{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "4ad86aaf",
   "metadata": {},
   "source": [
    "# zShim_off Images"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "c419aadc",
   "metadata": {
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-latest.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import plotly.graph_objects as go\n",
    "from plotly.subplots import make_subplots\n",
    "import numpy as np\n",
    "import math\n",
    "import nibabel as nib\n",
    "import matplotlib.pyplot as plt\n",
    "from math import ceil\n",
    "from scipy.interpolate import interp1d\n",
    "import time\n",
    "from ipywidgets import interactive, HBox, widgets, interact\n",
    "from plotly.offline import download_plotlyjs, init_notebook_mode, plot, iplot\n",
    "from IPython.core.display import display, HTML\n",
    "init_notebook_mode(connected=True)\n",
    "config={'showLink': False, 'displayModeBar': False}"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "9a2e2cd7",
   "metadata": {
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "def load_image(path):\n",
    "    nii_img = nib.load(path)\n",
    "    nii_data = nii_img.get_fdata()\n",
    "\n",
    "    number_of_slices = nii_data.shape[2]\n",
    "    number_of_frames = nii_data.shape[3]\n",
    "\n",
    "    layers = []\n",
    "\n",
    "    for frame in range(number_of_frames):\n",
    "        for s in range(number_of_slices):\n",
    "                layers.append(nii_data[:,:,s,frame])\n",
    "    \n",
    "    return layers\n",
    "\n",
    "def mapp(list_value, range_1,range_2):\n",
    "    m = interp1d(range_1,range_2)\n",
    "    return m(list_value)\n",
    "\n",
    "def compare_scans(scans,nb_frames,file_name):\n",
    "    newmap = np.concatenate((scans[0],scans[1],scans[2]), axis=1)\n",
    "    new_title = \"Echo1\\t\\t\\tEcho2\\t\\t\\tEcho3\"\n",
    "    \n",
    "    data = []\n",
    "    for i in range(nb_frames):\n",
    "        current = np.rot90(newmap[i],3)\n",
    "        data_c = go.Heatmap(z = current, \n",
    "                            visible = False,\n",
    "                            xtype = \"scaled\", \n",
    "                            ytype = \"scaled\",\n",
    "                            colorscale = \"gray\",\n",
    "                            showscale = False,\n",
    "                            hoverinfo = \"skip\"\n",
    "                            #colorbar = dict(title = dict(text = \"B<sub>0</sub> (Hz)\"))\n",
    "                           )\n",
    "        data.append(data_c)\n",
    "    data[0]['visible'] = True\n",
    "\n",
    "    # Create steps and slider\n",
    "    steps = []\n",
    "    for i in range(nb_frames):\n",
    "        step = dict(\n",
    "            method = 'restyle',  \n",
    "            args = ['visible', [False]*n],\n",
    "            label = str(i+1)\n",
    "        )\n",
    "        step['args'][1][i] = True # Toggle i'th trace to \"visible\"\n",
    "        steps.append(step)\n",
    "\n",
    "    sliders = [dict(\n",
    "        active = 0,\n",
    "        currentvalue = {'prefix':\"Current slice is: <b>\"},\n",
    "        pad = {\"t\": 50, \"b\": 10},\n",
    "        steps = steps\n",
    "    )]\n",
    "\n",
    "    # Setup the layout of the figure\n",
    "    layout = go.Layout(\n",
    "        title = new_title, \n",
    "        width=800,\n",
    "        height=500,\n",
    "        margin=go.layout.Margin(\n",
    "            l=50,\n",
    "            r=50,\n",
    "            b=60,\n",
    "            t=35,\n",
    "        ),\n",
    "        showlegend = False,\n",
    "        autosize = False,\n",
    "        sliders=sliders,\n",
    "        xaxis = dict(showgrid = False,\n",
    "                     showticklabels= False),\n",
    "        yaxis = dict(showgrid = False,\n",
    "                     showticklabels = False),\n",
    "        font = dict(family=\"Courier New, monospace\",\n",
    "                    size=14),\n",
    "    )\n",
    "    \n",
    "\n",
    "    # Plot function saves as html or with ipplot\n",
    "    fig = dict(data=data, layout=layout)\n",
    "    plot(fig, filename = file_name, config = config)\n",
    "\n",
    "    #display(HTML('fig2.html'))\n",
    "    "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "7c6d03cb",
   "metadata": {
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "raw_images_path = [\"data/mag_echo1_zShim_Gc_220_alpha_60deg.nii\",\"data/mag_echo2_zShim_Gc_220_alpha_60deg.nii\",\n",
    "                                  \"data/mag_echo3_zShim_Gc_220_alpha_60deg.nii\"]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "1e6cedbf",
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>                        <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.58.4\n",
       "* Copyright 2012-2020, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}((function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,(function(t){return i(e[o][1][t]||t)}),u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans', verdana, arial, sans-serif;position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":778}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1365}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":929}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":942}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":952}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":641}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":961}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":980}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":994}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":1001}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":1007}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":1022}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":1033}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":755}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":1041}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1366}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":1051}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":1060}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1367}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1073}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1083}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1095}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1101}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1105}],25:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/image\")},{\"../src/traces/image\":1113}],26:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./image\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./treemap\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./image\":25,\"./indicator\":27,\"./isosurface\":28,\"./mesh3d\":29,\"./ohlc\":30,\"./parcats\":31,\"./parcoords\":32,\"./pie\":33,\"./pointcloud\":34,\"./sankey\":35,\"./scatter3d\":36,\"./scattercarpet\":37,\"./scattergeo\":38,\"./scattergl\":39,\"./scattermapbox\":40,\"./scatterpolar\":41,\"./scatterpolargl\":42,\"./scatterternary\":43,\"./sort\":44,\"./splom\":45,\"./streamtube\":46,\"./sunburst\":47,\"./surface\":48,\"./table\":49,\"./treemap\":50,\"./violin\":51,\"./volume\":52,\"./waterfall\":53}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1121}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1127}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1132}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1137}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1146}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1156}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1167}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1176}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1182}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1220}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1227}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1235}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1248}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1258}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1266}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1273}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1281}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1369}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1290}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1298}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1306}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1315}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1323}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/treemap\")},{\"../src/traces/treemap\":1332}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1344}],52:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1352}],53:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1360}],54:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),f=i(),h=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),new o({turntable:u,orbit:f,matrix:h},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map((function(e){return t[e]})),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach((function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))})),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":480,\"orbit-camera-controller\":501,\"turntable-camera-controller\":581}],55:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return f(t.source,e.source)||t.index-e.index}function u(t,e){return f(t.target,e.target)||t.index-e.index}function f(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function h(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function m(t){return t.index}function v(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}function _(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort((function(t,e){return t.length-e.length}));var f={};for(o=0;o<u.length;o++){var h=u[o].slice(-2);f[h[0]]||(f[h[0]]={}),f[h[0]][h[1]]=!0}t.links.forEach((function(t){var e=t.target.index,r=t.source.index;e===r||f[r]&&f[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1}))}else t.links.forEach((function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)}))}function w(t,e){var r=0,n=0;t.links.forEach((function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach((function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)})))})),t.links.forEach((function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),H(t,e)&&(t.circularLinkType=t.source.circularLinkType))}))}function T(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function k(t,e){var r=0;t.sourceLinks.forEach((function(t){r=t.circular&&!H(t,e)?r+1:r}));var n=0;return t.targetLinks.forEach((function(t){n=t.circular&&!H(t,e)?n+1:n})),r+n}function M(t){var e=t.source.sourceLinks,r=0;e.forEach((function(t){r=t.circular?r+1:r}));var n=t.target.targetLinks,i=0;return n.forEach((function(t){i=t.circular?i+1:i})),!(r>1||i>1)}function A(t,e,r){return t.sort(E),t.forEach((function(n,i){var a,o,s=0;if(H(n,r)&&M(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}})),t}function S(t,r,i,a){var o=e.min(t.links,(function(t){return t.source.y0}));t.links.forEach((function(t){t.circular&&(t.circularPathData={})})),A(t.links.filter((function(t){return\"top\"==t.circularLinkType})),r,a),A(t.links.filter((function(t){return\"bottom\"==t.circularLinkType})),r,a),t.links.forEach((function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+10,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,H(e,a)&&M(e))e.circularPathData.leftSmallArcRadius=10+e.width/2,e.circularPathData.leftLargeArcRadius=10+e.width/2,e.circularPathData.rightSmallArcRadius=10+e.width/2,e.circularPathData.rightLargeArcRadius=10+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter((function(t){return t.source.column==s&&t.circularLinkType==l}));\"bottom\"==e.circularLinkType?c.sort(L):c.sort(C);var u=0;c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=10+e.width/2+u,e.circularPathData.leftLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),s=e.target.column,c=t.links.filter((function(t){return t.target.column==s&&t.circularLinkType==l})),\"bottom\"==e.circularLinkType?c.sort(P):c.sort(I),u=0,c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=10+e.width/2+u,e.circularPathData.rightLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var f=n.linkHorizontal().source((function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]})).target((function(t){return[t.target.x0,t.y1]}));e.path=f(e)}}))}function E(t,e){return z(t)==z(e)?\"bottom\"==t.circularLinkType?L(t,e):C(t,e):z(e)-z(t)}function C(t,e){return t.y0-e.y0}function L(t,e){return e.y0-t.y0}function I(t,e){return t.y1-e.y1}function P(t,e){return e.y1-t.y1}function z(t){return t.target.column-t.source.column}function O(t){return t.target.x0-t.source.x1}function D(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1+n:t.y1-n}function R(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1-n:t.y1+n}function F(t,e,r,n){t.links.forEach((function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach((function(o){if(o.column==a){var c,u=s/(l+1),f=Math.pow(1-u,3),h=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=f*i.y0+h*i.y0+p*i.y1+d*i.y1,m=g-i.width/2,v=g+i.width/2;m>o.y0&&m<o.y1?(c=o.y1-m+10,c=\"bottom\"==o.circularLinkType?c:-c,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&B(o,t)&&N(t,c,e,r)}))):(v>o.y0&&v<o.y1||m<o.y0&&v>o.y1)&&(c=v-o.y0+10,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&N(t,c,e,r)})))}}))}}))}function B(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function N(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach((function(t){t.y1=t.y1+e})),t.sourceLinks.forEach((function(t){t.y0=t.y0+e}))),t}function j(t,e,r,n){t.nodes.forEach((function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter((function(t){return b(t.source,r)==b(i,r)})),o=a.length;o>1&&a.sort((function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!V(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=R(e,t);return t.y1-r}if(e.target.column>t.target.column)return R(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0}));var s=i.y0;a.forEach((function(t){t.y0=s+t.width/2,s+=t.width})),a.forEach((function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}}))}))}function U(t,e,r){t.nodes.forEach((function(e){var n=t.links.filter((function(t){return b(t.target,r)==b(e,r)})),i=n.length;i>1&&n.sort((function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!V(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=D(e,t);return t.y0-r}if(t.source.column<e.source.column)return D(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0}));var a=e.y0;n.forEach((function(t){t.y1=a+t.width/2,a+=t.width})),n.forEach((function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}}))}))}function V(t,e){return q(t)==q(e)}function q(t){return t.y0-t.y1>0?\"up\":\"down\"}function H(t,e){return b(t.source,e)==b(t.target,e)}function G(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach((function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)})),0==o||0==s){var l=e.min(i,(function(t){return t.y0})),c=(n-r)/(e.max(i,(function(t){return t.y1}))-l);i.forEach((function(t){var e=(t.y1-t.y0)*c;t.y0=(t.y0-l)*c,t.y1=t.y0+e})),a.forEach((function(t){t.y0=(t.y0-l)*c,t.y1=(t.y1-l)*c,t.width=t.width*c}))}}t.sankeyCircular=function(){var t,n,i=0,a=0,b=1,T=1,M=24,A=m,E=o,C=v,L=y,I=32,P=2,z=null;function O(){var t={nodes:C.apply(null,arguments),links:L.apply(null,arguments)};D(t),_(t,A,z),R(t),B(t),w(t,A),N(t,I,A),V(t);for(var e=4,r=0;r<e;r++)j(t,T,A),U(t,T,A),F(t,a,T,A),j(t,T,A),U(t,T,A);return G(t,a,T),S(t,P,T,A),t}function D(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,A);return t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})),t}function R(t){t.nodes.forEach((function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,h),e.sum(t.targetLinks,h)),t.sourceLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})),t.targetLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}))}))}function B(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.depth=n,t.sourceLinks.forEach((function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)}))}));for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.height=n,t.targetLinks.forEach((function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)}))}));t.nodes.forEach((function(t){t.column=Math.floor(E.call(null,t,n))}))}function N(o,s,l){var c=r.nest().key((function(t){return t.column})).sortKeys(e.ascending).entries(o.nodes).map((function(t){return t.values}));!function(r){if(n){var s=1/0;c.forEach((function(t){var e=T*n/(t.length+1);s=e<s?e:s})),t=s}var l=e.min(c,(function(r){return(T-a-(r.length-1)*t)/e.sum(r,h)}));l*=.3,o.links.forEach((function(t){t.width=t.value*l}));var u=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,(function(t){return t.column}));return t.links.forEach((function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))})),{top:r=r>0?r+25+10:r,bottom:n=n>0?n+25+10:n,left:a=a>0?a+25+10:a,right:i=i>0?i+25+10:i}}(o),f=function(t,r){var n=e.max(t.nodes,(function(t){return t.column})),o=b-i,s=T-a,l=o/(o+r.right+r.left),c=s/(s+r.top+r.bottom);return i=i*l+r.left,b=0==r.right?b:b*l,a=a*c+r.top,T*=c,t.nodes.forEach((function(t){t.x0=i+t.column*((b-i-M)/n),t.x1=t.x0+M})),c}(o,u);l*=f,o.links.forEach((function(t){t.width=t.value*l})),c.forEach((function(t){var e=t.length;t.forEach((function(t,n){t.depth==c.length-1&&1==e||0==t.depth&&1==e?(t.y0=T/2-t.value*l,t.y1=t.y0+t.value*l):t.partOfCycle?0==k(t,r)?(t.y0=T/2+n,t.y1=t.y0+t.value*l):\"top\"==t.circularLinkType?(t.y0=a+n,t.y1=t.y0+t.value*l):(t.y0=T-t.value*l-n,t.y1=t.y0+t.value*l):0==u.top||0==u.bottom?(t.y0=(T-a)/e*n,t.y1=t.y0+t.value*l):(t.y0=(T-a)/2-e/2+n,t.y1=t.y0+t.value*l)}))}))}(l),y();for(var u=1,m=s;m>0;--m)v(u*=.99,l),y();function v(t,r){var n=c.length;c.forEach((function(i){var a=i.length,o=i[0].depth;i.forEach((function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&k(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}}))}))}function y(){c.forEach((function(e){var r,n,i,o=a,s=e.length;for(e.sort(f),i=0;i<s;++i)(n=o-(r=e[i]).y0)>0&&(r.y0+=n,r.y1+=n),o=r.y1+t;if((n=o-t-T)>0)for(o=r.y0-=n,r.y1-=n,i=s-2;i>=0;--i)(n=(r=e[i]).y1+t-o)>0&&(r.y0-=n,r.y1-=n),o=r.y0}))}}function V(t){t.nodes.forEach((function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)})),t.nodes.forEach((function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach((function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)})),t.targetLinks.forEach((function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)}))}))}return O.nodeId=function(t){return arguments.length?(A=\"function\"==typeof t?t:s(t),O):A},O.nodeAlign=function(t){return arguments.length?(E=\"function\"==typeof t?t:s(t),O):E},O.nodeWidth=function(t){return arguments.length?(M=+t,O):M},O.nodePadding=function(e){return arguments.length?(t=+e,O):t},O.nodes=function(t){return arguments.length?(C=\"function\"==typeof t?t:s(t),O):C},O.links=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),O):L},O.size=function(t){return arguments.length?(i=a=0,b=+t[0],T=+t[1],O):[b-i,T-a]},O.extent=function(t){return arguments.length?(i=+t[0][0],b=+t[1][0],a=+t[0][1],T=+t[1][1],O):[[i,a],[b,T]]},O.iterations=function(t){return arguments.length?(I=+t,O):I},O.circularLinkGap=function(t){return arguments.length?(P=+t,O):P},O.nodePaddingRatio=function(t){return arguments.length?(n=+t,O):n},O.sortNodes=function(t){return arguments.length?(z=t,O):z},O.update=function(t){return w(t,A),V(t),t.links.forEach((function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<T?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)})),j(t,T,A,!1),U(t,T,A),S(t,P,T,A),t},O},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165,\"elementary-circuits-directed-graph\":179}],56:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)}(this,(function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function f(t){return(t.y0+t.y1)/2}function h(t){return f(t.source)*t.value}function p(t){return f(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function m(t){return t.links}function v(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,T=g,k=m,M=32;function A(){var t={nodes:T.apply(null,arguments),links:k.apply(null,arguments)};return S(t),E(t),C(t),L(t),I(t),t}function S(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,_);t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=v(e,n)),\"object\"!=typeof i&&(i=t.target=v(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)}))}function E(t){t.nodes.forEach((function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))}))}function C(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.depth=a,t.sourceLinks.forEach((function(t){n.indexOf(t.target)<0&&n.push(t.target)}))}));for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.height=a,t.targetLinks.forEach((function(t){n.indexOf(t.source)<0&&n.push(t.source)}))}));var o=(i-t-x)/(a-1);e.nodes.forEach((function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x}))}function L(t){var i=r.nest().key((function(t){return t.x0})).sortKeys(e.ascending).entries(t.nodes).map((function(t){return t.values}));!function(){var r=e.max(i,(function(t){return t.length})),a=2/3*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,(function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)}));i.forEach((function(t){t.forEach((function(t,e){t.y1=(t.y0=e)+t.value*o}))})),t.links.forEach((function(t){t.width=t.value*o}))}(),d();for(var a=1,o=M;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach((function(r){r.forEach((function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,h)/e.sum(r.targetLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function l(t){i.slice().reverse().forEach((function(r){r.forEach((function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function d(){i.forEach((function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)(r=a-(e=t[i]).y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)(r=(e=t[i]).y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0}))}}function I(t){t.nodes.forEach((function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)})),t.nodes.forEach((function(t){var e=t.y0,r=e;t.sourceLinks.forEach((function(t){t.y0=e+t.width/2,e+=t.width})),t.targetLinks.forEach((function(t){t.y1=r+t.width/2,r+=t.width}))}))}return A.update=function(t){return I(t),t},A.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),A):_},A.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),A):w},A.nodeWidth=function(t){return arguments.length?(x=+t,A):x},A.nodePadding=function(t){return arguments.length?(b=+t,A):b},A.nodes=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),A):T},A.links=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),A):k},A.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],A):[i-t,y-n]},A.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],A):[[t,n],[i,y]]},A.iterations=function(t){return arguments.length?(M=+t,A):M},A},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165}],57:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":58}],58:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),f=t(\"dtype\"),h=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(f(e.dtype))(m):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=m));for(var v=0;v<m;++v)d[v]=v;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]),c=b[o]||(b[o]=[]),u=x[o]||(x[o]=[]),f=l.length;if(++o>r||s>1073741824){for(var h=0;h<a.length;h++)l.push(a[h]),c.push(s),u.push(null,null,null,null);return f}if(l.push(a[0]),c.push(s),a.length<=1)return u.push(null,null,null,null),f;for(var p=.5*i,d=e+p,m=n+p,v=[],_=[],w=[],T=[],k=1,M=a.length;k<M;k++){var A=a[k],S=g[2*A],E=g[2*A+1];S<d?E<m?v.push(A):_.push(A):E<m?w.push(A):T.push(A)}return s<<=2,u.push(t(e,n,p,v,o,s),t(e,m,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,m,p,T,o,s+3)),f}(0,0,1,d,0,1);for(var w=0,T=0;T<y.length;T++){var k=y[T];if(d.set)d.set(k,w);else for(var M=0,A=k.length;M<A;M++)d[M+w]=k[M];var S=w+y[T].length;_[T]=[w,S],w=S}return d.range=function(){var e,r=[],n=arguments.length;for(;n--;)r[n]=arguments[n];if(u(r[r.length-1])){var o=r.pop();r.length||null==o.x&&null==o.l&&null==o.left||(r=[o],e={}),e=s(o,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var c=a.apply(void 0,r),f=[Math.min(c.x,c.x+c.width),Math.min(c.y,c.y+c.height),Math.max(c.x,c.x+c.width),Math.max(c.y,c.y+c.height)],d=f[0],g=f[1],m=f[2],v=f[3],b=p([d,g,m,v],i),_=b[0],w=b[1],T=b[2],k=b[3],M=l(e.level,y.length);if(null!=e.d){var A;\"number\"==typeof e.d?A=[e.d,e.d]:e.d.length&&(A=e.d),M=Math.min(Math.max(Math.ceil(-h(Math.abs(A[0])/(i[2]-i[0]))),Math.ceil(-h(Math.abs(A[1])/(i[3]-i[1])))),M)}if(M=Math.min(M,y.length),e.lod)return E(_,w,T,k,M);var S=[];function C(e,r,n,i,a,o){if(null!==a&&null!==o&&!(_>e+n||w>r+n||T<e||k<r||i>=M||a===o)){var s=y[i];void 0===o&&(o=s.length);for(var l=a;l<o;l++){var c=s[l],u=t[2*c],f=t[2*c+1];u>=d&&u<=m&&f>=g&&f<=v&&S.push(c)}var h=x[i],p=h[4*a+0],b=h[4*a+1],A=h[4*a+2],E=h[4*a+3],I=L(h,a+1),P=.5*n,z=i+1;C(e,r,P,z,p,b||A||E||I),C(e,r+P,P,z,b,A||E||I),C(e+P,r,P,z,A,E||I),C(e+P,r+P,P,z,E,I)}}function L(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}return C(0,0,1,0,0,1),S},d;function E(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=C(t,e,s),f=C(r,i,s),h=n.ge(l,u),p=n.gt(l,f,h,l.length-1);o[s]=[h+c,p+c]}return o}function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":70,\"binary-search-bounds\":96,clamp:120,defined:170,dtype:175,\"flatten-vertex-data\":244,\"is-obj\":468,\"math-log2\":479,\"parse-rect\":504,\"pick-by-alias\":511}],59:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");function i(t){var e=0;if(t&&t.length>0){e+=Math.abs(a(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(a(t[r]))}return e}function a(t){var e,r,n,i,a,s,l=0,c=t.length;if(c>2){for(s=0;s<c;s++)s===c-2?(n=c-2,i=c-1,a=0):s===c-1?(n=c-1,i=0,a=1):(n=s,i=s+1,a=s+2),e=t[n],r=t[i],l+=(o(t[a][0])-o(e[0]))*Math.sin(o(r[1]));l=6378137*l*6378137/2}return l}function o(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,(function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return i(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=i(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)}),0)}},{\"@turf/meta\":63}],60:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");r.default=function(t){var e=[1/0,1/0,-1/0,-1/0];return n.coordEach(t,(function(t){e[0]>t[0]&&(e[0]=t[0]),e[1]>t[1]&&(e[1]=t[1]),e[2]<t[0]&&(e[2]=t[0]),e[3]<t[1]&&(e[3]=t[1])})),e}},{\"@turf/meta\":63}],61:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,(function(t){r+=t[0],a+=t[1],o++})),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":62,\"@turf/meta\":63}],62:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:386e-9,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return i(t,e)})),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return a(t,e)})),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return o(t,e)})),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=f,r.lengthToRadians=h,r.lengthToDegrees=function(t,e){return p(h(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return f(h(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach((function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")}))},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],63:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,f,h=0,p=0,d=t.type,g=\"FeatureCollection\"===d,m=\"Feature\"===d,v=g?t.features.length:1,y=0;y<v;y++){l=(f=!!(u=g?t.features[y].geometry:m?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=f?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(h=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-h;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-h;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,f,h=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,f=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,h,c,u,f))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],h,c,u,f))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,h,c,u,f))return!1;h++}}function l(t,e){s(t,(function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}}))}function c(t,e){l(t,(function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,f=0;return!1!==i(t,(function(i,s,h,p,d){if(void 0===l||r>c||p>u||d>f)return l=i,c=r,u=p,f=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i}))&&void 0}}}))}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,(function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}}))}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,(function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)}),n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.coordAll=function(t){var e=[];return i(t,(function(t){e.push(t)})),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,(function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)})),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,(function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)})),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,(function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0})),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,(function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)})),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":62}],64:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":259,\"gl-vao\":358,\"weak-map\":602}],65:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map((function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t}))}},{}],66:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map((function(t,i){var o=i+e,s=String(o).length;return n(o,a-s)+r+t})).join(\"\\n\")}},{\"pad-left\":502}],67:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":548}],68:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter((function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1}))};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:119,\"delaunay-triangulate\":171}],69:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":68,\"simplicial-complex-boundary\":555}],70:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],71:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)isNaN(t[s])||(t[s]=0===c?.5:(t[s]-o)/c)}}return t}},{\"array-bounds\":70}],72:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],73:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"object-assign\");\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>\n",
       " * @license  MIT\n",
       " */function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function f(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var h=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function m(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function v(t,e,r,n,i){throw new h.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||v(t,!0,e,\"==\",h.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(f(t)&&f(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=T(t),f=T(e);if(u.length!==f.length)return!1;for(u.sort(),f.sort(),c=u.length-1;c>=0;c--)if(u[c]!==f[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&v(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&v(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}h.AssertionError=function(t){this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=function(t){return g(m(t.actual),128)+\" \"+t.operator+\" \"+g(m(t.expected),128)}(this),this.generatedMessage=!0);var e=t.stackStartFunction||v;if(Error.captureStackTrace)Error.captureStackTrace(this,e);else{var r=new Error;if(r.stack){var n=r.stack,i=d(e),a=n.indexOf(\"\\n\"+i);if(a>=0){var o=n.indexOf(\"\\n\",a+1);n=n.substring(o+1)}this.stack=n}}},o.inherits(h.AssertionError,Error),h.fail=v,h.ok=y,h.equal=function(t,e,r){t!=e&&v(t,e,r,\"==\",h.equal)},h.notEqual=function(t,e,r){t==e&&v(t,e,r,\"!=\",h.notEqual)},h.deepEqual=function(t,e,r){x(t,e,!1)||v(t,e,r,\"deepEqual\",h.deepEqual)},h.deepStrictEqual=function(t,e,r){x(t,e,!0)||v(t,e,r,\"deepStrictEqual\",h.deepStrictEqual)},h.notDeepEqual=function(t,e,r){x(t,e,!1)&&v(t,e,r,\"notDeepEqual\",h.notDeepEqual)},h.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&v(e,r,n,\"notDeepStrictEqual\",t)},h.strictEqual=function(t,e,r){t!==e&&v(t,e,r,\"===\",h.strictEqual)},h.notStrictEqual=function(t,e,r){t===e&&v(t,e,r,\"!==\",h.notStrictEqual)},h.throws=function(t,e,r){w(!0,t,e,r)},h.doesNotThrow=function(t,e,r){w(!1,t,e,r)},h.ifError=function(t){if(t)throw t},h.strict=n((function t(e,r){e||v(e,!0,r,\"==\",t)}),h,{equal:h.strictEqual,deepEqual:h.deepStrictEqual,notEqual:h.notStrictEqual,notDeepEqual:h.notDeepStrictEqual}),h.strict.strict=h.strict;var T=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":499,\"util/\":76}],74:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],75:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],76:[function(t,e,r){(function(e,n){(function(){var i=/%[sdj%]/g;r.format=function(t){if(!v(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,(function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}})),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&T(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return v(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(v(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(m(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach((function(t,r){e[t]=!0})),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return f(e);if(0===o.length){if(T(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return f(e)}var c,b=\"\",k=!1,M=[\"{\",\"}\"];(p(e)&&(k=!0,M=[\"[\",\"]\"]),T(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+f(e)),0!==o.length||k&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=k?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)E(e,String(o))?a.push(h(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach((function(i){i.match(/^\\d+$/)||a.push(h(t,e,r,n,i,!0))})),a}(t,e,n,s,o):o.map((function(r){return h(t,e,n,s,r,k)})),t.seen.pop(),function(t,e,r){if(t.reduce((function(t,e){return e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1}),0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,M)):M[0]+b+M[1]}function f(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function h(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),E(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map((function(t){return\"  \"+t})).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map((function(t){return\"   \"+t})).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function m(t){return\"number\"==typeof t}function v(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===k(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===k(t)}function w(t){return b(t)&&(\"[object Error]\"===k(t)||t instanceof Error)}function T(t){return\"function\"==typeof t}function k(t){return Object.prototype.toString.call(t)}function M(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=m,r.isString=v,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=T,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var A=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(){var t=new Date,e=[M(t.getHours()),M(t.getMinutes()),M(t.getSeconds())].join(\":\");return[t.getDate(),A[t.getMonth()],e].join(\" \")}function E(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){console.log(\"%s - %s\",S(),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":75,_process:526,inherits:74}],77:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],78:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(o=0;o<=r;++o)a[r][o]=1;var c=new Array(r+1);for(o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),f=i(u[r+1]);0===f&&(f=1);var h=new Array(r+1);for(o=0;o<=r;++o)h[o]=i(u[o])/f;return h};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":547}],79:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){var e,r,n=c(t),o=n[0],s=n[1],l=new a(function(t,e,r){return 3*(e+r)/4-r}(0,o,s)),u=0,f=s>0?o-4:o;for(r=0;r<f;r+=4)e=i[t.charCodeAt(r)]<<18|i[t.charCodeAt(r+1)]<<12|i[t.charCodeAt(r+2)]<<6|i[t.charCodeAt(r+3)],l[u++]=e>>16&255,l[u++]=e>>8&255,l[u++]=255&e;2===s&&(e=i[t.charCodeAt(r)]<<2|i[t.charCodeAt(r+1)]>>4,l[u++]=255&e);1===s&&(e=i[t.charCodeAt(r)]<<10|i[t.charCodeAt(r+1)]<<4|i[t.charCodeAt(r+2)]>>2,l[u++]=e>>8&255,l[u++]=255&e);return l},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],80:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],81:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],82:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":90}],83:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c,u,f=0;if(i(e))c=e.clone();else if(\"string\"==typeof e)c=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))c=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),f-=256;c=a(e)}}if(n(r))c.mul(r[1]),u=r[0].clone();else if(i(r))u=r.clone();else if(\"string\"==typeof r)u=o(r);else if(r)if(r===Math.floor(r))u=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),f+=256;u=a(r)}else u=a(1);f>0?c=c.ushln(f):f<0&&(u=u.ushln(-f));return s(c,u)}},{\"./div\":82,\"./is-rat\":84,\"./lib/is-bn\":88,\"./lib/num-to-bn\":89,\"./lib/rationalize\":90,\"./lib/str-to-bn\":91}],84:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":88}],85:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":99}],86:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":85}],87:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":97,\"double-bits\":173}],88:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":99}],89:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":99,\"double-bits\":173}],90:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":85,\"./num-to-bn\":89}],91:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":99}],92:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],93:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":85}],94:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],95:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,f=n(l.ushln(u).divRound(r));return c*(s+f*Math.pow(2,-u))}var h=r.bitLength()-l.bitLength()+53;f=n(l.ushln(h).divRound(r));return h<1023?c*f*Math.pow(2,-h):(f*=Math.pow(2,-1023),c*f*Math.pow(2,1023-h))}},{\"./lib/bn-to-num\":86,\"./lib/ctz\":87}],96:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],97:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],98:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,f,h,p,d,g,m=null==e.cutoff?.25:e.cutoff,v=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(f=(h=t).getContext(\"2d\"),r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(h=t.canvas,f=t,r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),T=Array(s+1),k=Array(s);for(d=0,g=r*o;d<g;d++){var M=l[d];x[d]=1===M?0:0===M?i:Math.pow(Math.max(0,.5-M),2),b[d]=1===M?i:0===M?0:Math.pow(Math.max(0,M-.5),2)}a(x,r,o,_,w,k,T),a(b,r,o,_,w,k,T);var A=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)A[d]=n(1-((x[d]-b[d])/v+m),0,1);return A};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:120}],99:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var f=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)f*=e;this.imuln(f),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],f=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function h(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,f=67108863&l,h=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=h;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+f)/67108864|0,f=67108863&o}r.words[c]=0|f,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var h=u[t],p=f[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[h-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],f=8191&u,h=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,m=0|o[2],v=8191&m,y=m>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],T=8191&w,k=w>>>13,M=0|o[5],A=8191&M,S=M>>>13,E=0|o[6],C=8191&E,L=E>>>13,I=0|o[7],P=8191&I,z=I>>>13,O=0|o[8],D=8191&O,R=O>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,Q=0|s[4],$=8191&Q,tt=Q>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ft=8191&ut,ht=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var mt=(c+(n=Math.imul(f,U))|0)+((8191&(i=(i=Math.imul(f,V))+Math.imul(h,U)|0))<<13)|0;c=((a=Math.imul(h,V))+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var vt=(c+(n=n+Math.imul(f,H)|0)|0)+((8191&(i=(i=i+Math.imul(f,G)|0)+Math.imul(h,H)|0))<<13)|0;c=((a=a+Math.imul(h,G)|0)+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(v,U),i=(i=Math.imul(v,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(f,W)|0)|0)+((8191&(i=(i=i+Math.imul(f,X)|0)+Math.imul(h,W)|0))<<13)|0;c=((a=a+Math.imul(h,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(v,H)|0,i=(i=i+Math.imul(v,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(f,J)|0)|0)+((8191&(i=(i=i+Math.imul(f,K)|0)+Math.imul(h,J)|0))<<13)|0;c=((a=a+Math.imul(h,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(T,U),i=(i=Math.imul(T,V))+Math.imul(k,U)|0,a=Math.imul(k,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(v,W)|0,i=(i=i+Math.imul(v,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(f,$)|0)|0)+((8191&(i=(i=i+Math.imul(f,tt)|0)+Math.imul(h,$)|0))<<13)|0;c=((a=a+Math.imul(h,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(A,U),i=(i=Math.imul(A,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(T,H)|0,i=(i=i+Math.imul(T,G)|0)+Math.imul(k,H)|0,a=a+Math.imul(k,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(v,J)|0,i=(i=i+Math.imul(v,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,$)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,$)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(f,rt)|0)|0)+((8191&(i=(i=i+Math.imul(f,nt)|0)+Math.imul(h,rt)|0))<<13)|0;c=((a=a+Math.imul(h,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(A,H)|0,i=(i=i+Math.imul(A,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(T,W)|0,i=(i=i+Math.imul(T,X)|0)+Math.imul(k,W)|0,a=a+Math.imul(k,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(v,$)|0,i=(i=i+Math.imul(v,tt)|0)+Math.imul(y,$)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(f,at)|0)|0)+((8191&(i=(i=i+Math.imul(f,ot)|0)+Math.imul(h,at)|0))<<13)|0;c=((a=a+Math.imul(h,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(P,U),i=(i=Math.imul(P,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(A,W)|0,i=(i=i+Math.imul(A,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(T,J)|0,i=(i=i+Math.imul(T,K)|0)+Math.imul(k,J)|0,a=a+Math.imul(k,K)|0,n=n+Math.imul(b,$)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,$)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(v,rt)|0,i=(i=i+Math.imul(v,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var Tt=(c+(n=n+Math.imul(f,lt)|0)|0)+((8191&(i=(i=i+Math.imul(f,ct)|0)+Math.imul(h,lt)|0))<<13)|0;c=((a=a+Math.imul(h,ct)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(P,H)|0,i=(i=i+Math.imul(P,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(A,J)|0,i=(i=i+Math.imul(A,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(T,$)|0,i=(i=i+Math.imul(T,tt)|0)+Math.imul(k,$)|0,a=a+Math.imul(k,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(v,at)|0,i=(i=i+Math.imul(v,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var kt=(c+(n=n+Math.imul(f,ft)|0)|0)+((8191&(i=(i=i+Math.imul(f,ht)|0)+Math.imul(h,ft)|0))<<13)|0;c=((a=a+Math.imul(h,ht)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(P,W)|0,i=(i=i+Math.imul(P,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(A,$)|0,i=(i=i+Math.imul(A,tt)|0)+Math.imul(S,$)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(T,rt)|0,i=(i=i+Math.imul(T,nt)|0)+Math.imul(k,rt)|0,a=a+Math.imul(k,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(v,lt)|0,i=(i=i+Math.imul(v,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ft)|0,i=(i=i+Math.imul(d,ht)|0)+Math.imul(g,ft)|0,a=a+Math.imul(g,ht)|0;var Mt=(c+(n=n+Math.imul(f,dt)|0)|0)+((8191&(i=(i=i+Math.imul(f,gt)|0)+Math.imul(h,dt)|0))<<13)|0;c=((a=a+Math.imul(h,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(P,J)|0,i=(i=i+Math.imul(P,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,$)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,$)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(A,rt)|0,i=(i=i+Math.imul(A,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(T,at)|0,i=(i=i+Math.imul(T,ot)|0)+Math.imul(k,at)|0,a=a+Math.imul(k,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(v,ft)|0,i=(i=i+Math.imul(v,ht)|0)+Math.imul(y,ft)|0,a=a+Math.imul(y,ht)|0;var At=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(P,$)|0,i=(i=i+Math.imul(P,tt)|0)+Math.imul(z,$)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(A,at)|0,i=(i=i+Math.imul(A,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(T,lt)|0,i=(i=i+Math.imul(T,ct)|0)+Math.imul(k,lt)|0,a=a+Math.imul(k,ct)|0,n=n+Math.imul(b,ft)|0,i=(i=i+Math.imul(b,ht)|0)+Math.imul(_,ft)|0,a=a+Math.imul(_,ht)|0;var St=(c+(n=n+Math.imul(v,dt)|0)|0)+((8191&(i=(i=i+Math.imul(v,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,$)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,$)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(P,rt)|0,i=(i=i+Math.imul(P,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(A,lt)|0,i=(i=i+Math.imul(A,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(T,ft)|0,i=(i=i+Math.imul(T,ht)|0)+Math.imul(k,ft)|0,a=a+Math.imul(k,ht)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,$),i=(i=Math.imul(B,tt))+Math.imul(N,$)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(P,at)|0,i=(i=i+Math.imul(P,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(A,ft)|0,i=(i=i+Math.imul(A,ht)|0)+Math.imul(S,ft)|0,a=a+Math.imul(S,ht)|0;var Ct=(c+(n=n+Math.imul(T,dt)|0)|0)+((8191&(i=(i=i+Math.imul(T,gt)|0)+Math.imul(k,dt)|0))<<13)|0;c=((a=a+Math.imul(k,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(P,lt)|0,i=(i=i+Math.imul(P,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ft)|0,i=(i=i+Math.imul(C,ht)|0)+Math.imul(L,ft)|0,a=a+Math.imul(L,ht)|0;var Lt=(c+(n=n+Math.imul(A,dt)|0)|0)+((8191&(i=(i=i+Math.imul(A,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(P,ft)|0,i=(i=i+Math.imul(P,ht)|0)+Math.imul(z,ft)|0,a=a+Math.imul(z,ht)|0;var It=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(It>>>26)|0,It&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ft)|0,i=(i=i+Math.imul(D,ht)|0)+Math.imul(R,ft)|0,a=a+Math.imul(R,ht)|0;var Pt=(c+(n=n+Math.imul(P,dt)|0)|0)+((8191&(i=(i=i+Math.imul(P,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,ft),i=(i=Math.imul(B,ht))+Math.imul(N,ft)|0,a=Math.imul(N,ht);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var Ot=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,l[0]=mt,l[1]=vt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=Tt,l[8]=kt,l[9]=Mt,l[10]=At,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=It,l[16]=Pt,l[17]=zt,l[18]=Ot,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=h),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?h(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,f=(0|t.words[u])*(0|e.words[c]),h=67108863&f;s=67108863&(h=h+s|0),i+=(o=(o=o+(f/67108864|0)|0)+(h>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var f=l,h=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],m=r[u+p+o],v=n[u+p+o],y=f*m-h*v;v=f*v+h*m,m=y,r[u+p]=d+m,n[u+p]=g+v,r[u+p+o]=d-m,n[u+p+o]=g-v,p!==s&&(y=l*f-c*h,h=l*h+c*f,f=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),f=new Array(n),h=r.words;h.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,f,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*f[p];l[p]=s[p]*f[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,h,a,n,i),this.conjugate(h,a,n),this.normalize13b(h,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var f=0|this.words[c];this.words[c]=u<<26-a|f>>>a,u=f&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var f=l-1;f>=0;f--){var h=67108864*(0|n.words[i.length+f])+(0|n.words[i.length+f-1]);for(h=Math.min(h/o|0,67108863),n._ishlnsubmul(i,h,f);0!==n.negative;)h--,n.negative=0,n._ishlnsubmul(i,1,f),n.isZero()||(n.negative^=1);s&&(s.words[f]=h)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),f=e.clone();!e.isZero();){for(var h=0,p=1;0==(e.words[0]&p)&&h<26;++h,p<<=1);if(h>0)for(e.iushrn(h);h-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(f)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(f)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var f=0,h=1;0==(r.words[0]&h)&&f<26;++f,h<<=1);if(f>0)for(r.iushrn(f);f-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var m={k256:null,p224:null,p192:null,p25519:null};function v(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){v.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){v.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){v.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){v.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function T(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}v.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},v.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},v.prototype.split=function(t,e){t.iushrn(this.n,0,e)},v.prototype.imulK=function(t){return t.imul(this.k)},i(y,v),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,v),i(b,v),i(_,v),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(m[t])return m[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return m[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var f=this.pow(u,i),h=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,m=0;0!==g.cmp(s);m++)g=g.redSqr();n(m<d);var v=this.pow(f,new a(1).iushln(d-m-1));h=h.redMul(v),f=v.redSqr(),p=p.redMul(f),d=m}return h},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var f=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==f||0!==o?(o<<=1,o|=f,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new T(t)},i(T,w),T.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},T.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},T.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},T.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},T.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:108}],100:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),f=0;for(n=0;n<c;++n)n!==r&&(u[f++]=l[n]);if(1&r){var h=u[1];u[1]=u[0],u[0]=h}}}return o}},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return f(t);case 2:return\"function\"==typeof e?c(t,t,e,!0):h(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var f,h=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,h,p))>0){if(1===u&&n)a.init(s),f=a.sweepComplete(u,r,0,s,h,p,0,s,h,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),f=1===u?a.sweepBipartite(u,r,0,s,h,p,0,c,d,g):o(u,r,n,s,h,p,c,d,g),i.free(d),i.free(g))}i.free(h),i.free(p)}return f}}}function u(t,e){n.push([t,e])}function f(t){return n=[],c(t,t,u,!0),n}function h(t,e){return n=[],c(t,e,u,!1),n}},{\"./lib/intersect\":103,\"./lib/sweep\":107,\"typedarray-pool\":595}],102:[function(t,e,r){\"use strict\";var n=[\"d\",\"ax\",\"vv\",\"rs\",\"re\",\"rb\",\"ri\",\"bs\",\"be\",\"bb\",\"bi\"];function i(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],i=n.slice();t||i.splice(3,0,\"fp\");var a=[\"function \"+e+\"(\"+i.join()+\"){\"];function o(e,i){var o=function(t,e,r){var i=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),a=[\"function \",i,\"(\",n.join(),\"){\",\"var \",\"es\",\"=2*\",\"d\",\";\"],o=\"for(var i=rs,rp=es*rs;i<re;++i,rp+=es){var x0=rb[ax+rp],x1=rb[ax+rp+d],xi=ri[i];\",s=\"for(var j=bs,bp=es*bs;j<be;++j,bp+=es){var y0=bb[ax+bp],\"+(r?\"y1=bb[ax+bp+d],\":\"\")+\"yi=bi[j];\";return t?a.push(o,\"Q\",\":\",s):a.push(s,\"Q\",\":\",o),r?a.push(\"if(y1<x0||x1<y0)continue;\"):e?a.push(\"if(y0<=x0||x1<y0)continue;\"):a.push(\"if(y0<x0||x1<y0)continue;\"),a.push(\"for(var k=ax+1;k<d;++k){var r0=rb[k+rp],r1=rb[k+d+rp],b0=bb[k+bp],b1=bb[k+d+bp];if(r1<b0||b1<r0)continue Q;}var rv=vv(\"),e?a.push(\"yi,xi\"):a.push(\"xi,yi\"),a.push(\");if(rv!==void 0)return rv;}}}\"),{name:i,code:a.join(\"\")}}(e,i,t);r.push(o.code),a.push(\"return \"+o.name+\"(\"+n.join()+\");\")}a.push(\"if(re-rs>be-bs){\"),t?(o(!0,!1),a.push(\"}else{\"),o(!1,!1)):(a.push(\"if(fp){\"),o(!0,!0),a.push(\"}else{\"),o(!0,!1),a.push(\"}}else{if(fp){\"),o(!1,!0),a.push(\"}else{\"),o(!1,!1),a.push(\"}\")),a.push(\"}}return \"+e);var s=r.join(\"\")+a.join(\"\");return new Function(s)()}r.partial=i(!1),r.full=i(!0)},{}],103:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,w,T,k,M){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(6*r);v.length<a&&(n.free(v),v=n.mallocInt32(a));var o=i.nextPow2(2*r);y.length<o&&(n.free(y),y=n.mallocDouble(o))}(t,a+T);var A,S=0,E=2*t;x(S++,0,0,a,0,T,r?16:0,-1/0,1/0),r||x(S++,0,0,T,0,a,1,-1/0,1/0);for(;S>0;){var C=6*(S-=1),L=v[C],I=v[C+1],P=v[C+2],z=v[C+3],O=v[C+4],D=v[C+5],R=2*S,F=y[R],B=y[R+1],N=1&D,j=!!(16&D),U=u,V=w,q=k,H=M;if(N&&(U=k,V=M,q=u,H=w),!(2&D&&(P=p(t,L,I,P,U,V,B),I>=P)||4&D&&(I=d(t,L,I,P,U,V,F))>=P)){var G=P-I,Y=O-z;if(j){if(t*G*(G+Y)<1<<22){if(void 0!==(A=l.scanComplete(t,L,e,I,P,U,V,z,O,q,H)))return A;continue}}else{if(t*Math.min(G,Y)<128){if(void 0!==(A=o(t,L,e,N,I,P,U,V,z,O,q,H)))return A;continue}if(t*G*Y<1<<22){if(void 0!==(A=l.scanBipartite(t,L,e,N,I,P,U,V,z,O,q,H)))return A;continue}}var W=f(t,L,I,P,U,V,F,B);if(I<W)if(t*(W-I)<128){if(void 0!==(A=s(t,L+1,e,I,W,U,V,z,O,q,H)))return A}else if(L===t-2){if(void 0!==(A=N?l.sweepBipartite(t,e,z,O,q,H,I,W,U,V):l.sweepBipartite(t,e,I,W,U,V,z,O,q,H)))return A}else x(S++,L+1,I,W,z,O,N,-1/0,1/0),x(S++,L+1,z,O,I,W,1^N,-1/0,1/0);if(W<P){var X=c(t,L,z,O,q,H),Z=q[E*X+L],J=h(t,L,X,O,q,H,Z);if(J<O&&x(S++,L,W,P,J,O,(4|N)+(j?16:0),Z,B),z<X&&x(S++,L,W,P,z,X,(2|N)+(j?16:0),F,Z),X+1===J){if(void 0!==(A=j?_(t,L,e,W,P,U,V,X,q,H[X]):b(t,L,e,N,W,P,U,V,X,q,H[X])))return A}else if(X<J){var K;if(j){if(K=g(t,L,W,P,U,V,Z),W<K){var Q=h(t,L,W,K,U,V,Z);if(L===t-2){if(W<Q&&void 0!==(A=l.sweepComplete(t,e,W,Q,U,V,X,J,q,H)))return A;if(Q<K&&void 0!==(A=l.sweepBipartite(t,e,Q,K,U,V,X,J,q,H)))return A}else W<Q&&x(S++,L+1,W,Q,X,J,16,-1/0,1/0),Q<K&&(x(S++,L+1,Q,K,X,J,0,-1/0,1/0),x(S++,L+1,X,J,Q,K,1,-1/0,1/0))}}else K=N?m(t,L,W,P,U,V,Z):g(t,L,W,P,U,V,Z),W<K&&(L===t-2?A=N?l.sweepBipartite(t,e,X,J,q,H,W,K,U,V):l.sweepBipartite(t,e,W,K,U,V,X,J,q,H):(x(S++,L+1,W,K,X,J,N,-1/0,1/0),x(S++,L+1,X,J,W,K,1^N,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),f=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),h=u(\"lo===p0\",[\"p0\"]),p=u(\"lo<p0\",[\"p0\"]),d=u(\"hi<=p0\",[\"p0\"]),g=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),m=u(\"lo<p0&&p0<=hi\",[\"p0\"]),v=n.mallocInt32(1024),y=n.mallocDouble(1024);function x(t,e,r,n,i,a,o,s,l){var c=6*t;v[c]=e,v[c+1]=r,v[c+2]=n,v[c+3]=i,v[c+4]=a,v[c+5]=o;var u=2*t;y[u]=s,y[u+1]=l}function b(t,e,r,n,i,a,o,s,l,c,u){var f=2*t,h=l*f,p=c[h+e];t:for(var d=i,g=i*f;d<a;++d,g+=f){var m=o[g+e],v=o[g+e+t];if(!(p<m||v<p)&&(!n||p!==m)){for(var y,x=s[d],b=e+1;b<t;++b){m=o[g+b],v=o[g+b+t];var _=c[h+b],w=c[h+b+t];if(v<_||w<m)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function _(t,e,r,n,i,a,o,s,l,c){var u=2*t,f=s*u,h=l[f+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var m=a[d+e],v=a[d+e+t];if(!(h<m||v<h)){for(var y=e+1;y<t;++y){m=a[d+y],v=a[d+y+t];var x=l[f+y],b=l[f+y+t];if(v<x||b<m)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":102,\"./median\":104,\"./partition\":105,\"./sweep\":107,\"bit-twiddle\":97,\"typedarray-pool\":595}],104:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,o,s){if(a<=r+1)return r;var l=r,c=a,u=a+r>>>1,f=2*t,h=u,p=o[f*u+e];for(;l<c;){if(c-l<8){i(t,e,l,c,o,s),p=o[f*u+e];break}var d=c-l,g=Math.random()*d+l|0,m=o[f*g+e],v=Math.random()*d+l|0,y=o[f*v+e],x=Math.random()*d+l|0,b=o[f*x+e];m<=y?b>=y?(h=v,p=y):m>=b?(h=g,p=m):(h=x,p=b):y>=b?(h=v,p=y):b>=m?(h=g,p=m):(h=x,p=b);for(var _=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){var k=o[_];o[_]=o[w],o[w]=k}var M=s[c-1];s[c-1]=s[h],s[h]=M,h=n(t,e,l,c-1,o,s,p);for(_=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){k=o[_];o[_]=o[w],o[w]=k}M=s[c-1];if(s[c-1]=s[h],s[h]=M,u<h){for(c=h-1;l<c&&o[f*(c-1)+e]===p;)c-=1;c+=1}else{if(!(h<u))break;for(l=h+1;l<c&&o[f*l+e]===p;)l+=1}}return n(t,e,r,u,o,s,o[f*u+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]);function i(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,f=o*(l-1);u>r&&i[f+e]>c;--u,f-=o){for(var h=f,p=f+o,d=0;d<o;++d,++h,++p){var g=i[h];i[h]=i[p],i[p]=g}var m=a[u];a[u]=a[u-1],a[u-1]=m}}},{\"./partition\":105}],105:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),n=[];t.indexOf(\"lo\")>=0&&n.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&n.push(\"hi=e[k+o]\");return r.push(\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\".replace(\"_\",n.join()).replace(\"$\",t)),Function.apply(void 0,r)}},{}],106:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=128?n(0,e-1,t):function t(e,r,u){var f=(r-e+1)/6|0,h=e+f,p=r-f,d=e+r>>1,g=d-f,m=d+f,v=h,y=g,x=d,b=m,_=p,w=e+1,T=r-1,k=0;l(v,y,u)&&(k=v,v=y,y=k);l(b,_,u)&&(k=b,b=_,_=k);l(v,x,u)&&(k=v,v=x,x=k);l(y,x,u)&&(k=y,y=x,x=k);l(v,b,u)&&(k=v,v=b,b=k);l(x,b,u)&&(k=x,x=b,b=k);l(y,_,u)&&(k=y,y=_,_=k);l(y,x,u)&&(k=y,y=x,x=k);l(b,_,u)&&(k=b,b=_,_=k);for(var M=u[2*y],A=u[2*y+1],S=u[2*b],E=u[2*b+1],C=2*v,L=2*x,I=2*_,P=2*h,z=2*d,O=2*p,D=0;D<2;++D){var R=u[C+D],F=u[L+D],B=u[I+D];u[P+D]=R,u[z+D]=F,u[O+D]=B}a(g,e,u),a(m,r,u);for(var N=w;N<=T;++N)if(c(N,M,A,u))N!==w&&i(N,w,u),++w;else if(!c(N,S,E,u))for(;;){if(c(T,S,E,u)){c(T,M,A,u)?(o(N,w,T,u),++w,--T):(i(N,T,u),--T);break}if(--T<N)break}s(e,w-1,M,A,u),s(r,T+1,S,E,u),w-2-e<=32?n(e,w-2,u):t(e,w-2,u);r-(T+2)<=32?n(T+2,r,u):t(T+2,r,u);T-w<=32?n(w,T,u):t(w,T,u)}(0,e-1,t)};function n(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function i(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function a(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function o(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function s(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function l(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function c(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],107:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);o.length<e&&(n.free(o),o=n.mallocInt32(e));s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;h.length<r&&(n.free(h),h=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,u,f,g,m,v){for(var y=0,x=2*t,b=t-1,_=x-1,w=r;w<n;++w){var T=u[w],k=x*w;h[y++]=i[k+b],h[y++]=-(T+1),h[y++]=i[k+_],h[y++]=T}for(w=f;w<g;++w){T=v[w]+(1<<28);var M=x*w;h[y++]=m[M+b],h[y++]=-T,h[y++]=m[M+_],h[y++]=T}var A=y>>>1;a(h,A);var S=0,E=0;for(w=0;w<A;++w){var C=0|h[2*w+1];if(C>=1<<28)p(l,c,E--,C=C-(1<<28)|0);else if(C>=0)p(o,s,S--,C);else if(C<=-(1<<28)){C=-C-(1<<28)|0;for(var L=0;L<S;++L){if(void 0!==(I=e(o[L],C)))return I}d(l,c,E++,C)}else{C=-C-1|0;for(L=0;L<E;++L){var I;if(void 0!==(I=e(C,l[L])))return I}d(o,s,S++,C)}}},sweepComplete:function(t,e,r,n,i,g,m,v,y,x){for(var b=0,_=2*t,w=t-1,T=_-1,k=r;k<n;++k){var M=g[k]+1<<1,A=_*k;h[b++]=i[A+w],h[b++]=-M,h[b++]=i[A+T],h[b++]=M}for(k=m;k<v;++k){M=x[k]+1<<1;var S=_*k;h[b++]=y[S+w],h[b++]=1|-M,h[b++]=y[S+T],h[b++]=1|M}var E=b>>>1;a(h,E);var C=0,L=0,I=0;for(k=0;k<E;++k){var P=0|h[2*k+1],z=1&P;if(k<E-1&&P>>1==h[2*k+3]>>1&&(z=2,k+=1),P<0){for(var O=-(P>>1)-1,D=0;D<I;++D){if(void 0!==(R=e(u[D],O)))return R}if(0!==z)for(D=0;D<C;++D){if(void 0!==(R=e(o[D],O)))return R}if(1!==z)for(D=0;D<L;++D){var R;if(void 0!==(R=e(l[D],O)))return R}0===z?d(o,s,C++,O):1===z?d(l,c,L++,O):2===z&&d(u,f,I++,O)}else{O=(P>>1)-1;0===z?p(o,s,C--,O):1===z?p(l,c,L--,O):2===z&&p(u,f,I--,O)}}},scanBipartite:function(t,e,r,n,i,l,c,u,f,g,m,v){var y=0,x=2*t,b=e,_=e+t,w=1,T=1;n?T=1<<28:w=1<<28;for(var k=i;k<l;++k){var M=k+w,A=x*k;h[y++]=c[A+b],h[y++]=-M,h[y++]=c[A+_],h[y++]=M}for(k=f;k<g;++k){M=k+T;var S=x*k;h[y++]=m[S+b],h[y++]=-M}var E=y>>>1;a(h,E);var C=0;for(k=0;k<E;++k){var L=0|h[2*k+1];if(L<0){var I=!1;if((M=-L)>=1<<28?(I=!n,M-=1<<28):(I=!!n,M-=1),I)d(o,s,C++,M);else{var P=v[M],z=x*M,O=m[z+e+1],D=m[z+e+1+t];t:for(var R=0;R<C;++R){var F=o[R],B=x*F;if(!(D<c[B+e+1]||c[B+e+1+t]<O)){for(var N=e+2;N<t;++N)if(m[z+N+t]<c[B+N]||c[B+N+t]<m[z+N])continue t;var j,U=u[F];if(void 0!==(j=n?r(P,U):r(U,P)))return j}}}}else p(o,s,C--,L-w)}},scanComplete:function(t,e,r,n,i,s,l,c,u,f,p){for(var d=0,g=2*t,m=e,v=e+t,y=n;y<i;++y){var x=y+(1<<28),b=g*y;h[d++]=s[b+m],h[d++]=-x,h[d++]=s[b+v],h[d++]=x}for(y=c;y<u;++y){x=y+1;var _=g*y;h[d++]=f[_+m],h[d++]=-x}var w=d>>>1;a(h,w);var T=0;for(y=0;y<w;++y){var k=0|h[2*y+1];if(k<0){if((x=-k)>=1<<28)o[T++]=x-(1<<28);else{var M=p[x-=1],A=g*x,S=f[A+e+1],E=f[A+e+1+t];t:for(var C=0;C<T;++C){var L=o[C],I=l[L];if(I===M)break;var P=g*L;if(!(E<s[P+e+1]||s[P+e+1+t]<S)){for(var z=e+2;z<t;++z)if(f[A+z+t]<s[P+z]||s[P+z+t]<f[A+z])continue t;var O=r(I,M);if(void 0!==O)return O}}}}else{for(x=k-(1<<28),C=T-1;C>=0;--C)if(o[C]===x){for(z=C+1;z<T;++z)o[z-1]=o[z];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=n.mallocInt32(1024),s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),f=n.mallocInt32(1024),h=n.mallocDouble(8192);function p(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function d(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":106,\"bit-twiddle\":97,\"typedarray-pool\":595}],108:[function(t,e,r){},{}],109:[function(t,e,r){arguments[4][108][0].apply(r,arguments)},{dup:108}],110:[function(t,e,r){\"use strict\";var n,i=\"object\"==typeof Reflect?Reflect:null,a=i&&\"function\"==typeof i.apply?i.apply:function(t,e,r){return Function.prototype.apply.call(t,e,r)};n=i&&\"function\"==typeof i.ownKeys?i.ownKeys:Object.getOwnPropertySymbols?function(t){return Object.getOwnPropertyNames(t).concat(Object.getOwnPropertySymbols(t))}:function(t){return Object.getOwnPropertyNames(t)};var o=Number.isNaN||function(t){return t!=t};function s(){s.init.call(this)}e.exports=s,e.exports.once=function(t,e){return new Promise((function(r,n){function i(){void 0!==a&&t.removeListener(\"error\",a),r([].slice.call(arguments))}var a;\"error\"!==e&&(a=function(r){t.removeListener(e,i),n(r)},t.once(\"error\",a)),t.once(e,i)}))},s.EventEmitter=s,s.prototype._events=void 0,s.prototype._eventsCount=0,s.prototype._maxListeners=void 0;var l=10;function c(t){if(\"function\"!=typeof t)throw new TypeError('The \"listener\" argument must be of type Function. Received type '+typeof t)}function u(t){return void 0===t._maxListeners?s.defaultMaxListeners:t._maxListeners}function f(t,e,r,n){var i,a,o,s;if(c(r),void 0===(a=t._events)?(a=t._events=Object.create(null),t._eventsCount=0):(void 0!==a.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),a=t._events),o=a[e]),void 0===o)o=a[e]=r,++t._eventsCount;else if(\"function\"==typeof o?o=a[e]=n?[r,o]:[o,r]:n?o.unshift(r):o.push(r),(i=u(t))>0&&o.length>i&&!o.warned){o.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+o.length+\" \"+String(e)+\" listeners added. Use emitter.setMaxListeners() to increase limit\");l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=o.length,s=l,console&&console.warn&&console.warn(s)}return t}function h(){if(!this.fired)return this.target.removeListener(this.type,this.wrapFn),this.fired=!0,0===arguments.length?this.listener.call(this.target):this.listener.apply(this.target,arguments)}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=h.bind(n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(void 0===n)return[];var i=n[e];return void 0===i?[]:\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):m(i,i.length)}function g(t){var e=this._events;if(void 0!==e){var r=e[t];if(\"function\"==typeof r)return 1;if(void 0!==r)return r.length}return 0}function m(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}Object.defineProperty(s,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"defaultMaxListeners\" is out of range. It must be a non-negative number. Received '+t+\".\");l=t}}),s.init=function(){void 0!==this._events&&this._events!==Object.getPrototypeOf(this)._events||(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},s.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"n\" is out of range. It must be a non-negative number. Received '+t+\".\");return this._maxListeners=t,this},s.prototype.getMaxListeners=function(){return u(this)},s.prototype.emit=function(t){for(var e=[],r=1;r<arguments.length;r++)e.push(arguments[r]);var n=\"error\"===t,i=this._events;if(void 0!==i)n=n&&void 0===i.error;else if(!n)return!1;if(n){var o;if(e.length>0&&(o=e[0]),o instanceof Error)throw o;var s=new Error(\"Unhandled error.\"+(o?\" (\"+o.message+\")\":\"\"));throw s.context=o,s}var l=i[t];if(void 0===l)return!1;if(\"function\"==typeof l)a(l,this,e);else{var c=l.length,u=m(l,c);for(r=0;r<c;++r)a(u[r],this,e)}return!0},s.prototype.addListener=function(t,e){return f(this,t,e,!1)},s.prototype.on=s.prototype.addListener,s.prototype.prependListener=function(t,e){return f(this,t,e,!0)},s.prototype.once=function(t,e){return c(e),this.on(t,p(this,t,e)),this},s.prototype.prependOnceListener=function(t,e){return c(e),this.prependListener(t,p(this,t,e)),this},s.prototype.removeListener=function(t,e){var r,n,i,a,o;if(c(e),void 0===(n=this._events))return this;if(void 0===(r=n[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=Object.create(null):(delete n[t],n.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(i=-1,a=r.length-1;a>=0;a--)if(r[a]===e||r[a].listener===e){o=r[a].listener,i=a;break}if(i<0)return this;0===i?r.shift():function(t,e){for(;e+1<t.length;e++)t[e]=t[e+1];t.pop()}(r,i),1===r.length&&(n[t]=r[0]),void 0!==n.removeListener&&this.emit(\"removeListener\",t,o||e)}return this},s.prototype.off=s.prototype.removeListener,s.prototype.removeAllListeners=function(t){var e,r,n;if(void 0===(r=this._events))return this;if(void 0===r.removeListener)return 0===arguments.length?(this._events=Object.create(null),this._eventsCount=0):void 0!==r[t]&&(0==--this._eventsCount?this._events=Object.create(null):delete r[t]),this;if(0===arguments.length){var i,a=Object.keys(r);for(n=0;n<a.length;++n)\"removeListener\"!==(i=a[n])&&this.removeAllListeners(i);return this.removeAllListeners(\"removeListener\"),this._events=Object.create(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(void 0!==e)for(n=e.length-1;n>=0;n--)this.removeListener(t,e[n]);return this},s.prototype.listeners=function(t){return d(this,t,!0)},s.prototype.rawListeners=function(t){return d(this,t,!1)},s.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},s.prototype.listenerCount=g,s.prototype.eventNames=function(){return this._eventsCount>0?n(this._events):[]}},{}],111:[function(t,e,r){(function(e){(function(){\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "\"use strict\";var e=t(\"base64-js\"),n=t(\"ieee754\");r.Buffer=a,r.SlowBuffer=function(t){+t!=t&&(t=0);return a.alloc(+t)},r.INSPECT_MAX_BYTES=50;function i(t){if(t>2147483647)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var e=new Uint8Array(t);return e.__proto__=a.prototype,e}function a(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return l(t)}return o(t,e,r)}function o(t,e,r){if(\"string\"==typeof t)return function(t,e){\"string\"==typeof e&&\"\"!==e||(e=\"utf8\");if(!a.isEncoding(e))throw new TypeError(\"Unknown encoding: \"+e);var r=0|f(t,e),n=i(r),o=n.write(t,e);o!==r&&(n=n.slice(0,o));return n}(t,e);if(ArrayBuffer.isView(t))return c(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(B(t,ArrayBuffer)||t&&B(t.buffer,ArrayBuffer))return function(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('\"length\" is outside of buffer bounds');var n;n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r);return n.__proto__=a.prototype,n}(t,e,r);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return a.from(n,e,r);var o=function(t){if(a.isBuffer(t)){var e=0|u(t.length),r=i(e);return 0===r.length||t.copy(r,0,0,e),r}if(void 0!==t.length)return\"number\"!=typeof t.length||N(t.length)?i(0):c(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return c(t.data)}(t);if(o)return o;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return a.from(t[Symbol.toPrimitive](\"string\"),e,r);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function s(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function l(t){return s(t),i(t<0?0:0|u(t))}function c(t){for(var e=t.length<0?0:0|u(t.length),r=i(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function u(t){if(t>=2147483647)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+2147483647..toString(16)+\" bytes\");return 0|t}function f(t,e){if(a.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||B(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var i=!1;;)switch(e){case\"ascii\":case\"latin1\":case\"binary\":return r;case\"utf8\":case\"utf-8\":return D(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*r;case\"hex\":return r>>>1;case\"base64\":return R(t).length;default:if(i)return n?-1:D(t).length;e=(\"\"+e).toLowerCase(),i=!0}}function h(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return A(this,e,r);case\"utf8\":case\"utf-8\":return T(this,e,r);case\"ascii\":return k(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return S(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,e,r,n,i){if(0===t.length)return-1;if(\"string\"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),N(r=+r)&&(r=i?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(i)return-1;r=t.length-1}else if(r<0){if(!i)return-1;r=0}if(\"string\"==typeof e&&(e=a.from(e,n)),a.isBuffer(e))return 0===e.length?-1:g(t,e,r,n,i);if(\"number\"==typeof e)return e&=255,\"function\"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):g(t,[e],r,n,i);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var f=!0,h=0;h<l;h++)if(c(t,a+h)!==c(e,h)){f=!1;break}if(f)return a}return-1}function m(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(N(s))return o;t[r+o]=s}return o}function v(t,e,r,n){return F(D(e,t.length-r),t,r,n)}function y(t,e,r,n){return F(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return F(R(e),t,r,n)}function _(t,e,r,n){return F(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,r,n){return 0===r&&n===t.length?e.fromByteArray(t):e.fromByteArray(t.slice(r,n))}function T(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,f=c>239?4:c>223?3:c>191?2:1;if(i+f<=r)switch(f){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,f=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=f}return function(t){var e=t.length;if(e<=4096)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=4096));return r}(n)}r.kMaxLength=2147483647,a.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),a.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(a.prototype,\"parent\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.buffer}}),Object.defineProperty(a.prototype,\"offset\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&a[Symbol.species]===a&&Object.defineProperty(a,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),a.poolSize=8192,a.from=function(t,e,r){return o(t,e,r)},a.prototype.__proto__=Uint8Array.prototype,a.__proto__=Uint8Array,a.alloc=function(t,e,r){return function(t,e,r){return s(t),t<=0?i(t):void 0!==e?\"string\"==typeof r?i(t).fill(e,r):i(t).fill(e):i(t)}(t,e,r)},a.allocUnsafe=function(t){return l(t)},a.allocUnsafeSlow=function(t){return l(t)},a.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==a.prototype},a.compare=function(t,e){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),B(e,Uint8Array)&&(e=a.from(e,e.offset,e.byteLength)),!a.isBuffer(t)||!a.isBuffer(e))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,i=0,o=Math.min(r,n);i<o;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0},a.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},a.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return a.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=a.allocUnsafe(e),i=0;for(r=0;r<t.length;++r){var o=t[r];if(B(o,Uint8Array)&&(o=a.from(o)),!a.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(n,i),i+=o.length}return n},a.byteLength=f,a.prototype._isBuffer=!0,a.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},a.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},a.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},a.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?T(this,0,t):h.apply(this,arguments)},a.prototype.toLocaleString=a.prototype.toString,a.prototype.equals=function(t){if(!a.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===a.compare(this,t)},a.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},a.prototype.compare=function(t,e,r,n,i){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),!a.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===i&&(i=this.length),e<0||r>t.length||n<0||i>this.length)throw new RangeError(\"out of range index\");if(n>=i&&e>=r)return 0;if(n>=i)return-1;if(e>=r)return 1;if(this===t)return 0;for(var o=(i>>>=0)-(n>>>=0),s=(r>>>=0)-(e>>>=0),l=Math.min(o,s),c=this.slice(n,i),u=t.slice(e,r),f=0;f<l;++f)if(c[f]!==u[f]){o=c[f],s=u[f];break}return o<s?-1:s<o?1:0},a.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},a.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},a.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},a.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return m(this,t,e,r);case\"utf8\":case\"utf-8\":return v(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},a.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};function k(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function A(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=O(t[a]);return i}function S(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function E(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function C(t,e,r,n,i,o){if(!a.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(e>i||e<o)throw new RangeError('\"value\" argument is out of bounds');if(r+n>t.length)throw new RangeError(\"Index out of range\")}function L(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function I(t,e,r,i,a){return e=+e,r>>>=0,a||L(t,0,r,4),n.write(t,e,r,i,23,4),r+4}function P(t,e,r,i,a){return e=+e,r>>>=0,a||L(t,0,r,8),n.write(t,e,r,i,52,8),r+8}a.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return n.__proto__=a.prototype,n},a.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},a.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},a.prototype.readUInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),this[t]},a.prototype.readUInt16LE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]|this[t+1]<<8},a.prototype.readUInt16BE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]<<8|this[t+1]},a.prototype.readUInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},a.prototype.readUInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},a.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},a.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},a.prototype.readInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},a.prototype.readInt16LE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt16BE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},a.prototype.readInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},a.prototype.readFloatLE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!0,23,4)},a.prototype.readFloatBE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!1,23,4)},a.prototype.readDoubleLE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!0,52,8)},a.prototype.readDoubleBE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!1,52,8)},a.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},a.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},a.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,255,0),this[e]=255&t,e+1},a.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},a.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);C(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);C(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},a.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},a.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeFloatLE=function(t,e,r){return I(this,t,e,!0,r)},a.prototype.writeFloatBE=function(t,e,r){return I(this,t,e,!1,r)},a.prototype.writeDoubleLE=function(t,e,r){return P(this,t,e,!0,r)},a.prototype.writeDoubleBE=function(t,e,r){return P(this,t,e,!1,r)},a.prototype.copy=function(t,e,r,n){if(!a.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError(\"targetStart out of bounds\");if(r<0||r>=this.length)throw new RangeError(\"Index out of range\");if(n<0)throw new RangeError(\"sourceEnd out of bounds\");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var i=n-r;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(e,r,n);else if(this===t&&r<e&&e<n)for(var o=i-1;o>=0;--o)t[o+e]=this[o+r];else Uint8Array.prototype.set.call(t,this.subarray(r,n),e);return i},a.prototype.fill=function(t,e,r,n){if(\"string\"==typeof t){if(\"string\"==typeof e?(n=e,e=0,r=this.length):\"string\"==typeof r&&(n=r,r=this.length),void 0!==n&&\"string\"!=typeof n)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof n&&!a.isEncoding(n))throw new TypeError(\"Unknown encoding: \"+n);if(1===t.length){var i=t.charCodeAt(0);(\"utf8\"===n&&i<128||\"latin1\"===n)&&(t=i)}}else\"number\"==typeof t&&(t&=255);if(e<0||this.length<e||this.length<r)throw new RangeError(\"Out of range index\");if(r<=e)return this;var o;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),\"number\"==typeof t)for(o=e;o<r;++o)this[o]=t;else{var s=a.isBuffer(t)?t:a.from(t,n),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<r-e;++o)this[o+e]=s[o%l]}return this};var z=/[^+/0-9A-Za-z-_]/g;function O(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function D(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function R(t){return e.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(z,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function F(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function B(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function N(t){return t!=t}}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":79,buffer:111,ieee754:442}],112:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),f=!!c(r,\"interior\",!0),h=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!f&&!h||0===t.length)return[];var d=n(t,e);if(u||f!==h||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),m=0;m<d.length;++m){var v=d[m];g.addTriangle(v[0],v[1],v[2])}return u&&a(t,g),h?f?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":113,\"./lib/filter\":114,\"./lib/monotone\":115,\"./lib/triangulation\":116}],113:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){if(!((p=l[c])<s)&&!e.isConstraint(s,p)){for(var u=l[c-1],f=-1,h=1;h<l.length;h+=2)if(l[h-1]===p){f=l[h];break}f<0||n(t[s],t[p],t[u],t[f])<0&&r.push(s,p)}}for(;r.length>0;){for(var p=r.pop(),d=(s=r.pop(),u=-1,f=-1,l=o[s],1);d<l.length;d+=2){var g=l[d-1],m=l[d];g===p?f=m:m===p&&(u=g)}u<0||f<0||(n(t[s],t[p],t[u],t[f])>=0||(e.flip(s,p),i(t,e,r,u,s,f),i(t,e,r,s,f,u),i(t,e,r,f,p,u),i(t,e,r,p,u,f)))}}},{\"binary-search-bounds\":96,\"robust-in-sphere\":546}],114:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=(v=r[i])[0],l=v[1],c=v[2];l<c?l<s&&(v[0]=l,v[1]=c,v[2]=s):c<s&&(v[0]=c,v[1]=s,v[2]=l)}r.sort(o);var u=new Array(n);for(i=0;i<u.length;++i)u[i]=0;var f=[],h=[],p=new Array(3*n),d=new Array(3*n),g=null;e&&(g=[]);var m=new a(r,p,d,u,f,h,g);for(i=0;i<n;++i)for(var v=r[i],y=0;y<3;++y){s=v[y],l=v[(y+1)%3];var x=p[3*i+y]=m.locate(l,s,t.opposite(l,s)),b=d[3*i+y]=t.isConstraint(s,l);x<0&&(b?h.push(i):(f.push(i),u[i]=1),e&&g.push([l,s,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,f=n.constraint,h=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=h[3*p+d];g>=0&&0===c[g]&&(f[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var m=l;l=s,s=m,l.length=0,i=-i}var v=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return v.concat(n.boundary);return v},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":96}],115:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3];function a(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function o(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function s(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(0!==t.type&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function l(t,e){return i(t.a,t.b,e)}function c(t,e,r,a,o){for(var s=n.lt(e,a,l),c=n.gt(e,a,l),u=s;u<c;++u){for(var f=e[u],h=f.lowerIds,p=h.length;p>1&&i(r[h[p-2]],r[h[p-1]],a)>0;)t.push([h[p-1],h[p-2],o]),p-=1;h.length=p,h.push(o);var d=f.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function u(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function f(t,e,r){var i=n.le(t,r,u),o=t[i],s=o.upperIds,l=s[s.length-1];o.upperIds=[l],t.splice(i+1,0,new a(r.a,r.b,r.idx,[l],s))}function h(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,u),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],l=0;l<r;++l)i.push(new o(t[l],null,0,l));for(l=0;l<n;++l){var u=e[l],p=t[u[0]],d=t[u[1]];p[0]<d[0]?i.push(new o(p,d,2,l),new o(d,p,1,l)):p[0]>d[0]&&i.push(new o(d,p,2,l),new o(p,d,1,l))}i.sort(s);for(var g=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),m=[new a([g,1],[g,0],-1,[],[],[],[])],v=[],y=(l=0,i.length);l<y;++l){var x=i[l],b=x.type;0===b?c(v,m,t,x.a,x.idx):2===b?f(m,t,x):h(m,t,x)}return v}},{\"binary-search-bounds\":96,\"robust-orientation\":548}],116:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":96}],117:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],118:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,f=c[e+1];for(s=0;s<f.length;++s)u+=f[s];var h=new Array(e);for(s=0;s<e;++s){f=c[s];var p=0;for(l=0;l<f.length;++l)p+=f[l];h[s]=p/u}return h}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:176,\"robust-linear-solve\":547}],119:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:118}],120:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],121:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return v(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(a=0;a<e.length;++a){o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),f=t(\"./lib/rat-seg-intersect\");function h(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],f=h(c[0]),p=h(c[1]);s.push([u(f[0],-1/0),u(p[0],-1/0),u(f[1],1/0),u(p[1],1/0)])}i(s,(function(t,e){o.link(t,e)}));var d=!0,g=new Array(a);for(l=0;l<a;++l){(v=o.find(l))!==l&&(d=!1,t[v]=[Math.min(t[l][0],t[v][0]),Math.min(t[l][1],t[v][1])])}if(d)return null;var m=0;for(l=0;l<a;++l){var v;(v=o.find(l))===l?(g[l]=m,t[m++]=t[l]):g[l]=-1}t.length=m;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function m(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function v(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(m):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),h=function(t,e,r){var n=[];return i(r,(function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],f=t[s[1]];a(l,c,u,f)&&n.push([r,i])}})),n}(t,e,n),g=p(t),m=function(t,e,r,n){var o=[];return i(r,n,(function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}})),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,h=t.map((function(t){return[o(t[0]),o(t[1])]}));for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],m=e[d],v=f(c(t[g[0]]),c(t[g[1]]),c(t[m[0]]),c(t[m[1]]));if(v){var y=t.length;t.push([l(v[0]),l(v[1])]),h.push(v),n.push([u,y],[d,y])}}for(n.sort((function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=h[t[1]],n=h[e[1]];return s(r[0],n[0])||s(r[1],n[1])})),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],T=t[_];if((w[0]-T[0]||w[1]-T[1])<0){var k=b;b=_,_=k}x[0]=b;var M,A=x[1]=S[1];for(i&&(M=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([A,E,M]):e.push([A,E]),A=E}i?e.push([A,_,M]):e.push([A,_])}return h}(t,e,h,m,r));return v(e,y,r),!!y||(h.length>0||m.length>0)}},{\"./lib/rat-seg-intersect\":122,\"big-rat\":83,\"big-rat/cmp\":81,\"big-rat/to-float\":95,\"box-intersect\":101,nextafter:496,\"rat-vec\":530,\"robust-segment-intersect\":551,\"union-find\":596}],122:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),f=s(n,r),h=u(a,f);if(0===o(h))return null;var p=s(t,r),d=u(f,p),g=i(d,h),m=c(a,g);return l(t,m)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":82,\"big-rat/mul\":92,\"big-rat/sign\":93,\"big-rat/sub\":94,\"rat-vec/add\":529,\"rat-vec/muls\":531,\"rat-vec/sub\":532}],123:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:120}],124:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],125:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:120,\"color-rgba\":127,dtype:175}],126:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=(p=t.slice(1)).length;c=1,u<=4?(l=[parseInt(p[0]+p[0],16),parseInt(p[1]+p[1],16),parseInt(p[2]+p[2],16)],4===u&&(c=parseInt(p[3]+p[3],16)/255)):(l=[parseInt(p[0]+p[1],16),parseInt(p[2]+p[3],16),parseInt(p[4]+p[5],16)],8===u&&(c=parseInt(p[6]+p[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var f=e[1],h=\"rgb\"===f,p=f.replace(/a$/,\"\");s=p;u=\"cmyk\"===p?4:\"gray\"===p?1:3;l=e[2].trim().split(/\\s*,\\s*/).map((function(t,e){if(/%$/.test(t))return e===u?parseFloat(t)/100:\"rgb\"===p?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===p[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)})),f===p&&l.push(1),c=h||void 0===l[u]?1:l[u],l=l.slice(0,u)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map((function(t){return parseFloat(t)})),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var d=a(t.r,t.red,t.R,null);null!==d?(s=\"rgb\",l=[d,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":124,defined:170,\"is-plain-obj\":469}],127:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:120,\"color-parse\":126,\"color-space/hsl\":128}],128:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":129}],129:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],130:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],131:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,f,h,p,d,g;t||(t={});p=(t.nshades||72)-1,h=t.format||\"hex\",(f=t.colormap)||(f=\"jet\");if(\"string\"==typeof f){if(f=f.toLowerCase(),!n[f])throw Error(f+\" not a supported colorscale\");u=n[f]}else{if(!Array.isArray(f))throw Error(\"unsupported colormap option\",f);u=f.slice()}if(u.length>p+1)throw new Error(f+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map((function(t){return Math.round(t.index*p)})),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var m=u.map((function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1||(n[3]=d[0]+(d[1]-d[0])*r),n})),v=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=m[g],l=m[g+1];for(var y=0;y<c;y++){var x=y/c;v.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}v.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===h?v=v.map(o):\"rgbaString\"===h?v=v.map(s):\"float\"===h&&(v=v.map(a));return v}},{\"./colorScale\":130,lerp:472}],132:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),f=l(t,e,a);return u===f?0:u?1:-1}return 0}return 0===c?s>0||l(t,e,a)?-1:1:0===s?c>0||l(t,e,r)?1:-1:i(c-s)}var h=n(t,e,r);return h>0?o>0&&n(t,e,a)>0?1:-1:h<0?o>0||n(t,e,a)>0?1:-1:n(t,e,a)>0||l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":548,\"robust-product\":549,\"robust-sum\":553,signum:554,\"two-sum\":583}],133:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],f=t[1],h=t[2],p=t[3],d=e[0],g=e[1],m=e[2],v=e[3];return u+f+h+p-(d+g+m+v)||n(u,f,h,p)-n(d,g,m,v,d)||n(u+f,u+h,u+p,f+h,f+p,h+p)-n(d+g,d+m,d+v,g+m,g+v,m+v)||n(u+f+h,u+f+p,u+h+p,f+h+p)-n(d+g+m,d+g+v,d+m+v,g+m+v);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],134:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":117,\"compare-cell\":133}],135:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":136,\"./lib/ch2d\":137,\"./lib/chnd\":138}],136:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],137:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":482}],138:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(o){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];var a=e.length;for(i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(n(a,!0),r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":67,\"incremental-convex-hull\":459}],139:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],140:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],141:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],142:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],143:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],144:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":146,\"./stringify\":147}],145:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":140}],146:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=h;var f=h.cache={};function h(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(f[t])return f[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return f[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},h=c(t,/\\s+/);e=h.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach((function(t){r[t]=e})),f[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===h[0]&&(h.shift(),r.lineHeight=p(h.shift())),!h.length)throw new Error(\"Missing required font-family.\");return r.family=c(h.join(\" \"),/\\s*,\\s*/).map(n),f[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"string-split-by\":568,unquote:598}],147:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},f={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},h=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=h),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map((function(t){return f[t]?t:'\"'+t+'\"'})).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"pick-by-alias\":511}],148:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],149:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],150:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,f=s*(3-2*i),h=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+f*r[p]+h*n[p];return a}return c*t+u*e+f*r+h*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],151:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":153}],152:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,f=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)f=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",f,\"*t\",i,\"p\",f,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(f=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",f,\"]-=s\",f].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var f=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[f].array,c=\"+q\"+f;case\"array\":c=\"p\"+u+c;var h=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):(i.push([\"var \",h,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\"[\",c,\"]=\",h].join(\"\")));else{for(var d=[s.name],g=[c],m=0;m<Math.abs(e.arrayBlockIndices[u]);m++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(m+1)+\"*t\"+u+\"b\"+m);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}function o(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,s=new Array(t.arrayArgs.length),l=new Array(t.arrayArgs.length),c=0;c<t.arrayArgs.length;++c)l[c]=e[2*c],s[c]=e[2*c+1];var u=[],f=[],h=[],p=[],d=[];for(c=0;c<t.arrayArgs.length;++c){t.arrayBlockIndices[c]<0?(h.push(0),p.push(r),u.push(r),f.push(r+t.arrayBlockIndices[c])):(h.push(t.arrayBlockIndices[c]),p.push(t.arrayBlockIndices[c]+r),u.push(0),f.push(t.arrayBlockIndices[c]));for(var g=[],m=0;m<s[c].length;m++)h[c]<=s[c][m]&&s[c][m]<p[c]&&g.push(s[c][m]-h[c]);d.push(g)}var v=[\"SS\"],y=[\"'use strict'\"],x=[];for(m=0;m<r;++m)x.push([\"s\",m,\"=SS[\",m,\"]\"].join(\"\"));for(c=0;c<t.arrayArgs.length;++c){v.push(\"a\"+c),v.push(\"t\"+c),v.push(\"p\"+c);for(m=0;m<r;++m)x.push([\"t\",c,\"p\",m,\"=t\",c,\"[\",h[c]+m,\"]\"].join(\"\"));for(m=0;m<Math.abs(t.arrayBlockIndices[c]);++m)x.push([\"t\",c,\"b\",m,\"=t\",c,\"[\",u[c]+m,\"]\"].join(\"\"))}for(c=0;c<t.scalarArgs.length;++c)v.push(\"Y\"+c);if(t.shapeArgs.length>0&&x.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var b=new Array(r);for(c=0;c<r;++c)b[c]=\"0\";x.push([\"index=[\",b.join(\",\"),\"]\"].join(\"\"))}for(c=0;c<t.offsetArgs.length;++c){var _=t.offsetArgs[c],w=[];for(m=0;m<_.offset.length;++m)0!==_.offset[m]&&(1===_.offset[m]?w.push([\"t\",_.array,\"p\",m].join(\"\")):w.push([_.offset[m],\"*t\",_.array,\"p\",m].join(\"\")));0===w.length?x.push(\"q\"+c+\"=0\"):x.push([\"q\",c,\"=\",w.join(\"+\")].join(\"\"))}var T=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((x=x.concat(T)).length>0&&y.push(\"var \"+x.join(\",\")),c=0;c<t.arrayArgs.length;++c)y.push(\"p\"+c+\"|=0\");t.pre.body.length>3&&y.push(a(t.pre,t,l));var k=a(t.body,t,l),M=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(d);M<r?y.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var f=[\"offset\"+u],h=t;h<a;++h)f.push([\"j\",h,\"*t\",u,\"p\",e[h]].join(\"\"));c.push([\"p\",u,\"=(\",f.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(M,d[0],t,k)):y.push(i(d[0],t,k)),t.post.body.length>3&&y.push(a(t.post,t,l)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+y.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",s[0].join(\"s\"),\"m\",M,o(l)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",y.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:597}],153:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var f=t.arrayArgs[u];r.push([\"t\",f,\"=array\",f,\".dtype,\",\"r\",f,\"=array\",f,\".order\"].join(\"\")),a.push(\"t\"+f),a.push(\"r\"+f),o.push(\"t\"+f),o.push(\"r\"+f+\".join()\"),s.push(\"array\"+f+\".data\"),s.push(\"array\"+f+\".stride\"),s.push(\"array\"+f+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+f+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+f+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":152}],154:[function(t,e,r){\"use strict\";var n,i=t(\"type/value/is\"),a=t(\"type/value/ensure\"),o=t(\"type/plain-function/ensure\"),s=t(\"es5-ext/object/copy\"),l=t(\"es5-ext/object/normalize-options\"),c=t(\"es5-ext/object/map\"),u=Function.prototype.bind,f=Object.defineProperty,h=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,i=a(e)&&o(e.value);return delete(n=s(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&h.call(this,t)?i:(e.value=u.call(i,r.resolveContext?r.resolveContext(this):this),f(this,t,e),this[t])},n},e.exports=function(t){var e=l(arguments[1]);return i(e.resolveContext)&&o(e.resolveContext),c(t,(function(t,r){return n(r,t,e)}))}},{\"es5-ext/object/copy\":196,\"es5-ext/object/map\":204,\"es5-ext/object/normalize-options\":205,\"type/plain-function/ensure\":589,\"type/value/ensure\":593,\"type/value/is\":594}],155:[function(t,e,r){\"use strict\";var n=t(\"type/value/is\"),i=t(\"type/plain-function/is\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/normalize-options\"),s=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,i,l,c,u;return arguments.length<2||\"string\"!=typeof t?(c=e,e=t,t=null):c=arguments[2],n(t)?(r=s.call(t,\"c\"),i=s.call(t,\"e\"),l=s.call(t,\"w\")):(r=l=!0,i=!1),u={value:e,configurable:r,enumerable:i,writable:l},c?a(o(c),u):u}).gs=function(t,e,r){var l,c,u,f;return\"string\"!=typeof t?(u=r,r=e,e=t,t=null):u=arguments[3],n(e)?i(e)?n(r)?i(r)||(u=r,r=void 0):r=void 0:(u=e,e=r=void 0):e=void 0,n(t)?(l=s.call(t,\"c\"),c=s.call(t,\"e\")):(l=!0,c=!1),f={get:e,set:r,configurable:l,enumerable:c},u?a(o(u),f):f}},{\"es5-ext/object/assign\":193,\"es5-ext/object/normalize-options\":205,\"es5-ext/string/#/contains\":212,\"type/plain-function/is\":590,\"type/value/is\":594}],156:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var f=Array.prototype,h=f.slice,p=f.map;function d(t){return function(){return t}}function g(t){return t}function m(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var v=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=v?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=v?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=v?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function T(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function k(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function M(t){if(!(i=t.length))return[];for(var e=-1,r=k(t,A),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function A(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],f=c[1],h=r(l,u,f);Array.isArray(h)||(h=_(u,f,h),h=m(Math.ceil(u/h)*h,f,h));for(var p=h.length;h[0]<=u;)h.shift(),--p;for(;h[p-1]>f;)h.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?h[a-1]:u,d.x1=a<p?h[a]:f;for(a=0;a<s;++a)u<=(o=l[a])&&o<=f&&g[i(h,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(h.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(T(t,.75)-T(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return T(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=k,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=T,t.range=m,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)===(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=M,t.variance=l,t.zip=function(){return M(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],157:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each((function(t,e){n.set(e,t)}));else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each((function(t){r.add(t)}));else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each},t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,f,h=-1,p=n.length,d=l[i++],g=r(),m=a();++h<p;)(f=g.get(s=d(c=n[h])+\"\"))?f.push(c):g.set(s,[c]);return g.each((function(t,e){o(m,e,u(t,i,a,o))})),m}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each((function(e,r){i.push({key:r,values:t(e,n)})}))),null!=a?i.sort((function(t,e){return a(t.key,e.key)})):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],158:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3,8})$/,l=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),c=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),u=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),h=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),p=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),d={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function g(){return this.rgb().formatHex()}function m(){return this.rgb().formatRgb()}function v(t){var e,r;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?(r=e[1].length,e=parseInt(e[1],16),6===r?y(e):3===r?new w(e>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):8===r?x(e>>24&255,e>>16&255,e>>8&255,(255&e)/255):4===r?x(e>>12&15|e>>8&240,e>>8&15|e>>4&240,e>>4&15|240&e,((15&e)<<4|15&e)/255):null):(e=l.exec(t))?new w(e[1],e[2],e[3],1):(e=c.exec(t))?new w(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=u.exec(t))?x(e[1],e[2],e[3],e[4]):(e=f.exec(t))?x(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=h.exec(t))?A(e[1],e[2]/100,e[3]/100,1):(e=p.exec(t))?A(e[1],e[2]/100,e[3]/100,e[4]):d.hasOwnProperty(t)?y(d[t]):\"transparent\"===t?new w(NaN,NaN,NaN,0):null}function y(t){return new w(t>>16&255,t>>8&255,255&t,1)}function x(t,e,r,n){return n<=0&&(t=e=r=NaN),new w(t,e,r,n)}function b(t){return t instanceof n||(t=v(t)),t?new w((t=t.rgb()).r,t.g,t.b,t.opacity):new w}function _(t,e,r,n){return 1===arguments.length?b(t):new w(t,e,r,null==n?1:n)}function w(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function T(){return\"#\"+M(this.r)+M(this.g)+M(this.b)}function k(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}function M(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function A(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new C(t,e,r,n)}function S(t){if(t instanceof C)return new C(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new C;if(t instanceof C)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new C(s,l,c,t.opacity)}function E(t,e,r,n){return 1===arguments.length?S(t):new C(t,e,r,null==n?1:n)}function C(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function L(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{copy:function(t){return Object.assign(new this.constructor,this,t)},displayable:function(){return this.rgb().displayable()},hex:g,formatHex:g,formatHsl:function(){return S(this).formatHsl()},formatRgb:m,toString:m}),e(w,_,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:T,formatHex:T,formatRgb:k,toString:k})),e(C,E,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new C(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new C(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new w(L(t>=240?t-240:t+120,i,n),L(t,i,n),L(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"hsl(\":\"hsla(\")+(this.h||0)+\", \"+100*(this.s||0)+\"%, \"+100*(this.l||0)+\"%\"+(1===t?\")\":\", \"+t+\")\")}}));var I=Math.PI/180,P=180/Math.PI,z=6/29,O=3*z*z;function D(t){if(t instanceof F)return new F(t.l,t.a,t.b,t.opacity);if(t instanceof H)return G(t);t instanceof w||(t=b(t));var e,r,n=U(t.r),i=U(t.g),a=U(t.b),o=B((.2225045*n+.7168786*i+.0606169*a)/1);return n===i&&i===a?e=r=o:(e=B((.4360747*n+.3850649*i+.1430804*a)/.96422),r=B((.0139322*n+.0971045*i+.7141733*a)/.82521)),new F(116*o-16,500*(e-o),200*(o-r),t.opacity)}function R(t,e,r,n){return 1===arguments.length?D(t):new F(t,e,r,null==n?1:n)}function F(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function B(t){return t>.008856451679035631?Math.pow(t,1/3):t/O+4/29}function N(t){return t>z?t*t*t:O*(t-4/29)}function j(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function U(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function V(t){if(t instanceof H)return new H(t.h,t.c,t.l,t.opacity);if(t instanceof F||(t=D(t)),0===t.a&&0===t.b)return new H(NaN,0<t.l&&t.l<100?0:NaN,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*P;return new H(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function q(t,e,r,n){return 1===arguments.length?V(t):new H(t,e,r,null==n?1:n)}function H(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}function G(t){if(isNaN(t.h))return new F(t.l,0,0,t.opacity);var e=t.h*I;return new F(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}e(F,R,r(n,{brighter:function(t){return new F(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new F(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new w(j(3.1338561*(e=.96422*N(e))-1.6168667*(t=1*N(t))-.4906146*(r=.82521*N(r))),j(-.9787684*e+1.9161415*t+.033454*r),j(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(H,q,r(n,{brighter:function(t){return new H(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new H(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return G(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,Q=J*W,$=W*X-Z*Y;function tt(t){if(t instanceof rt)return new rt(t.h,t.s,t.l,t.opacity);t instanceof w||(t=b(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=($*n+K*e-Q*r)/($+K-Q),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*P-120:NaN;return new rt(l<0?l+360:l,s,i,t.opacity)}function et(t,e,r,n){return 1===arguments.length?tt(t):new rt(t,e,r,null==n?1:n)}function rt(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(rt,et,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*I,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new w(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.cubehelix=et,t.gray=function(t,e){return new F(t,0,0,null==e?1:e)},t.hcl=q,t.hsl=E,t.lab=R,t.lch=function(t,e,r,n){return 1===arguments.length?V(t):new H(r,e,t,null==n?1:n)},t.rgb=_,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],159:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i||/[\\s.]/.test(t))throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){return t.trim().split(/^|\\s+/).map((function(t){var r=\"\",n=t.indexOf(\".\");if(n>=0&&(r=t.slice(n+1),t=t.slice(0,n)),t&&!e.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:r}}))}function a(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function o(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n=this._,s=i(t+\"\",n),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)n[r]=o(n[r],t.name,e);else if(null==e)for(r in n)n[r]=o(n[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=a(n[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],160:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return function(){return t}}function o(){return 1e-6*(Math.random()-.5)}function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function f(t){return t.x}function h(t){return t.y}var p=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,h,p,d,g,m=r.length,v=0;v<c;++v)for(a=e.quadtree(r,s,l).visitAfter(f),t=0;t<m;++t)u=r[t],d=n[u.index],g=d*d,h=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>h+c||n<h-c||r>p+c||a<p-c;if(s.index>u.index){var f=h-s.x-s.vx,m=p-s.y-s.vy,v=f*f+m*m;v<c*c&&(0===f&&(v+=(f=o())*f),0===m&&(v+=(m=o())*m),v=(c-(v=Math.sqrt(v)))/v*i,u.vx+=(f*=v)*(c=(l*=l)/(g+l)),u.vy+=(m*=v)*c,s.vx-=f*(c=1-c),s.vy-=m*c)}}}function f(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function h(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,h()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),h(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,f=c,h=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,f,h,p,g,m=0;m<a;++m)c=(s=t[m]).source,f=(u=s.target).x+u.vx-c.x-c.vx||o(),h=u.y+u.vy-c.y-c.vy||o(),f*=p=((p=Math.sqrt(f*f+h*h))-n[m])/p*r*e[m],h*=p,u.vx-=f*(g=l[m]),u.vy-=h*g,c.vx+=f*(g=1-g),c.vy+=h*g}function m(){if(i){var a,o,c=i.length,h=t.length,p=r.map(i,f);for(a=0,s=new Array(c);a<h;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(h);a<h;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(h),v(),n=new Array(h),y()}}function v(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+h(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,m()},g.links=function(e){return arguments.length?(t=e,m(),g):t},g.id=function(t){return arguments.length?(f=t,g):f},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(h=\"function\"==typeof t?t:a(+t),v(),g):h},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,f,h).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(m)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function m(t,e,a,s){if(!t.value)return!0;var f=t.x-r.x,h=t.y-r.y,p=s-e,d=f*f+h*h;if(p*p/u<d)return d<c&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)),r.vx+=f*t.value*n/d,r.vy+=h*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=f*p,r.vy+=h*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,f=Math.sqrt(c*c+u*u),h=(o[a]-f)*i[a]*t/f;l.vx+=c*h,l.vy+=u*h}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),f=i.timer(d),h=n.dispatch(\"tick\",\"end\");function d(){g(),h.call(\"tick\",e),a<o&&(f.stop(),h.call(\"end\",e))}function g(r){var n,i,o=t.length;void 0===r&&(r=1);for(var f=0;f<r;++f)for(a+=(l-a)*s,u.each((function(t){t(a)})),n=0;n<o;++n)null==(i=t[n]).fx?i.x+=i.vx*=c:(i.x=i.fx,i.vx=0),null==i.fy?i.y+=i.vy*=c:(i.y=i.fy,i.vy=0);return e}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,null!=e.fx&&(e.x=e.fx),null!=e.fy&&(e.y=e.fy),isNaN(e.x)||isNaN(e.y)){var i=10*Math.sqrt(r),a=r*p;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function v(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:g,restart:function(){return f.restart(d),e},stop:function(){return f.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(v),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,v(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(h.on(t,r),e):h.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-collection\":157,\"d3-dispatch\":159,\"d3-quadtree\":164,\"d3-timer\":168}],161:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),f=+t.value&&(u.value=t.value),h=[u];for(null==e&&(e=o);r=h.pop();)if(f&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)h.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter((function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r}))},sort:function(t){return this.eachBefore((function(e){e.children&&e.children.sort(t)}))},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;t=r.pop(),e=n.pop();for(;t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each((function(e){t.push(e)})),t},leaves:function(){var t=[];return this.eachBefore((function(e){e.children||t.push(e)})),t},links:function(){var t=this,e=[];return t.each((function(r){r!==t&&e.push({source:r.parent,target:r})})),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function f(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=m(a=h(a,e)),n=0);return r}function h(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(v(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(v(t[r],t[n]),e)&&p(v(t[r],e),t[n])&&p(v(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function m(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return v(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function v(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,f=Math.sqrt(l*l+c*c);return{x:(r+a+l/f*u)/2,y:(n+o+c/f*u)/2,r:(f+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,f=r.r,h=n-o,p=n-c,d=i-s,g=i-u,m=l-a,v=f-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+f*f,_=p*d-h*g,w=(d*b-g*x)/(2*_)-n,T=(g*m-d*v)/_,k=(p*x-h*b)/(2*_)-i,M=(h*v-p*m)/_,A=T*T+M*M-1,S=2*(a+w*T+k*M),E=w*w+k*k-a*a,C=-(A?(S+Math.sqrt(S*S-4*A*E))/(2*A):E/S);return{x:n+w+T*C,y:i+k+M*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function T(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,h;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,h=e._.r;do{if(u<=h){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}h+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=f(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function k(t){return null==t?null:M(t)}function M(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function S(t){return function(){return t}}function E(t){return Math.sqrt(t.value)}function C(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function L(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=T(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function I(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function z(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var O={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,f,h,p,d,g,m,v=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(f=h=u,m=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(h/m,m/f);b<_;++b){if(u+=s=y[b].value,s<f&&(f=s),s>h&&(h=s),m=u*u*g,(p=Math.max(h/m,m/f))>d){u-=s;break}d=p}v.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?z(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return v}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,f=-1,h=o.length,p=t.value;++f<h;){for(l=(s=o[f]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?z(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter((function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)}));var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),f=c.x-t(c,u)/2,h=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-f)/(h-f)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(C(t)).eachAfter(L(n,.5)).eachBefore(I(1)):i.eachBefore(C(E)).eachAfter(L(A,1)).eachAfter(L(n,i.r/Math.min(e,r))).eachBefore(I(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=k(e),i):t},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:S(+t),i):n},i},t.packEnclose=f,t.packSiblings=function(t){return T(t),t},t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&z(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,f,h=r.length,p=new Array(h),d={};for(i=0;i<h;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[f=\"$\"+(s.id=u)]=f in d?D:s);for(i=0;i<h;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[\"$\"+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=O,a.eachBefore((function(t){t.depth=t.parent.depth+1,--h})).eachBefore(l),a.parent=null,h>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=M(e),r):t},r.parentId=function(t){return arguments.length?(e=M(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,f=i;i.eachBefore((function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>f.depth&&(f=t)}));var h=c===u?1:t(c,u)/2,p=h-c.x,d=e/(u.x+h+p),g=r/(f.depth||1);i.eachBefore((function(t){t.x=(t.x+p)*d,t.y=t.depth*g}))}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+f-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=f-u),a&&!N(l)&&(l.t=a,l.m+=c-h,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(f),i=[0],e&&t.eachBefore(P),t}function f(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,f=e.x1-r,h=e.y1-r;f<n&&(n=f=(n+f)/2),h<u&&(u=h=(u+h)/2),e.x0=n,e.y0=u,e.x1=f,e.y1=h,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(f-=s(e)-r)<n&&(n=f=(n+f)/2),(h-=l(e)-r)<u&&(u=h=(u+h)/2),t(e,n,u,f,h))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=M(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:S(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:S(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:S(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:S(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:S(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}var f=c[e],h=n/2+f,p=e+1,d=r-1;for(;p<d;){var g=p+d>>>1;c[g]<h?p=g+1:d=g}h-c[p-1]<c[p]-h&&e+1<p&&--p;var m=c[p]-f,v=n-m;if(o-i>l-a){var y=(i*v+o*m)/n;t(e,p,m,i,a,y,l),t(p,r,v,y,a,o,l)}else{var x=(a*v+l*m)/n;t(e,p,m,i,a,o,x),t(p,r,v,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=z,t.treemapResquarify=X,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:z)(t,e,r,n,i)},t.treemapSquarify=W,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],162:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function f(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var h=f(n),p=f(i);function d(t,e){e||(e=[]);var r,n=t?Math.min(e.length,t.length):0,i=e.slice();return function(a){for(r=0;r<n;++r)i[r]=t[r]*(1-a)+e[r]*a;return i}}function g(t){return ArrayBuffer.isView(t)&&!(t instanceof DataView)}function m(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=T(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function v(t,e){var r=new Date;return t=+t,e=+e,function(n){return r.setTime(t*(1-n)+e*n),r}}function y(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function x(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=T(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var b=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,_=new RegExp(b.source,\"g\");function w(t,e){var r,n,i,a=b.lastIndex=_.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=b.exec(t))&&(n=_.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:y(r,n)})),a=_.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function T(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?y:\"string\"===i?(n=e.color(r))?(r=n,u):w:r instanceof e.color?u:r instanceof Date?v:g(r)?d:Array.isArray(r)?m:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?x:y)(t,r)}var k,M,A,S,E=180/Math.PI,C={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function L(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*E,skewX:Math.atan(l)*E,scaleX:o,scaleY:s}}function I(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:y(t,i)},{i:l-2,x:y(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:y(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:y(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:y(t,r)},{i:s-2,x:y(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var P=I((function(t){return\"none\"===t?C:(k||(k=document.createElement(\"DIV\"),M=document.documentElement,A=document.defaultView),k.style.transform=t,t=A.getComputedStyle(M.appendChild(k),null).getPropertyValue(\"transform\"),M.removeChild(k),L(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))}),\"px, \",\"px)\",\"deg)\"),z=I((function(t){return null==t?C:(S||(S=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),S.setAttribute(\"transform\",t),(t=S.transform.baseVal.consolidate())?L((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):C)}),\", \",\")\",\")\"),O=Math.SQRT2;function D(t){return((t=Math.exp(t))+1/t)/2}function R(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var F=R(s),B=R(c);function N(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var j=N(s),U=N(c);function V(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var q=V(s),H=V(c);t.interpolate=T,t.interpolateArray=function(t,e){return(g(e)?d:m)(t,e)},t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateCubehelix=q,t.interpolateCubehelixLong=H,t.interpolateDate=v,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHcl=j,t.interpolateHclLong=U,t.interpolateHsl=F,t.interpolateHslLong=B,t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateNumber=y,t.interpolateNumberArray=d,t.interpolateObject=x,t.interpolateRgb=u,t.interpolateRgbBasis=h,t.interpolateRgbBasisClosed=p,t.interpolateRound=function(t,e){return t=+t,e=+e,function(r){return Math.round(t*(1-r)+e*r)}},t.interpolateString=w,t.interpolateTransformCss=P,t.interpolateTransformSvg=z,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<1e-12)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*f,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),g=(c*c-o*o-4*h)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/O,r=function(t){var e,r=t*n,s=D(m),l=o/(2*p)*(s*(e=O*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[i+l*u,a+l*f,o*s/D(O*r+m)]}}return r.duration=1e3*n,r},t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-color\":158}],163:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,f=s-r,h=u*u+f*f;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(h>1e-6)if(Math.abs(f*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,m=p*p+d*d,v=Math.sqrt(g),y=Math.sqrt(h),x=a*Math.tan((e-Math.acos((g+h-m)/(2*v*y)))/2),b=x/y,_=x/v;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*f)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(f*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i,l=!!l;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),f=t+c,h=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+f+\",\"+h:(Math.abs(this._x1-f)>1e-6||Math.abs(this._y1-h)>1e-6)&&(this._+=\"L\"+f+\",\"+h),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=f)+\",\"+(this._y1=h):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],164:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,f,h,p=t._root,d={data:n},g=t._x0,m=t._y0,v=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+v)/2))?g=a:v=a,(u=r>=(o=(m+y)/2))?m=o:y=o,i=p,!(p=p[f=u<<1|c]))return i[f]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[f]=d:t._root=d,t;do{i=i?i[f]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+v)/2))?g=a:v=a,(u=r>=(o=(m+y)/2))?m=o:y=o}while((f=u<<1|c)==(h=(l>=o)<<1|s>=a));return i[h]=p,i[f]=d,t}function r(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i}function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,f=-1/0,h=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>f&&(f=i),a<u&&(u=a),a>h&&(h=a));if(c>f||u>h)return this;for(this.cover(c,u).cover(f,h),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{for(var o,s,l=i-r,c=this._root;r>t||t>=i||n>e||e>=a;)switch(s=(e<n)<<1|t<r,(o=new Array(4))[s]=c,c=o,l*=2,s){case 0:i=r+l,a=n+l;break;case 1:r=i-l,a=n+l;break;case 2:i=r+l,n=a-l;break;case 3:r=i-l,n=a-l}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit((function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)})),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,f=this._x0,h=this._y0,p=this._x1,d=this._y1,g=[],m=this._root;for(m&&g.push(new r(m,f,h,p,d)),null==n?n=1/0:(f=t-n,h=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(m=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<f||(l=c.y1)<h))if(m.length){var v=(a+s)/2,y=(o+l)/2;g.push(new r(m[3],v,y,s,l),new r(m[2],a,y,v,l),new r(m[1],v,o,s,y),new r(m[0],a,o,v,y)),(u=(e>=y)<<1|t>=v)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,m.data),b=e-+this._y.call(null,m.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);f=t-w,h=e-w,p=t+w,d=e+w,i=m.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,f,h,p=this._root,d=this._x0,g=this._y0,m=this._x1,v=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+m)/2))?d=s:m=s,(u=o>=(l=(g+v)/2))?g=l:v=l,e=p,!(p=p[f=u<<1|c]))return this;if(!p.length)break;(e[f+1&3]||e[f+2&3]||e[f+3&3])&&(r=e,h=f)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[f]=i:delete e[f],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[h]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit((function(e){if(!e.length)do{++t}while(e=e.next)})),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,f=(a+s)/2;(n=c[3])&&l.push(new r(n,u,f,o,s)),(n=c[2])&&l.push(new r(n,i,f,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,f)),(n=c[0])&&l.push(new r(n,i,a,u,f))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,f=(s+c)/2,h=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,f,h)),(o=a[1])&&n.push(new r(o,f,l,c,h)),(o=a[2])&&n.push(new r(o,s,h,f,u)),(o=a[3])&&n.push(new r(o,f,h,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],165:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=Math.PI,f=u/2,h=2*u;function p(t){return t>1?0:t<-1?u:Math.acos(t)}function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function m(t){return t.outerRadius}function v(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,u=o-i,f=s-a,h=f*l-u*c;if(!(h*h<1e-12))return[t+(h=(u*(e-a)-f*(t-i))/h)*l,e+h*c]}function _(t,e,r,n,i,a,s){var l=t-r,u=e-n,f=(s?a:-a)/c(l*l+u*u),h=f*u,p=-f*l,d=t+h,g=e+p,m=r+h,v=n+p,y=(d+m)/2,x=(g+v)/2,b=m-d,_=v-g,w=b*b+_*_,T=i-a,k=d*v-m*g,M=(_<0?-1:1)*c(o(0,T*T*w-k*k)),A=(k*_-b*M)/w,S=(-k*b-_*M)/w,E=(k*_+b*M)/w,C=(-k*b+_*M)/w,L=A-y,I=S-x,P=E-y,z=C-x;return L*L+I*I>P*P+z*z&&(A=E,S=C),{cx:A,cy:S,x01:-h,y01:-p,x11:A*(i/T-1),y11:S*(i/T-1)}}function w(t){this._context=t}function T(t){return new w(t)}function k(t){return t[0]}function M(t){return t[1]}function A(){var t=k,n=M,i=r(!0),a=null,o=T,s=null;function l(r){var l,c,u,f=r.length,h=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=f;++l)!(l<f&&i(c=r[l],l,r))===h&&((h=!h)?s.lineStart():s.lineEnd()),h&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function S(){var t=k,n=null,i=r(0),a=M,o=r(!0),s=null,l=T,c=null;function u(r){var u,f,h,p,d,g=r.length,m=!1,v=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===m)if(m=!m)f=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),h=u-1;h>=f;--h)c.point(v[h],y[h]);c.lineEnd(),c.areaEnd()}m&&(v[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):v[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function f(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return f().x(t).y(i)},u.lineY1=function(){return f().x(t).y(a)},u.lineX1=function(){return f().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function E(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function C(t){return t}w.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var L=P(T);function I(t){this._curve=t}function P(t){function e(e){return new I(t(e))}return e._curve=t,e}function z(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function O(){return z(A().curve(L))}function D(){var t=S().curve(L),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return z(r())},delete t.lineX0,t.lineEndAngle=function(){return z(n())},delete t.lineX1,t.lineInnerRadius=function(){return z(i())},delete t.lineY0,t.lineOuterRadius=function(){return z(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function R(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}I.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var F=Array.prototype.slice;function B(t){return t.source}function N(t){return t.target}function j(t){var n=B,i=N,a=k,o=M,s=null;function l(){var r,l=F.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function V(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function q(t,e,r,n,i){var a=R(e,r),o=R(e,r=(r+i)/2),s=R(n,r),l=R(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var H={draw:function(t,e){var r=Math.sqrt(e/u);t.moveTo(r,0),t.arc(0,0,r,0,h)}},G={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},Y=Math.sqrt(1/3),W=2*Y,X={draw:function(t,e){var r=Math.sqrt(e/W),n=r*Y;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},Z=Math.sin(u/10)/Math.sin(7*u/10),J=Math.sin(h/10)*Z,K=-Math.cos(h/10)*Z,Q={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=J*r,i=K*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=h*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},tt=Math.sqrt(3),et={draw:function(t,e){var r=-Math.sqrt(e/(3*tt));t.moveTo(0,2*r),t.lineTo(-tt*r,-r),t.lineTo(tt*r,-r),t.closePath()}},rt=-.5,nt=Math.sqrt(3)/2,it=1/Math.sqrt(12),at=3*(it/2+1),ot={draw:function(t,e){var r=Math.sqrt(e/at),n=r/2,i=r*it,a=n,o=r*it+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(rt*n-nt*i,nt*n+rt*i),t.lineTo(rt*a-nt*o,nt*a+rt*o),t.lineTo(rt*s-nt*l,nt*s+rt*l),t.lineTo(rt*n+nt*i,rt*i-nt*n),t.lineTo(rt*a+nt*o,rt*o-nt*a),t.lineTo(rt*s+nt*l,rt*l-nt*s),t.closePath()}},st=[H,G,X,$,Q,et,ot];function lt(){}function ct(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ut(t){this._context=t}function ft(t){this._context=t}function ht(t){this._context=t}function pt(t,e){this._basis=new ut(t),this._beta=e}ut.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:ct(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},pt.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var dt=function t(e){function r(t){return 1===e?new ut(t):new pt(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function gt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:gt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function yt(t,e){this._context=t,this._k=(1-e)/6}yt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var xt=function t(e){function r(t){return new yt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function bt(t,e){this._context=t,this._k=(1-e)/6}bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var _t=function t(e){function r(t){return new bt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function wt(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>1e-12){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>1e-12){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,u=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/u,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/u}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Mt(t,e):new yt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function St(t,e){this._context=t,this._alpha=e}St.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var Et=function t(e){function r(t){return e?new St(t,e):new bt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Ct(t){this._context=t}function Lt(t){return t<0?-1:1}function It(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Lt(a)+Lt(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function zt(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function Ot(t){this._context=t}function Dt(t){this._context=new Rt(t)}function Rt(t){this._context=t}function Ft(t){this._context=t}function Bt(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Nt(t,e){this._context=t,this._t=e}function jt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function Ut(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Vt(t,e){return t[e]}function qt(t){var e=t.map(Ht);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Ht(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Gt(t){var e=t.map(Yt);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Yt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Ct.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},Ot.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:zt(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,zt(this,Pt(this,r=It(this,t,e)),r);break;default:zt(this,this._t0,r=It(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(Dt.prototype=Object.create(Ot.prototype)).point=function(t,e){Ot.prototype.point.call(this,e,t)},Rt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Ft.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Bt(t),i=Bt(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Nt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=m,w=r(0),T=null,k=v,M=y,A=x,S=null;function E(){var r,g,m=+t.apply(this,arguments),v=+o.apply(this,arguments),y=k.apply(this,arguments)-f,x=M.apply(this,arguments)-f,E=n(x-y),C=x>y;if(S||(S=r=e.path()),v<m&&(g=v,v=m,m=g),v>1e-12)if(E>h-1e-12)S.moveTo(v*a(y),v*l(y)),S.arc(0,0,v,y,x,!C),m>1e-12&&(S.moveTo(m*a(x),m*l(x)),S.arc(0,0,m,x,y,C));else{var L,I,P=y,z=x,O=y,D=x,R=E,F=E,B=A.apply(this,arguments)/2,N=B>1e-12&&(T?+T.apply(this,arguments):c(m*m+v*v)),j=s(n(v-m)/2,+w.apply(this,arguments)),U=j,V=j;if(N>1e-12){var q=d(N/m*l(B)),H=d(N/v*l(B));(R-=2*q)>1e-12?(O+=q*=C?1:-1,D-=q):(R=0,O=D=(y+x)/2),(F-=2*H)>1e-12?(P+=H*=C?1:-1,z-=H):(F=0,P=z=(y+x)/2)}var G=v*a(P),Y=v*l(P),W=m*a(D),X=m*l(D);if(j>1e-12){var Z,J=v*a(z),K=v*l(z),Q=m*a(O),$=m*l(O);if(E<u&&(Z=b(G,Y,Q,$,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(p((tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(v-at)/(it+1))}}F>1e-12?V>1e-12?(L=_(Q,$,G,Y,v,V,C),I=_(J,K,W,X,v,V,C),S.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?S.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(I.y01,I.x01),!C):(S.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),S.arc(0,0,v,i(L.cy+L.y11,L.cx+L.x11),i(I.cy+I.y11,I.cx+I.x11),!C),S.arc(I.cx,I.cy,V,i(I.y11,I.x11),i(I.y01,I.x01),!C))):(S.moveTo(G,Y),S.arc(0,0,v,P,z,!C)):S.moveTo(G,Y),m>1e-12&&R>1e-12?U>1e-12?(L=_(W,X,J,K,m,-U,C),I=_(G,Y,Q,$,m,-U,C),S.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?S.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(I.y01,I.x01),!C):(S.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),S.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(I.cy+I.y11,I.cx+I.x11),C),S.arc(I.cx,I.cy,U,i(I.y11,I.x11),i(I.y01,I.x01),!C))):S.arc(0,0,m,D,O,C):S.lineTo(W,X)}else S.moveTo(0,0);if(S.closePath(),r)return S=null,r+\"\"||null}return E.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +M.apply(this,arguments))/2-u/2;return[a(r)*e,l(r)*e]},E.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),E):t},E.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),E):o},E.cornerRadius=function(t){return arguments.length?(w=\"function\"==typeof t?t:r(+t),E):w},E.padRadius=function(t){return arguments.length?(T=null==t?null:\"function\"==typeof t?t:r(+t),E):T},E.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),E):k},E.endAngle=function(t){return arguments.length?(M=\"function\"==typeof t?t:r(+t),E):M},E.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),E):A},E.context=function(t){return arguments.length?(S=null==t?null:t,E):S},E},t.area=S,t.areaRadial=D,t.curveBasis=function(t){return new ut(t)},t.curveBasisClosed=function(t){return new ft(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBundle=dt,t.curveCardinal=vt,t.curveCardinalClosed=xt,t.curveCardinalOpen=_t,t.curveCatmullRom=kt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=Et,t.curveLinear=T,t.curveLinearClosed=function(t){return new Ct(t)},t.curveMonotoneX=function(t){return new Ot(t)},t.curveMonotoneY=function(t){return new Dt(t)},t.curveNatural=function(t){return new Ft(t)},t.curveStep=function(t){return new Nt(t,.5)},t.curveStepAfter=function(t){return new Nt(t,1)},t.curveStepBefore=function(t){return new Nt(t,0)},t.line=A,t.lineRadial=O,t.linkHorizontal=function(){return j(U)},t.linkRadial=function(){var t=j(q);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.linkVertical=function(){return j(V)},t.pie=function(){var t=C,e=E,n=null,i=r(0),a=r(h),o=r(0);function s(r){var s,l,c,u,f,p=r.length,d=0,g=new Array(p),m=new Array(p),v=+i.apply(this,arguments),y=Math.min(h,Math.max(-h,a.apply(this,arguments)-v)),x=Math.min(Math.abs(y)/p,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<p;++s)(f=m[g[s]=s]=+t(r[s],s,r))>0&&(d+=f);for(null!=e?g.sort((function(t,r){return e(m[t],m[r])})):null!=n&&g.sort((function(t,e){return n(r[t],r[e])})),s=0,c=d?(y-p*b)/d:0;s<p;++s,v=u)l=g[s],u=v+((f=m[l])>0?f*c:0)+b,m[l]={data:r[l],index:s,value:f,startAngle:v,endAngle:u,padAngle:x};return m}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.pointRadial=R,t.radialArea=D,t.radialLine=O,t.stack=function(){var t=r([]),e=Ut,n=jt,i=Vt;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var f,h=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=f=[0,+i(r[d],h,d,r)],f.data=r[d];p.key=h}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(F.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?Ut:\"function\"==typeof t?t:r(F.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?jt:t,a):n},a},t.stackOffsetDiverging=function(t,e){if((s=t.length)>0)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):(n[0]=0,n[1]=i)},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}jt(t,e)}},t.stackOffsetNone=jt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}jt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],f=u[o][1]||0,h=(f-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];h+=(d[o][1]||0)-(d[o-1][1]||0)}l+=f,c+=h*f}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,jt(t,e)}},t.stackOrderAppearance=qt,t.stackOrderAscending=Gt,t.stackOrderDescending=function(t){return Gt(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Yt),a=qt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=Ut,t.stackOrderReverse=function(t){return Ut(t).reverse()},t.symbol=function(){var t=r(H),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbolCircle=H,t.symbolCross=G,t.symbolDiamond=X,t.symbolSquare=$,t.symbolStar=Q,t.symbolTriangle=et,t.symbolWye=ot,t.symbols=st,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-path\":163}],166:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-time\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){if(0<=t.y&&t.y<100){var e=new Date(-1,t.m,t.d,t.H,t.M,t.S,t.L);return e.setFullYear(t.y),e}return new Date(t.y,t.m,t.d,t.H,t.M,t.S,t.L)}function n(t){if(0<=t.y&&t.y<100){var e=new Date(Date.UTC(-1,t.m,t.d,t.H,t.M,t.S,t.L));return e.setUTCFullYear(t.y),e}return new Date(Date.UTC(t.y,t.m,t.d,t.H,t.M,t.S,t.L))}function i(t,e,r){return{y:t,m:e,d:r,H:0,M:0,S:0,L:0}}function a(t){var a=t.dateTime,o=t.date,l=t.time,c=t.periods,u=t.days,f=t.shortDays,h=t.months,yt=t.shortMonths,xt=p(c),bt=d(c),_t=p(u),wt=d(u),Tt=p(f),kt=d(f),Mt=p(h),At=d(h),St=p(yt),Et=d(yt),Ct={a:function(t){return f[t.getDay()]},A:function(t){return u[t.getDay()]},b:function(t){return yt[t.getMonth()]},B:function(t){return h[t.getMonth()]},c:null,d:D,e:D,f:j,H:R,I:F,j:B,L:N,m:U,M:V,p:function(t){return c[+(t.getHours()>=12)]},q:function(t){return 1+~~(t.getMonth()/3)},Q:mt,s:vt,S:q,u:H,U:G,V:Y,w:W,W:X,x:null,X:null,y:Z,Y:J,Z:K,\"%\":gt},Lt={a:function(t){return f[t.getUTCDay()]},A:function(t){return u[t.getUTCDay()]},b:function(t){return yt[t.getUTCMonth()]},B:function(t){return h[t.getUTCMonth()]},c:null,d:Q,e:Q,f:nt,H:$,I:tt,j:et,L:rt,m:it,M:at,p:function(t){return c[+(t.getUTCHours()>=12)]},q:function(t){return 1+~~(t.getUTCMonth()/3)},Q:mt,s:vt,S:ot,u:st,U:lt,V:ct,w:ut,W:ft,x:null,X:null,y:ht,Y:pt,Z:dt,\"%\":gt},It={a:function(t,e,r){var n=Tt.exec(e.slice(r));return n?(t.w=kt[n[0].toLowerCase()],r+n[0].length):-1},A:function(t,e,r){var n=_t.exec(e.slice(r));return n?(t.w=wt[n[0].toLowerCase()],r+n[0].length):-1},b:function(t,e,r){var n=St.exec(e.slice(r));return n?(t.m=Et[n[0].toLowerCase()],r+n[0].length):-1},B:function(t,e,r){var n=Mt.exec(e.slice(r));return n?(t.m=At[n[0].toLowerCase()],r+n[0].length):-1},c:function(t,e,r){return Ot(t,a,e,r)},d:M,e:M,f:I,H:S,I:S,j:A,L:L,m:k,M:E,p:function(t,e,r){var n=xt.exec(e.slice(r));return n?(t.p=bt[n[0].toLowerCase()],r+n[0].length):-1},q:T,Q:z,s:O,S:C,u:m,U:v,V:y,w:g,W:x,x:function(t,e,r){return Ot(t,o,e,r)},X:function(t,e,r){return Ot(t,l,e,r)},y:_,Y:b,Z:w,\"%\":P};function Pt(t,e){return function(r){var n,i,a,o=[],l=-1,c=0,u=t.length;for(r instanceof Date||(r=new Date(+r));++l<u;)37===t.charCodeAt(l)&&(o.push(t.slice(c,l)),null!=(i=s[n=t.charAt(++l)])?n=t.charAt(++l):i=\"e\"===n?\" \":\"0\",(a=e[n])&&(n=a(r,i)),o.push(n),c=l+1);return o.push(t.slice(c,l)),o.join(\"\")}}function zt(t,a){return function(o){var s,l,c=i(1900,void 0,1);if(Ot(c,t,o+=\"\",0)!=o.length)return null;if(\"Q\"in c)return new Date(c.Q);if(\"s\"in c)return new Date(1e3*c.s+(\"L\"in c?c.L:0));if(a&&!(\"Z\"in c)&&(c.Z=0),\"p\"in c&&(c.H=c.H%12+12*c.p),void 0===c.m&&(c.m=\"q\"in c?c.q:0),\"V\"in c){if(c.V<1||c.V>53)return null;\"w\"in c||(c.w=1),\"Z\"in c?(l=(s=n(i(c.y,0,1))).getUTCDay(),s=l>4||0===l?e.utcMonday.ceil(s):e.utcMonday(s),s=e.utcDay.offset(s,7*(c.V-1)),c.y=s.getUTCFullYear(),c.m=s.getUTCMonth(),c.d=s.getUTCDate()+(c.w+6)%7):(l=(s=r(i(c.y,0,1))).getDay(),s=l>4||0===l?e.timeMonday.ceil(s):e.timeMonday(s),s=e.timeDay.offset(s,7*(c.V-1)),c.y=s.getFullYear(),c.m=s.getMonth(),c.d=s.getDate()+(c.w+6)%7)}else(\"W\"in c||\"U\"in c)&&(\"w\"in c||(c.w=\"u\"in c?c.u%7:\"W\"in c?1:0),l=\"Z\"in c?n(i(c.y,0,1)).getUTCDay():r(i(c.y,0,1)).getDay(),c.m=0,c.d=\"W\"in c?(c.w+6)%7+7*c.W-(l+5)%7:c.w+7*c.U-(l+6)%7);return\"Z\"in c?(c.H+=c.Z/100|0,c.M+=c.Z%100,n(c)):r(c)}}function Ot(t,e,r,n){for(var i,a,o=0,l=e.length,c=r.length;o<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(o++))){if(i=e.charAt(o++),!(a=It[i in s?e.charAt(o++):i])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}return Ct.x=Pt(o,Ct),Ct.X=Pt(l,Ct),Ct.c=Pt(a,Ct),Lt.x=Pt(o,Lt),Lt.X=Pt(l,Lt),Lt.c=Pt(a,Lt),{format:function(t){var e=Pt(t+=\"\",Ct);return e.toString=function(){return t},e},parse:function(t){var e=zt(t+=\"\",!1);return e.toString=function(){return t},e},utcFormat:function(t){var e=Pt(t+=\"\",Lt);return e.toString=function(){return t},e},utcParse:function(t){var e=zt(t+=\"\",!0);return e.toString=function(){return t},e}}}var o,s={\"-\":\"\",_:\" \",0:\"0\"},l=/^\\s*\\d+/,c=/^%/,u=/[\\\\^$*+?|[\\]().{}]/g;function f(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function h(t){return t.replace(u,\"\\\\$&\")}function p(t){return new RegExp(\"^(?:\"+t.map(h).join(\"|\")+\")\",\"i\")}function d(t){for(var e={},r=-1,n=t.length;++r<n;)e[t[r].toLowerCase()]=r;return e}function g(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function m(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.u=+n[0],r+n[0].length):-1}function v(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.U=+n[0],r+n[0].length):-1}function y(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.V=+n[0],r+n[0].length):-1}function x(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.W=+n[0],r+n[0].length):-1}function b(t,e,r){var n=l.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function _(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.y=+n[0]+(+n[0]>68?1900:2e3),r+n[0].length):-1}function w(t,e,r){var n=/^(Z)|([+-]\\d\\d)(?::?(\\d\\d))?/.exec(e.slice(r,r+6));return n?(t.Z=n[1]?0:-(n[2]+(n[3]||\"00\")),r+n[0].length):-1}function T(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.q=3*n[0]-3,r+n[0].length):-1}function k(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function M(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function A(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.m=0,t.d=+n[0],r+n[0].length):-1}function S(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function E(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function C(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function L(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function I(t,e,r){var n=l.exec(e.slice(r,r+6));return n?(t.L=Math.floor(n[0]/1e3),r+n[0].length):-1}function P(t,e,r){var n=c.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function z(t,e,r){var n=l.exec(e.slice(r));return n?(t.Q=+n[0],r+n[0].length):-1}function O(t,e,r){var n=l.exec(e.slice(r));return n?(t.s=+n[0],r+n[0].length):-1}function D(t,e){return f(t.getDate(),e,2)}function R(t,e){return f(t.getHours(),e,2)}function F(t,e){return f(t.getHours()%12||12,e,2)}function B(t,r){return f(1+e.timeDay.count(e.timeYear(t),t),r,3)}function N(t,e){return f(t.getMilliseconds(),e,3)}function j(t,e){return N(t,e)+\"000\"}function U(t,e){return f(t.getMonth()+1,e,2)}function V(t,e){return f(t.getMinutes(),e,2)}function q(t,e){return f(t.getSeconds(),e,2)}function H(t){var e=t.getDay();return 0===e?7:e}function G(t,r){return f(e.timeSunday.count(e.timeYear(t)-1,t),r,2)}function Y(t,r){var n=t.getDay();return t=n>=4||0===n?e.timeThursday(t):e.timeThursday.ceil(t),f(e.timeThursday.count(e.timeYear(t),t)+(4===e.timeYear(t).getDay()),r,2)}function W(t){return t.getDay()}function X(t,r){return f(e.timeMonday.count(e.timeYear(t)-1,t),r,2)}function Z(t,e){return f(t.getFullYear()%100,e,2)}function J(t,e){return f(t.getFullYear()%1e4,e,4)}function K(t){var e=t.getTimezoneOffset();return(e>0?\"-\":(e*=-1,\"+\"))+f(e/60|0,\"0\",2)+f(e%60,\"0\",2)}function Q(t,e){return f(t.getUTCDate(),e,2)}function $(t,e){return f(t.getUTCHours(),e,2)}function tt(t,e){return f(t.getUTCHours()%12||12,e,2)}function et(t,r){return f(1+e.utcDay.count(e.utcYear(t),t),r,3)}function rt(t,e){return f(t.getUTCMilliseconds(),e,3)}function nt(t,e){return rt(t,e)+\"000\"}function it(t,e){return f(t.getUTCMonth()+1,e,2)}function at(t,e){return f(t.getUTCMinutes(),e,2)}function ot(t,e){return f(t.getUTCSeconds(),e,2)}function st(t){var e=t.getUTCDay();return 0===e?7:e}function lt(t,r){return f(e.utcSunday.count(e.utcYear(t)-1,t),r,2)}function ct(t,r){var n=t.getUTCDay();return t=n>=4||0===n?e.utcThursday(t):e.utcThursday.ceil(t),f(e.utcThursday.count(e.utcYear(t),t)+(4===e.utcYear(t).getUTCDay()),r,2)}function ut(t){return t.getUTCDay()}function ft(t,r){return f(e.utcMonday.count(e.utcYear(t)-1,t),r,2)}function ht(t,e){return f(t.getUTCFullYear()%100,e,2)}function pt(t,e){return f(t.getUTCFullYear()%1e4,e,4)}function dt(){return\"+0000\"}function gt(){return\"%\"}function mt(t){return+t}function vt(t){return Math.floor(+t/1e3)}function yt(e){return o=a(e),t.timeFormat=o.format,t.timeParse=o.parse,t.utcFormat=o.utcFormat,t.utcParse=o.utcParse,o}yt({dateTime:\"%x, %X\",date:\"%-m/%-d/%Y\",time:\"%-I:%M:%S %p\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});var xt=Date.prototype.toISOString?function(t){return t.toISOString()}:t.utcFormat(\"%Y-%m-%dT%H:%M:%S.%LZ\");var bt=+new Date(\"2000-01-01T00:00:00.000Z\")?function(t){var e=new Date(t);return isNaN(e)?null:e}:t.utcParse(\"%Y-%m-%dT%H:%M:%S.%LZ\");t.isoFormat=xt,t.isoParse=bt,t.timeFormatDefaultLocale=yt,t.timeFormatLocale=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-time\":167}],167:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=new Date,r=new Date;function n(t,i,a,o){function s(e){return t(e=0===arguments.length?new Date:new Date(+e)),e}return s.floor=function(e){return t(e=new Date(+e)),e},s.ceil=function(e){return t(e=new Date(e-1)),i(e,1),t(e),e},s.round=function(t){var e=s(t),r=s.ceil(t);return t-e<r-t?e:r},s.offset=function(t,e){return i(t=new Date(+t),null==e?1:Math.floor(e)),t},s.range=function(e,r,n){var a,o=[];if(e=s.ceil(e),n=null==n?1:Math.floor(n),!(e<r&&n>0))return o;do{o.push(a=new Date(+e)),i(e,n),t(e)}while(a<e&&e<r);return o},s.filter=function(e){return n((function(r){if(r>=r)for(;t(r),!e(r);)r.setTime(r-1)}),(function(t,r){if(t>=t)if(r<0)for(;++r<=0;)for(;i(t,-1),!e(t););else for(;--r>=0;)for(;i(t,1),!e(t););}))},a&&(s.count=function(n,i){return e.setTime(+n),r.setTime(+i),t(e),t(r),Math.floor(a(e,r))},s.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?s.filter(o?function(e){return o(e)%t==0}:function(e){return s.count(0,e)%t==0}):s:null}),s}var i=n((function(){}),(function(t,e){t.setTime(+t+e)}),(function(t,e){return e-t}));i.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?n((function(e){e.setTime(Math.floor(e/t)*t)}),(function(e,r){e.setTime(+e+r*t)}),(function(e,r){return(r-e)/t})):i:null};var a=i.range,o=n((function(t){t.setTime(t-t.getMilliseconds())}),(function(t,e){t.setTime(+t+1e3*e)}),(function(t,e){return(e-t)/1e3}),(function(t){return t.getUTCSeconds()})),s=o.range,l=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds())}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getMinutes()})),c=l.range,u=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds()-6e4*t.getMinutes())}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getHours()})),f=u.range,h=n((function(t){t.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/864e5}),(function(t){return t.getDate()-1})),p=h.range;function d(t){return n((function(e){e.setDate(e.getDate()-(e.getDay()+7-t)%7),e.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+7*e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/6048e5}))}var g=d(0),m=d(1),v=d(2),y=d(3),x=d(4),b=d(5),_=d(6),w=g.range,T=m.range,k=v.range,M=y.range,A=x.range,S=b.range,E=_.range,C=n((function(t){t.setDate(1),t.setHours(0,0,0,0)}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t,e){return e.getMonth()-t.getMonth()+12*(e.getFullYear()-t.getFullYear())}),(function(t){return t.getMonth()})),L=C.range,I=n((function(t){t.setMonth(0,1),t.setHours(0,0,0,0)}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t,e){return e.getFullYear()-t.getFullYear()}),(function(t){return t.getFullYear()}));I.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setFullYear(Math.floor(e.getFullYear()/t)*t),e.setMonth(0,1),e.setHours(0,0,0,0)}),(function(e,r){e.setFullYear(e.getFullYear()+r*t)})):null};var P=I.range,z=n((function(t){t.setUTCSeconds(0,0)}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getUTCMinutes()})),O=z.range,D=n((function(t){t.setUTCMinutes(0,0,0)}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getUTCHours()})),R=D.range,F=n((function(t){t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+e)}),(function(t,e){return(e-t)/864e5}),(function(t){return t.getUTCDate()-1})),B=F.range;function N(t){return n((function(e){e.setUTCDate(e.getUTCDate()-(e.getUTCDay()+7-t)%7),e.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+7*e)}),(function(t,e){return(e-t)/6048e5}))}var j=N(0),U=N(1),V=N(2),q=N(3),H=N(4),G=N(5),Y=N(6),W=j.range,X=U.range,Z=V.range,J=q.range,K=H.range,Q=G.range,$=Y.range,tt=n((function(t){t.setUTCDate(1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCMonth(t.getUTCMonth()+e)}),(function(t,e){return e.getUTCMonth()-t.getUTCMonth()+12*(e.getUTCFullYear()-t.getUTCFullYear())}),(function(t){return t.getUTCMonth()})),et=tt.range,rt=n((function(t){t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCFullYear(t.getUTCFullYear()+e)}),(function(t,e){return e.getUTCFullYear()-t.getUTCFullYear()}),(function(t){return t.getUTCFullYear()}));rt.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setUTCFullYear(Math.floor(e.getUTCFullYear()/t)*t),e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)}),(function(e,r){e.setUTCFullYear(e.getUTCFullYear()+r*t)})):null};var nt=rt.range;t.timeDay=h,t.timeDays=p,t.timeFriday=b,t.timeFridays=S,t.timeHour=u,t.timeHours=f,t.timeInterval=n,t.timeMillisecond=i,t.timeMilliseconds=a,t.timeMinute=l,t.timeMinutes=c,t.timeMonday=m,t.timeMondays=T,t.timeMonth=C,t.timeMonths=L,t.timeSaturday=_,t.timeSaturdays=E,t.timeSecond=o,t.timeSeconds=s,t.timeSunday=g,t.timeSundays=w,t.timeThursday=x,t.timeThursdays=A,t.timeTuesday=v,t.timeTuesdays=k,t.timeWednesday=y,t.timeWednesdays=M,t.timeWeek=g,t.timeWeeks=w,t.timeYear=I,t.timeYears=P,t.utcDay=F,t.utcDays=B,t.utcFriday=G,t.utcFridays=Q,t.utcHour=D,t.utcHours=R,t.utcMillisecond=i,t.utcMilliseconds=a,t.utcMinute=z,t.utcMinutes=O,t.utcMonday=U,t.utcMondays=X,t.utcMonth=tt,t.utcMonths=et,t.utcSaturday=Y,t.utcSaturdays=$,t.utcSecond=o,t.utcSeconds=s,t.utcSunday=j,t.utcSundays=W,t.utcThursday=H,t.utcThursdays=K,t.utcTuesday=V,t.utcTuesdays=Z,t.utcWednesday=q,t.utcWednesdays=J,t.utcWeek=j,t.utcWeeks=W,t.utcYear=rt,t.utcYears=nt,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],168:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=0,s=0,l=0,c=\"object\"==typeof performance&&performance.now?performance:Date,u=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return s||(u(h),s=c.now()+l)}function h(){s=0}function p(){this._call=this._time=this._next=null}function d(t,e,r){var n=new p;return n.restart(t,e,r),n}function g(){f(),++n;for(var t,r=e;r;)(t=s-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){s=(o=c.now())+l,n=i=0;try{g()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,y(a)}(),s=0}}function v(){var t=c.now(),e=t-o;e>1e3&&(l-=e,o=t)}function y(t){n||(i&&(i=clearTimeout(i)),t-s>24?(t<1/0&&(i=setTimeout(m,t-c.now()-l)),a&&(a=clearInterval(a))):(a||(o=c.now(),a=setInterval(v,1e3)),n=1,u(m)))}p.prototype=d.prototype={constructor:p,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,y()},stop:function(){this._call&&(this._call=null,this._time=1/0,y())}},t.interval=function(t,e,r){var n=new p,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart((function a(o){o+=i,n.restart(a,i+=e,r),t(o)}),e,r),n)},t.now=f,t.timeout=function(t,e,r){var n=new p;return e=null==e?0:+e,n.restart((function(r){n.stop(),t(r+e)}),e,r),n},t.timer=d,t.timerFlush=g,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],169:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,f=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){f.call(this,t,e+\"\",r)}}function h(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=h,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(h),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var m=g(h);function v(t){return t.length}t.bisectLeft=m.left,t.bisect=t.bisectRight=m.right,t.bisector=function(t){return g(1===t.length?function(e,r){return h(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,v),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t){for(var e=1;t*e%1;)e*=10;return e}function b(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function _(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=x(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new _;if(t instanceof _)t.forEach((function(t,e){r.set(t,e)}));else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};function w(t){return\"__proto__\"==(t+=\"\")||\"\\0\"===t[0]?\"\\0\"+t:t}function T(t){return\"\\0\"===(t+=\"\")[0]?t.slice(1):t}function k(t){return w(t)in this._}function M(t){return(t=w(t))in this._&&delete this._[t]}function A(){var t=[];for(var e in this._)t.push(T(e));return t}function S(){var t=0;for(var e in this._)++t;return t}function E(){for(var t in this._)return!1;return!0}function C(){this._=Object.create(null)}function L(t){return t}function I(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function P(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=z.length;r<n;++r){var i=z[r]+e;if(i in t)return i}}b(_,{has:k,get:function(t){return this._[w(t)]},set:function(t,e){return this._[w(t)]=e},remove:M,keys:A,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,f,h=-1,p=a.length,d=i[s++],g=new _;++h<p;)(f=g.get(l=d(c=a[h])))?f.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach((function(e,i){n.push({key:e,values:t(i,r)})})),o?n.sort((function(t,e){return o(t.key,e.key)})):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new C;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},b(C,{has:k,add:function(t){return this._[w(t+=\"\")]=!0,t},remove:M,values:A,size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=I(t,e,e[r]);return t};var z=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function O(){}function D(){}function R(t){var e=[],r=new _;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function F(){t.event.preventDefault()}function B(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function N(e){for(var r=new D,n=0,i=arguments.length;++n<i;)r[arguments[n]]=R(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new D,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=R(t);return t},D.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(j,\"\\\\$&\")};var j=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,U={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function V(t){return U(t,Y),t}var q=function(t,e){return e.querySelector(t)},H=function(t,e){return e.querySelectorAll(t)},G=function(t,e){var r=t.matches||t[P(t,\"matchesSelector\")];return(G=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(q=function(t,e){return Sizzle(t,e)[0]||null},H=Sizzle,G=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var Y=t.selection.prototype=[];function W(t){return\"function\"==typeof t?t:function(){return q(t,this)}}function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}Y.select=function(t){var e,r,n,i,a=[];t=W(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return V(a)},Y.selectAll=function(t){var e,r,i=[];t=X(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return V(i)};var Z=\"http://www.w3.org/1999/xhtml\",J={svg:\"http://www.w3.org/2000/svg\",xhtml:Z,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function K(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function $(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function tt(t){return(t+\"\").trim().split(/^|\\s+/)}function et(t,e){var r=(t=tt(t).map(rt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function rt(t){var e=$(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function nt(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function it(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function at(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===Z&&t.documentElement.namespaceURI===Z?t.createElement(e):t.createElementNS(r,e)}}function ot(){var t=this.parentNode;t&&t.removeChild(this)}function st(t){return{__data__:t}}function lt(t){return function(){return G(this,t)}}function ct(t){return arguments.length||(t=h),function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ft(t){return U(t,ht),t}t.ns={prefix:J,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),J.hasOwnProperty(r)?{space:J[r],local:t}:t}},Y.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each(K(r,e[r]));return this}return this.each(K(e,r))},Y.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=tt(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!$(t[i]).test(e))return!1;return!0}for(e in t)this.each(et(e,t[e]));return this}return this.each(et(t,e))},Y.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(nt(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(nt(t,e,r))},Y.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(it(e,t[e]));return this}return this.each(it(t,e))},Y.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},Y.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},Y.append=function(t){return t=at(t),this.select((function(){return this.appendChild(t.apply(this,arguments))}))},Y.insert=function(t,e){return t=at(t),e=W(e),this.select((function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)}))},Y.remove=function(){return this.each(ot)},Y.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,f=Math.min(o,u),h=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,m=new _,v=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(m.has(g=e.call(i,i.__data__,n))?d[n]=i:m.set(g,i),v[n]=g);for(n=-1;++n<u;)(i=m.get(g=e.call(r,a=r[n],n)))?!0!==i&&(h[n]=i,i.__data__=a):p[n]=st(a),m.set(g,!0);for(n=-1;++n<o;)n in v&&!0!==m.get(v[n])&&(d[n]=t[n])}else{for(n=-1;++n<f;)i=t[n],a=r[n],i?(i.__data__=a,h[n]=i):p[n]=st(a);for(;n<u;++n)p[n]=st(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=h,p.parentNode=h.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(h),c.push(d)}var s=ft([]),l=V([]),c=V([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},Y.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},Y.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=lt(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return V(i)},Y.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},Y.sort=function(t){t=ct.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},Y.each=function(t){return ut(this,(function(e,r,n){t.call(e,e.__data__,r,n)}))},Y.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},Y.empty=function(){return!this.node()},Y.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},Y.size=function(){var t=0;return ut(this,(function(){++t})),t};var ht=[];function pt(t){var e,r;return function(n,i,a){var o,s=t[a].update,l=s.length;for(a!=r&&(r=a,e=0),i>=e&&(e=i+1);!(o=s[e])&&++e<l;);return o}}function dt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=mt;o>0&&(e=e.slice(0,o));var l=gt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?O:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ft,t.selection.enter.prototype=ht,ht.append=Y.append,ht.empty=Y.empty,ht.node=Y.node,ht.call=Y.call,ht.size=Y.size,ht.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return V(o)},ht.insert=function(t,e){return arguments.length<2&&(e=pt(this)),Y.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[q(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),V([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(H(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,V([e])},Y.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(dt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(dt(t,e,r))};var gt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function mt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=mt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&gt.forEach((function(t){\"on\"+t in i&&gt.remove(t)}));var yt,xt=0;function bt(e){var r=\".dragsuppress-\"+ ++xt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,F).on(\"dragstart\"+r,F).on(\"selectstart\"+r,F);if(null==yt&&(yt=!(\"onselectstart\"in e)&&P(e.style,\"userSelect\")),yt){var s=a(e).style,l=s[yt];s[yt]=\"none\"}return function(t){if(i.on(r,null),yt&&(s[yt]=l),t){var e=function(){i.on(n,null)};i.on(n,(function(){F(),e()}),!0),setTimeout(e,0)}}}t.mouse=function(t){return wt(t,B())};var _t=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function wt(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(_t<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();_t=!(s.f||s.e),n.remove()}}return _t?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function Tt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=B().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return wt(t,n)},t.behavior.drag=function(){var e=N(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(O,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(Tt,t.touch,L,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=this,u=t.event.target.correspondingElement||t.event.target,f=c.parentNode,h=e.of(c,arguments),p=0,d=n(),g=\".drag\"+(null==d?\"\":\"-\"+d),m=t.select(a(u)).on(o+g,x).on(s+g,b),v=bt(u),y=i(f,d);function x(){var t,e,r=i(f,d);r&&(t=r[0]-y[0],e=r[1]-y[1],p|=t|e,y=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e}))}function b(){i(f,d)&&(m.on(o+g,null).on(s+g,null),v(p),h({type:\"dragend\"}))}l=r?[(l=r.apply(c,arguments)).x-y[0],l.y-y[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=B().touches),e?n(e).map((function(e){var r=wt(t,e);return r.identifier=e.identifier,r})):[]};var kt=1e-6,Mt=1e-12,At=Math.PI,St=2*At,Et=St-kt,Ct=At/2,Lt=At/180,It=180/At;function Pt(t){return t>0?1:t<0?-1:0}function zt(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function Ot(t){return t>1?0:t<-1?At:Math.acos(t)}function Dt(t){return t>1?Ct:t<-1?-Ct:Math.asin(t)}function Rt(t){return((t=Math.exp(t))+1/t)/2}function Ft(t){return(t=Math.sin(t/2))*t}var Bt=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<Mt)n=Math.log(c/o)/Bt,r=function(t){return[i+t*u,a+t*f,o*Math.exp(Bt*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),g=(c*c-o*o-4*h)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/Bt,r=function(t){var e,r=t*n,s=Rt(m),l=o/(2*p)*(s*(e=Bt*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[i+l*u,a+l*f,o*s/Rt(Bt*r+m)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,f,h={x:0,y:0,k:1},p=[960,500],d=Ut,g=250,m=0,v=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=N(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(v,I).on(jt+\".zoom\",z).on(\"dblclick.zoom\",O).on(b,P)}function T(t){return[(t[0]-h.x)/h.k,(t[1]-h.y)/h.k]}function k(t){h.k=Math.max(d[0],Math.min(d[1],t))}function M(t,e){e=function(t){return[t[0]*h.k+h.x,t[1]*h.k+h.y]}(e),h.x+=t[0]-e[0],h.y+=t[1]-e[1]}function A(e,n,i,a){e.__chart__={x:h.x,y:h.y,k:h.k},k(Math.pow(2,a)),M(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map((function(t){return(t-h.x)/h.k})).map(l.invert)),f&&f.domain(u.range().map((function(t){return(t-h.y)/h.k})).map(u.invert))}function E(t){m++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:h.k,translate:[h.x,h.y]})}function L(t){--m||(t({type:\"zoomend\"}),r=null)}function I(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,l).on(x,c),a=T(t.mouse(e)),s=bt(e);function l(){n=1,M(t.mouse(e),a),C(r)}function c(){i.on(y,null).on(x,null),s(n),L(r)}vs.call(e),E(r)}function P(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],f=t.select(r),p=bt(r);function d(){var n=t.touches(r);return e=h.k,n.forEach((function(t){t.identifier in i&&(i[t.identifier]=T(t))})),n}function g(){var e=t.event.target;t.select(e).on(l,m).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,f=n.length;o<f;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var v=p[0];A(r,v,i[v.identifier],Math.floor(Math.log(h.k)/Math.LN2)+1),F()}s=g}else if(p.length>1){v=p[0];var x=p[1],b=v[0]-x[0],_=v[1]-x[1];a=b*b+_*_}}function m(){var o,l,c,u,f=t.touches(r);vs.call(r);for(var h=0,p=f.length;h<p;++h,u=null)if(c=f[h],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],k(g*e)}s=null,M(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),f.on(v,I).on(b,P),p(),L(n)}g(),E(n),f.on(v,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(vs.call(this),e=T(r=n||t.mouse(this)),E(i)),a=setTimeout((function(){a=null,L(i)}),50),F(),k(Math.pow(2,.002*Nt())*h.k),M(r,e),C(i)}function O(){var e=t.mouse(this),r=Math.log(h.k)/Math.LN2;A(this,e,T(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return jt||(jt=\"onwheel\"in i?(Nt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Nt=function(){return t.event.wheelDelta},\"mousewheel\"):(Nt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each((function(){var e=_.of(this,arguments),n=h;bs?t.select(this).transition().each(\"start.zoom\",(function(){h=this.__chart__||{x:0,y:0,k:1},E(e)})).tween(\"zoom:zoom\",(function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-h.x)/h.k,(s-h.y)/h.k,i/h.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=h={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}})).each(\"interrupt.zoom\",(function(){L(e)})).each(\"end.zoom\",(function(){L(e)})):(this.__chart__=h,E(e),C(e),L(e))}))},w.translate=function(t){return arguments.length?(h={x:+t[0],y:+t[1],k:h.k},S(),w):[h.x,h.y]},w.scale=function(t){return arguments.length?(h={x:h.x,y:h.y,k:null},k(+t),S(),w):h.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?Ut:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),h={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(f=t,u=t.copy(),h={x:0,y:0,k:1},w):f},t.rebind(w,_,\"on\")};var Nt,jt,Ut=[0,1/0];function Vt(){}function qt(t,e,r){return this instanceof qt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof qt?new qt(t.h,t.s,t.l):le(\"\"+t,ce,qt):new qt(t,e,r)}t.color=Vt,Vt.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=qt;var Ht=qt.prototype=new Vt;function Gt(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)||e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ne(a(t+120),a(t),a(t-120))}function Yt(e,r,n){return this instanceof Yt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Yt?new Yt(e.h,e.c,e.l):$t(e instanceof Zt?e.l:(e=ue((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Yt(e,r,n)}Ht.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,this.l/t)},Ht.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,t*this.l)},Ht.rgb=function(){return Gt(this.h,this.s,this.l)},t.hcl=Yt;var Wt=Yt.prototype=new Vt;function Xt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Zt(r,Math.cos(t*=Lt)*e,Math.sin(t)*e)}function Zt(t,e,r){return this instanceof Zt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Zt?new Zt(t.l,t.a,t.b):t instanceof Yt?Xt(t.h,t.c,t.l):ue((t=ne(t)).r,t.g,t.b):new Zt(t,e,r)}Wt.brighter=function(t){return new Yt(this.h,this.c,Math.min(100,this.l+Jt*(arguments.length?t:1)))},Wt.darker=function(t){return new Yt(this.h,this.c,Math.max(0,this.l-Jt*(arguments.length?t:1)))},Wt.rgb=function(){return Xt(this.h,this.c,this.l).rgb()},t.lab=Zt;var Jt=18,Kt=Zt.prototype=new Vt;function Qt(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ne(re(3.2404542*(i=.95047*te(i))-1.5371385*(n=1*te(n))-.4985314*(a=1.08883*te(a))),re(-.969266*i+1.8760108*n+.041556*a),re(.0556434*i-.2040259*n+1.0572252*a))}function $t(t,e,r){return t>0?new Yt(Math.atan2(r,e)*It,Math.sqrt(e*e+r*r),t):new Yt(NaN,NaN,t)}function te(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ee(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function re(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ne(t,e,r){return this instanceof ne?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ne?new ne(t.r,t.g,t.b):le(\"\"+t,ne,Gt):new ne(t,e,r)}function ie(t){return new ne(t>>16,t>>8&255,255&t)}function ae(t){return ie(t)+\"\"}Kt.brighter=function(t){return new Zt(Math.min(100,this.l+Jt*(arguments.length?t:1)),this.a,this.b)},Kt.darker=function(t){return new Zt(Math.max(0,this.l-Jt*(arguments.length?t:1)),this.a,this.b)},Kt.rgb=function(){return Qt(this.l,this.a,this.b)},t.rgb=ne;var oe=ne.prototype=new Vt;function se(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function le(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(he(i[0]),he(i[1]),he(i[2]))}return(a=pe.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function ce(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new qt(n,i,l)}function ue(t,e,r){var n=ee((.4124564*(t=fe(t))+.3575761*(e=fe(e))+.1804375*(r=fe(r)))/.95047),i=ee((.2126729*t+.7151522*e+.072175*r)/1);return Zt(116*i-16,500*(n-i),200*(i-ee((.0193339*t+.119192*e+.9503041*r)/1.08883)))}function fe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function he(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}oe.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ne(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ne(i,i,i)},oe.darker=function(t){return new ne((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},oe.hsl=function(){return ce(this.r,this.g,this.b)},oe.toString=function(){return\"#\"+se(this.r)+se(this.g)+se(this.b)};var pe=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function de(t){return\"function\"==typeof t?t:function(){return t}}function ge(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),me(e,r,t,n)}}function me(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function f(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return this.XDomainRequest&&!(\"withCredentials\"in c)&&/^(http(s)?:)?\\/\\//.test(e)&&(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=f:c.onreadystatechange=function(){c.readyState>3&&f()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach((function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}})),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",(function(t){i(null,t)})),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}pe.forEach((function(t,e){pe.set(t,ie(e))})),t.functor=de,t.xhr=ge(L),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=me(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,(function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map((function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"})).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i}))},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function f(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=f())!==o;){for(var h=[];r!==a&&r!==o;)h.push(r),r=f();e&&null==(h=e(h,u++))||s.push(h)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new C,n=[];return e.forEach((function(t){for(var e in t)r.has(e)||n.push(r.add(e))})),[n.map(l).join(t)].concat(e.map((function(e){return n.map((function(t){return l(e[t])})).join(t)}))).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var ve,ye,xe,be,_e=this[P(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function we(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i=r+e,a={c:t,t:i,n:null};return ye?ye.n=a:ve=a,ye=a,xe||(be=clearTimeout(be),xe=1,_e(Te)),a}function Te(){var t=ke(),e=Me()-t;e>24?(isFinite(e)&&(clearTimeout(be),be=setTimeout(Te,e)),xe=0):(xe=1,_e(Te))}function ke(){for(var t=Date.now(),e=ve;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Me(){for(var t,e=ve,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:ve=e.n;return ye=t,r}function Ae(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){we.apply(this,arguments)},t.timer.flush=function(){ke(),Me()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Se=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map((function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}}));function Ee(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:L;return function(e){var n=Ce.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],f=+n[6],h=n[7],p=n[8],d=n[9],g=1,m=\"\",v=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":h=!0,d=\"g\";break;case\"%\":g=100,v=\"%\",d=\"f\";break;case\"p\":g=100,v=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(m=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(m=a[0],v=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Le.get(d)||Ie;var b=u&&h;return function(e){var n=v;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+v}else e*=g;var _,w,T=(e=d(e,p)).lastIndexOf(\".\");if(T<0){var k=x?e.lastIndexOf(\"e\"):-1;k<0?(_=e,w=\"\"):(_=e.substring(0,k),w=e.substring(k))}else _=e.substring(0,T),w=r+e.substring(T+1);!u&&h&&(_=o(_,1/0));var M=m.length+_.length+w.length+(b?0:a.length),A=M<f?new Array(M=f-M+1).join(i):\"\";return b&&(_=o(A+_,A.length?f-w.length:1/0)),a+=m,e=_+w,(\"<\"===s?a+e+A:\">\"===s?A+a+e:\"^\"===s?A.substring(0,M>>=1)+a+e+A.substring(M):a+(b?e:A+e))+n}}}t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ae(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Se[8+n/3]};var Ce=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Le=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ae(e,r))).toFixed(Math.max(0,Math.min(20,Ae(e*(1+1e-15),r))))}});function Ie(t){return t+\"\"}var Pe=t.time={},ze=Date;function Oe(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}Oe.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){De.setUTCDate.apply(this._,arguments)},setDay:function(){De.setUTCDay.apply(this._,arguments)},setFullYear:function(){De.setUTCFullYear.apply(this._,arguments)},setHours:function(){De.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){De.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){De.setUTCMinutes.apply(this._,arguments)},setMonth:function(){De.setUTCMonth.apply(this._,arguments)},setSeconds:function(){De.setUTCSeconds.apply(this._,arguments)},setTime:function(){De.setTime.apply(this._,arguments)}};var De=Date.prototype;function Re(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new ze(r-1)),1),r}function a(t,r){return e(t=new ze(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Fe(t);return s.floor=s,s.round=Fe(n),s.ceil=Fe(i),s.offset=Fe(a),s.range=function(t,e,r){try{ze=Oe;var n=new Oe;return n._=t,o(n,e,r)}finally{ze=Date}},t}function Fe(t){return function(e,r){try{ze=Oe;var n=new Oe;return n._=e,t(n,r)._}finally{ze=Date}}}function Be(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(f(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&ze!==Oe,i=new(n?Oe:ze);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function f(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(ze=Oe);return r._=t,e(r)}finally{ze=Date}}return r.parse=function(t){try{ze=Oe;var r=e.parse(t);return r&&r._}finally{ze=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var h=t.map(),p=qe(o),d=He(o),g=qe(s),m=He(s),v=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach((function(t,e){h.set(t.toLowerCase(),e)}));var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+Pe.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(Pe.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(Pe.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=m.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){v.lastIndex=0;var n=v.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return f(t,_.c.toString(),e,r)},d:Qe,e:Qe,H:tr,I:tr,j:$e,L:nr,m:Ke,M:er,p:function(t,e,r){var n=h.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return f(t,_.x.toString(),e,r)},X:function(t,e,r){return f(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}Pe.year=Re((function(t){return(t=Pe.day(t)).setMonth(0,1),t}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t){return t.getFullYear()})),Pe.years=Pe.year.range,Pe.years.utc=Pe.year.utc.range,Pe.day=Re((function(t){var e=new ze(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t){return t.getDate()-1})),Pe.days=Pe.day.range,Pe.days.utc=Pe.day.utc.range,Pe.dayOfYear=function(t){var e=Pe.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach((function(t,e){e=7-e;var r=Pe[t]=Re((function(t){return(t=Pe.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t}),(function(t,e){t.setDate(t.getDate()+7*Math.floor(e))}),(function(t){var r=Pe.year(t).getDay();return Math.floor((Pe.dayOfYear(t)+(r+e)%7)/7)-(r!==e)}));Pe[t+\"s\"]=r.range,Pe[t+\"s\"].utc=r.utc.range,Pe[t+\"OfYear\"]=function(t){var r=Pe.year(t).getDay();return Math.floor((Pe.dayOfYear(t)+(r+e)%7)/7)}})),Pe.week=Pe.sunday,Pe.weeks=Pe.sunday.range,Pe.weeks.utc=Pe.sunday.utc.range,Pe.weekOfYear=Pe.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new _,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(t){return{numberFormat:Ee(t),timeFormat:Be(t)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function fr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&hr.hasOwnProperty(t.type)?hr[t.type](t,e):fr(t,e)};var hr={Feature:function(t,e){fr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)fr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)fr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return mr=0,t.geo.stream(e,Cr),mr};var mr,vr,yr,xr,br,_r,wr,Tr,kr,Mr,Ar,Sr,Er=new lr,Cr={sphere:function(){mr+=4*At},point:O,lineStart:O,lineEnd:O,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;mr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=O}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Lt/2+At/4;var a=(t*=Lt)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,f=n*l+u*Math.cos(s),h=u*o*Math.sin(s);Er.add(Math.atan2(h,f)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Lt,n=Math.cos(s=(e=s)*Lt/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Ir(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Pr(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Or(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),Dt(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,f,h={point:p,lineStart:g,lineEnd:m,polygonStart:function(){h.point=v,h.lineStart=x,h.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),h.point=p,h.lineStart=g,h.lineEnd=m,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),f[0]=e,f[1]=n}};function p(t,a){u.push(f=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Ir([t*Lt,o*Lt]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var f=t-a,h=f>0?1:-1,d=u[0]*It*h,g=y(f)>180;if(g^(h*a<d&&d<h*t))(m=u[1]*It)>i&&(i=m);else if(g^(h*a<(d=(d+360)%360-180)&&d<h*t)){var m;(m=-u[1]*It)<r&&(r=m)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){h.point=d}function m(){f[0]=e,f[1]=n,h.point=p,l=null}function v(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){v(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),f[0]=e,f[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function T(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,h),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)T((p=u[o])[0],g)||T(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=f=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){vr=yr=xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,Nr);var r=Mr,n=Ar,i=Sr,a=r*r+n*n+i*i;return a<Mt&&(r=wr,n=Tr,i=kr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Mt)?[NaN,NaN]:[Math.atan2(n,r)*It,Dt(i/Math.sqrt(a))*It]};var Nr={sphere:O,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Lt;var r=Math.cos(e*=Lt);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){++vr,xr+=(t-xr)/vr,br+=(e-br)/vr,_r+=(r-_r)/vr}function Vr(){var t,e,r;function n(n,i){n*=Lt;var a=Math.cos(i*=Lt),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),Tr+=c*(e+(e=s)),kr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Lt;var o=Math.cos(a*=Lt);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Lt;var a=Math.cos(e*=Lt),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,f=r*s-n*o,h=Math.sqrt(c*c+u*u+f*f),p=r*o+n*s+i*l,d=h&&-Ot(p)/h,g=Math.atan2(h,p);Mr+=d*c,Ar+=d*u,Sr+=d*f,yr+=g,wr+=g*(r+(r=o)),Tr+=g*(n+(n=s)),kr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Lt;var l=Math.cos(s*=Lt);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach((function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}})),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,f,h=a[0];;){for(var p=h,d=!0;p.v;)if((p=p.n)===h)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((f=u[s])[0],f[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((f=u[s])[0],f[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:f,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=f,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var f=c[0],h=f[0],p=f[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),m=1;;){m===u&&(m=0);var v=(t=c[m])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=v-h,w=_>=0?1:-1,T=w*_,k=T>At,M=d*x;if(Er.add(Math.atan2(M*w*Math.sin(T),g*b+M*Math.cos(T))),a+=k?_+w*St:_,k^h>=r^v>=r){var A=zr(Ir(f),Ir(t));Rr(A);var S=zr(i,A);Rr(S);var E=(k^_>=0?-1:1)*Dt(S[2]);(n>E||n===E&&(A[0]||A[1]))&&(o+=k^_>=0?1:-1)}if(!m++)break;h=v,d=x,g=b,f=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,$r,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function f(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function h(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=h,l.lineStart()}function d(){u.point=f,l.lineEnd()}var g,m,v=Qr(),y=r(v),x=!1;function b(t,e){m.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),m=[]}function w(){b(m[0][0],m[0][1]),y.lineEnd();var t,e=y.clean(),r=v.buffer(),n=r.length;if(m.pop(),g.push(m),m=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function Qr(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:O,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function $r(t,e){return((t=t.x)[0]<0?t[1]-Ct-kt:Ct-t[1])-((e=e.x)[0]<0?e[1]-Ct-kt:Ct-e[1])}var tn=Jr(Yr,(function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Ct:-Ct),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}}),(function(t,e,r,n){var i;if(null==t)i=r*Ct,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])}),[-At,-At/2]);function en(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,(function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(f,h){var p,d=[f,h],g=i(f,h),m=r?g?0:o(f,h):g?o(f+(f<0?At:-At),h):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var v;m&s||!(v=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(v[0][0],v[0][1]),t.point(v[1][0],v[1][1]),t.lineEnd()):(t.point(v[1][0],v[1][1]),t.lineEnd(),t.lineStart(),t.point(v[0][0],v[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=m},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}}),Bn(t,6*Lt),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Ir(t),Ir(r)),o=Pr(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,f=zr(i,a),h=Dr(i,c);Or(h,Dr(a,u));var p=f,d=Pr(h,p),g=Pr(p,p),m=d*d-g*(Pr(h,h)-1);if(!(m<0)){var v=Math.sqrt(m),x=Dr(p,(-d-v)/g);if(Or(x,h),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],T=t[1],k=r[1];w<_&&(b=_,_=w,w=b);var M=w-_,A=y(M-At)<kt;if(!A&&k<T&&(b=T,T=k,k=b),A||M<kt?A?T+k>0^x[1]<(y(x[0]-_)<kt?T:k):T<=x[1]&&x[1]<=k:M>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+v)/g);return Or(S,h),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}function rn(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,f=1,h=s.x-l,p=s.y-c;if(a=t-l,h||!(a>0)){if(a/=h,h<0){if(a<u)return;a<f&&(f=a)}else if(h>0){if(a>f)return;a>u&&(u=a)}if(a=r-l,h||!(a<0)){if(a/=h,h<0){if(a>f)return;a>u&&(u=a)}else if(h>0){if(a<u)return;a<f&&(f=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<f&&(f=a)}else if(p>0){if(a>f)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>f)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<f&&(f=a)}return u>0&&(i.a={x:l+u*h,y:c+u*p}),f<1&&(i.b={x:l+f*h,y:c+f*p}),i}}}}}}function nn(e,r,n,i){return function(l){var c,u,f,h,p,d,g,m,v,y,x,b=l,_=Qr(),w=rn(e,r,n,i),T={point:A,lineStart:function(){T.point=S,u&&u.push(f=[]);y=!0,v=!1,g=m=NaN},lineEnd:function(){c&&(S(h,p),d&&v&&_.rejoin(),c.push(_.buffer()));T.point=A,v&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&zt(c,a,t)>0&&++e:a[1]<=n&&zt(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),k(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,k,l),l.polygonEnd()),c=u=f=null}};function k(t,o,l,c){var u=0,f=0;if(null==t||(u=a(t,l))!==(f=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==f);else c.point(o[0],o[1])}function M(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function A(t,e){M(t,e)&&l.point(t,e)}function S(t,e){var r=M(t=Math.max(-1e9,Math.min(1e9,t)),e=Math.max(-1e9,Math.min(1e9,e)));if(u&&f.push([t,e]),y)h=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&v)l.point(t,e);else{var n={a:{x:g,y:m},b:{x:t,y:e}};w(n)?(v||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,m=e,v=r}return T};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Ln(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,Dt((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],f=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,f-.238*e],[u+.455*e,f+.238*e]]).stream(l).point,n=o.translate([u-.307*e,f+.201*e]).clipExtent([[u-.425*e+kt,f+.12*e+kt],[u-.214*e-kt,f+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,f+.212*e]).clipExtent([[u-.214*e+kt,f+.166*e+kt],[u-.115*e-kt,f+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,fn,hn,pn={point:O,lineStart:O,lineEnd:O,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=O,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>fn&&(fn=t);e<un&&(un=e);e>hn&&(hn=e)},lineStart:O,lineEnd:O,polygonStart:O,polygonEnd:O};function mn(){var t=vn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=vn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function vn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=Tn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,Tr+=o*(e+n)/2,kr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function Tn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,Tr+=o*(n+e)/2,kr+=o,Mr+=(o=n*t-r*e)*(r+t),Ar+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function kn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:O};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,St)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function Mn(t){var e=.5,r=Math.cos(30*Lt),n=16;function i(t){return(n?o:a)(t)}function a(e){return En(e,(function(r,n){r=t(r,n),e.point(r[0],r[1])}))}function o(e){var r,i,a,o,l,c,u,f,h,p,d,g,m={point:v,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),m.lineStart=_},polygonEnd:function(){e.polygonEnd(),m.lineStart=y}};function v(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){f=NaN,m.point=x,e.lineStart()}function x(r,i){var a=Ir([r,i]),o=t(r,i);s(f,h,u,p,d,g,f=o[0],h=o[1],u=r,p=a[0],d=a[1],g=a[2],n,e),e.point(f,h)}function b(){m.point=v,e.lineEnd()}function _(){y(),m.point=w,m.lineEnd=T}function w(t,e){x(r=t,e),i=f,a=h,o=p,l=d,c=g,m.point=x}function T(){s(f,h,u,p,d,g,i,a,r,o,l,c,n,e),m.lineEnd=b,b()}return m}function s(n,i,a,o,l,c,u,f,h,p,d,g,m,v){var x=u-n,b=f-i,_=x*x+b*b;if(_>4*e&&m--){var w=o+p,T=l+d,k=c+g,M=Math.sqrt(w*w+T*T+k*k),A=Math.asin(k/=M),S=y(y(k)-1)<kt||y(a-h)<kt?(a+h)/2:Math.atan2(T,w),E=t(S,A),C=E[0],L=E[1],I=C-n,P=L-i,z=b*I-x*P;(z*z/_>e||y((x*I+b*P)/_-.5)>.3||o*p+l*d+c*g<r)&&(s(n,i,a,o,l,c,C,L,S,w/=M,T/=M,k,m,v),v.point(C,L),s(C,L,S,w,T,k,u,f,h,p,d,g,m,v))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function An(t){var e=Mn((function(e,r){return t([e*It,r*It])}));return function(t){return In(e(t))}}function Sn(t){this.stream=t}function En(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function Cn(t){return Ln((function(){return t}))()}function Ln(e){var r,n,i,a,o,s,l=Mn((function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]})),c=150,u=480,f=250,h=0,p=0,d=0,g=0,m=0,v=tn,y=L,x=null,b=null;function _(t){return[(t=i(t[0]*Lt,t[1]*Lt))[0]*c+a,o-t[1]*c]}function w(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*It,t[1]*It]}function T(){i=Gr(n=On(d,g,m),r);var t=r(h,p);return a=u-t[0]*c,o=f+t[1]*c,k()}function k(){return s&&(s.valid=!1,s=null),_}return _.stream=function(t){return s&&(s.valid=!1),(s=In(v(n,l(y(t))))).valid=!0,s},_.clipAngle=function(t){return arguments.length?(v=null==t?(x=t,tn):en((x=+t)*Lt),k()):x},_.clipExtent=function(t){return arguments.length?(b=t,y=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):L,k()):b},_.scale=function(t){return arguments.length?(c=+t,T()):c},_.translate=function(t){return arguments.length?(u=+t[0],f=+t[1],T()):[u,f]},_.center=function(t){return arguments.length?(h=t[0]%360*Lt,p=t[1]%360*Lt,T()):[h*It,p*It]},_.rotate=function(t){return arguments.length?(d=t[0]%360*Lt,g=t[1]%360*Lt,m=t.length>2?t[2]%360*Lt:0,T()):[d*It,g*It,m*It]},t.rebind(_,l,\"precision\"),function(){return r=e.apply(this,arguments),_.invert=r.invert&&w,T()}}function In(t){return En(t,(function(e,r){t.point(e*Lt,r*Lt)}))}function Pn(t,e){return[t,e]}function zn(t,e){return[t>At?t-St:t<-At?t+St:t,e]}function On(t,e,r){return t?e||r?Gr(Rn(t),Fn(e,r)):Rn(t):e||r?Fn(e,r):zn}function Dn(t){return function(e,r){return[(e+=t)>At?e-St:e<-At?e+St:e,r]}}function Rn(t){var e=Dn(t);return e.invert=Dn(-t),e}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),Dt(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),Dt(u*r-s*n)]},o}function Bn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Nn(r,i),a=Nn(r,a),(o>0?i<a:i>a)&&(i+=o*St)):(i=t+o*St,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Nn(t,e){var r=Ir(e);r[0]-=t,Rr(r);var n=Ot(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[t,e]}))}}function Un(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[e,t]}))}}function Vn(t){return t.source}function qn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,n(xn)),Sr?[Mr/Sr,Ar/Sr]:kr?[wr/kr,Tr/kr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return fn=hn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[fn,hn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||An(t):L,l()):e},s.context=function(t){return arguments.length?(i=null==(r=t)?new mn:new kn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Sn(e);for(var n in t)r[n]=t[n];return r}}},Sn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=Cn,t.geo.projectionMutator=Ln,(t.geo.equirectangular=function(){return Cn(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Lt,e[1]*Lt))[0]*=It,e[1]*=It,e}return t=On(t[0]%360*Lt,t[1]*Lt,t.length>2?t[2]*Lt:0),e.invert=function(e){return(e=t.invert(e[0]*Lt,e[1]*Lt))[0]*=It,e[1]*=It,e},e},zn.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=On(-t[0]*Lt,-t[1]*Lt,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=It,t[1]*=It}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Bn((t=+r)*Lt,n*Lt),i):t},i.precision=function(r){return arguments.length?(e=Bn(t*Lt,(n=+r)*Lt),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Lt,i=t[1]*Lt,a=e[1]*Lt,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),f=Math.cos(a);return Math.atan2(Math.sqrt((r=f*o)*r+(r=c*u-l*f*s)*r),l*u+c*f*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,f,h,p=10,d=p,g=90,m=360,v=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(f).concat(t.range(Math.ceil(l/m)*m,s,m).map(h)).concat(t.range(Math.ceil(r/p)*p,e,p).filter((function(t){return y(t%g)>kt})).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter((function(t){return y(t%m)>kt})).map(u))}return x.lines=function(){return b().map((function(t){return{type:\"LineString\",coordinates:t}}))},x.outline=function(){return{type:\"Polygon\",coordinates:[f(i).concat(h(s).slice(1),f(n).reverse().slice(1),h(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(v)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(v)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],m=+t[1],x):[g,m]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(v=+t,c=jn(o,a,90),u=Un(r,e,v),f=jn(l,s,90),h=Un(i,n,v),x):v},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Vn,i=qn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Lt,n=t[1]*Lt,i=e[0]*Lt,a=e[1]*Lt,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),f=o*Math.sin(r),h=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Ft(a-n)+o*l*Ft(i-r))),g=1/Math.sin(d),(m=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*h,i=r*f+e*p,a=r*s+e*c;return[Math.atan2(i,n)*It,Math.atan2(a,Math.sqrt(n*n+i*i))*It]}:function(){return[r*It,n*It]}).distance=d,m;var r,n,i,a,o,s,l,c,u,f,h,p,d,g,m},t.geo.length=function(e){return yn=0,t.geo.stream(e,Hn),yn};var Hn={sphere:O,point:O,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Lt),o=Math.cos(i),s=y((n*=Lt)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}Hn.point=function(i,a){t=i*Lt,e=Math.sin(a*=Lt),r=Math.cos(a),Hn.point=n},Hn.lineEnd=function(){Hn.point=Hn.lineEnd=O}},lineEnd:O,polygonStart:O,polygonEnd:O};function Gn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Yn=Gn((function(t){return Math.sqrt(2/(1+t))}),(function(t){return 2*Math.asin(t/2)}));(t.geo.azimuthalEqualArea=function(){return Cn(Yn)}).raw=Yn;var Wn=Gn((function(t){var e=Math.acos(t);return e&&e/Math.sin(e)}),L);function Xn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Kn;function o(t,e){a>0?e<-Ct+kt&&(e=-Ct+kt):e>Ct-kt&&(e=Ct-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Ct]},o}function Zn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return Cn(Wn)}).raw=Wn,(t.geo.conicConformal=function(){return an(Xn)}).raw=Xn,(t.geo.conicEquidistant=function(){return an(Zn)}).raw=Zn;var Jn=Gn((function(t){return 1/t}),Math.atan);function Kn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Qn(t){var e,r=Cn(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return Cn(Jn)}).raw=Jn,Kn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Ct]},(t.geo.mercator=function(){return Qn(Kn)}).raw=Kn;var $n=Gn((function(){return 1}),Math.asin);(t.geo.orthographic=function(){return Cn($n)}).raw=$n;var ti=Gn((function(t){return 1/(1+t)}),(function(t){return 2*Math.atan(t)}));function ei(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ri(t){return t[0]}function ni(t){return t[1]}function ii(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&zt(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ai(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return Cn(ti)}).raw=ti,ei.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Ct]},(t.geo.transverseMercator=function(){var t=Qn(ei),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ei,t.geom={},t.geom.hull=function(t){var e=ri,r=ni;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=de(e),a=de(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ai),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ii(s),u=ii(l),f=u[0]===c[0],h=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+f;n<u.length-h;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return U(t,oi),t};var oi=t.geom.polygon.prototype=[];function si(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function li(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,f=n[1]-c,h=(s*(l-c)-f*(i-a))/(f*o-s*u);return[i+h*o,l+h*u]}function ci(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}oi.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},oi.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},oi.clip=function(t){for(var e,r,n,i,a,o,s=ci(t),l=-1,c=this.length-ci(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)si(o=e[r],u,i)?(si(a,u,i)||t.push(li(a,o,u,i)),t.push(o)):si(a,u,i)&&t.push(li(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ui,fi,hi,pi,di,gi=[],mi=[];function vi(){Ri(this),this.edge=this.site=this.circle=null}function yi(t){var e=gi.pop()||new vi;return e.site=t,e}function xi(t){Ei(t),hi.remove(t),gi.push(t),Ri(t)}function bi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];xi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),xi(l),l=a;s.unshift(l),Ei(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),xi(c),c=o;s.push(c),Ei(c);var u,f=s.length;for(u=1;u<f;++u)c=s[u],l=s[u-1],zi(c.edge,l.site,c.site,i);l=s[0],(c=s[f-1]).edge=Ii(l.site,c.site,null,i),Si(l),Si(c)}function _i(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=wi(s,o)-a)>kt)s=s.L;else{if(!((i=a-Ti(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=yi(t);if(hi.insert(e,l),e||r){if(e===r)return Ei(e),r=yi(e.site),hi.insert(l,r),l.edge=r.edge=Ii(e.site,l.site),Si(e),void Si(r);if(r){Ei(e),Ei(r);var c=e.site,u=c.x,f=c.y,h=t.x-u,p=t.y-f,d=r.site,g=d.x-u,m=d.y-f,v=2*(h*m-p*g),y=h*h+p*p,x=g*g+m*m,b={x:(m*y-p*x)/v+u,y:(h*x-g*y)/v+f};zi(r.edge,c,d,b),l.edge=Ii(c,t,null,b),r.edge=Ii(t,d,null,b),Si(e),Si(r)}else l.edge=Ii(e.site,l.site)}}function wi(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,f=1/a-1/c,h=u/c;return f?(-h+Math.sqrt(h*h-2*f*(u*u/(-2*c)-l+c/2+i-a/2)))/f+n:(n+s)/2}function Ti(t,e){var r=t.N;if(r)return wi(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Mi(t,e){return e.angle-t.angle}function Ai(){Ri(this),this.x=this.y=this.arc=this.site=this.cy=null}function Si(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,f=2*(l*(m=a.y-s)-c*u);if(!(f>=-Mt)){var h=l*l+c*c,p=u*u+m*m,d=(m*h-c*p)/f,g=(l*p-u*h)/f,m=g+s,v=mi.pop()||new Ai;v.arc=t,v.site=i,v.x=d+o,v.y=m+Math.sqrt(d*d+g*g),v.cy=m,t.circle=v;for(var y=null,x=di._;x;)if(v.y<x.y||v.y===x.y&&v.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}di.insert(y,v),y||(pi=v)}}}}function Ei(t){var e=t.circle;e&&(e.P||(pi=e.N),di.remove(e),mi.push(e),Ri(e),t.circle=null)}function Ci(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,f=t.r,h=u.x,p=u.y,d=f.x,g=f.y,m=(h+d)/2,v=(p+g)/2;if(g===p){if(m<o||m>=s)return;if(h>d){if(a){if(a.y>=c)return}else a={x:m,y:l};r={x:m,y:c}}else{if(a){if(a.y<l)return}else a={x:m,y:c};r={x:m,y:l}}}else if(i=v-(n=(h-d)/(g-p))*m,n<-1||n>1)if(h>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Li(t,e){this.l=t,this.r=e,this.a=this.b=null}function Ii(t,e,r,n){var i=new Li(t,e);return ui.push(i),r&&zi(i,t,e,r),n&&zi(i,e,t,n),fi[t.i].edges.push(new Oi(i,t,e)),fi[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r){var n=new Li(t,null);return n.a=e,n.b=r,ui.push(n),n}function zi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function Di(){this._=null}function Ri(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Fi(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Bi(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Ni(t){for(;t.L;)t=t.L;return t}function ji(t,e){var r,n,i,a=t.sort(Ui).pop();for(ui=[],fi=new Array(t.length),hi=new Di,di=new Di;;)if(i=pi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(fi[a.i]=new ki(a),_i(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;bi(i.arc)}e&&(function(t){for(var e,r=ui,n=rn(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ci(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,f=t[0][0],h=t[1][0],p=t[0][1],d=t[1][1],g=fi,m=g.length;m--;)if((a=g[m])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi(Pi(a.site,u,y(n-f)<kt&&d-i>kt?{x:f,y:y(e-f)<kt?r:d}:y(i-d)<kt&&h-n>kt?{x:y(r-d)<kt?e:h,y:d}:y(n-h)<kt&&i-p>kt?{x:h,y:y(e-h)<kt?r:p}:y(i-p)<kt&&n-f>kt?{x:y(r-p)<kt?e:f,y:p}:null),a.site,null)),++l)}(e));var o={cells:fi,edges:ui};return hi=di=ui=fi=null,o}function Ui(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Mi),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},Di.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Ni(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Fi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Bi(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Bi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Fi(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Ni(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Fi(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Bi(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Fi(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Bi(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Fi(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Bi(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ri,r=ni,n=e,i=r,a=Vi;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return ji(s(t),a).cells.forEach((function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map((function(t){var e=t.start();return[e.x,e.y]})):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]})),e}function s(t){return t.map((function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}}))}return o.links=function(t){return ji(s(t)).edges.filter((function(t){return t.l&&t.r})).map((function(e){return{source:t[e.l.i],target:t[e.r.i]}}))},o.triangles=function(t){var e=[];return ji(s(t)).cells.forEach((function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Mi),u=-1,f=c.length,h=c[f-1].edge,p=h.l===l?h.r:h.l;++u<f;)h,i=p,p=(h=c[u].edge).l===l?h.r:h.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])})),e},o.x=function(t){return arguments.length?(n=de(e=t),o):e},o.y=function(t){return arguments.length?(i=de(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?Vi:t,o):a===Vi?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===Vi?null:a&&a[1]},o};var Vi=[[-1e6,-1e6],[1e6,1e6]];function qi(t){return t.x}function Hi(t){return t.y}function Gi(t,e,r,n,i,a){if(!t(e,r,n,i,a)){var o=.5*(r+i),s=.5*(n+a),l=e.nodes;l[0]&&Gi(t,l[0],r,n,o,s),l[1]&&Gi(t,l[1],o,n,i,s),l[2]&&Gi(t,l[2],r,s,o,a),l[3]&&Gi(t,l[3],o,s,i,a)}}function Yi(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,f,h,p){if(!(u>a||f>o||h<n||p<i)){if(d=c.point){var d,g=e-c.x,m=r-c.y,v=g*g+m*m;if(v<l){var y=Math.sqrt(l=v);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+h),_=.5*(f+p),w=(r>=_)<<1|e>=b,T=w+4;w<T;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,f,b,_);break;case 1:t(c,b,f,h,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,h,p)}}}(t,n,i,a,o),s}function Wi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+se(Math.round(n+o*t))+se(Math.round(i+s*t))+se(Math.round(a+l*t))}}function Xi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=$i(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Zi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Ji(t,e){var r,n,i,a=Ki.lastIndex=Qi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Ki.exec(t))&&(n=Qi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Zi(r,n)})),a=Qi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ri,s=ni;if(a=arguments.length)return o=qi,s=Hi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,f,h,p,d,g,m,v=de(o),x=de(s);if(null!=e)p=e,d=r,g=n,m=i;else if(g=m=-(p=d=1/0),c=[],u=[],h=t.length,a)for(f=0;f<h;++f)(l=t[f]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>m&&(m=l.y),c.push(l.x),u.push(l.y);else for(f=0;f<h;++f){var b=+v(l=t[f],f),_=+x(l,f);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>m&&(m=_),c.push(b),u.push(_)}var w=g-p,T=m-d;function k(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)M(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,M(t,u,l,c,i,a,o,s),M(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else M(t,e,r,n,i,a,o,s)}function M(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,f=n>=c,h=f<<1|u;t.leaf=!1,u?i=l:o=l,f?a=c:s=c,k(t=t.nodes[h]||(t.nodes[h]={leaf:!0,nodes:[],point:null,x:null,y:null}),e,r,n,i,a,o,s)}w>T?m=d+w:g=p+T;var A={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){k(A,t,+v(t,++f),+x(t,f),p,d,g,m)},visit:function(t){Gi(t,A,p,d,g,m)},find:function(t){return Yi(A,t[0],t[1],p,d,g,m)}};if(f=-1,null==e){for(;++f<h;)k(A,t[f],c[f],u[f],p,d,g,m);--f}else t.forEach(A.add);return c=u=t=l=null,A}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=Wi,t.interpolateObject=Xi,t.interpolateNumber=Zi,t.interpolateString=Ji;var Ki=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Qi=new RegExp(Ki.source,\"g\");function $i(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function ta(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push($i(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=$i,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?pe.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?Wi:Ji:e instanceof Vt?Wi:Array.isArray(e)?ta:\"object\"===r&&isNaN(e)?Xi:Zi)(t,e)}],t.interpolateArray=ta;var ea=function(){return L},ra=t.map({linear:ea,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return sa},cubic:function(){return la},sin:function(){return ua},exp:function(){return fa},circle:function(){return ha},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/St*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*St/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return pa}}),na=t.map({in:L,out:aa,\"in-out\":oa,\"out-in\":function(t){return oa(aa(t))}});function ia(t){return function(e){return e<=0?0:e>=1?1:t(e)}}function aa(t){return function(e){return 1-t(1-e)}}function oa(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function sa(t){return t*t}function la(t){return t*t*t}function ca(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function ua(t){return 1-Math.cos(t*Ct)}function fa(t){return Math.pow(2,10*(t-1))}function ha(t){return 1-Math.sqrt(1-t*t)}function pa(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function da(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ga(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=va(i),s=ma(i,a),l=va(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*It,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*It:0}function ma(t,e){return t[0]*e[0]+t[1]*e[1]}function va(t){var e=Math.sqrt(ma(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e=t.indexOf(\"-\"),n=e>=0?t.slice(0,e):t,i=e>=0?t.slice(e+1):\"in\";return n=ra.get(n)||ea,ia((i=na.get(i)||L)(n.apply(null,r.call(arguments,1))))},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Xt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Gt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return Qt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=da,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ga(e?e.matrix:ya)})(e)},ga.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var ya={a:1,b:0,c:0,d:1,e:0,f:0};function xa(t){return t.length?t.pop()+\",\":\"\"}function ba(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(xa(r)+\"rotate(\",null,\")\")-2,x:Zi(t,e)})):e&&r.push(xa(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(xa(r)+\"skewX(\",null,\")\")-2,x:Zi(t,e)}):e&&r.push(xa(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(xa(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(xa(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function _a(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function wa(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function Ta(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=ka(t),n=ka(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function ka(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function Ma(t){t.fixed|=2}function Aa(t){t.fixed&=-7}function Sa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function Ea(t){t.fixed&=-5}t.interpolateTransform=ba,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(Ta(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,h,p,d,g={},m=[],v=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];m.push(u),y.push(t.range(i)),l+=u}for(a&&v.sort((function(t,e){return a(m[t],m[e])})),o&&y.forEach((function(t,e){t.sort((function(t,r){return o(n[e][t],n[e][r])}))})),l=(St-c*i)/l,u=0,p=-1;++p<i;){for(h=u,d=-1;++d<i;){var x=v[p],b=y[x][d],_=n[x][b],w=u,T=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:T,value:_}}r[x]={index:x,startAngle:h,endAngle:u,value:m[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var k=g[p+\"-\"+d],M=g[d+\"-\"+p];(k.value||M.value)&&e.push(k.value<M.value?{source:M,target:k}:{source:k,target:M})}s&&f()}function f(){e.sort((function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)}))}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&f(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,f=Ca,h=La,p=-30,d=Ia,g=.1,m=.64,v=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/m<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,f,h,d,m,b,_,w,T=v.length,k=y.length;for(s=0;s<k;++s)h=(f=y[s]).source,(m=(_=(d=f.target).x-h.x)*_+(w=d.y-h.y)*w)&&(_*=m=n*a[s]*((m=Math.sqrt(m))-i[s])/m,w*=m,d.x-=_*(b=h.weight+d.weight?h.weight/(h.weight+d.weight):.5),d.y-=w*b,h.x+=_*(b=1-b),h.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<T;)(f=v[s]).x+=(_-f.x)*b,f.y+=(w-f.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;if(e.charge=0,!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge,e.cy=a/e.charge}(r=t.geom.quadtree(v),n,o),s=-1;++s<T;)(f=v[s]).fixed||r.visit(x(f));for(s=-1;++s<T;)(f=v[s]).fixed?(f.x=f.px,f.y=f.py):(f.x-=(f.px-(f.px=f.x))*u,f.y-=(f.py-(f.py=f.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(v=t,s):v},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(m=t*t,s):Math.sqrt(m)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=we(s.tick)),s):n},s.start=function(){var t,e,r,n=v.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=v[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=v[r.source]),\"number\"==typeof r.target&&(r.target=v[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=v[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=f;if(a=[],\"function\"==typeof h)for(t=0;t<l;++t)a[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=h;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,v[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(L).on(\"dragstart.force\",Ma).on(\"drag.force\",b).on(\"dragend.force\",Aa)),!arguments.length)return r;this.on(\"mouseover.force\",Sa).on(\"mouseout.force\",Ea).call(r)},t.rebind(s,l,\"on\")};var Ca=20,La=1,Ia=1/0;function Pa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=Ba,e}function za(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Oa(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function Da(t){return t.children}function Ra(t){return t.value}function Fa(t,e){return e.value-t.value}function Ba(e){return t.merge(e.map((function(t){return(t.children||[]).map((function(e){return{source:t,target:e}}))})))}t.layout.hierarchy=function(){var t=Fa,e=Da,r=Ra;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Oa(i,(function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)})),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(za(t,(function(t){t.children&&(t.value=0)})),Oa(t,(function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)}))),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Pa(n,e)},t.layout.pie=function(){var e=Number,r=Na,n=0,i=St,a=0;function o(s){var l,c=s.length,u=s.map((function(t,r){return+e.call(o,t,r)})),f=+(\"function\"==typeof n?n.apply(this,arguments):n),h=(\"function\"==typeof i?i.apply(this,arguments):i)-f,p=Math.min(Math.abs(h)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(h<0?-1:1),g=t.sum(u),m=g?(h-c*d)/g:0,v=t.range(c),y=[];return null!=r&&v.sort(r===Na?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),v.forEach((function(t){y[t]={data:s[t],value:l=u[t],startAngle:f,endAngle:f+=l*m+d,padAngle:p}})),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Na={};function ja(t){return t.x}function Ua(t){return t.y}function Va(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=L,r=Ga,n=Ya,i=Va,a=ja,o=Ua;function s(l,c){if(!(p=l.length))return l;var u=l.map((function(t,r){return e.call(s,t,r)})),f=u.map((function(t){return t.map((function(t,e){return[a.call(s,t,e),o.call(s,t,e)]}))})),h=r.call(s,f,c);u=t.permute(u,h),f=t.permute(f,h);var p,d,g,m,v=n.call(s,f,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],m=v[g],f[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],m+=f[d-1][g][1],f[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:qa.get(t)||Ga,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Ha.get(t)||Ya,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var qa=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Wa),o=e.map(Xa),s=t.range(i).sort((function(t,e){return a[t]-a[e]})),l=0,c=0,u=[],f=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],f.push(n));return f.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:Ga}),Ha=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,f=t[0],h=f.length,p=[];for(p[0]=l=c=0,r=1;r<h;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=f[r][0]-f[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<h;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ya});function Ga(e){return t.range(e.length)}function Ya(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Wa(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function Xa(t){return t.reduce(Za,0)}function Za(t,e){return t+e[1]}function Ja(t,e){return Ka(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ka(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Qa(e){return[t.min(e),t.max(e)]}function $a(t,e){return t.value-e.value}function to(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function eo(t,e){t._pack_next=e,e._pack_prev=t}function ro(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function no(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,f=1/0,h=-1/0;if(e.forEach(io),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(oo(r,n,i=e[2]),x(i),to(r,i),r._pack_prev=i,to(i,n),n=r._pack_next,a=3;a<l;a++){oo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(ro(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!ro(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?eo(r,n=o):eo(r=s,n),a--):(to(r,i),n=i,x(i))}var m=(c+u)/2,v=(f+h)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=m,i.y-=v,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(ao)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),f=Math.min(t.y-t.r,f),h=Math.max(t.y+t.r,h)}}function io(t){t._pack_next=t._pack_prev=t}function ao(t){delete t._pack_next,delete t._pack_prev}function oo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function so(t,e){return t.parent==e.parent?1:2}function lo(t){var e=t.children;return e.length?e[0]:t.t}function co(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function uo(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function fo(t,e,r){return t.a.parent===e.parent?t.a:r}function ho(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function po(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function go(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function mo(t){return t.rangeExtent?t.rangeExtent():go(t.range())}function vo(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function yo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function xo(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:bo}t.layout.histogram=function(){var e=!0,r=Number,n=Qa,i=Ja;function a(a,o){for(var s,l,c=[],u=a.map(r,this),f=n.call(this,u,o),h=i.call(this,f,u,o),p=(o=-1,u.length),d=h.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=h[o+1]-(s.x=h[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=f[0]&&l<=f[1]&&((s=c[t.bisect(h,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=de(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ka(e,t)}:de(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort($a),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Oa(s,(function(t){t.r=+u(t.value)})),Oa(s,no),n){var f=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Oa(s,(function(t){t.r+=f})),Oa(s,no),Oa(s,(function(t){t.r-=f}))}return function t(e,r,n,i){var a=e.children;if(e.x=r+=i*e.x,e.y=n+=i*e.y,e.r*=i,a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Pa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],f=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Oa(f,o),f.parent.m=-f.z,za(f,s),i)za(u,l);else{var h=u,p=u,d=u;za(u,(function(t){t.x<h.x&&(h=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)}));var g=r(h,p)/2-h.x,m=n[0]/(p.x+r(p,h)/2+g),v=n[1]/(d.depth||1);za(u,(function(t){t.x=(t.x+g)*m,t.y=t.depth*v}))}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=co(s),a=lo(a),s&&a;)l=lo(l),(o=co(o)).a=t,(i=s.z+f-a.z-c+r(s._,a._))>0&&(uo(fo(s,t,n),t,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!co(o)&&(o.t=s,o.m+=f-u),a&&!lo(l)&&(l.t=a,l.m+=c-h,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Pa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Oa(c,(function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce((function(t,e){return t+e.x}),0)/t.length}(n),e.y=function(e){return 1+t.max(e,(function(t){return t.y}))}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)}));var f=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),h=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=f.x-r(f,h)/2,d=h.x+r(h,f)/2;return Oa(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Pa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=ho,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function f(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),h=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=h?(c.pop(),h=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,h=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(f)}}function h(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(h)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?h:f)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){var r=t.call(g,e,e.depth);return null==r?ho(e):po(e,\"number\"==typeof r?[r,r,r,r]:r)}function r(e){return po(e,t)}var n;return o=null==(a=t)?ho:\"function\"==(n=typeof t)?e:\"number\"===n?(t=[t,t,t,t],r):r,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Pa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var bo={floor:L,ceil:L};function _o(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function wo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function To(t,e){return yo(t,xo(ko(t,e)[2])),yo(t,xo(ko(t,e)[2])),t}function ko(t,e){null==e&&(e=10);var r=go(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function Mo(e,r){return t.range.apply(t,ko(e,r))}function Ao(e,r,n){var i=ko(e,r);if(n){var a=Ce.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+Eo(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=Eo(e[2]);return t in So?Math.abs(r-Eo(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+Eo(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?_o:vo,s=i?wa:_a;return a=t(e,r,s,n),o=t(r,e,s,$i),l}function l(t){return a(t)}return l.invert=function(t){return o(t)},l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e},l.range=function(t){return arguments.length?(r=t,s()):r},l.rangeRound=function(t){return l.range(t).interpolate(da)},l.clamp=function(t){return arguments.length?(i=t,s()):i},l.interpolate=function(t){return arguments.length?(n=t,s()):n},l.ticks=function(t){return Mo(e,t)},l.tickFormat=function(t,r){return Ao(e,t,r)},l.nice=function(t){return To(e,t),s()},l.copy=function(){return t(e,r,n,i)},s()}([0,1],[0,1],$i,!1)};var So={s:1,g:1,p:1,r:1,e:1};function Eo(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}return l.invert=function(t){return s(r.invert(t))},l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a},l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n},l.nice=function(){var t=yo(a.map(o),i?Math:Lo);return r.domain(t),a=t.map(s),l},l.ticks=function(){var t=go(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),f=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var h=1;h<f;h++)e.push(s(c)*h);e.push(s(c))}else for(e.push(s(c));c++<u;)for(h=f-1;h>0;h--)e.push(s(c)*h);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e},l.tickFormat=function(e,r){if(!arguments.length)return Co;arguments.length<2?r=Co:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}},l.copy=function(){return e(r.copy(),n,i,a)},wo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var Co=t.format(\".0e\"),Lo={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Io(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Io(r),a=Io(1/r);function o(t){return e(i(t))}return o.invert=function(t){return a(e.invert(t))},o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n},o.ticks=function(t){return Mo(n,t)},o.tickFormat=function(t,e){return Ao(n,t,e)},o.nice=function(t){return o.domain(To(n,t))},o.exponent=function(t){return arguments.length?(i=Io(r=t),a=Io(1/r),e.domain(n.map(i)),o):r},o.copy=function(){return t(e.copy(),r,n)},wo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map((function(t){return e+n*t}))}return s.domain=function(t){if(!arguments.length)return r;r=[],i=new _;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)},s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a},s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s},s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s},s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=(f-u)/(r.length-e+2*i);return a=l(u+h*i,h),c&&a.reverse(),o=h*(1-e),n={t:\"rangeBands\",a:arguments},s},s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=Math.floor((f-u)/(r.length-e+2*i));return a=l(u+Math.round((f-u-(r.length-e)*h)/2),h),c&&a.reverse(),o=Math.round(h*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s},s.rangeBand=function(){return o},s.rangeExtent=function(){return go(n.a[0])},s.copy=function(){return e(r,n)},s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(Po)},t.scale.category20=function(){return t.scale.ordinal().range(zo)},t.scale.category20b=function(){return t.scale.ordinal().range(Oo)},t.scale.category20c=function(){return t.scale.ordinal().range(Do)};var Po=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(ae),zo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(ae),Oo=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(ae),Do=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(ae);function Ro(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}return o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(h),a()):r},o.range=function(t){return arguments.length?(n=t,a()):n},o.quantiles=function(){return i},o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]},o.copy=function(){return e(r,n)},a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}return o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]},o.range=function(t){return arguments.length?(n=t,s()):n},o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]},o.copy=function(){return t(e,r,n)},s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}return i.domain=function(t){return arguments.length?(r=t,i):r},i.range=function(t){return arguments.length?(n=t,i):n},i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]},i.copy=function(){return e(r,n)},i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}return r.invert=r,r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e},r.ticks=function(t){return Mo(e,t)},r.tickFormat=function(t,r){return Ao(e,t,r)},r.copy=function(){return t(e)},r}([0,1])},t.svg={},t.svg.arc=function(){var t=Bo,e=No,r=Ro,n=Fo,i=jo,a=Uo,o=Vo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Ct,f=a.apply(this,arguments)-Ct,h=Math.abs(f-u),p=u>f?0:1;if(c<s&&(d=c,c=s,s=d),h>=Et)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,m,v,y,x,b,_,w,T,k,M,A=0,S=0,E=[];if((v=(+o.apply(this,arguments)||0)/2)&&(m=n===Fo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=Dt(m/c*Math.sin(v))),s&&(A=Dt(m/s*Math.sin(v)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(f-S),_=c*Math.sin(f-S);var C=Math.abs(f-u-2*S)<=At?0:1;if(S&&qo(y,x,b,_)===p^C){var L=(u+f)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(f-A),T=s*Math.sin(f-A),k=s*Math.cos(u+A),M=s*Math.sin(u+A);var I=Math.abs(u-f+2*A)<=At?0:1;if(A&&qo(w,T,k,M)===1-p^I){var P=(u+f)/2;w=s*Math.cos(P),T=s*Math.sin(P),k=M=null}}else w=T=0;if(h>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,O=d;if(h<At){var D=null==k?[w,T]:null==b?[y,x]:li([y,x],[k,M],[b,_],[w,T]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);O=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=Ho(null==k?[w,T]:[k,M],[y,x],c,z,p),q=Ho([b,_],[w,T],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^qo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=k){var H=Ho([y,x],[k,M],s,-O,p),G=Ho([w,T],null==b?[y,x]:[b,_],s,-O,p);d===O?E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^qo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",T)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",T),null!=k&&E.push(\"A\",s,\",\",s,\" 0 \",I,\",\",1-p,\" \",k,\",\",M);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=de(e),s):t},s.outerRadius=function(t){return arguments.length?(e=de(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=de(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Fo?Fo:de(t),s):n},s.startAngle=function(t){return arguments.length?(i=de(t),s):i},s.endAngle=function(t){return arguments.length?(a=de(t),s):a},s.padAngle=function(t){return arguments.length?(o=de(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Ct;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Fo=\"auto\";function Bo(t){return t.innerRadius}function No(t){return t.outerRadius}function jo(t){return t.startAngle}function Uo(t){return t.endAngle}function Vo(t){return t&&t.padAngle}function qo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function Ho(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,f=t[1]+c,h=e[0]+l,p=e[1]+c,d=(u+h)/2,g=(f+p)/2,m=h-u,v=p-f,y=m*m+v*v,x=r-n,b=u*p-h*f,_=(v<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*v-m*_)/y,T=(-b*m-v*_)/y,k=(b*v+m*_)/y,M=(-b*m+v*_)/y,A=w-d,S=T-g,E=k-d,C=M-g;return A*A+S*S>E*E+C*C&&(w=k,T=M),[[w-l,T-c],[w*r/x,T*r/x]]}function Go(t){var e=ri,r=ni,n=Yr,i=Wo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,f=a.length,h=de(e),p=de(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<f;)n.call(this,s=a[u],u)?c.push([+h.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Yo.get(t)||Wo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return Go(L)};var Yo=t.map({linear:Wo,\"linear-closed\":Xo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Zo,\"step-after\":Jo,basis:$o,\"basis-open\":function(t){if(t.length<4)return Wo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(ts(ns,a)+\",\"+ts(ns,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),is(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[ts(ns,o),\",\",ts(ns,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),is(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return $o(t)},cardinal:function(t,e){return t.length<3?Wo(t):t[0]+Ko(t,Qo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Wo(t):t[1]+Ko(t.slice(1,-1),Qo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?Xo(t):t[0]+Ko((t.push(t[0]),t),Qo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Wo(t):t[0]+Ko(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=as(i,a);for(;++e<r;)n[e]=(o+(o=as(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=as(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Wo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function Xo(t){return t.join(\"L\")+\"Z\"}function Zo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Jo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Ko(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Wo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Qo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function $o(t){if(t.length<3)return Wo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",ts(ns,o),\",\",ts(ns,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),is(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function ts(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Yo.forEach((function(t,e){e.key=t,e.closed=/-closed$/.test(t)}));var es=[0,2/3,1/3,0],rs=[0,1/3,2/3,0],ns=[0,1/6,2/3,1/6];function is(t,e,r){t.push(\"C\",ts(es,e),\",\",ts(es,r),\",\",ts(rs,e),\",\",ts(rs,r),\",\",ts(ns,e),\",\",ts(ns,r))}function as(t,e){return(e[1]-t[1])/(e[0]-t[0])}function os(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Ct,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function ss(t){var e=ri,r=ri,n=0,i=ni,a=Yr,o=Wo,s=o.key,l=o,c=\"L\",u=.7;function f(s){var f,h,p,d=[],g=[],m=[],v=-1,y=s.length,x=de(e),b=de(n),_=e===r?function(){return h}:de(r),w=n===i?function(){return p}:de(i);function T(){d.push(\"M\",o(t(m),u),c,l(t(g.reverse()),u),\"Z\")}for(;++v<y;)a.call(this,f=s[v],v)?(g.push([h=+x.call(this,f,v),p=+b.call(this,f,v)]),m.push([+_.call(this,f,v),+w.call(this,f,v)])):g.length&&(T(),g=[],m=[]);return g.length&&T(),d.length?d.join(\"\"):null}return f.x=function(t){return arguments.length?(e=r=t,f):r},f.x0=function(t){return arguments.length?(e=t,f):e},f.x1=function(t){return arguments.length?(r=t,f):r},f.y=function(t){return arguments.length?(n=i=t,f):i},f.y0=function(t){return arguments.length?(n=t,f):n},f.y1=function(t){return arguments.length?(i=t,f):i},f.defined=function(t){return arguments.length?(a=t,f):a},f.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Yo.get(t)||Wo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",f):s},f.tension=function(t){return arguments.length?(u=t,f):u},f}function ls(t){return t.radius}function cs(t){return[t.x,t.y]}function us(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Ct;return[r*Math.cos(n),r*Math.sin(n)]}}function fs(){return 64}function hs(){return\"circle\"}function ps(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=Go(os);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Zo.reverse=Jo,Jo.reverse=Zo,t.svg.area=function(){return ss(L)},t.svg.area.radial=function(){var t=ss(os);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Vn,e=qn,r=ls,n=jo,i=Uo;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,((i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\")}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Ct,u=i.call(t,s,o)-Ct;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=de(t),a):r},a.source=function(e){return arguments.length?(t=de(e),a):t},a.target=function(t){return arguments.length?(e=de(t),a):e},a.startAngle=function(t){return arguments.length?(n=de(t),a):n},a.endAngle=function(t){return arguments.length?(i=de(t),a):i},a},t.svg.diagonal=function(){var t=Vn,e=qn,r=cs;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=de(e),n):t},n.target=function(t){return arguments.length?(e=de(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=cs,n=e.projection;return e.projection=function(t){return arguments.length?n(us(r=t)):r},e},t.svg.symbol=function(){var t=hs,e=fs;function r(r,n){return(ds.get(t.call(this,r,n))||ps)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=de(e),r):t},r.size=function(t){return arguments.length?(e=de(t),r):e},r};var ds=t.map({circle:ps,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*ms)),r=e*ms;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ds.keys();var gs=Math.sqrt(3),ms=Math.tan(30*Lt);Y.transition=function(t){for(var e,r,n=bs||++Ts,i=As(t),a=[],o=_s||{time:Date.now(),ease:ca,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(r=c[u])&&Ss(r,u,i,n,o),e.push(r)}return xs(a,i,n)},Y.interrupt=function(t){return this.each(null==t?vs:ys(As(t)))};var vs=ys(As());function ys(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function xs(t,e,r){return U(t,ws),t.namespace=e,t.id=r,t}var bs,_s,ws=[],Ts=0;function ks(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function Ms(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function As(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function Ss(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),f=u[n];function h(r){var i=u.active,h=u[i];for(var d in h&&(h.timer.c=null,h.timer.t=NaN,--u.count,delete u[i],h.event&&h.event.interrupt.call(t,t.__data__,h.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,we((function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1}),0,a),u.active=n,f.event&&f.event.start.call(t,t.__data__,e),c=[],f.tween.forEach((function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)})),l=f.ease,s=f.duration}function p(i){for(var a=i/s,o=l(a),h=c.length;h>0;)c[--h].call(t,o);if(a>=1)return f.event&&f.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}f||(a=i.time,o=we((function(t){var e=f.delay;if(o.t=e+a,e<=t)return h(t-e);o.c=h}),0,a),f=u[n]={tween:new _,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}ws.call=Y.call,ws.empty=Y.empty,ws.node=Y.node,ws.size=Y.size,t.transition=function(e,r){return e&&e.transition?bs?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=ws,ws.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=W(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),Ss(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return xs(o,a,i)},ws.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=X(t);for(var c=-1,u=this.length;++c<u;)for(var f=this[c],h=-1,p=f.length;++h<p;)if(n=f[h]){a=n[s][o],r=t.call(n,n.__data__,h,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&Ss(i,d,s,o,a),e.push(i)}return xs(l,s,o)},ws.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=lt(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return xs(n,this.namespace,this.id)},ws.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},ws.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ba:$i,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}function s(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})}function l(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}return ks(this,\"attr.\"+e,r,i.local?l:s)},ws.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},ws.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}function a(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=$i(i,e),function(e){this.style.setProperty(t,n(e),r)})})}return ks(this,\"style.\"+t,e,a)},ws.styleTween=function(t,e,r){function n(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}}return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,n)},ws.text=function(t){return ks(this,\"text\",t,Ms)},ws.remove=function(){var t=this.namespace;return this.each(\"end.transition\",(function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)}))},ws.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,(function(t){t[n][r].ease=e})))},ws.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},ws.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},ws.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=_s,o=bs;try{bs=n,ut(this,(function(t,r,a){_s=t[i][n],e.call(t,t.__data__,r,a)}))}finally{_s=a,bs=o}}else ut(this,(function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)}));return this},ws.transition=function(){for(var t,e,r,n=this.id,i=++Ts,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,f=(c=this[s]).length;u<f;u++)(e=c[u])&&Ss(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return xs(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=Es,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each((function(){var n,u=t.select(this),f=this.__chart__||r,h=this.__chart__=r.copy(),p=null==c?h.ticks?h.ticks.apply(h,l):h.domain():c,d=null==e?h.tickFormat?h.tickFormat.apply(h,l):L:e,g=u.selectAll(\".tick\").data(p,h),m=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),v=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=mo(h),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));m.append(\"line\"),m.append(\"text\");var T,k,M,A,S=m.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),I=m.select(\"text\"),P=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ls,T=\"x\",M=\"y\",k=\"x2\",A=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=Is,T=\"y\",M=\"x\",k=\"y2\",A=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(A,z*a),I.attr(M,z*x),E.attr(k,0).attr(A,z*a),P.attr(T,0).attr(M,z*x),h.rangeBand){var O=h,D=O.rangeBand()/2;f=h=function(t){return O(t)+D}}else f.rangeBand?f=h:v.call(n,h,f);m.call(n,f,h),y.call(n,h,h)}))}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in Cs?t+\"\":Es,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var Es=\"bottom\",Cs={top:1,right:1,bottom:1,left:1};function Ls(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"}))}function Is(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"}))}t.svg.brush=function(){var e,r,n=N(h,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,f=zs[0];function h(e){e.each((function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",m).on(\"touchstart.brush\",m),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(f,L);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",(function(t){return\"resize \"+t})).style(\"cursor\",(function(t){return Ps[t]})).append(\"rect\").attr(\"x\",(function(t){return/[ew]$/.test(t)?-3:null})).attr(\"y\",(function(t){return/^[ns]/.test(t)?-3:null})).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",h.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=mo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=mo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)}))}function p(t){t.selectAll(\".resize\").attr(\"transform\",(function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"}))}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function m(){var f,m,v=this,y=t.select(t.event.target),x=n.of(v,arguments),b=t.select(v),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,T=!/^(e|w)$/.test(_)&&a,k=y.classed(\"extent\"),M=bt(v),A=t.mouse(v),S=t.select(o(v)).on(\"keydown.brush\",L).on(\"keyup.brush\",I);if(t.event.changedTouches?S.on(\"touchmove.brush\",P).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",P).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),k)A[0]=s[0]-A[0],A[1]=l[0]-A[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);m=[s[1-E]-A[0],l[1-C]-A[1]],A[0]=s[E],A[1]=l[C]}else t.event.altKey&&(f=A.slice());function L(){32==t.event.keyCode&&(k||(f=null,A[0]-=s[1],A[1]-=l[1],k=2),F())}function I(){32==t.event.keyCode&&2==k&&(A[0]+=s[1],A[1]+=l[1],k=0,F())}function P(){var e=t.mouse(v),r=!1;m&&(e[0]+=m[0],e[1]+=m[1]),k||(t.event.altKey?(f||(f=[(s[0]+s[1])/2,(l[0]+l[1])/2]),A[0]=s[+(e[0]<f[0])],A[1]=l[+(e[1]<f[1])]):f=null),w&&z(e,i,0)&&(d(b),r=!0),T&&z(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:k?\"move\":\"resize\"}))}function z(t,n,i){var a,o,h=mo(n),p=h[0],d=h[1],g=A[i],m=i?l:s,v=m[1]-m[0];if(k&&(p-=g,d-=v+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],k?o=(a+=g)+v:(f&&(g=Math.max(p,Math.min(d,2*f[i]-a))),g<a?(o=a,a=g):o=g),m[0]!=a||m[1]!=o)return i?r=null:e=null,m[0]=a,m[1]=o,!0}function O(){P(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",h.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),M(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),P()}return h.event=function(i){i.each((function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,bs?t.select(this).transition().each(\"start.brush\",(function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})})).tween(\"brush:brush\",(function(){var t=ta(s,a.x),n=ta(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}})).each(\"end.brush\",(function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})})):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))}))},h.x=function(t){return arguments.length?(f=zs[!(i=t)<<1|!a],h):i},h.y=function(t){return arguments.length?(f=zs[!i<<1|!(a=t)],h):a},h.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),h):i&&a?[c,u]:i?c:a?u:null},h.extent=function(t){var n,o,c,u,f;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(f=n,n=o,o=f),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(f=c,c=u,u=f),c==l[0]&&u==l[1]||(l=[c,u])),h):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(f=n,n=o,o=f))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(f=c,c=u,u=f))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},h.clear=function(){return h.empty()||(s=[0,0],l=[0,0],e=r=null),h},h.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(h,n,\"on\")};var Ps={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},zs=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Os=Pe.format=sr.timeFormat,Ds=Os.utc,Rs=Ds(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Fs(t){return t.toISOString()}function Bs(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(js,i);return a==js.length?[r.year,ko(e.map((function(t){return t/31536e6})),n)[2]]:a?r[i/js[a-1]<js[a]/i?a-1:a]:[qs,ko(e,n)[2]]}return i.invert=function(t){return Ns(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(Ns)},i.nice=function(t,e){var r=i.domain(),n=go(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,Ns(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(yo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=Ns(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=Ns(+e+1);return e}}:t))},i.ticks=function(t,e){var r=go(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],Ns(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Bs(e.copy(),r,n)},wo(i,e)}function Ns(t){return new Date(t)}Os.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Fs:Rs,Fs.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Fs.toString=Rs.toString,Pe.second=Re((function(t){return new ze(1e3*Math.floor(t/1e3))}),(function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))}),(function(t){return t.getSeconds()})),Pe.seconds=Pe.second.range,Pe.seconds.utc=Pe.second.utc.range,Pe.minute=Re((function(t){return new ze(6e4*Math.floor(t/6e4))}),(function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))}),(function(t){return t.getMinutes()})),Pe.minutes=Pe.minute.range,Pe.minutes.utc=Pe.minute.utc.range,Pe.hour=Re((function(t){var e=t.getTimezoneOffset()/60;return new ze(36e5*(Math.floor(t/36e5-e)+e))}),(function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))}),(function(t){return t.getHours()})),Pe.hours=Pe.hour.range,Pe.hours.utc=Pe.hour.utc.range,Pe.month=Re((function(t){return(t=Pe.day(t)).setDate(1),t}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t){return t.getMonth()})),Pe.months=Pe.month.range,Pe.months.utc=Pe.month.utc.range;var js=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Us=[[Pe.second,1],[Pe.second,5],[Pe.second,15],[Pe.second,30],[Pe.minute,1],[Pe.minute,5],[Pe.minute,15],[Pe.minute,30],[Pe.hour,1],[Pe.hour,3],[Pe.hour,6],[Pe.hour,12],[Pe.day,1],[Pe.day,2],[Pe.week,1],[Pe.month,1],[Pe.month,3],[Pe.year,1]],Vs=Os.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),qs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(Ns)},floor:L,ceil:L};Us.year=Pe.year,Pe.scale=function(){return Bs(t.scale.linear(),Us,Vs)};var Hs=Us.map((function(t){return[t[0].utc,t[1]]})),Gs=Ds.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function Ys(t){return JSON.parse(t.responseText)}function Ws(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Hs.year=Pe.year.utc,Pe.scale.utc=function(){return Bs(t.scale.linear(),Hs,Gs)},t.text=ge((function(t){return t.responseText})),t.json=function(t,e){return me(t,\"application/json\",Ys,e)},t.html=function(t,e){return me(t,\"text/html\",Ws,e)},t.xml=ge((function(t){return t.responseXML})),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],170:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],171:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map((function(t,e){return[t[0],e]}));n.sort((function(t,e){return t[0]-e[0]}));for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var f=t[u],h=new Array(s+1),p=0,d=0;d<s;++d){var g=f[d];h[d]=g,p+=g*g}h[s]=p,l[u]=new a(h,u),c=Math.max(p,c)}i(l,o),r=l.length;var m=new Array(r+s+1),v=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1);for(u=0;u<=s;++u)x[u]=0;x[s]=y,m[0]=x.slice(),v[0]=-1;for(u=0;u<=s;++u){(h=x.slice())[u]=1,m[u+1]=h,v[u+1]=-1}for(u=0;u<r;++u){var b=l[u];m[u+s+1]=b.point,v[u+s+1]=b.index}var _=n(m,!1);_=e?_.filter((function(t){for(var e=0,r=0;r<=s;++r){var n=v[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0})):_.filter((function(t){for(var e=0;e<=s;++e){var r=v[t[e]];if(r<0)return!1;t[e]=r}return!0}));if(1&s)for(u=0;u<_.length;++u){h=(b=_[u])[0];b[0]=b[1],b[1]=h}return _}},{\"incremental-convex-hull\":459,uniq:597}],172:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],f=n.measureText(u[0]).width+n.measureText(u[1]).width,h=n.measureText(u).width;if(Math.abs(f-h)>s*l){var p=(h-f)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],173:[function(t,e,r){(function(t){(function(){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this)}).call(this,t(\"buffer\").Buffer)},{buffer:111}],174:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach((function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)})),t.closePath()}},{\"abs-svg-path\":65,\"normalize-svg-path\":497}],175:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],176:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],177:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,d,m=e&&e.length,v=m?e[0]*r:t.length,y=i(t,0,v,r,!0),x=[];if(!y||y.next===y.prev)return x;if(m&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(g(u));for(p.sort(f),o=0;o<p.length;o++)h(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<v;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);d=0!==(d=Math.max(l-n,c-s))?1/d:0}return o(y,x,r,n,s,d),x}function i(t,e,r,n,i){var a,o;if(i===E(t,e,r,n)>0)for(a=e;a<r;a+=n)o=M(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=M(a,t[a],t[a+1],o);return o&&x(o,o.next)&&(A(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!x(n,n.next)&&0!==y(n.prev,n,n.next))n=n.next;else{if(A(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,f,h){if(t){!h&&f&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=d(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,f);for(var p,g,m=t;t.prev!==t.next;)if(p=t.prev,g=t.next,f?l(t,n,i,f):s(t))e.push(p.i/r),e.push(t.i/r),e.push(g.i/r),A(t),t=g.next,m=g.next;else if((t=g)===m){h?1===h?o(t=c(a(t),e,r),e,r,n,i,f,2):2===h&&u(t,e,r,n,i,f):o(a(t),e,r,n,i,f,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(y(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(m(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&y(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(y(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,f=d(s,l,e,r,n),h=d(c,u,e,r,n),p=t.prevZ,g=t.nextZ;p&&p.z>=f&&g&&g.z<=h;){if(p!==t.prev&&p!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,g!==t.prev&&g!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}for(;p&&p.z>=f;){if(p!==t.prev&&p!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;g&&g.z<=h;){if(g!==t.prev&&g!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,o=n.next.next;!x(i,o)&&b(i,n,n.next,o)&&T(i,o)&&T(o,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(o.i/r),A(n),A(n.next),n=t=o),n=n.next}while(n!==t);return a(n)}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=k(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function f(t,e){return t.x-e.x}function h(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&m(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),T(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&p(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=k(e,t);a(e,e.next),a(r,r.next)}}function p(t,e){return y(t.prev,t,e.prev)<0&&y(e.next,t,t.next)<0}function d(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function g(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function m(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&b(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(T(t,e)&&T(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(y(t.prev,t,e.prev)||y(t,e.prev,e))||x(t,e)&&y(t.prev,t,t.next)>0&&y(e.prev,e,e.next)>0)}function y(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function x(t,e){return t.x===e.x&&t.y===e.y}function b(t,e,r,n){var i=w(y(t,e,r)),a=w(y(t,e,n)),o=w(y(r,n,t)),s=w(y(r,n,e));return i!==a&&o!==s||(!(0!==i||!_(t,r,e))||(!(0!==a||!_(t,n,e))||(!(0!==o||!_(r,t,n))||!(0!==s||!_(r,e,n)))))}function _(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function w(t){return t>0?1:t<0?-1:0}function T(t,e){return y(t.prev,t,t.next)<0?y(t,e,t.next)>=0&&y(t,t.prev,e)>=0:y(t,e,t.prev)<0||y(t,t.next,e)<0}function k(t,e){var r=new S(t.i,t.x,t.y),n=new S(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function M(t,e,r,n){var i=new S(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function A(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function S(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function E(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(E(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(E(t,c,u,r))}var f=0;for(s=0;s<n.length;s+=3){var h=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;f+=Math.abs((t[h]-t[d])*(t[p+1]-t[h+1])-(t[h]-t[p])*(t[d+1]-t[h+1]))}return 0===o&&0===f?0:Math.abs((f-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],178:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;var o=new Array(e);for(i=0;i<e;++i)o[i]=[];for(i=0;i<r;++i){a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],(function(t,e){return t-e}));return o};var n=t(\"uniq\")},{uniq:597}],179:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t,e){var r,i=[],a=[],o=[],s={},l=[];function c(t){var e,n,i=!1;for(a.push(t),o[t]=!0,e=0;e<l[t].length;e++)(n=l[t][e])===r?(u(r,a),i=!0):o[n]||(i=c(n));if(i)!function t(e){o[e]=!1,s.hasOwnProperty(e)&&Object.keys(s[e]).forEach((function(r){delete s[e][r],o[r]&&t(r)}))}(t);else for(e=0;e<l[t].length;e++){n=l[t][e];var f=s[n];f||(f={},s[n]=f),f[n]=!0}return a.pop(),i}function u(t,r){var n=[].concat(r).concat(t);e?e(c):i.push(n)}function f(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter((function(t){return t>=e}))}(e);for(var r,i=n(t).components.filter((function(t){return t.length>1})),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map((function(t,e){return-1===l.indexOf(e)?[]:t.filter((function(t){return-1!==l.indexOf(t)}))}))}}r=0;for(var h=t.length;r<h;){var p=f(r);if(r=p.leastVertex,l=p.adjList){for(var d=0;d<l.length;d++)for(var g=0;g<l[d].length;g++){var m=l[d][g];o[+m]=!1,s[m]={}}c(r),r+=1}else r=h}return e?void 0:i}},{\"strongly-connected-components\":569}],180:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":211}],181:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":182,\"./shim\":183}],182:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),f=Array.isArray,h=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,m,v,y,x,b,_,w,T=arguments[1],k=arguments[2];if(t=Object(l(t)),c(T)&&s(T),this&&this!==Array&&a(this))e=this;else{if(!T){if(i(t))return 1!==(v=t.length)?Array.apply(null,t):((m=new Array(1))[0]=t[0],m);if(f(t)){for(m=new Array(v=t.length),r=0;r<v;++r)m[r]=t[r];return m}}m=[]}if(!f(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(m=new e),b=x.next(),r=0;!b.done;)w=T?h.call(T,k,b.value,r):b.value,e?(p.value=w,d(m,r,p)):m[r]=w,b=x.next(),++r;v=r}else if(u(t)){for(v=t.length,e&&(m=new e),r=0,g=0;r<v;++r)w=t[r],r+1<v&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=T?h.call(T,k,w,g):w,e?(p.value=w,d(m,g,p)):m[g]=w,++g;v=g}if(void 0===v)for(v=o(t.length),e&&(m=new e(v)),r=0;r<v;++r)w=T?h.call(T,k,t[r],r):t[r],e?(p.value=w,d(m,r,p)):m[r]=w;return e&&(p.value=null,m.length=v),m}},{\"../../function/is-arguments\":184,\"../../function/is-function\":185,\"../../number/to-pos-integer\":191,\"../../object/is-value\":200,\"../../object/valid-callable\":209,\"../../object/valid-value\":211,\"../../string/is-string\":215,\"es6-symbol\":225}],184:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],185:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=RegExp.prototype.test.bind(/^[object [A-Za-z0-9]*Function]$/);e.exports=function(t){return\"function\"==typeof t&&i(n.call(t))}},{}],186:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],187:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":188,\"./shim\":189}],188:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],189:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],190:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":187}],191:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":190}],192:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,f=arguments[2],h=arguments[3];return r=Object(i(r)),n(c),u=s(r),h&&u.sort(\"function\"==typeof h?a.call(h,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,(function(t,n){return l.call(r,t)?o.call(c,f,r[t],t,r,n):e}))}}},{\"./valid-callable\":209,\"./valid-value\":211}],193:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":194,\"./shim\":195}],194:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],195:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)n(e=arguments[o]).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":201,\"../valid-value\":211}],196:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,(function(e){(o.ensure||e in t)&&(s[e]=t[e])})):i(s,t),s}},{\"../array/from\":181,\"./assign\":193,\"./valid-value\":211}],197:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach((function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}})),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":207,\"./set-prototype-of/shim\":208}],198:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":192}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":200}],200:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":186}],201:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":202,\"./shim\":203}],202:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],203:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":200}],204:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,(function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)})),r}},{\"./for-each\":198,\"./valid-callable\":209}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create,o=function(t,e){var r;for(r in t)e[r]=t[r]};e.exports=function(t){var e=a(null);return i.call(arguments,(function(t){n(t)&&o(Object(t),e)})),e}},{\"./is-value\":200}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],208:[function(t,e,r){\"use strict\";var n,i=t(\"../is-object\"),a=t(\"../valid-value\"),o=Object.prototype.isPrototypeOf,s=Object.defineProperty,l={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(a(t),null===e||i(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=function(t){var e,r;return t?(2===t.level?t.set?(r=t.set,e=function(t,e){return r.call(n(t,e),e),t}):e=function(t,e){return n(t,e).__proto__=e,t}:e=function t(e,r){var i;return n(e,r),(i=o.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&s(t.nullPolyfill,\"__proto__\",l),e},Object.defineProperty(e,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:t.level})):null}(function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}()),t(\"../create\")},{\"../create\":197,\"../is-object\":199,\"../valid-value\":211}],209:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],210:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":199}],211:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":200}],212:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":213,\"./shim\":214}],213:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],214:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],215:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],216:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],217:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o((function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t}))}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/string/#/contains\":212,\"es6-symbol\":225}],218:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,f,h,p,d,g,m,v=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),f=function(){h=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,v,u.value,f),h)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(m=g.charCodeAt(0))>=55296&&m<=56319&&(g+=t[++p]),l.call(e,v,g,f),!h);++p);else c.call(t,(function(t){return l.call(e,v,t,f),h}))}},{\"./get\":219,\"es5-ext/function/is-arguments\":184,\"es5-ext/object/valid-callable\":209,\"es5-ext/string/is-string\":215}],219:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":217,\"./string\":222,\"./valid-iterable\":223,\"es5-ext/function/is-arguments\":184,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],220:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),f=Object.defineProperty,h=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");h(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,h(n.prototype,a({_next:l((function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()})),next:l((function(){return this._createResult(this._next())})),_createResult:l((function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}})),_resolve:l((function(t){return this.__list__[t]})),_unBind:l((function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)})),toString:l((function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"}))},c({_onAdd:l((function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach((function(e,r){e>=t&&(this.__redo__[r]=++e)}),this),this.__redo__.push(t)):f(this,\"__redo__\",l(\"c\",[t])))})),_onDelete:l((function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach((function(e,r){e>t&&(this.__redo__[r]=--e)}),this)))})),_onClear:l((function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0}))}))),f(n.prototype,u.iterator,l((function(){return this})))},{d:155,\"d/auto-bind\":154,\"es5-ext/array/#/clear\":180,\"es5-ext/object/assign\":193,\"es5-ext/object/valid-callable\":209,\"es5-ext/object/valid-value\":211,\"es6-symbol\":225}],221:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":184,\"es5-ext/object/is-value\":200,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],222:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a((function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()})),_resolve:a((function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r}))}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es6-symbol\":225}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":221}],224:[function(t,e,r){(function(n,i){(function(){\n",
       "/*!\n",
       " * @overview es6-promise - a tiny implementation of Promises/A+.\n",
       " * @copyright Copyright (c) 2014 Yehuda Katz, Tom Dale, Stefan Penner and contributors (Conversion to ES6 API by Jake Archibald)\n",
       " * @license   Licensed under MIT license\n",
       " *            See https://raw.githubusercontent.com/stefanpenner/es6-promise/master/LICENSE\n",
       " * @version   v4.2.8+1e68dce6\n",
       " */\n",
       "!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,(function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(m):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},f=u.MutationObserver||u.WebKitMutationObserver,h=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(m,1)}}var g=new Array(1e3);function m(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var v,y,x,b,_=void 0;function w(t,e){var r=this,n=new this.constructor(M);void 0===n[k]&&D(n);var i=r._state;if(i){var a=arguments[i-1];l((function(){return z(i,n,a,r._result)}))}else I(r,n,t,e);return n}function T(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(M);return S(e,t),e}h?_=function(){return n.nextTick(m)}:f?(y=0,x=new f(m),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((v=new MessageChannel).port1.onmessage=m,_=function(){return v.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var t=Function(\"return this\")().require(\"vertx\");return\"undefined\"!=typeof(o=t.runOnLoop||t.runOnContext)?function(){o(m)}:d()}catch(t){return d()}}():d();var k=Math.random().toString(36).substring(2);function M(){}function A(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===T?function(t,e){1===e._state?C(t,e._result):2===e._state?L(t,e._result):I(e,void 0,(function(e){return S(t,e)}),(function(e){return L(t,e)}))}(t,r):void 0===n?C(t,r):e(n)?function(t,e,r){l((function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,(function(r){n||(n=!0,e!==r?S(t,r):C(t,r))}),(function(e){n||(n=!0,L(t,e))}),t._label);!n&&i&&(n=!0,L(t,i))}),t)}(t,r,n):C(t,r)}function S(t,e){if(t===e)L(t,new TypeError(\"You cannot resolve a promise with itself\"));else if(i=typeof(n=e),null===n||\"object\"!==i&&\"function\"!==i)C(t,e);else{var r=void 0;try{r=e.then}catch(e){return void L(t,e)}A(t,e,r)}var n,i}function E(t){t._onerror&&t._onerror(t._result),P(t)}function C(t,e){void 0===t._state&&(t._result=e,t._state=1,0!==t._subscribers.length&&l(P,t))}function L(t,e){void 0===t._state&&(t._state=2,t._result=e,l(E,t))}function I(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+1]=r,i[a+2]=n,0===a&&t._state&&l(P,t)}function P(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?z(r,n,i,a):i(a);t._subscribers.length=0}}function z(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=!0;if(a){try{o=n(i)}catch(t){l=!1,s=t}if(r===o)return void L(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i;void 0!==r._state||(a&&l?S(r,o):!1===l?L(r,s):1===t?C(r,o):2===t&&L(r,o))}var O=0;function D(t){t[k]=O++,t._state=void 0,t._result=void 0,t._subscribers=[]}var R=function(){function t(t,e){this._instanceConstructor=t,this.promise=new t(M),this.promise[k]||D(this.promise),r(e)?(this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?C(this.promise,this._result):(this.length=this.length||0,this._enumerate(e),0===this._remaining&&C(this.promise,this._result))):L(this.promise,new Error(\"Array Methods must be provided an Array\"))}return t.prototype._enumerate=function(t){for(var e=0;void 0===this._state&&e<t.length;e++)this._eachEntry(t[e],e)},t.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===T){var i=void 0,a=void 0,o=!1;try{i=t.then}catch(t){o=!0,a=t}if(i===w&&void 0!==t._state)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===F){var s=new r(M);o?L(s,a):A(s,t,i),this._willSettleAt(s,e)}else this._willSettleAt(new r((function(e){return e(t)})),e)}else this._willSettleAt(n(t),e)},t.prototype._settledAt=function(t,e,r){var n=this.promise;void 0===n._state&&(this._remaining--,2===t?L(n,r):this._result[e]=r),0===this._remaining&&C(n,this._result)},t.prototype._willSettleAt=function(t,e){var r=this;I(t,void 0,(function(t){return r._settledAt(1,e,t)}),(function(t){return r._settledAt(2,e,t)}))},t}();var F=function(){function t(e){this[k]=O++,this._result=this._state=void 0,this._subscribers=[],M!==e&&(\"function\"!=typeof e&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof t?function(t,e){try{e((function(e){S(t,e)}),(function(e){L(t,e)}))}catch(e){L(t,e)}}(this,e):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}return t.prototype.catch=function(t){return this.then(null,t)},t.prototype.finally=function(t){var r=this.constructor;return e(t)?this.then((function(e){return r.resolve(t()).then((function(){return e}))}),(function(e){return r.resolve(t()).then((function(){throw e}))})):this.then(t,t)},t}();return F.prototype.then=w,F.all=function(t){return new R(this,t).promise},F.race=function(t){var e=this;return r(t)?new e((function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)})):new e((function(t,e){return e(new TypeError(\"You must pass an array to race.\"))}))},F.resolve=T,F.reject=function(t){var e=new this(M);return L(e,t),e},F._setScheduler=function(t){s=t},F._setAsap=function(t){l=t},F._asap=l,F.polyfill=function(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=F},F.Promise=F,F}))}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:526}],225:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?t(\"ext/global-this\").Symbol:t(\"./polyfill\")},{\"./is-implemented\":226,\"./polyfill\":231,\"ext/global-this\":238}],226:[function(t,e,r){\"use strict\";var n=t(\"ext/global-this\"),i={object:!0,symbol:!0};e.exports=function(){var t,e=n.Symbol;if(\"function\"!=typeof e)return!1;t=e(\"test symbol\");try{String(t)}catch(t){return!1}return!!i[typeof e.iterator]&&(!!i[typeof e.toPrimitive]&&!!i[typeof e.toStringTag])}},{\"ext/global-this\":238}],227:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],228:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=Object.create,a=Object.defineProperty,o=Object.prototype,s=i(null);e.exports=function(t){for(var e,r,i=0;s[t+(i||\"\")];)++i;return s[t+=i||\"\"]=!0,a(o,e=\"@@\"+t,n.gs(null,(function(t){r||(r=!0,a(this,e,n(t)),r=!1)}))),e}},{d:155}],229:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"ext/global-this\").Symbol;e.exports=function(t){return Object.defineProperties(t,{hasInstance:n(\"\",i&&i.hasInstance||t(\"hasInstance\")),isConcatSpreadable:n(\"\",i&&i.isConcatSpreadable||t(\"isConcatSpreadable\")),iterator:n(\"\",i&&i.iterator||t(\"iterator\")),match:n(\"\",i&&i.match||t(\"match\")),replace:n(\"\",i&&i.replace||t(\"replace\")),search:n(\"\",i&&i.search||t(\"search\")),species:n(\"\",i&&i.species||t(\"species\")),split:n(\"\",i&&i.split||t(\"split\")),toPrimitive:n(\"\",i&&i.toPrimitive||t(\"toPrimitive\")),toStringTag:n(\"\",i&&i.toStringTag||t(\"toStringTag\")),unscopables:n(\"\",i&&i.unscopables||t(\"unscopables\"))})}},{d:155,\"ext/global-this\":238}],230:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"../../../validate-symbol\"),a=Object.create(null);e.exports=function(t){return Object.defineProperties(t,{for:n((function(e){return a[e]?a[e]:a[e]=t(String(e))})),keyFor:n((function(t){var e;for(e in i(t),a)if(a[e]===t)return e}))})}},{\"../../../validate-symbol\":232,d:155}],231:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"d\"),s=t(\"./validate-symbol\"),l=t(\"ext/global-this\").Symbol,c=t(\"./lib/private/generate-name\"),u=t(\"./lib/private/setup/standard-symbols\"),f=t(\"./lib/private/setup/symbol-registry\"),h=Object.create,p=Object.defineProperties,d=Object.defineProperty;if(\"function\"==typeof l)try{String(l()),a=!0}catch(t){}else l=null;i=function(t){if(this instanceof i)throw new TypeError(\"Symbol is not a constructor\");return n(t)},e.exports=n=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return a?l(e):(r=h(i.prototype),e=void 0===e?\"\":String(e),p(r,{__description__:o(\"\",e),__name__:o(\"\",c(e))}))},u(n),f(n),p(i.prototype,{constructor:o(n),toString:o(\"\",(function(){return this.__name__}))}),p(n.prototype,{toString:o((function(){return\"Symbol (\"+s(this).__description__+\")\"})),valueOf:o((function(){return s(this)}))}),d(n.prototype,n.toPrimitive,o(\"\",(function(){var t=s(this);return\"symbol\"==typeof t?t:t.toString()}))),d(n.prototype,n.toStringTag,o(\"c\",\"Symbol\")),d(i.prototype,n.toStringTag,o(\"c\",n.prototype[n.toStringTag])),d(i.prototype,n.toPrimitive,o(\"c\",n.prototype[n.toPrimitive]))},{\"./lib/private/generate-name\":228,\"./lib/private/setup/standard-symbols\":229,\"./lib/private/setup/symbol-registry\":230,\"./validate-symbol\":232,d:155,\"ext/global-this\":238}],232:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":227}],233:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":234,\"./polyfill\":236}],234:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],235:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],236:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),f=t(\"es6-iterator/for-of\"),h=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,m=Object.prototype.hasOwnProperty,v=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,v(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(f(e,(function(e){s(e),t.set(e[0],e[1])})),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c((function(t){return!!m.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)})),get:c((function(t){if(m.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]})),has:c((function(t){return m.call(o(t),this.__weakMapData__)})),set:c((function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this})),toString:c((function(){return\"[object WeakMap]\"}))}),g(n.prototype,h,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":235,d:155,\"es5-ext/object/is-value\":200,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/object/valid-object\":210,\"es5-ext/object/valid-value\":211,\"es5-ext/string/random-uniq\":216,\"es6-iterator/for-of\":218,\"es6-iterator/get\":219,\"es6-symbol\":225}],237:[function(t,e,r){var n=function(){if(\"object\"==typeof self&&self)return self;if(\"object\"==typeof window&&window)return window;throw new Error(\"Unable to resolve global `this`\")};e.exports=function(){if(this)return this;try{Object.defineProperty(Object.prototype,\"__global__\",{get:function(){return this},configurable:!0})}catch(t){return n()}try{return __global__||n()}finally{delete Object.prototype.__global__}}()},{}],238:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?globalThis:t(\"./implementation\")},{\"./implementation\":237,\"./is-implemented\":239}],239:[function(t,e,r){\"use strict\";e.exports=function(){return\"object\"==typeof globalThis&&(!!globalThis&&globalThis.Array===Array)}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],241:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":470}],242:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:return\"number\"==typeof t?new o(n=l(t),n,0):new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,f=this.bounds;if(o<0)for(var h=u-1,p=0;p<u;++p,--h)s[p]=l[h];else if(o>=r-1){h=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--h)s[p]=l[h]+d*c[h]}else{h=u*(o+1)-1;var g=e[o],m=e[o+1]-g||1,v=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--h)v[p]=l[h],x[p]=c[h]*m,y[p]=l[h+u],b[p]=c[h+u]*m,_=_&&v[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=v[p];else n(v,x,y,b,(t-g)/m,s)}var w=f[0],T=f[1];for(p=0;p<u;++p)s[p]=a(w[p],T[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,f=(e[r-1],0);f<c;++f,--u)o[f]=l[u];else{u=c*(a+1)-1;var h=e[a],p=e[a+1]-h||1,d=this._scratch[1],g=this._scratch[2],m=this._scratch[3],v=this._scratch[4],y=!0;for(f=0;f<c;++f,--u)d[f]=s[u],m[f]=l[u]*p,g[f]=s[u+c],v[f]=l[u+c]*p,y=y&&d[f]===g[f]&&m[f]===v[f]&&0===m[f];if(y)for(f=0;f<c;++f)o[f]=0;else{n.derivative(d,m,g,v,(t-h)/p,o);for(f=0;f<c;++f)o[f]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var f=0;f<r;++f)n.push(n[o++]),i.push(0);this._time.push(t);for(f=r;f>0;--f)n.push(a(l[f-1],c[f-1],arguments[f])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],f=s>1e-6?1/s:0;this._time.push(t);for(var h=r;h>0;--h){var p=a(c[h-1],u[h-1],arguments[h]);n.push(p),i.push((p-n[o++])*f)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,f=u>1e-6?1/u:0;this._time.push(t);for(var h=r;h>0;--h){var p=arguments[h];n.push(a(l[h-1],c[h-1],n[o++]+p)),i.push(p*f)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var f=r-1;f>=0;--f)n.push(a(l[f],c[f],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":243,\"cubic-hermite\":150}],243:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],244:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var f=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new f(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new f(t):(e=new f(t.length+r)).set(t,r)}return e}},{dtype:175}],245:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var f=r.getContext(\"2d\");f.fillStyle=\"#000\",f.fillRect(0,0,r.width,r.height),f.font=a,f.textAlign=\"center\",f.textBaseline=\"middle\",f.fillStyle=\"#fff\";var h=o[0]/2,p=o[1]/2;for(c=0;c<s.length;c++)f.fillText(s[c],h,p),(h+=o[0])>e[0]-o[0]/2&&(h=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":147}],246:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,f=u.getContext(\"2d\"),h={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,f.font=t;var d={top:0};f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillStyle=\"black\",f.fillText(\"H\",0,0);var g=a(f.getImageData(0,0,p,p));f.clearRect(0,0,p,p),f.textBaseline=\"bottom\",f.fillText(\"H\",0,p);var m=a(f.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-m+g,f.clearRect(0,0,p,p),f.textBaseline=\"alphabetic\",f.fillText(\"H\",0,p);var v=p-a(f.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=v,f.clearRect(0,0,p,p),f.textBaseline=\"middle\",f.fillText(\"H\",0,.5*p);var y=a(f.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"hanging\",f.fillText(\"H\",0,.5*p);var x=a(f.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"ideographic\",f.fillText(\"H\",0,p);var b=a(f.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,h.upper&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.upper,0,0),d.upper=a(f.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),h.lower&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.lower,0,0),d.lower=a(f.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),h.tittle&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.tittle,0,0),d.tittle=a(f.getImageData(0,0,p,p))),h.ascent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.ascent,0,0),d.ascent=a(f.getImageData(0,0,p,p))),h.descent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.descent,0,0),d.descent=o(f.getImageData(0,0,p,p))),h.overshoot){f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.overshoot,0,0);var _=o(f.getImageData(0,0,p,p));d.overshoot=_-v}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],247:[function(t,e,r){\"use strict\";e.exports=function(t){return new s(t||g,null)};function n(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function i(t){return new n(t._color,t.key,t.value,t.left,t.right,t._count)}function a(t,e){return new n(t,e.key,e.value,e.left,e.right,e._count)}function o(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function s(t,e){this._compare=t,this.root=e}var l=s.prototype;function c(t,e){var r;if(e.left&&(r=c(t,e.left)))return r;return(r=t(e.key,e.value))||(e.right?c(t,e.right):void 0)}function u(t,e,r,n){if(e(t,n.key)<=0){var i;if(n.left)if(i=u(t,e,r,n.left))return i;if(i=r(n.key,n.value))return i}if(n.right)return u(t,e,r,n.right)}function f(t,e,r,n,i){var a,o=r(t,i.key),s=r(e,i.key);if(o<=0){if(i.left&&(a=f(t,e,r,n,i.left)))return a;if(s>0&&(a=n(i.key,i.value)))return a}if(s>0&&i.right)return f(t,e,r,n,i.right)}function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(l,\"keys\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(e)})),t}}),Object.defineProperty(l,\"values\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(r)})),t}}),Object.defineProperty(l,\"length\",{get:function(){return this.root?this.root._count:0}}),l.insert=function(t,e){for(var r=this._compare,i=this.root,l=[],c=[];i;){var u=r(t,i.key);l.push(i),c.push(u),i=u<=0?i.left:i.right}l.push(new n(0,t,e,null,null,1));for(var f=l.length-2;f>=0;--f){i=l[f];c[f]<=0?l[f]=new n(i._color,i.key,i.value,l[f+1],i.right,i._count+1):l[f]=new n(i._color,i.key,i.value,i.left,l[f+1],i._count+1)}for(f=l.length-1;f>1;--f){var h=l[f-1];i=l[f];if(1===h._color||1===i._color)break;var p=l[f-2];if(p.left===h)if(h.left===i){if(!(d=p.right)||0!==d._color){if(p._color=0,p.left=h.right,h._color=1,h.right=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(g=l[f-3]).left===p?g.left=h:g.right=h;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else{if(!(d=p.right)||0!==d._color){if(h.right=i.left,p._color=0,p.left=i.right,i._color=1,i.left=h,i.right=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(g=l[f-3]).left===p?g.left=i:g.right=i;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else if(h.right===i){if(!(d=p.left)||0!==d._color){if(p._color=0,p.right=h.left,h._color=1,h.left=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(g=l[f-3]).right===p?g.right=h:g.left=h;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}else{var d;if(!(d=p.left)||0!==d._color){var g;if(h.left=i.right,p._color=0,p.right=i.left,i._color=1,i.right=h,i.left=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(g=l[f-3]).right===p?g.right=i:g.left=i;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}}return l[0]._color=1,new s(r,l[0])},l.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return c(t,this.root);case 2:return u(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return f(e,r,this._compare,t,this.root)}},Object.defineProperty(l,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(l,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),l.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},l.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},l.remove=function(t){var e=this.find(t);return e?e.remove():this},l.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var p=h.prototype;function d(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function g(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(p,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(p,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),p.clone=function(){return new h(this.tree,this._stack.slice())},p.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new n(r._color,r.key,r.value,r.left,r.right,r._count);for(var l=t.length-2;l>=0;--l){(r=t[l]).left===t[l+1]?e[l]=new n(r._color,r.key,r.value,e[l+1],r.right,r._count):e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count)}if((r=e[e.length-1]).left&&r.right){var c=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var u=e[c-1];e.push(new n(r._color,u.key,u.value,r.left,r.right,r._count)),e[c-1].key=r.key,e[c-1].value=r.value;for(l=e.length-2;l>=c;--l)r=e[l],e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count);e[c-1].left=e[c]}if(0===(r=e[e.length-1])._color){var f=e[e.length-2];f.left===r?f.left=null:f.right===r&&(f.right=null),e.pop();for(l=0;l<e.length;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(r.left||r.right){r.left?d(r,r.left):r.right&&d(r,r.right),r._color=1;for(l=0;l<e.length-1;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(1===e.length)return new s(this.tree._compare,null);for(l=0;l<e.length;++l)e[l]._count--;var h=e[e.length-2];return function(t){for(var e,r,n,s,l=t.length-1;l>=0;--l){if(e=t[l],0===l)return void(e._color=1);if((r=t[l-1]).left===e){if((n=r.right).right&&0===n.right._color){if(s=(n=r.right=i(n)).right=i(n.right),r.right=n.left,n.left=r,n.right=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).left===r?c.left=n:c.right=n;return void(t[l-1]=n)}if(n.left&&0===n.left._color){if(s=(n=r.right=i(n)).left=i(n.left),r.right=s.left,n.left=s.right,s.left=r,s.right=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).left===r?c.left=s:c.right=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.right=a(0,n));r.right=a(0,n);continue}n=i(n),r.right=n.left,n.left=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).left===r?c.left=n:c.right=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}else{if((n=r.left).left&&0===n.left._color){if(s=(n=r.left=i(n)).left=i(n.left),r.left=n.right,n.right=r,n.left=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).right===r?c.right=n:c.left=n;return void(t[l-1]=n)}if(n.right&&0===n.right._color){if(s=(n=r.left=i(n)).right=i(n.right),r.left=s.right,n.right=s.left,s.right=r,s.left=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).right===r?c.right=s:c.left=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.left=a(0,n));r.left=a(0,n);continue}var c;n=i(n),r.left=n.right,n.right=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).right===r?c.right=n:c.left=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}}}(e),h.left===r?h.left=null:h.right=null,new s(this.tree._compare,e[0])},Object.defineProperty(p,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(p,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(p,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),p.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),p.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),i=e[e.length-1];r[r.length-1]=new n(i._color,i.key,t,i.left,i.right,i._count);for(var a=e.length-2;a>=0;--a)(i=e[a]).left===e[a+1]?r[a]=new n(i._color,i.key,i.value,r[a+1],i.right,i._count):r[a]=new n(i._color,i.key,i.value,i.left,r[a+1],i._count);return new s(this.tree._compare,r[0])},p.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],248:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function a(t){if(t<0)return Number(\"0/0\");for(var e=i[0],r=i.length-1;r>0;--r)e+=i[r]/(t+r);var n=t+607/128+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(a(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var o=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(o,e+.5)*Math.exp(-o)*r},e.exports.log=a},{}],249:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],250:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var f=u.prototype;function h(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}f.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,(function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]})),u=!1,f=!1;if(\"bounds\"in t)for(var h=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)h[p][d]!==this.bounds[p][d]&&(f=!0),this.bounds[p][d]=h[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,f=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),f=!0,u=!0,this._firstInit=!1),f&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort((function(t,e){return t.x-e.x}));s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new h,new h,new h];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var f=a,h=s,p=o,d=l;c&1<<u&&(f=s,h=a,p=l,d=o),f[u]=r[0][u],h[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],m={model:l,view:l,projection:l,_ortho:!1};f.isOpaque=function(){return!0},f.isTransparent=function(){return!1},f.drawTransparent=function(t){};var v=[0,0,0],y=[0,0,0],x=[0,0,0];f.draw=function(t){t=t||m;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),f=u.cubeEdges,h=u.axis,b=n[12],_=n[13],w=n[14],T=n[15],k=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*T)/e.drawingBufferHeight,M=0;M<3;++M)this.lastCubeProps.cubeEdges[M]=f[M],this.lastCubeProps.axis[M]=h[M];var A=p;for(M=0;M<3;++M)d(p[M],M,this.bounds,f,h);e=this.gl;var S,E=g;for(M=0;M<3;++M)this.backgroundEnable[M]?E[M]=h[M]:E[M]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(M=0;M<3;++M){var C=[0,0,0];h[M]>0?C[M]=a[1][M]:C[M]=a[0][M];for(var L=0;L<2;++L){var I=(M+1+L)%3,P=(M+1+(1^L))%3;this.gridEnable[I]&&this._lines.drawGrid(I,P,this.bounds,C,this.gridColor[I],this.gridWidth[I]*this.pixelRatio)}for(L=0;L<2;++L){I=(M+1+L)%3,P=(M+1+(1^L))%3;this.zeroEnable[P]&&Math.min(a[0][P],a[1][P])<=0&&Math.max(a[0][P],a[1][P])>=0&&this._lines.drawZero(I,P,this.bounds,C,this.zeroLineColor[P],this.zeroLineWidth[P]*this.pixelRatio)}}for(M=0;M<3;++M){this.lineEnable[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].primalOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio),this.lineMirror[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].mirrorOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio);var z=c(v,A[M].primalMinor),O=c(y,A[M].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=k/r[5*L];z[L]*=D[L]*R,O[L]*=D[L]*R}this.lineTickEnable[M]&&this._lines.drawAxisTicks(M,A[M].primalOffset,z,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio),this.lineTickMirror[M]&&this._lines.drawAxisTicks(M,A[M].mirrorOffset,O,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0||a>0&&l<0||a<0&&l>0||a<0&&l<0?N(n):(o>0&&s>0||o>0&&s<0||o<0&&s>0||o<0&&s<0)&&N(i)}for(M=0;M<3;++M){var U=A[M].primalMinor,V=A[M].mirrorMinor,q=c(x,A[M].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[M]&&(q[L]+=k*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[M]=1,this.tickEnable[M]){-3600===this.tickAngle[M]?(this.tickAngle[M]=0,this.tickAlign[M]=\"auto\"):this.tickAlign[M]=-1,F=1,\"auto\"===(S=[this.tickAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(M,U,V);for(L=0;L<3;++L)q[L]+=k*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(M,this.tickSize[M],this.tickAngle[M],q,this.tickColor[M],H,B,S)}if(this.labelEnable[M]){F=0,B=[0,0,0],this.labels[M].length>4&&(N(M),F=1),\"auto\"===(S=[this.labelAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=k*U[L]*this.labelPad[L]/r[5*L];q[M]+=.5*(a[0][M]+a[1][M]),this._text.drawLabel(M,this.labelSize[M],this.labelAngle[M],q,this.labelColor[M],[0,0,0],B,S)}}this._text.unbind()},f.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":251,\"./lib/cube.js\":252,\"./lib/lines.js\":253,\"./lib/text.js\":255,\"./lib/ticks.js\":256}],251:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,f=[0,0,0],h=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),f[l]=p,h[l]=p;for(var d=-1;d<=1;d+=2){f[c]=d;for(var g=-1;g<=1;g+=2)f[u]=g,e.push(f[0],f[1],f[2],h[0],h[1],h[2]),s+=1}var m=c;c=u,u=m}var v=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:v,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:v,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,v,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":259,\"gl-vao\":358}],252:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],h(l[y],u,s),y+=1}}var w=-1;for(x=0;x<8;++x){for(var T=l[x][3],k=0;k<3;++k)c[x][k]=l[x][k]/T;p&&(c[x][2]*=-1),T<0&&(w<0||c[x][2]<c[w][2])&&(w=x)}if(w<0){w=0;for(var M=0;M<3;++M){for(var A=(M+2)%3,S=(M+1)%3,E=-1,C=-1,L=0;L<2;++L){var I=(z=L<<M)+(L<<A)+(1-L<<S),P=z+(1-L<<A)+(L<<S);o(c[z],c[I],c[P],f)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<M);else{for(L=0;L<2;++L){I=(z=L<<M)+(L<<A)+(1-L<<S),P=z+(1-L<<A)+(L<<S);var z,O=d([l[z],l[I],l[P],l[z+(1<<A)+(1<<S)]]);L?E=O:C=O}C>E&&(w|=1<<M)}}}var D=7^w,R=-1;for(x=0;x<8;++x)x!==w&&x!==D&&(R<0||c[R][1]>c[x][1])&&(R=x);var F=-1;for(x=0;x<3;++x){if((N=R^1<<x)!==w&&N!==D)F<0&&(F=N),(S=c[N])[0]<c[F][0]&&(F=N)}var B=-1;for(x=0;x<3;++x){var N;if((N=R^1<<x)!==w&&N!==D&&N!==F)B<0&&(B=N),(S=c[N])[0]>c[B][0]&&(B=N)}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^B)]=R&B;var U=7^B;U===w||U===D?(U=7^F,j[n.log2(B^U)]=U&B):j[n.log2(F^U)]=U&F;var V=m,q=w;for(M=0;M<3;++M)V[M]=q&1<<M?-1:1;return v};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),f=[0,0,0];function h(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,f=l[0]/l[3]-n,h=l[1]/l[3]-i;o+=Math.abs(c*h-u*f)}return o}var g=[1,1,1],m=[0,0,0],v={cubeEdges:g,axis:m}},{\"bit-twiddle\":97,\"gl-mat4/multiply\":295,\"robust-orientation\":548,\"split-polygon\":566}],253:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var f=0;f<3;++f){for(var h=o.length/3|0,d=0;d<r[f].length;++d){var g=+r[f][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var m=o.length/3|0;s[f]=h,l[f]=m-h;h=o.length/3|0;for(var v=0;v<r[f].length;++v){g=+r[f][v].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}m=o.length/3|0;c[f]=h,u[f]=m-h}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function f(t){return t[0]=t[1]=t[2]=0,t}function h(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=f(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=h(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=f(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=f(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=f(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=f(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=f(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=h(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=f(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=f(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=f(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=h(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=f(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":259,\"gl-vao\":358}],254:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:257}],255:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),f=i(t,[{buffer:u,size:3}]),h=o(t);h.attributes.position.location=0;var p=new c(t,h,u,f);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,f=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,f[0]=this.gl.drawingBufferWidth,f[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=f},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var f=(n||12)/12,h=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var m=p[d],v=2;v>=0;--v){var y=h[m[v]];o.push(f*y[0],-f*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],f=[0,0,0],h=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){f[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),h[d]=(o.length/3|0)-f[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=f,this.labelCount=h},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this)}).call(this,t(\"_process\"))},{\"./shaders\":254,_process:526,\"gl-buffer\":259,\"gl-vao\":358,\"vectorize-text\":600}],256:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var f=\"\"+c;f.length<i;)f=\"0\"+f;return u+\".\"+f}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],257:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],258:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,f){var h=e.model||c,p=e.view||c,v=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(f=f||a(h,p,v,x,y)).axis;o(u,p,h),o(u,v,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var T=n(s(u,u));s(u,u);for(var k=0;k<3;++k){var M=(k+1)%3,A=(k+2)%3,S=m;t:for(w=0;w<2;++w){var E=[];if(b[k]<0!=!!w){S[k]=x[w][k];for(var C=0;C<2;++C){S[M]=x[C^w][M];for(var L=0;L<2;++L)S[A]=x[L^C^w][A],E.push(S.slice())}var I=y?5:4;for(C=I;C===I;++C){if(0===E.length)continue t;E=i.positive(E,T[C])}for(C=0;C<E.length;++C){A=E[C];var P=d(m,u,A,r,l);for(L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,A[L]),_[L].hi=Math.max(_[L].hi,A[L]),L!==k&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(P[L])))}}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function f(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var h=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=h,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,f=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+f*f)}return t}var g=[new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0)],m=[0,0,0]},{\"./lib/cube.js\":252,\"extract-frustum-planes\":240,\"gl-mat4/multiply\":295,\"gl-mat4/transpose\":306,\"gl-vec4/transformMat4\":429,\"split-polygon\":566}],259:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var f;f=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?f:f.subarray(0,t.length),e),n.free(f)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:495,\"ndarray-ops\":490,\"typedarray-pool\":595}],260:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\");e.exports=function(t,e){var r=t.positions,i=t.vectors,a={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),a;for(var o=0,s=1/0,l=-1/0,c=1/0,u=-1/0,f=1/0,h=-1/0,p=null,d=null,g=[],m=1/0,v=!1,y=0;y<r.length;y++){var x=r[y];s=Math.min(x[0],s),l=Math.max(x[0],l),c=Math.min(x[1],c),u=Math.max(x[1],u),f=Math.min(x[2],f),h=Math.max(x[2],h);var b=i[y];if(n.length(b)>o&&(o=n.length(b)),y){var _=2*n.distance(p,x)/(n.length(d)+n.length(b));_?(m=Math.min(m,_),v=!1):v=!0}v||(p=x,d=b),g.push(b)}var w=[s,c,f],T=[l,u,h];e&&(e[0]=w,e[1]=T),0===o&&(o=1);var k=1/o;isFinite(m)||(m=1),a.vectorScale=m;var M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*k),a.coneScale=M;y=0;for(var A=0;y<r.length;y++)for(var S=(x=r[y])[0],E=x[1],C=x[2],L=g[y],I=n.length(L)*k,P=0;P<8;P++){a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vertexIntensity.push(I,I,I),a.vertexIntensity.push(I,I,I);var z=a.positions.length;a.cells.push([z-6,z-5,z-4],[z-3,z-2,z-1])}return a};var i=t(\"./lib/shaders\");e.exports.createMesh=t(\"./create_mesh\"),e.exports.createConeMesh=function(t,r){return e.exports.createMesh(t,r,{shaders:i,traceType:\"cone\"})}},{\"./create_mesh\":261,\"./lib/shaders\":262,\"gl-vec3\":377}],261:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"gl-mat4/multiply\"),l=t(\"gl-mat4/invert\"),c=t(\"ndarray\"),u=t(\"colormap\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e,r,n,i,a,o,s,l,c,u){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=c,this.triangleCount=0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.traceType=u,this.tubeScale=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=f,this._view=f,this._projection=f,this._resolution=[1,1]}var p=h.prototype;function d(t,e){var r=n(t,e.meshShader.vertex,e.meshShader.fragment,null,e.meshShader.attributes);return r.attributes.position.location=0,r.attributes.color.location=2,r.attributes.uv.location=3,r.attributes.vector.location=4,r}function g(t,e){var r=n(t,e.pickShader.vertex,e.pickShader.fragment,null,e.pickShader.attributes);return r.attributes.position.location=0,r.attributes.id.location=1,r.attributes.vector.location=4,r}p.isOpaque=function(){return this.opacity>=1},p.isTransparent=function(){return this.opacity<1},p.pickSlots=1,p.setPickBase=function(t){this.pickId=t},p.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=u({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return c(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],o=[],s=[],l=[],f=[];this.cells=r,this.positions=n,this.vectors=i;var h=t.meshColor||[1,1,1,1],p=t.vertexIntensity,d=1/0,g=-1/0;if(p)if(t.vertexIntensityBounds)d=+t.vertexIntensityBounds[0],g=+t.vertexIntensityBounds[1];else for(var m=0;m<p.length;++m){var v=p[m];d=Math.min(d,v),g=Math.max(g,v)}else for(m=0;m<n.length;++m){v=n[m][2];d=Math.min(d,v),g=Math.max(g,v)}this.intensity=p||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(m=0;m<n.length;++m)for(var y=n[m],x=0;x<3;++x)!isNaN(y[x])&&isFinite(y[x])&&(this.bounds[0][x]=Math.min(this.bounds[0][x],y[x]),this.bounds[1][x]=Math.max(this.bounds[1][x],y[x]));var b=0;t:for(m=0;m<r.length;++m){var _=r[m];switch(_.length){case 3:for(x=0;x<3;++x){y=n[T=_[x]];for(var w=0;w<3;++w)if(isNaN(y[w])||!isFinite(y[w]))continue t}for(x=0;x<3;++x){var T;y=n[T=_[2-x]];a.push(y[0],y[1],y[2],y[3]);var k=i[T];o.push(k[0],k[1],k[2],k[3]||0);var M,A=h;3===A.length?s.push(A[0],A[1],A[2],1):s.push(A[0],A[1],A[2],A[3]),M=p?[(p[T]-d)/(g-d),0]:[(y[2]-d)/(g-d),0],l.push(M[0],M[1]),f.push(m)}b+=1}}this.triangleCount=b,this.trianglePositions.update(a),this.triangleVectors.update(o),this.triangleColors.update(s),this.triangleUVs.update(l),this.triangleIds.update(new Uint32Array(f))}},p.drawTransparent=p.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var c={model:r,view:n,projection:i,inverseModel:f.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,texture:0};c.inverseModel=l(c.inverseModel,c.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);s(u,c.view,c.model),s(u,c.projection,u),l(u,u);for(o=0;o<3;++o)c.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];c.lightPosition[o]=p/h}if(this.triangleCount>0){var g=this.triShader;g.bind(),g.uniforms=c,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},p.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind())},p.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3),i={position:n,dataCoordinate:n,index:Math.floor(r[1]/48)};return\"cone\"===this.traceType?i.index=Math.floor(r[1]/48):\"streamtube\"===this.traceType&&(i.intensity=this.intensity[r[1]],i.velocity=this.vectors[r[1]].slice(0,3),i.divergence=this.vectors[r[1]][3],i.index=e),i},p.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleIds.dispose()},e.exports=function(t,e,r){var n=r.shaders;1===arguments.length&&(t=(e=t).gl);var s=d(t,n),l=g(t,n),u=o(t,c(new Uint8Array([255,255,255,255]),[1,1,4]));u.generateMipmap(),u.minFilter=t.LINEAR_MIPMAP_LINEAR,u.magFilter=t.LINEAR;var f=i(t),p=i(t),m=i(t),v=i(t),y=i(t),x=a(t,[{buffer:f,type:t.FLOAT,size:4},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:m,type:t.FLOAT,size:4},{buffer:v,type:t.FLOAT,size:2},{buffer:p,type:t.FLOAT,size:4}]),b=new h(t,u,s,l,f,p,y,m,v,x,r.traceType||\"cone\");return b.update(e),b}},{colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-shader\":335,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495}],262:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, coneScale, coneOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float vectorScale, coneScale, coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector.xyz), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:263}],263:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],264:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34e3:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],265:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":264}],266:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var f=0;f<3;++f)e.lineWidth(this.lineWidth[f]*this.pixelRatio),r.capSize=this.capSize[f]*u,this.lineCount[f]&&e.drawArrays(e.LINES,this.lineOffset[f],this.lineCount[f]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function f(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],h=0;h<3;++h)if(isNaN(u[h])||!isFinite(u[h]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":268,\"gl-buffer\":259,\"gl-vao\":358}],267:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],268:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:267}],269:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var f=1;if(\"color\"in(n=n||{})){if((f=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(f>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(f>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+f+\" draw buffers\")}}var h=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&f>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");h=t.FLOAT}else n.preferFloat&&f>0&&p&&(h=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var m=!1;\"stencil\"in n&&(m=!!n.stencil);return new d(t,e,r,h,f,g,m,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function f(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function h(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,m=[0|e,0|r];Object.defineProperties(m,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=m,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,m=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var v=0;v<o;++v)t.color[v]=h(r,i,a,m,r.RGBA,r.COLOR_ATTACHMENT0+v);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=h(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=h(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null);for(v=0;v<t.color.length;++v)t.color[v].dispose(),t.color[v]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),f(x)}u(r,e)}(this)}var g=d.prototype;function m(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),f(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return m(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return m(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,m(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":353}],270:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),f=t.split(\"\\n\"),h={},p=0;p<f.length;p++){var d=f[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));h[g]=d}}var m=o(e).split(\"\\n\");for(p=0;p<m.length;p++)if(h[p+3]||h[p+2]||h[p+1]){var v=m[p];if(c+=v+\"\\n\",h[p+1]){var y=h[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":66,\"gl-constants/lookup\":265,\"glsl-shader-name\":431,\"sprintf-js\":567}],271:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),f=s(r),h=s(r),p=new c(t,n,i,a,u,f,h);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,f=c.prototype,h=[0,0,1,0,0,1,1,0,1,1,0,1];f.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var f=e.uniforms;f.viewTransform=u,f.shape=this.shape;var h=e.attributes;this.positionBuffer.bind(),h.position.pointer(),this.weightBuffer.bind(),h.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),h.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),f.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],f=l[2]-l[0],h=l[3]-l[1];t[0]=2*c/f,t[4]=2*u/h,t[6]=2*(a[0]-l[0])/f-1,t[7]=2*(a[1]-l[1])/h-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),f.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},f.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]),l=!1!==t.zsmooth;this.xData=r,this.yData=o;var c,u,f,p,d=t.colorLevels||[0],g=t.colorValues||[0,0,0,1],m=d.length,v=this.bounds;l?(c=v[0]=r[0],u=v[1]=o[0],f=v[2]=r[r.length-1],p=v[3]=o[o.length-1]):(c=v[0]=r[0]+(r[1]-r[0])/2,u=v[1]=o[0]+(o[1]-o[0])/2,f=v[2]=r[r.length-1]+(r[r.length-1]-r[r.length-2])/2,p=v[3]=o[o.length-1]+(o[o.length-1]-o[o.length-2])/2);var y=1/(f-c),x=1/(p-u),b=e[0],_=e[1];this.shape=[b,_];var w=(l?(b-1)*(_-1):b*_)*(h.length>>>1);this.numVertices=w;for(var T=a.mallocUint8(4*w),k=a.mallocFloat32(2*w),M=a.mallocUint8(2*w),A=a.mallocUint32(w),S=0,E=l?b-1:b,C=l?_-1:_,L=0;L<C;++L){var I,P;l?(I=x*(o[L]-u),P=x*(o[L+1]-u)):(I=L<_-1?x*(o[L]-(o[L+1]-o[L])/2-u):x*(o[L]-(o[L]-o[L-1])/2-u),P=L<_-1?x*(o[L]+(o[L+1]-o[L])/2-u):x*(o[L]+(o[L]-o[L-1])/2-u));for(var z=0;z<E;++z){var O,D;l?(O=y*(r[z]-c),D=y*(r[z+1]-c)):(O=z<b-1?y*(r[z]-(r[z+1]-r[z])/2-c):y*(r[z]-(r[z]-r[z-1])/2-c),D=z<b-1?y*(r[z]+(r[z+1]-r[z])/2-c):y*(r[z]+(r[z]-r[z-1])/2-c));for(var R=0;R<h.length;R+=2){var F,B,N,j,U=h[R],V=h[R+1],q=s[l?(L+V)*b+(z+U):L*b+z],H=n.le(d,q);if(H<0)F=g[0],B=g[1],N=g[2],j=g[3];else if(H===m-1)F=g[4*m-4],B=g[4*m-3],N=g[4*m-2],j=g[4*m-1];else{var G=(q-d[H])/(d[H+1]-d[H]),Y=1-G,W=4*H,X=4*(H+1);F=Y*g[W]+G*g[X],B=Y*g[W+1]+G*g[X+1],N=Y*g[W+2]+G*g[X+2],j=Y*g[W+3]+G*g[X+3]}T[4*S]=255*F,T[4*S+1]=255*B,T[4*S+2]=255*N,T[4*S+3]=255*j,k[2*S]=.5*O+.5*D,k[2*S+1]=.5*I+.5*P,M[2*S]=U,M[2*S+1]=V,A[S]=L*b+z,S+=1}}}this.positionBuffer.update(k),this.weightBuffer.update(M),this.colorBuffer.update(T),this.idBuffer.update(A),a.free(k),a.free(T),a.free(M),a.free(A)},f.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":272,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335,\"iota-array\":463,\"typedarray-pool\":595}],272:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:273}],273:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],274:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\n// https://github.com/mikolalysenko/glsl-read-float/blob/master/index.glsl\\nvec4 packFloat(float v) {\\n  float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  float e = floor(log2(av));\\n  float m = av * pow(2.0, -e) - 1.0;\\n\\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n\\n  //Unpack exponent\\n  float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0;\\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, packFloat(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":335,glslify:276}],275:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=f(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),l=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),u=c(new Array(1024),[256,1,4]),p=0;p<1024;++p)u.data[p]=255;var d=a(e,u);d.wrap=e.REPEAT;var g=new v(e,r,o,s,l,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=new Uint8Array(4),s=new Float32Array(o.buffer);var l=t(\"binary-search-bounds\"),c=t(\"ndarray\"),u=t(\"./lib/shaders\"),f=u.createShader,h=u.createPickShader,p=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function d(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function g(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function m(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var y=v.prototype;y.isTransparent=function(){return this.hasAlpha},y.isOpaque=function(){return!this.hasAlpha},y.pickSlots=1,y.setPickBase=function(t){this.pickId=t},y.drawTransparent=y.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,clipBounds:g(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,pickId:this.pickId,clipBounds:g(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],s=0,u=0,f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],h=t.position||t.positions;if(h){var p=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,m=!1;t:for(e=1;e<h.length;++e){var v,y,x,b=h[e-1],_=h[e];for(a.push(s),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,m=!0}continue t}f[0][r]=Math.min(f[0][r],b[r],_[r]),f[1][r]=Math.max(f[1][r],b[r],_[r])}Array.isArray(p[0])?(v=p.length>e-1?p[e-1]:p.length>0?p[p.length-1]:[0,0,0,1],y=p.length>e?p[e]:p.length>0?p[p.length-1]:[0,0,0,1]):v=y=p,3===v.length&&(v=[v[0],v[1],v[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&v[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var T=s;if(s+=d(b,_),m){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3]);u+=2,m=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3],b[0],b[1],b[2],_[0],_[1],_[2],T,-x,v[0],v[1],v[2],v[3],_[0],_[1],_[2],b[0],b[1],b[2],s,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],s,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(s),o.push(h[h.length-1].slice()),this.bounds=f,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var k=t.dashes.slice();for(k.unshift(0),e=1;e<k.length;++e)k[e]=k[e-1]+k[e];var M=c(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)M.set(e,0,r,0);1&l.le(k,k[k.length-1]*e/255)?M.set(e,0,0,0):M.set(e,0,0,255)}this.texture.setPixels(M)}},y.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},y.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=function(t,e,r,n){return o[0]=n,o[1]=r,o[2]=e,o[3]=t,s[0]}(t.value[0],t.value[1],t.value[2],0),r=l.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new m(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),c=1-a,u=[0,0,0],f=0;f<3;++f)u[f]=c*n[f]+a*i[f];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new m(e,u,h,this.points[h])}},{\"./lib/shaders\":274,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495}],276:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],277:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15];return t[0]=s*(h*v-p*m)-f*(l*v-c*m)+g*(l*p-c*h),t[1]=-(n*(h*v-p*m)-f*(i*v-a*m)+g*(i*p-a*h)),t[2]=n*(l*v-c*m)-s*(i*v-a*m)+g*(i*c-a*l),t[3]=-(n*(l*p-c*h)-s*(i*p-a*h)+f*(i*c-a*l)),t[4]=-(o*(h*v-p*m)-u*(l*v-c*m)+d*(l*p-c*h)),t[5]=r*(h*v-p*m)-u*(i*v-a*m)+d*(i*p-a*h),t[6]=-(r*(l*v-c*m)-o*(i*v-a*m)+d*(i*c-a*l)),t[7]=r*(l*p-c*h)-o*(i*p-a*h)+u*(i*c-a*l),t[8]=o*(f*v-p*g)-u*(s*v-c*g)+d*(s*p-c*f),t[9]=-(r*(f*v-p*g)-u*(n*v-a*g)+d*(n*p-a*f)),t[10]=r*(s*v-c*g)-o*(n*v-a*g)+d*(n*c-a*s),t[11]=-(r*(s*p-c*f)-o*(n*p-a*f)+u*(n*c-a*s)),t[12]=-(o*(f*m-h*g)-u*(s*m-l*g)+d*(s*h-l*f)),t[13]=r*(f*m-h*g)-u*(n*m-i*g)+d*(n*h-i*f),t[14]=-(r*(s*m-l*g)-o*(n*m-i*g)+d*(n*l-i*s)),t[15]=r*(s*h-l*f)-o*(n*h-i*f)+u*(n*l-i*s),t}},{}],278:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],279:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],280:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],281:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],f=t[10],h=t[11],p=t[12],d=t[13],g=t[14],m=t[15];return(e*o-r*a)*(f*m-h*g)-(e*s-n*a)*(u*m-h*d)+(e*l-i*a)*(u*g-f*d)+(r*s-n*o)*(c*m-h*p)-(r*l-i*o)*(c*g-f*p)+(n*l-i*s)*(c*d-u*p)}},{}],282:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,f=n*s,h=i*o,p=i*s,d=i*l,g=a*o,m=a*s,v=a*l;return t[0]=1-f-d,t[1]=u+v,t[2]=h-m,t[3]=0,t[4]=u-v,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=h+m,t[9]=p-g,t[10]=1-c-f,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],283:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o=r[0],s=r[1],l=r[2],c=Math.sqrt(o*o+s*s+l*l);if(Math.abs(c)<1e-6)return null;return o*=c=1/c,s*=c,l*=c,n=Math.sin(e),i=Math.cos(e),a=1-i,t[0]=o*o*a+i,t[1]=s*o*a+l*n,t[2]=l*o*a-s*n,t[3]=0,t[4]=o*s*a-l*n,t[5]=s*s*a+i,t[6]=l*s*a+o*n,t[7]=0,t[8]=o*l*a+s*n,t[9]=s*l*a-o*n,t[10]=l*l*a+i,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],284:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,f=n*l,h=n*c,p=i*l,d=i*c,g=a*c,m=o*s,v=o*l,y=o*c;return t[0]=1-(p+g),t[1]=f+y,t[2]=h-v,t[3]=0,t[4]=f-y,t[5]=1-(u+g),t[6]=d+m,t[7]=0,t[8]=h+v,t[9]=d-m,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],285:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=e[1],t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=e[2],t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],286:[function(t,e,r){e.exports=function(t,e){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=e[0],t[13]=e[1],t[14]=e[2],t[15]=1,t}},{}],287:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=n,t[6]=r,t[7]=0,t[8]=0,t[9]=-r,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],288:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=0,t[2]=-r,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=r,t[9]=0,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],289:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=0,t[4]=-r,t[5]=n,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],290:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(r-e),l=1/(i-n),c=1/(a-o);return t[0]=2*a*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=2*a*l,t[6]=0,t[7]=0,t[8]=(r+e)*s,t[9]=(i+n)*l,t[10]=(o+a)*c,t[11]=-1,t[12]=0,t[13]=0,t[14]=o*a*2*c,t[15]=0,t}},{}],291:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],292:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),copy:t(\"./copy\"),identity:t(\"./identity\"),transpose:t(\"./transpose\"),invert:t(\"./invert\"),adjoint:t(\"./adjoint\"),determinant:t(\"./determinant\"),multiply:t(\"./multiply\"),translate:t(\"./translate\"),scale:t(\"./scale\"),rotate:t(\"./rotate\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),fromRotation:t(\"./fromRotation\"),fromRotationTranslation:t(\"./fromRotationTranslation\"),fromScaling:t(\"./fromScaling\"),fromTranslation:t(\"./fromTranslation\"),fromXRotation:t(\"./fromXRotation\"),fromYRotation:t(\"./fromYRotation\"),fromZRotation:t(\"./fromZRotation\"),fromQuat:t(\"./fromQuat\"),frustum:t(\"./frustum\"),perspective:t(\"./perspective\"),perspectiveFromFieldOfView:t(\"./perspectiveFromFieldOfView\"),ortho:t(\"./ortho\"),lookAt:t(\"./lookAt\"),str:t(\"./str\")}},{\"./adjoint\":277,\"./clone\":278,\"./copy\":279,\"./create\":280,\"./determinant\":281,\"./fromQuat\":282,\"./fromRotation\":283,\"./fromRotationTranslation\":284,\"./fromScaling\":285,\"./fromTranslation\":286,\"./fromXRotation\":287,\"./fromYRotation\":288,\"./fromZRotation\":289,\"./frustum\":290,\"./identity\":291,\"./invert\":293,\"./lookAt\":294,\"./multiply\":295,\"./ortho\":296,\"./perspective\":297,\"./perspectiveFromFieldOfView\":298,\"./rotate\":299,\"./rotateX\":300,\"./rotateY\":301,\"./rotateZ\":302,\"./scale\":303,\"./str\":304,\"./translate\":305,\"./transpose\":306}],293:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*g-f*d,M=u*m-h*d,A=u*v-p*d,S=f*m-h*g,E=f*v-p*g,C=h*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(h*w-f*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-i*A+a*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-h*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-a*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+i*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-f*x+h*y)*L,t}},{}],294:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g=e[0],m=e[1],v=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],T=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(m-w)<1e-6&&Math.abs(v-T)<1e-6)return n(t);f=g-_,h=m-w,p=v-T,d=1/Math.sqrt(f*f+h*h+p*p),a=x*(p*=d)-b*(h*=d),o=b*(f*=d)-y*p,s=y*h-x*f,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=h*s-p*o,c=p*a-f*s,u=f*o-h*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=f,t[3]=0,t[4]=o,t[5]=c,t[6]=h,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*m+s*v),t[13]=-(l*g+c*m+u*v),t[14]=-(f*g+h*m+p*v),t[15]=1,t}},{\"./identity\":291}],295:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*m,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*f+w*g,t[5]=x*i+b*l+_*h+w*m,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*f+w*g,t[9]=x*i+b*l+_*h+w*m,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*f+w*g,t[13]=x*i+b*l+_*h+w*m,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}},{}],296:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],297:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],298:[function(t,e,r){e.exports=function(t,e,r,n){var i=Math.tan(e.upDegrees*Math.PI/180),a=Math.tan(e.downDegrees*Math.PI/180),o=Math.tan(e.leftDegrees*Math.PI/180),s=Math.tan(e.rightDegrees*Math.PI/180),l=2/(o+s),c=2/(i+a);return t[0]=l,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=c,t[6]=0,t[7]=0,t[8]=-(o-s)*l*.5,t[9]=(i-a)*c*.5,t[10]=n/(r-n),t[11]=-1,t[12]=0,t[13]=0,t[14]=n*r/(r-n),t[15]=0,t}},{}],299:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E=n[0],C=n[1],L=n[2],I=Math.sqrt(E*E+C*C+L*L);if(Math.abs(I)<1e-6)return null;E*=I=1/I,C*=I,L*=I,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],f=e[4],h=e[5],p=e[6],d=e[7],g=e[8],m=e[9],v=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,T=C*C*o+a,k=L*C*o+E*i,M=E*L*o+C*i,A=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+f*b+g*_,t[1]=l*x+h*b+m*_,t[2]=c*x+p*b+v*_,t[3]=u*x+d*b+y*_,t[4]=s*w+f*T+g*k,t[5]=l*w+h*T+m*k,t[6]=c*w+p*T+v*k,t[7]=u*w+d*T+y*k,t[8]=s*M+f*A+g*S,t[9]=l*M+h*A+m*S,t[10]=c*M+p*A+v*S,t[11]=u*M+d*A+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],300:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t}},{}],301:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-f*n,t[3]=l*i-h*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+f*i,t[11]=l*n+h*i,t}},{}],302:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t}},{}],303:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],304:[function(t,e,r){e.exports=function(t){return\"mat4(\"+t[0]+\", \"+t[1]+\", \"+t[2]+\", \"+t[3]+\", \"+t[4]+\", \"+t[5]+\", \"+t[6]+\", \"+t[7]+\", \"+t[8]+\", \"+t[9]+\", \"+t[10]+\", \"+t[11]+\", \"+t[12]+\", \"+t[13]+\", \"+t[14]+\", \"+t[15]+\")\"}},{}],305:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],m=r[1],v=r[2];e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*m+f*v+e[12],t[13]=i*g+l*m+h*v+e[13],t[14]=a*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]);return t}},{}],306:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],307:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}function s(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}e.exports=function(t,e,r,a,l,c){if(1===t.length)return[0,t[0].slice()];for(var u=new Array(t.length),f=0;f<t.length;++f)u[f]=o(t[f],r,a,l,c);var h=0,p=1/0;for(f=0;f<u.length;++f){for(var d=0,g=0;g<2;++g)d+=Math.pow(u[f][g]-e[g],2);d<p&&(p=d,h=f)}var m=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(u,e),v=0;for(f=0;f<3;++f){if(m[f]<-.001||m[f]>1.0001)return null;v+=m[f]}if(Math.abs(v-1)>.001)return null;return[h,s(t,m),m]}},{barycentric:78,\"polytope-closest-point/lib/closest_point_2d.js\":525}],308:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:h,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:310}],309:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),f=t(\"colormap\"),h=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),m=d.meshShader,v=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function T(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,T,k,M,A,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=h,this.triangleUVs=f,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=m,this.edgeUVs=v,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=T,this.pointSizes=k,this.pointIds=b,this.pointVAO=M,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=A,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickVertex=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var k=T.prototype;function M(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function A(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}function S(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}function E(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function L(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function I(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}k.isOpaque=function(){return!this.hasAlpha},k.isTransparent=function(){return this.hasAlpha},k.pickSlots=1,k.setPickBase=function(t){this.pickId=t},k.highlight=function(t){if(t&&this.contourEnable){for(var e=h(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var f=c[0];2===c.length&&(f=c[u]);for(var d=n[f][0],g=n[f][1],m=i[f],v=1-m,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=m*y[b]+v*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},k.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=f({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*M(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],h=[],p=[],d=[],g=[],m=[],v=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,T=t.cellNormals,k=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,A=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!T&&(T=s.faceNormals(r,n,A)),T||w||(w=s.vertexNormals(r,n,k));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,I=t.vertexIntensity,P=t.cellUVs,z=t.cellIntensity,O=1/0,D=-1/0;if(!L&&!P)if(I)if(t.vertexIntensityBounds)O=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<I.length;++R){var F=I[R];O=Math.min(O,F),D=Math.max(D,F)}else if(z)if(t.cellIntensityBounds)O=+t.cellIntensityBounds[0],D=+t.cellIntensityBounds[1];else for(R=0;R<z.length;++R){F=z[R];O=Math.min(O,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];O=Math.min(O,F),D=Math.max(D,F)}this.intensity=I||(z||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n)),this.pickVertex=!(z||E);var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;v.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],g.push(Z[0],Z[1]),m.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),(X=S?S[W]:E?E[R]:C)?this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)):a.push(.5,.5,.5,1),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],c.push(Z[0],Z[1]),J=w?w[W]:T[R],l.push(J[0],J[1],J[2]),h.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(v),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(m)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(h))}},k.drawTransparent=k.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var f,h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/h}this.triangleCount>0&&((f=this.triShader).bind(),f.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((f=this.lineShader).bind(),f.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((f=this.pointShader).bind(),f.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((f=this.contourShader).bind(),f.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},k.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},k.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=t.coord[0],s=t.coord[1];if(!this.pickVertex){var l=this.positions[r[0]],c=this.positions[r[1]],u=this.positions[r[2]],f=[(l[0]+c[0]+u[0])/3,(l[1]+c[1]+u[1])/3,(l[2]+c[2]+u[2])/3];return{_cellCenter:!0,position:[o,s],index:e,cell:r,cellId:e,intensity:this.intensity[e],dataCoordinate:f}}var h=g(i,[o*this.pixelRatio,this._resolution[1]-s*this.pixelRatio],this._model,this._view,this._projection,this._resolution);if(!h)return null;var p=h[2],d=0;for(a=0;a<r.length;++a)d+=p[a]*this.intensity[r[a]];return{position:h[1],index:r[h[0]],cell:r,cellId:e,intensity:d,dataCoordinate:this.positions[r[h[0]]]}},k.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\");if(!r)throw new Error(\"derivatives not supported\");var n=A(t),s=S(t),l=E(t),c=C(t),f=L(t),h=I(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),m=i(t),v=i(t),y=i(t),x=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:m,type:t.FLOAT,size:2},{buffer:v,type:t.FLOAT,size:3}]),b=i(t),_=i(t),w=i(t),k=i(t),M=a(t,[{buffer:b,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),P=i(t),z=i(t),O=i(t),D=i(t),R=i(t),F=a(t,[{buffer:P,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:O,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=a(t,[{buffer:B,type:t.FLOAT,size:3}]),j=new T(t,p,n,s,l,c,f,h,d,y,g,m,v,x,b,k,_,w,M,P,R,z,O,D,F,B,N);return j.update(e),j}},{\"./lib/closest-point\":307,\"./lib/shaders\":308,colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-shader\":335,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495,normals:498,\"simplicial-complex-contour\":556,\"typedarray-pool\":595}],310:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],311:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"gl-buffer\":259,\"gl-shader\":335}],312:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,f,h,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],f=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,h=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var m=a[g],v=a[g+2]-m,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*v/x,c[g]=2*(m-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){f[0]=f[1]=0,f[g]=1,r.uniforms.dataAxis=f,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=h[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,f=this.ticks,h=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,m=s.pixelRatio,v=s.screenBox,y=v[2]-v[0],x=v[3]-v[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var T=p[w],k=p[w+2]-T,M=.5*(d[w+2]+d[w]),A=d[w+2]-d[w];e[w]=2*k/A,t[w]=2*(T-M)/A}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,I=6*f[0].length,P=Math.min(a.ge(f[0],(d[0]-p[0])/(p[2]-p[0]),l),f[0].length),z=Math.min(a.gt(f[0],(d[2]-p[0])/(p[2]-p[0]),l),f[0].length),O=0+6*P,D=6*Math.max(0,z-P),R=Math.min(a.ge(f[1],(d[1]-p[1])/(p[3]-p[1]),l),f[1].length),F=Math.min(a.gt(f[1],(d[3]-p[1])/(p[3]-p[1]),l),f[1].length),B=I+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*m/y,o[1]=C[1]*m/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*m/y,o[1]=E[0]*m/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,O,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*m/y,o[1]=C[3]*m/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*m/y,o[1]=E[2]*m/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,O,D))}}(),d.update=(h=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],f=0;f<l.length;++f){var d=(l[f].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=h[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":314,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335}],313:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"gl-buffer\":259,\"gl-shader\":335}],314:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:316}],315:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,f,h,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],f=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,h=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,m=e.tickColor,v=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],T=this.labelCount[t],k=o.lt(n,l[t]),M=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(h[2+t]-h[t])-1;var A=2/h[2+(1^t)]-h[1^t];u[1^t]=A*s[1^t]-1,d[t]&&(u[1^t]-=A*p*g[t],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t],r.uniforms.angle=v[t],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t]&&T&&(u[1^t]-=A*p*x[t],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,T)),u[1^t]=A*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=A*p*g[t+2],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t+2],r.uniforms.angle=v[t+2],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t+2]&&T&&(u[1^t]+=A*p*x[t+2],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,T))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(h=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],f=a[o],g=a[o+2]-f,m=i[o],v=i[o+2]-m;p[o]=2*l/u*g/v,h[o]=2*(s-c)/u*g/v}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=h,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],f=[-1/0],h=l[o];for(e=0;e<h.length;++e){var p=h[e],d=p.x,g=p.text,m=p.font||\"sans-serif\";i=p.fontSize||12;for(var v=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(m,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*v);u.push(Math.floor(s.length/3)),f.push(d)}this.tickOffset[o]=u,this.tickX[o]=f}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335,\"text-cache\":575}],316:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],317:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function f(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var f=this.zeroLineEnable,h=this.zeroLineColor,p=this.zeroLineWidth;if(f[0]||f[1]){o.bind();for(var d=0;d<2;++d)if(f[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],h[d]):o.drawLine(e[0],g,e[2],g,p[d],h[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var m=this.borderLineEnable,v=this.borderLineWidth,y=this.borderLineColor;for(m[1]&&o.drawLine(r[0],r[1]-.5*v[1]*i,r[0],r[3]+.5*v[3]*i,v[1],y[1]),m[0]&&o.drawLine(r[0]-.5*v[0]*i,r[1],r[2]+.5*v[2]*i,r[1],v[0],y[0]),m[3]&&o.drawLine(r[2],r[1]-.5*v[1]*i,r[2],r[3]+.5*v[3]*i,v[3],y[3]),m[2]&&o.drawLine(r[0]-.5*v[0]*i,r[3],r[2]+.5*v[2]*i,r[3],v[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl,this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var f=c[u].pick(a,o,l);if(f)return f}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t)||!!t.titleEnable,this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(f),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":311,\"./lib/grid\":312,\"./lib/line\":313,\"./lib/text\":315,\"gl-select-static\":334}],318:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],f=0,h=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===h&&t.clientHeight===p;return h=t.clientWidth,p=t.clientHeight,a?!l:(f=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return f},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",(function(t){return t.preventDefault(),!1})),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,h=!!a.control,p=!!a.alt,g=!!a.shift,m=!!(1&e),v=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,T=d.flipY?1:-1,k=Math.PI*d.rotateSpeed,M=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&m&&!h&&!p&&!g||m&&!h&&!p&&g)&&c.rotate(M,w*k*b,-T*k*_,0),(l&&m&&!h&&!p&&!g||v||m&&h&&!p&&!g)&&c.pan(M,-d.translateSpeed*b*f,d.translateSpeed*_*f,0),u&&m&&!h&&!p&&!g||y||m&&!h&&p&&!g)){var A=-d.zoomSpeed*_/window.innerHeight*(M-c.lastT())*100;c.pan(M,0,0,f*(Math.exp(A)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",(function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods)}),!!l&&{passive:!0}),t.addEventListener(\"touchmove\",(function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()}),!!l&&{passive:!1}),t.addEventListener(\"touchend\",(function(t){e(0,d._lastX,d._lastY,d._lastMods)}),!!l&&{passive:!0}),d.wheelListener=o(t,(function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,f*(Math.exp(o)-1))}}}),!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":54,\"has-passive-events\":441,\"mouse-change\":483,\"mouse-event-offset\":484,\"mouse-wheel\":486,\"right-now\":542}],319:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":335,glslify:320}],320:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],321:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),f=t(\"gl-mat4/perspective\"),h=t(\"gl-mat4/ortho\"),p=t(\"./lib/shader\"),d=t(\"is-mobile\")({tablet:!0,featureDetect:!0});function g(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function v(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e){if(e=document.createElement(\"canvas\"),t.container)t.container.appendChild(e);else document.body.appendChild(e)}var r=t.gl;r||(t.glOptions&&(d=!!t.glOptions.preserveDrawingBuffer),r=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:d}));if(!r)throw new Error(\"webgl not supported\");var y=t.bounds||[[-10,-10,-10],[10,10,10]],x=new g,b=l(r,r.drawingBufferWidth,r.drawingBufferHeight,{preferFloat:!d}),_=p(r),w=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,T={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:w},k=t.axes||{},M=i(r,k);M.enable=!k.disable;var A=t.spikes||{},S=o(r,A),E=[],C=[],L=[],I=[],P=!0,z=!0,O=new Array(16),D=new Array(16),R={view:null,projection:O,model:D,_ortho:!1},F=(z=!0,[r.drawingBufferWidth,r.drawingBufferHeight]),B=t.cameraObject||n(e,T),N={gl:r,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:x,camera:B,axes:M,axesPixels:null,spikes:S,bounds:y,objects:E,shape:F,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:v(t.autoResize),autoBounds:v(t.autoBounds),autoScale:!!t.autoScale,autoCenter:v(t.autoCenter),clipToBounds:v(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:R,oncontextloss:null,mouseListener:null,_stopped:!1,getAspectratio:function(){return{x:this.aspect[0],y:this.aspect[1],z:this.aspect[2]}},setAspectratio:function(t){this.aspect[0]=t.x,this.aspect[1]=t.y,this.aspect[2]=t.z,z=!0},setBounds:function(t,e){this.bounds[0][t]=e.min,this.bounds[1][t]=e.max},setClearColor:function(t){this.clearColor=t},clearRGBA:function(){this.gl.clearColor(this.clearColor[0],this.clearColor[1],this.clearColor[2],this.clearColor[3]),this.gl.clear(this.gl.COLOR_BUFFER_BIT|this.gl.DEPTH_BUFFER_BIT)}},j=[r.drawingBufferWidth/N.pixelRatio|0,r.drawingBufferHeight/N.pixelRatio|0];function U(){if(!N._stopped&&N.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*N.pixelRatio),a=0|Math.ceil(n*N.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",P=!0}}}N.autoResize&&U();function V(){for(var t=E.length,e=I.length,n=0;n<e;++n)L[n]=0;t:for(n=0;n<t;++n){var i=E[n],a=i.pickSlots;if(a){for(var o=0;o<e;++o)if(L[o]+a<255){C[n]=o,i.setPickBase(L[o]+1),L[o]+=a;continue t}var l=s(r,F);C[n]=e,I.push(l),L.push(a),i.setPickBase(1),e+=1}else C[n]=-1}for(;e>0&&0===L[e-1];)L.pop(),I.pop().dispose()}function q(){if(N.contextLost)return!0;r.isContextLost()&&(N.contextLost=!0,N.mouseListener.enabled=!1,N.selection.object=null,N.oncontextloss&&N.oncontextloss())}window.addEventListener(\"resize\",U),N.update=function(t){N._stopped||(t=t||{},P=!0,z=!0)},N.add=function(t){N._stopped||(t.axes=M,E.push(t),C.push(-1),P=!0,z=!0,V())},N.remove=function(t){if(!N._stopped){var e=E.indexOf(t);e<0||(E.splice(e,1),C.pop(),P=!0,z=!0,V())}},N.dispose=function(){if(!N._stopped&&(N._stopped=!0,window.removeEventListener(\"resize\",U),e.removeEventListener(\"webglcontextlost\",q),N.mouseListener.enabled=!1,!N.contextLost)){M.dispose(),S.dispose();for(var t=0;t<E.length;++t)E[t].dispose();b.dispose();for(t=0;t<I.length;++t)I[t].dispose();_.dispose(),r=null,M=null,S=null,E=[]}},N._mouseRotating=!1,N._prevButtons=0,N.enableMouseListeners=function(){N.mouseListener=u(e,(function(t,e,r){if(!N._stopped){var n=I.length,i=E.length,a=x.object;x.distance=1/0,x.mouse[0]=e,x.mouse[1]=r,x.object=null,x.screen=null,x.dataCoordinate=x.dataPosition=null;var o=!1;if(t&&N._prevButtons)N._mouseRotating=!0;else{N._mouseRotating&&(z=!0),N._mouseRotating=!1;for(var s=0;s<n;++s){var l=I[s].query(e,j[1]-r-1,N.pickRadius);if(l){if(l.distance>x.distance)continue;for(var c=0;c<i;++c){var u=E[c];if(C[c]===s){var f=u.pick(l);f&&(x.buttons=t,x.screen=l.coord,x.distance=l.distance,x.object=u,x.index=f.distance,x.dataPosition=f.position,x.dataCoordinate=f.dataCoordinate,x.data=f,o=!0)}}}}}a&&a!==x.object&&(a.highlight&&a.highlight(null),P=!0),x.object&&(x.object.highlight&&x.object.highlight(x.data),P=!0),(o=o||x.object!==a)&&N.onselect&&N.onselect(x),1&t&&!(1&N._prevButtons)&&N.onclick&&N.onclick(x),N._prevButtons=t}}))},e.addEventListener(\"webglcontextlost\",q);var H=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],G=[H[0].slice(),H[1].slice()];function Y(){if(!q()){U();var t=N.camera.tick();R.view=N.camera.matrix,P=P||t,z=z||t,M.pixelRatio=N.pixelRatio,S.pixelRatio=N.pixelRatio;var e=E.length,n=H[0],i=H[1];n[0]=n[1]=n[2]=1/0,i[0]=i[1]=i[2]=-1/0;for(var o=0;o<e;++o){(L=E[o]).pixelRatio=N.pixelRatio,L.axes=N.axes,P=P||!!L.dirty,z=z||!!L.dirty;var s=L.bounds;if(s)for(var l=s[0],u=s[1],p=0;p<3;++p)n[p]=Math.min(n[p],l[p]),i[p]=Math.max(i[p],u[p])}var d=N.bounds;if(N.autoBounds)for(p=0;p<3;++p){if(i[p]<n[p])n[p]=-1,i[p]=1;else{n[p]===i[p]&&(n[p]-=1,i[p]+=1);var g=.05*(i[p]-n[p]);n[p]=n[p]-g,i[p]=i[p]+g}d[0][p]=n[p],d[1][p]=i[p]}var v=!1;for(p=0;p<3;++p)v=v||G[0][p]!==d[0][p]||G[1][p]!==d[1][p],G[0][p]=d[0][p],G[1][p]=d[1][p];if(z=z||v,P=P||v){if(v){var y=[0,0,0];for(o=0;o<3;++o)y[o]=m((d[1][o]-d[0][o])/10);M.autoTicks?M.update({bounds:d,tickSpacing:y}):M.update({bounds:d})}var T=r.drawingBufferWidth,k=r.drawingBufferHeight;F[0]=T,F[1]=k,j[0]=0|Math.max(T/N.pixelRatio,1),j[1]=0|Math.max(k/N.pixelRatio,1),function(t,e){var r=t.bounds,n=t.cameraParams,i=n.projection,a=n.model,o=t.gl.drawingBufferWidth,s=t.gl.drawingBufferHeight,l=t.zNear,c=t.zFar,u=t.fovy,p=o/s;e?(h(i,-p,p,-1,1,l,c),n._ortho=!0):(f(i,u,p,l,c),n._ortho=!1);for(var d=0;d<16;++d)a[d]=0;a[15]=1;var g=0;for(d=0;d<3;++d)g=Math.max(g,r[1][d]-r[0][d]);for(d=0;d<3;++d)t.autoScale?a[5*d]=t.aspect[d]/(r[1][d]-r[0][d]):a[5*d]=1/g,t.autoCenter&&(a[12+d]=.5*-a[5*d]*(r[0][d]+r[1][d]))}(N,w);for(o=0;o<e;++o){(L=E[o]).axesBounds=d,N.clipToBounds&&(L.clipBounds=d)}x.object&&(N.snapToData?S.position=x.dataCoordinate:S.position=x.dataPosition,S.bounds=d),z&&(z=!1,function(){if(!q()){r.colorMask(!0,!0,!0,!0),r.depthMask(!0),r.disable(r.BLEND),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL);for(var t=E.length,e=I.length,n=0;n<e;++n){var i=I[n];i.shape=j,i.begin();for(var a=0;a<t;++a)if(C[a]===n){var o=E[a];o.drawPick&&(o.pixelRatio=1,o.drawPick(R))}i.end()}}}()),N.axesPixels=a(N.axes,R,T,k),N.onrender&&N.onrender(),r.bindFramebuffer(r.FRAMEBUFFER,null),r.viewport(0,0,T,k),N.clearRGBA(),r.depthMask(!0),r.colorMask(!0,!0,!0,!0),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL),r.disable(r.BLEND),r.disable(r.CULL_FACE);var A=!1;M.enable&&(A=A||M.isTransparent(),M.draw(R)),S.axes=M,x.object&&S.draw(R),r.disable(r.CULL_FACE);for(o=0;o<e;++o){(L=E[o]).axes=M,L.pixelRatio=N.pixelRatio,L.isOpaque&&L.isOpaque()&&L.draw(R),L.isTransparent&&L.isTransparent()&&(A=!0)}if(A){b.shape=F,b.bind(),r.clear(r.DEPTH_BUFFER_BIT),r.colorMask(!1,!1,!1,!1),r.depthMask(!0),r.depthFunc(r.LESS),M.enable&&M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){(L=E[o]).isOpaque&&L.isOpaque()&&L.draw(R)}r.enable(r.BLEND),r.blendEquation(r.FUNC_ADD),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.colorMask(!0,!0,!0,!0),r.depthMask(!1),r.clearColor(0,0,0,0),r.clear(r.COLOR_BUFFER_BIT),M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){var L;(L=E[o]).isTransparent&&L.isTransparent()&&L.drawTransparent(R)}r.bindFramebuffer(r.FRAMEBUFFER,null),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.disable(r.DEPTH_TEST),_.bind(),b.color[0].bind(0),_.uniforms.accumBuffer=0,c(r),r.disable(r.BLEND)}P=!1;for(o=0;o<e;++o)E[o].dirty=!1}}}return N.enableMouseListeners(),function t(){if(N._stopped||N.contextLost)return;Y(),requestAnimationFrame(t)}(),N.redraw=function(){N._stopped||(P=!0,Y())},N},createCamera:n}},{\"./camera.js\":318,\"./lib/shader\":319,\"a-big-triangle\":64,\"gl-axes3d\":250,\"gl-axes3d/properties\":258,\"gl-fbo\":269,\"gl-mat4/ortho\":296,\"gl-mat4/perspective\":297,\"gl-select-static\":334,\"gl-spikes3d\":345,\"is-mobile\":467,\"mouse-change\":483}],322:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:323}],323:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],324:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),f=new s(t,a,l,c,u);return f.update(e),t.addObject(f),f};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var f=n.getParameter(n.BLEND),h=n.getParameter(n.DITHER);return f&&!this.blend&&n.disable(n.BLEND),h&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),f&&!this.blend&&n.enable(n.BLEND),h&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":322,\"gl-buffer\":259,\"gl-shader\":335,\"typedarray-pool\":595}],325:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],f=e[2],h=e[3],p=r[0],d=r[1],g=r[2],m=r[3];(a=c*p+u*d+f*g+h*m)<0&&(a=-a,p=-p,d=-d,g=-g,m=-m);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*f+l*g,t[3]=s*h+l*m,t}},{}],326:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],327:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var f=[[1/0,1/0],[-1/0,-1/0]],h=u.positions.length;for(l=0;l<h;++l){var p=u.positions[l];for(c=0;c<2;++c)f[0][c]=Math.min(f[0][c],p[c]),f[1][c]=Math.max(f[1][c],p[c])}return a[t]=[s,u,f]};var i={}},{\"vectorize-text\":600}],328:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],f={vertex:a,fragment:l,attributes:u},h={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},m={vertex:s,fragment:c,attributes:u};function v(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return v(t,f)},r.createOrtho=function(t){return v(t,h)},r.createProject=function(t){return v(t,p)},r.createPickPerspective=function(t){return v(t,d)},r.createPickOrtho=function(t){return v(t,g)},r.createPickProject=function(t){return v(t,m)}},{\"gl-shader\":335,glslify:329}],329:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],330:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return h(n,n),h(n,n),h(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t||t>1?1:t}function m(t,e,r,n,i,a,o,s,l,c,u,f){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=f,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),f=i(e),h=i(e),p=i(e),d=i(e),g=a(e,[{buffer:f,size:3,type:e.FLOAT},{buffer:h,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),v=new m(e,r,n,o,f,h,p,d,g,s,c,u);return v.update(t),v};var v=m.prototype;v.pickSlots=1,v.setPickBase=function(t){this.pickId=t},v.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},v.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],T=f.slice(),k=[0,0,0],M=[[0,0,0],[0,0,0]];function A(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||f,u=r.view||f,h=r.projection||f,d=e.axesBounds,g=function(t){for(var e=M,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=h,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var m=0;m<3;++m)if(a[m]){l.scale=e.projectScale[m],l.opacity=e.projectOpacity[m];for(var v=T,C=0;C<16;++C)v[C]=0;for(C=0;C<4;++C)v[5*C]=1;v[5*m]=0,i[m]<0?v[12+m]=d[0][m]:v[12+m]=d[1][m],s(v,c,v),l.model=v;var L=(m+1)%3,I=(m+2)%3,P=A(x),z=A(b);P[L]=1,z[I]=1;var O=p(0,0,0,S(_,P)),D=p(0,0,0,S(w,z));if(Math.abs(O[1])>Math.abs(D[1])){var R=O;O=D,D=R,R=P,P=z,z=R;var F=L;L=I,I=F}O[0]<0&&(P[L]=-1),D[1]>0&&(z[I]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*I+C],2);P[L]/=Math.sqrt(B),z[I]/=Math.sqrt(N),l.axes[0]=P,l.axes[1]=z,l.fragClipBounds[0]=E(k,g[0],m,-1e8),l.fragClipBounds[1]=E(k,g[1],m,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function I(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||f,l.view=n.view||f,l.projection=n.projection||f,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function P(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}v.draw=function(t){I(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},v.drawTransparent=function(t){I(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},v.drawPick=function(t){I(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},v.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},v.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},v.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],f=[-1/0,-1/0,-1/0],h=t.glyph,p=t.color,d=t.size,m=t.angle,v=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],T=0;T<3;++T)if(isNaN(w[T])||!isFinite(w[T]))continue t;var k=(N=P(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;x+=3*k.cells.length,b+=2*M.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),I=o.mallocUint32(S);if(S>0){var z=0,O=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(v)&&Array.isArray(v[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],T=0;T<3;++T){if(isNaN(w[T])||!isFinite(w[T]))continue t;f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T])}k=(N=P(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(T=0;T<3;++T)D[T]=U[T];D[3]=1}else if(4===U.length){for(T=0;T<4;++T)D[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(v)){var U;if(3===(U=B?n<v.length?v[n]:[0,0,0,0]:v).length){for(T=0;T<3;++T)R[T]=U[T];R[T]=1}else if(4===U.length){for(T=0;T<4;++T)R[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(m)?q=n<m.length?+m[n]:0:m&&(q=+m);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],T=0;T<3;++T)f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-A[0][0]:Y<0?1+A[1][0]:1,W*=W>0?1-A[0][1]:W<0?1+A[1][1]:1],Z=k.cells||[],J=k.positions||[];for(T=0;T<Z.length;++T)for(var K=Z[T],Q=0;Q<3;++Q){for(var $=0;$<3;++$)E[3*z+$]=w[$];for($=0;$<4;++$)C[4*z+$]=D[$];I[z]=y;var tt=J[K[Q]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=M.edges,J=M.positions,T=0;T<Z.length;++T)for(K=Z[T],Q=0;Q<2;++Q){for($=0;$<3;++$)E[3*O+$]=w[$];for($=0;$<4;++$)C[4*O+$]=R[$];I[O]=y;tt=J[K[Q]];L[2*O]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*O+1]=V*(G*tt[0]+H*tt[1]+X[1]),O+=1}}}this.bounds=[u,f],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(I),o.free(E),o.free(C),o.free(L),o.free(I)},v.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":326,\"./lib/glyphs\":327,\"./lib/shaders\":328,\"gl-buffer\":259,\"gl-mat4/multiply\":295,\"gl-vao\":358,\"is-string-blank\":470,\"typedarray-pool\":595}],331:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:332}],332:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],333:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,f=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],h=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(f=Math.max(f,c[0]),h=Math.max(h,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<f||d<h)){o.bind();var g=s[2]-s[0],m=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,h,i),o.drawBox(0,h,f,d,i),o.drawBox(0,d,g,m,i),o.drawBox(p,h,g,d,i)),this.innerFill&&o.drawBox(f,h,p,d,n),r>0){var v=r*u;o.drawBox(f-v,h-v,p+v,h+v,a),o.drawBox(f-v,d-v,p+v,d+v,a),o.drawBox(f-v,h-v,f+v,d+v,a),o.drawBox(p-v,h-v,p+v,d+v,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":331,\"gl-buffer\":259,\"gl-shader\":335}],334:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=e[0],a=e[1],o=n(t,r,a,{}),s=i.mallocUint8(r*a*4);return new l(t,o,s)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2;function s(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function l(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var c=l.prototype;Object.defineProperty(c,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),c.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},c.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},c.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),l=0|Math.min(Math.max(e-r,0),n[1]),c=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||c<=l)return null;var u=[o-i,c-l],f=a(this.buffer,[u[0],u[1],4],[4,4*n[0],1],4*(i+n[0]*l)),h=function(t,e,r){for(var n=1e8,i=-1,a=-1,o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++){var u=t.get(l,c,0),f=t.get(l,c,1),h=t.get(l,c,2),p=t.get(l,c,3);if(u<255||f<255||h<255||p<255){var d=e-l,g=r-c,m=d*d+g*g;m<n&&(n=m,i=l,a=c)}}return[i,a,n]}(f.hi(u[0],u[1],1),r,r),p=h[0],d=h[1];return p<0||Math.pow(this.radius,2)<h[2]?null:new s(p+i|0,d+l|0,f.get(p,d,0),[f.get(p,d,1),f.get(p,d,2),f.get(p,d,3)],Math.sqrt(h[2]))},c.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":97,\"gl-fbo\":269,ndarray:495,\"typedarray-pool\":595}],335:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function f(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var h=this,p=h.gl,d=h._vref;h._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),h.vertShader=h._vref.shader;var g=this._fref;if(h._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),h.fragShader=h._fref.shader,!r||!c){var m=p.createProgram();if(p.attachShader(m,h.fragShader),p.attachShader(m,h.vertShader),p.linkProgram(m),!p.getProgramParameter(m,p.LINK_STATUS)){var v=p.getProgramInfoLog(m);throw new l(v,\"Error linking program:\"+v)}r=r||s.uniforms(p,m),c=c||s.attributes(p,m),p.deleteProgram(m)}(c=c.slice()).sort(f);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var T=0|w.type.charAt(w.type.length-1),k=new Array(T),M=0;M<T;++M)k[M]=_.length,b.push(w.name+\"[\"+M+\"]\"),\"number\"==typeof w.location?_.push(w.location+M):Array.isArray(w.location)&&w.location.length===T&&\"number\"==typeof w.location[M]?_.push(0|w.location[M]):_.push(-1);x.push({name:w.name,type:w.type,locations:k})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var A=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(A)>=0;)A+=1;_[y]=A}var S=new Array(r.length);function E(){h.program=o.program(p,h._vref,h._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(h.program,r[t].name)}E(),h._relink=E,h.types={uniforms:a(r),attributes:a(c)},h.attributes=i(p,h,x,_),Object.defineProperty(h,\"uniforms\",n(p,h,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":336,\"./lib/create-attributes\":337,\"./lib/create-uniforms\":338,\"./lib/reflect\":339,\"./lib/runtime-reflect\":340,\"./lib/shader-cache\":341}],336:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],337:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],f=u.name,h=u.type,p=u.locations;switch(h){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,f);break;default:if(h.indexOf(\"vec\")>=0){if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);o(t,e,p[0],i,d,a,f)}else{if(!(h.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+f+\": \"+h);var d;if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);s(t,e,p,i,d,a,f)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var f=Function.apply(null,l),h=new i(t,e,r,n,a,f);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),f(t,n[r],e),e},get:function(){return h},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var f=new Array(i),h=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))h.call(t,o,e[a]);else{for(var s=0;s<i;++s)f[s]=e[i*a+s];h.call(t,o,f)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":336}],338:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a;if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}return n.push(\"return obj}\"),new Function(\"gl\",\"locations\",n.join(\"\\n\"))(t,s)}function u(n,l,u){if(\"object\"==typeof u){var h=f(u);Object.defineProperty(n,l,{get:a(h),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r;if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function f(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var h=n(r,!0);return{get:a(f(h)),set:c(h),enumerable:!0,configurable:!0}}},{\"./GLError\":336,\"./reflect\":339}],339:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name.split(\".\"),a=r,o=0;o<i.length;++o){var s=i[o].split(\"[\");if(s.length>1){s[0]in a||(a[s[0]]=[]),a=a[s[0]];for(var l=1;l<s.length;++l){var c=parseInt(s[l]);l<s.length-1||o<i.length-1?(c in a||(l<s.length-1?a[c]=[]:a[c]={}),a=a[c]):a[c]=e?n:t[n].type}}else o<i.length-1?(s[0]in a||(a[s[0]]={}),a=a[s[0]]):a[s[0]]=e?n:t[n].type}return r}},{}],340:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],341:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":336,\"gl-format-compiler-error\":270,\"weakmap-shim\":605}],342:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map((function(t){return t.slice()})),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],343:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],344:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":335,glslify:343}],345:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var f=new s(t,l,c,u);return f.update(e),f};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],f=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var h=c,p=u,d=0;d<3;++d)i&&i[d]<0?(h[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(h[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);f[0]=e.drawingBufferWidth,f[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,h,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=f;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":344,\"gl-buffer\":259,\"gl-vao\":358}],346:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, tubeScale;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:347}],347:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],348:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"],o=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++)o=Math.max(o,n.length(l[c]));var u=t.map((function(t){return function(t,e,r,a){for(var o=t.points,s=t.velocities,l=t.divergences,c=[],u=[],f=[],h=[],p=[],d=[],g=0,m=0,v=i.create(),y=i.create(),x=0;x<o.length;x++){var b=o[x],_=s[x],w=l[x];0===e&&(w=.05*r),m=n.length(_)/a,v=i.create(),n.copy(v,_),v[3]=w;for(var T=0;T<8;T++)p[T]=[b[0],b[1],b[2],T];if(h.length>0)for(T=0;T<8;T++){var k=(T+1)%8;c.push(h[T],p[T],p[k],p[k],h[k],h[T]),f.push(y,v,v,v,y,y),d.push(g,m,m,m,g,g);var M=c.length;u.push([M-6,M-5,M-4],[M-3,M-2,M-1])}var A=h;h=p,p=A;var S=y;y=v,v=S;var E=g;g=m,m=E}return{positions:c,cells:u,vectors:f,vertexIntensity:d}}(t,r,a,o)})),f=[],h=[],p=[],d=[];for(s=0;s<u.length;s++){var g=u[s],m=f.length;f=f.concat(g.positions),p=p.concat(g.vectors),d=d.concat(g.vertexIntensity);for(c=0;c<g.cells.length;c++){var v=g.cells[c],y=[];h.push(y);for(var x=0;x<v.length;x++)y.push(v[x]+m)}}return{positions:f,cells:h,vectors:p,vertexIntensity:d,colormap:e}},s=function(t,e){var r,n=t.length;for(r=0;r<n;r++){var i=t[r];if(i===e)return r;if(i>e)return r-1}return r},l=function(t,e,r){return t<e?e:t>r?r:t},c=function(t){var e=1/0;t.sort((function(t,e){return t-e}));for(var r=t.length,n=1;n<r;n++){var i=Math.abs(t[n]-t[n-1]);i<e&&(e=i)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,u=t.tubeSize||1,f=t.absoluteTubeSize,h=t.gridFill||\"+x+y+z\",p={};-1!==h.indexOf(\"-x\")&&(p.reversedX=!0),-1!==h.indexOf(\"-y\")&&(p.reversedY=!0),-1!==h.indexOf(\"-z\")&&(p.reversedZ=!0),p.filled=a.indexOf(h.replace(/-/g,\"\").replace(/\\+/g,\"\"));var d=t.getVelocity||function(e){return function(t,e,r){var i=e.vectors,a=e.meshgrid,o=t[0],c=t[1],u=t[2],f=a[0].length,h=a[1].length,p=a[2].length,d=s(a[0],o),g=s(a[1],c),m=s(a[2],u),v=d+1,y=g+1,x=m+1;if(d=l(d,0,f-1),v=l(v,0,f-1),g=l(g,0,h-1),y=l(y,0,h-1),m=l(m,0,p-1),x=l(x,0,p-1),d<0||g<0||m<0||v>f-1||y>h-1||x>p-1)return n.create();var b,_,w,T,k,M,A=a[0][d],S=a[0][v],E=a[1][g],C=a[1][y],L=a[2][m],I=(o-A)/(S-A),P=(c-E)/(C-E),z=(u-L)/(a[2][x]-L);switch(isFinite(I)||(I=.5),isFinite(P)||(P=.5),isFinite(z)||(z=.5),r.reversedX&&(d=f-1-d,v=f-1-v),r.reversedY&&(g=h-1-g,y=h-1-y),r.reversedZ&&(m=p-1-m,x=p-1-x),r.filled){case 5:k=m,M=x,w=g*p,T=y*p,b=d*p*h,_=v*p*h;break;case 4:k=m,M=x,b=d*p,_=v*p,w=g*p*f,T=y*p*f;break;case 3:w=g,T=y,k=m*h,M=x*h,b=d*h*p,_=v*h*p;break;case 2:w=g,T=y,b=d*h,_=v*h,k=m*h*f,M=x*h*f;break;case 1:b=d,_=v,k=m*f,M=x*f,w=g*f*p,T=y*f*p;break;default:b=d,_=v,w=g*f,T=y*f,k=m*f*h,M=x*f*h}var O=i[b+w+k],D=i[b+w+M],R=i[b+T+k],F=i[b+T+M],B=i[_+w+k],N=i[_+w+M],j=i[_+T+k],U=i[_+T+M],V=n.create(),q=n.create(),H=n.create(),G=n.create();n.lerp(V,O,B,I),n.lerp(q,D,N,I),n.lerp(H,R,j,I),n.lerp(G,F,U,I);var Y=n.create(),W=n.create();n.lerp(Y,V,H,P),n.lerp(W,q,G,P);var X=n.create();return n.lerp(X,Y,W,z),X}(e,t,p)},g=t.getDivergence||function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=d(r);n.subtract(a,a,e),n.scale(a,a,1/i),n.add(r,t,[0,i,0]);var o=d(r);n.subtract(o,o,e),n.scale(o,o,1/i),n.add(r,t,[0,0,i]);var s=d(r);return n.subtract(s,s,e),n.scale(s,s,1/i),n.add(r,a,o),n.add(r,r,s),r},m=[],v=e[0][0],y=e[0][1],x=e[0][2],b=e[1][0],_=e[1][1],w=e[1][2],T=function(t){var e=t[0],r=t[1],n=t[2];return!(e<v||e>b||r<y||r>_||n<x||n>w)},k=10*n.distance(e[0],e[1])/i,M=k*k,A=1,S=0,E=r.length;E>1&&(A=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=t.length,l=0;l<s;l++){var u=t[l],f=u[0],h=u[1],p=u[2];i[f]||(e.push(f),i[f]=!0),a[h]||(r.push(h),a[h]=!0),o[p]||(n.push(p),o[p]=!0)}var d=c(e),g=c(r),m=c(n),v=Math.min(d,g,m);return isFinite(v)?v:1}(r));for(var C=0;C<E;C++){var L=n.create();n.copy(L,r[C]);var I=[L],P=[],z=d(L),O=L;P.push(z);var D=[],R=g(L,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F),m.push({points:I,velocities:P,divergences:D});for(var B=0;B<100*i&&I.length<i&&T(L);){B++;var N=n.clone(z),j=n.squaredLength(N);if(0===j)break;if(j>M&&n.scale(N,N,k/Math.sqrt(j)),n.add(N,N,L),z=d(N),n.squaredDistance(O,N)-M>-1e-4*M){I.push(N),O=N,P.push(z);R=g(N,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F)}L=N}}var U=o(m,t.colormap,S,A);return f?U.tubeScale=f:(0===S&&(S=1),U.tubeScale=.5*u*A/S),U};var u=t(\"./lib/shaders\"),f=t(\"gl-cone3d\").createMesh;e.exports.createTubeMesh=function(t,e){return f(t,e,{shaders:u,traceType:\"streamtube\"})}},{\"./lib/shaders\":346,\"gl-cone3d\":260,\"gl-vec3\":377,\"gl-vec4\":413}],349:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if (\\n    kill > 0.0 ||\\n    vColor.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], worldCoordinate)\\n  ) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":335,glslify:350}],350:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],351:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:40,offset:0},{buffer:c,size:3,stride:40,offset:16},{buffer:c,size:3,stride:40,offset:28}]),f=i(e),h=a(e,[{buffer:f,size:4,stride:20,offset:0},{buffer:f,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,256,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var m=new A(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,f,h,p,d,[0,0,0]),v={levels:[[],[],[]]};for(var w in t)v[w]=t[w];return v.colormap=v.colormap||\"jet\",m.update(v),m};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),f=t(\"ndarray\"),h=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),m=t(\"ndarray-gradient\"),v=t(\"./lib/shaders\"),y=v.createShader,x=v.createContourShader,b=v.createPickShader,_=v.createPickContourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],k=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=k[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();function A(t,e,r,n,i,a,o,l,c,u,h,p,d,g,m){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=m,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=h,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var S=A.prototype;S.genColormap=function(t,e){var r=!1,n=u([l({colormap:t,nshades:256,format:\"rgba\"}).map((function(t,n){var i=e?function(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}(n/255,e):t[3];return i<1&&(r=!0),[t[0],t[1],t[2],255*i]}))]);return c.divseq(n,255),this.hasAlphaScale=r,n},S.isTransparent=function(){return this.opacity<1||this.hasAlphaScale},S.isOpaque=function(){return!this.isTransparent()},S.pickSlots=1,S.setPickBase=function(t){this.pickId=t};var E=[0,0,0],C={showSurface:!1,showContour:!1,projections:[w.slice(),w.slice(),w.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function L(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||E,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=C.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=C.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return C.showSurface=o,C.showContour=s,C}var I={model:w,view:w,projection:w,inverseModel:w.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},P=w.slice(),z=[1,0,0,0,1,0,0,0,1];function O(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=I;n.model=t.model||w,n.view=t.view||w,n.projection=t.projection||w,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=z,n.vertexColor=this.vertexColor;var s=P;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=L(n,this);if(u.showSurface){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour){var f=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,f.bind(),f.uniforms=n;var h=this._contourVAO;for(h.bind(),i=0;i<3;++i)for(f.uniforms.permutation=k[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(f.uniforms.contourColor=this.highlightColor[i],f.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(f.uniforms.contourColor=this.contourColor[i],f.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(f.uniforms.height=this.contourLevels[i][o],h.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(f.uniforms.model=u.projections[i],f.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){f.uniforms.permutation=k[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(f.uniforms.contourColor=this.highlightColor[o],f.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(f.uniforms.contourColor=this.contourColor[o],f.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(f.uniforms.height=this.contourLevels[o][g],h.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(h.unbind(),(h=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(f.uniforms.model=n.model,f.uniforms.clipBounds=n.clipBounds,f.uniforms.permutation=k[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),f.uniforms.contourColor=this.dynamicColor[i],f.uniforms.contourTint=this.dynamicTint[i],f.uniforms.height=this.dynamicLevel[i],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(f.uniforms.model=u.projections[o],f.uniforms.clipBounds=u.clipBounds[o],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));h.unbind()}}S.draw=function(t){return O.call(this,t,!1)},S.drawTransparent=function(t){return O.call(this,t,!0)};var D={model:w,view:w,projection:w,inverseModel:w,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function R(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function F(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function B(t){if(Array.isArray(t)){if(Array.isArray(t))return[F(t[0]),F(t[1]),F(t[2])];var e=F(t);return[e.slice(),e.slice(),e.slice()]}}S.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=D;r.model=t.model||w,r.view=t.view||w,r.projection=t.projection||w,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=z;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=L(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=k[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=k[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},S.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var f=u?a:1-a,h=0;h<2;++h)for(var p=i+u,d=s+h,m=f*(h?l:1-l),v=0;v<3;++v)c[v]+=this._field[v].get(p,d)*m;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],v=0;v<3;++v)r.dataCoordinate[v]=this._field[v].get(r.index[0],r.index[1]);return r},S.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},S.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=R(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=R(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=R(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=B(t.contourColor)),\"contourProject\"in t&&(this.contourProject=R(t.contourProject,(function(t){return R(t,Boolean)}))),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=B(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=R(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=R(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0),\"colormap\"in t&&this._colorMap.setPixels(this.genColormap(t.colormap,this.opacityscale));var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=f(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var l=t.coords;if(!Array.isArray(l)||3!==l.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var c=l[o];for(v=0;v<2;++v)if(c.shape[v]!==a[v])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],c)}}else if(t.ticks){var u=t.ticks;if(!Array.isArray(u)||2!==u.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var p=u[o];if((Array.isArray(p)||p.length)&&(p=f(p)),p.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var d=f(p.data,a);d.stride[o]=p.stride[0],d.stride[1^o]=0,this.padField(this._field[o],d)}}else{for(o=0;o<2;++o){var g=[0,0];g[o]=1,this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2],g,0)}this._field[0].set(0,0,0);for(var v=0;v<a[0];++v)this._field[0].set(v+1,0,v);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),v=0;v<a[1];++v)this._field[1].set(0,v+1,v);this._field[1].set(0,a[1]+1,a[1]-1)}var y=this._field,x=f(s.mallocFloat(3*y[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)m(x.pick(o),y[o],\"mirror\");var b=f(s.mallocFloat(3*y[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(v=0;v<a[1]+2;++v){var _=x.get(0,o,v,0),w=x.get(0,o,v,1),k=x.get(1,o,v,0),M=x.get(1,o,v,1),A=x.get(2,o,v,0),S=x.get(2,o,v,1),E=k*S-M*A,C=A*w-S*_,L=_*M-w*k,I=Math.sqrt(E*E+C*C+L*L);I<1e-8?(I=Math.max(Math.abs(E),Math.abs(C),Math.abs(L)))<1e-8?(L=1,C=E=0,I=1):I=1/I:I=1/Math.sqrt(I),b.set(o,v,0,E*I),b.set(o,v,1,C*I),b.set(o,v,2,L*I)}s.free(x.data);var P=[1/0,1/0,1/0],z=[-1/0,-1/0,-1/0],O=1/0,D=-1/0,F=(a[0]-1)*(a[1]-1)*6,N=s.mallocFloat(n.nextPow2(10*F)),j=0,U=0;for(o=0;o<a[0]-1;++o)t:for(v=0;v<a[1]-1;++v){for(var V=0;V<2;++V)for(var q=0;q<2;++q)for(var H=0;H<3;++H){var G=this._field[H].get(1+o+V,1+v+q);if(isNaN(G)||!isFinite(G))continue t}for(H=0;H<6;++H){var Y=o+T[H][0],W=v+T[H][1],X=this._field[0].get(Y+1,W+1),Z=this._field[1].get(Y+1,W+1);G=this._field[2].get(Y+1,W+1),E=b.get(Y+1,W+1,0),C=b.get(Y+1,W+1,1),L=b.get(Y+1,W+1,2),t.intensity&&(J=t.intensity.get(Y,W));var J=t.intensity?t.intensity.get(Y,W):G+this.objectOffset[2];N[j++]=Y,N[j++]=W,N[j++]=X,N[j++]=Z,N[j++]=G,N[j++]=0,N[j++]=J,N[j++]=E,N[j++]=C,N[j++]=L,P[0]=Math.min(P[0],X+this.objectOffset[0]),P[1]=Math.min(P[1],Z+this.objectOffset[1]),P[2]=Math.min(P[2],G+this.objectOffset[2]),O=Math.min(O,J),z[0]=Math.max(z[0],X+this.objectOffset[0]),z[1]=Math.max(z[1],Z+this.objectOffset[1]),z[2]=Math.max(z[2],G+this.objectOffset[2]),D=Math.max(D,J),U+=1}}for(t.intensityBounds&&(O=+t.intensityBounds[0],D=+t.intensityBounds[1]),o=6;o<j;o+=10)N[o]=(N[o]-O)/(D-O);this._vertexCount=U,this._coordinateBuffer.update(N.subarray(0,j)),s.freeFloat(N),s.free(b.data),this.bounds=[P,z],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===O&&this.intensityBounds[1]===D||(r=!0),this.intensityBounds=[O,D]}if(\"levels\"in t){var K=t.levels;for(K=Array.isArray(K[0])?K.slice():[[],[],K],o=0;o<3;++o)K[o]=K[o].slice(),K[o].sort((function(t,e){return t-e}));for(o=0;o<3;++o)for(v=0;v<K[o].length;++v)K[o][v]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(K[o].length!==this.contourLevels[o].length){r=!0;break}for(v=0;v<K[o].length;++v)if(K[o][v]!==this.contourLevels[o][v]){r=!0;break t}}this.contourLevels=K}if(r){y=this._field,a=this.shape;for(var Q=[],$=0;$<3;++$){var tt=this.contourLevels[$],et=[],rt=[],nt=[0,0,0];for(o=0;o<tt.length;++o){var it=h(this._field[$],tt[o]);et.push(Q.length/5|0),U=0;t:for(v=0;v<it.cells.length;++v){var at=it.cells[v];for(H=0;H<2;++H){var ot=it.positions[at[H]],st=ot[0],lt=0|Math.floor(st),ct=st-lt,ut=ot[1],ft=0|Math.floor(ut),ht=ut-ft,pt=!1;e:for(var dt=0;dt<3;++dt){nt[dt]=0;var gt=($+dt+1)%3;for(V=0;V<2;++V){var mt=V?ct:1-ct;for(Y=0|Math.min(Math.max(lt+V,0),a[0]),q=0;q<2;++q){var vt=q?ht:1-ht;if(W=0|Math.min(Math.max(ft+q,0),a[1]),G=dt<2?this._field[gt].get(Y,W):(this.intensity.get(Y,W)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(G)||isNaN(G)){pt=!0;break e}var yt=mt*vt;nt[dt]+=yt*G}}}if(pt){if(H>0){for(var xt=0;xt<5;++xt)Q.pop();U-=1}continue t}Q.push(nt[0],nt[1],ot[0],ot[1],nt[2]),U+=1}}rt.push(U)}this._contourOffsets[$]=et,this._contourCounts[$]=rt}var bt=s.mallocFloat(Q.length);for(o=0;o<Q.length;++o)bt[o]=Q[o];this._contourBuffer.update(bt),s.freeFloat(bt)}},S.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},S.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],f=this._field[l],p=this._field[c],d=h(u,r[o]),g=d.cells,m=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var v=g[e],y=0;y<2;++y){var x=m[v[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),T=b-_,k=1-T,M=+x[1],A=0|M,S=0|Math.min(A+1,i[1]),E=M-A,C=1-E,L=k*C,I=k*E,P=T*C,z=T*E,O=L*f.get(_,A)+I*f.get(_,S)+P*f.get(w,A)+z*f.get(w,S),D=L*p.get(_,A)+I*p.get(_,S)+P*p.get(w,A)+z*p.get(w,S);if(isNaN(O)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=O,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":349,\"binary-search-bounds\":96,\"bit-twiddle\":97,colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495,\"ndarray-gradient\":488,\"ndarray-ops\":490,\"ndarray-pack\":491,\"surface-nets\":570,\"typedarray-pool\":595}],352:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),f=t(\"parse-rect\"),h=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),m=t(\"object-assign\"),v=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var T=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(h(t)?t:{})};T.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(T.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(T.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},T.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map((function(t){return parseFloat(t)})):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=f(t.viewport),T.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=T.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach((function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(T.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:T.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=T.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:v(c,{origin:\"top\",fontSize:T.baseFontSize,fontStyle:u.join(\" \")})},T.fonts[i]=e.font[r]}})),(a||o)&&this.font.forEach((function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)})),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),h=0;h<s.length;h++)s[h]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach((function(t,n){T.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=T.atlasContext.measureText(o).width/T.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);m(t.kerning,g(t.family,{pairs:s}))}}}))}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,k=u.mallocFloat(2*this.count),M=0,A=0;M<this.counts.length;M++){var S=this.counts[M];if(w)for(var E=0;E<S;E++)k[A++]=t.position[2*M],k[A++]=t.position[2*M+1];else for(var C=0;C<S;C++)k[A++]=t.position[M][0],k[A++]=t.position[M][1]}this.position.call?this.position({type:\"float\",data:k}):this.position=this.regl.buffer({type:\"float\",data:k}),u.freeFloat(k)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),I=u.mallocFloat(2*this.count);this.textWidth=[];for(var P=0,z=0;P<this.counts.length;P++){for(var O=this.counts[P],D=this.font[P]||this.font[0],R=this.fontAtlas[P]||this.fontAtlas[0],F=0;F<O;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],I[2*z]=D.width[B],F){var j=I[2*z-2],U=I[2*z],V=I[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}I[2*z+1]=V}else I[2*z+1]=.5*I[2*z];z++}this.textWidth.push(I.length?.5*I[2*z-2]+I[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:I,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(I),r.length&&this.font.forEach((function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(T.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:T.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})}))}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map((function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0}))),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map((function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],T.normalViewport||(i*=-1),i}))),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},T.prototype.destroy=function(){},T.prototype.kerning=!0,T.prototype.position={constant:new Float32Array(2)},T.prototype.translate=null,T.prototype.scale=null,T.prototype.font=null,T.prototype.text=\"\",T.prototype.positionOffset=[0,0],T.prototype.opacity=1,T.prototype.color=new Uint8Array([0,0,0,255]),T.prototype.alignOffset=[0,0],T.normalViewport=!1,T.maxAtlasSize=1024,T.atlasCanvas=document.createElement(\"canvas\"),T.atlasContext=T.atlasCanvas.getContext(\"2d\",{alpha:!1}),T.baseFontSize=64,T.fonts={},e.exports=T},{\"bit-twiddle\":97,\"color-normalize\":125,\"css-font\":144,\"detect-kerning\":172,\"es6-weak-map\":233,\"flatten-vertex-data\":244,\"font-atlas\":245,\"font-measure\":246,\"gl-util/context\":354,\"is-plain-obj\":469,\"object-assign\":499,\"parse-rect\":504,\"parse-unit\":506,\"pick-by-alias\":511,regl:540,\"to-px\":578,\"typedarray-pool\":595}],353:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||c(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=u(e)?e:e.raw;if(r)return y(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return x(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}function u(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var f=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function p(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var d=p.prototype;function g(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function m(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new p(t,o,e,r,n,i)}function y(t,e,r,n,i,a){var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new p(t,o,r,n,i,a)}function x(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=g(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var u,h,d=0;if(2===o.length)d=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])d=t.ALPHA;else if(2===o[2])d=t.LUMINANCE_ALPHA;else if(3===o[2])d=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");d=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var v=e.size;if(l)u=0===e.offset&&e.data.length===v?e.data:e.data.subarray(e.offset,e.offset+v);else{var y=[o[2],o[2]*o[0],1];h=a.malloc(v,r);var x=n(h,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):f(x,e),u=h.subarray(0,v)}var b=m(t);return t.texImage2D(t.TEXTURE_2D,0,d,o[0],o[1],0,d,c,u),l||a.free(h),new p(t,b,o[0],o[1],d,c)}Object.defineProperties(d,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),d.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},d.dispose=function(){this.gl.deleteTexture(this.handle)},d.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},d.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=u(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,u){var h=u.dtype,p=u.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var d=0,m=0,v=g(p,u.stride.slice());\"float32\"===h?d=t.FLOAT:\"float64\"===h?(d=t.FLOAT,v=!1,h=\"float32\"):\"uint8\"===h?d=t.UNSIGNED_BYTE:(d=t.UNSIGNED_BYTE,v=!1,h=\"uint8\");if(2===p.length)m=t.LUMINANCE,p=[p[0],p[1],1],u=n(u.data,p,[u.stride[0],u.stride[1],1],u.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])m=t.ALPHA;else if(2===p[2])m=t.LUMINANCE_ALPHA;else if(3===p[2])m=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");m=t.RGBA}p[2]}m!==t.LUMINANCE&&m!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(m=s);if(m!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=u.size,x=c.indexOf(o)<0;x&&c.push(o);if(d===l&&v)0===u.offset&&u.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data.subarray(u.offset,u.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data.subarray(u.offset,u.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);d===t.FLOAT&&l===t.UNSIGNED_BYTE?f(_,u):i.assign(_,u),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:495,\"ndarray-ops\":490,\"typedarray-pool\":595}],354:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":511}],355:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,f=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,f)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else{t.bindBuffer(t.ARRAY_BUFFER,null);for(i=0;i<n;++i)t.disableVertexAttribArray(i)}}},{}],356:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":355}],357:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":355}],358:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":356,\"./lib/vao-native.js\":357}],359:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],360:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":370,\"./fromValues\":376,\"./normalize\":387}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],363:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],364:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],365:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],366:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":367}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],368:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":369}],369:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],370:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],371:[function(t,e,r){e.exports=1e-6},{}],372:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":371}],373:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],374:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],375:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":364}],376:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],377:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":359,\"./angle\":360,\"./ceil\":361,\"./clone\":362,\"./copy\":363,\"./create\":364,\"./cross\":365,\"./dist\":366,\"./distance\":367,\"./div\":368,\"./divide\":369,\"./dot\":370,\"./epsilon\":371,\"./equals\":372,\"./exactEquals\":373,\"./floor\":374,\"./forEach\":375,\"./fromValues\":376,\"./inverse\":378,\"./len\":379,\"./length\":380,\"./lerp\":381,\"./max\":382,\"./min\":383,\"./mul\":384,\"./multiply\":385,\"./negate\":386,\"./normalize\":387,\"./random\":388,\"./rotateX\":389,\"./rotateY\":390,\"./rotateZ\":391,\"./round\":392,\"./scale\":393,\"./scaleAndAdd\":394,\"./set\":395,\"./sqrDist\":396,\"./sqrLen\":397,\"./squaredDistance\":398,\"./squaredLength\":399,\"./sub\":400,\"./subtract\":401,\"./transformMat3\":402,\"./transformMat4\":403,\"./transformQuat\":404}],378:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],379:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":380}],380:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],382:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],383:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],384:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":385}],385:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],386:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],387:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],388:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],389:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],390:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],391:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],392:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],393:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],395:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],396:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":398}],397:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":399}],398:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],399:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],400:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":401}],401:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],402:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],403:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],404:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t}},{}],405:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],406:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],407:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],408:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],409:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],410:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],411:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],412:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],413:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":405,\"./clone\":406,\"./copy\":407,\"./create\":408,\"./distance\":409,\"./divide\":410,\"./dot\":411,\"./fromValues\":412,\"./inverse\":414,\"./length\":415,\"./lerp\":416,\"./max\":417,\"./min\":418,\"./multiply\":419,\"./negate\":420,\"./normalize\":421,\"./random\":422,\"./scale\":423,\"./scaleAndAdd\":424,\"./set\":425,\"./squaredDistance\":426,\"./squaredLength\":427,\"./subtract\":428,\"./transformMat4\":429,\"./transformQuat\":430}],414:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],415:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],416:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],417:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],418:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],419:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],420:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],421:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],422:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":421,\"./scale\":423}],423:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],424:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],425:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],426:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],427:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],428:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],429:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],430:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t[3]=e[3],t}},{}],431:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":77,\"glsl-tokenizer\":438}],432:[function(t,e,r){e.exports=function(t){var e,r,c,u=0,f=0,h=999,p=[],d=[],g=1,m=0,v=0,y=!1,x=!1,b=\"\",_=a,w=n;\"300 es\"===(t=t||{}).version&&(_=s,w=o);var T={},k={};for(u=0;u<_.length;u++)T[_[u]]=!0;for(u=0;u<w.length;u++)k[w[u]]=!0;return function(t){return d=[],null!==t?function(t){u=0,t.toString&&(t=t.toString());var r;b+=t.replace(/\\r\\n/g,\"\\n\"),c=b.length;for(;e=b[u],u<c;){switch(r=u,h){case 0:u=C();break;case 1:case 2:u=E();break;case 3:u=L();break;case 4:u=z();break;case 11:u=P();break;case 5:u=O();break;case 9999:u=D();break;case 9:u=S();break;case 999:u=A()}if(r!==u)switch(b[r]){case\"\\n\":m=0,++g;break;default:++m}}return f+=u,b=b.slice(u),d}(t):function(t){p.length&&M(p.join(\"\"));return h=10,M(\"(eof)\"),d}()};function M(t){t.length&&d.push({type:l[h],data:t,position:v,line:g,column:m})}function A(){return p=p.length?[]:p,\"/\"===r&&\"*\"===e?(v=f+u-1,h=0,r=e,u+1):\"/\"===r&&\"/\"===e?(v=f+u-1,h=1,r=e,u+1):\"#\"===e?(h=2,v=f+u,u):/\\s/.test(e)?(h=9,v=f+u,u):(y=/\\d/.test(e),x=/[^\\w_]/.test(e),v=f+u,h=y?4:x?3:9999,u)}function S(){return/[^\\s]/g.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function E(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(p.push(e),r=e,u+1):(M(p.join(\"\")),h=999,u)}function C(){return\"/\"===e&&\"*\"===r?(p.push(e),M(p.join(\"\")),h=999,u+1):(p.push(e),r=e,u+1)}function L(){if(\".\"===r&&/\\d/.test(e))return h=5,u;if(\"/\"===r&&\"*\"===e)return h=0,u;if(\"/\"===r&&\"/\"===e)return h=1,u;if(\".\"===e&&p.length){for(;I(p););return h=5,u}if(\";\"===e||\")\"===e||\"(\"===e){if(p.length)for(;I(p););return M(e),h=999,u+1}var t=2===p.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;I(p););return h=999,u}return p.push(e),r=e,u+1}function I(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return M(r),v+=r.length,(p=p.slice(r.length)).length}}function P(){return/[^a-fA-F0-9]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function z(){return\".\"===e||/[eE]/.test(e)?(p.push(e),h=5,r=e,u+1):\"x\"===e&&1===p.length&&\"0\"===p[0]?(h=11,p.push(e),r=e,u+1):/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function O(){return\"f\"===e&&(p.push(e),r=e,u+=1),/[eE]/.test(e)?(p.push(e),r=e,u+1):(\"-\"!==e&&\"+\"!==e||!/[eE]/.test(r))&&/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function D(){if(/[^\\d\\w_]/.test(e)){var t=p.join(\"\");return h=k[t]?8:T[t]?7:6,M(p.join(\"\")),h=999,u}return p.push(e),r=e,u+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":434,\"./lib/builtins-300es\":433,\"./lib/literals\":436,\"./lib/literals-300es\":435,\"./lib/operators\":437}],433:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter((function(t){return!/^(gl\\_|texture)/.test(t)})),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":434}],434:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],435:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":436}],436:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"uint\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],437:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],438:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":432}],439:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],440:[function(t,e,r){(function(r){(function(){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":464}],441:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":464}],442:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],443:[function(t,e,r){\"use strict\";var n=t(\"./types\");e.exports=function(t,e){var r;for(r in n)if(n[r].detect(t,e))return r}},{\"./types\":446}],444:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"fs\"),i=t(\"path\"),a=t(\"./types\"),o=t(\"./detector\");function s(t,e){var r=o(t,e);if(r in a){var n=a[r].calculate(t,e);if(!1!==n)return n.type=r,n}throw new TypeError(\"unsupported file type: \"+r+\" (file: \"+e+\")\")}e.exports=function(t,e){if(r.isBuffer(t))return s(t);if(\"string\"!=typeof t)throw new TypeError(\"invalid invocation\");var a=i.resolve(t);if(\"function\"!=typeof e)return s(function(t){var e=n.openSync(t,\"r\"),i=n.fstatSync(e).size,a=Math.min(i,524288),o=r.alloc(a);return n.readSync(e,o,0,a,0),n.closeSync(e),o}(a),a);!function(t,e){n.open(t,\"r\",(function(i,a){if(i)return e(i);n.fstat(a,(function(i,o){if(i)return e(i);var s=o.size;if(s<=0)return e(new Error(\"File size is not greater than 0 \\u2014\\u2014 \"+t));var l=Math.min(s,524288),c=r.alloc(l);n.read(a,c,0,l,0,(function(t){if(t)return e(t);n.close(a,(function(t){e(t,c)}))}))}))}))}(a,(function(t,r){if(t)return e(t);var n;try{n=s(r,a)}catch(e){t=e}e(t,n)}))},e.exports.types=Object.keys(a)}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"./detector\":443,\"./types\":446,buffer:111,fs:109,path:507}],445:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){return r=r||0,t[\"readUInt\"+e+(n?\"BE\":\"LE\")].call(t,r)}},{}],446:[function(t,e,r){\"use strict\";var n={bmp:t(\"./types/bmp\"),cur:t(\"./types/cur\"),dds:t(\"./types/dds\"),gif:t(\"./types/gif\"),icns:t(\"./types/icns\"),ico:t(\"./types/ico\"),jpg:t(\"./types/jpg\"),png:t(\"./types/png\"),psd:t(\"./types/psd\"),svg:t(\"./types/svg\"),tiff:t(\"./types/tiff\"),webp:t(\"./types/webp\")};e.exports=n},{\"./types/bmp\":447,\"./types/cur\":448,\"./types/dds\":449,\"./types/gif\":450,\"./types/icns\":451,\"./types/ico\":452,\"./types/jpg\":453,\"./types/png\":454,\"./types/psd\":455,\"./types/svg\":456,\"./types/tiff\":457,\"./types/webp\":458}],447:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"BM\"===t.toString(\"ascii\",0,2)},calculate:function(t){return{width:t.readUInt32LE(18),height:Math.abs(t.readInt32LE(22))}}}},{}],448:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&2===t.readUInt16LE(2)},calculate:t(\"./ico\").calculate}},{\"./ico\":452}],449:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 542327876===t.readUInt32LE(0)},calculate:function(t){return{height:t.readUInt32LE(12),width:t.readUInt32LE(16)}}}},{}],450:[function(t,e,r){\"use strict\";var n=/^GIF8[79]a/;e.exports={detect:function(t){var e=t.toString(\"ascii\",0,6);return n.test(e)},calculate:function(t){return{width:t.readUInt16LE(6),height:t.readUInt16LE(8)}}}},{}],451:[function(t,e,r){\"use strict\";var n={ICON:32,\"ICN#\":32,\"icm#\":16,icm4:16,icm8:16,\"ics#\":16,ics4:16,ics8:16,is32:16,s8mk:16,icp4:16,icl4:32,icl8:32,il32:32,l8mk:32,icp5:32,ic11:32,ich4:48,ich8:48,ih32:48,h8mk:48,icp6:64,ic12:32,it32:128,t8mk:128,ic07:128,ic08:256,ic13:256,ic09:512,ic14:512,ic10:1024};function i(t,e){var r=e+4;return[t.toString(\"ascii\",e,r),t.readUInt32BE(r)]}function a(t){var e=n[t];return{width:e,height:e,type:t}}e.exports={detect:function(t){return\"icns\"===t.toString(\"ascii\",0,4)},calculate:function(t){var e,r,n,o=t.length,s=8,l=t.readUInt32BE(4);if(r=a((e=i(t,s))[0]),(s+=e[1])===l)return r;for(n={width:r.width,height:r.height,images:[r]};s<l&&s<o;)r=a((e=i(t,s))[0]),s+=e[1],n.images.push(r);return n}}},{}],452:[function(t,e,r){\"use strict\";function n(t,e){var r=t.readUInt8(e);return 0===r?256:r}function i(t,e){var r=6+16*e;return{width:n(t,r),height:n(t,r+1)}}e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&1===t.readUInt16LE(2)},calculate:function(t){var e,r=t.readUInt16LE(4),n=i(t,0);if(1===r)return n;for(n.images=[{width:n.width,height:n.height}],e=1;e<r;e+=1)n.images.push(i(t,e));return n}}},{}],453:[function(t,e,r){\"use strict\";var n=t(\"../readUInt\");function i(t){return\"45786966\"===t.toString(\"hex\",2,6)}function a(t,e){return{height:t.readUInt16BE(e),width:t.readUInt16BE(e+2)}}function o(t,e){var r=t.slice(2,e),i=r.toString(\"hex\",6,8),a=\"4d4d\"===i;if(a||\"4949\"===i)return function(t,e){for(var r,i,a=n(t,16,14,e),o=0;o<a;o++){if(i=(r=16+12*o)+12,r>t.length)return;var s=t.slice(r,i);if(274===n(s,16,0,e)){if(3!==n(s,16,2,e))return;if(1!==n(s,32,4,e))return;return n(s,16,8,e)}}}(r,a)}function s(t,e){if(e>t.length)throw new TypeError(\"Corrupt JPG, exceeded buffer limits\");if(255!==t[e])throw new TypeError(\"Invalid JPG, marker table corrupted\")}e.exports={detect:function(t){return\"ffd8\"===t.toString(\"hex\",0,2)},calculate:function(t){var e,r,n;for(t=t.slice(4);t.length;){if(r=t.readUInt16BE(0),i(t)&&(e=o(t,r)),s(t,r),192===(n=t[r+1])||193===n||194===n){var l=a(t,r+5);return e?{width:l.width,height:l.height,orientation:e}:l}t=t.slice(r+2)}throw new TypeError(\"Invalid JPG, no size found\")}}},{\"../readUInt\":445}],454:[function(t,e,r){\"use strict\";e.exports={detect:function(t){if(\"PNG\\r\\n\\x1a\\n\"===t.toString(\"ascii\",1,8)){var e=t.toString(\"ascii\",12,16);if(\"CgBI\"===e&&(e=t.toString(\"ascii\",28,32)),\"IHDR\"!==e)throw new TypeError(\"invalid png\");return!0}},calculate:function(t){return\"CgBI\"===t.toString(\"ascii\",12,16)?{width:t.readUInt32BE(32),height:t.readUInt32BE(36)}:{width:t.readUInt32BE(16),height:t.readUInt32BE(20)}}}},{}],455:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"8BPS\"===t.toString(\"ascii\",0,4)},calculate:function(t){return{width:t.readUInt32BE(18),height:t.readUInt32BE(14)}}}},{}],456:[function(t,e,r){\"use strict\";var n=/<svg\\s([^>\"']|\"[^\"]*\"|'[^']*')*>/;var i={root:n,width:/\\swidth=(['\"])([^%]+?)\\1/,height:/\\sheight=(['\"])([^%]+?)\\1/,viewbox:/\\sviewBox=(['\"])(.+?)\\1/},a={cm:96/2.54,mm:96/2.54/10,m:96/2.54*100,pt:96/72,pc:96/72/12,em:16,ex:8};function o(t){var e=/([0-9.]+)([a-z]*)/.exec(t);if(e)return Math.round(parseFloat(e[1])*(a[e[2]]||1))}function s(t){var e=t.split(\" \");return{width:o(e[2]),height:o(e[3])}}e.exports={detect:function(t){return n.test(t)},calculate:function(t){var e=t.toString(\"utf8\").match(i.root);if(e){var r=function(t){var e=t.match(i.width),r=t.match(i.height),n=t.match(i.viewbox);return{width:e&&o(e[2]),height:r&&o(r[2]),viewbox:n&&s(n[2])}}(e[0]);if(r.width&&r.height)return function(t){return{width:t.width,height:t.height}}(r);if(r.viewbox)return function(t){var e=t.viewbox.width/t.viewbox.height;return t.width?{width:t.width,height:Math.floor(t.width/e)}:t.height?{width:Math.floor(t.height*e),height:t.height}:{width:t.viewbox.width,height:t.viewbox.height}}(r)}throw new TypeError(\"invalid svg\")}}},{}],457:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"fs\"),i=t(\"../readUInt\");function a(t,e){var r=i(t,16,8,e);return(i(t,16,10,e)<<16)+r}function o(t){if(t.length>24)return t.slice(12)}e.exports={detect:function(t){var e=t.toString(\"hex\",0,4);return\"49492a00\"===e||\"4d4d002a\"===e},calculate:function(t,e){if(!e)throw new TypeError(\"Tiff doesn't support buffer\");var s=\"BE\"===function(t){var e=t.toString(\"ascii\",0,2);return\"II\"===e?\"LE\":\"MM\"===e?\"BE\":void 0}(t),l=function(t,e){for(var r,n,s,l={};t&&t.length&&(r=i(t,16,0,e),n=i(t,16,2,e),s=i(t,32,4,e),0!==r);)1!==s||3!==n&&4!==n||(l[r]=a(t,e)),t=o(t);return l}(function(t,e,a){var o=i(t,32,4,a),s=1024,l=n.statSync(e).size;o+s>l&&(s=l-o-10);var c=r.alloc(s),u=n.openSync(e,\"r\");return n.readSync(u,c,0,s,o),c.slice(2)}(t,e,s),s),c=l[256],u=l[257];if(!c||!u)throw new TypeError(\"Invalid Tiff, missing tags\");return{width:c,height:u}}}}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"../readUInt\":445,buffer:111,fs:109}],458:[function(t,e,r){\"use strict\";e.exports={detect:function(t){var e=\"RIFF\"===t.toString(\"ascii\",0,4),r=\"WEBP\"===t.toString(\"ascii\",8,12),n=\"VP8\"===t.toString(\"ascii\",12,15);return e&&r&&n},calculate:function(t){var e=t.toString(\"ascii\",12,16);if(t=t.slice(20,30),\"VP8X\"===e){var r=t[0];return!(!(0==(192&r))||!(0==(1&r)))&&function(t){return{width:1+t.readUIntLE(4,3),height:1+t.readUIntLE(7,3)}}(t)}if(\"VP8 \"===e&&47!==t[0])return function(t){return{width:16383&t.readInt16LE(6),height:16383&t.readInt16LE(8)}}(t);var n=t.toString(\"hex\",3,6);return\"VP8L\"===e&&\"9d012a\"!==n&&function(t){return{width:1+((63&t[2])<<8|t[1]),height:1+((15&t[4])<<10|t[3]<<2|(192&t[2])>>6)}}(t)}}},{}],459:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);var f=new a(l,new Array(i+1),!1),h=f.adjacent,p=new Array(i+2);for(u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var m=d[0];d[0]=d[1],d[1]=m;var v=new a(d,new Array(i+1),!0);h[u]=v,p[u]=v}p[i+1]=f;for(u=0;u<=i;++u){d=h[u].vertices;var y=h[u].adjacent;for(g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=f;else for(var b=0;b<=i;++b)h[b].vertices.indexOf(x)<0&&(y[g]=h[b])}}var _=new c(i,o,p),w=!!e;for(u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter((function(t){return!t.boundary})),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,f=0;f<=r;++f){var h=u[f];i[f]=h<0?e:a[h]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var f=c[u];if(!(f.lastVisited>=r)){var h=a[u];a[u]=t;var p=this.orient();if(a[u]=h,p<0){s=f;continue t}f.boundary?f.lastVisited=-r:f.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,f=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var h=[];f.length>0;){var p=(e=f.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var m=0;m<=n;++m)if(m!==g){var v=d[m];if(v.boundary&&!(v.lastVisited>=r)){var y=v.vertices;if(v.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,v.boundary=!1,c.push(v),f.push(v),v.lastVisited=r;continue}v.lastVisited=-r}var _=v.adjacent,w=p.slice(),T=d.slice(),k=new a(w,T,!0);u.push(k);var M=_.indexOf(e);if(!(M<0)){_[M]=k,T[g]=v,w[m]=-1,T[m]=e,d[m]=k,k.flip();for(b=0;b<=n;++b){var A=w[b];if(!(A<0||A===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}h.push(new o(S,k,b))}}}}}}h.sort(s);for(m=0;m+1<h.length;m+=2){var I=h[m],P=h[m+1],z=I.index,O=P.index;z<0||O<0||(I.cell.adjacent[I.index]=P.cell,P.cell.adjacent[P.index]=I.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var f=o[0];o[0]=o[1],o[1]=f}e.push(o)}}return e}},{\"robust-orientation\":548,\"simplicial-complex\":558}],460:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new v(null);return new v(m(t))};var a=i.prototype;function o(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function s(t,e){var r=m(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function l(t,e){var r=t.intervals([]);r.push(e),s(t,r)}function c(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?0:(r.splice(n,1),s(t,r),1)}function u(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function f(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function h(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function p(t,e){return t-e}function d(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function g(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function m(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(p);var n=e[e.length>>1],a=[],o=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?a.push(l):n<l[0]?o.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(d),u.sort(g),new i(n,m(a),m(o),c,u)}function v(t){this.root=t}a.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},a.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?l(this,t):this.left.insert(t):this.left=m([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?l(this,t):this.right.insert(t):this.right=m([t]);else{var r=n.ge(this.leftPoints,t,d),i=n.ge(this.rightPoints,t,g);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},a.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?c(this,t):2===(s=this.left.remove(t))?(this.left=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?c(this,t):2===(s=this.right.remove(t))?(this.right=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(1===this.count)return this.leftPoints[0]===t?2:0;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,i=this.left;i.right;)r=i,i=i.right;if(r===this)i.right=this.right;else{var a=this.left,s=this.right;r.count-=i.count,r.right=i.left,i.left=a,i.right=s}o(this,i),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?o(this,this.left):o(this,this.right);return 1}for(a=n.ge(this.leftPoints,t,d);a<this.leftPoints.length&&this.leftPoints[a][0]===t[0];++a)if(this.leftPoints[a]===t){this.count-=1,this.leftPoints.splice(a,1);for(s=n.ge(this.rightPoints,t,g);s<this.rightPoints.length&&this.rightPoints[s][1]===t[1];++s)if(this.rightPoints[s]===t)return this.rightPoints.splice(s,1),1}return 0},a.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return u(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return f(this.rightPoints,t,e)}return h(this.leftPoints,e)},a.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?u(this.leftPoints,e,r):t>this.mid?f(this.rightPoints,t,r):h(this.leftPoints,r)};var y=v.prototype;y.insert=function(t){this.root?this.root.insert(t):this.root=new i(t[0],null,null,[t],[t])},y.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),0!==e}return!1},y.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},y.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(y,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(y,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":461}],461:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],462:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],463:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],464:[function(t,e,r){e.exports=!0},{}],465:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}\n",
       "/*!\n",
       " * Determine if an object is a Buffer\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],466:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],467:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a,e.exports.default=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;if(e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"!=typeof e)return!1;var r=t.tablet?i.test(e):n.test(e);return!r&&t.tablet&&t.featureDetect&&navigator&&navigator.maxTouchPoints>1&&-1!==e.indexOf(\"Macintosh\")&&-1!==e.indexOf(\"Safari\")&&(r=!0),r}},{}],468:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],469:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],470:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],471:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],472:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],473:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():(t=t||self).mapboxgl=n()}(this,(function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,(function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[2]*this.x+t[3]*this.y;return this.x=t[0]*this.x+t[1]*this.y,this.y=e,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=r*this.x+e*this.y;return this.x=e*this.x-r*this.y,this.y=n,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=e.x+r*(this.x-e.x)-n*(this.y-e.y),this.y=i,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var s=o(.25,.1,.25,1);function l(t,e,r){return Math.min(r,Math.max(e,t))}function c(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function u(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function h(){return f++}function p(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function d(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function g(t,e){t.forEach((function(t){e[t]&&(e[t]=e[t].bind(e))}))}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function v(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function y(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function x(t){return Array.isArray(t)?t.map(x):\"object\"==typeof t&&t?v(t,x):t}var b={};function _(t){b[t]||(\"undefined\"!=typeof console&&console.warn(t),b[t]=!0)}function w(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)e+=((o=t[i]).x-(a=t[r]).x)*(a.y+o.y);return e}function k(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}function M(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,(function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"})),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}var A=null;function S(t){if(null==A){var e=t.navigator?t.navigator.userAgent:null;A=!!t.safari||!(!e||!(/\\b(iPad|iPhone|iPod)\\b/.test(e)||e.match(\"Safari\")&&!e.match(\"Chrome\")))}return A}function E(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var C,L,I,P,z=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),O=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,D=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,R={now:z,frame:function(t){var e=O(t);return{cancel:function(){return D(e)}}},getImageData:function(t,e){void 0===e&&(e=0);var r=self.document.createElement(\"canvas\"),n=r.getContext(\"2d\");if(!n)throw new Error(\"failed to create canvas 2d context\");return r.width=t.width,r.height=t.height,n.drawImage(t,0,0,t.width,t.height),n.getImageData(-e,-e,t.width+2*e,t.height+2*e)},resolveURL:function(t){return C||(C=self.document.createElement(\"a\")),C.href=t,C.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio},get prefersReducedMotion(){return!!self.matchMedia&&(null==L&&(L=self.matchMedia(\"(prefers-reduced-motion: reduce)\")),L.matches)}},F={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},B={supported:!1,testSupport:function(t){!N&&P&&(j?U(t):I=t)}},N=!1,j=!1;function U(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,P),t.isContextLost())return;B.supported=!0}catch(t){}t.deleteTexture(e),N=!0}self.document&&((P=self.document.createElement(\"img\")).onload=function(){I&&U(I),I=null,j=!0},P.onerror=function(){N=!0,I=null},P.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var V=\"01\",q=function(t,e){this._transformRequestFn=t,this._customAccessToken=e,this._createSkuToken()};function H(t){return 0===t.indexOf(\"mapbox:\")}q.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",V,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},q.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},q.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},q.prototype.normalizeStyleURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/styles/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeGlyphsURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/fonts/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSourceURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSpriteURL=function(t,e,r,n){var i=X(t);return H(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,this._makeAPIURL(i,this._customAccessToken||n)):(i.path+=\"\"+e+r,Z(i))},q.prototype.normalizeTileURL=function(t,e){if(this._isSkuTokenExpired()&&this._createSkuToken(),t&&!H(t))return t;var r=X(t);r.path=r.path.replace(/(\\.(png|jpg)\\d*)(?=$)/,(R.devicePixelRatio>=2||512===e?\"@2x\":\"\")+(B.supported?\".webp\":\"$1\")),r.path=r.path.replace(/^.+\\/v4\\//,\"/\"),r.path=\"/v4\"+r.path;var n=this._customAccessToken||function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e].match(/^access_token=(.*)$/);if(n)return n[1]}return null}(r.params)||F.ACCESS_TOKEN;return F.REQUIRE_ACCESS_TOKEN&&n&&this._skuToken&&r.params.push(\"sku=\"+this._skuToken),this._makeAPIURL(r,n)},q.prototype.canonicalizeTileURL=function(t,e){var r=X(t);if(!r.path.match(/(^\\/v4\\/)/)||!r.path.match(/\\.[\\w]+$/))return t;var n=\"mapbox://tiles/\";n+=r.path.replace(\"/v4/\",\"\");var i=r.params;return e&&(i=i.filter((function(t){return!t.match(/^access_token=/)}))),i.length&&(n+=\"?\"+i.join(\"&\")),n},q.prototype.canonicalizeTileset=function(t,e){for(var r=!!e&&H(e),n=[],i=0,a=t.tiles||[];i<a.length;i+=1){var o=a[i];Y(o)?n.push(this.canonicalizeTileURL(o,r)):n.push(o)}return n},q.prototype._makeAPIURL=function(t,e){var r=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\",n=X(F.API_URL);if(t.protocol=n.protocol,t.authority=n.authority,\"/\"!==n.path&&(t.path=\"\"+n.path+t.path),!F.REQUIRE_ACCESS_TOKEN)return Z(t);if(!(e=e||F.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+r);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+r);return t.params=t.params.filter((function(t){return-1===t.indexOf(\"access_token\")})),t.params.push(\"access_token=\"+e),Z(t)};var G=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function Y(t){return G.test(t)}var W=/^(\\w+):\\/\\/([^/?]*)(\\/[^?]+)?\\??(.+)?/;function X(t){var e=t.match(W);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function Z(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function J(t){if(!t)return null;var e=t.split(\".\");if(!e||3!==e.length)return null;try{return JSON.parse(decodeURIComponent(self.atob(e[1]).split(\"\").map((function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)})).join(\"\")))}catch(t){return null}}var K=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};K.prototype.getStorageKey=function(t){var e,r=J(F.ACCESS_TOKEN);return e=r&&r.u?self.btoa(encodeURIComponent(r.u).replace(/%([0-9A-F]{2})/g,(function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):F.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+e:\"mapbox.eventData:\"+e},K.prototype.fetchEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){_(\"Unable to read from LocalStorage\")}},K.prototype.saveEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){_(\"Unable to write to LocalStorage\")}},K.prototype.processRequests=function(t){},K.prototype.postEvent=function(t,e,r,n){var i=this;if(F.EVENTS_URL){var a=X(F.EVENTS_URL);a.params.push(\"access_token=\"+(n||F.ACCESS_TOKEN||\"\"));var o={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.10.1\",skuId:V,userId:this.anonId},s=e?u(o,e):o,l={url:Z(a),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([s])};this.pendingRequest=xt(l,(function(t){i.pendingRequest=null,r(t),i.saveEventData(),i.processRequests(n)}))}},K.prototype.queueRequest=function(t,e){this.queue.push(t),this.processRequests(e)};var Q,$,tt=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postMapLoadEvent=function(t,e,r,n){this.skuToken=r,(F.EVENTS_URL&&n||F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)})))&&this.queueRequest({id:e,timestamp:Date.now()},n)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){var r=this.queue.shift(),n=r.id,i=r.timestamp;n&&this.success[n]||(this.anonId||this.fetchEventData(),d(this.anonId)||(this.anonId=p()),this.postEvent(i,{skuToken:this.skuToken},(function(t){t||n&&(e.success[n]=!0)}),t))}},e}(K),et=new(function(t){function e(e){t.call(this,\"appUserTurnstile\"),this._customAccessToken=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postTurnstileEvent=function(t,e){F.EVENTS_URL&&F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)}))&&this.queueRequest(Date.now(),e)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var r=J(F.ACCESS_TOKEN),n=r?r.u:F.ACCESS_TOKEN,i=n!==this.eventData.tokenU;d(this.anonId)||(this.anonId=p(),i=!0);var a=this.queue.shift();if(this.eventData.lastSuccess){var o=new Date(this.eventData.lastSuccess),s=new Date(a),l=(a-this.eventData.lastSuccess)/864e5;i=i||l>=1||l<-1||o.getDate()!==s.getDate()}else i=!0;if(!i)return this.processRequests();this.postEvent(a,{\"enabled.telemetry\":!1},(function(t){t||(e.eventData.lastSuccess=a,e.eventData.tokenU=n)}),t)}},e}(K)),rt=et.postTurnstileEvent.bind(et),nt=new tt,it=nt.postMapLoadEvent.bind(nt),at=500,ot=50;function st(){self.caches&&!Q&&(Q=self.caches.open(\"mapbox-tiles\"))}function lt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var ct,ut=1/0;function ft(){return null==ct&&(ct=self.OffscreenCanvas&&new self.OffscreenCanvas(1,1).getContext(\"2d\")&&\"function\"==typeof self.createImageBitmap),ct}var ht={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(ht);var pt,dt,gt=function(t){function e(e,r,n){401===r&&Y(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error),mt=k()?function(){return self.worker&&self.worker.referrer}:function(){return(\"blob:\"===self.location.protocol?self.parent:self).location.href},vt=function(t,e){if(!(/^file:/.test(r=t.url)||/^file:/.test(mt())&&!/^\\w+:/.test(r))){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return function(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:mt(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&Y(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&_(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then((function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new gt(r.statusText,r.status,t.url))})).catch((function(t){20!==t.code&&e(new Error(t.message))}))}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then((function(t){o||(n&&s&&function(t,e,r){if(st(),Q){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach((function(t,e){return n.headers.set(e,t)}));var i=M(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<42e4||function(t,e){if(void 0===$)try{new Response(new ReadableStream),$=!0}catch(t){$=!1}$?e(t.body):t.blob().then(e)}(e,(function(e){var r=new self.Response(e,n);st(),Q&&Q.then((function(e){return e.put(lt(t.url),r)})).catch((function(t){return _(t.message)}))})))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))})).catch((function(t){o||e(new Error(t.message))}))};return s?function(t,e){if(st(),!Q)return e(null);var r=lt(t.url);Q.then((function(t){t.match(r).then((function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")||0),r=M(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})).catch(e)})).catch(e)}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}(t,e);if(k()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e,void 0,!0)}var r;return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&(r.responseType=\"text\",r.setRequestHeader(\"Accept\",\"application/json\")),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new gt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},yt=function(t,e){return vt(u(t,{type:\"arrayBuffer\"}),e)},xt=function(t,e){return vt(u(t,{method:\"POST\"}),e)};pt=[],dt=0;var bt=function(t,e){if(B.supported&&(t.headers||(t.headers={}),t.headers.accept=\"image/webp,*/*\"),dt>=F.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return pt.push(r),r}dt++;var n=!1,i=function(){if(!n)for(n=!0,dt--;pt.length&&dt<F.MAX_PARALLEL_IMAGE_REQUESTS;){var t=pt.shift();t.cancelled||(t.cancel=bt(t.requestParameters,t.callback).cancel)}},a=yt(t,(function(t,r,n,a){i(),t?e(t):r&&(ft()?function(t,e){var r=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});self.createImageBitmap(r).then((function(t){e(null,t)})).catch((function(t){e(new Error(\"Could not load image because of \"+t.message+\". Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))}))}(r,e):function(t,e,r,n){var i=new self.Image,a=self.URL;i.onload=function(){e(null,i),a.revokeObjectURL(i.src)},i.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var o=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});i.cacheControl=r,i.expires=n,i.src=t.byteLength?a.createObjectURL(o):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}(r,e,n,a))}));return{cancel:function(){a.cancel(),i()}}};function _t(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function wt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Tt=function(t,e){void 0===e&&(e={}),u(this,e),this.type=t},kt=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",u({error:e},r))}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Tt),Mt=function(){};Mt.prototype.on=function(t,e){return this._listeners=this._listeners||{},_t(t,e,this._listeners),this},Mt.prototype.off=function(t,e){return wt(t,e,this._listeners),wt(t,e,this._oneTimeListeners),this},Mt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},_t(t,e,this._oneTimeListeners),this},Mt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Tt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];wt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(u(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof kt&&console.error(t.error);return this},Mt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},Mt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var At={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},promoteId:{type:\"promoteId\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1},promoteId:{type:\"promoteId\"}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{\"fill-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{\"circle-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"resolvedImage\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[\"text-field\"],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"text-field\",{\"!\":\"text-variable-anchor\"}],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-writing-mode\":{type:\"array\",value:\"enum\",values:{horizontal:{},vertical:{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{},within:{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:24,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},in:{group:\"Lookup\"},\"index-of\":{group:\"Lookup\"},slice:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},image:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},distance:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},within:{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,overridable:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}},promoteId:{\"*\":{type:\"string\"}}},St=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Et(t){var e=t.value;return e?[new St(t.key,e,\"constants have been deprecated as of v8\")]:[]}function Ct(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Lt(t){return t instanceof Number||t instanceof String||t instanceof Boolean?t.valueOf():t}function It(t){if(Array.isArray(t))return t.map(It);if(t instanceof Object&&!(t instanceof Number||t instanceof String||t instanceof Boolean)){var e={};for(var r in t)e[r]=It(t[r]);return e}return Lt(t)}var Pt=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Error),zt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r];this.bindings[i[0]]=i[1]}};zt.prototype.concat=function(t){return new zt(this,t)},zt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},zt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var Ot={kind:\"null\"},Dt={kind:\"number\"},Rt={kind:\"string\"},Ft={kind:\"boolean\"},Bt={kind:\"color\"},Nt={kind:\"object\"},jt={kind:\"value\"},Ut={kind:\"collator\"},Vt={kind:\"formatted\"},qt={kind:\"resolvedImage\"};function Ht(t,e){return{kind:\"array\",itemType:t,N:e}}function Gt(t){if(\"array\"===t.kind){var e=Gt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var Yt=[Ot,Dt,Rt,Ft,Bt,Vt,Nt,Ht(jt),qt];function Wt(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!Wt(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=Yt;r<n.length;r+=1)if(!Wt(n[r],e))return null}return\"Expected \"+Gt(t)+\" but found \"+Gt(e)+\" instead.\"}function Xt(t,e){return e.some((function(e){return e.kind===t.kind}))}function Zt(t,e){return e.some((function(e){return\"null\"===e?null===t:\"array\"===e?Array.isArray(t):\"object\"===e?t&&!Array.isArray(t)&&\"object\"==typeof t:e===typeof t}))}var Jt=e((function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return n(\"%\"===t[t.length-1]?parseFloat(t)/100*255:parseInt(t))}function a(t){return(e=\"%\"===t[t.length-1]?parseFloat(t)/100:parseFloat(t))<0?0:e>1?1:e;var e}function o(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,s=t.replace(/ /g,\"\").toLowerCase();if(s in r)return r[s].slice();if(\"#\"===s[0])return 4===s.length?(e=parseInt(s.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===s.length&&(e=parseInt(s.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=s.indexOf(\"(\"),c=s.indexOf(\")\");if(-1!==l&&c+1===s.length){var u=s.substr(0,l),f=s.substr(l+1,c-(l+1)).split(\",\"),h=1;switch(u){case\"rgba\":if(4!==f.length)return null;h=a(f.pop());case\"rgb\":return 3!==f.length?null:[i(f[0]),i(f[1]),i(f[2]),h];case\"hsla\":if(4!==f.length)return null;h=a(f.pop());case\"hsl\":if(3!==f.length)return null;var p=(parseFloat(f[0])%360+360)%360/360,d=a(f[1]),g=a(f[2]),m=g<=.5?g*(d+1):g+d-g*d,v=2*g-m;return[n(255*o(v,m,p+1/3)),n(255*o(v,m,p)),n(255*o(v,m,p-1/3)),h];default:return null}}return null}}catch(t){}})).parseCSSColor,Kt=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};Kt.parse=function(t){if(t){if(t instanceof Kt)return t;if(\"string\"==typeof t){var e=Jt(t);if(e)return new Kt(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},Kt.prototype.toString=function(){var t=this.toArray(),e=t[1],r=t[2],n=t[3];return\"rgba(\"+Math.round(t[0])+\",\"+Math.round(e)+\",\"+Math.round(r)+\",\"+n+\")\"},Kt.prototype.toArray=function(){var t=this.a;return 0===t?[0,0,0,0]:[255*this.r/t,255*this.g/t,255*this.b/t,t]},Kt.black=new Kt(0,0,0,1),Kt.white=new Kt(1,1,1,1),Kt.transparent=new Kt(0,0,0,0),Kt.red=new Kt(1,0,0,1);var Qt=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};Qt.prototype.compare=function(t,e){return this.collator.compare(t,e)},Qt.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var $t=function(t,e,r,n,i){this.text=t,this.image=e,this.scale=r,this.fontStack=n,this.textColor=i},te=function(t){this.sections=t};te.fromString=function(t){return new te([new $t(t,null,null,null,null)])},te.prototype.isEmpty=function(){return 0===this.sections.length||!this.sections.some((function(t){return 0!==t.text.length||t.image&&0!==t.image.name.length}))},te.factory=function(t){return t instanceof te?t:te.fromString(t)},te.prototype.toString=function(){return 0===this.sections.length?\"\":this.sections.map((function(t){return t.text})).join(\"\")},te.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];if(n.image)t.push([\"image\",n.image.name]);else{t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),n.textColor&&(i[\"text-color\"]=[\"rgba\"].concat(n.textColor.toArray())),t.push(i)}}return t};var ee=function(t){this.name=t.name,this.available=t.available};function re(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function ne(t){if(null===t)return!0;if(\"string\"==typeof t)return!0;if(\"boolean\"==typeof t)return!0;if(\"number\"==typeof t)return!0;if(t instanceof Kt)return!0;if(t instanceof Qt)return!0;if(t instanceof te)return!0;if(t instanceof ee)return!0;if(Array.isArray(t)){for(var e=0,r=t;e<r.length;e+=1)if(!ne(r[e]))return!1;return!0}if(\"object\"==typeof t){for(var n in t)if(!ne(t[n]))return!1;return!0}return!1}function ie(t){if(null===t)return Ot;if(\"string\"==typeof t)return Rt;if(\"boolean\"==typeof t)return Ft;if(\"number\"==typeof t)return Dt;if(t instanceof Kt)return Bt;if(t instanceof Qt)return Ut;if(t instanceof te)return Vt;if(t instanceof ee)return qt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=ie(i[n]);if(e){if(e===a)continue;e=jt;break}e=a}return Ht(e||jt,r)}return Nt}function ae(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof Kt||t instanceof te||t instanceof ee?t.toString():JSON.stringify(t)}ee.prototype.toString=function(){return this.name},ee.fromString=function(t){return t?new ee({name:t,available:!1}):null},ee.prototype.serialize=function(){return[\"image\",this.name]};var oe=function(t,e){this.type=t,this.value=e};oe.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!ne(t[1]))return e.error(\"invalid value\");var r=t[1],n=ie(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new oe(n,r)},oe.prototype.evaluate=function(){return this.value},oe.prototype.eachChild=function(){},oe.prototype.outputDefined=function(){return!0},oe.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof Kt?[\"rgba\"].concat(this.value.toArray()):this.value instanceof te?this.value.serialize():this.value};var se=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};se.prototype.toJSON=function(){return this.message};var le={string:Rt,number:Dt,boolean:Ft,object:Nt},ce=function(t,e){this.type=t,this.args=e};ce.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in le)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=le[s],n++}else a=jt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=Ht(a,o)}else r=le[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,jt);if(!c)return null;l.push(c)}return new ce(r,l)},ce.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!Wt(this.type,ie(r)))return r;if(e===this.args.length-1)throw new se(\"Expected value to be of type \"+Gt(this.type)+\", but found \"+Gt(ie(r))+\" instead.\")}return null},ce.prototype.eachChild=function(t){this.args.forEach(t)},ce.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ce.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map((function(t){return t.serialize()})))};var ue=function(t){this.type=Vt,this.sections=t};ue.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[1];if(!Array.isArray(r)&&\"object\"==typeof r)return e.error(\"First argument must be an image or text section.\");for(var n=[],i=!1,a=1;a<=t.length-1;++a){var o=t[a];if(i&&\"object\"==typeof o&&!Array.isArray(o)){i=!1;var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Dt)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,Ht(Rt))))return null;var c=null;if(o[\"text-color\"]&&!(c=e.parse(o[\"text-color\"],1,Bt)))return null;var u=n[n.length-1];u.scale=s,u.font=l,u.textColor=c}else{var f=e.parse(t[a],1,jt);if(!f)return null;var h=f.type.kind;if(\"string\"!==h&&\"value\"!==h&&\"null\"!==h&&\"resolvedImage\"!==h)return e.error(\"Formatted text type must be 'string', 'value', 'image' or 'null'.\");i=!0,n.push({content:f,scale:null,font:null,textColor:null})}}return new ue(n)},ue.prototype.evaluate=function(t){return new te(this.sections.map((function(e){var r=e.content.evaluate(t);return ie(r)===qt?new $t(\"\",r,null,null,null):new $t(ae(r),null,e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null,e.textColor?e.textColor.evaluate(t):null)})))},ue.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.content),n.scale&&t(n.scale),n.font&&t(n.font),n.textColor&&t(n.textColor)}},ue.prototype.outputDefined=function(){return!1},ue.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.content.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),n.textColor&&(i[\"text-color\"]=n.textColor.serialize()),t.push(i)}return t};var fe=function(t){this.type=qt,this.input=t};fe.parse=function(t,e){if(2!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Rt);return r?new fe(r):e.error(\"No image name provided.\")},fe.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=ee.fromString(e);return r&&t.availableImages&&(r.available=t.availableImages.indexOf(e)>-1),r},fe.prototype.eachChild=function(t){t(this.input)},fe.prototype.outputDefined=function(){return!1},fe.prototype.serialize=function(){return[\"image\",this.input.serialize()]};var he={\"to-boolean\":Ft,\"to-color\":Bt,\"to-number\":Dt,\"to-string\":Rt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=he[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,jt);if(!o)return null;i.push(o)}return new pe(n,i)},pe.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof Kt)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":re(e[0],e[1],e[2],e[3])))return new Kt(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new se(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new se(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?te.fromString(ae(this.args[0].evaluate(t))):\"resolvedImage\"===this.type.kind?ee.fromString(ae(this.args[0].evaluate(t))):ae(this.args[0].evaluate(t))},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},pe.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new ue([{content:this.args[0],scale:null,font:null,textColor:null}]).serialize();if(\"resolvedImage\"===this.type.kind)return new fe(this.args[0]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild((function(e){t.push(e.serialize())})),t};var de=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ge=function(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={},this.availableImages=null,this.canonical=null};ge.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ge.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?de[this.feature.type]:this.feature.type:null},ge.prototype.geometry=function(){return this.feature&&\"geometry\"in this.feature?this.feature.geometry:null},ge.prototype.canonicalID=function(){return this.canonical},ge.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ge.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=Kt.parse(t)),e};var me=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};me.prototype.evaluate=function(t){return this._evaluate(t,this.args)},me.prototype.eachChild=function(t){this.args.forEach(t)},me.prototype.outputDefined=function(){return!1},me.prototype.serialize=function(){return[this.name].concat(this.args.map((function(t){return t.serialize()})))},me.parse=function(t,e){var r,n=t[0],i=me.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter((function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1})),l=null,c=0,u=s;c<u.length;c+=1){var f=u[c],h=f[0],p=f[1];l=new Be(e.registry,e.path,null,e.scope);for(var d=[],g=!1,m=1;m<t.length;m++){var v=t[m],y=Array.isArray(h)?h[m-1]:h.type,x=l.parse(v,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(h)&&h.length!==d.length)l.error(\"Expected \"+h.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(h)?h[b]:h.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new me(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var T=(s.length?s:o).map((function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Gt).join(\", \")+\")\":\"(\"+Gt(e.type)+\"...)\"})).join(\" | \"),k=[],M=1;M<t.length;M++){var A=e.parse(t[M],1+k.length);if(!A)return null;k.push(Gt(A.type))}e.error(\"Expected arguments of type \"+T+\", but found (\"+k.join(\", \")+\") instead.\")}return null},me.register=function(t,e){for(var r in me.definitions=e,e)t[r]=me};var ve=function(t,e,r){this.type=Ut,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function ye(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.min(t[1],e[1]),t[2]=Math.max(t[2],e[0]),t[3]=Math.max(t[3],e[1])}function xe(t,e){return!(t[0]<=e[0]||t[2]>=e[2]||t[1]<=e[1]||t[3]>=e[3])}function be(t,e){var r=(180+t[0])/360,n=(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t[1]*Math.PI/360)))/360,i=Math.pow(2,e.z);return[Math.round(r*i*8192),Math.round(n*i*8192)]}function _e(t,e,r){return e[1]>t[1]!=r[1]>t[1]&&t[0]<(r[0]-e[0])*(t[1]-e[1])/(r[1]-e[1])+e[0]}function we(t,e){for(var r,n,i,a,o,s,l,c=!1,u=0,f=e.length;u<f;u++)for(var h=e[u],p=0,d=h.length;p<d-1;p++){if((a=(r=t)[0]-(n=h[p])[0])*(l=r[1]-(i=h[p+1])[1])-(s=r[0]-i[0])*(o=r[1]-n[1])==0&&a*s<=0&&o*l<=0)return!1;_e(t,h[p],h[p+1])&&(c=!c)}return c}function Te(t,e){for(var r=0;r<e.length;r++)if(we(t,e[r]))return!0;return!1}function ke(t,e,r,n){var i=n[0]-r[0],a=n[1]-r[1],o=(t[0]-r[0])*a-i*(t[1]-r[1]),s=(e[0]-r[0])*a-i*(e[1]-r[1]);return o>0&&s<0||o<0&&s>0}function Me(t,e,r){for(var n=0,i=r;n<i.length;n+=1)for(var a=i[n],o=0;o<a.length-1;++o)if(0!=(f=[(u=a[o+1])[0]-(c=a[o])[0],u[1]-c[1]])[0]*(h=[(l=e)[0]-(s=t)[0],l[1]-s[1]])[1]-f[1]*h[0]&&ke(s,l,c,u)&&ke(c,u,s,l))return!0;var s,l,c,u,f,h;return!1}function Ae(t,e){for(var r=0;r<t.length;++r)if(!we(t[r],e))return!1;for(var n=0;n<t.length-1;++n)if(Me(t[n],t[n+1],e))return!1;return!0}function Se(t,e){for(var r=0;r<e.length;r++)if(Ae(t,e[r]))return!0;return!1}function Ee(t,e,r){for(var n=[],i=0;i<t.length;i++){for(var a=[],o=0;o<t[i].length;o++){var s=be(t[i][o],r);ye(e,s),a.push(s)}n.push(a)}return n}function Ce(t,e,r){for(var n=[],i=0;i<t.length;i++){var a=Ee(t[i],e,r);n.push(a)}return n}function Le(t,e,r,n){if(t[0]<r[0]||t[0]>r[2]){var i=.5*n,a=t[0]-r[0]>i?-n:r[0]-t[0]>i?n:0;0===a&&(a=t[0]-r[2]>i?-n:r[2]-t[0]>i?n:0),t[0]+=a}ye(e,t)}function Ie(t,e,r,n){for(var i=8192*Math.pow(2,n.z),a=[8192*n.x,8192*n.y],o=[],s=0,l=t;s<l.length;s+=1)for(var c=0,u=l[s];c<u.length;c+=1){var f=u[c],h=[f.x+a[0],f.y+a[1]];Le(h,e,r,i),o.push(h)}return o}function Pe(t,e,r,n){for(var i,a=8192*Math.pow(2,n.z),o=[8192*n.x,8192*n.y],s=[],l=0,c=t;l<c.length;l+=1){for(var u=[],f=0,h=c[l];f<h.length;f+=1){var p=h[f],d=[p.x+o[0],p.y+o[1]];ye(e,d),u.push(d)}s.push(u)}if(e[2]-e[0]<=a/2){(i=e)[0]=i[1]=1/0,i[2]=i[3]=-1/0;for(var g=0,m=s;g<m.length;g+=1)for(var v=0,y=m[g];v<y.length;v+=1)Le(y[v],e,r,a)}return s}ve.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Ft);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Ft);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Rt))?null:new ve(n,i,a)},ve.prototype.evaluate=function(t){return new Qt(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},ve.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},ve.prototype.outputDefined=function(){return!1},ve.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var ze=function(t,e){this.type=Ft,this.geojson=t,this.geometries=e};function Oe(t){if(t instanceof me){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}if(t instanceof ze)return!1;var e=!0;return t.eachChild((function(t){e&&!Oe(t)&&(e=!1)})),e}function De(t){if(t instanceof me&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild((function(t){e&&!De(t)&&(e=!1)})),e}function Re(t,e){if(t instanceof me&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild((function(t){r&&!Re(t,e)&&(r=!1)})),r}ze.parse=function(t,e){if(2!==t.length)return e.error(\"'within' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(ne(t[1])){var r=t[1];if(\"FeatureCollection\"===r.type)for(var n=0;n<r.features.length;++n){var i=r.features[n].geometry.type;if(\"Polygon\"===i||\"MultiPolygon\"===i)return new ze(r,r.features[n].geometry)}else if(\"Feature\"===r.type){var a=r.geometry.type;if(\"Polygon\"===a||\"MultiPolygon\"===a)return new ze(r,r.geometry)}else if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type)return new ze(r,r)}return e.error(\"'within' expression requires valid geojson object that contains polygon geometry type.\")},ze.prototype.evaluate=function(t){if(null!=t.geometry()&&null!=t.canonicalID()){if(\"Point\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ee(e.coordinates,n,i),o=Ie(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!we(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,i),u=Ie(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1)if(!Te(h[f],c))return!1}return!0}(t,this.geometries);if(\"LineString\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ee(e.coordinates,n,i),o=Pe(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!Ae(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,i),u=Pe(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1)if(!Se(h[f],c))return!1}return!0}(t,this.geometries)}return!1},ze.prototype.eachChild=function(){},ze.prototype.outputDefined=function(){return!0},ze.prototype.serialize=function(){return[\"within\",this.geojson]};var Fe=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Fe.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Fe(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Fe.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Fe.prototype.eachChild=function(){},Fe.prototype.outputDefined=function(){return!1},Fe.prototype.serialize=function(){return[\"var\",this.name]};var Be=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new zt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map((function(t){return\"[\"+t+\"]\"})).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Ne(t,e){for(var r,n=t.length-1,i=0,a=n,o=0;i<=a;)if((r=t[o=Math.floor((i+a)/2)])<=e){if(o===n||e<t[o+1])return o;i=o+1}else{if(!(r>e))throw new se(\"Input is not a number.\");a=o-1}return 0}Be.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Be.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new ce(e,[t]):\"coerce\"===r?new pe(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind&&\"resolvedImage\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof oe)&&\"resolvedImage\"!==a.type.kind&&function t(e){if(e instanceof Fe)return t(e.boundExpression);if(e instanceof me&&\"error\"===e.name)return!1;if(e instanceof ve)return!1;if(e instanceof ze)return!1;var r=e instanceof pe||e instanceof ce,n=!0;return e.eachChild((function(e){n=r?n&&t(e):n&&e instanceof oe})),!!n&&Oe(e)&&Re(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"])}(a)){var l=new ge;try{a=new oe(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return this.error(void 0===t?\"'undefined' value invalid. Use null instead.\":\"object\"==typeof t?'Bare objects invalid. Use [\"literal\", {...}] instead.':\"Expected an array, but found \"+typeof t+\" instead.\")},Be.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Be(this.registry,n,e||null,i,this.errors)},Be.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map((function(t){return\"[\"+t+\"]\"})).join(\"\");this.errors.push(new Pt(n,t))},Be.prototype.checkSubtype=function(t,e){var r=Wt(t,e);return r&&this.error(r),r};var je=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[1];this.labels.push(a[0]),this.outputs.push(o)}};function Ue(t,e,r){return t*(1-r)+e*r}je.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new je(i,r,n)},je.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Ne(e,n)].evaluate(t)},je.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},je.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},je.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ve=Object.freeze({__proto__:null,number:Ue,color:function(t,e,r){return new Kt(Ue(t.r,e.r,r),Ue(t.g,e.g,r),Ue(t.b,e.b,r),Ue(t.a,e.a,r))},array:function(t,e,r){return t.map((function(t,n){return Ue(t,e[n],r)}))}}),qe=6/29*3*(6/29),He=Math.PI/180,Ge=180/Math.PI;function Ye(t){return t>.008856451679035631?Math.pow(t,1/3):t/qe+4/29}function We(t){return t>6/29?t*t*t:qe*(t-4/29)}function Xe(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ze(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function Je(t){var e=Ze(t.r),r=Ze(t.g),n=Ze(t.b),i=Ye((.4124564*e+.3575761*r+.1804375*n)/.95047),a=Ye((.2126729*e+.7151522*r+.072175*n)/1);return{l:116*a-16,a:500*(i-a),b:200*(a-Ye((.0193339*e+.119192*r+.9503041*n)/1.08883)),alpha:t.a}}function Ke(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=1*We(e),r=.95047*We(r),n=1.08883*We(n),new Kt(Xe(3.2404542*r-1.5371385*e-.4985314*n),Xe(-.969266*r+1.8760108*e+.041556*n),Xe(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}function Qe(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}var $e={forward:Je,reverse:Ke,interpolate:function(t,e,r){return{l:Ue(t.l,e.l,r),a:Ue(t.a,e.a,r),b:Ue(t.b,e.b,r),alpha:Ue(t.alpha,e.alpha,r)}}},tr={forward:function(t){var e=Je(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Ge;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*He,r=t.c;return Ke({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:Qe(t.h,e.h,r),c:Ue(t.c,e.c,r),l:Ue(t.l,e.l,r),alpha:Ue(t.alpha,e.alpha,r)}}},er=Object.freeze({__proto__:null,lab:$e,hcl:tr}),rr=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[1];this.labels.push(s[0]),this.outputs.push(l)}};function nr(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}rr.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=nr(e,t.base,n,i);else if(\"linear\"===t.name)a=nr(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(nr(e,1,n,i))}return a},rr.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some((function(t){return\"number\"!=typeof t||t<0||t>1})))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Dt)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Bt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var f=a[u],h=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof f)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=f)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(h,d,c);if(!g)return null;c=c||g.type,l.push([f,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new rr(c,r,n,i,l):e.error(\"Type \"+Gt(c)+\" is not interpolatable.\")},rr.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Ne(e,n),o=rr.interpolationFactor(this.interpolation,n,e[a],e[a+1]),s=r[a].evaluate(t),l=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ve[this.type.kind.toLowerCase()](s,l,o):\"interpolate-hcl\"===this.operator?tr.reverse(tr.interpolate(tr.forward(s),tr.forward(l),o)):$e.reverse($e.interpolate($e.forward(s),$e.forward(l),o))},rr.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},rr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},rr.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var ir=function(t,e){this.type=t,this.args=e};ir.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=e.parse(o[a],1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!s)return null;r=r||s.type,i.push(s)}var l=n&&i.some((function(t){return Wt(n,t.type)}));return new ir(l?jt:r,i)},ir.prototype.evaluate=function(t){for(var e,r=null,n=0,i=0,a=this.args;i<a.length&&(n++,(r=a[i].evaluate(t))&&r instanceof ee&&!r.available&&(e||(e=r.name),r=null,n===this.args.length&&(r=e)),null===r);i+=1);return r},ir.prototype.eachChild=function(t){this.args.forEach(t)},ir.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ir.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var ar=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};ar.prototype.evaluate=function(t){return this.result.evaluate(t)},ar.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},ar.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new ar(r,o):null},ar.prototype.outputDefined=function(){return this.result.outputDefined()},ar.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e];t.push(n[0],n[1].serialize())}return t.push(this.result.serialize()),t};var or=function(t,e,r){this.type=t,this.index=e,this.input=r};or.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Dt),n=e.parse(t[2],2,Ht(e.expectedType||jt));return r&&n?new or(n.type.itemType,r,n):null},or.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new se(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new se(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new se(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},or.prototype.eachChild=function(t){t(this.index),t(this.input)},or.prototype.outputDefined=function(){return!1},or.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var sr=function(t,e){this.type=Ft,this.needle=t,this.haystack=e};sr.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);return r&&n?Xt(r.type,[Ft,Rt,Dt,Ot,jt])?new sr(r,n):e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\"):null},sr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!r)return!1;if(!Zt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ie(e))+\" instead.\");if(!Zt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ie(r))+\" instead.\");return r.indexOf(e)>=0},sr.prototype.eachChild=function(t){t(this.needle),t(this.haystack)},sr.prototype.outputDefined=function(){return!0},sr.prototype.serialize=function(){return[\"in\",this.needle.serialize(),this.haystack.serialize()]};var lr=function(t,e,r){this.type=Dt,this.needle=t,this.haystack=e,this.fromIndex=r};lr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);if(!r||!n)return null;if(!Xt(r.type,[Ft,Rt,Dt,Ot,jt]))return e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Dt);return i?new lr(r,n,i):null}return new lr(r,n)},lr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!Zt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ie(e))+\" instead.\");if(!Zt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ie(r))+\" instead.\");if(this.fromIndex){var n=this.fromIndex.evaluate(t);return r.indexOf(e,n)}return r.indexOf(e)},lr.prototype.eachChild=function(t){t(this.needle),t(this.haystack),this.fromIndex&&t(this.fromIndex)},lr.prototype.outputDefined=function(){return!1},lr.prototype.serialize=function(){if(null!=this.fromIndex&&void 0!==this.fromIndex){var t=this.fromIndex.serialize();return[\"index-of\",this.needle.serialize(),this.haystack.serialize(),t]}return[\"index-of\",this.needle.serialize(),this.haystack.serialize()]};var cr=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};cr.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,f=s;u<f.length;u+=1){var h=f[u];if(\"number\"!=typeof h&&\"string\"!=typeof h)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof h&&Math.abs(h)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof h&&Math.floor(h)!==h)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,ie(h)))return null}else r=ie(h);if(void 0!==i[String(h)])return c.error(\"Branch labels must be unique.\");i[String(h)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,jt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new cr(r,n,d,i,a,g):null},cr.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(ie(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},cr.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},cr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))&&this.otherwise.outputDefined()},cr.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(f=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[f][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],f=u[0],h=u[1];e.push(1===h.length?s(h[0]):h.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var ur=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};ur.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Ft);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new ur(r,n,s):null},ur.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[1];if(n[0].evaluate(t))return i.evaluate(t)}return this.otherwise.evaluate(t)},ur.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[1];t(n[0]),t(i)}t(this.otherwise)},ur.prototype.outputDefined=function(){return this.branches.every((function(t){return t[1].outputDefined()}))&&this.otherwise.outputDefined()},ur.prototype.serialize=function(){var t=[\"case\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var fr=function(t,e,r,n){this.type=t,this.input=e,this.beginIndex=r,this.endIndex=n};function hr(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function pr(t,e,r,n){return 0===n.compare(e,r)}function dr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Ft,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,jt);if(!a)return null;if(!hr(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(a.type)+\"'.\");var o=e.parse(t[2],2,jt);if(!o)return null;if(!hr(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Gt(a.type)+\"' and '\"+Gt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new ce(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new ce(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Ut)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=ie(a),l=ie(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new se('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=ie(a),u=ie(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.outputDefined=function(){return!0},i.prototype.serialize=function(){var e=[t];return this.eachChild((function(t){e.push(t.serialize())})),e},i}()}fr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,Dt);if(!r||!n)return null;if(!Xt(r.type,[Ht(jt),Rt,jt]))return e.error(\"Expected first argument to be of type array or string, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Dt);return i?new fr(r.type,r,n,i):null}return new fr(r.type,r,n)},fr.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=this.beginIndex.evaluate(t);if(!Zt(e,[\"string\",\"array\"]))throw new se(\"Expected first argument to be of type array or string, but found \"+Gt(ie(e))+\" instead.\");if(this.endIndex){var n=this.endIndex.evaluate(t);return e.slice(r,n)}return e.slice(r)},fr.prototype.eachChild=function(t){t(this.input),t(this.beginIndex),this.endIndex&&t(this.endIndex)},fr.prototype.outputDefined=function(){return!1},fr.prototype.serialize=function(){if(null!=this.endIndex&&void 0!==this.endIndex){var t=this.endIndex.serialize();return[\"slice\",this.input.serialize(),this.beginIndex.serialize(),t]}return[\"slice\",this.input.serialize(),this.beginIndex.serialize()]};var gr=dr(\"==\",(function(t,e,r){return e===r}),pr),mr=dr(\"!=\",(function(t,e,r){return e!==r}),(function(t,e,r,n){return!pr(0,e,r,n)})),vr=dr(\"<\",(function(t,e,r){return e<r}),(function(t,e,r,n){return n.compare(e,r)<0})),yr=dr(\">\",(function(t,e,r){return e>r}),(function(t,e,r,n){return n.compare(e,r)>0})),xr=dr(\"<=\",(function(t,e,r){return e<=r}),(function(t,e,r,n){return n.compare(e,r)<=0})),br=dr(\">=\",(function(t,e,r){return e>=r}),(function(t,e,r,n){return n.compare(e,r)>=0})),_r=function(t,e,r,n,i){this.type=Rt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};_r.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Rt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Rt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Dt)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Dt))?null:new _r(r,i,a,o,s)},_r.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},_r.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},_r.prototype.outputDefined=function(){return!1},_r.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var wr=function(t){this.type=Dt,this.input=t};wr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Gt(r.type)+\" instead.\"):new wr(r):null},wr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new se(\"Expected value to be of type string or array, but found \"+Gt(ie(e))+\" instead.\")},wr.prototype.eachChild=function(t){t(this.input)},wr.prototype.outputDefined=function(){return!1},wr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var Tr={\"==\":gr,\"!=\":mr,\">\":yr,\"<\":vr,\">=\":br,\"<=\":xr,array:ce,at:or,boolean:ce,case:ur,coalesce:ir,collator:ve,format:ue,image:fe,in:sr,\"index-of\":lr,interpolate:rr,\"interpolate-hcl\":rr,\"interpolate-lab\":rr,length:wr,let:ar,literal:oe,match:cr,number:ce,\"number-format\":_r,object:ce,slice:fr,step:je,string:ce,\"to-boolean\":pe,\"to-color\":pe,\"to-number\":pe,\"to-string\":pe,var:Fe,within:ze};function kr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=re(r,n,i,o);if(s)throw new se(s);return new Kt(r/255*o,n/255*o,i/255*o,o)}function Mr(t,e){return t in e}function Ar(t,e){var r=e[t];return void 0===r?null:r}function Sr(t){return{type:t}}function Er(t){return{result:\"success\",value:t}}function Cr(t){return{result:\"error\",value:t}}function Lr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function Ir(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function Pr(t){return!!t.expression&&t.expression.interpolated}function zr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function Or(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Dr(t){return t}function Rr(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Fr(t,e,r,n,i){return Rr(typeof r===i?n[r]:void 0,t.default,e.default)}function Br(t,e,r){if(\"number\"!==zr(r))return Rr(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Ne(t.stops.map((function(t){return t[0]})),r);return t.stops[i][1]}function Nr(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==zr(r))return Rr(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Ne(t.stops.map((function(t){return t[0]})),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ve[e.type]||Dr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=er[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function jr(t,e,r){return\"color\"===e.type?r=Kt.parse(r):\"formatted\"===e.type?r=te.fromString(r.toString()):\"resolvedImage\"===e.type?r=ee.fromString(r.toString()):zr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Rr(r,t.default,e.default)}me.register(Tr,{error:[{kind:\"error\"},[Rt],function(t,e){throw new se(e[0].evaluate(t))}],typeof:[Rt,[jt],function(t,e){return Gt(ie(e[0].evaluate(t)))}],\"to-rgba\":[Ht(Dt,4),[Bt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Bt,[Dt,Dt,Dt],kr],rgba:[Bt,[Dt,Dt,Dt,Dt],kr],has:{type:Ft,overloads:[[[Rt],function(t,e){return Mr(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Mr(e[0].evaluate(t),r.evaluate(t))}]]},get:{type:jt,overloads:[[[Rt],function(t,e){return Ar(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Ar(e[0].evaluate(t),r.evaluate(t))}]]},\"feature-state\":[jt,[Rt],function(t,e){return Ar(e[0].evaluate(t),t.featureState||{})}],properties:[Nt,[],function(t){return t.properties()}],\"geometry-type\":[Rt,[],function(t){return t.geometryType()}],id:[jt,[],function(t){return t.id()}],zoom:[Dt,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Dt,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Dt,[],function(t){return t.globals.lineProgress||0}],accumulated:[jt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Dt,Sr(Dt),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Dt,Sr(Dt),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Dt,overloads:[[[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)-r.evaluate(t)}],[[Dt],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)/r.evaluate(t)}],\"%\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)%r.evaluate(t)}],ln2:[Dt,[],function(){return Math.LN2}],pi:[Dt,[],function(){return Math.PI}],e:[Dt,[],function(){return Math.E}],\"^\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return Math.pow(e[0].evaluate(t),r.evaluate(t))}],sqrt:[Dt,[Dt],function(t,e){return Math.sqrt(e[0].evaluate(t))}],log10:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN10}],ln:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))}],log2:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN2}],sin:[Dt,[Dt],function(t,e){return Math.sin(e[0].evaluate(t))}],cos:[Dt,[Dt],function(t,e){return Math.cos(e[0].evaluate(t))}],tan:[Dt,[Dt],function(t,e){return Math.tan(e[0].evaluate(t))}],asin:[Dt,[Dt],function(t,e){return Math.asin(e[0].evaluate(t))}],acos:[Dt,[Dt],function(t,e){return Math.acos(e[0].evaluate(t))}],atan:[Dt,[Dt],function(t,e){return Math.atan(e[0].evaluate(t))}],min:[Dt,Sr(Dt),function(t,e){return Math.min.apply(Math,e.map((function(e){return e.evaluate(t)})))}],max:[Dt,Sr(Dt),function(t,e){return Math.max.apply(Math,e.map((function(e){return e.evaluate(t)})))}],abs:[Dt,[Dt],function(t,e){return Math.abs(e[0].evaluate(t))}],round:[Dt,[Dt],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Dt,[Dt],function(t,e){return Math.floor(e[0].evaluate(t))}],ceil:[Dt,[Dt],function(t,e){return Math.ceil(e[0].evaluate(t))}],\"filter-==\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Ft,[jt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Ft,[Rt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Ft,[jt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Ft,[],function(t){return null!==t.id()&&void 0!==t.id()}],\"filter-type-in\":[Ft,[Ht(Rt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Ft,[Ht(jt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)&&r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)||r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Ft,[Ft],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Ft,[Rt],function(t,e){var r=t.globals&&t.globals.isSupportedScript;return!r||r(e[0].evaluate(t))}],upcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Rt,Sr(jt),function(t,e){return e.map((function(e){return ae(e.evaluate(t))})).join(\"\")}],\"resolved-locale\":[Rt,[Ut],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Ur=function(t,e){this.expression=t,this._warningHistory={},this._evaluator=new ge,this._defaultValue=e?function(t){return\"color\"===t.type&&Or(t.default)?new Kt(0,0,0,0):\"color\"===t.type?Kt.parse(t.default)||null:void 0===t.default?null:t.default}(e):null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Vr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in Tr}function qr(t,e){var r=new Be(Tr,[],e?function(t){var e={color:Bt,string:Rt,number:Dt,enum:Rt,boolean:Ft,formatted:Vt,resolvedImage:qt};return\"array\"===t.type?Ht(e[t.value]||jt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?Er(new Ur(n,e)):Cr(r.errors)}Ur.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a,this.expression.evaluate(this._evaluator)},Ur.prototype.evaluate=function(t,e,r,n,i,a){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a||null;try{var o=this.expression.evaluate(this._evaluator);if(null==o||\"number\"==typeof o&&o!=o)return this._defaultValue;if(this._enumValues&&!(o in this._enumValues))throw new se(\"Expected value to be one of \"+Object.keys(this._enumValues).map((function(t){return JSON.stringify(t)})).join(\", \")+\", but found \"+JSON.stringify(o)+\" instead.\");return o}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var Hr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!De(e.expression)};Hr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Hr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)};var Gr=function(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!De(e.expression),this.interpolationType=n};function Yr(t,e){if(\"error\"===(t=qr(t,e)).result)return t;var r=t.value.expression,n=Oe(r);if(!n&&!Lr(e))return Cr([new Pt(\"\",\"data expressions not supported\")]);var i=Re(r,[\"zoom\"]);if(!i&&!Ir(e))return Cr([new Pt(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof ar)r=t(e.result);else if(e instanceof ir)for(var n=0,i=e.args;n<i.length&&!(r=t(i[n]));n+=1);else(e instanceof je||e instanceof rr)&&e.input instanceof me&&\"zoom\"===e.input.name&&(r=e);return r instanceof Pt||e.eachChild((function(e){var n=t(e);n instanceof Pt?r=n:!r&&n?r=new Pt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Pt(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))})),r}(r);return a||i?a instanceof Pt?Cr([a]):a instanceof rr&&!Pr(e)?Cr([new Pt(\"\",'\"interpolate\" expressions cannot be used with this property')]):Er(a?new Gr(n?\"camera\":\"composite\",t.value,a.labels,a instanceof rr?a.interpolation:void 0):new Hr(n?\"constant\":\"source\",t.value)):Cr([new Pt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Gr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Gr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)},Gr.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?rr.interpolationFactor(this.interpolationType,t,e,r):0};var Wr=function(t,e){this._parameters=t,this._specification=e,Ct(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||!(s||void 0!==e.property),c=e.type||(Pr(r)?\"exponential\":\"interval\");if(o&&((e=Ct({},e)).stops&&(e.stops=e.stops.map((function(t){return[t[0],Kt.parse(t[1])]}))),e.default=Kt.parse(e.default?e.default:r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!er[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===c)n=Nr;else if(\"interval\"===c)n=Br;else if(\"categorical\"===c){n=Fr,i=Object.create(null);for(var u=0,f=e.stops;u<f.length;u+=1){var h=f[u];i[h[0]]=h[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==c)throw new Error('Unknown function type \"'+c+'\"');n=jr}if(s){for(var p={},d=[],g=0;g<e.stops.length;g++){var m=e.stops[g],v=m[0].zoom;void 0===p[v]&&(p[v]={zoom:v,type:e.type,property:e.property,default:e.default,stops:[]},d.push(v)),p[v].stops.push([m[0].value,m[1]])}for(var y=[],x=0,b=d;x<b.length;x+=1){var _=b[x];y.push([p[_].zoom,t(p[_],r)])}var w={name:\"linear\"};return{kind:\"composite\",interpolationType:w,interpolationFactor:rr.interpolationFactor.bind(void 0,w),zoomStops:y.map((function(t){return t[0]})),evaluate:function(t,n){var i=t.zoom;return Nr({stops:y,base:e.base},r,i).evaluate(i,n)}}}if(l){var T=\"exponential\"===c?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:rr.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map((function(t){return t[0]})),evaluate:function(t){return n(e,r,t.zoom,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Rr(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Xr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=zr(r);if(\"object\"!==l)return[new St(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],f=n[u]||n[\"*\"],h=void 0;if(i[u])h=i[u];else if(n[u])h=bn;else if(i[\"*\"])h=i[\"*\"];else{if(!n[\"*\"]){s.push(new St(e,r[c],'unknown property \"'+c+'\"'));continue}h=bn}s=s.concat(h({key:(e?e+\".\":e)+c,value:r[c],valueSpec:f,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new St(e,r,'missing required property \"'+p+'\"'));return s}function Zr(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||bn;if(\"array\"!==zr(e))return[new St(a,e,\"array expected, \"+zr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new St(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new St(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===zr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Jr(t){var e=t.key,r=t.value,n=t.valueSpec,i=zr(r);return\"number\"===i&&r!=r&&(i=\"NaN\"),\"number\"!==i?[new St(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new St(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new St(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function Kr(t){var e,r,n,i=t.valueSpec,a=Lt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===zr(t.value.stops)&&\"array\"===zr(t.value.stops[0])&&\"object\"===zr(t.value.stops[0][0]),u=Xr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new St(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Zr({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:f})),\"array\"===zr(r)&&0===r.length&&e.push(new St(t.key,r,\"array must have at least one stop\")),e},default:function(t){return bn({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new St(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new St(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!Pr(t.valueSpec)&&u.push(new St(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!Lr(t.valueSpec)?u.push(new St(t.key,t.value,\"property functions not supported\")):s&&!Ir(t.valueSpec)&&u.push(new St(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new St(t.key,t.value,'\"property\" property is required')),u;function f(t){var e=[],a=t.value,s=t.key;if(\"array\"!==zr(a))return[new St(s,a,\"array expected, \"+zr(a)+\" found\")];if(2!==a.length)return[new St(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==zr(a[0]))return[new St(s,a,\"object expected, \"+zr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new St(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new St(s,a,\"object stop key must have value\")];if(n&&n>Lt(a[0].zoom))return[new St(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Lt(a[0].zoom)!==n&&(n=Lt(a[0].zoom),r=void 0,o={}),e=e.concat(Xr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Jr,value:h}}))}else e=e.concat(h({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Vr(It(a[1]))?e.concat([new St(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(bn({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function h(t,n){var s=zr(t.value),l=Lt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new St(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new St(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return Lr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new St(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new St(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new St(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new St(t.key,c,\"integer expected, found \"+l)]}}function Qr(t){var e=(\"property\"===t.expressionContext?Yr:qr)(It(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map((function(e){return new St(\"\"+t.key+e.key,t.value,e.message)}));var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&!r.outputDefined())return[new St(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!Re(r,[\"zoom\",\"feature-state\"]))return[new St(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!Oe(r))return[new St(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function $r(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Lt(r))&&i.push(new St(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Lt(r))&&i.push(new St(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function tn(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":return t.length>=3&&(\"string\"!=typeof t[1]||Array.isArray(t[2]));case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!tn(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Wr.deserialize=function(t){return new Wr(t._parameters,t._specification)},Wr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var en={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function rn(t){if(null==t)return{filter:function(){return!0},needGeometry:!1};tn(t)||(t=an(t));var e=qr(t,en);if(\"error\"===e.result)throw new Error(e.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return{filter:function(t,r,n){return e.value.evaluate(t,r,{},n)},needGeometry:function t(e){if(!Array.isArray(e))return!1;if(\"within\"===e[0])return!0;for(var r=1;r<e.length;r++)if(t(e[r]))return!0;return!1}(t)}}function nn(t,e){return t<e?-1:t>e?1:0}function an(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?on(t[1],t[2],\"==\"):\"!=\"===r?cn(on(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?on(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(an))):\"all\"===r?[\"all\"].concat(t.slice(1).map(an)):\"none\"===r?[\"all\"].concat(t.slice(1).map(an).map(cn)):\"in\"===r?sn(t[1],t.slice(2)):\"!in\"===r?cn(sn(t[1],t.slice(2))):\"has\"===r?ln(t[1]):\"!has\"===r?cn(ln(t[1])):\"within\"!==r||t}function on(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function sn(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some((function(t){return typeof t!=typeof e[0]}))?[\"filter-in-large\",t,[\"literal\",e.sort(nn)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function ln(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function cn(t){return[\"!\",t]}function un(t){return tn(It(t.value))?Qr(Ct({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==zr(r))return[new St(n,r,\"array expected, \"+zr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new St(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat($r({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Lt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Lt(r[1])&&o.push(new St(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new St(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=zr(r[1]))&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=zr(r[s]),\"$type\"===Lt(r[1])?o=o.concat($r({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new St(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));break;case\"within\":i=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"object\"!==i&&o.push(new St(n+\"[1]\",r[1],\"object expected, \"+i+\" found\"))}return o}(t)}function fn(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return bn({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new St(r,a,'unknown property \"'+o+'\"')];if(\"string\"===zr(a)&&Lr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new St(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var f=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&f.push(new St(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&Or(It(a))&&\"identity\"===Lt(a.type)&&f.push(new St(r,a,'\"text-font\" does not support identity functions'))),f.concat(bn({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function hn(t){return fn(t,\"paint\")}function pn(t){return fn(t,\"layout\")}function dn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new St(n,r,'either \"type\" or \"ref\" is required'));var o,s=Lt(r.type),l=Lt(r.ref);if(r.id)for(var c=Lt(r.id),u=0;u<t.arrayIndex;u++){var f=i.layers[u];Lt(f.id)===c&&e.push(new St(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+f.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach((function(t){t in r&&e.push(new St(n,r[t],'\"'+t+'\" is prohibited for ref layers'))})),i.layers.forEach((function(t){Lt(t.id)===l&&(o=t)})),o?o.ref?e.push(new St(n,r.ref,\"ref cannot reference another ref layer\")):s=Lt(o.type):e.push(new St(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var h=i.sources&&i.sources[r.source],p=h&&Lt(h.type);h?\"vector\"===p&&\"raster\"===s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new St(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&h.lineMetrics||e.push(new St(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new St(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new St(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new St(n,r,'missing required property \"source\"'));return e=e.concat(Xr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return bn({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:un,layout:function(t){return Xr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return pn(Ct({layerType:s},t))}}})},paint:function(t){return Xr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return hn(Ct({layerType:s},t))}}})}}}))}function gn(t){var e=t.value,r=t.key,n=zr(e);return\"string\"!==n?[new St(r,e,\"string expected, \"+n+\" found\")]:[]}var mn={promoteId:function(t){var e=t.key,r=t.value;if(\"string\"===zr(r))return gn({key:e,value:r});var n=[];for(var i in r)n.push.apply(n,gn({key:e+\".\"+i,value:r[i]}));return n}};function vn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new St(r,e,'\"type\" is required')];var a,o=Lt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":return Xr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n,objectElementValidators:mn});case\"geojson\":if(a=Xr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n,objectElementValidators:mn}),e.cluster)for(var s in e.clusterProperties){var l=e.clusterProperties[s],c=l[0],u=\"string\"==typeof c?[c,[\"accumulated\"],[\"get\",s]]:c;a.push.apply(a,Qr({key:r+\".\"+s+\".map\",value:l[1],expressionContext:\"cluster-map\"})),a.push.apply(a,Qr({key:r+\".\"+s+\".reduce\",value:u,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Xr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Xr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new St(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return $r({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function yn(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=zr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new St(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=a.concat(l&&n[l[1]]&&n[l[1]].transition?bn({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r}):n[s]?bn({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r}):[new St(s,e[s],'unknown property \"'+s+'\"')])}return a}var xn={\"*\":function(){return[]},array:Zr,boolean:function(t){var e=t.value,r=t.key,n=zr(e);return\"boolean\"!==n?[new St(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Jr,color:function(t){var e=t.key,r=t.value,n=zr(r);return\"string\"!==n?[new St(e,r,\"color expected, \"+n+\" found\")]:null===Jt(r)?[new St(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Et,enum:$r,filter:un,function:Kr,layer:dn,object:Xr,source:vn,light:yn,string:gn,formatted:function(t){return 0===gn(t).length?[]:Qr(t)},resolvedImage:function(t){return 0===gn(t).length?[]:Qr(t)}};function bn(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&Or(Lt(e))?Kr(t):r.expression&&Vr(It(e))?Qr(t):r.type&&xn[r.type]?xn[r.type](t):Xr(Ct({},t,{valueSpec:r.type?n[r.type]:r}))}function _n(t){var e=t.value,r=t.key,n=gn(t);return n.length||(-1===e.indexOf(\"{fontstack}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{range}\" token'))),n}function wn(t,e){void 0===e&&(e=At);var r=[];return r=r.concat(bn({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:_n,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Et({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),Tn(r)}function Tn(t){return[].concat(t).sort((function(t,e){return t.line-e.line}))}function kn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return Tn(t.apply(this,e))}}wn.source=kn(vn),wn.light=kn(yn),wn.layer=kn(dn),wn.filter=kn(un),wn.paintProperty=kn(hn),wn.layoutProperty=kn(pn);var Mn=wn,An=Mn.light,Sn=Mn.paintProperty,En=Mn.layoutProperty;function Cn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1)t.fire(new kt(new Error(i[n].message))),r=!0;return r}var Ln=In;function In(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],this.d=(e=i[1])+2*(r=i[2]);for(var a=0;a<this.d*this.d;a++){var o=i[3+a],s=i[3+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[3+n.length+1];this.keys=i.subarray(i[3+n.length],l),this.bboxes=i.subarray(l),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var c=0;c<this.d*this.d;c++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var u=r/e*t;this.min=-u,this.max=t+u}In.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},In.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},In.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},In.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},In.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,f=0;f<l.length;f++){var h=l[f];if(void 0===o[h]){var p=4*h;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[h]=!0,a.push(c[h])):o[h]=!1}}},In.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),f=this._convertToCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++){var d=this.d*p+h;if((!s||s(this._convertFromCellCoord(h),this._convertFromCellCoord(p),this._convertFromCellCoord(h+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},In.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},In.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},In.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=3+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[3+o]=a,i.set(s,a),a+=s.length}return i[3+t.length]=a,i.set(this.keys,a),i[3+t.length+1]=a+=this.keys.length,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var Pn=self.ImageData,zn=self.ImageBitmap,On={};function Dn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),On[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Rn in Dn(\"Object\",Object),Ln.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},Ln.deserialize=function(t){return new Ln(t.buffer)},Dn(\"Grid\",Ln),Dn(\"Color\",Kt),Dn(\"Error\",Error),Dn(\"ResolvedImage\",ee),Dn(\"StylePropertyFunction\",Wr),Dn(\"StyleExpression\",Ur,{omit:[\"_evaluator\"]}),Dn(\"ZoomDependentExpression\",Gr),Dn(\"ZoomConstantExpression\",Hr),Dn(\"CompoundExpression\",me,{omit:[\"_evaluate\"]}),Tr)Tr[Rn]._classRegistryKey||Dn(\"Expression_\"+Rn,Tr[Rn]);function Fn(t){return t&&\"undefined\"!=typeof ArrayBuffer&&(t instanceof ArrayBuffer||t.constructor&&\"ArrayBuffer\"===t.constructor.name)}function Bn(t){return zn&&t instanceof zn}function Nn(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(Fn(t)||Bn(t))return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof Pn)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1)n.push(Nn(a[i],e));return n}if(\"object\"==typeof t){var o=t.constructor,s=o._classRegistryKey;if(!s)throw new Error(\"can't serialize object of unregistered class\");var l=o.serialize?o.serialize(t,e):{};if(!o.serialize){for(var c in t)if(t.hasOwnProperty(c)&&!(On[s].omit.indexOf(c)>=0)){var u=t[c];l[c]=On[s].shallow.indexOf(c)>=0?u:Nn(u,e)}t instanceof Error&&(l.message=t.message)}if(l.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==s&&(l.$name=s),l}throw new Error(\"can't serialize object of type \"+typeof t)}function jn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||Fn(t)||Bn(t)||ArrayBuffer.isView(t)||t instanceof Pn)return t;if(Array.isArray(t))return t.map(jn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=On[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=On[e].shallow.indexOf(o)>=0?s:jn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Un=function(){this.first=!0};Un.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var Vn={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function qn(t){for(var e=0,r=t;e<r.length;e+=1)if(Hn(r[e].charCodeAt(0)))return!0;return!1}function Hn(t){return!(746!==t&&747!==t&&(t<4352||!(Vn[\"Bopomofo Extended\"](t)||Vn.Bopomofo(t)||Vn[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||Vn[\"CJK Compatibility Ideographs\"](t)||Vn[\"CJK Compatibility\"](t)||Vn[\"CJK Radicals Supplement\"](t)||Vn[\"CJK Strokes\"](t)||!(!Vn[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||Vn[\"CJK Unified Ideographs Extension A\"](t)||Vn[\"CJK Unified Ideographs\"](t)||Vn[\"Enclosed CJK Letters and Months\"](t)||Vn[\"Hangul Compatibility Jamo\"](t)||Vn[\"Hangul Jamo Extended-A\"](t)||Vn[\"Hangul Jamo Extended-B\"](t)||Vn[\"Hangul Jamo\"](t)||Vn[\"Hangul Syllables\"](t)||Vn.Hiragana(t)||Vn[\"Ideographic Description Characters\"](t)||Vn.Kanbun(t)||Vn[\"Kangxi Radicals\"](t)||Vn[\"Katakana Phonetic Extensions\"](t)||Vn.Katakana(t)&&12540!==t||!(!Vn[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!Vn[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||Vn[\"Unified Canadian Aboriginal Syllabics\"](t)||Vn[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||Vn[\"Vertical Forms\"](t)||Vn[\"Yijing Hexagram Symbols\"](t)||Vn[\"Yi Syllables\"](t)||Vn[\"Yi Radicals\"](t))))}function Gn(t){return!(Hn(t)||function(t){return!!(Vn[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||Vn[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||Vn[\"Letterlike Symbols\"](t)||Vn[\"Number Forms\"](t)||Vn[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||Vn[\"Control Pictures\"](t)&&9251!==t||Vn[\"Optical Character Recognition\"](t)||Vn[\"Enclosed Alphanumerics\"](t)||Vn[\"Geometric Shapes\"](t)||Vn[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||Vn[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||Vn[\"CJK Symbols and Punctuation\"](t)||Vn.Katakana(t)||Vn[\"Private Use Area\"](t)||Vn[\"CJK Compatibility Forms\"](t)||Vn[\"Small Form Variants\"](t)||Vn[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function Yn(t){return t>=1424&&t<=2303||Vn[\"Arabic Presentation Forms-A\"](t)||Vn[\"Arabic Presentation Forms-B\"](t)}function Wn(t,e){return!(!e&&Yn(t)||t>=2304&&t<=3583||t>=3840&&t<=4255||Vn.Khmer(t))}function Xn(t){for(var e=0,r=t;e<r.length;e+=1)if(Yn(r[e].charCodeAt(0)))return!0;return!1}var Zn=null,Jn=\"unavailable\",Kn=null,Qn=function(t){t&&\"string\"==typeof t&&t.indexOf(\"NetworkError\")>-1&&(Jn=\"error\"),Zn&&Zn(t)};function $n(){ti.fire(new Tt(\"pluginStateChange\",{pluginStatus:Jn,pluginURL:Kn}))}var ti=new Mt,ei=function(){return Jn},ri=function(){if(\"deferred\"!==Jn||!Kn)throw new Error(\"rtl-text-plugin cannot be downloaded unless a pluginURL is specified\");Jn=\"loading\",$n(),Kn&&yt({url:Kn},(function(t){t?Qn(t):(Jn=\"loaded\",$n())}))},ni={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return\"loaded\"===Jn||null!=ni.applyArabicShaping},isLoading:function(){return\"loading\"===Jn},setState:function(t){Jn=t.pluginStatus,Kn=t.pluginURL},isParsed:function(){return null!=ni.applyArabicShaping&&null!=ni.processBidirectionalText&&null!=ni.processStyledBidirectionalText},getPluginURL:function(){return Kn}},ii=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Un,this.transition={})};ii.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!Wn(n[r].charCodeAt(0),e))return!1;return!0}(t,ni.isLoaded())},ii.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},ii.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var ai=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(Or(t))return new Wr(t,e);if(Vr(t)){var r=Yr(t,e);if(\"error\"===r.result)throw new Error(r.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=Kt.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};ai.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},ai.prototype.possiblyEvaluate=function(t,e,r){return this.property.possiblyEvaluate(this,t,e,r)};var oi=function(t){this.property=t,this.value=new ai(t,void 0)};oi.prototype.transitioned=function(t,e){return new li(this.property,this.value,e,u({},t.transition,this.transition),t.now)},oi.prototype.untransitioned=function(){return new li(this.property,this.value,null,{},0)};var si=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};si.prototype.getValue=function(t){return x(this._values[t].value.value)},si.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oi(this._values[t].property)),this._values[t].value=new ai(this._values[t].property,null===e?void 0:x(e))},si.prototype.getTransition=function(t){return x(this._values[t].transition)},si.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oi(this._values[t].property)),this._values[t].transition=x(e)||void 0},si.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},si.prototype.transitioned=function(t,e){for(var r=new ci(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},si.prototype.untransitioned=function(){for(var t=new ci(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var li=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};li.prototype.possiblyEvaluate=function(t,e,r){var n=t.now||0,i=this.value.possiblyEvaluate(t,e,r),a=this.prior;if(a){if(n>this.end)return this.prior=null,i;if(this.value.isDataDriven())return this.prior=null,i;if(n<this.begin)return a.possiblyEvaluate(t,e,r);var o=(n-this.begin)/(this.end-this.begin);return this.property.interpolate(a.possiblyEvaluate(t,e,r),i,function(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}(o))}return i};var ci=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};ci.prototype.possiblyEvaluate=function(t,e,r){for(var n=new hi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n},ci.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1)if(this._values[e[t]].prior)return!0;return!1};var ui=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};ui.prototype.getValue=function(t){return x(this._values[t].value)},ui.prototype.setValue=function(t,e){this._values[t]=new ai(this._values[t].property,null===e?void 0:x(e))},ui.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},ui.prototype.possiblyEvaluate=function(t,e,r){for(var n=new hi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n};var fi=function(t,e,r){this.property=t,this.value=e,this.parameters=r};fi.prototype.isConstant=function(){return\"constant\"===this.value.kind},fi.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},fi.prototype.evaluate=function(t,e,r,n){return this.property.evaluate(this.value,this.parameters,t,e,r,n)};var hi=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};hi.prototype.get=function(t){return this._values[t]};var pi=function(t){this.specification=t};pi.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},pi.prototype.interpolate=function(t,e,r){var n=Ve[this.specification.type];return n?n(t,e,r):t};var di=function(t,e){this.specification=t,this.overrides=e};di.prototype.possiblyEvaluate=function(t,e,r,n){return new fi(this,\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?{kind:\"constant\",value:t.expression.evaluate(e,null,{},r,n)}:t.expression,e)},di.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new fi(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ve[this.specification.type];return n?new fi(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},di.prototype.evaluate=function(t,e,r,n,i,a){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n,i,a)};var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0===t.value)return new fi(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n),a=\"resolvedImage\"===t.property.specification.type&&\"string\"!=typeof i?i.name:i,o=this._calculate(a,a,a,e);return new fi(this,{kind:\"constant\",value:o},e)}if(\"camera\"===t.expression.kind){var s=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new fi(this,{kind:\"constant\",value:s},e)}return new fi(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n,i,a){if(\"source\"===t.kind){var o=t.evaluate(e,r,n,i,a);return this._calculate(o,o,o,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(di),mi=function(t){this.specification=t};mi.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n);return this._calculate(i,i,i,e)}return this._calculate(t.expression.evaluate(new ii(Math.floor(e.zoom-1),e)),t.expression.evaluate(new ii(Math.floor(e.zoom),e)),t.expression.evaluate(new ii(Math.floor(e.zoom+1),e)),e)}},mi.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},mi.prototype.interpolate=function(t){return t};var vi=function(t){this.specification=t};vi.prototype.possiblyEvaluate=function(t,e,r,n){return!!t.expression.evaluate(e,null,{},r,n)},vi.prototype.interpolate=function(){return!1};var yi=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[],t){var r=t[e];r.specification.overridable&&this.overridableProperties.push(e);var n=this.defaultPropertyValues[e]=new ai(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new oi(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};Dn(\"DataDrivenProperty\",di),Dn(\"DataConstantProperty\",pi),Dn(\"CrossFadedDataDrivenProperty\",gi),Dn(\"CrossFadedProperty\",mi),Dn(\"ColorRampProperty\",vi);var xi=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter={filter:function(){return!0},needGeometry:!1},\"custom\"!==e.type&&(this.metadata=(e=e).metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new ui(r.layout)),r.paint)){for(var n in this._transitionablePaint=new si(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned(),this.paint=new hi(r.paint)}}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){void 0===r&&(r={}),null!=e&&this._validate(En,\"layers.\"+this.id+\".layout.\"+t,t,e,r)||(\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e)},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e&&this._validate(Sn,\"layers.\"+this.id+\".paint.\"+t,t,e,r))return!1;if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var n=this._transitionablePaint._values[t],i=\"cross-faded-data-driven\"===n.property.specification[\"property-type\"],a=n.value.isDataDriven(),o=n.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);var s=this._transitionablePaint._values[t].value;return s.isDataDriven()||a||i||this._handleOverridablePaintPropertyUpdate(t,o,s)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype._handleOverridablePaintPropertyUpdate=function(t,e,r){return!1},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t,e){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t,void 0,e)),this.paint=this._transitioningPaint.possiblyEvaluate(t,void 0,e)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),y(t,(function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)}))},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&Cn(this,t.call(Mn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:At,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof fi&&Lr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(Mt),bi={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},_i=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},wi=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function Ti(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map((function(t){var i=bi[t.type].BYTES_PER_ELEMENT,a=r=ki(r,Math.max(e,i)),o=t.components||1;return n=Math.max(n,i),r+=i*o,{name:t.name,type:t.type,components:o,offset:a}})),size:ki(r,Math.max(n,e)),alignment:e}}function ki(t,e){return Math.ceil(t/e)*e}wi.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},wi.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},wi.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},wi.prototype.clear=function(){this.length=0},wi.prototype.resize=function(t){this.reserve(t),this.length=t},wi.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},wi.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(wi);Mi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2i4\",Mi);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(wi);Ai.prototype.bytesPerElement=8,Dn(\"StructArrayLayout4i8\",Ai);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(wi);Si.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i4i12\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(wi);Ei.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2i4ub8\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c){var u=this.length;return this.resize(u+1),this.emplace(u,t,e,r,n,i,a,o,s,l,c)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u){var f=9*t,h=18*t;return this.uint16[f+0]=e,this.uint16[f+1]=r,this.uint16[f+2]=n,this.uint16[f+3]=i,this.uint16[f+4]=a,this.uint16[f+5]=o,this.uint16[f+6]=s,this.uint16[f+7]=l,this.uint8[h+16]=c,this.uint8[h+17]=u,t},e}(wi);Ci.prototype.bytesPerElement=18,Dn(\"StructArrayLayout8ui2ub18\",Ci);var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u,f)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=12*t;return this.int16[p+0]=e,this.int16[p+1]=r,this.int16[p+2]=n,this.int16[p+3]=i,this.uint16[p+4]=a,this.uint16[p+5]=o,this.uint16[p+6]=s,this.uint16[p+7]=l,this.int16[p+8]=c,this.int16[p+9]=u,this.int16[p+10]=f,this.int16[p+11]=h,t},e}(wi);Li.prototype.bytesPerElement=24,Dn(\"StructArrayLayout4i4ui4i24\",Li);var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(wi);Ii.prototype.bytesPerElement=12,Dn(\"StructArrayLayout3f12\",Ii);var Pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint32[1*t+0]=e,t},e}(wi);Pi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1ul4\",Pi);var zi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l){var c=this.length;return this.resize(c+1),this.emplace(c,t,e,r,n,i,a,o,s,l)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c){var u=10*t,f=5*t;return this.int16[u+0]=e,this.int16[u+1]=r,this.int16[u+2]=n,this.int16[u+3]=i,this.int16[u+4]=a,this.int16[u+5]=o,this.uint32[f+3]=s,this.uint16[u+8]=l,this.uint16[u+9]=c,t},e}(wi);zi.prototype.bytesPerElement=20,Dn(\"StructArrayLayout6i1ul2ui20\",zi);var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(wi);Oi.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i2i2i12\",Oi);var Di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n,i)},e.prototype.emplace=function(t,e,r,n,i,a){var o=4*t,s=8*t;return this.float32[o+0]=e,this.float32[o+1]=r,this.float32[o+2]=n,this.int16[s+6]=i,this.int16[s+7]=a,t},e}(wi);Di.prototype.bytesPerElement=16,Dn(\"StructArrayLayout2f1f2i16\",Di);var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(wi);Ri.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2ub2f12\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(wi);Fi.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3ui6\",Fi);var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m){var v=this.length;return this.resize(v+1),this.emplace(v,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v){var y=24*t,x=12*t,b=48*t;return this.int16[y+0]=e,this.int16[y+1]=r,this.uint16[y+2]=n,this.uint16[y+3]=i,this.uint32[x+2]=a,this.uint32[x+3]=o,this.uint32[x+4]=s,this.uint16[y+10]=l,this.uint16[y+11]=c,this.uint16[y+12]=u,this.float32[x+7]=f,this.float32[x+8]=h,this.uint8[b+36]=p,this.uint8[b+37]=d,this.uint8[b+38]=g,this.uint32[x+10]=m,this.int16[y+22]=v,t},e}(wi);Bi.prototype.bytesPerElement=48,Dn(\"StructArrayLayout2i2ui3ul3ui2f3ub1ul1i48\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S){var E=this.length;return this.resize(E+1),this.emplace(E,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E){var C=34*t,L=17*t;return this.int16[C+0]=e,this.int16[C+1]=r,this.int16[C+2]=n,this.int16[C+3]=i,this.int16[C+4]=a,this.int16[C+5]=o,this.int16[C+6]=s,this.int16[C+7]=l,this.uint16[C+8]=c,this.uint16[C+9]=u,this.uint16[C+10]=f,this.uint16[C+11]=h,this.uint16[C+12]=p,this.uint16[C+13]=d,this.uint16[C+14]=g,this.uint16[C+15]=m,this.uint16[C+16]=v,this.uint16[C+17]=y,this.uint16[C+18]=x,this.uint16[C+19]=b,this.uint16[C+20]=_,this.uint16[C+21]=w,this.uint16[C+22]=T,this.uint32[L+12]=k,this.float32[L+13]=M,this.float32[L+14]=A,this.float32[L+15]=S,this.float32[L+16]=E,t},e}(wi);Ni.prototype.bytesPerElement=68,Dn(\"StructArrayLayout8i15ui1ul4f68\",Ni);var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.float32[1*t+0]=e,t},e}(wi);ji.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1f4\",ji);var Ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(wi);Ui.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3i6\",Ui);var Vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=4*t;return this.uint32[2*t+0]=e,this.uint16[i+2]=r,this.uint16[i+3]=n,t},e}(wi);Vi.prototype.bytesPerElement=8,Dn(\"StructArrayLayout1ul2ui8\",Vi);var qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(wi);qi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2ui4\",qi);var Hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint16[1*t+0]=e,t},e}(wi);Hi.prototype.bytesPerElement=2,Dn(\"StructArrayLayout1ui2\",Hi);var Gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(wi);Gi.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2f8\",Gi);var Yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(wi);Yi.prototype.bytesPerElement=16,Dn(\"StructArrayLayout4f16\",Yi);var Wi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(_i);Wi.prototype.size=20;var Xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Wi(this,t)},e}(zi);Dn(\"CollisionBoxArray\",Xi);var Zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},placedOrientation:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0},associatedIconIndex:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.placedOrientation.get=function(){return this._structArray.uint8[this._pos1+37]},r.placedOrientation.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+38]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+38]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},r.associatedIconIndex.get=function(){return this._structArray.int16[this._pos2+22]},Object.defineProperties(e.prototype,r),e}(_i);Zi.prototype.size=48;var Ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Zi(this,t)},e}(Bi);Dn(\"PlacedSymbolArray\",Ji);var Ki=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},placedIconSymbolIndex:{configurable:!0},verticalPlacedIconSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},verticalTextBoxStartIndex:{configurable:!0},verticalTextBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},verticalIconBoxStartIndex:{configurable:!0},verticalIconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},numVerticalIconVertices:{configurable:!0},useRuntimeCollisionCircles:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},textOffset0:{configurable:!0},textOffset1:{configurable:!0},collisionCircleDiameter:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.placedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+6]},r.verticalPlacedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+7]},r.key.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.verticalTextBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.verticalTextBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+12]},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+13]},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+14]},r.verticalIconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+15]},r.verticalIconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+16]},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+17]},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+18]},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+19]},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+20]},r.numVerticalIconVertices.get=function(){return this._structArray.uint16[this._pos2+21]},r.useRuntimeCollisionCircles.get=function(){return this._structArray.uint16[this._pos2+22]},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+12]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+12]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+13]},r.textOffset0.get=function(){return this._structArray.float32[this._pos4+14]},r.textOffset1.get=function(){return this._structArray.float32[this._pos4+15]},r.collisionCircleDiameter.get=function(){return this._structArray.float32[this._pos4+16]},Object.defineProperties(e.prototype,r),e}(_i);Ki.prototype.size=68;var Qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Ki(this,t)},e}(Ni);Dn(\"SymbolInstanceArray\",Qi);var $i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e}(ji);Dn(\"GlyphOffsetArray\",$i);var ta=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e}(Ui);Dn(\"SymbolLineVertexArray\",ta);var ea=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},Object.defineProperties(e.prototype,r),e}(_i);ea.prototype.size=8;var ra=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new ea(this,t)},e}(Vi);Dn(\"FeatureIndexArray\",ra);var na=Ti([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,ia=function(t){void 0===t&&(t=[]),this.segments=t};function aa(t,e){return 256*(t=l(Math.floor(t),0,255))+l(Math.floor(e),0,255)}ia.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>ia.MAX_VERTEX_ARRAY_LENGTH&&_(\"Max vertices per segment is \"+ia.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>ia.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},ia.prototype.get=function(){return this.segments},ia.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},ia.simpleSegment=function(t,e,r,n){return new ia([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},ia.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,Dn(\"SegmentVector\",ia);var oa=Ti([{name:\"a_pattern_from\",components:4,type:\"Uint16\"},{name:\"a_pattern_to\",components:4,type:\"Uint16\"},{name:\"a_pixel_ratio_from\",components:1,type:\"Uint8\"},{name:\"a_pixel_ratio_to\",components:1,type:\"Uint8\"}]),sa=e((function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(n=t.length-(r=3&t.length),i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}})),la=e((function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}})),ca=sa,ua=la;ca.murmur3=sa,ca.murmur2=ua;var fa=function(){this.ids=[],this.positions=[],this.indexed=!1};fa.prototype.add=function(t,e,r,n){this.ids.push(pa(t)),this.positions.push(e,r,n)},fa.prototype.getPositions=function(t){for(var e=pa(t),r=0,n=this.ids.length-1;r<n;){var i=r+n>>1;this.ids[i]>=e?n=i:r=i+1}for(var a=[];this.ids[r]===e;)a.push({index:this.positions[3*r],start:this.positions[3*r+1],end:this.positions[3*r+2]}),r++;return a},fa.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){for(;n<i;){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;da(e,o,s),da(r,3*o,3*s),da(r,3*o+1,3*s+1),da(r,3*o+2,3*s+2)}s-n<i-s?(t(e,r,n,s),n=s+1):(t(e,r,s+1,i),i=s)}}(r,n,0,r.length-1),e&&e.push(r.buffer,n.buffer),{ids:r,positions:n}},fa.deserialize=function(t){var e=new fa;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e};var ha=Math.pow(2,53)-1;function pa(t){var e=+t;return!isNaN(e)&&e<=ha?e:ca(String(t))}function da(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Dn(\"FeaturePositionMap\",fa);var ga=function(t,e){this.gl=t.gl,this.location=e},ma=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(ga),va=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(ga),ya=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(ga),xa=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(ga),ba=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(ga),_a=function(t){function e(e,r){t.call(this,e,r),this.current=Kt.transparent}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(ga),wa=new Float32Array(16),Ta=function(t){function e(e,r){t.call(this,e,r),this.current=wa}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(ga);function ka(t){return[aa(255*t.r,255*t.g),aa(255*t.b,255*t.a)]}var Ma=function(t,e,r){this.value=t,this.uniformNames=e.map((function(t){return\"u_\"+t})),this.type=r};Ma.prototype.setUniform=function(t,e,r){t.set(r.constantOr(this.value))},Ma.prototype.getBinding=function(t,e,r){return\"color\"===this.type?new _a(t,e):new va(t,e)};var Aa=function(t,e){this.uniformNames=e.map((function(t){return\"u_\"+t})),this.patternFrom=null,this.patternTo=null,this.pixelRatioFrom=1,this.pixelRatioTo=1};Aa.prototype.setConstantPatternPositions=function(t,e){this.pixelRatioFrom=e.pixelRatio,this.pixelRatioTo=t.pixelRatio,this.patternFrom=e.tlbr,this.patternTo=t.tlbr},Aa.prototype.setUniform=function(t,e,r,n){var i=\"u_pattern_to\"===n?this.patternTo:\"u_pattern_from\"===n?this.patternFrom:\"u_pixel_ratio_to\"===n?this.pixelRatioTo:\"u_pixel_ratio_from\"===n?this.pixelRatioFrom:null;i&&t.set(i)},Aa.prototype.getBinding=function(t,e,r){return\"u_pattern\"===r.substr(0,9)?new ba(t,e):new va(t,e)};var Sa=function(t,e,r,n){this.expression=t,this.type=r,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}})),this.paintVertexArray=new n};Sa.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.paintVertexArray.length,o=this.expression.evaluate(new ii(0),e,{},n,[],i);this.paintVertexArray.resize(t),this._setPaintValue(a,t,o)},Sa.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:0},r,n);this._setPaintValue(t,e,i)},Sa.prototype._setPaintValue=function(t,e,r){if(\"color\"===this.type)for(var n=ka(r),i=t;i<e;i++)this.paintVertexArray.emplace(i,n[0],n[1]);else{for(var a=t;a<e;a++)this.paintVertexArray.emplace(a,r);this.maxValue=Math.max(this.maxValue,Math.abs(r))}},Sa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Sa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()};var Ea=function(t,e,r,n,i,a){this.expression=t,this.uniformNames=e.map((function(t){return\"u_\"+t+\"_t\"})),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}})),this.paintVertexArray=new a};Ea.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.expression.evaluate(new ii(this.zoom),e,{},n,[],i),o=this.expression.evaluate(new ii(this.zoom+1),e,{},n,[],i),s=this.paintVertexArray.length;this.paintVertexArray.resize(t),this._setPaintValue(s,t,a,o)},Ea.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:this.zoom},r,n),a=this.expression.evaluate({zoom:this.zoom+1},r,n);this._setPaintValue(t,e,i,a)},Ea.prototype._setPaintValue=function(t,e,r,n){if(\"color\"===this.type)for(var i=ka(r),a=ka(n),o=t;o<e;o++)this.paintVertexArray.emplace(o,i[0],i[1],a[0],a[1]);else{for(var s=t;s<e;s++)this.paintVertexArray.emplace(s,r,n);this.maxValue=Math.max(this.maxValue,Math.abs(r),Math.abs(n))}},Ea.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Ea.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Ea.prototype.setUniform=function(t,e){var r=this.useIntegerZoom?Math.floor(e.zoom):e.zoom,n=l(this.expression.interpolationFactor(r,this.zoom,this.zoom+1),0,1);t.set(n)},Ea.prototype.getBinding=function(t,e,r){return new va(t,e)};var Ca=function(t,e,r,n,i,a){this.expression=t,this.type=e,this.useIntegerZoom=r,this.zoom=n,this.layerId=a,this.zoomInPaintVertexArray=new i,this.zoomOutPaintVertexArray=new i};Ca.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray.length;this.zoomInPaintVertexArray.resize(t),this.zoomOutPaintVertexArray.resize(t),this._setPaintValues(n,t,e.patterns&&e.patterns[this.layerId],r)},Ca.prototype.updatePaintArray=function(t,e,r,n,i){this._setPaintValues(t,e,r.patterns&&r.patterns[this.layerId],i)},Ca.prototype._setPaintValues=function(t,e,r,n){if(n&&r){var i=n[r.min],a=n[r.mid],o=n[r.max];if(i&&a&&o)for(var s=t;s<e;s++)this.zoomInPaintVertexArray.emplace(s,a.tl[0],a.tl[1],a.br[0],a.br[1],i.tl[0],i.tl[1],i.br[0],i.br[1],a.pixelRatio,i.pixelRatio),this.zoomOutPaintVertexArray.emplace(s,a.tl[0],a.tl[1],a.br[0],a.br[1],o.tl[0],o.tl[1],o.br[0],o.br[1],a.pixelRatio,o.pixelRatio)}},Ca.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,oa.members,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,oa.members,this.expression.isStateDependent))},Ca.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()};var La=function(t,e,r,n){this.binders={},this.layoutAttributes=n,this._buffers=[];var i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof fi&&Lr(o.property.specification)){var s=Pa(a,t.type),l=o.value,c=o.property.specification.type,u=o.property.useIntegerZoom,f=o.property.specification[\"property-type\"],h=\"cross-faded\"===f||\"cross-faded-data-driven\"===f;if(\"constant\"===l.kind)this.binders[a]=h?new Aa(l.value,s):new Ma(l.value,s,c),i.push(\"/u_\"+a);else if(\"source\"===l.kind||h){var p=za(a,c,\"source\");this.binders[a]=h?new Ca(l,c,u,e,p,t.id):new Sa(l,s,c,p),i.push(\"/a_\"+a)}else{var d=za(a,c,\"composite\");this.binders[a]=new Ea(l,s,c,u,e,d),i.push(\"/z_\"+a)}}}this.cacheKey=i.sort().join(\"\")};La.prototype.getMaxValue=function(t){var e=this.binders[t];return e instanceof Sa||e instanceof Ea?e.maxValue:0},La.prototype.populatePaintArrays=function(t,e,r,n,i){for(var a in this.binders){var o=this.binders[a];(o instanceof Sa||o instanceof Ea||o instanceof Ca)&&o.populatePaintArray(t,e,r,n,i)}},La.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders){var n=this.binders[r];n instanceof Aa&&n.setConstantPatternPositions(t,e)}},La.prototype.updatePaintArrays=function(t,e,r,n,i){var a=!1;for(var o in t)for(var s=0,l=e.getPositions(o);s<l.length;s+=1){var c=l[s],u=r.feature(c.index);for(var f in this.binders){var h=this.binders[f];if((h instanceof Sa||h instanceof Ea||h instanceof Ca)&&!0===h.expression.isStateDependent){var p=n.paint.get(f);h.expression=p.value,h.updatePaintArray(c.start,c.end,u,t[o],i),a=!0}}}return a},La.prototype.defines=function(){var t=[];for(var e in this.binders){var r=this.binders[e];(r instanceof Ma||r instanceof Aa)&&t.push.apply(t,r.uniformNames.map((function(t){return\"#define HAS_UNIFORM_\"+t})))}return t},La.prototype.getPaintVertexBuffers=function(){return this._buffers},La.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders){var i=this.binders[n];if(i instanceof Ma||i instanceof Aa||i instanceof Ea)for(var a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s],s);r.push({name:s,property:n,binding:l})}}}return r},La.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property;this.binders[l].setUniform(o.binding,n,r.get(l),s)}},La.prototype.updatePaintBuffers=function(t){for(var e in this._buffers=[],this.binders){var r=this.binders[e];if(t&&r instanceof Ca){var n=2===t.fromScale?r.zoomInPaintVertexBuffer:r.zoomOutPaintVertexBuffer;n&&this._buffers.push(n)}else(r instanceof Sa||r instanceof Ea)&&r.paintVertexBuffer&&this._buffers.push(r.paintVertexBuffer)}},La.prototype.upload=function(t){for(var e in this.binders){var r=this.binders[e];(r instanceof Sa||r instanceof Ea||r instanceof Ca)&&r.upload(t)}this.updatePaintBuffers()},La.prototype.destroy=function(){for(var t in this.binders){var e=this.binders[t];(e instanceof Sa||e instanceof Ea||e instanceof Ca)&&e.destroy()}};var Ia=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=new La(o,r,n,t)}this.needsUpload=!1,this._featureMap=new fa,this._bufferOffset=0};function Pa(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function za(t,e,r){var n={color:{source:Gi,composite:Yi},number:{source:ji,composite:Gi}},i=function(t){return{\"line-pattern\":{source:Ci,composite:Ci},\"fill-pattern\":{source:Ci,composite:Ci},\"fill-extrusion-pattern\":{source:Ci,composite:Ci}}[t]}(t);return i&&i[r]||n[e][r]}Ia.prototype.populatePaintArrays=function(t,e,r,n,i,a){for(var o in this.programConfigurations)this.programConfigurations[o].populatePaintArrays(t,e,n,i,a);void 0!==e.id&&this._featureMap.add(e.id,r,this._bufferOffset,t),this._bufferOffset=t,this.needsUpload=!0},Ia.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,this._featureMap,e,o,n)||this.needsUpload}},Ia.prototype.get=function(t){return this.programConfigurations[t]},Ia.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},Ia.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},Dn(\"ConstantBinder\",Ma),Dn(\"CrossFadedConstantBinder\",Aa),Dn(\"SourceExpressionBinder\",Sa),Dn(\"CrossFadedCompositeBinder\",Ca),Dn(\"CompositeExpressionBinder\",Ea),Dn(\"ProgramConfiguration\",La,{omit:[\"_buffers\"]}),Dn(\"ProgramConfigurationSet\",Ia);var Oa={min:-1*Math.pow(2,14),max:Math.pow(2,14)-1};function Da(t){for(var e=8192/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<Oa.min||o.x>Oa.max||o.y<Oa.min||o.y>Oa.max)&&(_(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\"),o.x=l(o.x,Oa.min,Oa.max),o.y=l(o.y,Oa.min,Oa.max))}return r}function Ra(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var Fa=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Mi,this.indexArray=new Fi,this.segments=new ia,this.programConfigurations=new Ia(na,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function Ba(t,e){for(var r=0;r<t.length;r++)if(Wa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Wa(t,e[n]))return!0;return!!Va(t,e)}function Na(t,e,r){return!!Wa(t,e)||!!Ha(e,t,r)}function ja(t,e){if(1===t.length)return Ya(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Wa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ya(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(Va(t,e[o]))return!0;return!1}function Ua(t,e,r){if(t.length>1){if(Va(t,e))return!0;for(var n=0;n<e.length;n++)if(Ha(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(Ha(t[i],e,r))return!0;return!1}function Va(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(qa(n,i,e[a],e[a+1]))return!0;return!1}function qa(t,e,r,n){return w(t,r,n)!==w(e,r,n)&&w(t,e,r)!==w(t,e,n)}function Ha(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(Ga(t,e[i-1],e[i])<n)return!0;return!1}function Ga(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return t.distSqr(i<0?e:i>1?r:r.sub(e)._mult(i)._add(e))}function Ya(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)(n=r[s]).y>e.y!=(i=r[l]).y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Wa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Xa(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=w(t,e,r[0]);return a!==w(t,e,r[1])||a!==w(t,e,r[2])||a!==w(t,e,r[3])}function Za(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).getMaxValue(t)}function Ja(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ka(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++)s.push(t[l].sub(o));return s}Fa.prototype.populate=function(t,e,r){var n=this.layers[0],i=[],a=null;\"circle\"===n.type&&(a=n.layout.get(\"circle-sort-key\"));for(var o=0,s=t;o<s.length;o+=1){var l=s[o],c=l.feature,u=l.id,f=l.index,h=l.sourceLayerIndex,p=this.layers[0]._featureFilter.needGeometry,d={type:c.type,id:u,properties:c.properties,geometry:p?Da(c):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),d,r)){p||(d.geometry=Da(c));var g=a?a.evaluate(d,{},r):void 0;i.push({id:u,properties:c.properties,type:c.type,sourceLayerIndex:h,index:f,geometry:d.geometry,patterns:{},sortKey:g})}}a&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var m=0,v=i;m<v.length;m+=1){var y=v[m],x=y.geometry,b=y.index,_=y.sourceLayerIndex,w=t[b].feature;this.addFeature(y,x,b,r),e.featureIndex.insert(w,x,b,_,this.index)}},Fa.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Fa.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Fa.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Fa.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,na),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Fa.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Fa.prototype.addFeature=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1)for(var o=0,s=a[i];o<s.length;o+=1){var l=s[o],c=l.x,u=l.y;if(!(c<0||c>=8192||u<0||u>=8192)){var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),h=f.vertexLength;Ra(this.layoutVertexArray,c,u,-1,-1),Ra(this.layoutVertexArray,c,u,1,-1),Ra(this.layoutVertexArray,c,u,1,1),Ra(this.layoutVertexArray,c,u,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),f.vertexLength+=4,f.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{},n)},Dn(\"CircleBucket\",Fa,{omit:[\"layers\"]});var Qa=new yi({\"circle-sort-key\":new di(At.layout_circle[\"circle-sort-key\"])}),$a={paint:new yi({\"circle-radius\":new di(At.paint_circle[\"circle-radius\"]),\"circle-color\":new di(At.paint_circle[\"circle-color\"]),\"circle-blur\":new di(At.paint_circle[\"circle-blur\"]),\"circle-opacity\":new di(At.paint_circle[\"circle-opacity\"]),\"circle-translate\":new pi(At.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new pi(At.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new pi(At.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new pi(At.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new di(At.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new di(At.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new di(At.paint_circle[\"circle-stroke-opacity\"])}),layout:Qa},to=\"undefined\"!=typeof Float32Array?Float32Array:Array;function eo(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}function ro(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*m,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,t[4]=(x=r[4])*n+(b=r[5])*s+(_=r[6])*f+(w=r[7])*g,t[5]=x*i+b*l+_*h+w*m,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,t[8]=(x=r[8])*n+(b=r[9])*s+(_=r[10])*f+(w=r[11])*g,t[9]=x*i+b*l+_*h+w*m,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,t[12]=(x=r[12])*n+(b=r[13])*s+(_=r[14])*f+(w=r[15])*g,t[13]=x*i+b*l+_*h+w*m,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}Math.hypot||(Math.hypot=function(){for(var t=arguments,e=0,r=arguments.length;r--;)e+=t[r]*t[r];return Math.sqrt(e)});var no,io=ro;function ao(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}no=new to(3),to!=Float32Array&&(no[0]=0,no[1]=0,no[2]=0),function(){var t=new to(4);to!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();var oo=(function(){var t=new to(2);to!=Float32Array&&(t[0]=0,t[1]=0)}(),function(t){function e(e){t.call(this,e,$a)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new Fa(t)},e.prototype.queryRadius=function(t){var e=t;return Za(\"circle-radius\",this,e)+Za(\"circle-stroke-width\",this,e)+Ja(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ka(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),f=u?l:function(t,e){return t.map((function(t){return so(t,e)}))}(l,s),h=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,m=d[p];g<m.length;g+=1){var v=m[g],y=u?v:so(v,s),x=h,b=ao([],[v.x,v.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),Na(f,y,x))return!0}return!1},e}(xi));function so(t,e){var r=ao([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var lo=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Fa);function co(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function uo(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=co({},{width:n,height:i},r);fo(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function fo(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,f=0;f<i.width*a;f++)s[u+f]=o[c+f];return e}Dn(\"HeatmapBucket\",lo,{omit:[\"layers\"]});var ho=function(t,e){co(this,t,1,e)};ho.prototype.resize=function(t){uo(this,t,1)},ho.prototype.clone=function(){return new ho({width:this.width,height:this.height},new Uint8Array(this.data))},ho.copy=function(t,e,r,n,i){fo(t,e,r,n,i,1)};var po=function(t,e){co(this,t,4,e)};po.prototype.resize=function(t){uo(this,t,4)},po.prototype.replace=function(t,e){e?this.data.set(t):this.data=t instanceof Uint8ClampedArray?new Uint8Array(t.buffer):t},po.prototype.clone=function(){return new po({width:this.width,height:this.height},new Uint8Array(this.data))},po.copy=function(t,e,r,n,i){fo(t,e,r,n,i,4)},Dn(\"AlphaImage\",ho),Dn(\"RGBAImage\",po);var go={paint:new yi({\"heatmap-radius\":new di(At.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new di(At.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new pi(At.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new vi(At.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new pi(At.paint_heatmap[\"heatmap-opacity\"])})};function mo(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new po({width:256,height:1},r)}var vo=function(t){function e(e){t.call(this,e,go),this._updateColorRamp()}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new lo(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){this.colorRamp=mo(this._transitionablePaint._values[\"heatmap-color\"].value.expression,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(xi),yo={paint:new yi({\"hillshade-illumination-direction\":new pi(At.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new pi(At.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new pi(At.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new pi(At.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new pi(At.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new pi(At.paint_hillshade[\"hillshade-accent-color\"])})},xo=function(t){function e(e){t.call(this,e,yo)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(xi),bo=Ti([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,_o=To,wo=To;function To(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,f=u?e[0]*r:t.length,h=ko(t,0,f,r,!0),p=[];if(!h||h.next===h.prev)return p;if(u&&(h=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=ko(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(Do(o));for(s.sort(Io),i=0;i<s.length;i++)Po(s[i],r),r=Mo(r,r.next);return r}(t,e,h,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<f;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return Ao(h,p,r,n,i,c),p}function ko(t,e,r,n,i){var a,o;if(i===Xo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=Go(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=Go(a,t[a],t[a+1],o);return o&&No(o,o.next)&&(Yo(o),o=o.next),o}function Mo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!No(n,n.next)&&0!==Bo(n.prev,n,n.next))n=n.next;else{if(Yo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function Ao(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=Oo(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?Eo(t,n,i,a):So(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),Yo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?Ao(t=Co(Mo(t),e,r),e,r,n,i,a,2):2===o&&Lo(t,e,r,n,i,a):Ao(Mo(t),e,r,n,i,a,1);break}}}function So(t){var e=t.prev,r=t,n=t.next;if(Bo(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(Ro(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&Bo(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function Eo(t,e,r,n){var i=t.prev,a=t,o=t.next;if(Bo(i,a,o)>=0)return!1;for(var s=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,l=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,c=Oo(i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,e,r,n),u=Oo(s,l,e,r,n),f=t.prevZ,h=t.nextZ;f&&f.z>=c&&h&&h.z<=u;){if(f!==t.prev&&f!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;if(f=f.prevZ,h!==t.prev&&h!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;h=h.nextZ}for(;f&&f.z>=c;){if(f!==t.prev&&f!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;f=f.prevZ}for(;h&&h.z<=u;){if(h!==t.prev&&h!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;h=h.nextZ}return!0}function Co(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!No(i,a)&&jo(i,n,n.next,a)&&qo(i,a)&&qo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),Yo(n),Yo(n.next),n=t=a),n=n.next}while(n!==t);return Mo(n)}function Lo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&Fo(o,s)){var l=Ho(o,s);return o=Mo(o,o.next),l=Mo(l,l.next),Ao(o,e,r,n,i,a),void Ao(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function Io(t,e){return t.x-e.x}function Po(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&Ro(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),qo(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&zo(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=Ho(e,t);Mo(e,e.next),Mo(r,r.next)}}function zo(t,e){return Bo(t.prev,t,e.prev)<0&&Bo(e.next,t,t.next)<0}function Oo(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function Do(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function Ro(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function Fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&jo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(qo(t,e)&&qo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(Bo(t.prev,t,e.prev)||Bo(t,e.prev,e))||No(t,e)&&Bo(t.prev,t,t.next)>0&&Bo(e.prev,e,e.next)>0)}function Bo(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function No(t,e){return t.x===e.x&&t.y===e.y}function jo(t,e,r,n){var i=Vo(Bo(t,e,r)),a=Vo(Bo(t,e,n)),o=Vo(Bo(r,n,t)),s=Vo(Bo(r,n,e));return i!==a&&o!==s||!(0!==i||!Uo(t,r,e))||!(0!==a||!Uo(t,n,e))||!(0!==o||!Uo(r,t,n))||!(0!==s||!Uo(r,e,n))}function Uo(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function Vo(t){return t>0?1:t<0?-1:0}function qo(t,e){return Bo(t.prev,t,t.next)<0?Bo(t,e,t.next)>=0&&Bo(t,t.prev,e)>=0:Bo(t,e,t.prev)<0||Bo(t,t.next,e)<0}function Ho(t,e){var r=new Wo(t.i,t.x,t.y),n=new Wo(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function Go(t,e,r,n){var i=new Wo(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function Yo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function Wo(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function Xo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function Zo(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var f=e[r],h=n,p=i;for(Jo(e,n,r),a(e[i],f)>0&&Jo(e,n,i);h<p;){for(Jo(e,h,p),h++,p--;a(e[h],f)<0;)h++;for(;a(e[p],f)>0;)p--}0===a(e[n],f)?Jo(e,n,p):Jo(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ko)}function Jo(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ko(t,e){return t<e?-1:t>e?1:0}function Qo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(Zo(a[l],e,1,a[l].length-1,$o),a[l]=a[l].slice(0,e));return a}function $o(t,e){return e.area-t.area}function ts(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function es(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{},i.availableImages),f=c.evaluate({zoom:n},r,{},i.availableImages),h=c.evaluate({zoom:n+1},r,{},i.availableImages);f=f&&f.name?f.name:f,h=h&&h.name?h.name:h,a[u=u&&u.name?u.name:u]=!0,a[f]=!0,a[h]=!0,r.patterns[l.id]={min:u,mid:f,max:h}}}return r}To.deviation=function(t,e,r,n){var i=e&&e.length,a=Math.abs(Xo(t,0,i?e[0]*r:t.length,r));if(i)for(var o=0,s=e.length;o<s;o++)a-=Math.abs(Xo(t,e[o]*r,o<s-1?e[o+1]*r:t.length,r));var l=0;for(o=0;o<n.length;o+=3){var c=n[o]*r,u=n[o+1]*r,f=n[o+2]*r;l+=Math.abs((t[c]-t[f])*(t[u+1]-t[c+1])-(t[c]-t[u])*(t[f+1]-t[c+1]))}return 0===a&&0===l?0:Math.abs((l-a)/a)},To.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&r.holes.push(n+=t[i-1].length)}return r},_o.default=wo;var rs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Mi,this.indexArray=new Fi,this.indexArray2=new qi,this.programConfigurations=new Ia(bo,t.layers,t.zoom),this.segments=new ia,this.segments2=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};rs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"fill\",this.layers,e);for(var n=this.layers[0].layout.get(\"fill-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Da(l):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),p,r)){h||(p.geometry=Da(l));var d=n?n.evaluate(p,{},r,e.availableImages):void 0;i.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=i;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"fill\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},rs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},rs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},rs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},rs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},rs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,bo),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},rs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},rs.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Qo(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray),h=f.vertexLength,p=[],d=[],g=0,m=s;g<m.length;g+=1){var v=m[g];if(0!==v.length){v!==s[0]&&d.push(p.length/2);var y=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),x=y.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(x+v.length-1,x),p.push(v[0].x),p.push(v[0].y);for(var b=1;b<v.length;b++)this.layoutVertexArray.emplaceBack(v[b].x,v[b].y),this.indexArray2.emplaceBack(x+b-1,x+b),p.push(v[b].x),p.push(v[b].y);y.vertexLength+=v.length,y.primitiveLength+=v.length}}for(var _=_o(p,d),w=0;w<_.length;w+=3)this.indexArray.emplaceBack(h+_[w],h+_[w+1],h+_[w+2]);f.vertexLength+=l,f.primitiveLength+=_.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Dn(\"FillBucket\",rs,{omit:[\"layers\",\"patternFeatures\"]});var ns=new yi({\"fill-sort-key\":new di(At.layout_fill[\"fill-sort-key\"])}),is={paint:new yi({\"fill-antialias\":new pi(At.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new di(At.paint_fill[\"fill-opacity\"]),\"fill-color\":new di(At.paint_fill[\"fill-color\"]),\"fill-outline-color\":new di(At.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new pi(At.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new pi(At.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new gi(At.paint_fill[\"fill-pattern\"])}),layout:ns},as=function(t){function e(e){t.call(this,e,is)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r);var n=this.paint._values[\"fill-outline-color\"];\"constant\"===n.value.kind&&void 0===n.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new rs(t)},e.prototype.queryRadius=function(){return Ja(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ja(Ka(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(xi),os=Ti([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,ss=ls;function ls(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(cs,this,e)}function cs(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function us(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)n+=((r=t[o]).x-(e=t[i]).x)*(e.y+r.y);return n}ls.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ls.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},ls.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},ls.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=ls.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e];t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp((180-360*(r.y+s)/a)*Math.PI/180))-90]}}switch(this.type){case 1:var f=[];for(n=0;n<l.length;n++)f[n]=l[n][0];u(l=f);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=us(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var h={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(h.id=this.id),h};var fs=hs;function hs(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(ps,this,e),this.length=this._features.length}function ps(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function ds(t,e,r){if(3===t){var n=new fs(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}hs.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new ss(this._pbf,e,this.extent,this._keys,this._values)};var gs={VectorTile:function(t,e){this.layers=t.readFields(ds,{},e)},VectorTileFeature:ss,VectorTileLayer:fs},ms=gs.VectorTileFeature.types,vs=Math.pow(2,13);function ys(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*vs)+o,i*vs*2,a*vs*2,Math.round(s))}var xs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Si,this.indexArray=new Fi,this.programConfigurations=new Ia(os,t.layers,t.zoom),this.segments=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function bs(t,e){return t.x===e.x&&(t.x<0||t.x>8192)||t.y===e.y&&(t.y<0||t.y>8192)}xs.prototype.populate=function(t,e,r){this.features=[],this.hasPattern=ts(\"fill-extrusion\",this.layers,e);for(var n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.feature,s=a.id,l=a.index,c=a.sourceLayerIndex,u=this.layers[0]._featureFilter.needGeometry,f={type:o.type,id:s,properties:o.properties,geometry:u?Da(o):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),f,r)){var h={id:s,sourceLayerIndex:c,index:l,geometry:u?f.geometry:Da(o),properties:o.properties,type:o.type,patterns:{}};void 0!==o.id&&(h.id=o.id),this.hasPattern?this.features.push(es(\"fill-extrusion\",this.layers,h,this.zoom,e)):this.addFeature(h,h.geometry,l,r,{}),e.featureIndex.insert(o,h.geometry,l,c,this.index,!0)}}},xs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.features;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},xs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},xs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},xs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},xs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,os),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},xs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},xs.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Qo(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,p=s;h<p.length;h+=1){var d=p[h];if(0!==d.length&&!((P=d).every((function(t){return t.x<0}))||P.every((function(t){return t.x>8192}))||P.every((function(t){return t.y<0}))||P.every((function(t){return t.y>8192}))))for(var g=0,m=0;m<d.length;m++){var v=d[m];if(m>=1){var y=d[m-1];if(!bs(v,y)){f.vertexLength+4>ia.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var x=v.sub(y)._perp()._unit(),b=y.dist(v);g+b>32768&&(g=0),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,0,g),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,1,g),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,0,g+=b),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,1,g);var _=f.vertexLength;this.indexArray.emplaceBack(_,_+2,_+1),this.indexArray.emplaceBack(_+1,_+2,_+3),f.vertexLength+=4,f.primitiveLength+=2}}}}if(f.vertexLength+l>ia.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray)),\"Polygon\"===ms[t.type]){for(var w=[],T=[],k=f.vertexLength,M=0,A=s;M<A.length;M+=1){var S=A[M];if(0!==S.length){S!==s[0]&&T.push(w.length/2);for(var E=0;E<S.length;E++){var C=S[E];ys(this.layoutVertexArray,C.x,C.y,0,0,1,1,0),w.push(C.x),w.push(C.y)}}}for(var L=_o(w,T),I=0;I<L.length;I+=3)this.indexArray.emplaceBack(k+L[I],k+L[I+2],k+L[I+1]);f.primitiveLength+=L.length/3,f.vertexLength+=l}}var P;this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Dn(\"FillExtrusionBucket\",xs,{omit:[\"layers\",\"features\"]});var _s={paint:new yi({\"fill-extrusion-opacity\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new gi(At[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},ws=function(t){function e(e){t.call(this,e,_s)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new xs(t)},e.prototype.queryRadius=function(){return Ja(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ka(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),f=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),h=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];ao(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,f=n[8]*r,h=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,m=t;g<m.length;g+=1){for(var v=[],y=[],x=0,b=m[g];x<b.length;x+=1){var _=b[x],w=_.x,T=_.y,k=n[0]*w+n[4]*T+n[12],M=n[1]*w+n[5]*T+n[13],A=n[2]*w+n[6]*T+n[14],S=n[3]*w+n[7]*T+n[15],E=A+c,C=S+u,L=k+f,I=M+h,P=A+p,z=S+d,O=new i((k+s)/C,(M+l)/C);O.z=E/C,v.push(O);var D=new i(L/z,I/z);D.z=P/z,y.push(D)}a.push(v),o.push(y)}return[a,o]}(n,f,u,l);return function(t,e,r){var n=1/0;ja(r,e)&&(n=ks(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=[l,a[s+1],o[s+1],o[s],l];Ba(r,c)&&(n=Math.min(n,ks(r,c)))}return n!==1/0&&n}(p[0],p[1],h)},e}(xi);function Ts(t,e){return t.x*e.x+t.y*e.y}function ks(t,e){if(1===t.length){for(var r,n=0,i=e[n++];!r||i.equals(r);)if(!(r=e[n++]))return 1/0;for(;n<e.length;n++){var a=e[n],o=t[0],s=r.sub(i),l=a.sub(i),c=o.sub(i),u=Ts(s,s),f=Ts(s,l),h=Ts(l,l),p=Ts(c,s),d=Ts(c,l),g=u*h-f*f,m=(h*p-f*d)/g,v=(u*d-f*p)/g,y=i.z*(1-m-v)+r.z*m+a.z*v;if(isFinite(y))return y}return 1/0}for(var x=1/0,b=0,_=e;b<_.length;b+=1)x=Math.min(x,_[b].z);return x}var Ms=Ti([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,As=gs.VectorTileFeature.types,Ss=Math.cos(Math.PI/180*37.5),Es=Math.pow(2,14)/.5,Cs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Ei,this.indexArray=new Fi,this.programConfigurations=new Ia(Ms,t.layers,t.zoom),this.segments=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};Cs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"line\",this.layers,e);for(var n=this.layers[0].layout.get(\"line-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Da(l):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),p,r)){h||(p.geometry=Da(l));var d=n?n.evaluate(p,{},r):void 0;i.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=i;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"line\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},Cs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Cs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},Cs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Cs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Cs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ms),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Cs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Cs.prototype.addFeature=function(t,e,r,n,i){for(var a=this.layers[0].layout,o=a.get(\"line-join\").evaluate(t,{}),s=a.get(\"line-cap\"),l=a.get(\"line-miter-limit\"),c=a.get(\"line-round-limit\"),u=0,f=e;u<f.length;u+=1)this.addLine(f[u],t,o,s,l,c);this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Cs.prototype.addLine=function(t,e,r,n,i,a){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")){this.clipStart=+e.properties.mapbox_clip_start,this.clipEnd=+e.properties.mapbox_clip_end;for(var o=0;o<t.length-1;o++)this.totalDistance+=t[o].dist(t[o+1]);this.updateScaledDistance()}for(var s=\"Polygon\"===As[e.type],l=t.length;l>=2&&t[l-1].equals(t[l-2]);)l--;for(var c=0;c<l-1&&t[c].equals(t[c+1]);)c++;if(!(l<(s?3:2))){\"bevel\"===r&&(i=1.05);var u,f=this.overscaling<=16?122880/(512*this.overscaling):0,h=this.segments.prepareSegment(10*l,this.layoutVertexArray,this.indexArray),p=void 0,d=void 0,g=void 0,m=void 0;this.e1=this.e2=-1,s&&(m=t[c].sub(u=t[l-2])._unit()._perp());for(var v=c;v<l;v++)if(!(d=v===l-1?s?t[c+1]:void 0:t[v+1])||!t[v].equals(d)){m&&(g=m),u&&(p=u),u=t[v],m=d?d.sub(u)._unit()._perp():g;var y=(g=g||m).add(m);0===y.x&&0===y.y||y._unit();var x=g.x*m.x+g.y*m.y,b=y.x*m.x+y.y*m.y,_=0!==b?1/b:1/0,w=2*Math.sqrt(2-2*b),T=b<Ss&&p&&d,k=g.x*m.y-g.y*m.x>0;if(T&&v>c){var M=u.dist(p);if(M>2*f){var A=u.sub(u.sub(p)._mult(f/M)._round());this.updateDistance(p,A),this.addCurrentVertex(A,g,0,0,h),p=A}}var S=p&&d,E=S?r:s?\"butt\":n;if(S&&\"round\"===E&&(_<a?E=\"miter\":_<=2&&(E=\"fakeround\")),\"miter\"===E&&_>i&&(E=\"bevel\"),\"bevel\"===E&&(_>2&&(E=\"flipbevel\"),_<i&&(E=\"miter\")),p&&this.updateDistance(p,u),\"miter\"===E)y._mult(_),this.addCurrentVertex(u,y,0,0,h);else if(\"flipbevel\"===E){if(_>100)y=m.mult(-1);else{var C=_*g.add(m).mag()/g.sub(m).mag();y._perp()._mult(C*(k?-1:1))}this.addCurrentVertex(u,y,0,0,h),this.addCurrentVertex(u,y.mult(-1),0,0,h)}else if(\"bevel\"===E||\"fakeround\"===E){var L=-Math.sqrt(_*_-1),I=k?L:0,P=k?0:L;if(p&&this.addCurrentVertex(u,g,I,P,h),\"fakeround\"===E)for(var z=Math.round(180*w/Math.PI/20),O=1;O<z;O++){var D=O/z;if(.5!==D){var R=D-.5;D+=D*R*(D-1)*((1.0904+x*(x*(3.55645-1.43519*x)-3.2452))*R*R+(.848013+x*(.215638*x-1.06021)))}var F=m.sub(g)._mult(D)._add(g)._unit()._mult(k?-1:1);this.addHalfVertex(u,F.x,F.y,!1,k,0,h)}d&&this.addCurrentVertex(u,m,-I,-P,h)}else if(\"butt\"===E)this.addCurrentVertex(u,y,0,0,h);else if(\"square\"===E){var B=p?1:-1;this.addCurrentVertex(u,y,B,B,h)}else\"round\"===E&&(p&&(this.addCurrentVertex(u,g,0,0,h),this.addCurrentVertex(u,g,1,1,h,!0)),d&&(this.addCurrentVertex(u,m,-1,-1,h,!0),this.addCurrentVertex(u,m,0,0,h)));if(T&&v<l-1){var N=u.dist(d);if(N>2*f){var j=u.add(d.sub(u)._mult(f/N)._round());this.updateDistance(u,j),this.addCurrentVertex(j,m,0,0,h),u=j}}}}},Cs.prototype.addCurrentVertex=function(t,e,r,n,i,a){void 0===a&&(a=!1);var o=e.y*n-e.x,s=-e.y-e.x*n;this.addHalfVertex(t,e.x+e.y*r,e.y-e.x*r,a,!1,r,i),this.addHalfVertex(t,o,s,a,!0,-n,i),this.distance>Es/2&&0===this.totalDistance&&(this.distance=0,this.addCurrentVertex(t,e,r,n,i,a))},Cs.prototype.addHalfVertex=function(t,e,r,n,i,a,o){var s=.5*this.scaledDistance;this.layoutVertexArray.emplaceBack((t.x<<1)+(n?1:0),(t.y<<1)+(i?1:0),Math.round(63*e)+128,Math.round(63*r)+128,1+(0===a?0:a<0?-1:1)|(63&s)<<2,s>>6);var l=o.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,l),o.primitiveLength++),i?this.e2=l:this.e1=l},Cs.prototype.updateScaledDistance=function(){this.scaledDistance=this.totalDistance>0?(this.clipStart+(this.clipEnd-this.clipStart)*this.distance/this.totalDistance)*(Es-1):this.distance},Cs.prototype.updateDistance=function(t,e){this.distance+=t.dist(e),this.updateScaledDistance()},Dn(\"LineBucket\",Cs,{omit:[\"layers\",\"patternFeatures\"]});var Ls=new yi({\"line-cap\":new pi(At.layout_line[\"line-cap\"]),\"line-join\":new di(At.layout_line[\"line-join\"]),\"line-miter-limit\":new pi(At.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new pi(At.layout_line[\"line-round-limit\"]),\"line-sort-key\":new di(At.layout_line[\"line-sort-key\"])}),Is={paint:new yi({\"line-opacity\":new di(At.paint_line[\"line-opacity\"]),\"line-color\":new di(At.paint_line[\"line-color\"]),\"line-translate\":new pi(At.paint_line[\"line-translate\"]),\"line-translate-anchor\":new pi(At.paint_line[\"line-translate-anchor\"]),\"line-width\":new di(At.paint_line[\"line-width\"]),\"line-gap-width\":new di(At.paint_line[\"line-gap-width\"]),\"line-offset\":new di(At.paint_line[\"line-offset\"]),\"line-blur\":new di(At.paint_line[\"line-blur\"]),\"line-dasharray\":new mi(At.paint_line[\"line-dasharray\"]),\"line-pattern\":new gi(At.paint_line[\"line-pattern\"]),\"line-gradient\":new vi(At.paint_line[\"line-gradient\"])}),layout:Ls},Ps=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new ii(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=u({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(di))(Is.paint.properties[\"line-width\"].specification);Ps.useIntegerZoom=!0;var zs=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){this.gradient=mo(this._transitionablePaint._values[\"line-gradient\"].value.expression,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r),this.paint._values[\"line-floorwidth\"]=Ps.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new Cs(t)},e.prototype.queryRadius=function(t){var e=t,r=Os(Za(\"line-width\",this,e),Za(\"line-gap-width\",this,e)),n=Za(\"line-offset\",this,e);return r/2+Math.abs(n)+Ja(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ka(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*Os(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l],u=o[l+1],f=0===l?n:c.sub(o[l-1])._unit()._perp(),h=l===o.length-1?n:u.sub(c)._unit()._perp(),p=f._add(h)._unit();p._mult(1/(p.x*h.x+p.y*h.y)),s.push(p._mult(e)._add(c))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Wa(t,i[a]))return!0;if(Ua(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(xi);function Os(t,e){return e>0?e+2*t:t}var Ds=Ti([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"},{name:\"a_pixeloffset\",components:4,type:\"Int16\"}],4),Rs=Ti([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),Fs=(Ti([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),Ti([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),Bs=(Ti([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"}]),Ti([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),Ns=Ti([{name:\"a_pos\",components:2,type:\"Float32\"},{name:\"a_radius\",components:1,type:\"Float32\"},{name:\"a_flags\",components:2,type:\"Int16\"}],4);function js(t,e,r){return t.sections.forEach((function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),ni.applyArabicShaping&&(t=ni.applyArabicShaping(t)),t}(t.text,e,r)})),t}Ti([{name:\"triangle\",components:3,type:\"Uint16\"}]),Ti([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"placedOrientation\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Int16\",name:\"associatedIconIndex\"}]),Ti([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Int16\",name:\"placedIconSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedIconSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"verticalTextBoxStartIndex\"},{type:\"Uint16\",name:\"verticalTextBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"verticalIconBoxStartIndex\"},{type:\"Uint16\",name:\"verticalIconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint16\",name:\"numVerticalIconVertices\"},{type:\"Uint16\",name:\"useRuntimeCollisionCircles\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",components:2,name:\"textOffset\"},{type:\"Float32\",name:\"collisionCircleDiameter\"}]),Ti([{type:\"Float32\",name:\"offsetX\"}]),Ti([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var Us={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},Vs=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},qs=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Hs=Gs;function Gs(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}Gs.Varint=0,Gs.Fixed64=1,Gs.Bytes=2,Gs.Fixed32=5;var Ys=\"undefined\"==typeof TextDecoder?null:new TextDecoder(\"utf8\");function Ws(t){return t.type===Gs.Bytes?t.readVarint()+t.pos:t.pos+1}function Xs(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function Zs(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function Js(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function Ks(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function Qs(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function $s(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function tl(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function el(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function rl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function nl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function il(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function al(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function ol(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function sl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}function ll(t,e,r){1===t&&r.readMessage(cl,e)}function cl(t,e,r){if(3===t){var n=r.readMessage(ul,{}),i=n.width,a=n.height,o=n.left,s=n.top,l=n.advance;e.push({id:n.id,bitmap:new ho({width:i+6,height:a+6},n.bitmap),metrics:{width:i,height:a,left:o,top:s,advance:l}})}}function ul(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}function fl(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort((function(t,e){return e.h-t.h}));for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var f=u[c],h=o.length-1;h>=0;h--){var p=o[h];if(!(f.w>p.w||f.h>p.h)){if(f.x=p.x,f.y=p.y,l=Math.max(l,f.y+f.h),s=Math.max(s,f.x+f.w),f.w===p.w&&f.h===p.h){var d=o.pop();h<o.length&&(o[h]=d)}else f.h===p.h?(p.x+=f.w,p.w-=f.w):f.w===p.w?(p.y+=f.h,p.h-=f.h):(o.push({x:p.x+f.w,y:p.y,w:p.w-f.w,h:f.h}),p.y+=f.h,p.h-=f.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}Gs.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=al(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=sl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=al(this.buf,this.pos)+4294967296*al(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=al(this.buf,this.pos)+4294967296*sl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Vs(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Vs(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return Xs(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return Xs(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=this.pos;return this.pos=t,t-e>=12&&Ys?function(t,e,r){return Ys.decode(t.subarray(e,r))}(this.buf,e,t):function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(o=t[i+2],128==(192&(a=t[i+1]))&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(o=t[i+2],s=t[i+3],128==(192&(a=t[i+1]))&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,e,t)},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==Gs.Bytes)return t.push(this.readVarint(e));var r=Ws(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSVarint());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==Gs.Bytes)return t.push(this.readBoolean());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFloat());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==Gs.Bytes)return t.push(this.readDouble());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===Gs.Varint)for(;this.buf[this.pos++]>127;);else if(e===Gs.Bytes)this.pos=this.readVarint()+this.pos;else if(e===Gs.Fixed32)this.pos+=4;else{if(e!==Gs.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,r.buf[r.pos]=127&(t>>>=7)}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&Zs(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),qs(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),qs(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&Zs(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,Gs.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,Js,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,Ks,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,tl,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,Qs,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,$s,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,el,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,rl,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,nl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,il,e)},writeBytesField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var hl=function(t,e){var r=e.pixelRatio,n=e.version,i=e.stretchX,a=e.stretchY,o=e.content;this.paddedRect=t,this.pixelRatio=r,this.stretchX=i,this.stretchY=a,this.content=o,this.version=n},pl={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};pl.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},pl.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},pl.tlbr.get=function(){return this.tl.concat(this.br)},pl.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(hl.prototype,pl);var dl=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=fl(i),o=new po({width:a.w||1,height:a.h||1});for(var s in t){var l=t[s],c=r[s].paddedRect;po.copy(l.data,o,{x:0,y:0},{x:c.x+1,y:c.y+1},l.data)}for(var u in e){var f=e[u],h=n[u].paddedRect,p=h.x+1,d=h.y+1,g=f.data.width,m=f.data.height;po.copy(f.data,o,{x:0,y:0},{x:p,y:d},f.data),po.copy(f.data,o,{x:0,y:m-1},{x:p,y:d-1},{width:g,height:1}),po.copy(f.data,o,{x:0,y:0},{x:p,y:d+m},{width:g,height:1}),po.copy(f.data,o,{x:g-1,y:0},{x:p-1,y:d},{width:1,height:m}),po.copy(f.data,o,{x:0,y:0},{x:p+g,y:d},{width:1,height:m})}this.image=o,this.iconPositions=r,this.patternPositions=n};dl.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new hl(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},dl.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},dl.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl;r.update(e.data,void 0,{x:n[0],y:n[1]})}},Dn(\"ImagePosition\",hl),Dn(\"ImageAtlas\",dl);var gl={horizontal:1,vertical:2,horizontalOnly:3},ml=function(){this.scale=1,this.fontStack=\"\",this.imageName=null};ml.forText=function(t,e){var r=new ml;return r.scale=t||1,r.fontStack=e,r},ml.forImage=function(t){var e=new ml;return e.imageName=t,e};var vl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[],this.imageSectionID=null};function yl(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g){var m,v=vl.fromFeature(t,i);f===gl.vertical&&v.verticalizePunctuation();var y=ni.processBidirectionalText,x=ni.processStyledBidirectionalText;if(y&&1===v.sections.length){m=[];for(var b=0,_=y(v.toString(),Ml(v,c,a,e,n,p,d));b<_.length;b+=1){var w=_[b],T=new vl;T.text=w,T.sections=v.sections;for(var k=0;k<w.length;k++)T.sectionIndex.push(0);m.push(T)}}else if(x){m=[];for(var M=0,A=x(v.text,v.sectionIndex,Ml(v,c,a,e,n,p,d));M<A.length;M+=1){var S=A[M],E=new vl;E.text=S[0],E.sectionIndex=S[1],E.sections=v.sections,m.push(E)}}else m=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(v,Ml(v,c,a,e,n,p,d));var C=[],L={positionedLines:C,text:v.toString(),top:u[1],bottom:u[1],left:u[0],right:u[0],writingMode:f,iconsInText:!1,verticalizable:!1};return function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=0,p=-17,d=0,g=0,m=\"right\"===s?1:\"left\"===s?0:.5,v=0,y=0,x=i;y<x.length;y+=1){var b=x[y];b.trim();var _=b.getMaxScale(),w=24*(_-1),T={positionedGlyphs:[],lineOffset:0};t.positionedLines[v]=T;var k=T.positionedGlyphs,M=0;if(b.length()){for(var A=0;A<b.length();A++){var S=b.getSection(A),E=b.getSectionIndex(A),C=b.getCharCode(A),L=0,I=null,P=null,z=null,O=24,D=!(l===gl.horizontal||!u&&!Hn(C)||u&&(xl[C]||(H=C,Vn.Arabic(H)||Vn[\"Arabic Supplement\"](H)||Vn[\"Arabic Extended-A\"](H)||Vn[\"Arabic Presentation Forms-A\"](H)||Vn[\"Arabic Presentation Forms-B\"](H))));if(S.imageName){var R=n[S.imageName];if(!R)continue;z=S.imageName,t.iconsInText=t.iconsInText||!0,P=R.paddedRect;var F=R.displaySize;S.scale=24*S.scale/f,L=w+(24-F[1]*S.scale),O=(I={width:F[0],height:F[1],left:1,top:-3,advance:D?F[1]:F[0]}).advance;var B=D?F[0]*S.scale-24*_:F[1]*S.scale-24*_;B>0&&B>M&&(M=B)}else{var N=r[S.fontStack],j=N&&N[C];if(j&&j.rect)P=j.rect,I=j.metrics;else{var U=e[S.fontStack],V=U&&U[C];if(!V)continue;I=V.metrics}L=24*(_-S.scale)}D?(t.verticalizable=!0,k.push({glyph:C,imageName:z,x:h,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),h+=O*S.scale+c):(k.push({glyph:C,imageName:z,x:h,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),h+=I.advance*S.scale+c)}0!==k.length&&(d=Math.max(h-c,d),Sl(k,0,k.length-1,m,M)),h=0;var q=a*_+M;T.lineOffset=Math.max(M,w),p+=q,g=Math.max(q,g),++v}else p+=a,++v}var H,G=p- -17,Y=Al(o),W=Y.horizontalAlign,X=Y.verticalAlign;(function(t,e,r,n,i,a,o,s,l){var c,u=(e-r)*i;c=a!==o?-s*n- -17:(-n*l+.5)*o;for(var f=0,h=t;f<h.length;f+=1)for(var p=0,d=h[f].positionedGlyphs;p<d.length;p+=1){var g=d[p];g.x+=u,g.y+=c}})(t.positionedLines,m,W,X,d,g,a,G,i.length),t.top+=-X*G,t.bottom=t.top+G,t.left+=-W*d,t.right=t.left+d}(L,e,r,n,m,o,s,l,f,c,h,g),!function(t){for(var e=0,r=t;e<r.length;e+=1)if(0!==r[e].positionedGlyphs.length)return!1;return!0}(C)&&L}vl.fromFeature=function(t,e){for(var r=new vl,n=0;n<t.sections.length;n++){var i=t.sections[n];i.image?r.addImageSection(i):r.addTextSection(i,e)}return r},vl.prototype.length=function(){return this.text.length},vl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},vl.prototype.getSectionIndex=function(t){return this.sectionIndex[t]},vl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},vl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;e+=n&&Gn(n)&&!Us[t[r+1]]||i&&Gn(i)&&!Us[t[r-1]]||!Us[t[r]]?t[r]:Us[t[r]]}return e}(this.text)},vl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&xl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&xl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},vl.prototype.substring=function(t,e){var r=new vl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},vl.prototype.toString=function(){return this.text},vl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce((function(e,r){return Math.max(e,t.sections[r].scale)}),0)},vl.prototype.addTextSection=function(t,e){this.text+=t.text,this.sections.push(ml.forText(t.scale,t.fontStack||e));for(var r=this.sections.length-1,n=0;n<t.text.length;++n)this.sectionIndex.push(r)},vl.prototype.addImageSection=function(t){var e=t.image?t.image.name:\"\";if(0!==e.length){var r=this.getNextImageSectionCharCode();r?(this.text+=String.fromCharCode(r),this.sections.push(ml.forImage(e)),this.sectionIndex.push(this.sections.length-1)):_(\"Reached maximum number of images 6401\")}else _(\"Can't add FormattedSection with an empty image.\")},vl.prototype.getNextImageSectionCharCode=function(){return this.imageSectionID?this.imageSectionID>=63743?null:++this.imageSectionID:(this.imageSectionID=57344,this.imageSectionID)};var xl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},bl={};function _l(t,e,r,n,i,a){if(e.imageName){var o=n[e.imageName];return o?o.displaySize[0]*e.scale*24/a+i:0}var s=r[e.fontStack],l=s&&s[t];return l?l.metrics.advance*e.scale+i:0}function wl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function Tl(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function kl(t,e,r,n,i,a){for(var o=null,s=wl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],f=wl(e-u.x,r,i,a)+u.badness;f<=s&&(o=u,s=f)}return{index:t,x:e,priorBreak:o,badness:s}}function Ml(t,e,r,n,i,a,o){if(\"point\"!==a)return[];if(!t)return[];for(var s,l=[],c=function(t,e,r,n,i,a){for(var o=0,s=0;s<t.length();s++){var l=t.getSection(s);o+=_l(t.getCharCode(s),l,n,i,e,a)}return o/Math.max(1,Math.ceil(o/r))}(t,e,r,n,i,o),u=t.text.indexOf(\"\\u200b\")>=0,f=0,h=0;h<t.length();h++){var p=t.getSection(h),d=t.getCharCode(h);if(xl[d]||(f+=_l(d,p,n,i,e,o)),h<t.length()-1){var g=!((s=d)<11904||!(Vn[\"Bopomofo Extended\"](s)||Vn.Bopomofo(s)||Vn[\"CJK Compatibility Forms\"](s)||Vn[\"CJK Compatibility Ideographs\"](s)||Vn[\"CJK Compatibility\"](s)||Vn[\"CJK Radicals Supplement\"](s)||Vn[\"CJK Strokes\"](s)||Vn[\"CJK Symbols and Punctuation\"](s)||Vn[\"CJK Unified Ideographs Extension A\"](s)||Vn[\"CJK Unified Ideographs\"](s)||Vn[\"Enclosed CJK Letters and Months\"](s)||Vn[\"Halfwidth and Fullwidth Forms\"](s)||Vn.Hiragana(s)||Vn[\"Ideographic Description Characters\"](s)||Vn[\"Kangxi Radicals\"](s)||Vn[\"Katakana Phonetic Extensions\"](s)||Vn.Katakana(s)||Vn[\"Vertical Forms\"](s)||Vn[\"Yi Radicals\"](s)||Vn[\"Yi Syllables\"](s)));(bl[d]||g||p.imageName)&&l.push(kl(h+1,f,c,l,Tl(d,t.getCharCode(h+1),g&&u),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(kl(t.length(),f,c,l,0,!0))}function Al(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function Sl(t,e,r,n,i){if(n||i)for(var a=t[r],o=(t[r].x+a.metrics.advance*a.scale)*n,s=e;s<=r;s++)t[s].x-=o,t[s].y+=i}function El(t,e,r,n,i,a){var o,s=t.image;if(s.content){var l=s.content,c=s.pixelRatio||1;o=[l[0]/c,l[1]/c,s.displaySize[0]-l[2]/c,s.displaySize[1]-l[3]/c]}var u,f,h,p,d=e.left*a,g=e.right*a;\"width\"===r||\"both\"===r?(p=i[0]+d-n[3],f=i[0]+g+n[1]):f=(p=i[0]+(d+g-s.displaySize[0])/2)+s.displaySize[0];var m=e.top*a,v=e.bottom*a;return\"height\"===r||\"both\"===r?(u=i[1]+m-n[0],h=i[1]+v+n[2]):h=(u=i[1]+(m+v-s.displaySize[1])/2)+s.displaySize[1],{image:s,top:u,right:f,bottom:h,left:p,collisionPadding:o}}bl[10]=!0,bl[32]=!0,bl[38]=!0,bl[40]=!0,bl[41]=!0,bl[43]=!0,bl[45]=!0,bl[47]=!0,bl[173]=!0,bl[183]=!0,bl[8203]=!0,bl[8208]=!0,bl[8211]=!0,bl[8231]=!0;var Cl=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);function Ll(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new ii(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new ii(s)),maxSize:r.evaluate(new ii(l)),interpolationType:i}}function Il(t,e,r){var n=e.uSize,i=r.lowerSize;return\"source\"===t.kind?i/128:\"composite\"===t.kind?Ue(i/128,r.upperSize/128,e.uSizeT):n}function Pl(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=i?l(rr.interpolationFactor(i,e,t.minZoom,t.maxZoom),0,1):0;\"camera\"===t.kind?n=Ue(t.minSize,t.maxSize,a):r=a}return{uSizeT:r,uSize:n}}Dn(\"Anchor\",Cl);var zl=Object.freeze({__proto__:null,getSizeData:Ll,evaluateSizeForFeature:Il,evaluateSizeForZoom:Pl,SIZE_PACK_FACTOR:128});function Ol(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o],f=t[o+1];if(!f)return!1;var h=t[o-1].angleTo(u)-u.angleTo(f);for(h=Math.abs((h+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:h}),c+=h;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=u.dist(f)}return!0}function Dl(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function Rl(t,e,r){return t?.6*e*r:0}function Fl(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function Bl(t,e,r,n,i,a){for(var o=Rl(r,i,a),s=Fl(r,n)*a,l=0,c=Dl(t)/2,u=0;u<t.length-1;u++){var f=t[u],h=t[u+1],p=f.dist(h);if(l+p>c){var d=(c-l)/p,g=Ue(f.x,h.x,d),m=Ue(f.y,h.y,d),v=new Cl(g,m,h.angleTo(f),u);return v._round(),!o||Ol(t,v,s,o,e)?v:void 0}l+=p}}function Nl(t,e,r,n,i,a,o,s,l){var c=Rl(n,a,o),u=Fl(n,i),f=u*o,h=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-f<e/4&&(e=f+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,f=Dl(e),h=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var m=e[g],v=e[g+1],y=m.dist(v),x=v.angleTo(m);p+n<h+y;){var b=((p+=n)-h)/y,_=Ue(m.x,v.x,b),w=Ue(m.y,v.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=f){var T=new Cl(_,w,x,g);T._round(),i&&!Ol(e,T,o,i,a)||d.push(T)}}h+=y}return l||d.length||s||(d=t(e,h/2,n,i,a,o,s,!0,c)),d}(t,h?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,f,h,!1,l)}function jl(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var f=l[u],h=l[u+1];f.x<e&&h.x<e||(f.x<e?f=new i(e,f.y+(e-f.x)/(h.x-f.x)*(h.y-f.y))._round():h.x<e&&(h=new i(e,f.y+(e-f.x)/(h.x-f.x)*(h.y-f.y))._round()),f.y<r&&h.y<r||(f.y<r?f=new i(f.x+(r-f.y)/(h.y-f.y)*(h.x-f.x),r)._round():h.y<r&&(h=new i(f.x+(r-f.y)/(h.y-f.y)*(h.x-f.x),r)._round()),f.x>=n&&h.x>=n||(f.x>=n?f=new i(n,f.y+(n-f.x)/(h.x-f.x)*(h.y-f.y))._round():h.x>=n&&(h=new i(n,f.y+(n-f.x)/(h.x-f.x)*(h.y-f.y))._round()),f.y>=a&&h.y>=a||(f.y>=a?f=new i(f.x+(a-f.y)/(h.y-f.y)*(h.x-f.x),a)._round():h.y>=a&&(h=new i(f.x+(a-f.y)/(h.y-f.y)*(h.x-f.x),a)._round()),c&&f.equals(c[c.length-1])||o.push(c=[f]),c.push(h)))))}return o}function Ul(t,e,r,n){var a=[],o=t.image,s=o.pixelRatio,l=o.paddedRect.w-2,c=o.paddedRect.h-2,u=t.right-t.left,f=t.bottom-t.top,h=o.stretchX||[[0,l]],p=o.stretchY||[[0,c]],d=function(t,e){return t+e[1]-e[0]},g=h.reduce(d,0),m=p.reduce(d,0),v=l-g,y=c-m,x=0,b=g,_=0,w=m,T=0,k=v,M=0,A=y;if(o.content&&n){var S=o.content;x=Vl(h,0,S[0]),_=Vl(p,0,S[1]),b=Vl(h,S[0],S[2]),w=Vl(p,S[1],S[3]),T=S[0]-x,M=S[1]-_,k=S[2]-S[0]-b,A=S[3]-S[1]-w}var E=function(n,a,l,c){var h=Hl(n.stretch-x,b,u,t.left),p=Gl(n.fixed-T,k,n.stretch,g),d=Hl(a.stretch-_,w,f,t.top),v=Gl(a.fixed-M,A,a.stretch,m),y=Hl(l.stretch-x,b,u,t.left),S=Gl(l.fixed-T,k,l.stretch,g),E=Hl(c.stretch-_,w,f,t.top),C=Gl(c.fixed-M,A,c.stretch,m),L=new i(h,d),I=new i(y,d),P=new i(y,E),z=new i(h,E),O=new i(p/s,v/s),D=new i(S/s,C/s),R=e*Math.PI/180;if(R){var F=Math.sin(R),B=Math.cos(R),N=[B,-F,F,B];L._matMult(N),I._matMult(N),z._matMult(N),P._matMult(N)}var j=n.stretch+n.fixed,U=a.stretch+a.fixed;return{tl:L,tr:I,bl:z,br:P,tex:{x:o.paddedRect.x+1+j,y:o.paddedRect.y+1+U,w:l.stretch+l.fixed-j,h:c.stretch+c.fixed-U},writingMode:void 0,glyphOffset:[0,0],sectionIndex:0,pixelOffsetTL:O,pixelOffsetBR:D,minFontScaleX:k/s/u,minFontScaleY:A/s/f,isSDF:r}};if(n&&(o.stretchX||o.stretchY))for(var C=ql(h,v,g),L=ql(p,y,m),I=0;I<C.length-1;I++)for(var P=C[I],z=C[I+1],O=0;O<L.length-1;O++)a.push(E(P,L[O],z,L[O+1]));else a.push(E({fixed:0,stretch:-1},{fixed:0,stretch:-1},{fixed:0,stretch:l+1},{fixed:0,stretch:c+1}));return a}function Vl(t,e,r){for(var n=0,i=0,a=t;i<a.length;i+=1){var o=a[i];n+=Math.max(e,Math.min(r,o[1]))-Math.max(e,Math.min(r,o[0]))}return n}function ql(t,e,r){for(var n=[{fixed:-1,stretch:0}],i=0,a=t;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=n[n.length-1];n.push({fixed:s-c.stretch,stretch:c.stretch}),n.push({fixed:s-c.stretch,stretch:c.stretch+(l-s)})}return n.push({fixed:e+1,stretch:r}),n}function Hl(t,e,r,n){return t/e*r+n}function Gl(t,e,r,n){return t-e*r/n}var Yl=function(t,e,r,n,a,o,s,l,c,u){if(this.boxStartIndex=t.length,c){var f=o.top,h=o.bottom,p=o.collisionPadding;p&&(f-=p[1],h+=p[3]);var d=h-f;d>0&&(d=Math.max(10,d),this.circleDiameter=d)}else{var g=o.top*s-l,m=o.bottom*s+l,v=o.left*s-l,y=o.right*s+l,x=o.collisionPadding;if(x&&(v-=x[0]*s,g-=x[1]*s,y+=x[2]*s,m+=x[3]*s),u){var b=new i(v,g),_=new i(y,g),w=new i(v,m),T=new i(y,m),k=u*Math.PI/180;b._rotate(k),_._rotate(k),w._rotate(k),T._rotate(k),v=Math.min(b.x,_.x,w.x,T.x),y=Math.max(b.x,_.x,w.x,T.x),g=Math.min(b.y,_.y,w.y,T.y),m=Math.max(b.y,_.y,w.y,T.y)}t.emplaceBack(e.x,e.y,v,g,y,m,r,n,a)}this.boxEndIndex=t.length},Wl=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=Xl),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function Xl(t,e){return t<e?-1:t>e?1:0}function Zl(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var f=Math.min(o-n,s-a),h=f/2,p=new Wl([],Jl);if(0===f)return new i(n,a);for(var d=n;d<o;d+=f)for(var g=a;g<s;g+=f)p.push(new Kl(d+h,g+h,h,t));for(var m=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new Kl(r/e,n/e,0,t)}(t),v=p.length;p.length;){var y=p.pop();(y.d>m.d||!m.d)&&(m=y,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*y.d)/1e4,v)),y.max-m.d<=e||(p.push(new Kl(y.p.x-(h=y.h/2),y.p.y-h,h,t)),p.push(new Kl(y.p.x+h,y.p.y-h,h,t)),p.push(new Kl(y.p.x-h,y.p.y+h,h,t)),p.push(new Kl(y.p.x+h,y.p.y+h,h,t)),v+=4)}return r&&(console.log(\"num probes: \"+v),console.log(\"best distance: \"+m.d)),m.p}function Jl(t,e){return e.max-t.max}function Kl(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,Ga(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}Wl.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},Wl.prototype.pop=function(){if(0!==this.length){var t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}},Wl.prototype.peek=function(){return this.data[0]},Wl.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},Wl.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var Ql=Number.POSITIVE_INFINITY;function $l(t,e){return e[1]!==Ql?function(t,e,r){var n=0,i=0;switch(e=Math.abs(e),r=Math.abs(r),t){case\"top-right\":case\"top-left\":case\"top\":i=r-7;break;case\"bottom-right\":case\"bottom-left\":case\"bottom\":i=7-r}switch(t){case\"top-right\":case\"bottom-right\":case\"right\":n=-e;break;case\"top-left\":case\"bottom-left\":case\"left\":n=e}return[n,i]}(t,e[0],e[1]):function(t,e){var r=0,n=0;e<0&&(e=0);var i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-7;break;case\"bottom-right\":case\"bottom-left\":n=7-i;break;case\"bottom\":n=7-e;break;case\"top\":n=e-7}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}(t,e[0])}function tc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function ec(t,e,r,n,a,o,s,l,c,u,f,h,p,d,g){var m=function(t,e,r,n,a,o,s,l){for(var c=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,u=[],f=0,h=e.positionedLines;f<h.length;f+=1)for(var p=h[f],d=0,g=p.positionedGlyphs;d<g.length;d+=1){var m=g[d];if(m.rect){var v=m.rect||{},y=4,x=!0,b=1,_=0,w=(a||l)&&m.vertical,T=m.metrics.advance*m.scale/2;if(l&&e.verticalizable&&(_=p.lineOffset/2-(m.imageName?-(24-m.metrics.width*m.scale)/2:24*(m.scale-1))),m.imageName){var k=s[m.imageName];x=k.sdf,y=1/(b=k.pixelRatio)}var M=a?[m.x+T,m.y]:[0,0],A=a?[0,0]:[m.x+T+r[0],m.y+r[1]-_],S=[0,0];w&&(S=A,A=[0,0]);var E=(m.metrics.left-y)*m.scale-T+A[0],C=(-m.metrics.top-y)*m.scale+A[1],L=E+v.w*m.scale/b,I=C+v.h*m.scale/b,P=new i(E,C),z=new i(L,C),O=new i(E,I),D=new i(L,I);if(w){var R=new i(-T,T- -17),F=-Math.PI/2,B=12-T,N=new i(22-B,-(m.imageName?B:0)),j=new(Function.prototype.bind.apply(i,[null].concat(S)));P._rotateAround(F,R)._add(N)._add(j),z._rotateAround(F,R)._add(N)._add(j),O._rotateAround(F,R)._add(N)._add(j),D._rotateAround(F,R)._add(N)._add(j)}if(c){var U=Math.sin(c),V=Math.cos(c),q=[V,-U,U,V];P._matMult(q),z._matMult(q),O._matMult(q),D._matMult(q)}var H=new i(0,0),G=new i(0,0);u.push({tl:P,tr:z,bl:O,br:D,tex:v,writingMode:e.writingMode,glyphOffset:M,sectionIndex:m.sectionIndex,isSDF:x,pixelOffsetTL:H,pixelOffsetBR:G,minFontScaleX:0,minFontScaleY:0})}}return u}(0,r,l,a,o,s,n,t.allowVerticalPlacement),v=t.textSizeData,y=null;\"source\"===v.kind?(y=[128*a.layout.get(\"text-size\").evaluate(s,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'):\"composite\"===v.kind&&((y=[128*d.compositeTextSizes[0].evaluate(s,{},g),128*d.compositeTextSizes[1].evaluate(s,{},g)])[0]>32640||y[1]>32640)&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'),t.addSymbols(t.text,m,y,l,o,s,u,e,c.lineStartIndex,c.lineLength,p,g);for(var x=0,b=f;x<b.length;x+=1)h[b[x]]=t.text.placedSymbolArray.length-1;return 4*m.length}function rc(t){for(var e in t)return t[e];return null}function nc(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}var ic=gs.VectorTileFeature.types,ac=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function oc(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=s?Math.min(32640,Math.round(s[0])):0,d=s?Math.min(32640,Math.round(s[1])):0;t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,(p<<1)+(l?1:0),d,16*c,16*u,256*f,256*h)}function sc(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}function lc(t){for(var e=0,r=t.sections;e<r.length;e+=1)if(Xn(r[e].text))return!0;return!1}var cc=function(t){this.layoutVertexArray=new Li,this.indexArray=new Fi,this.programConfigurations=t,this.segments=new ia,this.dynamicLayoutVertexArray=new Ii,this.opacityVertexArray=new Pi,this.placedSymbolArray=new Ji};cc.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length&&0===this.indexArray.length&&0===this.dynamicLayoutVertexArray.length&&0===this.opacityVertexArray.length},cc.prototype.upload=function(t,e,r,n){this.isEmpty()||(r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ds.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,Rs.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,ac,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t))},cc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},Dn(\"SymbolBuffers\",cc);var uc=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new ia,this.collisionVertexArray=new Ri};uc.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,Fs.members,!0)},uc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},Dn(\"CollisionBuffers\",uc);var fc=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1,this.hasRTLText=!1,this.sortKeyRanges=[],this.collisionCircleArray=[],this.placementInvProjMatrix=eo([]),this.placementViewportMatrix=eo([]);var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=Ll(this.zoom,e[\"text-size\"]),this.iconSizeData=Ll(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1),this.sortFeaturesByY=(\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey)&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),\"point\"===r.get(\"symbol-placement\")&&(this.writingModes=r.get(\"text-writing-mode\").map((function(t){return gl[t]}))),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id})),this.sourceID=t.sourceID};fc.prototype.createArrays=function(){this.text=new cc(new Ia(Ds.members,this.layers,this.zoom,(function(t){return/^text/.test(t)}))),this.icon=new cc(new Ia(Ds.members,this.layers,this.zoom,(function(t){return/^icon/.test(t)}))),this.glyphOffsetArray=new $i,this.lineVertexArray=new ta,this.symbolInstances=new Qi},fc.prototype.calculateGlyphDependencies=function(t,e,r,n,i){for(var a=0;a<t.length;a++)if(e[t.charCodeAt(a)]=!0,(r||n)&&i){var o=Us[t.charAt(a)];o&&(e[o.charCodeAt(0)]=!0)}},fc.prototype.populate=function(t,e,r){var n=this.layers[0],i=n.layout,a=i.get(\"text-font\"),o=i.get(\"text-field\"),s=i.get(\"icon-image\"),l=(\"constant\"!==o.value.kind||o.value.value instanceof te&&!o.value.value.isEmpty()||o.value.value.toString().length>0)&&(\"constant\"!==a.value.kind||a.value.value.length>0),c=\"constant\"!==s.value.kind||!!s.value.value||Object.keys(s.parameters).length>0,u=i.get(\"symbol-sort-key\");if(this.features=[],l||c){for(var f=e.iconDependencies,h=e.glyphDependencies,p=e.availableImages,d=new ii(this.zoom),g=0,m=t;g<m.length;g+=1){var v=m[g],y=v.feature,x=v.id,b=v.index,_=v.sourceLayerIndex,w=n._featureFilter.needGeometry,T={type:y.type,id:x,properties:y.properties,geometry:w?Da(y):[]};if(n._featureFilter.filter(d,T,r)){w||(T.geometry=Da(y));var k=void 0;if(l){var M=n.getValueAndResolveTokens(\"text-field\",T,r,p),A=te.factory(M);lc(A)&&(this.hasRTLText=!0),(!this.hasRTLText||\"unavailable\"===ei()||this.hasRTLText&&ni.isParsed())&&(k=js(A,n,T))}var S=void 0;if(c){var E=n.getValueAndResolveTokens(\"icon-image\",T,r,p);S=E instanceof ee?E:ee.fromString(E)}if(k||S){var C=this.sortFeaturesByKey?u.evaluate(T,{},r):void 0,L={id:x,text:k,icon:S,index:b,sourceLayerIndex:_,geometry:Da(y),properties:y.properties,type:ic[y.type],sortKey:C};if(this.features.push(L),S&&(f[S.name]=!0),k){var I=a.evaluate(T,{},r).join(\",\"),P=\"map\"===i.get(\"text-rotation-alignment\")&&\"point\"!==i.get(\"symbol-placement\");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(gl.vertical)>=0;for(var z=0,O=k.sections;z<O.length;z+=1){var D=O[z];if(D.image)f[D.image.name]=!0;else{var R=qn(k.toString()),F=D.fontStack||I,B=h[F]=h[F]||{};this.calculateGlyphDependencies(D.text,B,P,this.allowVerticalPlacement,R)}}}}}}\"line\"===i.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.text?u.text.toString():null;if(h){var p=l(h,f),d=l(h,f,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,f),m=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(h,n[m].geometry,!0)]=m,n[g].geometry=null}else p in r?o(p,d,f):d in e?s(p,d,f):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter((function(t){return t.geometry}))}(this.features)),this.sortFeaturesByKey&&this.features.sort((function(t,e){return t.sortKey-e.sortKey}))}},fc.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},fc.prototype.isEmpty=function(){return 0===this.symbolInstances.length&&!this.hasRTLText},fc.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},fc.prototype.upload=function(t){!this.uploaded&&this.hasDebugData()&&(this.textCollisionBox.upload(t),this.iconCollisionBox.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},fc.prototype.destroyDebugData=function(){this.textCollisionBox.destroy(),this.iconCollisionBox.destroy()},fc.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.hasDebugData()&&this.destroyDebugData()},fc.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},fc.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=t.indexArray,p=t.layoutVertexArray,d=t.segments.prepareSegment(4*e.length,p,h,a.sortKey),g=this.glyphOffsetArray.length,m=d.vertexLength,v=this.allowVerticalPlacement&&o===gl.vertical?Math.PI/2:0,y=a.text&&a.text.sections,x=0;x<e.length;x++){var b=e[x],_=b.tl,w=b.tr,T=b.bl,k=b.br,M=b.tex,A=b.pixelOffsetTL,S=b.pixelOffsetBR,E=b.minFontScaleX,C=b.minFontScaleY,L=b.glyphOffset,I=b.isSDF,P=b.sectionIndex,z=d.vertexLength,O=L[1];oc(p,s.x,s.y,_.x,O+_.y,M.x,M.y,r,I,A.x,A.y,E,C),oc(p,s.x,s.y,w.x,O+w.y,M.x+M.w,M.y,r,I,S.x,A.y,E,C),oc(p,s.x,s.y,T.x,O+T.y,M.x,M.y+M.h,r,I,A.x,S.y,E,C),oc(p,s.x,s.y,k.x,O+k.y,M.x+M.w,M.y+M.h,r,I,S.x,S.y,E,C),sc(t.dynamicLayoutVertexArray,s,v),h.emplaceBack(z,z+1,z+2),h.emplaceBack(z+1,z+2,z+3),d.vertexLength+=4,d.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(L[0]),x!==e.length-1&&P===e[x+1].sectionIndex||t.programConfigurations.populatePaintArrays(p.length,a,a.index,{},f,y&&y[P])}t.placedSymbolArray.emplaceBack(s.x,s.y,g,this.glyphOffsetArray.length-g,m,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,0,!1,0,u)},fc.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},fc.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s){var l=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),c=l.vertexLength,u=a.layoutVertexArray,f=a.collisionVertexArray,h=s.anchorX,p=s.anchorY;this._addCollisionDebugVertex(u,f,o,h,p,new i(t,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,n)),this._addCollisionDebugVertex(u,f,o,h,p,new i(t,n)),l.vertexLength+=4;var d=a.indexArray;d.emplaceBack(c,c+1),d.emplaceBack(c+1,c+2),d.emplaceBack(c+2,c+3),d.emplaceBack(c+3,c),l.primitiveLength+=4},fc.prototype.addDebugCollisionBoxes=function(t,e,r,n){for(var i=t;i<e;i++){var a=this.collisionBoxArray.get(i);this.addCollisionDebugVertices(a.x1,a.y1,a.x2,a.y2,n?this.textCollisionBox:this.iconCollisionBox,a.anchorPoint,r)}},fc.prototype.generateCollisionDebugBuffers=function(){this.hasDebugData()&&this.destroyDebugData(),this.textCollisionBox=new uc(Oi,Bs.members,qi),this.iconCollisionBox=new uc(Oi,Bs.members,qi);for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e,!1),this.addDebugCollisionBoxes(e.verticalIconBoxStartIndex,e.verticalIconBoxEndIndex,e,!1)}},fc.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i,a,o,s,l){for(var c={},u=e;u<r;u++){var f=t.get(u);c.textBox={x1:f.x1,y1:f.y1,x2:f.x2,y2:f.y2,anchorPointX:f.anchorPointX,anchorPointY:f.anchorPointY},c.textFeatureIndex=f.featureIndex;break}for(var h=n;h<i;h++){var p=t.get(h);c.verticalTextBox={x1:p.x1,y1:p.y1,x2:p.x2,y2:p.y2,anchorPointX:p.anchorPointX,anchorPointY:p.anchorPointY},c.verticalTextFeatureIndex=p.featureIndex;break}for(var d=a;d<o;d++){var g=t.get(d);c.iconBox={x1:g.x1,y1:g.y1,x2:g.x2,y2:g.y2,anchorPointX:g.anchorPointX,anchorPointY:g.anchorPointY},c.iconFeatureIndex=g.featureIndex;break}for(var m=s;m<l;m++){var v=t.get(m);c.verticalIconBox={x1:v.x1,y1:v.y1,x2:v.x2,y2:v.y2,anchorPointX:v.anchorPointX,anchorPointY:v.anchorPointY},c.verticalIconFeatureIndex=v.featureIndex;break}return c},fc.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex,r.verticalIconBoxStartIndex,r.verticalIconBoxEndIndex))}},fc.prototype.hasTextData=function(){return this.text.segments.get().length>0},fc.prototype.hasIconData=function(){return this.icon.segments.get().length>0},fc.prototype.hasDebugData=function(){return this.textCollisionBox&&this.iconCollisionBox},fc.prototype.hasTextCollisionBoxData=function(){return this.hasDebugData()&&this.textCollisionBox.segments.get().length>0},fc.prototype.hasIconCollisionBoxData=function(){return this.hasDebugData()&&this.iconCollisionBox.segments.get().length>0},fc.prototype.addIndicesForPlacedSymbol=function(t,e){for(var r=t.placedSymbolArray.get(e),n=r.vertexStartIndex+4*r.numGlyphs,i=r.vertexStartIndex;i<n;i+=4)t.indexArray.emplaceBack(i,i+1,i+2),t.indexArray.emplaceBack(i+1,i+2,i+3)},fc.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort((function(t,e){return n[t]-n[e]||i[e]-i[t]})),a},fc.prototype.addToSortKeyRanges=function(t,e){var r=this.sortKeyRanges[this.sortKeyRanges.length-1];r&&r.sortKey===e?r.symbolInstanceEnd=t+1:this.sortKeyRanges.push({sortKey:e,symbolInstanceStart:t,symbolInstanceEnd:t+1})},fc.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=this.symbolInstances.get(n[r]);this.featureSortOrder.push(i.featureIndex),[i.rightJustifiedTextSymbolIndex,i.centerJustifiedTextSymbolIndex,i.leftJustifiedTextSymbolIndex].forEach((function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedSymbol(e.text,t)})),i.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.text,i.verticalPlacedTextSymbolIndex),i.placedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,i.placedIconSymbolIndex),i.verticalPlacedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,i.verticalPlacedIconSymbolIndex)}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},Dn(\"SymbolBucket\",fc,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),fc.MAX_GLYPHS=65535,fc.addDynamicAttributes=sc;var hc=new yi({\"symbol-placement\":new pi(At.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new pi(At.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new pi(At.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new di(At.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new pi(At.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new pi(At.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new pi(At.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new pi(At.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new pi(At.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new di(At.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new pi(At.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new pi(At.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new di(At.layout_symbol[\"icon-image\"]),\"icon-rotate\":new di(At.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new pi(At.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new pi(At.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new di(At.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new di(At.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new pi(At.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new pi(At.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new pi(At.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new di(At.layout_symbol[\"text-field\"]),\"text-font\":new di(At.layout_symbol[\"text-font\"]),\"text-size\":new di(At.layout_symbol[\"text-size\"]),\"text-max-width\":new di(At.layout_symbol[\"text-max-width\"]),\"text-line-height\":new pi(At.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new di(At.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new di(At.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new di(At.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new pi(At.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new di(At.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new pi(At.layout_symbol[\"text-max-angle\"]),\"text-writing-mode\":new pi(At.layout_symbol[\"text-writing-mode\"]),\"text-rotate\":new di(At.layout_symbol[\"text-rotate\"]),\"text-padding\":new pi(At.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new pi(At.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new di(At.layout_symbol[\"text-transform\"]),\"text-offset\":new di(At.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new pi(At.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new pi(At.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new pi(At.layout_symbol[\"text-optional\"])}),pc={paint:new yi({\"icon-opacity\":new di(At.paint_symbol[\"icon-opacity\"]),\"icon-color\":new di(At.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new di(At.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new di(At.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new di(At.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new pi(At.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new pi(At.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new di(At.paint_symbol[\"text-opacity\"]),\"text-color\":new di(At.paint_symbol[\"text-color\"],{runtimeType:Bt,getOverride:function(t){return t.textColor},hasOverride:function(t){return!!t.textColor}}),\"text-halo-color\":new di(At.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new di(At.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new di(At.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new pi(At.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new pi(At.paint_symbol[\"text-translate-anchor\"])}),layout:hc},dc=function(t){this.type=t.property.overrides?t.property.overrides.runtimeType:Ot,this.defaultValue=t};dc.prototype.evaluate=function(t){if(t.formattedSection){var e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default},dc.prototype.eachChild=function(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)},dc.prototype.outputDefined=function(){return!1},dc.prototype.serialize=function(){return null},Dn(\"FormatSectionOverride\",dc,{omit:[\"defaultValue\"]});var gc=function(t){function e(e){t.call(this,e,pc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){if(t.prototype.recalculate.call(this,e,r),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(this.layout._values[\"icon-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(this.layout._values[\"text-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\")),\"point\"===this.layout.get(\"symbol-placement\")){var n=this.layout.get(\"text-writing-mode\");if(n){for(var i=[],a=0,o=n;a<o.length;a+=1){var s=o[a];i.indexOf(s)<0&&i.push(s)}this.layout._values[\"text-writing-mode\"]=i}else this.layout._values[\"text-writing-mode\"]=[\"horizontal\"]}this._setPaintOverrides()},e.prototype.getValueAndResolveTokens=function(t,e,r,n){var i=this.layout.get(t).evaluate(e,{},r,n),a=this._unevaluatedLayout._values[t];return a.isDataDriven()||Vr(a.value)||!i?i:function(t,e){return e.replace(/{([^{}]+)}/g,(function(e,r){return r in t?String(t[r]):\"\"}))}(e.properties,i)},e.prototype.createBucket=function(t){return new fc(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype._setPaintOverrides=function(){for(var t=0,r=pc.paint.overridableProperties;t<r.length;t+=1){var n=r[t];if(e.hasPaintOverride(this.layout,n)){var i,a=this.paint.get(n),o=new dc(a),s=new Ur(o,a.property.specification);i=\"constant\"===a.value.kind||\"source\"===a.value.kind?new Hr(\"source\",s):new Gr(\"composite\",s,a.value.zoomStops,a.value._interpolationType),this.paint._values[n]=new fi(a.property,i,a.parameters)}}},e.prototype._handleOverridablePaintPropertyUpdate=function(t,r,n){return!(!this.layout||r.isDataDriven()||n.isDataDriven())&&e.hasPaintOverride(this.layout,t)},e.hasPaintOverride=function(t,e){var r=t.get(\"text-field\"),n=pc.paint.properties[e],i=!1,a=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n.overrides&&n.overrides.hasOverride(r[e]))return void(i=!0)};if(\"constant\"===r.value.kind&&r.value.value instanceof te)a(r.value.value.sections);else if(\"source\"===r.value.kind){var o=function(t){i||(t instanceof oe&&ie(t.value)===Vt?a(t.value.sections):t instanceof ue?a(t.sections):t.eachChild(o))},s=r.value;s._styleExpression&&o(s._styleExpression.expression)}return i},e}(xi),mc={paint:new yi({\"background-color\":new pi(At.paint_background[\"background-color\"]),\"background-pattern\":new mi(At.paint_background[\"background-pattern\"]),\"background-opacity\":new pi(At.paint_background[\"background-opacity\"])})},vc=function(t){function e(e){t.call(this,e,mc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xi),yc={paint:new yi({\"raster-opacity\":new pi(At.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new pi(At.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new pi(At.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new pi(At.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new pi(At.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new pi(At.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new pi(At.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new pi(At.paint_raster[\"raster-fade-duration\"])})},xc=function(t){function e(e){t.call(this,e,yc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xi),bc=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(xi),_c={circle:oo,heatmap:vo,hillshade:xo,fill:as,\"fill-extrusion\":ws,line:zs,symbol:gc,background:vc,raster:xc},wc=self.HTMLImageElement,Tc=self.HTMLCanvasElement,kc=self.HTMLVideoElement,Mc=self.ImageData,Ac=self.ImageBitmap,Sc=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Sc.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Sc.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Sc.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Sc.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ec=function(t){var e=this;this._callback=t,this._triggered=!1,\"undefined\"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=function(){e._triggered=!1,e._callback()})};Ec.prototype.trigger=function(){var t=this;this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout((function(){t._triggered=!1,t._callback()}),0))},Ec.prototype.remove=function(){delete this._channel,this._callback=function(){}};var Cc=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.tasks={},this.taskQueue=[],this.cancelCallbacks={},g([\"receive\",\"process\"],this),this.invoker=new Ec(this.process),this.target.addEventListener(\"message\",this.receive,!1),this.globalScope=k()?t:self};function Lc(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}Cc.prototype.send=function(t,e,r,n,i){var a=this;void 0===i&&(i=!1);var o=Math.round(1e18*Math.random()).toString(36).substring(0,10);r&&(this.callbacks[o]=r);var s=S(this.globalScope)?void 0:[];return this.target.postMessage({id:o,type:t,hasCallback:!!r,targetMapId:n,mustQueue:i,sourceMapId:this.mapId,data:Nn(e,s)},s),{cancel:function(){r&&delete a.callbacks[o],a.target.postMessage({id:o,type:\"<cancel>\",targetMapId:n,sourceMapId:a.mapId})}}},Cc.prototype.receive=function(t){var e=t.data,r=e.id;if(r&&(!e.targetMapId||this.mapId===e.targetMapId))if(\"<cancel>\"===e.type){delete this.tasks[r];var n=this.cancelCallbacks[r];delete this.cancelCallbacks[r],n&&n()}else k()||e.mustQueue?(this.tasks[r]=e,this.taskQueue.push(r),this.invoker.trigger()):this.processTask(r,e)},Cc.prototype.process=function(){if(this.taskQueue.length){var t=this.taskQueue.shift(),e=this.tasks[t];delete this.tasks[t],this.taskQueue.length&&this.invoker.trigger(),e&&this.processTask(t,e)}},Cc.prototype.processTask=function(t,e){var r=this;if(\"<response>\"===e.type){var n=this.callbacks[t];delete this.callbacks[t],n&&(e.error?n(jn(e.error)):n(null,jn(e.data)))}else{var i=!1,a=S(this.globalScope)?void 0:[],o=e.hasCallback?function(e,n){i=!0,delete r.cancelCallbacks[t],r.target.postMessage({id:t,type:\"<response>\",sourceMapId:r.mapId,error:e?Nn(e):null,data:Nn(n,a)},a)}:function(t){i=!0},s=null,l=jn(e.data);if(this.parent[e.type])s=this.parent[e.type](e.sourceMapId,l,o);else if(this.parent.getWorkerSource){var c=e.type.split(\".\");s=this.parent.getWorkerSource(e.sourceMapId,c[0],l.source)[c[1]](l,o)}else o(new Error(\"Could not find function \"+e.type));!i&&s&&s.cancel&&(this.cancelCallbacks[t]=s.cancel)}},Cc.prototype.remove=function(){this.invoker.remove(),this.target.removeEventListener(\"message\",this.receive,!1)};var Ic=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};Ic.prototype.setNorthEast=function(t){return this._ne=t instanceof Pc?new Pc(t.lng,t.lat):Pc.convert(t),this},Ic.prototype.setSouthWest=function(t){return this._sw=t instanceof Pc?new Pc(t.lng,t.lat):Pc.convert(t),this},Ic.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Pc)e=t,r=t;else{if(!(t instanceof Ic))return Array.isArray(t)?4===t.length||t.every(Array.isArray)?this.extend(Ic.convert(t)):this.extend(Pc.convert(t)):this;if(r=t._ne,!(e=t._sw)||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Pc(e.lng,e.lat),this._ne=new Pc(r.lng,r.lat)),this},Ic.prototype.getCenter=function(){return new Pc((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},Ic.prototype.getSouthWest=function(){return this._sw},Ic.prototype.getNorthEast=function(){return this._ne},Ic.prototype.getNorthWest=function(){return new Pc(this.getWest(),this.getNorth())},Ic.prototype.getSouthEast=function(){return new Pc(this.getEast(),this.getSouth())},Ic.prototype.getWest=function(){return this._sw.lng},Ic.prototype.getSouth=function(){return this._sw.lat},Ic.prototype.getEast=function(){return this._ne.lng},Ic.prototype.getNorth=function(){return this._ne.lat},Ic.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},Ic.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},Ic.prototype.isEmpty=function(){return!(this._sw&&this._ne)},Ic.prototype.contains=function(t){var e=Pc.convert(t),r=e.lng,n=e.lat,i=this._sw.lng<=r&&r<=this._ne.lng;return this._sw.lng>this._ne.lng&&(i=this._sw.lng>=r&&r>=this._ne.lng),this._sw.lat<=n&&n<=this._ne.lat&&i},Ic.convert=function(t){return!t||t instanceof Ic?t:new Ic(t)};var Pc=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};Pc.prototype.wrap=function(){return new Pc(c(this.lng,-180,180),this.lat)},Pc.prototype.toArray=function(){return[this.lng,this.lat]},Pc.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Pc.prototype.distanceTo=function(t){var e=Math.PI/180,r=this.lat*e,n=t.lat*e,i=Math.sin(r)*Math.sin(n)+Math.cos(r)*Math.cos(n)*Math.cos((t.lng-this.lng)*e);return 6371008.8*Math.acos(Math.min(i,1))},Pc.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new Ic(new Pc(this.lng-r,this.lat-e),new Pc(this.lng+r,this.lat+e))},Pc.convert=function(t){if(t instanceof Pc)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Pc(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Pc(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var zc=2*Math.PI*6371008.8;function Oc(t){return zc*Math.cos(t*Math.PI/180)}function Dc(t){return(180+t)/360}function Rc(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Fc(t,e){return t/Oc(e)}function Bc(t){return 360/Math.PI*Math.atan(Math.exp((180-360*t)*Math.PI/180))-90}var Nc=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Nc.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Pc.convert(t);return new Nc(Dc(r.lng),Rc(r.lat),Fc(e,r.lat))},Nc.prototype.toLngLat=function(){return new Pc(360*this.x-180,Bc(this.y))},Nc.prototype.toAltitude=function(){return this.z*Oc(Bc(this.y))},Nc.prototype.meterInMercatorCoordinateUnits=function(){return 1/zc*(t=Bc(this.y),1/Math.cos(t*Math.PI/180));var t};var jc=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=qc(0,t,t,e,r)};jc.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},jc.prototype.url=function(t,e){var r,n,i,a,o,s=(n=this.y,i=this.z,a=Lc(256*(r=this.x),256*(n=Math.pow(2,i)-n-1),i),o=Lc(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},jc.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i(8192*(t.x*e-this.x),8192*(t.y*e-this.y))},jc.prototype.toString=function(){return this.z+\"/\"+this.x+\"/\"+this.y};var Uc=function(t,e){this.wrap=t,this.canonical=e,this.key=qc(t,e.z,e.z,e.x,e.y)},Vc=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new jc(r,+n,+i),this.key=qc(e,t,r,n,i)};function qc(t,e,r,n,i){(t*=2)<0&&(t=-1*t-1);var a=1<<r;return(a*a*t+a*i+n).toString(36)+r.toString(36)+e.toString(36)}Vc.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},Vc.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new Vc(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new Vc(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},Vc.prototype.calculateScaledKey=function(t,e){var r=this.canonical.z-t;return t>this.canonical.z?qc(this.wrap*+e,t,this.canonical.z,this.canonical.x,this.canonical.y):qc(this.wrap*+e,t,t,this.canonical.x>>r,this.canonical.y>>r)},Vc.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},Vc.prototype.children=function(t){if(this.overscaledZ>=t)return[new Vc(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new Vc(e,this.wrap,e,r,n),new Vc(e,this.wrap,e,r+1,n),new Vc(e,this.wrap,e,r,n+1),new Vc(e,this.wrap,e,r+1,n+1)]},Vc.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},Vc.prototype.wrapped=function(){return new Vc(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.unwrapTo=function(t){return new Vc(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},Vc.prototype.toUnwrapped=function(){return new Uc(this.wrap,this.canonical)},Vc.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},Vc.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Nc(t.x-this.wrap,t.y))},Dn(\"CanonicalTileID\",jc),Dn(\"OverscaledTileID\",Vc,{omit:[\"posMatrix\"]});var Hc=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return _('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');this.stride=e.height;var n=this.dim=e.height-2;this.data=new Uint32Array(e.data.buffer),this.encoding=r||\"mapbox\";for(var i=0;i<n;i++)this.data[this._idx(-1,i)]=this.data[this._idx(0,i)],this.data[this._idx(n,i)]=this.data[this._idx(n-1,i)],this.data[this._idx(i,-1)]=this.data[this._idx(i,0)],this.data[this._idx(i,n)]=this.data[this._idx(i,n-1)];this.data[this._idx(-1,-1)]=this.data[this._idx(0,0)],this.data[this._idx(n,-1)]=this.data[this._idx(n-1,0)],this.data[this._idx(-1,n)]=this.data[this._idx(0,n-1)],this.data[this._idx(n,n)]=this.data[this._idx(n-1,n-1)]};Hc.prototype.get=function(t,e){var r=new Uint8Array(this.data.buffer),n=4*this._idx(t,e);return(\"terrarium\"===this.encoding?this._unpackTerrarium:this._unpackMapbox)(r[n],r[n+1],r[n+2])},Hc.prototype.getUnpackVector=function(){return\"terrarium\"===this.encoding?[256,1,1/256,32768]:[6553.6,25.6,.1,1e4]},Hc.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Hc.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Hc.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Hc.prototype.getPixels=function(){return new po({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Hc.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.data[this._idx(u,c)]=t.data[this._idx(u+s,c+l)]},Dn(\"DEMData\",Hc);var Gc=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Gc.prototype.encode=function(t){return this._stringToNumber[t]},Gc.prototype.decode=function(t){return this._numberToString[t]};var Yc=function(t,e,r,n,i){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,this.id=i},Wc={geometry:{configurable:!0}};Wc.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Wc.geometry.set=function(t){this._geometry=t},Yc.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Yc.prototype,Wc);var Xc=function(){this.state={},this.stateChanges={},this.deletedStates={}};Xc.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},u(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},Xc.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},Xc.prototype.getState=function(t,e){var r=String(e),n=u({},(this.state[t]||{})[r],(this.stateChanges[t]||{})[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var i=this.deletedStates[t][e];if(null===i)return{};for(var a in i)delete n[a]}return n},Xc.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},Xc.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),u(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var f=0,h=Object.keys(this.deletedStates[o][c]);f<h.length;f+=1)delete this.state[o][c][h[f]];s[c]=this.state[o][c]}r[o]=r[o]||{},u(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var p in t)t[p].setFeatureState(r,e)};var Zc=function(t,e){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=new Ln(8192,16,0),this.grid3D=new Ln(8192,16,0),this.featureIndexArray=new ra,this.promoteId=e};function Jc(t,e,r,n,i){return v(t,(function(t,a){var o=e instanceof hi?e.get(a):null;return o&&o.evaluate?o.evaluate(r,n,i):o}))}function Kc(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function Qc(t,e){return e-t}Zc.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],f=0;f<c.length;f++){var h=c[f];u[0]=Math.min(u[0],h.x),u[1]=Math.min(u[1],h.y),u[2]=Math.max(u[2],h.x),u[3]=Math.max(u[3],h.y)}u[0]<8192&&u[1]<8192&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Zc.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new gs.VectorTile(new Hs(this.rawTileData)).layers,this.sourceLayerCoder=new Gc(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Zc.prototype.query=function(t,e,r,n){var a=this;this.loadVTLayers();for(var o=t.params||{},s=8192/t.tileSize/t.scale,l=rn(o.filter),c=t.queryGeometry,u=t.queryPadding*s,f=Kc(c),h=this.grid.query(f.minX-u,f.minY-u,f.maxX+u,f.maxY+u),p=Kc(t.cameraQueryGeometry),d=0,g=this.grid3D.query(p.minX-u,p.minY-u,p.maxX+u,p.maxY+u,(function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,f=c;u<f.length;u+=1)if(Wa(t,f[u]))return!0;for(var h=0;h<t.length-1;h++)if(Xa(t[h],t[h+1],c))return!0;return!1}(t.cameraQueryGeometry,e-u,r-u,n+u,a+u)}));d<g.length;d+=1)h.push(g[d]);h.sort(Qc);for(var m,v={},y=function(i){var u=h[i];if(u!==m){m=u;var f=a.featureIndexArray.get(u),p=null;a.loadMatchingFeature(v,f.bucketIndex,f.sourceLayerIndex,f.featureIndex,l,o.layers,o.availableImages,e,r,n,(function(e,r,n){return p||(p=Da(e)),r.queryIntersectsFeature(c,e,n,p,a.z,t.transform,s,t.pixelPosMatrix)}))}},x=0;x<h.length;x++)y(x);return v},Zc.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s,l,c,u){var f=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,f)){var h=this.sourceLayerCoder.decode(r),p=this.vtLayers[h].feature(n);if(i.filter(new ii(this.tileID.overscaledZ),p))for(var d=this.getId(p,h),g=0;g<f.length;g++){var m=f[g];if(!(a&&a.indexOf(m)<0)){var v=s[m];if(v){var y={};void 0!==d&&c&&(y=c.getState(v.sourceLayer||\"_geojsonTileLayer\",d));var x=l[m];x.paint=Jc(x.paint,v.paint,p,y,o),x.layout=Jc(x.layout,v.layout,p,y,o);var b=!u||u(p,v,y);if(b){var _=new Yc(p,this.z,this.x,this.y,d);_.layer=x;var w=t[m];void 0===w&&(w=t[m]=[]),w.push({featureIndex:n,feature:_,intersectionZ:b})}}}}}},Zc.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a,o,s){var l={};this.loadVTLayers();for(var c=rn(i),u=0,f=t;u<f.length;u+=1)this.loadMatchingFeature(l,r,n,f[u],c,a,o,s,e);return l},Zc.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},Zc.prototype.getId=function(t,e){var r=t.id;return this.promoteId&&\"boolean\"==typeof(r=t.properties[\"string\"==typeof this.promoteId?this.promoteId:this.promoteId[e]])&&(r=Number(r)),r},Dn(\"FeatureIndex\",Zc,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var $c=function(t,e){this.tileID=t,this.uid=h(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.hasRTLText=!1,this.dependencies={},this.expiredRequestCount=0,this.state=\"loading\"};$c.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<R.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},$c.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},$c.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map((function(t){return e.getLayer(t)})).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map((function(t){return n.filter((function(e){return e.id===t}))[0]})));for(var o=0,s=n;o<s.length;o+=1)r[s[o].id]=t}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof fc){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}if(this.hasRTLText=!1,this.hasSymbolBuckets)for(var a in this.buckets){var o=this.buckets[a];if(o instanceof fc&&o.hasRTLText){this.hasRTLText=!0,ni.isLoading()||ni.isLoaded()||\"deferred\"!==ei()||ri();break}}for(var s in this.queryPadding=0,this.buckets){var l=this.buckets[s];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(s).queryRadius(l))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Xi},$c.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},$c.prototype.getBucket=function(t){return this.buckets[t.id]},$c.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Sc(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Sc(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},$c.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},$c.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l,c){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:n,cameraQueryGeometry:i,scale:a,tileSize:this.tileSize,pixelPosMatrix:c,transform:s,params:o,queryPadding:this.queryPadding*l},t,e,r):{}},$c.prototype.querySourceFeatures=function(t,e){var r=this.latestFeatureIndex;if(r&&r.rawTileData){var n=r.loadVTLayers(),i=e?e.sourceLayer:\"\",a=n._geojsonTileLayer||n[i];if(a)for(var o=rn(e&&e.filter),s=this.tileID.canonical,l=s.z,c=s.x,u=s.y,f={z:l,x:c,y:u},h=0;h<a.length;h++){var p=a.feature(h);if(o.filter(new ii(this.tileID.overscaledZ),p)){var d=r.getId(p,i),g=new Yc(p,l,c,u,d);g.tile=f,t.push(g)}}}},$c.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},$c.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},$c.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=M(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},$c.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},$c.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets)if(e.style.hasLayer(n)){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];if(o&&s&&0!==Object.keys(s).length){i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{});var l=e&&e.style&&e.style.getLayer(n);l&&(this.queryPadding=Math.max(this.queryPadding,l.queryRadius(i)))}}}},$c.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},$c.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<R.now()},$c.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},$c.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=R.now()+t},$c.prototype.setDependencies=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1)r[i[n]]=!0;this.dependencies[t]=r},$c.prototype.hasDependency=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=this.dependencies[n[r]];if(i)for(var a=0,o=e;a<o.length;a+=1)if(i[o[a]])return!0}return!1};var tu=self.performance,eu=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},tu.mark(this._marks.start)};eu.prototype.finish=function(){tu.mark(this._marks.end);var t=tu.getEntriesByName(this._marks.measure);return 0===t.length&&(tu.measure(this._marks.measure,this._marks.start,this._marks.end),t=tu.getEntriesByName(this._marks.measure),tu.clearMarks(this._marks.start),tu.clearMarks(this._marks.end),tu.clearMeasures(this._marks.measure)),t},t.Actor=Cc,t.AlphaImage=ho,t.CanonicalTileID=jc,t.CollisionBoxArray=Xi,t.Color=Kt,t.DEMData=Hc,t.DataConstantProperty=pi,t.DictionaryCoder=Gc,t.EXTENT=8192,t.ErrorEvent=kt,t.EvaluationParameters=ii,t.Event=Tt,t.Evented=Mt,t.FeatureIndex=Zc,t.FillBucket=rs,t.FillExtrusionBucket=xs,t.ImageAtlas=dl,t.ImagePosition=hl,t.LineBucket=Cs,t.LngLat=Pc,t.LngLatBounds=Ic,t.MercatorCoordinate=Nc,t.ONE_EM=24,t.OverscaledTileID=Vc,t.Point=i,t.Point$1=i,t.Properties=yi,t.Protobuf=Hs,t.RGBAImage=po,t.RequestManager=q,t.RequestPerformance=eu,t.ResourceType=ht,t.SegmentVector=ia,t.SourceFeatureState=Xc,t.StructArrayLayout1ui2=Hi,t.StructArrayLayout2f1f2i16=Di,t.StructArrayLayout2i4=Mi,t.StructArrayLayout3ui6=Fi,t.StructArrayLayout4i8=Ai,t.SymbolBucket=fc,t.Texture=Sc,t.Tile=$c,t.Transitionable=si,t.Uniform1f=va,t.Uniform1i=ma,t.Uniform2f=ya,t.Uniform3f=xa,t.Uniform4f=ba,t.UniformColor=_a,t.UniformMatrix4f=Ta,t.UnwrappedTileID=Uc,t.ValidationError=St,t.WritingMode=gl,t.ZoomHistory=Un,t.add=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t},t.addDynamicAttributes=sc,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach((function(t,o){e(t,(function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)}))}))},t.bezier=o,t.bindAll=g,t.browser=R,t.cacheEntryPossiblyAdded=function(t){++ut>ot&&(t.getActor().send(\"enforceCacheSizeLimit\",at),ut=0)},t.clamp=l,t.clearTileCache=function(t){var e=self.caches.delete(\"mapbox-tiles\");t&&e.catch(t).then((function(){return t()}))},t.clipLine=jl,t.clone=function(t){var e=new to(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=x,t.clone$2=function(t){var e=new to(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e},t.collisionCircleLayout=Ns,t.config=F,t.create=function(){var t=new to(16);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=function(){var t=new to(9);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t},t.create$2=function(){var t=new to(4);return to!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=qr,t.createLayout=Ti,t.createStyleLayer=function(t){return\"custom\"===t.type?new bc(t):new _c[t.type](t)},t.cross=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t},t.deepEqual=function t(e,r){if(Array.isArray(e)){if(!Array.isArray(r)||e.length!==r.length)return!1;for(var n=0;n<e.length;n++)if(!t(e[n],r[n]))return!1;return!0}if(\"object\"==typeof e&&null!==e&&null!==r){if(\"object\"!=typeof r)return!1;if(Object.keys(e).length!==Object.keys(r).length)return!1;for(var i in e)if(!t(e[i],r[i]))return!1;return!0}return e===r},t.dot=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]},t.dot$1=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]},t.ease=s,t.emitValidationErrors=Cn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){st(),Q&&Q.then((function(e){e.keys().then((function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])}))}))},t.evaluateSizeForFeature=Il,t.evaluateSizeForZoom=Pl,t.evaluateVariableOffset=$l,t.evented=ti,t.extend=u,t.featureFilter=rn,t.filterObject=y,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=Al,t.getAnchorJustification=tc,t.getArrayBuffer=yt,t.getImage=bt,t.getJSON=function(t,e){return vt(u(t,{type:\"json\"}),e)},t.getRTLTextPluginStatus=ei,t.getReferrer=mt,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=eo,t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*g-f*d,M=u*m-h*d,A=u*v-p*d,S=f*m-h*g,E=f*v-p*g,C=h*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;return L?(t[0]=(s*C-l*E+c*S)*(L=1/L),t[1]=(i*E-n*C-a*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(h*w-f*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-i*A+a*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-h*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-a*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+i*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-f*x+h*y)*L,t):null},t.isChar=Vn,t.isMapboxURL=H,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=vt,t.mapObject=v,t.mercatorXfromLng=Dc,t.mercatorYfromLat=Rc,t.mercatorZfromAltitude=Fc,t.mul=io,t.multiply=ro,t.mvt=gs,t.normalize=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;return a>0&&(a=1/Math.sqrt(a)),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a,t},t.number=Ue,t.offscreenCanvasSupported=ft,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Hs(t).readFields(ll,[])},t.pbf=Hs,t.performSymbolLayout=function(t,e,r,n,i,a,o){t.createArrays(),t.tilePixelRatio=8192/(512*t.overscaling),t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new ii(u.minZoom),o),l[\"text-size\"].possiblyEvaluate(new ii(f),o)]}if(\"composite\"===t.iconSizeData.kind){var h=t.iconSizeData,p=h.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new ii(h.minZoom),o),l[\"icon-size\"].possiblyEvaluate(new ii(p),o)]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new ii(t.zoom+1),o),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new ii(t.zoom+1),o),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new ii(18));for(var d=24*s.get(\"text-line-height\"),g=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),m=s.get(\"text-keep-upright\"),v=s.get(\"text-size\"),y=function(){var a=b[x],l=s.get(\"text-font\").evaluate(a,{},o).join(\",\"),u=v.evaluate(a,{},o),f=c.layoutTextSize.evaluate(a,{},o),h=c.layoutIconSize.evaluate(a,{},o),p={horizontal:{},vertical:void 0},y=a.text,w=[0,0];if(y){var T=y.toString(),k=24*s.get(\"text-letter-spacing\").evaluate(a,{},o),M=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n=r[e].charCodeAt(0),Vn.Arabic(n)||Vn[\"Arabic Supplement\"](n)||Vn[\"Arabic Extended-A\"](n)||Vn[\"Arabic Presentation Forms-A\"](n)||Vn[\"Arabic Presentation Forms-B\"](n))return!1;var n;return!0}(T)?k:0,A=s.get(\"text-anchor\").evaluate(a,{},o),S=s.get(\"text-variable-anchor\");if(!S){var E=s.get(\"text-radial-offset\").evaluate(a,{},o);w=E?$l(A,[24*E,Ql]):s.get(\"text-offset\").evaluate(a,{},o).map((function(t){return 24*t}))}var C=g?\"center\":s.get(\"text-justify\").evaluate(a,{},o),L=s.get(\"symbol-placement\"),I=\"point\"===L?24*s.get(\"text-max-width\").evaluate(a,{},o):0,P=function(){t.allowVerticalPlacement&&qn(T)&&(p.vertical=yl(y,e,r,i,l,I,d,A,\"left\",M,w,gl.vertical,!0,L,f,u))};if(!g&&S){for(var z=\"auto\"===C?S.map((function(t){return tc(t)})):[C],O=!1,D=0;D<z.length;D++){var R=z[D];if(!p.horizontal[R])if(O)p.horizontal[R]=p.horizontal[0];else{var F=yl(y,e,r,i,l,I,d,\"center\",R,M,w,gl.horizontal,!1,L,f,u);F&&(p.horizontal[R]=F,O=1===F.positionedLines.length)}}P()}else{\"auto\"===C&&(C=tc(A));var B=yl(y,e,r,i,l,I,d,A,C,M,w,gl.horizontal,!1,L,f,u);B&&(p.horizontal[C]=B),P(),qn(T)&&g&&m&&(p.vertical=yl(y,e,r,i,l,I,d,A,C,M,w,gl.vertical,!1,L,f,u))}}var N=void 0,j=!1;if(a.icon&&a.icon.name){var U=n[a.icon.name];U&&(N=function(t,e,r){var n=Al(r),i=e[0]-t.displaySize[0]*n.horizontalAlign,a=e[1]-t.displaySize[1]*n.verticalAlign;return{image:t,top:a,bottom:a+t.displaySize[1],left:i,right:i+t.displaySize[0]}}(i[a.icon.name],s.get(\"icon-offset\").evaluate(a,{},o),s.get(\"icon-anchor\").evaluate(a,{},o)),j=U.sdf,void 0===t.sdfIcons?t.sdfIcons=U.sdf:t.sdfIcons!==U.sdf&&_(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),(U.pixelRatio!==t.pixelRatio||0!==s.get(\"icon-rotate\").constantOr(1))&&(t.iconsNeedLinear=!0))}var V=rc(p.horizontal)||p.vertical;t.iconsInText=!!V&&V.iconsInText,(V||N)&&function(t,e,r,n,i,a,o,s,l,c,u){var f=a.textMaxSize.evaluate(e,{});void 0===f&&(f=o);var h,p=t.layers[0].layout,d=p.get(\"icon-offset\").evaluate(e,{},u),g=rc(r.horizontal),m=o/24,v=t.tilePixelRatio*m,y=t.tilePixelRatio*f/24,x=t.tilePixelRatio*s,b=t.tilePixelRatio*p.get(\"symbol-spacing\"),w=p.get(\"text-padding\")*t.tilePixelRatio,T=p.get(\"icon-padding\")*t.tilePixelRatio,k=p.get(\"text-max-angle\")/180*Math.PI,M=\"map\"===p.get(\"text-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),A=\"map\"===p.get(\"icon-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),S=p.get(\"symbol-placement\"),E=b/2,C=p.get(\"icon-text-fit\");n&&\"none\"!==C&&(t.allowVerticalPlacement&&r.vertical&&(h=El(n,r.vertical,C,p.get(\"icon-text-fit-padding\"),d,m)),g&&(n=El(n,g,C,p.get(\"icon-text-fit-padding\"),d,m)));var L=function(s,f){f.x<0||f.x>=8192||f.y<0||f.y>=8192||function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,w,T,k,M){var A,S,E,C,L,I=t.addToLineVertexArray(e,r),P=0,z=0,O=0,D=0,R=-1,F=-1,B={},N=ca(\"\"),j=0,U=0;if(void 0===s._unevaluatedLayout.getValue(\"text-radial-offset\")?(j=(A=s.layout.get(\"text-offset\").evaluate(b,{},k).map((function(t){return 24*t})))[0],U=A[1]):(j=24*s.layout.get(\"text-radial-offset\").evaluate(b,{},k),U=Ql),t.allowVerticalPlacement&&n.vertical){var V=s.layout.get(\"text-rotate\").evaluate(b,{},k)+90;C=new Yl(l,e,c,u,f,n.vertical,h,p,d,V),o&&(L=new Yl(l,e,c,u,f,o,m,v,d,V))}if(i){var q=s.layout.get(\"icon-rotate\").evaluate(b,{}),H=\"none\"!==s.layout.get(\"icon-text-fit\"),G=Ul(i,q,T,H),Y=o?Ul(o,q,T,H):void 0;E=new Yl(l,e,c,u,f,i,m,v,!1,q),P=4*G.length;var W=t.iconSizeData,X=null;\"source\"===W.kind?(X=[128*s.layout.get(\"icon-size\").evaluate(b,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'):\"composite\"===W.kind&&((X=[128*w.compositeIconSizes[0].evaluate(b,{},k),128*w.compositeIconSizes[1].evaluate(b,{},k)])[0]>32640||X[1]>32640)&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'),t.addSymbols(t.icon,G,X,x,y,b,!1,e,I.lineStartIndex,I.lineLength,-1,k),R=t.icon.placedSymbolArray.length-1,Y&&(z=4*Y.length,t.addSymbols(t.icon,Y,X,x,y,b,gl.vertical,e,I.lineStartIndex,I.lineLength,-1,k),F=t.icon.placedSymbolArray.length-1)}for(var Z in n.horizontal){var J=n.horizontal[Z];if(!S){N=ca(J.text);var K=s.layout.get(\"text-rotate\").evaluate(b,{},k);S=new Yl(l,e,c,u,f,J,h,p,d,K)}var Q=1===J.positionedLines.length;if(O+=ec(t,e,J,a,s,d,b,g,I,n.vertical?gl.horizontal:gl.horizontalOnly,Q?Object.keys(n.horizontal):[Z],B,R,w,k),Q)break}n.vertical&&(D+=ec(t,e,n.vertical,a,s,d,b,g,I,gl.vertical,[\"vertical\"],B,F,w,k));var $=S?S.boxStartIndex:t.collisionBoxArray.length,tt=S?S.boxEndIndex:t.collisionBoxArray.length,et=C?C.boxStartIndex:t.collisionBoxArray.length,rt=C?C.boxEndIndex:t.collisionBoxArray.length,nt=E?E.boxStartIndex:t.collisionBoxArray.length,it=E?E.boxEndIndex:t.collisionBoxArray.length,at=L?L.boxStartIndex:t.collisionBoxArray.length,ot=L?L.boxEndIndex:t.collisionBoxArray.length,st=-1,lt=function(t,e){return t&&t.circleDiameter?Math.max(t.circleDiameter,e):e};st=lt(S,st),st=lt(C,st),st=lt(E,st);var ct=(st=lt(L,st))>-1?1:0;ct&&(st*=M/24),t.glyphOffsetArray.length>=fc.MAX_GLYPHS&&_(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),void 0!==b.sortKey&&t.addToSortKeyRanges(t.symbolInstances.length,b.sortKey),t.symbolInstances.emplaceBack(e.x,e.y,B.right>=0?B.right:-1,B.center>=0?B.center:-1,B.left>=0?B.left:-1,B.vertical||-1,R,F,N,$,tt,et,rt,nt,it,at,ot,c,O,D,P,z,ct,0,h,j,U,st)}(t,f,s,r,n,i,h,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,v,w,M,l,x,T,A,d,e,a,c,u,o)};if(\"line\"===S)for(var I=0,P=jl(e.geometry,0,0,8192,8192);I<P.length;I+=1)for(var z=P[I],O=0,D=Nl(z,b,k,r.vertical||g,n,24,y,t.overscaling,8192);O<D.length;O+=1){var R=D[O];g&&nc(t,g.text,E,R)||L(z,R)}else if(\"line-center\"===S)for(var F=0,B=e.geometry;F<B.length;F+=1){var N=B[F];if(N.length>1){var j=Bl(N,k,r.vertical||g,n,24,y);j&&L(N,j)}}else if(\"Polygon\"===e.type)for(var U=0,V=Qo(e.geometry,0);U<V.length;U+=1){var q=V[U],H=Zl(q,16);L(q[0],new Cl(H.x,H.y,0))}else if(\"LineString\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1){var W=Y[G];L(W,new Cl(W[0].x,W[0].y,0))}else if(\"Point\"===e.type)for(var X=0,Z=e.geometry;X<Z.length;X+=1)for(var J=0,K=Z[X];J<K.length;J+=1){var Q=K[J];L([Q],new Cl(Q.x,Q.y,0))}}(t,a,p,N,n,c,f,h,w,j,o)},x=0,b=t.features;x<b.length;x+=1)y();a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(t[10]=(i+n)*(a=1/(n-i)),t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=ni,t.polygonIntersectsPolygon=Ba,t.postMapLoadEvent=it,t.postTurnstileEvent=rt,t.potpack=fl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=Dn,t.registerForPluginStateChange=function(t){return t({pluginStatus:Jn,pluginURL:Kn}),ti.on(\"pluginStateChange\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.scale$1=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t},t.scale$2=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t},t.setCacheLimits=function(t,e){at=t,ot=e},t.setRTLTextPlugin=function(t,e,r){if(void 0===r&&(r=!1),\"deferred\"===Jn||\"loading\"===Jn||\"loaded\"===Jn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Kn=R.resolveURL(t),Jn=\"deferred\",Zn=e,$n(),r||ri()},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.sqrLen=function(t){var e=t[0],r=t[1];return e*e+r*r},t.styleSpec=At,t.sub=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t},t.symbolSize=zl,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=ao,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],m=r[1],v=r[2];return e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n=e[0],t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*m+f*v+e[12],t[13]=i*g+l*m+h*v+e[13],t[14]=a*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]),t},t.triggerPluginCompletionEvent=Qn,t.uniqueId=h,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=An,t.validateStyle=Mn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=gs,t.version=\"1.10.1\",t.warnOnce=_,t.webpSupported=B,t.window=self,t.wrap=c})),n(0,(function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var f=u[c];delete this.keyCache[f],delete this._layerConfigs[f],delete this._layers[f]}this.familiesBySource={};for(var h=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);h<p.length;h+=1){var d=p[h].map((function(t){return i._layers[t.id]})),g=d[0];if(\"none\"!==g.visibility){var m=g.source||\"\",v=this.familiesBySource[m];v||(v=this.familiesBySource[m]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=v[y];x||(x=v[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),f=new t.AlphaImage({width:u.w||1,height:u.h||1});for(var h in e){var p=e[h];for(var d in p){var g=p[+d];if(g&&0!==g.bitmap.width&&0!==g.bitmap.height){var m=r[h][d].rect;t.AlphaImage.copy(g.bitmap,f,{x:0,y:0},{x:m.x+1,y:m.y+1},g.bitmap)}}}this.image=f,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies,this.promoteId=e.promoteId};function o(e,r,n){for(var i=new t.EvaluationParameters(r),a=0,o=e;a<o.length;a+=1)o[a].recalculate(i,n)}function s(e,r){var n=t.getArrayBuffer(e.request,(function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})}));return function(){n.cancel(),r()}}a.prototype.parse=function(e,r,n,a,s){var l=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var c=new t.DictionaryCoder(Object.keys(e.layers).sort()),u=new t.FeatureIndex(this.tileID,this.promoteId);u.bucketLayerIDs=[];var f,h,p,d,g={},m={featureIndex:u,iconDependencies:{},patternDependencies:{},glyphDependencies:{},availableImages:n},v=r.familiesBySource[this.source];for(var y in v){var x=e.layers[y];if(x){1===x.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+y+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var b=c.encode(y),_=[],w=0;w<x.length;w++){var T=x.feature(w),k=u.getId(T,y);_.push({feature:T,id:k,index:w,sourceLayerIndex:b})}for(var M=0,A=v[y];M<A.length;M+=1){var S=A[M],E=S[0];E.minzoom&&this.zoom<Math.floor(E.minzoom)||E.maxzoom&&this.zoom>=E.maxzoom||\"none\"!==E.visibility&&(o(S,this.zoom,n),(g[E.id]=E.createBucket({index:u.bucketLayerIDs.length,layers:S,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:b,sourceID:this.source})).populate(_,m,this.tileID.canonical),u.bucketLayerIDs.push(S.map((function(t){return t.id}))))}}}var C=t.mapObject(m.glyphDependencies,(function(t){return Object.keys(t).map(Number)}));Object.keys(C).length?a.send(\"getGlyphs\",{uid:this.uid,stacks:C},(function(t,e){f||(f=t,h=e,P.call(l))})):h={};var L=Object.keys(m.iconDependencies);L.length?a.send(\"getImages\",{icons:L,source:this.source,tileID:this.tileID,type:\"icons\"},(function(t,e){f||(f=t,p=e,P.call(l))})):p={};var I=Object.keys(m.patternDependencies);function P(){if(f)return s(f);if(h&&p&&d){var e=new i(h),r=new t.ImageAtlas(p,d);for(var a in g){var l=g[a];l instanceof t.SymbolBucket?(o(l.layers,this.zoom,n),t.performSymbolLayout(l,h,e.positions,p,r.iconPositions,this.showCollisionBoxes,this.tileID.canonical)):l.hasPattern&&(l instanceof t.LineBucket||l instanceof t.FillBucket||l instanceof t.FillExtrusionBucket)&&(o(l.layers,this.zoom,n),l.addFeatures(m,this.tileID.canonical,r.patternPositions))}this.status=\"done\",s(null,{buckets:t.values(g).filter((function(t){return!t.isEmpty()})),featureIndex:u,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?p:null,glyphPositions:this.returnDependencies?e.positions:null})}}I.length?a.send(\"getImages\",{icons:I,source:this.source,tileID:this.tileID,type:\"patterns\"},(function(t,e){f||(f=t,d=e,P.call(l))})):d={},P.call(this)};var l=function(t,e,r,n){this.actor=t,this.layerIndex=e,this.availableImages=r,this.loadVectorData=n||s,this.loading={},this.loaded={}};l.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new t.RequestPerformance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,(function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var f=o.finish();f&&(u.resourceTiming=JSON.parse(JSON.stringify(f)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.availableImages,n.actor,(function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))})),n.loaded=n.loaded||{},n.loaded[i]=s}))},l.prototype.reloadTile=function(t,e){var r=this,n=this.loaded,i=t.uid,a=this;if(n&&n[i]){var o=n[i];o.showCollisionBoxes=t.showCollisionBoxes;var s=function(t,n){var i=o.reloadCallback;i&&(delete o.reloadCallback,o.parse(o.vectorTile,a.layerIndex,r.availableImages,a.actor,i)),e(t,n)};\"parsing\"===o.status?o.reloadCallback=s:\"done\"===o.status&&(o.vectorTile?o.parse(o.vectorTile,this.layerIndex,this.availableImages,this.actor,s):s())}},l.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},l.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var c=t.window.ImageBitmap,u=function(){this.loaded={}};function f(t,e){if(0!==t.length){h(t[0],e);for(var r=1;r<t.length;r++)h(t[r],!e)}}function h(t,e){for(var r=0,n=0,i=t.length,a=i-1;n<i;a=n++)r+=(t[n][0]-t[a][0])*(t[a][1]+t[n][1]);r>=0!=!!e&&t.reverse()}u.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=c&&a instanceof c?this.getImageData(a):a,s=new t.DEMData(n,o,i);this.loaded=this.loaded||{},this.loaded[n]=s,r(null,s)},u.prototype.getImageData=function(e){this.offscreenCanvas&&this.offscreenCanvasContext||(this.offscreenCanvas=new OffscreenCanvas(e.width,e.height),this.offscreenCanvasContext=this.offscreenCanvas.getContext(\"2d\")),this.offscreenCanvas.width=e.width,this.offscreenCanvas.height=e.height,this.offscreenCanvasContext.drawImage(e,0,0,e.width,e.height);var r=this.offscreenCanvasContext.getImageData(-1,-1,e.width+2,e.height+2);return this.offscreenCanvasContext.clearRect(0,0,this.offscreenCanvas.width,this.offscreenCanvas.height),new t.RGBAImage({width:r.width,height:r.height},r.data)},u.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,d=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};d.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var f=u[c];l.push(new t.Point$1(f[0],f[1]))}a.push(l)}return a},d.prototype.toGeoJSON=function(t,e,r){return p.call(this,t,e,r)};var g=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};g.prototype.feature=function(t){return new d(this._features[t])};var m=t.vectorTile.VectorTileFeature,v=y;function y(t,e){this.options=e||{},this.features=t,this.length=t.length}function x(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}y.prototype.feature=function(t){return new x(this.features[t],this.options.extent)},x.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},x.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},x.prototype.toGeoJSON=m.prototype.toGeoJSON;var b=w,_=v;function w(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,T,t.layers[r])}(e,r),r.finish()}function T(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,k,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,C,a[r])}function k(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,M,t),e.writeVarintField(3,r.type),e.writeMessage(4,E,r)}function M(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),a[s]=l=n.length-1),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var f=u+\":\"+c,h=o[f];void 0===h&&(i.push(c),o[f]=h=i.length-1),e.writeVarint(h)}}function A(t,e){return(e<<3)+(7&t)}function S(t){return t<<1^t>>31}function E(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(A(1,c));for(var u=3===n?l.length-1:l.length,f=0;f<u;f++){1===f&&1!==n&&e.writeVarint(A(2,u-1));var h=l[f].x-i,p=l[f].y-a;e.writeVarint(S(h)),e.writeVarint(S(p)),i+=h,a+=p}3===n&&e.writeVarint(A(7,1))}}function C(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function L(t,e,r,n){I(t,r,n),I(e,2*r,2*n),I(e,2*r+1,2*n+1)}function I(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function P(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}b.fromVectorTileJs=w,b.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new v(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return w({layers:r})},b.GeoJSONWrapper=_;var z=function(t){return t[0]},O=function(t){return t[1]},D=function(t,e,r,n,i){void 0===e&&(e=z),void 0===r&&(r=O),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),f=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+f)),Math.min(a,Math.floor(n+(s-l)*u/s+f)),o)}var h=r[2*n+o],p=i,d=a;for(L(e,r,i,n),r[2*a+o]>h&&L(e,r,i,a);p<d;){for(L(e,r,p,d),p++,d--;r[2*p+o]<h;)p++;for(;r[2*d+o]>h;)d--}r[2*i+o]===h?L(e,r,i,d):L(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};D.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var f=c.pop(),h=c.pop(),p=c.pop();if(h-p<=o)for(var d=p;d<=h;d++)l=e[2*d+1],(s=e[2*d])>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+h)/2);l=e[2*g+1],(s=e[2*g])>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var m=(f+1)%2;(0===f?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(m)),(0===f?i>=s:a>=l)&&(c.push(g+1),c.push(h),c.push(m))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},D.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),f=o.pop();if(u-f<=a)for(var h=f;h<=u;h++)P(e[2*h],e[2*h+1],r,n)<=l&&s.push(t[h]);else{var p=Math.floor((f+u)/2),d=e[2*p],g=e[2*p+1];P(d,g,r,n)<=l&&s.push(t[p]);var m=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(f),o.push(p-1),o.push(m)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(m))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var R={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,generateId:!1,reduce:null,map:function(t){return t}},F=function(t){this.options=H(Object.create(R),t),this.trees=new Array(this.options.maxZoom+1)};function B(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function N(t,e){var r=t.geometry.coordinates,n=r[1];return{x:V(r[0]),y:q(n),zoom:1/0,index:e,parentId:-1}}function j(t){return{type:\"Feature\",id:t.id,properties:U(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function U(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return H(H({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function V(t){return t/360+.5}function q(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function H(t,e){for(var r in e)t[r]=e[r];return t}function G(t){return t.x}function Y(t){return t.y}function W(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function X(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)Z(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)Z(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)Z(t,e[n][i])}(i),i}function Z(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function J(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)K(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)K(i[c],s);else if(\"LineString\"===a)Q(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)Q(i[c],s=[],o,!1),t.push(X(l,\"LineString\",s,e.properties));return}$(i,s,o,!1)}else if(\"Polygon\"===a)$(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)J(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];$(i[c],u,o,!0),s.push(u)}}t.push(X(l,a,s,e.properties))}}function K(t,e){e.push(tt(t[0])),e.push(et(t[1])),e.push(0)}function Q(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=tt(t[s][0]),c=et(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],f=e[n],h=e[n+1],p=r+3;p<n;p+=3){var d=W(e[p],e[p+1],c,u,f,h);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function $(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];Q(t[i],a,r,n),e.push(a)}}function tt(t){return t/360+.5}function et(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function rt(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===h||\"MultiPoint\"===h)nt(f,g,r,n,i);else if(\"LineString\"===h)it(f,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===h)ot(f,g,r,n,i,!1);else if(\"Polygon\"===h)ot(f,g,r,n,i,!0);else if(\"MultiPolygon\"===h)for(var m=0;m<f.length;m++){var v=[];ot(f[m],v,r,n,i,!0),v.length&&g.push(v)}if(g.length){if(s.lineMetrics&&\"LineString\"===h){for(m=0;m<g.length;m++)l.push(X(u.id,h,g[m],u.tags));continue}\"LineString\"!==h&&\"MultiLineString\"!==h||(1===g.length?(h=\"LineString\",g=g[0]):h=\"MultiLineString\"),\"Point\"!==h&&\"MultiPoint\"!==h||(h=3===g.length?\"Point\":\"MultiPoint\"),l.push(X(u.id,h,g,u.tags))}}}return l.length?l:null}function nt(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function it(t,e,r,n,i,a,o){for(var s,l,c=at(t),u=0===i?lt:ct,f=t.start,h=0;h<t.length-3;h+=3){var p=t[h],d=t[h+1],g=t[h+2],m=t[h+3],v=t[h+4],y=0===i?p:d,x=0===i?m:v,b=!1;o&&(s=Math.sqrt(Math.pow(p-m,2)+Math.pow(d-v,2))),y<r?x>r&&(l=u(c,p,d,m,v,r),o&&(c.start=f+s*l)):y>n?x<n&&(l=u(c,p,d,m,v,n),o&&(c.start=f+s*l)):st(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,m,v,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,m,v,n),b=!0),!a&&b&&(o&&(c.end=f+s*l),e.push(c),c=at(t)),o&&(f+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&st(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&st(c,c[0],c[1],c[2]),c.length&&e.push(c)}function at(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function ot(t,e,r,n,i,a){for(var o=0;o<t.length;o++)it(t[o],e,r,n,i,a,!1)}function st(t,e,r,n){t.push(e),t.push(r),t.push(n)}function lt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function ct(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function ut(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=ft(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(ft(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(ft(a.geometry[s][c],e));i.push(l)}r.push(X(a.id,o,i,a.tags))}return r}function ft(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function ht(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(pt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var f=[];for(i=0;i<c[n].length;i+=2)f.push(pt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(f)}}return t.transformed=!0,t}function pt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function dt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,gt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,f=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),f>o.maxY&&(o.maxY=f)}return o}function gt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)mt(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)mt(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)mt(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var f in u={},e.tags)u[f]=e.tags[f];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var h={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(h.id=e.id),t.features.push(h)}}function mt(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function vt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)J(r,t.features[n],e,n);else J(r,\"Feature\"===t.type?t:{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=rt(t,1,-1-r,r,0,-1,2,e),a=rt(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=rt(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=ut(i,1).concat(n)),a&&(n=n.concat(ut(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function yt(t,e,r){return 32*((1<<t)*r+e)+t}function xt(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new g(n.features),a=b(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}F.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(N(t[l],l));this.trees[i+1]=new D(s,G,Y,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new D(s,G,Y,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},F.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,f=l.range(V(r),q(a),V(i),q(n));u<f.length;u+=1){var h=l.points[f[u]];c.push(h.numPoints?j(h):this.points[h.index])}return c},F.prototype.getChildren=function(t){var e=this._getOriginId(t),r=this._getOriginZoom(t),n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=i.points[c[l]];u.parentId===t&&s.push(u.numPoints?j(u):this.points[u.index])}if(0===s.length)throw new Error(n);return s},F.prototype.getLeaves=function(t,e,r){var n=[];return this._appendLeaves(n,t,e=e||10,r=r||0,0),n},F.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.radius/a.extent,s=(r-o)/i,l=(r+1+o)/i,c={features:[]};return this._addTileFeatures(n.range((e-o)/i,s,(e+1+o)/i,l),n.points,e,r,i,c),0===e&&this._addTileFeatures(n.range(1-o/i,s,1,l),n.points,i,r,i,c),e===i-1&&this._addTileFeatures(n.range(0,s,o/i,l),n.points,-1,r,i,c),c.features.length?c:null},F.prototype.getClusterExpansionZoom=function(t){for(var e=this._getOriginZoom(t)-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},F.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},F.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c=l.numPoints,u={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:c?U(l):this.points[l.index].properties},f=void 0;c?f=l.id:this.options.generateId?f=l.index:this.points[l.index].id&&(f=this.points[l.index].id),void 0!==f&&(u.id=f),a.features.push(u)}},F.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},F.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.reduce,a=n.radius/(n.extent*Math.pow(2,e)),o=0;o<t.length;o++){var s=t[o];if(!(s.zoom<=e)){s.zoom=e;for(var l=this.trees[e+1],c=l.within(s.x,s.y,a),u=s.numPoints||1,f=s.x*u,h=s.y*u,p=i&&u>1?this._map(s,!0):null,d=(o<<5)+(e+1)+this.points.length,g=0,m=c;g<m.length;g+=1){var v=l.points[m[g]];if(!(v.zoom<=e)){v.zoom=e;var y=v.numPoints||1;f+=v.x*y,h+=v.y*y,u+=y,v.parentId=d,i&&(p||(p=this._map(s,!0)),i(p,this._map(v)))}}1===u?r.push(s):(s.parentId=d,r.push(B(f/u,h/u,d,u,p)))}}return r},F.prototype._getOriginId=function(t){return t-this.points.length>>5},F.prototype._getOriginZoom=function(t){return(t-this.points.length)%32},F.prototype._map=function(t,e){if(t.numPoints)return e?H({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?H({},n):n},vt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},vt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,f=yt(e,r,n),h=this.tiles[f];if(!h&&(c>1&&console.time(\"creation\"),h=this.tiles[f]=dt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,h.numFeatures,h.numPoints,h.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(h.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||h.numPoints<=l.indexMaxPoints)continue;if(h.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,m,v,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,T=.5+_,k=1+_;g=m=v=y=null,x=rt(t,u,r-_,r+T,0,h.minX,h.maxX,l),b=rt(t,u,r+w,r+k,0,h.minX,h.maxX,l),t=null,x&&(g=rt(x,u,n-_,n+T,1,h.minY,h.maxY,l),m=rt(x,u,n+w,n+k,1,h.minY,h.maxY,l),x=null),b&&(v=rt(b,u,n-_,n+T,1,h.minY,h.maxY,l),y=rt(b,u,n+w,n+k,1,h.minY,h.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(m||[],e+1,2*r,2*n+1),s.push(v||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},vt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=yt(t,e=(e%o+o)%o,r);if(this.tiles[s])return ht(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,f=r;!l&&c>0;)c--,u=Math.floor(u/2),f=Math.floor(f/2),l=this.tiles[yt(c,u,f)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,f),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,f,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?ht(this.tiles[s],i):null):null};var bt=function(e){function r(t,r,n,i){e.call(this,t,r,n,xt),i&&(this.loadGeoJSON=i)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new t.RequestPerformance(n.request);this.loadGeoJSON(n,(function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){var n,i=e&&e.type;if(\"FeatureCollection\"===i)for(n=0;n<e.features.length;n++)t(e.features[n],r);else if(\"GeometryCollection\"===i)for(n=0;n<e.geometries.length;n++)t(e.geometries[n],r);else if(\"Feature\"===i)t(e.geometry,r);else if(\"Polygon\"===i)f(e.coordinates,r);else if(\"MultiPolygon\"===i)for(n=0;n<e.coordinates.length;n++)f(e.coordinates[n],r);return e}(o,!0);try{e._geoJSONIndex=n.cluster?new F(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var f=u[c],h=n[f],p=h[0],d=t.createExpression(h[1]),g=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",f]]:p);i[f]=d.value,a[f]=g.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):function(t,e){return new vt(t,e)}(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)}))}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded;return n&&n[t.uid]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){try{e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterChildren=function(t,e){try{e(null,this._geoJSONIndex.getChildren(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterLeaves=function(t,e){try{e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))}catch(t){e(t)}},r}(l),_t=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.availableImages={},this.workerSourceTypes={vector:l,geojson:bt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isParsed())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return _t.prototype.setReferrer=function(t,e){this.referrer=e},_t.prototype.setImages=function(t,e,r){for(var n in this.availableImages[t]=e,this.workerSources[t]){var i=this.workerSources[t][n];for(var a in i)i[a].availableImages=e}r()},_t.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},_t.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},_t.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},_t.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},_t.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},_t.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},_t.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},_t.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},_t.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},_t.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},_t.prototype.syncRTLPluginState=function(e,r,n){try{t.plugin.setState(r);var i=t.plugin.getPluginURL();if(t.plugin.isLoaded()&&!t.plugin.isParsed()&&null!=i){this.self.importScripts(i);var a=t.plugin.isParsed();n(a?void 0:new Error(\"RTL Text Plugin failed to import scripts from \"+i),a)}}catch(t){n(t.toString())}},_t.prototype.getAvailableImages=function(t){var e=this.availableImages[t];return e||(e=[]),e},_t.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},_t.prototype.getWorkerSource=function(t,e,r){var n=this;return this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),this.workerSources[t][e][r]||(this.workerSources[t][e][r]=new this.workerSourceTypes[e]({send:function(e,r,i){n.actor.send(e,r,i,t)}},this.getLayerIndex(t),this.getAvailableImages(t))),this.workerSources[t][e][r]},_t.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new u),this.demWorkerSources[t][e]},_t.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new _t(t.window)),_t})),n(0,(function(t){var e=t.createCommonjsModule((function(t){function e(t){return!r(t)}function r(t){return\"undefined\"==typeof window||\"undefined\"==typeof document?\"not a browser\":Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray?Function.prototype&&Function.prototype.bind?Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions?\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON?function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()?\"Uint8ClampedArray\"in window?ArrayBuffer.isView?function(){var t=document.createElement(\"canvas\");t.width=t.height=1;var e=t.getContext(\"2d\");if(!e)return!1;var r=e.getImageData(0,0,1,1);return r&&r.width===t.width}()?(void 0===n[r=t&&t.failIfMajorPerformanceCaveat]&&(n[r]=function(t){var r=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t);if(!r)return!1;var n=r.createShader(r.VERTEX_SHADER);return!(!n||r.isContextLost())&&(r.shaderSource(n,\"void main() {}\"),r.compileShader(n),!0===r.getShaderParameter(n,r.COMPILE_STATUS))}(r)),n[r]?void 0:\"insufficient WebGL support\"):\"insufficient Canvas/getImageData support\":\"insufficient ArrayBuffer support\":\"insufficient Uint8ClampedArray support\":\"insufficient worker support\":\"insufficient JSON support\":\"insufficient Object support\":\"insufficient Function support\":\"insufficent Array support\";var r}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e,window.mapboxgl.notSupportedReason=r);var n={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}})),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),t.addEventListener(e,r,\"passive\"in n&&l?n:n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),t.removeEventListener(e,r,\"passive\"in n&&l?n:n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function f(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout((function(){t.window.removeEventListener(\"click\",u,!0)}),0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect();return new t.Point(r.clientX-n.left-e.clientLeft,r.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=0;a<r.length;a++)i.push(new t.Point(r[a].clientX-n.left-e.clientLeft,r[a].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var h=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e];this._notify(n.ids,n.callback)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this._validate(t,e)&&(this.images[t]=e)},r.prototype._validate=function(e,r){var n=!0;return this._validateStretch(r.stretchX,r.data&&r.data.width)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchX\" value'))),n=!1),this._validateStretch(r.stretchY,r.data&&r.data.height)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchY\" value'))),n=!1),this._validateContent(r.content,r)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"content\" value'))),n=!1),n},r.prototype._validateStretch=function(t,e){if(!t)return!0;for(var r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];if(a[0]<r||a[1]<a[0]||e<a[1])return!1;r=a[1]}return!0},r.prototype._validateContent=function(t,e){return!(t&&(4!==t.length||t[0]<0||e.data.width<t[0]||t[1]<0||e.data.height<t[1]||t[2]<0||e.data.width<t[2]||t[3]<0||e.data.height<t[3]||t[2]<t[0]||t[3]<t[1]))},r.prototype.updateImage=function(t,e){e.version=this.images[t].version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1)this.images[i[n]]||(r=!1);this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,stretchX:s.stretchX,stretchY:s.stretchY,content:s.content,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,f=this.images[s].data,h=f.width,p=f.height;t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u},{width:h,height:p}),t.RGBAImage.copy(f,o,{x:0,y:p-1},{x:c,y:u-1},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u+p},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:h-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c+h,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];f(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=m,d=m,g=1e20;function m(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(y(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(y(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function y(t,e,r,n,i){r[0]=0,n[0]=-g,n[1]=+g;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+g}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}m.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?g:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?g:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++)r[n]=Math.max(0,Math.min(255,Math.round(255-255*((this.gridOuter[n]-this.gridInner[n])/this.radius+this.cutoff))));return r},p.default=d;var x=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};x.prototype.setURL=function(t){this.url=t},x.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1)i.push({stack:a,id:s[o]});t.asyncAll(i,(function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{},ranges:{}});var o=a.glyphs[i];if(void 0===o){if(o=n._tinySDF(a,r,i))return a.glyphs[i]=o,void e(null,{stack:r,id:i,glyph:o});var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else if(a.ranges[s])e(null,{stack:r,id:i,glyph:o});else{var l=a.requests[s];l||(l=a.requests[s]=[],x.loadGlyphRange(r,s,n.url,n.requestManager,(function(t,e){if(e){for(var r in e)n._doesCharSupportLocalGlyph(+r)||(a.glyphs[+r]=e[+r]);a.ranges[s]=!0}for(var i=0,o=l;i<o.length;i+=1)(0,o[i])(t,e);delete a.requests[s]}))),l.push((function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})}))}}else e(null,{stack:r,id:i,glyph:o})}),(function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}}))},x.prototype._doesCharSupportLocalGlyph=function(e){return!!this.localIdeographFontFamily&&(t.isChar[\"CJK Unified Ideographs\"](e)||t.isChar[\"Hangul Syllables\"](e)||t.isChar.Hiragana(e)||t.isChar.Katakana(e))},x.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&this._doesCharSupportLocalGlyph(n)){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new x.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},x.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,(function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}}))},x.TinySDF=p;var b=function(){this.specification=t.styleSpec.light.position};b.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},b.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var _=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new b,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),w=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(_),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),T=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.data=new Uint8Array(this.width*this.height),this.dashEntry={}};T.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.dashEntry[r]||(this.dashEntry[r]=this.addDash(t,e)),this.dashEntry[r]},T.prototype.getDashRanges=function(t,e,r){var n=[],i=t.length%2==1?-t[t.length-1]*r:0,a=t[0]*r,o=!0;n.push({left:i,right:a,isDash:o,zeroLength:0===t[0]});for(var s=t[0],l=1;l<t.length;l++){var c=t[l];n.push({left:i=s*r,right:a=(s+=c)*r,isDash:o=!o,zeroLength:0===c})}return n},T.prototype.addRoundDash=function(t,e,r){for(var n=e/2,i=-r;i<=r;i++)for(var a=this.width*(this.nextRow+r+i),o=0,s=t[o],l=0;l<this.width;l++){l/s.right>1&&(s=t[++o]);var c=Math.abs(l-s.left),u=Math.abs(l-s.right),f=Math.min(c,u),h=void 0,p=i/r*(n+1);if(s.isDash){var d=n-Math.abs(p);h=Math.sqrt(f*f+d*d)}else h=n-Math.sqrt(f*f+p*p);this.data[a+l]=Math.max(0,Math.min(255,h+128))}},T.prototype.addRegularDash=function(t){for(var e=t.length-1;e>=0;--e){var r=t[e],n=t[e+1];r.zeroLength?t.splice(e,1):n&&n.isDash===r.isDash&&(n.left=r.left,t.splice(e,1))}var i=t[0],a=t[t.length-1];i.isDash===a.isDash&&(i.left=a.left-this.width,a.right=i.right+this.width);for(var o=this.width*this.nextRow,s=0,l=t[s],c=0;c<this.width;c++){c/l.right>1&&(l=t[++s]);var u=Math.abs(c-l.left),f=Math.abs(c-l.right),h=Math.min(u,f);this.data[o+c]=Math.max(0,Math.min(255,(l.isDash?h:-h)+128))}},T.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];if(0!==a){var s=this.width/a,l=this.getDashRanges(e,this.width,s);r?this.addRoundDash(l,s,n):this.addRegularDash(l)}var c={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,c},T.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.ALPHA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.ALPHA,this.width,this.height,0,e.ALPHA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=new e.Actor(i[a],n,this.id);o.name=\"Worker \"+a,this.actors.push(o)}};function M(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(t.extend(a,e),[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\",\"scheme\",\"tileSize\",\"encoding\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map((function(t){return t.id}))),o.tiles=r.canonicalizeTileset(o,e.url),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame((function(){return i(null,e)}))}k.prototype.broadcast=function(e,r,n){t.asyncAll(this.actors,(function(t,n){t.send(e,r,n)}),n=n||function(){})},k.prototype.getActor=function(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]},k.prototype.remove=function(){this.actors.forEach((function(t){t.remove()})),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var S=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\",\"promoteId\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles,e.map._requestManager._customAccessToken),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken,e.map._requestManager._customAccessToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme)),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};function a(n,i){return delete e.request,e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,e.actor&&\"expired\"!==e.state?\"loading\"===e.state?e.reloadCallback=r:e.request=e.actor.send(\"reloadTile\",i,a.bind(this)):(e.actor=this.dispatcher.getActor(),e.request=e.actor.send(\"loadTile\",i,a.bind(this)))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.actor&&t.actor.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.unloadTile=function(t){t.unloadVectorData(),t.actor&&t.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({type:\"raster\"},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),(function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}}))},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),C=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({type:\"raster-dem\"},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);function i(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(a){this.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=t.window.ImageBitmap&&a instanceof t.window.ImageBitmap&&t.offscreenCanvasSupported()?a:t.browser.getImageData(a,1),s={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:o,encoding:this.encoding};e.actor&&\"expired\"!==e.state||(e.actor=this.dispatcher.getActor(),e.actor.send(\"loadDEMTile\",s,i.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",t.actor&&t.actor.send(\"removeDEMTile\",{uid:t.uid,source:this.id})},r}(E),L=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._loaded=!1,this.actor=i.getActor(),this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution),this.promoteId=n.promoteId;var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1,generateId:n.generateId||!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}}))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}})),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.actor.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterChildren=function(t,e){return this.actor.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.actor.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n),this},r.prototype._updateWorkerData=function(e){var r=this;this._loaded=!1;var n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.actor.send(this.type+\".loadData\",n,(function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.actor.send(r.type+\".coalesce\",{source:n.source},null),e(t))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.loadTile=function(e,r){var n=this,i=e.actor?\"reloadTile\":\"loadTile\";e.actor=this.actor,e.request=this.actor.send(i,{type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId},(function(t,a){return delete e.request,e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))}))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id})},r.prototype.onRemove=function(){this._removed=!0,this.actor.send(\"removeSource\",{type:this.type,source:this.id})},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),I=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),P=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(e,r){var n=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),(function(i,a){n._loaded=!0,i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())}))},r.prototype.loaded=function(){return this._loaded},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,(function(){e.texture=null})),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=Math.max(i-r,a-n),u=Math.max(0,Math.floor(-Math.log(c)/Math.LN2)),f=Math.pow(2,u);return new t.CanonicalTileID(u,Math.floor((r+i)/2*f),Math.floor((n+a)/2*f))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map((function(t){return r.tileID.getTilePoint(t)._round()}));return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),z=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1;var r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1)this.urls.push(this.map._requestManager.transformRequest(i[n],t.ResourceType.Source).url);t.getVideo(this.urls,(function(r,n){e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",(function(){e.map.triggerRepaint()})),e.map&&e.video.play(),e._finishLoading())}))},r.prototype.pause=function(){this.video&&this.video.pause()},r.prototype.play=function(){this.video&&this.video.play()},r.prototype.seek=function(e){if(this.video){var r=this.video.seekable;e<r.start(0)||e>r.end(0)?this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+this.id,null,\"Playback for this video can be set only between the \"+r.start(0)+\" and \"+r.end(0)+\"-second mark.\"))):this.video.currentTime=e}},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(P),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some((function(t){return!Array.isArray(t)||2!==t.length||t.some((function(t){return\"number\"!=typeof t}))}))||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(P),D={vector:S,raster:E,\"raster-dem\":C,geojson:L,video:z,image:P,canvas:O};function R(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function F(t,e,r,n,i,a){var o=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(i&&i.layers,e,t.id),s=a.maxPitchScaleFactor(),l=t.tilesIn(n,s,o);l.sort(B);for(var c=[],u=0,f=l;u<f.length;u+=1){var h=f[u];c.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,r,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,i,a,s,R(t.transform,h.tileID))})}var p=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],f=l[c]=l[c]||{},h=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];f[g.featureIndex]||(f[g.featureIndex]=!0,h.push(g))}}return e}(c);for(var d in p)p[d].forEach((function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n}));return p}function B(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var N=function(t,e){this.max=t,this.onRemove=e,this.reset()};N.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},N.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout((function(){n.remove(t,a)}),r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},N.prototype.has=function(t){return t.wrapped().key in this.data},N.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},N.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},N.prototype.getByKey=function(t){var e=this.data[t];return e?e[0].value:null},N.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},N.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},N.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this},N.prototype.filter=function(t){var e=[];for(var r in this.data)for(var n=0,i=this.data[r];n<i.length;n+=1){var a=i[n];t(a.value)||e.push(a)}for(var o=0,s=e;o<s.length;o+=1){var l=s[o];this.remove(l.value.tileID,l)}};var j=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};j.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},j.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},j.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var U={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},V=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};V.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},V.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},V.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=e.attributes[this.attributes[r].name];void 0!==n&&t.enableVertexAttribArray(n)}},V.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[U[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},V.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var q=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};q.prototype.get=function(){return this.current},q.prototype.set=function(t){},q.prototype.getDefault=function(){return this.default},q.prototype.setDefault=function(){this.set(this.default)};var H=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(q),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(q),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(q),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(q),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(q),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(q),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(q),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(q),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(q),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(q),nt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),it=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(q),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(q),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(q),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(q),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(q),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(q),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(q),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(q),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(q),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(q),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(q),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(q),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(q),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),bt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),_t=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e}(q),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(_t),Tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(_t),kt=function(t,e,r,n){this.context=t,this.width=e,this.height=r;var i=this.framebuffer=t.gl.createFramebuffer();this.colorAttachment=new wt(t,i),n&&(this.depthAttachment=new Tt(t,i))};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();if(e&&t.deleteTexture(e),this.depthAttachment){var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r)}t.deleteFramebuffer(this.framebuffer)};var Mt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Mt.ReadOnly=!1,Mt.ReadWrite=!0,Mt.disabled=new Mt(519,Mt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var St=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};St.disabled=new St(St.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),St.unblended=new St(St.Replace,t.Color.transparent,[!0,!0,!0,!0]),St.alphaBlended=new St([1,771],t.Color.transparent,[!0,!0,!0,!0]);var Et=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};Et.disabled=new Et(!1,1029,2305),Et.backCCW=new Et(!0,1029,2305);var Ct=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new H(this),this.clearDepth=new G(this),this.clearStencil=new Y(this),this.colorMask=new W(this),this.depthMask=new X(this),this.stencilMask=new Z(this),this.stencilFunc=new J(this),this.stencilOp=new K(this),this.stencilTest=new Q(this),this.depthRange=new $(this),this.depthTest=new tt(this),this.depthFunc=new et(this),this.blend=new rt(this),this.blendFunc=new nt(this),this.blendColor=new it(this),this.blendEquation=new at(this),this.cullFace=new ot(this),this.cullFaceSide=new st(this),this.frontFace=new lt(this),this.program=new ct(this),this.activeTexture=new ut(this),this.viewport=new ft(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new pt(this),this.bindTexture=new dt(this),this.bindVertexBuffer=new gt(this),this.bindElementBuffer=new mt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new yt(this),this.pixelStoreUnpackPremultiplyAlpha=new xt(this),this.pixelStoreUnpackFlipY=new bt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&(t.getExtension(\"OES_texture_half_float_linear\"),this.extRenderToTextureHalfFloat=t.getExtension(\"EXT_color_buffer_half_float\")),this.extTimerQuery=t.getExtension(\"EXT_disjoint_timer_query\")};Ct.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Ct.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Ct.prototype.createIndexBuffer=function(t,e){return new j(this,t,e)},Ct.prototype.createVertexBuffer=function(t,e,r){return new V(this,t,e,r)},Ct.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Ct.prototype.createFramebuffer=function(t,e,r){return new kt(this,t,e,r)},Ct.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Ct.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Ct.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Ct.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Ct.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,St.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Ct.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Lt=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",(function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))})),this.on(\"error\",(function(){a._sourceErrored=!0})),this._source=function(e,r,n,i){var a=new D[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a}(r,n,i,this),this._tiles={},this._cache=new N(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._loadedParentTiles={},this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,(function(){}))},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,(function(){}))},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return t.values(this._tiles).map((function(t){return t.tileID})).sort(It).map((function(t){return t.key}))},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(i,e)&&n.push(this._tiles[i]);return e?n.sort((function(e,n){var i=e.tileID,a=n.tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x})).map((function(t){return t.tileID.key})):n.map((function(t){return t.tileID})).sort(It).map((function(t){return t.key}))},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){if(t.key in this._loadedParentTiles){var r=this._loadedParentTiles[t.key];return r&&r.tileID.overscaledZ>=e?r:null}for(var n=t.overscaledZ-1;n>=e;n--){var i=t.scaledTo(n),a=this._getLoadedTile(i);if(a)return a}},r.prototype._getLoadedTile=function(t){var e=this._tiles[t.key];return e&&e.hasData()?e:this._cache.getByKey(t.wrapped().key)},r.prototype.updateCacheSize=function(t){var e=Math.ceil(t.width/this._source.tileSize)+1,r=Math.ceil(t.height/this._source.tileSize)+1,n=Math.floor(e*r*5),i=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,n):n;this._cache.setMaxSize(i)},r.prototype.handleWrapJump=function(t){var e=Math.round((t-(void 0===this._prevLng?t:this._prevLng))/360);if(this._prevLng=t,e){var r={};for(var n in this._tiles){var i=this._tiles[n];i.tileID=i.tileID.unwrapTo(i.tileID.wrap+e),r[i.tileID.key]=i}for(var a in this._tiles=r,this._timers)clearTimeout(this._timers[a]),delete this._timers[a];for(var o in this._tiles)this._setTileReloadTimer(o,this._tiles[o])}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map((function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)})):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter((function(t){return n._source.hasTile(t)})))):i=[];var a=e.coveringZoomLevel(this._source),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},f=0,h=Object.keys(l);f<h.length;f+=1){var p=h[f],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var m=this.findLoadedParent(d,o);m&&(this._addTile(m.tileID),c[m.tileID.key]=m.tileID),u[p]=d}}for(var v in this._retainLoadedChildren(u,a,s,l),c)l[v]||(this._coveredTiles[v]=!0,l[v]=c[v])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}this._updateLoadedParentTileCache()}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],f=this._addTile(u);n[u.key]=u,f.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var h=0,p=t;h<p.length;h+=1){var d=p[h],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var m=d.children(this._source.maxzoom)[0],v=this.getTile(m);if(v&&v.hasData()){n[m.key]=m;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._updateLoadedParentTileCache=function(){for(var t in this._loadedParentTiles={},this._tiles){for(var e=[],r=void 0,n=this._tiles[t].tileID;n.overscaledZ>0;){if(n.key in this._loadedParentTiles){r=this._loadedParentTiles[n.key];break}e.push(n.key);var i=n.scaledTo(n.overscaledZ-1);if(r=this._getLoadedTile(i))break;n=i}for(var a=0,o=e;a<o.length;a+=1)this._loadedParentTiles[o[a]]=r}},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout((function(){r._reloadTile(t,\"expired\"),delete r._timers[t]}),n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&\"reloading\"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map((function(t){return o.pointCoordinate(t)})),c=s.map((function(t){return o.pointCoordinate(t)})),u=this.getIds(),f=1/0,h=1/0,p=-1/0,d=-1/0,g=0,m=c;g<m.length;g+=1){var v=m[g];f=Math.min(f,v.x),h=Math.min(h,v.y),p=Math.max(p,v.x),d=Math.max(d,v.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),m=r*n.queryPadding*t.EXTENT/n.tileSize/g,v=[s.getTilePoint(new t.MercatorCoordinate(f,h)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(v[0].x-m<t.EXTENT&&v[0].y-m<t.EXTENT&&v[1].x+m>=0&&v[1].y+m>=0){var y=l.map((function(t){return s.getTilePoint(t)})),x=c.map((function(t){return s.getTilePoint(t)}));a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map((function(t){return e._tiles[t].tileID})),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){this._state.updateState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.removeFeatureState=function(t,e,r){this._state.removeFeatureState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.getFeatureState=function(t,e){return this._state.getState(t=t||\"_geojsonTileLayer\",e)},r.prototype.setDependencies=function(t,e,r){var n=this._tiles[t];n&&n.setDependencies(e,r)},r.prototype.reloadTilesForDependencies=function(t,e){for(var r in this._tiles)this._tiles[r].hasDependency(t,e)&&this._reloadTile(r,\"reloading\");this._cache.filter((function(r){return!r.hasDependency(t,e)}))},r}(t.Evented);function It(t,e){var r=Math.abs(2*t.wrap)-+(t.wrap<0),n=Math.abs(2*e.wrap)-+(e.wrap<0);return t.overscaledZ-e.overscaledZ||n-r||e.canonical.y-t.canonical.y||e.canonical.x-t.canonical.x}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function zt(){return new t.window.Worker(Yi.workerUrl)}Lt.maxOverzooming=10,Lt.maxUnderzooming=3;var Ot=\"mapboxgl_preloaded_worker_pool\",Dt=function(){this.active={}};Dt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<Dt.workerCount;)this.workers.push(new zt);return this.active[t]=!0,this.workers.slice()},Dt.prototype.release=function(t){delete this.active[t],0===this.numActive()&&(this.workers.forEach((function(t){t.terminate()})),this.workers=null)},Dt.prototype.isPreloaded=function(){return!!this.active[Ot]},Dt.prototype.numActive=function(){return Object.keys(this.active).length};var Rt,Ft=Math.floor(t.browser.hardwareConcurrency/2);function Bt(){return Rt||(Rt=new Dt),Rt}function Nt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach((function(t){t in r&&(n[t]=r[t])})),n}function jt(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Nt(t[n],e[t[n].ref]));return t}Dt.workerCount=Math.max(Math.min(Ft,6),1);var Ut={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Vt(t,e,r){r.push({command:Ut.addSource,args:[t,e[t]]})}function qt(t,e,r){e.push({command:Ut.removeSource,args:[t]}),r[t]=!0}function Ht(t,e,r,n){qt(t,r,n),Vt(t,e,r)}function Gt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function Yt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Wt(t){return t.id}function Xt(t,e){return t[e.id]=e,t}var Zt=function(t,e){this.reset(t,e)};Zt.prototype.reset=function(t,e){this.points=t||[],this._distances=[0];for(var r=1;r<this.points.length;r++)this._distances[r]=this._distances[r-1]+this.points[r].dist(this.points[r-1]);this.length=this._distances[this._distances.length-1],this.padding=Math.min(e||0,.5*this.length),this.paddedLength=this.length-2*this.padding},Zt.prototype.lerp=function(e){if(1===this.points.length)return this.points[0];e=t.clamp(e,0,1);for(var r=1,n=this._distances[r],i=e*this.paddedLength+this.padding;n<i&&r<this._distances.length;)n=this._distances[++r];var a=r-1,o=this._distances[a],s=n-o,l=s>0?(i-o)/s:0;return this.points[a].mult(1-l).add(this.points[r].mult(l))};var Jt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Kt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Qt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function $t(e,r){var n=[e.x,e.y,0,1];ue(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function te(t,e){return.5+t/e*.5}function ee(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function re(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),f=[256/n.width*2+1,256/n.height*2+1],h=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;h.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,m=!1,v=0;v<d.length;v++){var y=d.get(v);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!m)ce(y.numGlyphs,h);else{m=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),ee(x,f)){var b=te(n.transform.cameraToCenterDistance,x[3]),_=t.evaluateSizeForFeature(c,u,y),w=s?_/b:_*b,T=new t.Point(y.anchorX,y.anchorY),k=$t(T,a).point,M={},A=ae(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,h,k,T,M,g);m=A.useVertical,(A.notEnoughRoom||m||A.needsFlipping&&ae(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,h,k,T,M,g).notEnoughRoom)&&ce(y.numGlyphs,h)}else ce(y.numGlyphs,h)}}i?e.text.dynamicLayoutVertexBuffer.updateData(h):e.icon.dynamicLayoutVertexBuffer.updateData(h)}function ne(t,e,r,n,i,a,o,s,l,c,u){var f=s.glyphStartIndex+s.numGlyphs,h=s.lineStartIndex,p=s.lineStartIndex+s.lineLength,d=e.getoffsetX(s.glyphStartIndex),g=e.getoffsetX(f-1),m=se(t*d,r,n,i,a,o,s.segment,h,p,l,c,u);if(!m)return null;var v=se(t*g,r,n,i,a,o,s.segment,h,p,l,c,u);return v?{first:m,last:v}:null}function ie(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function ae(e,r,n,i,a,o,s,l,c,u,f,h,p,d){var g,m=r/24,v=e.lineOffsetX*m,y=e.lineOffsetY*m;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=ne(m,l,v,y,n,f,h,e,c,o,p);if(!w)return{notEnoughRoom:!0};var T=$t(w.first.point,s).point,k=$t(w.last.point,s).point;if(i&&!n){var M=ie(e.writingMode,T,k,d);if(M)return M}g=[w.first];for(var A=e.glyphStartIndex+1;A<x-1;A++)g.push(se(m*l.getoffsetX(A),v,y,n,f,h,e.segment,b,_,c,o,p));g.push(w.last)}else{if(i&&!n){var S=$t(h,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=$t(C,a),I=L.signedDistanceFromCamera>0?L.point:oe(h,C,S,1,a),P=ie(e.writingMode,S,I,d);if(P)return P}var z=se(m*l.getoffsetX(e.glyphStartIndex),v,y,n,f,h,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p);if(!z)return{notEnoughRoom:!0};g=[z]}for(var O=0,D=g;O<D.length;O+=1){var R=D[O];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function oe(t,e,r,n,i){var a=$t(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function se(e,r,n,i,a,o,s,l,c,u,f,h){var p=i?e-r:e+r,d=p>0?1:-1,g=0;i&&(d*=-1,g=Math.PI),d<0&&(g+=Math.PI);for(var m=d>0?l+s:l+s+1,v=a,y=a,x=0,b=0,_=Math.abs(p),w=[];x+b<=_;){if((m+=d)<l||m>=c)return null;if(y=v,w.push(v),void 0===(v=h[m])){var T=new t.Point(u.getx(m),u.gety(m)),k=$t(T,f);if(k.signedDistanceFromCamera>0)v=h[m]=k.point;else{var M=m-d;v=oe(0===x?o:new t.Point(u.getx(M),u.gety(M)),T,y,_-x+1,f)}}x+=b,b=y.dist(v)}var A=(_-x)/b,S=v.sub(y),E=S.mult(A)._add(y);E._add(S._unit()._perp()._mult(n*d));var C=g+Math.atan2(v.y-y.y,v.x-y.x);return w.push(E),{point:E,angle:C,path:w}}Jt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Jt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Jt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Jt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Jt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Jt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],f=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-f,y1:u-f,x2:c+f,y2:u+f})}return a?o.filter(a):o}return this._forEachCell(t,e,r,n,this._queryCell,o,{hitTest:i,seenUids:{box:{},circle:{}}},a),i?o.length>0:o},Jt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[];return this._forEachCell(a,s,o,l,this._queryCellCircle,c,{hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}},i),n?c.length>0:c},Jt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Jt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Jt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Jt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,f=0,h=c;f<h.length;f+=1){var p=h[f];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var m=this.circles,v=0,y=g;v<y.length;v+=1){var x=y[v];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(m[b],m[b+1],m[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=m[b],w=m[b+1],T=m[b+2];a.push({key:this.circleKeys[x],x1:_-T,y1:w-T,x2:_+T,y2:w+T})}}}},Jt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var f=this.bboxes,h=0,p=u;h<p.length;h+=1){var d=p[h];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,f[g+0],f[g+1],f[g+2],f[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var m=this.circleCells[i];if(null!==m)for(var v=this.circles,y=0,x=m;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(v[_],v[_+1],v[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Jt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),f=this._convertToYCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++)if(i.call(this,t,e,r,n,this.xCellCount*p+h,a,o,s))return},Jt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Jt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Jt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Jt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var f=l-s,h=u-c;return f*f+h*h<=r*r};var le=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ce(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(le,3*n)}}function ue(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var fe=function(t,e,r){void 0===e&&(e=new Jt(t.width+200,t.height+200,25)),void 0===r&&(r=new Jt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function he(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}fe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},fe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,f,h,p){var d=[],g=new t.Point(r.anchorX,r.anchorY),m=$t(g,o),v=te(this.transform.cameraToCenterDistance,m.signedDistanceFromCamera),y=(u?a/v:a*v)/t.ONE_EM,x=$t(g,s).point,b=ne(y,i,r.lineOffsetX*y,r.lineOffsetY*y,!1,x,g,r,n,s,{}),_=!1,w=!1,T=!0;if(b){for(var k=.5*h*v+p,M=new t.Point(-100,-100),A=new t.Point(this.screenRightBoundary,this.screenBottomBoundary),S=new Zt,E=b.first,C=b.last,L=[],I=E.path.length-1;I>=1;I--)L.push(E.path[I]);for(var P=1;P<C.path.length;P++)L.push(C.path[P]);var z=2.5*k;if(l){var O=L.map((function(t){return $t(t,l)}));L=O.some((function(t){return t.signedDistanceFromCamera<=0}))?[]:O.map((function(t){return t.point}))}var D=[];if(L.length>0){for(var R=L[0].clone(),F=L[0].clone(),B=1;B<L.length;B++)R.x=Math.min(R.x,L[B].x),R.y=Math.min(R.y,L[B].y),F.x=Math.max(F.x,L[B].x),F.y=Math.max(F.y,L[B].y);D=R.x>=M.x&&F.x<=A.x&&R.y>=M.y&&F.y<=A.y?[L]:F.x<M.x||R.x>A.x||F.y<M.y||R.y>A.y?[]:t.clipLine([L],M.x,M.y,A.x,A.y)}for(var N=0,j=D;N<j.length;N+=1){var U;S.reset(j[N],.25*k),U=S.length<=.5*k?1:Math.ceil(S.paddedLength/z)+1;for(var V=0;V<U;V++){var q=V/Math.max(U-1,1),H=S.lerp(q),G=H.x+100,Y=H.y+100;d.push(G,Y,k,0);var W=G-k,X=Y-k,Z=G+k,J=Y+k;if(T=T&&this.isOffscreen(W,X,Z,J),w=w||this.isInsideGrid(W,X,Z,J),!e&&this.grid.hitTestCircle(G,Y,k,f)&&(_=!0,!c))return{circles:[],offscreen:!1,collisionDetected:_}}}}return{circles:!c&&_||!w?[]:d,offscreen:T,collisionDetected:_}},fe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var f={},h={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],m=g.key;if(void 0===f[m.bucketInstanceId]&&(f[m.bucketInstanceId]={}),!f[m.bucketInstanceId][m.featureIndex]){var v=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,v)&&(f[m.bucketInstanceId][m.featureIndex]=!0,void 0===h[m.bucketInstanceId]&&(h[m.bucketInstanceId]=[]),h[m.bucketInstanceId].push(m.featureIndex))}}return h},fe.prototype.insertCollisionBox=function(t,e,r,n,i){(e?this.ignoredGrid:this.grid).insert({bucketInstanceId:r,featureIndex:n,collisionGroupID:i},t[0],t[1],t[2],t[3])},fe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},fe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ue(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},fe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},fe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary},fe.prototype.getViewportMatrix=function(){var e=t.identity([]);return t.translate(e,e,[-100,-100,0]),e};var pe=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};pe.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var de=function(t,e,r,n,i){this.text=new pe(t?t.text:null,e,r,i),this.icon=new pe(t?t.icon:null,e,n,i)};de.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var ge=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},me=function(){this.invProjMatrix=t.create(),this.viewportMatrix=t.create(),this.circles=[]},ve=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},ye=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function xe(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateVariableOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}function be(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,f=e.anchorPointX,h=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:f,anchorPointY:h}}ye.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var _e=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new fe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new ye(r),this.collisionCircleArrays={},this.prevPlacement=n,n&&(n.prevPlacement=void 0),this.placedOrientations={}};function we(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}_e.prototype.getBucketParts=function(e,r,n,i){var a=n.getBucket(r),o=n.latestFeatureIndex;if(a&&o&&r.id===a.layerIds[0]){var s=n.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-n.tileID.overscaledZ),u=n.tileSize/t.EXTENT,f=this.transform.calculatePosMatrix(n.tileID.toUnwrapped()),h=\"map\"===l.get(\"text-pitch-alignment\"),p=\"map\"===l.get(\"text-rotation-alignment\"),d=he(n,1,this.transform.zoom),g=Kt(f,h,p,this.transform,d),m=null;if(h){var v=Qt(f,h,p,this.transform,d);m=t.multiply([],this.transform.labelPlaneMatrix,v)}this.retainedQueryData[a.bucketInstanceId]=new ve(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,n.tileID);var y={bucket:a,layout:l,posMatrix:f,textLabelPlaneMatrix:g,labelToScreenMatrix:m,scale:c,textPixelRatio:u,holdingForFade:n.holdingForFade(),collisionBoxArray:s,partiallyEvaluatedTextSize:t.evaluateSizeForZoom(a.textSizeData,this.transform.zoom),collisionGroup:this.collisionGroups.get(a.sourceID)};if(i)for(var x=0,b=a.sortKeyRanges;x<b.length;x+=1){var _=b[x];e.push({sortKey:_.sortKey,symbolInstanceStart:_.symbolInstanceStart,symbolInstanceEnd:_.symbolInstanceEnd,parameters:y})}else e.push({symbolInstanceStart:0,symbolInstanceEnd:a.symbolInstances.length,parameters:y})}},_e.prototype.attemptAnchorPlacement=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d){var g,m=[f.textOffset0,f.textOffset1],v=xe(t,r,n,m,i),y=this.collisionIndex.placeCollisionBox(be(e,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate);if(!d||0!==this.collisionIndex.placeCollisionBox(be(d,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate).box.length)return y.box.length>0?(this.prevPlacement&&this.prevPlacement.variableOffsets[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID].text&&(g=this.prevPlacement.variableOffsets[f.crossTileID].anchor),this.variableOffsets[f.crossTileID]={textOffset:m,width:r,height:n,anchor:t,textBoxScale:i,prevAnchor:g},this.markUsedJustification(h,t,f,p),h.allowVerticalPlacement&&(this.markUsedOrientation(h,p,f),this.placedOrientations[f.crossTileID]=p),{shift:v,placedGlyphBoxes:y}):void 0},_e.prototype.placeLayerBucketPart=function(e,r,n){var i=this,a=e.parameters,o=a.bucket,s=a.layout,l=a.posMatrix,c=a.textLabelPlaneMatrix,u=a.labelToScreenMatrix,f=a.textPixelRatio,h=a.holdingForFade,p=a.collisionBoxArray,d=a.partiallyEvaluatedTextSize,g=a.collisionGroup,m=s.get(\"text-optional\"),v=s.get(\"icon-optional\"),y=s.get(\"text-allow-overlap\"),x=s.get(\"icon-allow-overlap\"),b=\"map\"===s.get(\"text-rotation-alignment\"),_=\"map\"===s.get(\"text-pitch-alignment\"),w=\"none\"!==s.get(\"icon-text-fit\"),T=\"viewport-y\"===s.get(\"symbol-z-order\"),k=y&&(x||!o.hasIconData()||v),M=x&&(y||!o.hasTextData()||m);!o.collisionArrays&&p&&o.deserializeCollisionBoxes(p);var A=function(e,a){if(!r[e.crossTileID])if(h)i.placements[e.crossTileID]=new ge(!1,!1,!1);else{var p,T=!1,A=!1,S=!0,E=null,C={box:null,offscreen:null},L={box:null,offscreen:null},I=null,P=null,z=0,O=0,D=0;a.textFeatureIndex?z=a.textFeatureIndex:e.useRuntimeCollisionCircles&&(z=e.featureIndex),a.verticalTextFeatureIndex&&(O=a.verticalTextFeatureIndex);var R=a.textBox;if(R){var F=function(r){var n=t.WritingMode.horizontal;if(o.allowVerticalPlacement&&!r&&i.prevPlacement){var a=i.prevPlacement.placedOrientations[e.crossTileID];a&&(i.placedOrientations[e.crossTileID]=a,i.markUsedOrientation(o,n=a,e))}return n},B=function(r,n){if(o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&a.verticalTextBox)for(var i=0,s=o.writingModes;i<s.length&&(s[i]===t.WritingMode.vertical?(C=n(),L=C):C=r(),!(C&&C.box&&C.box.length));i+=1);else C=r()};if(s.get(\"text-variable-anchor\")){var N=s.get(\"text-variable-anchor\");if(i.prevPlacement&&i.prevPlacement.variableOffsets[e.crossTileID]){var j=i.prevPlacement.variableOffsets[e.crossTileID];N.indexOf(j.anchor)>0&&(N=N.filter((function(t){return t!==j.anchor}))).unshift(j.anchor)}var U=function(t,r,n){for(var a=t.x2-t.x1,s=t.y2-t.y1,c=e.textBoxScale,u=w&&!x?r:null,h={box:[],offscreen:!1},p=y?2*N.length:N.length,d=0;d<p;++d){var m=i.attemptAnchorPlacement(N[d%N.length],t,a,s,c,b,_,f,l,g,d>=N.length,e,o,n,u);if(m&&(h=m.placedGlyphBoxes)&&h.box&&h.box.length){T=!0,E=m.shift;break}}return h};B((function(){return U(R,a.iconBox,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&!(C&&C.box&&C.box.length)&&e.numVerticalGlyphVertices>0&&r?U(r,a.verticalIconBox,t.WritingMode.vertical):{box:null,offscreen:null}})),C&&(T=C.box,S=C.offscreen);var V=F(C&&C.box);if(!T&&i.prevPlacement){var q=i.prevPlacement.variableOffsets[e.crossTileID];q&&(i.variableOffsets[e.crossTileID]=q,i.markUsedJustification(o,q.anchor,e,V))}}else{var H=function(t,r){var n=i.collisionIndex.placeCollisionBox(t,y,f,l,g.predicate);return n&&n.box&&n.box.length&&(i.markUsedOrientation(o,r,e),i.placedOrientations[e.crossTileID]=r),n};B((function(){return H(R,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&r?H(r,t.WritingMode.vertical):{box:null,offscreen:null}})),F(C&&C.box&&C.box.length)}}if(T=(p=C)&&p.box&&p.box.length>0,S=p&&p.offscreen,e.useRuntimeCollisionCircles){var G=o.text.placedSymbolArray.get(e.centerJustifiedTextSymbolIndex),Y=t.evaluateSizeForFeature(o.textSizeData,d,G),W=s.get(\"text-padding\");I=i.collisionIndex.placeCollisionCircles(y,G,o.lineVertexArray,o.glyphOffsetArray,Y,l,c,u,n,_,g.predicate,e.collisionCircleDiameter,W),T=y||I.circles.length>0&&!I.collisionDetected,S=S&&I.offscreen}if(a.iconFeatureIndex&&(D=a.iconFeatureIndex),a.iconBox){var X=function(t){var e=w&&E?be(t,E.x,E.y,b,_,i.transform.angle):t;return i.collisionIndex.placeCollisionBox(e,x,f,l,g.predicate)};A=L&&L.box&&L.box.length&&a.verticalIconBox?(P=X(a.verticalIconBox)).box.length>0:(P=X(a.iconBox)).box.length>0,S=S&&P.offscreen}var Z=m||0===e.numHorizontalGlyphVertices&&0===e.numVerticalGlyphVertices,J=v||0===e.numIconVertices;if(Z||J?J?Z||(A=A&&T):T=A&&T:A=T=A&&T,T&&p&&p.box&&i.collisionIndex.insertCollisionBox(p.box,s.get(\"text-ignore-placement\"),o.bucketInstanceId,L&&L.box&&O?O:z,g.ID),A&&P&&i.collisionIndex.insertCollisionBox(P.box,s.get(\"icon-ignore-placement\"),o.bucketInstanceId,D,g.ID),I&&(T&&i.collisionIndex.insertCollisionCircles(I.circles,s.get(\"text-ignore-placement\"),o.bucketInstanceId,z,g.ID),n)){var K=o.bucketInstanceId,Q=i.collisionCircleArrays[K];void 0===Q&&(Q=i.collisionCircleArrays[K]=new me);for(var $=0;$<I.circles.length;$+=4)Q.circles.push(I.circles[$+0]),Q.circles.push(I.circles[$+1]),Q.circles.push(I.circles[$+2]),Q.circles.push(I.collisionDetected?1:0)}i.placements[e.crossTileID]=new ge(T||k,A||M,S||o.justReloaded),r[e.crossTileID]=!0}};if(T)for(var S=o.getSortedSymbolIndexes(this.transform.angle),E=S.length-1;E>=0;--E){var C=S[E];A(o.symbolInstances.get(C),o.collisionArrays[C])}else for(var L=e.symbolInstanceStart;L<e.symbolInstanceEnd;L++)A(o.symbolInstances.get(L),o.collisionArrays[L]);if(n&&o.bucketInstanceId in this.collisionCircleArrays){var I=this.collisionCircleArrays[o.bucketInstanceId];t.invert(I.invProjMatrix,l),I.viewportMatrix=this.collisionIndex.getViewportMatrix()}o.justReloaded=!1},_e.prototype.markUsedJustification=function(e,r,n,i){var a;a=i===t.WritingMode.vertical?n.verticalPlacedTextSymbolIndex:{left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex}[t.getAnchorJustification(r)];for(var o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];o<s.length;o+=1){var l=s[o];l>=0&&(e.text.placedSymbolArray.get(l).crossTileID=a>=0&&l!==a?0:n.crossTileID)}},_e.prototype.markUsedOrientation=function(e,r,n){for(var i=r===t.WritingMode.horizontal||r===t.WritingMode.horizontalOnly?r:0,a=r===t.WritingMode.vertical?r:0,o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];o<s.length;o+=1)e.text.placedSymbolArray.get(s[o]).placedOrientation=i;n.verticalPlacedTextSymbolIndex&&(e.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=a)},_e.prototype.commit=function(t){this.commitTime=t,this.zoomAtLastRecencyCheck=this.transform.zoom;var e=this.prevPlacement,r=!1;this.prevZoomAdjustment=e?e.zoomAdjustment(this.transform.zoom):0;var n=e?e.symbolFadeChange(t):1,i=e?e.opacities:{},a=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(var s in this.placements){var l=this.placements[s],c=i[s];c?(this.opacities[s]=new de(c,n,l.text,l.icon),r=r||l.text!==c.text.placed||l.icon!==c.icon.placed):(this.opacities[s]=new de(null,n,l.text,l.icon,l.skipFade),r=r||l.text||l.icon)}for(var u in i){var f=i[u];if(!this.opacities[u]){var h=new de(f,n,!1,!1);h.isHidden()||(this.opacities[u]=h,r=r||f.text.placed||f.icon.placed)}}for(var p in a)this.variableOffsets[p]||!this.opacities[p]||this.opacities[p].isHidden()||(this.variableOffsets[p]=a[p]);for(var d in o)this.placedOrientations[d]||!this.opacities[d]||this.opacities[d].isHidden()||(this.placedOrientations[d]=o[d]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},_e.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},_e.prototype.updateBucketOpacities=function(e,r,n){var i=this;e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexArray.clear(),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexArray.clear();var a=e.layers[0].layout,o=new de(null,0,!1,!1,!0),s=a.get(\"text-allow-overlap\"),l=a.get(\"icon-allow-overlap\"),c=a.get(\"text-variable-anchor\"),u=\"map\"===a.get(\"text-rotation-alignment\"),f=\"map\"===a.get(\"text-pitch-alignment\"),h=\"none\"!==a.get(\"icon-text-fit\"),p=new de(null,0,s&&(l||!e.hasIconData()||a.get(\"icon-optional\")),l&&(s||!e.hasTextData()||a.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData())&&e.deserializeCollisionBoxes(n);for(var d=function(t,e,r){for(var n=0;n<e/4;n++)t.opacityVertexArray.emplaceBack(r)},g=function(n){var a=e.symbolInstances.get(n),s=a.numHorizontalGlyphVertices,l=a.numVerticalGlyphVertices,g=a.crossTileID,m=i.opacities[g];r[g]?m=o:m||(i.opacities[g]=m=p),r[g]=!0;var v=a.numIconVertices>0,y=i.placedOrientations[a.crossTileID],x=y===t.WritingMode.vertical,b=y===t.WritingMode.horizontal||y===t.WritingMode.horizontalOnly;if(s>0||l>0){var _=Le(m.text);d(e.text,s,x?Ie:_),d(e.text,l,b?Ie:_);var w=m.text.isHidden();[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach((function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=w||x?1:0)})),a.verticalPlacedTextSymbolIndex>=0&&(e.text.placedSymbolArray.get(a.verticalPlacedTextSymbolIndex).hidden=w||b?1:0);var T=i.variableOffsets[a.crossTileID];T&&i.markUsedJustification(e,T.anchor,a,y);var k=i.placedOrientations[a.crossTileID];k&&(i.markUsedJustification(e,\"left\",a,k),i.markUsedOrientation(e,k,a))}if(v){var M=Le(m.icon),A=!(h&&a.verticalPlacedIconSymbolIndex&&x);a.placedIconSymbolIndex>=0&&(d(e.icon,a.numIconVertices,A?M:Ie),e.icon.placedSymbolArray.get(a.placedIconSymbolIndex).hidden=m.icon.isHidden()),a.verticalPlacedIconSymbolIndex>=0&&(d(e.icon,a.numVerticalIconVertices,A?Ie:M),e.icon.placedSymbolArray.get(a.verticalPlacedIconSymbolIndex).hidden=m.icon.isHidden())}if(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData()){var S=e.collisionArrays[n];if(S){var E=new t.Point(0,0);if(S.textBox||S.verticalTextBox){var C=!0;if(c){var L=i.variableOffsets[g];L?(E=xe(L.anchor,L.width,L.height,L.textOffset,L.textBoxScale),u&&E._rotate(f?i.transform.angle:-i.transform.angle)):C=!1}S.textBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||x,E.x,E.y),S.verticalTextBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||b,E.x,E.y)}var I=Boolean(!b&&S.verticalIconBox);S.iconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,I,h?E.x:0,h?E.y:0),S.verticalIconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,!I,h?E.x:0,h?E.y:0)}}},m=0;m<e.symbolInstances.length;m++)g(m);if(e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexBuffer&&e.iconCollisionBox.collisionVertexBuffer.updateData(e.iconCollisionBox.collisionVertexArray),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexBuffer&&e.textCollisionBox.collisionVertexBuffer.updateData(e.textCollisionBox.collisionVertexArray),e.bucketInstanceId in this.collisionCircleArrays){var v=this.collisionCircleArrays[e.bucketInstanceId];e.placementInvProjMatrix=v.invProjMatrix,e.placementViewportMatrix=v.viewportMatrix,e.collisionCircleArray=v.circles,delete this.collisionCircleArrays[e.bucketInstanceId]}},_e.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration+this.prevZoomAdjustment},_e.prototype.zoomAdjustment=function(t){return Math.max(0,(this.transform.zoom-t)/1.5)},_e.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},_e.prototype.stillRecent=function(t,e){var r=this.zoomAtLastRecencyCheck===e?1-this.zoomAdjustment(e):1;return this.zoomAtLastRecencyCheck=e,this.commitTime+this.fadeDuration*r>t},_e.prototype.setStale=function(){this.stale=!0};var Te=Math.pow(2,25),ke=Math.pow(2,24),Me=Math.pow(2,17),Ae=Math.pow(2,16),Se=Math.pow(2,9),Ee=Math.pow(2,8),Ce=Math.pow(2,1);function Le(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*Te+e*ke+r*Me+e*Ae+r*Se+e*Ee+r*Ce+e}var Ie=0,Pe=function(t){this._sortAcrossTiles=\"viewport-y\"!==t.layout.get(\"symbol-z-order\")&&void 0!==t.layout.get(\"symbol-sort-key\").constantOr(1),this._currentTileIndex=0,this._currentPartIndex=0,this._seenCrossTileIDs={},this._bucketParts=[]};Pe.prototype.continuePlacement=function(t,e,r,n,i){for(var a=this._bucketParts;this._currentTileIndex<t.length;)if(e.getBucketParts(a,n,t[this._currentTileIndex],this._sortAcrossTiles),this._currentTileIndex++,i())return!0;for(this._sortAcrossTiles&&(this._sortAcrossTiles=!1,a.sort((function(t,e){return t.sortKey-e.sortKey})));this._currentPartIndex<a.length;)if(e.placeLayerBucketPart(a[this._currentPartIndex],this._seenCrossTileIDs,r),this._currentPartIndex++,i())return!0;return!1};var ze=function(t,e,r,n,i,a,o){this.placement=new _e(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};ze.prototype.isDone=function(){return this._done},ze.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Pe(s)),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},ze.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Oe=512/t.EXTENT/2,De=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};De.prototype.getScaledCoordinates=function(e,r){var n=Oe/Math.pow(2,r.canonical.z-this.tileID.canonical.z);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*n),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*n)}},De.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Re=function(){this.maxCrossTileID=0};Re.prototype.generate=function(){return++this.maxCrossTileID};var Fe=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Fe.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Fe.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var f=e.symbolInstances.get(u);f.crossTileID||(f.crossTileID=r.generate(),i[f.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new De(t,e.symbolInstances,e.bucketInstanceId),!0},Fe.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1)delete this.usedCrossTileIDs[t][i[n].crossTileID]},Fe.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Be=function(){this.layerIndexes={},this.crossTileIDs=new Re,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Be.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Fe);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Be.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach((function(t){e[t]=!0})),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Ne=function(e,r){return t.emitValidationErrors(e,r&&r.filter((function(t){return\"source.canvas\"!==t.identifier})))},je=t.pick(Ut,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ue=t.pick(Ut,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),Ve=function(){var e={},r=t.styleSpec.$version;for(var n in t.styleSpec.$root){var i,a=t.styleSpec.$root[n];a.required&&null!=(i=\"version\"===n?r:\"array\"===a.type?[]:{})&&(e[n]=i)}return e}(),qe=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k(Bt(),this),this.imageManager=new h,this.imageManager.setEventedParent(this),this.glyphManager=new x(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new T(256,512),this.crossTileSymbolIndex=new Be,this._layers={},this._serializedLayers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._availableImages=[],this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginStateChange((function(e){o.dispatcher.broadcast(\"syncRTLPluginState\",{pluginStatus:e.pluginStatus,pluginURL:e.pluginURL},(function(e,r){if(t.triggerPluginCompletionEvent(e),r&&r.every((function(t){return t})))for(var n in o.sourceCaches)o.sourceCaches[n].reload()}))})),this.on(\"data\",(function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}}))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,(function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)}))},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame((function(){n._request=null,n._load(e,!1!==r.validate)}))},r.prototype.loadEmpty=function(){this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._load(Ve,!1)},r.prototype._load=function(e,r){if(!r||!Ne(this,t.validateStyle(e))){for(var n in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(n,e.sources[n],{validate:!1});e.sprite?this._loadSprite(e.sprite):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var i=jt(this.stylesheet.layers);this._order=i.map((function(t){return t.id})),this._layers={},this._serializedLayers={};for(var a=0,o=i;a<o.length;a+=1){var s=o[a];(s=t.createStyleLayer(s)).setEventedParent(this,{layer:{id:s.id}}),this._layers[s.id]=s,this._serializedLayers[s.id]=s.serialize()}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new w(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._loadSprite=function(e){var r=this;this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),(function(t,e){l=null,o||(o=t,i=e,u())})),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),(function(t,e){c=null,o||(o=t,a=e,u())}));function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,f=l.x,h=l.y,p=l.sdf,d=l.pixelRatio,g=l.stretchX,m=l.stretchY,v=l.content,y=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,y,{x:f,y:h},{x:0,y:0},{width:c,height:u}),r[s]={data:y,pixelRatio:d,sdf:p,stretchX:g,stretchY:m,content:v}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e,this.map._requestManager,(function(e,n){if(r._spriteRequest=null,e)r.fire(new t.ErrorEvent(e));else if(n)for(var i in n)r.imageManager.addImage(i,n[i]);r.imageManager.setLoaded(!0),r._availableImages=r.imageManager.listImages(),r.dispatcher.broadcast(\"setImages\",r._availableImages),r.fire(new t.Event(\"data\",{dataType:\"style\"}))}))},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=this._layers[n[r]];\"custom\"!==i.type&&e.push(i.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updateTilesForChangedImages(),this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var f=this._layers[u[c]];f.recalculate(e,this._availableImages),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateTilesForChangedImages=function(){var t=Object.keys(this._changedImages);if(t.length){for(var e in this.sourceCaches)this.sourceCaches[e].reloadTilesForDependencies([\"icons\",\"patterns\"],t);this._changedImages={}}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={},this._changedImages={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Ne(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=jt(e.layers);var n=function(e,r){if(!e)return[{command:Ut.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Ut.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Ut.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Ut.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Ut.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Ut.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Ut.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Ut.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Ut.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Ut.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||qt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Gt(e,r,a)?n.push({command:Ut.setGeoJSONSourceData,args:[a,r[a].data]}):Ht(a,r,n,i)):Vt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach((function(t){i[t.source]?n.push({command:Ut.removeLayer,args:[t.id]}):o.push(t)})),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,f=(e=e||[]).map(Wt),h=r.map(Wt),p=e.reduce(Xt,{}),d=r.reduce(Xt,{}),g=f.slice(),m=Object.create(null);for(i=0,a=0;i<f.length;i++)d.hasOwnProperty(o=f[i])?a++:(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<h.length;i++)g[g.length-1-i]!==(o=h[h.length-1-i])&&(p.hasOwnProperty(o)?(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,n.push({command:Ut.addLayer,args:[d[o],c=g[g.length-i]]}),g.splice(g.length-i,0,o),m[o]=!0);for(i=0;i<h.length;i++)if(s=p[o=h[i]],l=d[o],!m[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in Yt(s.layout,l.layout,n,o,null,Ut.setLayoutProperty),Yt(s.paint,l.paint,n,o,null,Ut.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Ut.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Ut.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Ut.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Ut.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Ut.setStyle,args:[r]}]}return n}(this.serialize(),e).filter((function(t){return!(t.command in Ue)}));if(0===n.length)return!1;var i=n.filter((function(t){return!(t.command in je)}));if(i.length>0)throw new Error(\"Unimplemented: \"+i.map((function(t){return t.command})).join(\", \")+\".\");return n.forEach((function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)})),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Lt(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,(function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}})),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Ne(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}}),this._serializedLayers[a.id]=a.serialize()}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._serializedLayers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.hasLayer=function(t){return t in this._layers},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n];if(void 0!==a){var o=a.getSource().type;\"geojson\"===o&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==o||i?(void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),a.setFeatureState(i,e.id,r)):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0;\"vector\"!==a||o?r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,e.id,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r];if(void 0!==i){if(\"vector\"!==i.getSource().type||n)return void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),i.getFeatureState(n,e.id);this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,(function(t){return t.serialize()})),layers:this._serializeLayers(this._order)},(function(t){return void 0!==t}))},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&\"raster\"!==this.sourceCaches[t.source].getSource().type&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,f=c;u<f.length;u+=1)i.push(f[u])}}}i.sort((function(t,e){return e.intersectionZ-t.intersectionZ}));for(var h=[],p=this._order.length-1;p>=0;p--){var d=this._order[p];if(r(d))for(var g=i.length-1;g>=0;g--){var m=i[g].feature;if(n[m.layer.id]<p)break;h.push(m),i.pop()}else for(var v=0,y=t;v<y.length;v+=1){var x=y[v][d];if(x)for(var b=0,_=x;b<_.length;b+=1)h.push(_[b].feature)}}return h},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in r.availableImages=this._availableImages,this.sourceCaches)r.layers&&!i[u]||c.push(F(this.sourceCaches[u],this._layers,this._serializedLayers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a,o){for(var s={},l=a.queryRenderedSymbols(n),c=[],u=0,f=Object.keys(l).map(Number);u<f.length;u+=1)c.push(o[f[u]]);c.sort(B);for(var h=function(){var r=d[p],n=r.featureIndex.lookupSymbolFeatures(l[r.bucketInstanceId],e,r.bucketIndex,r.sourceLayerIndex,i.filter,i.layers,i.availableImages,t);for(var a in n){var o=s[a]=s[a]||[],c=n[a];c.sort((function(t,e){var n=r.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(e.featureIndex)-i}return e.featureIndex-t.featureIndex}));for(var u=0,f=c;u<f.length;u+=1)o.push(f[u])}},p=0,d=c;p<d.length;p+=1)h();var g=function(e){s[e].forEach((function(n){var i=n.feature,a=r[t[e].source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=a}))};for(var m in s)g(m);return s}(this._layers,this._serializedLayers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map((function(e){return t.getTileByID(e)})),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Ne(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginStateChange\",this._rtlTextPluginCallback),this._layers)this._layers[e].setEventedParent(null);for(var r in this.sourceCaches)this.sourceCaches[r].clearTiles(),this.sourceCaches[r].setEventedParent(null);this.imageManager.setEventedParent(null),this.setEventedParent(null),this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i,a){void 0===a&&(a=!1);for(var o=!1,s=!1,l={},c=0,u=this._order;c<u.length;c+=1){var f=this._layers[u[c]];if(\"symbol\"===f.type){if(!l[f.source]){var h=this.sourceCaches[f.source];l[f.source]=h.getRenderableIds(!0).map((function(t){return h.getTileByID(t)})).sort((function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)}))}var p=this.crossTileSymbolIndex.addLayer(f,l[f.source],e.center.lng);o=o||p}}if(this.crossTileSymbolIndex.pruneUnusedLayers(this._order),((a=a||this._layerOrderChanged||0===n)||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now(),e.zoom))&&(this.pauseablePlacement=new ze(e,this._order,a,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,l),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),s=!0),o&&this.pauseablePlacement.placement.setStale()),s||o)for(var d=0,g=this._order;d<g.length;d+=1){var m=this._layers[g[d]];\"symbol\"===m.type&&this.placement.updateLayerOpacities(m,l[m.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r),this._updateTilesForChangedImages();var n=this.sourceCaches[e.source];n&&n.setDependencies(e.tileID.key,e.type,e.icons)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);qe.getSourceType=function(t){return D[t]},qe.setSourceType=function(t,e){D[t]=e},qe.registerForPluginStateChange=t.registerForPluginStateChange;var He=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Ge=vr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Ye=vr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=vr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),Xe=vr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ze=vr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Je=vr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),Ke=vr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),Qe=vr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),$e=vr(\"varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;void main() {float alpha=0.5*min(v_perspective_ratio,1.0);float stroke_radius=0.9*max(v_perspective_ratio,1.0);float distance_to_center=length(v_extrude);float distance_to_edge=abs(distance_to_center-v_radius);float opacity_t=smoothstep(-stroke_radius,0.0,-distance_to_edge);vec4 color=mix(vec4(0.0,0.0,1.0,0.5),vec4(1.0,0.0,0.0,1.0),v_collision);gl_FragColor=color*alpha*opacity_t;}\",\"attribute vec2 a_pos;attribute float a_radius;attribute vec2 a_flags;uniform mat4 u_matrix;uniform mat4 u_inv_matrix;uniform vec2 u_viewport_size;uniform float u_camera_to_center_distance;varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;vec3 toTilePosition(vec2 screenPos) {vec4 rayStart=u_inv_matrix*vec4(screenPos,-1.0,1.0);vec4 rayEnd  =u_inv_matrix*vec4(screenPos, 1.0,1.0);rayStart.xyz/=rayStart.w;rayEnd.xyz  /=rayEnd.w;highp float t=(0.0-rayStart.z)/(rayEnd.z-rayStart.z);return mix(rayStart.xyz,rayEnd.xyz,t);}void main() {vec2 quadCenterPos=a_pos;float radius=a_radius;float collision=a_flags.x;float vertexIdx=a_flags.y;vec2 quadVertexOffset=vec2(mix(-1.0,1.0,float(vertexIdx >=2.0)),mix(-1.0,1.0,float(vertexIdx >=1.0 && vertexIdx <=2.0)));vec2 quadVertexExtent=quadVertexOffset*radius;vec3 tilePos=toTilePosition(quadCenterPos);vec4 clipPos=u_matrix*vec4(tilePos,1.0);highp float camera_to_anchor_distance=clipPos.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);float padding_factor=1.2;v_radius=radius;v_extrude=quadVertexExtent*padding_factor;v_perspective_ratio=collision_perspective_ratio;v_collision=collision;gl_Position=vec4(clipPos.xyz/clipPos.w,1.0)+vec4(quadVertexExtent*padding_factor/u_viewport_size*2.0,0.0,0.0);}\"),tr=vr(\"uniform highp vec4 u_color;uniform sampler2D u_overlay;varying vec2 v_uv;void main() {vec4 overlay_color=texture2D(u_overlay,v_uv);gl_FragColor=mix(u_color,overlay_color,overlay_color.a);}\",\"attribute vec2 a_pos;varying vec2 v_uv;uniform mat4 u_matrix;uniform float u_overlay_scale;void main() {v_uv=a_pos/8192.0;gl_Position=u_matrix*vec4(a_pos*u_overlay_scale,0,1);}\"),er=vr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),rr=vr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),nr=vr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),ir=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),ar=vr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),or=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec3 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),sr=vr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;uniform vec4 u_unpack;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;data.a=-1.0;return dot(data,u_unpack)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),lr=vr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),cr=vr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),ur=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),fr=vr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec3 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float aspect_a=display_size_a.y/v_width;float aspect_b=display_size_b.y/v_width;float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x*aspect_a,1.0);float x_b=mod(v_linesofar/pattern_size_b.x*aspect_b,1.0);float y=0.5*v_normal.y+0.5;vec2 texel_size=1.0/u_texsize;vec2 pos_a=mix(pattern_tl_a*texel_size-texel_size,pattern_br_a*texel_size+texel_size,vec2(x_a,y));vec2 pos_b=mix(pattern_tl_b*texel_size-texel_size,pattern_br_b*texel_size+texel_size,vec2(x_b,y));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);v_width=floorwidth;}\"),hr=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),pr=vr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),dr=vr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;vec2 a_minFontScale=a_pixeloffset.zw/256.0;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*max(a_minFontScale,fontScale)+a_pxoffset/16.0),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),gr=vr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale+a_pxoffset),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=a_tex/u_texsize;v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\"),mr=vr(\"#define SDF_PX 8.0\\n#define SDF 1.0\\n#define ICON 0.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform sampler2D u_texture_icon;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat fade_opacity=v_data1[2];if (v_data1.w==ICON) {vec2 tex_icon=v_data0.zw;lowp float alpha=opacity*fade_opacity;gl_FragColor=texture2D(u_texture_icon,tex_icon)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\nreturn;}vec2 tex=v_data0.xy;float EDGE_GAMMA=0.105/u_device_pixel_ratio;float gamma_scale=v_data1.x;float size=v_data1.y;float fontScale=size/24.0;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;uniform vec2 u_texsize_icon;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);float is_sdf=a_size[0]-2.0*a_size_min;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=size/24.0;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0.xy=a_tex/u_texsize;v_data0.zw=a_tex/u_texsize_icon;v_data1=vec4(gamma_scale,size,interpolated_fade_opacity,is_sdf);}\");function vr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,(function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})),vertexSource:e=e.replace(r,(function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}))}}var yr=Object.freeze({__proto__:null,prelude:Ge,background:Ye,backgroundPattern:We,circle:Xe,clippingMask:Ze,heatmap:Je,heatmapTexture:Ke,collisionBox:Qe,collisionCircle:$e,debug:tr,fill:er,fillOutline:rr,fillOutlinePattern:nr,fillPattern:ir,fillExtrusion:ar,fillExtrusionPattern:or,hillshadePrepare:sr,hillshade:lr,line:cr,lineGradient:ur,linePattern:fr,lineSDF:hr,raster:pr,symbolIcon:dr,symbolSDF:gr,symbolTextAndIcon:mr}),xr=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};xr.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);t.extVertexArrayObject&&this.vao&&this.boundProgram===e&&this.boundLayoutVertexBuffer===r&&!l&&this.boundIndexBuffer===i&&this.boundVertexOffset===a&&this.boundDynamicVertexBuffer===o&&this.boundDynamicVertexBuffer2===s?(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind()):this.freshBind(e,r,n,i,a,o,s)},xr.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var f=l;f<s;f++)u.disableVertexAttribArray(f)}e.enableAttributes(u,t);for(var h=0,p=r;h<p.length;h+=1)p[h].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var m=g[d];m.bind(),m.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},xr.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var br=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r?r.defines():[];i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Ge.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Ge.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var f=r?r.layoutAttributes:[],h=0;h<f.length;h++)a.bindAttribLocation(this.program,h,f[h].name);a.linkProgram(this.program),a.deleteShader(u),a.deleteShader(c),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var m=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),v=0;v<m;v++){var y=a.getActiveUniform(this.program,v);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r?r.getUniforms(t,p):[]}}};function _r(t,e,r){var n=1/he(r,1,e.transform.tileZoom),i=Math.pow(2,r.tileID.overscaledZ),a=r.tileSize*Math.pow(2,e.transform.tileZoom)/i,o=a*(r.tileID.canonical.x+r.tileID.wrap*i),s=a*r.tileID.canonical.y;return{u_image:0,u_texsize:r.imageAtlasTexture.size,u_scale:[n,t.fromScale,t.toScale],u_fade:t.t,u_pixel_coord_upper:[o>>16,s>>16],u_pixel_coord_lower:[65535&o,65535&s]}}br.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g){var m,v=t.gl;if(!this.failedToCreate){for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,f,{zoom:h});for(var x=(m={},m[v.LINES]=2,m[v.TRIANGLES]=3,m[v.LINE_STRIP]=1,m)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],T=w.vaos||(w.vaos={});(T[s]||(T[s]=new xr)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),v.drawElements(e,w.primitiveLength*x,v.UNSIGNED_SHORT,w.primitiveOffset*x*2)}}};var wr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},Tr=function(e,r,n,i,a,o,s){return t.extend(wr(e,r,n,i),_r(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},kr=function(t){return{u_matrix:t}},Mr=function(e,r,n,i){return t.extend(kr(e),_r(n,r,i))},Ar=function(t,e){return{u_matrix:t,u_world:e}},Sr=function(e,r,n,i,a){return t.extend(Mr(e,r,n,i),{u_world:a})},Er=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=he(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},Cr=function(t,e,r){var n=he(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},Lr=function(t,e,r){return{u_matrix:t,u_inv_matrix:e,u_camera_to_center_distance:r.cameraToCenterDistance,u_viewport_size:[r.width,r.height]}},Ir=function(t,e,r){return void 0===r&&(r=1),{u_matrix:t,u_color:e,u_overlay:0,u_overlay_scale:r}},Pr=function(t){return{u_matrix:t}},zr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:he(e,1,r),u_intensity:n}},Or=function(e,r,n){var i=e.transform;return{u_matrix:Nr(e,r,n),u_ratio:1/he(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Dr=function(e,r,n){return t.extend(Or(e,r,n),{u_image:0})},Rr=function(e,r,n,i){var a=e.transform,o=Br(r,a);return{u_matrix:Nr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/he(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Fr=function(e,r,n,i,a){var o=e.lineAtlas,s=Br(r,e.transform),l=\"round\"===n.layout.get(\"line-cap\"),c=o.getDash(i.from,l),u=o.getDash(i.to,l),f=c.width*a.fromScale,h=u.width*a.toScale;return t.extend(Or(e,r,n),{u_patternscale_a:[s/f,-c.height/2],u_patternscale_b:[s/h,-u.height/2],u_sdfgamma:o.width/(256*Math.min(f,h)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:c.y,u_tex_y_b:u.y,u_mix:a.t})};function Br(t,e){return 1/he(t,1,e.tileZoom)}function Nr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var jr=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:Ur(i.paint.get(\"raster-hue-rotate\"))};var a,o};function Ur(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}var Vr,qr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Hr=function(e,r,n,i,a,o,s,l,c,u,f){var h=a.transform;return t.extend(qr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(h._pitch)*h.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+f})},Gr=function(e,r,n,i,a,o,s,l,c,u){return t.extend(Hr(e,r,n,i,a,o,s,l,!0,c,!0),{u_texsize_icon:u,u_texture_icon:1})},Yr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Wr=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from.toString()),a=r.imageManager.getPattern(t.to.toString()),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,f=u*(n.tileID.canonical.x+n.tileID.wrap*c),h=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/he(n,1,r.transform.tileZoom),u_pixel_coord_upper:[f>>16,h>>16],u_pixel_coord_lower:[65535&f,65535&h]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Xr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},collisionCircle:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_inv_matrix:new t.UniformMatrix4f(e,r.u_inv_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_viewport_size:new t.Uniform2f(e,r.u_viewport_size)}},debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_overlay:new t.Uniform1i(e,r.u_overlay),u_overlay_scale:new t.Uniform1f(e,r.u_overlay_scale)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom),u_unpack:new t.Uniform4f(e,r.u_unpack)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},symbolTextAndIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texsize_icon:new t.Uniform2f(e,r.u_texsize_icon),u_texture:new t.Uniform1i(e,r.u_texture),u_texture_icon:new t.Uniform1i(e,r.u_texture_icon),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function Zr(e,r,n,i,a,o,s){for(var l=e.context,c=l.gl,u=e.useProgram(\"collisionBox\"),f=[],h=0,p=0,d=0;d<i.length;d++){var g=i[d],m=r.getTile(g),v=m.getBucket(n);if(v){var y=g.posMatrix;0===a[0]&&0===a[1]||(y=e.translatePosMatrix(g.posMatrix,m,a,o));var x=s?v.textCollisionBox:v.iconCollisionBox,b=v.collisionCircleArray;if(b.length>0){var _=t.create(),w=y;t.mul(_,v.placementInvProjMatrix,e.transform.glCoordMatrix),t.mul(_,_,v.placementViewportMatrix),f.push({circleArray:b,circleOffset:p,transform:w,invTransform:_}),p=h+=b.length/4}x&&u.draw(l,c.LINES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,Cr(y,e.transform,m),n.id,x.layoutVertexBuffer,x.indexBuffer,x.segments,null,e.transform.zoom,null,null,x.collisionVertexBuffer)}}if(s&&f.length){var T=e.useProgram(\"collisionCircle\"),k=new t.StructArrayLayout2f1f2i16;k.resize(4*h),k._trim();for(var M=0,A=0,S=f;A<S.length;A+=1)for(var E=S[A],C=0;C<E.circleArray.length/4;C++){var L=4*C,I=E.circleArray[L+0],P=E.circleArray[L+1],z=E.circleArray[L+2],O=E.circleArray[L+3];k.emplace(M++,I,P,z,O,0),k.emplace(M++,I,P,z,O,1),k.emplace(M++,I,P,z,O,2),k.emplace(M++,I,P,z,O,3)}(!Vr||Vr.length<2*h)&&(Vr=function(e){var r=2*e,n=new t.StructArrayLayout3ui6;n.resize(r),n._trim();for(var i=0;i<r;i++){var a=6*i;n.uint16[a+0]=4*i+0,n.uint16[a+1]=4*i+1,n.uint16[a+2]=4*i+2,n.uint16[a+3]=4*i+2,n.uint16[a+4]=4*i+3,n.uint16[a+5]=4*i+0}return n}(h));for(var D=l.createIndexBuffer(Vr,!0),R=l.createVertexBuffer(k,t.collisionCircleLayout.members,!0),F=0,B=f;F<B.length;F+=1){var N=B[F],j=Lr(N.transform,N.invTransform,e.transform);T.draw(l,c.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,j,n.id,R,D,t.SegmentVector.simpleSegment(0,2*N.circleOffset,N.circleArray.length,N.circleArray.length/2),null,e.transform.zoom,null,null,null)}R.destroy(),D.destroy()}}var Jr=t.identity(new Float32Array(16));function Kr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateVariableOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Qr(e,r,n,i,a,o,s,l,c,u,f){var h=e.text.placedSymbolArray,p=e.text.dynamicLayoutVertexArray,d=e.icon.dynamicLayoutVertexArray,g={};p.clear();for(var m=0;m<h.length;m++){var v=h.get(m),y=v.hidden||!v.crossTileID||e.allowVerticalPlacement&&!v.placedOrientation?null:i[v.crossTileID];if(y){var x=new t.Point(v.anchorX,v.anchorY),b=$t(x,n?l:s),_=te(o.cameraToCenterDistance,b.signedDistanceFromCamera),w=a.evaluateSizeForFeature(e.textSizeData,u,v)*_/t.ONE_EM;n&&(w*=e.tilePixelRatio/c);for(var T=Kr(y.anchor,y.width,y.height,y.textOffset,y.textBoxScale,w),k=n?$t(x.add(T),s).point:b.point.add(r?T.rotate(-o.angle):T),M=e.allowVerticalPlacement&&v.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,A=0;A<v.numGlyphs;A++)t.addDynamicAttributes(p,k,M);f&&v.associatedIconIndex>=0&&(g[v.associatedIconIndex]={shiftedAnchor:k,angle:M})}else ce(v.numGlyphs,p)}if(f){d.clear();for(var S=e.icon.placedSymbolArray,E=0;E<S.length;E++){var C=S.get(E);if(C.hidden)ce(C.numGlyphs,d);else{var L=g[E];if(L)for(var I=0;I<C.numGlyphs;I++)t.addDynamicAttributes(d,L.shiftedAnchor,L.angle);else ce(C.numGlyphs,d)}}e.icon.dynamicLayoutVertexBuffer.updateData(d)}e.text.dynamicLayoutVertexBuffer.updateData(p)}function $r(t,e,r){return r.iconsInText&&e?\"symbolTextAndIcon\":t?\"symbolSDF\":\"symbolIcon\"}function tn(e,r,n,i,a,o,s,l,c,u,f,h){for(var p=e.context,d=p.gl,g=e.transform,m=\"map\"===l,v=\"map\"===c,y=m&&\"point\"!==n.layout.get(\"symbol-placement\"),x=m&&!v&&!y,b=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),_=e.depthModeForSublayer(0,Mt.ReadOnly),w=n.layout.get(\"text-variable-anchor\"),T=[],k=0,M=i;k<M.length;k+=1){var A=M[k],S=r.getTile(A),E=S.getBucket(n);if(E){var C=a?E.text:E.icon;if(C&&C.segments.get().length){var L=C.programConfigurations.get(n.id),I=a||E.sdfIcons,P=a?E.textSizeData:E.iconSizeData,z=v||0!==g.pitch,O=e.useProgram($r(I,a,E),L),D=t.evaluateSizeForZoom(P,g.zoom),R=void 0,F=[0,0],B=void 0,N=void 0,j=null,U=void 0;if(a)B=S.glyphAtlasTexture,N=d.LINEAR,R=S.glyphAtlasTexture.size,E.iconsInText&&(F=S.imageAtlasTexture.size,j=S.imageAtlasTexture,U=z||e.options.rotating||e.options.zooming||\"composite\"===P.kind||\"camera\"===P.kind?d.LINEAR:d.NEAREST);else{var V=1!==n.layout.get(\"icon-size\").constantOr(0)||E.iconsNeedLinear;B=S.imageAtlasTexture,N=I||e.options.rotating||e.options.zooming||V||z?d.LINEAR:d.NEAREST,R=S.imageAtlasTexture.size}var q=he(S,1,e.transform.zoom),H=Kt(A.posMatrix,v,m,e.transform,q),G=Qt(A.posMatrix,v,m,e.transform,q),Y=w&&E.hasTextData(),W=\"none\"!==n.layout.get(\"icon-text-fit\")&&Y&&E.hasIconData();y&&re(E,A.posMatrix,e,a,H,G,v,u);var X=e.translatePosMatrix(A.posMatrix,S,o,s),Z=y||a&&w||W?Jr:H,J=e.translatePosMatrix(G,S,o,s,!0),K=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Q={program:O,buffers:C,uniformValues:I?E.iconsInText?Gr(P.kind,D,x,v,e,X,Z,J,R,F):Hr(P.kind,D,x,v,e,X,Z,J,a,R,!0):qr(P.kind,D,x,v,e,X,Z,J,a,R),atlasTexture:B,atlasTextureIcon:j,atlasInterpolation:N,atlasInterpolationIcon:U,isSDF:I,hasHalo:K};if(b)for(var $=0,tt=C.segments.get();$<tt.length;$+=1){var et=tt[$];T.push({segments:new t.SegmentVector([et]),sortKey:et.sortKey,state:Q})}else T.push({segments:C.segments,sortKey:0,state:Q})}}}b&&T.sort((function(t,e){return t.sortKey-e.sortKey}));for(var rt=0,nt=T;rt<nt.length;rt+=1){var it=nt[rt],at=it.state;if(p.activeTexture.set(d.TEXTURE0),at.atlasTexture.bind(at.atlasInterpolation,d.CLAMP_TO_EDGE),at.atlasTextureIcon&&(p.activeTexture.set(d.TEXTURE1),at.atlasTextureIcon&&at.atlasTextureIcon.bind(at.atlasInterpolationIcon,d.CLAMP_TO_EDGE)),at.isSDF){var ot=at.uniformValues;at.hasHalo&&(ot.u_is_halo=1,en(at.buffers,it.segments,n,e,at.program,_,f,h,ot)),ot.u_is_halo=0}en(at.buffers,it.segments,n,e,at.program,_,f,h,at.uniformValues)}}function en(t,e,r,n,i,a,o,s,l){var c=n.context;i.draw(c,c.gl.TRIANGLES,a,o,s,Et.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function rn(t,e,r,n,i,a,o){var s,l,c,u,f,h=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=h.LINES):(l=d?\"fillPattern\":\"fill\",s=h.TRIANGLES);for(var m=0,v=n;m<v.length;m+=1){var y=v[m],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(h.TEXTURE0),x.imageAtlasTexture.bind(h.LINEAR,h.CLAMP_TO_EDGE),_.updatePaintBuffers(g));var T=p.constantOr(null);if(T&&x.imageAtlas){var k=x.imageAtlas,M=k.patternPositions[T.to.toString()],A=k.patternPositions[T.from.toString()];M&&A&&_.setConstantPatternPositions(M,A)}var S=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,f=b.segments2;var E=[h.drawingBufferWidth,h.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?Sr(S,t,g,x,E):Ar(S,E)}else u=b.indexBuffer,f=b.segments,c=d?Mr(S,t,g,x):kr(S);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,Et.disabled,c,r.id,b.layoutVertexBuffer,u,f,r.paint,t.transform.zoom,_)}}}}function nn(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),f=r.getCrossfadeParameters(),h=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],m=e.getTile(g),v=m.getBucket(r);if(v){var y=v.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),m.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePaintBuffers(f));var b=c.constantOr(null);if(b&&m.imageAtlas){var _=m.imageAtlas,w=_.patternPositions[b.to.toString()],T=_.patternPositions[b.from.toString()];w&&T&&y.setConstantPatternPositions(w,T)}var k=t.translatePosMatrix(g.posMatrix,m,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),M=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?Tr(k,t,M,h,g,f,m):wr(k,t,M,h);x.draw(s,s.gl.TRIANGLES,i,a,o,Et.backCCW,A,r.id,v.layoutVertexBuffer,v.indexBuffer,v.segments,r.paint,t.transform.zoom,y)}}}function an(e,r,n,i,a,o){var s=e.context,l=s.gl,c=r.fbo;if(c){var u=e.useProgram(\"hillshade\");s.activeTexture.set(l.TEXTURE0),l.bindTexture(l.TEXTURE_2D,c.colorAttachment.get());var f=function(e,r,n){var i=n.paint.get(\"hillshade-shadow-color\"),a=n.paint.get(\"hillshade-highlight-color\"),o=n.paint.get(\"hillshade-accent-color\"),s=n.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===n.paint.get(\"hillshade-illumination-anchor\")&&(s-=e.transform.angle);var l,c,u,f=!e.options.moving;return{u_matrix:e.transform.calculatePosMatrix(r.tileID.toUnwrapped(),f),u_image:0,u_latrange:(l=r.tileID,c=Math.pow(2,l.canonical.z),u=l.canonical.y,[new t.MercatorCoordinate(0,u/c).toLngLat().lat,new t.MercatorCoordinate(0,(u+1)/c).toLngLat().lat]),u_light:[n.paint.get(\"hillshade-exaggeration\"),s],u_shadow:i,u_highlight:a,u_accent:o}}(e,r,n);u.draw(s,l.TRIANGLES,i,a,o,Et.disabled,f,n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments)}}function on(e,r,n,i,a,o,s){var l=e.context,c=l.gl,u=r.dem;if(u&&u.data){var f=u.dim,h=u.stride,p=u.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var d=r.demTexture;d.update(p,{premultiply:!1}),d.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,p,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var g=r.fbo;if(!g){var m=new t.Texture(l,{width:f,height:f,data:null},c.RGBA);m.bind(c.LINEAR,c.CLAMP_TO_EDGE),(g=r.fbo=l.createFramebuffer(f,f,!0)).colorAttachment.set(m.texture)}l.bindFramebuffer.set(g.framebuffer),l.viewport.set([0,0,f,f]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,Et.disabled,function(e,r,n){var i=r.stride,a=t.create();return t.ortho(a,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(a,a,[0,-t.EXTENT,0]),{u_matrix:a,u_image:1,u_dimension:[i,i],u_zoom:e.overscaledZ,u_maxzoom:n,u_unpack:r.getUnpackVector()}}(r.tileID,u,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function sn(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),f=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),h=!r||Math.abs(r.tileID.overscaledZ-f)>Math.abs(e.tileID.overscaledZ-f),p=h&&e.refreshedUponExpiration?1:t.clamp(h?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}var ln=new t.Color(1,0,0,1),cn=new t.Color(0,1,0,1),un=new t.Color(0,0,1,1),fn=new t.Color(1,0,1,1),hn=new t.Color(0,1,1,1);function pn(t,e,r,n){gn(t,0,e+r/2,t.transform.width,r,n)}function dn(t,e,r,n){gn(t,e-r/2,0,r,t.transform.height,n)}function gn(e,r,n,i,a,o){var s=e.context,l=s.gl;l.enable(l.SCISSOR_TEST),l.scissor(r*t.browser.devicePixelRatio,n*t.browser.devicePixelRatio,i*t.browser.devicePixelRatio,a*t.browser.devicePixelRatio),s.clear({color:o}),l.disable(l.SCISSOR_TEST)}function mn(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Mt.disabled,c=At.disabled,u=e.colorModeForRenderPass();i.activeTexture.set(a.TEXTURE0),e.emptyTexture.bind(a.LINEAR,a.CLAMP_TO_EDGE),s.draw(i,a.LINE_STRIP,l,c,u,Et.disabled,Ir(o,t.Color.red),\"$debug\",e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);var f=r.getTileByID(n.key).latestRawTileData,h=Math.floor((f&&f.byteLength||0)/1024),p=r.getTile(n).tileSize,d=512/Math.min(p,512)*(n.overscaledZ/e.transform.zoom)*.5,g=n.canonical.toString();n.overscaledZ!==n.canonical.z&&(g+=\" => \"+n.overscaledZ),function(t,e){t.initDebugOverlayCanvas();var r=t.debugOverlayCanvas,n=t.context.gl,i=t.debugOverlayCanvas.getContext(\"2d\");i.clearRect(0,0,r.width,r.height),i.shadowColor=\"white\",i.shadowBlur=2,i.lineWidth=1.5,i.strokeStyle=\"white\",i.textBaseline=\"top\",i.font=\"bold 36px Open Sans, sans-serif\",i.fillText(e,5,5),i.strokeText(e,5,5),t.debugOverlayTexture.update(r),t.debugOverlayTexture.bind(n.LINEAR,n.CLAMP_TO_EDGE)}(e,g+\" \"+h+\"kb\"),s.draw(i,a.TRIANGLES,l,c,St.alphaBlended,Et.disabled,Ir(o,t.Color.transparent,d),\"$debug\",e.debugBuffer,e.quadTriangleIndexBuffer,e.debugSegments)}var vn={symbol:function(e,r,n,i,a){if(\"translucent\"===e.renderPass){var o=At.disabled,s=e.colorModeForRenderPass();n.layout.get(\"text-variable-anchor\")&&function(e,r,n,i,a,o,s){for(var l=r.transform,c=\"map\"===a,u=\"map\"===o,f=0,h=e;f<h.length;f+=1){var p=h[f],d=i.getTile(p),g=d.getBucket(n);if(g&&g.text&&g.text.segments.get().length){var m=t.evaluateSizeForZoom(g.textSizeData,l.zoom),v=he(d,1,r.transform.zoom),y=Kt(p.posMatrix,u,c,r.transform,v),x=\"none\"!==n.layout.get(\"icon-text-fit\")&&g.hasIconData();if(m){var b=Math.pow(2,l.zoom-d.tileID.overscaledZ);Qr(g,c,u,s,t.symbolSize,l,y,p.posMatrix,b,m,x)}}}}(i,e,n,r,n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),a),0!==n.paint.get(\"icon-opacity\").constantOr(1)&&tn(e,r,n,i,!1,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),n.layout.get(\"icon-rotation-alignment\"),n.layout.get(\"icon-pitch-alignment\"),n.layout.get(\"icon-keep-upright\"),o,s),0!==n.paint.get(\"text-opacity\").constantOr(1)&&tn(e,r,n,i,!0,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),n.layout.get(\"text-keep-upright\"),o,s),r.map.showCollisionBoxes&&(Zr(e,r,n,i,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),!0),Zr(e,r,n,i,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),!1))}},circle:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"circle-opacity\"),o=n.paint.get(\"circle-stroke-width\"),s=n.paint.get(\"circle-stroke-opacity\"),l=void 0!==n.layout.get(\"circle-sort-key\").constantOr(1);if(0!==a.constantOr(1)||0!==o.constantOr(1)&&0!==s.constantOr(1)){for(var c=e.context,u=c.gl,f=e.depthModeForSublayer(0,Mt.ReadOnly),h=At.disabled,p=e.colorModeForRenderPass(),d=[],g=0;g<i.length;g++){var m=i[g],v=r.getTile(m),y=v.getBucket(n);if(y){var x=y.programConfigurations.get(n.id),b={programConfiguration:x,program:e.useProgram(\"circle\",x),layoutVertexBuffer:y.layoutVertexBuffer,indexBuffer:y.indexBuffer,uniformValues:Er(e,m,v,n)};if(l)for(var _=0,w=y.segments.get();_<w.length;_+=1){var T=w[_];d.push({segments:new t.SegmentVector([T]),sortKey:T.sortKey,state:b})}else d.push({segments:y.segments,sortKey:0,state:b})}}l&&d.sort((function(t,e){return t.sortKey-e.sortKey}));for(var k=0,M=d;k<M.length;k+=1){var A=M[k],S=A.state;S.program.draw(c,u.TRIANGLES,f,h,p,Et.disabled,S.uniformValues,n.id,S.layoutVertexBuffer,S.indexBuffer,A.segments,n.paint,e.transform.zoom,S.programConfiguration)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=At.disabled,l=new St([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4,!1),function(t,e,r,n){var i=t.gl;i.texImage2D(i.TEXTURE_2D,0,i.RGBA,e.width/4,e.height/4,0,i.RGBA,t.extRenderToTextureHalfFloat?t.extTextureHalfFloat.HALF_FLOAT_OES:i.UNSIGNED_BYTE,null),n.colorAttachment.set(r)}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var c=0;c<i.length;c++){var u=i[c];if(!r.hasRenderableParent(u)){var f=r.getTile(u),h=f.getBucket(n);if(h){var p=h.programConfigurations.get(n.id);e.useProgram(\"heatmap\",p).draw(a,o.TRIANGLES,Mt.disabled,s,l,Et.disabled,zr(u.posMatrix,f,e.transform.zoom,n.paint.get(\"heatmap-intensity\")),n.id,h.layoutVertexBuffer,h.indexBuffer,h.segments,n.paint,e.transform.zoom,p)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:0,u_color_ramp:1,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Mt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),f=u.constantOr(1),h=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=f?\"linePattern\":c?\"lineSDF\":h?\"lineGradient\":\"line\",g=e.context,m=g.gl,v=!0;if(h){g.activeTexture.set(m.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,m.RGBA)),y.bind(m.LINEAR,m.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!f||w.patternsLoaded()){var T=w.getBucket(n);if(T){var k=T.programConfigurations.get(n.id),M=e.context.program.get(),A=e.useProgram(d,k),S=v||A.program!==M,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas,L=C.patternPositions[E.to.toString()],I=C.patternPositions[E.from.toString()];L&&I&&k.setConstantPatternPositions(L,I)}var P=f?Rr(e,w,n,p):c?Fr(e,w,n,c,p):h?Dr(e,w,n):Or(e,w,n);f?(g.activeTexture.set(m.TEXTURE0),w.imageAtlasTexture.bind(m.LINEAR,m.CLAMP_TO_EDGE),k.updatePaintBuffers(p)):c&&(S||e.lineAtlas.dirty)&&(g.activeTexture.set(m.TEXTURE0),e.lineAtlas.bind(g)),A.draw(g,m.TRIANGLES,s,e.stencilModeForClipping(_),l,Et.disabled,P,n.id,T.layoutVertexBuffer,T.indexBuffer,T.segments,n.paint,e.transform.zoom,k),v=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Mt.ReadWrite:Mt.ReadOnly);rn(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var f=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Mt.ReadOnly);rn(e,r,n,i,f,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))nn(t,e,r,n,a,At.disabled,St.disabled),nn(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();nn(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Mt.ReadOnly),s=t.colorModeForRenderPass(),l=\"translucent\"===t.renderPass?t.stencilConfigForOverlap(n):[{},n],c=l[0],u=0,f=l[1];u<f.length;u+=1){var h=f[u],p=e.getTile(h);p.needsHillshadePrepare&&\"offscreen\"===t.renderPass?on(t,p,r,a,o,At.disabled,s):\"translucent\"===t.renderPass&&an(t,p,r,o,c[h.overscaledZ],s)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\")&&n.length)for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=t.colorModeForRenderPass(),c=o instanceof P?[{},n]:t.stencilConfigForOverlap(n),u=c[0],f=c[1],h=f[f.length-1].overscaledZ,p=!t.options.moving,d=0,g=f;d<g.length;d+=1){var m=g[d],v=t.depthModeForSublayer(m.overscaledZ-h,1===r.paint.get(\"raster-opacity\")?Mt.ReadWrite:Mt.ReadOnly,a.LESS),y=e.getTile(m),x=t.transform.calculatePosMatrix(m.toUnwrapped(),p);y.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var b=e.findLoadedParent(m,0),_=sn(y,b,e,r,t.transform),w=void 0,T=void 0,k=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),b?(b.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),w=Math.pow(2,b.tileID.overscaledZ-y.tileID.overscaledZ),T=[y.tileID.canonical.x*w%1,y.tileID.canonical.y*w%1]):y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var M=jr(x,T||[0,0],w||1,_,r);o instanceof P?s.draw(i,a.TRIANGLES,v,At.disabled,l,Et.disabled,M,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):s.draw(i,a.TRIANGLES,v,u[m.overscaledZ],l,Et.disabled,M,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=!c&&1===n.a&&1===i&&t.opaquePassEnabledForLayer()?\"opaque\":\"translucent\";if(t.renderPass===u){var f=At.disabled,h=t.depthModeForSublayer(0,\"opaque\"===u?Mt.ReadWrite:Mt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var m=r.getCrossfadeParameters(),v=0,y=g;v<y.length;v+=1){var x=y[v],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Wr(b,i,t,c,{tileID:x,tileSize:l},m):Yr(b,i,n);d.draw(a,o.TRIANGLES,h,f,p,Et.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)mn(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Mt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},yn=function(t,e){this.context=new Ct(t),this.transform=e,this._tileTextures={},this.setup(),this.numSublayers=Lt.maxUnderzooming+Lt.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.crossTileSymbolIndex=new Be,this.gpuTimers={}};yn.prototype.resize=function(e,r){if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var n=0,i=this.style._order;n<i.length;n+=1)this.style._layers[i[n]].resize()},yn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,He.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,He.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,I.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,He.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s),this.emptyTexture=new t.Texture(e,{width:1,height:1,data:new Uint8Array([0,0,0,0])},e.gl.RGBA);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},yn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Mt.disabled,this.stencilClearMode,St.disabled,Et.disabled,Pr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},yn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(St.disabled),r.setDepthMode(Mt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Mt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),St.disabled,Et.disabled,Pr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},yn.prototype.stencilModeFor3D=function(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilConfigForOverlap=function(t){var e,r=this.context.gl,n=t.sort((function(t,e){return e.overscaledZ-t.overscaledZ})),i=n[n.length-1].overscaledZ,a=n[0].overscaledZ-i+1;if(a>1){this.currentStencilSource=void 0,this.nextStencilID+a>256&&this.clearStencil();for(var o={},s=0;s<a;s++)o[s+i]=new At({func:r.GEQUAL,mask:255},s+this.nextStencilID,255,r.KEEP,r.KEEP,r.REPLACE);return this.nextStencilID+=a,[o,n]}return[(e={},e[i]=At.disabled,e),n]},yn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new St([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?St.unblended:St.alphaBlended},yn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Mt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Mt(r||this.context.gl.LEQUAL,e,[n,n])},yn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},yn.prototype.render=function(e,r){var n=this;this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var i=this.style._order,a=this.style.sourceCaches;for(var o in a){var s=a[o];s.used&&s.prepare(this.context)}var l,c,u={},f={},h={};for(var p in a){var d=a[p];u[p]=d.getVisibleCoordinates(),f[p]=u[p].slice().reverse(),h[p]=d.getVisibleCoordinates(!0).reverse()}this.opaquePassCutoff=1/0;for(var g=0;g<i.length;g++)if(this.style._layers[i[g]].is3D()){this.opaquePassCutoff=g;break}this.renderPass=\"offscreen\";for(var m=0,v=i;m<v.length;m+=1){var y=this.style._layers[v[m]];if(y.hasOffscreenPass()&&!y.isHidden(this.transform.zoom)){var x=f[y.source];(\"custom\"===y.type||x.length)&&this.renderLayer(this,a[y.source],y,x)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=i.length-1;this.currentLayer>=0;this.currentLayer--){var b=this.style._layers[i[this.currentLayer]],_=a[b.source],w=u[b.source];this._renderTileClippingMasks(b,w),this.renderLayer(this,_,b,w)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<i.length;this.currentLayer++){var T=this.style._layers[i[this.currentLayer]],k=a[T.source],M=(\"symbol\"===T.type?h:f)[T.source];this._renderTileClippingMasks(T,u[T.source]),this.renderLayer(this,k,T,M)}this.options.showTileBoundaries&&(t.values(this.style._layers).forEach((function(t){t.source&&!t.isHidden(n.transform.zoom)&&(t.source!==(c&&c.id)&&(c=n.style.sourceCaches[t.source]),(!l||l.getSource().maxzoom<c.getSource().maxzoom)&&(l=c))})),l&&vn.debug(this,l,l.getVisibleCoordinates())),this.options.showPadding&&function(t){var e=t.transform.padding;pn(t,t.transform.height-(e.top||0),3,ln),pn(t,e.bottom||0,3,cn),dn(t,e.left||0,3,un),dn(t,t.transform.width-(e.right||0),3,fn);var r=t.transform.centerPoint;!function(t,e,r,n){gn(t,e-1,r-10,2,20,n),gn(t,e-10,r-1,20,2,n)}(t,r.x,t.transform.height-r.y,hn)}(this),this.context.setDefault()},yn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,this.gpuTimingStart(r),vn[r.type](t,e,r,n,this.style.placement.variableOffsets),this.gpuTimingEnd())},yn.prototype.gpuTimingStart=function(t){if(this.options.gpuTiming){var e=this.context.extTimerQuery,r=this.gpuTimers[t.id];r||(r=this.gpuTimers[t.id]={calls:0,cpuTime:0,query:e.createQueryEXT()}),r.calls++,e.beginQueryEXT(e.TIME_ELAPSED_EXT,r.query)}},yn.prototype.gpuTimingEnd=function(){if(this.options.gpuTiming){var t=this.context.extTimerQuery;t.endQueryEXT(t.TIME_ELAPSED_EXT)}},yn.prototype.collectGpuTimers=function(){var t=this.gpuTimers;return this.gpuTimers={},t},yn.prototype.queryGpuTimers=function(t){var e={};for(var r in t){var n=t[r],i=this.context.extTimerQuery,a=i.getQueryObjectEXT(n.query,i.QUERY_RESULT_EXT)/1e6;i.deleteQueryEXT(n.query),e[r]=a}return e},yn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:he(r,n[0],this.transform.zoom),a?n[1]:he(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},yn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},yn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},yn.prototype.isPatternMissing=function(t){if(!t)return!1;if(!t.from||!t.to)return!0;var e=this.imageManager.getPattern(t.from.toString()),r=this.imageManager.getPattern(t.to.toString());return!e||!r},yn.prototype.useProgram=function(t,e){this.cache=this.cache||{};var r=\"\"+t+(e?e.cacheKey:\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new br(this.context,yr[t],e,Xr[t],this._showOverdrawInspector)),this.cache[r]},yn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},yn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)},yn.prototype.initDebugOverlayCanvas=function(){null==this.debugOverlayCanvas&&(this.debugOverlayCanvas=t.window.document.createElement(\"canvas\"),this.debugOverlayCanvas.width=512,this.debugOverlayCanvas.height=512,this.debugOverlayTexture=new t.Texture(this.context,this.debugOverlayCanvas,this.context.gl.RGBA))},yn.prototype.destroy=function(){this.emptyTexture.destroy(),this.debugOverlayTexture&&this.debugOverlayTexture.destroy()};var xn=function(t,e){this.points=t,this.planes=e};xn.fromInvProjectionMatrix=function(e,r,n){var i=Math.pow(2,n),a=[[-1,1,-1,1],[1,1,-1,1],[1,-1,-1,1],[-1,-1,-1,1],[-1,1,1,1],[1,1,1,1],[1,-1,1,1],[-1,-1,1,1]].map((function(r){return t.transformMat4([],r,e)})).map((function(e){return t.scale$1([],e,1/e[3]/r*i)})),o=[[0,1,2],[6,5,4],[0,3,7],[2,1,5],[3,2,6],[0,4,5]].map((function(e){var r=t.sub([],a[e[0]],a[e[1]]),n=t.sub([],a[e[2]],a[e[1]]),i=t.normalize([],t.cross([],r,n)),o=-t.dot(i,a[e[1]]);return i.concat(o)}));return new xn(a,o)};var bn=function(e,r){this.min=e,this.max=r,this.center=t.scale$2([],t.add([],this.min,this.max),.5)};bn.prototype.quadrant=function(e){for(var r=[e%2==0,e<2],n=t.clone$2(this.min),i=t.clone$2(this.max),a=0;a<r.length;a++)n[a]=r[a]?this.min[a]:this.center[a],i[a]=r[a]?this.center[a]:this.max[a];return i[2]=this.max[2],new bn(n,i)},bn.prototype.distanceX=function(t){return Math.max(Math.min(this.max[0],t[0]),this.min[0])-t[0]},bn.prototype.distanceY=function(t){return Math.max(Math.min(this.max[1],t[1]),this.min[1])-t[1]},bn.prototype.intersects=function(e){for(var r=[[this.min[0],this.min[1],0,1],[this.max[0],this.min[1],0,1],[this.max[0],this.max[1],0,1],[this.min[0],this.max[1],0,1]],n=!0,i=0;i<e.planes.length;i++){for(var a=e.planes[i],o=0,s=0;s<r.length;s++)o+=t.dot$1(a,r[s])>=0;if(0===o)return 0;o!==r.length&&(n=!1)}if(n)return 2;for(var l=0;l<3;l++){for(var c=Number.MAX_VALUE,u=-Number.MAX_VALUE,f=0;f<e.points.length;f++){var h=e.points[f][l]-this.min[l];c=Math.min(c,h),u=Math.max(u,h)}if(u<0||c>this.max[l]-this.min[l])return 0}return 1};var _n=function(t,e,r,n){if(void 0===t&&(t=0),void 0===e&&(e=0),void 0===r&&(r=0),void 0===n&&(n=0),isNaN(t)||t<0||isNaN(e)||e<0||isNaN(r)||r<0||isNaN(n)||n<0)throw new Error(\"Invalid value for edge-insets, top, bottom, left and right must all be numbers\");this.top=t,this.bottom=e,this.left=r,this.right=n};_n.prototype.interpolate=function(e,r,n){return null!=r.top&&null!=e.top&&(this.top=t.number(e.top,r.top,n)),null!=r.bottom&&null!=e.bottom&&(this.bottom=t.number(e.bottom,r.bottom,n)),null!=r.left&&null!=e.left&&(this.left=t.number(e.left,r.left,n)),null!=r.right&&null!=e.right&&(this.right=t.number(e.right,r.right,n)),this},_n.prototype.getCenter=function(e,r){var n=t.clamp((this.left+e-this.right)/2,0,e),i=t.clamp((this.top+r-this.bottom)/2,0,r);return new t.Point(n,i)},_n.prototype.equals=function(t){return this.top===t.top&&this.bottom===t.bottom&&this.left===t.left&&this.right===t.right},_n.prototype.clone=function(){return new _n(this.top,this.bottom,this.left,this.right)},_n.prototype.toJSON=function(){return{top:this.top,bottom:this.bottom,left:this.left,right:this.right}};var wn=function(e,r,n,i,a){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===a||a,this._minZoom=e||0,this._maxZoom=r||22,this._minPitch=null==n?0:n,this._maxPitch=null==i?60:i,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._edgeInsets=new _n,this._posMatrixCache={},this._alignedPosMatrixCache={}},Tn={minZoom:{configurable:!0},maxZoom:{configurable:!0},minPitch:{configurable:!0},maxPitch:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerOffset:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},padding:{configurable:!0},centerPoint:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};wn.prototype.clone=function(){var t=new wn(this._minZoom,this._maxZoom,this._minPitch,this.maxPitch,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._edgeInsets=this._edgeInsets.clone(),t._calcMatrices(),t},Tn.minZoom.get=function(){return this._minZoom},Tn.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},Tn.maxZoom.get=function(){return this._maxZoom},Tn.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},Tn.minPitch.get=function(){return this._minPitch},Tn.minPitch.set=function(t){this._minPitch!==t&&(this._minPitch=t,this.pitch=Math.max(this.pitch,t))},Tn.maxPitch.get=function(){return this._maxPitch},Tn.maxPitch.set=function(t){this._maxPitch!==t&&(this._maxPitch=t,this.pitch=Math.min(this.pitch,t))},Tn.renderWorldCopies.get=function(){return this._renderWorldCopies},Tn.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},Tn.worldSize.get=function(){return this.tileSize*this.scale},Tn.centerOffset.get=function(){return this.centerPoint._sub(this.size._div(2))},Tn.size.get=function(){return new t.Point(this.width,this.height)},Tn.bearing.get=function(){return-this.angle/Math.PI*180},Tn.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},Tn.pitch.get=function(){return this._pitch/Math.PI*180},Tn.pitch.set=function(e){var r=t.clamp(e,this.minPitch,this.maxPitch)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},Tn.fov.get=function(){return this._fov/Math.PI*180},Tn.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},Tn.zoom.get=function(){return this._zoom},Tn.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},Tn.center.get=function(){return this._center},Tn.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},Tn.padding.get=function(){return this._edgeInsets.toJSON()},Tn.padding.set=function(t){this._edgeInsets.equals(t)||(this._unmodified=!1,this._edgeInsets.interpolate(this._edgeInsets,t,1),this._calcMatrices())},Tn.centerPoint.get=function(){return this._edgeInsets.getCenter(this.width,this.height)},wn.prototype.isPaddingEqual=function(t){return this._edgeInsets.equals(t)},wn.prototype.interpolatePadding=function(t,e,r){this._unmodified=!1,this._edgeInsets.interpolate(t,e,r),this._constrain(),this._calcMatrices()},wn.prototype.coveringZoomLevel=function(t){var e=(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize));return Math.max(0,e)},wn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},wn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=[a*i.x,a*i.y,0],s=xn.fromInvProjectionMatrix(this.invProjMatrix,this.worldSize,r),l=e.minzoom||0;this.pitch<=60&&this._edgeInsets.top<.1&&(l=r);var c=function(t){return{aabb:new bn([t*a,0,0],[(t+1)*a,a,0]),zoom:0,x:0,y:0,wrap:t,fullyVisible:!1}},u=[],f=[],h=r,p=e.reparseOverscaled?n:r;if(this._renderWorldCopies)for(var d=1;d<=3;d++)u.push(c(-d)),u.push(c(d));for(u.push(c(0));u.length>0;){var g=u.pop(),m=g.x,v=g.y,y=g.fullyVisible;if(!y){var x=g.aabb.intersects(s);if(0===x)continue;y=2===x}var b=g.aabb.distanceX(o),_=g.aabb.distanceY(o),w=Math.max(Math.abs(b),Math.abs(_));if(g.zoom===h||w>3+(1<<h-g.zoom)-2&&g.zoom>=l)f.push({tileID:new t.OverscaledTileID(g.zoom===h?p:g.zoom,g.wrap,g.zoom,m,v),distanceSq:t.sqrLen([o[0]-.5-m,o[1]-.5-v])});else for(var T=0;T<4;T++){var k=(m<<1)+T%2,M=(v<<1)+(T>>1);u.push({aabb:g.aabb.quadrant(T),zoom:g.zoom+1,x:k,y:M,wrap:g.wrap,fullyVisible:y})}}return f.sort((function(t,e){return t.distanceSq-e.distanceSq})).map((function(t){return t.tileID}))},wn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},Tn.unmodified.get=function(){return this._unmodified},wn.prototype.zoomScale=function(t){return Math.pow(2,t)},wn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},wn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},wn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},Tn.point.get=function(){return this.project(this.center)},wn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},wn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},wn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},wn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},wn.prototype.coordinateLocation=function(t){return t.toLngLat()},wn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[1]/i,s=n[1]/a,l=r[2]/i,c=n[2]/a,u=l===c?0:(0-l)/(c-l);return new t.MercatorCoordinate(t.number(r[0]/i,n[0]/a,u)/this.worldSize,t.number(o,s,u)/this.worldSize)},wn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},wn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},wn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},wn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},wn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},wn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},wn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var f=this.latRange;a=t.mercatorYfromLat(f[1])*this.worldSize,e=(o=t.mercatorYfromLat(f[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var h=this.lngRange;s=t.mercatorXfromLng(h[0])*this.worldSize,r=(l=t.mercatorXfromLng(h[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,m=c.y/2;g-m<a&&(i=a+m),g+m>o&&(i=o-m)}if(this.lngRange){var v=p.x,y=c.x/2;v-y<s&&(n=s+y),v+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},wn.prototype._calcMatrices=function(){if(this.height){var e=this.centerOffset;this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var r=Math.PI/2+this._pitch,n=this._fov*(.5+e.y/this.height),i=Math.sin(n)*this.cameraToCenterDistance/Math.sin(t.clamp(Math.PI-r-n,.01,Math.PI-.01)),a=this.point,o=a.x,s=a.y,l=1.01*(Math.cos(Math.PI/2-this._pitch)*i+this.cameraToCenterDistance),c=this.height/50,u=new Float64Array(16);t.perspective(u,this._fov,this.width/this.height,c,l),u[8]=2*-e.x/this.width,u[9]=2*e.y/this.height,t.scale(u,u,[1,-1,1]),t.translate(u,u,[0,0,-this.cameraToCenterDistance]),t.rotateX(u,u,this._pitch),t.rotateZ(u,u,this.angle),t.translate(u,u,[-o,-s,0]),this.mercatorMatrix=t.scale([],u,[this.worldSize,this.worldSize,this.worldSize]),t.scale(u,u,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=u,this.invProjMatrix=t.invert([],this.projMatrix);var f=this.width%2/2,h=this.height%2/2,p=Math.cos(this.angle),d=Math.sin(this.angle),g=o-Math.round(o)+p*f+d*h,m=s-Math.round(s)+p*h+d*f,v=new Float64Array(u);if(t.translate(v,v,[g>.5?g-1:g,m>.5?m-1:m,0]),this.alignedProjMatrix=v,u=t.create(),t.scale(u,u,[this.width/2,-this.height/2,1]),t.translate(u,u,[1,-1,0]),this.labelPlaneMatrix=u,u=t.create(),t.scale(u,u,[1,-1,1]),t.translate(u,u,[-1,-1,0]),t.scale(u,u,[2/this.width,2/this.height,1]),this.glCoordMatrix=u,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(u=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=u,this._posMatrixCache={},this._alignedPosMatrixCache={}}},wn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},wn.prototype.getCameraPoint=function(){var e=Math.tan(this._pitch)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,e))},wn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(wn.prototype,Tn);var kn=function(e){var r,n,i,a;this._hashName=e&&encodeURIComponent(e),t.bindAll([\"_getCurrentHash\",\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(r=this._updateHashUnthrottled.bind(this),n=!1,i=null,a=function(){i=null,n&&(r(),i=setTimeout(a,300),n=!1)},function(){return n=!0,i||a(),i})};kn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},kn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},kn.prototype.getHashString=function(e){var r=this._map.getCenter(),n=Math.round(100*this._map.getZoom())/100,i=Math.ceil((n*Math.LN2+Math.log(512/360/.5))/Math.LN10),a=Math.pow(10,i),o=Math.round(r.lng*a)/a,s=Math.round(r.lat*a)/a,l=this._map.getBearing(),c=this._map.getPitch(),u=\"\";if(u+=e?\"/\"+o+\"/\"+s+\"/\"+n:n+\"/\"+s+\"/\"+o,(l||c)&&(u+=\"/\"+Math.round(10*l)/10),c&&(u+=\"/\"+Math.round(c)),this._hashName){var f=this._hashName,h=!1,p=t.window.location.hash.slice(1).split(\"&\").map((function(t){var e=t.split(\"=\")[0];return e===f?(h=!0,e+\"=\"+u):t})).filter((function(t){return t}));return h||p.push(f+\"=\"+u),\"#\"+p.join(\"&\")}return\"#\"+u},kn.prototype._getCurrentHash=function(){var e,r=this,n=t.window.location.hash.replace(\"#\",\"\");return this._hashName?(n.split(\"&\").map((function(t){return t.split(\"=\")})).forEach((function(t){t[0]===r._hashName&&(e=t)})),(e&&e[1]||\"\").split(\"/\")):n.split(\"/\")},kn.prototype._onHashChange=function(){var t=this._getCurrentHash();if(t.length>=3&&!t.some((function(t){return isNaN(t)}))){var e=this._map.dragRotate.isEnabled()&&this._map.touchZoomRotate.isEnabled()?+(t[3]||0):this._map.getBearing();return this._map.jumpTo({center:[+t[2],+t[1]],zoom:+t[0],bearing:e,pitch:+(t[4]||0)}),!0}return!1},kn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var Mn={linearity:.3,easing:t.bezier(0,0,.3,1)},An=t.extend({deceleration:2500,maxSpeed:1400},Mn),Sn=t.extend({deceleration:20,maxSpeed:1400},Mn),En=t.extend({deceleration:1e3,maxSpeed:360},Mn),Cn=t.extend({deceleration:1e3,maxSpeed:90},Mn),Ln=function(t){this._map=t,this.clear()};function In(t,e){(!t.duration||t.duration<e.duration)&&(t.duration=e.duration,t.easing=e.easing)}function Pn(e,r,n){var i=n.maxSpeed,a=n.linearity,o=n.deceleration,s=t.clamp(e*a/(r/1e3),-i,i),l=Math.abs(s)/(o*a);return{easing:n.easing,duration:1e3*l,amount:s*(l/2)}}Ln.prototype.clear=function(){this._inertiaBuffer=[]},Ln.prototype.record=function(e){this._drainInertiaBuffer(),this._inertiaBuffer.push({time:t.browser.now(),settings:e})},Ln.prototype._drainInertiaBuffer=function(){for(var e=this._inertiaBuffer,r=t.browser.now();e.length>0&&r-e[0].time>160;)e.shift()},Ln.prototype._onMoveEnd=function(e){if(this._drainInertiaBuffer(),!(this._inertiaBuffer.length<2)){for(var r={zoom:0,bearing:0,pitch:0,pan:new t.Point(0,0),pinchAround:void 0,around:void 0},n=0,i=this._inertiaBuffer;n<i.length;n+=1){var a=i[n].settings;r.zoom+=a.zoomDelta||0,r.bearing+=a.bearingDelta||0,r.pitch+=a.pitchDelta||0,a.panDelta&&r.pan._add(a.panDelta),a.around&&(r.around=a.around),a.pinchAround&&(r.pinchAround=a.pinchAround)}var o=this._inertiaBuffer[this._inertiaBuffer.length-1].time-this._inertiaBuffer[0].time,s={};if(r.pan.mag()){var l=Pn(r.pan.mag(),o,t.extend({},An,e||{}));s.offset=r.pan.mult(l.amount/r.pan.mag()),s.center=this._map.transform.center,In(s,l)}if(r.zoom){var c=Pn(r.zoom,o,Sn);s.zoom=this._map.transform.zoom+c.amount,In(s,c)}if(r.bearing){var u=Pn(r.bearing,o,En);s.bearing=this._map.transform.bearing+t.clamp(u.amount,-179,179),In(s,u)}if(r.pitch){var f=Pn(r.pitch,o,Cn);s.pitch=this._map.transform.pitch+f.amount,In(s,f)}if(s.zoom||s.bearing){var h=void 0===r.pinchAround?r.around:r.pinchAround;s.around=h?this._map.unproject(h):this._map.getCenter()}return this.clear(),t.extend(s,{noMoveStart:!0})}};var zn=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),On=function(e){function n(n,i,a){var o=\"touchend\"===n?a.changedTouches:a.touches,s=r.touchPos(i.getCanvasContainer(),o),l=s.map((function(t){return i.unproject(t)})),c=s.reduce((function(t,e,r,n){return t.add(e.div(n.length))}),new t.Point(0,0)),u=i.unproject(c);e.call(this,n,{points:s,point:c,lngLats:l,lngLat:u,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),Dn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),Rn=function(t,e){this._map=t,this._clickTolerance=e.clickTolerance};Rn.prototype.reset=function(){delete this._mousedownPos},Rn.prototype.wheel=function(t){return this._firePreventable(new Dn(t.type,this._map,t))},Rn.prototype.mousedown=function(t,e){return this._mousedownPos=e,this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseup=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.click=function(t,e){this._mousedownPos&&this._mousedownPos.dist(e)>=this._clickTolerance||this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.dblclick=function(t){return this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseover=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.mouseout=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.touchstart=function(t){return this._firePreventable(new On(t.type,this._map,t))},Rn.prototype.touchmove=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchend=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchcancel=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype._firePreventable=function(t){if(this._map.fire(t),t.defaultPrevented)return{}},Rn.prototype.isEnabled=function(){return!0},Rn.prototype.isActive=function(){return!1},Rn.prototype.enable=function(){},Rn.prototype.disable=function(){};var Fn=function(t){this._map=t};Fn.prototype.reset=function(){this._delayContextMenu=!1,delete this._contextMenuEvent},Fn.prototype.mousemove=function(t){this._map.fire(new zn(t.type,this._map,t))},Fn.prototype.mousedown=function(){this._delayContextMenu=!0},Fn.prototype.mouseup=function(){this._delayContextMenu=!1,this._contextMenuEvent&&(this._map.fire(new zn(\"contextmenu\",this._map,this._contextMenuEvent)),delete this._contextMenuEvent)},Fn.prototype.contextmenu=function(t){this._delayContextMenu?this._contextMenuEvent=t:this._map.fire(new zn(t.type,this._map,t)),this._map.listens(\"contextmenu\")&&t.preventDefault()},Fn.prototype.isEnabled=function(){return!0},Fn.prototype.isActive=function(){return!1},Fn.prototype.enable=function(){},Fn.prototype.disable=function(){};var Bn=function(t,e){this._map=t,this._el=t.getCanvasContainer(),this._container=t.getContainer(),this._clickTolerance=e.clickTolerance||1};function Nn(t,e){for(var r={},n=0;n<t.length;n++)r[t[n].identifier]=e[n];return r}Bn.prototype.isEnabled=function(){return!!this._enabled},Bn.prototype.isActive=function(){return!!this._active},Bn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Bn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Bn.prototype.mousedown=function(t,e){this.isEnabled()&&t.shiftKey&&0===t.button&&(r.disableDrag(),this._startPos=this._lastPos=e,this._active=!0)},Bn.prototype.mousemoveWindow=function(t,e){if(this._active){var n=e;if(!(this._lastPos.equals(n)||!this._box&&n.dist(this._startPos)<this._clickTolerance)){var i=this._startPos;this._lastPos=n,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var a=Math.min(i.x,n.x),o=Math.max(i.x,n.x),s=Math.min(i.y,n.y),l=Math.max(i.y,n.y);r.setTransform(this._box,\"translate(\"+a+\"px,\"+s+\"px)\"),this._box.style.width=o-a+\"px\",this._box.style.height=l-s+\"px\"}}},Bn.prototype.mouseupWindow=function(e,n){var i=this;if(this._active&&0===e.button){var a=this._startPos,o=n;if(this.reset(),r.suppressClick(),a.x!==o.x||a.y!==o.y)return this._map.fire(new t.Event(\"boxzoomend\",{originalEvent:e})),{cameraAnimation:function(t){return t.fitScreenCoordinates(a,o,i._map.getBearing(),{linear:!0})}};this._fireEvent(\"boxzoomcancel\",e)}},Bn.prototype.keydown=function(t){this._active&&27===t.keyCode&&(this.reset(),this._fireEvent(\"boxzoomcancel\",t))},Bn.prototype.reset=function(){this._active=!1,this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},Bn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var jn=function(t){this.reset(),this.numTouches=t.numTouches};jn.prototype.reset=function(){delete this.centroid,delete this.startTime,delete this.touches,this.aborted=!1},jn.prototype.touchstart=function(e,r,n){(this.centroid||n.length>this.numTouches)&&(this.aborted=!0),this.aborted||(void 0===this.startTime&&(this.startTime=e.timeStamp),n.length===this.numTouches&&(this.centroid=function(e){for(var r=new t.Point(0,0),n=0,i=e;n<i.length;n+=1)r._add(i[n]);return r.div(e.length)}(r),this.touches=Nn(n,r)))},jn.prototype.touchmove=function(t,e,r){if(!this.aborted&&this.centroid){var n=Nn(r,e);for(var i in this.touches){var a=n[i];(!a||a.dist(this.touches[i])>30)&&(this.aborted=!0)}}},jn.prototype.touchend=function(t,e,r){if((!this.centroid||t.timeStamp-this.startTime>500)&&(this.aborted=!0),0===r.length){var n=!this.aborted&&this.centroid;if(this.reset(),n)return n}};var Un=function(t){this.singleTap=new jn(t),this.numTaps=t.numTaps,this.reset()};Un.prototype.reset=function(){this.lastTime=1/0,delete this.lastTap,this.count=0,this.singleTap.reset()},Un.prototype.touchstart=function(t,e,r){this.singleTap.touchstart(t,e,r)},Un.prototype.touchmove=function(t,e,r){this.singleTap.touchmove(t,e,r)},Un.prototype.touchend=function(t,e,r){var n=this.singleTap.touchend(t,e,r);if(n){var i=t.timeStamp-this.lastTime<500,a=!this.lastTap||this.lastTap.dist(n)<30;if(i&&a||this.reset(),this.count++,this.lastTime=t.timeStamp,this.lastTap=n,this.count===this.numTaps)return this.reset(),n}};var Vn=function(){this._zoomIn=new Un({numTouches:1,numTaps:2}),this._zoomOut=new Un({numTouches:2,numTaps:1}),this.reset()};Vn.prototype.reset=function(){this._active=!1,this._zoomIn.reset(),this._zoomOut.reset()},Vn.prototype.touchstart=function(t,e,r){this._zoomIn.touchstart(t,e,r),this._zoomOut.touchstart(t,e,r)},Vn.prototype.touchmove=function(t,e,r){this._zoomIn.touchmove(t,e,r),this._zoomOut.touchmove(t,e,r)},Vn.prototype.touchend=function(t,e,r){var n=this,i=this._zoomIn.touchend(t,e,r),a=this._zoomOut.touchend(t,e,r);return i?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()+1,around:e.unproject(i)},{originalEvent:t})}}):a?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()-1,around:e.unproject(a)},{originalEvent:t})}}):void 0},Vn.prototype.touchcancel=function(){this.reset()},Vn.prototype.enable=function(){this._enabled=!0},Vn.prototype.disable=function(){this._enabled=!1,this.reset()},Vn.prototype.isEnabled=function(){return this._enabled},Vn.prototype.isActive=function(){return this._active};var qn=function(t){this.reset(),this._clickTolerance=t.clickTolerance||1};qn.prototype.reset=function(){this._active=!1,this._moved=!1,delete this._lastPoint,delete this._eventButton},qn.prototype._correctButton=function(t,e){return!1},qn.prototype._move=function(t,e){return{}},qn.prototype.mousedown=function(t,e){if(!this._lastPoint){var n=r.mouseButton(t);this._correctButton(t,n)&&(this._lastPoint=e,this._eventButton=n)}},qn.prototype.mousemoveWindow=function(t,e){var r=this._lastPoint;if(r&&(t.preventDefault(),this._moved||!(e.dist(r)<this._clickTolerance)))return this._moved=!0,this._lastPoint=e,this._move(r,e)},qn.prototype.mouseupWindow=function(t){r.mouseButton(t)===this._eventButton&&(this._moved&&r.suppressClick(),this.reset())},qn.prototype.enable=function(){this._enabled=!0},qn.prototype.disable=function(){this._enabled=!1,this.reset()},qn.prototype.isEnabled=function(){return this._enabled},qn.prototype.isActive=function(){return this._active};var Hn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.mousedown=function(e,r){t.prototype.mousedown.call(this,e,r),this._lastPoint&&(this._active=!0)},e.prototype._correctButton=function(t,e){return 0===e&&!t.ctrlKey},e.prototype._move=function(t,e){return{around:e,panDelta:e.sub(t)}},e}(qn),Gn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=.8*(e.x-t.x);if(r)return this._active=!0,{bearingDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Yn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=-.5*(e.y-t.y);if(r)return this._active=!0,{pitchDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Wn=function(t){this._minTouches=1,this._clickTolerance=t.clickTolerance||1,this.reset()};Wn.prototype.reset=function(){this._active=!1,this._touches={},this._sum=new t.Point(0,0)},Wn.prototype.touchstart=function(t,e,r){return this._calculateTransform(t,e,r)},Wn.prototype.touchmove=function(t,e,r){if(this._active)return t.preventDefault(),this._calculateTransform(t,e,r)},Wn.prototype.touchend=function(t,e,r){this._calculateTransform(t,e,r),this._active&&r.length<this._minTouches&&this.reset()},Wn.prototype.touchcancel=function(){this.reset()},Wn.prototype._calculateTransform=function(e,r,n){n.length>0&&(this._active=!0);var i=Nn(n,r),a=new t.Point(0,0),o=new t.Point(0,0),s=0;for(var l in i){var c=i[l],u=this._touches[l];u&&(a._add(c),o._add(c.sub(u)),s++,i[l]=c)}if(this._touches=i,!(s<this._minTouches)&&o.mag()){var f=o.div(s);if(this._sum._add(f),!(this._sum.mag()<this._clickTolerance))return{around:a.div(s),panDelta:f}}},Wn.prototype.enable=function(){this._enabled=!0},Wn.prototype.disable=function(){this._enabled=!1,this.reset()},Wn.prototype.isEnabled=function(){return this._enabled},Wn.prototype.isActive=function(){return this._active};var Xn=function(){this.reset()};function Zn(t,e,r){for(var n=0;n<t.length;n++)if(t[n].identifier===r)return e[n]}function Jn(t,e){return Math.log(t/e)/Math.LN2}Xn.prototype.reset=function(){this._active=!1,delete this._firstTwoTouches},Xn.prototype._start=function(t){},Xn.prototype._move=function(t,e,r){return{}},Xn.prototype.touchstart=function(t,e,r){this._firstTwoTouches||r.length<2||(this._firstTwoTouches=[r[0].identifier,r[1].identifier],this._start([e[0],e[1]]))},Xn.prototype.touchmove=function(t,e,r){if(this._firstTwoTouches){t.preventDefault();var n=this._firstTwoTouches,i=n[1],a=Zn(r,e,n[0]),o=Zn(r,e,i);if(a&&o){var s=this._aroundCenter?null:a.add(o).div(2);return this._move([a,o],s,t)}}},Xn.prototype.touchend=function(t,e,n){if(this._firstTwoTouches){var i=this._firstTwoTouches,a=i[1],o=Zn(n,e,i[0]),s=Zn(n,e,a);o&&s||(this._active&&r.suppressClick(),this.reset())}},Xn.prototype.touchcancel=function(){this.reset()},Xn.prototype.enable=function(t){this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around},Xn.prototype.disable=function(){this._enabled=!1,this.reset()},Xn.prototype.isEnabled=function(){return this._enabled},Xn.prototype.isActive=function(){return this._active};var Kn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._distance,delete this._startDistance},e.prototype._start=function(t){this._startDistance=this._distance=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._distance;if(this._distance=t[0].dist(t[1]),this._active||!(Math.abs(Jn(this._distance,this._startDistance))<.1))return this._active=!0,{zoomDelta:Jn(this._distance,r),pinchAround:e}},e}(Xn);function Qn(t,e){return 180*t.angleWith(e)/Math.PI}var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._minDiameter,delete this._startVector,delete this._vector},e.prototype._start=function(t){this._startVector=this._vector=t[0].sub(t[1]),this._minDiameter=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._vector;if(this._vector=t[0].sub(t[1]),this._active||!this._isBelowThreshold(this._vector))return this._active=!0,{bearingDelta:Qn(this._vector,r),pinchAround:e}},e.prototype._isBelowThreshold=function(t){this._minDiameter=Math.min(this._minDiameter,t.mag());var e=25/(Math.PI*this._minDiameter)*360,r=Qn(t,this._startVector);return Math.abs(r)<e},e}(Xn);function ti(t){return Math.abs(t.y)>Math.abs(t.x)}var ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),this._valid=void 0,delete this._firstMove,delete this._lastPoints},e.prototype._start=function(t){this._lastPoints=t,ti(t[0].sub(t[1]))&&(this._valid=!1)},e.prototype._move=function(t,e,r){var n=t[0].sub(this._lastPoints[0]),i=t[1].sub(this._lastPoints[1]);if(this._valid=this.gestureBeginsVertically(n,i,r.timeStamp),this._valid)return this._lastPoints=t,this._active=!0,{pitchDelta:(n.y+i.y)/2*-.5}},e.prototype.gestureBeginsVertically=function(t,e,r){if(void 0!==this._valid)return this._valid;var n=t.mag()>=2,i=e.mag()>=2;if(n||i){if(!n||!i)return void 0===this._firstMove&&(this._firstMove=r),r-this._firstMove<100&&void 0;var a=t.y>0==e.y>0;return ti(t)&&ti(e)&&a}},e}(Xn),ri={panStep:100,bearingStep:15,pitchStep:10},ni=function(){var t=ri;this._panStep=t.panStep,this._bearingStep=t.bearingStep,this._pitchStep=t.pitchStep};function ii(t){return t*(2-t)}ni.prototype.reset=function(){this._active=!1},ni.prototype.keydown=function(t){var e=this;if(!(t.altKey||t.ctrlKey||t.metaKey)){var r=0,n=0,i=0,a=0,o=0;switch(t.keyCode){case 61:case 107:case 171:case 187:r=1;break;case 189:case 109:case 173:r=-1;break;case 37:t.shiftKey?n=-1:(t.preventDefault(),a=-1);break;case 39:t.shiftKey?n=1:(t.preventDefault(),a=1);break;case 38:t.shiftKey?i=1:(t.preventDefault(),o=-1);break;case 40:t.shiftKey?i=-1:(t.preventDefault(),o=1);break;default:return}return{cameraAnimation:function(s){var l=s.getZoom();s.easeTo({duration:300,easeId:\"keyboardHandler\",easing:ii,zoom:r?Math.round(l)+r*(t.shiftKey?2:1):l,bearing:s.getBearing()+n*e._bearingStep,pitch:s.getPitch()+i*e._pitchStep,offset:[-a*e._panStep,-o*e._panStep],center:s.getCenter()},{originalEvent:t})}}}},ni.prototype.enable=function(){this._enabled=!0},ni.prototype.disable=function(){this._enabled=!1,this.reset()},ni.prototype.isEnabled=function(){return this._enabled},ni.prototype.isActive=function(){return this._active};var ai=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._handler=r,this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};ai.prototype.setZoomRate=function(t){this._defaultZoomRate=t},ai.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},ai.prototype.isEnabled=function(){return!!this._enabled},ai.prototype.isActive=function(){return!!this._active||void 0!==this._finishTimeout},ai.prototype.isZooming=function(){return!!this._zooming},ai.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},ai.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},ai.prototype.wheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this._active||this._start(e)),e.preventDefault()}},ai.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this._active||this._start(t)},ai.prototype._start=function(e){if(this._delta){this._frameId&&(this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0),this._finishTimeout&&(clearTimeout(this._finishTimeout),delete this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=!0,this._handler._triggerRenderFrame())}},ai.prototype.renderFrame=function(){return this._onScrollFrame()},ai.prototype._onScrollFrame=function(){var e=this;if(this._frameId&&(this._frameId=null,this.isActive())){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o,s=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,l=this._startZoom,c=this._easing,u=!1;if(\"wheel\"===this._type&&l&&c){var f=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=c(f);o=t.number(l,s,h),f<1?this._frameId||(this._frameId=!0):u=!0}else o=s,u=!0;return this._active=!0,u&&(this._active=!1,this._finishTimeout=setTimeout((function(){e._zooming=!1,e._handler._triggerRenderFrame(),delete e._targetZoom,delete e._finishTimeout}),200)),{noInertia:!0,needsRenderFrame:!u,zoomDelta:o-r.zoom,around:this._aroundPoint,originalEvent:this._lastWheelEvent}}},ai.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r},ai.prototype.reset=function(){this._active=!1};var oi=function(t,e){this._clickZoom=t,this._tapZoom=e};oi.prototype.enable=function(){this._clickZoom.enable(),this._tapZoom.enable()},oi.prototype.disable=function(){this._clickZoom.disable(),this._tapZoom.disable()},oi.prototype.isEnabled=function(){return this._clickZoom.isEnabled()&&this._tapZoom.isEnabled()},oi.prototype.isActive=function(){return this._clickZoom.isActive()||this._tapZoom.isActive()};var si=function(){this.reset()};si.prototype.reset=function(){this._active=!1},si.prototype.dblclick=function(t,e){return t.preventDefault(),{cameraAnimation:function(r){r.easeTo({duration:300,zoom:r.getZoom()+(t.shiftKey?-1:1),around:r.unproject(e)},{originalEvent:t})}}},si.prototype.enable=function(){this._enabled=!0},si.prototype.disable=function(){this._enabled=!1,this.reset()},si.prototype.isEnabled=function(){return this._enabled},si.prototype.isActive=function(){return this._active};var li=function(){this._tap=new Un({numTouches:1,numTaps:1}),this.reset()};li.prototype.reset=function(){this._active=!1,delete this._swipePoint,delete this._swipeTouch,delete this._tapTime,this._tap.reset()},li.prototype.touchstart=function(t,e,r){this._swipePoint||(this._tapTime&&t.timeStamp-this._tapTime>500&&this.reset(),this._tapTime?r.length>0&&(this._swipePoint=e[0],this._swipeTouch=r[0].identifier):this._tap.touchstart(t,e,r))},li.prototype.touchmove=function(t,e,r){if(this._tapTime){if(this._swipePoint){if(r[0].identifier!==this._swipeTouch)return;var n=e[0],i=n.y-this._swipePoint.y;return this._swipePoint=n,t.preventDefault(),this._active=!0,{zoomDelta:i/128}}}else this._tap.touchmove(t,e,r)},li.prototype.touchend=function(t,e,r){this._tapTime?this._swipePoint&&0===r.length&&this.reset():this._tap.touchend(t,e,r)&&(this._tapTime=t.timeStamp)},li.prototype.touchcancel=function(){this.reset()},li.prototype.enable=function(){this._enabled=!0},li.prototype.disable=function(){this._enabled=!1,this.reset()},li.prototype.isEnabled=function(){return this._enabled},li.prototype.isActive=function(){return this._active};var ci=function(t,e,r){this._el=t,this._mousePan=e,this._touchPan=r};ci.prototype.enable=function(t){this._inertiaOptions=t||{},this._mousePan.enable(),this._touchPan.enable(),this._el.classList.add(\"mapboxgl-touch-drag-pan\")},ci.prototype.disable=function(){this._mousePan.disable(),this._touchPan.disable(),this._el.classList.remove(\"mapboxgl-touch-drag-pan\")},ci.prototype.isEnabled=function(){return this._mousePan.isEnabled()&&this._touchPan.isEnabled()},ci.prototype.isActive=function(){return this._mousePan.isActive()||this._touchPan.isActive()};var ui=function(t,e,r){this._pitchWithRotate=t.pitchWithRotate,this._mouseRotate=e,this._mousePitch=r};ui.prototype.enable=function(){this._mouseRotate.enable(),this._pitchWithRotate&&this._mousePitch.enable()},ui.prototype.disable=function(){this._mouseRotate.disable(),this._mousePitch.disable()},ui.prototype.isEnabled=function(){return this._mouseRotate.isEnabled()&&(!this._pitchWithRotate||this._mousePitch.isEnabled())},ui.prototype.isActive=function(){return this._mouseRotate.isActive()||this._mousePitch.isActive()};var fi=function(t,e,r,n){this._el=t,this._touchZoom=e,this._touchRotate=r,this._tapDragZoom=n,this._rotationDisabled=!1,this._enabled=!0};fi.prototype.enable=function(t){this._touchZoom.enable(t),this._rotationDisabled||this._touchRotate.enable(t),this._tapDragZoom.enable(),this._el.classList.add(\"mapboxgl-touch-zoom-rotate\")},fi.prototype.disable=function(){this._touchZoom.disable(),this._touchRotate.disable(),this._tapDragZoom.disable(),this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\")},fi.prototype.isEnabled=function(){return this._touchZoom.isEnabled()&&(this._rotationDisabled||this._touchRotate.isEnabled())&&this._tapDragZoom.isEnabled()},fi.prototype.isActive=function(){return this._touchZoom.isActive()||this._touchRotate.isActive()||this._tapDragZoom.isActive()},fi.prototype.disableRotation=function(){this._rotationDisabled=!0,this._touchRotate.disable()},fi.prototype.enableRotation=function(){this._rotationDisabled=!1,this._touchZoom.isEnabled()&&this._touchRotate.enable()};var hi=function(t){return t.zoom||t.drag||t.pitch||t.rotate},pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(t.Event);function di(t){return t.panDelta&&t.panDelta.mag()||t.zoomDelta||t.bearingDelta||t.pitchDelta}var gi=function(e,n){this._map=e,this._el=this._map.getCanvasContainer(),this._handlers=[],this._handlersById={},this._changes=[],this._inertia=new Ln(e),this._bearingSnap=n.bearingSnap,this._previousActiveHandlers={},this._eventsInProgress={},this._addDefaultHandlers(n),t.bindAll([\"handleEvent\",\"handleWindowEvent\"],this);var i=this._el;this._listeners=[[i,\"touchstart\",{passive:!1}],[i,\"touchmove\",{passive:!1}],[i,\"touchend\",void 0],[i,\"touchcancel\",void 0],[i,\"mousedown\",void 0],[i,\"mousemove\",void 0],[i,\"mouseup\",void 0],[t.window.document,\"mousemove\",{capture:!0}],[t.window.document,\"mouseup\",void 0],[i,\"mouseover\",void 0],[i,\"mouseout\",void 0],[i,\"dblclick\",void 0],[i,\"click\",void 0],[i,\"keydown\",{capture:!1}],[i,\"keyup\",void 0],[i,\"wheel\",{passive:!1}],[i,\"contextmenu\",void 0],[t.window,\"blur\",void 0]];for(var a=0,o=this._listeners;a<o.length;a+=1){var s=o[a],l=s[0];r.addEventListener(l,s[1],l===t.window.document?this.handleWindowEvent:this.handleEvent,s[2])}};gi.prototype.destroy=function(){for(var e=0,n=this._listeners;e<n.length;e+=1){var i=n[e],a=i[0];r.removeEventListener(a,i[1],a===t.window.document?this.handleWindowEvent:this.handleEvent,i[2])}},gi.prototype._addDefaultHandlers=function(t){var e=this._map,r=e.getCanvasContainer();this._add(\"mapEvent\",new Rn(e,t));var n=e.boxZoom=new Bn(e,t);this._add(\"boxZoom\",n);var i=new Vn,a=new si;e.doubleClickZoom=new oi(a,i),this._add(\"tapZoom\",i),this._add(\"clickZoom\",a);var o=new li;this._add(\"tapDragZoom\",o);var s=e.touchPitch=new ei;this._add(\"touchPitch\",s);var l=new Gn(t),c=new Yn(t);e.dragRotate=new ui(t,l,c),this._add(\"mouseRotate\",l,[\"mousePitch\"]),this._add(\"mousePitch\",c,[\"mouseRotate\"]);var u=new Hn(t),f=new Wn(t);e.dragPan=new ci(r,u,f),this._add(\"mousePan\",u),this._add(\"touchPan\",f,[\"touchZoom\",\"touchRotate\"]);var h=new $n,p=new Kn;e.touchZoomRotate=new fi(r,p,h,o),this._add(\"touchRotate\",h,[\"touchPan\",\"touchZoom\"]),this._add(\"touchZoom\",p,[\"touchPan\",\"touchRotate\"]);var d=e.scrollZoom=new ai(e,this);this._add(\"scrollZoom\",d,[\"mousePan\"]);var g=e.keyboard=new ni;this._add(\"keyboard\",g),this._add(\"blockableMapEvent\",new Fn(e));for(var m=0,v=[\"boxZoom\",\"doubleClickZoom\",\"tapDragZoom\",\"touchPitch\",\"dragRotate\",\"dragPan\",\"touchZoomRotate\",\"scrollZoom\",\"keyboard\"];m<v.length;m+=1){var y=v[m];t.interactive&&t[y]&&e[y].enable(t[y])}},gi.prototype._add=function(t,e,r){this._handlers.push({handlerName:t,handler:e,allowed:r}),this._handlersById[t]=e},gi.prototype.stop=function(){if(!this._updatingCamera){for(var t=0,e=this._handlers;t<e.length;t+=1)e[t].handler.reset();this._inertia.clear(),this._fireEvents({},{}),this._changes=[]}},gi.prototype.isActive=function(){for(var t=0,e=this._handlers;t<e.length;t+=1)if(e[t].handler.isActive())return!0;return!1},gi.prototype.isZooming=function(){return!!this._eventsInProgress.zoom||this._map.scrollZoom.isZooming()},gi.prototype.isRotating=function(){return!!this._eventsInProgress.rotate},gi.prototype.isMoving=function(){return Boolean(hi(this._eventsInProgress))||this.isZooming()},gi.prototype._blockedByActive=function(t,e,r){for(var n in t)if(n!==r&&(!e||e.indexOf(n)<0))return!0;return!1},gi.prototype.handleWindowEvent=function(t){this.handleEvent(t,t.type+\"Window\")},gi.prototype._getMapTouches=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r];this._el.contains(i.target)&&e.push(i)}return e},gi.prototype.handleEvent=function(t,e){if(\"blur\"!==t.type){this._updatingCamera=!0;for(var n=\"renderFrame\"===t.type?void 0:t,i={needsRenderFrame:!1},a={},o={},s=t.touches?this._getMapTouches(t.touches):void 0,l=s?r.touchPos(this._el,s):r.mousePos(this._el,t),c=0,u=this._handlers;c<u.length;c+=1){var f=u[c],h=f.handlerName,p=f.handler,d=f.allowed;if(p.isEnabled()){var g=void 0;this._blockedByActive(o,d,h)?p.reset():p[e||t.type]&&(g=p[e||t.type](t,l,s),this.mergeHandlerResult(i,a,g,h,n),g&&g.needsRenderFrame&&this._triggerRenderFrame()),(g||p.isActive())&&(o[h]=p)}}var m={};for(var v in this._previousActiveHandlers)o[v]||(m[v]=n);this._previousActiveHandlers=o,(Object.keys(m).length||di(i))&&(this._changes.push([i,a,m]),this._triggerRenderFrame()),(Object.keys(o).length||di(i))&&this._map._stop(!0),this._updatingCamera=!1;var y=i.cameraAnimation;y&&(this._inertia.clear(),this._fireEvents({},{}),this._changes=[],y(this._map))}else this.stop()},gi.prototype.mergeHandlerResult=function(e,r,n,i,a){if(n){t.extend(e,n);var o={handlerName:i,originalEvent:n.originalEvent||a};void 0!==n.zoomDelta&&(r.zoom=o),void 0!==n.panDelta&&(r.drag=o),void 0!==n.pitchDelta&&(r.pitch=o),void 0!==n.bearingDelta&&(r.rotate=o)}},gi.prototype._applyChanges=function(){for(var e={},r={},n={},i=0,a=this._changes;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=o[2];s.panDelta&&(e.panDelta=(e.panDelta||new t.Point(0,0))._add(s.panDelta)),s.zoomDelta&&(e.zoomDelta=(e.zoomDelta||0)+s.zoomDelta),s.bearingDelta&&(e.bearingDelta=(e.bearingDelta||0)+s.bearingDelta),s.pitchDelta&&(e.pitchDelta=(e.pitchDelta||0)+s.pitchDelta),void 0!==s.around&&(e.around=s.around),void 0!==s.pinchAround&&(e.pinchAround=s.pinchAround),s.noInertia&&(e.noInertia=s.noInertia),t.extend(r,l),t.extend(n,c)}this._updateMapTransform(e,r,n),this._changes=[]},gi.prototype._updateMapTransform=function(t,e,r){var n=this._map,i=n.transform;if(!di(t))return this._fireEvents(e,r);var a=t.panDelta,o=t.zoomDelta,s=t.bearingDelta,l=t.pitchDelta,c=t.around,u=t.pinchAround;void 0!==u&&(c=u),n._stop(!0),c=c||n.transform.centerPoint;var f=i.pointLocation(a?c.sub(a):c);s&&(i.bearing+=s),l&&(i.pitch+=l),o&&(i.zoom+=o),i.setLocationAtPoint(f,c),this._map._update(),t.noInertia||this._inertia.record(t),this._fireEvents(e,r)},gi.prototype._fireEvents=function(e,r){var n=this,i=hi(this._eventsInProgress),a=hi(e),o={};for(var s in e)this._eventsInProgress[s]||(o[s+\"start\"]=e[s].originalEvent),this._eventsInProgress[s]=e[s];for(var l in!i&&a&&this._fireEvent(\"movestart\",a.originalEvent),o)this._fireEvent(l,o[l]);for(var c in e.rotate&&(this._bearingChanged=!0),a&&this._fireEvent(\"move\",a.originalEvent),e)this._fireEvent(c,e[c].originalEvent);var u,f={};for(var h in this._eventsInProgress){var p=this._eventsInProgress[h],d=p.handlerName,g=p.originalEvent;this._handlersById[d].isActive()||(delete this._eventsInProgress[h],f[h+\"end\"]=u=r[d]||g)}for(var m in f)this._fireEvent(m,f[m]);var v=hi(this._eventsInProgress);if((i||a)&&!v){this._updatingCamera=!0;var y=this._inertia._onMoveEnd(this._map.dragPan._inertiaOptions),x=function(t){return 0!==t&&-n._bearingSnap<t&&t<n._bearingSnap};y?(x(y.bearing||this._map.getBearing())&&(y.bearing=0),this._map.easeTo(y,{originalEvent:u})):(this._map.fire(new t.Event(\"moveend\",{originalEvent:u})),x(this._map.getBearing())&&this._map.resetNorth()),this._bearingChanged=!1,this._updatingCamera=!1}},gi.prototype._fireEvent=function(e,r){this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},gi.prototype._triggerRenderFrame=function(){var t=this;void 0===this._frameId&&(this._frameId=this._map._requestRenderFrame((function(e){delete t._frameId,t.handleEvent(new pi(\"renderFrame\",{timeStamp:e})),t._applyChanges()})))};var mi=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.getPadding=function(){return this.transform.padding},r.prototype.setPadding=function(t,e){return this.jumpTo({padding:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.resetNorthPitch=function(e,r){return this.easeTo(t.extend({bearing:0,pitch:0,duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){var a={top:0,bottom:0,right:0,left:0};if(\"number\"==typeof(i=t.extend({padding:a,offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var o=i.padding;i.padding={top:o,bottom:o,right:o,left:o}}i.padding=t.extend(a,i.padding);var s=this.transform,l=s.padding,c=s.project(t.LngLat.convert(e)),u=s.project(t.LngLat.convert(r)),f=c.rotate(-n*Math.PI/180),h=u.rotate(-n*Math.PI/180),p=new t.Point(Math.max(f.x,h.x),Math.max(f.y,h.y)),d=new t.Point(Math.min(f.x,h.x),Math.min(f.y,h.y)),g=p.sub(d),m=(s.width-(l.left+l.right+i.padding.left+i.padding.right))/g.x,v=(s.height-(l.top+l.bottom+i.padding.top+i.padding.bottom))/g.y;if(!(v<0||m<0)){var y=Math.min(s.scaleZoom(s.scale*Math.min(m,v)),i.maxZoom),x=t.Point.convert(i.offset),b=new t.Point(x.x+(i.padding.left-i.padding.right)/2,x.y+(i.padding.top-i.padding.bottom)/2).mult(s.scale/s.zoomScale(y));return{center:s.unproject(c.add(u).div(2).sub(b)),zoom:y,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(delete(r=t.extend(e,r)).padding,r.linear?this.easeTo(r,n):this.flyTo(r,n)):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),null==e.padding||n.isPaddingEqual(e.padding)||(n.padding=e.padding),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this._stop(!1,e.easeId),(!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate||!e.essential&&t.browser.prefersReducedMotion)&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=this.getPadding(),c=\"zoom\"in e?+e.zoom:a,u=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,f=\"pitch\"in e?+e.pitch:s,h=\"padding\"in e?e.padding:i.padding,p=t.Point.convert(e.offset),d=i.centerPoint.add(p),g=i.pointLocation(d),m=t.LngLat.convert(e.center||g);this._normalizeCenter(m);var v,y,x=i.project(g),b=i.project(m).sub(x),_=i.zoomScale(c-a);e.around&&(v=t.LngLat.convert(e.around),y=i.locationPoint(v));var w={moving:this._moving,zooming:this._zooming,rotating:this._rotating,pitching:this._pitching};return this._zooming=this._zooming||c!==a,this._rotating=this._rotating||o!==u,this._pitching=this._pitching||f!==s,this._padding=!i.isPaddingEqual(h),this._easeId=e.easeId,this._prepareEase(r,e.noMoveStart,w),clearTimeout(this._easeEndTimeoutID),this._ease((function(e){if(n._zooming&&(i.zoom=t.number(a,c,e)),n._rotating&&(i.bearing=t.number(o,u,e)),n._pitching&&(i.pitch=t.number(s,f,e)),n._padding&&(i.interpolatePadding(l,h,e),d=i.centerPoint.add(p)),v)i.setLocationAtPoint(v,y);else{var g=i.zoomScale(i.zoom-a),m=c>a?Math.min(2,_):Math.max(.5,_),w=Math.pow(m,1-e),T=i.unproject(x.add(b.mult(e*w)).mult(g));i.setLocationAtPoint(i.renderWorldCopies?T.wrap():T,d)}n._fireMoveEvents(r)}),(function(t){n._afterEase(r,t)}),e),this},r.prototype._prepareEase=function(e,r,n){void 0===n&&(n={}),this._moving=!0,r||n.moving||this.fire(new t.Event(\"movestart\",e)),this._zooming&&!n.zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&!n.rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&!n.pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e,r){if(!this._easeId||!r||this._easeId!==r){delete this._easeId;var n=this._zooming,i=this._rotating,a=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,this._padding=!1,n&&this.fire(new t.Event(\"zoomend\",e)),i&&this.fire(new t.Event(\"rotateend\",e)),a&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))}},r.prototype.flyTo=function(e,r){var n=this;if(!e.essential&&t.browser.prefersReducedMotion){var i=t.pick(e,[\"center\",\"zoom\",\"bearing\",\"pitch\",\"around\"]);return this.jumpTo(i,r)}this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var a=this.transform,o=this.getZoom(),s=this.getBearing(),l=this.getPitch(),c=this.getPadding(),u=\"zoom\"in e?t.clamp(+e.zoom,a.minZoom,a.maxZoom):o,f=\"bearing\"in e?this._normalizeBearing(e.bearing,s):s,h=\"pitch\"in e?+e.pitch:l,p=\"padding\"in e?e.padding:a.padding,d=a.zoomScale(u-o),g=t.Point.convert(e.offset),m=a.centerPoint.add(g),v=a.pointLocation(m),y=t.LngLat.convert(e.center||v);this._normalizeCenter(y);var x=a.project(v),b=a.project(y).sub(x),_=e.curve,w=Math.max(a.width,a.height),T=w/d,k=b.mag();if(\"minZoom\"in e){var M=t.clamp(Math.min(e.minZoom,o,u),a.minZoom,a.maxZoom),A=w/a.zoomScale(M-o);_=Math.sqrt(A/k*2)}var S=_*_;function E(t){var e=(T*T-w*w+(t?-1:1)*S*S*k*k)/(2*(t?T:w)*S*k);return Math.log(Math.sqrt(e*e+1)-e)}function C(t){return(Math.exp(t)-Math.exp(-t))/2}function L(t){return(Math.exp(t)+Math.exp(-t))/2}var I=E(0),P=function(t){return L(I)/L(I+_*t)},z=function(t){return w*((L(I)*(C(e=I+_*t)/L(e))-C(I))/S)/k;var e},O=(E(1)-I)/_;if(Math.abs(k)<1e-6||!isFinite(O)){if(Math.abs(w-T)<1e-6)return this.easeTo(e,r);var D=T<w?-1:1;O=Math.abs(Math.log(T/w))/_,z=function(){return 0},P=function(t){return Math.exp(D*_*t)}}return e.duration=\"duration\"in e?+e.duration:1e3*O/(\"screenSpeed\"in e?+e.screenSpeed/_:+e.speed),e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=s!==f,this._pitching=h!==l,this._padding=!a.isPaddingEqual(p),this._prepareEase(r,!1),this._ease((function(e){var i=e*O,d=1/P(i);a.zoom=1===e?u:o+a.scaleZoom(d),n._rotating&&(a.bearing=t.number(s,f,e)),n._pitching&&(a.pitch=t.number(l,h,e)),n._padding&&(a.interpolatePadding(c,p,e),m=a.centerPoint.add(g));var v=1===e?y:a.unproject(x.add(b.mult(z(i))).mult(d));a.setLocationAtPoint(a.renderWorldCopies?v.wrap():v,m),n._fireMoveEvents(r)}),(function(){return n._afterEase(r)}),e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){return this._stop()},r.prototype._stop=function(t,e){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var r=this._onEaseEnd;delete this._onEaseEnd,r.call(this,e)}if(!t){var n=this.handlers;n&&n.stop()}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),vi=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};vi.prototype.getDefaultPosition=function(){return\"bottom-right\"},vi.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},vi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0,this._attribHTML=void 0},vi.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:this._map._requestManager._customAccessToken||t.config.ACCESS_TOKEN}];if(e){var n=r.reduce((function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t}),\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},vi.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},vi.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map((function(t){return\"string\"!=typeof t?\"\":t}))):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort((function(t,e){return t.length-e.length}));var o=(t=t.filter((function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0}))).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},vi.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var yi=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};yi.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",this._map._getUIString(\"LogoControl.Title\")),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},yi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},yi.prototype.getDefaultPosition=function(){return\"bottom-left\"},yi.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},yi.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},yi.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var xi=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};xi.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},xi.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},xi.prototype.run=function(t){void 0===t&&(t=0);var e=this._currentlyRunning=this._queue;this._queue=[];for(var r=0,n=e;r<n.length;r+=1){var i=n[r];if(!i.cancelled&&(i.callback(t),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},xi.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var bi={\"FullscreenControl.Enter\":\"Enter fullscreen\",\"FullscreenControl.Exit\":\"Exit fullscreen\",\"GeolocateControl.FindMyLocation\":\"Find my location\",\"GeolocateControl.LocationNotAvailable\":\"Location not available\",\"LogoControl.Title\":\"Mapbox logo\",\"NavigationControl.ResetBearing\":\"Reset bearing to north\",\"NavigationControl.ZoomIn\":\"Zoom in\",\"NavigationControl.ZoomOut\":\"Zoom out\",\"ScaleControl.Feet\":\"ft\",\"ScaleControl.Meters\":\"m\",\"ScaleControl.Kilometers\":\"km\",\"ScaleControl.Miles\":\"mi\",\"ScaleControl.NauticalMiles\":\"nm\"},_i=t.window.HTMLImageElement,wi=t.window.HTMLElement,Ti=t.window.ImageBitmap,ki={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:-2,maxZoom:22,minPitch:0,maxPitch:60,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,touchPitch:!0,bearingSnap:7,clickTolerance:3,pitchWithRotate:!0,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,accessToken:null,fadeDuration:300,crossSourceCollisions:!0},Mi=function(n){function i(e){var r=this;if(null!=(e=t.extend({},ki,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than or equal to minZoom\");if(null!=e.minPitch&&null!=e.maxPitch&&e.minPitch>e.maxPitch)throw new Error(\"maxPitch must be greater than or equal to minPitch\");if(null!=e.minPitch&&e.minPitch<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(null!=e.maxPitch&&e.maxPitch>60)throw new Error(\"maxPitch must be less than or equal to 60\");var i=new wn(e.minZoom,e.maxZoom,e.minPitch,e.maxPitch,e.renderWorldCopies);if(n.call(this,i,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new xi,this._controls=[],this._mapId=t.uniqueId(),this._locale=t.extend({},bi,e.locale),this._requestManager=new t.RequestManager(e.transformRequest,e.accessToken),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof wi))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",(function(){return r._update(!1)})),this.on(\"moveend\",(function(){return r._update(!1)})),this.on(\"zoom\",(function(){return r._update(!0)})),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),this.handlers=new gi(this,e),this._hash=e.hash&&new kn(\"string\"==typeof e.hash&&e.hash||void 0).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new vi({customAttribution:e.customAttribution})),this.addControl(new yi,e.logoPosition),this.on(\"style.load\",(function(){r.transform.unmodified&&r.jumpTo(r.style.stylesheet)})),this.on(\"data\",(function(e){r._update(\"style\"===e.dataType),r.fire(new t.Event(e.dataType+\"data\",e))})),this.on(\"dataloading\",(function(e){r.fire(new t.Event(e.dataType+\"dataloading\",e))}))}n&&(i.__proto__=n),(i.prototype=Object.create(n&&n.prototype)).constructor=i;var a={showTileBoundaries:{configurable:!0},showPadding:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0},version:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i);var a=!this._moving;return a&&(this.stop(),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e))),this.fire(new t.Event(\"resize\",e)),a&&this.fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?-2:t)>=-2&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between -2 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.setMinPitch=function(t){if((t=null==t?0:t)<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(t>=0&&t<=this.transform.maxPitch)return this.transform.minPitch=t,this._update(),this.getPitch()<t&&this.setPitch(t),this;throw new Error(\"minPitch must be between 0 and the current maxPitch, inclusive\")},i.prototype.getMinPitch=function(){return this.transform.minPitch},i.prototype.setMaxPitch=function(t){if((t=null==t?60:t)>60)throw new Error(\"maxPitch must be less than or equal to 60\");if(t>=this.transform.minPitch)return this.transform.maxPitch=t,this._update(),this.getPitch()>t&&this.setPitch(t),this;throw new Error(\"maxPitch must be greater than the current minPitch\")},i.prototype.getMaxPitch=function(){return this.transform.maxPitch},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.handlers.isMoving()},i.prototype.isZooming=function(){return this._zooming||this.handlers.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.handlers.isRotating()},i.prototype._createDelegatedListener=function(t,e,r){var n,i=this;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new zn(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new zn(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new zn(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}},i.prototype.on=function(t,e,r){if(void 0===r)return n.prototype.on.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(i),i.delegates)this.on(a,i.delegates[a]);return this},i.prototype.once=function(t,e,r){if(void 0===r)return n.prototype.once.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in i.delegates)this.once(a,i.delegates[a]);return this},i.prototype.off=function(t,e,r){var i=this;return void 0===r?n.prototype.off.call(this,t,e):(this._delegatedListeners&&this._delegatedListeners[t]&&function(n){for(var a=n[t],o=0;o<a.length;o++){var s=a[o];if(s.layer===e&&s.listener===r){for(var l in s.delegates)i.off(l,s.delegates[l]);return a.splice(o,1),i}}}(this._delegatedListeners),this)},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:this._localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._getUIString=function(t){var e=this._locale[t];if(null==e)throw new Error(\"Missing UI string '\"+t+\"'\");return e},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new qe(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._lazyInitEmptyStyle=function(){this.style||(this.style=new qe(this,{}),this.style.setEventedParent(this,{style:this.style}),this.style.loadEmpty())},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,(function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)}))}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this._lazyInitEmptyStyle(),this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this._lazyInitEmptyStyle(),this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;void 0===a&&(a=!1);var o=n.stretchX,s=n.stretchY,l=n.content;if(this._lazyInitEmptyStyle(),r instanceof _i||Ti&&r instanceof Ti){var c=t.browser.getImageData(r);this.style.addImage(e,{data:new t.RGBAImage({width:c.width,height:c.height},c.data),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r;this.style.addImage(e,{data:new t.RGBAImage({width:r.width,height:r.height},new Uint8Array(r.data)),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0,userImage:u}),u.onAdd&&u.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof _i||Ti&&r instanceof Ti?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;return void 0===a||void 0===o?this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\"))):a!==n.data.width||o!==n.data.height?this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\"))):(n.data.replace(s,!(r instanceof _i||Ti&&r instanceof Ti)),void this.style.updateImage(e,n))},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this._lazyInitEmptyStyle(),this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this._lazyInitEmptyStyle(),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach((function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)}))},i.prototype._resizeCanvas=function(e,r){var n=t.browser.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new yn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(e){var r,n=this,i=0,a=this.painter.context.extTimerQuery;if(this.listens(\"gpu-timing-frame\")&&(r=a.createQueryEXT(),a.beginQueryEXT(a.TIME_ELAPSED_EXT,r),i=t.browser.now()),this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run(e),!this._removed){var o=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var s=this.transform.zoom,l=t.browser.now();this.style.zoomHistory.update(s,l);var c=new t.EvaluationParameters(s,{now:l,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),u=c.crossFadingFactor();1===u&&u===this._crossFadingFactor||(o=!0,this._crossFadingFactor=u),this.style.update(c)}if(this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration,showPadding:this.showPadding,gpuTiming:!!this.listens(\"gpu-timing-layer\")}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||o)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this.listens(\"gpu-timing-frame\")){var f=t.browser.now()-i;a.endQueryEXT(a.TIME_ELAPSED_EXT,r),setTimeout((function(){var e=a.getQueryObjectEXT(r,a.QUERY_RESULT_EXT)/1e6;a.deleteQueryEXT(r),n.fire(new t.Event(\"gpu-timing-frame\",{cpuTime:f,gpuTime:e}))}),50)}if(this.listens(\"gpu-timing-layer\")){var h=this.painter.collectGpuTimers();setTimeout((function(){var e=n.painter.queryGpuTimers(h);n.fire(new t.Event(\"gpu-timing-layer\",{layerTimes:e}))}),50)}return this._sourcesDirty||this._styleDirty||this._placementDirty||this._repaint?this.triggerRepaint():!this.isMoving()&&this.loaded()&&(this._fullyLoaded||(this._fullyLoaded=!0),this.fire(new t.Event(\"idle\"))),this}},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.painter.destroy(),this.handlers.destroy(),delete this.handlers,this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),Ai(this._canvasContainer),Ai(this._controlContainer),Ai(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this._removed=!0,this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame((function(t){e._frame=null,e._render(t)})))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(t){this._trackResize&&this.resize({originalEvent:t})._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showPadding.get=function(){return!!this._showPadding},a.showPadding.set=function(t){this._showPadding!==t&&(this._showPadding=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},a.version.get=function(){return t.version},Object.defineProperties(i.prototype,a),i}(mi);function Ai(t){t.parentNode&&t.parentNode.removeChild(t)}var Si={showCompass:!0,showZoom:!0,visualizePitch:!1},Ei=function(e){var n=this;this.options=t.extend({},Si,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this.options.showZoom&&(t.bindAll([\"_setButtonTitle\",\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-zoom-in\",(function(t){return n._map.zoomIn({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomInButton).setAttribute(\"aria-hidden\",!0),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-zoom-out\",(function(t){return n._map.zoomOut({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomOutButton).setAttribute(\"aria-hidden\",!0)),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-compass\",(function(t){n.options.visualizePitch?n._map.resetNorthPitch({},{originalEvent:t}):n._map.resetNorth({},{originalEvent:t})})),this._compassIcon=r.create(\"span\",\"mapboxgl-ctrl-icon\",this._compass),this._compassIcon.setAttribute(\"aria-hidden\",!0))};Ei.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.disabled=t===this._map.getMaxZoom(),this._zoomOutButton.disabled=t===this._map.getMinZoom()},Ei.prototype._rotateCompassArrow=function(){var t=this.options.visualizePitch?\"scale(\"+1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)+\") rotateX(\"+this._map.transform.pitch+\"deg) rotateZ(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\":\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassIcon.style.transform=t},Ei.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._setButtonTitle(this._zoomInButton,\"ZoomIn\"),this._setButtonTitle(this._zoomOutButton,\"ZoomOut\"),this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._setButtonTitle(this._compass,\"ResetBearing\"),this.options.visualizePitch&&this._map.on(\"pitch\",this._rotateCompassArrow),this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new Ci(this._map,this._compass,this.options.visualizePitch)),this._container},Ei.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off(\"pitch\",this._rotateCompassArrow),this._map.off(\"rotate\",this._rotateCompassArrow),this._handler.off(),delete this._handler),delete this._map},Ei.prototype._createButton=function(t,e){var n=r.create(\"button\",t,this._container);return n.type=\"button\",n.addEventListener(\"click\",e),n},Ei.prototype._setButtonTitle=function(t,e){var r=this._map._getUIString(\"NavigationControl.\"+e);t.title=r,t.setAttribute(\"aria-label\",r)};var Ci=function(e,n,i){void 0===i&&(i=!1),this._clickTolerance=10,this.element=n,this.mouseRotate=new Gn({clickTolerance:e.dragRotate._mouseRotate._clickTolerance}),this.map=e,i&&(this.mousePitch=new Yn({clickTolerance:e.dragRotate._mousePitch._clickTolerance})),t.bindAll([\"mousedown\",\"mousemove\",\"mouseup\",\"touchstart\",\"touchmove\",\"touchend\",\"reset\"],this),r.addEventListener(n,\"mousedown\",this.mousedown),r.addEventListener(n,\"touchstart\",this.touchstart,{passive:!1}),r.addEventListener(n,\"touchmove\",this.touchmove),r.addEventListener(n,\"touchend\",this.touchend),r.addEventListener(n,\"touchcancel\",this.reset)};function Li(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Ci.prototype.down=function(t,e){this.mouseRotate.mousedown(t,e),this.mousePitch&&this.mousePitch.mousedown(t,e),r.disableDrag()},Ci.prototype.move=function(t,e){var r=this.map,n=this.mouseRotate.mousemoveWindow(t,e);if(n&&n.bearingDelta&&r.setBearing(r.getBearing()+n.bearingDelta),this.mousePitch){var i=this.mousePitch.mousemoveWindow(t,e);i&&i.pitchDelta&&r.setPitch(r.getPitch()+i.pitchDelta)}},Ci.prototype.off=function(){var t=this.element;r.removeEventListener(t,\"mousedown\",this.mousedown),r.removeEventListener(t,\"touchstart\",this.touchstart,{passive:!1}),r.removeEventListener(t,\"touchmove\",this.touchmove),r.removeEventListener(t,\"touchend\",this.touchend),r.removeEventListener(t,\"touchcancel\",this.reset),this.offTemp()},Ci.prototype.offTemp=function(){r.enableDrag(),r.removeEventListener(t.window,\"mousemove\",this.mousemove),r.removeEventListener(t.window,\"mouseup\",this.mouseup)},Ci.prototype.mousedown=function(e){this.down(t.extend({},e,{ctrlKey:!0,preventDefault:function(){return e.preventDefault()}}),r.mousePos(this.element,e)),r.addEventListener(t.window,\"mousemove\",this.mousemove),r.addEventListener(t.window,\"mouseup\",this.mouseup)},Ci.prototype.mousemove=function(t){this.move(t,r.mousePos(this.element,t))},Ci.prototype.mouseup=function(t){this.mouseRotate.mouseupWindow(t),this.mousePitch&&this.mousePitch.mouseupWindow(t),this.offTemp()},Ci.prototype.touchstart=function(t){1!==t.targetTouches.length?this.reset():(this._startPos=this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.down({type:\"mousedown\",button:0,ctrlKey:!0,preventDefault:function(){return t.preventDefault()}},this._startPos))},Ci.prototype.touchmove=function(t){1!==t.targetTouches.length?this.reset():(this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.move({preventDefault:function(){return t.preventDefault()}},this._lastPos))},Ci.prototype.touchend=function(t){0===t.targetTouches.length&&this._startPos&&this._lastPos&&this._startPos.dist(this._lastPos)<this._clickTolerance&&this.element.click(),this.reset()},Ci.prototype.reset=function(){this.mouseRotate.reset(),this.mousePitch&&this.mousePitch.reset(),delete this._startPos,delete this._lastPos,this.offTemp()};var Ii={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Pi(t,e,r){var n=t.classList;for(var i in Ii)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var zi,Oi=function(e){function n(n,i){var a=this;if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\",\"_onKeyPress\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",this._rotation=n&&n.rotation||0,this._rotationAlignment=n&&n.rotationAlignment||\"auto\",this._pitchAlignment=n&&n.pitchAlignment&&\"auto\"!==n.pitchAlignment?n.pitchAlignment:this._rotationAlignment,n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\"),this._element.setAttribute(\"aria-label\",\"Map marker\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");o.setAttributeNS(null,\"display\",\"block\"),o.setAttributeNS(null,\"height\",\"41px\"),o.setAttributeNS(null,\"width\",\"27px\"),o.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"stroke\",\"none\"),s.setAttributeNS(null,\"stroke-width\",\"1\"),s.setAttributeNS(null,\"fill\",\"none\"),s.setAttributeNS(null,\"fill-rule\",\"evenodd\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"fill-rule\",\"nonzero\");var c=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");c.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),c.setAttributeNS(null,\"fill\",\"#000000\");for(var u=0,f=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];u<f.length;u+=1){var h=f[u],p=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");p.setAttributeNS(null,\"opacity\",\"0.04\"),p.setAttributeNS(null,\"cx\",\"10.5\"),p.setAttributeNS(null,\"cy\",\"5.80029008\"),p.setAttributeNS(null,\"rx\",h.rx),p.setAttributeNS(null,\"ry\",h.ry),c.appendChild(p)}var d=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");d.setAttributeNS(null,\"fill\",this._color);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");g.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),d.appendChild(g);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"opacity\",\"0.25\"),m.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),m.appendChild(v);var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),y.setAttributeNS(null,\"fill\",\"#FFFFFF\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");x.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#000000\"),b.setAttributeNS(null,\"opacity\",\"0.25\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\");var _=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");_.setAttributeNS(null,\"fill\",\"#FFFFFF\"),_.setAttributeNS(null,\"cx\",\"5.5\"),_.setAttributeNS(null,\"cy\",\"5.5\"),_.setAttributeNS(null,\"r\",\"5.4999962\"),x.appendChild(b),x.appendChild(_),l.appendChild(c),l.appendChild(d),l.appendChild(m),l.appendChild(y),l.appendChild(x),o.appendChild(l),this._element.appendChild(o),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",(function(t){t.preventDefault()})),this._element.addEventListener(\"mousedown\",(function(t){t.preventDefault()})),this._element.addEventListener(\"focus\",(function(){var t=a._map.getContainer();t.scrollTop=0,t.scrollLeft=0})),Pi(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null,this._element.removeEventListener(\"keypress\",this._onKeyPress),this._originalTabIndex||this._element.removeAttribute(\"tabindex\")),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat),this._originalTabIndex=this._element.getAttribute(\"tabindex\"),this._originalTabIndex||this._element.setAttribute(\"tabindex\",\"0\"),this._element.addEventListener(\"keypress\",this._onKeyPress)}return this},n.prototype._onKeyPress=function(t){var e=t.code,r=t.charCode||t.keyCode;\"Space\"!==e&&\"Enter\"!==e&&32!==r&&13!==r||this.togglePopup()},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){if(this._map){this._map.transform.renderWorldCopies&&(this._lngLat=Li(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset);var e=\"\";\"viewport\"===this._rotationAlignment||\"auto\"===this._rotationAlignment?e=\"rotateZ(\"+this._rotation+\"deg)\":\"map\"===this._rotationAlignment&&(e=\"rotateZ(\"+(this._rotation-this._map.getBearing())+\"deg)\");var n=\"\";\"viewport\"===this._pitchAlignment||\"auto\"===this._pitchAlignment?n=\"rotateX(0deg)\":\"map\"===this._pitchAlignment&&(n=\"rotateX(\"+this._map.getPitch()+\"deg)\"),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Ii[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px) \"+n+\" \"+e)}},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n.prototype.setRotation=function(t){return this._rotation=t||0,this._update(),this},n.prototype.getRotation=function(){return this._rotation},n.prototype.setRotationAlignment=function(t){return this._rotationAlignment=t||\"auto\",this._update(),this},n.prototype.getRotationAlignment=function(){return this._rotationAlignment},n.prototype.setPitchAlignment=function(t){return this._pitchAlignment=t&&\"auto\"!==t?t:this._rotationAlignment,this._update(),this},n.prototype.getPitchAlignment=function(){return this._pitchAlignment},n}(t.Evented),Di={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showAccuracyCircle:!0,showUserLocation:!0},Ri=0,Fi=!1,Bi=function(e){function n(r){e.call(this),this.options=t.extend({},Di,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_onZoom\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==zi?n(zi):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then((function(t){n(zi=\"denied\"!==t.state)})):n(zi=!!t.window.navigator.geolocation),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),this.options.showAccuracyCircle&&this._accuracyCircleMarker&&this._accuracyCircleMarker.remove(),r.remove(this._container),this._map.off(\"zoom\",this._onZoom),this._map=void 0,Ri=0,Fi=!1},n.prototype._isOutOfMapMaxBounds=function(t){var e=this._map.getMaxBounds(),r=t.coords;return e&&(r.longitude<e.getWest()||r.longitude>e.getEast()||r.latitude<e.getSouth()||r.latitude>e.getNorth())},n.prototype._setErrorState=function(){switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}},n.prototype._onSuccess=function(e){if(this._map){if(this._isOutOfMapMaxBounds(e))return this._setErrorState(),this.fire(new t.Event(\"outofmaxbounds\",e)),this._updateMarker(),void this._finish();if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()}},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(e){if(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude);this._accuracyCircleMarker.setLngLat(r).addTo(this._map),this._userLocationDotMarker.setLngLat(r).addTo(this._map),this._accuracy=e.coords.accuracy,this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()}else this._userLocationDotMarker.remove(),this._accuracyCircleMarker.remove()},n.prototype._updateCircleRadius=function(){var t=this._map._container.clientHeight/2,e=this._map.unproject([0,t]),r=this._map.unproject([1,t]),n=e.distanceTo(r),i=Math.ceil(2*this._accuracy/n);this._circleElement.style.width=i+\"px\",this._circleElement.style.height=i+\"px\"},n.prototype._onZoom=function(){this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()},n.prototype._onError=function(e){if(this._map){if(this.options.trackUserLocation)if(1===e.code){this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.disabled=!0;var r=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.title=r,this._geolocateButton.setAttribute(\"aria-label\",r),void 0!==this._geolocationWatchID&&this._clearWatch()}else{if(3===e.code&&Fi)return;this._setErrorState()}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()}},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;if(this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-geolocate\",this._container),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._geolocateButton).setAttribute(\"aria-hidden\",!0),this._geolocateButton.type=\"button\",!1===e){t.warnOnce(\"Geolocation support is not available so the GeolocateControl will be disabled.\");var i=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.disabled=!0,this._geolocateButton.title=i,this._geolocateButton.setAttribute(\"aria-label\",i)}else{var a=this._map._getUIString(\"GeolocateControl.FindMyLocation\");this._geolocateButton.title=a,this._geolocateButton.setAttribute(\"aria-label\",a)}this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new Oi(this._dotElement),this._circleElement=r.create(\"div\",\"mapboxgl-user-location-accuracy-circle\"),this._accuracyCircleMarker=new Oi({element:this._circleElement,pitchAlignment:\"map\"}),this.options.trackUserLocation&&(this._watchState=\"OFF\"),this._map.on(\"zoom\",this._onZoom)),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",(function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||e.originalEvent&&\"resize\"===e.originalEvent.type||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))}))},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":Ri--,Fi=!1,this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}if(\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID)this._clearWatch();else if(void 0===this._geolocationWatchID){var e;this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),++Ri>1?(e={maximumAge:6e5,timeout:0},Fi=!0):(e=this.options.positionOptions,Fi=!1),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,e)}}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),Ni={maxWidth:100,unit:\"metric\"},ji=function(e){this.options=t.extend({},Ni,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Ui(t,e,r){var n=r&&r.maxWidth||100,i=t._container.clientHeight/2,a=t.unproject([0,i]),o=t.unproject([n,i]),s=a.distanceTo(o);if(r&&\"imperial\"===r.unit){var l=3.2808*s;l>5280?Vi(e,n,l/5280,t._getUIString(\"ScaleControl.Miles\")):Vi(e,n,l,t._getUIString(\"ScaleControl.Feet\"))}else r&&\"nautical\"===r.unit?Vi(e,n,s/1852,t._getUIString(\"ScaleControl.NauticalMiles\")):s>=1e3?Vi(e,n,s/1e3,t._getUIString(\"ScaleControl.Kilometers\")):Vi(e,n,s,t._getUIString(\"ScaleControl.Meters\"))}function Vi(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o)));t.style.width=e*(s/r)+\"px\",t.innerHTML=s+\"&nbsp;\"+n}ji.prototype.getDefaultPosition=function(){return\"bottom-left\"},ji.prototype._onMove=function(){Ui(this._map,this._container,this.options)},ji.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},ji.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},ji.prototype.setUnit=function(t){this.options.unit=t,Ui(this._map,this._container,this.options)};var qi=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\")};qi.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},qi.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},qi.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},qi.prototype._setupUI=function(){var e=this._fullscreenButton=r.create(\"button\",\"mapboxgl-ctrl-fullscreen\",this._controlContainer);r.create(\"span\",\"mapboxgl-ctrl-icon\",e).setAttribute(\"aria-hidden\",!0),e.type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},qi.prototype._updateTitle=function(){var t=this._getTitle();this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},qi.prototype._getTitle=function(){return this._map._getUIString(this._isFullscreen()?\"FullscreenControl.Exit\":\"FullscreenControl.Enter\")},qi.prototype._isFullscreen=function(){return this._fullscreen},qi.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-shrink\"),this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-fullscreen\"),this._updateTitle())},qi.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Hi={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Gi=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Hi),r),t.bindAll([\"_update\",\"_onClose\",\"remove\",\"_onMouseMove\",\"_onMouseUp\",\"_onDrag\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(e){return this._map&&this.remove(),this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClose),this.options.closeOnMove&&this._map.on(\"move\",this._onClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"mouseup\",this._onMouseUp),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"move\",this._onClose),this._map.off(\"click\",this._onClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\",this._onMouseMove),this._map.off(\"mouseup\",this._onMouseUp),this._map.off(\"drag\",this._onDrag),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\",this._onMouseMove),this._container&&this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this},n.prototype.trackPointer=function(){return this._trackPointer=!0,this._pos=null,this._update(),this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"drag\",this._onDrag),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container&&this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype.addClassName=function(t){this._container&&this._container.classList.add(t)},n.prototype.removeClassName=function(t){this._container&&this._container.classList.remove(t)},n.prototype.toggleClassName=function(t){if(this._container)return this._container.classList.toggle(t)},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClose))},n.prototype._onMouseUp=function(t){this._update(t.point)},n.prototype._onMouseMove=function(t){this._update(t.point)},n.prototype._onDrag=function(t){this._update(t.point)},n.prototype._update=function(e){var n=this;if(this._map&&(this._lngLat||this._trackPointer)&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach((function(t){return n._container.classList.add(t)})),this._trackPointer&&this._container.classList.add(\"mapboxgl-popup-track-pointer\")),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Li(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var i=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),a=this.options.anchor,o=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!a){var s,l=this._container.offsetWidth,c=this._container.offsetHeight;s=i.y+o.bottom.y<c?[\"top\"]:i.y>this._map.transform.height-c?[\"bottom\"]:[],i.x<l/2?s.push(\"left\"):i.x>this._map.transform.width-l/2&&s.push(\"right\"),a=0===s.length?\"bottom\":s.join(\"-\")}var u=i.add(o[a]).round();r.setTransform(this._container,Ii[a]+\" translate(\"+u.x+\"px,\"+u.y+\"px)\"),Pi(this._container,a,\"popup\")}},n.prototype._onClose=function(){this.remove()},n}(t.Evented),Yi={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,getRTLTextPluginStatus:t.getRTLTextPluginStatus,Map:Mi,NavigationControl:Ei,GeolocateControl:Bi,AttributionControl:vi,ScaleControl:ji,FullscreenControl:qi,Popup:Gi,Marker:Oi,Style:qe,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,prewarm:function(){Bt().acquire(Ot)},clearPrewarmedResources:function(){var t=Rt;t&&(t.isPreloaded()&&1===t.numActive()?(t.release(Ot),Rt=null):console.warn(\"Could not clear WebWorkers since there are active Map instances that still reference it. The pre-warmed WebWorker pool can only be cleared when all map instances have been removed with map.remove()\"))},get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return Dt.workerCount},set workerCount(t){Dt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Yi})),r}))},{}],474:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],f=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;f.push(a[u[s]].slice())}c.push(f)}return c}},{\"convex-hull\":135}],475:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),f=i(),h=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,m,v){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),m||(m=[0,0,0,1]),v||(v=[0,0,0,1]),!n(u,t))return!1;if(a(f,u),f[3]=0,f[7]=0,f[11]=0,f[15]=1,Math.abs(o(f)<1e-8))return!1;var y,x,b,_,w,T,k,M=u[3],A=u[7],S=u[11],E=u[12],C=u[13],L=u[14],I=u[15];if(0!==M||0!==A||0!==S){if(h[0]=M,h[1]=A,h[2]=S,h[3]=I,!s(f,f))return!1;l(f,f),y=m,b=f,_=(x=h)[0],w=x[1],T=x[2],k=x[3],y[0]=b[0]*_+b[4]*w+b[8]*T+b[12]*k,y[1]=b[1]*_+b[5]*w+b[9]*T+b[13]*k,y[2]=b[2]*_+b[6]*w+b[10]*T+b[14]*k,y[3]=b[3]*_+b[7]*w+b[11]*T+b[15]*k}else m[0]=m[1]=m[2]=0,m[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var P=0;P<3;P++)r[P]*=-1,p[P][0]*=-1,p[P][1]*=-1,p[P][2]*=-1;return v[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),v[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),v[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),v[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(v[0]=-v[0]),p[0][2]>p[2][0]&&(v[1]=-v[1]),p[1][0]>p[0][1]&&(v[2]=-v[2]),!0}},{\"./normalize\":476,\"gl-mat4/clone\":278,\"gl-mat4/create\":280,\"gl-mat4/determinant\":281,\"gl-mat4/invert\":293,\"gl-mat4/transpose\":306,\"gl-vec3/cross\":365,\"gl-vec3/dot\":370,\"gl-vec3/length\":380,\"gl-vec3/normalize\":387}],476:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],477:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=f(),c=f(),u=f();function f(){return{translate:h(),scale:h(1),skew:h(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function h(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,f){if(0===o(e)||0===o(r))return!1;var h=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!h||!p)&&(n(u.translate,l.translate,c.translate,f),n(u.skew,l.skew,c.skew,f),n(u.scale,l.scale,c.scale,f),n(u.perspective,l.perspective,c.perspective,f),s(u.quaternion,l.quaternion,c.quaternion,f),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),!0)}},{\"gl-mat4/determinant\":281,\"gl-vec3/lerp\":381,\"mat4-decompose\":475,\"mat4-recompose\":478,\"quat-slerp\":527}],478:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":280,\"gl-mat4/fromRotationTranslation\":284,\"gl-mat4/identity\":291,\"gl-mat4/multiply\":295,\"gl-mat4/scale\":303,\"gl-mat4/translate\":305}],479:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],480:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),f=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),h=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],h=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)h[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&h[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=h[c];else i(o,h,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],f(g,g);var m=this.computedInverse;a(m,o);var v=this.computedEye,y=m[15];v[0]=m[12]/y,v[1]=m[13]/y,v[2]=m[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=v[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||h,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":481,\"gl-mat4/invert\":293,\"gl-mat4/lookAt\":294,\"gl-mat4/rotateX\":300,\"gl-mat4/rotateY\":301,\"gl-mat4/rotateZ\":302,\"gl-mat4/scale\":303,\"gl-mat4/translate\":305,\"gl-vec3/normalize\":387,\"mat4-interpolate\":477}],481:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],482:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}var a=new Array(e);for(i=0;i<e;++i)a[i]=i;a.sort((function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]}));var o=[a[0],a[1]],s=[a[0],a[1]];for(i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}r=new Array(s.length+o.length-2);for(var f=0,h=(i=0,o.length);i<h;++i)r[f++]=o[i];for(var p=s.length-2;p>0;--p)r[f++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":548}],483:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function f(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function h(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function m(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",f),t.addEventListener(\"keyup\",h),t.addEventListener(\"keydown\",h),t.addEventListener(\"keypress\",h),t!==window&&(window.addEventListener(\"blur\",f),window.addEventListener(\"keyup\",h),window.addEventListener(\"keydown\",h),window.addEventListener(\"keypress\",h)))}m();var v={element:t};return Object.defineProperties(v,{enabled:{get:function(){return s},set:function(e){e?m():function(){if(!s)return;s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",f),t.removeEventListener(\"keyup\",h),t.removeEventListener(\"keydown\",h),t.removeEventListener(\"keypress\",h),t!==window&&(window.removeEventListener(\"blur\",f),window.removeEventListener(\"keyup\",h),window.removeEventListener(\"keydown\",h),window.removeEventListener(\"keypress\",h))}()},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),v};var n=t(\"mouse-event\")},{\"mouse-event\":485}],484:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],485:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],486:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=1;switch(t.deltaMode){case 1:s=i;break;case 2:s=window.innerHeight}if(a*=s,o*=s,(n*=s)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":578}],487:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function f(t){return\"p\"+t}function h(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function m(t){return\"y\"+t}function v(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var b=t.arrayArguments||1;b<1&&e(\"Must have at least one array argument\");var _=t.scalarArguments||0;_<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var w=t.getters||[],T=new Array(b),k=0;k<b;++k)w.indexOf(k)>=0?T[k]=!0:T[k]=!1;return function(t,e,r,b,_,w){var T=w.length,k=_.length;if(k<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var M=\"extractContour\"+_.join(\"_\"),A=[],S=[],E=[],C=0;C<T;++C)E.push(i(C));for(C=0;C<b;++C)E.push(u(C));for(C=0;C<k;++C)S.push(s(C)+\"=\"+i(0)+\".shape[\"+C+\"]|0\");for(C=0;C<T;++C){S.push(a(C)+\"=\"+i(C)+\".data\",c(C)+\"=\"+i(C)+\".offset|0\");for(var L=0;L<k;++L)S.push(l(C,L)+\"=\"+i(C)+\".stride[\"+L+\"]|0\")}for(C=0;C<T;++C){S.push(f(C)+\"=\"+c(C)),S.push(o(C,0));for(L=1;L<1<<k;++L){for(var I=[],P=0;P<k;++P)L&1<<P&&I.push(\"-\"+l(C,P));S.push(h(C,L)+\"=(\"+I.join(\"\")+\")|0\"),S.push(o(C,L)+\"=0\")}}for(C=0;C<T;++C)for(L=0;L<k;++L){var z=[l(C,_[L])];L>0&&z.push(l(C,_[L-1])+\"*\"+s(_[L-1])),S.push(d(C,_[L])+\"=(\"+z.join(\"-\")+\")|0\")}for(C=0;C<k;++C)S.push(p(C)+\"=0\");S.push(\"N=0\");var O=[\"2\"];for(C=k-2;C>=0;--C)O.push(s(_[C]));S.push(\"Q=(\"+O.join(\"*\")+\")|0\",\"P=mallocUint32(Q)\",\"V=mallocUint32(Q)\",\"X=0\"),S.push(g(0)+\"=0\");for(L=1;L<1<<k;++L){var D=[],R=[];for(P=0;P<k;++P)L&1<<P&&(0===R.length?D.push(\"1\"):D.unshift(R.join(\"*\"))),R.push(s(_[P]));var F=\"\";D[0].indexOf(s(_[k-2]))<0&&(F=\"-\");var B=x(k,L,_);S.push(v(B)+\"=(-\"+D.join(\"-\")+\")|0\",m(B)+\"=(\"+F+D.join(\"-\")+\")|0\",g(B)+\"=0\")}function N(t,e){A.push(\"for(\",p(_[t]),\"=\",e,\";\",p(_[t]),\"<\",s(_[t]),\";\",\"++\",p(_[t]),\"){\")}function j(t){for(var e=0;e<T;++e)A.push(f(e),\"+=\",d(e,_[t]),\";\");A.push(\"}\")}function U(){for(var t=1;t<1<<k;++t)A.push(\"T\",\"=\",v(t),\";\",v(t),\"=\",m(t),\";\",m(t),\"=\",\"T\",\";\")}S.push(y(0)+\"=0\",\"T=0\"),function t(e,r){if(e<0)!function(t){for(var e=0;e<T;++e)w[e]?A.push(o(e,0),\"=\",a(e),\".get(\",f(e),\");\"):A.push(o(e,0),\"=\",a(e),\"[\",f(e),\"];\");var r=[];for(e=0;e<T;++e)r.push(o(e,0));for(e=0;e<b;++e)r.push(u(e));A.push(g(0),\"=\",\"P\",\"[\",\"X\",\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<k;++n)A.push(g(n),\"=\",\"P\",\"[\",\"X\",\"+\",v(n),\"];\");var i=[];for(n=1;n<1<<k;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");A.push(\"if(\",i.join(\"||\"),\"){\");var s=[];for(e=0;e<k;++e)s.push(p(e));for(e=0;e<T;++e){s.push(o(e,0));for(n=1;n<1<<k;++n)w[e]?A.push(o(e,n),\"=\",a(e),\".get(\",f(e),\"+\",h(e,n),\");\"):A.push(o(e,n),\"=\",a(e),\"[\",f(e),\"+\",h(e,n),\"];\"),s.push(o(e,n))}for(e=0;e<1<<k;++e)s.push(g(e));for(e=0;e<b;++e)s.push(u(e));A.push(\"vertex(\",s.join(),\");\",y(0),\"=\",\"V\",\"[\",\"X\",\"]=\",\"N\",\"++;\");var l=(1<<k)-1,c=g(l);for(n=0;n<k;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,m=g(d),x=[],_=d;_>0;_=_-1&d)x.push(\"V[X+\"+v(_)+\"]\");x.push(y(0));for(_=0;_<T;++_)1&n?x.push(o(_,l),o(_,d)):x.push(o(_,d),o(_,l));1&n?x.push(c,m):x.push(m,c);for(_=0;_<b;++_)x.push(u(_));A.push(\"if(\",c,\"!==\",m,\"){\",\"face(\",x.join(),\")}\")}A.push(\"}\",\"X\",\"+=1;\")}(r);else{!function(t){for(var e=t-1;e>=0;--e)N(e,0);var r=[];for(e=0;e<T;++e)w[e]?r.push(a(e)+\".get(\"+f(e)+\")\"):r.push(a(e)+\"[\"+f(e)+\"]\");for(e=0;e<b;++e)r.push(u(e));for(A.push(\"P\",\"[\",\"X\",\"++]=phase(\",r.join(),\");\"),e=0;e<t;++e)j(e);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[t]),\";\")}(e),A.push(\"if(\",s(_[e]),\">0){\",p(_[e]),\"=1;\"),t(e-1,r|1<<_[e]);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[e]),\";\");e===k-1&&(A.push(\"X\",\"=0;\"),U()),N(e,2),t(e-1,r),e===k-1&&(A.push(\"if(\",p(_[k-1]),\"&1){\",\"X\",\"=0;}\"),U()),j(e),A.push(\"}\")}}(k-1,0),A.push(\"freeUint32(\",\"V\",\");freeUint32(\",\"P\",\");\");var V=[\"'use strict';\",\"function \",M,\"(\",E.join(),\"){\",\"var \",S.join(),\";\",A.join(\"\"),\"}\",\"return \",M].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",V)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,_,r,T)};function x(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":595}],488:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(v=o[e])return v;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(l=0;l<e.length;++l){var u=Math.abs(e[l])-1,f=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var h=s.slice(),p=s.slice();e[l]<0?h[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",h.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",f,\",src.pick(\",h.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",f,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",f,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",f,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",f,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var f=[],h=0;h<r;++h)s&1<<h&&f.push(h+1);for(var p=0;p<1<<f.length;++p){var d=f.slice();for(h=0;h<f.length;++h)p&1<<h&&(d[h]=-d[h]);i(d)}}n.push(\"return dst;};return gradient\");var g=[\"diff\",\"zero\"],m=[l,c];for(s=1;s<=r;++s)g.push(\"grad\"+s),m.push(u(s));g.push(n.join(\"\"));var v=Function.apply(void 0,g).apply(void 0,m);return a[e]=v,v}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map((function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}})),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":151,dup:176}],489:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],f=a&&c?t.get(n,s):0,h=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*f+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*h+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],f=0<=l+1&&l+1<t.shape[1],h=Math.floor(n),p=n-h,d=0<=h&&h<t.shape[2],g=0<=h+1&&h+1<t.shape[2],m=o&&u&&d?t.get(i,l,h):0,v=o&&f&&d?t.get(i,l+1,h):0,y=s&&u&&d?t.get(i+1,l,h):0,x=s&&f&&d?t.get(i+1,l+1,h):0,b=o&&u&&g?t.get(i,l,h+1):0,_=o&&f&&g?t.get(i,l+1,h+1):0;return(1-p)*((1-c)*((1-a)*m+a*y)+c*((1-a)*v+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,h+1):0))+c*((1-a)*_+a*(s&&f&&g?t.get(i+1,l+1,h+1):0)))}function o(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,f=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}f+=c*t.data[u]}return f}e.exports=function(t,e,r,s){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,s);default:return o.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],490:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var f=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var h=[\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":151}],491:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":492,ndarray:495}],492:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":151}],493:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l){0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p))}var f=-1,h=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(f>0?s.push([\"d\",d,\"=s\",d,\"-d\",f,\"*n\",f].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),f=d),0!==(p=t.length-1-l)&&(h>0?s.push([\"e\",p,\"=s\",p,\"-e\",h,\"*n\",h,\",f\",p,\"=\",c[p],\"-f\",h,\"*n\",h].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),h=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var m=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),v=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function f(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function h(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){r.push(\"dptr=0;sptr=ptr\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(\"scratch[dptr++]=\",f(\"sptr\"));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\")}r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\");for(u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));r.push([\"a=\",f(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\"));for(u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");r.push(\"dptr=cptr;sptr=cptr-s0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",f(\"sptr\")));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\")}r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",\"scratch[sptr++]\"));for(u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+f(\"ptr\"),\"while((j--\\x3eleft)&&(\"+f(\"cptr-s0\")+\">scratch)){\",h(\"cptr\",f(\"cptr-s0\")),\"cptr-=s0\",\"}\",h(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var f=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var h=[],p=1;p<t.length;++p)h.push(\"n\"+p),f.push(\"i\"+p);for(p=0;p<8;++p)f.push(\"b_ptr\"+p);f.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+h.join(\"*\")),c?f.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):f.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else f.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function m(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function v(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\");for(a=t.length-1;a>=0;--a){0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"))}if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));n.push(i),r&&n.push(\"++pivot_ptr\");for(a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\");for(o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));n.push(a);for(o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?v([e,r],!1,m(\"ptr0\",g(\"ptr1\"))):n.push(m(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function T(e,r){t.length>1?v([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\"))}function k(e,r,i){t.length>1?(v([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\"))}function M(t,e){T(t,e),n.push(\"--\"+e)}function A(e,r,i){t.length>1?v([e,r],!0,[m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(m(d(e),g(d(r))),m(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),v([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+f.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?v([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",m(\"ptr5\",\"x\"),\"\\n\",m(\"ptr6\",\"y\"),\"\\n\",m(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",m(d(\"index1\"),\"x\"),\"\\n\",m(d(\"index3\"),\"y\"),\"\\n\",m(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),A(\"left\",\"(less-1)\",1),A(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,v);return m(v,y)}},{\"typedarray-pool\":595}],494:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":493}],495:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map((function(t){return\"i\"+t})),u=\"this.offset+\"+o.map((function(t){return\"this.stride[\"+t+\"]*i\"+t})).join(\"+\"),f=o.map((function(t){return\"b\"+t})).join(\",\"),h=o.map((function(t){return\"c\"+t})).join(\",\");a.push(\"function \"+r+\"(a,\"+f+\",\"+h+\",d){this.data=a\",\"this.shape=[\"+f+\"]\",\"this.stride=[\"+h+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map((function(t){return\"this.shape[\"+t+\"]\"})).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map((function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")})).join(\",\")+\",\"+o.map((function(t){return\"this.stride[\"+t+\"]\"})).join(\",\")+\",this.offset)}\");var p=o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})),d=o.map((function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"}));a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"c\"+t})).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"})).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t})).join(\",\")+\",c)}\");var m=new Array(e),v=new Array(e);for(g=0;g<e;++g)m[g]=\"a[i\"+g+\"]\",v[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map((function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"})).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+m.join(\",\")+\",\"+v.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map((function(t){return\"shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"stride[\"+t+\"]\"})).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],bigint64:[],biguint64:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n){n=0;for(s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s])}for(var f=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\";case\"[object BigInt64Array]\":return\"bigint64\";case\"[object BigUint64Array]\":return\"biguint64\"}return Array.isArray(t)?\"array\":\"generic\"}(t),h=c[f];h.length<=o+1;)h.push(l(f,h.length-1));return(0,h[o+1])(t,e,r,n)}},{\"iota-array\":463,\"is-buffer\":465}],496:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074);e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),a=n.lo(t);e>t==t>0?a===-1>>>0?(r+=1,a=0):a+=1:0===a?(a=-1>>>0,r-=1):a-=1;return n.pack(a,r)}},{\"double-bits\":173}],497:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,f,h,p){if(p)T=p[0],k=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(f=(d=l(f,h,-o)).x))/2,m=(e-(h=d.y))/2,v=g*g/(r*r)+m*m/(a*a);v>1&&(r*=v=Math.sqrt(v),a*=v);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*m*m-x*g*g)/(y*m*m+x*g*g)));b==1/0&&(b=1);var _=b*r*m/a+(t+f)/2,w=b*-a*g/r+(e+h)/2,T=Math.asin(((e-w)/a).toFixed(9)),k=Math.asin(((h-w)/a).toFixed(9));(T=t<_?n-T:T)<0&&(T=2*n+T),(k=f<_?n-k:k)<0&&(k=2*n+k),u&&T>k&&(T-=2*n),!u&&k>T&&(k-=2*n)}if(Math.abs(k-T)>i){var M=k,A=f,S=h;k=T+i*(u&&k>T?1:-1);var E=s(f=_+r*Math.cos(k),h=w+a*Math.sin(k),r,a,o,0,u,A,S,[k,M,_,w])}var C=Math.tan((k-T)/4),L=4/3*r*C,I=4/3*a*C,P=[2*t-(t+L*Math.sin(T)),2*e-(e-I*Math.cos(T)),f+L*Math.sin(k),h-I*Math.cos(k),f,h];if(p)return P;E&&(P=P.concat(E));for(var z=0;z<P.length;){var O=l(P[z],P[z+1],o);P[z++]=O.x,P[z++]=O.y}return P}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,f=null,h=null,p=0,d=0,g=0,m=t.length;g<m;g++){var v=t[g],y=v[0];switch(y){case\"M\":l=v[1],u=v[2];break;case\"A\":(v=s(p,d,v[1],v[2],c(v[3]),v[4],v[5],v[6],v[7])).unshift(\"C\"),v.length>7&&(r.push(v.splice(0,7)),v.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),v=[\"C\",x,b,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(f=2*p-f,h=2*d-h):(f=p,h=d),v=o(p,d,f,h,v[1],v[2]);break;case\"Q\":f=v[1],h=v[2],v=o(p,d,v[1],v[2],v[3],v[4]);break;case\"L\":v=a(p,d,v[1],v[2]);break;case\"H\":v=a(p,d,v[1],d);break;case\"V\":v=a(p,d,p,v[1]);break;case\"Z\":v=a(p,d,l,u)}e=y,p=v[v.length-2],d=v[v.length-1],v.length>4?(n=v[v.length-4],i=v[v.length-3]):(n=p,i=d),r.push(v)}return r}},{}],498:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],f=0;f<s.length;++f){l=c,c=u,u=s[(f+1)%s.length];for(var h=e[l],p=e[c],d=e[u],g=new Array(3),m=0,v=new Array(3),y=0,x=0;x<3;++x)g[x]=h[x]-p[x],m+=g[x]*g[x],v[x]=d[x]-p[x],y+=v[x]*v[x];if(m*y>a){var b=i[c],_=1/Math.sqrt(m*y);for(x=0;x<3;++x){var w=(x+1)%3,T=(x+2)%3;b[x]+=_*(v[w]*g[T]-v[T]*g[w])}}}for(o=0;o<n;++o){b=i[o];var k=0;for(x=0;x<3;++x)k+=b[x]*b[x];if(k>a)for(_=1/Math.sqrt(k),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),f=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],f[c]=l[2][c]-l[0][c];var h=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;h[c]=u[d]*f[g]-u[g]*f[d],p+=h[c]*h[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)h[c]*=p;i[o]=h}return i}},{}],499:[function(t,e,r){\n",
       "/*\n",
       "object-assign\n",
       "(c) Sindre Sorhus\n",
       "@license MIT\n",
       "*/\n",
       "\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;function o(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map((function(t){return e[t]})).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach((function(t){n[t]=t})),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,s,l=o(t),c=1;c<arguments.length;c++){for(var u in r=Object(arguments[c]))i.call(r,u)&&(l[u]=r[u]);if(n){s=n(r);for(var f=0;f<s.length;f++)a.call(r,s[f])&&(l[s[f]]=r[s[f]])}}return l}},{}],500:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(f>0){var f=Math.sqrt(u+1);t[0]=.5*(o-l)/f,t[1]=.5*(s-n)/f,t[2]=.5*(r-a)/f,t[3]=.5*f}else{var h=Math.max(e,a,c);f=Math.sqrt(2*h-u+1);e>=h?(t[0]=.5*f,t[1]=.5*(i+r)/f,t[2]=.5*(s+n)/f,t[3]=.5*(o-l)/f):a>=h?(t[0]=.5*(r+i)/f,t[1]=.5*f,t[2]=.5*(l+o)/f,t[3]=.5*(s-n)/f):(t[0]=.5*(n+s)/f,t[1]=.5*(o+l)/f,t[2]=.5*f,t[3]=.5*(r-i)/f)}return t}},{}],501:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new f(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function f(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var h=f.prototype;h.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},h.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,f=0;f<3;++f)c+=r[l+4*f]*i[f];r[12+l]=-c}},h.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},h.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},h.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},h.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=l(u-=a*p,f-=o*p,h-=s*p);u/=d,f/=d,h/=d;var g=i[2],m=i[6],v=i[10],y=g*a+m*o+v*s,x=g*u+m*f+v*h,b=l(g-=y*a+x*u,m-=y*o+x*f,v-=y*s+x*h);g/=b,m/=b,v/=b;var _=u*e+a*r,w=f*e+o*r,T=h*e+s*r;this.center.move(t,_,w,T);var k=Math.exp(this.computedRadius[0]);k=Math.max(1e-4,k+n),this.radius.set(t,Math.log(k))},h.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],f=i[5],h=i[9],p=i[2],d=i[6],g=i[10],m=e*a+r*u,v=e*o+r*f,y=e*s+r*h,x=-(d*y-g*v),b=-(g*m-p*y),_=-(p*v-d*m),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),T=c(x,b,_,w);T>1e-6?(x/=T,b/=T,_/=T,w/=T):(x=b=_=0,w=1);var k=this.computedRotation,M=k[0],A=k[1],S=k[2],E=k[3],C=M*w+E*x+A*_-S*b,L=A*w+E*b+S*x-M*_,I=S*w+E*_+M*b-A*x,P=E*w-M*x-A*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,P=P*(w=Math.cos(e))-(C=C*w+P*x+L*_-I*b)*x-(L=L*w+P*b+I*x-C*_)*b-(I=I*w+P*_+C*b-L*x)*_}var O=c(C,L,I,P);O>1e-6?(C/=O,L/=O,I/=O,P/=O):(C=L=I=0,P=1),this.rotation.set(t,C,L,I,P)},h.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},h.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},h.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var f=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*f,l-n[6]*f,c-n[10]*f),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},h.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},h.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},h.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},h.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},h.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":500,\"filtered-vector\":242,\"gl-mat4/fromQuat\":282,\"gl-mat4/invert\":293,\"gl-mat4/lookAt\":294}],502:[function(t,e,r){\n",
       "/*!\n",
       " * pad-left <https://github.com/jonschlinkert/pad-left>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT license.\n",
       " */\n",
       "\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":541}],503:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach((function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach((function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t})),n=n.reverse(),r=r.map((function(e){return n.forEach((function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])})),e}))}));var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce((function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r}),\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],504:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":511}],505:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,(function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}})),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],506:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],507:[function(t,e,r){(function(t){(function(){\"use strict\";function r(t){if(\"string\"!=typeof t)throw new TypeError(\"Path must be a string. Received \"+JSON.stringify(t))}function n(t,e){for(var r,n=\"\",i=0,a=-1,o=0,s=0;s<=t.length;++s){if(s<t.length)r=t.charCodeAt(s);else{if(47===r)break;r=47}if(47===r){if(a===s-1||1===o);else if(a!==s-1&&2===o){if(n.length<2||2!==i||46!==n.charCodeAt(n.length-1)||46!==n.charCodeAt(n.length-2))if(n.length>2){var l=n.lastIndexOf(\"/\");if(l!==n.length-1){-1===l?(n=\"\",i=0):i=(n=n.slice(0,l)).length-1-n.lastIndexOf(\"/\"),a=s,o=0;continue}}else if(2===n.length||1===n.length){n=\"\",i=0,a=s,o=0;continue}e&&(n.length>0?n+=\"/..\":n=\"..\",i=2)}else n.length>0?n+=\"/\"+t.slice(a+1,s):n=t.slice(a+1,s),i=s-a-1;a=s,o=0}else 46===r&&-1!==o?++o:o=-1}return n}var i={resolve:function(){for(var e,i=\"\",a=!1,o=arguments.length-1;o>=-1&&!a;o--){var s;o>=0?s=arguments[o]:(void 0===e&&(e=t.cwd()),s=e),r(s),0!==s.length&&(i=s+\"/\"+i,a=47===s.charCodeAt(0))}return i=n(i,!a),a?i.length>0?\"/\"+i:\"/\":i.length>0?i:\".\"},normalize:function(t){if(r(t),0===t.length)return\".\";var e=47===t.charCodeAt(0),i=47===t.charCodeAt(t.length-1);return 0!==(t=n(t,!e)).length||e||(t=\".\"),t.length>0&&i&&(t+=\"/\"),e?\"/\"+t:t},isAbsolute:function(t){return r(t),t.length>0&&47===t.charCodeAt(0)},join:function(){if(0===arguments.length)return\".\";for(var t,e=0;e<arguments.length;++e){var n=arguments[e];r(n),n.length>0&&(void 0===t?t=n:t+=\"/\"+n)}return void 0===t?\".\":i.normalize(t)},relative:function(t,e){if(r(t),r(e),t===e)return\"\";if((t=i.resolve(t))===(e=i.resolve(e)))return\"\";for(var n=1;n<t.length&&47===t.charCodeAt(n);++n);for(var a=t.length,o=a-n,s=1;s<e.length&&47===e.charCodeAt(s);++s);for(var l=e.length-s,c=o<l?o:l,u=-1,f=0;f<=c;++f){if(f===c){if(l>c){if(47===e.charCodeAt(s+f))return e.slice(s+f+1);if(0===f)return e.slice(s+f)}else o>c&&(47===t.charCodeAt(n+f)?u=f:0===f&&(u=0));break}var h=t.charCodeAt(n+f);if(h!==e.charCodeAt(s+f))break;47===h&&(u=f)}var p=\"\";for(f=n+u+1;f<=a;++f)f!==a&&47!==t.charCodeAt(f)||(0===p.length?p+=\"..\":p+=\"/..\");return p.length>0?p+e.slice(s+u):(s+=u,47===e.charCodeAt(s)&&++s,e.slice(s))},_makeLong:function(t){return t},dirname:function(t){if(r(t),0===t.length)return\".\";for(var e=t.charCodeAt(0),n=47===e,i=-1,a=!0,o=t.length-1;o>=1;--o)if(47===(e=t.charCodeAt(o))){if(!a){i=o;break}}else a=!1;return-1===i?n?\"/\":\".\":n&&1===i?\"//\":t.slice(0,i)},basename:function(t,e){if(void 0!==e&&\"string\"!=typeof e)throw new TypeError('\"ext\" argument must be a string');r(t);var n,i=0,a=-1,o=!0;if(void 0!==e&&e.length>0&&e.length<=t.length){if(e.length===t.length&&e===t)return\"\";var s=e.length-1,l=-1;for(n=t.length-1;n>=0;--n){var c=t.charCodeAt(n);if(47===c){if(!o){i=n+1;break}}else-1===l&&(o=!1,l=n+1),s>=0&&(c===e.charCodeAt(s)?-1==--s&&(a=n):(s=-1,a=l))}return i===a?a=l:-1===a&&(a=t.length),t.slice(i,a)}for(n=t.length-1;n>=0;--n)if(47===t.charCodeAt(n)){if(!o){i=n+1;break}}else-1===a&&(o=!1,a=n+1);return-1===a?\"\":t.slice(i,a)},extname:function(t){r(t);for(var e=-1,n=0,i=-1,a=!0,o=0,s=t.length-1;s>=0;--s){var l=t.charCodeAt(s);if(47!==l)-1===i&&(a=!1,i=s+1),46===l?-1===e?e=s:1!==o&&(o=1):-1!==e&&(o=-1);else if(!a){n=s+1;break}}return-1===e||-1===i||0===o||1===o&&e===i-1&&e===n+1?\"\":t.slice(e,i)},format:function(t){if(null===t||\"object\"!=typeof t)throw new TypeError('The \"pathObject\" argument must be of type Object. Received type '+typeof t);return function(t,e){var r=e.dir||e.root,n=e.base||(e.name||\"\")+(e.ext||\"\");return r?r===e.root?r+n:r+t+n:n}(\"/\",t)},parse:function(t){r(t);var e={root:\"\",dir:\"\",base:\"\",ext:\"\",name:\"\"};if(0===t.length)return e;var n,i=t.charCodeAt(0),a=47===i;a?(e.root=\"/\",n=1):n=0;for(var o=-1,s=0,l=-1,c=!0,u=t.length-1,f=0;u>=n;--u)if(47!==(i=t.charCodeAt(u)))-1===l&&(c=!1,l=u+1),46===i?-1===o?o=u:1!==f&&(f=1):-1!==o&&(f=-1);else if(!c){s=u+1;break}return-1===o||-1===l||0===f||1===f&&o===l-1&&o===s+1?-1!==l&&(e.base=e.name=0===s&&a?t.slice(1,l):t.slice(s,l)):(0===s&&a?(e.name=t.slice(1,o),e.base=t.slice(1,l)):(e.name=t.slice(s,o),e.base=t.slice(s,l)),e.ext=t.slice(o,l)),s>0?e.dir=t.slice(0,s-1):a&&(e.dir=\"/\"),e},sep:\"/\",delimiter:\":\",win32:null,posix:null};i.posix=i,e.exports=i}).call(this)}).call(this,t(\"_process\"))},{_process:526}],508:[function(t,e,r){(function(t){(function(){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this)}).call(this,t(\"_process\"))},{_process:526}],509:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<32){for(var r=1,i=0;i<e;++i)for(var a=0;a<i;++a)if(t[i]<t[a])r=-r;else if(t[i]===t[a])return 0;return r}var o=n.mallocUint8(e);for(i=0;i<e;++i)o[i]=0;for(r=1,i=0;i<e;++i)if(!o[i]){var s=1;o[i]=1;for(a=t[i];a!==i;a=t[a]){if(o[a])return n.freeUint8(o),0;s+=1,o[a]=1}1&s||(r=-r)}return n.freeUint8(o),r};var n=t(\"typedarray-pool\")},{\"typedarray-pool\":595}],510:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":462,\"typedarray-pool\":595}],511:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var f=a;f<c.length;f++)l[c[f]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],512:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}var l=[];for(o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var f=0;f<2;++f)for(var h=a[f][r],p=0;p<h.length;++p){var d=h[p],g=d[1^f];n(e[t],e[r],e[s],e[g])>0&&(o=d,s=g,l=f)}return i||o&&c(o,l),s}function f(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],f=t,h=o[1],p=u(l,f,!0);if(n(e[l],e[f],e[h],e[p])<0)break;o.push(t),s=u(l,f)}return o}function h(t,e){return e[1]===e[e.length-1]}for(o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=f(o,p);h(0,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":132}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;var u=r[c];for(s=0;s<u.length;++s){var f=u[s];0==--a[f]&&o.push(f)}}var h=new Array(e.length),p=[];for(s=0;s<e.length;++s)if(i[s]){c=p.length;h[s]=c,p.push(e[s])}else h[s]=-1;var d=[];for(s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([h[g[0]],h[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":178}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var f=(e=r[1]).length,h=(t.length,n(t,e.length)),p=0;p<f;++p)if(h[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);var g=(d=d.filter((function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),f=o(l[0],a[1]),h=o(l[0],l[1]);n=s(n,s(s(c,u),s(f,h)))}return n[n.length-1]>0}))).length,m=new Array(g),v=new Array(g);for(p=0;p<g;++p){m[p]=p;var y=new Array(g),x=d[p].map((function(t){return e[t]})),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var T=(q=d[w]).length,k=0;k<T;++k){var M=b(e[q[k]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}v[p]=[_,p,y]}v.sort((function(t,e){return e[0]-t[0]}));for(p=0;p<g;++p){var A=(y=v[p])[1],S=y[2];for(w=0;w<g;++w)S[w]&&(m[w]=A)}var E=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g);for(p=0;p<g;++p)E[p].push(m[p]),E[m[p]].push(p);var C={},L=u(f,!1);for(p=0;p<g;++p)for(T=(q=d[p]).length,w=0;w<T;++w){var I=q[w],P=q[(w+1)%T],z=Math.min(I,P)+\":\"+Math.max(I,P);if(z in C){var O=C[z];E[O].push(p),E[p].push(O),L[I]=L[P]=!0}else C[z]=p}function D(t){for(var e=t.length,r=0;r<e;++r)if(!L[t[r]])return!1;return!0}var R=[],F=u(g,-1);for(p=0;p<g;++p)m[p]!==p||D(d[p])?F[p]=-1:(R.push(p),F[p]=0);r=[];for(;R.length>0;){var B=R.pop(),N=E[B];l(N,(function(t,e){return t-e}));var j,U=N.length,V=F[B];if(0===V){var q=d[B];j=[q]}for(p=0;p<U;++p){var H=N[p];if(!(F[H]>=0))if(F[H]=1^V,R.push(H),0===V)D(q=d[H])||(q.reverse(),j.push(q))}0===V&&r.push(j)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":513,\"edges-to-adjacency-list\":178,\"planar-dual\":512,\"point-in-big-polygon\":516,\"robust-sum\":553,\"two-product\":582,uniq:597}],515:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],516:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],f=u.length,h=f-1,p=0;p<f;h=p++){var d=u[h],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(m=l(a),function(t){return m(t[0],t[1])?0:1});var m;var v=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(v.slabs,v.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},f=Object.keys(e);for(r=0;r<f.length;++r){var h=e[f[r]];u[f[r]]=a(h)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":515,\"interval-tree-1d\":460,\"robust-orientation\":548,\"slab-decomposition\":565}],517:[function(t,e,r){\n",
       "/*\n",
       " * @copyright 2016 Sean Connelly (@voidqk), http://syntheti.cc\n",
       " * @license MIT\n",
       " * @preserve Project Home: https://github.com/voidqk/polybooljs\n",
       " */\n",
       "var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,f=a();function h(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return f.epsilon(t)},segments:function(t){var e=o(!0,f,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,f,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,f,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,f,t)},union:function(t,e){return h(t,e,n.selectUnion)},intersect:function(t,e){return h(t,e,n.selectIntersect)},difference:function(t,e){return h(t,e,n.selectDifference)},differenceRev:function(t,e){return h(t,e,n.selectDifferenceRev)},xor:function(t,e){return h(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":518,\"./lib/epsilon\":519,\"./lib/geojson\":520,\"./lib/intersecter\":521,\"./lib/segment-chainer\":523,\"./lib/segment-selector\":524}],518:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],519:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t)&&!(l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],f=e[1]-n[1],h=(s*f-l*u)/c,p=(a*f-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+h*a,e[1]+h*o]};return d.alongA=h<=-t?-2:h<t?-1:h-1<=-t?0:h-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],520:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function f(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(h(t.children[r]))}function h(t){for(var e=0;e<t.children.length;e++)f(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)f(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],521:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,(function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0}))}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition((function(r){var n,i,a,o,s,l;return(n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)||e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0}))}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var f=e.linesIntersect(o,s,c,u);if(!1===f){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var h=e.pointsSame(o,c),p=e.pointsSame(s,u);if(h&&p)return n;var d=!h&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(h)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===f.alongA&&(-1===f.alongB?l(t,c):0===f.alongB?l(t,f.pt):1===f.alongB&&l(t,u)),0===f.alongB&&(-1===f.alongA?l(n,o):0===f.alongA?l(n,f.pt):1===f.alongA&&l(n,s));return!1}for(var f=[];!a.isEmpty();){var h=a.getHead();if(r&&r.vert(h.pt[0]),h.isStart){r&&r.segmentNew(h.seg,h.primary);var p=c(h),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function m(){if(d){var t=u(h,d);if(t)return t}return!!g&&u(h,g)}r&&r.tempStatus(h.seg,!!d&&d.seg,!!g&&g.seg);var v,y=m();if(y){var x;if(t)(x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below)&&(y.seg.myFill.above=!y.seg.myFill.above);else y.seg.otherFill=h.seg.myFill;r&&r.segmentUpdate(y.seg),h.other.remove(),h.remove()}if(a.getHead()!==h){r&&r.rewind(h.seg);continue}if(t)x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below,h.seg.myFill.below=g?g.seg.myFill.above:i,h.seg.myFill.above=x?!h.seg.myFill.below:h.seg.myFill.below;else if(null===h.seg.otherFill)v=g?h.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:h.primary?o:i,h.seg.otherFill={above:v,below:v};r&&r.status(h.seg,!!d&&d.seg,!!g&&g.seg),h.other.status=p.insert(n.node({ev:h}))}else{var b=h.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!h.primary){var _=h.seg.myFill;h.seg.myFill=h.seg.otherFill,h.seg.otherFill=_}f.push(h.seg)}a.getHead().remove()}return r&&r.done(),f}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach((function(t){s(i(t.start,t.end,t),!0)})),r.forEach((function(t){s(i(t.start,t.end,t),!1)})),c(e,n)}}}},{\"./linked-list\":522}],522:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],523:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach((function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var f=(m=n[u])[0],h=(m[1],m[m.length-1]);m[m.length-2];if(e.pointsSame(f,a)){if(k(u,!0,!0))break}else if(e.pointsSame(f,o)){if(k(u,!0,!1))break}else if(e.pointsSame(h,a)){if(k(u,!1,!0))break}else if(e.pointsSame(h,o)&&k(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,m=n[p],v=g?m[0]:m[m.length-1],y=g?m[1]:m[m.length-2],x=g?m[m.length-1]:m[0],b=g?m[m.length-2]:m[1];return e.pointsCollinear(y,v,d)&&(g?(r&&r.chainRemoveHead(s.index,d),m.shift()):(r&&r.chainRemoveTail(s.index,d),m.pop()),v=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,v)&&(g?(r&&r.chainRemoveTail(s.index,v),m.pop()):(r&&r.chainRemoveHead(s.index,v),m.shift())),r&&r.chainClose(s.index),void i.push(m)):void(g?(r&&r.chainAddHead(s.index,d),m.unshift(d)):(r&&r.chainAddTail(s.index,d),m.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var T=n[_].length<n[w].length;s.matches_head?l.matches_head?T?(M(_),A(_,w)):(M(w),A(w,_)):A(w,_):l.matches_head?A(_,w):T?(M(_),A(w,_)):(M(w),A(_,w))}function k(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function M(t){r&&r.chainReverse(t),n[t].reverse()}function A(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}})),i}},{}],524:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach((function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})})),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],525:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,f=0,h=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],m=a[l],v=n[l];c+=g*g,u+=g*m,f+=m*m,h+=v*g,p+=v*m,d+=v*v}var y,x,b,_,w,T=Math.abs(c*f-u*u),k=u*p-f*h,M=u*h-c*p;if(k+M<=T)if(k<0)M<0&&h<0?(M=0,-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d):(k=0,p>=0?(M=0,y=d):-p>=f?(M=1,y=f+2*p+d):y=p*(M=-p/f)+d);else if(M<0)M=0,h>=0?(k=0,y=d):-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d;else{var A=1/T;y=(k*=A)*(c*k+u*(M*=A)+2*h)+M*(u*k+f*M+2*p)+d}else k<0?(b=f+p)>(x=u+h)?(_=b-x)>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d:(k=0,b<=0?(M=1,y=f+2*p+d):p>=0?(M=0,y=d):y=p*(M=-p/f)+d):M<0?(b=c+h)>(x=u+p)?(_=b-x)>=(w=c-2*u+f)?(M=1,k=0,y=f+2*p+d):y=(k=1-(M=_/w))*(c*k+u*M+2*h)+M*(u*k+f*M+2*p)+d:(M=0,b<=0?(k=1,y=c+2*h+d):h>=0?(k=0,y=d):y=h*(k=-h/c)+d):(_=f+p-u-h)<=0?(k=0,M=1,y=f+2*p+d):_>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d;var S=1-k-M;for(l=0;l<o.length;++l)s[l]=S*t[l]+k*e[l]+M*r[l];return y<0?0:y}},{}],526:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],f=!1,h=-1;function p(){f&&c&&(f=!1,c.length?u=c.concat(u):h=-1,u.length&&d())}function d(){if(!f){var t=l(p);f=!0;for(var e=u.length;e;){for(c=u,u=[];++h<e;)c&&c[h].run();h=-1,e=u.length}c=null,f=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function m(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||f||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=m,a.addListener=m,a.once=m,a.off=m,a.removeListener=m,a.removeAllListeners=m,a.emit=m,a.prependListener=m,a.prependOnceListener=m,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],527:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":325}],528:[function(t,e,r){(function(r){(function(){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,f=0,h=[];s=function(t){if(0===h.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout((function(){var t=h.slice(0);h.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout((function(){throw t}),0)}}),Math.round(r))}return h.push({handle:++f,callback:t,cancelled:!1}),f},l=function(t){for(var e=0;e<h.length;e++)h[e].handle===t&&(h[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":508}],529:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":80}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":83}],531:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":83,\"big-rat/mul\":92}],532:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":94}],533:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":117,\"compare-cell\":133,\"compare-oriented-cell\":134}],534:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,f=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,m,v=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),m=t.buffer({usage:\"static\",type:\"float\",data:h}),T(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:m,stride:24,offset:0},lineOffset:{buffer:m,stride:24,offset:8},capOffset:{buffer:m,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:h.length}),s(b,{update:T,draw:_,destroy:k,regl:t,gl:v,canvas:v.canvas,groups:x}),b;function b(t){t?T(t):null===t&&k(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach((function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)}))}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function T(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map((function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=f(e.scale),e.translateFract=f(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:v.drawingBufferWidth,height:v.drawingBufferHeight},e}}]),u):u})),e||r){var h=x.reduce((function(t,e,r){return t+(e?e.count:0)}),0),m=new Float64Array(2*h),_=new Uint8Array(4*h),w=new Float32Array(4*h);x.forEach((function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),m.set(r,2*i))}})),c(u(m)),p(f(m)),d(_),g(w)}}}function k(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),m.destroy()}};var h=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":70,\"color-normalize\":125,\"flatten-vertex-data\":244,\"object-assign\":499,\"pick-by-alias\":511,\"to-float32\":577,\"update-diff\":599}],535:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),f=t(\"to-float32\"),h=f.float32,p=f.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function m(t,e){if(!(this instanceof m))return new m(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=m.shaders.has(t)?m.shaders.get(t):m.shaders.set(t,m.createShaders(t)).get(t),this.update(e)}e.exports=m,m.dashMult=2,m.maxPatternLength=256,m.precisionThreshold=3e6,m.maxPoints=1e4,m.maxLines=2048,m.shaders=new d,m.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},m.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},m.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},m.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach((function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>m.precisionThreshold||e.scale[1]*e.viewport.height>m.precisionThreshold||\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=m.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))})),this},m.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach((function(t,f){var d=e.passes[f];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[f]=d={id:f,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},m.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,f<m.maxLines&&(d.depth=2*(m.maxLines-1-f%m.maxLines)/m.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var v,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),v=new Float64Array(2*y);for(var _=0;_<y;_++)v[2*_]=x[_],v[2*_+1]=b[_]}else v=l(t.positions,\"float64\"),y=d.count=Math.floor(v.length/2);var w=d.bounds=i(v,2);if(d.fill){for(var T=[],k={},M=0,A=0,S=0,E=d.count;A<E;A++){var C=v[2*A],L=v[2*A+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=v[2*M],L=v[2*M+1],k[A]=M):M=A,T[S++]=C,T[S++]=L}for(var I=c(T,d.hole||[]),P=0,z=I.length;P<z;P++)null!=k[I[P]]&&(I[P]=k[I[P]]);d.triangles=I}var O=new Float64Array(v);u(O,2,w);var D=new Float64Array(2*y+6);d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[0]=O[2*y-4],D[1]=O[2*y-3]):(D[0]=O[2*y-2],D[1]=O[2*y-1]):(D[0]=O[0],D[1]=O[1]),D.set(O,2),d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[2*y+2]=O[2],D[2*y+3]=O[3],d.count-=1):(D[2*y+2]=O[0],D[2*y+3]=O[1],D[2*y+4]=O[2],D[2*y+5]=O[3]):(D[2*y+2]=O[2*y-2],D[2*y+3]=O[2*y-1],D[2*y+4]=O[2*y-2],D[2*y+5]=O[2*y-1]),d.positionBuffer(h(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*m.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*m.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var Q=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var $=0;$<J;$++){var tt=n(K[$],\"uint8\");Q.set(tt,4*$)}Q.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)Q.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:Q})}}else e.passes[f]=null})),t.length<this.passes.length){for(var f=t.length;f<this.passes.length;f++){var d=this.passes[f];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var v=[],y=0;y<this.passes.length;y++)null!==this.passes[y]&&v.push(this.passes[y]);return this.passes=v,this}},m.prototype.destroy=function(){return this.passes.forEach((function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()})),this.passes.length=0,this}},{\"array-bounds\":70,\"array-normalize\":71,\"color-normalize\":125,earcut:177,\"es6-weak-map\":233,\"flatten-vertex-data\":244,glslify:536,\"object-assign\":499,\"parse-rect\":504,\"pick-by-alias\":511,\"to-float32\":577}],536:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],537:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){if(\"undefined\"==typeof Symbol||!(Symbol.iterator in Object(t)))return;var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||a(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function i(t){return function(t){if(Array.isArray(t))return o(t)}(t)||function(t){if(\"undefined\"!=typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}(t)||a(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function a(t,e){if(t){if(\"string\"==typeof t)return o(t,e);var r=Object.prototype.toString.call(t).slice(8,-1);return\"Object\"===r&&t.constructor&&(r=t.constructor.name),\"Map\"===r||\"Set\"===r?Array.from(t):\"Arguments\"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?o(t,e):void 0}}function o(t,e){(null==e||e>t.length)&&(e=t.length);for(var r=0,n=new Array(e);r<e;r++)n[r]=t[r];return n}var s=t(\"color-normalize\"),l=t(\"array-bounds\"),c=t(\"color-id\"),u=t(\"@plotly/point-cluster\"),f=t(\"object-assign\"),h=t(\"glslify\"),p=t(\"pick-by-alias\"),d=t(\"update-diff\"),g=t(\"flatten-vertex-data\"),m=t(\"is-iexplorer\"),v=t(\"to-float32\"),y=t(\"parse-rect\"),x=b;function b(t,e){var r=this;if(!(this instanceof b))return new b(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=m,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),f(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{constPointSize:!!e.constPointSize,pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=f({},o);s.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pointSizeScale;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=f({},o);l.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pointSizeScale;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),m&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}b.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},b.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},b.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach((function(e,r){t.drawItem(r)}));return this},b.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},b.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,c=e.count;this.regl;if(!a)return r?[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var u=[],h=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(c),g=0;g<r.length;g++){var m=r[g];d[m]=p?p[m]:1}l.subdata(d)}for(var v=h.length;v--;){var y=n(h[v],2),x=y[0],b=y[1];u.push(f({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return u},b.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,o=this.regl,s=this.maxSize,c=this.maxColors,h=this.palette;this.groups=i=r.map((function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=p(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:o.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=f({},b.defaults,e)),e.positions&&!(\"marker\"in e)&&(e.marker=n.marker,delete n.marker),e.marker&&!(\"positions\"in e)&&(e.positions=n.positions,delete n.positions);var m=0,x=0;if(d(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=b.defaults.size),m+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=b.defaults.borderSize),m+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=b.defaults.color),e=t.updateColor(e),x++,e},borderColor:function(e,r){return null==e&&(e=b.defaults.borderColor),e=t.updateColor(e),x++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,s=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:o.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:o.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=g(t,\"float64\");var c=e.count=Math.floor(t.length/2),f=e.bounds=c?l(t,2):null;if(r.range||e.range||(delete e.range,r.range=f),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||c>n)?e.tree=u(t,{bounds:f}):n&&n.length&&(e.tree=n),e.tree){var h={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(h):e.elements=o.elements(h)}return i({data:v.float(t),usage:\"dynamic\"}),a({data:v.fract(t),usage:\"dynamic\"}),s({data:new Uint8Array(c),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach((function(t){return t&&t.destroy&&t.destroy()})),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],s=0,l=Math.min(e.length,r.count);s<l;s++){var c=t.addMarker(e[s]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][s]=1}for(var u=0;u<a.length;u++)if(a[u]){var f={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](f):i[u]=o.buffer(f),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=v.fract(e.scale),e.translateFract=v.fract(e.translate),t},viewport:function(t){return y(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),m){var _=n,w=_.count,T=_.size,k=_.borderSize,M=_.sizeBuffer,A=new Uint8Array(2*w);if(T.length||k.length)for(var S=0;S<w;S++)A[2*S]=Math.round(255*(null==T[S]?T:T[S])/s),A[2*S+1]=Math.round(255*(null==k[S]?k:k[S])/s);M({data:A,usage:\"dynamic\"})}if(x){var E,C=n,L=C.count,I=C.color,P=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(I.length||P.length){E=new Uint8Array(8*L);for(var O=0;O<L;O++){var D=I[O];E[8*O]=h[4*D],E[8*O+1]=h[4*D+1],E[8*O+2]=h[4*D+2],E[8*O+3]=h[4*D+3];var R=P[O];E[8*O+4]=h[4*R],E[8*O+5]=h[4*R+1],E[8*O+6]=h[4*R+2],E[8*O+7]=h[4*R+3]}}}else if(I.length||P.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=I[F]&&(E[4*F]=I[F]%c,E[4*F+1]=Math.floor(I[F]/c)),null!=P[F]&&(E[4*F+2]=P[F]%c,E[4*F+3]=Math.floor(P[F]/c))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n}))}},b.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},b.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var a=[];if(Array.isArray(t))for(var o=0;o<t.length;o+=4)a.push(t.slice(o,o+4));else for(var l=0;l<t.length;l+=4)a.push(t.subarray(l,l+4));t=a}for(var u=0;u<t.length;u++){var f=t[u];f=s(f,\"uint8\");var h=c(f,!1);if(null==e[h]){var p=r.length;e[h]=Math.floor(p/4),r[p]=f[0],r[p+1]=f[1],r[p+2]=f[2],r[p+3]=f[3]}i[u]=e[h]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},b.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},b.prototype.destroy=function(){return this.groups.forEach((function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach((function(t){return t&&t.destroy&&t.destroy()})),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()})),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach((function(t){return t&&t.destroy&&t.destroy()})),this};var _=t(\"object-assign\");e.exports=function(t,e){var r=new x(t,e),n=r.render.bind(r);return _(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"@plotly/point-cluster\":57,\"array-bounds\":70,\"color-id\":123,\"color-normalize\":125,\"flatten-vertex-data\":244,glslify:538,\"is-iexplorer\":466,\"object-assign\":499,\"parse-rect\":504,\"pick-by-alias\":511,\"to-float32\":577,\"update-diff\":599}],538:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],539:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function f(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function h(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o((function(){e.draw(),e.dirty=!0,e.planned=null}))):(this.draw(),this.dirty=!0,o((function(){e.dirty=!1}))),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,m=s.count,v=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=v/g,w=y/g;s.passes=[];for(var T=0;T<g;T++)for(var k=0;k<g;k++)if((s.diagonal||k!==T)&&(s.upper||!(T>k))&&(s.lower||!(T<k))){var M=f(s.id,T,k),A=this.passes[M]||(this.passes[M]={});if(o.data&&(o.transpose?A.positions={x:{buffer:s.buffer,offset:k,count:m,stride:g},y:{buffer:s.buffer,offset:T,count:m,stride:g}}:A.positions={x:{buffer:s.buffer,offset:k*m,count:m},y:{buffer:s.buffer,offset:T*m,count:m}},A.bounds=h(s.bounds,T,k)),o.domain||o.viewport||o.data){var S=d?h(s.padding,T,k):s.padding;if(s.domain){var E=h(s.domain,T,k),C=E[0],L=E[1],I=E[2],P=E[3];A.viewport=[x+C*v+S[0],b+L*y+S[1],x+I*v-S[2],b+P*y-S[3]]}else A.viewport=[x+k*_+_*S[0],b+T*w+w*S[1],x+(k+1)*_-_*S[2],b+(T+1)*w-w*S[3]]}o.color&&(A.color=s.color),o.size&&(A.size=s.size),o.marker&&(A.marker=s.marker),o.borderSize&&(A.borderSize=s.borderSize),o.borderColor&&(A.borderColor=s.borderColor),o.opacity&&(A.opacity=s.opacity),o.range&&(A.range=n?h(s.range,T,k):s.range||A.bounds),s.passes.push(M)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],f=u.passes,h=u.passOffset;f=f.map((function(t,e){n[h+e]=c}))}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach((function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()})),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":70,\"array-range\":72,\"flatten-vertex-data\":244,\"parse-rect\":504,\"pick-by-alias\":511,raf:528,\"regl-scatter2d\":537}],540:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.createREGL=n()}(this,(function(){function t(t,e){this.id=V++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,f=!1,h=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(h=s.onDone),\"profile\"in s&&(f=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),a.width=r*e,a.height=r*n,U(a.style,{width:e+\"px\",height:n+\"px\"})}var i,a=document.createElement(\"canvas\");return U(a.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(a),t===document.body&&(a.style.position=\"absolute\",U(t.style,{margin:0,padding:0})),t!==document.body&&\"function\"==typeof ResizeObserver?(i=new ResizeObserver((function(){setTimeout(n)}))).observe(t):window.addEventListener(\"resize\",n,!1),n(),{canvas:a,onDestroy:function(){i?i.disconnect():window.removeEventListener(\"resize\",n),t.removeChild(a)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}void 0===t.premultipliedAlpha&&(t.premultipliedAlpha=!0),o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:f,onDone:h,onDestroy:p}:(p(),h(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,(function(){return[]}));return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||X(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|K[Object.prototype.toString.call(t)]}function f(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function h(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=et(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=tt(e,i,t.dtype),r),o?t.persistentData=e:Y.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,f(i=Y.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:Y.freeType(i)):X(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=tt(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:Y.freeType(e))}else if(X(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,m=0;1===i.length?(p=i[0],d=1,g=c[0],m=0):2===i.length&&(p=i[0],d=i[1],g=c[0],m=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,h(i=Y.allocType(t.dtype,p*d),e.data,p,d,g,m,s),a(t,i,r),o?t.persistentData=i:Y.freeType(i)}else e instanceof ArrayBuffer&&(t.dtype=5121,t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e))))}function s(r){e.bufferCount--,n(r),t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach((function(e){t+=p[e].stats.size})),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||X(e)||l(e)||e instanceof ArrayBuffer?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=Q[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),m.bind(),i?o(m,i,n,s,c,d):(a&&t.bufferData(m.type,a,n),m.dtype=s||5121,m.usage=n,m.dimension=c,m.byteLength=a),r.profile&&(m.stats.size=m.byteLength*rt[m.dtype]),g}e.bufferCount++;var m=new i(a);return p[m.id]=m,c||g(n),g._reglType=\"buffer\",g._buffer=m,g.subdata=function(e,r){var n,i=0|(r||0);if(m.bind(),X(e)||e instanceof ArrayBuffer)t.bufferSubData(m.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=Y.allocType(m.dtype,e.length);f(a,e),t.bufferSubData(m.type,i,a),Y.freeType(a)}else(Array.isArray(e[0])||X(e[0]))&&(n=et(e),a=tt(e,n,m.dtype),t.bufferSubData(m.type,i,a),Y.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?m.dtype:u(e.data),h(n=Y.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(m.type,i,n),Y.freeType(n)}return g},r.profile&&(g.stats=m.stats),g.destroy=function(){s(m)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){Z(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){Z(p).forEach((function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)}))},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){var f;if(n.buffer.bind(),i?((f=u)||X(i)&&(!l(i)||X(i.data))||(f=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,f,3)):(t.bufferData(34963,c,a),n.buffer.dtype=f||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c),f=u,!u){switch(n.buffer.dtype){case 5121:case 5120:f=5121;break;case 5123:case 5122:f=5123;break;case 5125:case 5124:f=5125}n.buffer.dtype=f}n.type=f,0>(i=s)&&(i=n.buffer.byteLength,5123===f?i>>=1:5125===f&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var f=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),f.primType=4,f.vertCount=0|t,f.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,h=0;Array.isArray(t)||X(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=nt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(h=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===h||5122===h?o*=2:5125!==h&&5124!==h||(o*=4))),a(f,e,r,n,i,o,h)}else c(),f.primType=4,f.vertCount=0,f.type=5121;return s}var c=r.create(null,34963,!0),f=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=f,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(f)},s},createStream:function(t){var e=f.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){f.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){Z(s).forEach(o)}}}function g(t){for(var e=Y.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{it[0]=t[r];var n=(a=at[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function m(t){return Array.isArray(t)||X(t)}function v(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!m(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=gt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),Y.freeType(e)):t.data=e}function T(t,e,r,n,i,a){if(t=\"undefined\"!=typeof vt[t]?vt[t]:lt[t]*mt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function k(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=G[r],t.format=at[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in W&&(t.compressed=!0),r=!0),!a&&r?t.channels=lt[t.format]:a&&!r&&t.channels!==st[t.format]&&(t.format=t.internalformat=st[t.channels])}}function f(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function h(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(X(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=Y.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,f,h=r.stride;3===a.length?(c=a[2],f=h[2]):f=c=1,o=a[0],s=a[1],a=h[0],h=h[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=st[c],t.needsFree=!0,o=f,r=r.offset,c=t.width,f=t.height,s=t.channels;for(var p=Y.allocType(36193===t.type?5126:t.type,c*f*s),d=0,v=0;v<f;++v)for(var T=0;T<c;++T)for(var k=0;k<s;++k)p[d++]=n[a*T+h*v+o*k+r];w(t,p)}else if(b(r)===ct||b(r)===ut||b(r)===ft)b(r)===ct||b(r)===ut?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===pt)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===dt)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,h=t.channels,h=m(r[0][0])?h||r[0][0].length:h||1,o=J.shape(r),c=1,f=0;f<o.length;++f)c*=o[f];c=Y.allocType(36193===t.type?5126:t.type,c),J.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=h,t.format=t.internalformat=st[h],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,h=e.type,p=e.width,d=e.height;f(e),s?t.texSubImage2D(r,o,i,a,u,h,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,h,l)}function v(){return gt.pop()||new h}function k(t){t.needsFree&&Y.freeType(t.data),h.call(t),gt.push(t)}function M(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function A(t,e,r){var n=t.images[0]=v();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=v(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,h=o.internalformat,p=o.format,d=o.type,g=o.width,m=o.height;f(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,h,g,m,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,m,0)):t.texImage2D(s,l,p,g,m,0,p,d,u||null)}}function C(){var t=mt.pop()||new M;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&k(e[r]),e[r]=null;mt.push(t)}function I(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function P(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=ot.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=j[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function O(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new I,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=bt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),bt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete yt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},j={nearest:9728,linear:9729},V=U({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},j),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},G={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},W={};e.ext_srgb&&(G.srgb=35904,G.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(U(G,{depth:6402,\"depth stencil\":34041}),U(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&U(W,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&U(W,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&U(W,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(W[\"rgb etc1\"]=36196);var Q=Array.prototype.slice.call(t.getParameter(34467));Object.keys(W).forEach((function(t){var e=W[t];0<=Q.indexOf(e)&&(G[t]=e)}));var $=Object.keys(G);r.textureFormats=$;var tt=[];Object.keys(G).forEach((function(t){tt[G[t]]=t}));var et=[];Object.keys(H).forEach((function(t){et[H[t]]=t}));var rt=[];Object.keys(j).forEach((function(t){rt[j[t]]=t}));var nt=[];Object.keys(V).forEach((function(t){nt[V[t]]=t}));var it=[];Object.keys(N).forEach((function(t){it[N[t]]=t}));var at=$.reduce((function(t,r){var n=G[r];return 6409===n||6406===n||6409===n||6410===n||6402===n||34041===n||e.ext_srgb&&(35904===n||35906===n)?t[n]=n:32855===n||0<=r.indexOf(\"rgba\")?t[n]=6408:t[n]=6407,t}),{}),gt=[],mt=[],vt=0,yt={},xt=r.maxTextureUnits,bt=Array(xt).map((function(){return null}));return U(O.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<xt;++r){var n=bt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}bt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(yt).forEach((function(e){t+=yt[e].stats.size})),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;I.call(r);var a=C();return\"number\"==typeof t?A(a,0|t,\"number\"==typeof e?0|e:0|t):t?(P(r,t),S(a,t)):A(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=T(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new O(3553);return yt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=v();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),k(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l=0;i.mipmask>>l;++l){var c=a>>l,u=s>>l;if(!c||!u)break;t.texImage2D(3553,l,i.format,c,u,0,i.format,i.type,null)}return R(),o.profile&&(i.stats.size=T(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function f(t,e,r,n,i,a){var s,l=h.texInfo;for(I.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(P(l,t),u(h,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],h),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)A(g[s],t,t);for(c(h,g[0]),h.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,h.internalformat=g[0].internalformat,f.width=g[0].width,f.height=g[0].height,D(h),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,l.genMipmaps,!0)),f.format=tt[h.internalformat],f.type=et[h.type],f.mag=rt[l.magFilter],f.min=nt[l.minFilter],f.wrapS=it[l.wrapS],f.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return f}var h=new O(34067);yt[h.id]=h,a.cubeCount++;var g=Array(6);return f(e,r,n,i,s,l),f.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=v();return c(a,h),a.width=0,a.height=0,p(a,e),a.width=a.width||(h.width>>i)-r,a.height=a.height||(h.height>>i)-n,D(h),d(a,34069+t,r,n,i),R(),k(a),f},f.resize=function(e){if((e|=0)!==h.width){f.width=h.width=e,f.height=h.height=e,D(h);for(var r=0;6>r;++r)for(var n=0;h.mipmask>>n;++n)t.texImage2D(34069+r,n,h.format,e>>n,e>>n,0,h.format,h.type,null);return R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,!1,!0)),f}},f._reglType=\"textureCube\",f._texture=h,o.profile&&(f.stats=h.stats),f.destroy=function(){h.decRef()},f},clear:function(){for(var e=0;e<xt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),bt[e]=null;Z(yt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<xt;++e){var r=bt[e];r&&(r.bindCount=0,r.unit=-1,bt[e]=null)}Z(yt).forEach((function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)}))}}}function M(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)||\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function f(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function h(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=T++,k[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function m(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete k[e.id]}function v(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",m=\"uint8\",y=1,x=null,w=null,T=null,k=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(m=t.colorType,!p)&&(\"half float\"===m||\"float16\"===m?d=\"rgba16f\":\"float\"!==m&&\"float32\"!==m||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(k=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(T=t.depthStencil,c=s=!1))):a=o=1;var M=null,A=null,S=null,E=null;if(Array.isArray(i))M=i.map(u);else if(i)M=[u(i)];else for(M=Array(y),i=0;i<y;++i)M[i]=f(a,o,p,d,m);for(a=a||M[0].width,o=o||M[0].height,x?A=u(x):s&&!c&&(A=f(a,o,k,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=f(a,o,!1,\"stencil\",\"uint8\")),T?E=u(T):!x&&!w&&c&&s&&(E=f(a,o,k,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<M.length;++i)l(M[i]),M[i]&&M[i].texture&&(c=bt[M[i].texture._texture.format]*_t[M[i].texture._texture.type],null===s&&(s=c));return l(A),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=M,n.depthAttachment=A,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=M.map(h),r.depth=h(A),r.stencil=h(S),r.depthStencil=h(E),r.width=n.width,r.height=n.height,v(n),r}var n=new d;return a.framebufferCount++,r(t,e),U(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,v(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){m(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var T=0,k={};return U(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return U(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),U(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach((function(t){t.destroy()}))}})},clear:function(){Z(k).forEach(m)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,Z(k).forEach((function(e){e.framebuffer=t.createFramebuffer(),v(e)}))}})}function A(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n,i){function a(){this.id=++c,this.attributes=[];var t=e.oes_vertex_array_object;this.vao=t?t.createVertexArrayOES():null,u[this.id]=this,this.buffers=[]}var o=r.maxAttributes,s=Array(o);for(r=0;r<o;++r)s[r]=new A;var c=0,u={},f={Record:A,scope:{},state:s,currentVAO:null,targetVAO:null,restore:e.oes_vertex_array_object?function(){e.oes_vertex_array_object&&Z(u).forEach((function(t){t.refresh()}))}:function(){},createVAO:function(t){function e(t){for(var n=0;n<r.buffers.length;++n)r.buffers[n].destroy();r.buffers.length=0,(n=r.attributes).length=t.length;for(var a=0;a<t.length;++a){var o=t[a],s=n[a]=new A;Array.isArray(o)||X(o)||l(o)?(o=i.create(o,34962,!1,!0),s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1,r.buffers.push(o)):i.getBuffer(o)?(s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1):i.getBuffer(o.buffer)?(s.buffer=i.getBuffer(o.buffer),s.size=0|(+o.size||s.buffer.dimension),s.normalized=!!o.normalized||!1,s.type=\"type\"in o?Q[o.type]:s.buffer.dtype,s.offset=0|(o.offset||0),s.stride=0|(o.stride||0),s.divisor=0|(o.divisor||0),s.state=1):\"x\"in o&&(s.x=+o.x||0,s.y=+o.y||0,s.z=+o.z||0,s.w=+o.w||0,s.state=2)}return r.refresh(),e}var r=new a;return n.vaoCount+=1,e.destroy=function(){r.destroy()},e._vao=r,e._reglType=\"vao\",e(t)},getVAO:function(t){return\"function\"==typeof t&&t._vao?t._vao:null},destroyBuffer:function(e){for(var r=0;r<s.length;++r){var n=s[r];n.buffer===e&&(t.disableVertexAttribArray(r),n.buffer=null)}},setVAO:e.oes_vertex_array_object?function(t){if(t!==f.currentVAO){var r=e.oes_vertex_array_object;t?r.bindVertexArrayOES(t.vao):r.bindVertexArrayOES(null),f.currentVAO=t}}:function(r){if(r!==f.currentVAO){if(r)r.bindAttrs();else for(var n=e.angle_instanced_arrays,i=0;i<s.length;++i){var a=s[i];a.buffer?(t.enableVertexAttribArray(i),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offfset),n&&n.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}f.currentVAO=r}},clear:e.oes_vertex_array_object?function(){Z(u).forEach((function(t){t.destroy()}))}:function(){}};return a.prototype.bindAttrs=function(){for(var r=e.angle_instanced_arrays,n=this.attributes,i=0;i<n.length;++i){var a=n[i];a.buffer?(t.enableVertexAttribArray(i),t.bindBuffer(34962,a.buffer.buffer),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offset),r&&r.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}for(r=n.length;r<o;++r)t.disableVertexAttribArray(r)},a.prototype.refresh=function(){var t=e.oes_vertex_array_object;t&&(t.bindVertexArrayOES(this.vao),this.bindAttrs(),f.currentVAO=this)},a.prototype.destroy=function(){if(this.vao){var t=e.oes_vertex_array_object;this===f.currentVAO&&(f.currentVAO=null,t.bindVertexArrayOES(null)),t.deleteVertexArrayOES(this.vao),this.vao=null}u[this.id]&&(delete u[this.id],--n.vaoCount)},f}function E(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s,l){var c;c=o(35632,r.fragId);var u=o(35633,r.vertId);if(s=r.program=t.createProgram(),t.attachShader(s,c),t.attachShader(s,u),l)for(c=0;c<l.length;++c)u=l[c],t.bindAttribLocation(s,u[0],u[1]);t.linkProgram(s),u=t.getProgramParameter(s,35718),n.profile&&(r.stats.uniformsCount=u);var f=r.uniforms;for(c=0;c<u;++c)if(l=t.getActiveUniform(s,c))if(1<l.size)for(var h=0;h<l.size;++h){var p=l.name.replace(\"[0]\",\"[\"+h+\"]\");a(f,new i(p,e.id(p),t.getUniformLocation(s,p),l))}else a(f,new i(l.name,e.id(l.name),t.getUniformLocation(s,l.name),l));for(u=t.getProgramParameter(s,35721),n.profile&&(r.stats.attributesCount=u),r=r.attributes,c=0;c<u;++c)(l=t.getActiveAttrib(s,c))&&a(r,new i(l.name,e.id(l.name),t.getAttribLocation(s,l.name),l))}var c={},u={},f={},h=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return h.forEach((function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)})),t},r.getMaxAttributesCount=function(){var t=0;return h.forEach((function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)})),t}),{clear:function(){var e=t.deleteShader.bind(t);Z(c).forEach(e),c={},Z(u).forEach(e),u={},h.forEach((function(e){t.deleteProgram(e.program)})),h.length=0,f={},r.shaderCount=0},program:function(t,e,n,i){var a=f[e];a||(a=f[e]={});var o=a[t];return o&&!i?o:(e=new s(e,t),r.shaderCount++,l(e,n,i),o||(a[t]=e),h.push(e),e)},restore:function(){c={},u={};for(var t=0;t<h.length;++t)l(h[t],null,h[t].attributes.map((function(t){return[t.location,t.name]})))},shader:o,frag:-1,vert:-1}}function C(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return X(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},(function(){r=s(t)})),r}(t):s(t)}}function L(t){return Array.prototype.slice.call(t)}function I(t){return L(t).join(\"\")}function P(){function t(){var t=[],e=[];return U((function(){t.push.apply(t,L(arguments))}),{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,L(arguments)),t.push(\";\")),n},toString:function(){return I([0<e.length?\"var \"+e.join(\",\")+\";\":\"\",I(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return U((function(){r.apply(r,L(arguments))}),{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=U(a,{arg:n,toString:function(){return I([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=I(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return U(r,{then:function(){return r.apply(r,L(arguments)),this},else:function(){return n.apply(n,L(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),I([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach((function(e){t.push('\"',e,'\":',o[e].toString(),\",\")})),t.push(\"}\");var e=I(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function z(t){return Array.isArray(t)||X(t)||l(t)}function O(t){return t.sort((function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1}))}function D(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function R(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function F(t){return new D(!1,!1,!1,t)}function B(t,e){var r=t.type;return 0===r?new D(!0,1<=(r=t.data.length),2<=r,e):4===r?new D((r=t.data).thisDep,r.contextDep,r.propDep,e):new D(3===r,2===r,1===r,e)}function N(t,e,r,n,i,o,s,l,c,u,f,h,p,d,g){function v(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=v(t);rt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=v(t);rt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach((function(t){a[t]=n.def(i,\".\",t)}));var o=t.next={},s=t.current={};Object.keys(at).forEach((function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))}));var l=t.constants={};Object.keys(st).forEach((function(t){l[t]=n.def(JSON.stringify(st[t]))})),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),F((function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r}))):F((function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"}))}if(\"framebuffer\"in n){var a=n.framebuffer;return B(a,(function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r}))}return null}function w(t,r,n){function i(t){if(t in a){var r=e.id(a[t]);return(t=F((function(){return r}))).id=r,t}if(t in o){var n=o[t];return B(n,(function(t,e){var r=t.invoke(e,n);return e.def(t.shared.strings,\".id(\",r,\")\")}))}return null}var a=t.static,o=t.dynamic,s=i(\"frag\"),l=i(\"vert\"),c=null;return R(s)&&R(l)?(c=f.program(l.id,s.id,null,n),t=F((function(t,e){return t.link(c)}))):t=new D(s&&s.thisDep||l&&l.thisDep,s&&s.contextDep||l&&l.contextDep,s&&s.propDep||l&&l.propDep,(function(t,e){var r,n,i=t.shared.shader;return r=s?s.append(t,e):e.def(i,\".\",\"frag\"),n=l?l.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")})),{frag:s,vert:l,progVar:t,program:c}}function T(t,e){function r(t,e){if(t in n){var r=0|n[t];return F((function(t,n){return e&&(t.OFFSET=r),r}))}if(t in i){var o=i[t];return B(o,(function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n}))}return e&&a?F((function(t,e){return t.OFFSET=\"0\",0})):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;z(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=F((function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null}));return e.value=t,e}if(\"elements\"in i){var r=i.elements;return B(r,(function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o}))}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return F((function(e,r){return nt[t]}))}if(\"primitive\"in i){var e=i.primitive;return B(e,(function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")}))}return a?R(a)?a.value?F((function(t,e){return e.def(t.ELEMENTS,\".primType\")})):F((function(){return 4})):new D(a.thisDep,a.contextDep,a.propDep,(function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)})):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return F((function(){return t}))}if(\"count\"in i){var e=i.count;return B(e,(function(t,r){return t.invoke(r,e)}))}return a?R(a)?a?s?new D(s.thisDep,s.contextDep,s.propDep,(function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)})):F((function(t,e){return e.def(t.ELEMENTS,\".vertCount\")})):F((function(){return-1})):new D(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,(function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")})):null}(),instances:r(\"instances\",!1),offset:s}}function k(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach((function(t){var r=n[t],a=e.id(t),s=new Z;if(z(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:wt.forEach((function(t,e){e<l.length&&(s[t]=l[e])}))}else{var c=z(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,f=0|r.stride,h=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=Q[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=h,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=f,s.divisor=r}o[t]=F((function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach((function(t){n[t]=s[t]})),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n}))})),Object.keys(a).forEach((function(t){var e=a[t];o[t]=B(e,(function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=t.constants,s=a.isBufferArgs,l=(a=a.buffer,{isStream:r.def(!1)}),c=new Z;c.state=1,Object.keys(c).forEach((function(t){l[t]=r.def(\"\"+c[t])}));var u=l.buffer,f=l.type;return r(\"if(\",s,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",a,\".createStream(\",34962,\",\",i,\");\",f,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",f,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[wt[0]],\"=\",i,\".constant;\",wt.slice(1).map((function(t){return l[t]})).join(\"=\"),\"=0;\",\"}else{\",wt.map((function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"})).join(\"\"),\"}}else{\",\"if(\",s,\"(\",i,\".buffer)){\",u,\"=\",a,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\".buffer);\",\"}\",f,'=\"type\" in ',i,\"?\",o.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",a,\".destroyStream(\",u,\");\",\"}\"),l}))})),o}function M(t,e,n,i,o){function s(t){var e=c[t];e&&(h[t]=e)}var l=function(t,e){if(\"string\"==typeof(r=t.static).frag&&\"string\"==typeof r.vert){if(0<Object.keys(e.dynamic).length)return null;var r=e.static,n=Object.keys(r);if(0<n.length&&\"number\"==typeof r[n[0]]){for(var i=[],a=0;a<n.length;++a)i.push([0|r[n[a]],n[a]]);return i}}return null}(t,e),c=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new D(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,(function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]}))}if(t in a){var c=a[t];return t=B(c,(function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]})),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new D(e.thisDep,e.contextDep,e.propDep,(function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]})):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new D(t.thisDep,t.contextDep,t.propDep,(function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r}))}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,d=_(t)),f=T(t),h=function(t,e){var r=t.static,n=t.dynamic,i={};return rt.forEach((function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=F((function(){return s}))}else if(t in n){var l=n[t];i[o]=B(l,(function(t,e){return a(t,e,t.invoke(e,l))}))}}var o=v(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e((function(t){return t}),(function(t,e,r){return r}));case\"depth.func\":return e((function(t){return Mt[t]}),(function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")}));case\"depth.range\":return e((function(t){return t}),(function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]}));case\"blend.func\":return e((function(t){return[kt[\"srcRGB\"in t?t.srcRGB:t.src],kt[\"dstRGB\"in t?t.dstRGB:t.dst],kt[\"srcAlpha\"in t?t.srcAlpha:t.src],kt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]}),(function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]}));case\"blend.equation\":return e((function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0}),(function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]}));case\"blend.color\":return e((function(t){return a(4,(function(e){return+t[e]}))}),(function(t,e,r){return a(4,(function(t){return e.def(\"+\",r,\"[\",t,\"]\")}))}));case\"stencil.mask\":return e((function(t){return 0|t}),(function(t,e,r){return e.def(r,\"|0\")}));case\"stencil.func\":return e((function(t){return[Mt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]}),(function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]}));case\"stencil.opFront\":case\"stencil.opBack\":return e((function(e){return[\"stencil.opBack\"===t?1029:1028,At[e.fail||\"keep\"],At[e.zfail||\"keep\"],At[e.zpass||\"keep\"]]}),(function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]}));case\"polygonOffset.offset\":return e((function(t){return[0|t.factor,0|t.units]}),(function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]}));case\"cull.face\":return e((function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e}),(function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)}));case\"lineWidth\":return e((function(t){return t}),(function(t,e,r){return r}));case\"frontFace\":return e((function(t){return St[t]}),(function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')}));case\"colorMask\":return e((function(t){return t.map((function(t){return!!t}))}),(function(t,e,r){return a(4,(function(t){return\"!!\"+r+\"[\"+t+\"]\"}))}));case\"sample.coverage\":return e((function(t){return[\"value\"in t?t.value:1,!!t.invert]}),(function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]}))}})),i}(t),p=w(t,0,l);s(\"viewport\"),s(v(\"scissor.box\"));var d,g=0<Object.keys(h).length;if((d={framebuffer:d,draw:f,shader:p,state:h,dirty:g,scopeVAO:null,drawVAO:null,useVAO:!1,attributes:{}}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=F((function(t,e){return n}))).enable=n}else if(\"profile\"in t){var i=t.profile;e=B(i,(function(t,e){return t.invoke(e,i)}))}return e}(t),d.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach((function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=F((function(){return n}));else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=F((function(t){return t.link(n)})):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=F((function(t){return t.link(n.color[0])})))}else m(n)&&(e=F((function(t){return t.global.def(\"[\",a(n.length,(function(t){return n[t]})),\"]\")})));e.value=n,i[t]=e})),Object.keys(n).forEach((function(t){var e=n[t];i[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),i}(n),d.drawVAO=d.scopeVAO=function(t,e){var r=t.static,n=t.dynamic;if(\"vao\"in r){var i=r.vao;return null!==i&&null===u.getVAO(i)&&(i=u.createVAO(i)),F((function(t){return t.link(u.getVAO(i))}))}if(\"vao\"in n){var a=n.vao;return B(a,(function(t,e){var r=t.invoke(e,a);return e.def(t.shared.vao+\".getVAO(\"+r+\")\")}))}return null}(t),!d.drawVAO&&p.program&&!l&&r.angle_instanced_arrays){var y=!0;if(t=p.program.attributes.map((function(t){return t=e.static[t],y=y&&!!t,t})),y&&0<t.length){var x=u.getVAO(u.createVAO(t));d.drawVAO=new D(null,null,null,(function(t,e){return t.link(x)})),d.useVAO=!0}}return l?d.useVAO=!0:d.attributes=k(e),d.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach((function(t){var r=e[t];n[t]=F((function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)}))})),Object.keys(r).forEach((function(t){var e=r[t];n[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),n}(i),d}function A(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach((function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")})),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;$&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),$&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),$&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");rt.forEach((function(e){var n,f;if(!((e=v(e))in r.state))if(e in s){n=s[e],f=o[e];var h=a(tt[e].length,(function(t){return u.def(n,\"[\",t,\"]\")}));u(t.cond(h.map((function(t,e){return t+\"!==\"+f+\"[\"+e+\"]\"})).join(\"||\")).then(i,\".\",at[e],\"(\",h,\");\",h.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\"))}else n=u.def(c,\".\",e),h=t.cond(n,\"!==\",l,\".\",e),u(h),e in it?h(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):h(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")})),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;O(Object.keys(r)).forEach((function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];R(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(m(c)){var f=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}}))}function L(t,e){K&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function I(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(h,\".count+=\",i,\";\"):t(h,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",h,\");\"))}function s(t){t(h,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",h,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,f=t.shared,h=t.stats,p=f.current,g=f.timer;if(r=r.profile){if(R(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(f=t.block()),e(\"if(\",r,\"){\",f,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map((function(t){return u+\".\"+t+\"!==\"+i[t]})).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",f,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map((function(t){return u+\".\"+t+\"=\"+i[t]+\";\"})).join(\"\"),\"}\"),K&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",u,\".buffer=null;\",\"}if(\",wt.map((function(t,e){return u+\".\"+t+\"!==\"+h[e]})).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",h,\");\",wt.map((function(t,e){return u+\".\"+t+\"=\"+h[e]+\";\"})).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var f=i.buffer,h=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach((function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Et))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach((function(t){o[t]=e.def(c,\".\",t)}))}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)}))}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var f,h=(g=i[u]).name,p=g.info.type,d=n.uniforms[h],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(R(d)){if(h=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(h._texture||h.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",h=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(h)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",m(h)?Array.prototype.slice.call(h):h,\");\")}continue}f=d.append(t,r)}else{if(!o(Et))continue;f=r.def(l.uniforms,\"[\",e.id(h),\"]\")}switch(35678===p?r(\"if(\",f,\"&&\",f,'._reglType===\"framebuffer\"){',f,\"=\",f,\".color[0];\",\"}\"):35680===p&&r(\"if(\",f,\"&&\",f,'._reglType===\"framebufferCube\"){',f,\"=\",f,\".color[0];\",\"}\"),h=1,p){case 35678:case 35680:p=r.def(f,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",h=2;break;case 35668:case 35672:s=\"3i\",h=3;break;case 35669:case 35673:s=\"4i\",h=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",h=2;break;case 35665:s=\"3f\",h=3;break;case 35666:s=\"4f\",h=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var v=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",f,\")||\",f,\" instanceof Float32Array)?\",f,\":(\",a(g,(function(t){return v+\"[\"+t+\"]=\"+f+\"[\"+t+\"]\"})),\",\",v,\")\")}else r(1<h?a(h,(function(t){return f+\"[\"+t+\"]\"})):f);r(\");\")}}function U(t,e,r,n){function i(i){var a=h[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(f,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,m,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,m]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,f=c.draw,h=n.draw,p=function(){var i=h.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),m=function(){var i=h.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"count\"),i}();if(\"number\"==typeof m){if(0===m)return}else r(\"if(\",m,\"){\"),r.exit(\"}\");K&&(s=i(\"instances\"),l=t.instancing);var v=p+\".type\",y=h.elements&&R(h.elements);K&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function V(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),K&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),r.useVAO?r.drawVAO?e(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,e),\");\"):e(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(e(t.shared.vao,\".setVAO(null);\"),N(t,e,r,n.attributes,(function(){return!0}))),j(t,e,r,n.uniforms,(function(){return!0})),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&A(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&I(t,u,r,!1,!0),n?(r.useVAO?r.drawVAO?i(r.drawVAO)?u(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,u),\");\"):c(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,c),\");\"):c(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(c(t.shared.vao,\".setVAO(null);\"),N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i)),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link((function(e){return V(G,t,r,e,2)})),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;A(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),O(Object.keys(r.state)).forEach((function(e){var n=r.state[e].append(t,i);m(n)?n.forEach((function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)})):i.set(a.next,\".\"+e,n)})),I(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach((function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))})),Object.keys(r.uniforms).forEach((function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))})),Object.keys(r.attributes).forEach((function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach((function(t){i.set(a,\".\"+t,n[t])}))})),r.scopeVAO&&i.set(a.vao,\".targetVAO\",r.scopeVAO.append(t,i)),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!m(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(q.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach((function(e){var r=n[e];if(q.isDynamic(r))\"function\"==typeof r&&(r=n[e]=q.unbox(r)),e=B(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}})),e.dynamic[r]=new q.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach((function(r){var i=n[r];q.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))}))}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var K=r.angle_instanced_arrays,$=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},rt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:h,elements:o,buffer:i,shader:f,attributes:u.state,vao:u,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:z},st={primTypes:nt,compareFuncs:Mt,blendFuncs:kt,blendEquations:J,stencilOps:At,glTypes:Q,orientationType:St};$&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,(function(t){return 0===t?[0]:a(t,(function(t){return 36064+t}))})));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),i=t.proc(\"refresh\"),o=t.block();e(o),i(o);var s,l=t.shared,c=l.gl,u=l.next,f=l.current;o(f,\".dirty=false;\"),S(t,e),S(t,i,null,!0),K&&(s=t.link(K)),r.oes_vertex_array_object&&i(t.link(r.oes_vertex_array_object),\".bindVertexArrayOES(null);\");for(var h=0;h<n.maxAttributes;++h){var p=i.def(l.attributes,\"[\",h,\"]\"),d=t.cond(p,\".buffer\");d.then(c,\".enableVertexAttribArray(\",h,\");\",c,\".bindBuffer(\",34962,\",\",p,\".buffer.buffer);\",c,\".vertexAttribPointer(\",h,\",\",p,\".size,\",p,\".type,\",p,\".normalized,\",p,\".stride,\",p,\".offset);\").else(c,\".disableVertexAttribArray(\",h,\");\",c,\".vertexAttrib4f(\",h,\",\",p,\".x,\",p,\".y,\",p,\".z,\",p,\".w);\",p,\".buffer=null;\"),i(d),K&&i(s,\".vertexAttribDivisorANGLE(\",h,\",\",p,\".divisor);\")}return i(t.shared.vao,\".currentVAO=null;\",t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"),Object.keys(it).forEach((function(r){var n=it[r],a=o.def(u,\".\",r),s=t.block();s(\"if(\",a,\"){\",c,\".enable(\",n,\")}else{\",c,\".disable(\",n,\")}\",f,\".\",r,\"=\",a,\";\"),i(s),e(\"if(\",a,\"!==\",f,\".\",r,\"){\",s,\"}\")})),Object.keys(at).forEach((function(r){var n,s,l=at[r],h=tt[r],p=t.block();p(c,\".\",l,\"(\"),m(h)?(l=h.length,n=t.global.def(u,\".\",r),s=t.global.def(f,\".\",r),p(a(l,(function(t){return n+\"[\"+t+\"]\"})),\");\",a(l,(function(t){return s+\"[\"+t+\"]=\"+n+\"[\"+t+\"];\"})).join(\"\")),e(\"if(\",a(l,(function(t){return n+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"})).join(\"||\"),\"){\",p,\"}\")):(n=o.def(u,\".\",r),s=o.def(f,\".\",r),p(n,\");\",f,\".\",r,\"=\",n,\";\"),e(\"if(\",n,\"!==\",s,\"){\",p,\"}\")),i(p)})),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach((function(t){X(a,e,t)})),Tt.forEach((function(e){X(a,t,e)})),r=M(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),A(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),I(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{r(t.shared.vao,\".setVAO(null);\");var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link((function(r){return V(H,t,e,r,1)})),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach((function(t){i=i||e.context[t].propDep})),i||(A(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,(function(t){return!r(t)})),e.profile&&r(e.profile)||I(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{n(t.shared.vao,\".setVAO(null);\");var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link((function(r){return V(Y,t,e,r,2)})),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function j(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var U=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},V=0,q={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},H={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},G=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},Y=s();Y.zero=s();var W=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=Y.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),Y.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=Y.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),Y.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter((function(t){return!!e[t]})),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},X=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},Z=function(t){return Object.keys(t).map((function(e){return t[e]}))},J={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||Y.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],f=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,f,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},K={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},Q={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},tt=J.flatten,et=J.shape,rt=[];rt[5120]=1,rt[5122]=2,rt[5124]=4,rt[5121]=1,rt[5123]=2,rt[5125]=4,rt[5126]=4;var nt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},it=new Float32Array(1),at=new Uint32Array(it.buffer),ot=[9984,9986,9985,9987],st=[0,6409,6410,6407,6408],lt={};lt[6409]=lt[6406]=lt[6402]=1,lt[34041]=lt[6410]=2,lt[6407]=lt[35904]=3,lt[6408]=lt[35906]=4;var ct=v(\"HTMLCanvasElement\"),ut=v(\"OffscreenCanvas\"),ft=v(\"CanvasRenderingContext2D\"),ht=v(\"ImageBitmap\"),pt=v(\"HTMLImageElement\"),dt=v(\"HTMLVideoElement\"),gt=Object.keys(K).concat([ct,ut,ft,ht,pt,dt]),mt=[];mt[5121]=1,mt[5126]=4,mt[36193]=2,mt[5123]=2,mt[5125]=4;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[34041]=4,vt[33776]=.5,vt[33777]=.5,vt[33778]=1,vt[33779]=1,vt[35986]=.5,vt[35987]=1,vt[34798]=1,vt[35840]=.5,vt[35841]=.25,vt[35842]=.5,vt[35843]=.25,vt[36196]=.5;var yt=[];yt[32854]=2,yt[32855]=2,yt[36194]=2,yt[33189]=2,yt[36168]=1,yt[34041]=4,yt[35907]=4,yt[34836]=16,yt[34842]=8,yt[34843]=6;var xt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach((function(t){l[s[t]]=t}));var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach((function(e){t+=u[e].stats.size})),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height||(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height)),o},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){Z(u).forEach(o)},restore:function(){Z(u).forEach((function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)})),t.bindRenderbuffer(36161,null)}}},bt=[];bt[6408]=4,bt[6407]=3;var _t=[];_t[5121]=1,_t[5126]=4,_t[36193]=2;var wt=[\"x\",\"y\",\"z\",\"w\"],Tt=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),kt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},Mt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},At={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},St={cw:2304,ccw:2305},Et=new D(!1,!1,!1,(function(){}));return function(t){function e(){if(0===J.length)w&&w.update(),tt=null;else{tt=H.next(e),f();for(var t=J.length-1;0<=t;--t){var r=J[t];r&&r(I,null,0)}m.flush(),w&&w.update()}}function r(){!tt&&0<J.length&&(tt=H.next(e))}function n(){tt&&(H.cancel(e),tt=null)}function a(t){t.preventDefault(),n(),K.forEach((function(t){t()}))}function o(t){m.getError(),y.restore(),R.restore(),z.restore(),F.restore(),B.restore(),V.restore(),O.restore(),w&&w.restore(),Y.procs.refresh(),r(),Q.forEach((function(t){t()}))}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach((function(n){var i=t[n];q.isDynamic(i)?r[n]=q.unbox(i,n):e[n]=i})),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach((function(n){r[t+\".\"+n]=e[n]}))}}var r=U({},t);return delete r.uniforms,delete r.attributes,delete r.context,delete r.vao,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),\"vao\"in t&&(r.vao=t.vao),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=Y.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return U((function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}}),{stats:t})}function l(t,e){var r=0;Y.procs.poll();var n=e.color;n&&(m.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(m.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(m.clearStencil(0|e.stencil),r|=1024),m.clear(r)}function c(t){return J.push(t),r(),{cancel:function(){var e=j(J,t);J[e]=function t(){var e=j(J,t);J[e]=J[J.length-1],--J.length,0>=J.length&&n()}}}}function u(){var t=X.viewport,e=X.scissor_box;t[0]=t[1]=e[0]=e[1]=0,I.viewportWidth=I.framebufferWidth=I.drawingBufferWidth=t[2]=e[2]=m.drawingBufferWidth,I.viewportHeight=I.framebufferHeight=I.drawingBufferHeight=t[3]=e[3]=m.drawingBufferHeight}function f(){I.tick+=1,I.time=g(),u(),Y.procs.poll()}function h(){u(),Y.procs.refresh(),w&&w.update()}function g(){return(G()-T)/1e3}if(!(t=i(t)))return null;var m=t.gl,v=m.getContextAttributes();m.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach((function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)}))}}}(m,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={vaoCount:0,bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var f=(n=s[r]).startQueryIndex;u=n.endQueryIndex;n.sum+=l[u]-l[f],f=c[f],(u=c[u])===f?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=f,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),T=G(),A=m.drawingBufferWidth,L=m.drawingBufferHeight,I={tick:0,time:0,viewportWidth:A,viewportHeight:L,framebufferWidth:A,framebufferHeight:L,drawingBufferWidth:A,drawingBufferHeight:L,pixelRatio:t.pixelRatio},P=W(m,_),z=p(m,b,t,(function(t){return O.destroyBuffer(t)})),O=S(m,_,P,b,z),D=d(m,_,z,b),R=E(m,x,b,t),F=k(m,_,P,(function(){Y.procs.poll()}),I,b,t),B=xt(m,_,0,b,t),V=M(m,_,P,F,B,b),Y=N(m,x,_,P,z,D,0,V,{},O,R,{elements:null,primitive:4,count:-1,offset:0,instances:-1},I,w,t),X=(x=C(m,V,Y.procs.poll,I),Y.next),Z=m.canvas,J=[],K=[],Q=[],$=[t.onDestroy],tt=null;Z&&(Z.addEventListener(\"webglcontextlost\",a,!1),Z.addEventListener(\"webglcontextrestored\",o,!1));var et=V.setFBO=s({framebuffer:q.define.call(null,1,\"framebuffer\")});return h(),v=U(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)et(U({framebuffer:t.framebuffer.faces[e]},t),l);else et(t,l);else l(0,t)},prop:q.define.bind(null,1),context:q.define.bind(null,2),this:q.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return D.create(t,!1)},texture:F.create2D,cube:F.createCube,renderbuffer:B.create,framebuffer:V.create,framebufferCube:V.createCube,vao:O.createVAO,attributes:v,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=K;break;case\"restore\":r=Q;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:P,hasExtension:function(t){return 0<=P.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){J.length=0,n(),Z&&(Z.removeEventListener(\"webglcontextlost\",a),Z.removeEventListener(\"webglcontextrestored\",o)),R.clear(),V.clear(),B.clear(),F.clear(),D.clear(),z.clear(),O.clear(),w&&w.clear(),$.forEach((function(t){t()}))},_gl:m,_refresh:h,poll:function(){f(),w&&w.update()},now:g,stats:b}),t.onDone(null,v),v}}))},{}],541:[function(t,e,r){\n",
       "/*!\n",
       " * repeat-string <https://github.com/jonschlinkert/repeat-string>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT License.\n",
       " */\n",
       "\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],542:[function(t,e,r){(function(t){(function(){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],543:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i];(l=o-((r=a+o)-a))&&(t[--n]=r,r=l)}var s=0;for(i=n;i<e;++i){var l;a=t[i];(l=(o=r)-((r=a+o)-a))&&(t[s++]=l)}return t[s++]=r,t.length=s,t}},{}],544:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(s(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(l(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var f=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;f.length<6;)f.push(u(f.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<6;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,f.concat([f,u])),n=0;n<f.length;++n)e.exports[n]=f[n]}()},{\"robust-compress\":543,\"robust-scale\":550,\"robust-sum\":553,\"two-product\":582}],545:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":553,\"two-product\":582}],546:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return c(e,t)}function u(t){if(2===t.length)return[[\"diff(\",c(t[0][0],t[1][1]),\",\",c(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(u(s(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return l(r)}function h(t){for(var e=[],r=[],c=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),h=0;h<t;++h)c[0][h]=\"1\",c[t-1][h]=\"w\"+h;for(h=0;h<t;++h)0==(1&h)?e.push.apply(e,u(s(c,h))):r.push.apply(r,u(s(c,h)));var p=l(e),d=l(r),g=\"exactInSphere\"+t,m=[];for(h=0;h<t;++h)m.push(\"m\"+h);var v=[\"function \",g,\"(\",m.join(),\"){\"];for(h=0;h<t;++h){v.push(\"var w\",h,\"=\",f(h,t),\";\");for(var y=0;y<t;++y)y!==h&&v.push(\"var w\",h,\"m\",y,\"=scale(w\",h,\",m\",y,\"[0]);\")}return v.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",v.join(\"\"))(i,a,n,o)}var p=[function(){return 0},function(){return 0},function(){return 0}];function d(t){var e=p[t.length];return e||(e=p[t.length]=h(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=6;)p.push(h(p.length));for(var t=[],r=[\"slow\"],n=0;n<=6;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=6;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=6;++n)e.exports[n]=p[n]}()},{\"robust-scale\":550,\"robust-subtract\":552,\"robust-sum\":553,\"two-product\":582}],547:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\");function i(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var a=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;a.length<6;)a.push(i(a.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<6;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var o=Function.apply(void 0,t);for(e.exports=o.apply(void 0,a.concat([a,i])),n=0;n<6;++n)e.exports[n]=a[n]}()},{\"robust-determinant\":544}],548:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(c(s(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function u(t){for(var e=[],r=[],u=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),f=[],h=0;h<t;++h)0==(1&h)?e.push.apply(e,c(s(u,h))):r.push.apply(r,c(s(u,h))),f.push(\"m\"+h);var p=l(e),d=l(r),g=\"orientation\"+t+\"Exact\",m=[\"function \",g,\"(\",f.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",m)(i,n,a,o)}var f=u(3),h=u(4),p=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=33306690738754716e-32*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],f=e[2]-n[2],p=r[2]-n[2],d=a*c,g=o*l,m=o*s,v=i*c,y=i*l,x=a*s,b=u*(d-g)+f*(m-v)+p*(y-x),_=7771561172376103e-31*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(m)+Math.abs(v))*Math.abs(f)+(Math.abs(y)+Math.abs(x))*Math.abs(p));return b>_||-b>_?b:h(t,e,r,n)}];function d(t){var e=p[t.length];return e||(e=p[t.length]=u(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=5;)p.push(u(p.length));for(var t=[],r=[\"slow\"],n=0;n<=5;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=5;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=5;++n)e.exports[n]=p[n]}()},{\"robust-scale\":550,\"robust-subtract\":552,\"robust-sum\":553,\"two-product\":582}],549:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":550,\"robust-sum\":553}],550:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var f=s[1];i(f,l[0],s),s[0]&&(o[c++]=s[0]);var h=l[1],p=s[1],d=h+p,g=p-(d-h);s[1]=d,g&&(o[c++]=g)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":582,\"two-sum\":583}],551:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],f=Math.min(c,u);if(Math.max(c,u)<s||l<f)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":548}],552:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=-e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,m,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],553:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,m,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],554:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],555:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":100,\"reduce-simplicial-complex\":533}],556:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],f=(e=u.length,0);f<e;++f)for(var h=0;h<f;++h){var p=u[h],d=u[f];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));var g=2;for(c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var f=o[2*u],h=o[2*u+1];if(r[f]!==r[h]){var p=e[f],d=e[h];o[2*c]=f,o[2*c+1]=h,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),f=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),h=o(s)(t,c.data,f,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(f),{cells:h,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":557,ndarray:495,\"ndarray-sort\":494,\"typedarray-pool\":595}],557:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");var u=[];for(s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":474,\"typedarray-pool\":595}],558:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var f=e.slice(0);f.sort();for(var h=0;h<r;++h)if(n=u[h]-f[h])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],f=u.length,h=1,p=1<<f;h<p;++h){s.length=n.popCount(h);for(var d=0,g=0;g<f;++g)h&1<<g&&(s[d++]=u[g]);var m=c(t,s);if(!(m<0))for(;r[m++].push(i),!(m>=t.length||0!==a(t[m],s)););}return r}function f(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,f=0;f<o.length;++f)l&1<<f&&(c[u++]=o[f]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(f(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=f,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(f(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),h=o+1;h<a.length;++h)r.link(u,c(e,[a[h]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":97,\"union-find\":596}],559:[function(t,e,r){arguments[4][97][0].apply(r,arguments)},{dup:97}],560:[function(t,e,r){arguments[4][558][0].apply(r,arguments)},{\"bit-twiddle\":559,dup:558,\"union-find\":561}],561:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],562:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),f=0;f<a;++f)s[f]=l[f]=-1,c[f]=1/0,u[f]=!1;for(f=0;f<o;++f){var h=t[f];if(2!==h.length)throw new Error(\"Input must be a graph\");var p=h[1],d=h[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,f=s[t],h=l[t];return f<0||h<0?1/0:(r=e[t],i=e[f],a=e[h],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function m(t,e){var r=k[t],n=k[e];k[t]=n,k[e]=r,M[r]=e,M[n]=t}function v(t){return c[k[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=v(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<A){var o=v(n);o<r&&(a=n,r=o)}if(i<A)v(i)<r&&(a=i);if(a===t)return t;m(t,a),t=a}}function b(t){for(var e=v(t);t>0;){var r=y(t);if(r>=0)if(e<v(r)){m(t,r),t=r;continue}return t}}function _(){if(A>0){var t=k[0];return m(0,A-1),A-=1,x(0),t}return-1}function w(t,e){var r=k[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((A+=1)-1))}function T(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),M[e]>=0&&w(M[e],g(e)),M[r]>=0&&w(M[r],g(r))}}var k=[],M=new Array(a);for(f=0;f<a;++f){(c[f]=g(f))<1/0?(M[f]=k.length,k.push(f)):M[f]=-1}var A=k.length;for(f=A>>1;f>=0;--f)x(f);for(;;){var S=_();if(S<0||c[S]>r)break;T(S)}var E=[];for(f=0;f<a;++f)u[f]||(M[f]=E.length,E.push(e[f].slice()));E.length;function C(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var L=[];return t.forEach((function(t){var e=C(s,t[0]),r=C(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=M[e],i=M[r];n!==i&&L.push([n,i])}})),i.unique(i.normalize(L)),{positions:E,edges:L}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":548,\"simplicial-complex\":560}],563:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var f=n(i,r,a);return f||((f=n(i,r,o))||o-i)}},{\"robust-orientation\":548}],564:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],565:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new f(l[0][0],l,c,a),n[2*a+1]=new f(l[1][0],l,!c,a)}n.sort((function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))}));var h=i(o),p=[],d=[],g=[];for(a=0;a<r;){for(var m=n[a].x,v=[];a<r;){var y=n[a];if(y.x!==m)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(v.push(new u(y.segment[0][1],y.index,!0,!0)),v.push(new u(y.segment[1][1],y.index,!1,!1))):(v.push(new u(y.segment[1][1],y.index,!0,!1)),v.push(new u(y.segment[0][1],y.index,!1,!0)))):h=y.create?h.insert(y.segment,y.index):h.remove(y.segment)}p.push(h.root),d.push(m),g.push(v)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function f(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var f=this.horizontal[e];if(f.length>0){var h=n.ge(f,t[1],l);if(h<f.length){var p=f[h];if(t[1]===p.y){if(p.closed)return p.index;for(;h<f.length-1&&f[h+1].y===t[1];)if((p=f[h+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((h+=1)>=f.length)return i;p=f[h]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":563,\"binary-search-bounds\":564,\"functional-red-black-tree\":247,\"robust-orientation\":548}],566:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var f=o(s,u,l,i);r.push(f),n.push(f.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":545,\"robust-sum\":553}],567:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(t){return i(o(t),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}function i(r,n){var i,a,o,s,l,c,u,f,h,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(f=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||f&&!s.sign?h=\"\":(h=f?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(h+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?h+i+l:\"0\"===c?h+l+i:l+h+i)}return g}var a=Object.create(null);function o(e){if(a[e])return a[e];for(var r,n=e,i=[],o=0;n;){if(null!==(r=t.text.exec(n)))i.push(r[0]);else if(null!==(r=t.modulo.exec(n)))i.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");i.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return a[e]=i}\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],568:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map((function(t){return 1===t.length&&(t+=t),t})));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:503}],569:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,f=[],h=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){var m=[],v=[],y=0;for(d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,m.push(x),v.push(s[x]),y+=s[x].length,o[x]=f.length,x===e){l.length=d;break}}f.push(m);var b=new Array(y);for(d=0;d<v.length;d++)for(var _=0;_<v[d].length;_++)b[--y]=v[d][_];h.push(b)}c.pop()}}}for(l=0;l<e;++l)r[l]<0&&p(l);for(l=0;l<h.length;l++){var d=h[l];if(0!==d.length){d.sort((function(t,e){return t-e})),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);h[l]=c}}return{components:f,adjacencyList:h}}},{}],570:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r];e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");var u=[];for(c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var f=[],h=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),h=a):a.push(\"switch(m>>>7){\");for(c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){f.length>0&&h.push(\"}}\");var p=\"vExtra\"+f.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),h=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],f.push(h)}h.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),m=new Array(r),v=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],m[x]=0,v[x]=0;for(x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),m[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),m[b]-=2),y+=1;for(var T=0;T<r;++T)T!==b&&(_&1<<T?v[T]+=1:v[T]-=1)}}var k=[];for(b=0;b<r;++b)if(0===d[b].length)k.push(\"d\"+b+\"-0.5\");else{var M=\"\";m[b]<0?M=m[b]+\"*c\":m[b]>0&&(M=\"+\"+m[b]+\"*c\");var A=d[b].length/y*.5,S=.5+v[b]/y*.5;k.push(\"d\"+b+\"-\"+S+\"-\"+A+\"*(\"+d[b].join(\"+\")+M+\")/(\"+g[b].join(\"+\")+\")\")}h.push(\"a.push([\",k.join(),\"]);\",\"break;\")}a.push(\"}},\"),f.length>0&&h.push(\"}}\");var E=[];for(c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map((function(t){return\"[\"+t.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}else{b.push(\",C.map((function(t){var e=t.slice();return e.reverse(),\"[\"+e.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(c=0;c<f.length;++c)a.push(f[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":487,\"triangulate-hypercube\":580,\"zero-crossings\":624}],571:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")},i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=1.5707963267948966===e?.551915024494:-1.5707963267948966===e?-.551915024494:4/3*Math.tan(e/4),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*r+e*n;return i>1&&(i=1),i<-1&&(i=-1),(t*n-e*r<0?-1:1)*Math.acos(i)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,f=t.ry,h=t.xAxisRotation,p=void 0===h?0:h,d=t.largeArcFlag,g=void 0===d?0:d,m=t.sweepFlag,v=void 0===m?0:m,y=[];if(0===u||0===f)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),f=Math.abs(f);var T=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(f,2);T>1&&(u*=Math.sqrt(T),f*=Math.sqrt(T));var k=function(t,e,r,n,a,o,l,c,u,f,h,p){var d=Math.pow(a,2),g=Math.pow(o,2),m=Math.pow(h,2),v=Math.pow(p,2),y=d*g-d*v-g*m;y<0&&(y=0),y/=d*v+g*m;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*h,_=f*x-u*b+(t+r)/2,w=u*x+f*b+(e+n)/2,T=(h-x)/a,k=(p-b)/o,M=(-h-x)/a,A=(-p-b)/o,S=s(1,0,T,k),E=s(T,k,M,A);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,f,g,v,x,b,_,w),M=n(k,4),A=M[0],S=M[1],E=M[2],C=M[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var I=Math.max(Math.ceil(L),1);C/=I;for(var P=0;P<I;P++)y.push(o(E,C)),E+=C;return y.map((function(t){var e=a(t[0],u,f,b,x,A,S),r=e.x,n=e.y,i=a(t[1],u,f,b,x,A,S),o=i.x,s=i.y,l=a(t[2],u,f,b,x,A,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}}))},e.exports=r.default},{}],572:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":65,assert:73,\"is-svg-path\":471,\"normalize-svg-path\":573,\"parse-svg-path\":505}],573:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,f=null,h=0,p=0,d=0,g=t.length;d<g;d++){var m=t[d],v=m[0];switch(v){case\"M\":l=m[1],c=m[2];break;case\"A\":var y=n({px:h,py:p,cx:m[6],cy:m[7],rx:m[1],ry:m[2],xAxisRotation:m[3],largeArcFlag:m[4],sweepFlag:m[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],m=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(m);break;case\"S\":var _=h,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),m=[\"C\",_,w,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*h-u,f=2*p-f):(u=h,f=p),m=a(h,p,u,f,m[1],m[2]);break;case\"Q\":u=m[1],f=m[2],m=a(h,p,m[1],m[2],m[3],m[4]);break;case\"L\":m=i(h,p,m[1],m[2]);break;case\"H\":m=i(h,p,m[1],p);break;case\"V\":m=i(h,p,h,m[1]);break;case\"Z\":m=i(h,p,l,c)}e=v,h=m[m.length-2],p=m[m.length-1],m.length>4?(o=m[m.length-4],s=m[m.length-3]):(o=h,s=p),r.push(m)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":571}],574:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,f;e.shape?(r=e.shape[0],f=e.shape[1]):(r=c.width=e.w||e.width||200,f=c.height=e.h||e.height||200);var h=Math.min(r,f),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),f/(d[3]-d[1])],m=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,f),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*f),u.scale(m,m),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var v=new Path2D(t);u.fill(v),p&&u.stroke(v)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*h})}},{\"bitmap-sdf\":98,\"draw-svg-path\":174,\"is-svg-path\":471,\"parse-svg-path\":505,\"svg-path-bounds\":572}],575:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function t(e,r,i){i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,f=0,h=0;h<l.length;++h)c[h]=t(e,l[h]),u+=c[h].data.length,f+=c[h].shape,h>0&&(f+=.02);var p=new Float32Array(u),d=0,g=-.5*f;for(h=0;h<c.length;++h){for(var m=c[h].data,v=0;v<m.length;v+=2)p[d++]=m[v]+g,p[d++]=m[v+1];g+=c[h].shape+.02}s=o[r]={data:p,shape:f}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this)}).call(this,t(\"_process\"))},{_process:526,\"vectorize-text\":600}],576:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,f=!1,h=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:P(e[1]),g:P(e[2]),b:P(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:P(e[1]),g:P(e[2]),b:P(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:P(e[1]+\"\"+e[1]),g:P(e[2]+\"\"+e[2]),b:P(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:P(e[1]+\"\"+e[1]),g:P(e[2]+\"\"+e[2]),b:P(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},f=!0,h=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=O(e.s),c=O(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),f=!0,h=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=O(e.s),u=O(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),f=!0,h=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:f,format:e.format||h,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function f(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function h(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=I(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=I(r.s),c(r)}function m(t){return c(t).desaturate(100)}function v(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=I(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=I(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function M(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function A(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=f(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=f(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return h(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[h(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(v,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(m,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(M,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(A,arguments)},splitcomplement:function(){return this._applyCombination(k,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(T,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:O(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function I(t){return o(1,s(0,t))}function P(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function O(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return P(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],577:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],578:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=a;function i(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*a(r[1],t)}function a(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=i(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return i(e,\"font-size\");case\"rem\":return i(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return 96;case\"cm\":return 96/2.54;case\"mm\":return 96/25.4;case\"pt\":return 96/72;case\"pc\":return 16}return 1}},{\"parse-unit\":506}],579:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).topojson=t.topojson||{})}(this,(function(t){\"use strict\";function e(t){return t}function r(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c);for(u[0]=(r+=t[0])*i+o,u[1]=(n+=t[1])*a+s;l<c;)u[l]=t[l],++l;return u}}function n(t){var e,n=r(t.transform),i=1/0,a=i,o=-i,s=-i;function l(t){(t=n(t))[0]<i&&(i=t[0]),t[0]>o&&(o=t[0]),t[1]<a&&(a=t[1]),t[1]>s&&(s=t[1])}function c(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(c);break;case\"Point\":l(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(l)}}for(e in t.arcs.forEach((function(t){for(var e,r=-1,l=t.length;++r<l;)(e=n(t[r],r))[0]<i&&(i=e[0]),e[0]>o&&(o=e[0]),e[1]<a&&(a=e[1]),e[1]>s&&(s=e[1])})),t.objects)c(t.objects[e]);return[i,a,o,s]}function i(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,o=a(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:o}:null==n?{type:\"Feature\",id:r,properties:i,geometry:o}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:o}}function a(t,e){var n=r(t.transform),i=t.arcs;function a(t,e){e.length&&e.pop();for(var r=i[t<0?~t:t],a=0,o=r.length;a<o;++a)e.push(n(r[a],a));t<0&&function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r}(e,o)}function o(t){return n(t)}function s(t){for(var e=[],r=0,n=t.length;r<n;++r)a(t[r],e);return e.length<2&&e.push(e[0]),e}function l(t){for(var e=s(t);e.length<4;)e.push(e[0]);return e}function c(t){return t.map(l)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=o(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(o);break;case\"LineString\":r=s(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(s);break;case\"Polygon\":r=c(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(c);break;default:return null}return{type:n,coordinates:r}}(e)}function o(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach((function(t){r[t<0?~t:t]=1})),a.push(i)}}return e.forEach((function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)})),e.forEach((function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach((function(t){r[0]+=t[0],r[1]+=t[1]}))):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r})),s(i,n),s(n,i),e.forEach((function(t){r[t<0?~t:t]||a.push([t])})),a}function s(t,e,r){var n,i,a;if(arguments.length>1)n=l(t,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:o(t,n)}}function l(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":!function(t){t.forEach(l)}(e.arcs)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}function c(t,e){var r={},n=[],i=[];function s(t){t.forEach((function(e){e.forEach((function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)}))})),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(a(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach((function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":s(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(s)}})),n.forEach((function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].forEach((function(t){t._||(t._=1,n.push(t))}))}))}))}})),n.forEach((function(t){delete t._})),{type:\"MultiPolygon\",arcs:i.map((function(e){var n,i=[];if(e.forEach((function(t){t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].length<2&&i.push(t)}))}))})),(n=(i=o(t,i)).length)>1)for(var a,s,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(s=i[0],i[0]=i[c],i[c]=s,u=a);return i})).filter((function(t){return t.length>0}))}}function u(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r}function f(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c),f=Math.round((t[0]-o)/i),h=Math.round((t[1]-s)/a);for(u[0]=f-r,r=f,u[1]=h-n,n=h;l<c;)u[l]=t[l],++l;return u}}t.bbox=n,t.feature=function(t,e){return\"string\"==typeof e&&(e=t.objects[e]),\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map((function(e){return i(t,e)}))}:i(t,e)},t.merge=function(t){return a(t,c.apply(this,arguments))},t.mergeArcs=c,t.mesh=function(t){return a(t,s.apply(this,arguments))},t.meshArcs=s,t.neighbors=function(t){var e={},r=t.map((function(){return[]}));function n(t,r){t.forEach((function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]}))}function i(t,e){t.forEach((function(t){n(t,e)}))}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach((function(t){i(t,e)}))}};for(var o in t.forEach((function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach((function(e){t(e,r)})):e.type in a&&a[e.type](e.arcs,r)})),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var f=c+1;f<l;++f){var h,p=s[c],d=s[f];(h=r[p])[o=u(h,d)]!==d&&h.splice(o,0,d),(h=r[d])[o=u(h,p)]!==p&&h.splice(o,0,p)}return r},t.quantize=function(t,e){if(t.transform)throw new Error(\"already quantized\");if(e&&e.scale)l=t.bbox;else{if(!((r=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");var r,i=(l=t.bbox||n(t))[0],a=l[1],o=l[2],s=l[3];e={scale:[o-i?(o-i)/(r-1):1,s-a?(s-a)/(r-1):1],translate:[i,a]}}var l,c,u=f(e),h=t.objects,p={};function d(t){return u(t)}function g(t){var e;switch(t.type){case\"GeometryCollection\":e={type:\"GeometryCollection\",geometries:t.geometries.map(g)};break;case\"Point\":e={type:\"Point\",coordinates:d(t.coordinates)};break;case\"MultiPoint\":e={type:\"MultiPoint\",coordinates:t.coordinates.map(d)};break;default:return t}return null!=t.id&&(e.id=t.id),null!=t.bbox&&(e.bbox=t.bbox),null!=t.properties&&(e.properties=t.properties),e}for(c in h)p[c]=g(h[c]);return{type:\"Topology\",bbox:l,transform:e,objects:p,arcs:t.arcs.map((function(t){var e,r=0,n=1,i=t.length,a=new Array(i);for(a[0]=u(t[0],0);++r<i;)((e=u(t[r],r))[0]||e[1])&&(a[n++]=e);return 1===n&&(a[n++]=[0,0]),a.length=n,a}))}},t.transform=r,t.untransform=f,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],580:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:248,\"permutation-parity\":509,\"permutation-rank\":510}],581:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||f(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=f(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,m=l(n,d)/i;u=Math.acos(g),a=Math.acos(m)}return i=Math.log(i),new h(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function f(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function h(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=h.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var f=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=f;var h=this.computedToward;o(h,e,r),s(h,h);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],m=Math.cos(d),v=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=m*y,w=v*y,T=x,k=-m*x,M=-v*x,A=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*h[a]+T*e[a];E[4*a+1]=k*r[a]+M*h[a]+A*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],I=E[5],P=E[9],z=E[2],O=E[6],D=E[10],R=I*D-P*O,F=P*z-L*D,B=L*O-I*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=c(u-=a*p,f-=o*p,h-=s*p),g=(u/=d)*e+a*r,m=(f/=d)*e+o*r,v=(h/=d)*e+s*r;this.center.move(t,g,m,v);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],f=e[a+8];if(n){var h=Math.abs(s),p=Math.abs(l),d=Math.abs(f),g=Math.max(h,p,d);h===g?(s=s<0?-1:1,l=f=0):d===g?(f=f<0?-1:1,s=l=0):(l=l<0?-1:1,s=f=0)}else{var m=c(s,l,f);s/=m,l/=m,f/=m}var v,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*f,T=c(x-=s*w,b-=l*w,_-=f*w),k=l*(_/=T)-f*(b/=T),M=f*(x/=T)-s*_,A=s*b-l*x,S=c(k,M,A);if(k/=S,M/=S,A/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,f),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],I=E*x+C*b+L*_,P=E*k+C*M+L*A;v=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(P,I)}else{var z=e[2],O=e[6],D=e[10],R=z*s+O*l+D*f,F=z*x+O*b+D*_,B=z*k+O*M+D*A;v=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,v),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],f=e[1]-r[1],h=e[2]-r[2],p=c(l,f,h);if(!(p<1e-6)){l/=p,f/=p,h/=p;var d=this.computedRight,g=d[0],m=d[1],v=d[2],y=i*g+a*m+o*v,x=c(g-=y*i,m-=y*a,v-=y*o);if(!(x<.01&&(x=c(g=a*h-o*f,m=o*l-i*h,v=i*f-a*l))<1e-6)){g/=x,m/=x,v/=x,this.up.set(t,i,a,o),this.right.set(t,g,m,v),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*v-o*m,_=o*g-i*v,w=i*m-a*g,T=c(b,_,w),k=i*l+a*f+o*h,M=g*l+m*f+v*h,A=(b/=T)*l+(_/=T)*f+(w/=T)*h,S=Math.asin(u(k)),E=Math.atan2(A,M),C=this.angle._state,L=C[C.length-1],I=C[C.length-2];L%=2*Math.PI;var P=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),O=Math.abs(L-2*Math.PI-E);P<z&&(L+=2*Math.PI),O<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,I),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":242,\"gl-mat4/invert\":293,\"gl-mat4/rotate\":299,\"gl-vec3/cross\":365,\"gl-vec3/dot\":370,\"gl-vec3/normalize\":387}],582:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,f=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=f,r[1]=i,r;return[f,i]};var n=+(Math.pow(2,27)+1)},{}],583:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],584:[function(t,e,r){\"use strict\";var n=t(\"../prototype/is\");e.exports=function(t){if(\"function\"!=typeof t)return!1;if(!hasOwnProperty.call(t,\"length\"))return!1;try{if(\"number\"!=typeof t.length)return!1;if(\"function\"!=typeof t.call)return!1;if(\"function\"!=typeof t.apply)return!1}catch(t){return!1}return!n(t)}},{\"../prototype/is\":591}],585:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=t(\"../string/coerce\"),o=t(\"./to-short-string\"),s=function(t,e){return t.replace(\"%v\",o(e))};e.exports=function(t,e,r){if(!i(r))throw new TypeError(s(e,t));if(!n(t)){if(\"default\"in r)return r.default;if(r.isOptional)return null}var o=a(r.errorMessage);throw n(o)||(o=e),new TypeError(s(o,t))}},{\"../object/is\":588,\"../string/coerce\":592,\"../value/is\":594,\"./to-short-string\":587}],586:[function(t,e,r){\"use strict\";e.exports=function(t){try{return t.toString()}catch(e){try{return String(t)}catch(t){return null}}}},{}],587:[function(t,e,r){\"use strict\";var n=t(\"./safe-to-string\"),i=/[\\n\\r\\u2028\\u2029]/g;e.exports=function(t){var e=n(t);return null===e?\"<Non-coercible to string value>\":(e.length>100&&(e=e.slice(0,99)+\"\\u2026\"),e=e.replace(i,(function(t){switch(t){case\"\\n\":return\"\\\\n\";case\"\\r\":return\"\\\\r\";case\"\\u2028\":return\"\\\\u2028\";case\"\\u2029\":return\"\\\\u2029\";default:throw new Error(\"Unexpected character\")}})))}},{\"./safe-to-string\":586}],588:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i={object:!0,function:!0,undefined:!0};e.exports=function(t){return!!n(t)&&hasOwnProperty.call(i,typeof t)}},{\"../value/is\":594}],589:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"%v is not a plain function\",arguments[1])}},{\"../lib/resolve-exception\":585,\"./is\":590}],590:[function(t,e,r){\"use strict\";var n=t(\"../function/is\"),i=/^\\s*class[\\s{/}]/,a=Function.prototype.toString;e.exports=function(t){return!!n(t)&&!i.test(a.call(t))}},{\"../function/is\":584}],591:[function(t,e,r){\"use strict\";var n=t(\"../object/is\");e.exports=function(t){if(!n(t))return!1;try{return!!t.constructor&&t.constructor.prototype===t}catch(t){return!1}}},{\"../object/is\":588}],592:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=Object.prototype.toString;e.exports=function(t){if(!n(t))return null;if(i(t)){var e=t.toString;if(\"function\"!=typeof e)return null;if(e===a)return null}try{return\"\"+t}catch(t){return null}}},{\"../object/is\":588,\"../value/is\":594}],593:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"Cannot use %v\",arguments[1])}},{\"../lib/resolve-exception\":585,\"./is\":594}],594:[function(t,e,r){\"use strict\";e.exports=function(t){return null!=t}},{}],595:[function(t,e,r){(function(e){(function(){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"dup\"),a=t(\"buffer\").Buffer;e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:i([32,0]),UINT16:i([32,0]),UINT32:i([32,0]),BIGUINT64:i([32,0]),INT8:i([32,0]),INT16:i([32,0]),INT32:i([32,0]),BIGINT64:i([32,0]),FLOAT:i([32,0]),DOUBLE:i([32,0]),DATA:i([32,0]),UINT8C:i([32,0]),BUFFER:i([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=\"undefined\"!=typeof BigUint64Array,l=\"undefined\"!=typeof BigInt64Array,c=e.__TYPEDARRAY_POOL;c.UINT8C||(c.UINT8C=i([32,0])),c.BIGUINT64||(c.BIGUINT64=i([32,0])),c.BIGINT64||(c.BIGINT64=i([32,0])),c.BUFFER||(c.BUFFER=i([32,0]));var u=c.DATA,f=c.BUFFER;function h(t){if(t){var e=t.length||t.byteLength,r=n.log2(e);u[r].push(t)}}function p(t){t=n.nextPow2(t);var e=n.log2(t),r=u[e];return r.length>0?r.pop():new ArrayBuffer(t)}function d(t){return new Uint8Array(p(t),0,t)}function g(t){return new Uint16Array(p(2*t),0,t)}function m(t){return new Uint32Array(p(4*t),0,t)}function v(t){return new Int8Array(p(t),0,t)}function y(t){return new Int16Array(p(2*t),0,t)}function x(t){return new Int32Array(p(4*t),0,t)}function b(t){return new Float32Array(p(4*t),0,t)}function _(t){return new Float64Array(p(8*t),0,t)}function w(t){return o?new Uint8ClampedArray(p(t),0,t):d(t)}function T(t){return s?new BigUint64Array(p(8*t),0,t):null}function k(t){return l?new BigInt64Array(p(8*t),0,t):null}function M(t){return new DataView(p(t),0,t)}function A(t){t=n.nextPow2(t);var e=n.log2(t),r=f[e];return r.length>0?r.pop():new a(t)}r.free=function(t){if(a.isBuffer(t))f[n.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|n.log2(e);u[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeBigUint64=r.freeInt8=r.freeInt16=r.freeInt32=r.freeBigInt64=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){h(t.buffer)},r.freeArrayBuffer=h,r.freeBuffer=function(t){f[n.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return p(t);switch(e){case\"uint8\":return d(t);case\"uint16\":return g(t);case\"uint32\":return m(t);case\"int8\":return v(t);case\"int16\":return y(t);case\"int32\":return x(t);case\"float\":case\"float32\":return b(t);case\"double\":case\"float64\":return _(t);case\"uint8_clamped\":return w(t);case\"bigint64\":return k(t);case\"biguint64\":return T(t);case\"buffer\":return A(t);case\"data\":case\"dataview\":return M(t);default:return null}return null},r.mallocArrayBuffer=p,r.mallocUint8=d,r.mallocUint16=g,r.mallocUint32=m,r.mallocInt8=v,r.mallocInt16=y,r.mallocInt32=x,r.mallocFloat32=r.mallocFloat=b,r.mallocFloat64=r.mallocDouble=_,r.mallocUint8Clamped=w,r.mallocBigUint64=T,r.mallocBigInt64=k,r.mallocDataView=M,r.mallocBuffer=A,r.clearCache=function(){for(var t=0;t<32;++t)c.UINT8[t].length=0,c.UINT16[t].length=0,c.UINT32[t].length=0,c.INT8[t].length=0,c.INT16[t].length=0,c.INT32[t].length=0,c.FLOAT[t].length=0,c.DOUBLE[t].length=0,c.BIGUINT64[t].length=0,c.BIGINT64[t].length=0,c.UINT8C[t].length=0,u[t].length=0,f[t].length=0}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"bit-twiddle\":97,buffer:111,dup:176}],596:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],597:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],598:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],599:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],600:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":601}],601:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter((function(t){return t})).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",h(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(p=0;p<r.length;++p)l[p]=s;!0===o.bolds&&(l=c(\"b\",\"b|\",r,l));!0===o.italics&&(l=c(\"i\",\"i|\",r,l));!0===o.superscripts&&(l=c(\"sup\",\"+1\",r,l));!0===o.subscripts&&(l=c(\"sub\",\"-1\",r,l));var u=[],f=\"\";for(p=0;p<r.length;++p)null!==l[p]&&(f+=r[p],u.push(l[p]));var h,p,d,g,m,v=f.split(\"\\n\"),y=v.length,x=Math.round(a*n),b=n,_=2*n,w=0,T=y*x+_;t.height<T&&(t.height=T);e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var k=0,M=\"\";function A(){if(\"\"!==M){var t=e.measureText(M).width;e.fillText(M,b+d,_+g),d+=t}}function S(){return Math.round(m)+\"px \"}function E(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(\"-\"),a=r.indexOf(\"-\"),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,l-s),n=n.replace(\"?px \",S())),g+=.25*x*(l-s)}if(!0===o.superscripts){var c=t.indexOf(\"+\"),u=r.indexOf(\"+\"),f=c>-1?parseInt(t[1+c]):0,h=u>-1?parseInt(r[1+u]):0;f!==h&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,h-f),n=n.replace(\"?px \",S())),g-=.25*x*(h-f)}if(!0===o.bolds){var p=t.indexOf(\"b|\")>-1,d=r.indexOf(\"b|\")>-1;!p&&d&&(n=v?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),p&&!d&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var v=t.indexOf(\"i|\")>-1,y=r.indexOf(\"i|\")>-1;!v&&y&&(n=\"italic \"+n),v&&!y&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(h=0;h<y;++h){var C=v[h]+\"\\n\";for(d=0,g=h*x,m=n,M=\"\",p=0;p<C.length;++p){var L=p+k<u.length?u[p+k]:u[u.length-1];s===L?M+=C[p]:(A(),M=C[p],void 0!==L&&(E(s,L),s=L))}A(),k+=C.length;var I=0|Math.round(d+2*b);w<I&&(w=I)}var P=w,z=_+x*y;return i(e.getImageData(0,0,P,z).data,[z,P,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=h;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\");function c(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=\"+\"===e[0]||\"-\"===e[0],c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var f=c;f<u+s;++f)if(f<c+o||f>=u)n[f]=null,r=r.substr(0,f)+\" \"+r.substr(f+1);else if(null!==n[f]){var h=n[f].indexOf(e[0]);-1===h?n[f]+=e:l&&(n[f]=n[f].substr(0,h+1)+(1+parseInt(n[f][h+1]))+n[f].substr(h+2))}var p=c+o,d=r.substr(p,u-p).indexOf(i);c=-1!==d?d:u+s}return n}function u(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function f(t,e,r,n){var i=u(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var f=0;switch(n){case\"center\":f=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":f=-o[0];break;case\"left\":case\"start\":f=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var h=0;switch(i){case\"hanging\":case\"top\":h=-a[1];break;case\"middle\":h=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":h=-3*r;break;case\"bottom\":h=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map((function(t){return[p*(t[0]+f),p*(t[1]+h)]}))}(i.positions,e,r),c=i.edges,f=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),p=new Array(h.length),d=0;d<h.length;++d){for(var g=h[d],m=new Array(g.length),v=0;v<g.length;++v){for(var y=g[v],x=new Array(y.length),b=0;b<y.length;++b)x[b]=a[y[b]].slice();f&&x.reverse(),m[v]=x}p[d]=m}return p}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function h(t,e,r){try{return f(t,e,r,!0)}catch(t){}try{return f(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:112,\"clean-pslg\":121,ndarray:495,\"planar-graph-to-polyline\":514,\"simplify-planar-graph\":562,\"surface-nets\":570}],602:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=g);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var c=new ArrayBuffer(25),u=new Uint8Array(c);crypto.getRandomValues(u),l=\"weakmap:rand:\"+Array.prototype.map.call(u,(function(t){return(t%36).toString(36)})).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return v(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return v(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return v(t),r(t)}})}();var h=!1,p=0,d=function(){this instanceof d||x();var t=[],e=[],r=p++;return Object.create(d.prototype,{get___:{value:y((function(n,i){var a,o=v(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i}))},has___:{value:y((function(e){var n=v(e);return n?r in n:t.indexOf(e)>=0}))},set___:{value:y((function(n,i){var a,o=v(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this}))},delete___:{value:y((function(n){var i,a,o=v(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0)&&(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,!0)}))}})};d.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof d||x();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new d),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new d),i.set___(t,e)}else n.set(t,e);return this},Object.create(d.prototype,{get___:{value:y((function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)}))},has___:{value:y((function(t){return n.has(t)||!!i&&i.has___(t)}))},set___:{value:y(e)},delete___:{value:y((function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e}))},permitHostObjects___:{value:y((function(t){if(t!==g)throw new Error(\"bogus call to permitHostObjects___\");a=!0}))}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=d.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=d)}function g(t){t.permitHostObjects___&&t.permitHostObjects___(g)}function m(t){return!(\"weakmap:\"==t.substr(0,\"weakmap:\".length)&&\"___\"===t.substr(t.length-3))}function v(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[l];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,l,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function y(t){return t.prototype=null,Object.freeze(t)}function x(){h||\"undefined\"==typeof console||(h=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],603:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":604}],604:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],605:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":603}],606:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":249}],607:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),f[t-f[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=h[o-h[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var f=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(f/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=f[t-f[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l;if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Lunar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Lunar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=30))throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(l=!1,a=n):(l=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:l}}s=o.day-1;var c,u=f[o.year-f[0]],p=u>>13;c=p&&(o.month>p||o.isIntercalary)?o.month:o.month-1;for(var d=0;d<c;d++){s+=u&1<<12-d?30:29}var g=h[o.year-h[0]],m=new Date(g>>9&4095,(g>>5&15)-1,(31&g)+s);return a.year=m.getFullYear(),a.month=1+m.getMonth(),a.day=m.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Solar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Solar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=31))throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var o=h[i.year-h[0]],s=i.year<<9|i.month<<5|i.day;a.year=s>=o?i.year:i.year-1,o=h[a.year-h[0]];var l,c=new Date(o>>9&4095,(o>>5&15)-1,31&o),u=new Date(i.year,i.month-1,i.day);l=Math.round((u-c)/864e5);var p,d=f[a.year-f[0]];for(p=0;p<13;p++){var g=d&1<<12-p?30:29;if(l<g)break;l-=g}var m=d>>13;!m||p<m?(a.isIntercalary=!1,a.month=1+p):p===m?(a.isIntercalary=!0,a.month=p):(a.isIntercalary=!1,a.month=p);return a.day=1+l,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),f=this.isIntercalaryMonth(c,s),h=a&&f?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);h!==u&&l.month(h)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-/](\\d?\\d)([iI]?)[-/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var f=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],h=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":621,\"object-assign\":499}],608:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":621,\"object-assign\":499}],609:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":621,\"object-assign\":499}],610:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":621,\"object-assign\":499}],611:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)||8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":621,\"object-assign\":499}],612:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":621,\"object-assign\":499}],613:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":621,\"object-assign\":499}],614:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":621,\"object-assign\":499}],615:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":621,\"object-assign\":499}],616:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2e3:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":621,\"object-assign\":499}],617:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),f=t-this.toJD(l,u,1)+1;return this.newDate(l,u,f)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":621,\"object-assign\":499}],618:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":621,\"object-assign\":499}],619:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":621,\"object-assign\":499}],620:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":621,\"object-assign\":499}],621:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,(function(e){return t[e]}))}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":499}],622:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,f=r.monthNamesShort||this.local.monthNamesShort,h=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,m=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},v=function(t,e){return e?\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]:\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=m(e);break;case\"M\":b+=v(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,f=-1,h=-1,p=-1,d=-1,g=-1,m=!1,v=!1,y=function(e,r){for(var n=1;A+n<t.length&&t.charAt(A+n)===e;)n++;return A+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(M).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,M);return M+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(M));return M+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(M,o[s].length).toLowerCase()===o[s].toLowerCase())return M+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,M)},T=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(M)):c.call(b,e.substring(M));return M+=t.length,t}return w(\"M\",c,u)},k=function(){if(e.charAt(M)!==t.charAt(A))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,M);M++},M=0,A=0;A<t.length;A++)if(v)\"'\"!==t.charAt(A)||y(\"'\")?k():v=!1;else switch(t.charAt(A)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=T();break;case\"y\":var S=A;m=!y(\"y\",2),A=S,h=x(\"y\",2);break;case\"Y\":h=x(\"Y\",2);break;case\"J\":f=x(\"J\")+.5,\".\"===e.charAt(M)&&(M++,x(\"J\"));break;case\"@\":f=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":f=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":M=e.length;break;case\"'\":y(\"'\")?k():v=!0;break;default:k()}if(M<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===h?h=this.today().year():h<100&&m&&(h+=-1===n?1900:this.today().year()-this.today().year()%100-(h<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,h,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(h,p);d>E;E=this.daysInMonth(h,p))p++,d-=E}return f>-1?this.fromJD(f):this.newDate(h,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":621,\"object-assign\":499}],623:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":151}],624:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":623}],625:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],626:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../constants/axis_placeable_objects\":746,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/font_attributes\":856,\"./arrow_paths\":625}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach((function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref),a=i.getRefType(e.xref),o=i.getRefType(e.yref);e._extremes={},\"range\"===a&&s(e,r),\"range\"===o&&s(e,n)}))}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],f=t[\"_\"+a+\"padminus\"],h={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+h,g=p-h,m=3*t.startarrowsize*t.arrowwidth||0,v=m+h,y=m-h;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,v),ppadminus:Math.max(f,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else v=s?v+s:v,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,v),ppadminus:Math.max(f,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./draw\":632}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,f=[],h=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?h:p:f).push(r);break}n===d&&i.visible&&\"onout\"===a&&h.push(r)}return{on:f,off:h,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),f={},h=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",h[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(f,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",h[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(f,s.getUpdateObj());return i.call(\"update\",t,{},f)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911}],629:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var f,h,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(f=a(\"arrowhead\"),h=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",f),a(\"startarrowsize\",h)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var m=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),v=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(m));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||v})}a(\"captureevents\",!!d)}},{\"../../lib\":778,\"../color\":643}],630:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,f=e._id.charAt(0),h=0;h<u.length;h++)l=u[h],c=\"annotations[\"+h+\"].\",l[f+\"ref\"]===e._id&&p(f),l[\"a\"+f+\"ref\"]===e._id&&p(\"a\"+f);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":805,\"fast-isnumeric\":241}],631:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,f=[\"x\",\"y\"],h=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=f[d],m=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==m)i.getFromId(p,m)._annIndices.push(e._index);if(i.coercePosition(e,p,a,m,g,.5),u){var v=\"a\"+g,y=i.coerceRef(t,e,p,v,\"pixel\",[\"pixel\",\"paper\"]);\"pixel\"!==y&&y!==m&&(y=e[v]=\"pixel\");var x=\"pixel\"===y?h[d]:.4;i.coercePosition(e,p,a,y,v,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":626,\"./common_defaults\":629}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../plots/cartesian/axes\"),c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),p=t(\"../../lib/setcursor\"),d=t(\"../dragelement\"),g=t(\"../../plot_api/plot_template\").arrayEditor,m=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=l.getFromId(t,r.xref),i=l.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),x(t,r,e,!1,n,i)}function y(t,e,r,n,i){var a=i[r],o=i[r+\"ref\"],s=-1!==r.indexOf(\"y\"),c=\"domain\"===l.getRefType(o),u=s?n.h:n.w;return t?c?a+(s?-e:e)/t._length:t.p2r(t.r2p(a)+e):a+(s?-e:e)/u}function x(t,e,r,a,v,x){var b,_,w=t._fullLayout,T=t._fullLayout._size,k=t._context.edits;a?(b=\"annotation-\"+a,_=a+\".annotations\"):(b=\"annotation\",_=\"annotations\");var M=g(t.layout,_,e),A=M.modifyBase,S=M.modifyItem,E=M.getUpdateObj;w._infolayer.selectAll(\".\"+b+'[data-index=\"'+r+'\"]').remove();var C=\"clip\"+w._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var L={x:{},y:{}},I=+e.textangle||0,P=w._infolayer.append(\"g\").classed(b,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),z=P.append(\"g\").classed(\"annotation-text-g\",!0),O=k[e.showarrow?\"annotationTail\":\"annotationPosition\"],D=e.captureevents||k.annotationText||O,R=z.append(\"g\").style(\"pointer-events\",D?\"all\":null).call(p,\"pointer\").on(\"click\",(function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",Y(n.event))}));e.hovertext&&R.on(\"mouseover\",(function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();f.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:w._hoverlayer.node(),outerContainer:w._paper.node(),gd:t})})).on(\"mouseout\",(function(){f.loneUnhover(w._hoverlayer.node())}));var F=e.borderwidth,B=e.borderpad,N=F+B,j=R.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",F+\"px\").call(c.stroke,e.bordercolor).call(c.fill,e.bgcolor),U=e.width||e.height,V=w._topclips.selectAll(\"#\"+C).data(U?[0]:[]);V.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",C).append(\"rect\"),V.exit().remove();var q=e.font,H=w._meta?o.templateString(e.text,w._meta):e.text,G=R.append(\"text\").classed(\"annotation-text\",!0).text(H);k.annotationText?G.call(h.makeEditable,{delegate:R,gd:t}).call(W).on(\"edit\",(function(r){e.text=r,this.call(W),S(\"text\",r),v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,E())})):G.call(W)}else n.selectAll(\"#\"+C).remove();function Y(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function W(r){return r.call(u.font,q).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,X),r}function X(){var r=G.selectAll(\"a\");1===r.size()&&r.text()===G.text()&&R.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(j.node());var n=R.select(\".annotation-text-math-group\"),f=!n.empty(),g=u.bBox((f?n:G).node()),b=g.width,_=g.height,M=e.width||b,D=e.height||_,B=Math.round(M+2*N),q=Math.round(D+2*N);function H(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var W=!1,X=[\"x\",\"y\"],Z=0;Z<X.length;Z++){var J,K,Q,$,tt,et=X[Z],rt=e[et+\"ref\"]||et,nt=e[\"a\"+et+\"ref\"],it={x:v,y:x}[et],at=(I+(\"x\"===et?0:-90))*Math.PI/180,ot=B*Math.cos(at),st=q*Math.sin(at),lt=Math.abs(ot)+Math.abs(st),ct=e[et+\"anchor\"],ut=e[et+\"shift\"]*(\"x\"===et?1:-1),ft=L[et],ht=l.getRefType(rt);if(it&&\"domain\"!==ht){var pt=it.r2fraction(e[et]);(pt<0||pt>1)&&(nt===rt?((pt=it.r2fraction(e[\"a\"+et]))<0||pt>1)&&(W=!0):W=!0),J=it._offset+it.r2p(e[et]),$=.5}else{var dt=\"domain\"===ht;\"x\"===et?(Q=e[et],J=dt?it._offset+it._length*Q:J=T.l+T.w*Q):(Q=1-e[et],J=dt?it._offset+it._length*Q:J=T.t+T.h*Q),$=e.showarrow?.5:Q}if(e.showarrow){ft.head=J;var gt=e[\"a\"+et];if(tt=ot*H(.5,e.xanchor)-st*H(.5,e.yanchor),nt===rt){var mt=l.getRefType(nt);\"domain\"===mt?(\"y\"===et&&(gt=1-gt),ft.tail=it._offset+it._length*gt):\"paper\"===mt?\"y\"===et?(gt=1-gt,ft.tail=T.t+T.h*gt):ft.tail=T.l+T.w*gt:ft.tail=it._offset+it.r2p(gt),K=tt}else ft.tail=J+gt,K=tt+gt;ft.text=ft.tail+tt;var vt=w[\"x\"===et?\"width\":\"height\"];if(\"paper\"===rt&&(ft.head=o.constrain(ft.head,1,vt-1)),\"pixel\"===nt){var yt=-Math.max(ft.tail-3,ft.text),xt=Math.min(ft.tail+3,ft.text)-vt;yt>0?(ft.tail+=yt,ft.text+=yt):xt>0&&(ft.tail-=xt,ft.text-=xt)}ft.tail+=ut,ft.head+=ut}else K=tt=lt*H($,ct),ft.text=J+tt;ft.text+=ut,tt+=ut,K+=ut,e[\"_\"+et+\"padplus\"]=lt/2+K,e[\"_\"+et+\"padminus\"]=lt/2-K,e[\"_\"+et+\"size\"]=lt,e[\"_\"+et+\"shift\"]=tt}if(W)R.remove();else{var bt=0,_t=0;if(\"left\"!==e.align&&(bt=(M-b)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(_t=(D-_)*(\"middle\"===e.valign?.5:1)),f)n.select(\"svg\").attr({x:N+bt-1,y:N+_t}).call(u.setClipUrl,U?C:null,t);else{var wt=N+_t-g.top,Tt=N+bt-g.left;G.call(h.positionText,Tt,wt).call(u.setClipUrl,U?C:null,t)}V.select(\"rect\").call(u.setRect,N,N,M,D),j.call(u.setRect,F/2,F/2,B-F,q-F),R.call(u.setTranslate,Math.round(L.x.text-B/2),Math.round(L.y.text-q/2)),z.attr({transform:\"rotate(\"+I+\",\"+L.x.text+\",\"+L.y.text+\")\"});var kt,Mt=function(r,n){P.selectAll(\".annotation-arrow-g\").remove();var l=L.x.head,f=L.y.head,h=L.x.tail+r,p=L.y.tail+n,g=L.x.text+r,b=L.y.text+n,_=o.rotationXYMatrix(I,g,b),w=o.apply2DTransform(_),M=o.apply2DTransform2(_),C=+j.attr(\"width\"),O=+j.attr(\"height\"),D=g-.5*C,F=D+C,B=b-.5*O,N=B+O,U=[[D,B,D,N],[D,N,F,N],[F,N,F,B],[F,B,D,B]].map(M);if(!U.reduce((function(t,e){return t^!!o.segmentsIntersect(l,f,l+1e6,f+1e6,e[0],e[1],e[2],e[3])}),!1)){U.forEach((function(t){var e=o.segmentsIntersect(h,p,l,f,t[0],t[1],t[2],t[3]);e&&(h=e.x,p=e.y)}));var V=e.arrowwidth,q=e.arrowcolor,H=e.arrowside,G=P.append(\"g\").style({opacity:c.opacity(q)}).classed(\"annotation-arrow-g\",!0),Y=G.append(\"path\").attr(\"d\",\"M\"+h+\",\"+p+\"L\"+l+\",\"+f).style(\"stroke-width\",V+\"px\").call(c.stroke,c.rgb(q));if(m(Y,H,e),k.annotationPosition&&Y.node().parentNode&&!a){var W=l,X=f;if(e.standoff){var Z=Math.sqrt(Math.pow(l-h,2)+Math.pow(f-p,2));W+=e.standoff*(h-l)/Z,X+=e.standoff*(p-f)/Z}var J,K,Q=G.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(h-W)+\",\"+(p-X),transform:s(W,X)}).style(\"stroke-width\",V+6+\"px\").call(c.stroke,\"rgba(0,0,0,0)\").call(c.fill,\"rgba(0,0,0,0)\");d.init({element:Q.node(),gd:t,prepFn:function(){var t=u.getTranslate(R);J=t.x,K=t.y,v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(J,K),i=n[0]+t,a=n[1]+r;R.call(u.setTranslate,i,a),S(\"x\",y(v,t,\"x\",T,e)),S(\"y\",y(x,r,\"y\",T,e)),e.axref===e.xref&&S(\"ax\",y(v,t,\"ax\",T,e)),e.ayref===e.yref&&S(\"ay\",y(x,r,\"ay\",T,e)),G.attr(\"transform\",s(t,r)),z.attr({transform:\"rotate(\"+I+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&Mt(0,0),O)d.init({element:R.node(),gd:t,prepFn:function(){kt=z.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?S(\"ax\",y(v,t,\"ax\",T,e)):S(\"ax\",e.ax+t),e.ayref===e.yref?S(\"ay\",y(x,r,\"ay\",T.w,e)):S(\"ay\",e.ay+r),Mt(t,r);else{if(a)return;var i,o;if(v)i=y(v,t,\"x\",T,e);else{var l=e._xsize/T.w,c=e.x+(e._xshift-e.xshift)/T.w-l/2;i=d.align(c+t/T.w,l,0,1,e.xanchor)}if(x)o=y(x,r,\"y\",T,e);else{var u=e._ysize/T.h,f=e.y-(e._yshift+e.yshift)/T.h-u/2;o=d.align(f-r/T.h,u,0,1,e.yanchor)}S(\"x\",i),S(\"y\",o),v&&x||(n=d.getCursor(v?.5:i,x?.5:o,e.xanchor,e.yanchor))}z.attr({transform:s(t,r)+kt}),p(R,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",Y(n))},doneFn:function(){p(R),i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:x}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axes\":828,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../fx\":683,\"./draw_arrow_head\":633,d3:169}],633:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\"),o=t(\"../../lib\"),s=o.strScale,l=o.strRotate,c=o.strTranslate;e.exports=function(t,e,r){var o,u,f,h,p=t.node(),d=a[r.arrowhead||0],g=a[r.startarrowhead||0],m=(r.arrowwidth||1)*(r.arrowsize||1),v=(r.arrowwidth||1)*(r.startarrowsize||1),y=e.indexOf(\"start\")>=0,x=e.indexOf(\"end\")>=0,b=d.backoff*m+r.standoff,_=g.backoff*v+r.startstandoff;if(\"line\"===p.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},u={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var w=o.x-u.x,T=o.y-u.y;if(h=(f=Math.atan2(T,w))+Math.PI,b&&_&&b+_>Math.sqrt(w*w+T*T))return void O();if(b){if(b*b>w*w+T*T)return void O();var k=b*Math.cos(f),M=b*Math.sin(f);u.x+=k,u.y+=M,t.attr({x2:u.x,y2:u.y})}if(_){if(_*_>w*w+T*T)return void O();var A=_*Math.cos(f),S=_*Math.sin(f);o.x-=A,o.y-=S,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===p.nodeName){var E=p.getTotalLength(),C=\"\";if(E<b+_)return void O();var L=p.getPointAtLength(0),I=p.getPointAtLength(.1);f=Math.atan2(L.y-I.y,L.x-I.x),o=p.getPointAtLength(Math.min(_,E)),C=\"0px,\"+_+\"px,\";var P=p.getPointAtLength(E),z=p.getPointAtLength(E-.1);h=Math.atan2(P.y-z.y,P.x-z.x),u=p.getPointAtLength(Math.max(0,E-b)),C+=E-(C?_+b:b)+\"px,\"+E+\"px\",t.style(\"stroke-dasharray\",C)}function O(){t.style(\"stroke-dasharray\",\"0px,100px\")}function D(e,a,o,u){e.path&&(e.noRotate&&(o=0),n.select(p.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:c(a.x,a.y)+l(180*o/Math.PI)+s(u)}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}y&&D(g,o,f,v),x&&D(d,u,h,m)}},{\"../../lib\":778,\"../color\":643,\"./arrow_paths\":625,d3:169}],634:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":626,\"./calc_autorange\":627,\"./click\":628,\"./convert_coords\":630,\"./defaults\":631,\"./draw\":632}],635:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../annotations/attributes\":626}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],637:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"../annotations/common_defaults\":629,\"./attributes\":635}],638:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var f=a[u],h=l[f],p=e[f+\"axis\"].r2fraction(h);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":879,\"../annotations/draw\":632}],639:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":778,\"../../registry\":911,\"./attributes\":635,\"./convert\":636,\"./defaults\":637,\"./draw\":638}],640:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":607,\"world-calendars/dist/calendars/coptic\":608,\"world-calendars/dist/calendars/discworld\":609,\"world-calendars/dist/calendars/ethiopian\":610,\"world-calendars/dist/calendars/hebrew\":611,\"world-calendars/dist/calendars/islamic\":612,\"world-calendars/dist/calendars/julian\":613,\"world-calendars/dist/calendars/mayan\":614,\"world-calendars/dist/calendars/nanakshahi\":615,\"world-calendars/dist/calendars/nepali\":616,\"world-calendars/dist/calendars/persian\":617,\"world-calendars/dist/calendars/taiwan\":618,\"world-calendars/dist/calendars/thai\":619,\"world-calendars/dist/calendars/ummalqura\":620,\"world-calendars/dist/main\":621,\"world-calendars/dist/plus\":622}],641:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:\"##\",w:\"##\",c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function h(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function p(t){return i.extendFlat({},l,{description:t})}function d(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var g={xcalendar:p(d(\"x\"))},m=i.extendFlat({},g,{ycalendar:p(d(\"y\"))}),v=i.extendFlat({},m,{zcalendar:p(d(\"z\"))}),y=p([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:v,surface:v,mesh3d:v,scattergl:m,ohlc:g,candlestick:g},layout:{calendar:p([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:y},yaxis:{calendar:y},scene:{xaxis:{calendar:y},yaxis:{calendar:y},zaxis:{calendar:y}},polar:{radialaxis:{calendar:y}}},transforms:{filter:{valuecalendar:p([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:p([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:h,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,p=h(r).fromJD(f),d=0;-1!==(d=t.indexOf(\"%\",d));)\"0\"===(n=t.charAt(d+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(d+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=u[i])?(c=\"##\"===l?\"##\":p.formatDate(l[n]),t=t.substr(0,d)+c+t.substr(d+a),d+=c.length):d+=a;return t}}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./calendars\":640}],642:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],643:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":642,\"fast-isnumeric\":241,tinycolor2:576}],644:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\"},ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,minexponent:n.minexponent,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/font_attributes\":856}],645:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],646:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function f(t,e){return n.coerce(u,c,l,t,e)}var h=f(\"thicknessmode\");f(\"thickness\",\"fraction\"===h?30/(r.width-r.margin.l-r.margin.r):30);var p=f(\"lenmode\");f(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),f(\"x\"),f(\"xanchor\"),f(\"xpad\"),f(\"y\"),f(\"yanchor\"),f(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),f(\"outlinecolor\"),f(\"outlinewidth\"),f(\"bordercolor\"),f(\"borderwidth\"),f(\"bgcolor\");var d=f(\"ticklabelposition\");a(u,c,f,\"linear\");var g={outerTicks:!1,font:r.font};-1!==d.indexOf(\"inside\")&&(g.bgColor=\"black\"),s(u,c,f,\"linear\",g),o(u,c,f,\"linear\",g),f(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(f,\"title.font\",r.font),f(\"title.side\")}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_mark_defaults\":850,\"../../plots/cartesian/tick_value_defaults\":851,\"./attributes\":644}],647:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),p=t(\"../drawing\"),d=t(\"../color\"),g=t(\"../titles\"),m=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,y=t(\"../../plots/cartesian/axis_defaults\"),x=t(\"../../plots/cartesian/position_defaults\"),b=t(\"../../plots/cartesian/layout_attributes\"),_=t(\"../../constants/alignment\"),w=_.LINE_SPACING,T=_.FROM_TL,k=_.FROM_BR,M=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+M.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return f(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var u=0;u<o.length;u++){var h=o[u],p=(n=h[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),(function(t){return t._id}));e.enter().append(\"g\").attr(\"class\",(function(t){return t._id})).classed(M.colorbar,!0),e.each((function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",M.cbbg),c.ensureSingle(r,\"g\",M.cbfills),c.ensureSingle(r,\"g\",M.cblines),c.ensureSingle(r,\"g\",M.cbaxis,(function(t){t.classed(M.crisp,!0)})),c.ensureSingle(r,\"g\",M.cbtitleunshift,(function(t){t.append(\"g\").classed(M.cbtitle,!0)})),c.ensureSingle(r,\"rect\",M.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,_=e.title,A=_.side,S=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),E=\"function\"==typeof v.color?v.color:function(){return v.color},C=\"function\"==typeof h?h:function(){return h},L=e._levels,I=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],f=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<f&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var h=e._filllevels;if(h)for(l=h.end+h.size/100,c=h.size,i=0;i<1e5&&(n=h.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map((function(t){return t-a.size/2}))).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);a.size<0&&(o.reverse(),s.reverse());return{line:o,fill:s}}(0,e,S),P=I.fill,z=I.line,O=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),D=O/l.w,R=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),F=R/l.h,B=e.xpad/l.w,N=(e.borderwidth+e.outlinewidth)/2,j=e.ypad/l.h,U=Math.round(e.x*l.w+e.xpad),V=e.x-D*({middle:.5,right:1}[e.xanchor]||0),q=e.y+F*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),H=Math.round(l.h*(1-q)),G=H-R;e._lenFrac=F,e._thickFrac=D,e._xLeftFrac=V,e._yBottomFrac=q;var Y=e._axis=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,ticklabelposition:e.ticklabelposition,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,minexponent:e.minexponent,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,noTicklabelmode:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,b,t,e)}return y(i,a,s,o,n),x(i,a,s,o),a}(r,e,S);Y.position=e.x+B+D,-1!==[\"top\",\"bottom\"].indexOf(A)&&(Y.title.side=A,Y.titlex=e.x+B,Y.titley=q+(\"top\"===_.side?F-j:j));if(v.color&&\"auto\"===e.tickmode){Y.tickmode=\"linear\",Y.tick0=L.start;var W=L.size,X=c.constrain((H-G)/50,4,15)+1,Z=(S[1]-S[0])/((e.nticks||X)*W);if(Z>1){var J=Math.pow(10,Math.floor(Math.log(Z)/Math.LN10));W*=J*c.roundUp(Z/J,[2,5,10]),(Math.abs(L.start)/L.size+1e-6)%1<2e-6&&(Y.tick0=0)}Y.dtick=W}Y.domain=[q+j,q+F-j],Y.setScale(),t.attr(\"transform\",u(Math.round(l.l),Math.round(l.t)));var K,Q=t.select(\".\"+M.cbtitleunshift).attr(\"transform\",u(-Math.round(l.l),-Math.round(l.t))),$=t.select(\".\"+M.cbaxis),tt=0;function et(n,i){var a={propContainer:Y,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+M.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),g.draw(r,n,f(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+B)*l.w,n=Y.title.font.size;t=\"top\"===A?(1-(q+F-j))*l.h+l.t+3+.75*n:(1-(q+j))*l.h+l.t-3-.25*n,et(Y._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+M.cbtitle),o=a.select(\"text\"),f=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+Y._id+\"title-math-group\").node(),d=15.6;if(o.node()&&(d=parseInt(o.node().style.fontSize,10)*w),h?(tt=p.bBox(h).height)>d&&(f[1]-=(tt-d)/2):o.node()&&!o.classed(M.jsPlaceholder)&&(tt=p.bBox(o.node()).height),tt){if(tt+=5,\"top\"===A)Y.domain[1]-=tt/l.h,f[1]*=-1;else{Y.domain[0]+=tt/l.h;var g=m.lineCount(o);f[1]+=(1-g)*d}a.attr(\"transform\",u(f[0],f[1])),Y.setScale()}}t.selectAll(\".\"+M.cbfills+\",.\"+M.cblines).attr(\"transform\",u(0,Math.round(l.h*(1-Y.domain[1])))),$.attr(\"transform\",u(0,Math.round(-l.t)));var y=t.select(\".\"+M.cbfills).selectAll(\"rect.\"+M.cbfill).attr(\"style\",\"\").data(P);y.enter().append(\"rect\").classed(M.cbfill,!0).style(\"stroke\",\"none\"),y.exit().remove();var x=S.map(Y.c2p).map(Math.round).sort((function(t,e){return t-e}));y.each((function(t,a){var o=[0===a?S[0]:(P[a]+P[a-1])/2,a===P.length-1?S[1]:(P[a]+P[a+1])/2].map(Y.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,x[0],x[1]);var s=n.select(this).attr({x:U,width:Math.max(O,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)p.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=C(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}}));var b=t.select(\".\"+M.cblines).selectAll(\"path.\"+M.cbline).data(v.color&&v.width?z:[]);b.enter().append(\"path\").classed(M.cbline,!0),b.exit().remove(),b.each((function(t){n.select(this).attr(\"d\",\"M\"+U+\",\"+(Math.round(Y.c2p(t))+v.width/2%1)+\"h\"+O).call(p.lineGroupStyle,v.width,E(t),v.dash)})),$.selectAll(\"g.\"+Y._id+\"tick,path\").remove();var _=U+O+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),T=s.calcTicks(Y),k=s.getTickSigns(Y)[2];return s.drawTicks(r,Y,{vals:\"inside\"===Y.ticks?s.clipEnds(Y,T):T,layer:$,path:s.makeTickPath(Y,_,k),transFn:s.makeTransTickFn(Y)}),s.drawLabels(r,Y,{vals:T,layer:$,transFn:s.makeTransTickLabelFn(Y),labelFns:s.makeLabelFns(Y,_)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=Y.title.font.size,e=Y._offset+Y._length/2,i=l.l+(Y.position||0)*l.w+(\"right\"===Y.side?10+t*(Y.showticklabels?1:.5):-10-t*(Y.showticklabels?.5:0));et(\"h\"+Y._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+Y._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=O+e.outlinewidth/2;if(-1===Y.ticklabelposition.indexOf(\"inside\")&&(n+=p.bBox($.node()).width),(K=Q.select(\"text\")).node()&&!K.classed(M.jsPlaceholder)){var i,o=Q.select(\".h\"+Y._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?p.bBox(o).width:p.bBox(Q.node()).right-U-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=H-G;t.select(\".\"+M.cbbg).attr({x:U-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:G-N,width:Math.max(s,2),height:Math.max(c+2*N,2)}).call(d.fill,e.bgcolor).call(d.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+M.cboutline).attr({x:U,y:G+e.ypad+(\"top\"===A?tt:0),width:Math.max(O,2),height:Math.max(c-2*e.ypad-tt,2)}).call(d.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var f=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",u(l.l-f,l.t));var h={},g=T[e.yanchor],m=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*g,h.b=c*m):(h.t=h.b=0,h.yt=e.y+e.len*g,h.yb=e.y-e.len*m);var v=T[e.xanchor],y=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*y;else{var x=s-O;h.l=x*v,h.r=x*y,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*y}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+u(r,o)),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)})),e.exit().each((function(e){a.autoMargin(t,e._id)})).remove(),e.order()}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/extend\":768,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_defaults\":830,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/cartesian/position_defaults\":845,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../colorscale/helpers\":654,\"../dragelement\":662,\"../drawing\":665,\"../titles\":738,\"./constants\":645,d3:169,tinycolor2:576}],648:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":778}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":644,\"./defaults\":646,\"./draw\":647,\"./has_colorbar\":648}],650:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,f=e.editTypeOverride||\"\",h=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(h+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",m=s+\"mid\",v=(o(h+p),o(h+d),o(h+g),{});v[d]=v[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:f||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:v},x[d]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[m]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:v},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":795,\"../colorbar/attributes\":644,\"./scales.js\":658}],651:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,f=a(u),h=!1!==f.auto,p=f.min,d=f.max,g=f.mid,m=function(){return i.aggNums(Math.min,null,l)},v=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=m():h&&(p=u._colorAx&&n(p)?Math.min(p,m()):m()),void 0===d?d=v():h&&(d=u._colorAx&&n(d)?Math.max(d,v()):v()),h&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),f._sync(\"min\",p),f._sync(\"max\",d),f.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,f._sync(\"colorscale\",o))}},{\"../../lib\":778,\"./helpers\":654,\"fast-isnumeric\":241}],652:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var f in e._colorAxes)o(e[f],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":778,\"./helpers\":654}],653:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,f,h){var p=h.prefix,d=h.cLetter,g=\"_module\"in r,m=c(e,p),v=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,f,h)};if(g){var b=u._colorAxes||{},_=f(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",T=b[_];return void(T?(T[2].push(x),T[0]!==w&&(T[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var k=m[d+\"min\"],M=m[d+\"max\"],A=n(k)&&n(M)&&k<M;f(p+d+\"auto\",!A)?f(p+d+\"mid\"):(f(p+d+\"min\"),f(p+d+\"max\"));var S,E,C=m.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),f(p+\"autocolorscale\",S),f(p+\"colorscale\"),f(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(m)),f(p+\"showscale\",E)&&(p&&y&&(v._template=y),o(m,v,u)))}},{\"../../lib\":778,\"../../registry\":911,\"../colorbar/defaults\":646,\"../colorbar/has_colorbar\":648,\"./scales\":658,\"fast-isnumeric\":241}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function f(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)((s=\"c\"+(n=u[r]))in a||(s=\"z\"+n)in a)&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function h(t){for(var e=f(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var f=i(o[u]).toRgb();c[u]=[f.r,f.g,f.b,f.a]}var h,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,m=e.returnArray;return(h=d&&m?p:d?function(t){return g(p(t))}:m?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,h.range=function(){return o},h}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e,r){var n=e?o.nestedProperty(t,e).get()||{}:t,i=n[r||\"color\"],s=!1;if(o.isArrayOrTypedArray(i))for(var c=0;c<i.length;c++)if(a(i[c])){s=!0;break}return o.isPlainObject(n)&&(s||!0===n.showscale||a(n.cmin)&&a(n.cmax)||l(n.colorscale)||o.isPlainObject(n.colorbar))},extractOpts:f,extractScale:h,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(h(t),e)}}},{\"../../lib\":778,\"../color\":643,\"./scales\":658,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],655:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":650,\"./calc\":651,\"./cross_trace_defaults\":652,\"./defaults\":653,\"./helpers\":654,\"./layout_attributes\":656,\"./layout_defaults\":657,\"./scales\":658}],656:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":768,\"./attributes\":650,\"./scales\":658}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var f in c){var h=c[f];if(h[0])s=t[f]||{},(l=i.newContainer(e,f,\"coloraxis\"))._name=f,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<h[2].length;p++)h[2][p]();delete e._colorAxes[f]}}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"./defaults\":653,\"./layout_attributes\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:576}],659:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],660:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":778}],661:[function(t,e,r){\"use strict\";r.selectMode=function(t){return\"lasso\"===t||\"select\"===t},r.drawMode=function(t){return\"drawclosedpath\"===t||\"drawopenpath\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.openMode=function(t){return\"drawline\"===t||\"drawopenpath\"===t},r.rectMode=function(t){return\"select\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.freeMode=function(t){return\"lasso\"===t||\"drawclosedpath\"===t||\"drawopenpath\"===t},r.selectingOrDrawing=function(t){return r.freeMode(t)||r.rectMode(t)}},{}],662:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function f(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,h,p,d,g,m=t.gd,v=1,y=m._context.doubleClickDelay,x=t.element;m._mouseDownTime||(m._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){m._dragged=!1,m._dragging=!0;var o=f(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-m._mouseDownTime<y?v+=1:(v=1,m._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(h=u()).style.cursor=window.getComputedStyle(x).cursor:i||(h=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",T),document.addEventListener(\"touchend\",T),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w,{passive:!1}))}function w(n){n.preventDefault();var i=f(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(m._dragged=!0,l.unhover(m)),m._dragged&&t.moveFn&&!g&&(m._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function T(e){if(delete m._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",T),document.removeEventListener(\"touchend\",T),i?o(h):c&&(h.documentElement.style.cursor=c,c=null),m._dragging){if(m._dragging=!1,(new Date).getTime()-m._mouseDownTime>y&&(v=Math.max(v-1,1)),m._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(v,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=f(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}m._dragging=!1,m._dragged=!1}else m._dragged=!1}},l.coverSlip=u},{\"../../lib\":778,\"../../plots/cartesian/constants\":834,\"./align\":659,\"./cursor\":660,\"./unhover\":663,\"has-hover\":440,\"has-passive-events\":441,\"mouse-event-offset\":484}],663:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":766,\"../../lib/events\":767,\"../../lib/throttle\":804,\"../fx/constants\":677}],664:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),p=t(\"../../constants/alignment\").LINE_SPACING,d=t(\"../../constants/interactions\").DESELECTDIM,g=t(\"../../traces/scatter/subtypes\"),m=t(\"../../traces/scatter/make_bubble_size_func\"),v=t(\"../../components/fx/helpers\").appendArrayPointValue,y=e.exports={};y.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},y.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},y.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},y.setRect=function(t,e,r,n,i){t.call(y.setPosition,e,r).call(y.setSize,n,i)},y.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",u(a,o)),!0)},y.translatePoints=function(t,e,r){t.each((function(t){var i=n.select(this);y.translatePoint(t,i,e,r)}))},y.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},y.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each((function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each((function(t){y.hideOutsideRangePoint(t,n.select(this),r,i,s,l)}))}))}},y.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},y.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),y.dashLine(e,l,o)},y.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each((function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(y.dashLine,l,o)}))},y.dashLine=function(t,e,r){r=+r||0,e=y.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},y.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},y.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},y.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each((function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)}))};var x=t(\"./symbol_defs\");y.symbolNames=[],y.symbolFuncs=[],y.symbolNeedLines={},y.symbolNoDot={},y.symbolNoFill={},y.symbolList=[],Object.keys(x).forEach((function(t){var e=x[t],r=e.n;y.symbolList.push(r,String(r),t,r+100,String(r+100),t+\"-open\"),y.symbolNames[r]=t,y.symbolFuncs[r]=e.f,e.needLine&&(y.symbolNeedLines[r]=!0),e.noDot?y.symbolNoDot[r]=!0:y.symbolList.push(r+200,String(r+200),t+\"-dot\",r+300,String(r+300),t+\"-open-dot\"),e.noFill&&(y.symbolNoFill[r]=!0)}));var b=y.symbolNames.length;function _(t,e){var r=t%100;return y.symbolFuncs[r](e)+(t>=200?\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\":\"\")}y.symbolNumber=function(t){if(i(t))t=+t;else if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=y.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=b||t>=400?0:Math.floor(Math.max(t,0))};var w={x1:1,x2:0,y1:0,y2:0},T={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),M={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:w},horizontalreversed:{node:\"linearGradient\",attrs:w,reversed:!0},vertical:{node:\"linearGradient\",attrs:T},verticalreversed:{node:\"linearGradient\",attrs:T,reversed:!0}};y.gradient=function(t,e,r,i,o,l){for(var u=o.length,f=M[i],h=new Array(u),p=0;p<u;p++)f.reversed?h[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:h[p]=[k(100*o[p][0]),o[p][1]];var d=e._fullLayout,g=\"g\"+d._uid+\"-\"+r,m=d._defs.select(\".gradients\").selectAll(\"#\"+g).data([i+h.join(\";\")],c.identity);m.exit().remove(),m.enter().append(f.node).each((function(){var t=n.select(this);f.attrs&&t.attr(f.attrs),t.attr(\"id\",g);var e=t.selectAll(\"stop\").data(h);e.exit().remove(),e.enter().append(\"stop\"),e.each((function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})}))})),t.style(l,O(g,e)).style(l+\"-opacity\",null);var v=function(t){return\".\"+t.attr(\"class\").replace(/\\s/g,\".\")},y=v(n.select(t.node().parentNode))+\">\"+v(t);d._gradientUrlQueryParts[y]=1},y.initGradients=function(t){var e=t._fullLayout;c.ensureSingle(e._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove(),e._gradientUrlQueryParts={}},y.pointStyle=function(t,e,r){if(t.size()){var i=y.makePointStyleFns(e);t.each((function(t){y.singlePointStyle(t,n.select(this),e,i,r)}))}},y.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=y.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",_(u,l))}var f,h,p,d=!1;if(t.so)p=o.outlierwidth,h=o.outliercolor,f=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,h=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(f=s.defaultLine,d=!0),f=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(f=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,f).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",(t.isBlank?0:p)+\"px\");var m=a.gradient,v=t.mgt;if(v?d=!0:v=m&&m.type,Array.isArray(v)&&(v=v[0],M[v]||(v=0)),v&&\"none\"!==v){var x=t.mgc;x?d=!0:x=m.color;var b=r.uid;d&&(b+=\"-\"+t.i),y.gradient(e,i,b,v,[[0,x],[1,f]],\"fill\")}else s.fill(e,f);p&&s.stroke(e,h)}},y.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=y.tryColorscale(r,\"\"),e.lineScale=y.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=g.isBubble(t)?m(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,y.makeSelectedPointStyleFns(t)),e},y.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,f=s.opacity,h=void 0!==u,p=void 0!==f;(c.isArrayOrTypedArray(l)||h||p)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?h?u:e:p?f:d*e});var g=i.color,m=a.color,v=s.color;(m||v)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?m||e:v||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},y.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,d))},e},y.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push((function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))})),r.selectedColorFn&&a.push((function(t,e){s.fill(t,r.selectedColorFn(e))})),r.selectedSizeFn&&a.push((function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",_(y.symbolNumber(n),a)),e.mrc2=a})),a.length&&t.each((function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)}))}},y.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function S(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(f.lineCount(t)-1)*p+1,h=A[s]*l,d=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",u(h,d))}function E(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}y.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=y.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}var o=e.texttemplate,s=r._fullLayout;t.each((function(t){var a=n.select(this),l=o?c.extractOption(t,e,\"txt\",\"texttemplate\"):c.extractOption(t,e,\"tx\",\"text\");if(l||0===l){if(o){var u=e._module.formatLabels?e._module.formatLabels(t,e,s):{},h={};v(h,e,t.i);var p=e._meta||{};l=c.texttemplateString(l,u,s._d3locale,h,t,p)}var d=t.tp||e.textposition,g=E(t,e),m=i?i(t):t.tc||e.textfont.color;a.call(y.font,t.tf||e.textfont.family,g,m).text(l).call(f.convertToTspans,r).call(S,d,g,t.mrc)}else a.remove()}))}},y.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedTextStyleFns(e);t.each((function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=E(t,e);s.fill(i,a),S(i,o,l,t.mrc2||t.mrc)}))}};function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,.25),u=Math.pow(s*s+l*l,.25),f=(u*u*a-c*c*s)*i,h=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&f/p),2),n.round(e[1]+(p&&h/p),2)],[n.round(e[0]-(d&&f/d),2),n.round(e[1]-(d&&h/d),2)]]}y.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},y.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},I=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};y.steps=function(t){var e=L[t]||I;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},y.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",(function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})})),e=c.ensureSingle(t,\"path\",\"js-reference-point\",(function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})}));y.tester=t,y.testref=e},y.savedBBoxes={};var P=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function O(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}y.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=y.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,u=+s.getAttribute(\"y\")||0,h=s.getAttribute(\"transform\");if(!h){var p=y.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),u&&(p.top+=u,p.bottom+=u),p}if(r+=\"~\"+l+\"~\"+u+\"~\"+h,i=y.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=y.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(f.positionText,0,0);var d=a.getBoundingClientRect(),g=y.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return P>=1e4&&(y.savedBBoxes={},P=0),r&&(y.savedBBoxes[r]=m),P++,c.extendFlat({},m)},y.setClipUrl=function(t,e,r){t.attr(\"clip-path\",O(e,r))},y.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},y.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=u(e,r)).trim(),t[i](\"transform\",a),a},y.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},y.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\"scale(\"+e+\",\"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;y.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\"scale(\"+e+\",\"+r+\")\";t.each((function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)}))}};var R=/translate\\([^)]*\\)\\s*$/;y.setTextPointsScale=function(t,e,r){t&&t.each((function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[u(o,s),\"scale(\"+e+\",\"+r+\")\",u(-o,-s)],l&&t.push(l),i.attr(\"transform\",t.join(\"\"))}}))}},{\"../../components/fx/helpers\":679,\"../../constants/alignment\":745,\"../../constants/interactions\":752,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../registry\":911,\"../../traces/scatter/make_bubble_size_func\":1204,\"../../traces/scatter/subtypes\":1212,\"../color\":643,\"../colorscale\":655,\"./symbol_defs\":666,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],666:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0},\"arrow-up\":{n:45,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-down\":{n:46,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-left\":{n:47,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-right\":{n:48,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-bar-up\":{n:49,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-down\":{n:50,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-left\":{n:51,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-right\":{n:52,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0}}},{d3:169}],667:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],668:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),f=0;f<t.length;f++){var h=t[f],p=h.i;if(void 0===p)p=f;else if(null===p)continue;var d=h[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var m=h[i+\"s\"]=d-g[0],v=h[i+\"h\"]=d+g[1];c.push(m,v)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./compute_error\":669,\"fast-isnumeric\":241}],669:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],670:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),f=t[c]||{};function h(t,e){return a.coerce(f,u,s,t,e)}if(!1!==h(\"visible\",void 0!==f.array||void 0!==f.value||\"sqrt\"===f.type)){var p=h(\"type\",\"array\"in f?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=h(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in f))),\"data\"===p?(h(\"array\"),h(\"traceref\"),d||(h(\"arrayminus\"),h(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(h(\"value\"),d||h(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&h(g,!(f.color||n(f.thickness)||n(f.width)));l.inherit&&u[g]||(h(\"color\",r),h(\"thickness\"),h(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911,\"./attributes\":667,\"fast-isnumeric\":241}],671:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":778,\"../../plot_api/edit_types\":810,\"./attributes\":667,\"./calc\":668,\"./compute_error\":669,\"./defaults\":670,\"./plot\":672,\"./style\":673}],672:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each((function(e){var f,h=e[0].trace,p=h.error_x||{},d=h.error_y||{};h.ids&&(f=function(t){return t.id});var g=o.hasMarkers(h)&&h.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var m=n.select(this).selectAll(\"g.errorbar\").data(e,f);if(m.exit().remove(),e.length){p.visible||m.selectAll(\"path.xerror\").remove(),d.visible||m.selectAll(\"path.yerror\").remove(),m.style(\"opacity\",1);var v=m.enter().append(\"g\").classed(\"errorbar\",!0);u&&v.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(m,r.layerClipId,t),m.each((function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var f=d.width;a=\"M\"+(r.x-f)+\",\"+r.yh+\"h\"+2*f+\"m-\"+f+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+f+\",0h\"+2*f),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var h=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var m=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-m)+\"v\"+2*m+\"m0,-\"+m+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+m+\"v\"+2*m),!h.size()?h=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(h=h.transition().duration(s.duration).ease(s.easing)),h.attr(\"d\",a)}else h.remove()}}))}}))}},{\"../../traces/scatter/subtypes\":1212,\"../drawing\":665,d3:169,\"fast-isnumeric\":241}],673:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each((function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)}))}},{\"../color\":643,d3:169}],674:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"./layout_attributes\":684}],675:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":778,\"../../registry\":911}],676:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":911,\"./hover\":680}],677:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,(function(r,a){return n.coerce(t,e,i,r,a)}),s)}},{\"../../lib\":778,\"./attributes\":674,\"./hoverlabel_defaults\":681}],679:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t.charAt(0)?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),f=new Array(r.length),h=0;h<r.length;h++)f[h]=o(u,r[h]);t[c]=f}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}var s={x:!0,y:!0},l={\"x unified\":!0,\"y unified\":!0};r.isUnifiedHover=function(t){return\"string\"==typeof t&&!!l[t]},r.isXYhover=function(t){return\"string\"==typeof t&&!!s[t]}},{\"../../lib\":778}],680:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=o.strTranslate,l=o.strRotate,c=t(\"../../lib/events\"),u=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/override_cursor\"),h=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../dragelement\"),g=t(\"../../plots/cartesian/axes\"),m=t(\"../../registry\"),v=t(\"./helpers\"),y=t(\"./constants\"),x=t(\"../legend/defaults\"),b=t(\"../legend/draw\"),_=y.YANGLE,w=Math.PI*_/180,T=1/Math.sin(w),k=Math.cos(w),M=Math.sin(w),A=y.HOVERARROWSIZE,S=y.HOVERTEXTPAD;function E(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")}r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+y.HOVERID,y.HOVERMINTIME,(function(){!function(t,e,r,a){r||(r=\"xy\");var s=Array.isArray(r)?r:[r],l=t._fullLayout,u=l._plots||[],h=u[r],g=l._has(\"cartesian\");if(h){var y=h.overlays.map((function(t){return t.id}));s=s.concat(y)}for(var x=s.length,b=new Array(x),_=new Array(x),w=!1,k=0;k<x;k++){var M=s[k];if(u[M])w=!0,b[k]=u[M].xaxis,_[k]=u[M].yaxis;else{if(!l[M]||!l[M]._subplot)return void o.warn(\"Unrecognized subplot: \"+M);var A=l[M]._subplot;b[k]=A.xaxis,_[k]=A.yaxis}}var S=e.hovermode||l.hovermode;S&&!w&&(S=\"closest\");if(-1===[\"x\",\"y\",\"closest\",\"x unified\",\"y unified\"].indexOf(S)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return d.unhoverRaw(t,e);var C,I,R,F,B,N,j,U,V,q,H,G,Y,W=-1===l.hoverdistance?1/0:l.hoverdistance,X=-1===l.spikedistance?1/0:l.spikedistance,Z=[],J=[],K={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(S=\"array\",R=0;R<e.length;R++)(B=t.calcdata[e[R].curveNumber||0])&&(N=B[0].trace,\"skip\"!==B[0].trace.hoverinfo&&(J.push(B),\"h\"===N.orientation&&(Q=!0)));else{for(F=0;F<t.calcdata.length;F++)B=t.calcdata[F],\"skip\"!==(N=B[0].trace).hoverinfo&&v.isTraceInSubplots(N,s)&&(J.push(B),\"h\"===N.orientation&&(Q=!0));var $,tt;if(!e.target)$=\"xpx\"in e?e.xpx:b[0]._length/2,tt=\"ypx\"in e?e.ypx:_[0]._length/2;else{if(!1===c.triggerHandler(t,\"plotly_beforehover\",e))return;var et=e.target.getBoundingClientRect();$=e.clientX-et.left,tt=e.clientY-et.top,l._calcInverseTransform(t);var rt=o.apply3DTransform(l._invTransform)($,tt);if($=rt[0],tt=rt[1],$<0||$>b[0]._length||tt<0||tt>_[0]._length)return d.unhoverRaw(t,e)}if(e.pointerX=$+b[0]._offset,e.pointerY=tt+_[0]._offset,C=\"xval\"in e?v.flat(s,e.xval):v.p2c(b,$),I=\"yval\"in e?v.flat(s,e.yval):v.p2c(_,tt),!i(C[0])||!i(I[0]))return o.warn(\"Fx.hover failed\",e,t),d.unhoverRaw(t,e)}var nt=1/0;function it(t,r){for(F=0;F<J.length;F++)if((B=J[F])&&B[0]&&B[0].trace&&!0===(N=B[0].trace).visible&&0!==N._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(N._module.name)){if(\"splom\"===N.type?j=s[U=0]:(j=v.getSubplot(N),U=s.indexOf(j)),V=S,v.isUnifiedHover(V)&&(V=V.charAt(0)),G={cd:B,trace:N,xa:b[U],ya:_[U],maxHoverDistance:W,maxSpikeDistance:X,index:!1,distance:Math.min(nt,W),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:p.defaultLine,name:N.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},l[j]&&(G.subplot=l[j]._subplot),l._splomScenes&&l._splomScenes[N.uid]&&(G.scene=l._splomScenes[N.uid]),Y=Z.length,\"array\"===V){var n=e[F];\"pointNumber\"in n?(G.index=n.pointNumber,V=\"closest\"):(V=\"\",\"xval\"in n&&(q=n.xval,V=\"x\"),\"yval\"in n&&(H=n.yval,V=V?\"closest\":\"y\"))}else void 0!==t&&void 0!==r?(q=t,H=r):(q=C[U],H=I[U]);if(0!==W)if(N._module&&N._module.hoverPoints){var a=N._module.hoverPoints(G,q,H,V,l._hoverlayer);if(a)for(var c,u=0;u<a.length;u++)c=a[u],i(c.x0)&&i(c.y0)&&Z.push(z(c,S))}else o.log(\"Unrecognized trace type in hover:\",N);if(\"closest\"===S&&Z.length>Y&&(Z.splice(0,Y),nt=Z[0].distance),g&&0!==X&&0===Z.length){G.distance=X,G.index=!1;var f=N._module.hoverPoints(G,q,H,\"closest\",l._hoverlayer);if(f&&(f=f.filter((function(t){return t.spikeDistance<=X}))),f&&f.length){var h,d=f.filter((function(t){return t.xa.showspikes&&\"hovered data\"!==t.xa.spikesnap}));if(d.length){var m=d[0];i(m.x0)&&i(m.y0)&&(h=ot(m),(!K.vLinePoint||K.vLinePoint.spikeDistance>h.spikeDistance)&&(K.vLinePoint=h))}var y=f.filter((function(t){return t.ya.showspikes&&\"hovered data\"!==t.ya.spikesnap}));if(y.length){var x=y[0];i(x.x0)&&i(x.y0)&&(h=ot(x),(!K.hLinePoint||K.hLinePoint.spikeDistance>h.spikeDistance)&&(K.hLinePoint=h))}}}}}function at(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<=i&&r<=e&&(n=t[a],i=r);return n}function ot(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}it();var st={fullLayout:l,container:l._hoverlayer,outerContainer:l._paperdiv,event:e},lt=t._spikepoints,ct={vLinePoint:K.vLinePoint,hLinePoint:K.hLinePoint};if(t._spikepoints=ct,g&&0!==X&&0!==Z.length){var ut=at(Z.filter((function(t){return t.ya.showspikes})),X);K.hLinePoint=ot(ut);var ft=at(Z.filter((function(t){return t.xa.showspikes})),X);K.vLinePoint=ot(ft)}if(0===Z.length){var ht=d.unhoverRaw(t,e);return!g||null===K.hLinePoint&&null===K.vLinePoint||D(lt)&&O(t,K,st),ht}g&&D(lt)&&O(t,K,st);if(Z.sort((function(t,e){return t.distance-e.distance})),v.isXYhover(V)&&0!==Z[0].length&&\"splom\"!==Z[0].trace.type){var pt=Z[0],dt=pt.cd[pt.index],gt=\"group\"===l.boxmode||\"group\"===l.violinmode,mt=pt.xVal,vt=pt.xa;\"category\"===vt.type&&(mt=vt._categoriesMap[mt]),\"date\"===vt.type&&(mt=vt.d2c(mt)),dt&&dt.t&&dt.t.posLetter===vt._id&&gt&&(mt+=dt.t.dPos);var yt=pt.yVal;\"category\"===(vt=pt.ya).type&&(yt=vt._categoriesMap[yt]),\"date\"===vt.type&&(yt=vt.d2c(yt)),dt&&dt.t&&dt.t.posLetter===vt._id&&gt&&(yt+=dt.t.dPos),it(mt,yt);var xt={};Z=Z.filter((function(t){var e=E(t);if(!xt[e])return xt[e]=!0,xt[e]}))}var bt=t._hoverdata,_t=[];for(R=0;R<Z.length;R++){var wt=Z[R],Tt=v.makeEventData(wt,wt.trace,wt.cd);if(!1!==wt.hovertemplate){var kt=!1;wt.cd[wt.index]&&wt.cd[wt.index].ht&&(kt=wt.cd[wt.index].ht),wt.hovertemplate=kt||wt.trace.hovertemplate||!1}wt.eventData=[Tt],_t.push(Tt)}t._hoverdata=_t;var Mt=\"y\"===S&&(J.length>1||Z.length>1)||\"closest\"===S&&Q&&Z.length>1,At=p.combine(l.plot_bgcolor||p.background,l.paper_bgcolor),St={hovermode:S,rotateLabels:Mt,bgColor:At,container:l._hoverlayer,outerContainer:l._paperdiv,commonLabelOpts:l.hoverlabel,hoverdistance:l.hoverdistance},Et=L(Z,St,t);v.isUnifiedHover(S)||(!function(t,e,r){var n,i,a,o,s,l,c,u=0,f=1,h=t.size(),p=new Array(h),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}t.each((function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(f=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?T:1)/2,pmin:0,pmax:i?r.width:r.height}]})),p.sort((function(t,e){return t[0].posref-e[0].posref||f*(e[0].traceIndex-t[0].traceIndex)}));for(;!n&&u<=h;){for(u++,n=!0,o=0;o<p.length-1;){var m=p[o],v=p[o+1],y=m[m.length-1],x=v[0];if((i=y.pos+y.dp+y.size-x.pos-x.dp+x.size)>.01&&y.pmin===x.pmin&&y.pmax===x.pmax){for(s=v.length-1;s>=0;s--)v[s].dp+=i;for(m.push.apply(m,v),p.splice(o+1,1),c=0,s=m.length-1;s>=0;s--)c+=m[s].dp;for(a=c/m.length,s=m.length-1;s>=0;s--)m[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var b=p[o];for(s=b.length-1;s>=0;s--){var _=b[s],w=_.datum;w.offset=_.dp,w.del=_.del}}}(Et,Mt?\"xa\":\"ya\",l),P(Et,Mt,l._invScaleX,l._invScaleY));if(e.target&&e.target.tagName){var Ct=m.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,_t);f(n.select(e.target),Ct?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,bt))return;bt&&t.emit(\"plotly_unhover\",{event:e,points:bt});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:b,yaxes:_,xvals:C,yvals:I})}(t,e,r,a)}))},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map((function(t){return{color:t.color||p.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}})),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||p.background,container:a,outerContainer:o},l=L(i,s,e.gd),c=0,u=0;l.sort((function(t,e){return t.y0-e.y0})).each((function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)})).each((function(t){t.offset-=u}));var f=e.gd._fullLayout._invScaleX,h=e.gd._fullLayout._invScaleY;return P(l,s.rotateLabels,f,h),r?l:l.node()};var C=/<extra>([\\s\\S]*)<\\/extra>/;function L(t,e,r){var i=r._fullLayout,a=e.hovermode,c=e.rotateLabels,f=e.bgColor,d=e.container,g=e.outerContainer,m=e.commonLabelOpts||{},w=e.fontFamily||y.HOVERFONT,T=e.fontSize||y.HOVERFONTSIZE,k=t[0],M=k.xa,C=k.ya,L=\"y\"===a.charAt(0)?\"yLabel\":\"xLabel\",P=k[L],z=(String(P)||\"\").split(\" \")[0],O=g.node().getBoundingClientRect(),D=O.top,R=O.width,F=O.height,B=void 0!==P&&k.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(B){var N,j,U=!0;for(N=0;N<t.length;N++)if(U&&void 0===t[N].zLabel&&(U=!1),j=t[N].hoverinfo||t[N].trace.hoverinfo){var V=Array.isArray(j)?j:j.split(\"+\");if(-1===V.indexOf(\"all\")&&-1===V.indexOf(a)){B=!1;break}}U&&(B=!1)}var q=d.selectAll(\"g.axistext\").data(B?[0]:[]);function H(t){return t.filter((function(t){return void 0!==t.zLabelVal||(t[L]||\"\").split(\" \")[0]===z}))}if(q.enter().append(\"g\").classed(\"axistext\",!0),q.exit().remove(),q.each((function(){var e=n.select(this),l=o.ensureSingle(e,\"path\",\"\",(function(t){t.style({\"stroke-width\":\"1px\"})})),c=o.ensureSingle(e,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),f=m.bgcolor||p.defaultLine,d=m.bordercolor||p.contrast(f),g=p.contrast(f),v={family:m.font.family||w,size:m.font.size||T,color:m.font.color||g};l.style({fill:f,stroke:d}),c.text(P).call(h.font,v).call(u.positionText,0,0).call(u.convertToTspans,r),e.attr(\"transform\",\"\");var y,x,b=c.node().getBoundingClientRect();if(\"x\"===a){var _=\"top\"===M.side?\"-\":\"\";c.attr(\"text-anchor\",\"middle\").call(u.positionText,0,\"top\"===M.side?D-b.bottom-A-S:D-b.top+A+S),y=M._offset+(k.x0+k.x1)/2,x=C._offset+(\"top\"===M.side?0:C._length);var E=b.width/2+S;y<E?(y=E,l.attr(\"d\",\"M-\"+(E-A)+\",0L-\"+(E-2*A)+\",\"+_+A+\"H\"+(S+b.width/2)+\"v\"+_+(2*S+b.height)+\"H-\"+E+\"V\"+_+A+\"Z\")):y>i.width-E?(y=i.width-E,l.attr(\"d\",\"M\"+(E-A)+\",0L\"+E+\",\"+_+A+\"v\"+_+(2*S+b.height)+\"H-\"+E+\"V\"+_+A+\"H\"+(E-2*A)+\"Z\")):l.attr(\"d\",\"M0,0L\"+A+\",\"+_+A+\"H\"+(S+b.width/2)+\"v\"+_+(2*S+b.height)+\"H-\"+(S+b.width/2)+\"V\"+_+A+\"H-\"+A+\"Z\")}else{var L,I,z;\"right\"===C.side?(L=\"start\",I=1,z=\"\",y=M._offset+M._length):(L=\"end\",I=-1,z=\"-\",y=M._offset),x=C._offset+(k.y0+k.y1)/2,c.attr(\"text-anchor\",L),l.attr(\"d\",\"M0,0L\"+z+A+\",\"+A+\"V\"+(S+b.height/2)+\"h\"+z+(2*S+b.width)+\"V-\"+(S+b.height/2)+\"H\"+z+A+\"V-\"+A+\"Z\");var O,R=b.height/2,F=D-b.top-R,B=\"clip\"+i._uid+\"commonlabel\"+C._id;if(y<b.width+2*S+A){O=\"M-\"+(A+S)+\"-\"+R+\"h-\"+(b.width-S)+\"V\"+R+\"h\"+(b.width-S)+\"Z\";var N=b.width-y+S;u.positionText(c,N,F),\"end\"===L&&c.selectAll(\"tspan\").each((function(){var t=n.select(this),e=h.tester.append(\"text\").text(t.text()).call(h.font,v),r=e.node().getBoundingClientRect();Math.round(r.width)<Math.round(b.width)&&t.attr(\"x\",N-r.width),e.remove()}))}else u.positionText(c,I*(S+A),F),O=null;var j=i._topclips.selectAll(\"#\"+B).data(O?[0]:[]);j.enter().append(\"clipPath\").attr(\"id\",B).append(\"path\"),j.exit().remove(),j.select(\"path\").attr(\"d\",O),h.setClipUrl(c,O?B:null,r)}e.attr(\"transform\",s(y,x)),t=H(t)})),v.isUnifiedHover(a)){if(d.selectAll(\"g.hovertext\").remove(),void 0!==P&&k.distance<=e.hoverdistance&&(t=H(t)),0===t.length)return;var G={showlegend:!0,legend:{title:{text:P,font:i.hoverlabel.font},font:i.hoverlabel.font,bgcolor:i.hoverlabel.bgcolor,bordercolor:i.hoverlabel.bordercolor,borderwidth:1,tracegroupgap:7,traceorder:i.legend?i.legend.traceorder:void 0,orientation:\"v\"}},Y={};x(G,Y,r._fullData);var W=Y.legend;W.entries=[];for(var X=0;X<t.length;X++){var Z=I(t[X],!0,a,i,P),J=Z[0],K=Z[1],Q=t[X];Q.name=K,Q.text=\"\"!==K?K+\" : \"+J:J;var $=Q.cd[Q.index];$&&($.mc&&(Q.mc=$.mc),$.mcc&&(Q.mc=$.mcc),$.mlc&&(Q.mlc=$.mlc),$.mlcc&&(Q.mlc=$.mlcc),$.mlw&&(Q.mlw=$.mlw),$.mrc&&(Q.mrc=$.mrc),$.dir&&(Q.dir=$.dir)),Q._distinct=!0,W.entries.push([Q])}W.entries.sort((function(t,e){return t[0].trace.index-e[0].trace.index})),W.layer=d,b(r,W);var tt=o.mean(t.map((function(t){return(t.y0+t.y1)/2}))),et=o.mean(t.map((function(t){return(t.x0+t.x1)/2}))),rt=d.select(\"g.legend\"),nt=rt.node().getBoundingClientRect();et+=M._offset,tt+=C._offset-nt.height/2;var it=nt.width+2*S;!(et+it<=R)&&et-it>=0?et-=it:et+=2*S;var at=nt.height+2*S,ot=tt+at>=F;return at<=F&&(tt<=D?tt=C._offset+2*S:ot&&(tt=F-at)),rt.attr(\"transform\",s(et,tt)),rt}var st=d.selectAll(\"g.hovertext\").data(t,(function(t){return E(t)}));return st.enter().append(\"g\").classed(\"hovertext\",!0).each((function(){var t=n.select(this);t.append(\"rect\").call(p.fill,p.addOpacity(f,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(h.font,w,T)})),st.exit().remove(),st.each((function(t){var e=n.select(this).attr(\"transform\",\"\"),o=t.color;Array.isArray(o)&&(o=o[t.eventData[0].pointNumber]);var d=t.bgcolor||o,g=p.combine(p.opacity(d)?d:p.defaultLine,f),m=p.combine(p.opacity(o)?o:p.defaultLine,f),v=t.borderColor||p.contrast(g),y=I(t,B,a,i,P,e),x=y[0],b=y[1],k=e.select(\"text.nums\").call(h.font,t.fontFamily||w,t.fontSize||T,t.fontColor||v).text(x).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r),M=e.select(\"text.name\"),E=0,C=0;if(b&&b!==x){M.call(h.font,t.fontFamily||w,t.fontSize||T,m).text(b).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r);var L=M.node().getBoundingClientRect();E=L.width+2*S,C=L.height+2*S}else M.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:g,stroke:v});var z,O,N=k.node().getBoundingClientRect(),j=t.xa._offset+(t.x0+t.x1)/2,U=t.ya._offset+(t.y0+t.y1)/2,V=Math.abs(t.x1-t.x0),q=Math.abs(t.y1-t.y0),H=N.width+A+S+E;if(t.ty0=D-N.top,t.bx=N.width+2*S,t.by=Math.max(N.height+2*S,C),t.anchor=\"start\",t.txwidth=N.width,t.tx2width=E,t.offset=0,c)t.pos=j,z=U+q/2+H<=F,O=U-q/2-H>=0,\"top\"!==t.idealAlign&&z||!O?z?(U+=q/2,t.anchor=\"start\"):t.anchor=\"middle\":(U-=q/2,t.anchor=\"end\");else if(t.pos=U,z=j+V/2+H<=R,O=j-V/2-H>=0,\"left\"!==t.idealAlign&&z||!O)if(z)j+=V/2,t.anchor=\"start\";else{t.anchor=\"middle\";var G=H/2,Y=j+G-R,W=j-G;Y>0&&(j-=Y),W<0&&(j+=-W)}else j-=V/2,t.anchor=\"end\";k.attr(\"text-anchor\",t.anchor),E&&M.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",s(j,U)+(c?l(_):\"\"))})),st}function I(t,e,r,n,i,a){var s=\"\",l=\"\";void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),s=R(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(l+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(l+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(l+=(l?\"z: \":\"\")+t.zLabel)):e&&t[r.charAt(0)+\"Label\"]===i?l=t[(\"x\"===r.charAt(0)?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(l=t.yLabel):l=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(l+=(l?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(l+=(l?\"<br>\":\"\")+t.extraText),a&&\"\"===l&&!t.hovertemplate&&(\"\"===s&&a.remove(),l=s);var c=n._d3locale,u=t.hovertemplate||!1,f=t.hovertemplateLabels||t,h=t.eventData[0]||{};return u&&(l=(l=o.hovertemplateString(u,f,c,h,t.trace._meta)).replace(C,(function(e,r){return s=R(r,t.nameLength),\"\"}))),[l,s]}function P(t,e,r,i){var a=function(t){return t*r},o=function(t){return t*i};t.each((function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),s=t.anchor,l=\"end\"===s?-1:1,c={start:1,end:-1,middle:0}[s],f=c*(A+S),p=f+c*(t.txwidth+S),d=0,g=t.offset,m=\"middle\"===s;m&&(f-=t.tx2width/2,p+=t.txwidth/2+S),e&&(g*=-M,d=t.offset*k),r.select(\"path\").attr(\"d\",m?\"M-\"+a(t.bx/2+t.tx2width/2)+\",\"+o(g-t.by/2)+\"h\"+a(t.bx)+\"v\"+o(t.by)+\"h-\"+a(t.bx)+\"Z\":\"M0,0L\"+a(l*A+d)+\",\"+o(A+g)+\"v\"+o(t.by/2-A)+\"h\"+a(l*t.bx)+\"v-\"+o(t.by)+\"H\"+a(l*A+d)+\"V\"+o(g-A)+\"Z\");var v=d+f,y=g+t.ty0-t.by/2+S,x=t.textAlign||\"auto\";\"auto\"!==x&&(\"left\"===x&&\"start\"!==s?(i.attr(\"text-anchor\",\"start\"),v=m?-t.bx/2-t.tx2width/2+S:-t.bx-S):\"right\"===x&&\"end\"!==s&&(i.attr(\"text-anchor\",\"end\"),v=m?t.bx/2-t.tx2width/2-S:t.bx+S)),i.call(u.positionText,a(v),o(y)),t.tx2width&&(r.select(\"text.name\").call(u.positionText,a(p+c*S+d),o(g+t.ty0-t.by/2+S)),r.select(\"rect\").call(h.setRect,a(p+(c-1)*t.tx2width/2+d),o(g-t.by/2-1),a(t.tx2width),o(t.by+2)))}))}function z(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:g.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:g.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var f=g.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+f+\" / -\"+g.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+f,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var h=g.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+h+\" / -\"+g.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+h,\"y\"===e&&(t.distance+=1)}var p=t.hoverinfo||t.trace.hoverinfo;return p&&\"all\"!==p&&(-1===(p=Array.isArray(p)?p:p.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===p.indexOf(\"y\")&&(t.yLabel=void 0),-1===p.indexOf(\"z\")&&(t.zLabel=void 0),-1===p.indexOf(\"text\")&&(t.text=void 0),-1===p.indexOf(\"name\")&&(t.name=void 0)),t}function O(t,e,r){var n,i,o=r.container,s=r.fullLayout,l=s._size,c=r.event,u=!!e.hLinePoint,f=!!e.vLinePoint;if(o.selectAll(\".spikeline\").remove(),f||u){var d=p.combine(s.plot_bgcolor,s.paper_bgcolor);if(u){var m,v,y=e.hLinePoint;n=y&&y.xa,\"cursor\"===(i=y&&y.ya).spikesnap?(m=c.pointerX,v=c.pointerY):(m=n._offset+y.x,v=i._offset+y.y);var x,b,_=a.readability(y.color,d)<1.5?p.contrast(d):y.color,w=i.spikemode,T=i.spikethickness,k=i.spikecolor||_,M=g.getPxPosition(t,i);if(-1!==w.indexOf(\"toaxis\")||-1!==w.indexOf(\"across\")){if(-1!==w.indexOf(\"toaxis\")&&(x=M,b=m),-1!==w.indexOf(\"across\")){var A=i._counterDomainMin,S=i._counterDomainMax;\"free\"===i.anchor&&(A=Math.min(A,i.position),S=Math.max(S,i.position)),x=l.l+A*l.w,b=l.l+S*l.w}o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T,stroke:k,\"stroke-dasharray\":h.dashStyle(i.spikedash,T)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==w.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:M+(\"right\"!==i.side?T:-T),cy:v,r:T,fill:k}).classed(\"spikeline\",!0)}if(f){var E,C,L=e.vLinePoint;n=L&&L.xa,i=L&&L.ya,\"cursor\"===n.spikesnap?(E=c.pointerX,C=c.pointerY):(E=n._offset+L.x,C=i._offset+L.y);var I,P,z=a.readability(L.color,d)<1.5?p.contrast(d):L.color,O=n.spikemode,D=n.spikethickness,R=n.spikecolor||z,F=g.getPxPosition(t,n);if(-1!==O.indexOf(\"toaxis\")||-1!==O.indexOf(\"across\")){if(-1!==O.indexOf(\"toaxis\")&&(I=F,P=C),-1!==O.indexOf(\"across\")){var B=n._counterDomainMin,N=n._counterDomainMax;\"free\"===n.anchor&&(B=Math.min(B,n.position),N=Math.max(N,n.position)),I=l.t+(1-N)*l.h,P=l.t+(1-B)*l.h}o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D,stroke:R,\"stroke-dasharray\":h.dashStyle(n.spikedash,D)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==O.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:E,cy:F-(\"top\"!==n.side?D:-D),r:D,fill:R}).classed(\"spikeline\",!0)}}}function D(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function R(t,e){return u.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":778,\"../../lib/events\":767,\"../../lib/override_cursor\":789,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../legend/defaults\":695,\"../legend/draw\":696,\"./constants\":677,\"./helpers\":679,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],681:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"./helpers\").isUnifiedHover;e.exports=function(t,e,r,o){function s(t){o.font[t]||(o.font[t]=e.legend?e.legend.font[t]:e.font[t])}o=o||{},e&&a(e.hovermode)&&(o.font||(o.font={}),s(\"size\"),s(\"family\"),s(\"color\"),e.legend?(o.bgcolor||(o.bgcolor=i.combine(e.legend.bgcolor,e.paper_bgcolor)),o.bordercolor||(o.bordercolor=e.legend.bordercolor)):o.bgcolor||(o.bgcolor=e.paper_bgcolor)),r(\"hoverlabel.bgcolor\",o.bgcolor),r(\"hoverlabel.bordercolor\",o.bordercolor),r(\"hoverlabel.namelength\",o.namelength),n.coerceFont(r,\"hoverlabel.font\",o.font),r(\"hoverlabel.align\",o.align)}},{\"../../lib\":778,\"../color\":643,\"./helpers\":679}],682:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return void 0!==e[r]?e[r]:n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");return e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=(r[a]||{})[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==o.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)}},{\"../../lib\":778,\"./layout_attributes\":684}],683:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",(function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)}))},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":778,\"../dragelement\":662,\"./attributes\":674,\"./calc\":675,\"./click\":676,\"./constants\":677,\"./defaults\":678,\"./helpers\":679,\"./hover\":680,\"./layout_attributes\":684,\"./layout_defaults\":685,\"./layout_global_defaults\":686,d3:169}],684:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"drawclosedpath\",\"drawopenpath\",\"drawline\",\"drawrect\",\"drawcircle\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1,\"x unified\",\"y unified\"],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":856,\"./constants\":677}],685:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").isUnifiedHover,a=t(\"./layout_attributes\"),o=t(\"./hovermode_defaults\"),s=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r){function l(r,i){return n.coerce(t,e,a,r,i)}var c=o(t,e,r);c&&(l(\"hoverdistance\"),l(\"spikedistance\",i(c)?-1:void 0)),\"select\"===l(\"dragmode\")&&l(\"selectdirection\");var u=e._has(\"mapbox\"),f=e._has(\"geo\"),h=e._basePlotModules.length;\"zoom\"===e.dragmode&&((u||f)&&1===h||u&&f&&2===h)&&(e.dragmode=\"pan\"),s(t,e,l)}},{\"../../lib\":778,\"./helpers\":679,\"./hoverlabel_defaults\":681,\"./hovermode_defaults\":682,\"./layout_attributes\":684}],686:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,(function(r,i){return n.coerce(t,e,a,r,i)}))}},{\"../../lib\":778,\"./hoverlabel_defaults\":681,\"./layout_attributes\":684}],687:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),f=u*(1-o),h=0;h<i;h++){var p=c+u*h;l[a?i-1-h:h]=[p,p+f]}return l}function f(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,f,h=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;h?(o=r.subplots.length,f=r.subplots[0].length):(d&&(o=a.length),p&&(f=i.length));var m=s.newContainer(e,\"grid\"),v=k(\"rows\",o),y=k(\"columns\",f);if(v*y>1){if(!h&&!p&&!d)\"independent\"===k(\"pattern\")&&(h=!0);m._hasSubplotGrid=h;var x,b,_=\"top to bottom\"===k(\"roworder\"),w=h?.2:.1,T=h?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),m._domains={x:u(\"x\",k,w,x,y),y:u(\"y\",k,T,b,v,_)}}else delete e.grid}function k(t,e){return n.coerce(r,m,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,h=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,m=r.columns,v=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=h.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(m),w=x[n]||[];for(i=0;i<m;i++)if(v?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var T=c(e,h,\"x\"),k=c(e,h,\"y\");r.xaxes=f(T,p.xaxis,m,y,\"x\"),r.yaxes=f(k,p.yaxis,g,y,\"y\")}var M=r._anchors={},A=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,I=S.charAt(0),P=r[I+\"side\"];if(P.length<8)M[S]=\"free\";else if(\"x\"===I){if(\"t\"===P.charAt(0)===A?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){M[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){M[S]=o;break}}else if(\"l\"===P.charAt(0)?(E=0,C=1,L=m):(E=m-1,C=-1,L=-1),d){var O=y[S];for(n=E;n!==L;n+=C)if((s=l[O][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){M[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){M[S]=a;break}}}}}},{\"../../lib\":778,\"../../lib/regex\":795,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/domain\":855}],688:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":746,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834}],689:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,f=e._id.charAt(0),h=0;h<u.length;h++)if(c=\"images[\"+h+\"].\",(l=u[h])[f+\"ref\"]===e._id){var p=l[f],d=l[\"size\"+f],g=null,m=null;if(o){g=i(p,e.range);var v=d/Math.pow(10,g)/2;m=2*Math.log(v+Math.sqrt(1+v*v))/Math.LN10}else m=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(m)||(m=null):(g=null,m=null),a(c+f,g),a(c+\"size\"+f,m)}}},{\"../../lib/to_log_range\":805,\"fast-isnumeric\":241}],690:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var f=c[u],h=i.coerceRef(t,e,l,f,\"paper\",void 0);if(\"paper\"!==h)i.getFromId(l,h)._imgIndices.push(e._index);i.coercePosition(e,l,a,h,f,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":688}],691:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/axis_ids\"),s=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,l=t._fullLayout,c=[],u={},f=[];for(r=0;r<l.images.length;r++){var h=l.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=o.ref2id(h.xref)+o.ref2id(h.yref);var p=l._plots[e];if(!p){f.push(h);continue}p.mainplot&&(e=p.mainplot.id),u[e]||(u[e]=[]),u[e].push(h)}else\"above\"===h.layer?c.push(h):f.push(h)}var d={left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},g={top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}};function m(e){var r=n.select(this);if(this._imgSrc!==e.source)if(r.attr(\"xmlns\",s.svg),e.source&&\"data:\"===e.source.slice(0,5))r.attr(\"xlink:href\",e.source),this._imgSrc=e.source;else{var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source,this._imgSrc=e.source}.bind(this));t._promises.push(i)}}function v(e){var r,o,s=n.select(this),c=a.getFromId(t,e.xref),u=a.getFromId(t,e.yref),f=\"domain\"===a.getRefType(e.xref),h=\"domain\"===a.getRefType(e.yref),p=l._size;r=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.sizex:Math.abs(c.l2p(e.sizex)-c.l2p(0)):e.sizex*p.w,o=void 0!==u?\"string\"==typeof e.yref&&h?u._length*e.sizey:Math.abs(u.l2p(e.sizey)-u.l2p(0)):e.sizey*p.h;var m,v,y=r*d[e.xanchor].offset,x=o*g[e.yanchor].offset,b=d[e.xanchor].sizing+g[e.yanchor].sizing;switch(m=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.x+c._offset:c.r2p(e.x)+c._offset:e.x*p.w+p.l,m+=y,v=void 0!==u?\"string\"==typeof e.yref&&h?u._length*(1-e.y)+u._offset:u.r2p(e.y)+u._offset:p.h-e.y*p.h+p.t,v+=x,e.sizing){case\"fill\":b+=\" slice\";break;case\"stretch\":b=\"none\"}s.attr({x:m,y:v,width:r,height:o,preserveAspectRatio:b,opacity:e.opacity});var _=(c&&\"domain\"!==a.getRefType(e.xref)?c._id:\"\")+(u&&\"domain\"!==a.getRefType(e.yref)?u._id:\"\");i.setClipUrl(s,_?\"clip\"+l._uid+_:null,t)}var y=l._imageLowerLayer.selectAll(\"image\").data(f),x=l._imageUpperLayer.selectAll(\"image\").data(c);y.enter().append(\"image\"),x.enter().append(\"image\"),y.exit().remove(),x.exit().remove(),y.each((function(t){m.bind(this)(t),v.bind(this)(t)})),x.each((function(t){m.bind(this)(t),v.bind(this)(t)}));var b=Object.keys(l._plots);for(r=0;r<b.length;r++){e=b[r];var _=l._plots[e];if(_.imagelayer){var w=_.imagelayer.selectAll(\"image\").data(u[e]||[]);w.enter().append(\"image\"),w.exit().remove(),w.each((function(t){m.bind(this)(t),v.bind(this)(t)}))}}}},{\"../../constants/xmlns_namespaces\":754,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_ids\":831,\"../drawing\":665,d3:169}],692:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":688,\"./convert_coords\":689,\"./defaults\":690,\"./draw\":691}],693:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemwidth:{valType:\"number\",min:30,dflt:30,editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"legend\"},font:n({editType:\"legend\"}),side:{valType:\"enumerated\",values:[\"top\",\"left\",\"top left\"],editType:\"legend\"},editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":856,\"../color/attributes\":642}],694:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,scrollBarEnterAttrs:{rx:20,ry:3,width:0,height:0},titlePad:2,itemGap:5}},{}],695:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c=t.legend||{},u=0,f=!1,h=\"normal\",p=0;p<r.length;p++){var d=r[p];d.visible&&((d.showlegend||d._dfltShowLegend&&!(d._module&&d._module.attributes&&d._module.attributes.showlegend&&!1===d._module.attributes.showlegend.dflt))&&(u++,d.showlegend&&(f=!0,(n.traceIs(d,\"pie-like\")||!0===d._input.showlegend)&&u++)),(n.traceIs(d,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(d.fill))&&(h=l.isGrouped({traceorder:h})?\"grouped+reversed\":\"reversed\"),void 0!==d.legendgroup&&\"\"!==d.legendgroup&&(h=l.isReversed({traceorder:h})?\"reversed+grouped\":\"grouped\"))}var g=i.coerce(t,e,s,\"showlegend\",f&&u>1);if(!1!==g||c.uirevision){var m=a.newContainer(e,\"legend\");if(_(\"uirevision\",e.uirevision),!1!==g){_(\"bgcolor\",e.paper_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),i.coerceFont(_,\"font\",e.font);var v,y,x,b=_(\"orientation\");\"h\"===b?(v=0,n.getComponentMethod(\"rangeslider\",\"isVisible\")(t.xaxis)?(y=1.1,x=\"bottom\"):(y=-.1,x=\"top\")):(v=1.02,y=1,x=\"auto\"),_(\"traceorder\",h),l.isGrouped(e.legend)&&_(\"tracegroupgap\"),_(\"itemsizing\"),_(\"itemwidth\"),_(\"itemclick\"),_(\"itemdoubleclick\"),_(\"x\",v),_(\"xanchor\"),_(\"y\",y),_(\"yanchor\",x),_(\"valign\"),i.noneOrAll(c,m,[\"x\",\"y\"]),_(\"title.text\")&&(_(\"title.side\",\"h\"===b?\"left\":\"top\"),i.coerceFont(_,\"title.font\",e.font))}}function _(t,e){return i.coerce(c,m,o,t,e)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/layout_attributes\":882,\"../../registry\":911,\"./attributes\":693,\"./helpers\":699}],696:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,m=d.FROM_TL,v=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout((function(){h(r,t,n)}),t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&h(r,t,n)}}function w(t,e,r){var n,a=t.data()[0][0],s=a.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,h=r._main&&e._context.edits.legendText&&!l,d=r._maxNameLength;r.entries?n=a.text:(n=l?a.label:s.name,s._meta&&(n=i.templateString(n,s._meta)));var g=i.ensureSingle(t,\"text\",\"legendtext\");g.attr(\"text-anchor\",\"start\").call(c.font,r.font).text(h?T(n,d):n);var m=r.itemwidth+2*p.itemGap;f.positionText(g,m,0),h?g.call(f.makeEditable,{gd:e,text:n}).call(M,t,e,r).on(\"edit\",(function(n){this.text(T(n,d)).call(M,t,e,r);var s=a.trace._fullInput||{},l={};if(o.hasTransform(s,\"groupby\")){var c=o.getTransformIndices(s,\"groupby\"),f=c[c.length-1],h=i.keyedContainer(s,\"transforms[\"+f+\"].styles\",\"target\",\"value.name\");h.set(a.trace._group,n),l=h.constructUpdate()}else l.name=n;return o.call(\"_guiRestyle\",e,l,u)})):M(g,t,e,r)}function T(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function k(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",(function(t){e._context.staticPlot||t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\"),t.call(u.fill,\"rgba(0,0,0,0)\")}));e._context.staticPlot||(s.on(\"mousedown\",(function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)})),s.on(\"mouseup\",(function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})))}function M(t,e,r,n){n._main||t.attr(\"data-notex\",!0),f.convertToTspans(t,r,(function(){!function(t,e,r){var n=t.data()[0][0];if(r._main&&n&&!n.trace.showlegend)return void t.remove();var i=t.select(\"g[class*=math-group]\"),a=i.node();r||(r=e._fullLayout.legend);var o,s,l=r.borderwidth,u=(n?r:r.title).font.size*g;if(a){var h=c.bBox(a);o=h.height,s=h.width,n?c.setTranslate(i,0,.25*o):c.setTranslate(i,l,.75*o+l)}else{var d=t.select(n?\".legendtext\":\".legendtitletext\"),m=f.lineCount(d),v=d.node();o=u*m,s=v?c.bBox(v).width:0;var y=u*((m-1)/2-.3);if(n){var x=r.itemwidth+2*p.itemGap;f.positionText(d,x,-y)}else f.positionText(d,p.titlePad+l,u+l)}n?(n.lineHeight=u,n.height=Math.max(o,16)+3,n.width=s):(r._titleWidth=s,r._titleHeight=o)}(e,r,n)}))}function A(t){return i.isRightAnchor(t)?\"right\":i.isCenterAnchor(t)?\"center\":\"left\"}function S(t){return i.isBottomAnchor(t)?\"bottom\":i.isMiddleAnchor(t)?\"middle\":\"top\"}e.exports=function(t,e){var r,s=t._fullLayout,f=\"legend\"+s._uid;if(e?(r=e.layer,f+=\"-hover\"):((e=s.legend||{})._main=!0,r=s._infolayer),r){var h;if(t._legendMouseDownTime||(t._legendMouseDownTime=0),e._main){if(!t.calcdata)return;h=s.showlegend&&y(t.calcdata,e)}else{if(!e.entries)return;h=y(e.entries,e)}var d=s.hiddenlabels||[];if(e._main&&(!s.showlegend||!h.length))return r.selectAll(\".legend\").remove(),s._topdefs.select(\"#\"+f).remove(),a.autoMargin(t,\"legend\");var g=i.ensureSingle(r,\"g\",\"legend\",(function(t){e._main&&t.attr(\"pointer-events\",\"all\")})),T=i.ensureSingleById(s._topdefs,\"clipPath\",f,(function(t){t.append(\"rect\")})),E=i.ensureSingle(g,\"rect\",\"bg\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));E.call(u.stroke,e.bordercolor).call(u.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\");var C=i.ensureSingle(g,\"g\",\"scrollbox\"),L=e.title;if(e._titleWidth=0,e._titleHeight=0,L.text){var I=i.ensureSingle(C,\"text\",\"legendtitletext\");I.attr(\"text-anchor\",\"start\").call(c.font,L.font).text(L.text),M(I,C,t,e)}else C.selectAll(\".legendtitletext\").remove();var P=i.ensureSingle(g,\"rect\",\"scrollbar\",(function(t){t.attr(p.scrollBarEnterAttrs).call(u.fill,p.scrollBarColor)})),z=C.selectAll(\"g.groups\").data(h);z.enter().append(\"g\").attr(\"class\",\"groups\"),z.exit().remove();var O=z.selectAll(\"g.traces\").data(i.identity);O.enter().append(\"g\").attr(\"class\",\"traces\"),O.exit().remove(),O.style(\"opacity\",(function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==d.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1})).each((function(){n.select(this).call(w,t,e)})).call(x,t,e).each((function(){e._main&&n.select(this).call(k,t)})),i.syncOrAsync([a.previousPromises,function(){return function(t,e,r,i){var a=t._fullLayout;i||(i=a.legend);var o=a._size,s=b.isVertical(i),l=b.isGrouped(i),u=i.borderwidth,f=2*u,h=p.itemGap,d=i.itemwidth+2*h,g=2*(u+h),m=S(i),v=i.y<0||0===i.y&&\"top\"===m,y=i.y>1||1===i.y&&\"bottom\"===m;i._maxHeight=Math.max(v||y?a.height/2:o.h,30);var x=0;i._width=0,i._height=0;var _=function(t){var e=0,r=0,n=t.title.side;n&&(-1!==n.indexOf(\"left\")&&(e=t._titleWidth),-1!==n.indexOf(\"top\")&&(r=t._titleHeight));return[e,r]}(i);if(s)r.each((function(t){var e=t[0].height;c.setTranslate(this,u+_[0],u+_[1]+i._height+e/2+h),i._height+=e,i._width=Math.max(i._width,t[0].width)})),x=d+i._width,i._width+=h+d+f,i._height+=g,l&&(e.each((function(t,e){c.setTranslate(this,0,e*i.tracegroupgap)})),i._height+=(i._lgroupsLength-1)*i.tracegroupgap);else{var w=A(i),T=i.x<0||0===i.x&&\"right\"===w,k=i.x>1||1===i.x&&\"left\"===w,M=y||v,E=a.width/2;i._maxWidth=Math.max(T?M&&\"left\"===w?o.l+o.w:E:k?M&&\"right\"===w?o.r+o.w:E:o.w,2*d);var C=0,L=0;r.each((function(t){var e=t[0].width+d;C=Math.max(C,e),L+=e})),x=null;var I=0;if(l){var P=0,z=0,O=0;e.each((function(){var t=0,e=0;n.select(this).selectAll(\"g.traces\").each((function(r){var n=r[0].height;c.setTranslate(this,_[0],_[1]+u+h+n/2+e),e+=n,t=Math.max(t,d+r[0].width)})),P=Math.max(P,e);var r=t+h;r+u+z>i._maxWidth&&(I=Math.max(I,z),z=0,O+=P+i.tracegroupgap,P=e),c.setTranslate(this,z,O),z+=r})),i._width=Math.max(I,z)+u,i._height=O+P+g}else{var D=r.size(),R=L+f+(D-1)*h<i._maxWidth,F=0,B=0,N=0,j=0;r.each((function(t){var e=t[0].height,r=d+t[0].width,n=(R?r:C)+h;n+u+B-h>=i._maxWidth&&(I=Math.max(I,j),B=0,N+=F,i._height+=F,F=0),c.setTranslate(this,_[0]+u+B,_[1]+u+N+e/2+h),j=B+r+h,B+=n,F=Math.max(F,e)})),R?(i._width=B+f,i._height=F+g):(i._width=Math.max(I,j)+f,i._height+=F+g)}}i._width=Math.ceil(Math.max(i._width+_[0],i._titleWidth+2*(u+p.titlePad))),i._height=Math.ceil(Math.max(i._height+_[1],i._titleHeight+2*(u+p.itemGap))),i._effHeight=Math.min(i._height,i._maxHeight);var U=t._context.edits,V=U.legendText||U.legendPosition;r.each((function(t){var e=n.select(this).select(\".legendtoggle\"),r=t[0].height,i=V?d:x||d+t[0].width;s||(i+=h/2),c.setRect(e,0,-r/2,i,r)}))}(t,z,O,e)},function(){if(!e._main||!function(t){var e=t._fullLayout.legend,r=A(e),n=S(e);return a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*m[r],r:e._width*v[r],b:e._effHeight*v[n],t:e._effHeight*m[n]})}(t)){var u,h,d,y,x=s._size,b=e.borderwidth,w=x.l+x.w*e.x-m[A(e)]*e._width,k=x.t+x.h*(1-e.y)-m[S(e)]*e._effHeight;if(e._main&&s.margin.autoexpand){var M=w,L=k;w=i.constrain(w,0,s.width-e._width),k=i.constrain(k,0,s.height-e._effHeight),w!==M&&i.log(\"Constrain legend.x to make legend fit inside graph\"),k!==L&&i.log(\"Constrain legend.y to make legend fit inside graph\")}if(e._main&&c.setTranslate(g,w,k),P.on(\".drag\",null),g.on(\"wheel\",null),!e._main||e._height<=e._maxHeight||t._context.staticPlot){var I=e._effHeight;e._main||(I=e._height),E.attr({width:e._width-b,height:I-b,x:b/2,y:b/2}),c.setTranslate(C,0,0),T.select(\"rect\").attr({width:e._width-2*b,height:I-2*b,x:b,y:b}),c.setClipUrl(C,f,t),c.setRect(P,0,0,0,0),delete e._scrollY}else{var z,O,D,R=Math.max(p.scrollBarMinHeight,e._effHeight*e._effHeight/e._height),F=e._effHeight-R-2*p.scrollBarMargin,B=e._height-e._effHeight,N=F/B,j=Math.min(e._scrollY||0,B);E.attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-b,x:b/2,y:b/2}),T.select(\"rect\").attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-2*b,x:b,y:b+j}),c.setClipUrl(C,f,t),q(j,R,N),g.on(\"wheel\",(function(){q(j=i.constrain(e._scrollY+n.event.deltaY/F*B,0,B),R,N),0!==j&&j!==B&&n.event.preventDefault()}));var U=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;z=\"touchstart\"===t.type?t.changedTouches[0].clientY:t.clientY,D=j})).on(\"drag\",(function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||(O=\"touchmove\"===t.type?t.changedTouches[0].clientY:t.clientY,q(j=function(t,e,r){var n=(r-e)/N+t;return i.constrain(n,0,B)}(D,z,O),R,N))}));P.call(U);var V=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;\"touchstart\"===t.type&&(z=t.changedTouches[0].clientY,D=j)})).on(\"drag\",(function(){var t=n.event.sourceEvent;\"touchmove\"===t.type&&(O=t.changedTouches[0].clientY,q(j=function(t,e,r){var n=(e-r)/N+t;return i.constrain(n,0,B)}(D,z,O),R,N))}));C.call(V)}if(t._context.edits.legendPosition)g.classed(\"cursor-move\",!0),l.init({element:g.node(),gd:t,prepFn:function(){var t=c.getTranslate(g);d=t.x,y=t.y},moveFn:function(t,r){var n=d+t,i=y+r;c.setTranslate(g,n,i),u=l.align(n,0,x.l,x.l+x.w,e.xanchor),h=l.align(i,0,x.t+x.h,x.t,e.yanchor)},doneFn:function(){void 0!==u&&void 0!==h&&o.call(\"_guiRelayout\",t,{\"legend.x\":u,\"legend.y\":h})},clickFn:function(e,n){var i=r.selectAll(\"g.traces\").filter((function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom}));i.size()>0&&_(t,g,i,e,n)}})}function q(r,n,i){e._scrollY=t._fullLayout.legend._scrollY=r,c.setTranslate(C,0,-r),c.setRect(P,e._width,p.scrollBarMargin+r*i,p.scrollBarWidth,n),T.select(\"rect\").attr(\"y\",b+r)}}],t)}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/events\":767,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"./constants\":694,\"./get_legend_data\":697,\"./handle_click\":698,\"./helpers\":699,\"./style\":701,d3:169}],697:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0,f=0,h=e._main;function p(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var d=t[r],g=d[0],m=g.trace,v=m.legendgroup;if(!h||m.visible&&m.showlegend)if(n.traceIs(m,\"pie-like\"))for(c[v]||(c[v]={}),a=0;a<d.length;a++){var y=d[a].label;c[v][y]||(p(v,{label:y,color:d[a].color,i:d[a].i,trace:m,pts:d[a].pts}),c[v][y]=!0,f=Math.max(f,(y||\"\").length))}else p(v,g),f=Math.max(f,(m.name||\"\").length)}if(!s.length)return[];var x,b,_=s.length;if(l&&i.isGrouped(e))for(b=new Array(_),r=0;r<_;r++)x=o[s[r]],b[r]=i.isReversed(e)?x.reverse():x;else{for(b=[new Array(_)],r=0;r<_;r++)x=o[s[r]][0],b[0][i.isReversed(e)?_-r-1:r]=x;_=1}return e._lgroupsLength=_,e._maxNameLength=f,b}},{\"../../registry\":911,\"./helpers\":699}],698:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,f,h,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],m=t.data()[0][0],v=e._fullData,y=m.trace,x=y.legendgroup,b={},_=[],w=[],T=[];if(i.traceIs(y,\"pie-like\")){var k=m.label,M=g.indexOf(k);\"toggle\"===s?-1===M?g.push(k):g.splice(M,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach((function(t){k!==t.label&&g.push(t.label)})),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===M&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var A,S=x&&x.length,E=[];if(S)for(u=0;u<v.length;u++)(A=v[u]).visible&&A.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<v.length;u++)!1!==v[u].visible&&v[u].legendgroup===x&&B(v[u],C);else B(y,C)}else if(\"toggleothers\"===s){var L,I,P,z,O=!0;for(u=0;u<v.length;u++)if(L=v[u]===y,P=!0!==v[u].showlegend,!(L||P||(I=S&&v[u].legendgroup===x)||!0!==v[u].visible||i.traceIs(v[u],\"notLegendIsolatable\"))){O=!1;break}for(u=0;u<v.length;u++)if(!1!==v[u].visible&&!i.traceIs(v[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":B(v[u],!0);break;case!0:z=!!O||\"legendonly\",L=v[u]===y,P=!0!==v[u].showlegend&&!v[u].legendgroup,I=L||S&&v[u].legendgroup===x,B(v[u],!(!I&&!P)||z)}}for(u=0;u<w.length;u++)if(h=w[u]){var D=h.constructUpdate(),R=Object.keys(D);for(f=0;f<R.length;f++)p=R[f],(b[p]=b[p]||[])[T[u]]=D[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],f=0;f<_.length;f++)b[p].hasOwnProperty(f)||(b[p][f]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function F(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function B(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),T[r.index]=F(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;F(r.index,\"visible\",c)}}}},{\"../../lib\":778,\"../../registry\":911}],699:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],700:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":693,\"./defaults\":695,\"./draw\":696,\"./style\":701}],701:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../colorscale/helpers\").extractOpts,u=t(\"../../traces/scatter/subtypes\"),f=t(\"../../traces/pie/style_one\"),h=t(\"../../traces/pie/helpers\").castOption,p=t(\"./constants\");function d(t,e){return(e?\"radial\":\"horizontal\")+(t?\"\":\"reversed\")}e.exports=function(t,e,r){var g=e._fullLayout;r||(r=g.legend);var m=\"constant\"===r.itemsizing,v=r.itemwidth,y=(v+2*p.itemGap)/2,x=o(y,0),b=function(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return m?n:Math.min(i,r)};function _(t,e,r){var a=t[0].trace,o=a.marker||{},s=o.line||{},c=r?a.visible&&a.type===r:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),u.exit().remove(),u.each((function(t){var e=n.select(this),r=t[0],i=b(r.mlw,o.line,5,2);e.style(\"stroke-width\",i+\"px\").call(l.fill,r.mc||o.color),i&&l.stroke(e,r.mlc||s.color)}))}function w(t,e,r){var o=t[0],s=o.trace,l=r?s.visible&&s.type===r:i.traceIs(s,r),c=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(c.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),c.exit().remove(),c.size()){var u=(s.marker||{}).line,p=b(h(u.width,o.pts),u,5,2),d=a.minExtend(s,{marker:{line:{width:p}}});d.marker.line.color=u.color;var g=a.minExtend(o,{trace:d});f(c,g,d)}}t.each((function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var s=r.valign,l=t[0].lineHeight,c=t[0].height;if(\"middle\"!==s&&l&&c){var u={top:1,bottom:-1}[s]*(.5*(l-c+3));i.attr(\"transform\",o(0,u))}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var f=i.selectAll(\"g.legendsymbols\").data([t]);f.enter().append(\"g\").classed(\"legendsymbols\",!0),f.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)})).each((function(t){var r,i=t[0].trace,o=[];if(i.visible)switch(i.type){case\"histogram2d\":case\"heatmap\":o=[[\"M-15,-2V4H15V-2Z\"]],r=!0;break;case\"choropleth\":case\"choroplethmapbox\":o=[[\"M-6,-6V6H6V-6Z\"]],r=!0;break;case\"densitymapbox\":o=[[\"M-6,0 a6,6 0 1,0 12,0 a 6,6 0 1,0 -12,0\"]],r=\"radial\";break;case\"cone\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 V6L6,4Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 L6,-4Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 L6,0Z\"]],r=!1;break;case\"streamtube\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 H6 A2,2 0 0,1 6,2 Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 H6 A2,2 0 0,1 6,-6 Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 H6 A2,2 0 0,1 6,-2 Z\"]],r=!1;break;case\"surface\":o=[[\"M-6,-6 A2,3 0 0,0 -6,0 H6 A2,3 0 0,1 6,-6 Z\"],[\"M-6,1 A2,3 0 0,1 -6,6 H6 A2,3 0 0,0 6,0 Z\"]],r=!0;break;case\"mesh3d\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!1;break;case\"volume\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!0;break;case\"isosurface\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6 A12,24 0 0,0 6,-6 L0,6Z\"]],r=!1}var u=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legend3dandfriends\").data(o);u.enter().append(\"path\").classed(\"legend3dandfriends\",!0).attr(\"transform\",x).style(\"stroke-miterlimit\",1),u.exit().remove(),u.each((function(t,o){var u,f=n.select(this),h=c(i),p=h.colorscale,g=h.reversescale;if(p){if(!r){var m=p.length;u=0===o?p[g?m-1:0][1]:1===o?p[g?0:m-1][1]:p[Math.floor((m-1)/2)][1]}}else{var v=i.vertexcolor||i.facecolor||i.color;u=a.isArrayOrTypedArray(v)?v[o]||v[0]:v}f.attr(\"d\",t[0]),u?f.call(l.fill,u):f.call((function(t){if(t.size()){var n=\"legendfill-\"+i.uid;s.gradient(t,e,n,d(g,\"radial\"===r),p,\"fill\")}}))}))})).each((function(t){var e=t[0].trace,r=\"waterfall\"===e.type;if(t[0]._distinct&&r){var i=t[0].trace[t[0].dir].marker;return t[0].mc=i.color,t[0].mlw=i.line.width,t[0].mlc=i.line.color,_(t,this,\"waterfall\")}var a=[];e.visible&&r&&(a=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(a);o.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",x).style(\"stroke-miterlimit\",1),o.exit().remove(),o.each((function(t){var r=n.select(this),i=e[t[0]].marker,a=b(void 0,i.line,5,2);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(l.fill,i.color),a&&r.call(l.stroke,i.line.color)}))})).each((function(t){_(t,this,\"funnel\")})).each((function(t){_(t,this)})).each((function(t){var r=t[0].trace,o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(r.visible&&i.traceIs(r,\"box-violin\")?[t]:[]);o.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),o.exit().remove(),o.each((function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==l.opacity(r.fillcolor)||0!==l.opacity((r.line||{}).color)){var i=b(void 0,r.line,5,2);t.style(\"stroke-width\",i+\"px\").call(l.fill,r.fillcolor),i&&l.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:m?12:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});o.call(s.pointStyle,c,e)}}))})).each((function(t){w(t,this,\"funnelarea\")})).each((function(t){w(t,this,\"pie\")})).each((function(t){var r,i,o=t[0],l=o.trace,f=l.visible&&l.fill&&\"none\"!==l.fill,h=u.hasLines(l),p=l.contours,g=!1,m=!1,y=c(l),x=y.colorscale,_=y.reversescale;if(p){var w=p.coloring;\"lines\"===w?g=!0:h=\"none\"===w||\"heatmap\"===w||p.showlines,\"constraint\"===p.type?f=\"=\"!==p._operation:\"fill\"!==w&&\"heatmap\"!==w||(m=!0)}var T=u.hasMarkers(l)||u.hasText(l),k=f||m,M=h||g,A=T||!k?\"M5,0\":M?\"M5,-2\":\"M5,-3\",S=n.select(this),E=S.select(\".legendfill\").selectAll(\"path\").data(f||m?[t]:[]);if(E.enter().append(\"path\").classed(\"js-fill\",!0),E.exit().remove(),E.attr(\"d\",A+\"h\"+v+\"v6h-\"+v+\"z\").call(f?s.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+l.uid;s.gradient(t,e,r,d(_),x,\"fill\")}}),h||g){var C=b(void 0,l.line,10,5);i=a.minExtend(l,{line:{width:C}}),r=[a.minExtend(o,{trace:i})]}var L=S.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);L.enter().append(\"path\").classed(\"js-line\",!0),L.exit().remove(),L.attr(\"d\",A+(g?\"l\"+v+\",0.0001\":\"h\"+v)).call(h?s.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+l.uid;s.lineGroupStyle(t),s.gradient(t,e,r,d(_),x,\"stroke\")}})})).each((function(t){var r,i,o=t[0],l=o.trace,c=u.hasMarkers(l),f=u.hasText(l),h=u.hasLines(l);function p(t,e,r,n){var i=a.nestedProperty(l,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(m&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function d(t){return o._distinct&&o.index&&t[o.index]?t[o.index]:t[0]}if(c||f||h){var g={},v={};if(c){g.mc=p(\"marker.color\",d),g.mx=p(\"marker.symbol\",d),g.mo=p(\"marker.opacity\",a.mean,[.2,1]),g.mlc=p(\"marker.line.color\",d),g.mlw=p(\"marker.line.width\",a.mean,[0,5],2),v.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var y=p(\"marker.size\",a.mean,[2,16],12);g.ms=y,v.marker.size=y}h&&(v.line={width:p(\"line.width\",d,[0,10],5)}),f&&(g.tx=\"Aa\",g.tp=p(\"textposition\",d),g.ts=10,g.tc=p(\"textfont.color\",d),g.tf=p(\"textfont.family\",d)),r=[a.minExtend(o,g)],(i=a.minExtend(l,v)).selectedpoints=null,i.texttemplate=null}var b=n.select(this).select(\"g.legendpoints\"),_=b.selectAll(\"path.scatterpts\").data(c?r:[]);_.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",x),_.exit().remove(),_.call(s.pointStyle,i,e),c&&(r[0].mrc=3);var w=b.selectAll(\"g.pointtext\").data(f?r:[]);w.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",x),w.exit().remove(),w.selectAll(\"text\").call(s.textPointStyle,i,e)})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(e.visible&&\"candlestick\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"})).attr(\"transform\",x).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=b(void 0,a.line,5,2);i.style(\"stroke-width\",o+\"px\").call(l.fill,a.fillcolor),o&&l.stroke(i,a.line.color)}))})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(e.visible&&\"ohlc\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"})).attr(\"transform\",x).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=b(void 0,a.line,5,2);i.style(\"fill\",\"none\").call(s.dashLine,a.line.dash,o),o&&l.stroke(i,a.line.color)}))}))}},{\"../../lib\":778,\"../../registry\":911,\"../../traces/pie/helpers\":1166,\"../../traces/pie/style_one\":1172,\"../../traces/scatter/subtypes\":1212,\"../color\":643,\"../colorscale/helpers\":654,\"../drawing\":665,\"./constants\":694,d3:169}],702:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../fonts/ploticon\"),s=t(\"../shapes/draw\").eraseActiveShape,l=t(\"../../lib\"),c=l._,u=e.exports={};function f(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},f=a.list(t,null,!0),h=c._cartesianSpikesEnabled;if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,m=(1-d)/2;for(i=0;i<f.length;i++)if(!(r=f[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var v=r._rangeInitial.slice();u[p+\".range[0]\"]=v[0],u[p+\".range[1]\"]=v[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==h||r._showSpikeInitial||(h=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+m*y[1],g*y[1]+m*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}}else\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l||(l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l)),u[s]=l;c._cartesianSpikesEnabled=h,n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d||[],s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function p(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=\"resetLastSave\"===r,a=\"resetDefault\"===r,o=t._fullLayout,s=o._subplots.gl3d||[],l={},c=0;c<s.length;c++){var u,f=s[c],h=f+\".camera\",p=f+\".aspectratio\",d=f+\".aspectmode\",g=o[f]._scene;i?(l[h+\".up\"]=g.viewInitial.up,l[h+\".eye\"]=g.viewInitial.eye,l[h+\".center\"]=g.viewInitial.center,u=!0):a&&(l[h+\".up\"]=null,l[h+\".eye\"]=null,l[h+\".center\"]=null,u=!0),u&&(l[p+\".x\"]=g.viewInitial.aspectratio.x,l[p+\".y\"]=g.viewInitial.aspectratio.y,l[p+\".z\"]=g.viewInitial.aspectratio.z,l[d]=g.viewInitial.aspectmode)}n.call(\"_guiRelayout\",t,l)}function d(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d||[],o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],f=i[u],h=u+\".hovermode\";s[h]=f.hovermode,l[h]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=f[d].showspikes}}r._previousVal=s}return l}function g(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo||[],l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var f=u.projection.scale,h=\"in\"===a?2*f:.5*f;n.call(\"_guiRelayout\",t,c+\".projection.scale\",h)}}\"reset\"===i&&x(t,\"geo\")}function m(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=m(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function y(t,e){for(var r=e.currentTarget.getAttribute(\"data-val\"),i=t._fullLayout,a=i._subplots.mapbox||[],o={},s=0;s<a.length;s++){var l=a[s],c=i[l].zoom,u=\"in\"===r?1.05*c:c/1.05;o[l+\".zoom\"]=u}n.call(\"_guiRelayout\",t,o)}function x(t,e){for(var r=t._fullLayout,i=r._subplots[e]||[],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var f=c[u];a[s+\".\"+f]=l[f]}n.call(\"_guiRelayout\",t,a)}u.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return c(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:o.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};l.notifier(c(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&l.isIE()&&(l.notifier(c(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach((function(t){t in e&&(r[t]=e[t])})),n.call(\"downloadImage\",t,r).then((function(e){l.notifier(c(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")})).catch((function(){l.notifier(c(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")}))}},u.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.disk,click:function(t){i.sendDataToCloud(t)}},u.editInChartStudio={name:\"editInChartStudio\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.pencil,click:function(t){i.sendDataToCloud(t)}},u.zoom2d={name:\"zoom2d\",title:function(t){return c(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:o.zoombox,click:f},u.pan2d={name:\"pan2d\",title:function(t){return c(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:o.pan,click:f},u.select2d={name:\"select2d\",title:function(t){return c(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:o.selectbox,click:f},u.lasso2d={name:\"lasso2d\",title:function(t){return c(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:o.lasso,click:f},u.drawclosedpath={name:\"drawclosedpath\",title:function(t){return c(t,\"Draw closed freeform\")},attr:\"dragmode\",val:\"drawclosedpath\",icon:o.drawclosedpath,click:f},u.drawopenpath={name:\"drawopenpath\",title:function(t){return c(t,\"Draw open freeform\")},attr:\"dragmode\",val:\"drawopenpath\",icon:o.drawopenpath,click:f},u.drawline={name:\"drawline\",title:function(t){return c(t,\"Draw line\")},attr:\"dragmode\",val:\"drawline\",icon:o.drawline,click:f},u.drawrect={name:\"drawrect\",title:function(t){return c(t,\"Draw rectangle\")},attr:\"dragmode\",val:\"drawrect\",icon:o.drawrect,click:f},u.drawcircle={name:\"drawcircle\",title:function(t){return c(t,\"Draw circle\")},attr:\"dragmode\",val:\"drawcircle\",icon:o.drawcircle,click:f},u.eraseshape={name:\"eraseshape\",title:function(t){return c(t,\"Erase active shape\")},icon:o.eraseshape,click:s},u.zoomIn2d={name:\"zoomIn2d\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:f},u.zoomOut2d={name:\"zoomOut2d\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:f},u.autoScale2d={name:\"autoScale2d\",title:function(t){return c(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:o.autoscale,click:f},u.resetScale2d={name:\"resetScale2d\",title:function(t){return c(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:o.home,click:f},u.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return c(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:f},u.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return c(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:o.tooltip_compare,gravity:\"ne\",click:f},u.zoom3d={name:\"zoom3d\",title:function(t){return c(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:o.zoombox,click:h},u.pan3d={name:\"pan3d\",title:function(t){return c(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:o.pan,click:h},u.orbitRotation={name:\"orbitRotation\",title:function(t){return c(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:o[\"3d_rotate\"],click:h},u.tableRotation={name:\"tableRotation\",title:function(t){return c(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:o[\"z-axis\"],click:h},u.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return c(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:o.home,click:p},u.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return c(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:o.movie,click:p},u.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);n.call(\"_guiRelayout\",t,r)}},u.zoomInGeo={name:\"zoomInGeo\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:g},u.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:g},u.resetGeo={name:\"resetGeo\",title:function(t){return c(t,\"Reset\")},attr:\"reset\",val:null,icon:o.autoscale,click:g},u.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:v},u.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return c(t,\"Reset view\")},icon:o.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},u.toggleHover={name:\"toggleHover\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);r.hovermode=m(t),n.call(\"_guiRelayout\",t,r)}},u.resetViews={name:\"resetViews\",title:function(t){return c(t,\"Reset views\")},icon:o.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),f(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),p(t,e),x(t,\"geo\"),x(t,\"mapbox\")}},u.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return c(t,\"Toggle Spike Lines\")},icon:o.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout,r=e._cartesianSpikesEnabled;e._cartesianSpikesEnabled=\"on\"===r?\"off\":\"on\",n.call(\"_guiRelayout\",t,function(t){for(var e=\"on\"===t._fullLayout._cartesianSpikesEnabled,r=a.list(t,null,!0),n={},i=0;i<r.length;i++){var o=r[i];n[o._name+\".showspikes\"]=!!e||o._showSpikeInitial}return n}(t))}},u.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return c(t,\"Reset view\")},attr:\"reset\",icon:o.home,click:function(t){x(t,\"mapbox\")}},u.zoomInMapbox={name:\"zoomInMapbox\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:y},u.zoomOutMapbox={name:\"zoomOutMapbox\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:y}},{\"../../fonts/ploticon\":757,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../shapes/draw\":724}],703:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":704}],704:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"../fx/helpers\").isUnifiedHover,s=t(\"./modebar\"),l=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,u=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var f,h=r.modeBarButtons;f=Array.isArray(h)&&h.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===l[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=l[i]}}return t}(h):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,s=t._context,u=s.modeBarButtonsToRemove,f=s.modeBarButtonsToAdd,h=e._has(\"cartesian\"),p=e._has(\"gl3d\"),d=e._has(\"geo\"),g=e._has(\"pie\"),m=e._has(\"funnelarea\"),v=e._has(\"gl2d\"),y=e._has(\"ternary\"),x=e._has(\"mapbox\"),b=e._has(\"polar\"),_=e._has(\"sankey\"),w=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),T=o(e.hovermode),k=[];function M(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===u.indexOf(n)&&e.push(l[n])}k.push(e)}}var A=[\"toImage\"];s.showEditInChartStudio?A.push(\"editInChartStudio\"):s.showSendToCloud&&A.push(\"sendDataToCloud\");M(A);var S=[],E=[],C=[],L=[];(h||v||g||m||y)+d+p+x+b>1?(E=[\"toggleHover\"],C=[\"resetViews\"]):d?(S=[\"zoomInGeo\",\"zoomOutGeo\"],E=[\"hoverClosestGeo\"],C=[\"resetGeo\"]):p?(E=[\"hoverClosest3d\"],C=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):x?(S=[\"zoomInMapbox\",\"zoomOutMapbox\"],E=[\"toggleHover\"],C=[\"resetViewMapbox\"]):v?E=[\"hoverClosestGl2d\"]:g?E=[\"hoverClosestPie\"]:_?(E=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],C=[\"resetViewSankey\"]):E=[\"toggleHover\"];h&&(E=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0}(r)||T)&&(E=[]);!h&&!v||w||(S=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==C[0]&&(C=[\"resetScale2d\"]));p?L=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(h||v)&&!w||y?L=[\"zoom2d\",\"pan2d\"]:x||d?L=[\"pan2d\"]:b&&(L=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&L.push(\"select2d\",\"lasso2d\");if(Array.isArray(f)){for(var I=[],P=0;P<f.length;P++){var z=f[P];\"string\"==typeof z?-1!==c.indexOf(z)&&(e._has(\"mapbox\")||e._has(\"cartesian\"))&&L.push(z):I.push(z)}f=I}return M(L),M(S.concat(C)),M(E),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(k,f)}(t),u?u.update(t,f):e._modeBar=s(t,f)}else u&&(u.destroy(),delete e._modeBar)};var c=[\"drawline\",\"drawopenpath\",\"drawclosedpath\",\"drawcircle\",\"drawrect\",\"eraseshape\"]},{\"../../plots/cartesian/axis_ids\":831,\"../../registry\":911,\"../../traces/scatter/subtypes\":1212,\"../fx/helpers\":679,\"./buttons\":702,\"./modebar\":705}],705:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var f=this.getLogo();r.watermark&&(f.className=f.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(f,this.element.childNodes[0]):this.element.appendChild(f),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach((function(t){var r=e.createGroup();t.forEach((function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)})),e.element.appendChild(r)}))},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",(function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)})),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach((function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}}))},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plotly.com/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":757,\"../../lib\":778,d3:169,\"fast-isnumeric\":241}],706:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":817,\"../../plots/font_attributes\":856,\"../color/attributes\":642}],707:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],708:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,f){var h=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(h,p,s,t,e)}if(d(\"visible\",o(h,p,{name:\"buttons\",handleItemDefaults:c,calendar:f}).length>0)){var g=function(t,e,r){for(var n=r.filter((function(r){return e[r].anchor===t._id})),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var m=d(\"bgcolor\");d(\"activecolor\",i.contrast(m,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../color\":643,\"./attributes\":706,\"./constants\":707}],709:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=l.strTranslate,u=t(\"../../lib/svg_text_utils\"),f=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,g=h.FROM_BR,m=t(\"./constants\"),v=t(\"./get_update_object\");function y(t){return t._id}function x(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));n.attr({rx:m.rx,ry:m.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",(function(t){t.attr(\"text-anchor\",\"middle\")})).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call((function(t){u.convertToTspans(t,n)}))}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=f.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),y);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each((function(e){var r=n.select(this),o=e,f=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(f.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each((function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(x,f,e),r.call(b,f,e,t),r.on(\"click\",(function(){t._dragged||i.call(\"_guiRelayout\",t,a)})),r.on(\"mouseover\",(function(){e._isHovered=!0,r.call(x,f,e)})),r.on(\"mouseout\",(function(){e._isHovered=!1,r.call(x,f,e)}))})),function(t,e,r,i,o){var f=0,h=0,v=r.borderwidth;e.each((function(){var t=n.select(this).select(\".selector-text\"),e=r.font.size*p,i=Math.max(e*u.lineCount(t),16)+3;h=Math.max(h,i)})),e.each((function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*p,l=u.lineCount(i),d=Math.max(a+10,m.minButtonWidth);t.attr(\"transform\",c(v+f,v)),e.attr({x:0,y:0,width:d,height:h}),u.positionText(i,d/2,h/2-(l-1)*o/2+3),f+=d+5}));var y=t._fullLayout._size,x=y.l+y.w*r.x,b=y.t+y.h*(1-r.y),_=\"left\";l.isRightAnchor(r)&&(x-=f,_=\"right\");l.isCenterAnchor(r)&&(x-=f/2,_=\"center\");var w=\"top\";l.isBottomAnchor(r)&&(b-=h,w=\"bottom\");l.isMiddleAnchor(r)&&(b-=h/2,w=\"middle\");f=Math.ceil(f),h=Math.ceil(h),x=Math.round(x),b=Math.round(b),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:f*d[_],r:f*g[_],b:h*g[w],t:h*d[w]}),o.attr(\"transform\",c(x,b))}(t,h,f,o._name,r)}))}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../drawing\":665,\"./constants\":707,\"./get_update_object\":710,d3:169}],710:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:169}],711:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":706,\"./defaults\":708,\"./draw\":709}],712:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":642}],713:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":827,\"../../plots/cartesian/axis_ids\":831,\"./constants\":714}],714:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],715:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,f,h=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(h.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter((function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)})).map((function(t){return t.substr(t.indexOf(\"y\"),t.length)})),m=n.simpleMap(g,a.id2name),v=0;v<m.length;v++){var y=m[v];u=h[y]||{},f=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=h}}function _(t,e){return n.coerce(h,p,o,t,e)}function w(t,e){return n.coerce(u,f,s,t,e)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axis_ids\":831,\"./attributes\":712,\"./oppaxis_attributes\":719}],716:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../titles\"),f=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),p=t(\"../dragelement\"),d=t(\"../../lib/setcursor\"),g=t(\"./constants\");function m(t,e,r,n){var i=o.ensureSingle(t,\"rect\",g.bgClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,c=-n._offsetShift,u=l.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:s(c,c),fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":u})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,(function(t){t.append(\"rect\").attr({x:0,y:0})})).select(\"rect\").attr({width:n._width,height:n._height})}function y(t,e,r,i){var s,c=e.calcdata,u=t.selectAll(\"g.\"+g.rangePlotClassName).data(r._subplotsWith,o.identity);u.enter().append(\"g\").attr(\"class\",(function(t){return g.rangePlotClassName+\" \"+t})).call(l.setClipUrl,i._clipId,e),u.order(),u.exit().remove(),u.each((function(t,o){var l=n.select(this),u=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],m={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};r.rangebreaks&&(m.layout.xaxis.rangebreaks=r.rangebreaks),m.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},p.rangebreaks&&(m.layout[d].rangebreaks=p.rangebreaks),a.supplyDefaults(m);var v=m._fullLayout.xaxis,y=m._fullLayout[d];v.clearCalc(),v.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:l,xaxis:v,yaxis:y,isRangePlot:!0};u?s=x:(x.mainplot=\"xy\",x.mainplotinfo=s),f.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))}))}function x(t,e,r,n,i){(o.ensureSingle(t,\"rect\",g.maskMinClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,g.maskColor),o.ensureSingle(t,\"rect\",g.maskMaxClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,g.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",g.maskMinOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).call(c.fill,g.maskOppAxisColor),o.ensureSingle(t,\"rect\",g.maskMaxOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).style(\"border-top\",g.maskOppBorder).call(c.fill,g.maskOppAxisColor))}function b(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",g.slideBoxClassName,(function(t){t.attr({y:0,cursor:g.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})})).attr({height:n._height,fill:g.slideBoxFill})}function _(t,e,r,n){var i=o.ensureSingle(t,\"g\",g.grabberMinClassName),a=o.ensureSingle(t,\"g\",g.grabberMaxClassName),s={x:0,width:g.handleWidth,rx:g.handleRadius,fill:c.background,stroke:c.defaultLine,\"stroke-width\":g.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},l={y:Math.round(n._height/4),height:Math.round(n._height/2)};o.ensureSingle(i,\"rect\",g.handleMinClassName,(function(t){t.attr(s)})).attr(l),o.ensureSingle(a,\"rect\",g.handleMaxClassName,(function(t){t.attr(s)})).attr(l);var u={width:g.grabAreaWidth,x:0,y:0,fill:g.grabAreaFill,cursor:e._context.staticPlot?void 0:g.grabAreaCursor};o.ensureSingle(i,\"rect\",g.grabAreaMinClassName,(function(t){t.attr(u)})).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",g.grabAreaMaxClassName,(function(t){t.attr(u)})).attr(\"height\",n._height)}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var l=r[a][g.name];l._clipId=l._id+\"-\"+e._uid}var c=e._infolayer.selectAll(\"g.\"+g.containerClassName).data(r,(function(t){return t._name}));c.exit().each((function(t){var r=t[g.name];e._topdefs.select(\"#\"+r._clipId).remove()})).remove(),0!==r.length&&(c.enter().append(\"g\").classed(g.containerClassName,!0).attr(\"pointer-events\",\"all\"),c.each((function(r){var a=n.select(this),l=r[g.name],c=e[h.id2name(r.anchor)],f=l[h.id2name(r.anchor)];if(l.range){var w,T=o.simpleMap(l.range,r.r2l),k=o.simpleMap(r.range,r.r2l);w=k[0]<k[1]?[Math.min(T[0],k[0]),Math.max(T[1],k[1])]:[Math.max(T[0],k[0]),Math.min(T[1],k[1])],l.range=l._input.range=o.simpleMap(w,r.l2r)}r.cleanRange(\"rangeslider.range\");var M=e._size,A=r.domain;l._width=M.w*(A[1]-A[0]);var S=Math.round(M.l+M.w*A[0]),E=Math.round(M.t+M.h*(1-r._counterDomainMin)+(\"bottom\"===r.side?r._depth:0)+l._offsetShift+g.extraPad);a.attr(\"transform\",s(S,E)),l._rl=o.simpleMap(l.range,r.r2l);var C=l._rl[0],L=l._rl[1],I=L-C;if(l.p2d=function(t){return t/l._width*I+C},l.d2p=function(t){return(t-C)/I*l._width},r.rangebreaks){var P=r.locateBreaks(C,L);if(P.length){var z,O,D=0;for(z=0;z<P.length;z++)D+=(O=P[z]).max-O.min;var R=l._width/(L-C-D),F=[-R*C];for(z=0;z<P.length;z++)O=P[z],F.push(F[F.length-1]-R*(O.max-O.min));for(l.d2p=function(t){for(var e=F[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.max)e=F[r+1];else if(t<n.min)break}return e+R*t},z=0;z<P.length;z++)(O=P[z]).pmin=l.d2p(O.min),O.pmax=l.d2p(O.max);l.p2d=function(t){for(var e=F[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.pmax)e=F[r+1];else if(t<n.pmin)break}return(t-e)/R}}}if(\"match\"!==f.rangemode){var B=c.r2l(f.range[0]),N=c.r2l(f.range[1])-B;l.d2pOppAxis=function(t){return(t-B)/N*l._height}}a.call(m,t,r,l).call(v,t,r,l).call(y,t,r,l).call(x,t,r,l,f).call(b,t,r,l).call(_,t,r,l),function(t,e,r,a){if(e._context.staticPlot)return;var s=t.select(\"rect.\"+g.slideBoxClassName).node(),l=t.select(\"rect.\"+g.grabAreaMinClassName).node(),c=t.select(\"rect.\"+g.grabAreaMaxClassName).node();function u(){var u=n.event,f=u.target,h=u.clientX||u.touches[0].clientX,g=h-t.node().getBoundingClientRect().left,m=a.d2p(r._rl[0]),v=a.d2p(r._rl[1]),y=p.coverSlip();function x(t){var u,p,x,b=+(t.clientX||t.touches[0].clientX)-h;switch(f){case s:x=\"ew-resize\",u=m+b,p=v+b;break;case l:x=\"col-resize\",u=m+b,p=v;break;case c:x=\"col-resize\",u=m,p=v+b;break;default:x=\"ew-resize\",u=g,p=g+b}if(p<u){var _=p;p=u,u=_}a._pixelMin=u,a._pixelMax=p,d(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame((function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])}))}(0,e,r,a)}function b(){y.removeEventListener(\"mousemove\",x),y.removeEventListener(\"mouseup\",b),this.removeEventListener(\"touchmove\",x),this.removeEventListener(\"touchend\",b),o.removeElement(y)}this.addEventListener(\"touchmove\",x),this.addEventListener(\"touchend\",b),y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",b)}t.on(\"mousedown\",u),t.on(\"touchstart\",u)}(a,t,r,l),function(t,e,r,n,i,a){var l=g.handleWidth/2;function c(t){return o.constrain(t,0,n._width)}function u(t){return o.constrain(t,0,n._height)}function f(t){return o.constrain(t,-l,n._width+l)}var h=c(n.d2p(r._rl[0])),p=c(n.d2p(r._rl[1]));if(t.select(\"rect.\"+g.slideBoxClassName).attr(\"x\",h).attr(\"width\",p-h),t.select(\"rect.\"+g.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+g.maskMaxClassName).attr(\"x\",p).attr(\"width\",n._width-p),\"match\"!==a.rangemode){var d=n._height-u(n.d2pOppAxis(i._rl[1])),m=n._height-u(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+g.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",d).attr(\"width\",p-h),t.select(\"rect.\"+g.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",m).attr(\"height\",n._height-m).attr(\"width\",p-h),t.select(\"rect.\"+g.slideBoxClassName).attr(\"y\",d).attr(\"height\",m-d)}var v=Math.round(f(h-l))-.5,y=Math.round(f(p-l))+.5;t.select(\"g.\"+g.grabberMinClassName).attr(\"transform\",s(v,.5)),t.select(\"g.\"+g.grabberMaxClassName).attr(\"transform\",s(y,.5))}(a,0,r,l,c,f),\"bottom\"===r.side&&u.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:E+l._height+l._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})})))}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plots/cartesian\":841,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../titles\":738,\"./constants\":714,d3:169}],717:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../lib/svg_text_utils\"),a=t(\"./constants\"),o=t(\"../../constants/alignment\").LINE_SPACING,s=a.name;function l(t){var e=t&&t[s];return e&&e.visible}r.isVisible=l,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var a=0;a<e.length;a++){var o=e[a];if(l(o)){i.push(o);var c=o[s];c._id=s+o._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){var r=t._fullLayout,n=e[s],l=e._id.charAt(0),c=0,u=0;\"bottom\"===e.side&&(c=e._depth,e.title.text!==r._dfltTitle[l]&&(u=1.5*e.title.font.size+10+n._offsetShift,u+=(e.title.text.match(i.BR_TAG_ALL)||[]).length*e.title.font.size*o));return{x:0,y:e._counterDomainMin,l:0,r:0,t:0,b:n._height+c+Math.max(r.margin.b,u),pad:a.extraPad+2*n._offsetShift}}},{\"../../constants/alignment\":745,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axis_ids\":831,\"./constants\":714}],718:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":778,\"./attributes\":712,\"./calc_autorange\":713,\"./defaults\":715,\"./draw\":716,\"./helpers\":717,\"./oppaxis_attributes\":719}],719:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],720:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"arraydraw\"},editable:{valType:\"boolean\",dflt:!1,editType:\"calc+arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":746,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../traces/scatter/attributes\":1187,\"../annotations/attributes\":626,\"../drawing/attributes\":664}],721:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var f=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],h=n.aggNums(Math.max,null,f),p=n.aggNums(Math.min,null,f),d=p<0?Math.abs(p)+c:c,g=h>0?h+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,f,h=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((f=s(u[c]))<h&&(h=f),f>p&&(p=f)));return p>=h?[h,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,f,h=r[o];h._extremes={};var p=i.getRefType(h.xref),d=i.getRefType(h.yref);if(\"paper\"!==h.xref&&\"domain\"!==p){var g=\"pixel\"===h.xsizemode?h.xanchor:h.x0,m=\"pixel\"===h.xsizemode?h.xanchor:h.x1;(f=u(c=i.getFromId(t,h.xref),g,m,h.path,a.paramIsX))&&(h._extremes[c._id]=i.findExtremes(c,f,s(h)))}if(\"paper\"!==h.yref&&\"domain\"!==d){var v=\"pixel\"===h.ysizemode?h.yanchor:h.y0,y=\"pixel\"===h.ysizemode?h.yanchor:h.y1;(f=u(c=i.getFromId(t,h.yref),v,y,h.path,a.paramIsY))&&(h._extremes[c._id]=i.findExtremes(c,f,l(h)))}}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./constants\":722,\"./helpers\":731}],722:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],723:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){var l=a(\"path\"),c=a(\"type\",l?\"path\":\"rect\");\"path\"!==e.type&&delete e.path,a(\"editable\"),a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"fillrule\"),a(\"line.width\")&&(a(\"line.color\"),a(\"line.dash\"));for(var u=a(\"xsizemode\"),f=a(\"ysizemode\"),h=[\"x\",\"y\"],p=0;p<2;p++){var d,g,m,v=h[p],y=v+\"anchor\",x=\"x\"===v?u:f,b={_fullLayout:r},_=i.coerceRef(t,e,b,v,void 0,\"paper\");if(\"range\"===i.getRefType(_)?((d=i.getFromId(b,_))._shapeIndices.push(e._index),m=s.rangeToShapePosition(d),g=s.shapePositionToRange(d)):g=m=n.identity,\"path\"!==c){var w=v+\"0\",T=v+\"1\",k=t[w],M=t[T];t[w]=g(t[w],!0),t[T]=g(t[T],!0),\"pixel\"===x?(a(w,0),a(T,10)):(i.coercePosition(e,b,a,_,w,.25),i.coercePosition(e,b,a,_,T,.75)),e[w]=m(e[w]),e[T]=m(e[T]),t[w]=k,t[T]=M}if(\"pixel\"===x){var A=t[y];t[y]=g(t[y],!0),i.coercePosition(e,b,a,_,y,.25),e[y]=m(e[y]),t[y]=A}}\"path\"===c?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":720,\"./helpers\":731}],724:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"./draw_newshape/helpers\").readPaths,s=t(\"./draw_newshape/display_outlines\"),l=t(\"../../plots/cartesian/handle_outline\").clearOutlineControllers,c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../../plot_api/plot_template\").arrayEditor,h=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\"),g=t(\"./helpers\");function m(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&x(t,i)}function v(t){return!!t._fullLayout._drawing}function y(t){return!t._context.edits.shapePosition}function x(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=g.makeOptionsAndPlotinfo(t,e),l=r.options,x=r.plotinfo;if(l._input&&!1!==l.visible)if(\"below\"!==l.layer)k(t._fullLayout._shapeUpperLayer);else if(\"paper\"===l.xref||\"paper\"===l.yref)k(t._fullLayout._shapeLowerLayer);else{if(x._hadPlotinfo)k((x.mainplotinfo||x).shapelayer);else k(t._fullLayout._shapeLowerLayer)}function k(r){var k=_(t,l),M={\"data-index\":e,\"fill-rule\":l.fillrule,d:k},A=l.opacity,S=l.fillcolor,E=l.line.width?l.line.color:\"rgba(0,0,0,0)\",C=l.line.width,L=l.line.dash;C||!0!==l.editable||(C=5,L=\"solid\");var I=\"Z\"!==k[k.length-1],P=y(t)&&l.editable&&t._fullLayout._activeShapeIndex===e;P&&(S=I?\"rgba(0,0,0,0)\":t._fullLayout.activeshape.fillcolor,A=t._fullLayout.activeshape.opacity);var z,O=r.append(\"path\").attr(M).style(\"opacity\",A).call(c.stroke,E).call(c.fill,S).call(u.dashLine,L,C);if(b(O,t,l),(P||t._context.edits.shapePosition)&&(z=f(t.layout,\"shapes\",l)),P){O.style({cursor:\"move\"});var D={element:O.node(),plotinfo:x,gd:t,editHelpers:z,isActiveShape:!0},R=o(k,t);s(R,O,D)}else t._context.edits.shapePosition?function(t,e,r,o,s,l){var c,f,m,y,x,T,k,M,A,S,E,C,L,I,P,z,O=\"pixel\"===r.xsizemode,D=\"pixel\"===r.ysizemode,R=\"line\"===r.type,F=\"path\"===r.type,B=l.modifyItem,N=a.getFromId(t,r.xref),j=a.getRefType(r.xref),U=a.getFromId(t,r.yref),V=a.getRefType(r.yref),q=g.getDataToPixel(t,N,!1,j),H=g.getDataToPixel(t,U,!0,V),G=g.getPixelToData(t,N,!1,j),Y=g.getPixelToData(t,U,!0,V),W=R?function(){var t=Math.max(r.line.width,10),n=s.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=Math.max(t/2,10);return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:O?q(r.xanchor)+r.x0:q(r.x0),cy:D?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:O?q(r.xanchor)+r.x1:q(r.x1),cy:D?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){if(v(t))return;O&&(x=q(r.xanchor));D&&(T=H(r.yanchor));\"path\"===r.type?P=r.path:(c=O?r.x0:q(r.x0),f=D?r.y0:H(r.y0),m=O?r.x1:q(r.x1),y=D?r.y1:H(r.y1));c<m?(A=c,L=\"x0\",S=m,I=\"x1\"):(A=m,L=\"x1\",S=c,I=\"x0\");!D&&f<y||D&&f>y?(k=f,E=\"y0\",M=y,C=\"y1\"):(k=y,E=\"y1\",M=f,C=\"y0\");Z(n),Q(s,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),s=a.getFromId(r,i),l=\"\";\"paper\"===n||o.autorange||(l+=n);\"paper\"===i||s.autorange||(l+=i);u.setClipUrl(t,l?\"clip\"+r._fullLayout._uid+l:null,r)}(e,r,t),X.moveFn=\"move\"===z?J:K,X.altKey=n.altKey},doneFn:function(){if(v(t))return;p(e),$(s),b(e,t,r),n.call(\"_guiRelayout\",t,l.getUpdateObj())},clickFn:function(){if(v(t))return;$(s)}};function Z(r){if(v(t))z=null;else if(R)z=\"path\"===r.target.tagName?\"move\":\"start-point\"===r.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var n=X.element.getBoundingClientRect(),i=n.right-n.left,a=n.bottom-n.top,o=r.clientX-n.left,s=r.clientY-n.top,l=!F&&i>10&&a>10&&!r.shiftKey?h.getCursor(o/i,1-s/a):\"move\";p(e,l),z=l.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,l=a;O?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(P,o,l))}else O?B(\"xanchor\",r.xanchor=G(x+n)):(B(\"x0\",r.x0=G(c+n)),B(\"x1\",r.x1=G(m+n))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(B(\"y0\",r.y0=Y(f+i)),B(\"y1\",r.y1=Y(y+i)));e.attr(\"d\",_(t,r)),Q(s,r)}function K(n,i){if(F){var a=function(t){return t},o=a,l=a;O?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(P,o,l))}else if(R){if(\"resize-over-start-point\"===z){var u=c+n,h=D?f-i:f+i;B(\"x0\",r.x0=O?u:G(u)),B(\"y0\",r.y0=D?h:Y(h))}else if(\"resize-over-end-point\"===z){var p=m+n,d=D?y-i:y+i;B(\"x1\",r.x1=O?p:G(p)),B(\"y1\",r.y1=D?d:Y(d))}}else{var v=function(t){return-1!==z.indexOf(t)},b=v(\"n\"),j=v(\"s\"),V=v(\"w\"),W=v(\"e\"),X=b?k+i:k,Z=j?M+i:M,J=V?A+n:A,K=W?S+n:S;D&&(b&&(X=k-i),j&&(Z=M-i)),(!D&&Z-X>10||D&&X-Z>10)&&(B(E,r[E]=D?X:Y(X)),B(C,r[C]=D?Z:Y(Z))),K-J>10&&(B(L,r[L]=O?J:G(J)),B(I,r[I]=O?K:G(K)))}e.attr(\"d\",_(t,r)),Q(s,r)}function Q(t,e){(O||D)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(O?e.xanchor:i.midRange(r?[e.x0,e.x1]:g.extractPathCoords(e.path,d.paramIsX))),o=H(D?e.yanchor:i.midRange(r?[e.y0,e.y1]:g.extractPathCoords(e.path,d.paramIsY)));if(a=g.roundPositionForSharpStrokeRendering(a,1),o=g.roundPositionForSharpStrokeRendering(o,1),O&&D){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(O){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function $(t){t.selectAll(\".visual-cue\").remove()}h.init(X),W.node().onmousemove=Z}(t,O,l,e,r,z):!0===l.editable&&O.style(\"pointer-events\",I||c.opacity(S)*A<=.5?\"stroke\":\"all\");O.node().addEventListener(\"click\",(function(){return function(t,e){if(!y(t))return;var r=+e.node().getAttribute(\"data-index\");if(r>=0){if(r===t._fullLayout._activeShapeIndex)return void T(t);t._fullLayout._activeShapeIndex=r,t._fullLayout._deactivateShape=T,m(t)}}(t,O)}))}}function b(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\").replace(/[xyz][1-9]* *domain/g,\"\");u.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function _(t,e){var r,n,o,s,l,c,u,f,h=e.type,p=a.getRefType(e.xref),m=a.getRefType(e.yref),v=a.getFromId(t,e.xref),y=a.getFromId(t,e.yref),x=t._fullLayout._size;if(v?\"domain\"===p?n=function(t){return v._offset+v._length*t}:(r=g.shapePositionToRange(v),n=function(t){return v._offset+v.r2p(r(t,!0))}):n=function(t){return x.l+x.w*t},y?\"domain\"===m?s=function(t){return y._offset+y._length*(1-t)}:(o=g.shapePositionToRange(y),s=function(t){return y._offset+y.r2p(o(t,!0))}):s=function(t){return x.t+x.h*(1-t)},\"path\"===h)return v&&\"date\"===v.type&&(n=g.decodeDate(n)),y&&\"date\"===y.type&&(s=g.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(d.segmentRE,(function(t){var n=0,c=t.charAt(0),u=d.paramIsX[c],f=d.paramIsY[c],h=d.numParams[c],p=t.substr(1).replace(d.paramRE,(function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>h&&(t=\"X\"),t}));return n>h&&(p=p.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+p}))}(e,n,s);if(\"pixel\"===e.xsizemode){var b=n(e.xanchor);l=b+e.x0,c=b+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var _=s(e.yanchor);u=_-e.y0,f=_-e.y1}else u=s(e.y0),f=s(e.y1);if(\"line\"===h)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+f;if(\"rect\"===h)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+f+\"H\"+l+\"Z\";var w=(l+c)/2,T=(u+f)/2,k=Math.abs(w-l),M=Math.abs(T-u),A=\"A\"+k+\",\"+M,S=w+k+\",\"+T;return\"M\"+S+A+\" 0 1,1 \"+(w+\",\"+(T-M))+A+\" 0 0,1 \"+S+\"Z\"}function w(t,e,r){return t.replace(d.segmentRE,(function(t){var n=0,i=t.charAt(0),a=d.paramIsX[i],o=d.paramIsY[i],s=d.numParams[i];return i+t.substr(1).replace(d.paramRE,(function(t){return n>=s||(a[n]?t=e(t):o[n]&&(t=r(t)),n++),t}))}))}function T(t){y(t)&&(t._fullLayout._activeShapeIndex>=0&&(l(t),delete t._fullLayout._activeShapeIndex,m(t)))}e.exports={draw:m,drawOne:x,eraseActiveShape:function(t){if(!y(t))return;l(t);var e=t._fullLayout._activeShapeIndex,r=(t.layout||{}).shapes||[];if(e<r.length){for(var i=[],a=0;a<r.length;a++)a!==e&&i.push(r[a]);delete t._fullLayout._activeShapeIndex,n.call(\"_guiRelayout\",t,{shapes:i})}}}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/handle_outline\":838,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"./constants\":722,\"./draw_newshape/display_outlines\":728,\"./draw_newshape/helpers\":729,\"./helpers\":731}],725:[function(t,e,r){\"use strict\";var n=t(\"../../drawing/attributes\").dash,i=t(\"../../../lib/extend\").extendFlat;e.exports={newshape:{line:{color:{valType:\"color\",editType:\"none\"},width:{valType:\"number\",min:0,dflt:4,editType:\"none\"},dash:i({},n,{dflt:\"solid\",editType:\"none\"}),editType:\"none\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"none\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"none\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"none\"},drawdirection:{valType:\"enumerated\",values:[\"ortho\",\"horizontal\",\"vertical\",\"diagonal\"],dflt:\"diagonal\",editType:\"none\"},editType:\"none\"},activeshape:{fillcolor:{valType:\"color\",dflt:\"rgb(255,0,255)\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"none\"},editType:\"none\"}}},{\"../../../lib/extend\":768,\"../../drawing/attributes\":664}],726:[function(t,e,r){\"use strict\";e.exports={CIRCLE_SIDES:32,i000:0,i090:8,i180:16,i270:24,cos45:Math.cos(Math.PI/4),sin45:Math.sin(Math.PI/4),SQRT2:Math.sqrt(2)}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"../../color\");e.exports=function(t,e,r){if(r(\"newshape.drawdirection\"),r(\"newshape.layer\"),r(\"newshape.fillcolor\"),r(\"newshape.fillrule\"),r(\"newshape.opacity\"),r(\"newshape.line.width\")){var i=(t||{}).plot_bgcolor||\"#FFF\";r(\"newshape.line.color\",n.contrast(i)),r(\"newshape.line.dash\")}r(\"activeshape.fillcolor\"),r(\"activeshape.opacity\")}},{\"../../color\":643}],728:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement\"),i=t(\"../../dragelement/helpers\").drawMode,a=t(\"../../../registry\"),o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=t(\"../../../plots/cartesian/handle_outline\").clearOutlineControllers,h=t(\"./helpers\"),p=h.pointsShapeRectangle,d=h.pointsShapeEllipse,g=h.writePaths,m=t(\"./newshapes\");e.exports=function t(e,r,o,h){h||(h=0);var v=o.gd;function y(){t(e,r,o,h++),d(e[0])&&x({redrawing:!0})}function x(t){o.isActiveShape=!1;var e=m(r,o);Object.keys(e).length&&a.call((t||{}).redrawing?\"relayout\":\"_guiRelayout\",v,e)}var b,_,w,T,k,M=o.isActiveShape,A=v._fullLayout._zoomlayer,S=o.dragmode;(i(S)?v._fullLayout._drawing=!0:v._fullLayout._activeShapeIndex>=0&&f(v),r.attr(\"d\",g(e)),M&&!h)&&(k=function(t,e){for(var r=0;r<e.length;r++){var n=e[r];t[r]=[];for(var i=0;i<n.length;i++){t[r][i]=[];for(var a=0;a<n[i].length;a++)t[r][i][a]=n[i][a]}}return t}([],e),function(t){b=[];for(var r=0;r<e.length;r++){var i=e[r],a=!p(i)&&d(i);b[r]=[];for(var o=0;o<i.length;o++)if(\"Z\"!==i[o][0]&&(!a||o===s||o===l||o===c||o===u)){var f=i[o][1],h=i[o][2],g=t.append(\"circle\").classed(\"cursor-grab\",!0).attr(\"data-i\",r).attr(\"data-j\",o).attr(\"cx\",f).attr(\"cy\",h).attr(\"r\",4).style({\"mix-blend-mode\":\"luminosity\",fill:\"black\",stroke:\"white\",\"stroke-width\":1});b[r][o]={element:g.node(),gd:v,prepFn:E,doneFn:L,clickFn:I},n.init(b[r][o])}}}(A.append(\"g\").attr(\"class\",\"outline-controllers\")),function(){if(_=[],!e.length)return;_[0]={element:r[0][0],gd:v,prepFn:z,doneFn:O},n.init(_[0])}());function E(t){w=+t.srcElement.getAttribute(\"data-i\"),T=+t.srcElement.getAttribute(\"data-j\"),b[w][T].moveFn=C}function C(t,r){if(e.length){var n=k[w][T][1],i=k[w][T][2],a=e[w],o=a.length;if(p(a)){for(var s=0;s<o;s++)if(s!==T){var l=a[s];l[1]===a[T][1]&&(l[1]=n+t),l[2]===a[T][2]&&(l[2]=i+r)}if(a[T][1]=n+t,a[T][2]=i+r,!p(a))for(var c=0;c<o;c++)for(var u=0;u<a[c].length;u++)a[c][u]=k[w][c][u]}else a[T][1]=n+t,a[T][2]=i+r;y()}}function L(){x()}function I(t,r){if(2===t){w=+r.srcElement.getAttribute(\"data-i\"),T=+r.srcElement.getAttribute(\"data-j\");var n=e[w];p(n)||d(n)||function(){if(e.length&&e[w]&&e[w].length){for(var t=[],r=0;r<e[w].length;r++)r!==T&&t.push(e[w][r]);t.length>1&&(2!==t.length||\"Z\"!==t[1][0])&&(0===T&&(t[0][0]=\"M\"),e[w]=t,y(),x())}}()}}function P(t,r){!function(t,r){if(e.length)for(var n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)for(var a=0;a+2<e[n][i].length;a+=2)e[n][i][a+1]=k[n][i][a+1]+t,e[n][i][a+2]=k[n][i][a+2]+r}(t,r),y()}function z(t){(w=+t.srcElement.getAttribute(\"data-i\"))||(w=0),_[w].moveFn=P}function O(){x()}}},{\"../../../plots/cartesian/handle_outline\":838,\"../../../registry\":911,\"../../dragelement\":662,\"../../dragelement/helpers\":661,\"./constants\":726,\"./helpers\":729,\"./newshapes\":730}],729:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"./constants\"),a=i.CIRCLE_SIDES,o=i.SQRT2,s=t(\"../../../plots/cartesian/helpers\"),l=s.p2r,c=s.r2p,u=[0,3,4,5,6,1,2],f=[0,3,4,1,2];function h(t,e){return Math.abs(t-e)<=1e-6}function p(t,e){var r=e[1]-t[1],n=e[2]-t[2];return Math.sqrt(r*r+n*n)}r.writePaths=function(t){var e=t.length;if(!e)return\"M0,0Z\";for(var r=\"\",n=0;n<e;n++)for(var i=t[n].length,a=0;a<i;a++){var o=t[n][a][0];if(\"Z\"===o)r+=\"Z\";else for(var s=t[n][a].length,l=0;l<s;l++){var c=l;\"Q\"===o||\"S\"===o?c=f[l]:\"C\"===o&&(c=u[l]),r+=t[n][a][c],l>0&&l<s-1&&(r+=\",\")}}return r},r.readPaths=function(t,e,r,i){var o,s,u,f=n(t),h=[],p=-1,d=0,g=0,m=function(){s=d,u=g};m();for(var v=0;v<f.length;v++){var y,x,b,_,w=[],T=f[v][0],k=T;switch(T){case\"M\":p++,h[p]=[],d=+f[v][1],g=+f[v][2],w.push([k,d,g]),m();break;case\"Q\":case\"S\":y=+f[v][1],b=+f[v][2],d=+f[v][3],g=+f[v][4],w.push([k,d,g,y,b]);break;case\"C\":y=+f[v][1],b=+f[v][2],x=+f[v][3],_=+f[v][4],d=+f[v][5],g=+f[v][6],w.push([k,d,g,y,b,x,_]);break;case\"T\":case\"L\":d=+f[v][1],g=+f[v][2],w.push([k,d,g]);break;case\"H\":k=\"L\",d=+f[v][1],w.push([k,d,g]);break;case\"V\":k=\"L\",g=+f[v][1],w.push([k,d,g]);break;case\"A\":k=\"L\";var M=+f[v][1],A=+f[v][2];+f[v][4]||(M=-M,A=-A);var S=d-M,E=g;for(o=1;o<=a/2;o++){var C=2*Math.PI*o/a;w.push([k,S+M*Math.cos(C),E+A*Math.sin(C)])}break;case\"Z\":d===s&&g===u||(d=s,g=u,w.push([k,d,g]))}for(var L=(r||{}).domain,I=e._fullLayout._size,P=r&&\"pixel\"===r.xsizemode,z=r&&\"pixel\"===r.ysizemode,O=!1===i,D=0;D<w.length;D++){for(o=0;o+2<7;o+=2){var R=w[D][o+1],F=w[D][o+2];void 0!==R&&void 0!==F&&(d=R,g=F,r&&(r.xaxis&&r.xaxis.p2r?(O&&(R-=r.xaxis._offset),R=P?c(r.xaxis,r.xanchor)+R:l(r.xaxis,R)):(O&&(R-=I.l),L?R=L.x[0]+R/I.w:R/=I.w),r.yaxis&&r.yaxis.p2r?(O&&(F-=r.yaxis._offset),F=z?c(r.yaxis,r.yanchor)-F:l(r.yaxis,F)):(O&&(F-=I.t),F=L?L.y[1]-F/I.h:1-F/I.h)),w[D][o+1]=R,w[D][o+2]=F)}h[p].push(w[D].slice())}}return h},r.pointsShapeRectangle=function(t){if(5!==t.length)return!1;for(var e=1;e<3;e++){if(!h(t[0][e]-t[1][e],t[3][e]-t[2][e]))return!1;if(!h(t[0][e]-t[3][e],t[1][e]-t[2][e]))return!1}return!(!h(t[0][1],t[1][1])&&!h(t[0][1],t[3][1]))&&!!(p(t[0],t[1])*p(t[0],t[3]))},r.pointsShapeEllipse=function(t){var e=t.length;if(e!==a+1)return!1;e=a;for(var r=0;r<e;r++){var n=(2*e-r)%e,i=(e/2+n)%e,o=(e/2+r)%e;if(!h(p(t[r],t[o]),p(t[n],t[i])))return!1}return!0},r.handleEllipse=function(t,e,n){if(!t)return[e,n];var i=r.ellipseOver({x0:e[0],y0:e[1],x1:n[0],y1:n[1]}),s=(i.x1+i.x0)/2,l=(i.y1+i.y0)/2,c=(i.x1-i.x0)/2,u=(i.y1-i.y0)/2;c||(c=u/=o),u||(u=c/=o);for(var f=[],h=0;h<a;h++){var p=2*h*Math.PI/a;f.push([s+c*Math.cos(p),l+u*Math.sin(p)])}return f},r.ellipseOver=function(t){var e=t.x0,r=t.y0,n=t.x1,i=t.y1,a=n-e,s=i-r,l=((e-=a)+n)/2,c=((r-=s)+i)/2;return{x0:l-(a*=o),y0:c-(s*=o),x1:l+a,y1:c+s}}},{\"../../../plots/cartesian/helpers\":839,\"./constants\":726,\"parse-svg-path\":505}],730:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement/helpers\"),i=n.drawMode,a=n.openMode,o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=o.cos45,h=o.sin45,p=t(\"../../../plots/cartesian/helpers\"),d=p.p2r,g=p.r2p,m=t(\"../../../plots/cartesian/handle_outline\").clearSelect,v=t(\"./helpers\"),y=v.readPaths,x=v.writePaths,b=v.ellipseOver;e.exports=function(t,e){if(t.length){var r=t[0][0];if(r){var n=r.getAttribute(\"d\"),o=e.gd,p=o._fullLayout.newshape,v=e.plotinfo,_=v.xaxis,w=v.yaxis,T=!!v.domain||!v.xaxis,k=!!v.domain||!v.yaxis,M=e.isActiveShape,A=e.dragmode,S=(o.layout||{}).shapes||[];if(!i(A)&&void 0!==M){var E=o._fullLayout._activeShapeIndex;if(E<S.length)switch(o._fullLayout.shapes[E].type){case\"rect\":A=\"drawrect\";break;case\"circle\":A=\"drawcircle\";break;case\"line\":A=\"drawline\";break;case\"path\":var C=S[E].path||\"\";A=\"Z\"===C[C.length-1]?\"drawclosedpath\":\"drawopenpath\"}}var L,I=a(A),P=y(n,o,v,M),z={editable:!0,xref:T?\"paper\":_._id,yref:k?\"paper\":w._id,layer:p.layer,opacity:p.opacity,line:{color:p.line.color,width:p.line.width,dash:p.line.dash}};if(I||(z.fillcolor=p.fillcolor,z.fillrule=p.fillrule),1===P.length&&(L=P[0]),L&&\"drawrect\"===A)z.type=\"rect\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[2][1],z.y1=L[2][2];else if(L&&\"drawline\"===A)z.type=\"line\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[1][1],z.y1=L[1][2];else if(L&&\"drawcircle\"===A){z.type=\"circle\";var O=L[s][1],D=L[l][1],R=L[c][1],F=L[u][1],B=L[s][2],N=L[l][2],j=L[c][2],U=L[u][2],V=v.xaxis&&(\"date\"===v.xaxis.type||\"log\"===v.xaxis.type),q=v.yaxis&&(\"date\"===v.yaxis.type||\"log\"===v.yaxis.type);V&&(O=g(v.xaxis,O),D=g(v.xaxis,D),R=g(v.xaxis,R),F=g(v.xaxis,F)),q&&(B=g(v.yaxis,B),N=g(v.yaxis,N),j=g(v.yaxis,j),U=g(v.yaxis,U));var H=(D+F)/2,G=(B+j)/2,Y=b({x0:H,y0:G,x1:H+(F-D+R-O)/2*f,y1:G+(U-N+j-B)/2*h});V&&(Y.x0=d(v.xaxis,Y.x0),Y.x1=d(v.xaxis,Y.x1)),q&&(Y.y0=d(v.yaxis,Y.y0),Y.y1=d(v.yaxis,Y.y1)),z.x0=Y.x0,z.y0=Y.y0,z.x1=Y.x1,z.y1=Y.y1}else z.type=\"path\",_&&w&&function(t,e,r){var n=\"date\"===e.type,i=\"date\"===r.type;if(!n&&!i)return t;for(var a=0;a<t.length;a++)for(var o=0;o<t[a].length;o++)for(var s=0;s+2<t[a][o].length;s+=2)n&&(t[a][o][s+1]=t[a][o][s+1].replace(\" \",\"_\")),i&&(t[a][o][s+2]=t[a][o][s+2].replace(\" \",\"_\"))}(P,_,w),z.path=x(P),L=null;m(o);for(var W=e.editHelpers,X=(W||{}).modifyItem,Z=[],J=0;J<S.length;J++){var K=o._fullLayout.shapes[J];if(Z[J]=K._input,void 0!==M&&J===o._fullLayout._activeShapeIndex){var Q=z;switch(K.type){case\"line\":case\"rect\":case\"circle\":X(\"x0\",Q.x0),X(\"x1\",Q.x1),X(\"y0\",Q.y0),X(\"y1\",Q.y1);break;case\"path\":X(\"path\",Q.path)}}}return void 0===M?(Z.push(z),Z):W?W.getUpdateObj():{}}}}},{\"../../../plots/cartesian/handle_outline\":838,\"../../../plots/cartesian/helpers\":839,\"../../dragelement/helpers\":661,\"./constants\":726,\"./helpers\":729}],731:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach((function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}})),r},r.getDataToPixel=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){return e._length*(n?1-t:t)+e._offset};else{var s=r.shapePositionToRange(e);a=function(t){return e._offset+e.r2p(s(t,!0))},\"date\"===e.type&&(a=r.decodeDate(a))}else a=n?function(t){return o.t+o.h*(1-t)}:function(t){return o.l+o.w*t};return a},r.getPixelToData=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){var r=(t-e._offset)/e._length;return n?1-r:r};else{var s=r.rangeToShapePosition(e);a=function(t){return s(e.p2r(t-e._offset))}}else a=n?function(t){return 1-(t-o.t)/o.h}:function(t){return(t-o.l)/o.w};return a},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n},r.makeOptionsAndPlotinfo=function(t,e){var r=t._fullLayout.shapes[e]||{},n=t._fullLayout._plots[r.xref+r.yref];return!!n?n._hadPlotinfo=!0:(n={},r.xref&&\"paper\"!==r.xref&&(n.xaxis=t._fullLayout[r.xref+\"axis\"]),r.yref&&\"paper\"!==r.yref&&(n.yaxis=t._fullLayout[r.yref+\"axis\"])),n.xsizemode=r.xsizemode,n.ysizemode=r.ysizemode,n.xanchor=r.xanchor,n.yanchor=r.yanchor,{options:r,plotinfo:n}}},{\"../../lib\":778,\"./constants\":722}],732:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),supplyDrawNewShapeDefaults:t(\"./draw_newshape/defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":720,\"./calc_autorange\":721,\"./defaults\":723,\"./draw\":724,\"./draw_newshape/defaults\":727}],733:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/animation_attributes\":822,\"../../plots/font_attributes\":856,\"../../plots/pad_attributes\":890,\"./constants\":734}],734:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],735:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var f=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=f[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"./attributes\":733,\"./constants\":734}],736:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plot_api/plot_template\").arrayEditor,f=t(\"./constants\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,g=h.FROM_BR;function m(t){return f.autoMarginIdRoot+t._index}function v(t){return t._index}function y(t,e){var r=o.tester.selectAll(\"g.\"+f.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(f.labelGroupClass,!0);var a=0,l=0;r.each((function(t){var r=_(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);l=Math.max(l,i.height),a=Math.max(a,i.width)}})),r.remove();var u=e._dims={};u.inputAreaWidth=Math.max(f.railWidth,f.gripHeight);var h=t._fullLayout._size;u.lx=h.l+h.w*e.x,u.ly=h.t+h.h*(1-e.y),\"fraction\"===e.lenmode?u.outerLength=Math.round(h.w*e.len):u.outerLength=e.len,u.inputAreaStart=0,u.inputAreaLength=Math.round(u.outerLength-e.pad.l-e.pad.r);var p=(u.inputAreaLength-2*f.stepInset)/(e._stepCount-1),v=a+f.labelPadding;if(u.labelStride=Math.max(1,Math.ceil(v/p)),u.labelHeight=l,u.currentValueMaxWidth=0,u.currentValueHeight=0,u.currentValueTotalHeight=0,u.currentValueMaxLines=1,e.currentvalue.visible){var y=o.tester.append(\"g\");r.each((function(t){var r=x(y,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=c.lineCount(r);u.currentValueMaxWidth=Math.max(u.currentValueMaxWidth,Math.ceil(n.width)),u.currentValueHeight=Math.max(u.currentValueHeight,Math.ceil(n.height)),u.currentValueMaxLines=Math.max(u.currentValueMaxLines,i)})),u.currentValueTotalHeight=u.currentValueHeight+e.currentvalue.offset,y.remove()}u.height=u.currentValueTotalHeight+f.tickOffset+e.ticklen+f.labelOffset+u.labelHeight+e.pad.t+e.pad.b;var b=\"left\";s.isRightAnchor(e)&&(u.lx-=u.outerLength,b=\"right\"),s.isCenterAnchor(e)&&(u.lx-=u.outerLength/2,b=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(u.ly-=u.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(u.ly-=u.height/2,w=\"middle\"),u.outerLength=Math.ceil(u.outerLength),u.height=Math.ceil(u.height),u.lx=Math.round(u.lx),u.ly=Math.round(u.ly);var T={y:e.y,b:u.height*g[w],t:u.height*d[w]};\"fraction\"===e.lenmode?(T.l=0,T.xl=e.x-e.len*d[b],T.r=0,T.xr=e.x+e.len*g[b]):(T.x=e.x,T.l=u.outerLength*d[b],T.r=u.outerLength*g[b]),i.autoMargin(t,m(e),T)}function x(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-f.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=f.currentValueInset,i=\"left\"}var l=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":i,\"data-notex\":1})})),u=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)u+=r;else{var h=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(h=s.templateString(h,d)),u+=h}e.currentvalue.suffix&&(u+=e.currentvalue.suffix),l.call(o.font,e.currentvalue.font).text(u).call(c.convertToTspans,e._gd);var g=c.lineCount(l),m=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*p;return c.positionText(l,n,m),l}}function b(t,e,r){s.ensureSingle(t,\"rect\",f.gripRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")})).attr({width:f.gripWidth,height:f.gripHeight,rx:f.gripRadius,ry:f.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function _(t,e,r){var n=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":\"middle\",\"data-notex\":1})})),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(c.convertToTspans,r._gd),n}function w(t,e){var r=s.ensureSingle(t,\"g\",f.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+f.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(f.labelGroupClass,!0),a.exit().remove(),a.each((function(t){var r=n.select(this);r.call(_,t,e),o.setTranslate(r,E(e,t.fraction),f.tickOffset+e.ticklen+e.font.size*p+f.labelOffset+i.currentValueTotalHeight)}))}function T(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,u(t.layout,f.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(S,r,o),e.call(x,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame((function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)}))))}function M(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",(function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+f.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=C(t,n.mouse(i)[0]);T(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",(function(){var t=s(),a=C(t,n.mouse(i)[0]);T(e,r,t,a,!1)})),o.on(\"mouseup\",(function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})}))}))}function A(t,e){var r=t.selectAll(\"rect.\"+f.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(f.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each((function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,E(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?f.tickOffset:f.minorTickOffset)+i.currentValueTotalHeight)}))}function S(t,e,r){for(var n=t.select(\"rect.\"+f.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=E(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",l(o-.5*f.gripWidth,e._dims.currentValueTotalHeight))}}function E(t,e){var r=t._dims;return r.inputAreaStart+f.stepInset+(r.inputAreaLength-2*f.stepInset)*Math.min(1,Math.max(0,e))}function C(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-f.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*f.stepInset-2*r.inputAreaStart)))}function L(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",f.railTouchRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")}));i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,f.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function I(t,e){var r=e._dims,n=r.inputAreaLength-2*f.railInset,i=s.ensureSingle(t,\"rect\",f.railRectClass);i.attr({width:n,height:f.railWidth,rx:f.railRadius,ry:f.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,f.railInset,.5*(r.inputAreaWidth-f.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[f.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,m(e))}if(a.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each((function(){n.select(this).selectAll(\"g.\"+f.groupClassName).each(s)})).remove(),0!==r.length){var l=a.selectAll(\"g.\"+f.groupClassName).data(r,v);l.enter().append(\"g\").classed(f.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var u=r[c];y(t,u)}l.each((function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,(function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))})),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(x,r).call(I,r).call(w,r).call(A,r).call(L,t,r).call(b,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(S,r,!1),e.call(x,r)}(t,n.select(this),e)}))}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/plots\":891,\"../color\":643,\"../drawing\":665,\"./constants\":734,d3:169}],737:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":733,\"./constants\":734,\"./defaults\":735,\"./draw\":736}],738:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\"),p=t(\"../../constants/alignment\").OPPOSITE_SIDE,d=/ [XY][0-9]* /;e.exports={draw:function(t,e,r){var g,m=r.propContainer,v=r.propName,y=r.placeholder,x=r.traceIndex,b=r.avoid||{},_=r.attributes,w=r.transform,T=r.containerGroup,k=t._fullLayout,M=1,A=!1,S=m.title,E=(S&&S.text?S.text:\"\").trim(),C=S&&S.font?S.font:{},L=C.family,I=C.size,P=C.color;\"title.text\"===v?g=\"titleText\":-1!==v.indexOf(\"axis\")?g=\"axisTitleText\":v.indexOf(!0)&&(g=\"colorbarTitleText\");var z=t._context.edits[g];\"\"===E?M=0:E.replace(d,\" % \")===y.replace(d,\" % \")&&(M=.2,A=!0,z||(E=\"\")),r._meta?E=s.templateString(E,r._meta):k._meta&&(E=s.templateString(E,k._meta));var O=E||z;T||(T=s.ensureSingle(k._infolayer,\"g\",\"g-\"+e));var D=T.selectAll(\"text\").data(O?[0]:[]);if(D.enter().append(\"text\"),D.text(E).attr(\"class\",e),D.exit().remove(),!O)return T;function R(t){s.syncOrAsync([F,B],t)}function F(e){var r;return w?(r=\"\",w.rotate&&(r+=\"rotate(\"+[w.rotate,_.x,_.y]+\")\"),w.offset&&(r+=l(0,w.offset))):r=null,e.attr(\"transform\",r),e.style({\"font-family\":L,\"font-size\":n.round(I,2)+\"px\",fill:u.rgb(P),opacity:M*u.opacity(P),\"font-weight\":a.fontWeight}).attr(_).call(f.convertToTspans,t),a.previousPromises(t)}function B(t){var e=n.select(t.node().parentNode);if(b&&b.selection&&b.side&&E){e.attr(\"transform\",null);var r=p[b.side],a=\"left\"===b.side||\"top\"===b.side?-1:1,o=i(b.pad)?b.pad:2,u=c.bBox(e.node()),f={left:0,top:0,right:k.width,bottom:k.height},h=b.maxShift||a*(f[b.side]-u[b.side]),d=0;if(h<0)d=h;else{var g=b.offsetLeft||0,m=b.offsetTop||0;u.left-=g,u.right-=g,u.top-=m,u.bottom-=m,b.selection.each((function(){var t=c.bBox(this);s.bBoxIntersect(u,t,o)&&(d=Math.max(d,a*(t[b.side]-u[r])+o))})),d=Math.min(h,d)}if(d>0||h<0){var v={left:[-d,0],right:[d,0],top:[0,-d],bottom:[0,d]}[b.side];e.attr(\"transform\",l(v[0],v[1]))}}}return D.call(R),z&&(E?D.on(\".opacity\",null):(M=0,A=!0,D.text(y).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)}))),D.call(f.makeEditable,{gd:t}).on(\"edit\",(function(e){void 0!==x?o.call(\"_guiRestyle\",t,v,e,x):o.call(\"_guiRelayout\",t,v,e)})).on(\"cancel\",(function(){this.text(this.attr(\"data-unformatted\")).call(R)})).on(\"input\",(function(t){this.text(t||\" \").call(f.positionText,_.x,_.y)}))),D.classed(\"js-placeholder\",A),T}}},{\"../../constants/alignment\":745,\"../../constants/interactions\":752,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../drawing\":665,d3:169,\"fast-isnumeric\":241}],739:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},args2:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/font_attributes\":856,\"../../plots/pad_attributes\":890,\"../color/attributes\":642}],740:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],741:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"args2\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"./attributes\":739,\"./constants\":740}],742:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,f=t(\"./constants\"),h=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(f.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,f.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?v(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(f.menuIndexAttrName,\"-1\"),m(t,n,i,a,e),s||v(t,n,i,a,e))}function m(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",f.headerClassName,(function(t){t.style(\"pointer-events\",\"all\")})),l=i._dims,c=i.active,u=i.buttons[c]||f.blankHeaderOpts,h={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(A,i,h,p),s.ensureSingle(e,\"text\",f.headerArrowClassName,(function(t){t.attr(\"text-anchor\",\"end\").call(o.font,i.font).text(f.arrowSymbol[i.direction])})).attr({x:l.headerWidth-f.arrowOffsetX+i.pad.l,y:l.headerHeight/2+f.textOffsetY+i.pad.t}),a.on(\"click\",(function(){r.call(S,String(d(r,i)?-1:i._index)),v(t,e,r,n,i)})),a.on(\"mouseover\",(function(){a.call(w)})),a.on(\"mouseout\",(function(){a.call(T,i)})),o.setTranslate(e,l.lx,l.ly)}function v(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(f.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?f.dropdownButtonClassName:f.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),h=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(h.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,m=0,v=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?m=v.headerHeight+f.gapButtonHeader:d=v.headerWidth+f.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(m=-f.gapButtonHeader+f.gapButton-v.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-f.gapButtonHeader+f.gapButton-v.openWidth);var b={x:v.lx+d+o.pad.l,y:v.ly+m+o.pad.t,yPad:f.gapButton,xPad:f.gapButton,index:0},k={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each((function(s,l){var c=n.select(this);c.call(y,o,s,t).call(A,o,b),c.on(\"click\",(function(){n.event.defaultPrevented||(s.execute&&(s.args2&&o.active===l?(g(t,o,0,e,r,a,-1),i.executeAPICommand(t,s.method,s.args2)):(g(t,o,0,e,r,a,l),i.executeAPICommand(t,s.method,s.args))),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))})),c.on(\"mouseover\",(function(){c.call(w)})),c.on(\"mouseout\",(function(){c.call(T,o),u.call(_,o)}))})),u.call(_,o),x?(k.w=Math.max(v.openWidth,v.headerWidth),k.h=b.y-k.t):(k.w=b.x-k.l,k.h=Math.max(v.openHeight,v.headerHeight)),k.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,h=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=h.heights[l]+f.gapButton;else for(o=0,l=0;l<p;l++)o+=h.widths[l]+f.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,k):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){e=!1,r||t.disable()}));r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){r=!1,e||t.disable()}))}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",f.itemRectClassName,(function(t){t.attr({rx:f.rx,ry:f.ry,\"shape-rendering\":\"crispEdges\"})})).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",f.itemTextClassName,(function(t){t.attr({\"text-anchor\":\"start\",\"data-notex\":1})})),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each((function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.activeColor)}))}function w(t){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.hoverColor)}function T(t,e){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,e.bgcolor)}function k(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+f.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(f.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each((function(i,a){var s=n.select(this);s.call(y,e,i,t);var h=s.select(\".\"+f.itemTextClassName),p=h.node()&&o.bBox(h.node()).width,d=Math.max(p+f.textPadX,f.minWidth),g=e.font.size*u,m=l.lineCount(h),v=Math.max(g*m,f.minHeight)+f.textOffsetY;v=Math.ceil(v),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=v,r.height1=Math.max(r.height1,v),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=v+f.gapButton,r.openHeight+=v+f.gapButton):(r.totalWidth+=d+f.gapButton,r.openWidth+=d+f.gapButton,r.totalHeight=Math.max(r.totalHeight,v),r.openHeight=r.totalHeight)})),c?r.totalHeight-=f.gapButton:r.totalWidth-=f.gapButton,r.headerWidth=r.width1+f.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=f.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=f.arrowPadX),a.remove();var h=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=h,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=h/2,g=\"center\");var m=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,m=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,m=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,M(e),{x:e.x,y:e.y,l:h*({right:1,center:.5}[g]||0),r:h*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[m]||0),t:p*({bottom:1,middle:.5}[m]||0)})}function M(t){return f.autoMarginIdRoot+t._index}function A(t,e,r,n){n=n||{};var i=t.select(\".\"+f.itemRectClassName),a=t.select(\".\"+f.itemTextClassName),s=e.borderwidth,c=r.index,h=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?h.heights[c]:h.height1);i.attr({x:0,y:0,width:n.width||(p?h.width1:h.widths[c]),height:d});var g=e.font.size*u,m=(l.lineCount(a)-1)*g/2;l.positionText(a,f.textOffsetX,d/2-m+f.textOffsetY),p?r.y+=h.heights[c]+r.yPad:r.x+=h.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(f.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+f.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[f.name]);function a(e){i.autoMargin(t,M(e))}var o=e._menulayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each((function(){n.select(this).selectAll(\"g.\"+f.headerGroupClassName).each(a)})).remove(),0!==r.length){var l=o.selectAll(\"g.\"+f.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(f.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",f.dropdownButtonGroupClassName,(function(t){t.style(\"pointer-events\",\"all\")})),u=0;u<r.length;u++){var y=r[u];k(t,y)}var x=\"updatemenus\"+e._uid,b=new h(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each((function(t){c.call(S),a(t)})).remove(),l.each((function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,(function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)})),\"dropdown\"===e.type?(m(t,r,c,b,e),d(c,e)&&v(t,r,c,b,e)):v(t,r,null,null,e)}))}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/plots\":891,\"../color\":643,\"../drawing\":665,\"./constants\":740,\"./scrollbox\":744,d3:169}],743:[function(t,e,r){arguments[4][737][0].apply(r,arguments)},{\"./attributes\":739,\"./constants\":740,\"./defaults\":741,\"./draw\":742,dup:737}],744:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,f,h,p,d=this.position.l,g=this.position.w,m=this.position.t,v=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,T=v;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(f=(u=d)+w,x?(h=m,T=(p=Math.min(h+T,c))-h):T=(p=m+T)-(h=Math.max(p-T,0))):(p=(h=m)+T,b?w=(f=d+w)-(u=Math.max(f-w,0)):(u=d,w=(f=Math.min(u+w,l))-u)),this._box={l:u,t:h,w:w,h:T};var k=g>w,M=s.barLength+2*s.barPad,A=s.barWidth+2*s.barPad,S=d,E=m+v;E+A>c&&(E=c-A);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(k?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),k?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:M,height:A}),this._hbarXMin=S+M/2,this._hbarTranslateMax=w-M):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=v>T,I=s.barWidth+2*s.barPad,P=s.barLength+2*s.barPad,z=d+g,O=m;z+I>l&&(z=l-I);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:O,width:I,height:P}),this._vbarYMin=O+P/2,this._vbarTranslateMax=T-P):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?f+I+.5:f+.5,N=h-.5,j=k?p+A+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(k||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),k||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:m,width:g,height:v})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),k||L){var V=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault()})).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()})).on(\"drag\",this._onBarDrag.bind(this));k&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":778,\"../color\":643,\"../drawing\":665,d3:169}],745:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],746:[function(t,e,r){\"use strict\";e.exports={axisRefDescription:function(t,e,r){return[\"If set to a\",t,\"axis id (e.g. *\"+t+\"* or\",\"*\"+t+\"2*), the `\"+t+\"` position refers to a\",t,\"coordinate. If set to *paper*, the `\"+t+\"`\",\"position refers to the distance from the\",e,\"of the plotting\",\"area in normalized coordinates where *0* (*1*) corresponds to the\",e,\"(\"+r+\"). If set to a\",t,\"axis ID followed by\",\"*domain* (separated by a space), the position behaves like for\",\"*paper*, but refers to the distance in fractions of the domain\",\"length from the\",e,\"of the domain of that axis: e.g.,\",\"*\"+t+\"2 domain* refers to the domain of the second\",t,\" axis and a\",t,\"position of 0.5 refers to the\",\"point between the\",e,\"and the\",r,\"of the domain of the\",\"second\",t,\"axis.\"].join(\" \")}}},{}],747:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-time-format#locale_format\"}},{}],749:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],750:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],751:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],752:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],753:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEMAXYEAR:316224e5,ONEAVGYEAR:315576e5,ONEMINYEAR:31536e6,ONEMAXQUARTER:79488e5,ONEAVGQUARTER:78894e5,ONEMINQUARTER:76896e5,ONEMAXMONTH:26784e5,ONEAVGMONTH:26298e5,ONEMINMONTH:24192e5,ONEWEEK:6048e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:.999999,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],754:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],755:[function(t,e,r){\"use strict\";r.version=t(\"./version\").version,t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/legend\"),t(\"./components/fx\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),window.PlotlyLocales&&Array.isArray(window.PlotlyLocales)&&(i(window.PlotlyLocales),delete window.PlotlyLocales),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":634,\"./components/annotations3d\":639,\"./components/colorbar\":649,\"./components/colorscale\":655,\"./components/errorbars\":671,\"./components/fx\":683,\"./components/grid\":687,\"./components/images\":692,\"./components/legend\":700,\"./components/rangeselector\":711,\"./components/rangeslider\":718,\"./components/shapes\":732,\"./components/sliders\":737,\"./components/updatemenus\":743,\"./fonts/mathjax_config\":756,\"./fonts/ploticon\":757,\"./lib/queue\":794,\"./locale-en\":808,\"./locale-en-us\":807,\"./plot_api\":812,\"./plot_api/plot_schema\":816,\"./plots/plots\":891,\"./registry\":911,\"./snapshot\":916,\"./traces/scatter\":1199,\"./version\":1370,d3:169,\"es6-promise\":224}],756:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],757:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawopenpath:{width:70,height:70,path:\"M33.21,85.65a7.31,7.31,0,0,1-2.59-.48c-8.16-3.11-9.27-19.8-9.88-41.3-.1-3.58-.19-6.68-.35-9-.15-2.1-.67-3.48-1.43-3.79-2.13-.88-7.91,2.32-12,5.86L3,32.38c1.87-1.64,11.55-9.66,18.27-6.9,2.13.87,4.75,3.14,5.17,9,.17,2.43.26,5.59.36,9.25a224.17,224.17,0,0,0,1.5,23.4c1.54,10.76,4,12.22,4.48,12.4.84.32,2.79-.46,5.76-3.59L43,80.07C41.53,81.57,37.68,85.64,33.21,85.65ZM74.81,69a11.34,11.34,0,0,0,6.09-6.72L87.26,44.5,74.72,32,56.9,38.35c-2.37.86-5.57,3.42-6.61,6L38.65,72.14l8.42,8.43ZM55,46.27a7.91,7.91,0,0,1,3.64-3.17l14.8-5.3,8,8L76.11,60.6l-.06.19a6.37,6.37,0,0,1-3,3.43L48.25,74.59,44.62,71Zm16.57,7.82A6.9,6.9,0,1,0,64.64,61,6.91,6.91,0,0,0,71.54,54.09Zm-4.05,0a2.85,2.85,0,1,1-2.85-2.85A2.86,2.86,0,0,1,67.49,54.09Zm-4.13,5.22L60.5,56.45,44.26,72.7l2.86,2.86ZM97.83,35.67,84.14,22l-8.57,8.57L89.26,44.24Zm-13.69-8,8,8-2.85,2.85-8-8Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawclosedpath:{width:90,height:90,path:\"M88.41,21.12a26.56,26.56,0,0,0-36.18,0l-2.07,2-2.07-2a26.57,26.57,0,0,0-36.18,0,23.74,23.74,0,0,0,0,34.8L48,90.12a3.22,3.22,0,0,0,4.42,0l36-34.21a23.73,23.73,0,0,0,0-34.79ZM84,51.24,50.16,83.35,16.35,51.25a17.28,17.28,0,0,1,0-25.47,20,20,0,0,1,27.3,0l4.29,4.07a3.23,3.23,0,0,0,4.44,0l4.29-4.07a20,20,0,0,1,27.3,0,17.27,17.27,0,0,1,0,25.46ZM66.76,47.68h-33v6.91h33ZM53.35,35H46.44V68h6.91Z\",transform:\"matrix(1 0 0 1 -5 -5)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawline:{width:70,height:70,path:\"M60.64,62.3a11.29,11.29,0,0,0,6.09-6.72l6.35-17.72L60.54,25.31l-17.82,6.4c-2.36.86-5.57,3.41-6.6,6L24.48,65.5l8.42,8.42ZM40.79,39.63a7.89,7.89,0,0,1,3.65-3.17l14.79-5.31,8,8L61.94,54l-.06.19a6.44,6.44,0,0,1-3,3.43L34.07,68l-3.62-3.63Zm16.57,7.81a6.9,6.9,0,1,0-6.89,6.9A6.9,6.9,0,0,0,57.36,47.44Zm-4,0a2.86,2.86,0,1,1-2.85-2.85A2.86,2.86,0,0,1,53.32,47.44Zm-4.13,5.22L46.33,49.8,30.08,66.05l2.86,2.86ZM83.65,29,70,15.34,61.4,23.9,75.09,37.59ZM70,21.06l8,8-2.84,2.85-8-8ZM87,80.49H10.67V87H87Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawrect:{width:80,height:80,path:\"M78,22V79H21V22H78m9-9H12V88H87V13ZM68,46.22H31V54H68ZM53,32H45.22V69H53Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},drawcircle:{width:80,height:80,path:\"M50,84.72C26.84,84.72,8,69.28,8,50.3S26.84,15.87,50,15.87,92,31.31,92,50.3,73.16,84.72,50,84.72Zm0-60.59c-18.6,0-33.74,11.74-33.74,26.17S31.4,76.46,50,76.46,83.74,64.72,83.74,50.3,68.6,24.13,50,24.13Zm17.15,22h-34v7.11h34Zm-13.8-13H46.24v34h7.11Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},eraseshape:{width:80,height:80,path:\"M82.77,78H31.85L6,49.57,31.85,21.14H82.77a8.72,8.72,0,0,1,8.65,8.77V69.24A8.72,8.72,0,0,1,82.77,78ZM35.46,69.84H82.77a.57.57,0,0,0,.49-.6V29.91a.57.57,0,0,0-.49-.61H35.46L17,49.57Zm32.68-34.7-24,24,5,5,24-24Zm-19,.53-5,5,24,24,5-5Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #3f4f75;} .cls-2 {fill: #80cfbe;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],758:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],759:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function f(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,f,h,p,d,g=l([r,n]);function m(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,f=o,h=s):r<n?(u=r,h=n):(u=n,h=r),t<e?(p=t,d=e):(p=e,d=t);var v,y=Math.abs(h-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+m(t,e)}return g?v=null===p?\"M\"+m(d,u)+x(d,f,0)+x(d,h,0)+\"Z\":\"M\"+m(p,u)+x(p,f,0)+x(p,h,0)+\"ZM\"+m(d,u)+x(d,f,1)+x(d,h,1)+\"Z\":null===p?(v=\"M\"+m(d,u)+x(d,h,0),c&&(v+=\"L0,0Z\")):v=\"M\"+m(p,u)+\"L\"+m(d,u)+x(d,h,0)+\"L\"+m(p,h)+x(p,u,1)+\"Z\",v}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return f(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return f(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return f(t,e,r,n,i,a,1)}}},{\"./mod\":785}],760:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,f=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,f?t!==i.constructor&&(t=!1):t=i.constructor),f+=o);if(!f)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(f)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(f),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],761:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":753,\"fast-isnumeric\":241}],762:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each((function(t){t.regl&&t.regl.clear({color:!0,depth:!0})}))}},{}],763:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],764:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,f=t(\"./array\").isArrayOrTypedArray;function h(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&f(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){f(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every((function(t){return i(t).isValid()}))?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,f,h,p=i.items,d=[],g=Array.isArray(p),m=g&&o&&Array.isArray(p[0]),v=o&&g&&!m,y=g&&!v?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],f=v?p.length:g?p[s].length:c.length,l=0;l<f;l++)u=v?p[l]:g?p[s][l]:p,void 0!==(h=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=h);else for(s=0;s<y;s++)void 0!==(h=a(t[s],g?p[s]:p,n[s]))&&(d[s]=h);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!h(t[a][o],n?r[a][o]:r))return!1}else if(!h(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&f(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!h(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)f(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=h},{\"../components/colorscale/scales\":658,\"../constants/interactions\":752,\"../plots/attributes\":824,\"./array\":760,\"./mod\":785,\"./nested_property\":786,\"./regex\":795,\"fast-isnumeric\":241,tinycolor2:576}],765:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3-time-format\").timeFormat,o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,f=c.ONEDAY,h=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,m=t(\"../registry\"),v=t(\"d3-time-format\").utcFormat,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&m.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){var n=function(t,e){return _(t)?e?m.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:m.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"}(t,!!e);if(e<2)return n;var i=r.dateTime2ms(n,t);return i+=f*(e-1),r.ms2DateTime(i,0,t)},r.dfltRange=function(t){return _(t)?m.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),v=t.charAt(0);!c||\"G\"!==v&&\"g\"!==v||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),T=t.match(w?x:y);if(!T)return u;var k=T[1],M=T[3]||\"1\",A=Number(T[5]||1),S=Number(T[7]||0),E=Number(T[9]||0),C=Number(T[11]||0);if(c){if(2===k.length)return u;var L;k=Number(k);try{var I=m.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var P=\"i\"===M.charAt(M.length-1);M=parseInt(M,10),L=I.newDate(k,I.toMonthIndex(k,M,P),A)}else L=I.newDate(k,Number(M),A)}catch(t){return u}return L?(L.toJD()-g)*f+S*h+E*p+C*d:u}k=2===k.length?(Number(k)+2e3-b)%100+b:Number(k),M-=1;var z=new Date(Date.UTC(2e3,M,A,S,E));return z.setUTCFullYear(k),z.getUTCMonth()!==M||z.getUTCDate()!==A?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var T=90*f,k=3*h,M=5*p;function A(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/f)+g,E=Math.floor(l(t,f));try{a=m.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=v(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<T?Math.floor(E/h):0,s=e<T?Math.floor(E%h/p):0,c=e<k?Math.floor(E%p/d):0,y=e<M?E%d*10+b:0}else x=new Date(w),a=v(\"%Y-%m-%d\")(x),o=e<T?x.getUTCHours():0,s=e<T?x.getUTCMinutes():0,c=e<k?x.getUTCSeconds():0,y=e<M?10*x.getUTCMilliseconds()+b:0;return A(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+f&&t<=i-f))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return A(a(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,(function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"}));var i=new Date(Math.floor(e+.05));if(_(n))try{t=m.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,f),n=w(Math.floor(r/h),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*f;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,f);if(t=Math.round(t-n),r)try{var i=Math.round(t/f)+g,a=m.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*f+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&m.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%f))if(c)try{1===(r=c.fromJD(n/f+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var h=t.length-l;return{exactYears:i/h,exactMonths:a/h,exactDays:s/h}}},{\"../constants/numerical\":753,\"../registry\":911,\"./loggers\":782,\"./mod\":785,\"d3-time-format\":166,\"fast-isnumeric\":241}],766:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\"),a=t(\"./matrix\"),o=t(\"gl-mat4\");function s(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function l(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}function c(t){var e=window.getComputedStyle(t,null),r=e.getPropertyValue(\"-webkit-transform\")||e.getPropertyValue(\"-moz-transform\")||e.getPropertyValue(\"-ms-transform\")||e.getPropertyValue(\"-o-transform\")||e.getPropertyValue(\"transform\");return\"none\"===r?null:r.replace(\"matrix\",\"\").replace(\"3d\",\"\").slice(1,-1).split(\",\").map((function(t){return+t}))}function u(t){for(var e=[];f(t);)e.push(t),t=t.parentNode;return e}function f(t){return t&&(t instanceof Element||t instanceof HTMLElement)}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:s,addStyleRule:function(t,e){l(\"global\",t,e)},addRelatedStyleRule:l,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&s(r)},getFullTransformMatrix:function(t){var e=u(t),r=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];return e.forEach((function(t){var e=c(t);if(e){var n=a.convertCssMatrix(e);r=o.multiply(r,r,n)}})),r},getElementTransformMatrix:c,getElementAndAncestors:u,equalDomRects:function(t,e){return t&&e&&t.x===e.x&&t.y===e.y&&t.top===e.top&&t.left===e.left&&t.right===e.right&&t.bottom===e.bottom}}},{\"./loggers\":782,\"./matrix\":784,d3:169,\"gl-mat4\":292}],767:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:110}],768:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,f,h,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(f=i(u)))?(f?(f=!1,h=c&&i(c)?c:[]):h=c&&n(c)?c:{},p[l]=a([h,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":779}],769:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],770:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],771:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"country-regex\"),a=t(\"@turf/area\"),o=t(\"@turf/centroid\"),s=t(\"@turf/bbox\"),l=t(\"./identity\"),c=t(\"./loggers\"),u=t(\"./is_plain_object\"),f=t(\"./nested_property\"),h=t(\"./polygon\"),p=Object.keys(i),d={\"ISO-3\":l,\"USA-states\":l,\"country names\":function(t){for(var e=0;e<p.length;e++){var r=p[e];if(new RegExp(i[r]).test(t.trim().toLowerCase()))return r}return c.log(\"Unrecognized country name: \"+t+\".\"),!1}};function g(t){var e=t.geojson,r=window.PlotlyGeoAssets||{},n=\"string\"==typeof e?r[e]:e;return u(n)?n:(c.error(\"Oops ... something went wrong when fetching \"+e),!1)}e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,i,a,o=d[t](e);if(o){if(\"USA-states\"===t)for(n=[],a=0;a<r.length;a++)(i=r[a]).properties&&i.properties.gu&&\"USA\"===i.properties.gu&&n.push(i);else n=r;for(a=0;a<n.length;a++)if((i=n[a]).id===o)return i;c.log([\"Location with id\",o,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1},feature2polygons:function(t){var e,r,n,i,a=t.geometry,o=a.coordinates,s=t.id,l=[];function c(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===s||\"FJI\"===s?function(t){var e;if(null===c(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];l.push(h.tester(e))}:\"ATA\"===s?function(t){var e=c(t);if(null===e)return l.push(h.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var a=h.tester(r);a.pts.pop(),l.push(a)}:function(t){l.push(h.tester(t))},a.type){case\"MultiPolygon\":for(r=0;r<o.length;r++)for(n=0;n<o[r].length;n++)e(o[r][n]);break;case\"Polygon\":for(r=0;r<o.length;r++)e(o[r])}return l},getTraceGeojson:g,extractTraceFeature:function(t){var e=t[0].trace,r=g(e);if(!r)return!1;var n,i={},s=[];for(n=0;n<e._length;n++){var l=t[n];(l.loc||0===l.loc)&&(i[l.loc]=l)}function u(t){var r=f(t,e.featureidkey||\"id\").get(),n=i[r];if(n){var l=t.geometry;if(\"Polygon\"===l.type||\"MultiPolygon\"===l.type){var u={type:\"Feature\",id:r,geometry:l,properties:{}};u.properties.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,i=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=a.default(l);c>i&&(i=c,e=l)}else e=r;return o.default(e).geometry.coordinates}(u),n.fIn=t,n.fOut=u,s.push(u)}else c.log([\"Location\",n.loc,\"does not have a valid GeoJSON geometry.\",\"Traces with locationmode *geojson-id* only support\",\"*Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete i[r]}switch(r.type){case\"FeatureCollection\":var h=r.features;for(n=0;n<h.length;n++)u(h[n]);break;case\"Feature\":u(r);break;default:return c.warn([\"Invalid GeoJSON type\",(r.type||\"none\")+\".\",\"Traces with locationmode *geojson-id* only support\",\"*FeatureCollection* and *Feature* types.\"].join(\" \")),!1}for(var p in i)c.log([\"Location *\"+p+\"*\",\"does not have a matching feature with id-key\",\"*\"+e.featureidkey+\"*.\"].join(\" \"));return s},fetchTraceGeoData:function(t){var e=window.PlotlyGeoAssets||{},r=[];function i(t){return new Promise((function(r,i){n.json(t,(function(n,a){if(n){delete e[t];var o=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return i(new Error(o))}return e[t]=a,r(a)}))}))}function a(t){return new Promise((function(r,n){var i=0,a=setInterval((function(){return e[t]&&\"pending\"!==e[t]?(clearInterval(a),r(e[t])):i>100?(clearInterval(a),n(\"Unexpected error while fetching from \"+t)):void i++}),50)}))}for(var o=0;o<t.length;o++){var s=t[o][0].trace.geojson;\"string\"==typeof s&&(e[s]?\"pending\"===e[s]&&r.push(a(s)):(e[s]=\"pending\",r.push(i(s))))}return r},computeBbox:function(t){return s.default(t)}}},{\"./identity\":776,\"./is_plain_object\":779,\"./loggers\":782,\"./nested_property\":786,\"./polygon\":790,\"@turf/area\":59,\"@turf/bbox\":60,\"@turf/centroid\":61,\"country-regex\":139,d3:169}],772:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":753}],773:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,f=n-e,h=a-e,p=s-a,d=l*p-u*f;if(0===d)return null;var g=(c*p-u*h)/d,m=(c*f-l*h)/d;return m<0||m>1||g<0||g>1?null:{x:t+l*g,y:e+f*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,f=n-e,h=o-i,p=c-a,d=u*u+f*f,g=h*h+p*p,m=Math.min(l(u,f,d,i-t,a-e),l(u,f,d,o-t,c-e),l(h,p,g,t-i,e-a),l(h,p,g,r-i,n-a));return Math.sqrt(m)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),f=t.getPointAtLength(o(r,e)),h={x:(4*f.x+l.x+c.x)/6,y:(4*f.y+l.y+c.y)/6,theta:u};return n[r]=h,h},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),f=u;function h(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,f=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+f*f)}for(var p=h(c);p;){if((c+=p+r)>f)return;p=h(c)}for(p=h(f);p;){if(c>(f-=p+r))return;p=h(f)}return{min:c,max:f,len:f-c,total:u,isClosed:0===c&&f===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,f=0,h=0,p=s;f<c;){if(i=(h+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:h=i,f++}return a}},{\"./mod\":785}],774:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s);function u(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function h(t){return n(t)?t:1}e.exports={formatColor:function(t,e,r){var n,i,s,p,d,g=t.color,m=l(g),v=l(e),y=o.extractOpts(t),x=[];if(n=void 0!==y.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=v?function(t,e){return void 0===t[e]?1:h(t[e])}:h,m||v)for(var b=0;b<r;b++)p=i(g,b),d=s(e,b),x[b]=u(p,d);else x=u(a(g),e);return x},parseColorScale:function(t){var e=o.extractOpts(t),r=e.colorscale;return e.reversescale&&(r=o.flipScale(e.colorscale)),r.map((function(t){var e=t[0],r=i(t[1]).toRgb();return{index:e,rgb:[r.r,r.g,r.b,r.a]}}))}}},{\"../components/color/attributes\":642,\"../components/colorscale\":655,\"./array\":760,\"color-normalize\":125,\"fast-isnumeric\":241,tinycolor2:576}],775:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":776}],776:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],777:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!e)return t;var r=1/Math.abs(e),n=r>1?(r*t+r*e)/r:t+e,i=String(n).length;if(i>16){var a=String(e).length;if(i>=String(t).length+a){var o=parseFloat(n).toPrecision(12);-1===o.indexOf(\"e+\")&&(n=+o)}}return n}},{}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../constants/numerical\"),s=o.FP_SAFE,l=o.BADNUM,c=e.exports={};c.nestedProperty=t(\"./nested_property\"),c.keyedContainer=t(\"./keyed_container\"),c.relativeAttr=t(\"./relative_attr\"),c.isPlainObject=t(\"./is_plain_object\"),c.toLogRange=t(\"./to_log_range\"),c.relinkPrivateKeys=t(\"./relink_private\");var u=t(\"./array\");c.isTypedArray=u.isTypedArray,c.isArrayOrTypedArray=u.isArrayOrTypedArray,c.isArray1D=u.isArray1D,c.ensureArray=u.ensureArray,c.concat=u.concat,c.maxRowLength=u.maxRowLength,c.minRowLength=u.minRowLength;var f=t(\"./mod\");c.mod=f.mod,c.modHalf=f.modHalf;var h=t(\"./coerce\");c.valObjectMeta=h.valObjectMeta,c.coerce=h.coerce,c.coerce2=h.coerce2,c.coerceFont=h.coerceFont,c.coerceHoverinfo=h.coerceHoverinfo,c.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,c.validate=h.validate;var p=t(\"./dates\");c.dateTime2ms=p.dateTime2ms,c.isDateTime=p.isDateTime,c.ms2DateTime=p.ms2DateTime,c.ms2DateTimeLocal=p.ms2DateTimeLocal,c.cleanDate=p.cleanDate,c.isJSDate=p.isJSDate,c.formatDate=p.formatDate,c.incrementMonth=p.incrementMonth,c.dateTick0=p.dateTick0,c.dfltRange=p.dfltRange,c.findExactDates=p.findExactDates,c.MIN_MS=p.MIN_MS,c.MAX_MS=p.MAX_MS;var d=t(\"./search\");c.findBin=d.findBin,c.sorterAsc=d.sorterAsc,c.sorterDes=d.sorterDes,c.distinctVals=d.distinctVals,c.roundUp=d.roundUp,c.sort=d.sort,c.findIndexOfMin=d.findIndexOfMin;var g=t(\"./stats\");c.aggNums=g.aggNums,c.len=g.len,c.mean=g.mean,c.median=g.median,c.midRange=g.midRange,c.variance=g.variance,c.stdev=g.stdev,c.interp=g.interp;var m=t(\"./matrix\");c.init2dArray=m.init2dArray,c.transposeRagged=m.transposeRagged,c.dot=m.dot,c.translationMatrix=m.translationMatrix,c.rotationMatrix=m.rotationMatrix,c.rotationXYMatrix=m.rotationXYMatrix,c.apply3DTransform=m.apply3DTransform,c.apply2DTransform=m.apply2DTransform,c.apply2DTransform2=m.apply2DTransform2,c.convertCssMatrix=m.convertCssMatrix,c.inverseTransformMatrix=m.inverseTransformMatrix;var v=t(\"./angles\");c.deg2rad=v.deg2rad,c.rad2deg=v.rad2deg,c.angleDelta=v.angleDelta,c.angleDist=v.angleDist,c.isFullCircle=v.isFullCircle,c.isAngleInsideSector=v.isAngleInsideSector,c.isPtInsideSector=v.isPtInsideSector,c.pathArc=v.pathArc,c.pathSector=v.pathSector,c.pathAnnulus=v.pathAnnulus;var y=t(\"./anchor_utils\");c.isLeftAnchor=y.isLeftAnchor,c.isCenterAnchor=y.isCenterAnchor,c.isRightAnchor=y.isRightAnchor,c.isTopAnchor=y.isTopAnchor,c.isMiddleAnchor=y.isMiddleAnchor,c.isBottomAnchor=y.isBottomAnchor;var x=t(\"./geometry2d\");c.segmentsIntersect=x.segmentsIntersect,c.segmentDistance=x.segmentDistance,c.getTextLocation=x.getTextLocation,c.clearLocationCache=x.clearLocationCache,c.getVisibleSegment=x.getVisibleSegment,c.findPointOnPath=x.findPointOnPath;var b=t(\"./extend\");c.extendFlat=b.extendFlat,c.extendDeep=b.extendDeep,c.extendDeepAll=b.extendDeepAll,c.extendDeepNoArrays=b.extendDeepNoArrays;var _=t(\"./loggers\");c.log=_.log,c.warn=_.warn,c.error=_.error;var w=t(\"./regex\");c.counterRegex=w.counter;var T=t(\"./throttle\");c.throttle=T.throttle,c.throttleDone=T.done,c.clearThrottle=T.clear;var k=t(\"./dom\");function M(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}c.getGraphDiv=k.getGraphDiv,c.isPlotDiv=k.isPlotDiv,c.removeElement=k.removeElement,c.addStyleRule=k.addStyleRule,c.addRelatedStyleRule=k.addRelatedStyleRule,c.deleteRelatedStyleRule=k.deleteRelatedStyleRule,c.getFullTransformMatrix=k.getFullTransformMatrix,c.getElementTransformMatrix=k.getElementTransformMatrix,c.getElementAndAncestors=k.getElementAndAncestors,c.equalDomRects=k.equalDomRects,c.clearResponsive=t(\"./clear_responsive\"),c.preserveDrawingBuffer=t(\"./preserve_drawing_buffer\"),c.makeTraceGroups=t(\"./make_trace_groups\"),c._=t(\"./localize\"),c.notifier=t(\"./notifier\"),c.filterUnique=t(\"./filter_unique\"),c.filterVisible=t(\"./filter_visible\"),c.pushUnique=t(\"./push_unique\"),c.increment=t(\"./increment\"),c.cleanNumber=t(\"./clean_number\"),c.ensureNumber=function(t){return a(t)?(t=Number(t))<-s||t>s?l:a(t)?Number(t):l:l},c.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(a(t)&&t>=0&&t%1==0)},c.noop=t(\"./noop\"),c.identity=t(\"./identity\"),c.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},c.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=c.nestedProperty(t,a.replace(\"?\",r)),s=c.nestedProperty(t,a.replace(\"?\",n)),l=o.get();o.set(s.get()),s.set(l)}},c.raiseToTop=function(t){t.parentNode.appendChild(t)},c.cancelTransition=function(t){return t.transition().duration(0)},c.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},c.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},c.simpleMap=function(t,e,r,n,i){for(var a=t.length,o=new Array(a),s=0;s<a;s++)o[s]=e(t[s],r,n,i);return o},c.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),l=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)l=Math.floor(Math.random()*n).toString(n)+l;u&&(o=Math.pow(n,u),l=Math.floor(Math.random()*o).toString(n)+l);var f=parseInt(l,n);return e&&e[l]||f!==1/0&&f>=Math.pow(2,r)?i>10?(c.warn(\"randstr failed uniqueness\"),l):t(e,r,n,(i||0)+1):l},c.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},c.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},c.syncOrAsync=function(t,e,r){var n;function i(){return c.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,c.promiseError);return r&&r(e)},c.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},c.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},c.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(c.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},c.mergeArrayCastPositive=function(t,e,r){return c.mergeArray(t,e,r,(function(t){var e=+t;return isFinite(e)&&e>0?e:0}))},c.fillArray=function(t,e,r,n){if(n=n||c.identity,c.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},c.castOption=function(t,e,r,n){n=n||c.identity;var i=c.nestedProperty(t,r).get();return c.isArrayOrTypedArray(i)?Array.isArray(e)&&c.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},c.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=c.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},c.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=M(o));for(var s=0;s<a.length;s++){var l=a[s];if(c.isIndex(l)||c.isArrayOrTypedArray(l)&&c.isIndex(l[0])&&c.isIndex(l[1])){var u=n?n[l]:l,f=r?r[u]:u;void 0!==(i=f)&&i<t.length&&(t[f].selected=1)}}},c.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=M(r),i=[],a=0;a<e.length;a++){var o=e[a];if(c.isIndex(o)){var s=n[o];c.isIndex(s)&&i.push(s)}}return i}return e},c.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=c.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},c.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):c.isTypedArray(a)?r[i]=a.subarray(0,3):r[i]=a&&\"object\"==typeof a?c.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},c.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},c.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},c.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;c.isIE9orBelow=function(){return c.isIE()&&A.test(window.navigator.userAgent)};var S=/Version\\/[\\d\\.]+.*Safari/;c.isSafari=function(){return S.test(window.navigator.userAgent)};var E=/iPad|iPhone|iPod/;c.isIOS=function(){return E.test(window.navigator.userAgent)},c.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},c.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},c.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},c.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var C=/^([^\\[\\.]+)\\.(.+)?/,L=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;c.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(C))?(i=t[r],n=e[1],delete t[r],t[n]=c.extendDeepNoArrays(t[n]||{},c.objectFromPath(r,c.expandObjectPaths(i))[n])):(e=r.match(L))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},c.extendDeepNoArrays(o,c.objectFromPath(s,c.expandObjectPaths(i)))):t[n][a]=c.expandObjectPaths(i)):t[r]=c.expandObjectPaths(t[r]));return t},c.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},c.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)([:|\\|][^}]*)?}/g;var I=/^\\w*$/;c.templateString=function(t,e){var r={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,n){var i;return I.test(n)?i=e[n]:(r[n]=r[n]||c.nestedProperty(e,n).get,i=r[n]()),c.isValidTextValue(i)?i:\"\"}))};var P={max:10,count:0,name:\"hovertemplate\"};c.hovertemplateString=function(){return D.apply(P,arguments)};var z={max:10,count:0,name:\"texttemplate\"};c.texttemplateString=function(){return D.apply(z,arguments)};var O=/^[:|\\|]/;function D(t,e,r){var a=this,o=arguments;e||(e={});var s={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,l,u){var f,h,p,d;for(p=3;p<o.length;p++)if(f=o[p]){if(f.hasOwnProperty(l)){h=f[l];break}if(I.test(l)||(h=s[l]||c.nestedProperty(f,l).get())&&(s[l]=h),void 0!==h)break}if(void 0===h&&a)return a.count<a.max&&(c.warn(\"Variable '\"+l+\"' in \"+a.name+\" could not be found!\"),h=t),a.count===a.max&&c.warn(\"Too many \"+a.name+\" warnings - additional warnings will be suppressed\"),a.count++,t;if(u){if(\":\"===u[0]&&(h=(d=r?r.numberFormat:n.format)(u.replace(O,\"\"))(h)),\"|\"===u[0]){d=r?r.timeFormat:i;var g=c.dateTime2ms(h);h=c.formatDate(g,u.replace(O,\"\"),!1,d)}}else e.hasOwnProperty(l+\"Label\")&&(h=e[l+\"Label\"]);return h}))}c.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var R=2e9;c.seedPseudoRandom=function(){R=2e9},c.pseudoRandom=function(){var t=R;return R=(69069*R+1)%4294967296,Math.abs(R-t)<429496729?c.pseudoRandom():R/4294967296},c.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=c.extractOption(t,e,\"htx\",\"hovertext\");if(c.isValidTextValue(i))return n(i);var a=c.extractOption(t,e,\"tx\",\"text\");return c.isValidTextValue(a)?n(a):void 0},c.isValidTextValue=function(t){return t||0===t},c.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},c.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e},c.strTranslate=function(t,e){return t||e?\"translate(\"+t+\",\"+e+\")\":\"\"},c.strRotate=function(t){return t?\"rotate(\"+t+\")\":\"\"},c.strScale=function(t){return 1!==t?\"scale(\"+t+\")\":\"\"},c.getTextTransform=function(t){var e=t.noCenter,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.anchorX||0,s=t.anchorY||0,l=t.rotate,u=t.scale;return u?u>1&&(u=1):u=0,c.strTranslate(i-u*(r+o),a-u*(n+s))+c.strScale(u)+(l?\"rotate(\"+l+(e?\"\":\" \"+r+\" \"+n)+\")\":\"\")},c.ensureUniformFontSize=function(t,e){var r=c.extendFlat({},e);return r.size=Math.max(e.size,t._fullLayout.uniformtext.minsize||0),r},c.join2=function(t,e,r){var n=t.length;return n>1?t.slice(0,-1).join(e)+r+t[n-1]:t.join(e)}},{\"../constants/numerical\":753,\"./anchor_utils\":758,\"./angles\":759,\"./array\":760,\"./clean_number\":761,\"./clear_responsive\":763,\"./coerce\":764,\"./dates\":765,\"./dom\":766,\"./extend\":768,\"./filter_unique\":769,\"./filter_visible\":770,\"./geometry2d\":773,\"./identity\":776,\"./increment\":777,\"./is_plain_object\":779,\"./keyed_container\":780,\"./localize\":781,\"./loggers\":782,\"./make_trace_groups\":783,\"./matrix\":784,\"./mod\":785,\"./nested_property\":786,\"./noop\":787,\"./notifier\":788,\"./preserve_drawing_buffer\":792,\"./push_unique\":793,\"./regex\":795,\"./relative_attr\":796,\"./relink_private\":797,\"./search\":798,\"./stats\":801,\"./throttle\":804,\"./to_log_range\":805,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],779:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],780:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var f=i.test(a),h={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(f?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,f?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,h},get:function(t){if(s){var e=u[t];return void 0===e?void 0:f?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n||(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e),h},remove:function(t){var e=u[t];if(void 0===e)return h;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],h.set(t,null);if(f){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return h},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=f?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return h}},{\"./nested_property\":786}],781:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":911}],782:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=t(\"./notifier\"),a=e.exports={};function o(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}a.log=function(){var t;if(n.logging>1){var e=[\"LOG:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>1){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"long\")}},a.warn=function(){var t;if(n.logging>0){var e=[\"WARN:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}},a.error=function(){var t;if(n.logging>0){var e=[\"ERROR:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.error,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}}},{\"../plot_api/plot_config\":815,\"./notifier\":788}],783:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,(function(t){return t[0].trace.uid}));i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each((function(t){t[0][a]=n.select(this)})),i}},{d3:169}],784:[function(t,e,r){\"use strict\";var n=t(\"gl-mat4\");r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply3DTransform=function(t){return function(){var e=arguments,n=1===arguments.length?e[0]:[e[0],e[1],e[2]||0];return r.dot(t,[n[0],n[1],n[2],1]).slice(0,3)}},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}},r.convertCssMatrix=function(t){if(t){var e=t.length;if(16===e)return t;if(6===e)return[t[0],t[1],0,0,t[2],t[3],0,0,0,0,1,0,t[4],t[5],0,1]}return[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]},r.inverseTransformMatrix=function(t){var e=[];return n.invert(e,t),[[e[0],e[1],e[2],e[3]],[e[4],e[5],e[6],e[7]],[e[8],e[9],e[10],e[11]],[e[12],e[13],e[14],e[15]]]}},{\"gl-mat4\":292}],785:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],786:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;function a(t,e){return function(){var r,n,o,s,l,c=t;for(s=0;s<e.length-1;s++){if(-1===(r=e[s])){for(n=!0,o=[],l=0;l<c.length;l++)o[l]=a(c[l],e.slice(s+1))(),o[l]!==o[0]&&(n=!1);return n?o[0]:o}if(\"number\"==typeof r&&!i(c))return;if(\"object\"!=typeof(c=c[r])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[e[s]]))return o}}e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,i,o,s=0,c=e.split(\".\");s<c.length;){if(r=String(c[s]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[s]=r[1];else{if(0!==s)throw\"bad property string\";c.splice(0,1)}for(i=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<i.length;o++)s++,c.splice(s,0,Number(i[o]))}s++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:l(t,c,e),get:a(t,c),astr:e,parts:c,obj:t}};var o=/(^|\\.)args\\[/;function s(t,e){return void 0===t||null===t&&!e.match(o)}function l(t,e,r){return function(n){var a,o,l=t,h=\"\",p=[[t,h]],d=s(n,r);for(o=0;o<e.length-1;o++){if(\"number\"==typeof(a=e[o])&&!i(l))throw\"array index but container is not an array\";if(-1===a){if(d=!u(l,e.slice(o+1),n,r))break;return}if(!f(l,a,e[o+1],d))break;if(\"object\"!=typeof(l=l[a])||null===l)throw\"container is not an object\";h=c(h,a),p.push([l,h])}if(d){if(o===e.length-1&&(delete l[e[o]],Array.isArray(l)&&+e[o]==l.length-1))for(;l.length&&void 0===l[l.length-1];)l.pop()}else l[e[o]]=n}}function c(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function u(t,e,r,n){var a,o=i(r),c=!0,u=r,h=n.replace(\"-1\",0),p=!o&&s(r,h),d=e[0];for(a=0;a<t.length;a++)h=n.replace(\"-1\",a),o&&(p=s(u=r[a%r.length],h)),p&&(c=!1),f(t,a,d,p)&&l(t[a],e,n.replace(\"-1\",a))(u);return c}function f(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":760,\"fast-isnumeric\":241}],787:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],788:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each((function(t){var i=n.select(this);i.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",(function(){i.transition().call(s)}));for(var a=i.append(\"p\"),o=t.split(/<br\\s*\\/?>/g),l=0;l<o.length;l++)l&&a.append(\"br\"),a.append(\"span\").text(o[l]);\"stick\"===e?i.transition().duration(350).style(\"opacity\",1):i.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)}))}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",(function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()}))}}},{d3:169,\"fast-isnumeric\":241}],789:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":799}],790:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,f=r[0];for(e=1;e<r.length;e++)if(f[0]!==r[e][0]||f[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s)&&(!e||!l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,f,h,p,d,g=r.length,m=r[0][0],v=r[0][1],y=0;for(u=1;u<g;u++)if(f=m,h=v,m=r[u][0],v=r[u][1],!(l<(p=Math.min(f,m))||l>Math.max(f,m)||c>Math.max(h,v)))if(c<Math.min(h,v))l!==p&&y++;else{if(c===(d=m===f?c:h+(l-f)*(v-h)/(m-f)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),f=Math.sqrt(u),h=[-c[1]/f,c[0]/f];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,h))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":753,\"./matrix\":784}],791:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each((function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}n.regl||(o=!1),o&&this.addEventListener(\"webglcontextlost\",(function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})}),!1)}})),o||n({container:a._glcontainer.node()}),o}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":800,regl:540}],792:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"is-mobile\");e.exports=function(t){var e;if(\"string\"!=typeof(e=t&&t.hasOwnProperty(\"userAgent\")?t.userAgent:function(){var t;\"undefined\"!=typeof navigator&&(t=navigator.userAgent);t&&t.headers&&\"string\"==typeof t.headers[\"user-agent\"]&&(t=t.headers[\"user-agent\"]);return t}()))return!0;var r=i({ua:{headers:{\"user-agent\":e}},tablet:!0,featureDetect:!1});if(!r)for(var a=e.split(\" \"),o=1;o<a.length;o++){if(-1!==a[o].indexOf(\"Safari\"))for(var s=o-1;s>-1;s--){var l=a[s];if(\"Version/\"===l.substr(0,8)){var c=l.substr(8).split(\".\")[0];if(n(c)&&(c=+c),c>=13)return!0}}}return r}},{\"fast-isnumeric\":241,\"is-mobile\":467}],793:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],794:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":778,\"../plot_api/plot_config\":815}],795:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],796:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],797:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":760,\"./is_plain_object\":779}],798:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\"),o=t(\"../constants/numerical\").BADNUM;function s(t,e){return t<e}function l(t,e){return t<=e}function c(t,e){return t>e}function u(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,o,f=0,h=e.length,p=0,d=h>1?(e[h-1]-e[0])/(h-1):1;for(o=d>=0?r?s:l:r?u:c,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);f<h&&p++<100;)o(e[a=Math.floor((f+h)/2)],t)?f=a+1:h=a;return p>90&&i.log(\"Long binary search...\"),f-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t,e){var n,i=(e||{}).unitMinDiff,a=t.slice();for(a.sort(r.sorterAsc),n=a.length-1;n>-1&&a[n]===o;n--);var s=1;i||(s=a[n]-a[0]||1);for(var l,c=s/(n||1)/1e4,u=[],f=0;f<=n;f++){var h=a[f],p=h-l;void 0===l?(u.push(h),l=h):p>c&&(s=Math.min(s,p),u.push(h),l=h)}return{vals:u,minDiff:s}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"../constants/numerical\":753,\"./identity\":776,\"./loggers\":782,\"fast-isnumeric\":241}],799:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach((function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)})),e&&t.classed(\"cursor-\"+e,!0)}},{}],800:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":643}],801:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums((function(t){return t+1}),0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums((function(t,e){return t+e}),0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums((function(t,e){return t+Math.pow(e-i,2)}),0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":760,\"fast-isnumeric\":241}],802:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":125}],803:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=i.strTranslate,o=t(\"../constants/xmlns_namespaces\"),s=t(\"../constants/alignment\").LINE_SPACING;function l(t,e){return t.node().getBoundingClientRect()[e]}var c=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,A){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(c),L=n.select(t.node().parentNode);if(!L.empty()){var I=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return I+=\"-math\",L.selectAll(\"svg.\"+I).remove(),L.selectAll(\"g.\"+I+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise((function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),o={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue((function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})}),(function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")}),(function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(u,\"\\\\lt \").replace(f,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())}),(function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)}),(function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)}))}(C[2],o,(function(n,i,o){L.selectAll(\"svg.\"+I).remove(),L.selectAll(\"g.\"+I+\"-group\").remove();var s=n&&n.select(\"svg\");if(!s||!s.node())return P(),void e();var c=L.append(\"g\").classed(I+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});c.node().appendChild(s.node()),i&&i.node()&&s.node().insertBefore(i.node().cloneNode(!0),s.node().firstChild),s.attr({class:I,height:o.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var u=t.node().style.fill||\"black\",f=s.select(\"g\");f.attr({fill:u,stroke:u});var h=l(f,\"width\"),p=l(f,\"height\"),d=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],g=-(r||l(t,\"height\"))/4;\"y\"===I[0]?(c.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\")\"+a(-h/2,g-p/2)}),s.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===I[0]?s.attr({x:t.attr(\"x\"),y:g-p/2}):\"a\"===I[0]&&0!==I.indexOf(\"atitle\")?s.attr({x:0,y:g}):s.attr({x:d,y:+t.attr(\"y\")+g-p/2}),A&&A.call(t,c),e(c)}))}))):P(),t}function P(){L.empty()||(I=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+I).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(m,\" \");var r,a=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(o.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*s+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var a=1;a<i.length;a++)f(i[a])}function f(t){var e,i=t.type,a={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(a={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(a.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(a.style=t.style);var f=document.createElementNS(o.svg,e);if(\"sup\"===i||\"sub\"===i){A(r,\"\\u200b\"),r.appendChild(f);var h=document.createElementNS(o.svg,\"tspan\");A(h,\"\\u200b\"),n.select(h).attr(\"dy\",d[i]),a.dy=p[i],r.appendChild(f),r.appendChild(h)}else r.appendChild(f);n.select(f).attr(a),r=t.node=f,l.push(t)}function A(t,e){t.appendChild(document.createTextNode(e))}function S(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var C=e.split(v),L=0;L<C.length;L++){var I=C[L],P=I.match(y),z=P&&P[2].toLowerCase(),O=h[z];if(\"br\"===z)u();else if(void 0===O)A(r,E(I));else if(P[1])S(z);else{var D=P[4],R={type:z},F=k(D,b);if(F?(F=F.replace(M,\"$1 fill:\"),O&&(F+=\";\"+O)):O&&(F=O),F&&(R.style=F),\"a\"===z){a=!0;var B=k(D,_);if(B){var N=document.createElement(\"a\");N.href=B,-1!==g.indexOf(N.protocol)&&(R.href=encodeURI(decodeURI(B)),R.target=k(D,w)||\"_blank\",R.popup=k(D,T))}}f(R)}}return a}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),A&&A.call(t)}};var u=/(<|&lt;|&#60;)/g,f=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},p={sub:\"0.3em\",sup:\"-0.6em\"},d={sub:\"-0.21em\",sup:\"0.42em\"},g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],m=r.NEWLINES=/(\\r\\n?|\\n)/g,v=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i;r.BR_TAG_ALL=/<br(\\s+.*)?>/gi;var b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,T=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function k(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var M=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(v),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],f=u.match(y),h=f&&f[2].toLowerCase();if(h)-1!==n.indexOf(h)&&(o.push(u),s=h);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var A={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,(function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):A[e])||t}))}function C(t,e,r){var n,a,o,s=r.horizontalAlign,l=r.verticalAlign||\"top\",c=t.node().getBoundingClientRect(),u=e.node().getBoundingClientRect();return a=\"bottom\"===l?function(){return c.bottom-n.height}:\"middle\"===l?function(){return c.top+(c.height-n.height)/2}:function(){return c.top},o=\"right\"===s?function(){return c.right-n.width}:\"center\"===s?function(){return c.left+(c.width-n.width)/2}:function(){return c.left},function(){n=this.node().getBoundingClientRect();var t=o()-u.left,e=a()-u.top,s=r.gd||{};if(r.gd){s._fullLayout._calcInverseTransform(s);var l=i.apply3DTransform(s._fullLayout._invTransform)(t,e);t=l[0],e=l[1]}return this.style({top:e+\"px\",left:t+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.sanitizeHTML=function(t){t=t.replace(m,\" \");for(var e=document.createElement(\"p\"),r=e,i=[],a=t.split(v),o=0;o<a.length;o++){var s=a[o],l=s.match(y),c=l&&l[2].toLowerCase();if(c in h)if(l[1])i.length&&(r=i.pop());else{var u=l[4],f=k(u,b),p=f?{style:f}:{};if(\"a\"===c){var d=k(u,_);if(d){var x=document.createElement(\"a\");if(x.href=d,-1!==g.indexOf(x.protocol)){p.href=encodeURI(decodeURI(d));var T=k(u,w);T&&(p.target=T)}}}var M=document.createElement(c);r.appendChild(M),n.select(M).attr(p),r=M,i.push(M)}else r.appendChild(document.createTextNode(E(s)))}return e.innerHTML},r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each((function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})}))},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",(function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)})).on(\"focus\",(function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",(function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()}))})).on(\"keyup\",(function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",(function(){return!1})).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))})).on(\"keydown\",(function(){13===n.event.which&&this.blur()})).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":745,\"../constants/xmlns_namespaces\":754,\"../lib\":778,d3:169}],804:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout((function(){l(),a.timer=null}),e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise((function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}})):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],805:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":241}],806:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":858,\"topojson-client\":579}],807:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],808:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":911}],810:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function f(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=h(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function h(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=h(t.items[o],e,\"from-root\")}return a}return f(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:f}},{\"../lib\":778}],811:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,f=l.getFromTrace,h=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n,!0))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function m(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function v(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,f=(s.subplotsRegistry.ternary||{}).attrRegex,h=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var m=g[e];if(a&&a.test(m)){var v=t[m];v.anchor&&\"free\"!==v.anchor&&(v.anchor=u(v.anchor)),v.overlaying&&(v.overlaying=u(v.overlaying)),v.type||(v.isdate?v.type=\"date\":v.islog?v.type=\"log\":!1===v.isdate&&!1===v.islog&&(v.type=\"linear\")),\"withzero\"!==v.autorange&&\"tozero\"!==v.autorange||(v.autorange=!0,v.rangemode=\"tozero\"),delete v.islog,delete v.isdate,delete v.categories,y(v,\"domain\")&&delete v.domain,void 0!==v.autotick&&(void 0===v.tickmode&&(v.tickmode=v.autotick?\"auto\":\"linear\"),delete v.autotick),d(v)}else if(l&&l.test(m)){d(t[m].radialaxis)}else if(f&&f.test(m)){var x=t[m];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(h&&h.test(m)){var b=t[m],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],T=_[1],k=_[2],M=i([],w),A=[];for(n=0;n<3;++n)A[n]=T[n]+k*M[2+4*n];b.camera={eye:{x:A[0],y:A[1],z:A[2]},center:{x:T[0],y:T[1],z:T[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var I=Array.isArray(t.images)?t.images.length:0;for(e=0;e<I;e++){var P=t.images[e];o.isPlainObject(P)&&(p(P,\"xref\"),p(P,\"yref\"))}var z=t.legend;return z&&(z.x>3?(z.x=1.02,z.xanchor=\"left\"):z.x<-2&&(z.x=-.02,z.xanchor=\"right\"),z.y>3?(z.y=1.02,z.yanchor=\"bottom\"):z.y<-2&&(z.y=-.02,z.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,f=i.error_y.color||(h(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(f),c.opacity(f)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!h(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),h(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!h(i,\"pie-like\")&&!h(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=v(i.textposition[n]);else i.textposition&&(i.textposition=v(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var T=!1!==(i.increasing||{}).showlegend,k=!1!==(i.decreasing||{}).showlegend,M=g(i.increasing),A=g(i.decreasing);if(!1!==M&&!1!==A){var S=m(M,A,T,k);S&&(i.name=S)}else!M&&!A||i.name||(i.name=M||A)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,I=Object.keys(L);C.styles=[];for(var P=0;P<I.length;P++)C.styles.push({target:I[P],value:L[I[P]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map((function(t,e){return e}));if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=f(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":643,\"../lib\":778,\"../plots/cartesian/axis_ids\":831,\"../plots/plots\":891,\"../registry\":911,\"fast-isnumeric\":241,\"gl-mat4/fromQuat\":282}],812:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":913,\"./plot_api\":814,\"./template_api\":819,\"./to_image\":820,\"./validate\":821}],813:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var f=e.astr,h=s.getComponentMethod(f,\"supplyLayoutDefaults\"),p=s.getComponentMethod(f,\"draw\"),d=s.getComponentMethod(f,\"drawOne\"),g=n.replot||n.recalc||h===i||p===i,m=t.layout,v=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",f);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",f,y),!0;e.set(y)}return!g&&(h(m,v),p(t),!0)}var x,b,_,w,T,k,M,A,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(v,f).get(),I=[],P=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],T=Object.keys(w),k=w[\"\"],M=l(k),_<0||_>C.length-(M?0:1))a.warn(\"index out of range\",f,_);else if(void 0!==k)T.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",f,_),c(k)?I.push(_):M?(\"add\"===k&&(k={}),C.splice(_,0,k),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",f,_,k),-1===P&&(P=_);else for(b=0;b<T.length;b++)A=f+\"[\"+_+\"].\",u(C[_],T[b],A).set(w[T[b]]);for(x=I.length-1;x>=0;x--)C.splice(I[x],1),L&&L.splice(I[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(h(m,v),d!==i){var O;if(-1===P)O=S;else{for(z=Math.max(C.length,z),O=[],x=0;x<S.length&&!((_=S[x])>=P);x++)O.push(_);for(x=P;x<z;x++)O.push(x)}for(x=0;x<O.length;x++)d(t,O[x])}else p(t);return!0}},{\"../lib/is_plain_object\":779,\"../lib/loggers\":782,\"../lib/noop\":787,\"../lib/search\":798,\"../registry\":911,\"./container_array_match\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),f=t(\"./plot_schema\"),h=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),m=t(\"../components/color\"),v=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),T=t(\"./helpers\"),k=t(\"./subroutines\"),M=t(\"./edit_types\"),A=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0;function E(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function C(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function L(t,e){C(t,m.combine(e,\"white\"))}function I(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=L:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=C),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var f=c.scrollZoom,h=c._scrollZoom={};if(!0===f)h.cartesian=1,h.gl3d=1,h.geo=1,h.mapbox=1;else if(\"string\"==typeof f){var p=f.split(\"+\");for(i=0;i<p.length;i++)h[p[i]]=1}else!1!==f&&(h.gl3d=1,h.geo=1,h.mapbox=1)}function P(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function z(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function O(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),z(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&z(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function D(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in z(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,f,h=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=P(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);f=h?n[d][g]:n,i(f)||(f=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(f)})}return p}(t,e,r,n),c={},u={},f=0;f<l.length;f++){var h=l[f].prop,p=l[f].maxp,d=a(l[f].target,l[f].insert,p);h.set(d[0]),Array.isArray(c[h.astr])||(c[h.astr]=[]),c[h.astr].push(d[1]),Array.isArray(u[h.astr])||(u[h.astr]=[]),u[h.astr].push(l[f].target.length)}return{update:c,maxPoints:u}}function R(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function F(t,e,n,i){t=o.getGraphDiv(t),T.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=T.coerceTraceIndices(t,i),l=U(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&T.clearAxisTypes(t,s,{});var f=[];u.fullReplot?f.push(r.plot):(f.push(h.previousPromises),h.supplyDefaults(t),u.markerSize&&(h.doCalcdata(t),G(f)),u.style&&f.push(k.doTraceStyle),u.colorbars&&f.push(k.doColorBars),f.push(E)),f.push(h.rehover,h.redrag),c.add(t,F,[t,l.undoit,l.traces],F,[t,l.redoit,l.traces]);var p=o.syncOrAsync(f,t);return p&&p.then||(p=Promise.resolve()),p.then((function(){return t.emit(\"plotly_restyle\",l.eventData),t}))}function B(t){return void 0===t?null:t}function N(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){j((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function j(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)j(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},f=o.extendFlat({},c,u);for(var h in f)j(t+\".\"+h,c[h],u[h],n)}else void 0===n[t]&&(n[t]=B(e))}function U(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=N(i._preGUI,c),g=o.extendDeepAll({},e);V(e);var m,v=M.traceFlags(),y={},x={};function b(){return r.map((function(){}))}function _(t){var e=d.id2name(t);-1===m.indexOf(e)&&m.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function k(t){return\"LAYOUT\"+t+\".range\"}function A(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach((function(t){S(t,a,o)}));else if(!(n in e)&&!T.hasParent(e,n)){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=N(i._tracePreGUI[A(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=B(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(T.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var I,P,z,O,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(I=l[r[n]],P=A(r[n]),O=(z=N(i._tracePreGUI[P._fullInput.uid],c)(I,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var j=z.parts[z.parts.length-1],U=L.substr(0,L.length-j.length-1),q=U?U+\".\":\"\",H=U?s(P,U).get():P;if((R=f.getTraceValObject(P,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==j&&\"lenmode\"!==j||O===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===O)||\"funnelarea\"===D!=(\"funnelarea\"===O))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==O||\"h\"!==I.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(I,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(I,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(I,[\"?\",\"?src\"],\"values\",W),\"pie\"===O||\"funnelarea\"===O?(s(I,\"marker.color\").set(s(I,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(I,\"cartesian\")&&s(I,\"marker.colors\").set(s(I,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===j){var K=J?X.h:X.w;S(q+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var Q=J?X.w:X.h;S(q+\"len\",H.len*(\"fraction\"===D?1/Q:Q),n)}}x[L][n]=B(O);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var $=I.x&&!I.y?\"h\":\"v\";if((z.get()||$)===P.orientation)continue}else\"orientationaxes\"===L&&(I.orientation={v:\"h\",h:\"v\"}[P.orientation]);T.swapXYData(I),v.calc=v.clearAxisTypes=!0}else-1!==h.dataArrayContainers.indexOf(z.parts[0])?(T.manageArrayContainers(z,D,x),v.calc=!0):(R?R.arrayOk&&!u.traceIs(P,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(O))?v.calc=!0:M.update(v,R):v.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\"),et=tt.get();\"x\"===et?tt.set(\"y\"):\"y\"===et?tt.set(\"x\"):\"x unified\"===et?tt.set(\"y unified\"):\"y unified\"===et&&tt.set(\"x unified\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(m=[],n=0;n<r.length;n++){var rt=l[r[n]];u.traceIs(rt,\"cartesian\")&&(_(rt.xaxis||\"x\"),_(rt.yaxis||\"y\"))}S(m.map(w),!0,0),S(m.map(k),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[B(z.get())],z.set(Array.isArray(F)?F[0]:F),v.calc=!0}return(v.calc||v.plot)&&(v.fullReplot=!0),{flags:v,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function V(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function q(t,e,r){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=Z(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[h.previousPromises];a.layoutReplot?s.push(k.layoutReplot):Object.keys(n).length&&(H(t,a,i)||h.supplyDefaults(t),a.legend&&s.push(k.doLegend),a.layoutstyle&&s.push(k.layoutStyles),a.axrange&&G(s,i.rangesAltered),a.ticks&&s.push(k.doTicksRelayout),a.modebar&&s.push(k.doModeBar),a.camera&&s.push(k.doCamera),a.colorbars&&s.push(k.doColorBars),s.push(E)),s.push(h.rehover,h.redrag),c.add(t,q,[t,i.undoit],q,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then((function(){return t.emit(\"plotly_relayout\",i.eventData),t}))}function H(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,s.range&&(l.range=s.range.slice()),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function G(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),-1!==(a.ticklabelposition||\"\").indexOf(\"inside\")&&a._anchorAxis&&r.push(a._anchorAxis._id),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,k.doAutoRangeAndConstraints,r,k.drawData,k.finalDraw)}var Y=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,W=/^[xyz]axis[0-9]*\\.autorange$/,X=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function Z(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,h=N(l._preGUI,c),p=Object.keys(e),g=d.list(t),m=o.extendDeepAll({},e),v={};for(V(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=M.layoutFlags(),k={},S={};function E(t,r){if(Array.isArray(t))t.forEach((function(t){E(t,r)}));else if(!(t in e)&&!T.hasParent(e,t)){var n=h(a,t);t in S||(S[t]=B(n.get())),void 0!==r&&n.set(r)}}var C,L={};function I(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var P in e){if(T.hasParent(e,P))throw new Error(\"cannot set \"+P+\" and a parent attribute simultaneously\");for(var z=h(a,P),O=e[P],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,j=z.parts.slice(0,D).join(\".\"),U=s(t.layout,j).get(),q=s(l,j).get(),H=z.get();if(void 0!==O){k[P]=O,S[P]=\"reverse\"===R?O:B(H);var G=f.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==O)for(var Z in G.impliedEdits)E(o.relativeAttr(P,Z),G.impliedEdits[Z]);if(-1!==[\"width\",\"height\"].indexOf(P))if(O){E(\"autosize\",null);var K=\"height\"===P?\"width\":\"height\";E(K,l[K])}else l[P]=t._initialAutoSize[P];else if(\"autosize\"===P)E(\"width\",O?null:l.width),E(\"height\",O?null:l.height);else if(F.match(Y))I(F),s(l,j+\"._inputRange\").set(null);else if(F.match(W)){I(F),s(l,j+\"._inputRange\").set(null);var Q=s(l,j).get();Q._inputDomain&&(Q._input.domain=Q._inputDomain.slice())}else F.match(X)&&s(l,j+\"._inputDomain\").set(null);if(\"type\"===R){C=U;var $=\"linear\"===q.type&&\"log\"===O,tt=\"log\"===q.type&&\"linear\"===O;if($||tt){if(C&&C.range)if(q.autorange)$&&(C.range=C.range[1]>C.range[0]?[1,2]:[2,1]);else{var et=C.range[0],rt=C.range[1];$?(et<=0&&rt<=0&&E(j+\".autorange\",!0),et<=0?et=rt/1e6:rt<=0&&(rt=et/1e6),E(j+\".range[0]\",Math.log(et)/Math.LN10),E(j+\".range[1]\",Math.log(rt)/Math.LN10)):(E(j+\".range[0]\",Math.pow(10,et)),E(j+\".range[1]\",Math.pow(10,rt)))}else E(j+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,q,O,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,q,O,E)}else E(j+\".autorange\",!0),E(j+\".range\",null);s(l,j+\"._inputRange\").set(null)}else if(R.match(A)){var nt=s(l,P).get(),it=(O||{}).type;it&&\"-\"!==it||(it=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,nt,it,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,nt,it,E)}var at=w.containerArrayMatch(P);if(at){r=at.array,n=at.index;var ot=at.property,st=G||{editType:\"calc\"};\"\"!==n&&\"\"===ot&&(w.isAddVal(O)?S[P]=null:w.isRemoveVal(O)?S[P]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),M.update(_,st),v[r]||(v[r]={});var lt=v[r][n];lt||(lt=v[r][n]={}),lt[ot]=O,delete e[P]}else\"reverse\"===R?(U.range?U.range.reverse():(E(j+\".autorange\",!0),U.range=[1,0]),q.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===P&&(\"lasso\"===O||\"select\"===O)&&\"lasso\"!==H&&\"select\"!==H||l._has(\"gl2d\")?_.plot=!0:G?M.update(_,G):_.calc=!0,z.set(O))}}for(r in v){w.applyContainerArrayChanges(t,h(a,r),v[r],_,h)||(_.plot=!0)}for(var ct in L){var ut=(C=d.getFromId(t,ct))&&C._constraintGroup;if(ut)for(var ft in _.calc=!0,ut)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(J(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:k,eventData:m}}function J(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&h.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function K(t,e,n,i){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=T.coerceTraceIndices(t,i),s=U(t,o.extendFlat({},e),a),l=s.flags,u=Z(t,o.extendFlat({},n)),f=u.flags;(l.calc||f.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&T.clearAxisTypes(t,a,n);var p=[];f.layoutReplot?p.push(k.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(h.previousPromises),H(t,f,u)||h.supplyDefaults(t),l.style&&p.push(k.doTraceStyle),(l.colorbars||f.colorbars)&&p.push(k.doColorBars),f.legend&&p.push(k.doLegend),f.layoutstyle&&p.push(k.layoutStyles),f.axrange&&G(p,u.rangesAltered),f.ticks&&p.push(k.doTicksRelayout),f.modebar&&p.push(k.doModeBar),f.camera&&p.push(k.doCamera),p.push(E)),p.push(h.rehover,h.redrag),c.add(t,K,[t,s.undoit,u.undoit,s.traces],K,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then((function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t}))}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var $=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center|fitbounds)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],tt=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function et(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function rt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function nt(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function it(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function at(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function ot(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,f=n.immutable,h=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;h&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[h],p):(M.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(Y.test(l)||W.test(l))&&(u.rangesAltered[r[0]]=1),X.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var m=t[a],v=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof m&&m!==v){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(m)!==JSON.stringify(v))){var b,_=i.valType,w=g(i),T=Array.isArray(m),k=Array.isArray(v);if(T&&k){var A=\"_input_\"+a,S=t[A],E=e[A];if(Array.isArray(S)&&S===E)continue}if(void 0===v)w&&T?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;h||(u.arrays[a]=C);var I=Math.min(m.length,v.length),P=Math.max(m.length,v.length);if(I!==P){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<I;b++)ot(m[b],v[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=I;b<P;b++)C.push(b)}else!_&&o.isPlainObject(m)?ot(m,v,y,n):w?T&&k?(f&&(u.calc=!0),(f||n.newDataRevision)&&d()):T!==k?u.calc=!0:d():T&&k&&m.length===v.length&&String(m)===String(v)||d()}}}for(a in e)if(!(a in t)&&\"_\"!==a.charAt(0)&&\"function\"!=typeof e[a]){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function st(t){var e=t._fullLayout,r=t.getBoundingClientRect();if(!o.equalDomRects(r,e._lastBBox)){var n=e._invTransform=o.inverseTransformMatrix(o.getFullTransformMatrix(t));e._invScaleX=Math.sqrt(n[0][0]*n[0][0]+n[0][1]*n[0][1]+n[0][2]*n[0][2]),e._invScaleY=Math.sqrt(n[1][0]*n[1][0]+n[1][1]*n[1][1]+n[1][2]*n[1][2]),e._lastBBox=r}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._calcInverseTransform=st,r._calcInverseTransform(t),r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"user-select-none\",!0).classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),delete r._modeBar,r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each((function(){this.id&&(i[this.id.split(\"-\")[1]]=1)})),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._treemaplayer=r._paper.append(\"g\").classed(\"treemaplayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plotly.com/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=h.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise((function(a,u){function f(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,h.transition(t,e.frame.data,e.frame.layout,T.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then((function(){e.onComplete&&e.onComplete()})),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&f()};e()}var d,g,m=0;function v(t){return Array.isArray(i)?m>=i.length?t.transitionOpts=i[m]:t.transitionOpts=i[0]:t.transitionOpts=i,m++,t}var y=[],x=null==e,b=Array.isArray(e);if(!x&&!b&&o.isPlainObject(e))y.push({type:\"object\",data:v(o.extendFlat({},e))});else if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:v({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:v({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:v(o.extendFlat({},_))})}for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var k=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){k=d;break}if(k>0&&k<y.length-1){var M=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>k)&&M.push(g);y=M}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?h.computeFrame(t,e[i].name):e[i].data;var f=l(i),d=s(i);d.duration=Math.min(d.duration,f.duration);var g={frame:o,name:e[i].name,frameOpts:f,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())}))},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plotly.com/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var f=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,m=(u[g]||d[g]||{}).name,v=e[n].name,y=u[m]||d[m];m&&v&&\"number\"==typeof v&&y&&S<5&&(S++,o.warn('addFrames: overwriting frame \"'+(u[m]||d[m]).name+'\" with a frame whose name of type \"number\" also equates to \"'+m+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),5===S&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:h.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:f+n})}p.sort((function(t,e){return t.index>e.index?-1:t.index<e.index?1:0}));var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=h.modifyFrames,T=h.modifyFrames,k=[t,b],M=[t,x];return c&&c.add(t,w,k,T,M),h.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=h.modifyFrames,u=h.modifyFrames,f=[t,s],p=[t,a];return c&&c.add(t,l,f,u,p),h.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,f=t,h=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map((function(t){return o.extendFlat({},t)})),T.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,h,f,p),s;Array.isArray(i)||(i=[i]);try{O(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,h,f,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,f=[e,s,n],h=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),z(e,n,\"indices\"),(n=P(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,f,u,h),p},r.extendTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=R(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}var l=D(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.prependTraces,f,t,arguments),u},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,f=t,h=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(O(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=P(n,e.data.length-1),i=P(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort((function(t,e){return t.newIndex-e.newIndex})),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,h,f,p),d},r.prependTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=R(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}var l=D(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.extendTraces,f,t,arguments),u},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),h.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),h.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),I(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var f=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(T.cleanData(e),f?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!f||(t.layout=T.cleanLayout(i)),h.supplyDefaults(t);var m=t._fullLayout,y=m._has(\"cartesian\");if(!m._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e);r&&(t.layout=r);p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},f=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,f.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(100).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)})));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",(function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)})).on(\"cancel\",(function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)}))};f.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),h.addLinks(t),Promise.resolve()}(t,e,i);m._replotting=!0,(f||m._shouldCreateBgLayer)&&(lt(t),m._shouldCreateBgLayer&&delete m._shouldCreateBgLayer),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),f&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&h.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||h.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},m._size),M=0;function A(){if(h.clearAutoMarginIds(t),k.drawMarginPushers(t),d.allowAutoMargin(t),m._has(\"pie\"))for(var e=t._fullData,r=0;r<e.length;r++){var n=e[r];\"pie\"===n.type&&n.automargin&&h.allowAutoMargin(t,\"pie.\"+n.uid+\".automargin\")}return h.doAutoMargin(t),h.previousPromises(t)}function S(){t._transitioning||(k.doAutoRangeAndConstraints(t),f&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var C=[h.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=m._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!m._glcanvas&&m._has(\"gl\")&&(m._glcanvas=m._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],(function(t){return t.key})),m._glcanvas.enter().append(\"canvas\").attr(\"class\",(function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")})).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),m._glcanvas){m._glcanvas.attr(\"width\",m.width).attr(\"height\",m.height);var i=m._glcanvas.data()[0].regl;if(i&&(Math.floor(m.width)!==i._gl.drawingBufferWidth||Math.floor(m.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!M)return o.log(a+\" Clearing graph and plotting again.\"),h.cleanPlot([],{},t._fullData,m),h.supplyDefaults(t),m=t._fullLayout,h.doCalcdata(t),M++,e();o.error(a)}}return\"h\"===m.modebar.orientation?m._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):m._modebardiv.style(\"width\",null).style(\"height\",m.height+\"px\"),h.previousPromises(t)},A,function(){if(h.didMarginChange(w,m._size))return o.syncOrAsync([A,k.layoutStyles],t)}];y&&C.push((function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()})),C.push(k.layoutStyles),y&&C.push((function(){return d.draw(t,f?\"\":\"redraw\")}),(function(t){t._fullLayout._insideTickLabelsAutorange&&q(t,t._fullLayout._insideTickLabelsAutorange).then((function(){t._fullLayout._insideTickLabelsAutorange=void 0}))})),C.push(k.drawData,k.finalDraw,v,h.addLinks,h.rehover,h.redrag,h.doAutoMargin,(function(t){t._fullLayout._insideTickLabelsAutorange&&f&&d.saveRangeInitial(t,!0)}),h.previousPromises);var L=o.syncOrAsync(C,t);return L&&L.then||(L=Promise.resolve()),L.then((function(){return E(t),t}))},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return h.cleanPlot([],{},r,e),h.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l;t=o.getGraphDiv(t),T.clearPromiseQueue(t);var c=t._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var m=o.extendDeep({},t._context);t._context=void 0,I(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(m,t._context)}t.data=e||[],T.cleanData(t.data),t.layout=n||{},T.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,f,h,p,d=n._preGUI,g=[],m={};for(i in d){if(u=et(i,$)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&rt(a,e))&&c===l&&(null===(f=d[i])&&(f=void 0),at(p=(h=s(e,i)).get(),f))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),h.set(B(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(m[i.substr(0,i.length-9)]=1)}for(var v=0;v<g.length;v++){var y=g[v];if(m[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,T=b[_],k=null;for(i in T){if(!k){var M=nt(_,r);if(M<0){delete b[_];break}var A=it(_,t,(w=r[M]._fullInput).index);if(A<0){delete b[_];break}k=t[A]}if(u=et(i,tt)){if(u.attr?c=(l=s(n,u.attr).get())&&rt(u.attr,e):(l=w.uirevision,void 0===(c=k.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(f=T[i])&&(f=void 0),at(p=(h=s(k,i)).get(),f))){h.set(B(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete T[i]}}}(t.data,t.layout,c,p),h.supplyDefaults(t,{skipUpdateCalc:!0});var v=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=M.layoutFlags();function o(t){return f.getLayoutValObject(r,t)}a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,ot(e,r,[],{getValObject:o,flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0);i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\");return a}(t,p,y,x,b),w=_.newDataRevision,A=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=M.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=f.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,h.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,ot(e[s]._fullInput,l,[],u)}(c.calc||c.plot)&&(c.fullReplot=!0);i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\");return c}(t,c,v,x,b,w);if(J(t)&&(_.layoutReplot=!0),A.calc||_.calc){t.calcdata=void 0;for(var S=Object.getOwnPropertyNames(y),C=0;C<S.length;C++){var L=S[C],P=L.substring(0,5);if(\"xaxis\"===P||\"yaxis\"===P){var z=y[L]._emptyCategories;z&&z()}}}else h.supplyDefaultsUpdateCalc(t.calcdata,v);var O=[];if(a&&(t._transitionData={},h.createTransitionData(t),O.push((function(){return r.addFrames(t,a)}))),y.transition&&!g&&(A.anim||_.anim))_.ticks&&O.push(k.doTicksRelayout),h.doCalcdata(t),k.doAutoRangeAndConstraints(t),O.push((function(){return h.transitionFromReact(t,A,_,p)}));else if(A.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,O.push(r.plot);else{for(var D in _.arrays){var R=_.arrays[D];if(R.length){var F=u.getComponentMethod(D,\"drawOne\");if(F!==o.noop)for(var N=0;N<R.length;N++)F(t,R[N]);else{var j=u.getComponentMethod(D,\"draw\");if(j===o.noop)throw new Error(\"cannot draw components: \"+D);j(t)}}}O.push(h.previousPromises),A.style&&O.push(k.doTraceStyle),(A.colorbars||_.colorbars)&&O.push(k.doColorBars),_.legend&&O.push(k.doLegend),_.layoutstyle&&O.push(k.layoutStyles),_.axrange&&G(O),_.ticks&&O.push(k.doTicksRelayout),_.modebar&&O.push(k.doModeBar),_.camera&&O.push(k.doCamera),O.push(E)}O.push(h.rehover,h.redrag),(l=o.syncOrAsync(O,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then((function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t}))},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return T.cleanData(t.data),T.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then((function(){return t.emit(\"plotly_redraw\"),t}))},r.relayout=q,r.restyle=F,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=K,r._guiRelayout=Q(q),r._guiRestyle=Q(F),r._guiUpdate=Q(K),r._storeDirectGUIEdit=function(t,e,r){for(var n in r){j(n,s(t,n).get(),r[n],e)}}},{\"../components/color\":643,\"../components/drawing\":665,\"../constants/xmlns_namespaces\":754,\"../lib\":778,\"../lib/events\":767,\"../lib/queue\":794,\"../lib/svg_text_utils\":803,\"../plots/cartesian/axes\":828,\"../plots/cartesian/constants\":834,\"../plots/cartesian/graph_interact\":837,\"../plots/cartesian/select\":847,\"../plots/plots\":891,\"../plots/polar/legacy\":899,\"../registry\":911,\"./edit_types\":810,\"./helpers\":811,\"./manage_arrays\":813,\"./plot_config\":815,\"./plot_schema\":816,\"./subroutines\":818,d3:169,\"fast-isnumeric\":241,\"has-hover\":440}],815:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"integer\",min:0,max:2,dflt:1},notifyOnLogging:{valType:\"integer\",min:0,max:2,dflt:0},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],816:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),f=t(\"../plots/polar/legacy/axis_attributes\"),h=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,m=i.isArrayOrTypedArray,v=i.nestedProperty,y=i.valObjectMeta,x=[\"_isSubplotObj\",\"_isLinkedToArray\",\"_arrayAttrRegexps\",\"_deprecated\"];function b(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(_(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!_(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!_(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!_(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function _(t){return t===Math.round(t)&&t>=0}function w(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry){if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)M(r,e,e.attr[i]);else M(r,e,\"subplot\"===e.attr?e.name:e.attr)}for(t in r=function(t){return p(t,{radialaxis:f.radialaxis,angularaxis:f.angularaxis}),p(t,f.layout),t}(r),n.componentsRegistry){var a=(e=n.componentsRegistry[t]).schema;if(a&&(a.subplots||a.layout)){var s=a.subplots;if(s&&s.xaxis&&!s.yaxis)for(var l in s.xaxis)delete r.yaxis[l]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&A(r,e.layoutAttributes,e.name)}return{layoutAttributes:k(r)}}function T(){var t={frames:d({},s)};return k(t),t.frames}function k(t){return function(t){r.crawl(t,(function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")}))}(t),function(t){r.crawl(t,(function(t,e,r){if(t){var n=t._isLinkedToArray;n&&(delete t._isLinkedToArray,r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\")}}))}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function M(t,e,r){var n=v(t,r),i=d({},e.layoutAttributes);i._isSubplotObj=!0,n.set(i)}function A(t,e,r){var n=v(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=\"_isSubplotObj\",r.IS_LINKED_TO_ARRAY=\"_isLinkedToArray\",r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=x,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach((function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,(function(t,e,r,n,i){v(s,i).set(void 0),void 0===t&&v(l,i).set(void 0)})),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:k(o)};if(e.layoutAttributes){var f={};d(f,e.layoutAttributes),c.layoutAttributes=k(f)}e.animatable||r.crawl(c,(function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim}));return c}(e)}));var e={};return Object.keys(n.transformsRegistry).forEach((function(t){e[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach((function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach((function(e){A(r,i.schema.transforms[t][e],e)}))})),{attributes:k(r)}}(t)})),{defs:{valObjects:y,metaKeys:x.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:h.traces,layout:h.layout},impliedEdits:{}},traces:t,layout:w(),transforms:e,frames:T(),animation:k(l),config:k(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach((function(n){var o=t[n];if(-1===x.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}}))},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]],c=a+o[r];if(r===o.length-1)m(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var f=c[u],h=f._module;h&&(n=\"transforms[\"+u+\"].\",e=f,r.crawl(h.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!_(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var f=t._module;if(f||(f=(n.modules[t.type||a.type.dflt]||{})._module),!f)return!1;if(!(i=(r=f.attributes)&&r[o])){var h=f.basePlotModule;h&&h.attributes&&(i=h.attributes[o])}i||(i=a[o])}return b(i,e,s)},r.getLayoutValObject=function(t,e){return b(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var h=t._modules;if(h)for(r=0;r<h.length;r++)if((s=h[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return f[e];return f.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":778,\"../plots/animation_attributes\":822,\"../plots/attributes\":824,\"../plots/frame_attributes\":857,\"../plots/layout_attributes\":882,\"../plots/polar/legacy/area_attributes\":897,\"../plots/polar/legacy/axis_attributes\":898,\"../registry\":911,\"./edit_types\":810,\"./plot_config\":815}],817:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a={name:{valType:\"string\",editType:\"none\"}};function o(t){return t&&\"string\"==typeof t}function s(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}a.templateitemname={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=a.name,e.templateitemname=a.templateitemname,e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[s(e)],a=n&&n[e];Array.isArray(a)&&a.length||(a=[]);var l={};return{newItem:function(t){var e={name:t.name,_input:t},n=e.templateitemname=t.templateitemname;if(!o(n))return e._template=i,e;for(var s=0;s<a.length;s++){var c=a[s];if(c.name===n)return l[n]=1,e._template=c,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<a.length;e++){var r=a[e],n=r.name;if(o(n)&&!l[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i.templateitemname=r.templateitemname,t.push(i),l[n]=1}}return t}}},r.arrayDefaultKey=s,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,a=r._index,o=a>=i&&(r._input||{})._templateitemname;o&&(a=i);var s,l=e+\"[\"+a+\"]\";function c(){s={},o&&(s[l]={},s[l].templateitemname=o)}function u(t,e){o?n.nestedProperty(s[l],t).set(e):s[l+\".\"+t]=e}function f(){var t=s;return c(),t}return c(),{modifyBase:function(t,e){s[t]=e},modifyItem:u,getUpdateObj:f,applyUpdate:function(e,r){e&&u(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":778,\"../plots/attributes\":824}],818:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),f=t(\"../components/modebar\"),h=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,m=d.clean,v=t(\"../plots/cartesian/autorange\").doAutoRange;function y(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function x(t){var e,i,s,u,d,g,m=t._fullLayout,v=m._size,x=v.p,_=h.list(t,\"\",!0);if(m._paperdiv.style({width:t._context.responsive&&m.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":m.width+\"px\",height:t._context.responsive&&m.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":m.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,m.width,m.height),t._context.setBackground(t,m.paper_bgcolor),r.drawMainTitle(t),f.manage(t),!m._has(\"cartesian\"))return a.previousPromises(t);function T(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-x-n:e._offset+e._length+x+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+x+n:e._offset-x-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<_.length;e++){var k=(u=_[e])._anchorAxis;u._linepositions={},u._lw=c.crispRound(t,u.linewidth,1),u._mainLinePosition=T(u,k,u.side),u._mainMirrorPosition=u.mirror&&k?T(u,k,p.OPPOSITE_SIDE[u.side]):null}var M=[],A=[],S=[],E=1===l.opacity(m.paper_bgcolor)&&1===l.opacity(m.plot_bgcolor)&&m.paper_bgcolor===m.plot_bgcolor;for(i in m._plots)if((s=m._plots[i]).mainplot)s.bg&&s.bg.remove(),s.bg=void 0;else{var C=s.xaxis.domain,L=s.yaxis.domain,I=s.plotgroup;if(y(C,L,S)){var P=I.node(),z=s.bg=o.ensureSingle(I,\"rect\",\"bg\");P.insertBefore(z.node(),P.childNodes[0]),A.push(i)}else I.select(\"rect.bg\").remove(),S.push([C,L]),E||(M.push(i),A.push(i))}var O,D,R,F,B,N,j,U,V,q,H,G,Y,W=m._bgLayer.selectAll(\".bg\").data(M);for(W.enter().append(\"rect\").classed(\"bg\",!0),W.exit().remove(),W.each((function(t){m._plots[t].bg=n.select(this)})),e=0;e<A.length;e++)s=m._plots[A[e]],d=s.xaxis,g=s.yaxis,s.bg&&void 0!==d._offset&&void 0!==g._offset&&s.bg.call(c.setRect,d._offset-x,g._offset-x,d._length+2*x,g._length+2*x).call(l.fill,m.plot_bgcolor).style(\"stroke-width\",0);if(!m._hasOnlyLargeSploms)for(i in m._plots){s=m._plots[i],d=s.xaxis,g=s.yaxis;var X,Z,J=s.clipId=\"clip\"+m._uid+i+\"plot\",K=o.ensureSingleById(m._clips,\"clipPath\",J,(function(t){t.classed(\"plotclip\",!0).append(\"rect\")}));s.clipRect=K.select(\"rect\").attr({width:d._length,height:g._length}),c.setTranslate(s.plot,d._offset,g._offset),s._hasClipOnAxisFalse?(X=null,Z=J):(X=J,Z=null),c.setClipUrl(s.plot,X,t),s.layerClipId=Z}function Q(t){return\"M\"+O+\",\"+t+\"H\"+D}function $(t){return\"M\"+d._offset+\",\"+t+\"h\"+d._length}function tt(t){return\"M\"+t+\",\"+U+\"V\"+j}function et(t){return\"M\"+t+\",\"+g._offset+\"v\"+g._length}function rt(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in m._plots){s=m._plots[i],d=s.xaxis,g=s.yaxis;var nt=\"M0,0\";b(d,i)&&(B=w(d,\"left\",g,_),O=d._offset-(B?x+B:0),N=w(d,\"right\",g,_),D=d._offset+d._length+(N?x+N:0),R=T(d,g,\"bottom\"),F=T(d,g,\"top\"),!(Y=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[R,F]),nt=rt(d,Q,$),Y&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(R)+Q(F)),s.xlines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),s.xlines.attr(\"d\",nt);var it=\"M0,0\";b(g,i)&&(H=w(g,\"bottom\",d,_),j=g._offset+g._length+(H?x:0),G=w(g,\"top\",d,_),U=g._offset-(G?x:0),V=T(g,d,\"left\"),q=T(g,d,\"right\"),!(Y=!g._anchorAxis||i!==g._mainSubplot)||\"allticks\"!==g.mirror&&\"all\"!==g.mirror||(g._linepositions[i]=[V,q]),it=rt(g,tt,et),Y&&g.showline&&(\"all\"===g.mirror||\"allticks\"===g.mirror)&&(it+=tt(V)+tt(q)),s.ylines.style(\"stroke-width\",g._lw+\"px\").call(l.stroke,g.showline?g.linecolor:\"rgba(0,0,0,0)\")),s.ylines.attr(\"d\",it)}return h.makeClipPaths(t),a.previousPromises(t)}function b(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function _(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function w(t,e,r,n){if(_(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&_(t,e,a))return a._lw}return 0}function T(t,e){var r=t.title,n=t._size,i=0;switch(\"start\"===e?i=r.pad.l:\"end\"===e&&(i=-r.pad.r),r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}function k(t,e){var r=t.title,n=t._size,i=0;if(\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b,\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,x],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=\"middle\";o.isRightAnchor(e)?r=\"end\":o.isLeftAnchor(e)&&(r=\"start\");return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:T(e,r),y:k(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},f=u._module||{},h=f.arraysToCalcdata;h&&h(l,u);var p=f.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return h.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;f.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]];i._scene.setViewport(i)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r=h.list(t,\"\",!0),n={},i=0;i<r.length;i++)if(!n[(e=r[i])._id]){n[e._id]=1,m(t,e),v(t,e);var a=e._matchGroup;if(a)for(var o in a){var s=h.getFromId(t,o);v(t,s,e.range),n[o]=1}}g(t)},r.finalDraw=function(t){i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":643,\"../components/drawing\":665,\"../components/modebar\":703,\"../components/titles\":738,\"../constants/alignment\":745,\"../lib\":778,\"../lib/clear_gl_canvases\":762,\"../plots/cartesian/autorange\":827,\"../plots/cartesian/axes\":828,\"../plots/cartesian/constraints\":835,\"../plots/plots\":891,\"../registry\":911,d3:169}],819:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var f=o.defaultItems();for(a=0;a<f.length;a++)r.push(f[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],h=t[c];if(c in e?s(h,e[c],c):e[c]=h,f(c)===c)for(var p in e){var d=f(p);p===d||d!==c||p in t||s(h,e[p],c)}}}function f(t){return t.replace(/[0-9]+$/,\"\")}function h(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],p=g(t,c,a),d=g(t,c,o),m=r(d);if(!m){var v=f(c);v!==c&&(m=r(d=g(t,v,o)))}if((!s||s!==m)&&!(!m||m._noTemplating||\"data_array\"===m.valType||m.arrayOk&&Array.isArray(u)))if(!m.valType&&i(u))h(u,e,r,p,d);else if(m._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var T=w.name;if(T)b[T]||(h(w,e,r,g(u,x,p),g(u,x,d)),x++,b[T]=1);else if(!y){var k=g(t,l.arrayDefaultKey(c),a),M=g(u,x,p);h(w,e,r,M,g(u,x,d));var A=n.nestedProperty(e,M);n.nestedProperty(e,k).set(A.get()),A.set(null),y=!0}}}else{n.nestedProperty(e,p).set(u)}}}function p(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}function d(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}function g(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function m(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function v(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var a={data:{},layout:{}};e.forEach((function(t){var e={};h(t,e,d.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=a.data[r];i||(i=a.data[r]=[]),i.push(e)})),h(r,a.layout,p.bind(null,r)),delete a.layout.template;var l=r.template;if(i(l)){var f,g,m,v,y,x,b=l.layout;i(b)&&u(b,a.layout);var _=l.data;if(i(_)){for(g in a.data)if(m=_[g],Array.isArray(m)){for(x=(y=a.data[g]).length,v=m.length,f=0;f<x;f++)u(m[f%v],y[f]);for(f=x;f<v;f++)y.push(n.extendDeep({},m[f]))}for(g in _)g in a.data||(a.data[g]=n.extendDeep([],_[g]))}}return a},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var h=r._fullLayout,p=r._fullData,d={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=f(n),s=[];for(a=0;a<r.length;a++)s.push(g(e,n,r[a])),o!==n&&s.push(g(e,o,r[a]));for(a=0;a<s.length;a++)d[s[a]]=1;t(e[n],s)}}(h,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=g(e,n,r);d[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<p.length;b++){var _=p[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,T=x[y]||0;w>T?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:T}):T>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:T})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=g(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&m(a)&&t(a,o)}}({data:p,layout:h},\"\"),u.length)return u.map(v)}},{\"../lib\":778,\"../plots/attributes\":824,\"../plots/plots\":891,\"./plot_config\":815,\"./plot_schema\":816,\"./plot_template\":817}],820:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../snapshot/helpers\"),l=t(\"../snapshot/tosvg\"),c=t(\"../snapshot/svgtoimg\"),u=t(\"../version\").version,f={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\",\"full-json\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,h,p,d;function g(t){return!(t in e)||o.validate(e[t],f[t])}if(e=e||{},o.isPlainObject(t)?(r=t.data||[],h=t.layout||{},p=t.config||{},d={}):(t=o.getGraphDiv(t),r=o.extendDeep([],t.data),h=o.extendDeep({},t.layout),p=t._context,d=t._fullLayout||{}),!g(\"width\")&&null!==e.width||!g(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!g(\"format\"))throw new Error(\"Export format is not \"+o.join2(f.format.values,\", \",\" or \")+\".\");var m={};function v(t,r){return o.coerce(e,m,f,t,r)}var y=v(\"format\"),x=v(\"width\"),b=v(\"height\"),_=v(\"scale\"),w=v(\"setBackground\"),T=v(\"imageDataOnly\"),k=document.createElement(\"div\");k.style.position=\"absolute\",k.style.left=\"-5000px\",document.body.appendChild(k);var M=o.extendFlat({},h);x?M.width=x:null===e.width&&n(d.width)&&(M.width=d.width),b?M.height=b:null===e.height&&n(d.height)&&(M.height=d.height);var A=o.extendFlat({},p,{_exportedPlot:!0,staticPlot:!0,setBackground:w}),S=s.getRedrawFunc(k);function E(){return new Promise((function(t){setTimeout(t,s.getDelay(k._fullLayout))}))}function C(){return new Promise((function(t,e){var r=l(k,y,_),n=k._fullLayout.width,f=k._fullLayout.height;function h(){i.purge(k),document.body.removeChild(k)}if(\"full-json\"===y){var p=a.graphJson(k,!1,\"keepdata\",\"object\",!0,!0);return p.version=u,p=JSON.stringify(p),h(),t(T?p:s.encodeJSON(p))}if(h(),\"svg\"===y)return t(T?r:s.encodeSVG(r));var d=document.createElement(\"canvas\");d.id=o.randstr(),c({format:y,width:n,height:f,scale:_,canvas:d,svg:r,promise:!0}).then(t).catch(e)}))}return new Promise((function(t,e){i.plot(k,r,M,A).then(S).then(E).then(C).then((function(e){t(function(t){return T?t.replace(s.IMAGE_URL_PREFIX,\"\"):t}(e))})).catch((function(t){e(t)}))}))}},{\"../lib\":778,\"../plots/plots\":891,\"../snapshot/helpers\":915,\"../snapshot/svgtoimg\":917,\"../snapshot/tosvg\":919,\"../version\":1370,\"./plot_api\":814,\"fast-isnumeric\":241}],821:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var f=Object.keys(t),h=0;h<f.length;h++){var p=f[h];if(\"transforms\"!==p){var v=o.slice();v.push(p);var y=t[p],x=e[p],b=m(r,p),_=(b||{}).valType,w=\"info_array\"===_,T=\"colorscale\"===_,k=(b||{}).items;if(g(r,p))if(s(y)&&s(x)&&\"any\"!==_)u(y,x,b,i,a,v);else if(w&&l(y)){y.length>x.length&&i.push(d(\"unused\",a,v.concat(x.length)));var M,A,S,E,C,L=x.length,I=Array.isArray(k);if(I&&(L=Math.min(L,k.length)),2===b.dimensions)for(A=0;A<L;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(d(\"unused\",a,v.concat(A,x[A].length)));var P=x[A].length;for(M=0;M<(I?Math.min(P,k[A].length):P);M++)S=I?k[A][M]:k,E=y[A][M],C=x[A][M],n.validate(E,S)?C!==E&&C!==+E&&i.push(d(\"dynamic\",a,v.concat(A,M),E,C)):i.push(d(\"value\",a,v.concat(A,M),E))}else i.push(d(\"array\",a,v.concat(A),y[A]));else for(A=0;A<L;A++)S=I?k[A]:k,E=y[A],C=x[A],n.validate(E,S)?C!==E&&C!==+E&&i.push(d(\"dynamic\",a,v.concat(A),E,C)):i.push(d(\"value\",a,v.concat(A),E))}else if(b.items&&!w&&l(y)){var z,O,D=k[Object.keys(k)[0]],R=[];for(z=0;z<x.length;z++){var F=x[z]._index||z;if((O=v.slice()).push(F),s(y[F])&&s(x[z])){R.push(F);var B=y[F],N=x[z];s(B)&&!1!==B.visible&&!1===N.visible?i.push(d(\"invisible\",a,O)):u(B,N,D,i,a,O)}}for(z=0;z<y.length;z++)(O=v.slice()).push(z),s(y[z])?-1===R.indexOf(z)&&i.push(d(\"unused\",a,O)):i.push(d(\"object\",a,O,y[z]))}else!s(y)&&s(x)?i.push(d(\"object\",a,v,y)):c(y)||!c(x)||w||T?p in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(d(\"dynamic\",a,v,y,x)):i.push(d(\"value\",a,v,y)):i.push(d(\"unused\",a,v,y)):i.push(d(\"array\",a,v,y));else i.push(d(\"schema\",a,v))}}return i}function f(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}e.exports=function(t,e){void 0===t&&(t=[]),void 0===e&&(e={});var r,c,h=a.get(),p=[],g={_context:n.extendFlat({},o)};l(t)?(g.data=n.extendDeep([],t),r=t):(g.data=[],r=[],p.push(d(\"array\",\"data\"))),s(e)?(g.layout=n.extendDeep({},e),c=e):(g.layout={},c={},arguments.length>1&&p.push(d(\"object\",\"layout\"))),i.supplyDefaults(g);for(var m=g._fullData,v=r.length,y=0;y<v;y++){var x=r[y],b=[\"data\",y];if(s(x)){var _=m[y],w=_.type,T=h.traces[w].attributes;T.type={valType:\"enumerated\",values:[w]},!1===_.visible&&!1!==x.visible&&p.push(d(\"invisible\",b)),u(x,_,T,p,b);var k=x.transforms,M=_.transforms;if(k){l(k)||p.push(d(\"array\",b,[\"transforms\"])),b.push(\"transforms\");for(var A=0;A<k.length;A++){var S=[\"transforms\",A],E=k[A].type;if(s(k[A])){var C=h.transforms[E]?h.transforms[E].attributes:{};C.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],M[A],C,p,b,S)}else p.push(d(\"object\",b,S))}}}else p.push(d(\"object\",b))}var L=g._fullLayout,I=f(h,m);return u(c,L,I,p,\"layout\"),0===p.length?void 0:p};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":p(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":p(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return p(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return p(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[p(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?p(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[p(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function p(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function d(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function g(t,e){var r=y(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function m(t,e){return e in t?t[e]:t[y(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function y(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":778,\"../plots/plots\":891,\"./plot_config\":815,\"./plot_schema\":816}],822:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],823:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],f=e[s]=[],h=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=h.newItem(p):(o=h.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),f.push(o)}var d=h.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=f.length,r.handleItemDefaults({},o,e,r,{}),f.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,f.length);for(a=0;a<g;a++)n.relinkPrivateKeys(f[a],c[a])}return f}},{\"../lib\":778,\"../plot_api/plot_template\":817}],824:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":674}],825:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i.dateTime2ms,o=i.incrementMonth,s=t(\"../../constants/numerical\").ONEAVGMONTH;e.exports=function(t,e,r,i){if(\"date\"!==e.type)return i;var l=t[r+\"periodalignment\"];if(!l)return i;var c,u=t[r+\"period\"];if(n(u)){if((u=+u)<=0)return i}else if(\"string\"==typeof u&&\"M\"===u.charAt(0)){var f=+u.substring(1);if(!(f>0&&Math.round(f)===f))return i;c=f}for(var h=e.calendar,p=\"start\"===l,d=\"end\"===l,g=t[r+\"period0\"],m=a(g,h)||0,v=[],y=i.length,x=0;x<y;x++){var b,_,w,T=i[x];if(c){for(b=Math.round((T-m)/(c*s)),w=o(m,c*b,h);w>T;)w=o(w,-c,h);for(;w<=T;)w=o(w,c,h);_=o(w,-c,h)}else{for(w=m+(b=Math.round((T-m)/u))*u;w>T;)w-=u;for(;w<=T;)w+=u;_=w-u}v[x]=p?_:d?w:(_+w)/2}return v}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],826:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],827:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\"),s=t(\"./axis_ids\"),l=s.getFromId,c=s.isLinked;function u(t,e){var r,n,a=[],o=t._fullLayout,s=h(o,e,0),l=h(o,e,1),c=p(t,e),u=c.min,d=c.max;if(0===u.length||0===d.length)return i.simpleMap(e.range,e.r2l);var g=u[0].val,m=d[0].val;for(r=1;r<u.length&&g===m;r++)g=Math.min(g,u[r].val);for(r=1;r<d.length&&g===m;r++)m=Math.max(m,d[r].val);var v=!1;if(e.range){var y=i.simpleMap(e.range,e.r2l);v=y[1]<y[0]}\"reversed\"===e.autorange&&(v=!0,e.autorange=!0);var x,b,_,w,T,k,M=e.rangemode,A=\"tozero\"===M,S=\"nonnegative\"===M,E=e._length,C=E/10,L=0;for(r=0;r<u.length;r++)for(x=u[r],n=0;n<d.length;n++)(k=(b=d[n]).val-x.val-f(e,x.val,b.val))>0&&((T=E-s(x)-l(b))>C?k/T>L&&(_=x,w=b,L=k/T):k/E>L&&(_={val:x.val,nopad:1},w={val:b.val,nopad:1},L=k/E));if(g===m){var I=g-1,P=g+1;if(A)if(0===g)a=[0,1];else{var z=(g>0?d:u).reduce((function(t,e){return Math.max(t,l(e))}),0),O=g/(1-Math.min(.5,z/E));a=g>0?[0,O]:[O,0]}else a=S?[Math.max(0,I),Math.max(1,P)]:[I,P]}else A?(_.val>=0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:0,nopad:1})):S&&(_.val-L*s(_)<0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:1,nopad:1})),L=(w.val-_.val-f(e,x.val,b.val))/(E-s(_)-l(w)),a=[_.val-L*s(_),w.val+L*l(w)];return v&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function f(t,e,r){var n=0;if(t.rangebreaks)for(var i=t.locateBreaks(e,r),a=0;a<i.length;a++){var o=i[a];n+=o.max-o.min}return n}function h(t,e,r){var n=.05*e._length,a=e._anchorAxis||{};if(-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")||-1!==(a.ticklabelposition||\"\").indexOf(\"inside\")){var o=\"reversed\"===e.autorange;if(!o){var s=i.simpleMap(e.range,e.r2l);o=s[1]<s[0]}o&&(r=!r)}var l=0;return c(t,e._id)||(l=function(t,e){var r=0,n=t._anchorAxis||{};if(-1!==(n.ticklabelposition||\"\").indexOf(\"inside\")&&(!e&&(\"left\"===n.side||\"bottom\"===n.side)||e&&(\"top\"===n.side||\"right\"===n.side))){var a=\"x\"===t._id.charAt(0);if(n._vals){var o=i.deg2rad(n._tickAngles[n._id+\"tick\"]||0),s=Math.abs(Math.cos(o)),l=Math.abs(Math.sin(o));n._vals.forEach((function(t){if(t.bb){var e=6+t.bb.width,n=6+t.bb.height;r=Math.max(r,a?Math.max(e*s,n*l):Math.max(n*s,e*l))}}))}\"inside\"===n.ticks&&\"inside\"===n.ticklabelposition&&(r+=n.ticklen||0)}return r}(e,r)),n=Math.max(l,n),\"domain\"===e.constrain&&e._inputDomain&&(n*=(e._inputDomain[1]-e._inputDomain[0])/(e.domain[1]-e.domain[0])),function(t){return t.nopad?0:t.pad+(t.extrapad?n:l)}}e.exports={getAutoRange:u,makePadFn:h,doAutoRange:function(t,e,r){if(e.setScale(),e.autorange){e.range=r?r.slice():u(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var n=e._input,a={};a[e._attr+\".range\"]=e.range,a[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,a),n.range=e.range.slice(),n.autorange=e.autorange}var s=e._anchorAxis;if(s&&s.rangeslider){var l=s.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=u(t,e)),s._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,u,f,h,p,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,T=!1,k=r.vpadLinearized||!1;function M(t){if(Array.isArray(t))return T=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=M((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),S=M((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),E=M(r.vpadplus||r.vpad),C=M(r.vpadminus||r.vpad);if(!T){if(h=1/0,p=-1/0,w)for(i=0;i<x;i++)(o=e[i])<h&&o>0&&(h=o),o>p&&o<a&&(p=o);else for(i=0;i<x;i++)(o=e[i])<h&&o>-a&&(h=o),o>p&&o<a&&(p=o);e=[h,p],x=2}var L={tozero:_,extrapad:b};function I(r){s=e[r],n(s)&&(u=A(r),f=S(r),k?(l=t.c2l(s)-C(r),c=t.c2l(s)+E(r)):(h=s-C(r),p=s+E(r),w&&h<p/10&&(h=p/10),l=t.c2l(h),c=t.c2l(p)),_&&(l=Math.min(0,l),c=Math.max(0,c)),v(l)&&d(m,l,f,L),v(c)&&g(y,c,u,L))}var P=Math.min(6,x);for(i=0;i<P;i++)I(i);for(i=x-1;i>=P;i--)I(i);return{min:m,max:y,opts:r}},concatExtremes:p};function p(t,e,r){var n,i,a,o=e._id,s=t._fullData,c=t._fullLayout,u=[],f=[];function h(t,e){for(n=0;n<e.length;n++){var r=t[e[n]],s=(r._extremes||{})[o];if(!0===r.visible&&s){for(i=0;i<s.min.length;i++)a=s.min[i],d(u,a.val,a.pad,{extrapad:a.extrapad});for(i=0;i<s.max.length;i++)a=s.max[i],g(f,a.val,a.pad,{extrapad:a.extrapad})}}}if(h(s,e._traceIndices),h(c.annotations||[],e._annIndices||[]),h(c.shapes||[],e._shapeIndices||[]),e._matchGroup&&!r)for(var m in e._matchGroup)if(m!==e._id){var v=l(t,m),y=p(t,v,!0),x=e._length/v._length;for(i=0;i<y.min.length;i++)a=y.min[i],d(u,a.val,a.pad*x,{extrapad:a.extrapad});for(i=0;i<y.max.length;i++)a=y.max[i],g(f,a.val,a.pad*x,{extrapad:a.extrapad})}return{min:u,max:f}}function d(t,e,r,n){m(t,e,r,n,y)}function g(t,e,r,n){m(t,e,r,n,x)}function m(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function v(t){return n(t)&&Math.abs(t)<a}function y(t,e){return t<=e}function x(t,e){return t>=e}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../registry\":911,\"./axis_ids\":831,\"fast-isnumeric\":241}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/titles\"),f=t(\"../../components/color\"),h=t(\"../../components/drawing\"),p=t(\"./layout_attributes\"),d=t(\"./clean_ticks\"),g=t(\"../../constants/numerical\"),m=g.ONEMAXYEAR,v=g.ONEAVGYEAR,y=g.ONEMINYEAR,x=g.ONEMAXQUARTER,b=g.ONEAVGQUARTER,_=g.ONEMINQUARTER,w=g.ONEMAXMONTH,T=g.ONEAVGMONTH,k=g.ONEMINMONTH,M=g.ONEWEEK,A=g.ONEDAY,S=A/2,E=g.ONEHOUR,C=g.ONEMIN,L=g.ONESEC,I=g.MINUS_SIGN,P=g.BADNUM,z=t(\"../../constants/alignment\"),O=z.MID_SHIFT,D=z.CAP_SHIFT,R=z.LINE_SPACING,F=z.OPPOSITE_SIDE,B=e.exports={};B.setConvert=t(\"./set_convert\");var N=t(\"./axis_autotype\"),j=t(\"./axis_ids\"),U=j.idSort,V=j.isLinked;B.id2name=j.id2name,B.name2id=j.name2id,B.cleanId=j.cleanId,B.list=j.list,B.listIds=j.listIds,B.getFromId=j.getFromId,B.getFromTrace=j.getFromTrace;var q=t(\"./autorange\");B.getAutoRange=q.getAutoRange,B.findExtremes=q.findExtremes;function H(t){var e=1e-4*(t[1]-t[0]);return[t[0]-e,t[1]+e]}B.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||(\"string\"==typeof a?a:a[0])),a||(a=i),l=l.concat(l.map((function(t){return t+\" domain\"}))),u[c]={valType:\"enumerated\",values:l.concat(a?\"string\"==typeof a?[a]:a:[]),dflt:i},s.coerce(t,e,u,c)},B.getRefType=function(t){return void 0===t?t:\"paper\"===t?\"paper\":\"pixel\"===t?\"pixel\":/( domain)$/.test(t)?\"domain\":\"range\"},B.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"range\"!==B.getRefType(n))o=s.ensureNumber,l=r(i,a);else{var c=B.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},B.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:B.getFromId(e,r).cleanPos)(t)},B.redrawComponents=function(t,e){e=e||B.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var f=r[B.id2name(e[u])][a],h=0;h<f.length;h++){var p=f[h];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var G=B.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:N(n,void 0,{autotypenumbers:t._fullLayout.autotypenumbers}),_categories:[]},B.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=B.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:W,c2d:W}:{d2c:Y,c2d:Y}};function Y(t){return+t}function W(t){return String(t)}function X(t){return+t.substring(1)}B.getDataToCoordFunc=function(t,e,r,n){return G(t,e,r,n).d2c},B.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},B.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},B.saveRangeInitial=function(t,e){for(var r=B.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},B.saveShowSpikeInitial=function(t,e){for(var r=B.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},B.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},B.setConvert(l),o=o&&d.dtick(o,l.type))l.dtick=o,l.tick0=d.tick0(void 0,l.type,a);else{var f;if(r)f=(u-c)/r;else{var h=s.distinctVals(t),p=Math.pow(10,Math.floor(Math.log(h.minDiff)/Math.LN10)),g=p*s.roundUp(h.minDiff/p,[.9,1.9,4.9,9.9],!0);f=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(f)||(f=1)}B.autoTicks(l,f)}var m,v=l.dtick,y=B.tickIncrement(B.tickFirst(l),v,\"reverse\",a);if(\"number\"==typeof v)m=(y=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var f=0;f<e.length;f++)e[f]%1==0?l++:i(e[f])||c++,u(e[f])&&o++,u(e[f]+r.dtick/2)&&s++;var h=e.length-c;if(l===h&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*h&&(o>.3*h||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(y,t,l,c,u))+(1+Math.floor((u-y)/v))*v;else for(\"M\"===l.dtick.charAt(0)&&(y=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=B.tickIncrement(t,\"M6\",\"reverse\")+1.5*A:a.exactMonths>.8?t=B.tickIncrement(t,\"M1\",\"reverse\")+15.5*A:t-=S;var l=B.tickIncrement(t,r);if(l<=n)return l}return t}(y,t,v,c,a)),m=y,0;m<=u;)m=B.tickIncrement(m,v,!1,a);return{start:e.c2r(y,0,a),end:e.c2r(m,0,a),size:v,_dataSpan:u-c}},B.prepTicks=function(t,e){var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(t._dtickInit=t.dtick,t._tick0Init=t.tick0,\"auto\"===t.tickmode||!t.dtick){var n,a=t.nticks;a||(\"category\"===t.type||\"multicategory\"===t.type?(n=t.tickfont?1.2*(t.tickfont.size||12):15,a=t._length/n):(n=\"y\"===t._id.charAt(0)?40:80,a=s.constrain(t._length/n,4,9)+1),\"radialaxis\"===t._name&&(a*=2)),\"array\"===t.tickmode&&(a*=100),t._roughDTick=Math.abs(r[1]-r[0])/a,B.autoTicks(t,t._roughDTick),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}\"period\"===t.ticklabelmode&&function(t){var e;function r(){return!(i(t.dtick)||\"M\"!==t.dtick.charAt(0))}var n=r(),a=B.getTickFormat(t);if(a){var o=t._dtickInit!==t.dtick;/%[fLQsSMX]/.test(a)||(/%[HI]/.test(a)?(e=E,o&&!n&&t.dtick<E&&(t.dtick=E)):/%p/.test(a)?(e=S,o&&!n&&t.dtick<S&&(t.dtick=S)):/%[Aadejuwx]/.test(a)?(e=A,o&&!n&&t.dtick<A&&(t.dtick=A)):/%[UVW]/.test(a)?(e=M,o&&!n&&t.dtick<M&&(t.dtick=M)):/%[Bbm]/.test(a)?(e=T,o&&(n?X(t.dtick)<1:t.dtick<k)&&(t.dtick=\"M1\")):/%[q]/.test(a)?(e=b,o&&(n?X(t.dtick)<3:t.dtick<_)&&(t.dtick=\"M3\")):/%[Yy]/.test(a)&&(e=v,o&&(n?X(t.dtick)<12:t.dtick<y)&&(t.dtick=\"M12\")))}(n=r())&&t.tick0===t._dowTick0&&(t.tick0=t._rawTick0);t._definedDelta=e}(t),t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),nt(t)},B.calcTicks=function(t,e){B.prepTicks(t,e);var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=H(s.simpleMap(t.range,t.r2l)),a=Math.min(i[0],i[1]),o=Math.max(i[0],i[1]),l=0;Array.isArray(r)||(r=[]);var c=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var u=0;u<e.length;u++){var f=c(e[u]);f>a&&f<o&&(void 0===r[u]?n[l]=B.tickText(t,f):n[l]=it(t,f,String(r[u])),l++)}l<e.length&&n.splice(l,e.length-l);t.rangebreaks&&(n=n.filter((function(e){return t.maskBreaks(e.x)!==P})));return n}(t);var n=H(r),a=n[0],o=n[1],l=r[1]<r[0],c=Math.min(r[0],r[1]),u=Math.max(r[0],r[1]),f=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),h=\"period\"===t.ticklabelmode;if(t._tmin=B.tickFirst(t,e),t._tmin<a!==l)return[];\"category\"!==t.type&&\"multicategory\"!==t.type||(o=l?Math.max(-.5,o):Math.min(t._categories.length-.5,o));var p=t._tmin;t.rangebreaks&&t._tick0Init!==t.tick0&&(p=wt(p,t),l||(p=B.tickIncrement(p,t.dtick,!l,t.calendar))),h&&(p=B.tickIncrement(p,t.dtick,!l,t.calendar));for(var d,g=Math.max(1e3,t._length||0),C=[],L=null;l?p>=o:p<=o;p=B.tickIncrement(p,t.dtick,l,t.calendar)){if(t.rangebreaks&&!l){if(p<a)continue;if(t.maskBreaks(p)===P&&wt(p,t)>=u)break}if(C.length>g||p===L)break;L=p;var I=!1;f&&p!==(0|p)&&(I=!0),C.push({minor:I,value:p})}if(h&&function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n].value,a=n,o=n+1;n<t.length-1?(a=n,o=n+1):n>0?(a=n-1,o=n):(a=n,o=n);var s,l=t[a].value,c=t[o].value,u=Math.abs(c-l),f=r||u,h=0;f>=y?h=u>=y&&u<=m?u:v:r===b&&f>=_?h=u>=_&&u<=x?u:b:f>=k?h=u>=k&&u<=w?u:T:r===M&&f>=M?h=M:f>=A?h=A:r===S&&f>=S?h=S:r===E&&f>=E&&(h=E),h>=u&&(h=u,s=!0);var p=i+h;if(e.rangebreaks&&h>0){for(var d=0,g=0;g<84;g++){var C=(g+.5)/84;e.maskBreaks(i*(1-C)+C*p)!==P&&d++}(h*=d/84)||(t[n].drop=!0),s&&u>M&&(h=u)}(h>0||0===n)&&(t[n].periodX=i+h/2)}}(C,t,t._definedDelta),t.rangebreaks){var z=\"y\"===t._id.charAt(0),O=1;\"auto\"===t.tickmode&&(O=t.tickfont?t.tickfont.size:12);var D=NaN;for(d=C.length-1;d>-1;d--)if(C[d].drop)C.splice(d,1);else{C[d].value=wt(C[d].value,t);var R=t.c2p(C[d].value);(z?D>R-O:D<R+O)?C.splice(l?d+1:d,1):D=R}}_t(t)&&360===Math.abs(r[1]-r[0])&&C.pop(),t._tmax=(C[C.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;var F,N,j=[];for(d=0;d<C.length;d++){var U=C[d].minor,V=C[d].value;F=B.tickText(t,V,!1,U),void 0!==(N=C[d].periodX)&&(F.periodX=N,(N>u||N<c)&&(N>u&&(F.periodX=u),N<c&&(F.periodX=c),F.text=\" \",t._prevDateHead=\"\")),j.push(F)}return t._inCalcTicks=!1,j};var Z=[2,5,10],J=[1,2,3,6,12],K=[1,2,5,10,15,30],Q=[1,2,3,7,14],$=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],tt=[-.301,0,.301,.699,1],et=[15,30,45,90,180];function rt(t,e,r){return e*s.roundUp(t/e,r)}function nt(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=A&&a<=10||e>=15*A)t._tickround=\"d\";else if(e>=C&&a<=16||e>=E)t._tickround=\"M\";else if(e>=L&&a<=19||e>=C)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01),u=void 0===t.minexponent?3:t.minexponent;Math.abs(c)>u&&(ot(t.exponentformat)&&!st(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function it(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}B.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar,0);var a=2*e;if(a>v)e/=v,r=n(10),t.dtick=\"M\"+12*rt(e,r,Z);else if(a>T)e/=T,t.dtick=\"M\"+rt(e,1,J);else if(a>A){t.dtick=rt(e,A,t._hasDayOfWeekBreaks?[1,2,7,14]:Q);var o=B.getTickFormat(t),l=\"period\"===t.ticklabelmode;l&&(t._rawTick0=t.tick0),/%[uVW]/.test(o)?t.tick0=s.dateTick0(t.calendar,2):t.tick0=s.dateTick0(t.calendar,1),l&&(t._dowTick0=t.tick0)}else a>E?t.dtick=rt(e,E,J):a>C?t.dtick=rt(e,C,K):a>L?t.dtick=rt(e,L,K):(r=n(10),t.dtick=rt(e,r,Z))}else if(\"log\"===t.type){t.tick0=0;var c=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(c[1]-c[0])<1){var u=1.5*Math.abs((c[1]-c[0])/e);e=Math.abs(Math.pow(10,c[1])-Math.pow(10,c[0]))/u,r=n(10),t.dtick=\"L\"+rt(e,r,Z)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):_t(t)?(t.tick0=0,r=1,t.dtick=rt(e,r,et)):(t.tick0=0,r=n(10),t.dtick=rt(e,r,Z));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var f=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(f)}},B.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return s.increment(t,o*e);var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?tt:$,f=t+.01*o,h=s.roundUp(s.mod(f,1),u,r);return Math.floor(f)+Math.log(n.round(Math.pow(10,h),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},B.tickFirst=function(t,e){var r=t.r2l||Number,a=s.simpleMap(t.range,r,void 0,void 0,e),o=a[1]<a[0],l=o?Math.floor:Math.ceil,c=H(a)[0],u=t.dtick,f=r(t.tick0);if(i(u)){var h=l((c-f)/u)*u+f;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var p=u.charAt(0),d=Number(u.substr(1));if(\"M\"===p){for(var g,m,v,y=0,x=f;y<10;){if(((g=B.tickIncrement(x,u,o,t.calendar))-c)*(x-c)<=0)return o?Math.min(x,g):Math.max(x,g);m=(c-(x+g)/2)/(g-x),v=p+(Math.abs(Math.round(m))||1)*d,x=B.tickIncrement(x,v,m<0?!o:o,t.calendar),y++}return s.error(\"tickFirst did not converge\",t),x}if(\"L\"===p)return Math.log(l((Math.pow(10,c)-f)/d)*d+f)/Math.LN10;if(\"D\"===p){var b=\"D2\"===u?tt:$,_=s.roundUp(s.mod(c,1),b,o);return Math.floor(c)+Math.log(n.round(Math.pow(10,_),1))/Math.LN10}throw\"unrecognized dtick \"+String(u)},B.tickText=function(t,e,r,n){var a,o=it(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,f=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var h=s.simpleMap(t.range,t.r2l),p=(Math.abs(h[1]-h[0])-(t._lBreaks||0))/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-f(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||B.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));if(l)if(r)\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\");else if(t._inCalcTicks&&t._prevDateHead===l){var f=-1!==(t.ticklabelposition||\"\").indexOf(\"inside\"),h=t._realSide||t.side;(!f&&\"top\"===h||f&&\"bottom\"===h)&&(c+=\"<br> \")}else t._prevDateHead=l,c+=\"<br>\"+l;e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=lt(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var f=Math.round(l),h=Math.abs(f),p=t.exponentformat;\"power\"===p||ot(p)&&st(f)?(e.text=0===f?1:1===f?\"10\":\"10<sup>\"+(f>1?\"\":I)+h+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&h>2?e.text=\"1\"+p+(f>0?\"+\":I)+h:(e.text=lt(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):_t(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=lt(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){for(var r=1;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=lt(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=I+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=lt(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var m=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[m(o.x-.5),m(o.x+t.dtick-.5)]}return o},B.hoverLabelText=function(t,e,r){if(r!==P&&r!==e)return B.hoverLabelText(t,e)+\" - \"+B.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=B.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":I+i:i};var at=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function ot(t){return\"SI\"===t||\"B\"===t}function st(t){return t>14||t<-15}function lt(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=B.getTickFormat(e),f=e.separatethousands;if(n){var h={exponentformat:l,minexponent:e.minexponent,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};nt(h),o=(Number(h._tickround)||0)+4,c=h._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,I);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var m=(t=String(t)).indexOf(\".\")+1;m&&(t=t.substr(0,m+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,f)}c&&\"hide\"!==l&&(ot(l)&&st(c)&&(l=\"power\"),p=c<0?I+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":ot(l)&&(t+=at[c/3+5]));return a?I+t:t}function ct(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(it(t,s.interp(n[o],.5),o));return r}function ut(t){return void 0!==t.periodX?t.periodX:t.x}function ft(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function ht(t){var e=t.title.font.size,r=(t.title.text.match(c.BR_TAG_ALL)||[]).length;return t.title.hasOwnProperty(\"standoff\")?r?e*(D+r*R):e*D:r?e*(r+1)*R:e}function pt(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function dt(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function gt(t){return t._id+\".automargin\"}function mt(t){return gt(t)+\".mirror\"}function vt(t){return t._id+\".rangeslider\"}function yt(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function xt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(B.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(B.getFromId(t,r[n]));var c=Object.keys(p),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],f=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var h=c[n],d=a[0][h],g=o[0][h],m=!0,v=!1,y=!1;if(\"_\"!==h.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(h)){for(i=1;i<a.length&&m;i++){var x=a[i][h];\"type\"===h&&-1!==f.indexOf(d)&&-1!==f.indexOf(x)&&d!==x?v=!0:x!==d&&(m=!1)}for(i=1;i<o.length&&m;i++){var b=o[i][h];\"type\"===h&&-1!==f.indexOf(g)&&-1!==f.indexOf(b)&&g!==b?y=!0:o[i][h]!==g&&(m=!1)}m&&(v&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),bt(l,h,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function bt(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function _t(t){return\"angularaxis\"===t._id}function wt(t,e){for(var r=e._rangebreaks.length,n=0;n<r;n++){var i=e._rangebreaks[n];if(t>=i.min&&t<i.max)return i.max}return t}B.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*T}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function f(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,s=void 0,l=void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&f(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},B.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?B.findSubplotsWithAxis(n,e):n;return i.sort((function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]})),i},B.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},B.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=B.list(t,\"x\",!0),l=B.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,(function(t){return t.x._id+t.y._id}));u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",(function(t){return\"clip\"+e._uid+t.x._id+t.y._id})).append(\"rect\"),u.exit().remove(),u.each((function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})}))}},B.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each((function(t){var e=t[0],r=n._plots[e];if(r){var i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()}}));var i=e&&\"redraw\"!==e?e:B.listIds(t);return s.syncOrAsync(i.map((function(e){return function(){if(e){var n=B.getFromId(t,e),i=B.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}})))},B.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var c=t._fullLayout,p=e._id,d=p.charAt(0),g=B.counterLetter(p),m=c._plots[e._mainSubplot];if(m){var v=m[d+\"axislayer\"],y=e._mainLinePosition,x=e._mainMirrorPosition,b=e._vals=B.calcTicks(e),_=[e.mirror,y,x].join(\"_\");for(n=0;n<b.length;n++)b[n].axInfo=_;e._selections={},e._tickAngles&&(e._prevTickAngles=e._tickAngles),e._tickAngles={},e._depth=null;var w={};if(e.visible){var T,k,M=B.makeTransTickFn(e),A=B.makeTransTickLabelFn(e),S=\"inside\"===e.ticks,E=\"outside\"===e.ticks;if(\"boundaries\"===e.tickson){var C=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,b);k=B.clipEnds(e,C),T=S?k:C}else k=B.clipEnds(e,b),T=S&&\"period\"!==e.ticklabelmode?k:b;var L=e._gridVals=k,I=function(t,e){var r,n,i=[],a=e.length&&e[e.length-1].x<e[0].x,o=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var l=e[r];l.text2!==n&&o(l,a?1:0),n=l.text2}o(e[r-1],a?0:1)}return i}(e,b);if(!c._hasOnlyLargeSploms){var P=e._subplotsWith,z={};for(n=0;n<P.length;n++){i=P[n];var O=(l=c._plots[i])[g+\"axis\"],D=O._mainAxis._id;if(!z[D]){z[D]=1;var N=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;B.drawGrid(t,e,{vals:L,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:N,transFn:M}),B.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:N,transFn:M})}}}var j=B.getTickSigns(e),U=[];if(e.ticks){var V,q,H,G=B.makeTickPath(e,y,j[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(V=B.makeTickPath(e,x,j[3]),q=G+V):(V=\"\",q=G),e.showdividers&&E&&\"boundaries\"===e.tickson){var Y={};for(n=0;n<I.length;n++)Y[I[n].x]=1;H=function(t){return Y[t.x]?V:q}}else H=q;B.drawTicks(t,e,{vals:T,layer:v,path:H,transFn:M}),\"allticks\"===e.mirror&&(U=Object.keys(e._linepositions||{}))}for(n=0;n<U.length;n++){i=U[n],l=c._plots[i];var W=e._linepositions[i]||[],X=B.makeTickPath(e,W[0],j[0])+B.makeTickPath(e,W[1],j[1]);B.drawTicks(t,e,{vals:T,layer:l[d+\"axislayer\"],path:X,transFn:M})}var Z=[];if(Z.push((function(){return B.drawLabels(t,e,{vals:b,layer:v,transFn:A,labelFns:B.makeLabelFns(e,y)})})),\"multicategory\"===e.type){var J={x:2,y:10}[d];Z.push((function(){var r={x:\"height\",y:\"width\"}[d],n=Q()[r]+J+(e._tickAngles[p+\"tick\"]?e.tickfont.size*R:0);return B.drawLabels(t,e,{vals:ct(e,b),layer:v,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:M,labelFns:B.makeLabelFns(e,y+n*j[4])})})),Z.push((function(){return e._depth=j[4]*(Q(\"tick2\")[e.side]-y),function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,ft);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(f.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:I,layer:v,path:B.makeTickPath(e,y,j[4],e._depth),transFn:M})}))}else e.title.hasOwnProperty(\"standoff\")&&Z.push((function(){e._depth=j[4]*(Q()[e.side]-y)}));var K=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return Z.push((function(){var r,n,i,s,l=e.side.charAt(0),u=F[e.side].charAt(0),f=B.getPxPosition(t,e),h=E?e.ticklen:0;if((e.automargin||K)&&(\"multicategory\"===e.type?r=Q(\"tick2\"):(r=Q(),\"x\"===d&&\"b\"===l&&(e._depth=Math.max(r.width>0?r.bottom-f:0,h)))),e.automargin){n={x:0,y:0,r:0,l:0,t:0,b:0};var p=[0,1];if(\"x\"===d){if(\"b\"===l?n[l]=e._depth:(n[l]=e._depth=Math.max(r.width>0?f-r.top:0,h),p.reverse()),r.width>0){var m=r.right-(e._offset+e._length);m>0&&(n.xr=1,n.r=m);var v=e._offset-r.left;v>0&&(n.xl=0,n.l=v)}}else if(\"l\"===l?n[l]=e._depth=Math.max(r.height>0?f-r.left:0,h):(n[l]=e._depth=Math.max(r.height>0?r.right-f:0,h),p.reverse()),r.height>0){var y=r.bottom-(e._offset+e._length);y>0&&(n.yb=0,n.b=y);var x=e._offset-r.top;x>0&&(n.yt=1,n.t=x)}n[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[p[0]],e.title.text!==c._dfltTitle[d]&&(n[l]+=ht(e)+(e.title.standoff||0)),e.mirror&&\"free\"!==e.anchor&&((i={x:0,y:0,r:0,l:0,t:0,b:0})[u]=e.linewidth,e.mirror&&!0!==e.mirror&&(i[u]+=h),!0===e.mirror||\"ticks\"===e.mirror?i[g]=e._anchorAxis.domain[p[1]]:\"all\"!==e.mirror&&\"allticks\"!==e.mirror||(i[g]=[e._counterDomainMin,e._counterDomainMax][p[1]]))}K&&(s=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,gt(e),n),a.autoMargin(t,mt(e),i),a.autoMargin(t,vt(e),s)})),r.skipTitle||K&&\"bottom\"===e.side||Z.push((function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(e.title.hasOwnProperty(\"standoff\"))r=e._depth+e.title.standoff+ht(e);else{var s=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\");if(\"multicategory\"===e.type)r=e._depth;else{var l=1.5*o;s&&(l=.5*o,\"outside\"===e.ticks&&(l+=e.ticklen)),r=10+l+(e.linewidth?e.linewidth-1:0)}s||(r+=\"x\"===a?\"top\"===e.side?o*(e.showticklabels?1:0):o*(e.showticklabels?1.5:.5):\"right\"===e.side?o*(e.showticklabels?1:.5):o*(e.showticklabels?.5:0))}var c,f,p,d,g=B.getPxPosition(t,e);\"x\"===a?(f=e._offset+e._length/2,p=\"top\"===e.side?g-r:g+r):(p=e._offset+e._length/2,f=\"right\"===e.side?g+r:g-r,c={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var m=e._selections[e._id+\"tick\"];if(d={selection:m,side:e.side},m&&m.node()&&m.node().parentNode){var v=h.getTranslate(m.node().parentNode);d.offsetLeft=v.x,d.offsetTop=v.y}e.title.hasOwnProperty(\"standoff\")&&(d.pad=0)}return u.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:d,transform:c,attributes:{x:f,y:p,\"text-anchor\":\"middle\"}})}(t,e)})),s.syncOrAsync(Z)}}function Q(t){var r=p+(t||\"tick\");return w[r]||(w[r]=function(t,e){var r,n,i,a;t._selections[e].size()?(r=1/0,n=-1/0,i=1/0,a=-1/0,t._selections[e].each((function(){var t=dt(this),e=h.bBox(t.node().parentNode);r=Math.min(r,e.top),n=Math.max(n,e.bottom),i=Math.min(i,e.left),a=Math.max(a,e.right)}))):(r=0,n=0,i=0,a=0);return{top:r,bottom:n,left:i,right:a,height:n-r,width:a-i}}(e,r)),w[r]}},B.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map((function(t){return-t}))),t.side&&i.push({l:-1,t:-1,r:1,b:1}[t.side.charAt(0)]),i},B.makeTransTickFn=function(t){return\"x\"===t._id.charAt(0)?function(e){return l(t._offset+t.l2p(e.x),0)}:function(e){return l(0,t._offset+t.l2p(e.x))}},B.makeTransTickLabelFn=function(t){var e=function(t){var e=t.ticklabelposition||\"\",r=function(t){return-1!==e.indexOf(t)},n=r(\"top\"),i=r(\"left\"),a=r(\"right\"),o=r(\"bottom\"),s=r(\"inside\"),l=o||i||n||a;if(!l&&!s)return[0,0];var c=t.side,u=l?(t.tickwidth||0)/2:0,f=3,h=t.tickfont?t.tickfont.size:12;(o||n)&&(u+=h*D,f+=(t.linewidth||0)/2);(i||a)&&(u+=(t.linewidth||0)/2,f+=3);s&&\"top\"===c&&(f-=h*(1-D));(i||n)&&(u=-u);\"bottom\"!==c&&\"right\"!==c||(f=-f);return[l?u:0,s?f:0]}(t),r=e[0],n=e[1];return\"x\"===t._id.charAt(0)?function(e){return l(r+t._offset+t.l2p(ut(e)),n)}:function(e){return l(n,r+t._offset+t.l2p(ut(e)))}},B.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},B.makeLabelFns=function(t,e,r){var n=t.ticklabelposition||\"\",a=function(t){return-1!==n.indexOf(t)},o=a(\"top\"),l=a(\"left\"),c=a(\"right\"),u=a(\"bottom\")||l||o||c,f=a(\"inside\"),h=\"inside\"===n&&\"inside\"===t.ticks||!f&&\"outside\"===t.ticks&&\"boundaries\"!==t.tickson,p=0,d=0,g=h?t.ticklen:0;if(f?g*=-1:u&&(g=0),h&&(p+=g,r)){var m=s.deg2rad(r);p=g*Math.cos(m)+1,d=g*Math.sin(m)}t.showticklabels&&(h||t.showline)&&(p+=.2*t.tickfont.size);var v,y,x,b,_,w={labelStandoff:p+=(t.linewidth||1)/2*(f?-1:1),labelShift:d},T=0,k=t.side,M=t._id.charAt(0),A=t.tickangle;if(\"x\"===M)b=(_=!f&&\"bottom\"===k||f&&\"top\"===k)?1:-1,f&&(b*=-1),v=d*b,y=e+p*b,x=_?1:-.2,90===Math.abs(A)&&(f?x+=O:x=-90===A&&\"bottom\"===k?D:90===A&&\"top\"===k?O:.5,T=O/2*(A/90)),w.xFn=function(t){return t.dx+v+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*x},w.anchorFn=function(t,e){if(u){if(l)return\"end\";if(c)return\"start\"}return i(e)&&0!==e&&180!==e?e*b<0!==f?\"end\":\"start\":\"middle\"},w.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side!==f?-n:0};else if(\"y\"===M){if(b=(_=!f&&\"left\"===k||f&&\"right\"===k)?1:-1,f&&(b*=-1),v=p,y=d*b,x=0,f||90!==Math.abs(A)||(x=-90===A&&\"left\"===k||90===A&&\"right\"===k?D:.5),f){var S=i(A)?+A:0;if(0!==S){var E=s.deg2rad(S);T=Math.abs(Math.sin(E))*D*b,x=0}}w.xFn=function(t){return t.dx+e-(v+t.fontSize*x)*b+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*O},w.anchorFn=function(t,e){return i(e)&&90===Math.abs(e)?\"middle\":_?\"end\":\"start\"},w.heightFn=function(e,r,n){return\"right\"===t.side&&(r*=-1),r<-30?-n:r<30?-.5*n:0}}return w},B.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.vals;\"period\"===e.ticklabelmode&&(i=i.slice()).shift();var a=r.layer.selectAll(\"path.\"+n).data(e.ticks?i:[],ft);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(f.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),a.attr(\"transform\",r.transFn)},B.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&B.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,ft);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},B.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=B.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each((function(){r.layer.selectAll(\"path\").sort((function(t,e){return U(t.id,e.id)}))})),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.zerolinecolor||f.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},B.drawLabels=function(t,e,r){r=r||{};var a=t._fullLayout,o=e._id,u=o.charAt(0),f=r.cls||o+\"tick\",p=r.vals,d=r.labelFns,g=r.secondary?0:e.tickangle,m=(e._prevTickAngles||{})[f],v=r.layer.selectAll(\"g.\"+f).data(e.showticklabels?p:[],ft),y=[];function x(t,a){var o=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\");t.each((function(t){var s=n.select(this),u=s.select(\".text-math-group\"),f=d.anchorFn(t,a),p=r.transFn.call(s.node(),t)+(i(a)&&0!=+a?\" rotate(\"+a+\",\"+d.xFn(t)+\",\"+(d.yFn(t)-t.fontSize/2)+\")\":\"\"),g=c.lineCount(s),m=R*t.fontSize,v=d.heightFn(t,i(a)?+a:0,(g-1)*m);if(v&&(p+=l(0,v)),u.empty()){var y=s.select(\"text\");y.attr({transform:p,\"text-anchor\":f}),o&&(y.style({opacity:100}),e._hideOutOfRangeInsideTickLabels&&e._hideOutOfRangeInsideTickLabels())}else{var x=h.bBox(u.node()).width*{end:-.5,start:.5}[f];u.attr(\"transform\",p+l(x,0))}}))}v.enter().append(\"g\").classed(f,1).append(\"text\").attr(\"text-anchor\",\"middle\").each((function(e){var r=n.select(this),i=t._promises.length;r.call(c.positionText,d.xFn(e),d.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(c.convertToTspans,t),t._promises[i]?y.push(t._promises.pop().then((function(){x(r,g)}))):x(r,g)})),v.exit().remove(),r.repositionOnUpdate&&v.each((function(t){n.select(this).select(\"text\").call(c.positionText,d.xFn(t),d.yFn(t))})),e._hideOutOfRangeInsideTickLabels=void 0,-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")&&(e._hideOutOfRangeInsideTickLabels=function(){var t=s.simpleMap(e.range,e.r2l),r=e.l2p(t[0]),i=e.l2p(t[1]),a=Math.min(r,i)+e._offset,o=Math.max(r,i)+e._offset,l=\"x\"===e._id.charAt(0);v.each((function(t){var r=n.select(this);if(r.select(\".text-math-group\").empty()){var i=h.bBox(r.node()),s=!1;l?(i.right>o||i.left<a)&&(s=!0):(i.bottom>o||i.top+(e.tickangle?0:t.fontSize/4)<a)&&(s=!0),s&&r.select(\"text\").style({opacity:0})}}))}),x(v,m+1?m:g);var b=null;e._selections&&(e._selections[f]=v);var _=[function(){return y.length&&Promise.all(y)}];e.automargin&&a._redrawFromAutoMarginCount&&90===m?(b=90,_.push((function(){x(v,m)}))):_.push((function(){if(x(v,g),p.length&&\"x\"===u&&!i(g)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){b=0;var t,n=0,a=[];if(v.each((function(t){n=Math.max(n,t.fontSize);var r=e.l2p(t.x),i=dt(this),o=h.bBox(i.node());a.push({top:0,bottom:10,height:10,left:r-o.width/2,right:r+o.width/2+2,width:o.width+2})})),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var o=p.length,l=Math.abs((p[o-1].x-p[0].x)*e._m)/(o-1),c=e.ticklabelposition||\"\",f=function(t){return-1!==c.indexOf(t)},d=f(\"top\"),m=f(\"left\"),y=f(\"right\"),_=f(\"bottom\")||m||d||y?(e.tickwidth||0)+6:0,w=l<2.5*n||\"multicategory\"===e.type;for(t=0;t<a.length-1;t++)if(s.bBoxIntersect(a[t],a[t+1],_)){b=w?90:30;break}}else{var T=2;for(e.ticks&&(T+=e.tickwidth/2),t=0;t<a.length;t++){var k=p[t].xbnd,M=a[t];if(null!==k[0]&&M.left-e.l2p(k[0])<T||null!==k[1]&&e.l2p(k[1])-M.right<T){b=90;break}}}b&&x(v,b)}})),e._tickAngles&&_.push((function(){e._tickAngles[f]=null===b?i(g)?g:0:b}));var w=e._anchorAxis;w&&w.autorange&&-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")&&!V(a,e._id)&&(a._insideTickLabelsAutorange||(a._insideTickLabelsAutorange={}),a._insideTickLabelsAutorange[w._name+\".autorange\"]=w.autorange,_.push((function(){v.each((function(t,r){var n=dt(this);e._vals[r].bb=h.bBox(n.node())}))})));var T=s.syncOrAsync(_);return T&&T.then&&t._promises.push(T),T},B.getPxPosition=function(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=e._anchorAxis:\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0},B.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&!(e.rangebreaks&&e.maskBreaks(0)===P)&&(pt(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=B.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var f=B.list(t,s),h=0;h<f.length;h++){var p=f[h];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},B.clipEnds=function(t,e){return e.filter((function(e){return pt(t,e.x)}))},B.allowAutoMargin=function(t){for(var e=B.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&(a.allowAutoMargin(t,gt(n)),n.mirror&&a.allowAutoMargin(t,mt(n))),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,vt(n))}},B.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],yt(c.x,l.x),yt(c.y,l.y);yt(c.x,[o]),yt(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)xt(t,r[n].x,r[n].y)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/titles\":738,\"../../constants/alignment\":745,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"./autorange\":827,\"./axis_autotype\":829,\"./axis_ids\":831,\"./clean_ticks\":833,\"./layout_attributes\":842,\"./set_convert\":848,d3:169,\"fast-isnumeric\":241}],829:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=i.isArrayOrTypedArray,s=i.isDateTime,l=i.cleanNumber,c=Math.round;function u(t,e){return e?n(t):\"number\"==typeof t}function f(t){return Math.max(1,(t-1)/1e3)}e.exports=function(t,e,r){var i=t,h=r.noMultiCategory;if(o(i)&&!i.length)return\"-\";if(!h&&function(t){return o(t[0])&&o(t[1])}(i))return\"multicategory\";if(h&&Array.isArray(i[0])){for(var p=[],d=0;d<i.length;d++)if(o(i[d]))for(var g=0;g<i[d].length;g++)p.push(i[d][g]);i=p}if(function(t,e){for(var r=t.length,i=f(r),a=0,o=0,l={},u=0;u<r;u+=i){var h=c(u),p=t[h],d=String(p);l[d]||(l[d]=1,s(p,e)&&a++,n(p)&&o++)}return a>2*o}(i,e))return\"date\";var m=\"strict\"!==r.autotypenumbers;return function(t,e){for(var r=t.length,n=f(r),i=0,o=0,s={},u=0;u<r;u+=n){var h=c(u),p=t[h],d=String(p);if(!s[d]){s[d]=1;var g=typeof p;\"boolean\"===g?o++:(e?l(p)!==a:\"number\"===g)?i++:\"string\"===g&&o++}}return o>2*i}(i,m)?\"category\":function(t,e){for(var r=t.length,n=0;n<r;n++)if(u(t[n],e))return!0;return!1}(i,m)?\"linear\":\"-\"}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],830:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../array_container_defaults\"),s=t(\"./layout_attributes\"),l=t(\"./tick_value_defaults\"),c=t(\"./tick_mark_defaults\"),u=t(\"./tick_label_defaults\"),f=t(\"./category_order_defaults\"),h=t(\"./line_grid_defaults\"),p=t(\"./set_convert\"),d=t(\"./constants\").WEEKDAY_PATTERN,g=t(\"./constants\").HOUR_PATTERN;function m(t,e,r){function i(r,n){return a.coerce(t,e,s.rangebreaks,r,n)}if(i(\"enabled\")){var o=i(\"bounds\");if(o&&o.length>=2){var l,c,u=\"\";if(2===o.length)for(l=0;l<2;l++)if(c=y(o[l])){u=d;break}var f=i(\"pattern\",u);if(f===d)for(l=0;l<2;l++)(c=y(o[l]))&&(e.bounds[l]=o[l]=c-1);if(f)for(l=0;l<2;l++)switch(c=o[l],f){case d:if(!n(c))return void(e.enabled=!1);if((c=+c)!==Math.floor(c)||c<0||c>=7)return void(e.enabled=!1);e.bounds[l]=o[l]=c;break;case g:if(!n(c))return void(e.enabled=!1);if((c=+c)<0||c>24)return void(e.enabled=!1);e.bounds[l]=o[l]=c}if(!1===r.autorange){var h=r.range;if(h[0]<h[1]){if(o[0]<h[0]&&o[1]>h[1])return void(e.enabled=!1)}else if(o[0]>h[0]&&o[1]<h[1])return void(e.enabled=!1)}}else{var p=i(\"values\");if(!p||!p.length)return void(e.enabled=!1);i(\"dvalue\")}}}e.exports=function(t,e,r,n,g){var v,y=n.letter,x=n.font||{},b=n.splomStash||{},_=r(\"visible\",!n.visibleDflt),w=e._template||{},T=e.type||w.type||\"-\";\"date\"===T&&(i.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",n.calendar),n.noTicklabelmode||(v=r(\"ticklabelmode\")));n.noTicklabelposition&&\"multicategory\"!==T||a.coerce(t,e,{ticklabelposition:{valType:\"enumerated\",dflt:\"outside\",values:\"period\"===v?[\"outside\",\"inside\"]:\"x\"===y?[\"outside\",\"inside\",\"outside left\",\"inside left\",\"outside right\",\"inside right\"]:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"]}},\"ticklabelposition\"),p(e,g);var k=!e.isValidRange(t.range);k&&n.reverseDflt&&(k=\"reversed\"),!r(\"autorange\",k)||\"linear\"!==T&&\"-\"!==T||r(\"rangemode\"),r(\"range\"),e.cleanRange(),f(t,e,r,n),\"category\"===T||n.noHover||r(\"hoverformat\");var M=r(\"color\"),A=M!==s.color.dflt?M:x.color,S=b.label||g._dfltTitle[y];if(u(t,e,r,T,n,{pass:1}),!_)return e;r(\"title.text\",S),a.coerceFont(r,\"title.font\",{family:x.family,size:Math.round(1.2*x.size),color:A}),l(t,e,r,T),u(t,e,r,T,n,{pass:2}),c(t,e,r,n),h(t,e,r,{dfltColor:M,bgColor:n.bgColor,showGrid:n.showGrid,attributes:s}),(e.showline||e.ticks)&&r(\"mirror\"),n.automargin&&r(\"automargin\");var E,C=\"multicategory\"===T;n.noTickson||\"category\"!==T&&!C||!e.ticks&&!e.showgrid||(C&&(E=\"boundaries\"),\"boundaries\"===r(\"tickson\",E)&&delete e.ticklabelposition);C&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));if(\"date\"===T)if(o(t,e,{name:\"rangebreaks\",inclusionAttr:\"enabled\",handleItemDefaults:m}),e.rangebreaks.length){for(var L=0;L<e.rangebreaks.length;L++)if(e.rangebreaks[L].pattern===d){e._hasDayOfWeekBreaks=!0;break}if(p(e,g),g._has(\"scattergl\")||g._has(\"splom\"))for(var I=0;I<n.data.length;I++){var P=n.data[I];\"scattergl\"!==P.type&&\"splom\"!==P.type||(P.visible=!1,a.warn(P.type+\" traces do not work on axes with rangebreaks. Setting trace \"+P.index+\" to `visible: false`.\"))}}else delete e.rangebreaks;return e};var v={sun:1,mon:2,tue:3,wed:4,thu:5,fri:6,sat:7};function y(t){if(\"string\"==typeof t)return v[t.substr(0,3).toLowerCase()]}},{\"../../lib\":778,\"../../registry\":911,\"../array_container_defaults\":823,\"./category_order_defaults\":832,\"./constants\":834,\"./layout_attributes\":842,\"./line_grid_defaults\":844,\"./set_convert\":848,\"./tick_label_defaults\":849,\"./tick_mark_defaults\":850,\"./tick_value_defaults\":851,\"fast-isnumeric\":241}],831:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");function a(t,e){if(e&&e.length)for(var r=0;r<e.length;r++)if(e[r][t])return!0;return!1}r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.split(\" \")[0].substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e,r){var n=/( domain)$/.test(t);if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)&&(!n||r)){var a=t.split(\" \")[0].substr(1).replace(/^0+/,\"\");return\"1\"===a&&(a=\"\"),t.charAt(0)+a+(n&&r?\" domain\":\"\")}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return e=void 0===e||\"string\"!=typeof e?e:e.replace(\" domain\",\"\"),\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.ref2id=function(t){return!!/^[xyz]/.test(t)&&t.split(\" \")[0]},r.isLinked=function(t,e){return a(e,t._axisMatchGroups)||a(e,t._axisConstraintGroups)}},{\"../../registry\":911,\"./constants\":834}],832:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],833:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.ONEDAY,s=a.ONEWEEK;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,a=\"category\"===e,s=i?o:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:a?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r,a%s==0?1:0)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],834:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\",\"( domain)?\"),y:n(\"y\",\"( domain)?\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*( domain)?$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,HOUR_PATTERN:\"hour\",WEEKDAY_PATTERN:\"day of week\",MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"imagelayer\",\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":795}],835:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./autorange\"),a=t(\"./axis_ids\").id2name,o=t(\"./layout_attributes\"),s=t(\"./scale_zoom\"),l=t(\"./set_convert\"),c=t(\"../../constants/numerical\").ALMOST_EQUAL,u=t(\"../../constants/alignment\").FROM_BL;function f(t,e,r){var i=r.axIds,s=r.layoutOut,l=r.hasImage,c=s._axisConstraintGroups,u=s._axisMatchGroups,f=e._id,g=f.charAt(0),m=((s._splomAxes||{})[g]||{})[f]||{},v=e._id,y=\"x\"===v.charAt(0);function x(r,i){return n.coerce(t,e,o,r,i)}e._matchGroup=null,e._constraintGroup=null,x(\"constrain\",l?\"domain\":\"range\"),n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:y?\"center\":\"middle\"}},\"constraintoward\");var b,_,w=e.type,T=[];for(b=0;b<i.length;b++){if((_=i[b])!==v)s[a(_)].type===w&&T.push(_)}var k=p(c,v);if(k){var M=[];for(b=0;b<T.length;b++)k[_=T[b]]||M.push(_);T=M}var A,S,E=T.length;E&&(t.matches||m.matches)&&(A=n.coerce(t,e,{matches:{valType:\"enumerated\",values:T,dflt:-1!==T.indexOf(m.matches)?m.matches:void 0}},\"matches\"));var C=l&&!y?e.anchor:void 0;if(E&&!A&&(t.scaleanchor||C)&&(S=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:T}},\"scaleanchor\",C)),A){e._matchGroup=d(u,v,A,1);var L=s[a(A)],I=h(s,e)/h(s,L);y!==(\"x\"===A.charAt(0))&&(I=(y?\"x\":\"y\")+I),d(c,v,A,I)}else t.matches&&-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid an infinite loop');if(S){var P=x(\"scaleratio\");P||(P=e.scaleratio=1),d(c,v,S,P)}else t.scaleanchor&&-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because this axis declares a *matches* constraint.')}function h(t,e){var r=e.domain;return r||(r=t[a(e.overlaying)].domain),r[1]-r[0]}function p(t,e){for(var r=0;r<t.length;r++)if(t[r][e])return t[r];return null}function d(t,e,r,n){var i,a,o,s,l,c=p(t,e);null===c?((c={})[e]=1,l=t.length,t.push(c)):l=t.indexOf(c);var u=Object.keys(c);for(i=0;i<t.length;i++)if(o=t[i],i!==l&&o[r]){var f=o[r];for(a=0;a<u.length;a++)o[s=u[a]]=g(f,g(n,c[s]));return void t.splice(l,1)}if(1!==n)for(a=0;a<u.length;a++){var h=u[a];c[h]=g(n,c[h])}c[r]=1}function g(t,e){var r,n,i=\"\",a=\"\";\"string\"==typeof t&&(r=(i=t.match(/^[xy]*/)[0]).length,t=+t.substr(r)),\"string\"==typeof e&&(n=(a=e.match(/^[xy]*/)[0]).length,e=+e.substr(n));var o=t*e;return r||n?r&&n&&i.charAt(0)!==a.charAt(0)?r===n?o:(r>n?i.substr(n):a.substr(r))+o:i+a+t*e:o}function m(t,e){for(var r=e._size,n=r.h/r.w,i={},a=Object.keys(t),o=0;o<a.length;o++){var s=a[o],l=t[s];if(\"string\"==typeof l){var c=l.match(/^[xy]*/)[0],u=c.length;l=+l.substr(u);for(var f=\"y\"===c.charAt(0)?n:1/n,h=0;h<u;h++)l*=f}i[s]=l}return i}function v(t,e){var r=t._inputDomain,n=u[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleDefaults=function(t,e,r){var i,o,s,c,u,h,p,d,g=r.axIds,m=r.axHasImage,v=e._axisConstraintGroups=[],y=e._axisMatchGroups=[];for(i=0;i<g.length;i++)f(u=t[c=a(g[i])],h=e[c],{axIds:g,layoutOut:e,hasImage:m[c]});function x(t,r){for(i=0;i<t.length;i++)for(s in o=t[i])e[a(s)][r]=o}for(x(y,\"_matchGroup\"),i=0;i<v.length;i++)for(s in o=v[i])if((h=e[a(s)]).fixedrange){for(var b in o){var _=a(b);!1===(t[_]||{}).fixedrange&&n.warn(\"fixedrange was specified as false for axis \"+_+\" but was overridden because another axis in its constraint group has fixedrange true\"),e[_].fixedrange=!0}break}for(i=0;i<v.length;){for(s in o=v[i]){(h=e[a(s)])._matchGroup&&Object.keys(h._matchGroup).length===Object.keys(o).length&&(v.splice(i,1),i--);break}i++}x(v,\"_constraintGroup\");var w=[\"constrain\",\"range\",\"autorange\",\"rangemode\",\"rangebreaks\",\"categoryorder\",\"categoryarray\"],T=!1,k=!1;function M(){d=h[p],\"rangebreaks\"===p&&(k=h._hasDayOfWeekBreaks)}for(i=0;i<y.length;i++){o=y[i];for(var A=0;A<w.length;A++){var S;for(s in p=w[A],d=null,o)if(u=t[c=a(s)],h=e[c],p in h){if(!h.matches&&(S=h,p in u)){M();break}null===d&&p in u&&M()}if(\"range\"===p&&d&&(T=!0),\"autorange\"===p&&null===d&&T&&(d=!1),null===d&&p in S&&(d=S[p]),null!==d)for(s in o)(h=e[a(s)])[p]=\"range\"===p?d.slice():d,\"rangebreaks\"===p&&(h._hasDayOfWeekBreaks=k,l(h,e))}}},r.enforce=function(t){var e,r,n,o,l,u,f,h,p=t._fullLayout,d=p._axisConstraintGroups||[];for(e=0;e<d.length;e++){n=m(d[e],p);var g=Object.keys(n),y=1/0,x=0,b=1/0,_={},w={},T=!1;for(r=0;r<g.length;r++)w[o=g[r]]=l=p[a(o)],l._inputDomain?l.domain=l._inputDomain.slice():l._inputDomain=l.domain.slice(),l._inputRange||(l._inputRange=l.range.slice()),l.setScale(),_[o]=u=Math.abs(l._m)/n[o],y=Math.min(y,u),\"domain\"!==l.constrain&&l._constraintShrinkable||(b=Math.min(b,u)),delete l._constraintShrinkable,x=Math.max(x,u),\"domain\"===l.constrain&&(T=!0);if(!(y>c*x)||T)for(r=0;r<g.length;r++)if(u=_[o=g[r]],f=(l=w[o]).constrain,u!==b||\"domain\"===f)if(h=u/b,\"range\"===f)s(l,h);else{var k=l._inputDomain,M=(l.domain[1]-l.domain[0])/(k[1]-k[0]),A=(l.r2l(l.range[1])-l.r2l(l.range[0]))/(l.r2l(l._inputRange[1])-l.r2l(l._inputRange[0]));if((h/=M)*A<1){l.domain=l._input.domain=k.slice(),s(l,h);continue}if(A<1&&(l.range=l._input.range=l._inputRange.slice(),h*=A),l.autorange){var S=l.r2l(l.range[0]),E=l.r2l(l.range[1]),C=(S+E)/2,L=C,I=C,P=Math.abs(E-C),z=C-P*h*1.0001,O=C+P*h*1.0001,D=i.makePadFn(p,l,0),R=i.makePadFn(p,l,1);v(l,h);var F,B,N=Math.abs(l._m),j=i.concatExtremes(t,l),U=j.min,V=j.max;for(B=0;B<U.length;B++)(F=U[B].val-D(U[B])/N)>z&&F<L&&(L=F);for(B=0;B<V.length;B++)(F=V[B].val+R(V[B])/N)<O&&F>I&&(I=F);h/=(I-L)/(2*P),L=l.l2r(L),I=l.l2r(I),l.range=l._input.range=S<E?[L,I]:[I,L]}v(l,h)}}},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":745,\"../../constants/numerical\":753,\"../../lib\":778,\"./autorange\":827,\"./axis_ids\":831,\"./layout_attributes\":842,\"./scale_zoom\":846,\"./set_convert\":848}],836:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/color\"),f=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),p=t(\"./axes\"),d=t(\"../../lib/setcursor\"),g=t(\"../../components/dragelement\"),m=t(\"../../components/dragelement/helpers\"),v=m.selectingOrDrawing,y=m.freeMode,x=t(\"../../constants/alignment\").FROM_TL,b=t(\"../../lib/clear_gl_canvases\"),_=t(\"../../plot_api/subroutines\").redrawReglTraces,w=t(\"../plots\"),T=t(\"./axis_ids\").getFromId,k=t(\"./select\").prepSelect,M=t(\"./select\").clearSelect,A=t(\"./select\").selectOnClick,S=t(\"./scale_zoom\"),E=t(\"./constants\"),C=E.MINDRAG,L=E.MINZOOM,I=!0;function P(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,(function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)}));return i.call(d,n),i.node()}function z(t,e,r,i,a,o,s){var l=P(t,\"rect\",e,r);return n.select(l).call(f.setRect,i,a,o,s),l}function O(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function D(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange)if(o.rangebreaks){var s=\"y\"===o._id.charAt(0),l=s?1-e:e,c=s?1-r:r;n[o._name+\".range[0]\"]=o.l2r(o.p2l(l*o._length)),n[o._name+\".range[1]\"]=o.l2r(o.p2l(c*o._length))}else{var u=o._rl[0],f=o._rl[1]-u;n[o._name+\".range[0]\"]=o.l2r(u+f*e),n[o._name+\".range[1]\"]=o.l2r(u+f*r)}}if(i&&i.length){var h=(e+(1-r))/2;D(i,h,1-h,n,[])}}function R(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(!n.fixedrange)if(n.rangebreaks){var i=n._length,a=(n.p2l(0+e)-n.p2l(0)+(n.p2l(i+e)-n.p2l(i)))/2;n.range=[n.l2r(n._rl[0]-a),n.l2r(n._rl[1]-a)]}else n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)]}}function F(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function B(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",l(r,n)).attr(\"d\",i+\"Z\")}function N(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:u.background,stroke:u.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",l(e,r)).attr(\"d\",\"M0,0Z\")}function j(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),U(t,e,i,a)}function U(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function V(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function q(t){I&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),I=!1)}function H(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,L)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function G(t,e,r,n,i){for(var a,o,l,c,u=!1,f={},h={},p=(i||{}).xaHash,d=(i||{}).yaHash,g=0;g<e.length;g++){var m=e[g];for(a in r)if(m[a]){for(l in m)i&&(p[l]||d[l])||(\"x\"===l.charAt(0)?r:n)[l]||(f[l]=a);for(o in n)i&&(p[o]||d[o])||!m[o]||(u=!0)}for(o in n)if(m[o])for(c in m)i&&(p[c]||d[c])||(\"x\"===c.charAt(0)?r:n)[c]||(h[c]=o)}u&&(s.extendFlat(f,h),h={});var v={},y=[];for(l in f){var x=T(t,l);y.push(x),v[x._id]=x}var b={},_=[];for(c in h){var w=T(t,c);_.push(w),b[w._id]=w}return{xaHash:v,yaHash:b,xaxes:y,yaxes:_,xLinks:f,yLinks:h,isSubplotConstrained:u}}function Y(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel?t.onmousewheel=e:t.isAddedWheelEvent||(t.isAddedWheelEvent=!0,t.addEventListener(\"wheel\",e,{passive:!1}))}function W(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,l,u,d,m){var I,P,U,X,Z,J,K,Q,$,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ft,ht,pt,dt=t._fullLayout._zoomlayer,gt=d+m===\"nsew\",mt=1===(d+m).length;function vt(){if(I=e.xaxis,P=e.yaxis,$=I._length,tt=P._length,K=I._offset,Q=P._offset,(U={})[I._id]=I,(X={})[P._id]=P,d&&m)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;U[i._id]=i;var a=r[n].yaxis;X[a._id]=a}Z=W(U),J=W(X),nt=O(Z,m),it=O(J,d),at=!it&&!nt,rt=G(t,t._fullLayout._axisMatchGroups,U,X);var o=(et=G(t,t._fullLayout._axisConstraintGroups,U,X,rt)).isSubplotConstrained||rt.isSubplotConstrained;ot=m||o,st=d||o;var s=t._fullLayout;lt=s._has(\"scattergl\"),ct=s._has(\"splom\"),ut=s._has(\"svg\")}vt();var yt=function(t,e,r){if(!t)return\"pointer\";if(\"nsew\"===t)return r?\"\":\"pan\"===e?\"move\":\"crosshair\";return t.toLowerCase()+\"-resize\"}(it+nt,t._fullLayout.dragmode,gt),xt=z(e,d+m+\"drag\",yt,r,a,l,u);if(at&&!gt)return xt.onmousedown=null,xt.style.pointerEvents=\"none\",xt;var bt,_t,wt,Tt,kt,Mt,At,St,Et,Ct,Lt={element:xt,gd:t,plotinfo:e};function It(){Lt.plotinfo.selection=!1,M(t)}function Pt(t,r){var i=Lt.gd;if(i._fullLayout._activeShapeIndex>=0)i._fullLayout._deactivateShape(i);else{var a=i._fullLayout.clickmode;if(V(i),2!==t||mt||qt(),gt)a.indexOf(\"select\")>-1&&A(r,i,Z,J,e.id,Lt),a.indexOf(\"event\")>-1&&h.click(i,r,e.id);else if(1===t&&mt){var s=d?P:I,l=\"s\"===d||\"w\"===m?0:1,u=s._name+\".range[\"+l+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,l),p=\"left\",g=\"middle\";if(s.fixedrange)return;d?(g=\"n\"===d?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===m&&(p=\"right\"),i._context.showAxisRangeEntryBoxes&&n.select(xt).call(c.makeEditable,{gd:i,immediate:!0,background:i._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:g}).on(\"edit\",(function(t){var e=s.d2r(t);void 0!==e&&o.call(\"_guiRelayout\",i,u,e)}))}}}function zt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,ht*e+bt)),i=Math.max(0,Math.min(tt,pt*r+_t)),a=Math.abs(n-bt),o=Math.abs(i-_t);function s(){At=\"\",wt.r=wt.l,wt.t=wt.b,Et.attr(\"d\",\"M0,0Z\")}if(wt.l=Math.min(bt,n),wt.r=Math.max(bt,n),wt.t=Math.min(_t,i),wt.b=Math.max(_t,i),et.isSubplotConstrained)a>L||o>L?(At=\"xy\",a/$>o/tt?(o=a*tt/$,_t>i?wt.t=_t-o:wt.b=_t+o):(a=o*$/tt,bt>n?wt.l=bt-a:wt.r=bt+a),Et.attr(\"d\",H(wt))):s();else if(rt.isSubplotConstrained)if(a>L||o>L){At=\"xy\";var l=Math.min(wt.l/$,(tt-wt.b)/tt),c=Math.max(wt.r/$,(tt-wt.t)/tt);wt.l=l*$,wt.r=c*$,wt.b=(1-l)*tt,wt.t=(1-c)*tt,Et.attr(\"d\",H(wt))}else s();else!it||o<Math.min(Math.max(.6*a,C),L)?a<C||!nt?s():(wt.t=0,wt.b=tt,At=\"x\",Et.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-L-.5)+\"h-3v\"+(2*L+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-L-.5)+\"h3v\"+(2*L+1)+\"h-3Z\"}(wt,_t))):!nt||a<Math.min(.6*o,L)?(wt.l=0,wt.r=$,At=\"y\",Et.attr(\"d\",function(t,e){return\"M\"+(e-L-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*L+1)+\"v3ZM\"+(e-L-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*L+1)+\"v-3Z\"}(wt,bt))):(At=\"xy\",Et.attr(\"d\",H(wt)));wt.w=wt.r-wt.l,wt.h=wt.b-wt.t,At&&(Ct=!0),t._dragged=Ct,j(St,Et,wt,kt,Mt,Tt),Ot(),t.emit(\"plotly_relayouting\",ft),Mt=!0}function Ot(){ft={},\"xy\"!==At&&\"x\"!==At||(D(Z,wt.l/$,wt.r/$,ft,et.xaxes),Ut(\"x\",ft)),\"xy\"!==At&&\"y\"!==At||(D(J,(tt-wt.b)/tt,(tt-wt.t)/tt,ft,et.yaxes),Ut(\"y\",ft))}function Dt(){Ot(),V(t),Ht(),q(t)}Lt.prepFn=function(e,r,n){var a=Lt.dragmode,o=t._fullLayout.dragmode;o!==a&&(Lt.dragmode=o),vt(),ht=t._fullLayout._invScaleX,pt=t._fullLayout._invScaleY,at||(gt?e.shiftKey?\"pan\"===o?o=\"zoom\":v(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),y(o)?Lt.minDrag=1:Lt.minDrag=void 0,v(o)?(Lt.xaxes=Z,Lt.yaxes=J,k(e,r,n,Lt,o)):(Lt.clickFn=Pt,v(a)&&It(),at||(\"zoom\"===o?(Lt.moveFn=zt,Lt.doneFn=Dt,Lt.minDrag=1,function(e,r,n){var a=xt.getBoundingClientRect();bt=r-a.left,_t=n-a.top,t._fullLayout._calcInverseTransform(t);var o=s.apply3DTransform(t._fullLayout._invTransform)(bt,_t);bt=o[0],_t=o[1],wt={l:bt,r:bt,w:0,t:_t,b:_t,h:0},Tt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),Mt=!1,At=\"xy\",Ct=!1,St=B(dt,Tt,K,Q,kt=\"M0,0H\"+$+\"V\"+tt+\"H0V0\"),Et=N(dt,K,Q)}(0,r,n)):\"pan\"===o&&(Lt.moveFn=jt,Lt.doneFn=Ht))),t._fullLayout._redrag=function(){var e=t._dragdata;if(e&&e.element===xt){var r=t._fullLayout.dragmode;v(r)||(vt(),Gt([0,0,$,tt]),Lt.moveFn(e.dx,e.dy))}}},g.init(Lt);var Rt=[0,0,$,tt],Ft=null,Bt=E.REDRAWDELAY,Nt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function jt(e,r){if(e*=ht,r*=pt,!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===nt||\"ns\"===it){var n=nt?-e:0,i=it?-r:0;if(rt.isSubplotConstrained){if(nt&&it){var a=(e/$-r/tt)/2;n=-(e=a*$),i=-(r=-a*tt)}it?n=-i*$/tt:i=-n*tt/$}return nt&&(R(Z,e),Ut(\"x\")),it&&(R(J,r),Ut(\"y\")),Gt([n,i,$,tt]),Vt(),void t.emit(\"plotly_relayouting\",ft)}var o,s,l=\"w\"===nt==(\"n\"===it)?1:-1;if(nt&&it&&(et.isSubplotConstrained||rt.isSubplotConstrained)){var c=(e/$+l*r/tt)/2;e=c*$,r=l*c*tt}if(\"w\"===nt?e=p(Z,0,e):\"e\"===nt?e=p(Z,1,-e):nt||(e=0),\"n\"===it?r=p(J,1,r):\"s\"===it?r=p(J,0,-r):it||(r=0),o=\"w\"===nt?e:0,s=\"n\"===it?r:0,et.isSubplotConstrained&&!rt.isSubplotConstrained||rt.isSubplotConstrained&&nt&&it&&l>0){var u;if(rt.isSubplotConstrained||!nt&&1===it.length){for(u=0;u<Z.length;u++)Z[u].range=Z[u]._r.slice(),S(Z[u],1-r/tt);o=(e=r*$/tt)/2}if(rt.isSubplotConstrained||!it&&1===nt.length){for(u=0;u<J.length;u++)J[u].range=J[u]._r.slice(),S(J[u],1-e/$);s=(r=e*tt/$)/2}}rt.isSubplotConstrained&&it||Ut(\"x\"),rt.isSubplotConstrained&&nt||Ut(\"y\");var f=$-e,h=tt-r;!rt.isSubplotConstrained||nt&&it||(nt?(s=o?0:e*tt/$,h=f*tt/$):(o=s?0:r*$/tt,f=h*$/tt)),Gt([o,s,f,h]),Vt(),t.emit(\"plotly_relayouting\",ft)}function p(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/F(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Ut(t,e){for(var r=rt.isSubplotConstrained?{x:J,y:Z}[t]:rt[t+\"axes\"],n=rt.isSubplotConstrained?{x:Z,y:J}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=rt.xLinks[o]||rt.yLinks[o],l=n[0]||U[s]||X[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Vt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(ot&&(n(Z),n(et.xaxes),n(rt.xaxes)),st&&(n(J),n(et.yaxes),n(rt.yaxes)),ft={},e=0;e<r.length;e++){var i=r[e],a=T(t,i);p.drawOne(t,a,{skipTitle:!0}),ft[a._name+\".range[0]\"]=a.range[0],ft[a._name+\".range[1]\"]=a.range[1]}p.redrawComponents(t,r)}function qt(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];nt&&(r=r.concat(Z)),it&&(r=r.concat(J)),rt.xaxes&&(r=r.concat(rt.xaxes)),rt.yaxes&&(r=r.concat(rt.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((nt||et.isSubplotConstrained)&&(r=r.concat(et.xaxes)),it&&!et.isSubplotConstrained&&(r=r.concat(et.yaxes)),et.isSubplotConstrained&&(nt?it||(r=r.concat(J)):r=r.concat(Z)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}function Ht(){Gt([0,0,$,tt]),s.syncOrAsync([w.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ft)}],t)}function Gt(e){var r,n,i,a,l=t._fullLayout,c=l._plots,u=l._subplots.cartesian;if(ct&&o.subplotsRegistry.splom.drag(t),lt)for(r=0;r<u.length;r++)if(i=(n=c[u[r]]).xaxis,a=n.yaxis,n._scene){var h=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[h[0],p[0],h[1],p[1]]})}if((ct||lt)&&(b(t),_(t)),ut){var g=e[2]/I._length,v=e[3]/P._length;for(r=0;r<u.length;r++){i=(n=c[u[r]]).xaxis,a=n.yaxis;var y,x,w,T,k=(ot||rt.isSubplotConstrained)&&!i.fixedrange&&U[i._id],M=(st||rt.isSubplotConstrained)&&!a.fixedrange&&X[a._id];if(k?(y=g,w=m||rt.isSubplotConstrained?e[0]:Xt(i,y)):rt.xaHash[i._id]?(y=g,w=e[0]*i._length/I._length):rt.yaHash[i._id]?(y=v,w=\"ns\"===it?-e[1]*i._length/P._length:Xt(i,y,{n:\"top\",s:\"bottom\"}[it])):w=Wt(i,y=Yt(i,g,v)),M?(x=v,T=d||rt.isSubplotConstrained?e[1]:Xt(a,x)):rt.yaHash[a._id]?(x=v,T=e[1]*a._length/P._length):rt.xaHash[a._id]?(x=g,T=\"ew\"===nt?-e[0]*a._length/I._length:Xt(a,x,{e:\"right\",w:\"left\"}[nt])):T=Wt(a,x=Yt(a,g,v)),y||x){y||(y=1),x||(x=1);var A=i._offset-w/y,S=a._offset-T/x;n.clipRect.call(f.setTranslate,w,T).call(f.setScale,y,x),n.plot.call(f.setTranslate,A,S).call(f.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(f.setPointGroupScale(n.zoomScalePts,y,x),f.setTextPointsScale(n.zoomScaleTxt,y,x)),f.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Yt(t,e,r){return t.fixedrange?0:ot&&et.xaHash[t._id]?e:st&&(et.isSubplotConstrained?et.xaHash:et.yaHash)[t._id]?r:0}function Wt(t,e){return e?(t.range=t._r.slice(),S(t,e),Xt(t,e)):0}function Xt(t,e,r){return t._length*(1-e)*x[r||t.constraintoward||\"middle\"]}return d.length*m.length!=1&&Y(xt,(function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(It(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();vt(),clearTimeout(Ft);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Nt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(ot){for(m||(o=.5),n=0;n<Z.length;n++)c(Z[n],o,i);Ut(\"x\"),Rt[2]*=i,Rt[0]+=Rt[2]*o*(1/i-1)}if(st){for(d||(l=.5),n=0;n<J.length;n++)c(J[n],l,i);Ut(\"y\"),Rt[3]*=i,Rt[1]+=Rt[3]*(1-l)*(1/i-1)}Gt(Rt),Vt(),t.emit(\"plotly_relayouting\",ft),Ft=setTimeout((function(){Rt=[0,0,$,tt],Ht()}),Bt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map((function(e){return t.l2r(i+(e-i)*r)}))}}})),xt},makeDragger:P,makeRectDragger:z,makeZoombox:B,makeCorners:N,updateZoombox:j,xyCorners:H,transitionZoombox:U,removeZoombox:V,showDoubleClickNotifier:q,attachWheelEventHandler:Y}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plot_api/subroutines\":818,\"../../registry\":911,\"../plots\":891,\"./axes\":828,\"./axis_ids\":831,\"./constants\":834,\"./scale_zoom\":846,\"./select\":847,d3:169,\"has-passive-events\":441,tinycolor2:576}],837:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort((function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1})).forEach((function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&t._fullLayout._plots[r]&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var f=o._mainLinePosition;\"top\"===o.side&&(f-=l),s(t,n,o._offset+.1*o._length,f,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,f,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,f,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var h=c._mainLinePosition;\"right\"!==c.side&&(h-=l),s(t,n,h,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,h,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,h,c._offset,l,.1*c._length,\"n\",\"\")}}}));var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":662,\"../../components/fx\":683,\"../../lib/setcursor\":799,\"./constants\":834,\"./dragbox\":836,d3:169}],838:[function(t,e,r){\"use strict\";e.exports={clearOutlineControllers:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".outline-controllers\").remove()},clearSelect:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".select-outline\").remove(),t._fullLayout._drawing=!1}}},{}],839:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").strTranslate;function i(t,e){switch(t.type){case\"log\":return t.p2d(e);case\"date\":return t.p2r(e,0,t.calendar);default:return t.p2r(e)}}e.exports={p2r:i,r2p:function(t,e){switch(t.type){case\"log\":return t.d2p(e);case\"date\":return t.r2p(e,0,t.calendar);default:return t.r2p(e)}},axValue:function(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return i(t,r[e])}},getTransform:function(t){return n(t.xaxis._offset,t.yaxis._offset)}}},{\"../../lib\":778}],840:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./axis_ids\");e.exports=function(t){return function(e,r){var o=e[t];if(Array.isArray(o))for(var s=n.subplotsRegistry.cartesian,l=s.idRegex,c=r._subplots,u=c.xaxis,f=c.yaxis,h=c.cartesian,p=r._has(\"cartesian\")||r._has(\"gl2d\"),d=0;d<o.length;d++){var g=o[d];if(i.isPlainObject(g)){var m=a.cleanId(g.xref,\"x\",!1),v=a.cleanId(g.yref,\"y\",!1),y=l.x.test(m),x=l.y.test(v);if(y||x){p||i.pushUnique(r._basePlotModules,s);var b=!1;y&&-1===u.indexOf(m)&&(u.push(m),b=!0),x&&-1===f.indexOf(v)&&(f.push(v),b=!0),b&&y&&x&&h.push(m+v)}}}}}},{\"../../lib\":778,\"../../registry\":911,\"./axis_ids\":831}],841:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),f=t(\"../../constants/xmlns_namespaces\"),h=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,(function(t){t.datum(r)}))}function d(t,e,r,a,o){for(var c,f,h,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,m=[],v=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;h=(f=l(r,w))[0],r=f[1],h.length&&m.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:h}),b.zoomScale&&v.push(\".\"+_)}}m.sort((function(t,e){return t.i-e.i}));var T=e.plot.selectAll(\"g.mlayer\").data(m,(function(t){return t.className}));if(T.enter().append(\"g\").attr(\"class\",(function(t){return t.className})).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),T.exit().remove(),T.order(),T.each((function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)})),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),h=l(r,c)[0],c.plot(t,e,h)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),v.length)){var k=e.plot.selectAll(v.join(\",\")).selectAll(\".trace\");e.zoomScalePts=k.selectAll(\"path.point\"),e.zoomScaleTxt=k.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,f=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,h(s.overlinesBelow,\"path\",f),h(s.overlinesBelow,\"path\",d),h(s.overaxesBelow,\"g\",f),h(s.overaxesBelow,\"g\",d),e.plot=h(s.overplot,\"g\",n),h(s.overlinesAbove,\"path\",f),h(s.overlinesAbove,\"path\",d),h(s.overaxesAbove,\"g\",f),h(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+f),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+f),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.xaxislayer=h(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=h(r,\"g\",\"yaxislayer-above\");else{var g=h(r,\"g\",\"layer-subplot\");e.shapelayer=h(g,\"g\",\"shapelayer\"),e.imagelayer=h(g,\"g\",\"imagelayer\"),e.gridlayer=h(r,\"g\",\"gridlayer\"),e.zerolinelayer=h(r,\"g\",\"zerolinelayer\"),h(r,\"path\",\"xlines-below\"),h(r,\"path\",\"ylines-below\"),e.overlinesBelow=h(r,\"g\",\"overlines-below\"),h(r,\"g\",\"xaxislayer-below\"),h(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=h(r,\"g\",\"overaxes-below\"),e.plot=h(r,\"g\",\"plot\"),e.overplot=h(r,\"g\",\"overplot\"),e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.overlinesAbove=h(r,\"g\",\"overlines-above\"),h(r,\"g\",\"xaxislayer-above\"),h(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=h(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map((function(t){return t[0]})).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function m(t,e){if(t){var r={};for(var i in t.each((function(t){var i=t[0];n.select(this).remove(),v(i,e),r[i]=!0})),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function v(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,f=o.cartesian,h=f.concat(o.gl2d||[]),p={},d={};for(r=0;r<h.length;r++){var g=h[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),f.push(n+i),h.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),f.push(n+i),h.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!h.length){for(var m in n=\"\",i=\"\",t){if(u.attrRegex.test(m))\"x\"===m.charAt(0)?(!n||+m.substr(5)<+n.substr(5))&&(n=m):(!i||+m.substr(5)<+i.substr(5))&&(i=m)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),f.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],f=[],h=0;h<s.length;h++){var p=s[h],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===f.indexOf(l)&&f.push(l),f.push(p)),l=p)}d(t,u,f,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var f=n._has&&n._has(\"gl\"),h=e._has&&e._has(\"gl\");if(f&&!h)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)m(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups,delete n._axisMatchGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),v(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],f=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var h=a._mainAxis,p=o._mainAxis,d=h._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,f.push(n)):(i.mainplot=void 0,i.mainplotinfo=void 0,u.push(n))}for(e=0;e<f.length;e++)n=f[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var m=u.concat(f),v=new Array(c);for(e=0;e<c;e++){n=m[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);v[e]=y}return v}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",(function(t){return\"subplot \"+t[0]})),i.order(),i.exit().call(m,e),i.each((function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=h(e._draggers,\"g\",i)}))},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:f.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}))},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":665,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../registry\":911,\"../get_data\":865,\"../plots\":891,\"./attributes\":826,\"./axis_ids\":831,\"./constants\":834,\"./graph_interact\":837,\"./layout_attributes\":842,\"./layout_defaults\":843,\"./transition_axes\":852,d3:169}],842:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"../../constants/numerical\").ONEDAY),c=t(\"./constants\"),u=c.HOUR_PATTERN,f=c.WEEKDAY_PATTERN;e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),standoff:{valType:\"number\",min:0,editType:\"ticks\"},editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"calc\"},rangebreaks:s(\"rangebreak\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},bounds:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},pattern:{valType:\"enumerated\",values:[f,u,\"\"],editType:\"calc\"},values:{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"any\",editType:\"calc\"}},dvalue:{valType:\"number\",editType:\"calc\",min:0,dflt:l},editType:\"calc\"}),tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},ticklabelmode:{valType:\"enumerated\",values:[\"instant\",\"period\"],dflt:\"instant\",editType:\"ticks\"},ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside left\",\"inside left\",\"outside right\",\"inside right\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\",editType:\"calc\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\",\"hovered data\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":642,\"../../components/drawing/attributes\":664,\"../../constants/docs\":748,\"../../constants/numerical\":753,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../font_attributes\":856,\"./constants\":834}],843:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../components/fx/helpers\").isUnifiedHover,o=t(\"../../components/fx/hovermode_defaults\"),s=t(\"../../plot_api/plot_template\"),l=t(\"../layout_attributes\"),c=t(\"./layout_attributes\"),u=t(\"./type_defaults\"),f=t(\"./axis_defaults\"),h=t(\"./constraints\"),p=t(\"./position_defaults\"),d=t(\"./axis_ids\"),g=d.id2name,m=d.name2id,v=t(\"./constants\").AX_ID_PATTERN,y=t(\"../../registry\"),x=y.traceIs,b=y.getComponentMethod;function _(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var y,w,T=e.autotypenumbers,k={},M={},A={},S={},E={},C={},L={},I={},P={},z={};for(y=0;y<r.length;y++){var O=r[y];if(x(O,\"cartesian\")||x(O,\"gl2d\")){var D,R;if(O.xaxis)D=g(O.xaxis),_(k,D,O);else if(O.xaxes)for(w=0;w<O.xaxes.length;w++)_(k,g(O.xaxes[w]),O);if(O.yaxis)R=g(O.yaxis),_(k,R,O);else if(O.yaxes)for(w=0;w<O.yaxes.length;w++)_(k,g(O.yaxes[w]),O);if(\"funnel\"===O.type?\"h\"===O.orientation?(D&&(M[D]=!0),R&&(L[R]=!0)):R&&(A[R]=!0):\"image\"===O.type?(R&&(I[R]=!0),D&&(I[D]=!0)):(R&&(E[R]=!0,C[R]=!0),x(O,\"carpet\")&&(\"carpet\"!==O.type||O._cheater)||D&&(S[D]=!0)),\"carpet\"===O.type&&O._cheater&&D&&(M[D]=!0),x(O,\"2dMap\")&&(P[D]=!0,P[R]=!0),x(O,\"oriented\"))z[\"h\"===O.orientation?R:D]=!0}}var F=e._subplots,B=F.xaxis,N=F.yaxis,j=n.simpleMap(B,g),U=n.simpleMap(N,g),V=j.concat(U),q=i.background;B.length&&N.length&&(q=n.coerce(t,e,l,\"plot_bgcolor\"));var H,G,Y,W,X,Z=i.combine(q,e.paper_bgcolor);function J(){var t=k[H]||[];X._traceIndices=t.map((function(t){return t._expandedIndex})),X._annIndices=[],X._shapeIndices=[],X._imgIndices=[],X._subplotsWith=[],X._counterAxes=[],X._name=X._attr=H,X._id=G}function K(t,e){return n.coerce(W,X,c,t,e)}function Q(t,e){return n.coerce2(W,X,c,t,e)}function $(t){return\"x\"===t?N:B}function tt(e,r){for(var n=\"x\"===e?j:U,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(m(o))}return i}var et={x:$(\"x\"),y:$(\"y\")},rt=et.x.concat(et.y),nt={},it=[];function at(){var t=W.matches;v.test(t)&&-1===rt.indexOf(t)&&(nt[t]=W.type,it=Object.keys(nt))}var ot=o(t,e,r),st=a(ot);for(y=0;y<V.length;y++){H=V[y],G=m(H),Y=H.charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var lt=\"x\"===Y&&!S[H]&&M[H]||\"y\"===Y&&!E[H]&&A[H],ct=\"y\"===Y&&(!C[H]&&L[H]||I[H]),ut={letter:Y,font:e.font,outerTicks:P[H],showGrid:!z[H],data:k[H]||[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:lt,reverseDflt:ct,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),u(W,X,K,ut),f(W,X,K,ut,e);var ft=st&&Y===ot.charAt(0),ht=Q(\"spikecolor\",st?X.color:void 0),pt=Q(\"spikethickness\",st?1.5:void 0),dt=Q(\"spikedash\",st?\"dot\":void 0),gt=Q(\"spikemode\",st?\"across\":void 0),mt=Q(\"spikesnap\",st?\"hovered data\":void 0);K(\"showspikes\",!!(ft||ht||pt||dt||gt||mt))||(delete X.spikecolor,delete X.spikethickness,delete X.spikedash,delete X.spikemode,delete X.spikesnap),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"title.standoff\"),at(),X._input=W}for(y=0;y<it.length;){G=it[y++],Y=(H=g(G)).charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var vt={letter:Y,font:e.font,outerTicks:P[H],showGrid:!z[H],data:[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:!1,reverseDflt:!1,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),X.type=nt[G]||\"linear\",f(W,X,K,vt,e),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"fixedrange\"),at(),X._input=W}var yt=b(\"rangeslider\",\"handleDefaults\"),xt=b(\"rangeselector\",\"handleDefaults\");for(y=0;y<j.length;y++)H=j[y],W=t[H],X=e[H],yt(t,e,H),\"date\"===X.type&&xt(W,X,e,U,X.calendar),K(\"fixedrange\");for(y=0;y<U.length;y++){H=U[y],W=t[H],X=e[H];var bt=e[g(X.anchor)];K(\"fixedrange\",b(\"rangeslider\",\"isVisible\")(bt))}h.handleDefaults(t,e,{axIds:rt.concat(it).sort(d.idSort),axHasImage:I})}},{\"../../components/color\":643,\"../../components/fx/helpers\":679,\"../../components/fx/hovermode_defaults\":682,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911,\"../layout_attributes\":882,\"./axis_defaults\":830,\"./axis_ids\":831,\"./constants\":834,\"./constraints\":835,\"./layout_attributes\":842,\"./position_defaults\":845,\"./type_defaults\":853}],844:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var f=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),h=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!f||!!h)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":642,\"../../lib\":778,tinycolor2:576}],845:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],f=a.overlayableAxes||[],h=a.letter,p=a.grid;p&&(s=p._domains[h][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[h+\"side\"].split(\" \")[0],c=p.domain[h][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===h?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===h?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(f.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(f),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":778,\"fast-isnumeric\":241}],846:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)],t.setScale()}},{\"../../constants/alignment\":745}],847:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\").dashStyle,o=t(\"../../components/color\"),s=t(\"../../components/fx\"),l=t(\"../../components/fx/helpers\").makeEventData,c=t(\"../../components/dragelement/helpers\"),u=c.freeMode,f=c.rectMode,h=c.drawMode,p=c.openMode,d=c.selectMode,g=t(\"../../components/shapes/draw_newshape/display_outlines\"),m=t(\"../../components/shapes/draw_newshape/helpers\").handleEllipse,v=t(\"../../components/shapes/draw_newshape/newshapes\"),y=t(\"../../lib\"),x=t(\"../../lib/polygon\"),b=t(\"../../lib/throttle\"),_=t(\"./axis_ids\").getFromId,w=t(\"../../lib/clear_gl_canvases\"),T=t(\"../../plot_api/subroutines\").redrawReglTraces,k=t(\"./constants\"),M=k.MINSELECT,A=x.filter,S=x.tester,E=t(\"./handle_outline\").clearSelect,C=t(\"./helpers\"),L=C.p2r,I=C.axValue,P=C.getTransform;function z(t,e,r,n,i,a,o){var s,l,c,u,f,h,d,m,v,y=e._hoverdata,x=e._fullLayout.clickmode.indexOf(\"event\")>-1,b=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(y)){F(t,e,a);var _=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(y,s=N(e,r,n,i));if(_.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,_):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(h=j(_))){for(o&&o.remove(),v=0;v<s.length;v++)(l=s[v])._module.selectPoints(l,!1);U(e,s),B(a),x&&e.emit(\"plotly_deselect\",null)}else{for(d=t.shiftKey&&(void 0!==h?h:j(_)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(_.pointNumber,_.searchInfo,d),u=R(a.selectionDefs.concat([c])),v=0;v<s.length;v++)if(f=V(s[v]._module.selectPoints(s[v],u),s[v]),b.length)for(var w=0;w<f.length;w++)b.push(f[w]);else b=f;if(U(e,s,m={points:b}),c&&a&&a.selectionDefs.push(c),o){var T=a.mergedPolygons,k=p(a.dragmode);g(q(T,k),o,a)}x&&e.emit(\"plotly_selected\",m)}}}function O(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function D(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function R(t){for(var e=[],r=O(t[0])?0:t[0][0][0],n=r,i=O(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(O(t[o]))e.push(D(t[o]));else{var s=x.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function F(t,e,r){e._fullLayout._drawing=!1;var n=e._fullLayout,i=r.plotinfo,a=r.dragmode,o=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,s=(t.shiftKey||t.altKey)&&!(h(a)&&p(a));o&&s&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):s&&i.selection||B(r),o||(E(e),n._lastSelectedSubplot=i.id)}function B(t){var e=t.dragmode,r=t.plotinfo,n=t.gd;if(n._fullLayout._activeShapeIndex>=0&&n._fullLayout._deactivateShape(n),h(e)){var a=n._fullLayout._zoomlayer.selectAll(\".select-outline-\"+r.id);if(a&&n._fullLayout._drawing){var o=v(a,t);o&&i.call(\"_guiRelayout\",n,{shapes:o}),n._fullLayout._drawing=!1}}r.selection={},r.selection.selectionDefs=t.selectionDefs=[],r.selection.mergedPolygons=t.mergedPolygons=[]}function N(t,e,r,n){var i,a,o,s=[],l=e.map((function(t){return t._id})),c=r.map((function(t){return t._id}));for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=h(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=h(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(h(a._module,i,_(t,a.xaxis),_(t,a.yaxis)))}else s.push(h(a._module,i,e[0],r[0]));return s;function h(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function j(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function U(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var f=u[n],h=f.data,p=f.fullData;f.pointIndices?([].push.apply(h.selectedpoints,f.pointIndices),s._fullInput!==s&&[].push.apply(p.selectedpoints,f.pointIndices)):(h.selectedpoints.push(f.pointIndex),s._fullInput!==s&&p.selectedpoints.push(f.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var d=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(d=!0);var g=a._module,m=g.styleOnSelect||g.style;m&&(m(t,o,o[0].node3),o[0].nodeRangePlot3&&m(t,o,o[0].nodeRangePlot3))}d&&(w(t),T(t))}function V(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=l(t[i],n,r);return t}function q(t,e){for(var r=[],n=0;n<t.length;n++){r[n]=[];for(var i=0;i<t[n].length;i++){r[n][i]=[],r[n][i][0]=i?\"L\":\"M\";for(var a=0;a<t[n][i].length;a++)r[n][i].push(t[n][i][a])}e||r[n].push([\"Z\",r[n][0][1],r[n][0][2]])}return r}e.exports={prepSelect:function(t,e,r,i,l){var c=u(l),v=f(l),x=p(l),_=h(l),w=d(l),T=\"drawcircle\"===l,E=\"drawline\"===l||T,C=i.gd,O=C._fullLayout,D=O._zoomlayer,j=i.element.getBoundingClientRect(),H=i.plotinfo,G=P(H),Y=e-j.left,W=r-j.top;O._calcInverseTransform(C);var X=y.apply3DTransform(O._invTransform)(Y,W);Y=X[0],W=X[1];var Z,J,K,Q,$,tt,et,rt=O._invScaleX,nt=O._invScaleY,it=Y,at=W,ot=\"M\"+Y+\",\"+W,st=i.xaxes[0]._length,lt=i.yaxes[0]._length,ct=i.xaxes.concat(i.yaxes),ut=t.altKey&&!(h(l)&&x);F(t,C,i),c&&(Z=A([[Y,W]],k.BENDPX));var ft=D.selectAll(\"path.select-outline-\"+H.id).data(_?[0]:[1,2]),ht=O.newshape;ft.enter().append(\"path\").attr(\"class\",(function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+H.id})).style(_?{opacity:ht.opacity/2,fill:x?void 0:ht.fillcolor,stroke:ht.line.color,\"stroke-dasharray\":a(ht.line.dash,ht.line.width),\"stroke-width\":ht.line.width+\"px\"}:{}).attr(\"fill-rule\",ht.fillrule).classed(\"cursor-move\",!!_).attr(\"transform\",G).attr(\"d\",ot+\"Z\");var pt,dt=D.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:o.background,stroke:o.defaultLine,\"stroke-width\":1}).attr(\"transform\",G).attr(\"d\",\"M0,0Z\"),gt=O._uid+k.SELECTID,mt=[],vt=N(C,i.xaxes,i.yaxes,i.subplot);function yt(t,e){return t-e}pt=H.fillRangeItems?H.fillRangeItems:v?function(t,e){var r=t.range={};for($=0;$<ct.length;$++){var n=ct[$],i=n._id.charAt(0);r[n._id]=[L(n,e[i+\"min\"]),L(n,e[i+\"max\"])].sort(yt)}}:function(t,e,r){var n=t.lassoPoints={};for($=0;$<ct.length;$++){var i=ct[$];n[i._id]=r.filtered.map(I(i))}},i.moveFn=function(t,e){it=Math.max(0,Math.min(st,rt*t+Y)),at=Math.max(0,Math.min(lt,nt*e+W));var r=Math.abs(it-Y),a=Math.abs(at-W);if(v){var o,s,l;if(w){var u=O.selectdirection;switch(o=\"any\"===u?a<Math.min(.6*r,M)?\"h\":r<Math.min(.6*a,M)?\"v\":\"d\":u){case\"h\":s=T?lt/2:0,l=lt;break;case\"v\":s=T?st/2:0,l=st}}if(_)switch(O.newshape.drawdirection){case\"vertical\":o=\"h\",s=T?lt/2:0,l=lt;break;case\"horizontal\":o=\"v\",s=T?st/2:0,l=st;break;case\"ortho\":r<a?(o=\"h\",s=W,l=at):(o=\"v\",s=Y,l=it);break;default:o=\"d\"}\"h\"===o?((Q=E?m(T,[it,s],[it,l]):[[Y,s],[Y,l],[it,l],[it,s]]).xmin=E?it:Math.min(Y,it),Q.xmax=E?it:Math.max(Y,it),Q.ymin=Math.min(s,l),Q.ymax=Math.max(s,l),dt.attr(\"d\",\"M\"+Q.xmin+\",\"+(W-M)+\"h-4v\"+2*M+\"h4ZM\"+(Q.xmax-1)+\",\"+(W-M)+\"h4v\"+2*M+\"h-4Z\")):\"v\"===o?((Q=E?m(T,[s,at],[l,at]):[[s,W],[s,at],[l,at],[l,W]]).xmin=Math.min(s,l),Q.xmax=Math.max(s,l),Q.ymin=E?at:Math.min(W,at),Q.ymax=E?at:Math.max(W,at),dt.attr(\"d\",\"M\"+(Y-M)+\",\"+Q.ymin+\"v-4h\"+2*M+\"v4ZM\"+(Y-M)+\",\"+(Q.ymax-1)+\"v4h\"+2*M+\"v-4Z\")):\"d\"===o&&((Q=E?m(T,[Y,W],[it,at]):[[Y,W],[Y,at],[it,at],[it,W]]).xmin=Math.min(Y,it),Q.xmax=Math.max(Y,it),Q.ymin=Math.min(W,at),Q.ymax=Math.max(W,at),dt.attr(\"d\",\"M0,0Z\"))}else c&&(Z.addPt([it,at]),Q=Z.filtered);i.selectionDefs&&i.selectionDefs.length?(K=function(t,e,r){if(r)return n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions;return n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,Q,ut),Q.subtract=ut,J=R(i.selectionDefs.concat([Q]))):(K=[Q],J=S(Q)),g(q(K,x),ft,i),w&&b.throttle(gt,k.SELECTDELAY,(function(){var t;mt=[];var e,r=[];for($=0;$<vt.length;$++)if(e=(tt=vt[$])._module.selectPoints(tt,J),r.push(e),t=V(e,tt),mt.length)for(var n=0;n<t.length;n++)mt.push(t[n]);else mt=t;U(C,vt,et={points:mt}),pt(et,Q,Z),i.gd.emit(\"plotly_selecting\",et)}))},i.clickFn=function(t,e){if(dt.remove(),C._fullLayout._activeShapeIndex>=0)C._fullLayout._deactivateShape(C);else if(!_){var r=O.clickmode;b.done(gt).then((function(){if(b.clear(gt),2===t){for(ft.remove(),$=0;$<vt.length;$++)(tt=vt[$])._module.selectPoints(tt,!1);U(C,vt),B(i),C.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&z(e,C,i.xaxes,i.yaxes,i.subplot,i,ft),\"event\"===r&&C.emit(\"plotly_selected\",void 0);s.click(C,e)})).catch(y.error)}},i.doneFn=function(){dt.remove(),b.done(gt).then((function(){b.clear(gt),i.gd.emit(\"plotly_selected\",et),Q&&i.selectionDefs&&(Q.subtract=ut,i.selectionDefs.push(Q),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,K)),i.doneFnCompleted&&i.doneFnCompleted(mt)})).catch(y.error),_&&B(i)}},clearSelect:E,clearSelectionsCache:B,selectOnClick:z}},{\"../../components/color\":643,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/fx/helpers\":679,\"../../components/shapes/draw_newshape/display_outlines\":728,\"../../components/shapes/draw_newshape/helpers\":729,\"../../components/shapes/draw_newshape/newshapes\":730,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/polygon\":790,\"../../lib/throttle\":804,\"../../plot_api/subroutines\":818,\"../../registry\":911,\"./axis_ids\":831,\"./constants\":834,\"./handle_outline\":838,\"./helpers\":839,polybooljs:517}],848:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=o.cleanNumber,l=o.ms2DateTime,c=o.dateTime2ms,u=o.ensureNumber,f=o.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),p=h.FP_SAFE,d=h.BADNUM,g=h.LOG_CLIP,m=h.ONEWEEK,v=h.ONEDAY,y=h.ONEHOUR,x=h.ONEMIN,b=h.ONESEC,_=t(\"./axis_ids\"),w=t(\"./constants\"),T=w.HOUR_PATTERN,k=w.WEEKDAY_PATTERN;function M(t){return Math.pow(10,t)}function A(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function S(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*g*Math.abs(n-i))}return d}function E(e,r,n,i){if((i||{}).msUTC&&a(e))return+e;var s=c(e,n||t.calendar);if(s===d){if(!a(e))return d;e=+e;var l=Math.floor(10*o.mod(e+.05,1)),u=Math.round(e-l/10);s=c(new Date(u))+l/10}return s}function C(e,r,n){return l(e,r,n||t.calendar)}function L(e){return t._categories[Math.round(e)]}function I(e){if(A(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return d}function P(e){if(t._categoriesMap)return t._categoriesMap[e]}function z(t){var e=P(t);return void 0!==e?e:a(t)?+t:void 0}function O(t){return a(t)?+t:P(t)}function D(t,e,r){return n.round(r+e*t,2)}function R(t,e,r){return(t-r)/e}var F=function(e){return a(e)?D(e,t._m,t._b):d},B=function(e){return R(e,t._m,t._b)};if(t.rangebreaks){var N=\"y\"===h;F=function(e){if(!a(e))return d;var r=t._rangebreaks.length;if(!r)return D(e,t._m,t._b);var n=N;t.range[0]>t.range[1]&&(n=!n);for(var i=n?-1:1,o=i*e,s=0,l=0;l<r;l++){var c=i*t._rangebreaks[l].min,u=i*t._rangebreaks[l].max;if(o<c)break;if(!(o>u)){s=o<(c+u)/2?l:l+1;break}s=l+1}var f=t._B[s]||0;return isFinite(f)?D(e,t._m2,f):0},B=function(e){var r=t._rangebreaks.length;if(!r)return R(e,t._m,t._b);for(var n=0,i=0;i<r&&!(e<t._rangebreaks[i].pmin);i++)e>t._rangebreaks[i].pmax&&(n=i+1);return R(e,t._m2,t._B[n])}}t.c2l=\"log\"===t.type?S:u,t.l2c=\"log\"===t.type?M:u,t.l2p=F,t.p2l=B,t.c2p=\"log\"===t.type?function(t,e){return F(S(t,e))}:F,t.p2c=\"log\"===t.type?function(t){return M(B(t))}:B,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=s,t.c2d=t.c2r=t.l2d=t.l2r=u,t.d2p=t.r2p=function(e){return t.l2p(s(e))},t.p2d=t.p2r=B,t.cleanPos=u):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return S(s(t),e)},t.r2d=t.r2c=function(t){return M(s(t))},t.d2c=t.r2l=s,t.c2d=t.l2r=u,t.c2r=S,t.l2d=M,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return M(B(t))},t.r2p=function(e){return t.l2p(s(e))},t.p2r=B,t.cleanPos=u):\"date\"===t.type?(t.d2r=t.r2d=o.identity,t.d2c=t.r2c=t.d2l=t.r2l=E,t.c2d=t.c2r=t.l2d=t.l2r=C,t.d2p=t.r2p=function(e,r,n){return t.l2p(E(e,0,n))},t.p2d=t.p2r=function(t,e,r){return C(B(t),e,r)},t.cleanPos=function(e){return o.cleanDate(e,d,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=I,t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=O(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=u,t.r2l=O,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:u(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=z(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=P,t.l2r=t.c2r=u,t.r2l=z,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:u(t)},t.setupMultiCategory=function(n){var i,a,s=t._traceIndices,l=t._matchGroup;if(l&&0===t._categories.length)for(var c in l)if(c!==r){var u=e[_.id2name(c)];s=s.concat(u._traceIndices)}var p=[[0,{}],[0,{}]],d=[];for(i=0;i<s.length;i++){var g=n[s[i]];if(h in g){var m=g[h],v=g._length||o.minRowLength(m);if(f(m[0])&&f(m[1]))for(a=0;a<v;a++){var y=m[0][a],x=m[1][a];A(y)&&A(x)&&(d.push([y,x]),y in p[0][1]||(p[0][1][y]=p[0][0]++),x in p[1][1]||(p[1][1][x]=p[1][0]++))}}}for(d.sort((function(t,e){var r=p[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=p[1][1];return i[t[1]]-i[e[1]]})),i=0;i<d.length;i++)I(d[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,i,s=o.nestedProperty(t,e).get();if(i=(i=\"date\"===t.type?o.dfltRange(t.calendar):\"y\"===h?w.DFLTRANGEY:r.dfltRange||w.DFLTRANGEX).slice(),\"tozero\"!==t.rangemode&&\"nonnegative\"!==t.rangemode||(i[0]=0),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=o.cleanDate(s[0],d,t.calendar),s[1]=o.cleanDate(s[1],d,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!o.isDateTime(s[n],t.calendar)){t[e]=i;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=o.constrain(t.r2l(s[0]),o.MIN_MS+1e3,o.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!a(s[n])){if(!a(s[1-n])){t[e]=i;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-p?s[n]=-p:s[n]>p&&(s[n]=p),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else o.nestedProperty(t,e).set(i)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=_.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s,l,c=t.r2l(t[a][0],o),u=t.r2l(t[a][1],o),f=\"y\"===h;if((f?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(c-u),t._b=-t._m*u):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(u-c),t._b=-t._m*c),t._rangebreaks=[],t._lBreaks=0,t._m2=0,t._B=[],t.rangebreaks)&&(t._rangebreaks=t.locateBreaks(Math.min(c,u),Math.max(c,u)),t._rangebreaks.length)){for(s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._lBreaks+=Math.abs(l.max-l.min);var p=f;c>u&&(p=!p),p&&t._rangebreaks.reverse();var d=p?-1:1;for(t._m2=d*t._length/(Math.abs(u-c)-t._lBreaks),t._B.push(-t._m2*(f?u:c)),s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._B.push(t._B[t._B.length-1]-d*t._m2*(l.max-l.min));for(s=0;s<t._rangebreaks.length;s++)(l=t._rangebreaks[s]).pmin=F(l.min),l.pmax=F(l.max)}if(!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.maskBreaks=function(e){for(var r,n,i,a,l,c=t.rangebreaks||[],u=0;u<c.length;u++){var f=c[u];if(f.enabled)if(f.bounds){var h=f.pattern;switch(n=(r=o.simpleMap(f.bounds,h?s:t.d2c))[0],i=r[1],h){case k:a=(l=new Date(e)).getUTCDay(),n>i&&(i+=7,a<n&&(a+=7));break;case T:a=(l=new Date(e)).getUTCHours()+(l.getUTCMinutes()/60+l.getUTCSeconds()/3600+l.getUTCMilliseconds()/36e5),n>i&&(i+=24,a<n&&(a+=24));break;case\"\":a=e}if(a>=n&&a<i)return d}else for(var p=o.simpleMap(f.values,t.d2c).sort(o.sorterAsc),g=0;g<p.length;g++)if(i=(n=p[g])+f.dvalue,e>=n&&e<i)return d}return e},t.locateBreaks=function(e,r){var n,i,a,l,c=[];if(!t.rangebreaks)return c;var u=t.rangebreaks.slice().sort((function(t,e){return t.pattern===k&&e.pattern===T?-1:e.pattern===k&&t.pattern===T?1:0})),f=function(t,n){if((t=o.constrain(t,e,r))!==(n=o.constrain(n,e,r))){for(var i=!0,a=0;a<c.length;a++){var s=c[a];t<s.max&&n>=s.min&&(t<s.min&&(s.min=t),n>s.max&&(s.max=n),i=!1)}i&&c.push({min:t,max:n})}};for(n=0;n<u.length;n++){var h=u[n];if(h.enabled)if(h.bounds){var p=e,d=r;h.pattern&&(p=Math.floor(p)),a=(i=o.simpleMap(h.bounds,h.pattern?s:t.r2l))[0],l=i[1];var g,_,w=new Date(p);switch(h.pattern){case k:_=m,g=(l-a+(l<a?7:0))*v,p+=a*v-(w.getUTCDay()*v+w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;case T:_=v,g=(l-a+(l<a?24:0))*y,p+=a*y-(w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;default:p=Math.min(i[0],i[1]),g=_=(d=Math.max(i[0],i[1]))-p}for(var M=p;M<d;M+=_)f(M,M+g)}else for(var A=o.simpleMap(h.values,t.d2c),S=0;S<A.length;S++)f(a=A[S],l=a+h.dvalue)}return c.sort((function(t,e){return t.min-e.min})),c},t.makeCalcdata=function(e,r,n){var i,a,s,l,c=t.type,u=\"date\"===c&&e[r+\"calendar\"];if(r in e){if(i=e[r],l=e._length||o.minRowLength(i),o.isTypedArray(i)&&(\"linear\"===c||\"log\"===c)){if(l===i.length)return i;if(i.subarray)return i.subarray(0,l)}if(\"multicategory\"===c)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=P([i,a])}return r}(i,l);for(a=new Array(l),s=0;s<l;s++)a[s]=t.d2c(i[s],0,u,n)}else{var f=r+\"0\"in e?t.d2c(e[r+\"0\"],0,u):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(i=e[{x:\"y\",y:\"x\"}[r]],l=e._length||i.length,a=new Array(l),s=0;s<l;s++)a[s]=f+s*h}if(t.rangebreaks)for(s=0;s<l;s++)a[s]=t.maskBreaks(a[s]);return a},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&a(t.r2l(e[0]))&&a(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t._emptyCategories=function(){t._categories=[],t._categoriesMap={}},t.clearCalc=function(){var r=t._matchGroup;if(r){var n=null,i=null;for(var a in r){var o=e[_.id2name(a)];if(o._categories){n=o._categories,i=o._categoriesMap;break}}n&&i?(t._categories=n,t._categoriesMap=i):t._emptyCategories()}else t._emptyCategories();if(t._initialCategories)for(var s=0;s<t._initialCategories.length;s++)I(t._initialCategories[s])},t.sortByInitialCategories=function(){var n=[];if(t._emptyCategories(),t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)I(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[_.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var j=e._d3locale;\"date\"===t.type&&(t._dateFormat=j?j.timeFormat:i,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=j?j.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./axis_ids\":831,\"./constants\":834,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],849:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").contrast,a=t(\"./layout_attributes\"),o=t(\"../array_container_defaults\");function s(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter((function(e){return void 0!==t[e]}));if(e.every((function(r){return t[r]===t[e[0]]}))||1===e.length)return t[e[0]]}function l(t,e){function r(r,i){return n.coerce(t,e,a.tickformatstops,r,i)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,c,u,f){f&&1!==f.pass||function(t,e,r,n,i){var a=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,u),f&&2!==f.pass||function(t,e,r,c,u){var f=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",f);r(\"ticksuffix\",u.tickSuffixDflt)&&r(\"showticksuffix\",f);if(r(\"showticklabels\")){var h=u.font||{},p=e.color,d=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")?i(u.bgColor):p&&p!==a.color.dflt?p:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:d}),r(\"tickangle\"),\"category\"!==c){var g=r(\"tickformat\");o(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:l}),e.tickformatstops.length||delete e.tickformatstops,g||\"date\"===c||(r(\"showexponent\",f),r(\"exponentformat\"),r(\"minexponent\"),r(\"separatethousands\"))}}}(t,e,r,c,u)}},{\"../../components/color\":643,\"../../lib\":778,\"../array_container_defaults\":823,\"./layout_attributes\":842}],850:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":778,\"./layout_attributes\":842}],851:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){function o(r){var n=t[r];return void 0!==n?n:(e._template||{})[r]}var s=o(\"tick0\"),l=o(\"dtick\"),c=o(\"tickvals\"),u=r(\"tickmode\",i(c)?\"array\":l?\"linear\":\"auto\");if(\"auto\"===u)r(\"nticks\");else if(\"linear\"===u){var f=e.dtick=n.dtick(l,a);e.tick0=n.tick0(s,a,e.calendar,f)}else if(\"multicategory\"!==a){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"../../lib\":778,\"./clean_ticks\":833}],852:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"./axes\");e.exports=function(t,e,r,l){var c=t._fullLayout;if(0!==e.length){var u,f,h,p;l&&(u=l());var d=n.ease(r.easing);return t._transitionData._interruptCallbacks.push((function(){return window.cancelAnimationFrame(p),p=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr0&&(r[o._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[s._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}()})),f=Date.now(),p=window.requestAnimationFrame((function n(){h=Date.now();for(var a=Math.min(1,(h-f)/r.duration),o=d(a),s=0;s<e.length;s++)m(e[s],o);h-f>r.duration?(!function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr1&&(r[o._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[s._name+\".range\"]=a.yr1.slice())}u&&u(),i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}(),p=window.cancelAnimationFrame(n)):p=window.requestAnimationFrame(n)})),Promise.resolve()}function g(t){var e=t.xaxis,r=t.yaxis;c._defs.select(\"#\"+t.clipId+\"> rect\").call(o.setTranslate,0,0).call(o.setScale,1,1),t.plot.call(o.setTranslate,e._offset,r._offset).call(o.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(o.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(o.setTextPointsScale,1,1),n.call(o.hideOutsideRangePoints,t)}function m(e,r){var n=e.plotinfo,i=n.xaxis,l=n.yaxis,c=i._length,u=l._length,f=!!e.xr1,h=!!e.yr1,p=[];if(f){var d=a.simpleMap(e.xr0,i.r2l),g=a.simpleMap(e.xr1,i.r2l),m=d[1]-d[0],v=g[1]-g[0];p[0]=(d[0]*(1-r)+r*g[0]-d[0])/(d[1]-d[0])*c,p[2]=c*(1-r+r*v/m),i.range[0]=i.l2r(d[0]*(1-r)+r*g[0]),i.range[1]=i.l2r(d[1]*(1-r)+r*g[1])}else p[0]=0,p[2]=c;if(h){var y=a.simpleMap(e.yr0,l.r2l),x=a.simpleMap(e.yr1,l.r2l),b=y[1]-y[0],_=x[1]-x[0];p[1]=(y[1]*(1-r)+r*x[1]-y[1])/(y[0]-y[1])*u,p[3]=u*(1-r+r*_/b),l.range[0]=i.l2r(y[0]*(1-r)+r*x[0]),l.range[1]=l.l2r(y[1]*(1-r)+r*x[1])}else p[1]=0,p[3]=u;s.drawOne(t,i,{skipTitle:!0}),s.drawOne(t,l,{skipTitle:!0}),s.redrawComponents(t,[i._id,l._id]);var w=f?c/p[2]:1,T=h?u/p[3]:1,k=f?p[0]:0,M=h?p[1]:0,A=f?p[0]/p[2]*c:0,S=h?p[1]/p[3]*u:0,E=i._offset-A,C=l._offset-S;n.clipRect.call(o.setTranslate,k,M).call(o.setScale,1/w,1/T),n.plot.call(o.setTranslate,E,C).call(o.setScale,w,T),o.setPointGroupScale(n.zoomScalePts,1/w,1/T),o.setTextPointsScale(n.zoomScaleTxt,1/w,1/T)}s.redrawComponents(t)}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../registry\":911,\"./axes\":828,d3:169}],853:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){r(\"autotypenumbers\",s.autotypenumbersDflt),\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r,s=t._id,l=s.charAt(0);-1!==s.indexOf(\"scene\")&&(s=l);var c=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,s,l);if(!c)return;if(\"histogram\"===c.type&&l==={v:\"y\",h:\"x\"}[c.orientation||\"v\"])return void(t.type=\"linear\");var u=l+\"calendar\",f=c[u],h={noMultiCategory:!n(c,\"cartesian\")||n(c,\"noMultiCategory\")};\"box\"===c.type&&c._hasPreCompStats&&l==={h:\"x\",v:\"y\"}[c.orientation||\"v\"]&&(h.noMultiCategory=!0);if(h.autotypenumbers=t.autotypenumbers,o(c,l)){var p=a(c),d=[];for(r=0;r<e.length;r++){var g=e[r];n(g,\"box-violin\")&&(g[l+\"axis\"]||l)===s&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==f&&(f=void 0))}t.type=i(d,f,h)}else if(\"splom\"===c.type){var m=c.dimensions[c._axesDim[s]];m.visible&&(t.type=i(m.values,f,h))}else t.type=i(c[l]||[c[l+\"0\"]],f,h)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":911,\"./axis_autotype\":829}],854:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,(function(t,e,n){r.push({type:\"layout\",prop:t,value:n})}),\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,(function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var f=0;f<a.length;f++)o[f]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})}),\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach((function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}}))}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],f=0;f<u.length;f++)t._internalOn(u[f],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var f=r.computeAPICommandBindings(t,c,u);if(1!==f.length)return!1;if(a){if((s=f[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var h=0;h<a.traces.length;h++)if(a.traces[h]!==s.traces[h])return!1}else if(s.prop!==a.prop)return!1}else a=f[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=f[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch((function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)}))},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":778,\"../registry\":911}],855:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}var c=r(\"domain.x\",i),u=r(\"domain.y\",a);c[0]<c[1]||(t.domain.x=i.slice()),u[0]<u[1]||(t.domain.y=a.slice())}},{\"../lib/extend\":768}],856:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],857:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],858:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],859:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../components/fx\"),u=t(\"../plots\"),f=t(\"../cartesian/axes\"),h=t(\"../cartesian/autorange\").getAutoRange,p=t(\"../../components/dragelement\"),d=t(\"../cartesian/select\").prepSelect,g=t(\"../cartesian/select\").clearSelect,m=t(\"../cartesian/select\").selectOnClick,v=t(\"./zoom\"),y=t(\"./constants\"),x=t(\"../../lib/geo_location_utils\"),b=t(\"../../lib/topojson_utils\"),_=t(\"topojson-client\").feature;function w(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var T=w.prototype;function k(t,e){var r=y.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}e.exports=function(t){return new w(t)},T.plot=function(t,e,r){var n=this,i=e[this.id],a=[],o=!1;for(var s in y.layerNameToAdjective)if(\"frame\"!==s&&i[\"show\"+s]){o=!0;break}for(var l=0;l<t.length;l++)if(t[0][0].trace.locationmode){o=!0;break}if(o){var c=b.getTopojsonName(i);null!==n.topojson&&c===n.topojsonName||(n.topojsonName=c,void 0===PlotlyGeoAssets.topojson[n.topojsonName]&&a.push(n.fetchTopojson()))}a=a.concat(x.fetchTraceGeoData(t)),r.push(new Promise((function(r,i){Promise.all(a).then((function(){n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e),r()})).catch(i)})))},T.fetchTopojson=function(){var t=this,e=b.getTopojsonPath(t.topojsonURL,t.topojsonName);return new Promise((function(r,i){n.json(e,(function(n,a){if(n)return 404===n.status?i(new Error([\"plotly.js could not find topojson file at\",e,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):i(new Error([\"unexpected error while fetching topojson file at\",e].join(\" \")));PlotlyGeoAssets.topojson[t.topojsonName]=a,r()}))}))},T.update=function(t,e){var r=e[this.id];this.hasChoropleth=!1;for(var n=0;n<t.length;n++){var i=t[n],a=i[0].trace;\"choropleth\"===a.type&&(this.hasChoropleth=!0),!0===a.visible&&a._length>0&&a._module.calcGeoJSON(i,e)}if(!this.updateProjection(t,e)){this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),u.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var o=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=o.selectAll(\".point\"),this.dataPoints.text=o.selectAll(\"text\"),this.dataPaths.line=o.selectAll(\".js-line\");var s=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=s.selectAll(\"path\"),this.render()}},T.updateProjection=function(t,e){var r=this.graphDiv,o=e[this.id],s=e._size,l=o.domain,c=o.projection,u=o.lonaxis,f=o.lataxis,p=u._ax,d=f._ax,g=this.projection=function(t){for(var e=t.projection.type,r=n.geo[y.projNames[e]](),i=t._isClipped?y.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(y.precision),i&&r.clipAngle(i-y.clipPad);return r}(o),m=[[s.l+s.w*l.x[0],s.t+s.h*(1-l.y[1])],[s.l+s.w*l.x[1],s.t+s.h*(1-l.y[0])]],v=o.center||{},x=c.rotation||{},b=u.range||[],_=f.range||[];if(o.fitbounds){p._length=m[1][0]-m[0][0],d._length=m[1][1]-m[0][1],p.range=h(r,p),d.range=h(r,d);var w=(p.range[0]+p.range[1])/2,T=(d.range[0]+d.range[1])/2;if(o._isScoped)v={lon:w,lat:T};else if(o._isClipped){v={lon:w,lat:T},x={lon:w,lat:T,roll:x.roll};var M=c.type,A=y.lonaxisSpan[M]/2||180,S=y.lataxisSpan[M]/2||90;b=[w-A,w+A],_=[T-S,T+S]}else v={lon:w,lat:T},x={lon:w,lat:x.lat,roll:x.roll}}g.center([v.lon-x.lon,v.lat-x.lat]).rotate([-x.lon,-x.lat,x.roll]).parallels(c.parallels);var E=k(b,_);g.fitExtent(m,E);var C=this.bounds=g.getBounds(E),L=this.fitScale=g.scale(),I=g.translate();if(!isFinite(C[0][0])||!isFinite(C[0][1])||!isFinite(C[1][0])||!isFinite(C[1][1])||isNaN(I[0])||isNaN(I[0])){for(var P=[\"fitbounds\",\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],z=\"Invalid geo settings, relayout'ing to default view.\",O={},D=0;D<P.length;D++)O[this.id+\".\"+P[D]]=null;return this.viewInitial=null,a.warn(z),r._promises.push(i.call(\"relayout\",r,O)),z}if(o.fitbounds){var R=g.getBounds(k(p.range,d.range)),F=Math.min((C[1][0]-C[0][0])/(R[1][0]-R[0][0]),(C[1][1]-C[0][1])/(R[1][1]-R[0][1]));isFinite(F)?g.scale(F*L):a.warn(\"Something went wrong during\"+this.id+\"fitbounds computations.\")}else g.scale(c.scale*L);var B=this.midPt=[(C[0][0]+C[1][0])/2,(C[0][1]+C[1][1])/2];if(g.translate([I[0]+(B[0]-I[0]),I[1]+(B[1]-I[1])]).clipExtent(C),o._isAlbersUsa){var N=g([v.lon,v.lat]),j=g.translate();g.translate([j[0]-(N[0]-j[0]),j[1]-(N[1]-j[1])])}},T.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,o=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function u(t){return Boolean(y.lineLayers[t])}function h(t){return Boolean(y.fillLayers[t])}var p=(this.hasChoropleth?y.layersForChoropleth:y.layers).filter((function(t){return u(t)||h(t)?e[\"show\"+t]:!c(t)||e[t].showgrid})),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each((function(t){delete a[t],delete o[t],n.select(this).remove()})),d.enter().append(\"g\").attr(\"class\",(function(t){return\"layer \"+t})).each((function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):u(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):h(t)&&(o[t]=e.append(\"path\").style(\"stroke\",\"none\"))})),d.order(),d.each((function(r){var n=o[r],a=y.layerNameToAdjective[r];\"frame\"===r?n.datum(y.sphereSVG):u(r)||h(r)?n.datum(_(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=y.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};f.setConvert(l,r);var c=f.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var u=c.length,h=new Array(u),p=0;p<u;p++)for(var d=c[p].x,g=h[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)g.push(a(d,m));return{type:\"MultiLineString\",coordinates:h}}(r,e,t)).call(s.stroke,e[r].gridcolor).call(l.dashLine,\"\",e[r].gridwidth),u(r)?n.call(s.stroke,e[a+\"color\"]).call(l.dashLine,\"\",e[a+\"width\"]):h(r)&&n.call(s.fill,e[a+\"color\"])}))},T.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,o=r[1][0]-i+n,c=r[1][1]-a+n;l.setRect(this.clipRect,i,a,o,c),this.bgRect.call(l.setRect,i,a,o,c).call(s.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=o,this.yaxis._offset=a,this.yaxis._length=c},T.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,l=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[h([e.xmin,e.ymin]),h([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(h)});var f={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(t){2===t&&g(a)}};\"pan\"===s?(o.node().onmousedown=null,o.call(v(r,e)),o.on(\"dblclick.zoom\",(function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)})),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),f.prepFn=function(t,e,r){d(t,e,r,f,s)},p.init(f)),o.on(\"mousemove\",(function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return p.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},c.hover(a,n.event,r.id)})),o.on(\"mouseout\",(function(){a._dragging||p.unhover(a,n.event)})),o.on(\"click\",(function(){\"select\"!==s&&\"lasso\"!==s&&(l.indexOf(\"select\")>-1&&m(n.event,a,[r.xaxis],[r.yaxis],r.id,f),l.indexOf(\"event\")>-1&&c.click(a,n.event))}))}function h(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},T.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(l.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},f.setConvert(t.mockAxis,r)},T.saveViewInitial=function(t){var e,r=t.center||{},n=t.projection,i=n.rotation||{};this.viewInitial={fitbounds:t.fitbounds,\"projection.scale\":n.scale},e=t._isScoped?{\"center.lon\":r.lon,\"center.lat\":r.lat}:t._isClipped?{\"projection.rotation.lon\":i.lon,\"projection.rotation.lat\":i.lat}:{\"center.lon\":r.lon,\"center.lat\":r.lat,\"projection.rotation.lon\":i.lon},a.extendFlat(this.viewInitial,e)},T.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?o(r[0],r[1]):null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",(function(t){return r(t.geojson)}));for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/topojson_utils\":806,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/axes\":828,\"../cartesian/select\":847,\"../plots\":891,\"./constants\":858,\"./projections\":863,\"./zoom\":864,d3:169,\"topojson-client\":579}],860:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l.geo={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots.geo,s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots.geo,n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots.geo||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.framework.remove(),s.clipDef.remove())}}}},{\"../../lib\":778,\"../../plots/get_data\":865,\"./geo\":859,\"./layout_attributes\":861,\"./layout_defaults\":862}],861:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),fitbounds:{valType:\"enumerated\",values:[!1,\"locations\",\"geojson\"],dflt:!1,editType:\"plot\"},resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},visible:{valType:\"boolean\",dflt:!0},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":642,\"../../plot_api/edit_types\":810,\"../domain\":855,\"./constants\":858}],862:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../get_data\").getSubplotData,o=t(\"./constants\"),s=t(\"./layout_attributes\"),l=o.axesNames;function c(t,e,r,i){var s=a(i.fullData,\"geo\",i.id).map((function(t){return t._expandedIndex})),c=r(\"resolution\"),u=r(\"scope\"),f=o.scopeDefaults[u],h=r(\"projection.type\",f.projType),p=e._isAlbersUsa=\"albers usa\"===h;p&&(u=e.scope=\"usa\");var d=e._isScoped=\"world\"!==u,g=e._isConic=-1!==h.indexOf(\"conic\"),m=e._isClipped=!!o.lonaxisSpan[h];if(!1===t.visible){var v=n.extendDeep({},e._template);v.showcoastlines=!1,v.showcountries=!1,v.showframe=!1,v.showlakes=!1,v.showland=!1,v.showocean=!1,v.showrivers=!1,v.showsubunits=!1,v.lonaxis&&(v.lonaxis.showgrid=!1),v.lataxis&&(v.lataxis.showgrid=!1),e._template=v}for(var y=r(\"visible\"),x=0;x<l.length;x++){var b,_=l[x],w=[30,10][x];if(d)b=f[_+\"Range\"];else{var T=o[_+\"Span\"],k=(T[h]||T[\"*\"])/2,M=r(\"projection.rotation.\"+_.substr(0,3),f.projRotate[x]);b=[M-k,M+k]}var A=r(_+\".range\",b);r(_+\".tick0\"),r(_+\".dtick\",w),r(_+\".showgrid\",!!y&&void 0)&&(r(_+\".gridcolor\"),r(_+\".gridwidth\")),e[_]._ax={type:\"linear\",_id:_.slice(0,3),_traceIndices:s,setScale:n.identity,c2l:n.identity,r2l:n.identity,autorange:!0,range:A.slice(),_m:1,_input:{}}}var S=e.lonaxis.range,E=e.lataxis.range,C=S[0],L=S[1];C>0&&L<0&&(L+=360);var I,P,z,O=(C+L)/2;if(!p){var D=d?f.projRotate:[O,0,0];I=r(\"projection.rotation.lon\",D[0]),r(\"projection.rotation.lat\",D[1]),r(\"projection.rotation.roll\",D[2]),r(\"showcoastlines\",!d&&y)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\",!!y&&void 0)&&r(\"oceancolor\")}(p?(P=-96.6,z=38.7):(P=d?O:I,z=(E[0]+E[1])/2),r(\"center.lon\",P),r(\"center.lat\",z),g)&&r(\"projection.parallels\",f.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\",!!y&&void 0)&&r(\"landcolor\"),r(\"showlakes\",!!y&&void 0)&&r(\"lakecolor\"),r(\"showrivers\",!!y&&void 0)&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",d&&\"usa\"!==u&&y)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===u||\"north america\"===u&&50===c)&&(r(\"showsubunits\",y),r(\"subunitcolor\"),r(\"subunitwidth\")),d||r(\"showframe\",y)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\"),r(\"fitbounds\")&&(delete e.projection.scale,d?(delete e.center.lon,delete e.center.lat):m?(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon,delete e.projection.rotation.lat,delete e.lonaxis.range,delete e.lataxis.range):(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon))}e.exports=function(t,e,r){i(t,e,r,{type:\"geo\",attributes:s,handleDefaults:c,fullData:r,partition:\"y\"})}},{\"../../lib\":778,\"../get_data\":865,\"../subplot_defaults\":905,\"./constants\":858,\"./layout_attributes\":861}],863:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map((function(t){return r(t,n)}))};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map((function(t){return e(t,r)}))}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach((function(r){!function(t){if((e=t.length)<4)return!1;var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];for(;++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])})),e.forEach((function(e){var r=e[0];t.some((function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],f=t[s],h=f[0],p=f[1];u>n^p>n&&r<(h-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0}))||t.push([e])})),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var f=1e-6,h=Math.PI,p=h/2,d=(Math.sqrt(h),h/180),g=180/h;function m(t){return t>1?p:t<-1?-p:Math.asin(t)}function v(t){return t>1?0:t<-1?h:Math.acos(t)}var y=t.geo.projection,x=t.geo.projectionMutator;function b(t,e){var r=(2+p)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>f;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(h*(4+h))*t*(1+Math.cos(e)),2*Math.sqrt(h/(4+h))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-h,0],[0,p],[h,0]]],[[[-h,0],[0,-p],[h,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}function a(){r=n.map((function(t){return t.map((function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]}))}))}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],l=0,u=o.length;l<u;++l){var f=o[l];if(f[0][0]<=t&&t<f[1][0]&&f[0][1]<=a&&a<f[1][1]){var h=e.invert(t-e(s[l][1][0],0)[0],a);return h[0]+=s[l][1][0],c(i(h[0],h[1]),[t,a])?h:null}}});var o=t.geo.projection(i),s=o.stream;function l(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function c(t,e){return Math.abs(t[0]-e[0])<f&&Math.abs(t[1]-e[1])<f}return o.stream=function(e){var r=o.rotate(),i=s(e),a=(o.rotate([0,0]),s(e));return o.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=180*(p=n[0][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[o+e,s+e],[o+e,c-e],[u-e,c-e],[u-e,f+e]],30))}for(i=n[1].length-1;i>=0;--i){var p;o=180*(p=n[1][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[u-e,f-e],[u-e,c+e],[o+e,c+e],[o+e,s-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),a)},i},o.lobes=function(t){return arguments.length?(n=t.map((function(t){return t.map((function(t){return[[t[0][0]*h/180,t[0][1]*h/180],[t[1][0]*h/180,t[1][1]*h/180],[t[2][0]*h/180,t[2][1]*h/180]]}))})),a(),o):n.map((function(t){return t.map((function(t){return[[180*t[0][0]/h,180*t[0][1]/h],[180*t[1][0]/h,180*t[1][1]/h],[180*t[2][0]/h,180*t[2][1]/h]]}))}))},o},b.invert=function(t,e){var r=.5*e*Math.sqrt((4+h)/h),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(h*(4+h))*(1+i)),m((n+r*(i+2))/(2+p))]},(t.geo.eckert4=function(){return y(b)}).raw=b;var _=t.geo.azimuthalEqualArea.raw;function w(t,e){if(arguments.length<2&&(e=t),1===e)return _;if(e===1/0)return T;function r(r,n){var i=_(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=_.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function k(t,e){return[3*t/(2*h)*Math.sqrt(h*h/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(h/4+.4*e))]}function A(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>f&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=x(w),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=w,k.invert=function(t,e){return[2/3*h*t/Math.sqrt(h*h/3-e*e),e]},(t.geo.kavrayskiy7=function(){return y(k)}).raw=k,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*h]},(t.geo.miller=function(){return y(M)}).raw=M,A(h);var S=function(t,e,r){var n=A(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/p,Math.SQRT2,h);function E(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return y(S)}).raw=S,E.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>f&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return y(E)}).raw=E;var C=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function L(t,e){var r,n=Math.min(18,36*Math.abs(e)/h),i=Math.floor(n),a=n-i,o=(r=C[i])[0],s=r[1],l=(r=C[++i])[0],c=r[1],u=(r=C[Math.min(19,++i)])[0],f=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?p:-p)*(c+a*(f-s)/2+a*a*(f-2*c+s)/2)]}function I(t,e){return[t*Math.cos(e),e]}function P(t,e){var r,n=Math.cos(e),i=(r=v(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function z(t,e){var r=P(t,e);return[(r[0]+t/p)/2,(r[1]+e)/2]}C.forEach((function(t){t[1]*=1.0144})),L.invert=function(t,e){var r=e/p,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=C[a][1],s=C[a+1][1],l=C[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,f=2*(Math.abs(r)-s)/c,h=u/c,m=f*(1-h*f*(1-2*h*f));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var v,y=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=C[a][1],s=C[a+1][1],l=C[Math.min(19,a+2)][1],n-=(v=(e>=0?p:-p)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*g}while(Math.abs(v)>1e-12&&--y>0);break}}while(--a>=0);var x=C[a][0],b=C[a+1][0],_=C[Math.min(19,a+2)][0];return[t/(b+m*(_-x)/2+m*m*(_-2*b+x)/2),n*d]},(t.geo.robinson=function(){return y(L)}).raw=L,I.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return y(I)}).raw=I,P.invert=function(t,e){if(!(t*t+4*e*e>h*h+f)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),p=Math.sin(2*n),d=c*c,g=u*u,m=s*s,y=1-g*l*l,x=y?v(u*l)*Math.sqrt(a=1/y):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*m+x*u*l*d),T=a*(.5*o*p-2*x*c*s),k=.25*a*(p*s-x*c*g*o),M=a*(d*l+x*m*u),A=T*k-M*w;if(!A)break;var S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return y(P)}).raw=P,z.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,h=Math.sin(r),d=Math.cos(r/2),g=Math.sin(r/2),m=g*g,y=1-u*d*d,x=y?v(o*d)*Math.sqrt(a=1/y):a=0,b=.5*(2*x*o*g+r/p)-t,_=.5*(x*s+n)-e,w=.5*a*(u*m+x*o*d*c)+.5/p,T=a*(h*l/4-x*s*g),k=.125*a*(l*g-x*s*u*h),M=.5*a*(c*d+x*m*o)+.5,A=T*k-M*w,S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return y(z)}).raw=z}},{}],864:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function f(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],f={},h={};function p(t,e){f[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,f);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),h[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),p(\"fitbounds\",!1),o.emit(\"plotly_relayout\",h)}function h(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",(function(){n.select(this).style(l)})).on(\"zoom\",(function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})})).on(\"zoomend\",(function(){n.select(this).style(c),f(t,e,i)})),r}function p(t,e){var r,i,a,o,s,h,p,d,g,m=u(0,e);function v(t){return e.invert(t)}function y(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return m.on(\"zoomstart\",(function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=v(r)})).on(\"zoom\",(function(){if(h=n.mouse(this),function(t){var r=v(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>2||Math.abs(n[1]-t[1])>2}(r))return m.scale(e.scale()),void m.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?v(h)&&(d=v(h),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=v(r=h),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})})).on(\"zoomend\",(function(){n.select(this).style(c),g&&f(t,e,y)})),m}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),o=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),s=0,h=a.on;function p(t){s++||t({type:\"zoomstart\"})}function d(t){t({type:\"zoom\"})}function b(t){--s||t({type:\"zoomend\"})}function _(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",(function(){n.select(this).style(l);var t=n.mouse(this),s=e.rotate(),c=s,u=e.translate(),f=m(s);r=g(e,t),h.call(a,\"zoom\",(function(){var a=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,a)){e.rotate(s).translate(u);var l=g(e,a),h=y(r,l),p=T(v(f,h)),m=i.r=x(p,r,c);isFinite(m[0])&&isFinite(m[1])&&isFinite(m[2])||(m=c),e.rotate(m),c=m}}else r=g(e,t=a);d(o.of(this,arguments))})),p(o.of(this,arguments))})).on(\"zoomend\",(function(){n.select(this).style(c),h.call(a,\"zoom\",null),b(o.of(this,arguments)),f(t,e,_)})).on(\"zoom.redraw\",(function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})})),n.rebind(a,o,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function m(t){var e=.5*t[0]*o,r=.5*t[1]*o,n=.5*t[2]*o,i=Math.sin(e),a=Math.cos(e),s=Math.sin(r),l=Math.cos(r),c=Math.sin(n),u=Math.cos(n);return[a*l*u+i*s*c,i*l*u-a*s*c,a*s*u+i*l*c,a*l*c-i*s*u]}function v(t,e){var r=t[0],n=t[1],i=t[2],a=t[3],o=e[0],s=e[1],l=e[2],c=e[3];return[r*o-n*s-i*l-a*c,r*s+n*o+i*c-a*l,r*l-n*c+i*o+a*s,r*c+n*l-i*s+a*o]}function y(t,e){if(t&&e){var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(k(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,k(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}}function x(t,e,r){var n=w(e,2,t[0]);n=w(n,1,t[1]),n=w(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],f=n[1],h=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(f)>d?(a=(f>0?90:-90)-p,i=0):(a=Math.asin(f/d)*s-p,i=Math.sqrt(d*d-f*f));var g=180-a-2*p,m=(Math.atan2(h,u)-Math.atan2(c,i))*s,v=(Math.atan2(h,u)-Math.atan2(c,-i))*s;return b(r[0],r[1],a,m)<=b(r[0],r[1],g,v)?[a,m,r[2]]:[g,v,r[2]]}function b(t,e,r,n){var i=_(r-t),a=_(n-e);return Math.sqrt(i*i+a*a)}function _(t){return(t%360+540)%360-180}function w(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function T(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}function k(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?h:e._isClipped?d:p)(t,r)}},{\"../../lib\":778,\"../../registry\":911,d3:169}],865:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var f=0;f<t.length;f++)a=t[f],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":911,\"./cartesian/constants\":834}],866:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function f(e,n,i){var a,s,l=t.calcDataBox(),f=r.viewBox,h=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function m(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=f[3]-f[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var v=n/(f[2]-f[0])*(l[2]-l[0])+l[0],y=i/(f[3]-f[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=v,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=v,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(m(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(m(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(h-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,f),e.addEventListener(\"touchstart\",(function(t){var r=a(t.changedTouches[0],e);f(0,r[0],r[1]),f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchmove\",(function(t){t.preventDefault();var r=a(t.changedTouches[0],e);f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchend\",(function(t){f(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()}),!!s&&{passive:!1}),c.wheelListener=i(e,(function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),f=o/(a[2]-a[0])*(i[2]-i[0])+i[0],h=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-f)*l+f,i[2]=(i[2]-f)*l+f,i[1]=(i[1]-h)*l+h,i[3]=(i[3]-h)*l+h,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0}),!0),c}},{\"../cartesian/constants\":834,\"has-passive-events\":441,\"mouse-change\":483,\"mouse-event-offset\":484,\"mouse-wheel\":486}],867:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,f,h,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),h=0;h<2;++h){var d=(e=s[h]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[h+p]=!1,this.labels[h+p]=n,this.labelColor[h+p]=i(r.title.font.color),this.labelFont[h+p]=r.title.font.family,this.labelSize[h+p]=r.title.font.size,this.labelPad[h+p]=this.getLabelPad(e,r),this.tickEnable[h+p]=!1,this.tickColor[h+p]=i((r.tickfont||{}).color),this.tickAngle[h+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[h+p]=this.getTickPad(r),this.tickMarkLength[h+p]=0,this.tickMarkWidth[h+p]=r.tickwidth||0,this.tickMarkColor[h+p]=i(r.tickcolor),this.borderLineEnable[h+p]=!1,this.borderLineColor[h+p]=i(r.linecolor),this.borderLineWidth[h+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,f=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[h]=!0:l&&(this.labelEnable[h+2]=!0),o?this.tickEnable[h]=r.showticklabels:l&&(this.tickEnable[h+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[h]=r.showline),(l||u)&&(this.borderLineEnable[h+2]=r.showline),(o||f)&&(this.tickMarkLength[h]=this.getTickMarkLength(r)),(l||f)&&(this.tickMarkLength[h+2]=this.getTickMarkLength(r)),this.gridLineEnable[h]=r.showgrid,this.gridLineColor[h]=i(r.gridcolor),this.gridLineWidth[h]=r.gridwidth,this.zeroLineEnable[h]=r.zeroline,this.zeroLineColor[h]=i(r.zerolinecolor),this.zeroLineWidth[h]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":802,\"../cartesian/axes\":828}],868:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d){var c=u(t,\"gl2d\",o);0===c.length&&(s._scene2d.destroy(),delete n._plots[o])}}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":684,\"../../constants/xmlns_namespaces\":754,\"../../plot_api/edit_types\":810,\"../cartesian\":841,\"../cartesian/attributes\":826,\"../cartesian/constants\":834,\"../get_data\":865,\"../layout_attributes\":882,\"./scene2d\":869}],869:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),f=t(\"webgl-context\"),h=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),m=g.enforce,v=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=t(\"../../components/dragelement/helpers\"),b=x.drawMode,_=x.selectMode,w=[\"xaxis\",\"yaxis\"],T=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function k(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=h(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=k;var M=k.prototype;M.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=f({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=f({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r);var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",(function(){l.isMouseOver=!1,l.unhover()})),o.addEventListener(\"mouseover\",(function(){l.isMouseOver=!0}))},M.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var f=document.createElement(\"canvas\");f.width=r,f.height=i;var h,p=f.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":h=f.toDataURL(\"image/jpeg\");break;case\"webp\":h=f.toDataURL(\"image/webp\");break;default:h=f.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),h},M.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},M.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},M.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(T),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},M.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},M.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},M.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},M.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map((function(e){t[e].dispose(),delete t[e]})),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},M.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};v(s,this.xaxis),v(s,this.yaxis);var l,c,u=r._size,f=this.xaxis.domain,h=this.yaxis.domain;for(o.viewBox=[u.l+f[0]*u.w,u.b+h[0]*u.h,i-u.r-(1-f[1])*u.w,a-u.t-(1-h[1])*u.h],this.mouseContainer.style.width=u.w*(f[1]-f[0])+\"px\",this.mouseContainer.style.height=u.h*(h[1]-h[0])+\"px\",this.mouseContainer.height=u.h*(h[1]-h[0]),this.mouseContainer.style.left=u.l+f[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-h[1])*u.h+\"px\",c=0;c<2;++c)(l=this[w[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();m(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},M.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},M.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},M.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort((function(t,e){return t._trace.index-e._trace.index}))},M.updateFx=function(t){_(t)||b(t)?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},M.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},M.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var f=i._size,h=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+f.l+h[0]*f.w,l/t.pixelRatio-(f.t+(1-p[1])*f.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var m=this.fullData[g.trace.index]||{},v=g.pointIndex,y=s.castHoverinfo(m,i,v);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(m,v,\"bgcolor\")||g.color,borderColor:s.castHoverOption(m,v,\"bordercolor\"),fontFamily:s.castHoverOption(m,v,\"font.family\"),fontSize:s.castHoverOption(m,v,\"font.size\"),fontColor:s.castHoverOption(m,v,\"font.color\"),nameLength:s.castHoverOption(m,v,\"namelength\"),textAlign:s.castHoverOption(m,v,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},M.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},M.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/dragelement/helpers\":661,\"../../components/fx\":683,\"../../lib/show_no_webgl_msg\":800,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/constants\":834,\"../cartesian/constraints\":835,\"./camera\":866,\"./convert\":867,\"gl-plot2d\":317,\"gl-select-box\":333,\"gl-spikes2d\":342,\"webgl-context\":606}],870:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,f=c._scene;f||(f=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=f),f.viewInitial||(f.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),f.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":684,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../get_data\":865,\"./layout/attributes\":871,\"./layout/defaults\":875,\"./layout/layout_attributes\":876,\"./scene\":880}],871:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],872:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:{text:i.title.text,font:i.title.font},type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":643,\"../../../lib/extend\":768,\"../../../plot_api/edit_types\":810,\"../../cartesian/layout_attributes\":842}],873:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,f;function h(t,e){return i.coerce(u,f,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(f=a.newContainer(e,d))._id=d[0]+r.scene,f._name=d,s(u,f,h,r),l(u,f,h,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,noTicklabelmode:!0,noTicklabelposition:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),h(\"gridcolor\",n(f.color,r.bgColor,13600/187).toRgbString()),h(\"title.text\",d[0]),f.setScale=i.noop,h(\"showspikes\")&&(h(\"spikesides\"),h(\"spikethickness\"),h(\"spikecolor\",f.color)),h(\"showaxeslabels\"),h(\"showbackground\")&&h(\"backgroundcolor\")}}},{\"../../../lib\":778,\"../../../plot_api/plot_template\":817,\"../../cartesian/axis_defaults\":830,\"../../cartesian/type_defaults\":853,\"./axis_attributes\":872,tinycolor2:576}],874:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":778,\"../../../lib/str2rgbarray\":802}],875:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData;function u(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),u=[\"up\",\"center\",\"eye\"],f=0;f<u.length;f++)r(\"camera.\"+u[f]+\".x\"),r(\"camera.\"+u[f]+\".y\"),r(\"camera.\"+u[f]+\".z\");r(\"camera.projection.type\");var h=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),p=r(\"aspectmode\",h?\"manual\":\"auto\");h||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===p&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var d=c(n.fullData,\"gl3d\",n.id);s(t,e,{font:n.font,scene:n.id,data:d,bgColor:l,calendar:n.calendar,autotypenumbersDflt:n.autotypenumbersDflt,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var g=n.getDfltFromLayout(\"dragmode\");if(!1!==g&&!g)if(g=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,v=t.camera.up.y,y=t.camera.up.z;0!==y&&(m&&v&&y?y/Math.sqrt(m*m+v*v+y*y)>.999&&(g=\"turntable\"):g=\"turntable\")}else g=\"turntable\";r(\"dragmode\",g),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:\"gl3d\",attributes:l,handleDefaults:u,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":643,\"../../../lib\":778,\"../../../registry\":911,\"../../get_data\":865,\"../../subplot_defaults\":905,\"./axis_defaults\":873,\"./layout_attributes\":876}],876:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":778,\"../../../lib/extend\":768,\"../../domain\":855,\"./axis_attributes\":872}],877:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":802}],878:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var f=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var h=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/h)}for(var p=n.calcTicks(u,{msUTC:!0}),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=f}}e.ticks=l;for(c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":778,\"../../cartesian/axes\":828}],879:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],880:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\"),o=a.createCamera,s=a.createScene,l=t(\"webgl-context\"),c=t(\"has-passive-events\"),u=t(\"../../registry\"),f=t(\"../../lib\"),h=f.preserveDrawingBuffer(),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../components/fx\"),g=t(\"../../lib/str2rgbarray\"),m=t(\"../../lib/show_no_webgl_msg\"),v=t(\"./project\"),y=t(\"./layout/convert\"),x=t(\"./layout/spikes\"),b=t(\"./layout/tick_marks\");function _(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=y(e,e[this.id]),this.spikeOptions=x(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=u.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=u.getComponentMethod(\"annotations3d\",\"draw\"),this.initializeGLPlot()}var w=_.prototype;w.prepareOptions=function(){var t={canvas:this.canvas,gl:this.gl,glOptions:{preserveDrawingBuffer:h,premultipliedAlpha:!0,antialias:!0},container:this.container,axes:this.axesOptions,spikes:this.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:this.camera,pixelRatio:this.pixelRatio};if(this.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=l({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");t.gl=i,t.canvas=n}return t};var T=!0;w.tryCreatePlot=function(){var t=this.prepareOptions(),e=!0;try{this.glplot=s(t)}catch(r){if(this.staticMode||!T||h)e=!1;else{f.warn([\"webgl setup failed possibly due to\",\"false preserveDrawingBuffer config.\",\"The mobile/tablet device may not be detected by is-mobile module.\",\"Enabling preserveDrawingBuffer in second attempt to create webgl scene...\"].join(\" \"));try{h=t.glOptions.preserveDrawingBuffer=!0,this.glplot=s(t)}catch(r){h=t.glOptions.preserveDrawingBuffer=!1,e=!1}}}return T=!1,e},w.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=o(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},w.initializeGLPlot=function(){var t=this;if(t.initializeGLCamera(),!t.tryCreatePlot())return m(t);t.traces={},t.make4thDimension();var e=t.graphDiv,r=e.layout,n=function(){var e={};return t.isCameraChanged(r)&&(e[t.id+\".camera\"]=t.getCamera()),t.isAspectChanged(r)&&(e[t.id+\".aspectratio\"]=t.glplot.getAspectratio(),\"manual\"!==r[t.id].aspectmode&&(t.fullSceneLayout.aspectmode=r[t.id].aspectmode=e[t.id+\".aspectmode\"]=\"manual\")),e},i=function(t){if(!1!==t.fullSceneLayout.dragmode){var e=n();t.saveLayout(r),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas&&(t.glplot.canvas.addEventListener(\"mouseup\",(function(){i(t)})),t.glplot.canvas.addEventListener(\"wheel\",(function(r){if(e._context._scrollZoom.gl3d){if(t.camera._ortho){var n=r.deltaX>r.deltaY?1.1:1/1.1,a=t.glplot.getAspectratio();t.glplot.setAspectratio({x:n*a.x,y:n*a.y,z:n*a.z})}i(t)}}),!!c&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",(function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e=n();t.graphDiv.emit(\"plotly_relayouting\",e)}})),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",(function(r){e&&e.emit&&e.emit(\"plotly_webglcontextlost\",{event:r,layer:t.id})}),!1)),t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(){t.render()},!0},w.render=function(){var t,e=this,r=e.graphDiv,n=e.svgContainer,i=e.container.getBoundingClientRect();r._fullLayout._calcInverseTransform(r);var a=r._fullLayout._invScaleX,o=r._fullLayout._invScaleY,s=i.width*a,l=i.height*o;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+s+\" \"+l),n.setAttributeNS(null,\"width\",s),n.setAttributeNS(null,\"height\",l),b(e),e.glplot.axes.update(e.axesOptions);for(var c,u=Object.keys(e.traces),h=null,g=e.glplot.selection,m=0;m<u.length;++m)\"skip\"!==(t=e.traces[u[m]]).data.hoverinfo&&t.handlePick(g)&&(h=t),t.setContourLevels&&t.setContourLevels();function y(t,r){var n=e.fullSceneLayout[t];return p.tickText(n,n.d2l(r),\"hover\").text}if(null!==h){var x=v(e.glplot.cameraParams,g.dataCoordinate);t=h.data;var _,w=r._fullData[t.index],T=g.index,k={xLabel:y(\"xaxis\",g.traceCoordinate[0]),yLabel:y(\"yaxis\",g.traceCoordinate[1]),zLabel:y(\"zaxis\",g.traceCoordinate[2])},M=d.castHoverinfo(w,e.fullLayout,T),A=(M||\"\").split(\"+\"),S=M&&\"all\"===M;w.hovertemplate||S||(-1===A.indexOf(\"x\")&&(k.xLabel=void 0),-1===A.indexOf(\"y\")&&(k.yLabel=void 0),-1===A.indexOf(\"z\")&&(k.zLabel=void 0),-1===A.indexOf(\"text\")&&(g.textLabel=void 0),-1===A.indexOf(\"name\")&&(h.name=void 0));var E=[];\"cone\"===t.type||\"streamtube\"===t.type?(k.uLabel=y(\"xaxis\",g.traceCoordinate[3]),(S||-1!==A.indexOf(\"u\"))&&E.push(\"u: \"+k.uLabel),k.vLabel=y(\"yaxis\",g.traceCoordinate[4]),(S||-1!==A.indexOf(\"v\"))&&E.push(\"v: \"+k.vLabel),k.wLabel=y(\"zaxis\",g.traceCoordinate[5]),(S||-1!==A.indexOf(\"w\"))&&E.push(\"w: \"+k.wLabel),k.normLabel=g.traceCoordinate[6].toPrecision(3),(S||-1!==A.indexOf(\"norm\"))&&E.push(\"norm: \"+k.normLabel),\"streamtube\"===t.type&&(k.divergenceLabel=g.traceCoordinate[7].toPrecision(3),(S||-1!==A.indexOf(\"divergence\"))&&E.push(\"divergence: \"+k.divergenceLabel)),g.textLabel&&E.push(g.textLabel),_=E.join(\"<br>\")):\"isosurface\"===t.type||\"volume\"===t.type?(k.valueLabel=p.tickText(e._mockAxis,e._mockAxis.d2l(g.traceCoordinate[3]),\"hover\").text,E.push(\"value: \"+k.valueLabel),g.textLabel&&E.push(g.textLabel),_=E.join(\"<br>\")):_=g.textLabel;var C={x:g.traceCoordinate[0],y:g.traceCoordinate[1],z:g.traceCoordinate[2],data:w._input,fullData:w,curveNumber:w.index,pointNumber:T};d.appendArrayPointValue(C,w,T),t._module.eventData&&(C=w._module.eventData(C,g,w,{},T));var L={points:[C]};e.fullSceneLayout.hovermode&&d.loneHover({trace:w,x:(.5+.5*x[0]/x[3])*s,y:(.5-.5*x[1]/x[3])*l,xLabel:k.xLabel,yLabel:k.yLabel,zLabel:k.zLabel,text:_,name:h.name,color:d.castHoverOption(w,T,\"bgcolor\")||h.color,borderColor:d.castHoverOption(w,T,\"bordercolor\"),fontFamily:d.castHoverOption(w,T,\"font.family\"),fontSize:d.castHoverOption(w,T,\"font.size\"),fontColor:d.castHoverOption(w,T,\"font.color\"),nameLength:d.castHoverOption(w,T,\"namelength\"),textAlign:d.castHoverOption(w,T,\"align\"),hovertemplate:f.castOption(w,T,\"hovertemplate\"),hovertemplateLabels:f.extendFlat({},C,k),eventData:[C]},{container:n,gd:r}),g.buttons&&g.distance<5?r.emit(\"plotly_click\",L):r.emit(\"plotly_hover\",L),c=L}else d.loneUnhover(n),r.emit(\"plotly_unhover\",c);e.drawAnnotations(e)},w.recoverContext=function(){var t=this;t.glplot.dispose();var e=function(){t.glplot.gl.isContextLost()?requestAnimationFrame(e):t.initializeGLPlot()?t.plot.apply(t,t.plotArgs):f.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")};requestAnimationFrame(e)};var k=[\"xaxis\",\"yaxis\",\"zaxis\"];function M(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=k[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],u=e[\"_\"+o+\"length\"];if(f.isArrayOrTypedArray(l))for(var h,p=0;p<(u||l.length);p++)if(f.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)h=s.d2l(l[p][d],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else h=s.d2l(l[p],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],u-1)}}w.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];this.fullLayout=e,this.fullSceneLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setViewport(c),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.setClearColor(g(c.bgcolor)),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&M(this,n,f);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=k[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,f);var h=[1,1,1];for(o=0;o<3;++o)f[1][o]===f[0][o]?h[o]=1:h[o]=1/(f[1][o]-f[0][o]);for(this.dataScale=h,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var p=Object.keys(this.traces);t:for(a=0;a<p.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===p[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[p[a]]).dispose(),delete this.traces[p[a]]}this.glplot.objects.sort((function(t,e){return t._trace.data.index-e._trace.data.index}));var d,m=[[0,0,0],[0,0,0]],v=[],y={};for(a=0;a<3;++a){if((l=(s=c[k[a]]).type)in y?(y[l].acc*=h[a],y[l].count+=1):y[l]={acc:h[a],count:1},s.autorange){m[0][a]=1/0,m[1][a]=-1/0;var x=this.glplot.objects,b=this.fullSceneLayout.annotations||[],_=s._name.charAt(0);for(o=0;o<x.length;o++){var w=x[o],T=w.bounds,A=w._trace.data._pad||0;\"ErrorBars\"===w.constructor.name&&s._lowerLogErrorBound?m[0][a]=Math.min(m[0][a],s._lowerLogErrorBound):m[0][a]=Math.min(m[0][a],T[0][a]/h[a]-A),m[1][a]=Math.max(m[1][a],T[1][a]/h[a]+A)}for(o=0;o<b.length;o++){var S=b[o];if(S.visible){var E=s.r2l(S[_]);m[0][a]=Math.min(m[0][a],E),m[1][a]=Math.max(m[1][a],E)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(m[0][a]=Math.min(m[0][a],0),m[1][a]=Math.max(m[1][a],0)),m[0][a]>m[1][a])m[0][a]=-1,m[1][a]=1;else{var C=m[1][a]-m[0][a];m[0][a]-=C/32,m[1][a]+=C/32}if(\"reversed\"===s.autorange){var L=m[0][a];m[0][a]=m[1][a],m[1][a]=L}}else{var I=s.range;m[0][a]=s.r2l(I[0]),m[1][a]=s.r2l(I[1])}m[0][a]===m[1][a]&&(m[0][a]-=1,m[1][a]+=1),v[a]=m[1][a]-m[0][a],this.glplot.setBounds(a,{min:m[0][a]*h[a],max:m[1][a]*h[a]})}var P=c.aspectmode;if(\"cube\"===P)d=[1,1,1];else if(\"manual\"===P){var z=c.aspectratio;d=[z.x,z.y,z.z]}else{if(\"auto\"!==P&&\"data\"!==P)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var O=[1,1,1];for(a=0;a<3;++a){var D=y[l=(s=c[k[a]]).type];O[a]=Math.pow(D.acc,1/D.count)/h[a]}d=\"data\"===P||Math.max.apply(null,O)/Math.min.apply(null,O)<=4?O:[1,1,1]}c.aspectratio.x=u.aspectratio.x=d[0],c.aspectratio.y=u.aspectratio.y=d[1],c.aspectratio.z=u.aspectratio.z=d[2],this.glplot.setAspectratio(c.aspectratio),this.viewInitial.aspectratio||(this.viewInitial.aspectratio={x:c.aspectratio.x,y:c.aspectratio.y,z:c.aspectratio.z}),this.viewInitial.aspectmode||(this.viewInitial.aspectmode=c.aspectmode);var R=c.domain||null,F=e._size||null;if(R&&F){var B=this.container.style;B.position=\"absolute\",B.left=F.l+R.x[0]*F.w+\"px\",B.top=F.t+(1-R.y[1])*F.h+\"px\",B.width=F.w*(R.x[1]-R.x[0])+\"px\",B.height=F.h*(R.y[1]-R.y[0])+\"px\"}this.glplot.redraw()}},w.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},w.getCamera=function(){var t;return this.camera.view.recalcMatrix(this.camera.view.lastT()),{up:{x:(t=this.camera).up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}},w.setViewport=function(t){var e,r=t.camera;this.camera.lookAt.apply(this,[[(e=r).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]),this.glplot.setAspectratio(t.aspectratio),\"orthographic\"===r.projection.type!==this.camera._ortho&&(this.glplot.redraw(),this.glplot.clearRGBA(),this.glplot.dispose(),this.initializeGLPlot())},w.isCameraChanged=function(t){var e=this.getCamera(),r=f.nestedProperty(t,this.id+\".camera\").get();function n(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}var i=!1;if(void 0===r)i=!0;else{for(var a=0;a<3;a++)for(var o=0;o<3;o++)if(!n(e,r,a,o)){i=!0;break}(!r.projection||e.projection&&e.projection.type!==r.projection.type)&&(i=!0)}return i},w.isAspectChanged=function(t){var e=this.glplot.getAspectratio(),r=f.nestedProperty(t,this.id+\".aspectratio\").get();return void 0===r||r.x!==e.x||r.y!==e.y||r.z!==e.z},w.saveLayout=function(t){var e,r,n,i,a,o,s=this.fullLayout,l=this.isCameraChanged(t),c=this.isAspectChanged(t),h=l||c;if(h){var p={};if(l&&(e=this.getCamera(),n=(r=f.nestedProperty(t,this.id+\".camera\")).get(),p[this.id+\".camera\"]=n),c&&(i=this.glplot.getAspectratio(),o=(a=f.nestedProperty(t,this.id+\".aspectratio\")).get(),p[this.id+\".aspectratio\"]=o),u.call(\"_storeDirectGUIEdit\",t,s._preGUI,p),l)r.set(e),f.nestedProperty(s,this.id+\".camera\").set(e);if(c)a.set(i),f.nestedProperty(s,this.id+\".aspectratio\").set(i),this.glplot.redraw()}return h},w.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var c=this.id+\".camera.up\",h={x:0,y:0,z:1},p={};p[c]=h;var d=n.layout;u.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=h,f.nestedProperty(d,c).set(h)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},w.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a),function(t,e,r){for(var n=0,i=r-1;n<i;++n,--i)for(var a=0;a<e;++a)for(var o=0;o<4;++o){var s=4*(e*n+a)+o,l=4*(e*i+a)+o,c=t[s];t[s]=t[l],t[l]=c}}(a,r,i),function(t,e,r){for(var n=0;n<r;++n)for(var i=0;i<e;++i){var a=4*(e*n+i),o=t[a+3];if(o>0)for(var s=255/o,l=0;l<3;++l)t[a+l]=Math.min(s*t[a+l],255)}}(a,r,i);var o=document.createElement(\"canvas\");o.width=r,o.height=i;var s,l=o.getContext(\"2d\"),c=l.createImageData(r,i);switch(c.data.set(a),l.putImageData(c,0,0),t){case\"jpeg\":s=o.toDataURL(\"image/jpeg\");break;case\"webp\":s=o.toDataURL(\"image/webp\");break;default:s=o.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),s},w.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[k[t]];p.setConvert(e,this.fullLayout),e.setScale=f.noop}},w.make4thDimension=function(){var t=this.graphDiv._fullLayout;this._mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},p.setConvert(this._mockAxis,t)},e.exports=_},{\"../../components/fx\":683,\"../../lib\":778,\"../../lib/show_no_webgl_msg\":800,\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./layout/convert\":874,\"./layout/spikes\":877,\"./layout/tick_marks\":878,\"./project\":879,\"gl-plot3d\":321,\"has-passive-events\":441,\"webgl-context\":606}],881:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],882:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"../components/shapes/draw_newshape/attributes\"),s=t(\"./pad_attributes\"),l=t(\"../lib/extend\").extendFlat,c=n({editType:\"calc\"});c.family.dflt='\"Open Sans\", verdana, arial, sans-serif',c.size.dflt=12,c.color.dflt=a.defaultLine,e.exports={font:c,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:l(s({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},uniformtext:{mode:{valType:\"enumerated\",values:[!1,\"hide\",\"show\"],dflt:!1,editType:\"plot\"},minsize:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},computed:{valType:\"any\",editType:\"none\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},newshape:o.newshape,activeshape:o.activeshape,meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:l({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":642,\"../components/shapes/draw_newshape/attributes\":725,\"../lib/extend\":768,\"./animation_attributes\":822,\"./font_attributes\":856,\"./pad_attributes\":890}],883:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.10.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.10.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],884:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":778}],885:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=i.strTranslate,o=i.strScale,s=t(\"../../plots/get_data\").getSubplotCalcData,l=t(\"../../constants/xmlns_namespaces\"),c=t(\"d3\"),u=t(\"../../components/drawing\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./mapbox\"),p=r.constants=t(\"./constants\");function d(t){return\"string\"==typeof t&&(-1!==p.styleValuesMapbox.indexOf(t)||0===t.indexOf(\"mapbox://\"))}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,a=e._subplots.mapbox;if(n.version!==p.requiredVersion)throw new Error(p.wrongVersionErrorMsg);var o=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;d(c.style)&&(u?i.pushUnique(n,u):(d(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var f=o?p.noAccessTokenErrorMsg:p.missingStyleErrorMsg;throw i.error(f),new Error(f)}return n.length?(n.length>1&&i.warn(p.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,a);n.accessToken=o;for(var l=0;l<a.length;l++){var c=a[l],u=s(r,\"mapbox\",c),f=e[c],g=f._subplot;g||(g=new h(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},f.center),zoom:f.zoom,bearing:f.bearing,pitch:f.pitch}),g.plot(u,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var s=e[r[i]],h=s.domain,d=s._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":d,x:n.l+n.w*h.x[0],y:n.t+n.h*(1-h.y[1]),width:n.w*(h.x[1]-h.x[0]),height:n.h*(h.y[1]-h.y[0]),preserveAspectRatio:\"none\"});var g=c.select(s._subplot.div);if(!(null===g.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var m=e._glimages.append(\"g\");m.attr(\"transform\",a(n.l+n.w*h.x[0]+10,n.t+n.h*(1-h.y[0])-31)),m.append(\"path\").attr(\"d\",p.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),m.append(\"path\").attr(\"d\",p.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),m.append(\"path\").attr(\"d\",p.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),m.append(\"polygon\").attr(\"points\",p.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var v=g.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),y=e._glimages.append(\"g\"),x=y.append(\"text\");x.text(v).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":v});var b=u.bBox(x.node()),_=n.w*(h.x[1]-h.x[0]);if(b.width>_/2){var w=v.split(\"|\").join(\"<br>\");x.text(w).attr(\"data-unformatted\",w).call(f.convertToTspans,t),b=u.bBox(x.node())}x.attr(\"transform\",a(-3,8-b.height)),y.insert(\"rect\",\".static-attribution\").attr({x:-b.width-6,y:-b.height-3,width:b.width+6,height:b.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var T=1;b.width+6>_&&(T=_/(b.width+6));var k=[n.l+n.w*h.x[1],n.t+n.h*(1-h.y[0])];y.attr(\"transform\",a(k[0],k[1])+o(T))}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":665,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/get_data\":865,\"./constants\":883,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./mapbox\":889,d3:169,\"mapbox-gl\":473}],886:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/svg_text_utils\").sanitizeHTML,a=t(\"./convert_text_opts\"),o=t(\"./constants\");function s(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=o.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var l=s.prototype;function c(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if(\"string\"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||\"string\"==typeof e&&e.length>0}function u(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var i=t.symbol,o=a(i.textposition,i.iconsize);n.extendFlat(e,{\"icon-image\":i.icon+\"-15\",\"icon-size\":i.iconsize/10,\"text-field\":i.text,\"text-size\":i.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":i.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":i.textfont.color,\"text-opacity\":t.opacity});break;case\"raster\":n.extendFlat(r,{\"raster-fade-duration\":0,\"raster-opacity\":t.opacity})}return{layout:e,paint:r}}l.update=function(t){this.visible?this.needsNewImage(t)?this.updateImage(t):this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=c(t)},l.needsNewImage=function(t){return this.subplot.map.getSource(this.idSource)&&\"image\"===this.sourceType&&\"image\"===t.sourcetype&&(this.source!==t.source||JSON.stringify(this.coordinates)!==JSON.stringify(t.coordinates))},l.needsNewSource=function(t){return this.sourceType!==t.sourcetype||JSON.stringify(this.source)!==JSON.stringify(t.source)||this.layerType!==t.type},l.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},l.lookupBelow=function(){return this.subplot.belowLookup[\"layout-\"+this.index]},l.updateImage=function(t){this.subplot.map.getSource(this.idSource).updateImage({url:t.source,coordinates:t.coordinates});var e=this.findFollowingMapboxLayerId(this.lookupBelow());null!==e&&this.subplot.map.moveLayer(this.idLayer,e)},l.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,c(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,a={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",a.tileSize=256):\"image\"===r&&(e=\"url\",a.coordinates=t.coordinates);a[e]=n,t.sourceattribution&&(a.attribution=i(t.sourceattribution));return a}(t);e.addSource(this.idSource,r)}},l.findFollowingMapboxLayerId=function(t){if(\"traces\"===t)for(var e=this.subplot.getMapLayers(),r=0;r<e.length;r++){var n=e[r].id;if(\"string\"==typeof n&&0===n.indexOf(o.traceLayerPrefix)){t=n;break}}return t},l.updateLayer=function(t){var e=this.subplot,r=u(t),n=this.lookupBelow(),i=this.findFollowingMapboxLayerId(n);this.removeLayer(),c(t)&&e.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:r.layout,paint:r.paint},i),this.layerType=t.type,this.below=n},l.updateStyle=function(t){if(c(t)){var e=u(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},l.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},l.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new s(t,e);return n.update(r),n}},{\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"./constants\":883,\"./convert_text_opts\":884}],887:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),f=o({});f.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:f,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../traces/scatter/attributes\":1187,\"../domain\":855,\"../font_attributes\":856,\"./constants\":883}],888:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":778,\"../array_container_defaults\":823,\"../subplot_defaults\":905,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../registry\"),s=t(\"../cartesian/axes\"),l=t(\"../../components/dragelement\"),c=t(\"../../components/fx\"),u=t(\"../../components/dragelement/helpers\"),f=u.rectMode,h=u.drawMode,p=u.selectMode,d=t(\"../cartesian/select\").prepSelect,g=t(\"../cartesian/select\").clearSelect,m=t(\"../cartesian/select\").clearSelectionsCache,v=t(\"../cartesian/select\").selectOnClick,y=t(\"./constants\"),x=t(\"./layers\");function b(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={},this.dragging=!1,this.wheeling=!1}var _=b.prototype;_.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash={},i.layerList=[]),n=i.map?new Promise((function(r,n){i.updateMap(t,e,r,n)})):new Promise((function(r,n){i.createMap(t,e,r,n)})),r.push(n)},_.createMap=function(t,e,r,i){var o=this,s=e[o.id],l=o.styleObj=T(s.style);o.accessToken=s.accesstoken;var c=o.map=new n.Map({container:o.div,style:l.style,center:M(s.center),zoom:s.zoom,bearing:s.bearing,pitch:s.pitch,interactive:!o.isStatic,preserveDrawingBuffer:o.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));c._canvas.style.left=\"0px\",c._canvas.style.top=\"0px\",o.rejectOnError(i),o.isStatic||o.initFx(t,e);var u=[];u.push(new Promise((function(t){c.once(\"load\",t)}))),u=u.concat(a.fetchTraceGeoData(t)),Promise.all(u).then((function(){o.fillBelowLookup(t,e),o.updateData(t),o.updateLayout(e),o.resolveOnRender(r)})).catch(i)},_.updateMap=function(t,e,r,n){var i=this,o=i.map,s=e[this.id];i.rejectOnError(n);var l=[],c=T(s.style);JSON.stringify(i.styleObj)!==JSON.stringify(c)&&(i.styleObj=c,o.setStyle(c.style),i.traceHash={},l.push(new Promise((function(t){o.once(\"styledata\",t)})))),l=l.concat(a.fetchTraceGeoData(t)),Promise.all(l).then((function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)})).catch(n)},_.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,f,h={};for(u in a)h[n=a[u]]?h[n].push(u):h[n]=[u];for(n in h){var p=h[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(f=u.split(\"trace-\")[1],this.traceHash[f]&&(this.traceHash[f].below=null)):0===u.indexOf(\"layout-\")&&(f=u.split(\"layout-\")[1],this.layerList[f]&&(this.layerList[f].below=null))}};var w={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function T(t){var e={};return i.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==y.styleValuesMapbox.indexOf(t)?e.style=k(t):y.stylesNonMapbox[t]?e.style=y.stylesNonMapbox[t]:e.style=t):(e.id=y.styleValueDflt,e.style=k(y.styleValueDflt)),e.transition={duration:0,delay:0},e}function k(t){return y.styleUrlPrefix+t+\"-\"+y.styleUrlSuffix}function M(t){return[t.lon,t.lat]}_.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort((function(t,e){return w[t[0].trace.type]-w[e[0].trace.type]}));for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=a[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(a[r.uid]=r._module.plot(this,s))}var c=Object.keys(a);t:for(n=0;n<c.length;n++){var u=c[n];for(i=0;i<t.length;i++)if(u===(r=t[i][0].trace).uid)continue t;(e=a[u]).dispose(),delete a[u]}},_.updateLayout=function(t){var e=this.map,r=t[this.id];this.dragging||this.wheeling||(e.setCenter(M(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch)),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},_.resolveOnRender=function(t){var e=this.map;e.on(\"render\",(function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,10))}))},_.rejectOnError=function(t){var e=this.map;function r(){t(new Error(y.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},_.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},s.setConvert(e.mockAxis,t)},_.initFx=function(t,e){var r=this,n=r.gd,i=r.map;function a(){c.loneUnhover(e._hoverlayer)}function s(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEditsWithDerived(t))}i.on(\"moveend\",(function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||r.wheeling){var i=e[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))}t.originalEvent&&\"mouseup\"===t.originalEvent.type?r.dragging=!1:r.wheeling&&(r.wheeling=!1),e._rehover&&e._rehover()}})),i.on(\"wheel\",(function(){r.wheeling=!0})),i.on(\"mousemove\",(function(t){var e=r.div.getBoundingClientRect(),a=[t.originalEvent.offsetX,t.originalEvent.offsetY];t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return i.unproject(a).lng},r.yaxis.p2c=function(){return i.unproject(a).lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&c.hover(n,t,r.id)},c.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id})),i.on(\"dragstart\",(function(){r.dragging=!0,a()})),i.on(\"zoomstart\",a),i.on(\"mouseout\",(function(){n._fullLayout._hoversubplot=null})),i.on(\"drag\",s),i.on(\"zoom\",s),i.on(\"dblclick\",(function(){var t=n._fullLayout[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(M(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))})),r.clearSelect=function(){m(r.dragOptions),g(r.dragOptions.gd)},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&v(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&c.click(n,e.originalEvent)}}},_.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var a,o=t.dragmode;a=f(o)?function(t,r){(t.range={})[e.id]=[c([r.xmin,r.ymin]),c([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(c)};var s=e.dragOptions;e.dragOptions=i.extendDeep(s||{},{dragmode:t.dragmode,element:e.div,gd:n,plotinfo:{id:e.id,domain:t[e.id].domain,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:a},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),p(o)||h(o)?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){d(t,r,n,e.dragOptions,o)},l.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function c(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},_.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},_.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(x(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},_.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},_.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},_.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},_.getMapLayers=function(){return this.map.getStyle().layers},_.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),a=0;a<n.length;a++)if(e===n[a].id)return void r.addLayer(t,e);i.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},_.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},_.getView=function(){var t=this.map,e=t.getCenter(),r={lon:e.lng,lat:e.lat},n=t.getCanvas(),i=n.width,a=n.height;return{center:r,zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch(),_derived:{coordinates:[t.unproject([0,0]).toArray(),t.unproject([i,0]).toArray(),t.unproject([i,a]).toArray(),t.unproject([0,a]).toArray()]}}},_.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},_.getViewEditsWithDerived=function(t){var e=this.id,r=this.getViewEdits(t);return r[e+\"._derived\"]=t._derived,r},e.exports=b},{\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../registry\":911,\"../cartesian/axes\":828,\"../cartesian/select\":847,\"./constants\":883,\"./layers\":886,\"mapbox-gl\":473}],890:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").timeFormatLocale,a=t(\"fast-isnumeric\"),o=t(\"../registry\"),s=t(\"../plot_api/plot_schema\"),l=t(\"../plot_api/plot_template\"),c=t(\"../lib\"),u=t(\"../components/color\"),f=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),p=t(\"./cartesian/handle_outline\").clearSelect,d=t(\"./animation_attributes\"),g=t(\"./frame_attributes\"),m=t(\"../plots/get_data\").getModuleCalcData,v=c.relinkPrivateKeys,y=c._,x=e.exports={};c.extendFlat(x,o),x.attributes=t(\"./attributes\"),x.attributes.type.values=x.allTypes,x.fontAttrs=t(\"./font_attributes\"),x.layoutAttributes=t(\"./layout_attributes\"),x.fontWeight=\"normal\";var b=x.transformsRegistry,_=t(\"./command\");x.executeAPICommand=_.executeAPICommand,x.computeAPICommandBindings=_.computeAPICommandBindings,x.manageCommandObserver=_.manageCommandObserver,x.hasSimpleAPICommandBindings=_.hasSimpleAPICommandBindings,x.redrawText=function(t){var e=(t=c.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise((function(e){setTimeout((function(){o.getComponentMethod(\"annotations\",\"draw\")(t),o.getComponentMethod(\"legend\",\"draw\")(t),o.getComponentMethod(\"colorbar\",\"draw\")(t),e(x.previousPromises(t))}),300)}))},x.resize=function(t){var e;t=c.getGraphDiv(t);var r=new Promise((function(r,n){t&&!c.isHidden(t)||n(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._resolveResize&&(e=t._resolveResize),t._resolveResize=r,t._redrawTimer=setTimeout((function(){if(!t.layout||t.layout.width&&t.layout.height||c.isHidden(t))r(t);else{delete t.layout.width,delete t.layout.height;var e=t.changed;t.autoplay=!0,o.call(\"relayout\",t,{autosize:!0}).then((function(){t.changed=e,t._resolveResize===r&&(delete t._resolveResize,r(t))}))}}),100)}));return e&&e(r),r},x.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then((function(){t._promises=[]}))},x.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=c.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",(function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:u.defaultLine,\"pointer-events\":\"all\"}).each((function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)}))})),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),l=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",(function(){x.sendDataToCloud(t)}));else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&l.text()?\" - \":\"\")}},x.sendDataToCloud=function(t){var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL;if(e){t.emit(\"plotly_beforeexport\");var r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=x.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1}};var w=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],T=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function k(t,e){var r=t._context.locale;r||(r=\"en-US\");var n=!1,i={};function a(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(a(u),n))break;l=o.localeRegistry}var f=r.split(\"-\")[0];if(n||f===r)break;r=f}return n||a(o.localeRegistry.en.format),i}function M(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function A(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||b[n.type];if(i&&i.makesData)return!0}return!1}function S(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=b[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function E(t){return\"string\"==typeof t&&\"px\"===t.substr(t.length-2)&&parseFloat(t)}function C(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}x.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,a=t._fullLayout||{};if(a._skipDefaults)delete a._skipDefaults;else{var s,l=t._fullLayout={},u=t.layout||{},f=t._fullData||[],h=t._fullData=[],d=t.data||[],g=t.calcdata||[],m=t._context||{};t._transitionData||x.createTransitionData(t),l._dfltTitle={plot:y(t,\"Click to enter Plot title\"),x:y(t,\"Click to enter X axis title\"),y:y(t,\"Click to enter Y axis title\"),colorbar:y(t,\"Click to enter Colorscale title\"),annotation:y(t,\"new text\")},l._traceWord=y(t,\"trace\");var b=k(t,w);if(l._mapboxAccessToken=m.mapboxAccessToken,a._initialAutoSizeIsDone){var _=a.width,M=a.height;x.supplyLayoutGlobalDefaults(u,l,b),u.width||(l.width=_),u.height||(l.height=M),x.sanitizeMargins(l)}else{x.supplyLayoutGlobalDefaults(u,l,b);var A=!u.width||!u.height,S=l.autosize,E=m.autosizable;A&&(S||E)?x.plotAutoSize(t,u,l):A&&x.sanitizeMargins(l),!S&&A&&(u.width=l.width,u.height=l.height)}l._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),{numberFormat:n.locale(t).numberFormat,timeFormat:i(t).utcFormat}}(b,l.separators),l._extraFormat=k(t,T),l._initialAutoSizeIsDone=!0,l._dataLength=d.length,l._modules=[],l._visibleModules=[],l._basePlotModules=[];var L=l._subplots=function(){var t,e,r=o.collectableSubplotTypes,n={};if(!r){r=[];var i=o.subplotsRegistry;for(var a in i){var s=i[a].attr;if(s&&(r.push(a),Array.isArray(s)))for(e=0;e<s.length;e++)c.pushUnique(r,s[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),I=l._splomAxes={x:{},y:{}},P=l._splomSubplots={};l._splomGridDflt={},l._scatterStackOpts={},l._firstScatter={},l._alignmentOpts={},l._colorAxes={},l._requestRangeslider={},l._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,l=new Array(i),u={};function f(t,e){l[e]=t,u[t]=1}function h(t,e){if(t&&\"string\"==typeof t&&!u[t])return f(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),h(p,r)||(r<s&&h(a[r].uid,r)||f(c.randstr(u),r))}return l}(f,d),l._globalTransforms=(t._context||{}).globalTransforms,x.supplyDataDefaults(d,h,u,l);var z=Object.keys(I.x),O=Object.keys(I.y);if(z.length>1&&O.length>1){for(o.getComponentMethod(\"grid\",\"sizeDefaults\")(u,l),s=0;s<z.length;s++)c.pushUnique(L.xaxis,z[s]);for(s=0;s<O.length;s++)c.pushUnique(L.yaxis,O[s]);for(var D in P)c.pushUnique(L.cartesian,D)}if(l._has=x._hasPlotType.bind(l),f.length===h.length)for(s=0;s<h.length;s++)v(h[s],f[s]);x.supplyLayoutModuleDefaults(u,l,h,t._transitionData);var R=l._visibleModules,F=[];for(s=0;s<R.length;s++){var B=R[s].crossTraceDefaults;B&&c.pushUnique(F,B)}for(s=0;s<F.length;s++)F[s](h,l);l._hasOnlyLargeSploms=1===l._basePlotModules.length&&\"splom\"===l._basePlotModules[0].name&&z.length>15&&O.length>15&&0===l.shapes.length&&0===l.images.length,l._hasCartesian=l._has(\"cartesian\"),l._hasGeo=l._has(\"geo\"),l._hasGL3D=l._has(\"gl3d\"),l._hasGL2D=l._has(\"gl2d\"),l._hasTernary=l._has(\"ternary\"),l._hasPie=l._has(\"pie\"),x.linkSubplots(h,l,f,a),x.cleanPlot(h,l,f,a);var N=!(!a._has||!a._has(\"gl2d\")),j=!(!l._has||!l._has(\"gl2d\")),U=!(!a._has||!a._has(\"cartesian\"))||N,V=!(!l._has||!l._has(\"cartesian\"))||j;U&&!V?a._bgLayer.remove():V&&!U&&(l._shouldCreateBgLayer=!0),a._zoomlayer&&!t._dragging&&p({_fullLayout:a}),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,l),v(l,a),o.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,l),l._preGUI||(l._preGUI={}),l._tracePreGUI||(l._tracePreGUI={});var q,H=l._tracePreGUI,G={};for(q in H)G[q]=\"old\";for(s=0;s<h.length;s++)G[q=h[s]._fullInput.uid]||(H[q]={}),G[q]=\"new\";for(q in G)\"old\"===G[q]&&delete H[q];C(l),o.getComponentMethod(\"rangeslider\",\"makeData\")(l),r||g.length!==h.length||x.supplyDefaultsUpdateCalc(g,h)}},x.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,l,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],l=c.nestedProperty(a,s).get().slice(),c.nestedProperty(n,s).set(l)}i.trace=n}}},x.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},x._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var a=o.modules[i];if(a&&a.categories[t])return!0}return!1},x.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var f=r[i].uid;for(a=0;a<t.length;a++){if(f===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+f).remove()}},x.linkSubplots=function(t,e,r,n){var i,a,s=n._plots||{},l=e._plots={},u=e._subplots,f={_fullData:t,_fullLayout:e},p=u.cartesian.concat(u.gl2d||[]);for(i=0;i<p.length;i++){var d,g=p[i],m=s[g],v=h.getFromId(f,g,\"x\"),y=h.getFromId(f,g,\"y\");for(m?d=l[g]=m:(d=l[g]={}).id=g,v._counterAxes.push(y._id),y._counterAxes.push(v._id),v._subplotsWith.push(g),y._subplotsWith.push(g),d.xaxis=v,d.yaxis=y,d._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var x=t[a];if(x.xaxis===d.xaxis._id&&x.yaxis===d.yaxis._id&&!1===x.cliponaxis){d._hasClipOnAxisFalse=!0;break}}}var b,_=h.list(f,null,!0);for(i=0;i<_.length;i++){var w=null;(b=_[i]).overlaying&&(w=h.getFromId(f,b.overlaying))&&w.overlaying&&(b.overlaying=!1,w=null),b._mainAxis=w||b,w&&(b.domain=w.domain.slice()),b._anchorAxis=\"free\"===b.anchor?null:h.getFromId(f,b.anchor)}for(i=0;i<_.length;i++)if((b=_[i])._counterAxes.sort(h.idSort),b._subplotsWith.sort(c.subplotSort),b._mainSubplot=M(b,e),b._counterAxes.length&&(b.spikemode&&-1!==b.spikemode.indexOf(\"across\")||b.automargin&&b.mirror&&\"free\"!==b.anchor||o.getComponentMethod(\"rangeslider\",\"isVisible\")(b))){var T=1,k=0;for(a=0;a<b._counterAxes.length;a++){var A=h.getFromId(f,b._counterAxes[a]);T=Math.min(T,A.domain[0]),k=Math.max(k,A.domain[1])}T<k&&(b._counterDomainMin=T,b._counterDomainMax=k)}},x.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],s.crawl(t._module.attributes,(function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))}))),n=0;n<e.length;n++){c.nestedProperty(t,\"_input.\"+e[n]).get()||c.nestedProperty(t,e[n]).set(null)}},x.supplyDataDefaults=function(t,e,r,n){var i,a,s,u=n._modules,f=n._visibleModules,h=n._basePlotModules,p=0,d=0;function g(t){e.push(t);var r=t._module;r&&(c.pushUnique(u,r),!0===t.visible&&c.pushUnique(f,r),c.pushUnique(h,t._module.basePlotModule),p++,!1!==t._input.visible&&d++)}n._transformModules=[];var m={},y=[],b=(r.template||{}).data||{},_=l.traceTemplater(b);for(i=0;i<t.length;i++){if(s=t[i],(a=_.newTrace(s)).uid=n._traceUids[i],x.supplyTraceDefaults(s,a,d,n,i),a.index=i,a._input=s,a._expandedIndex=p,a.transforms&&a.transforms.length)for(var w=!1!==s.visible&&!1===a.visible,T=S(a,e,r,n),k=0;k<T.length;k++){var M=T[k],A={_template:a._template,type:a.type,uid:a.uid+k};w&&!1===M.visible&&delete M.visible,x.supplyTraceDefaults(M,A,p,n,i),v(A,M),A.index=i,A._input=s,A._fullInput=a,A._expandedIndex=p,A._expandedInput=M,g(A)}else a._fullInput=a,a._expandedInput=a,g(a);o.traceIs(a,\"carpetAxis\")&&(m[a.carpet]=a),o.traceIs(a,\"carpetDependent\")&&y.push(i)}for(i=0;i<y.length;i++)if((a=e[y[i]]).visible){var E=m[a.carpet];a._carpet=E,E&&E.visible?(a.xaxis=E.xaxis,a.yaxis=E.yaxis):a.visible=!1}},x.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return c.coerce(t||{},r,d,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=x.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=x.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=x.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=x.supplyAnimationTransitionDefaults(t.transition||{});return r},x.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},x.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},x.supplyFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t,e,g,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},x.supplyTraceDefaults=function(t,e,r,n,i){var a,s=n.colorway||u.defaults,l=s[r%s.length];function f(r,n){return c.coerce(t,e,x.attributes,r,n)}var h=f(\"visible\");f(\"type\"),f(\"name\",n._traceWord+\" \"+i),f(\"uirevision\",n.uirevision);var p=x.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var v=n._subplots,y=\"\";if(h||\"gl2d\"!==d.name){if(Array.isArray(g))for(a=0;a<g.length;a++){var b=g[a],_=c.coerce(t,e,m,b);v[b]&&c.pushUnique(v[b],_),y+=_}else y=c.coerce(t,e,m,g);v[d.name]&&c.pushUnique(v[d.name],y)}}}return h&&(f(\"customdata\"),f(\"ids\"),f(\"meta\"),o.traceIs(e,\"showLegend\")?(c.coerce(t,e,p.attributes.showlegend?p.attributes:x.attributes,\"showlegend\"),f(\"legendgroup\"),e._dfltShowLegend=!0):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,l,n),o.traceIs(e,\"noOpacity\")||f(\"opacity\"),o.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),o.traceIs(e,\"noHover\")||(e.hovertemplate||c.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&o.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,l,n)),p&&p.selectPoints&&f(\"selectedpoints\"),x.supplyTransformDefaults(t,e,n)),e},x.hasMakesDataTransform=A,x.supplyTransformDefaults=function(t,e,r){if(e._length||A(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],l=0;l<o.length;l++){var u,f=o[l],h=f.type,p=b[h],d=!(f._module&&f._module===p),g=p&&\"function\"==typeof p.transform;p||c.warn(\"Unrecognized transform type \"+h+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(f,e,r,t)).type=h,u._module=p,c.pushUnique(i,p)):u=c.extendFlat({},f),s.push(u)}}},x.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return c.coerce(t,e,x.layoutAttributes,r,n)}var i=t.template;c.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data),n(\"autotypenumbers\");var a=c.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),c.coerceFont(n,\"title.font\",{family:a.family,size:Math.round(1.4*a.size),color:a.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"uniformtext.mode\")&&n(\"uniformtext.minsize\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&x.sanitizeMargins(e),o.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",u.addOpacity(e.paper_bgcolor,.5));var l=u.contrast(u.rgb(e.modebar.bgcolor));n(\"modebar.color\",u.addOpacity(l,.3)),n(\"modebar.activecolor\",u.addOpacity(l,.7)),n(\"modebar.uirevision\",s),o.getComponentMethod(\"shapes\",\"supplyDrawNewShapeDefaults\")(t,e,n),n(\"meta\"),c.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),o.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),o.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},x.plotAutoSize=function(t,e,r){var n,i,o=t._context||{},s=o.frameMargins,l=c.isPlotDiv(t);if(l&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,i=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=l?window.getComputedStyle(t):{};if(n=E(u.width)||E(u.maxWidth)||r.width,i=E(u.height)||E(u.maxHeight)||r.height,a(s)&&s>0){var f=1-2*s;n=Math.round(f*n),i=Math.round(f*i)}}var h=x.layoutAttributes.width.min,p=x.layoutAttributes.height.min;n<h&&(n=h),i<p&&(i=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-i)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=i)),t._initialAutoSize||(t._initialAutoSize={width:n,height:i}),x.sanitizeMargins(r)},x.supplyLayoutModuleDefaults=function(t,e,r,n){var i,a,s,l=o.componentsRegistry,u=e._basePlotModules,f=o.subplotsRegistry.cartesian;for(i in l)(s=l[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var h in u.length||u.push(f),e._has(\"cartesian\")&&(o.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),f.finalizeSubplots(t,e)),e._subplots)e._subplots[h].sort(c.subplotSort);for(a=0;a<u.length;a++)(s=u[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(a=0;a<p.length;a++)(s=p[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(a=0;a<d.length;a++)(s=d[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in l)(s=l[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},x.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),c.clearThrottle(),c.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},x.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&c.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},x.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},x.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},x.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1};x.autoMargin=function(t,e,r){var n=t._fullLayout,i=n.width,a=n.height,o=n.margin,s=c.constrain(i-o.l-o.r,2,64),l=c.constrain(a-o.t-o.b,2,64),u=Math.max(0,i-s),f=Math.max(0,a-l),h=n._pushmargin,p=n._pushmarginIds;if(!1!==o.autoexpand){if(r){var d=r.pad;if(void 0===d&&(d=Math.min(12,o.l,o.r,o.t,o.b)),u){var g=(r.l+r.r)/u;g>1&&(r.l/=g,r.r/=g)}if(f){var m=(r.t+r.b)/f;m>1&&(r.t/=m,r.b/=m)}var v=void 0!==r.xl?r.xl:r.x,y=void 0!==r.xr?r.xr:r.x,b=void 0!==r.yt?r.yt:r.y,_=void 0!==r.yb?r.yb:r.y;h[e]={l:{val:v,size:r.l+d},r:{val:y,size:r.r+d},b:{val:_,size:r.b+d},t:{val:b,size:r.t+d}},p[e]=1}else delete h[e],delete p[e];if(!n._replotting)return x.doAutoMargin(t)}},x.doAutoMargin=function(t){var e=t._fullLayout,r=e.width,n=e.height;e._size||(e._size={}),C(e);var i=e._size,s=e.margin,l=c.extendFlat({},i),u=s.l,f=s.r,p=s.t,d=s.b,g=e._pushmargin,m=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var v in g)m[v]||delete g[v];for(var y in g.base={l:{val:0,size:u},r:{val:1,size:f},t:{val:1,size:p},b:{val:0,size:d}},g){var b=g[y].l||{},_=g[y].b||{},w=b.val,T=b.size,k=_.val,M=_.size;for(var A in g){if(a(T)&&g[A].r){var S=g[A].r.val,E=g[A].r.size;if(S>w){var L=(T*S+(E-r)*w)/(S-w),I=(E*(1-w)+(T-r)*(1-S))/(S-w);L+I>u+f&&(u=L,f=I)}}if(a(M)&&g[A].t){var P=g[A].t.val,z=g[A].t.size;if(P>k){var O=(M*P+(z-n)*k)/(P-k),D=(z*(1-k)+(M-n)*(1-P))/(P-k);O+D>d+p&&(d=O,p=D)}}}}}var R=c.constrain(r-s.l-s.r,2,64),F=c.constrain(n-s.t-s.b,2,64),B=Math.max(0,r-R),N=Math.max(0,n-F);if(B){var j=(u+f)/B;j>1&&(u/=j,f/=j)}if(N){var U=(d+p)/N;U>1&&(d/=U,p/=U)}if(i.l=Math.round(u),i.r=Math.round(f),i.t=Math.round(p),i.b=Math.round(d),i.p=Math.round(s.pad),i.w=Math.round(r)-i.l-i.r,i.h=Math.round(n)-i.t-i.b,!e._replotting&&x.didMarginChange(l,i)){\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1;var V=3*(1+Object.keys(m).length);if(e._redrawFromAutoMarginCount<V)return o.call(\"plot\",t);e._size=l,c.warn(\"Too many auto-margin redraws.\")}!function(t){for(var e=h.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r]._hideOutOfRangeInsideTickLabels;n&&n()}}(t)};var L=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function I(t,e,r){var n=!1;var i=[x.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,x.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise((function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push((function(){n=!0})),r.redraw&&t._transitionData._interruptCallbacks.push((function(){return o.call(\"redraw\",t)})),t._transitionData._interruptCallbacks.push((function(){t.emit(\"plotly_transitioninterrupted\",[])}));var a=0,s=0;function l(){return a++,function(){s++,n||s!==a||function(e){if(!t._transitionData)return;(function(t){if(t)for(;t.length;)t.shift()})(t._transitionData._interruptCallbacks),Promise.resolve().then((function(){if(r.redraw)return o.call(\"redraw\",t)})).then((function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])})).then(e)}(i)}}r.runFn(l),setTimeout(l())}))}],a=c.syncOrAsync(i,t);return a&&a.then||(a=Promise.resolve()),a.then((function(){return t}))}x.didMarginChange=function(t,e){for(var r=0;r<L.length;r++){var n=L[r],i=t[n],o=e[n];if(!a(i)||Math.abs(o-i)>1)return!0}return!1},x.graphJson=function(t,e,r,n,i,a){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&x.supplyDefaults(t);var o=i?t._fullData:t.data,s=i?t._fullLayout:t.layout,l=(t._transitionData||{})._frames;function u(t,e){if(\"function\"==typeof t)return e?\"_function_\":null;if(c.isPlainObject(t)){var n,i={};return Object.keys(t).sort().forEach((function(a){if(-1===[\"_\",\"[\"].indexOf(a.charAt(0)))if(\"function\"!=typeof t[a]){if(\"keepdata\"===r){if(\"src\"===a.substr(a.length-3))return}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0&&!c.isPlainObject(t.stream))return}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0)return;i[a]=u(t[a],e)}else e&&(i[a]=\"_function\")})),i}return Array.isArray(t)?t.map((function(t){return u(t,e)})):c.isTypedArray(t)?c.simpleMap(t,c.identity):c.isJSDate(t)?c.ms2DateTimeLocal(+t):t}var f={data:(o||[]).map((function(t){var r=u(t);return e&&delete r.fit,r}))};if(!e&&(f.layout=u(s),i)){var h=s._size;f.layout.computed={margin:{b:h.b,l:h.l,r:h.r,t:h.t}}}return t.framework&&t.framework.isPolar&&(f=t.framework.getConfig()),l&&(f.frames=u(l)),a&&(f.config=u(t._context,!0)),\"object\"===n?f:JSON.stringify(f)},x.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},x.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=x.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=x.extendTrace(u.data[a],s.data[r]))}return u},x.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},x.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,l,u,f=c.extendDeepNoArrays({},e||{}),h=c.expandObjectPaths(f),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=c.nestedProperty(h,r[a])).get())?c.nestedProperty(p,r[a]).set(null):(n.set(null),c.nestedProperty(p,r[a]).set(i));if(t=c.extendDeepNoArrays(t||{},h),r&&r.length)for(a=0;a<r.length;a++)if(l=c.nestedProperty(p,r[a]).get()){for(u=(s=c.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<l.length;o++){var d=l[o];u[o]=null===d?null:x.extendObjectWithContainers(u[o],d)}s.set(u)}return t},x.dataArrayContainers=[\"transforms\",\"dimensions\"],x.layoutArrayContainers=o.layoutArrayContainers,x.extendTrace=function(t,e){return x.extendObjectWithContainers(t,e,x.dataArrayContainers)},x.extendLayout=function(t,e){return x.extendObjectWithContainers(t,e,x.layoutArrayContainers)},x.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},l=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],f=t._fullData[u]._module;if(f){if(f.animatable){var h=f.basePlotModule.name;s[h]||(s[h]=[]),s[h].push(u)}t.data[a[o]]=x.extendTrace(t.data[a[o]],e[o])}}var p=c.expandObjectPaths(c.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;x.extendLayout(t.layout,p),delete t.calcdata,x.supplyDefaults(t),x.doCalcdata(t);var m=c.expandObjectPaths(r);if(m){var v=t._fullLayout._plots;for(var y in v){var b=v[y],_=b.xaxis,w=b.yaxis,T=_.range.slice(),k=w.range.slice(),M=null,A=null,S=null,E=null;Array.isArray(m[_._name+\".range\"])?M=m[_._name+\".range\"].slice():Array.isArray((m[_._name]||{}).range)&&(M=m[_._name].range.slice()),Array.isArray(m[w._name+\".range\"])?A=m[w._name+\".range\"].slice():Array.isArray((m[w._name]||{}).range)&&(A=m[w._name].range.slice()),T&&M&&(_.r2l(T[0])!==_.r2l(M[0])||_.r2l(T[1])!==_.r2l(M[1]))&&(S={xr0:T,xr1:M}),k&&A&&(w.r2l(k[0])!==w.r2l(A[0])||w.r2l(k[1])!==w.r2l(A[1]))&&(E={yr0:k,yr1:A}),(S||E)&&l.push(c.extendFlat({plotinfo:b},S,E))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=l.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,l,a,e);for(var f in u?((n=c.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var h=s[f];t._fullData[h[0]]._module.basePlotModule.plot(t,h,n,e)}},I(t,a,o)},x.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var l=t[a],u=l.xaxis,f=l.yaxis,h=n[u._name].range.slice(),p=n[f._name].range.slice(),d=u.range.slice(),g=f.range.slice();u.setScale(),f.setScale();var m=null,v=null;u.r2l(h[0])===u.r2l(d[0])&&u.r2l(h[1])===u.r2l(d[1])||(m={xr0:h,xr1:d}),f.r2l(p[0])===f.r2l(g[0])&&f.r2l(p[1])===f.r2l(g[1])||(v={yr0:p,yr1:g}),(m||v)&&s.push(c.extendFlat({plotinfo:l},m,v))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,l=t._fullData,u=t._fullLayout._basePlotModules,f=[],h=0;h<l.length;h++)f.push(h);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=c.extendFlat({},a,{duration:0}),o=f,i=a,setTimeout(p,a.duration),d()):(n=a,o=null,i=c.extendFlat({},a,{duration:0}),setTimeout(d,n.duration),p()):s.length?(n=a,p()):e.anim&&(o=f,i=a,d())},I(t,a,o)},x.doCalcdata=function(t,e){var r,n,i,a,l=h.list(t),u=t._fullData,p=t._fullLayout,d=new Array(u.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._treemapcolormap={},p._funnelareacolormap={},i=0;i<u.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<u.length;i++)(r=u[i])._arrayAttrs=s.findArrayAttributes(r),r._extremes={};var m=p._subplots.polar||[];for(i=0;i<m.length;i++)l.push(p[m[i]].radialaxis,p[m[i]].angularaxis);for(var v in p._colorAxes){var y=p[v];!1!==y.cauto&&(delete y.cmin,delete y.cmax)}var x=!1;function _(e){if(r=u[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(a=0;a<r.transforms.length;a++){var o=r.transforms[a];(n=b[o.type])&&n.calcTransform&&(r._hasCalcTransform=!0,x=!0,n.calcTransform(t,r,o))}}}function w(e,i){if(r=u[e],!!(n=r._module).isContainer===i){var o=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var s=r.transforms||[];for(a=s.length-1;a>=0;a--)if(s[a].enabled){r._indexToPoints=s[a]._indexToPoints;break}n&&n.calc&&(o=n.calc(t,r))}Array.isArray(o)&&o[0]||(o=[{x:f,y:f}]),o[0].t||(o[0].t={}),o[0].trace=r,d[e]=o}}for(z(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)_(i);for(x&&z(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)w(i,!1);O(t);var T=function(t,e){var r,n,i,a,s,l=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e||s&&t===n[e].length-1||l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return c.aggNums(Math.min,null,t)},max:function(t){return c.aggNums(Math.max,null,t)},sum:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},total:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},mean:function(t){return c.mean(t)},median:function(t){return c.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(P);if(d){var g=d[1],m=d[2],v=p._id.charAt(0),y=\"x\"===v,x=[];for(n=0;n<p._categories.length;n++)x.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var b=p._traceIndices[n],_=e._fullData[b];if(!0===_.visible){var w=_.type;o.traceIs(_,\"histogram\")&&(delete _._xautoBinFinished,delete _._yautoBinFinished);var T=\"splom\"===w,k=\"scattergl\"===w,M=e.calcdata[b];for(i=0;i<M.length;i++){var A,S,E=M[i];if(T){var C=_._axesDim[p._id];if(!y){var L=_._diag[C][0];L&&(p=e._fullLayout[h.id2name(L)])}var I=E.trace.dimensions[C].values;for(a=0;a<I.length;a++)for(A=p._categoriesMap[I[a]],s=0;s<E.trace.dimensions.length;s++)if(s!==C){var z=E.trace.dimensions[s];x[A][1].push(z.values[a])}}else if(k){for(a=0;a<E.t.x.length;a++)y?(A=E.t.x[a],S=E.t.y[a]):(A=E.t.y[a],S=E.t.x[a]),x[A][1].push(S);E.t&&E.t._scene&&delete E.t._scene.dirty}else if(E.hasOwnProperty(\"z\")){S=E.z;var O=u(_.type,p,S);for(a=0;a<S.length;a++)for(s=0;s<S[a].length;s++)(A=O(s,a))+1&&x[A][1].push(S[a][s])}else for(void 0===(A=E.p)&&(A=E[v]),void 0===(S=E.s)&&(S=E.v),void 0===S&&(S=y?E.y:E.x),Array.isArray(S)||(S=void 0===S?[]:[S]),a=0;a<S.length;a++)x[A][1].push(S[a])}}}p._categoriesValue=x;var D=[];for(n=0;n<x.length;n++)D.push([x[n][0],f[g](x[n][1])]);D.sort((function(t,e){return t[1]-e[1]})),p._categoriesAggregatedValue=D,p._initialCategories=D.map((function(t){return t[0]})),\"descending\"===m&&p._initialCategories.reverse(),l=l.concat(p.sortByInitialCategories())}}}return l}(l,t);if(T.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<T.length;i++)w(T[i],!0);for(i=0;i<T.length;i++)w(T[i],!1);O(t)}o.getComponentMethod(\"fx\",\"calc\")(t),o.getComponentMethod(\"errorbars\",\"calc\")(t)};var P=/(total|sum|min|max|mean|median) (ascending|descending)/;function z(t,e,r){var n={};function i(t){t.clearCalc(),\"multicategory\"===t.type&&t.setupMultiCategory(e),n[t._id]=1}c.simpleMap(t,i);for(var a=r._axisMatchGroups||[],o=0;o<a.length;o++)for(var s in a[o])n[s]||i(r[h.id2name(s)])}function O(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],l=s.crossTraceCalc;if(l){var u=s.basePlotModule.name;o[u]?c.pushUnique(o[u],l):o[u]=[l]}}for(n in o){var f=o[n],h=i._subplots[n];if(Array.isArray(h))for(e=0;e<h.length;e++){var p=h[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<f.length;r++)f[r](t,d,p)}else for(r=0;r<f.length;r++)f[r](t)}}x.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},x.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},x.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],l=s[0].trace;l.visible&&(o[l.type]=o[l.type]||[],o[l.type].push(s))}for(var u in a)if(!o[u]){var f=a[u][0];f[0].trace.visible=!1,o[u]=[f]}for(var h in o){var p=o[h];p[0][0].trace._module.plot(t,e,c.filterVisible(p),n)}e.traceHash=o},x.plotBasePlot=function(t,e,r,n,i){var a=o.getModule(t),s=m(e.calcdata,a)[0];a.plot(e,s,n,i)},x.cleanBasePlot=function(t,e,r,n,i){var a=i._has&&i._has(t),o=r._has&&r._has(t);a&&!o&&i[\"_\"+t+\"layer\"].selectAll(\"g.trace\").remove()}},{\"../components/color\":643,\"../constants/numerical\":753,\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plot_api/plot_template\":817,\"../plots/get_data\":865,\"../registry\":911,\"./animation_attributes\":822,\"./attributes\":824,\"./cartesian/axis_ids\":831,\"./cartesian/handle_outline\":838,\"./command\":854,\"./font_attributes\":856,\"./frame_attributes\":857,\"./layout_attributes\":882,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],892:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=f(Math.sin(e)-Math.sin(t)),c=f(Math.cos(e)-Math.cos(t)),u=Math.tan(r),h=f(1/u),p=l/c,d=s-p*o;return h?l&&c?a=u*(i=d/(u-p)):c?(i=s*h,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,f=i.length,h=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,f)}function m(t){return o(t,[e,r])}var v=a(i,(function(t){return m(t)?l(t,e):1/0})),y=d(i[v],i[g(v-1)],e);for(h.push(y),s=v,u=0;u<f;s++,u++){var x=i[g(s)];if(!m(x))break;h.push(p(x))}var b=a(i,(function(t){return m(t)?l(t,r):1/0})),_=d(i[b],i[g(b+1)],r);return h.push(_),h.push([0,0]),h.push(h[0].slice()),h}(t,e,r,i)}function f(t){return Math.abs(t)>1e-10?t:0}function h(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),f=i(u(l,n[0],n[1],a)),h=[t*Math.cos(e),t*Math.sin(e)];return f.contains(h)&&!c.contains(h)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,(function(e){var r=s(e,t);return r>0?r:1/0})),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:f,pathPolygon:function(t,e,r,n,i,a){return\"M\"+h(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=h(u(s,r,n,i),a,o);return\"M\"+h(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":778,\"../../lib/polygon\":790}],894:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],f=n[u]._subplot;if(!e[u]&&f)for(var h in f.framework.remove(),f.layers[\"radial-axis-title\"].remove(),f.clipPaths)f.clipPaths[h].remove();s&&f._scene&&(f._scene.destroy(),f._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":778,\"../cartesian\":841,\"../get_data\":865,\"./constants\":892,\"./layout_attributes\":895,\"./layout_defaults\":896,\"./polar\":903}],895:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:{text:o({},i.title.text,{editType:\"plot\",dflt:\"\"}),font:o({},i.title.font,{editType:\"plot\"}),editType:\"plot\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};o(u,l,c);var f={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:i.autotypenumbers,categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(f,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:f,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":642,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../cartesian/layout_attributes\":842,\"../domain\":855}],896:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),f=t(\"../cartesian/category_order_defaults\"),h=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),m=t(\"./constants\"),v=m.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,m.name,o.id),w=o.layoutOut;function T(t,e){return r(b+\".\"+t,e)}for(var k=0;k<v.length;k++){b=v[k],n.isPlainObject(t[b])||(t[b]={});var M=t[b],A=a.newContainer(e,b);A._id=A._name=b,A._attr=o.id+\".\"+b,A._traceIndices=_.map((function(t){return t._expandedIndex}));var S=m.axisName2dataArray[b],E=x(M,A,T,_,S,o);f(M,A,T,{axData:_,dataAttr:S});var C,L,I=T(\"visible\");switch(g(A,e,w),T(\"uirevision\",e.uirevision),I&&(L=(C=T(\"color\"))===M.color?C:o.font.color),A._m=1,b){case\"radialaxis\":var P=T(\"autorange\",!A.isValidRange(M.range));M.autorange=P,!P||\"linear\"!==E&&\"-\"!==E||T(\"rangemode\"),\"reversed\"===P&&(A._m=-1),T(\"range\"),A.cleanRange(\"range\",{dfltRange:[0,1]}),I&&(T(\"side\"),T(\"angle\",y[0]),T(\"title.text\"),n.coerceFont(T,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=M.type=A.type=\"linear\"}T(\"linear\"===E?\"thetaunit\":\"period\");var O=T(\"direction\");T(\"rotation\",{counterclockwise:0,clockwise:90}[O])}if(I)l(M,A,T,A.type),u(M,A,T,A.type,{tickSuffixDflt:\"degrees\"===A.thetaunit?\"\\xb0\":void 0}),c(M,A,T,{outerTicks:!0}),T(\"showticklabels\")&&(n.coerceFont(T,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),T(\"tickangle\"),T(\"tickformat\")),h(M,A,T,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),T(\"layer\");\"category\"!==E&&T(\"hoverformat\"),A._input=M}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i,a){var o=r(\"autotypenumbers\",a.autotypenumbersDflt);if(\"-\"===r(\"type\")){for(var s,l=0;l<n.length;l++)if(n[l].visible){s=n[l];break}s&&s[i]&&(e.type=p(s[i],\"gregorian\",{noMultiCategory:!0,autotypenumbers:o})),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:m.name,attributes:d,handleDefaults:y,font:e.font,autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../cartesian/axis_autotype\":829,\"../cartesian/category_order_defaults\":832,\"../cartesian/line_grid_defaults\":844,\"../cartesian/tick_label_defaults\":849,\"../cartesian/tick_mark_defaults\":850,\"../cartesian/tick_value_defaults\":851,\"../get_data\":865,\"../subplot_defaults\":905,\"./constants\":892,\"./layout_attributes\":895,\"./set_convert\":904}],897:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":768,\"../../../traces/scatter/attributes\":1187}],898:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":768,\"../../../plot_api/edit_types\":810,\"../../cartesian/layout_attributes\":842}],899:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":900,\"./micropolar_manager\":901}],900:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},f=n.dispatch(\"hover\"),h={};return h.render=function(c){return function(c){e=c||e;var f=l.data,h=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(f).each((function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(h)};var f=0;c.forEach((function(t,e){t.color||(t.color=h.defaultColorRange[f],f=(f+1)%h.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize}));var p=c.filter((function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r})),d=!1,g=p.map((function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t}));if(d){var m=n.nest().key((function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"})).entries(g),v=[],y=m.map((function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map((function(t,e){return 0}));return t.values.forEach((function(t,e,n){t.yStack=[r],v.push(r),r=o.util.sumArrays(t.r,r)})),t.values}));p=n.merge(y)}p.forEach((function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]}));var x=Math.min(h.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2;x=Math.max(10,x);var b,_=[h.margin.left+x,h.margin.top+x];d?b=[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(v)))]:b=n.extent(o.util.flattenArray(p.map((function(t,e){return t.r}))));h.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(h.radialAxis.domain!=o.DATAEXTENT&&h.radialAxis.domain?h.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,T=o.util.flattenArray(p.map((function(t,e){return t.t}))),k=\"string\"==typeof T[0];k&&(T=o.util.deduplicate(T),w=T.slice(),T=n.range(T.length),p=p.map((function(t,e){var r=t;return t.t=[T],d&&(r.yStack=t.yStack),r})));var M=p.filter((function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry})).length===p.length,A=null===h.needsEndSpacing?k||!M:h.needsEndSpacing,S=h.angularAxis.domain&&h.angularAxis.domain!=o.DATAEXTENT&&!k&&h.angularAxis.domain[0]>=0?h.angularAxis.domain:n.extent(T),E=Math.abs(T[1]-T[0]);M&&!k&&(E=0);var C=S.slice();A&&k&&(C[1]+=E);var L=h.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),h.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var I=h.angularAxis.ticksStep||(C[1]-C[0])/(L*(h.minorTicks+1));w&&(I=Math.max(Math.round(I),1)),C[2]||(C[2]=I);var P=n.range.apply(this,C);if(P=P.map((function(t,e){return parseFloat(t.toPrecision(12))})),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===h.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=A?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),O=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(O)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:h.tickColor},B={\"font-size\":h.font.size,\"font-family\":h.font.family,fill:h.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map((function(t,e){return\" \"+t+\" 0 \"+h.font.outlineColor})).join(\",\")};if(h.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,h.margin.top]+\")\"}).style({display:\"block\"});var N=p.map((function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r}));o.Legend().config({data:p.map((function(t,e){return t.name||\"Element\"+e})),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:h.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(h.width-j.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2,x=Math.max(10,x),_=[h.margin.left+x,h.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:h.width,height:h.height}).style({opacity:h.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(h.width-(h.margin.left+h.margin.right+2*x+(j?j.width:0)))/2,(h.height-(h.margin.top+h.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),h.title&&h.title.text){var V=t.select(\"g.title-group text\").style(B).text(h.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(h.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:h.backgroundColor,stroke:h.stroke});function W(t,e){return s(t)%360+h.orientation}if(h.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+h.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text((function(t,e){return this.textContent+h.radialAxis.ticksSuffix})).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===h.radialAxis.tickOrientation?\"rotate(\"+-h.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(P),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:h.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",(function(t,e){return e%(h.minorTicks+1)==0})).classed(\"minor\",(function(t,e){return!(e%(h.minorTicks+1)==0)})).style(F),J.selectAll(\".minor\").style({stroke:h.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:h.tickLength?x-h.tickLength:0,x2:x}).style({display:h.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+h.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+h.labelOffset,i=h.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:h.angularAxis.labelsVisible?\"block\":\"none\"}).text((function(t,e){return e%(h.minorTicks+1)!=0?\"\":w?w[t]+h.angularAxis.ticksSuffix:t+h.angularAxis.ticksSuffix})).style(B);h.angularAxis.rewriteTicks&&K.text((function(t,e){return e%(h.minorTicks+1)!=0?\"\":h.angularAxis.rewriteTicks(this.textContent,e)}));var Q=n.max(R.selectAll(\".angular-tick text\")[0].map((function(t,e){return t.getCTM().e+t.getBBox().width})));D.attr({transform:\"translate(\"+[x+Q,h.margin.top]+\")\"});var $=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||$){var et=[];p.forEach((function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter((function(t,r){return r==e})),n.geometry=t.geometry,n.orientation=h.orientation,n.direction=h.direction,n.index=e,et.push({data:t,geometryConfig:n})}));var rt=n.nest().key((function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"})).entries(et),nt=[];rt.forEach((function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map((function(t,e){return[t]}))):nt.push(t.values)})),nt.forEach((function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map((function(t,e){return i(o[r].defaultConfig(),t)}));o[r]().config(n)()}))}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!k){var ft=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",(function(t,e){var r=o.util.getMousePos(Y).angle;ft.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-h.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])})).on(\"mouseout.angular-guide\",(function(t,e){ot.select(\"line\").style({opacity:0})}))}var ht=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",(function(t,e){var n=o.util.getMousePos(Y).radius;ht.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,h.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])})).on(\"mouseout.radial-guide\",(function(t,e){ht.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()})),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",(function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};k&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,f=this.getBoundingClientRect(),h=t.node().getBoundingClientRect(),p=[f.left+f.width/2-U[0]-h.left,f.top+f.height/2-U[1]-h.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})})).on(\"mousemove.tooltip\",(function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()})).on(\"mouseout.tooltip\",(function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})}))}))}(c),this},h.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach((function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)})),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},h.getLiveConfig=function(){return u},h.getinputConfig=function(){return c},h.radialScale=function(t){return r},h.angularScale=function(t){return s},h.svg=function(){return t},n.rebind(h,f,\"on\"),h},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map((function(e,r){var n=e*Math.PI/180;return[e,t(n)]}))},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach((function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)}));var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map((function(t,e){return r[e]||r[0]}))},o.util.fillArrays=function(t,e,r){return e.forEach((function(e,n){t[e]=o.util.ensureArray(t[e],r)})),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map((function(t,e){return n.sum(t)}))},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter((function(t,e,r){return r.indexOf(t)==e}))},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce((function(t,e){if(\"undefined\"!=typeof t)return t[e]}),t);\"undefined\"!=typeof a&&(e.reduce((function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]}),t),r.reduce((function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]}),t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each((function(t,i){var a=!!t[0].data.yStack,o=t.map((function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])})),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius((function(t){return e.radialScale(t[1])})).angle((function(t){return e.angularScale(t[0])*Math.PI/180}));c.line=function(r,i,a){var s=r[2]?o[a].map((function(t,e){return[t[0],t[1]+t[2]]})):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var f=e.angularScale.range(),h=Math.abs(f[1]-f[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle((function(t){return-h/2})).endAngle((function(t){return h/2})).innerRadius((function(t){return e.radialScale(l+(t[2]||0))})).outerRadius((function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])}));c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var m=g.selectAll(\"path.mark\").data((function(t,e){return t}));m.enter().append(\"path\").attr({class:\"mark\"}),m.style(d).each(c[e.geometryType]),m.exit().remove(),g.exit().remove()}))}return a.config=function(e){return arguments.length?(e.forEach((function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)})),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map((function(t,r){return[].concat(t).map((function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a}))})),o=n.merge(a);o=o.filter((function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)})),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map((function(t,e){return t.color})),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,f=u?e.height:c*o.length,h=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=h.enter().append(\"svg\").attr({width:300,height:f+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),m=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,f]);if(u){var v=h.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);v.enter().append(\"stop\"),v.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),h.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=h.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,m(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(m).orient(\"right\"),b=h.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text((function(t,e){return o[e].name})),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",f=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(f);var h=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*h+l,m=p.height+2*h;return r.attr({d:\"M\"+[[l,-m/2],[l,-m/4],[a.hasTick?0:l,0],[l,m/4],[l,m/2],[g,m/2],[g,-m/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-m/2+2*h]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map((function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n})),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map((function(t,e){return t.geometry})));r.data.forEach((function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)}))}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach((function(t,e){u[c[l.indexOf(t.key)]]=t.value})),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":745,\"../../../lib\":778,d3:169}],901:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,f=new s;function h(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return h.isPolar=!0,h.svg=function(){return i.svg()},h.getConfig=function(){return e},h.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},h.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},h.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,f.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},h.undo=function(){f.undo()},h.redo=function(){f.redo()},h},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":643,\"../../../lib\":778,\"./micropolar\":900,\"./undo_manager\":902,d3:169}],902:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n||(e.splice(r+1,e.length-r),e.push(t),r=e.length-1),this},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],903:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../plots\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../cartesian/set_convert\"),d=t(\"./set_convert\"),g=t(\"../cartesian/autorange\").doAutoRange,m=t(\"../cartesian/dragbox\"),v=t(\"../../components/dragelement\"),y=t(\"../../components/fx\"),x=t(\"../../components/titles\"),b=t(\"../cartesian/select\").prepSelect,_=t(\"../cartesian/select\").selectOnClick,w=t(\"../cartesian/select\").clearSelect,T=t(\"../../lib/setcursor\"),k=t(\"../../lib/clear_gl_canvases\"),M=t(\"../../plot_api/subroutines\").redrawReglTraces,A=t(\"../../constants/alignment\").MID_SHIFT,S=t(\"./constants\"),E=t(\"./helpers\"),C=o._,L=o.mod,I=o.deg2rad,P=o.rad2deg;function z(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=z.prototype;function D(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function R(t,e){return e[o.findIndexOfMin(e,(function(e){return o.angleDist(t,e)}))]}function F(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}e.exports=function(t,e){return new z(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),f.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=S.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var f=this.framework.selectAll(\".polarsublayer\").data(l,String);f.enter().append(\"g\").attr(\"class\",(function(t){return\"polarsublayer \"+t})).each((function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}})),f.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,s=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-s[1]);var f=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(s[1]-s[0]),p=e.sector;this.sectorInRad=p.map(I);var d,g,m,v,y,x=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=L(a,360),l=s+o,c=Math.cos(I(s)),u=Math.sin(I(s)),f=Math.cos(I(l)),h=Math.sin(I(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&h<=0?0:Math.max(u,h);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&f>=0?0:Math.min(c,f);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&h>=0?0:Math.min(u,h);n=l>=360?1:c<=0&&f<=0?0:Math.max(c,f);return[e,r,n,i]}(p),b=x[2]-x[0],_=x[3]-x[1],w=h/f,T=Math.abs(_/b);w>T?(d=f,y=(h-(g=f*T))/n.h/2,m=[o[0],o[1]],v=[s[0]+y,s[1]-y]):(g=h,y=(f-(d=h/T))/n.w/2,m=[o[0]+y,o[1]-y],v=[s[0],s[1]]),this.xLength2=d,this.yLength2=g,this.xDomain2=m,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*m[0],M=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=d/b,S=this.innerRadius=e.hole*A,E=this.cx=k-A*x[0],C=this.cy=M+A*x[3],P=this.cxx=E-k,z=this.cyy=C-M;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],_realSide:i.side,domain:[S/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:m}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var O=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",O).attr(\"transform\",l(P,z)),r.frontplot.attr(\"transform\",l(k,M)).call(u.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",O).attr(\"transform\",l(E,C)).call(c.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({},r,n);return d(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);p(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),g(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.radialaxis,g=L(e.sector[0],360),m=r.radialAxis,v=u<a;r.fillViewInitialKey(\"radialaxis.angle\",d.angle),r.fillViewInitialKey(\"radialaxis.range\",m.range.slice()),m.setGeometry(),\"auto\"===m.tickangle&&g>90&&g<=270&&(m.tickangle=180);var y=function(t){return l(m.l2p(t.x)+u,0)},x=D(d);if(r.radialTickLayout!==x&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=x),v){m.setScale();var b=h.calcTicks(m),_=h.clipEnds(m,b),w=h.getTickSigns(m)[2];h.drawTicks(n,m,{vals:b,layer:i[\"radial-axis\"],path:h.makeTickPath(m,0,w),transFn:y,crisp:!1}),h.drawGrid(n,m,{vals:_,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(m.r2p(t.x)+u)},transFn:o.noop,crisp:!1}),h.drawLabels(n,m,{vals:b,layer:i[\"radial-axis\"],transFn:y,labelFns:h.makeLabelFns(m,0)})}var T=r.radialAxisAngle=r.vangles?P(R(I(d.angle),r.vangles)):d.angle,k=l(f,p),M=k+s(-T);F(i[\"radial-axis\"],v&&(d.showticklabels||d.ticks),{transform:M}),F(i[\"radial-grid\"],v&&d.showgrid,{transform:k}),F(i[\"radial-line\"].select(\"line\"),v&&d.showline,{x1:u,y1:0,x2:a,y2:0,transform:M}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,l=this.id+\"title\",c=void 0!==r?r:this.radialAxisAngle,f=I(c),h=Math.cos(f),p=Math.sin(f),d=0;if(s.title){var g=u.bBox(this.layers[\"radial-axis\"].node()).height,m=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*m:g+.8*m}this.layers[\"radial-axis-title\"]=x.draw(n,l,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:C(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*h+d*p,y:o-i/2*p+d*h,\"text-anchor\":\"middle\"},transform:{rotate:-c}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.angularaxis,g=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",d.rotation),g.setGeometry(),g.setScale();var m=function(t){return g.t2g(t.x)};\"linear\"===g.type&&\"radians\"===g.thetaunit&&(g.tick0=P(g.tick0),g.dtick=P(g.dtick));var v=function(t){return l(f+a*Math.cos(t),p-a*Math.sin(t))},y=h.makeLabelFns(g,0).labelStandoff,x={xFn:function(t){var e=m(t);return Math.cos(e)*y},yFn:function(t){var e=m(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(y+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*A)},anchorFn:function(t){var e=m(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=m(t);return-.5*(1+Math.sin(n))*r}},b=D(d);r.angularTickLayout!==b&&(i[\"angular-axis\"].selectAll(\".\"+g._id+\"tick\").remove(),r.angularTickLayout=b);var _,w=h.calcTicks(g);if(\"linear\"===e.gridshape?(_=w.map(m),o.angleDelta(_[0],_[1])<0&&(_=_.slice().reverse())):_=null,r.vangles=_,\"category\"===g.type&&(w=w.filter((function(t){return o.isAngleInsideSector(m(t),r.sectorInRad)}))),g.visible){var T=\"inside\"===g.ticks?-1:1,k=(g.linewidth||1)/2;h.drawTicks(n,g,{vals:w,layer:i[\"angular-axis\"],path:\"M\"+T*k+\",0h\"+T*g.ticklen,transFn:function(t){var e=m(t);return v(e)+s(-P(e))},crisp:!1}),h.drawGrid(n,g,{vals:w,layer:i[\"angular-grid\"],path:function(t){var e=m(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[f+u*r,p-u*n]+\"L\"+[f+a*r,p-a*n]},transFn:o.noop,crisp:!1}),h.drawLabels(n,g,{vals:w,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return v(m(t))},labelFns:x})}F(i[\"angular-line\"].select(\"path\"),d.showline,{d:r.pathSubplot(),transform:l(f,p)}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e,r,s=this,c=s.gd,u=s.layers,f=t._zoomlayer,h=S.MINZOOM,p=S.OFFEDGE,d=s.radius,g=s.innerRadius,x=s.cx,T=s.cy,k=s.cxx,M=s.cyy,A=s.sectorInRad,C=s.vangles,L=s.radialAxis,I=E.clampTiny,P=E.findXYatLength,z=E.findEnclosingVertexAngles,O=S.cornerHalfWidth,D=S.cornerLen/2,R=m.makeDragger(u,\"path\",\"maindrag\",\"crosshair\");n.select(R).attr(\"d\",s.pathSubplot()).attr(\"transform\",l(x,T));var F,B,N,j,U,V,q,H,G,Y={element:R,gd:c,subplot:s.id,plotinfo:{id:s.id,xaxis:s.xaxis,yaxis:s.yaxis},xaxes:[s.xaxis],yaxes:[s.yaxis]};function W(t,e){return Math.sqrt(t*t+e*e)}function X(t,e){return W(t-k,e-M)}function Z(t,e){return Math.atan2(M-e,t-k)}function J(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function K(t,e){if(0===t)return s.pathSector(2*O);var r=D/t,n=e-r,i=e+r,a=Math.max(0,Math.min(t,d)),o=a-O,l=a+O;return\"M\"+J(o,n)+\"A\"+[o,o]+\" 0,0,0 \"+J(o,i)+\"L\"+J(l,i)+\"A\"+[l,l]+\" 0,0,1 \"+J(l,n)+\"Z\"}function Q(t,e,r){if(0===t)return s.pathSector(2*O);var n,i,a=J(t,e),o=J(t,r),l=I((a[0]+o[0])/2),c=I((a[1]+o[1])/2);if(l&&c){var u=c/l,f=-1/u,h=P(O,u,l,c);n=P(D,f,h[0][0],h[0][1]),i=P(D,f,h[1][0],h[1][1])}else{var p,d;c?(p=D,d=O):(p=O,d=D),n=[[l-p,c-d],[l+p,c-d]],i=[[l-p,c+d],[l+p,c+d]]}return\"M\"+n.join(\"L\")+\"L\"+i.reverse().join(\"L\")+\"Z\"}function $(t,e){return e=Math.max(Math.min(e,d),g),t<p?t=0:d-t<p?t=d:e<p?e=0:d-e<p&&(e=d),Math.abs(e-t)>h?(t<e?(N=t,j=e):(N=e,j=t),!0):(N=null,j=null,!1)}function tt(t,e){t=t||U,e=e||\"M0,0Z\",H.attr(\"d\",t),G.attr(\"d\",e),m.transitionZoombox(H,G,V,q),V=!0;var r={};at(r),c.emit(\"plotly_relayouting\",r)}function et(t,n){var i,a,o=F+(t*=e),l=B+(n*=r),c=X(F,B),u=Math.min(X(o,l),d),f=Z(F,B);$(c,u)&&(i=U+s.pathSector(j),N&&(i+=s.pathSector(N)),a=K(N,f)+K(j,f)),tt(i,a)}function rt(t,e,r,n){var i=E.findIntersectionXY(r,n,r,[t-k,M-e]);return W(i[0],i[1])}function nt(t,e){var r,n,i=F+t,a=B+e,o=Z(F,B),l=Z(i,a),c=z(o,C),u=z(l,C);$(rt(F,B,c[0],c[1]),Math.min(rt(i,a,u[0],u[1]),d))&&(r=U+s.pathSector(j),N&&(r+=s.pathSector(N)),n=[Q(N,c[0],c[1]),Q(j,c[0],c[1])].join(\" \")),tt(r,n)}function it(){if(m.removeZoombox(c),null!==N&&null!==j){var t={};at(t),m.showDoubleClickNotifier(c),a.call(\"_guiRelayout\",c,t)}}function at(t){var e=L._rl,r=(e[1]-e[0])/(1-g/d)/d,n=[e[0]+(N-g)*r,e[0]+(j-g)*r];t[s.id+\".radialaxis.range\"]=n}function ot(t,e){var r=c._fullLayout.clickmode;if(m.removeZoombox(c),2===t){var n={};for(var i in s.viewInitial)n[s.id+\".\"+i]=s.viewInitial[i];c.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",c,n)}r.indexOf(\"select\")>-1&&1===t&&_(e,c,[s.xaxis],[s.yaxis],s.id,Y),r.indexOf(\"event\")>-1&&y.click(c,e,s.id)}Y.prepFn=function(t,n,a){var l=c._fullLayout.dragmode,u=R.getBoundingClientRect();c._fullLayout._calcInverseTransform(c);var h=c._fullLayout._invTransform;e=c._fullLayout._invScaleX,r=c._fullLayout._invScaleY;var p=o.apply3DTransform(h)(n-u.left,a-u.top);if(F=p[0],B=p[1],C){var g=E.findPolygonOffset(d,A[0],A[1],C);F+=k+g[0],B+=M+g[1]}switch(l){case\"zoom\":Y.moveFn=C?nt:et,Y.clickFn=ot,Y.doneFn=it,function(){N=null,j=null,U=s.pathSubplot(),V=!1;var t=c._fullLayout[s.id];q=i(t.bgcolor).getLuminance(),(H=m.makeZoombox(f,q,x,T,U)).attr(\"fill-rule\",\"evenodd\"),G=m.makeCorners(f,x,T),w(c)}();break;case\"select\":case\"lasso\":b(t,n,a,Y,l)}},R.onmousemove=function(t){y.hover(c,t,s.id),c._fullLayout._lasthover=R,c._fullLayout._hoversubplot=s.id},R.onmouseout=function(t){c._dragging||v.unhover(c,t)},v.init(Y)},O.updateRadialDrag=function(t,e,r){var i=this,c=i.gd,u=i.layers,f=i.radius,h=i.innerRadius,p=i.cx,d=i.cy,g=i.radialAxis,y=S.radialDragBoxSize,x=y/2;if(g.visible){var b,_,T,A=I(i.radialAxisAngle),E=g._rl,C=E[0],L=E[1],z=E[r],O=.75*(E[1]-E[0])/(1-e.hole)/f;r?(b=p+(f+x)*Math.cos(A),_=d-(f+x)*Math.sin(A),T=\"radialdrag\"):(b=p+(h-x)*Math.cos(A),_=d-(h-x)*Math.sin(A),T=\"radialdrag-inner\");var D,B,N,j=m.makeRectDragger(u,T,\"crosshair\",-x,-x,y,y),U={element:j,gd:c};F(n.select(j),g.visible&&h<f,{transform:l(b,_)}),U.prepFn=function(){D=null,B=null,N=null,U.moveFn=V,U.doneFn=q,w(c)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<S.MINDRAG&&(t=0,e=0),[t,e]},v.init(U)}function V(t,e){if(D)D(t,e);else{var n=[t,-e],a=[Math.cos(A),Math.sin(A)],s=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(s)||(D=s<.5?H:G)}var l={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(l),c.emit(\"plotly_relayouting\",l)}function q(){null!==B?a.call(\"_guiRelayout\",c,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",c,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=b+t,a=_+e;B=Math.atan2(d-a,n-p),i.vangles&&(B=R(B,i.vangles)),B=P(B);var o=l(p,d)+s(-B);u[\"radial-axis\"].attr(\"transform\",o),u[\"radial-line\"].select(\"line\").attr(\"transform\",o);var c=i.gd._fullLayout,f=c[i.id];i.updateRadialAxisTitle(c,f,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(A),Math.sin(A)]);if(N=z-O*n,O>0==(r?N>C:N<L)){var s=c._fullLayout,l=s[i.id];g.range[r]=N,g._rl[r]=N,i.updateRadialAxis(s,l),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var f in i.traceHash){var h=i.traceHash[f],p=o.filterVisible(h);h[0][0].trace._module.plot(c,i,p,l),a.traceIs(f,\"gl\")&&p.length&&(u=!0)}u&&(k(c),M(c))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,c=e.radius,f=e.angularAxis,h=e.cx,p=e.cy,d=e.cxx,g=e.cyy,y=S.angularDragBoxSize,x=m.makeDragger(i,\"path\",\"angulardrag\",\"move\"),b={element:x,gd:r};function _(t,e){return Math.atan2(g+y-e,t-d-y)}n.select(x).attr(\"d\",e.pathAnnulus(c,c+y)).attr(\"transform\",l(h,p)).call(T,\"move\");var A,E,C,L,I,z,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),D=O.selectAll(\".point\"),R=O.selectAll(\".textpoint\");function F(c,m){var v=e.gd._fullLayout,y=v[e.id],x=_(A+c*t._invScaleX,E+m*t._invScaleY),b=P(x-z);if(L=C+b,i.frontplot.attr(\"transform\",l(e.xOffset2,e.yOffset2)+s([-b,d,g])),e.vangles){I=e.radialAxisAngle+b;var w=l(h,p)+s(-b),T=l(h,p)+s(-I);i.bg.attr(\"transform\",w),i[\"radial-grid\"].attr(\"transform\",w),i[\"radial-axis\"].attr(\"transform\",T),i[\"radial-line\"].select(\"line\").attr(\"transform\",T),e.updateRadialAxisTitle(v,y,I)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",l(d,g)+s(b));D.each((function(){var t=n.select(this),e=u.getTranslate(t);t.attr(\"transform\",l(e.x,e.y)+s([b]))})),R.each((function(){var t=n.select(this),e=t.select(\"text\"),r=u.getTranslate(t);t.attr(\"transform\",s([b,e.attr(\"x\"),e.attr(\"y\")])+l(r.x,r.y))})),f.rotation=o.modHalf(L,360),e.updateAngularAxis(v,y),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(u.hideOutsideRangePoints,e);var S=!1;for(var F in e.traceHash)if(a.traceIs(F,\"gl\")){var N=e.traceHash[F],j=o.filterVisible(N);N[0][0].trace._module.plot(r,e,j,y),j.length&&(S=!0)}S&&(k(r),M(r));var U={};B(U),r.emit(\"plotly_relayouting\",U)}function B(t){t[e.id+\".angularaxis.rotation\"]=L,e.vangles&&(t[e.id+\".radialaxis.angle\"]=I)}function N(){R.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}b.prepFn=function(n,i,a){var s=t[e.id];C=s.angularaxis.rotation;var l=x.getBoundingClientRect();A=i-l.left,E=a-l.top,r._fullLayout._calcInverseTransform(r);var c=o.apply3DTransform(t._invTransform)(A,E);A=c[0],E=c[1],z=_(A,E),b.moveFn=F,b.doneFn=N,w(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(b.prepFn=o.noop,T(n.select(x),null)),v.init(b)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?E.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?E.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/titles\":738,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/setcursor\":799,\"../../plot_api/subroutines\":818,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/dragbox\":836,\"../cartesian/select\":847,\"../cartesian/set_convert\":848,\"../plots\":891,\"./constants\":892,\"./helpers\":893,\"./set_convert\":904,d3:169,tinycolor2:576}],904:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",f=\"d\"+i,h=u in e?c(e[u]):0,p=e[f]?c(e[f]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=h+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,f=u.map(a),h={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return h*t+p},g=function(t){return(t-p)/h};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(f)?[u[0],u[0]+360]:f.map(g).map(o);break;case\"category\":var m=t._categories.length,v=t.period?Math.max(t.period,m):m;0===v&&(v=1),s=c=function(t){return 2*t*Math.PI/v},i=l=function(t){return t*v/Math.PI/2},t.range=[0,v]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":778,\"../cartesian/set_convert\":848}],905:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,f=o.handleDefaults,h=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function m(t,e){return n.coerce(s,l,u,t,e)}for(var v=0;v<d;v++){var y=p[v];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),m(\"uirevision\",e.uirevision);var x={};x[h]=[v/d,(v+1)/d],a(l,e,m,x),o.id=y,f(s,l,m,o)}}},{\"../lib\":778,\"../plot_api/plot_template\":817,\"./domain\":855}],906:[function(t,e,r){\"use strict\";['Variables are inserted using %{variable}, for example \"y: %{y}\".','Numbers are formatted using d3-format\\'s syntax %{variable:d3-format}, for example \"Price: %{y:$.2f}\".',t(\"../constants/docs\").FORMAT_LINK,\"for details on the formatting syntax.\",'Dates are formatted using d3-time-format\\'s syntax %{variable|d3-time-format}, for example \"Day: %{2019-01-01|%A}\".',t(\"../constants/docs\").DATE_FORMAT_LINK,\"for details on the date formatting syntax.\"].join(\" \");function n(t){var e=t.description?\" \"+t.description:\"\",r=t.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";e+=\"Finally, the template string has access to \",e=1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}return e}r.hovertemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},r.texttemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"calc\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r}},{\"../constants/docs\":748}],907:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":778,\"../../plots/get_data\":865,\"./layout_attributes\":908,\"./layout_defaults\":909,\"./ternary\":910}],908:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:{text:a.title.text,font:a.title.font},color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,minexponent:a.minexponent,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../cartesian/layout_attributes\":842,\"../domain\":855}],909:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),f=t(\"./layout_attributes\"),h=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var f=0;f<h.length;f++)s=t[o=h[f]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,m=e.caxis;p.min+g.min+m.min>=u&&(p.min=0,g.min=0,m.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=f[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var h=o(\"color\"),p=h!==i.color.dflt?h:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,m=o(\"title.text\",g);e._hovertitle=m===g?m:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:h,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:f,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../cartesian/line_grid_defaults\":844,\"../cartesian/tick_label_defaults\":849,\"../cartesian/tick_mark_defaults\":850,\"../cartesian/tick_value_defaults\":851,\"../subplot_defaults\":905,\"./layout_attributes\":908}],910:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strTranslate,l=o._,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,p=t(\"../plots\"),d=t(\"../cartesian/axes\"),g=t(\"../../components/dragelement\"),m=t(\"../../components/fx\"),v=t(\"../../components/dragelement/helpers\"),y=v.freeMode,x=v.rectMode,b=t(\"../../components/titles\"),_=t(\"../cartesian/select\").prepSelect,w=t(\"../cartesian/select\").selectOnClick,T=t(\"../cartesian/select\").clearSelect,k=t(\"../cartesian/select\").clearSelectionsCache,M=t(\"../cartesian/constants\");function A(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=A;var S=A.prototype;S.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},S.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),p.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(c.fill,r.bgcolor)},S.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),u.setClipUrl(this.layers.backplot,n,e),u.setClipUrl(this.layers.grids,n,e)},S.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",(function(t){return\"toplevel \"+t})).each((function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach((function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)}))})),i.order()};var E=Math.sqrt(4/3);S.adjustLayout=function(t,e){var r,n,i,a,o,l,p=this,d=t.domain,g=(d.x[0]+d.x[1])/2,m=(d.y[0]+d.y[1])/2,v=d.x[1]-d.x[0],y=d.y[1]-d.y[0],x=v*e.w,b=y*e.h,_=t.sum,w=t.aaxis.min,T=t.baxis.min,k=t.caxis.min;x>E*b?i=(a=b)*E:a=(i=x)/E,o=v*i/x,l=y*a/b,r=e.l+e.w*g-i/2,n=e.t+e.h*(1-m)-a/2,p.x0=r,p.y0=n,p.w=i,p.h=a,p.sum=_,p.xaxis={type:\"linear\",range:[w+2*k-_,_-w-2*T],domain:[g-o/2,g+o/2],_id:\"x\"},f(p.xaxis,p.graphDiv._fullLayout),p.xaxis.setScale(),p.xaxis.isPtWithinRange=function(t){return t.a>=p.aaxis.range[0]&&t.a<=p.aaxis.range[1]&&t.b>=p.baxis.range[1]&&t.b<=p.baxis.range[0]&&t.c>=p.caxis.range[1]&&t.c<=p.caxis.range[0]},p.yaxis={type:\"linear\",range:[w,_-T-k],domain:[m-l/2,m+l/2],_id:\"y\"},f(p.yaxis,p.graphDiv._fullLayout),p.yaxis.setScale(),p.yaxis.isPtWithinRange=function(){return!0};var M=p.yaxis.domain[0],A=p.aaxis=h({},t.aaxis,{range:[w,_-T-k],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(A,p.graphDiv._fullLayout),A.setScale();var S=p.baxis=h({},t.baxis,{range:[_-w-k,T],side:\"bottom\",domain:p.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});f(S,p.graphDiv._fullLayout),S.setScale();var C=p.caxis=h({},t.caxis,{range:[_-w-T,k],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(C,p.graphDiv._fullLayout),C.setScale();var L=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDef.select(\"path\").attr(\"d\",L),p.layers.plotbg.select(\"path\").attr(\"d\",L);var I=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDefRelative.select(\"path\").attr(\"d\",I);var P=s(r,n);p.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),p.clipDefRelative.select(\"path\").attr(\"transform\",null);var z=s(r-S._offset,n+a);p.layers.baxis.attr(\"transform\",z),p.layers.bgrid.attr(\"transform\",z);var O=s(r+i/2,n)+\"rotate(30)\"+s(0,-A._offset);p.layers.aaxis.attr(\"transform\",O),p.layers.agrid.attr(\"transform\",O);var D=s(r+i/2,n)+\"rotate(-30)\"+s(0,-C._offset);p.layers.caxis.attr(\"transform\",D),p.layers.cgrid.attr(\"transform\",D),p.drawAxes(!0),p.layers.aline.select(\"path\").attr(\"d\",A.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(c.stroke,A.linecolor||\"#000\").style(\"stroke-width\",(A.linewidth||0)+\"px\"),p.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(c.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),p.layers.cline.select(\"path\").attr(\"d\",C.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(c.stroke,C.linecolor||\"#000\").style(\"stroke-width\",(C.linewidth||0)+\"px\"),p.graphDiv._context.staticPlot||p.initInteractions(),u.setClipUrl(p.layers.frontplot,p._hasClipOnAxisFalse?null:p.clipId,p.graphDiv)},S.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var s=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=b.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:l(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-s,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=b.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:l(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=b.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:l(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},S.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=d.calcTicks(t),f=d.clipEnds(t,u),h=d.makeTransTickFn(t),p=d.getTickSigns(t)[2],g=o.deg2rad(30),m=p*(t.linewidth||1)/2,v=p*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+m+\"l\"+Math.sin(g)*v+\",\"+Math.cos(g)*v:\"M\"+m+\",0l\"+Math.cos(g)*v+\",\"+-Math.sin(g)*v,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];d.drawTicks(r,t,{vals:\"inside\"===t.ticks?f:u,layer:s,path:b,transFn:h,crisp:!1}),d.drawGrid(r,t,{vals:f,layer:this.layers[i+\"grid\"],path:_,transFn:h,crisp:!1}),d.drawLabels(r,t,{vals:u,layer:s,transFn:h,labelFns:d.makeLabelFns(t,0,30)})};var C=M.MINZOOM/2+.87,L=\"m-0.87,.5h\"+C+\"v3h-\"+(C+5.2)+\"l\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l2.6,1.5l-\"+C/2+\",\"+.87*C+\"Z\",I=\"m0.87,.5h-\"+C+\"v3h\"+(C+5.2)+\"l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-2.6,1.5l\"+C/2+\",\"+.87*C+\"Z\",P=\"m0,1l\"+C/2+\",\"+.87*C+\"l2.6,-1.5l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-\"+(C/2+2.6)+\",\"+(.87*C+4.5)+\"l2.6,1.5l\"+C/2+\",-\"+.87*C+\"Z\",z=!0;function O(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}S.clearSelect=function(){k(this.dragOptions),T(this.dragOptions.gd)},S.initInteractions=function(){var t,e,r,n,f,h,p,d,v,b,T,k,A=this,S=A.layers.plotbg.select(\"path\").node(),C=A.graphDiv,D=C._fullLayout._zoomlayer;function R(t){var e={};return e[A.id+\".aaxis.min\"]=t.a,e[A.id+\".baxis.min\"]=t.b,e[A.id+\".caxis.min\"]=t.c,e}function F(t,e){var r=C._fullLayout.clickmode;O(C),2===t&&(C.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",C,R({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&w(e,C,[A.xaxis],[A.yaxis],A.id,A.dragOptions),r.indexOf(\"event\")>-1&&m.click(C,e,A.id)}function B(t,e){return 1-e/A.h}function N(t,e){return 1-(t+(A.h-e)/Math.sqrt(3))/A.w}function j(t,e){return(t-(A.h-e)/Math.sqrt(3))/A.w}function U(i,a){var o=r+i*t,s=n+a*e,l=Math.max(0,Math.min(1,B(0,n),B(0,s))),c=Math.max(0,Math.min(1,N(r,n),N(o,s))),u=Math.max(0,Math.min(1,j(r,n),j(o,s))),g=(l/2+u)*A.w,m=(1-l/2-c)*A.w,y=(g+m)/2,x=m-g,_=(1-l)*A.h,w=_-x/E;x<M.MINZOOM?(p=f,T.attr(\"d\",v),k.attr(\"d\",\"M0,0Z\")):(p={a:f.a+l*h,b:f.b+c*h,c:f.c+u*h},T.attr(\"d\",v+\"M\"+g+\",\"+_+\"H\"+m+\"L\"+y+\",\"+w+\"L\"+g+\",\"+_+\"Z\"),k.attr(\"d\",\"M\"+r+\",\"+n+\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2ZM\"+g+\",\"+_+L+\"M\"+m+\",\"+_+I+\"M\"+y+\",\"+w+P)),b||(T.transition().style(\"fill\",d>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),k.transition().style(\"opacity\",1).duration(200),b=!0),C.emit(\"plotly_relayouting\",R(p))}function V(){O(C),p!==f&&(a.call(\"_guiRelayout\",C,R(p)),z&&C.data&&C._context.showTips&&(o.notifier(l(C,\"Double-click to zoom back out\"),\"long\"),z=!1))}function q(t,e){var r=t/A.xaxis._m,n=e/A.yaxis._m,i=[(p={a:f.a-n,b:f.b+(r+n)/2,c:f.c-(r-n)/2}).a,p.b,p.c].sort(o.sorterAsc),a=i.indexOf(p.a),l=i.indexOf(p.b),c=i.indexOf(p.c);i[0]<0&&(i[1]+i[0]/2<0?(i[2]+=i[0]+i[1],i[0]=i[1]=0):(i[2]+=i[0]/2,i[1]+=i[0]/2,i[0]=0),p={a:i[a],b:i[l],c:i[c]},e=(f.a-p.a)*A.yaxis._m,t=(f.c-p.c-f.b+p.b)*A.xaxis._m);var h=s(A.x0+t,A.y0+e);A.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var d=s(-t,-e);A.clipDefRelative.select(\"path\").attr(\"transform\",d),A.aaxis.range=[p.a,A.sum-p.b-p.c],A.baxis.range=[A.sum-p.a-p.c,p.b],A.caxis.range=[A.sum-p.a-p.b,p.c],A.drawAxes(!1),A._hasClipOnAxisFalse&&A.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(u.hideOutsideRangePoints,A),C.emit(\"plotly_relayouting\",R(p))}function H(){a.call(\"_guiRelayout\",C,R(p))}this.dragOptions={element:S,gd:C,plotinfo:{id:A.id,domain:C._fullLayout[A.id].domain,xaxis:A.xaxis,yaxis:A.yaxis},subplot:A.id,prepFn:function(a,l,u){A.dragOptions.xaxes=[A.xaxis],A.dragOptions.yaxes=[A.yaxis],t=C._fullLayout._invScaleX,e=C._fullLayout._invScaleY;var g=A.dragOptions.dragmode=C._fullLayout.dragmode;y(g)?A.dragOptions.minDrag=1:A.dragOptions.minDrag=void 0,\"zoom\"===g?(A.dragOptions.moveFn=U,A.dragOptions.clickFn=F,A.dragOptions.doneFn=V,function(t,e,a){var l=S.getBoundingClientRect();r=e-l.left,n=a-l.top,C._fullLayout._calcInverseTransform(C);var u=C._fullLayout._invTransform,g=o.apply3DTransform(u)(r,n);r=g[0],n=g[1],f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,h=A.aaxis.range[1]-f.a,d=i(A.graphDiv._fullLayout[A.id].bgcolor).getLuminance(),v=\"M0,\"+A.h+\"L\"+A.w/2+\", 0L\"+A.w+\",\"+A.h+\"Z\",b=!1,T=D.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",s(A.x0,A.y0)).style({fill:d>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",v),k=D.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",s(A.x0,A.y0)).style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),A.clearSelect(C)}(0,l,u)):\"pan\"===g?(A.dragOptions.moveFn=q,A.dragOptions.clickFn=F,A.dragOptions.doneFn=H,f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,A.clearSelect(C)):(x(g)||y(g))&&_(a,l,u,A.dragOptions,g)}},S.onmousemove=function(t){m.hover(C,t,A.id),C._fullLayout._lasthover=S,C._fullLayout._hoversubplot=A.id},S.onmouseout=function(t){C._dragging||g.unhover(C,t)},g.init(this.dragOptions)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/titles\":738,\"../../lib\":778,\"../../lib/extend\":768,\"../../registry\":911,\"../cartesian/axes\":828,\"../cartesian/constants\":834,\"../cartesian/select\":847,\"../cartesian/set_convert\":848,\"../plots\":891,d3:169,tinycolor2:576}],911:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),f=l.extendFlat,h=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in v(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&f(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,h=u.name;if(\"mapbox\"===h){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==h&&\"mapbox\"!==h||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),v(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&h(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function m(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function v(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&h(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&h(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&h(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":m(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":766,\"./lib/extend\":768,\"./lib/is_plain_object\":779,\"./lib/loggers\":782,\"./lib/noop\":787,\"./lib/push_unique\":793,\"./plots/attributes\":824,\"./plots/layout_attributes\":882}],912:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),f=o({},c,s(e.tileClass)),h=t._context||{};if(e.width&&(f.width=e.width),e.height&&(f.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){f.annotations=[];var p=Object.keys(f);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(f[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)f.annotations.push(e.annotations[r]);var g=Object.keys(f).filter((function(t){return t.match(/^scene\\d*$/)}));if(g.length){var m={};for(\"thumbnail\"===e.tileClass&&(m={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var v=f[g[r]];v.xaxis||(v.xaxis={}),v.yaxis||(v.yaxis={}),v.zaxis||(v.zaxis={}),a(v.xaxis,m),a(v.yaxis,m),a(v.zaxis,m),v._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:f,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:h.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":778,\"../registry\":911}],913:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.width=e.width||null,e.height=e.height||null,e.imageDataOnly=!0,new Promise((function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format.replace(\"-\",\".\"),c.then((function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)})).then((function(t){s(t)})).catch((function(t){r&&(r._snapshotInProgress=!1),l(t)}))}))}},{\"../lib\":778,\"../plot_api/to_image\":820,\"./filesaver\":914,\"./helpers\":915}],914:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise((function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var f=\"svg\"===r?\",\":\";base64,\";return i.octetStream(f+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))}))}},{\"../lib\":778,\"./helpers\":915}],915:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)},r.encodeJSON=function(t){return\"data:application/json,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});if(\"full-json\"===e)return new window.Blob([t],{type:\"application/json;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":911}],916:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":912,\"./download\":913,\"./helpers\":915,\"./svgtoimg\":917,\"./toimage\":918,\"./tosvg\":919}],917:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise((function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var f,h,p=t.canvas,d=t.scale||1,g=t.width||300,m=t.height||150,v=d*g,y=d*m,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?h=a.encodeSVG(l):(f=a.createBlob(l,\"svg\"),h=a.createObjectURL(f)),p.width=v,p.height=y,b.onload=function(){var r;switch(f=null,a.revokeObjectURL(h),\"svg\"!==c&&x.drawImage(b,0,0,v,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=h;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(f=null,a.revokeObjectURL(h),o(r),!t.promise)return e.emit(\"error\",r)},b.src=h}));return t.promise?r:e}},{\"../lib\":778,\"./helpers\":915,events:110}],918:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),f=u.gd;f.style.position=\"absolute\",f.style.left=\"-5000px\",document.body.appendChild(f);var h=o.getRedrawFunc(f);return i.call(\"plot\",f,u.data,u.layout,u.config).then(h).then((function(){var t=o.getDelay(f._fullLayout);setTimeout((function(){var t=l(f),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:f._fullLayout.width,height:f._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){f&&document.body.removeChild(f)}}),t)})).catch((function(t){r.emit(\"error\",t)})),r}},{\"../lib\":778,\"../registry\":911,\"./cloneplot\":912,\"./helpers\":915,\"./svgtoimg\":917,\"./tosvg\":919,events:110}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,f=t._fullLayout,h=f._paper,p=f._toppaper,d=f.width,g=f.height;h.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,f.paper_bgcolor);var m=f._basePlotModules||[];for(u=0;u<m.length;u++){var v=m[u];v.toSVG&&v.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&h.node().appendChild(b)}}if(f._draggers&&f._draggers.remove(),h.node().style.background=\"\",h.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each((function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()})),f._gradientUrlQueryParts){var _=[];for(var w in f._gradientUrlQueryParts)_.push(w);_.length&&h.selectAll(_.join(\",\")).each((function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}))}\"pdf\"!==e&&\"eps\"!==e||h.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),h.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),h.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(h.attr(\"width\",r*d),h.attr(\"height\",r*g),h.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var T=(new window.XMLSerializer).serializeToString(h.node());return T=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,(function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()}));return e.remove(),r}(T),T=(T=T.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(T=(T=(T=T.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),T}},{\"../components/color\":643,\"../components/drawing\":665,\"../constants/xmlns_namespaces\":754,\"../lib\":778,d3:169}],920:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":778}],921:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/font_attributes\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=s({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),f=c({},n.marker.line.width,{dflt:0}),h=c({width:f,editType:\"calc\"},o(\"marker.line\")),p=c({line:h,editType:\"calc\"},o(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,texttemplate:a({editType:\"plot\"},{keys:l.eventDataKeys}),hovertext:n.hovertext,hovertemplate:i({},{keys:l.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:c({},u,{}),insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:c({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:p,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"./constants\":923}],922:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../components/colorscale/helpers\").hasColorscale,o=t(\"../../components/colorscale/calc\"),s=t(\"./arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,c,u,f,h=n.getFromId(t,e.xaxis||\"x\"),p=n.getFromId(t,e.yaxis||\"y\"),d={msUTC:!(!e.base&&0!==e.base)};\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\",d),u=p.makeCalcdata(e,\"y\"),c=i(e,p,\"y\",u),f=!!e.yperiodalignment):(r=p.makeCalcdata(e,\"y\",d),u=h.makeCalcdata(e,\"x\"),c=i(e,h,\"x\",u),f=!!e.xperiodalignment);for(var g=Math.min(c.length,r.length),m=new Array(g),v=0;v<g;v++)m[v]={p:c[v],s:r[v]},f&&(m[v].orig_p=u[v]),e.ids&&(m[v].id=String(e.ids[v]));return a(e,\"marker\")&&o(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),a(e,\"marker.line\")&&o(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),s(m,e),l(m,e),m}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189,\"./arrays_to_calcdata\":920}],923:[function(t,e,r){\"use strict\";e.exports={TEXTPAD:3,eventDataKeys:[\"value\",\"label\"]}},{}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,T;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,f=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=f(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=f(c,0,u);var h=n(o);for(o=h?o:0,a=0;a<s.length;a++)s[a].b=o,h&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":f(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.offset?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,f=a.length!==o.length,h=s*(1-n.gap),m=l(i,e._id)+c[0][0].trace.orientation,v=i._alignmentOpts[m]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,T=v[w.alignmentgroup]||{},k=Object.keys(T.offsetGroups||{}).length,M=(x=k?h/k:f?h/u:h)*(1-(n.groupgap||0));b=k?((2*w._offsetIndex+1-k)*x-M)/2:f?((2*y+1-u)*x-M)/2:-M/2;var A=_[0].t;A.barwidth=M,A.poffset=b,A.bargroupwidth=h,A.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,f)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r];if(void 0===n[0].trace.base)for(var i=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),o=0;o<n.length;o++){var s=n[o];if(s.p!==a){var l=i.put(s.p,s.b+s.s);l&&(s.b=l)}}}}(o),i.norm?(v(o),y(r,o,i)):m(r,o)}(t,e,r,_,u),b.length&&f(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.base?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});h(e,o,i),function(t,e,r){var n,i,o,l,c,u,f=x(t),h=e.traces;for(l=0;l<h.length;l++)if(n=h[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<h.length;l++){n=h[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),m=g+d;u.b=g,u[f]=m,r.norm||(p.push(m),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],f=0;f<u.length;f++){var p=u[f];if(p.s!==a)p.b+p.s===o.get(p.p,p.s)&&(p._outmost=!0)}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&f(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var f=1e4/(c-l),h=s.round=function(t){return String(Math.round(f*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],m=g[o]-g.w/2;if(n(m)){var v=g[o]+g.w/2,y=h(g.p);s[y]?s[y]=[Math.min(m,s[y][0]),Math.max(v,s[y][1])]:s[y]=[m,v]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function f(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{unitMinDiff:n.xCat||n.yCat,sepNegVal:!1,overlapNoMerge:!n.norm});h(t,o,n),n.norm?(v(o),y(e,o,n)):m(e,o)}}function h(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,f=c._offset||c.offset,h=u.poffset;if(i(f)){for(o=Array.prototype.slice.call(f,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=h);for(r=o.length;r<s.length;r++)o.push(h);u.poffset=o}else void 0!==f&&(u.poffset=f);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===f){for(o=[],r=0;r<s.length;r++)o.push(h+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===f&&(u.poffset=h+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),f=0;f<a.length;f++){var h=a[f],p=h.w=u?c[f]:c;h[n]=h.p+(l?s[f]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,f=n[a],h=f[0],p=h.trace,d=[];for(u=0;u<f.length;u++)l=(o=f[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=h.t,m=g.poffset,v=g.barwidth,y=Array.isArray(m),x=Array.isArray(v);for(u=0;u<f.length;u++){o=f[u];var b=y?m[u]:m,_=x?v[u]:v;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function m(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!1,u=0;u<a.length;u++){var f=a[u],h=f.b,p=h+f.s;f[n]=p,l.push(p),f.hasB&&l.push(h),f.hasB&&f.b||(c=!0)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:c,padded:!0})}}function v(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),f=\"stack\"===r.mode?l:u;function h(e){return n(t.c2l(e))&&(e<u-c||e>f+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,m=[],v=!1,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var T=_.b,k=T+_.s;_[o]=k,m.push(k),y=y||h(k),_.hasB&&(m.push(T),y=y||h(T)),_.hasB&&_.b||(v=!0)}}g._extremes[t._id]=s.findExtremes(t,m,{tozero:v,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],f=0;f<a.length;f++){var h=a[f];if(!0===h.visible&&o.traceIs(h,\"bar\")&&h.xaxis===r._id&&h.yaxis===n._id&&(\"h\"===h.orientation?l.push(s[f]):c.push(s[f]),h._computePh))for(var p=t.calcdata[f],d=0;d<p.length;d++)\"function\"==typeof p[d].ph0&&(p[d].ph0=p[d].ph0()),\"function\"==typeof p[d].ph1&&(p[d].ph1=p[d].ph1())}var g={xCat:\"category\"===r.type||\"multicategory\"===r.type,yCat:\"category\"===n.type||\"multicategory\"===n.type,mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,g),u(t,n,r,l,g)},setGroupPositions:u}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"./sieve.js\":934,\"fast-isnumeric\":241}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./style_defaults\"),c=t(\"../../plots/cartesian/constraints\").getAxisGroup,u=t(\"./attributes\"),f=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=c(r,a)+i,s=r._alignmentOpts||{},l=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var f=u[l];f?f.traces.push(e):f=u[l]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var h=n(\"offsetgroup\"),p=f.offsetGroups,d=p[h];h&&(d||(d=p[h]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function p(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),u=!(!1===o.moduleHasCliponaxis),h=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=!!o.hasPathbar,g=Array.isArray(a)||\"auto\"===a,m=g||\"inside\"===a,v=g||\"outside\"===a;if(m||v){var y=f(i,\"textfont\",r.font),x=n.extendFlat({},y),b=!(t.textfont&&t.textfont.color);if(b&&delete x.color,f(i,\"insidetextfont\",x),d){var _=n.extendFlat({},y);b&&delete _.color,f(i,\"pathbar.textfont\",_)}v&&f(i,\"outsidetextfont\",y),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),u&&i(\"cliponaxis\"),h&&i(\"textangle\"),i(\"texttemplate\")}m&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,c){function f(r,i){return n.coerce(t,e,u,r,i)}if(o(t,e,c,f)){s(t,e,c,f),f(\"orientation\",e.x&&!e.y?\"h\":\"v\"),f(\"base\"),f(\"offset\"),f(\"width\"),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\");var h=f(\"textposition\");p(t,e,c,f,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),l(t,e,f,r,c);var d=(e.marker.line||{}).color,g=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");g(t,e,d||i.defaultLine,{axis:\"y\"}),g(t,e,d||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,u,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:p}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":921,\"./style_defaults\":936}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),\"h\"===r.orientation?(t.label=t.y,t.value=t.x):(t.label=t.x,t.value=t.y),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":778,\"fast-isnumeric\":241,tinycolor2:576}],928:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth,l=t(\"../../plots/cartesian/axes\").hoverLabelText,c=t(\"../../constants/numerical\").BADNUM;function u(t,e,r,i){var a,s,u,f,h,p,d,g=t.cd,m=g[0].trace,v=g[0].t,y=\"closest\"===i,x=\"waterfall\"===m.type,b=t.maxHoverDistance;function _(t){return t[u]-t.w/2}function w(t){return t[u]+t.w/2}var T=y?_:function(t){return Math.min(_(t),t.p-v.bardelta/2)},k=y?w:function(t){return Math.max(w(t),t.p+v.bardelta/2)};function M(t,e){return n.inbox(t-a,e-a,b+Math.min(1,Math.abs(e-t)/d)-1)}function A(t){return M(T(t),k(t))}function S(t){var e=s,r=t.b,i=t[f];if(x){var a=Math.abs(t.rawS)||0;e>0?i+=a:e<0&&(i-=a)}return n.inbox(r-e,i-e,b+(i-e)/(i-r)-1)}\"h\"===m.orientation?(a=r,s=e,u=\"y\",f=\"x\",h=S,p=A):(a=e,s=r,u=\"x\",f=\"y\",p=S,h=A);var E=t[u+\"a\"],C=t[f+\"a\"];d=Math.abs(E.r2c(E.range[1])-E.r2c(E.range[0]));var L=n.getDistanceFunction(i,h,p,(function(t){return(h(t)+p(t))/2}));if(n.getClosest(g,L,t),!1!==t.index&&g[t.index].p!==c){y||(T=function(t){return Math.min(_(t),t.p-v.bargroupwidth/2)},k=function(t){return Math.max(w(t),t.p+v.bargroupwidth/2)});var I=g[t.index],P=m.base?I.b+I.s:I.s;t[f+\"0\"]=t[f+\"1\"]=C.c2p(I[f],!0),t[f+\"LabelVal\"]=P;var z=v.extents[v.extents.round(I.p)];t[u+\"0\"]=E.c2p(y?T(I):z[0],!0),t[u+\"1\"]=E.c2p(y?k(I):z[1],!0);var O=void 0!==I.orig_p;return t[u+\"LabelVal\"]=O?I.orig_p:I.p,t.labelLabel=l(E,t[u+\"LabelVal\"]),t.valueLabel=l(C,t[f+\"LabelVal\"]),t.baseLabel=l(C,I.b),t.spikeDistance=(S(I)+function(t){return M(_(t),w(t))}(I))/2-b,t[u+\"Spike\"]=E.c2p(I.p,!0),o(I,m,t),t.hovertemplate=m.hovertemplate,t}}function f(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=u(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,l=o[a.index];return a.color=f(s,l),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(l,s,a),[a]}},hoverOnBars:u,getTraceColor:f}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./helpers\":927}],929:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],animatable:!0,meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/marker_colorbar\":1205,\"./arrays_to_calcdata\":920,\"./attributes\":921,\"./calc\":922,\"./cross_trace_calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":928,\"./layout_attributes\":930,\"./layout_defaults\":931,\"./plot\":932,\"./select\":933,\"./style\":935}],930:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,f={},h=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===h){var g=d.xaxis+d.yaxis;f[g]&&(u=!0),f[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==h&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./layout_attributes\":930}],932:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,f=t(\"./uniform_text\"),h=f.recordMinTextSize,p=f.clearMinTextSize,d=t(\"./style\"),g=t(\"./helpers\"),m=t(\"./constants\"),v=t(\"./attributes\"),y=v.text,x=v.textposition,b=t(\"../../components/fx/helpers\").appendArrayPointValue,_=m.TEXTPAD;function w(t){return t.id}function T(t){if(t.ids)return w}function k(t,e){return t<e?1:-1}function M(t,e,r,n){var i;return!e.uniformtext.mode&&A(r)?(n&&(i=n()),t.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){i&&i()})).each(\"interrupt\",(function(){i&&i()}))):t}function A(t){return t&&t.duration>0}function S(t){return\"auto\"===t?0:t}function E(t,e){var r=Math.PI/180*e,n=Math.abs(Math.sin(r)),i=Math.abs(Math.cos(r));return{x:t.width*i+t.height*n,y:t.width*n+t.height*i}}function C(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||\"end\",u=\"end\"===c,f=\"start\"===c,h=((a.leftToRight||0)+1)/2,p=1-h,d=i.width,g=i.height,m=Math.abs(e-t),v=Math.abs(n-r),y=m>2*_&&v>2*_?_:0;m-=2*y,v-=2*y;var x=S(l);\"auto\"!==l||d<=m&&g<=v||!(d>m||g>v)||(d>v||g>m)&&d<g==m<v||(x+=90);var b=E(i,x),w=1;s&&(w=Math.min(1,m/b.x,v/b.y));var T=i.left*p+i.right*h,M=(i.top+i.bottom)/2,A=(t+_)*p+(e-_)*h,C=(r+n)/2,L=0,I=0;if(f||u){var P=(o?b.x:b.y)/2,z=o?k(t,e):k(r,n);o?f?(A=t+z*y,L=-z*P):(A=e-z*y,L=z*P):f?(C=r+z*y,I=-z*P):(C=n-z*y,I=z*P)}return{textX:T,textY:M,targetX:A,targetY:C,anchorX:L,anchorY:I,scale:w,rotate:x}}e.exports={plot:function(t,e,r,f,m,v){var w=e.xaxis,L=e.yaxis,I=t._fullLayout;m||(m={mode:I.barmode,norm:I.barmode,gap:I.bargap,groupgap:I.bargroupgap},p(\"bar\",I));var P=a.makeTraceGroups(f,r,\"trace bars\").each((function(r){var c=n.select(this),f=r[0].trace,p=\"waterfall\"===f.type,P=\"funnel\"===f.type,z=\"bar\"===f.type||P,O=0;p&&f.connector.visible&&\"between\"===f.connector.mode&&(O=f.connector.line.width/2);var D=\"h\"===f.orientation,R=A(m),F=a.ensureSingle(c,\"g\",\"points\"),B=T(f),N=F.selectAll(\"g.point\").data(a.identity,B);N.enter().append(\"g\").classed(\"point\",!0),N.exit().remove(),N.each((function(c,p){var T,A,P=n.select(this),F=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,L,D),B=F[0][0],N=F[0][1],j=F[1][0],U=F[1][1],V=0==(D?N-B:U-j);if(V&&z&&g.getLineWidth(f,c)&&(V=!1),V||(V=!(i(B)&&i(N)&&i(j)&&i(U))),c.isBlank=V,V&&(D?N=B:U=j),O&&!V&&(D?(B-=k(B,N)*O,N+=k(B,N)*O):(j-=k(j,U)*O,U+=k(j,U)*O)),\"waterfall\"===f.type){if(!V){var q=f[c.dir].marker;T=q.line.width,A=q.color}}else T=g.getLineWidth(f,c),A=c.mc||f.marker.color;function H(t){var e=n.round(T/2%1,2);return 0===m.gap&&0===m.groupgap?n.round(Math.round(t)-e,2):t}if(!t._context.staticPlot){var G=s.opacity(A)<1||T>.01?H:function(t,e,r){return r&&t===e?t:Math.abs(t-e)>=2?H(t):t>e?Math.ceil(t):Math.floor(t)};B=G(B,N,D),N=G(N,B,D),j=G(j,U,!D),U=G(U,j,!D)}var Y=M(a.ensureSingle(P,\"path\"),I,m,v);if(Y.style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",isNaN((N-B)*(U-j))||V&&t._context.staticPlot?\"M0,0Z\":\"M\"+B+\",\"+j+\"V\"+U+\"H\"+N+\"V\"+j+\"Z\").call(l.setClipUrl,e.layerClipId,t),!I.uniformtext.mode&&R){var W=l.makePointStyleFns(f);l.singlePointStyle(c,Y,f,W,t)}!function(t,e,r,n,i,s,c,f,p,m,v){var w,T=e.xaxis,A=e.yaxis,L=t._fullLayout;function I(e,r,n){return a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t)}var P=n[0].trace,z=\"h\"===P.orientation,O=function(t,e,r,n,i){var o,s=e[0].trace;o=s.texttemplate?function(t,e,r,n,i){var o=e[0].trace,s=a.castOption(o,r,\"texttemplate\");if(!s)return\"\";var l,c,f,h,p=\"waterfall\"===o.type,d=\"funnel\"===o.type;\"h\"===o.orientation?(l=\"y\",c=i,f=\"x\",h=n):(l=\"x\",c=n,f=\"y\",h=i);function g(t){return u(h,+t,!0).text}var m=e[r],v={};v.label=m.p,v.labelLabel=v[l+\"Label\"]=(y=m.p,u(c,y,!0).text);var y;var x=a.castOption(o,m.i,\"text\");(0===x||x)&&(v.text=x);v.value=m.s,v.valueLabel=v[f+\"Label\"]=g(m.s);var _={};b(_,o,m.i),p&&(v.delta=+m.rawS||m.s,v.deltaLabel=g(v.delta),v.final=m.v,v.finalLabel=g(v.final),v.initial=v.final-v.delta,v.initialLabel=g(v.initial));d&&(v.value=m.s,v.valueLabel=g(v.value),v.percentInitial=m.begR,v.percentInitialLabel=a.formatPercent(m.begR),v.percentPrevious=m.difR,v.percentPreviousLabel=a.formatPercent(m.difR),v.percentTotal=m.sumR,v.percenTotalLabel=a.formatPercent(m.sumR));var w=a.castOption(o,m.i,\"customdata\");w&&(v.customdata=w);return a.texttemplateString(s,v,t._d3locale,_,v,o._meta||{})}(t,e,r,n,i):s.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){return u(o?r:n,+t,!0).text}var f,h=i.textinfo,p=t[e],d=h.split(\"+\"),g=[],m=function(t){return-1!==d.indexOf(t)};m(\"label\")&&g.push((v=t[e].p,u(o?n:r,v,!0).text));var v;m(\"text\")&&(0===(f=a.castOption(i,p.i,\"text\"))||f)&&g.push(f);if(s){var y=+p.rawS||p.s,x=p.v,b=x-y;m(\"initial\")&&g.push(c(b)),m(\"delta\")&&g.push(c(y)),m(\"final\")&&g.push(c(x))}if(l){m(\"value\")&&g.push(c(p.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(f=a.formatPercent(p.begR),w&&(f+=\" of initial\"),g.push(f)),m(\"percent previous\")&&(f=a.formatPercent(p.difR),w&&(f+=\" of previous\"),g.push(f)),m(\"percent total\")&&(f=a.formatPercent(p.sumR),w&&(f+=\" of total\"),g.push(f))}return g.join(\"<br>\")}(e,r,n,i):g.getValue(s.text,r);return g.coerceString(y,o)}(L,n,i,T,A);w=function(t,e){var r=g.getValue(t.textposition,e);return g.coerceEnumerated(x,r)}(P,i);var D=\"stack\"===m.mode||\"relative\"===m.mode,R=n[i],F=!D||R._outmost;if(!O||\"none\"===w||(R.isBlank||s===c||f===p)&&(\"auto\"===w||\"inside\"===w))return void r.select(\"text\").remove();var B=L.font,N=d.getBarColor(n[i],P),j=d.getInsideTextFont(P,i,B,N),U=d.getOutsideTextFont(P,i,B),V=r.datum();z?\"log\"===T.type&&V.s0<=0&&(s=T.range[0]<T.range[1]?0:T._length):\"log\"===A.type&&V.s0<=0&&(f=A.range[0]<A.range[1]?A._length:0);var q,H,G,Y,W,X=Math.abs(c-s)-2*_,Z=Math.abs(p-f)-2*_;\"outside\"===w&&(F||R.hasB||(w=\"inside\"));if(\"auto\"===w)if(F){w=\"inside\",W=a.ensureUniformFontSize(t,j),q=I(r,O,W),H=l.bBox(q.node()),G=H.width,Y=H.height;var J=G<=X&&Y<=Z,K=G<=Z&&Y<=X,Q=z?X>=G*(Z/Y):Z>=Y*(X/G);G>0&&Y>0&&(J||K||Q)?w=\"inside\":(w=\"outside\",q.remove(),q=null)}else w=\"inside\";if(!q){W=a.ensureUniformFontSize(t,\"outside\"===w?U:j);var $=(q=I(r,O,W)).attr(\"transform\");if(q.attr(\"transform\",\"\"),H=l.bBox(q.node()),G=H.width,Y=H.height,q.attr(\"transform\",$),G<=0||Y<=0)return void q.remove()}var tt,et,rt=P.textangle;\"outside\"===w?(et=\"both\"===P.constraintext||\"outside\"===P.constraintext,tt=function(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,f=i.height,h=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*_?_:0:h>2*_?_:0;var d=1;l&&(d=s?Math.min(1,p/f):Math.min(1,h/u));var g=S(c),m=E(i,g),v=(s?m.x:m.y)/2,y=(i.left+i.right)/2,x=(i.top+i.bottom)/2,b=(t+e)/2,w=(r+n)/2,T=0,M=0,A=s?k(e,t):k(r,n);s?(b=e-A*o,T=A*v):(w=n+A*o,M=-A*v);return{textX:y,textY:x,targetX:b,targetY:w,anchorX:T,anchorY:M,scale:d,rotate:g}}(s,c,f,p,H,{isHorizontal:z,constrained:et,angle:rt})):(et=\"both\"===P.constraintext||\"inside\"===P.constraintext,tt=C(s,c,f,p,H,{isHorizontal:z,constrained:et,angle:rt,anchor:P.insidetextanchor}));tt.fontSize=W.size,h(P.type,tt,L),R.transform=tt,M(q,L,m,v).attr(\"transform\",a.getTextTransform(tt))}(t,e,P,r,p,B,N,j,U,m,v),e.layerClipId&&l.hideOutsideRangePoint(c,P.select(\"text\"),w,L,f.xcalendar,f.ycalendar)}));var j=!1===f.cliponaxis;l.setClipUrl(c,j?null:e.layerClipId,t)}));c.getComponentMethod(\"errorbars\",\"plot\")(t,P,e,m)},toMoveInsideBar:C}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./attributes\":921,\"./constants\":923,\"./helpers\":927,\"./style\":935,\"./uniform_text\":937,d3:169,\"fast-isnumeric\":241}],933:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var f=i[r],h=\"ct\"in f?f.ct:n(f,a,o,c,l);e.contains(h,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(f.x),y:o.c2d(f.y)}),f.selected=1):f.selected=0}return u}},{}],934:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a,{unitMinDiff:e.unitMinDiff});this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":753,\"../../lib\":778}],935:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./uniform_text\").resizeText,c=t(\"./attributes\"),u=c.textfont,f=c.insidetextfont,h=c.outsidetextfont,p=t(\"./helpers\");function d(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),g(t,e,r)}function g(t,e,r){t.selectAll(\"text\").each((function(t){var i=n.select(this),s=o.ensureUniformFontSize(r,m(i,t,e,r));a.font(i,s)}))}function m(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=_(e,r);a=y(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=x(r,e.i,i));return a}function v(t,e,r){return b(u,t.textfont,e,r)}function y(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),b(f,t.insidetextfont,e,a)}function x(t,e,r){var n=v(t,e,r);return b(h,t.outsidetextfont,e,n)}function b(t,e,r,n){e=e||{};var i=p.getValue(e.family,r),a=p.getValue(e.size,r),o=p.getValue(e.color,r);return{family:p.coerceString(t.family,i,n.family),size:p.coerceNumber(t.size,a,n.size),color:p.coerceColor(t.color,o,n.color)}}function _(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\");l(t,e,\"bar\");var r=e.size(),i=t._fullLayout;e.style(\"opacity\",(function(t){return t[0].trace.opacity})).each((function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")})),e.selectAll(\"g.points\").each((function(e){d(n.select(this),e[0].trace,t)})),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:g,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each((function(t){var i,s=n.select(this);if(t.selected){i=o.ensureUniformFontSize(r,m(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)}))}(t.selectAll(\"text\"),e,r)}(r,i,t):(d(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:y,getOutsideTextFont:x,getBarColor:_,resizeText:l}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../registry\":911,\"./attributes\":921,\"./helpers\":927,\"./uniform_text\":937,d3:169}],936:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":643,\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654}],937:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");function a(t){return\"_\"+t+\"Text_minsize\"}e.exports={recordMinTextSize:function(t,e,r){if(r.uniformtext.mode){var n=a(t),i=r.uniformtext.minsize,o=e.scale*e.fontSize;e.hide=o<i,r[n]=r[n]||1/0,e.hide||(r[n]=Math.min(r[n],Math.max(o,i)))}},clearMinTextSize:function(t,e){e[a(t)]=void 0},resizeText:function(t,e,r){var a=t._fullLayout,o=a[\"_\"+r+\"Text_minsize\"];if(o){var s,l=\"hide\"===a.uniformtext.mode;switch(r){case\"funnelarea\":case\"pie\":case\"sunburst\":s=\"g.slice\";break;case\"treemap\":s=\"g.slice, g.pathbar\";break;default:s=\"g.points > g.point\"}e.selectAll(s).each((function(t){var e=t.transform;e&&(e.scale=l&&e.hide?0:o/e.fontSize,n.select(this).select(\"text\").attr(\"transform\",i.getTextTransform(e)))}))}}}},{\"../../lib\":778,d3:169}],938:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatterpolar/attributes\":1261}],939:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),f=c.makeCalcdata(e,\"theta\"),h=e._length,p=new Array(h),d=u,g=f,m=0;m<h;m++)p[m]={p:g[m],s:d[m]};function v(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(v(\"width\"),v(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var f=c({},e.radialaxis,{_id:\"x\"}),h=e.angularaxis;o(t,h,f,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../registry\":911,\"../bar/arrays_to_calcdata\":920,\"../bar/cross_trace_calc\":924,\"../scatter/calc_selection\":1189}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":778,\"../bar/style_defaults\":936,\"../scatterpolar/defaults\":1263,\"./attributes\":938}],941:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,f=t.subplot,h=f.radialAxis,p=f.angularAxis,d=f.vangles,g=d?l:i.isPtInsideSector,m=t.maxHoverDistance,v=p._period||2*Math.PI,y=Math.abs(h.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);h.range[0]>h.range[1]&&(x+=Math.PI);if(n.getClosest(c,(function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?m+Math.min(1,Math.abs(t.thetag1-t.thetag0)/v)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0}),t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,f,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":683,\"../../lib\":778,\"../../plots/polar/helpers\":893,\"../bar/hover\":928,\"../scatterpolar/hover\":1265}],942:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"../scatterpolar/format_labels\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":894,\"../bar/select\":933,\"../bar/style\":935,\"../scatter/marker_colorbar\":1205,\"../scatterpolar/format_labels\":1264,\"./attributes\":938,\"./calc\":939,\"./defaults\":940,\"./hover\":941,\"./layout_attributes\":943,\"./layout_defaults\":944,\"./plot\":945}],943:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],944:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":778,\"./layout_attributes\":943}],945:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,f=e.angularAxis,h=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var f=[s.findEnclosingVertexAngles(c,t.vangles)[0],(c+u)/2,s.findEnclosingVertexAngles(u,t.vangles)[1]];return s.pathPolygonAnnulus(n,i,c,u,f,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each((function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each((function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=f.c2g(t.p0),d=t.thetag1=f.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),m=(p+d)/2;t.ct=[l.c2p(g*Math.cos(m)),c.c2p(g*Math.sin(m))],e=h(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)})),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../plots/polar/helpers\":893,d3:169,\"fast-isnumeric\":241}],946:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",editType:\"calc\"},dy:{valType:\"number\",editType:\"calc\"},xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},q1:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},median:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},q3:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},lowerfence:{valType:\"data_array\",editType:\"calc\"},upperfence:{valType:\"data_array\",editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},notchspan:{valType:\"data_array\",editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],editType:\"calc\"},mean:{valType:\"data_array\",editType:\"calc\"},sd:{valType:\"data_array\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},quartilemethod:{valType:\"enumerated\",values:[\"linear\",\"exclusive\",\"inclusive\"],dflt:\"linear\",editType:\"calc\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../../lib\"),s=t(\"../../constants/numerical\").BADNUM,l=o._;e.exports=function(t,e){var r,c,y,x,b,_,w,T=t._fullLayout,k=i.getFromId(t,e.xaxis||\"x\"),M=i.getFromId(t,e.yaxis||\"y\"),A=[],S=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(y=k,x=\"x\",b=M,_=\"y\",w=!!e.yperiodalignment):(y=M,x=\"y\",b=k,_=\"x\",w=!!e.xperiodalignment);var E,C,L,I,P,z,O=function(t,e,r,i){var s,l=e+\"0\"in t,c=\"d\"+e in t;if(e in t||l&&c){var u=r.makeCalcdata(t,e);return[a(t,r,e,u),u]}s=l?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||o.isDateTime(t.name)&&\"date\"===r.type)?t.name:i;for(var f=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]),h=t._length,p=new Array(h),d=0;d<h;d++)p[d]=f;return[p]}(e,_,b,T[S]),D=O[0],R=O[1],F=o.distinctVals(D),B=F.vals,N=F.minDiff/2,j=\"all\"===(e.boxpoints||e.points)?o.identity:function(t){return t.v<E.lf||t.v>E.uf};if(e._hasPreCompStats){var U=e[x],V=function(t){return y.d2c((e[t]||[])[r])},q=1/0,H=-1/0;for(r=0;r<e._length;r++){var G=D[r];if(n(G)){if((E={}).pos=E[_]=G,w&&R&&(E.orig_p=R[r]),E.q1=V(\"q1\"),E.med=V(\"median\"),E.q3=V(\"q3\"),C=[],U&&o.isArrayOrTypedArray(U[r]))for(c=0;c<U[r].length;c++)(z=y.d2c(U[r][c]))!==s&&(u(P={v:z,i:[r,c]},e,[r,c]),C.push(P));if(E.pts=C.sort(f),I=(L=E[x]=C.map(h)).length,E.med!==s&&E.q1!==s&&E.q3!==s&&E.med>=E.q1&&E.q3>=E.med){var Y=V(\"lowerfence\");E.lf=Y!==s&&Y<=E.q1?Y:p(E,L,I);var W=V(\"upperfence\");E.uf=W!==s&&W>=E.q3?W:d(E,L,I);var X=V(\"mean\");E.mean=X!==s?X:I?o.mean(L,I):(E.q1+E.q3)/2;var Z=V(\"sd\");E.sd=X!==s&&Z>=0?Z:I?o.stdev(L,I,E.mean):E.q3-E.q1,E.lo=g(E),E.uo=m(E);var J=V(\"notchspan\");J=J!==s&&J>0?J:v(E,I),E.ln=E.med-J,E.un=E.med+J;var K=E.lf,Q=E.uf;e.boxpoints&&L.length&&(K=Math.min(K,L[0]),Q=Math.max(Q,L[I-1])),e.notched&&(K=Math.min(K,E.ln),Q=Math.max(Q,E.un)),E.min=K,E.max=Q}else{var $;o.warn([\"Invalid input - make sure that q1 <= median <= q3\",\"q1 = \"+E.q1,\"median = \"+E.med,\"q3 = \"+E.q3].join(\"\\n\")),$=E.med!==s?E.med:E.q1!==s?E.q3!==s?(E.q1+E.q3)/2:E.q1:E.q3!==s?E.q3:0,E.med=$,E.q1=E.q3=$,E.lf=E.uf=$,E.mean=E.sd=$,E.ln=E.un=$,E.min=E.max=$}q=Math.min(q,E.min),H=Math.max(H,E.max),E.pts2=C.filter(j),A.push(E)}}e._extremes[y._id]=i.findExtremes(y,[q,H],{padded:!0})}else{var tt=y.makeCalcdata(e,x),et=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(B,N),rt=B.length,nt=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(rt);for(r=0;r<e._length;r++)if(z=tt[r],n(z)){var it=o.findBin(D[r],et);it>=0&&it<rt&&(u(P={v:z,i:r},e,r),nt[it].push(P))}var at=1/0,ot=-1/0,st=e.quartilemethod,lt=\"exclusive\"===st,ct=\"inclusive\"===st;for(r=0;r<rt;r++)if(nt[r].length>0){var ut,ft;if((E={}).pos=E[_]=B[r],C=E.pts=nt[r].sort(f),I=(L=E[x]=C.map(h)).length,E.min=L[0],E.max=L[I-1],E.mean=o.mean(L,I),E.sd=o.stdev(L,I,E.mean),E.med=o.interp(L,.5),I%2&&(lt||ct))lt?(ut=L.slice(0,I/2),ft=L.slice(I/2+1)):ct&&(ut=L.slice(0,I/2+1),ft=L.slice(I/2)),E.q1=o.interp(ut,.5),E.q3=o.interp(ft,.5);else E.q1=o.interp(L,.25),E.q3=o.interp(L,.75);E.lf=p(E,L,I),E.uf=d(E,L,I),E.lo=g(E),E.uo=m(E);var ht=v(E,I);E.ln=E.med-ht,E.un=E.med+ht,at=Math.min(at,E.ln),ot=Math.max(ot,E.un),E.pts2=C.filter(j),A.push(E)}e._extremes[y._id]=i.findExtremes(y,e.notched?tt.concat([at,ot]):tt,{padded:!0})}return function(t,e){if(o.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],i={},a=0;a<n.length;a++)i[n[a].i]=a;o.tagSelected(n,e,i)}}(A,e),A.length>0?(A[0].t={num:T[S],dPos:N,posLetter:_,valLetter:x,labels:{med:l(t,\"median:\"),min:l(t,\"min:\"),q1:l(t,\"q1:\"),q3:l(t,\"q3:\"),max:l(t,\"max:\"),mean:\"sd\"===e.boxmean?l(t,\"mean \\xb1 \\u03c3:\"):l(t,\"mean:\"),lf:l(t,\"lower fence:\"),uf:l(t,\"upper fence:\")}},T[S]++,A):[{t:{empty:!0}}]};var c={text:\"tx\",hovertext:\"htx\"};function u(t,e,r){for(var n in c)o.isArrayOrTypedArray(e[n])&&(Array.isArray(r)?o.isArrayOrTypedArray(e[n][r[0]])&&(t[c[n]]=e[n][r[0]][r[1]]):t[c[n]]=e[n][r])}function f(t,e){return t.v-e.v}function h(t){return t.v}function p(t,e,r){return 0===r?t.q1:Math.min(t.q1,e[Math.min(o.findBin(2.5*t.q1-1.5*t.q3,e,!0)+1,r-1)])}function d(t,e,r){return 0===r?t.q3:Math.max(t.q3,e[Math.max(o.findBin(2.5*t.q3-1.5*t.q1,e),0)])}function g(t){return 4*t.q1-3*t.q3}function m(t){return 4*t.q3-3*t.q1}function v(t,e){return 0===e?0:1.57*(t.q3-t.q1)/Math.sqrt(e)}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"fast-isnumeric\":241}],948:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/constraints\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,f=e._fullLayout,h=o._id,p=h.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(o.c2l(c[l].pos,!0)),g+=(c[l].pts2||[]).length;if(d.length){var m=i.distinctVals(d,{unitMinDiff:\"category\"===o.type||\"multicategory\"===o.type}),v=m.minDiff/2;n.minDtick(o,m.minDiff,m.vals[0],!0);var y=f[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===f[t+\"mode\"]&&y>1,b=1-f[t+\"gap\"],_=1-f[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,T,k,M,A,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,I=E.side;if(L)w=T=M=L/2,k=0;else if(w=v,x){var P=a(f,o._id)+E.orientation,z=(f._alignmentOpts[P]||{})[E.alignmentgroup]||{},O=Object.keys(z.offsetGroups||{}).length,D=O||y;T=w*b*_/D,k=2*w*(((O?E._offsetIndex:C.num)+.5)/D-.5)*b,M=w*b/D}else T=w*b*_,k=0,M=w;C.dPos=w,C.bPos=k,C.bdPos=T,C.wHover=M;var R,F,B,N,j,U,V=k+T,q=Boolean(L);if(\"positive\"===I?(A=w*(L?1:.5),R=V,S=R=k):\"negative\"===I?(A=R=k,S=w*(L?1:.5),F=V):(A=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>A?(q=!0,j=Y,B=W):W>R&&(j=Y,B=A)),W<=A&&(B=A);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=A,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[h]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,vpadLinearized:!0,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(f)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/constraints\":835}],949:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../scatter/period_defaults\"),s=t(\"../bar/defaults\").handleGroupingDefaults,l=t(\"../../plots/cartesian/axis_autotype\"),c=t(\"./attributes\");function u(t,e,r,a){function o(t){var e=0;return t&&t.length&&(e+=1,n.isArrayOrTypedArray(t[0])&&t[0].length&&(e+=1)),e}function s(e){return n.validate(t[e],c[e])}var u,f=r(\"y\"),h=r(\"x\");if(\"box\"===e.type){var p=r(\"q1\"),d=r(\"median\"),g=r(\"q3\");e._hasPreCompStats=p&&p.length&&d&&d.length&&g&&g.length,u=Math.min(n.minRowLength(p),n.minRowLength(d),n.minRowLength(g))}var m,v,y=o(f),x=o(h),b=y&&n.minRowLength(f),_=x&&n.minRowLength(h),w=a.calendar,T={autotypenumbers:a.autotypenumbers};if(e._hasPreCompStats)switch(String(x)+String(y)){case\"00\":var k=s(\"x0\")||s(\"dx\");m=(s(\"y0\")||s(\"dy\"))&&!k?\"h\":\"v\",v=u;break;case\"10\":m=\"v\",v=Math.min(u,_);break;case\"20\":m=\"h\",v=Math.min(u,h.length);break;case\"01\":m=\"h\",v=Math.min(u,b);break;case\"02\":m=\"v\",v=Math.min(u,f.length);break;case\"12\":m=\"v\",v=Math.min(u,_,f.length);break;case\"21\":m=\"h\",v=Math.min(u,h.length,b);break;case\"11\":v=0;break;case\"22\":var M,A=!1;for(M=0;M<h.length;M++)if(\"category\"===l(h[M],w,T)){A=!0;break}if(A)m=\"v\",v=Math.min(u,_,f.length);else{for(M=0;M<f.length;M++)if(\"category\"===l(f[M],w,T)){A=!0;break}A?(m=\"h\",v=Math.min(u,h.length,b)):(m=\"v\",v=Math.min(u,_,f.length))}}else y>0?(m=\"v\",v=x>0?Math.min(_,b):Math.min(b)):x>0?(m=\"h\",v=Math.min(_)):v=0;if(v){e._length=v;var S=r(\"orientation\",m);e._hasPreCompStats?\"v\"===S&&0===x?(r(\"x0\",0),r(\"dx\",1)):\"h\"===S&&0===y&&(r(\"y0\",0),r(\"dy\",1)):\"v\"===S&&0===x?r(\"x0\"):\"h\"===S&&0===y&&r(\"y0\"),i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a)}else e.visible=!1}function f(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,c,\"marker.outliercolor\"),s=r(\"marker.line.outliercolor\"),l=\"outliers\";e._hasPreCompStats?l=\"all\":(o||s)&&(l=\"suspectedoutliers\");var u=r(a+\"points\",l);u?(r(\"jitter\",\"all\"===u?.3:0),r(\"pointpos\",\"all\"===u?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===u&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var f=r(\"hoveron\");\"all\"!==f&&-1===f.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function s(r,i){return n.coerce(t,e,c,r,i)}if(u(t,e,s,i),!1!==e.visible){o(t,e,i,s);var l=e._hasPreCompStats;l&&(s(\"lowerfence\"),s(\"upperfence\")),s(\"line.color\",(t.marker||{}).color||r),s(\"line.width\"),s(\"fillcolor\",a.addOpacity(e.line.color,.5));var h=!1;if(l){var p=s(\"mean\"),d=s(\"sd\");p&&p.length&&(h=!0,d&&d.length&&(h=\"sd\"))}s(\"boxmean\",h),s(\"whiskerwidth\"),s(\"width\"),s(\"quartilemethod\");var g=!1;if(l){var m=s(\"notchspan\");m&&m.length&&(g=!0)}else n.validate(t.notchwidth,c.notchwidth)&&(g=!0);s(\"notched\",g)&&s(\"notchwidth\"),f(t,e,s,{prefix:\"box\"})}},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,c,t)}for(var o=0;o<t.length;o++){var l=(i=t[o]).type;\"box\"!==l&&\"violin\"!==l||(r=i._input,\"group\"===e[l+\"mode\"]&&s(r,i,e,a))}},handleSampleDefaults:u,handlePointsDefaults:f}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/axis_autotype\":829,\"../../registry\":911,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"./attributes\":946}],950:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],951:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,f,h,p,d,g,m,v,y,x,b,_,w=t.cd,T=t.xa,k=t.ya,M=w[0].trace,A=w[0].t,S=\"violin\"===M.type,E=[],C=A.bdPos,L=A.wHover,I=function(t){return u.c2l(t.pos)+A.bPos-u.c2l(p)};S&&\"both\"!==M.side?(\"positive\"===M.side&&(m=function(t){var e=I(t);return a.inbox(e,e+L,v)},x=C,b=0),\"negative\"===M.side&&(m=function(t){var e=I(t);return a.inbox(e-L,e,v)},x=0,b=C)):(m=function(t){var e=I(t);return a.inbox(e-L,e+L,v)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-h,t.span[1]-h,v)}:function(t){return a.inbox(t.min-h,t.max-h,v)},\"h\"===M.orientation?(h=e,p=r,d=_,g=m,l=\"y\",u=k,c=\"x\",f=T):(h=r,p=e,d=m,g=_,l=\"x\",u=T,c=\"y\",f=k);var P=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}v=t.maxHoverDistance-P,y=t.maxSpikeDistance-P;var O=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,O,t),!1===t.index)return[];var D=w[t.index],R=M.line.color,F=(M.marker||{}).color;o.opacity(R)&&M.line.width?t.color=R:o.opacity(F)&&M.boxpoints?t.color=F:t.color=M.fillcolor,t[l+\"0\"]=u.c2p(D.pos+A.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+A.bPos+x,!0),t[l+\"LabelVal\"]=void 0!==D.orig_p?D.orig_p:D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/v,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(M.boxmean||(M.meanline||{}).visible)&&j.push(\"mean\"),(M.boxpoints||M.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=f.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(A.labels?A.labels[V]+\" \":\"\")+n.hoverLabelText(f,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===M.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,f=t.ya,h=c[0].trace,p=u.c2p(e),d=f.c2p(r),g=a.quadrature((function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)}),(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(f.c2p(t.y)-d)-e,1-3/e)})),m=!1,v=0;v<c.length;v++){o=c[v];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,m=[v,y])}}if(!m)return!1;l=(o=c[m[0]]).pts[m[1]];var b=u.c2p(l.x,!0),_=f.c2p(l.y,!0),w=l.mrc||1;n=i.extendFlat({},t,{index:l.i,color:(h.marker||{}).color,name:h.name,x0:b-w,x1:b+w,y0:_-w,y1:_+w,spikeDistance:t.distance,hovertemplate:h.hovertemplate});var T,k=o.orig_p,M=void 0!==k?k:o.pos;return\"h\"===h.orientation?(T=f,n.xLabelVal=l.x,n.yLabelVal=M):(T=u,n.xLabelVal=M,n.yLabelVal=l.y),n[T._id.charAt(0)+\"Spike\"]=T.c2p(o.pos,!0),s(l,h,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],952:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":946,\"./calc\":947,\"./cross_trace_calc\":948,\"./defaults\":949,\"./event_data\":950,\"./hover\":951,\"./layout_attributes\":953,\"./layout_defaults\":954,\"./plot\":955,\"./select\":956,\"./style\":957}],953:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,(function(r,n){return i.coerce(t,e,a,r,n)}),\"box\")},_supply:o}},{\"../../lib\":778,\"../../registry\":911,\"./layout_attributes\":953}],955:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\");function o(t,e,r,a){var o,s,l=\"h\"===r.orientation,c=e.val,u=e.pos,f=!!u.rangebreaks,h=a.bPos,p=a.wdPos||0,d=a.bPosPxOffset||0,g=r.whiskerwidth||0,m=r.notched||!1,v=m?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var y=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);y.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),y.exit().remove(),y.each((function(t){if(t.empty)return\"M0,0Z\";var e=u.c2l(t.pos+h,!0),a=u.l2p(e-o)+d,y=u.l2p(e+s)+d,x=f?(a+y)/2:u.l2p(e)+d,b=r.whiskerwidth,_=f?a*b+(1-b)*x:u.l2p(e-p)+d,w=f?y*b+(1-b)*x:u.l2p(e+p)+d,T=u.l2p(e-o*v)+d,k=u.l2p(e+s*v)+d,M=c.c2p(t.q1,!0),A=c.c2p(t.q3,!0),S=i.constrain(c.c2p(t.med,!0),Math.min(M,A)+1,Math.max(M,A)-1),E=void 0===t.lf||!1===r.boxpoints,C=c.c2p(E?t.min:t.lf,!0),L=c.c2p(E?t.max:t.uf,!0),I=c.c2p(t.ln,!0),P=c.c2p(t.un,!0);l?n.select(this).attr(\"d\",\"M\"+S+\",\"+T+\"V\"+k+\"M\"+M+\",\"+a+\"V\"+y+(m?\"H\"+I+\"L\"+S+\",\"+k+\"L\"+P+\",\"+y:\"\")+\"H\"+A+\"V\"+a+(m?\"H\"+P+\"L\"+S+\",\"+T+\"L\"+I+\",\"+a:\"\")+\"ZM\"+M+\",\"+x+\"H\"+C+\"M\"+A+\",\"+x+\"H\"+L+(0===g?\"\":\"M\"+C+\",\"+_+\"V\"+w+\"M\"+L+\",\"+_+\"V\"+w)):n.select(this).attr(\"d\",\"M\"+T+\",\"+S+\"H\"+k+\"M\"+a+\",\"+M+\"H\"+y+(m?\"V\"+I+\"L\"+k+\",\"+S+\"L\"+y+\",\"+P:\"\")+\"V\"+A+\"H\"+a+(m?\"V\"+P+\"L\"+T+\",\"+S+\"L\"+a+\",\"+I:\"\")+\"ZM\"+x+\",\"+M+\"V\"+C+\"M\"+x+\",\"+A+\"V\"+L+(0===g?\"\":\"M\"+_+\",\"+C+\"H\"+w+\"M\"+_+\",\"+L+\"H\"+w))}))}function s(t,e,r,n){var o=e.x,s=e.y,l=n.bdPos,c=n.bPos,u=r.boxpoints||r.points;i.seedPseudoRandom();var f=t.selectAll(\"g.points\").data(u?function(t){return t.forEach((function(t){t.t=n,t.trace=r})),t}:[]);f.enter().append(\"g\").attr(\"class\",\"points\"),f.exit().remove();var h=f.selectAll(\"path\").data((function(t){var e,n,a=t.pts2,o=Math.max((t.max-t.min)/10,t.q3-t.q1),s=1e-9*o,f=.01*o,h=[],p=0;if(r.jitter){if(0===o)for(p=1,h=new Array(a.length),e=0;e<a.length;e++)h[e]=1;else for(e=0;e<a.length;e++){var d=Math.max(0,e-5),g=a[d].v,m=Math.min(a.length-1,e+5),v=a[m].v;\"all\"!==u&&(a[e].v<t.lf?v=Math.min(v,t.lf):g=Math.max(g,t.uf));var y=Math.sqrt(f*(m-d)/(v-g+s))||0;y=i.constrain(Math.abs(y),0,1),h.push(y),p=Math.max(y,p)}n=2*r.jitter/(p||1)}for(e=0;e<a.length;e++){var x=a[e],b=x.v,_=r.jitter?n*h[e]*(i.pseudoRandom()-.5):0,w=t.pos+c+l*(r.pointpos+_);\"h\"===r.orientation?(x.y=w,x.x=b):(x.x=w,x.y=b),\"suspectedoutliers\"===u&&b<t.uo&&b>t.lo&&(x.so=!0)}return a}));h.enter().append(\"path\").classed(\"point\",!0),h.exit().remove(),h.call(a.translatePoints,o,s)}function l(t,e,r,a){var o,s,l=e.val,c=e.pos,u=!!c.rangebreaks,f=a.bPos,h=a.bPosPxOffset||0,p=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var d=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);d.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),d.exit().remove(),d.each((function(t){var e=c.c2l(t.pos+f,!0),i=c.l2p(e-o)+h,a=c.l2p(e+s)+h,d=u?(i+a)/2:c.l2p(e)+h,g=l.c2p(t.mean,!0),m=l.c2p(t.mean-t.sd,!0),v=l.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+g+\",\"+i+\"V\"+a+(\"sd\"===p?\"m0,0L\"+m+\",\"+d+\"L\"+g+\",\"+i+\"L\"+v+\",\"+d+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+g+\"H\"+a+(\"sd\"===p?\"m0,0L\"+d+\",\"+m+\"L\"+i+\",\"+g+\"L\"+d+\",\"+v+\"Z\":\"\"))}))}e.exports={plot:function(t,e,r,a){var c=e.xaxis,u=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each((function(t){var e,r,i=n.select(this),a=t[0],f=a.t,h=a.trace;(f.wdPos=f.bdPos*h.whiskerwidth,!0!==h.visible||f.empty)?i.remove():(\"h\"===h.orientation?(e=u,r=c):(e=c,r=u),o(i,{pos:e,val:r},h,f),s(i,{x:c,y:u},h,f),l(i,{pos:e,val:r},h,f))}))},plotBoxAndWhiskers:o,plotPoints:s,plotBoxMean:l}},{\"../../components/drawing\":665,\"../../lib\":778,d3:169}],956:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],957:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each((function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}}));else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}}))},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":643,\"../../components/drawing\":665,d3:169}],958:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":778,\"../box/attributes\":946,\"../ohlc/attributes\":1133}],959:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../ohlc/calc\").calcCommon;function s(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,l=i.getFromId(t,e.xaxis),c=i.getFromId(t,e.yaxis),u=l.makeCalcdata(e,\"x\"),f=a(e,l,\"x\",u),h=o(t,e,u,f,c,s);return h.length?(n.extendFlat(h[0].t,{num:r._numBoxes,dPos:n.distinctVals(f).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,h):[{t:{empty:!0}}]}},{\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../ohlc/calc\":1134}],960:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"../scatter/period_defaults\"),s=t(\"./attributes\");function l(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}a(t,e,c,i)?(o(t,e,i,c,{x:!0}),c(\"line.width\"),l(t,e,c,\"increasing\"),l(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":643,\"../../lib\":778,\"../ohlc/ohlc_defaults\":1138,\"../scatter/period_defaults\":1207,\"./attributes\":958}],961:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":841,\"../box/cross_trace_calc\":948,\"../box/layout_attributes\":953,\"../box/layout_defaults\":954,\"../box/plot\":955,\"../box/style\":957,\"../ohlc/hover\":1136,\"../ohlc/select\":1140,\"./attributes\":958,\"./calc\":959,\"./defaults\":960}],962:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach((function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,autotypenumbersDflt:r.autotypenumbers,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})}))}(t,e,r,o)}},{\"../../plot_api/plot_template\":817,\"./axis_defaults\":967}],963:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;for(var i=1/0,a=-1/0,o=e.length,s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":778}],964:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":642,\"../../plots/font_attributes\":856,\"./axis_attributes\":966}],965:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g,m,v,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,T=\"a\"===y?e.a.length:e.b.length,k=\"a\"===y?e.b.length:e.a.length,M=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),A=\"a\"===y?function(e){return t.evalxy([],e,M)}:function(e){return t.evalxy([],M,e)};x&&(s=Math.max(0,Math.min(k-2,M)),l=M-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),I=C>0?Math.floor:Math.ceil,P=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,O=C>0?Math.max:Math.min,D=I(S+L),R=P(E-L),F=[[f=A(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=O(S,a),v=(m=z(E,a+C))-g,u=Math.max(0,Math.min(T-2,Math.floor(.5*(g+m)))),h=A(m),x&&(p=o(u,g-u),d=o(u,m-u),c.push([f[0]+p[0]/3*v,f[1]+p[1]/3*v]),c.push([h[0]-d[0]/3*v,h[1]-d[1]/3*v])),c.push(h),F.push(c),f=h;return F}},{\"../../lib\":778}],966:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autotypenumbers:a.autotypenumbers,autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":642,\"../../constants/docs\":748,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/font_attributes\":856}],967:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),f=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var h=r.letter,p=r.font||{},d=n[h+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function m(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name),g(\"autotypenumbers\",r.autotypenumbersDflt);var v=g(\"type\");(\"-\"===v&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=f(e,n,{autotypenumbers:t.autotypenumbers})}(e,r.data),\"-\"===e.type?e.type=\"linear\":v=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",h+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"minexponent\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=h,\"date\"===v)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,v),l(t,e,g,v,r),c(t,e,g,{data:r.data,dataAttr:h});var b=m(\"gridcolor\",i(y,.3)),_=m(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var T=m(\"startlinecolor\",y),k=m(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!T||!!k)||(delete e.startlinecolor,delete e.startlinewidth);var M=m(\"endlinecolor\",y),A=m(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!M||!!A)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.minexponent,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/axis_autotype\":829,\"../../plots/cartesian/category_order_defaults\":832,\"../../plots/cartesian/set_convert\":848,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_value_defaults\":851,\"../../registry\":911,\"./attributes\":964}],968:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),f=t(\"./smooth_fill_2d_array\"),h=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,m=e.baxis,v=e.x,y=e.y,x=[];v&&i(v)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&h(e,g,m,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;v=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var T=\"index\"===g.cheatertype?b.length:b,k=\"index\"===m.cheatertype?_.length:_;v=a(T,k,e.cheaterslope)}e._x=v=u(v),e._y=y=u(y),f(v,b,_),f(y,b,_),p(e),e.setScale();var M=o(v),A=o(y),S=.5*(M[1]-M[0]),E=.5*(M[1]+M[0]),C=.5*(A[1]-A[0]),L=.5*(A[1]+A[0]);return M=[E-1.3*S,E+1.3*S],A=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,M,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,A,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,m),w.clipsegments=c(e._xctrl,e._yctrl,g,m),w.x=v,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../heatmap/clean_2d_array\":1067,\"../heatmap/convert_column_xyz\":1069,\"./array_minmax\":963,\"./calc_clippath\":969,\"./calc_gridlines\":970,\"./calc_labels\":971,\"./cheater_basis\":973,\"./set_convert\":986,\"./smooth_fill_2d_array\":987}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,f=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=f;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[f][i],o[u-i]=e[f][i];for(s.push({x:a,y:o,bicubic:l}),i=f,a=[],o=[];i>=0;i--)a[f-i]=t[i][0],o[f-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,f,h,p,d,g,m,v,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],T=b._boundarylines=[],k=t[\"_\"+r],M=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var A=t._xctrl,S=t._yctrl,E=A[0].length,C=A.length,L=t._a.length,I=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var P=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,f,p,d,g,m,v=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(I-2,a))),s=a-o,x.length=I,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,f=t.evalxy([],i,a),M.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),v.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),v.push(f[0]-d[0]/3),y.push(f[1]-d[1]/3)),v.push(f[0]),y.push(f[1]),l=f;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=I,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<I;a++)o=Math.min(I-2,a),s=a-o,f=t.evalxy([],i,a),M.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),v.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),m=t.dxydj([],c,a-1,u,1),v.push(f[0]-m[0]/3),y.push(f[1]-m[1]/3)),v.push(f[0]),y.push(f[1]),l=f;return x.axisLetter=e,x.axis=b,x.crossAxis=M,x.value=n,x.constvar=r,x.index=h,x.x=v,x.y=y,x.smoothing=M.smoothing,x}function O(n){var i,a,o,s,l,c=[],u=[],f={};if(f.length=x.length,f.crossLength=k.length,\"b\"===e)for(o=Math.max(0,Math.min(I-2,n)),l=Math.min(1,Math.max(0,n-o)),f.xy=function(e){return t.evalxy([],e,n)},f.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=A[n*P][i],u[i]=S[n*P][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),f.xy=function(e){return t.evalxy([],n,e)},f.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=A[i][n*P],u[i]=S[i][n*P];return f.axisLetter=e,f.axis=b,f.crossAxis=M,f.value=x[n],f.constvar=r,f.index=n,f.x=c,f.y=u,f.smoothing=M.smoothing,f}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort((function(t,e){return t-e})))[0]-1,f=c[1]+1,h=u;h<f;h++)(o=b.arraytick0+b.arraydtick*h)<0||o>x.length-1||_.push(i(O(o),{color:b.gridcolor,width:b.gridwidth}));for(h=u;h<f;h++)if(s=b.arraytick0+b.arraydtick*h,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(m=x[s],v=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=m+(v-m)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(O(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(O(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort((function(t,e){return t-e})))[0],f=c[1],h=u;h<=f;h++)p=b.tick0+b.dtick*h,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(h=u-1;h<f+1;h++)for(p=b.tick0+b.dtick*h,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":768,\"../../plots/cartesian/axes\":828}],971:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":768,\"../../plots/cartesian/axes\":828}],972:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,f=(c*c*a-l*l*s)*n,h=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(h&&u/h),e[1]+(h&&f/h)],[e[0]-(p&&u/p),e[1]-(p&&f/p)]]}},{}],973:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],f=n(t)?t.length:t,h=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(f-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(h-1));var g=1/0,m=-1/0;for(a=0;a<h;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(h-1),i=0;i<f;i++)c=(p?(p[i]-p[0])*o:i/(f-1))-l*r,g=Math.min(c,g),m=Math.max(c,m),u[a][i]=c;var v=1/(m-g),y=-g*v;for(a=0;a<h;a++)for(i=0;i<f;i++)u[a][i]=v*u[a][i]+y;return u}},{\"../../lib\":778}],974:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,f,h,p,d,g,m,v,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),f=0;f<w;f++)t[f]=i(t[f],_),e[f]=i(e[f],_);for(u=0,h=0;u<b;u++,h+=l?3:1)for(p=t[h],d=e[h],g=r[u],m=o[u],c=0,f=0;c<x;c++,f+=s?3:1)p[f]=g[c],d[f]=m[c];if(s)for(u=0,h=0;u<b;u++,h+=l?3:1){for(c=1,f=3;c<x-1;c++,f+=3)v=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[h][f-1]=v[0][0],e[h][f-1]=v[0][1],t[h][f+1]=v[1][0],e[h][f+1]=v[1][1];y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=y[0],e[h][1]=y[1],y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=y[0],e[h][_-2]=y[1]}if(l)for(f=0;f<_;f++){for(h=3;h<w-3;h+=3)v=n([t[h-3][f],e[h-3][f]],[t[h][f],e[h][f]],[t[h+3][f],e[h+3][f]],l),t[h-1][f]=v[0][0],e[h-1][f]=v[0][1],t[h+1][f]=v[1][0],e[h+1][f]=v[1][1];y=a([t[0][f],e[0][f]],[t[2][f],e[2][f]],[t[3][f],e[3][f]]),t[1][f]=y[0],e[1][f]=y[1],y=a([t[w-1][f],e[w-1][f]],[t[w-3][f],e[w-3][f]],[t[w-4][f],e[w-4][f]]),t[w-2][f]=y[0],e[w-2][f]=y[1]}if(s&&l)for(h=1;h<w;h+=(h+1)%3==0?2:1){for(f=3;f<_-3;f+=3)v=n([t[h][f-3],e[h][f-3]],[t[h][f],e[h][f]],[t[h][f+3],e[h][f+3]],s),t[h][f-1]=.5*(t[h][f-1]+v[0][0]),e[h][f-1]=.5*(e[h][f-1]+v[0][1]),t[h][f+1]=.5*(t[h][f+1]+v[1][0]),e[h][f+1]=.5*(e[h][f+1]+v[1][1]);y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=.5*(t[h][1]+y[0]),e[h][1]=.5*(e[h][1]+y[1]),y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=.5*(t[h][_-2]+y[0]),e[h][_-2]=.5*(e[h][_-2]+y[1])}return[t,e]}},{\"../../lib\":778,\"./catmull_rom\":972}],975:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],976:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=1-i,d=p*p,g=p*i*2,m=-3*d,v=3*(d-g),y=3*(g-h),x=3*h,b=a*a,_=b*a,w=1-a,T=w*w,k=T*w;for(f=0;f<t.length;f++)o=m*(u=t[f])[n][r]+v*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=m*u[n+1][r]+v*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=m*u[n+2][r]+v*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=m*u[n+3][r]+v*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[f]=k*o+3*(T*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,f=1-i,h=f*f,p=f*i*2,d=-3*h,g=3*(h-p),m=3*(p-u),v=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+m*c[n][r+2]+v*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+m*c[n+1][r+2]+v*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),n*=3;var h=a*a,p=h*a,d=1-a,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n][r+1]-f[n][r],s=f[n+1][r+1]-f[n+1][r],l=f[n+2][r+1]-f[n+2][r],c=f[n+3][r+1]-f[n+3][r],e[u]=m*o+3*(g*a*s+d*h*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],977:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=h*i,d=1-i,g=d*d,m=g*d,v=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),T=3*(b-v),k=3*v;for(f=0;f<t.length;f++)o=_*(u=t[f])[n][r]+w*u[n+1][r]+T*u[n+2][r]+k*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+T*u[n+2][r+1]+k*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+T*u[n+2][r+2]+k*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+T*u[n+2][r+3]+k*u[n+3][r+3],e[f]=m*o+3*(g*i*s+d*h*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3;var h=a*a,p=h*a,d=1-a,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n+1][r]-f[n][r],s=f[n+1][r+1]-f[n][r+1],l=f[n+1][r+2]-f[n][r+2],c=f[n+1][r+3]-f[n][r+3],e[u]=m*o+3*(g*a*s+d*h*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,f=a*a,h=1-a,p=h*h,d=h*a*2,g=-3*p,m=3*(p-d),v=3*(d-f),y=3*f;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+m*c[n+1][r]+v*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+m*c[n+1][r+1]+v*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],978:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,f;e||(e=[]);var h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3,p*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,T=1-g,k=T*T,M=k*T;for(f=0;f<t.length;f++)i=b*(u=t[f])[p][h]+3*(x*d*u[p][h+1]+y*m*u[p][h+2])+v*u[p][h+3],s=b*u[p+1][h]+3*(x*d*u[p+1][h+1]+y*m*u[p+1][h+2])+v*u[p+1][h+3],l=b*u[p+2][h]+3*(x*d*u[p+2][h+1]+y*m*u[p+2][h+2])+v*u[p+2][h+3],c=b*u[p+3][h]+3*(x*d*u[p+3][h+1]+y*m*u[p+3][h+2])+v*u[p+3][h+3],e[f]=M*i+3*(k*g*s+T*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+g*f[p+1][h],s=_*f[p][h+1]+g*f[p+1][h+1],l=_*f[p][h+2]+g*f[p+1][h+1],c=_*f[p][h+3]+g*f[p+1][h+1],e[u]=b*i+3*(x*d*s+y*m*l)+v*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));p*=3;var m=g*g,v=m*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+d*f[p][h+1],s=_*f[p+1][h]+d*f[p+1][h+1],l=_*f[p+2][h]+d*f[p+2][h+1],c=_*f[p+3][h]+d*f[p+3][h+1],e[u]=b*i+3*(x*g*s+y*m*l)+v*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),f=Math.max(0,Math.min(Math.floor(n),o)),h=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-f)),d=1-p,g=1-h;for(l=0;l<t.length;l++)i=g*(c=t[l])[f][u]+h*c[f][u+1],s=g*c[f+1][u]+h*c[f+1][u+1],e[l]=d*i+p*s;return e}}},{}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":642,\"../../lib\":778,\"./ab_defaults\":962,\"./attributes\":964,\"./xy_defaults\":988}],980:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":964,\"./calc\":968,\"./defaults\":979,\"./plot\":985}],981:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],982:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":778}],984:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),f=Math.sqrt(a[0]*a[0]+a[1]*a[1]),h=(i[0]*a[0]+i[1]*a[1])/u/f;c=Math.max(0,h)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],985:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=c.strRotate,f=c.strTranslate,h=t(\"../../constants/alignment\");function p(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each((function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),f=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",f).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")})),u.exit().remove()}function d(t,e,r,a,o,c,h,p){var d=c.selectAll(\"text.\"+p).data(h);d.enter().append(\"text\").classed(p,!0);var g=0,m={};return d.each((function(o,c){var h;if(\"auto\"===o.axis.tickangle)h=s(a,e,r,o.xy,o.dxy);else{var p=(o.axis.tickangle+180)*Math.PI/180;h=s(a,e,r,o.xy,[Math.cos(p),Math.sin(p)])}c||(m={angle:h.angle,flip:h.flip});var d=(o.endAnchor?-1:1)*h.flip,v=n.select(this).attr({\"text-anchor\":d>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),y=i.bBox(this);v.attr(\"transform\",f(h.p[0],h.p[1])+u(h.angle)+f(o.axis.labelpadding*d,.3*y.height)),g=Math.max(g,y.width+o.axis.labelpadding)})),d.exit().remove(),m.maxExtent=g,m}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,f=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each((function(e){var r=n.select(this),i=e[0],h=i.trace,g=h.aaxis,m=h.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",h.opacity),p(l,u,x,g,\"a\",g._gridlines),p(l,u,x,m,\"b\",m._gridlines),p(l,u,y,g,\"a\",g._minorgridlines),p(l,u,y,m,\"b\",m._minorgridlines),p(l,u,b,g,\"a-boundary\",g._boundarylines),p(l,u,b,m,\"b-boundary\",m._boundarylines);var w=d(t,l,u,h,i,_,g._labels,\"a-label\"),T=d(t,l,u,h,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,f,h,p,d=c.aggNums(Math.min,null,r.a),g=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+g),f=m,h=r.ab2xy(u,f,!0),p=r.dxyda_rough(u,f),void 0===o.angle&&c.extendFlat(o,s(r,i,a,h,r.dxydb_rough(u,f)));v(t,e,r,n,h,p,r.aaxis,i,a,o,\"a-title\"),u=d,f=.5*(m+y),h=r.ab2xy(u,f,!0),p=r.dxydb_rough(u,f),void 0===l.angle&&c.extendFlat(l,s(r,i,a,h,r.dxyda_rough(u,f)));v(t,e,r,n,h,p,r.baxis,i,a,l,\"b-title\")}(t,_,h,i,l,u,w,T),function(t,e,r,n,i){var s,l,u,f,h=r.select(\"#\"+t._clipPathId);h.size()||(h=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(h,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(f=0;f<d.length;f++)s=d[f],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var m=\"M\"+g.join(\"L\")+\"Z\";h.attr(\"id\",t._clipPathId),p.attr(\"d\",m)}(h,i,f,l,u)}))};var g=h.LINE_SPACING,m=(1-h.MID_SHIFT)/g+1;function v(t,e,r,a,o,c,h,p,d,v,y){var x=[];h.title.text&&x.push(h.title.text);var b=e.selectAll(\"text.\"+y).data(x),_=v.maxExtent;b.enter().append(\"text\").classed(y,!0),b.each((function(){var e=s(r,p,d,o,c);-1===[\"start\",\"both\"].indexOf(h.showticklabels)&&(_=0);var a=h.title.font.size;_+=a+h.title.offset;var y=(v.angle+(v.flip<0?180:0)-e.angle+450)%360,x=y>90&&y<270,b=n.select(this);b.text(h.title.text).call(l.convertToTspans,t),x&&(_=(-l.lineCount(b)+m)*g*a-_),b.attr(\"transform\",f(e.p[0],e.p[1])+u(e.angle)+f(0,_)).attr(\"text-anchor\",\"middle\").call(i.font,h.title.font)})),b.exit().remove()}},{\"../../components/drawing\":665,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"./makepath\":982,\"./map_1d_array\":983,\"./orient_text\":984,d3:169}],986:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,f=t.aaxis,h=t.baxis,p=e[0],d=e[c-1],g=r[0],m=r[u-1],v=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=v*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,m+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<m},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>m},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,f.smoothing,h.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,f.smoothing,h.smoothing),t.dxydi=s([t._xctrl,t._yctrl],f.smoothing,h.smoothing),t.dxydj=l([t._xctrl,t._yctrl],f.smoothing,h.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var f,h,p,d,g=0,m=0,v=[];n<e[0]?(f=0,h=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(f=c-2,h=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):h=o-(f=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,m=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,m=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(v,f,p,h,d),l[0]+=v[0]*g,l[1]+=v[1]*g),m&&(t.dxydj(v,f,p,h,d),l[0]+=v[0]*m,l[1]+=v[1]*m)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=v*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":798,\"./compute_control_points\":974,\"./constants\":975,\"./create_i_derivative_evaluator\":976,\"./create_j_derivative_evaluator\":977,\"./create_spline_evaluator\":978}],987:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function f(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var h,p,d,g,m,v,y,x,b,_,w,T=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=f(i,a)),T=Math.max(T,Math.abs(t[a][i]));if(!s.length)return t;var k=0,M=0,A=s.length;do{for(k=0,o=0;o<A;o++){i=s[o],a=l[o];var S,E,C,L,I,P,z=0,O=0;0===i?(C=e[I=Math.min(c-1,2)],L=e[1],S=t[a][I],O+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[I=Math.max(0,c-3)],L=e[c-2],S=t[a][I],O+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(h=r[a+1]-r[a],O+=((p=r[a]-r[a-1])*t[a+1][i]+h*t[a-1][i])/(p+h),z++),0===a?(C=r[P=Math.min(u-1,2)],L=r[1],S=t[P][i],O+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[P=Math.max(0,u-3)],L=r[u-2],S=t[P][i],O+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(h=e[i+1]-e[i],O+=((p=e[i]-e[i-1])*t[a][i+1]+h*t[a][i-1])/(p+h),z++),z?O/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(m=r[a+1]-r[a])*(v=r[a]-r[a-1])*(m+v),O=((y=d*g*(d+g))*(v*t[a+1][i]+m*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(v+m))),k+=(_=(b=O-t[a][i])/T)*_,w=z?0:.85,t[a][i]+=b*(1+w)}k=Math.sqrt(k)}while(M++<100&&k>1e-5);return n.log(\"Smoother converged to\",k,\"after\",M,\"iterations\"),t}},{\"../../lib\":778}],988:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":778}],989:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},geojson:l({},i.geojson,{}),featureidkey:i.featureidkey,text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n(),showlegend:l({},o.showlegend,{dflt:!1})},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":642,\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scattergeo/attributes\":1229}],990:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var f=0;f<c;f++){var h=u[f]={},p=e.locations[f],d=e.z[f];r(p)&&n(d)?(h.loc=p,h.z=d):(h.loc=null,h.z=i),h.index=f}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc_selection\":1189,\"fast-isnumeric\":241}],991:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");if(l&&l.length&&n.isArrayOrTypedArray(c)&&c.length){e._length=Math.min(l.length,c.length);var u,f=s(\"geojson\");(\"string\"==typeof f&&\"\"!==f||n.isPlainObject(f))&&(u=\"geojson-id\"),\"geojson-id\"===s(\"locationmode\",u)&&s(\"featureidkey\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)}else e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":989}],992:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t.ct=a.ct,t}},{}],993:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,f=u[0].trace,h=t.subplot,p=[e,r],d=[e+360,r];for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains(p)&&(c=!c),o._polygons[l].contains(d)&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(h.mockAxis,h.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=String(r.loc),s=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),l=-1!==s.indexOf(\"name\"),c=-1!==s.indexOf(\"location\"),u=-1!==s.indexOf(\"z\"),f=-1!==s.indexOf(\"text\"),h=[];!l&&c?t.nameOverride=o:(l&&(t.nameOverride=e.name),c&&h.push(o));u&&h.push(t.zLabel);f&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,f,o),[t]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./attributes\":989}],994:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\",\"showLegend\"],meta:{}}},{\"../../plots/geo\":860,\"../heatmap/colorbar\":1068,\"./attributes\":989,\"./calc\":990,\"./defaults\":991,\"./event_data\":992,\"./hover\":993,\"./plot\":995,\"./select\":996,\"./style\":997}],995:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../plots/cartesian/autorange\").findExtremes,l=t(\"./style\").style;e.exports={calcGeoJSON:function(t,e){for(var r=t[0].trace,n=e[r.geo],i=n._subplot,l=r.locationmode,c=r._length,u=\"geojson-id\"===l?a.extractTraceFeature(t):o(r,i.topojson),f=[],h=[],p=0;p<c;p++){var d=t[p],g=\"geojson-id\"===l?d.fOut:a.locationToFeature(l,d.loc,u);if(g){d.geojson=g,d.ct=g.properties.ct,d._polygons=a.feature2polygons(g);var m=a.computeBbox(g);f.push(m[0],m[2]),h.push(m[1],m[3])}else d.geojson=null}if(\"geojson\"===n.fitbounds&&\"geojson-id\"===l){var v=a.computeBbox(a.getTraceGeojson(r));f=[v[0],v[2]],h=[v[1],v[3]]}var y={padded:!0};r._extremes.lon=s(n.lonaxis._ax,f,y),r._extremes.lat=s(n.lataxis._ax,h,y)},plot:function(t,e,r){var a=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(a,r,\"trace choropleth\").each((function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)}))}}},{\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/topojson_utils\":806,\"../../plots/cartesian/autorange\":827,\"./style\":997,d3:169}],996:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],997:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each((function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)})),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../components/drawing\":665,d3:169}],998:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:s({},n.featureidkey,{}),below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:s({},n.marker.line.color,{editType:\"plot\"}),width:s({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:s({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:s({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:s({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]}),showlegend:s({},o.showlegend,{dflt:!1})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../choropleth/attributes\":989}],999:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/geojson_utils\").makeBlank,l=t(\"../../lib/geo_location_utils\");function c(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var a=o.makeSelectedPointStyleFns(r),s=0;s<t.length;s++){var l=t[s];l.fOut&&(l.fOut.properties.mo2=a.selectedOpacityFn(l))}e={type:\"identity\",property:\"mo2\"}}else e=i.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return i.extendFlat(n.fill.paint,{\"fill-opacity\":e}),i.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,o={layout:{visibility:\"none\"},paint:{}},u={layout:{visibility:\"none\"},paint:{}},f=e._opts={fill:o,line:u,geojson:s()};if(!r)return f;var h=l.extractTraceFeature(t);if(!h)return f;var p,d,g,m=a.makeColorScaleFuncFromTrace(e),v=e.marker,y=v.line||{};i.isArrayOrTypedArray(v.opacity)&&(p=function(t){var e=t.mo;return n(e)?+i.constrain(e,0,1):0}),i.isArrayOrTypedArray(y.color)&&(d=function(t){return t.mlc}),i.isArrayOrTypedArray(y.width)&&(g=function(t){return t.mlw});for(var x=0;x<t.length;x++){var b=t[x],_=b.fOut;if(_){var w=_.properties;w.fc=m(b.z),p&&(w.mo=p(b)),d&&(w.mlc=d(b)),g&&(w.mlw=g(b)),b.ct=w.ct,b._polygons=l.feature2polygons(_)}}var T=p?{type:\"identity\",property:\"mo\"}:v.opacity;return i.extendFlat(o.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":T}),i.extendFlat(u.paint,{\"line-color\":d?{type:\"identity\",property:\"mlc\"}:y.color,\"line-width\":g?{type:\"identity\",property:\"mlw\"}:y.width,\"line-opacity\":T}),o.layout.visibility=\"visible\",u.layout.visibility=\"visible\",f.geojson={type:\"FeatureCollection\",features:h},c(t),f},convertOnSelect:c}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/geojson_utils\":772,\"fast-isnumeric\":241}],1e3:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(s(\"featureidkey\"),e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":998}],1001:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\",\"showLegend\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":885,\"../choropleth/calc\":990,\"../choropleth/event_data\":992,\"../choropleth/hover\":993,\"../choropleth/select\":996,\"../heatmap/colorbar\":1068,\"./attributes\":998,\"./defaults\":1e3,\"./plot\":1002}],1002:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.type=\"choroplethmapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":883,\"./convert\":999}],1003:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=a[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1004:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],f=i[c],h=a[c],p=Math.sqrt(u*u+f*f+h*h);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1005:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var f={xaxis:0,yaxis:1,zaxis:2},h={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[f[e]];return a(t,(function(t){return n.d2l(t)*o}))}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=h[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),m=e.lightposition;return g.lightPosition=[m.x,m.y,m.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/gl3d/zip3\":881,\"gl-cone3d\":260}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1003}],1007:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1003,\"./calc\":1004,\"./convert\":1005,\"./defaults\":1006}],1008:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,f=c.INTERVAL_OPS,h=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,hoverongaps:n.hoverongaps,connectgaps:l({},n.connectgaps,{}),fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(f),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},h.color,{editType:\"style+colorbars\"}),width:{valType:\"number\",min:0,editType:\"style+colorbars\"},dash:o,smoothing:l({},h.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../constants/docs\":748,\"../../constants/filter_ops\":749,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../heatmap/attributes\":1065,\"../scatter/attributes\":1187}],1009:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var f=c.start,h=o(c),p=c.size||1,d=Math.floor((h-f)/p)+1;isFinite(p)||(p=1,d=1);var g=f-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":655,\"../heatmap/calc\":1066,\"./end_plus\":1019,\"./set_contours\":1027}],1010:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t[0],i=n.z;switch(e.type){case\"levels\":var a=Math.min(i[0][0],i[0][1]);for(r=0;r<t.length;r++){var o=t[r];o.prefixBoundary=!o.edgepaths.length&&(a>o.level||o.starts.length&&a===o.level)}break;case\"constraint\":if(n.prefixBoundary=!1,n.edgepaths.length)return;var s=n.x.length,l=n.y.length,c=-1/0,u=1/0;for(r=0;r<l;r++)u=Math.min(u,i[r][0]),u=Math.min(u,i[r][s-1]),c=Math.max(c,i[r][0]),c=Math.max(c,i[r][s-1]);for(r=1;r<s-1;r++)u=Math.min(u,i[0][r]),u=Math.min(u,i[l-1][r]),c=Math.max(c,i[0][r]),c=Math.max(c,i[l-1][r]);var f,h,p=e.value;switch(e._operation){case\">\":p>c&&(n.prefixBoundary=!0);break;case\"<\":(p<u||n.starts.length&&p===u)&&(n.prefixBoundary=!0);break;case\"[]\":f=Math.min(p[0],p[1]),((h=Math.max(p[0],p[1]))<u||f>c||n.starts.length&&h===u)&&(n.prefixBoundary=!0);break;case\"][\":f=Math.min(p[0],p[1]),h=Math.max(p[0],p[1]),f<u&&h>c&&(n.prefixBoundary=!0)}}}},{}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var f=n.extractOpts(e);r._fillgradient=f.reversescale?n.flipScale(f.colorscale):f.colorscale,r._zrange=[f.min,f.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":655,\"./end_plus\":1019,\"./make_color_map\":1024}],1012:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],1013:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,f){var h,p,d,g=e.contours,m=r(\"contours.operation\");(g._operation=c[m],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===m?h=g.showlines=!0:(h=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),h)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,f)}},{\"../../components/color\":643,\"../../constants/filter_ops\":749,\"./label_defaults\":1023,\"fast-isnumeric\":241}],1014:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":749,\"fast-isnumeric\":241}],1015:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],1016:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths),starts:n.extendDeep([],t.starts)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));for(;o.starts.length;)a.starts.push(l(o.starts.shift()));return[a]}}},{\"../../lib\":778}],1017:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./constraint_defaults\"),s=t(\"./contours_defaults\"),l=t(\"./style_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(i(t,e,f,u)){a(t,e,u,f),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"hoverongaps\");var h=\"constraint\"===f(\"contours.type\");f(\"connectgaps\",n.isArray1D(e.z)),h?o(t,e,f,u,r):(s(t,e,f,(function(r){return n.coerce2(t,e,c,r)})),l(t,e,f,u))}else e.visible=!1}},{\"../../lib\":778,\"../heatmap/xyz_defaults\":1079,\"../scatter/period_defaults\":1207,\"./attributes\":1008,\"./constraint_defaults\":1013,\"./contours_defaults\":1015,\"./style_defaults\":1029}],1018:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,f=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},h=o.start;h<c;h+=s)if(l.push(n.extendFlat({level:h,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},f)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":778,\"./constraint_mapping\":1014,\"./end_plus\":1019}],1019:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],1020:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),f=t.crossings[u],h=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),p=[s(t,e,[-h[0],-h[1]])],d=t.z.length,g=t.z[0].length,m=e.slice(),v=h.slice();for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(h[0]||h[1])<0?0:1],t.crossings[u]=i.SADDLEREMAINDER[f]):delete t.crossings[u],!(h=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}p.push(s(t,e,h)),e[0]+=h[0],e[1]+=h[1],u=e.join(\",\"),a(p[p.length-1],p[p.length-2],o,l)&&p.pop();var y=h[0]&&(e[0]<0||e[0]>g-2)||h[1]&&(e[1]<0||e[1]>d-2);if(e[0]===m[0]&&e[1]===m[1]&&h[0]===v[0]&&h[1]===v[1]||r&&y)break;f=t.crossings[u]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,T,k,M,A,S,E,C,L,I,P,z,O=a(p[0],p[p.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<p.length;c++)L=p[c],I=p[c-1],P=void 0,z=void 0,P=L[2]-I[2],z=L[3]-I[3],D+=M=Math.sqrt(P*P+z*z),F.push(M);var N=D/F.length*R;function j(t){return p[t%p.length]}for(c=p.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(O&&c===p.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];T=c-b+_+1,k=Math.floor((c+b+_+2)/2),w=O||c!==p.length-2?O||-1!==b?T%2?j(k):[(j(k)[0]+j(k+1)[0])/2,(j(k)[1]+j(k+1)[1])/2]:p[0]:p[p.length-1],p.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),O&&(c===p.length-2?p[_]=p[p.length-1]:0===c&&(p[p.length-1]=p[0]))}for(p.splice(0,B),c=0;c<p.length;c++)p[c].length=2;if(!(p.length<2))if(O)p.pop(),t.paths.push(p);else{r||n.log(\"Unclosed interior contour?\",t.level,m.join(\",\"),p.join(\"L\"));var U=!1;for(A=0;A<t.edgepaths.length;A++)if(E=t.edgepaths[A],!U&&a(E[0],p[p.length-1],o,l)){p.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],p[0],o,l)){V=!0,p.shift(),t.edgepaths.splice(A,1),S===A?t.paths.push(p.concat(C)):(S>A&&S--,t.edgepaths[S]=C.concat(p,E));break}V||(t.edgepaths[A]=p.concat(E))}for(A=0;A<t.edgepaths.length&&!U;A++)a((E=t.edgepaths[A])[E.length-1],p[0],o,l)&&(p.shift(),t.edgepaths[A]=E.concat(p),U=!0);U||t.edgepaths.push(p)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":778,\"./constants\":1012}],1021:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach((function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))})),s}},{\"../../components/color\":643,\"../heatmap/hover\":1072}],1022:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1008,\"./calc\":1009,\"./colorbar\":1011,\"./defaults\":1017,\"./hover\":1021,\"./plot\":1026,\"./style\":1028}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":778}],1024:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var f,h,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),m=new Array(d);if(\"heatmap\"===e.coloring){var v=u.min,y=u.max;for(h=0;h<d;h++)f=p[h],g[h]=f[0]*(y-v)+v,m[h]=f[1];var x=n.extent([v,y,e.start,e.start+s*(l-1)]),b=x[v<y?0:1],_=x[v<y?1:0];b!==v&&(g.splice(0,0,b),m.splice(0,0,m[0])),_!==y&&(g.push(_),m.push(m[m.length-1]))}else for(h=0;h<d;h++)f=p[h],g[h]=(f[0]*(l+c-1)-c/2)*s+r,m[h]=f[1];return i.makeColorScaleFunc({domain:g,range:m},{noNumericCheck:!0})}},{\"../../components/colorscale\":655,\"./end_plus\":1019,d3:169}],1025:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,f,h=t[0].z,p=h.length,d=h[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[h[r][e],h[r][e+1]],[h[r+1][e],h[r+1][e+1]]],f=0;f<t.length;f++)(c=i((u=t[f]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":1012}],1026:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"../../plots/cartesian/set_convert\"),u=t(\"../heatmap/plot\"),f=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),p=t(\"./empty_pathinfo\"),d=t(\"./convert_to_constraints\"),g=t(\"./close_boundaries\"),m=t(\"./constants\"),v=m.LABELOPTIMIZER;function y(t,e){var r,n,o,s,l,c,u,f=\"\",h=0,p=t.edgepaths.map((function(t,e){return e})),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function m(t){return Math.abs(t[0]-e[0][0])<.01}function v(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[h],t.smoothing),f+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(h),1),r=t.edgepaths[h][t.edgepaths[h].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",h,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!v(r)?n=e[1]:m(r)?n=e[0]:g(r)?n=e[3]:v(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;f+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}h=s,(d=-1===p.indexOf(h))&&(h=p[0],f+=\"Z\")}for(h=0;h<t.paths.length;h++)f+=a.smoothclosed(t.paths[h],t.smoothing);return f}function x(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,f=Math.sin(c)*a,h=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(f)+Math.cos(c)*o);if(h<1||p<1)return 1/0;var d=v.EDGECOST*(1/(h-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-f,y=s+u,x=l+f,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,T=Math.sin(_.theta)*_.width/2,k=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-T,_.x+w,_.y+T)/(e.height+_.height),M=_.level===e.level,A=M?v.SAMELEVELDISTANCE:1;if(k<=A)return 1/0;d+=v.NEIGHBORCOST*(M?v.SAMELEVELFACTOR:1)/(k-A)}return d}function b(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)i[(r=n[e])[0]][r[1]]=0;return t.zmask=i,i}r.plot=function(t,e,o,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each((function(o){var s=n.select(this),v=o[0],x=v.trace,_=v.x,w=v.y,T=x.contours,k=p(T,e,v),M=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===T.coloring&&(A=[o]),u(t,e,A,M),f(k),h(k);var S=l.c2p(_[0],!0),E=l.c2p(_[_.length-1],!0),C=c.c2p(w[0],!0),L=c.c2p(w[w.length-1],!0),I=[[S,L],[E,L],[E,C],[S,C]],P=k;\"constraint\"===T.type&&(P=d(k,T._operation)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,I,T),function(t,e,r,a){var o=\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation,s=\"M\"+r.join(\"L\")+\"Z\";o&&g(e,a);var l=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(o?e:[]);l.enter().append(\"path\"),l.exit().remove(),l.each((function(t){var e=(t.prefixBoundary?s:\"\")+y(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(s,P,I,T),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,f=l.showlabels,h=u&&f,p=r.createLines(c,u||f,e),d=r.createLineClip(c,h,o,s.trace.uid),g=t.selectAll(\"g.contourlabels\").data(f?[0]:[]);if(g.exit().remove(),g.enter().append(\"g\").classed(\"contourlabels\",!0),f){var v=[],y=[];i.clearLocationCache();var x=r.labelFormatter(o,s),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,T=_._length,k=w._length,M=_.range,A=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),I=Math.max(_.c2p(S,!0),0),P=Math.min(_.c2p(E,!0),T),z=Math.max(w.c2p(L,!0),0),O=Math.min(w.c2p(C,!0),k),D={};M[0]<M[1]?(D.left=I,D.right=P):(D.left=P,D.right=I),A[0]<A[1]?(D.top=z,D.bottom=O):(D.top=O,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,v.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(T*T+k*k),F=m.LABELDISTANCE*R/Math.max(1,e.length/m.LABELINCREASE);p.each((function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each((function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*m.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),m.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,v)}}))})),b.remove(),r.drawLabels(g,y,o,d,h?v:null)}f&&!u&&p.remove()}(s,k,t,v,T),function(t,e,r,n,o){var s=n.trace,l=r._fullLayout._clips,c=\"clip\"+s.uid,u=l.selectAll(\"#\"+c).data(s.connectgaps?[]:[0]);if(u.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",c),u.exit().remove(),!1===s.connectgaps){var p={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:b(n),smoothing:0};f([p]),h([p]),g([p],{type:\"levels\"}),i.ensureSingle(u,\"path\",\"\").attr(\"d\",(p.prefixBoundary?\"M\"+o.join(\"L\")+\"Z\":\"\")+y(p,o))}else c=null;a.setClipUrl(t,c,r)}(s,e,t,v,I)}))},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data((function(t){return t.pedgepaths||t.edgepaths}));o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",(function(t){return a.smoothopen(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data((function(t){return t.ppaths||t.paths}));s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",(function(t){return a.smoothclosed(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e){var r=t._fullLayout,n=e.trace,i=n.contours,a={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"};if(i.labelformat)a.tickformat=i.labelformat,c(a,r);else{var s=o.extractOpts(n);if(s&&s.colorbar&&s.colorbar._axis)a=s.colorbar._axis;else{if(\"constraint\"===i.type){var u=i.value;Array.isArray(u)?a.range=[u[0],u[u.length-1]]:a.range=[u,u]}else a.range=[i.start,i.end],a.nticks=(i.end-i.start)/i.size;a.range[0]===a.range[1]&&(a.range[1]+=a.range[0]||1),a.nticks||(a.nticks=1e3),c(a,r),l.prepTicks(a),a._tmin=null,a._tmax=null}}return function(t){return l.tickText(a,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(s.convertToTspans,n);var o=r.node(),l=a.bBox(o,!0);return{text:i,width:l.width,height:l.height,fontSize:+o.style[\"font-size\"].replace(\"px\",\"\"),level:t,dy:(l.top+l.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,f=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-f)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+f/2,l=e.max-(s+f)/2);for(var h=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,f),m=x(g,r,n,a);m<h&&(h=m,u=g,c=d)}if(h>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(h<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.fontSize,a=e.width+i/3,o=Math.max(0,e.height-i/3),s=t.x,l=t.y,c=t.theta,u=Math.sin(c),f=Math.cos(c),h=function(t,e){return[s+t*f-e*u,l+t*u+e*f]},p=[h(-a/2,-o/2),h(-a/2,o/2),h(a/2,o/2),h(a/2,-o/2)];r.push({text:e.text,x:s,y:l,dy:e.dy,theta:c,level:e.level,width:a,height:o}),n.push(p)},r.drawLabels=function(t,e,r,a,o){var l=t.selectAll(\"text\").data(e,(function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta}));if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each((function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(s.convertToTspans,r)})),o){for(var c=\"\",u=0;u<o.length;u++)c+=\"M\"+o[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/set_convert\":848,\"../heatmap/plot\":1076,\"./close_boundaries\":1010,\"./constants\":1012,\"./convert_to_constraints\":1016,\"./empty_pathinfo\":1018,\"./find_all_paths\":1020,\"./make_crossings\":1025,d3:169}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,f=r.end,h=t._input.contours;if(u>f&&(r.start=h.start=f,f=r.end=h.end=u,u=r.start),!(r.size>0))c=u===f?1:a(u,f,t.ncontours).dtick,h.size=r.size=c}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1028:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,f=!u&&\"lines\"===a.coloring,h=!u&&\"fill\"===a.coloring,p=f||h?o(r):null;e.selectAll(\"g.contourlevel\").each((function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,f?p(t.level):s.color,s.dash)}));var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each((function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(f?p(t.level):s.color)})})),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(h){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",(function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)})),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}})),a(t)}},{\"../../components/drawing\":665,\"../heatmap/style\":1077,\"./make_color_map\":1024,d3:169}],1029:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":653,\"./label_defaults\":1023}],1030:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=i.contours;e.exports=o({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:s.type,start:s.start,end:s.end,size:s.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:s.showlines,showlabels:s.showlabels,labelfont:s.labelfont,labelformat:s.labelformat,operation:s.operation,value:s.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:i.line.color,width:i.line.width,dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../contour/attributes\":1008,\"../heatmap/attributes\":1065}],1031:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),f=t(\"../carpet/lookup_carpetid\"),h=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=f(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,f,h,p,d,g,m=e._carpetTrace,v=m.aaxis,y=m.baxis;v._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,v,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,h=e._b=e._b||e.b,r=r?v.makeCalcdata(e,\"_a\"):[],h=h?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,f=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,f,x,v),w=\"scaled\"===e.ytype?\"\":h,T=c(e,w,p,d,g.length,y),k={a:_,b:T,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[k]}(t,e);return h(e,e._z),g}}},{\"../../components/colorscale/calc\":651,\"../../lib\":778,\"../carpet/lookup_carpetid\":981,\"../contour/set_contours\":1027,\"../heatmap/clean_2d_array\":1067,\"../heatmap/convert_column_xyz\":1069,\"../heatmap/find_empties\":1071,\"../heatmap/interp2d\":1074,\"../heatmap/make_bound_array\":1075,\"./defaults\":1032}],1032:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,(function(r){return n.coerce2(t,e,a,r)})),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":778,\"../contour/constraint_defaults\":1013,\"../contour/contours_defaults\":1015,\"../contour/style_defaults\":1029,\"../heatmap/xyz_defaults\":1079,\"./attributes\":1030}],1033:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":841,\"../contour/colorbar\":1011,\"../contour/style\":1028,\"./attributes\":1030,\"./calc\":1031,\"./defaults\":1032,\"./plot\":1034}],1034:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),f=t(\"../contour/constants\"),h=t(\"../contour/convert_to_constraints\"),p=t(\"../contour/empty_pathinfo\"),d=t(\"../contour/close_boundaries\"),g=t(\"../carpet/lookup_carpetid\"),m=t(\"../carpet/axis_aligned_line\");function v(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function y(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function x(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,b){var _=e.xaxis,w=e.yaxis;s.makeTraceGroups(b,r,\"contour\").each((function(r){var b=n.select(this),T=r[0],k=T.trace,M=k._carpetTrace=g(t,k),A=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var S=T.a,E=T.b,C=k.contours,L=p(C,e,T),I=\"constraint\"===C.type,P=C._operation,z=I?\"=\"===P?\"lines\":\"fill\":C.coloring,O=[[S[0],E[E.length-1]],[S[S.length-1],E[E.length-1]],[S[S.length-1],E[0]],[S[0],E[0]]];l(L);var D=1e-8*(S[S.length-1]-S[0]),R=1e-8*(E[E.length-1]-E[0]);c(L,D,R);var F,B,N,j,U=L;\"constraint\"===C.type&&(U=h(L,P)),function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(a=t[r],o=a.pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}(L,H);var V=[];for(j=A.clipsegments.length-1;j>=0;j--)F=A.clipsegments[j],B=i([],F.x,_.c2p),N=i([],F.y,w.c2p),B.reverse(),N.reverse(),V.push(a(B,N,F.bicubic));var q=\"M\"+V.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,f,h,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(h=0;h<e.length;h++)c=e[h],u=i([],c.x,r.c2p),f=i([],c.y,n.c2p),d.push(a(u,f,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(b,A.clipsegments,_,w,I,z),function(t,e,r,i,a,l,c,u,f,h,p){var g=\"fill\"===h;g&&d(a,t.contours);var v=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(g?a:[]);v.enter().append(\"path\"),v.exit().remove(),v.each((function(t){var e=(t.prefixBoundary?p:\"\")+function(t,e,r,n,i,a,l,c){var u,f,h,p,d,g,v,y=\"\",x=e.edgepaths.map((function(t,e){return e})),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function T(t){return Math.abs(t[1]-r[0][1])<w}function k(t){return Math.abs(t[1]-r[2][1])<w}function M(t){return Math.abs(t[0]-r[0][0])<_}function A(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,o,s,u=\"\";for(T(t)&&!A(t)||k(t)&&!M(t)?(s=i.aaxis,o=m(i,a,[t[0],e[0]],.5*(t[1]+e[1]))):(s=i.baxis,o=m(i,a,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<o.length;r++)for(u+=s.smoothing?\"C\":\"L\",n=0;n<o[r].length;n++){var f=o[r][n];u+=[l.c2p(f[0]),c.c2p(f[1])]+\" \"}return u}u=0,f=null;for(;x.length;){var E=e.edgepaths[u][0];for(f&&(y+=S(f,E)),v=o.smoothopen(e.edgepaths[u].map(n),e.smoothing),y+=b?v:v.replace(/^M/,\"L\"),x.splice(x.indexOf(u),1),f=e.edgepaths[u][e.edgepaths[u].length-1],d=-1,p=0;p<4;p++){if(!f){s.log(\"Missing end?\",u,e);break}for(T(f)&&!A(f)?h=r[1]:M(f)?h=r[0]:k(f)?h=r[3]:A(f)&&(h=r[2]),g=0;g<e.edgepaths.length;g++){var C=e.edgepaths[g][0];Math.abs(f[0]-h[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(h[1]-C[1])>=0&&(h=C,d=g):Math.abs(f[1]-h[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(h[0]-C[0])>=0&&(h=C,d=g):s.log(\"endpt to newendpt is not vert. or horz.\",f,h,C)}if(d>=0)break;y+=S(f,h),f=h}if(d===e.edgepaths.length){s.log(\"unclosed perimeter path\");break}u=d,(b=-1===x.indexOf(u))&&(u=x[0],y+=S(f,h)+\"Z\",f=null)}for(u=0;u<e.paths.length;u++)y+=o.smoothclosed(e.paths[u].map(n),e.smoothing);return y}(0,t,l,c,u,f,r,i);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(k,b,_,w,U,O,H,M,A,z,q),function(t,e,r,i,a,l,c){var h=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,m=u.createLines(h,p||d,e),b=u.createLineClip(h,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,T=l.yaxis,k=w._length,M=T._length,A=[[[0,0],[k,0],[k,M],[0,M]]],S=[];s.clearLocationCache();var E=u.labelFormatter(r,i),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:k,center:k/2,top:0,bottom:M,middle:M/2},I=Math.sqrt(k*k+M*M),P=f.LABELDISTANCE*I/Math.max(1,e.length/f.LABELINCREASE);m.each((function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each((function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],f=i.b[i.b.length-1];function h(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=y(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-f)<.1)&&(r=y(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),n}var p=v(t,0,1),d=v(t,n.total,n.total-1),g=h(o[0],p),m=n.total-h(o[o.length-1],d);n.min<g&&(n.min=g);n.max>m&&(n.max=m);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*f.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/P),f.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,A)}}))})),C.remove(),u.drawLabels(_,S,r,b,g?A:null)}d&&!p&&m.remove()}(b,L,t,T,C,e,M),o.setClipUrl(b,M._clipPathId,t)}function H(t){var e=M.ab2xy(t[0],t[1],!0);return[_.c2p(e[0]),w.c2p(e[1])]}}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../carpet/axis_aligned_line\":965,\"../carpet/lookup_carpetid\":981,\"../carpet/makepath\":982,\"../carpet/map_1d_array\":983,\"../contour/close_boundaries\":1010,\"../contour/constants\":1012,\"../contour/convert_to_constraints\":1016,\"../contour/empty_pathinfo\":1018,\"../contour/find_all_paths\":1020,\"../contour/make_crossings\":1025,\"../contour/plot\":1026,d3:169}],1035:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i(),showlegend:s({},a.showlegend,{dflt:!1})},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scattermapbox/attributes\":1252}],1036:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,f=0;f<r;f++){var h=l[f]={},p=e.lon[f],d=e.lat[f];if(h.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[f];h.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],1037:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,f=[],h=e.z,p=e.radius,d=i.isArrayOrTypedArray(h)&&h.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var m=t[u],v=m.lonlat;if(v[0]!==s){var y={};if(d){var x=m.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),f.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:v},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],T=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)T.push(_[u][0],_[u][1]);var k=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?k:1/(b.max-b.min),\"heatmap-color\":T,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:f},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geojson_utils\":772,\"fast-isnumeric\":241}],1038:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1035}],1039:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],1040:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var f=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(f,f.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../scattermapbox/hover\":1257}],1041:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),formatLabels:t(\"../scattermapbox/format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"showLegend\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":885,\"../heatmap/colorbar\":1068,\"../scattermapbox/format_labels\":1256,\"./attributes\":1035,\"./calc\":1036,\"./defaults\":1038,\"./event_data\":1039,\"./hover\":1040,\"./plot\":1042}],1042:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.type=\"densitymapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":883,\"./convert\":1037}],1043:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":778}],1044:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\",\"value\"])}),text:n.text,textposition:c({},n.textposition,{dflt:\"auto\"}),insidetextanchor:c({},n.insidetextanchor,{dflt:\"middle\"}),textangle:c({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:c({},n.orientation,{}),offset:c({},n.offset,{arrayOk:!1}),width:c({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:c({},i.color,{dflt:u.defaultLine}),width:c({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":643,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187,\"./constants\":1046}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"./arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return t===s?0:t}e.exports=function(t,e){var r,c,u,f,h,p,d=n.getFromId(t,e.xaxis||\"x\"),g=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=d.makeCalcdata(e,\"x\"),u=g.makeCalcdata(e,\"y\"),c=i(e,g,\"y\",u),p=!!e.yperiodalignment):(r=g.makeCalcdata(e,\"y\"),u=d.makeCalcdata(e,\"x\"),c=i(e,d,\"x\",u),p=!!e.xperiodalignment);var m,v=Math.min(c.length,r.length),y=new Array(v);for(e._base=[],f=0;f<v;f++){r[f]<0&&(r[f]=s);var x=!1;r[f]!==s&&f+1<v&&r[f+1]!==s&&(x=!0),h=y[f]={p:c[f],s:r[f],cNext:x},e._base[f]=-.5*h.s,p&&(y[f].orig_p=u[f]),e.ids&&(h.id=String(e.ids[f])),0===f&&(y[0].vTotal=0),y[0].vTotal+=l(h.s),h.begR=l(h.s)/l(y[0].s)}for(f=0;f<v;f++)(h=y[f]).s!==s&&(h.sumR=h.s/y[0].vTotal,h.difR=void 0!==m?h.s/m:1,m=h.s);return a(y,e),o(y,e),y}},{\"../../constants/numerical\":753,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189,\"./arrays_to_calcdata\":1043}],1046:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],1047:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?h.push(r):f.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,f,g),n(t,c,l,h,g),i=0;i<u.length;i++){r=u[i];for(var m=0;m<r.length;m++)m+1<r.length&&(r[m].nextP0=r[m+1].p0,r[m].nextS0=r[m+1].s0,r[m].nextP1=r[m+1].p1,r[m].nextS1=r[m+1].s1)}}},{\"../bar/cross_trace_calc\":924}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function u(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,u)){s(t,e,i,u),u(\"orientation\",e.y&&!e.x?\"v\":\"h\"),u(\"offset\"),u(\"width\");var f=u(\"text\");u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");a(t,e,i,u,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"===e.textposition||e.texttemplate||u(\"textinfo\",Array.isArray(f)?\"text+value\":\"value\");var p=u(\"marker.color\",r);if(u(\"marker.line.color\",c.defaultLine),u(\"marker.line.width\"),u(\"connector.visible\"))u(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return c.addOpacity(e,.5*c.opacity(e))}(p)),u(\"connector.line.width\")&&(u(\"connector.line.color\"),u(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.funnelmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":1044}],1049:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1050:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,f=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=f.s,s.percentInitial=f.begR,s.percentInitialLabel=a(f.begR,1),s.percentPrevious=f.difR,s.percentPreviousLabel=a(f.difR,1),s.percentTotal=f.sumR,s.percentTotalLabel=a(f.sumR,1);var h=f.hi||c.hoverinfo,p=[];if(h&&\"none\"!==h&&\"skip\"!==h){var d=\"all\"===h,g=h.split(\"+\"),m=function(t){return d||-1!==g.indexOf(t)};m(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),m(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),m(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,f),[s]}}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/hover\":928}],1051:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/select\":933,\"./attributes\":1044,\"./calc\":1045,\"./cross_trace_calc\":1047,\"./defaults\":1048,\"./event_data\":1049,\"./hover\":1050,\"./layout_attributes\":1052,\"./layout_defaults\":1053,\"./plot\":1054,\"./style\":1055}],1052:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":778,\"./layout_attributes\":1052}],1054:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;function c(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,u){var f=t._fullLayout;l(\"funnel\",f),function(t,e,r,s){var l=e.xaxis,u=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),f=r[0].trace,h=i.ensureSingle(s,\"g\",\"regions\");if(f.connector&&f.connector.visible){var p=\"h\"===f.orientation,d=h.selectAll(\"g.region\").data(i.identity);d.enter().append(\"g\").classed(\"region\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var f=c(r,l,u,p),h=f[0],d=f[1],m=\"\";h[0]!==o&&d[0]!==o&&h[1]!==o&&d[1]!==o&&h[2]!==o&&d[2]!==o&&h[3]!==o&&d[3]!==o&&(m+=p?\"M\"+h[0]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+d[1]+\"Z\":\"M\"+h[1]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[3]+\"V\"+d[2]+\"L\"+h[1]+\",\"+d[0]+\"Z\"),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else h.remove()}))}(t,e,r,u),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each((function(r){var o=n.select(this),u=r[0].trace,f=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var h=\"h\"===u.orientation,p=f.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each((function(r,o){if(o===d-1||r.cNext){var u=c(r,s,l,h),f=u[0],p=u[1],g=\"\";void 0!==f[3]&&void 0!==p[3]&&(h?(g+=\"M\"+f[0]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[2],g+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[3]+\",\"+p[2]):(g+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[3],g+=\"M\"+f[1]+\",\"+p[0]+\"L\"+f[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,u),s.plot(t,e,r,u,{mode:f.funnelmode,norm:f.funnelmode,gap:f.funnelgap,groupgap:f.funnelgroupgap})}},{\"../../components/drawing\":665,\"../../constants/numerical\":753,\"../../lib\":778,\"../bar/plot\":932,\"../bar/uniform_text\":937,d3:169}],1055:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l(t,s,\"funnel\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".regions\").each((function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,s.connector.fillcolor)})),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/interactions\":752,\"../bar/style\":935,\"../bar/uniform_text\":937,d3:169}],1056:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:l({},n.marker.line.color,{dflt:null}),width:l({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:l({},n.scalegroup,{}),textinfo:l({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),texttemplate:s({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),hoverinfo:l({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),textposition:l({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:l({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161}],1057:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"funnelarea\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1058:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1163}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../pie/defaults\").handleLabelsAndValues;e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,i,r,a)}var u=c(\"labels\"),f=c(\"values\"),h=s(u,f),p=h.len;if(e._hasLabels=h.hasLabels,e._hasValues=h.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),p){e._length=p,c(\"marker.line.width\")&&c(\"marker.line.color\",l.paper_bgcolor),c(\"marker.colors\"),c(\"scalegroup\");var d,g=c(\"text\"),m=c(\"texttemplate\");if(m||(d=c(\"textinfo\",Array.isArray(g)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),m||d&&\"none\"!==d){var v=c(\"textposition\");o(t,e,l,c,v,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,l,c),c(\"title.text\")&&(c(\"title.position\"),n.coerceFont(c,\"title.font\",l.font)),c(\"aspectratio\"),c(\"baseratio\")}else e.visible=!1}},{\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"../pie/defaults\":1164,\"./attributes\":1056}],1060:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1172,\"./attributes\":1056,\"./base_plot\":1057,\"./calc\":1058,\"./defaults\":1059,\"./layout_attributes\":1061,\"./layout_defaults\":1062,\"./plot\":1063,\"./style\":1064}],1061:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1168}],1062:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":778,\"./layout_attributes\":1061}],1063:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=a.strScale,s=a.strTranslate,l=t(\"../../lib/svg_text_utils\"),c=t(\"../bar/plot\").toMoveInsideBar,u=t(\"../bar/uniform_text\"),f=u.recordMinTextSize,h=u.clearMinTextSize,p=t(\"../pie/helpers\"),d=t(\"../pie/plot\"),g=d.attachFxHandlers,m=d.determineInsideTextFont,v=d.layoutAreas,y=d.prerenderTitles,x=d.positionTitleOutside,b=d.formatSliceLabel;function _(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;h(\"funnelarea\",r),y(e,t),v(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each((function(e){var u=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var f,h,p=[];for(p.push(u()),f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var d=h.v/l;c+=d,p.push(u())}var g=1/0,m=-1/0;for(f=0;f<p.length;f++)a=p[f],g=Math.min(g,a[1]),m=Math.max(m,a[1]);for(f=0;f<p.length;f++)p[f][1]-=(m+g)/2;var v=p[p.length-1][0],y=e.r,x=(m-g)/2,b=y/v,_=y/x*n;for(e.r=_*x,f=0;f<p.length;f++)p[f][0]*=b,p[f][1]*=_;var w=[-(a=p[0])[0],a[1]],T=[a[0],a[1]],k=0;for(f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var M=p[k+=1][0],A=p[k][1];h.TL=[-M,A],h.TR=[M,A],h.BL=w,h.BR=T,h.pxmid=(S=h.TR,E=h.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=h.TL,T=h.TR}var S,E}(e),u.each((function(){var u=n.select(this).selectAll(\"g.slice\").data(e);u.enter().append(\"g\").classed(\"slice\",!0),u.exit().remove(),u.each((function(o,s){if(o.hidden)n.select(this).selectAll(\"path,g\").remove();else{o.pointNumber=o.i,o.curveNumber=d.index;var u=h.cx,v=h.cy,y=n.select(this),x=y.selectAll(\"path.surface\").data([o]);x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),y.call(g,t,e);var w=\"M\"+(u+o.TR[0])+\",\"+(v+o.TR[1])+_(o.TR,o.BR)+_(o.BR,o.BL)+_(o.BL,o.TL)+\"Z\";x.attr(\"d\",w),b(t,o,h);var T=p.castOption(d.textposition,o.pts),k=y.selectAll(\"g.slicetext\").data(o.text&&\"none\"!==T?[0]:[]);k.enter().append(\"g\").classed(\"slicetext\",!0),k.exit().remove(),k.each((function(){var h=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),p=a.ensureUniformFontSize(t,m(d,o,r.font));h.text(o.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p).call(l.convertToTspans,t);var g,y,x,b=i.bBox(h.node()),_=Math.min(o.BL[1],o.BR[1])+v,w=Math.max(o.TL[1],o.TR[1])+v;y=Math.max(o.TL[0],o.BL[0])+u,x=Math.min(o.TR[0],o.BR[0])+u,(g=c(y,x,_,w,b,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})).fontSize=p.size,f(d.type,g,r),e[s].transform=g,h.attr(\"transform\",a.getTextTransform(g))}))}}));var v=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);v.enter().append(\"g\").classed(\"titletext\",!0),v.exit().remove(),v.each((function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),c=d.title.text;d._meta&&(c=a.templateString(c,d._meta)),e.text(c).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(l.convertToTspans,t);var u=x(h,r._size);e.attr(\"transform\",s(u.x,u.y)+o(Math.min(1,u.scale))+s(u.tx,u.ty))}))}))}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../bar/plot\":932,\"../bar/uniform_text\":937,\"../pie/helpers\":1166,\"../pie/plot\":1170,d3:169}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._funnelarealayer.selectAll(\".trace\");a(t,e,\"funnelarea\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":937,\"../pie/style_one\":1172,d3:169}],1065:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=s({z:{valType:\"data_array\",editType:\"calc\"},x:s({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:s({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:s({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:s({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:s({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:s({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),xperiod:s({},n.xperiod,{impliedEdits:{xtype:\"scaled\"}}),yperiod:s({},n.yperiod,{impliedEdits:{ytype:\"scaled\"}}),xperiod0:s({},n.xperiod0,{impliedEdits:{xtype:\"scaled\"}}),yperiod0:s({},n.yperiod0,{impliedEdits:{ytype:\"scaled\"}}),xperiodalignment:s({},n.xperiodalignment,{impliedEdits:{xtype:\"scaled\"}}),yperiodalignment:s({},n.yperiodalignment,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},hoverongaps:{valType:\"boolean\",dflt:!0,editType:\"none\"},connectgaps:{valType:\"boolean\",editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:a(),showlegend:s({},i.showlegend,{dflt:!1})},{transforms:void 0},o(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1066:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../histogram2d/calc\"),l=t(\"../../components/colorscale/calc\"),c=t(\"./convert_column_xyz\"),u=t(\"./clean_2d_array\"),f=t(\"./interp2d\"),h=t(\"./find_empties\"),p=t(\"./make_bound_array\"),d=t(\"../../constants/numerical\").BADNUM;function g(t){for(var e=[],r=t.length,n=0;n<r;n++){var i=t[n];i!==d&&e.push(i)}return e}e.exports=function(t,e){var r,m,v,y,x,b,_,w,T,k,M,A=a.getFromId(t,e.xaxis||\"x\"),S=a.getFromId(t,e.yaxis||\"y\"),E=n.traceIs(e,\"contour\"),C=n.traceIs(e,\"histogram\"),L=n.traceIs(e,\"gl2d\"),I=E?\"best\":e.zsmooth;if(A._minDtick=0,S._minDtick=0,C)y=(M=s(t,e)).orig_x,r=M.x,m=M.x0,v=M.dx,w=M.orig_y,x=M.y,b=M.y0,_=M.dy,T=M.z;else{var P=e.z;i.isArray1D(P)?(c(e,A,S,\"x\",\"y\",[\"z\"]),r=e._x,x=e._y,P=e._z):(y=e.x?A.makeCalcdata(e,\"x\"):[],w=e.y?S.makeCalcdata(e,\"y\"):[],r=o(e,A,\"x\",y),x=o(e,S,\"y\",w),e._x=r,e._y=x),m=e.x0,v=e.dx,b=e.y0,_=e.dy,T=u(P,e,A,S)}function z(t){I=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if((A.rangebreaks||S.rangebreaks)&&(T=function(t,e,r){for(var n=[],i=-1,a=0;a<r.length;a++)if(e[a]!==d){i++,n[i]=[];for(var o=0;o<r[a].length;o++)t[o]!==d&&n[i].push(r[a][o])}return n}(r,x,T),C||(r=g(r),x=g(x),e._x=r,e._y=x)),C||!E&&!e.connectgaps||(e._emptypoints=h(T),f(T,e._emptypoints)),\"fast\"===I)if(\"log\"===A.type||\"log\"===S.type)z(\"log axis found\");else if(!C){if(r.length){var O=(r[r.length-1]-r[0])/(r.length-1),D=Math.abs(O/100);for(k=0;k<r.length-1;k++)if(Math.abs(r[k+1]-r[k]-O)>D){z(\"x scale is not linear\");break}}if(x.length&&\"fast\"===I){var R=(x[x.length-1]-x[0])/(x.length-1),F=Math.abs(R/100);for(k=0;k<x.length-1;k++)if(Math.abs(x[k+1]-x[k]-R)>F){z(\"y scale is not linear\");break}}}var B=i.maxRowLength(T),N=\"scaled\"===e.xtype?\"\":r,j=p(e,N,m,v,B,A),U=\"scaled\"===e.ytype?\"\":x,V=p(e,U,b,_,T.length,S);L||(e._extremes[A._id]=a.findExtremes(A,j),e._extremes[S._id]=a.findExtremes(S,V));var q={x:j,y:V,z:T,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(e.xperiodalignment&&y&&(q.orig_x=y),e.yperiodalignment&&w&&(q.orig_y=w),N&&N.length===j.length-1&&(q.xCenter=N),U&&U.length===V.length-1&&(q.yCenter=U),C&&(q.xRanges=M.xRanges,q.yRanges=M.yRanges,q.pts=M.pts),E||l(t,e,{vals:T,cLetter:\"z\"}),E&&e.contours&&\"heatmap\"===e.contours.coloring){var H={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};q.xfill=p(H,N,m,v,B,A),q.yfill=p(H,U,b,_,T.length,S)}return[q]}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../histogram2d/calc\":1098,\"./clean_2d_array\":1067,\"./convert_column_xyz\":1069,\"./find_empties\":1071,\"./interp2d\":1074,\"./make_bound_array\":1075}],1067:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,f,h;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,f=0;f<t.length;f++)s=Math.max(s,t[f].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(f=0;f<o.length;f++)n[o[f]]=f;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var m=g(r),v=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(f=0;f<s;f++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,f),y[f]=new Array(l),h=0;h<l;h++)y[f][h]=p(d(t,v(f),m(h)));return y}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],1068:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/align_period\");e.exports=function(t,e,r,o,s,l){var c=t._length,u=e.makeCalcdata(t,o),f=r.makeCalcdata(t,s);u=a(t,e,o,u),f=a(t,r,s,f);var h,p,d,g,m=t.text,v=void 0!==m&&n.isArray1D(m),y=t.hovertext,x=void 0!==y&&n.isArray1D(y),b=n.distinctVals(u),_=b.vals,w=n.distinctVals(f),T=w.vals,k=[],M=T.length,A=_.length;for(h=0;h<l.length;h++)k[h]=n.init2dArray(M,A);v&&(d=n.init2dArray(M,A)),x&&(g=n.init2dArray(M,A));var S=n.init2dArray(M,A);for(h=0;h<c;h++)if(u[h]!==i&&f[h]!==i){var E=n.findBin(u[h]+b.minDiff/2,_),C=n.findBin(f[h]+w.minDiff/2,T);for(p=0;p<l.length;p++){var L=t[l[p]];k[p][C][E]=L[h],S[C][E]=h}v&&(d[C][E]=m[h]),x&&(g[C][E]=y[h])}for(t[\"_\"+o]=_,t[\"_\"+s]=T,p=0;p<l.length;p++)t[\"_\"+l[p]]=k[p];v&&(t._text=d),x&&(t._hovertext=g),e&&\"category\"===e.type&&(t[\"_\"+o+\"CategoryMap\"]=_.map((function(t){return e._categories[t]}))),r&&\"category\"===r.type&&(t[\"_\"+s+\"CategoryMap\"]=T.map((function(t){return r._categories[t]}))),t._after2before=S}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./style_defaults\"),s=t(\"../../components/colorscale/defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}i(t,e,u,c)?(a(t,e,c,u),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\"),o(t,e,u,c),u(\"hoverongaps\"),u(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),s(t,e,c,u,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../scatter/period_defaults\":1207,\"./attributes\":1065,\"./style_defaults\":1078,\"./xyz_defaults\":1079}],1071:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],f={},h=[],p=t[0],d=[],g=[0,0,0],m=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<m;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(f[[r,i]]=[r,i,s]),u.push([r,i,s])):h.push([r,i]));for(;h.length;){for(l={},c=!1,o=h.length-1;o>=0;o--)(s=((f[[(r=(a=h[o])[0])-1,i=a[1]]]||g)[2]+(f[[r+1,i]]||g)[2]+(f[[r,i-1]]||g)[2]+(f[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],h.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)f[a]=l[a],u.push(l[a])}return u.sort((function(t,e){return e[2]-t[2]}))}},{\"../../lib\":778}],1072:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,f,h,p,d=t.cd[0],g=d.trace,m=t.xa,v=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,T=d.zmask,k=g.zhoverformat,M=y,A=x;if(!1!==t.index){try{h=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(h<0||h>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(M=[2*y[0]-y[1]],S=1;S<y.length;S++)M.push((y[S]+y[S-1])/2);for(M.push([2*y[y.length-1]-y[y.length-2]]),A=[2*x[0]-x[1]],S=1;S<x.length;S++)A.push((x[S]+x[S-1])/2);A.push([2*x[x.length-1]-x[x.length-2]])}h=Math.max(0,Math.min(M.length-2,i.findBin(e,M))),p=Math.max(0,Math.min(A.length-2,i.findBin(r,A)))}var E,C,L=m.c2p(y[h]),I=m.c2p(y[h+1]),P=v.c2p(x[p]),z=v.c2p(x[p+1]);c?(E=d.orig_x||y,C=d.orig_y||x,I=L,u=E[h],z=P,f=C[p]):(E=d.orig_x||_||y,C=d.orig_y||w||x,u=_?E[h]:(E[h]+E[h+1])/2,f=w?C[p]:(C[p]+C[p+1])/2,m&&\"category\"===m.type&&(u=y[h]),v&&\"category\"===v.type&&(f=x[p]),g.zsmooth&&(L=I=m.c2p(u),P=z=v.c2p(f)));var O=b[p][h];if(T&&!T[p][h]&&(O=void 0),void 0!==O||g.hoverongaps){var D;Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?D=d.hovertext[p][h]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(D=d.text[p][h]);var R=o(g),F={type:\"linear\",range:[R.min,R.max],hoverformat:k,_separators:m._separators,_numFormat:m._numFormat},B=a.tickText(F,O,\"hover\").text;return[i.extendFlat(t,{index:g._after2before?g._after2before[p][h]:[p,h],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:L,x1:I,y0:P,y1:z,xLabelVal:u,yLabelVal:f,zLabelVal:O,zLabel:B,text:D})]}}},{\"../../components/colorscale\":655,\"../../components/fx\":683,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1073:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1065,\"./calc\":1066,\"./colorbar\":1068,\"./defaults\":1070,\"./hover\":1072,\"./plot\":1076,\"./style\":1077}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,f,h,p,d,g,m,v=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,h=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(f=u[o+c[1]])&&(0===p?g=m=f:(g=Math.min(g,f),m=Math.max(m,f)),h++,p+=f);if(0===h)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/h,void 0===d?h<4&&(v=1):(t[a][o]=(1+r)*t[a][o]-r*d,m>g&&(v=Math.max(v,Math.abs(t[a][o]-d)/(m-g))))}return v}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":778}],1075:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,f=[],h=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return h?e.slice(0,o):e.slice(0,o+1);if(h||d)f=e.slice(0,o);else if(1===o)f=[e[0]-.5,e[0]+.5];else{for(f=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)f.push(.5*(e[u-1]+e[u]));f.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var m=f[f.length-1],v=m-f[f.length-2];for(u=g;u<o;u++)m+=v,f.push(m)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=h||d?0:-.5;u<o;u++)f.push(l+c*u)}return f}},{\"../../lib\":778,\"../../registry\":911}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function f(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,h){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(h,r,\"hm\").each((function(e){var r,h,g,m,v,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,T=b.x,k=b.y,M=b.xCenter,A=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),I=!1,P=!1;for(y=0;void 0===r&&y<T.length-1;)r=p.c2p(T[y]),y++;for(y=T.length-1;void 0===h&&y>0;)h=p.c2p(T[y]),y--;for(h<r&&(g=h,h=r,r=g,I=!0),y=0;void 0===m&&y<k.length-1;)m=d.c2p(k[y]),y++;for(y=k.length-1;void 0===v&&y>0;)v=d.c2p(k[y]),y--;if(v<m&&(g=m,m=v,v=g,P=!0),S&&(M=T,A=k,T=b.xfill,k=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),h=Math.min((1+z)*p._length,h),m=Math.max(-z*d._length,m),v=Math.min((1+z)*d._length,v)}var O=Math.round(h-r),D=Math.round(v-m);if(O<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=O,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=I?function(t){return L-1-t}:o.identity,j=P?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(T[t])-r),0,O)},j=function(t){return o.constrain(Math.round(d.c2p(k[t])-m),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=I?0:1,K=P?0:1,Q=0,$=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(O*D*4)}catch(t){rt=new Array(O*D*4)}if(\"best\"===E){var it,at,ot,st=M||T,lt=A||k,ct=new Array(st.length),ut=new Array(lt.length),ft=new Array(O),ht=M?u:c,pt=A?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-m);for(y=0;y<O;y++)ft[y]=ht(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<O;y++,nt+=4)f(rt,nt,W=kt(at,ot,ft[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<O;y++)W=Tt(Y[y],1),f(rt,nt=4*(Z*O+N(y)),W);var dt=U.createImageData(O,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,mt=gt.length;for(H=0;H<mt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var vt=_.xgap,yt=_.ygap,xt=Math.floor(vt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=Tt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-vt,Z[1]-Z[0]-yt))}$=Math.round($/Q),tt=Math.round(tt/Q),et=Math.round(et/Q);var _t=i(\"rgb(\"+$+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+Q,t._hmlumcount=(t._hmlumcount||0)+Q*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:O,x:r,y:m,\"xlink:href\":B.toDataURL(\"image/png\")})}function Tt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),Q+=e,$+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function kt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return Tt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,Tt(i+r.frac*c+n.frac*(u+r.frac*a))}}))}},{\"../../components/colorscale\":655,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../registry\":911,d3:169,tinycolor2:576}],1077:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",(function(t){return t.trace.opacity}))}},{d3:169}],1078:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,f,h=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===h||!h.length)return 0;if(i.isArray1D(t.z)){u=r(l),f=r(c);var p=i.minRowLength(u),d=i.minRowLength(f);if(0===p||0===d)return 0;e._length=Math.min(p,d,h.length)}else{if(u=o(l,r),f=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(h))return 0;r(\"transpose\"),e._length=null}return\"heatmapgl\"===t.type||\"contourgl\"===t.type||a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":778,\"../../registry\":911,\"fast-isnumeric\":241}],1080:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}l.zsmooth={valType:\"enumerated\",values:[\"fast\",!1],dflt:\"fast\",editType:\"calc\"},a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../heatmap/attributes\":1065}],1081:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={zsmooth:\"fast\",z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y,this.options.zsmooth=t.zsmooth;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var f=0;f<4;f++)s[4*l+f]=u[f]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c,u,f=this.scene.xaxis,h=this.scene.yaxis;!1===t.zsmooth&&(c={ppad:r.x[1]-r.x[0]},u={ppad:r.y[1]-r.y[0]}),t._extremes[f._id]=i.findExtremes(f,r.x,c),t._extremes[h._id]=i.findExtremes(h,r.y,u)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"gl-heatmap2d\":271}],1082:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,l,s)?(l(\"text\"),l(\"zsmooth\"),a(t,e,s,l,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../heatmap/xyz_defaults\":1079,\"./attributes\":1080}],1083:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":868,\"../heatmap/calc\":1066,\"../heatmap/colorbar\":1068,\"./attributes\":1080,\"./convert\":1081,\"./defaults\":1082}],1084:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"./bin_attributes\":1086,\"./constants\":1090}],1085:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1086:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1087:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":241}],1088:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function f(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=h(i,a),s=0;s<10;s++){var l=h(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function h(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,h=-.1*e,p=t-h,d=r[0],g=r[1],m=Math.min(f(d+h,d+p,n,a),f(g+h,g+p,n,a)),v=Math.min(f(d+c,d+h,n,a),f(g+c,g+h,n,a));if(m>v&&v<Math.abs(g-d)/4e3?(s=m,l=!1):(s=Math.min(m,v),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var f=u(c,x,!1,a);(c+f)/2<e+t&&(c=f)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":753,\"../../plots/cartesian/axes\":828}],1089:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),f=t(\"./bin_label_vals\");function h(t,e,r,s,l){var c,u,f,p,d,g,m,v=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},T=function(t){return r.c2r(t,0,p)},k=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function M(t,e,r){e[t+\"Found\"]?(e[t]=k(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],v+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var A=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((f=u[c]).visible){var L=b.dirs[c];d=f[\"_\"+L+\"pos0\"]=r.makeCalcdata(f,L),A=i.concat(A,d),delete f[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete f._autoBin,f[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(f,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===f.type&&(C=!0))}p=u[0][s+\"calendar\"];var I=o.autoBin(A,r,b.nbins,E,p,b.sizeFound&&b.size),P=u[0]._autoBin={};if(g=P[b.dirs[0]]={},C&&(b.size||(I.start=T(o.tickIncrement(w(I.start),I.size,!0,p))),void 0===b.end&&(I.end=T(o.tickIncrement(w(I.end),I.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===I._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[I,d,!0];I=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),f=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)f=!0;else if(f){var g=h(t,s,r,n,!0),m=g[0],v=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],v?d.push(s):p=Math.min(p,m.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,v)}(m=f.cumulative||{}).enabled&&\"include\"!==m.currentbin&&(\"decreasing\"===m.direction?I.start=T(o.tickIncrement(w(I.start),I.size,!0,p)):I.end=T(o.tickIncrement(w(I.end),I.size,!1,p))),b.size=I.size,b.sizeFound||(g.size=I.size,i.nestedProperty(u[0],v+\".size\").set(I.size)),M(\"start\",b,I),M(\"end\",b,I)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[v]||{},O=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),O.start=r.l2r(j),F||i.nestedProperty(e,v+\".start\").set(O.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);O.end=r.l2r(H),q||i.nestedProperty(e,v+\".start\").set(O.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[v]=i.extendFlat({},e[v]||{}),delete e._input[G],delete e[G]),[O,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],m=[],v=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=h(t,e,v,y),T=w[0],k=w[1],M=\"string\"==typeof T.size,A=[],S=M?A:T,E=[],C=[],L=[],I=0,P=e.histnorm,z=e.histfunc,O=-1!==P.indexOf(\"density\");_.enabled&&O&&(P=P.replace(/ ?density$/,\"\"),O=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[P],N=!1,j=function(t){return v.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(T.start),p=j(T.end)+(r-o.tickIncrement(r,T.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,T.size,!1,b),g.push((r+a)/2),m.push(R),L.push([]),A.push(r),O&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;A.push(r),M||\"date\"!==v.type||(S={start:j(S.start),end:j(S.end),size:S.size}),t._fullLayout._roundFnOpts||(t._fullLayout._roundFnOpts={});var U=e[\"_\"+y+\"bingroup\"],V={leftGap:1/0,rightGap:1/0};U&&(t._fullLayout._roundFnOpts[U]||(t._fullLayout._roundFnOpts[U]=V),V=t._fullLayout._roundFnOpts[U]);var q,H=m.length,G=!0,Y=V.leftGap,W=V.rightGap,X={};for(r=0;r<k.length;r++){var Z=k[r];(d=i.findBin(Z,S))>=0&&d<H&&(I+=F(d,r,m,D,C),G&&L[d].length&&Z!==k[L[d][0]]&&(G=!1),L[d].push(r),X[r]=d,Y=Math.min(Y,Z-A[d]),W=Math.min(W,A[d+1]-Z))}V.leftGap=Y,V.rightGap=W,G||(q=function(e,r){return function(){var n=t._fullLayout._roundFnOpts[U];return f(n.leftGap,n.rightGap,A,v,b)(e,r)}}),N&&(I=u(m,C)),B&&B(m,I,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(m,_.direction,_.currentbin);var J=Math.min(g.length,m.length),K=[],Q=0,$=J-1;for(r=0;r<J;r++)if(m[r]){Q=r;break}for(r=J-1;r>=Q;r--)if(m[r]){$=r;break}for(r=Q;r<=$;r++)if(n(g[r])&&n(m[r])){var tt={p:g[r],s:m[r],b:0};_.enabled||(tt.pts=L[r],G?tt.ph0=tt.ph1=L[r].length?k[L[r][0]]:g[r]:(e._computePh=!0,tt.ph0=q(A[r]),tt.ph1=q(A[r+1],!0))),K.push(tt)}return 1===K.length&&(K[0].width1=o.tickIncrement(K[0].p,T.size,!1,b)-K[0].p),s(K,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(K,e,X),K},calcAllAutoBins:h}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../bar/arrays_to_calcdata\":920,\"./average\":1085,\"./bin_functions\":1087,\"./bin_label_vals\":1088,\"./norm_functions\":1096,\"fast-isnumeric\":241}],1090:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,f,h,p,d,g,m,v=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function T(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"]||\"\",c=v[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(v[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var k=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],h=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var M=r[p+\"axis\"],A=l(e,M)+r.orientation;(k[A]||{})[r.alignmentgroup]&&(h=A)}h||\"overlay\"===e.barmode||(h=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}h?(x[h]||(x[h]=[]),x[h].push(r)):b.push(r)}for(h in x)if(1!==(f=x[h]).length){var S=!1;for(f.length&&(r=f[0],S=_(\"bingroup\")),h=S||h,d=0;d<f.length;d++){var E=(r=f[d])._input.bingroup;E&&E!==h&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",h+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=h,T(r,h,w(r))}}else b.push(f[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(m=0;m<2;m++){var L=_((p=u[m])+\"bingroup\",C?C+\"__\"+p:null);T(r,L,p)}else T(r,C,w(r))}for(h in v){var I=v[h];for(f=I.traces,g=0;g<c.length;g++){var P,z,O=c[g],D=O.name;if(\"nbins\"!==D||!I.sizeFound){for(d=0;d<f.length;d++){if(r=f[d],p=I.dirs[d],P=O.aStr[p],void 0!==s(r._input,P).get()){I[D]=_(P),I[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,P).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<f.length;d++)(r=f[d])[\"_\"+p+\"bingroup\"]&&_(P,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||I.sizeFound||I.nbinsFound||(r=f[0],I[D]=_(P))}}}}},{\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"../bar/defaults\":925}],1092:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),f=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"orientation\",f&&!u?\"h\":\"v\"),p=\"v\"===h?\"x\":\"y\",d=\"v\"===h?\"y\":\"x\",g=u&&f?Math.min(i.minRowLength(u)&&i.minRowLength(f)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var m=(e.marker.line||{}).color,v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,m||a.defaultLine,{axis:\"y\"}),v(t,e,m||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":643,\"../../lib\":778,\"../../registry\":911,\"../bar/style_defaults\":936,\"./attributes\":1084}],1093:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return o}}},{\"../../plots/cartesian/axes\":828,\"../bar/hover\":928}],1095:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/cross_trace_calc\":924,\"../bar/layout_attributes\":930,\"../bar/layout_defaults\":931,\"../bar/plot\":932,\"../bar/select\":933,\"../bar/style\":935,\"../scatter/marker_colorbar\":1205,\"./attributes\":1084,\"./calc\":1089,\"./cross_trace_defaults\":1091,\"./defaults\":1092,\"./event_data\":1093,\"./hover\":1094}],1096:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1097:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat;e.exports=c({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:c({},n.bingroup,{}),xbingroup:c({},n.bingroup,{}),ybingroup:c({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:s({},{keys:\"z\"}),showlegend:c({},o.showlegend,{dflt:!1})},l(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../heatmap/attributes\":1065,\"../histogram/attributes\":1084,\"../histogram/bin_attributes\":1086}],1098:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function f(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function h(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var f=(e||[])[o];c[o]=void 0===f?[u(t[o]),u(t[o+1],!0)]:[f,f]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),m=i.getFromId(t,e.yaxis),v=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,v)},b=function(t){return m.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],T=_[1],k=c(t,e,m,\"y\"),M=k[0],A=k[1],S=e._length;T.length>S&&T.splice(S,T.length-S),A.length>S&&A.splice(S,A.length-S);var E=[],C=[],L=[],I=\"string\"==typeof w.size,P=\"string\"==typeof M.size,z=[],O=[],D=I?z:w,R=P?O:M,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),Q=x(w.end)+(K-i.tickIncrement(K,J,!1,v))/1e6;for(r=K;r<Q;r=i.tickIncrement(r,J,!1,v))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var $,tt=C.length,et=(r-K)/tt,rt=($=K+et/2,g.c2r($,0,v)),nt=M.size,it=b(M.start),at=b(M.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),O.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}O.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return m.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,I),X=u(E.length,R,lt,P)),I||\"date\"!==g.type||(D=f(x,D)),P||\"date\"!==m.type||(R=f(b,R));var ut=!0,ft=!0,ht=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,mt=1/0,vt=1/0;for(r=0;r<S;r++){var yt=T[r],xt=A[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ht[p]?ht[p]=yt:ht[p]!==yt&&(ut=!1)),ft&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ft=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),mt=Math.min(mt,xt-O[d]),vt=Math.min(vt,O[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:T,xRanges:h(z,ut&&ht,dt,gt,g,v),x0:rt,dx:et,y:A,yRanges:h(O,ft&&pt,mt,vt,m,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../histogram/average\":1085,\"../histogram/bin_functions\":1087,\"../histogram/bin_label_vals\":1088,\"../histogram/calc\":1089,\"../histogram/norm_functions\":1096}],1099:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../heatmap/style_defaults\":1078,\"./attributes\":1097,\"./sample_defaults\":1102}],1100:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],f=c[1],h=t.cd[0],p=h.xRanges[f],d=h.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":828,\"../heatmap/hover\":1072}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../heatmap/calc\":1066,\"../heatmap/colorbar\":1068,\"../heatmap/plot\":1076,\"../heatmap/style\":1077,\"../histogram/cross_trace_defaults\":1091,\"../histogram/event_data\":1093,\"./attributes\":1097,\"./defaults\":1099,\"./hover\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":778,\"../../registry\":911}],1103:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:{color:i.line.color,width:o({},i.line.width,{dflt:.5}),dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../contour/attributes\":1008,\"../histogram2d/attributes\":1097}],1104:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,(function(r){return n.coerce2(t,e,s,r)})),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":778,\"../contour/contours_defaults\":1015,\"../contour/style_defaults\":1029,\"../histogram2d/sample_defaults\":1102,\"./attributes\":1103}],1105:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../contour/calc\":1009,\"../contour/colorbar\":1011,\"../contour/hover\":1021,\"../contour/plot\":1026,\"../contour/style\":1028,\"../histogram/cross_trace_defaults\":1091,\"./attributes\":1103,\"./defaults\":1104}],1106:[function(t,e,r){\"use strict\";for(var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"./constants\").colormodel,s=[\"rgb\",\"rgba\",\"rgba256\",\"hsl\",\"hsla\"],l=[],c=[],u=0;u<s.length;u++){var f=o[s[u]];l.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zminDflt||f.min).join(\", \")+\"].\"),c.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zmaxDflt||f.max).join(\", \")+\"].\")}e.exports=a({source:{valType:\"string\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},colormodel:{valType:\"enumerated\",values:s,editType:\"calc\"},zmin:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},zmax:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",dflt:1,editType:\"calc\"},dy:{valType:\"number\",dflt:1,editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"data_array\",editType:\"plot\"},hoverinfo:a({},n.hoverinfo,{flags:[\"x\",\"y\",\"z\",\"color\",\"name\",\"text\"],dflt:\"x+y+z+text+name\"}),hovertemplate:i({},{keys:[\"z\",\"color\",\"colormodel\"]}),transforms:void 0})},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"./constants\":1108}],1107:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\"),a=t(\"fast-isnumeric\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../lib\").maxRowLength,l=t(\"./helpers\").getImageSize;function c(t,e,r,i){return function(a){return n.constrain((a-t)*e,r,i)}}function u(t,e){return function(r){return n.constrain(r,t,e)}}e.exports=function(t,e){var r,n;if(e._hasZ)r=e.z.length,n=s(e.z);else if(e._hasSource){var f=l(e.source);r=f.height,n=f.width}var h,p=o.getFromId(t,e.xaxis||\"x\"),d=o.getFromId(t,e.yaxis||\"y\"),g=p.d2c(e.x0)-e.dx/2,m=d.d2c(e.y0)-e.dy/2,v=[g,g+n*e.dx],y=[m,m+r*e.dy];if(p&&\"log\"===p.type)for(h=0;h<n;h++)v.push(g+h*e.dx);if(d&&\"log\"===d.type)for(h=0;h<r;h++)y.push(m+h*e.dy);return e._extremes[p._id]=o.findExtremes(p,v),e._extremes[d._id]=o.findExtremes(d,y),e._scaler=function(t){var e=i.colormodel[t.colormodel],r=(e.colormodel||t.colormodel).length;t._sArray=[];for(var n=0;n<r;n++)e.min[n]!==t.zmin[n]||e.max[n]!==t.zmax[n]?t._sArray.push(c(t.zmin[n],(e.max[n]-e.min[n])/(t.zmax[n]-t.zmin[n]),e.min[n],e.max[n])):t._sArray.push(u(e.min[n],e.max[n]));return function(e){for(var n=e.slice(0,r),i=0;i<r;i++){var o=n[i];if(!a(o))return!1;n[i]=t._sArray[i](o)}return n}}(e),[{x0:g,y0:m,z:e.z,w:n,h:r}]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./constants\":1108,\"./helpers\":1111,\"fast-isnumeric\":241}],1108:[function(t,e,r){\"use strict\";e.exports={colormodel:{rgb:{min:[0,0,0],max:[255,255,255],fmt:function(t){return t.slice(0,3)},suffix:[\"\",\"\",\"\"]},rgba:{min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},rgba256:{colormodel:\"rgba\",zminDflt:[0,0,0,0],zmaxDflt:[255,255,255,255],min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},hsl:{min:[0,0,0],max:[360,100,100],fmt:function(t){var e=t.slice(0,3);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\"]},hsla:{min:[0,0,0,0],max:[360,100,100,1],fmt:function(t){var e=t.slice(0,4);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\",\"\"]}}}},{}],1109:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./constants\"),o=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX;e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"source\"),e.source&&!e.source.match(o)&&delete e.source,e._hasSource=!!e.source;var s,l=r(\"z\");(e._hasZ=!(void 0===l||!l.length||!l[0]||!l[0].length),e._hasZ||e._hasSource)?(r(\"x0\"),r(\"y0\"),r(\"dx\"),r(\"dy\"),e._hasZ?(r(\"colormodel\",\"rgb\"),r(\"zmin\",(s=a.colormodel[e.colormodel]).zminDflt||s.min),r(\"zmax\",s.zmaxDflt||s.max)):e._hasSource&&(e.colormodel=\"rgba256\",s=a.colormodel[e.colormodel],e.zmin=s.zminDflt,e.zmax=s.zmaxDflt),r(\"text\"),r(\"hovertext\"),r(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../lib\":778,\"../../snapshot/helpers\":915,\"./attributes\":1106,\"./constants\":1108}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){return\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t.color=e.color,t.colormodel=e.trace.colormodel,t.z||(t.z=e.color),t}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"image-size\"),i=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX,a=t(\"buffer/\").Buffer;r.getImageSize=function(t){var e=t.replace(i,\"\"),r=new a(e,\"base64\");return n(r)}},{\"../../snapshot/helpers\":915,\"buffer/\":111,\"image-size\":444}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"./constants\");e.exports=function(t,e,r){var o=t.cd[0],s=o.trace,l=t.xa,c=t.ya;if(!(n.inbox(e-o.x0,e-(o.x0+o.w*s.dx),0)>0||n.inbox(r-o.y0,r-(o.y0+o.h*s.dy),0)>0)){var u,f=Math.floor((e-o.x0)/s.dx),h=Math.floor(Math.abs(r-o.y0)/s.dy);if(s._hasZ?u=o.z[h][f]:s._hasSource&&(u=s._canvas.el.getContext(\"2d\").getImageData(f,h,1,1).data),u){var p,d=o.hi||s.hoverinfo;if(d){var g=d.split(\"+\");-1!==g.indexOf(\"all\")&&(g=[\"color\"]),-1!==g.indexOf(\"color\")&&(p=!0)}var m,v=a.colormodel[s.colormodel],y=v.colormodel||s.colormodel,x=y.length,b=s._scaler(u),_=v.suffix,w=[];(s.hovertemplate||p)&&(w.push(\"[\"+[b[0]+_[0],b[1]+_[1],b[2]+_[2]].join(\", \")),4===x&&w.push(\", \"+b[3]+_[3]),w.push(\"]\"),w=w.join(\"\"),t.extraText=y.toUpperCase()+\": \"+w),Array.isArray(s.hovertext)&&Array.isArray(s.hovertext[h])?m=s.hovertext[h][f]:Array.isArray(s.text)&&Array.isArray(s.text[h])&&(m=s.text[h][f]);var T=c.c2p(o.y0+(h+.5)*s.dy),k=o.x0+(f+.5)*s.dx,M=o.y0+(h+.5)*s.dy,A=\"[\"+u.slice(0,s.colormodel.length).join(\", \")+\"]\";return[i.extendFlat(t,{index:[h,f],x0:l.c2p(o.x0+f*s.dx),x1:l.c2p(o.x0+(f+1)*s.dx),y0:T,y1:T,color:b,xVal:k,xLabelVal:k,yVal:M,yLabelVal:M,zLabelVal:A,text:m,hovertemplateLabels:{zLabel:A,colorLabel:w,\"color[0]Label\":b[0]+_[0],\"color[1]Label\":b[1]+_[1],\"color[2]Label\":b[2]+_[2],\"color[3]Label\":b[3]+_[3]}})]}}}},{\"../../components/fx\":683,\"../../lib\":778,\"./constants\":1108}],1113:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"image\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"noSortingByValue\"],animatable:!1,meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1106,\"./calc\":1107,\"./defaults\":1109,\"./event_data\":1110,\"./hover\":1112,\"./plot\":1114,\"./style\":1115}],1114:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.strTranslate,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"./constants\"),l=i.isIOS()||i.isSafari()||i.isIE();e.exports=function(t,e,r,c){var u=e.xaxis,f=e.yaxis,h=!(l||t._context._exportedPlot);i.makeTraceGroups(c,r,\"im\").each((function(e){var r=n.select(this),l=e[0],c=l.trace,p=h&&!c._hasZ&&c._hasSource&&\"linear\"===u.type&&\"linear\"===f.type;c._fastImage=p;var d,g,m,v,y,x,b=l.z,_=l.x0,w=l.y0,T=l.w,k=l.h,M=c.dx,A=c.dy;for(x=0;void 0===d&&x<T;)d=u.c2p(_+x*M),x++;for(x=T;void 0===g&&x>0;)g=u.c2p(_+x*M),x--;for(x=0;void 0===v&&x<k;)v=f.c2p(w+x*A),x++;for(x=k;void 0===y&&x>0;)y=f.c2p(w+x*A),x--;if(g<d&&(m=g,g=d,d=m),y<v&&(m=v,v=y,y=m),!p){d=Math.max(-.5*u._length,d),g=Math.min(1.5*u._length,g),v=Math.max(-.5*f._length,v),y=Math.min(1.5*f._length,y)}var S=Math.round(g-d),E=Math.round(y-v);if(S<=0||E<=0){r.selectAll(\"image\").data([]).exit().remove()}else{var C=r.selectAll(\"image\").data([e]);C.enter().append(\"svg:image\").attr({xmlns:o.svg,preserveAspectRatio:\"none\"}),C.exit().remove();var L=\"image-rendering: optimizeSpeed; image-rendering: -moz-crisp-edges; image-rendering: -o-crisp-edges; image-rendering: -webkit-optimize-contrast; image-rendering: optimize-contrast; image-rendering: crisp-edges; image-rendering: pixelated;\";if(p){var I=i.simpleMap(u.range,u.r2l),P=i.simpleMap(f.range,f.r2l),z=I[1]<I[0],O=P[1]>P[0];if(z||O){var D=d+S/2,R=v+E/2;L+=\"transform:\"+a(D+\"px\",R+\"px\")+\"scale(\"+(z?-1:1)+\",\"+(O?-1:1)+\")\"+a(-D+\"px\",-R+\"px\")+\";\"}}C.attr(\"style\",L);var F=new Promise((function(t){if(c._hasZ)t();else if(c._hasSource)if(c._canvas&&c._canvas.el.width===T&&c._canvas.el.height===k&&c._canvas.source===c.source)t();else{var e=document.createElement(\"canvas\");e.width=T,e.height=k;var r=e.getContext(\"2d\");c._image=c._image||new Image;var n=c._image;n.onload=function(){r.drawImage(n,0,0),c._canvas={el:e,source:c.source},t()},n.setAttribute(\"src\",c.source)}})).then((function(){var t;if(c._hasZ)t=B((function(t,e){return b[e][t]})).toDataURL(\"image/png\");else if(c._hasSource)if(p)t=c.source;else{var e=c._canvas.el.getContext(\"2d\").getImageData(0,0,T,k).data;t=B((function(t,r){var n=4*(r*T+t);return[e[n],e[n+1],e[n+2],e[n+3]]})).toDataURL(\"image/png\")}C.attr({\"xlink:href\":t,height:E,width:S,x:d,y:v})}));t._promises.push(F)}function B(t){var e=document.createElement(\"canvas\");e.width=S,e.height=E;var r,n=e.getContext(\"2d\"),a=function(t){return i.constrain(Math.round(u.c2p(_+t*M)-d),0,S)},o=function(t){return i.constrain(Math.round(f.c2p(w+t*A)-v),0,E)},h=s.colormodel[c.colormodel],p=h.colormodel||c.colormodel,g=h.fmt;for(x=0;x<l.w;x++){var m=a(x),y=a(x+1);if(y!==m&&!isNaN(y)&&!isNaN(m))for(var b=0;b<l.h;b++){var T=o(b),k=o(b+1);k===T||isNaN(k)||isNaN(T)||!t(x,b)||(r=c._scaler(t(x,b)),n.fillStyle=r?p+\"(\"+g(r).join(\",\")+\")\":\"rgba(0,0,0,0)\",n.fillRect(m,T,y-m,k-T))}}return e}}))}},{\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"./constants\":1108,d3:169}],1115:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".im image\").style(\"opacity\",(function(t){return t[0].trace.opacity}))}},{d3:169}],1116:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../constants/delta.js\"),h=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"step\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},h,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},h,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:f.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:f.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},h,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,minexponent:c.minexponent,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":642,\"../../constants/delta.js\":747,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1117:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"indicator\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1118:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1119:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),f=t(\"../../plots/cartesian/tick_label_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var m,v,y,x,b,_,w=new Array(2);function T(t,e){return n.coerce(y,x,i.gauge,t,e)}function k(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),m=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(m||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),v=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(m||v||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),T(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),T(\"bgcolor\",p.paper_bgcolor),T(\"borderwidth\"),T(\"bordercolor\"),T(\"bar.color\"),T(\"bar.line.color\"),T(\"bar.line.width\"),T(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:h}),T(\"threshold.value\"),T(\"threshold.thickness\"),T(\"threshold.line.width\"),T(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),k(\"visible\"),e._range=k(\"range\",e._range);var M={outerTicks:!0};c(b,_,k,\"linear\"),f(b,_,k,\"linear\",M),u(b,_,k,M)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_mark_defaults\":850,\"../../plots/cartesian/tick_value_defaults\":851,\"../../plots/domain\":855,\"./attributes\":1116,\"./constants.js\":1119}],1121:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1116,\"./base_plot\":1117,\"./calc\":1118,\"./defaults\":1120,\"./plot\":1122}],1122:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.strScale,o=i.strTranslate,s=i.rad2deg,l=t(\"../../constants/alignment\").MID_SHIFT,c=t(\"../../components/drawing\"),u=t(\"./constants\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../../plots/cartesian/axis_defaults\"),d=t(\"../../plots/cartesian/position_defaults\"),g=t(\"../../plots/cartesian/layout_attributes\"),m=t(\"../../components/color\"),v={left:\"start\",center:\"middle\",right:\"end\"},y={left:0,center:.5,right:1},x=/[yzafpn\\xb5mkMGTPEZY]/;function b(t){return t&&t.duration>0}function _(t){t.each((function(t){m.stroke(n.select(this),t.line.color)})).each((function(t){m.fill(n.select(this),t.color)})).style(\"stroke-width\",(function(t){return t.line.width}))}function w(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,g,t,e)}return p(a,o,l,s,n),d(a,o,l,s),o}function T(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(f.convertToTspans,i).call(c.font,e),c.bBox(o.node())}function M(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,p){var d,g=t._fullLayout;b(r)&&p&&(d=p()),i.makeTraceGroups(g._indicatorlayer,e,\"trace\").each((function(e){var p,A,S,E,C,L=e[0].trace,I=n.select(this),P=L._hasGauge,z=L._isAngular,O=L._isBullet,D=L.domain,R={w:g._size.w*(D.x[1]-D.x[0]),h:g._size.h*(D.y[1]-D.y[0]),l:g._size.l+g._size.w*D.x[0],r:g._size.r+g._size.w*(1-D.x[1]),t:g._size.t+g._size.h*(1-D.y[1]),b:g._size.b+g._size.h*D.y[0]},F=R.l+R.w/2,B=R.t+R.h/2,N=Math.min(R.w/2,R.h),j=u.innerRadius*N,U=L.align||\"center\";if(A=B,P){if(z&&(p=F,A=B+N/2,S=function(t){return function(t,e){var r=Math.sqrt(t.width/2*(t.width/2)+t.height*t.height);return[e/r,t,e]}(t,.9*j)}),O){var V=u.bulletPadding,q=1-u.bulletNumberDomainSize+V;p=R.l+(q+(1-q)*y[U])*R.w,S=function(t){return T(t,(u.bulletNumberDomainSize-V)*R.w,R.h)}}}else p=R.l+y[U]*R.w,S=function(t){return T(t,R.w,R.h)};!function(t,e,r,s){var l,u,p,d=r[0].trace,g=s.numbersX,_=s.numbersY,T=d.align||\"center\",A=v[T],S=s.transitionOpts,E=s.onComplete,C=i.ensureSingle(e,\"g\",\"numbers\"),L=[];d._hasNumber&&L.push(\"number\");d._hasDelta&&(L.push(\"delta\"),\"left\"===d.delta.position&&L.reverse());var I=C.selectAll(\"text\").data(L);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(x)||r(i).slice(-1).match(x))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,(function(t){return parseInt(t)-1})),o=w(t,{tickformat:a});return function(t){return Math.abs(t)<1?h.tickText(o,t).text:r(t)}}I.enter().append(\"text\"),I.attr(\"text-anchor\",(function(){return A})).attr(\"class\",(function(t){return t})).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),I.exit().remove();var z,O=d.mode+d.align;d._hasDelta&&(z=function(){var e=w(t,{tickformat:d.delta.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=function(t){return d.delta.relative?t.relativeDelta:t.delta},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?d.delta.increasing.symbol:d.delta.decreasing.symbol)+e(t)},s=function(t){return t.delta>=0?d.delta.increasing.color:d.delta.decreasing.color};void 0===d._deltaLastValue&&(d._deltaLastValue=a(r[0]));var l=C.select(\"text.delta\");function p(){l.text(o(a(r[0]),i)).call(m.fill,s(r[0])).call(f.convertToTspans,t)}return l.call(c.font,d.delta.font).call(m.fill,s({delta:d._deltaLastValue})),b(S)?l.transition().duration(S.duration).ease(S.easing).tween(\"text\",(function(){var t=n.select(this),e=a(r[0]),l=d._deltaLastValue,c=P(d.delta.valueformat,i,l,e),u=n.interpolateNumber(l,e);return d._deltaLastValue=e,function(e){t.text(o(u(e),c)),t.call(m.fill,s({delta:u(e)}))}})).each(\"end\",(function(){p(),E&&E()})).each(\"interrupt\",(function(){p(),E&&E()})):p(),u=k(o(a(r[0]),i),d.delta.font,A,t),l}(),O+=d.delta.position+d.delta.font.size+d.delta.font.family+d.delta.valueformat,O+=d.delta.increasing.symbol+d.delta.decreasing.symbol,p=u);d._hasNumber&&(!function(){var e=w(t,{tickformat:d.number.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=d.number.suffix,o=d.number.prefix,s=C.select(\"text.number\");function u(){var e=\"number\"==typeof r[0].y?o+i(r[0].y)+a:\"-\";s.text(e).call(c.font,d.number.font).call(f.convertToTspans,t)}b(S)?s.transition().duration(S.duration).ease(S.easing).each(\"end\",(function(){u(),E&&E()})).each(\"interrupt\",(function(){u(),E&&E()})).attrTween(\"text\",(function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);d._lastValue=r[0].y;var s=P(d.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(o+s(e(r))+a)}})):u(),l=k(o+i(r[0].y)+a,d.number.font,A,t)}(),O+=d.number.font.size+d.number.font.family+d.number.valueformat+d.number.suffix+d.number.prefix,p=l);if(d._hasDelta&&d._hasNumber){var D,R,F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=[(u.left+u.right)/2,(u.top+u.bottom)/2],N=.75*d.delta.font.size;\"left\"===d.delta.position&&(D=M(d,\"deltaPos\",0,-1*(l.width*y[d.align]+u.width*(1-y[d.align])+N),O,Math.min),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:u.left+D,right:l.right,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"right\"===d.delta.position&&(D=M(d,\"deltaPos\",0,l.width*(1-y[d.align])+u.width*y[d.align]+N,O,Math.max),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:l.left,right:u.right+D,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"bottom\"===d.delta.position&&(D=null,R=u.height,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height,bottom:l.bottom+u.height}),\"top\"===d.delta.position&&(D=null,R=l.top,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height-u.height,bottom:l.bottom}),z.attr({dx:D,dy:R})}(d._hasNumber||d._hasDelta)&&C.attr(\"transform\",(function(){var t=s.numbersScaler(p);O+=t[2];var e,r=M(d,\"numbersScale\",1,t[0],O,Math.min);d._scaleNumbers||(r=1),e=d._isAngular?_-r*p.bottom:_-r*(p.top+p.bottom)/2,d._numbersTop=r*p.top+e;var n=p[T];\"center\"===T&&(n=(p.left+p.right)/2);var i=g-r*n;return i=M(d,\"numbersTranslate\",0,i,O,Math.max),o(i,e)+a(r)}))}(t,I,e,{numbersX:p,numbersY:A,numbersScaler:S,transitionOpts:r,onComplete:d}),P&&(E={range:L.gauge.axis.range,color:L.gauge.bgcolor,line:{color:L.gauge.bordercolor,width:0},thickness:1},C={range:L.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:L.gauge.bordercolor,width:L.gauge.borderwidth},thickness:1});var H=I.selectAll(\"g.angular\").data(z?e:[]);H.exit().remove();var G=I.selectAll(\"g.angularaxis\").data(z?e:[]);G.exit().remove(),z&&function(t,e,r,i){var a,c,u,f,p=r[0].trace,d=i.size,g=i.radius,m=i.innerRadius,v=i.gaugeBg,y=i.gaugeOutline,x=[d.l+d.w/2,d.t+d.h/2+g/2],T=i.gauge,k=i.layer,M=i.transitionOpts,A=i.onComplete,S=Math.PI/2;function E(t){var e=p.gauge.axis.range[0],r=(t-e)/(p.gauge.axis.range[1]-e)*Math.PI-S;return r<-S?-S:r>S?S:r}function C(t){return n.svg.arc().innerRadius((m+g)/2-t/2*(g-m)).outerRadius((m+g)/2+t/2*(g-m)).startAngle(-S)}function L(t){t.attr(\"d\",(function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()}))}T.enter().append(\"g\").classed(\"angular\",!0),T.attr(\"transform\",o(x[0],x[1])),k.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),k.selectAll(\"g.xangularaxistick,path,text\").remove(),(a=w(t,p.gauge.axis)).type=\"linear\",a.range=p.gauge.axis.range,a._id=\"xangularaxis\",a.setScale();var I=function(t){return(a.range[0]-t.x)/(a.range[1]-a.range[0])*Math.PI+Math.PI},P={},z=h.makeLabelFns(a,0).labelStandoff;P.xFn=function(t){var e=I(t);return Math.cos(e)*z},P.yFn=function(t){var e=I(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*l)},P.anchorFn=function(t){var e=I(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},P.heightFn=function(t,e,r){var n=I(t);return-.5*(1+Math.sin(n))*r};var O=function(t){return o(x[0]+g*Math.cos(t),x[1]-g*Math.sin(t))};u=function(t){return O(I(t))};if(c=h.calcTicks(a),f=h.getTickSigns(a)[2],a.visible){f=\"inside\"===a.ticks?-1:1;var D=(a.linewidth||1)/2;h.drawTicks(t,a,{vals:c,layer:k,path:\"M\"+f*D+\",0h\"+f*a.ticklen,transFn:function(t){var e=I(t);return O(e)+\"rotate(\"+-s(e)+\")\"}}),h.drawLabels(t,a,{vals:c,layer:k,transFn:u,labelFns:P})}var R=[v].concat(p.gauge.steps),F=T.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(_),F.exit().remove();var B=C(p.gauge.bar.thickness),N=T.selectAll(\"g.value-arc\").data([p.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");b(M)?(j.transition().duration(M.duration).ease(M.easing).each(\"end\",(function(){A&&A()})).each(\"interrupt\",(function(){A&&A()})).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),p._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(_),N.exit().remove(),R=[];var H=p.gauge.threshold.value;H&&R.push({range:[H,H],color:p.gauge.threshold.color,line:{color:p.gauge.threshold.line.color,width:p.gauge.threshold.line.width},thickness:p.gauge.threshold.thickness});var G=T.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(_),G.exit().remove();var Y=T.selectAll(\"g.gauge-outline\").data([y]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(_),Y.exit().remove()}(t,0,e,{radius:N,innerRadius:j,gauge:H,layer:G,size:R,gaugeBg:E,gaugeOutline:C,transitionOpts:r,onComplete:d});var Y=I.selectAll(\"g.bullet\").data(O?e:[]);Y.exit().remove();var W=I.selectAll(\"g.bulletaxis\").data(O?e:[]);W.exit().remove(),O&&function(t,e,r,n){var i,a,s,l,c,f=r[0].trace,p=n.gauge,d=n.layer,g=n.gaugeBg,v=n.gaugeOutline,y=n.size,x=f.domain,T=n.transitionOpts,k=n.onComplete;p.enter().append(\"g\").classed(\"bullet\",!0),p.attr(\"transform\",o(y.l,y.t)),d.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),d.selectAll(\"g.xbulletaxistick,path,text\").remove();var M=y.h,A=f.gauge.bar.thickness*M,S=x.x[0],E=x.x[0]+(x.x[1]-x.x[0])*(f._hasNumber||f._hasDelta?1-u.bulletNumberDomainSize:1);(i=w(t,f.gauge.axis))._id=\"xbulletaxis\",i.domain=[S,E],i.setScale(),a=h.calcTicks(i),s=h.makeTransTickFn(i),l=h.getTickSigns(i)[2],c=y.t+y.h,i.visible&&(h.drawTicks(t,i,{vals:\"inside\"===i.ticks?h.clipEnds(i,a):a,layer:d,path:h.makeTickPath(i,c,l),transFn:s}),h.drawLabels(t,i,{vals:a,layer:d,transFn:s,labelFns:h.makeLabelFns(i,c)}));function C(t){t.attr(\"width\",(function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))})).attr(\"x\",(function(t){return i.c2p(t.range[0])})).attr(\"y\",(function(t){return.5*(1-t.thickness)*M})).attr(\"height\",(function(t){return t.thickness*M}))}var L=[g].concat(f.gauge.steps),I=p.selectAll(\"g.bg-bullet\").data(L);I.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),I.select(\"rect\").call(C).call(_),I.exit().remove();var P=p.selectAll(\"g.value-bullet\").data([f.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(M-A)/2).call(_),b(T)?P.select(\"rect\").transition().duration(T.duration).ease(T.easing).each(\"end\",(function(){k&&k()})).each(\"interrupt\",(function(){k&&k()})).attr(\"width\",Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var z=r.filter((function(){return f.gauge.threshold.value})),O=p.selectAll(\"g.threshold-bullet\").data(z);O.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),O.select(\"line\").attr(\"x1\",i.c2p(f.gauge.threshold.value)).attr(\"x2\",i.c2p(f.gauge.threshold.value)).attr(\"y1\",(1-f.gauge.threshold.thickness)/2*M).attr(\"y2\",(1-(1-f.gauge.threshold.thickness)/2)*M).call(m.stroke,f.gauge.threshold.line.color).style(\"stroke-width\",f.gauge.threshold.line.width),O.exit().remove();var D=p.selectAll(\"g.gauge-outline\").data([v]);D.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),D.select(\"rect\").call(C).call(_),D.exit().remove()}(t,0,e,{gauge:Y,layer:W,size:R,gaugeBg:E,gaugeOutline:C,transitionOpts:r,onComplete:d});var X=I.selectAll(\"text.title\").data(e);X.exit().remove(),X.enter().append(\"text\").classed(\"title\",!0),X.attr(\"text-anchor\",(function(){return O?v.right:v[L.title.align]})).text(L.title.text).call(c.font,L.title.font).call(f.convertToTspans,t),X.attr(\"transform\",(function(){var t,e=R.l+R.w*y[L.title.align],r=u.titlePadding,n=c.bBox(X.node());if(P){if(z)if(L.gauge.axis.visible)t=c.bBox(G.node()).top-r-n.bottom;else t=R.t+R.h/2-N/2-n.bottom-r;O&&(t=A-(n.top+n.bottom)/2,e=R.l-u.bulletPadding*R.w)}else t=L._numbersTop-r-n.bottom;return o(e,t)}))}))}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_defaults\":830,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/cartesian/position_defaults\":845,\"./constants\":1119,d3:169}],1123:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i(),showlegend:s({},o.showlegend,{dflt:!1})},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../streamtube/calc\").processGrid,a=t(\"../streamtube/calc\").filter;e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length),e._x=a(e.x,e._len),e._y=a(e.y,e._len),e._z=a(e.z,e._len),e._value=a(e.value,e._len);var r=i(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;for(var o=1/0,s=-1/0,l=0;l<e._len;l++){var c=e._value[l];o=Math.min(o,c),s=Math.max(s,c)}e._minValues=o,e._maxValues=s,e._vMin=void 0===e.isomin||null===e.isomin?o:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?s:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651,\"../streamtube/calc\":1295}],1125:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function c(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},u.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=h(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[c.min,c.max],l.colormap=i(t),this.mesh.update(l)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()};var f=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"];function h(t){t._meshI=[],t._meshJ=[],t._meshK=[];var e,r,n,i,a,o,s,c=t.surface.show,u=t.spaceframe.show,h=t.surface.fill,p=t.spaceframe.fill,d=!1,g=!1,m=0,v=t._Xs,y=t._Ys,x=t._Zs,b=v.length,_=y.length,w=x.length,T=f.indexOf(t._gridFill.replace(/-/g,\"\").replace(/\\+/g,\"\")),k=function(t,e,r){switch(T){case 5:return r+w*e+w*_*t;case 4:return r+w*t+w*b*e;case 3:return e+_*r+_*w*t;case 2:return e+_*t+_*b*r;case 1:return t+b*r+b*w*e;default:return t+b*e+b*_*r}},M=t._minValues,A=t._maxValues,S=t._vMin,E=t._vMax;function C(t,e,s){for(var l=o.length,c=r;c<l;c++)if(t===n[c]&&e===i[c]&&s===a[c])return c;return-1}function L(){r=e}function I(){n=[],i=[],a=[],o=[],e=0,L()}function P(t,r,s,l){return n.push(t),i.push(r),a.push(s),o.push(l),++e-1}function z(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function O(t){s=t}function D(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function R(t,e){return null===t?e:t}function F(e,r,n){L();var i,a,o,l=[r],c=[n];if(s>=1)l=[r],c=[n];else if(s>0){var u=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-s),l=z(a,r,o),c=z(a,n,o),u=z(a,i,o),f=e[0],h=e[1],p=e[2];return{xyzv:[[r,n,c],[c,l,r],[n,i,u],[u,c,n],[i,r,l],[l,u,i]],abc:[[f,h,-1],[-1,-1,f],[h,p,-1],[-1,-1,h],[p,f,-1],[-1,-1,p]]}}(r,n);l=u.xyzv,c=u.abc}for(var f=0;f<l.length;f++){r=l[f],n=c[f];for(var h=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],y=r[p][3],x=n[p]>-1?n[p]:C(d,g,v);h[p]=x>-1?x:P(d,g,v,R(e,y))}i=h[0],a=h[1],o=h[2],t._meshI.push(i),t._meshJ.push(a),t._meshK.push(o),++m}}function B(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function N(t,e,r){return t>=e&&t<=r}function j(t){var e=.001*(E-S);return t>=S-e&&t<=E+e}function U(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t._x[i],t._y[i],t._z[i],t._value[i]])}return r}function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[N(e[0][3],n,i),N(e[1][3],n,i),N(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return j(e[0][3])&&j(e[1][3])&&j(e[2][3])?(F(t,e,r),!0):a<3&&V(t,e,r,S,E,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach((function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(h,u,n,i),d=B(h,f,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,f,d],[r[a[0]],r[a[1]],-1])||o,c=!0}})),c||[[0,1,2],[1,2,0],[2,0,1]].forEach((function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(f,u,n,i),d=B(h,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}})),o}function q(t,e,r,n){var i=!1,a=U(e),o=[N(a[0][3],r,n),N(a[1][3],r,n),N(a[2][3],r,n),N(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return g&&(i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]];if(g)i=F(t,[c,u,f],[e[l[0]],e[l[1]],e[l[2]]])||i;else{var p=B(h,c,r,n),d=B(h,u,r,n),m=B(h,f,r,n);i=F(null,[p,d,m],[-1,-1,-1])||i}s=!0}})),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(f,c,r,n),d=B(f,u,r,n),m=B(h,u,r,n),v=B(h,c,r,n);g?(i=F(t,[c,v,p],[e[l[0]],-1,-1])||i,i=F(t,[u,d,m],[e[l[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[p,d,m,v],[-1,-1,-1,-1])||i,s=!0}})),s||[[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach((function(l){if(o[l[0]]&&!o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(u,c,r,n),d=B(f,c,r,n),m=B(h,c,r,n);g?(i=F(t,[c,p,d],[e[l[0]],-1,-1])||i,i=F(t,[c,d,m],[e[l[0]],-1,-1])||i,i=F(t,[c,m,p],[e[l[0]],-1,-1])||i):i=F(null,[p,d,m],[-1,-1,-1])||i,s=!0}})),i)}function H(t,e,r,n,i,a,o,s,l,c,u){var f=!1;return d&&(D(t,\"A\")&&(f=q(null,[e,r,n,a],c,u)||f),D(t,\"B\")&&(f=q(null,[r,n,i,l],c,u)||f),D(t,\"C\")&&(f=q(null,[r,a,o,l],c,u)||f),D(t,\"D\")&&(f=q(null,[n,a,s,l],c,u)||f),D(t,\"E\")&&(f=q(null,[r,n,a,l],c,u)||f)),g&&(f=q(t,[r,n,a,l],c,u)||f),f}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,U([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,U([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,f=!1,h=function(){f=V(t,[s,l,c],[-1,-1,-1],i,a)||f,f=V(t,[c,u,s],[-1,-1,-1],i,a)||f},p=o[0],d=o[1],g=o[2];return p&&(s=z(U([k(e,r-0,n-0)])[0],U([k(e-1,r-0,n-0)])[0],p),l=z(U([k(e,r-0,n-1)])[0],U([k(e-1,r-0,n-1)])[0],p),c=z(U([k(e,r-1,n-1)])[0],U([k(e-1,r-1,n-1)])[0],p),u=z(U([k(e,r-1,n-0)])[0],U([k(e-1,r-1,n-0)])[0],p),h()),d&&(s=z(U([k(e-0,r,n-0)])[0],U([k(e-0,r-1,n-0)])[0],d),l=z(U([k(e-0,r,n-1)])[0],U([k(e-0,r-1,n-1)])[0],d),c=z(U([k(e-1,r,n-1)])[0],U([k(e-1,r-1,n-1)])[0],d),u=z(U([k(e-1,r,n-0)])[0],U([k(e-1,r-1,n-0)])[0],d),h()),g&&(s=z(U([k(e-0,r-0,n)])[0],U([k(e-0,r-0,n-1)])[0],g),l=z(U([k(e-0,r-1,n)])[0],U([k(e-0,r-1,n-1)])[0],g),c=z(U([k(e-1,r-1,n)])[0],U([k(e-1,r-1,n-1)])[0],g),u=z(U([k(e-1,r-0,n)])[0],U([k(e-1,r-0,n-1)])[0],g),h()),f}function X(t,e,r,n,i,a,o,s,l,c,u,f){var h=t;return f?(d&&\"even\"===t&&(h=null),H(h,e,r,n,i,a,o,s,l,c,u)):(d&&\"odd\"===t&&(h=null),H(h,l,s,o,a,i,n,r,e,c,u))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<w;c++)for(var u=1;u<_;u++)a.push(Y(t,k(l,u-1,c-1),k(l,u-1,c),k(l,u,c-1),k(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<b;c++)for(var u=1;u<w;u++)a.push(Y(t,k(c-1,l,u-1),k(c,l,u-1),k(c-1,l,u),k(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<_;c++)for(var u=1;u<b;u++)a.push(Y(t,k(u-1,c-1,l),k(u-1,c,l),k(u,c-1,l),k(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function Q(t,e,r){for(var n=1;n<w;n++)for(var i=1;i<_;i++)for(var a=1;a<b;a++)X(t,k(a-1,i-1,n-1),k(a-1,i-1,n),k(a-1,i,n-1),k(a-1,i,n),k(a,i-1,n-1),k(a,i-1,n),k(a,i,n-1),k(a,i,n),e,r,(a+i+n)%2)}function $(t,e,r){d=!0,Q(t,e,r),d=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<w;u++)for(var f=1;f<_;f++)o.push(W(t,c,f,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<b;u++)for(var f=1;f<w;f++)o.push(W(t,u,c,f,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<_;u++)for(var f=1;f<b;f++)o.push(W(t,f,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(I(),function(){for(var e=0;e<b;e++)for(var r=0;r<_;r++)for(var n=0;n<w;n++){var i=k(e,r,n);P(t._x[i],t._y[i],t._z[i],t._value[i])}}(),u&&p&&(O(p),g=!0,Q(null,S,E),g=!1),c&&h){O(h);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var f=1===r?.5:s/(r-1),d=(1-f)*S+f*E,T=Math.abs(d-M)>Math.abs(d-A)?[M,d]:[d,A];$(e,T[0],T[1])}}var C=[[Math.min(S,A),Math.max(S,A)],[Math.min(M,E),Math.max(M,E)]];[\"x\",\"y\",\"z\"].forEach((function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){O(s.fill);var c=[],u=[],f=[];if(s.locations.length)for(var h=0;h<s.locations.length;h++){var p=l(s.locations[h],\"x\"===e?v:\"y\"===e?y:x);0===p.distRatio?c.push(p.id):p.id>0&&(u.push(p.id),\"x\"===e?f.push([p.distRatio,0,0]):\"y\"===e?f.push([0,p.distRatio,0]):f.push([0,0,p.distRatio]))}else c=nt(1,\"x\"===e?b-1:\"y\"===e?_-1:w-1);u.length>0&&(r[i]=\"x\"===e?tt(null,u,a,o,f,r[i]):\"y\"===e?et(null,u,a,o,f,r[i]):rt(null,u,a,o,f,r[i]),i++),c.length>0&&(r[i]=\"x\"===e?Z(null,c,a,o,r[i]):\"y\"===e?J(null,c,a,o,r[i]):K(null,c,a,o,r[i]),i++)}var d=t.caps[e];d.show&&d.fill&&(O(d.fill),r[i]=\"x\"===e?Z(null,[0,b-1],a,o,r[i]):\"y\"===e?J(null,[0,_-1],a,o,r[i]):K(null,[0,w-1],a,o,r[i]),i++)}})),0===m&&I(),t._meshX=n,t._meshY=i,t._meshZ=a,t._meshIntensity=o,t._Xs=v,t._Ys=y,t._Zs=x}(),t}e.exports={findNearestOnAxis:l,generateIsoMeshes:h,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new c(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"gl-mesh3d\":309}],1126:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),f=a(\"z\"),h=a(\"value\");c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach((function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))})),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach((function(t){a(t)})),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,r,i,(function(r,i){return n.coerce(t,e,a,r,i)}))},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1123}],1127:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1123,\"./calc\":1124,\"./convert\":1125,\"./defaults\":1126}],1128:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},intensitymode:{valType:\"enumerated\",values:[\"vertex\",\"cell\"],dflt:\"vertex\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"}),showlegend:s({},o.showlegend,{dflt:!1})})},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../surface/attributes\":1311}],1129:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1130:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function f(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var h=f.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function m(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}h.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.data._cellCenter?t.traceCoordinate=t.data.dataCoordinate:t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,f=t.x.length,h=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!m(t.i,f)||!m(t.j,f)||!m(t.k,f))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(h):t.alphahull>0?a(t.alphahull,h):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,h);var v={positions:h,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\";var x=t.intensitymode;v[x+\"Intensity\"]=t.intensity,v[x+\"IntensityBounds\"]=[y.min,y.max],v.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],v.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],v.cellColors=p(t.facecolor)):(this.color=t.color,v.meshColor=l(t.color));this.mesh.update(v)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new f(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"alpha-shape\":69,\"convex-hull\":135,\"delaunay-triangulate\":171,\"gl-mesh3d\":309}],1131:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map((function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null}));return e.every((function(t){return t&&t.length===e[0].length}))&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach((function(t){l(t)})),l(\"contour.show\")&&(l(\"contour.color\"),l(\"contour.width\")),\"intensity\"in t?(l(\"intensity\"),l(\"intensitymode\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1128}],1132:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1128,\"./calc\":1129,\"./convert\":1130,\"./defaults\":1131}],1133:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function f(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:f(l),decreasing:f(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":664,\"../../components/fx/attributes\":674,\"../../constants/delta.js\":747,\"../../lib\":778,\"../scatter/attributes\":1187}],1134:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r,n){return{o:t,h:e,l:r,c:n}}function c(t,e,r,o,l,c){for(var u=l.makeCalcdata(e,\"open\"),f=l.makeCalcdata(e,\"high\"),h=l.makeCalcdata(e,\"low\"),p=l.makeCalcdata(e,\"close\"),d=Array.isArray(e.text),g=Array.isArray(e.hovertext),m=!0,v=null,y=!!e.xperiodalignment,x=[],b=0;b<o.length;b++){var _=o[b],w=u[b],T=f[b],k=h[b],M=p[b];if(_!==s&&w!==s&&T!==s&&k!==s&&M!==s){M===w?null!==v&&M!==v&&(m=M>v):m=M>w,v=M;var A=c(w,T,k,M);A.pos=_,A.yc=(w+M)/2,A.i=b,A.dir=m?\"increasing\":\"decreasing\",A.x=A.pos,A.y=[k,T],y&&(A.orig_p=r[b]),d&&(A.tx=e.text[b]),g&&(A.htx=e.hovertext[b]),x.push(A)}else x.push({pos:_,empty:!0})}return e._extremes[l._id]=a.findExtremes(l,n.concat(h,f),{padded:!0}),x.length&&(x[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),x}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),s=function(t,e,r){var i=r._minDiff;if(!i){var a,s=t._fullData,l=[];for(i=1/0,a=0;a<s.length;a++){var c=s[a];if(\"ohlc\"===c.type&&!0===c.visible&&c.xaxis===e._id){l.push(c);var u=e.makeCalcdata(c,\"x\");c._origX=u;var f=o(r,e,\"x\",u);c._xcalc=f;var h=n.distinctVals(f).minDiff;h&&isFinite(h)&&(i=Math.min(i,h))}}for(i===1/0&&(i=1),a=0;a<l.length;a++)l[a]._minDiff=i}return i*r.tickwidth}(t,r,e),u=e._minDiff;e._minDiff=null;var f=e._origX;e._origX=null;var h=e._xcalc;e._xcalc=null;var p=c(t,e,f,h,i,l);return e._extremes[r._id]=a.findExtremes(r,h,{vpad:u/2}),p.length?(n.extendFlat(p[0].t,{wHover:u/2,tickLen:s}),p):[{t:{empty:!0}}]},calcCommon:c}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}i(t,e,c,l)?(a(t,e,l,c,{x:!0}),c(\"line.width\"),c(\"line.dash\"),s(t,e,c,\"increasing\"),s(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"tickwidth\"),l._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":778,\"../scatter/period_defaults\":1207,\"./attributes\":1133,\"./ohlc_defaults\":1138}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,f=l[0].t,h=u.type,p=\"ohlc\"===h?\"l\":\"min\",d=\"ohlc\"===h?\"h\":\"max\",g=f.bPos||0,m=f.bdPos||f.tickLen,v=f.wHover,y=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function x(t){var r=function(t){return t.pos+g-e}(t);return a.inbox(r-v,r+v,i)}function b(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function _(t){return(x(t)+b(t))/2}i=t.maxHoverDistance-y,s=t.maxSpikeDistance-y;var w=a.getDistanceFunction(n,x,b,_);if(a.getClosest(l,w,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var k=u[T.dir],M=k.line.color;return o.opacity(M)&&k.line.width?t.color=M:t.color=k.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=void 0!==T.orig_p?T.orig_p:T.pos,t.spikeDistance=_(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function f(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,f=[],h=u(t,e,r,a);if(!h)return[];var p=o[h.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],m={},v=0;v<g.length;v++){var y,x=g[v],b=l[x][h.index],_=s.c2p(b,!0);b in m?(y=m[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},h)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",f.push(y),m[b]=y)}return f}function h(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,f=a[0].t,h=u(t,e,r,i);if(!h)return[];var p=a[h.index],d=h.index=p.i,g=p.dir;function m(t){return f.labels[t]+n.hoverLabelText(o,l[t][d])}var v=p.hi||l.hoverinfo,y=v.split(\"+\"),x=\"all\"===v,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[m(\"open\"),m(\"high\"),m(\"low\"),m(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),h.extraText=w.join(\"<br>\"),h.y0=h.y1=o.c2p(p.yc,!0),[h]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?f(t,e,r,n):h(t,e,r,n)},hoverSplit:f,hoverOnPoints:h}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../constants/delta.js\":747,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1137:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":841,\"./attributes\":1133,\"./calc\":1134,\"./defaults\":1135,\"./hover\":1136,\"./plot\":1139,\"./select\":1140,\"./style\":1141}],1138:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var f=Math.min(s.length,l.length,c.length,u.length);return o&&(f=Math.min(f,i.minRowLength(o))),e._length=f,f}}},{\"../../lib\":778,\"../../registry\":911}],1139:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.yaxis,s=e.xaxis,l=!!s.rangebreaks;i.makeTraceGroups(a,r,\"trace ohlc\").each((function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var c=a.tickLen,u=e.selectAll(\"path\").data(i.identity);u.enter().append(\"path\"),u.exit().remove(),u.attr(\"d\",(function(t){if(t.empty)return\"M0,0Z\";var e=s.c2p(t.pos-c,!0),r=s.c2p(t.pos+c,!0),n=l?(e+r)/2:s.c2p(t.pos,!0);return\"M\"+e+\",\"+o.c2p(t.o,!0)+\"H\"+n+\"M\"+n+\",\"+o.c2p(t.h,!0)+\"V\"+o.c2p(t.l,!0)+\"M\"+r+\",\"+o.c2p(t.c,!0)+\"H\"+n}))}}))}},{\"../../lib\":778,d3:169}],1140:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1141:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each((function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}}))}))}},{\"../../components/color\":643,\"../../components/drawing\":665,d3:169}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1143:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":865,\"./plot\":1148}],1144:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=t(\"fast-isnumeric\");function u(t,e,r){t.valueInds.push(e),t.count+=r}function f(t,e,r){return{categoryInds:t,color:e,rawColor:r,valueInds:[],count:0}}function h(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var p,d,g,m=r.map((function(t){var e;if(\"trace\"===t.categoryorder)e=null;else if(\"array\"===t.categoryorder)e=t.categoryarray;else{e=o(t.values);for(var r=!0,n=0;n<e.length;n++)if(!c(e[n])){r=!1;break}e.sort(r?l.sorterAsc:void 0),\"category descending\"===t.categoryorder&&(e=e.reverse())}return function(t,e){e=null==e?[]:e.map((function(t){return t}));var r={},n={},i=[];e.forEach((function(t,e){r[t]=0,n[t]=e}));for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map((function(t){return r[t]}));return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)}));p=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map((function(t){return t.displayindex}))))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach((function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,m[e])}));var v,y=e.line;y?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),v=s.tryColorscale(y)):v=l.identity;var x,b,_,w,T,k=r[0].values.length,M={},A=m.map((function(t){return t.inds}));for(g=0,x=0;x<k;x++){var S=[];for(b=0;b<A.length;b++)S.push(A[b][x]);d=p[x%p.length],g+=d;var E=(_=x,w=void 0,T=void 0,l.isArrayOrTypedArray(y.color)?T=w=y.color[_%y.color.length]:w=y.color,{color:v(w),rawColor:T}),C=S+\"-\"+E.rawColor;void 0===M[C]&&(M[C]=f(S,E.color,E.rawColor)),h(M[C],x,d)}var L,I=r.map((function(t,e){return function(t,e,r,n,i){return{dimensionInd:t,containerInd:e,displayInd:r,dimensionLabel:n,count:i,categories:[],dragX:null}}(e,t._index,t._displayindex,t.label,g)}));for(x=0;x<k;x++)for(d=p[x%p.length],b=0;b<I.length;b++){var P=I[b].containerInd,z=m[b].inds[x],O=I[b].categories;if(void 0===O[z]){var D=e.dimensions[P]._categoryarray[z],R=e.dimensions[P]._ticktext[z];O[z]={dimensionInd:b,categoryInd:L=z,categoryValue:D,displayInd:L,categoryLabel:R,valueInds:[],count:0,dragY:null}}u(O[z],x,d)}return n(function(t,e,r){var n=t.map((function(t){return t.categories.length})).reduce((function(t,e){return Math.max(t,e)}));return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(I,M,g))}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/filter_unique.js\":769,\"../../lib/gup\":775,\"fast-isnumeric\":241}],1145:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,f,h);o(e,f,h),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),h(\"hoveron\"),h(\"hovertemplate\"),h(\"arrangement\"),h(\"bundlecolors\"),h(\"sortpaths\"),h(\"counts\");var g={family:f.font.family,size:Math.round(f.font.size),color:f.font.color};n.coerceFont(h,\"labelfont\",g);var m={family:f.font.family,size:Math.round(f.font.size/1.2),color:f.font.color};n.coerceFont(h,\"tickfont\",m)}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/domain\":855,\"../parcoords/merge_length\":1158,\"./attributes\":1142}],1146:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1142,\"./base_plot\":1143,\"./calc\":1144,\"./defaults\":1145,\"./plot\":1148}],1147:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../components/drawing\"),c=t(\"tinycolor2\"),u=t(\"../../lib/svg_text_utils\");function f(t,e,r,i){var a=t.map(R.bind(0,e,r)),c=i.selectAll(\"g.parcatslayer\").data([null]);c.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var f=c.selectAll(\"g.trace.parcats\").data(a,h),v=f.enter().append(\"g\").attr(\"class\",\"trace parcats\");f.attr(\"transform\",(function(t){return s(t.x,t.y)})),v.append(\"g\").attr(\"class\",\"paths\");var y=f.select(\"g.paths\").selectAll(\"path.path\").data((function(t){return t.paths}),h);y.attr(\"fill\",(function(t){return t.model.color}));var _=y.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",0);b(_),y.attr(\"d\",(function(t){return t.svgD})),_.empty()||y.sort(d),y.exit().remove(),y.on(\"mouseover\",g).on(\"mouseout\",m).on(\"click\",x),v.append(\"g\").attr(\"class\",\"dimensions\");var k=f.select(\"g.dimensions\").selectAll(\"g.dimension\").data((function(t){return t.dimensions}),h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",(function(t){return s(t.x,0)})),k.exit().remove();var M=k.selectAll(\"g.category\").data((function(t){return t.categories}),h),A=M.enter().append(\"g\").attr(\"class\",\"category\");M.attr(\"transform\",(function(t){return s(0,t.y)})),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),M.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),w(A);var S=M.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h);S.each((function(){o.raiseToTop(this)})),S.attr(\"fill\",(function(t){return t.color}));var z=S.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);S.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})).attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"})),T(z),S.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var O=e._fullLayout.paper_bgcolor;M.select(\"text.catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",O+\" -1px  1px 2px, \"+O+\" 1px  1px 2px, \"+O+\"  1px -1px 2px, \"+O+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",(function(t){return p(t)?t.width+5:-5})).attr(\"y\",(function(t){return t.height/2})).text((function(t){return t.model.categoryLabel})).each((function(t){l.font(n.select(this),t.parcatsViewModel.categorylabelfont),u.convertToTspans(n.select(this),e)})),A.append(\"text\").attr(\"class\",\"dimlabel\"),M.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"})).attr(\"x\",(function(t){return t.width/2})).attr(\"y\",-5).text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})).each((function(t){l.font(n.select(this),t.parcatsViewModel.labelfont)})),M.selectAll(\"rect.bandrect\").on(\"mouseover\",E).on(\"mouseout\",C),M.exit().remove(),k.call(n.behavior.drag().origin((function(t){return{x:t.x,y:0}})).on(\"dragstart\",L).on(\"drag\",I).on(\"dragend\",P)),f.each((function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")})),f.exit().remove()}function h(t){return t.key}function p(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function d(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function g(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),_(n.select(this));var e=v(t),r=y(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event,constraints:r}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var i,s,l,u=n.mouse(this)[0],f=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,p=f._fullLayout,d=p._paperdiv.node().getBoundingClientRect(),g=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(l=0;l<t.leftXs.length-1;l++)if(t.leftXs[l]+t.dimWidths[l]-2<=u&&u<=t.leftXs[l+1]+2){var m=t.parcatsViewModel.dimensions[l],x=t.parcatsViewModel.dimensions[l+1];i=(m.x+m.width+x.x)/2,s=(t.topYs[l]+t.topYs[l+1]+t.height)/2;break}var b=t.parcatsViewModel.x+i,w=t.parcatsViewModel.y+s,T=c.mostReadable(t.model.color,[\"black\",\"white\"]),k=t.model.count,M=k/t.parcatsViewModel.model.count,A={countLabel:k,probabilityLabel:M.toFixed(3)},S=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&S.push([\"Count:\",A.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&S.push([\"P:\",A.probabilityLabel].join(\" \"));var E=S.join(\"<br>\"),C=n.mouse(f)[0];a.loneHover({trace:h,x:b-d.left+g.left,y:w-d.top+g.top,text:E,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:T,idealAlign:C<b?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:A,eventData:[{data:h._input,fullData:h,count:k,probability:M}]},{container:p._hoverlayer.node(),outerContainer:p._paper.node(),gd:f})}}}function m(t){if(!t.parcatsViewModel.dragDimension&&(b(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(d),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event,constraints:r})}}function v(t){for(var e=[],r=z(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function y(t){for(var e={},r=t.parcatsViewModel.model.dimensions,n=0;n<r.length;n++){var i=r[n],a=i.categories[t.model.categoryInds[n]];e[i.containerInd]=a.categoryValue}return void 0!==t.model.rawColor&&(e.color=t.model.rawColor),e}function x(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event,constraints:r})}}function b(t){t.attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",(function(t){return c.mostReadable(t.model.color,[\"black\",\"white\"])})).attr(\"stroke-width\",.3)}function w(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function T(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function k(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter((function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color}))}function M(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=n.select(t.parentNode).selectAll(\"rect.bandrect\"),l=[];s.each((function(t){k(t).each((function(t){Array.prototype.push.apply(l,v(t))}))}));var c={};c[a.dimensionInd]=a.categoryValue,o.emit(e,{points:l,event:r,constraints:c})}function A(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=k(i),l=[];s.each((function(t){Array.prototype.push.apply(l,v(t))}));var c={};c[a.dimensionInd]=a.categoryValue,void 0!==i.rawColor&&(c.color=i.rawColor),o.emit(e,{points:l,event:r,constraints:c})}function S(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=n.select(r.parentNode).select(\"rect.catrect\"),c=l.node().getBoundingClientRect(),u=l.datum(),f=u.parcatsViewModel,h=f.model.dimensions[u.model.dimensionInd],p=f.trace,d=c.top+c.height/2;f.dimensions.length>1&&h.displayInd===f.dimensions.length-1?(i=c.left,a=\"left\"):(i=c.left+c.width,a=\"right\");var g=u.model.count,m=u.model.categoryLabel,v=g/u.parcatsViewModel.model.count,y={countLabel:g,categoryLabel:m,probabilityLabel:v.toFixed(3)},x=[];-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&x.push([\"Count:\",y.countLabel].join(\" \")),-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&x.push([\"P(\"+y.categoryLabel+\"):\",y.probabilityLabel].join(\" \"));var b=x.join(\"<br>\");return{trace:p,x:o*(i-e.left),y:s*(d-e.top),text:b,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:a,hovertemplate:p.hovertemplate,hovertemplateLabels:y,eventData:[{data:p._input,fullData:p,count:g,category:m,probability:v}]}}function E(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),l=t.parcatsViewModel.hoveron;if(\"color\"===l?(!function(t){var e=n.select(t).datum(),r=k(e);_(r),r.each((function(){o.raiseToTop(this)})),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter((function(t){return t.color===e.color})).each((function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)}))}(this),A(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each((function(t){var e=k(t);_(e),e.each((function(){o.raiseToTop(this)}))})),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),M(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===l?e=S(r,s,this):\"color\"===l?e=function(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=r.getBoundingClientRect(),u=n.select(r).datum(),f=u.categoryViewModel,h=f.parcatsViewModel,p=h.model.dimensions[f.model.dimensionInd],d=h.trace,g=l.y+l.height/2;h.dimensions.length>1&&p.displayInd===h.dimensions.length-1?(i=l.left,a=\"left\"):(i=l.left+l.width,a=\"right\");var m=f.model.categoryLabel,v=u.parcatsViewModel.model.count,y=0;u.categoryViewModel.bands.forEach((function(t){t.color===u.color&&(y+=t.count)}));var x=f.model.count,b=0;h.pathSelection.each((function(t){t.model.color===u.color&&(b+=t.model.count)}));var _=y/v,w=y/b,T=y/x,k={countLabel:v,categoryLabel:m,probabilityLabel:_.toFixed(3)},M=[];-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&M.push([\"Count:\",k.countLabel].join(\" \")),-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(M.push(\"P(color \\u2229 \"+m+\"): \"+k.probabilityLabel),M.push(\"P(\"+m+\" | color): \"+w.toFixed(3)),M.push(\"P(color | \"+m+\"): \"+T.toFixed(3)));var A=M.join(\"<br>\"),S=c.mostReadable(u.color,[\"black\",\"white\"]);return{trace:d,x:o*(i-e.left),y:s*(g-e.top),text:A,color:u.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:S,fontSize:10,idealAlign:a,hovertemplate:d.hovertemplate,hovertemplateLabels:k,eventData:[{data:d._input,fullData:d,category:m,count:v,probability:_,categorycount:x,colorcount:b,bandcolorcount:y}]}}(r,s,this):\"dimension\"===l&&(e=function(t,e,r){var i=[];return n.select(r.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each((function(){i.push(S(t,e,this))})),i}(r,s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function C(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(b(e.pathSelection),w(e.dimensionSelection.selectAll(\"g.category\")),T(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(d),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?A(this,\"plotly_unhover\",n.event):M(this,\"plotly_unhover\",n.event)}}function L(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each((function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map((function(t){return t.displayInd})),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each((function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)})))})),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function I(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],f=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==f&&s+o.height>f.y+f.height/2&&(o.model.displayInd=f.model.displayInd,f.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var h=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==h&&a.model.dragX<h.x+h.width&&(a.model.displayInd=h.model.displayInd,h.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}N(t.parcatsViewModel),B(t.parcatsViewModel),D(t.parcatsViewModel),O(t.parcatsViewModel)}}function P(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=z(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),o=t.initialDragDimensionDisplayInds.some((function(t,e){return t!==a[e]}));o&&a.forEach((function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r}));var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map((function(t){return t.displayInd}));if(s=t.initialDragCategoryDisplayInds.some((function(t,e){return t!==l[e]}))){var c=t.model.categories.slice().sort((function(t,e){return t.displayInd-e.displayInd})),u=c.map((function(t){return t.categoryValue})),f=c.map((function(t){return t.categoryLabel}));e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[f],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?A(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):M(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,N(t.parcatsViewModel),B(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each((function(){D(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)})).each(\"end\",(function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])}))}}function z(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data((function(t){return t.paths}),h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",(function(t){return t.svgD}))}function D(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data((function(t){return t.dimensions}),h);var i=t.dimensionSelection.selectAll(\"g.category\").data((function(t){return t.categories}),h);r(t.dimensionSelection).attr(\"transform\",(function(t){return s(t.x,0)})),r(i).attr(\"transform\",(function(t){return s(0,t.y)})),i.select(\".dimlabel\").text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})),i.select(\".catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"x\",(function(t){return p(t)?t.width+5:-5})).each((function(t){var e,r;p(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)}));var a=i.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h),l=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);a.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})),T(l),a.each((function(){o.raiseToTop(this)})),a.exit().remove()}function R(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),f=Math.floor(c*(s.y[1]-s.y[0])),h=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:h,y:p,width:u,height:f,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};return i.dimensions&&(N(g),B(g)),g}function F(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function B(t){var e=t.dimensions,r=t.model,n=e.map((function(t){return t.categories.map((function(t){return t.y}))})),i=t.model.dimensions.map((function(t){return t.categories.map((function(t){return t.displayInd}))})),a=t.model.dimensions.map((function(t){return t.displayInd})),o=t.dimensions.map((function(t){return t.model.dimensionInd})),s=e.map((function(t){return t.x})),l=e.map((function(t){return t.width})),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function f(t){var e=t.categoryInds.map((function(t,e){return i[e][t]}));return o.map((function(t){return e[t]}))}c.sort((function(e,r){var n=f(e),i=f(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0}));for(var h=new Array(c.length),p=e[0].model.count,d=e[0].categories.map((function(t){return t.height})).reduce((function(t,e){return t+e})),g=0;g<c.length;g++){var m,v=c[g];m=p>0?d*(v.count/p):0;for(var y,x=new Array(n.length),b=0;b<v.categoryInds.length;b++){var _=v.categoryInds[b],w=i[b][_],T=a[b];x[T]=n[T][w],n[T][w]+=m;var k=t.dimensions[T].categories[w],M=k.bands.length,A=k.bands[M-1];if(void 0===A||v.rawColor!==A.rawColor){var S=void 0===A?0:A.y+A.height;k.bands.push({key:S,color:v.color,rawColor:v.rawColor,height:m,width:k.width,count:v.count,y:S,categoryViewModel:k,parcatsViewModel:t})}else{var E=k.bands[M-1];E.height+=m,E.count+=v.count}}y=\"hspline\"===t.pathShape?F(s,x,l,m,.5):F(s,x,l,m,0),h[g]={key:v.valueInds[0],model:v,height:m,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=h}function N(t){var e=t.model.dimensions.map((function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}}));e.sort((function(t,e){return t.displayInd-e.displayInd}));var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(j(t,a))}t.dimensions=r}function j(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],f=t.model.maxCats,h=e.categories.length,p=e.count,d=t.height-8*(f-1),g=8*(f-h)/2,m=e.categories.map((function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}}));for(m.sort((function(t,e){return t.displayInd-e.displayInd})),c=0;c<h;c++)l=m[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){f(r,t,n,e)}},{\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_api\":814,d3:169,tinycolor2:576}],1148:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1147}],1149:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1150:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=t(\"../../lib\").strTranslate,c=n.bar.snapRatio;function u(t,e){return t*(1-c)+e*c}var f=n.bar.snapClose;function h(t,e){return t*(1-f)+e*f}function p(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],c=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return u(l,c);if(i*r<i*d||p===o)return u(d,l);c=l,l=d}}function d(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function g(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function m(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map((function(t){return t.map((function(t){return Math.max(0,t*e)})).sort(s)}))}function y(){i.select(document.body).style(\"cursor\",null)}function x(t){t.attr(\"stroke-dasharray\",m)}function b(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");x(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function _(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,f=NaN,h=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(f=r?r-1:NaN,p&&p[0]>e){h=r;break}}if(a=u,isNaN(a)&&(a=isNaN(f)||isNaN(h)?isNaN(f)?h:f:e-c[f][1]<c[h][0]-e?f:h),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function w(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),b(t.parentNode)}function T(t,e){var r=_(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",(function(t){i.event.preventDefault(),t.parent.inBrushDrag||T(this,t)})).on(\"mouseleave\",(function(t){t.parent.inBrushDrag||y()})).call(i.behavior.drag().on(\"dragstart\",(function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=_(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter((function(t){return t[0]!==l[0]&&t[1]!==l[1]}))),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)})).on(\"drag\",(function(t){w(this,t)})).on(\"dragend\",(function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(T(t,e),w(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,y(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),b(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[p(0,l,a.newExtent[0],a.stayingIntervals),p(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?b(t.parentNode,s):(s(),b(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)})))}function M(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function S(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return 1===n.length&&n[0][0]>n[0][1]&&(n=[]),n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map((function(t){return t.slice().sort(s)})).sort(M)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=S(r),e=r.reduce((function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]}),[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map((function(t){return t.slice()}))}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(d).call(g).style(\"pointer-events\",\"auto\").attr(\"transform\",l(0,n.verticalPadding)),e.call(k).attr(\"height\",(function(t){return t.height-n.verticalPadding}));var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",(function(t){return t.height})).call(x);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",(function(t){return t.height})).call(x)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map((function(t){return t.sort(s)})),t=e.multiselect?S(t.sort(M)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map((function(t){var e=[p(0,r,t[0],[]),p(1,r,t[1],[])];if(e[1]>e[0])return e})).filter((function(t){return t}))).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":778,\"../../lib/gup\":775,\"./constants\":1153,d3:169}],1151:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})),window.setTimeout((function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")}),60)}},{\"../../constants/xmlns_namespaces\":754,\"../../plots/get_data\":865,\"./plot\":1160,d3:169}],1152:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gup\":775}],1153:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1154:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),f=t(\"./constants\").maxDimensionCount,h=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var f=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:f},l.setConvert(e._ax,i.layout),a(\"multiselect\");var h=a(\"constraintrange\");h&&(e.constraintrange=u.cleanRanges(h,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>f&&(n.log(\"parcoords traces support up to \"+f+\" dimensions at the moment\"),d.splice(f));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),m=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),h(e,g,\"values\",m);var v={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",v),n.coerceFont(u,\"tickfont\",v),n.coerceFont(u,\"rangefont\",v),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"../../plots/domain\":855,\"./attributes\":1149,\"./axisbrush\":1150,\"./constants\":1153,\"./merge_length\":1158}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":778}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1149,\"./base_plot\":1151,\"./calc\":1152,\"./defaults\":1154,\"./plot\":1160}],1157:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=new Uint8Array(4),c=new Uint8Array(4),u={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function f(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function h(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:l})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],f(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame((function(){s(l+1)}))),r.drawCompleted=!1)}(0)}function p(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}function d(t,e){return(t>>>8*e)%256/255}function g(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function v(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function y(t,e,r,n,i,a,o,l,c,u,f,h,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var m=t.lines.canvasOverdrag,v=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:f,resolution:[y,x],viewBoxPos:[o+m,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:h,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+m)+(t.pad.l-m)+t.layoutWidth*v.x[0],scissorWidth:(n===r?y-o+m:c+.5)+(n===e?o+m:0),scissorY:l+t.pad.b+t.layoutHeight*v.y[0],scissorHeight:u,viewportX:t.pad.l-m+t.layoutWidth*v.x[0],viewportY:t.pad.b+t.layoutHeight*v.y[0],viewportWidth:y,viewportHeight:x},p)}function x(t){var e=Math.max(0,Math.floor(2047*t[0]),0),r=Math.min(2047,Math.ceil(2047*t[1]),2047);return[Math.min(e,r),Math.max(e,r)]}e.exports=function(t,e){var r,n,l,m,b,_=e.context,w=e.pick,T=e.regl,k={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[v(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),A=T.texture(u),S=[];C(e);var E=T({profile:!1,blend:{enable:_,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!_,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:A,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function C(t){r=t.model,n=t.viewModel,l=n.dimensions.slice(),m=l[0]?l[0].values.length:0;var e=r.lines,i=w?e.color.map((function(t,r){return r/e.color.length})):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var l=0;l<o;l++)i[a++]=l<e.length?e[l].paddedUnitValues[s]:.5;i[a++]=d(s,2),i[a++]=d(s,1),i[a++]=d(s,0),i[a++]=(n=r[s],Math.max(1e-6,Math.min(.999999,n)))}return i}(m,l,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[v(n)](g(n/4,e,r))}(M,m,a),_||w||(A=T.texture(s.extendFlat({data:p(r.unitToColor,255)},u)))}return{render:function(t,e,n){var i,a,o,s=t.length,c=1/0,u=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<c&&(c=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>u&&(u=t[i].dim1.canvasX,o=i);0===s&&f(T,0,0,r.canvasWidth,r.canvasHeight);var p=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<l.length?l[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=new Array(16384);for(e=0;e<16384;e++)o[e]=255;if(!t)for(e=0;e<l.length;e++){var s=e%8,c=(e-s)/8,u=Math.pow(2,s),f=l[e].brush.filter.get();if(!(f.length<2)){var h=x(f[0])[1];for(r=1;r<f.length;r++){var p=x(f[r]);for(n=h+1;n<p[0];n++)o[8*n+c]&=~u;h=Math.max(h,p[1])}}}var d={shape:[8,2048],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:o};return b?b(d):b=T.texture(d),{maskTexture:b,maskHeight:2048,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(_);for(i=0;i<s;i++){var d=t[i],g=d.dim0.crossfilterDimensionIndex,v=d.dim1.crossfilterDimensionIndex,M=d.canvasX,A=d.canvasY,C=M+d.panelSizeX;if(e||!S[g]||S[g][0]!==M||S[g][1]!==C){S[g]=[M,C];var L=y(r,a,o,i,g,v,M,A,d.panelSizeX,d.panelSizeY,d.dim0.crossfilterDimensionIndex,_?0:w?2:1,p);k.clearOnly=n;var I=e?r.lines.blockLineCount:m;h(T,E,k,I,m,L)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:c}),c},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",A.destroy(),b&&b.destroy(),M)M[e].destroy()},update:C}}},{\"../../lib\":778,\"./constants\":1153,glslify:439}],1158:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/drawing\"),f=t(\"../../components/colorscale\"),h=t(\"../../lib/gup\"),p=h.keyFun,d=h.repeat,g=h.unwrap,m=t(\"./helpers\"),v=t(\"./constants\"),y=t(\"./axisbrush\"),x=t(\"./lines\");function b(t,e,r){return o.aggNums(t,null,e,r)}function _(t,e){return T(b(Math.min,t,e),b(Math.max,t,e))}function w(t){var e=t.range;return e?T(e[0],e[1]):_(t.values,t._length)}function T(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function k(t,e,r,i,a){var o,s,l=w(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map((function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)}))):n.scale.linear().domain(l).range([t-e,e])}function M(t){if(t.tickvals){var e=w(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map((function(t){return(t-e[0])/(e[1]-e[0])})))}}function A(t){var e=t.map((function(t){return t[0]})),r=t.map((function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")})),a=\"rgb\".split(\"\").map((function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i}));return function(t){return a.map((function(e){return e(t)}))}}function S(t){return t.dimensions.some((function(t){return t.brush.filterSpecified}))}function E(t,e,r){var a=g(e),s=a.trace,l=m.convertTypedArray(a.lineColor),c=s.line,u={color:i(v.deselectedLineColor)},h=f.extractOpts(c),p=h.reversescale?f.flipScale(a.cscale):a.cscale,d=s.domain,y=s.dimensions,x=t.width,b=s.labelangle,_=s.labelside,T=s.labelfont,k=s.tickfont,M=s.rangefont,S=o.extendDeepNoArrays({},c,{color:l.map(n.scale.linear().domain(w({values:l,range:[h.min,h.max],_length:s._length}))),blockLineCount:v.blockLineCount,canvasOverdrag:v.overdrag*v.canvasPixelRatio}),E=Math.floor(x*(d.x[1]-d.x[0])),C=Math.floor(t.height*(d.y[1]-d.y[0])),L=t.margin||{l:80,r:80,t:100,b:80},I=E,P=C;return{key:r,colCount:y.filter(m.isVisible).length,dimensions:y,tickDistance:v.tickDistance,unitToColor:A(p),lines:S,deselectedLines:u,labelAngle:b,labelSide:_,labelFont:T,tickFont:k,rangeFont:M,layoutWidth:x,layoutHeight:t.height,domain:d,translateX:d.x[0]*x,translateY:t.height-d.y[1]*t.height,pad:L,canvasWidth:I*v.canvasPixelRatio+2*S.canvasOverdrag,canvasHeight:P*v.canvasPixelRatio,width:I,height:P,canvasPixelRatio:v.canvasPixelRatio}}function C(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=v.verticalPadding/a,f=function(t,e){return n.scale.linear().range([e,t-e])}(a,v.verticalPadding),h={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return h.dimensions=s.filter(m.isVisible).map((function(i,s){var d=function(t,e){return n.scale.linear().domain(w(t)).range([e,1-e])}(i,u),g=p[i.label];p[i.label]=(g||0)+1;var x=i.label+(g?\"__\"+g:\"\"),b=i.constraintrange,_=b&&b.length;_&&!Array.isArray(b[0])&&(b=[b]);var T=_?b.map((function(t){return t.map(d)})):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var E,C=i.tickvals;function L(t,e){return{val:t,text:E[e]}}function I(t,e){return t.val-e.val}if(Array.isArray(C)&&C.length){E=i.ticktext,Array.isArray(E)&&E.length?E.length>C.length?E=E.slice(0,C.length):C.length>E.length&&(C=C.slice(0,E.length)):E=C.map(n.format(i.tickformat));for(var P=1;P<C.length;P++)if(C[P]<C[P-1]){for(var z=C.map(L).sort(I),O=0;O<C.length;O++)C[O]=z[O].val,E[O]=z[O].text;break}}else C=void 0;return A=m.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:C,ticktext:E,ordinal:m.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(d),unitTickvals:C&&C.map(d),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:f,domainScale:k(a,v.verticalPadding,i,C,E),ordinalScale:M(i),parent:h,model:r,brush:y.makeBrush(t,_,T,(function(){t.linePickActive(!1)}),(function(){var e=h;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=S(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))}),(function(r){if(h.focusLayer.render(h.panels,!0),h.pickLayer&&h.pickLayer.render(h.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=d.invert,a=r.map((function(t){return t.map(n).sort(o.sorterAsc)})).sort((function(t,e){return t[0]-e[0]}));e.filterChanged(h.key,i._index,a)}}))}})),h}function L(t){t.classed(v.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\")}function I(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function P(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function z(t,e){return a.tickText(t._ax,e,!1).text}function O(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return z(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var f=t._fullLayout,h=f._toppaper,b=f._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=T(l.range[0],l.range[1]):l.range=_(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var w,k,M=(w=!0,k=!1,{linePickActive:function(t){return arguments.length?w=!!t:w},contextShown:function(t){return arguments.length?k=!!t:k}}),A=e.filter((function(t){return g(t).trace.visible})).map(E.bind(0,r)).map(C.bind(0,M,i));b.each((function(t,e){return o.extendFlat(t,A[e])}));var D=b.selectAll(\".gl-canvas\").each((function(t){t.viewModel=A[0],t.model=t.viewModel?t.viewModel.model:null})),R=null;D.filter((function(t){return t.pick})).style(\"pointer-events\",\"auto\").on(\"mousemove\",(function(t){if(M.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],f=u?c[2]+256*(c[1]+256*c[0]):null,h={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:f};f!==R&&(u?i.hover(h):i.unhover&&i.unhover(h),R=f)}})),D.style(\"opacity\",(function(t){return t.pick?0:1})),h.style(\"background\",\"rgba(255, 255, 255, 0)\");var F=h.selectAll(\".\"+v.cn.parcoords).data(A,p);F.exit().remove(),F.enter().append(\"g\").classed(v.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),F.attr(\"transform\",(function(t){return l(t.model.translateX,t.model.translateY)}));var B=F.selectAll(\".\"+v.cn.parcoordsControlView).data(d,p);B.enter().append(\"g\").classed(v.cn.parcoordsControlView,!0),B.attr(\"transform\",(function(t){return l(t.model.pad.l,t.model.pad.t)}));var N=B.selectAll(\".\"+v.cn.yAxis).data((function(t){return t.dimensions}),p);N.enter().append(\"g\").classed(v.cn.yAxis,!0),B.each((function(t){P(N,t)})),D.each((function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=x(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}})),N.attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),N.call(n.behavior.drag().origin((function(t){return t})).on(\"drag\",(function(t){var e=t.parent;M.linePickActive(!1),t.x=Math.max(-v.overdrag,Math.min(t.model.width+v.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,N.sort((function(t,e){return t.x-e.x})).each((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio})),P(N,e),N.filter((function(e){return 0!==Math.abs(t.xIndex-e.xIndex)})).attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),n.select(this).attr(\"transform\",l(t.x,0)),N.each((function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)})).on(\"dragend\",(function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,P(N,e),n.select(this).attr(\"transform\",(function(t){return l(t.x,0)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),M.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map((function(t){return t.crossfilterDimensionIndex})))}))),N.exit().remove();var j=N.selectAll(\".\"+v.cn.axisOverlays).data(d,p);j.enter().append(\"g\").classed(v.cn.axisOverlays,!0),j.selectAll(\".\"+v.cn.axis).remove();var U=j.selectAll(\".\"+v.cn.axis).data(d,p);U.enter().append(\"g\").classed(v.cn.axis,!0),U.each((function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat((function(e){return m.isOrdinal(t)?e:z(t.model.dimensions[t.visibleIndex],e)})).scale(r)),u.font(U.selectAll(\"text\"),t.model.tickFont)})),U.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),U.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\");var V=j.selectAll(\".\"+v.cn.axisHeading).data(d,p);V.enter().append(\"g\").classed(v.cn.axisHeading,!0);var q=V.selectAll(\".\"+v.cn.axisTitle).data(d,p);q.enter().append(\"text\").classed(v.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"pointer-events\",\"auto\"),q.text((function(t){return t.label})).each((function(e){var r=n.select(this);u.font(r,e.model.labelFont),c.convertToTspans(r,t)})).attr(\"transform\",(function(t){var e=I(t.model.labelAngle,t.model.labelSide),r=v.axisTitleOffset;return(e.dir>0?\"\":l(0,2*r+t.model.height))+s(e.degrees)+l(-r*e.dx,-r*e.dy)})).attr(\"text-anchor\",(function(t){var e=I(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"}));var H=j.selectAll(\".\"+v.cn.axisExtent).data(d,p);H.enter().append(\"g\").classed(v.cn.axisExtent,!0);var G=H.selectAll(\".\"+v.cn.axisExtentTop).data(d,p);G.enter().append(\"g\").classed(v.cn.axisExtentTop,!0),G.attr(\"transform\",l(0,-v.axisExtentOffset));var Y=G.selectAll(\".\"+v.cn.axisExtentTopText).data(d,p);Y.enter().append(\"text\").classed(v.cn.axisExtentTopText,!0).call(L),Y.text((function(t){return O(t,!0)})).each((function(t){u.font(n.select(this),t.model.rangeFont)}));var W=H.selectAll(\".\"+v.cn.axisExtentBottom).data(d,p);W.enter().append(\"g\").classed(v.cn.axisExtentBottom,!0),W.attr(\"transform\",(function(t){return l(0,t.model.height+v.axisExtentOffset)}));var X=W.selectAll(\".\"+v.cn.axisExtentBottomText).data(d,p);X.enter().append(\"text\").classed(v.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(L),X.text((function(t){return O(t,!1)})).each((function(t){u.font(n.select(this),t.model.rangeFont)})),y.ensureAxisBrush(j)}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"./axisbrush\":1150,\"./constants\":1153,\"./helpers\":1155,\"./lines\":1157,\"color-rgba\":127,d3:169}],1160:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},f=r._size;e.forEach((function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()}));n(t,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map((function(t){return t.slice()})),s=\"dimensions[\"+n+\"].constraintrange\",f=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===f[s]){var h=a.constraintrange;f[s]=h||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter((function(t){return!a(t)})).sort((function(t){return l[e].indexOf(t)})).forEach((function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)})),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":791,\"./helpers\":1155,\"./parcoords\":1159}],1161:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/template_attributes\").texttemplateAttrs,c=t(\"../../lib/extend\").extendFlat,u=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:c({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),texttemplate:l({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:c({},u,{}),insidetextorientation:{valType:\"enumerated\",values:[\"horizontal\",\"radial\",\"tangential\",\"auto\"],dflt:\"auto\",editType:\"plot\"},insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),automargin:{valType:\"boolean\",dflt:!1,editType:\"plot\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:c({},u,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:c({},u,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1162:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"pie\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../components/color\"),o={};function s(t){return function(e,r){return!!e&&(!!(e=i(e)).isValid()&&(e=a.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function l(t,e){var r,n=JSON.stringify(t),a=e[n];if(!a){for(a=t.slice(),r=0;r<t.length;r++)a.push(i(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)a.push(i(t[r]).darken(20).toHexString());e[n]=a}return a}e.exports={calc:function(t,e){var r,i,a=[],o=t._fullLayout,l=o.hiddenlabels||[],c=e.labels,u=e.marker.colors||[],f=e.values,h=e._length,p=e._hasValues&&h;if(e.dlabel)for(c=new Array(h),r=0;r<h;r++)c[r]=String(e.label0+r*e.dlabel);var d={},g=s(o[\"_\"+e.type+\"colormap\"]),m=0,v=!1;for(r=0;r<h;r++){var y,x,b;if(p){if(y=f[r],!n(y))continue;if((y=+y)<0)continue}else y=1;void 0!==(x=c[r])&&\"\"!==x||(x=r);var _=d[x=String(x)];void 0===_?(d[x]=a.length,(b=-1!==l.indexOf(x))||(m+=y),a.push({v:y,label:x,color:g(u[r],x),i:r,pts:[r],hidden:b})):(v=!0,(i=a[_]).v+=y,i.pts.push(r),i.hidden||(m+=y),!1===i.color&&u[r]&&(i.color=g(u[r],x)))}return(\"funnelarea\"===e.type?v:e.sort)&&a.sort((function(t,e){return e.v-t.v})),a[0]&&(a[0].vTotal=m),a},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],s=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=l(a,o));for(var c=0,u=0;u<i.length;u++){var f=i[u];if(f[0].trace.type===r)for(var h=0;h<f.length;h++){var p=f[h];!1===p.color&&(s[p.label]?p.color=s[p.label]:(s[p.label]=p.color=a[c%a.length],c++))}}},makePullColorFn:s,generateExtendedColors:l}},{\"../../components/color\":643,\"fast-isnumeric\":241,tinycolor2:576}],1164:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./attributes\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText;function l(t,e){var r=Array.isArray(t),a=i.isArrayOrTypedArray(e),o=Math.min(r?t.length:1/0,a?e.length:1/0);if(isFinite(o)||(o=0),o&&a){for(var s,l=0;l<o;l++){var c=e[l];if(n(c)&&c>0){s=!0;break}}s||(o=0)}return{hasLabels:r,hasValues:a,len:o}}e.exports={handleLabelsAndValues:l,supplyDefaults:function(t,e,r,n){function c(r,n){return i.coerce(t,e,a,r,n)}var u=l(c(\"labels\"),c(\"values\")),f=u.len;if(e._hasLabels=u.hasLabels,e._hasValues=u.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),f){e._length=f,c(\"marker.line.width\")&&c(\"marker.line.color\"),c(\"marker.colors\"),c(\"scalegroup\");var h,p=c(\"text\"),d=c(\"texttemplate\");if(d||(h=c(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),d||h&&\"none\"!==h){var g=c(\"textposition\");s(t,e,n,c,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),(Array.isArray(g)||\"auto\"===g||\"outside\"===g)&&c(\"automargin\"),(\"inside\"===g||\"auto\"===g||Array.isArray(g))&&c(\"insidetextorientation\")}o(e,n,c);var m=c(\"hole\");if(c(\"title.text\")){var v=c(\"title.position\",m?\"middle center\":\"top center\");m||\"middle center\"!==v||(e.title.position=\"top center\"),i.coerceFont(c,\"title.font\",n.font)}c(\"sort\"),c(\"direction\"),c(\"rotation\"),c(\"pull\")}else e.visible=!1}}},{\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"./attributes\":1161,\"fast-isnumeric\":241}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":679}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return-1!==t.indexOf(\"e\")?t.replace(/[.]?0+e/,\"e\"):-1!==t.indexOf(\".\")?t.replace(/[.]?0+$/,\"\"):t}r.formatPiePercent=function(t,e){var r=i((100*t).toPrecision(3));return n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=i(t.toPrecision(10));return n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n||\"\"===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0},r.getRotationAngle=function(t){return(\"auto\"===t?0:t)*Math.PI/180}},{\"../../lib\":778}],1167:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1161,\"./base_plot\":1162,\"./calc\":1163,\"./defaults\":1164,\"./layout_attributes\":1168,\"./layout_defaults\":1169,\"./plot\":1170,\"./style\":1171,\"./style_one\":1172}],1168:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":778,\"./layout_attributes\":1168}],1170:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=l.strScale,u=l.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../bar/uniform_text\"),p=h.recordMinTextSize,d=h.clearMinTextSize,g=t(\"../bar/constants\").TEXTPAD,m=t(\"./helpers\"),v=t(\"./event_data\"),y=t(\"../../lib\").isValidTextValue;function x(t,e,r){var i=r[0],o=i.trace,s=i.cx,c=i.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",(function(t){var r=e._fullLayout,u=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var f=u.hoverinfo;if(Array.isArray(f)&&(f=a.castHoverinfo({hoverinfo:[m.castOption(f,t.pts)],_module:o._module},r,0)),\"all\"===f&&(f=\"label+text+value+percent+name\"),u.hovertemplate||\"none\"!==f&&\"skip\"!==f&&f){var h=t.rInscribed||0,p=s+t.pxmid[0]*(1-h),d=c+t.pxmid[1]*(1-h),g=r.separators,y=[];if(f&&-1!==f.indexOf(\"label\")&&y.push(t.label),t.text=m.castOption(u.hovertext||u.text,t.pts),f&&-1!==f.indexOf(\"text\")){var x=t.text;l.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=m.formatPieValue(t.v,g),f&&-1!==f.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/i.vTotal,t.percentLabel=m.formatPiePercent(t.percent,g),f&&-1!==f.indexOf(\"percent\")&&y.push(t.percentLabel);var b=u.hoverlabel,_=b.font;a.loneHover({trace:o,x0:p-h*i.r,x1:p+h*i.r,y:d,text:y.join(\"<br>\"),name:u.hovertemplate||-1!==f.indexOf(\"name\")?u.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:m.castOption(b.bgcolor,t.pts)||t.color,borderColor:m.castOption(b.bordercolor,t.pts),fontFamily:m.castOption(_.family,t.pts),fontSize:m.castOption(_.size,t.pts),fontColor:m.castOption(_.color,t.pts),nameLength:m.castOption(b.namelength,t.pts),textAlign:m.castOption(b.align,t.pts),hovertemplate:m.castOption(u.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[v(t,u)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[v(t,u)],event:n.event})}})),t.on(\"mouseout\",(function(t){var r=e._fullLayout,i=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[v(s,i)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(a.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)})),t.on(\"click\",(function(t){var r=e._fullLayout,i=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[v(t,i)],a.click(e,n.event))}))}function b(t,e,r){var n=m.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=m.castOption(t._input.textfont.color,e.pts));var i=m.castOption(t.insidetextfont.family,e.pts)||m.castOption(t.textfont.family,e.pts)||r.family,a=m.castOption(t.insidetextfont.size,e.pts)||m.castOption(t.textfont.size,e.pts)||r.size;return{color:n||o.contrast(e.color),family:i,size:a}}function _(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=l.templateString(a,n._meta));var o=s.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(s.font,n.title.font).call(f.convertToTspans,e),c=s.bBox(o.node(),!0);r.titleBox={width:c.width,height:c.height},o.remove()}}function w(t,e,r){var n=r.r||e.rpx1,i=e.rInscribed;if(e.startangle===e.stopangle)return{rCenter:1-i,scale:0,rotate:0,textPosAngle:0};var a,o=e.ring,s=1===o&&Math.abs(e.startangle-e.stopangle)===2*Math.PI,l=e.halfangle,c=e.midangle,u=r.trace.insidetextorientation,f=\"horizontal\"===u,h=\"tangential\"===u,p=\"radial\"===u,d=\"auto\"===u,g=[];if(!d){var m,v=function(r,i){if(function(t,e){var r=t.startangle,n=t.stopangle;return r>e&&e>n||r<e&&e<n}(e,r)){var s=Math.abs(r-e.startangle),l=Math.abs(r-e.stopangle),c=s<l?s:l;(a=\"tan\"===i?k(t,n,o,c,0):T(t,n,o,c,Math.PI/2)).textPosAngle=r,g.push(a)}};if(f||h){for(m=4;m>=-4;m-=2)v(Math.PI*m,\"tan\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+1),\"tan\")}if(f||p){for(m=4;m>=-4;m-=2)v(Math.PI*(m+1.5),\"rad\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+.5),\"rad\")}}if(s||d||f){var y=Math.sqrt(t.width*t.width+t.height*t.height);if((a={scale:i*n*2/y,rCenter:1-i,rotate:0}).textPosAngle=(e.startangle+e.stopangle)/2,a.scale>=1)return a;g.push(a)}(d||p)&&((a=T(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(a)),(d||h)&&((a=k(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(a));for(var x=0,b=0,_=0;_<g.length;_++){var w=g[_].scale;if(b<w&&(b=w,x=_),!d&&b>=1)break}return g[x]}function T(t,e,r,n,i){e=Math.max(0,e-2*g);var a=t.width/t.height,o=S(a,n,e,r);return{scale:2*o/t.height,rCenter:M(a,o/e),rotate:A(i)}}function k(t,e,r,n,i){e=Math.max(0,e-2*g);var a=t.height/t.width,o=S(a,n,e,r);return{scale:2*o/t.width,rCenter:M(a,o/e),rotate:A(i+Math.PI/2)}}function M(t,e){return Math.cos(e)-t*e}function A(t){return(180/Math.PI*t+720)%180-90}function S(t,e,r,n){var i=t+1/(2*Math.tan(e));return r*Math.min(1/(Math.sqrt(i*i+.5)+i),n/(Math.sqrt(t*t+n/2)+t))}function E(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function C(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function L(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=P(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),f=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(f+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?f*=2:-1!==a.title.position.indexOf(\"right\")&&(f+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=f/t.titleBox.width,n=I(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function I(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function P(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function z(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=I(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+P(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=I(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var f=o*r.vTotal;\"funnelarea\"===i.type&&(f/=(1+i.baseratio)/2,f/=i.aspectratio),r.r=Math.sqrt(f)}}}(t,r)}function O(t,e){return[t*Math.sin(e),-t*Math.cos(e)]}function D(t,e,r){var n=t._fullLayout,i=r.trace,a=i.texttemplate,o=i.textinfo;if(!a&&o&&\"none\"!==o){var s,c=o.split(\"+\"),u=function(t){return-1!==c.indexOf(t)},f=u(\"label\"),h=u(\"text\"),p=u(\"value\"),d=u(\"percent\"),g=n.separators;if(s=f?[e.label]:[],h){var v=m.getFirstFilled(i.text,e.pts);y(v)&&s.push(v)}p&&s.push(m.formatPieValue(e.v,g)),d&&s.push(m.formatPiePercent(e.v/r.vTotal,g)),e.text=s.join(\"<br>\")}if(a){var x=l.castOption(i,e.i,\"texttemplate\");if(x){var b=function(t){return{label:t.label,value:t.v,valueLabel:m.formatPieValue(t.v,n.separators),percent:t.v/r.vTotal,percentLabel:m.formatPiePercent(t.v/r.vTotal,n.separators),color:t.color,text:t.text,customdata:l.castOption(i,t.i,\"customdata\")}}(e),_=m.getFirstFilled(i.text,e.pts);(y(_)||\"\"===_)&&(b.text=_),e.text=l.texttemplateString(x,b,t._fullLayout._d3locale,b,i._meta||{})}else e.text=\"\"}}function R(t,e){var r=t.rotate*Math.PI/180,n=Math.cos(r),i=Math.sin(r),a=(e.left+e.right)/2,o=(e.top+e.bottom)/2;t.textX=a*n-o*i,t.textY=a*i+o*n,t.noCenter=!0}e.exports={plot:function(t,e){var r=t._fullLayout,a=r._size;d(\"pie\",r),_(e,t),z(e,a);var h=l.makeTraceGroups(r._pielayer,e,\"trace\").each((function(e){var h=n.select(this),d=e[0],g=d.trace;!function(t){var e,r,n,i=t[0],a=i.r,o=i.trace,s=m.getRotationAngle(o.rotation),l=2*Math.PI/i.vTotal,c=\"px0\",u=\"px1\";if(\"counterclockwise\"===o.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;s+=l*t[e].v,l*=-1,c=\"px1\",u=\"px0\"}for(n=O(a,s),e=0;e<t.length;e++)(r=t[e]).hidden||(r[c]=n,r.startangle=s,s+=l*r.v/2,r.pxmid=O(a,s),r.midangle=s,s+=l*r.v/2,n=O(a,s),r.stopangle=s,r[u]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-o.hole,r.rInscribed=E(r,i))}(e),h.attr(\"stroke-linejoin\",\"round\"),h.each((function(){var v=n.select(this).selectAll(\"g.slice\").data(e);v.enter().append(\"g\").classed(\"slice\",!0),v.exit().remove();var y=[[[],[]],[[],[]]],_=!1;v.each((function(i,a){if(i.hidden)n.select(this).selectAll(\"path,g\").remove();else{i.pointNumber=i.i,i.curveNumber=g.index,y[i.pxmid[1]<0?0:1][i.pxmid[0]<0?0:1].push(i);var o=d.cx,c=d.cy,u=n.select(this),h=u.selectAll(\"path.surface\").data([i]);if(h.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),u.call(x,t,e),g.pull){var v=+m.castOption(g.pull,i.pts)||0;v>0&&(o+=v*i.pxmid[0],c+=v*i.pxmid[1])}i.cxFinal=o,i.cyFinal=c;var T=g.hole;if(i.v===d.vTotal){var k=\"M\"+(o+i.px0[0])+\",\"+(c+i.px0[1])+L(i.px0,i.pxmid,!0,1)+L(i.pxmid,i.px0,!0,1)+\"Z\";T?h.attr(\"d\",\"M\"+(o+T*i.px0[0])+\",\"+(c+T*i.px0[1])+L(i.px0,i.pxmid,!1,T)+L(i.pxmid,i.px0,!1,T)+\"Z\"+k):h.attr(\"d\",k)}else{var M=L(i.px0,i.px1,!0,1);if(T){var A=1-T;h.attr(\"d\",\"M\"+(o+T*i.px1[0])+\",\"+(c+T*i.px1[1])+L(i.px1,i.px0,!1,T)+\"l\"+A*i.px0[0]+\",\"+A*i.px0[1]+M+\"Z\")}else h.attr(\"d\",\"M\"+o+\",\"+c+\"l\"+i.px0[0]+\",\"+i.px0[1]+M+\"Z\")}D(t,i,d);var S=m.castOption(g.textposition,i.pts),E=u.selectAll(\"g.slicetext\").data(i.text&&\"none\"!==S?[0]:[]);E.enter().append(\"g\").classed(\"slicetext\",!0),E.exit().remove(),E.each((function(){var u=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),h=l.ensureUniformFontSize(t,\"outside\"===S?function(t,e,r){var n=m.castOption(t.outsidetextfont.color,e.pts)||m.castOption(t.textfont.color,e.pts)||r.color,i=m.castOption(t.outsidetextfont.family,e.pts)||m.castOption(t.textfont.family,e.pts)||r.family,a=m.castOption(t.outsidetextfont.size,e.pts)||m.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(g,i,r.font):b(g,i,r.font));u.text(i.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,h).call(f.convertToTspans,t);var v,y=s.bBox(u.node());if(\"outside\"===S)v=C(y,i);else if(v=w(y,i,d),\"auto\"===S&&v.scale<1){var x=l.ensureUniformFontSize(t,g.outsidetextfont);u.call(s.font,x),v=C(y=s.bBox(u.node()),i)}var T=v.textPosAngle,k=void 0===T?i.pxmid:O(d.r,T);if(v.targetX=o+k[0]*v.rCenter+(v.x||0),v.targetY=c+k[1]*v.rCenter+(v.y||0),R(v,y),v.outside){var M=v.targetY;i.yLabelMin=M-y.height/2,i.yLabelMid=M,i.yLabelMax=M+y.height/2,i.labelExtraX=0,i.labelExtraY=0,_=!0}v.fontSize=h.size,p(g.type,v,r),e[a].transform=v,u.attr(\"transform\",l.getTextTransform(v))}))}function L(t,e,r,n){var a=n*(e[0]-t[0]),o=n*(e[1]-t[1]);return\"a\"+n*d.r+\",\"+n*d.r+\" 0 \"+i.largeArc+(r?\" 1 \":\" 0 \")+a+\",\"+o}}));var T=n.select(this).selectAll(\"g.titletext\").data(g.title.text?[0]:[]);if(T.enter().append(\"g\").classed(\"titletext\",!0),T.exit().remove(),T.each((function(){var e,r=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),i=g.title.text;g._meta&&(i=l.templateString(i,g._meta)),r.text(i).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,g.title.font).call(f.convertToTspans,t),e=\"middle center\"===g.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(d):L(d,a),r.attr(\"transform\",u(e.x,e.y)+c(Math.min(1,e.scale))+u(e.tx,e.ty))})),_&&function(t,e){var r,n,i,a,o,s,l,c,u,f,h,p,d;function g(t,e){return t.pxmid[1]-e.pxmid[1]}function v(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,c,u,h,p=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),d=n?t.yLabelMin:t.yLabelMax,g=n?t.yLabelMax:t.yLabelMin,v=t.cyFinal+o(t.px0[1],t.px1[1]),y=p-d;if(y*l>0&&(t.labelExtraY=y),Array.isArray(e.pull))for(c=0;c<f.length;c++)(u=f[c])===t||(m.castOption(e.pull,t.pts)||0)>=(m.castOption(e.pull,u.pts)||0)||((t.pxmid[1]-u.pxmid[1])*l>0?(y=u.cyFinal+o(u.px0[1],u.px1[1])-d-t.labelExtraY)*l>0&&(t.labelExtraY+=y):(g+t.labelExtraY-v)*l>0&&(i=3*s*Math.abs(c-f.indexOf(t)),(h=u.cxFinal+a(u.px0[0],u.px1[0])+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=h)))}for(n=0;n<2;n++)for(i=n?g:v,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(c=t[n][r]).sort(i),u=t[1-n][r],f=u.concat(c),p=[],h=0;h<c.length;h++)void 0!==c[h].yLabelMid&&p.push(c[h]);for(d=!1,h=0;n&&h<u.length;h++)if(void 0!==u[h].yLabelMid){d=u[h];break}for(h=0;h<p.length;h++){var x=h&&p[h-1];d&&!h&&(x=d),y(p[h],x)}}}(y,g),function(t,e){t.each((function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");t.transform.targetX+=t.labelExtraX,t.transform.targetY+=t.labelExtraY,i.attr(\"transform\",l.getTextTransform(t.transform));var a=t.cxFinal+t.pxmid[0],s=\"M\"+a+\",\"+(t.cyFinal+t.pxmid[1]),c=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var u=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(u)>Math.abs(f)?s+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(a+t.labelExtraX+c):s+=\"l\"+t.labelExtraX+\",\"+u+\"v\"+(f-u)+\"h\"+c}else s+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+c;l.ensureSingle(r,\"path\",\"textline\").call(o.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:s,fill:\"none\"})}else r.select(\"path.textline\").remove()}))}(v,g),_&&g.automargin){var k=s.bBox(h.node()),M=g.domain,A=a.w*(M.x[1]-M.x[0]),S=a.h*(M.y[1]-M.y[0]),E=(.5*A-d.r)/a.w,I=(.5*S-d.r)/a.h;i.autoMargin(t,\"pie.\"+g.uid+\".automargin\",{xl:M.x[0]-E,xr:M.x[1]+E,yb:M.y[0]-I,yt:M.y[1]+I,l:Math.max(d.cx-d.r-k.left,0),r:Math.max(k.right-(d.cx+d.r),0),b:Math.max(k.bottom-(d.cy+d.r),0),t:Math.max(d.cy-d.r-k.top,0),pad:5})}}))}));setTimeout((function(){h.selectAll(\"tspan\").each((function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))}))}),0)},formatSliceLabel:D,transformInsideText:w,determineInsideTextFont:b,positionTitleOutside:L,prerenderTitles:_,layoutAreas:z,attachFxHandlers:x,computeTransform:R}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../bar/constants\":923,\"../bar/uniform_text\":937,\"./event_data\":1165,\"./helpers\":1166,d3:169}],1171:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._pielayer.selectAll(\".trace\");a(t,e,\"pie\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":937,\"./style_one\":1172,d3:169}],1172:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":643,\"./helpers\":1166}],1173:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1187}],1174:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,f=this.pickXYData=t.xy,h=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(f){if(n=f,e=f.length>>>1,h)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),m=i(t.marker.border.color),v=t.opacity*t.marker.opacity;g[3]*=v,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,m[3]*=v,this.pointcloudOptions.borderColor=m;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,T=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:T}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:T})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/autorange\":827,\"../scatter/get_trace_color\":1197,\"gl-pointcloud2d\":324}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":778,\"./attributes\":1173}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":868,\"../scatter3d/calc\":1216,\"./attributes\":1173,\"./convert\":1174,\"./defaults\":1175}],1177:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../plots/template_attributes\").hovertemplateAttrs,c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../lib/extend\").extendFlat,h=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=h({hoverinfo:f({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),customdata:void 0,node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:f(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":642,\"../../components/colorscale/attributes\":650,\"../../components/fx/attributes\":674,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),f=t(\"../../registry\");function h(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var h={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:h,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[h],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),f.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)h(t,e)}},{\"../../components/dragelement\":662,\"../../components/fx/layout_attributes\":684,\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/select\":847,\"../../plots/get_data\":865,\"../../registry\":911,\"./plot\":1183}],1179:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),f=o(a.customdata),h={},p={},d=a.colorscales.length;for(e=0;e<d;e++){var g=a.colorscales[e],m=l.extractScale(g,{cLetter:\"c\"}),v=l.makeColorScaleFunc(m);p[g.label]=v}var y=0;for(e=0;e<a.value.length;e++)a.source[e]>y&&(y=a.source[e]),a.target[e]>y&&(y=a.target[e]);var x,b=y+1;t.node._count=b;var _=t.node.groups,w={};for(e=0;e<_.length;e++){var T=_[e];for(x=0;x<T.length;x++){var k=T[x],M=b+e;w.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):w[k]=M}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var S=a.value[e],E=a.source[e],C=a.target[e];if(S>0&&s(E,b)&&s(C,b)&&(!w.hasOwnProperty(E)||!w.hasOwnProperty(C)||w[E]!==w[C])){w.hasOwnProperty(C)&&(C=w[C]),w.hasOwnProperty(E)&&(E=w[E]),C=+C,h[E=+E]=h[C]=!0;var L=\"\";a.label&&a.label[e]&&(L=a.label[e]);var I=null;L&&p.hasOwnProperty(L)&&(I=p[L]),c.push({pointNumber:e,label:L,color:u?a.color[e]:a.color,customdata:f?a.customdata[e]:a.customdata,concentrationscale:I,source:E,target:C,value:+S}),A.source.push(E),A.target.push(C)}}var P=b+_.length,z=o(r.color),O=o(r.customdata),D=[];for(e=0;e<P;e++)if(h[e]){var R=r.label[e];D.push({group:e>b-1,childrenNodes:[],pointNumber:e,label:R,color:z?r.color[e]:r.color,customdata:O?r.customdata[e]:r.customdata})}var F=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some((function(t){return t.length>1}))}(P,A.source,A.target)&&(F=!0),{circular:F,links:c,nodes:D,groups:_,groupLookup:w}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gup\":775,\"strongly-connected-components\":569}],1180:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,h){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(h.hoverlabel,t.hoverlabel),g=t.node,m=c.newContainer(e,\"node\");function v(t,e){return n.coerce(g,m,i.node,t,e)}v(\"label\"),v(\"groups\"),v(\"x\"),v(\"y\"),v(\"pad\"),v(\"thickness\"),v(\"line.color\"),v(\"line.width\"),v(\"hoverinfo\",t.hoverinfo),l(g,m,v,d),v(\"hovertemplate\");var y=h.colorway;v(\"color\",m.label.map((function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}))),v(\"customdata\");var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,T=o(h.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(T,b.value.length)),_(\"customdata\"),u(x,b,{name:\"colorscales\",handleItemDefaults:f}),s(e,h,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),m.x.length&&m.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},h.font)),e._length=null}},{\"../../components/color\":643,\"../../components/fx/hoverlabel_defaults\":681,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../../plots/domain\":855,\"./attributes\":1177,tinycolor2:576}],1182:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1177,\"./base_plot\":1178,\"./calc\":1179,\"./defaults\":1181,\"./plot\":1183,\"./select.js\":1185}],1183:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function f(t,e){return t.filter((function(t){return t.key===e.traceId}))}function h(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function m(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function v(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),r&&f(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(m)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),r&&f(e,t).selectAll(l.sankeyNode).filter(g(t)).call(v)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,f=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].visible&&t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",T=c(t,\"concentration:\")+\" \",k=c(t,\"incoming flow count:\")+\" \",M=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,f=0;f<i.flow.links.length;f++){var d=i.flow.links[f];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=f),d.fullData=d.trace,s=i.link.trace.link;var g=v(d),m={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:m.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?T+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:m,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each((function(){i.link.concentrationscale||h(this,.65),p(this)}))}}function v(t){var e,r;t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2,r=t.circularPathData.verticalFullExtent):(e=(t.source.x1+t.target.x0)/2,r=(t.y0+t.y1)/2);var n=[e,r];return\"v\"===t.trace.orientation&&n.reverse(),n[0]+=i.parent.translateX,n[1]+=i.parent.translateY,n}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),f=s.node().getBoundingClientRect(),d=f.left-2-c.left,g=f.right+2-c.left,m=f.top+f.height/4-c.top,v={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace,t._fullLayout._calcInverseTransform(t);var y=t._fullLayout._invScaleX,x=t._fullLayout._invScaleY,_=a.loneHover({x0:y*d,x1:y*g,y:x*m,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,k+i.node.targetLinks.length,M+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:v,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});h(_,.85),p(_)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(v,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"./constants\":1180,\"./render\":1184,d3:169}],1184:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),f=t(\"../../lib\"),h=f.strTranslate,p=t(\"../../lib/gup\"),d=p.keyFun,g=p.repeat,m=p.unwrap,v=t(\"d3-interpolate\").interpolateNumber,y=t(\"../../registry\");function x(t,e,r){var i,o=m(e),s=o.trace,u=s.domain,h=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,g=t.width*(u.x[1]-u.x[0]),v=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(h?[g,v]:[v,g]).nodeWidth(d).nodePadding(p).nodeId((function(t){return t.pointNumber})).nodes(y).links(x);var _,w,T,k=i();for(var M in i.nodePadding()<p&&f.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var A,S=parseInt(o._groupLookup[M]);for(_=0;_<k.nodes.length;_++)if(k.nodes[_].pointNumber===S){A=k.nodes[_];break}if(A){var E={pointNumber:parseInt(M),x0:A.x0,x1:A.x1,y0:A.y0,y1:A.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};k.nodes.unshift(E),A.childrenNodes.unshift(E)}}if(function(){for(_=0;_<k.nodes.length;_++){var t,e,r=k.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(T=0;T<o.length;T++)l[(e=o[T]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(T=0;T<o.length;T++)(e=o[T]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,k.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*g,s.node.y[_]*v];k.nodes[_].x0=C[0]-d/2,k.nodes[_].x1=C[0]+d/2;var L=k.nodes[_].y1-k.nodes[_].y0;k.nodes[_].y0=C[1]-L/2,k.nodes[_].y1=C[1]+L/2}if(\"snap\"===s.arrangement)!function(t){t.forEach((function(t){var e,r,n,i=0,a=t.length;for(t.sort((function(t,e){return t.y0-e.y0})),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p}))}(function(t){var e,r,n=t.map((function(t,e){return{x0:t.x0,index:e}})).sort((function(t,e){return t.x0-e.x0})),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=k.nodes));i.update(k)}return{circular:b,key:r,trace:s,guid:f.randstr(),horizontal:h,width:g,height:v,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:h?v:g,dragPerpendicular:h?g:v,arrangement:s.arrangement,sankey:i,graph:k,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}function b(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:_,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}function _(){return function(t){if(t.link.circular)return e=t.link,r=e.width/2,n=e.circularPathData,\"top\"===e.circularLinkType?\"M \"+n.targetX+\" \"+(n.targetY+r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 1 \"+(n.rightFullExtent-r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 1 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 0 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 0 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"L\"+n.targetX+\" \"+(n.targetY-r)+\"Z\":\"M \"+n.targetX+\" \"+(n.targetY-r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 0 \"+(n.rightFullExtent-r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 0 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 1 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 1 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"L\"+n.targetX+\" \"+(n.targetY+r)+\"Z\";var e,r,n,i=t.link.source.x1,a=t.link.target.x0,o=v(i,a),s=o(.5),l=o(.5),c=t.link.y0-t.link.width/2,u=t.link.y0+t.link.width/2,f=t.link.y1-t.link.width/2,h=t.link.y1+t.link.width/2;return\"M\"+i+\",\"+c+\"C\"+s+\",\"+c+\" \"+l+\",\"+f+\" \"+a+\",\"+f+\"L\"+a+\",\"+h+\"C\"+l+\",\"+h+\" \"+s+\",\"+u+\" \"+i+\",\"+u+\"Z\"}}function w(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=f.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}function T(t){t.attr(\"transform\",(function(t){return h(t.node.x0.toFixed(3),t.node.y0.toFixed(3))}))}function k(t){t.call(T)}function M(t,e){t.call(k),e.attr(\"d\",_())}function A(t){t.attr(\"width\",(function(t){return t.node.x1-t.node.x0})).attr(\"height\",(function(t){return t.visibleHeight}))}function S(t){return t.link.width>1||t.linkLineWidth>0}function E(t){return h(t.translateX,t.translateY)+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function C(t){return h(t.horizontal?0:t.labelY,t.horizontal?t.labelY:0)}function L(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function I(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function P(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function z(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function O(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function D(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])})).on(\"mousemove.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])})).on(\"mouseout.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)})).on(\"click.basic\",(function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)}))}function R(t,e,r,a){var o=i.behavior.drag().origin((function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}})).on(\"dragstart\",(function(i){if(\"fixed\"!==i.arrangement&&(f.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",(function(t){a._fullLayout._dragCover=t})),f.raiseToTop(this),i.interactionState.dragInProgress=i.node,B(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter((function(t){return t.originalX===r.node.originalX})).filter((function(t){return!t.partOfGroup}));r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius((function(t){return t.dy/2+r.nodePad/2})).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame((function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(r.graph.nodes),r.sankey.update(r.graph),M(t.filter(N(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var l=r.node.originalX;r.node.x0=l-r.visibleWidth/2,r.node.x1=l+r.visibleWidth/2,F(r,a)}}))}(t,e,i,o,a)}})).on(\"drag\",(function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),B(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),M(t.filter(N(r)),e))}})).on(\"dragend\",(function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&F(t,a)}}));t.on(\".drag\",null).call(o)}function F(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}y.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then((function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()}))}function B(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function N(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,l,c){var u=!1;f.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",(function(){u=!0}));var h=t._fullLayout._dragCover,p=r.filter((function(t){return m(t).trace.visible})).map(x.bind(null,l)),v=e.selectAll(\".\"+n.cn.sankey).data(p,d);v.exit().remove(),v.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",E),v.each((function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;f.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})})),v.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var y=v.selectAll(\".\"+n.cn.sankeyLinks).data(g,d);y.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var k=y.selectAll(\".\"+n.cn.sankeyLink).data((function(t){return t.graph.links.filter((function(t){return t.value})).map(b.bind(null,t))}),d);k.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(D,v,c.linkEvents),k.style(\"stroke\",(function(t){return S(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue})).style(\"stroke-opacity\",(function(t){return S(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})).style(\"stroke-width\",(function(t){return S(t)?t.linkLineWidth:1})).attr(\"d\",_()),k.style(\"opacity\",(function(){return t._context.staticPlot||u||h?1:0})).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),k.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var M=v.selectAll(\".\"+n.cn.sankeyNodeSet).data(g,d);M.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),M.style(\"cursor\",(function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}}));var F=M.selectAll(\".\"+n.cn.sankeyNode).data((function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort((function(t,e){return t-e})),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(w.bind(null,t))}),d);F.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(T).style(\"opacity\",(function(e){return!t._context.staticPlot&&!u||e.partOfGroup?0:1})),F.call(D,v,c.nodeEvents).call(R,k,c,t),F.transition().ease(n.ease).duration(n.duration).call(T).style(\"opacity\",(function(t){return t.partOfGroup?0:1})),F.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var B=F.selectAll(\".\"+n.cn.nodeRect).data(g);B.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(A),B.style(\"stroke-width\",(function(t){return t.nodeLineWidth})).style(\"stroke\",(function(t){return o.tinyRGB(a(t.nodeLineColor))})).style(\"stroke-opacity\",(function(t){return o.opacity(t.nodeLineColor)})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),B.transition().ease(n.ease).duration(n.duration).call(A);var N=F.selectAll(\".\"+n.cn.nodeCapture).data(g);N.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),N.attr(\"x\",(function(t){return t.zoneX})).attr(\"y\",(function(t){return t.zoneY})).attr(\"width\",(function(t){return t.zoneWidth})).attr(\"height\",(function(t){return t.zoneHeight}));var j=F.selectAll(\".\"+n.cn.nodeCentered).data(g);j.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",C),j.transition().ease(n.ease).duration(n.duration).attr(\"transform\",C);var U=j.selectAll(\".\"+n.cn.nodeLabelGuide).data(g);U.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",(function(t){return t.uniqueNodeLabelPathId})).attr(\"d\",L).attr(\"transform\",I),U.transition().ease(n.ease).duration(n.duration).attr(\"d\",L).attr(\"transform\",I);var V=j.selectAll(\".\"+n.cn.nodeLabel).data(g);V.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",P).style(\"cursor\",\"default\").style(\"fill\",\"black\"),V.style(\"text-shadow\",(function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"})).each((function(t){s.font(V,t.textFont)})),V.transition().ease(n.ease).duration(n.duration).attr(\"transform\",P);var q=V.selectAll(\".\"+n.cn.nodeLabelTextPath).data(g);q.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",(function(t){return\"#\"+t.uniqueNodeLabelPathId})).attr(\"startOffset\",O).style(\"fill\",z),q.text((function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"})).attr(\"text-anchor\",(function(t){return t.horizontal&&t.left?\"end\":\"start\"})),q.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",O).style(\"fill\",z)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../registry\":911,\"./constants\":1180,\"@plotly/d3-sankey\":56,\"@plotly/d3-sankey-circular\":55,d3:169,\"d3-force\":160,\"d3-interpolate\":162,tinycolor2:576}],1185:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1186:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.texttemplate,t,\"txt\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":778}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").texttemplateAttrs,i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../components/drawing\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},xperiod:{valType:\"any\",dflt:0,editType:\"calc\"},yperiod:{valType:\"any\",dflt:0,editType:\"calc\"},xperiod0:{valType:\"any\",editType:\"calc\"},yperiod0:{valType:\"any\",editType:\"calc\"},xperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},yperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},texttemplate:n({},{}),hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:i({},{keys:c.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:u({},s,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:u({symbol:{valType:\"enumerated\",values:l.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:u({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},a(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},a(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:o({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":650,\"../../components/drawing\":665,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906,\"./constants\":1191}],1188:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"./subtypes\"),c=t(\"./colorscale_calc\"),u=t(\"./arrays_to_calcdata\"),f=t(\"./calc_selection\");function h(t,e,r,n,i,o,s){var c=e._length,u=t._fullLayout,f=r._id,h=n._id,p=u._firstScatter[g(e)]===e.uid,d=(m(e,u,r,n)||{}).orientation,v=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};s&&(y.ppad=x.ppad=s);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===v||\"tonextx\"===v&&(p||\"h\"===d))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==v&&\"tozeroy\"!==v&&(l.hasMarkers(e)||l.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===v||\"tonexty\"===v&&(p||\"v\"===d))?x.tozero=!0:\"tonextx\"!==v&&\"tozerox\"!==v||(x.padded=!1),f&&(e._extremes[f]=a.findExtremes(r,i,y)),h&&(e._extremes[h]=a.findExtremes(n,o,x))}function p(t,e){if(l.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var s={type:\"linear\"};a.setConvert(s);for(var c=s.makeCalcdata(t.marker,\"size\"),u=new Array(e),f=0;f<e;f++)u[f]=r(c[f]);return u}return r(n.size)}}function d(t,e){var r=g(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function g(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function m(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,l,g,v,y,x,b=t._fullLayout,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),T=_.makeCalcdata(e,\"x\"),k=w.makeCalcdata(e,\"y\"),M=o(e,_,\"x\",T),A=o(e,w,\"y\",k),S=e._length,E=new Array(S),C=e.ids,L=m(e,b,_,w),I=!1;d(b,e);var P,z=\"x\",O=\"y\";L?(i.pushUnique(L.traceIndices,e._expandedIndex),(r=\"v\"===L.orientation)?(O=\"s\",P=\"x\"):(z=\"s\",P=\"y\"),y=\"interpolate\"===L.stackgaps):h(t,e,_,w,M,A,p(e,S));var D=!!e.xperiodalignment,R=!!e.yperiodalignment;for(l=0;l<S;l++){var F=E[l]={},B=n(M[l]),N=n(A[l]);B&&N?(F[z]=M[l],F[O]=A[l],D&&(F.orig_x=T[l]),R&&(F.orig_y=k[l])):L&&(r?B:N)?(F[P]=r?M[l]:A[l],F.gap=!0,y?(F.s=s,I=!0):F.s=0):F[z]=F[O]=s,C&&(F.id=String(C[l]))}if(u(E,e),c(t,e),f(E,e),L){for(l=0;l<E.length;)E[l][P]===s?E.splice(l,1):l++;if(i.sort(E,(function(t,e){return t[P]-e[P]||t.i-e.i})),I){for(l=0;l<E.length-1&&E[l].gap;)l++;for((x=E[l].s)||(x=E[l].s=0),g=0;g<l;g++)E[g].s=x;for(v=E.length-1;v>l&&E[v].gap;)v--;for(x=E[v].s,g=E.length-1;g>v;g--)E[g].s=x;for(;l<v;)if(E[++l].gap){for(g=l+1;E[g].gap;)g++;for(var j=E[l-1][P],U=E[l-1].s,V=(E[g].s-U)/(E[g][P]-j);l<g;)E[l].s=U+(E[l][P]-j)*V,l++}}}return E},calcMarkerSize:p,calcAxisExpansion:h,setFirstScatter:d,getStackOpts:m}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"./arrays_to_calcdata\":1186,\"./calc_selection\":1189,\"./colorscale_calc\":1190,\"./subtypes\":1212,\"fast-isnumeric\":241}],1189:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":778}],1190:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"./subtypes\":1212}],1191:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1192:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T=t.calcdata;for(var k in s){var M=(v=s[k]).traceIndices;if(M.length){for(y=\"interpolate\"===v.stackgaps,x=v.groupnorm,\"v\"===v.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(M.length),l=0;l<w.length;l++)w[l]=!1;p=T[M[0]];var A=new Array(p.length);for(l=0;l<p.length;l++)A[l]=p[l][b];for(l=1;l<M.length;l++){for(h=T[M[l]],c=u=0;c<h.length;c++){for(d=h[c][b];d>A[u]&&u<A.length;u++)i(h,c,A[u],l,w,y,b),c++;if(d!==A[u]){for(f=0;f<l;f++)i(T[M[f]],u,d,f,w,y,b);A.splice(u,0,d)}u++}for(;u<A.length;u++)i(h,c,A[u],l,w,y,b),c++}var S=A.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<M.length;l++)(h=T[M[l]])[0].trace._rawLength=h[0].trace._length,h[0].trace._length=S,g+=h[c].s,h[c][_]=g;if(x)for(m=(\"fraction\"===x?g:g/100)||1,l=0;l<M.length;l++){var E=T[M[l]][c];E[_]/=m,E.sNorm=E.s/m}}for(l=0;l<M.length;l++){var C=(h=T[M[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),I=Array.isArray(L);if(L&&w[l]||I){var P=L;for(L=new Array(S),c=0;c<S;c++)L[c]=h[c].gap?0:I?P[h[c].i]:P}var z=new Array(S),O=new Array(S);for(c=0;c<S;c++)z[c]=h[c].x,O[c]=h[c].y;n.calcAxisExpansion(t,C,r,a,z,O,L),h[0].t.orientation=v.orientation}}}}}},{\"./calc\":1188}],1193:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1194:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./period_defaults\"),u=t(\"./stack_defaults\"),f=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),p=t(\"./line_shape_defaults\"),d=t(\"./text_defaults\"),g=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,m){function v(r,i){return n.coerce(t,e,a,r,i)}var y=l(t,e,m,v);if(y||(e.visible=!1),e.visible){c(t,e,m,v);var x=u(t,e,m,v),b=!x&&y<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",b),s.hasLines(e)&&(h(t,e,r,m,v),p(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&f(t,e,r,m,v,{gradient:!0}),s.hasText(e)&&(v(\"texttemplate\"),d(t,e,m,v));var _=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),_.push(\"points\")),v(\"fill\",x?x.fillDflt:\"none\"),\"none\"!==e.fill&&(g(t,e,r,v),s.hasLines(e)||p(t,e,v));var w=(e.line||{}).color,T=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||_.push(\"fills\"),v(\"hoveron\",_.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,w||T||r,{axis:\"y\"}),k(t,e,w||T||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":778,\"../../registry\":911,\"./attributes\":1187,\"./constants\":1191,\"./fillcolor_defaults\":1195,\"./line_defaults\":1200,\"./line_shape_defaults\":1202,\"./marker_defaults\":1206,\"./period_defaults\":1207,\"./stack_defaults\":1210,\"./subtypes\":1212,\"./text_defaults\":1213,\"./xy_defaults\":1214}],1195:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":643,\"../../lib\":778}],1196:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a={_fullLayout:r},o=n.getFromTrace(a,e,\"x\"),s=n.getFromTrace(a,e,\"y\");return i.xLabel=n.tickText(o,t.x,!0).text,i.yLabel=n.tickText(s,t.y,!0).text,i}},{\"../../plots/cartesian/axes\":828}],1197:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":643,\"./subtypes\":1212}],1198:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,f=u[0].trace,h=t.xa,p=t.ya,d=h.c2p(e),g=p.c2p(r),m=[d,g],v=f.hoveron||\"\",y=-1!==f.mode.indexOf(\"markers\")?3:.5;if(-1!==v.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=h.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(h.c2p(t.x)-d);return n<e?r*n/e:n-e+r}),(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r}),x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=h.c2p(_.x,!0),T=p.c2p(_.y,!0),k=_.mrc||1;t.index=_.i;var M=u[0].t.orientation,A=M&&(_.sNorm||_.s),S=\"h\"===M?A:void 0!==_.orig_x?_.orig_x:_.x,E=\"v\"===M?A:void 0!==_.orig_y?_.orig_y:_.y;return n.extendFlat(t,{color:o(f,_),x0:w-k,x1:w+k,xLabelVal:S,y0:T-k,y1:T+k,yLabelVal:E,spikeDistance:x(_),hovertemplate:f.hovertemplate}),l(_,f,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,f,t),[t]}}if(-1!==v.indexOf(\"fills\")&&f._polygons){var C,L,I,P,z,O,D,R,F,B=f._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(I=B[C]).contains(m)&&(j=!j,N.push(I),q=Math.min(q,I.ymin),H=Math.max(H,I.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(P=N[C].pts,L=1;L<P.length;L++)(R=P[L-1][1])>G!=(F=P[L][1])>=G&&(O=P[L-1][0],D=P[L][0],F-R&&(z=O+(D-O)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,h._length);var Y=s.defaultLine;return s.opacity(f.fillcolor)?Y=f.fillcolor:s.opacity((f.line||{}).color)&&(Y=f.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,f.text&&!Array.isArray(f.text)?t.text=String(f.text):t.text=f.name,[t]}}}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"../../registry\":911,\"./get_trace_color\":1197}],1199:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),formatLabels:t(\"./format_labels\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"./arrays_to_calcdata\":1186,\"./attributes\":1187,\"./calc\":1188,\"./cross_trace_calc\":1192,\"./cross_trace_defaults\":1193,\"./defaults\":1194,\"./format_labels\":1196,\"./hover\":1198,\"./marker_colorbar\":1205,\"./plot\":1208,\"./select\":1209,\"./style\":1211,\"./subtypes\":1212}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,f=t(\"./constants\");e.exports=function(t,e){var r,n,a,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,I=S._length,P=E._length,z=e.connectGaps,O=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=f.minTolerance,j=t.length,U=new Array(j),V=0;function q(r){var n=t[r];if(!n)return!1;var a=e.linearized?S.l2p(n.x):S.c2p(n.x),l=e.linearized?E.l2p(n.y):E.c2p(n.y);if(a===i){if(C&&(a=S.c2p(n.x,!0)),a===i)return!1;L&&l===i&&(a*=Math.abs(S._m*P*(S._m>0?o:s)/(E._m*I*(E._m>0?o:s)))),a*=1e3}if(l===i){if(L&&(l=E.c2p(n.y,!0)),l===i)return!1;l*=1e3}return[a,l]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/I,n=t[1]/P,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==M&&H(r,n,M,A)&&(i=0),i&&e&&H(r,n,e[0]/I,e[1]/P)&&(i=0),(1+f.toleranceGrowth*i)*O}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,Q,$,tt=f.maxScreensAway,et=-I*tt,rt=I*(1+tt),nt=-P*tt,it=P*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ft(t){if(M=t[0]/I,A=t[1]/P,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=$(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else Q=$(U[V-1],t)[0],U[V++]=Q;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut($(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?$=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?$=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)||(n&&r.push(n),i&&r.push(i)),r}:\"hvh\"===D?$=lt(0,et,rt):\"vhv\"===D&&($=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ft(n),r++;r<j;r++){if(!(h=q(r))){if(z)continue;break}if(R&&e.simplify){var ht=q(r+1);if(y=Y(h,n),F&&(0===V||V===j-1)||!(y<G(h,ht)*N)){for(m=[(h[0]-n[0])/y,(h[1]-n[1])/y],p=n,x=y,b=w=T=0,g=!1,a=h,r++;r<t.length;r++){if(d=ht,ht=q(r+1),!d){if(z)continue;break}if(k=(v=[d[0]-n[0],d[1]-n[1]])[0]*m[1]-v[1]*m[0],w=Math.min(w,k),(T=Math.max(T,k))-w>G(d,ht))break;a=d,(_=v[0]*m[0]+v[1]*m[1])>x?(x=_,h=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ft(h),a!==p&&ft(p)):(p!==n&&ft(p),a!==h&&ft(h)),ft(a),r>=t.length||!d)break;ft(d),n=d}}else ft(h)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./constants\":1191}],1202:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1203:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,f=-1,h=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=h,h++):i.fill in n&&p>=0?l=p:(l=p=h,h++),l<f&&(u=!0),i._groupIndex=f=l;var d=r.slice();u&&d.sort((function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index}));var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":241}],1205:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1206:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),f=(t.line||{}).color;(c=c||{},f&&(r=f),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",f&&!Array.isArray(f)&&e.marker.color!==f?f:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":643,\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"./subtypes\":1212}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").dateTick0,i=t(\"../../constants/numerical\").ONEWEEK;function a(t,e){return n(e,t%i==0?1:0)}e.exports=function(t,e,r,n,i){if(i||(i={x:!0,y:!0}),i.x){var o=n(\"xperiod\");o&&(n(\"xperiod0\",a(o,e.xcalendar)),n(\"xperiodalignment\"))}if(i.y){var s=n(\"yperiod\");s&&(n(\"yperiod0\",a(s,e.ycalendar)),n(\"yperiodalignment\"))}}},{\"../../constants/numerical\":753,\"../../lib\":778}],1208:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),f=t(\"./link_traces\"),h=t(\"../../lib/polygon\").tester;function p(t,e,r,f,p,d,g){var m;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),f=n.extent(a.simpleMap(l.range,l.r2c)),h=i[0].trace;if(!c.hasMarkers(h))return;var p=h.marker.maxdisplayed;if(0===p)return;var d=i.filter((function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=f[0]&&t.y<=f[1]})),g=Math.ceil(d.length/p),m=0;o.forEach((function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&m++}));var v=Math.round(m*g/3+Math.floor(m/3)*g/7.1);i.forEach((function(t){delete t.vis})),d.forEach((function(t,e){0===Math.round((e+v)%g)&&(t.vis=!0)}))}(0,e,r,f,p);var v=!!g&&g.duration>0;function y(t){return v?t.transition():t}var x=r.xaxis,b=r.yaxis,_=f[0].trace,w=_.line,T=n.select(d),k=o(T,\"g\",\"errorbars\"),M=o(T,\"g\",\"lines\"),A=o(T,\"g\",\"points\"),S=o(T,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,k,r,g),!0===_.visible){var E,C;y(T).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),f[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=T;var I,P,z=\"\",O=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,O=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(f),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(f,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),m=0;m<G.length;m++)_._polygons[m]=h(G[m]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(I=R(e),P=B(e),q?L?(q+=\"L\"+I.substr(1),H=P+\"L\"+H.substr(1)):(q+=\"Z\"+I,H=P+\"Z\"+H):(q=I,H=P),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(f),t)y(r.style(\"opacity\",0).attr(\"d\",I).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",I),l.singleLineStyle(f,i)}}}}}var W=M.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(f),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(O)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),A.datum(f),S.datum(f),function(e,i,a){var o,u=a[0].trace,f=c.hasMarkers(u),h=c.hasText(u),p=tt(u),d=et,g=et;if(f||h){var m=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?m=w?K:J:_&&!w&&(m=Q),f&&(d=m),h&&(g=m)}var T,k=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);v&&k.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),f&&(T=l.makePointStyleFns(u)),o.each((function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,T,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()})),v?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each((function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()})),o.selectAll(\"text\").call(l.textPointStyle,u,t).each((function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each((function(){y(n.select(this)).attr({x:e,y:r})}))})),o.exit().remove()}(A,S,f);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(A,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter((function(t){return!t.gap&&t.vis}))}function K(t){return t.filter((function(t){return t.vis}))}function Q(t){return t.filter((function(t){return!t.gap}))}function $(t){return t.id}function tt(t){if(t.ids)return $}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,h,d=!a,g=!!a&&a.duration>0,m=f(t,e,r);((u=i.selectAll(\"g.trace\").data(m,(function(t){return t[0].trace.uid}))).enter().append(\"g\").attr(\"class\",(function(t){return\"trace scatter trace\"+t[0].trace.uid})).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each((function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each((function(t){a[t]=null})).remove(),u.order().each((function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")}))}))}(t,u,e),g)?(c&&(h=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",(function(){h&&h()})).each(\"interrupt\",(function(){h&&h()})).each((function(){i.selectAll(\"g.trace\").each((function(r,n){p(t,n,e,r,m,this,a)}))}))):u.each((function(r,n){p(t,n,e,r,m,this,a)}));d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/polygon\":790,\"../../registry\":911,\"./line_points\":1201,\"./link_traces\":1203,\"./subtypes\":1212,d3:169}],1209:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],f=s[0].trace;if(!n.hasMarkers(f)&&!n.hasText(f))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1212}],1210:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var f={orientation:e.x&&!e.y?\"h\":\"v\"},h=0;h<n.length;h++){var p=n[h],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],m=\"orientation\"===p;if((g||u)&&(c[p]=i(p,f[p]),m&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],m))))for(var v=0;v<c.traces.length-1;v++){var y=c.traces[v];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1211:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.selectAll(\"g.points\").each((function(e){o(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.text\").each((function(e){s(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":665,\"../../registry\":911,d3:169}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":778}],1213:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":778}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":778,\"../../registry\":911}],1215:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../plots/attributes\"),l=t(\"../../constants/gl3d_dashes\"),c=t(\"../../constants/gl3d_markers\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,p=n.marker,d=p.line,g=u({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},i(\"line\"));var m=e.exports=f({x:n.x,y:n.y,z:{valType:\"data_array\"},text:u({},n.text,{}),texttemplate:o({},{}),hovertext:u({},n.hovertext,{}),hovertemplate:a(),mode:u({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:g,marker:u({symbol:{valType:\"enumerated\",values:Object.keys(c),dflt:\"circle\",arrayOk:!0},size:u({},p.size,{dflt:8}),sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode,opacity:u({},p.opacity,{arrayOk:!1}),colorbar:p.colorbar,line:u({width:u({},d.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:u({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:u({},n.textfont.family,{arrayOk:!1})},hoverinfo:u({},s.hoverinfo)},\"calc\",\"nested\");m.x.editType=m.y.editType=m.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":650,\"../../constants/gl3d_dashes\":750,\"../../constants/gl3d_markers\":751,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1216:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1186,\"../scatter/colorscale_calc\":1190}],1217:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],f=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(f,!0)-c)*r],u>0){var h=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=h),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,h)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":911}],1218:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/make_bubble_size_func\"),h=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"../../plots/cartesian/axes\"),g=t(\"../../components/fx/helpers\").appendArrayPointValue,m=t(\"./calc_errors\");function v(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var y=v.prototype;function x(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function b(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function _(t,e){return e(4*t)}function w(t){return p[t]}function T(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function k(t,e){var r,n,i,a,o,s,h=[],p=t.fullSceneLayout,v=t.dataScale,y=p.xaxis,k=p.yaxis,M=p.zaxis,A=e.marker,S=e.line,E=e.x||[],C=e.y||[],L=e.z||[],I=E.length,P=e.xcalendar,z=e.ycalendar,O=e.zcalendar;for(o=0;o<I;o++)r=y.d2l(E[o],0,P)*v[0],n=k.d2l(C[o],0,z)*v[1],i=M.d2l(L[o],0,O)*v[2],h[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(I),o=0;o<I;o++)s[o]=e.text;function D(t,e){var r=p[t];return d.tickText(r,r.d2l(e),!0).text}var R=e.texttemplate;if(R){var F=t.fullLayout._d3locale,B=Array.isArray(R),N=B?Math.min(R.length,I):I,j=B?function(t){return R[t]}:function(){return R};for(s=new Array(N),o=0;o<N;o++){var U={x:E[o],y:C[o],z:L[o]},V={xLabel:D(\"xaxis\",E[o]),yLabel:D(\"yaxis\",C[o]),zLabel:D(\"zaxis\",L[o])},q={};g(q,e,o);var H=e._meta||{};s[o]=l.texttemplateString(j(o),V,F,q,U,H)}}if(a={position:h,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(S,1,I),a.lineWidth=S.width,a.lineDashes=S.dash),\"marker\"in e){var G=f(e);a.scatterColor=u(A,1,I),a.scatterSize=T(A.size,I,_,20,G),a.scatterMarker=T(A.symbol,I,w,\"\\u25cf\"),a.scatterLineWidth=A.line.width,a.scatterLineColor=u(A.line,1,I),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=x(t[r]),e[r][1]=b(t[r]));else e[0]=x(t),e[1]=b(t);return e}(e.textposition),a.textColor=u(e.textfont,1,I),a.textSize=T(e.textfont.size,I,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var Y=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var W=e.projection[Y[o]];(a.project[o]=W.show)&&(a.projectOpacity[o]=W.opacity,a.projectScale[o]=W.scale)}a.errorBounds=m(e,v,p);var X=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=X.color,a.errorLineWidth=X.lineWidth,a.errorCapSize=X.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function M(t){if(l.isArrayOrTypedArray(t)){var e=t[0];return l.isArrayOrTypedArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map((function(t){return Math.round(255*t)}))+\")\"}return null}function A(t){return l.isArrayOrTypedArray(t)?4===t.length&&\"number\"==typeof t[0]?M(t):t.map(M):null}y.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},y.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,f=h.solid;this.data=t;var p=k(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in h&&(f=h[p.lineDashes]),this.color=A(p.scatterColor)||A(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:f[0],dashScale:f[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var f=u[n],h=0;h<f.length;++h)f[h]=l[f[h]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},y.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new v(t,e.uid);return r.update(e),r}},{\"../../components/fx/helpers\":679,\"../../constants/gl3d_dashes\":750,\"../../constants/gl3d_markers\":751,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"../scatter/make_bubble_size_func\":1204,\"./calc_errors\":1217,\"delaunay-triangulate\":171,\"gl-error3d\":266,\"gl-line3d\":275,\"gl-mesh3d\":309,\"gl-scatter3d\":330}],1219:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,f,u)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),a.hasLines(e)&&(f(\"connectgaps\"),s(t,e,r,u,f)),a.hasMarkers(e)&&o(t,e,r,u,f,{noSelect:!0}),a.hasText(e)&&(f(\"texttemplate\"),l(t,e,u,f,{noSelect:!0}));var h=(e.line||{}).color,p=(e.marker||{}).color;f(\"surfaceaxis\")>=0&&f(\"surfacecolor\",h||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var m=\"projection.\"+d[g];f(m+\".show\")&&(f(m+\".opacity\"),f(m+\".scale\"))}var v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,h||p||r,{axis:\"z\"}),v(t,e,h||p||r,{axis:\"y\",inherit:\"z\"}),v(t,e,h||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1215}],1220:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../constants/gl3d_markers\":751,\"../../plots/gl3d\":870,\"./attributes\":1215,\"./calc\":1216,\"./convert\":1218,\"./defaults\":1219}],1221:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=n.marker,u=n.line,f=c.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:l({},n.mode,{dflt:\"markers\"}),text:l({},n.text,{}),texttemplate:o({editType:\"plot\"},{keys:[\"a\",\"b\",\"text\"]}),hovertext:l({},n.hovertext,{}),line:{color:u.color,width:u.width,dash:u.dash,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:l({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:f.width,editType:\"calc\"},s(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},s(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:l({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1222:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,f,h=e._length,p=new Array(h),d=!1;for(c=0;c<h;c++)if(u=e.a[c],f=e.b[c],n(u)&&n(f)){var g=r.ab2xy(+u,+f,!0),m=r.isVisible(+u,+f);m||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:f,vis:m}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,h),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":981,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1223:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),m=Math.min(d.length,g.length);if(m){e._length=m,p(\"text\"),p(\"texttemplate\"),p(\"hovertext\"),p(\"mode\",m<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&c(t,e,h,p);var v=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),v.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),\"fills\"!==p(\"hoveron\",v.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1221}],1224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1225:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r={},n=e._carpet,i=n.ab2ij([t.a,t.b]),a=Math.floor(i[0]),o=i[0]-a,s=Math.floor(i[1]),l=i[1]-s,c=n.evalxy([],a,s,o,l);return r.yLabel=c[1].toFixed(3),r}},{}],1226:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,f=c-u;return s.x0=Math.max(Math.min(s.x0,f),u),s.x1=Math.max(Math.min(s.x1,f),u),o}var h=s.cd[s.index];s.a=h.a,s.b=h.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=p._module.formatLabels(h,p);s.yLabel=g.yLabel,delete s.text;var m=[];if(!p.hovertemplate){var v=(h.hi||p.hoverinfo).split(\"+\");-1!==v.indexOf(\"all\")&&(v=[\"a\",\"b\",\"text\"]),-1!==v.indexOf(\"a\")&&y(d.aaxis,h.a),-1!==v.indexOf(\"b\")&&y(d.baxis,h.b),m.push(\"y: \"+s.yLabel),-1!==v.indexOf(\"text\")&&i(h,p,m),s.extraText=m.join(\"<br>\")}return o}function y(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,m.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":778,\"../scatter/hover\":1198}],1227:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1221,\"./calc\":1222,\"./defaults\":1223,\"./event_data\":1224,\"./format_labels\":1225,\"./hover\":1226,\"./plot\":1228}],1228:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,f={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,f,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":665,\"../../plots/cartesian/axes\":828,\"../scatter/plot\":1208}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,f=a.marker,h=a.line,p=f.line;e.exports=u({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\",\"geojson-id\"],dflt:\"ISO-3\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:{valType:\"string\",editType:\"calc\",dflt:\"id\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"location\",\"text\"]}),hovertext:c({},a.hovertext,{}),textfont:a.textfont,textposition:a.textposition,line:{color:h.color,width:h.width,dash:l},connectgaps:a.connectgaps,marker:c({symbol:f.symbol,opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,colorbar:f.colorbar,line:c({width:p.width},s(\"marker.line\")),gradient:f.gradient},s(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:a.fillcolor,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1230:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;function c(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,u=Array.isArray(e.locations),f=u?e.locations.length:e._length,h=new Array(f);r=e.geojson?function(t){return c(t)||n(t)}:c;for(var p=0;p<f;p++){var d=h[p]={};if(u){var g=e.locations[p];d.loc=r(g)?g:null}else{var m=e.lon[p],v=e.lat[p];n(m)&&n(v)?d.lonlat=[+m,+v]:d.lonlat=[i,i]}}return o(h,e),a(t,e),s(h,e),f&&(h[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),h}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}var h,p=f(\"locations\");if(p&&p.length){var d,g=f(\"geojson\");(\"string\"==typeof g&&\"\"!==g||n.isPlainObject(g))&&(d=\"geojson-id\"),\"geojson-id\"===f(\"locationmode\",d)&&f(\"featureidkey\"),h=p.length}else{var m=f(\"lon\")||[],v=f(\"lat\")||[];h=Math.min(m.length,v.length)}h?(e._length=h,f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,f),f(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,f,{gradient:!0}),i.hasText(e)&&(f(\"texttemplate\"),s(t,e,u,f)),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)):e.visible=!1}},{\"../../lib\":778,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1229}],1232:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.geo]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":828}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/get_trace_color\"),o=t(\"../../lib\").fillText,s=t(\"./attributes\");e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=h.projection.isLonLatOverEdges,d=h.project;if(n.getClosest(l,(function(t){var n=t.lonlat;if(n[0]===i)return 1/0;if(p(n))return 1/0;var a=d(n),o=d([e,r]),s=Math.abs(a[0]-o[0]),l=Math.abs(a[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[u.c2p(m),f.c2p(m)],y=g.mrc||1;t.x0=v[0]-y,t.x1=v[0]+y,t.y0=v[1]-y,t.y1=v[1]+y,t.loc=g.loc,t.lon=m[0],t.lat=m[1];var x={};x[c.geo]={_subplot:h};var b=c._module.formatLabels(g,c,x);return t.lonLabel=b.lonLabel,t.latLabel=b.latLabel,t.color=a(c,g),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?s.hoverinfo.flags:i.split(\"+\"),l=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),f=-1!==a.indexOf(\"text\"),h=[];function p(t){return t+\"\\xb0\"}l?h.push(e.loc):c&&u?h.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?h.push(n.lon+p(r.lonLabel)):u&&h.push(n.lat+p(r.latLabel));f&&o(e,t,h);return h.join(\"<br>\")}(c,g,t,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/get_trace_color\":1197,\"./attributes\":1229}],1235:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":860,\"../scatter/marker_colorbar\":1205,\"../scatter/style\":1211,\"./attributes\":1229,\"./calc\":1230,\"./defaults\":1231,\"./event_data\":1232,\"./format_labels\":1233,\"./hover\":1234,\"./plot\":1236,\"./select\":1237,\"./style\":1238}],1236:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/topojson_utils\").getTopojsonFeatures,o=t(\"../../lib/geojson_utils\"),s=t(\"../../lib/geo_location_utils\"),l=t(\"../../plots/cartesian/autorange\").findExtremes,c=t(\"../../constants/numerical\").BADNUM,u=t(\"../scatter/calc\").calcMarkerSize,f=t(\"../scatter/subtypes\"),h=t(\"./style\");e.exports={calcGeoJSON:function(t,e){var r,n,i=t[0].trace,o=e[i.geo],f=o._subplot,h=i._length;if(Array.isArray(i.locations)){var p=i.locationmode,d=\"geojson-id\"===p?s.extractTraceFeature(t):a(i,f.topojson);for(r=0;r<h;r++){n=t[r];var g=\"geojson-id\"===p?n.fOut:s.locationToFeature(p,n.loc,d);n.lonlat=g?g.properties.ct:[c,c]}}var m,v,y={padded:!0};if(\"geojson\"===o.fitbounds&&\"geojson-id\"===i.locationmode){var x=s.computeBbox(s.getTraceGeojson(i));m=[x[0],x[2]],v=[x[1],x[3]]}else{for(m=new Array(h),v=new Array(h),r=0;r<h;r++)n=t[r],m[r]=n.lonlat[0],v[r]=n.lonlat[1];y.ppad=u(i,h)}i._extremes.lon=l(o.lonaxis._ax,m,y),i._extremes.lat=l(o.lataxis._ax,v,y)},plot:function(t,e,r){var a=e.layers.frontplot.select(\".scatterlayer\"),s=i.makeTraceGroups(a,r,\"trace scattergeo\");function l(t,e){t.lonlat[0]===c&&n.select(e).remove()}s.selectAll(\"*\").remove(),s.each((function(e){var r=n.select(this),a=e[0].trace;if(f.hasLines(a)||\"none\"!==a.fill){var s=o.calcTraceToLineCoords(e),c=\"none\"!==a.fill?o.makePolygon(s):o.makeLine(s);r.selectAll(\"path.js-line\").data([{geojson:c,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}f.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each((function(t){l(t,this)})),f.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each((function(t){l(t,this)})),h(t,e)}))}}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/geojson_utils\":772,\"../../lib/topojson_utils\":806,\"../../plots/cartesian/autorange\":827,\"../scatter/calc\":1188,\"../scatter/subtypes\":1212,\"./style\":1238,d3:169}],1237:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,f=t.yaxis,h=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=f.c2p(a),e.contains([o,s],null,l,t)?(h.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return h}},{\"../../constants/numerical\":753,\"../scatter/subtypes\":1212}],1238:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each((function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)}))}(t,e)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../scatter/style\":1211,d3:169}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,f=u.line,h=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,xperiod:i.xperiod,yperiod:i.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:i.xperiodalignment,yperiodalignment:i.yperiodalignment,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:f.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");h.x.editType=h.y.editType=h.x0.editType=h.y0.editType=\"calc+clearAxisTypes\",h.hovertemplate=i.hovertemplate,h.texttemplate=i.texttemplate},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../scatter/attributes\":1187,\"./constants\":1241}],1240:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../../plots/cartesian/align_period\"),l=t(\"../scatter/calc\"),c=l.calcMarkerSize,u=l.calcAxisExpansion,f=l.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),p=t(\"./convert\"),d=t(\"./scene_update\"),g=t(\"../../constants/numerical\").BADNUM,m=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,l,y=t._fullLayout,x=a.getFromId(t,e.xaxis),b=a.getFromId(t,e.yaxis),_=y._plots[e.xaxis+e.yaxis],w=e._length,T=w>=m,k=2*w,M={},A=x.makeCalcdata(e,\"x\"),S=b.makeCalcdata(e,\"y\"),E=s(e,x,\"x\",A),C=s(e,b,\"y\",S);e._x=E,e._y=C,e.xperiodalignment&&(e._origX=A),e.yperiodalignment&&(e._origY=S);var L=new Array(k);for(r=0;r<w;r++)o=E[r],l=C[r],L[2*r]=o===g?NaN:o,L[2*r+1]=l===g?NaN:l;if(\"log\"===x.type)for(r=0;r<k;r+=2)L[r]=x.c2l(L[r]);if(\"log\"===b.type)for(r=1;r<k;r+=2)L[r]=b.c2l(L[r]);if(T&&\"log\"!==x.type&&\"log\"!==b.type)M.tree=n(L);else{var I=M.ids=new Array(w);for(r=0;r<w;r++)I[r]=r}h(t,e);var P,z=function(t,e,r,n,a,o){var s=p.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,p.linePositions(t,r,n));if(s.errorX||s.errorY){var l=p.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},p.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},p.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},p.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,L,E,C),O=d(t,_);return f(y,e),T?z.marker&&(P=2*(z.marker.sizeAvg||Math.max(z.marker.size,3))):P=c(e,w),u(t,e,x,b,E,C,P),z.errorX&&v(e,x,z.errorX),z.errorY&&v(e,b,z.errorY),z.fill&&!O.fill2d&&(O.fill2d=!0),z.marker&&!O.scatter2d&&(O.scatter2d=!0),z.line&&!O.line2d&&(O.line2d=!0),!z.errorX&&!z.errorY||O.error2d||(O.error2d=!0),z.text&&!O.glText&&(O.glText=!0),z.marker&&(z.marker.snap=w),O.lineOptions.push(z.line),O.errorXOptions.push(z.errorX),O.errorYOptions.push(z.errorY),O.fillOptions.push(z.fill),O.markerOptions.push(z.marker),O.markerSelectedOptions.push(z.markerSel),O.markerUnselectedOptions.push(z.markerUnsel),O.textOptions.push(z.text),O.textSelectedOptions.push(z.textSel),O.textUnselectedOptions.push(z.textUnsel),O.selectBatch.push([]),O.unselectBatch.push([]),M._scene=O,M.index=O.count,M.x=E,M.y=C,M.positions=L,O.count++,[{x:!1,y:!1,t:M,trace:e}]}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/autorange\":827,\"../../plots/cartesian/axis_ids\":831,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"./constants\":1241,\"./convert\":1242,\"./scene_update\":1250,\"@plotly/point-cluster\":57}],1241:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1242:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/subtypes\"),h=t(\"../scatter/make_bubble_size_func\"),p=t(\"./helpers\"),d=t(\"./constants\"),g=t(\"../../constants/interactions\").DESELECTDIM,m={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1},v=t(\"../../components/fx/helpers\").appendArrayPointValue;function y(t,e){var r,i=t._fullLayout,a=e._length,o=e.textfont,l=e.textposition,c=Array.isArray(l)?l:[l],u=o.color,f=o.size,h=o.family,p={},d=e.texttemplate;if(d){p.text=[];var g=i._d3locale,m=Array.isArray(d),y=m?Math.min(d.length,a):a,x=m?function(t){return d[t]}:function(){return d};for(r=0;r<y;r++){var b={i:r},_=e._module.formatLabels(b,e,i),w={};v(w,e,r);var T=e._meta||{};p.text.push(s.texttemplateString(x(r),_,g,w,b,T))}}else Array.isArray(e.text)&&e.text.length<a?p.text=e.text.slice():p.text=e.text;if(Array.isArray(p.text))for(r=p.text.length;r<a;r++)p.text[r]=\"\";for(p.opacity=e.opacity,p.font={},p.align=[],p.baseline=[],r=0;r<c.length;r++){var k=c[r].split(/\\s+/);switch(k[1]){case\"left\":p.align.push(\"right\");break;case\"right\":p.align.push(\"left\");break;default:p.align.push(k[1])}switch(k[0]){case\"top\":p.baseline.push(\"bottom\");break;case\"bottom\":p.baseline.push(\"top\");break;default:p.baseline.push(k[0])}}if(Array.isArray(u))for(p.color=new Array(a),r=0;r<a;r++)p.color[r]=u[r];else p.color=u;if(s.isArrayOrTypedArray(f)||Array.isArray(h))for(p.font=new Array(a),r=0;r<a;r++){var M=p.font[r]={};M.size=s.isTypedArray(f)?f[r]:Array.isArray(f)?n(f[r])?f[r]:0:f,M.family=Array.isArray(h)?h[r]:h}else p.font={size:f,family:h};return p}function x(t){var e,r,n=t._length,i=t.marker,o={},l=s.isArrayOrTypedArray(i.symbol),c=s.isArrayOrTypedArray(i.color),f=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),m=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.isOpenSymbol(i.symbol)),l||c||f||d){o.colors=new Array(n),o.borderColors=new Array(n);var v=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(v[0])){var b=v;for(v=Array(n),e=0;e<n;e++)v[e]=b}for(o.colors=v,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.isOpenSymbol(_)}r&&(y[e]=v[e].slice(),v[e]=v[e].slice(),v[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=E(i.symbol[e]);else o.marker=E(i.symbol);var w,T=h(t);if(g||m){var k,M=o.sizes=new Array(n),A=o.borderSizes=new Array(n),S=0;if(g){for(e=0;e<n;e++)M[e]=T(i.size[e]),S+=M[e];k=S/n}else for(w=T(i.size),e=0;e<n;e++)M[e]=w;if(m)for(e=0;e<n;e++)A[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)A[e]=w;o.sizeAvg=k}else o.size=T(i&&i.size||10),o.borderSizes=T(i.line.width);return o}function b(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=x(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function _(t,e,r){var n={};if(!r)return n;if(r.textfont){var i={opacity:1,text:e.text,texttemplate:e.texttemplate,textposition:e.textposition,textfont:s.extendFlat({},e.textfont)};r.textfont&&s.extendFlat(i.textfont,r.textfont),n=y(t,i)}return n}function w(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var T=d.SYMBOL_SDF_SIZE,k=d.SYMBOL_SIZE,M=d.SYMBOL_STROKE,A={},S=l.symbolFuncs[0](.05*k);function E(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.isDotSymbol(t);return A[t]?A[t]:(e=c&&!o?a(1.1*k)+S:a(k),r=i(e,{w:T,h:T,viewBox:[-k,-k,k,k],stroke:s?M:-M}),A[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(f.hasText(e)&&(n.text=y(t,e),n.textSel=_(t,e,e.selected),n.textUnsel=_(t,e,e.unselected)),f.hasMarkers(e)&&(n.marker=x(e),n.markerSel=b(e,e.selected),n.markerUnsel=b(e,e.unselected),!e.unselected&&s.isArrayOrTypedArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=g*i[r]}if(f.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(d.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=w(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=w(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:x,markerSelection:b,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(f.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>d.TOO_MANY_POINTS||f.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var h=n[0],p=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=h,n[i+1]=p):(h=n[i],p=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),f=r.length/2,h={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*f),d=1/0,g=-1/0,m=0,v=0;m<f;m++,v+=4){var y=t[m];if(n(y)){var x=r[2*m+c],b=l(y,m),_=b[0],w=b[1];if(n(_)&&n(w)){var T=y-_,k=y+w;p[v+u[0]]=x-i.c2l(T),p[v+u[1]]=i.c2l(k)-x,p[v+u[2]]=0,p[v+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}h[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),h},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(f.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,h=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,g=m[p],v=m[d],y=u?u/.8+1:0,x=-v*y-.5*v;o.offset[i]=[g*y/h,x/h]}}return o}}},{\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../constants/interactions\":752,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/cartesian/axis_ids\":831,\"../../registry\":911,\"../scatter/make_bubble_size_func\":1204,\"../scatter/subtypes\":1212,\"./constants\":1241,\"./helpers\":1246,\"color-normalize\":125,\"fast-isnumeric\":241,\"svg-path-sdf\":574}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./helpers\"),o=t(\"./attributes\"),s=t(\"../scatter/constants\"),l=t(\"../scatter/subtypes\"),c=t(\"../scatter/xy_defaults\"),u=t(\"../scatter/period_defaults\"),f=t(\"../scatter/marker_defaults\"),h=t(\"../scatter/line_defaults\"),p=t(\"../scatter/fillcolor_defaults\"),d=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,g){function m(r,i){return n.coerce(t,e,o,r,i)}var v=!!t.marker&&a.isOpenSymbol(t.marker.symbol),y=l.isBubble(t),x=c(t,e,g,m);if(x){u(t,e,g,m);var b=x<s.PTS_LINESONLY?\"lines+markers\":\"lines\";m(\"text\"),m(\"hovertext\"),m(\"hovertemplate\"),m(\"mode\",b),l.hasLines(e)&&(m(\"connectgaps\"),h(t,e,r,g,m),m(\"line.shape\")),l.hasMarkers(e)&&(f(t,e,r,g,m),m(\"marker.line.width\",v||y?1:0)),l.hasText(e)&&(m(\"texttemplate\"),d(t,e,g,m));var _=(e.line||{}).color,w=(e.marker||{}).color;m(\"fill\"),\"none\"!==e.fill&&p(t,e,r,m);var T=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");T(t,e,_||w||r,{axis:\"y\"}),T(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,m)}else e.visible=!1}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/period_defaults\":1207,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"../scatter/xy_defaults\":1214,\"./attributes\":1239,\"./helpers\":1246}],1244:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,f=c.selectBatch[u],h=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},m=n.extendFlat({},p);if(f.length||h.length){var v=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(m.color=new Array(s._length),e=0;e<f.length;e++)r=f[e],m.color[r]=v||(b?x[r]:x);for(e=0;e<h.length;e++){r=h[e];var _=b?x[r]:x;m.color[r]=y||(v?_:i.addOpacity(_,a))}}c.glText[u].update(m)}}},{\"../../components/color\":643,\"../../constants/interactions\":752,\"../../lib\":778}],1245:[function(t,e,r){\"use strict\";var n=t(\"../scatter/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"x\"in t||(t.x=e._x[i]),\"y\"in t||(t.y=e._y[i]),n(t,e,r)}},{\"../scatter/format_labels\":1196}],1246:[function(t,e,r){\"use strict\";var n=t(\"./constants\");r.isOpenSymbol=function(t){return\"string\"==typeof t?n.OPEN_RE.test(t):t%200>100},r.isDotSymbol=function(t){return\"string\"==typeof t?n.DOT_RE.test(t):t>200}},{\"./constants\":1241}],1247:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,f=t.index,h={pointNumber:f,x:e[f],y:r[f]};h.tx=Array.isArray(o.text)?o.text[f]:o.text,h.htx=Array.isArray(o.hovertext)?o.hovertext[f]:o.hovertext,h.data=Array.isArray(o.customdata)?o.customdata[f]:o.customdata,h.tp=Array.isArray(o.textposition)?o.textposition[f]:o.textposition;var p=o.textfont;p&&(h.ts=i.isArrayOrTypedArray(p.size)?p.size[f]:p.size,h.tc=Array.isArray(p.color)?p.color[f]:p.color,h.tf=Array.isArray(p.family)?p.family[f]:p.family);var d=o.marker;d&&(h.ms=i.isArrayOrTypedArray(d.size)?d.size[f]:d.size,h.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[f]:d.opacity,h.mx=i.isArrayOrTypedArray(d.symbol)?d.symbol[f]:d.symbol,h.mc=i.isArrayOrTypedArray(d.color)?d.color[f]:d.color);var g=d&&d.line;g&&(h.mlc=Array.isArray(g.color)?g.color[f]:g.color,h.mlw=i.isArrayOrTypedArray(g.width)?g.width[f]:g.width);var m=d&&d.gradient;m&&\"none\"!==m.type&&(h.mgt=Array.isArray(m.type)?m.type[f]:m.type,h.mgc=Array.isArray(m.color)?m.color[f]:m.color);var v=s.c2p(h.x,!0),y=l.c2p(h.y,!0),x=h.mrc||1,b=o.hoverlabel;b&&(h.hbg=Array.isArray(b.bgcolor)?b.bgcolor[f]:b.bgcolor,h.hbc=Array.isArray(b.bordercolor)?b.bordercolor[f]:b.bordercolor,h.hts=i.isArrayOrTypedArray(b.font.size)?b.font.size[f]:b.font.size,h.htc=Array.isArray(b.font.color)?b.font.color[f]:b.font.color,h.htf=Array.isArray(b.font.family)?b.font.family[f]:b.font.family,h.hnl=i.isArrayOrTypedArray(b.namelength)?b.namelength[f]:b.namelength);var _=o.hoverinfo;_&&(h.hi=Array.isArray(_)?_[f]:_);var w=o.hovertemplate;w&&(h.ht=Array.isArray(w)?w[f]:w);var T={};T[t.index]=h;var k=o._origX,M=o._origY,A=i.extendFlat({},t,{color:a(o,h),x0:v-x,x1:v+x,xLabelVal:k?k[f]:h.x,y0:y-x,y1:y+x,yLabelVal:M?M[f]:h.y,cd:T,distance:c,spikeDistance:u,hovertemplate:h.ht});return h.htx?A.text=h.htx:h.tx?A.text=h.tx:o.text&&(A.text=o.text),i.fillText(h,o,A),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(h,o,A),A}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,f,h,p,d=t.cd,g=d[0].t,m=d[0].trace,v=t.xa,y=t.ya,x=g.x,b=g.y,_=v.c2p(e),w=y.c2p(r),T=t.distance;if(g.tree){var k=v.p2c(_-T),M=v.p2c(_+T),A=y.p2c(w-T),S=y.p2c(w+T);i=\"x\"===n?g.tree.range(Math.min(k,M),Math.min(y._rl[0],y._rl[1]),Math.max(k,M),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(k,M),Math.min(A,S),Math.max(k,M),Math.max(A,S))}else i=g.ids;var E=T;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(v.c2p(s)-_))<E&&(E=u,f=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+f*f),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=v.c2p(s)-_,f=y.c2p(l)-w,(h=Math.sqrt(u*u+f*f))<E&&(E=p=h,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:[o(t,x,b,m)]},calcHover:o}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/get_trace_color\":1197}],1248:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/cross_trace_defaults\":1193,\"../scatter/marker_colorbar\":1205,\"./attributes\":1239,\"./calc\":1240,\"./defaults\":1243,\"./format_labels\":1245,\"./hover\":1247,\"./plot\":1249,\"./select\":1251}],1249:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../components/dragelement/helpers\").selectMode,c=t(\"../../lib/prepare_regl\"),u=t(\"../scatter/subtypes\"),f=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;function p(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}e.exports=function(t,e,r){if(r.length){var d,g,m=t._fullLayout,v=e._scene,y=e.xaxis,x=e.yaxis;if(v)if(c(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var b=v.count,_=m._glcanvas.data()[0].regl;if(f(t,e,r),v.dirty){if(!0===v.error2d&&(v.error2d=a(_)),!0===v.line2d&&(v.line2d=i(_)),!0===v.scatter2d&&(v.scatter2d=n(_,{constPointSize:!0})),!0===v.fill2d&&(v.fill2d=i(_)),!0===v.glText)for(v.glText=new Array(b),d=0;d<b;d++)v.glText[d]=new o(_);if(v.glText){if(b>v.glText.length){var w=b-v.glText.length;for(d=0;d<w;d++)v.glText.push(new o(_))}else if(b<v.glText.length){var T=v.glText.length-b;v.glText.splice(b,T).forEach((function(t){t.destroy()}))}for(d=0;d<b;d++)v.glText[d].update(v.textOptions[d])}if(v.line2d&&(v.line2d.update(v.lineOptions),v.lineOptions=v.lineOptions.map((function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t})),v.line2d.update(v.lineOptions)),v.error2d){var k=(v.errorXOptions||[]).concat(v.errorYOptions||[]);v.error2d.update(k)}v.scatter2d&&v.scatter2d.update(v.markerOptions),v.fillOrder=s.repeat(null,b),v.fill2d&&(v.fillOptions=v.fillOptions.map((function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=v.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(v.fillOrder[e]=u);var f,h,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(f=0;f<d.length&&isNaN(d[f+1]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h+1]);)h-=2;0!==d[f+1]&&(p=[d[f],0]),p=p.concat(d.slice(f,h+2)),0!==d[h+1]&&(p=p.concat([d[h],0]))}else if(\"tozerox\"===s.fill){for(f=0;f<d.length&&isNaN(d[f]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h]);)h-=2;0!==d[f]&&(p=[0,d[f+1]]),p=p.concat(d.slice(f,h+2)),0!==d[h]&&(p=p.concat([0,d[h+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var g=s._nexttrace;if(g){var m=v.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=g.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=v.lineOptions[e-1].positions,w=p.length/2,T=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(T.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=T}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}})),v.fill2d.update(v.fillOptions))}var M=m.dragmode,A=l(M),S=m.clickmode.indexOf(\"select\")>-1;for(d=0;d<b;d++){var E=r[d][0],C=E.trace,L=E.t,I=L.index,P=C._length,z=L.x,O=L.y;if(C.selectedpoints||A||S){if(A||(A=!0),C.selectedpoints){var D=v.selectBatch[I]=s.selIndices2selPoints(C),R={};for(g=0;g<D.length;g++)R[D[g]]=1;var F=[];for(g=0;g<P;g++)R[g]||F.push(g);v.unselectBatch[I]=F}var B=L.xpx=new Array(P),N=L.ypx=new Array(P);for(g=0;g<P;g++)B[g]=y.c2p(z[g]),N[g]=x.c2p(O[g])}else L.xpx=L.ypx=null}if(A){if(v.select2d||(v.select2d=n(m._glcanvas.data()[1].regl)),v.scatter2d){var j=new Array(b);for(d=0;d<b;d++)j[d]=v.selectBatch[d].length||v.unselectBatch[d].length?v.markerUnselectedOptions[d]:{};v.scatter2d.update(j)}v.select2d&&(v.select2d.update(v.markerOptions),v.select2d.update(v.markerSelectedOptions)),v.glText&&r.forEach((function(t){var e=((t||[])[0]||{}).trace||{};u.hasText(e)&&h(t)}))}else v.scatter2d&&v.scatter2d.update(v.markerOptions);var U={viewport:p(m,y,x),range:[(y._rl||y.range)[0],(x._rl||x.range)[0],(y._rl||y.range)[1],(x._rl||x.range)[1]]},V=s.repeat(U,v.count);v.fill2d&&v.fill2d.update(V),v.line2d&&v.line2d.update(V),v.error2d&&v.error2d.update(V.concat(V)),v.scatter2d&&v.scatter2d.update(V),v.select2d&&v.select2d.update(V),v.glText&&v.glText.forEach((function(t){t.update(U)}))}else v.init()}}},{\"../../components/dragelement/helpers\":661,\"../../lib\":778,\"../../lib/prepare_regl\":791,\"../scatter/link_traces\":1203,\"../scatter/subtypes\":1212,\"./edit_style\":1244,\"gl-text\":352,\"regl-error2d\":534,\"regl-line2d\":535,\"regl-scatter2d\":537}],1250:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,f=0;f<t;f++){if(e&&r.fillOrder[f]&&e.draw(r.fillOrder[f]),a&&r.lineOptions[f]&&a.draw(f),i&&(r.errorXOptions[f]&&i.draw(f),r.errorYOptions[f]&&i.draw(f+t)),o&&r.markerOptions[f])if(u[f].length){var h=n.repeat([],r.count);h[f]=u[f],o.draw(h)}else c[f].length||o.draw(f);s[f]&&r.textOptions[f]&&s[f].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach((function(t){t.destroy&&t.destroy()})),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":778}],1251:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,f=s._scene,h=s.index;if(!f)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var m=[],v=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(m.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):v.push(y);if(d){var x=f.scatter2d;if(m.length||v.length){if(!f.selectBatch[h].length&&!f.unselectBatch[h].length){var b=new Array(f.count);b[h]=f.markerUnselectedOptions[h],x.update.apply(x,b)}}else{var _=new Array(f.count);_[h]=f.markerOptions[h],x.update.apply(x,_)}}return f.selectBatch[h]=m,f.unselectBatch[h]=v,p&&i(r),a}},{\"../scatter/subtypes\":1212,\"./edit_style\":1244}],1252:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scattergeo/attributes\"),o=t(\"../scatter/attributes\"),s=t(\"../../plots/mapbox/layout_attributes\"),l=t(\"../../plots/attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll,h=a.line,p=a.marker;e.exports=f({lon:a.lon,lat:a.lat,mode:u({},o.mode,{dflt:\"markers\"}),text:u({},o.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"text\"]}),hovertext:u({},o.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:o.connectgaps,marker:u({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},angle:{valType:\"number\",dflt:\"auto\",arrayOk:!0},allowoverlap:{valType:\"boolean\",dflt:!1},opacity:p.opacity,size:p.size,sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode},c(\"marker\")),fill:a.fill,fillcolor:o.fillcolor,textfont:s.layers.symbol.textfont,textposition:s.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:o.selected.marker},unselected:{marker:o.unselected.marker},hoverinfo:u({},l.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/mapbox/layout_attributes\":887,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"../scattergeo/attributes\":1229}],1253:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),f=t(\"../../plots/mapbox/convert_text_opts\"),h=t(\"../../components/fx/helpers\").appendArrayPointValue,p=t(\"../../lib/svg_text_utils\").NEWLINES,d=t(\"../../lib/svg_text_utils\").BR_TAG_ALL;function g(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function m(t,e){return i.isArrayOrTypedArray(t)?e?function(e){return n(t[e])?+t[e]:0}:function(e){return t[e]}:t?function(){return t}:v}function v(){return\"\"}function y(t){return t[0]===a}e.exports=function(t,e){var r,a=e[0].trace,x=!0===a.visible&&0!==a._length,b=\"none\"!==a.fill,_=u.hasLines(a),w=u.hasMarkers(a),T=u.hasText(a),k=w&&\"circle\"===a.marker.symbol,M=w&&\"circle\"!==a.marker.symbol,A=g(),S=g(),E=g(),C=g(),L={fill:A,line:S,circle:E,symbol:C};if(!x)return L;if((b||_)&&(r=o.calcTraceToLineCoords(e)),b&&(A.geojson=o.makePolygon(r),A.layout.visibility=\"visible\",i.extendFlat(A.paint,{\"fill-color\":a.fillcolor})),_&&(S.geojson=o.makeLine(r),S.layout.visibility=\"visible\",i.extendFlat(S.paint,{\"line-width\":a.line.width,\"line-color\":a.line.color,\"line-opacity\":a.opacity})),k){var I=function(t){var e,r,a,o,u=t[0].trace,f=u.marker,h=u.selectedpoints,p=i.isArrayOrTypedArray(f.color),d=i.isArrayOrTypedArray(f.size),g=i.isArrayOrTypedArray(f.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(f):i.identity);d&&(a=c(u));g&&(o=function(t){return m(n(t)?+i.constrain(t,0,1):0)});var v,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!y(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),h&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(h)for(v=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var T=x[e].properties;v.selectedOpacityFn&&(T.mo=m(v.selectedOpacityFn(T))),v.selectedColorFn&&(T.mcc=v.selectedColorFn(T)),v.selectedSizeFn&&(T.mrc=v.selectedSizeFn(T))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||v&&v.selectedColorFn?{type:\"identity\",property:\"mcc\"}:f.color,mrc:d||v&&v.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(k=f.size,k/2),mo:g||v&&v.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(f.opacity)};var k}(e);E.geojson=I.geojson,E.layout.visibility=\"visible\",i.extendFlat(E.paint,{\"circle-color\":I.mcc,\"circle-radius\":I.mrc,\"circle-opacity\":I.mo})}if((M||T)&&(C.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,a=n.marker||{},o=a.symbol,s=a.angle,l=\"circle\"!==o?m(o):v,c=\"auto\"!==s?m(s,!0):v,f=u.hasText(n)?m(n.text):v,g=[],x=0;x<t.length;x++){var b=t[x];if(!y(b.lonlat)){var _,w=n.texttemplate;if(w){var T=Array.isArray(w)?w[x]||\"\":w,k=n._module.formatLabels(b,n,r),M={};h(M,n,b.i);var A=n._meta||{};_=i.texttemplateString(T,k,r._d3locale,M,b,A)}else _=f(x);_&&(_=_.replace(p,\"\").replace(d,\"\\n\")),g.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:b.lonlat},properties:{symbol:l(x),angle:c(x),text:_}})}}return{type:\"FeatureCollection\",features:g}}(e,t),i.extendFlat(C.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),M&&(i.extendFlat(C.layout,{\"icon-size\":a.marker.size/10}),\"angle\"in a.marker&&\"auto\"!==a.marker.angle&&i.extendFlat(C.layout,{\"icon-rotate\":{type:\"identity\",property:\"angle\"},\"icon-rotation-alignment\":\"map\"}),C.layout[\"icon-allow-overlap\"]=a.marker.allowoverlap,i.extendFlat(C.paint,{\"icon-opacity\":a.opacity*a.marker.opacity,\"icon-color\":a.marker.color})),T)){var P=(a.marker||{}).size,z=f(a.textposition,P);i.extendFlat(C.layout,{\"text-size\":a.textfont.size,\"text-anchor\":z.anchor,\"text-offset\":z.offset}),i.extendFlat(C.paint,{\"text-color\":a.textfont.color,\"text-opacity\":a.opacity})}return L}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geojson_utils\":772,\"../../lib/svg_text_utils\":803,\"../../plots/mapbox/convert_text_opts\":884,\"../scatter/make_bubble_size_func\":1204,\"../scatter/subtypes\":1212,\"fast-isnumeric\":241}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,f)){if(f(\"text\"),f(\"texttemplate\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),f(\"below\"),i.hasLines(e)&&(o(t,e,r,u,f,{noDash:!0}),f(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,f,{noLine:!0}),f(\"marker.allowoverlap\"),f(\"marker.angle\");var h=e.marker;\"circle\"!==h.symbol&&(n.isArrayOrTypedArray(h.size)&&(h.size=h.size[0]),n.isArrayOrTypedArray(h.color)&&(h.color=h.color[0]))}i.hasText(e)&&s(t,e,u,f,{noSelect:!0}),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1252}],1255:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":828}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,(function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=h.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-f.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[i.modHalf(m[0],360)+p,m[1]],y=u.c2p(v),x=f.c2p(v),b=g.mrc||1;t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b;var _={};_[c.subplot]={_subplot:h};var w=c._module.formatLabels(g,c,_);return t.lonLabel=w.lonLabel,t.latLabel=w.latLabel,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/get_trace_color\":1197}],1258:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/mapbox\":885,\"../scatter/marker_colorbar\":1205,\"../scattergeo/calc\":1230,\"./attributes\":1252,\"./defaults\":1254,\"./event_data\":1255,\"./format_labels\":1256,\"./hover\":1257,\"./plot\":1259,\"./select\":1260}],1259:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.type=\"scattermapbox\",this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(o.gd,t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(t.gd,e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],f=s[u];i.addSource(u,f),i.addLayer(u,f,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":883,\"./convert\":1253}],1260:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var f=o[r],h=f.lonlat;if(h[0]!==a){var p=[n.modHalf(h[0],360),h[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:h[0],lat:h[1]}),f.selected=1):f.selected=0}}return c}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/subtypes\":1212}],1261:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"../scatter/attributes\"),s=t(\"../../plots/attributes\"),l=o.line;e.exports={mode:o.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:o.text,texttemplate:i({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:o.hovertext,line:{color:l.color,width:l.width,dash:l.dash,shape:a({},l.shape,{values:[\"linear\",\"spline\"]}),smoothing:l.smoothing,editType:\"calc\"},connectgaps:o.connectgaps,marker:o.marker,cliponaxis:a({},o.cliponaxis,{dflt:!1}),textposition:o.textposition,textfont:o.textfont,fill:a({},o.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:o.fillcolor,hoverinfo:a({},s.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:o.hoveron,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1262:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,f=r[u].radialaxis,h=r[u].angularaxis,p=f.makeCalcdata(e,\"r\"),d=h.makeCalcdata(e,\"theta\"),g=e._length,m=new Array(g),v=0;v<g;v++){var y=p[v],x=d[v],b=m[v]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(f,p,{ppad:_}),o(t,e),s(m,e),l(m,e),m}},{\"../../constants/numerical\":753,\"../../plots/cartesian/axes\":828,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1263:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");function h(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:h,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,f,r,i)}var g=h(t,e,p,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&(d(\"texttemplate\"),l(t,e,p,d));var m=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),m.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),d(\"hoveron\",m.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1261}],1264:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var a,o,s={},l=r[e.subplot]._subplot;l?(a=l.radialAxis,o=l.angularAxis):(a=(l=r[e.subplot]).radialaxis,o=l.angularaxis);var c=a.c2l(t.r);s.rLabel=i.tickText(a,c,!0).text;var u=\"degrees\"===o.thetaunit?n.rad2deg(t.theta):t.theta;return s.thetaLabel=i.tickText(o,u,!0).text,s}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1265:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");function i(t,e,r,n){var i=r.radialAxis,a=r.angularAxis;i._hovertitle=\"r\",a._hovertitle=\"\\u03b8\";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.rLabel=s.rLabel,n.thetaLabel=s.thetaLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var f=l.split(\"+\");-1!==f.indexOf(\"all\")&&(f=[\"r\",\"theta\",\"text\"]),-1!==f.indexOf(\"r\")&&u(i,n.rLabel),-1!==f.indexOf(\"theta\")&&u(a,n.thetaLabel),-1!==f.indexOf(\"text\")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,i(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:i}},{\"../scatter/hover\":1198}],1266:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":894,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1261,\"./calc\":1262,\"./defaults\":1263,\"./format_labels\":1264,\"./hover\":1265,\"./plot\":1267}],1267:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],f=0;f<u.length;f++){var h=u[f],p=h.r;if(p===i)h.x=h.y=i;else{var d=s.c2g(p),g=l.c2g(h.theta);h.x=d*Math.cos(g),h.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":753,\"../scatter/plot\":1208}],1268:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\"),a=t(\"../../plots/template_attributes\").texttemplateAttrs;e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,texttemplate:a({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../../plots/template_attributes\":906,\"../scattergl/attributes\":1239,\"../scatterpolar/attributes\":1261}],1269:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,f=e._r=c.makeCalcdata(e,\"r\"),h=e._theta=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<f.length&&(f=f.slice(0,p)),p<h.length&&(h=h.slice(0,p)),d.r=f,d.theta=h,n(t,e);var g,m=d.opts=a.style(t,e);return p<s?g=i(e,p):m.marker&&(g=2*(m.marker.sizeAvg||Math.max(m.marker.size,3))),e._extremes.x=o.findExtremes(c,f,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":828,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242}],1270:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d=a(t,e,h,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,h,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,h,p),i.hasText(e)&&(p(\"texttemplate\"),l(t,e,h,p)),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"../scatterpolar/defaults\":1263,\"./attributes\":1268}],1271:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"r\"in t||(t.r=e._r[i]),\"theta\"in t||(t.theta=e._theta[i]),n(t,e,r)}},{\"../scatterpolar/format_labels\":1264}],1272:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var f=t.subplot,h=u.cd[u.index],p=u.trace;if(h.r=s[u.index],h.theta=l[u.index],f.isPtInside(h))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(h,p,f,u),c}}}},{\"../scattergl/hover\":1247,\"../scatterpolar/hover\":1265}],1273:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":894,\"../scatter/marker_colorbar\":1205,\"../scattergl/select\":1251,\"./attributes\":1268,\"./calc\":1269,\"./defaults\":1270,\"./format_labels\":1271,\"./hover\":1272,\"./plot\":1274}],1274:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,f=e.angularAxis,h=o(t,e);return r.forEach((function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,m=d.r,v=d.theta,y=d.opts,x=m.slice(),b=v.slice();for(a=0;a<m.length;a++)e.isPtInside({r:m[a],theta:v[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),T=Array(g);for(a=0;a<g;a++){var k,M,A=x[a];if(i(A)){var S=u.c2g(A),E=f.c2g(b[a],p.thetaunit);k=S*Math.cos(E),M=S*Math.sin(E)}else k=M=NaN;w[a]=_[2*a]=k,T[a]=_[2*a+1]=M}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!h.fill2d&&(h.fill2d=!0),y.marker&&!h.scatter2d&&(h.scatter2d=!0),y.line&&!h.line2d&&(h.line2d=!0),y.text&&!h.glText&&(h.glText=!0),h.lineOptions.push(y.line),h.fillOptions.push(y.fill),h.markerOptions.push(y.marker),h.markerSelectedOptions.push(y.markerSel),h.markerUnselectedOptions.push(y.markerUnsel),h.textOptions.push(y.text),h.textSelectedOptions.push(y.textSel),h.textUnselectedOptions.push(y.textUnsel),h.selectBatch.push([]),h.unselectBatch.push([]),d.x=w,d.y=T,d.rawx=w,d.rawy=T,d.r=m,d.theta=v,d.positions=_,d._scene=h,d.index=h.count,h.count++}})),a(t,e,r)}}},{\"../../lib\":778,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242,\"../scattergl/plot\":1249,\"../scattergl/scene_update\":1250,\"@plotly/point-cluster\":57,\"fast-isnumeric\":241}],1275:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=a.marker,f=a.line,h=u.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"a\",\"b\",\"c\",\"text\"]}),hovertext:c({},a.hovertext,{}),line:{color:f.color,width:f.width,dash:l,shape:c({},f.shape,{values:[\"linear\",\"spline\"]}),smoothing:f.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,cliponaxis:a.cliponaxis,fill:c({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:h.width,editType:\"calc\"},s(\"marker.line\")),gradient:u.gradient,editType:\"calc\"},s(\"marker\")),textfont:a.textfont,textposition:a.textposition,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1276:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,f,h,p,d,g=t._fullLayout[e.subplot].sum,m=e.sum||g,v={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!v[f=l[r]]){for(p=v[c[f][0]],d=v[c[f][1]],h=new Array(p.length),u=0;u<p.length;u++)h[u]=m-p[u]-d[u];v[f]=h}var y,x,b,_,w,T,k=e._length,M=new Array(k);for(r=0;r<k;r++)y=v.a[r],x=v.b[r],b=v.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),T=y,w=b-x,M[r]={x:w,y:T,a:y,b:x,c:b}):M[r]={x:!1,y:!1};return s(e,k),i(t,e),a(M,e),o(M,e),M}},{\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1277:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d,g=p(\"a\"),m=p(\"b\"),v=p(\"c\");if(g?(d=g.length,m?(d=Math.min(d,m.length),v&&(d=Math.min(d,v.length))):d=v?Math.min(d,v.length):0):m&&v&&(d=Math.min(m.length,v.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&(p(\"texttemplate\"),c(t,e,h,p));var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1275}],1278:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1279:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot;return i.aLabel=n.tickText(a.aaxis,t.a,!0).text,i.bLabel=n.tickText(a.baxis,t.b,!0).text,i.cLabel=n.tickText(a.caxis,t.c,!0).text,i}},{\"../../plots/cartesian/axes\":828}],1280:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");e.exports=function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var o=a[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),a}var f=o.cd[o.index],h=o.trace,p=o.subplot;o.a=f.a,o.b=f.b,o.c=f.c,o.xLabelVal=void 0,o.yLabelVal=void 0;var d={};d[h.subplot]={_subplot:p};var g=h._module.formatLabels(f,h,d);o.aLabel=g.aLabel,o.bLabel=g.bLabel,o.cLabel=g.cLabel;var m=f.hi||h.hoverinfo,v=[];if(!h.hovertemplate){var y=m.split(\"+\");-1!==y.indexOf(\"all\")&&(y=[\"a\",\"b\",\"c\"]),-1!==y.indexOf(\"a\")&&x(p.aaxis,o.aLabel),-1!==y.indexOf(\"b\")&&x(p.baxis,o.bLabel),-1!==y.indexOf(\"c\")&&x(p.caxis,o.cLabel)}return o.extraText=v.join(\"<br>\"),o.hovertemplate=h.hovertemplate,a}function x(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../scatter/hover\":1198}],1281:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":907,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1275,\"./calc\":1276,\"./defaults\":1277,\"./event_data\":1278,\"./format_labels\":1279,\"./hover\":1280,\"./plot\":1282}],1282:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1208}],1283:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,f=u.line,h=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},f.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:h,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"../scattergl/attributes\":1239}],1284:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine;function u(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var f=l(t,e._diag[s][1]);f&&(c[1]=f.r2l(f.range[0]),c[3]=f.r2l(f.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],f=u.xaxis,h=u.yaxis,p=f._gridVals,d=h._gridVals,g=n.b+h.domain[0]*n.h,m=-h._m,v=-m*h.r2l(h.range[0],h.calendar);if(f.showgrid)for(e=0;e<p.length;e++)s=f._offset+f.l2p(p[e].x),o(\"grid\",f,s,g,s,g+h._length);if(h.showgrid)for(e=0;e<d.length;e++)l=g+v+m*d[e].x,o(\"grid\",h,f._offset,l,f._offset+f._length,l);c(t,f,h)&&(s=f._offset+f.l2p(0),o(\"zeroline\",f,s,g,s,g+h._length)),c(t,h,f)&&(l=g+v+0,o(\"zeroline\",h,f._offset,l,f._offset+f._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:\"splom\",attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(\"splom\"),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&u(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":791,\"../../plots/cartesian\":841,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_ids\":831,\"../../plots/get_data\":865,\"../../registry\":911,\"regl-line2d\":535}],1285:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),f=t(\"../../constants/numerical\").BADNUM,h=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,m,v,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],T=e._visibleDims=[];function k(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===f?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),m=i.getFromId(t,e._diag[r][1]),g&&m&&g.type!==m.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(k(g,d),m&&\"category\"===m.type&&(m._categories=g._categories.slice())):k(m,d),T.push(r)}for(s(t,e),n.extendFlat(b,c(e)),v=_.length*x>h?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<T.length;p++)d=y[r=T[p]],g=i.getFromId(t,e._diag[r][0])||{},m=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,m,_[p],_[p],v);var M=u(t,e);return M.matrix||(M.matrix=!0),M.matrixOptions=b,M.selectedOptions=l(e,e.selected),M.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242,\"./scene_update\":1292}],1286:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=t(\"../scattergl/helpers\").isOpenSymbol;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=h(\"diagonal.visible\"),g=h(\"showupperhalf\"),m=h(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||m)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),s(t,e,r,f,h);var v=c(e.marker.symbol),y=o.isBubble(e);h(\"marker.line.width\",v||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,f=new Array(s),h=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";f[i]=\"x\"+p,h[i]=\"y\"+p}var d=n(\"xaxes\",f),g=n(\"yaxes\",h),m=e._diag=new Array(s);e._xaxes={},e._yaxes={};var v=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],T=0===i,k=i===s-1,M=T&&b||k&&_?void 0:d[i],A=T&&_||k&&b?void 0:g[i];x(M,A,w,v),x(A,M,w,y),m[i]=[M,A],e._axesDim[M]=i,e._axesDim[A]=i}for(i=0;i<v.length;i++)for(a=0;a<y.length;a++){var S=v[i]+y[a];i>a&&l||i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,f,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../parcoords/merge_length\":1158,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scattergl/helpers\":1246,\"./attributes\":1283}],1287:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":778,\"../scatter/colorscale_calc\":1190,\"../scattergl/convert\":1242}],1288:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1289:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),f=t.distance,h=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===h||!1===p)return[t];for(var d,g,m=o[h],v=o[p],y=f,x=0;x<m.length;x++){var b=m[x],_=v[x],w=s.c2p(b)-c,T=l.c2p(_)-u,k=Math.sqrt(w*w+T*T);k<y&&(y=g=k,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:[i(t,m,v,a)]}}},{\"../scattergl/hover\":1247,\"./helpers\":1288}],1290:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":687,\"../../registry\":911,\"../scatter/marker_colorbar\":1205,\"./attributes\":1283,\"./base_plot\":1284,\"./calc\":1285,\"./defaults\":1286,\"./edit_style\":1287,\"./hover\":1289,\"./plot\":1291,\"./select\":1293}],1291:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../components/dragelement/helpers\").selectMode;function s(t,e){var r,s,l,c,u,f=t._fullLayout,h=f._size,p=e.trace,d=e.t,g=f._splomScenes[p.uid],m=g.matrixOptions,v=m.cdata,y=f._glcanvas.data()[0].regl,x=f.dragmode;if(0!==v.length){m.lower=p.showupperhalf,m.upper=p.showlowerhalf,m.diagonal=p.diagonal.visible;var b=p._visibleDims,_=v.length,w=g.viewOpts={};for(w.ranges=new Array(_),w.domains=new Array(_),u=0;u<b.length;u++){l=b[u];var T=w.ranges[u]=new Array(4),k=w.domains[u]=new Array(4);(r=a.getFromId(t,p._diag[l][0]))&&(T[0]=r._rl[0],T[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(s=a.getFromId(t,p._diag[l][1]))&&(T[1]=s._rl[0],T[3]=s._rl[1],k[1]=s.domain[0],k[3]=s.domain[1])}w.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===g.matrix&&(g.matrix=n(y));var M=f.clickmode.indexOf(\"select\")>-1,A=!0;if(o(x)||!!p.selectedpoints||M){var S=p._length;if(p.selectedpoints){g.selectBatch=p.selectedpoints;var E=p.selectedpoints,C={};for(l=0;l<E.length;l++)C[E[l]]=!0;var L=[];for(l=0;l<S;l++)C[l]||L.push(l);g.unselectBatch=L}var I=d.xpx=new Array(_),P=d.ypx=new Array(_);for(u=0;u<b.length;u++){if(l=b[u],r=a.getFromId(t,p._diag[l][0]))for(I[u]=new Array(S),c=0;c<S;c++)I[u][c]=r.c2p(v[u][c]);if(s=a.getFromId(t,p._diag[l][1]))for(P[u]=new Array(S),c=0;c<S;c++)P[u][c]=s.c2p(v[u][c])}if(g.selectBatch.length||g.unselectBatch.length){var z=i.extendFlat({},m,g.unselectedOptions,w),O=i.extendFlat({},m,g.selectedOptions,w);g.matrix.update(z,O),A=!1}}else d.xpx=d.ypx=null;if(A){var D=i.extendFlat({},m,w);g.matrix.update(D,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)s(t,r[n][0])}},{\"../../components/dragelement/helpers\":661,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"regl-splom\":539}],1292:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0,selectBatch:[],unselectBatch:[]},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":778}],1293:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,f=t.yaxis,h=[];if(!l)return h;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return h;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,f);if(!1===d||!1===g)return h;var m=s.xpx[d],v=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([m[w],v[w]],null,w,t)?(b.push(w),h.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var T=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},T,l.selectedOptions,l.viewOpts)):l.matrix.update(T,null),l.selectBatch=b,l.unselectBatch=_,h}},{\"../../lib\":778,\"../scatter/subtypes\":1212,\"./helpers\":1288}],1294:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=a[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1295:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/calc\");function a(t){var e,r,i,a,s,l,c,u,f,h,p,d,g=t._x,m=t._y,v=t._z,y=t._len,x=-1/0,b=1/0,_=-1/0,w=1/0,T=-1/0,k=1/0,M=\"\";for(y&&(c=g[0],f=m[0],p=v[0]),y>1&&(u=g[y-1],h=m[y-1],d=v[y-1]),e=0;e<y;e++)x=Math.max(x,g[e]),b=Math.min(b,g[e]),_=Math.max(_,m[e]),w=Math.min(w,m[e]),T=Math.max(T,v[e]),k=Math.min(k,v[e]),a||g[e]===c||(a=!0,M+=\"x\"),s||m[e]===f||(s=!0,M+=\"y\"),l||v[e]===p||(l=!0,M+=\"z\");a||(M+=\"x\"),s||(M+=\"y\"),l||(M+=\"z\");var A=o(t._x),S=o(t._y),E=o(t._z);M=(M=(M=M.replace(\"x\",(c>u?\"-\":\"+\")+\"x\")).replace(\"y\",(f>h?\"-\":\"+\")+\"y\")).replace(\"z\",(p>d?\"-\":\"+\")+\"z\");var C=function(){y=0,A=[],S=[],E=[]};(!y||y<A.length*S.length*E.length)&&C();var L=function(t){return\"x\"===t?g:\"y\"===t?m:v},I=function(t){return\"x\"===t?A:\"y\"===t?S:E},P=function(t){return t[y-1]<t[0]?-1:1},z=L(M[1]),O=L(M[3]),D=L(M[5]),R=I(M[1]).length,F=I(M[3]).length,B=I(M[5]).length,N=!1,j=function(t,e,r){return R*(F*t+e)+r},U=P(L(M[1])),V=P(L(M[3])),q=P(L(M[5]));for(e=0;e<B-1;e++){for(r=0;r<F-1;r++){for(i=0;i<R-1;i++){var H=j(e,r,i),G=j(e,r,i+1),Y=j(e,r+1,i),W=j(e+1,r,i);if(z[H]*U<z[G]*U&&O[H]*V<O[Y]*V&&D[H]*q<D[W]*q||(N=!0),N)break}if(N)break}if(N)break}return N&&(n.warn(\"Encountered arbitrary coordinates! Unable to input data grid.\"),C()),{xMin:b,yMin:w,zMin:k,xMax:x,yMax:_,zMax:T,Xs:A,Ys:S,Zs:E,len:y,fill:M}}function o(t){return n.distinctVals(t).vals}function s(t,e){if(void 0===e&&(e=t.length),n.isTypedArray(t))return t.subarray(0,e);for(var r=[],i=0;i<e;i++)r[i]=+t[i];return r}e.exports={calc:function(t,e){e._len=Math.min(e.u.length,e.v.length,e.w.length,e.x.length,e.y.length,e.z.length),e._u=s(e.u,e._len),e._v=s(e.v,e._len),e._w=s(e.w,e._len),e._x=s(e.x,e._len),e._y=s(e.y,e._len),e._z=s(e.z,e._len);var r=a(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;var n,o,l,c=0;e.starts&&(n=s(e.starts.x||[]),o=s(e.starts.y||[]),l=s(e.starts.z||[]),c=Math.min(n.length,o.length,l.length)),e._startsX=n||[],e._startsY=o||[],e._startsZ=l||[];var u,f=0,h=1/0;for(u=0;u<e._len;u++){var p=e._u[u],d=e._v[u],g=e._w[u],m=Math.sqrt(p*p+d*d+g*g);f=Math.max(f,m),h=Math.min(h,m)}for(i(t,e,{vals:[h,f],containerStr:\"\",cLetter:\"c\"}),u=0;u<c;u++){var v=n[u];r.xMax=Math.max(r.xMax,v),r.xMin=Math.min(r.xMin,v);var y=o[u];r.yMax=Math.max(r.yMax,y),r.yMin=Math.min(r.yMin,y);var x=l[u];r.zMax=Math.max(r.zMax,x),r.zMin=Math.min(r.zMin,x)}e._slen=c,e._normMax=f,e._xbnds=[r.xMin,r.xMax],e._ybnds=[r.yMin,r.yMax],e._zbnds=[r.zMin,r.zMax]},filter:s,processGrid:a}},{\"../../components/colorscale/calc\":651,\"../../lib\":778}],1296:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var f=u.prototype;function h(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,f={};function d(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,(function(t){return n.d2l(t)*o}))}if(f.vectors=l(d(e._u,\"xaxis\"),d(e._v,\"yaxis\"),d(e._w,\"zaxis\"),u),!u)return{positions:[],cells:[]};var g=d(e._Xs,\"xaxis\"),m=d(e._Ys,\"yaxis\"),v=d(e._Zs,\"zaxis\");if(f.meshgrid=[g,m,v],f.gridFill=e._gridFill,e._slen)f.startingPositions=l(d(e._startsX,\"xaxis\"),d(e._startsY,\"yaxis\"),d(e._startsZ,\"zaxis\"));else{for(var y=m[0],x=h(g),b=h(v),_=new Array(x.length*b.length),w=0,T=0;T<x.length;T++)for(var k=0;k<b.length;k++)_[w++]=[x[T],y,b[k]];f.startingPositions=_}f.colormap=o(e),f.tubeSize=e.sizeref,f.maxLength=e.maxdisplayed;var M=d(e._xbnds,\"xaxis\"),A=d(e._ybnds,\"yaxis\"),S=d(e._zbnds,\"zaxis\"),E=p(g),C=p(m),L=p(v),I=[[M[0]-E[0],A[0]-C[0],S[0]-L[0]],[M[1]+E[1],A[1]+C[1],S[1]+L[1]]],P=n(f,I),z=s(e);P.vertexIntensityBounds=[z.min/e._normMax,z.max/e._normMax];var O=e.lightposition;return P.lightPosition=[O.x,O.y,O.z],P.ambient=e.lighting.ambient,P.diffuse=e.lighting.diffuse,P.specular=e.lighting.specular,P.roughness=e.lighting.roughness,P.fresnel=e.lighting.fresnel,P.opacity=e.opacity,e._pad=P.tubeScale*e.sizeref*2,P}f.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},f.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/gl3d/zip3\":881,\"gl-streamtube3d\":348}],1297:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1294}],1298:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\").calc,plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1294,\"./calc\":1295,\"./convert\":1296,\"./defaults\":1297}],1299:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../pie/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},count:{valType:\"flaglist\",flags:[\"branches\",\"leaves\"],dflt:\"leaves\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:u({colors:{valType:\"data_array\",editType:\"calc\"},line:{color:u({},l.marker.line.color,{dflt:null}),width:u({},l.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},o(\"marker\",{colorAttr:\"colors\",anim:!1})),leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1},editType:\"plot\"},text:l.text,textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],extras:[\"none\"],editType:\"plot\"},texttemplate:a({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:l.hovertext,hoverinfo:u({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],dflt:\"label+text+value+name\"}),hovertemplate:i({},{keys:c.eventDataKeys}),textfont:l.textfont,insidetextorientation:l.insidetextorientation,insidetextfont:l.insidetextfont,outsidetextfont:u({},l.outsidetextfont,{}),rotation:{valType:\"angle\",dflt:0,editType:\"plot\"},sort:l.sort,root:{color:{valType:\"color\",editType:\"calc\",dflt:\"rgba(0,0,0,0)\"},editType:\"calc\"},domain:s({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161,\"./constants\":1302}],1300:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"sunburst\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1301:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,s=t(\"../pie/calc\").makePullColorFn,l=t(\"../pie/calc\").generateExtendedColors,c=t(\"../../components/colorscale\").calc,u=t(\"../../constants/numerical\").ALMOST_EQUAL,f={},h={};r.calc=function(t,e){var r,l,f,h,p,d,g=t._fullLayout,m=e.ids,v=a.isArrayOrTypedArray(m),y=e.labels,x=e.parents,b=e.values,_=a.isArrayOrTypedArray(b),w=[],T={},k={},M=function(t){return t||\"number\"==typeof t},A=function(t){return!_||i(b[t])&&b[t]>=0};v?(r=Math.min(m.length,x.length),l=function(t){return M(m[t])&&A(t)},f=function(t){return String(m[t])}):(r=Math.min(y.length,x.length),l=function(t){return M(y[t])&&A(t)},f=function(t){return String(y[t])}),_&&(r=Math.min(r,b.length));for(var S=0;S<r;S++)if(l(S)){var E=f(S),C=M(x[S])?String(x[S]):\"\",L={i:S,id:E,pid:C,label:M(y[S])?String(y[S]):\"\"};_&&(L.v=+b[S]),w.push(L),p=E,T[h=C]?T[h].push(p):T[h]=[p],k[p]=1}if(T[\"\"]){if(T[\"\"].length>1){for(var I=a.randstr(),P=0;P<w.length;P++)\"\"===w[P].pid&&(w[P].pid=I);w.unshift({hasMultipleRoots:!0,id:I,pid:\"\",label:\"\"})}}else{var z,O=[];for(z in T)k[z]||O.push(z);if(1!==O.length)return a.warn([\"Multiple implied roots, cannot build\",e.type,\"hierarchy of\",e.name+\".\",\"These roots include:\",O.join(\", \")].join(\" \"));z=O[0],w.unshift({hasImpliedRoot:!0,id:z,pid:\"\",label:z})}try{d=n.stratify().id((function(t){return t.id})).parentId((function(t){return t.pid}))(w)}catch(t){return a.warn([\"Failed to build\",e.type,\"hierarchy of\",e.name+\".\",\"Error:\",t.message].join(\" \"))}var D=n.hierarchy(d),R=!1;if(_)switch(e.branchvalues){case\"remainder\":D.sum((function(t){return t.data.v}));break;case\"total\":D.each((function(t){var r=t.data.data,n=r.v;if(t.children){var i=t.children.reduce((function(t,e){return t+e.data.data.v}),0);if((r.hasImpliedRoot||r.hasMultipleRoots)&&(n=i),n<i*u)return R=!0,a.warn([\"Total value for node\",t.data.data.id,\"of\",e.name,\"is smaller than the sum of its children.\",\"\\nparent value =\",n,\"\\nchildren sum =\",i].join(\" \"))}t.value=n}))}else!function t(e,r,n){var i=0,a=e.children;if(a){for(var o=a.length,s=0;s<o;s++)i+=t(a[s],r,n);n.branches&&i++}else n.leaves&&i++;e.value=e.data.data.value=i,r._values||(r._values=[]);return r._values[e.data.data.i]=i,i}(D,e,{branches:-1!==e.count.indexOf(\"branches\"),leaves:-1!==e.count.indexOf(\"leaves\")});if(!R){var F,B;e.sort&&D.sort((function(t,e){return e.value-t.value}));var N=e.marker.colors||[],j=!!N.length;return e._hasColorscale?(j||(N=_?e.values:e._values),c(t,e,{vals:N,containerStr:\"marker\",cLetter:\"c\"}),B=o(e.marker)):F=s(g[\"_\"+e.type+\"colormap\"]),D.each((function(t){var r=t.data.data;r.color=e._hasColorscale?B(N[r.i]):F(N[r.i],r.id)})),w[0].hierarchy=D,w}},r._runCrossTraceCalc=function(t,e){var r=e._fullLayout,n=e.calcdata,i=r[t+\"colorway\"],a=r[\"_\"+t+\"colormap\"];r[\"extend\"+t+\"colors\"]&&(i=l(i,\"treemap\"===t?h:f));var o,s=0;function c(t){var e=t.data.data,r=e.id;!1===e.color&&(a[r]?e.color=a[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(a[r]=e.color=i[s%i.length],s++):e.color=o)}for(var u=0;u<n.length;u++){var p=n[u][0];p.trace.type===t&&p.hierarchy&&(o=p.trace.root.color,p.hierarchy.each(c))}},r.crossTraceCalc=function(t){return r._runCrossTraceCalc(\"sunburst\",t)}},{\"../../components/colorscale\":655,\"../../constants/numerical\":753,\"../../lib\":778,\"../pie/calc\":1163,\"d3-hierarchy\":161,\"fast-isnumeric\":241}],1302:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"]}},{}],1303:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../../components/colorscale\"),l=s.hasColorscale,c=s.handleDefaults;e.exports=function(t,e,r,s){function u(r,a){return n.coerce(t,e,i,r,a)}var f=u(\"labels\"),h=u(\"parents\");if(f&&f.length&&h&&h.length){var p=u(\"values\");p&&p.length?u(\"branchvalues\"):u(\"count\"),u(\"level\"),u(\"maxdepth\"),u(\"marker.line.width\")&&u(\"marker.line.color\",s.paper_bgcolor),u(\"marker.colors\");var d=e._hasColorscale=l(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;d&&c(t,e,s,u,{prefix:\"marker.\",cLetter:\"c\"}),u(\"leaf.opacity\",d?1:.7);var g=u(\"text\");u(\"texttemplate\"),e.texttemplate||u(\"textinfo\",Array.isArray(g)?\"text+label\":\"label\"),u(\"hovertext\"),u(\"hovertemplate\");o(t,e,s,u,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),u(\"insidetextorientation\"),u(\"sort\"),u(\"rotation\"),u(\"root.color\"),a(e,s,u),e._length=null}else e.visible=!1}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"./attributes\":1299}],1304:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/fx/helpers\").appendArrayPointValue,o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/events\"),c=t(\"./helpers\"),u=t(\"../pie/helpers\").formatPieValue;function f(t,e,r){for(var n=t.data.data,i={curveNumber:e.index,pointNumber:n.i,data:e._input,fullData:e},o=0;o<r.length;o++){var s=r[o];s in t&&(i[s]=t[s])}return\"parentString\"in t&&!c.isHierarchyRoot(t)&&(i.parent=t.parentString),a(i,e,n.i),i}e.exports=function(t,e,r,a,h){var p=a[0],d=p.trace,g=p.hierarchy,m=\"sunburst\"===d.type,v=\"treemap\"===d.type;\"_hasHoverLabel\"in d||(d._hasHoverLabel=!1),\"_hasHoverEvent\"in d||(d._hasHoverEvent=!1);t.on(\"mouseover\",(function(i){var a=r._fullLayout;if(!r._dragging&&!1!==a.hovermode){var l=r._fullData[d.index],y=i.data.data,x=y.i,b=c.isHierarchyRoot(i),_=c.getParent(g,i),w=c.getValue(i),T=function(t){return s.castOption(l,x,t)},k=T(\"hovertemplate\"),M=o.castHoverinfo(l,a,x),A=a.separators;if(k||M&&\"none\"!==M&&\"skip\"!==M){var S,E;m&&(S=p.cx+i.pxmid[0]*(1-i.rInscribed),E=p.cy+i.pxmid[1]*(1-i.rInscribed)),v&&(S=i._hoverX,E=i._hoverY);var C,L={},I=[],P=[],z=function(t){return-1!==I.indexOf(t)};M&&(I=\"all\"===M?l._module.attributes.hoverinfo.flags:M.split(\"+\")),L.label=y.label,z(\"label\")&&L.label&&P.push(L.label),y.hasOwnProperty(\"v\")&&(L.value=y.v,L.valueLabel=u(L.value,A),z(\"value\")&&P.push(L.valueLabel)),L.currentPath=i.currentPath=c.getPath(i.data),z(\"current path\")&&!b&&P.push(L.currentPath);var O=[],D=function(){-1===O.indexOf(C)&&(P.push(C),O.push(C))};L.percentParent=i.percentParent=w/c.getValue(_),L.parent=i.parentString=c.getPtLabel(_),z(\"percent parent\")&&(C=c.formatPercent(L.percentParent,A)+\" of \"+L.parent,D()),L.percentEntry=i.percentEntry=w/c.getValue(e),L.entry=i.entry=c.getPtLabel(e),!z(\"percent entry\")||b||i.onPathbar||(C=c.formatPercent(L.percentEntry,A)+\" of \"+L.entry,D()),L.percentRoot=i.percentRoot=w/c.getValue(g),L.root=i.root=c.getPtLabel(g),z(\"percent root\")&&!b&&(C=c.formatPercent(L.percentRoot,A)+\" of \"+L.root,D()),L.text=T(\"hovertext\")||T(\"text\"),z(\"text\")&&(C=L.text,s.isValidTextValue(C)&&P.push(C));var R={trace:l,y:E,text:P.join(\"<br>\"),name:k||z(\"name\")?l.name:void 0,color:T(\"hoverlabel.bgcolor\")||y.color,borderColor:T(\"hoverlabel.bordercolor\"),fontFamily:T(\"hoverlabel.font.family\"),fontSize:T(\"hoverlabel.font.size\"),fontColor:T(\"hoverlabel.font.color\"),nameLength:T(\"hoverlabel.namelength\"),textAlign:T(\"hoverlabel.align\"),hovertemplate:k,hovertemplateLabels:L,eventData:[f(i,l,h.eventDataKeys)]};m&&(R.x0=S-i.rInscribed*i.rpx1,R.x1=S+i.rInscribed*i.rpx1,R.idealAlign=i.pxmid[0]<0?\"left\":\"right\"),v&&(R.x=S,R.idealAlign=S<0?\"left\":\"right\"),o.loneHover(R,{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:r}),d._hasHoverLabel=!0}if(v){var F=t.select(\"path.surface\");h.styleOne(F,i,l,{hovered:!0})}d._hasHoverEvent=!0,r.emit(\"plotly_hover\",{points:[f(i,l,h.eventDataKeys)],event:n.event})}})),t.on(\"mouseout\",(function(e){var i=r._fullLayout,a=r._fullData[d.index],s=n.select(this).datum();if(d._hasHoverEvent&&(e.originalEvent=n.event,r.emit(\"plotly_unhover\",{points:[f(s,a,h.eventDataKeys)],event:n.event}),d._hasHoverEvent=!1),d._hasHoverLabel&&(o.loneUnhover(i._hoverlayer.node()),d._hasHoverLabel=!1),v){var l=t.select(\"path.surface\");h.styleOne(l,s,a,{hovered:!1})}})),t.on(\"click\",(function(t){var e=r._fullLayout,a=r._fullData[d.index],s=m&&(c.isHierarchyRoot(t)||c.isLeaf(t)),u=c.getPtId(t),p=c.isEntry(t)?c.findEntryWithChild(g,u):c.findEntryWithLevel(g,u),v=c.getPtId(p),y={points:[f(t,a,h.eventDataKeys)],event:n.event};s||(y.nextLevel=v);var x=l.triggerHandler(r,\"plotly_\"+d.type+\"click\",y);if(!1!==x&&e.hovermode&&(r._hoverdata=[f(t,a,h.eventDataKeys)],o.click(r,n.event)),!s&&!1!==x&&!r._dragging&&!r._transitioning){i.call(\"_storeDirectGUIEdit\",a,e._tracePreGUI[a.uid],{level:a.level});var b={data:[{level:v}],traces:[d.index]},_={frame:{redraw:!1,duration:h.transitionTime},transition:{duration:h.transitionTime,easing:h.transitionEasing},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(e._hoverlayer.node()),i.call(\"animate\",r,b,_)}}))}},{\"../../components/fx\":683,\"../../components/fx/helpers\":679,\"../../lib\":778,\"../../lib/events\":767,\"../../registry\":911,\"../pie/helpers\":1166,\"./helpers\":1305,d3:169}],1305:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../lib/setcursor\"),o=t(\"../pie/helpers\");function s(t){return t.data.data.pid}r.findEntryWithLevel=function(t,e){var n;return e&&t.eachAfter((function(t){if(r.getPtId(t)===e)return n=t.copy()})),n||t},r.findEntryWithChild=function(t,e){var n;return t.eachAfter((function(t){for(var i=t.children||[],a=0;a<i.length;a++){var o=i[a];if(r.getPtId(o)===e)return n=t.copy()}})),n||t},r.isEntry=function(t){return!t.parent},r.isLeaf=function(t){return!t.children},r.getPtId=function(t){return t.data.data.id},r.getPtLabel=function(t){return t.data.data.label},r.getValue=function(t){return t.value},r.isHierarchyRoot=function(t){return\"\"===s(t)},r.setSliceCursor=function(t,e,n){var i=n.isTransitioning;if(!i){var o=t.datum();i=n.hideOnRoot&&r.isHierarchyRoot(o)||n.hideOnLeaves&&r.isLeaf(o)}a(t,i?null:\"pointer\")},r.getInsideTextFontKey=function(t,e,r,i,a){var o=(a||{}).onPathbar?\"pathbar.textfont\":\"insidetextfont\",s=r.data.data.i;return n.castOption(e,s,o+\".\"+t)||n.castOption(e,s,\"textfont.\"+t)||i.size},r.getOutsideTextFontKey=function(t,e,r,i){var a=r.data.data.i;return n.castOption(e,a,\"outsidetextfont.\"+t)||n.castOption(e,a,\"textfont.\"+t)||i.size},r.isOutsideText=function(t,e){return!t._hasColorscale&&r.isHierarchyRoot(e)},r.determineTextFont=function(t,e,a,o){return r.isOutsideText(t,e)?function(t,e,n){return{color:r.getOutsideTextFontKey(\"color\",t,e,n),family:r.getOutsideTextFontKey(\"family\",t,e,n),size:r.getOutsideTextFontKey(\"size\",t,e,n)}}(t,e,a):function(t,e,a,o){var s=(o||{}).onPathbar,l=e.data.data,c=l.i,u=n.castOption(t,c,(s?\"pathbar.textfont\":\"insidetextfont\")+\".color\");return!u&&t._input.textfont&&(u=n.castOption(t._input,c,\"textfont.color\")),{color:u||i.contrast(l.color),family:r.getInsideTextFontKey(\"family\",t,e,a,o),size:r.getInsideTextFontKey(\"size\",t,e,a,o)}}(t,e,a,o)},r.hasTransition=function(t){return!!(t&&t.duration>0)},r.getMaxDepth=function(t){return t.maxdepth>=0?t.maxdepth:1/0},r.isHeader=function(t,e){return!(r.isLeaf(t)||t.depth===e._maxDepth-1)},r.getParent=function(t,e){return r.findEntryWithLevel(t,s(e))},r.listPath=function(t,e){var n=t.parent;if(!n)return[];var i=e?[n.data[e]]:[n];return r.listPath(n,e).concat(i)},r.getPath=function(t){return r.listPath(t,\"label\").join(\"/\")+\"/\"},r.formatValue=o.formatPieValue,r.formatPercent=function(t,e){var r=n.formatPercent(t,0);return\"0%\"===r&&(r=o.formatPiePercent(t,e)),r}},{\"../../components/color\":643,\"../../lib\":778,\"../../lib/setcursor\":799,\"../pie/helpers\":1166}],1306:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1205,\"./attributes\":1299,\"./base_plot\":1300,\"./calc\":1301,\"./defaults\":1303,\"./layout_attributes\":1307,\"./layout_defaults\":1308,\"./plot\":1309,\"./style\":1310}],1307:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1308:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":778,\"./layout_attributes\":1307}],1309:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,f=t(\"../pie/plot\"),h=t(\"../pie/helpers\").getRotationAngle,p=f.computeTransform,d=f.transformInsideText,g=t(\"./style\").styleOne,m=t(\"../bar/style\").resizeText,v=t(\"./fx\"),y=t(\"./constants\"),x=t(\"./helpers\");function b(t,e,l,u){var f=t._fullLayout,m=!f.uniformtext.mode&&x.hasTransition(u),b=n.select(l).selectAll(\"g.slice\"),w=e[0],T=w.trace,k=w.hierarchy,M=x.findEntryWithLevel(k,T.level),A=x.getMaxDepth(T),S=f._size,E=T.domain,C=S.w*(E.x[1]-E.x[0]),L=S.h*(E.y[1]-E.y[0]),I=.5*Math.min(C,L),P=w.cx=S.l+S.w*(E.x[1]+E.x[0])/2,z=w.cy=S.t+S.h*(1-E.y[0])-L/2;if(!M)return b.remove();var O=null,D={};m&&b.each((function(t){D[x.getPtId(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!O&&x.isEntry(t)&&(O=t)}));var R=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(M).descendants(),F=M.height+1,B=0,N=A;w.hasMultipleRoots&&x.isHierarchyRoot(M)&&(R=R.slice(1),F-=1,B=1,N+=1),R=R.filter((function(t){return t.y1<=N}));var j=h(T.rotation);j&&R.forEach((function(t){t.x0+=j,t.x1+=j}));var U=Math.min(F,A),V=function(t){return(t-B)/U*I},q=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},H=function(t){return o.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,z)},G=function(t){return P+_(t)[0]*(t.transform.rCenter||0)+(t.transform.x||0)},Y=function(t){return z+_(t)[1]*(t.transform.rCenter||0)+(t.transform.y||0)};(b=b.data(R,x.getPtId)).enter().append(\"g\").classed(\"slice\",!0),m?b.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=x.getPtId(t),i=D[r],a=D[x.getPtId(M)];if(a){var o=(t.x1>a.x1?2*Math.PI:0)+j;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=x.getPtId(t.parent);b.each((function(t){if(x.getPtId(t)===l)return s=t}));var c,u=s.children;u.forEach((function(t,e){if(x.getPtId(t)===r)return c=e}));var f=u.length,h=n.interpolate(s.x0,s.x1);e={rpx0:I,rpx1:I,x0:h(c/f),x1:h((c+1)/f)}}return n.interpolate(i,e)}(t);return function(t){return H(e(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():b.exit().remove(),b.order();var W=null;if(m&&O){var X=x.getPtId(O);b.each((function(t){null===W&&x.getPtId(t)===X&&(W=t.x1)}))}var Z=b;function J(t){var e=t.parent,r=D[x.getPtId(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}m&&(Z=Z.transition().each(\"end\",(function(){var e=n.select(this);x.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:!1})}))),Z.each((function(i){var l=n.select(this),u=o.ensureSingle(l,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));i.rpx0=V(i.y0),i.rpx1=V(i.y1),i.xmid=(i.x0+i.x1)/2,i.pxmid=q(i.rpx1,i.xmid),i.midangle=-(i.xmid-Math.PI/2),i.startangle=-(i.x0-Math.PI/2),i.stopangle=-(i.x1-Math.PI/2),i.halfangle=.5*Math.min(o.angleDelta(i.x0,i.x1)||Math.PI,Math.PI),i.ring=1-i.rpx0/i.rpx1,i.rInscribed=function(t){return 0===t.rpx0&&o.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(i),m?u.transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(O)if(t.parent)if(W){var a=(t.x1>W?2*Math.PI:0)+j;e={x0:a,x1:a}}else e={rpx0:I,rpx1:I},o.extendFlat(e,J(t));else e={rpx0:0,rpx1:0};else e={x0:j,x1:j};return n.interpolate(e,i)}(t);return function(t){return H(e(t))}})):u.attr(\"d\",H),l.call(v,M,t,e,{eventDataKeys:y.eventDataKeys,transitionTime:y.CLICK_TRANSITION_TIME,transitionEasing:y.CLICK_TRANSITION_EASING}).call(x.setSliceCursor,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:t._transitioning}),u.call(g,i,T);var h=o.ensureSingle(l,\"g\",\"slicetext\"),b=o.ensureSingle(h,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),_=o.ensureUniformFontSize(t,x.determineTextFont(T,i,f.font));b.text(r.formatSliceLabel(i,M,T,e,f)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(a.font,_).call(s.convertToTspans,t);var k=a.bBox(b.node());i.transform=d(k,i,w),i.transform.targetX=G(i),i.transform.targetY=Y(i);var A=function(t,e){var r=t.transform;return p(r,e),r.fontSize=_.size,c(T.type,r,f),o.getTextTransform(r)};m?b.transition().attrTween(\"transform\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{textPosAngle:i.textPosAngle,scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},O)if(t.parent)if(W){var a=t.x1>W?2*Math.PI:0;e.x0=e.x1=a}else o.extendFlat(e,J(t));else e.x0=e.x1=j;else e.x0=e.x1=j;var s=n.interpolate(e.transform.textPosAngle,t.transform.textPosAngle),l=n.interpolate(e.rpx1,t.rpx1),u=n.interpolate(e.x0,t.x0),h=n.interpolate(e.x1,t.x1),p=n.interpolate(e.transform.scale,i.scale),d=n.interpolate(e.transform.rotate,i.rotate),g=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,m=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=l(t),r=u(t),n=h(t),a=function(t){return m(Math.pow(t,g))}(t),o={pxmid:q(e,(r+n)/2),rpx1:e,transform:{textPosAngle:s(t),rCenter:a,x:i.x,y:i.y}};return c(T.type,i,f),{transform:{targetX:G(o),targetY:Y(o),scale:p(t),rotate:d(t),rCenter:a}}}}(t);return function(t){return A(e(t),k)}})):b.attr(\"transform\",A(i,k))}))}function _(t){return e=t.rpx1,r=t.transform.textPosAngle,[e*Math.sin(r),-e*Math.cos(r)];var e,r}r.plot=function(t,e,r,i){var a,o,s=t._fullLayout,l=s._sunburstlayer,c=!r,f=!s.uniformtext.mode&&x.hasTransition(r);(u(\"sunburst\",s),(a=l.selectAll(\"g.trace.sunburst\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),f)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){o&&o()})).each(\"interrupt\",(function(){o&&o()})).each((function(){l.selectAll(\"g.trace\").each((function(e){b(t,e,this,r)}))}))):(a.each((function(e){b(t,e,this,r)})),s.uniformtext.mode&&m(t,s._sunburstlayer.selectAll(\".trace\"),\"sunburst\"));c&&a.exit().remove()},r.formatSliceLabel=function(t,e,r,n,i){var a=r.texttemplate,s=r.textinfo;if(!(a||s&&\"none\"!==s))return\"\";var l=i.separators,c=n[0],u=t.data.data,f=c.hierarchy,h=x.isHierarchyRoot(t),p=x.getParent(f,t),d=x.getValue(t);if(!a){var g,m=s.split(\"+\"),v=function(t){return-1!==m.indexOf(t)},y=[];if(v(\"label\")&&u.label&&y.push(u.label),u.hasOwnProperty(\"v\")&&v(\"value\")&&y.push(x.formatValue(u.v,l)),!h){v(\"current path\")&&y.push(x.getPath(t.data));var b=0;v(\"percent parent\")&&b++,v(\"percent entry\")&&b++,v(\"percent root\")&&b++;var _=b>1;if(b){var w,T=function(t){g=x.formatPercent(w,l),_&&(g+=\" of \"+t),y.push(g)};v(\"percent parent\")&&!h&&(w=d/x.getValue(p),T(\"parent\")),v(\"percent entry\")&&(w=d/x.getValue(e),T(\"entry\")),v(\"percent root\")&&(w=d/x.getValue(f),T(\"root\"))}}return v(\"text\")&&(g=o.castOption(r,u.i,\"text\"),o.isValidTextValue(g)&&y.push(g)),y.join(\"<br>\")}var k=o.castOption(r,u.i,\"texttemplate\");if(!k)return\"\";var M={};u.label&&(M.label=u.label),u.hasOwnProperty(\"v\")&&(M.value=u.v,M.valueLabel=x.formatValue(u.v,l)),M.currentPath=x.getPath(t.data),h||(M.percentParent=d/x.getValue(p),M.percentParentLabel=x.formatPercent(M.percentParent,l),M.parent=x.getPtLabel(p)),M.percentEntry=d/x.getValue(e),M.percentEntryLabel=x.formatPercent(M.percentEntry,l),M.entry=x.getPtLabel(e),M.percentRoot=d/x.getValue(f),M.percentRootLabel=x.formatPercent(M.percentRoot,l),M.root=x.getPtLabel(f),u.hasOwnProperty(\"color\")&&(M.color=u.color);var A=o.castOption(r,u.i,\"text\");return(o.isValidTextValue(A)||\"\"===A)&&(M.text=A),M.customdata=o.castOption(r,u.i,\"customdata\"),o.texttemplateString(k,M,i._d3locale,M,r._meta||{})}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../bar/style\":935,\"../bar/uniform_text\":937,\"../pie/helpers\":1166,\"../pie/plot\":1170,\"./constants\":1302,\"./fx\":1304,\"./helpers\":1305,\"./style\":1310,d3:169,\"d3-hierarchy\":161}],1310:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../bar/uniform_text\").resizeText;function s(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){var e=t._fullLayout._sunburstlayer.selectAll(\".trace\");o(t,e,\"sunburst\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(s,t,r)}))}))},styleOne:s}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/uniform_text\":937,d3:169}],1311:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},opacityscale:{valType:\"any\",editType:\"calc\"},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":643,\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906}],1312:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1313:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-linear-interpolate\").d2,o=t(\"../heatmap/interp2d\"),s=t(\"../heatmap/find_empties\"),l=t(\"../../lib\").isArrayOrTypedArray,c=t(\"../../lib/gl_format_color\").parseColorScale,u=t(\"../../lib/str2rgbarray\"),f=t(\"../../components/colorscale\").extractOpts;function h(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var p=h.prototype;p.getXat=function(t,e,r,n){var i=l(this.data.x)?l(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},p.getYat=function(t,e,r,n){var i=l(this.data.y)?l(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},p.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},p.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var d=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function g(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<d.length;r++){var n=d[r];e.push(g(t,n))}return e}function v(t){for(var e=m(t),r=t,n=0;n<d.length;n++)if(e[n]>0){r=d[n];break}return r}function y(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<d.length;a++)i*=Math.pow(d[a],Math.max(r[a],n[a]));return i}}p.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},p.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var x=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],b=x[9],_=x[13];function w(t,e,r){var n=r[8]+r[2]*e[0]+r[5]*e[1];return t[0]=(r[6]+r[0]*e[0]+r[3]*e[1])/n,t[1]=(r[7]+r[1]*e[0]+r[4]*e[1])/n,t}function T(t,e,r){return function(t,e,r,n){for(var i=[0,0],o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++)r(i,[l,c],n),t.set(l,c,a(e,i[0],i[1]))}(t,e,w,r),t}function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}p.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=y(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<b;)r*=2;for(;r>_;)r--,r/=v(r),++r<b&&(r=_);var n=Math.round(r/t);return n>1?n:1},p.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],a=t[0].shape[1],o=0|Math.floor(t[0].shape[0]*e+1),s=0|Math.floor(t[0].shape[1]*r+1),l=1+n+1,c=1+a+1,u=i(new Float32Array(l*c),[l,c]),f=[1/e,0,0,0,1/r,0,0,0,1],h=0;h<t.length;++h){this.surface.padField(u,t[h]);var p=i(new Float32Array(o*s),[o,s]);T(p,u,f),t[h]=p}},p.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},p.update=function(t){var e,r,n,a,l=this.scene,h=l.fullSceneLayout,p=this.surface,d=c(t),g=l.dataScale,m=t.z[0].length,v=t._ylength,y=l.contourLevels;this.data=t;var x=[];for(e=0;e<3;e++)for(x[e]=[],r=0;r<m;r++)x[e][r]=[];for(r=0;r<m;r++)for(n=0;n<v;n++)x[0][r][n]=this.getXat(r,n,t.xcalendar,h.xaxis),x[1][r][n]=this.getYat(r,n,t.ycalendar,h.yaxis),x[2][r][n]=this.getZat(r,n,t.zcalendar,h.zaxis);if(t.connectgaps)for(t._emptypoints=s(x[2]),o(x[2],t._emptypoints),t._interpolatedZ=[],r=0;r<m;r++)for(t._interpolatedZ[r]=[],n=0;n<v;n++)t._interpolatedZ[r][n]=x[2][r][n];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null==(a=x[e][r][n])?x[e][r][n]=NaN:a=x[e][r][n]*=g[e];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(x[e][r][n]-=this.objectOffset[e]);var b=[i(new Float32Array(m*v),[m,v]),i(new Float32Array(m*v),[m,v]),i(new Float32Array(m*v),[m,v])];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)b[e].set(r,n,x[e][r][n]);x=[];var w={colormap:d,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacityscale:t.opacityscale,opacity:t.opacity},T=f(t);if(w.intensityBounds=[T.min,T.max],t.surfacecolor){var k=i(new Float32Array(m*v),[m,v]);for(r=0;r<m;r++)for(n=0;n<v;n++)k.set(r,n,t.surfacecolor[n][r]);b.push(k)}else w.intensityBounds[0]*=g[2],w.intensityBounds[1]*=g[2];(_<b[0].shape[0]||_<b[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(b[0].shape[0],0),this.dataScaleY=this.estimateScale(b[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(b)),t.surfacecolor&&(w.intensity=b.pop());var M=[!0,!0,!0],A=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var S=t.contours[A[e]];M[e]=S.highlight,w.showContour[e]=S.show||S.highlight,w.showContour[e]&&(w.contourProject[e]=[S.project.x,S.project.y,S.project.z],S.show?(this.showContour[e]=!0,w.levels[e]=y[e],p.highlightColor[e]=w.contourColor[e]=u(S.color),S.usecolormap?p.highlightTint[e]=w.contourTint[e]=0:p.highlightTint[e]=w.contourTint[e]=1,w.contourWidth[e]=S.width,this.contourStart[e]=S.start,this.contourEnd[e]=S.end,this.contourSize[e]=S.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),S.highlight&&(w.dynamicColor[e]=u(S.highlightcolor),w.dynamicWidth[e]=S.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(d)&&(w.vertexColor=!0),w.objectOffset=this.objectOffset,w.coords=b,p.update(w),p.visible=t.visible,p.enableDynamic=M,p.enableHighlight=M,p.snapToData=!0,\"lighting\"in t&&(p.ambientLight=t.lighting.ambient,p.diffuseLight=t.lighting.diffuse,p.specularLight=t.lighting.specular,p.roughness=t.lighting.roughness,p.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(p.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z])},p.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../heatmap/find_empties\":1071,\"../heatmap/interp2d\":1074,\"gl-surface3d\":351,ndarray:495,\"ndarray-linear-interpolate\":489}],1314:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var i=n(\"opacityscale\");\"max\"===i?e.opacityscale=[[0,.1],[1,1]]:\"min\"===i?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===i?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(0,Math.min(1,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(i)||(e.opacityscale=void 0)}function l(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports={supplyDefaults:function(t,e,r,c){var u,f;function h(r,n){return i.coerce(t,e,o,r,n)}var p=h(\"x\"),d=h(\"y\"),g=h(\"z\");if(!g||!g.length||p&&p.length<1||d&&d.length<1)e.visible=!1;else{e._xlength=Array.isArray(p)&&i.isArrayOrTypedArray(p[0])?g.length:g[0].length,e._ylength=g.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],c),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach((function(t){h(t)}));var m=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(u=0;u<3;++u){var y=\"contours.\"+v[u],x=h(y+\".show\"),b=h(y+\".highlight\");if(x||b)for(f=0;f<3;++f)h(y+\".project.\"+v[f]);x&&(h(y+\".color\"),h(y+\".width\"),h(y+\".usecolormap\")),b&&(h(y+\".highlightcolor\"),h(y+\".highlightwidth\")),h(y+\".start\"),h(y+\".end\"),h(y+\".size\")}m||(l(t,\"zmin\",\"cmin\"),l(t,\"zmax\",\"cmax\"),l(t,\"zauto\",\"cauto\")),a(t,e,c,h,{prefix:\"\",cLetter:\"c\"}),s(t,e,c,h),e._length=null}},opacityscaleDefaults:s}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1311}],1315:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1311,\"./calc\":1312,\"./convert\":1313,\"./defaults\":1314}],1316:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":626,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1317:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":865,\"./plot\":1324}],1318:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":775}],1319:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1320:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce((function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e}),0)}function f(t,e){return Object.keys(t).map((function(r){return i({},t[r],{auxiliaryBlocks:e})}))}function h(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map((function(){return c((d[0]||[\"\"]).length)}))),m=e.domain,v=Math.floor(t._fullLayout._size.w*(m.x[1]-m.x[0])),y=Math.floor(t._fullLayout._size.h*(m.y[1]-m.y[0])),x=e.header.values.length?g[0].map((function(){return e.header.height})):[n.emptyHeaderHeight],b=r.length?r[0].map((function(){return e.cells.height})):[],_=x.reduce(s,0),w=h(b,y-_+n.uplift),T=f(h(x,_),[]),k=f(w,T),M={},A=e._fullInput.columnorder.concat(p(r.map((function(t,e){return e})))),S=g.map((function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1})),E=S.reduce(s,0);S=S.map((function(t){return t/E*v}));var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:m.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-m.y[1]),size:t._fullLayout._size,width:v,maxLineWidth:C,height:y,columnOrder:A,groupHeight:y,rowBlocks:k,headerRowBlocks:T,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map((function(t){return t[0]})),gdColumnsOriginalOrder:g.map((function(t){return t[0]})),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map((function(t,e){var r=M[t];return M[t]=(r||0)+1,{key:t+\"__\"+M[t],label:t,specIndex:e,xIndex:A[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}}))};return L.columns.forEach((function(t){t.calcdata=L,t.x=u(t)})),L}},{\"../../lib/extend\":768,\"./constants\":1319,\"fast-isnumeric\":241}],1321:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map((function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}}))}},{\"../../lib/extend\":768}],1322:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort((function(t,e){return t-e})),o=i.map((function(t){return a.indexOf(t)})),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":778,\"../../plots/domain\":855,\"./attributes\":1316}],1323:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1316,\"./base_plot\":1317,\"./calc\":1318,\"./defaults\":1322,\"./plot\":1324}],1324:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").strTranslate,u=t(\"../../lib\").cancelTransition,f=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),p=t(\"../../components/color\");function d(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function m(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map((function(t){return t}))).map((function(t){return t.__data__}))}function y(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each((function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return O(e,e.length-1)+(e.length?D(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom})).attr(\"transform\",(function(t){var e=t.width+n.scrollbarWidth/2+n.scrollbarOffset;return c(e,A(t))}));var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",(function(t){return c(0,t.scrollbarState.topY||0)}));var u=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),u.attr(\"y2\",(function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2})).attr(\"stroke-opacity\",(function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4})),u.transition().delay(0).duration(0),u.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var f=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);f.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",(function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||E(e,t,null,l(s-o.barLength/2))(r)})).call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t})).on(\"drag\",E(e,t)).on(\"dragend\",(function(){}))),f.attr(\"y2\",(function(t){return t.scrollbarState.scrollableAreaHeight})),e._context.staticPlot&&(u.remove(),f.remove())}function x(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each((function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:w(r.size,n,e),color:w(r.color,n,e),family:w(r.family,n,e)};t.rowNumber=t.key,t.align=w(t.calcdata.cells.align,n,e),t.cellBorderWidth=w(t.calcdata.cells.line.width,n,e),t.font=i}))}(l),function(t){t.attr(\"width\",(function(t){return t.column.columnWidth})).attr(\"stroke-width\",(function(t){return t.cellBorderWidth})).each((function(t){var e=i.select(this);p.stroke(e,w(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),p.fill(e,w(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))}))}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",(function(){return\"auto\"})).on(\"mousedown\",(function(){i.event.stopPropagation()})),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each((function(t){o.font(i.select(this),t.font)}))}(c),b(c,e,s,t),z(l)}function b(t,e,r,a){t.text((function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var f,h,p=u?\"\":w(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":w(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:w(t.calcdata.cells.format,e,r)||null,m=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(f=_(m)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===f?_(m):f),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var v=(\" \"===n.wrapSplitCharacter?m.replace(/<a href=/gi,\"<a_href=\"):m).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?v.map((function(t){return t.replace(/<a_href=/gi,\"<a href=\")})):v;t.fragments=y.map((function(t){return{text:t,width:null}})),t.fragments.push({fragment:n.wrapSpacer,width:null}),h=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,h=m;return h})).attr(\"dy\",(function(t){return t.needsConvertToTspans?0:\"0.75em\"})).each((function(t){var o=i.select(this),l=t.wrappingNeeded?L:I;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",(function(t){return c(P(t),n.cellPad)})).attr(\"text-anchor\",(function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]}))}))}function _(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function w(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function T(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",c(e.x,r))}function k(t){return\"cells\"===t.type}function M(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce((function(t,e){return t+D(e,1/0)}),0)}function S(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=O(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),u=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l;e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===u.length&&(u[0]===i.length-1?u.unshift(u[0]-1):u.push(u[0]+1)),u[0]%2&&u.reverse(),e.each((function(t,e){t.page=u[e],t.scrollY=l})),e.attr(\"transform\",(function(t){var e=O(t.rowBlocks,t.page)-t.scrollY;return c(0,e)})),t&&(C(t,r,e,u,n.prevPages,n,0),C(t,r,e,u,n.prevPages,n,1),y(r,t))}}function E(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter((function(t){return s.key===t.key})),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var f=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return S(t,f,l),s.scrollY===u}}function C(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout((function(){var a=r.filter((function(t,e){return e===o&&n[e]!==i[e]}));x(t,e,a,r),i[o]=n[o]})))}function L(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each((function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each((function(t,r){e[r].width=this.getComputedTextLength()}));var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0})),o.selectAll(\"tspan.line\").remove(),b(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(z)}}function I(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=F(o),u=o.key-l.firstRowIndex,f=l.rows[u].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:f,p=Math.max(h,f);p-l.rows[u].rowHeight&&(l.rows[u].rowHeight=p,t.selectAll(\".\"+n.cn.columnCell).call(z),S(null,t.filter(k),0),y(r,a,!0)),s.attr(\"transform\",(function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return c(P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width),a)})),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function z(t){t.attr(\"transform\",(function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce((function(t,e){return t+D(e,1/0)}),0),r=D(F(t),t.key);return c(0,r+e)})).selectAll(\".\"+n.cn.cellRect).attr(\"height\",(function(t){return(e=F(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r}))}function O(t,e){for(var r=0,n=e-1;n>=0;n--)r+=R(t[n]);return r}function D(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function R(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function F(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map((function(e){var r=a.unwrap(e).trace;return f(t,r)})),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",(function(t){return t.width+t.size.l+t.size.r})).attr(\"height\",(function(t){return t.height+t.size.t+t.size.b})).attr(\"transform\",(function(t){return c(t.translateX,t.translateY)}));var p=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),b=p.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");if(r){var _=\"onwheel\"in document?\"wheel\":\"mousewheel\";b.on(\"mousemove\",(function(e){p.filter((function(t){return e===t})).call(y,t)})).on(_,(function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;E(t,p,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}})).call(y,t,!0)}p.attr(\"transform\",(function(t){return c(t.size.l,t.size.t)}));var w=p.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);w.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),w.attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),p.each((function(e){o.setClipUrl(i.select(this),g(t,e),t)}));var A=p.selectAll(\".\"+n.cn.yColumn).data((function(t){return t.columns}),a.keyFun);A.enter().append(\"g\").classed(n.cn.yColumn,!0),A.exit().remove(),A.attr(\"transform\",(function(t){return c(t.x,0)})),r&&A.call(i.behavior.drag().origin((function(e){return T(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,y(p.filter((function(t){return e.calcdata.key===t.key})),t),e})).on(\"drag\",(function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(A).filter((function(e){return e.calcdata.key===t.calcdata.key})).sort((function(t,e){return r(t)-r(e)})).forEach((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)})),A.filter((function(e){return t!==e})).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",(function(t){return c(t.x,0)})),e.call(u).attr(\"transform\",c(t.x,-n.uplift))})).on(\"dragend\",(function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,T(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort((function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]})),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map((function(t){return t.xIndex})))}))),A.each((function(e){o.setClipUrl(i.select(this),m(t,e),t)}));var C=A.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);C.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",(function(t){return t.key})),C.style(\"cursor\",(function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"}));var L=C.filter(M),I=C.filter(k);r&&I.call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t})).on(\"drag\",E(t,p,-1)).on(\"dragend\",(function(){}))),x(t,p,L,C),x(t,p,I,C);var P=p.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);P.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",(function(e){return g(t,e)}));var z=P.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),z.attr(\"width\",(function(t){return t.width+2*n.overdrag})).attr(\"height\",(function(t){return t.height+n.uplift})),A.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=A.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",(function(e){return m(t,e)}));var D=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);D.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),D.attr(\"width\",(function(t){return t.columnWidth+2*d(t)})).attr(\"height\",(function(t){return t.calcdata.height+2*d(t)+n.uplift})).attr(\"x\",(function(t){return-d(t)})).attr(\"y\",(function(t){return-d(t)})),S(null,I,p)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../lib/svg_text_utils\":803,\"./constants\":1319,\"./data_preparation_helper\":1320,\"./data_split_helpers\":1321,d3:169}],1325:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../pie/attributes\"),l=t(\"../sunburst/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{packing:{valType:\"enumerated\",values:[\"squarify\",\"binary\",\"dice\",\"slice\",\"slice-dice\",\"dice-slice\"],dflt:\"squarify\",editType:\"plot\"},squarifyratio:{valType:\"number\",min:1,dflt:1,editType:\"plot\"},flip:{valType:\"flaglist\",flags:[\"x\",\"y\"],dflt:\"\",editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:3,editType:\"plot\"},editType:\"calc\"},marker:u({pad:{t:{valType:\"number\",min:0,editType:\"plot\"},l:{valType:\"number\",min:0,editType:\"plot\"},r:{valType:\"number\",min:0,editType:\"plot\"},b:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\"},colors:l.marker.colors,depthfade:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],editType:\"style\"},line:l.marker.line,editType:\"calc\"},a(\"marker\",{colorAttr:\"colors\",anim:!1})),pathbar:{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},edgeshape:{valType:\"enumerated\",values:[\">\",\"<\",\"|\",\"/\",\"\\\\\"],dflt:\">\",editType:\"plot\"},thickness:{valType:\"number\",min:12,editType:\"plot\"},textfont:u({},s.textfont,{}),editType:\"calc\"},text:s.text,textinfo:l.textinfo,texttemplate:i({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:c.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:u({},s.outsidetextfont,{}),textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"top left\",editType:\"plot\"},sort:s.sort,root:l.root,domain:o({name:\"treemap\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161,\"../sunburst/attributes\":1299,\"./constants\":1328}],1326:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"treemap\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1327:[function(t,e,r){\"use strict\";var n=t(\"../sunburst/calc\");r.calc=function(t,e){return n.calc(t,e)},r.crossTraceCalc=function(t){return n._runCrossTraceCalc(\"treemap\",t)}},{\"../sunburst/calc\":1301}],1328:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"poly\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"],gapWithPathbar:1}},{}],1329:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText,l=t(\"../bar/constants\").TEXTPAD,c=t(\"../../components/colorscale\"),u=c.hasColorscale,f=c.handleDefaults;e.exports=function(t,e,r,c){function h(r,a){return n.coerce(t,e,i,r,a)}var p=h(\"labels\"),d=h(\"parents\");if(p&&p.length&&d&&d.length){var g=h(\"values\");g&&g.length?h(\"branchvalues\"):h(\"count\"),h(\"level\"),h(\"maxdepth\"),\"squarify\"===h(\"tiling.packing\")&&h(\"tiling.squarifyratio\"),h(\"tiling.flip\"),h(\"tiling.pad\");var m=h(\"text\");h(\"texttemplate\"),e.texttemplate||h(\"textinfo\",Array.isArray(m)?\"text+label\":\"label\"),h(\"hovertext\"),h(\"hovertemplate\");var v=h(\"pathbar.visible\");s(t,e,c,h,\"auto\",{hasPathbar:v,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),h(\"textposition\");var y=-1!==e.textposition.indexOf(\"bottom\");h(\"marker.line.width\")&&h(\"marker.line.color\",c.paper_bgcolor);var x=h(\"marker.colors\"),b=e._hasColorscale=u(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;b?f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}):h(\"marker.depthfade\",!(x||[]).length);var _=2*e.textfont.size;h(\"marker.pad.t\",y?_/4:_),h(\"marker.pad.l\",_/4),h(\"marker.pad.r\",_/4),h(\"marker.pad.b\",y?_:_/4),b&&f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}),e._hovered={marker:{line:{width:2,color:a.contrast(c.paper_bgcolor)}}},v&&(h(\"pathbar.thickness\",e.pathbar.textfont.size+2*l),h(\"pathbar.side\"),h(\"pathbar.edgeshape\")),h(\"sort\"),h(\"root.color\"),o(e,c,h),e._length=null}else e.visible=!1}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../lib\":778,\"../../plots/domain\":855,\"../bar/constants\":923,\"../bar/defaults\":925,\"./attributes\":1325}],1330:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\");e.exports=function(t,e,r,h,p){var d=p.barDifY,g=p.width,m=p.height,v=p.viewX,y=p.viewY,x=p.pathSlice,b=p.toMoveInsideSlice,_=p.strTransform,w=p.hasTransition,T=p.handleSlicesExit,k=p.makeUpdateSliceInterpolator,M=p.makeUpdateTextInterpolator,A={},S=t._fullLayout,E=e[0],C=E.trace,L=E.hierarchy,I=g/C._entryDepth,P=u.listPath(r.data,\"id\"),z=s(L.copy(),[g,m],{packing:\"dice\",pad:{inner:0,top:0,left:0,right:0,bottom:0}}).descendants();(z=z.filter((function(t){var e=P.indexOf(t.data.id);return-1!==e&&(t.x0=I*e,t.x1=I*(e+1),t.y0=d,t.y1=d+m,t.onPathbar=!0,!0)}))).reverse(),(h=h.data(z,u.getPtId)).enter().append(\"g\").classed(\"pathbar\",!0),T(h,!0,A,[g,m],x),h.order();var O=h;w&&(O=O.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:!1})}))),O.each((function(s){s._hoverX=v(s.x1-Math.min(g,m)/2),s._hoverY=y(s.y1-m/2);var h=n.select(this),p=i.ensureSingle(h,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?p.transition().attrTween(\"d\",(function(t){var e=k(t,!0,A,[g,m]);return function(t){return x(e(t))}})):p.attr(\"d\",x),h.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:t._transitioning}),p.call(l,s,C,{hovered:!1}),s._text=(u.getPtLabel(s)||\"\").split(\"<br>\").join(\" \")||\"\";var d=i.ensureSingle(h,\"g\",\"slicetext\"),T=i.ensureSingle(d,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),E=i.ensureUniformFontSize(t,u.determineTextFont(C,s,S.font,{onPathbar:!0}));T.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",\"start\").call(a.font,E).call(o.convertToTspans,t),s.textBB=a.bBox(T.node()),s.transform=b(s,{fontSize:E.size,onPathbar:!0}),s.transform.fontSize=E.size,w?T.transition().attrTween(\"transform\",(function(t){var e=M(t,!0,A,[g,m]);return function(t){return _(e(t))}})):T.attr(\"transform\",_(s))}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../sunburst/fx\":1304,\"../sunburst/helpers\":1305,\"./constants\":1328,\"./partition\":1335,\"./style\":1337,d3:169}],1331:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\"),h=t(\"../sunburst/plot\").formatSliceLabel;e.exports=function(t,e,r,p,d){var g=d.width,m=d.height,v=d.viewX,y=d.viewY,x=d.pathSlice,b=d.toMoveInsideSlice,_=d.strTransform,w=d.hasTransition,T=d.handleSlicesExit,k=d.makeUpdateSliceInterpolator,M=d.makeUpdateTextInterpolator,A=d.prevEntry,S=t._fullLayout,E=e[0].trace,C=-1!==E.textposition.indexOf(\"left\"),L=-1!==E.textposition.indexOf(\"right\"),I=-1!==E.textposition.indexOf(\"bottom\"),P=!I&&!E.marker.pad.t||I&&!E.marker.pad.b,z=s(r,[g,m],{packing:E.tiling.packing,squarifyratio:E.tiling.squarifyratio,flipX:E.tiling.flip.indexOf(\"x\")>-1,flipY:E.tiling.flip.indexOf(\"y\")>-1,pad:{inner:E.tiling.pad,top:E.marker.pad.t,left:E.marker.pad.l,right:E.marker.pad.r,bottom:E.marker.pad.b}}).descendants(),O=1/0,D=-1/0;z.forEach((function(t){var e=t.depth;e>=E._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(O=Math.min(O,e),D=Math.max(D,e))})),p=p.data(z,u.getPtId),E._maxVisibleLayers=isFinite(D)?D-O+1:0,p.enter().append(\"g\").classed(\"slice\",!0),T(p,!1,{},[g,m],x),p.order();var R=null;if(w&&A){var F=u.getPtId(A);p.each((function(t){null===R&&u.getPtId(t)===F&&(R={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})}))}var B=function(){return R||{x0:0,x1:g,y0:0,y1:m}},N=p;return w&&(N=N.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})}))),N.each((function(s){var p=u.isHeader(s,E);s._hoverX=v(s.x1-E.marker.pad.r),s._hoverY=y(I?s.y1-E.marker.pad.b/2:s.y0+E.marker.pad.t/2);var d=n.select(this),T=i.ensureSingle(d,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?T.transition().attrTween(\"d\",(function(t){var e=k(t,!1,B(),[g,m]);return function(t){return x(e(t))}})):T.attr(\"d\",x),d.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),T.call(l,s,E,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text=\"\":s._text=p?P?\"\":u.getPtLabel(s)||\"\":h(s,r,E,e,S)||\"\";var A=i.ensureSingle(d,\"g\",\"slicetext\"),z=i.ensureSingle(A,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),O=i.ensureUniformFontSize(t,u.determineTextFont(E,s,S.font));z.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",L?\"end\":C||p?\"start\":\"middle\").call(a.font,O).call(o.convertToTspans,t),s.textBB=a.bBox(z.node()),s.transform=b(s,{fontSize:O.size,isHeader:p}),s.transform.fontSize=O.size,w?z.transition().attrTween(\"transform\",(function(t){var e=M(t,!1,B(),[g,m]);return function(t){return _(e(t))}})):z.attr(\"transform\",_(s))})),R}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../sunburst/fx\":1304,\"../sunburst/helpers\":1305,\"../sunburst/plot\":1309,\"./constants\":1328,\"./partition\":1335,\"./style\":1337,d3:169}],1332:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"treemap\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1205,\"./attributes\":1325,\"./base_plot\":1326,\"./calc\":1327,\"./defaults\":1329,\"./layout_attributes\":1333,\"./layout_defaults\":1334,\"./plot\":1336,\"./style\":1337}],1333:[function(t,e,r){\"use strict\";e.exports={treemapcolorway:{valType:\"colorlist\",editType:\"calc\"},extendtreemapcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1334:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"treemapcolorway\",e.colorway),r(\"extendtreemapcolors\")}},{\"../../lib\":778,\"./layout_attributes\":1333}],1335:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\");e.exports=function(t,e,r){var i,a=r.flipX,o=r.flipY,s=\"dice-slice\"===r.packing,l=r.pad[o?\"bottom\":\"top\"],c=r.pad[a?\"right\":\"left\"],u=r.pad[a?\"left\":\"right\"],f=r.pad[o?\"top\":\"bottom\"];s&&(i=c,c=l,l=i,i=u,u=f,f=i);var h=n.treemap().tile(function(t,e){switch(t){case\"squarify\":return n.treemapSquarify.ratio(e);case\"binary\":return n.treemapBinary;case\"dice\":return n.treemapDice;case\"slice\":return n.treemapSlice;default:return n.treemapSliceDice}}(r.packing,r.squarifyratio)).paddingInner(r.pad.inner).paddingLeft(c).paddingRight(u).paddingTop(l).paddingBottom(f).size(s?[e[1],e[0]]:e)(t);return(s||a||o)&&function t(e,r,n){var i;n.swapXY&&(i=e.x0,e.x0=e.y0,e.y0=i,i=e.x1,e.x1=e.y1,e.y1=i);n.flipX&&(i=e.x0,e.x0=r[0]-e.x1,e.x1=r[0]-i);n.flipY&&(i=e.y0,e.y0=r[1]-e.y1,e.y1=r[1]-i);var a=e.children;if(a)for(var o=0;o<a.length;o++)t(a[o],r,n)}(h,e,{swapXY:s,flipX:a,flipY:o}),h}},{\"d3-hierarchy\":161}],1336:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../sunburst/helpers\"),a=t(\"../../lib\"),o=t(\"../bar/constants\").TEXTPAD,s=t(\"../bar/plot\").toMoveInsideBar,l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,f=t(\"../bar/style\").resizeText,h=t(\"./constants\"),p=t(\"./draw_descendants\"),d=t(\"./draw_ancestors\");function g(t){return i.isHierarchyRoot(t)?\"\":i.getPtId(t)}function m(t,e,r,l){var u=t._fullLayout,f=e[0],m=f.trace,v=f.hierarchy,y=i.findEntryWithLevel(v,m.level),x=n.select(r),b=x.selectAll(\"g.pathbar\"),_=x.selectAll(\"g.slice\");if(!y)return b.remove(),void _.remove();var w=i.isHierarchyRoot(y),T=!u.uniformtext.mode&&i.hasTransition(l),k=i.getMaxDepth(m),M=u._size,A=m.domain,S=M.w*(A.x[1]-A.x[0]),E=M.h*(A.y[1]-A.y[0]),C=S,L=m.pathbar.thickness,I=m.marker.line.width+h.gapWithPathbar,P=m.pathbar.visible?m.pathbar.side.indexOf(\"bottom\")>-1?E+I:-(L+I):0,z={x0:C,x1:C,y0:P,y1:P+L},O=function(t,e,r){var n=m.tiling.pad,i=function(t){return t-n<=e.x0},a=function(t){return t+n>=e.x1},o=function(t){return t-n<=e.y0},s=function(t){return t+n>=e.y1};return{x0:i(t.x0-n)?0:a(t.x0-n)?r[0]:t.x0,x1:i(t.x1+n)?0:a(t.x1+n)?r[0]:t.x1,y0:o(t.y0-n)?0:s(t.y0-n)?r[1]:t.y0,y1:o(t.y1+n)?0:s(t.y1+n)?r[1]:t.y1}},D=null,R={},F={},B=null,N=function(t,e){return e?R[g(t)]:F[g(t)]},j=function(t,e,r,n){if(e)return R[g(v)]||z;var i=F[m.level]||r;return function(t){return t.data.depth-y.data.depth<k}(t)?O(t,i,n):{}};f.hasMultipleRoots&&w&&k++,m._maxDepth=k,m._backgroundColor=u.paper_bgcolor,m._entryDepth=y.data.depth,m._atRootLevel=w;var U=-S/2+M.l+M.w*(A.x[1]+A.x[0])/2,V=-E/2+M.t+M.h*(1-(A.y[1]+A.y[0])/2),q=function(t){return U+t},H=function(t){return V+t},G=H(0),Y=q(0),W=function(t){return Y+t},X=function(t){return G+t};function Z(t,e){return t+\",\"+e}var J=W(0),K=function(t){t.x=Math.max(J,t.x)},Q=m.pathbar.edgeshape,$=function(t,e){var r=t.x0,n=t.x1,i=t.y0,a=t.y1,l=t.textBB,f=function(t){return-1!==m.textposition.indexOf(t)},h=f(\"bottom\"),p=f(\"top\")||e.isHeader&&!h?\"start\":h?\"end\":\"middle\",d=f(\"right\"),g=f(\"left\")||e.onPathbar?-1:d?1:0,v=m.marker.pad;if(e.isHeader){if((r+=v.l-o)>=(n-=v.r-o)){var y=(r+n)/2;r=y,n=y}var x;h?i<(x=a-v.b)&&x<a&&(i=x):i<(x=i+v.t)&&x<a&&(a=x)}var b=s(r,n,i,a,l,{isHorizontal:!1,constrained:!0,angle:0,anchor:p,leftToRight:g});return b.fontSize=e.fontSize,b.targetX=q(b.targetX),b.targetY=H(b.targetY),isNaN(b.targetX)||isNaN(b.targetY)?{}:(r!==n&&i!==a&&c(m.type,b,u),{scale:b.scale,rotate:b.rotate,textX:b.textX,textY:b.textY,anchorX:b.anchorX,anchorY:b.anchorY,targetX:b.targetX,targetY:b.targetY})},tt=function(t,e){for(var r,n=0,i=t;!r&&n<k;)n++,(i=i.parent)?r=N(i,e):n=k;return r||{}},et=function(t,e,r,i){var o,s=N(t,e);if(s)o=s;else if(e)o=z;else if(D)if(t.parent){var l=B||r;l&&!e?o=O(t,l,i):(o={},a.extendFlat(o,tt(t,e)))}else o=t;else o={};return n.interpolate(o,{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})},rt=function(t,e,r,o){var s=N(t,e),l={},f=j(t,e,r,o);a.extendFlat(l,{transform:$({x0:f.x0,x1:f.x1,y0:f.y0,y1:f.y1,textBB:t.textBB,_text:t._text},{isHeader:i.isHeader(t,m)})}),s?l=s:t.parent&&a.extendFlat(l,tt(t,e));var h=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,h,u),n.interpolate(l,{transform:{scale:h.scale,rotate:h.rotate,textX:h.textX,textY:h.textY,anchorX:h.anchorX,anchorY:h.anchorY,targetX:h.targetX,targetY:h.targetY}})},nt=function(t,e,r,i,a){var o=i[0],s=i[1];T?t.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var r=function(t,e,r,i){var a,o=N(t,e);if(e)a=z;else{var s=N(y,e);a=s?O(t,s,i):{}}return n.interpolate(o,a)}(t,e,0,[o,s]);return function(t){return a(r(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():t.exit().remove()},it=function(t){var e=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,e,u),a.getTextTransform({textX:e.textX,textY:e.textY,anchorX:e.anchorX,anchorY:e.anchorY,targetX:e.targetX,targetY:e.targetY,scale:e.scale,rotate:e.rotate})};T&&(b.each((function(t){R[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(R[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})})),_.each((function(t){F[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(F[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate}),!D&&i.isEntry(t)&&(D=t)}))),B=p(t,e,y,_,{width:S,height:E,viewX:q,viewY:H,pathSlice:function(t){var e=q(t.x0),r=q(t.x1),n=H(t.y0),i=H(t.y1),a=r-e,o=i-n;if(!a||!o)return\"\";return\"M\"+Z(e,n+0)+\"L\"+Z(r-0,n)+\"L\"+Z(r,i-0)+\"L\"+Z(e+0,i)+\"Z\"},toMoveInsideSlice:$,prevEntry:D,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:it}),m.pathbar.visible?d(t,e,y,b,{barDifY:P,width:C,height:L,viewX:W,viewY:X,pathSlice:function(t){var e=W(Math.max(Math.min(t.x0,t.x0),0)),r=W(Math.min(Math.max(t.x1,t.x1),C)),n=X(t.y0),i=X(t.y1),a=L/2,o={},s={};o.x=e,s.x=r,o.y=s.y=(n+i)/2;var l={x:e,y:n},c={x:r,y:n},u={x:r,y:i},f={x:e,y:i};return\">\"===Q?(l.x-=a,c.x-=a,u.x-=a,f.x-=a):\"/\"===Q?(u.x-=a,f.x-=a,o.x-=a/2,s.x-=a/2):\"\\\\\"===Q?(l.x-=a,c.x-=a,o.x-=a/2,s.x-=a/2):\"<\"===Q&&(o.x-=a,s.x-=a),K(l),K(f),K(o),K(c),K(u),K(s),\"M\"+Z(l.x,l.y)+\"L\"+Z(c.x,c.y)+\"L\"+Z(s.x,s.y)+\"L\"+Z(u.x,u.y)+\"L\"+Z(f.x,f.y)+\"L\"+Z(o.x,o.y)+\"Z\"},toMoveInsideSlice:$,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:it}):b.remove()}e.exports=function(t,e,r,a){var o,s,l=t._fullLayout,c=l._treemaplayer,h=!r;(u(\"treemap\",l),(o=c.selectAll(\"g.trace.treemap\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"treemap\",!0),o.order(),!l.uniformtext.mode&&i.hasTransition(r))?(a&&(s=a()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){s&&s()})).each(\"interrupt\",(function(){s&&s()})).each((function(){c.selectAll(\"g.trace\").each((function(e){m(t,e,this,r)}))}))):(o.each((function(e){m(t,e,this,r)})),l.uniformtext.mode&&f(t,l._treemaplayer.selectAll(\".trace\"),\"treemap\"));h&&o.exit().remove()}},{\"../../lib\":778,\"../bar/constants\":923,\"../bar/plot\":932,\"../bar/style\":935,\"../bar/uniform_text\":937,\"../sunburst/helpers\":1305,\"./constants\":1328,\"./draw_ancestors\":1330,\"./draw_descendants\":1331,d3:169}],1337:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../sunburst/helpers\"),s=t(\"../bar/uniform_text\").resizeText;function l(t,e,r,n){var s,l,c=(n||{}).hovered,u=e.data.data,f=u.i,h=u.color,p=o.isHierarchyRoot(e),d=1;if(c)s=r._hovered.marker.line.color,l=r._hovered.marker.line.width;else if(p&&h===r.root.color)d=100,s=\"rgba(0,0,0,0)\",l=0;else if(s=a.castOption(r,f,\"marker.line.color\")||i.defaultLine,l=a.castOption(r,f,\"marker.line.width\")||0,!r._hasColorscale&&!e.onPathbar){var g=r.marker.depthfade;if(g){var m,v=i.combine(i.addOpacity(r._backgroundColor,.75),h);if(!0===g){var y=o.getMaxDepth(r);m=isFinite(y)?o.isLeaf(e)?0:r._maxVisibleLayers-(e.data.depth-r._entryDepth):e.data.height+1}else m=e.data.depth-r._entryDepth,r._atRootLevel||m++;if(m>0)for(var x=0;x<m;x++){var b=.5*x/m;h=i.combine(i.addOpacity(v,b),h)}}}t.style(\"stroke-width\",l).call(i.fill,h).call(i.stroke,s).style(\"opacity\",d)}e.exports={style:function(t){var e=t._fullLayout._treemaplayer.selectAll(\".trace\");s(t,e,\"treemap\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(l,t,r,{hovered:!1})}))}))},styleOne:l}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/uniform_text\":937,\"../sunburst/helpers\":1305,d3:169}],1338:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":768,\"../box/attributes\":946}],1339:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function f(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var h={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[f(0),f(1)]};return i.setConvert(h),h.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),f=1/0,h=-1/0,p=0,d=0,g=0;g<r.length;g++){var m=r[g],v=m.pts.map(o.extractVal),y=m.bandwidth=l(e,m,v),x=m.span=c(e,m,u,y);if(m.min===m.max&&0===y)x=m.span=[m.min,m.max],m.density=[{v:1,t:x[0]}],m.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var T=o.makeKDE(m,e,v);m.density=new Array(_);for(var k=0,M=x[0];M<x[1]+w/2;k++,M+=w){var A=T(M);m.density[k]={v:A,t:M},p=Math.max(p,A)}}d=Math.max(d,v.length),f=Math.min(f,x[0]),h=Math.max(h,x[1])}var S=i.findExtremes(u,[f,h],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../box/calc\":947,\"./helpers\":1342}],1340:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(f)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":948}],1341:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,f=l(\"span\");Array.isArray(f)&&(u=\"manual\"),l(\"spanmode\",u);var h=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),m=c(\"box.fillcolor\",d),v=c(\"box.line.color\",h),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||m||v||y))||(e.box={visible:!1});var x=c(\"meanline.color\",h),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":643,\"../../lib\":778,\"../box/defaults\":949,\"./attributes\":1338}],1342:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":778}],1343:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,f=t.cd,h=f[0].trace,p=h.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),m=[];if(d||g){var v=a.hoverOnBoxes(t,e,r,s);if(g&&v.length>0){var y,x,b,_,w,T=t.xa,k=t.ya;\"h\"===h.orientation?(w=e,y=\"y\",b=k,x=\"x\",_=T):(w=r,y=\"x\",b=T,x=\"y\",_=k);var M=f[t.index];if(w>=M.span[0]&&w<=M.span[1]){var A=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(M,h,w),C=o.getPositionOnKdePath(M,h,S),L=b._offset,I=b._length;A[y+\"0\"]=C[0],A[y+\"1\"]=C[1],A[x+\"0\"]=A[x+\"1\"]=S,A[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+f[0].t.labels.kde+\" \"+E.toFixed(3),A.spikeDistance=v[0].spikeDistance;var P=y+\"Spike\";A[P]=v[0][P],v[0].spikeDistance=void 0,v[0][P]=void 0,A.hovertemplate=!1,m.push(A),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+I),u[y+\"2\"]=n.constrain(L+C[1],L,L+I),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(m=m.concat(v))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+h.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+h.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:m:c?(m.push(c),m):m}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../box/hover\":951,\"./helpers\":1342}],1344:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../box/defaults\":949,\"../box/select\":956,\"../scatter/style\":1211,\"./attributes\":1338,\"./calc\":1339,\"./cross_trace_calc\":1340,\"./defaults\":1341,\"./hover\":1343,\"./layout_attributes\":1345,\"./layout_defaults\":1346,\"./plot\":1347,\"./style\":1348}],1345:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":778,\"../box/layout_attributes\":953}],1346:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,(function(r,a){return n.coerce(t,e,i,r,a)}),\"violin\")}},{\"../../lib\":778,\"../box/layout_defaults\":954,\"./layout_attributes\":1345}],1347:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,f=e.xaxis,h=e.yaxis;function p(t){var e=s(t,{xaxis:f,yaxis:h,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0,linearized:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each((function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,m=e[s.valLetter+\"axis\"],v=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each((function(t){var e,r,i,a,o,l,f,h,_=n.select(this),w=t.density,T=w.length,k=v.c2l(t.pos+d,!0),M=v.l2p(k);if(c.width)e=s.maxKDE/g;else{var A=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?A.maxKDE/g*(A.maxCount/t.pts.length):A.maxKDE/g}if(x){for(f=new Array(T),o=0;o<T;o++)(h=f[o]={})[s.posLetter]=k+w[o].v/e,h[s.valLetter]=m.c2l(w[o].t,!0);r=p(f)}if(b){for(f=new Array(T),l=0,o=T-1;l<T;l++,o--)(h=f[l]={})[s.posLetter]=k-w[o].v/e,h[s.valLetter]=m.c2l(w[o].t,!0);i=p(f)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[M,m.c2p(w[0].t)],E=[M,m.c2p(w[T-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=M,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)}));var w,T,k,M=c.box,A=M.width,S=(M.line||{}).width;y?(w=g*A,T=0):x?(w=[0,g*A/2],T=S*{x:1,y:-1}[s.posLetter]):(w=[g*A/2,0],T=S*{x:-1,y:1}[s.posLetter]),o.plotBoxAndWhiskers(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),o.plotBoxMean(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),!c.box.visible&&c.meanline.visible&&(k=i.identity);var E=r.selectAll(\"path.meanline\").data(k||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each((function(t){var e=m.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])})),o.plotPoints(r,{x:f,y:h},c,s)}}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../box/plot\":955,\"../scatter/line_points\":1201,\"./helpers\":1342,d3:169}],1348:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var f={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(f).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(f).call(i.stroke,c.color),a(o,r,t)}))}},{\"../../components/color\":643,\"../scatter/style\":1211,d3:169}],1349:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll,c=e.exports=l(s({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:a.opacityscale,lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../isosurface/attributes\":1123,\"../surface/attributes\":1311}],1350:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=u.prototype;f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=c(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"../isosurface/convert\":1125,\"gl-mesh3d\":309}],1351:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults,o=t(\"../surface/defaults\").opacityscaleDefaults;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,s,l),o(t,e,s,l)}},{\"../../lib\":778,\"../isosurface/defaults\":1126,\"../surface/defaults\":1314,\"./attributes\":1349}],1352:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"../isosurface/calc\":1124,\"./attributes\":1349,\"./convert\":1350,\"./defaults\":1351}],1353:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");function f(t){return{marker:{color:c({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:c({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:c({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\"])}),text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:f(),decreasing:f(),totals:f(),connector:{line:{color:c({},i.color,{dflt:u.defaultLine}),width:c({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":643,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187,\"./constants\":1355}],1354:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../lib\").mergeArray,o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return\"a\"===t||\"absolute\"===t}function c(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,u,f,h,p=n.getFromId(t,e.xaxis||\"x\"),d=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=p.makeCalcdata(e,\"x\"),f=d.makeCalcdata(e,\"y\"),u=i(e,d,\"y\",f),h=!!e.yperiodalignment):(r=d.makeCalcdata(e,\"y\"),f=p.makeCalcdata(e,\"x\"),u=i(e,p,\"x\",f),h=!!e.xperiodalignment);for(var g,m=Math.min(u.length,r.length),v=new Array(m),y=0,x=!1,b=0;b<m;b++){var _=r[b]||0,w=!1;(r[b]!==s||c(e.measure[b])||l(e.measure[b]))&&b+1<m&&(r[b+1]!==s||c(e.measure[b+1])||l(e.measure[b+1]))&&(w=!0);var T=v[b]={i:b,p:u[b],s:_,rawS:_,cNext:w};l(e.measure[b])?(y=T.s,T.isSum=!0,T.dir=\"totals\",T.s=y):c(e.measure[b])?(T.isSum=!0,T.dir=\"totals\",T.s=y):(T.isSum=!1,T.dir=T.rawS<0?\"decreasing\":\"increasing\",g=T.s,T.s=y+g,y+=g),\"totals\"===T.dir&&(x=!0),h&&(v[b].orig_p=f[b]),e.ids&&(T.id=String(e.ids[b])),T.v=(e.base||0)+y}return v.length&&(v[0].hasTotals=x),a(e.text,v,\"tx\"),a(e.hovertext,v,\"htx\"),o(v,e),v}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189}],1355:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1356:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?h.push(r):f.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,f,d),n(t,c,l,h,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var m=r[g];!1===m.isSum&&(m.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":924}],1357:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\"),u=t(\"../../constants/delta.js\"),f=u.INCREASING.COLOR,h=u.DECREASING.COLOR;function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",c.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,c)){s(t,e,i,c),c(\"measure\"),c(\"orientation\",e.x&&!e.y?\"h\":\"v\"),c(\"base\"),c(\"offset\"),c(\"width\"),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var u=c(\"textposition\");if(a(t,e,i,c,u,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&(c(\"texttemplate\"),e.texttemplate||c(\"textinfo\")),p(c,\"increasing\",f),p(c,\"decreasing\",h),p(c,\"totals\",\"#4499FF\"),c(\"connector.visible\"))c(\"connector.mode\"),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.waterfallmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":643,\"../../constants/delta.js\":747,\"../../lib\":778,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":1353}],1358:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1359:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,f=u[0].trace,h=\"h\"===f.orientation,p=h?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var m=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+m+\")\":m,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var v=d.hi||f.hoverinfo,y=[];if(v&&\"none\"!==v&&\"skip\"!==v){var x=\"all\"===v,b=v.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(h?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(f,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":643,\"../../constants/delta.js\":747,\"../../plots/cartesian/axes\":828,\"../bar/hover\":928}],1360:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/select\":933,\"./attributes\":1353,\"./calc\":1354,\"./cross_trace_calc\":1356,\"./defaults\":1357,\"./event_data\":1358,\"./hover\":1359,\"./layout_attributes\":1361,\"./layout_defaults\":1362,\"./plot\":1363,\"./style\":1364}],1361:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1362:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":778,\"./layout_attributes\":1361}],1363:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;e.exports=function(t,e,r,c){var u=t._fullLayout;l(\"waterfall\",u),s.plot(t,e,r,c,{mode:u.waterfallmode,norm:u.waterfallmode,gap:u.waterfallgap,groupgap:u.waterfallgroupgap}),function(t,e,r,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),u=r[0].trace,f=i.ensureSingle(s,\"g\",\"lines\");if(u.connector&&u.connector.visible){var h=\"h\"===u.orientation,p=u.connector.mode,d=f.selectAll(\"g.line\").data(i.identity);d.enter().append(\"g\").classed(\"line\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var u=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,l,c,h),f=u[0],d=u[1],m=\"\";f[0]!==o&&d[0]!==o&&f[1]!==o&&d[1]!==o&&(\"spanning\"===p&&!r.isSum&&s>0&&(m+=h?\"M\"+f[0]+\",\"+d[1]+\"V\"+d[0]:\"M\"+f[1]+\",\"+d[0]+\"H\"+f[0]),\"between\"!==p&&(r.isSum||s<g-1)&&(m+=h?\"M\"+f[1]+\",\"+d[0]+\"V\"+d[1]:\"M\"+f[0]+\",\"+d[1]+\"H\"+f[1]),f[2]!==o&&d[2]!==o&&(m+=h?\"M\"+f[1]+\",\"+d[1]+\"V\"+d[2]:\"M\"+f[1]+\",\"+d[1]+\"H\"+f[2])),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,c)}},{\"../../components/drawing\":665,\"../../constants/numerical\":753,\"../../lib\":778,\"../bar/plot\":932,\"../bar/uniform_text\":937,d3:169}],1364:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l(t,s,\"waterfall\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/interactions\":752,\"../bar/style\":935,\"../bar/uniform_text\":937,d3:169}],1365:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,a=e.c2d;switch(r){case\"count\":return f;case\"first\":return h;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r+=o)}return a(r)};case\"avg\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,i++)}return i?a(r/i):s};case\"min\":return function(t,e){for(var r=1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:a(r)};case\"max\":return function(t,e){for(var r=-1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:a(r)};case\"range\":return function(t,e){for(var r=1/0,i=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),i=Math.max(i,l))}return i===-1/0||r===1/0?s:a(i-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),i=n(t[e[e.length-1]]);return r===s||i===s?s:a(i-r)};case\"median\":return function(t,e){for(var r=[],o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&r.push(l)}if(!r.length)return s;r.sort(i.sorterAsc);var c=(r.length-1)/2;return a((r[Math.floor(c)]+r[Math.ceil(c)])/2)};case\"mode\":return function(t,e){for(var r={},i=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>i&&(i=u,o=c)}}return i?a(o):s};case\"rms\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,i++)}return i?a(Math.sqrt(r/i)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var f=u-c;a+=f,o+=f*f,l++}}var h=\"sample\"===t.funcmode?l-1:l;return h?Math.sqrt((o-a*a/l)/h):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function f(t,e){return e.length}function h(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var f=o(\"groups\");if(!Array.isArray(f)){if(!u[f])return n.enabled=!1,n;u[f]=0}var h,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],h,c,t,e)}for(r=0;r<p.length;r++){h={_index:r};var m=g(\"target\"),v=g(\"func\");g(\"enabled\")&&m&&(u[m]||\"count\"===v&&void 0===u[m])?(\"stddev\"===v&&g(\"funcmode\"),u[m]=0,d[r]=h):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,f,h={},p={},d=[],g=o(e.transforms,r),m=a.length;for(e._length&&(m=Math.min(m,e._length)),s=0;s<m;s++)void 0===(c=h[l=a[s]])?(h[l]=d.length,f=[s],d.push(f),p[h[l]]=g(s)):(d[c].push(s),p[h[l]]=(p[h[l]]||[]).concat(g(s)));r._indexToPoints=p;var v=r.aggregations;for(s=0;s<v.length;s++)u(t,e,d,v[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":753,\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plots/cartesian/axes\":828,\"./helpers\":1368}],1366:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,f=i.length;e._length&&(f=Math.min(f,e._length));var h=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(h=g)}var m,v,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,f=function(r){return e(r,0,t.valuecalendar)},h=function(t){return e(t,0,r)};o(l)?s=f(a?i[0]:i):o(c)?s=a?[f(i[0]),f(i[1])]:[f(i),f(i)]:o(u)&&(s=a?i.map(f):[f(i)]);switch(n){case\"=\":return function(t){return h(t)===s};case\"!=\":return function(t){return h(t)!==s};case\"<\":return function(t){return h(t)<s};case\"<=\":return function(t){return h(t)<=s};case\">\":return function(t){return h(t)>s};case\">=\":return function(t){return h(t)>=s};case\"[]\":return function(t){var e=h(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=h(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=h(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=h(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=h(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=h(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=h(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=h(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(h(t))};case\"}{\":return function(t){return-1===s.indexOf(h(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),h),x={},b={},_=0;d?(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(f))},v=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},v=function(t,e){var r=x[t.astr][e];t.get().push(r)}),k(m);for(var w=o(e.transforms,r),T=0;T<f;T++){y(i[T])?(k(v,T),b[_++]=w(T)):d&&_++}r._indexToPoints=b,e._length=_}}function k(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":749,\"../lib\":778,\"../plots/cartesian/axes\":828,\"../registry\":911,\"./helpers\":1368}],1367:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,f,h,p,d,g,m=e.transform,v=e.transformIndex,y=t.transforms[v].groups,x=o(t.transforms,m);if(!n.isArrayOrTypedArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,T=i.findArrayAttributes(t),k=m.styles||[],M={};for(r=0;r<k.length;r++)M[k[r].target]=k[r].value;m.styles&&(g=n.keyedContainer(m,\"styles\",\"target\",\"value.name\"));var A={},S={};for(r=0;r<b.length;r++){A[f=b[r]]=r,S[f]=0,(h=_[r]=n.extendDeepNoArrays({},t))._group=f,h.transforms[v]._indexToPoints={};var E=null;for(g&&(E=g.get(f)),h.name=E||\"\"===E?E:n.templateString(m.nameformat,{trace:t.name,group:f}),p=h.transforms,h.transforms=[],s=0;s<p.length;s++)h.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<T.length;s++)n.nestedProperty(h,T[s]).set([])}for(l=0;l<T.length;l++){for(c=T[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[A[y[s]]].push(u[s])}for(s=0;s<w;s++){(h=_[A[y[s]]]).transforms[v]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)f=b[r],h=_[r],a.clearExpandedTraceDefaultColors(h),h=n.extendDeepNoArrays(h,M[f]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var f=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(f)?u.value=n.extendDeep({},f):f&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plots/plots\":891,\"./helpers\":1368}],1368:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1369:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction,o=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var s=n.getTargetArray(e,r);if(s){var l=r.target,c=s.length;e._length&&(c=Math.min(c,e._length));var u,f,h=e._arrayAttrs,p=function(t,e,r,n){var i,a=new Array(n),s=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:n-i};case\"descending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:i-n}}}(t,r)),i=0;i<n;i++)s[i]=a[i].i;return s}(r,s,i.getDataToCoordFunc(t,e,l,s),c),d=a(e.transforms,r),g={};for(u=0;u<h.length;u++){var m=n.nestedProperty(e,h[u]),v=m.get(),y=new Array(c);for(f=0;f<c;f++)y[f]=v[p[f]];m.set(y)}for(f=0;f<c;f++)g[f]=d(p[f]);r._indexToPoints=g,e._length=c}}}},{\"../constants/numerical\":753,\"../lib\":778,\"../plots/cartesian/axes\":828,\"./helpers\":1368}],1370:[function(t,e,r){\"use strict\";r.version=\"1.58.4\"},{}]},{},[26])(26)}));</script>                <div id=\"a5ee6ec5-ee51-42ac-bc65-1816f8108c3c\" class=\"plotly-graph-div\" style=\"height:500px; width:800px;\"></div>            <script type=\"text/javascript\">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"a5ee6ec5-ee51-42ac-bc65-1816f8108c3c\")) {                    Plotly.newPlot(                        \"a5ee6ec5-ee51-42ac-bc65-1816f8108c3c\",                        [{\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": true, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.013005351835501291, 0.046645117202593435, 0.045256590500714323, 0.03858787938952446, 0.023872621222248962, 0.03772821765573275, 0.051658323800732056, 0.041673298504564076, 0.03683122445739085, 0.0477979263110507, 0.0635827811164481, 0.06398223468192643, 0.04956500769983377, 0.03493406516950458, 0.06175985191798499, 0.021138359574721228, 0.04449853500831993, 0.011957819487208561, 0.10835310113766503, 0.044916347870903636, 0.025802777832253807, 0.07459215023705075, 0.05022700342740263, 0.0381812245975579, 0.039496459667721105, 0.03290588952480786, 0.08153102991561736, 0.03220717903346785, 0.025979244270392006, 0.04403230921936132, 0.06758944777351233, 0.05766654454712426, 0.056132254295892296, 0.04845217305926546, 0.04478793621303574, 0.046718975739373315, 0.04582376752589499, 0.05476335859707287, 0.07493593219307161, 0.07658910396839343, 0.031506321580720045, 0.04909343461716368, 0.01768129014019524, 0.009026717293196389, 0.04601565722916876, 0.029369631496768807, 0.06395862002166049, 0.04201349899953893, 0.041932948684740456, 0.029690183751705675, 0.04550306013815346, 0.050398672239915024, 0.05198417546888513, 0.02781615265825343, 0.045427324685959086, 0.02460983720788312, 0.12367506646701407, 0.03225584093841814, 0.06479936321416209, 0.10011741080351415, 0.056079800255716815, 0.016661265136433706, 0.0884333672001958, 0.037288249530378854, 0.09171261422095761, 0.04777123963820839, 0.028083978911801696, 0.0832954912836994, 0.013930104229779494, 0.03468565732961701, 0.04405962408430154, 0.020384100047991644, 0.016816736935006998, 0.05552520239425283, 0.0267378015503768, 0.03832413063895318, 0.04734930905303167, 0.029902631424427516, 0.037347828188250144, 0.01736089493328285, 0.0339592948946501, 0.05188720405942971, 0.024960081115545287, 0.052397495225792935, 0.028284310904001037, 0.07241967044049695, 0.03402847646465225, 0.024780843354341005, 0.06852330895321024, 0.11460722078599277, 0.04478736164709253, 0.017934800125658512, 0.03516797862586475, 0.019130469938259453, 0.04340900859284786, 0.037811981709373575, 0.018331022715316187, 0.036868923644144694, 0.021008180168968056, 0.04016593624387057, 0.13463241438711845, 0.03790376670358162, 0.012161347981271966, 0.01703906139629262, 0.045083458460266554, 0.03865409619925964, 0.05869658423527595, 0.0346838110577195, 0.03794548785193794, 0.07331954795987376, 0.031594707059764096, 0.03397631353788799, 0.015635555760274013, 0.06860630691892679, 0.03331588062968466, 0.04295700905664314, 0.032379675220938466, 0.05143598976334737, 0.0514805224543858, 0.11045827244919156, 0.02338943233142697, 0.04081354100978182, 0.06446854346582005, 0.07274565617403678, 0.035449508277158585, 0.02512911075515853, 0.04653464349347257, 0.03369490263022242, 0.028145277437062997, 0.024825402858456778, 0.00887842086564389, 0.06622151351503788, 0.01262501503656348, 0.021269592351370284, 0.02987093645178022, 0.0369006933103646, 0.00994015648405278, 0.06435856388341035, 0.02865314201992606, 0.06484525188082649, 0.022078878058481122, 0.03218406616079231, 0.03282594824990919, 0.032881884159700524, 0.042910021053807396, 0.01505134189726725, 0.044861534279921365, 0.01949202513412362, 0.023875570660757444, 0.025711891076136983, 0.027771049231711416, 0.015730014401337793, 0.030565245767995238, 0.029809208917281324, 0.0448007605248882, 0.029646451622548125, 0.019291926798741185, 0.09610902427905992, 0.04214331259830825, 0.039737731398593996, 0.04065426366944467, 0.02929881432904832, 0.0392717584186504, 0.01683135772304189, 0.027068150154645407, 0.024551850097674518, 0.03907627959345137, 0.029090878914200494, 0.027689296158871828, 0.023263087195734826, 0.03979922144583637, 0.08980976673023355, 0.04571407139601727, 0.002689426591161699, 0.019324849427287138, 0.02255598995684376, 0.06716082157987742, 0.038182676334174416, 0.07878934679132316, 0.01112370104003217, 0.03191094049402783, 0.026783717030118552, 0.03980479473548551, 0.018843296134183486, 0.04089248253993931, 0.02072409561444675, 0.03348788269044411, 0.02606624887595254, 0.04073386786565666, 0.03298753151489842, 0.05478346074420599, 0.04838385333817813, 0.047875190108654, 0.06846785950925081, 0.08355558579487186, 0.030577698527204416, 0.02876196097913048, 0.0369152068460901, 0.03344882369762467, 0.026126746839332967, 0.05495057899444815, 0.08153009528834974, 0.04602373945676992, 0.010855613358979745, 0.03342003411343021, 0.02901999088334701, 0.011013952241609655, 0.06555266513098633, 0.03478363231425324, 0.04168652118213716, 0.05307519958624917, 0.02803442068397999, 0.026080411926452673, 0.04200760395296159, 0.007154525768372321, 0.09154502482664201, 0.026644880830821012, 0.0483019853521499, 0.027353983304853884, 0.08604239146675795, 0.047982074695849614, 0.04465195943691558, 0.014300952072165186, 0.006278590890654033, 0.0344742706886703, 0.007238476077139739, 0.03334155989690654, 0.04074780300499932, 0.04086256297605653, 0.003886156956732814, 0.007509450473251843, 0.03431647189802701, 0.01929994199364897, 0.05561696057538352, 0.0470843996792551, 0.038487269062428706, 0.011601142356202248, 0.029939225529350584, 0.0512319460751549, 0.019846733419164535, 0.0467459075603514, 0.08149001356815139, 0.02811990843545045, 0.08609905899051698, 0.09031054308457721, 0.014579226807390731, 0.026470534541013262, 0.00860590806921884, 0.040141731695902926, 0.04804508925806131, 0.05139290114804622, 0.02042003914773945, 0.04632713708786234, 0.03287663262697958, 0.024515671595450372, 0.04070738037567466, 0.06202322145503375, 0.06374049946785935, 0.04069825243805686, 0.07219926694468146, 0.04137420628760611, 0.022583731915801767, 0.015354726121820992, 0.10581404060846376, 0.02919233576845258, 0.017375278234061216, 0.011391671892676142, 0.01630157727988497, 0.06286920468893743, 0.04308271642413832, 0.024657378709244154, 0.00433516372258084, 0.02976879969449534, 0.04180678932536994, 0.04298329736376482, 0.008235040117025135, 0.06876430489243039, 0.0748163918333669, 0.055483983033486915, 0.014466743075078534, 0.07840104746602236, 0.028454244527364933, 0.014621846193838266, 0.018592528743489135, 0.01744191256171513, 0.023053564063663927, 0.07358725738501357, 0.0316059110956567, 0.018144641184217988, 0.05691590095539728, 0.05524195287556899, 0.0028228393667602855, 0.04597971621420115, 0.06861442745092415, 0.026506318507956404, 0.034651857530397755, 0.013505999870117635, 0.06203263284518354, 0.03870009594867307, 0.024548917896144336, 0.05462919361889363, 0.015318810004710913, 0.10351232177908383, 0.030611343193619005, 0.0208079171246819, 0.008022640803603516, 0.07972853228209481, 0.04256587903646212, 0.014135176391010324, 0.03682663559072441, 0.04488003530329274, 0.01996958136348234, 0.05495358588955095, 0.034015246126199924, 0.0463141365757873, 0.02465307904076913, 0.030873123098224885, 0.04481374954564437, 0.0768196887727226, 0.03712140707178943, 0.05547128895658159, 0.015572149535611033, 0.03652853928806801, 0.0360417133948255, 0.027069948546047655, 0.04365184697352591, 0.03732921225169013, 0.017876079486262415, 0.006086260208018846, 0.013293342480826522, 0.018298515689469153, 0.06199802482320417, 0.0265010382469383, 0.029923714164103714, 0.03577075192644712, 0.050443722040302334, 0.038257412041627595, 0.06062690746940433, 0.0064087224159119355, 0.04457429344315202, 0.04888560262418563, 0.053098703163766095, 0.011476631043478848, 0.0021814401524381773, 0.04820399121531556, 0.027275629747178287, 0.01616961863492766, 0.02970680211400313, 0.03500990404356872, 0.032936429619909294, 0.02458930030585297, 0.039548078672059124, 0.1355999527919677, 0.16571702946337963, 0.1696624588822165, 0.11494297414056717, 0.11605239968987242, 0.12063934347562252, 0.11301431714767411, 0.1241399362803467, 0.1590730400095063, 0.08725795849797227, 0.14090399317924054, 0.19512734405936735, 0.14050395738693977, 0.14698555152262413, 0.207294168611688, 0.16372463395518644, 0.16188444479578928, 0.1383243606335694, 0.3020620334052271, 0.12151646052276897, 0.08712175572591443, 0.18727863537928752, 0.12740062865158244, 0.12670981652674176, 0.15711079772201278, 0.11604955750367335, 0.1582701492213434, 0.2413926655126195, 0.1046993520351187, 0.12819988052210501, 0.21421273929938195, 0.20123691057726262, 0.1472915576830987, 0.15931181429374605, 0.18019509531797903, 0.13736627575370575, 0.1888846774255076, 0.14738961693740663, 0.13309905876315412, 0.18070632111160986, 0.08396568032161844, 0.07289039316557108, 0.11313424821222022, 0.21385136030374036, 0.1283108943232125, 0.08942377332958484, 0.1449111999282914, 0.07139777043654073, 0.11280492233533053, 0.08705840791545569, 0.12202953258829734, 0.15445359111312898, 0.08213787114307766, 0.09347476966438756, 0.21154869918621358, 0.09423765534114453, 0.1741547831484387, 0.11320248366363587, 0.19155406483238746, 0.1513258992664276, 0.1703367388296512, 0.07265779355000104, 0.22805346596625545, 0.11258612762415603, 0.21634390397417932, 0.142585770677655, 0.08289095089440385, 0.2740201203813476, 0.18627843098534694, 0.22225313849987524, 0.11657114080604046, 0.08777711330161941, 0.10511681632769686, 0.24192794646707275, 0.15508541446780005, 0.142122088300605, 0.22965736296628753, 0.16518942470992767, 0.11167137267728967, 0.15383877491037692, 0.14270252247731532, 0.14112192987193986, 0.16014016984451204, 0.12263111079171782, 0.15767479165186807, 0.1238006052951659, 0.0872406755544005, 0.2545936168321679, 0.2041141069944828, 0.20298651750049285, 0.10172512292140916, 0.08683080319315196, 0.20103392792084526, 0.09360711135330702, 0.16086799933785395, 0.13704006019378864, 0.11366802763434188, 0.11340077020107739, 0.10366442087557047, 0.14301667981330426, 0.23739164875399685, 0.18170802703788205, 0.17588205094779694, 0.09053924331261266, 0.24537888145254505, 0.18135532015754333, 0.18012640787468803, 0.14789016346537298, 0.17912661716822656, 0.09147842880338432, 0.20469952074270095, 0.08679687315898557, 0.05525196564473933, 0.19987678275473658, 0.3210772243478606, 0.09841549285357037, 0.21794835255751688, 0.25273703339119113, 0.11949753538975794, 0.10371377225965263, 0.10288055971144669, 0.15235676249909788, 0.1836995185623246, 0.14230547442791924, 0.19204287489335384, 0.12658719649358144, 0.197913023613153, 0.10350449236049768, 0.14148933031866628, 0.1638490159905726, 0.1352383899352243, 0.1992624108829806, 0.17986150999223033, 0.19689670072928553, 0.19454660344748728, 0.1115160100462456, 0.10170791658662981, 0.12235636101855386, 0.10968037144911867, 0.09275880687299276, 0.1287771584165673, 0.1338371997999568, 0.1867183952802612, 0.12333462465434306, 0.22040735689863084, 0.1232634167817812, 0.1631318351193782, 0.09590267083577572, 0.16727393463013635, 0.15255065935273326, 0.17003811775676667, 0.09379068900260235, 0.14696664447265287, 0.07760122102955658, 0.13390907416901282, 0.10331484729484205, 0.17734978348016742, 0.12394467579020609, 0.12935314928331684, 0.09354907253216352, 0.1467227833645959, 0.07526016358526484, 0.1032470255309055, 0.13619540229199395, 0.1356587270575185, 0.09143022655118858, 0.1650048741289685, 0.12344622834315225, 0.13980724638508213, 0.14727779874397864, 0.1384405302064073, 0.20115861639140115, 0.25938339771762975, 0.10418991122635142, 0.19193906997961385, 0.15002728830422127], [0.026595458583605867, 0.043315852301255356, 0.05590632730614274, 0.02786416913412752, 0.027886766812673984, 0.045713312968972235, 0.01813268638215959, 0.03755309761712148, 0.029457850351689324, 0.020324745470838203, 0.02048405920035176, 0.034907926249528126, 0.08233568270600612, 0.04669515423536782, 0.055765321162799676, 0.008346613162317345, 0.027689403411181226, 0.04293093525414025, 0.0010518741516035892, 0.05391846703846128, 0.03183571832074273, 0.01615995635098267, 0.04122269324838154, 0.06471730753659241, 0.03148090278339242, 0.015939825773990203, 0.12591313871164478, 0.02836928729178204, 0.0660089700813255, 0.03759504476141545, 0.056002938654273755, 0.02009715607029296, 0.025644084633958918, 0.07127753293682491, 0.023587418179358208, 0.09647721379634835, 0.037052462989043806, 0.005570382824272759, 0.03584415464091205, 0.024177093291655186, 0.03747575338028612, 0.028630871843967228, 0.005996519232153773, 0.036240428941504615, 0.01342145057635442, 0.06696347733058276, 0.03855215287917564, 0.009201786578482678, 0.05306297282297766, 0.07713651209468804, 0.046766522986393784, 0.025381944668028626, 0.041268758115268526, 0.04210183659808771, 0.04167252858620017, 0.03832252951519143, 0.06916362822296158, 0.09659015813902502, 0.05073891486972571, 0.03362012095749378, 0.03531720106219573, 0.05616055358381522, 0.04108090569535571, 0.022610387945127104, 0.0226044450180545, 0.038263364544799255, 0.03669181177693029, 0.012134305077544864, 0.019498123194000894, 0.021336596316447663, 0.03508039562392139, 0.011867672963548574, 0.0033956296618036447, 0.008210289731411444, 0.025308229772734548, 0.020252756188593565, 0.021151764198176323, 0.016836352616308198, 0.0612970122376517, 0.03484925923628673, 0.03244530214297195, 0.03631947389353187, 0.031056859710764502, 0.005841745531201484, 0.06271733158838845, 0.09923719876115361, 0.05424264480449981, 0.04796608261043026, 0.041321200664125146, 0.019149083959599657, 0.008583545005099188, 0.0668545626103878, 0.02963702108020023, 0.041007495320011536, 0.049314952770909, 0.048806875598646944, 0.05218423166943174, 0.03721945100433884, 0.06640452425926924, 0.07267773481867007, 0.018641721164326996, 0.010275931863655007, 0.04837237351063279, 0.03478755085398594, 0.010239589610137045, 0.029692769298450123, 0.047486672448294784, 0.05131156176268574, 0.0677233292991596, 0.023228291482214006, 0.06264300573797477, 0.009786207285228997, 0.0020265010243747383, 0.06902551023109306, 0.054849256205582814, 0.06502915128705002, 0.01834811222168707, 0.08256566230087511, 0.0871779099707642, 0.03301633259041175, 0.02861052837913796, 0.06980034687946882, 0.038490946284465255, 0.027677666944181247, 0.03411180767861586, 0.05804884540397794, 0.01647134044868571, 0.050706348472064545, 0.06349721675618522, 0.04101617509619363, 0.041838907561595404, 0.029025221348650036, 0.0283849403832949, 0.03768312955094922, 0.08683196764679686, 0.02720872345831125, 0.06387281817414107, 0.010485332421658021, 0.07218395284707509, 0.009844320799945103, 0.019003345308104352, 0.03597452365342648, 0.05640779697005788, 0.03585849580685458, 0.08531784082973197, 0.056820913713665745, 0.010907942909867534, 0.012202847921740145, 0.042701522564335216, 0.03549176185662228, 0.0455462368535659, 0.03646958882229463, 0.0501337360530611, 0.0884309157188381, 0.06994964975503183, 0.06338046112608525, 0.04712344718075568, 0.07240717554645193, 0.07811165009174617, 0.021405356538091457, 0.030501817518304435, 0.03155104196329992, 0.048119361482320294, 0.024167722121121425, 0.04366286714831668, 0.07337868228674897, 0.0450779004923759, 0.038567918968657335, 0.03568338342912255, 0.03639440112296612, 0.021671250334850723, 0.06474786678389197, 0.0348243422265495, 0.05604018201871265, 0.041404581673803835, 0.030861568577106924, 0.05531216866426891, 0.012495279004196487, 0.041134535680494966, 0.03666338991493948, 0.026515605408818494, 0.020714858509299737, 0.02214830094617942, 0.07785350144390138, 0.11127885220752609, 0.07424059248859845, 0.02177614883910264, 0.01721640500510412, 0.016442470425259204, 0.057123943622554504, 0.03234319794442385, 0.032011573803761316, 0.10628395894121741, 0.03534432440515488, 0.04535794010265701, 0.018145801807423274, 0.008395448394660509, 0.022234776951072198, 0.0460034764311727, 0.04904756510269739, 0.053499528026628884, 0.055439511629482435, 0.09714030119920931, 0.007223761922139074, 0.05998878304155604, 0.03353726088760361, 0.03776203277671049, 0.05799935995450905, 0.028578276077525753, 0.09314076299028051, 0.02566036400234988, 0.023268304254499175, 0.06680097476008438, 0.03609210282804505, 0.04739211804624047, 0.03050155704841018, 0.018481614533811808, 0.022910138997699947, 0.022961758002037966, 0.038508118145288005, 0.038939414155339046, 0.011253859378367422, 0.014786807906573579, 0.016919973028463223, 0.056036734623053384, 0.017002279599828106, 0.10940605834607156, 0.024259014903838118, 0.07518490310758352, 0.05101539217115891, 0.0021951524080753688, 0.014261847114070289, 0.033813290027601105, 0.08280008520570495, 0.06681923063532, 0.029453897338000037, 0.03636879846453667, 0.02800180640582356, 0.013146718040168768, 0.03200271016647739, 0.02567486987719613, 0.03165551145831424, 0.04394144353066241, 0.06720792066546218, 0.05582707934081555, 0.007572722632528073, 0.027467963781448144, 0.035556312425122145, 0.03824752567696475, 0.05581272285311453, 0.02569636247391182, 0.04227741628945355, 0.05201160907745362, 0.08943403124689095, 0.03173819915842145, 0.03562804506791215, 0.0552889715219217, 0.00494473030783176, 0.026989505483558583, 0.028204819705757885, 0.0387903755801099, 0.007118192133343509, 0.07738703816768623, 0.042183723736314044, 0.0472388353439108, 0.024114536466978254, 0.02407189409789299, 0.02260050924134351, 0.029132182544638074, 0.04759960529965259, 0.04864060387556111, 0.03258318647802357, 0.05858821726794686, 0.06012050802969645, 0.059370078942588264, 0.04374749305087232, 0.060357972303585666, 0.027995917104905652, 0.07985613188676297, 0.02097767837826283, 0.0297898039101593, 0.009360439557161544, 0.013994859726799112, 0.04354106682923533, 0.024563703393082947, 0.01652890812575577, 0.00857021028716718, 0.03463031896840661, 0.05819817892305794, 0.0974734728374789, 0.0061340391966364085, 0.010312562357754478, 0.028144335148916132, 0.06864508628965386, 0.04906215141677568, 0.025931147355285865, 0.019026565433089292, 0.03281820310099471, 0.03495817395648168, 0.05028490818315937, 0.03718111213416823, 0.030101739591167822, 0.019796012652917735, 0.034910534778910304, 0.04773065613041963, 0.08016186991646405, 0.07501919062868243, 0.005154002067302504, 0.05958879704497034, 0.03557809230480944, 0.01588629921072073, 0.02354681360415153, 0.008478030757678133, 0.09735739519519192, 0.02807279594332701, 0.04171526863149578, 0.037252588137503595, 0.02387853925146403, 0.0014620128481070542, 0.07650250538943276, 0.03523942781612277, 0.0657524838442764, 0.022015568552418582, 0.021448184683498357, 0.04029169723752045, 0.10350875180935669, 0.044214488758194836, 0.032954731460420356, 0.01765350987684102, 0.059398270978201786, 0.015417641092602526, 0.07039419525573332, 0.029490759573696606, 0.046287024724147016, 0.04397510543405529, 0.043519126071083936, 0.041870776819245475, 0.044763283503632394, 0.03183320363713128, 0.03995954832662979, 0.10077291393592473, 0.044916236788154616, 0.07861821040991815, 0.03655393127231829, 0.06984934586310579, 0.05842466898743184, 0.008482729749483688, 0.10122741091876261, 0.019952738920467037, 0.019354113985994653, 0.015210550289691217, 0.08075528928349096, 0.08990689135727384, 0.1383545904630615, 0.25142538361251354, 0.08943503482207175, 0.17061976235239737, 0.08088304210574397, 0.1572754606604576, 0.18838920239959994, 0.1344282366335392, 0.09107311466528524, 0.17370775552286258, 0.16166952648951163, 0.169346233108832, 0.12112502023697862, 0.16124171234907644, 0.14277618949211415, 0.16347516508352372, 0.1810061372816563, 0.15120220671017326, 0.17094758669695548, 0.1165720064853949, 0.09607618208974601, 0.1444541212291487, 0.14933748741544065, 0.18295276669725297, 0.1156508700261193, 0.21567130942017804, 0.058068070380437764, 0.16480238176882267, 0.08180306773752936, 0.11076501405407345, 0.08357894381568318, 0.0669473588406559, 0.166801028554478, 0.14970646600329107, 0.18817307367440195, 0.09742732370092023, 0.17527321023085426, 0.11356252200540998, 0.06656260650244451, 0.09003024683484147, 0.11702724657351933, 0.1241504087022716, 0.1302852484607889, 0.08408818544159014, 0.15829176822256658, 0.13950825758999394, 0.13364809865672744, 0.13714778747770096, 0.18101127007074896, 0.17268796992157737, 0.09413843929407098, 0.1892531657170865, 0.11603706260962833, 0.12980180101529246, 0.1096148709315927, 0.10785080026835205, 0.16376391894394354, 0.17089278076685246, 0.12170614389282082, 0.14189822208737174, 0.14652038293500103, 0.06335209672068877, 0.14592462699980507, 0.06821656734832833, 0.15956736590352752, 0.16446724894546694, 0.15585000085974896, 0.16833712677321128, 0.08580301963393727, 0.14015005540943917, 0.09557895272249177, 0.09657033944442388, 0.19122001985388418, 0.17108526801870716, 0.07340425430166145, 0.1610607317378444, 0.286179835637731, 0.20083610869703755, 0.1362433900395709, 0.16058719747008818, 0.078190618434981, 0.0997014327215091, 0.23802632195574625, 0.11287908730728012, 0.17683368536733812, 0.13455758291867473, 0.17986733226045487, 0.13342928862379444, 0.1138492227501927, 0.13455724583998804, 0.19374866158731524, 0.13936481528705166, 0.11551295887799033, 0.18779002971226172, 0.16949336795556932, 0.14421326318575492, 0.13935249659322924, 0.20391057275475996, 0.24669393266160644, 0.12514125916265673, 0.1105401442656594, 0.11980009415457327, 0.15497903549863448, 0.18670382428794138, 0.0920661025109791, 0.14205274202169912, 0.19237938667497329, 0.1840944062437742, 0.09211702437530603, 0.11089693439463455, 0.12137772199968178, 0.1216448262153614, 0.16541727458036717, 0.13089261828891693, 0.17479887923165677, 0.13692453413480712, 0.279105810388442, 0.23945927409635437, 0.10248117509388155, 0.08166337926541606, 0.13473081072011303, 0.2499818288150334, 0.22864301658926472, 0.1209907863108862, 0.14440365135669708, 0.06792213677638961, 0.14726053112216536, 0.08574254465319457, 0.1961623135233118, 0.15303661956662132, 0.10046630256598997, 0.1869963932662241, 0.1575983207552664, 0.15231972980883815, 0.07496043168489011, 0.16088013417057453, 0.1458295095231264, 0.14384748684542795, 0.1028151817679886, 0.06929349544788561, 0.07544852162320768, 0.11711071185286968, 0.19298447356108697, 0.20612727880718248, 0.15169809542356, 0.13727673539711585, 0.1670821368574135, 0.11496248639999859, 0.13896131677733314, 0.1628642865727025, 0.13662173022185603, 0.18214252146501697, 0.09844504852568912, 0.12481204819895568, 0.16754238716056272, 0.12391994647201031, 0.12018638632951245, 0.26056173287572404, 0.07088354923912595, 0.0783587287690851, 0.2550333666224634, 0.10787909189539571, 0.09671274752866837, 0.20133670119027938, 0.1558912623553507, 0.1625120699886353, 0.1870582472052305, 0.12618899165141967, 0.1989608939977423, 0.10964039698122971, 0.1870347129841966, 0.1373237119086327, 0.16267258073053054, 0.12166265308135941, 0.17277412416954196], [0.0741334857359048, 0.03927671117708087, 0.07780179050901244, 0.022065006121392214, 0.03723099977979737, 0.00788392334793424, 0.0192833925792647, 0.015695023335396283, 0.015495396144087277, 0.019393377907333836, 0.014119420835237591, 0.02174935108351131, 0.05819249455065978, 0.030111641277589148, 0.05927731718627676, 0.007961156023215623, 0.01831061030257373, 0.04149927397168452, 0.07419703272922386, 0.030818556570598198, 0.027769970962957993, 0.02773475581629863, 0.033191184498249524, 0.07747826391770955, 0.02778829578610678, 0.062100197969665455, 0.04371684570346148, 0.008813786027472346, 0.06301094627668781, 0.008112653740681708, 0.030594142604499098, 0.028571704958355235, 0.08694950085613998, 0.019029093523239417, 0.06214629348006941, 0.01361866937875147, 0.033032872428696965, 0.08349673492052863, 0.05624350558425631, 0.02052424434241989, 0.04566869217782252, 0.022137876404749773, 0.026356287848865314, 0.018067360149636384, 0.05863188044919122, 0.04046556472237553, 0.08069924995182984, 0.012506107657006191, 0.019057375574184042, 0.04395448617757328, 0.038021525908862396, 0.05365222467169647, 0.0692512380379823, 0.037023910892105875, 0.02448588609695435, 0.0371045952722911, 0.03550023478906482, 0.010142995498984331, 0.04025121715160147, 0.016142953029503266, 0.04798030886318415, 0.04945799287769103, 0.05513367783879081, 0.043129187317625176, 0.040628101766830495, 0.08868617621520836, 0.053128584423252655, 0.01718102897998066, 0.05653770249937812, 0.024955270083380804, 0.02214754060391457, 0.026664138366017612, 0.0038232848389945446, 0.06375960187025129, 0.024556080818236358, 0.042407647406141606, 0.013239753672913199, 0.055066871141353925, 0.058508544123821685, 0.056683393270378156, 0.006801563206188862, 0.025322695427964774, 0.039918210222235614, 0.036699848039255994, 0.04005237520041485, 0.06361717463380868, 0.027724358087946332, 0.037698868827353564, 0.05492746612177261, 0.007616403050750735, 0.04762133155318518, 0.011557099003825459, 0.08904262926549682, 0.039809820272268794, 0.020858551706037214, 0.02725725895875404, 0.02237615273183873, 0.025653409839217222, 0.022137476123809334, 0.029535673393477357, 0.0681966950275725, 0.014078098052601903, 0.017491503348273617, 0.06763634767623679, 0.09568186897423961, 0.05416694765670165, 0.08695906163343499, 0.00391024683091429, 0.02637146596586512, 0.025106748648648782, 0.014469871586639316, 0.027762080257337902, 0.02167651718933015, 0.056275482094215776, 0.03958062591752218, 0.06211099597895819, 0.02335578000413314, 0.026376142932642854, 0.01953637204884041, 0.018542323171371417, 0.027683062118387995, 0.01680297608066711, 0.021102772875418587, 0.06960854910674595, 0.0482609115480896, 0.01764733520817132, 0.040128999314601385, 0.026169894826448253, 0.012029588519174968, 0.03148409928525648, 0.026448329482527993, 0.03264780216399701, 0.07089908550223036, 0.03177008948348944, 0.021102119785463138, 0.026362906848531098, 0.013158011133782567, 0.019594956707629948, 0.013066562260651301, 0.005768285360142228, 0.09101238687552753, 0.02671157453028906, 0.02300126515629311, 0.003930864650981441, 0.017245694461669174, 0.021875993078274113, 0.0073883329300330055, 0.0457214679749262, 0.045571782055401036, 0.043845196074295434, 0.021008854326341423, 0.03352445955838888, 0.022586020603475553, 0.04194989454962554, 0.0532161099686017, 0.017384072923431956, 0.020372911333857525, 0.08474100726626574, 0.043225155151899786, 0.006601484023004531, 0.02808298299750013, 0.04204025462029442, 0.06387820377224876, 0.02880450950244502, 0.026870037902206666, 0.03797507799801327, 0.0066224580739564715, 0.04321317736720366, 0.06166729700541305, 0.012065323648012936, 0.03989548039352221, 0.026381296789153453, 0.027994139780921322, 0.017997839585727742, 0.025567021934435736, 0.04338718657832473, 0.07506504099095061, 0.06810743812351458, 0.026548855539952076, 0.032991622424414085, 0.029282035088286768, 0.023387903986018033, 0.05947516322316182, 0.04373959085393337, 0.05241082515567542, 0.011271479400625874, 0.013968682502426449, 0.10866695203848424, 0.03871660131300169, 0.004149025903203555, 0.09557519889166279, 0.0333074766451553, 0.02560750968123396, 0.03383223538196856, 0.02125674697209991, 0.03149306442919037, 0.017256839125747644, 0.027916058184458848, 0.0016553421981722839, 0.06321330457144687, 0.0052364987242336, 0.044186760205775506, 0.011672599207339509, 0.05482403276067588, 0.0659629894841102, 0.004687352057155823, 0.07873187487524363, 0.02206641955361251, 0.048739214713174495, 0.026459016409071705, 0.008613640769204546, 0.01769387504957136, 0.017541896611932787, 0.052757391841301036, 0.04129842870057591, 0.029865370823010325, 0.02707219509888561, 0.03222152019941038, 0.04300334588474324, 0.019051725675742474, 0.04371641669422389, 0.040396092038962154, 0.05440763333031247, 0.03990991349001566, 0.04778286502245934, 0.03765269287771756, 0.046863444600134134, 0.043921146031108596, 0.05199803399943537, 0.02999769335973167, 0.02358042954226896, 0.03571702618031733, 0.03210037871594391, 0.029251732480441852, 0.012360046290972782, 0.02794321408615478, 0.005455293435408104, 0.036807092687776016, 0.06458227687905874, 0.04778946870036664, 0.027061180669754267, 0.03705995149850365, 0.019143259776155316, 0.015876859092273782, 0.0586100967390643, 0.06158929393296281, 0.07624096297208341, 0.10817156128224828, 0.021215784250788634, 0.04583745368666226, 0.040646457233496254, 0.01141595975270555, 0.01306173877955805, 0.012478145447769954, 0.01765195663357454, 0.06478084686903224, 0.02367163230965455, 0.024178342014971762, 0.0546487863175571, 0.04410742414033702, 0.05981391581195978, 0.03980322042480111, 0.02879356019078724, 0.06885271143889235, 0.04754315611095198, 0.10103376687414224, 0.02085893858043898, 0.012659222777602414, 0.048305739182978875, 0.05325076778629615, 0.028363514819272587, 0.02721275691123259, 0.027975596622714115, 0.01925599535987262, 0.009447076440518423, 0.013801611175069646, 0.10164883588590931, 0.012816679701509496, 0.047913379591679385, 0.07876227324407908, 0.012044361567184811, 0.03316974552768854, 0.0379748328498775, 0.03660187305461976, 0.02409076858912745, 0.04531909944489599, 0.056699266612169244, 0.054114635342792164, 0.039224632519988284, 0.02229681283596062, 0.08769637529527949, 0.04324802670687918, 0.09582884294251282, 0.03772954298784176, 0.018405777574967475, 0.043077660243838065, 0.04383795271297136, 0.02551998030544529, 0.023763124275231556, 0.04729837952782551, 0.0290359887144258, 0.006849344110026235, 0.04150557887530135, 0.0459019084941716, 0.036474273449951605, 0.023681932361796502, 0.03968759860482909, 0.02891303160257878, 0.11318583657304127, 0.015456732644158748, 0.017688269201185436, 0.02181941940028581, 0.026385288107238954, 0.07315231096600333, 0.07420564355749278, 0.02107448124837491, 0.12036843180295922, 0.04905171729924698, 0.03338949401832877, 0.003767456181512605, 0.03673245657175299, 0.04615760949109832, 0.01876049352088763, 0.06193903988347419, 0.017381776574878924, 0.06432141627996199, 0.012416918743251553, 0.05074373739320905, 0.06628022649355474, 0.02477517430370133, 0.005538663432572879, 0.06817218787487477, 0.0443889461307516, 0.06246356113303093, 0.028344444975617434, 0.028752990089537158, 0.024985775704525655, 0.09960700472396228, 0.05818947616423811, 0.007487306222995564, 0.009182747378344498, 0.01762499799951911, 0.04548285839959018, 0.030130812627894264, 0.08758413575349316, 0.030942829438455166, 0.039190013006690054, 0.080855593175417, 0.05976035094429409, 0.04039722201865047, 0.1625196082938102, 0.06945556900914639, 0.2886470677631517, 0.15650854536121891, 0.2338488598264033, 0.09291838298762038, 0.07107944558224372, 0.1548421049430486, 0.11939814314246179, 0.10539469173959187, 0.1474617058110814, 0.14545104676677337, 0.12846123907835255, 0.27700391027235216, 0.14731784982066, 0.05893994738618213, 0.17034511983154282, 0.10345645098676605, 0.11555996603302418, 0.14106070412503136, 0.10387037595313403, 0.08055430611655598, 0.12282852398892566, 0.13052411467557953, 0.1975022319463953, 0.23967690435388397, 0.2353493656001745, 0.18578343093395236, 0.21586402649841002, 0.14602141454815865, 0.09545271675432883, 0.1463278956831463, 0.10604311621958211, 0.15432199252949608, 0.140381260744987, 0.053471722865417126, 0.12503667283923398, 0.16595771896743006, 0.12141871536451003, 0.14608582722083216, 0.1721147216495968, 0.12789040398333343, 0.12239456582333773, 0.10096534756162476, 0.15298498524052484, 0.14887657827667652, 0.10112225002939663, 0.15209638453539343, 0.18818655682186927, 0.1341695287415097, 0.1290748601839427, 0.09810538812270088, 0.14293300769021436, 0.2534336984277733, 0.1316167705602223, 0.1167291617621818, 0.1021685192902242, 0.15372516407120615, 0.11416736374338789, 0.13972846190294913, 0.12501110082432149, 0.08448390049799796, 0.11296287434355867, 0.1444208883349934, 0.1879745649714624, 0.13889753229675755, 0.10322261030875868, 0.2321630067402317, 0.17100030886790446, 0.14222115879097294, 0.19255331927730193, 0.12329196121783988, 0.175543915059778, 0.19078509641751168, 0.16759130953540727, 0.14866529122715996, 0.13130861935355972, 0.10280618789575754, 0.08377202095523958, 0.16608901111589325, 0.1983379112977174, 0.14795480596442379, 0.09812840140394627, 0.11208640847114787, 0.1682938734490064, 0.1224630694055269, 0.1896490493128377, 0.12978742920583294, 0.12881515637761162, 0.28605122479700273, 0.18377494757934926, 0.14356408027871964, 0.08482640308718528, 0.19884729848033, 0.12188432828312921, 0.15666890288552932, 0.1343953254963121, 0.1353044113925388, 0.10759127266224354, 0.14581783434316037, 0.11275653622203297, 0.11366405163801487, 0.17064482874927983, 0.05405673824791467, 0.10911089232972554, 0.17273706083576526, 0.19636742590415865, 0.1288742983653661, 0.13731009086533902, 0.11638464436175362, 0.08349770019131322, 0.10836636211963431, 0.10328727579044719, 0.13159855298938292, 0.1450002040233343, 0.16758613078103912, 0.21234877077081513, 0.24705122074773236, 0.23217794545475515, 0.11370720537078959, 0.08946185556030081, 0.15194532731848379, 0.15765413792142946, 0.2053157312254752, 0.08961845925378223, 0.18476609681402484, 0.15894632906683032, 0.10135663462983024, 0.1202329644753087, 0.1727665092555746, 0.15247500050933133, 0.11852651894573243, 0.13947798179522639, 0.15088017399032272, 0.24782610336138358, 0.1215696729899895, 0.09159557896876529, 0.07285867712550587, 0.07728808259050693, 0.1092329454578219, 0.10432652768588836, 0.15155595547008902, 0.3685306409193624, 0.15594979147276572, 0.13192818530144232, 0.12508397876855828, 0.12545839658067112, 0.14406220596884528, 0.0915959773344859, 0.1291577202538329, 0.09647016578744497, 0.21783276521150144, 0.12372116963829725, 0.13623571383856958, 0.174128950663632, 0.1656347362985534, 0.1212031765270137, 0.1144976242475452, 0.08527531528905516, 0.23464844111473332, 0.10487244194073063, 0.08645869896657045, 0.08719151569229942, 0.2517361241963602, 0.1428931404746348, 0.12819581259522708, 0.19076125576130806, 0.20865581328830413, 0.11847696071791074, 0.16020161009603934, 0.18095007496735743, 0.1419699125953259, 0.12583088385121477, 0.19476947374641898, 0.11646162853726458, 0.09659161370608116, 0.18247770025364815, 0.17563253611085877], [0.054664728607261376, 0.0536200681310748, 0.030751541114201954, 0.014275768846874277, 0.042492284800016114, 0.06912461136497798, 0.14492138889768433, 0.0523871262257378, 0.024715180043131117, 0.007269585471329911, 0.013974718317659873, 0.05734359635220421, 0.05558301521945865, 0.012926788561256423, 0.012346430035728601, 0.022870884652459816, 0.0251810610925238, 0.07309487735432002, 0.06858675635509914, 0.044554202787337766, 0.00849704410234887, 0.03844378591184655, 0.025635822375695554, 0.021692147298205285, 0.05121329566463829, 0.024609279878918203, 0.012216863500314855, 0.031115088138669252, 0.027019476758376248, 0.009299385222426106, 0.02527501794599718, 0.06370900176285256, 0.06303272232593549, 0.050608821648864016, 0.0055860378310054306, 0.03842063473477479, 0.03171436041743765, 0.031211643945425752, 0.06873504799460212, 0.029462412405278415, 0.03240593288454317, 0.03800304786812875, 0.05897504953487266, 0.0381737437489773, 0.12691047793674853, 0.054923260299068306, 0.05642473900450334, 0.015377980720762525, 0.07510216561176124, 0.037628070811831185, 0.04957806183806351, 0.01786298512841665, 0.018602009081552108, 0.040243307293783274, 0.09323513736167262, 0.046953015600241, 0.08072240878978083, 0.026031451247211908, 0.005401508317464182, 0.014918796237437956, 0.012355867281345832, 0.021968507771230033, 0.04684979674376307, 0.033815971335336086, 0.03879278492663176, 0.03769383179925142, 0.048294791786540905, 0.007765081564655468, 0.006701939217295619, 0.05338496723843198, 0.07031536480832486, 0.05324033366876745, 0.015135130848765615, 0.026011793431074872, 0.05358730255055332, 0.027953745879893823, 0.029495549538443168, 0.020758575316698804, 0.038736450651119796, 0.044630102948435856, 0.0311691107438697, 0.04244919618471496, 0.07413758430629969, 0.05205147629303317, 0.05300988292982502, 0.03646347544065887, 0.020075709438852726, 0.04009368649173168, 0.004529576727955212, 0.040580397471785545, 0.035833751166900324, 0.01514254849509246, 0.0386445124393269, 0.08024078463354418, 0.00988584372305101, 0.05172938611658831, 0.08610607635590338, 0.08343576964351439, 0.021879264273710793, 0.024762570242127104, 0.028583012416117617, 0.032124763294573755, 0.05426130670633528, 0.02519023691063687, 0.08777465415938247, 0.04948646836583653, 0.018569990436756806, 0.01379316792853417, 0.028708947694770275, 0.03347184847018892, 0.06798781349413818, 0.026405734993937998, 0.051377292106589006, 0.02123749518256274, 0.014791774071542727, 0.04662887996903831, 0.04492399725882758, 0.06531302516739215, 0.03655412279429936, 0.03073815564294496, 0.02958304060983562, 0.022037476751833193, 0.0295448262289527, 0.03252369208982395, 0.08286350196407688, 0.028562125028862108, 0.06581478977515813, 0.010149033229437568, 0.02339330490588421, 0.002057658299060178, 0.06141128957331662, 0.024639230086317947, 0.08839143154722068, 0.05646842899882505, 0.03342879432884436, 0.016080377052628225, 0.05280446028336883, 0.034273467552397525, 0.04922459270024011, 0.08210302180340213, 0.016643419118237593, 0.02143399098948125, 0.02398519975794179, 0.06284877312399688, 0.10143457641524654, 0.008462101874512531, 0.03671577500720178, 0.0398718542419374, 0.033174908960298184, 0.07641612131509089, 0.054425103965425686, 0.04293870721613208, 0.01748077811733369, 0.029187245114195733, 0.04653235289057897, 0.011666975164365385, 0.034606673664623694, 0.036035668961102926, 0.031402581784453605, 0.033398215929346706, 0.03902926094709866, 0.03065773939353324, 0.023872845302966815, 0.00838978796250998, 0.02878938118116029, 0.011806881013927201, 0.043895819164331884, 0.027328388307303674, 0.07977894852839171, 0.02962524822402385, 0.021298140617868593, 0.0236783528159703, 0.0242968462407589, 0.03567953000686342, 0.08268769244633375, 0.03636116822881084, 0.10878573397114392, 0.055484435025362246, 0.0425738578421935, 0.034550220645483465, 0.06454152100148701, 0.008974946986493326, 0.08733169446068426, 0.0489120326575733, 0.035863670730783094, 0.07414555162071221, 0.029162552185176365, 0.045241739886302146, 0.05010378201522174, 0.07285755863713642, 0.02598775359201095, 0.07062162377781446, 0.008350985609145175, 0.03993895588322513, 0.007766596503525733, 0.028294141727289366, 0.1037556313038353, 0.04566681143196841, 0.02788741224175019, 0.043730348003126925, 0.028335897349602276, 0.034939531206844315, 0.05039303383279232, 0.06546933774746234, 0.04271333564012762, 0.06645359219081941, 0.019926735981097145, 0.04488056007352087, 0.04547344700944039, 0.028342792140920798, 0.03492020663895434, 0.016765435857157555, 0.007747387327629352, 0.01593644732624413, 0.018533698936563828, 0.02962084130323943, 0.04337691333926013, 0.03345999325956068, 0.05976195589849546, 0.030835236219929594, 0.11859795664467158, 0.0801212136303225, 0.09128894461619277, 0.043936820190039375, 0.016473918334550915, 0.010713082700667363, 0.031488914147860585, 0.018625876550833066, 0.03907825610029601, 0.08584541493966695, 0.023153864125150348, 0.04203433276063973, 0.016298943852645256, 0.021311332651924704, 0.03787092834470734, 0.022848382734903888, 0.029439851115908355, 0.010424817221299296, 0.035836091565509, 0.03806312831359045, 0.08246134410822585, 0.054681053940927794, 0.050225563182104985, 0.02722800589136539, 0.04262667194369339, 0.06532199605698548, 0.03485837185214605, 0.02706155030717773, 0.03947971298569634, 0.0629432202737418, 0.06478266249741278, 0.0601947381191196, 0.0069133541077345375, 0.04652315217460837, 0.026103021096318, 0.042103954831198345, 0.012883002805944174, 0.015105550278789334, 0.07246428740120704, 0.026256508727167404, 0.11195845646603454, 0.03608976242943637, 0.03185021653470974, 0.06062064087018371, 0.010624914599071828, 0.03270656110778932, 0.023885001203105338, 0.041859856235884854, 0.12107770664677506, 0.04324343784021274, 0.046151928949139776, 0.08020664009475902, 0.06466985605056248, 0.013087671813404849, 0.08920902356265054, 0.012522024091243023, 0.03189753395535293, 0.040510216157042214, 0.07935357054755574, 0.025369246760683677, 0.046915197669858896, 0.060441192434800256, 0.013876054811501696, 0.02652619274393205, 0.04036064898114532, 0.023366758044088082, 0.025494881349826054, 0.053568613835640495, 0.02851613677076755, 0.010889258983004238, 0.0233606408320127, 0.05622470578659446, 0.03041510785659475, 0.05871782785341625, 0.08146687005195888, 0.022756275983767647, 0.010733608111378648, 0.04852432705041382, 0.05168628217952867, 0.07950278149256784, 0.06791616129058023, 0.02422193433308313, 0.03177497137878691, 0.04030816429745286, 0.05379863173490571, 0.0352942528984239, 0.02998144271963787, 0.0028614607318529803, 0.05951807946868001, 0.08770989674714305, 0.007869943679730979, 0.02262196161844317, 0.00416976246689897, 0.0491844458625682, 0.014548940478914208, 0.011654258104822329, 0.05363652753012796, 0.04973026818685955, 0.028995282632569154, 0.038996840106143106, 0.05676332688439758, 0.0236093053113549, 0.06324169578992071, 0.026854922987460613, 0.010953436083641025, 0.057988244018727736, 0.011477056222276823, 0.01878609426409727, 0.030087846586660996, 0.021377135774180777, 0.06892502247806519, 0.07952463032016832, 0.03376033419983522, 0.04553084997760673, 0.05406703446961699, 0.03407234648963617, 0.04915269151810677, 0.07457960171685105, 0.03379942766661125, 0.04035391123785127, 0.03605889291652749, 0.023482167274661125, 0.027146842706227498, 0.06315797770155535, 0.11206637527192793, 0.013446600285298644, 0.03229306515065893, 0.061162268863089626, 0.025944170849998633, 0.01746780633355581, 0.05902846884583274, 0.029780375283031218, 0.26464718784536084, 0.15098126695281075, 0.14773568949632107, 0.14120203202530263, 0.1492942034477188, 0.1699960595297237, 0.22289755634002148, 0.1937868127659444, 0.14816281415762442, 0.10949791994907203, 0.17717372115340926, 0.12773930080114834, 0.18246812415459465, 0.13314669411028587, 0.11853971097978855, 0.19036852844780494, 0.12270260211681167, 0.10018548537646571, 0.1988480492464958, 0.10910964360640896, 0.14011999411929038, 0.16211879109182667, 0.1349239874510996, 0.18138400248942838, 0.11587482050902422, 0.2521712008503176, 0.15096858053678466, 0.09522147311438477, 0.13788732279452587, 0.11187253970532648, 0.0761518516247311, 0.14644835534836018, 0.20029940281904515, 0.1360318271984016, 0.07115192516075988, 0.11407492757444421, 0.1080696945709567, 0.31432731557757626, 0.20365076169611948, 0.084150874416434, 0.21245200877949116, 0.17654053416223298, 0.1814686398833029, 0.1063862240182296, 0.20889405131099686, 0.25251431630984433, 0.25641646176095934, 0.1688301809612782, 0.15571529195914346, 0.15978164069594877, 0.14260421807487167, 0.08267755710309552, 0.16538088540396384, 0.1237112794431948, 0.15976739146055716, 0.14301018338770638, 0.15037273267103782, 0.07187798499099671, 0.12286705821151696, 0.053492426391570806, 0.14145698608650317, 0.12637266889214516, 0.12695362400864402, 0.14927175707153736, 0.19493386089321108, 0.15168438244971538, 0.19380607221636081, 0.20501747787479432, 0.14515614888120085, 0.15104151210717617, 0.13104465609836963, 0.14691116438517648, 0.07629291139422886, 0.12657670874989804, 0.1505113486200571, 0.130753603974177, 0.18186008016909325, 0.26812777043350283, 0.14675423893476688, 0.15936298896708798, 0.15333723246810899, 0.1339476237133626, 0.13640111222142173, 0.17524642779702143, 0.2121694142659826, 0.2097492965479051, 0.15102916276983677, 0.21561743811734263, 0.1908787889706512, 0.10969650526080402, 0.0634820367239656, 0.062002238306787714, 0.150694060589998, 0.12613709685542893, 0.16219806587023122, 0.13205682678568748, 0.20229763591722136, 0.17064777052690908, 0.19978816170365582, 0.13763976914267387, 0.1354763368445058, 0.07469730346553749, 0.16953882761299613, 0.12398465791897428, 0.24214481063667806, 0.1157389241721361, 0.15503728882439677, 0.1970042594738545, 0.14812296226380334, 0.18218968183763568, 0.15615858107564912, 0.20597726346984987, 0.1009832893408114, 0.20784916866931225, 0.10427351440152816, 0.11356996838003398, 0.18256151027256445, 0.12683070520119322, 0.24015031604757234, 0.1396132882444128, 0.11461992252377734, 0.1729112079427127, 0.12270366697902642, 0.16901231070439662, 0.14331962162208173, 0.1254220074042678, 0.12473422132672803, 0.13463837455116934, 0.12955334337968982, 0.15344807006899389, 0.20229581262796156, 0.09779657808042343, 0.1686182963631807, 0.20470828478855474, 0.2697525509903508, 0.15402547053752408, 0.11120360705160326, 0.1583387140905665, 0.176217888572043, 0.0968713047463567, 0.1306570309304422, 0.1225521271267245, 0.1452970477722345, 0.14384685865333005, 0.13533275664573716, 0.10173657593587715, 0.11154810146939372, 0.1082445158352775, 0.09252970061835744, 0.19325959105645457, 0.1340567759208141, 0.11692665156818206, 0.09159555598612755, 0.1292930573465363, 0.175169175490737, 0.15497353498733815, 0.12657230374433343, 0.14416521415114403, 0.16787566605114168, 0.18839370699659472, 0.22602411437659498, 0.3379781351935479, 0.07575887150221294, 0.13328849698507017, 0.16083553253162294, 0.11031645425264874, 0.15955469480925993, 0.10521184187382461, 0.1851968220885723, 0.1714890882853539, 0.13936866104843157, 0.19687711952194092, 0.08731176085289448, 0.16591952182352543, 0.1530462416309503, 0.1714658604994897], [0.015324178365840307, 0.03147115814499557, 0.035688393644147345, 0.029449185897265712, 0.0073959210309230035, 0.027334407843168707, 0.06599011665750897, 0.036973571254601406, 0.015317693431561273, 0.03599486711825575, 0.01715867070391053, 0.07732493908054407, 0.02092775242823747, 0.01851904367457234, 0.017807491634401585, 0.04355098383741514, 0.03713249236405377, 0.04111763195044572, 0.05248580601126437, 0.06749863571096813, 0.015944507528817462, 0.01824237485115807, 0.0018896883745084427, 0.026724676549014066, 0.02025113591263371, 0.06329707628596695, 0.02228558198699067, 0.02538159609802308, 0.02426155831574673, 0.016480797804110957, 0.025480218426955324, 0.03312046309151957, 0.050129522569477565, 0.012352342319284237, 0.1309891300456178, 0.0719055794780293, 0.05675206922235028, 0.07105803342476007, 0.0715094430732631, 0.038672509122519724, 0.043433584693458774, 0.05568732192078906, 0.04479298090201713, 0.009190606482837711, 0.0368300331906686, 0.023631498878521305, 0.04100560691327818, 0.041967889954966885, 0.014453568278000721, 0.01643440543463634, 0.11881367934326972, 0.03434100203336247, 0.06446688105502436, 0.022820539269295913, 0.03554442274053732, 0.034922838150974245, 0.027661651876124165, 0.05390950764018682, 0.008457507262186659, 0.061563499752552285, 0.026772001630536495, 0.027524317209158215, 0.032344063623778285, 0.027789107839306517, 0.046089711118369334, 0.04099203949613918, 0.031114741483883514, 0.02131257562958185, 0.029639989670906818, 0.021040736990530166, 0.06877761950055439, 0.06532284641458143, 0.06984296435069653, 0.055474315003882495, 0.04498194414942015, 0.02962584577260479, 0.03523245641601182, 0.04408374053215788, 0.046733148365972504, 0.04391344301702996, 0.029579250389830242, 0.03651748463932065, 0.06173752428543183, 0.08805896470984144, 0.039966619318170894, 0.02236681603526156, 0.028897857316018596, 0.023530610844553, 0.02770399930135858, 0.047488966881628, 0.04160899308419997, 0.014353016365109193, 0.016399983188978607, 0.04275954606372022, 0.045321577739331036, 0.02481335804106728, 0.03473936392354869, 0.020173209448975903, 0.04702729931581886, 0.06071244118615024, 0.008739284934445975, 0.1277239177556288, 0.03234214074308834, 0.01836717440446298, 0.025840099720704942, 0.026763511461115656, 0.054344737511729045, 0.06357941032958127, 0.045771884221223094, 0.08422916094141622, 0.03895398514765886, 0.027348793059166883, 0.019858950606336998, 0.034680800332177075, 0.016342972840873465, 0.03729851127812459, 0.10015483419861525, 0.02615150105538628, 0.05067299300384137, 0.01656550989155808, 0.02817946028024439, 0.15613094062334107, 0.02405285872819443, 0.008005928116730385, 0.008571707031449244, 0.037909301688834544, 0.030113958693560094, 0.036679404982996565, 0.04198326150916758, 0.00272513275230003, 0.010620489483699204, 0.08399336673920194, 0.01858702440175318, 0.09936979325908808, 0.08552607118843064, 0.02122244155485063, 0.02392947835276925, 0.030758244383539406, 0.03617308598252074, 0.023461528865981008, 0.03503327738613852, 0.058725419784745866, 0.031296951666234, 0.009665368406492616, 0.036375428955521316, 0.06306877442365212, 0.028479002573857867, 0.08267791716441994, 0.046790409607872854, 0.08551046597741305, 0.0650089418876075, 0.04573788523914353, 0.02302697123659234, 0.008524311086793822, 0.03637088605413034, 0.01884939802450038, 0.03040101183878799, 0.038828599537091876, 0.007372856517547682, 0.03160202511466079, 0.06036685892350732, 0.09376608991935369, 0.06285878972360684, 0.06503179429038879, 0.05214520332012927, 0.04145205997291111, 0.035432164046552875, 0.030317044771847226, 0.03333204125444735, 0.05613224663501305, 0.061702425967180924, 0.10543409164153761, 0.022965465867591482, 0.04120115468639039, 0.053795724431233066, 0.025561090498681993, 0.04661161234722503, 0.1045214357755838, 0.04111364446279984, 0.09638560500236289, 0.013281922025095313, 0.01950810340443446, 0.006931320784778725, 0.07334277574573794, 0.028790790782940966, 0.02879126384223421, 0.06926565581271726, 0.022760703971969987, 0.034557379737135865, 0.11663681752378903, 0.031445980665364096, 0.05802066485968329, 0.05211273268345864, 0.020870134955452337, 0.026150643036911086, 0.038384314506284656, 0.038772717253455234, 0.048935609013443036, 0.04965682333755878, 0.07179521685165745, 0.0381290540099144, 0.013068783915631715, 0.0954473234953419, 0.052966966684306824, 0.013499622188148, 0.09290673079029207, 0.023827199869218375, 0.06109802856019909, 0.05571765900259057, 0.04278139872176032, 0.11011374738788414, 0.01269927959994323, 0.04783567529351962, 0.03721203527323181, 0.1084387344458411, 0.012462335308232616, 0.050119781761520335, 0.09143567343633022, 0.018671732658760685, 0.031160572693953593, 0.01831729058927346, 0.025650584889996438, 0.05206411291334418, 0.060294030774985595, 0.05732025365315138, 0.03331163650258415, 0.02156738987973621, 0.06459097197699933, 0.011665458310275309, 0.02518793673164422, 0.12207660103036512, 0.052688145153825326, 0.06245547890542977, 0.04740904475892744, 0.042570153807079604, 0.0546127955068744, 0.01581744131286659, 0.03644239270098267, 0.00830787018076667, 0.023445165227918376, 0.03028631698520434, 0.07154625359802477, 0.06468913848361661, 0.013525904749610252, 0.05755766813132552, 0.040647035629879084, 0.05512185710211916, 0.11032701094424534, 0.02093083018647327, 0.04391678699081944, 0.05297263190450688, 0.07269428997871376, 0.025512361561038324, 0.06607902116112171, 0.05637111284980371, 0.05346250682768803, 0.03444294152300685, 0.07141621017287816, 0.03486892854374263, 0.05939390810747301, 0.07121140422720103, 0.058931742584513086, 0.018694163713183616, 0.013848075365287163, 0.02306409585740297, 0.07756792684836734, 0.016667321061475143, 0.07868944892599698, 0.08012630045413971, 0.024856910139562625, 0.05922374465773183, 0.07345811794361762, 0.05469732564843951, 0.030013928678066983, 0.024713163316670447, 0.03438413661393908, 0.06881308937144857, 0.07579182094383626, 0.06915424364588915, 0.05435475794177863, 0.09356928959248528, 0.028989165420493776, 0.023083029720451564, 0.09634764534571479, 0.013175745111619754, 0.08236321590600476, 0.04083168963270803, 0.04207007459274704, 0.035409319304650834, 0.03186695555585527, 0.0827732491457174, 0.028151467427491184, 0.06394565398354204, 0.020452151638305476, 0.0537142624718047, 0.06062021186094611, 0.09113902887029034, 0.11895068650764805, 0.06875306638258119, 0.04297498147934676, 0.03516455421284322, 0.036721083996517044, 0.027435843630002874, 0.021040298405193517, 0.03602092559900015, 0.011828699198010708, 0.030856115946305857, 0.05610325020707904, 0.051040895238158204, 0.08690853047394946, 0.027043539580077897, 0.014498231203986273, 0.026966641589458433, 0.023238112729403283, 0.0410987823570688, 0.019107778413942265, 0.055415904630095734, 0.06150579801009548, 0.06274449706618344, 0.05315061328151534, 0.001718263632820679, 0.03044966225241942, 0.04490797836033087, 0.00676475172381728, 0.01792405574252048, 0.04079042047622704, 0.04306665539080578, 0.04257951540151431, 0.07651186698386747, 0.002337800613003633, 0.0741874642910496, 0.04317637450332123, 0.06631309932638561, 0.008887371645429203, 0.03015190302844971, 0.07327268636154552, 0.030001864708479375, 0.0518285523679468, 0.04095903259792155, 0.004623454578611399, 0.024110309576856035, 0.08532612224019344, 0.010074315716572588, 0.05809769500046969, 0.038944880192678784, 0.022299298791274912, 0.043362491734085545, 0.04140850787441577, 0.01028111732129248, 0.02981917189073659, 0.06477066556051855, 0.10649979655300418, 0.08501129074683113, 0.1696845988232282, 0.21568500707226418, 0.1398433904133497, 0.10381266654979798, 0.08004904814785527, 0.11850917471512673, 0.15396249811014823, 0.1272976204692837, 0.14307215990078065, 0.1413593405196744, 0.16945561514266078, 0.09252858979086723, 0.278419150460151, 0.127374206279074, 0.20270056752187593, 0.14154124043641553, 0.19092737426680906, 0.09335502246094328, 0.15536106822471465, 0.14509758912026882, 0.15488370351733702, 0.15145875423425628, 0.13075944156416003, 0.16884599301603534, 0.11612894719526654, 0.2260445229588978, 0.12456896083970224, 0.08392959758038483, 0.11926401646867876, 0.09248301522025178, 0.15074970921681774, 0.18355595368531444, 0.11148217960350937, 0.32257921633220493, 0.16635323484097758, 0.219069920600422, 0.15748296323562824, 0.19054730272581502, 0.11167675061451812, 0.13814569360786869, 0.13916221567459647, 0.09781962966606503, 0.08785654895848806, 0.15279404548627717, 0.1554233358512002, 0.11330575231582889, 0.14790179268006357, 0.10763995754983156, 0.1715361414056632, 0.1983587795327748, 0.11044206968959301, 0.1660054768886297, 0.14606751771944185, 0.34597440772960264, 0.20623204899170708, 0.16351910788686047, 0.11385035656032064, 0.0991553882317197, 0.16651072719645116, 0.08939529784143933, 0.1641368045802078, 0.09866867725166584, 0.09469118705319782, 0.09562561513795968, 0.22385231639829375, 0.15654056783645384, 0.08561920449738541, 0.24800555179676703, 0.11066595888546399, 0.22632045250746513, 0.22754898174635826, 0.14388677183418505, 0.2514342549106767, 0.16345584434607338, 0.09413807923274656, 0.07140028320493237, 0.17116405250084016, 0.1660066566640331, 0.15109955092831967, 0.09087406970079868, 0.12739572568886703, 0.10725783289320047, 0.2078714618279088, 0.1876178897556759, 0.12826506694358203, 0.16898744349037448, 0.11461120444319903, 0.11987779845273304, 0.1408996571215891, 0.12557926227248487, 0.14680280890916625, 0.1527779423181088, 0.1277150771009826, 0.10640060348856835, 0.10710920417501081, 0.16249742238752304, 0.12864194389793182, 0.09793448156767315, 0.2392648256594135, 0.19059670007517263, 0.21119321906758895, 0.13262316494459106, 0.1936348975305596, 0.2297514079198722, 0.12940836890089896, 0.18114913525360246, 0.20321807523648586, 0.1624574325978756, 0.23427437570306564, 0.16103037933428443, 0.07969603483234683, 0.17170438963559367, 0.10056938735708114, 0.22238153483598466, 0.11887546433436295, 0.27652461502340536, 0.18818317071324397, 0.15714196217877252, 0.12162434102426614, 0.134951229537687, 0.2967617468487832, 0.12268473694641745, 0.27524288863905017, 0.10269809288964157, 0.10907909201998865, 0.06798796671172304, 0.11357258073985578, 0.2186341238238158, 0.06813935334644011, 0.11908465230296697, 0.12214102136391787, 0.14725426452294474, 0.20415054213616157, 0.1372849785031811, 0.08221972763778702, 0.16842081421805968, 0.12197710919163882, 0.15777134937384438, 0.10028467844090155, 0.11848629932970771, 0.1953684625726554, 0.10308932633169236, 0.1577819673524749, 0.10159681851585066, 0.13166572357858383, 0.11299234574600575, 0.17940754161006023, 0.11498848742414867, 0.14719573540552972, 0.11253756531063588, 0.11813667978370383, 0.13434266461239708, 0.13464485565500875, 0.13563235831116477, 0.19188924362101864, 0.14004877858584927, 0.14936420856223953, 0.11807919254586582, 0.1673114729384261, 0.10350305977607928, 0.18077117811527946, 0.1599968807591546, 0.07850907352422515, 0.17659717870335426, 0.15938961818333597, 0.10371315938931319, 0.19327266051644282, 0.19293372789698263, 0.14278633249623163, 0.14868127182126045, 0.19683473953796973, 0.20157343768064054, 0.14766378448374812, 0.2008577889852947, 0.20401407123333026], [0.031686367564684445, 0.03465516319979103, 0.03998533867660069, 0.026133997861536282, 0.10671362701442935, 0.04683697626235024, 0.003413956878977197, 0.00805990188382566, 0.03457871528582708, 0.023450039462336612, 0.07742702795733368, 0.06090001781441032, 0.025410069670948773, 0.03216164659768824, 0.07899240605653295, 0.01534979155797872, 0.03911363021019967, 0.040346334628280134, 0.028726954591430487, 0.022867241904379863, 0.14477796191650052, 0.03663521320108445, 0.06204660628892242, 0.11420056599402621, 0.04753992321991152, 0.06647911824045644, 0.021702497146062313, 0.017708666292169405, 0.06728032363518592, 0.018011914536116586, 0.037863328752498475, 0.05861775761830711, 0.038736561733868816, 0.016373694881856922, 0.02827650638327243, 0.025961545724121314, 0.08683758307128184, 0.08041645625546094, 0.03340424887175041, 0.020101486382284955, 0.011197700345468138, 0.06116052984350151, 0.058666189696880124, 0.038690627101928964, 0.051974787061373075, 0.022242606369658344, 0.012740778582801503, 0.09859591422061767, 0.03891172007687631, 0.04993811933203571, 0.013406449617187103, 0.07501840921899966, 0.01602597140346564, 0.027749464704444813, 0.03712034220957468, 0.023237432826370485, 0.019087132344382907, 0.04377887201225085, 0.04881046855101182, 0.0586616927607646, 0.059965329259754195, 0.04941812183167185, 0.013366492386276444, 0.053846558195448695, 0.054327906560032606, 0.08163833585117133, 0.01664409902127039, 0.04445473010080957, 0.025869247451004003, 0.04359482321888209, 0.039738275321020235, 0.010797021039310965, 0.04156481662404634, 0.03143106493347835, 0.04718971761664556, 0.08591087715279672, 0.028695380277631265, 0.02997352328572062, 0.0841309178260065, 0.024375479420526855, 0.0450616134631057, 0.016623552543141188, 0.04134028008387935, 0.012723898792999887, 0.06059134566795923, 0.026357415913333817, 0.006474378545047536, 0.022563608701250727, 0.02560434765332649, 0.035907854851815975, 0.007231221224496803, 0.0605418372358526, 0.02490327378074008, 0.037611822086957195, 0.06073544297607676, 0.06346187328979855, 0.07979626211548045, 0.07908472731228798, 0.021792698253486908, 0.03495757257746112, 0.0053471012318867354, 0.04740154092770912, 0.07852008986857631, 0.031191838657363292, 0.09637425157932505, 0.030076726820440065, 0.045850266507195855, 0.04978605470950565, 0.07339495399426069, 0.049551516891487186, 0.035276828228586146, 0.09429171050508177, 0.0513421056882268, 0.05766927948101394, 0.04232661445595084, 0.013939246531545877, 0.02131713768317094, 0.056629859046229435, 0.05907421578623115, 0.05022829045511542, 0.04643321345229784, 0.04042603075504303, 0.009088892031521087, 0.05326176880888882, 0.0715671601374784, 0.038247901060047655, 0.015614592721835982, 0.10112211213357027, 0.06865716749621976, 0.03720919691747235, 0.051246969059350035, 0.0400091793328043, 0.08154015402279555, 0.06443345663888801, 0.04068811709481863, 0.01666962698612723, 0.04110837760832041, 0.06172043669428076, 0.04650277806626213, 0.017717679316598563, 0.03097010025333974, 0.06790525985941773, 0.03259621380317596, 0.06017001263136345, 0.10277198206993843, 0.02637039152755132, 0.01688190994994535, 0.05461933023686852, 0.010006860717229787, 0.03828069345364648, 0.003565020320351206, 0.06140519534387897, 0.02777761843566212, 0.09026370446888671, 0.027880925392251343, 0.01857046732648967, 0.043951460130272374, 0.05249931214136943, 0.06840142436445722, 0.08468730450277367, 0.03536829912674523, 0.05269039362188309, 0.041770480588198676, 0.036926483660335505, 0.045404652313840006, 0.0895456119530624, 0.04771934867265725, 0.05864692641602409, 0.0321020238897613, 0.06468325492835815, 0.03280568139387235, 0.04572280862879369, 0.018419436922657396, 0.09389343671500684, 0.04710634426784612, 0.02846455224038613, 0.07390627171844244, 0.06301150935131215, 0.051203769361299854, 0.046464695835546146, 0.08774320625009076, 0.039609461466992096, 0.07526177236990583, 0.057652739642728726, 0.03295589591406527, 0.0348582377867593, 0.006056637982011683, 0.04604468813105937, 0.04803036121771701, 0.02898954080357667, 0.0401089393023041, 0.05006698681221855, 0.023041095982696262, 0.05872317514712772, 0.03404222391245346, 0.025812851888458097, 0.05563862171144255, 0.021255120950480624, 0.0967584446733517, 0.07129119228451483, 0.035429999848166784, 0.015509198175653096, 0.030400623049166416, 0.01229736593461806, 0.06042287144209109, 0.018800626952020873, 0.02790669467480433, 0.05025866967175276, 0.05414042569276306, 0.04355006836234562, 0.02701991725893271, 0.02088590870581327, 0.024904959174173496, 0.07903569768513403, 0.06420847576772494, 0.017562644188142112, 0.040835753729146336, 0.1339283489411877, 0.06851398566317174, 0.06337381531334212, 0.03754198934221941, 0.04536342529219486, 0.01238559053519801, 0.024215501109738986, 0.017695388073221813, 0.07230412139887772, 0.02982547870957323, 0.01682532669585799, 0.0935090674207576, 0.04121791285973403, 0.052512653562570774, 0.049089209642261274, 0.02954767416081121, 0.050296901289613984, 0.03241433303863291, 0.029924501319445913, 0.031445540164807634, 0.06589873768990079, 0.039907507973933415, 0.01599350268201482, 0.0533118594678179, 0.0776159912047367, 0.04164622878775962, 0.0626175792797679, 0.02198709880993251, 0.08148012337304893, 0.04438816855150846, 0.0796382564810976, 0.05721549879038527, 0.02533587980114164, 0.01643162070503158, 0.02570986477357726, 0.011909182480115806, 0.06727150596317745, 0.12504562840706882, 0.019243029321754174, 0.08951758079591299, 0.03959944103694251, 0.01829131829342054, 0.022228927869770317, 0.045340806546230475, 0.02683317949694972, 0.01190129081688581, 0.022915963181144288, 0.01642517215992895, 0.02217794471840945, 0.00679344650463111, 0.039870551892466126, 0.042706356579137426, 0.025854902454621853, 0.04058197561290957, 0.008390272513122089, 0.07534473203122616, 0.05695029447275785, 0.0305755841245334, 0.016010547180720154, 0.04052846437139858, 0.024311459367914547, 0.056428615409400196, 0.025284894734560966, 0.06707457540136191, 0.04509239487590329, 0.026786953751598636, 0.03980043952563598, 0.030494407532856833, 0.033679419993272716, 0.03829790361886544, 0.02246746658197334, 0.008423632769394786, 0.011497145920481172, 0.04404237178424674, 0.016125216178836364, 0.02747494284243834, 0.056644518138660546, 0.0367589287399765, 0.05140817694125637, 0.008168944923747933, 0.08269314699235462, 0.04073004125647488, 0.04938188204241376, 0.05056089901876065, 0.026555631587642337, 0.08408524366396089, 0.0955859930705159, 0.005026889886076172, 0.03742592702169092, 0.02391863054776144, 0.052507003664129206, 0.03646415725891148, 0.016713575535123388, 0.008483767798621087, 0.039918432387733654, 0.004274194615126978, 0.05109085949257978, 0.020907359167693124, 0.007134457137585888, 0.02748776140863136, 0.03349214213930311, 0.04350390007358886, 0.054302974228536895, 0.03853726779080687, 0.07291689980775118, 0.06412764200039449, 0.022543309286477107, 0.014899401764024892, 0.045630793808208364, 0.043536117901244474, 0.04127497874921368, 0.03165128648341183, 0.04759647966092152, 0.03897267386257168, 0.043124931699205796, 0.08611332354766708, 0.009492023776645863, 0.018020274470590295, 0.03012732501261898, 0.029524161007195234, 0.015545280916886705, 0.026192559537688093, 0.029667917406186465, 0.06091140571140474, 0.00938157209255282, 0.03783153610364084, 0.07448534991952681, 0.003790118738130156, 0.028550549440326232, 0.019148553443712094, 0.035000029170224746, 0.04602071723990864, 0.03439774616591392, 0.03292020770811266, 0.04335927033436395, 0.13148455910624998, 0.17192770426552142, 0.13527833375959628, 0.10934480961652533, 0.2249637414370814, 0.1338928177832596, 0.10991946749028661, 0.1197371370489559, 0.1428016848982342, 0.0626967046710272, 0.11710866639811186, 0.14975129746861998, 0.11232911278643917, 0.13510204160646086, 0.14422719066421832, 0.11231647999656778, 0.0769144385271976, 0.15642372410624258, 0.15672686509788036, 0.13673644422763778, 0.1910988400660215, 0.2399035591271616, 0.2958013177398713, 0.30858968474691917, 0.1821042630340784, 0.11942927695570454, 0.13096916579431103, 0.13464847159001136, 0.13634285889565945, 0.11407654401996445, 0.1386792278818546, 0.16554908766861887, 0.16895318403840068, 0.17596969140633462, 0.14000334957193944, 0.1678283831044551, 0.1221996577336423, 0.1830084306458312, 0.2148039293505492, 0.2180829082405375, 0.24685954554907738, 0.2714461568863161, 0.16717186107510523, 0.10958942915162734, 0.16735129418873018, 0.26210907726518573, 0.09369997653148829, 0.1530033407071906, 0.1319171229918157, 0.1338855705914959, 0.16045743749747354, 0.1036969796123524, 0.2296397276222706, 0.10071872087616114, 0.22938763872990686, 0.14198558675425668, 0.12360668545889279, 0.11688011172678202, 0.13839474879205227, 0.1234832150681365, 0.13385805271325574, 0.12445713498539503, 0.1647541335513515, 0.15424113960996752, 0.1554726106264899, 0.2060089795099151, 0.16349869930455763, 0.1426491108272345, 0.12006579642935146, 0.15776024109894232, 0.16692970068224017, 0.18701526967267837, 0.20782445467287497, 0.10850418899809161, 0.3013429219924635, 0.15945770807804602, 0.16454722852476183, 0.14742713992393788, 0.2640685769579103, 0.14197487684507526, 0.1697023720630715, 0.17488818976186937, 0.10799229670796665, 0.19616853415725694, 0.19083656220426484, 0.11222500143752945, 0.08187042984871135, 0.12330865427370995, 0.11623871227305745, 0.10655218164526647, 0.0911892612554854, 0.114296886228746, 0.12829160422927913, 0.08945176618233805, 0.13306938051696748, 0.08776196008247715, 0.13131479402222943, 0.23122634167873093, 0.11853661598457445, 0.1547918189316988, 0.07404360830062821, 0.21774863343565695, 0.15220887688619478, 0.11920649858732378, 0.2179596140500038, 0.1640744143796544, 0.12269213735576599, 0.09722099324027378, 0.13122870106129877, 0.15483576173503555, 0.11964380455714081, 0.2484543873898445, 0.17898524330267984, 0.1178572798568395, 0.08915762672381056, 0.06670246351390116, 0.13785271094210688, 0.18108674505304906, 0.11792551530825517, 0.1284477712526437, 0.10987812938589243, 0.1742020507733668, 0.14892073558463206, 0.1933297187450432, 0.158555930660617, 0.09127874032504137, 0.147602665989149, 0.19700856488798896, 0.1812835836843137, 0.12588929039456193, 0.1252153858302101, 0.10760579768928791, 0.1549754961724243, 0.13720668431731964, 0.15006450485558281, 0.086360149415991, 0.08798132935959486, 0.20031343754981795, 0.15459798336509736, 0.11528107938506912, 0.13248327728961745, 0.12837028911998197, 0.17885065697614225, 0.15455370348307396, 0.24496246670042318, 0.16791511957924213, 0.1494603066314613, 0.23838626070609018, 0.1353427464322698, 0.08974469522194517, 0.11599685831536209, 0.1842732724523352, 0.17914409929465863, 0.21369238173769367, 0.14178972871553513, 0.1802883895053979, 0.19351641437219036, 0.2545042909801968, 0.1532117779096288, 0.14382438163363165, 0.09079624282857103, 0.16402471059512708, 0.12482711714842629, 0.13221946725201222, 0.14977552116878573, 0.14731182836957518, 0.18403102012891925, 0.2076058131792853, 0.08449146178581061, 0.17690457914385105, 0.1974638969066643, 0.13242286359590869, 0.14346888619324855, 0.17079067656830435, 0.13324777175101543, 0.08337931662437417], [0.05139926350825737, 0.030956622851531834, 0.03065637384180821, 0.0036956814038867675, 0.0638821644468173, 0.03682021960435856, 0.10093651201215484, 0.06615768306918683, 0.0513693439443746, 0.035603821367746404, 0.0913211815960465, 0.09865751535060907, 0.031203105895509644, 0.09878939738677395, 0.015710322111244165, 0.027763740752913782, 0.05821992815922826, 0.044833131570128665, 0.03355655864241623, 0.03836485970344755, 0.04413561617595054, 0.07414270943451313, 0.09695528330461634, 0.043248283346333814, 0.034405184879658685, 0.031987424797168186, 0.015047542101162818, 0.04232248907247859, 0.06899513484489533, 0.02913924204486032, 0.07158044410208542, 0.008502762948703623, 0.031229309932959658, 0.021754663903266195, 0.04010316299935503, 0.05061880377451739, 0.037233792170281374, 0.043956811254423474, 0.042709049378191276, 0.07494230604460163, 0.0514382305705259, 0.06889623289387073, 0.05390960723161698, 0.02217195582606139, 0.045717966953112234, 0.0609342159793502, 0.04242542064598492, 0.020604388630618493, 0.0609363457037797, 0.09762482116779975, 0.009248178947957294, 0.04608027674558182, 0.05722897427697336, 0.07444287034412546, 0.038566551501712495, 0.0858595262792322, 0.04366811868103762, 0.03616658955692284, 0.03169035888276994, 0.047473300383576465, 0.08853766241020734, 0.043428007573370016, 0.039368101636007916, 0.03849964904328508, 0.0502254942341918, 0.03885994019407419, 0.03896420093012914, 0.04700221759717792, 0.006537147959123456, 0.025251815057990533, 0.05986689845280302, 0.07269522460598139, 0.043747385798562924, 0.03576296081225719, 0.04992434890159676, 0.04517746127901539, 0.03532550162485531, 0.03178093728849725, 0.04703829650797191, 0.056561167772498824, 0.029301507128102165, 0.010579012525868754, 0.05736896152337713, 0.028069597526243138, 0.00400170001329013, 0.016514007715628515, 0.022823609366652467, 0.05305664876716272, 0.028292776175564336, 0.02238085076603438, 0.02026513999988956, 0.024548056047229518, 0.03649041875295582, 0.06620922546473242, 0.07273089365973588, 0.03275559839582251, 0.031016134476709752, 0.053071637277401267, 0.02409142359430271, 0.08122386696237711, 0.021764657520238432, 0.013390946870429382, 0.061929057757820816, 0.018687964146656376, 0.04380883371096946, 0.016983338075900273, 0.036851418535074884, 0.014133858719780562, 0.030943241210714467, 0.04249008612767343, 0.010351851176951202, 0.10577806511953955, 0.03984170102123772, 0.03018514741392386, 0.05082149531752352, 0.07075374330123586, 0.0227213500352997, 0.06413771605659878, 0.052645634934907, 0.012414278612742502, 0.01660864447213469, 0.03899170348661081, 0.033677477960384665, 0.010590440642479207, 0.028834844669026714, 0.034323784207264264, 0.020572170802962877, 0.04182267032804028, 0.05974819695937538, 0.016425026603223338, 0.06160170455733615, 0.010541310466285194, 0.021889187027550033, 0.041861798268772905, 0.01879228808496508, 0.06318896212765286, 0.05760074525530781, 0.0826929095050981, 0.08353179876482295, 0.045358265690024824, 0.025481742941924644, 0.03467585140418622, 0.01598630049791668, 0.024098737818759777, 0.018200134678233056, 0.021595723641615723, 0.041423025240580884, 0.04525814565920061, 0.03201811427941486, 0.012582654204790392, 0.04796994752400825, 0.04440565067794054, 0.05010801465100339, 0.048988679754397566, 0.0385132547648203, 0.0380665029308969, 0.04001364179496323, 0.0200504515199892, 0.0795786395188301, 0.04577954127002628, 0.06698002482974721, 0.04216271760543028, 0.0505379623463077, 0.017017070842426152, 0.0025832791241907306, 0.017319738774770693, 0.007379856645955795, 0.02529894095665265, 0.0454829694823392, 0.08848025178116176, 0.04274590586822841, 0.05123758831271722, 0.061835437983034126, 0.02581611350779572, 0.01690046459947142, 0.03218317749880014, 0.019341950424976887, 0.03591648483228299, 0.031760176305749246, 0.020868189092124664, 0.025989429409345313, 0.020125533882228118, 0.03979128477494082, 0.03297681777527736, 0.096379897647327, 0.0045778081872530525, 0.02980229305854488, 0.06559853847589224, 0.02893742575730768, 0.0181337799726715, 0.041422714974971554, 0.061149448381676796, 0.04758491173326489, 0.0344442208898404, 0.06132965141366567, 0.036145525969444744, 0.0629143885547115, 0.0019322566485272781, 0.0240526384779162, 0.03294729274667559, 0.053459890637426614, 0.019493017217985565, 0.05681776892273657, 0.09615980824756046, 0.04070256934351018, 0.03640098947911494, 0.07709191045573643, 0.04409894737745485, 0.07201748194112893, 0.02436616762180723, 0.022481081879607612, 0.02052016300900329, 0.025009032218687, 0.037466525851238164, 0.03386462174896752, 0.050063650499308304, 0.06941976205956552, 0.07583227804711751, 0.025502800783743302, 0.08210219442844391, 0.044719179821831566, 0.03500419285809321, 0.015269952747339924, 0.04910003829507097, 0.057608724061039195, 0.111290397152545, 0.03626344605318962, 0.042617157131673834, 0.031070325621253544, 0.04098576523603932, 0.06153928371326578, 0.049500713770788525, 0.039833572828361107, 0.029612280270685593, 0.026433814031582688, 0.031226136413733327, 0.06497652104665196, 0.05190796887261733, 0.0801569899363864, 0.006089418884291644, 0.05962170052131819, 0.03602431936850471, 0.025663631367346933, 0.03494508534429535, 0.05796605811244058, 0.03337877644826809, 0.08170388999485201, 0.06465900058467543, 0.05198958021919093, 0.06952701436896479, 0.04869522211412269, 0.04926401175438397, 0.038892744078991875, 0.04478555367959123, 0.046460566621634274, 0.036643555898579865, 0.014726314731242677, 0.03716250768892708, 0.018551227028271364, 0.01550213676021104, 0.0397746185321481, 0.03445347523196571, 0.03819809002321094, 0.030947443202979145, 0.012744118726151365, 0.032127555685057756, 0.036769489262012706, 0.08507716664744001, 0.03591036378976799, 0.08817852039130465, 0.047285244950363715, 0.03139778798926742, 0.011310190781049672, 0.05747656623322157, 0.04623571215497871, 0.052374378522677775, 0.05031629480541714, 0.04616718559015182, 0.020899635086196567, 0.019499546202320247, 0.02853582139998194, 0.08654711317391166, 0.015240050420435447, 0.03878438860298165, 0.024896325363266854, 0.03657842693369716, 0.04106487913597976, 0.13386559101843065, 0.04227695663669898, 0.02685530220098313, 0.015073912762736362, 0.07162147577130987, 0.01845668603275572, 0.10040667028196397, 0.04710571224530859, 0.06195912670884883, 0.01936154120842055, 0.019812069855810657, 0.06604567335377778, 0.018288905116459055, 0.017741330366040912, 0.025886327381275838, 0.023672689510990056, 0.044681227826062715, 0.048907685108603015, 0.04943065119967346, 0.021585080765127655, 0.018574224987758264, 0.034207212438266126, 0.018860004511812044, 0.048896209111497294, 0.036079611764439655, 0.012535236235107146, 0.019817610586723013, 0.04807195596156582, 0.020879555921701175, 0.06085422107829683, 0.03740309760154736, 0.02137780801633433, 0.012991165802363428, 0.08720587218000043, 0.027218757294899514, 0.07485221410470624, 0.01761644462784452, 0.029688969502345692, 0.03800453407870185, 0.06328940391540527, 0.02761264140116832, 0.08399326714777178, 0.046066249675688245, 0.059363187981709364, 0.036616677703756484, 0.027863960375168154, 0.04237773550313808, 0.03642408703003199, 0.01922431762420362, 0.11107542522011266, 0.03811452515243042, 0.01862902708742167, 0.03511045691407016, 0.024319380717051607, 0.011000919170797834, 0.035040957417579434, 0.03373684211363716, 0.034558103690224315, 0.006315654703235675, 0.03864844247037846, 0.046883803386721885, 0.06316997846888919, 0.038310973078853665, 0.02451249807622404, 0.02555261565101964, 0.11451619421882976, 0.12017498694119916, 0.24997369296127753, 0.0867021463871483, 0.1431304438700599, 0.14292442750546241, 0.2495365325481661, 0.14294788511770387, 0.18639896725935323, 0.16975471119005836, 0.2186633883825233, 0.19140666951575588, 0.2308698962893217, 0.19219610779996843, 0.1705601300683714, 0.12742393304623906, 0.15280663997175234, 0.1873191154652065, 0.10702907137813107, 0.17640962505773192, 0.11739253261757475, 0.10594964583194065, 0.2016477788528127, 0.09558751758548523, 0.1160121800738477, 0.09130796657935267, 0.16898938935370217, 0.1456225278877443, 0.08928101284489517, 0.14870309000534399, 0.23579326758701957, 0.10536237815094572, 0.12663273275980066, 0.10339392289038628, 0.21124166646792045, 0.1326432517699657, 0.12628151975091428, 0.14561459121684875, 0.09517214471294035, 0.18628022363108976, 0.17219601890012143, 0.12969139242364516, 0.18893415138365763, 0.15803676819609058, 0.21139345912923738, 0.15648193146672942, 0.21207680955769556, 0.15135870315134525, 0.13437929893693618, 0.2296664487690695, 0.1056254833876606, 0.1553103378823688, 0.21732523196166564, 0.17912310848553337, 0.11153435019115288, 0.2402583344448959, 0.1891727724503125, 0.12190642991974471, 0.15331291683739232, 0.13085108100166246, 0.22243223453481353, 0.1633513805967185, 0.18647294070932174, 0.1427534213590045, 0.22379579443124034, 0.13750689885308667, 0.10656272301510458, 0.15260345813247467, 0.1838077054989915, 0.09344882226639217, 0.12110238999969537, 0.23829866621282794, 0.10753103516875737, 0.14599797225767566, 0.10438361655800574, 0.22640850665348194, 0.12138084763841284, 0.14092625569432013, 0.3058259459512849, 0.12582392011198307, 0.1310518266813409, 0.10892542244325723, 0.14583410605067207, 0.07294097029033207, 0.11812790807697082, 0.07398491830474908, 0.0966926530424145, 0.23403504983552043, 0.10967782803721006, 0.15429308037123374, 0.16638426140191095, 0.21586584978766982, 0.12813002862516912, 0.14007848747555288, 0.21651658019231212, 0.13353597402812975, 0.090449710616902, 0.1658332296797345, 0.2850324504317776, 0.16554040023155753, 0.10920311399405042, 0.1310659993079401, 0.22333721419976604, 0.06647871221385657, 0.18054294520087782, 0.11774529312406817, 0.19536136859847655, 0.1847146157055132, 0.07470962982023917, 0.10439765128877856, 0.17223508938425974, 0.18546633182033417, 0.11957419014746144, 0.12948549863311554, 0.1844212040305138, 0.13547383939787266, 0.22298334286578242, 0.14628183847713858, 0.17529706620881635, 0.14434512223928206, 0.18071068781277827, 0.054842476327452934, 0.15815054757460473, 0.12864900722859368, 0.13115578481266577, 0.13211158675051507, 0.10644799368756433, 0.13287821093634253, 0.1790086089843704, 0.13136593805205438, 0.21177440401046507, 0.11334943464927136, 0.16750618184526123, 0.17414008958205102, 0.11089912540609799, 0.20667487845545818, 0.16545956263378744, 0.10793225073646154, 0.13408527439159734, 0.1445864552571889, 0.22311898639365552, 0.17767351691520986, 0.14269017313997592, 0.10106919077976097, 0.1866732573797626, 0.14217389116604484, 0.1356115666848998, 0.16057354578327748, 0.063735818670642, 0.21452055342735785, 0.21732826566984578, 0.11278216186310015, 0.13260189834381306, 0.1738161263206313, 0.1739716728127772, 0.11229598714459328, 0.12512273515664762, 0.11874735145078552, 0.1879407958157601, 0.09164856160960852, 0.22764124937595862, 0.07889136672019958, 0.24284359007593126, 0.12073554879715367, 0.09497232599965028, 0.11797960111570936, 0.12253027829912402, 0.11672855655272162, 0.10839443158117995, 0.16388048688250204, 0.169884976780703, 0.11571116880663943, 0.1282272605045188, 0.12157131241814745, 0.14167389622138393, 0.13033381843518826], [0.014586583166683634, 0.02231729228139645, 0.01919700084404359, 0.01159197228374861, 0.02833039492308613, 0.03937786542660287, 0.01532851346588183, 0.0777835805990523, 0.022782005046704606, 0.03933026838386732, 0.009097614900148925, 0.04478897426217314, 0.007642314059569711, 0.028088738233031287, 0.04738433842336939, 0.023783260896321268, 0.039468302106064175, 0.027943424760333957, 0.08350837179609845, 0.014187812377067824, 0.054805474280710184, 0.0925134442326042, 0.052118700508388786, 0.03649004720031254, 0.033543144442862084, 0.08697003967338994, 0.04522520004801693, 0.016948492566664374, 0.03959139328329794, 0.04133240086957812, 0.032344603715764905, 0.04368302675204412, 0.049589890235614394, 0.038593705488188614, 0.05622700788080693, 0.018759390354276668, 0.05721384404046882, 0.02277417179767884, 0.02360298891641921, 0.019636580179775917, 0.0821653507169216, 0.13597225620140954, 0.04259251208314973, 0.04288351058118767, 0.046920866720498576, 0.043499632963850614, 0.023519470010914152, 0.08659789714241221, 0.02570595389472381, 0.009406522618636731, 0.023503786275884318, 0.02634190454808695, 0.04458190835711937, 0.007260247817142837, 0.04302960354834796, 0.007933039159979671, 0.01321562669134789, 0.043878643473069516, 0.06994613341145939, 0.07927554449246776, 0.04360862812327762, 0.03914924180735985, 0.041951625908334414, 0.06282050447959094, 0.010956778142210698, 0.08218735276210694, 0.05832383649483804, 0.011519125940638685, 0.06427782587707043, 0.01720121922722507, 0.05586179461510432, 0.0322339806194988, 0.02619377570226789, 0.011385426360873446, 0.04556067761093859, 0.14306661342420887, 0.021929891194186864, 0.0901433980212577, 0.04933482892210445, 0.0704261564439343, 0.0613286554993641, 0.03969100003521289, 0.09409363081137981, 0.039516665236724, 0.11066127042736738, 0.02020425707732718, 0.02912906073634663, 0.03796519929422967, 0.08268711788039054, 0.033892461384135875, 0.025994265339367335, 0.053662697093621384, 0.011251046878075408, 0.07980844291347651, 0.11091509833931924, 0.055492789214176524, 0.039967576928076246, 0.05063266996594687, 0.03853921365413455, 0.016275650949307507, 0.03996883714271169, 0.042838391832887165, 0.06749923325954907, 0.03713388664407596, 0.07894247244562834, 0.03447296067831978, 0.09595605950321882, 0.034460676458453944, 0.022689570792980736, 0.05078855353677946, 0.09118421273606439, 0.014367183246048949, 0.02743875859455476, 0.022127993870526556, 0.09963958644338193, 0.003243195401850127, 0.008789933879949875, 0.04511636959749364, 0.04156433398865404, 0.05317941818746829, 0.014625452552741815, 0.026383815303204522, 0.0484457187685034, 0.05494944135388059, 0.03783515969952268, 0.028713816183529077, 0.02472106359838959, 0.04540145772719576, 0.022513364824736794, 0.03189476837794627, 0.00993495378943701, 0.04753738363844253, 0.027215756145456148, 0.04168335723900988, 0.029845649804619533, 0.07897981157105777, 0.08774939624051895, 0.043137752180618626, 0.055301140828598896, 0.025219807904514096, 0.014662649951905254, 0.009354445876763954, 0.0450692551901504, 0.022002677207872755, 0.07719129504215333, 0.06048191000797576, 0.018775727179261948, 0.02920973745565261, 0.005517260851188293, 0.06278412296406685, 0.03558909715784173, 0.01892257474302765, 0.007148147128792781, 0.02255211546716671, 0.007614343231844326, 0.06605473617392202, 0.09554083218737956, 0.001562330385974248, 0.06930253528539213, 0.03695932584964941, 0.06142961822690503, 0.027981777037043246, 0.003480451634987408, 0.06983642195982319, 0.012933901687633368, 0.03232325667575483, 0.08522017994114468, 0.0369838981198207, 0.03388646291568875, 0.02893790647748017, 0.04793401416991988, 0.013093157960552604, 0.01893541054619897, 0.048639339830486045, 0.051306781374038234, 0.02201864439543457, 0.025985549174008832, 0.042163939515669505, 0.032332304174140576, 0.04557308057443269, 0.022605304951749505, 0.054630959451559095, 0.015664760947167393, 0.09646093442795739, 0.08916223091223548, 0.06233295846369959, 0.016419738681325992, 0.045495586950452103, 0.07622479851688109, 0.05481064154375946, 0.029649318706604744, 0.025692643117039435, 0.06440880392948467, 0.02347385330546287, 0.017727081130649296, 0.05502128507941962, 0.04171273288046641, 0.017177118101127205, 0.11182921743320842, 0.006370422328942486, 0.005099785546096223, 0.10067255641784399, 0.02886574482545257, 0.03480041730067423, 0.022121694712569157, 0.04571532394977347, 0.09673702485498883, 0.027662496488060684, 0.03277590738669519, 0.027628593266971653, 0.03529305014038279, 0.023431398627919056, 0.030006892160482468, 0.011386001884426561, 0.04450114736814172, 0.03259162876694914, 0.0758930747847884, 0.06525209819477412, 0.015510642251390365, 0.021304941563416394, 0.05941784835510677, 0.04693377147158308, 0.02644236548803747, 0.05985973553071099, 0.03881890469441011, 0.031869590898314794, 0.04032725903896555, 0.028459032576891686, 0.08190213056701807, 0.09243735637996467, 0.05525974143717078, 0.00810637948058185, 0.01773173894522892, 0.07717506163903783, 0.06542083672097614, 0.06923358737220688, 0.009253482191613125, 0.07380271961371745, 0.0011645766977791585, 0.0244769650030761, 0.022269978691192887, 0.09321099793117854, 0.005787856033777879, 0.06335314626114504, 0.06112206839926301, 0.03767241581132816, 0.023098738353338935, 0.04807013267230603, 0.053374318616284486, 0.019580741946194923, 0.027943030225052953, 0.054965713061392314, 0.018553929403424263, 0.05573298842195542, 0.024372652556086262, 0.06660688638446793, 0.04036584688771156, 0.03760764307733025, 0.0327121956844724, 0.01574293543179069, 0.05412015117584698, 0.0378302950412035, 0.018532243369507696, 0.044711821547318856, 0.0175466061374473, 0.015931770359466395, 0.03230201305761453, 0.02225963458899529, 0.030255219561137983, 0.0471635403922729, 0.07844951784899158, 0.021002813723058473, 0.04382639627663359, 0.042403602461901405, 0.03306610149241263, 0.03405006099191885, 0.06312954051780605, 0.04459667087142025, 0.02609001866902315, 0.04925606742260918, 0.020212624672680132, 0.04191366625168631, 0.017564745184274453, 0.03991222707554698, 0.043350548423346014, 0.016004603296037645, 0.03362191743367622, 0.053823035465733665, 0.0172932340478104, 0.05878907786081395, 0.05336758853386968, 0.06292751164085443, 0.022125373849825516, 0.05085260614812855, 0.044411921107600776, 0.007738694623713532, 0.05312368146053726, 0.03590531143990736, 0.049047791098635045, 0.03104326931098777, 0.014043910421370981, 0.015025717213809972, 0.03953170737311725, 0.029138537243969982, 0.059431848611923, 0.08668353811146752, 0.00655262628682859, 0.11362072170501757, 0.04099262555340125, 0.03434150382095287, 0.037040236225772294, 0.07416715530017692, 0.040841066548901225, 0.01578412606425944, 0.05081401829938254, 0.057814728934317834, 0.010833753040060403, 0.03628237608579859, 0.04370764115705125, 0.028412266739553986, 0.03317171437365394, 0.04690067264281454, 0.03416859394600315, 0.007129959722665409, 0.06384830719100372, 0.05195142137968252, 0.026456411710129153, 0.018719396734189604, 0.024848613407342665, 0.04100446161183138, 0.08091650482627653, 0.03665265319268069, 0.02207846820144163, 0.030373905732807134, 0.04852347669281787, 0.06283851903713038, 0.019552153460080587, 0.05692346990408917, 0.048350666409298304, 0.03817649783506509, 0.04173542057434398, 0.028335378325033574, 0.0578594493168977, 0.04213892291450212, 0.017021818672336878, 0.018290933334238587, 0.012414331281287296, 0.1456552091985941, 0.088106278300045, 0.0714047801410479, 0.023271039188388857, 0.07063139905972828, 0.12313465272346813, 0.16551138082098577, 0.09846302094839274, 0.20584388756223265, 0.12760053163454418, 0.12356795971432041, 0.21282020595765885, 0.2238854726836566, 0.19327632241672088, 0.1852532521250748, 0.04634456941857935, 0.14946099611059313, 0.1865961736128215, 0.08063834596184954, 0.11737802291228888, 0.13824724622311133, 0.13873715945068868, 0.12803969153713796, 0.1585144853039134, 0.12815121095627546, 0.15103677768380414, 0.25142869311234645, 0.21172967979744559, 0.13620805806450306, 0.10225811327296881, 0.21113986870454204, 0.12830079728437047, 0.1257781310367488, 0.12962864982264657, 0.1135619014741913, 0.14693224712485267, 0.17380647361278537, 0.17018987977456662, 0.155040766863573, 0.14726483653629982, 0.2138215135182104, 0.12640790127578283, 0.11752307399987214, 0.14982237510623472, 0.08216851466004887, 0.19019444262789142, 0.2820398045643684, 0.08868203934041724, 0.10861679626208161, 0.13344313949346542, 0.15648104280473726, 0.11780526248678086, 0.21278179430913544, 0.1517807103453144, 0.14964024536311626, 0.11325509092139621, 0.14861563340790812, 0.18817212372537584, 0.1054539563014142, 0.12821640503863174, 0.09871126407937658, 0.18716263434579297, 0.15630802950791775, 0.16627386813202213, 0.22508769446322996, 0.11383820640584154, 0.13975035669582506, 0.11792388354097644, 0.18735768033131478, 0.16646094680313142, 0.21347072185768237, 0.08257848661272757, 0.10929930399382308, 0.15250394331111064, 0.1579115587857462, 0.17893060591192017, 0.11873474164355187, 0.15024894818423257, 0.14141953970876434, 0.13910782343197253, 0.21819782142917957, 0.19459353399372872, 0.18040048349047863, 0.14062568875810794, 0.22091066134312462, 0.14787744640582992, 0.10562923721848957, 0.1708744099784282, 0.10046927498713618, 0.24295597517442322, 0.13578088743792427, 0.19799307980124028, 0.14509107737291246, 0.18142149483244266, 0.09600429239893153, 0.11600756056366429, 0.11057752935636429, 0.15464771779314165, 0.22229611603242738, 0.21468267295389407, 0.12472307474742975, 0.17650812864303592, 0.19649750763370147, 0.23539868634073968, 0.12154023223105939, 0.1213276504929508, 0.16082414846506812, 0.12308435139035988, 0.09194096970942714, 0.1352806626668861, 0.20045727821848086, 0.18063691354567007, 0.10580834857518635, 0.1265533124246905, 0.08213121383901566, 0.22247862881950795, 0.1397571135913172, 0.09820189987940174, 0.10287971701472999, 0.181956147594798, 0.1182035209550973, 0.09712216023716236, 0.16758154957525193, 0.13517511107267874, 0.18318513648644572, 0.14495402424325868, 0.17653036051459853, 0.1271927277106912, 0.2401610106349953, 0.18678748108927282, 0.06179695738659752, 0.22965927818609824, 0.1427636562936729, 0.27026910875593463, 0.13479231225867427, 0.09540716516635112, 0.25171554707471405, 0.08450123706772443, 0.22722287343875056, 0.1358555044017492, 0.13523279749337705, 0.22810444145673708, 0.10172838645596659, 0.22701828199769222, 0.16234429673321787, 0.08781308879054363, 0.109831198839651, 0.26675448122043766, 0.10349426508670855, 0.17228768898114083, 0.1616173865453851, 0.12514650686493806, 0.09673432822549537, 0.14087652126627584, 0.12339073293391736, 0.14987653752248134, 0.08235154072603873, 0.1265968032361519, 0.12453456349190205, 0.09758362095923194, 0.15350808539698202, 0.1255693720773824, 0.08498895162295911, 0.30882275933700226, 0.14180083699043722, 0.1205216647095738, 0.1541880190732979, 0.16058681442612605, 0.15005840679570553, 0.1562313134631803, 0.0917669834809438, 0.1775585577612923, 0.17947379289375198, 0.10831838969381587, 0.07414782690184732, 0.11316816292462811, 0.2544147659453654, 0.14663767099620836, 0.1530222630789203, 0.19360452980524112, 0.11179884204701071], [0.05699136827681815, 0.04068031831974945, 0.03203781806082735, 0.05650147037099927, 0.02493282945285882, 0.0157975421790334, 0.022310654129532557, 0.023559310413416357, 0.021266882315338142, 0.04710475846584286, 0.024374303475563085, 0.024735875908405553, 0.06236161015206768, 0.08094701810830063, 0.03128067995872229, 0.06749226185943812, 0.10859541474811493, 0.04259019083673916, 0.05338848741244405, 0.011537510135601605, 0.001494004081318816, 0.03464821095187818, 0.046690113376826055, 0.015166302008794682, 0.02120747219681019, 0.09872192036240332, 0.015999041497707367, 0.04051149169343614, 0.025069932378227675, 0.04262399446639804, 0.04457286085873362, 0.06217250517839867, 0.009634353336878121, 0.034657898133680705, 0.1272631694953288, 0.030756980338464343, 0.04247520103930466, 0.06424996325926435, 0.02130899416853584, 0.03837478820294623, 0.06333422388941531, 0.039346563074016766, 0.0052586860669356205, 0.07797257448997229, 0.018818764083628214, 0.0553087289294889, 0.07009951187477959, 0.056580821758196245, 0.009803406916739, 0.05347248129246216, 0.0743048366219286, 0.04413897547149851, 0.01954953726981917, 0.04216281719686043, 0.06546447308914316, 0.04775800163887682, 0.03780503712233998, 0.03762573041322251, 0.060639249145864486, 0.024179609890486446, 0.056918072814662615, 0.02235690285752137, 0.06449571660449428, 0.07121272189843078, 0.07326954540105597, 0.054456436961528756, 0.03457455542839823, 0.07550279129176371, 0.017839471974800673, 0.0583427818492055, 0.007020042863704505, 0.02494512516404352, 0.02572874118003153, 0.05125789730358989, 0.07568793176042457, 0.021884278319175207, 0.036398112818959265, 0.021339407859129772, 0.053329824229642275, 0.04090080991567623, 0.020381133372504866, 0.03945620557773979, 0.06102304770461014, 0.045465238377331726, 0.01836946692257639, 0.09368462412948571, 0.07138204265145526, 0.02943411886301493, 0.03326672842846282, 0.031091417937028794, 0.03724305034284631, 0.02948383796930073, 0.016539734863345663, 0.04966369514623958, 0.04553217914015536, 0.026805422216233228, 0.04605649737641216, 0.040372128808690656, 0.019875549816436345, 0.02979603986586294, 0.01878409668983471, 0.025872804014192476, 0.047559967910450314, 0.028270184242677306, 0.009381932153877233, 0.05571004408862322, 0.04264232311998645, 0.03523662010388028, 0.06906196835540956, 0.021507885915437536, 0.024955017274365793, 0.028553676994277105, 0.00781759258262032, 0.03244281618765766, 0.04705098675443761, 0.04654998057371667, 0.057225821825164946, 0.029701895320848114, 0.017842208823910164, 0.04188126073248925, 0.03144998730520808, 0.012483112570349009, 0.040536194198554566, 0.033778942475515994, 0.030243153676330566, 0.10802580539377467, 0.06998377131117929, 0.04456038128644709, 0.017906778544608145, 0.08294761075728363, 0.049634737022701776, 0.04930266089016392, 0.07108177448953353, 0.09163055088250868, 0.07448577892876442, 0.025977200730853987, 0.04869200837528033, 0.06289659233223047, 0.03209108415420257, 0.01229964791902251, 0.03968475641863, 0.023973380936489954, 0.03117839764473179, 0.08528558086724052, 0.0075015947203933, 0.07804710718412554, 0.0031803333390158636, 0.05906270531516883, 0.02465218080267791, 0.012415060022425269, 0.02795458474617091, 0.0508102874511913, 0.032443670375693234, 0.03452789684336993, 0.04598699404948181, 0.021727511832009883, 0.07120937409420168, 0.021332763961606452, 0.09232818118987546, 0.050939143440055276, 0.02583116522028802, 0.0421810309372602, 0.11151411014819339, 0.03793023121092589, 0.027479931990045215, 0.021747761451068427, 0.030044137440141172, 0.03228445432239002, 0.05332978209480644, 0.022236203789831172, 0.03937043820417697, 0.046017484348868175, 0.025075701020297506, 0.00822607593070115, 0.033437546883379264, 0.02942393755450124, 0.0668935411639752, 0.04591805379717581, 0.07690216579865064, 0.04000752841332748, 0.04510206290550771, 0.07905933915847733, 0.015128932239848281, 0.10375193109916103, 0.03963253603527143, 0.08654740428732288, 0.025258706018869436, 0.014469142845501343, 0.03238914406768257, 0.05454521123019438, 0.018918355513784676, 0.07985846079405277, 0.06535202670361727, 0.07661928783261007, 0.03604501140333953, 0.035835126294724406, 0.05975127663283099, 0.04507390151341115, 0.020994815765128984, 0.023569168049782038, 0.045672752443821206, 0.04929187054175043, 0.008213871192457456, 0.04073220545486097, 0.011496161497498473, 0.040777308881402984, 0.017941403803565813, 0.02692992108002786, 0.0561712711538759, 0.035622234291006485, 0.0324746088365153, 0.031084969391926166, 0.019280485275592056, 0.07212215253422338, 0.013418810445845369, 0.020441840094844663, 0.00021226592135433514, 0.04762287905079223, 0.023859616879734303, 0.012816111838835622, 0.03865416897761245, 0.055866440938365076, 0.041207168476595994, 0.05719474546851651, 0.030314242805264173, 0.03671888149373474, 0.04056283873656104, 0.054270089904387156, 0.03211647230801323, 0.04514605167411989, 0.03976704575301659, 0.031218655565152728, 0.07641328678977105, 0.007286217718970992, 0.03636045576704126, 0.058386793600455414, 0.07499675957425948, 0.028468533982372576, 0.05389625814953639, 0.07433063080233913, 0.05928837183502413, 0.09984762528009954, 0.10014805432048537, 0.039783443865035815, 0.03271518725781672, 0.025296834214860876, 0.04652392592341189, 0.09266957295157256, 0.007606232754750959, 0.05317417814606621, 0.006796925022612296, 0.035162704110506086, 0.04760825826275734, 0.04946841550390086, 0.045053684453089396, 0.06779216996003544, 0.058383388339631984, 0.022656738179765885, 0.04144485108554363, 0.02302175034738837, 0.052156752095587795, 0.10726016180049028, 0.028017660595416546, 0.016123791255297202, 0.05868468688981188, 0.03426112204549774, 0.007333316325750803, 0.07739278382711834, 0.010677968103048063, 0.04446583071483239, 0.05148635238348957, 0.041729751523704305, 0.06154278856551936, 0.03265169006021273, 0.019775278483247085, 0.07096140675487057, 0.032445271499454975, 0.09583894764223407, 0.02143423613761702, 0.04680216522707094, 0.024818613404227842, 0.07101943025425558, 0.036769424144539146, 0.05084913576983156, 0.059086538310493195, 0.03567719343869436, 0.025021910156694152, 0.049269033460727626, 0.017435056074792822, 0.013998246793034337, 0.0887207957285066, 0.039659494669326854, 0.034227827864308516, 0.09629527557521098, 0.029370410991231763, 0.081930682663956, 0.024907583025314158, 0.09334324768954709, 0.04794169420136079, 0.09430360785054584, 0.069404348370529, 0.07782684924501566, 0.012141272647216195, 0.023493968859134663, 0.04439483734688932, 0.00609508793493132, 0.020848636613077214, 0.008916823895678164, 0.037333923692424456, 0.060988964452858896, 0.010812329391257898, 0.04162104747768852, 0.07006909818418565, 0.08138935727578017, 0.057273951299007864, 0.0450632605521429, 0.016359721438118046, 0.01665638324113623, 0.05232955854866774, 0.04327146133648292, 0.054495346567202965, 0.10402989844160695, 0.04938132279822904, 0.028245841798883294, 0.02656380957623403, 0.05303340948997967, 0.008205941224831247, 0.055494080072328936, 0.06053716409951449, 0.02685582505599145, 0.02444459012739601, 0.046294099546127745, 0.019290837038668896, 0.0486035367113448, 0.04378557911202793, 0.0366049948629112, 0.06506084434447751, 0.009651081824314692, 0.03985154142062511, 0.023901933661451744, 0.0667977725125609, 0.054316629745787194, 0.0329803494406083, 0.018407137381033074, 0.03817102796728573, 0.01781524061375568, 0.045350535862868836, 0.06040745775305456, 0.05429750436075753, 0.0501702094991361, 0.05713210628938772, 0.010001006847878378, 0.12433638420676994, 0.1114669880799709, 0.12221409849101499, 0.15385153793519543, 0.16205034879667146, 0.11216821133970253, 0.10890558076601838, 0.15473830002930858, 0.1849560866192464, 0.17368160128112764, 0.13813699084904887, 0.0779698548778411, 0.13587577508822565, 0.20381730921085806, 0.12037939452115567, 0.23155966653458535, 0.15720491928438987, 0.1870127875478037, 0.20165171654474354, 0.1207508016077261, 0.07561670090522497, 0.09177171024343661, 0.1320918370038271, 0.12443222180609742, 0.09799882529243346, 0.19363868200490553, 0.11141937571547686, 0.14620498453657474, 0.08387381871861797, 0.14126596972346306, 0.1530382436730208, 0.11722583188525132, 0.13546590272697712, 0.12811558786779642, 0.22498062601493252, 0.06895404954951617, 0.22013087576675802, 0.09691959892910335, 0.18759619414566026, 0.15005094509932304, 0.17672249536600806, 0.14635348301981727, 0.13306714354022858, 0.15199555204279963, 0.18219679113357298, 0.12043373313762488, 0.256373698733026, 0.14669793147233226, 0.08659895434374772, 0.10042261257166825, 0.20102309543759594, 0.23030089214444163, 0.11092612234454964, 0.20508624192687774, 0.11757309188044841, 0.2022627635949081, 0.10853400514010461, 0.12746867258101702, 0.12407697917472933, 0.12725125682810623, 0.16203611488303832, 0.15272008735806714, 0.16216138558041665, 0.132057347725476, 0.17059325571021727, 0.18320643373074072, 0.26780438939890555, 0.14556206822876008, 0.14753141981219092, 0.22986529455069574, 0.10908256239828565, 0.20359180356946685, 0.12121279093046343, 0.20642809089153044, 0.13355042244638168, 0.15090677256305374, 0.22416656566483362, 0.1178007961941823, 0.13979512687412002, 0.22474675469340819, 0.18438424794904648, 0.11913133004019338, 0.1065565330246764, 0.15740961797775763, 0.146465546361381, 0.28605974369472076, 0.15101969392309267, 0.08629978934843695, 0.13725563733568116, 0.09073300993130093, 0.11260664345876825, 0.24398107742590291, 0.07339784980661447, 0.1434645961008726, 0.16419032348259804, 0.23472898759909216, 0.16295880650080022, 0.20941022603261858, 0.053846719073912794, 0.11980177954800668, 0.15009459678924855, 0.1463696474750196, 0.1691296753743964, 0.14007277245963776, 0.09974840157214673, 0.12347309504665675, 0.1803874140304904, 0.1053795921466043, 0.11387076514262347, 0.1185198386590327, 0.13889768551434242, 0.18401027446792972, 0.1716144968785586, 0.1272381490637218, 0.22444646354884873, 0.11430725905924075, 0.11375936829755384, 0.13211416080594063, 0.14935179793786618, 0.12146369238654453, 0.0978109269072452, 0.19295853382397085, 0.17492270968373747, 0.19021244569411203, 0.10148254118018574, 0.2821525420633055, 0.2206074590644529, 0.11705363064163155, 0.17115545699432974, 0.1459030692856158, 0.10447488827330452, 0.1070685938541447, 0.1472849846487084, 0.1414637736255123, 0.12684411940074738, 0.1488227376173581, 0.2204721219717495, 0.31968591674681635, 0.25717887246320326, 0.09147448345057427, 0.19721543927106167, 0.10323776352790096, 0.10947949553449308, 0.1191117181893318, 0.10778087942350296, 0.24054678187014597, 0.10067193588662533, 0.1906145958890838, 0.15084519441570007, 0.10163262546543153, 0.11041023107545991, 0.1029299034346496, 0.16612448098678745, 0.13657450856220338, 0.12540819483899301, 0.13432769525435664, 0.18475580059232252, 0.1416822312580001, 0.15625716126974554, 0.20631970477200326, 0.1814496715462977, 0.14557840122330576, 0.16161660513570233, 0.15736477119067024, 0.08493406908406366, 0.10990963092133885, 0.159227728483177, 0.1667688835051752, 0.13419185254362323, 0.12733656071847485, 0.11628034915174208, 0.2663887202018692, 0.19197567366063598, 0.13960077036773005, 0.13253138761126226, 0.09836044177533158], [0.0734947522681567, 0.01038163380261751, 0.03748534097065849, 0.034640576885712725, 0.023837978726313002, 0.022380021475856344, 0.041671796972232486, 0.06856808679238444, 0.07454047760655803, 0.047475380312290885, 0.06648450383856412, 0.059860482466437166, 0.027202119780403954, 0.05004314615601494, 0.05963697248408872, 0.02714857023449675, 0.045053033278353756, 0.027215091564181833, 0.03357363091180882, 0.04175569892169968, 0.01861903155522962, 0.07617552374159137, 0.026476795394574443, 0.016062991644796586, 0.019726769795881647, 0.027350459300402193, 0.05651989861601784, 0.026019257042677175, 0.037934862212428165, 0.02126743198342381, 0.105437669272144, 0.10168669595112724, 0.011297126109110973, 0.07489390460954559, 0.06445234836710077, 0.06298726266850868, 0.02848125104191563, 0.06551596185853405, 0.013939201523880325, 0.010250141513684105, 0.03250046047352014, 0.02217758465708504, 0.05653532379637322, 0.03913073695354885, 0.033831568885474436, 0.04641539041673945, 0.05719314051431514, 0.06584034646831213, 0.06582331633375538, 0.03723631642999188, 0.02591854137849183, 0.025594273597122203, 0.01929157822873564, 0.04647581560176708, 0.04767367451061164, 0.06340913579709108, 0.09766300298994589, 0.08411741935678067, 0.009900124559569503, 0.09125497627763018, 0.022053874863852418, 0.01180459519908313, 0.02443107059075227, 0.06192334657234531, 0.027964461534734697, 0.03108517432044591, 0.020611053595559734, 0.03463052964258579, 0.09914886882348407, 0.07667730367111583, 0.0397912273183465, 0.01650369425694789, 0.03591500245214951, 0.04923408452962195, 0.03517149879987683, 0.009952132353529094, 0.03727448676081915, 0.01824376913118026, 0.04149301120290353, 0.034204554113168875, 0.04447932535361859, 0.0812548628797935, 0.03538373962885911, 0.07423568952588305, 0.04593669654681318, 0.06291443835042658, 0.056694072536042625, 0.09659217295026588, 0.013698224736858281, 0.039525720395989, 0.030068052789917397, 0.02149704960174859, 0.023095886591040803, 0.048403465189039714, 0.013813535333611073, 0.029768332380861528, 0.035227143596256935, 0.030575685631183368, 0.035838462607634645, 0.12308745404645322, 0.02308446230486997, 0.05777450931829311, 0.012338998025253177, 0.014601674141182054, 0.08613547881043727, 0.028853931749660163, 0.05240657719813528, 0.017739074237103906, 0.07282576598827878, 0.045542628579442544, 0.027801608479010965, 0.06809934057415494, 0.005342846571077263, 0.09919193828658712, 0.04215628246686632, 0.022274121311643434, 0.026502172057066235, 0.0021622489317275227, 0.07364199436720341, 0.02925155053455984, 0.013743191225183828, 0.023617686313246528, 0.036948577636071754, 0.06196045970183708, 0.0445742359865577, 0.008152106311172247, 0.040426168650869405, 0.04757401030210238, 0.031814011219408245, 0.06084734543917641, 0.02084286414056776, 0.017334468730334795, 0.04782326466914627, 0.021393614325432048, 0.05592995728816717, 0.02629812262321432, 0.05206605494623223, 0.02805940855685021, 0.03419964348957424, 0.03004155763905616, 0.014243960876258151, 0.018616907576459552, 0.02585620671931294, 0.05341377597482455, 0.037489776619740074, 0.00959870152010192, 0.09158689919258318, 0.048727259911116094, 0.01712061720149171, 0.029307787133861455, 0.015656806081683648, 0.033427806075422034, 0.029341512239508094, 0.02797542425293115, 0.009212334651590116, 0.026324391778137897, 0.0132953429279188, 0.0717324436071419, 0.031019692955118035, 0.09980678513285615, 0.06243510479708353, 0.0395749913408391, 0.026177923427894715, 0.030351039923487172, 0.07599629747170596, 0.04221820152334629, 0.02757336215807065, 0.03607096646221415, 0.007319814504890313, 0.032580639235675335, 0.02632128337638513, 0.04976424418630139, 0.03466549006501033, 0.05873934343276967, 0.03872017128272884, 0.07153447882662858, 0.02742632307232388, 0.030534757383828683, 0.03814245671814969, 0.06399410138387354, 0.0335425928595566, 0.031638772437168707, 0.0056365632448315385, 0.01870188396424055, 0.05813246007047354, 0.051018092631092, 0.052875660495051456, 0.036724688440200784, 0.05449595560710277, 0.03004355904375834, 0.04546681651845575, 0.022660043849159154, 0.02631743761500524, 0.030398183059127584, 0.04750161116281825, 0.04913621679729512, 0.02835849885858836, 0.033398710056057865, 0.012210665849007428, 0.02553310722202784, 0.05208058380371621, 0.02155531058839012, 0.056517435643341274, 0.03189487563025567, 0.06316428260517216, 0.05751333079270779, 0.01179556589528558, 0.010143470473497385, 0.03850313091290094, 0.05499060325805218, 0.029764745174156084, 0.013012748414410219, 0.021840595985732732, 0.06213101002598002, 0.03937221935860092, 0.03177868307478005, 0.08608780515890929, 0.09422380447147355, 0.013190918440570035, 0.0338845553567573, 0.06086224967974329, 0.03531787521956909, 0.0726428931398738, 0.01778808471205975, 0.09768584773184792, 0.06898388101328766, 0.028180038676627224, 0.05074906936516205, 0.05028067554737772, 0.03195244905298516, 0.014597737406861159, 0.0284093345380238, 0.010063707314041114, 0.05493918343657448, 0.07101489501374383, 0.06946765787659154, 0.07430774009516163, 0.015100796703219175, 0.06729848757987061, 0.05701866781999988, 0.09840587845012065, 0.0479368448648001, 0.014620387753952416, 0.13331075950014976, 0.08091915549049455, 0.12024004312772905, 0.06417235855253474, 0.0238321258145715, 0.046622651674213915, 0.017461449719004093, 0.03351140925059876, 0.015406246492338758, 0.043408476161740484, 0.02342935891882066, 0.014130321308790196, 0.04116624405968093, 0.037520810841552676, 0.03454049515928473, 0.049330887399734034, 0.041767370271226095, 0.009622658047104075, 0.06610993280886643, 0.026427413366975325, 0.058993278597030914, 0.07984601952616247, 0.009701764286165277, 0.04817705556389786, 0.06836166440118706, 0.02703349425217077, 0.0487417044989284, 0.03213833454215238, 0.04592723536094831, 0.011127747899492182, 0.029549970509364244, 0.02676607211000256, 0.10701967147930015, 0.030414163653228073, 0.028424886122886694, 0.036700181287503054, 0.008039832295429322, 0.1072379912159616, 0.033133390825241804, 0.06514823199400017, 0.08283167101082303, 0.0438361868803059, 0.010446309818014985, 0.028400578153049274, 0.04929069459678666, 0.012639659764846007, 0.07943770998427946, 0.04542525241812391, 0.07853416290374533, 0.06895778039770742, 0.05963876512983154, 0.03324883261455163, 0.11657317859991906, 0.079394280459852, 0.04215874160910326, 0.017740782613175052, 0.042381554451440616, 0.03655765062919067, 0.03902048924036565, 0.035070359872113314, 0.02838707393816402, 0.05121036920876754, 0.027677552030992605, 0.017431300328744036, 0.06482216199078868, 0.04802062040975979, 0.07710517909858497, 0.05766495108424176, 0.02996645420939932, 0.06649679954974883, 0.044652775320554935, 0.007191218985920593, 0.05340116233715127, 0.01809378635258444, 0.023957484612061132, 0.032306728328788475, 0.02729005518279249, 0.025106212387101787, 0.04904407174176267, 0.07337056941563085, 0.06199411777479034, 0.05127036155411794, 0.02470833504752767, 0.08109114989037476, 0.029755958145664587, 0.020127889602595282, 0.014181186674132705, 0.04402491647089201, 0.040495737095273314, 0.02700115193522746, 0.04899341034733, 0.07594920604700044, 0.050878856150854024, 0.0566169849386619, 0.0077808811704838474, 0.08404538410926059, 0.055487832625306426, 0.08903607921374422, 0.01048041030674452, 0.018852887554995475, 0.03518769772903573, 0.026691257878537142, 0.08664959275554265, 0.0196476195067648, 0.048364000169620405, 0.06206356747556598, 0.04277480653517189, 0.014301369590083919, 0.018824371847233946, 0.09758044169434617, 0.13700256785077436, 0.1614499044033789, 0.1361082674514863, 0.17851146388678782, 0.07081238733183953, 0.12127433843430012, 0.21537446567127783, 0.2099817123023733, 0.14899978053665933, 0.1465908936675518, 0.1685859214875006, 0.1670124688215794, 0.1151690390261431, 0.18144662251635907, 0.06140506127849222, 0.1531620741251015, 0.1133358748930116, 0.16517802532161438, 0.11210742992379012, 0.13992900839976727, 0.20268101695804827, 0.0750243770439298, 0.2512015480427973, 0.2811093448150543, 0.18455301711876548, 0.17314040612789894, 0.17770204602951006, 0.16233822931685757, 0.10368577940689941, 0.15998591038007892, 0.18994740991582795, 0.11601581899148804, 0.17397798537727327, 0.2963387743840295, 0.13671416639079972, 0.14883586836438026, 0.14483707326073803, 0.1633898228887589, 0.13337494234644598, 0.1804520412077827, 0.11122912544036105, 0.1626788932950266, 0.1207498899630962, 0.14368777283497397, 0.1831190384203388, 0.14198641412921492, 0.2422889424187522, 0.2743501204156107, 0.17859830761388426, 0.12574944870486376, 0.1362699886123019, 0.1646415033047238, 0.13678254739892098, 0.13640523377445438, 0.09985727032706623, 0.12549068718667955, 0.22187289841953786, 0.13412598430389358, 0.19918987767830973, 0.19389300787400818, 0.13110531494021416, 0.08016514111190073, 0.18415984547426625, 0.1557230294471787, 0.14666708877250073, 0.07494392249012187, 0.10881976359674048, 0.1621543988585472, 0.20218822323987562, 0.09280650350715845, 0.14365201185066856, 0.11943755070528678, 0.2277946814654335, 0.11377023142432013, 0.11586539762755556, 0.13620324703233858, 0.09444478253323225, 0.07758940029288493, 0.12930385918626863, 0.17948012078000655, 0.2053151030333773, 0.1719634192845514, 0.15766759042537984, 0.17734953833203163, 0.13216751116898753, 0.16702045145775044, 0.20501988339087657, 0.14244654185829625, 0.13258613225433136, 0.1684840317935713, 0.10373498523427595, 0.1336606778204441, 0.11835182025547951, 0.15591315714822662, 0.1282446890047962, 0.1350114134050185, 0.08537871417619529, 0.13962539243361644, 0.24245648584779234, 0.12111581952100801, 0.11627508612770228, 0.09822868997411383, 0.11507743789303689, 0.2679273618325111, 0.0884723993799379, 0.1954396781060965, 0.1303061013740878, 0.16438950634291097, 0.10717081296588145, 0.10837364761579422, 0.09283170779986728, 0.13721973845554938, 0.17007312797490629, 0.16081740689133445, 0.1272857078020611, 0.11795867159361802, 0.17485098853226633, 0.20275517426911863, 0.1708241546105954, 0.27514384879219916, 0.1760345330882457, 0.16118109947250736, 0.10063267388050595, 0.14402232343150725, 0.08593356867711391, 0.10515458446236388, 0.14898455070872463, 0.11893316607681975, 0.2939460060048488, 0.1799651616883855, 0.17424086078761086, 0.175532209236295, 0.08849471552117218, 0.17915275608820302, 0.11381160017223128, 0.1427955102295645, 0.1013743619043981, 0.12267233398292335, 0.1252836825686597, 0.08288366539824395, 0.08786348205420279, 0.054929411985100283, 0.16677896522225874, 0.09541841133707955, 0.17315575852990153, 0.12025129695933674, 0.16143076752703037, 0.1574913135940029, 0.0935894989919278, 0.1217382506377274, 0.175516243963953, 0.13075495228892373, 0.19875397364939415, 0.14628516329872995, 0.1344711682008159, 0.1605708644755425, 0.1526986215744288, 0.0968487511178659, 0.21396757584185372, 0.1526327073694237, 0.21957248960050846, 0.20126105766863595, 0.09660101360491208, 0.18397861971489846, 0.1040273473688191, 0.11148817041107725, 0.1246863025270643, 0.11023256762494003, 0.20448380570498206, 0.11147589768253027, 0.11447490207971105, 0.11101066780787323, 0.13961696546644936, 0.14884130758864267, 0.13386004454185887], [0.023183155496935212, 0.04834525016767364, 0.0014327146533516146, 0.03366307550740819, 0.004171765786820963, 0.032313347328454256, 0.09459243831975807, 0.024429741428203644, 0.049989359122851205, 0.03329955529601824, 0.10902915840908405, 0.035379782784730196, 0.044816584070964206, 0.020515576057556658, 0.06527574732899666, 0.051334276269640655, 0.01675801821083071, 0.027964289164951736, 0.10910153073529083, 0.03655414960737671, 0.042870977382746436, 0.09552769377947816, 0.038029830301961595, 0.020432913255306984, 0.04645380972614212, 0.03432232864020813, 0.0162143332718481, 0.019672655260130283, 0.06289070494653237, 0.031841835532818115, 0.09529226729946752, 0.02170716070630137, 0.01595874431528031, 0.047474123928095066, 0.062299105038325635, 0.0271424587680808, 0.033092497051843715, 0.014547931158073969, 0.04228414637186835, 0.026173485863593318, 0.021977664437144998, 0.034399385594071887, 0.03616418787128022, 0.04588050016712758, 0.01731184040827136, 0.056042526247760946, 0.01937418357439099, 0.03136399776614722, 0.04293762320171922, 0.012724646686335966, 0.057076603219273596, 0.02878894451104345, 0.04991361217933798, 0.049017469338592023, 0.01901978555495941, 0.060569466196841774, 0.04992721407043357, 0.023208867322893876, 0.02496823229105963, 0.046934154515545216, 0.033192115295077526, 0.025255170523098884, 0.10252920880673394, 0.04771461807972482, 0.042490695167573235, 0.041397506851823106, 0.00026213161676893044, 0.10754318532323646, 0.032948051173720634, 0.06484149038911828, 0.021917463332835226, 0.011929895582368538, 0.018687998620612968, 0.06173448291637244, 0.106484804212326, 0.021546207548629855, 0.053521622002365134, 0.0359882902534258, 0.034103434337603475, 0.03775250647337206, 0.008428316439441856, 0.034471305928403334, 0.026536042719418486, 0.040558357122204, 0.05420946553649922, 0.034388602906537634, 0.041245645242592985, 0.06319374634673999, 0.0484481166237064, 0.010462491510195598, 0.014172708953640634, 0.023454503839715354, 0.05827317126996576, 0.034269912904428865, 0.04229795127626389, 0.08693915100828295, 0.026078646093787208, 0.043168384206270984, 0.0738648493443766, 0.007730770880551709, 0.08203975826261506, 0.017107967174642028, 0.1078799116094747, 0.0662907448807551, 0.01998861864840071, 0.04103175349413388, 0.004048567357277799, 0.04908448671020808, 0.05201967981373591, 0.03702445864497173, 0.014655474580884462, 0.026565115756144928, 0.05107779386303118, 0.030667531912425355, 0.04781207212457254, 0.058640736425595905, 0.08051908139379756, 0.021770724936598734, 0.044678806988221985, 0.08692015968864003, 0.04503033409315733, 0.06364684521911607, 0.0656312121258628, 0.020832022081219384, 0.05560325143197852, 0.09057213146720203, 0.07456440253243332, 0.048257839535513235, 0.02902905561871106, 0.010142767587826859, 0.05107297900042707, 0.020796602006040273, 0.042621623424272385, 0.05164259601564658, 0.06279480222973131, 0.077005319537655, 0.024830932098050273, 0.0057634953953956646, 0.09922617475592321, 0.0344112178220624, 0.0339904363687721, 0.032903173743116285, 0.04273502741970363, 0.060907035179796724, 0.01902666119407983, 0.05601103237319378, 0.033231940375821244, 0.06744669494970192, 0.016536660935549487, 0.025089412078922315, 0.08370028448200996, 0.08288887479612905, 0.04079420878101261, 0.018030042091624874, 0.019753557975373922, 0.030011477196709286, 0.04122759238065731, 0.0222200661477062, 0.030275689430474758, 0.10117387669461389, 0.04564539927448477, 0.007100776560799851, 0.03524387495652322, 0.033400223079708316, 0.05226285527310064, 0.049956612694527835, 0.038043704154270316, 0.024417888132795215, 0.035768798402240204, 0.024980734845983888, 0.0739121169693047, 0.039097810494563276, 0.029668214265257124, 0.024868298036557053, 0.06021101365707094, 0.02857482485142687, 0.037414060319743814, 0.0310980943932889, 0.0733475484735062, 0.04105279026853462, 0.04362075529511898, 0.08755765209395079, 0.05789415693030723, 0.04505043240985082, 0.026777609394142227, 0.003025736077688635, 0.0148003418073659, 0.03799260992016043, 0.1076507900330809, 0.05799365259947316, 0.013036598646712881, 0.04933400537758585, 0.03312984383815239, 0.052447834863297405, 0.0684597313163742, 0.007856747815235248, 0.055175713083196076, 0.03407483627539008, 0.04962594999421028, 0.04859037915124528, 0.056046636309474714, 0.030702974970242193, 0.01579903988092537, 0.040918211602876266, 0.036700131491787975, 0.07234054887967725, 0.04241855649818336, 0.021869611565864856, 0.07306651677936316, 0.023389635344726906, 0.06519658746378076, 0.04036435684669883, 0.02766688617186681, 0.02561635991197921, 0.046986964786605495, 0.03065192095574833, 0.05781406626826333, 0.017497212618529316, 0.02532350173550508, 0.02554051146181601, 0.02360247372229013, 0.07617770709217557, 0.0596390983780786, 0.030411198892961108, 0.044998093282863985, 0.01448955047019427, 0.037839315726511905, 0.06807709338083383, 0.03499565863861673, 0.05299880912887955, 0.0059867674116826355, 0.06648491752604324, 0.028983209086882494, 0.062148836891978025, 0.041990140978727615, 0.05436553679887326, 0.03243532767819782, 0.01213902896720796, 0.05994431546799118, 0.044181596773165854, 0.021003811552579847, 0.016268407587983435, 0.017357960816532854, 0.03907408475154831, 0.0708364348317827, 0.0456116684231787, 0.049456866728442336, 0.03314277157187462, 0.07889784016315976, 0.021660519358251366, 0.10203711222857238, 0.03663227142345521, 0.05956478018854415, 0.023162827353864428, 0.03989337748217006, 0.036732659585052924, 0.01169813004502606, 0.010771232604559873, 0.0983393820182931, 0.021383448338676846, 0.0807920768256149, 0.023731030936863635, 0.045090211525319085, 0.01611950499336085, 0.042017429030590484, 0.0653499735879802, 0.030530271939032023, 0.034445473443596594, 0.0473752832641044, 0.02822417491716483, 0.04409320171802275, 0.06154951864793416, 0.045178104792871786, 0.03248222758092227, 0.10500338934962788, 0.022605230258176887, 0.030952771344492515, 0.026057272240699782, 0.044177180276282375, 0.05639928573321912, 0.026560300893540827, 0.08642050948354506, 0.040554465395548654, 0.05868580537818133, 0.031712397317131685, 0.028582834300675222, 0.052312685462135466, 0.021867060493077004, 0.03322598787264959, 0.024752789214553855, 0.04652980564823074, 0.07128192262063104, 0.05403833681597345, 0.018950558019681804, 0.11847637849108827, 0.06524131167680025, 0.047035312595506834, 0.07214342679588065, 0.01330068160314113, 0.029007762204855684, 0.026140040380039045, 0.07645611110473834, 0.08867443208732913, 0.010676919520201703, 0.02374967177128119, 0.024310936512906226, 0.03186380310404686, 0.026007463119082877, 0.05233662187932961, 0.03515028965569312, 0.06439380392792725, 0.028603712111831676, 0.046180668737619154, 0.07125840372135563, 0.08065928314482013, 0.059381777105192025, 0.009561391122969649, 0.02482551202598599, 0.020146181867007288, 0.07159614124365392, 0.029141984639629245, 0.017542172403585528, 0.02306433717509912, 0.07672359070350086, 0.0517568388773549, 0.030483218818722718, 0.12499026323278105, 0.04585893862249871, 0.07718000290614944, 0.02761802316883639, 0.03408046319119392, 0.13532725613444083, 0.06024970109724711, 0.016674614218514294, 0.04461994845299952, 0.06637677655465181, 0.02521021265326248, 0.06338063732630785, 0.026098874645427834, 0.04197591855641335, 0.054264922641337886, 0.02852382829352733, 0.03751279373142508, 0.05237925850275544, 0.03530233895646469, 0.02405935706901214, 0.03563028587509067, 0.021702410961170832, 0.05896091521266968, 0.035760689361561696, 0.012618071407139783, 0.03432442006024142, 0.20030124143006342, 0.17636807244871894, 0.1326034458414201, 0.13729884469461057, 0.19368178211152556, 0.22146268897960264, 0.2417655358271253, 0.09528047720631284, 0.22189870026082764, 0.11352004243000863, 0.16791139639193015, 0.17802767936260472, 0.1367509232894067, 0.17381246442035322, 0.205483642376719, 0.12226853669891435, 0.14714331966975044, 0.10977595623943115, 0.15567727867634068, 0.12633521485352708, 0.18386041234818198, 0.17786398169494447, 0.14140240998277742, 0.0876118298319559, 0.24245959616476492, 0.15737071603296265, 0.11465899300791564, 0.11329698826997511, 0.12511708142776645, 0.12553728065423428, 0.16115244778413929, 0.11159362241385445, 0.10951984538546494, 0.13889465180616226, 0.20054213011697417, 0.1492493413388729, 0.1270014968430323, 0.07977575394174746, 0.13056490119666825, 0.18013586139967366, 0.14297558685704587, 0.12521136386860765, 0.09611250231823615, 0.1920504898073212, 0.14484749205650824, 0.20941016474558463, 0.12097637619703047, 0.24194147557981555, 0.11553803293575203, 0.11206235331032546, 0.12425678767143719, 0.15226150712659284, 0.13648596411991504, 0.11424306855206529, 0.08191575927119102, 0.16869110535950432, 0.14262772165238857, 0.14625010711531486, 0.09956032698673588, 0.17647187736245895, 0.08143535319475398, 0.12724827674608077, 0.2179070297748812, 0.10374008737985166, 0.1501001739093373, 0.13547042264573037, 0.10687018474263531, 0.1725958248660449, 0.19235920791904773, 0.16102120160095154, 0.11224568581148503, 0.18816116866805863, 0.1832271181046963, 0.1316314488048515, 0.270040875841533, 0.12273160620562493, 0.10685064183968691, 0.08561617078920526, 0.12226653720943198, 0.1451800355026799, 0.0968680105682823, 0.1130438115327589, 0.19377545934290658, 0.1367056628148402, 0.1413575172304146, 0.15757425027268548, 0.21071125783266562, 0.17520037059101368, 0.07062864880408011, 0.1006419358835105, 0.09574260442487656, 0.10653505958015881, 0.16417642664765159, 0.1978769102284024, 0.10224541919606348, 0.23631506539400549, 0.181435514241457, 0.11461607676239745, 0.23909334453844258, 0.07602659624911125, 0.16852651902985188, 0.1315355499184901, 0.17911265904624618, 0.15771228399488235, 0.08947494034204753, 0.21556663116620434, 0.09649024495194036, 0.22836690317959557, 0.1730111824168313, 0.1109024195841724, 0.21109398003787766, 0.09659857744531286, 0.12685652236424147, 0.08821795093676738, 0.11755051526931987, 0.1467406791785071, 0.211167064825854, 0.12617746202815927, 0.19416567388801806, 0.15810729425039985, 0.09894636114157977, 0.16867710127224847, 0.09506418760265074, 0.09228416943862554, 0.18181042234984138, 0.2506674468637474, 0.14533460140228271, 0.11473278259678234, 0.08014658646237466, 0.0947422085089549, 0.17138735180900944, 0.08402537389267838, 0.17924278674106445, 0.1467966955275305, 0.27490528901257827, 0.17106913420702183, 0.08243136708774874, 0.1381406833928439, 0.24041415672869454, 0.15240730898034188, 0.233978527868467, 0.08564138274279334, 0.09414464460625764, 0.15778736061146184, 0.13992764476326205, 0.09062892156502894, 0.14957518917658638, 0.23944185325695624, 0.1582475802710941, 0.11558286440108093, 0.17485203041184336, 0.19528909586369994, 0.2022545817758768, 0.12766407862786325, 0.083000723633074, 0.19220133251961202, 0.18387472287060755, 0.11281229976204135, 0.09386643211567595, 0.21061402595331594, 0.12098681797543842, 0.13136195439484813, 0.15316797300211846, 0.14994285009320707, 0.14716129209245407, 0.14206933548613904, 0.1367068425902436, 0.16381714673292253, 0.08333050150183902, 0.14718896318827906, 0.08519448535216433, 0.17873024327620385, 0.07615893793803069, 0.14433565339253795, 0.14069448345370833, 0.11995349560053119], [0.06441008329631821, 0.01674794223940661, 0.058746705537722, 0.010865095612262527, 0.09007006808514557, 0.030937960949696364, 0.04274679453022057, 0.06383191290942412, 0.039071104669522856, 0.04702516959138936, 0.03814428766828872, 0.03951575359209411, 0.02879334185572882, 0.02163201705702851, 0.025107074236016602, 0.009661548500580174, 0.056423681803167834, 0.0611689759628667, 0.04451666447904803, 0.06867052806961922, 0.044189211687133204, 0.04923470889128024, 0.041840493363598665, 0.01631236188263903, 0.05814917993942096, 0.05449033252173855, 0.11399693216287321, 0.03488901153867764, 0.0752817212994541, 0.05377329337681013, 0.0168037440838112, 0.02494670713560716, 0.04497565073712219, 0.0666308649364979, 0.0200616727928601, 0.05243503353408268, 0.03434041980654001, 0.04160486003984848, 0.06228095258495981, 0.030213214960249684, 0.025038114831512494, 0.04550170416252748, 0.027707760793066798, 0.04120099763836592, 0.011093973955740372, 0.008630084846499226, 0.0995145685550186, 0.015953190177829278, 0.015531273956801143, 0.059831351973116405, 0.007874715449889342, 0.029228221242045684, 0.021305228846388, 0.02008020062930882, 0.041001247872989026, 0.014125200968626288, 0.04614740136950728, 0.0729146475092538, 0.02586396335954628, 0.03346326445499736, 0.05800909693202665, 0.04098052136419762, 0.08448151796455346, 0.07383576098589167, 0.04741570972386868, 0.04357824890664028, 0.02296182120429172, 0.027687752491704402, 0.030134497510810054, 0.012931887834002415, 0.027986932808773655, 0.032925034062035625, 0.01187423737944975, 0.07365352399046383, 0.047915176067861824, 0.02663701502305846, 0.04362558164904195, 0.01640489955823268, 0.029003280590498642, 0.055162762366836114, 0.05360023411471517, 0.04871543917444445, 0.027218889445066455, 0.02420559176243842, 0.0309475427944093, 0.019622949560383157, 0.06501524679122433, 0.061568138414933804, 0.03890482528555778, 0.03676656663658158, 0.009487265413026176, 0.05967983510345221, 0.07712610095979706, 0.00816021439424085, 0.05755813927539895, 0.054049916234948946, 0.006649916580382495, 0.021082777980594866, 0.14672554128112333, 0.07282368989000398, 0.021553858851773605, 0.006880768079070315, 0.028725472211297003, 0.07277704279629454, 0.03321482597159282, 0.054617920635087844, 0.01885649965955846, 0.020133437994386882, 0.055269367331939365, 0.047365561608345284, 0.06211655011640922, 0.04470873038254438, 0.03907234190152057, 0.0641520572225413, 0.10554883629083635, 0.03134218532772314, 0.020833514037451917, 0.0383300946334437, 0.1161910616041672, 0.05003633180392846, 0.021927516321621595, 0.057910114541769996, 0.014213040610024286, 0.07640381794302695, 0.0008077029574891523, 0.06891779826893922, 0.06312196007779529, 0.06689129652635706, 0.069649220714646, 0.05037646335099013, 0.05068621951185408, 0.013102002445638422, 0.023519560026245254, 0.005212252999040028, 0.046276621250135284, 0.04745175416070608, 0.08481988367894966, 0.011812732010448893, 0.047896770805480986, 0.03649945092958309, 0.0593689221498226, 0.05068495163633939, 0.04326040285729593, 0.044008131484471025, 0.04927728422767213, 0.05558866511790022, 0.023337579670272047, 0.014546525386732914, 0.009200382722361435, 0.03478124211992949, 0.07525568963178704, 0.07139958606492128, 0.010334369050519121, 0.02553373732934556, 0.04789638776151885, 0.05110330459090972, 0.017568368780156298, 0.00989130592995113, 0.05635900099972083, 0.06977875086088335, 0.014669802340288318, 0.05135322545444773, 0.0021371008986006343, 0.024907872223505573, 0.049963917342885855, 0.1315400851590018, 0.06722869696996867, 0.034557808746373465, 0.04974777329592936, 0.02515694081422783, 0.04606818404769705, 0.012104868149054388, 0.022680281976898833, 0.05336625937132105, 0.06222643010738877, 0.024329832071558605, 0.06313906299070486, 0.05743060478820436, 0.07836147902473327, 0.1736787667558078, 0.08932045105123713, 0.03353677442177169, 0.04393994582877044, 0.0145522499787471, 0.0330515266696532, 0.07785026855286091, 0.032895355815849, 0.027938201955910173, 0.0038362209518034494, 0.04189576277689588, 0.054639842241041126, 0.05009944978800993, 0.034806810304402344, 0.08649001664091503, 0.02176602498718327, 0.037739915818336515, 0.050650018026992205, 0.0201286441992007, 0.08127914020611395, 0.029992623772892742, 0.014540433072515074, 0.05010433359852722, 0.06849338555888784, 0.08784806070428702, 0.02297181673648377, 0.02883455355561549, 0.04153928291353007, 0.04007834941148758, 0.01282853012408821, 0.06544738932843171, 0.0548620498739183, 0.020431080389948144, 0.015092803533339213, 0.02324102577873536, 0.08793606888502838, 0.008844178650648364, 0.04892404491622602, 0.08229223019894093, 0.07967515127553094, 0.016102834920128508, 0.03218658659006319, 0.02776001756560178, 0.05459012696519495, 0.02696103574107251, 0.0325399523060168, 0.08764207498320649, 0.0348324129628318, 0.02414354247101132, 0.03393949918268669, 0.05610410439511461, 0.02968927210707578, 0.07640290629839705, 0.060496320121831475, 0.0774623063062468, 0.0059955711983474755, 0.04988444721206062, 0.021553035307255004, 0.025473534309815977, 0.02818274296699993, 0.06678209835363012, 0.028333417139947418, 0.07550034747128526, 0.0435635591706922, 0.024929123502525113, 0.024806352166999734, 0.04202099133943839, 0.09390489739035407, 0.06898128397522435, 0.026439534793157252, 0.0627373494658499, 0.05370570910013011, 0.021471540789089857, 0.02249896045654051, 0.0544882296103864, 0.0356850037050824, 0.02271619809400891, 0.061498052861181006, 0.011480934542393493, 0.02508302673607344, 0.020795403078438777, 0.03627651551317784, 0.025585940475725842, 0.07783053412793145, 0.027723955891786084, 0.02393816387461078, 0.03365487453617877, 0.056979087887391935, 0.0383788101645487, 0.02046171816125993, 0.020646180642107805, 0.05506137829093684, 0.03161465981975198, 0.026749507373859806, 0.0930805714620698, 0.12809011544431412, 0.05420237539276, 0.0673275146513216, 0.04335431757593348, 0.014638800677212497, 0.06816929972340023, 0.036277373531653036, 0.049354739547256506, 0.0685164141618917, 0.01917482259863567, 0.05372914372973385, 0.020843463604368513, 0.017892684442021193, 0.04663470223726285, 0.03707819588242039, 0.025564532148681825, 0.06081688578330702, 0.043822780341630986, 0.0631112923034497, 0.057438840233390374, 0.0633780900839596, 0.021860926044023326, 0.019868524790170695, 0.028656784768006014, 0.03529445974216346, 0.05151487383691054, 0.015984673518687487, 0.05657268590444038, 0.028632474882948785, 0.025641359276168292, 0.0568969326183921, 0.09738528845651497, 0.03197178319697419, 0.028404762908335657, 0.04308998276810012, 0.08065303952823724, 0.04570617685995756, 0.04845775784023347, 0.03158989028194018, 0.0068303973192439206, 0.07627448697964992, 0.04120548308316258, 0.053684017320554105, 0.035727023627729185, 0.021274018424352812, 0.0032284680797132637, 0.03006284147681248, 0.02695101531102292, 0.04505106060194873, 0.018795743141503587, 0.03208517187064694, 0.10348191574936914, 0.01527112773469379, 0.09077873771950122, 0.018523102025351217, 0.06065685384636445, 0.03661678112562626, 0.022653164379599116, 0.024881541781548052, 0.034095869219351205, 0.016964783426374197, 0.07051024991538256, 0.025167524318901763, 0.07431962211886722, 0.035516452870421836, 0.015784625936630034, 0.0021615455672520426, 0.08849771858583536, 0.0686913580002804, 0.03949578934078736, 0.03959701253822254, 0.08159334350737833, 0.07769263064068171, 0.04734407667250884, 0.013919935370194576, 0.0009606193141793953, 0.08511734029818928, 0.042732794273404345, 0.1207601632021608, 0.2304492527318578, 0.29248063302328514, 0.2534889486888724, 0.20069076649604306, 0.10497562632325197, 0.1501907714672627, 0.12175639926065361, 0.128875462819011, 0.23599807353269672, 0.21366592106078902, 0.10375866501201546, 0.11517383473654909, 0.11882320947704778, 0.23761546900195463, 0.18562981498337564, 0.17789488568180994, 0.16626297436173887, 0.1071568625047803, 0.12479991336623508, 0.26225457268376506, 0.18348129075621405, 0.24222915691714136, 0.09889296481325742, 0.15473440830265323, 0.16088529760318418, 0.23583906432313306, 0.16146104332179795, 0.22263429788572175, 0.15888976113450143, 0.07262318169758206, 0.10296618535874352, 0.12517164987061294, 0.23837279288038132, 0.11821999184546933, 0.12688685944604297, 0.17441295477892124, 0.15586883130092777, 0.18180323644511162, 0.058100031568638744, 0.14195420779287815, 0.18191321602752134, 0.19654454543225228, 0.10702882622999531, 0.10896348169133549, 0.10218207138560473, 0.15666461279315336, 0.13413963599070428, 0.15050298293992398, 0.2523879271240965, 0.17233782177490575, 0.12922812373407427, 0.16262391882558025, 0.12640042425764184, 0.08775416896828721, 0.19642716544049402, 0.1221337435286372, 0.13986352320399978, 0.07951133869468205, 0.11415420235284876, 0.1611352720928769, 0.0930139754388121, 0.17321289336729437, 0.1470251889118264, 0.14207180228925523, 0.34071435611094203, 0.1473207303112553, 0.1577284024848092, 0.1872107140239208, 0.06042886224965896, 0.26711947615108184, 0.11699608977763884, 0.12515186181952878, 0.1629634030283459, 0.14952626680174183, 0.12356808994926753, 0.16044894924327252, 0.08840208783024743, 0.04387824127690927, 0.17553591710184852, 0.2992176715164416, 0.08423483765293514, 0.179786816419613, 0.11530790012329818, 0.12487239294475126, 0.11734891157116621, 0.21896447625852403, 0.20074474505118786, 0.11988585769769647, 0.16425185566467626, 0.08951893677153895, 0.18205679622628998, 0.20765760072296668, 0.11089550181021614, 0.1580040562417238, 0.14749965780685026, 0.06078756759844481, 0.11000608139100576, 0.23733379379395517, 0.14077985629199014, 0.16296547146574145, 0.08670792269009737, 0.1188162150942991, 0.10552039910708705, 0.10865522323236351, 0.22563584569481113, 0.15690429106114373, 0.06895830133749593, 0.16653277520691195, 0.18412717948517493, 0.19925554673517906, 0.1676011614261135, 0.14515187411058336, 0.18410470246547656, 0.22228252563265063, 0.13168116791113732, 0.18573432469800596, 0.21518925625470378, 0.26439214185360943, 0.16077185530335675, 0.11592699875754696, 0.17497990580816425, 0.1292345741943967, 0.18168728137689252, 0.13028336388449516, 0.19386248693110483, 0.1384692585035678, 0.1525236930577986, 0.10886617320319338, 0.16727736670403712, 0.1886150910849533, 0.11663642681894765, 0.12552388943731785, 0.15412438781030718, 0.17867476318872746, 0.10621579243771492, 0.16039857130137183, 0.11769243305729282, 0.17034606978056893, 0.1297891912080588, 0.15440797823811733, 0.1460699385572826, 0.15505883121682754, 0.09063580869546822, 0.2155188732450047, 0.1274238181330504, 0.20822130353941073, 0.11289548924973897, 0.10539280716329814, 0.32474396630160274, 0.160555450786506, 0.19112379921059455, 0.13302511595670255, 0.19303109767215867, 0.13022652016051356, 0.0978421756336766, 0.10382964305820004, 0.17517869030275654, 0.12598993136517464, 0.25452158924552704, 0.11173125777033069, 0.24710545977277143, 0.09492544907956355, 0.08027764112358132, 0.15345304964050172, 0.3133185616424007, 0.2183292974387446, 0.19768381010620825, 0.19931677248208754, 0.2306260811465402, 0.18255913539999918, 0.07725982160698022, 0.07849155309339685, 0.12739729616911183, 0.19109079614281657, 0.14885751800912042], [0.02296758410070212, 0.07302129460919289, 0.04480413897263427, 0.06800934056481046, 0.0239992689626712, 0.021575734492451436, 0.02620525361459342, 0.061090294902603474, 0.03903235211187313, 0.05360506429907776, 0.024102395888598218, 0.015503225562673424, 0.05850994989516274, 0.0320434813658076, 0.004325419562988945, 0.05678162872490864, 0.02290114129502927, 0.013858454899051258, 0.04460054727631711, 0.017950575791239258, 0.057896535633312124, 0.07756713777780533, 0.1085874091293062, 0.03159725047167271, 0.07135818667349315, 0.044222735694699714, 0.04707941244686804, 0.05688610013514277, 0.007968590906520766, 0.0404876089023967, 0.05136866212612198, 0.028351445104025548, 0.11237041258643712, 0.04805443553073753, 0.04881146829575301, 0.10333576149517491, 0.007721836858939741, 0.01409392447150763, 0.018110682421754447, 0.05117166644683288, 0.012778319763920963, 0.005489459041611202, 0.019566902567842798, 0.05271891890574367, 0.07041267329646696, 0.0031877619978566206, 0.0033867169470120704, 0.044577771482328256, 0.014710700901735936, 0.0354129467309723, 0.019983303913426016, 0.035131892054191524, 0.041130686088675456, 0.03186569534121983, 0.1149903183742877, 0.05023624627820907, 0.010614467075004453, 0.03650029745673941, 0.04535356957104899, 0.045619195237034754, 0.044577219899022774, 0.01170913681327816, 0.07129268615596718, 0.07328890444290254, 0.06714255804376257, 0.03832786914802367, 0.016135950985875343, 0.10565529186879435, 0.03783770694187091, 0.015497516292417723, 0.047818032288623434, 0.10407235503437058, 0.01235792326981262, 0.018709644434913512, 0.08107076429070965, 0.08926198322085604, 0.054775125707589814, 0.024196760683891275, 0.053368565295973135, 0.009406772554822026, 0.017006458609455058, 0.013845357668375777, 0.051231589844270106, 0.014230403035218197, 0.028287792773616892, 0.06917886571177552, 0.029556897859419548, 0.012544223404068862, 0.025307904185366728, 0.045466923770765146, 0.01761750949005927, 0.10766912251710893, 0.013536896196103865, 0.04848895294051017, 0.03181666379884607, 0.005847421285110496, 0.03282741913872381, 0.018666460058621822, 0.04464753144871324, 0.0429932258632635, 0.030673842561701616, 0.06279829942110567, 0.054613481155566634, 0.12746303417389432, 0.05756462804011761, 0.056674476006939534, 0.028759327551890767, 0.009051756877001495, 0.056444829660317594, 0.08227847125982085, 0.04983066017889688, 0.02096139326421244, 0.012406989286142974, 0.0428534492910389, 0.007070811510446572, 0.033835023942012946, 0.039431813338230697, 0.049239891476087996, 0.09901626666467037, 0.03763306187465787, 0.09061894710025481, 0.0415117803570484, 0.08926602816509624, 0.07200994363595402, 0.020596361944391843, 0.04516811117589955, 0.01824100355377361, 0.042046030923243494, 0.05777929353738024, 0.015825832848467173, 0.018283462061757044, 0.04620648207022779, 0.010178011462783382, 0.04166085723667376, 0.08509706195083358, 0.08170300133285985, 0.017168072517961264, 0.04915025535850756, 0.038417972579237916, 0.07981471717357635, 0.006249984209951495, 0.038152147730391835, 0.021419971580466917, 0.04190474898824769, 0.017580769828430588, 0.06622231024647914, 0.09398555112702232, 0.07102733628163416, 0.04006110860275165, 0.0471968652169791, 0.013928058775021665, 0.10307022775974005, 0.03511380088785964, 0.030057718263818856, 0.09663996917586173, 0.0194740699483983, 0.06681726178935458, 0.012134803992305553, 0.02802881866603369, 0.037138326123597167, 0.056900345540094766, 0.03114649774356475, 0.04883548898261882, 0.031169664242394993, 0.008999026087563365, 0.06935100566836135, 0.024195877767558542, 0.03464675538482205, 0.03831744652181383, 0.08689661780672689, 0.049625808267944285, 0.04731654730294982, 0.03483196863183572, 0.01214930029105275, 0.05652018206854982, 0.07182883278977487, 0.0256589716375475, 0.0065474341259217795, 0.009988045597809457, 0.04098887938345152, 0.009228883108364479, 0.022608124155310855, 0.03360040185432281, 0.05126864168672793, 0.050500653864395235, 0.037287866486416715, 0.1067644109829299, 0.033224126278993585, 0.056536783193868984, 0.06486826516207188, 0.024984199478621447, 0.030648385459977775, 0.056825996707043344, 0.03589617967184994, 0.05275065792844661, 0.06038831704626642, 0.021896968565640912, 0.0489443730592968, 0.03327936504877383, 0.007093581079971046, 0.07984057264102083, 0.03809298275999966, 0.03382637480934782, 0.008451548055745661, 0.019263028047017513, 0.03995967090069767, 0.064552184945393, 0.03916892260613461, 0.04097159643987975, 0.021330865978774045, 0.06382230999729326, 0.03146286524321524, 0.025010560564095938, 0.03764827255039446, 0.01026335269993832, 0.07641459680012158, 0.055418647224864656, 0.026981338986285755, 0.03534826975796492, 0.03711219486449996, 0.023154517215105797, 0.021755680884985674, 0.012908000254913444, 0.00936607126101491, 0.035517487089119615, 0.03866230100092869, 0.014210133306351642, 0.021468112545628703, 0.018625185156481403, 0.0031284651166999774, 0.041851172629263134, 0.08984535917519562, 0.024698270567422433, 0.01694561399128889, 0.0227062983228074, 0.019394088453883608, 0.029117301286708926, 0.02380886163953091, 0.022207988771579923, 0.047957111720836935, 0.042438746745427774, 0.01628698905058686, 0.04447272933659054, 0.07859520478955201, 0.08908003733883943, 0.06789374555791579, 0.02330319572901053, 0.07169119743329865, 0.0483876607951618, 0.03919388175070767, 0.02201929940060983, 0.05319334183549208, 0.007249473269292785, 0.10534144096797514, 0.0858105579391122, 0.013664061045874993, 0.038869244331914576, 0.04298585992787154, 0.04522090995564096, 0.06088432450328143, 0.07957365994732227, 0.0668730329902422, 0.0725883093752688, 0.04006925211738675, 0.015544704435723684, 0.0495105350179778, 0.02507514177611278, 0.027202943324922558, 0.0718560442328453, 0.023452044697478417, 0.04236802533869782, 0.045517830313333583, 0.043812733098504045, 0.026382172044606942, 0.04360164140140818, 0.023377151942000757, 0.05010252563102592, 0.014994005004184381, 0.03314709996864681, 0.12337030136897681, 0.006087009537769783, 0.05410220173578109, 0.060644876061668324, 0.040974580352344823, 0.033071659460303285, 0.04411011310895124, 0.049435266879417246, 0.14203112302047594, 0.0370475217219322, 0.017047312163237124, 0.07118959370399676, 0.054131328398662235, 0.023310550173083623, 0.030313840609103925, 0.11992257629190722, 0.015107471244259468, 0.035647147470304084, 0.020502495106249567, 0.011348250986737831, 0.05047561428059013, 0.05100150682753132, 0.03947960190294732, 0.02197762038708935, 0.06621948338203854, 0.08370227631061308, 0.027007947135115826, 0.04746167116888589, 0.0429639996089522, 0.04152771881631306, 0.06971222378553883, 0.023794154666604537, 0.0155994548244522, 0.025712662909720695, 0.0757596146074995, 0.06647311977200931, 0.02110684846317576, 0.03164346664092474, 0.01875137324414907, 0.029681433112390583, 0.0495582661261001, 0.02042468738622002, 0.05644019865881532, 0.04111750171549859, 0.06050091281893754, 0.01469843679167811, 0.02408719478896068, 0.06484086219702037, 0.04934036007691776, 0.022816308548734076, 0.05270573070212718, 0.03885053263436403, 0.01246046030803794, 0.03434724564994535, 0.06252041251789178, 0.043312247857571616, 0.04307525472775583, 0.030724509701793714, 0.02660824842150173, 0.03494324290283746, 0.041625260961272066, 0.03654384572479514, 0.009890775414063566, 0.03960889456192813, 0.037865676811986396, 0.061663956862063184, 0.046839669061404084, 0.032714294765384934, 0.033712587769954436, 0.04207347985357047, 0.05802460638205371, 0.0690554949124494, 0.025368099544017066, 0.10168000034266904, 0.1312302638806643, 0.14901945367455482, 0.2545849600386235, 0.1305380881193184, 0.20450490376641675, 0.13292794536438682, 0.12830291934792074, 0.13672938089697592, 0.09728653206219597, 0.24625729318828354, 0.1163504921620892, 0.16970030362567595, 0.16637007345355329, 0.08766269807012812, 0.16097018014519446, 0.10128882818765218, 0.08518500884454097, 0.14001836489525535, 0.15116250803393705, 0.16619523686747398, 0.15197442333784797, 0.24414054628822113, 0.15259945915350992, 0.14361600571822736, 0.1048937545067841, 0.148186654813828, 0.20420234500160142, 0.09381832179403114, 0.13774008069547916, 0.12294532175386146, 0.10101104470630808, 0.2186830768421773, 0.1289615864234586, 0.15167534261220886, 0.1659866464474509, 0.09603259934773369, 0.1515312567954102, 0.08327013377340571, 0.19181314044662062, 0.09970722434621665, 0.08132155849448136, 0.1886810972205093, 0.24286805892423277, 0.1441516237513673, 0.12693893044225632, 0.13270720478988465, 0.2071952666606634, 0.09982144805572687, 0.14640418271864616, 0.0958663352855271, 0.06788602339163904, 0.1722750485303902, 0.10627225311773439, 0.2438294686256878, 0.16242896477060934, 0.15317129782370983, 0.09467638623450073, 0.11787609497625982, 0.1448810620293502, 0.12101144770220404, 0.15744689581615312, 0.17849684692919257, 0.14620285481214523, 0.20946420458776338, 0.1875100092541787, 0.14190170012654799, 0.2130166002579274, 0.1971399183234861, 0.20369427549021862, 0.12208444577070976, 0.1916597543224212, 0.1205765012831938, 0.09636069948394453, 0.29423414699492917, 0.2071912063946647, 0.24588662920699966, 0.1037318978999411, 0.24173216503714365, 0.2249012286624601, 0.11714148560478804, 0.12154618473423105, 0.11825554598603519, 0.09078851300141505, 0.15147439774967011, 0.1715136797077233, 0.17377848076003213, 0.14728611845883632, 0.1355563011020422, 0.16314092092216015, 0.11028839245198235, 0.2680085671524848, 0.16210463378698597, 0.13884664873682684, 0.1597988470307281, 0.1341476952356677, 0.12103653708172422, 0.1253626585727738, 0.261690364249291, 0.10982304766413667, 0.09650506875327519, 0.11303959804917536, 0.08956467222061851, 0.23197237342115373, 0.0874793349254516, 0.2063293268363322, 0.21295183518480873, 0.11338541013819557, 0.1694679338364832, 0.19338355940436164, 0.09792276042243166, 0.2095632903998898, 0.06302906425609704, 0.14704464754510313, 0.16865016562083077, 0.09736441256057832, 0.12705631043401458, 0.10807168639955983, 0.16462449615280475, 0.18734781311885004, 0.15615991406863736, 0.15763481718397912, 0.17760142804153506, 0.11874198883531556, 0.20528825931251052, 0.1000319766781984, 0.09165095180393228, 0.1608165029075838, 0.3403887993866398, 0.11601109222899522, 0.09552335006094749, 0.139492767292165, 0.19056057136866356, 0.16834883259669428, 0.12136075315215897, 0.14956892257736576, 0.1477241522121814, 0.15087600647201463, 0.10700345339794314, 0.18124350196411534, 0.1751371989807775, 0.12230891719340317, 0.07404891728994346, 0.110595409848517, 0.12098660347081962, 0.15838656394231707, 0.1891226396565476, 0.15387412220720323, 0.08465797865703222, 0.18598664341674698, 0.18568005502944995, 0.20722621661280433, 0.12437717838873788, 0.10714192379025683, 0.15670694681184907, 0.07383946119056595, 0.16303944491570996, 0.12874319007800472, 0.1737337105817372, 0.11945553078886964, 0.17872769986429524, 0.1083757007314313, 0.08161788130359304, 0.15247280949786787, 0.07860103471865577, 0.09480095213098873, 0.150300138179333, 0.110531265306617, 0.07406681310385466, 0.19818817175203757, 0.1886858776091568, 0.1365411530939802, 0.17882741386851958, 0.15092295234001454, 0.1395398510559913, 0.21609939935226596], [0.029114259917649533, 0.09422489997720528, 0.022350054031478304, 0.013210966961548455, 0.0671025835758736, 0.04211037464800381, 0.07356478036531518, 0.07010238470449563, 0.06057837962984078, 0.015455277077102614, 0.08011691587706728, 0.0469977589654586, 0.055064706942967834, 0.08501432445501128, 0.021499167834859223, 0.007350492974623077, 0.043544261415879575, 0.021471441197659702, 0.025749889037181294, 0.06454238668084145, 0.06790176649848301, 0.028633804045497414, 0.04033234969322239, 0.0756025129568673, 0.016507015248099645, 0.1299282668098327, 0.04613695193022009, 0.03877980739719445, 0.0732837793146891, 0.04929814863228991, 0.025511951703998833, 0.015954288556390715, 0.03328896413046507, 0.006986242585680298, 0.044325414459191026, 0.044676554689724604, 0.026909638902232535, 0.058064891115552, 0.02836756550917222, 0.03365250732449274, 0.022971732466812098, 0.03288088824539896, 0.03395816108452217, 0.024702210174573046, 0.10853368338317641, 0.06562707525107168, 0.05914800537509784, 0.08164598140865564, 0.03735355469548414, 0.03111525093235316, 0.08365516956414908, 0.06891375332469903, 0.07059045166017548, 0.025333041445382183, 0.027127782438671397, 0.06266564746657688, 0.0464867017111711, 0.040368819308857766, 0.047484420149797396, 0.009351417914243236, 0.04834338857401763, 0.0825558870189613, 0.060451281812763026, 0.00698020437642211, 0.03300860276325576, 0.015461266927060582, 0.06244076235640434, 0.06669551509642793, 0.027256060031152544, 0.0349371295212017, 0.010716161416513065, 0.013956067907143266, 0.0390039800455974, 0.03997828300681807, 0.04830049148069755, 0.06688728988651307, 0.00651095254016259, 0.06149112359590589, 0.01405861835190726, 0.07262885840910097, 0.048007857384941274, 0.01805567730879111, 0.05546649324617559, 0.054354198697593906, 0.05646876990795136, 0.02941323530619904, 0.030162312248120868, 0.10866355060810044, 0.005462247119735806, 0.07448833766243151, 0.08822935032508067, 0.07666261776560739, 0.048362092610688946, 0.0012739201878092343, 0.014045756693268496, 0.05874502014428858, 0.021442452430604927, 0.05562200143392529, 0.021040206474642602, 0.05686653424955665, 0.03151349982457056, 0.07765755913550816, 0.01702067145567027, 0.03243965224453038, 0.04493350440996789, 0.04025679427169023, 0.02956105771684839, 0.02005507294539242, 0.05561188907332479, 0.022183359044814305, 0.03131323869550421, 0.03779635351571826, 0.03780683359852241, 0.05891794534099679, 0.02186675214268748, 0.02448274896690442, 0.05071629612376133, 0.028734412457373355, 0.028150161247580286, 0.03884769044816494, 0.02711795161538307, 0.043661162602685155, 0.01332327162080835, 0.03866965544500178, 0.06704862034248729, 0.12728468890512182, 0.03476959758348042, 0.019914938227063226, 0.04177377476627308, 0.09142949876766052, 0.02741116027708256, 0.016598495722357786, 0.03716772474769143, 0.08831370426642318, 0.04885163045518341, 0.006796767495782867, 0.03258582182048309, 0.07399568184008522, 0.05769650624584287, 0.03036397531808865, 0.02376450323349526, 0.049160980589447484, 0.07227950699387059, 0.029038804087547526, 0.006180228074006136, 0.06568299966954416, 0.05018624371939129, 0.03730104702915396, 0.05202090172397514, 0.03946083657924206, 0.03150603429774844, 0.03160949638714233, 0.02546854133176948, 0.03010440557714432, 0.02354650716898182, 0.03573071617152422, 0.06087949814935846, 0.03240952583690805, 0.006136958949237822, 0.010356192022652156, 0.02868181477571207, 0.03021571049166303, 0.004181457756673016, 0.002686078547530117, 0.0650678234054677, 0.023999634769655043, 0.06652066318859017, 0.01765668531128716, 0.09992783468577171, 0.08281884669897058, 0.04020924702466976, 0.03817425702788657, 0.040893547402154055, 0.014972011577488195, 0.01717521054219575, 0.028627041404345827, 0.015146601100211904, 0.014344228379007791, 0.04966927609676796, 0.007173211610455427, 0.03731527328190785, 0.012558906436747602, 0.01201368549147681, 0.028394160251463615, 0.0672269502895013, 0.045593787931025996, 0.03856244910087797, 0.05084449327701042, 0.010372399570300214, 0.03610418403461095, 0.009608991996144817, 0.04021478200992269, 0.026917949040991165, 0.09909950211764344, 0.025886132028855147, 0.05946601996378553, 0.034024975442838286, 0.04530977615485749, 0.04149503750546325, 0.04937424414580868, 0.02718541714843483, 0.03781450596908408, 0.019855553006392815, 0.05605534289873416, 0.06034844600024724, 0.07831558269718963, 0.04653284701729014, 0.048691778548903046, 0.03239792343529482, 0.019383491542670998, 0.04216927148762249, 0.07764812093228102, 0.01800163555139255, 0.03401932554439672, 0.028784482048884518, 0.0455068446124994, 0.054634958430523836, 0.051142467005598935, 0.03410506993532181, 0.029768523902842597, 0.1063226004161181, 0.0647977008033664, 0.12266281151002455, 0.05531122637612205, 0.05578908521021086, 0.025504007372224045, 0.08719240435429158, 0.09112628882810955, 0.031122436837082913, 0.07367579416642267, 0.03952619154006243, 0.06970188925944029, 0.05924864251527095, 0.016868499580830816, 0.06341820627811455, 0.10410800110548736, 0.020953284223533927, 0.0845992886611531, 0.02346265310000989, 0.05886331178067673, 0.04266928941492112, 0.03342890541159338, 0.05961834505620984, 0.06929344182173092, 0.04691919281838402, 0.029892609079158115, 0.014165267367066156, 0.014405634156578492, 0.03333735407420224, 0.06956439945966968, 0.030964436948359497, 0.03981797910866238, 0.03064299220099084, 0.07585388938746146, 0.01931338109106066, 0.11226566538455025, 0.04070538471663191, 0.06451431721929582, 0.049513924957042744, 0.036723776795570894, 0.036654334755674485, 0.03511579271646277, 0.012940677735323628, 0.047527822861147505, 0.027694760280991756, 0.006781594645637538, 0.05778436120899935, 0.08321818535126026, 0.03996579577365229, 0.036115250174677184, 0.0157632865574992, 0.07431614407969099, 0.02183949281912177, 0.014046157931818837, 0.03738360449431404, 0.033035354553571636, 0.0800335348673886, 0.03863465288774141, 0.014919445496953785, 0.025544370629734574, 0.04995703787332581, 0.045277477887969826, 0.046499526023023555, 0.038783124557906584, 0.012672330541986854, 0.030515609016161294, 0.05960298882376763, 0.03183242031222871, 0.07384223442885184, 0.043629894724055644, 0.029137889899673964, 0.015115619546944096, 0.039171201717709346, 0.013304742826749722, 0.06102522339431509, 0.03736665479898934, 0.02548312190018835, 0.03868176346464503, 0.04230676894827236, 0.013953004513056049, 0.04559933057715816, 0.04560841637994013, 0.025157787341384158, 0.05460027379975204, 0.022337771726832278, 0.06447852559147343, 0.05504642042421526, 0.007284930691258201, 0.012178154992720774, 0.00654139208622397, 0.036177889353805975, 0.041666510965554945, 0.05494729247725299, 0.05148770452867593, 0.026068361363403743, 0.05104888553520845, 0.03079475038835118, 0.03798443193156873, 0.007324104118461331, 0.09038646239787342, 0.03852094245714046, 0.03200727413528629, 0.018943835598146243, 0.012243755101676912, 0.07964476056757473, 0.018191424258533987, 0.045484451862472686, 0.02958864071256211, 0.01260903444246299, 0.00966084274207993, 0.07165607996284962, 0.0387200218955836, 0.0981402910885311, 0.09708335022291831, 0.0666583521712211, 0.07576261767216268, 0.05057509845843719, 0.033024479935486475, 0.00342119234001955, 0.030486258272562298, 0.03210595775125248, 0.012314933288331715, 0.032673799357707464, 0.03596509311107859, 0.02196424066149179, 0.03952657075358495, 0.011173418231098162, 0.03191105349199667, 0.03779156163575188, 0.04866499228463058, 0.012465744399495665, 0.03246486802855807, 0.06170134578320769, 0.15086253864630578, 0.18467166881647804, 0.12119394516752613, 0.13370535606818815, 0.11043007275269878, 0.16800043113049, 0.11835257102164531, 0.18467519282092973, 0.12324951994683474, 0.18469670456984352, 0.17687690804802603, 0.09754271186407536, 0.13293906896104737, 0.12900425752084102, 0.07201074802827451, 0.233496229554857, 0.24575654747745684, 0.09559156252972542, 0.13492113760402127, 0.14143210355072253, 0.18282807822669708, 0.1325035632978524, 0.12933390515465892, 0.13755058118652913, 0.2691738788158663, 0.10315424462239589, 0.12523571014284127, 0.1587136988077433, 0.21965913414474458, 0.13144879812194457, 0.08835951632429516, 0.12323441269296793, 0.10653710503491665, 0.12456923663135498, 0.16372613548751802, 0.2953084474129062, 0.11369798167218124, 0.09563059470946751, 0.19310767582106977, 0.3010940966346572, 0.2746502430208268, 0.1131041792611922, 0.15560241656437998, 0.27058629980010374, 0.11446085202717975, 0.28603142908503937, 0.17003004319004475, 0.08269637222251586, 0.15670058828207756, 0.2513513488755111, 0.2644824482981236, 0.20866071625101953, 0.11986448384460904, 0.13635715409632654, 0.1463307761737416, 0.1991703117927236, 0.16659490493757112, 0.2120768708447295, 0.13458176065356503, 0.18377338475998373, 0.1429052906291139, 0.12145932568537614, 0.09120621478124973, 0.09800896829655094, 0.11061015704105939, 0.19289625087572684, 0.1296594925224781, 0.14884964262525882, 0.15151238038895593, 0.07660272501168713, 0.17488875666693335, 0.10677544264903954, 0.15182609339394879, 0.12653574602858675, 0.1585946640660686, 0.10096760752100138, 0.15005532712224992, 0.15776252404095667, 0.1444941569840716, 0.1414551321537264, 0.2270702534024754, 0.17359025295703642, 0.16851049247047595, 0.12473402214386772, 0.16218781561380433, 0.12354431058009788, 0.2546819774133544, 0.10323955617364376, 0.17092981345711217, 0.18770237393196554, 0.11520777243159472, 0.11628754271735108, 0.17275883305457332, 0.18870006555751448, 0.2193097061207218, 0.14733062816723702, 0.15464192616843409, 0.10979673254393763, 0.14749662409867012, 0.18488761368057421, 0.15207312610601226, 0.03680346143101493, 0.13699395702250544, 0.13784034628300898, 0.1221025101239643, 0.15102334050161226, 0.20561547078672918, 0.1641038934429807, 0.17854734744516113, 0.1575595260627808, 0.20948392369093435, 0.08074062636062022, 0.10118842470429598, 0.11934858491464008, 0.12935959974363928, 0.23656744539978045, 0.14944881531259707, 0.21729209099806127, 0.12663208924594427, 0.17382479843593415, 0.10291326400493422, 0.14223502498240242, 0.18289820591528572, 0.22181105980228996, 0.21465711626074008, 0.13562947782056947, 0.11844459350310987, 0.06615571422322143, 0.1496162514893278, 0.1394316641193244, 0.07450541376226372, 0.17428321012806508, 0.19827504612265096, 0.1776433330509932, 0.1062636805938617, 0.19914166010435552, 0.1532427738270452, 0.12191901674434064, 0.1076768140398687, 0.09677663926155337, 0.17252862363332705, 0.15040539866012914, 0.19489704270757016, 0.08428739128454078, 0.19227530596958053, 0.07625709678376875, 0.09654323525366285, 0.1946694686287834, 0.14126834459602833, 0.09684716531586263, 0.12569514073191151, 0.11106211061198866, 0.1569669264098329, 0.18191707711065971, 0.11582966728676712, 0.23317048896945294, 0.14447615391785099, 0.14269047957514563, 0.149747543637791, 0.12158758412565916, 0.10139334556316176, 0.10596420916338121, 0.12094744871700965, 0.287041163612758, 0.10848003424583905, 0.1284110986237084, 0.1676958192500376, 0.2566085200035765, 0.21939419029701143, 0.08383879317871987, 0.0770990657169492, 0.09667367704453007, 0.1006455518185131, 0.06888471859236879, 0.19008745078838643], [0.05294696412860386, 0.050105815978660706, 0.017630774302468184, 0.09904252049783546, 0.08546709007914029, 0.008350038532948783, 0.024336010570667928, 0.02182668957468723, 0.07617381536552022, 0.05942116934625853, 0.04437462028656756, 0.006367299084236185, 0.10719213319281418, 0.02005455583604353, 0.015440701296733273, 0.04901230207554275, 0.008983125932694925, 0.04457713945979073, 0.02628435793843481, 0.020711932053428986, 0.07161668772178312, 0.06795107191728969, 0.016080551337631, 0.04463520126357194, 0.0742704009697322, 0.07410710932867182, 0.023358467057527556, 0.048465663867612044, 0.026900298375215743, 0.083174005060667, 0.003147167477553951, 0.0429932986416163, 0.03302973146820742, 0.019045932135815104, 0.018164276017717296, 0.05163375536100038, 0.007513774560779454, 0.007955685197826355, 0.013261724116971657, 0.045742297905587384, 0.0395368171795722, 0.03638249994706243, 0.048135119910922744, 0.10128174953523184, 0.09960782443804127, 0.01006269895081078, 0.03799411528293164, 0.02464876596575543, 0.026315748391132203, 0.056513850351855646, 0.07252437167710836, 0.016878868580885956, 0.08371906895791331, 0.09673199931820554, 0.03922694610551961, 0.03900666135333238, 0.025010290518102628, 0.0548160539549445, 0.071320288303879, 0.05430858582258225, 0.008666695230790685, 0.029462682451271725, 0.07006119215680708, 0.030351955398556688, 0.03388256352815417, 0.03929424692966765, 0.06900808173081568, 0.031237606665179617, 0.048707747651684674, 0.08098762842916674, 0.005701450892018095, 0.060111253687571135, 0.03313200803653848, 0.06357000276987111, 0.05398589043667721, 0.03745970766871207, 0.03528670310193012, 0.09858351125712357, 0.01009905748369713, 0.031575738722758914, 0.07231744366788095, 0.05245695897047559, 0.051829885360935045, 0.03607427596204704, 0.005556388791920918, 0.011694913433353988, 0.05834449405571627, 0.07888555977373354, 0.0773493772853286, 0.017371599096804857, 0.02222508019317062, 0.027589187619366476, 0.024772805176795493, 0.0669972388254058, 0.03984296506631278, 0.03968392138279254, 0.008702897673262464, 0.02207614312459144, 0.04767963084422293, 0.01785120652658084, 0.08680873220005343, 0.1069229452179805, 0.015221635581955556, 0.062415661485565294, 0.029016093411032232, 0.010482322653725503, 0.053826015547759114, 0.004934300020742681, 0.026940786122013966, 0.019932217340195374, 0.029669606630059502, 0.08003181883043821, 0.020576294271215316, 0.03674277960653267, 0.02509010538849379, 0.044684487530180526, 0.017657997236857494, 0.007658095949614842, 0.06269344113646977, 0.04887963096881586, 0.05893375739575394, 0.020895994253336422, 0.042469267688331105, 0.05382444889795396, 0.052086877216014175, 0.04827414188654192, 0.07075680765293299, 0.03581759437257725, 0.03729097680338929, 0.02860839482426884, 0.025452269624257763, 0.037246520721143296, 0.1309577970495147, 0.032206884089617, 0.03717567290990584, 0.03181183936014291, 0.06828654948021136, 0.02643237187106523, 0.038915638616609, 0.012451304599732883, 0.019751732770894325, 0.10689921947496553, 0.009648789306201283, 0.05166251813211749, 0.05155296372850576, 0.028049047217674317, 0.03123406350852982, 0.03823360202894096, 0.003296788040203073, 0.026008219630908103, 0.043869182287204656, 0.021289409130751606, 0.05054923533011348, 0.0246698257227939, 0.0362119879273157, 0.09989829433541145, 0.07228732875157749, 0.020908397216830524, 0.10334822574570295, 0.020725455420512347, 0.040069091238922654, 0.010725013562478127, 0.04318770494372134, 0.02912992450048126, 0.08740668680759207, 0.052508137474257144, 0.04530079760438493, 0.05300992889510048, 0.011572409270992203, 0.03996808254610627, 0.015379651750047362, 0.012040496653606816, 0.03476901535665797, 0.06601810184938293, 0.031522974416974096, 0.03802659358048151, 0.035106059569384784, 0.03655959266207872, 0.059527241880254406, 0.05291784129616234, 0.04195634117950836, 0.029112212547671892, 0.0311850396270353, 0.04968387773260475, 0.04607720856344508, 0.02535412418505838, 0.01809951669025806, 0.011561342173316067, 0.01991027275160436, 0.03297460378117619, 0.08495171208895984, 0.04199701661784803, 0.04565546183937019, 0.03351635817858962, 0.017668084699600455, 0.048648314550518997, 0.05171797140651653, 0.031392297054070144, 0.03881088758428251, 0.013992348873627283, 0.03245598906951566, 0.03306240128773836, 0.04574496006112426, 0.0077707415180010425, 0.0703663632814442, 0.03828670724385208, 0.042141707644106886, 0.05904474055334445, 0.022907599416230957, 0.011113863513474504, 0.03281580141535209, 0.03727223446232177, 0.018380056172909758, 0.023463082109247486, 0.02254782537479074, 0.04583595598477029, 0.01795032681266387, 0.07148337310119983, 0.027128538950496627, 0.03635292129230596, 0.009354904571908617, 0.05945265172950684, 0.04371602215894288, 0.046344389387917136, 0.017622994679597118, 0.017745840708695112, 0.04376869836461641, 0.02794564641531437, 0.04175525076026398, 0.008419791796064426, 0.02976432765623735, 0.02662855932759422, 0.033061815230476285, 0.06601665394320604, 0.039562002320082924, 0.00652217046139882, 0.037094720398947116, 0.017455518283250353, 0.019945365324195836, 0.03539055398094558, 0.05637637587384351, 0.08953153891789337, 0.10692751110200921, 0.035291847382341666, 0.11208501419112568, 0.06934906746591292, 0.025708784589604027, 0.07010779328524105, 0.018667005896267873, 0.04549239619424747, 0.00886986940918911, 0.032453081765843016, 0.03284065330761575, 0.04091577161283743, 0.0722674640917009, 0.04633183320683818, 0.07560090417222631, 0.010615598969912578, 0.027416907851734472, 0.0886763396462606, 0.00707819372520692, 0.013916114506672227, 0.03347597002322155, 0.029360631878878322, 0.0250532929485123, 0.017511950234972665, 0.047993857128125046, 0.04584725195121381, 0.06526339033077802, 0.031560470590428, 0.022406116345777147, 0.025986863014798973, 0.011169172188777839, 0.0512974504231205, 0.017338519420234427, 0.03031642615584837, 0.11808331409889845, 0.07853675994180864, 0.05470253887676424, 0.08590061923549061, 0.016778553197641047, 0.04249887315616493, 0.03896227804943919, 0.03267049368831419, 0.031481879545495875, 0.028686097207208796, 0.06868170529243446, 0.0460736692372349, 0.02447780769979281, 0.028514098976888967, 0.026563167977597446, 0.03685149897430693, 0.030454716517499862, 0.02560625329703814, 0.020091961994166338, 0.03223016933207551, 0.011257706097357217, 0.0292116507602435, 0.08558257017284633, 0.030864037295442917, 0.04905327245773328, 0.040165978378706405, 0.054702964055562214, 0.05870353265274918, 0.020170261925687234, 0.04965040735119293, 0.021986026286838517, 0.007214445335369918, 0.15472365242819633, 0.05062959412293089, 0.057854255240771084, 0.08679692678514027, 0.0028910606934298435, 0.028844953199187597, 0.05521230527289933, 0.014835356813555044, 0.005877116289470466, 0.06839094428165306, 0.05304915642726326, 0.026191902617293022, 0.02754629435648601, 0.02032315775361513, 0.020255420259350253, 0.027858829501295285, 0.033072333617676655, 0.1047127049476389, 0.05456741245824003, 0.035827047897562865, 0.03500881619871624, 0.015988402451658924, 0.02423187240868086, 0.04283767171023835, 0.023083677064747583, 0.049992446457186056, 0.041575549515865506, 0.05779626621534267, 0.023680804297328, 0.0587976044194112, 0.05526152642203435, 0.023736575498215617, 0.012209804000092611, 0.0329895501565789, 0.04831691640579412, 0.024078315829918272, 0.0454976630487269, 0.11332564761922245, 0.04500127254774974, 0.06839586256612694, 0.0373339313533037, 0.014664235753908515, 0.010218453244306147, 0.07603241851733578, 0.10046047263688619, 0.17022086037022455, 0.1150959465772875, 0.26849543135012355, 0.1651015544250127, 0.09046325505140329, 0.18458517748982678, 0.12240664702990364, 0.1091133744546002, 0.08760544831954664, 0.1653837812163176, 0.09033505023727495, 0.17849090208690013, 0.1744589966631705, 0.1791244568002801, 0.21745148325158706, 0.09691428993978808, 0.08657189611826213, 0.16843173863185992, 0.08424762366039139, 0.18188637230665455, 0.10253582780639972, 0.06877635545547932, 0.16793600313605803, 0.16383950117855303, 0.16185404642695383, 0.16634431757753895, 0.09917090917306562, 0.14540146555631392, 0.13425795060973014, 0.2546101949748493, 0.23535040747975153, 0.1352406115902047, 0.06939245868594417, 0.23968058157592054, 0.13841811447374283, 0.09067535415411958, 0.13275010571364435, 0.06409755006672875, 0.14101993292570114, 0.08893634222688214, 0.16933849562079678, 0.1056213848172657, 0.19832246696516392, 0.22617039120485707, 0.1539002611271797, 0.16451145221869792, 0.11860727227383083, 0.12254590649277934, 0.12997436998111586, 0.13891147509697946, 0.10271645601718657, 0.12393301593199854, 0.14799914713348114, 0.21970047224913875, 0.0999452478642906, 0.11727862300411349, 0.18454080567725245, 0.12027304619550706, 0.11131972299828646, 0.08056643328839734, 0.1347039057122123, 0.13720112251898936, 0.09967384589535576, 0.15701278443298033, 0.1404444936422571, 0.23434197530150416, 0.1276450106994279, 0.2974431667356722, 0.2444237996373446, 0.08678634711090596, 0.1672244913155033, 0.12920595314954558, 0.20723959250796228, 0.22440259735430443, 0.11761921803436934, 0.13037538636595974, 0.1608496285494297, 0.15513502632177648, 0.13358884941666357, 0.15135072051517426, 0.1455369252230852, 0.11097126790592748, 0.22767976827679143, 0.13022730157019632, 0.14598758410542242, 0.11394100774440075, 0.13971994300523113, 0.2174093790592686, 0.13983574485586536, 0.13041821068092702, 0.1113491714180958, 0.14609431547503318, 0.2656142665974556, 0.11070829290415972, 0.15139961224650184, 0.08126925767189072, 0.16276274927921836, 0.11873726207282274, 0.10518194146213994, 0.2966177836060524, 0.17213531409300145, 0.19512397327250053, 0.15716577219145914, 0.15178100145872564, 0.07535474480039651, 0.1656945830871982, 0.2023852304104836, 0.09997729332216325, 0.1044490787711355, 0.20900225356942226, 0.1328664131823086, 0.12411827897472728, 0.08474627029030554, 0.1304025518437547, 0.14831664461281993, 0.08045044757666127, 0.100084308144306, 0.1444050456367193, 0.2153603236881956, 0.10379209708903106, 0.14479153699451877, 0.1702382658878642, 0.10455414006907134, 0.17006405749388281, 0.08569656405597927, 0.15736752910719765, 0.15792383151429315, 0.10582747779065564, 0.1842924399722007, 0.12639714540132593, 0.2612626726829237, 0.37342459444076787, 0.10148539102726406, 0.16733321451371716, 0.1512379370509617, 0.19450563306529678, 0.10044069224668127, 0.10961866306681788, 0.1665021929769747, 0.11701062246556244, 0.13245903826769323, 0.10978704153169548, 0.14600088339178793, 0.12121652943953393, 0.14288500462087894, 0.1049622274454563, 0.09703388392564752, 0.11253204181670182, 0.19214091882590326, 0.10071765601394639, 0.1615398890909649, 0.11767474408712118, 0.15692283038891133, 0.11746147286988075, 0.22574804693220124, 0.19116329870397047, 0.14069837518036366, 0.22978298606411104, 0.10354044486678417, 0.16007615553755916, 0.1330258207575929, 0.21052178896723256, 0.13067979906355182, 0.14290380441854078, 0.24614935139975241, 0.1733028167678464, 0.18772299701888717, 0.08037360895785593, 0.23012495239175138, 0.10253059542587689, 0.16340344393205258, 0.22499862908115312, 0.1833526339502104, 0.12451274530781854, 0.1357271846744322], [0.008009316140575515, 0.025164335477916945, 0.018457046094080134, 0.04945024772877655, 0.02377748076293257, 0.020921118106813203, 0.032403037072189396, 0.020670088331004786, 0.057041558527177384, 0.011686993041826833, 0.0542920038494612, 0.05610950148454117, 0.010926895925114232, 0.04277685198992972, 0.015878106857980454, 0.06818523435222526, 0.006831314709533247, 0.026585336646906314, 0.02899650454280838, 0.030088390509087234, 0.043086600489914424, 0.04515315330917797, 0.10032633830222393, 0.017221917007719318, 0.015057010947906924, 0.03989079959630486, 0.057091982434353525, 0.06846285695510526, 0.01684137623787167, 0.02236239570793846, 0.054395406567040956, 0.026513284162407922, 0.03834584157072729, 0.03311939056842558, 0.0847352922503506, 0.019696539966389537, 0.020583859389467586, 0.0059348999075741786, 0.053658663640700044, 0.03709576993940338, 0.05510759637540868, 0.04639460645135372, 0.06800751727555068, 0.06340809008707443, 0.03175584982419687, 0.0022097013753673606, 0.024961885252606966, 0.06004206062625012, 0.055973934565460494, 0.032330335328175176, 0.06671495074706693, 0.027900251875361128, 0.11086059118350668, 0.05467251206057207, 0.02567820044444694, 0.045835714667074146, 0.04368404564898341, 0.02289143687624845, 0.049334825091664834, 0.04265451540930137, 0.0337232478834208, 0.07361094482363233, 0.0914488424877486, 0.07605908603797998, 0.030948042666779894, 0.008537844029976236, 0.030779093466398698, 0.05590049737703897, 0.01958584217655082, 0.04384143458258721, 0.030206530843110337, 0.06923469053881784, 0.033902094939783696, 0.06478692194627178, 0.07622596297052599, 0.04436073111250036, 0.059178625909431334, 0.04798896565672852, 0.026396438516976855, 0.03516368470304916, 0.027146589897212484, 0.053826689705132484, 0.059972894378006465, 0.06806082933420135, 0.06836919504548274, 0.05150644686974345, 0.08449317016188176, 0.031028288461628462, 0.05357940801449361, 0.026826202351179336, 0.010526384200690495, 0.021695043110559066, 0.0711151146359982, 0.017850666434594223, 0.03566618092478283, 0.06104395807450337, 0.050839574992536544, 0.0378925052110947, 0.061500688203640526, 0.06140038431171448, 0.04855310897372904, 0.020633886846142913, 0.03169283334676537, 0.04518021153466356, 0.03651949178968226, 0.02518693698690303, 0.04054116227874353, 0.0819505473238326, 0.015372554903038809, 0.06643025715264582, 0.0352912996294758, 0.029431901038474137, 0.02058654069720257, 0.04562052056914376, 0.007428055067711901, 0.022222688083627054, 0.021161382432065664, 0.013556463039299894, 0.012034781637691684, 0.07526089902967215, 0.03919482020841491, 0.020333925119390892, 0.07386442799601825, 0.07802070779425484, 0.07159691499245745, 0.05114518278729051, 0.02166597007383262, 0.02776209940953601, 0.06812673587832721, 0.035793205963507775, 0.05340541795557065, 0.029104053711278305, 0.06682126842919858, 0.015537280086127501, 0.04619036358030093, 0.061336963722902926, 0.0633837974389955, 0.035507278967528574, 0.06683097476319921, 0.008893325106210766, 0.07907648420622272, 0.052391220965693076, 0.05492306877708724, 0.008642062631195352, 0.04552374451210903, 0.07327274764857947, 0.03245618825237597, 0.07144796451733959, 0.11169464642842931, 0.020124223871877598, 0.023343175942558917, 0.05401772138993106, 0.026782966263952757, 0.013265714477447253, 0.02578379800392976, 0.01020333737195019, 0.0393085727738517, 0.019309927949741967, 0.017377356247555827, 0.04034465689572596, 0.02061465037836423, 0.08198099165794351, 0.05183673035653849, 0.06984995107256597, 0.09741354944004167, 0.01345343474719313, 0.03654450839084964, 0.0038864727285991035, 0.019105916820286263, 0.058564702199111064, 0.06535149810294952, 0.032889093047068, 0.032418883600903135, 0.017486056463131984, 0.04014066683368818, 0.06573756045151143, 0.03130407436871, 0.019293326824422807, 0.007196470039836582, 0.030426352112103375, 0.022488459306318435, 0.03488626894390872, 0.039519354205338225, 0.015101300406029389, 0.036261638085688316, 0.029405300550523306, 0.0607080131979479, 0.004371134902260477, 0.007485930616366527, 0.06516788214925798, 0.0064707831986578965, 0.07274148865572869, 0.05360169734265055, 0.014211789971487898, 0.06892108478613439, 0.02019683177012109, 0.02463567926878891, 0.016575520745508613, 0.04636092156532311, 0.03935738406594723, 0.05900424897610661, 0.05134930308427542, 0.042525586642084584, 0.05871869736321031, 0.020729483127774253, 0.0389157458689184, 0.045287640044285406, 0.015306683790479458, 0.05474958050575468, 0.03147957170562398, 0.04998415738584534, 0.009905238196464076, 0.03063263852269419, 0.0040136883316952135, 0.04082583289052691, 0.02585069854713736, 0.054912596355162324, 0.023292807576757286, 0.05452458048239351, 0.07956718650436209, 0.05198726663365961, 0.006827958765619945, 0.03292618319392204, 0.05650487946226232, 0.06499132186534905, 0.027919193399288965, 0.032884021545009266, 0.03935055439210227, 0.02981690235526091, 0.03862894936314514, 0.08498723558600872, 0.009402088884774958, 0.03516062418179166, 0.03144197977117954, 0.03612499098263441, 0.053725508642533136, 0.058359766018486796, 0.00949770048816478, 0.038585941187076034, 0.04660857480860526, 0.016087944086100307, 0.03419675150766008, 0.038020250372468464, 0.027816600819689133, 0.006315691571217031, 0.04018804171092568, 0.023017230428635113, 0.02361763651753145, 0.02785564449075009, 0.04939396324897966, 0.04926046859773417, 0.01605973864394811, 0.10946118603310279, 0.006871615243594974, 0.035832422004351695, 0.034159063812225096, 0.04542148709597607, 0.03347368325076757, 0.036128511156646476, 0.04445866013186113, 0.013660764952580775, 0.059736088939732125, 0.00847604180190472, 0.050504675825997714, 0.013196697616348825, 0.04718894003740242, 0.03049833564868858, 0.023101358374039975, 0.04418732711083947, 0.10621812900588398, 0.04490095716450484, 0.07931331262713479, 0.03004156146949578, 0.05297363547968769, 0.016666577956188592, 0.06937619463931169, 0.033234200335197875, 0.04962469361001446, 0.008992654151253162, 0.02463707929447053, 0.030067692728592988, 0.06523576520022846, 0.022797190824583657, 0.04421365372235737, 0.06595213401822314, 0.0316423328307968, 0.06433784120505856, 0.05162304162137932, 0.03591893248320107, 0.044910885664003516, 0.025876379729579055, 0.020955237747740843, 0.044608736756227674, 0.004300557137016327, 0.04988949956192125, 0.05816603387375513, 0.051664341421377276, 0.03193386184472231, 0.0791880878950319, 0.03697557074408378, 0.07068631990301995, 0.03204085942988675, 0.021335588910827236, 0.08533078005477306, 0.03350649096612488, 0.017447204314052098, 0.04983274776849055, 0.021322672668423866, 0.035114831276117794, 0.025286463299585928, 0.039330609292993625, 0.04418620096159078, 0.03190418934419511, 0.029758965040767388, 0.018394529489019228, 0.02153172082598171, 0.04438202452635573, 0.06250950342585003, 0.05623189169132421, 0.05059195239277137, 0.05590487556952623, 0.1263188205719475, 0.019403268102436297, 0.02957593897477754, 0.0849023990092739, 0.028929378003663117, 0.07352281406882309, 0.06394545480068173, 0.046501173112060756, 0.03598021951714351, 0.013501327691389429, 0.0381159883803658, 0.034199317902206414, 0.06612743791793624, 0.010847918005780348, 0.03189276314280447, 0.025125400974385204, 0.05739877766539013, 0.07493953280631574, 0.03064181625602707, 0.0564496445229217, 0.03356499710090218, 0.012460296556744124, 0.052231250315784454, 0.02703868641307758, 0.04286535429738222, 0.041088788740096555, 0.09683185121825627, 0.026863999214143525, 0.05023433105839838, 0.05056654891720222, 0.048778139640607183, 0.0808259915380228, 0.13373581572405754, 0.1368136352468883, 0.18804738928954448, 0.08080545272077284, 0.18204093820625739, 0.1757302429647215, 0.12604552636583968, 0.19091281859624773, 0.12874777128379192, 0.12732832527328886, 0.1223818334420362, 0.08390845355367468, 0.20021297277942782, 0.13721014703473738, 0.14766781410622984, 0.12139665203229075, 0.1203826044295584, 0.13298506488002118, 0.12312549031189374, 0.11761773182379624, 0.1468283196370448, 0.17694793972036532, 0.0945562023609396, 0.14283772167419234, 0.12132787265844884, 0.15908834644623343, 0.19394761462125087, 0.13078674493778136, 0.12775145095562743, 0.1486026558784708, 0.06411730747429595, 0.08418032283624334, 0.0935263580252086, 0.10092382559612875, 0.06129187944855902, 0.099230395900386, 0.20934846402416307, 0.13860854860996047, 0.10489550884813072, 0.1802613619234293, 0.11871722121272357, 0.1618263906528873, 0.15764964864619319, 0.19943036799949987, 0.10323093768449561, 0.07511985458193288, 0.18451399259990264, 0.11473503489527972, 0.12939776624402693, 0.09804147340717817, 0.16798769874918848, 0.264189220484226, 0.1424639473759359, 0.1713822803069507, 0.12032982097157549, 0.09796883295019788, 0.10651545539017647, 0.244399422719594, 0.13317755213187588, 0.15262734475395373, 0.1802607950183653, 0.1452666953686745, 0.09972535764738437, 0.07599291902395987, 0.08783027980356448, 0.09447108999255205, 0.11276880895057995, 0.09424119466735471, 0.11143007030289982, 0.13708951883018017, 0.14831862111966457, 0.13468375759980372, 0.15040124646357952, 0.18235354804463927, 0.10449212525160083, 0.24954292172145462, 0.14880893271296255, 0.28726265495342596, 0.13518278727368002, 0.1729465705612975, 0.1772950694806153, 0.15016169076965702, 0.12629835836348996, 0.1780693392239271, 0.16998185625960752, 0.16502186595912904, 0.15438494963511346, 0.08512066511978066, 0.0935967998098462, 0.1464871806843627, 0.16247051737962231, 0.19748821253738097, 0.1647443429476792, 0.17175539576959226, 0.12252139167920237, 0.12115272963719985, 0.17766401742494878, 0.16831201441105337, 0.16787027279215475, 0.1050224879215802, 0.11271038708547432, 0.13338264919096424, 0.07935534787154006, 0.13529233784685213, 0.17833054456258976, 0.15986044049984025, 0.22887210752214157, 0.13205485027884284, 0.14562896302630826, 0.1425257093843914, 0.14603521945255418, 0.1350489823568252, 0.12727788604435422, 0.09051939397449456, 0.11496118405052733, 0.16150821901617513, 0.06269309639690385, 0.24354085266109438, 0.26584669767368224, 0.17346991586589044, 0.12304007150833646, 0.18452465654380862, 0.29404703768030294, 0.15760710012287865, 0.15394971976357122, 0.13927902876129075, 0.17268381772502778, 0.16702458833254155, 0.2343318169756282, 0.19805059768259528, 0.10451598122956292, 0.16800919517634377, 0.1420851168973792, 0.11433086988906707, 0.1557238721438954, 0.12460028617492608, 0.13841863541353133, 0.14473745118706458, 0.14053899824859636, 0.20232302407103203, 0.15194325888108823, 0.2105063293129206, 0.11278862764518108, 0.16040666118985222, 0.24783675198353108, 0.12074734655118759, 0.17955387972535627, 0.2337360150751568, 0.1243864174091047, 0.15474329492257488, 0.19963882052369658, 0.12991288376431312, 0.09239987169782962, 0.08779094884953192, 0.1704055335252516, 0.10484778157044804, 0.17134998204006305, 0.12769233195051072, 0.18179661744544584, 0.20740563440467083, 0.1354099016997122, 0.13916966204922046, 0.1399779614181288, 0.217873168688628, 0.08976895722650713, 0.15987430669126973, 0.11381103326716732, 0.11353564764102621, 0.15404117533997183, 0.13180387987484857, 0.15428195677457318, 0.09081710340274919, 0.15266974005968342, 0.15377662985795928, 0.10736618070833145], [0.026829479292275447, 0.017325900036901716, 0.0811236779836397, 0.042538292210308776, 0.05936870381476418, 0.021834722006573312, 0.027571324364192067, 0.06242244519413479, 0.026155553660505725, 0.02981512503127658, 0.02674457376762744, 0.01931272800110521, 0.042869108128211195, 0.04710729804731185, 0.017269138667371967, 0.09699706574000659, 0.03325724042952061, 0.026978673000309258, 0.03905566033696936, 0.030387716382862102, 0.004996104642838961, 0.07942532234254383, 0.04374154437814028, 0.0304125395468286, 0.03838964647823765, 0.0852747330622327, 0.029124987063809272, 0.02687994341906761, 0.02080727169560569, 0.04443767315317546, 0.03928547522293464, 0.04596022310696783, 0.06283225243790977, 0.01626838652056552, 0.05111152088389762, 0.013593132795405485, 0.040331966649260254, 0.012079507765930989, 0.010758914868347349, 0.02123061379778289, 0.03364853898904497, 0.04925309883190259, 0.02409388082131984, 0.09522976218572549, 0.06599180205094238, 0.06871170529554929, 0.056127201946031664, 0.012414959473385206, 0.014425318785792878, 0.0311747663879707, 0.08109986797095307, 0.0267219262933659, 0.011606129588589314, 0.0487629481170687, 0.04920801455755869, 0.02781358626370709, 0.04820610178754695, 0.036176820661151604, 0.06862140651191435, 0.013051273060902473, 0.03261292218080452, 0.05894791470059465, 0.07758818987396456, 0.014418073509248995, 0.08930011141684749, 0.045548040990627585, 0.07507245672205765, 0.07399974210608391, 0.020917852657035958, 0.02465927860729637, 0.05826421187169129, 0.01858052797615528, 0.09141822961429436, 0.009746228029290515, 0.01087402340941011, 0.01800217564337917, 0.0230624545140252, 0.0404111341753554, 0.0261327836121763, 0.016624854892612468, 0.02333586554854147, 0.026580154062098554, 0.007930820377828975, 0.05256156827653608, 0.03636660745307323, 0.01622089289969975, 0.05545006066019978, 0.07089442002677149, 0.025914871817334525, 0.011234898702241482, 0.03628622950805772, 0.04164324870573417, 0.028803697449245283, 0.032113147486421856, 0.02471956398127781, 0.042358368800412265, 0.018940455235180356, 0.06725583180424667, 0.039528014829322215, 0.06250960301728019, 0.024639796991381916, 0.06663058148396593, 0.0656954792418307, 0.046413865901770136, 0.018401569837043365, 0.06299974607123483, 0.03527268752335541, 0.06817325273708952, 0.07702454834455445, 0.029371855066969033, 0.023251235815546206, 0.03320999961766986, 0.031687646931517995, 0.030559320077900926, 0.04743518367890389, 0.04013149293079492, 0.025782802089628194, 0.0402013601494893, 0.02454450714492029, 0.0063398563783736, 0.0673059645980116, 0.05457046914905791, 0.09057925608489784, 0.03282980167216832, 0.03995361880609586, 0.044001968307120186, 0.03959737259954695, 0.04304605145608226, 0.0788017574156965, 0.03539532670871385, 0.0019799767441356616, 0.05904721118690026, 0.06281328410090459, 0.06845999178626845, 0.06171105594764795, 0.016611373660364942, 0.026718067125447338, 0.03428713456096669, 0.03477187669505516, 0.02464956078197687, 0.07198442524719624, 0.06102550684684708, 0.020520674372692744, 0.059782985012016954, 0.03617286764746232, 0.014793289968022897, 0.0440707859853583, 0.011871184519071494, 0.046902381018885685, 0.0255264958832413, 0.021875152296777216, 0.010686992618796087, 0.05991422353432544, 0.03661248720281067, 0.05965912391641929, 0.06513260380034486, 0.036303566077784184, 0.03401985414506447, 0.09655019899289455, 0.01401208712899637, 0.03424432173731827, 0.01867178245447576, 0.03169649333182362, 0.06643671527384751, 0.017540850901916143, 0.036836119759227, 0.046152139623318954, 0.02724413970305074, 0.031278789636769125, 0.10255362402888075, 0.021466668469891436, 0.018637785387616006, 0.05272779786478608, 0.04535215613882869, 0.033760441452144616, 0.007259000051436165, 0.03484591143205762, 0.047644934722132264, 0.04468148829595697, 0.016615838037743684, 0.05699283916563277, 0.021583029564710397, 0.03552697508806183, 0.04335064801477617, 0.008501723941956318, 0.04754528583538148, 0.030153896772272648, 0.018762994797960408, 0.02332597918387863, 0.054183008690034194, 0.011661502423756307, 0.03247373932672124, 0.011452688880625271, 0.02011737121539491, 0.03695287921976659, 0.020835862096939838, 0.020159197700840813, 0.07365811285713027, 0.026506651756203464, 0.077704849743074, 0.028952565569911274, 0.06996109510862059, 0.04676450051427369, 0.07053404460631071, 0.034457807459177515, 0.08728299425133774, 0.029849346178854187, 0.04725935883940228, 0.0540472770620498, 0.05146815013440867, 0.06218664716148089, 0.03091479445086612, 0.040062602474204, 0.03119273881067432, 0.023090485671174624, 0.013194726855163614, 0.023388834782846035, 0.034713830213032426, 0.0785031593254497, 0.09728252542235198, 0.031504869844103535, 0.028088184734505993, 0.029576998091332858, 0.05548801265596863, 0.04017337878805496, 0.07548068965514822, 0.037078812583199436, 0.08033230149697873, 0.016638433801070336, 0.019093680480915694, 0.07287943044737463, 0.044375459152844646, 0.10594298086699941, 0.07272815106496697, 0.0956792719361763, 0.033403187839975285, 0.015082614563946283, 0.038879138357456655, 0.04502842653422587, 0.05093401831184184, 0.020566727748260866, 0.037241897380520264, 0.12067830670745143, 0.01207814412942577, 0.05505423452104292, 0.0242345996816913, 0.03696888279650481, 0.05297577669543605, 0.06275388164325588, 0.03155841364435131, 0.03869429666308626, 0.005049559864170489, 0.04084679688657484, 0.03441158937470567, 0.10904835657246652, 0.09092296143212626, 0.04833821365008912, 0.07881242902048173, 0.02324913290419406, 0.09063085976747737, 0.01759898931448979, 0.06809653669235206, 0.09850570736753364, 0.036858060517378395, 0.07915123140499478, 0.05427228474629022, 0.06170017749912316, 0.06019759179663755, 0.03957169333232507, 0.03896417411705179, 0.007818313184074097, 0.040082597369027716, 0.062056021509511824, 0.015682232539890515, 0.01511390734043333, 0.021141255387075005, 0.02272365404473197, 0.09158224137800355, 0.009092871858287723, 0.07766181858436716, 0.06228734941912755, 0.016177438477414752, 0.011762609750392937, 0.08189112188354616, 0.047035190021438945, 0.11472642406701081, 0.03136723448762731, 0.02089852425870636, 0.033122723050896204, 0.01092031810267438, 0.047918385976264556, 0.05322360996938041, 0.018666490702138796, 0.007906931362325146, 0.02814815218199886, 0.04500933179271318, 0.07527947666183596, 0.06257995287136686, 0.057065705618550705, 0.0037634679756592964, 0.010755166783177806, 0.06978910836961962, 0.019570508926746347, 0.059434192840971296, 0.07000354404050498, 0.02032321137976983, 0.09806094736221338, 0.01491098980148954, 0.031756512490251375, 0.0954584394311232, 0.03469191243751876, 0.028612449344608094, 0.05046619139912148, 0.03888348590642695, 0.041733467050137064, 0.03858532831673661, 0.06177418542304828, 0.03050237484726935, 0.026908110556823593, 0.05088964649926751, 0.036789909335634405, 0.028321067802608017, 0.07416766091820694, 0.02066543051642516, 0.025056341978450938, 0.05106962353531873, 0.026137221176477692, 0.01507221204754446, 0.06936988207481562, 0.033129043276271516, 0.05597510284954502, 0.06489038212044586, 0.02721481194208947, 0.038594061719073404, 0.005626820521654502, 0.019915418947235714, 0.08734380631076713, 0.021535170136860782, 0.0644038166970976, 0.02518344362596831, 0.014438005201818963, 0.05130330716530162, 0.052661711289998026, 0.040535972033056526, 0.021624317873389493, 0.026909290332226988, 0.015342300175689163, 0.06113192412040888, 0.01346770792283238, 0.022560542434333794, 0.017118188702771743, 0.04696580160769725, 0.0920596597115359, 0.1008248623580702, 0.13275384422271483, 0.13514612230562395, 0.16266475131194438, 0.07123042619036091, 0.09158165149030187, 0.08788721545809701, 0.10351337898041933, 0.13452569833926617, 0.18969047934778277, 0.14186342637385094, 0.29972191058820297, 0.1554535503589338, 0.09999808494842823, 0.1665872440583283, 0.11722587018964753, 0.1869185740548757, 0.11023652063862932, 0.07993328460161725, 0.07978089439171938, 0.1767287313217117, 0.19311408031611674, 0.17692553930945937, 0.07625466062416954, 0.1338097432087506, 0.14772625129309394, 0.17202550304993508, 0.1166348256951859, 0.2179713198734868, 0.16838444036341485, 0.14190851830907408, 0.14848130755126476, 0.08516587962907168, 0.19106021391287928, 0.14790566908496042, 0.10353495201636707, 0.11347642138360009, 0.1732913101272237, 0.18433688839356746, 0.12084368210766586, 0.2031493418279194, 0.2130455737032237, 0.18192642338333592, 0.12830609095192727, 0.11628721329954364, 0.12713678797046024, 0.2124582294134363, 0.13825987135210346, 0.10678792222132606, 0.1731406665977932, 0.18497480980811581, 0.09417800773536006, 0.1390371748035954, 0.16703178955902978, 0.1455571499442862, 0.17736997755785144, 0.15017293694038547, 0.20872128316231314, 0.12747744428775004, 0.2105776520986711, 0.15075298807313367, 0.17552148400535508, 0.21523560457412275, 0.2328936094718595, 0.12745974765669915, 0.17241728041441212, 0.1569626669609739, 0.2134336432021472, 0.1902713425337307, 0.14004937613443022, 0.08952003227727068, 0.19917153753340247, 0.11685018833245962, 0.1256716218326361, 0.1281710449726351, 0.08978161299901624, 0.13933536686724232, 0.20450055238700685, 0.14126786962151527, 0.1825565613445736, 0.12265633806706437, 0.17448469125215085, 0.18944147012887463, 0.10649203608233122, 0.12080312541295445, 0.22232507415596517, 0.12286135085648107, 0.23970426901453928, 0.1148186457313357, 0.11545180973987426, 0.1404030789290705, 0.07733925726384887, 0.10356625436895317, 0.09556242054508579, 0.12198023483036988, 0.13499779236172477, 0.20370245730924993, 0.11445829329351265, 0.15150603718094288, 0.08866153882756349, 0.16554732566639302, 0.11899371000547564, 0.2243260804924273, 0.21605724919467204, 0.18223026917586405, 0.11618926129754513, 0.2176751349602015, 0.13431387502820263, 0.229502490631515, 0.15015061313827194, 0.09326270120518823, 0.13980393688524925, 0.1389647794947509, 0.11605907997657215, 0.17989534043496658, 0.18285263900554952, 0.1651178261325244, 0.08666053249110138, 0.17762909913736005, 0.11988332960754634, 0.1502529778067143, 0.14833464767904053, 0.07899936213488541, 0.11829771146538759, 0.18755902355957418, 0.2392006121696003, 0.17330827131386728, 0.15866171208120164, 0.1141749173703213, 0.15915254461428813, 0.07305439726840104, 0.17393660130760363, 0.22623984473607234, 0.1726571731870213, 0.1083716404654326, 0.13942881427224607, 0.14866109306533493, 0.1134971287401934, 0.154733580927695, 0.18921651607078893, 0.1528468136225016, 0.2384946161821004, 0.17402791898817788, 0.10495341743432707, 0.15613481702823795, 0.267422724395029, 0.08207666071792764, 0.15614053204415307, 0.13306553475558758, 0.08332672468837231, 0.1900434007327403, 0.1285489101804072, 0.1648279384619767, 0.12798409653647294, 0.1559894135402095, 0.12882226567354896, 0.11754927420688253, 0.2610862579557204, 0.14507788533885635, 0.22663392036432223, 0.10880202100041414, 0.15788656899765616, 0.1601864109116216, 0.07848661182628525, 0.11962973152197177, 0.11502738936894363, 0.07599392259914069, 0.08214796052104043, 0.2411673896976056, 0.12622562597595877, 0.16087671741843224, 0.10745153056397554, 0.10896531264147452, 0.10528479642685383, 0.14478399868934386], [0.12341225234371041, 0.042285234216720834, 0.06177466805844058, 0.05800516307053547, 0.08474142095374484, 0.018898663223691044, 0.07359838098167412, 0.06175419435866418, 0.008554266082243094, 0.038457464411734574, 0.0030497689740807423, 0.03779726899078777, 0.028715099380802245, 0.05747452460890336, 0.05049453282188024, 0.020435477734633514, 0.062243268719964454, 0.027481247746055166, 0.09425872275906225, 0.0015405897682930735, 0.03513124854033513, 0.03239540683646356, 0.022752342122276465, 0.03821090667418415, 0.04009264078171503, 0.029383733260235, 0.036653978524789695, 0.046457735926754055, 0.05820820318354715, 0.04171460213500165, 0.018147772568608486, 0.023534429792855537, 0.013944189713877297, 0.016305966963691097, 0.006960154419028832, 0.05036643909050092, 0.0746075332825703, 0.07018725192474742, 0.045309879576727274, 0.044957574892548785, 0.11242280533957867, 0.027060941267277927, 0.04929870404603501, 0.04020652741253857, 0.026626533025034496, 0.014028960215528647, 0.017075531011927995, 0.06681913870476908, 0.030870307725103154, 0.0915074022486806, 0.03140415034947857, 0.051990185428651116, 0.00828143248649975, 0.05410358069404479, 0.08032713040348985, 0.04508901259771759, 0.046046691450981364, 0.0701256967600315, 0.03977338513059001, 0.03132043609155282, 0.016194648642633713, 0.05006688722078839, 0.04719089739204896, 0.03006333560352364, 0.031133966460343332, 0.02606770635822848, 0.03259408024830684, 0.08014421158980939, 0.0771346428401528, 0.053511360254619396, 0.03578278716773756, 0.050567805301398046, 0.02916652626628357, 0.07975907620763587, 0.02943989325074419, 0.0176295236639318, 0.076185230075592, 0.052405454879326206, 0.010327284652439338, 0.05888399232419268, 0.0508668783661579, 0.04329227594538562, 0.007080054840057969, 0.017750033124860738, 0.06358828928862369, 0.06997596487523088, 0.031102750292648713, 0.07043885818171887, 0.03278631469114654, 0.04757497174244735, 0.02593244012865809, 0.019529714744778413, 0.03586305019956443, 0.05800066613441995, 0.046163948868671735, 0.02053773515076647, 0.017954501991851196, 0.02480506322406713, 0.02828111440213698, 0.013275123952377229, 0.06622154415855486, 0.05021507543842158, 0.014761900472935411, 0.006654069255737047, 0.022870470964980703, 0.02590444727590488, 0.02922440995462239, 0.021439380418028564, 0.05132453163124381, 0.04935489276484136, 0.015427692166169085, 0.06583231786686568, 0.044169936914958303, 0.0558251373079275, 0.024769392255092823, 0.04695958097375209, 0.09375203986682239, 0.08381553474933871, 0.04554766560754469, 0.024907510246961348, 0.04580559208989144, 0.03395527676348725, 0.052418397934806925, 0.0964245529124333, 0.02854795623270254, 0.11839398573483191, 0.0049157726630989105, 0.0925076985731721, 0.008057839192089536, 0.04325918477749632, 0.03377030100373011, 0.07227654989448286, 0.022760403282459707, 0.024603756384984143, 0.037806937020392194, 0.03868518404722695, 0.03380907654401756, 0.025184370592356693, 0.05403755540629068, 0.032012265198112975, 0.02231879955938747, 0.03981927379725441, 0.012531912371125675, 0.08927290763465628, 0.011267018853686752, 0.0586658985834689, 0.01799649510142063, 0.03875296367632766, 0.05321572692463956, 0.06942782130452894, 0.019305086274060513, 0.026720428591473933, 0.044330803887738336, 0.10534738581026755, 0.02373475220895583, 0.05406789631853181, 0.045108256726375515, 0.01842898429341374, 0.059765725051082914, 0.043655037729730534, 0.005937860837401522, 0.06174338102761296, 0.00831226752545204, 0.028294390705864758, 0.025742400527721452, 0.024043477981561617, 0.01277692165345915, 0.058190594652607563, 0.051260869724736105, 0.06561964419820616, 0.01655491298034547, 0.05493457158727031, 0.06724309176206589, 0.026097886392005512, 0.07913519718473958, 0.0473138774865337, 0.027996681277610125, 0.04454686366502316, 0.02694715997354398, 0.060735894967952085, 0.01687860619577189, 0.05297997102682149, 0.06194237236594481, 0.023578372596192266, 0.02831790960514017, 0.0892277390906407, 0.007256358963317208, 0.029283525129299492, 0.049739905572946996, 0.022152780645316648, 0.1278221225666423, 0.05622186743083501, 0.0696301068209352, 0.03317501238216797, 0.06778270877417057, 0.03409124587872817, 0.012864371547625672, 0.020894726377821738, 0.07094734904146002, 0.037849994992176374, 0.04921365679512101, 0.02542153034629601, 0.040120388486332474, 0.0289124800192733, 0.04366568252143841, 0.05030335558037605, 0.07825099382429354, 0.08679853556978126, 0.011641375378765648, 0.01582354128796367, 0.02436527321415563, 0.0449823463455804, 0.013384367132769718, 0.07208093700389709, 0.009486085637622784, 0.037812770779935584, 0.005830914484367016, 0.03054151810976046, 0.0374908912776699, 0.03994737135907335, 0.019792507800664154, 0.10379329984707218, 0.0040684095133216155, 0.18306948785339633, 0.03772266351828172, 0.026536693894154122, 0.03228392572172227, 0.04743287392381219, 0.011474608571358747, 0.016761712669845552, 0.015608015857006033, 0.012439638038255997, 0.04537695440493765, 0.015173714867072, 0.014792988320902712, 0.0013470515395672391, 0.017133002928007516, 0.08920765226526607, 0.0452164436630424, 0.031055988285750635, 0.014750219547309944, 0.07590648898434255, 0.042292592491233544, 0.06337785259670307, 0.041930784486354365, 0.035856163069125147, 0.04206158250810639, 0.06209308867372813, 0.047931486079769756, 0.05555373916943228, 0.01169940941185961, 0.001484499683306973, 0.06689472860025783, 0.02896828569411751, 0.025989864164242343, 0.05576595701577683, 0.03560075318560966, 0.041509811511082996, 0.026028294964963873, 0.022307787045475938, 0.029298915835698287, 0.0907073766293545, 0.020768499985757857, 0.0331813364379829, 0.06170303500708073, 0.024949434408617598, 0.0794392038557318, 0.0383774848324397, 0.014585376578202892, 0.039876481413000056, 0.03471807434013294, 0.05205170994985008, 0.04811155121593226, 0.07763392532304411, 0.04475715863067777, 0.04020111500135353, 0.024050478109969728, 0.05264037574130682, 0.014167452632870167, 0.061325008920844526, 0.009654692971267769, 0.03494305521129601, 0.03831657318158015, 0.04950556310734922, 0.05923574925550531, 0.0665985207043348, 0.00266744178295466, 0.05657072088891461, 0.008402290517434238, 0.038936660069251255, 0.014903565451893357, 0.019457154727030187, 0.007952778851763617, 0.04485738591381139, 0.017405155663108154, 0.01833270044787036, 0.03237131720168456, 0.0017736215053329005, 0.01586722457901605, 0.04497081289188035, 0.022645187489087545, 0.014317983164331846, 0.022453249905318506, 0.04267269467574455, 0.06716147275461305, 0.032785433690033616, 0.04495635298230956, 0.09199469545555693, 0.0341677435884072, 0.020493026259505463, 0.04244593648059715, 0.04797242198800368, 0.049185506894343325, 0.06437609197511789, 0.011747723704414263, 0.019944049568185886, 0.02752326000782271, 0.006177069876538289, 0.03235622910001586, 0.06524482035949346, 0.044485289348109115, 0.05486312239701229, 0.013913849759246073, 0.028343020052078272, 0.0468978917436494, 0.027269485722025557, 0.03529277817916966, 0.008899003732949495, 0.004539411860488115, 0.022202505497261885, 0.05778827974873205, 0.004559805599837414, 0.042063589658468, 0.056381711676236124, 0.06966242807046061, 0.020620761844780178, 0.01343237307493485, 0.06175006514475231, 0.03268598398614315, 0.03859016233153882, 0.03134046546033314, 0.007934465519933692, 0.00621490121345907, 0.04886441263220003, 0.01833906472330132, 0.03462751508660374, 0.040976005275883985, 0.04698135319256014, 0.0658742381980823, 0.01600744452462682, 0.05589674354620999, 0.029874780297940298, 0.24840598595478844, 0.14722984163991867, 0.14935717587509464, 0.14998003600105164, 0.15791017982748248, 0.19064727719993363, 0.12369371304709105, 0.06278719497664322, 0.17117097793567568, 0.1665163196382984, 0.17737658123575872, 0.10488653795853739, 0.19257308434574835, 0.08689474855219165, 0.19665627169512934, 0.08456325188519494, 0.15297471966233947, 0.11254531045955037, 0.1640975349132092, 0.06571821673142333, 0.09350873034207091, 0.06037123328555496, 0.1914189116007859, 0.1300026692690388, 0.12503096548419806, 0.10497094552603461, 0.16316660018938203, 0.14663621542915223, 0.09221961887012567, 0.10154739818385533, 0.14247389119719306, 0.23609715934482314, 0.1305244977195417, 0.10367529932409526, 0.12125441248738959, 0.1500968797312629, 0.209674357827152, 0.19106612811165471, 0.1362373073014521, 0.1572012727058703, 0.14445096494690066, 0.1453204900627175, 0.20598849431881983, 0.19343969832745292, 0.08250186249854104, 0.22216347556921745, 0.23791834952369814, 0.2385300554094776, 0.13300159705742715, 0.1814885275258172, 0.11069625000199003, 0.11556663865884466, 0.13511912536717233, 0.13830721558582398, 0.11381209046850282, 0.11648819646647862, 0.29582996942823936, 0.17383883316670695, 0.15198689524925527, 0.14692719094455242, 0.08701419698134547, 0.23645993262048692, 0.21667257101545412, 0.15733005208594186, 0.11622297682709272, 0.20165563891491584, 0.12943862937390804, 0.1617853743054213, 0.15045072042172955, 0.10927954658625588, 0.1253438511142327, 0.12754639220093528, 0.12535944866437104, 0.2152668456396749, 0.1030745868000292, 0.12085760958612927, 0.1547965227115539, 0.104255840753115, 0.1897040697475595, 0.20021019954114191, 0.14192633751419284, 0.10836852248758079, 0.11497051500144506, 0.1569665280441123, 0.2626723051071167, 0.12899785302579403, 0.09304481047776439, 0.16194246829517428, 0.16259632433854765, 0.17142495140433314, 0.18859175604677972, 0.18019796048681583, 0.16675970577184232, 0.1431409086311056, 0.11227885741860637, 0.09017347463316495, 0.09653126896028558, 0.18852984082073937, 0.23730819113552573, 0.17312816404286893, 0.1461562613445905, 0.1000809986444731, 0.0622294599851293, 0.12182964492709407, 0.13670282828952038, 0.15563735017372718, 0.13359635707832154, 0.11609661062398266, 0.19884011257560025, 0.2623613040533758, 0.08283511074560304, 0.15181391259595273, 0.115392200438486, 0.16829252513425966, 0.14446031121957686, 0.12022049256390142, 0.14548532154050567, 0.16815562522219074, 0.14903468350248952, 0.07641396860802367, 0.13982031584507035, 0.09943222942491693, 0.11031391084074013, 0.15973366827013033, 0.1218004416554205, 0.15184043455989132, 0.0878695494705631, 0.12289885852125385, 0.21324089548039823, 0.16012141601212565, 0.10679120107764199, 0.21598168228182102, 0.12824799850462906, 0.1287270562663194, 0.07163512745812055, 0.1350604736756894, 0.11216568324955241, 0.1851110202410529, 0.15728568027336753, 0.08966090052478737, 0.22374022241321304, 0.12963477852604083, 0.08578970502581328, 0.10800220222482759, 0.15661955150144716, 0.18896254260213147, 0.14749285494608266, 0.20583665569222745, 0.16157983291533687, 0.18464301712810996, 0.13941442714102809, 0.142452655239932, 0.11273559137818315, 0.16250117621835203, 0.14898022997283167, 0.1388517049171271, 0.19138786971809404, 0.10048718612280585, 0.23944257337960506, 0.15163691564192697, 0.1372493247711851, 0.15416946442377183, 0.07549007423222065, 0.20768151798796272, 0.09873805417408867, 0.10781735286957796, 0.13202308827350218, 0.2708545225041528, 0.12232796980008004, 0.16008435267834895, 0.1305406774965025, 0.09141983839893535, 0.2718249107560804, 0.15541555239788948, 0.22605907862945912, 0.21161205465755156], [0.050740301488868655, 0.08642330570446868, 0.005853418795947707, 0.0332650238828313, 0.07812638962340933, 0.04473508380713963, 0.03573626264809601, 0.035602959518831585, 0.02456198352569294, 0.049046278074984594, 0.008786459671213262, 0.06145980209112168, 0.019409071218462724, 0.035329420164588, 0.09097954468621362, 0.02182236883879429, 0.02054546114748284, 0.031085683768915556, 0.012893549921441705, 0.04021371331726832, 0.045796299443369916, 0.05776315206481565, 0.04798280247937768, 0.058284367644979115, 0.07202900390351011, 0.024559710159777634, 0.05039877949222442, 0.11681255043273973, 0.0510463880885753, 0.032144505380382465, 0.009508516692045716, 0.021779393221461968, 0.03291974422491847, 0.029870633847050132, 0.04193053167733935, 0.027374301871825612, 0.018661359828265927, 0.021425659783304702, 0.011571192148802503, 0.06815210104950013, 0.026953342303092924, 0.09927083768190877, 0.04287363187740407, 0.037851113480545824, 0.06050346006128577, 0.022791747769881642, 0.05899625101817712, 0.1039616629901913, 0.08056807271655529, 0.018113380966467724, 0.01565093784818366, 0.03291490637967664, 0.12261640190357163, 0.056673775036488815, 0.027691663370557854, 0.021203092089103117, 0.027710599148826256, 0.017859451547865907, 0.03627577623833091, 0.060779404931611596, 0.05031107774665279, 0.11608325771146244, 0.06973602613734622, 0.03178854071114573, 0.0439025147727901, 0.1427638861200502, 0.06088570729198475, 0.053098013684634245, 0.056191993832227685, 0.06884043104946613, 0.04976375389002985, 0.04752000493388023, 0.0177926218677913, 0.03796327641353973, 0.055002619347144524, 0.009946034293651823, 0.04431201558139536, 0.028915326035912, 0.09087349513485547, 0.04987137009119315, 0.04438017825445822, 0.01629420751405339, 0.02162095666262171, 0.043830533151424704, 0.055052794275745276, 0.03471330927324391, 0.06911403935162291, 0.055371927352802414, 0.07369282430097943, 0.04172270734524054, 0.08615251660587327, 0.040438793779861544, 0.03823239927089984, 0.03284431903833344, 0.03380190213060668, 0.05700842139401263, 0.0363478651120057, 0.02129777481088475, 0.029901338651055293, 0.016162363782284722, 0.06007481088501312, 0.06498040511242806, 0.02963018949113546, 0.012546024668300826, 0.05961636088848595, 0.06151262768394044, 0.03025830498025302, 0.04344654307069798, 0.1256371861804397, 0.03168162548043315, 0.07872782227012419, 0.01697726682910035, 0.008979636402199826, 0.06377134982857012, 0.02569860902674977, 0.016436228723896128, 0.018846469653409817, 0.02959707917104806, 0.031507206412272594, 0.065863911332863, 0.09104467748153595, 0.09826812818045579, 0.08146055748746281, 0.06432633456443587, 0.09092896756145263, 0.029994946934523124, 0.054813169633909586, 0.014453833535944503, 0.017205402067291643, 0.03609054383911914, 0.02662539921490656, 0.019653912919062762, 0.04542262856698325, 0.06527757827913569, 0.015175659772789767, 0.02678871000816505, 0.003968030209615526, 0.03896577524081354, 0.08335194430283963, 0.057579421197935465, 0.07510540616368094, 0.07047359260820574, 0.07022577848645949, 0.05262065280769622, 0.0425163897565536, 0.015405207485591453, 0.050202212822172916, 0.034069358746731476, 0.08058953850019364, 0.02458687563757262, 0.040596056308957844, 0.03507632769704346, 0.024980144958282192, 0.011005486970046356, 0.022927619208912217, 0.027517627346359437, 0.10825036108613977, 0.01392129804908989, 0.049122289318831704, 0.08265431399547285, 0.016143516104127613, 0.03985947426108103, 0.062083183156867186, 0.07238190230582991, 0.038915722886280674, 0.07417804907046019, 0.08515836430653449, 0.0339252537777347, 0.039107432558892236, 0.010744411866330813, 0.030420420676349636, 0.05115471292106856, 0.05169952017886024, 0.013122630320609579, 0.020301726443933386, 0.017934415166476564, 0.03319278179157165, 0.013142303458505101, 0.014883560023360677, 0.04264014359984187, 0.03756365047827844, 0.03144279948525852, 0.04794454787887874, 0.007864122369116353, 0.05975715252721022, 0.06525565284274279, 0.02109931015800084, 0.07380488764254317, 0.09437818650997455, 0.008952688301853355, 0.03261654194624674, 0.011919403050635612, 0.03384844963288596, 0.05671530849330368, 0.05039831983946985, 0.03106357255620101, 0.04021863543218182, 0.05049609947168539, 0.0591836667679731, 0.038374363024148254, 0.0181616272687191, 0.043548700895400784, 0.024488902568156203, 0.052144843258804856, 0.02470951673815087, 0.022356717081199733, 0.01032988360572246, 0.05044632673924489, 0.007885040399888832, 0.021235681469402006, 0.02908786627343826, 0.02405690175721482, 0.05889059600209998, 0.013835327662227136, 0.030385025499028065, 0.01862785688811733, 0.05075046747562386, 0.04166813890239404, 0.014174389559024525, 0.04060753613650318, 0.053467271894577055, 0.021769554737294396, 0.03630716286058869, 0.10525829744555297, 0.07018798736915474, 0.05890189196854349, 0.025783267488042196, 0.03357465363918774, 0.14564456057644662, 0.04760794416670838, 0.031122999911707257, 0.05163877706734404, 0.03188760354063444, 0.03136411076411605, 0.027212718606836377, 0.05751658283594636, 0.0408995688532389, 0.004900900981268816, 0.04805011862528421, 0.02316009433519456, 0.0658582729257403, 0.05377970553273636, 0.029537963996370955, 0.03561399884582047, 0.05157037307658503, 0.09146483074272833, 0.032536907106517785, 0.026364132589209947, 0.02314715319493365, 0.055386885219523986, 0.014582396496177442, 0.04783265307665833, 0.09230100039032199, 0.03478736316244449, 0.03971682485914038, 0.05548007598507309, 0.018335285994614807, 0.08525336687002452, 0.016053782310336828, 0.055817813507371375, 0.05114548922246022, 0.0776318492247693, 0.06170375896016918, 0.06083555151558211, 0.003963322359918347, 0.016866230045355136, 0.06466806340481966, 0.059077961956180876, 0.05020461833825515, 0.0298911745795199, 0.031869652185348735, 0.03591378054191028, 0.05450464687460373, 0.026200239569129005, 0.04112490595528676, 0.04233929321109768, 0.026040774537250403, 0.01824535301796371, 0.018384501398090395, 0.07699983434811716, 0.05140511641999887, 0.027034199053061106, 0.010891249853997462, 0.020947383431297158, 0.013761449015639244, 0.0109207155107851, 0.07027042609068655, 0.022838295272160924, 0.006257495702049065, 0.059656434947805065, 0.03299881599002308, 0.020180075511997266, 0.04444234628951357, 0.04720011342977805, 0.033124236074546655, 0.06664305339537321, 0.07699956621734366, 0.049549452284531253, 0.038440560681685325, 0.018859460589385802, 0.017002515171864824, 0.04729421583995704, 0.01100708426336848, 0.03187452641976697, 0.03707984297145759, 0.02567615498968911, 0.02976847410712752, 0.03783944213101941, 0.06860802295587717, 0.005717932794904036, 0.04291311604902149, 0.04025706623290335, 0.015039324850565004, 0.07941216861288394, 0.029222174893103303, 0.046782392497745254, 0.08860078805516805, 0.039115292620995355, 0.02996054958672293, 0.0315696693911788, 0.040475523865391175, 0.08218880066828382, 0.04715471505938519, 0.03267245104296073, 0.08645563461487332, 0.009072340701917007, 0.04487356952121181, 0.02907223999500275, 0.04026875290418825, 0.025302553061215628, 0.023153107613325122, 0.03466879190396398, 0.011952823636332347, 0.02471191267813406, 0.05159847318164764, 0.03555592172028076, 0.08541126525209797, 0.009091449807578278, 0.045562703913498315, 0.07300629460763547, 0.0921957322486466, 0.004888961979773857, 0.05164030541275298, 0.021002873094872605, 0.022240486221327897, 0.03406898336364858, 0.016931906763103702, 0.09434187394236365, 0.05766819546660108, 0.05011897353876022, 0.02281893814553417, 0.028150534715443373, 0.1582171359369832, 0.1528515174023567, 0.08429345104002184, 0.20437129803242224, 0.1897695396215685, 0.09202982058688518, 0.23727344138728035, 0.2915414092281173, 0.18208006997742962, 0.1806412189598045, 0.19911578165427332, 0.16389766257376442, 0.17973072346179716, 0.17748993160503526, 0.16450687101291073, 0.1355355401192942, 0.09845670838389667, 0.10805670938064015, 0.16451145221869792, 0.12928725040007022, 0.13324179626520605, 0.18726100003527058, 0.15714458219947355, 0.10764851475194578, 0.1992985089459727, 0.16996258148743262, 0.0754139097707887, 0.268886749061846, 0.07086759928854243, 0.0721666469208656, 0.14369233871900267, 0.14120223120816294, 0.0841200010730855, 0.20489861167246298, 0.13253702601838496, 0.11639464180916549, 0.1589329225281554, 0.08254347639458795, 0.08230582059871766, 0.1351389364008942, 0.06919995611233097, 0.20139067974542418, 0.08747148252422772, 0.1557195207644855, 0.11210028998433583, 0.10784516186122933, 0.2039843010565927, 0.2835525830666865, 0.12940265388498384, 0.14738512766217032, 0.12789713789618787, 0.12132171331153763, 0.3799792733644286, 0.20848971010456163, 0.17057178992657893, 0.12414568960065804, 0.13148276646050716, 0.04529014132135818, 0.11785010927386823, 0.1294404066978924, 0.0738514274839432, 0.25208608848193004, 0.17624894577649333, 0.19466802838348574, 0.10626875975679968, 0.1840559792734923, 0.23953136297002917, 0.1262922449818542, 0.17731043720437636, 0.24960581754003805, 0.09676536244730796, 0.12448227799106991, 0.08631652836958248, 0.19892393791627502, 0.17378690772719924, 0.13032149974136584, 0.13261744992867594, 0.056563343462203784, 0.1390395343544022, 0.15470056253815853, 0.11289492234467499, 0.22462117756086014, 0.12145823017964441, 0.20304729891640527, 0.16511632460019282, 0.14427913142548454, 0.19549065359657813, 0.17712011032046812, 0.11567569127486599, 0.15372272791160693, 0.15700990394238504, 0.10841421963226412, 0.1692362688481808, 0.10445491636111852, 0.1440105409992318, 0.10245914240517925, 0.10886181416290422, 0.12752671906303975, 0.11555032864693673, 0.07581875659525394, 0.2119062170987168, 0.19687739531359366, 0.1202064042069739, 0.1467300305563596, 0.15700411231767747, 0.18769670488132587, 0.0716661157146577, 0.07516821005171345, 0.2890922261341926, 0.16029458252653, 0.168466227910211, 0.11019296854013398, 0.16031483789124798, 0.1327998554634471, 0.13769901838273774, 0.05171523647262685, 0.11332316549434779, 0.11667323734370932, 0.15765265171085635, 0.3087169472729006, 0.2650398232283131, 0.1723903754065114, 0.19506582719904764, 0.1258997398338491, 0.1094520236215284, 0.19888535772840824, 0.11843853374762882, 0.08999815541169337, 0.1872817303745016, 0.07244620772619402, 0.16403345931922236, 0.0941416108980775, 0.19971424954072123, 0.13616802230958017, 0.12979882859414624, 0.13983271114768522, 0.16518029294187025, 0.10124966577296296, 0.12811204088070702, 0.17207460928588145, 0.2805277921499745, 0.12050325561675335, 0.10802082582226685, 0.08079818254637142, 0.09119332918236334, 0.16908032399031425, 0.20028653254191722, 0.16362700371011613, 0.1685243893054224, 0.07229177972241756, 0.13010010033124877, 0.19434210393697987, 0.12885335352151625, 0.12637468370338603, 0.253248228541305, 0.15465136437166124, 0.18527246561021576, 0.08665112493139121, 0.09477126622392286, 0.14724064347965105, 0.1943457964807749, 0.17185613633163516, 0.18919963149293778, 0.1362900141506426, 0.284081275664991, 0.10661107848488516, 0.3220326892070232, 0.08988560177385808, 0.15059128223407656, 0.13692491717876928, 0.15211392794885945, 0.22169682077102124, 0.1041193545285252, 0.12021693791593276, 0.1277899775173395, 0.059553702557159055], [0.017033139536637935, 0.030856602412137776, 0.032883715109839555, 0.022074044043678912, 0.05070890337529202, 0.06642833427195588, 0.0788706440418478, 0.04999428889864395, 0.01961954621477954, 0.05504774958676389, 0.024211831548581683, 0.023946075647648786, 0.03700017365777204, 0.03370778056822958, 0.06529020340812784, 0.014834378136231776, 0.04611297337819011, 0.020820530762355176, 0.023974828842666843, 0.015463794059600803, 0.006577158337383862, 0.06877185085848456, 0.055995634005915736, 0.05401326275821175, 0.01961145824151895, 0.011636082668818775, 0.004411702130680844, 0.09204944775950524, 0.03713913434635728, 0.031599604276820056, 0.009686964425078083, 0.05905122931806311, 0.0301183981730813, 0.05523074883967639, 0.03635850607327396, 0.030435437914885344, 0.029883318347856406, 0.06766388853711468, 0.06869151121786526, 0.03575625371248011, 0.021416248393154914, 0.006390752866038032, 0.024777072286533735, 0.02164143802327735, 0.037561593532201745, 0.0862674757597908, 0.023646378221230644, 0.07431042906377586, 0.06561009874266964, 0.06016810124199237, 0.041429617427169316, 0.004342828911068219, 0.024769809773011554, 0.04027578942177277, 0.09559857989511183, 0.08537574941592832, 0.07008975191462426, 0.037978395158725406, 0.042738513119759104, 0.020414701430127025, 0.02538733792701556, 0.06291133569433324, 0.0568163593209559, 0.02199570197732218, 0.04567238089117793, 0.05353197568066178, 0.04616662251552747, 0.05831447490040333, 0.07281636608944786, 0.1282560041234378, 0.0635675321363153, 0.04185659270132742, 0.025689203382259416, 0.051230471355900656, 0.04938846273768333, 0.06724810197709069, 0.021153386389355988, 0.04541438163047837, 0.007601618032617075, 0.04709529727997799, 0.016906152802309202, 0.014305547642100964, 0.05888246780922336, 0.04649110288629609, 0.03193493819825592, 0.029607915484737006, 0.025763538808772163, 0.07605711719201458, 0.03934752834480136, 0.005808823381460482, 0.021594473003079335, 0.04047742376344339, 0.028348432463263313, 0.0025268529181278524, 0.028516142516426986, 0.08440529221608754, 0.0487392874915273, 0.014548403259757307, 0.039429672122482336, 0.04206730135446114, 0.06375177245166513, 0.04384131583895895, 0.0448327791696835, 0.01830494699759349, 0.058256838275420095, 0.04845002418263786, 0.08742464390853721, 0.024201121639400244, 0.04994362367377166, 0.10574962793579025, 0.023260436531516816, 0.06226496432998008, 0.0403938090969478, 0.04520679861607571, 0.048864064062194484, 0.06743187880924634, 0.03545521180175486, 0.03731786648953154, 0.04887592693370196, 0.044903029432340015, 0.06371937459334731, 0.026465702441430865, 0.01330233156500805, 0.04124433140180284, 0.07958543471871846, 0.047647773077891725, 0.06864242030367737, 0.028954921290278438, 0.03885700224688457, 0.05450323727282305, 0.03792129096484954, 0.05814820700775712, 0.014440064063115467, 0.022015384691316756, 0.015713158551783814, 0.022845019608916297, 0.03649494250214869, 0.09673867194402604, 0.0492255388188266, 0.023738536683301774, 0.05667673979675578, 0.012309477784700934, 0.048147136000015085, 0.04687049643947713, 0.0689200658891951, 0.05181022371435839, 0.05696840096084822, 0.028765437103086905, 0.02710296502036433, 0.041238325272476485, 0.07318549789488316, 0.014815664523461414, 0.048290857925049724, 0.007121574411529207, 0.06049637374798618, 0.027009347160797448, 0.0802884659459514, 0.016421228722338716, 0.04452819027186883, 0.08823007810860874, 0.015803275389536735, 0.025151848244751175, 0.054333506662759094, 0.04607548869605507, 0.014268412487581374, 0.032281619797070185, 0.025891134583000696, 0.022637976686500257, 0.10428119060252944, 0.04462010550102399, 0.0832547200843692, 0.04788717555422937, 0.007077924158018564, 0.05461412849986265, 0.012798273481518753, 0.006658924816762128, 0.018757969261177124, 0.05453954217955471, 0.05458364203091591, 0.03427475841054994, 0.02815765933313918, 0.03188542019005024, 0.064527700775333, 0.04013797020419471, 0.07089464219226953, 0.04751770283966776, 0.0031259650366395834, 0.006065532741617532, 0.05498218778220396, 0.026051497852970517, 0.004158146658747067, 0.07165246402784702, 0.03870973716520014, 0.011834582753269183, 0.05721096738031315, 0.08126754163494034, 0.018850367125724594, 0.08488819573915775, 0.03921818972054509, 0.05226803019702916, 0.04376902778242384, 0.08217815970701557, 0.022286501292499806, 0.06147322395155507, 0.04307869829297547, 0.012429835943264828, 0.015613967402567788, 0.0756769460595904, 0.039245297741745754, 0.026440297050641912, 0.04404365115108029, 0.011846289534362094, 0.037080363911246104, 0.03212632228349967, 0.025529194427954576, 0.02467364658631625, 0.03468522448993979, 0.02364459323636707, 0.04350586891955426, 0.08518282549395677, 0.018354675679978345, 0.14453711919486523, 0.05945250617280122, 0.010536075212932643, 0.05035500522823103, 0.02555539271974516, 0.055253769781801014, 0.088012317616132, 0.03819466177974978, 0.01636893364540752, 0.06782492021879843, 0.03656941007882838, 0.052618063430512146, 0.04642589348218134, 0.0477405118515655, 0.0806342397305754, 0.031110753996237635, 0.025323128267641992, 0.04464775361421128, 0.03821272613300431, 0.0220661131184428, 0.026990959135394905, 0.014413362068514672, 0.026764007503046628, 0.029371316890202226, 0.08432062417869607, 0.08532384695905833, 0.010165358563103985, 0.008596258234202622, 0.0068820809622505506, 0.027046151939899694, 0.04398898694724326, 0.012061260509184532, 0.05648176275914716, 0.0225143683999176, 0.04187541165118737, 0.017092030630597187, 0.023796956633187594, 0.017682536948292006, 0.012034633208156354, 0.03449904980258115, 0.03420610161077592, 0.020497109508141875, 0.012024183768869169, 0.012356675504105947, 0.02172100774553274, 0.02106009411715692, 0.05782091892474602, 0.07422821250774207, 0.1122424605813238, 0.020394108986722368, 0.07565273768118314, 0.04333824122084245, 0.022792659414511536, 0.01125610305837566, 0.07319901934674672, 0.023505780019707257, 0.03888266236190835, 0.04227625949668788, 0.04336148815890474, 0.05108737762296393, 0.06603303290302716, 0.04778302207048382, 0.04982809378435055, 0.02424053303266485, 0.024233176673371947, 0.02683282326606493, 0.02762213897620959, 0.08107342261580691, 0.06336444605802817, 0.019036051516811696, 0.06121487995128959, 0.04152339424998049, 0.05939358252010519, 0.06381851786206807, 0.029186649480834607, 0.004043325879460862, 0.030903416129970745, 0.03341975066089823, 0.10320864452589905, 0.023464499371907404, 0.0328352753703873, 0.04267800366505981, 0.042761851988372304, 0.03152842130211573, 0.050823498637445515, 0.06684432001484018, 0.06467566299702852, 0.014831918993994836, 0.013568244513965422, 0.026751765418016625, 0.018763444874615922, 0.050737532081022385, 0.14170515260869457, 0.029466541619190288, 0.06506469776673664, 0.015311761995807532, 0.01871910753599819, 0.11496064012810109, 0.04257517551342326, 0.018974672552318345, 0.01937593217007816, 0.06038885330781341, 0.011510728659378666, 0.0247918845965497, 0.03342276904731989, 0.010031173475116733, 0.05026921487203048, 0.05834879180897148, 0.054525695140323335, 0.04046420108587031, 0.042107214535316156, 0.047594323123414675, 0.02189647252370994, 0.06296926726316733, 0.050228956951609546, 0.02972578002710737, 0.024482881117071358, 0.13247990650275063, 0.0666803848599234, 0.00666022094176902, 0.04122447823324511, 0.020109352190047503, 0.07163158047103113, 0.03492250107228756, 0.035697510090446284, 0.047568490638607935, 0.004727540072053671, 0.07383795199735511, 0.04555876239112789, 0.043985225455535036, 0.007549495804273794, 0.16725989989936355, 0.18601491206115295, 0.13619756265994043, 0.11409304555385344, 0.08541274380179183, 0.18032120871207408, 0.11043800942359433, 0.10024199968263989, 0.1651421264414826, 0.1979032176877222, 0.07544236993717571, 0.08082237560302019, 0.15581391811851533, 0.13883727182063366, 0.14321771660639396, 0.12443841179652561, 0.1778573320517617, 0.14952226782277708, 0.11156636500550855, 0.16809418497066345, 0.07257615922078972, 0.22473878737899566, 0.09797215777178926, 0.18900463147269142, 0.08341336923260843, 0.15738507252066367, 0.060754468769676266, 0.2029891068776769, 0.2336507188456674, 0.08282983239980475, 0.1369170111513907, 0.1222939938006382, 0.1258230850761456, 0.11269590802370541, 0.0758536672219634, 0.15022392775262558, 0.09955208388067062, 0.16772748932482737, 0.10775987329261918, 0.11925431013467813, 0.0846644367782339, 0.11261600505320296, 0.14856341685498917, 0.10391980394600861, 0.1924674408209901, 0.24672863644457635, 0.1736412744127935, 0.2107616204528078, 0.17706107558502307, 0.12604564127902831, 0.21239115075478632, 0.1675939448778668, 0.07950194645673037, 0.12146311015972208, 0.15469284037188177, 0.26991496163029827, 0.17950872650309918, 0.1687199868742497, 0.1307395385998872, 0.16698006330238235, 0.08858420225160737, 0.13303499849092576, 0.14852096026222553, 0.13083211266465727, 0.09813158066883203, 0.13156387984992998, 0.14438837556348694, 0.14019189913186336, 0.17295536525066824, 0.23599375279680376, 0.18822152107473344, 0.15440664524512906, 0.11939956806600095, 0.16782873550490027, 0.14389291585933778, 0.12420474731874083, 0.10036934647829303, 0.25070040396625, 0.06616411054687155, 0.12753107044244968, 0.15481382097688415, 0.08778387019711156, 0.18588705198659053, 0.08586705692352788, 0.1657636995397268, 0.1282348447749692, 0.18296854810849314, 0.17519900695450846, 0.102260296623553, 0.10789209240747076, 0.10216982930057472, 0.17361164213188235, 0.1315236142686298, 0.18189528957009318, 0.14487226733997946, 0.1572801797620712, 0.156173090780935, 0.09998190517146742, 0.10899408690391049, 0.1752196300414301, 0.17253276050811814, 0.15458522034027886, 0.18884900837175309, 0.11009300172689462, 0.16056994517003337, 0.15915249864901268, 0.23151567776597318, 0.11870760680927385, 0.14149483082996261, 0.21244402614332017, 0.12976505943844396, 0.09395042599569406, 0.1597814874783639, 0.15090681852832918, 0.1808255550361449, 0.21277037959906364, 0.1353794420438428, 0.09415702458711402, 0.13222772567983598, 0.17695088149799457, 0.1540341886181024, 0.17385470650849805, 0.1377710153258616, 0.19687073034865243, 0.19001937621543485, 0.24534598563707646, 0.1817349014022658, 0.21199897502458867, 0.13919790005010946, 0.19465592419428213, 0.1628607472464923, 0.14121332416130652, 0.10951475090076847, 0.10084452017420724, 0.09499096491884801, 0.06873619712648854, 0.19092325271377641, 0.27970225580276986, 0.2730424083288639, 0.1138433698384512, 0.13909464671967492, 0.11205119907014793, 0.18052405347266506, 0.1438338045151003, 0.12875601438985718, 0.12069588076443442, 0.2246669742969736, 0.13981677651886018, 0.09187269595361526, 0.13655310406559898, 0.09610670303264934, 0.12129716785444368, 0.19664139426763982, 0.12365330190908526, 0.19720152711435673, 0.17827558541490188, 0.19518104682285942, 0.1463833604488642, 0.1494423035652407, 0.1993179829010079, 0.0786339152123659, 0.06895372013170874, 0.20001771228928722, 0.09400530853458951, 0.09941697661434451, 0.11868783407994818, 0.12051971884624613, 0.1339041099192635, 0.14130903918656612, 0.19455409578738675, 0.20190087898123651, 0.122179739447611, 0.24040419758567888, 0.15434574125514877, 0.06060738754909366, 0.10020133573561908], [0.055285547108900164, 0.02605683365536313, 0.03190308426236434, 0.023150818925651333, 0.01963536401519612, 0.016334266251614018, 0.009237350295147589, 0.012185618604323076, 0.046970532200629675, 0.007968435294911145, 0.022107160109425747, 0.049683111644680464, 0.0786366731288933, 0.07932351691828621, 0.014964052881564827, 0.08148982970704956, 0.020760551823543447, 0.06169213357591822, 0.030228486923020215, 0.04404130692203199, 0.009833436605760889, 0.026842437669514652, 0.022228703789052465, 0.012463229715884214, 0.04442373418339318, 0.04056260124930451, 0.05368368790274667, 0.009836067160170887, 0.04177024310094215, 0.07916288360232308, 0.046365280605612263, 0.028854784022475925, 0.07229567144907291, 0.04031393293952269, 0.051427654726731206, 0.047022840684099544, 0.0779967905292588, 0.007762146011490616, 0.07766382573472877, 0.038799105152007074, 0.05237587622456974, 0.011591833430312334, 0.04967060142887696, 0.034546823045539285, 0.03325832827437309, 0.0558451283723116, 0.062127543478122646, 0.03881983932167773, 0.056754214268538265, 0.0866441228877633, 0.07164719334292798, 0.021626344175949212, 0.06628694508465068, 0.03472102377864142, 0.06310646594952672, 0.04796019139429254, 0.017078392350325183, 0.02921941314613627, 0.042983010080793214, 0.06444253478079073, 0.04333176777788228, 0.05930593823112788, 0.07113271933649817, 0.033389114804806254, 0.09969383312930023, 0.07773940030845904, 0.0565731532180742, 0.0545642753281901, 0.04195552146542938, 0.03498605189604625, 0.01538162538406229, 0.029238486820231044, 0.01098012371409324, 0.013279536618821084, 0.05604529948604684, 0.029214615520510464, 0.016603712781122135, 0.02187161105534723, 0.09006021619443932, 0.016109453919794292, 0.05227539230198149, 0.07172445331009165, 0.06384923798783172, 0.05010290101410882, 0.044164313829594085, 0.027849159556471055, 0.07452046738997584, 0.010211718373841817, 0.043771938916536114, 0.024196098017836773, 0.017311637394971425, 0.06966546177864075, 0.041688589619532715, 0.005235177701369169, 0.0903826472800105, 0.022969593166283542, 0.0483207774889325, 0.020537332954606222, 0.0036585203938997325, 0.04756748706342713, 0.034916219151308464, 0.025082145734960516, 0.022687465966408773, 0.00832760556330604, 0.06296853181876003, 0.055289097926429207, 0.04638970348863833, 0.05284145849967196, 0.01118437616124509, 0.03616489267217056, 0.03196008694959024, 0.06698512697532293, 0.05326663729764762, 0.034777518932617484, 0.009938058360750157, 0.024843413585556612, 0.01943320490329737, 0.027187340029124773, 0.09738967047944184, 0.03827187578163801, 0.048201398007691874, 0.023045230942267566, 0.09972971668767353, 0.10257966335742705, 0.04176896756454822, 0.021952611446801214, 0.024550465393751383, 0.04123371725361194, 0.05973922990022167, 0.021351782094326713, 0.03811742479522382, 0.051246846485282146, 0.05347485999546705, 0.0017230371984976135, 0.03914050840502305, 0.03574470493702158, 0.06729023681292612, 0.03759966044115924, 0.028039716266756578, 0.05243036422818419, 0.013451044552869374, 0.01540368201301223, 0.031284226945811705, 0.027296768028228998, 0.04103756810147916, 0.05707347758054253, 0.020761697124990246, 0.07772241613917774, 0.04095890236297443, 0.03285687904985201, 0.051155559448224884, 0.03927332889889518, 0.06898729010455071, 0.05321712120466175, 0.03989021736948241, 0.06933762977320342, 0.07897300104941092, 0.07313524252705036, 0.028796657101221146, 0.02836641446206599, 0.008115900995870753, 0.06811062504927959, 0.031858687551932476, 0.0370284614543761, 0.01844119381970696, 0.04123880024698954, 0.0242227521319423, 0.037402369818019296, 0.049446758198281454, 0.04194363561128417, 0.037183536802448576, 0.015076393930001125, 0.04856261612486936, 0.08870181206974292, 0.03173015906565613, 0.009474680503650058, 0.04542542095746725, 0.051669903219707554, 0.09608505338790918, 0.037687783535089225, 0.06668773930399649, 0.043067658965986584, 0.06103529362007976, 0.015865664632480233, 0.035795776188493736, 0.034604605227228136, 0.04996576744522299, 0.02291139729711558, 0.0375648072710441, 0.03621746928641393, 0.015164943160338989, 0.05459583048979121, 0.021995169546214804, 0.01301067423135523, 0.05136741340280541, 0.005431536091266261, 0.05300067838341479, 0.041925349092531594, 0.009864335804576836, 0.06275695748627186, 0.007744278447071632, 0.03269541835893066, 0.047627536865371856, 0.02784613925482958, 0.01696820975461554, 0.06046308722767619, 0.0997910803304084, 0.035916515475799965, 0.03486107231207913, 0.028362043930457968, 0.005795695986072984, 0.035092810078734354, 0.05737693266822927, 0.04944885344875436, 0.016198616978081486, 0.01514922590896247, 0.0420914369545156, 0.029366676312600894, 0.018641276833330913, 0.05835936382232655, 0.11430500676074337, 0.023419696634875673, 0.033958953985523795, 0.02015808878857042, 0.05421257968391142, 0.07567444861295723, 0.03575399375310348, 0.01703400521599237, 0.03890736103658715, 0.04686401916607734, 0.03575219727692104, 0.0706304184671852, 0.04345826421593947, 0.048483425616136486, 0.012187681296059202, 0.04005951513986915, 0.06490423299011684, 0.10088626430520128, 0.13433226113838537, 0.0793604729997535, 0.002828275957595437, 0.015710300086216343, 0.046705687944326675, 0.037309397387528614, 0.051524200957388654, 0.036549032140042514, 0.002943923633034912, 0.06951211395883752, 0.011774143204092981, 0.05101096418295657, 0.08708306828573828, 0.02269682373040386, 0.01626939775662557, 0.045884874529175224, 0.06961116146656775, 0.026984073920175437, 0.030955222825850212, 0.01955816725028619, 0.030148005556134932, 0.06527259104674862, 0.029078127380700845, 0.03206333453436533, 0.059486079976082816, 0.004173465065598007, 0.03089687182387758, 0.05881925023371174, 0.06352011895468158, 0.06932773957810096, 0.09426031622194475, 0.09648602380747758, 0.10799513889416572, 0.03193909039480552, 0.04557368578389288, 0.03251318519394244, 0.054136028348077694, 0.025517011714738705, 0.03778506137971436, 0.02695925267142875, 0.07575620551623645, 0.062350609129475015, 0.027044987486254786, 0.01717303102205117, 0.02436948286729955, 0.06574159007399313, 0.0119326985065615, 0.035995740458489425, 0.02958913100883365, 0.02994896633730781, 0.03203667850503999, 0.018584375652754982, 0.09409065072935435, 0.027451822308883555, 0.032127247334668235, 0.04593001242967383, 0.024218216891430562, 0.020799436531360113, 0.08466445976087163, 0.01653060309528824, 0.055591955465535005, 0.07831179822284369, 0.0788156619115222, 0.022347847698256377, 0.033929812000884164, 0.024729241586981282, 0.05056603180785334, 0.05917427453002142, 0.0468933450118188, 0.017149006504745736, 0.09865504088661364, 0.08090955640880332, 0.048589295136832425, 0.017129580430205793, 0.07562809263265903, 0.07501505375389131, 0.041782228546517516, 0.05971296840617734, 0.02445478292722856, 0.010668901452464203, 0.08054791694326748, 0.06481940407426127, 0.03305991533242407, 0.005576979320105767, 0.05005147353175187, 0.03151103685189399, 0.03044076222595909, 0.014645467557373547, 0.03771085044248931, 0.042985963349741314, 0.046918840417938854, 0.047072686194892854, 0.05981427204284457, 0.06709617141994738, 0.06384418180753147, 0.02121293440371031, 0.009757856286371188, 0.04830963857051346, 0.08474520542809079, 0.012784555719624604, 0.03734895433749884, 0.05073254484863532, 0.054451147124411604, 0.039721716330536914, 0.0413742407615627, 0.02773771100046654, 0.04680436772985324, 0.03568518373574461, 0.02125118134333001, 0.023764597079265985, 0.02221079839904222, 0.04440792595907565, 0.03610892994930187, 0.03956680569136816, 0.11729654946154165, 0.08125223519821322, 0.143011118014974, 0.23026595853509443, 0.15848952615934034, 0.11054878573744528, 0.18398373718223265, 0.12079155748529781, 0.19859755381701455, 0.07254840385529303, 0.14234262969224684, 0.15746440858610217, 0.16615034411511115, 0.17934522801829925, 0.12489097057691506, 0.10136352942114878, 0.12048804111057713, 0.12131887112533855, 0.17122353156728132, 0.08936530549920375, 0.13527441138942398, 0.053262473609779155, 0.11947069932977039, 0.14107755805936553, 0.08700051465101781, 0.14027016267420786, 0.1602047357347704, 0.08529329537263802, 0.16905475197540176, 0.12752526349598362, 0.3279369594829698, 0.08070059826657658, 0.22356347060732304, 0.08855133707965575, 0.11626684302163702, 0.12928001853006502, 0.1915776296969383, 0.08334720987946757, 0.16786507871602813, 0.1133273559952936, 0.15254318233459227, 0.09342771654407825, 0.11287036922670181, 0.10149812340856561, 0.17088584001025847, 0.10468185458692814, 0.12231169809256831, 0.12874921152908958, 0.09783606991292008, 0.15315274317418376, 0.12712499021642631, 0.13044719944798178, 0.1447325329025907, 0.13496759317574963, 0.16888420548169844, 0.13810749646396409, 0.0867210304544818, 0.22187282181074544, 0.10085780413881426, 0.15370772791004952, 0.12041694049032466, 0.13566658711962162, 0.20570197743513893, 0.24604338611806595, 0.1764568313956261, 0.14316087288241233, 0.14799914713348114, 0.13159274604291687, 0.11033233525531908, 0.10756893353837152, 0.09500404203971548, 0.13489254720268712, 0.17896059059327651, 0.14384920288237835, 0.16803544134862963, 0.05980875237935013, 0.09285459084616554, 0.12476330202433372, 0.20193362157912026, 0.1595308847965733, 0.17896276628298147, 0.0867495748905405, 0.19795790104375732, 0.13628875776644678, 0.1031263283784351, 0.1361596719512055, 0.16367189646247896, 0.13616028482154494, 0.26042539986871904, 0.07809147899669987, 0.15865204405159722, 0.23443490176671938, 0.23972302284692568, 0.19790505629874047, 0.208352503757323, 0.22122465013977022, 0.20806155888543976, 0.10121320764864646, 0.16856034947258813, 0.14226704745763732, 0.1567114054435684, 0.15142356015501485, 0.09841150919636411, 0.1851909538550723, 0.17380616717761563, 0.11812006333662618, 0.1328873886696754, 0.1445743051027098, 0.11503721061613291, 0.2266020051413967, 0.1229737512767315, 0.20364748283980355, 0.10979642610876791, 0.16248419970994996, 0.1054623143206681, 0.10441040665271784, 0.13842922274864491, 0.10706906882865776, 0.17438952781019673, 0.1004215860138497, 0.2458274106104528, 0.08350681663761217, 0.2587872280949547, 0.21674243823414852, 0.18429761872656886, 0.1273682844194193, 0.15997403601725257, 0.09722270161634493, 0.10089600128271889, 0.17362184642303377, 0.10931538417935373, 0.09673897837919575, 0.1928723182889723, 0.1429792640790824, 0.21905919536948207, 0.10832787386231846, 0.21383868920947277, 0.2037036524064118, 0.13073150999844074, 0.10203125165595163, 0.2168408345671431, 0.1371043962576697, 0.1853281142370355, 0.15711927065445533, 0.14924056197126068, 0.15152390235133711, 0.2119023406938199, 0.17858189801054616, 0.12178850600556021, 0.1034377584414136, 0.11421517529074224, 0.19362363603807267, 0.15097339156894915, 0.08682560911702533, 0.11748817103404192, 0.13599055038104135, 0.15886877032537616, 0.19098084720392383, 0.12625141249549005, 0.11126382156245171, 0.1573554402397525, 0.16885057422182254, 0.1400514292500673, 0.13784348724349854, 0.16189671752433624, 0.17859236277159185, 0.09089348236879996, 0.12302601379492592, 0.22515949222349355, 0.16621838804454575, 0.15676916847305913, 0.18226540196807156, 0.15129539364528272, 0.1579310174190229, 0.18459659219989855, 0.13202455916231678], [0.03558822764804767, 0.01876988767405912, 0.03428860928022093, 0.053976348811580296, 0.04543328485000999, 0.03781989539763139, 0.06798012963225765, 0.01199337745821404, 0.006281136696587407, 0.08242571335886756, 0.08742750141649477, 0.028821112542983987, 0.0918567383421525, 0.05511290153428432, 0.009898894030841128, 0.04927675562700437, 0.009814357186006683, 0.03299982339564351, 0.06030311657776756, 0.07038036736870004, 0.0391837578987883, 0.03684922369317182, 0.0757723393279218, 0.028794450767999216, 0.06858664910278975, 0.04981594746031108, 0.012524064757951326, 0.0744975537001606, 0.061866284513305274, 0.0026966081866468756, 0.013544269792375066, 0.014175219806812465, 0.06479439130353351, 0.04510558307951978, 0.060836325264385635, 0.06740123529227511, 0.038491869420414014, 0.02856871530023073, 0.0043846668878329866, 0.049817590718908664, 0.06455943979803594, 0.012213301191466951, 0.028474549687797987, 0.03664475482618136, 0.03465806284258443, 0.019968060678952647, 0.02663997978332543, 0.04308500702703192, 0.04207279037443861, 0.029407782675397974, 0.06851357197569263, 0.01589097138944893, 0.053069587992203814, 0.03365991539472053, 0.030981039988898465, 0.010787060938685412, 0.02311068549451809, 0.03172982198696944, 0.05583303567442683, 0.06974992297229267, 0.024990582906250513, 0.039860588919010856, 0.026726162759587172, 0.026018113656450185, 0.015553814178753286, 0.026792161234263933, 0.06374388174604505, 0.0696424178538784, 0.06132344227103938, 0.03826059513695298, 0.03041316965414632, 0.030889647614751613, 0.027654582799802867, 0.01539450236445954, 0.012756030435764022, 0.03525284584611654, 0.01904251155323319, 0.032372282472469156, 0.02330745709308934, 0.037034341179194956, 0.037113420605178804, 0.07953786065862065, 0.06855906227663641, 0.03350303590958638, 0.03110913563549759, 0.054983122409471584, 0.049363377188602765, 0.045254215628149054, 0.10142644822236993, 0.02821532085597996, 0.06535558901246517, 0.07091712687284717, 0.03736395816949587, 0.0819730626479272, 0.020918400409901818, 0.051029637576110905, 0.10941659205503042, 0.033229006259071256, 0.02962452427093541, 0.036858577626727285, 0.04203648163726734, 0.03371834875114503, 0.01709479620800384, 0.03649414960114706, 0.0471317898782511, 0.066618247468385, 0.054174922631993416, 0.01287144062394697, 0.026587782382604577, 0.04664555004227065, 0.015849190869278485, 0.05115346419775198, 0.04680362462456669, 0.023518114035288175, 0.10851754191061182, 0.0360395300442413, 0.07909860882547595, 0.044048508148520224, 0.01590612843903082, 0.09165708050732652, 0.009288928122259676, 0.06455173295351767, 0.022423269054401788, 0.055762528772315675, 0.06314821391096039, 0.008136801789664935, 0.05671771783982554, 0.017238569843973366, 0.06581154156235919, 0.08374819562079446, 0.058839061267433636, 0.034371637889454444, 0.03832906041474592, 0.030799287544082732, 0.04040403254029732, 0.04352949507113907, 0.031424673844970046, 0.030485109140675877, 0.02587641803397527, 0.029429558724645647, 0.0570040661841631, 0.012919167901629643, 0.07031058441967734, 0.032512572323603016, 0.03574990667402744, 0.007993516055942184, 0.039141542623720826, 0.07181014024442242, 0.012208324492788844, 0.015978827310215323, 0.018594794448525197, 0.062094168857701366, 0.05665780210326757, 0.008361797024976582, 0.06819933037003202, 0.02537728302300938, 0.041318519356390165, 0.019132065316361767, 0.036944724213812626, 0.06795066589068982, 0.006690929576213802, 0.007863531523804751, 0.014179547245974743, 0.08259418375429609, 0.07623428268538368, 0.054895853503577174, 0.037228475520086866, 0.0873027976241804, 0.0565893521472331, 0.005487431302636622, 0.06561196799720488, 0.04854993353928289, 0.028914705504693335, 0.02052205524617626, 0.01229768481871654, 0.013861221434067816, 0.06982515280645701, 0.0644536430556928, 0.023136832075373783, 0.054229962218913345, 0.0160429670640658, 0.06677517291879462, 0.02197745950862525, 0.0834438442102363, 0.026434250701699528, 0.04809755095911603, 0.08458753687239463, 0.08769875782872401, 0.05494292194564497, 0.01846126723854292, 0.01945020056389753, 0.034264439206209876, 0.041707205556092725, 0.016517252097987843, 0.04370221725454734, 0.004234163169448655, 0.030000962639948534, 0.06725380167124734, 0.08110184447779771, 0.05448009758707016, 0.009761730776048236, 0.04481780981164306, 0.06321774022052846, 0.07415001025243152, 0.042672453358048396, 0.01619780684010156, 0.029474009061232213, 0.022520910790790955, 0.025362455391234932, 0.02855592737755468, 0.00831181840640643, 0.020487966248765588, 0.03863278746364578, 0.028521750280032718, 0.03595822130239779, 0.021034617863234975, 0.010050072864208733, 0.042625361933342876, 0.06141598569229246, 0.02339368411940673, 0.06176861213339914, 0.0524709209228956, 0.03846680685397118, 0.008994878679063291, 0.011977091386553743, 0.021522454992537538, 0.04645027806081119, 0.023576183499948635, 0.09636340377431724, 0.036754232621000665, 0.06604914373207478, 0.018142136076705593, 0.07564371316543511, 0.03879532833854037, 0.041959229330982895, 0.11098189354543725, 0.03672530897141945, 0.028880679709536415, 0.04234911445828696, 0.007433402361423379, 0.01421024917715019, 0.026791772444642363, 0.00860537276528175, 0.03723868364167791, 0.08000554967551463, 0.05907603141461169, 0.033532526464231556, 0.024217351212076122, 0.03426761464065602, 0.03322024221321748, 0.04576814571215261, 0.03339589851337575, 0.03720126024657681, 0.0032982720961538896, 0.0171011968726112, 0.07454760222425384, 0.055196271052644144, 0.06859507606995684, 0.024121153551424225, 0.03049341544899489, 0.07417709912143408, 0.04513143854696424, 0.033079090513168805, 0.02938004454687959, 0.03178275674731741, 0.02252805073024525, 0.030471957326235793, 0.08377008275279114, 0.037083562328329975, 0.08629529241232142, 0.026026998361152028, 0.008052648946402535, 0.07021148328579242, 0.012861005548808365, 0.06898051788730007, 0.03781371306808245, 0.02703691291953287, 0.015955135083547043, 0.10838723801557096, 0.02515841170304245, 0.02427947136663622, 0.038586442974666436, 0.017733443490860444, 0.0399951484324711, 0.02797803852797276, 0.0412347667940682, 0.0551116987762432, 0.0373679724702191, 0.07881743157462728, 0.0327986563676067, 0.03736611470700272, 0.07183383534392042, 0.05055107394113176, 0.06202458126109935, 0.05236208281149307, 0.026055347444790027, 0.03341486685038094, 0.009572436195617963, 0.04135346445705622, 0.011871517767318556, 0.04261411576261444, 0.02883340442372907, 0.024008467763421998, 0.04319210611884633, 0.024857387029295488, 0.045951462891553684, 0.049747876717799136, 0.06716857438967114, 0.031681671445708603, 0.03322874961961662, 0.008750968732901158, 0.012948899773970969, 0.04705839865510503, 0.08501576470030893, 0.07433446124196053, 0.01836351058896511, 0.05961975848843014, 0.010734681592082546, 0.10868456439986345, 0.015515730990427396, 0.024583543155102, 0.059690966360992005, 0.028443138167682677, 0.024953115461093765, 0.015490994968962286, 0.044830695410529454, 0.0602631229576805, 0.035826714649315805, 0.07991407111647629, 0.008850233618079895, 0.05246479221950135, 0.03348905863540788, 0.05280239950685252, 0.024282416974705075, 0.018101908799801624, 0.024453670184518543, 0.051251669008765495, 0.05191342341863821, 0.035287997790522156, 0.049582865209348743, 0.02121818785165106, 0.020003028762256427, 0.029212108497778257, 0.05351669222657239, 0.03798130629283767, 0.04213866244460787, 0.04912040857297759, 0.07951028915422578, 0.028651902872708537, 0.014275115756918828, 0.022197378453828638, 0.019684696247080163, 0.2033156748380392, 0.17155172363404306, 0.11187945747928274, 0.16858086530720034, 0.23761620444636192, 0.12981226577633811, 0.10057599869586768, 0.08592060646943508, 0.16266668185351357, 0.1856886198924434, 0.17857604509880468, 0.1408009696751833, 0.12175623072131027, 0.11479752468726329, 0.12200926956270011, 0.07977832799717303, 0.11066442670961542, 0.07108471626716276, 0.15297557768081466, 0.17025418519493074, 0.14824414205166603, 0.1947125840571619, 0.19201019358250404, 0.12535398645747092, 0.20564594576435707, 0.12421623863760503, 0.16365210075051556, 0.1241054316802371, 0.16856303078032311, 0.15024548546681482, 0.12631791658819685, 0.14399413139589373, 0.11796737435243784, 0.11308882685918963, 0.11149074446650283, 0.07910940300432906, 0.21704850568165704, 0.10682191354252639, 0.1327778227747448, 0.11298088507065851, 0.14421232855848728, 0.1858046668912134, 0.19788421870720005, 0.10478873917412375, 0.1584871206432581, 0.10690349424558301, 0.11800603880997627, 0.1267935805803826, 0.07285909081298499, 0.1059378787214237, 0.14575276283487199, 0.19628177727422408, 0.19689198162767196, 0.11218638294526648, 0.10866964866797771, 0.11568883734364664, 0.1670760694410532, 0.15691778953036956, 0.2928251274410756, 0.21712719823323914, 0.18755235859463293, 0.14448940723894105, 0.20079792687489142, 0.11863305113248288, 0.13397678101976074, 0.09910816657206706, 0.12446976011438717, 0.1632661150107461, 0.3042308283188651, 0.14734734420574483, 0.12525853956298483, 0.1772572707024313, 0.16502560446819953, 0.11808334474241543, 0.1850163624171288, 0.13760062204974313, 0.16092079811759535, 0.08079176272956595, 0.0950269174251345, 0.13126590229090185, 0.16348045109020126, 0.2107157624296604, 0.13738752703272528, 0.1332025725634829, 0.12271133551914847, 0.1975263024289762, 0.14047383480975706, 0.1738360139631456, 0.15762530237195954, 0.15815393368323005, 0.10097005900235907, 0.17903191337902702, 0.11952443273677943, 0.26968007907271385, 0.12835047808626007, 0.18039260810661703, 0.17344725498509023, 0.14316834990055333, 0.2638784339351039, 0.13209338450143415, 0.14396425396684678, 0.13034684192990104, 0.21734467527318388, 0.10673483998905267, 0.16401090569073157, 0.22341481890649567, 0.10564204620858354, 0.1508896581588253, 0.10062223210209802, 0.20823310129344466, 0.12087510703431985, 0.17493113665090454, 0.1364353563516371, 0.11698116638487387, 0.14649340131830785, 0.18143865520194655, 0.18057764898384773, 0.10778025889228429, 0.15593546562858168, 0.17320281165021081, 0.15940333115718058, 0.1340969036062879, 0.08373993719297071, 0.2369925322672052, 0.1466527629283167, 0.09604148596765534, 0.10293536564154972, 0.08723768015061656, 0.1854213777809374, 0.12390064871719769, 0.1229087104119601, 0.09797927472860583, 0.1010051075248949, 0.13998382965162878, 0.11194278996798301, 0.10742212810944166, 0.22781277646220502, 0.11409297660594026, 0.20824397974196943, 0.18330456959384103, 0.18033423220678685, 0.16501152377215125, 0.26926452233906717, 0.1562526413509923, 0.17258025795942353, 0.12369645564185998, 0.12796748775027453, 0.18717642392843, 0.10558502628437935, 0.14003350279263913, 0.13772166394177945, 0.13705959543585777, 0.19263476974541144, 0.12223941003603321, 0.18537528993141267, 0.12025262229144575, 0.10809617823049908, 0.1278019361498375, 0.15278105263508138, 0.2108037859321602, 0.12943204101775924, 0.20974640073555134, 0.11900160071109572, 0.1702338991866958, 0.17590063624083999, 0.11676230272578618, 0.1590606753504084, 0.24106082686733818, 0.13708099993246217, 0.15288645101170387, 0.13363308333341153, 0.1554683664993894, 0.16252798929570184, 0.0952388556493867, 0.11905057671209497, 0.09827493870210263], [0.03637858523776935, 0.0413459453040794, 0.048707870225752556, 0.03118596084776425, 0.07487988520053125, 0.04611901398147306, 0.013732554094355195, 0.04171354493366615, 0.04752264027633975, 0.016677352982843598, 0.0858832213787302, 0.048407264985144145, 0.068322318125396, 0.01939948171287054, 0.03946062973550251, 0.02860080289293922, 0.01276061547199084, 0.039202584509527495, 0.03411148592168766, 0.023905135908975236, 0.010354479816141389, 0.04027396613251298, 0.056408279605450175, 0.041593414686259725, 0.060043225079895034, 0.026795859523718397, 0.06200105087050508, 0.03291816225335483, 0.06083141847123062, 0.07167763001615964, 0.06864276504324329, 0.050678217723484964, 0.0503185432734749, 0.06803615364216029, 0.028603819364141074, 0.03474324032844555, 0.053430108969370206, 0.04403980155926078, 0.0588917451339864, 0.043658128894505, 0.0384934245789003, 0.08182459480820164, 0.01670757515145646, 0.07435551333811975, 0.04495458714964409, 0.006504875068898283, 0.059365746715376456, 0.034740536038072846, 0.051070795649842876, 0.03930583783996202, 0.026756099560448242, 0.07292086814319895, 0.037284177773061304, 0.04835776421391676, 0.03784283590052397, 0.015429926270078269, 0.07679314382614628, 0.03751675057555399, 0.07578045219903992, 0.027808319409227664, 0.021451528657287843, 0.07027632496770352, 0.06526079329271471, 0.028932823484102567, 0.013178306718116567, 0.03743230470366055, 0.08232861937534425, 0.049312236989217426, 0.06551018555558498, 0.007491742829687053, 0.022123023875117786, 0.09175542321416641, 0.06946447095082653, 0.01387608066696914, 0.04346429332790356, 0.028567736622907465, 0.02493195228218552, 0.07212448144151319, 0.039188239513145345, 0.020291420646132003, 0.042464433673528895, 0.04369922185076341, 0.051499682313372055, 0.05404348492682461, 0.022662529804473443, 0.07248234409358233, 0.08050339957398754, 0.03121642050363364, 0.017726288229647665, 0.03310336400904963, 0.04152131815170569, 0.05870990650427919, 0.04053827029682937, 0.06425003603761716, 0.038323372211908145, 0.05458353477860651, 0.07930421150259434, 0.01494851853368023, 0.015318105203820574, 0.02489057970383475, 0.011308678715009124, 0.0587850061034964, 0.05451514227916637, 0.05900689197944538, 0.022369388175467332, 0.06646800230467512, 0.04389355920495526, 0.016846072356847507, 0.03331110024103715, 0.006027181422518146, 0.05462893314899937, 0.017369980736064817, 0.035554454661905766, 0.019183902655758204, 0.015739880656192622, 0.06955958076662595, 0.10060419839236046, 0.01995258378766237, 0.027234492740864237, 0.02461211057379842, 0.046262008122979634, 0.0314235381196223, 0.07242521691706873, 0.04711583226678833, 0.08246553460917166, 0.04649217540939008, 0.0718982250339562, 0.041281613070637956, 0.03513749215691801, 0.0719115243203217, 0.05107052368862976, 0.06708341605600811, 0.059972047850850134, 0.0739737717254508, 0.08915918954317609, 0.01904977023631575, 0.04281250572192573, 0.04898988251243869, 0.01607855950902787, 0.04224923191471927, 0.06163825461220357, 0.04004957514905161, 0.03330397179290172, 0.010808533425593089, 0.040458313700172215, 0.05169153371224961, 0.07080440469566854, 0.048797625086961255, 0.007961240771692246, 0.026111448063485088, 0.04192072958234818, 0.05764116788463247, 0.09105512692082314, 0.011991774419232482, 0.08059169120726087, 0.04893994890153409, 0.04125375811371111, 0.07423657052699598, 0.01230036038079209, 0.031523924366000204, 0.047928869889508334, 0.02337014223749359, 0.060344722812935236, 0.052764367071851614, 0.13781365577972707, 0.04934508300897095, 0.03203472115039345, 0.05734468036661706, 0.0452188415182454, 0.06225423526860053, 0.03747447784389219, 0.027119614026178757, 0.006341659557825376, 0.058341594412922866, 0.051104369453124465, 0.025308944149723938, 0.07361792388462252, 0.017084660864765608, 0.05801131475656744, 0.06314987249131646, 0.027144653609983867, 0.04039937089527807, 0.057437143348638094, 0.06990929990405999, 0.016530074494620486, 0.02113760497811581, 0.014757590270751427, 0.05974463082008785, 0.023840886029985645, 0.047855831066807436, 0.06683653656152949, 0.026814285853517153, 0.0589490868151188, 0.039686288594478564, 0.056568912921413306, 0.05008722685517804, 0.03784844749456933, 0.06977088313790099, 0.07361798517165646, 0.06710832157442648, 0.13062706157084436, 0.028528081996726896, 0.15137200243771076, 0.0630226137957746, 0.06141187563057869, 0.043148983029588577, 0.011264102931524958, 0.0524223662702547, 0.03559583107069616, 0.049749696176619305, 0.04536796436314622, 0.041006993532421133, 0.027042438328686743, 0.02031520959140072, 0.030210252115202528, 0.010447799859027709, 0.046286362058092514, 0.012611314511647629, 0.07320883293305674, 0.021019125650186214, 0.02912296459168917, 0.03356515414892666, 0.037873264912876396, 0.014392062908999864, 0.05879233756493177, 0.023500714263307954, 0.0637744946194993, 0.030907505124266592, 0.0390427096206094, 0.06827167971360107, 0.032953601480732043, 0.06095074815675617, 0.02402420320938672, 0.0796577304361328, 0.03438805515367178, 0.10015586841731303, 0.03723187695047067, 0.025891952381859866, 0.056036485644477996, 0.030792741322769757, 0.05096489548562996, 0.055827776480826645, 0.03128631453540537, 0.023711147124788935, 0.045246662001215646, 0.0168661515213429, 0.07851309548582762, 0.039574818971056136, 0.0237570472827722, 0.015412146326965623, 0.030164076165566524, 0.017108643247235208, 0.0980599131435156, 0.028547086722908482, 0.02374956260375198, 0.07035030607855128, 0.033038468700983835, 0.018673421882633722, 0.04361967511114575, 0.05097940519091584, 0.10202704583324733, 0.0657009567704893, 0.038753978742827336, 0.02099614875811723, 0.10169618778050908, 0.07466788568924512, 0.04191042953020623, 0.019710434886116176, 0.05299782470589685, 0.023179028198243152, 0.03403556277795184, 0.07618685418199148, 0.03947646094245776, 0.05675381590281764, 0.031856061785572, 0.009543264525071269, 0.03372364241870181, 0.03734716935263526, 0.020049457520907445, 0.07232951721356762, 0.0337427563124126, 0.05628481304513351, 0.039317221906516826, 0.05573188908578408, 0.03741028350627711, 0.15293269207881344, 0.025699110814340176, 0.03218650232039152, 0.07598670605089396, 0.07990239593651026, 0.02935351875250138, 0.04071328308313124, 0.04686764659239881, 0.03580030759856586, 0.04040143550223401, 0.03534390688723615, 0.06055262758426609, 0.03654341671555754, 0.050664608171510125, 0.033721432255040255, 0.05570737044176748, 0.08147159681445168, 0.0635707343838388, 0.06266455962172439, 0.02326121219554015, 0.031734826456334804, 0.02896670372255387, 0.05022734050608931, 0.05891201965090248, 0.03788253457676019, 0.003074501883313661, 0.03934692313534118, 0.026404170259352655, 0.02991573344315252, 0.00659577283752902, 0.05010409228083107, 0.0247611376577087, 0.009716860048713223, 0.06743939413178353, 0.04471006720597225, 0.03774939232595986, 0.08805339525063192, 0.049334936174413854, 0.04904731229368237, 0.08736193961193485, 0.08860273391849573, 0.037912768236691916, 0.06043245520202383, 0.05599779054342259, 0.040554109164663864, 0.009480068016977561, 0.06666448087461534, 0.03480501382821991, 0.010334947446901954, 0.014066015888426094, 0.012403049678992362, 0.05815148203363342, 0.1374332931253218, 0.01596469681845197, 0.07354915217165986, 0.04658357735963599, 0.029271156639761986, 0.07847081509328659, 0.031212205104830287, 0.042517538888440023, 0.03303333208145153, 0.06916537490342894, 0.01834944712989513, 0.05714399980441217, 0.022053325195766745, 0.018089653308232947, 0.002771506687783967, 0.19580542380290647, 0.06753839567423829, 0.280670958661264, 0.18688744024163295, 0.11776590855011057, 0.1234452017853337, 0.131721418170679, 0.1085352921678174, 0.11521867386275723, 0.08915680700973158, 0.169468684602649, 0.13668228181139117, 0.1335751824080944, 0.13391488111547886, 0.15466074128785443, 0.1267110422674206, 0.10825842799198244, 0.13505932454380298, 0.09994736992784085, 0.29234025507204, 0.14188861534480127, 0.16186449586624102, 0.22392091191103383, 0.2002664610383011, 0.20021744673290562, 0.13342728147343283, 0.3805440640257251, 0.15300165531375717, 0.216652468868321, 0.14618281395204608, 0.09492996899831681, 0.13162204124514135, 0.11987127138361817, 0.1602996999938642, 0.0940405102747102, 0.07890119562826811, 0.11259615571508486, 0.13144711272851115, 0.18228004956918378, 0.20439734502184778, 0.08612543539774996, 0.17085449169239691, 0.12353254346958092, 0.15585642067655442, 0.10634467907009587, 0.21911709629479917, 0.19246023959450184, 0.11668337268694756, 0.18794022891069614, 0.1347380732336352, 0.1622430045878695, 0.3046407466453891, 0.10393103479497856, 0.12190014033788636, 0.11757752752952999, 0.17812264362169852, 0.22666920637411458, 0.2312807952083888, 0.1881754638687257, 0.2694593231764532, 0.10918570847641076, 0.18032537623038217, 0.2518634020441002, 0.08003341995419995, 0.15725097649039763, 0.11094450079385312, 0.1537915379289658, 0.17260048268062456, 0.16941357223737627, 0.07734900190224571, 0.12836026868993236, 0.23105855310155501, 0.19019415151448021, 0.1117219727846884, 0.12645199729670442, 0.21300262681418852, 0.2587169318670227, 0.20415547574239395, 0.22777343018641397, 0.1299035221698784, 0.18882772644921658, 0.07773055965381284, 0.16677554847011644, 0.129259257547317, 0.1563762419766957, 0.3665075865724395, 0.25557456177569204, 0.1537591477315272, 0.20365506711025394, 0.218875058476002, 0.11791590856568468, 0.13122477869112648, 0.17955967135006384, 0.165946610692528, 0.12243782680842186, 0.14685979052897424, 0.16945294915668427, 0.16842315844710798, 0.1222331434368126, 0.11872059199959041, 0.08751483543986276, 0.1189317794576768, 0.13701736866947145, 0.19388772186733064, 0.17709296016443163, 0.26191740206653075, 0.15519576177241343, 0.15053612390352836, 0.09408255317999471, 0.20603464345537847, 0.12985501348251297, 0.13447682192969707, 0.1926072212236543, 0.15501219178399733, 0.07908457409470313, 0.08860824975155054, 0.27595519719104616, 0.11507959826098335, 0.10953224068807979, 0.17271593213081363, 0.13120027919930796, 0.14018138840554223, 0.1792409328082877, 0.25035731915024023, 0.1574937497536021, 0.2880283445119858, 0.1483314913967925, 0.08924306084912631, 0.10108166269116825, 0.08975668449796016, 0.15909067535352323, 0.20374258499472372, 0.1067767603202693, 0.21775831678701987, 0.16760614099762133, 0.1888722055141003, 0.11963182294200506, 0.11815787743656866, 0.14369851338767237, 0.1655595830731815, 0.16666616643628768, 0.15540930112042736, 0.15502247268394118, 0.08040061355718682, 0.10771361690375114, 0.185410606584722, 0.11528986641356062, 0.20168194637423564, 0.18743860985963576, 0.09806391212248033, 0.08797174559966212, 0.15877523098982152, 0.24655614408754536, 0.2226585215858875, 0.1365269191803471, 0.14136766023453207, 0.1255517597160032, 0.07838106789295712, 0.10650535835133446, 0.12345748217475992, 0.22145109040842903, 0.2722751865944555, 0.18727777736081233, 0.20448069538800948, 0.19869974994611359, 0.22867016674530125, 0.16878369474603286, 0.10758755713581078, 0.17876120855010327, 0.1255449415334771, 0.11864261957065714, 0.1267169641270753, 0.09530835514587742, 0.18085667352762916, 0.06423567954991614, 0.11649104631355695], [0.03425029722312766, 0.016784092013333595, 0.04300560584411987, 0.026851824161806898, 0.06093305918658453, 0.030871929916282816, 0.02379785487127881, 0.04301465334250562, 0.08074206660591787, 0.009757567088179772, 0.03314942121505737, 0.053537932014273065, 0.04992441018863071, 0.04039233437769356, 0.013542763471993948, 0.033757181748026804, 0.033840696823092244, 0.030442581684779257, 0.04332411455951872, 0.0619514619991664, 0.01546791178219381, 0.03334248686329492, 0.03820834411007743, 0.043562095942756826, 0.009487955849767934, 0.008721729072051184, 0.014046698981415362, 0.04483601206072396, 0.05785113343247964, 0.026827724950928843, 0.05821624710675209, 0.03298893728623948, 0.02897156263521362, 0.014399852107969985, 0.04282625316972694, 0.029820049061409892, 0.06201732640845641, 0.01815021638908694, 0.04070472588101703, 0.08603725101678603, 0.05414933146488282, 0.04006146866407606, 0.05546535177516842, 0.011014107374414321, 0.14194763475848785, 0.006849664909344528, 0.052320369324016, 0.026440647535867272, 0.042315100154448906, 0.05544844804511917, 0.037757237066304496, 0.05920725461516169, 0.021586553569162087, 0.049877992921298554, 0.021178261264257377, 0.16136692175942083, 0.05385222341564875, 0.021246757185567292, 0.10232634872438447, 0.025084302272467364, 0.031090399040089502, 0.048184026964008815, 0.04145443867591601, 0.0479548862354169, 0.04991347811395123, 0.028426711327366294, 0.025321601837452863, 0.05213310296136526, 0.12174224195581292, 0.018536476005289345, 0.03644584775752118, 0.031759710907335245, 0.047072893038632414, 0.035586511611097285, 0.07153543643653393, 0.04568789417164461, 0.053890045176470475, 0.06602485874487508, 0.011523587445187713, 0.028641298300616687, 0.03194354902652483, 0.00787154719751749, 0.07418494386177871, 0.03198386248832028, 0.057300419636791756, 0.05467477201994869, 0.04852992332270069, 0.06660464940772903, 0.02285445398170381, 0.07775682114785717, 0.030805937187265486, 0.047503806004721316, 0.031998435395859906, 0.04655648466019381, 0.049978790939935756, 0.02692752130960505, 0.040761021852132776, 0.03191662678164581, 0.044937756197947654, 0.055442376798319246, 0.10977404868049968, 0.07212442015447924, 0.05637325406555207, 0.054919138746035684, 0.012596981964194247, 0.03411050532914458, 0.10960747818312339, 0.01152117043778661, 0.006240376030966159, 0.0456241786389822, 0.04710465504397308, 0.05878795554200488, 0.08719949832847042, 0.03327142837787828, 0.04797360176340707, 0.0034749166497344817, 0.03601966921480433, 0.023559065265280586, 0.021526371617050424, 0.05936342929940551, 0.07438521456694411, 0.016790889128441774, 0.008988388956734731, 0.0672426091266736, 0.03757002816024808, 0.03183393525109897, 0.035213292726585944, 0.04843187172927203, 0.053580277524287664, 0.06005237983059018, 0.04981499751128497, 0.02267122490241403, 0.060041424773272976, 0.02433555666357279, 0.061157473152683633, 0.06731295131988103, 0.0546847235020851, 0.032956121910002925, 0.02461773940482207, 0.007102011877577753, 0.01927549804320499, 0.03656393255016977, 0.023743154278265375, 0.030985010239566048, 0.09366551789665416, 0.02733610855836061, 0.022358482913865198, 0.05269690919967909, 0.021668825666570378, 0.029764655158824982, 0.07422598319188242, 0.06047227262188831, 0.057952138294856397, 0.02975894780378909, 0.09076654926062593, 0.03122283074434006, 0.08003320544958115, 0.047329505680189024, 0.03689088738493381, 0.10756259799123773, 0.013016657378043861, 0.04358055866173199, 0.05255216837770516, 0.03520055268440516, 0.024470522203632904, 0.07269629712907538, 0.13160443654464138, 0.03136381198982558, 0.021832481199394793, 0.07447118495380686, 0.04427557660927696, 0.022406978194691965, 0.02332001901982773, 0.030876283210912542, 0.05984939334373321, 0.07723552895890129, 0.11788970069779504, 0.05908949540988092, 0.04171764733450067, 0.08600179646765033, 0.08419752151014344, 0.04258805728187004, 0.007314080336777073, 0.017363497717005592, 0.07549069476343932, 0.008194799433582494, 0.060108595362473885, 0.016949419533052755, 0.08058109621126806, 0.032973443157970905, 0.03291219825886431, 0.09248973381134773, 0.04820974453562691, 0.042376747249715754, 0.13071592777006089, 0.04042406190907763, 0.07217247684996936, 0.06444497094038995, 0.07521800576679169, 0.06425503859176271, 0.027788786082378322, 0.014167580952597483, 0.04533564694406045, 0.0314722019397924, 0.057059297293064096, 0.04416691469809702, 0.03938349617284633, 0.053455091096580996, 0.030658988116849816, 0.030538421199326555, 0.04294431497973781, 0.029027194025055058, 0.022998306141685576, 0.0491944509708593, 0.02689681650559989, 0.10662910453374348, 0.04238943366574184, 0.051049946566983584, 0.02048125148810927, 0.06354104081589369, 0.017392452010103775, 0.0707672264487032, 0.028617900060189348, 0.036311966231873924, 0.05514049219087728, 0.0380582521639524, 0.04109339675896111, 0.04018339921810454, 0.03343443656640668, 0.05847587813473037, 0.009991946900563856, 0.06887007099125655, 0.03589095878264597, 0.03628804896687789, 0.030029290656168616, 0.042467360129399646, 0.02706479468953706, 0.03343463957970662, 0.044755959703076276, 0.04004749522033719, 0.04082048559681543, 0.04061093373644737, 0.07728074346819232, 0.04146865343735103, 0.07497731626274125, 0.05003102664505282, 0.0512915630374224, 0.012275156088083262, 0.02651857399952508, 0.04092537452496829, 0.026845701204072085, 0.07081434085604645, 0.046859889952165466, 0.07162720610898349, 0.04126618405984294, 0.019049360379276258, 0.027273653240333644, 0.05377792054787279, 0.036137604620307684, 0.043825465479805585, 0.07173274238143237, 0.07370652195306555, 0.07796040135285548, 0.011944787374006645, 0.05207458150482947, 0.04489415047329761, 0.041372279576476545, 0.0022311262211822456, 0.07543802621864504, 0.00391006775786199, 0.017819021257662007, 0.012008189768230003, 0.011567575256189993, 0.015868780695112245, 0.028807167827542272, 0.029686703797309633, 0.013291286492359736, 0.056387330931160724, 0.03150321509418709, 0.08629033582345133, 0.05894100458751764, 0.03922025432750102, 0.043838737953093745, 0.06493201133825126, 0.0479913060553372, 0.018113635690702547, 0.016885587171981895, 0.019446691881204327, 0.01150380322454317, 0.028620922277050636, 0.06498060429528837, 0.03484943543650931, 0.07884695660322905, 0.01785686983156108, 0.050909105132544236, 0.04798724578933851, 0.07360654747894696, 0.04693878551704749, 0.04968455188997811, 0.04875993356108666, 0.06167017366556872, 0.034506105472363775, 0.021086156428340944, 0.006975584866238699, 0.026813966011808767, 0.07938979118461571, 0.06108535746593149, 0.033596950628223925, 0.07139085266258448, 0.03748829423960659, 0.013266011336517912, 0.07399103934726409, 0.043806715477858825, 0.03283166709626394, 0.03873900172390765, 0.04154313250534958, 0.03151522352240019, 0.04656648593804529, 0.04059606396983709, 0.024090751352149154, 0.046036245842133804, 0.020946990811235962, 0.01885040926056043, 0.07941852714265547, 0.01193187017399337, 0.10825874974891063, 0.04923811798254329, 0.05476847606440706, 0.03099206207890905, 0.04258221203100778, 0.004413659964132333, 0.03633144784778838, 0.04979198806047921, 0.0810969032106861, 0.031388841997531634, 0.03358104664291586, 0.0269841926638037, 0.002771952694597384, 0.05864794148252376, 0.026598982588057558, 0.06079701346255118, 0.07333377421262764, 0.029726249255960988, 0.017190359930898395, 0.051332046953781005, 0.06816106427821421, 0.04810838727280498, 0.022215513670216167, 0.04561991535968358, 0.012262439986150111, 0.05347452291678037, 0.023360522088384437, 0.16209056841269617, 0.11379250160027897, 0.10785960261860203, 0.1018850437756027, 0.21882379187210915, 0.11213420469674373, 0.11533715702112644, 0.11635171790276805, 0.19941762029643983, 0.06392292032438902, 0.13317001382670096, 0.16385664622629845, 0.2215676123817121, 0.15786142599198127, 0.13615481495376558, 0.2336455860565747, 0.09211378382338632, 0.17383535512753073, 0.16110182469410284, 0.14537958608519647, 0.150863902282811, 0.13735861487446294, 0.1843920314023572, 0.23664034632665498, 0.15793590505997981, 0.0931752675903901, 0.20760250367945243, 0.13723365061225432, 0.1953139171124466, 0.11883320692445963, 0.10150843495202642, 0.13673638294060386, 0.07714553661043606, 0.1820146154251791, 0.1337184255281764, 0.0843446486960015, 0.16247111492820326, 0.14923841692507267, 0.1884973433709914, 0.21653553320755883, 0.13233401271845066, 0.16244208019587303, 0.13356669415389338, 0.06282079942344178, 0.19589186916428228, 0.1694935977819466, 0.12931314417191092, 0.10939079787461989, 0.17463417032793646, 0.15447948488496965, 0.13013177040603854, 0.08599902322936444, 0.09474184078675124, 0.14789074569219543, 0.12715579461186163, 0.27991976348623154, 0.18494539203182345, 0.1594700880589024, 0.20226572069429583, 0.16460276989927217, 0.10993147974893933, 0.13595477407497747, 0.18626747592802972, 0.11481575757986116, 0.12620998246054496, 0.18436694968371622, 0.19464067904458893, 0.15681257501484888, 0.19551843194471252, 0.12652417044005088, 0.15122618526220322, 0.09389601077043241, 0.1085132977835113, 0.12248380740563716, 0.28725732298147294, 0.20577789674843514, 0.1721555847794779, 0.08932630396297864, 0.15435770754852604, 0.126824829306814, 0.13782802758918655, 0.09528681275344665, 0.10113218618977456, 0.17625063116992676, 0.16678852599955377, 0.25900755498197775, 0.16469667695703047, 0.17243477786260267, 0.1332074448826813, 0.15382489339718897, 0.10532333064944514, 0.10565078727179959, 0.12817099900735965, 0.12464489547475693, 0.19271648068341518, 0.17966516165723725, 0.1265225616554099, 0.16600317862485686, 0.1429464755159232, 0.15013121579202915, 0.1556730958362741, 0.1274454524560321, 0.21947945588298384, 0.19985125670509957, 0.18606794066727164, 0.14863938213356082, 0.26946820979637487, 0.1702926428087296, 0.11166456981652206, 0.1469350050413801, 0.13481454413023689, 0.15380960228222032, 0.13368408946741012, 0.16266950105707492, 0.14075584709644318, 0.06212552100600255, 0.16330843370768333, 0.1014117316733445, 0.100464126876285, 0.18177902806670437, 0.25366044513160185, 0.11793794125438699, 0.15532947475871733, 0.2564793269360258, 0.14430084235725865, 0.143249616507561, 0.1404788143812649, 0.11347813742055048, 0.1577727130103496, 0.174834824077064, 0.1612902976452343, 0.1803226642791302, 0.12795972727960156, 0.111985131647558, 0.1643910691622765, 0.11847265530377628, 0.21915878679963852, 0.07693868521000109, 0.08234477616966733, 0.1344704174346501, 0.1440849741019549, 0.22261107009985756, 0.15232215064667887, 0.18679832889428064, 0.15523169129606218, 0.08759397998332016, 0.1346684358413181, 0.18593579050033324, 0.1547062315887982, 0.1860894830597024, 0.13489237866334378, 0.156333310409419, 0.15969084395516306, 0.19245476972672249, 0.17147825580210457, 0.18137765928141533, 0.13891130655763612, 0.19130194529650674, 0.06601454720141427, 0.1555396892851399, 0.10594158658697721, 0.16999544665938424, 0.1549156493837795, 0.0966065677423631, 0.16844456294371238, 0.17395406811227723, 0.19886258959529862, 0.11900343166123475, 0.15370702310915918, 0.16790396533906463, 0.11006297874114207, 0.15080900442215706, 0.17248135600839892, 0.07186297732856005, 0.19015642934508864, 0.12278791366805955], [0.04616398334262833, 0.0444435681997528, 0.024863333786807718, 0.024242704891930186, 0.02608944410307994, 0.0720197648831433, 0.07350478801996478, 0.04457120610881717, 0.008853206039226104, 0.03998678275233796, 0.05182358045731822, 0.027826362695064277, 0.012813846133799564, 0.01679314525737878, 0.028722371470423478, 0.05282263188893276, 0.08854734576157025, 0.0601103880082167, 0.008799185349245467, 0.08591137510994751, 0.05400244942716053, 0.05480468137970856, 0.04250889358621451, 0.07220066122470364, 0.04379543866361341, 0.0037985093161208377, 0.039225969343416156, 0.032821271283131455, 0.0367342300652977, 0.024004531986711007, 0.04769187292925293, 0.09512406503481251, 0.07764035280072883, 0.02801902040148214, 0.06537280300812376, 0.06014340639775319, 0.0373297255305994, 0.03564445850168986, 0.07432682334535545, 0.02004167789803638, 0.04577175398627597, 0.031378335101650126, 0.021332721826770616, 0.053267824733930255, 0.019582950194636663, 0.03222567239595998, 0.050051090487789725, 0.025223253384953546, 0.020776034460493156, 0.04111351039741309, 0.02590769548870383, 0.0343545196547864, 0.01387843734494621, 0.02985069449360092, 0.0836146358520754, 0.013375907606865852, 0.007150675218942906, 0.04401890268068641, 0.07558104717322896, 0.034327767864470525, 0.04591370624820552, 0.03298085505863832, 0.052718742705521085, 0.043296382176659765, 0.036311376344172225, 0.06199127175815164, 0.08249657649186351, 0.024061452319485047, 0.039782486255130464, 0.06279883951309227, 0.08839407455055945, 0.0597761208642154, 0.07075604156500871, 0.008337861565392344, 0.045434606351679376, 0.020394312000022303, 0.03222737311115188, 0.03761154246486483, 0.04398721345369855, 0.04139878621865665, 0.031386354126997536, 0.08917002968730466, 0.0345441417378043, 0.004050825880239568, 0.045951164117263216, 0.013015419188436243, 0.08907821404957965, 0.010725031757066327, 0.014530525640434316, 0.02031091949902475, 0.05840776142694297, 0.019112208317364418, 0.03296668243203913, 0.018376993736432447, 0.06034638905417054, 0.019668478165723143, 0.05313402364751505, 0.052496695951108015, 0.05442322321957158, 0.013540783134709685, 0.03226732459640311, 0.04599652418325986, 0.058090669974204034, 0.07757947179338626, 0.04313978614405759, 0.018378487607884793, 0.05985059993221395, 0.026494007475013216, 0.04049141252894075, 0.012728204207134344, 0.03758076488250687, 0.05044556831219985, 0.042089958404821735, 0.06312453413322087, 0.061353538035144733, 0.06403514837485648, 0.05803121005996101, 0.038889629931579676, 0.020750414565085404, 0.07895770993444227, 0.05139035007525837, 0.07182206057252423, 0.027565019460575237, 0.07001544904684828, 0.02403736843036548, 0.010951088024153104, 0.03580061786417519, 0.0379157176752004, 0.027773719048127535, 0.025219350166979338, 0.05315416026860476, 0.0038902852130347806, 0.04690636084565232, 0.021041121949712117, 0.011813782508515063, 0.0616162640583371, 0.01870719869921525, 0.04792281013402728, 0.06587023921911755, 0.03735757665708661, 0.06246218983564646, 0.03300952972964414, 0.11440807623007607, 0.003813460000768124, 0.04469146659117072, 0.10045468867305787, 0.006492125929423398, 0.051426168516158104, 0.10840861186865838, 0.0400951229065897, 0.08804394172564631, 0.026350086367118265, 0.032898500606778174, 0.017314529376885584, 0.0499637296513444, 0.026470084464357748, 0.021187892904685392, 0.048016249878151764, 0.08284464087938109, 0.06623244558971736, 0.05591951550975923, 0.015187725657597186, 0.027024247570924705, 0.053678355930793675, 0.011324156563909305, 0.06923742547270752, 0.011595128565996645, 0.021394510648303458, 0.008671346342100972, 0.04064638828558307, 0.013137894622500867, 0.02726162565992244, 0.07861434932677977, 0.045745251174535484, 0.06107981865023894, 0.058981588095306396, 0.026074415373225367, 0.03417550788951978, 0.03933406434953213, 0.016638451038048636, 0.027258630256138505, 0.023040395012245547, 0.043374917680217374, 0.037808047847882394, 0.053136061441393635, 0.02152292422139116, 0.062316828482453866, 0.07696084047277128, 0.03039874230331231, 0.02448417006000396, 0.023112008911407283, 0.07282215005327618, 0.05121572799379787, 0.012829020420359749, 0.019489439587379177, 0.045491664580279784, 0.03585956066906933, 0.045497149769817634, 0.06546140873744603, 0.046033514738683744, 0.014836476259534399, 0.007071576640760947, 0.01727012500557448, 0.11561795122801297, 0.04741927586315621, 0.05578129409602093, 0.016489477580293052, 0.015611062014114954, 0.03149677995562313, 0.03523081315741424, 0.03413428469831425, 0.04997849599608491, 0.02574569470579586, 0.0340695770817899, 0.038652564023411086, 0.030190904564674825, 0.05581719297615271, 0.013051544064505687, 0.015237098109097251, 0.05582926269139975, 0.027546395863135977, 0.02887593571006531, 0.08648437823379233, 0.03552895542534609, 0.03481179370634979, 0.024061764500314192, 0.08377108632797196, 0.06489137037386818, 0.024331343179989248, 0.0031311586339612526, 0.03353420802722535, 0.05381796396367493, 0.01362683970646392, 0.08603093079141072, 0.06706287723875816, 0.050001585886122725, 0.02481404368975951, 0.011508963784323105, 0.10384124162937365, 0.04319726955145598, 0.018941680975859205, 0.1468052144252485, 0.006289953889790923, 0.029838877587368893, 0.01185743324083066, 0.0373308708320462, 0.032445983961224556, 0.0705405027275124, 0.07752609844770163, 0.040526192920703086, 0.08042814675718546, 0.0642329331247076, 0.037357051886858485, 0.01957739797240544, 0.01950887140757855, 0.012312387961203293, 0.007218540075325197, 0.07176144003507591, 0.06639680975387174, 0.010472529177223484, 0.01431863338145758, 0.014538624147403867, 0.009580408298080007, 0.027340747220742128, 0.026539049614521287, 0.051310680761572816, 0.030638546975810203, 0.023874245328648437, 0.039373491064555226, 0.06965734890752262, 0.07797833547116288, 0.00543552166369233, 0.04991452765440749, 0.029492100227564096, 0.017635386151772355, 0.05797530479368664, 0.052877223314416986, 0.008120079047887797, 0.06005670439692275, 0.051718025032671235, 0.012275073733631403, 0.05107333906175149, 0.08302929871264966, 0.05698816219885504, 0.023550425708714514, 0.036932053119545026, 0.04632584622970993, 0.03564118347581356, 0.013978557375770424, 0.07948177536168406, 0.04070383721902486, 0.03446547982973918, 0.0816083358480565, 0.060799307895884405, 0.017935784548641216, 0.032903725326421766, 0.02441211757550557, 0.07785201523332827, 0.04657789298723783, 0.011454720928844427, 0.043177374248062415, 0.11428119674805673, 0.06212766222175091, 0.0634021069403858, 0.012978153798969523, 0.021307753106098504, 0.07639248750262684, 0.04811599069545346, 0.03547604556285566, 0.033921457812069886, 0.016064005753686352, 0.0352477551918597, 0.04281114591586013, 0.007865393117460753, 0.022540524556872346, 0.01214386489722998, 0.051682068695945126, 0.07583574842541449, 0.06724433282450323, 0.058284838789052544, 0.04519843676638219, 0.03225274594320405, 0.03932638814853084, 0.044606434662015214, 0.044959126220595454, 0.030718059241471272, 0.036575749456401796, 0.03105089380105417, 0.05679348010509726, 0.043592716477090315, 0.04938817162427211, 0.031562613721396175, 0.05239630012863106, 0.027782942746735872, 0.03167353176151312, 0.028644864439904213, 0.03373839344168383, 0.04883975992279668, 0.027246418814625473, 0.005167723659636273, 0.0838547814336996, 0.048121820624557235, 0.0427722669537029, 0.012396421103227525, 0.015406012835521853, 0.045300989126365994, 0.01698907224401351, 0.019034301005904714, 0.0527812056844273, 0.0032793032803437525, 0.0247616030561227, 0.04242020358722057, 0.09424464972389322, 0.10149047785108128, 0.13303329777573386, 0.17171945092418503, 0.0947103162686671, 0.22710727077097664, 0.19966362645068478, 0.1660993073375956, 0.13861622481096175, 0.09341037997435178, 0.16917314320322008, 0.12577696658310392, 0.09912074573578374, 0.1623948278927034, 0.10976553744366092, 0.1738796809748296, 0.11313902860086773, 0.13260240396184306, 0.1834619853405222, 0.3090295111460071, 0.12865211754556627, 0.1489368693963174, 0.1443168689166346, 0.2554370796368007, 0.07651324594213117, 0.09518365135356303, 0.08627063204203883, 0.22380271986607583, 0.1843853970809329, 0.08034918607482988, 0.11683439159946096, 0.23773418198670113, 0.14182165926021917, 0.12664233950237114, 0.12027281636912977, 0.17207896066529138, 0.13401686273995908, 0.07761129508576087, 0.1258006770043604, 0.11617708049954907, 0.13058255186244366, 0.12710008469800796, 0.09572587306461028, 0.1310926132024296, 0.07306267101798328, 0.07841560313658369, 0.31216373006182335, 0.18269214358541275, 0.055915179452107805, 0.19477068416533933, 0.2753278018245774, 0.19352156248304153, 0.08950545362407163, 0.1338430833552153, 0.16386729484844595, 0.16675795909137497, 0.10655095590458763, 0.09967304150303526, 0.1606964109645736, 0.15989367339399554, 0.151737502986385, 0.12294439478747307, 0.20511466378886856, 0.08605392109001837, 0.1939040395401178, 0.1543309097929347, 0.19154482581202062, 0.062206335621134895, 0.1406071800738573, 0.17203086566540504, 0.15270251330108414, 0.140420668307812, 0.18287696995802466, 0.10390242907188593, 0.16857887347859724, 0.23034834363047155, 0.11796958834653902, 0.15820846382168033, 0.1162355023646547, 0.1104378791886472, 0.07918446429915006, 0.19799182341704447, 0.15901763653082235, 0.13492470757374841, 0.06682046403687808, 0.10522560847382392, 0.1986792953985353, 0.0500870774680328, 0.11352987899895638, 0.1165816362106031, 0.13981478469025704, 0.09045825249725774, 0.16174869401560676, 0.21978003814095454, 0.212505420429572, 0.1710331740398561, 0.2413626501877462, 0.17497437465335094, 0.12102892982863611, 0.19609483649894116, 0.18821235866315905, 0.08337132632732393, 0.19936727299805612, 0.2308575469519823, 0.1286075771936486, 0.2069707109682983, 0.24354891190605782, 0.11825059705804433, 0.07669403503138213, 0.13656746055330002, 0.16702564553387705, 0.06198164203294343, 0.10070467848450908, 0.17164860311294758, 0.24442225213973756, 0.12228447132773938, 0.2156907220881793, 0.12054510700005679, 0.13520301199488102, 0.21363360747214288, 0.11706833952977774, 0.16767493569322173, 0.11012189090251924, 0.14676433597360888, 0.07744662448643677, 0.21884276020911433, 0.13806366091293676, 0.14152354380536464, 0.1053143214554556, 0.08621561926819625, 0.15231563889932248, 0.16318766760729975, 0.17040728020571894, 0.11754254795490734, 0.11179710302742259, 0.12564902223886984, 0.05343292051205232, 0.2176424383275932, 0.12682962501721998, 0.19999114436007318, 0.2452626812361902, 0.1665745729640607, 0.1949263838750701, 0.148687094089485, 0.23019468171461938, 0.13174152031781214, 0.18442052987314042, 0.14130010660136902, 0.24397862594454522, 0.12111359020514835, 0.1943668792204511, 0.08729040232156554, 0.11678304838677568, 0.16820716761773633, 0.1255032433677585, 0.15724238098388718, 0.160323862406996, 0.11203950856842342, 0.15551791706633183, 0.15986086950907785, 0.12224460411215983, 0.08425143111737506, 0.12288637894896731, 0.1408749584469103, 0.13433503437667124, 0.09294125071216015, 0.0943100966152645, 0.1821433335182167, 0.10341197192188233, 0.09001542303350665, 0.13117490636725582, 0.12727430075286858, 0.14930498996569266, 0.11069321629380989, 0.1035575975754088, 0.15922803491834672], [0.009298237048149591, 0.03485111699950311, 0.04564786607760095, 0.03604970369187575, 0.047176939270068566, 0.097090061153135, 0.047749827480724746, 0.0635378921945249, 0.05451794233052962, 0.06453752202252228, 0.02833741228847254, 0.029472668407364722, 0.008293046379431842, 0.05375627090313262, 0.03963042163260041, 0.028419372205051686, 0.10209131294921522, 0.025911119901725364, 0.04526742681440327, 0.06933145510453372, 0.03405505205474554, 0.031141161941172137, 0.05344125171822887, 0.0208594614354473, 0.017834749042747483, 0.03271200033205171, 0.0870569600092788, 0.02514661586422834, 0.050864905689752875, 0.06447935296643166, 0.034675732660557956, 0.0573935644370654, 0.03187676339650587, 0.02126035907666289, 0.05618038760017484, 0.041878813081571174, 0.047447012076454784, 0.029597370284459287, 0.05412665909276374, 0.08695189871134297, 0.0199763746481509, 0.013276834243668184, 0.06165268004781777, 0.03752694337538654, 0.049820444396426605, 0.013741563288344732, 0.04035790255593677, 0.005362328186991715, 0.012826189725479532, 0.06019647713870772, 0.03455397447631244, 0.016073036015093807, 0.03591082344252256, 0.07915483201823889, 0.02543344109829876, 0.08568676579142771, 0.025278997772763816, 0.024962122739863493, 0.009748991691477357, 0.05970737213389047, 0.020762465128134337, 0.056987775324453274, 0.011204586518297513, 0.02484443822815534, 0.028697471697664553, 0.036990513289046865, 0.05941476102077192, 0.023233119751356786, 0.028227271827598734, 0.06173767367257707, 0.06943098524765623, 0.039101491547039444, 0.018594375015386654, 0.013277383911753855, 0.026328953831726988, 0.030178729512338198, 0.053615988712878, 0.022740216865654916, 0.050928318617685195, 0.049612803925429626, 0.03403019633204226, 0.04113349763135757, 0.028174794804785522, 0.025202659026329077, 0.0848460915468393, 0.08227785838948143, 0.025859148496942177, 0.036033753741292224, 0.05430514225736261, 0.04802147076735574, 0.04600335385710482, 0.05092169961801941, 0.01750647653675368, 0.02042640342317041, 0.05941978272711558, 0.04143108831598394, 0.054103281919754324, 0.021801019883564404, 0.06569755534010549, 0.02682161539973271, 0.021597937635716893, 0.029912818478600636, 0.03465687923674141, 0.02122910843501168, 0.0431158765399408, 0.05885422214745514, 0.03585463472371621, 0.016075230856996872, 0.04873911895218396, 0.04308944650655312, 0.040825629877226974, 0.029022461516902815, 0.006388103159429927, 0.045345724830704356, 0.03726208762776467, 0.050580120164780855, 0.03405423234066656, 0.03508395793276929, 0.05677187642563255, 0.08339124461335522, 0.03470092546194792, 0.04240372120552967, 0.056021604386548844, 0.01428375339826509, 0.015453483473749892, 0.02600711454907733, 0.022124387511623003, 0.0441153684721118, 0.021179318465592883, 0.03244256720908227, 0.1034435194226042, 0.053582809444877415, 0.054549719657628774, 0.03548022840292223, 0.0508128653370565, 0.0452911104225824, 0.026393230523793932, 0.036761261477705934, 0.012567840937164523, 0.024992766256834713, 0.05719266170936246, 0.05901563304266142, 0.06886358222653789, 0.019161609497161645, 0.02117617367466371, 0.042880511346964106, 0.02839700818332213, 0.030764041753906398, 0.05216198064567101, 0.0480987613780364, 0.004047203241967627, 0.08082161717597516, 0.11985468558005749, 0.024233575039092573, 0.015550420409248722, 0.04119383854671352, 0.009777498780749738, 0.032793412495765, 0.011688197715087764, 0.0388121018336425, 0.027800704495260314, 0.06123249614310842, 0.028538728703654585, 0.037443964561868104, 0.026115650055749763, 0.015450012137842997, 0.0321683690192238, 0.05437232433788238, 0.02202714605617427, 0.037304969399326274, 0.05313436072620173, 0.03479452991497613, 0.01881965657606, 0.0389616345355828, 0.07593331738345085, 0.007649357280423565, 0.03646801834204986, 0.061387058212271625, 0.020167046271625067, 0.04792641074727139, 0.030501158682689555, 0.055440990179176294, 0.032213644815548774, 0.06825730790414157, 0.054067260465554656, 0.04604523205348561, 0.022832589832344846, 0.07956162470603183, 0.015796884301028425, 0.02289823399135663, 0.039151815862785426, 0.015364276365407053, 0.10182126695590635, 0.03205970519282405, 0.03151894670971219, 0.05069381910406294, 0.0255000083932593, 0.06039947511688356, 0.03437102884955464, 0.015345583820054609, 0.024274706299747192, 0.06509381676873853, 0.0868356065644372, 0.09253015261023276, 0.026463676138871142, 0.020200198726548303, 0.08373283555791264, 0.03689649897897917, 0.07272127925628617, 0.013268356523176116, 0.0504554738290608, 0.027723708828430504, 0.03489976741313454, 0.009726369115073356, 0.12707035282566664, 0.05500330116539713, 0.06803223127198797, 0.07561576627795735, 0.06325907832492264, 0.04026751950263016, 0.027715245472087015, 0.04453338051755582, 0.028443241589552457, 0.05413625434401536, 0.02674083525855695, 0.04044620568052896, 0.0549493341015712, 0.04652291851779146, 0.03513657285140888, 0.06990437395870686, 0.01972508631766804, 0.05204317956081322, 0.019527508411556482, 0.039098155234129205, 0.025460416969332485, 0.05195812081858035, 0.03903601784259081, 0.05091173281412452, 0.015017317059720236, 0.022608342490369276, 0.028242243100858988, 0.010703090998914935, 0.0863575906823239, 0.02607155403482818, 0.04475152405399469, 0.009932178635931304, 0.03249954882889025, 0.055384165607392795, 0.07456528353354624, 0.07879749796683751, 0.05556294371584251, 0.1597502157692948, 0.06928333712200965, 0.06773755555191348, 0.07197681799410813, 0.07870906843773781, 0.06333053134562028, 0.02189141442818988, 0.04357670906991248, 0.004985104099051246, 0.027593249800584974, 0.04555276775312039, 0.07662517904874779, 0.014995728702014013, 0.050610775173070936, 0.031677055765964815, 0.01833638916122577, 0.055471694983181455, 0.023086662892432466, 0.04506621765153063, 0.034301740027243094, 0.026305230003931833, 0.05103459033454138, 0.01348118628225019, 0.0737093411566269, 0.05551390259736969, 0.05330492254166354, 0.0520648675099496, 0.028316540222975518, 0.01629124466900624, 0.03781906802267317, 0.03688334141887965, 0.05974334379237506, 0.03791302870658617, 0.03662156534471339, 0.0961511361322576, 0.020573699148371816, 0.03605416615403468, 0.0031864723367165896, 0.04373698615499082, 0.05880731841429107, 0.02827713074493072, 0.055630876562528075, 0.024007523560055324, 0.020254451158126036, 0.08391101228734178, 0.02656407962222734, 0.044500760493739966, 0.07417012006044388, 0.0474705501279283, 0.04432849796308626, 0.01231018067037146, 0.0330636078762191, 0.05002209789029533, 0.03019198091820844, 0.03450399106969276, 0.060929190442566915, 0.02009649914989789, 0.02368239584499069, 0.049110897591397654, 0.045463418918511564, 0.024235907776822007, 0.026092784246429804, 0.0923853160272683, 0.06047109284648492, 0.03500366808786508, 0.022251734307276148, 0.09810436156488235, 0.02588467646179901, 0.0021299559316943373, 0.05059047001263788, 0.04619173487768539, 0.04649293766687474, 0.10037946649977278, 0.028041235036066467, 0.022739039005471334, 0.026667775368438135, 0.0607460992591035, 0.048246459299398047, 0.027551185827882543, 0.01671600786428298, 0.03146951297117818, 0.018081881346241124, 0.05407037078252724, 0.03193544190106613, 0.045494725101537285, 0.0735855107045462, 0.06352438606441983, 0.03905286794648536, 0.005554527677069869, 0.02013187517502135, 0.012970568570909242, 0.023421514178476027, 0.015296935321642988, 0.07202198653812371, 0.10400673194277672, 0.05365462252689947, 0.010341547294369629, 0.015038422782034164, 0.03730119258585957, 0.04981822274144619, 0.003960107424063608, 0.21022109945695247, 0.12453352927320427, 0.10112193593334767, 0.18497860960422025, 0.1680482196952066, 0.16808747404044674, 0.19005460093819326, 0.15528007740935973, 0.1191459546586679, 0.13511911004541383, 0.2164440010223658, 0.3284731903864492, 0.19268372276377296, 0.09395923600682328, 0.10028492358903732, 0.1156776447990729, 0.2331633796735156, 0.15600436757649147, 0.09995847820274292, 0.2163182859939914, 0.15265898418522653, 0.09074712127086618, 0.2482326968663162, 0.12638989820956223, 0.11707249172632733, 0.1879121594491505, 0.15060105751599037, 0.17841553435690943, 0.19760042909652958, 0.12283587843299874, 0.1466320019455687, 0.21965383281630857, 0.18044706163627489, 0.11579150844725872, 0.1808337368551762, 0.08556232246900759, 0.12472335819996173, 0.09240905709204175, 0.15406565951003184, 0.24377830927410435, 0.15128885125440938, 0.14292690963033708, 0.18959594409792654, 0.1213123670388614, 0.1839363010179612, 0.19410968818251165, 0.1697136488773169, 0.13614321638259197, 0.12726213527663102, 0.11523856150527155, 0.16132547640271727, 0.1464722879351147, 0.14984779390356234, 0.2184947571086307, 0.13482018253735958, 0.16702809701523474, 0.12301079162787046, 0.08362748314656558, 0.08858399540786782, 0.19523352384567264, 0.15202172160629304, 0.16453175354869137, 0.12838870587368167, 0.13876852309030874, 0.11881764001783826, 0.10632900491116509, 0.23666005010806748, 0.0900862172185894, 0.11390279527873763, 0.14353683819213223, 0.15025811059580696, 0.24078984624676167, 0.14084063770790256, 0.16531112543757887, 0.18724028501779805, 0.2610640414059162, 0.12685854483636158, 0.1353753204908102, 0.209751533524644, 0.13032459473657992, 0.15922342306904255, 0.0829310862407569, 0.17663603468287378, 0.17995670407770142, 0.3084496745178777, 0.2704759524954904, 0.2011351587791597, 0.11831025232470806, 0.16392646747971737, 0.1234347829895635, 0.14474590879774865, 0.22380711721076121, 0.17591192837684386, 0.2042135452070544, 0.09496762988067443, 0.14181749174191108, 0.10497982448507702, 0.17963940578122295, 0.21835758140490902, 0.1800495845776412, 0.08082740113980348, 0.2043983562579078, 0.18526650544616485, 0.17844222486019137, 0.14807649137031648, 0.1093911043097896, 0.15169504639362136, 0.12105123064811192, 0.13059977351898147, 0.13283229162616114, 0.14239513735857703, 0.07789646365469502, 0.12159123070417874, 0.15991538432576966, 0.1797468879169995, 0.13940425349339364, 0.18279922735546866, 0.14199266540667704, 0.1425465776194488, 0.22478406317532065, 0.07930198218673468, 0.13766865065741923, 0.14333937136876967, 0.18271979935947927, 0.13444692917889164, 0.14544038282286736, 0.09646926180369432, 0.18430207735828816, 0.0735216879195744, 0.15792458228045897, 0.12533782200226862, 0.15830129835634463, 0.12177012755625671, 0.08970547152022201, 0.11703517558353564, 0.14503487716278723, 0.15409311610123805, 0.22566650453354084, 0.15144488804282683, 0.06588836485940604, 0.09417731059534896, 0.21003143140865912, 0.1618306347799878, 0.11434403127960621, 0.09335562000952422, 0.10513261306069552, 0.17056999728083613, 0.17667911946773532, 0.07009414159843037, 0.1335476032428203, 0.11738168481256693, 0.22394769434486667, 0.16810837291902112, 0.10758366540915544, 0.10996555533981132, 0.17808354249404323, 0.1963546628793401, 0.08158421173932091, 0.11190353562274288, 0.12489945883111608, 0.10233649938938119, 0.12321051841060962, 0.14638700702738378, 0.15047823829996973, 0.11330080338783803, 0.097171243490471, 0.13371718446573905, 0.1509898624593212, 0.09448884024975762, 0.1677939091478625, 0.20639324921273416, 0.08591805539664724, 0.09680459380991037, 0.13246550404977414, 0.16845260686691732, 0.06632287460829943], [0.04288534536176632, 0.07321172108453128, 0.05568532243130669, 0.06380666648187945, 0.09323065574731558, 0.06113861589842747, 0.03756771840515637, 0.03370702980206378, 0.013840657718960318, 0.04129298564587389, 0.03439250229407222, 0.02247584949908478, 0.057248988323995186, 0.04143624408771435, 0.04392630946371825, 0.018165440471362204, 0.048395984340459115, 0.028045996272515868, 0.048057296869134715, 0.03883036920019696, 0.009433795348741114, 0.03809026697830808, 0.04635999459893473, 0.015429198486550201, 0.06924067368550647, 0.031687045552497434, 0.03911576376506879, 0.05124470143909416, 0.10172173681278383, 0.018721342597517277, 0.04717397067936198, 0.015214606725250282, 0.029959362150440295, 0.036512187141324245, 0.012457107715759308, 0.04750890048941778, 0.009997541257630914, 0.04018080601048085, 0.04809031908911082, 0.04289913877484299, 0.04129895347080404, 0.055474426086631515, 0.02436317030280348, 0.018113520777513905, 0.10183956113553817, 0.006904769613738022, 0.01681119428887483, 0.06523937347435182, 0.04273152256745004, 0.03253269362293425, 0.0642162707123545, 0.05308604739125698, 0.03243698242811426, 0.01234833950987987, 0.0498532674335424, 0.03861067050527181, 0.038110962843582515, 0.008473698530466327, 0.0074235835082588665, 0.027109042012823686, 0.12548878728862733, 0.06889999438557895, 0.029857323069365758, 0.04129108574782168, 0.04044254761069052, 0.03661534088032861, 0.055656908230195125, 0.0448423361165389, 0.035817264954769806, 0.08083117795327018, 0.027044399513772903, 0.05025620286863658, 0.021390934932916876, 0.00815701406193717, 0.05029551467047103, 0.030349865893743215, 0.05956571864625139, 0.04000051487838069, 0.07625725766223285, 0.09068420246964501, 0.03897697927670614, 0.009000644448303409, 0.06394646603674178, 0.04001716962985454, 0.06188753579232482, 0.09226554584118629, 0.037710444415889444, 0.029546666755190784, 0.019153113582081372, 0.06891439683855542, 0.010040982273377238, 0.034406192285279115, 0.08697221536309489, 0.05941256617886886, 0.06261767887119805, 0.03779955193280213, 0.03096602658080238, 0.0910862071079112, 0.09540871266395816, 0.01749514226591395, 0.06397902860396332, 0.08882219512616435, 0.059223242870141427, 0.09198747124643096, 0.050715526205397425, 0.042777755973680366, 0.10507127240059838, 0.10244228080996584, 0.08637945483168287, 0.01329797922798823, 0.061230714988684466, 0.01711105642419669, 0.04705392087118761, 0.04610205662526912, 0.02082704442493137, 0.04657467158751623, 0.11237482525288098, 0.11452171005188458, 0.013185777990598113, 0.034481774519888625, 0.015957083819704433, 0.03896332375945584, 0.04172212511841809, 0.0762916626709123, 0.021514819011152275, 0.04519710377339394, 0.03733843595029847, 0.024602950077443838, 0.028680156195356, 0.03488900004735878, 0.04880036768173018, 0.05356915009718749, 0.003389727911956969, 0.012387446383194578, 0.033594909003905715, 0.10541550634849457, 0.024458100087940696, 0.028415650932959495, 0.027449070138015577, 0.07776631297723902, 0.0340711169185177, 0.03142272606642256, 0.025282713299196576, 0.06781161327155368, 0.057254745474746155, 0.02460080694647566, 0.01341422732483836, 0.024841724361683575, 0.02317052462228364, 0.03397231838936287, 0.018260257258530588, 0.02804168702794179, 0.08842806587175978, 0.028991226197010087, 0.023034434848194642, 0.07738369036345713, 0.031830960914732954, 0.04905382404103876, 0.041889182081626314, 0.00868557259485486, 0.07515382292049547, 0.056605351893531705, 0.042024465548175, 0.02159517397353005, 0.03475612592733195, 0.06153996936195801, 0.02679097762842092, 0.03935153881508497, 0.06238855729480425, 0.05039833899166796, 0.050442159220936804, 0.030169099787129994, 0.07125794406860106, 0.01690344085105725, 0.0292252354143608, 0.013842937788144957, 0.01835428305991715, 0.06579159263281092, 0.03640025020426801, 0.035072079739503326, 0.09761485436390485, 0.052985180424706596, 0.0911797387825866, 0.025232477083561883, 0.06818255304449028, 0.04908003956980763, 0.0316982974688853, 0.07839720170464247, 0.045947574995337956, 0.04507314308636612, 0.008161403745743296, 0.02697438865359272, 0.02925013518711973, 0.07641295737196362, 0.025433646026818503, 0.03843098458263182, 0.038884094946326754, 0.08322439066344693, 0.020228034531277035, 0.038138982509413076, 0.037352734981405164, 0.027393837113894766, 0.045235220478066517, 0.036149892670613144, 0.09434731316662605, 0.054583255156514146, 0.022740222611314347, 0.018802164873528867, 0.03294157390032084, 0.014697871801833955, 0.020633438684707208, 0.03712108148442161, 0.047297939027269045, 0.0672848282321807, 0.04875972288690748, 0.025718726495641376, 0.056373231082914345, 0.07537006655888212, 0.027231211969328505, 0.016435692462349133, 0.02810201645197888, 0.014453932169764755, 0.02877650898881257, 0.05761567247851242, 0.04934542008765763, 0.05183345533066219, 0.03995735731516634, 0.02513146456030588, 0.042761652805511995, 0.0324564793657872, 0.052934304525655125, 0.022652072704307014, 0.02982763141664046, 0.04381913376311141, 0.021187404523633664, 0.02014586394051871, 0.06352072416414177, 0.033720118414250114, 0.01931748923755461, 0.04123116235038446, 0.06380769687013761, 0.08905066552782252, 0.043115252178282513, 0.07367042389007346, 0.05692977863814562, 0.1376007599455695, 0.06867690958202848, 0.07792452545536142, 0.04590170548087166, 0.06063845624486285, 0.07397823801804936, 0.055999284414874936, 0.08280132626814228, 0.06615395988187482, 0.06215000517606255, 0.05369850021276263, 0.03133604704822985, 0.050821690669944214, 0.08229904838146702, 0.029307208737478625, 0.09338483094207703, 0.09233542072075991, 0.05571514623419893, 0.04818161378704733, 0.04926130363357164, 0.06765467249938557, 0.037881718693120826, 0.03083634896263961, 0.030517198648604176, 0.02967850282608021, 0.11344070636457014, 0.15975663558610026, 0.03351125220257429, 0.06459967473581915, 0.12839130291174497, 0.07415372577886428, 0.028518337358330047, 0.04461524850358406, 0.04107763449991903, 0.04364599789222402, 0.06123170707254641, 0.060757900843577045, 0.0602983438499993, 0.0672073001342435, 0.012352771328521833, 0.029776581232586218, 0.003064919320393294, 0.042345276357786316, 0.10092384857876648, 0.04167745070111367, 0.05168093105537757, 0.05512348503895825, 0.024762372974486604, 0.1503946734291892, 0.025879649009795922, 0.03468242826901617, 0.0475346218914755, 0.004555854980172891, 0.04890426835646072, 0.04195538740004263, 0.010132073958013809, 0.029938677776484724, 0.026795581816845847, 0.0993686517880809, 0.02364343835882122, 0.02264940671833052, 0.01996761251751694, 0.045969508092610106, 0.08055265136663953, 0.033288328277487914, 0.03020533957638808, 0.050451153093167854, 0.014777882982255712, 0.011241008253437618, 0.019041450521458062, 0.05618966492493788, 0.04082836481111665, 0.05505240740134351, 0.007411027805984862, 0.06922684579847321, 0.02680083909522622, 0.017230723188408924, 0.04951656412994189, 0.03128639880507704, 0.08188025875677986, 0.030811891605656956, 0.053313081378057126, 0.04958920458692217, 0.03260241911536263, 0.031711217541728294, 0.05510851568091781, 0.09878262516952331, 0.03327086530325394, 0.07883387948236159, 0.028876606036999056, 0.047544837673945774, 0.05491750697875696, 0.012806741625911767, 0.05774616406509473, 0.05884278828518526, 0.0683660387632347, 0.028947779435604334, 0.027545298442184448, 0.03811266355877442, 0.02895266133090181, 0.0203036799681403, 0.05503825009650281, 0.03151593789938958, 0.04963049672604088, 0.08493397715351275, 0.0447832937202146, 0.05233887034738737, 0.2175655537435124, 0.14435112836860842, 0.14745870274641823, 0.2503046276228082, 0.2765040838670346, 0.2350302593361947, 0.22013331192635724, 0.12042233374931159, 0.172705406082734, 0.19339581681115015, 0.11588056616845632, 0.14781353935118646, 0.18422120911700113, 0.1436885695664152, 0.13661563216197875, 0.14324506594529077, 0.12030113097881118, 0.15121699220711185, 0.11146409226761711, 0.1773717395600773, 0.09858249236018428, 0.17808277640611897, 0.1061650314518521, 0.214792974293232, 0.1961994687876394, 0.0890082089350589, 0.11648739207415812, 0.1415981148039141, 0.23929405957460406, 0.07883918847167685, 0.18276421713732904, 0.11769709853275169, 0.12235948665728494, 0.08376740910593541, 0.09411064562417808, 0.14798073037978143, 0.1402805508264611, 0.1600031626801337, 0.14691448920676786, 0.05890195708601706, 0.23010526393209735, 0.194386153992626, 0.18245168390773958, 0.10083421629162566, 0.18446321629228132, 0.0958754440709468, 0.09853633556274638, 0.15180865723279216, 0.1257678577976842, 0.19232053580063005, 0.256878366814025, 0.1765691398853256, 0.15284673701370918, 0.14804364152012334, 0.14110369697934197, 0.17401598333831758, 0.16612933798422738, 0.12833422936138608, 0.1470550050538394, 0.1683594505753248, 0.25174257465668265, 0.2583188112945326, 0.14639813062404433, 0.17862688269345992, 0.16016336698685923, 0.21499935838003315, 0.12338917777543107, 0.23669173550461572, 0.15980925050473985, 0.12739485234863338, 0.09631524748739698, 0.20097719144917306, 0.09400766042451705, 0.16416583931253803, 0.173494890332222, 0.15927058344166126, 0.2627645114496831, 0.14105051515563843, 0.1308867960206924, 0.13720666899556114, 0.11675717759757273, 0.1824035429425778, 0.2758199673506522, 0.26729592152180215, 0.26897828124703904, 0.19382102625264278, 0.27278377704562684, 0.17998817496963088, 0.21498080373050707, 0.18706292034156863, 0.13821856389122625, 0.17392137147966893, 0.32196993128426615, 0.09808524767117155, 0.4118116975070969, 0.28185180658774994, 0.15999355593756323, 0.30246652782924716, 0.23460583130438484, 0.1648200630781151, 0.11129642626450909, 0.14430700170416988, 0.16410038476028752, 0.12314893260237672, 0.12073991549832207, 0.16205140599800696, 0.182501295761716, 0.2990093875315882, 0.1268700208334673, 0.11475311457029275, 0.18572594369611434, 0.09254958059999252, 0.33403955460075413, 0.098091161869947, 0.18493826741412764, 0.10456538623979977, 0.29253576071031634, 0.23448793037283808, 0.17814389490071805, 0.20488934200857917, 0.0993245327845216, 0.1277261164279715, 0.12168139925286656, 0.2806020720351127, 0.17425135619217352, 0.11907016558031883, 0.20799717685628324, 0.20371880562555408, 0.09480628410294172, 0.08699906674484092, 0.13214167868418078, 0.11629943240193591, 0.1789965814039592, 0.1533788770076729, 0.10892397453708035, 0.1653378159408608, 0.1504661187890076, 0.21483880167286243, 0.10998616310497446, 0.14146763470865067, 0.24164803326129916, 0.13579902839997124, 0.11299584676781971, 0.2219335725831409, 0.15398632344459334, 0.11187226391367375, 0.13433737860571954, 0.11222128591109669, 0.17526032463196786, 0.11777749179952568, 0.13788891625740837, 0.1810903303445347, 0.1563294952915561, 0.16671409289683067, 0.18422445732980006, 0.11993247414788893, 0.1091093448321185, 0.15836091531861216, 0.09718596770037567, 0.17083563060770113, 0.15853101748131937, 0.10454886938415228, 0.13573921225484342, 0.154451982328488, 0.14844856495338102, 0.14731639425360388, 0.11195687066403129, 0.19132417716806938, 0.18259757769203958, 0.056204377643523686, 0.16742873035611647, 0.09959714517237679, 0.2330261580045185, 0.16994595737947574, 0.12047799769788982, 0.21243434279195725], [0.002944824504553371, 0.050948053042614655, 0.027681675499245047, 0.07372735188372674, 0.0019470614173652365, 0.05704944540235785, 0.03585184999411145, 0.013114171752315617, 0.015552395958483461, 0.012678039812242553, 0.025656736576028412, 0.03728556439220425, 0.008064766542144842, 0.06146772344025874, 0.023016284310048627, 0.01462323951625055, 0.03527349191567591, 0.05647999692648169, 0.04542931651456222, 0.016176965418121508, 0.02378091475205316, 0.053896265810415636, 0.03974090683304014, 0.050934397525364355, 0.030738952374386213, 0.041505973410582354, 0.11800805362121713, 0.0648797564809361, 0.014409470341859326, 0.016353339925708792, 0.03193447471506173, 0.04356645498304598, 0.033623265748422955, 0.040424556035788796, 0.06915068133704125, 0.009787708817560588, 0.030732666622967492, 0.048804117682119535, 0.052070712760811856, 0.06317363270828802, 0.05905752273036107, 0.029533375129704515, 0.04167059804463098, 0.022010412780688177, 0.018325805656551834, 0.05222999393158863, 0.043360193470312704, 0.06433892904991104, 0.026246679819098888, 0.05261422149957188, 0.025225352465866074, 0.043548823469468666, 0.006176156795493538, 0.02099064633160109, 0.08989729993646184, 0.04990790482430209, 0.08211074396967888, 0.03878708906291473, 0.03111863321053886, 0.07888299337918721, 0.046015936851261124, 0.03227066473975297, 0.04516819544557122, 0.072225030481575, 0.023236758668997118, 0.06664583429453835, 0.05008107516914607, 0.012735462890216901, 0.017407884851338404, 0.03350007114931941, 0.09030613041813336, 0.05049632929806268, 0.03901937841287544, 0.02488664392712376, 0.05705377762956966, 0.05847756352816379, 0.03471307561642701, 0.05528781472915604, 0.01636964419195729, 0.058567211137063084, 0.039088192260673935, 0.02279329526748869, 0.06362941288839906, 0.06591654923414031, 0.03522331315663553, 0.06917333455696222, 0.045065432411408236, 0.01655578632057915, 0.031190423309923183, 0.035517881624400616, 0.019663266852618228, 0.06317863143199394, 0.08976344905433156, 0.06836799994832085, 0.040099141037752556, 0.015161090695689765, 0.0012069149060182334, 0.12856257718897637, 0.06000775137856122, 0.08040069782685849, 0.022558523792653315, 0.03596491308041638, 0.04764863875724616, 0.01876986852186101, 0.05859983882175819, 0.010821451583216268, 0.0029474617622327064, 0.045327940099542184, 0.0325260822841477, 0.023363278089692036, 0.03710893132994252, 0.02292530562338089, 0.05189719384596233, 0.021965403199916887, 0.03622027699865642, 0.012450086519933276, 0.008383545303537, 0.071408664206824, 0.030378354788427393, 0.03741158202530877, 0.032152208394461104, 0.05633403419426853, 0.028240754975066073, 0.02448955757333146, 0.049636127472284346, 0.03399026399898914, 0.042246841720395514, 0.0168283891323353, 0.045820595921888474, 0.06882039018936696, 0.026476826038091417, 0.050821813244012096, 0.02327689593056998, 0.0318586741453938, 0.031513084221871636, 0.023027589852591197, 0.016678188018681064, 0.05032431957642398, 0.0465948196999248, 0.030645045316627914, 0.08910528759682372, 0.05422910803087777, 0.05436854752441568, 0.033790924090651736, 0.1427248003141534, 0.05866332452804331, 0.0682719555052538, 0.03397491159698656, 0.03525021050365702, 0.06270974348749846, 0.014855141034199586, 0.020807152951977426, 0.10164943343449025, 0.05948210014931618, 0.03246928452544155, 0.02849343567035131, 0.025687314975526065, 0.0626292123248981, 0.04567459871571872, 0.09994917023446291, 0.03935700102198509, 0.029045545661281195, 0.03577999477725356, 0.07941506442523773, 0.013757127322136395, 0.05606326424787122, 0.057280283015702045, 0.014398269178796441, 0.013407440743439141, 0.05048561555844161, 0.04467275489362017, 0.0722303088273733, 0.06343014958885408, 0.04345576676930632, 0.02214682431170537, 0.05920794792473317, 0.02206480885375171, 0.03729944207495259, 0.03957668822559138, 0.013804060741207533, 0.033425787433741555, 0.04883543535646412, 0.018467934118703972, 0.03955200487267106, 0.03872457628829345, 0.0028371300187803087, 0.025538965879428773, 0.04441773188450644, 0.05161071143623802, 0.07247395543081146, 0.13376892604414495, 0.056817286287344275, 0.06849399076834803, 0.025891816401253306, 0.039419843214413816, 0.024803079056343245, 0.054596382073096694, 0.013902033810623953, 0.04223780954376825, 0.09352151634952716, 0.14469494862902552, 0.03574355197469554, 0.010907336742797447, 0.018494241578023762, 0.03983358048924035, 0.06687657997733162, 0.013330923881562007, 0.005020356592496918, 0.0249384640295419, 0.02122580276561841, 0.07999551392370656, 0.05273316814113529, 0.06372968613680813, 0.05368654158026461, 0.02777359838927946, 0.04932124618320696, 0.136000509524057, 0.018601463243906057, 0.00902957575876386, 0.033989547706779935, 0.010583667467618662, 0.03588552721926282, 0.050408267491166635, 0.07162925156374132, 0.02587251481600106, 0.03647971650465362, 0.03045372826407754, 0.0756303449311564, 0.011932056907924914, 0.018600084285642353, 0.04165483195514929, 0.015444670589790951, 0.008377633019981366, 0.023897088155330672, 0.04281121869421294, 0.07469744136136386, 0.01281969425749154, 0.031082820515298558, 0.052863740166949655, 0.05572585614338037, 0.023464470643610246, 0.03475349824575167, 0.038015167379090865, 0.04223096071772518, 0.01930574127923577, 0.04709726995638302, 0.0547979244842164, 0.015954457095734054, 0.021466639741594275, 0.055943486400909966, 0.049778152512566703, 0.06475869160626205, 0.020018597584097617, 0.007387611370969324, 0.09270467510026309, 0.06346729336186283, 0.06449980751400994, 0.017102983772694584, 0.04827799913924068, 0.11030296344430217, 0.04560608747265032, 0.11270667155904156, 0.03323269497242666, 0.029352333231438554, 0.030206241644918922, 0.037288153769388314, 0.014474414488030298, 0.04033673171614928, 0.04983585042458388, 0.033068028203542196, 0.05263000674125168, 0.016406753491009438, 0.033090049400925636, 0.05412815679465571, 0.060669647514699936, 0.02735093810535487, 0.03469206565510362, 0.020744929375547557, 0.05079897999342892, 0.06223303378529607, 0.09115659526639408, 0.02367379267760102, 0.013184187400545324, 0.07959888722266882, 0.041023698079610066, 0.015543291961113292, 0.010267744298964258, 0.029194787249810276, 0.0056607534286505995, 0.03164526503232699, 0.013080531873950555, 0.05740568011758789, 0.020650112588379173, 0.05387256688047802, 0.024846918437810197, 0.03859041131011421, 0.03675300688032181, 0.07403175692043959, 0.11629297428073422, 0.06813670268222209, 0.017005202225259235, 0.08080036589695562, 0.031378248916758646, 0.06862085492860887, 0.009646405815146863, 0.0573340738793054, 0.07827383090531634, 0.03627578389921016, 0.009201829670928419, 0.014399555248899326, 0.029813973984170346, 0.008926980306334313, 0.03330607470425387, 0.05198618644968637, 0.021700909428839243, 0.03423379951967828, 0.02555861986512619, 0.026560136184637106, 0.05102418686052965, 0.04362085488654914, 0.04245041426451456, 0.06021070339146161, 0.03927834294435959, 0.02787329707174532, 0.05954355955304158, 0.009684340573937423, 0.05764694035714192, 0.023224213979237025, 0.027372620308831818, 0.016846662244549202, 0.019628381123766303, 0.04374226067034949, 0.019544576850509452, 0.018023926794769305, 0.03528810504283156, 0.05268858182394216, 0.07760886658704089, 0.04605774226928911, 0.018087062015829068, 0.07509220646874559, 0.045561340276993094, 0.10325254902483956, 0.050830703694373376, 0.03767910758934675, 0.007958258295642033, 0.06374750151148727, 0.015616470594860375, 0.046563406264589685, 0.026949456322097012, 0.059460408369740175, 0.034145458090689876, 0.04378266414747604, 0.15907775911111988, 0.12495038835632226, 0.17776132591309088, 0.15318289639488344, 0.12979775607105226, 0.11931980299132487, 0.0861052183374282, 0.14644579661469306, 0.18898477447369408, 0.1398626498637661, 0.11396785146526753, 0.1107577208970343, 0.1566066199372853, 0.15179322822199715, 0.11979444808657132, 0.13656934512959373, 0.09346683299349201, 0.1687610798305081, 0.14289243567374446, 0.15557589460044138, 0.15150023023447684, 0.1046878990206507, 0.11105224339952392, 0.2950538304303923, 0.19524538288674048, 0.12674052133074692, 0.2710463815639096, 0.15806425543081376, 0.16795111038992483, 0.21260309663991775, 0.1315007235614523, 0.23581897749775843, 0.11339880135511199, 0.14850478048526472, 0.2904164857201038, 0.19391773719220393, 0.08990577286890439, 0.14725706840474762, 0.14493085774442843, 0.13280843564819905, 0.2931560467808478, 0.11322492237893805, 0.17082974705244267, 0.11166471537322768, 0.07156748955528583, 0.1225079928014067, 0.14001566826576187, 0.13625920209432804, 0.23852596449996197, 0.15925849457421612, 0.14817980598778496, 0.17729248010343124, 0.12530115703421255, 0.07633008198031495, 0.2601956041349519, 0.14870924935225519, 0.1533630036658818, 0.2613976880186989, 0.11840051280394678, 0.1322394161815605, 0.1418831454770219, 0.19432546450726448, 0.18700580082593427, 0.16364934283398813, 0.20572817764214932, 0.1443345349041685, 0.07982754148542881, 0.1297293597411725, 0.11725387070327999, 0.11628745078680017, 0.18908900839667167, 0.12747499280639235, 0.13272595862227102, 0.19079556117855734, 0.17212426710513332, 0.139066883693299, 0.057740058344338215, 0.13624510607652127, 0.12044651914508113, 0.13304201585631217, 0.1338235940784216, 0.15034604216775588, 0.14824631774137098, 0.21526486913283027, 0.18488778221991756, 0.2516153734177351, 0.12911232188344002, 0.10749529716708969, 0.09692676185119538, 0.1750610958063795, 0.06631063252326942, 0.12530040626804675, 0.1791846100240946, 0.17330185149706182, 0.14420085256138157, 0.10836647703282296, 0.09074160543781135, 0.2558243370825245, 0.20861047620494522, 0.18010253657496747, 0.21120140088662026, 0.180284543744018, 0.1421240954509666, 0.18954826278551934, 0.14176084720078977, 0.13806864048444456, 0.14484899358883982, 0.12247567155188131, 0.14383185865177264, 0.10237261277413177, 0.12739135898769866, 0.10522602982218228, 0.153523545051294, 0.07483391992507443, 0.07157091396830736, 0.14563130725535656, 0.09272257091417428, 0.15433569018158222, 0.11716173330862677, 0.164682780122084, 0.14930558751427359, 0.16529931236178647, 0.14173081655415798, 0.1400735845128375, 0.10914081572404793, 0.11771069659340767, 0.09694012242459482, 0.17688135135798685, 0.17459502323500573, 0.1274653554203049, 0.1533795971303217, 0.16464695785074465, 0.07209761473800867, 0.12230298001199, 0.14544474952403577, 0.11520611768167828, 0.16091238647218675, 0.1484701226675703, 0.10549149460970395, 0.1852893501880669, 0.15367219675212138, 0.14993810034807653, 0.1524802558724919, 0.10726984515185319, 0.1409686816435668, 0.1430079157674505, 0.14225661334010864, 0.13996424844428418, 0.22559357296314933, 0.12728875683199975, 0.13222018737466107, 0.18851321671278248, 0.2100085866667571, 0.16070316786006575, 0.12118031646335319, 0.18162106073671774, 0.17127487477996658, 0.10760981199001113, 0.11317245301700408, 0.19904494916479434, 0.19710198164947573, 0.11847604141240159, 0.1583005782336958, 0.16167266745000117, 0.11758809188200582, 0.20090160921456354, 0.12591165250107167, 0.1338059280908877, 0.1294193086364577, 0.14713310005684055, 0.06763163623550246, 0.275283491299037, 0.20863800940494384, 0.12516240318936686, 0.10276842742196976, 0.11453358441471093], [0.03783039080219404, 0.04414120478735816, 0.03540960658762244, 0.0991441114174743, 0.06876614350344866, 0.038665545383288015, 0.0331691479791076, 0.059115998221621405, 0.1280115454667999, 0.07084579642621741, 0.014784347806726734, 0.0009588818507073748, 0.03819111479266036, 0.017362687579025666, 0.014006553101353349, 0.027208911149852702, 0.02802013505941197, 0.014008737409547454, 0.041498676423103585, 0.012427468731578802, 0.0366280464485528, 0.014736558284400212, 0.05817412759267515, 0.04493757999772507, 0.029514519790668162, 0.0590562203808898, 0.04536450930660771, 0.015062370690547172, 0.047503537873947815, 0.07744086350524619, 0.04209502990688047, 0.004020970955025405, 0.014419471619710808, 0.02751340428667684, 0.06003824933882683, 0.06396203294336315, 0.03478086673684659, 0.06124673005674155, 0.04240518060302542, 0.10455787857814182, 0.05007264437153936, 0.04655741162658219, 0.02536680102498541, 0.03950201763561176, 0.010195101926764174, 0.0635423853002008, 0.0215839967507148, 0.05326836482591687, 0.04063832904061964, 0.019924772880791176, 0.07581232145669, 0.029017049105717774, 0.04136664883023308, 0.014286946069689528, 0.10528340980771089, 0.02412850991071713, 0.028338222426452467, 0.049035031904256156, 0.09251835485619885, 0.03298413008451462, 0.030903285895023617, 0.024221919011324648, 0.020565002135211424, 0.02767610795525534, 0.02502100234250388, 0.05271002462494278, 0.03071523237703068, 0.03683626914637224, 0.041308874309423475, 0.051103542078166246, 0.037022007163614035, 0.02906505600549281, 0.011442306474031461, 0.03420921575818812, 0.03730312695786838, 0.03506506237411692, 0.053893649620154215, 0.02268243659918587, 0.010234900194430544, 0.05721307412210492, 0.023344430411534927, 0.21846638121191533, 0.31764913410429035, 0.30420168633422545, 0.2192376938558394, 0.26475152902064786, 0.10630563922947454, 0.14984563353561586, 0.03177102219553725, 0.03642905511022095, 0.017266897860193448, 0.042148043191240686, 0.3304928126594713, 0.010812410788099852, 0.07230775265563881, 0.1272167292453589, 0.138088405552891, 0.19590440236272352, 0.24549368738887772, 0.1067798936198796, 0.15833027180164091, 0.03853668939442404, 0.048147185795730164, 0.05050949451904144, 0.057366138489376155, 0.049118535488002726, 0.08098556765265043, 0.02393130738768847, 0.048467851048635865, 0.03622334901123278, 0.06050018886584909, 0.009949546806784648, 0.017258865428307367, 0.026132369924697186, 0.02672252958760627, 0.022527491486060525, 0.05370649817069212, 0.03095568247860478, 0.05254321664030995, 0.00438350243418808, 0.02811742822579559, 0.04732800031741781, 0.05068543044129207, 0.032984834885404955, 0.12539216061873784, 0.020342430610570218, 0.05707769106412607, 0.01705148542720464, 0.04801854048104537, 0.010322346258157445, 0.03026453519029723, 0.020260399830858075, 0.09288512711082736, 0.04053230630233884, 0.07219590381869385, 0.08167647170804201, 0.031154748510509252, 0.04506025748747972, 0.003798303190588711, 0.031013642775736032, 0.022378841700452953, 0.059812816475788434, 0.008477574935363186, 0.09766915467597785, 0.043294436313332095, 0.09048947058017216, 0.02632234823859988, 0.08498636224577505, 0.057280305998339776, 0.040747711074448405, 0.06555127085096414, 0.05653377246832656, 0.019237130444737214, 0.04114063757081186, 0.019341745496457143, 0.013259941047327894, 0.025156033000037558, 0.07879768182793934, 0.007851050993908317, 0.019547099195000146, 0.05579450911271477, 0.022166784732572498, 0.012645644826754447, 0.028372522098042315, 0.06351373744227233, 0.05840403057875172, 0.06299532957435136, 0.05096138297249714, 0.03695692416400679, 0.034194763509496566, 0.030083579476922754, 0.0300812429087537, 0.07784262299537659, 0.047900620397300496, 0.027230181581070347, 0.05016359816034956, 0.018768455089640715, 0.05222028376714838, 0.03664259828867451, 0.04289559944863281, 0.04182252860177429, 0.05697867419991282, 0.055057950047475684, 0.045131335125094464, 0.04980521073805229, 0.01700002730133072, 0.024602865807772167, 0.05560561481322493, 0.053559842128907485, 0.028501343612949696, 0.07157117443820162, 0.011933239556158022, 0.10222821286128414, 0.03157352664387755, 0.052276212016060475, 0.037438919872886715, 0.030066727457808393, 0.027814982458949093, 0.05399228727084495, 0.05473447325188787, 0.0046164386496398485, 0.018150746904974504, 0.015526619015051233, 0.07021663139664358, 0.017516948958678592, 0.04238184173441222, 0.06905566345179273, 0.02818942325369966, 0.06368393919640972, 0.05461608202406957, 0.034299165971817515, 0.020449548854582736, 0.05445524952524612, 0.042710861176132195, 0.07123913661005997, 0.029916478463658885, 0.07526825347374524, 0.037097168049865195, 0.033699771118981224, 0.09049793585173546, 0.0421152048323664, 0.04135647518259864, 0.08034200017010013, 0.05824889777408493, 0.06666139354028049, 0.032616790924822135, 0.027825286341530663, 0.02991115989824457, 0.06974678201180312, 0.025133442982370337, 0.05836403695866466, 0.03470695840435163, 0.03208264761093644, 0.07249704532084927, 0.0838503611063765, 0.013001003328921094, 0.021370053291320804, 0.0511256552061006, 0.07490672892139805, 0.03287541454717998, 0.1144016410915121, 0.046179423844742204, 0.0793173039452203, 0.020475616911426187, 0.03323609257237085, 0.0701712636697677, 0.037906176050103484, 0.08759780276206233, 0.03434774360709614, 0.04106612785929634, 0.07021447102869711, 0.032756697731993856, 0.06955383510719385, 0.02017316922935988, 0.07907475284751385, 0.019529940740716074, 0.11410404657644611, 0.05115915240058976, 0.18100215362445002, 0.18094610663190966, 0.15509826942316948, 0.13814264457793007, 0.11238221800135029, 0.14672898867678258, 0.08341975840589694, 0.05192696402269987, 0.10924813698136038, 0.0752184194542708, 0.1849883542426171, 0.1027794590880794, 0.1302067550920671, 0.5233790737486655, 0.7687881697089441, 0.37774821082430504, 0.06026128817710185, 0.24085534676428766, 0.17098921591476088, 0.06982759662693547, 0.01925116326029022, 0.08725698556630843, 0.05915588458939906, 0.02549371881140096, 0.07828126961906111, 0.02796943536058309, 0.002347837083019136, 0.04193030185096207, 0.06204131645180526, 0.022517842608654214, 0.0632659271509657, 0.03348565337458446, 0.02165061767183004, 0.04735816502943636, 0.07297572769945668, 0.12556537309841764, 0.022671971838140202, 0.1466329518945948, 0.039585770197933724, 0.07247718832185192, 0.03258856824569164, 0.05905394509975469, 0.05800303334610597, 0.017305321000035734, 0.06708061217420525, 0.12547670608206143, 0.08042448485690741, 0.01744141843500397, 0.03305445695596357, 0.025960444472730163, 0.05113005638122559, 0.019624998845580607, 0.03778199319757762, 0.11925356702939158, 0.04471352992339, 0.05019062957275779, 0.023289088219884905, 0.016509099007253687, 0.056772347569705985, 0.06764913368369303, 0.034147488223689224, 0.08650763666317349, 0.009647792434289811, 0.013925544091410214, 0.06472314512657543, 0.04601360411353169, 0.030601972023085244, 0.02273437544523228, 0.017978536085255684, 0.0635151815180096, 0.0397774453965887, 0.03783719366296165, 0.03603957600951676, 0.04123507322923791, 0.0957492157636631, 0.07134350842886394, 0.024671717959966873, 0.030924807220036467, 0.049898918612950274, 0.006055218804131953, 0.043271603062748916, 0.04193241242319346, 0.03636903978223282, 0.021266028127302567, 0.029530033071134842, 0.06725718011899341, 0.013147826952439164, 0.05050073430362729, 0.07222272455692291, 0.056214528308520396, 0.05994796970739, 0.019905193588666378, 0.040008712019170486, 0.042841479167222016, 0.1381172564241194, 0.15877921464702777, 0.15362374935178988, 0.12770813634438863, 0.1588669163925994, 0.09760449685516859, 0.13342642345495764, 0.12935526368598785, 0.1527381976765971, 0.13900495314550015, 0.13175238344457843, 0.09309285951237525, 0.1581062983360983, 0.1934479107900012, 0.12603429551686973, 0.1335736042669704, 0.16108212091269034, 0.12330005110632028, 0.12181433849036695, 0.12702073331081098, 0.11543890115835014, 0.1555397965374493, 0.2006420892693343, 0.17510847068361698, 0.19302680757978272, 0.14302374314396613, 0.11990036740298234, 0.19269253277490217, 0.17415262278049223, 0.13734525430106348, 0.1501753577782262, 0.12271494379327183, 0.13974153136293735, 0.14780195610177133, 0.1321005550844054, 0.22386278115933944, 0.16968905745494753, 0.12035028318003302, 0.15641047078515255, 0.19129777777819865, 0.11853997911056204, 0.15756619102772207, 0.1037309326291565, 0.18467519282092973, 0.14603718063764035, 0.1605020851017006, 0.2030150925800685, 0.10711797588174382, 0.187674212539869, 0.1543684787447414, 0.14355451950142462, 0.18427719482250754, 0.10045003085847824, 0.12549876175340147, 0.3075029737045688, 0.1252416396633752, 0.15556922963550016, 0.19379602114279426, 0.11729085742826424, 0.12201687681578821, 0.13561404880977448, 0.1441614143550396, 0.21961038030924337, 0.1205033015820288, 0.20605074662354686, 0.15227782479938, 0.19623156787166673, 0.20909381639813224, 0.13492286896273015, 0.2368319755600345, 0.18317203638294052, 0.16619217251577686, 0.21412895992398265, 0.17204238762778623, 0.15909957729520338, 0.1206110595094581, 0.16300760630157687, 0.11456611250797588, 0.26681776008298325, 0.15495136440280946, 0.1849564083761746, 0.3914446065262441, 0.5608108651734168, 0.47833083618071776, 0.5746864335190865, 0.40313415830173804, 0.26065412307939223, 0.28958748665548145, 0.2137492254616753, 0.20189399951167647, 0.1654925044145315, 0.26832226483571914, 0.7421435091284014, 0.35300023072669584, 0.2961437896855416, 0.3905804287041388, 0.4093360384145091, 0.20816444449367064, 0.7283113320027629, 0.4325314647247715, 0.18560859434787305, 0.14641601111619704, 0.12821898675493656, 0.19193672575056556, 0.23308496291358627, 0.14359214974026527, 0.20786556295089184, 0.06586102318138846, 0.1489078959510211, 0.14318374826783134, 0.17038406774161324, 0.10926267733016323, 0.1317157797635563, 0.11280299945464058, 0.1064310937879547, 0.11972798229826075, 0.1430701987156945, 0.1757596300974969, 0.23620323187881903, 0.13013250585044586, 0.18436344100102303, 0.1456187127698814, 0.13219711280638172, 0.15706366799291105, 0.25298236538806274, 0.14226435082814387, 0.13458638782462767, 0.22772427798519213, 0.2032783050690928, 0.13273113737663916, 0.08676388541296606, 0.15720499589318232, 0.2178823004566854, 0.12595373371075239, 0.18254870128247047, 0.28566643415439513, 0.13229635183609303, 0.0960558501162356, 0.14536501509287666, 0.16797245359949528, 0.11258343099466256, 0.11449793068271492, 0.16989504317602805, 0.2006526153174139, 0.17288238771500128, 0.18370500375186244, 0.19191144484906428, 0.21817753542094462, 0.1415683139836596, 0.08936519058601511, 0.13846150569377408, 0.15544952073645207, 0.10355501585910398, 0.15322939793188728, 0.1128175014990472, 0.09319035952249843, 0.19592808980134227, 0.18784578559139084, 0.12983227599292033, 0.15497842262829506, 0.18942922804384463, 0.13740695502248504, 0.13385910991459124, 0.11286916646866069, 0.1808505448242349, 0.10480476573349969, 0.13492423259923536, 0.1302676744038059, 0.10968846133759907, 0.14211470321301492, 0.16986415451092107, 0.1321467808297565, 0.18544964642534334, 0.17513214280047726, 0.12894483974143384, 0.18413269531822976], [0.040855855876279455, 0.11040202627379088, 0.07926079729992537, 0.02876012428333202, 0.05044844880279514, 0.03656122442935744, 0.035698444717713905, 0.07215218318085517, 0.029482863122417085, 0.029953645219305353, 0.04248595691376156, 0.030494137486863523, 0.04768597788267559, 0.0574397940128561, 0.08108112946032517, 0.009827230335964311, 0.037926090505695155, 0.04857088221357234, 0.030459809086976514, 0.03771141351711366, 0.019470398472021186, 0.06491651337954306, 0.08456957211057026, 0.05493199753184473, 0.11062328778808156, 0.01638110869774415, 0.014570661944397276, 0.043792370481476675, 0.06995131982670677, 0.05183923163361127, 0.008870804036456731, 0.04347885665934413, 0.07873084065654586, 0.007231103917283397, 0.011363923230448799, 0.034358916999471766, 0.029261463712300026, 0.07180873064264175, 0.037011239797838276, 0.04788709894543694, 0.020569160077420455, 0.03946856640639805, 0.10660742424548635, 0.05670446834917511, 0.02265823013599842, 0.027407674577027082, 0.013555904752725076, 0.05145200483140446, 0.07562990060016032, 0.03236945177758894, 0.04862953007461564, 0.03243466118170369, 0.024396481720971006, 0.026262170116927837, 0.10185214029925485, 0.04761553992847762, 0.05359096445083138, 0.04614250989811075, 0.0639835523531562, 0.04041340179561127, 0.06138777833492045, 0.020925205185889237, 0.05958996532905487, 0.04316884002858593, 0.07113756101217962, 0.03701358402688657, 0.020370475174258315, 0.057085263843257586, 0.02011821199689181, 0.039663451513455766, 0.07387715271644055, 0.02591634845180858, 0.08858084678649904, 0.2688336132034179, 0.38507415642661436, 0.0206843548033747, 0.11740524201623856, 0.5739097429379341, 1.3778845148701824, 1.4436955125101152, 3.2398831555920267, 9.585062649942214, 14.225951221681411, 15.802661661178837, 10.262192199307105, 7.5378820492375285, 4.295551824954249, 4.717512563351662, 2.7929170621979624, 2.9378449628430032, 4.147151400966029, 5.48538516606054, 8.039597811237458, 11.003198527520704, 25.200814547077304, 41.23646205471408, 40.77925882031841, 31.398514393837225, 12.330919850257136, 3.557178387718816, 0.4901321448626057, 0.16572021638914464, 0.07888221963038368, 0.06563768556882298, 0.0024552169939382907, 0.03233791959862555, 0.0405484784184204, 0.05637672444384906, 0.0653856426417347, 0.07871335853011378, 0.06260521845110963, 0.06395979596662425, 0.05410279545392241, 0.052683138769240155, 0.0557976117688081, 0.02224756104330863, 0.045287184221970464, 0.0855659384040102, 0.008824847379489052, 0.03090976891408284, 0.05567994066363862, 0.04460733864576586, 0.07428954550695997, 0.054001216025602435, 0.05348663859730286, 0.010033877765489443, 0.00043864785062220523, 0.02445360698226479, 0.06028024885322779, 0.06343316031439651, 0.0412951881486562, 0.03796229199055703, 0.053006611734388344, 0.01429801220975576, 0.06470772377665966, 0.025102081257970105, 0.01577513602246801, 0.07619727297776169, 0.04484843417641617, 0.06183078399889412, 0.017412155791516268, 0.005385767125840029, 0.05472621865450375, 0.013443338665961018, 0.024970685687637138, 0.04372077190407342, 0.012702796901125583, 0.0456374051469949, 0.020257565305538235, 0.10567661209572708, 0.048050712343425526, 0.028432253973498463, 0.03607927468575297, 0.02931110237935378, 0.02411920385765693, 0.0395099887804639, 0.0600004812041598, 0.04893785365106118, 0.06921369206881331, 0.08879643925015004, 0.0652649608110228, 0.031096765230740273, 0.07764008466995533, 0.01525784281247686, 0.01791002101174766, 0.009961477668595412, 0.052876445735173846, 0.05203442700627831, 0.013462724520884936, 0.022255216176892002, 0.029566397349680626, 0.03180751862424997, 0.030761636237824158, 0.012319912859839539, 0.02863055008703903, 0.03861029129174929, 0.02406197708971318, 0.09353021144746773, 0.07290237478070682, 0.042012001297646956, 0.07067505841053302, 0.08481435252413635, 0.023754523023061698, 0.014993001429003575, 0.047529971737775116, 0.09893779627858632, 0.06038469728082419, 0.03592155633434173, 0.07180369744497923, 0.04726136215932427, 0.07818399943531522, 0.015626115641827067, 0.010668958909058524, 0.008813454694445095, 0.06952948117208096, 0.07297335282689141, 0.10306126453102597, 0.02979158123414363, 0.06726454988482498, 0.04331839188272434, 0.017942240754623088, 0.05251145463496928, 0.05153648517725449, 0.06127513276653425, 0.06771334717350622, 0.08490310381016425, 0.02501247195346702, 0.04140299970224019, 0.022432839407795863, 0.024932762420165445, 0.017962505695440115, 0.03829126929744117, 0.05708308049267339, 0.02323193039985434, 0.014723504146170473, 0.01955683234207813, 0.038914087288562334, 0.03457749337558785, 0.05823700425906047, 0.038428812723366484, 0.02896054820608228, 0.06185364789299427, 0.028530891624189196, 0.047925977907594175, 0.00946295265513923, 0.024337130974257187, 0.021667479267043453, 0.013998158692923045, 0.10177572302880789, 0.06911372525557395, 0.033339441663795905, 0.0891141971993831, 0.07715936449746932, 0.049778704095872185, 0.04806162143546728, 0.040768146469828584, 0.020850281786894607, 0.013649312895722689, 0.022989551671930862, 0.03707054649449645, 0.04923527196590458, 0.07824946930932422, 0.032205964784107866, 0.030657607243366303, 0.06114823030187719, 0.04502470717735348, 0.04578530991209611, 0.17502156566948662, 0.1051567524911896, 0.2054931265452216, 0.09088133987520011, 0.12282493869744002, 0.7301966437409002, 2.4262087912328782, 5.910990766940579, 5.706726966365691, 10.929269694512891, 22.91893647563073, 29.73629236221314, 33.70577020029868, 21.94533359619879, 16.533504147683423, 9.451162738184776, 9.659878919201514, 6.264353663690629, 6.496089254656146, 8.454967006560295, 11.029110685471567, 17.101267230126165, 23.16226267045544, 46.579169534867816, 67.58361478005686, 71.19545090583064, 62.7829239445348, 33.977731658566384, 14.745639774107165, 1.7159864498722939, 0.29967579209516126, 0.03257237697741197, 0.011526250558334493, 0.045923006555606286, 0.0238301397316278, 0.012101546200292726, 0.02841170941058907, 0.02500535499665045, 0.013982255665224888, 0.02412846011500205, 0.037317257449631734, 0.08648352787619637, 0.028018072367675846, 0.0031739353078357397, 0.036535403435869564, 0.07755412194397181, 0.05309804049771159, 0.035025827181074894, 0.08946665893158606, 0.030067284786773306, 0.0702460568338152, 0.02318617962901631, 0.08142658148802097, 0.04938886110340396, 0.024686388543716842, 0.036499404964307626, 0.03958419971768895, 0.061034512210397, 0.06515925599923057, 0.04360912224998878, 0.03839942559059109, 0.05191756795430857, 0.010686881536047065, 0.05265385505833453, 0.03181307084648119, 0.0526857243159846, 0.019016818879472635, 0.03349513754308705, 0.023572529260549816, 0.015122602438373912, 0.11449035407314379, 0.07007508133087428, 0.04520304861568636, 0.06230084405791375, 0.026086519562428998, 0.017477956998552528, 0.1477496169747845, 0.039591918053526076, 0.05928174900491873, 0.003199174792708589, 0.062119016919525406, 0.05635376478875837, 0.04336419244927745, 0.07896734732052973, 0.03703701099561107, 0.0446826029538868, 0.021782308186013854, 0.026046568077177774, 0.03589664315504413, 0.014832325020594703, 0.033849096977181976, 0.08915591834773941, 0.0420698715794471, 0.034437525281382185, 0.09982541639117465, 0.04413192746259513, 0.06826970320675643, 0.03752292524422369, 0.0243423058981857, 0.053056173792649666, 0.08036106043765623, 0.0365378970520631, 0.05100754743081428, 0.022241043550292813, 0.01670285030418346, 0.1400301166840138, 0.18266113234623788, 0.15628671694186427, 0.14112790535774924, 0.09111114326984653, 0.16238816292776218, 0.10918080551369537, 0.19826547002359746, 0.09987504356690954, 0.3086076418478643, 0.16050475108767712, 0.13622469749421845, 0.23043987581566458, 0.14140211886936618, 0.14291512719806165, 0.11210919192601597, 0.15575836142224653, 0.14668853923438058, 0.11181973326470583, 0.17906388988898647, 0.17544220922695053, 0.17237430288185998, 0.19756615432279725, 0.07277754075344532, 0.12720452546472513, 0.11412441685435273, 0.11862169004856579, 0.14223821190816743, 0.17901076935231688, 0.19061646514361907, 0.13342574929758427, 0.14434625604941, 0.14020244050170147, 0.16059862750191845, 0.1298228377896932, 0.21214045614244478, 0.13964624534691536, 0.1193045961460279, 0.1082502231903134, 0.11210150806413544, 0.10634255700654562, 0.1417254692604465, 0.27867266427605386, 0.20634408168975385, 0.1545894338238624, 0.10479849913427908, 0.17299779119991487, 0.10394442601189499, 0.17957128524299593, 0.1330250546696686, 0.08356493972842732, 0.0901008188544262, 0.17501137670009367, 0.14928571519351777, 0.1820232415752065, 0.1567151133091219, 0.14853956087702705, 0.2146669068644124, 0.23773274174140346, 0.12060900639382102, 0.11836130442398211, 0.12089876382942162, 0.1144509465103188, 0.18701323187879978, 0.3325877566972087, 0.21891469586520426, 0.10883477892005637, 0.21267952157124398, 0.14579357999947765, 0.07492874628834187, 0.17971152529841472, 0.2238197883050288, 0.3104411966858372, 0.4974477023126618, 0.4023581725214759, 0.17820035558073752, 0.31279636546969414, 1.8096847639929865, 4.418248957203281, 4.268986102073423, 9.715574614463314, 20.27594735545497, 27.255324586745235, 31.396921911547263, 21.942927222098074, 16.268679441944247, 9.187794212372072, 10.525996108208934, 7.203875558991586, 7.72263696116786, 9.030463041797761, 11.66549269230135, 16.407449956863157, 22.185202221716604, 46.80248183588828, 68.10283460924703, 74.98056950107699, 60.179333071554865, 28.8594308207112, 9.27576611118932, 1.0808369252950916, 0.3667907939562875, 0.2299197634021121, 0.20549986811895526, 0.10655531494487679, 0.1587532136228777, 0.13576239407543214, 0.18002016680134883, 0.14402891178765606, 0.11077989914244223, 0.0826544289086615, 0.10431869826730221, 0.17647688757748375, 0.15750039939678487, 0.11584534910657715, 0.1119140999752187, 0.16715234115479455, 0.19321393221616748, 0.1617468554045885, 0.2857686302834942, 0.21501797431659317, 0.14724585287753614, 0.13960450887680054, 0.11835567367773865, 0.2230117800495317, 0.21432189150683342, 0.10380020996014919, 0.1093128560892036, 0.136001551403634, 0.18007014637752888, 0.12033324538459701, 0.12742960209687873, 0.14094617398035142, 0.21421626330383364, 0.16324904657179312, 0.16575781598446832, 0.13140779709623707, 0.1425079208227896, 0.230034829808339, 0.18099596363402184, 0.14421318657696247, 0.2120376931082818, 0.23332514679960667, 0.11297663328267875, 0.14825952509718557, 0.14486256866685807, 0.08730513419234946, 0.265653214507526, 0.16581363315063138, 0.3057025445084418, 0.07283366435477812, 0.188255520056813, 0.15004628728474342, 0.1782016426084503, 0.20056603206021173, 0.11048778981691408, 0.2369113882342654, 0.14661226752063922, 0.15111364694612642, 0.17005451203834626, 0.10540756967759903, 0.06859860007440852, 0.22128892491661736, 0.1530027891238851, 0.1420904641910907, 0.1550362775883367, 0.12665533235356694, 0.2518360833487203, 0.0989934908706815, 0.22948081034325787, 0.20167831511747455, 0.14925338628311313, 0.12930551393618508, 0.14149383491566106, 0.14456321214956624, 0.1615135663098866], [0.007739661809717937, 0.039532833522365945, 0.034764775059997075, 0.05510031087924877, 0.04526543881623976, 0.19219535703380264, 0.011044815051249199, 0.01200587522508877, 0.07893769971786008, 0.048139191668240294, 0.061463942796352415, 0.03607274378619848, 0.06879000714229, 0.03802956600162772, 0.046827710428906065, 0.016886837810518283, 0.04043070006094152, 0.013831886012227306, 0.09257543606743698, 0.0070045372441170685, 0.047735892341382084, 0.009338034358206055, 0.027613332795519984, 0.0523145164122745, 0.08070986026958113, 0.03212652338157979, 0.050149686003644625, 0.038809646521845174, 0.022811451551294135, 0.04285617273360972, 0.06858075788665204, 0.023798619043983282, 0.033997947860869675, 0.04725016578431091, 0.0642129956864782, 0.04023230244075099, 0.016169689498060656, 0.10361968900167173, 0.034848179052313494, 0.06661051764122902, 0.013878255399064192, 0.07807808777978344, 0.05632273822782501, 0.015928616950048075, 0.04172220938808976, 0.03572768246334407, 0.025524115265016595, 0.02483457676135004, 0.03044245528027175, 0.04612588195971424, 0.029849014845826936, 0.10295911436720241, 0.02393508420115517, 0.033719045891156124, 0.02045407643421523, 0.04463063154910361, 0.028551957126887097, 0.03540865663859633, 0.03848567176910658, 0.05206703936921493, 0.07154118975684529, 0.08737939875572921, 0.023726802131521608, 0.03709560140006004, 0.03961755901635174, 0.05702564688099008, 0.12224360819785826, 0.10671816991582032, 0.12389098068759327, 0.4434160419529485, 0.8454932440673152, 1.0479746951210884, 2.8308022550998198, 7.056927392559667, 13.102825630095698, 28.31048530917014, 43.30645368945214, 53.41406037730556, 61.967172930317545, 83.7208418692312, 83.81493168492472, 107.37832730816258, 103.42622556994039, 105.78771991114463, 88.74517056249803, 83.51316805808776, 83.94379723456599, 69.24870014190674, 65.6955309068003, 71.2722901375063, 78.1308211049726, 74.47040250224453, 93.0312385866719, 100.99869420451503, 100.98635442795293, 112.45274466852989, 105.12080715548609, 104.81387384476201, 94.60082207956623, 85.89786714123142, 48.349829412275746, 22.37669429471416, 4.311697281176045, 0.19111190952600973, 0.04216720305022694, 0.3020113183846397, 0.09078907990647901, 0.1782216834685495, 0.10270458931523947, 0.07612679288872788, 0.06069197897769271, 0.061620052363122665, 0.061781708406464714, 0.08916937085168977, 0.10565793487213312, 0.0579505984581286, 0.022744095185771588, 0.023045227111827944, 0.07932832028957144, 0.051969041401940974, 0.004540159753824194, 0.027531250304872953, 0.02677308372972954, 0.022502059282194224, 0.07555101652659717, 0.11169211067739995, 0.030854650803150672, 0.04761402690482717, 0.02941371794159134, 0.0751103550916718, 0.05344781326130033, 0.006575761184531956, 0.018182215881684137, 0.05329318990510318, 0.08534722796250736, 0.014091489269518325, 0.051212548728912115, 0.017831472101651372, 0.08162486802546248, 0.018494488641379342, 0.058821065862092285, 0.02179799766670312, 0.032771215098158966, 0.05541320417016264, 0.1030349800543439, 0.030343742936008403, 0.024908211217412067, 0.02071128087869335, 0.008016636589496967, 0.04253780957491648, 0.08305974304676057, 0.03077800562154622, 0.0033360711137403647, 0.008695723259851577, 0.07627318463017864, 0.017745269973191525, 0.022764626342142304, 0.015273044869724303, 0.05197037822536884, 0.08543148231241973, 0.09235885535036364, 0.007628367907713138, 0.03713185268063699, 0.04522443012965303, 0.06662636800038238, 0.014629977259544596, 0.10485284541162754, 0.017720879648902246, 0.10438927028688694, 0.025597855058168213, 0.07690755139675833, 0.013369614194567888, 0.05525188137506766, 0.03310950420376274, 0.04636189832742657, 0.06595293074966439, 0.030484969329629696, 0.044561618518444805, 0.06262074322289517, 0.05871055767901483, 0.017215975995866523, 0.07189047222416248, 0.022831408141721642, 0.050865445781739495, 0.06237930678311856, 0.04539792989230445, 0.06148380745622901, 0.012765116238545988, 0.02374325195447572, 0.020033582263896545, 0.02892717550088081, 0.06306806579232216, 0.03515451080015591, 0.03269244210734483, 0.08061141797131108, 0.0747210904955864, 0.07127309728774332, 0.017260631260972832, 0.060899627109568935, 0.03003566450769863, 0.044700410667686694, 0.030051788743284923, 0.04881005486353271, 0.03494904601886388, 0.02524096725298272, 0.0201451821222661, 0.04380332553879388, 0.063606457063748, 0.01618612208403647, 0.03711679522248526, 0.042867579782802256, 0.032422867258109396, 0.017691249283210888, 0.05266210965571865, 0.06150102911276683, 0.04752886474072453, 0.06584133472173445, 0.002123512892848662, 0.07332024509988486, 0.0752923699216016, 0.061581805423502965, 0.014118972673801886, 0.016540474138192592, 0.05220590429680963, 0.0277255512698884, 0.05999167885390982, 0.06569537965040054, 0.06270916509111563, 0.05369107299033673, 0.06640780311558517, 0.04543516942630372, 0.02346132202224145, 0.044694209185939644, 0.04719585398091905, 0.04007664103541644, 0.06578715698372933, 0.08210528176277876, 0.05814974684448493, 0.024193707823513017, 0.031135745699547475, 0.07369879978678881, 0.008673515328536592, 0.03329043501927968, 0.06372467975222296, 0.11228267253646929, 0.6146240066136084, 2.8384138595673347, 6.124809461255228, 12.561149251076484, 20.388113414087606, 29.792980417128536, 53.172430607580374, 68.02108457011562, 80.7382559007214, 88.08679288433444, 111.73092657519926, 113.58281089413552, 136.4513037281652, 127.24126477395336, 126.0283188666067, 112.46324877585135, 104.73360646155574, 108.22457082809942, 91.88281566865983, 85.16739629930066, 89.12857440210159, 97.97591963121968, 97.27211306172033, 115.707488213816, 122.19406866258191, 121.62717634631743, 131.92517095996487, 121.21030684440368, 119.5713915363435, 115.46860802558162, 119.2004765233686, 81.94571833456718, 47.63114921508297, 14.162600040435793, 1.2458534899257845, 0.012430822281467338, 0.10031812583967563, 0.14737495401453587, 0.16947864374566465, 0.18890666414893445, 0.09563103904046359, 0.08033544245746829, 0.022222059891529145, 0.06447820383454524, 0.06255307084610386, 0.012257184622989548, 0.0527317202349584, 0.012722065927641047, 0.026516350429324854, 0.0716057326644659, 0.07569661919748591, 0.040644526691927065, 0.047622852237714876, 0.03431976607610141, 0.021194680443694516, 0.021899084883531737, 0.041798186157980276, 0.06834084213140511, 0.13264608629528554, 0.05501481546689907, 0.019573450704375585, 0.020361351067080133, 0.03183536975073718, 0.036141009881131114, 0.01840778281010928, 0.04927444204147305, 0.006609994781038334, 0.09078710339963438, 0.06336531939826186, 0.02446510787722805, 0.03760149139129827, 0.017101024502828237, 0.059716959724262844, 0.06294960178615105, 0.04898934242045207, 0.02688444418562276, 0.060173904358018795, 0.03859427239325258, 0.04647908679720375, 0.028970405842447956, 0.011508214933377121, 0.004764255793434718, 0.039719536810392336, 0.041307108476758, 0.03358604536662179, 0.04084622615107125, 0.04608533292588207, 0.03756797121417138, 0.04347442867114179, 0.07614792925455878, 0.04192221579292128, 0.046457935109614365, 0.05016775035689916, 0.035187215093643434, 0.07992782239471713, 0.021309635767172423, 0.029141745237152905, 0.00827013939288595, 0.024173349036925265, 0.09837104443220362, 0.01399500624111463, 0.08948550469452336, 0.013423424210369348, 0.017819429199481686, 0.04766558079169162, 0.04532042094656537, 0.0836923095067182, 0.09090505795733583, 0.12563959169652195, 0.19428495377782853, 0.26793833221158675, 0.15305010271408867, 0.2569855884799073, 0.12126009685978775, 0.30596485301371545, 0.13163374706862435, 0.09091102578226598, 0.18855613295830068, 0.19908745172283343, 0.20582458214654079, 0.10255181606137946, 0.15331334584662992, 0.11861707053838239, 0.12788185444209846, 0.08894960320885144, 0.14022507073898471, 0.17355277593578064, 0.15088633333723392, 0.14839783461103517, 0.18778475902734265, 0.21232883716302536, 0.1251878756128492, 0.1731431180791509, 0.24842450996079754, 0.08155264125596132, 0.08103023823951522, 0.12526178777578378, 0.304450266543896, 0.150212298537935, 0.12438071771494805, 0.18994934045739714, 0.14003593895223834, 0.15256178294939382, 0.14361151644299108, 0.3029185503480896, 0.16924535465096274, 0.19436603652373438, 0.17475302120850933, 0.2268257947458375, 0.1913502241574949, 0.15122882060466275, 0.16184627829540163, 0.08712855092580281, 0.1321894672488974, 0.18365971263377898, 0.08710234305791317, 0.09797886104112673, 0.19729022477422992, 0.14968624128209007, 0.16976503805527765, 0.09279240748935169, 0.12281789834941588, 0.19242178198070298, 0.15299517420991776, 0.20478723781003108, 0.23595541775707277, 0.1701010288971086, 0.14171387068927288, 0.1609046796276685, 0.14318969311012378, 0.116013988041349, 0.18121123434074465, 0.16590291303732704, 0.23671651078808695, 0.16143778489241678, 0.3434716291244953, 0.5943080903060975, 1.6616502235974036, 3.085410167132655, 8.80522877939286, 14.186501983673343, 22.33467786542831, 47.9159721251457, 67.95118008890461, 84.009536158654, 96.54659225094704, 121.72136029889508, 126.88808671889768, 150.02050799708215, 139.5851206010388, 145.31727237086145, 124.1145238568706, 120.81556735500213, 119.78725525640674, 105.884014098875, 101.79109927146666, 104.19875990959906, 110.51121850167553, 110.09011283997567, 130.2638824524418, 138.05337229082662, 141.20094883826474, 147.64818006946194, 140.13119297642862, 142.99858677771786, 134.8205234158424, 128.57387435051703, 81.90265071007514, 42.21951000152096, 11.190719200718789, 0.6253176747310547, 0.14537050028241452, 0.42961000374728636, 0.31072667168994106, 0.5746362394382877, 0.3165323311282743, 0.17600969651774054, 0.17420542156023366, 0.1705221014638101, 0.2854404075732154, 0.15209244684346263, 0.1890702545642853, 0.15230014860149355, 0.14450664421723736, 0.1007841447848947, 0.16733324515723413, 0.18353241946428053, 0.12858387443327135, 0.19698613383356603, 0.1646548945216402, 0.14761106231279914, 0.1694741085051529, 0.2545145105931067, 0.17412070755756673, 0.24025324762107866, 0.15179558777280394, 0.12200085025641227, 0.18586979968653572, 0.13798568848400347, 0.12164088852343061, 0.10980223305523397, 0.1320632006372175, 0.09644393493691761, 0.18185300151667289, 0.13950963654825765, 0.12652157340198755, 0.15080259992711006, 0.08139307280221293, 0.11333567571015128, 0.17632207652974516, 0.1725707278256455, 0.22086504846811297, 0.08823514961066746, 0.19233162875377363, 0.09630337312457063, 0.09487744601022813, 0.11823889889544058, 0.13747178138263766, 0.16522423574520698, 0.11940260943506034, 0.11996363860464866, 0.133534625713383, 0.2007380034774542, 0.11856214203421148, 0.1356335074430512, 0.208138520078313, 0.1314384252914498, 0.2013224213113708, 0.229158609084064, 0.16356328051657448, 0.10329454596484862, 0.1712349156338361, 0.11125398499350395, 0.21354705485845768, 0.11572477452817465, 0.20717476614780966, 0.1354001264177984, 0.18507743494645243, 0.16291734582233816, 0.10859769002925004, 0.12308994383220712, 0.1582676977399857, 0.17822149960744768], [0.026191475523275234, 0.013932995254083747, 0.03630862608852406, 0.02935332723052031, 0.06743240740991409, 0.15202395858303194, 0.07178204013935982, 0.0546116502054276, 0.022586844147994153, 0.0741165551927782, 0.02621104140886136, 0.019090351828884695, 0.059546754139685826, 0.050114725581220085, 0.051915269690535726, 0.13622892629956046, 0.05223965046987419, 0.028668251189012683, 0.021842285209605773, 0.00846518537840776, 0.039733242123357715, 0.08844845147142488, 0.030421592790873784, 0.07474743625930241, 0.025682927206939748, 0.12604588642716408, 0.01882765836442911, 0.06345631149146827, 0.048938037512163, 0.04721453120451301, 0.04610165825954849, 0.06549630404239701, 0.07085295934830943, 0.12205273739152378, 0.08723035635006043, 0.022686129142980904, 0.031296331135015336, 0.04745795564245313, 0.013656189492453012, 0.03405364245296486, 0.040759508828482324, 0.017419468100753524, 0.06604874536635415, 0.014321623997191989, 0.08140657127143876, 0.03747834275747019, 0.029386318806979447, 0.06826742026474207, 0.032688163506287726, 0.09913312571664011, 0.027629750059737314, 0.028026727246000405, 0.04647418000404874, 0.024069515394888098, 0.055226803486866344, 0.03897322927631679, 0.14459670551361578, 0.05126389577203701, 0.042814329011185516, 0.054549953314445676, 0.042923063700718266, 0.09551355945727519, 0.04738622683010275, 0.027845662365096713, 0.22702258741182668, 0.09174747122151237, 0.6723528379394162, 0.6784235637995505, 3.789163784634683, 14.95517671108246, 38.819764275704664, 67.69482966392272, 72.67785579927506, 99.46630262559461, 101.20450096745645, 109.43865422279605, 102.63189854160433, 100.11990285688832, 104.7584899779289, 91.00194546484178, 97.89646810100925, 101.35829710191297, 98.458677107288, 89.47929705342939, 99.88958128036992, 102.19144775021462, 90.22390411746117, 98.34593249905495, 90.39438601463073, 98.24075806525447, 99.12056922912599, 101.04411525111045, 104.3762000914543, 93.75635931568762, 88.6856838964647, 85.49645962253695, 101.55222692797261, 91.60638270839569, 92.87037434116488, 101.160444905681, 114.0987123981599, 117.34528956874725, 81.71352970984675, 46.5075784344827, 22.26356529420422, 10.780554990614615, 6.541700536204923, 3.74244713014172, 0.09753731860508842, 0.04617158293483719, 0.015053800081894284, 0.02743340747040366, 0.08110158400790346, 0.06389487767592072, 0.025192056369457035, 0.009653825376693521, 0.05573016921839407, 0.04386692998870727, 0.03875345780303882, 0.03345086149150326, 0.03266441478063503, 0.08873263178693672, 0.026570045531937675, 0.07062938424848741, 0.011950238089587902, 0.0402570202676279, 0.04196397141523419, 0.02699869853864995, 0.04360704232127436, 0.0718654747751932, 0.03593711558008387, 0.04111203950859847, 0.012473978887071774, 0.009457074845540188, 0.026831660727639834, 0.02072685353097416, 0.031125575882352652, 0.028843223755698533, 0.03705780645231566, 0.0735558171366011, 0.021356081762801737, 0.03141166567201576, 0.03758854067493831, 0.03609301064223532, 0.0834064208151352, 0.012053078690153218, 0.0935534009289357, 0.04385939934441159, 0.030724157301348545, 0.002575145903862112, 0.07969360633362686, 0.05138932351743983, 0.07274390183269017, 0.05433670891028258, 0.05741163645119918, 0.04000356390831932, 0.06091505995080356, 0.08020719933894374, 0.04924352656328871, 0.04092870700743891, 0.09739140183815072, 0.032935441366486976, 0.15526408149350077, 0.03327049375061066, 0.024819440779186068, 0.05983840764289903, 0.12870448731607007, 0.10819477374635397, 0.04447626100192147, 0.0456007861442143, 0.044451692562189796, 0.06605506559172947, 0.058811359528091654, 0.04437615246241612, 0.004298451352834461, 0.08268069040270583, 0.026125245307001378, 0.07255420314087983, 0.04544070441155665, 0.09450505833111464, 0.06708676386023722, 0.08615652324571725, 0.052439331287337895, 0.0622659525834024, 0.025553439195538243, 0.08312099943718604, 0.06052943044191888, 0.035142092514903314, 0.023832702295734517, 0.03286137598596754, 0.048122498612370224, 0.030177628260947047, 0.04694413281075897, 0.022732546410313057, 0.0076568089219020505, 0.06403298800691001, 0.08607473569892107, 0.04257365099845394, 0.03502837825386274, 0.05336920114895029, 0.05474817856485325, 0.055900738694735115, 0.024015314674245256, 0.07462937444929155, 0.037519006704490994, 0.028497863658553654, 0.09202857186356861, 0.033847806119029565, 0.012543621067438396, 0.04085215567160518, 0.029392707980267947, 0.0759449236155037, 0.02977237732510173, 0.029897489059235782, 0.05614205256044384, 0.08225720465904282, 0.028690592228104512, 0.03245183687296606, 0.01857044625907175, 0.06666433531790972, 0.07992036069833464, 0.04076307496776985, 0.1212976887942322, 0.03383510821168462, 0.06605363300731106, 0.013967876194886143, 0.04998729451589527, 0.12519775814707243, 0.057235987811920144, 0.05237275824671792, 0.04788305017075712, 0.05224677125713038, 0.06528652618609129, 0.03191598326778941, 0.04150633730234639, 0.015117009996526666, 0.034573222435409987, 0.10118349875894286, 0.0313106952835956, 0.05854165827434871, 0.021652601839553927, 0.4377690546454922, 2.3621947294281376, 3.5191306616029436, 10.629610419273378, 35.992896403035815, 66.23792017659834, 100.57263851165773, 101.3073847370763, 120.78841670866936, 117.02137239517705, 124.15126077590452, 118.48088633629584, 113.66779296628891, 123.47935876538678, 103.62170080984794, 106.8887213737734, 105.07925356588056, 109.58954780332505, 99.5207686578074, 112.45811831566596, 116.72087961627592, 105.23567768835254, 110.06072644264468, 106.45077305455362, 111.48037341333206, 110.25581729027533, 116.14134942331623, 120.55287053508144, 105.17524180873748, 107.35192975690289, 108.99729344152637, 127.26344969964798, 111.7753513397709, 109.46225904649305, 115.694764044977, 129.2165703927317, 142.03813952784387, 110.98082034818589, 74.35640273555633, 42.490255525035245, 25.330644999780965, 16.63562305511967, 11.753262589054724, 2.930537832360114, 0.6367771243376117, 0.04888607759869868, 0.06670124543410155, 0.1790570410629434, 0.04087773151695728, 0.03336646158488528, 0.022564905305062572, 0.054574360875713254, 0.1262774748066741, 0.03284217782258507, 0.0447165904446475, 0.045436674789074934, 0.0519945138254233, 0.031251637565512816, 0.04082654535229649, 0.010600053130709117, 0.016759019870791706, 0.027497762686482845, 0.019326251368188573, 0.0938786282354305, 0.03544938953353032, 0.018541829044660254, 0.0530037235829138, 0.005327498957124209, 0.05166056077747096, 0.04259196816072349, 0.02143603835945889, 0.039690337369158384, 0.13102985527967254, 0.014210847683341033, 0.018224544154720444, 0.02093619088672342, 0.025039938120772282, 0.015191116554272032, 0.08851474105951287, 0.06410801865821404, 0.018487469360773123, 0.0029943109116321734, 0.02376372948469174, 0.03494194821424542, 0.014052220560129614, 0.014303493568853987, 0.014878701110700927, 0.05315314137166547, 0.07462404247733855, 0.02151740647311653, 0.007203587475458101, 0.07844083041193024, 0.07968118804837428, 0.039038702980765415, 0.014333858421342749, 0.0224910659204808, 0.053893159323882674, 0.109710356130475, 0.05454030443703937, 0.061868349120261214, 0.03597702493049926, 0.024957215946708477, 0.06249746052368034, 0.060628045109971884, 0.11573642672550295, 0.03717133685225441, 0.05120272365128321, 0.04105565543737143, 0.026115115709422577, 0.02118840618359466, 0.08668554526182913, 0.09443253278732301, 0.14178697079900773, 0.10953160483510264, 0.20366795270914034, 0.1961591112757883, 0.307963821556299, 0.17832139747277384, 0.1526332283092122, 0.10841504700722233, 0.1649999711662531, 0.19461233379139056, 0.18113660205516124, 0.12694502084125436, 0.1317804069408486, 0.18115308826729176, 0.2231270916038944, 0.3230584809376348, 0.11559517543402412, 0.1615384794891842, 0.22949355804631788, 0.13592694976156758, 0.16055114537237153, 0.1047036114839777, 0.14541073522019773, 0.09311288505071595, 0.2570161400663276, 0.14666172615703077, 0.206343392210622, 0.15143594013587122, 0.16197600762449926, 0.26230366359795293, 0.16093094112171283, 0.13943307372110506, 0.1703212944970977, 0.19824587349449435, 0.12409767120956414, 0.16079082364036193, 0.1407281453571012, 0.12236328645338937, 0.18486294564941239, 0.14722774255900614, 0.12256551068276168, 0.13709596929050263, 0.1777421277497084, 0.1780729245154127, 0.1455872878432274, 0.10255170114819082, 0.1379706578389291, 0.09752867713330254, 0.1835891252924358, 0.18341830300707973, 0.18168240905769412, 0.25569630846861874, 0.1814175418187534, 0.18475822143016324, 0.10085668565044481, 0.2561255934978685, 0.15962333628727546, 0.06665115094473285, 0.12712664496634277, 0.12318546733548566, 0.22842236794531348, 0.21164522626467291, 0.13121561627955208, 0.3250813207799389, 0.3220187770503183, 1.2728936970233917, 2.5178914973812723, 11.603451582693285, 37.62380223120413, 68.30529166806129, 105.21780736984746, 111.61662870837797, 137.6025350632206, 131.69477093604306, 144.09182979214577, 134.4585043384183, 126.9853065859887, 132.38466878091137, 114.54648233229115, 119.75659801113991, 116.923901496395, 122.36297376694219, 111.63177690198346, 121.6272940174226, 126.9999134925104, 116.44079100701117, 124.73104200055523, 120.78854222451488, 129.0945533014113, 125.64772344404652, 128.96163202101187, 129.1412530406829, 117.56074536231257, 114.19372789321409, 113.53683287097563, 130.38112209689234, 122.28496566895517, 118.84869483209427, 129.53706725951164, 149.25424944969916, 155.65750306652438, 123.05453469676357, 75.80355336589199, 41.320902839783706, 21.767946366340887, 13.753102633260912, 9.600391272575626, 2.0581186202264603, 0.3673380871693934, 0.14135800752668612, 0.19481016833695675, 0.18306306803659086, 0.15734943411042615, 0.15525985268815873, 0.1018161035232967, 0.2605943375777814, 0.1450418332411397, 0.09170405701884339, 0.10485289903778224, 0.15849378560819935, 0.2156937251528425, 0.1585387549693546, 0.19523985173192718, 0.14257103114599182, 0.1557757209746107, 0.1435653826281909, 0.12733072312849184, 0.19586482626055518, 0.1955144176439893, 0.13070534043494733, 0.15523118567803215, 0.12874383359186112, 0.19219391678850498, 0.10018424431402838, 0.12150033437196286, 0.2036957770225502, 0.193526404158723, 0.13124052945884968, 0.20422454622964706, 0.09482720596415382, 0.09762879716412676, 0.16535428683123282, 0.16880180506456285, 0.1587529684747419, 0.0714265983251314, 0.18570634716701123, 0.13519564222904945, 0.10097961211877485, 0.14955597569144544, 0.0878422384360625, 0.13223406888784903, 0.17887607577346987, 0.14100520871579647, 0.12151371792800005, 0.15662106835553724, 0.20696199288772, 0.1657460335521929, 0.09558484393862948, 0.21478056366885864, 0.11530274435156777, 0.2113738472783758, 0.47380687248322273, 0.11396460325246859, 0.16154356631300143, 0.152801139460456, 0.25843495022385354, 0.15092376439321428, 0.13689862504120798, 0.20300032240488838, 0.13463984543998397, 0.1516519003217259, 0.1294654118077409, 0.12026121779795616, 0.10971096133993519, 0.20579403056012047], [0.015585220910819068, 0.05386793970941536, 0.04619170806460804, 0.050107133649890466, 0.037080563094106414, 0.06653697320049809, 0.11677990742628613, 0.034600801600684086, 0.03473690478131175, 0.01827662664225265, 0.013157863661857143, 0.01978599222286815, 0.015183171264887338, 0.03617447260166368, 0.12264165982243516, 0.06731177154447764, 0.035476597146161144, 0.0939610286525661, 0.0398043274218517, 0.039212635583094055, 0.07726739055567211, 0.0638645367636796, 0.10185499780721242, 0.07805265366069733, 0.04846336943427882, 0.037719438288120494, 0.01940561999236384, 0.017907895117757783, 0.07839681866068034, 0.006579573429565156, 0.015975160621887734, 0.018325635201988683, 0.018807703689221415, 0.04215290784955986, 0.05704004167308731, 0.06852962917858554, 0.025086648416735476, 0.04330621874560753, 0.06596352574565718, 0.16057590533408428, 0.01834218270115314, 0.03566251902450477, 0.010098360343686035, 0.04034140102204777, 0.03120817356712876, 0.07845654287525723, 0.02577298275765873, 0.04560357470425867, 0.010380161956192986, 0.026643113082935734, 0.04117693864710389, 0.013407454149977816, 0.021671418874194066, 0.02094416394679537, 0.06752855910529053, 0.03729888283076786, 0.053112910264321876, 0.05455029422357198, 0.10415183665651469, 0.017714568999625983, 0.0892781017107829, 0.12670187985584622, 0.2678562995166548, 1.116223323249048, 10.718092226213026, 15.574349318781207, 36.24212772615495, 35.538513352794034, 42.93995526529128, 73.36800467583441, 84.55516922858455, 93.45114400309902, 93.94730814041631, 87.04679212262555, 89.56013710268083, 87.51857480695172, 79.80179002208095, 87.87273345455047, 83.23046715028825, 90.95989765659456, 91.70252000131916, 100.73471869191816, 110.73101243665143, 94.04091158220845, 76.48441406988329, 94.25628108362999, 88.25197958177137, 92.64151188635057, 108.06987254850327, 94.15865329004104, 110.17012134675058, 82.82568639324558, 80.00176814294632, 98.08061553585915, 84.51002274790119, 92.60647727597146, 65.1019900075851, 88.29196422330796, 65.9199022477673, 74.36414549427649, 75.96902247398131, 81.38003410831575, 98.96427846723988, 105.24635437996157, 102.79528094876198, 93.14182589131018, 91.0261151098436, 78.43391833766815, 57.71498241732198, 36.18610843535393, 9.819288945967152, 1.552621080510078, 0.06588853339874937, 0.10971705173893322, 0.06410513433717913, 0.03461173750580319, 0.049088520163129416, 0.11559778779384591, 0.06869655973728626, 0.12967342000094154, 0.03245642190919288, 0.03899500915600408, 0.12058242314284849, 0.05688207434310068, 0.034130021419015624, 0.0393365464744068, 0.016070371944337122, 0.08492398736698013, 0.05162264325565869, 0.007195648889342744, 0.03915338251259058, 0.054562785287177375, 0.05035688597408514, 0.04612272184702658, 0.03254484760785296, 0.012122861639175926, 0.03369893608314376, 0.07639501559277696, 0.0232971589561672, 0.022377060546029, 0.040799475635492036, 0.05034904123374051, 0.07436937186866999, 0.07466346536192202, 0.017878889113724712, 0.06617623005783366, 0.06690123268673498, 0.07721983181733279, 0.03287265663065257, 0.10676303968554544, 0.10783365522060664, 0.03097690119888754, 0.060398666894123446, 0.03527012112880907, 0.014975474294905942, 0.04802161632406135, 0.03144078658923748, 0.01808290981927947, 0.03616993353071232, 0.06971190202861063, 0.029370822763491063, 0.04800812168527515, 0.07029299504093586, 0.03206881206302393, 0.15869457725315325, 0.14149958057509315, 0.06671426126793509, 0.07075632501754069, 0.03135228428178497, 0.023951072456134904, 0.02137818531463704, 0.02252693032665599, 0.018478739788875948, 0.06865283143856833, 0.08186273066507233, 0.03230561367085865, 0.032806324907728744, 0.04464602991638165, 0.17580207136850204, 0.11468587503317865, 0.07797842740171379, 0.07454549548246207, 0.02936723555678562, 0.03790951236301372, 0.06161350997224931, 0.038565149560811064, 0.019170168614495667, 0.02127695828676224, 0.028509404773132938, 0.03359856707374415, 0.030013629903776512, 0.026587332305949063, 0.0234541897436664, 0.0455266747984194, 0.037718940330969716, 0.01959758438921023, 0.06716986141738392, 0.06065806426528481, 0.04969021711017817, 0.0772182230326918, 0.015056743774743331, 0.07221578380032893, 0.014290012336606461, 0.017408838630804134, 0.00986825434430953, 0.08766135741626063, 0.031697525635301586, 0.013587332552208776, 0.07567372082942918, 0.05088101268836087, 0.052526638497628515, 0.03166588237358919, 0.02378195854684999, 0.03926120938793306, 0.01673201335624101, 0.09104375051514757, 0.017487891243710633, 0.0597536591662755, 0.03278620743883714, 0.11476661303951857, 0.060753315807350224, 0.11031454669371729, 0.0736140015144502, 0.09880556184197627, 0.076827242399656, 0.04451774466302126, 0.10411788363971057, 0.012520816545152377, 0.03984412185907845, 0.07318971903934594, 0.04596812147346716, 0.03825731628063706, 0.08790085948402844, 0.02826156000786972, 0.2089963393706468, 0.022241346155022903, 0.1715194253671554, 0.05491066581359314, 0.9742976292487114, 5.099296464074043, 23.283106973094327, 33.56451388328306, 63.78860396723594, 73.41035058421474, 83.08228000517815, 106.86590102411087, 104.33972989359211, 108.84494073929326, 109.08896707719373, 98.40819620317029, 108.86676480693203, 106.93269114340507, 105.98447384372835, 112.19825344700968, 110.73421309071203, 125.37240443691131, 130.28151742873655, 136.46330618089246, 126.95359030077536, 119.53879664021154, 94.38829237414946, 117.98644019711404, 113.93163511829992, 115.20679766131987, 139.01275265601376, 122.21267638667938, 141.33004188537598, 115.84453582763673, 114.75060247605848, 137.27165960496473, 115.51071074701126, 123.90677944306405, 96.78052240802397, 115.73002615282613, 103.14041814496441, 97.87356930394327, 95.76141218985282, 97.0671143070344, 109.22488504840483, 117.64796318546419, 120.00773168379261, 118.05310480056272, 114.72866858205488, 103.03474949252222, 84.74226628580402, 57.12747020106162, 22.59909660585465, 5.056222465730483, 1.1653690280452853, 0.16475393436849117, 0.32103233159549777, 0.1080753866042341, 0.08971246590297069, 0.03771360835901672, 0.043483319121503064, 0.08279402545022388, 0.0360812128882014, 0.06355272365673896, 0.016773744080696377, 0.07312751269989437, 0.03651842309702789, 0.014826803441880452, 0.050758101541789315, 0.005005934029712432, 0.03712426074930737, 0.040243280480705926, 0.05922204777297955, 0.08096891290117657, 0.06092095116694128, 0.03262748934268471, 0.03331190080291802, 0.023531474608687625, 0.06739204223718374, 0.0356255131473224, 0.03975715172747451, 0.048860915440825686, 0.09839382788707172, 0.059694325656539975, 0.06285841434052394, 0.06074457474413419, 0.038171751920374176, 0.07025074529191179, 0.04845973817751773, 0.019397953367461602, 0.05520740614062356, 0.055227469983360464, 0.10665060096089879, 0.057909601262860724, 0.08234736554685139, 0.0034203336033369267, 0.01891159095741328, 0.0045330825378187, 0.04335084719763648, 0.02207765040258246, 0.09179506826424792, 0.035415421194967725, 0.04287640894612959, 0.012407002692681648, 0.023718681599524234, 0.1217889350147978, 0.08117741905152798, 0.07373825331488926, 0.007730915000842465, 0.05249959559390142, 0.0390051253470442, 0.07781081502476046, 0.0343914604144952, 0.08341128547345439, 0.07063870753852591, 0.07758114186506118, 0.02347199554224649, 0.13202089726203872, 0.09449321461180527, 0.14071257845047982, 0.3029069977421915, 0.19992406570142318, 0.12257285746595553, 0.1476349336125197, 0.1467990397565788, 0.14299070943267117, 0.1696022903366435, 0.13051110650262526, 0.11385938107606866, 0.12664489057515899, 0.08214044519850323, 0.14919822795256493, 0.1847097280645563, 0.2122339035474485, 0.05776074654873341, 0.1643084389187636, 0.18988739458783982, 0.1316830065221556, 0.2332392223780194, 0.18664158730497285, 0.17828202055346581, 0.17142452239509554, 0.19469649621075202, 0.14548725208207486, 0.09815641723933721, 0.14070085730523835, 0.13299275640278094, 0.19295384536587423, 0.17062821996308145, 0.16873319423006428, 0.14435759415068936, 0.15721421959179063, 0.15648936251959494, 0.08733653613636572, 0.1194320961592659, 0.14206513732431397, 0.16627414392367487, 0.23655339534724915, 0.2237321784900081, 0.1518340607083613, 0.21032208516713113, 0.21621334727012345, 0.10930668908141314, 0.19262445820195062, 0.07970885914419928, 0.2598538063466549, 0.11827465987974599, 0.13409629073594848, 0.1543681876313302, 0.07930291681400231, 0.1841023888799452, 0.12814213281437276, 0.24836352936202483, 0.1591033004825154, 0.25521045550704, 0.16699564553076224, 0.39068394250446753, 0.09005345163806792, 0.22853429339105086, 0.24585454544473082, 0.43970103645997666, 2.6136470946573445, 17.064214560293383, 32.092497387240016, 65.93009256547498, 82.9218158414287, 98.73335284571495, 123.80179328303184, 119.84799708089521, 120.16792912637035, 116.1977452616538, 110.81584545873828, 114.29399936429917, 109.62793996257167, 98.90349741904967, 109.1319013410999, 105.45046667898856, 118.89368441797073, 120.28137191649407, 132.76247147590885, 133.6718023976972, 122.61231099405597, 102.02375073586742, 118.16664172757058, 112.09971566354076, 116.22200904353973, 131.1912876559842, 116.95384487029045, 134.35482825002364, 107.5256750660558, 103.3014706642397, 125.8387742503997, 113.67510426429011, 118.46983309715026, 90.76560697247906, 117.84921999900573, 96.83494921653502, 102.78276074317195, 97.5127112480902, 101.52385250214608, 120.18060622676727, 129.98379384317707, 134.63728597087245, 128.9918891845211, 124.01473091494654, 113.63618650744039, 90.24538301652478, 57.45105789553735, 19.99064003267596, 3.5869996778426634, 0.5375809955500788, 0.18645896726558286, 0.3228765810208936, 0.1810289054147659, 0.13938130149918218, 0.2457738610645456, 0.2058054912354677, 0.3595651752285419, 0.12331391729774976, 0.14481540829423936, 0.2512137901278273, 0.23353985060126553, 0.1568048834920891, 0.13246761845244517, 0.16281110474899893, 0.20286320798820068, 0.2824736248341299, 0.10419551132907791, 0.14945662940942472, 0.19146380435314872, 0.20540845850783013, 0.11685650855783494, 0.13672481501294723, 0.10719735025157852, 0.10058147622452629, 0.2311623733370535, 0.16493494562324018, 0.13637970772481736, 0.148601905112305, 0.24550303366155396, 0.21687293365117044, 0.20781775906441674, 0.14761507661352236, 0.15636545545872182, 0.28471461587375213, 0.2036122121517697, 0.12412335813766527, 0.16892048740579238, 0.23697498885373916, 0.17219840909444517, 0.23415832870429565, 0.12618548296872648, 0.11898778814582095, 0.21794400117810697, 0.09390958584845067, 0.13188715363221784, 0.1244311799265204, 0.11523346702057509, 0.13597714384236645, 0.21361520604020168, 0.1244377836044277, 0.19472542369077284, 0.1850738649767253, 0.21828331684152927, 0.15507272805177397, 0.2563073861623003, 0.20776142095846517, 0.11578081385983575, 0.1156593352976826, 0.17445542669344336, 0.10721454126459938, 0.23241570850293483, 0.13857323195665114, 0.23225237855747824], [0.05361063375828728, 0.045406720751235564, 0.027840330393143722, 0.04331301777593551, 0.04413952322436437, 0.015091316365156204, 0.044226830434654994, 0.015821471892958208, 0.055585374770265435, 0.02617118951504029, 0.022750942096594843, 0.025345342902226314, 0.024204182160657742, 0.03661277448578227, 0.01873375322189062, 0.033064090511611396, 0.056501968328150055, 0.032720775869224346, 0.034647697672968915, 0.03794674040569413, 0.11172803254016947, 0.030549280495653232, 0.0325006673172597, 0.047200151734174266, 0.09512676932518521, 0.019261606953917973, 0.07383995148683749, 0.037012829430281155, 0.031114103715686552, 0.07601621575773725, 0.013562205825902283, 0.006925254326028329, 0.009933030908747066, 0.04247435451214833, 0.04969615429159134, 0.01860390323394489, 0.04216103604243648, 0.013618036398604033, 0.07103669021518962, 0.018576318323011362, 0.030839279248949983, 0.03216628526006976, 0.036755910353554834, 0.022055043147936947, 0.05713810092739521, 0.08755157701671125, 0.03254714970206542, 0.03124692420955868, 0.05657198493398967, 0.0014994454602034943, 0.022474290510158867, 0.08620734551861402, 0.05555676138629356, 0.013698445944746417, 0.019906764068911155, 0.048384657730498624, 0.15285173190697549, 0.07492476263113561, 0.10651519492028222, 0.10336922421570748, 1.611765887468092, 11.572088310795447, 37.37260580062866, 60.49879051023915, 78.05159707223216, 88.21008082359069, 87.76522913286763, 77.63459420973255, 81.56096519962435, 76.86064781681185, 78.53389170862015, 78.30489589321998, 75.99967187450778, 92.93597990466704, 71.54618924663913, 81.51931747313469, 79.17271244910457, 79.3921455260246, 55.32944394696144, 54.753141864653564, 35.20511973288752, 46.69067467412641, 105.15231947745048, 92.07426655677058, 111.23095773881482, 103.83494438663607, 100.04956691495835, 82.36122285166095, 69.43285542149698, 61.67423071399812, 51.872294333673295, 58.214813970750384, 59.42790108342325, 60.44330466178156, 61.990122718195764, 45.056827068328865, 38.24254435877646, 35.517952288350756, 41.45784847197994, 72.27593052771785, 67.63112252758395, 79.08529850744432, 84.8955289779171, 70.95693942039244, 84.19323644330426, 86.29894518083142, 87.32083243708458, 93.77673995110297, 97.5999604502032, 98.83704462359029, 97.11538299437493, 60.321173821726155, 41.43032912285098, 16.433261113782084, 0.5073293478738877, 0.10992898996318541, 0.18689382941492144, 0.1733923724461948, 0.037159880007346796, 0.049248383560728644, 0.06339772491745892, 0.07144510700938202, 0.01393071901533873, 0.0423781683428153, 0.013876441685903459, 0.04151585594480557, 0.06602662840798017, 0.041074911057348215, 0.07404511749383903, 0.10155231646832921, 0.04563977235868093, 0.03830461837952176, 0.056563366444841515, 0.09559946089622476, 0.03279936882937628, 0.051592547491553335, 0.047081220414369344, 0.06265638546357233, 0.01274865109383339, 0.03844228820995458, 0.04183208554862969, 0.13241016185812413, 0.04428795275969371, 0.08432228658949176, 0.039599092466936964, 0.09909115175926879, 0.04353263603162862, 0.0087767303545749, 0.04268990101052388, 0.03637562813838163, 0.06878046168675346, 0.021241319876524712, 0.03913319992622541, 0.06784076291707254, 0.028300546222336354, 0.05910675537081496, 0.05410389479009375, 0.061414909338758844, 0.060950928187418374, 0.06641131945915761, 0.026972004204928398, 0.07538523509978287, 0.03155918739315483, 0.04492161855582268, 0.020965097299326333, 0.12160090639466241, 0.08554958242682681, 0.025002928413150292, 0.09083449359863036, 0.05525160941385454, 0.03193085878005913, 0.02341652694608896, 0.027612737162158858, 0.05726458204369392, 0.013782932993865783, 0.022150499618522102, 0.02166490521161787, 0.0419738347972593, 0.09845157559480398, 0.01529464471874939, 0.03225628526941423, 0.020460674366463098, 0.04644368204378313, 0.06159331589456528, 0.031381497129557595, 0.03795623989595521, 0.032354398149876826, 0.011925250216717682, 0.057871220257854274, 0.041786503317135, 0.01988683812200062, 0.021362695016808087, 0.08524118607202846, 0.0349244775791322, 0.08446965126260635, 0.017860974147615415, 0.08186458459784908, 0.009732175103929496, 0.09511761457449007, 0.047888110181496996, 0.10133671634379895, 0.029856761909961223, 0.04470622144459237, 0.05858509929009503, 0.04213952812396231, 0.06067614777073745, 0.06407848596873303, 0.04129913733190587, 0.022245444725417805, 0.03632922236236834, 0.03579269268459851, 0.032024627941991055, 0.03582220239144179, 0.02546397736296058, 0.00576777016601315, 0.048535167194542386, 0.06777128640321955, 0.035869021854934194, 0.030184695422048533, 0.03775872710731722, 0.0571631022068041, 0.0363274795123406, 0.025449647688336914, 0.08330183449171244, 0.043594022657001213, 0.009298262903617035, 0.05036704046952148, 0.08937049957533037, 0.06170241830630168, 0.0508019485841355, 0.027991678723464572, 0.03705073546077456, 0.09284497644271582, 0.1487117927641638, 0.13072744973244207, 0.20548096106898403, 5.298003737003573, 25.247690793006655, 60.19274365517401, 86.23857990387948, 97.27577655546128, 111.45807866127261, 107.37788800270327, 96.54400348663331, 100.57539986025904, 92.1735260563512, 101.56812821665119, 104.2711982419414, 103.48154667885073, 127.20781480112385, 99.70526126123245, 122.05331833131852, 112.4058174317883, 111.15573452365015, 66.67351507371473, 51.18333393527616, 54.65946782019831, 52.436319397341826, 117.96834238113897, 122.59036141057169, 123.05368746480634, 108.9115974980016, 112.01100733972366, 97.19099844655683, 94.18333284316525, 85.2643886689217, 72.14376234239148, 88.75132083892824, 79.64901370386924, 87.9889532827562, 79.25297983231084, 68.37381547497165, 53.72403744728335, 62.50179198480422, 69.69892547976586, 105.76635083844586, 107.54165480213781, 116.06508285768571, 112.05107042866369, 103.14667824775943, 108.99173152062201, 102.5099834319084, 105.31636868753742, 107.75887566228067, 112.33246910956599, 115.31181520031346, 115.88619139886673, 84.6197549758419, 62.572241675469186, 33.5701620963312, 6.085108210963588, 1.7154671035466658, 0.2750257486777921, 0.2630526217962465, 0.06454448576175398, 0.2455060673697341, 0.05592740621537932, 0.10252912453706227, 0.026283852320404786, 0.002742383376537492, 0.02518491643000274, 0.006373773963611213, 0.08006657623956281, 0.005219547592494036, 0.06882608222264437, 0.07959514871359834, 0.07484233157048303, 0.11580772652861573, 0.04566599554832905, 0.14067634249166136, 0.012551315463027887, 0.07996503128519944, 0.03558698658561034, 0.08753617098855396, 0.020927700717302582, 0.046809638414772294, 0.03588974453328598, 0.034350819450112126, 0.032701822853977644, 0.01588112715962193, 0.025810298900450432, 0.041599305902397445, 0.11909242809539843, 0.007387005203899237, 0.030647747691780813, 0.0435030841899495, 0.09137717496243217, 0.04346147795478183, 0.09308123795856392, 0.030740476889355533, 0.06503622993947038, 0.10024152470812683, 0.051479951718882214, 0.05660807916654214, 0.021203749009498188, 0.10849270534010665, 0.032242158608090495, 0.06205590659632318, 0.0657217177532373, 0.024933066940115347, 0.03130135667179862, 0.054305345270662546, 0.052893276686870286, 0.11873731569897746, 0.0399889737638014, 0.054723935712489395, 0.07841347341215418, 0.058017891621397394, 0.0028690119647616225, 0.03770695488539435, 0.07011261197828478, 0.03999683765634414, 0.08266244984922871, 0.26265143687205933, 0.16990831181887658, 0.07773499530289443, 0.2790953303056379, 0.15006508708240526, 0.218613684597996, 0.10578502885877125, 0.2638147873503547, 0.08809608166977283, 0.09458399603083249, 0.10671816991582032, 0.14471980052128916, 0.0860950906550692, 0.0763613383676256, 0.13990164373911199, 0.27461751574470156, 0.1238396221531495, 0.16424505280390864, 0.1951411336420044, 0.3556025394749257, 0.08145126484094128, 0.14508010699383675, 0.14222649076292593, 0.22265113649829743, 0.18690233299088094, 0.22460787827449463, 0.21614015522983768, 0.09518272438717466, 0.1370526393575053, 0.24300949407681344, 0.12294368232570349, 0.1316976847667848, 0.12379557209750339, 0.20981093598229272, 0.11508881429871244, 0.10929787907028392, 0.09851876916664262, 0.15315501079443963, 0.1607096029986297, 0.14071032615198245, 0.21422747883104512, 0.13648358924734977, 0.19047015767183997, 0.19685951482144096, 0.15347065434100168, 0.17818118806087202, 0.13394676569488742, 0.1984222575781807, 0.13525665347133914, 0.1394396620772539, 0.16688784163805748, 0.22041627416206946, 0.1183178672386754, 0.2907512354994974, 0.14578627152068002, 0.227920871468321, 0.21196174315146862, 0.25579795301441227, 0.11218634464087025, 2.9687240671726967, 20.890718083227835, 59.25237894058228, 89.41655482015302, 109.66142915910291, 124.476299747344, 122.59566445504467, 108.3168092850716, 105.86791669168781, 97.8111094813193, 100.7420692136211, 103.89927125746205, 100.95854482343121, 116.70726899177798, 94.15990060375583, 106.48315614269626, 103.2501111492034, 99.20093859395674, 70.9989558496783, 68.0540717032648, 46.55307792848157, 62.2251001481087, 121.7345629968951, 109.23218850166568, 125.77237636812272, 121.68671008079284, 114.06445441707488, 101.75972031008814, 86.54654872032904, 81.13823567667316, 70.06653785705566, 76.38215003475067, 76.13793542308193, 78.52104986867597, 82.07168917502128, 61.045494387226725, 54.63733388531593, 56.252738506563254, 59.0372722379623, 98.7722941367857, 98.14069840215869, 110.51590965640162, 117.04905648385326, 98.33122361090876, 107.0975483617475, 106.47837085108604, 109.39594745635988, 113.44795980761128, 120.07805193624189, 127.78234004974367, 125.32790906967656, 89.2964675349574, 64.09514111857261, 29.211365484422256, 4.007206871624916, 0.8209491965751495, 0.26229866870468665, 0.3142676220065163, 0.1366657343122267, 0.29673254357710965, 0.17235003321641879, 0.21951658050379447, 0.13028367031966487, 0.13320248063293197, 0.10772139269618258, 0.11173989924211657, 0.28126749600614276, 0.0907720038066468, 0.19008121483268278, 0.18842526981907506, 0.18439992210797726, 0.17922003392971333, 0.18061843550493642, 0.31633976726762714, 0.12624840176994764, 0.2932142388195761, 0.16665905714035037, 0.2571017427309867, 0.09754147846251728, 0.09224218782037498, 0.1401318991256337, 0.26876166222556946, 0.1604470340234618, 0.15090248247067775, 0.1636774889043262, 0.2466959857772435, 0.2820861069185119, 0.13814710320964937, 0.18503862493220838, 0.09947799551751345, 0.17602808262792327, 0.09730409079742047, 0.12434587603615177, 0.2235678985955254, 0.12744422671535324, 0.21483184559450996, 0.12663238802023474, 0.1491226763614724, 0.1703618511918091, 0.23820734853225373, 0.12043547215721301, 0.13897836989452764, 0.1514367368673125, 0.1578413851318821, 0.14079451921486086, 0.22624108579850968, 0.15007250281351228, 0.2584848378694827, 0.08404106337336764, 0.20528913265274418, 0.15795985296849283, 0.09839830950142876, 0.07600635620615176, 0.15002955592447711, 0.1314863517519928, 0.1375656424751205], [0.07270078640431166, 0.035792708006357, 0.06766057137640254, 0.03613123459921729, 0.04732964740645501, 0.08061773053580716, 0.04027636398771598, 0.03840233289426373, 0.07048794909590675, 0.008345492758728083, 0.077258994232022, 0.023561765725213676, 0.04769138263298139, 0.0272769742314854, 0.02187008270993829, 0.008737786274944103, 0.007017348149430848, 0.05323284898974723, 0.05323063116520644, 0.036149938635888605, 0.020097115850676934, 0.06445162824445194, 0.027627227715246623, 0.005896471979682364, 0.054924616274694284, 0.08501126010331415, 0.019735284863160025, 0.008678781225406116, 0.019303119343314922, 0.03646120398996338, 0.041235743556171656, 0.017879272157686855, 0.003579988241976788, 0.04343602851393723, 0.08329668638086127, 0.027938996772131616, 0.03679588099100417, 0.05063932343956925, 0.0071977259452274496, 0.06569072949670016, 0.05239715048622701, 0.013069493504571579, 0.02406061536842777, 0.017862805097754446, 0.018678479978153785, 0.039294369503735535, 0.05479672938705452, 0.05993295821451372, 0.026033898898129983, 0.06470272888339336, 0.08756128335071188, 0.04051839031519429, 0.07300809491425753, 0.025452116406672907, 0.12123709890030085, 0.07923287339508533, 0.3408523745113804, 0.4842815926719097, 6.034727817581547, 17.330104189534342, 54.436284957393525, 70.08824425358927, 83.29504505280526, 85.75561061982187, 83.0714464187622, 71.03072704807406, 66.32305914355864, 73.63253716499575, 66.57135302020659, 79.46323456302767, 65.65815464142831, 53.04669903170679, 44.35710368617889, 48.17600565571939, 41.50363822137156, 34.729187180919034, 34.96477650057885, 31.572495045200473, 50.427395143816554, 68.26461668937438, 60.37711466512373, 61.24234245669458, 38.351719610152706, 31.289433279345115, 48.098040703804266, 78.87105864863243, 68.89971902293544, 58.97429466247559, 51.772332729831824, 41.217430714638006, 46.18301799220424, 36.26424989392681, 47.71209516832906, 35.8735151444712, 39.34251423804991, 34.3713846514302, 56.08889325972527, 26.621183233876383, 35.33331455722932, 25.47012056073835, 20.900590688951556, 37.441415940561605, 40.06363807186004, 48.986222205623505, 55.59774583385837, 70.96277590720885, 69.23340289823471, 64.10091876983643, 70.14972348367014, 67.57059251108478, 75.7875265613679, 84.00360553495346, 94.62936124494, 90.36547814646076, 67.22134467094176, 45.81568802556684, 21.329448915296986, 2.8439456272509793, 0.12323770687104234, 0.30216426017784304, 0.008605195607449259, 0.021361396497776432, 0.04866255995547099, 0.011396836282895699, 0.054742107318053325, 0.06903503270399186, 0.012896686093881728, 0.11160610964702022, 0.005619696861568598, 0.11178371181050617, 0.015331657299201096, 0.03398288657227832, 0.05357256684932978, 0.053794349303408984, 0.023091533296411077, 0.09140823982776174, 0.047188147136400786, 0.03060603037386412, 0.04237130036457412, 0.045060598396606026, 0.0997723418197805, 0.030888912170344306, 0.032243434144484426, 0.025958893144683495, 0.0769568338329273, 0.04130448845605697, 0.03625403083260021, 0.0651541768362926, 0.04815347537758851, 0.037394869817240585, 0.1124668553952248, 0.08357129825819885, 0.05805518095111174, 0.07213267858230299, 0.09234659794357516, 0.09240937884896995, 0.08034827443019998, 0.02192973989182182, 0.013391236068620799, 0.11773852856769679, 0.06148733529112032, 0.013349209442704678, 0.11238915109706503, 0.05673997269402589, 0.010696939312882963, 0.0060075925542942945, 0.05084734312408874, 0.011301395134069027, 0.08514802211955672, 0.04384985005843543, 0.06470551744343774, 0.07672947425875934, 0.01016014437716935, 0.03340743579751542, 0.04304546156838056, 0.003753259854068259, 0.061699825098677996, 0.038447459303443475, 0.05562534540771477, 0.021802421824465838, 0.04131275837519958, 0.020378842769611268, 0.010757133713923396, 0.046910903747043306, 0.03267594440389545, 0.022543638704284545, 0.03987602176024549, 0.02129291206778538, 0.049080721388060244, 0.05131167284543476, 0.02277461612867492, 0.02649186242882523, 0.01961518334405076, 0.052238865229751796, 0.05670923341606414, 0.027502106405013514, 0.019899693077370044, 0.0724674130399381, 0.034111750222021536, 0.052090041159141454, 0.002936392988739235, 0.04537006344405874, 0.020706165326578964, 0.046610758159189455, 0.03763156800320552, 0.06087231224462871, 0.0119425063472121, 0.019716873855119752, 0.01081383666924892, 0.06375080718088054, 0.04149167820991528, 0.06895080899759647, 0.06370648133358167, 0.02997464368930988, 0.01846880554371784, 0.08532289701003222, 0.08582462331340199, 0.06041714876529671, 0.012493186626553297, 0.047086230629394134, 0.04517040177879315, 0.1104261197390095, 0.09167932003976838, 0.030576103149102103, 0.019920768156167, 0.06789179203370888, 0.03729571122676134, 0.0363661363089998, 0.1179622645459829, 0.05427787335769785, 0.06840376859350551, 0.07826849893336335, 0.16810540049787492, 2.268318928057148, 15.463009899662389, 39.53783650552073, 79.19382264537197, 87.79762791049096, 96.31925952049994, 93.24680420660204, 102.28320767802578, 84.42612324991535, 90.97921925206339, 102.05858922773793, 102.09276876141949, 122.23808550065564, 105.63357860811296, 82.70552850538685, 75.14896469731485, 80.38437966377505, 65.7248035553963, 51.514868351721, 51.009572936642556, 43.59008812135266, 48.22860463973015, 63.257593493307795, 43.42028479422293, 60.06778870859454, 65.27351917759066, 47.999969682385846, 72.63414490607478, 101.05511357707363, 91.98876673175444, 75.80920157894012, 61.34999190607379, 45.86502359759423, 44.51692850359025, 28.28862790138491, 42.8423745401444, 31.85293470659564, 44.387258868063654, 30.93771826836371, 51.75371323862384, 33.76986172891433, 31.273894809907485, 38.33112716674805, 28.863455172507997, 52.344775199890144, 59.82007142036193, 72.63085011513003, 90.81987688618322, 112.5316470669162, 98.56116079515027, 106.06149350443195, 101.85490054468956, 96.53216577345326, 93.01285051530408, 99.96511044040804, 111.58092729506954, 108.02813068512948, 94.13393451321511, 71.27207048477666, 41.13394698789043, 7.27251801759966, 0.15040325361394113, 0.49213580186328587, 0.04300680477172137, 0.09779645550635555, 0.032008134068981293, 0.06527465948414418, 0.019167644354785164, 0.014249738136817132, 0.05401350024546828, 0.10734909694762, 0.04780113238901381, 0.06046242456162169, 0.018690689504447005, 0.033254160756065, 0.033298279759624315, 0.03876652726302705, 0.051244237955899975, 0.028590320894915252, 0.03398051553015267, 0.06501414362461337, 0.0443646228391557, 0.011033608142526881, 0.020426966497794758, 0.05690871505066753, 0.09400102610309279, 0.12981885413248695, 0.03326970468004865, 0.0996268540620804, 0.03908074588604993, 0.017863071313308134, 0.03342735408354671, 0.08596670964071829, 0.11054540728969921, 0.0889034387505343, 0.11678565308571824, 0.1509110626554297, 0.04420958579547944, 0.04947739405437343, 0.050211122424732295, 0.030080063133350307, 0.020372286972199238, 0.07455213746476559, 0.027735782374117165, 0.024178642704482042, 0.04218607562624159, 0.051027940691358624, 0.03513089997032958, 0.016878539163078514, 0.09513418505629224, 0.05934726484420319, 0.03076977975245926, 0.01592496845630869, 0.10079978063942925, 0.04856342817806909, 0.045950501451208714, 0.029147950549339576, 0.054777274584217425, 0.03624521316059175, 0.14455009672430255, 0.15141853461823157, 0.11283673796682589, 0.04967598319654504, 0.16882285716072207, 0.215842759897632, 0.10512387199747948, 0.09695260199688135, 0.1476970173779034, 0.11405660275129542, 0.23161845612189463, 0.13735150557852563, 0.13201800144968495, 0.1627091384462772, 0.1795767244672583, 0.06629645223579099, 0.09097338533930241, 0.1680082299055592, 0.13880822176654495, 0.10207587627754097, 0.17086976748560706, 0.15066289613323827, 0.10935095364167806, 0.14876702770350442, 0.10992303746001375, 0.22899857331668177, 0.10569908145454623, 0.12850967115692555, 0.12765277117010088, 0.2567565894775814, 0.11337885242556373, 0.0897067738696933, 0.12367626156417594, 0.10572190321381054, 0.20965895945987395, 0.1706729594978594, 0.21217531314299953, 0.1247616166309003, 0.0644406119001008, 0.14109053558880283, 0.2088175957361537, 0.13014281739390668, 0.10218436964937758, 0.08885093108420411, 0.1298630727274764, 0.1226927119217092, 0.16827104402886284, 0.1525891629318076, 0.1079481700435281, 0.2882552597551577, 0.2384463986081462, 0.12666364440754538, 0.24114284424051163, 0.12797638969195466, 0.27737390009626267, 0.2223510292148398, 0.5327179919808142, 1.1354016296325193, 11.299653226329434, 35.832887234226355, 82.9642637314335, 99.17888702884798, 111.60143344633042, 108.43753983897548, 104.99664060531124, 87.59596317045151, 88.67830984054073, 97.33578881909771, 93.66798047096499, 106.30253099626111, 91.535780045294, 73.34385856505364, 59.72038046006234, 63.80685475564773, 57.36212207425026, 43.354404664808705, 47.279320455366566, 43.746084705475845, 64.34835756978681, 86.82514682892831, 82.38561214939241, 83.89174738237935, 54.71255710048061, 42.51055379067698, 61.123667224760986, 93.18707435361802, 83.83221364790394, 77.59129124303018, 66.98775183769965, 55.006891758211204, 63.77848425219136, 48.846056307515795, 64.94966083957304, 51.678701831448464, 57.02977964954992, 49.28336528039748, 79.50765932759931, 39.69354283425116, 51.605659454099595, 40.49029780972389, 32.72594840295854, 52.32620277712422, 58.27692078005884, 68.73525404161023, 78.48723903779062, 97.35572230431342, 93.47896929710143, 92.19518538444274, 93.89429338516729, 91.06202048640098, 94.74472599644815, 106.51171099755072, 121.66785916974469, 122.29329678320117, 98.9694324616463, 73.9709278845018, 36.53479929893248, 5.839321709448292, 0.1910296163611835, 0.7047788270058171, 0.1721498237982873, 0.1003012795662207, 0.17058124345156456, 0.13739770068035972, 0.1013574849874262, 0.16449982300400734, 0.07170975208282471, 0.1916271342986053, 0.1677769786047359, 0.3516599445814087, 0.1186983448062693, 0.13448685768150515, 0.10954544804389439, 0.14446622541835233, 0.115343232098366, 0.21328623256375714, 0.2722069128386436, 0.14194380431886644, 0.1753295023715304, 0.1320062496609265, 0.128125638941363, 0.1452131305010088, 0.20338797821633278, 0.23944314028466904, 0.18607454434517892, 0.16683496624952363, 0.12584414483318407, 0.13537924286098252, 0.1634754408751765, 0.14333391682274882, 0.18123829256623022, 0.1884791104783935, 0.21763960380227337, 0.16656410820301504, 0.15614820824515435, 0.2898965878111701, 0.1818212548330907, 0.08825111488300948, 0.07568962481473723, 0.17138811789693373, 0.11791995350992489, 0.13882248632369504, 0.2135609516934041, 0.1859936761038919, 0.09456777028859624, 0.11231008316240004, 0.1717766317268533, 0.10094753601738524, 0.1694492872564062, 0.11381209812938206, 0.1964036618629771, 0.17356544703004823, 0.07660079447011794, 0.12567447934059367, 0.14097340074518036, 0.08368106333598976], [0.05251903124454041, 0.1057507464241597, 0.03354877518910555, 0.03066144917430657, 0.0679565494459483, 0.045094785070227045, 0.04368485387174353, 0.06162605083156979, 0.10778420424509434, 0.004952040701849206, 0.03474341269822852, 0.024179713312356223, 0.0406718262351088, 0.02595942366057106, 0.07569852675641738, 0.06289483799088387, 0.055346608146904945, 0.06018987729124004, 0.04319350422930814, 0.047313019468058506, 0.043541580108144594, 0.0485815231748406, 0.06886463176699416, 0.032129735205202334, 0.04668363993386588, 0.06062449812288247, 0.053177334428314245, 0.07620554672734392, 0.12301783963677385, 0.06192378707290177, 0.06127574563687367, 0.040571365295158285, 0.08182350696334917, 0.02492580634181298, 0.08138283786754455, 0.020520155348124045, 0.025990300834359183, 0.06784417966921484, 0.09372065324456462, 0.013993278712845378, 0.07037390158661912, 0.04893651682763331, 0.07096768867584967, 0.04720419667841447, 0.15134367250627087, 0.0521150884038258, 0.03120622770380109, 0.016207384854374875, 0.09206414132589295, 0.018923051632760514, 0.08475256753304312, 0.026397997505902767, 0.04975684760739246, 0.07124855949152863, 0.053146311697820504, 2.376063249764904, 19.819314825919367, 45.864494077620975, 70.25727487379505, 86.88227222811791, 81.33978274560745, 79.5270436809909, 73.57845552505987, 74.26456436034172, 61.894150164819536, 66.02222119608234, 55.23218877853886, 60.594868967610026, 54.510711931413226, 38.26636491283294, 46.591740731270086, 35.021599877265196, 34.46856921718967, 31.081681020798225, 42.26560569578602, 51.41979009874406, 55.675946127983835, 79.12121172874205, 76.97201959548458, 35.322677089322, 73.47731328779652, 32.71716817732781, 25.393610808157153, 51.99613532712383, 28.98246184472115, 29.337728561893588, 38.486303975505216, 39.017455654759566, 62.38424247311008, 53.74812080014137, 60.28681385901667, 97.03094220930531, 80.51231953405565, 72.90093668045537, 54.940999861686464, 79.21897288291686, 57.22506661568919, 60.598454013947524, 79.37629915052845, 60.70703698742775, 80.57525788584064, 52.99373918964017, 17.7057142796055, 70.7031463807629, 33.62090972162063, 29.541297612651704, 57.58441848139609, 36.26737210058397, 52.56793845084406, 61.342194234171224, 66.64158698051207, 66.82214152428412, 62.150304471292806, 66.74261939141059, 89.00261140638783, 87.4860897371846, 85.07488327641641, 47.81834825392693, 23.16563198643346, 6.03641051438547, 0.09588462180427967, 0.2650906301794514, 0.06049173508560466, 0.029364242068221493, 0.08018039392247316, 0.023955299346257123, 0.004638716007672972, 0.08737998098255166, 0.06006131624622692, 0.07777018938213587, 0.060698092359328465, 0.038270684514915755, 0.07421145816483805, 0.018540582236563487, 0.04702397449422748, 0.016594422049820423, 0.014322811433474624, 0.07793170369921193, 0.10634647171583869, 0.018999252483368884, 0.11788921806240275, 0.009934355283246167, 0.023107046576877757, 0.08999791026355759, 0.11522503239252876, 0.059831240890367385, 0.05363005025672817, 0.1505447960188312, 0.08619345634454682, 0.015419234555485028, 0.07613623875283426, 0.14367064310898706, 0.009778373078593324, 0.051814950476851196, 0.05309081245814601, 0.006012044961549222, 0.08314021292232698, 0.092398400809015, 0.030782734299258842, 0.06263156804526526, 0.09957803893954524, 0.05760244214006009, 0.03974366474956755, 0.05602220959600903, 0.03521069951896225, 0.02528196061781097, 0.039010913141312144, 0.05657718284055591, 0.006088977426125278, 0.04066234589704583, 0.03910247980046176, 0.055441124244563045, 0.022786800757110603, 0.03170882351696491, 0.035645450585551804, 0.015169283048430038, 0.04364143966907456, 0.025139784275163567, 0.035612248334913485, 0.03417017974800641, 0.02368719538583631, 0.029007499819741617, 0.018136049508147182, 0.013297721630923692, 0.022432144183004578, 0.051512437677311326, 0.017335970262666384, 0.017784053174358223, 0.028566227429696632, 0.04123611893925456, 0.07037505837938479, 0.037325377981629104, 0.04003591580136169, 0.06298047512949956, 0.025168242526330778, 0.0560627586298412, 0.0025948027623892435, 0.10031545985369913, 0.1335670159108216, 0.07215325570394916, 0.053269548431759885, 0.017184001401126865, 0.05843524100078691, 0.027458987146195386, 0.028622347200589798, 0.02479975614997168, 0.029873100650166313, 0.008965112332765375, 0.025824481103148673, 0.008831905922101391, 0.024023377749648307, 0.010239976484538808, 0.04653924385145788, 0.060055601230311784, 0.03766335682162354, 0.020104192587877476, 0.006713610088017079, 0.027998621395278363, 0.05062998482777227, 0.0421564931410455, 0.06456706237288252, 0.03724276689031432, 0.04439051661099638, 0.06993258897695812, 0.08172288131449493, 0.033459430184936335, 0.07610669074159476, 0.0645837937331488, 0.055012103515647115, 0.03614531529526557, 0.20118950505650815, 7.87888212550071, 40.34295397420084, 70.30397461306664, 90.3627089531191, 102.6195744545229, 89.57133154715262, 93.68364641743322, 98.25060321438698, 100.15343912186162, 93.01143846204205, 115.50708647697203, 92.03054781882994, 82.00766824906873, 79.13764645976406, 55.719253017056374, 58.444888437947924, 37.46127882311421, 39.23217012036232, 24.250473283952285, 29.172661496746926, 27.446926486107614, 23.216069744479274, 43.498543923900975, 56.77972855106477, 49.56781948766401, 64.58012257852863, 42.01938675295922, 19.162241335838072, 26.474219868260047, 14.37890894951359, 19.852588292091124, 17.733412096577307, 23.395253419876102, 33.788979361134196, 33.45049450474401, 46.439148764456476, 54.18254290857623, 56.13379655345794, 49.412101391823064, 36.29797835503855, 45.87279381290559, 42.45715856552124, 38.54563374673167, 51.45230654747256, 38.988414426003736, 52.43012989720991, 40.061272882646136, 19.431561077794722, 58.19916763613301, 33.25477215551561, 34.035382655359086, 59.87018754405361, 43.33694227280156, 74.78497659006428, 91.07161460384246, 97.53789286459647, 104.25489687150525, 89.59583851598924, 87.25925122537922, 106.76952054423671, 98.81661691973287, 98.3829753629623, 70.44651354512861, 46.750337846817516, 16.10957634064459, 0.6736320209118628, 0.3110772641676088, 0.052046569499878154, 0.06254646333775694, 0.030401902415999965, 0.02396532169152652, 0.015525451688576612, 0.06137493487086989, 0.046085658513249896, 0.061011242289696975, 0.010059276453009056, 0.06243462216169123, 0.014961041198412498, 0.06303884336845049, 0.07947687239896867, 0.062205106050016425, 0.06964748169505788, 0.03448134168021141, 0.07808653006870901, 0.0846485787582013, 0.02818964350397789, 0.06199687952175737, 0.03919962741013977, 0.06147883937604005, 0.10219800601442976, 0.00902376785468791, 0.030968093102978125, 0.14626628689227567, 0.1814717195567585, 0.01478764198480114, 0.02228719077163166, 0.07190282156150188, 0.011805233924889998, 0.016631715209974397, 0.04628586410094173, 0.07928445409502714, 0.02530066273926247, 0.05178578167913422, 0.026844875744333672, 0.05480273551638088, 0.11889114615417297, 0.05017546103185704, 0.024746867354899168, 0.04438896145251009, 0.04968730980650552, 0.05972410349415676, 0.016882551548581932, 0.047340491381023204, 0.04199306360415874, 0.050281326722113356, 0.006195281222913295, 0.029812035781721917, 0.04806656653301851, 0.02238560434160454, 0.07919114458584979, 0.06737260658654474, 0.11331932739384713, 0.18210410981649355, 0.12911814415166456, 0.13427426828251732, 0.14150759385478112, 0.07931479117682866, 0.1317923272689504, 0.152431670576334, 0.24668020436600333, 0.13643206217356268, 0.16218547138475603, 0.06751686094268676, 0.1486024260520935, 0.14900578666598568, 0.11239091309929088, 0.16810832695374567, 0.14263985648510918, 0.09892389178276063, 0.11928647816661866, 0.14404621005298632, 0.11193149017109988, 0.2190229440889051, 0.2156359927668687, 0.17000490018436987, 0.12560014582930074, 0.1442726809651621, 0.1439990496803676, 0.16394831630731785, 0.21494821435020817, 0.08545441132399344, 0.20385854006294282, 0.0936203187091216, 0.15675988348741687, 0.13184445189131846, 0.13758442695102385, 0.06708633485099963, 0.1280031184996328, 0.16834345465946585, 0.1423381097734936, 0.1084347278059971, 0.11802702961910157, 0.20603988349678057, 0.21109496063042074, 0.14224630179664782, 0.20696839738276698, 0.12745919607339368, 0.1604368144105519, 0.11765728494332683, 0.18222620890986535, 0.17720833300582825, 0.2131720394977639, 0.1400316182163454, 0.12379341939043616, 0.24758803387803419, 0.19732017881206929, 4.635655639633056, 34.69725908771638, 70.40754087509649, 100.50584054762318, 117.27948788673648, 103.51055652864518, 100.81934775075605, 94.0267361364057, 95.51660922265823, 84.33723449707031, 92.15629900655439, 77.43922879618984, 76.68423529594176, 68.82400158912905, 47.677103704021825, 57.04006018177156, 48.64610172087147, 47.02898694622902, 44.472276241548606, 54.682456831778254, 70.16335764238912, 75.26774975561327, 102.16006094409575, 94.07226700936594, 44.77528325973019, 90.7609550414547, 44.560247159773304, 34.14033351405975, 68.47571865204843, 39.14448553516019, 39.803479025440836, 49.40537060460737, 51.38793653057468, 82.03607405385664, 74.11286277155723, 80.90886331373646, 128.87875233927082, 106.69698807501025, 106.44375201194518, 72.30074344142791, 107.31203925225043, 76.05139224759995, 81.50757389683878, 107.04208604751095, 81.62231106911936, 104.90407266924458, 81.60954767657866, 33.61621464452436, 97.59872098122874, 46.04700588410901, 40.53855865232406, 74.10314313827023, 47.91271655790268, 68.10798860365345, 81.38290528328189, 90.0255733920682, 91.24547758410054, 81.66378621132144, 85.89168548583986, 105.90670108795167, 111.48224046153408, 112.29737958600445, 76.5120981585595, 45.589139769154215, 12.905833413524013, 0.29003494329029517, 0.42643364999563466, 0.19365493839065875, 0.16001836186455143, 0.17966054980793308, 0.12040675152093173, 0.19628481098240425, 0.1466080233935387, 0.16281274417715688, 0.2375528796185409, 0.11119896455878213, 0.2180151094592387, 0.15771190095092022, 0.22384035010491649, 0.09599722906826966, 0.21071124251090714, 0.15097723733032906, 0.08514570087314614, 0.19598016845843486, 0.1810674549591157, 0.1893325937130759, 0.10252055967406881, 0.1458433297492804, 0.21069392892381839, 0.1475108886558202, 0.1534728606742236, 0.19680938202767603, 0.22545702545152557, 0.3505346227076746, 0.09634818926814104, 0.06426206361802836, 0.17693225023967607, 0.10983646952457006, 0.1050168495144575, 0.1276247323520722, 0.1392238244654671, 0.14693227776836965, 0.12531572802653237, 0.13871888059281534, 0.11637371994795338, 0.1752928680469913, 0.22152670328655552, 0.14381154200002072, 0.21237334687142603, 0.09023014981780322, 0.17194192285739607, 0.15212033244390644, 0.13720646981270085, 0.10236683647118269, 0.08486525906670479, 0.13432619372202506, 0.15966134957007824, 0.1942149486633078, 0.12338091168672809, 0.187693364737976, 0.10446302157135741], [0.03210315578466943, 0.015752885956317186, 0.029829726667113365, 0.07467619008234433, 0.04054655936817008, 0.08072305996451648, 0.021703788004214727, 0.0069850326455648875, 0.059251783475760496, 0.014151330312503683, 0.020316151879547585, 0.03286103890728086, 0.10371282231062652, 0.026075901583798473, 0.05184786544451791, 0.026169733947984157, 0.03963652352291731, 0.09187354631121121, 0.0721780309874204, 0.02154794082255854, 0.022810547567543485, 0.02330486005502603, 0.01644371340291635, 0.0124989859121401, 0.01337498734374681, 0.053269165387797746, 0.04315864722875338, 0.02048054285677931, 0.06934520638277454, 0.09249992278074065, 0.017844643068289565, 0.036484481571542646, 0.03614795063772509, 0.06978867936038202, 0.028753087765747504, 0.08014157624734987, 0.04176173186410339, 0.086972629050574, 0.09331054339605956, 0.03540015689307644, 0.07468955831662302, 0.04821475092021208, 0.02073455079939337, 0.06482701898822862, 0.028596139332700162, 0.0347674640286113, 0.0918161663256826, 0.05312733186949646, 0.09650628683307479, 0.0979978983260451, 0.09958301085017382, 0.14124758361328033, 0.06490456240792429, 5.204449815134849, 33.09471199589391, 68.08945932695943, 82.1828648351854, 89.60216137670702, 80.51655569384175, 76.01154881138956, 74.32834209934359, 65.65511480454477, 51.658482013210175, 49.870214616098714, 39.11600520533901, 24.88749169534253, 21.692495653706214, 33.76275831653226, 33.359911287984545, 41.872458688674435, 54.1856219691615, 63.20370012714017, 75.02248394873835, 81.73977821103989, 74.10229590631302, 80.84394024264428, 82.86487871600737, 72.0560424558578, 54.845274417631096, 36.482102255667414, 40.925374953977524, 43.844249863778394, 92.69397750977548, 85.34552681830623, 101.98830035425003, 89.37092981030865, 97.62512637722878, 78.07956357156077, 77.81867104191934, 69.07642179919829, 64.58956764590356, 58.16231304599393, 63.47681868460871, 65.38718162044403, 75.90961425535141, 70.2700068873744, 70.54739690596058, 71.01858339002057, 68.47579709945187, 112.4538900006202, 102.31280588334607, 67.22256060569518, 49.661124829323064, 58.91066205117011, 111.67446797893895, 72.3353858147898, 59.03848425034554, 65.88834285736084, 38.95713352387951, 34.02991879370905, 31.462158772253225, 41.84302914527155, 61.20906506815265, 61.943587718471406, 47.180002120233354, 70.75823999220326, 73.23413418185326, 84.69200503441596, 76.86113419071322, 59.1384340870765, 22.605025268370106, 2.064616516713173, 0.06442669208251661, 0.168276728401261, 0.044347447147893335, 0.034327878947219545, 0.10685297074697672, 0.07745612397669785, 0.025257985896220612, 0.058922921082065, 0.05579960359741123, 0.08968336988360652, 0.0461792974402347, 0.030422686381385695, 0.10933905629621399, 0.0509270315899724, 0.09952034485796768, 0.01069055875808361, 0.03332082572723589, 0.06187673012215284, 0.05100163323203883, 0.03738627431073016, 0.06334332118351614, 0.026360627736956365, 0.013489866058432288, 0.030560633918691068, 0.023602730361744765, 0.05819722131315259, 0.02541864027960166, 0.06709169746646959, 0.09150036190065647, 0.11850369718646812, 0.05429327555541551, 0.07357411131623291, 0.12166972407290053, 0.09725188956626, 0.09082207531337777, 0.009960785316633842, 0.12035235927830781, 0.015374003766825604, 0.08529962325889258, 0.06617364834152883, 0.014013338725142663, 0.03413110543342848, 0.07001318908747166, 0.03987589535573798, 0.08012082292548112, 0.05739394748102754, 0.015060081045263478, 0.014083362034251614, 0.04069658236638193, 0.03808621437318864, 0.05068528488458646, 0.007837593223103474, 0.03426144380242594, 0.017495942827794823, 0.054197981878514254, 0.025065864451349746, 0.03308776262847166, 0.02836421004406387, 0.0626983326078663, 0.017147861203298937, 0.08398037388800614, 0.05138872596885889, 0.04910480336196, 0.11271453928202392, 0.06157608657714821, 0.024128961902592453, 0.04766057440710645, 0.10819502655536899, 0.01496489845111125, 0.11591674084024084, 0.04218259758706536, 0.013068375973812035, 0.03563174910302605, 0.018758787060036294, 0.12605118009472085, 0.06492034381916446, 0.01887247259277971, 0.0723126556183542, 0.06400828167135197, 0.10683130578047807, 0.05274895721325471, 0.07213006622248119, 0.021882252016615485, 0.1101616508657894, 0.0783572961846667, 0.09428846995316206, 0.10240414495309515, 0.030140727720854264, 0.04467388104286887, 0.015770641959182197, 0.007447483536276607, 0.12704877212883967, 0.12562357279802525, 0.04176182762509392, 0.048686304850684065, 0.035078392303999395, 0.07120617184667818, 0.050010740636817874, 0.03151648948269506, 0.09286563783403366, 0.07169124339857409, 0.016299459046774333, 0.10699367045515007, 0.03653033959469007, 0.009473070761399164, 0.07082857476967959, 0.2932860978668736, 15.664529512005469, 56.69822954362439, 88.83754238005608, 92.6281209145823, 100.70480669698408, 94.38233037148753, 97.03120108573668, 101.13883264603155, 98.95991679160826, 88.0138760228311, 81.55114358471286, 52.840790287140884, 27.439675984844087, 22.608451458715624, 28.94213595697957, 19.595745609652614, 17.01847384052892, 25.8463974537388, 40.575923150585545, 26.37224412733509, 44.502050953526656, 45.99215545961934, 49.70695380241641, 59.79857290944746, 57.4284101301624, 56.3673540853685, 26.499444630838212, 35.816699612525206, 33.19713292583343, 57.078644537156634, 55.224983384532315, 62.14068681963029, 53.32040594470117, 58.20803219272245, 47.1985980772203, 47.814892645805116, 49.50130393428188, 51.49013388541437, 52.730540306337424, 58.542104382668775, 56.7648627681117, 66.92911240362352, 60.665146073987415, 62.480109122491655, 67.23429633725074, 65.63509894955543, 96.75503484664425, 92.89334374089395, 55.285113319273925, 37.21724071810323, 51.964591626198064, 77.33769432190927, 46.458599798140995, 44.59105737747685, 39.47976973748977, 26.791259165733095, 31.676863431930546, 19.258313909653697, 49.51477727582378, 92.41402226109659, 88.35898184007215, 81.88262308797529, 100.80277181440785, 97.84644219183154, 102.71864568033527, 90.9609410070604, 78.73941606090915, 42.83120362989364, 7.857647393980335, 0.032993801944558664, 0.3668177296077052, 0.00935116989327775, 0.04266915534953437, 0.10710676801541161, 0.04804915718493923, 0.0044382274462541026, 0.017123871159950094, 0.01843373978420371, 0.10221829968354396, 0.0038837854358022136, 0.06110293535335411, 0.11462991231030996, 0.06133184242512911, 0.04362840468304292, 0.08091083577563686, 0.11734144221390448, 0.07418524263606918, 0.06374782326841547, 0.08785726142025764, 0.0639354994881057, 0.03716759068230468, 0.027891252257470644, 0.04246324240680664, 0.043874192502229445, 0.04970438590633774, 0.04991251284316663, 0.03708833122565862, 0.04579600066907945, 0.08600568819430568, 0.0667123307263659, 0.02692364298948838, 0.0813570207044963, 0.05670260292507949, 0.0316122466427905, 0.047364209463158925, 0.06240171868534339, 0.005561271166023348, 0.04676334372150802, 0.031167766259562586, 0.028496689628809694, 0.056100637847257245, 0.023320245015765392, 0.03933607916077299, 0.01990902019784816, 0.015045989815506243, 0.05365395603040534, 0.015078888503804564, 0.04520099550004929, 0.006131917133086151, 0.02530040226936821, 0.0537475872965109, 0.053556915673036734, 0.05423494945130041, 0.1514299799718203, 0.11274019556660807, 0.24448933079838756, 0.18652232273692088, 0.1847257852674492, 0.1686620399836571, 0.1302039818537812, 0.13375611705405097, 0.18261740404751994, 0.19568073533235059, 0.17587665768881, 0.12080806668006605, 0.17264335296086727, 0.1986309399287547, 0.14543368721440916, 0.22007294419792392, 0.13197444169031036, 0.16790137596188054, 0.09836032686214294, 0.12752304950188245, 0.1521941373545316, 0.1321579503916925, 0.17705744432826198, 0.18225470738064858, 0.09201197073824945, 0.26510206021128163, 0.12440357777860858, 0.14676502545274075, 0.13297579521613737, 0.283894932438289, 0.12879373655924875, 0.11193289977288055, 0.2335128230192969, 0.22740333311019406, 0.1170903109314461, 0.16779329627752307, 0.13690441666591552, 0.23325532554618775, 0.19607908573121796, 0.1287151206164591, 0.18838832905936628, 0.13873613289287015, 0.14636981601436294, 0.14758829417968952, 0.1324897277499399, 0.18845497870877867, 0.2120245930047766, 0.1260289022578828, 0.2283097836639612, 0.2646304258415776, 0.23585087739892546, 0.3266973372909331, 0.19564999988482845, 10.788902774933847, 50.89939748087237, 95.9458577248358, 108.4559279103433, 111.67992007347846, 100.22739148909046, 95.48606180375623, 96.44363787866409, 88.50669045602122, 70.70509187636837, 66.81836820417836, 51.09992081119169, 29.702854156494144, 30.057036338313935, 51.037296249020486, 51.03162057938115, 61.001426558340754, 74.30896559069234, 87.73316767907913, 94.16074783571305, 109.65615749359132, 98.9695893564532, 109.79701765121953, 119.79952443030574, 102.31021711903234, 79.30845783602807, 56.4265073499372, 60.58159566694691, 64.61387065149123, 131.00655971034882, 124.91915887401952, 143.83805244199692, 122.0825242996216, 133.34787737938666, 110.43884292725595, 110.65826031469531, 101.59257242756506, 94.37431304685532, 87.30195799181539, 91.01095122675743, 90.47630079330938, 110.27868470837994, 95.18046209889074, 96.29604693382018, 93.96311529221074, 91.9871271810224, 143.87173775703678, 127.75235745214648, 97.9401005468061, 71.8596258471089, 84.64555632683539, 139.27506508365755, 99.08235749890729, 83.3212229513353, 89.23953825427641, 55.139620842472205, 48.478938148867705, 44.24131924106229, 56.77762223828224, 77.2635458361718, 84.11876632321267, 67.36776674947431, 92.77233077633767, 94.02362961922923, 111.14042943523778, 104.9532513464651, 86.30413839893957, 43.029824610679384, 6.207310634274637, 0.13874557109609728, 0.5579804460848532, 0.22472832261795, 0.153731154878774, 0.2572852361106104, 0.17081675420124687, 0.07518510229044384, 0.11496525197740524, 0.281336443919328, 0.28026940601487316, 0.14986245682643307, 0.16313142143189907, 0.37208682106387236, 0.09815757403210287, 0.1793258766373319, 0.18734603579486572, 0.1252073265852467, 0.24145117930827603, 0.21674939431250098, 0.21154974106579058, 0.1989523597782658, 0.16021489406064635, 0.098638140987004, 0.08858763432550816, 0.12256198667830999, 0.19752754349141352, 0.11620080624256404, 0.2594972383831778, 0.18120110665838565, 0.22440547784489973, 0.16231314759821663, 0.18830416664000482, 0.24008219550934531, 0.24030607704433704, 0.1727876992475602, 0.17102733644987309, 0.21384659523685134, 0.07833118024732798, 0.22868867542955185, 0.3122988986151834, 0.17699699999103624, 0.11411317834450353, 0.1828773683237453, 0.11522278009403138, 0.14355594442496378, 0.09932184381590736, 0.06828273436234844, 0.09305561997837598, 0.15988555286199818, 0.1893332525486908, 0.09436580652911818, 0.12378053379154975, 0.16798009915697962, 0.10548533526279273], [0.03606749608391716, 0.016244532457823237, 0.04460730417180927, 0.015953709202397977, 0.05926077351755193, 0.03114887070091021, 0.053506365361353087, 0.06664094665358145, 0.05359114448149359, 0.04898724333953954, 0.033095228155293775, 0.014463497735109302, 0.05955180648954646, 0.0386362808245805, 0.05280036554341355, 0.029382019138504422, 0.04782776926614104, 0.03581608900980603, 0.03872442307070859, 0.04645312024701027, 0.04175081894162201, 0.07155863357888115, 0.03478665453111453, 0.03325296948934275, 0.031022337873676614, 0.08526965389929472, 0.020614658039243474, 0.0267432599268373, 0.034936554955258485, 0.026123234326200142, 0.06432399033538758, 0.018061294648495894, 0.008336651146471983, 0.05520617656950509, 0.007664632116023812, 0.07668167803316348, 0.023525359311832056, 0.06703159020793054, 0.04086606016743087, 0.04656377398679334, 0.06789975168724215, 0.12000368968133004, 0.04663913022546519, 0.08526443684053037, 0.1375011072283791, 0.1178209672892286, 0.015521127122244047, 0.03604518760356211, 0.11259893661425, 0.05704676409462287, 0.04855908828997805, 2.0557493860683134, 33.85715015472905, 71.5713708631454, 91.86296063084757, 86.32861398881482, 82.52857469743299, 66.86334210057413, 68.08162243135514, 63.48703253653742, 51.447556557193884, 45.28408135137251, 33.166063831698516, 26.67789286182773, 41.14585530373358, 73.0271428631198, 93.9226128978114, 61.42388151537988, 81.8219518661499, 117.57008060332268, 71.299848710337, 65.11831098987211, 88.11456326515444, 51.525039057577814, 50.406877225445164, 48.90579792761034, 28.663375070018155, 30.33838010603382, 31.286942574285696, 56.62624620622205, 40.15353095146918, 50.05666448223976, 38.452783400012606, 33.46810594681771, 28.594821845331502, 30.951013142062774, 24.378409231862715, 30.902687580354755, 32.67069789671129, 25.89041429181253, 25.629868891931352, 24.23769420193088, 20.507249524516446, 18.589604708456225, 18.435481056090325, 30.3189722184212, 33.38925061687347, 37.35633188678373, 36.19784024453933, 30.221854332954656, 34.65039460889755, 44.27746780457036, 54.71196482258459, 51.756572646479455, 54.04363216892366, 62.91358986208516, 58.19098164958339, 72.61585881633144, 79.73661591929775, 85.7847224512408, 109.15507470407795, 54.17286249899096, 31.485783207801084, 37.84833438934819, 33.84331203276111, 46.95537190283499, 54.729591954138975, 63.95706584376674, 73.84235259025328, 74.0781105718305, 75.43792570790937, 50.52064164992302, 24.469378802084155, 2.4284597414155162, 0.17938091239381224, 0.22421007945893273, 0.09047977190705077, 0.05980132515692423, 0.08352157915191305, 0.030620120646011446, 0.019783423913101998, 0.01370267570769835, 0.07534286277669092, 0.07374632022073192, 0.03870949967794361, 0.033932455004222935, 0.012535139516506706, 0.01501798164099455, 0.008193844696506858, 0.06274604456379049, 0.0422864101616846, 0.02539959916424367, 0.043806025998726975, 0.0750501482417026, 0.06531256551463759, 0.05611293738888157, 0.046884676726955565, 0.05149546116890927, 0.0398095712936934, 0.07811437736475661, 0.05655521909976679, 0.025089877477336316, 0.02509608661996261, 0.05622692744157488, 0.03815419701558929, 0.02589953090665081, 0.10558606050307713, 0.10365471454156984, 0.015927018699116044, 0.1263452735879729, 0.13095853249392203, 0.12838918084819473, 0.03516090763432365, 0.04299108081707551, 0.04407640140984328, 0.10207534001599397, 0.04965107001724744, 0.0936085592594839, 0.014230792782449675, 0.03886046879474194, 0.008659702763261815, 0.015429252112704902, 0.019122931633084532, 0.03843946134551399, 0.07251605962312992, 0.04183392032920834, 0.039832615218455755, 0.05064619141781042, 0.10536967130798487, 0.07973584842177169, 0.032779285834441264, 0.021337000427827723, 0.005433209514575861, 0.07230247430984052, 0.04788473939463016, 0.006672822609318481, 0.06758121232832633, 0.07706632311906546, 0.08298687276340301, 0.028287896195486672, 0.002868708402421626, 0.04220197195067041, 0.02020835756294189, 0.027801934066378785, 0.04200185446308986, 0.0426247758760808, 0.019669100612161622, 0.042490377241084655, 0.022195378964346264, 0.06920659809463447, 0.02930738685292102, 0.07669605750350222, 0.027956515287740097, 0.05259074856557193, 0.04952628578570101, 0.001059433643897665, 0.07086509418103003, 0.030522515298798684, 0.015384847741393794, 0.022330840546337348, 0.011115430163279658, 0.034070454252463196, 0.02525030203434008, 0.05357576909685328, 0.044434348331584085, 0.036739351363071514, 0.021922621019785444, 0.0772458405023621, 0.07857472725933598, 0.038103937817316864, 0.15663462811179701, 0.012703350399650875, 0.026320017416090257, 0.04006634864415373, 0.031809041223999475, 0.193177159995802, 0.20889900023898772, 6.6229843035821, 57.982386081449455, 93.14454801620977, 101.64021353567801, 97.90102589514949, 103.07091374551098, 90.22661055288008, 98.9071216890889, 104.0775743607552, 85.50956033891248, 67.61004371027794, 44.17796119566887, 25.223546643410963, 29.351798103701686, 46.20937239739203, 65.22502691515031, 47.09560448123563, 58.47127814446726, 91.0850840230142, 54.930142741049494, 55.48257327848866, 73.9814555260443, 52.88443450004824, 54.15596885065879, 48.4779183326229, 28.33030308446577, 28.94776259699176, 34.81128631099578, 53.204378312633885, 37.50171845959079, 49.81282641810756, 41.73657994116507, 33.955887979076756, 33.3273438484438, 33.878605519571614, 26.73621262273481, 31.119588767328572, 31.49491252437715, 25.657282337065666, 23.870115164787542, 20.48264841879568, 15.295445265308505, 9.754679664488762, 13.840804869128814, 23.960041384543143, 29.099391621928064, 27.90963084466996, 26.604721046263172, 28.350569971146125, 36.3163625040362, 43.958971346578295, 52.48924393807688, 54.35506836060555, 54.42819703009821, 59.56458783918812, 60.35104659295852, 66.88562116315289, 63.149728313569106, 62.731874296742106, 102.17310674728887, 40.347150910285215, 18.634590371962517, 30.8276310659224, 39.63771181721842, 73.47576787394863, 82.85547287233415, 89.94019123815721, 95.19477090527936, 93.24186986492526, 96.71758405623898, 75.52055435795938, 46.353182177389826, 9.546008590729008, 0.16728067620387002, 0.21954674904625263, 0.07265547996446972, 0.062275827456746376, 0.018525632030721155, 0.04753330038980611, 0.10355141524585987, 0.0599075049432295, 0.009671018304934186, 0.06377245299518108, 0.07031540311272107, 0.036543642711495204, 0.0361471462454046, 0.0689945372963144, 0.06178121044931393, 0.057472092279743765, 0.10085391241215891, 0.0280313793149206, 0.027844086139192505, 0.08358438303994556, 0.061614505886550874, 0.05734816989711216, 0.052681185245033235, 0.008139119205635884, 0.017143975222303022, 0.03489127532849389, 0.027307742237744313, 0.0865732674156466, 0.003004974616135681, 0.05208899161868519, 0.10650351974031619, 0.08045102980348372, 0.07271732624259687, 0.054662024316888665, 0.09108739454419383, 0.11126082615866778, 0.03889654387509631, 0.0423299545993007, 0.12016410849267438, 0.06602640624248213, 0.010977933660239704, 0.040172375212874145, 0.03898244531404588, 0.04937141728136809, 0.0064696896081459865, 0.019159403163939714, 0.013134288263597317, 0.014121962331926391, 0.02589277784159828, 0.03261364613389296, 0.07798599635040568, 0.03687053242878568, 0.22571993150538017, 0.14689564344383058, 0.19690604700196176, 0.18210152043930947, 0.17039064077600358, 0.11307840806341941, 0.14361156240826653, 0.17837834844906486, 0.19224187389256495, 0.19413905999352857, 0.15664051166705548, 0.18245804243751113, 0.22510136147179913, 0.10284830740983449, 0.1381305710322434, 0.186148471829872, 0.08847767006485693, 0.17971416064087423, 0.1034363794831499, 0.11839479778803165, 0.1225217210970098, 0.16951540064427162, 0.13477276169484662, 0.1067471050567204, 0.14382675650619692, 0.20100319247332313, 0.17255885346281916, 0.1376285689372209, 0.22570018175869222, 0.10174774549781315, 0.14280056640986474, 0.1198949205178407, 0.12675593501978344, 0.09599577350121352, 0.09790239014452505, 0.18849968760003968, 0.11281536411373846, 0.19421597522112632, 0.18800076517847278, 0.08968428918911565, 0.1043236012300176, 0.2909242487963169, 0.15484172189908643, 0.1566615790849732, 0.4221021888717529, 0.18681484574992813, 0.15236031714706652, 0.1636720803235808, 0.19635444837472132, 0.2529407514920158, 0.33153729693543527, 3.7225268829253415, 54.81012998088714, 102.93754531491189, 112.70944026208694, 104.62909883068454, 104.16935782278739, 88.6405138815603, 91.25032563363352, 82.76069271949031, 70.11919175424885, 58.400726472177816, 43.78807760054066, 37.41257867505474, 59.728990062590576, 103.52196278110628, 130.46220533309446, 87.86510052219515, 104.62185813534646, 150.51555818127048, 100.01930190670876, 94.94651625233313, 120.70003786394675, 75.73634747535952, 75.24167383870771, 78.80766530190745, 49.30432642659834, 51.827544012377345, 52.48223858494913, 88.87716616353681, 65.04210325979417, 77.54396392453101, 60.38666563649332, 53.65316806300994, 48.87614088673746, 50.47039216564548, 43.3959190307125, 51.870227244592485, 54.2292034241461, 44.73425919009794, 46.749219971318404, 41.95140031076247, 37.70527770442348, 31.19142109347928, 30.68115407420743, 49.86704534099948, 53.44547464001564, 55.46734663747973, 54.12280128848169, 48.19260512628863, 58.01105468503891, 74.3330724777714, 83.31672791511782, 77.40122887396043, 83.54180920508601, 88.22148707605179, 80.07046453414425, 95.58634111958166, 108.41176986694337, 111.64346556509696, 129.56098587282244, 73.24764282472673, 43.04949529709355, 53.056120564860684, 47.13852697803129, 63.89757133299305, 73.18442990702968, 83.31046781232281, 93.20674896240236, 96.29361506431334, 103.89199133842223, 78.76237761589789, 42.99071465769122, 5.490310682404426, 0.18663669966401594, 0.47238240859681563, 0.1615861761233499, 0.13893854864422353, 0.17398498742090118, 0.12925784794553635, 0.26681867938849235, 0.1593016253243531, 0.16037866833709902, 0.18480976382570882, 0.21530645238536023, 0.15796990404205938, 0.14858517375203872, 0.14136956013258428, 0.10805176045264929, 0.19025407491191743, 0.3127474584166081, 0.1711864988770216, 0.10941823914406762, 0.1504450207275729, 0.12877086117382974, 0.25001296262827616, 0.1396154179688423, 0.1923495398894433, 0.1054631723391433, 0.17112200959555565, 0.15377846846897758, 0.21230249906018858, 0.12698546262277713, 0.12625891249626875, 0.19256183817501993, 0.17260632027060757, 0.15416799353495722, 0.21928574289045027, 0.20947957231152445, 0.21586727471120898, 0.16870474172455652, 0.28433653616136123, 0.23870879904397074, 0.21409330619198663, 0.12780988048161232, 0.21352053289451908, 0.14349409048595738, 0.17122656527546146, 0.14108508104278197, 0.1406423435095818, 0.13259560110107546, 0.06417446146388689, 0.173596044581744, 0.10826353779843739, 0.16824335761127934, 0.12693346057447696], [0.031014556335585735, 0.049677572828987916, 0.028596277228526534, 0.08141613970961302, 0.06517204966756605, 0.009519636458266647, 0.0205741434793679, 0.011008718903476914, 0.07881105772309727, 0.03069373978031499, 0.10076589657053833, 0.04777130092524233, 0.04203842367015539, 0.021077637530622945, 0.02735752837672349, 0.03278174114623859, 0.035430873188400464, 0.01337042912059734, 0.028293126660789696, 0.06092883804212175, 0.019343310231042486, 0.030820345385901393, 0.05515505552231785, 0.07774159898080173, 0.04936428500279304, 0.04756323144500775, 0.03548425802540395, 0.04326274325590461, 0.045019057278911916, 0.050383243229120016, 0.05310725653544069, 0.04289715843755872, 0.0356842682606751, 0.03924155923267526, 0.06461770078467746, 0.0471073784865439, 0.06146809499290201, 0.012104885386032684, 0.03534877537599495, 0.06728262189895877, 0.03511357106148236, 0.06554618402714692, 0.05151030795288183, 0.09575431790923881, 0.06464198577187716, 0.044444138935256394, 0.07130384039614471, 0.05615477345042652, 0.11020036128860329, 2.055042991715093, 15.74845450539743, 50.35346631080874, 82.00686808555358, 79.77594160264539, 73.26861966040828, 71.55673257766232, 63.707607023177616, 74.1945343632852, 33.19565811464864, 41.49787625958843, 23.755970270402972, 36.39330763970652, 52.843375129084436, 78.09010690258395, 38.55325491197648, 102.956145194269, 105.42912898525115, 42.605267263227894, 56.74571767930062, 29.43006507812008, 37.546370721632435, 46.266234997780096, 36.79273043909381, 24.799422717863514, 29.38173951641206, 7.590045159862888, 2.0220755929908445, 1.20862124908355, 3.5178473111121886, 0.24053231813013556, 0.4329043043957603, 1.4380341840367166, 3.586937410216178, 2.379603924289827, 2.007350892789902, 0.15593780985762998, 0.34512797250382365, 0.29378500496668203, 0.05487861269484124, 0.15922055790020576, 0.5260687778072973, 0.5334458367959146, 0.4736539306900194, 0.11175938085803103, 0.13102498296047413, 0.28985313530410495, 2.25676215464069, 5.981143338064994, 5.818186508071038, 5.210750122224131, 5.819660828959558, 4.597409098379074, 10.942556723471611, 19.725795715085923, 17.50875638377282, 18.63006199559858, 20.996910372088035, 28.216883828563077, 43.91765702155329, 55.44644040446128, 56.877705435599054, 92.5795227481473, 93.72192875031503, 51.86253939905475, 50.2358030503796, 34.02569832340364, 30.13764104535503, 40.16702782723212, 53.34529730581468, 48.95815372467042, 58.764369410853234, 79.37816619873047, 82.13491778219901, 61.540838749178, 18.33186576443334, 1.491471452097739, 0.09315751733318453, 0.07215013772609734, 0.03384718941825052, 0.14688573026609036, 0.11383047657868556, 0.082805608699639, 0.06847417973462613, 0.029098334864923553, 0.062373231705879016, 0.062317912496866724, 0.053251982035656134, 0.05360851552517665, 0.02181439577872234, 0.03650936410732327, 0.03399771037361315, 0.07296337070123804, 0.027704179332020785, 0.042225827928632505, 0.04355571059990795, 0.026637068649213162, 0.05739939053572955, 0.09722972664261058, 0.02837825435093574, 0.03741246685686131, 0.11703709846422558, 0.04959048012331609, 0.05361064524960615, 0.06090921853038092, 0.0967100662209334, 0.02117606067669488, 0.03083298392143221, 0.010616592968994332, 0.09739281910081064, 0.03893981635149929, 0.02444180539779125, 0.02297499600136953, 0.06988774985074997, 0.05618437891826034, 0.08802478186666005, 0.05669133760215295, 0.032842036096319076, 0.04725560117813368, 0.03524293649881598, 0.062267055750013366, 0.04809409973301715, 0.056614778605439973, 0.01080138007960012, 0.024280850324899923, 0.014115713927293978, 0.07067556402856304, 0.03190484434937037, 0.016652110385738553, 0.03601553617045283, 0.012352347107333763, 0.05579701422022716, 0.024575985697728973, 0.11046725866054335, 0.02916560504555462, 0.01959204557351768, 0.04235050490786953, 0.08483153587627797, 0.02158400249637423, 0.03149690636013064, 0.050017183436261076, 0.05795932803002577, 0.027094149263575677, 0.07603801095918303, 0.09449562012788751, 0.03960691039420424, 0.02305856661780948, 0.10827056282470304, 0.03348636966679366, 0.03587566766767733, 0.0797961472022918, 0.05730839844252314, 0.050925491753244595, 0.07277521950703475, 0.04250984353524062, 0.018755395205751545, 0.07535898892749703, 0.02477377619323952, 0.046751059501642184, 0.02543496561326808, 0.10796050405910901, 0.034525518140365044, 0.008795465034763179, 0.009077204402626283, 0.020186920507600712, 0.025177745847031478, 0.07612906816986299, 0.05156357404625705, 0.11266575480300574, 0.05415634116938999, 0.023280467815516938, 0.07258527566708865, 0.06472353583141681, 0.10333355516195299, 0.0350722367875278, 0.1068875979211542, 7.345811916935829, 33.04893009124264, 74.47448961196407, 91.80989096241613, 93.68751387442313, 92.10151918472783, 104.09036913225728, 94.24642808975713, 106.72201279670962, 42.50323072556527, 45.581546060500614, 21.453691951690182, 23.702210264821208, 22.960907797659598, 47.87928619692403, 28.902116014111428, 92.27596267577141, 97.58557319641115, 45.17422360758628, 56.495113526621175, 34.55007999174057, 39.32331031368625, 46.45630913396036, 39.662748306028305, 18.76621138664984, 19.77220323777968, 5.462389290332795, 1.501450084390179, 0.42472680610033775, 1.0722415413587325, 0.25317054722578297, 0.1913959902500914, 0.4281748452734563, 1.2220358776469384, 0.6948449955351892, 0.8230301365256311, 0.17281383816753665, 0.2666603136927851, 0.40575240167879295, 0.2857880889167709, 0.37417756693978466, 0.7626032661045752, 0.5724902739447932, 0.5686340937691351, 0.37340556481672876, 0.4496251232922078, 0.6275363879338388, 0.26050590038780247, 1.0406635196939593, 2.1006442221903034, 1.6841646283864977, 2.6978667561084997, 2.458490142899175, 10.185615766432978, 18.934037839212728, 16.47181507079832, 18.84132085307952, 22.257524844138853, 30.504702329635624, 45.24818381955547, 52.808520947733236, 67.2372067359186, 86.76089056076543, 77.90353544296758, 50.983704905356134, 24.834633834900398, 16.106641427163158, 30.714178469873247, 56.150313654253566, 82.10622956675869, 78.12085043999457, 79.71817293474751, 96.11943044970113, 94.25684590493479, 82.50728407213765, 38.26224642415201, 9.5978799750728, 0.3519407617709329, 0.2613575450114666, 0.072925349757556, 0.07378811031700143, 0.06067549659600181, 0.047764785347446326, 0.0383295392196986, 0.07606925202473518, 0.0822816658464651, 0.04728192395921196, 0.04183760521212413, 0.02728838894155718, 0.06713733332411898, 0.06274521335839264, 0.050897529544008356, 0.0582379388863281, 0.03150092449129349, 0.031432622007184455, 0.09233582674735978, 0.01815333245171895, 0.07130541853726872, 0.05738569288364342, 0.030094911832542672, 0.03613414573332956, 0.14232983602391136, 0.012499129553625902, 0.008028810205418737, 0.04464899084620899, 0.028002719965673266, 0.05797975959496633, 0.07672350643382919, 0.025960120800582152, 0.035739790482987324, 0.035963629883143215, 0.023996219932732564, 0.09151548447628176, 0.11863135041729098, 0.02843771426517877, 0.08018219422909521, 0.016820739744411364, 0.06392435673924704, 0.08992405938765696, 0.04501052688987506, 0.020681424517064326, 0.03507744618541291, 0.034779300087041436, 0.020508715740194725, 0.04173239835748269, 0.017673326656222343, 0.01496470692913018, 0.0836144749736113, 0.11010276934792919, 0.16996348547118326, 0.16306045104659375, 0.13283975332254364, 0.10501596085246533, 0.1375529560590944, 0.06682047169775733, 0.15699550148940858, 0.15428287608008232, 0.1612577235866939, 0.16069121688844698, 0.20546092020888485, 0.2628984542623643, 0.13026180617030592, 0.22766795520099903, 0.19846799302726023, 0.18427698031788875, 0.1584344291158261, 0.22526447691263693, 0.24105171042103923, 0.11426255016797975, 0.08722830323442336, 0.20984326489269736, 0.1827095491030524, 0.09004110230072852, 0.19994157847137223, 0.13985357938274262, 0.129446137035566, 0.12545201506826187, 0.1985934475857404, 0.09463115640345121, 0.2165166261575876, 0.14798552609018742, 0.14588741044844353, 0.1474944790524821, 0.10299887433047257, 0.11018491695604979, 0.16312731520062493, 0.15598893856569646, 0.1518090402767543, 0.17401802113219617, 0.2778612852336899, 0.21163166650841314, 0.3174790012980661, 0.15805288668601744, 0.27176533975908834, 0.10712860918213284, 0.1898874252313568, 4.248977601528168, 28.398909261149747, 80.27452976472917, 105.0393944401895, 99.45173494277462, 93.33078999673167, 96.64188231191328, 81.25274535148375, 96.70844493373748, 43.76615155127741, 51.69509341639858, 31.748291753953506, 50.95295744557535, 75.11081572501891, 103.52808952331544, 55.830836603718424, 131.3375371502292, 141.28888837752805, 68.11006745984479, 84.04544937995173, 55.030296541029415, 58.81968659739341, 69.83145452314808, 57.29497501927038, 40.168941943876206, 45.088045212530325, 14.778729869473366, 4.6322853430624935, 4.4174693861315335, 7.590741380568474, 0.8358299948515431, 1.653840049139915, 2.7713381426949657, 7.559556086217204, 4.934138203820875, 4.878754336987773, 0.7857106842340962, 1.2416036018440801, 0.8191575314248762, 0.4412917720694696, 0.4380339984932254, 2.0933169895602814, 2.828286054634279, 1.9905686642854445, 1.5212822008517481, 1.4173818019128617, 2.213743314627678, 4.479344775599818, 10.769348779032308, 11.24476848110076, 11.154350003888531, 11.468484786248977, 8.861512830180507, 19.641358852386475, 34.832624004733184, 33.316290609298214, 38.75942253297375, 44.53265328561106, 53.367023314199145, 70.5439373754686, 80.95281739388743, 72.77072968021517, 113.09064757439398, 130.41665877065353, 81.5022159391834, 73.66042521692091, 44.7114388404354, 41.83028928695187, 55.93696809584095, 73.4801217048399, 68.7909673875378, 76.84102812120992, 100.89023282451015, 106.60457703375049, 89.59244958816036, 33.427250539102864, 6.591522972429953, 0.2046264359547246, 0.2837215514192658, 0.17231303116967603, 0.3146431889505156, 0.15701234010198425, 0.14767530644612928, 0.1653609211526571, 0.16739146783947947, 0.16402190671332423, 0.21883652425341069, 0.14578833995807558, 0.152969341725111, 0.24319052065332092, 0.10851931923459615, 0.14687511228745984, 0.21486517041921618, 0.08102045529672215, 0.16990742315688442, 0.24121778296126475, 0.10252750809154204, 0.27003732119356433, 0.2568448274847, 0.10154894568146237, 0.06811502239396496, 0.17069116174694032, 0.08354427067623024, 0.10376945152998933, 0.2336815921890159, 0.15174395344670744, 0.15500549617553913, 0.18365614266405184, 0.17979659170152681, 0.16175053262662503, 0.16051703913798257, 0.14631692530407062, 0.3187132302311159, 0.21035252950124203, 0.10044520450455528, 0.18424203138678305, 0.15368923454755737, 0.13046705644697915, 0.11824400104101628, 0.1615107930716007, 0.12531250279637116, 0.11152763926093617, 0.11721076293578071, 0.18834524427450475, 0.08924106902052319, 0.17580178025509083, 0.15895714622832116], [0.017270586573548855, 0.025749165084092848, 0.0209809840476561, 0.03343334872155421, 0.02076156880526293, 0.012150601682914122, 0.015406654434158437, 0.007777901088458396, 0.008335127589112569, 0.028848082668358282, 0.02929894839443507, 0.048401362277687564, 0.06041784207486819, 0.04923246808410172, 0.02145777993474997, 0.04735254194407214, 0.05388302398064444, 0.032616940311967366, 0.020234423704565536, 0.04561830657504259, 0.03371463705515189, 0.05651146781841113, 0.05687208838700768, 0.0240631262215996, 0.09266763474912414, 0.010628219310855194, 0.048412053034670895, 0.10025808752904977, 0.0496582406002187, 0.04696222397709086, 0.01658034135377215, 0.0363626659307028, 0.011329017391788864, 0.04425497267455344, 0.09865232127448244, 0.02000792214887277, 0.03373534058130557, 0.031714973287777073, 0.011039306879073623, 0.1318456776319973, 0.04526062012319604, 0.060061086419849634, 0.039109987462119716, 0.027254981762399117, 0.1566418906253192, 0.08272839469775077, 0.1790670461712345, 1.1457865949599975, 19.139673979051654, 59.77403848401962, 76.37883170958489, 85.2879072004749, 75.59416940135341, 74.6141730585406, 76.12830992667907, 63.646065035173976, 51.25413271688646, 25.865036556797644, 41.87032099693052, 56.059263675443596, 62.238573489650605, 72.34310503928893, 73.41053101324266, 55.563625135729396, 53.847403833943034, 28.953997204380652, 18.8729194671877, 20.791301688840313, 16.375228666490127, 14.354438262601054, 3.721441612128289, 1.5934547926149063, 0.8027615950953576, 2.424402539768527, 0.8075701757784813, 0.27476871085743754, 0.009330263353824135, 0.07463465279508984, 0.04331826930865646, 0.13911058134849996, 0.10204203051304626, 0.1551874880228312, 0.06795192227488564, 0.20314963294133065, 0.1478579724507947, 0.12040992312493826, 0.04777842171249851, 0.06767377873221714, 0.03593361838870952, 0.10179243906731568, 0.03972547016136589, 0.07823035541561343, 0.06040357368727846, 0.023906599136910612, 0.1068303098661765, 0.04579660204810001, 0.027774347240225445, 0.21678952199797477, 0.3573307725450685, 0.31502044128794826, 0.18055719443626944, 0.33021233254863375, 0.23904874289949096, 0.9014738014628811, 0.8876757612151485, 1.8003611675193234, 2.6674674066805073, 6.780438048224296, 8.144948261399424, 14.983491320763866, 24.551373989351337, 35.381783285448634, 31.73864664569978, 36.93143329312725, 62.186672687530525, 79.19623098065777, 54.36139122132332, 33.39526361034763, 25.67430934598369, 34.31731085623465, 56.31286059656451, 41.80230709814256, 59.47720135411909, 70.3215938998807, 77.84902234231272, 62.63538006813296, 24.841582313660656, 0.5672165859610804, 0.1517596582491552, 0.025173591735262065, 0.03832555173205272, 0.022307984313116442, 0.015058871583953021, 0.057894605091742934, 0.058293005286325375, 0.027524912842519345, 0.014382932098552346, 0.06511270849695129, 0.016981271553724524, 0.06007392605346057, 0.039094550790445465, 0.04936752938515237, 0.09872300054637656, 0.12150442528147852, 0.08474911247650463, 0.030735625637575027, 0.09494706808078675, 0.03541962318723241, 0.08947399039302142, 0.06647980005870904, 0.004633540604939504, 0.03510062417556201, 0.06108248846665506, 0.059458477828170986, 0.0472981458710086, 0.04585606579278265, 0.03943989173539224, 0.04208529292936287, 0.04629809469465287, 0.032107861479744315, 0.017455359320006063, 0.03272747530812218, 0.04418815831623731, 0.015487415423136086, 0.02956594918824492, 0.04629427574635033, 0.011970301932324807, 0.0710890370030557, 0.05484909915755834, 0.06168076866156152, 0.05289772765771036, 0.050028575163695126, 0.024736873737926927, 0.06167965017319207, 0.03559209639206529, 0.09958487244382982, 0.011190995160910872, 0.04795868220108171, 0.052239570030642134, 0.022116257403526577, 0.0297768110589635, 0.0735648186697114, 0.04292104122859817, 0.01619209948506567, 0.021058163575587735, 0.05896586797110016, 0.03745702253053746, 0.027615876207428596, 0.05916834883992711, 0.04010199088483088, 0.07887858071274335, 0.027610107565358765, 0.06360459163965237, 0.009304661653004587, 0.010756082258247321, 0.08153705136670221, 0.04169961745520273, 0.061153719321854656, 0.040210223786773226, 0.01939813339812381, 0.04099550987443617, 0.013032628396045298, 0.022554743148746993, 0.060175896186621926, 0.06948726972745312, 0.11786863327987733, 0.01514047239681766, 0.026191477438495047, 0.05546291178512958, 0.024989933646734686, 0.052573469452439785, 0.028020278700897773, 0.055354812948573986, 0.06951283408148635, 0.014886133121176353, 0.11997505331472044, 0.027367667550401344, 0.06220336319998868, 0.1133237936864457, 0.033658410031949325, 0.13109947735023114, 0.0930693865783753, 0.05105997848835203, 4.831768754989871, 39.28763635696904, 82.60392342844318, 91.9190191453503, 98.24307226365613, 98.82636793198125, 102.7050821242794, 103.04523791036299, 83.8013053709461, 71.74493574327039, 35.483458965055405, 33.13722656619164, 27.014804847778816, 34.135685505405554, 52.162894894999845, 59.76619374367499, 53.615740806825706, 48.2523859700849, 26.590198470700173, 19.17448893670113, 16.850298297020696, 13.90764597923525, 10.370968349518316, 1.625469668257621, 0.7427164203216954, 0.42927142352827136, 0.5881368537102977, 0.7614664529119769, 0.4073143630258499, 0.067112818510542, 0.09385196837566553, 0.05227616988122464, 0.3446560929859838, 0.10739720726926481, 0.19257074011670006, 0.16875407778688017, 0.2853063115429494, 0.18095025882845928, 0.28423280785641364, 0.18662287943786193, 0.20583771289356295, 0.1965304800579625, 0.10327486516607386, 0.11557859729134268, 0.0768502556809014, 0.07042906757804655, 0.00285768439719123, 0.11792209855611287, 0.020549705274583354, 0.12237870014242588, 0.06503973096128433, 0.1604152107310872, 0.12198311532096517, 0.15511136952667468, 0.21967750493316884, 0.07296523229489404, 0.6342304029291677, 0.6768373940740863, 1.1017799305339013, 1.819210239956456, 4.3821239279162505, 4.644216212534136, 12.233203803339313, 24.027547336393788, 32.878503107255504, 35.06858594955937, 50.585800063225534, 76.01977009927073, 76.85321884770548, 40.458777643019154, 22.786717299492132, 30.423191555084724, 52.04931482192009, 77.6002577812441, 70.1972233864569, 82.49562678798553, 84.2932882616597, 89.99269608528384, 85.96071135613226, 46.21690727049305, 4.154659798068385, 0.009567035275751786, 0.054454674959302916, 0.04376303697485597, 0.06325191157239099, 0.0063177236194361846, 0.07472884330538011, 0.13210464599392108, 0.053451352587510506, 0.023608263431777878, 0.02596268144946906, 0.07233888646888156, 0.047296797556261864, 0.054858085368910146, 0.08228781753249707, 0.10739811125301546, 0.019336781246707808, 0.03296294392296865, 0.03386210515013626, 0.13630562702253943, 0.11774647289947157, 0.028550308122630083, 0.01935710747455878, 0.0686165648362329, 0.09223255043428752, 0.03132575465696714, 0.06394569611837787, 0.009877523050583419, 0.03346453999139128, 0.005296574860450722, 0.03237246250313136, 0.07119071219236621, 0.08445116556099347, 0.04959294692643228, 0.01328445777612468, 0.045853932237913536, 0.05910788152006365, 0.06699783637398674, 0.025343262973511894, 0.045627495799694336, 0.014916918364413565, 0.014015890755540421, 0.04962653988191197, 0.025567111949766838, 0.0019493830228795208, 0.022492234204565326, 0.09943864158084316, 0.030049069131153728, 0.04833184745943835, 0.15011466829286468, 0.1480360112843975, 0.22702643317320656, 0.08838154901299747, 0.14665480072219528, 0.16530056874598228, 0.1660527445135578, 0.14486885058783716, 0.19153077575948932, 0.14200841617440024, 0.19783126670987378, 0.10683120618904791, 0.20084386150683128, 0.11379914358258249, 0.18810719011291382, 0.1442527626791308, 0.17423877702845683, 0.14089979501741548, 0.23284076472684262, 0.2065375954994271, 0.18255725082370544, 0.2122393734152279, 0.25858173267014567, 0.18419393638689674, 0.21523496106026635, 0.10262984977734667, 0.17804491634090103, 0.24769425962961492, 0.18204818539802106, 0.22302186176661523, 0.10228062093618417, 0.13618794059561146, 0.11747244324895645, 0.10148640992420335, 0.17485993643922193, 0.13904999911544785, 0.1897640237885137, 0.2179307631787754, 0.19992481646758897, 0.4066372638748538, 0.19029579606027375, 0.18559229199684438, 0.17113903206923317, 0.1261972424183642, 0.424477459802743, 0.21511773428609296, 0.36985146843137284, 2.8630735556925497, 35.48615755573396, 87.55338191986085, 104.69988976755451, 105.16295694535779, 97.02367797974618, 97.08647512620496, 95.17844600062217, 76.08023735784715, 64.97594071972755, 35.646837449842884, 62.38283041984805, 81.19073267905944, 86.14965192733273, 98.24817134488015, 103.46615529829457, 78.67555987450385, 78.95138094502111, 49.777846720910844, 37.62794033173592, 37.14184491865097, 28.206069853998002, 23.88126842437252, 8.129077861385962, 4.247287550280172, 2.863596211518011, 4.928569909065001, 2.9884290743258695, 1.0132509325781176, 0.141625402855777, 0.2380528745632018, 0.354126533192973, 0.7220131699596682, 0.4250515967367157, 0.4966176307249454, 0.5947219616463107, 0.5039387346515732, 0.3969049135283117, 0.4652245120415765, 0.2810427870961928, 0.3883887430833232, 0.44412133313955804, 0.3739647783579365, 0.2814610711028499, 0.25668371919422384, 0.2321334051028375, 0.11006894656607222, 0.2951768641510318, 0.1426707298284577, 0.18653948310642474, 0.288693553978397, 0.6967227689681516, 0.771738650097001, 0.36403526762320154, 0.45874641126682686, 0.50807750934074, 1.6564983129501345, 2.5733910741344577, 4.231223973535722, 5.989019457371005, 13.68758826486526, 16.466000157017863, 30.254033457848337, 45.1331603142523, 52.526267190133375, 47.1704040804217, 51.32626118198518, 90.88809474822014, 114.79925555567588, 74.16600304265177, 46.31476648392216, 34.561976540473204, 47.06541399801932, 74.65422045799994, 59.39307828103343, 77.22254922313076, 91.43637149564682, 101.62053892689367, 92.3438745929349, 44.7572874253796, 2.164878427020965, 0.25380759530009767, 0.08386228143447831, 0.15643481705938617, 0.10732044525925191, 0.09805683347005999, 0.18240744999099165, 0.41883761243474105, 0.1672955229878426, 0.1462703931235498, 0.11402238160371782, 0.09501567125440606, 0.16188491977030234, 0.15373098633943066, 0.24903915762420625, 0.20938883685777265, 0.150902206679025, 0.2532112724598377, 0.08456564974039794, 0.2589832853165365, 0.18905880921069654, 0.1685481380310751, 0.11588300232805553, 0.16984268872728273, 0.15095379503984607, 0.20431197218356595, 0.15203348871681, 0.12505784750946108, 0.12092086546603711, 0.08625403091671967, 0.17976717392523445, 0.18041885427890286, 0.10644421687409764, 0.09842942033203379, 0.11009685514915375, 0.12662399935746385, 0.1748455952732794, 0.1838425012125123, 0.1362566893259364, 0.16368073711712516, 0.15778201331775035, 0.14659256373922672, 0.15944382656485806, 0.14509780362488764, 0.12968287352592717, 0.07107231330366866, 0.21906825052874707, 0.08869370685950403, 0.22509710202294014], [0.0692679540764901, 0.022743980272582943, 0.03699804393334254, 0.01580356841816777, 0.014992831932050327, 0.014973078354922755, 0.04214473369140779, 0.03225029063140673, 0.07353994379481, 0.09129930212492905, 0.022580102574260488, 0.02545925060046777, 0.052075462505942395, 0.028522619789826776, 0.05868185619493166, 0.012240518380196826, 0.013808433188035363, 0.03478679625738052, 0.044418712477049524, 0.02105495175196519, 0.056958472461349545, 0.04109150069134851, 0.0690586282120597, 0.025782915087597027, 0.05598978492461386, 0.014900869780009793, 0.043901423097498, 0.03698846400384942, 0.023355149896815423, 0.054782863195625045, 0.026529161334638635, 0.06087978926276969, 0.06029248327737855, 0.03580677721108641, 0.0535327839034219, 0.022184163437134797, 0.09351451430589923, 0.059500892286098776, 0.047886589496967294, 0.05698987057492618, 0.02063783602939258, 0.10197581753375069, 0.04679747676897434, 0.06725849012934393, 0.3078032495273698, 0.4664823364826941, 13.469717271866338, 53.540611728545166, 80.33232981158842, 79.31006600779872, 75.50959525569793, 61.6719243603368, 67.16702768879553, 56.705772261465754, 44.97017406648205, 45.29007865536598, 37.59537289219518, 44.519379984947946, 43.02699658178514, 62.215788441319624, 54.94995855516004, 44.87952024705949, 38.39330065634943, 28.729347375131425, 15.47843756214265, 8.7948727415454, 4.094425430220943, 0.950716891356053, 0.9882758533762348, 0.2614601395062862, 0.21035858159584386, 0.045171290440785314, 0.04121078058115898, 0.10262406581351835, 0.1209301351299209, 0.058359076539354945, 0.091245852170452, 0.041879253582127636, 0.16821119724021805, 0.057867700083842205, 0.09682745387357089, 0.10467464569956066, 0.10642915558550628, 0.09771007909289292, 0.11971789292029797, 0.1469344687798331, 0.1545362979654343, 0.0472071384560437, 0.11752281352997788, 0.12799377988783583, 0.20055273277384622, 0.124393810157574, 0.08359724565619424, 0.05316367508062432, 0.29945978594403116, 0.17612842482424554, 0.09810823030889997, 0.11388044849398637, 0.1743190783646799, 0.27134233665081764, 0.24730986735272795, 0.23914704730193462, 0.1453239834236522, 0.047458304212458675, 0.029413331067189578, 0.06873298721808581, 0.1275574928149581, 0.21976649370645324, 0.6296454586328999, 1.8359829076836187, 11.9311430569618, 30.674276198110274, 37.89634027788716, 16.665266367696947, 10.918217435959848, 21.69808307001668, 50.45215314434421, 54.67702827145977, 48.57657378719699, 33.06332911214521, 30.154877901077274, 40.55814304659444, 50.5359741949266, 62.04510650327129, 52.531699672822036, 74.22137906474453, 70.94833374023438, 47.855846112774266, 7.574146812961948, 0.10026754105403539, 0.18883681225199855, 0.028721132323205955, 0.05138266621337784, 0.03881825351967447, 0.07826447697176088, 0.03851037810466463, 0.03477550795181625, 0.053270348993640755, 0.032160290622062264, 0.05323944117633566, 0.009857773303895468, 0.03144790546127385, 0.043913657521648754, 0.03474826203478921, 0.0628393808860452, 0.10106670099400705, 0.016243465680388675, 0.05317432753321144, 0.01585342925071957, 0.024879724237947695, 0.029442664573810277, 0.06488064514292825, 0.025404429348606258, 0.02606715860536262, 0.025989360461432128, 0.06285860969294464, 0.006684100859978747, 0.06570219783292663, 0.026677525752494415, 0.04885594353019711, 0.09016817330472893, 0.07506747715054982, 0.00993317455023287, 0.035301113215785836, 0.035006353226039684, 0.005973437481800155, 0.06244304912885832, 0.05144454313502197, 0.008185015533179527, 0.028934370981709614, 0.045018566982640375, 0.06663495584601356, 0.07757645340696459, 0.008840193078222295, 0.01706068231273563, 0.017280720001567277, 0.03816994012243325, 0.032820348147182696, 0.02860200948141996, 0.04966168033499872, 0.032255603451161616, 0.019665046091822368, 0.010372321046287976, 0.06603826528354999, 0.0709924639593209, 0.03464592034898458, 0.04540563290638309, 0.019734989919309175, 0.035273227615342025, 0.062014591474566734, 0.03987518672440802, 0.02924292821497206, 0.042353530955170436, 0.052596448259728576, 0.11522735363893932, 0.057862866069039995, 0.06221310017750629, 0.062173351705555, 0.05114783345150852, 0.021937837441181465, 0.05677099925495925, 0.04034669852004417, 0.08017496235909001, 0.03332360662640103, 0.05815975961365527, 0.08009352721273899, 0.021384505540012352, 0.043783330643970164, 0.0929961868772103, 0.04848802214368217, 0.028747351682414452, 0.05015721281750068, 0.06040705555689432, 0.04561028180403575, 0.06650178678213589, 0.13972064780612148, 0.08074834852689698, 0.03339404075015937, 0.11018610439233242, 0.08085118050897315, 0.18248827226700323, 2.083680706639444, 31.022502260823405, 76.68763991325133, 96.04188519139444, 86.97633066485005, 91.05776863713419, 83.16028810316517, 100.18942294582244, 81.47851697860226, 58.257159879130704, 38.43496407231977, 18.886545781166323, 30.265780956514423, 43.84316336724066, 67.06940773994693, 60.53487239345428, 50.333387697896654, 39.93861252261747, 26.18849873542786, 10.238362819917741, 4.733413852030232, 1.722739913290547, 0.139519396508413, 0.46548715762553683, 0.13820762415566754, 0.19789356497987626, 0.12083201458857906, 0.06368396600948707, 0.05895666342468993, 0.08018106041896729, 0.07204198143294743, 0.0958365191435141, 0.08161342267187373, 0.15263158888105424, 0.03088086633191955, 0.12990413504021783, 0.09552685108276145, 0.10360514099198966, 0.031999004216143684, 0.48154197032413176, 0.12718898920162072, 0.09180389359713563, 0.23930522913654007, 0.2526296431859655, 0.28280779238670106, 0.3306661630349775, 0.014994591061446457, 0.2874421340323264, 0.08370935496303343, 0.20301132342748104, 0.2205081127824322, 0.052798404358327396, 0.1429535235248266, 0.35139561360401494, 0.31661411867507044, 0.22330175965063034, 0.18194917619468706, 0.2847736046439217, 0.02900893431937983, 0.07079530357112808, 0.02567705705821995, 0.08829896473476002, 0.21552869449219397, 0.6765753920039823, 0.878600622377088, 6.99297510808514, 22.12369553504452, 23.22733283042908, 12.015607376252452, 13.750863940485063, 33.79931088416807, 70.56633410915252, 55.38667132777553, 31.807092005206695, 17.439259829059726, 28.37551820662714, 58.55445200397123, 77.83696497640302, 94.23802637284803, 76.92610433024745, 90.99978031650667, 84.34965272103587, 70.12152948687154, 21.592771353260165, 0.9035486739970023, 0.17539317959979658, 0.20443908149196258, 0.02156859072255752, 0.07614938482161492, 0.13750636259153967, 0.02745943530763109, 0.04509069799115101, 0.04046035915493004, 0.04346197974237223, 0.00649663818729741, 0.05659012589603663, 0.026591808174646674, 0.06909722372168495, 0.03834483416510686, 0.029861990460044438, 0.13182985025548166, 0.04950486979777775, 0.006782888376619668, 0.045504416113779436, 0.07540703030122865, 0.04990983536587127, 0.029275933197969874, 0.07795014343554936, 0.05330040262291028, 0.05287415896271987, 0.05494046663384765, 0.013333185756158446, 0.009557873821787296, 0.025797313710133878, 0.029368444060486172, 0.04040259229499967, 0.10612069028279475, 0.010657337355247189, 0.049969379549785975, 0.0616239057853818, 0.011699965783214618, 0.08723223326547493, 0.029891266510070815, 0.0076320810401211345, 0.008563153659774652, 0.045986791036181876, 0.017042259813376495, 0.012214297105768516, 0.03844658979364941, 0.058981323794972514, 0.026019864167357167, 0.16153172259369206, 0.14154952950775623, 0.1447411437308596, 0.1656898946291016, 0.056813520965196436, 0.07567083267795463, 0.10354665783985008, 0.18079886453286295, 0.20164840704491063, 0.21494524192906198, 0.07846197443864039, 0.18244161751241456, 0.2663117743307545, 0.14463151654889508, 0.21754718295508818, 0.07796655303888744, 0.09455315333100096, 0.11137544823389862, 0.22961562649617273, 0.12216502289858558, 0.14956265597814514, 0.1550170334596788, 0.18836176113015224, 0.09375859757945423, 0.1562504043742534, 0.19034873273584152, 0.15443434698447106, 0.1399700860342672, 0.18097901776913675, 0.10589478627568293, 0.20088553668991213, 0.2459497242084434, 0.20587499073195845, 0.2597987705901746, 0.11693776750396337, 0.1652170651622357, 0.17592767914456708, 0.23854459575828046, 0.1307918470833571, 0.18851125552769632, 0.16793886830489482, 0.18983755290748613, 0.17726914506525765, 0.23343079032436495, 0.4361720677585371, 1.040564602421176, 24.657652570355324, 79.57029173451086, 109.32621555943643, 97.84709330528014, 95.58992616591915, 82.86181926727295, 89.07089987108785, 72.03058627343947, 57.5818532513034, 60.42588541584631, 49.507834680618785, 62.009711034836315, 63.72273952730241, 86.3985106252855, 81.70003675645398, 68.87248208445888, 60.69911772204984, 45.52687606503887, 26.56799589433978, 15.614244726396377, 7.195011002402152, 2.2079313426248492, 1.9281306598455676, 0.49965526127526844, 0.453621803993179, 0.2676148592464386, 0.2726443183998908, 0.199153381249597, 0.1745954675660018, 0.17287305676408354, 0.7594309266536468, 0.41796500764546857, 0.5792043298002213, 0.22377481894387355, 0.33538106648672017, 0.2921157606667088, 0.6390704851477378, 0.5293556014376303, 0.6646746144660058, 0.4967349647514282, 0.32003038052108984, 0.47774428862237167, 0.4205983276328733, 0.3873809390971738, 0.5570162784668707, 0.6203818008784325, 0.8565906711643743, 0.6647938177470238, 0.7190126180648805, 0.5879794686071335, 0.7278940898756827, 0.5868055154719661, 1.1301791163221484, 0.969240774791087, 0.7246823428619293, 0.48072666891159554, 0.5395191367114744, 0.17888131581487196, 0.20133080231326245, 0.17270991067972877, 0.21109480741283587, 0.5432520686618744, 1.7004561928972122, 3.747889173607673, 16.42677253292453, 42.115378918186316, 57.098342680162006, 31.65647691295993, 18.694632053375244, 28.993903398513797, 74.15161578885971, 80.88458384236982, 68.7386586589198, 44.47848143116121, 41.06420332385648, 52.24710818259947, 64.81040885371547, 81.00353364021548, 71.05883475272887, 92.59270191192628, 96.76815125250049, 73.34618060819565, 17.372081395118467, 0.4105916565224048, 0.3750506926688456, 0.3078536581127875, 0.1328885684450788, 0.1572284228619068, 0.3328885228162812, 0.11554948595022002, 0.16591206012714296, 0.1427877420980123, 0.2343808159592652, 0.1239444612855873, 0.15514641038833127, 0.10266909646170755, 0.19788420338544155, 0.14203386561524484, 0.26306564529095927, 0.24864305952383628, 0.1935178699392465, 0.13038369075905892, 0.1261212158527586, 0.18713911544651757, 0.14026081640153162, 0.2544708435814227, 0.159096788735159, 0.10769755970085822, 0.17747716858021675, 0.25385613463098006, 0.10117979089338934, 0.10369478860088896, 0.10932145159571402, 0.16276895459140503, 0.17182388403002294, 0.17309300060714447, 0.146040199024062, 0.2221358351169094, 0.17538568725989712, 0.1309800748863528, 0.1994418286748471, 0.0983120326793963, 0.07974864209010717, 0.1655818149447441, 0.09893614152866988, 0.18334940105916994, 0.11599572450523415, 0.10664552945884005, 0.18166682682931426, 0.1790821840686183], [0.08679475875631457, 0.03467816498971755, 0.01588039746087405, 0.01689188058427986, 0.055881904423116684, 0.026387965584534313, 0.007944236492602936, 0.043961013246688156, 0.043016541749238975, 0.022782575782208193, 0.033937978498156995, 0.07889170379888627, 0.06865306126494562, 0.027512521370344108, 0.02534166376496996, 0.06184267751391857, 0.07171024237909625, 0.054730298072700544, 0.03439432558333201, 0.04939729573145028, 0.08551489396561539, 0.047936323925011584, 0.06670675360627713, 0.06698172554493913, 0.049462183378636844, 0.06441970536064717, 0.01585475745565829, 0.03681799028849891, 0.030365455783002322, 0.08177267702957315, 0.05258892527631214, 0.015595339017079003, 0.09709641202202729, 0.0790503835906425, 0.012863268381014708, 0.056425443805393674, 0.014014898671678478, 0.02018276448061149, 0.038548494809337204, 0.09785100096656431, 0.05522322585625995, 0.019364929232265682, 0.09939164208668856, 0.1820191966309663, 10.369052271689139, 39.926943471354825, 81.20941885056035, 81.28039806119858, 73.10141686470278, 65.54280557940083, 61.407603679164765, 63.7393742992032, 45.510002028557565, 39.93137574964955, 28.811287649216194, 50.30798642866073, 76.31466957830614, 78.25793727751702, 42.78486082630773, 31.77759382032579, 27.667302893054103, 31.87137180759061, 15.793815735847721, 2.3005654686881654, 0.15740810112366754, 0.3697168821048352, 0.2504296072067753, 0.07489497713263958, 0.09275075528890857, 0.07163338077765319, 0.14319421302887703, 0.09036919477606013, 0.1506700054291756, 0.11585618158982647, 0.151310546864425, 0.15958434241192956, 0.058536858733503096, 0.09220415155493444, 0.08104003650406677, 0.1483055056944009, 0.11858610526448297, 0.137238216496283, 0.10736074148406906, 0.09049875556581444, 0.01335896940286001, 0.33139946239609874, 0.12275944584079328, 0.4367315264478807, 0.21230718751828517, 0.10516460489241347, 0.038915722886280674, 0.14052326280263164, 0.03109280072573212, 0.08403394641655107, 0.013690175067993903, 0.03934554800751709, 0.03833650678936993, 0.00909916048253616, 0.01531009383935241, 0.03696219101848622, 0.09571792107195624, 0.028781720301917488, 0.025329990500223734, 0.15875338216222104, 0.059621918856376604, 0.20772927590916235, 0.1616080249509504, 0.09602116931590343, 0.03670483527164306, 0.07807192843287222, 0.4368150913186612, 0.8075676017230558, 7.598028163756094, 27.752316344168882, 32.76729410694492, 24.751252089777303, 11.498278129485346, 25.055818250102384, 52.453487611586056, 118.87939130106281, 63.08795882809547, 26.615450689869544, 31.564010958517756, 35.244237530616026, 45.12683353116436, 40.6898013237984, 52.39922554262223, 68.37293686405306, 68.7751994594451, 30.097193564138106, 2.8996479415124465, 0.08465365792113928, 0.09966459155323044, 0.08728568321995198, 0.03110620343396741, 0.03814062576801066, 0.04448697857198216, 0.05738562393573023, 0.10775166849095015, 0.09365252504545836, 0.012778896245083982, 0.05440866371857063, 0.05005365305189645, 0.0066490523374429155, 0.019009719159634366, 0.07364681306024713, 0.07668467343694742, 0.039658372350517786, 0.07064050018426872, 0.12623637418953643, 0.11521842871462146, 0.032076193320174376, 0.09989912937124891, 0.014771018834454159, 0.06335143022419465, 0.07822352957220809, 0.012479263936139405, 0.008952760122596257, 0.0652314751078525, 0.025002438116878755, 0.02435221141504665, 0.03182250521926871, 0.12395301082682227, 0.024501062298734343, 0.050231036880323966, 0.05613501987329895, 0.018940265628419096, 0.060720247622098655, 0.02709402668950779, 0.058906499987408045, 0.03920582889188682, 0.060299504473204577, 0.030700521573664683, 0.02707432865375473, 0.007621259090580768, 0.036241083946679874, 0.056925208923677285, 0.05055270570841047, 0.11584494307997728, 0.047912349203421224, 0.009546074152533567, 0.016642484490969972, 0.027688145111765594, 0.02647315264649449, 0.049353486993500305, 0.002760918155658029, 0.0634150116914703, 0.04639377524595588, 0.04604573384107602, 0.04413769610466496, 0.04099687734138101, 0.0342784739369827, 0.042972418915240035, 0.07085036997112536, 0.025566880208169742, 0.042088211724354375, 0.021354346573653243, 0.11553751199596352, 0.032570772023210605, 0.05781115130371144, 0.03995939127860531, 0.0734511005782312, 0.055972298967742154, 0.035849226142970786, 0.07579053391612346, 0.03893626936440987, 0.05459397655701446, 0.06320113526476968, 0.0722753931017172, 0.05437626969069243, 0.07510297766496098, 0.05434823853354301, 0.055150313438066555, 0.0467601184913468, 0.015826151732565658, 0.019322279202301177, 0.029503189350268053, 0.03657780257203887, 0.045484049666312434, 0.7692458612784263, 26.930819057649185, 68.15541790377709, 97.73048908479753, 91.38707514732116, 89.18489963777604, 89.03639085831182, 89.73192907148793, 86.3187688396823, 57.935407853895626, 36.18760678075975, 16.516839958006337, 38.50116191371795, 71.28166460221814, 82.09754543919718, 49.53365956583331, 33.36412783591978, 25.644797432807188, 23.282618638007875, 9.104577206796217, 0.4757736959765035, 0.49450022498926816, 0.25075566954910755, 0.07870235750752111, 0.08419789689322633, 0.030955646089428378, 0.10418239590381423, 0.07869459703684815, 0.08574860440867563, 0.05038571769311544, 0.22929170920002848, 0.27247774024163524, 0.2124746543385329, 0.023994335356438835, 0.06943981824142319, 0.057579264149910984, 0.1646265645902003, 0.07697483689914789, 0.09446567375092738, 0.22818322593887008, 0.16956251505161488, 0.06839479004303295, 0.4216043849385554, 0.1607839135272849, 0.507136355004003, 0.19772741583085832, 0.3796908872262124, 0.25854949569029195, 0.15205375940328644, 0.13501578010618687, 0.038650671786238114, 0.042198444115779096, 0.11180123224133447, 0.0570941619544981, 0.03751811421205921, 0.05531483081980579, 0.02947570020032506, 0.030501635572422418, 0.11078261109369417, 0.03731864406877468, 0.19356720600157015, 0.057446405351642645, 0.22801157627855578, 0.07955659916924854, 0.1747781795359427, 0.04867338094740145, 0.02754472579146105, 0.2731536749389864, 0.36509697355570336, 4.920105924529414, 15.420409037220864, 11.254944089920292, 8.633931029227472, 10.609538670509092, 32.18830520106901, 63.87930877747075, 114.80134225660755, 48.97048565649217, 8.372398172655414, 27.021843541053038, 46.60328426668721, 69.97002401659566, 73.77760210344869, 75.8568819107548, 83.93645455760341, 89.19816509369882, 53.16955551024407, 10.208661652380421, 0.5699333176016808, 0.16501201406842278, 0.0709412433207035, 0.06545640618330048, 0.009660746981089395, 0.07811023282908625, 0.10439081778449398, 0.055567609191301374, 0.07591529133459253, 0.10314943359023142, 0.051163626354067564, 0.055220789696660735, 0.024141466372736523, 0.08037583061283635, 0.01580811706521819, 0.04066622230194269, 0.04490961395804921, 0.03176908207786901, 0.04619827726855875, 0.06463447044933997, 0.08246477618212662, 0.031392151497364525, 0.026224059157914696, 0.0333224383423165, 0.06920219308906986, 0.007768873221075704, 0.0801622529604262, 0.01832171474703618, 0.032642661714025085, 0.023513827773351825, 0.04275101950512298, 0.03948449337434384, 0.018078315206953598, 0.01591032181280635, 0.10116358047291156, 0.024738972818839456, 0.04707455161898848, 0.0635401291712638, 0.07302266590657734, 0.03223598776986042, 0.0348551427915452, 0.07837176758555636, 0.08302951321726845, 0.03629787404450678, 0.018886804182623184, 0.2609752977807676, 0.1143348458853941, 0.14134692989530104, 0.163695277465928, 0.18486470765163823, 0.12488252062711025, 0.12886649959029692, 0.14842765075304817, 0.1793421636666021, 0.0868724400718366, 0.11798758375188036, 0.1707594508245107, 0.23480504480821474, 0.1310269135020433, 0.1543708382955482, 0.0842510097690167, 0.14629015819199626, 0.25443310609027264, 0.14738679773384525, 0.16592290793215075, 0.11901381215260876, 0.25121844794240694, 0.21461268316113183, 0.15229964298346352, 0.12018343689100397, 0.2700850331494885, 0.1576666711198707, 0.1713228625275435, 0.11636446560582808, 0.16443619174101662, 0.13254543766379356, 0.17393156044906186, 0.22980458974357576, 0.21123731508851054, 0.15027277351867768, 0.14021299719329805, 0.17668587636322747, 0.13887945262174453, 0.1548000160724886, 0.19412611310760822, 0.14077018826238571, 0.14197029563928806, 0.34160280359848855, 0.24552030128336724, 19.868687660463397, 71.85821379384687, 111.88442460952267, 103.39960052121071, 90.25556548949211, 90.95213136365338, 83.80143873153195, 80.10923324092742, 56.90575430470129, 52.51143670851185, 43.80740704074983, 68.02436367157968, 104.76268691401329, 110.1787740953507, 64.12691231696837, 52.76691636731548, 45.992645755890884, 43.81109799108198, 22.920105341942083, 5.049871658125232, 1.1143468368437983, 0.493273840796563, 0.32355573328752674, 0.3419854491949082, 0.1733467902147001, 0.26866605445261926, 0.3442155924295226, 0.27317690272485057, 0.27914478894202943, 0.6432105468646173, 0.9077641187656311, 0.3958633403864599, 0.20118218125595203, 0.171930278320947, 0.2778759634783191, 0.4795066585704204, 0.5094395217395599, 0.7080716567654765, 0.7120426888427427, 0.4565718247284813, 0.13909964161294122, 0.9220922305699318, 0.3523871152391357, 1.2983697364407203, 0.5935157102442558, 0.5713926231668842, 0.4681452069311373, 0.4430785342570274, 0.3451706895664815, 0.17446520197535717, 0.09482791076504415, 0.2887823282470626, 0.12061836798825573, 0.15899474582364484, 0.20550028180643437, 0.1378655505757178, 0.19258535707429533, 0.29254130718688814, 0.22575909392006938, 0.43276573441201643, 0.3297424448593971, 0.552305757038055, 0.365762795892454, 0.31536842906667345, 0.14676972923259582, 0.17500999774183, 0.42473321059538477, 0.9994447411548708, 11.388403715625888, 43.95771618812315, 51.51003599166871, 40.121077260663434, 20.011601178876816, 35.595042551717455, 78.35407457044049, 153.56102758838287, 79.16687596228816, 38.99660433492353, 40.460181851540845, 46.12642211298789, 60.43638952316777, 58.20150929112589, 69.84549660836497, 90.37470356110605, 96.23339883742794, 52.77774603136125, 7.515342149042315, 0.339779544982218, 0.4587773612189678, 0.19794126161404196, 0.12610053913968225, 0.1762582614056526, 0.17919654567395488, 0.1467746628388282, 0.26428914899306916, 0.21133295350497772, 0.14061980520284947, 0.1095163826680472, 0.18684066291297638, 0.11585454216166852, 0.1520596736020619, 0.21574727469874969, 0.1238174285859831, 0.0990389122237121, 0.2567457110290566, 0.15571732975302205, 0.18887032093780656, 0.16853387347392498, 0.1645010334229277, 0.11096687822212135, 0.1425182630097674, 0.13131263365428295, 0.11416257569386114, 0.19498745640439374, 0.15462344812770046, 0.1098141227398188, 0.11639919237143571, 0.13870501440138588, 0.25154319261350944, 0.06791934821634524, 0.14026401864905513, 0.19746728301528962, 0.11058719738596871, 0.1629617789219464, 0.19362464727413273, 0.20658398978412154, 0.16650190186356345, 0.15779163538207933, 0.15645130327151668, 0.07656845023795482, 0.1028053758425578, 0.1630947717856015], [0.02734334808924506, 0.0535058674042023, 0.05200274160973007, 0.029582590533180103, 0.02903921585980683, 0.07040551803525417, 0.028356608536635197, 0.0472995593032289, 0.018517745155540687, 0.03397162891023102, 0.012653189835198706, 0.025123148675887816, 0.031330148171212886, 0.029401249860623674, 0.038219670720037915, 0.004895685358919324, 0.024352795557088913, 0.0503454597726945, 0.011679181817828888, 0.026969633162802747, 0.041007966464084965, 0.06709467754849503, 0.034937635139231725, 0.053806097261727824, 0.08379612974221669, 0.014830618559743368, 0.0594356254253897, 0.030317332054818832, 0.06206175950806468, 0.04535322866192268, 0.004816749095616322, 0.02764161676168442, 0.024759256911854592, 0.05678663893993344, 0.044649304942257946, 0.042933275652748924, 0.026349703323156125, 0.020220478989123818, 0.03829466689738535, 0.08845837231004432, 0.07832142794805189, 0.1353097127209748, 1.5722578139074388, 29.408531265874064, 80.93781040560815, 83.59159192731305, 77.27981582764657, 69.72983375672372, 65.70434839494767, 53.13006508734919, 40.53698970425514, 28.104507923126224, 34.499473571777344, 48.76630667717227, 65.62236693597609, 58.99554998643937, 27.987421251112416, 24.643175102049305, 28.166853997015185, 27.933718119898153, 17.238108919512843, 3.846129102091636, 0.3527745718677198, 0.08045356555451309, 0.12888143830482038, 0.20916849464899112, 0.12253311282444386, 0.10856743721712021, 0.044237789322411826, 0.11239528746133852, 0.05905443539602622, 0.0924619707849718, 0.0787550107305569, 0.05984360937990489, 0.03802206217040939, 0.023185719976261742, 0.06679865351367383, 0.03217428704843887, 0.08233876237946172, 0.03267106059337816, 0.13089330776804878, 0.09948181829625562, 0.019805402975649606, 0.12511593995675926, 0.6154864377552464, 0.044467190520897995, 0.2193793894783143, 0.5194605646594879, 0.19542483132212393, 0.22998025370461328, 0.15000778370566908, 0.08587585927377786, 0.08500049656797802, 0.11549635775267117, 0.12871380294522933, 0.06478611755395128, 0.017502255392290892, 0.14908576624528055, 0.1644524940920453, 0.05999609918123292, 0.009180809175896068, 0.08252928844623028, 0.0980239223328329, 0.06755334971052024, 0.03486472655147795, 0.10378045255258199, 0.04013173807893069, 0.0279536520341231, 0.12866344032508711, 0.10597736289304112, 0.3575104661285878, 0.10335541931131195, 0.6746172712695214, 0.7022840770021562, 1.5987622497543212, 18.046989902373284, 40.00810907733056, 24.09278223591466, 14.779238797003224, 20.14732107039421, 56.63224351021552, 83.40065094732469, 67.93367847319573, 39.610188545719275, 25.755700488244337, 30.545087052929787, 47.11024668908889, 55.3889423801053, 61.37716216425742, 65.60268448245141, 48.37164563517417, 26.055724543909875, 2.895736112709969, 0.07072984901887756, 0.17467739300862437, 0.07804699993181614, 0.05363567717253201, 0.11990437404282632, 0.07340695859203417, 0.0763135881073052, 0.004506055434655038, 0.014866188022067711, 0.031872760587101506, 0.10999759313680472, 0.10691795798559343, 0.07674496455658829, 0.07900432638463475, 0.010245950055128385, 0.03116643326657434, 0.05415452554100945, 0.024019809695140972, 0.036642632762631105, 0.03440238482829544, 0.05893579902007215, 0.0179747803392069, 0.06311247207885308, 0.07467521715068048, 0.010620586202299644, 0.015132640105401798, 0.14859851900367968, 0.031679112712041504, 0.06225030906798859, 0.08837407199485649, 0.03300718167015622, 0.051801812068949786, 0.019631828519425566, 0.0319682419555442, 0.08329210517507407, 0.04517986679509763, 0.07349770936754442, 0.011495473933586431, 0.07657982664363039, 0.033448203166406, 0.04251982949133362, 0.046835643269361994, 0.019672728038483092, 0.07611386898544527, 0.036748835531574105, 0.009980463242578891, 0.03309374577516029, 0.003061943787014893, 0.0484037141676151, 0.03802937064920703, 0.07720241863881389, 0.02696199335097786, 0.08729388802162102, 0.07584203034639359, 0.04409465345463926, 0.02213732482144429, 0.034171095223075924, 0.0558750172926774, 0.07801789625157272, 0.04204847857416157, 0.021073784108363816, 0.06113190496821077, 0.0489592619781052, 0.06788907242157767, 0.08336270017729652, 0.04913484549991066, 0.09457890154613603, 0.0068847651428152485, 0.05201569232609003, 0.06924255060092097, 0.04444518081483342, 0.09798954030679119, 0.04501821458219521, 0.05652497777895582, 0.027446553539184314, 0.07391973188327206, 0.04707994870841504, 0.04118683267264597, 0.02532598577559956, 0.04484525108109078, 0.040447006242409836, 0.1414514089664144, 0.11524083678640666, 0.13550023878774337, 0.3097085714820893, 8.7125971048109, 52.6096018668144, 98.19751785647486, 95.2758070730394, 93.78405909384452, 99.39832795050837, 96.99474657735517, 81.5559288763231, 59.62290563891011, 27.606206094065023, 18.72626793000006, 31.830936093484205, 75.52861090629332, 74.78889111549624, 36.75477758530648, 20.768136170602617, 20.279593198530137, 15.801477105386796, 8.860180204914464, 1.1425703739927662, 0.30987971552437354, 0.02657500212080777, 0.14816028606747428, 0.24165262978884483, 0.1554832439268789, 0.06026062168060772, 0.1775550644003576, 0.03130597235154241, 0.1015501867438997, 0.08453316761240845, 0.13114087674165928, 0.01271337561774999, 0.04753785478251596, 0.13044935981592826, 0.0684083114948965, 0.013850599624997666, 0.036418927427861965, 0.0425217408807047, 0.16181969504442908, 0.03153760478110804, 0.032131196517917904, 0.07182694821348114, 0.3280310657235884, 0.20267819775448692, 0.4401570426360254, 0.4095745062635791, 0.09379347756264672, 0.2989264355311471, 0.18066303714388804, 0.020589200937519633, 0.07002532392019226, 0.22063044170218132, 0.14345204758067287, 0.2050166351780776, 0.07504126162178094, 0.11932442250150828, 0.053495429456233985, 0.20473947988883143, 0.016184065137959776, 0.11093159987320823, 0.14540771683377607, 0.031193052906723275, 0.024749046875043743, 0.09945268397249522, 0.026187011145896492, 0.09681869748859637, 0.1529448728768095, 0.14869077131152153, 0.33787612292555075, 0.11025345118175592, 0.6380465626716614, 0.5456403630875772, 0.9856052095851592, 7.497513505720324, 12.937787002132787, 8.535476596124711, 9.815258710615097, 25.027757613889634, 74.2583905496905, 76.25322172718664, 42.35664390748547, 26.98036643766588, 20.878847029901323, 34.637517467621834, 74.18745840749433, 84.25683375327819, 79.64446375446936, 84.45114797161472, 69.11211536776635, 46.8542649669032, 10.784848024768214, 0.2673335517606428, 0.19193151635268044, 0.07079292869856281, 0.05931327735344249, 0.09805381508363832, 0.08797673283204918, 0.0157935508609479, 0.0352721665835669, 0.061970648671230005, 0.007329816261546747, 0.01368507196480829, 0.07423139943350708, 0.09397798217833044, 0.07057681529512329, 0.0068434375721300325, 0.021071211968158043, 0.01074344468032641, 0.02239342226887182, 0.023269667891004396, 0.04825132012727761, 0.022658871734635006, 0.04954079166054726, 0.029957360745738112, 0.052221325646725394, 0.056585831973221035, 0.040289353008472154, 0.02817440218472433, 0.040706277209063696, 0.03428856331494547, 0.07539795982020517, 0.015863850919319498, 0.07510103946251255, 0.03938325485515018, 0.029163482982004364, 0.003821503923973069, 0.05270543575827634, 0.06643382712237297, 0.020185937999837825, 0.021300712758074367, 0.01828132659166811, 0.018434178369540363, 0.022386086976996834, 0.002124742942772085, 0.1464937690405115, 0.18443315500213256, 0.10366786061035049, 0.29442229818913246, 0.13788277223225565, 0.21480613568377113, 0.13771443207177425, 0.11745503007043755, 0.08860824975155054, 0.19883433627265118, 0.1277261930367639, 0.10962521311857047, 0.17621016640576626, 0.17142069195547413, 0.1213268077962341, 0.10507373920371456, 0.16274477685651473, 0.19744541886593067, 0.10983740415183768, 0.11807193769322288, 0.11326197039095626, 0.16563269850467482, 0.23992222102899707, 0.18194516189396384, 0.19207285957471018, 0.1471694432679684, 0.19468989253284472, 0.18013812901992954, 0.3000165173603643, 0.1759320152022185, 0.12668260508367132, 0.08811068330560962, 0.15966965396317745, 0.2452584217873312, 0.18904904925054122, 0.10611325922992923, 0.13552443184439214, 0.11552834958438912, 0.30407335128515, 0.29287293132755066, 0.2681961974068996, 0.25981605353374637, 4.933892565388834, 52.31596146860431, 113.12119499329599, 106.09512390628939, 97.93096926904495, 93.0735452713505, 90.81179680362825, 70.17004136116275, 53.121851644208355, 40.10923170274304, 52.81970754746468, 65.18858417387932, 94.90467240733486, 81.37266789713215, 44.10159264841388, 41.52412476078157, 47.35714812432566, 42.877264022827156, 22.49795044622114, 6.6962845767697985, 0.5102326678893259, 0.16887567126222197, 0.3444559601766448, 0.6010060276715987, 0.5382455921461505, 0.34616599099770673, 0.40401497555355875, 0.20151616494742133, 0.12405299296182011, 0.3769304885739281, 0.2567546742577707, 0.15001158350177352, 0.23175367064053015, 0.2074104760803523, 0.30604909204186936, 0.2767927764404205, 0.3090969268833437, 0.30631474069049286, 0.379293165019443, 0.2563061604216214, 0.15667208981129432, 0.7340262253438273, 1.4250817822833217, 0.8371818642462454, 0.7805329104585033, 1.365175545215607, 0.6795684055935952, 1.272443114749847, 0.5250289819894299, 0.5105343839574246, 0.8133217187658434, 0.6296941205378502, 0.48491937619063163, 0.326818808192207, 0.3916155054203926, 0.477341418304751, 0.5019612778579036, 0.5540880452721351, 0.2128512325185922, 0.3000982742636435, 0.3191609320140654, 0.21852746906299747, 0.10193702284126513, 0.3043775494781233, 0.11472438627313222, 0.28534354341606943, 0.4190655695574899, 0.5112247517512691, 0.8215742017472945, 0.24430056673384484, 1.0773429514900332, 0.967850171990933, 3.6989818753734713, 31.173342889355077, 57.78935055578909, 35.38896122286397, 22.42638876361232, 26.657400438862464, 76.02934852723153, 116.12758974875175, 87.15724606667796, 56.56615157281199, 37.69419308631651, 40.064042075987786, 62.51857580677156, 71.04956226964151, 77.46000166862243, 89.36421471257364, 76.85481917473578, 45.83683744553597, 8.572275292488838, 0.22263917020492016, 0.32639246494058644, 0.15687657400004326, 0.08195238593485087, 0.2524031875955482, 0.16741443515544938, 0.19724098064245718, 0.1428772518110852, 0.16773931772237824, 0.09029606402280832, 0.1376656322709976, 0.16124310662909863, 0.14975719634563694, 0.15253428039291214, 0.14230904439764638, 0.14865709408637018, 0.14320887595174775, 0.1536741885807245, 0.12535529646782145, 0.16144697794750815, 0.16914142716315486, 0.16626455250286287, 0.11139291503857221, 0.1629076931144922, 0.11617382462587088, 0.13573366577827162, 0.22785488065452347, 0.1512674007925295, 0.12633172915347163, 0.18513153607566513, 0.2123439903821676, 0.17271626920950028, 0.15792062926676967, 0.1819754223669729, 0.17634274558194224, 0.17915252626182573, 0.1843770007572828, 0.08450566505592677, 0.11839178706248922, 0.07039926675779205, 0.10245023280261986, 0.0794077406246816, 0.27979467664995505], [0.04367299483067567, 0.018668777474592772, 0.030672210794422897, 0.020288838929827177, 0.05502275979867386, 0.0987411032040273, 0.028864386934606783, 0.025378164024122303, 0.04147572059845252, 0.011129151755613426, 0.05217702661250388, 0.024181189946830276, 0.039255984668289466, 0.04244736523457593, 0.05576637453369557, 0.03170373477792788, 0.03118203656237212, 0.06170614915449293, 0.06787994065352025, 0.07248733132596939, 0.05172702273534191, 0.04177625689114775, 0.048976219334309144, 0.008011181085866185, 0.055876725668748545, 0.030738222675638336, 0.026840690989047292, 0.05678057152357313, 0.032890000861258276, 0.01608489697138148, 0.024970099630375064, 0.10849834374722936, 0.020704068160886248, 0.05440538869269433, 0.015912675617953703, 0.02107708211687784, 0.031817998707054124, 0.02764230049515684, 0.017600812603749575, 0.3770098552828835, 0.8448966147918856, 22.23996635406248, 63.930589845103604, 82.95279472104966, 81.52239261134979, 68.6842946083315, 63.10041627576275, 52.73432931592388, 24.98678649625471, 29.13459881659477, 32.94509318567092, 57.617319322401485, 84.32629108428955, 57.619531539178666, 28.208478189283802, 16.538097243155203, 33.599309229081676, 36.21882100259104, 10.688601886072467, 1.6117501979874027, 0.2351621796767558, 0.22136758682468247, 0.13512188328369973, 0.09485804100310612, 0.055749463142767075, 0.03786874499412314, 0.01828009510532983, 0.04478646532422112, 0.04495145768047341, 0.06530989952866109, 0.06846577575009677, 0.01810700136927828, 0.035693717955221096, 0.0916034390308684, 0.10329827681303987, 0.0641031233563779, 0.005927213651668882, 0.029161981449672775, 0.045469589756741646, 0.05097107781517891, 0.08204960249244206, 0.04895451223297466, 0.06715162852478605, 0.03781591940130438, 0.1781275619061724, 0.024651075720847137, 0.342457328712748, 0.324752178764151, 0.0651454970601105, 0.14148454993001877, 0.11728902647812521, 0.05992954146237143, 0.00426474156894631, 0.12276034216366469, 0.03310578484689036, 0.07238561017138344, 0.016268097322374102, 0.05358827931265678, 0.05133554797559496, 0.03287481316815942, 0.051155632226577694, 0.04772307569040887, 0.08844508068455804, 0.08346107352765338, 0.10956376520616394, 0.05080993505074613, 0.06559436329670491, 0.013623377946656079, 0.08433763899149434, 0.027870064180704857, 0.09272624813621083, 0.12180686147222597, 0.535967736955612, 0.3646351451114301, 0.061018267315962625, 1.0297074817842053, 0.5932508276835565, 16.009629445691264, 42.43956281292824, 30.948898984539895, 7.7147706477872795, 20.024260628607966, 59.51497377887849, 73.39323336078276, 60.83745187328708, 53.65516454942765, 26.025887074009066, 43.81567931944325, 36.755585593561975, 52.24537841735348, 59.64028958351382, 72.52056091062485, 55.33718670568159, 16.83839390354772, 0.4601982091703723, 0.17756634121460302, 0.07983801390735373, 0.06268805170792245, 0.060605522124998035, 0.05080730736916585, 0.06314229588174532, 0.12028549512427662, 0.012148549524886955, 0.02090316866674731, 0.03684461950474689, 0.059680965083140525, 0.05625768587173474, 0.030141602976307757, 0.04194244051412229, 0.05701797451042841, 0.037197598346298745, 0.024407247171526956, 0.044764041930677435, 0.029091510936738025, 0.0710581100335525, 0.04385174612604803, 0.03132906224158022, 0.038051901295060114, 0.060995012717021097, 0.04480144617358043, 0.026167332262341535, 0.055865985116050135, 0.06035940488800407, 0.09787466542254533, 0.015934579029318788, 0.04121964804888253, 0.014950786153936099, 0.0642166997215921, 0.022402465936817953, 0.1342614286489064, 0.04201948597666718, 0.03227697347380942, 0.01595037384709764, 0.02984268887479219, 0.062429217411385435, 0.060555500413982145, 0.10212999272851214, 0.05092820753493617, 0.029782173674433466, 0.020632682172881982, 0.004450419256764074, 0.10350010267669156, 0.03081173455763248, 0.024806654771729827, 0.052655325947149154, 0.048234094640300165, 0.03199842965020047, 0.010108948636409498, 0.05744850443255517, 0.08104878522816204, 0.04305545135491318, 0.04071115718914136, 0.10691758260251054, 0.037321501576732245, 0.03921826632933752, 0.030185796673439687, 0.06790011174856656, 0.0439757336261532, 0.016435562227402004, 0.03019561217496953, 0.059294891243259755, 0.026145033358085542, 0.05168289607090335, 0.02992634567612362, 0.05868521549047963, 0.019482571609138, 0.011190570939722802, 0.015345605845082433, 0.003398792886723494, 0.012601430062204601, 0.04610848793339345, 0.10027544708141398, 0.014587338720898957, 0.015485444661950874, 0.06638641394073926, 0.1081665893716197, 4.692238771146344, 44.02963284523257, 90.64873603082474, 100.46698554869621, 99.73267862873693, 95.78788818851595, 90.42650238160165, 76.39344646084693, 41.496228864116055, 34.681404867479884, 17.561070995946086, 43.49717501671084, 88.00063410112935, 82.01430489940029, 31.491513790622836, 10.697066360904325, 13.493246589937518, 14.091146223006712, 4.819253942658825, 0.6927404600766398, 0.22137236721332998, 0.1203225048318986, 0.08714374244934128, 0.14523427452771895, 0.14320643979214853, 0.0076012081755775845, 0.03772604579646741, 0.06932278298923085, 0.03827107521975714, 0.1397998306539751, 0.12293219866771853, 0.04433418233548442, 0.16556200391102224, 0.04294495466315458, 0.1395081043724091, 0.028097008152173895, 0.05790810739140838, 0.10524675250053407, 0.09104893693039495, 0.08722736860715574, 0.20361077190647203, 0.21088330585870052, 0.24584929008157025, 0.2015443110177594, 0.23806454974316785, 0.14360145004766603, 0.37041475756033776, 0.38898699646515233, 0.16774892446494874, 0.17786626463695882, 0.13286382380512454, 0.10625913769247071, 0.032890640544675054, 0.2726060140036768, 0.05976859405035934, 0.014651911314426651, 0.007931529487963886, 0.09827745913137352, 0.042161426747277866, 0.05104432731205898, 0.03034589181263601, 0.018762992882740595, 0.20981577765797416, 0.1943845298862265, 0.1510484988290456, 0.036287030069938594, 0.06882931511368483, 0.048642044120858756, 0.03079436351394942, 0.03327636198411065, 0.021495733845738635, 0.13915624018878708, 0.6831101832851287, 0.39142367700415276, 0.10317585596273984, 0.9396059811115266, 0.0315103761010593, 7.233987594804457, 14.5214625904637, 7.432433049524985, 5.134480124519718, 22.827205965595862, 70.86991771574944, 69.0814345882785, 41.7637070532768, 32.803983957536765, 23.87296280553264, 59.59415466554704, 64.0383412761073, 85.49398852932839, 81.45938365690171, 88.46490936894571, 77.23499882605769, 35.357001750699936, 3.1707173057140845, 0.20245756443229415, 0.08964605374081482, 0.08167113207520978, 0.03437683962646031, 0.06613874537569862, 0.10615105034723397, 0.06138720759941686, 0.03114155839167295, 0.028971164269492995, 0.018252935373194275, 0.03598402697412718, 0.038845664145605224, 0.05192357791407455, 0.02346645289611432, 0.032179848846769145, 0.08198113721464911, 0.035179178831317735, 0.03062665537600556, 0.03020917959210854, 0.054690377230966286, 0.014813933164752541, 0.020869363121868625, 0.009489322359102869, 0.06874872266405052, 0.07231440229882156, 0.013271270530118097, 0.05640128139226187, 0.06271586453001346, 0.07152241294182117, 0.04330311991995381, 0.031189580613206473, 0.029367080423980955, 0.016889415696383487, 0.01041184064947189, 0.0688896062333257, 0.03184152335198897, 0.006152339600732611, 0.015768795687284683, 0.05331568224656005, 0.07135133018657085, 0.036481715994135994, 0.18039106060900997, 0.12760187228841166, 0.19742117984400642, 0.11889416454059464, 0.18060591762825368, 0.1796160400995324, 0.11494298946232566, 0.10590788637918812, 0.09694941507111635, 0.06575949354878356, 0.10610773573599516, 0.0892940286787287, 0.12292720377445222, 0.11049227143127112, 0.13763060673109948, 0.11896571715272243, 0.29874570006805085, 0.16885285716383688, 0.12558084041360887, 0.12732600402687827, 0.15300159402672323, 0.14194754282793692, 0.09899548269928464, 0.12680514084716, 0.14255947854009368, 0.16319448578982584, 0.18433359421549306, 0.17801637190484232, 0.1759912031552484, 0.2135137300337515, 0.11920859766823631, 0.1491237488845664, 0.1279013360580129, 0.15665946468230219, 0.1522273549269284, 0.1872607702088933, 0.11529852320710499, 0.09925085810884353, 0.1146238525548289, 0.49504279910076054, 2.0868281635545918, 37.50756279114754, 94.56778003323464, 107.47098153637303, 104.13973608324605, 91.02551106483706, 85.87769831380537, 70.09619097555839, 32.43198440920922, 39.17428770372945, 44.87236976623536, 73.99392081845191, 113.40631992586198, 84.82423597766508, 36.69655392246862, 27.227214920905332, 47.90424816070065, 53.26220189371417, 17.85561157811073, 2.780644456225057, 0.36629400125915007, 0.4753125723331206, 0.2294406213707501, 0.3627269426661153, 0.20879326478367854, 0.15332650723716906, 0.19920533733262172, 0.14747699692605004, 0.13544586186687793, 0.26455939416923835, 0.3744131849417764, 0.17419403749367884, 0.37078851653683575, 0.4099725655490353, 0.40264821340960844, 0.39801684418512934, 0.14351554094783722, 0.29136263495010717, 0.1714237103418958, 0.24288900376808262, 0.33629157730648596, 0.29613873350524134, 0.38042532039746163, 0.38125523876759315, 0.6838653621173675, 0.31055920486969335, 0.7589715190472142, 1.2992338836193085, 0.45568386753720624, 0.7016552720339068, 0.5417471042563838, 0.3141839652051849, 0.2805242987890398, 0.545257380412471, 0.14788210422040957, 0.16551473628609412, 0.14316758381262903, 0.13764635749882267, 0.2695781893787846, 0.1307412546368376, 0.16653383240824746, 0.23050104027553914, 0.3395283907171219, 0.3250617089290773, 0.31715083987482134, 0.22030205045255924, 0.2045206085688645, 0.2720578627720956, 0.16878732600279395, 0.20435127249408155, 0.19028845693795912, 0.2856532267985806, 1.335568882284626, 0.9422698833288686, 0.22934037110497876, 1.6346166354994622, 1.8874265085304938, 25.394573750034457, 60.540638277607584, 41.90683826323479, 13.47494088834332, 27.030751243714366, 86.70557729659542, 101.56778304807602, 83.17964892233573, 77.32009856931626, 34.751344650022446, 55.717660534766416, 50.30145175995366, 71.01698306299025, 78.99513890666347, 97.4785081801876, 83.06859877801712, 33.705119086850075, 1.8740230342072828, 0.35462743212138453, 0.18221652555850246, 0.18774280805260907, 0.19157240497729472, 0.12380630498932255, 0.19428752783325412, 0.3032004094171909, 0.09274436611562006, 0.1343769240643709, 0.12835922681035536, 0.2746420305582785, 0.19537327360481987, 0.07444777330684085, 0.21899317391216758, 0.18163658167806365, 0.18413217437844123, 0.09618672091634044, 0.1964375229492303, 0.14524020404825289, 0.16737810726608002, 0.08740893910608946, 0.22224336321796143, 0.17075534459323655, 0.08695934508596698, 0.15612614491293508, 0.09923974217306222, 0.14313111802743328, 0.16158528746135775, 0.20838420447562972, 0.12592708917274592, 0.1800936805985628, 0.13236641823764772, 0.17173167768745654, 0.15785463845297215, 0.2179697417323628, 0.10278155050811269, 0.18825214926994618, 0.12360435655160297, 0.14103387572592305, 0.11452668962339241, 0.16761803068220618], [0.017840870085262486, 0.03686035112027199, 0.06767990743561138, 0.020168756562916022, 0.014417405097535061, 0.02133142522295877, 0.0575330384045599, 0.03763432975017256, 0.0270123272428229, 0.008498707470754463, 0.03156092449752314, 0.051985056469998056, 0.0309354079616887, 0.021828834620875218, 0.07671717088669538, 0.03927402603890627, 0.06923992291934068, 0.04001270716769561, 0.04680232227509541, 0.0296502590795318, 0.05176286032843975, 0.05410235112292632, 0.022917916705351205, 0.015117012869356381, 0.035247490891525825, 0.015922659658826888, 0.05816428336284815, 0.04502258894424285, 0.08995604355849567, 0.04558872025940688, 0.021716947479534055, 0.03440959371566292, 0.05155019815109911, 0.03987768034060155, 0.053982906524212136, 0.022710498399852265, 0.038666468519236774, 0.050498550953043085, 0.4106699200647493, 12.602795996973592, 55.84183885205177, 92.05980870031541, 88.47528796042167, 82.81947335889264, 63.723496544745664, 40.79705069142003, 44.57116703833304, 39.265788755109234, 41.34939885908558, 41.73832931826192, 100.01443816769509, 89.85985325228783, 30.524333792348063, 13.44130068056045, 39.83549733315745, 48.93128548899005, 19.087545679461574, 0.7192474699789478, 0.17413592206374293, 0.09225696565643435, 0.1362737117996139, 0.2713985981479768, 0.10962125244400195, 0.09406779066569383, 0.011210969945926581, 0.07827389985322952, 0.08141889762614044, 0.06262133311059687, 0.05710635424381303, 0.016834759153425694, 0.11051656407935005, 0.037976196486382716, 0.09701883795881465, 0.038263452644910545, 0.08386513128155663, 0.10169654784183349, 0.03261518597062076, 0.03671137766251641, 0.04331821951294138, 0.08040961509029712, 0.10925228917790998, 0.07666284759198466, 0.030920515212440686, 0.03913593102967547, 0.09823456586849305, 0.09781019912371713, 0.021824601985093568, 0.04001376053859149, 0.08288017203730923, 0.1284637748293819, 0.15235912204990465, 0.06659874286983283, 0.10810688047880128, 0.08125213560678306, 0.09199667196240156, 0.04635215751946934, 0.11688542837697653, 0.03660213352451402, 0.15823516964672074, 0.02830196540021608, 0.044507934907150846, 0.01858795328336137, 0.006066677085454426, 0.05821332065088134, 0.06865051019215776, 0.08216883641697707, 0.0677400300159089, 0.15689339729086046, 0.18626232781717855, 0.11110449059595985, 0.12329278093191887, 0.014009081191503474, 0.11004767230441494, 0.08742585432745757, 0.17880858342734077, 0.4745395589740046, 0.024240923737506234, 1.2483544912069076, 0.36436548216208337, 18.613544894802956, 51.18797409919001, 27.93056061190944, 7.53386014892209, 19.573076271241714, 50.236426707237, 54.64458242539437, 59.14263494553105, 30.29802872288612, 26.60332468248183, 30.246473089341197, 41.253461607040904, 50.423421782831994, 66.90011824330976, 76.90901848577684, 35.55156307835733, 2.7642879274583634, 0.1909837583380361, 0.028800081514242678, 0.06574752725540631, 0.03691175178955159, 0.0694978264190497, 0.1254885498013708, 0.06003568677472011, 0.09346888610912908, 0.057336663256489465, 0.0813445104886928, 0.07420536010496079, 0.08717301466892804, 0.03043679197529151, 0.043712559441525134, 0.0370405962870967, 0.04800891075583716, 0.022747960099349582, 0.0073149637319147595, 0.084666459250354, 0.02404278467199014, 0.04344303438800477, 0.056402338593597376, 0.10428879785561755, 0.04283002998319365, 0.007838473745411443, 0.008124657380845278, 0.07657223471230076, 0.03326087934716094, 0.07433888156928363, 0.025827786772541945, 0.03717510983528149, 0.03202657572053854, 0.01608379763521014, 0.04645171447566921, 0.043975741287032445, 0.05430403526031202, 0.005713573275809927, 0.039626771223641215, 0.07325289064958211, 0.015373589121736588, 0.025189641277275743, 0.037134947675851085, 0.06131832097326556, 0.021185292036182458, 0.023144565732969392, 0.020854704029437517, 0.04756736065891962, 0.047675972774384484, 0.017594739441729842, 0.026343317980307247, 0.016770808048726573, 0.05673000205969138, 0.033399755766074506, 0.025018150580205747, 0.062004957918918906, 0.007516472147882826, 0.07250231600576833, 0.06055192661381537, 0.10577111670206632, 0.08301338706646236, 0.05371617003073616, 0.06073265058559276, 0.011913343295154553, 0.02805020018000036, 0.03439982226418872, 0.07349293663977616, 0.05296091842014463, 0.05203300591317877, 0.043080954421912475, 0.08086259521904492, 0.07620317185477865, 0.06665918720705856, 0.02225426048220646, 0.057082865988054586, 0.040236944933572126, 0.054018866691377856, 0.021321778260772268, 0.023932234354076848, 0.8611865245526837, 29.53354112563595, 82.16693216754545, 107.69655704498292, 103.30996651803295, 106.17867039095972, 87.6186344700475, 68.47231403473886, 58.86841812441426, 34.786465552545366, 29.81123708909558, 18.934930178426928, 99.36334825331166, 120.22467797802342, 41.290704511827045, 11.408990275475288, 16.252898766148476, 23.67706002727632, 9.242714258932299, 0.26244002724847487, 0.1684073770358678, 0.04278755806867154, 0.2058050775479886, 0.2510750362829816, 0.16905723410027643, 0.04975322401151062, 0.08048897413837333, 0.15106614949482103, 0.05500354248309328, 0.02358860178520122, 0.058400188647811456, 0.05100819094467068, 0.096039455834656, 0.0734983682031593, 0.08862737130614058, 0.11869410834004802, 0.28236441133964446, 0.1752955340329678, 0.3022727075844042, 0.03608025527829605, 0.10179139718773866, 0.07571339652302765, 0.10171162445218333, 0.15365874424817103, 0.14008711362558027, 0.08628712591504858, 0.07283030888966976, 0.3069715844767709, 0.1120333492215122, 0.12286412409476696, 0.08141479905574553, 0.09616570712457742, 0.3006672017997311, 0.114812471062666, 0.11788800764348238, 0.04369555228960611, 0.2770878122218194, 0.11560951659996664, 0.32012724467823583, 0.22889525869921332, 0.20681628296452187, 0.09560849307285202, 0.13652459027305727, 0.0973266444259113, 0.09777365672972896, 0.18512381390938837, 0.09033859722436437, 0.10794206432277158, 0.055871546914380406, 0.13793898776413935, 0.1801688185021762, 0.19356933572599966, 0.09632558967437475, 0.021944667115026427, 0.1320742782686026, 0.06097249356248687, 0.18409799153525985, 0.3733968620579089, 0.04764903712296679, 0.9511879434989345, 0.05095171494289272, 8.437260447009917, 21.18226001339574, 11.190114175119708, 6.4695583428106005, 25.194568172577892, 52.84010387236073, 52.81450256224602, 44.65037145922261, 15.33142810867679, 25.58899191118056, 44.43317021093061, 64.70326539008849, 78.10607094918528, 85.80633471089025, 91.5647820503481, 59.79306590172553, 8.828358015706463, 0.06397229086066927, 0.030431281887896122, 0.042952489137889883, 0.041728276804450064, 0.1366576291019878, 0.038589227704271194, 0.010843396171807282, 0.08123888228569301, 0.013888085264742616, 0.051146492797641024, 0.017855149964171074, 0.09849859041071708, 0.019774721154282172, 0.01349421360740258, 0.020810504586646156, 0.043957090876515836, 0.01749719346633121, 0.0061914507832918925, 0.05386286437691701, 0.05289321923027596, 0.058963952751289454, 0.022301501294057217, 0.007057713800966139, 0.03518575186570806, 0.01973836645183544, 0.1053039026596854, 0.032459379008580605, 0.01759912146465673, 0.04635663147294714, 0.09468486682782251, 0.03143105344215949, 0.0647446338928515, 0.026190194241221876, 0.046376718298321774, 0.05550895749981846, 0.08389641065150501, 0.030759177095587217, 0.012309212526757152, 0.0765459502356187, 0.007652342150498543, 0.24326014272387952, 0.10932784076900252, 0.19335780352834733, 0.058324939661449006, 0.1064395207551218, 0.1043895690611774, 0.15348995975669355, 0.06501359970218713, 0.09668889921158554, 0.10045347059325826, 0.0978633119995075, 0.17587512551296144, 0.09497238728668421, 0.12915821055010443, 0.17257628962397578, 0.12179411376916593, 0.17597431857739726, 0.17722357815552145, 0.27496767921313164, 0.09350993310011203, 0.16139427109831767, 0.11569334960152065, 0.10488938780561571, 0.08055507220448026, 0.16876111047402506, 0.16077331087041288, 0.12196331194812253, 0.13250858883463568, 0.24124721605931562, 0.17949418615429633, 0.15262351431433233, 0.20495122659110254, 0.17643311331349035, 0.19580917763373545, 0.1570525443962505, 0.10668463058649533, 0.12889631573230992, 0.11305586975668708, 0.5579531733547488, 23.088575063213227, 87.036923439272, 123.15220171405424, 110.6561500795426, 105.2070914545367, 86.26421651532574, 56.04664933296942, 58.71099771991853, 51.37532611047068, 57.433297403397106, 57.40801380526636, 133.42834872584191, 119.33484123599146, 43.18364035698676, 21.343557680806807, 55.648407167004, 70.18487576515444, 29.241808960514685, 1.3438995062343537, 0.3284806980481071, 0.2631286177183351, 0.29104283920699553, 1.1047397265511176, 0.3312138239702871, 0.4860637889754388, 0.19478942267596724, 0.3629814370745613, 0.2738277710253193, 0.23686462622736734, 0.36720478787056865, 0.24491915208918436, 0.31462320937745036, 0.23760262936834367, 0.25499538398317756, 0.16287142651215678, 0.24704498479202872, 0.21006687063603632, 0.4390258372070328, 0.18808842095876896, 0.19177976965663895, 0.12092273472057236, 0.2725190170589955, 0.2091354762594546, 0.1594073607796623, 0.17430372596267732, 0.3655114271227391, 0.2650423972837387, 0.37521714825303326, 0.20400362179404308, 0.24597926455880367, 0.15851617069734683, 0.2794214386132456, 0.17582261784663125, 0.21380815294481095, 0.17236313331992398, 0.2891406428910071, 0.25441818269750766, 0.25279707936269624, 0.24251345214584183, 0.3052013085013436, 0.23622760879656962, 0.10376185193778047, 0.13569205188222472, 0.2699604978965175, 0.21907004317448986, 0.19181500970115586, 0.22197713234251548, 0.33179660237604575, 0.4465795560709892, 0.45289806540935273, 0.3394500352442265, 0.27370577918425687, 0.18539864029134476, 0.24281840110498093, 0.198992089098019, 0.5745522762017866, 1.0852451790725033, 0.11458995316417948, 2.0001561627272637, 1.3065812183964638, 30.29303554565676, 70.64908827504804, 37.16178624860702, 13.252889629333252, 30.916796345864576, 74.03494881045434, 76.99701293822258, 82.8734451724637, 43.341421619538345, 33.70278919896772, 39.55391822322723, 55.48872355491885, 68.12606288540748, 86.42042098506805, 104.21360215833111, 61.0998623601852, 5.833306264492774, 0.43891570440703825, 0.14518475460429348, 0.24161504551527963, 0.16414752981114775, 0.28000247033853687, 0.25465393859532576, 0.18675335953312536, 0.2609030403677495, 0.14215458575035297, 0.10376254141691232, 0.1208450840485673, 0.22879255695208428, 0.11994479284171136, 0.08040624430343028, 0.17928741902353304, 0.18135084620406552, 0.09623876126903681, 0.13681334413347707, 0.16156729971689565, 0.17272175439903814, 0.17823717376637846, 0.18128522311247167, 0.16154620165546096, 0.14081923321129816, 0.10700933695320161, 0.16581715715508308, 0.19972296762129954, 0.15816108894444283, 0.15436826424012262, 0.27883893599913967, 0.1219430489225253, 0.18110787375800072, 0.11550449360642703, 0.16534446558404356, 0.17079082978588922, 0.180747184241491, 0.14819240047326013, 0.057000840954001875, 0.254717048918528, 0.07695061319898214], [0.01632691946842017, 0.0506349835514782, 0.029452692664739107, 0.017512909760097825, 0.012416012844281092, 0.028435839264984095, 0.02608747525711454, 0.09116010394908729, 0.05984456315937062, 0.03518572888307033, 0.06456222069720108, 0.010414598565999298, 0.07465115432897884, 0.003159121082599966, 0.03926369917368697, 0.034732652993331996, 0.05021686425372478, 0.045434962582564166, 0.05829618838165076, 0.005483112003158538, 0.045723563225399104, 0.035491187290679065, 0.049545614184030605, 0.06678340070310139, 0.05533063904412332, 0.020828703005287438, 0.028832986905810334, 0.017990439176379193, 0.014683680980646563, 0.03821731499967076, 0.03310966125178722, 0.08134732969225415, 0.04902633297587595, 0.09668212699433489, 0.02990517483633613, 0.10106897627514216, 0.09312099792183408, 1.1508752573882381, 29.025190184193274, 75.53676943625175, 84.90752358590403, 76.93504733424034, 66.27692422559186, 46.01094753511491, 51.86274336230371, 23.273930588076194, 24.439378553821197, 49.50191974639893, 88.12863672933271, 95.12970662886097, 32.727597759615996, 5.951606910074911, 28.79303097724915, 67.8159289206228, 24.809852300151704, 0.607232177449811, 0.9857159552554932, 0.07528207369989927, 0.2549135657928644, 0.18182528445557242, 0.15316394337963674, 0.03408116799208426, 0.08446112470400911, 0.009910935017791007, 0.10744367050187242, 0.019366741030206604, 0.04334084208934538, 0.056231615899671475, 0.07370744125857469, 0.03783941531794206, 0.049783959459032745, 0.07503488010937169, 0.18265436012898723, 0.05373998387386242, 0.11259997849382701, 0.1497150921533185, 0.07877905056962083, 0.014459081238225825, 0.1061404936556374, 0.04973004985180113, 0.13726130638632084, 0.23658976920189398, 0.2501484376168059, 0.3747643290027496, 0.06463666912168264, 0.18861630150387365, 0.14688288041901204, 0.10203172663046468, 0.02174163083245437, 0.14575394261027538, 0.25819752425436054, 0.08719819597899915, 0.013588231747909902, 0.17869209209757467, 0.08626483275645203, 0.10161050850705755, 0.06173299670579934, 0.10549860390564127, 0.054311129234490864, 0.028570666909217838, 0.08959431982328815, 0.08321124459466628, 0.06292159361163936, 0.03313453995712823, 0.05176652605915743, 0.02808172852852412, 0.07727971691037379, 0.046836328918054226, 0.06910358225145648, 0.06976319161514122, 0.03517881110911408, 0.17885212786495688, 0.2334703511047748, 0.08427003173217659, 0.058953656529587124, 0.07271117455656491, 0.13409416101151897, 0.5223769694566727, 0.040527939601170446, 1.4632534307818261, 0.6303384311256871, 20.619525409513905, 42.81998957357099, 20.27160333048913, 11.657398881450778, 19.57840677230589, 48.05449455015121, 82.70536376583962, 53.3180917462995, 35.040799879258685, 28.63501633367231, 42.58580054006269, 49.507426754120864, 57.45376825332642, 79.33342764454504, 56.753225095810436, 9.930116495778485, 0.20997333130048168, 0.09974149145906973, 0.0467990089448229, 0.1681017079540799, 0.06035832853447046, 0.03066500573749504, 0.008043498026147004, 0.01749768567782256, 0.050840819885413495, 0.03811304277229694, 0.01297953658767285, 0.09127610498258183, 0.045798513437471086, 0.07236965255992067, 0.011826805045617925, 0.04465418109189599, 0.015387917838750348, 0.026937744752954573, 0.036883919815262484, 0.04893132658194631, 0.06306725373912243, 0.034371672363411036, 0.03724631004696412, 0.10451431115788799, 0.0029485007689800118, 0.07529359566228044, 0.014142220569474083, 0.006781325557254136, 0.06674307383476727, 0.03403177064272665, 0.06239872328155945, 0.07528146082955985, 0.016517548957058502, 0.03961194359186677, 0.026493325656760606, 0.015914091923003717, 0.02993730647910026, 0.013846040444238292, 0.026258180714062145, 0.011050383552848812, 0.039867468388570894, 0.03310008132229409, 0.02076274858066632, 0.022392495302483443, 0.026108278374698375, 0.04822881246406225, 0.0641281974141396, 0.017406967461049076, 0.04763685632497073, 0.033239562950667836, 0.026749386715011734, 0.07229772456470998, 0.03191688150588063, 0.021527762066632993, 0.04179162078446919, 0.039307197646027615, 0.02371668019482205, 0.054281876167102214, 0.07806522516353477, 0.021438581771367503, 0.029158447869122032, 0.02983858647395767, 0.03880811434599661, 0.007977657557104625, 0.034197138382061835, 0.019023439794358228, 0.055055490905238744, 0.028877071435413057, 0.0025943392791950536, 0.04649311386709733, 0.03817707623144792, 0.032176711716719215, 0.08050014370030935, 0.01026819724844949, 0.10962411761283876, 0.13788367621600628, 5.922474976508848, 56.94612333851477, 94.86598999269548, 99.3492590996527, 98.69209735624253, 95.792328311551, 76.32315758735903, 74.97106952051963, 23.907646363781346, 14.958049847233681, 33.4948290548017, 65.8915513561618, 122.37619999916323, 53.386278229375044, 6.9273955302853745, 12.078548669815065, 31.23421807442942, 13.777447804327934, 0.27823262337234717, 0.7789253515581932, 0.13479666363808418, 0.2105324222676216, 0.12299737742831632, 0.08685491198012907, 0.07488898632507171, 0.07789297795463955, 0.020154719916923393, 0.016037598702936404, 0.04900421218706235, 0.0889417584685068, 0.04953430289582861, 0.11589597985749284, 0.04430115245462907, 0.06828601321866436, 0.23730442198293827, 0.5481350518042042, 0.5198385217978109, 0.5462535398621713, 0.6962084481793066, 0.34499317167266724, 0.5118825761300902, 0.32398278134003766, 0.057153709968852426, 0.7861408579253382, 0.7882390808193915, 1.7868585307751934, 1.45766147923085, 0.916902567109754, 0.9239729457805235, 0.5631654517304513, 0.46834365434704295, 0.557429107927507, 1.0431246844030198, 1.2201342635577725, 0.5863140547467817, 0.5030697764408204, 0.6365035390180926, 0.396239121835078, 0.6622143077754206, 0.23306004973428868, 0.5495771357128697, 0.41746956326307794, 0.49476657843878197, 0.5047489798838093, 0.5124135363486506, 0.2700974131303449, 0.19446256360219372, 0.19501574037055816, 0.050064412756792964, 0.15350227845051598, 0.03673879211888679, 0.027700618938392693, 0.14297871249577693, 0.08241012346960845, 0.15483897930431753, 0.36372212152327266, 0.021555841104277683, 0.04226058916819673, 0.1942370579608025, 0.134048348953647, 0.4128349458257998, 0.027714485129822167, 1.174696179166917, 0.3017425440972851, 10.10442662623621, 22.867418104602447, 12.012860736539288, 13.28174650669098, 21.015563203442483, 50.433776840086914, 77.3973221932688, 26.846286096880515, 18.111222636315134, 34.15521890886369, 65.94713134150352, 72.7489056125764, 75.66000246232556, 89.49712814823275, 75.37197497583206, 24.16271809608706, 1.0667334304701899, 0.11477335461325223, 0.016074068318571777, 0.0885810919346348, 0.049373795984372984, 0.024655561165643797, 0.020404079621056878, 0.011557994369086961, 0.02895192014083507, 0.029022381077670766, 0.023278786252523144, 0.14611887625388562, 0.00923229603006715, 0.016596988444366766, 0.045170566487696864, 0.03872017894360808, 0.045991885520878344, 0.001402939808265787, 0.024190557286924413, 0.006071753854367642, 0.03647368356224991, 0.06212454807433871, 0.05219546634884131, 0.1189023540205052, 0.03764732643180797, 0.061517974977651914, 0.05061299682805135, 0.023928235375112104, 0.06404938994936886, 0.014356974166848007, 0.037838576451664975, 0.041424879173357645, 0.04572044141710766, 0.045111600700165, 0.042760729669563236, 0.0662130865478708, 0.0250728722406371, 0.03822965284569129, 0.0337095195878177, 0.17348709155715283, 0.1374054994554289, 0.15799748320733348, 0.17638218378828419, 0.07935003888222479, 0.10028889958536434, 0.23398736852311322, 0.18600847692258898, 0.16058713618305423, 0.1485858325876536, 0.19445847269267807, 0.14118254274850892, 0.21874971116983125, 0.0844452283795803, 0.1083356649765084, 0.14444456045185367, 0.16329138059048884, 0.09843235444878379, 0.15457041952158176, 0.24181176157247639, 0.13252076963263174, 0.09652942268838806, 0.2052570642122338, 0.19441813050258547, 0.12821061341392417, 0.10296884368384078, 0.07836639730920715, 0.1503987183734294, 0.09635513768561425, 0.16703701427867337, 0.18203222012567907, 0.18022232208280795, 0.10326160418410456, 0.15569465355046336, 0.12459191283391369, 0.21652105414578993, 0.22272403742517197, 2.948193401098252, 53.92696126814812, 108.64927722561745, 110.4954819525442, 94.52403776107296, 90.4279536585654, 65.21242826215683, 68.17401778313422, 32.631909578077256, 37.819638329167525, 72.07165348914363, 116.48130124615086, 131.42214267484604, 48.06973295827066, 11.687407955046623, 38.79484545799994, 91.5684376993487, 39.78656968762798, 1.0972274070785892, 1.3384355220102495, 0.2086374424998799, 0.7884280900320699, 0.33621153644015717, 0.21654310215625072, 0.1303828480623422, 0.2761372503253722, 0.28066559604579405, 0.3712111212793858, 0.25583734525547874, 0.17861419627743383, 0.28270673006772995, 0.2509368340214414, 0.23946258359618727, 0.1767716475672299, 0.22945228122895767, 0.31486648825868485, 0.2528370385088267, 0.5444183609177989, 0.36392792338325136, 0.2941147598528093, 0.25320345836301006, 0.2277437979055028, 0.2730174951495663, 0.6224036601281936, 0.5177779291425982, 1.426994673186733, 1.0724081195169881, 0.30942423028811333, 1.0407724880403089, 0.4776682007697321, 0.6844475889398206, 0.25945960814433716, 0.5770342785023874, 0.6290123022852406, 0.3254050695367398, 0.189947884890341, 0.286687660000978, 0.1604925090026471, 0.17404403747810474, 0.09139401357500784, 0.42033062586861275, 0.2393183752053207, 0.30444888758563227, 0.3408877984169991, 0.23468602538829852, 0.2278972453167362, 0.26190223352562997, 0.1997530289114483, 0.11642586755295915, 0.3179505743807362, 0.19840802366454757, 0.1172393609979941, 0.23838627602784868, 0.25312531739473343, 0.6173780007708458, 0.5821778541130405, 0.23114358886115013, 0.10836727376426421, 0.2958030644203386, 0.451202774119954, 1.0817320837128548, 0.15257569510609875, 2.651216781908466, 1.4263672165332304, 31.688257917281124, 61.252191528197265, 29.67406199824426, 21.99306688001079, 33.53466856864191, 71.05837975778888, 116.96928331928869, 72.28084133517358, 47.47032419327767, 39.723560733179895, 56.11228235306279, 63.70455541918355, 72.7771702120381, 100.57183834814258, 79.89107101194321, 19.597306712981194, 0.5624591799512987, 0.1271682818450274, 0.21552661073303994, 0.2776405293374293, 0.19815993375114857, 0.153471895403439, 0.1230792032795087, 0.12320136365991448, 0.10081311056931173, 0.14694778338795708, 0.07082521930457124, 0.1684297621250153, 0.15463567489097196, 0.15348825904150165, 0.14078134250256324, 0.14502946858204183, 0.10576353243161594, 0.15019662437900422, 0.10155698194378808, 0.22357680053720552, 0.0983064862028245, 0.16113000140795786, 0.1710616878323978, 0.17913994709810904, 0.23135440093615364, 0.13940475911142367, 0.18645696011522125, 0.13319025386966046, 0.1290632616127691, 0.15846799908866807, 0.20700259554770686, 0.21643223391184885, 0.17877997770424814, 0.17950330260059527, 0.10528492666180096, 0.17826933413743976, 0.11600714687618519, 0.11665788494170674, 0.09593577349498388], [0.06164659347925937, 0.07133418513882546, 0.023750638957285596, 0.03578627286779304, 0.006856102920738199, 0.04952931183300192, 0.0656730175438908, 0.041134673576321334, 0.037792829511266564, 0.040621076740564845, 0.007178830386575072, 0.010319409268577735, 0.02101239556777141, 0.008399459822554021, 0.04682660343185548, 0.020015138697119492, 0.025197240869484605, 0.035821930430228674, 0.09159102840649505, 0.02600950091296146, 0.044311812568095424, 0.07423431822849859, 0.05325272897138231, 0.0488372394935258, 0.017056731214266152, 0.0498760317362124, 0.019408314706637494, 0.06651608198280297, 0.0359384102686759, 0.08659019029789394, 0.003520019836874018, 0.03218264889813239, 0.03460429113117918, 0.015442530331652493, 0.07610699717676447, 0.0418803031225839, 3.6553570291688366, 54.63274078984415, 88.73725521949031, 82.57263075920844, 61.038704764458444, 70.58514579649895, 59.04837254554995, 37.186344208255896, 25.883909040881743, 56.225089719218595, 59.21860733339864, 52.168327377688506, 55.35214270314863, 9.141491613080426, 17.92679867436809, 71.531982421875, 56.744348772110484, 3.8969392401556817, 1.0452529379437048, 0.09875335294993655, 0.6241446409013964, 0.11992184084749992, 0.06234057337766694, 0.0250929169311759, 0.09423557924286974, 0.14870214005631788, 0.10225654279272403, 0.0364957851988654, 0.07830982171599904, 0.10732512605646927, 0.011656271958453281, 0.014745736017733093, 0.07207274752398653, 0.05761703611501764, 0.04815844728821709, 0.06393639964141673, 0.10158828429637418, 0.04264699625632456, 0.09078170247976819, 0.07408617214570123, 0.2706919586466205, 0.1432770884205257, 0.4667749207827353, 0.1709600279648458, 0.53376802273335, 0.28469077521754854, 0.1816381138539122, 0.4882873438539044, 0.26608182537940245, 0.16294985859384462, 0.1777606517557175, 0.8408271557381077, 0.7807464344847588, 0.2091983261127626, 0.10005108291102995, 0.08540601754981665, 0.6299897691895885, 0.36298382726888506, 0.7782459847869412, 0.565547494878692, 1.3626915817299199, 0.8026617585170654, 0.39950354505450497, 0.8261064391943717, 0.6504611707022113, 0.12442992354232459, 0.11818232330223245, 0.2588109461770904, 0.23181819056551303, 0.07617344764331657, 0.10791479925354643, 0.10383946430538932, 0.0714404491948024, 0.05332248510732766, 0.07960334585438814, 0.10438473504637519, 0.11300453420488105, 0.11916251747959083, 0.08767585179978803, 0.16629354126991766, 0.037829153570196325, 0.17646067715700597, 0.09307317871360049, 0.6834589677952951, 0.07977956139873113, 1.278371654691235, 0.7937093163209578, 20.363312267488052, 30.407735455420713, 30.553661354126472, 21.092580902960993, 23.46649739050096, 63.9808746307127, 73.32467817491101, 44.23359217182283, 25.126579769196052, 34.6715557959772, 46.96537002440422, 39.950669888527166, 71.14972391436177, 68.63677117132372, 28.031245893047704, 0.791039775696493, 0.10460103997179579, 0.020468260552133286, 0.0637313447171642, 0.04556683312741019, 0.10246431349866814, 0.06076773358208518, 0.09047508344895418, 0.03691865807218898, 0.062072346843178236, 0.011857840225040432, 0.02986762503672752, 0.004990134902689005, 0.03657458883319651, 0.11928919011787062, 0.013596279501554467, 0.0631196005269885, 0.021670706412424485, 0.022083662277568254, 0.008533127801192385, 0.004508282835294883, 0.02517413182724868, 0.07221639667066836, 0.0449791440980569, 0.04628334367167085, 0.05245860605951279, 0.010280994747224595, 0.04351482065694948, 0.01616908237338066, 0.011459120188749606, 0.03770872454849943, 0.022835648438382535, 0.041159203711656794, 0.02364737796597183, 0.1064876463985251, 0.011684714887862005, 0.03637517997694593, 0.03700690374018685, 0.05964860552921892, 0.034643392258834456, 0.024637558099423206, 0.06681610499658892, 0.025159093521295056, 0.06964615636294888, 0.057813104827918356, 0.03902254618644234, 0.0545899392736535, 0.028633547406042778, 0.016521092113708297, 0.015663660653386147, 0.1135149556061914, 0.0336209828064086, 0.017103058466267203, 0.03139156160966283, 0.06977014003261443, 0.022096086308480273, 0.07082583217491066, 0.032514552660887285, 0.020003852306775028, 0.03464549133974699, 0.03885670730303373, 0.01878657881470938, 0.05333276217683189, 0.0625333900473291, 0.03813835048687555, 0.08448786883344574, 0.07231493856036857, 0.03529110044661549, 0.02533101705804227, 0.022235730730537927, 0.09277671034778319, 0.01049223870429541, 0.06328631658107042, 0.06674214686837888, 11.768935399670756, 83.11706358386625, 104.41185443632065, 97.54227807444911, 85.57191033517161, 106.73823571974232, 84.31600662969774, 47.00557431867046, 25.083653350030225, 26.68698883825733, 51.06438805980068, 68.255093174596, 78.38330407296458, 14.02121134342686, 7.323879984117324, 38.16724661857852, 31.550329731356715, 1.235718943418995, 0.6203772043508868, 0.019598030635426124, 0.8272622513674921, 0.16236945506065123, 0.06720346969462211, 0.059364984457891797, 0.040603092826542356, 0.31085837752588336, 0.15446650735553236, 0.13438308341128213, 0.0756511212356629, 0.18849714418813107, 0.07864022777686197, 0.07451322019821213, 0.08630235574298328, 0.2645147159214943, 0.5427834680003505, 0.7645107024619657, 0.9109257329856196, 0.32601076929319295, 0.2588302515927823, 0.9412650824073823, 2.8243399050927933, 1.3794338510882471, 1.725167492705007, 1.81310078069087, 3.0830842016204714, 2.643016821915104, 2.8373518778431803, 3.0869798506459887, 2.7071936620819956, 1.1298009753227234, 2.3112424054453453, 2.9783252939101192, 3.867191739620701, 1.3446719680101642, 1.3152248965155695, 0.30782280009119745, 1.4735242796521035, 2.6829820967489675, 3.3187583425352654, 3.2011215581047923, 3.526053644957081, 2.893725407700385, 1.4193715467568369, 2.4365734092650877, 2.1741580194042576, 0.5433310676486262, 0.8987609309054191, 0.4665371577345556, 0.36960368495314355, 0.14229695553020125, 0.29982701785141425, 0.25380761062185614, 0.3058613085698697, 0.3625193328386353, 0.027838208329593463, 0.12137614385855776, 0.1305617295926617, 0.1482769612583422, 0.1444369761814033, 0.08861309908811124, 0.047808494493966146, 0.06436937338402195, 0.03727102404340141, 0.7573306812874733, 0.11970205022202385, 1.240876492473387, 0.22771258748346762, 10.673931241035463, 21.05722858059791, 25.907664875830374, 18.972027955516694, 30.807711309002293, 75.12356342807894, 68.05197715759277, 30.620924119026434, 18.7878099180037, 45.6010010165553, 73.7071563351539, 64.47438724579351, 90.68884618820684, 83.55197598857265, 48.8734854421308, 3.7337880076900607, 0.22447578939459017, 0.055597279776608756, 0.0940019760521189, 0.04173308400617492, 0.16715203471962484, 0.03239832946189469, 0.04660123951673027, 0.042953511865268794, 0.12046093691981609, 0.025354444026766766, 0.04220421658828855, 0.04271707414919811, 0.01661719401336966, 0.020764027947499868, 0.035011654554475705, 0.020495324523278305, 0.08132623929169872, 0.06278798787764485, 0.0688193942750654, 0.03698391344157919, 0.021505064796656374, 0.048546275469444455, 0.03325584997993804, 0.03901869276418321, 0.03049120720055315, 0.07844165012600922, 0.045056564943684686, 0.016613673839357593, 0.012773810378876666, 0.064151716313415, 0.04573187144893793, 0.04645537254550765, 0.0828516199403713, 0.04003431850803956, 0.05442200130933235, 0.04882127039074417, 0.017067307058060845, 0.18219377274715132, 0.15370929072941505, 0.10341778652922762, 0.16108772867629606, 0.17081825573357845, 0.19142690955871539, 0.16447877090784813, 0.13638022866460586, 0.18409788428295046, 0.13325474315112637, 0.09657527305065625, 0.09357263739671438, 0.16256494537716912, 0.1337452386055262, 0.08965307876708047, 0.146649775185412, 0.15767008787201298, 0.1382573739054703, 0.2100376213990873, 0.07460207107567018, 0.14621883540624572, 0.08703777716765482, 0.1632423509633349, 0.17878278158605101, 0.11436418705289403, 0.1664248947054148, 0.09902372070017362, 0.1532837901745112, 0.20137008730201952, 0.1843186555009696, 0.1401281912600802, 0.15984384703540033, 0.15219433653739192, 0.11721638602114494, 0.19059231805224575, 0.28460233802756957, 8.037349312536179, 88.02270135571881, 118.45215105241346, 104.36897508559689, 82.74351273813556, 92.57011690447408, 76.03901324733611, 49.93240771755096, 33.4768489099318, 83.21684868104997, 82.71931955891272, 72.28488137645107, 79.36502625865322, 13.902468450607794, 25.863853962190692, 99.82491708570912, 86.94815235753214, 8.360770306279584, 1.4033810241568474, 0.16320207006027623, 1.5200310873408474, 0.3141194299584435, 0.16490007330092693, 0.15947569582250812, 0.23551367613817417, 0.6675857485782716, 0.30469820323971014, 0.2290622352231895, 0.23682774675469245, 0.3066972330693276, 0.12353088871966447, 0.20755404095736243, 0.37823381863774796, 0.26021573692560196, 0.26893001770780933, 0.36541502261834763, 0.25518246265428685, 0.16457591085664688, 0.12379985452900011, 0.2642589651288525, 1.34816667725963, 0.5178615246568957, 1.0425571664687128, 0.9572945222739251, 1.6073082363413227, 1.0071299513501506, 1.01588265910264, 1.2259549383194217, 1.2702474454718253, 0.37195272503360627, 1.0256394323322082, 1.9574974453256977, 1.7316368294339028, 0.22725558539311733, 0.37608052934369735, 0.1241840169795098, 1.3918567328683793, 1.8198674821084546, 2.7883389207624623, 2.139708822773349, 3.9148926638787795, 2.2928258968937785, 1.0557271371926031, 3.0442691618396394, 2.310537604555007, 0.7591582606396368, 0.8387928552204563, 0.5047894906132452, 0.48567213418502964, 0.4566974018610293, 0.28479036664770496, 0.3814337372539505, 0.9716837372510665, 0.5252135785356645, 0.21253623248588657, 0.20092980125017706, 0.19459702735466344, 0.23666461599209618, 0.4233355597863275, 0.338122864524203, 0.16004436288870152, 0.31789642728624806, 0.2934436668311396, 1.677686588898782, 0.25672298886122247, 1.8634044427064158, 1.859581847825358, 33.231386984548266, 46.24151622095416, 47.14593633528679, 33.12499661599436, 35.36055934044623, 93.48254649869858, 101.51393675035047, 61.66360501320132, 33.17092364834201, 46.255668132535874, 62.85680570910054, 59.54155960390645, 93.29150353708576, 96.19968214342671, 48.76485540020851, 2.505387716716336, 0.31828860301644574, 0.22435848601162436, 0.25876890327180585, 0.21910221886730966, 0.22090965010706456, 0.13655167914205982, 0.2841697128549699, 0.11549652629201451, 0.23455534611017476, 0.12258998719194245, 0.2319246001781956, 0.1251228883742325, 0.2854670980764974, 0.18332746030101854, 0.13069125973889906, 0.11558032865005156, 0.18238394641347472, 0.21178837745420395, 0.24947420363464665, 0.17569049832320985, 0.10347862923217398, 0.19896320758327363, 0.1257356974266229, 0.0767387745661601, 0.18277699548390605, 0.1361077311899393, 0.16476747880299247, 0.15070251820068206, 0.05693099671794523, 0.1229836491327132, 0.19981175721172365, 0.13722431966133658, 0.11892248681115529, 0.30893436302581145, 0.2528164920306975, 0.09764485436701968, 0.14725763530981156], [0.013599772862489186, 0.03146036396614246, 0.01319035919638531, 0.07648187464163189, 0.04005624777487209, 0.0642501854247624, 0.009522613667462383, 0.04091407089764553, 0.05247196280247262, 0.068407507102576, 0.10324053676618684, 0.02058900750031875, 0.019861317818023024, 0.08146857842803001, 0.025669771562060042, 0.04734343698909206, 0.020927762004336523, 0.01774068876740433, 0.04395720578970448, 0.013469403849974757, 0.01567928214377213, 0.036436666193748676, 0.00830332249132616, 0.03738080061251118, 0.052475230167469675, 0.03841537554117461, 0.040967210586513245, 0.007955186283065668, 0.03959993899409329, 0.054249252312846725, 0.05892402424867596, 0.021483581776039738, 0.025898969747246276, 0.023631225002088377, 0.1875752646235689, 5.926575814524005, 53.3374172641385, 85.26543201938753, 68.97177296300089, 67.32954717451527, 45.844815546466464, 34.56531447748984, 27.75615634456758, 38.82498102803385, 56.901471076473115, 66.61947265748056, 55.798049511448035, 27.689917318282593, 12.03527904325916, 59.49163567635321, 87.0698791934598, 17.628655395200177, 0.09485306143159829, 0.2167522288378208, 0.5354368686676025, 0.07487531931650254, 0.0923912225651645, 0.08599224335123455, 0.057099708431069894, 0.021396446935532075, 0.13269969712822668, 0.14402111301258688, 0.06532225652687973, 0.050500776438463124, 0.0768003067482383, 0.036795160868355346, 0.013458737033239056, 0.03869121315919104, 0.09403754551444324, 0.11674552540024442, 0.14991677246026455, 0.725272475711761, 1.523590760846292, 1.2365562468767166, 0.6389865219112366, 4.974183151798864, 3.2339888138155786, 2.7754637406718348, 2.041971570541782, 1.065121336329368, 3.9588067848836226, 3.26126350510505, 3.3289930320555166, 6.874354299037688, 3.4389826655387883, 0.8373407202382243, 1.2199947742685195, 2.392900023729571, 2.1816772030245875, 8.164442931452106, 4.860704570047317, 6.327545008351726, 7.452878404048182, 6.571119783386108, 14.726259343085752, 9.659286641305494, 5.645216847619703, 4.104816769399951, 1.4447229283471263, 0.7249281651550724, 1.434793693404044, 1.9581619193477018, 0.5008770489404278, 0.592315526258561, 0.06752557136238584, 0.26223830097625334, 0.3572250524115178, 0.21891612078874342, 0.27741750582091274, 0.17451921117401895, 0.17931731177433846, 0.046565620258690855, 0.1291959173977375, 0.0705359751478799, 0.12268603163500949, 0.07589852166993004, 0.10514328466548074, 0.07529851394675433, 0.05296210968686689, 0.18065523836881886, 0.08773658725042498, 0.9027987658496827, 0.042658184970458674, 0.584309846162796, 2.264825076826157, 18.603295741542695, 44.255584901379, 42.520006702792266, 24.727698256892545, 30.1514026811046, 66.26505513345042, 76.93052091906148, 30.97336869085989, 22.9181755358173, 42.191739620700965, 44.02599288571266, 51.66194938844251, 70.12305921123874, 39.84730758974629, 1.75744210279757, 0.31309054323261787, 0.078684116954044, 0.009949723007007232, 0.014223560912444467, 0.05536171923121137, 0.04740092422693007, 0.04238739204142363, 0.07729173682990574, 0.036312877876503814, 0.024127265017840172, 0.01289113482926041, 0.07252034205462664, 0.06274843858855386, 0.029454985182852517, 0.05593353108833394, 0.05648735137055478, 0.040615453655200626, 0.033723523675073544, 0.055656958025910204, 0.05567286584165789, 0.03612577239231717, 0.05299024426588609, 0.051595010464229894, 0.036375183807385546, 0.03030516274814164, 0.04192823341356651, 0.11854671302341646, 0.004819373425561935, 0.10954362475463461, 0.013543746937366744, 0.08696830831468107, 0.040197273070413264, 0.03925880770229044, 0.018618667663465586, 0.02584561363853995, 0.011956759413043338, 0.05703776256151258, 0.023601527603703643, 0.08255509028752005, 0.015001562461557408, 0.05285870313884751, 0.04954643389810959, 0.07372829417187361, 0.025725952619987152, 0.014322451372150213, 0.06324063092770596, 0.012213325131714586, 0.04060850140728778, 0.05797647690821079, 0.06417027862382031, 0.04578172079017086, 0.08583429900388564, 0.01200971236797951, 0.014281477159520072, 0.024948365715963226, 0.10535348387014483, 0.00881622601751118, 0.008586048197391774, 0.03840622079047946, 0.01196958659772551, 0.07475236986553477, 0.05785987449569568, 0.13264812408916413, 0.04905773491989221, 0.058361845947201216, 0.06290175576484011, 0.015738082264790374, 0.01949980475699469, 0.05014783973174711, 0.047526823116406325, 0.22427161164101095, 19.92088656271658, 79.00673343289283, 101.62371604673325, 96.55197374282345, 99.25713046904534, 73.07311304153936, 44.6677004906439, 30.989358232867335, 17.064718584860525, 30.147958840093306, 85.00702627243535, 76.00360993416079, 27.786044805280625, 7.523954693348178, 27.183594242219005, 52.594602723275464, 9.229315442423667, 0.25787457222900084, 0.0461696868672246, 0.5377850200860732, 0.05271342222488696, 0.09965524528055422, 0.05454157614299367, 0.29724324843095196, 0.1458751990069305, 0.12335883303275033, 0.08357746526598932, 0.12157665971185892, 0.12796085342885027, 0.051642653472240896, 0.09949920849213678, 0.4875983856618405, 0.4189123213291169, 0.42414353739830757, 0.4005262111463855, 0.6698727355368677, 1.2750035644538942, 4.731037876298351, 2.503102936090962, 5.108306148359853, 13.210100493123456, 13.226100821648876, 8.597441219514417, 4.643482729311913, 5.597523768101969, 11.63592488534989, 9.914263256134527, 9.56795915480583, 11.683623848422883, 9.449994852465968, 6.4484015683974, 5.820442851512663, 9.70267786133674, 7.532010751385843, 10.904130243485975, 4.0913233257109125, 11.718148550679608, 12.048710219321713, 12.036809748218907, 21.001248513498616, 20.57355719227945, 21.380814313888553, 9.02158965987544, 10.572283018019892, 4.745487397716892, 4.816059662449745, 5.910730419620391, 2.5114217929301725, 1.7238373189203202, 1.793792423221373, 0.0924451474941546, 0.43447824735795304, 0.0945566313701772, 0.3371823843448393, 0.08846127578327734, 0.27718099915692884, 0.15255855005835334, 0.11482894195303803, 0.019789453025066087, 0.0806476462692503, 0.11482335717207003, 0.08197789666272941, 0.2199957685004319, 0.028020740268872153, 0.05640295912481605, 0.1300479297436053, 0.9823278241580533, 0.05008778992980238, 0.6853858934294793, 0.9011126369718583, 11.664904336775503, 33.65850956209245, 35.557140688742365, 30.553292651330274, 47.08404525633782, 68.35219537058185, 55.27878261381581, 22.198261753205333, 26.352230233530847, 63.27892726467502, 75.22604711594121, 71.52296881521903, 84.54122128025179, 60.92603860362884, 7.107892219097384, 0.21787290821873376, 0.13128667859540832, 0.1366576444237463, 0.024612129725996527, 0.026063123237221472, 0.11711098764452244, 0.06319001549854875, 0.06889745863454957, 0.03045736335127825, 0.03676632148844581, 0.014564480572458238, 0.04021419595266062, 0.08576115292887534, 0.04200288868178764, 0.026759958728366805, 0.01302013829004981, 0.01005576202465642, 0.03873004998651244, 0.027456642917147087, 0.014103544620616783, 0.03822031806433394, 0.08720928893214272, 0.009221452055498958, 0.05724909557630459, 0.04259379144998328, 0.04621157272448463, 0.0735252655501808, 0.01631786430915517, 0.08480005732346928, 0.04374151373462331, 0.07439853683594735, 0.015821505409304895, 0.051840744657261725, 0.06378553394648818, 0.022243887651711706, 0.06289380377218609, 0.18697405414235208, 0.16113856627095133, 0.2133993684284149, 0.1353658363223076, 0.15053440786657796, 0.17204183604448073, 0.18592812962109045, 0.17165600352229612, 0.11569125818148737, 0.20753306546999564, 0.19170159804484538, 0.09062011155389971, 0.16915956812520183, 0.1377540694609765, 0.06776744830271891, 0.22184659096021808, 0.06250702130097537, 0.10798770018042096, 0.12002153186908654, 0.22020299528394977, 0.05795914799936357, 0.0628510867095282, 0.14316553069699195, 0.15558392320188785, 0.2226241242380873, 0.12961237811513487, 0.19550436657042275, 0.08463153330188605, 0.1546621355678766, 0.1583028152104347, 0.12961725043433328, 0.11207408977732544, 0.12514900431157122, 0.12668239057905253, 0.3263044567598451, 15.864414476579237, 90.85018896287488, 114.27434044499552, 94.07756220909857, 95.33019465784874, 63.094411127028934, 45.71752678963446, 43.19619194153817, 54.94155683825093, 79.31100737664008, 94.88278558177333, 82.18750892146942, 41.52141832536267, 18.061792927403605, 76.67610030020438, 125.63816855030676, 29.39073939477244, 0.21962242321141306, 0.3693106410003478, 1.2089546505481967, 0.3094733824893352, 0.272633439951366, 0.23274595368533368, 0.5032864567493239, 0.4436998009201019, 0.33499789995051205, 0.161546171011944, 0.23716951389947247, 0.20642435238245996, 0.20720407667179264, 0.20831931682844318, 0.36935688206745737, 0.3488576562414247, 0.31278306618332863, 0.2885071494646611, 0.42649573376101835, 1.3472363400843836, 3.2030442549336344, 3.381538573772677, 3.969756081219643, 11.535205283472616, 8.166309979654129, 8.096508460660136, 5.341667071465523, 4.3299318898108705, 10.113184298238448, 8.69000131084073, 8.602292210825029, 13.823307175790111, 6.649572580091416, 3.5012583819127854, 2.894090678422682, 8.058143267708441, 5.604429100790332, 17.417933902432843, 13.246873694081462, 19.75853377772916, 18.96342423654372, 13.181093585106636, 28.76169908431269, 22.140661747224872, 14.873211922184115, 12.546769842024773, 4.815324218042435, 2.339652377751566, 4.641416130527373, 5.905308723449708, 2.127356053360047, 1.7649384876412733, 2.027758494500191, 0.4171153854939246, 1.6527034198084187, 0.5287897995402736, 0.5212457333841632, 0.8126644766138447, 0.6008733412431133, 0.23125179111957553, 0.3283085427697628, 0.16612969038467254, 0.23125631103832878, 0.26768334750686923, 0.3676812332724372, 0.6138965908077456, 0.1539828760489341, 0.37575837404977896, 0.4454268388930829, 1.8381837250724917, 0.07917391526843272, 1.1507883523741076, 5.011318681701537, 28.676001179602842, 68.57860242166828, 60.0482709946171, 36.827039410991055, 47.570595664362756, 94.66867908354729, 103.7714647477673, 41.471341425372714, 31.505296999408355, 56.27617466834284, 60.555609964555316, 66.87714099884033, 91.84371748278218, 67.34342452018493, 4.9251613693852585, 0.6818053210454603, 0.30442982731807616, 0.212425057806315, 0.15652893862176329, 0.19214523956179622, 0.16036475618039409, 0.19625730842592257, 0.17311409866857916, 0.18987513718105134, 0.15133857036069517, 0.18183735800125908, 0.0966951045237722, 0.24425031136601205, 0.11816283402543877, 0.09587087052603883, 0.12457651446663565, 0.11828165426249466, 0.14532784450679057, 0.15626025626495962, 0.15886912272582132, 0.11867019873593124, 0.13014655590297716, 0.16610773430476267, 0.12829270739589008, 0.11334418694699004, 0.11360202915966512, 0.19035636297156736, 0.14970648132504957, 0.34920015883061195, 0.09907912417885759, 0.2185192259569322, 0.07218219850572848, 0.15541763615704354, 0.1846552898566569, 0.07915126970939099, 0.08415308074965593], [0.006491588710266496, 0.026991995269312497, 0.060671888321878455, 0.0599987804889679, 0.052178110626916734, 0.048529191708733, 0.012185595621685348, 0.010154438937353271, 0.07145256104488527, 0.019494292754379493, 0.07770849632159357, 0.029356483512768344, 0.024188230294854413, 0.024643508687375054, 0.02829690730469602, 0.026246865595420523, 0.08994480504864648, 0.03283034176415494, 0.008648305290168332, 0.028378832747318575, 0.0481699041331247, 0.08782024405175641, 0.01976939684320842, 0.06801733852273996, 0.033010161752181674, 0.05661443003543443, 0.043999716008622805, 0.043942255583862146, 0.03299332697004561, 0.029641215411585667, 0.06129635340203682, 0.030912344884728233, 0.11861446583943984, 0.28791906973046644, 11.41223995916305, 62.91222095489503, 80.7101325065859, 69.71171240652762, 58.294414551027366, 55.85277442009219, 25.63017483680479, 54.91191548685874, 48.03812649942214, 68.10689034000521, 66.18369733133625, 34.687021701566636, 20.6513907447938, 34.78898763656616, 81.89490010661464, 47.854116347528276, 2.4288941439121, 0.08489897459625237, 0.3294179913017058, 0.1729052784221788, 0.1022116500403612, 0.03567591790230044, 0.20832956708487005, 0.056209127388654224, 0.1012821555618317, 0.08514677339624013, 0.11509447568847288, 0.09317832428120798, 0.04121150453424743, 0.05069633953333382, 0.022500910150307803, 0.1964640295914104, 0.1456360570004871, 0.06156590909907415, 0.11452560177853993, 0.1771866986828466, 2.498825836566187, 2.8439039520678984, 10.459050074700388, 7.313896081139965, 1.9558164645587246, 6.151052078893108, 7.427136378903543, 6.440886307147242, 3.467692944311327, 4.339725557834872, 7.297056365397669, 9.000294131617393, 9.95325553801752, 5.886912317045274, 16.9696383706985, 7.059313174216979, 5.393760069724053, 6.969174656175799, 17.018352247053578, 20.830172377247965, 15.875502036463832, 19.63257862675575, 12.178395544328998, 5.458829249105146, 9.04728118450411, 13.7926979795579, 2.101351229413863, 6.086686474661674, 2.373939286316595, 1.4735415625956751, 3.6347104080261725, 1.518040361904329, 1.8350285459910671, 0.9042736383215074, 0.4410027117738801, 0.11359992241787334, 0.1031739330820499, 0.3430842031394282, 0.05528237550489365, 0.14621468320969613, 0.07106361054484883, 0.19232631210357914, 0.12164248198631311, 0.22676070791579064, 0.029690746826330022, 0.06026350217120302, 0.06019632392112286, 0.02420166173138686, 0.05091164854445285, 0.33124106605687453, 0.11109924289367853, 0.20428269230309995, 0.20397670146438385, 0.4758469339820647, 0.08000276111547025, 0.18785471817658794, 5.539305498523097, 48.49561606684039, 91.78485839597641, 45.0606043108048, 29.264040954651374, 47.392151355743415, 61.29203496440765, 50.691037254948775, 21.896272590083463, 23.90191578095959, 44.42161490840297, 55.12062872609785, 67.66294863916212, 43.452189353204545, 7.410537398630574, 0.05577777392200886, 0.06283380759639606, 0.05828135308899707, 0.024592561925190593, 0.029250500994103572, 0.07008854915658314, 0.016696311743749727, 0.05049576239299871, 0.10159814384795966, 0.02654033855745389, 0.04707327991303417, 0.045796276460732185, 0.06295203794575026, 0.051872656049747626, 0.04119067460358624, 0.03575603920786131, 0.06625974130245947, 0.010256830418872978, 0.0427960884577084, 0.03883039601327431, 0.031370325652401776, 0.03806787039784174, 0.01475674757403472, 0.04732428479098505, 0.0709397188057342, 0.04231932895979093, 0.016274461597805063, 0.0343137139814996, 0.052915209784142436, 0.02914273540579504, 0.06298477288275477, 0.013421692851660474, 0.04423236541990792, 0.028515033604156588, 0.08350420427779037, 0.024194893344575842, 0.016596716483153643, 0.04591848663685303, 0.05567962273715004, 0.0538556516591099, 0.04760758793582359, 0.01159688673778287, 0.06969531622504996, 0.061679788069018436, 0.036431954753014355, 0.04746510324278667, 0.05084310282742785, 0.019625544683226658, 0.014334831353006585, 0.027678938650135553, 0.05987608384701514, 0.07192437927569113, 0.009705026863112805, 0.10634379040810371, 0.07063091642433597, 0.07516858543479636, 0.02510392561464781, 0.01592729927881831, 0.12501039602343114, 0.08156339713041821, 0.02478544562754612, 0.03182038507093826, 0.05299348098736617, 0.03498549648230115, 0.096128620808163, 0.018728237388835802, 0.11712596466344212, 0.06635214682788619, 0.6506585149515061, 27.1656435151254, 87.97205571205386, 96.69677196010467, 98.22801036219444, 95.66516507056453, 82.85732423105549, 33.2532855772203, 38.038585032186205, 21.837205617658555, 52.65978859316919, 86.06629371643068, 52.95006359777143, 18.400617068813695, 18.899218959193078, 40.69671254004202, 28.070526469138365, 0.5748839003424491, 0.0608621271056754, 0.4592479230655778, 0.13216602495841442, 0.1598583720624447, 0.13236059596942318, 0.3837761276912305, 0.13408961044924875, 0.22206336319927247, 0.0486725842159602, 0.11673195032222618, 0.27772997776346825, 0.34907715575348947, 0.1704176530362137, 0.35250631852015374, 0.3065531778960459, 0.15651130327774634, 0.38183339000228916, 0.8465756343737726, 0.44868338672864827, 0.6753544930008151, 1.090355046814488, 0.95856481862645, 2.33515513520087, 2.841010468621408, 5.128600981927687, 10.869597696488905, 9.741854494617833, 9.502399679153196, 12.979133686711712, 15.004338718229725, 13.101687162153183, 14.601374999169382, 8.357114657278984, 18.930619493607555, 11.698310182940576, 5.624558704514658, 7.380706792877567, 20.531444664924376, 20.12463604250262, 21.496059433106456, 18.9933362314778, 15.624712551793746, 14.46088158315228, 21.009595317225305, 21.525420335031328, 5.513655649077508, 4.107863715579433, 5.577422111265121, 2.959384168348005, 2.5037131098008927, 3.0572095513343815, 1.8291707312868488, 1.3151633643334912, 1.3683263116305875, 0.929533395796053, 1.5067945588980953, 1.1238055099402706, 0.5216975413983869, 0.7829368330778614, 0.29443902954939877, 0.48121227672503847, 0.506860593994779, 0.6240712190347334, 0.26902590127241227, 0.2376779970983344, 0.08288348153714212, 0.054001396056264646, 0.15214481661396642, 0.39359645557499706, 0.09577267337590457, 0.19778019928884125, 0.0803674649327032, 0.7614720300320656, 0.061288780622905305, 0.14200945805397727, 1.7954648238035942, 36.24999992309078, 66.75328823827928, 38.502005223305, 39.753029500284505, 55.14713218135219, 37.828534264718336, 23.85089162857302, 16.86208894175868, 30.941591608908873, 68.0345618340277, 81.58351882811516, 85.30153351445352, 63.58742167872768, 18.529643435632032, 0.08903592599615937, 0.06852483346817956, 0.019403647315958818, 0.026225558775026473, 0.058788012998599204, 0.08877235344581066, 0.02201924194401551, 0.016019674160728054, 0.07238438443070458, 0.012570165056404809, 0.015619521540018822, 0.011078425243707194, 0.00564529568955843, 0.05554603615535363, 0.061050791578787955, 0.08236457188163074, 0.037639956665976394, 0.026879684864393166, 0.02014482589138131, 0.05140553010747798, 0.019310941101021824, 0.015718089285186462, 0.03954641243082382, 0.02650355484576956, 0.00993312475451779, 0.02711771029768692, 0.039665696151073904, 0.13439318045012413, 0.034409773746325124, 0.050952369948067976, 0.03519606340916888, 0.07215685631719328, 0.05924153321933362, 0.04452016933130161, 0.025100711875805454, 0.1627827135305251, 0.13163612194118962, 0.1227976046803017, 0.1892930788979415, 0.11056636745530753, 0.12054034193316776, 0.11626307386904956, 0.34593631783800743, 0.20370095577691832, 0.12962858853561263, 0.174314190723723, 0.1664286025709683, 0.1410149993194688, 0.05643233476627258, 0.15447922441507542, 0.12897845567955127, 0.1515883303457691, 0.14700968329223896, 0.19083751215329095, 0.2199401964824046, 0.25450260558676335, 0.15512495992645142, 0.1187533269365949, 0.20475193647848022, 0.14412770648637127, 0.24116510675559122, 0.1817981649430529, 0.1239058581150828, 0.13427616818056953, 0.2037525288159809, 0.14507224693173362, 0.1983916906700019, 0.13877422278446538, 0.5694408762839533, 25.846513163658884, 105.51481708403557, 111.23301306078511, 95.28198872843097, 86.19941896007907, 69.71559555299821, 38.37942723304995, 71.30594407358478, 67.35082995507025, 100.67447893081173, 100.85653181998961, 50.9050182373293, 30.664511457566295, 45.92453772021879, 113.85920463069793, 73.07694911956787, 4.113790662057938, 0.18179082582073827, 0.6251039668436974, 0.6077513399143374, 0.32236897116226537, 0.352372957934295, 0.6557192917793029, 0.3368222004463596, 0.3373916182787188, 0.15920640059536503, 0.26396607439364156, 0.3171270605056517, 0.387921582667097, 0.3939624617417013, 0.5657208758977152, 0.5837130943132985, 0.5583272694099335, 0.48337347204646763, 1.216975774976515, 4.0216870365604285, 5.087695073696875, 8.671001349726032, 21.45618854030486, 16.667637440466113, 6.76357283707588, 15.043982113561324, 15.596401864482512, 14.653401317134982, 12.523989696656505, 17.73864257720209, 19.486201655480173, 16.983125440536007, 20.96738669180101, 14.636425299029197, 29.017359172144246, 18.80043798877347, 15.506919853148924, 13.37700911106602, 31.665978854702367, 41.3204360777332, 33.02346214171379, 35.32828607866841, 25.4257663988298, 17.46678702292904, 20.23437415399859, 26.45439228703899, 9.978672496734127, 11.34794544789099, 6.31624662107037, 4.224130857375361, 5.661167165925426, 4.0556434854384396, 4.984498985352055, 2.678546141232214, 1.0268924457411612, 0.39147564840893595, 1.1967576727751763, 0.5778923582646155, 0.3484150106387754, 1.267887281794702, 0.43650399833436937, 0.3340786557284094, 0.4225487262010575, 0.37978159203644724, 0.3382852138771165, 0.32991959503100765, 0.2685516622037657, 0.11272026961969753, 0.3841003973878199, 0.8217166941012106, 0.20222448984221106, 0.3634861357990773, 0.5446220790186237, 0.9621966882578789, 0.18510156671606726, 0.4677628984134044, 7.832579035912791, 68.47178059239542, 117.70645356947377, 63.91398252979402, 44.76128432058519, 68.63202510341522, 87.15210776175223, 70.83851522014987, 31.575187752323767, 31.640250067557062, 60.30761026567029, 73.06751189693328, 89.14073374963577, 68.41565147522958, 14.230494306933496, 0.19312857469964415, 0.23572376809052883, 0.09039085974255878, 0.088345313054179, 0.17696715320550627, 0.2705848595548061, 0.0829932619366915, 0.07887578449181973, 0.2177707427331517, 0.12818368542338573, 0.14194801780244998, 0.09637122553202415, 0.1324382006761528, 0.10989322897888, 0.13593275670803365, 0.20711015429227583, 0.14469626630025526, 0.15427054206450141, 0.13598094363847088, 0.12438746694956096, 0.10791329772121484, 0.14329798729910007, 0.08165584096024114, 0.08237230936966597, 0.16386141129318746, 0.08136712540421756, 0.10610725310060287, 0.3298791149450887, 0.21640499182526143, 0.15478457173993512, 0.13909950371711485, 0.11048281024540625, 0.1196536104825716, 0.15581518982446965, 0.14392113853846827], [0.04066947434518126, 0.05497572200012304, 0.022330108932369662, 0.014217212916381899, 0.02147935297069771, 0.03909057096367882, 0.01115582119147744, 0.05053734564552865, 0.08802864294979842, 0.015458235134100242, 0.06371257556301933, 0.0643154407941526, 0.0728925611943968, 0.026690754175726927, 0.033698916930945656, 0.02618319411281376, 0.09880933865544297, 0.04906947521733181, 0.020510077461480133, 0.05866438555981844, 0.06437215428318709, 0.013708747912108177, 0.020270992911631064, 0.043036226378453356, 0.05584980150864971, 0.07643902734402688, 0.027945146542943777, 0.029174064571458488, 0.02287051501503635, 0.10920230960172993, 0.04852063450661879, 0.0563633255660534, 1.0785262815413938, 21.189583078507457, 58.86410743959489, 64.0338227056688, 61.1481192804152, 53.033849347022276, 45.4235843689211, 29.339878020748017, 50.91566354997697, 77.41431390085529, 94.35257527136034, 62.139965103518584, 33.3477323285995, 50.65001710768669, 72.6053939327117, 41.788112040488954, 9.496038575326244, 0.15422047055777044, 0.06602207018483071, 0.16214742745843627, 0.03916048031720904, 0.04244284531582267, 0.14570626129786815, 0.12217279103013778, 0.26913116175320845, 0.08513786379368075, 0.019839470905642358, 0.04615868201419231, 0.06172864532638943, 0.11639940687605452, 0.08423587953251216, 0.22264719880636663, 0.13058287361937185, 0.16479036951016995, 0.8507867890500254, 1.7636159134487954, 2.2610622980902275, 1.2627242169072552, 2.6346124083765092, 1.1302205463570933, 7.475294259286697, 4.031598620837735, 8.100541637789819, 15.805818188575008, 27.54023575013684, 12.754081814519822, 5.866444408893586, 9.980620934117226, 7.799025610569985, 10.885708831971693, 11.084162131432565, 13.883015455738192, 44.3168640905811, 14.62422868897838, 18.737725173273397, 14.606282864847492, 21.193817277108472, 18.08698631102039, 12.118645098901565, 27.643754943724606, 12.270273143245328, 16.60214170332878, 13.64982270425366, 16.03199578100635, 23.02887070563532, 5.339148419518625, 27.25663858075296, 7.3776350867363725, 6.591584749760167, 10.52194724159856, 2.6096661340805793, 2.446205524667617, 0.5216906159635514, 0.13106219951183568, 0.06900894741017012, 0.34570854457636035, 0.40255566998835535, 0.0881226879033831, 0.08798691414056287, 0.22665472731234568, 0.08726257800815568, 0.23066532017002184, 0.0938773948338724, 0.2086403229904752, 0.05363205740708978, 0.023232031906504306, 0.10599515911552215, 0.07678176742047071, 0.029733034879750306, 0.391160418549853, 0.13330179627143568, 0.10411275851149714, 0.16143432217499903, 0.031211542438775785, 0.03125270051250775, 0.3070828510868934, 20.73181502280697, 103.51481622265231, 84.31398268668883, 63.12553121197609, 64.45112759067167, 72.85725716621646, 65.08979928108954, 46.01177907759144, 22.40695341940849, 34.787304939762244, 42.01882193165441, 63.302877256947184, 64.44495378002044, 22.784550189971927, 0.05588539012317216, 0.010695171564997686, 0.04326445163197575, 0.0055448792784685095, 0.04467558558850039, 0.04672841394260045, 0.06734219289595081, 0.04524302691401494, 0.08697872711045128, 0.052290200781557834, 0.014976714399733372, 0.05908091139468936, 0.05340808394154715, 0.03963877199097507, 0.05275137039021619, 0.04168714171335582, 0.062328051670544574, 0.03641368355602026, 0.08855983299473602, 0.050728097708234866, 0.0664344782971086, 0.045213475072335814, 0.04356473128521635, 0.06710750186034749, 0.034482352916271455, 0.03618265825113462, 0.027475565288876815, 0.08926567576465108, 0.030849901058020133, 0.04651079900682934, 0.02311396626605382, 0.05220539867877961, 0.061142844703769496, 0.03154139691633323, 0.018271964997233405, 0.05604420398031512, 0.04904258936162918, 0.12269663429188153, 0.03529748578946437, 0.0039472139248954916, 0.09274922311306001, 0.03188602922995004, 0.021833996138265057, 0.0990114556325059, 0.04849980074551798, 0.0354449998497242, 0.04859620141946981, 0.07760610867051349, 0.04346785180631184, 0.08390921198071973, 0.04186791548084828, 0.058250993024557836, 0.04528689693899886, 0.01096948179521508, 0.06043064340408291, 0.08476926824979245, 0.03759397606876108, 0.06276530784464653, 0.06296279765064679, 0.011091726445292514, 0.04460241653085236, 0.027343279141331875, 0.0054946042796326505, 0.04170947700678822, 0.015436377688010615, 0.034572310790780096, 2.023382722850769, 44.36205763970652, 88.04425870218586, 83.52677868258569, 95.93601257570329, 81.23423176427042, 51.77490188229469, 23.20148244980843, 19.330099167362338, 54.383227056072606, 85.75663043606667, 78.41354554699313, 45.17345482303251, 28.908829150661347, 50.5232657155683, 28.732079305956443, 3.6837809749187964, 0.29281097013623486, 0.0907281376121025, 0.20683633914637953, 0.032519742906574285, 0.03502134556671785, 0.10552427551198391, 0.20239647658121204, 0.5932101330930187, 0.26127027227513255, 0.17055156520537793, 0.322800585098805, 0.3213303397980429, 0.33975990248783944, 0.13896174578657075, 0.16107738648931827, 0.47082590179577954, 0.14413973406678246, 0.2639052470124537, 0.5587133164367368, 0.593343983975149, 1.1890575698306485, 1.3874843932928578, 1.4565551256941212, 1.487276477198447, 1.9898680309134147, 3.015646891247842, 2.2002300139396422, 5.1182939737073845, 6.613097479266505, 6.192862583744911, 14.100326530395018, 13.556597771183139, 16.261669185853776, 18.44378863611529, 22.87945781984637, 39.599335347452474, 12.923452700338057, 20.183036211998235, 19.494597488834014, 22.40810267386898, 19.40270223925191, 19.440912008285522, 34.23032837529337, 21.308619168496904, 18.781247792705415, 13.056856432268697, 14.04240292887534, 4.267612782216841, 1.4584840738004254, 4.913406516275098, 1.6173023129663162, 3.1289200388616134, 1.7259511087209949, 0.1921851680644097, 0.8004418808606364, 0.6363432121372993, 1.3548990579382068, 1.1710138090195195, 0.6719190483131717, 0.8438195564573812, 0.5813697845705095, 0.5336847336542222, 1.554451356491735, 0.9752974046334144, 0.3893484673913448, 0.3391699841426265, 0.48010773115581085, 0.3963441984547723, 0.44062959631123855, 0.1537684327171695, 0.13298425282682144, 0.14702747185384074, 0.5113041797472585, 0.08619655133976091, 0.09258872769292324, 0.14643759947390328, 0.26927720875509326, 0.05498855014241511, 0.2726298853033974, 12.470395411214522, 66.03231737690588, 68.58730223871046, 68.9629005616711, 69.9289175771898, 61.80848952262633, 36.25546378474082, 19.50216374089641, 21.80962351060683, 61.652116390966604, 65.45854522335914, 79.89864118637578, 80.52085461155062, 41.263675458969615, 0.6515738980904703, 0.018145550913628072, 0.03767522735401027, 0.0339899345811817, 0.008318202791645402, 0.07278314085617181, 0.06135884319402038, 0.026875551820041674, 0.018541415357181144, 0.023931211626697934, 0.0349569597071217, 0.08959925342952052, 0.058629727742123994, 0.0454217437354307, 0.06012130859157732, 0.01966647484580115, 0.05197987005475068, 0.07881066701825588, 0.013449514292240625, 0.043297684526131044, 0.06064659975949795, 0.04913264299712835, 0.010167028634778915, 0.02534746113533695, 0.045067439561769854, 0.02045827459604029, 0.0495930771613794, 0.03448209627681682, 0.07366800305223273, 0.019082273431723158, 0.016459416290144288, 0.06483097966279715, 0.03720817419009344, 0.030600018498878327, 0.12976250070477688, 0.11250383445932982, 0.18179882377866777, 0.13888302259147167, 0.10149980880199902, 0.12790030950019438, 0.1803935733774016, 0.13891864567995071, 0.10663694161320887, 0.19285635301663032, 0.12748288351201242, 0.17954293998979753, 0.0885958391271772, 0.22707638210586964, 0.13533171476616015, 0.1432506737088965, 0.1434667105035436, 0.10743784057276864, 0.20569546568778255, 0.11675274960937039, 0.0979348109854806, 0.10573758503362056, 0.1845984614544338, 0.13813427889779692, 0.1302646866609012, 0.30548531261663286, 0.1075447864469982, 0.09163254271111182, 0.08170603504104, 0.10258884109075993, 0.11192313215184597, 0.1717753753426575, 1.5505634296324946, 45.854299837543124, 104.15685330667804, 91.3805090996527, 86.829328075532, 79.55779506314187, 60.22642504784369, 44.76185698663035, 67.6817838607296, 104.72494586821526, 134.77998179774133, 85.7169674288842, 46.89281402095672, 65.44296949140488, 97.02604709133026, 63.34486622964183, 17.83554473230916, 0.2405746368270728, 0.1495991370850994, 0.5167701864434827, 0.16787212672493151, 0.24526827367803744, 0.5079411150467011, 0.24551345245732417, 0.5667898443437392, 0.24116164403817347, 0.09881708380435744, 0.18153052446582627, 0.22514869038376117, 0.39884026612966295, 0.3103470904452186, 0.7556102316706412, 0.7168630366363834, 1.141492212491651, 3.433336658823875, 4.685288821497272, 7.744717453756641, 7.567206669238306, 8.935908425238825, 8.964788836817588, 18.706265803306334, 13.536067105108692, 27.469686039032478, 36.609783249516646, 46.39820314222767, 23.775350701424387, 14.666071553384105, 24.587383308718284, 17.626672637078073, 24.61240410804749, 22.864360617053126, 27.13326042698276, 63.33831979382423, 28.16869554981109, 33.33099165270406, 29.506539529369725, 36.30969055237309, 33.20865292702952, 25.051523254763698, 42.96065361269059, 26.386941248370757, 30.509065966452326, 23.24651125938662, 28.89071172283542, 47.46961032190631, 11.850334386671744, 46.63698527120775, 20.165067834238855, 14.030885869456878, 20.74308595349712, 8.178799296579054, 6.771474942084282, 4.609333593999186, 1.1925552208577435, 1.059759333729744, 0.47240539123454406, 0.49753166554916295, 0.19467815606584474, 0.4388293203326964, 0.7922604295515245, 0.43083068824583487, 0.39973321821420427, 0.28927847743034363, 0.35224879040352763, 0.3458032636873184, 0.4479782794031405, 0.1782431952174633, 0.19942800844869307, 0.30907967458328894, 0.7537044500631671, 0.2615842151065027, 0.2728104062618748, 0.49657111386618313, 0.4968731670129684, 0.1321798145410515, 0.332987715880717, 26.548472296807077, 127.27254959844775, 107.11683857825496, 82.26328126845821, 87.16991532233455, 102.51418036799278, 87.9655759565292, 65.11144684207055, 33.45211836599535, 48.99004651654152, 59.92557141088671, 81.15367412567139, 93.52511205980855, 38.93700784252536, 0.3133367332479646, 0.18546813978783547, 0.19230176664648518, 0.1465756638396171, 0.1234577809490504, 0.14879932597039208, 0.19872763554655737, 0.1914995959809711, 0.11573910803323793, 0.12286145810879047, 0.12177556678051911, 0.1826060506244821, 0.17280571763553929, 0.1247637999814845, 0.17643056990158174, 0.24619977530692858, 0.21377112025455122, 0.16627451164587853, 0.14075687365426173, 0.12062026788630795, 0.14608852385032564, 0.24762823817230042, 0.14108805346392816, 0.146552880384749, 0.10431727334376305, 0.07523931067196593, 0.12962293480673145, 0.13092801155101869, 0.10232860102288185, 0.16812452205246495, 0.15280686979812963, 0.2328245083410894, 0.15454657886537815, 0.12953042202899534], [0.015248446744085561, 0.05760725317222457, 0.007445026309259477, 0.020272015639009978, 0.10905328251781965, 0.07044357728333243, 0.035607954412097895, 0.03663447392623752, 0.048424896498721455, 0.021870867950060678, 0.04993741453114537, 0.04697543516334507, 0.03308459485490476, 0.02324264796991502, 0.13481308856318075, 0.04154770605025753, 0.06959084481481584, 0.09293380433753615, 0.03707995405420661, 0.04730849188842601, 0.023782757193511053, 0.03581823405599402, 0.09030163348201783, 0.10389875951072863, 0.04882911130064919, 0.04277414386911739, 0.08598382404494671, 0.009662221700343634, 0.06178006514786713, 0.04581986430792078, 0.03727585422776399, 1.6101882366403457, 28.748376754022416, 68.22097639883718, 76.45714575244536, 77.65319408908968, 54.1612522832809, 43.46830244987242, 42.874718404585316, 51.76985771425309, 72.48588715830158, 51.80026392782889, 124.7729721376973, 94.16459175848192, 62.361426045817716, 80.36103371650943, 21.129827730117306, 0.5379249996715977, 0.17830256703159503, 0.2596401291028146, 0.16218217720668163, 0.09683568165787766, 0.26243953695220334, 0.008955358118269472, 0.13390044801898543, 0.1150197744549763, 0.2045525391135485, 0.06773631448947615, 0.10161536550449748, 0.1329866276993867, 0.20712334632633195, 0.5538348072478848, 0.3477600973940665, 0.33197298645973206, 0.7577861665237335, 1.024972016532575, 0.4931254955309053, 0.6774204176279807, 0.5481104144165593, 1.5668782832161074, 3.4619471623051554, 3.2018570025121016, 2.1142435698739948, 2.7987184928309534, 1.8303213340620843, 2.4580790294754893, 8.390351841526648, 8.721755839163258, 7.591751390887846, 10.256559675739659, 15.465875191073264, 16.465898175393384, 33.58475723574239, 25.654970099849088, 22.726877620143277, 30.006928059362597, 19.232438033626927, 15.995524602551615, 21.69358999498429, 15.044547915458681, 21.60274790179345, 22.6757122624305, 18.31435630398412, 23.997813809302546, 14.032188096354085, 7.5577753301589725, 3.427939232318632, 0.5711401818740753, 1.6957806050777438, 1.552997015176281, 0.3172868664466566, 1.4177674199304273, 1.846310263199191, 0.5074140159112792, 2.7460748918594855, 4.321332093208067, 5.369769382861353, 5.120144842132445, 2.7080102505222445, 0.6363951222550485, 0.412457907992986, 0.899693719562023, 0.6665153705304669, 0.6113217999377559, 0.5100491745097022, 0.12569581488928488, 0.07967200265416215, 0.3211733530605993, 0.2014837441064658, 0.21926872041677276, 0.07520006398760504, 0.1579933310107839, 0.16608945544688933, 0.11125410756757183, 0.0630066485234326, 0.06940227993313344, 0.26219389852016206, 0.23612535138043667, 0.3153204719626135, 3.597813652407739, 56.00839053430865, 121.18361903775124, 116.32393575483754, 75.13337719825007, 57.37215941952121, 58.685796491561405, 41.776203724645804, 25.00903614105717, 29.43911986966287, 42.17449295905329, 61.48525484146611, 71.50465919125465, 31.253722060111265, 0.18914623516461543, 0.05572678310976875, 0.0364190423410506, 0.06367166646786275, 0.07237849321456687, 0.0760205211718717, 0.007591080014413644, 0.022373716572239515, 0.011642835733871306, 0.0877856475210959, 0.04188408376649023, 0.06914192495206672, 0.027993076833926385, 0.04925967952717216, 0.029820324853062633, 0.043402653893515955, 0.06290231500902484, 0.0711479721470706, 0.052593437534186153, 0.07056030610035505, 0.04242455496663048, 0.052331113707154035, 0.019867136255807934, 0.06741287216784493, 0.017633231529485316, 0.021020941278566758, 0.039967266662466916, 0.026739253286993312, 0.08421881875443844, 0.07265351111850432, 0.03209142697854869, 0.10275266899336731, 0.021171789736517017, 0.029171237707017895, 0.0517751292265471, 0.04172646117606952, 0.016664180100985592, 0.01837640193351094, 0.022626989070446264, 0.04914881511320991, 0.009531445703619431, 0.03361238346945855, 0.06135169942412646, 0.08774572667936165, 0.08506674019079055, 0.03940256793172129, 0.0486081715432867, 0.05253504248215787, 0.03334416842628871, 0.08467654862831678, 0.020130793075828303, 0.06977915688748322, 0.019704541754758647, 0.03785099473691756, 0.02593800575742799, 0.14495980054620775, 0.026993665340987426, 0.10925603534785971, 0.020868962840928186, 0.09578756612515259, 0.04802673379139555, 0.050154746014384494, 0.09414770129707553, 0.010698923480606849, 5.344434793918364, 53.28825035402852, 93.372202381011, 102.40365582127725, 116.56292576943676, 81.13953790357037, 47.177805592936856, 27.7090859413147, 37.12296262864144, 65.53096002148044, 56.92529555289977, 135.74168420607046, 98.39498566042994, 42.90458333107733, 52.629452982256495, 12.68271723101216, 0.4450959501968276, 0.03440462563547396, 0.24623660881432796, 0.15718688557465232, 0.040454969726382725, 0.2643014370433746, 0.38541540263160584, 0.6081175299421434, 1.6149852953610884, 1.0363084630620096, 0.5940442496249753, 0.2813945133839884, 0.4967653018332297, 0.5534961963853529, 0.5437435906740927, 0.301553167162403, 0.49048687421506454, 0.9558489450043248, 0.5928458429632649, 0.4281646103387879, 1.1022929030079995, 2.0745418292860833, 2.9387034716144687, 6.7132208808775875, 6.710935609955942, 6.021663873426377, 5.2241455066588625, 5.246305917539905, 3.4085271771877044, 1.6300052764915651, 0.9227866739515336, 2.3998394320088052, 0.8448688517655096, 4.249615476977441, 11.478833959948632, 31.991563035595803, 31.11220882784936, 27.332675687728393, 29.585361519167503, 23.90477126644504, 20.978783138336677, 22.539611901006392, 17.945431893871678, 27.55587620119895, 27.887436113049908, 18.26121211051941, 12.980237833915218, 2.3671991834717416, 1.891762933904125, 1.9748974471322953, 0.3587192609425514, 2.3103880641921877, 2.132687044720496, 1.7099359487333607, 1.209531606685731, 0.38926548474738676, 0.9554673719309992, 1.189657447318877, 2.988225111076909, 1.8447188840758417, 0.9524319477138982, 0.7549140722520891, 1.2705153923842216, 0.9802797340577649, 1.0955643221255273, 1.136662671642919, 1.6413335718454856, 2.108120995183145, 1.465400070432694, 0.6569338782179741, 0.9186521893547428, 1.1812720327608048, 0.6627024590007721, 0.14743075585894047, 0.14320832436844227, 0.21341366362908196, 0.3231030366113109, 0.043168311427918174, 0.12401494137462109, 0.21539833697099842, 0.46288696327997797, 0.28067147960105254, 0.4758107133450047, 30.033796295042965, 95.19736751433342, 118.79774324355589, 91.64530830998575, 64.96262427299254, 46.21172974186559, 18.272408516176288, 22.371259850840417, 50.57524104272166, 64.70564626878308, 78.89819360548451, 84.19717450295725, 54.88099544279037, 2.255700908360943, 0.1473503625921665, 0.09011728974479823, 0.03722219359910777, 0.03240934580624585, 0.024701934382920305, 0.0474112204486324, 0.0591616532314689, 0.07210905243071818, 0.060234957735144326, 0.03375788654891714, 0.003867202505071257, 0.03451056410408309, 0.07089615904635961, 0.02376529230405727, 0.0719986821434671, 0.007829516262356794, 0.06366471805038952, 0.0479163711650237, 0.0784405163158813, 0.06306575603723046, 0.057873334660525286, 0.017314665357492143, 0.01299244038114745, 0.03302081420476879, 0.09532097261399032, 0.029435258418802294, 0.0069963879838225345, 0.032831985022752516, 0.03262714460311878, 0.11095598445183809, 0.04764322634606112, 0.05249301106819222, 0.06672025207550296, 0.1054482642681368, 0.13083183687300454, 0.10484262579871763, 0.1870745342345007, 0.18070785328745845, 0.13547886493465594, 0.09521285462523661, 0.11634284660460488, 0.18632315519836642, 0.15999832100445227, 0.23974157749645172, 0.16345504761463212, 0.166598214437404, 0.2483365017800562, 0.15412913755543772, 0.18244206184341064, 0.11065904111150773, 0.1769462696486904, 0.11197348711110892, 0.1702035621048943, 0.09585694304757542, 0.17882289394976633, 0.26792291852255024, 0.10100385114069908, 0.13542975869870957, 0.16131003207016378, 0.14354941735584892, 0.1718953906768753, 0.21507841865381888, 0.1379055863306407, 4.521599488873636, 56.55143483992546, 113.54236341291859, 106.97851227175806, 108.89328002929689, 72.12679416902604, 58.032541428842855, 61.54108585849885, 76.69027574600713, 112.39882776814123, 70.61882326679846, 131.97487523478847, 115.53466858402376, 82.20449278431555, 115.82940332351194, 34.32828957034696, 0.8210155704329092, 0.2638912122816809, 0.4545240410633626, 0.47000376687895873, 0.31623156500920174, 0.5729515814492779, 0.38819878392161866, 0.473498874494145, 0.6422566141813033, 0.5046933006134726, 0.19830052620701252, 0.3400958473643949, 0.5591056760280364, 0.6038882343038436, 2.718014255646737, 1.8681552910035657, 1.3072491244923685, 1.3434662069043806, 2.1111461231785436, 1.9355905176170412, 1.7670907656992636, 1.4477269736028489, 1.3927887860805759, 3.717472418662041, 3.6547890209382583, 3.521191131684088, 3.8411209708259957, 4.872887942098803, 6.801593351748682, 16.759513078197358, 17.062661301705145, 19.255215237217566, 20.003211229078232, 28.715936791512277, 28.798520334305305, 50.94155119311426, 41.460711802205736, 35.11846673104071, 44.04489086520287, 32.67348474071872, 31.07320281767076, 39.69029511174848, 30.928190831215154, 40.41164252065843, 37.108277274716286, 34.260628684874504, 36.9018703891385, 23.130336538437877, 14.090178378166692, 7.316973670836418, 2.529055788632362, 5.233251779310165, 3.8644252429085397, 3.612017780542374, 7.286742493029564, 4.06529815446946, 4.373185826886085, 7.995633925161055, 10.657338634614023, 13.093498233825931, 10.106583929830983, 6.1494208631976965, 3.3912895860210543, 0.9093440372136332, 0.6516560227159531, 1.540504756473726, 1.3763820019460495, 1.2014397570202429, 0.7723729708983053, 0.2891994478000749, 0.5138707581547, 1.025787624380281, 0.964391009221154, 0.20949477149594217, 0.2554817732063032, 0.4224413513175903, 0.4865826756483125, 0.17213949693306801, 0.33385937072096333, 0.4462707000634363, 0.49759617015238733, 0.4729212135557206, 4.25329024753263, 65.14650890904089, 139.49205060159008, 131.9329215634254, 92.14423379590436, 86.96432821212277, 88.43878638359809, 57.53843653586603, 35.896143297995295, 42.25417590910389, 59.018488007207075, 77.87246242646249, 95.38868504185831, 53.11756057123984, 1.0946545773936858, 0.34904078189884463, 0.23400979957753615, 0.1768910040658328, 0.17206460417759034, 0.09609023214227731, 0.07786527621529757, 0.08652640581731835, 0.1771035168560282, 0.16528218263579955, 0.1758804881284314, 0.10106583531465262, 0.11684292581893745, 0.19545867708661865, 0.262001242728964, 0.12335928502462565, 0.10374230137395282, 0.19130789013879915, 0.14322168494184173, 0.1536067268781124, 0.14164424861871427, 0.2207472547888756, 0.12733419350678885, 0.1325100903669673, 0.12637672149726462, 0.14163908518610463, 0.09820405258646897, 0.17887023818348685, 0.24941115459847837, 0.1424648207161696, 0.17722621349798096, 0.14734892234686883, 0.1709373364405286], [0.01733437488456407, 0.034932532993656014, 0.11586398802577488, 0.21463232565551035, 0.039916034532530655, 0.025038607043003844, 0.03668960544370836, 0.029812648652061343, 0.04667801301806204, 0.07570459417277768, 0.009838239019436222, 0.05838139651102885, 0.012649597840443736, 0.10578565705086916, 0.04661315218395284, 0.011772948106931103, 0.07049171058761497, 0.023058068660658695, 0.004768725437667942, 0.014921204626349913, 0.09084830616390513, 0.08037795267638662, 0.0563558447174728, 0.02995560831961132, 0.0300568315170465, 0.021568571570359414, 0.04551814440938254, 0.1029442752441091, 0.035205038129201824, 0.1163498639699913, 4.877232457360914, 34.43820614968577, 82.73736246170537, 69.1832357837308, 70.9116203554215, 48.610459143115634, 35.57932169206681, 34.65825503872287, 49.7348653885626, 56.732260027239406, 47.61098431002709, 109.71402029837333, 83.20956091726981, 36.13950283296647, 51.69174763464159, 14.356962307806938, 0.10591460497028406, 0.008320054809202351, 0.14545775769699007, 0.09059018049869808, 0.06120975099263653, 0.10614795535201989, 0.043796017059996244, 0.024972072306780085, 0.09050552012218584, 0.5054205019147165, 0.8492627030899449, 1.518268104522459, 2.0766493678092957, 2.242081213381983, 0.9578040013870887, 1.8389929590686676, 0.16224295862259405, 0.12284143257044977, 5.76696966924975, 12.425217551569785, 26.89258771557962, 47.45934940153553, 65.9230322991648, 75.10078230211812, 89.69785151943084, 84.81653244264665, 82.99537597164031, 73.09835741596838, 60.00020627052554, 33.357165628863925, 12.571612173511136, 4.104489006342427, 6.592702134963005, 10.360723118628226, 10.768297583826127, 13.58031242124496, 16.434229939214646, 25.579056547534083, 21.499913161800755, 23.576047228228663, 12.570871826141113, 14.921410987454077, 19.780402952624907, 20.00156383360586, 16.177792241496427, 12.037933507273275, 13.8405587404005, 3.1620768145207436, 1.3022878165206602, 2.5891992065214344, 7.601983874074875, 22.146980685572473, 32.859540408657445, 43.305586845644065, 41.89598506496799, 39.37756453790973, 34.70888499290713, 17.536697387695312, 8.54405580028411, 5.477920895622623, 1.4940570294857027, 0.8501228053242931, 1.3776191420132116, 2.4755421569270473, 0.8839324717560123, 6.145125377562739, 4.468697501767067, 1.0312710365941449, 1.0008759772585285, 1.3368715994781064, 1.417828461816234, 0.5755695796781971, 0.5429920277768566, 0.38030483008873084, 0.22570684672363345, 0.40878007308610026, 0.034963862159319466, 0.02501668926749018, 0.317371626414599, 0.18683277220735628, 0.14557703758680052, 0.25243844296182355, 0.3211422192473566, 0.2558849346373351, 0.18041461015180235, 13.221217470784342, 54.99712505648213, 82.6904038460024, 88.24182064302506, 108.32852932714648, 66.4980988348684, 46.11104249954224, 30.48063074388812, 32.90790911643736, 37.88190595565304, 57.761215394543065, 67.94499058877268, 24.669490283535374, 1.2024440063584236, 0.13740908474691454, 0.12414113903838782, 0.026944934488123944, 0.010034099930987484, 0.029175230940323205, 0.061381979049333645, 0.04812154100246487, 0.07768281705437169, 0.0516854816176478, 0.00462649355364603, 0.052020499527814894, 0.02310743536649933, 0.057647388518577626, 0.09021880405564463, 0.024627290606018037, 0.05773081549353177, 0.03567758414353575, 0.05432252479236453, 0.07206764537841082, 0.043581481797680746, 0.049043669545602415, 0.01296285789595136, 0.01920166440428265, 0.022353081993999022, 0.035094323102384806, 0.1099048964979668, 0.013837849049107924, 0.04237139995600428, 0.024048610770654295, 0.013629079556032537, 0.0644885077171268, 0.04063194369777076, 0.028526034626749255, 0.08285254690675967, 0.07516726010268734, 0.04675702732657233, 0.027712736534135, 0.0156432137666871, 0.058434842635066285, 0.06423939890678852, 0.06516692453935262, 0.008099046103926677, 0.05574105532779809, 0.06677519590143235, 0.05351625172601593, 0.07607332761249236, 0.047800806801645994, 0.0349206279873127, 0.019310100319524928, 0.02414176323180718, 0.05577113577014497, 0.08015472231613052, 0.04896392362312444, 0.06494006292233545, 0.055628819616451386, 0.010362917317017432, 0.021971989640845888, 0.0690716746894102, 0.14268200664270309, 0.02451031281042003, 0.1148695982391796, 9.451115669742707, 59.47698170138944, 102.42118881594752, 97.52840072877946, 99.89737895227249, 81.92343142724808, 34.19980841298258, 19.313750728484123, 36.76199474642354, 53.69128565634451, 55.3638784347042, 112.34551491275911, 89.80785831328362, 28.482285122717585, 32.35043244977152, 7.094139408680701, 0.07500459665372487, 0.08119783529471006, 0.07255395033186482, 0.07601144302996897, 0.026919454403762377, 0.2878773945473856, 0.4194365399739435, 0.17976568771466134, 1.607638083158001, 1.77057848822686, 1.4281452759619684, 2.1054630990951293, 1.2416075242142524, 0.12141385070619085, 1.4265287691547026, 1.1585008352994919, 0.16599010916486864, 0.5610931532517557, 10.743990655868284, 19.731830281596032, 38.45698818083733, 63.1005496363486, 80.36341067283385, 91.9378935906195, 100.93585783435454, 100.94923311664213, 98.30819145325692, 92.60035837850263, 79.17758403285858, 51.80277424473917, 24.496213697618057, 9.433974912089687, 10.567385938859756, 9.648300082452836, 3.2742328220798127, 0.5120520654224581, 9.65349918411624, 26.284081012971942, 25.19825520053987, 25.05383941435045, 14.652628610211035, 18.580808793344808, 20.231334317115046, 22.53602881585398, 19.7000551608301, 6.539857512520206, 2.9516306231098794, 1.3546463102102282, 1.407198470927054, 4.785128831863403, 12.96105940495768, 32.9659366607666, 46.50013769826582, 59.66391794143185, 58.043433850811375, 53.40581555520335, 47.21256171503375, 26.5677664356847, 12.526751045257816, 8.637679834519664, 2.4315160032241576, 0.4153884700950115, 1.792815998196602, 2.5620098267832114, 1.9002831799368707, 3.040295065410676, 0.8396861137401673, 0.5537166458464439, 1.160581162379634, 1.0728422768654362, 2.610178493684338, 1.0006533827512496, 1.2460575757488128, 0.8771491615522293, 0.8157576945039534, 1.6621362297765672, 0.288559427304614, 0.1841758873554007, 0.18069220977204462, 0.15633030734475584, 0.12766819252001663, 0.13283166343406325, 0.4147444659423444, 0.13567213359619343, 0.3044913595001544, 5.897261000448658, 45.14153849694037, 78.1099227166945, 97.99267599659582, 119.37532009616976, 67.97983692538354, 23.928405507918328, 28.37175077007663, 52.31188612599527, 61.075677025702696, 79.29759287065076, 81.06245548494401, 45.72941941599692, 4.701911826287547, 0.004844992363359779, 0.09964756907955294, 0.033626843379029346, 0.0020171899438625384, 0.06728898808960954, 0.08309008778944131, 0.07947334073363774, 0.03855162427850789, 0.05566924990665528, 0.07445228556471487, 0.057432611938565976, 0.04495136574992249, 0.04699462949628792, 0.03957281182069452, 0.018837052517600598, 0.025719103793944084, 0.02764172209877401, 0.02747378030401324, 0.08583501146565523, 0.08068461767247609, 0.055716877592907804, 0.030786375132118984, 0.027787922318243695, 0.02954583554979294, 0.05566655710760144, 0.029717630766812834, 0.039127829649876204, 0.0337087688216519, 0.1118669779069962, 0.006601630537320049, 0.10233717354675455, 0.08760025424342002, 0.11823748163278065, 0.16733830133753438, 0.2780912954720759, 0.17095388393969307, 0.11878468291533571, 0.14244700151105083, 0.10498281988886096, 0.17352944089760705, 0.1769869489174697, 0.137919636383172, 0.1903770779890399, 0.0963579032630209, 0.11458266766801958, 0.23094311897312444, 0.18835325755419272, 0.10632054730048103, 0.11091696759385448, 0.1386898458604851, 0.1267538512606294, 0.18000853758665825, 0.22599250558883915, 0.11163823937456455, 0.2122888780168949, 0.15916936790510533, 0.14401699145955427, 0.15956330563752882, 0.24539412660223825, 0.11332845916190457, 0.3590568912125403, 9.551139050914395, 65.92115740622243, 121.58364588214506, 95.97175321271344, 97.57169585074149, 65.84329051356163, 54.63983243511569, 55.478497935879616, 69.53726891548403, 88.88261825807633, 63.654121583507916, 126.93372741822274, 114.4002720617479, 50.01600127066336, 74.82151739058956, 24.59405722156648, 0.16851429226658038, 0.22196237748909384, 0.6700672605826009, 0.15342629785018583, 0.31661957322109135, 0.32031505879375244, 0.2330388444205446, 0.15703470986937323, 0.8430085451372209, 1.903968614435965, 1.9739079066822607, 3.684752496980852, 3.7434635143126216, 5.082397912779163, 4.599868424477116, 3.4114245830043672, 0.5508447967229352, 0.344086338074938, 8.044947433856226, 14.315025306517079, 33.443151827781435, 56.272013033590014, 78.09086784239739, 92.13996625715687, 103.61795886870354, 100.72735248073455, 99.36168516835859, 89.30424167263894, 72.4937318986462, 41.5588612710276, 17.963976860046387, 6.151526685683958, 11.791304676763474, 18.197512818921, 23.977917586603475, 26.954417997790923, 29.291366146456813, 40.343710991644095, 38.08649678384104, 38.725074337374785, 22.80799811886203, 28.843141217385572, 34.93855545597692, 35.074697002287834, 34.170574988088305, 21.242729233157252, 22.03192384012284, 6.872752501118568, 4.688549291703009, 4.434428243867813, 10.113543195109214, 31.21136046225025, 42.44786647058303, 58.88832807540894, 53.898551540990034, 49.9704860871838, 43.54835018034905, 24.746360894172426, 11.823360246996726, 8.587242076473853, 3.261465507168924, 3.130910151427792, 7.314732526579212, 10.253176631466037, 12.783020081058627, 20.033174214824555, 14.675622524753695, 5.799504749236569, 3.1567600417521695, 2.801326623847408, 5.0010680575524615, 1.2966277137879403, 0.9978778768450984, 0.5481237749899588, 0.5503665739970823, 0.9870077020698979, 0.22551817458964166, 0.21910490017504464, 0.7300666539419083, 0.3554114465030932, 0.2740028987248098, 0.37950147964781333, 0.6820632781713241, 0.391334014073495, 0.3718895993886456, 16.404393449906383, 63.311447635773696, 94.3066050929408, 101.95007293455063, 122.70623607020225, 92.60697149461316, 71.66704531638854, 46.25322449591852, 45.18222916510798, 57.02578275434433, 74.20423046235116, 94.27185289321407, 49.02698739882439, 3.9770720370354193, 0.1640853694369716, 0.18461810394881234, 0.13405426315242244, 0.09547605945338165, 0.17706009499248, 0.12714502341564626, 0.20466426537642557, 0.11667036451399328, 0.18519167397772113, 0.1394640083514875, 0.18788782849667535, 0.09919098067668178, 0.12609579705543097, 0.14099259890856283, 0.21872210136104017, 0.13529282814312366, 0.12324980339936673, 0.17190415472272905, 0.14143651621716638, 0.1619636429654014, 0.10007594246417285, 0.1351731192440756, 0.13464583624755183, 0.11273459546388158, 0.14938126167943402, 0.18218333862962263, 0.12567477811488414, 0.10201818219596341, 0.2373545241331862, 0.06700231032746454, 0.20741787648970084], [0.03836566409576805, 0.019095176267587853, 0.00809559775065751, 0.08476015180349351, 0.036997009714644764, 0.02483758365645284, 0.040700324705892035, 0.04183498902186271, 0.017600870060343898, 0.02976942597137344, 0.07105866161685798, 0.13562388537872222, 0.0909053031054716, 0.07038165439641283, 0.03034002357913602, 0.030856002948337027, 0.013229156761700589, 0.10955520034317048, 0.10616009018474049, 0.05129666135255849, 0.05406532226310623, 0.03461854419701042, 0.05089711585652925, 0.08948560428595351, 0.04956521454357332, 0.03952787693349585, 0.046481109269323855, 0.0652051829702912, 0.23434540737540493, 5.567258759852379, 42.5710641953253, 73.7835091929282, 76.63984975507184, 62.679385139096176, 57.495627787805375, 50.579383065623624, 50.75044547357867, 50.783032524970274, 54.73037250580327, 41.64832661228795, 96.05252265930177, 79.3470931822254, 24.63658944252999, 32.736064195632935, 5.741198716625091, 0.17672609597925218, 0.1928947033781198, 0.044379320235983025, 0.03522413287071451, 0.38259668936652524, 0.2758831849261638, 0.007663070733073138, 0.613523536632138, 1.2202018018691771, 1.9310186274590033, 3.510517381852673, 2.0821242611254416, 3.2703705132007603, 0.8731947995481953, 0.011460514468771797, 1.5745048417199043, 11.43784813342556, 26.635937229279552, 55.764105319976814, 89.42948295224099, 106.33861680184643, 103.41854556914299, 109.13623163777014, 95.23995660966443, 95.00613627895233, 86.61464106652045, 90.4574106585595, 89.55808178071054, 98.05244507328158, 96.82885385328724, 107.91675890645674, 94.3031769414102, 71.9337978670674, 86.6779951895437, 61.56408663718932, 10.892329792822562, 1.763844146363197, 6.1012056181507734, 20.41095925915626, 15.807349874127297, 12.26349920995774, 11.748851883795954, 13.531984898351855, 14.36675548553467, 15.953281656388315, 11.823683842535942, 5.8261253852998065, 1.3193588295290548, 5.963234776450742, 27.277356540003133, 50.747193828705825, 78.29167750573929, 86.4296934681554, 88.69872185491747, 84.28112106938516, 94.8049500680739, 92.45102590130222, 86.93750704488447, 84.22205801933043, 80.1848957615514, 66.90841013385405, 48.20106567875032, 30.95103079272855, 14.759769132060391, 3.0753230567901366, 1.033732691599477, 1.0214535892009735, 0.6184641908734076, 3.168392320794444, 6.520007867966929, 4.898916790562292, 2.8900457341824812, 2.2512370059567113, 1.6672486715739774, 0.3919782020872639, 0.290978487821356, 0.2985498573510878, 0.3604895675614957, 0.18587445750111536, 0.1453280283678924, 0.09793340138369992, 0.28344107130842827, 0.059983194430148414, 0.12388042399599669, 0.16781244847563007, 0.03780917016669147, 0.11239144936083786, 10.446086641280882, 30.21164832576629, 67.02237067684051, 81.27882911312966, 37.18915654766945, 55.56060098832654, 44.462882164985906, 25.55302966025568, 29.243754456120154, 41.40972883470597, 54.107001981427594, 60.193218261964866, 45.35882211500599, 5.101057608281413, 0.06449157972970317, 0.06052037145221426, 0.11232565006902141, 0.028363681443396117, 0.0071791138391070555, 0.009437545349130468, 0.1768441501283838, 0.039629996453802434, 0.12077347781028479, 0.02743635499369233, 0.06322590671780129, 0.11481149813100217, 0.052315604257126974, 0.07376915730175472, 0.12968394604902114, 0.02211969905352641, 0.09935617987667361, 0.020244913363468744, 0.0447295296696886, 0.08438663031425207, 0.009503305378940799, 0.034451341677096584, 0.06591623513809135, 0.03732957231301454, 0.040507519527548747, 0.05421428422954294, 0.03385958472086537, 0.060216973821121844, 0.03610925170623007, 0.07247482877104514, 0.05312639724222883, 0.053937293649200475, 0.07118907276420824, 0.06491367119334399, 0.06129775151249863, 0.02841314965588672, 0.028308197525480104, 0.06345745679291506, 0.03892445245817785, 0.010624321838540417, 0.07038883264026335, 0.007166996243364749, 0.06192035499900099, 0.09657284455193628, 0.04193869817461218, 0.037381926761759866, 0.05764482978491053, 0.07156026534615986, 0.12322889685991312, 0.07919423958106388, 0.06334761127589211, 0.03970892649264105, 0.09385069666971123, 0.044507479084835905, 0.004593219482264812, 0.02477181309293355, 0.04417164912146907, 0.0847563749900268, 0.40944969521895536, 9.833060387642155, 66.32834649855091, 95.7352892045052, 102.08796778032857, 95.41449423759215, 92.91098656192904, 38.72141084363384, 33.661051257964104, 43.464882143082164, 50.205185028814505, 53.03997608923143, 97.47786491147934, 77.87742030236029, 23.701961194315267, 26.45795968271071, 2.2119191673494156, 0.2169275097548962, 0.1237668514612221, 0.09175481800470622, 0.048442853599666595, 0.36228653404020494, 0.47504214329584954, 0.3246687364674384, 1.534669250249863, 0.938638749141847, 0.1485043974413026, 1.9278974013943828, 0.22228399652146527, 1.690283158133107, 0.35192507229024367, 0.38863606690879793, 4.173048850028746, 18.752110465880364, 38.86656991897091, 70.95638244382798, 102.80580859030448, 115.48508198030534, 111.94275809872536, 111.23054981231691, 102.73326827633767, 100.07208916448779, 93.30915420286118, 93.93907116305445, 92.10224090083953, 98.26258213289323, 103.77251594297348, 112.97024649958458, 108.39946146934264, 82.90462017059326, 102.1282583667386, 81.82057903658959, 16.044953330870598, 2.627122397384336, 2.936855054670765, 15.380211607102426, 16.779260250829882, 9.389148104575373, 9.867014385038807, 17.97184709579714, 17.004902439732707, 17.814867957945793, 9.23805840553776, 1.0517162685432742, 2.1030738853639175, 11.361149126483548, 43.86414020292221, 69.5401793141519, 94.25570057284449, 98.76448077540245, 102.57692260126915, 93.71872809625442, 103.26548684027888, 101.16735612192463, 98.11786236301546, 97.01764537442116, 95.26762500885995, 84.36848794260334, 67.13725689918765, 43.799574067515714, 21.612959792537076, 6.111036548691412, 1.7608464749590045, 0.4866769963935499, 1.7234057356272976, 1.7244447960007576, 1.2521888531984822, 0.5068524428192647, 0.8315460924660006, 1.033145806962444, 0.8974830349606853, 1.374921777075337, 1.1042268766510872, 0.8303345090919926, 0.7527239188071221, 0.6452375542252295, 0.18626778236319944, 0.08715089771055406, 0.17663136154653566, 0.3062160685658455, 0.20528547075246611, 0.2165417385197455, 0.09611407279848092, 0.200223422218715, 8.711519433606057, 27.988352814028342, 58.49179606283865, 80.91335834995394, 41.71832523038311, 58.14502716064454, 25.424879943170858, 24.114012064472323, 43.82519106711111, 61.501203198586744, 74.84542031441966, 73.78640390211537, 70.37559709241314, 12.31133153361659, 0.07606489298444602, 0.023862813381598364, 0.008854237385094166, 0.06862634777902596, 0.03706296222404607, 0.07502513547097484, 0.0952240931350858, 0.11826791830601231, 0.0916068404612522, 0.007827264921469314, 0.02321781139940985, 0.06758287473912201, 0.013857893739646722, 0.018030731570756724, 0.08126984755959242, 0.05723000466523152, 0.056858264330414035, 0.04798867071287767, 0.04136705868727258, 0.06644882712393038, 0.03981713641194567, 0.04042159127552183, 0.027572389226406816, 0.033439527220663526, 0.039397948421537876, 0.08358891061957806, 0.04699537260157447, 0.06734292067947888, 0.04983871942386032, 0.03341319677870601, 0.10754856326046491, 0.15957272851899748, 0.08612899770659786, 0.25730258034121606, 0.15135085841100063, 0.08115838942748886, 0.15558234506076382, 0.10908240918070079, 0.09823687945402439, 0.08020612681584974, 0.20571207447398096, 0.1416405867184362, 0.14363442247192706, 0.18454023877218848, 0.155471446172845, 0.1318186194065117, 0.14876382545598094, 0.24629935141532655, 0.276423828496087, 0.1184885516282051, 0.13483953391832693, 0.16451370451719532, 0.16169221801382883, 0.1320897992099485, 0.1839892223717705, 0.21662567111272968, 0.28217708752039944, 0.14457781378540302, 0.48576437117111304, 11.47235812679414, 79.27297607544931, 109.71754258678807, 104.73772495023667, 92.67481280911355, 80.3499569431428, 64.96618186273884, 75.1339106405935, 75.78830319066202, 84.65071816598216, 64.66311993137484, 122.5364915786251, 107.747296825532, 40.231460602052756, 47.77211919907601, 11.297890120936978, 0.33828772664550816, 0.6657307126349019, 0.21846045169138142, 0.1932208116857275, 0.6041689289193, 0.632329462997375, 0.2986006336587091, 1.4178014955212994, 2.3416459223916455, 9.301322314047045, 13.67489351380256, 5.489336954009149, 8.80328328378739, 1.6968645275600496, 0.27691823099890067, 2.553781184457964, 14.595190402000183, 33.620541018824426, 64.05899647743472, 98.77358851894256, 117.89713567303075, 115.56283120186099, 120.2364529332807, 107.29006613454511, 101.07307803246283, 97.17393613630726, 99.56389119548183, 96.46830958704795, 104.94857588121968, 109.53445419188469, 120.79058970174482, 110.64974092668103, 80.2394873096097, 101.73065554711127, 73.44091369259742, 10.895928567455663, 5.569253285085002, 13.998808726187676, 35.448942107539025, 30.877629518508915, 22.830636078311553, 22.553389226236654, 29.538173444809456, 27.108914275323194, 31.171216964721683, 25.573792726762836, 13.55733713796062, 3.5927577172556235, 8.528278066265969, 38.20294803188693, 65.86148246642082, 94.8685944464899, 103.74722450010239, 109.1701993634624, 98.77533005129908, 110.3171004018476, 106.93829228801113, 104.08082208325787, 101.52568817138673, 101.19627183483493, 85.11595049212056, 67.57737036674254, 43.10744047164918, 19.7446995781314, 5.557372425833057, 2.714976625096414, 5.073791252028558, 7.71032169941933, 11.307271449796616, 18.93247281351397, 14.564796936127449, 8.612411925869605, 6.287617241182636, 3.928873952358, 1.7263820791436781, 1.0476709565808697, 0.5231212391968697, 0.5047776009286604, 0.6377653777599335, 0.31676745883399443, 0.16943198899107595, 0.5051591740019861, 0.4446201483088155, 0.34476947399877733, 0.44003238480898643, 0.3722457383428851, 0.9081114936740169, 19.764931163480206, 41.04326571187666, 78.06896532735517, 97.29891853947794, 53.344112750022646, 79.45065944425522, 66.66294820847051, 40.53786831517374, 42.27541946595715, 58.32602885461623, 70.28815961653187, 80.38989451623733, 78.8302424646193, 12.051006767057604, 0.23281320088332702, 0.11657006062206723, 0.22428172400161145, 0.13643221539114753, 0.1320005959320453, 0.08746081858032173, 0.2352693860208796, 0.22937262340659098, 0.21742321460718111, 0.1746398853438516, 0.15314719669761198, 0.17131936916660878, 0.1539413387616796, 0.15588344825852304, 0.1984799593206375, 0.08591400279152779, 0.12138198910942002, 0.11611318110578484, 0.20506799371252138, 0.2505032895433326, 0.13955993788136592, 0.09657292882160795, 0.14233389628991006, 0.1350091304630041, 0.13319071352241502, 0.3000408483128394, 0.206308274740173, 0.23114728140494517, 0.22871899718959487, 0.0928466005491153], [0.02818314324794037, 0.01267990427872827, 0.09323234880162824, 0.03841606885074608, 0.0707305001936132, 0.033614026728056134, 0.059188431834862124, 0.012875587074837137, 0.0850475803318043, 0.015084103647349103, 0.1058306570555414, 0.013255778317069335, 0.016405462632857023, 0.05270270465482628, 0.005436872372463827, 0.1253306054540219, 0.08298915570541736, 0.10647569542690631, 0.020041528510891145, 0.12099025771021844, 0.04341498790909687, 0.07100963965058327, 0.08132635420488735, 0.02922080359571884, 0.04993758690092833, 0.1416925581232194, 0.07708564385651581, 0.2722933275565025, 15.693917870521547, 38.81841498036539, 62.063427894346184, 69.56979320895287, 61.992758550951564, 72.89265263465144, 31.49787195267216, 72.97175115154636, 63.533371417753166, 40.74758568117696, 36.828647582761704, 96.61970523095901, 77.82851619105186, 26.875352821042462, 33.76710038031302, 3.2628721671719707, 0.11267982017729553, 0.27983448257850063, 0.06188208507674356, 0.10771698002973873, 0.1572742195980203, 0.11131823678771335, 0.026917010583283923, 0.6505336119763313, 3.1099369929682825, 3.5700908303260808, 3.893037952723042, 0.5487434481901508, 0.3042126873568181, 0.6853868127349885, 11.89629868153603, 40.3110101915175, 69.97174201473113, 88.31247037456882, 103.05570279398273, 100.59469007676648, 95.91885612856959, 86.08951414785078, 89.27401588809106, 83.47520735956009, 90.76428121136081, 95.46282568285542, 96.37874618653329, 92.79109539524202, 91.96216521724578, 89.50349807739259, 87.47083956195463, 87.14449836361794, 93.77004054284866, 100.80634117126466, 90.5801651554723, 94.64811801910402, 74.00781385360226, 33.61240602308704, 6.408109020802283, 1.4445927546870325, 13.165895381281453, 15.257774822173582, 11.168070454751293, 11.382594685400687, 10.904353818585797, 5.878267903481761, 1.126528492858333, 1.3209353771901902, 32.15136627997122, 71.26618692951818, 90.28356336778211, 86.51429899277227, 80.43329161982383, 77.09398961836293, 75.6717146596601, 78.848081404163, 75.7934336508474, 75.33147258143272, 80.01503359886908, 79.79472975577079, 79.72428398747599, 79.95546848543229, 84.87157114090459, 83.56400197552097, 98.74471202973398, 81.9892095750378, 46.89714431762696, 19.330046215365012, 8.706704724219538, 1.3117309227105112, 0.10144542422025435, 0.27364329705315255, 1.8606199276062751, 1.022508277768089, 2.843287894802709, 2.197420371155585, 2.7311365450582197, 5.355834672527929, 0.8385444588718877, 0.23233936018040105, 0.460268781189957, 0.17615290899430552, 0.15580486295925033, 0.11727050247211611, 0.07839752346157067, 0.07354050303899473, 0.06785483595224158, 0.022320599866009528, 0.9789245551632297, 13.956182368340032, 29.11141957006147, 44.316369871939386, 32.28750782628214, 13.948006187715839, 53.62073006168489, 46.503354041807114, 30.60376374952255, 41.68769544170749, 37.94767233633226, 56.82275695185508, 62.29886031919911, 48.400690786300174, 7.718600351964274, 0.11801062767664272, 0.06404590807975301, 0.09204154939300592, 0.08160806005640377, 0.057110985245315306, 0.04101912453470211, 0.03699273494402728, 0.12404753841579923, 0.059324768672306696, 0.009517775822220551, 0.02379039317489632, 0.04330207420993717, 0.07953217628622249, 0.16469361260533333, 0.03990537058862467, 0.01820536322831627, 0.06584972338450533, 0.03593946363957178, 0.015478127564664091, 0.09660018622995385, 0.03977513564149699, 0.04912647981977752, 0.02826028064103617, 0.03233954753546465, 0.03739405393360123, 0.06854094429722718, 0.01598343149864025, 0.01785402381492238, 0.036109653902390314, 0.021122352167543386, 0.015166834439902056, 0.06547395725764575, 0.045562125517115484, 0.05897455923860112, 0.044792915784543565, 0.09495490516025214, 0.03218034680391992, 0.1199610339057061, 0.037649563408546874, 0.06237060785473836, 0.09527981837069797, 0.034571598329010515, 0.012240532744345407, 0.06836010158182153, 0.10083353447337305, 0.06655882202809857, 0.06037408313263328, 0.07859231663807746, 0.04657433450882954, 0.08234351212459226, 0.06866136565804482, 0.023213889029237534, 0.02908696995056685, 0.017807411195169535, 0.057495894631551164, 0.1069730933335039, 0.6709770053144425, 27.138673297820556, 62.949095156884965, 90.03927815345027, 95.46135087167063, 93.51278797272714, 94.73890519911244, 27.96881744938512, 46.51439943621236, 63.49787396769371, 39.84984144087761, 52.32010741387644, 105.22545599168348, 75.97762815413937, 27.613888056047504, 29.029973514618415, 0.51038701928431, 0.14751841163923665, 0.19125202700736063, 0.11713262196750411, 0.06126426580932833, 0.25292826425885, 0.14409124070117552, 0.37744719955709677, 1.4554696097489328, 2.134469516815678, 0.3879175377228568, 0.6664873010689213, 1.0928391328742428, 0.4358715467876004, 2.1270961963361312, 20.87032371951688, 55.08384473862187, 87.04966329759168, 101.74854155509703, 110.83053865740376, 106.06955005276589, 98.7647867202759, 89.9234740964828, 95.39507066049885, 93.30115256770965, 98.60716235253119, 102.064190372344, 102.85935678789693, 101.52213450401061, 101.79925780142509, 94.66823193334764, 93.57792285180862, 89.1576156308574, 95.65798713314919, 105.38624178978705, 99.71057215044576, 103.82097290408228, 83.50466435955417, 51.58306267953689, 12.841616369062855, 0.9590016113173578, 6.120712545610243, 16.48342920887855, 15.456094761048595, 11.817841472164279, 10.190559914035182, 5.941771566867829, 0.377378803227217, 3.8934838771820073, 45.06968852012388, 86.89987582545128, 94.23297436006608, 93.80426714497229, 84.95314859574842, 82.29008674621582, 81.46154096049648, 86.06498364479312, 82.7240970057826, 82.19977809536843, 87.01305973914363, 85.71531218867149, 85.46493161109187, 85.9111325971542, 94.75570863293063, 97.72805721529069, 110.5832253732989, 97.10602421914378, 62.468538130483324, 32.9862545382592, 15.11545358165618, 3.025938209987456, 1.0186159995294388, 0.6299245597854738, 0.7171748037780485, 0.7794879665297847, 1.1557235520693565, 2.030574633709846, 0.693315209880952, 0.8104550790402197, 0.6544247257613367, 0.20836609415709975, 0.7954715024079047, 0.62950694993619, 0.20341021008789542, 0.27131730089745215, 0.0933951348246586, 0.05641138609198313, 0.09939609305752863, 0.03102445227634763, 0.4158569788259845, 12.494836680350765, 28.338608703305646, 48.1359935575916, 33.069330338508856, 14.261757558391942, 61.58833865196475, 33.220243530888716, 28.217213307657552, 52.45395045126639, 60.731128185026115, 79.82783456002512, 73.57953025448707, 69.89950764563777, 17.440287490044874, 0.08066966363619413, 0.03809670594731166, 0.10063075866069525, 0.07454491325563962, 0.02526882029468975, 0.12976338936676904, 0.031929719224271756, 0.04377684954013075, 0.01156289445897264, 0.03307617554861692, 0.006141908834838579, 0.03407632631640281, 0.11907190459990695, 0.008766533724302727, 0.10045612125747627, 0.010830833287458989, 0.09957248480209421, 0.005046128269074666, 0.02019480355234156, 0.0644572589906954, 0.017992404191904975, 0.04990373347555438, 0.07205809992287429, 0.03319318015729228, 0.01743699044680163, 0.14429007116104328, 0.0380008377044672, 0.024569638659276312, 0.07479540868512086, 0.10585437513767712, 0.10235925986161155, 0.20597058318315015, 0.12620055191819707, 0.10629001869669846, 0.1587382902301127, 0.2595260739326477, 0.08736370927503995, 0.17205960928432404, 0.11865165174728441, 0.18603892125669988, 0.17155262761779372, 0.1375000500270436, 0.17584440538719778, 0.13569064228044403, 0.33042515177399884, 0.19152014245910032, 0.14680567407800307, 0.1624115286094527, 0.269551131153299, 0.17588166790383478, 0.14420394755659566, 0.17732320022919487, 0.08111096858497589, 0.18488788947222695, 0.16549032872482655, 0.15064415762261038, 0.959430436693853, 27.74591503604766, 74.9974121585969, 101.25382085000315, 97.63984311011531, 91.1462337740006, 91.27699775080528, 47.01525865062591, 109.895931982225, 95.25119027783795, 61.353957422318004, 67.21834013538977, 129.20519551923198, 101.88305531778644, 41.855431679756414, 53.370514223652506, 5.776378944996865, 0.39732445391916466, 0.5720517652169351, 0.2868061891246227, 0.3787504683338827, 0.5156740065543882, 0.3722704063740469, 0.473331744752584, 2.3949273988123867, 6.498334321283526, 9.379201954410924, 10.186866021925404, 3.236009079602457, 1.0291193714064937, 1.1386182183219542, 15.890195235129326, 49.591432156101355, 83.16584217932918, 100.92806016245197, 111.82569103856241, 106.32823036563013, 101.23360495413505, 91.18115855801491, 95.5192058317123, 94.6272196308259, 96.912933780301, 104.79284994063839, 103.89409372883459, 101.8837848786385, 103.25780683948149, 96.41331011249174, 95.01161975245323, 91.83606101620583, 100.3986264813331, 110.46979042791553, 107.72403717041017, 113.60141077349263, 82.67363179114558, 41.00464213278986, 8.069042553824763, 5.168492467172685, 24.451626154684252, 28.94715855198522, 24.96636663713763, 23.87095259081933, 24.541379790152273, 14.372385067324485, 3.553655609007805, 2.248371224249563, 39.09714252718034, 82.7897104140251, 102.34485949239424, 99.61287375419371, 90.00371794546805, 85.28815038742559, 81.13297185590191, 85.58684672078779, 82.14066797687163, 81.21361578664472, 87.4918556213379, 84.79463777234479, 87.71329695178618, 86.17057384983187, 97.48315226647162, 100.46312593644666, 116.04314896368213, 93.39483445690524, 58.554852085728804, 29.32398065443962, 13.048178188262447, 1.6793946585347577, 3.4318221336410892, 3.911674359152394, 7.957599191896378, 5.873128127667212, 7.7532451768075275, 9.14445790552324, 7.312242311816062, 10.638328867573893, 2.352126250343938, 0.4637833167949031, 0.7037409310860019, 0.4914362103708329, 0.26567441982127005, 0.40857650820286046, 0.19350928975449455, 0.16664070167368458, 0.4800414798721191, 0.1676690061726878, 2.1516026748764903, 26.396747173801547, 43.008569286715606, 61.07841484008297, 47.62410071588332, 25.395064046305997, 74.29064812198763, 68.17582207341349, 47.65888821694159, 54.00366321686776, 56.48297771330803, 75.82141583965671, 83.5650453259868, 78.38011126364432, 16.540746804206602, 0.1541380854623933, 0.19890899920175154, 0.3294076337929695, 0.1958413992918307, 0.08995724631653679, 0.21834582961615057, 0.1378910153383209, 0.17049495130777362, 0.09342249182443466, 0.10332411695872584, 0.1186631583879071, 0.1274702277395033, 0.27361648397580274, 0.30768956207940656, 0.23257038165484709, 0.14069416169678012, 0.21945307181487161, 0.1018137209898522, 0.11346352046295521, 0.25488710511595974, 0.0946379209598226, 0.13988773158240703, 0.1063094620082167, 0.10634945945874338, 0.1782679092139006, 0.32770553964280313, 0.0962473874190642, 0.12497432094307677, 0.2764597120544603], [0.0951998770957993, 0.022995406498892174, 0.013142309204164534, 0.022603705743207567, 0.02835704712197185, 0.0888248151468654, 0.07742011018337742, 0.046005303550872116, 0.057673715130095525, 0.10128817701291654, 0.07091992309377079, 0.04177752476666243, 0.022380090423769528, 0.019241870613768697, 0.019466194564536698, 0.033107225092188004, 0.0343436029018654, 0.022812125708667502, 0.033083568297086224, 0.06679948088863204, 0.06068870778225603, 0.06443667420817, 0.033745839816307834, 0.057468020522426215, 0.05860520143722815, 0.1634006553720082, 0.7178063053757914, 17.424241073669926, 53.445251064915816, 69.48093583506923, 68.4509998752225, 65.40838987596574, 50.623027278530984, 38.913575603115945, 80.89044386340727, 64.73945317729827, 23.449866540970344, 43.848223224762954, 97.89231823336695, 94.25197432118078, 40.94157042041902, 23.830505109602406, 2.5085915577027107, 0.050686223342293696, 0.261215512310305, 0.07014819676236761, 0.09648724954815642, 0.2164424075594833, 0.09184207541928177, 0.25261738577917703, 0.4695154624360223, 1.2467482806213441, 0.7748204685987965, 0.691895863461879, 0.02371135013808887, 3.112659853312277, 18.78070258325146, 55.232020116621456, 93.20677249662339, 100.23314168376308, 101.6214410720333, 96.7239853643602, 92.71689984106249, 89.80805443179223, 90.36920439812445, 99.57281066525368, 93.95629036811091, 94.95098775432956, 101.48058875914543, 90.21182321733045, 89.40983972241803, 93.22403877012192, 93.25909691472208, 91.72843902341782, 91.8933197759813, 89.34955289286953, 92.33367643048688, 93.43790208139728, 94.8974709356985, 91.14220157746347, 97.49241690481864, 98.98307446510562, 88.0493813176309, 14.079677212622858, 1.1328056334487855, 9.548776803478118, 4.459779993180306, 9.918148363790205, 7.4890480502959225, 1.0201039261394933, 5.700323697059385, 55.26270089610931, 89.4279924515755, 85.91958138250536, 74.4515908148981, 75.95292506679412, 80.16799819084906, 85.24188210887294, 84.68720405332505, 83.78162291742142, 86.1834627582181, 85.88500961180657, 82.24987460720925, 83.21800970262098, 82.32751400240006, 78.92569726513278, 75.19637046321746, 77.56669013730942, 74.7503891298848, 80.03378252829276, 90.10675076515444, 86.19310394410165, 71.93706912379112, 64.36742813356462, 33.94059858014507, 8.541474880710725, 4.5373002463771455, 1.571600816903576, 1.5955399000836958, 1.8721536570979704, 1.3922794908285143, 2.5279236945413777, 2.3175495766824294, 1.640122540054783, 0.3821865871788994, 0.019580761098393032, 0.1725229239391704, 0.05293037066416395, 0.13124310351427526, 0.23545897746038055, 0.1134071440526074, 0.08670728683712021, 0.036968725748480334, 0.35582531784330645, 8.32451387759178, 43.7290890755192, 67.17375847601122, 37.2426066860076, 18.085866474336196, 68.78281670231974, 47.240645885467536, 30.26123885185488, 23.013294973681052, 35.41791223710583, 59.75685458029471, 63.538831357033025, 54.333005028386275, 11.344364323923665, 0.07110205283688922, 0.11398518037411476, 0.10433658642033417, 0.04297333439030955, 0.031316345182037165, 0.04379851067618978, 0.03181501287936924, 0.0880077364103448, 0.02702650369986171, 0.06283185024174952, 0.02985336622523685, 0.008087697468938367, 0.06423438103088448, 0.0554420282283137, 0.06408593617379665, 0.0876595800922763, 0.09471166458341385, 0.07428282691586403, 0.06384728446362481, 0.11473210077852973, 0.06418631667451513, 0.0413300336578921, 0.042604214076193116, 0.1054636549745356, 0.04001494797487413, 0.04414117031340157, 0.03541689974466159, 0.014839631584172529, 0.049671064912071156, 0.03183313085877847, 0.04846996545130688, 0.052924927609461936, 0.058327069385878505, 0.0908272004415912, 0.09382997399135944, 0.02279624470599717, 0.026742020779619777, 0.10355397397952695, 0.06253518652351153, 0.025371688665942322, 0.017949032124071833, 0.0642027607518098, 0.0707085058093071, 0.10785874460012683, 0.02565340026311817, 0.037008041380754406, 0.07568117486493242, 0.007523623578655984, 0.03380002138475257, 0.04190469919253261, 0.06635629136355654, 0.09714033950360552, 0.03349192763468431, 0.13206206682708957, 2.2489902232923815, 29.72898106421194, 76.6567865494759, 89.88848655454575, 96.38997200996646, 92.73042417341664, 85.00696351451259, 36.10680595521004, 48.649753447501894, 62.80384194466376, 27.096458788841005, 75.31493586878624, 119.19846042510002, 94.5187190271193, 41.943077041256814, 20.997757604045255, 0.43711475427112273, 0.13773974361679248, 0.27445780173424755, 0.09225482061024635, 0.12800020736552056, 0.09659416477886901, 0.2018441271878058, 0.4970094693764564, 0.03750586063571034, 0.3322706575835905, 0.9194938441918743, 0.1747100436759572, 0.49949174746871, 7.742148301293773, 34.14440101192844, 73.97711738463371, 104.74589916967578, 109.06692335682531, 107.20091066052838, 101.80205837372812, 97.55211537884128, 98.29088595605667, 97.12331402686335, 105.43076853598319, 101.91074725120299, 105.33229351043703, 103.88475064308413, 94.71837551363053, 94.21455490973689, 95.95443987077283, 97.5274044467557, 94.72361580018075, 95.66768323221515, 95.7848208950412, 97.84451238570675, 95.69436319412725, 100.30530545019336, 95.7773527022331, 98.47907343218404, 101.29469194719869, 100.34807497455229, 24.330697521086663, 0.5956699494873324, 5.001082276144336, 5.375286196508716, 5.955963682743811, 1.1834771402420536, 0.6802712452988471, 11.976710211846138, 70.5096087917205, 98.33952334619339, 90.36695295764555, 83.61368271612352, 84.3685350110454, 89.73437663047545, 92.69654273986818, 92.23950816738991, 91.52103977818643, 93.09602829717821, 93.96040101205149, 90.31099642476728, 91.72499518240653, 91.83436655229139, 87.58526294462143, 84.24744359908566, 86.91739313064083, 87.14100745416458, 91.86255270434965, 97.26413496078985, 93.40098473333543, 81.12044380557153, 76.61800215321203, 48.111768999407374, 16.731699551305464, 8.763064280633005, 3.32632361400512, 3.4966500872565858, 2.8189544908462034, 1.1652806521423402, 1.3900050064248424, 1.3036865092092946, 1.3149004429578781, 0.40208219700763304, 0.28657314517805654, 0.6619192719940217, 0.22847374180151572, 0.18590114800439728, 0.18527906928812304, 0.12782830489619126, 0.11401294340049067, 0.13042956410396483, 0.3978280188335527, 4.7532380011773885, 35.7702705167955, 74.93885901666458, 36.030425640844534, 16.890988965188306, 72.87797512546663, 39.63766867114652, 30.226806325297204, 36.9412588304089, 55.22304965603737, 79.5671695278537, 79.5036663547639, 71.35032176971436, 24.41153560915301, 0.03942274285720722, 0.10136208917585113, 0.05536515130511215, 0.040603544818417686, 0.06458591579669906, 0.0885068350321343, 0.052863579288485556, 0.05402343640584619, 0.029019709346034837, 0.05726550134920305, 0.03263885425704141, 0.029542179395174308, 0.08920234327595081, 0.03190941980949814, 0.07247558719809018, 0.05465176639958255, 0.009527378734351407, 0.0788688360743465, 0.03033086691322106, 0.016015640707806717, 0.028472004360669566, 0.026843355059803977, 0.02898759685546881, 0.07372436414082205, 0.022834009010224574, 0.018139590749577172, 0.10676559075833329, 0.02713786224053512, 0.18179962051010903, 0.10220372103034489, 0.130115314837425, 0.18324567275422235, 0.09149683023532552, 0.22004735686125296, 0.24902248755097392, 0.16358310687205485, 0.1800623629242182, 0.22339578928245654, 0.22799605533720987, 0.1714270045199702, 0.14051846709222565, 0.10730964341951955, 0.29338777305618413, 0.234936781287674, 0.26889030370981465, 0.14675627672864547, 0.0917972669365906, 0.16611510407059424, 0.11097931949001168, 0.13522918155837443, 0.11463883723462782, 0.1572932645438179, 0.18995868673007335, 0.36025168193924817, 3.528517628869703, 35.680616901766875, 91.21735418996504, 104.55538965040638, 95.84817501806444, 92.14411612479918, 67.93317640981367, 60.31681606846472, 107.73358421940958, 90.9200071519421, 42.252642262366514, 80.60134949222689, 124.68715067832701, 109.34522336529149, 61.306386916868156, 37.34668677853, 3.64082440253227, 0.1987167570980326, 0.7180167650503497, 0.16106413316822824, 0.38289000911097376, 0.4219019641318629, 0.25282887201155385, 1.183539653016675, 0.9942203892334815, 4.030376557380923, 3.71352308219479, 2.586122597417524, 0.2628196697802313, 4.239541359486119, 28.04576062387036, 66.79687361563406, 107.93224442389705, 109.09161859943022, 109.59114028561501, 101.43110413705149, 100.26056689600792, 98.3730282322053, 97.68498174605831, 104.06884316475161, 108.5799297209709, 109.79838263603949, 108.16853584781771, 98.24872047670426, 97.71958489571848, 101.87029976998608, 100.75016498565675, 100.58965375346523, 101.2430343320293, 100.21063512371433, 101.92809197210498, 98.40179489504908, 100.95525003248646, 98.18702159389373, 103.23296254681003, 105.8894112802321, 97.39061570936634, 16.941703250331265, 3.141463043228273, 16.883099117586692, 13.439285562884423, 19.49759221846058, 15.319284450623298, 3.51150042587711, 8.544593164997718, 66.19847682214552, 101.89830549301641, 96.44232780702653, 85.5347341106784, 86.11216975796609, 91.06334624751922, 95.53171819256198, 95.96379080126363, 92.77579815156999, 95.66881287482478, 95.57651950467019, 91.50280075688516, 91.67918189879387, 93.00277786870157, 86.62012454002135, 84.56583023071289, 86.46015459491362, 83.99154032430341, 95.65666137203094, 108.30477545338293, 104.56284999847414, 89.62933555726083, 75.01739271225469, 40.755453955742624, 12.389614197515673, 6.028919277652618, 1.6527566169538808, 2.3120482073676203, 3.6311819909080385, 5.071518728809973, 9.394064795586372, 6.905882310482764, 6.864449824056318, 0.9744676394808678, 0.23062949789868248, 0.5171686134511425, 0.2032308229395459, 0.24452360557211986, 0.49056440231300175, 0.26631100824283016, 0.44841041427946865, 0.1965930847631347, 0.6611019481093653, 13.312584180985729, 57.28508672406597, 85.67286429866668, 50.501720136211766, 31.131249973850867, 93.80646367226878, 67.78992360638034, 46.670148911014685, 33.155653861261186, 49.938118688521854, 79.68186747643256, 83.66920778828283, 82.3637096343502, 24.75826136527523, 0.1700861974348945, 0.20443056259424458, 0.13892443730465828, 0.1617796592895062, 0.170158623387256, 0.21889076327844975, 0.1805275315118413, 0.18752179168645414, 0.1447775788725384, 0.21293852057668472, 0.05881885569843073, 0.11732264241624264, 0.16000608913600445, 0.15412167585905523, 0.1552088771976771, 0.1526522885767683, 0.126681616830249, 0.14823652713769866, 0.15845427079306496, 0.18492164330617075, 0.20616454132381948, 0.11470409260401804, 0.11926260686689809, 0.1823782007540426, 0.18774044850180227, 0.0662001473228297, 0.18955698086609765, 0.10397362162268932], [0.08069683677486836, 0.020653613610193133, 0.029494063327870065, 0.060608138315259456, 0.017028135067272573, 0.01896890007980889, 0.0926096418932561, 0.050701564252977414, 0.08351916597495157, 0.04956966551441339, 0.02990685065367049, 0.030830128328694455, 0.08096692873345268, 0.02580592453840279, 0.07736097585650221, 0.028267907046322382, 0.06169157050129387, 0.07469802358818632, 0.0661308316874408, 0.03687616317502914, 0.028714473103924144, 0.018874874278422327, 0.010533699382757469, 0.08159843799207481, 0.19098248663208178, 3.6963019159532364, 24.29014805824526, 60.3134467524867, 67.8086176226216, 74.16684242986864, 57.569399726006296, 71.00459621798608, 41.98794503365794, 57.73652799667851, 99.73329836322416, 33.37691084031136, 82.41892091689571, 139.16184979100382, 109.85739861765217, 47.18580330571821, 14.486625079185734, 2.075432452463335, 0.030637987731625477, 0.3100401956227518, 0.07684484710015597, 0.11226755762172323, 0.03810466560084493, 0.24241588318780546, 0.11688760406668149, 0.4484553683188654, 0.6357771038047729, 0.0391376892014617, 0.40885616093873983, 7.547754654961248, 37.3886679064843, 69.64125879349248, 90.0963015710154, 102.07523576674923, 98.2668653611214, 97.50443504702662, 96.40944265550183, 96.1414114121468, 90.86048126220705, 97.87080795534196, 101.62057030585505, 92.52129908530944, 85.00261752836167, 90.70990147129183, 91.29339325812556, 92.40803672421364, 91.67860923274871, 87.1766225753292, 87.78098921622001, 85.19461754829653, 83.98606469554286, 84.18493670801963, 86.1578889046946, 87.37696155425041, 89.91307197078582, 89.0389011752221, 89.13831756960961, 83.53946362772297, 90.12251869324716, 87.41660102721184, 12.462158433852657, 0.8977650778908884, 4.772822395447762, 2.268377518461597, 1.0915013594973473, 9.32222560528786, 67.4865988762148, 83.97396810593145, 84.78898955929665, 80.66897899873796, 86.62132478529408, 88.53985017345798, 84.27446088483258, 80.83167891348563, 78.38410423647973, 81.3801125557192, 83.89031963963663, 84.39482273594027, 84.34935462090277, 85.20799283058413, 87.30627259900494, 86.19939542585804, 84.20286193970712, 81.26623830487652, 88.46045355642997, 78.85367470402872, 67.14561154765468, 53.69807527911279, 64.29943384662752, 83.67314584793584, 92.33559054713096, 76.16213644704511, 61.00175211506506, 50.107737664253484, 44.558176148322325, 27.779388543098207, 12.875878272518037, 4.168237572716129, 0.15782819309782598, 1.345943306242266, 2.3012989519103884, 2.219814898506288, 0.3392788912019422, 0.12334158073269552, 0.01259438205330122, 0.061322189717283176, 0.11156572149165216, 0.12618152229415794, 0.07710880269446681, 0.022113350099853935, 0.696576476818131, 2.8866592578349577, 27.88523566338324, 66.58122170356013, 48.62707038079539, 24.55196430606227, 36.02689158531928, 42.463104878702474, 34.27659273147583, 36.17583574787263, 39.97492582567277, 48.283400151037405, 65.25041641727572, 55.97867465788319, 13.017049277982405, 0.11724365875124933, 0.05307721439749003, 0.06928332946113042, 0.09572482352415401, 0.10175261015613234, 0.02602959539921534, 0.07441679271118296, 0.03548581318389024, 0.045162308059873126, 0.01465698664692501, 0.08374226610026053, 0.02897031008145742, 0.06232266990287651, 0.015448495283752922, 0.035280681650845275, 0.12578312593001512, 0.07163271428115907, 0.06493234075605869, 0.03644741057688671, 0.01713940359261488, 0.06069967433089211, 0.04057263700111259, 0.027399027359581767, 0.06907110012346698, 0.07068951448966419, 0.03218632612016893, 0.05000108792897194, 0.016654378005994425, 0.029398551315910397, 0.020249033001281565, 0.07022125856770624, 0.03055443818260345, 0.029848662445381768, 0.12494127957090256, 0.03934087487117898, 0.03138379539333044, 0.011320803971630673, 0.05429121477889919, 0.030207229898341244, 0.025151026615452383, 0.042021496957468416, 0.007333221043565221, 0.010222474248298715, 0.14732050048487802, 0.06920305876842431, 0.031235086235908732, 0.025106585854964874, 0.034065585763704394, 0.029000279441055273, 0.034606869017044385, 0.014633858452490984, 0.06818953976635972, 7.363012000437706, 38.23355036397135, 84.2880009066674, 84.06117808434271, 97.69002591409992, 84.34366718415292, 91.76599964018791, 42.29330155157274, 35.24866588654057, 97.33305884945779, 41.656846000302224, 111.65349898799774, 142.24230674005324, 97.44450907553397, 40.94942692787417, 8.500966602756131, 0.6489364105847575, 0.1281491578406384, 0.11920277540001178, 0.08279579511332898, 0.14304205264535644, 0.08587405130627655, 0.2991857103282406, 0.04097589802357458, 0.30114940818279023, 0.5925947499852027, 0.20433411212457767, 1.1628536855982197, 16.888537483830607, 58.07761730686311, 88.11612436848303, 100.03185349126016, 106.37780127986785, 102.73567661162346, 102.56878760553177, 104.31518370105375, 103.22521978808989, 98.18832382079094, 102.47274444949244, 104.83474869881908, 94.93746342197542, 93.1793551291189, 94.39034769611975, 95.59529981305523, 97.23773740953015, 96.71658777421521, 94.14156744557043, 93.38625231096822, 92.94737831238778, 88.98301524500694, 88.64930783548664, 88.62600895666307, 90.78236333785519, 92.09319591522218, 94.30233755419331, 94.38403268014231, 87.75579191023304, 92.53751416360178, 96.90636773263255, 22.195325859131355, 1.0745974149434798, 1.2092338742748385, 1.3334082691900193, 1.0194925879759174, 18.50598958230788, 80.11243389498803, 89.18111062818959, 87.70770365192045, 89.60849208216514, 91.89851299408944, 95.52704272731658, 88.16734267819314, 85.56318698390838, 82.21851918005174, 83.79695154005482, 83.37586156783566, 85.57752716925837, 88.1919437839139, 88.26469590587001, 91.22660313883136, 91.1010088459138, 90.35422094406621, 89.29169793282786, 94.02621838354295, 85.0916317970522, 77.78772354125977, 67.30507158464002, 72.34932591838222, 85.82816662326937, 98.79682463984336, 87.92547364388743, 77.37333297729492, 70.66598584575038, 59.81489781410464, 41.35630615295903, 21.781868819267522, 9.731553369952787, 1.7012269386360723, 0.5508605474906584, 2.1708928913839403, 0.4810853206342267, 0.42620541708123305, 1.0919811143990488, 0.33491972833871847, 0.1072970336122859, 0.16910298487111447, 0.12357015072578385, 0.13744941161524865, 0.013123790943814863, 0.4565058492364422, 1.6737095506921893, 23.173415930040424, 73.05204991371401, 38.8652676920737, 21.1212004769233, 41.87902081397272, 38.649988405166134, 26.068097660618445, 45.91994854711717, 62.01423352764499, 68.9969624242475, 81.11063003540039, 71.83584843912433, 26.460436659474528, 0.0943771752739145, 0.07568584034039129, 0.06651709321886301, 0.1339330373992843, 0.014239240817034678, 0.04013233562751163, 0.04668259422384924, 0.0554054283777312, 0.058013003980440486, 0.04676374591766827, 0.03025559302900107, 0.06283068578810462, 0.07740452795499757, 0.03953916523906012, 0.003248860622050181, 0.05774570824277978, 0.036842991567907796, 0.04752613746771409, 0.02484245406043145, 0.026565270888949596, 0.07133842926592597, 0.027264699587718617, 0.018101937528098785, 0.008350259740836918, 0.05015587982451243, 0.036263794623195164, 0.02694527539725025, 0.21162270327969906, 0.13569963615267508, 0.12203746925919287, 0.13850900314507947, 0.15574906111484574, 0.13599468725583247, 0.33709315042341914, 0.17618007447210052, 0.22893918618079157, 0.11788995350681006, 0.13310463588324287, 0.12688103717781846, 0.1343948045565236, 0.1440924511200959, 0.2800667297936255, 0.20696305008905552, 0.19763197659725146, 0.24166913132273385, 0.1787686396029688, 0.0819353174958979, 0.13648162806226363, 0.07617418308772388, 0.1944443766748713, 0.1906746418605889, 0.19268107209955493, 9.00211215019226, 46.378842323057114, 102.14563446660196, 97.85663250953921, 102.8341124134679, 86.10721188206827, 88.3058023452759, 58.68256053616924, 78.5797599054152, 134.68841798843877, 54.855080343061886, 120.60763466742732, 155.95378321986047, 122.29291239092429, 66.26234085329118, 22.988107473619525, 3.392787441130608, 0.27123391988777346, 0.44826574623584753, 0.21531979763700118, 0.39755621083801795, 0.2298703660527545, 0.5706167906042069, 0.8638729191114827, 1.7888599201556177, 2.580359655041849, 0.7360727832682672, 0.5840950963958618, 11.248982087258371, 50.42033095513621, 86.84559806700676, 99.73798951795025, 112.13412269469231, 104.40100516042402, 107.20850436918198, 105.80312698118149, 105.08863587533276, 101.74767078891878, 105.60337635778613, 109.71859378199424, 99.92720465506278, 97.98137957049956, 97.26972826065557, 96.71897257527998, 102.47123041460591, 99.37668431189753, 100.36772604911559, 99.98898198527675, 95.38880271296348, 91.75253022101619, 91.13304676548128, 93.38175727475075, 94.14164589297388, 98.05188025197675, 101.35450809232651, 96.8458612503544, 91.13628664324361, 96.62795789780156, 96.87119976166757, 17.204405953807218, 2.7020323132314994, 11.483703582517563, 6.2724430618747595, 3.740356016543604, 13.200435773018869, 75.41880023094916, 91.76738031448858, 90.32249681411251, 91.06555846429642, 94.88065965713994, 99.23007395959671, 90.88041474742275, 89.31514586171797, 84.13388313785677, 86.37603544419812, 88.76056194305421, 89.72107195085096, 88.15279852959418, 87.69734859466554, 92.47885904004498, 91.21548714176302, 91.60348799920853, 94.39012804339009, 96.42188441368842, 83.71522503514444, 77.54328927686139, 66.92977920655282, 72.02781708009782, 86.22646762478738, 97.76924994684036, 85.68712603661322, 75.8125199041059, 65.40511861924203, 53.89467623925979, 33.67381857287499, 15.095985877898434, 5.33462445582113, 1.4217215367863256, 4.27856796210812, 8.571754597848463, 5.139709134255686, 0.5582602213948005, 0.46324656495163524, 0.26040793306404547, 0.23308995780685257, 0.31654685615531863, 0.43655327310965913, 0.22264634078789144, 0.08877404650012333, 0.8493090973746392, 4.332382390576025, 40.14344261538598, 86.70655004439816, 61.36206496146418, 39.03251755622126, 56.69208711193454, 59.92132740636026, 49.92593188439646, 49.51352996210898, 59.540406427075794, 68.20889549870645, 83.6872350015948, 87.68755835871544, 25.989061901646277, 0.19283419775386013, 0.13327838462446967, 0.10874589739908135, 0.2061671613445205, 0.20034745185365602, 0.08273419398333758, 0.1372382318180415, 0.1497290349535404, 0.11665882722985361, 0.11167970771390585, 0.1455685493325995, 0.11688692990930812, 0.1318466582245404, 0.11703686863784829, 0.09815007403132417, 0.1593746794688125, 0.17649410923402156, 0.1921287533496657, 0.06767152643371975, 0.1573069009088701, 0.13297127529738412, 0.11585071938292635, 0.12726617255999198, 0.19932680823389562, 0.16376952670754927, 0.08500203640470583, 0.0906591437336418], [0.04008415252751401, 0.037143976022038734, 0.06559206503293206, 0.0390839634553319, 0.05438520610632916, 0.04534685097995304, 0.08376659705273568, 0.02519458445960716, 0.023765171645209197, 0.03226303833446676, 0.05107315903108928, 0.04268329733261659, 0.01636669475344881, 0.027290828931596012, 0.01576034765269968, 0.04565404074627065, 0.12752581507928912, 0.013465219094688374, 0.035123760030875285, 0.0652926855330025, 0.010127737900362381, 0.03118205571457023, 0.1735286288444073, 0.1223541470244527, 7.1767479565835774, 46.44402427058066, 64.1060374629113, 70.28880288524013, 71.6125871289161, 62.44861249000796, 61.94780034403648, 46.67598539783109, 56.748608466117616, 83.99536071285125, 39.36547971540882, 92.05879672881096, 136.57363460909937, 66.65620173177412, 37.735115174324285, 6.516242392601506, 0.07478083003192179, 0.21972639666449642, 0.1536950721375404, 0.09035513706264958, 0.3047482747464411, 0.07274196363024174, 0.12445749504671944, 0.1455394686349938, 0.3343398610670721, 0.26476280583489326, 0.7326323130438406, 9.417483306700184, 47.20760383913594, 90.1540231704712, 100.20213926992109, 97.06202307055074, 97.17185728011593, 96.85957385647683, 98.16768430894422, 102.03361941922097, 97.05618658373433, 99.35823348260696, 94.68483924865724, 88.18272621400895, 87.81252507240542, 90.78103757673695, 89.23954609901675, 97.1349242425734, 92.71919050524312, 88.77072872654085, 85.7586230001142, 87.54642363517516, 88.71761198966735, 88.64602088928224, 88.8497958644744, 89.51242539190477, 87.08783580410866, 89.1718852135443, 88.37039593727359, 89.78594010876071, 88.65860385279503, 89.16519365003033, 84.16228109790434, 91.88807948943108, 75.95258774295931, 7.688611870811832, 0.09420495104765701, 0.2577750420858783, 11.407410540888387, 75.17415415856146, 95.9870190774241, 85.98834053162606, 85.7893822270055, 84.55470638890421, 83.268019922318, 80.93482155953684, 82.05399928554412, 78.88488108111967, 80.51492398785007, 78.09445288873489, 77.53497385209607, 79.63994518403085, 82.81302498232934, 83.42215338060933, 83.59498085514193, 83.01519178575086, 84.69395837476178, 80.78126861203103, 87.48375984930223, 88.00894952589466, 82.77300111709103, 79.16160429677656, 76.41319167229437, 78.35371371238463, 82.2659327906947, 83.45194770443825, 82.10606482721145, 78.6371990942186, 88.28812030053909, 85.51151367925829, 76.86133030922183, 68.10889074879309, 37.609532648517245, 10.030488967895508, 0.3271234353944179, 1.8516261779492902, 2.2039008621246587, 2.413471139246418, 0.308530236323995, 0.08248155350766836, 0.05344708164733264, 0.054086922112131314, 0.024941423044149435, 0.20067405045753528, 0.35068351955663774, 0.09590300025358316, 3.3402612661161735, 26.720176012285297, 36.950409720020915, 31.76084726087509, 26.96277460744304, 48.77171954801006, 59.82537838720507, 29.339766233198105, 34.08091352831933, 43.85850375698459, 54.447608840081, 65.94182829703054, 56.75791232816635, 12.902252289556689, 0.22277672895260398, 0.046235788763771137, 0.0783192445974677, 0.057070256180820934, 0.008924768227452954, 0.09072972341410576, 0.0776162976399064, 0.1667316363102967, 0.04450361417125791, 0.06475805575328489, 0.051043365871714014, 0.04858648742458994, 0.04325176904638929, 0.039488733671004736, 0.06622751198348499, 0.11757116899975847, 0.041355241781040546, 0.022231233794422402, 0.011769276630553988, 0.0013703990266695921, 0.1217468921095133, 0.02904011601311786, 0.04384883116149614, 0.06453799699703533, 0.03441266955867891, 0.11215616843753284, 0.03710276049171244, 0.019523798630783157, 0.044324996941272295, 0.03731677481423944, 0.05898649105802179, 0.039787377726527, 0.042394007210649794, 0.035696698037246545, 0.07662342470740119, 0.08333678342281811, 0.07362372317020932, 0.03167462918246466, 0.06303230480801675, 0.09038104615624874, 0.04840595497479362, 0.030908395701478568, 0.03378735412092459, 0.051123536972989964, 0.04129274049773812, 0.035311237067705205, 0.058271872750934095, 0.028455548792056022, 0.02838734589937714, 0.1760951459648148, 14.041405666259028, 62.97493180921001, 86.23112740055208, 91.7315298511136, 92.9116847438197, 79.5916529624693, 77.9493957950223, 58.90124836275655, 29.04487263771796, 71.7880190572431, 48.791806005662494, 111.57762465938445, 126.0805413030809, 60.475028791735255, 39.45415273789437, 4.619572941334018, 0.1337909280893303, 0.18415252167371013, 0.06175573036495236, 0.1054771304611237, 0.36862903725235696, 0.10447814414698271, 0.481689764006484, 0.09714197127088424, 0.4780616022406086, 0.6459107310060532, 2.184142657826024, 19.03622538812699, 64.74130845838978, 105.42286103771579, 103.19297790527345, 100.47256315908125, 101.72161840623426, 103.90783771391838, 105.62791470558413, 107.7726588710662, 103.58476777230541, 102.80812278870614, 99.83266768916961, 91.51909428258097, 91.25746434734714, 98.0029526064473, 98.21097943090625, 101.68439511329898, 97.4011355061685, 92.14371604304161, 90.84013200575306, 92.02180093334567, 91.62087978855257, 93.82712671833654, 93.24328976292765, 94.25511221731864, 93.5078614757907, 92.05350937381868, 92.46732727173837, 93.28616126891106, 93.86121211513397, 93.80040753272273, 89.85748414070376, 94.47494537599626, 88.21974554369527, 14.804388053955572, 0.1841956983891226, 0.8096828624125451, 18.20532618030425, 86.53475023085072, 98.7030956822057, 94.16108515954788, 91.50350678351619, 86.91709503050774, 89.26856379355155, 83.41768972335323, 87.31264252816477, 85.1711460851854, 87.80421749238046, 85.64137551092333, 84.6451013318954, 86.3276098620507, 89.06567527401833, 86.86325657752253, 88.81395324583977, 87.25865502511301, 88.19773320228823, 85.87833373777329, 90.94736960626419, 94.16233247326267, 87.89910747158913, 86.26406746525919, 84.67973586051696, 86.2232905049478, 86.33121844260924, 87.8499052601476, 86.24720127351823, 81.38950270991172, 92.44598957800096, 95.05806061529344, 86.95722872211088, 80.6916424535936, 55.01597204516011, 21.42779842499764, 2.8539815016331214, 2.1280444293252887, 0.8059449662123958, 0.7833129516051662, 1.1480044501443063, 0.899032555039852, 0.1622438779281032, 0.20116597083547424, 0.08064409928216089, 0.21283103844090817, 0.48068833387186455, 0.13464336944443567, 2.713023529898736, 27.626837761171405, 38.8845932099127, 26.406972792840776, 16.911963839684766, 42.44832931026336, 42.653594786121005, 25.860212041485696, 53.88109307135306, 64.53927109318396, 76.02933283775084, 78.60462773230769, 71.39035347969302, 26.00876592820691, 0.5503739284411554, 0.07796952546003365, 0.06558731528780153, 0.10861559350404049, 0.02794002141473034, 0.07932476564160279, 0.0028156165940491787, 0.05523700777801776, 0.02740324850404455, 0.06699176895762644, 0.02333649374063938, 0.038707258870765086, 0.02171761206080837, 0.04276057645197838, 0.12409695108691532, 0.03924681842627545, 0.05407440040500895, 0.05847910336489159, 0.05899051301962426, 0.016952780743820534, 0.04273923324240793, 0.05376867386662672, 0.059140049552004186, 0.041837049798379024, 0.05803408672011668, 0.05135639705845425, 0.1792589205527498, 0.10423851950514702, 0.12297363636354286, 0.18555165869334053, 0.14222304336726665, 0.12696362911693512, 0.13061825155971513, 0.12313900410287804, 0.1348347535296794, 0.15409834082088164, 0.14669644526175915, 0.19074081653548827, 0.301059132381793, 0.1627822845212875, 0.14571350848963185, 0.1372051061761956, 0.184521576870353, 0.11691835483596211, 0.15040619539157038, 0.07404426713624308, 0.20949317803305967, 0.16168733037287192, 0.3244589815937704, 0.23803292563365352, 15.460639807485766, 72.83618619365078, 101.34405105344712, 101.36784415091239, 100.16338625261861, 91.60080509801065, 87.85953075655046, 68.82325633879631, 81.97591274015366, 120.34070168772053, 57.038765799614694, 117.21399999433949, 148.71923815819525, 83.38913486849877, 57.22115209025722, 13.506228654615342, 0.514778909423659, 0.3338681654103341, 0.29241830410976566, 0.3126334645334752, 0.9657138285617676, 0.3234878578974355, 0.3981892752551264, 0.507966947531508, 0.9201969903322958, 1.1204775014231283, 1.1491539497529308, 14.003970565334445, 57.46571971524147, 104.2047768254434, 107.6251777525871, 106.36579098240023, 107.95605321084301, 105.6604939122354, 106.12425927192935, 112.47497666266658, 104.79179874543222, 103.86466026306154, 101.64729733620922, 93.98567676544191, 91.61484718322755, 101.82511406560099, 103.92815559141098, 101.98662942455661, 102.92827283182453, 96.05086741908904, 95.90599859914472, 95.64694958348429, 96.95646424447337, 96.3769732752154, 95.5127731446297, 97.69080254339404, 97.07483353153353, 96.86079763597058, 94.06171583360242, 94.9545963348881, 95.61107558588829, 93.82721301048034, 94.28796598988195, 96.75370908552601, 84.79408864052066, 11.148520381219926, 0.706976518755959, 1.1760307656180475, 14.264847405495184, 84.10295132667788, 102.055859258098, 97.59533205339986, 94.09751922853532, 90.4360886543028, 91.92840929954284, 89.40087318420412, 91.88756958130868, 87.66731108388593, 91.07408569705103, 88.44481114418276, 88.02566666756907, 89.94601203549294, 91.62047186205464, 90.51425364709671, 91.8108009522961, 90.60073406465592, 90.71253730404763, 88.00493301883822, 93.56978001133089, 97.79942866294616, 91.61545907297443, 91.43597141388925, 85.2640199661255, 86.89834610108407, 85.30707974587718, 89.98360403122442, 89.62713118522399, 84.50565322752922, 97.75367029251592, 98.91527237430697, 86.61901843163275, 77.81927508692588, 46.237193769024266, 13.923903223006958, 1.5674174865407329, 7.743992795867305, 6.278231499656555, 3.954566457579213, 0.7910581005196419, 0.40894343367507385, 0.18556218474142014, 0.27557886415912264, 0.21618802040334673, 0.3711652479344799, 0.9181583997222685, 0.29117632236692215, 7.0449396487205265, 41.201454900926166, 50.20836607102425, 42.37057616633754, 40.66361558052802, 67.59447974543419, 86.11195010523643, 47.48779050765499, 48.54980361077094, 61.385532502205145, 71.21839677133869, 83.81703407533708, 85.26784035467333, 27.51450304062136, 0.6620249921275724, 0.17942122394038787, 0.11425767018790207, 0.2087564619197961, 0.12442128973141794, 0.128163690528562, 0.19678373340397112, 0.23274512631037544, 0.1236348238683516, 0.13216702087271598, 0.12375522990741077, 0.16648104895026455, 0.14410152160111936, 0.2287502535769055, 0.18926237409393634, 0.14871524015982307, 0.1669360438902532, 0.12413451237784279, 0.09837151940671668, 0.11349577276456742, 0.20570908673107627, 0.11683547944431344, 0.20924450589283822, 0.1582310634154466, 0.18133146417958124, 0.1437860006286252], [0.034652631279201276, 0.02201956944660314, 0.04552955911945432, 0.0756887055092281, 0.028490195118431604, 0.09675456826845485, 0.02551451235288574, 0.04935676584981623, 0.09458800267067649, 0.05319067967995521, 0.05265701517102219, 0.04889370783442452, 0.02495045139033708, 0.025155150083704822, 0.015679290762261277, 0.02043079693741616, 0.09233709845331409, 0.06704070665422948, 0.036762981345095945, 0.023112424514106205, 0.09108612283823952, 0.048341611250033306, 0.028893900471889687, 14.501894866266559, 47.64739567233671, 81.2138589735954, 72.84035175077378, 66.47142671769666, 47.81340998987998, 55.57793001974783, 53.523000286471465, 33.19013933981619, 61.467062888606904, 55.16906607535578, 88.34038980545537, 76.34961005180114, 39.478028205133256, 38.930386881674494, 16.387869484962955, 0.989451154826149, 0.17396148384338425, 0.056505771954694105, 0.13740162305053205, 0.24997600654680885, 0.05365502472305971, 0.1185892768684895, 0.25400147683197455, 0.2019606185175719, 2.2527539826208547, 13.572675566519461, 46.58647298812867, 82.22879578990322, 100.57856913535826, 98.82981177299254, 100.47740336387389, 100.20548112930791, 101.9026279449463, 99.12029466321393, 97.37050963986306, 94.66359569180398, 95.7585959280691, 94.9645277761644, 94.79596784037929, 90.9419410459457, 91.81716303671561, 88.0798424443891, 89.1028122748098, 93.66327362675821, 84.13694258659118, 92.52770039343065, 93.10026445696431, 91.27112204028715, 90.18919114143618, 87.86535155388617, 84.67393859740227, 84.00959107183641, 81.39513523347917, 81.78114352687713, 80.98099570120536, 88.33929154180711, 91.04470714446038, 87.80563739038284, 85.66788288854784, 85.6749039311563, 101.49571341852989, 55.194424198519805, 3.737256608663067, 7.19369504720934, 54.655035541903594, 87.86575163564375, 86.78941403665851, 87.14832659690612, 82.39783425484934, 83.43191223759806, 81.99960385599445, 79.45877090577157, 80.89573906313989, 80.25383533970003, 78.81918922547372, 82.22536763837262, 83.18016667519846, 82.4202545227543, 82.86901289416899, 83.9588277570663, 88.50823586986911, 87.47762526235273, 83.3026466061992, 87.25811373802924, 82.1784874700731, 84.14576007473855, 80.62354226266184, 75.57904474196896, 77.8622877982355, 78.92366547738352, 85.02613605991488, 79.94945156958796, 78.31205029641428, 79.19153982593168, 74.03123040353098, 74.88853500735375, 78.08389386823102, 78.07448017981746, 85.98233146052208, 77.0202882828251, 47.78623973169635, 6.646479791210544, 1.6324129989070277, 4.57878029154193, 1.346457627031111, 0.7036073253520074, 0.7166509222119086, 0.29090377892698016, 0.02925459190361923, 0.0993096093917566, 0.28107520793714835, 0.09960187959574884, 0.13795827785807271, 11.052248747118059, 33.24604880425238, 37.759151458740234, 37.96859818120157, 34.34100589444561, 55.31687275055916, 44.022509820999645, 34.71341533045615, 34.580658789603945, 43.52154862496161, 61.79642823434646, 58.3802556222485, 52.66694299636349, 14.878587530505273, 0.6539499351093847, 0.12249936665137931, 0.061010859245734836, 0.1021891883424213, 0.07341015317867841, 0.03719612745748412, 0.03520568547349784, 0.040995908240156795, 0.048099404891892794, 0.046919257935857585, 0.02297734406085745, 0.07009322229292124, 0.05486109226401295, 0.06701048448561661, 0.050326449300853476, 0.02081221679315692, 0.015826281967512783, 0.0709356202353393, 0.07125369994150055, 0.01960750331260985, 0.029787743133642984, 0.07127574795196134, 0.06935253018333067, 0.057030277882492354, 0.0608463227117975, 0.07517100627263708, 0.014665133991999733, 0.027358980113340002, 0.027456468632144314, 0.029079741911001267, 0.0874721949859973, 0.05673574005824424, 0.018852203821523056, 0.06771526239331692, 0.06338255637655817, 0.0647117917035376, 0.04897725355300692, 0.06450961343944073, 0.03330951826947351, 0.062241024082346316, 0.06193438589933419, 0.05126831992979973, 0.04796186529640709, 0.020814359924125097, 0.11055386490038327, 0.041012245065142075, 0.14437444808502353, 0.3855609593372191, 22.96180602042906, 65.53835368925526, 98.36484616802585, 92.5935491438835, 93.24288968117007, 73.6880700818954, 78.54514106627434, 63.115340894268414, 23.770257503755634, 52.856299338802216, 68.46252379878875, 99.3358838173651, 70.329909324646, 40.55945704060216, 43.804331902534734, 13.645262948928343, 0.47916378825902944, 0.0837785403634752, 0.0752038867663472, 0.220903352864327, 0.3496645306867938, 0.17796959457618577, 0.15203293713350452, 0.6415101993949183, 0.6022819011442123, 4.3637152641050285, 23.655000617427213, 65.09046608401884, 99.0643616645567, 105.50783526512885, 100.35947338227304, 107.51441001892091, 106.51414286705756, 103.70902845936438, 102.4721404044859, 100.34805144033125, 99.42523540989046, 101.5281435751146, 102.31778729346492, 98.49230750914543, 97.19576020394602, 94.22528651452835, 90.74965077061808, 93.76088573086648, 95.78066318265854, 91.00395371837001, 98.53532022045505, 99.09530132047593, 98.94258776018697, 93.68977315964239, 93.03895781117102, 88.17368907313194, 87.46632883625647, 83.9691435906195, 85.26153318343624, 84.4009651676301, 92.20178281107258, 94.5627280204527, 92.32600427442982, 89.88126939342868, 91.41459449645012, 103.77746597413095, 68.53886096708237, 8.182948673925093, 12.938449882691907, 66.7230938326928, 94.31967443035495, 91.14202899317588, 90.44566708226358, 85.37140661670317, 89.77388274285101, 88.15982741694297, 86.40512374139603, 85.73668126137026, 85.05450264100106, 82.24524621040591, 85.29046458582725, 84.9862769342238, 83.79180539038875, 86.67023674134286, 89.71052861982777, 91.78895335043632, 92.24772161053073, 90.00398466663977, 91.36121888314524, 86.21804237365724, 86.36700614806145, 84.78760888499599, 79.91699787878221, 81.55847057219475, 84.29572797590687, 90.3988261376658, 85.47807155116912, 84.74341161789434, 86.68740887795725, 81.14614317494055, 80.03950918874433, 80.55624223524525, 83.43134741629325, 89.86925909596106, 86.63081692111108, 67.83198710410826, 16.792480599495672, 1.245657126269033, 2.863832779469029, 0.6720257490392655, 1.285097293796078, 3.034735841135825, 1.2251423948234128, 0.22211257668752826, 0.10677625470223928, 0.14637920825231462, 0.15118052642191612, 0.13227074917766357, 10.266245968880193, 33.828916934228715, 36.92452992162397, 30.681689477735954, 27.758582330519154, 41.47184348875477, 21.872365743883197, 33.03042434876965, 48.121649449871434, 60.10336068368728, 87.978864946673, 70.58541251767066, 73.68431245127033, 31.17670043822258, 2.9070891680256015, 0.08575843331674415, 0.04018134610246747, 0.10601185217139222, 0.023613986108572255, 0.022958513619678638, 0.11043397214023337, 0.04633949791652061, 0.059169792915664376, 0.012095742126656397, 0.03900228316084512, 0.03886086716046257, 0.06654161569331923, 0.05385642923835305, 0.10767915060803776, 0.05303144064401427, 0.04109448460381358, 0.06663647270010364, 0.04479093927769892, 0.039254954280031305, 0.037740026901085535, 0.04326445546241538, 0.03948891370166694, 0.028708246724319555, 0.015218387369156606, 0.1907105560624792, 0.08237604021785722, 0.12605319490596173, 0.12912369062823634, 0.08168479908377894, 0.26422761681099094, 0.22796640773454022, 0.1722115704849843, 0.1772639663108895, 0.14477955537938303, 0.18943547932130678, 0.1595973965501593, 0.11272829056026475, 0.1276084836271982, 0.20429452070065085, 0.12056378422365074, 0.14728886105360525, 0.1729537871095442, 0.10713219447361846, 0.16889442509460836, 0.1268669947861664, 0.18529570871783843, 0.46604137627347825, 24.825988931040612, 82.01315956730997, 117.29971162734495, 101.19747992484801, 95.6716291366085, 74.21207520269579, 79.93595077145486, 82.0877944269488, 52.19413265105217, 99.52949200907062, 75.95913025640672, 112.84120836565572, 92.73212648207142, 55.44393400992117, 60.757176645340465, 25.459981233842914, 1.6400320803926838, 0.3401294939460293, 0.23566626553093237, 0.2843320928514004, 0.45907733060659905, 0.2579476570169772, 0.678051428929452, 0.9839271705958151, 0.6375425993915528, 3.102068473254481, 19.330381578014745, 57.98154669423258, 98.1585922548848, 109.62010306696739, 105.42417895409369, 113.12533701619795, 110.98661761130057, 106.75100695702338, 106.94502307522683, 103.87301491152857, 102.56142139434816, 103.9100891543973, 106.1247770247921, 100.47033525282338, 98.69128934798702, 97.59189605712892, 97.10185081728044, 96.17850918923655, 97.61294349547356, 92.54637087545088, 99.74240610676428, 101.44982953225413, 102.06112307886924, 98.39522884738062, 97.27993426784393, 92.82939341760452, 90.51137462739023, 89.01604160185784, 90.50153732299806, 90.11440723173081, 100.08102432374032, 97.37573423693257, 96.41655783499442, 92.55015988503733, 96.12082681348248, 104.13292684862691, 66.67532720873433, 5.593292020982312, 11.012326863504226, 65.91405791621055, 93.00899874779486, 94.62181460472846, 92.92034533716019, 87.4286505483812, 90.10712731269099, 90.02526744719475, 87.24428346080165, 87.86357864256829, 87.31463509221231, 84.93668248576503, 88.01268362229871, 87.32259750366212, 86.4517685674852, 88.85178842852193, 91.77295008013326, 95.05120431223224, 93.3612197445285, 92.72252451988959, 92.38882495510964, 88.24342881479572, 88.21633308164536, 85.45939322440856, 78.92367332212388, 82.81788087660267, 86.90717927871212, 94.15505255422285, 86.21183718404463, 87.9014059805101, 88.21958080414804, 80.9602463629938, 81.60498203769808, 85.23125248570597, 87.37478856117495, 98.01077381257089, 94.14507404450448, 64.59788699303904, 9.651201655787807, 4.916739060032753, 12.780895137017774, 3.624441642915049, 1.687437110850888, 1.600781412374589, 0.3864763424761834, 0.23782401345670226, 0.23829871217810342, 0.3936384678367646, 0.20007516888360824, 0.7227722711620793, 20.761066098367017, 50.176053585544715, 50.65774417692616, 51.28932029970231, 52.374016469524754, 74.24879643224901, 65.54214269884172, 51.67565414982458, 51.01513877991707, 59.81787097069525, 84.8478800250638, 76.58202617399155, 82.86106617219987, 35.78850953809677, 3.212549628749971, 0.13980192973488761, 0.14625332468459684, 0.21161737130774608, 0.1367121745621966, 0.15537608354803056, 0.16711293359196958, 0.17057540586158154, 0.1544181059204763, 0.16916272440744987, 0.25756452112428607, 0.12161934613099984, 0.15496775868438906, 0.20107171137727078, 0.25160435707338397, 0.20072570010539026, 0.11292241724027742, 0.18977373778339357, 0.1282032053436964, 0.08480342044945686, 0.12025056917580867, 0.0992282125498018, 0.24993641512288203, 0.17451652986628396, 0.1529032589807626], [0.009883290735043345, 0.11558995071438052, 0.04574186123547055, 0.10007676983913107, 0.1194088836951602, 0.04406667975408416, 0.03123397540841853, 0.11759890904349667, 0.006953731729393646, 0.091800561114665, 0.06800539521200043, 0.05579083189067822, 0.036164934807006395, 0.05539858721256737, 0.01320317010169909, 0.05867761206783115, 0.04780773989736073, 0.05238300467270517, 0.004298468111007805, 0.04252201284191782, 0.022480809918394493, 1.137731517514875, 24.893787099469094, 52.38348507112073, 70.54445512833135, 69.80259372342017, 68.19359041029408, 73.24313209902856, 65.30531783257761, 37.54478608408282, 37.84405508349019, 51.09342536618633, 41.448681892887244, 64.0715951304282, 43.684401512146, 32.417000955150975, 41.552016735076904, 15.562641043816845, 1.3982807171921576, 0.11244357398320591, 0.0625329610380915, 0.13911811965367488, 0.07146311773648185, 0.38288173536139153, 0.26822497166933557, 0.023367370914427504, 0.21945455802544472, 5.899371725897636, 34.003952703168316, 81.50211395755892, 104.31420310851067, 101.14274717146351, 95.16246626454016, 99.80875692059918, 97.78806947892713, 95.98736424599925, 93.9575533713064, 92.1967072640696, 97.50975378098028, 99.24977994734242, 98.093473065284, 100.59232096518241, 94.91982060094034, 92.65121583015689, 86.39116794832292, 87.92997652484526, 90.93288037084764, 91.06092222275274, 91.30972600752308, 93.98500211777227, 91.75650750437092, 88.77068165809878, 88.94124200267177, 88.43843337028258, 85.31226511924498, 84.2211558741908, 82.32587445166804, 78.43095302581787, 77.03167884580552, 78.3015775680542, 84.84158854330741, 92.05337601323282, 85.98899164507466, 89.78239428612494, 90.02957420964395, 92.37068791543284, 35.32149645590013, 25.65893953846347, 74.6895767027332, 92.6497410189721, 84.73091494652533, 86.84843001827117, 87.97182821458387, 85.6762061580535, 81.17057169637373, 81.86000670156172, 81.31012178236439, 77.16824793046521, 77.10625879226193, 76.50109983259632, 76.39599600145894, 81.40143455997591, 82.52371880315965, 82.23626398271131, 81.06593854965703, 82.68987824839931, 83.61506339042418, 88.18213001374276, 83.49147735103485, 81.13992229584726, 85.4657788430491, 83.9678256742416, 77.83242287174349, 82.21561662612423, 82.82226608645531, 81.47931714211741, 79.26724941499772, 80.32639918788787, 81.12285214085733, 80.76902297235306, 77.64846371066186, 78.9471604747157, 71.09185326483943, 69.402786531756, 74.40125896084693, 78.79355261402746, 23.024885577540246, 0.776571439158532, 3.1088318651722324, 1.964504146768201, 1.4768399081883894, 0.9634978119884768, 0.43216705202094974, 0.302077018085026, 0.09764266335555623, 0.11896328865400246, 0.04014491096078869, 0.6041064774317126, 10.101877085624203, 27.86866561059029, 30.425458685044322, 34.86454817556566, 45.425800508068455, 53.30087646361321, 37.02072212772985, 35.892558251657796, 36.209579898465066, 41.118881164058564, 57.37656031885455, 62.49142123806862, 65.6600256120005, 29.888052786550215, 1.8755892856467156, 0.07941082029813722, 0.03572515820363357, 0.07083544657836038, 0.09636626128227481, 0.09189470565967983, 0.03870431326269623, 0.05439700002992346, 0.03499534837300739, 0.030959578035699747, 0.008048935335189586, 0.0688712967319354, 0.03439235673736661, 0.006721037789247931, 0.03882462354076486, 0.04593839343156546, 0.04417397036787964, 0.03622832092186136, 0.03245870868164686, 0.0698276732357279, 0.04483238463440249, 0.059498015625943104, 0.023031527544522, 0.042070028627471584, 0.023642264329077258, 0.018391390443749486, 0.053482145491626956, 0.03456028704080851, 0.10847607357127052, 0.03222254292678929, 0.03312606319424606, 0.050770680705506, 0.030817813465311646, 0.06245821000887983, 0.04222719922601696, 0.03450203754548584, 0.06466332132056837, 0.03141745729672332, 0.006465580504042127, 0.006857894130066158, 0.01439771759549096, 0.07383624362128396, 0.010484787541621876, 0.059084002559463826, 0.12993454873081178, 2.684335804754688, 42.30053440217049, 75.0022445186492, 92.15101949630245, 91.58324072437902, 94.77196293492472, 92.97551739600398, 82.32314448202811, 54.99775263570971, 43.732623131044456, 27.548894382292225, 49.71028781706288, 81.65023050000592, 43.83015678774926, 41.959904009296054, 45.38593746000721, 11.526255415331933, 0.6308340593691796, 0.14620032672199512, 0.03542822252418246, 0.03879799432451687, 0.1656503032051748, 0.6166546911962572, 0.2913091313694754, 0.26962988499191504, 0.4918101532084327, 11.137235722234173, 47.21614676137125, 98.54559683030652, 109.27880194879349, 106.77742019776376, 101.60812070292812, 103.6704715605705, 99.08669564031787, 98.66191079539638, 99.60659011717766, 98.638047095268, 101.48457388724051, 103.99875825451267, 101.6272226456673, 104.29926672289449, 97.02347401649722, 94.79061772746425, 91.9968625037901, 92.77794761042442, 95.42347646528675, 95.65163289347004, 97.14663643990794, 95.95374168888216, 94.70338421483194, 92.06636690324353, 92.54058930181688, 95.08150069944321, 91.30923963362171, 91.24519517344814, 87.50105750176215, 83.60175871079969, 81.28667385347428, 82.8510327492991, 89.77052519398352, 93.81683441900438, 91.05457582781392, 94.17797488550987, 94.84583685475012, 97.74795147680469, 44.03106058797529, 32.20568914567271, 82.25860580321282, 97.1258714122157, 90.21601230867448, 90.92469830666819, 91.5142854567497, 87.22360472525321, 86.10821600883239, 84.58395942564934, 86.58843963376938, 83.01887881371283, 81.77995112634476, 81.8712168355142, 82.49392447933074, 86.80493093306019, 88.10993486835112, 85.99080378009428, 84.73106399659189, 84.61099240087694, 86.98697597749772, 90.28111580879458, 87.22038053697156, 86.37850653740668, 91.04387560198384, 88.51458226480793, 82.55349743750789, 87.45274174597957, 85.77930173566266, 86.00453992043772, 84.26856948483376, 81.92765189755349, 85.77570099984446, 88.21687436872914, 86.76934719085695, 84.40464435085174, 77.47958998526298, 74.79012273973035, 80.86458759923136, 90.61722370886034, 41.220478396261896, 1.791019797805817, 2.5974175526249796, 0.6487714871764183, 1.7115063676911018, 6.471303797537281, 1.5265631819925003, 0.733713477609619, 0.33611963653276045, 0.0131019986151988, 0.14868841176071476, 0.3019443316565406, 7.041928249020731, 29.386044317676177, 31.138223948017245, 34.20866120246149, 50.90678722627702, 47.856650198659594, 15.3424705613044, 38.61336915723739, 48.36508350987589, 54.07085341791953, 72.45454742062476, 77.23404176773565, 81.48043109524636, 52.74568457757273, 4.027443605084573, 0.044019055898271264, 0.024582491699425925, 0.03108301969815887, 0.09717404737227386, 0.039630770202605956, 0.0969322776842502, 0.07351176708095497, 0.02915016645866056, 0.024977005913012454, 0.035183189301601345, 0.015802412583012015, 0.005353202643398677, 0.004434807342477143, 0.020861993356037046, 0.04617175147418053, 0.009714346322711679, 0.06367989425216952, 0.020598227368487466, 0.031034495689034946, 0.04823461941052829, 0.048554441966717286, 0.03983522757827755, 0.038701697072434815, 0.12136935631954864, 0.2627543071585317, 0.09772248205638702, 0.12813306999422852, 0.18375430917066915, 0.1475052502486975, 0.1605340616116601, 0.19276957057656782, 0.12369058740835999, 0.20329184950359408, 0.20681608378166155, 0.11018741440268294, 0.13958938630117526, 0.10156210707200151, 0.13142020772061042, 0.10850602760910989, 0.09567063046439041, 0.1772493799968112, 0.09614484655039926, 0.20307624171818459, 0.11537384497182024, 2.1349436333102565, 45.22264526736352, 89.03595155285251, 104.76161218458607, 97.80318629357123, 98.94603160119827, 98.28374724234305, 90.04775047302248, 53.9637452556241, 58.03514980500745, 77.50830957966467, 62.743394297938195, 89.94230931805026, 62.06960562736758, 50.281969347307765, 64.76456419114145, 24.569750293608635, 1.6781360680057158, 0.20663675792034597, 0.19975341195541046, 0.3243073574717968, 0.2754705086831124, 1.239370057179082, 2.086266774323679, 0.6228707899009028, 0.6489841531841987, 8.58784023792513, 40.97620887141074, 93.29563771524738, 112.30838575670796, 113.08896095521989, 105.566953228366, 109.69473008186587, 105.08614124790316, 103.27407683095625, 104.48653636440154, 99.99776809446274, 103.49602022478658, 103.73613988199543, 102.37645810650241, 105.73876088665378, 100.64862266663583, 97.37968014132593, 95.80583695442446, 99.669081318763, 99.78584243405251, 98.83005495994323, 97.64507555192517, 97.53205637778007, 97.6278720363494, 95.1962378717238, 95.1587635470975, 96.5746371976791, 93.58925850160661, 94.18306612199353, 92.72809428553428, 84.66946709540584, 83.50874362453338, 85.45296053732596, 93.76287045017366, 99.06687982620733, 92.88441642638176, 97.30619845851776, 98.00552568128033, 98.23438029135428, 45.75806840773552, 35.75097637791788, 83.74785131023776, 101.02712354352398, 92.95921602556783, 94.85920429229738, 96.52973390394642, 91.92710707264563, 89.56569902358517, 89.33231015359202, 90.1390318716726, 86.94281008935745, 86.4869914516326, 84.78588304212018, 84.47428995563139, 90.20051894649383, 91.63255276218538, 89.58916264195597, 88.61901144827567, 88.46868268905148, 89.1394393674789, 91.79409950010239, 87.11094640916394, 87.9649248430806, 94.5836107192501, 90.12235395369991, 81.69723618415095, 88.07799893040811, 86.75384598393595, 87.25969837557885, 84.93379562131821, 84.38376949679467, 88.95140094141807, 92.77327214517902, 88.35194510798301, 87.61726948522752, 79.71396815392279, 79.1405725479126, 87.246134819523, 99.10720963631907, 31.629273314629835, 1.9167490447721176, 9.56619506882083, 6.453591844727916, 2.6786267949688822, 3.370616488879727, 1.2598679959774017, 0.8790117970878079, 1.0937959460481521, 0.3435949692803045, 0.15863466917747454, 1.2647127360105515, 17.48272361293916, 44.56676221662953, 41.80632752756919, 49.93168207906908, 64.78957322336012, 76.64855741685437, 56.885103025744044, 57.57340446595223, 52.546534076813735, 58.41204251012495, 78.82176230030676, 81.94833063310193, 91.02584054393154, 61.246915940315496, 4.168812199946373, 0.16684379158241136, 0.11220982523574946, 0.19547997433091366, 0.1793684864476804, 0.15890327492548575, 0.18847727186737523, 0.1582903892643029, 0.14619888647669746, 0.117506189422021, 0.10070980361272251, 0.16728499693976295, 0.1291019030876698, 0.05494756060802648, 0.06534796643761859, 0.10710807802576212, 0.11743456020110077, 0.13261582582227646, 0.13619803763445348, 0.17933712280806036, 0.15431564932148303, 0.13528728166655188, 0.22955291453869114, 0.18472118873990354], [0.06666823470544431, 0.07346923387939892, 0.058541780848416596, 0.028147001134892626, 0.03422746014210486, 0.06427768798124406, 0.047883548127907904, 0.010456904814007783, 0.06675049722675355, 0.0179114057156708, 0.046295807922198895, 0.05823994220625009, 0.04131993278861046, 0.01482568974156053, 0.09583806664112116, 0.03431224309268498, 0.057137645105080265, 0.0038622430433714466, 0.036900218335851546, 0.13261360416729606, 0.37400985497140116, 32.324542845449145, 65.94200088131812, 76.56315172872236, 75.945660837235, 67.49354931616014, 55.2228888388603, 56.83942310271725, 73.30476822391634, 38.3477540939085, 28.796796452614572, 31.096442860941735, 40.20148192682574, 29.800442726381366, 32.03630355096633, 52.15400288181921, 15.87924691938585, 0.9757018990574345, 0.14723540343824895, 0.15268993413736745, 0.12693333800040907, 0.1099001927181117, 0.2564986170299592, 0.9238622613972234, 0.15681671188964, 0.18505157181812873, 12.358838300551138, 51.64156875302715, 96.09925377753474, 104.6701660463887, 96.49873933484479, 97.92970626584946, 94.72703610697101, 89.4951512736659, 89.71080318573983, 95.4519058042957, 98.21059503862935, 102.83006452745008, 101.78654147732644, 101.72195573006908, 100.99498364233203, 100.19414547950991, 92.44638965975855, 92.55430975267964, 89.22551970328055, 86.96769360573062, 88.26732389388546, 90.18231130415394, 91.86184667771863, 88.99661802476453, 93.80262759424026, 92.072705453442, 90.83983390561997, 91.89888169688564, 93.89474838010727, 89.65583509014499, 87.16753052126977, 83.5454099409042, 77.88860690209174, 80.65536052949967, 83.81047587240897, 86.74896655544158, 85.44126402947211, 89.02642019333379, 92.7543741656888, 87.7361879041118, 42.75775332604685, 30.15719209947894, 81.99682681791245, 88.12667554424655, 82.33895163382255, 85.53212181214364, 81.13086946548955, 79.68023577044087, 76.67864199607604, 77.3084020614624, 76.09517374346333, 75.92129507372456, 78.5486319757277, 79.76557870065012, 79.53662995369204, 82.58318977971231, 82.40634579812327, 83.27113428423482, 84.9929371187764, 82.11143062960717, 83.6389898484753, 82.09525477501654, 83.1983272490963, 77.67980344833867, 77.88465315295805, 80.76211175610943, 77.70641280758765, 81.96657749914354, 82.05152819233557, 83.20638379743023, 80.5327315484324, 78.34009524314635, 76.98891716618692, 77.049604077493, 80.09798388327323, 77.29308912830969, 76.6416540453511, 75.07587525152391, 70.07449242376512, 67.44881860671505, 86.48265331022202, 40.77748198663035, 0.23437277203606022, 2.0529388852657813, 3.7479627180484036, 2.591244722566297, 1.0995354767768615, 0.04690490910903581, 0.303407957957637, 0.09527731326318557, 0.11433694496630661, 0.05859766313205323, 0.8223682365590527, 14.986824354817792, 30.87721766964082, 33.762970124521566, 35.08377336686657, 35.10754293011081, 45.307635184257265, 30.088405493767034, 34.191304714449, 41.18309036377938, 47.82583998095605, 56.016745182775686, 60.770763735617365, 61.9638506827816, 28.550732443409583, 4.144781308789407, 0.06488282849351246, 0.08297727368171177, 0.0326077817308326, 0.021903744613331173, 0.05046559002010092, 0.021878682046888337, 0.05032848326429244, 0.025462676928709113, 0.06758454481079694, 0.09631755341204906, 0.01912316720512125, 0.08225477616032285, 0.0333524881411464, 0.02644370805712477, 0.10926156650267302, 0.022045719857898452, 0.03755842575863485, 0.039855222473101276, 0.019877204566352794, 0.08538249865054123, 0.024849279903836792, 0.06326018915241284, 0.02995172616905503, 0.053116296372947194, 0.0252598628116351, 0.0670589855121028, 0.015091759738542381, 0.008188825862992915, 0.068089687866309, 0.08743739161159723, 0.013423085216462854, 0.04844604435587122, 0.13061673470562504, 0.03737843723126477, 0.0487210507684898, 0.07376453779157131, 0.03219985906335135, 0.027621198603282535, 0.03920235085271059, 0.02050192628596579, 0.03314946334989321, 0.10202011273753259, 1.6794191733483346, 53.00658495195451, 85.50756777486494, 93.78100748985045, 93.39807433466758, 94.41088522634199, 73.20594802979501, 71.10511087602185, 88.9964532852173, 48.86294995584796, 23.540318358329035, 27.518919629435388, 55.661307842500754, 33.79850679828275, 39.76175677391791, 53.78685420559299, 13.322618584479056, 0.25817895428307597, 0.17880843020975593, 0.12722059032849728, 0.44139148607369394, 0.3232260396884334, 1.110555866072255, 1.2818059349252333, 0.24897365710668026, 0.507417417341663, 20.178743177844634, 69.43840165292063, 109.15227413177492, 105.04379533952283, 101.56815959561257, 104.4995507886333, 96.79571767007151, 92.54694354149603, 97.13344158664827, 101.94403248448526, 105.25753313495268, 105.44477139749836, 104.34849246855705, 102.56832476585143, 103.88427995866346, 102.99529044858872, 99.71633803459906, 96.65965064879387, 95.73051960237565, 91.44183927966704, 91.99221841750607, 92.62721876944266, 94.68833800285094, 94.45558455682571, 99.24254709674467, 97.83884848317793, 94.32056873075425, 94.4599070087556, 96.79352114277502, 91.77134975310295, 90.26024879947786, 86.28921770280408, 82.24903521999236, 87.02264601184477, 87.62054858669158, 88.33153309360628, 90.06530700191375, 93.26993050113802, 96.28967700466033, 89.14723703938147, 49.096495720648, 39.0801743538149, 83.13977410716396, 92.54420572711577, 85.64504684940462, 86.682600052126, 83.85845430435674, 85.78914688479516, 81.97049202457552, 83.17171004510696, 80.21761617352887, 79.39352620032527, 81.65420778336065, 85.14612920822637, 84.19201266381049, 87.1592935439079, 86.9663207761703, 86.92927791226296, 87.32289560379522, 87.22078846346948, 86.98139052237235, 85.17275425695604, 87.13472381714853, 81.07488939839025, 80.11216717381632, 84.02333505692022, 81.90032082219278, 86.81269722600138, 88.6356109188449, 88.40527365284582, 85.58380296153408, 84.15880587793167, 80.83036884184807, 78.86208426567816, 83.9895320707752, 83.82474545509585, 84.26160335540771, 81.74043716922884, 76.48120557108234, 74.6351420494818, 93.22796898503458, 59.13330754926128, 2.2265635815358933, 1.8878209518809475, 1.4492765549690494, 1.6735408887747796, 2.206272670338231, 0.29620333003901667, 0.2456068998623279, 0.10662210249011556, 0.2065725291087743, 0.16147846416119607, 0.5518077386002387, 12.564774501708246, 31.09172817199461, 33.5661808906063, 42.694175627923784, 40.750194057341545, 33.03651971201743, 16.26453447726465, 41.21684628148233, 54.609696865081794, 65.89898032526817, 73.62119367045742, 71.68757500187044, 78.88303756713867, 46.11645929275021, 7.583524219451412, 0.05162091955782906, 0.03979975387694375, 0.08071313912589705, 0.020122088401788668, 0.04644167872386114, 0.04007528505979046, 0.05679113970648858, 0.04999305166664624, 0.01066513900314608, 0.03353836405421457, 0.01078203157146251, 0.023413782436100226, 0.06543103335124832, 0.0141746356647702, 0.033920473389087186, 0.1031510960010271, 0.03413852499497514, 0.017038013771056168, 0.013147196845121443, 0.05552990617410791, 0.04680247166224065, 0.03227797321855061, 0.1156513526615116, 0.13686065772368064, 0.1428623590618372, 0.10902483001231186, 0.12537077910477115, 0.23287194450536083, 0.14874887141969897, 0.24955039873959559, 0.1285854219308784, 0.15167402494097912, 0.28622212369115124, 0.1414220371553975, 0.11240438858587896, 0.13253734777531317, 0.29751879493555716, 0.273944124459259, 0.12016909572506144, 0.1006293184153976, 0.11948143222158956, 0.29530780389904976, 1.9465770764696984, 56.87335944944813, 101.84309421047088, 105.03285192674207, 105.26812353441792, 95.36785725624331, 81.66442163528936, 78.11053460644138, 99.78517563112321, 61.85270640157885, 47.5685207305416, 48.28537310323408, 61.91414248558783, 45.852817181617986, 49.84898282635597, 75.82896247986825, 25.24008531724253, 1.2257589423848738, 0.23613049949128784, 0.23811148028940926, 0.3581473303418006, 0.3493418544530869, 1.4744135545146082, 3.579775407429665, 1.7009296965214515, 0.47598308312796783, 14.85936007192058, 63.70237850373792, 107.25787132017075, 109.51208883716215, 104.8310616708571, 110.46655839489354, 103.87343068276684, 95.59195795366841, 99.95054275758805, 102.37346141569077, 104.03105505051153, 107.81032146946077, 106.05684941814792, 106.07406077846404, 109.18288430859967, 107.3649206469136, 102.08585754517587, 101.63797778467979, 101.91171999900573, 95.61863007084017, 92.5305715683968, 94.60224197756861, 97.30165635385822, 96.05557426329582, 101.0241033184913, 99.84309334908762, 99.6754434031825, 97.31933839859502, 99.4977992580783, 94.45534921461537, 92.17983322758829, 89.34671309686478, 87.58662008470105, 90.45152710330102, 92.92848033289756, 90.0480015047135, 91.55196374462497, 96.41955452580606, 101.37623802308114, 90.23764810254498, 59.719898008531146, 48.29607332906416, 87.4856347422446, 96.3546863678963, 88.67267731697329, 91.533003007212, 86.15387239763814, 88.7044563601094, 85.38504077542214, 86.15395084504159, 85.13790007560485, 83.80851468732281, 83.29934397051412, 87.80679841195384, 84.1371073261384, 88.29152491784866, 89.84421084004065, 90.35764125085647, 89.47129541827788, 90.33707234167284, 89.59241036445864, 88.12107439964049, 91.97139847663142, 82.48575810463198, 82.12610813879198, 85.03871117868732, 84.61434994974445, 90.57457185560658, 91.09856128692628, 90.61503502630418, 87.69845470305413, 85.7747047178207, 83.5198910005631, 82.4683427810669, 89.09353194698211, 86.90070736792781, 86.58075963297199, 84.64683501951157, 80.84821562613212, 78.09095413454118, 104.27927832449637, 49.42685342604115, 0.9950030859439605, 7.485166865010416, 11.787148925565905, 4.758762169268824, 2.023854265289922, 0.4691398342049891, 0.40398696737904705, 0.3946866599782821, 0.46684013018685006, 0.14890080197684227, 1.160603470859989, 25.778105066668605, 47.57059958673293, 46.86755395704701, 52.38739567418253, 50.28171439324656, 65.8410547625634, 53.3226260062187, 53.42065388156522, 60.717901952805065, 66.74885595998457, 80.3615906930739, 79.20304806001725, 92.14321397965955, 55.136537859516764, 6.91909138233431, 0.17121496670428785, 0.2236490426284652, 0.15775670177273213, 0.16840828101961844, 0.12555795736731062, 0.11206197792724257, 0.17666395092683454, 0.18062267963203693, 0.2166623820460612, 0.16380374019424762, 0.12007050787008579, 0.12845663488992762, 0.16421381173835647, 0.13524770556438354, 0.20349927546997226, 0.19859350887277435, 0.10048536283354606, 0.0946258933794114, 0.14515147574486273, 0.19945400947284317, 0.09930202512130623, 0.2184557632332848], [0.02490106170185872, 0.03816795978514898, 0.023327603290278106, 0.019187551149497592, 0.02133420995256353, 0.009871561928922612, 0.028415637526420817, 0.026609181133549542, 0.06122006636653697, 0.06788842890772127, 0.07639434143540359, 0.017376553770455144, 0.04654244226854175, 0.05773872535134997, 0.052462693138588826, 0.020190944384422996, 0.02414487354877976, 0.050717410781691154, 0.07731501058104538, 0.10481462528508519, 20.737355370675367, 61.38160228729249, 68.51800964724633, 70.9447879175986, 55.32609424283428, 50.37662398430609, 72.73389077955677, 53.19231310198384, 38.19486010459162, 47.98986565682196, 46.095945296748994, 49.87448607721637, 27.342581633598577, 35.32068060290429, 42.42629735700546, 23.71153569990589, 1.5475634293210123, 0.09510873561544765, 0.3066269981284296, 0.08474693678679966, 0.0891866461343823, 0.15089004120278746, 0.9439904555197686, 0.25584860674796567, 0.12261097800106772, 11.830366580717026, 62.74340214267854, 97.00028496403849, 100.68773654199417, 94.78527545928956, 95.64756147323116, 91.74399514352122, 90.31120038801625, 96.28158123262467, 99.75720128705426, 101.12423358425018, 99.81869620661583, 97.5248941298454, 94.02835999765705, 98.91741398842105, 97.90325380140736, 95.05971585550617, 91.00689549599925, 88.62761712843373, 80.27478864116054, 87.19266506933397, 91.09696880463632, 94.39328947374898, 92.30408606990692, 96.93434207670151, 93.37329279991889, 91.11892623286094, 90.14653928818242, 92.65335744427097, 87.83323518691525, 88.21820797458773, 83.20165341900241, 81.82968678012972, 77.2935833469514, 77.95123930900328, 80.8442932559598, 85.98738347330402, 86.43140362155053, 89.11317517680507, 79.74433514379686, 85.38725299219932, 39.80145900480209, 29.071013273731356, 81.14691980423467, 93.37101782521894, 87.44146100936398, 77.69190788269043, 81.96982522164622, 83.30132084508097, 74.44689966017201, 72.25665600069108, 74.42278492835261, 76.85049672280589, 79.84641874990156, 82.10469984239148, 84.57762087545088, 84.53594176999985, 81.99991764560824, 80.55020962992023, 81.84181474870252, 81.10374235337781, 82.78511339618315, 79.80952493606075, 76.60891794389295, 83.29799467517485, 81.49336707207465, 78.90297889709473, 78.76793953680223, 77.24095298397926, 82.8943592502225, 83.85833663325157, 80.46450584165513, 81.55152797698975, 79.7323719147713, 78.25468955501434, 77.54854525289228, 76.81809010044222, 76.24862470934468, 76.11595446063627, 76.22190552373087, 76.29372412158598, 68.59011065575385, 86.7517122145622, 61.13468516257502, 0.9133652633716984, 1.4909545572534686, 12.868578741627356, 1.0571194560297075, 0.7107723924902178, 0.229301790917112, 0.05821060486918977, 0.4069517276460125, 0.052235567221237775, 0.05586751346145907, 0.7590512534783733, 20.31912676749691, 35.36615656268212, 21.479546254681004, 26.581526110249182, 29.336679327872496, 37.58778702828192, 35.74242561094223, 34.65784711222495, 40.80847655573199, 60.723389348676136, 55.21285541595952, 56.180747324420565, 58.00429644123201, 39.47902448715703, 5.9766865449567, 0.08557730714880651, 0.05834487709967841, 0.06317850119704682, 0.03955836340244259, 0.017075421844398784, 0.020413799361596187, 0.02941252859008889, 0.023959183412033225, 0.032811001874506474, 0.023734079966802272, 0.025575487205999035, 0.07838423949696365, 0.058084924314771934, 0.013732016875198292, 0.04118271495005296, 0.03429633144649767, 0.1127423482736753, 0.05643324258046285, 0.018124224941035914, 0.028409346029342666, 0.0696232503340129, 0.0564192729671636, 0.06172196887012932, 0.004648473573803541, 0.0669139267636403, 0.022381413840658726, 0.08180303709401239, 0.015874932381144215, 0.02194613225818161, 0.030542653835108204, 0.030345244468339992, 0.037578359366424625, 0.014925539726391436, 0.033397503467577125, 0.029846364181608926, 0.01059752121011937, 0.03443190602645759, 0.05318255914795784, 0.07285101624626307, 0.0695744275505985, 0.17506701000515493, 34.852145641080796, 81.89263297665505, 84.95161887138121, 95.3174469547887, 83.45395595796647, 60.90367717127646, 94.68246229233281, 72.9668560335713, 50.27851766155612, 42.18741716877107, 33.54998934653498, 56.013944610472656, 28.579271608783355, 34.13690144015897, 47.98118152926045, 23.62861287209296, 1.0257818633990905, 0.06572093634355454, 0.19322196081761392, 0.09318735645783525, 0.36376535952571903, 0.2367295496045582, 0.8645094462460088, 0.32753975821598885, 0.1538756390612933, 20.946143134947746, 75.42250294839182, 104.41016781714656, 105.6075732938705, 99.31052961657124, 99.36259515823858, 94.8368703165362, 98.87571919348933, 103.6963592037078, 103.15026329409693, 102.60014303268926, 100.95368892915788, 99.28286906211608, 98.0258749377343, 105.15073483990085, 99.62580973102202, 99.2397935928837, 95.5265877323766, 92.62015850313249, 89.25532971659015, 93.57206283077117, 96.97378543115433, 98.51533182205694, 97.29369394240841, 99.3632854953889, 96.56022640966602, 94.9792209748299, 93.1652581307196, 95.73190027667631, 93.62504620705882, 92.64897223441832, 88.918484410932, 86.12584314038678, 80.46743977454402, 81.26121767105596, 85.6453763284991, 89.20699042658653, 91.76676842474168, 91.35226018967168, 84.74796156729423, 88.14068625050207, 44.21984426436886, 32.30204609132583, 81.9316291809082, 97.66702513540946, 92.2082390323762, 84.70072838567918, 86.33853758535078, 85.7006895926691, 77.00692084527786, 76.14302665956559, 78.68473822070708, 81.53367334796538, 83.20069636068037, 85.4806838497039, 88.7200830828759, 88.69702739100303, 85.82200065735849, 84.836913078062, 86.21128805222051, 85.57207507471885, 89.17224607160016, 83.18950191620858, 83.3674833851476, 86.77505031708749, 84.819544822939, 83.77464894325503, 84.65613103681996, 81.77253000197872, 85.65214633941652, 86.88465702918269, 83.58448459256081, 83.24960831672915, 84.85190437686059, 83.96249909554759, 83.43137879525462, 80.1481431530368, 82.04151045891547, 80.89788852199432, 80.87021227805846, 81.5539441570159, 74.60962310914071, 85.76547145843507, 79.80679496642082, 4.146078142427629, 1.556106964426656, 0.5050828410012107, 1.2021356100036253, 3.612258025715428, 1.3297086160990501, 0.19724835040828875, 0.2572161043363233, 0.24944814132346263, 0.026256895601569165, 0.13192576446360157, 19.98145580291748, 34.44654118630194, 23.20548522856928, 29.409027445700865, 37.77445654715262, 26.144568189497917, 24.350197584398334, 42.9411005973816, 58.290641230921594, 81.97162166718515, 79.0319856520622, 72.73846426317769, 69.3043742641326, 56.77670440366192, 10.901333593553113, 0.13574868110158753, 0.05546181627939786, 0.06564451907310756, 0.024342168002359332, 0.03809963240318241, 0.03672991315984438, 0.027910875599651087, 0.017362000015113625, 0.030019310445735053, 0.05007793803909614, 0.07658335830896132, 0.04922674923774697, 0.03543109918433813, 0.06162479444737397, 0.04820859923418011, 0.03343213447219422, 0.043106223832094864, 0.04381549101503145, 0.03610039572982538, 0.05885042235135071, 0.05179021349777618, 0.13158496258960617, 0.22636767416711778, 0.13433321108741147, 0.15701221752791636, 0.04474204371593172, 0.20943261112176606, 0.17094452234525837, 0.14200968788035456, 0.20956834658019005, 0.10057868000360266, 0.15047650694126083, 0.0901916309169704, 0.10380795510906367, 0.14535951458158033, 0.22738108591687298, 0.052720071868069714, 0.21215590047499827, 0.27374527867763276, 0.10669560862645026, 0.29568413693097334, 40.58923959732056, 102.37773679917859, 98.96918142995527, 103.13705275135656, 82.1104500370641, 73.81301326136436, 97.35097623640492, 74.90722902359502, 53.88633335790327, 68.79992608101138, 63.40017949381183, 72.05106104573896, 42.264958504707586, 53.23259584365353, 64.6482463036814, 40.26347890976937, 2.526403530951469, 0.14330292090533242, 0.37502381830446185, 0.19490229807073073, 0.28247463607018997, 0.29753564886989137, 2.8209009670442153, 1.0482107727758347, 0.4004656902003673, 15.443381378727576, 72.2241787756643, 104.76154158192297, 108.67766734092467, 105.15301765934115, 103.94752425532188, 99.54147092757687, 99.54213773050617, 105.11765356986754, 103.28240794520225, 104.54563863815801, 107.83100020500922, 106.9136284243676, 100.61508640166252, 108.00235286835702, 106.25954966391288, 102.75521785982194, 99.60952405006655, 99.55029626046458, 94.16964377126386, 94.8785964904293, 99.2663323494696, 103.38950434038716, 101.56597091305642, 104.75698378778274, 101.27511932003884, 99.72815221355808, 97.50365057299214, 99.87809658050539, 97.4603868299915, 96.95624459174373, 93.15562478957638, 87.23177109995197, 85.03580862475981, 85.55056479669388, 90.568617697685, 92.92856662504136, 94.87474472292008, 92.46527979450842, 86.62592964787638, 89.91628046958678, 53.42611774321526, 43.450494889290106, 85.22265465028825, 103.05265118998867, 95.26851930925923, 87.95809991898076, 90.17428613478138, 91.17460819982713, 82.98026700173655, 80.17880039830362, 81.69658507070234, 88.41665637108588, 86.93432208030455, 92.01509368035101, 93.20030843057941, 93.6312121729697, 86.5311259608115, 87.63280207110991, 89.21573731207079, 86.789061023343, 89.4560609325286, 84.23529994103217, 81.26335144042969, 90.46395317200692, 88.4432892645559, 86.43770294804727, 85.1867022052888, 84.22616866327103, 89.24315467957528, 92.32616901397706, 86.29160250386884, 87.32652771857478, 87.79662378372686, 88.14413009151336, 88.25132062358242, 82.99586234554168, 84.65742541897683, 84.16735664490731, 85.96950531005861, 87.49224785835513, 77.84553143285936, 97.81159585522067, 71.46356059658912, 1.4832952714735463, 7.17437296144424, 33.111633100817286, 5.388620293909504, 2.8666610535114043, 0.6256639464728294, 0.2573990767761584, 1.3189012605336405, 0.5325317406846631, 0.13061405339789006, 1.6288860526777085, 34.72129929450251, 55.52011820577807, 33.05397818165441, 41.878695257248424, 44.17600001058271, 55.96162019237396, 55.93450092500257, 49.10771369934083, 58.47564374246905, 78.03369537476571, 78.6816317035306, 75.49501188339727, 81.50129810456308, 67.00985047125047, 11.39076792424725, 0.27688746490786154, 0.14229386053498716, 0.15061670103140418, 0.1923905562369093, 0.1375390132588725, 0.12966096341129274, 0.13462941132245526, 0.12329616704054418, 0.16339878611747297, 0.20634434215964811, 0.1414810106038086, 0.18777962623824998, 0.1537823601956329, 0.1380220776604068, 0.10698399476466641, 0.13239638759724556, 0.28330121429697164, 0.17964030976497358, 0.11843180749565364, 0.1873227314002091, 0.18014151512855486], [0.11338798419362116, 0.050241873194012916, 0.040496288678578796, 0.0768473751903061, 0.1005779522200746, 0.021273445773629412, 0.02952047037862001, 0.051486965253829, 0.04023499523980483, 0.09992808749478671, 0.03809714644786812, 0.03930015346756385, 0.06484398017487218, 0.0739832941983496, 0.06876848773249696, 0.028421570877394373, 0.06795637324572572, 0.06108500889592594, 0.1946320069292861, 4.336631788361458, 52.413934430768414, 64.33149530041602, 66.3593646018736, 48.8289822301557, 50.25363414518295, 57.57223167727071, 42.76480966998685, 38.66756846827846, 44.028393376258116, 55.532909054909986, 50.90232356902092, 30.000156087260095, 29.642924262631325, 32.246164083480835, 33.64255336023147, 9.695330281411449, 0.006328306645305167, 0.2600019983947277, 0.04513466377712546, 0.21347657476942386, 0.418172157820194, 0.4273132721502935, 0.3892685797426009, 0.4125514013632652, 8.374887897122292, 63.74122565792453, 91.463804552632, 99.60673132250386, 96.37020326429798, 97.9468156445411, 90.43719476269138, 95.835144904352, 101.70398342993953, 100.78279126075007, 100.9926929781514, 97.25778856585103, 95.4405858439784, 97.79172512792773, 97.66119649333339, 95.92121739541331, 89.57404582731186, 94.03793842561784, 89.25784787824078, 85.9645317446801, 91.99702724333733, 91.73652695071314, 94.22811062105241, 90.9266830259754, 91.96505992643296, 91.98103966251497, 89.9666044788976, 87.14576921155377, 89.14240467932918, 86.90885020840554, 87.65971737523233, 85.75615975164598, 83.87801908677625, 81.35762952989148, 78.45848806442754, 72.47240204964915, 80.92838887245425, 83.27357399848201, 85.88954387172576, 86.95403591279062, 89.70652780225201, 79.36207663628363, 33.15147653702767, 25.21684135160139, 60.7990675587808, 94.36620943007931, 80.29856604914512, 84.24369381320092, 82.76137521190029, 80.03530440791961, 68.4294189945344, 75.12397135457685, 73.52114969684233, 76.66154830686509, 77.84644142273935, 78.13821869511759, 80.31749540759672, 77.35118727530204, 82.53161061194636, 85.56670927232312, 81.92170558437225, 80.78790526236259, 81.52690333704795, 80.36696434020996, 79.06483157988518, 81.47761483346262, 82.45554016482446, 79.73430956563642, 81.03019791264688, 80.78089990923482, 77.84981466108754, 82.16555933798514, 78.15648125063989, 77.01929984554168, 72.96111368363904, 74.10015429219892, 73.19443979570943, 73.00681714088687, 76.03746783348822, 77.64483944062265, 75.95753777411677, 70.87724470323133, 76.87848675635554, 66.27400598218365, 83.8654596574845, 73.6793859543339, 2.5119660217915816, 1.79526282173972, 2.1584535846787114, 0.7248342121320387, 0.062171930612455455, 0.16425514984275066, 0.019992527612034353, 0.39210595490951694, 0.18006567242405108, 0.05698569922617847, 1.4473292207525623, 23.71273986754879, 37.23072582675565, 21.77088422159995, 21.983213886137932, 38.11256093363608, 49.305479603429, 32.07474866221028, 25.994649317956743, 34.459641902677475, 44.2435706815412, 46.88730309086461, 66.84887639937863, 56.050854113794145, 44.181946323763945, 9.76142418000006, 0.5078808086053018, 0.17914604515798632, 0.056856230366975076, 0.046045285679640315, 0.07035929995078234, 0.03908993511070167, 0.039452754351640903, 0.0402279740439788, 0.004193799433133175, 0.05337073332479885, 0.03578921081498265, 0.08392455672184307, 0.045491859932700475, 0.04308029558629759, 0.030210874561641007, 0.014299351906013346, 0.050904098747959065, 0.049101819449494925, 0.0515582688873814, 0.03127924354386426, 0.023147185753670432, 0.055638709811553846, 0.010825809665895518, 0.08879941167129625, 0.086806004927043, 0.021219859838545806, 0.027655040537337625, 0.07697263056592596, 0.03921546244753465, 0.03482454523984944, 0.029027182533736193, 0.043745305869848504, 0.055231208492430954, 0.03581739518971693, 0.06203604959732583, 0.01474093743449738, 0.10941429379125757, 0.10324501071966465, 0.12221606733698039, 7.543871508490655, 82.27100049295734, 78.22062769243794, 90.63613737783125, 66.96696327578637, 70.89783714663598, 78.14914641841766, 56.23353065982942, 45.99906275349279, 45.20824624646095, 42.3794093439656, 50.98198690722066, 39.17120079840384, 22.5750603214387, 32.87181350492662, 36.913151125754084, 7.646965124914724, 0.04932828270079148, 0.20622317769354392, 0.006743636425404299, 0.5808159949318056, 0.8645729396131732, 0.1966282022335837, 0.6586003952449369, 0.10825576200600594, 15.314826676922461, 78.68931954906833, 97.69339915244811, 106.66487955277967, 101.31344087662237, 100.187955979378, 96.30287185792001, 101.88054500087615, 103.52343759229107, 103.26414538967995, 103.68693767055389, 100.2727811567245, 98.45008711661063, 104.59801796943911, 97.81290592685824, 95.8505049059468, 96.07461344811225, 97.1949286614695, 94.61054171285322, 95.08747054684548, 96.83265070761405, 95.33454848874001, 97.12212947107132, 93.01125018827378, 96.27718817803168, 93.86961383204307, 93.43757260230281, 91.64616338668331, 94.52533214322983, 89.74434729545348, 91.4144140674222, 88.49488412180256, 90.02814646690123, 85.92934023949408, 83.85242954377206, 76.55138461820542, 86.26425573902746, 85.44098946356004, 90.25399654142319, 87.75281090890208, 96.40850913140082, 73.39398645585584, 38.16527758875201, 33.68180451854583, 53.03823063450476, 98.14515421467443, 85.0314312596475, 89.0153669541882, 83.09796164112707, 84.50205249171104, 73.07404656564036, 79.17998452340403, 75.4578435036444, 80.29705985899895, 80.937465237033, 85.30547157410653, 84.28558472664126, 83.64034698855492, 85.78648751781833, 88.27046963476366, 86.34050661517729, 87.71112395871071, 85.16874559463994, 85.26086638050695, 82.19844448950984, 83.32565522963002, 82.33631580106675, 83.13407882567375, 82.53859243085309, 87.02087310052688, 83.18179053644981, 86.00944288315313, 82.11211312201716, 81.80693703313028, 78.92550899136451, 77.74056096230784, 76.43860863101098, 75.58289650947818, 81.23782465534826, 82.13845576009443, 82.98634667550364, 76.61482503337245, 82.63734986705165, 72.83668041229248, 82.59105805427798, 88.82164893611785, 7.446565349255839, 1.6688905512132954, 0.031138128232991988, 0.6897692033840764, 0.6389001071933778, 0.34032803329248584, 0.24324681279399704, 0.35646414324160547, 0.4391723438616722, 0.11657241251199477, 0.7126974795133837, 22.87832425486657, 37.810208951273275, 20.968110369097804, 24.077031958487726, 42.90572866316765, 31.463162899017338, 29.96729054758626, 38.77806555840277, 54.14660615305747, 59.64891487552274, 58.66323109596007, 82.35741030785346, 68.43003872902163, 62.90318773638818, 19.041257789058072, 0.5138576120859193, 0.14827734430230435, 0.0429240902585368, 0.0453061448980964, 0.03750076615101388, 0.01047978786030604, 0.06967106954224649, 0.0277733551563635, 0.08254048099080402, 0.03161050570798257, 0.07370923390431751, 0.08906616348653071, 0.028600898653929754, 0.008213547520309446, 0.017028659837500706, 0.034474071505809986, 0.12898014107298467, 0.024341294662125652, 0.05117019938845789, 0.09289903160665305, 0.1474186057044614, 0.16275775438595205, 0.14385893219901671, 0.21728093675788374, 0.25613975080270923, 0.14015212384683473, 0.13017991137120033, 0.25110013332338105, 0.15136685432685962, 0.17121485945197845, 0.1283837722674493, 0.1665461357803114, 0.09142094156554631, 0.19492865149532596, 0.14387644496896576, 0.14169412094258493, 0.24262752263776718, 0.3080913598739332, 0.359864286597698, 10.324443155719388, 99.8267056865077, 98.02293316010507, 94.71709682095437, 75.27697517025855, 74.96446424914946, 78.75824343773627, 61.617960391506074, 57.173240338602376, 65.588744378859, 72.43164077881845, 72.58248729090538, 49.87876146070419, 44.57623866296584, 47.434446273311494, 55.05449364262243, 15.918220570010526, 0.14727277320719537, 0.29420908059804673, 0.1353026034250375, 0.2649203441556423, 0.8674540430788071, 1.6200130384775902, 1.985861329782394, 0.9676758103793668, 11.998266577720644, 75.09546356816446, 99.783873404226, 111.04953242886452, 103.97520834399809, 104.4099638538976, 98.84950991599791, 105.18154897997456, 108.57922369433989, 109.2228767948766, 107.98452961829402, 104.67015820164835, 99.64685716936665, 108.94475721543836, 102.61520493415095, 101.67707597055744, 98.2284261334327, 101.92572286052089, 98.2448059512723, 98.92529010772706, 101.541377652076, 98.73816167154621, 101.79109927146666, 96.95179662396832, 98.51454734802248, 98.95502951837356, 97.45768823931294, 95.84255818397769, 97.59785021505049, 94.47372944124284, 95.21906606612667, 93.36546374905495, 91.46330248924994, 91.2424102906258, 87.44830946768485, 81.22073881087765, 89.87520540914228, 88.8327649331862, 92.59686746904927, 93.09096059491559, 97.5576380760439, 82.533446281187, 43.1224121585969, 37.02686063704952, 67.89423511874291, 98.52800107771351, 89.00008539999686, 89.66347586724066, 86.83569800469184, 86.46943492274131, 75.9428681096723, 81.3853136185677, 78.16456133319487, 82.64265291152462, 82.68372012722878, 84.40452667974657, 87.276227243485, 82.84814588485226, 89.2962557269681, 91.19923283976894, 88.67504642855737, 90.6671319469329, 87.54491744502899, 87.62902090626379, 85.53775433571109, 86.93711480786725, 86.13937531748127, 84.02807328008836, 86.01417326158094, 90.89749274715301, 86.33964369373938, 89.27094074987596, 86.11372301655432, 85.45894607420891, 80.00436475200038, 79.71889465085923, 80.75814231749504, 80.50241162700038, 86.13040877926736, 85.76387113140476, 87.24629171432989, 78.84240965689384, 87.81151310090097, 74.31851263969176, 91.23702095400904, 86.63676323429232, 3.4910668384644294, 6.935580536242455, 11.680801703083901, 1.087962646157511, 0.22385315909501047, 0.1916932783299877, 0.3884964244019601, 1.2417020288205918, 0.39027623051116545, 0.2832466075497289, 3.0202728365698173, 40.28007838033861, 55.10315456698018, 33.31161122168265, 35.039823209085775, 55.96312638252012, 68.61274273164811, 51.989282946432795, 42.041963915671076, 49.79019041984312, 62.10210246424522, 68.30292255647721, 88.0765711876654, 77.30873154055688, 73.89415925548923, 21.575812985820157, 0.6746238902691872, 0.41608518109686915, 0.15400910689946146, 0.12846881568792368, 0.14674247182424993, 0.1854872919859425, 0.15717783041538733, 0.1841572407753237, 0.18678014196695822, 0.15903297361106644, 0.21670468542123997, 0.16122533338925532, 0.12807353730163268, 0.14824144542217255, 0.09899978045253985, 0.11854175643454637, 0.30140142046636154, 0.18891132196351407, 0.23622577018555135, 0.14614677717608793], [0.03518776667694892, 0.025601296708168044, 0.024801196395269325, 0.016570326669381994, 0.04449262847042373, 0.0318325448015164, 0.06060500884608877, 0.021099382936353647, 0.0783459657442666, 0.07781939520951241, 0.05548311735413248, 0.05140369915733895, 0.03622070600789401, 0.02885097656549225, 0.128525935203558, 0.01804593458561407, 0.021319941564973806, 0.05005293675968724, 0.06956006340201824, 19.032501097648375, 66.9301792883104, 65.83429259638633, 56.194918847853145, 52.40231244794784, 51.37780897078976, 37.542805287145804, 41.153696121708045, 45.58264824651903, 52.28533167992869, 43.16913543208953, 34.21412506411153, 21.04893865123872, 33.75738466939619, 29.97184834172649, 12.441851342878035, 0.3340278487772711, 0.4211087260515459, 0.020855502676098578, 0.21859103903895427, 0.387246536631738, 1.2780038099135123, 0.8503447869612325, 0.4810979764067358, 3.812241049543504, 57.2481458417831, 84.20593707792221, 99.69419233260616, 98.74388833199778, 96.06476045423939, 93.80222751248269, 100.97934907482517, 99.50630295661189, 99.62644515498992, 94.53427514722271, 95.51090609642768, 93.88840198516847, 97.88136697584584, 93.48521371041575, 89.50589856793805, 88.01631573707827, 94.16185394410165, 93.42638600257136, 92.46279301181917, 85.18364275655439, 89.08527928013956, 88.5771832927581, 92.5546706107355, 89.68108730931436, 92.77209543412732, 85.31253968515705, 89.04116046044135, 87.03272650318762, 87.48229288285779, 82.91342196925994, 84.85478339656707, 80.73005030232092, 82.54656268704323, 75.38526396597587, 79.52680049404022, 73.83781833033409, 84.68249720911827, 81.45101331895398, 90.56780968942951, 77.42620652721774, 94.65504492482832, 48.300689958756976, 47.205811315967196, 57.33734053950156, 21.70649067048104, 91.62915598961615, 78.37245479706796, 87.48888246474728, 76.51893092739967, 87.48033169777163, 73.28841194029778, 78.40579494353264, 70.46001434326172, 77.91124682272635, 74.0987971521193, 79.2175216059531, 79.11141364805161, 84.80540860083796, 80.62044359022572, 81.08507187135758, 79.26951654495733, 83.85837585695329, 80.85219290948685, 84.15996689950266, 78.72577405744984, 78.36373144580473, 76.69318614467498, 78.28919856779038, 76.1945430694088, 77.29144957757767, 82.17961711268272, 83.5272885907081, 83.71910033687469, 82.06256574200046, 78.93569146433185, 75.49916175103958, 71.72129169587167, 74.08210354466593, 71.95226438583867, 75.15709969305223, 75.64681545380624, 79.0414228746968, 73.50431488406274, 80.11494421189832, 71.67738468416276, 76.24373743610998, 72.72727766344624, 4.755667909499138, 1.9389997927411913, 4.2548895939703915, 1.0613740019259914, 0.12007934086385275, 0.04477995740730436, 0.27827255187496064, 0.4085359055428736, 0.06142053625456268, 0.2406166797323573, 2.4478649323986423, 29.488396606137677, 34.70620993644961, 23.260131689809985, 25.52835402950164, 36.828074916716545, 36.42010135035361, 30.948161578947502, 25.712195519478094, 45.54161633214643, 49.43291348795737, 48.64307365109844, 60.05739835000808, 55.58109145010672, 47.951779442448775, 19.73019269204909, 0.30153468912166936, 0.051183134783059366, 0.059559743160442005, 0.081321926216685, 0.04858802343087812, 0.03284348783293559, 0.09550753034531109, 0.03974660652719679, 0.061751666268514055, 0.026617186752358274, 0.03548830296964415, 0.04652471116353427, 0.11181252437733835, 0.027065313714105758, 0.027233805176952196, 0.05686101458606221, 0.049078208619668606, 0.02863393811088416, 0.008744475180132976, 0.020317647666219744, 0.011443316752481605, 0.01855471272832684, 0.04415841878301675, 0.04603850580151043, 0.043658676647370866, 0.0311485106395858, 0.018052883003087297, 0.1112810355581103, 0.08467414311223453, 0.012612575683892976, 0.029369305909400987, 0.05748632236293728, 0.031155460972278833, 0.06504811196317596, 0.03828634335208805, 0.0771729089319706, 0.10494038627873506, 0.2533197658316743, 36.95709343879454, 91.69601671157345, 82.25643281013735, 76.01921312270626, 67.70625945060485, 71.64442892997496, 54.75960593069754, 40.44504934741605, 43.684652543837025, 40.5756328951928, 34.901689098727324, 46.27756672520792, 21.957371350257628, 29.458415969725582, 31.527701577832623, 7.264164840021442, 0.12654473223993856, 0.41495051295045887, 0.08214316481063444, 0.6442439688309547, 1.2304698315358933, 1.8265965532871986, 1.0265809850346659, 0.2520004092084785, 7.8377477392073605, 71.035551563386, 90.53097863351145, 107.95937153600879, 99.85997523030927, 102.8183287958945, 97.73361913619503, 105.19377893017185, 103.77745028465026, 103.38266372680665, 100.58091471272131, 98.93315053755238, 96.2189958941552, 102.60149232802853, 95.77143776801326, 92.91654063809304, 93.27774386252128, 99.31114935105848, 99.14768849649738, 96.92439494594451, 92.27667654714277, 93.79009169916954, 92.88889577311855, 94.5922399336292, 93.48165219829929, 96.00778410511633, 89.4535819945797, 94.47188592726185, 89.54365530321675, 92.66312414600004, 86.08980440324353, 88.82284133665024, 86.1359707001717, 85.65068721771242, 78.72534259673088, 82.81056957860147, 75.81551659491755, 87.61440615500175, 88.1845618832496, 94.20569035314745, 79.16434995589718, 95.61203264421033, 48.09756609701341, 54.44623993289087, 69.0712756495322, 22.833864188963368, 86.67906207423057, 85.68034033621512, 88.1539438616845, 84.06469252801712, 89.77592237534063, 78.28943391000071, 79.6096174178585, 75.08312379160236, 84.0894897522465, 78.8914785077495, 81.16348005110218, 83.28924778969058, 87.95280471924814, 83.69517387882357, 84.70862803920623, 83.68790180452409, 85.43950680763491, 85.7306408113049, 86.69076642682477, 83.45051996169552, 82.42966036642753, 81.18027564018004, 81.71980550212245, 79.4040616866081, 81.90032082219278, 85.59476206379553, 88.01821416424167, 86.43388255949944, 85.05399273287865, 84.2059527674029, 81.52517749417214, 75.74361170491865, 77.72045489280455, 74.01198725546561, 77.45666765397596, 80.91229146526706, 83.81263317600374, 77.72499699746409, 83.63925656964703, 79.44586630790465, 78.39041925245716, 87.22758200860794, 14.812750547162949, 0.699891860206281, 1.0996075503287779, 0.270512540854754, 0.6389740806433463, 0.12047821986338786, 0.9526839599974695, 0.5434154598943649, 0.12764960722697358, 0.23382983020236417, 1.505291678251759, 26.82952973150438, 36.463682805338216, 21.071443250102384, 28.802587832173995, 39.57276128953503, 22.18975805467175, 25.832720148947935, 30.20226601631411, 62.129410005384884, 64.91865450336088, 70.50319963885893, 78.53771994190832, 66.74811070965183, 66.96468830108643, 35.53606187143634, 0.4118634544072613, 0.04557162117693694, 0.08391524875356306, 0.09402833713759338, 0.10004013551459198, 0.03906917795839329, 0.06538177389771709, 0.025369327199915727, 0.04551732469530356, 0.01603571508425258, 0.04164263583539475, 0.09667828889383424, 0.08458051950700822, 0.02254652111009965, 0.07931491375089654, 0.04697144001481995, 0.021421277760377815, 0.08299217409183902, 0.012717424392429812, 0.08263331552546832, 0.1581947661695942, 0.10495671927328072, 0.12607352687947213, 0.1040143162132271, 0.13463584646101923, 0.1676589704208797, 0.15155106782913208, 0.1512633864918063, 0.21111896982596767, 0.129894926663368, 0.13636266992938134, 0.12240902190246891, 0.0852839490999618, 0.20591616029700927, 0.20541553716025046, 0.20897891853124867, 0.1775795485704176, 0.31896306682498227, 46.121487771311116, 113.20642025240006, 94.29098621491464, 88.48437216974075, 77.48119815703362, 78.77365835251348, 53.23061112434634, 65.31544539236253, 65.73072241198632, 78.28130675900367, 60.90259067473873, 53.97717545109411, 35.125142605074, 49.441017104733376, 45.75049823330295, 21.20493131299173, 0.470508128524788, 0.5087613807089868, 0.18614114802931586, 0.5306459386502543, 1.0797063020929214, 5.571887646951984, 4.552380288800886, 0.785999468738033, 5.0363237915500525, 68.53995923073062, 93.22538022072085, 109.35770434717979, 105.45151787419474, 105.3647707354638, 102.4530541512274, 110.13265486686461, 109.08308352193525, 107.6715950812063, 101.96378554067304, 102.43490142206993, 98.50791854243126, 107.44384657952094, 100.35948122701338, 95.81841207319691, 95.76240062713624, 103.32805648926767, 102.07159580722933, 100.6538551084457, 97.29212499433949, 98.88612131918632, 95.87290948437106, 98.90242268962245, 96.35819296683036, 98.53011131286623, 91.25029425467216, 97.4846584566178, 94.9548081428774, 95.2377365481469, 91.06595854605399, 91.73341258879631, 91.39259784452378, 91.30512114494078, 83.96375425400274, 88.25136769202449, 80.5970976429601, 92.4053773572368, 90.05212783813478, 98.40981221968129, 85.44226031149589, 99.3317182602421, 56.456890029291955, 53.223884259500814, 62.588684251231534, 28.624816210039203, 93.10208443672427, 87.41878970976799, 95.30230660592356, 86.14277209005049, 93.29543375199842, 80.6336384434854, 83.57412169056555, 79.08210569812407, 87.49672720509191, 83.15401231088947, 85.43188956476028, 87.98050449740502, 94.52592834349602, 85.25055839169411, 87.6135196993428, 86.70404757222822, 87.75404253313619, 88.14589515809091, 88.43618977454402, 82.84355671175065, 86.59742186146399, 87.96945125825944, 85.9717724400182, 82.49243397866526, 84.8071030647524, 89.64956714260964, 89.36869405931043, 90.84473686833536, 87.51709215102657, 86.20997013584261, 83.61032516725602, 77.83976554870605, 79.79406295284149, 79.9024066617412, 82.99914929174608, 85.29223749714514, 87.67666201437675, 80.57847422938194, 91.2394920472176, 81.33856681085403, 85.08905087747883, 89.98904043628325, 8.521573755048937, 4.0147495894662795, 12.631514610782748, 2.0937236903175234, 0.4854043098467012, 0.21187270841290876, 0.6533282394370725, 0.6320663577606601, 0.4026461296504544, 0.4921713176994555, 5.158138880806585, 48.68207770009195, 53.887816013828406, 36.64838721675258, 38.64770558572585, 55.86755391090147, 55.096408090283795, 46.91497541243031, 39.67226397606635, 69.33290558476602, 69.55553147100633, 71.32903898915937, 81.46389438259988, 79.86541086627592, 79.21522309703212, 36.17853826092136, 0.4791330221679903, 0.20096358572763784, 0.21365525711688305, 0.23392494767904284, 0.23760561711124836, 0.15868258031625904, 0.17432747468833001, 0.14363146537253935, 0.11541853088044352, 0.1034715122753574, 0.17091017096273362, 0.1571977793449356, 0.18002081031520523, 0.10587498290284027, 0.19921151200129142, 0.1740669588287992, 0.08262879560671507, 0.1298567908064973, 0.07179481848593681], [0.056022056378424175, 0.022118381382296645, 0.034210843695027214, 0.09580608247028244, 0.07214534967657059, 0.06248341047114903, 0.09946892503648998, 0.016900263501391295, 0.01382462924436456, 0.021439432128963452, 0.06338348334294654, 0.08160095842134568, 0.0472786910681715, 0.021093231250321674, 0.030425727750445088, 0.08954810173881632, 0.09044895218985696, 0.030391684718309876, 0.26400208052608276, 33.70975925076392, 71.87438180369716, 64.47222209745838, 60.267994326929895, 53.232133003973196, 63.4904214643663, 40.71582624989171, 48.72170932831303, 46.07893789968183, 48.889680908572295, 60.26102819750386, 28.428068161010746, 33.38544591780632, 42.43453433436733, 13.294826630623112, 0.11023409213990935, 0.13014297061149152, 0.1159909900818621, 0.27567079471003625, 0.08953834943954023, 2.3447431239389607, 0.8752161685016848, 0.2223553959160082, 2.6484056682355943, 49.41095605973275, 85.2340373685283, 100.6793583593061, 102.32926414858912, 94.2774461930798, 97.98234447356194, 95.97176890219413, 102.13917040055799, 92.92195350893083, 93.63788804700299, 96.59976390100296, 96.01792735438194, 90.64953619433989, 90.95045258921962, 89.83613860222601, 92.98881423088812, 94.18473705168694, 95.49596186607116, 93.64461098947834, 87.65523802849555, 87.43825251056303, 94.17052238218247, 88.51903023258333, 89.35876261803412, 90.27856626818257, 91.02980998254593, 88.00810229393744, 89.38359122122489, 85.33772914640366, 84.84520496860628, 83.45148486475792, 83.31204460513207, 79.586593104947, 77.27415976985809, 72.86383105862525, 71.55575198511924, 71.66056556086387, 80.00592585532897, 83.76787893233761, 82.97889417217624, 79.86104919064431, 84.79284917154621, 43.257612336066465, 62.167331480210834, 82.24804678270894, 29.170600291221376, 59.11254252156904, 88.18919028005293, 75.01453722676924, 83.71763337043025, 77.59464879189768, 77.96285736945369, 73.11525498667072, 73.91444575402045, 73.85705363365912, 73.41053885798301, 72.91720667193013, 77.37365461164906, 79.62649929908015, 81.56583678337836, 80.84140639151298, 80.42066943260932, 78.1791368607552, 81.15041855842837, 82.46966854218515, 82.8246351980394, 75.15391472847232, 77.4107131650371, 76.63009089808311, 74.27246401386877, 79.87597773152014, 81.14472327693817, 83.35170761231454, 81.80663893299719, 77.84547651967695, 78.43995094299316, 78.33931861385223, 74.45130055950534, 73.01193191159156, 72.1530112912578, 70.60009002685547, 73.09457625112226, 75.17296960276943, 77.68025059853831, 71.8690787592242, 78.38328053874355, 77.17917565376528, 72.25547144489904, 86.86317028537874, 13.36955366596099, 2.3908601460918306, 5.289626534908049, 2.0882389910759467, 0.08678197274885832, 0.1017592061731604, 0.5573753591987395, 0.08414929627530998, 0.17949590219124673, 0.23440018266199097, 5.69377726124179, 30.982507813361387, 29.688612030398463, 17.494884921658425, 24.95582526729953, 42.61289235084288, 43.26992465603737, 45.50833109886416, 28.095202099892404, 30.43504495774546, 37.26426209172895, 38.511920975100615, 49.89738487428235, 56.7940491245639, 59.349787081441576, 8.235912438361876, 0.36244263211565636, 0.0350065715610981, 0.09023680712186521, 0.046316821713961905, 0.09829346270811173, 0.07685172656971602, 0.08897059401797672, 0.0053981380094023, 0.05596353492188839, 0.041422837549039436, 0.06467594644956051, 0.034498318188613465, 0.021044561684492136, 0.06491583156129045, 0.05768565844083506, 0.04031116353167642, 0.060374029506478584, 0.02306244685314596, 0.02987524761157411, 0.05181007049677353, 0.046856691535081596, 0.022747829864402453, 0.07273451725561773, 0.0226463251296551, 0.12515221421997394, 0.10019761254830707, 0.009831725356860027, 0.03758906927560607, 0.06794783136536998, 0.01882129408899815, 0.09372243822942819, 0.09271129409992888, 0.015523209923788186, 0.15011269178602005, 0.004710190095788529, 0.046051843392272154, 0.23046238347887996, 53.47579848381781, 89.24186814215876, 76.15863769285141, 74.3637611019996, 65.00880233703121, 81.22306869876, 51.19705046376875, 54.61025384164626, 32.38669672319966, 43.5731081808767, 59.23652472034578, 27.323246309834143, 27.44591255341807, 39.079087857277166, 10.594592478967483, 0.17053975212958553, 0.16695412356526623, 0.0268683793218506, 0.4096611967730907, 1.1314363585364435, 1.2073024746871766, 0.7904113384504473, 0.14697712455545703, 6.197978335042154, 65.64894099389353, 93.18232044096916, 110.63900147714924, 104.08228120496197, 101.34067781509893, 101.27758256850704, 102.40669173579063, 103.11637401580812, 97.94301094547396, 96.78090680030085, 100.51748998703496, 100.14436275728288, 95.33924748820644, 94.96756369067778, 94.75849351575299, 96.40276678146856, 96.79825936594318, 96.45462051514657, 97.09069559651037, 93.25685331898352, 94.1242854825912, 96.58852238808909, 92.06184048806468, 93.50189947312879, 94.24940909108808, 93.4410870459772, 90.62495862284015, 92.17281218497985, 89.97419034281086, 85.84570746267997, 88.62211796545213, 85.28685600526872, 84.0800525296119, 82.03281848661362, 80.65095178542599, 74.55369795522383, 78.20811533158826, 81.66655540466309, 87.44572854811146, 84.91994965460994, 87.88594399729084, 84.06217436636649, 47.377909229647734, 64.06987713229272, 80.0006934135191, 39.06741488364435, 54.120102697803134, 92.62142150632798, 77.72686404566612, 87.22984129382719, 81.20460217998874, 83.82396882580173, 75.51708698272705, 78.45507560237762, 73.70881942010695, 77.28320475547545, 74.92949239669308, 80.95059733236991, 81.26153930541008, 85.0659167382025, 83.89213177465624, 85.04301794113653, 81.11388560264342, 84.56932114016625, 85.17530379756805, 85.5615552779167, 77.28911184495496, 78.5994109799785, 79.86894884417134, 79.04136011677404, 85.881377497027, 85.0213429235643, 85.60161836685674, 83.36723235345657, 81.74097845631262, 81.30048059648084, 79.29602392258184, 79.10320020491078, 75.37879989993188, 78.58213686173963, 74.12120173054358, 76.24230969336726, 78.48559948705858, 81.93197434948337, 75.12516375510924, 82.43974870251071, 85.22093665215277, 77.35001056425034, 96.85853835075133, 26.456565280114454, 0.7122132506582045, 0.5627596089916845, 0.8468760021271244, 1.3033461210227784, 1.1897781827757437, 0.6068194705632426, 0.08766541002138008, 0.13714397235983802, 0.11861035194728645, 4.186141231367666, 31.511870891817157, 25.645395594258463, 14.235779700740693, 32.93583639206425, 40.157688663851836, 18.443827859817013, 39.05196074516543, 36.106872635502974, 47.746757153541814, 58.214653153573316, 55.604492310554754, 73.1961577938449, 68.09145189100697, 76.51262375616258, 19.168964278313425, 0.18839816562831405, 0.08629114021577182, 0.03744318315218534, 0.04910781791794205, 0.059451920115539146, 0.08489627030587966, 0.05606245219467148, 0.010950252030705734, 0.030962123362828168, 0.07162561264610098, 0.04259876336061186, 0.0928889115851733, 0.062487229419451576, 0.03655591544004218, 0.04280198350428574, 0.008568646510191744, 0.01837621041152987, 0.011267898897189769, 0.1964806690211258, 0.14613910097508662, 0.14715718586117993, 0.20156660417635597, 0.12056932303934328, 0.17284918546436295, 0.2544943011936642, 0.17916997774474083, 0.10482315950456167, 0.15235605769820754, 0.13468487608817317, 0.1489820992273669, 0.20943794309371905, 0.17459585060996397, 0.13622509585993905, 0.2553447660419249, 0.18203010572300804, 0.15651375475910403, 0.40853746836223914, 71.34336348502868, 106.32578280664261, 92.67378514812839, 88.0599795618365, 74.06616303228563, 89.06350228094286, 63.10836299773186, 76.91894208231281, 68.68172937823881, 70.40172792250111, 89.46172483505742, 46.579706899581424, 48.00466475948211, 61.132049329819225, 24.348150107168383, 0.47693398210310173, 0.3638997313476378, 0.2866984771624688, 0.517718542006708, 0.4840903158389753, 7.401804731738183, 4.140563780261624, 0.332335039612747, 3.9702770210081533, 59.867500720485566, 94.49374921860235, 114.30195393100863, 112.19140498868882, 104.57561339101484, 105.92621095718877, 102.481475645496, 110.27862979519753, 102.14830167831914, 101.61572225632207, 103.24955417263894, 106.38919968758862, 98.88166550667056, 97.5049606446297, 98.83208674769249, 101.22995714987479, 101.71469150050994, 103.53324351772186, 102.76429422440069, 99.88232489555114, 97.25897312164308, 99.91615141591718, 95.01896242941581, 96.18562436872914, 95.33916119606265, 97.26316221298711, 94.08572858379733, 97.15416739063879, 91.22859570287889, 90.47323349983462, 90.0275424218947, 90.01257465731713, 85.41256796929144, 85.08964707774501, 81.87632376147856, 79.66638195899226, 80.5788350874378, 88.48618430476036, 89.56606772638138, 90.1127363020374, 89.89909264349168, 94.86569189256238, 51.37706764282719, 64.15585156409972, 83.24031229942076, 37.803097694150864, 64.23446370709327, 93.38058056369906, 82.29259706312611, 89.70316240864416, 86.17702222639515, 85.97004659714239, 80.82697991401919, 81.87269949143933, 78.45974322288268, 81.13814153978902, 80.43418592022311, 83.52577455582158, 86.16449417606478, 86.10106160563808, 88.78455900376844, 87.78191489558067, 84.6787944916756, 86.84738666780534, 89.8939621833063, 88.05695149206346, 76.86920642852783, 79.76200149905297, 79.541454469004, 81.28297113603162, 88.71193239765783, 87.8580951690674, 91.37666517688383, 87.7611812468498, 84.74503547914567, 84.47190515456661, 82.85023258578393, 83.38664024106919, 79.20143988824661, 79.38636395239061, 78.72038472083308, 80.41613517269012, 81.98281611165693, 86.55342855761128, 77.65494346618652, 87.43979792441093, 87.00049246511152, 79.67273619867142, 98.48712998051798, 17.98196484965663, 5.425641094484638, 10.93003063432632, 2.610727135212191, 0.3325101366687206, 0.426118144344899, 1.1227490440491708, 0.35718337722843696, 0.6110836998108895, 0.3290233640901504, 10.299875390145088, 47.437866580101755, 43.50587875612321, 29.007563052638886, 40.08730173110962, 62.6423305080783, 66.78675390058949, 72.63645125973609, 46.746384097683816, 49.832375511046386, 56.36855433064123, 57.82015685112246, 72.405407967106, 78.00063763895344, 91.72075902262043, 21.068758387719434, 0.35094300885835006, 0.11584071427463524, 0.24861335063413267, 0.29494869252366407, 0.17289444593892944, 0.16905816872754406, 0.19564227771855172, 0.05485243547046858, 0.1423235387811738, 0.16359963904946082, 0.2166342666192401, 0.26366656465876487, 0.2131999250982077, 0.23116479417489422, 0.10722349683243422, 0.0858393551841859, 0.13131637216335343, 0.0923595984556502], [0.04157800482766282, 0.06523374272810836, 0.0659957780472694, 0.05386342362110173, 0.027598141271981503, 0.008755365119976623, 0.051916575870446624, 0.009215807902716823, 0.044335082488795446, 0.10406405830215062, 0.008571911002359083, 0.009356719242679256, 0.032638494195717, 0.019249175262126713, 0.009060473999969903, 0.07708147633820772, 0.05760324270194096, 0.09315508117358531, 0.37863147955748344, 44.38729809176537, 73.08135786364156, 58.85519189219321, 64.28102616340884, 44.392338337436804, 38.07780088916902, 42.72240884842412, 35.61842380031463, 54.314197263410016, 37.6627984354573, 32.90402596996677, 37.4016313399038, 45.69361994343419, 20.08480437340275, 0.637887400244513, 0.15071566426946273, 0.2258630826949112, 0.06312639572687688, 0.44181589878374533, 0.7608478828783959, 2.0884731075456067, 0.19526428993671172, 1.2834387440835278, 46.85774410924604, 95.76500508093065, 103.97611048913772, 102.26934602183681, 93.41478363160165, 97.88635623070502, 97.68917083740236, 101.20166901619204, 95.12397996840939, 93.0228368697628, 95.33920041976437, 93.22703546093356, 86.62312907557335, 91.96188280659338, 92.59429439421623, 95.49996268364691, 93.34760127529022, 89.98843639127671, 89.44016748859038, 88.84656383145241, 90.88035983424034, 94.23164859894784, 91.20656767199117, 88.96482329214774, 89.94014416971515, 89.26252334348618, 86.79972202547135, 91.25517368316652, 87.1659694179412, 89.18981828997212, 86.76536206276187, 87.85676940794914, 82.32822787377143, 83.27628827864125, 79.21007694736605, 77.85743190396217, 72.2781898129371, 72.29211422704881, 71.05470841930759, 83.0052838786956, 74.95607822172104, 86.25047253024194, 67.50140190124512, 53.80849392183366, 73.18479076508554, 70.05973646717688, 59.583140650103175, 37.09188176739601, 88.80060934251355, 71.06576950319352, 79.61362608017461, 76.18084615276706, 80.77565962268461, 72.8165586533085, 72.51353986801641, 67.74821312196794, 70.2005809353244, 70.88770174211072, 76.52247675003545, 73.99750586478942, 77.43990344385948, 75.56511248311689, 79.08338439080023, 75.688078788019, 77.80867684272029, 80.30506933889082, 85.35843141617315, 80.00496095226657, 75.0889681231591, 76.27773654076361, 77.87863623711371, 81.346646893409, 83.2098747068836, 76.01959751498315, 79.12690701023226, 76.43012846669843, 77.01806037656723, 73.87908166454685, 74.92551511333835, 71.59557973184894, 73.31378967531266, 72.32345396472563, 68.55391502380371, 72.90913443411551, 75.14162202035227, 79.09248428960001, 74.08215845784834, 73.62636335434453, 83.17540491780927, 72.36074786032401, 87.36323325864731, 10.048702493790659, 0.4148223617624852, 0.502465486286148, 0.9352446732021148, 0.5596885157208289, 0.7051942305218789, 0.16318737649388854, 0.19772885607615595, 0.08348981714657239, 0.11413231522085206, 11.722156232403172, 29.016496250706336, 26.567166313048332, 16.372324151377526, 28.027207812955304, 40.58874930104902, 26.589653261246223, 41.23881939918765, 28.101499465204057, 33.09799501972814, 46.07334067744594, 44.07512841686126, 54.89832447421167, 59.63880300521851, 48.05738141459804, 8.099601249541006, 0.10122559529038207, 0.049475605239070235, 0.045482620912333654, 0.056903026847829746, 0.027306123877004273, 0.10254344272036707, 0.02594460368967585, 0.0924887991840801, 0.09354659040728885, 0.08170577457114574, 0.0680531224896831, 0.05304654406744146, 0.036759599066910245, 0.012159837830451228, 0.0341209241249148, 0.044357954043774836, 0.033715096707906456, 0.0328317666876941, 0.04720186011024541, 0.029692778874549176, 0.020152191826773268, 0.05475675874960519, 0.05471098499612943, 0.005456497629864081, 0.028022008144386837, 0.01583549130197254, 0.0658435640375941, 0.16240886262347623, 0.039096274488275094, 0.019199057790120284, 0.021337396878328536, 0.025576774233711824, 0.019734846277823372, 0.06936122528127125, 0.08116529187968663, 0.06309627314969417, 62.13861580817931, 83.76461552035424, 71.15898070796844, 70.46199906256892, 59.98049636040965, 43.8826734019864, 34.2235505196356, 35.085922825721006, 30.163120761994396, 30.670591131333385, 39.70857727912165, 27.884329595873435, 40.6508521879873, 17.84158714355961, 0.22638186211547545, 0.1570672379626382, 0.17852523814766638, 0.16825408284221927, 1.240123887696574, 1.9806735049332342, 0.4209413818053661, 0.3918434625431415, 3.129703287155398, 61.61179050322502, 103.84879819808468, 112.94896371902959, 103.07205907760128, 99.82397571686776, 100.8774458977484, 101.35446886862479, 102.08952888365715, 97.74859474551295, 97.15687382605769, 98.45142072246921, 95.9528160095215, 92.32287422303231, 96.04308543666717, 97.26837112057595, 95.17974822751938, 96.84684968763783, 96.50035535135578, 94.86275011493315, 93.24660024335309, 97.03893599971649, 94.58561112803798, 93.71266411196802, 93.44982608672112, 93.98424117795884, 94.3040398628481, 90.60449954002135, 94.39848269185713, 92.2402455729823, 93.52551998630648, 91.3360058876776, 91.548049219193, 86.56396404389413, 86.9510627562, 80.71858913667741, 80.8966725872409, 75.31975253935784, 73.3203871019425, 74.34975824048443, 83.32359990765973, 79.50735338272588, 90.5494608417634, 74.90001186247795, 59.90511232806791, 77.53002382093861, 69.45773893787016, 65.18708975084367, 39.25757138959823, 88.61489295959474, 76.42746125498127, 80.8139576450471, 79.45466026183098, 81.62402906725484, 76.90292312252906, 77.2089542881135, 72.76508146716704, 73.58527260441934, 72.55653688984533, 76.8967571566182, 78.65117842151274, 80.81915086315524, 79.10208625178184, 81.70876795245756, 78.13311961389358, 80.09486167661606, 82.49125726761358, 87.42377896462718, 82.46453808199975, 80.95575917151668, 78.3019619603311, 83.02283256284653, 82.77869639858123, 85.12041414937666, 80.34193177377024, 82.01251629860171, 78.62918961432673, 80.14316174291795, 77.89142316387546, 76.21970899643438, 75.45933400430988, 75.49505110709899, 75.94713564841979, 74.00187538516137, 77.24198064496441, 77.60962440121558, 83.87801124203591, 80.9373789448892, 76.21126805582355, 88.34643810026108, 74.24039471533992, 94.33896464686241, 20.68364243353567, 0.3839009080923373, 0.9862780799308132, 3.7322460259160692, 2.5668919519070656, 1.779403821114571, 0.24401699162779317, 0.2257582971886281, 0.2011099391646924, 0.13958774687301728, 9.38130336423074, 28.947350748123664, 20.109162292172833, 14.682448429446067, 33.74112644503194, 34.405481815338135, 14.195879390162808, 39.096205080709154, 37.65922515623031, 42.369446523727916, 58.38398971865254, 63.98726809409357, 74.66732117437547, 67.85213239731328, 66.70305052111226, 14.658870081747732, 0.028528535903822032, 0.019368575810785257, 0.03848577519097636, 0.015281942023354915, 0.024453886604357152, 0.04797118092556635, 0.01543659889589875, 0.02968620967059847, 0.026028955715798566, 0.023861401864597877, 0.1510381872855848, 0.07751673685326692, 0.05746720080834724, 0.036642326327461394, 0.03764868240743395, 0.09887364407580707, 0.03755722300059373, 0.14679203771295088, 0.21055512911369725, 0.11160071638803329, 0.14006275202958815, 0.10538557529329293, 0.13863841071724892, 0.20439898445000573, 0.12814674466367693, 0.16203127320735686, 0.29175171568509073, 0.21844344453946238, 0.12520465293839095, 0.12144662394759156, 0.16792670282865726, 0.12410465027055434, 0.14376882493736284, 0.10951553997133048, 0.24721194599424642, 1.1015693482852753, 82.97203002437469, 101.96561336517335, 87.87689901167347, 88.32703021264847, 69.89949195615708, 60.903006445977, 67.27792878304759, 54.69622042871291, 81.6047388507474, 54.989029284446474, 59.177532272954146, 53.546656100980705, 61.02009704036098, 35.49222154002036, 1.5825137087414343, 0.21441141654166485, 0.28788910037086857, 0.1797965763797683, 0.7536675552687337, 2.342574788678077, 8.305633548767336, 0.547239832099407, 2.0793180504152855, 56.77233488328996, 106.81989946672994, 114.50163395174089, 112.35361852953511, 101.84111733590404, 106.1830791350334, 105.6018074097172, 109.9388191776891, 103.32094915451543, 100.62948150019493, 102.92082817323747, 101.7852000267275, 94.29694821757656, 99.0989883484379, 100.23598147976784, 100.59615704321094, 102.2605206889491, 99.92958945612754, 96.99014955951323, 97.76937546268587, 101.00216157974737, 97.44398347793087, 98.09533226874568, 98.26786948788552, 97.31310183002104, 97.90025711059572, 93.32770701377623, 98.55474379754837, 95.78621725882255, 95.91669098023446, 92.43851354045253, 94.55060789662024, 91.30467399474114, 90.45706548998433, 86.63920294853949, 86.91104673570203, 77.92676371912803, 79.63110416166245, 79.95308368436753, 92.64549701444565, 84.0123837993991, 93.6769470091789, 79.55350399017334, 58.79211233508203, 76.57794690901234, 71.65646276166363, 62.16040457448652, 46.20921550258514, 96.0604223128288, 80.10120807155486, 83.88966852618803, 82.51669776055121, 86.26632675047844, 80.33392229387837, 80.05515160099154, 76.80765659578385, 79.65363425593223, 78.54503908464986, 82.00350269194573, 81.27475769289079, 84.10899962148359, 81.6742903186429, 83.53860855102539, 79.98644736505325, 82.98142017856722, 86.26985688363352, 92.48512698758034, 86.78090249338459, 83.79974426761751, 84.01192095971878, 87.45835858006632, 85.67895966191446, 92.12514754264586, 83.0311401428715, 85.00810884660291, 83.01663521797427, 85.37066136637043, 83.34924436384632, 81.39546471257364, 78.25111235341718, 80.60866863496842, 79.44605458167293, 77.607129773786, 81.98657374228202, 80.96049739468484, 88.28377431438815, 81.82108109997165, 81.91056605308287, 93.97608264800041, 78.90221011254096, 96.72214969511955, 13.62137375339385, 0.9456863903230237, 5.81619345372723, 2.2250524884270084, 0.6544803131011225, 1.563671868174307, 0.5029915741855099, 0.38445429936532055, 0.23612221041994713, 0.3879686817526818, 20.912846134554957, 44.141745951867875, 39.19407606124878, 26.781680737772298, 43.271124901310095, 59.78649985405707, 42.06898512378816, 66.09352204107469, 41.97567585975894, 45.99118663418678, 64.97561908537342, 66.65741766652754, 79.05737123181744, 78.3574007403466, 79.03346830798735, 13.401623945082388, 0.24308006609639815, 0.14399039288682325, 0.14617516839456174, 0.11633562239547891, 0.18278669415702745, 0.1614731015457261, 0.11443757061516086, 0.13677686302652284, 0.14207262966421344, 0.18335303231593103, 0.23023082574288692, 0.18792374269856563, 0.12301157303755322, 0.2220622906761785, 0.1351527719488067, 0.18056405858407099, 0.12638034509314647], [0.025747864649841384, 0.030490485162684516, 0.036860385594228585, 0.031677547977456165, 0.023971860251960256, 0.02296714934580509, 0.05559849402596874, 0.08491554507805456, 0.057678254201046886, 0.06449125031189573, 0.023083301681664684, 0.0817958435284034, 0.013442198152563745, 0.027462511150647077, 0.03199807150409587, 0.022288818708470753, 0.07768119294797221, 0.04772543141077604, 0.18192519764265708, 46.44149041944935, 62.24612797460249, 60.02859638583276, 49.37501145947365, 57.90325618559315, 49.29705042992869, 57.367625159602014, 35.93557096296741, 42.40304554662397, 40.56012384353146, 29.5343981635186, 42.61521439398489, 29.661312333999145, 4.194288974808109, 0.07300441769222099, 0.1572278866003598, 0.08614894663614613, 0.19470761980741255, 0.6630737971394294, 4.008308812495201, 0.10010473970924655, 0.12340154243452896, 32.70481271128501, 98.3150791352795, 100.44674611860707, 101.29586865825038, 91.99468951071464, 99.66659453607376, 95.04306147175451, 99.00355708214545, 93.44624104038363, 93.26017948888963, 90.57405410274383, 89.20306021167387, 86.78899826542025, 88.55584559902069, 89.13356365696077, 89.38579559326173, 90.97732866964033, 95.24505569088845, 93.96475484294277, 96.713897028277, 88.58549087278305, 94.35243406603414, 91.32360335319274, 92.48570749836584, 90.08149070124473, 87.55473121520012, 88.29805958655574, 89.68347211037913, 88.17722705102737, 88.53286835455125, 89.70868510584678, 88.88701131266933, 85.36921008940666, 86.04595230471703, 81.39875165877804, 79.66419327643611, 72.72557535479146, 70.20011025090372, 65.98513910847326, 68.45693834366338, 72.5788865550872, 72.74859182296261, 80.26797156180106, 79.5317191462363, 68.8700423702117, 73.78543115431263, 66.84054528513263, 75.92478598317793, 43.58344754865093, 69.357420398343, 80.70388809327157, 75.21824944403865, 77.41931100045481, 72.04445577436879, 72.68360599394768, 70.41085920026227, 69.84057795616889, 67.59791574170514, 70.4357897850775, 70.53034244045135, 74.53151302952921, 75.87723901194911, 76.2714058353055, 76.69231537849673, 77.76705265045166, 77.56622729762908, 79.5436353068198, 80.04639687076693, 81.05171603541221, 78.38723428787725, 77.34547630433114, 74.3852400010632, 79.25264250847601, 77.47310238499796, 77.95214145414292, 74.40301618268414, 75.33468108023368, 69.2128182995704, 73.09502340132191, 70.16824491562383, 68.73956864879978, 66.81286904119676, 67.85475254058838, 71.75638906417355, 68.63127200834214, 74.56348034643358, 72.75389486743559, 77.2084443799911, 74.59645963484242, 71.36441876811367, 79.44967885171214, 75.79788161862281, 87.09120904245685, 4.999752102359649, 0.9637072297834581, 6.503554995982878, 5.572183295603722, 0.7928237186804895, 0.32988539686606777, 0.14405626112655287, 0.060521930441140175, 0.1308459022472943, 0.4854108062722991, 21.100470750562607, 35.853601271106356, 32.08393289196876, 20.529863949744932, 26.721458627331643, 52.08143118889102, 39.653103197774584, 43.88246551636727, 70.04926373881679, 34.54700485352547, 33.94737643580283, 39.03360405275899, 51.52140694279825, 57.47511771417434, 42.92486198486821, 4.7432359572379825, 0.18259057564841163, 0.06779138088947342, 0.08483722024867613, 0.022855097495560205, 0.0568725748528396, 0.04047770721597537, 0.02729723534186281, 0.07869526353334227, 0.02649732272050554, 0.02282699930571741, 0.009967871629933437, 0.05238040380420224, 0.004859719446094166, 0.04757087317205245, 0.0664659951543135, 0.10246958418358719, 0.05331671646525783, 0.06931920535862446, 0.03931980362282165, 0.02771700364387324, 0.04031446537063007, 0.03463172857018729, 0.03194222944007526, 0.07200486447301603, 0.028769696551945903, 0.03926647624241249, 0.06839651374086257, 0.034486386369192795, 0.03555257774649128, 0.03921930820891454, 0.08037086636308702, 0.025289998795356483, 0.06507193729762109, 0.06462598985601818, 0.13966657732042576, 59.681517616395034, 74.1967858037641, 72.87599040615943, 55.67617362545383, 60.52425453739782, 55.26465815882529, 47.39070007877965, 19.865845903273552, 41.44734044228831, 46.32939300229473, 25.835934531304147, 36.629434324079945, 25.959247965966505, 3.312532315331121, 0.14173691461403526, 0.22796677545674388, 0.06982705270450923, 0.8933713491405211, 1.9031432006628284, 1.0820837487136166, 0.2879372413360304, 0.6042006756028822, 48.07846807664441, 105.31153632748513, 104.60311705066313, 104.58785118595247, 96.55361329355549, 103.67492737308626, 98.59657195306595, 102.55233718502907, 94.64233644547002, 97.08741649504631, 93.09679708173199, 91.07722359318888, 90.317978243674, 94.58256736878427, 94.17365243357997, 95.27292805333292, 95.37237582668182, 99.58034946072488, 97.89351063389933, 98.64794715758293, 92.13593406061973, 99.12367574630245, 93.81403384670135, 97.3916119913901, 91.4085775806058, 88.81316877180531, 91.31593904187604, 94.34571112355879, 91.34701205838113, 90.31195348308933, 91.4605882090907, 91.7950487136841, 87.8703643429664, 89.92514502617621, 84.43059475191178, 81.91046407145839, 78.63978785853233, 74.49012417947093, 70.9727151932255, 74.52664929051554, 77.66332949361494, 76.5132748696112, 82.53918078637894, 86.31703515206614, 71.64213826579433, 72.7440889420048, 68.64977775081512, 79.70611556883782, 53.75973886059177, 70.81089388939643, 88.04913813068022, 77.81686675164008, 81.13228936349192, 76.52910555562666, 76.63278164402132, 73.62318623450496, 73.83134641954976, 70.01663746372347, 76.46428446615897, 73.86999745522776, 77.49106684038716, 80.5612079558834, 79.77289784339168, 80.84842743412142, 81.00566740958922, 83.29961853642618, 81.19782432433098, 82.60219758556735, 82.88719700228783, 80.2278535596786, 80.7101874197683, 78.34247219947078, 81.65545509707543, 80.65193237796908, 82.62715954934397, 77.02127672010853, 77.34380537463774, 74.42242407029676, 75.80013305910173, 73.18093899757632, 72.8604970439788, 69.7935801167642, 71.35768798089796, 73.64737156898745, 72.18228001748362, 76.89891446021296, 77.92793258543938, 79.01133829547514, 81.38790238288142, 74.1017310850082, 86.48280236028856, 76.75945851110643, 99.60229904420915, 13.326048697194746, 2.153531745556862, 1.1117867548619549, 10.980769434282857, 4.5467502167147975, 2.221773386962952, 0.08035552162196367, 0.18756510629769296, 0.0506325856962752, 0.33620758342646784, 19.085619795706965, 34.24881450591549, 23.709788283994122, 18.4467343361147, 28.01209492068137, 47.489939966509425, 33.22850404247161, 40.09879819808468, 71.05171957323628, 47.66527383558212, 41.9030963220904, 50.18154882615613, 66.85497960736676, 68.20361598845452, 59.31922005068872, 8.311186644338793, 0.23549282322487525, 0.030098550750183004, 0.061221008654683835, 0.025550445706974116, 0.0999512616544962, 0.048115852799627094, 0.0391343797016288, 0.046398624582516576, 0.02732755901712564, 0.07637626942126982, 0.051951375414407065, 0.023586071779831283, 0.04462099416301616, 0.02840072945541432, 0.014173725935360117, 0.06470158741238617, 0.19790758438889058, 0.16447472596360793, 0.13152790436100575, 0.11095861213341837, 0.0719342158446389, 0.11360275694319319, 0.2024056696363034, 0.3130778568165918, 0.19556565360436517, 0.20424296298334677, 0.23654170484552461, 0.15727706944509862, 0.08713853305145618, 0.10353658378364579, 0.2487745355334013, 0.18660663837386718, 0.12046999207908109, 0.12106480572613017, 0.7888721145929829, 82.12936370603501, 87.4252223968506, 88.95154999148461, 73.49963941881734, 79.5790699989565, 75.09080379239975, 90.26131568416473, 52.24442528140161, 62.84208505384384, 72.0533517099196, 43.66267550376154, 57.919934103565836, 47.81257060266311, 7.056681754127626, 0.24488636352602514, 0.36579074277993173, 0.2577246947874946, 0.5894822266794021, 1.3470544401676425, 7.840402693517747, 0.8733245441990515, 0.37420379779031204, 41.90559094951999, 104.34972409279116, 108.02543209445093, 111.10580275135656, 100.64651243148312, 107.52410611798688, 103.52756392571234, 109.16154661486226, 99.64198558561264, 102.46751200768256, 98.22012639814808, 96.86054660427956, 94.94818718202653, 97.87680133696526, 97.60153724301247, 97.14521654190557, 97.75369382673695, 102.01964009192683, 102.17595438803397, 103.63280896217593, 95.60480763835292, 105.47709172771823, 99.2177184935539, 102.52044047078779, 95.3043697726342, 93.65340494340467, 95.91818148089995, 96.42255121661772, 95.90109563642933, 91.6665675563197, 95.15927345521989, 96.85193307938115, 91.4710295584894, 93.58373580440399, 88.55840298437303, 86.8592792941678, 81.14138141755136, 78.72182815305649, 75.38404803122245, 77.87845580808579, 80.58813110474618, 80.21086185209214, 89.57586580707182, 88.43418936575614, 72.4833611519106, 75.82475769904353, 70.3011191275812, 78.16043499977359, 51.980849850562315, 76.32464024328416, 90.13190884743968, 81.95498297291418, 82.7112865447998, 79.2261508203322, 79.3789271385439, 77.508317424405, 77.27437157784739, 71.3244027476157, 78.14020341442478, 75.4583534117668, 80.58396554762318, 82.52040832273423, 83.63631479201779, 83.11819322647588, 83.26297575427641, 84.19532314423593, 86.68788740711828, 86.29822346471971, 85.85321487918978, 84.05510625531598, 84.86159263118621, 81.76093547574936, 86.77845493439706, 84.56105278384301, 84.51561604776691, 80.37514640438943, 80.40580364965624, 74.98491548722791, 80.38077892795687, 77.02128456484887, 77.48285339724633, 73.750271028088, 77.35487430326401, 79.13725422274682, 75.18652531408495, 83.279355572116, 80.91932035261586, 82.48895091395225, 81.32584264201503, 75.71107956670946, 87.17891323950984, 82.59459603217341, 97.52214062598445, 7.795942137318273, 7.414268553256989, 16.713101633133427, 12.879423114561266, 1.4825883868240541, 1.6146283596754076, 0.5587861254330605, 0.20000343241037863, 0.23255804763926616, 0.9333756025279722, 34.684931078264796, 54.85598641057169, 49.27529304258285, 34.05098976627473, 40.63811232966762, 72.92633794969129, 61.16176128387452, 64.32317987565072, 93.62357139587404, 51.29274845123292, 51.835353451390425, 60.821448602984034, 74.76260339060138, 78.10082281789472, 70.27252504902502, 7.949842704880623, 0.35230891298382516, 0.2034649547309645, 0.16440829081881433, 0.08673938592114756, 0.2620434082083164, 0.05611192615282151, 0.06340712864672945, 0.1581317324551844, 0.13665047384077503, 0.1828156982458407, 0.12343436930208437, 0.13041871629895704, 0.1340353714242097, 0.1349502642669024, 0.22700645360014132, 0.18231639278031167], [0.02097177950124587, 0.037518194651291255, 0.08173835629056539, 0.04599573128225823, 0.015455278992322425, 0.14008349769057768, 0.013803427761060097, 0.036842194836466544, 0.03501640046916662, 0.05861884546315959, 0.051266397049109784, 0.010738405737004453, 0.06833547185505591, 0.03177346218557608, 0.06205956466616162, 0.07256459895401232, 0.05754792349292867, 0.05572173075990812, 0.24416797223591039, 44.33686817845991, 71.89628431873938, 53.11157111198672, 69.43995491150888, 58.944363055690644, 38.40280063690678, 36.135792270783455, 51.17381826523812, 24.485697823186076, 25.39602306581313, 34.373032046902566, 24.85444768782585, 10.9704771349507, 0.15332980141524347, 0.045860516763622725, 0.17467944612426145, 0.4462226510288254, 0.2354011071785804, 2.4304662789067915, 2.1049264698259296, 0.40824558886308826, 23.710288386191092, 105.49333034023162, 101.54885368962442, 102.12024888684674, 96.5909307233749, 99.59366982983005, 94.41219529797955, 94.08339085117464, 93.90200476492606, 91.59783978616038, 86.49966070728918, 85.85797663657897, 81.72136660545104, 87.62173314248362, 87.30424865599602, 90.26063319175475, 92.79411562027471, 90.57283032325007, 93.39852148486723, 92.8107935382474, 88.90605049748575, 87.36383730365385, 89.29384739168229, 90.19899706686698, 87.34934022349697, 87.39267456916072, 86.06878049911992, 91.32463885891823, 87.49573876780849, 87.03671163128269, 88.9475727081299, 89.5899941844325, 86.23412409136373, 84.57411427651682, 81.78206136149745, 78.56321534802838, 76.00604964840797, 74.28670221759428, 72.30883921346357, 72.19520814957158, 73.66609696419009, 82.57975378344136, 79.1544028251402, 78.10506682242118, 84.40975912155645, 71.32946260513799, 72.28413612611833, 65.3780895663846, 71.31857410553964, 81.66296251358526, 74.09351764186736, 85.70862846989786, 74.92935119136688, 73.04382078109249, 74.43107681889688, 72.48520466589159, 71.31670705733761, 70.62342812938076, 69.86158617081182, 72.18492369497977, 74.63150993470224, 77.10425053873371, 77.4033312643728, 78.36731649214222, 77.19477099757042, 77.06993764446628, 77.4026095482611, 79.46266974172285, 77.21950546387704, 77.5486707687378, 76.39636470425513, 72.43950905338411, 78.37002292756112, 80.35922158148982, 82.39202914699432, 79.54018362106817, 79.76852832301971, 76.63886131778841, 77.47453012774068, 70.80829728034236, 73.63340008643367, 69.47935119751962, 70.15691711056617, 64.04131835506809, 65.46717443773824, 66.39585048921647, 68.21588516235352, 73.27138100900959, 75.01357232370685, 75.71908904660133, 75.23916352179744, 73.47026871096703, 78.07936745305216, 77.5818383309149, 78.52040659996771, 0.34917524565131436, 8.312559473899103, 14.356944657141163, 2.710108228268162, 0.07639315399912096, 0.6109630869280908, 0.21699814306151485, 0.0303819534864517, 0.025289054591989806, 1.195400532695555, 25.782996262273482, 25.503929430438628, 38.74701215374855, 29.70608226714596, 32.445524431044056, 46.85982688780754, 53.740323128238806, 83.16788181181877, 33.30450780930058, 50.9122157865955, 44.8692318700975, 49.622207072473344, 45.79741762530419, 51.92414806735132, 30.01905995030557, 0.45532025156482575, 0.04473142573730119, 0.007370952310250893, 0.01595130655914545, 0.05035098709706819, 0.07622260750541765, 0.06100245526120548, 0.047338315691318245, 0.029089139894612377, 0.038515081884519714, 0.07887132586010041, 0.02051295986729524, 0.054640298063356074, 0.08456322890255721, 0.011566451979771016, 0.07446992856961104, 0.014729274703460115, 0.045120901007565765, 0.03184178190666341, 0.03253765404224396, 0.008284832001663744, 0.07228788799576222, 0.046873419064908266, 0.043441222590063854, 0.04778606343954321, 0.022260687959891175, 0.041652571995772665, 0.045543429141323415, 0.029485079031738064, 0.05502359866495094, 0.061614134333907604, 0.06230370156587132, 0.04282112804151351, 0.07381381256686104, 0.4687954317177496, 61.89939437373992, 83.53374481201172, 65.57751463305566, 72.40729854952905, 58.865911729874156, 41.74795089229461, 39.52719903761341, 40.93511812148556, 29.460235949485536, 31.473051194221746, 30.58916468774119, 27.173419613992017, 9.013551742799821, 0.07264669293597822, 0.1866581654476543, 0.19921310546417392, 1.28125790626772, 0.973562368702504, 0.47037329705011466, 1.9275088415991877, 0.15321675748113664, 39.9294694777458, 116.51931685786094, 105.970808306048, 105.99488381416568, 99.7110899033085, 104.66998561736077, 97.48206969230407, 100.279143241144, 97.22891992138278, 94.71793620817124, 88.84026450495567, 88.30179368295978, 87.48261451721193, 91.96028247956308, 90.20675551506781, 93.57456530294111, 98.65087324573149, 95.44553587513586, 94.86520551866101, 94.4228563001079, 92.24008083343507, 92.76758470842915, 95.60641581012358, 94.50175869849421, 90.04473809273013, 93.31897581777265, 90.91020907125166, 93.6008216488746, 90.13650586528163, 90.19639261307256, 92.4357835708126, 93.27535121671616, 91.16635553298458, 88.32965820066391, 85.71878740864416, 81.57470918470814, 78.6007994990195, 76.72459648501489, 76.0185855434787, 73.5279824656825, 77.34852006358486, 88.17950202572732, 86.30748810306673, 82.75893549765311, 85.91017553883215, 72.74009596916937, 73.35127184467932, 67.48411209352555, 75.78337669372559, 86.73304957728233, 78.38458276564076, 86.18137605728643, 78.17038213053058, 75.20283452926144, 76.02409255120062, 75.62060617631482, 74.27691982638451, 72.93189202585529, 71.23867542512956, 73.67407506512058, 76.67464117850028, 81.24766195974043, 79.67008467643493, 81.69790298708024, 79.5889308375697, 78.9603945516771, 80.48599258545907, 83.73000452595373, 80.64775897610573, 81.0791883160991, 80.411647981213, 77.41696542309177, 82.07217554892264, 82.36494125858431, 85.86817479902699, 84.9373100649926, 83.11117218386742, 79.55380209030645, 81.1057976753481, 77.94225708130868, 77.12360351316391, 75.34602457477202, 73.09442720105572, 71.10400476763326, 69.3973030582551, 71.03061722170922, 72.94309431506743, 76.3383371599259, 79.89263996001213, 79.13755232287993, 80.69121099287464, 76.06967833734329, 83.83275493498772, 77.3429189189788, 90.45811668519052, 1.7059830576181414, 4.403847975115623, 4.47380393743515, 4.738998326563067, 0.5248055294636758, 0.8286233138172858, 0.24568421345564628, 0.0492653600691307, 0.0418681146637086, 0.5598397721205989, 24.618356304783976, 19.95626045811561, 34.35572654970231, 37.30696885816513, 33.59831686942808, 34.98652996555452, 31.042749535652902, 63.401340515382834, 33.05623354450349, 64.03783529035508, 58.17058924705752, 63.94798555681783, 60.08470196877757, 62.658745627249445, 48.8823970671623, 1.1812049847456718, 0.0932688682129787, 0.0015542436097260386, 0.0472882135410703, 0.047360505428045034, 0.043599209072248596, 0.03123390071484591, 0.06664008863510625, 0.053596587536195596, 0.0632626712772875, 0.04036514974770047, 0.021048236991308873, 0.03169364923040473, 0.06179482383172839, 0.031555119466276906, 0.014990674436933573, 0.13590336957525823, 0.14105609227572719, 0.16122596158135324, 0.1660284901698751, 0.05819368581738203, 0.1708612179443721, 0.1486357661985582, 0.1180096394232204, 0.128839242181951, 0.18028258255893187, 0.1849336249213065, 0.17079130476040227, 0.1600354456252629, 0.17469047779037108, 0.149108718239492, 0.12587784504097316, 0.1776098090434267, 0.2336215308957523, 0.8728807647862743, 78.55946556214364, 95.46917207779424, 78.9265601865707, 95.0234260866719, 86.72535388700425, 58.209232437995176, 57.92049892487065, 72.62196986905991, 37.04416221187961, 47.242257979608354, 54.01499494429558, 40.19919126264511, 18.393639172277144, 0.4057165487639366, 0.27033162153055595, 0.2958362207057015, 0.5337745191589479, 0.6031038828434483, 5.356378901389338, 6.927264130884602, 0.5514628764602446, 31.879396976963168, 116.5597172706358, 111.31077012708111, 109.26918429713096, 103.20218763043805, 109.36354867873654, 101.94797054413827, 102.45103805295884, 100.4213370046308, 96.97148692223334, 92.97132830465995, 93.53941302145682, 90.22141733477193, 95.4703252546249, 92.98701778534921, 97.13242177040347, 103.64385435658117, 98.64209498128584, 99.7918515051565, 100.51367744322746, 97.4132634747413, 96.12900887766193, 97.48937314556491, 98.08613823306177, 95.37787498966341, 97.34747748221122, 92.44258496069139, 98.56045476851925, 94.45172494457614, 93.94522928422498, 95.30697422642862, 96.34921073913576, 93.2277101086032, 93.44865722040977, 89.98105449061241, 86.66148201111825, 83.29408799448322, 82.03894522882278, 80.57419100115376, 78.57911663670694, 79.319746417384, 89.65095566165063, 86.6470947573262, 85.16490167187106, 90.06938626689296, 74.01969863522437, 71.319287976911, 65.98636288796702, 74.45384225537701, 87.09011077880861, 78.9812929399552, 92.9378704870901, 80.54362004803073, 79.98235241059335, 79.64949223303026, 78.59872848756852, 77.9942520203129, 77.39715745372158, 76.99003111931586, 79.64564046552105, 83.42727599605438, 85.06465373500701, 81.89625724669426, 84.98081699494394, 82.9751443862915, 83.43510504691832, 83.33053465812438, 86.47619708891838, 85.11056900024415, 85.17940659676829, 83.31432742457237, 79.05533944406818, 84.96871256059217, 86.38822617069368, 90.52195718211513, 87.83142305189564, 85.55509905661307, 83.43628175797002, 85.19934792672434, 80.1523087101598, 81.29295749049034, 77.69317873062627, 76.46081709092664, 72.0103782223117, 74.48853954192131, 74.63750331632554, 75.17357364777597, 81.59479956473075, 83.51912221600934, 83.55551396646808, 83.8086715821297, 81.0377053291567, 85.56491282678421, 83.7321775190292, 87.32399386744346, 0.520783935583407, 24.184746126974783, 37.540094929356734, 2.27977053292336, 0.2130158341700031, 1.383362717686161, 0.9350864913675093, 0.1841476493545117, 0.20112336102512576, 1.9970142216451707, 39.10625419309063, 37.40513009409751, 57.41647828009821, 47.31650060222995, 47.30917753711824, 61.25883602326917, 74.24203426607194, 97.9875063127087, 51.66493823451381, 78.71084551657401, 71.79722093766736, 73.73612696124663, 67.53942535769555, 78.3647120383478, 52.7443431269738, 0.8533320395696549, 0.11054606612531409, 0.10612020764740245, 0.11528570655613177, 0.1056228327234426, 0.15528418364063387, 0.13744676095103064, 0.15703976604967348, 0.1602951034663185, 0.10673677053062186, 0.1633492661940475, 0.09880980596907678, 0.2150111254905501, 0.20602154335187328, 0.1264524646103382, 0.12948765900106202], [0.05435348240538471, 0.12286831459571278, 0.06885386823165802, 0.07718469136424604, 0.03067622509514613, 0.017637841463569674, 0.0781946097530665, 0.04910799794860425, 0.04198078704517215, 0.05936554370207652, 0.1514930136862301, 0.026174364949486432, 0.04346629664782555, 0.02602492609331685, 0.03174249691167667, 0.02204123824354141, 0.06193454677779829, 0.030715297494504242, 0.5522804454930368, 55.073407311593336, 64.44334168587962, 58.72919751751808, 42.32576308711883, 40.06394401673348, 38.08491214629143, 26.37216764111673, 32.64558688286812, 31.137011935634, 29.059261852695098, 26.877347346275087, 21.732454799836685, 0.85241726930103, 0.043208691922407, 0.09605806411033678, 0.08430121917157404, 0.17138634057294938, 2.5249534797283912, 4.893204348702585, 0.38147611723792174, 10.834750379285506, 106.6762936499811, 97.34637137382262, 100.64785388208206, 96.3596599332748, 96.97134571690714, 96.0049835328133, 91.46127070150068, 93.60374773702314, 89.67087345738565, 85.66907528908023, 81.74398299186461, 81.89010697026407, 90.00390621923631, 87.33541580938524, 86.17984633291923, 88.7882617212111, 89.5161202646071, 89.91635107224988, 92.02735500950968, 90.70367274745819, 88.24084005048199, 90.11738038832142, 90.00654989673247, 89.92942825440439, 87.48135935875678, 88.05058156290363, 89.69567068161504, 85.06377512408842, 89.44629423079952, 88.61935661685082, 88.07263312801238, 90.28481852623725, 86.88612399562713, 83.54143265754946, 79.12252964511995, 76.57251050395351, 70.2880419454267, 68.45970753700503, 67.4035152312248, 65.14352398533975, 74.8088873586347, 86.77010813067037, 84.07941710564398, 85.6289965106595, 83.42224751749347, 77.38153073095506, 78.71169274853122, 74.56504929450251, 77.9877487305672, 72.85648053692233, 81.3754370904738, 73.54818267206993, 76.61155377664875, 68.63152304003316, 68.32178131226571, 67.98685012325164, 69.02264610413583, 65.04728078842163, 65.99755733243882, 68.40511598894673, 73.06606061996953, 75.32741685067454, 76.77816821682838, 78.16460840163693, 80.46062269518453, 76.97832676672166, 76.34463648642264, 76.43477255298247, 77.04161813182216, 77.48453217168009, 78.22760166660433, 71.45780255717617, 79.73571377415811, 78.94610927950951, 79.64129447937012, 76.81528168339884, 76.47201153539842, 72.15963225210868, 75.01361939214891, 76.43196413593908, 72.7317491654427, 70.32787753689674, 71.0361477636522, 70.37579321092176, 68.31741179189375, 65.27196984137258, 67.3363720986151, 68.91000347752725, 74.35146054913922, 72.58546044749599, 75.69634714434224, 71.64120474169331, 79.15368895376884, 72.7058615223054, 88.19482280362038, 42.98649026501564, 1.9851833726129227, 13.657426218832693, 16.432962033056445, 3.6804516180869076, 0.04363116259957033, 0.2700969228340734, 0.052068820523638884, 0.10351665017585601, 0.0777019692524787, 5.5700617836367705, 36.216228315907145, 31.19506105299919, 35.71630654796478, 38.03788685029553, 38.63462448120117, 55.98318930595152, 52.70641380740751, 35.09114350042036, 23.98330496203515, 28.30555488986354, 38.843882929894235, 48.2635372684848, 50.42945831052719, 58.40728075273576, 9.392804734168514, 0.4023882644551416, 0.0038115122222206407, 0.07711292424749944, 0.08447329018024669, 0.032444911438130566, 0.019172597113215638, 0.01847301136642214, 0.01397810729911491, 0.07143897064510854, 0.04859136357422798, 0.0405673778075124, 0.027482588399922656, 0.033633290008912166, 0.08126250843727782, 0.0381244536519291, 0.07255255605184263, 0.11198218220904951, 0.06122952755240183, 0.03679879595555606, 0.07449749241312666, 0.04954133941341312, 0.020565306655161326, 0.055187710020090305, 0.027178432341785203, 0.019568530504681894, 0.03534234406787061, 0.02497306630586184, 0.036513738469370914, 0.03545572508066412, 0.015371913304402223, 0.010615187197653277, 0.046403991028426156, 0.12051788023522786, 1.1339269410217963, 71.24309201394358, 71.67792597124654, 75.13481278573313, 55.6919337088062, 50.2839187652834, 46.06784935920469, 34.18657825839135, 37.553462366903986, 34.26692801137125, 33.154159438225534, 26.542302408526023, 18.580997067113078, 0.2914054745868329, 0.14868337090217298, 0.08615013407242876, 0.34997283511104127, 1.1058980514926295, 3.0408763116405857, 0.22551495702035967, 0.8271741818997168, 23.6971817862603, 118.93029582115912, 100.35645315724035, 107.1684177460209, 99.35479748633601, 101.39978793359573, 98.40386590650006, 97.86429682085591, 96.99392287961899, 92.77282499497937, 86.91082708297238, 87.22951181473272, 85.59206347311698, 91.72494811396446, 89.97916390818935, 90.49646177599507, 92.01787856317337, 92.38494180863904, 95.48021747219948, 96.10059522813367, 93.66762745764949, 94.09307126075991, 93.62094340785858, 94.59047486705165, 91.05976120118173, 92.85583803730627, 91.94284362177696, 91.693616221028, 91.8890130135321, 92.07568645477296, 91.22673649941721, 93.21504085294663, 91.39195457581552, 91.14760660356092, 85.04006047402659, 81.17657292273738, 80.3837913082492, 73.12885776642831, 72.62322502751505, 69.51615871921663, 68.41528277243337, 78.69013540206417, 88.33298437057003, 87.63606548309328, 87.8200089546942, 87.63328060027092, 82.14299786475398, 77.51818610775855, 72.25027038205054, 76.79264176276423, 75.86112591528124, 83.73075762102681, 76.48655568399738, 80.68778284134405, 75.48530793959095, 73.80698065603934, 70.3751499422135, 71.43397808074951, 69.90575205895209, 70.78015035198581, 73.19709916268626, 75.0642022778911, 77.21482999863164, 79.9585828473491, 80.77094493373748, 84.67837872043734, 79.3064417377595, 81.50602063825055, 78.05449178141933, 81.89005205708166, 79.38157866078039, 81.46383946941745, 75.85821551661338, 82.20967815768334, 82.04500921310918, 81.17607085935532, 81.1872103906447, 78.226683831984, 75.99985230353572, 78.50015932513823, 77.36346429394138, 74.89375960442328, 74.70542307822936, 74.23415030202558, 73.39027589367282, 71.71804397336899, 67.9275909546883, 71.54624415982154, 71.73208605858588, 77.41082299140193, 76.60352860727619, 78.6327354369625, 76.59738617558634, 80.52331786001884, 79.48041454438241, 87.41645982188564, 57.220159730603626, 1.8353596185484242, 3.705331212089908, 8.891303231639247, 5.245671964460804, 0.4246073883147009, 0.2649514779688851, 0.056866714280218854, 0.1366529866091667, 0.0951194991507838, 3.488529310111077, 33.25790612928329, 30.16520550174098, 39.53481628048805, 43.74726926126788, 43.80555960439867, 48.40023971373036, 36.22295910312284, 38.302136928804465, 37.64217069072109, 39.49065039234777, 47.17576988281743, 60.025399654142326, 58.81213995718188, 74.66004910007601, 14.428509281527612, 0.3936647599743259, 0.08305791975750078, 0.057479818276460135, 0.03350369474520126, 0.1325984356263953, 0.010184899550832568, 0.10088098595940298, 0.0390421005807096, 0.027522681611439878, 0.03340483109857286, 0.02928531202938288, 0.05808628029039791, 0.0530117598452395, 0.027426951264421788, 0.09920923655191738, 0.15160087886596882, 0.23384325206279757, 0.16092611476778984, 0.17560708667001418, 0.19651425431572622, 0.15563223270639298, 0.22868694407084297, 0.2604545112098417, 0.07660096300946129, 0.12200910102335677, 0.23851692466245544, 0.19134087788481868, 0.1458807148399853, 0.14676237478852272, 0.1559904860633035, 0.14008257838506855, 0.1481268386687002, 0.23996069396455444, 2.8540025843727976, 90.05612081097019, 85.63904562304097, 87.09225239292269, 60.82409228048017, 62.10488734706756, 62.515653640993186, 43.32501042273737, 54.488342654320505, 56.1977586438579, 51.01840219190044, 38.213503130020634, 32.436824614001864, 1.6318713441010446, 0.24261894245301527, 0.24834338124961625, 0.2828705503094581, 0.6090816975601259, 4.71284935551305, 9.626198507124379, 1.2106018008724337, 17.091284798037623, 121.10937641512965, 105.7500651574904, 110.57323901884018, 105.03933952700709, 106.88783491811445, 103.36720958832773, 101.49952596233737, 105.11759865668513, 100.22947819002214, 92.39304542541505, 90.46320007693383, 88.63350852843254, 95.9270852611911, 95.1110439915811, 94.87487808350595, 97.4580490973688, 96.84539056593373, 97.90440697823801, 99.88569813389933, 98.06409451269336, 97.33468271070912, 98.84707020175074, 100.84892242185532, 97.83958588877033, 93.97190924613707, 94.35584652808406, 96.08001062946936, 94.47830292486375, 95.5321418085406, 93.21666471419796, 98.13616414223948, 96.62515732549853, 95.08751761528754, 90.07997666635822, 84.3846716419343, 86.4129057238179, 76.7176538898099, 75.86522871448149, 75.46875553746378, 72.53636806241929, 84.46267189518099, 91.32743943122126, 91.79340916295206, 91.16822258118661, 92.17660903930665, 82.00395768688571, 76.63810037797498, 74.21456198538505, 76.1434502755442, 87.9649248430806, 89.85298910448628, 78.18348284690612, 83.46062398725941, 77.91818941793134, 76.9619312594014, 74.53410963858329, 74.84281586062524, 72.47455150850358, 73.11144244286322, 76.14982020470404, 78.33055603888728, 81.27135307558122, 82.33262092836442, 85.04751297735399, 89.28138994401502, 83.37069188394855, 85.02481814353698, 81.6929215769614, 84.6728717127154, 82.69153348861202, 84.61742508795955, 75.46866924531999, 85.80307129890689, 84.93647067777573, 87.74514659758538, 84.43796096309539, 81.64902240999284, 78.55555888145201, 81.11571342714372, 81.08180845937422, 79.19542297240227, 77.77248905551049, 80.1106531389298, 78.37090938322007, 75.44835136782739, 71.17812187440934, 76.35136727363833, 76.40464090531873, 82.2780607592675, 80.0791721959268, 80.81325161841609, 78.82891670350106, 86.62716911685082, 80.89402106500442, 91.84145035282259, 53.5498449879308, 3.8477784587490946, 27.71174530829153, 29.375832426932554, 8.1768587039363, 0.4190756819180904, 2.566293545307652, 0.21152139581259222, 0.3899211947235369, 0.20403196704724144, 9.680710627186684, 50.25728587181338, 42.45778222237864, 54.66404914855958, 53.898355422481416, 60.78631985572077, 72.67321171299105, 65.27263664430188, 61.38245736399005, 40.89455689153364, 46.44636200320336, 59.55421709245252, 71.6910659113238, 70.78795586862873, 89.7015699263542, 17.06546579637835, 0.5079685103508734, 0.1489672064781189, 0.1505674568996314, 0.24825515856425612, 0.2485297551198352, 0.11190381141439562, 0.21923018619418147, 0.18101928335043693, 0.21860072239031716, 0.17346378716249622, 0.19105321186925137, 0.16900138629059638, 0.10016338373985022, 0.1163098818412231, 0.24089837026211525], [0.03825031040656952, 0.04099855507393518, 0.017801152256828164, 0.04314668093537612, 0.02913189717688628, 0.04365676525799979, 0.020496282133183653, 0.011601818428795424, 0.03314884281867454, 0.08099478369037952, 0.04709157409266599, 0.06186499748559249, 0.05391855130813295, 0.04832635077858164, 0.0346095924596152, 0.03706594996695076, 0.036729388389616244, 0.19141031609427547, 0.4754476183124127, 60.740565407660704, 66.10420657742408, 55.68130016326905, 36.711709960814446, 45.024024286577784, 43.52337252709174, 29.5796662376773, 25.43523500042577, 30.943223314900553, 22.48524392804792, 31.88365863215539, 5.24871523341825, 0.12142026286211707, 0.314612943799265, 0.1439660466125896, 0.2296537010660095, 2.8513929824675284, 1.3991606764255033, 0.11091467699096089, 2.244478517001675, 81.69411397749379, 101.72584672128002, 92.78315651801326, 96.96995719786614, 93.84342808877268, 97.27458415492889, 90.39815933473649, 87.13886584005049, 87.8271790473692, 85.5689920917634, 82.30330513369653, 82.07324243360951, 90.34256365991409, 85.70517678414622, 85.3926815525178, 87.14578490103446, 87.51075360082811, 84.76564361203103, 88.70160087462395, 90.63741607050743, 89.15690175948605, 89.34316727422899, 90.27692671745055, 87.70803313101493, 86.67164094986455, 87.9772646196427, 88.66309104427215, 86.02503822695824, 87.72034152861565, 90.12842578272667, 86.95585589255057, 85.50965447579661, 83.96614689980784, 81.830581080529, 78.59410793550553, 77.38511577729257, 73.82347030024376, 73.70142182996197, 70.95078914396225, 67.09385979560115, 70.02128939474784, 72.82531338353311, 81.75454201236849, 80.80301423226634, 78.87123123292001, 78.62371398556617, 85.58079842598208, 81.0738068242227, 72.97631679042694, 77.23561071580457, 66.38053755606374, 73.08142062156432, 78.43380066656297, 78.00440311431885, 78.30209532091695, 74.43824691157188, 63.82725892528411, 63.06038456578409, 62.457304462309814, 65.9009728893157, 68.19570849018713, 69.5529583961733, 71.15437584538614, 72.60671969382994, 72.8286160192182, 73.9080915143413, 75.49159942134735, 77.08181458134806, 75.59409879869031, 76.55103944963025, 74.59037211633499, 74.05361929247456, 79.02445470133136, 79.48200702667236, 78.06801611377348, 78.08537652415615, 78.98268930373654, 75.34337305253553, 74.64778777091735, 67.36509953775715, 68.23356720709032, 69.16935843806114, 72.05835665425947, 71.9239527179349, 68.14519620710804, 64.92805250229375, 65.52271912174841, 63.95108030688379, 70.13947040803971, 69.74267559666788, 73.3149742311047, 73.22274361887287, 74.54325660582512, 69.45857048034668, 79.14461258919009, 77.62590223743071, 87.73948269505655, 7.3523255029032315, 2.02220392803992, 15.486851046162268, 5.3989753511644185, 0.09846584015195409, 0.14033232304838397, 0.06415653883689834, 0.07053887096023367, 0.06562545114467222, 0.14042246095355482, 10.60920330785936, 40.99151788219329, 27.886788921971476, 30.266698791134743, 19.329073467562278, 31.568082378756618, 31.628981098051998, 26.57179863222184, 24.851419618052823, 26.451087690168812, 39.14242236844955, 51.39294147491456, 45.397328022987615, 64.61764789396717, 14.53899754631904, 0.25876305036006436, 0.10131023268425658, 0.025793885466672724, 0.06637426378626017, 0.009313831725458225, 0.059100128710269935, 0.06519533874046418, 0.041516403697671435, 0.012252575646515095, 0.033611785920877615, 0.04345350297949007, 0.03535545183225505, 0.02133371774107218, 0.0846640230907548, 0.03373570830350922, 0.015525119397939454, 0.040297224561894135, 0.03630299917272022, 0.04388413632348661, 0.0650718683497079, 0.0050979052790470665, 0.017399139957682743, 0.035574886226846326, 0.060254010341821186, 0.02240284515034047, 0.007701597773590156, 0.06518838266211172, 0.0078000841219158425, 0.03485737593784448, 0.04519479018786261, 0.11366277993206056, 0.10423940816713918, 0.33801337523806485, 2.3451275162158476, 77.90237442139657, 78.54325832859163, 71.86707835043632, 48.30823659896851, 56.38425950081118, 51.8834299425925, 29.907007640407933, 32.93325939486104, 39.96684966548797, 22.41699468704962, 26.62423287668536, 1.7195524972292686, 0.1067856546010702, 0.14905607267733545, 0.15851200317903874, 2.0224346124356796, 1.797033281576249, 10.90465093812635, 0.3943261696446327, 8.438323409326616, 102.33230790784283, 103.32829967621835, 102.14784668337916, 99.70843838107203, 98.32978802342569, 99.70378645004766, 94.13449933451992, 90.39971259332474, 90.97512429760349, 87.53317386873307, 84.63309887916812, 86.93174900547152, 94.09021577527447, 91.40433357607935, 91.69452621090798, 90.36078699173467, 90.0412001148347, 88.71924369565903, 91.67774631131081, 91.48343209297427, 93.54083291945919, 92.76083823173278, 94.40498598160283, 89.53360619083529, 93.32881312216483, 91.27866868049868, 92.36074078467585, 88.92698810946557, 91.67445152036606, 91.84819682951897, 90.7282816979193, 88.82096644370787, 87.53807683144846, 85.0085481520622, 80.67393687463577, 80.74666546237084, 77.78435814765193, 76.66154830686509, 76.27905445714151, 71.2641159180672, 73.695663790549, 78.4215707163657, 88.6906966855449, 85.63568807417347, 81.25127054029896, 80.80649729697936, 85.7953050059657, 80.64183619714554, 77.36848492776194, 79.69545456670946, 75.74958155232092, 79.0434781966671, 80.40703527389034, 82.15964440376528, 82.14206434065296, 78.32382525167158, 69.57924612106817, 65.35079379235545, 66.57540875096475, 67.11720574286677, 71.67037148629466, 72.33911991119385, 76.95482392464915, 75.78229411955803, 75.31740696199479, 75.9861240079326, 79.38921159313571, 80.90176382372456, 80.05854837356075, 79.50194051188808, 79.04428620492259, 76.33996102117723, 82.60924216239684, 80.51081334390949, 79.94693340793734, 81.21817358078496, 81.51498717646446, 78.72731162655738, 76.7462715025871, 71.9340959672005, 70.49757496003183, 70.94047331040906, 74.98012235087734, 73.97932175667056, 72.55303029091128, 69.5243250939154, 69.13335892461961, 67.53500876888153, 75.06658707895588, 72.9654126013479, 76.18775736901068, 76.1365233698199, 78.04700789913055, 73.77808847735005, 82.92918989735266, 78.50636451475083, 93.38860573307161, 15.32746063124749, 1.6834000113510317, 6.55584019037985, 8.207594396606568, 0.589405617886974, 0.06664581897277987, 0.23339118357867966, 0.12051954264602355, 0.21492247379595236, 0.11846883252503411, 6.498244597065834, 40.06399892991589, 24.751061854823945, 29.112460959342222, 28.893496605657763, 44.28571262667256, 39.96931291395619, 19.160372326450965, 30.390981051229662, 40.212797964772875, 46.54879077788323, 60.251069299636356, 56.403737991086906, 77.55801385448825, 22.88038742157721, 0.2520604245364666, 0.09034215187233302, 0.035329086916340936, 0.03917004492494368, 0.07082239244013064, 0.018929821934791344, 0.03165945872634409, 0.037258012040007504, 0.023865113560591015, 0.04669837946552904, 0.05320560690315981, 0.042023193842220696, 0.03492429371803038, 0.019433392594838818, 0.048451135010128064, 0.16178797900436387, 0.10970876266759251, 0.14038712897848699, 0.10050834547127448, 0.20451489355294936, 0.1157815186607261, 0.17144641718797146, 0.072074655082918, 0.21466123781377272, 0.1968822523110336, 0.13568100489435658, 0.24156756338573274, 0.11166589514863108, 0.15777517981346578, 0.1870741205470216, 0.19738325849175456, 0.22180906797368682, 0.7502234691093046, 3.6893161746763417, 97.74561374418198, 88.98722002583166, 83.76748669532039, 57.62056312253399, 69.12295679892264, 63.91640655456051, 42.96854149910712, 38.42557391812725, 51.92653286841608, 35.98910347107918, 46.933881236660866, 8.37219028703628, 0.37487859867753526, 0.6921719002627558, 0.25009928541558407, 0.9617923776949606, 4.184728197513088, 11.849653855446848, 0.8404738359874295, 7.385390593159584, 102.55084668436359, 107.18457791113086, 104.32250284379529, 104.92426503089168, 100.14710057166316, 106.38460266974666, 99.988919227354, 96.11818313598634, 96.4135140757407, 93.81491245761995, 92.04634712588404, 89.24662989954795, 101.14615963351343, 94.51029377598917, 94.39104587801042, 91.59405862131428, 95.94056252510318, 92.80616514144405, 96.8732080151958, 97.81051328105312, 98.80595591760452, 96.5597165015436, 98.53871699302428, 92.63212173215805, 95.80531135682138, 93.87910596786007, 98.07028401282527, 90.75318090377316, 95.13692378997804, 97.58241176605226, 96.33450185098957, 93.72308192714569, 91.41188021629088, 89.73981303553428, 84.96724559414773, 85.07734652488463, 80.21349768484794, 80.40278342462356, 80.94378809775077, 73.95311247917914, 75.44237367568478, 79.53799493851201, 91.84327817732289, 87.66233751850744, 87.10279572394587, 85.54661104756018, 89.25242716266264, 86.39152096163842, 77.14574921515681, 83.35649290392476, 75.69883392703149, 83.91357929475846, 86.7833657418528, 83.82734990889027, 86.0085407380135, 79.79350597627702, 71.32259845733643, 69.96496415907338, 69.78269946190619, 72.78518753667032, 76.0364087935417, 77.31951805853075, 79.11220596682641, 78.2938269645937, 77.40308807742211, 79.20734697772612, 81.77930001289614, 81.65934608828637, 83.30154834255096, 84.1979040638093, 82.67462807316934, 79.05806941370811, 85.46900303133073, 84.80180786501977, 85.976730315916, 85.20640034829417, 86.18805977606004, 81.41690438793552, 80.18669220709032, 76.82253806821763, 76.3672685623169, 75.93510181673112, 79.60629909269272, 78.51371503645375, 73.3782655962052, 72.9434237941619, 74.09438056330528, 70.67957293602728, 79.40676027728666, 77.23892119623001, 81.79534250690092, 82.24034324769052, 79.65366563489361, 75.03887945605864, 87.38362958354335, 83.03008894766532, 95.83803961353918, 11.732838807567475, 8.822196952758297, 39.05016429962651, 16.843847959272324, 0.9459173811539527, 0.30865835686845167, 0.6472445207257426, 0.2864115619130673, 0.5429452657699585, 0.3157301451410017, 17.267791455791844, 58.75179036971062, 41.192045134882775, 49.67808908031833, 33.36769719277659, 49.80904917563162, 49.72837778829759, 40.009501518741736, 41.45298473296627, 44.07748183896465, 57.48438235252135, 78.57048742232784, 66.26045811560847, 92.4368896792012, 27.740441368472194, 0.3251026793112678, 0.15944849970119615, 0.12777804952835844, 0.16514489967976848, 0.10338316701592938, 0.19897852934175925, 0.19016646509689672, 0.19413703752140846, 0.2701603242706868, 0.15960493485533422, 0.10424511552217508, 0.16160497592101175, 0.18986222093864796, 0.14621465256617916, 0.12741195909198255], [0.04746438695057746, 0.12107863361316344, 0.02718875154612526, 0.021942638897246892, 0.04649497163031371, 0.020201874543882666, 0.033732812491155444, 0.03957509476270887, 0.046308896534385226, 0.038862307405760216, 0.03882289984293523, 0.11038386232910619, 0.0738184780423199, 0.11772817871983975, 0.026939252030945597, 0.017750843262840665, 0.0974703778422648, 0.4353333240555179, 5.400064789479779, 63.372632688091656, 66.47717691236927, 66.19430342028218, 53.982215696765536, 42.71605853111514, 38.678668775866115, 44.114540392352694, 36.6123680914602, 23.949462752188406, 40.27415560137841, 10.437428009125496, 0.041051671780165166, 0.2334643756189654, 0.07661629242882614, 0.21427990988858286, 0.7901653322962023, 4.013668976483807, 3.377781188295734, 0.06840166951259298, 43.412396907806404, 107.9912604055097, 93.16841956107848, 97.58615370719664, 90.37117342795096, 99.25978199128183, 88.1435574254682, 89.44348581375615, 87.84451592353084, 86.56277164336174, 81.22371981220861, 76.89467045568651, 82.65514173815328, 83.19045112979028, 87.77613332194667, 85.17191486973917, 84.3956542784168, 85.71073086031022, 83.97627445959276, 84.90484068470617, 85.53488316074495, 87.4073834573069, 87.43858198965751, 90.495481183452, 89.10471854671356, 92.0272530278852, 90.11750590416693, 88.01423688088694, 90.33298523195329, 87.24956297105359, 85.34289883029076, 84.8022863941808, 84.53219982885545, 82.3901620987923, 79.7021225960024, 77.2504686540173, 75.52541809697306, 74.66668575040757, 69.74321688375166, 65.9836878315095, 68.93808764796104, 71.31120004961568, 84.06278625611337, 83.24519957265547, 86.5499141139369, 74.43899216190462, 76.5135415907829, 80.08977828487274, 71.58383615555303, 76.07524810298797, 77.83327010370071, 79.01141674287858, 76.78838991349744, 74.53822812726422, 73.59480396393808, 72.98677382930633, 76.53973517879363, 72.12131854026549, 64.51872964059153, 62.971750767000266, 60.82440214772379, 62.89235807234242, 67.14519577641641, 70.89487967952606, 69.73983580066313, 72.8070665174915, 75.09205895085489, 75.7898093808082, 74.98728459881198, 77.04707022636168, 74.54597873072471, 74.89178272985643, 78.38320993608045, 80.48419613992014, 77.05126716244605, 76.5730204120759, 73.06546441970333, 73.33851629687895, 70.4299376087804, 69.42280630911551, 69.20568743059712, 67.6632781182566, 65.4347913495956, 65.30483145867625, 64.09572555172828, 72.09652916077646, 69.55102074530818, 61.85436948653191, 62.3061010145372, 66.4192670391452, 68.0187625269736, 70.7991660025812, 69.10014429400044, 73.35389983269476, 72.33235774501678, 77.07316183274793, 73.34732594028597, 87.85993083830803, 45.06664476087017, 0.5273314132805794, 4.565850688565162, 6.764560784063032, 0.38756676138408724, 0.11955056399587663, 0.05500180346350517, 0.06958054093223426, 0.012713799838938061, 0.07714277103302941, 0.09975055427921396, 11.498456597328188, 35.87877112050211, 28.385349627464052, 25.48317420867182, 14.319402671629383, 28.108677402619396, 37.256374205312426, 31.25009582888696, 28.34239967407719, 46.051869623122684, 55.970355310747706, 51.63799939617034, 61.19306572021977, 23.73355588605327, 0.24194424881810145, 0.013634284165868116, 0.08999458544196622, 0.047122604484038974, 0.19282744085836798, 0.03701379087062613, 0.03715114277457038, 0.0486404238448989, 0.03689841802922949, 0.04136151987158003, 0.02376353987793048, 0.01642815032673459, 0.08566819582014315, 0.028331936675033746, 0.03692914198543276, 0.0126331259924618, 0.031062438746073076, 0.02609462477266789, 0.029227476221539324, 0.08942198834472126, 0.025564624079232736, 0.06404973085849516, 0.06627638073217484, 0.03172269928449344, 0.09097864070246298, 0.015194390622538426, 0.021860895400506355, 0.023489902847476547, 0.1555104094046739, 0.011380156633564302, 0.032496285294332815, 0.035923268540852496, 0.35433996528867756, 11.973044756920109, 76.18078339484431, 75.62518750467609, 75.87286949157715, 68.62690248797017, 49.80950417057161, 33.539371490478516, 33.260412523823405, 35.7787859824396, 29.06245662320045, 37.01859228072628, 7.207818521607307, 0.057658362728092945, 0.13904693476375074, 0.18390384953348868, 0.24489060765312565, 1.3844911345551092, 1.6548092422946807, 3.2037029679744475, 0.4653983527133542, 62.99608122917914, 110.14010737019201, 99.96969961350965, 101.04151079731604, 96.84635546899612, 103.7365556532337, 91.66865425725138, 94.60140259035173, 92.80094054437454, 90.32845881677444, 85.42276613173946, 80.73211346903156, 87.39301189299553, 87.53397403224822, 90.81513866301506, 88.19823526567029, 87.07802203393753, 88.12225895543253, 86.56889054083055, 88.64113361604753, 91.0868412448514, 92.32434118947675, 91.96473044733848, 93.92726482883577, 91.76221847534181, 96.88753251106509, 93.26349781405543, 92.4922735460343, 93.66080253354966, 89.61455606645154, 88.90012771852555, 88.7571337915236, 87.88934076986006, 85.31432828595563, 85.10230848866125, 83.54246816327496, 77.78896301023423, 75.43309334785708, 73.10625706949543, 69.5635409508982, 72.60587246187272, 76.3294961375575, 86.43915422501104, 84.27883040520453, 86.29910207563832, 74.93583094689154, 79.52920098458567, 80.58695439369448, 75.11954692102249, 79.8819632684031, 80.66692367676767, 81.39346430378576, 79.87534230755222, 79.33399246584985, 76.26895043157762, 74.07465888607886, 80.19343083904636, 76.74962905145462, 68.11205217915197, 65.74938504926621, 64.61749884390062, 65.66153572451684, 69.81319196762578, 73.45049996529856, 72.72783464001071, 75.11179631756198, 78.31314071532219, 79.58921324822211, 79.25313672711773, 80.46682788479714, 78.68712302177184, 75.49048546821841, 81.49008012587025, 82.7483372534475, 78.71869025691863, 78.9950055460776, 76.41960082515594, 75.91818071180775, 74.69888056478193, 72.41166022516066, 73.28658411579748, 71.78404177388838, 70.55324908225768, 68.67863855054303, 67.76619326683783, 72.02074112430697, 73.84714572660386, 67.23849327333512, 65.82396891809279, 69.07488423009073, 71.651167561931, 72.64097767491495, 71.39325603362053, 76.44605328959804, 74.97857693702944, 81.0342771776261, 76.79894893400132, 88.70342085438391, 58.42993244048088, 0.5846234519154795, 0.6606138581710478, 4.637380011620061, 1.0287163478712882, 0.06629501199049335, 0.08123010291808075, 0.11467009362193847, 0.1008764966841667, 0.18153412507907038, 0.07787804690099533, 7.198050839285697, 36.94613825890326, 26.125446634907878, 23.883680682028494, 24.485888058139434, 38.78896582511164, 40.12199509528376, 35.87102836178195, 35.5158067518665, 56.673361716731904, 68.42415517376315, 62.47214671104186, 71.89301306201567, 30.445503957809944, 0.12815019972021544, 0.07567572031891154, 0.07162598036830464, 0.022372458272823886, 0.045098454631384344, 0.07547745676410776, 0.02558178444873662, 0.016346515997523264, 0.05482820027898397, 0.037594768969762715, 0.06832405714498413, 0.02753293569830637, 0.038389137029768004, 0.09053715189257938, 0.05813680378900421, 0.15165150195600527, 0.3136776117307525, 0.1301589665273505, 0.067799286916852, 0.13957236382749774, 0.14911336073231313, 0.15715749844187693, 0.16002145685976552, 0.1522530341941503, 0.1787894005857168, 0.20712690097430062, 0.21972440483589328, 0.09994733162344464, 0.20643193665291035, 0.12346810015339045, 0.1538268852257921, 0.18770916147097466, 0.47189744429722913, 15.900171783662612, 94.25450032757175, 87.79066178106493, 97.7559531119562, 77.1622153251402, 64.62532789476457, 64.35500598722889, 66.70445472963395, 52.43842963249453, 41.66480841175203, 56.765388365714784, 15.88276626602296, 0.11397868394851686, 0.42531966622317996, 0.341838666748616, 0.32255994156003, 2.3389659629714106, 11.23309942983812, 7.075171807119924, 0.33090450830997964, 61.00387803969845, 118.15068552570959, 103.38308734278526, 105.64303152022823, 99.38441922587734, 110.5793422268283, 96.61767344320975, 97.32994448754096, 97.42241044198313, 96.73721159658125, 89.17682739996141, 84.39006097855108, 90.11747452520555, 92.57559253323464, 95.15508436387586, 92.44665638093026, 94.0080499649048, 93.13449105908795, 91.15819700302617, 93.02325264100106, 94.1139853385187, 96.01325973387688, 93.82737775002757, 97.56352163130238, 96.08921250989361, 101.51773360467728, 95.97042745159519, 93.09487512034755, 95.83273656906621, 92.81470021893902, 92.16441046807074, 92.2829366499378, 90.7159419213572, 89.36121017702165, 86.87560419882499, 85.47601622919883, 83.56757133237778, 79.96277978343349, 76.56054727492794, 74.24766678963938, 78.06422710418701, 80.1848251588883, 89.50270575861778, 89.77035260969593, 92.42458128160047, 80.22557074023833, 82.44160790597239, 85.21488835734706, 82.6378676199144, 85.32125519167992, 84.65672723708614, 83.03751791677168, 83.61376116352697, 82.01108855585899, 82.14912460696313, 76.60221853563863, 85.73384931010585, 77.76170253753662, 70.40368910758727, 67.94961898557602, 67.03216875753095, 67.7106995736399, 74.49290121755293, 77.80262070317423, 75.83435181648501, 78.11631618007537, 84.03532182016681, 83.46038864504906, 82.624633542953, 84.36276128215175, 82.49760366255238, 77.64494142224713, 84.76907960830196, 85.32924113735076, 83.00756669813588, 82.8214188544981, 80.06621268487747, 79.93684507185414, 78.00713308395879, 75.91032812672277, 76.56776443604501, 73.99540347437706, 73.71111792902794, 73.40234894906321, 72.40223084726642, 78.31898504687895, 77.26189844069943, 69.4567269663657, 70.56343939996535, 71.77328663487589, 76.34766455619567, 75.70338387643137, 75.68130877710159, 78.9372133439587, 79.0302441197057, 84.30206652610534, 83.68652897496378, 94.83975718098303, 56.44491895552605, 0.5579449608922005, 12.505744791799977, 15.114347473267587, 3.2339388035958816, 0.48482370713064754, 0.22537370572888085, 0.39324727269911003, 0.14479893740386734, 0.3853857703506947, 0.7901132996043851, 19.41594612213873, 55.60197022653396, 43.18708812036822, 42.40036264542611, 26.40738268052378, 43.833792824899, 65.86338089358422, 51.59321769591301, 42.61297079824632, 63.97597166799731, 77.73929795911236, 71.5063379656884, 86.0372289534538, 41.25559537641464, 0.2942131561858039, 0.17128063576115718, 0.2429750507637378, 0.12826960218409378, 0.25150220690956043, 0.1807394161099388, 0.20850308599971956, 0.09624060754093433, 0.18586754738803835, 0.1568541582673788, 0.21337264728161598, 0.12149743855960908, 0.1542171150926621, 0.11204778997888488, 0.1673151654822211], [0.05132568459356985, 0.094890094121858, 0.0052340376667768486, 0.08260000602252061, 0.02921019902362699, 0.013829473792875727, 0.02440187306473813, 0.022217532311896646, 0.04970568442536939, 0.06037155887292278, 0.02570114286255933, 0.02612973266701785, 0.03693296859461454, 0.0734226250900857, 0.05114619402335056, 0.1283459351848691, 0.03004932002494893, 0.03787965791660451, 12.770025268677744, 69.89407124057894, 52.11866624893681, 68.59913210715018, 69.75528209440171, 43.68405634357084, 47.54568076902821, 37.60577894026233, 29.2672533758225, 34.81939777251213, 24.014797672148674, 0.740496849100436, 0.09851323801182932, 0.076012484909546, 0.15205498514396532, 0.22285851649940017, 5.760472753355581, 1.8218522014156466, 0.19757934635685337, 9.755181727870818, 101.74383471089025, 93.45225011148761, 98.68726499619024, 91.0022984781573, 97.58750300253593, 88.68727637875466, 86.2894687344951, 92.41272787893973, 90.63396438475579, 80.20924583558114, 78.26518581759545, 83.09867551249843, 86.34322089533653, 81.22343740155621, 84.21517818204819, 81.03987832223216, 81.23499270408385, 81.62017729974563, 86.45184701488864, 85.36309119193785, 86.47118429983817, 86.99227117723035, 88.42089253087198, 87.5549194889684, 87.5833252937563, 87.15291577000772, 89.36134353760751, 86.05748407302364, 90.08549151882049, 87.98986327263617, 88.39087855431342, 85.31585016558248, 84.91425437311973, 83.7773318444529, 81.6519328086607, 75.89380710355698, 73.08100485032605, 65.01203829242338, 66.38150245912614, 64.53126161329209, 71.23296445415866, 73.49176329951133, 82.37119351663898, 82.69739350964947, 76.57619753191548, 70.83074892720869, 82.20643827992102, 73.46841735224571, 72.47837189705142, 71.5301545973747, 81.27720525187831, 76.20412934210994, 73.71791147416639, 78.04631756198022, 71.01262138735864, 70.9523110235891, 74.00252649860998, 75.7884914644303, 68.65568484029463, 62.54744837360998, 60.79702008155085, 63.136482469497196, 64.67041161752516, 65.92162809064313, 68.47800147148871, 69.7077900363553, 71.42698841710245, 70.85698173892114, 73.78164214472618, 75.5871562034853, 71.81465195071313, 72.50066664911085, 75.95162283989691, 72.92782845035677, 74.74660796503868, 71.81549133793001, 74.67318904015326, 73.62171142332016, 72.2101523799281, 71.43118535318683, 71.55888203651675, 69.61835215168615, 69.30537054615637, 65.59643222439674, 65.56120541787917, 61.40164952124319, 65.56630842147335, 69.37070154374646, 63.88859302766862, 63.27845265788417, 65.72403477084252, 67.63628436673072, 74.41323003461285, 69.58448640761837, 72.08764106996598, 68.35539602464246, 78.2084212764617, 74.79471975757231, 80.76254321682839, 6.716053322438271, 0.4666173518184693, 8.294044906093228, 0.6592152880564813, 0.050028318524240493, 0.06343046751534266, 0.08760769295716479, 0.018907404286907088, 0.21975851107028224, 0.1934599536921709, 0.10395154296871155, 15.487415867467082, 37.45563061006608, 22.665853385002386, 18.089743737251528, 28.12922669995216, 24.461428157744873, 28.18872121072585, 44.95576720083914, 38.120805755738296, 41.71568939762731, 49.55686038540256, 57.91634121248799, 9.451531440980974, 0.24988827415772025, 0.03401374842430796, 0.08050547567226234, 0.05898907277432661, 0.07635562335171046, 0.054371971937437216, 0.07982591737902935, 0.04184515883905753, 0.040849098980787306, 0.02210260380149609, 0.019434666216012933, 0.09545286231103445, 0.054923444160170136, 0.0707611590323429, 0.034598296493171685, 0.036169477708397374, 0.07339460925469476, 0.037487731164982246, 0.026369322834896947, 0.040048720961016034, 0.1335279301049248, 0.04009436447954467, 0.01577146741892061, 0.09574311770378582, 0.05600353620285469, 0.06715177408149166, 0.0418854933682709, 0.028778927911433484, 0.03068029493724387, 0.016867015285477523, 0.0981129800540305, 0.06895709857945481, 0.23656548421469428, 19.953834472164033, 88.10740886196014, 63.41942264187721, 93.30686353868055, 92.26592140813028, 55.622798012148955, 26.521845286892308, 33.19251629614061, 31.214798419706284, 39.464496028038766, 19.075370642446703, 0.13537247064373187, 0.20508365254969368, 0.06938521149418048, 0.3633660132125501, 0.8382067673148648, 2.8024812715668834, 0.7154244460886525, 0.6477122633687912, 20.48767689735659, 111.14374776040356, 97.6080640669792, 104.55302838356265, 93.01958130251978, 101.30180712669127, 92.71216946263468, 93.87149656972578, 96.20923703716647, 93.81396324403825, 84.63994733748898, 83.74179517069172, 85.75605777002151, 88.43193008053689, 85.13338150516634, 88.00040660365936, 86.70485558048372, 85.4230171634305, 84.86163969962828, 90.6657277384112, 87.95312635360226, 88.3732121990573, 90.87431153943463, 91.51949436433854, 88.98811432623094, 89.97414327436879, 89.47241721614715, 90.01382981577228, 89.31102737303704, 90.61240703828874, 89.19010070062454, 91.58785343170167, 90.31148279866865, 88.31013264194613, 85.20126988810878, 84.43585857268303, 79.4745074549029, 76.97692255819999, 67.99547149289039, 70.48359563273769, 67.76909582076534, 74.35471611638224, 77.50106103958623, 86.07123590284779, 86.13149919817525, 79.38992546450707, 76.59485232445502, 84.71069905065721, 77.01212190812635, 80.50734596867716, 77.98567771911621, 82.00063936171993, 80.15001804597917, 77.78133792261924, 81.1085747134301, 79.0441999127788, 75.51902463359218, 76.40232670691707, 77.8990404067501, 71.55385355795585, 65.9172664150115, 64.41356697390157, 64.64572421966061, 66.64437186333441, 68.70247871645036, 72.15816528566423, 72.26661097618842, 74.51492140370031, 75.5159887190788, 76.39916527655818, 78.3502463371523, 76.39487420358967, 77.32075752750521, 78.17355140562981, 75.93153245987432, 78.51991238132601, 76.23834809949322, 78.7459115059145, 76.92914024476083, 74.82427873919087, 75.76351381117298, 73.46671504359092, 72.65114445840159, 72.47425340837049, 69.75649802915513, 70.6050165237919, 66.66848659515381, 68.35396043715939, 70.81549875197872, 69.25280294110699, 68.75743896730485, 68.34680603396508, 69.94077097985053, 78.62005833656558, 74.171494360893, 77.91962500541442, 71.33411453616235, 82.71145912908739, 76.52567740409606, 88.71055956809752, 11.568145348179726, 0.8931003991634616, 3.510215359349405, 0.8498018451275364, 0.07335838095675554, 0.0946135287203135, 0.08826190906186258, 0.07388410113391376, 0.8448947148938334, 0.1918411639428908, 0.09816705820060546, 9.5557007674248, 35.8517812913464, 19.225113007330126, 14.347181877782269, 41.151538818113266, 28.104078423592355, 19.38719907114583, 53.87810030291158, 55.09461556711505, 58.269346683256096, 55.79377805033038, 69.38560655040126, 10.922857599873698, 0.14618923376885154, 0.04736449291569091, 0.05009633947103735, 0.06493668447458936, 0.11473009362816812, 0.023123412130160198, 0.007660162471790588, 0.028168030248414126, 0.1372489723707399, 0.025107679445476785, 0.019762666760793617, 0.051838055688647494, 0.048724524977226416, 0.06134523747248515, 0.03160634010489429, 0.17501464023465113, 0.1624061200287073, 0.14779739021774263, 0.23421737876149917, 0.1309116172694391, 0.29473452498355224, 0.13953582143350957, 0.1630786992609501, 0.18869551499524426, 0.19641693050582565, 0.17617684158106006, 0.19796985201537612, 0.1369018885757654, 0.18875790519579766, 0.13849426361341632, 0.31498541574805017, 0.2642394452085418, 0.30811771329852844, 27.343879938125614, 105.62855797429239, 71.92949110461821, 90.42075218692904, 86.8155840904482, 67.79292814193234, 69.82421382780998, 57.64225382958689, 46.586269024879705, 53.94209377227291, 36.20352375891901, 1.9000189102465108, 0.3527446637951559, 0.24460982110711837, 0.24808557734133738, 1.054154757049776, 10.025043737503792, 4.517971296464244, 0.6340808625663481, 16.803561295232466, 118.30715671662362, 102.16753698164418, 109.32496824572164, 97.95480943495228, 105.08761605908795, 94.58996495892926, 98.12457746075046, 103.38308734278526, 102.07343932121032, 87.39343550897415, 86.32647237470074, 89.22293093896683, 94.85867869469428, 88.87493825727894, 93.93283459448045, 89.95847732790055, 88.48766696068549, 89.3253283346853, 95.56920036192864, 91.81773570276077, 92.23354616472798, 95.5651524759108, 97.46897682066887, 94.76386716288906, 96.48582689223751, 95.2861072171119, 93.05943258347051, 95.66376086204284, 96.71896473053964, 91.97411275679066, 95.4681444168091, 94.23072291958718, 90.69484741457048, 87.00907461104855, 88.17805859350389, 83.9901831842238, 81.02217274327433, 71.88197551235076, 74.06485296064808, 70.9249956377091, 78.75875334585868, 80.59974916519658, 89.6353054046631, 90.6953965463946, 85.71521020704701, 78.33686321012436, 88.54604751833024, 81.72843471650155, 86.65118186704575, 79.43628003520351, 88.56646737744732, 85.37592518714168, 82.04672721124466, 84.19318153012185, 79.15678762620496, 80.44530976203181, 80.166790100836, 79.8449831624185, 73.12366454832016, 69.344923726974, 67.8698536657518, 69.96647819395989, 71.00501198922434, 72.4011718073199, 76.38597826803885, 77.29340291792347, 79.3834457089824, 77.52126124597366, 79.15961957746937, 81.5719243018858, 79.01090683475618, 80.74872078434115, 83.0299477423391, 80.7034017193702, 81.28712884841427, 78.53837105535692, 81.11072417228453, 80.0868521967242, 79.54168981121433, 78.91717787711852, 78.80287216555688, 78.00652903895225, 76.3373722568635, 72.04615808302357, 72.20827748698574, 69.61512011866417, 74.15861329724713, 75.67153423063218, 71.0670481958697, 72.98340843569848, 73.00421268709245, 74.3207876143917, 82.67182750086631, 75.6898360098562, 81.33482486970964, 74.13333754385673, 87.20047843071723, 80.05798355225595, 92.10344114611226, 9.829227251391258, 5.9185099505609085, 25.290844709642474, 3.42576967131707, 0.45044272296851684, 0.2588712832620067, 0.4169477041690581, 0.10714169396387954, 2.2808651193495724, 1.1084779904734705, 0.3957070278063897, 26.220848483424035, 57.2540960773345, 36.174686493412146, 29.534337366780928, 50.97686429177561, 32.42136263078259, 37.863870897600734, 67.45208986343877, 55.82833413154849, 63.849381093055975, 67.38926133801861, 83.69904133581346, 20.13299265215474, 0.35031886170468024, 0.148199463803922, 0.26293783118167235, 0.16945117183269995, 0.20266145107246217, 0.1408845498677223, 0.16773910321775945, 0.15356609357460854, 0.2525878913940922, 0.11571673826584894, 0.09076979747342487, 0.11740979257850878, 0.1511031208980468, 0.22481769443519656, 0.1315324396015175], [0.03478252914764228, 0.014534313945219883, 0.046128433032502095, 0.06255720772089497, 0.05283341840690663, 0.05331180967210282, 0.03329633006585702, 0.0509172065123435, 0.07942877739908234, 0.013629884905962935, 0.04365947337881212, 0.11101820611304815, 0.05163542160223569, 0.0676337736208112, 0.021739236807690996, 0.07642873878320379, 0.11554262946329771, 0.359669455116795, 15.03565590227804, 68.94259052891886, 59.29259892432921, 46.00373037399785, 30.15322069967947, 27.86577090140312, 47.501922807385846, 45.099565213726414, 36.79239311525899, 44.1423656863551, 3.0105784535408024, 0.08919632182486596, 0.12884586118161678, 0.11743721852619803, 0.3615384338603866, 0.3532307006178364, 1.3784112156398836, 0.47391311355656196, 0.1709133885320156, 60.50545069479174, 101.42844477007466, 94.16069292253064, 92.84918569749402, 93.5801350685858, 92.84906018164851, 87.34144841471027, 88.6235535529352, 91.15492574630245, 81.90483939263129, 80.74917577928113, 78.35736936138522, 79.38049608661284, 76.37343452822778, 78.65499881006058, 79.46841993639546, 78.9926835029356, 79.69790997043734, 82.11156399019303, 83.29474695267217, 83.54338599789529, 81.10094962581512, 83.97254820792907, 84.98774390066825, 84.72462346476894, 83.77465678799538, 84.52386871460946, 84.20924755834764, 84.6664390256328, 85.39806304439422, 84.36596978095271, 85.75091162035542, 84.59835452418174, 82.79542922973633, 82.97388138309603, 77.12097552514847, 73.47466961030038, 71.36017476358722, 68.97757022611557, 65.00054967018866, 68.24485578844624, 71.89134213232225, 78.3858222346152, 81.30756439701204, 75.62113177391791, 69.19515978905463, 82.10186789112707, 78.63794434455134, 76.67588064747473, 71.9468044465588, 78.90534016393846, 77.44548889898485, 78.23869412945163, 69.59295872719058, 72.15386636795537, 77.9677838663901, 71.05956431358092, 68.12738864652573, 74.9931053961477, 74.76018721057524, 66.3114018594065, 61.958116177589666, 60.411988458325794, 61.66467189788819, 64.33502543357112, 67.87010469744283, 69.08249362822502, 67.31247701952535, 67.63894373370756, 70.29136811533283, 71.71974628202378, 71.27554570474933, 74.6336829277777, 71.29358860754198, 71.90732186840427, 72.23181170801963, 73.77338163314327, 71.27673810528171, 70.56873459969798, 68.27148868191627, 67.50352782587852, 67.8225734156947, 65.35988976878505, 66.53326680583339, 65.61016444237002, 68.52856082300987, 66.20455649591261, 63.254169264147365, 60.48461114206622, 65.06280552956366, 60.22251052241172, 63.627735799358746, 65.59342376647457, 67.57724485089703, 69.24785290994953, 72.92318436407274, 67.78378901943084, 72.19836173519012, 70.76504138208205, 81.71745992475941, 27.408430384051417, 0.1656315646945469, 3.2177730000788167, 0.6326463169628574, 0.10586214326922933, 0.06214324445013077, 0.06021310890754385, 0.09004903897162407, 0.10803580284118654, 0.0110631954157725, 0.05768317631596039, 0.11840522424468111, 18.57120683116298, 31.787285997021584, 42.868850538807536, 18.894268928035615, 33.54228581151655, 45.58359353773056, 30.56763479786535, 29.002361989790394, 46.56520589705437, 50.24742895557035, 59.42269609820459, 7.832070598679205, 0.22494613673658143, 0.0538914279651738, 0.07664074595536917, 0.012252238567828411, 0.10871608125706834, 0.035547073404755325, 0.04080015745374464, 0.034007531620802424, 0.01875704612522837, 0.020684090503040823, 0.057780921474219336, 0.09608778832179886, 0.05677717392362895, 0.02439905960683621, 0.0362456881351048, 0.10880858637392522, 0.08205650494463983, 0.033957666957811, 0.07080522440974751, 0.07218410606465994, 0.03060444840230048, 0.048432507582249186, 0.053786351345479495, 0.027654607697660406, 0.07595869021550303, 0.0870390105692129, 0.018421984165005626, 0.046603537780503114, 0.15206474510412063, 0.07018348277215997, 0.14800660882986363, 0.18367923255408966, 0.38848284932394184, 26.468699132242513, 79.04120322196715, 77.77267732927876, 66.62819600874379, 43.187852982551824, 28.402472734451297, 43.209731963373, 50.312830555823545, 37.641786298444195, 36.48604816006076, 1.546218178925976, 0.02111657203415469, 0.09258964699843238, 0.09415163132812708, 0.42402666302457936, 0.7060873664675221, 0.7582976068219831, 1.1206645494507206, 1.3464463502168658, 76.43722795671033, 105.17428475041544, 103.3272877047139, 95.07430707254719, 97.1812552790488, 95.51169841520249, 93.93526646398729, 91.13764378332323, 95.56136346632435, 83.91371265534433, 85.59954735540575, 82.26072388310587, 84.15602099510932, 81.54924515754946, 82.8235447791315, 82.17596146368211, 84.00126780233076, 84.45658437667355, 86.26607571878742, 85.87231682192895, 86.74513832215341, 83.62461828416394, 86.74023535943802, 88.29554926964545, 87.30188738915228, 86.47932714031589, 88.20091816686815, 87.682631861779, 88.64980205412834, 87.3315248181743, 86.90687333383869, 86.98296731518161, 89.87987302964734, 85.49039563825055, 83.98237766758089, 78.89362796660393, 75.47958127913937, 74.2267370223999, 72.45215477481966, 69.75847490372198, 71.12978258440572, 74.28175218643682, 78.9988180898851, 83.89533242871686, 74.77360171656456, 72.96962522691297, 82.28760780826693, 80.2017697980327, 80.04582420472177, 74.37882300346129, 81.65929901984431, 81.24008394056752, 81.23801292911654, 76.14124590350737, 73.19833078692037, 79.98918517943352, 77.50204947686966, 71.67887518482824, 75.91386610461821, 76.57963352818643, 69.43323981377387, 65.10989358348232, 63.97953318011377, 64.16006811203496, 68.43418075192359, 67.96093110115298, 70.91585651520761, 70.28442552012783, 72.44401193434193, 71.8769548785302, 75.89550941221177, 73.5344700659475, 75.1325221215525, 72.60756692578717, 72.53201423152801, 73.5694811421056, 74.86484389151298, 73.27060437971546, 73.16866982367732, 69.28153038024902, 70.50335653366582, 70.27995401813139, 69.63357879269508, 67.7205604122531, 71.00578077377813, 71.52358070496591, 69.1046001065162, 66.27708896513909, 63.245469447105165, 67.50616365863432, 64.20504985317108, 69.31217193603516, 70.93405631280714, 72.20192324730658, 73.63680470374324, 76.24297649629655, 73.03726257816439, 74.46638599518808, 73.57805544330229, 87.65958401464647, 39.506410475700136, 0.4685610088129198, 1.5653982013463976, 0.4198305236716425, 0.11823014251046604, 0.10542524332601218, 0.09653827866479274, 0.3144178058831923, 0.5356879003586308, 0.0734553600270902, 0.04346334337887745, 0.0991529903765167, 18.134117511010942, 31.969278089461792, 27.3476081509744, 17.549268584097586, 42.69951005135813, 33.00653319205008, 37.241794755381925, 34.824155607531154, 54.64922651167839, 58.77311237396733, 69.61146446966356, 11.184774848722643, 0.315052708911319, 0.05455184172117903, 0.02322403586379463, 0.0302854685428282, 0.09745144014877659, 0.06092118865419781, 0.05700038130124731, 0.024803188223872456, 0.035040539899660696, 0.03923022113139591, 0.06122888786898506, 0.025275144350504684, 0.14045114328543987, 0.021166099618459423, 0.03185328471684649, 0.2000621453888955, 0.1498970227135766, 0.15610970466608004, 0.1226086644155364, 0.1413833956804968, 0.16280710577003418, 0.13051581028248035, 0.16718152910470965, 0.15174364701153772, 0.1577136323096291, 0.23285456963123816, 0.15126344777884024, 0.2467060062072931, 0.26863207079229817, 0.11805544382021313, 0.2063844851668804, 0.34010764511842884, 0.5334119450661444, 33.77292117764873, 98.25891079441195, 83.81943456588253, 68.60660814469861, 44.840112193938225, 46.20718763720605, 65.00212646299794, 66.34889971825385, 55.951139619273526, 62.13932967955067, 5.417046691140821, 0.18856287453203432, 0.25164356545334865, 0.3715332152862703, 0.5874149537374896, 0.6937426869427005, 3.1714434344922346, 1.66650905964836, 1.3445042866852976, 75.94460964202881, 110.95563873167961, 104.94852881277762, 100.69868779951527, 100.1633156499555, 100.72702300164008, 98.44717671794277, 94.89770627790882, 101.72975340197164, 90.46425127214002, 89.53059381054294, 87.85516908091884, 91.4871975683397, 84.08054674825361, 89.45263278099799, 88.72624120404645, 88.5683971835721, 89.10650714751213, 90.10299313452937, 93.1160794534991, 90.5173444747925, 87.2957371127221, 91.1360199220719, 93.11842503086214, 91.1017462515062, 91.1349138136833, 93.60758381505167, 91.5217536495578, 93.34910746543639, 91.72318304738691, 91.16659871993527, 91.76572507427585, 91.43360230230516, 89.19086948517831, 90.24507707165134, 84.13579725450086, 82.38011298641082, 77.56053201613888, 76.93397260481312, 73.37435107077323, 76.54039413698258, 77.90217830288795, 84.45647455030873, 85.18940079596736, 80.82403813638996, 76.91705934463009, 86.4931966412452, 83.51497234836702, 84.383753807314, 80.00660834773895, 87.4076109547769, 82.04508766051262, 84.51110532206874, 77.12321127614668, 79.6745797126524, 84.44231479398667, 79.64177300853115, 76.17593534531133, 79.89324400501867, 79.16038836202314, 72.32054356605776, 65.49060667714765, 66.59185917146745, 67.46903450258317, 72.08564850591844, 73.07366217336347, 75.51194867780133, 73.63728323290425, 76.3378978544666, 75.062743156187, 79.50365851002356, 77.63482170720255, 80.62428751299458, 76.57863724616267, 77.53656633438604, 78.12186241149902, 80.04660083401589, 76.60008476626489, 79.13182566242834, 73.86826376761161, 75.89698422339656, 73.16668510437012, 70.31434535980225, 73.6380127937563, 74.76089323720625, 75.66761186045986, 73.2277956316548, 69.00807842131584, 68.20644009497859, 71.75511821623772, 68.33776104834773, 69.09391557016681, 74.35926606578212, 75.22229733005648, 76.94935614062895, 79.30080921419206, 76.00717929101761, 77.49784469604492, 77.91141940701392, 92.03881617515319, 37.97643115443569, 0.4282606471209757, 11.218634709235161, 2.8107626207413214, 0.29226885567749705, 0.33658428418059505, 0.2366290388688926, 1.0750616029385598, 2.2142647447124606, 0.23363116828183975, 0.20090130277939383, 0.7735259638678643, 34.76736753217636, 50.49605623368294, 59.52522685450893, 31.87887530173025, 57.55903290164087, 65.7438466625829, 48.04550840008644, 42.9906322879176, 67.06616001744425, 66.69998322763752, 82.84135233971381, 14.119390230025015, 0.4268805856906599, 0.13999253241044862, 0.3679439707869484, 0.16091918933295435, 0.23249035611027674, 0.13298276661624833, 0.229142076906658, 0.06026982239657833, 0.14488221116123662, 0.17194943051905404, 0.16810708589130835, 0.23466342579453225, 0.18258268494279156, 0.14487485671716352, 0.1254296836052691], [0.10599608608191052, 0.03629671725174112, 0.014327595652561757, 0.06325727418786095, 0.03695031665565987, 0.04560584998539379, 0.04570319294749249, 0.10829531512553654, 0.04354757474615209, 0.07805732679703543, 0.038109606867956544, 0.08631414583613796, 0.046508454777781046, 0.02334318360343816, 0.06807992790615366, 0.10386032487956748, 0.07424215530796398, 0.27164812830667345, 29.679882795579974, 66.5800214582874, 43.820127287218654, 42.15246100579539, 39.78204327244913, 42.67254375642346, 32.63199390903596, 27.138010417261434, 32.95777420843802, 7.500370952390856, 0.021419398929743518, 0.10535638734337785, 0.09125424849410212, 0.04779162140743387, 0.4553947459545828, 1.2292666444855354, 0.421432321590762, 0.6605775149599199, 8.864492850918925, 96.38133495084702, 89.58441657404747, 100.0006784931306, 88.34129979533535, 91.27440898649155, 89.50037587073543, 90.7919260763353, 86.09402487354895, 84.88893155128726, 81.46915035863077, 78.90687773304602, 75.96379787691178, 79.9860865069974, 77.08281086337182, 77.27554044415875, 73.17674206149194, 79.20957488398399, 76.99395348948818, 81.36259525052964, 79.25917717718309, 79.03437045312698, 79.13628147494408, 79.7447979834772, 78.20088248099051, 82.58406839063092, 83.35381784746724, 81.91364119129797, 81.59716867631482, 81.9722649358934, 81.70290008667978, 81.73288268427696, 79.90762341407039, 86.7427299868676, 80.16800603558941, 77.13817904072424, 74.47589382048577, 72.13436434345861, 67.55504423572172, 66.24263486554547, 65.073921526632, 69.50742752321305, 72.78807440111714, 76.30185127258301, 73.39124864147556, 64.44928799906086, 73.87720677160448, 73.80697281129899, 76.62071643337127, 78.87651858791229, 69.1876837515062, 75.95446263590168, 76.94338629322668, 77.73493628348075, 75.1260188318068, 68.24221995569044, 68.85316048899006, 75.5720393888412, 71.45202882828252, 66.90404061348208, 66.47131689133184, 66.12035889779368, 60.86080174292288, 58.39658052690568, 57.41707055799423, 60.679517638298776, 61.16160438906763, 60.25354431521509, 59.10862799613707, 62.27484364663402, 63.593171873400294, 61.89057296322238, 63.42650252003824, 65.29377821953067, 64.48712318174302, 65.63649531333678, 65.17131790038079, 66.38208296991164, 65.63624035927558, 64.44344758987427, 66.39707426871023, 66.78992317568871, 66.50111905990109, 67.92805379436862, 66.77193518607848, 68.295132729315, 66.65263237491732, 64.0590984590592, 66.58132368518461, 61.90440716282014, 62.16369936543127, 61.145742324090776, 60.564184265752, 67.5305921800675, 67.71973671451693, 69.28466043164654, 68.78308342349145, 72.61519985814249, 70.74900673281762, 69.35759298263058, 76.87291699071085, 59.605145146769864, 2.664445955907145, 0.4206116575627558, 0.7621113150831192, 0.03555626262940707, 0.1373507548123598, 0.06375988149234364, 0.32366568222641945, 0.06054419295621976, 0.1099430553374752, 0.06774408262102835, 0.08390492188834375, 2.230336166197254, 21.21145421458829, 35.94733415111419, 34.69592548185779, 27.043247915083363, 31.603150329282208, 35.50550268542382, 53.28290416348366, 60.76855544121035, 50.05513083550238, 52.38256331413023, 7.714789769341869, 0.39134403450354455, 0.06068364394107654, 0.09652702483318507, 0.046351326314071496, 0.08128146911340375, 0.03022702561030465, 0.0862018296855592, 0.05690210371188099, 0.1455727015291491, 0.04185529801273539, 0.05714092396139618, 0.019767983410988125, 0.033424780028121125, 0.07708909891305432, 0.041309996628232544, 0.13419102516866502, 0.055218104558486136, 0.024191045667976144, 0.019026891020457112, 0.07149098035428794, 0.052112368791694605, 0.026555633502862146, 0.03552028714048286, 0.08739331091243414, 0.02399164255738499, 0.006504617950638697, 0.05524852207951969, 0.027775253139195905, 0.0465979683212936, 0.03944877069443464, 0.10979515440281361, 0.059696692868226, 0.854243316477345, 44.37785302439044, 79.55296270308956, 65.1940558802697, 62.73725186624835, 48.34659737925376, 32.991867449975786, 40.45016804049092, 30.170069240754653, 29.305202307239657, 5.077872478192853, 0.1721551557702403, 0.2535104910813032, 0.04296042963922505, 0.0988783018903867, 0.5511351134027205, 1.3808146479629702, 0.8576409470650458, 1.030433978284559, 14.039339557770761, 105.04455627933626, 93.16427753817652, 104.69443767301499, 94.25475920400312, 96.75792171109109, 93.79667343631868, 95.95713846145138, 91.00473819240447, 88.28829288482667, 85.28880150087419, 80.92483520507812, 80.11241820550735, 84.63797046292214, 80.84944725036621, 81.46635763106808, 78.8037900001772, 82.59367819755309, 79.62314959495299, 84.33184516045355, 84.13121592613959, 83.4951957579582, 81.66646911251931, 82.13672207247826, 82.28701945274108, 82.99640363262546, 84.72085014466317, 86.0072934242987, 84.48557069224697, 83.31628076491818, 84.78647139764603, 84.32717753994851, 81.96199617078229, 89.45037349577873, 81.63598445154007, 79.36388877130325, 78.12557297368204, 73.31255020633822, 70.1572387449203, 69.93826850768059, 69.1298915493873, 74.16428504451629, 77.36901052536504, 78.67706606465002, 75.49646316036102, 70.45137728414228, 80.06629897702126, 77.9142278240573, 79.38754066344231, 80.64707648369574, 77.1212814700219, 77.99761741392075, 79.416260257844, 82.62818721032913, 79.90112796906503, 74.1581347680861, 70.79223125211655, 75.77274707055862, 74.11901304798742, 70.06334504773541, 68.26802130668395, 67.07322812849476, 63.47041345411732, 60.356992906139745, 61.84336331582839, 61.91166354763893, 64.15540441390007, 61.83793083313973, 59.830163678815296, 62.5794235352547, 66.86944530856225, 64.75124774440643, 64.65535756080382, 65.2932212429662, 67.68951092996906, 68.0397315179148, 67.85841603432932, 68.97567179895216, 67.47134870098483, 67.87274053019863, 70.00290132338002, 70.02834181631766, 70.24826911187941, 70.52871857920002, 70.42356767962056, 72.77009425624725, 69.17078618080386, 66.82148256609517, 70.54582011315131, 66.14447362961309, 64.5275471287389, 66.45225417229437, 63.224790711556714, 70.61918412485431, 69.43484798554452, 73.42021926756829, 71.48850687088506, 73.5351368688768, 73.37457072350287, 74.73093417383011, 76.19227593944919, 67.82964937148556, 5.8014070987701425, 0.26042592080850757, 0.8697308563897688, 0.13317234273399078, 0.2916787534711823, 0.05598508880563802, 0.4931532892007982, 0.1311043190259126, 0.042995926323196584, 0.14480552576001615, 0.010298960466658878, 1.251883643769449, 21.122553694632746, 34.85685640765775, 25.898547326364827, 30.623254006908788, 31.499238898677213, 28.74790018604648, 64.2411199692757, 64.03345008050242, 56.60557139304377, 59.608459549565474, 8.733302316358014, 0.5533025906451288, 0.13890367632191028, 0.12032124078682355, 0.025382182155285152, 0.07870490091942972, 0.05516614081458219, 0.08871649797525137, 0.08444322889009792, 0.12019826835321805, 0.027521641647082665, 0.06278646719311515, 0.06973356699510928, 0.07314149380451249, 0.011375523716842216, 0.03435158170759678, 0.21752717273850597, 0.13933469270986898, 0.11151352026049169, 0.14071987160751898, 0.15731306025578132, 0.11994631735668068, 0.17284805165423503, 0.23686246585942086, 0.1903424661366209, 0.0956184751985054, 0.09465161095102949, 0.1346706881398155, 0.1909298717134422, 0.22589861385283933, 0.14274222115355154, 0.31286353605889505, 0.17303805678121506, 0.8025976522795616, 53.650967613343276, 92.88163154355942, 67.5677840940414, 61.98365865215179, 62.884144629201586, 60.385747801872995, 50.34624914969168, 44.64808079504198, 50.199195569561375, 13.777824351864478, 0.6676372909738172, 0.3592244806068559, 0.27068438969792863, 0.22850930360296082, 1.7465449004404008, 3.7954052561713807, 1.6581181292572331, 1.9201908020242568, 12.7668648189114, 107.72107970330023, 96.63549669327276, 110.61445528461088, 98.26446487057595, 102.37131980157669, 100.80930648311492, 100.42927588185957, 95.30531898621591, 95.70530660690801, 89.59782323529645, 87.60813820746638, 83.18642677799349, 90.72537129925144, 85.67514711810698, 85.19194249183901, 80.97183304448282, 88.02787888434626, 82.61682018156975, 90.67837345984675, 88.01859071177822, 87.38927779659149, 86.24302787165489, 86.71622260924309, 86.70175690804759, 90.70306085771131, 90.43903827667238, 92.15794640202677, 88.20590742172735, 87.05411126536708, 89.23678475041544, 88.1901865620767, 85.28298854827882, 95.2557716061992, 86.08385809006231, 83.82837756987541, 80.81467936115881, 79.42534446716309, 75.41678413268059, 74.52981856561478, 73.04873158854824, 79.01922225952148, 81.32090045559792, 84.48359381768012, 81.68367262809508, 72.31345192078622, 80.90547438590758, 79.1921595604189, 81.1234797200849, 87.77008502714096, 79.63305750200826, 81.46001123612928, 81.73771504432925, 85.9316465931554, 83.22907078650691, 74.37861119547199, 76.29956845314273, 81.74240619905534, 77.07409535684894, 74.24861600322109, 73.52868849231352, 72.7591900671682, 66.3403489512782, 64.16451215744019, 64.92664044903171, 68.79001032921576, 68.6557319087367, 65.54542180030577, 64.79335046583607, 68.60286620355421, 72.46074476549703, 69.31412527638098, 70.14192581176758, 71.70386852756624, 72.51679543525943, 73.30220299382364, 71.71314885539394, 73.49172407580961, 71.00553758682744, 71.16442495776762, 74.14283752441406, 74.65464407397856, 73.84277620623189, 74.97318760041269, 73.75900222409156, 75.82917428785755, 73.70247302516815, 70.30850887298584, 76.22636918098696, 69.90082556201567, 67.77568540265484, 71.60086708684122, 66.07884453188989, 75.66109288123347, 72.25211389603155, 76.50802673832064, 73.5534700270622, 79.95382108995992, 77.38633955678633, 76.8125674032396, 82.3621093073199, 75.38276149380592, 5.733189727029493, 0.8534673000535659, 2.393873997272984, 0.498143831087697, 0.5264078789661008, 0.24885967854530583, 1.0660247072096796, 0.4034746997058392, 0.2892516643529938, 0.42563376227213495, 0.20902324437854752, 5.326030052477314, 37.32758091342065, 53.8054423178396, 52.952307193509995, 42.76103242751091, 45.82249726018598, 52.00145013870732, 76.86862591774234, 81.94545161339545, 70.47418978906447, 74.0901679377402, 12.309531165707497, 0.8046811049984348, 0.3099770699777911, 0.1935990139721863, 0.2352680377061329, 0.19009980012572583, 0.17145490544217248, 0.2698613661191156, 0.22336071777728297, 0.3537477793232087, 0.1528766297645146, 0.15271613434437784, 0.23182107105610833, 0.09130082663989837, 0.17432548285972688, 0.10071443078378517], [0.019997692959863814, 0.05150041009690012, 0.07777076394807908, 0.07863559294492006, 0.01916892372161871, 0.03389403186438065, 0.0340716187061081, 0.04368687634386363, 0.07931005675345659, 0.06641784652827248, 0.014900130505162864, 0.02593247077217506, 0.03372109517635357, 0.03326044650748372, 0.07294145292572438, 0.06710922555817712, 0.20502628788592356, 7.341753734696296, 61.40470504760743, 45.866157162574034, 42.801511287689216, 37.24528958720546, 37.51309333309051, 47.49210903721471, 26.976649991927612, 31.571310489408432, 17.067122997776156, 0.22791164776971265, 0.3999186114918801, 0.16482609985095842, 0.1972709959673305, 0.05252137547358871, 0.51951578427707, 1.7337757469184938, 1.1689599579380405, 0.6521357776176545, 32.36842240056684, 104.63298982189548, 85.91014415987077, 98.51129178077944, 84.8212863552955, 88.58539673589891, 82.39419429532944, 90.73055667261924, 82.09667467301892, 79.56967984476398, 79.89635052219515, 73.79988116602745, 76.08934510138728, 78.34127979893839, 75.46337404558736, 78.92416754076558, 78.5662591072821, 78.6936027772965, 74.45968658693376, 75.29997594894903, 79.25556859662457, 80.38619964353501, 75.88320101461103, 77.18971898478847, 76.5370758118168, 77.39620039539953, 75.93273270514705, 77.88300575748568, 77.22243939676594, 77.76089452928113, 78.23650544689548, 77.05859414992794, 74.96135773197298, 73.50192223825763, 71.23834594603508, 67.87952623059674, 67.2931868030179, 64.14165650644611, 62.2922589701991, 64.91845446248209, 61.36614030407321, 66.16114370284542, 67.93051704283684, 67.26282765788417, 67.47760880377986, 76.50539090556484, 78.45384397814351, 80.83327139577558, 78.6759364220404, 69.45929219645839, 69.40819940259381, 74.53756916907527, 76.51583225496354, 78.97573101905085, 77.46534393679711, 75.35232390126875, 72.95669709482502, 67.58098679204141, 71.39433860778809, 69.7479158832181, 63.68522597897438, 61.668445217993956, 56.91018266062583, 56.91361473452661, 57.09987240452921, 56.25510369577716, 56.247702183262, 54.45082518362231, 54.81426415904876, 56.988614374591464, 54.77078076331846, 55.82854201716762, 56.267027701101, 54.394903952075595, 58.52810544352378, 61.385175566519464, 61.42472090259675, 61.44411702309886, 62.420241986551595, 62.26022497300179, 62.3156362964261, 61.94208152832524, 63.656871164998705, 64.02184378716254, 65.09970326577464, 65.69764898669335, 68.1326053988549, 66.06284126158684, 63.78359510052589, 61.61470874663323, 59.85167787921045, 64.08580587756249, 62.29287085994598, 63.889597154432735, 65.26674524430307, 70.12323964026668, 69.54634528006278, 70.55213512912874, 67.07990400252804, 69.41445166064848, 69.83554947760798, 63.59709424357261, 14.9343861879841, 0.1752063307550646, 0.043064667392642274, 0.21206819872942664, 0.07351502295463316, 0.06650393182832388, 0.06766588802659704, 0.1265559630889085, 0.03475779216856726, 0.10175109330204227, 0.16323023145237278, 0.06400194612421817, 5.4786303543275405, 28.04309537333827, 37.007068357160016, 28.682241670546997, 26.167588580039244, 47.527488816169004, 29.915850623961422, 56.88323989991219, 45.36263858118365, 52.69024579755722, 5.41330720147779, 0.3691191190192777, 0.050286233515268376, 0.050027640536427505, 0.05351234084716248, 0.05169157201664583, 0.04266119186556147, 0.057043795503916285, 0.03766803378840128, 0.06305178642393121, 0.018435660749673843, 0.10757839472423639, 0.04842864649911081, 0.036801852646373936, 0.058163973097238815, 0.045602980986117356, 0.011993069107824517, 0.0329235440210229, 0.030307817242799268, 0.12082870508874617, 0.019246388617302143, 0.03528678354116217, 0.09926123860021753, 0.05130271727759993, 0.10217143042433648, 0.07631492876117268, 0.04188502605463709, 0.08985753231231244, 0.0903751319574733, 0.0636250002219552, 0.04897033960949029, 0.0706727295032432, 0.3421051121286808, 12.550043059933571, 75.73063650438863, 55.353864623654275, 57.21129125164401, 46.32388991694297, 21.93518642456301, 43.48475287037511, 29.286235686271425, 25.49574540507409, 15.388899657034106, 0.3100106552723916, 0.768870355621461, 0.13353704655122373, 0.43815743057958545, 0.0584771191971677, 0.8026890312471698, 0.11150379860473257, 1.2807016651476584, 0.5447538461415999, 42.9185861925925, 109.89518673189225, 90.58409537038496, 103.25046416251891, 88.65515216704338, 91.46075294863795, 90.32681142130207, 95.01387119293214, 87.0954530469833, 86.22085079070061, 81.43097000737345, 79.88677209423435, 81.31143969874229, 81.16021663911881, 81.36741976584159, 82.41037014992007, 82.39828924978934, 82.49701530702653, 79.14205520383774, 79.4023907569147, 80.95411962078464, 81.84991836547852, 80.06458097888579, 81.9158063396331, 80.46512557614236, 80.24014626779865, 77.85120318012854, 81.86026557799309, 80.18560963292276, 78.74740200657999, 78.51251479118102, 78.48801566708472, 76.76894280218309, 73.14171529585316, 73.35998735120221, 68.70536558089718, 67.2472244693387, 66.70886347370764, 64.82032460551109, 66.45117159812682, 64.24938048085859, 68.70172562137728, 68.68027810127505, 66.77926217356037, 72.09113982415968, 82.00596594041394, 83.34190168688374, 82.99378348935036, 81.53747804703252, 71.64068698883057, 71.37797447942918, 77.30850404308688, 80.01348818502119, 80.30914860387003, 79.99728879620953, 80.79933504904471, 79.23258350741479, 71.9476124548143, 75.12444988373788, 71.80459499359131, 68.70581273109683, 65.12524574033677, 60.61426116574196, 60.406230418912834, 61.24690417320498, 60.71735282098094, 59.63137795848232, 56.55730270570325, 58.79910592109927, 59.98567781140728, 57.657484392966, 58.235245596977975, 58.13279328807708, 56.66704277838431, 60.07468423535747, 63.74965090905467, 64.5393063945155, 64.89491239670785, 65.5419034342612, 65.65548350734096, 63.90465905589443, 65.90181227653258, 67.81450117788008, 66.07456130366172, 66.96179359189927, 70.49519015896705, 70.52409018239668, 70.13739155184838, 68.409697317308, 66.35786625646776, 64.09278769646922, 68.08484661963679, 66.06389245679303, 67.32425197478264, 68.71962731884372, 73.58179738444667, 72.75590312096381, 73.34725533762287, 69.4364090888731, 73.09097551530408, 74.96007119455646, 73.31298951179751, 24.300293268695956, 0.20710313692688945, 0.1349093858152628, 0.15524272296217181, 0.16852221361571745, 0.13672401828150596, 0.11637191964133133, 0.04106854486669745, 0.09440454759544904, 0.024657600874742194, 0.07198609531887117, 0.028928772794202934, 2.907031067917424, 25.719116541647143, 34.1188467702558, 26.60226760372039, 30.699426435655166, 33.22071813767956, 36.75871172258931, 72.36652158921765, 57.8213414069145, 63.309953212738044, 10.588942304734262, 0.47977874235760787, 0.14240033143470365, 0.07292075323001032, 0.0620153192580948, 0.12033808706027847, 0.03091132598778894, 0.08889835192671708, 0.025500540824366674, 0.02770881033352306, 0.03183407314692534, 0.07480815638818088, 0.028863212904862823, 0.06310410256828032, 0.03764917270370549, 0.046350797713403745, 0.07241428484238925, 0.18182482480281786, 0.10983762631733572, 0.48748767063502346, 0.14387039287436393, 0.147000030584393, 0.1583186885522258, 0.1503489992671436, 0.18906559674970566, 0.16135869397511407, 0.1472357711604526, 0.17961938024288227, 0.11817779572259997, 0.17047422096854256, 0.251558008753965, 0.18602821134751846, 0.49326467838498855, 12.772424778630658, 88.23431322651525, 65.71132629148423, 64.29124786007789, 52.1472877840842, 51.68771151573428, 68.3071194925616, 46.229670663033765, 44.95223314531388, 33.11607322385235, 0.8909656491971786, 1.2008312993472623, 0.26218645214553804, 0.8943044442322947, 0.2760042574617171, 2.303679585456848, 5.495291111930724, 3.914895360508273, 1.4165523431954847, 41.920060573085664, 116.96267804791852, 93.82354951673939, 110.24156339706914, 93.76265079744401, 100.06148307554184, 92.57090137850855, 102.25518626551475, 89.56196492718112, 89.35076882762294, 88.26488417963829, 86.03714266131001, 86.08978871376284, 88.76198968579693, 83.59953864928215, 88.00235994400518, 86.68463183987527, 86.80462498818675, 82.17559276088592, 82.7982533362604, 86.81712165955575, 89.39379722841325, 83.1627356621527, 85.67251913009152, 82.76947098393595, 87.4204606394614, 83.5340036884431, 86.79878065663, 84.82391434331095, 86.01814270019533, 83.48259710496473, 84.60816044961253, 81.30853714481478, 79.78071904951527, 78.12940905171057, 74.8995647122783, 71.89698250063005, 71.45706515158378, 67.57126715875441, 70.8833557559598, 68.0886826976653, 74.91071208830803, 75.60870570521202, 72.9777680673907, 75.38693489566927, 83.61769922317998, 85.27901910966443, 85.69236632316344, 88.14252976448306, 78.97110262224751, 74.99336427257907, 82.30694509321644, 81.94609488210371, 83.93810979781613, 84.39745856869607, 84.23479003290977, 79.87926467772454, 74.06712009060767, 78.43176887881371, 75.7009441621842, 69.92250842432823, 66.26177603198637, 63.72859954833985, 61.56193717833489, 64.93962349430208, 62.94373327685941, 63.18681040117818, 59.95309076001568, 61.8790098159544, 64.55470169744184, 61.79478476124426, 63.465377130816066, 62.08532256464805, 61.11440258641397, 64.28223817579209, 69.71028466378489, 67.228452005694, 68.46074304273053, 71.24735955269107, 70.22167544211112, 69.00007678616431, 69.29783175068518, 71.1843192192816, 69.456005250254, 73.88052509677026, 73.84432946482013, 75.53029752546742, 74.6942678574593, 71.41722956011373, 68.1954417690154, 66.88901793572211, 71.26863448850571, 69.83202718919324, 70.80291578846594, 72.62177375055128, 77.3546781847554, 76.0795783996582, 78.67572461405109, 73.26763122312485, 78.65180600074031, 79.4781631039035, 76.60220284615794, 24.255301721634407, 0.4530247150649948, 0.5201710039569486, 0.7792165875434877, 0.6039857419748461, 0.27382017143311044, 0.5325781962563915, 0.4489982795090445, 0.2012297859595668, 0.16255524670404775, 0.2677205793799893, 0.21080691157089126, 11.410872032565456, 40.91146230697632, 53.601447689917784, 46.99020647233533, 43.4320479823697, 71.02828733382687, 45.117906216652166, 76.32984130613266, 59.35527839968282, 75.32417697291221, 10.275459616414963, 0.7754315003272026, 0.19277545413182628, 0.21214869924851004, 0.21014056829435213, 0.2527843776249117, 0.22315482398675335, 0.16079804018860863, 0.15085929043350682, 0.22724312880346853, 0.179899140231071, 0.15605220210648355, 0.11939034436739261, 0.20591070575098838, 0.15063928530341195, 0.2035962162359107], [0.024444099831124468, 0.05266173044219614, 0.026466792201503154, 0.08303821597608828, 0.0558346597808263, 0.027617100032887636, 0.02709177822145003, 0.02466020174324513, 0.011038829989340759, 0.008138106054356022, 0.02459957354491757, 0.032480365987266266, 0.06473324216541744, 0.026021968993929126, 0.11985473154533295, 0.05168114172955675, 0.011042037982523683, 31.741759046431515, 63.955257631117306, 49.375215422722604, 46.331040397767104, 35.33957858239451, 69.74092621957102, 33.27149321956019, 33.93841381995909, 31.172876127304573, 0.5925330339420227, 0.07697872096492399, 0.11901793370564138, 0.7810960770134003, 0.1985318234731113, 0.1419525683647202, 0.27271332760010997, 0.8904074468920309, 0.7448057565958269, 0.4933337488722417, 60.5025089171625, 94.39419161888861, 89.1487040058259, 87.0997598094325, 84.12649339245212, 82.6746359179097, 87.61122119042182, 85.02214308707946, 82.47254756189163, 79.46459170310729, 73.4443889125701, 77.57164016846689, 76.69346071058705, 74.9184234680668, 76.80230648286881, 79.39744857049759, 76.00677920926002, 74.75231893600957, 70.92920041853382, 73.4704569847353, 72.0580977778281, 73.71843707176947, 75.03201530825707, 73.78263842674994, 75.37071197263657, 74.28183063384026, 72.47063698307161, 73.17096833259829, 71.98136052777691, 72.82079481309461, 68.70617358915268, 65.14372794858872, 64.88809139497819, 65.57635361148466, 62.041854858398445, 61.77631432010282, 61.35661678929483, 60.35713411146595, 60.6233375303207, 63.11261876936882, 61.35414569608627, 60.4321768976027, 59.21043703632971, 63.8104711809466, 75.728800835148, 81.30924317144579, 78.36154276324858, 75.37997661098358, 68.12321524466238, 67.06412822969499, 70.57727752193328, 71.10608362382459, 76.01709504281321, 74.1253359087052, 74.88383600788733, 73.34819670646422, 78.15353162827031, 75.71091482716223, 71.77050959679389, 69.65193548510152, 65.90593860995385, 62.60905311953638, 58.03618923310311, 56.98594716287429, 55.5838567210782, 55.32550588730843, 56.22212440736833, 54.05236336492724, 55.35543749409338, 56.241791171412316, 55.699248929177564, 54.49112753714285, 52.9824859096158, 54.13096374081027, 52.791599842809866, 56.42862542983025, 59.8659239276763, 59.41181544334658, 58.849951605643, 58.92479042853079, 60.40242964221586, 62.39731965526458, 62.880026140520656, 64.10685331590714, 62.159678936004646, 64.73977481165241, 65.16801134232553, 63.55176733386133, 65.5791541837877, 63.9683073566806, 59.84349973740117, 62.21993046422159, 62.63930636067545, 64.42638920199487, 64.46141204526349, 66.33211197391634, 69.44307711816603, 68.67170380007836, 69.0085098820348, 66.54775604124993, 68.1736804592994, 72.81746079844814, 42.70933166626961, 0.9937807160519785, 0.07413265070006733, 0.057268378009358724, 0.1247514506441451, 0.11436140615372889, 0.004176651033753109, 0.061147100322188876, 0.024476829022469542, 0.0090297797296737, 0.07438664715136252, 0.04605485411781458, 0.07935679577771695, 6.71321842939623, 25.372992869346376, 31.130247808271843, 22.73457331042136, 29.59150787322752, 39.84631915246287, 51.30955580742129, 36.07459545135498, 58.18707889126193, 19.039294642786828, 0.30258962283692054, 0.02324515307742742, 0.07910587133899813, 0.035152262332098144, 0.06300265337490747, 0.04015823706023155, 0.061509176457841555, 0.02990103987676482, 0.14822368750408774, 0.021045279891921148, 0.030362743831750368, 0.03299257237344019, 0.018218449925282793, 0.0677910361499075, 0.036483255830863794, 0.008533121097923048, 0.058420447842969056, 0.03435649616163104, 0.10625690071573181, 0.04180281332904293, 0.011755553123000409, 0.055844825767581506, 0.028745191314467983, 0.03513736958285013, 0.06183379089399692, 0.02656700224765847, 0.05230962877131758, 0.10655828736602299, 0.0377109193904025, 0.05450771122630085, 0.06825952955912198, 0.01853862296669714, 43.08061145967053, 73.85449624830677, 73.65254909761491, 57.218771211562625, 20.011928696786207, 42.89968429073211, 29.688023674872618, 25.88364035852494, 23.828800839762536, 0.1544393878430128, 0.16178872977052966, 0.15847644137759365, 1.277688917133116, 0.16628652390453125, 0.21322062479392176, 0.20652398977789188, 0.596308192658809, 1.046057514125301, 1.8272324675513854, 75.1896082970404, 98.62042780845397, 95.35636471163843, 91.67011337895548, 94.03884057075747, 87.77454083965671, 93.86525215641146, 89.81535004031274, 87.17721877559539, 83.82709887719925, 78.92918817458614, 81.29902931951708, 80.47551201235864, 80.8788336476972, 82.33062836431688, 84.81613236088907, 79.59381026606407, 79.46498394012451, 74.0945609923332, 75.72127772915748, 76.24923659909156, 76.454360869623, 76.7815100762152, 76.79022558273809, 75.83774074431389, 76.02064871018933, 75.22895751460906, 77.50754863985124, 74.05843596304618, 74.51482726681617, 71.66396233343309, 68.14079530777471, 68.2158302491711, 66.38733894594255, 65.11745983554472, 64.52130663779475, 66.83521086169829, 66.43221870545419, 65.49080279565626, 66.40856681331512, 64.051673412323, 64.95337532412621, 62.02246266026651, 69.82298220357588, 80.04457689100697, 85.13657431448661, 80.31147849175238, 76.11372655437839, 72.31746058310233, 71.68772405193698, 75.17267934737667, 75.21895547066966, 77.24856238211356, 77.48603051708591, 76.70669478754844, 73.69723273861793, 79.76943046815934, 78.55022445801767, 75.54815999923214, 72.86223073159495, 69.0996265411377, 64.84118769245764, 60.916668061287176, 61.34792481699298, 59.27121416214974, 57.819972499724365, 58.51205118240849, 58.48129587788736, 59.11475081597606, 58.87010866595853, 57.67366024755663, 60.041018532168486, 56.66004919236707, 56.14704631990003, 55.669760550222094, 59.00777601426648, 61.81114888960316, 62.097834925497736, 61.13992152675506, 61.768155790144405, 62.550452909161976, 64.71584835360127, 66.34672672517839, 64.9107038590216, 65.55539638765397, 68.1472985975204, 68.19625762201125, 66.25775952492991, 68.77748227888539, 67.56670151987385, 61.69215986805578, 67.65968522717877, 66.2079454237415, 66.40329514780353, 68.29350102332332, 70.29107785994007, 71.15394438466718, 68.89623595822242, 73.293652226848, 70.8113645738171, 71.01885795593262, 77.70531454393941, 55.621821341976045, 2.252739518880844, 0.2421973642682837, 0.09337090346361361, 0.17959458963765254, 0.4579927646104367, 0.09609891191845941, 0.027755692999269214, 0.09993802365516463, 0.04298183796626907, 0.008227573632593117, 0.03823445621697653, 0.12278365421920054, 3.413963337098399, 23.469758841299242, 27.613054552385886, 23.986748803046442, 26.528576074108003, 22.712684523674753, 69.46285370857485, 55.738570690155036, 66.77263336796915, 25.467978946624267, 0.28211135717649616, 0.03551470235951486, 0.09683776541703171, 0.03563396692756684, 0.0728906842789823, 0.0330879656417716, 0.014233114028860246, 0.03142763285957758, 0.05152505897586385, 0.013185029139652128, 0.010237971249397003, 0.06254950087637672, 0.04990812698980013, 0.02252515874833109, 0.0056591800755761085, 0.09332483859672662, 0.160134332254529, 0.11347412311982726, 0.3637604872065206, 0.11634841606381441, 0.08943971561928911, 0.2253329651730676, 0.13422151546805136, 0.1951135544767303, 0.1977289173631899, 0.09189417705901208, 0.1511967215206354, 0.17629134108222302, 0.12386499498520168, 0.18204098417153283, 0.15278341218588815, 0.0871979738135011, 45.52313412389448, 87.71175153793828, 75.09557339452928, 73.3436232228433, 53.991237148161865, 99.28945864400556, 53.61165369710615, 46.84910312775643, 49.8854334123673, 1.4091677459016925, 0.48277736371082647, 0.6866895912155029, 3.0502394995381756, 0.4442055721677119, 0.3794214387814845, 0.7464761959929621, 2.965503310964954, 1.6701660569637053, 1.9853157526062382, 77.4705606891263, 106.78703784942628, 102.54106429315384, 98.59527757090908, 97.98780441284181, 91.94723667636995, 97.92215962563792, 97.42604255676271, 93.28638876638105, 90.86852996580063, 82.95896068696054, 85.16963989503923, 85.53384765501946, 85.07766031449842, 85.16028896454843, 88.36936043154809, 84.60015881446101, 85.55869979243126, 75.98610831845191, 81.22925819889193, 80.42181476469963, 81.52946856714065, 83.44925695850004, 82.8129465349259, 81.43254680018272, 81.48025851095878, 78.56504317252868, 80.09093930644374, 79.20220082806003, 79.63604634807956, 76.41176392955165, 73.0653702828192, 73.94383999609178, 71.43802596676734, 68.74398523761381, 68.65289995747229, 68.3320265431558, 67.56623083545317, 67.80376957308862, 71.90532145961639, 69.73392871118361, 68.29638788777014, 63.026397228240974, 68.82087153773155, 84.03288995065998, 89.93584525200629, 84.55876211966239, 80.84965905835553, 75.64938068389893, 71.47388427488266, 77.27467752272084, 78.56433714589765, 80.21827513171782, 79.5415799848495, 79.04308595964986, 78.15115467194589, 85.37729017196163, 82.53561142952212, 76.18470576501663, 76.23559459563225, 72.56807650289228, 70.26244455768217, 62.287171656085604, 63.960309643899244, 63.912205696105964, 60.59502194004675, 62.56010978452621, 62.95400204197053, 63.23296100862565, 63.2315371882531, 62.04979373562721, 63.77769585578673, 59.51081606649584, 60.72789615200412, 59.30884930395312, 63.54643291042697, 64.50293033353745, 65.99339177531581, 67.19884595563336, 66.09971154120662, 68.97777418936454, 68.66007005014728, 70.33545555606966, 70.08268233268493, 69.04332483968427, 74.46267543300506, 73.1782639411188, 69.7318341655116, 73.4617022545107, 73.0804321842809, 66.18756478832614, 72.03678361831173, 71.16418177081694, 70.28280950361683, 72.8511147345266, 73.42836995278635, 76.61194601366597, 73.49675255437052, 74.936615420926, 75.5542867414413, 77.62869496499339, 82.47377134138539, 55.31864566187705, 1.9266874727702912, 0.3571774017426276, 0.3125049456232979, 0.4419378293377738, 0.9233796260049267, 0.6105446803473658, 0.1554637699718437, 0.36083749405318694, 0.3388168176095332, 0.33638448844994273, 0.22379613150992703, 0.21718085503145573, 12.640697859948682, 38.84997437077184, 45.28747420157156, 37.24681538920249, 41.99194977360387, 59.98625047745244, 67.85017121222712, 49.94109184511247, 79.37102748501685, 28.402519802893366, 0.5521910889975487, 0.21934563564437054, 0.2323465460851308, 0.1358822408703066, 0.150361348604483, 0.15131773276915475, 0.11227030021649216, 0.15015056717299646, 0.29997999028813455, 0.12471161407208252, 0.13754569354557222, 0.13537358913210132, 0.1276474775025441, 0.20114651220219754, 0.12839758483272407], [0.05584514369407008, 0.013098905535204517, 0.04861842563015319, 0.009928540675900877, 0.01558331526710742, 0.03225582178622004, 0.022185331721219326, 0.04206506437772224, 0.04104607933831792, 0.049197576609590364, 0.07113710135942505, 0.014664218516930219, 0.05875478776532316, 0.03992613923225192, 0.045639155657901886, 0.11010077751932607, 2.5964551010439476, 55.362901764531294, 51.26532716135825, 27.13969115288027, 38.726737422327844, 69.93573465654927, 29.846926735293483, 33.72950053984119, 48.14709386517925, 3.4563075294417724, 0.03830872078035628, 0.11728682780578253, 0.05945988359951204, 0.3822727567486225, 0.1284193187471359, 0.1899163680331361, 0.06315759848803282, 0.36651530873871624, 1.094678724485059, 7.246751477641444, 83.61259229721563, 81.96922902138003, 86.44319426628851, 83.4453659672891, 86.52860779916087, 81.02555382636287, 85.44514717594271, 80.40216369013633, 76.45660446536156, 76.48365313006987, 79.375287179024, 75.46204828446912, 76.5641793897075, 76.69231537849673, 75.7392421845467, 77.33330126731627, 74.26655692438926, 71.02565150107108, 72.37384073195919, 70.00335631832, 72.37576269334363, 70.74670822389665, 72.25330629656392, 69.00673697071691, 70.17168091189477, 67.48419838566934, 69.1214741429975, 69.39777374267578, 71.45354286316903, 65.97328570581251, 62.91549613398891, 62.825564030678045, 61.77073670971779, 62.018195121519035, 62.63821594176754, 61.128052434613636, 61.49189541416784, 62.2434058497029, 60.276333285916245, 62.06880546385243, 61.37405564708095, 60.88797984584686, 67.87991846761396, 72.6314070916945, 75.52005229457733, 76.38920245632049, 72.0456167959398, 68.0069326585339, 68.65735576998803, 74.66079435040875, 77.28366759515579, 74.6918281432121, 74.49290906229328, 75.40956697156354, 71.50984456462245, 70.26272696833458, 74.5999191653344, 71.40641166317847, 71.7743613643031, 72.91277439363542, 67.3778001723751, 58.59547215123331, 56.62345740102953, 56.21331476396131, 56.01209717412149, 56.66245360528269, 55.08027145939489, 55.07174422664028, 56.34092907751761, 53.44004215732698, 52.65050042060114, 53.308583921001805, 53.16398966696955, 54.90314114478327, 53.69914216379966, 53.54609912441623, 54.39854783396567, 52.95225620269776, 55.20532446522867, 54.62612375136345, 55.38420023456697, 56.43415204940304, 55.2878511336542, 57.09580490666052, 59.57728455143591, 60.47280480784755, 60.90286131828063, 63.60419765595467, 63.584452444507235, 61.88748998026695, 60.51450352514944, 64.1036291276255, 60.64431828837241, 59.86528065896804, 67.32744478410291, 67.06886645286315, 66.17592319365471, 67.5412453374555, 65.48563311176916, 63.04580119348342, 65.85767776735368, 66.87261458366149, 68.64325877158873, 8.626564818043864, 0.32864632625733653, 0.03747637774194441, 0.11486880916861758, 0.12850118290272453, 0.054806087151049614, 0.07836559291688666, 0.04434052937393708, 0.08754694218476934, 0.11202757291856313, 0.08962818090954135, 0.026083524158645063, 0.07721111373675447, 5.422267365840174, 28.377824560288463, 29.281385675553356, 33.103294141830936, 48.52651257668772, 27.61060699339836, 19.25634095745702, 48.297622665282226, 23.59678872169987, 0.08196099676311978, 0.06425182868335998, 0.033366775680934234, 0.04793787908349787, 0.012123112532971127, 0.05019305041059852, 0.010491455379392832, 0.06845226195911247, 0.02030018852242539, 0.01833818563740821, 0.056836810038094564, 0.022603675099690596, 0.04495365635281609, 0.027049951736004125, 0.04545165180799462, 0.09178340840604036, 0.06631548952070937, 0.028943112044925653, 0.03859027724472746, 0.024055135924549356, 0.033281130881439296, 0.03407336155613584, 0.04649031381573408, 0.023362234294895205, 0.09801396318981725, 0.03639294938634961, 0.05400185953945883, 0.0733454340708352, 0.013419069958129718, 0.16072916888421582, 0.11521692718228987, 4.566255182989182, 69.1400347986529, 65.34558096239644, 50.29756469111289, 47.35772079037082, 47.910649468821866, 30.27971321536649, 33.27882412941226, 40.98879967966388, 2.3052178900088034, 0.08790630636917007, 0.20260336628604322, 0.16423803543852222, 0.5726250441324326, 0.552999893984487, 0.12678228078349946, 0.0704434470483853, 0.5332962964330951, 0.7776177314019973, 10.991211764274105, 93.54508476872599, 88.79179185436618, 94.50225291713592, 88.15140216581284, 89.77181173140004, 88.06109351496544, 92.77269163439351, 86.18077201227989, 81.5782863863053, 81.07990218747048, 82.95200240227484, 78.09949705677649, 79.89453838717553, 81.04965286870157, 79.69426216617708, 79.59708152278778, 77.57884164010325, 75.3555324000697, 79.37475373668056, 73.33466452936973, 76.26083897006127, 75.19881802220499, 74.86469484144642, 74.41904298720821, 74.07664360538607, 70.39680927030503, 72.82881998246717, 72.86863988445651, 73.16889732114731, 69.2056482068954, 64.4710846101084, 66.26318024050805, 66.53682831794985, 64.18982321216215, 65.38877802510416, 65.49154020124867, 64.0091117735832, 65.94725685734903, 61.99390780541205, 63.041639558730594, 64.45690524193549, 63.568535466347974, 71.15657237268263, 78.24521310867803, 79.83084694031747, 78.59712816053822, 74.94576238816785, 71.53137837686847, 71.43367213587608, 79.7610209065099, 81.33735087610061, 80.33143551118913, 78.58514139729162, 77.14631403646162, 73.75612320438509, 72.06542476530998, 79.22238534496677, 74.01600376252206, 75.98629659222019, 75.19340515136719, 71.72225659893405, 61.721895356332105, 59.593338812551195, 59.12546673128682, 58.40401734075239, 59.02814096020114, 58.934945444906916, 60.62002704989526, 61.13685031091014, 57.23815948732438, 56.60086454883699, 54.94872693092593, 57.198825959236395, 57.30906417292934, 57.85965119638751, 57.266855547505045, 56.152682765837646, 57.479953996596805, 58.02845039675313, 56.74811816984608, 58.97758160867999, 59.34240125840711, 59.344884118726185, 60.80273105252174, 61.98720055241739, 63.11267368255123, 63.516242427210656, 66.23491564104634, 67.3967295308267, 66.04640653056484, 64.25272234024541, 67.27691681154313, 66.03260763229864, 64.88073302853492, 70.13569708793395, 69.64147060148179, 70.3795273073258, 72.85725716621646, 68.43139586910125, 65.69070639148836, 71.01371180626654, 70.22464075396138, 76.37346590718916, 15.636772859481075, 0.17584701008614034, 0.14882171105953956, 0.1566514667243727, 0.49828292201122937, 0.07363887638935158, 0.08715836706781581, 0.07525267124536537, 0.06498677896395808, 0.10638407897204162, 0.05859968177373371, 0.03458803474542595, 0.028877033131016843, 2.532218444731928, 27.657848019753736, 29.324549398114605, 31.028705489250925, 34.21758067223334, 32.747203726922315, 29.65175940144447, 56.68466206519835, 33.60095662455405, 0.0800009991132444, 0.0075963042552522845, 0.09531187148944986, 0.043419729993348165, 0.11350524161131152, 0.0867541560963277, 0.03654751528595244, 0.07429868493589663, 0.07295774761587381, 0.02048617168780296, 0.047710132634928154, 0.06471364563631435, 0.09367923853137801, 0.025341543106121883, 0.08032890006659493, 0.19247427432527467, 0.1114301545725715, 0.10313888455951407, 0.12666292428489656, 0.07805512046381351, 0.17369658596092657, 0.13973907988157966, 0.18208273596340613, 0.1628807574630745, 0.2517182743477245, 0.12810165272845378, 0.09582838328975825, 0.1912599177129807, 0.10939392351335096, 0.29182182805192086, 0.3558614771933325, 4.105817218942027, 79.19236352366786, 73.05782364260766, 43.72864584768973, 58.59103202819825, 98.54325125294348, 54.17314490964336, 54.25053719551333, 69.76144806031259, 6.195491062056634, 0.15349386680510738, 0.39219433081246197, 0.29457799789886324, 1.2529792107882038, 1.115905856413226, 0.49219065375866433, 0.15594058309591588, 1.0161757949859866, 1.5671729512753025, 11.527513515564705, 101.54323685553767, 94.4343880684145, 99.71397676775533, 94.56934113656321, 95.91915422870268, 91.58022834408669, 97.83171761420466, 91.36682002775132, 89.09274747294765, 87.04132433860534, 89.6821306597802, 85.08487747561547, 84.4047071087745, 85.89735723310902, 85.22050519143382, 84.0820372489191, 82.49807434697306, 79.18327146960844, 83.76346234352359, 77.93462414895335, 79.02996955379363, 79.56969553424467, 80.02999351870629, 78.03870816384593, 78.18136476701306, 76.5296233084894, 76.78035689938453, 78.67489307157456, 80.16094576927924, 73.19933491368448, 68.5580256677443, 71.4238348314839, 69.89768766587781, 68.0938288473314, 68.3228011285105, 69.62246279562675, 68.39684763262349, 69.59521801240983, 65.85050767467868, 68.51840188426357, 67.99345539462182, 69.1714608284735, 74.76018721057524, 82.22152371560374, 82.56182855175388, 84.25956372291812, 79.11694418999457, 73.8478203742735, 72.91289990948093, 80.4660826344644, 83.24635274948614, 83.02418185818581, 79.84699141594672, 80.45874780224216, 75.05039553488456, 75.47649829618393, 80.45582171409362, 76.0787154782203, 78.5178021461733, 77.23467719170355, 74.3823060681743, 63.58706082067182, 63.16766138999694, 63.483906407510084, 62.62267158877466, 63.63393706660118, 63.30272428451046, 64.93483035795151, 64.46762115724626, 60.2953097128099, 60.95203215076078, 58.960958603889715, 60.60702047040386, 60.567145655232096, 60.02495250394268, 60.805527702454604, 59.57985762626895, 62.90391337487006, 63.35959472963887, 60.982489355148815, 62.636776431914306, 64.22625418632262, 61.24888889251217, 63.08014938908239, 66.68624708729406, 69.76395053248253, 68.60376834869385, 70.23859654703449, 70.9157309993621, 70.19297938193046, 67.61925343544253, 71.10024713700818, 69.67399489495062, 67.65161298936414, 73.94058442884877, 73.2414690140755, 74.60938776693037, 77.6260591322376, 70.81187448193951, 70.26067164636427, 73.715330554593, 77.6325467325026, 79.28332328796387, 14.61772834101031, 0.7018729022914364, 0.5707945842896739, 0.3558182698344031, 1.2527675253729667, 0.38475049960036434, 0.21947559479984546, 0.20708098166411926, 0.19801572536028203, 0.40898737647841055, 0.17227221400507037, 0.1373284156884878, 0.19017374293217737, 9.079353424810595, 45.62469997713643, 47.33839135016165, 47.272738718217425, 73.32985570353847, 40.717744288905976, 27.76917665235458, 67.81920802208685, 38.34418865942186, 0.282775923129051, 0.17214584014108106, 0.193626485885151, 0.16678722365008247, 0.17833904813854926, 0.1725626072936481, 0.15946553749663217, 0.1300368674339787, 0.12149922354447266, 0.07225066378352142, 0.19611910616438236, 0.1135879408027376, 0.22368155539997164, 0.1440616543855398, 0.23943417705595496], [0.0351434140165727, 0.05990663543343545, 0.03573140182021645, 0.0163737082883956, 0.023224790460400047, 0.04997744645562865, 0.07862623135048537, 0.01852395238294717, 0.006089375313040951, 0.051861375405062596, 0.0029365960020391693, 0.017672717616322543, 0.018727327659425717, 0.060862759128212936, 0.05086749506693694, 0.14644968834134842, 21.469867806280813, 65.06131895126836, 34.69650991501347, 39.59183185331283, 24.001088988396432, 27.398008646503573, 26.407584682587657, 43.86380287908739, 11.438724783159072, 0.0973746091908505, 0.06428266755275189, 0.050597525682420506, 0.15767051688125058, 0.06904362054962306, 0.21273726927897624, 0.09382396786203308, 0.30227840727856087, 0.06886497650656008, 0.2812359944706963, 17.921668214182702, 88.85454977712324, 81.40996963747087, 85.21896762232628, 78.7092451895437, 82.95797224967711, 82.84337628272273, 84.29774407417544, 81.26838776373094, 76.45341165604131, 78.63555954348656, 79.55950521653699, 75.33595977290985, 78.59685359462615, 74.26105776140767, 76.96204893050655, 75.17752739690965, 67.68420004075574, 70.00492526638892, 71.14343243260538, 68.98429316859092, 69.91847622779109, 70.24797101174632, 69.07431156404557, 67.68544735447054, 66.81248464891988, 64.03239888529625, 70.21651360296434, 65.21415802740282, 66.31964668150871, 61.94292483791229, 63.294389247894294, 62.213074161160385, 62.640079067599395, 60.57942267387145, 61.811266560708326, 59.760761260986335, 59.22156480050857, 60.03408378170383, 59.94737978904479, 60.17612457275391, 58.754202627366595, 61.926454805558734, 67.81544254672143, 74.7668081714261, 78.79514509631743, 71.97344518476918, 68.84447636142855, 67.27491640275525, 69.97578990074896, 77.02086094887026, 76.79199064931562, 74.6388526116648, 74.33384910706552, 74.14236683999339, 72.5419064491026, 69.53261698445966, 71.37375400912377, 71.02086620946085, 73.45588145717498, 73.35724953682193, 75.65049463702788, 63.98573836972637, 54.9003170382592, 56.7017989004812, 54.995799295363895, 53.18943015990719, 54.96680513505013, 52.771187828433135, 52.17507385438489, 53.38296774894961, 53.59605443093085, 52.42317945726457, 52.67954557172714, 52.313521754357126, 53.127091930758574, 52.96497644916658, 52.21622343986265, 53.803437986681544, 55.13343918708063, 54.43167225007088, 53.13811771331295, 54.81127531297746, 54.83727670484974, 55.6943695006832, 56.48716288228189, 55.30219131900419, 55.685269601883434, 57.77357086058586, 60.74403278289303, 65.56646531628024, 62.206963108431914, 62.80437930937737, 62.65429765947404, 58.80853137662334, 66.32746004289197, 67.818847164031, 66.78196076423892, 63.698518891488355, 63.951876548028764, 62.74511621844385, 65.73291109454247, 66.5322313001079, 72.7602961755568, 40.91539252188898, 1.334956747389609, 0.06538892149805062, 0.1280413079826582, 0.036070349761435104, 0.09281021137271198, 0.06503816048103957, 0.07553134338870164, 0.0721600279211998, 0.07527079688565386, 0.07026044396503318, 0.17539383843541148, 0.11754360515624286, 0.1660061204024861, 6.396177170738098, 31.500619572977868, 32.74464045801471, 25.064539640180527, 35.74791692918347, 39.76015252451743, 40.77965105733564, 40.202635103656405, 0.20984680421890753, 0.04130557247046982, 0.04214487924811341, 0.050151099435864925, 0.08553675811497435, 0.08737317812178405, 0.023632343490457824, 0.07520686684837265, 0.05457628758684282, 0.017992647424820932, 0.005251666307524448, 0.029673404510944124, 0.0709759624254319, 0.046861625141313965, 0.04462149595060656, 0.047030229602129235, 0.016364605248635335, 0.09065535925929585, 0.046049001206073074, 0.03857060793727156, 0.04070169983371612, 0.02558924039945968, 0.023866255031598192, 0.0024747330838093356, 0.02596709794635254, 0.03226684196101081, 0.0620270595555344, 0.03243479524709044, 0.07095642718336276, 0.039847006180113366, 0.06417296376199493, 28.762077593034316, 78.25206156699889, 51.50375627702283, 55.08300927377517, 22.691660619551136, 29.780550426052464, 32.721335695635894, 43.05293521573467, 8.908044888127236, 0.1235849055792055, 0.04529376108680041, 0.026009648384886886, 0.28760334957511197, 0.30383678333413217, 0.2475286007768685, 0.5561532344548934, 0.4464686265395534, 0.1471473186487152, 0.4533820797599131, 24.666768158635787, 98.66122045824605, 85.69653972502678, 90.38396035471271, 83.82034455576252, 90.27316908682548, 88.90784694302468, 89.7696779620263, 83.80503946735014, 84.08103312215498, 81.93284511566162, 82.82305840523013, 78.28274234648674, 81.91999543097712, 78.49286371661772, 82.82184247047671, 77.61921851865708, 72.4957166179534, 72.8605676466419, 72.94869545967349, 70.08286276171285, 74.09660846956315, 75.47222291269611, 73.62436294555664, 73.01943148336103, 69.72571526804279, 66.82676207634711, 71.5566070618168, 68.32991630800309, 68.58242281021612, 65.60386903824346, 67.85403866921702, 65.25654315948486, 65.37878774827527, 63.695145653140166, 65.87368103765672, 64.51951411462599, 65.08815188561717, 62.19254447567848, 62.647213858942834, 62.62000829942765, 61.48428601603354, 66.80471051123835, 73.72136315991803, 78.77909475757231, 83.72537612915039, 76.85634105436264, 74.14729333692982, 68.43946026217553, 72.3640504960091, 79.16453038492511, 79.88390091926821, 77.40818715864613, 75.72256426657401, 75.79523794112667, 76.04371224680256, 71.97929736106627, 73.12262119785433, 75.25319776227398, 77.90001315455284, 76.9019111510246, 78.84491997380411, 68.61937153723933, 58.527305280008626, 57.917031549638324, 59.172503794393236, 55.27893558625252, 57.02376665607576, 57.561947222678896, 56.696499778378396, 57.200587103443766, 56.25442904810752, 56.74578043722338, 57.742690040219216, 56.480761574160674, 57.687419922121116, 57.07888380173714, 55.623174559685495, 57.72142294914492, 59.24644439451156, 57.92640993672033, 58.69112699262558, 58.70028180460776, 57.35130417731501, 60.17299059898623, 60.513609224750155, 59.13550407655778, 57.93169729171261, 59.501559272889175, 63.457124463973514, 66.68320332804035, 65.16030780730709, 65.56368435582807, 66.41008084820163, 62.76729329939812, 68.5062974499118, 71.35456577424081, 69.51924170217207, 68.83971460403936, 66.87932183665615, 68.39852640705725, 69.56621600735572, 72.48089790344238, 74.3949596343502, 56.366875556207475, 3.4606701856659305, 0.11046198797562432, 0.1707936030241751, 0.1907563221550757, 0.08767861737719468, 0.05559573610944133, 0.1663417282003549, 0.12853322069971793, 0.013116861678539746, 0.07800712505535734, 0.11599799978636927, 0.09601365399336624, 0.6002558130891092, 4.8141156377330905, 29.63686223953001, 32.14018164142486, 29.313527537930398, 21.272452954323064, 42.67093166228264, 50.6587718379113, 51.05667275767173, 0.41298007352217553, 0.04106416284377056, 0.10447164006050556, 0.012538117683312346, 0.026416770490487258, 0.04796348557236695, 0.04857480075330504, 0.034868943865501115, 0.07801618787550157, 0.042891535352194504, 0.08511715643708745, 0.06710539511855572, 0.021929751383140687, 0.036179207025035735, 0.038599497112896175, 0.1866780377684101, 0.1779617804793581, 0.20081908622336006, 0.1946364808827639, 0.14568415200037343, 0.23218943677361936, 0.11330642647320226, 0.138486618055932, 0.12156057186544904, 0.17565899678776342, 0.12332423650208982, 0.18020237315325968, 0.07732249526006561, 0.31782107487801586, 0.17386785257727871, 0.21866547214167736, 32.28338541523103, 91.42766383386429, 51.72095752531483, 57.910132100505216, 38.76457260501, 46.49048474527175, 44.06523227691651, 65.96606069995512, 17.79272029476781, 0.3545691787956223, 0.22263491075606118, 0.17282493112068023, 0.3977839228126311, 0.773296382638716, 0.5577825502522531, 1.030618084534522, 0.7912577123891923, 0.8248811888117945, 0.5675389557596177, 26.14054972125638, 106.0656512168146, 94.94038166538363, 97.61928204567202, 89.36713295598184, 94.49647918824228, 94.55141590487574, 96.26125551039173, 91.49050020402478, 88.6491274064587, 88.38305734818982, 88.9154092727169, 82.5995695975519, 88.31371768828362, 83.60291188763034, 86.51179652060233, 83.5034013563587, 76.24982495461741, 80.45350751569195, 79.61398693823045, 75.32263155906432, 79.82395141355454, 81.09295583540394, 78.02876103308894, 75.31058988263531, 74.22932578671363, 71.10791144832488, 76.99755422530636, 71.59628575847995, 74.27989298297514, 70.29392550068518, 72.07034341750607, 69.32823796426096, 69.24127901754072, 68.85604735343688, 70.46487808227539, 68.34013800467214, 68.65009938516926, 66.96963048750355, 63.906463346173695, 66.55031342660227, 62.78248071670533, 67.91627883911133, 75.23164826054727, 80.66114994787401, 86.35787487030031, 79.2437465729252, 74.11808736862676, 70.85192188139885, 75.13922937454717, 83.57153292625182, 85.33325764440721, 81.41347623640492, 78.56713771820068, 79.49400163465931, 78.16427892254245, 74.33738708496094, 78.2118494279923, 77.42270777302404, 78.38138211158015, 80.34905479800317, 81.73201976283904, 69.8716195937126, 60.383947433963904, 61.79212539426742, 62.227912487522254, 58.02792479915004, 61.226821637922725, 58.91487859910535, 59.26395777733096, 59.593695748236875, 60.010427967194595, 58.89197195729902, 62.401928440217056, 59.413611888885505, 62.73403552270705, 61.331207675318566, 58.82617419765842, 61.06670656511861, 62.94651423731158, 61.03985794128911, 61.73083443795482, 62.39655087071081, 62.649547669195364, 66.20134799711167, 64.77941036224365, 63.856849285864065, 62.63049671726843, 65.01626268509897, 66.84599737967214, 72.10085945744669, 68.27556794689548, 69.3366632153911, 68.59649627439438, 64.52802565789992, 72.10874342149305, 75.07571051197668, 73.82893023952361, 70.81631460497456, 69.65375546486148, 73.41301779593192, 72.94780900401454, 76.85473288259199, 82.40204688041442, 52.577967951374674, 2.5205743985791362, 0.2904083039010725, 0.4628830715533226, 0.5141941085457802, 0.4779950751652641, 0.13751797648447175, 0.534273763337443, 0.24145871761345097, 0.223654022199973, 0.16075320872327975, 0.2265361062581501, 0.38644710856099285, 0.8291589624939427, 13.12260025931943, 46.1250610505381, 50.217273773685584, 38.95532531123008, 54.49458314526466, 57.692216980841856, 57.50266451989451, 60.23909822587044, 0.45034539915861627, 0.1488018847040592, 0.17433712739617596, 0.19635147595357513, 0.10365663742225978, 0.2019588105500706, 0.1357722306443799, 0.18010075925098312, 0.18162421701896578, 0.09296053314521428, 0.21494717247063116, 0.09353808683132933, 0.11903911603674774, 0.08912191170478061, 0.1453687995672226], [0.006202413501488346, 0.12582025055082577, 0.009499796696247594, 0.01889755048098103, 0.03484674646789509, 0.056111171556216095, 0.05219053657304856, 0.03240664917675238, 0.049891399459973465, 0.11176065256398533, 0.01410267415321282, 0.07267184360253234, 0.06425218108380515, 0.08111122905487016, 0.043599618929288084, 0.5403484728547835, 39.086877684439386, 52.81013304187406, 46.284387726937574, 50.39191338323778, 28.924855955185432, 34.945956968492084, 35.17618048575617, 23.04494457860147, 1.0472605786015912, 0.023281737606251435, 0.04290241763115891, 0.09410634021004362, 0.09524391182968694, 0.04387985389198988, 0.11349581106896363, 0.046037758865784255, 0.13176841000395437, 0.11762137074143657, 0.37366811847013814, 30.42982428304611, 91.76164580929665, 75.64148887511223, 80.17698826328402, 79.89351857093074, 85.52445750082694, 80.02775776770808, 78.88499875222483, 75.00695136285599, 79.33660476438462, 78.02944352549892, 76.0770445485269, 71.57011570469027, 78.35663195579284, 75.38190641710835, 74.34894238748859, 67.99265523110667, 66.57772294936642, 66.48019713740196, 65.3357122790429, 66.72114049234699, 68.10070868461364, 66.73872840019965, 68.34128333676246, 69.29717279249623, 64.11997364413354, 67.51165497687556, 64.91394373678392, 67.40607261657715, 64.40784815819033, 66.11656988820722, 63.18873236256262, 62.8852899612919, 60.985842981646144, 61.412290911520685, 60.00795687398603, 60.50267757907991, 58.96768939110541, 59.04344212624335, 61.32237057532034, 58.654719552686146, 58.43182694527411, 62.851181030273445, 68.28793910241896, 78.33129344447967, 78.0965474344069, 76.48681456042875, 76.68553752283897, 70.98356446912213, 75.34994694494432, 75.41749800405195, 75.81152362208213, 73.94925286692958, 69.92673673937398, 73.99941213669317, 72.84758460137152, 73.42094098368, 70.38429690945533, 68.85714561708512, 70.55458268811627, 74.02165982031053, 75.41952194706087, 68.68886024721208, 61.15979617641818, 56.54671622860817, 55.856332009838475, 54.986671939972915, 52.34710901014267, 54.633195784784135, 55.94008245775777, 52.5093186286188, 53.15578406856906, 51.19776041276994, 53.91135415723247, 52.57788950397123, 52.17486596876576, 52.44320707936441, 53.98429847532704, 51.378205130177165, 55.557565073813166, 56.21028669418828, 55.66018996700164, 53.49607321523852, 56.83182939406365, 54.7438850710469, 56.96842201294438, 55.10453916365101, 56.62344563391901, 56.4505083330216, 56.60450058598673, 58.61185981381325, 59.04913348536338, 61.43646840126284, 60.74833170060189, 61.7923411246269, 63.38200715280349, 66.57092940422797, 68.47517736496465, 65.42595817196754, 64.0236206208506, 66.27055429643201, 64.40856987430205, 65.78519628893945, 64.21846828153058, 71.19274447041174, 20.58301991032016, 0.1710543333883247, 0.14689457092073657, 0.06317297387267314, 0.05314806986960673, 0.10379994182937569, 0.06733823222138229, 0.13833071916334092, 0.2775481084902441, 0.07869715577051525, 0.033177969481555686, 0.06172951483618348, 0.4868827982535286, 0.36588475708999946, 15.176034588967601, 31.31347348613124, 28.609269895861228, 46.52216572915354, 40.93149777381651, 33.18177684660881, 42.26598616569273, 0.3916925432220582, 0.08514478922851625, 0.06028610176496929, 0.08270112962852563, 0.02688961144867203, 0.08658328784569617, 0.04015812597748253, 0.06601223361588295, 0.042368232182437376, 0.05609151757051868, 0.10630862697237924, 0.03646809112040266, 0.04598320574469624, 0.12201046465986198, 0.04403905462353461, 0.047956020045544834, 0.08777098459822517, 0.04175060826744284, 0.052937104577018376, 0.020267645107401956, 0.03655967693175039, 0.10420134125818169, 0.04200747371801446, 0.07577502829653603, 0.07520580964703714, 0.047441971217913013, 0.06267281421910852, 0.043111325977670575, 0.03414155104227605, 0.018989634249479543, 1.0825726966704092, 52.17326564173545, 63.53405783253332, 67.70239199361494, 47.376163774921054, 21.69556098599588, 46.55805541623024, 40.5005822643157, 23.13547484336361, 0.9749939112413315, 0.030992780286338062, 0.28052858888141574, 0.16019306055480437, 0.2290341197963684, 0.13165357342410472, 0.07999254150256034, 0.06566600783938362, 0.41279651885551794, 0.3787242068398384, 0.3423333756865994, 34.285229790595274, 95.66515722582417, 83.6218334013416, 86.10099100297498, 84.7818979140251, 89.44829463958742, 85.8692495284542, 84.97301932304137, 79.94253250860399, 83.35534757183444, 81.35192640366094, 80.46746330876505, 78.32828890892768, 82.71333402202976, 78.82573958366149, 80.40896508001512, 70.66622903270107, 69.01795494940974, 71.37264005599484, 70.41045127376434, 69.26566831527218, 71.24359407732564, 69.0800303797568, 74.88733476208103, 71.52275700722971, 68.61140912578952, 73.33240524415048, 70.57229611181444, 69.08434498694636, 69.11677514353107, 68.77924734546293, 67.10330486297607, 65.91641918305429, 64.48630732874717, 64.53947505643292, 61.66181249003257, 64.1593110945917, 62.04172149781258, 64.10055006704023, 62.69537271991853, 60.031020410599254, 63.267568080656, 65.20773318506056, 69.79766722648375, 79.70620970572196, 80.28941123716294, 77.47828775836577, 78.05366808368315, 74.23732742186516, 77.8953141550864, 79.2302300853114, 79.6986944444718, 76.3227653503418, 72.93222150494977, 74.81352360017839, 75.03372546165221, 76.82766068366267, 74.18803891827984, 69.85778931648501, 73.67562047896847, 75.01054425393382, 78.57796345987629, 71.58352236593925, 62.798480064638206, 61.4666392726283, 61.110872453258885, 57.79648534713253, 55.55318770870086, 56.203461770088445, 59.24496173858643, 55.57441949844361, 56.275880490579915, 53.87138912754675, 56.60382593831709, 56.08755180912634, 58.31821941560315, 55.551022560365745, 58.21469629964521, 55.0944665170485, 57.53967208247031, 59.37019517344814, 57.78949176111529, 57.26132500556208, 58.76611878795009, 57.52825798526887, 60.35988369295674, 58.78853905585505, 59.600540284187566, 59.03262030693793, 60.54034409984466, 62.56820555656188, 63.0468955347615, 62.99510063663606, 64.90957421641197, 65.6700158888294, 66.54659501967892, 69.43107466543876, 71.34650922590687, 70.25449783571305, 67.37439555506553, 69.52802781135806, 70.49928511342695, 68.38089143076252, 68.81836122082126, 75.01230147577103, 33.27020668214367, 0.07938923960131022, 0.19651626146608786, 0.1212158093168851, 0.225400687345574, 0.041703129968335556, 0.04811137884614929, 0.10806320580623804, 0.05482730012567294, 0.05892344968273275, 0.09945863647566688, 0.16422855127001965, 1.775118509127248, 1.1116253248145505, 13.02288478420627, 26.883258358124767, 34.54502797895862, 40.9035312744879, 43.1299078079962, 43.782362707199596, 53.01302940614762, 2.2799181121010936, 0.06283418680991858, 0.0509141996172407, 0.040731347436385776, 0.04161491494385466, 0.03589755479967402, 0.07029599044471979, 0.04451487949418445, 0.10439688520085427, 0.050178421961684386, 0.04524288135730932, 0.050204982230019186, 0.04652655360499217, 0.01597451519281153, 0.057691147460812525, 0.10706097894017735, 0.255012973361919, 0.17339166764530445, 0.11293586208334855, 0.10760935999813581, 0.19233686879517572, 0.3002171711094918, 0.13276669917808426, 0.1803748501885322, 0.2787330932915211, 0.12481833778081403, 0.21456867907076113, 0.14541759936799928, 0.18731540759965298, 0.14475960644983477, 1.045777554954252, 60.253073630794404, 73.78656079692226, 66.18246570710214, 73.4100289498606, 48.690734371062256, 56.2245366650243, 55.45864682043753, 36.42984059549148, 2.5369015095695375, 0.09974644038706057, 0.44222774765183853, 0.4902599896154096, 0.259108372152813, 0.2910374153044916, 0.22588479362668532, 0.8205761423995419, 0.9323731305137758, 0.5472698014590048, 0.488504974111434, 38.07863635401572, 107.79587930248631, 88.6112843790362, 93.16398728278376, 90.40302307375016, 98.27996607749694, 91.95793690220003, 89.94995009514594, 85.55256520548176, 89.0311505717616, 85.36058087502757, 85.75106851516232, 82.89265694156771, 88.2974398520685, 84.17258908671718, 82.92613044861825, 76.35224588455694, 74.7609716846097, 77.25486170861029, 72.4251296443324, 75.18690970636185, 76.54103740569084, 73.43082535651423, 77.70537730186217, 77.1575241704141, 72.05410480499268, 76.3191803040043, 74.09005811137538, 74.62479483696723, 72.14502534558697, 71.98113303030692, 71.02982490293442, 71.05965845046505, 66.7402659693072, 68.7436165348176, 65.81788139958536, 68.23392806514617, 64.84639267767629, 66.13278496649959, 67.19779476042717, 63.11230105738487, 66.68825534082228, 69.25499162366314, 74.63047442897674, 86.41206633660101, 83.05786717322566, 80.99431607031053, 81.73660893594065, 75.38028255585702, 80.92198756433304, 83.04867313754174, 85.03408278188398, 79.1964114096857, 75.89817662392893, 80.87496619070731, 79.37518519739952, 77.8906230003603, 74.86881333012735, 72.33543288323187, 75.33897999794253, 79.03472346644249, 82.74872949046474, 71.69570215286748, 65.82380417854556, 64.92548727220105, 63.66269196233442, 60.561607268548784, 58.6944963086036, 59.93841325083087, 63.33538978330551, 59.975201160677024, 58.78175727782711, 58.367672658735714, 61.88401868266445, 60.02596055307696, 61.51465300590762, 58.63446051074613, 61.446466522832075, 57.669718265533454, 61.822994447523556, 63.233259108758745, 61.384547987291896, 62.93405678964431, 64.88186267114455, 61.473958415369836, 64.87832077087896, 64.22845071361911, 64.49726250863844, 61.66992787391909, 62.83000807608328, 66.1286586330783, 66.45554111849877, 67.36281671831685, 68.80788849246117, 69.57828121800577, 68.63291940381451, 74.45862754698723, 77.57144404995826, 73.26315187638806, 72.27495777991511, 74.78852241270005, 74.52570792167418, 75.5867482769874, 74.53516867852981, 84.52267631407707, 34.080991975722775, 0.24219829889555133, 0.6116254771909406, 0.2476788459405784, 0.3766909175582471, 0.4565411199244761, 0.26500017051735236, 0.2815723377129724, 0.6154584295807347, 0.24426914180719086, 0.1985105262288163, 0.20524511324061503, 1.424189075346916, 3.680720055295575, 23.989704308971284, 50.386582882173606, 44.58742918506746, 70.91459351201212, 61.712030595348736, 47.13831517004198, 68.67245689515146, 2.7039187281362476, 0.2081933413301745, 0.143947507284822, 0.13533960547178023, 0.16979718310458047, 0.22039701471165304, 0.1760079498372732, 0.17740817470175607, 0.18777863032394843, 0.1964364504261363, 0.2339890845600636, 0.1208484318527964, 0.11905151900024184, 0.13480012635550193, 0.156651129645686], [0.06836234621943967, 0.05140489042406121, 0.07558716821574396, 0.010235285153612494, 0.02896120704169716, 0.10608929599965773, 0.013441165849085779, 0.08369586415468686, 0.12878869570070697, 0.09464879940834739, 0.05947812415298916, 0.03383267971296464, 0.11653630678812343, 0.22663465580872952, 0.5639312332195621, 10.6352605935066, 67.40888887836088, 40.76159638743247, 38.34193721894295, 39.602881170088246, 31.94629300025202, 30.689651889185754, 26.968203167761526, 8.13011876037044, 0.07821484979602598, 0.01824851313065137, 0.11295584931729302, 0.020388826810484453, 0.10790909955938978, 0.03816117224613986, 0.07059357729890654, 0.036808927468354666, 0.21453218264204843, 0.16757131464058356, 0.4724928478319799, 35.375115256155695, 81.06369495391846, 73.80991458892822, 76.30797017005183, 80.18520955116519, 76.62382295054775, 80.46667098999023, 76.93548663969963, 72.489880131137, 79.59220209429341, 77.38619835146012, 75.51669474570983, 77.06591329266949, 76.31679550293954, 73.5112496345274, 71.9677028348369, 65.47282265078637, 64.11925977276218, 67.34722921925207, 66.11366733427971, 66.84538548992526, 71.0641299524615, 67.6109693896386, 69.84315103100192, 66.21455069511168, 68.0480077189784, 68.16290178606587, 67.2199639966411, 66.75240962736069, 67.29569711992818, 65.3127311122033, 62.106519053059245, 64.12672796557027, 59.94587752126879, 60.89667181814871, 63.27336142140051, 61.348254296087454, 62.623495286510845, 60.230072852103945, 56.84957811909338, 59.95262399796517, 60.08371353149415, 62.65724335947345, 62.17170492295296, 68.67580659927862, 76.64011647624355, 75.54329626021847, 73.97876478010609, 76.30966463396626, 74.60697943164458, 73.02688398668843, 70.42784306310838, 69.77068131969821, 70.52890685296828, 67.70805589614376, 71.6318851901639, 71.15435231116511, 74.53818105882215, 72.95038992358793, 71.25962088184973, 73.86321959957, 73.86441984484273, 65.77852041490617, 59.694853674980905, 61.07437087643532, 55.322913200624534, 52.63458344244188, 55.351562192363126, 54.27263975143433, 51.40078229288901, 52.60125506308771, 51.875906836602, 52.777569524703495, 51.67792520215435, 54.027856396090606, 52.477115969504084, 52.73333303390011, 53.61227735396355, 52.00404282539122, 51.85994279000067, 53.06047831812213, 54.744159636958955, 53.547656305374645, 54.59881621022379, 53.44530205572806, 52.06964838889338, 54.6445079003611, 54.98587569882793, 55.11954222956012, 53.98322766826999, 58.59862573685185, 58.10763912816202, 59.85885973899596, 61.10751490439139, 60.58527092779837, 65.03571371878347, 66.50889319758262, 66.09663640299152, 66.04472775613108, 66.75152317170175, 65.0217540033402, 68.50839984032416, 66.89679991814398, 64.51903166309481, 62.842449834269864, 49.00045256460867, 2.840514533942746, 0.04946308736238749, 0.20860393381407186, 0.027941595725414735, 0.1296011625879234, 0.1504928399358065, 0.225091923268572, 0.07502381779974507, 0.026775010440859105, 2.0078605557641676, 0.9159839357579909, 4.514934891654599, 1.2205924454235262, 1.4242216800489735, 12.802626048364948, 27.168683352008944, 34.07225685734903, 40.276057950911984, 26.674213678606097, 48.34723280322168, 3.6740503099656876, 0.19397629695313592, 0.04767219979135741, 0.05204563870305016, 0.07318516847707572, 0.024528476755104722, 0.03139442486327983, 0.02311896307453994, 0.055746574991292534, 0.05072313728892515, 0.03233165299940494, 0.038154495789879755, 0.02583782635478964, 0.04636522314901795, 0.08029060333126015, 0.07338894020405508, 0.053738807928898645, 0.01534752776816247, 0.041555608247196486, 0.07194648091230663, 0.020199627991044716, 0.05967491681897833, 0.11168166123811277, 0.09222295901347553, 0.09616841141495014, 0.14676010716826687, 0.08558722798742595, 0.1425109085656943, 0.1616197307744334, 0.4692314276772161, 14.631805727558753, 82.264050053012, 49.18161115338726, 48.20034788500879, 26.936753603719897, 30.336830769815755, 40.481080239818944, 28.977574571486446, 6.962291877115927, 0.010177729925471208, 0.05845293380139817, 0.08525912019033587, 0.10135273524229566, 0.14849100622438616, 0.3049367323758141, 0.24146870739998358, 0.10241110103144761, 0.31039483304465976, 0.34835255915118807, 0.5771073939338808, 49.46438266384987, 92.75968505490212, 81.75565596549743, 84.6915029710339, 84.88594270521595, 84.22674917405652, 86.08201457608132, 84.3589722725653, 79.67125354274627, 84.91197939841979, 82.88685967845302, 79.57271575927734, 79.46181466502529, 80.02279204706993, 78.59359802738314, 75.64166930414017, 67.89743577280353, 70.11272768820487, 73.59873417885073, 69.27573311713435, 69.60492980095648, 72.57785889410204, 72.36490557270666, 73.50953948113226, 67.83363449958064, 73.48243590324157, 72.88393712812855, 69.66631489415323, 70.54232920369795, 69.825147351911, 68.22000365103445, 65.86526363126694, 66.35141003516414, 64.14098185877647, 64.2239321431806, 64.2543383567564, 63.970786294629505, 64.70166506305819, 62.90669433532223, 60.679360743491884, 62.600302311681936, 64.68464197651033, 65.71354635300176, 66.40717044953378, 70.91054562599429, 79.17670542193999, 79.89097687505907, 77.76722523473924, 80.33528727869835, 79.09635959133026, 75.53678512573242, 73.8613917750697, 72.0704532438709, 72.44001896150651, 70.77384318074873, 74.80106615251111, 75.46084803919639, 76.16724337300947, 76.47484348666283, 73.07052427722563, 74.05853009993031, 75.4006161228303, 67.03966832930043, 61.889313882397076, 63.780280697730284, 57.07184314727784, 53.73191356658936, 58.942578377262244, 56.00762567212505, 55.07541556512156, 56.95514086754092, 55.70506188177294, 59.289209996500325, 55.82169748121693, 56.11415332363498, 55.41402593735726, 54.49964692515712, 56.19567978766657, 56.09170559913882, 55.174078864436, 55.601993760754986, 58.475141679086995, 57.68157951293453, 57.753437334491366, 56.147948465039654, 56.609458461884536, 57.32668345974338, 58.24624000057098, 59.339020175318566, 57.53428274585355, 58.85340721376481, 62.188080818422385, 63.09278334340742, 64.5505282955785, 62.575916936320645, 68.83209736116471, 70.5146215808007, 69.74279326777305, 69.27763154429775, 71.54096464956962, 67.32993156679215, 73.66348466565533, 68.54842370556247, 71.03181746698195, 65.42424017383208, 62.54926050862959, 4.769351097845263, 0.05955293646923477, 0.8603332864661372, 0.3400181354053559, 0.11545249921900612, 0.2852720214474586, 0.058252092360729174, 0.05924913281154248, 0.3714308965831034, 5.267692150608187, 2.9108303737255836, 4.00549304100775, 2.063775658607483, 0.7466878814081992, 10.100150262155841, 28.52227564780943, 30.56291618654805, 39.871677275626894, 38.10810119875016, 61.63766245688162, 10.10695557440481, 0.3873269145767535, 0.16118135994240163, 0.07170569947770528, 0.11831121759549265, 0.08084655333791049, 0.06682809427260392, 0.027760358474728082, 0.07634362641481623, 0.0029055768625825765, 0.041838325334772955, 0.05170784372415754, 0.05348638195784823, 0.046253772677793625, 0.07517863650836291, 0.1469979315034805, 0.13691272105901472, 0.1124269268926113, 0.09350684576577718, 0.1209308858960867, 0.18024794006299588, 0.17222889939383154, 0.19748251284322432, 0.21548922564233505, 0.24018264495797698, 0.2526613285825137, 0.13009945681739238, 0.251112911669958, 0.3396548871551791, 0.8775439113378526, 15.20358531705795, 92.5187260104764, 58.74844066558346, 55.47447358408282, 55.522710892461966, 54.830067388473026, 50.71851738037602, 45.609481180867846, 12.035316305775797, 0.2576503842588394, 0.297066465981545, 0.3053469264939908, 0.2672770144718309, 0.31199617131102475, 0.29140939695700524, 0.4013988159356579, 0.1888756222662426, 0.5023482441902161, 1.461323011786707, 0.7586003647696588, 57.975114007149976, 111.0160981455157, 86.63001675759593, 95.07956304857808, 90.96953884247812, 92.7742370482414, 92.81453547939178, 92.53385066986085, 82.38602792063068, 91.28423060140302, 85.09176515763806, 85.16044585935532, 83.03229331970215, 84.03586310725059, 80.52989959716797, 80.57436358544135, 71.00803221425703, 73.36994232669954, 77.81871811036142, 73.70921165712419, 72.02008216611802, 78.97029461399202, 76.63282871246338, 77.98937259181854, 71.01863830320298, 77.90762255268713, 77.04404215658866, 75.36939405625867, 75.5430216943064, 76.0747068159042, 73.54531934184413, 71.1728580536381, 71.89584501328008, 67.72939358988117, 67.0401390137211, 69.86644990982549, 65.77473532768988, 68.75091998807846, 65.3982505490703, 62.02630266066521, 66.07527517503308, 66.91590186088317, 68.44582234659504, 68.13187583800286, 74.00367967544064, 85.45316450057491, 83.58231944422569, 79.67287740399762, 82.78902792161512, 80.79099609005837, 79.8394996889176, 78.84722632746544, 73.76141840411772, 76.86973202613093, 75.80749927028533, 79.22499764350154, 79.01458601797782, 80.1675824196108, 78.96699982304727, 75.59110210787865, 77.60835355327976, 79.41873919579291, 70.01407223363077, 64.91093527886176, 66.97986787365329, 62.44713767882317, 59.25187295483005, 62.4270002303585, 59.92910154404179, 58.60597625855477, 58.7194896513416, 58.19350373360419, 62.88294438392886, 58.42888909001505, 60.606585087314734, 59.0049675972231, 58.97109400841498, 61.69510949042536, 57.876187909033995, 58.45568280066214, 60.41969983808456, 61.58674616967479, 60.97462500295332, 61.582976771939194, 60.28064004836544, 60.70587988822692, 61.956190293835064, 62.74249607516874, 62.37917084847728, 60.70597010274088, 63.30775276307137, 63.53930988619405, 66.5860854425738, 68.50140233193675, 66.51180359625047, 74.03941246771043, 72.49197467680901, 72.30493253277194, 72.50815837613999, 75.43218335797711, 70.57325317013648, 78.91089424010246, 73.11343500691076, 77.31756471818494, 70.52531396189045, 68.18862468965592, 4.828807365509772, 0.22176835806139056, 0.4598112121945428, 0.36871784216453957, 0.2929187127419057, 0.96399282736163, 1.129553498279664, 0.15654654332226323, 0.163197519498006, 3.8182633586468238, 4.673679586379759, 8.461279080760095, 1.6063383077421498, 1.9333242456759177, 22.866590484496086, 42.07570414389334, 49.675759192435976, 58.182654457707564, 39.12618767830634, 77.3077666374945, 11.856558207542667, 0.5211133533908475, 0.356304980814457, 0.20036170108904763, 0.20078191563727396, 0.08293525375906499, 0.15746687538921833, 0.06998492810394495, 0.15655855558091597, 0.10438234485205143, 0.11475517534680905, 0.1709821679058575, 0.11756008370749413, 0.0992372140829121, 0.1945060161092589], [0.04676514402813008, 0.0911690365342844, 0.03625599967856561, 0.01636254255689921, 0.06949689945266133, 0.018571181703479062, 0.11719795394568674, 0.04078222333543724, 0.1375836302195826, 0.04981681313966552, 0.038812841108489426, 0.02739060230763449, 0.007376096590662436, 0.05770848403053899, 0.05871122034506933, 37.28023790544079, 61.34954867824432, 56.82613411257344, 51.06474891785653, 42.60150963260282, 25.349407657500237, 31.350306503234375, 10.77669341717997, 0.28211923256035776, 0.16817745872803275, 0.03776841428911975, 0.1299402790684854, 0.07970597865360399, 0.1298806467844594, 0.03351502901604099, 0.09505100322947388, 0.2501194948150266, 0.08647568313585174, 0.12439206347710664, 2.3363597931400424, 56.140864664508456, 69.1404741041122, 74.39623048228603, 72.32317939881356, 79.46405041602351, 75.57227473105155, 75.83813298133113, 75.662857947811, 74.38296502636325, 76.85326591614755, 76.13505640337544, 74.1593114791378, 78.06551364160354, 76.46083278040733, 75.2459962906376, 69.5683890004312, 67.5482036221412, 68.0091997884935, 67.9321095251268, 66.41004946924025, 68.34823377670781, 71.29816993590325, 70.89163980176373, 64.9102645535623, 67.80395784685689, 67.1696242978496, 69.06132851877521, 65.56994053625291, 66.65028679755427, 64.88523198712257, 65.17023532621323, 63.3065015269864, 60.718992371712964, 60.20467158286803, 60.73357966638381, 59.45685994240546, 58.886916022146906, 59.4537651923395, 62.49415905244889, 63.93302563698062, 58.836446885139715, 59.973808719265854, 64.7689768575853, 65.73934378162508, 71.61313626074022, 76.18751418206, 74.41595215951243, 78.28380138643327, 78.0296867124496, 74.35119382796749, 69.99376220087852, 70.27453330255324, 72.64926956545922, 72.00039186785298, 67.17017342967372, 66.24798497846051, 70.37947239414339, 72.85351522507207, 73.42673824679467, 69.36846579274824, 68.48896057375016, 70.1963996887207, 62.21090901282526, 59.72438912237845, 59.739815804266165, 52.71287395108131, 55.45355166158369, 57.146678047795454, 54.21616546569332, 55.28829828385384, 53.620184852230935, 51.88146483513617, 53.06532636765511, 52.127824983289166, 53.14496617163382, 52.516782899056714, 54.589747690385394, 54.099239610856586, 53.4719898623805, 53.7065319092043, 53.653968226525095, 54.63340367040327, 52.13239454453992, 54.846384448389855, 55.35925396027104, 53.26926216002434, 54.291306311084384, 52.15158670179306, 56.72976932217998, 55.26388937427152, 54.13495671364569, 56.689027663200136, 58.73858374934043, 60.024442595820275, 61.028577204673525, 61.853537944055375, 67.17662180623701, 65.59347083491664, 64.68586575600409, 66.35719945353847, 67.05039993409189, 64.92714643478394, 65.89107282700078, 66.49194071369787, 61.23272872740223, 66.15300086236769, 16.06310311825045, 0.1874334617487846, 0.8337131406991714, 0.03354385307419204, 0.09962856243815153, 0.025586063049793727, 0.13330038666965502, 2.0705772936344147, 5.56123350897143, 4.888653909006427, 0.6623710187212114, 1.9510623067617419, 2.3336744404608205, 0.06051061532249855, 2.7406085787280916, 22.274389074694728, 16.970640536277525, 34.26610431363506, 22.608451458715624, 48.83603465172553, 13.76204171488362, 0.1978464658942915, 0.0999023852449271, 0.08415259045338438, 0.03724794181424283, 0.07911050617094002, 0.04209991754783739, 0.006221165418654921, 0.008695756776198264, 0.07924538361088884, 0.016690682912726077, 0.04199100665808205, 0.0227150144881659, 0.08372757253387282, 0.0245989702506772, 0.0589047379851822, 0.051120104899089185, 0.05058691919510884, 0.04573515413569347, 0.046827721920224934, 0.017782304578671054, 0.04504477485053001, 0.05582020370169513, 0.10058267132168817, 0.10711308057990768, 0.030680921214121967, 0.11577237923178943, 0.020177480389153766, 0.06048039315388568, 0.03139886051236141, 46.73122413696782, 67.73271975978729, 74.96056541319817, 48.417129439692346, 31.495806824776437, 33.74577837605631, 35.62436619112569, 8.532326932876341, 0.26346827046044413, 0.21462176896391377, 0.007916585506585938, 0.1532635348097932, 0.13113330779296736, 0.9904663745434055, 0.19989771227682793, 0.3363260206195616, 0.13065677046054794, 0.36531616663259847, 0.07311381504780824, 4.797521560422836, 70.00374071059689, 82.32012425699543, 81.37298953148627, 82.30629397976784, 85.77708951888546, 80.92572950547742, 81.70535549040764, 83.11218415537189, 78.77292094692108, 81.98486358888688, 81.96305521072881, 79.76229959918608, 83.20806257186398, 78.81886759111958, 79.59039780401415, 74.69396191258585, 69.71958068109328, 74.16283376755254, 70.86663076954504, 71.63721961359825, 71.75927592862037, 74.77065209419497, 76.49283932101342, 70.60644426653462, 72.26188844250095, 72.5877981801187, 71.64534676459529, 69.41334555225988, 69.37399633469121, 67.43811053614463, 67.79106109373032, 66.04419431378766, 64.85956399671494, 63.21698911728398, 64.25914326021748, 62.63595665654829, 60.97549576913158, 60.21195542427802, 67.02755605020832, 67.47054069272934, 61.72073825713127, 61.74742606378371, 68.21596360975697, 67.57304791481265, 76.56028839849657, 80.62644481658936, 76.73251182802262, 81.44592992721066, 80.40976524353027, 76.2454632789858, 71.14919831675869, 71.86425424391224, 75.7859968370007, 74.34946014035133, 71.95953646013814, 69.79040299692463, 70.36131182024556, 74.8521589463757, 74.37506537283622, 71.7282029121153, 69.79273288480698, 73.48253788486605, 65.88094526721586, 61.882775291319824, 61.84543432727937, 55.795123423299486, 58.98510471467049, 59.352497439230646, 59.46490472362888, 60.004348293427505, 57.550129121349705, 54.7384722002091, 56.28774958272135, 56.87032745730493, 56.047680916324744, 56.635236278657, 56.39194342397875, 56.120899800331365, 57.34147471766318, 57.03018365367767, 56.335637800155155, 55.87044469771847, 56.39933316938339, 57.00634348777033, 58.921750591647246, 55.988382524059666, 56.44040822982789, 57.191032209704005, 59.0203550554091, 58.67099346653108, 57.19059682661488, 59.55663719484883, 61.01987738763133, 62.98272163637223, 64.35734371985158, 65.33289601725917, 71.73297251424482, 71.01015813889043, 68.27374796713552, 70.0470672115203, 69.54551373758625, 72.1293358648977, 70.26636692785448, 71.86929841195384, 66.55221969850602, 75.48036575317383, 21.74494754883551, 0.1417780688573276, 1.706586122032135, 0.14614634816685032, 0.21865917489893977, 0.2077540358708751, 0.8754907957007809, 3.859863771546272, 3.7705158562429495, 0.5660667186302524, 0.3678061975346458, 2.4369656462823195, 2.3061845091081437, 0.21439182001256177, 2.3403586495307187, 24.08480609616926, 19.942726319836034, 28.50543691265968, 31.889353913645593, 59.30032599356867, 21.413601406158943, 0.4682709372812702, 0.09602592672191321, 0.09597613866771422, 0.029789579829441446, 0.10421627997270516, 0.04777865919975504, 0.017920403418341474, 0.07255171335512593, 0.10308101427771392, 0.033449957507752606, 0.04948252684346611, 0.0560242627116461, 0.10457289390145771, 0.07697577918729476, 0.237320663046933, 0.18826790003766938, 0.10801833603651294, 0.17845690310482057, 0.17480231130555754, 0.11728406222837588, 0.24645083764147377, 0.16977986951749172, 0.3469549083421308, 0.2785998859232472, 0.12919878256657433, 0.14352743063242207, 0.12570719895583968, 0.1367710407582983, 0.16021109426454191, 54.257879872475904, 80.06862886490362, 81.7300271987915, 73.922698420863, 65.60313163265106, 47.541785855447095, 49.09895896911622, 17.351588972153202, 0.5576507831292769, 0.37988053995274734, 0.15167822310280415, 0.37851871141502935, 0.3278948246471344, 0.31061987903329635, 0.1212743537560586, 0.3198240577213226, 0.4225600030153029, 0.6841955766562493, 0.19285874321095406, 4.640264424585528, 75.40013759366929, 96.1638238353114, 90.84010847153203, 88.93986132837112, 93.01711020931121, 88.06233298393988, 90.387631693194, 88.6319866488057, 85.42079710191297, 87.02940817802184, 86.84169923105549, 84.6822383326869, 88.13695215409803, 85.952191968118, 82.27009050307736, 79.75783594192998, 75.03483157004081, 78.71523072642665, 74.65378899728098, 75.95013233923143, 76.89587070095924, 79.12734631569155, 79.496794362222, 73.77534281822943, 75.44673535131639, 76.13127523852934, 76.50671666668308, 74.27033024449503, 73.51940816448581, 72.09088094772832, 69.43321627955284, 69.20881748199463, 67.98383774295931, 67.1992774163523, 67.18143063206827, 66.5549575128863, 62.911511005893836, 64.09083043375324, 68.34404468536377, 70.99752026219522, 65.85308859425207, 65.28190912738924, 71.63526627325243, 72.5052793564335, 76.41715326616841, 82.61150144761609, 78.90406931600263, 85.61598208642776, 87.04798452315792, 80.57508530155306, 74.91155932026525, 77.02018630120062, 80.26360988616943, 78.59312734296246, 73.94591885228311, 72.34738826751709, 74.94699401240196, 78.86362967952606, 78.47122792274722, 74.87876046088435, 72.92970334329914, 76.22042286780574, 66.97123865927419, 64.9789531000199, 65.55896574451079, 61.28261343125374, 61.1615651653659, 65.48158130338116, 60.994193707743, 63.00134112758022, 60.880064502839126, 59.463602496731674, 59.73261825499996, 60.04106952298073, 60.708170552407545, 60.137344098860225, 59.631209296564904, 60.08096787237353, 59.460731321765536, 61.71390941066127, 59.703624094686205, 61.41529152470251, 57.860231707173014, 62.44217588055519, 63.54604459577992, 60.30696699696203, 61.013742800681825, 61.60703659057618, 64.25270272839454, 64.99486615580898, 60.66884879143008, 64.26513664184078, 63.787497858847345, 68.85777319631269, 67.81574849159487, 69.42578731044647, 74.76563930511475, 74.29249948070895, 71.34563845972862, 75.01754176232123, 74.0281238863545, 77.78031810637444, 73.55621568618282, 75.68767086152108, 70.84895656954858, 82.05595262588994, 23.222072932028002, 0.46594190741738967, 2.0817050578132754, 0.2951038100065724, 0.375520856149735, 0.34175954518779633, 0.40004262580506267, 2.121688718757322, 6.698350194961795, 6.652152028775985, 1.644764420005583, 2.5534671496960426, 3.910426064845055, 0.3070530655883974, 5.179619741055274, 38.205026888078265, 28.812097618656775, 54.12008700832244, 36.25024311004147, 66.56428490915607, 25.768236383315056, 0.7858136464511195, 0.2774244618992652, 0.2981590912226708, 0.1851948915470031, 0.1647822489781726, 0.17535758715483452, 0.08883032331904096, 0.17747411955027811, 0.3366805661109186, 0.15356289132708503, 0.15032341193047263, 0.19968345280616515, 0.19721819718758907, 0.18510417141500982], [0.17227682585437454, 0.07890022269660428, 0.09692814080945908, 0.06629542567797246, 0.10389179577149692, 0.1489366395699401, 0.03769312316792146, 0.03767967832485034, 0.04986539077494414, 0.041969203795757026, 0.009862445482623675, 0.02931968256410572, 0.056599265324973294, 0.09202847993301769, 1.158242081442187, 49.694963116799634, 49.109612126504224, 25.842524113193637, 39.07005463877032, 18.63413537702253, 25.459514471792406, 19.9089821692436, 0.30437727368647055, 0.015655769947766057, 0.058062313229686795, 0.29921564904432146, 0.028885935072696982, 0.1459698568308546, 0.6597951246846108, 2.148669722580141, 0.22717297047136292, 0.12250400914420044, 0.10251880533272222, 0.2593791689122877, 21.550174413188813, 82.52716264417096, 67.18072460543725, 73.13050516190069, 74.45738807801278, 76.2998273295741, 74.1686467201479, 76.52352794524163, 72.25890744117, 73.9583606104697, 78.72901393521217, 76.54418314656904, 77.7556856216923, 76.2155669735324, 73.56024003797963, 75.22218750369164, 65.91264586294851, 65.99012836333245, 67.24769515375938, 67.20418037906771, 68.89287056461458, 67.33544641925444, 71.88858862846129, 67.89825947053971, 66.45582352915119, 69.6908453972109, 67.9293481765255, 67.02783846086072, 67.45659274439659, 67.79157100185272, 63.585362434387214, 62.98734611080539, 60.99027525994086, 60.52314058426888, 58.61310712752804, 61.94689427652667, 58.64341528184953, 58.554279419683645, 56.722242293819306, 61.555025962091264, 63.58761779723629, 62.65591367598503, 58.39843580799719, 62.37410706858482, 65.45719985039004, 71.22485299264231, 76.21038944490495, 75.76855797921458, 74.66121796638735, 76.88231498964372, 69.19468125989361, 66.35953718616118, 69.4261246342813, 71.72981108388593, 71.8338401855961, 69.03154988442698, 67.53591091402116, 64.27307159669938, 68.80096158673688, 70.90784703531574, 67.22273318998276, 66.70953027663693, 73.18122925296908, 63.153046638734885, 57.6973121396957, 56.50705322142571, 52.23879668020433, 54.02449492485293, 51.470549491144, 58.65271522152809, 52.80742268408499, 56.752601438953036, 52.872381056508715, 51.081258173911806, 54.6055862211412, 52.30816379670174, 51.83111336923415, 53.017194963270626, 53.11142990666052, 52.04705553670084, 54.39129537151706, 53.40623132644161, 52.52711834446077, 55.87695190983435, 53.184997881612475, 51.126989087750836, 53.16074586683705, 52.28642994357694, 53.15983587695707, 52.4462979070602, 53.40273649461808, 55.067527678705034, 56.07246637344361, 55.12584547842703, 58.82449542322467, 60.31731028710643, 61.72350745047293, 65.79128772981706, 65.93933366960096, 65.03136773263255, 67.73806202796199, 66.0927846354823, 64.68248075054538, 66.17668413346814, 68.88187223865141, 59.53866097234911, 68.57126758944604, 35.99782682234241, 0.23284378311326429, 3.168999552726746, 1.6035757334001604, 0.2092530554340732, 2.552715525511773, 6.4225202991116435, 4.215367301817864, 0.4800851162402861, 0.021792587170737888, 0.20226067983575408, 3.341130806553749, 1.8182129773401448, 0.2270352278625773, 0.3376031198328541, 12.163909250690091, 30.18297972217683, 26.503286592421997, 25.48334090940414, 43.87144757855324, 25.82346139415618, 0.3678563609719277, 0.07660826382737967, 0.08718949322017931, 0.02464953396889952, 0.09810591672336864, 0.03243482972104703, 0.07613446142884993, 0.036628218818335764, 0.01580323516992071, 0.046714298772595586, 0.09701984919487469, 0.09898573040000855, 0.06551472845697595, 0.09457360787857925, 0.08531312938899764, 0.051209304346552784, 0.10670447992461343, 0.023275375246040286, 0.04526464974567775, 0.06523267020501437, 0.05633488455186448, 0.08220710250879489, 0.026853896429642077, 0.030383376494771054, 0.057406166583419814, 0.10591582305008367, 0.05292365590350763, 0.1068323323382966, 2.2877118616334857, 60.13826193348054, 60.14002700005809, 46.17150191337832, 30.319264434999038, 18.963232040405273, 34.88633694187288, 19.227739034160493, 0.19271643471813973, 0.046785476001640486, 0.05293296770222726, 0.23471420210215355, 0.0975498594644089, 0.47736473802116614, 2.482978970773759, 2.900490515655087, 1.2492809060119814, 0.4572879024330647, 0.4714126945022614, 0.12178300549426388, 29.763690117866766, 90.01859941790181, 76.23439435035952, 81.32175553229548, 80.59078262698266, 83.4711673182826, 79.92663121992543, 83.13220393273139, 77.78075741183373, 81.69450621451102, 84.34176875698952, 82.21477723890736, 81.48320813332835, 80.93834384795159, 78.81779286169237, 81.57900025767665, 72.38756902756231, 70.28610429456158, 68.91553401947021, 71.52683627220893, 71.8550915871897, 71.65943591825425, 76.27068411919379, 72.74603443761026, 70.62378114269626, 73.06912006870394, 71.91904975521949, 68.27128471866732, 71.63251276939147, 69.68198084062146, 68.38920685552782, 64.75699401670887, 64.83715941829067, 62.995947868593284, 62.11754483561363, 65.74799260785504, 62.18781801962084, 62.574100878930864, 60.91538152387066, 63.706806859662464, 66.4253310234316, 67.32797822644635, 61.05442170173892, 65.38847208023071, 69.02393264155235, 73.02256937949889, 79.56044658537834, 79.0757828374063, 77.36333093335553, 79.24171478517594, 68.971616068194, 69.48032394532235, 71.26910517292639, 71.84599168838994, 75.104171229947, 71.05052717270391, 71.46854985144832, 67.1203044153029, 71.68334668682468, 73.05594090492495, 70.62025100954118, 70.14870366742535, 76.39528213008758, 66.34183160720333, 60.470267034346065, 61.3728867807696, 56.599868266813225, 57.373394966125495, 55.726685908532914, 61.42145749061339, 54.53345383367231, 59.0899222127853, 56.52737502128848, 54.84168544892342, 55.0049933310478, 55.22969807347944, 55.38831480087773, 56.48562139080417, 55.92755048505722, 53.94100335336501, 57.208200423948234, 55.430021362919966, 55.998510083844586, 58.24967599684193, 58.533655597317605, 55.36268211180165, 55.74840407217703, 54.941835326533166, 54.472402141940215, 56.49597644805909, 55.83409609333162, 59.0887455017336, 61.12007433368314, 59.61825763025592, 61.83915853500367, 63.6494618077432, 64.86461600949688, 69.32281724868282, 69.74276973355201, 70.4344718686996, 70.15334775370937, 70.7521132499941, 69.54586675090175, 71.12261249173072, 73.17032506389003, 67.00482983742991, 74.39603436377742, 44.39589200481292, 0.30836800954514937, 5.6768448795041735, 3.4669788277918294, 0.13825910526417917, 7.5289179625049725, 7.270558303402317, 3.6536758032537278, 0.5321814852856821, 0.040690989924534675, 0.028431394039803458, 4.702938016383879, 2.0116810668860716, 0.26858463462802673, 0.3163883985290605, 9.405776012328364, 36.951072600580034, 26.08505210568828, 28.86265108662267, 56.126889259584495, 34.74337047146213, 0.09683361322048212, 0.04290170899982895, 0.036102418201945485, 0.08871256028332057, 0.059771815450080944, 0.010582915743842963, 0.018356669423801285, 0.05765093933610667, 0.09796690240862871, 0.031132390234439127, 0.011241850950154326, 0.07712929554644131, 0.05288705988336475, 0.05331005150031659, 0.24599218080120705, 0.180690202621683, 0.16401626830620153, 0.211840532720089, 0.18436713354481807, 0.387562747083364, 0.19099777774705043, 0.1687605282472026, 0.1472058630878887, 0.11926921820568463, 0.1344088699308134, 0.31237973621295345, 0.31506089073035026, 0.21204797400822564, 2.1943418008665887, 69.43942146916544, 68.46035080571329, 38.952548273148075, 57.82408706603512, 38.21276180205807, 46.399411232240745, 32.58867721403799, 0.38136203142423786, 0.20737378046877925, 0.2596287603580183, 0.4417855310584269, 0.11351701638270771, 0.29573224725261815, 2.6798875918311458, 4.491308004625382, 0.33791834969193707, 0.16270523139786336, 0.7899031463649966, 0.5129769786952004, 32.071924555686216, 97.70515841822471, 85.16289341834285, 91.2379623228504, 87.50234403917867, 93.22599211046773, 87.60649865673435, 90.36924362182619, 82.21695023198282, 87.34721429886358, 87.10184651036417, 89.24248003190564, 85.82461295589324, 85.57407548350673, 83.40928800644414, 85.73235096470003, 75.64196740427326, 74.37534778348862, 74.11812659232848, 75.84301240982549, 75.47142274918096, 75.5725492969636, 81.45976804917859, 79.51095411854406, 74.3166926599318, 77.21705006014916, 75.77687340397989, 73.54748449017926, 75.3399056773032, 73.28318734322825, 70.13793283893217, 69.54751414637413, 67.9738356990199, 69.27578803031676, 64.8382890609003, 70.88023354930263, 64.77791201683783, 65.08965415339317, 62.9452512341161, 68.84042847541072, 70.51695146868306, 71.26401393644272, 63.31040428530786, 70.62746817065825, 73.34734162976666, 76.18031271042364, 81.6541842491396, 81.80812943366267, 80.57271618996897, 84.07245097621795, 73.14048367161905, 71.68077361199164, 73.81030682594546, 77.26756234322825, 78.34568069827172, 76.93849901999198, 74.9915050691174, 69.5540488150812, 77.65981504994055, 77.15041683566186, 71.93451958317911, 69.96046127811556, 79.57164887459048, 70.13193945730887, 62.83478552295316, 64.3236780166626, 59.06957687870149, 60.04521939062304, 57.832151459109404, 67.45679670764555, 57.309534857350016, 61.445097615641934, 60.02052807038831, 58.22751068299817, 61.05883829055294, 60.51700207494921, 58.487693263638405, 61.80774427229359, 60.25582713465537, 58.44249186977264, 61.391949499807055, 58.904064624540275, 60.11683402522918, 65.98147561473232, 62.3455600584707, 59.54999269977693, 60.54610213925762, 59.89744409438103, 59.144960911043235, 61.19858057268205, 62.76149995865361, 62.16157344079787, 63.95145293205016, 63.372993546147505, 67.071776851531, 68.70012529434698, 70.67514850247291, 71.53311206448463, 73.05050449986612, 73.17817764897501, 76.84261275875953, 74.55450596347933, 74.1033314120385, 76.26273739722468, 78.4811201403218, 71.54411823518815, 79.23528994283369, 47.41097873257053, 0.4173200229002584, 13.635854163477498, 4.184180536577779, 0.2632556044526639, 4.606673736726084, 8.399616479873657, 5.120653769662304, 0.737017339035388, 0.12536026837845005, 0.42974269017577177, 4.352605150591943, 3.5550720749362825, 0.42558798085777994, 0.5253635479077217, 18.84675725813835, 47.56280191483037, 42.44138279268819, 39.0416213773912, 61.69132440320907, 40.65922252593502, 0.6847455052118148, 0.293590234772813, 0.22517761786378201, 0.2082987550285555, 0.22682363437789105, 0.12703564904269674, 0.11342756795666872, 0.13496979950897156, 0.17370515082392002, 0.18152327727406256, 0.1401126243534588, 0.10814242695848789, 0.1362276086283307, 0.1840372560846229], [0.003150038870855145, 0.009751890376660853, 0.050922982815292575, 0.034947146120811665, 0.03848099863276847, 0.1347021896752619, 0.006070786668363238, 0.055951614593786586, 0.048463595430216486, 0.07834912968739387, 0.10900637495421595, 0.016690485645085573, 0.11513946803226588, 0.30665105328925196, 12.018273607377084, 65.66299876859112, 36.26289275384719, 35.049201596167784, 17.913029193878174, 22.164907878445042, 25.06290989537393, 3.0090102409162833, 0.05309621337801219, 0.07799392536042199, 0.046878157318719936, 0.10668012598950057, 0.0733588406095101, 0.44405958645286103, 4.962059105596235, 5.255723038027364, 2.4135777786854775, 3.0718118000415067, 0.11189123225067893, 3.2982718031252585, 54.41212315713206, 81.83298941581481, 69.35945218609226, 72.99286919255411, 73.70453619187879, 73.62583775674143, 71.83009824445172, 75.99036801245906, 71.76792867722051, 75.29216258756577, 75.71704156937139, 76.38748445818501, 77.3801657461351, 78.02131637450188, 73.03936496857675, 72.41199754899549, 63.430773981155895, 68.25966665821691, 66.37779974168348, 69.81482367361747, 69.62614197884837, 70.17475605010986, 69.97176554895216, 62.752043124168154, 70.00718455160819, 70.7896738667642, 66.42922201464253, 65.622182584578, 64.734871848937, 62.18205998020788, 64.86952289458245, 62.80781530564832, 60.22230263679259, 61.0285811270437, 60.225652340919744, 59.37941274335308, 60.75866714600594, 63.88036781741727, 60.70755866266067, 59.16440802235758, 58.593534500368186, 60.24619771588234, 61.871027792653734, 56.88589142214868, 67.5248262959142, 71.63526627325243, 75.04110736231651, 74.52392716561594, 78.4404843853366, 71.85076129051947, 62.02089763456776, 63.67037980787216, 62.86491717061689, 67.12560745977586, 66.6857607133927, 64.57729062726422, 62.94325867006856, 61.7570201812252, 66.53960535603186, 68.733245788082, 69.72762153994653, 71.83286743779337, 70.17495216861849, 64.84350973559965, 58.504300578948, 55.6176910861846, 55.29544876467798, 56.020742077981275, 55.10766137030817, 50.3796834330405, 50.72054916812528, 54.840410678617424, 49.58409732387912, 51.700427839832926, 50.02518746160692, 51.35718907079389, 49.93163108825684, 54.00431040794619, 52.182075285142474, 54.38184638177195, 53.34724672379033, 55.21357713207122, 54.55349714525285, 50.402523394553896, 53.916735649108894, 51.5179278004554, 52.259879419880534, 50.97617003225511, 50.05353050847208, 52.92417595463415, 50.006987664007376, 55.194016272021884, 56.85382604599, 57.81095889306838, 55.410021197411325, 55.25904132473854, 60.99358966273647, 64.43834066390991, 64.43208448348507, 67.1288630270189, 63.93515548398418, 66.36094139468285, 64.73643295226559, 66.3260244554089, 66.60704658877465, 66.26591805488833, 68.31126151546356, 52.42466603555987, 1.9146696982845184, 0.35201111928589884, 0.21439871480388029, 4.137769091513849, 9.777742220509438, 0.6400605158940439, 0.0444408830615782, 0.07880041676182901, 0.13025443640447434, 0.1164469579535146, 8.05894882448258, 1.2585695688762975, 0.19118447337419758, 0.06328153236198329, 2.0323226624919526, 29.65862354924602, 29.45556832898048, 36.49065302264306, 34.155026712725245, 41.4273363544095, 0.026670475828371225, 0.08111116010695696, 0.0950869787183981, 0.03489934606477618, 0.03613720242414744, 0.036319749685184616, 0.04435500460526636, 0.04719275132482571, 0.020757466404428406, 0.023590235467699748, 0.03010834135385531, 0.08651844616378508, 0.0807905906150418, 0.043445439904087016, 0.026613938539559324, 0.030411411482360096, 0.04414872010989536, 0.0607967836361739, 0.015252493603545574, 0.0706273234719711, 0.023917226691640193, 0.09910850365075374, 0.02460278919897974, 0.07126060239369832, 0.11343980238081948, 0.06502099245065643, 0.20677212565656633, 0.4281448146268245, 16.220945177539704, 76.78974705357706, 51.76438600786271, 34.65423068692608, 15.498411251652627, 32.70903318159042, 29.23118325971788, 2.3876614532163067, 0.03136857705671461, 0.10555230666913333, 0.051859295476348176, 0.22209812826927633, 0.2701604162012377, 1.3783145047003225, 3.0562439128275845, 5.388846320490684, 2.917040711449039, 5.7741892818481695, 0.13653287934439798, 4.186004929004177, 63.565232830662886, 89.43575089977634, 81.3239049911499, 82.05208516890004, 80.90591369136688, 81.45130357434674, 77.33978886758128, 79.1632281580279, 78.15097424291795, 81.66051495459773, 81.06662888680735, 80.69797315905171, 81.97271993083339, 81.4965912603563, 77.16321160716396, 76.7877152658278, 68.69604602936776, 72.90769884663244, 70.3026645414291, 74.25777865994361, 73.62462966672837, 73.84271344830914, 71.57863509270453, 69.4909143447876, 73.66620679055491, 73.83438233406314, 69.52163434797718, 72.04298880792433, 68.69925452816871, 66.39548178642028, 68.29195560947542, 66.26599650229177, 64.24574836607903, 63.2027038451164, 63.71008988349669, 63.704849596946474, 61.907501912886104, 67.13808059692383, 62.127644938807336, 62.45493142835556, 61.87413430983021, 64.38489837031211, 64.41603414473995, 61.86119441063174, 69.14920530011578, 73.53470540815785, 77.31103004947786, 77.13513528147053, 77.70194130559122, 75.93366622924805, 64.8038741850084, 65.24048497599941, 66.7624822739632, 67.97538895760813, 69.23523856747535, 66.83375173999418, 63.50742101669312, 65.90986098012617, 70.16305954225602, 70.3821631400816, 72.73047831750685, 74.77850467927995, 72.1734703740766, 66.44884171024447, 62.58892743818222, 60.54264653113581, 59.13748095112463, 60.107879254125784, 56.96710409656648, 53.22709275830177, 55.60193100283223, 56.31655154689666, 52.00769455202165, 54.44553390625985, 52.871023916429095, 53.3300785095461, 54.87135425690682, 56.34130954742432, 54.10438183815249, 56.06183282790646, 55.83413531703334, 58.08057869634321, 55.40234904135428, 54.3965317356971, 56.92055732973161, 55.54549594079295, 54.67973470687867, 55.365929834304325, 55.822489799991736, 56.626646287979625, 54.110779223903535, 56.50614323154573, 60.57626124351256, 60.59284110223094, 59.71179831412531, 59.10925949773481, 65.04980287244244, 68.15206819964995, 68.34103230507144, 69.30194239462577, 68.96159049003356, 69.0873573672387, 69.08142674353816, 69.50030449898013, 71.8654074207429, 69.7787457127725, 72.59760410554948, 60.4877451158339, 2.5120934988221815, 2.8626695515648013, 3.311467636977473, 5.739752832920321, 4.831285322866132, 0.36979257159175416, 0.7872445148325736, 0.07420740555971861, 0.2642617843324139, 0.2486156795414225, 10.452488929994646, 0.3870447797159995, 0.04994489921016559, 0.04054827157468085, 1.6434749408114342, 38.17245552616735, 34.28819510244554, 38.219543580086004, 44.62835127307523, 52.405622928373276, 0.18336587194954196, 0.05774306906988064, 0.060038559604436166, 0.03806173786400788, 0.052866643640182676, 0.040479974836231246, 0.1119994498308628, 0.07018778052541517, 0.050762755525929314, 0.008333670106836626, 0.009872864278393888, 0.05246090049284601, 0.07005895518006817, 0.06737794621937698, 0.1015895789849662, 0.1530219566437506, 0.1487031512923779, 0.15072577663006323, 0.1560474370395945, 0.266535809083331, 0.1170304258384051, 0.3039599396288395, 0.09541386843568857, 0.148747262635058, 0.23610802247158943, 0.16670278543906827, 0.42730355815541365, 0.687241051946917, 17.958236471299205, 89.25126614109163, 55.36182703510408, 51.42095112031507, 30.001544606301096, 43.06267053850236, 43.558105114967596, 5.026502176638573, 0.12704420624481094, 0.430105478773194, 0.21533930223555336, 0.5253390943811787, 0.2718076584560256, 0.930367022031738, 9.343735883312842, 17.193503725913263, 6.937452487407192, 7.574045811930011, 0.5971651692544261, 4.5871996591168065, 69.61195868830528, 97.05808501089774, 90.83276579456945, 88.58353753243723, 87.86240977625694, 87.0658391521823, 84.00414682203724, 87.06892213513775, 83.91220646519815, 88.13066851708197, 84.36794665551956, 85.5704512134675, 88.36259042063068, 86.68189402549498, 81.3798850582492, 79.21614093165245, 70.80773245903754, 77.0040810492731, 73.9979608597294, 77.3585299522646, 78.03324822456607, 77.4163378438642, 77.3830290763609, 71.85721751182311, 77.22127837519493, 78.51081248252623, 73.07617249027376, 74.69120840872489, 71.5226471808649, 70.2601303592805, 72.23733440522226, 70.65471295387515, 65.76636106737199, 68.57874362699448, 66.58577949770036, 67.09219671064808, 67.85685493100074, 71.59957270468436, 67.35016315214096, 65.91027675136444, 65.3299738514808, 70.01019693190052, 69.97571145334553, 64.36013644741428, 74.21572300695604, 76.62232460514193, 80.81482056648501, 79.27961272578086, 80.41803359985352, 78.30947722158125, 69.9628068554786, 70.07357458914481, 71.1168779865388, 72.95970163037701, 73.33817897304412, 72.31724877511301, 67.72593405938917, 68.9379072189331, 73.58993238018405, 72.71206671191801, 73.99023379048994, 79.59430448470577, 75.94150312485235, 68.7674331665039, 67.54148067966585, 63.6023659090842, 63.20668112847113, 64.01219475653865, 63.83266395138156, 57.94536675176313, 58.18993829911756, 62.64172254070159, 54.319276732783166, 57.38243995174285, 56.39877619281892, 56.138797575427645, 55.39159782471196, 59.316592062673266, 57.11992356085009, 59.87792245803341, 60.19106095837009, 61.939041691441695, 59.052683230369325, 58.386496113192656, 61.03451175074424, 59.65959548950196, 60.43865665312737, 59.82112653793828, 59.28412268238684, 61.94022624723373, 57.2083180950534, 60.782013093271566, 64.71307131551927, 65.44741745918029, 62.53201776935209, 61.01571183050833, 68.97866064502348, 74.09810681496897, 72.23282367952409, 72.79809213453724, 71.58252608391547, 74.69791566171955, 73.79231883633521, 77.80787667920514, 75.58422227059641, 78.9426968174596, 76.2676638941611, 64.33739846752536, 2.8757729645698302, 7.243477279140103, 5.694100856781007, 4.957510627085163, 12.64565573584649, 0.5692941551246952, 0.3344201777250536, 0.15889049657890875, 0.5107464370948653, 0.25852458251099436, 10.359144364633869, 2.7430286811244105, 0.4469283712246726, 0.289839192503883, 4.914369948448674, 44.6906542008923, 47.48158924041256, 55.888385618886645, 47.7828037354254, 62.52442013832831, 0.2193348184828797, 0.2289436294907524, 0.20208526102285232, 0.1740592826277979, 0.15580444927177123, 0.12549422651288972, 0.29557667011695526, 0.18550747074186805, 0.1913766388691241, 0.15626442378326771, 0.06638197063077843, 0.15254307508228288, 0.10290617769163463, 0.15815735043537232], [0.11887465994204245, 0.03308603510020241, 0.06605492769590308, 0.09659128428827371, 0.024961797152495673, 0.028872179964016524, 0.054704929071087996, 0.1322041761370436, 0.10954237603131803, 0.06974140407457467, 0.012909158005289013, 0.08648417905093202, 0.06362999511522151, 0.060874974400165587, 20.59286309826759, 63.87591200490152, 32.35632581095542, 44.985251657424435, 16.498555829448087, 19.24600943442314, 11.0110128694965, 0.12305605210243695, 0.0763252403046335, 0.023278575578343966, 0.08523702621459962, 0.19790972943507856, 0.32941029977894604, 2.196699880784558, 1.8562027259219078, 2.747036117699839, 5.940937082613669, 5.469033785404698, 0.08706187063287343, 15.991467891200898, 77.97485982218097, 74.84604004890689, 73.23319281301191, 73.90145486400974, 72.25997432585686, 69.48758817488148, 68.83925960909936, 72.29909604595554, 70.35727177896808, 75.69547637816399, 75.746624085211, 76.77160216915992, 76.01443567583638, 80.0334373597176, 74.93006506273824, 71.30337884349208, 63.75078447403447, 69.60810692079606, 65.815779009173, 71.23169360622283, 69.65204531146635, 70.71266205080094, 64.98649974023142, 68.09357781564036, 70.82227660763648, 67.74323171184909, 66.23901844024658, 66.19430342028218, 66.9550157362415, 64.04995149181735, 60.247664682326786, 59.9410726178077, 59.4855167788844, 60.6849697328383, 61.52600826755647, 59.49668376676498, 58.58937678798553, 61.95926150967998, 59.14135625285488, 59.503665585671705, 56.56224096975019, 58.19968931136593, 62.820461027083866, 58.52290830304546, 61.508718459836906, 69.51105963799262, 78.1569205560992, 74.36609098988195, 71.579192069269, 67.25491231487644, 55.703359573118156, 58.67430786932669, 65.33784212604647, 70.60607556373843, 69.9330125316497, 66.31333951027163, 59.32067917239282, 58.527128773350874, 61.96643160235498, 66.25347629670175, 73.0430990649808, 72.36773752397107, 73.17496915017405, 64.44717776390814, 57.27158592593286, 54.29040416594475, 55.598800951434725, 54.81104389313729, 48.483468486416726, 51.50088117968652, 50.06086141832414, 50.14814592176869, 50.50162207695746, 50.83301921044627, 51.73830616858698, 52.897001774080344, 51.769316427169315, 51.040202725318174, 52.4074899765753, 52.054617866393066, 51.3690189392336, 52.023799803949174, 52.18281269073487, 52.72577854894823, 52.10054097637054, 53.93230745869299, 51.329391233382694, 50.63337841341573, 51.735497751543605, 50.30890818565123, 49.73036250760479, 53.892416954040534, 56.11982114853398, 59.08234419361238, 58.38846514301916, 56.35420237818072, 57.840980714367284, 62.54830737267772, 64.59379988331949, 64.97622705275013, 63.583452240113296, 67.22539255695959, 63.67349416978898, 65.76534909586753, 66.31402984742196, 63.637227935175744, 65.24737265802199, 53.86614491862636, 2.5198186068765582, 1.4170638447807682, 4.836244669652754, 2.282552719116211, 0.25402626743720425, 0.6672645432333792, 1.0127309733821501, 0.15593411731383494, 0.059755206663882544, 2.158532032082158, 10.708617741061795, 0.021651743821078734, 0.12032841136979482, 0.017485650436532114, 0.490665250127354, 38.11691476452736, 22.93465929646646, 16.01318213247484, 27.55763146185106, 47.0151331347804, 0.4551031422470847, 0.05943524621186718, 0.019943645456805825, 0.07245019138340028, 0.033746506312801954, 0.03872200989374711, 0.039048328875534, 0.07659672654324001, 0.043586231542811285, 0.03839865184178756, 0.03629431939653812, 0.038797492536926464, 0.016311251055148822, 0.04100238551355658, 0.11640802536520267, 0.04905200075177897, 0.0797095256406934, 0.02550096791838446, 0.06256185404415573, 0.020588553593223615, 0.0635273852986434, 0.06878001735575738, 0.0651222309698501, 0.03693891726734658, 0.017902421419538798, 0.06245350622902475, 0.05544116637939888, 0.318764251686873, 28.46794101499742, 68.70386723549136, 51.217893938864435, 40.354925047966745, 15.967917000093768, 28.244405138877134, 11.013158405980757, 0.08463903330266477, 0.13754469763127067, 0.01456191992357133, 0.06036790080308434, 0.24032052546258897, 0.5830838603358115, 1.0012953031447627, 1.2973721061022052, 2.933381550735043, 0.8262375321599745, 4.540777427534904, 0.23901157231340486, 20.74915974370895, 83.7721464710851, 81.59593705208071, 79.765484563766, 79.59673635421261, 79.65240263169812, 76.97605963676207, 78.72429140152471, 79.7229346921367, 78.77949483932989, 81.33110646278628, 82.21979002798759, 80.55729343045144, 80.9647649334323, 84.24496466113676, 78.0802539087111, 74.40358100398895, 66.86359313226515, 74.39923501783802, 69.81179560384443, 74.30727897151824, 73.54981437806161, 71.70597876271894, 70.40128077230146, 72.178600834262, 74.9630129721857, 71.61110447299096, 70.52798117360761, 70.35631472064604, 70.19755286555137, 67.85165386815225, 64.4056006400816, 61.193363820352864, 62.810388380481356, 63.89693198665496, 64.18891322228217, 61.576273441314704, 61.56233333772229, 64.44906050159086, 61.212383393318426, 63.94364349303707, 62.888494537722686, 60.86376705477315, 68.34504881212789, 64.35914801013085, 65.86364761475595, 70.51240151928317, 77.3788478297572, 76.49184303898966, 73.4031020441363, 69.63189217352098, 58.716551796082534, 64.8423251798076, 72.01066847770446, 73.04690376404794, 74.11967985091671, 72.12725700870638, 65.54164063545966, 61.2242603302002, 64.00156121100149, 70.89545234557121, 74.03672956651258, 75.92492718850413, 74.24679602346113, 64.53079877361175, 62.19669434332079, 57.150365075757435, 59.213720060163936, 56.59082328119586, 52.589197697178015, 57.120021620104396, 53.09581495100453, 53.378111854676284, 53.291662816078436, 53.639169123864946, 54.63896166893744, 55.79055386204874, 54.49091965152372, 55.07008506405739, 54.91238617127942, 57.99444344735915, 54.270482447839555, 55.577745668349735, 55.3199282769234, 58.06727793908889, 56.54915986522552, 57.27870502779561, 55.005271819330034, 53.91328788572743, 55.35816746373331, 54.86214060937205, 53.77230613462387, 57.343016209140906, 60.3032446676685, 62.69409402724236, 63.914704245905725, 61.83140008680282, 61.32544179116527, 64.72385391112297, 66.7287185115199, 68.52302243632656, 68.18753427074802, 71.19679235642957, 68.9166009041571, 72.17170530749907, 69.49846882973948, 69.95994352525281, 69.89941350875363, 62.26817953971125, 2.4742813600647837, 1.8734338206629602, 7.521567440802052, 3.156288621887084, 1.3602196305028855, 1.5836825750527845, 4.031719478868669, 1.3099511472448226, 0.18502682717817445, 4.495717238995337, 7.739509526760348, 0.035474961548442804, 0.10558454364898706, 0.027363657080117735, 0.3878061485386664, 45.142475943411554, 28.95623491656396, 15.364297570720797, 37.99936917520339, 57.583892883793006, 1.0313780437554083, 0.1730653907983534, 0.037199122861268065, 0.08187089716234515, 0.044119386603274656, 0.062488401533975724, 0.04979062059353437, 0.02213828051612983, 0.04900880871460803, 0.020501054860951922, 0.051081785181116675, 0.055532625786239104, 0.0025093142927113564, 0.08355121909370346, 0.14391592914058318, 0.2237586851321882, 0.1978842646724755, 0.16203297392254876, 0.13631186297824308, 0.09607376891278452, 0.18815176110834847, 0.24873030161665333, 0.20176505159226157, 0.22226211705034782, 0.09077952679006324, 0.1748584808721658, 0.14222302804550818, 0.31833744878249787, 32.68579509950454, 83.27584897318195, 53.16874357961839, 66.67105966998686, 33.51509201911188, 38.125265490624216, 19.5800345559274, 0.2925749844120395, 0.43435570393358514, 0.12965040671969616, 0.3203082252894679, 0.5655076583066295, 0.5232895333920756, 5.3138530542773585, 10.478877655921444, 8.87314756070414, 13.735648085994105, 10.764086919446147, 0.3218458556840497, 21.92976963135504, 96.34210340438351, 88.43858242034914, 88.28441758309641, 86.15489221388295, 89.94188570207166, 82.60033838210568, 85.7832633295367, 84.43356006376206, 81.92547105973767, 85.94743805546915, 86.88070328004899, 86.93488690160936, 84.41831773327243, 89.97741453109249, 81.31911969953968, 80.16665674025013, 70.93956332052909, 78.51065558771934, 74.73746884253718, 78.85103887127292, 77.88459823977563, 77.22096458558114, 73.59788694689351, 74.55938539197369, 78.79594525983258, 77.04053555765461, 73.72293995272729, 74.05503134573661, 74.25171467565721, 71.8082114188902, 67.24370218092396, 66.19161267434397, 65.50397411469491, 68.80358957475232, 68.21687359963694, 63.79864915724724, 64.55518414897304, 72.5526302091537, 67.57680554543772, 68.78647235132033, 67.32981389568698, 65.01283845593854, 73.21249838798278, 66.35657971905124, 70.58931919836229, 74.25497808764058, 84.68556450259301, 82.9061185159991, 77.39349395998063, 75.23344470608619, 60.78412332842427, 66.21938305516397, 70.2726270306495, 77.10261098800167, 74.01528204641035, 73.39786960232642, 67.70349025726318, 65.49031249938473, 69.82764982408094, 74.3123152948195, 77.6031054219892, 77.79642335830196, 78.61350797837781, 70.68953575626497, 64.1902272162899, 60.01775103230631, 63.461988202987186, 62.17414855957032, 55.60031890869141, 60.14486328248055, 58.62740024443596, 58.196057196586366, 56.29235836767382, 55.458101610983576, 59.216646148312485, 59.90345708785519, 58.23577119458107, 59.234261512756355, 58.12693326703964, 61.95553918038646, 56.80623985105946, 59.46252384493428, 60.60116829410676, 60.97433474756057, 60.50429751796108, 63.27817024723176, 58.20066990390901, 58.366550860866425, 60.24346382387223, 58.22566716901718, 55.45011958768291, 60.65739939289709, 63.21426307001422, 69.46545816236927, 65.07415686884235, 65.02408781359273, 66.78353755704819, 69.27245401567029, 69.78148352715277, 73.15543574671592, 73.330914743485, 76.98623426498906, 71.6613971033404, 76.1645761612923, 73.64129189522036, 75.01478041371992, 71.22613953005883, 65.22265780356624, 3.9951274423829974, 4.120063022259743, 8.750058681734147, 4.168571464477047, 1.5950198183136604, 0.9403290455379795, 3.2318420515906428, 1.695232944142434, 0.34615379487795217, 1.9681589377503244, 14.292334395070231, 0.17133922616560615, 0.2797884560160099, 0.13881398274773551, 1.1608976486229128, 53.91233867214572, 36.72736414017216, 31.338278555100967, 43.18878650665284, 68.37511770186886, 1.3765664759182161, 0.3775229503310496, 0.2319533591188731, 0.21708305624704208, 0.13280370122482701, 0.1486650614007827, 0.13825493774587108, 0.15057730879033768, 0.16853581933725267, 0.132230376344054, 0.14672266079052804, 0.14201811484752164, 0.08949426874037712, 0.19534146563420374], [0.1780272656751256, 0.04006070257615178, 0.0277946524006585, 0.04871497569125026, 0.03524089487449777, 0.041037648540711215, 0.07304971647118369, 0.09182559686803049, 0.0238727706093942, 0.03752300568345574, 0.07142174132769147, 0.09760972157481218, 0.10224643809300277, 0.03486166603022045, 39.54562633268295, 60.56548649264921, 27.74620136907024, 23.381278014952137, 18.754754143376505, 20.368046568286037, 3.489142425598637, 0.06406925843968507, 0.3504835706084006, 0.032973109909723845, 0.208306186081421, 0.09769319451504177, 0.7462202613392185, 2.1235515994410363, 0.6185251714721803, 3.1516293364186443, 1.6429741031700567, 2.9180855328036897, 0.7856646576716054, 34.44083413770122, 79.77445894672026, 71.44876541629915, 72.85359367247551, 69.93047083577802, 73.76008479825913, 70.79992694239463, 71.88946723937988, 70.10616164053641, 72.37672759640601, 75.977824272648, 78.16478098592451, 78.81954223878923, 80.8151343560988, 75.44140092788204, 74.47983188013878, 66.00242107145249, 64.67786019848239, 65.70164980426912, 68.60494505974555, 71.23720061394476, 70.72479001937374, 69.49525248619818, 64.33158159255981, 71.21970684297624, 68.17925806968444, 65.44299302562591, 66.0549965212422, 65.70410520799699, 65.04965382237589, 64.12072673920663, 61.55674003785657, 63.29389895162275, 58.25432008312595, 58.65143260648174, 59.43753050219629, 59.41815007117487, 59.711504136362386, 56.958643544104795, 55.43456738994968, 55.84555725897513, 57.80376134380218, 59.18147817734749, 61.75827141731017, 67.63240122026014, 68.03238884095224, 62.72027977051274, 61.66105155021914, 66.6869923376268, 70.92565459589805, 63.62348002772178, 60.6534731003546, 72.55312442779541, 75.23605700462096, 73.00088651718633, 73.9516455127347, 74.15394567674207, 68.71927430552822, 61.979293054150006, 62.666162829245295, 67.53731512254285, 68.32602531679215, 71.20367219371181, 65.36918578609344, 56.08202911192372, 58.39690216125981, 55.22333598905995, 58.76004695892335, 52.352921962738044, 50.20929175038492, 51.10908739028439, 47.43216737624138, 51.38115475254675, 49.28477733365951, 48.94775159897343, 49.7955915235704, 53.169449606249415, 52.73036772204984, 52.015688342432824, 48.78063117304156, 52.48860066936862, 52.86778403866676, 54.360830322388686, 52.20269126276816, 51.50354446903352, 51.84948575112128, 51.8154788017273, 54.96558527792654, 51.46829805066509, 50.555346781207675, 49.64589034357379, 49.121057602667044, 50.585458817020545, 54.76117880113664, 59.45281205638763, 57.731279865387954, 58.30378509336903, 58.44719086923907, 60.137759870098485, 61.22136562101303, 64.666128389297, 63.33695873137444, 65.42932356557539, 62.808250688737445, 67.42011470179405, 64.66624606040217, 64.77801007609214, 66.89914549550703, 52.26860277114376, 1.6263431310653689, 1.6820640765851544, 3.821415718524687, 0.9518256963741396, 0.1395785844614429, 1.4611673427204934, 6.224269982307188, 1.9650435952409624, 0.06064933469338764, 11.090952734793387, 2.0011427613996693, 0.06235361985501744, 0.07072514523902247, 0.06651984347451119, 0.21705849546818964, 33.823566821313676, 26.837260723114017, 22.968505428683375, 30.07478310215858, 42.773776208200765, 1.4222857452207998, 0.20162211490734933, 0.027813350691670374, 0.0363107443216347, 0.06998183310873086, 0.07175593186290034, 0.008277108877777092, 0.05701015658316113, 0.006374573567882181, 0.06361928137560045, 0.028435488779758735, 0.03203572855601388, 0.0578961372675915, 0.04070924196933066, 0.09582003293138358, 0.04618867818686751, 0.08161308559318704, 0.01768811598360058, 0.038256293553258144, 0.02631016552538401, 0.16307658485827908, 0.02638732398589773, 0.026535401120781902, 0.01823690115293909, 0.026039845655642213, 0.1000139199858231, 0.07599995171110477, 0.019189698110905387, 48.648466910085375, 74.55259969157558, 43.437500076909224, 29.99833610750014, 25.44755320395193, 27.30104961702901, 3.1683109316133686, 0.026563811491453843, 0.24214960634708407, 0.04749900263343607, 0.05119875531583544, 0.4579925194623009, 1.6559431749966838, 1.017009053499468, 0.7477860224823798, 0.548316216276538, 2.1887573263337536, 0.9556993433544714, 0.6914343720962924, 38.375626456352975, 86.52845090435397, 77.0464583366148, 80.94566299069314, 78.28267174382364, 80.71585916703748, 78.46398722740912, 78.54944782872354, 75.99888740047332, 77.95028225068124, 81.1123872572376, 81.42023840258199, 84.15296154637491, 84.88350299096878, 81.87462929756411, 78.66057642044561, 72.10148703667426, 68.8267707824707, 71.8164405515117, 72.41762222782259, 75.4877241196171, 76.48935625630041, 72.16243282441171, 69.0899069078507, 72.29911173543623, 73.37156618795088, 69.59531214929396, 69.62339631972775, 68.160901377278, 66.42894744873047, 65.78389406204224, 63.30967472445581, 65.10560643288397, 61.55230775956185, 60.375690844751176, 62.26168801707607, 62.674929326580425, 64.5821661333884, 60.916848490315104, 60.04756104561591, 60.30313876367385, 59.60967940668906, 64.38776954527825, 65.03196001052856, 68.39743598814934, 71.9565240798458, 67.31376355694186, 61.801817570963216, 66.48498242901218, 76.27550078976539, 66.95796535861108, 66.08886226530998, 75.73714763887467, 77.47207472401281, 76.04912511764034, 75.58085687698858, 77.54190860256072, 72.61164619076636, 66.64464642924648, 65.01813757804133, 69.38516724494197, 69.2306572391141, 72.3740525399485, 66.22178354570943, 59.594676340779955, 62.08230233961537, 59.727817273909054, 59.950600054956254, 56.290750195903165, 55.05925932238179, 53.600961316016416, 52.08283931978288, 53.993037516070956, 53.869137687067834, 52.96989117899249, 51.33508259250272, 55.223449737794944, 55.186724585871545, 54.888440101377434, 53.703939222520404, 55.42860930965793, 54.46481235565678, 55.56686109112155, 55.75895524794056, 55.583648835459066, 55.06440547204787, 54.74827812563989, 56.73746501245807, 55.677762185373616, 54.64441376347696, 54.267736788718935, 53.57897250883041, 54.43306076911188, 58.74360046079082, 64.48009037202405, 63.45550844746252, 63.53939225596767, 62.286493086045795, 64.83395091948971, 63.972606274389456, 68.97037659921955, 65.62081759975803, 68.40208007443336, 66.54746578585717, 71.5777878607473, 68.05963362416914, 69.96042989915418, 70.81522418606666, 57.95529819303944, 1.5441508446970296, 1.9764078047967728, 3.0644502466724766, 0.6493268702780047, 0.4156892055705671, 2.252751776287633, 5.655382160217532, 1.2323106488873883, 0.12334413180548338, 10.576335807000438, 0.43168898251268173, 0.08142470457260648, 0.14269078601031535, 0.04147034649166369, 0.16455286693188453, 39.129882551008656, 31.114717183574555, 23.031057427006385, 35.427459286105254, 51.19670137282341, 1.8878421571946915, 0.21872764783761195, 0.0061969862473497716, 0.0032803446811158214, 0.05418539888435795, 0.04643957198206936, 0.0190027458443036, 0.05478039639250887, 0.06811938909513336, 0.03189074450112399, 0.04172155055247488, 0.04309298200232368, 0.04833540976828626, 0.035048403792203434, 0.22121769406141775, 0.23440392117106149, 0.15777415325564725, 0.1732182713045228, 0.22401278117491355, 0.08628489659918893, 0.2849174759561016, 0.15748792748537757, 0.11228306324131067, 0.12981202062820235, 0.24121727734323473, 0.17985057025667162, 0.1670361409384397, 0.2559199142119577, 54.45818747243574, 85.3013530854256, 45.42899331738872, 42.929823783136186, 34.66219309837588, 43.855142285746915, 5.8839126844559955, 0.09876981617942934, 0.6843729413324787, 0.19438564837459596, 0.504633208676692, 0.3338548661239686, 1.6673196419592828, 5.9017746679244505, 3.4851950503164724, 12.791084474132909, 8.78793602989566, 4.792993674355169, 0.8705631343107071, 41.00095902719806, 94.4344743605583, 84.37246522595807, 89.67670994420206, 85.22153285241897, 88.95602149348106, 85.474972878733, 86.02989412123158, 81.51867420442643, 82.50940999677105, 86.12879276275636, 86.2641929811047, 87.8618057312504, 89.26290773576306, 88.20822946486935, 84.06276272189233, 74.17157280829646, 74.21874323198873, 73.9457384232552, 76.20858515462568, 79.46109294891357, 80.06672259299987, 77.76899814605713, 71.78842698374103, 77.10636077388641, 76.85412099284511, 73.31783756133049, 73.31557827611124, 71.0719511585851, 70.93295020441856, 71.28297467385569, 68.72538535825669, 71.1633659178211, 64.04977890752977, 63.47155878620764, 65.72472510799285, 67.85564684098767, 68.64976990607478, 64.23933136847712, 64.74384623189127, 64.67539695001417, 64.09929098621492, 67.64831819841939, 68.85068155104115, 73.92894283417733, 73.97761160327543, 72.15760046435942, 67.2991095819781, 71.44529804106682, 74.25770021254017, 69.6501390395626, 68.86405683332875, 77.72284753860967, 81.24949762898108, 77.47928404038953, 79.71102637629356, 82.54115766094577, 73.63714202757805, 66.86478553279754, 68.72751912763043, 73.73029831917056, 73.18017805776289, 80.25129364382836, 70.82782283906015, 62.42036750239711, 65.08237423435335, 60.873973061961514, 65.09324704447101, 61.753360609854425, 57.25685742593581, 60.97999080534905, 54.04223972751249, 58.5785000554977, 56.23697057847054, 54.18881477848176, 55.13665553062193, 59.11897520865164, 57.8922970833317, 58.288480004956654, 54.767780150136645, 58.90994817979875, 58.62909078598023, 60.937688043040616, 59.37554920873335, 58.01988394029679, 59.07608801318754, 57.68314846100346, 61.990973872523156, 59.30324423697687, 58.85372884811894, 57.50410795211793, 57.46069123668056, 59.27349698159003, 62.746924431093284, 67.28036849729477, 66.53013675443589, 64.87167235343688, 64.03953367663969, 67.91656909450408, 69.1048276039862, 75.0913215452625, 71.16245592794111, 74.0258175326932, 68.86422941761633, 76.39099890185942, 71.76341795152234, 75.10703456017279, 74.4808203174222, 67.59899831587269, 2.78540033005899, 3.765416284722667, 7.628190700084933, 0.8055214728078535, 0.2966024005605329, 4.263300626508651, 12.29792977533033, 6.128493057143304, 0.1380056680570687, 15.589168033292218, 2.5109795456932438, 0.28143223555338, 0.1978642238123763, 0.12024473158582566, 0.4415941622949416, 46.93310460736675, 43.64221249857257, 39.64896901961296, 48.442389503602065, 63.552363534127515, 2.648769222920941, 0.48605214443898975, 0.12002335515834632, 0.17429280154887708, 0.19156483602860283, 0.1191358806024636, 0.20575017968733467, 0.1818855755752133, 0.15086278379444154, 0.15739849438109707, 0.15668258521585696, 0.13835040762299491, 0.16528337773296142, 0.14494317643825086], [0.03661062177871505, 0.06623242260707964, 0.07716383079006787, 0.0383164199639953, 0.02718740514659834, 0.04534528816058751, 0.04251818240229641, 0.06841513733830183, 0.060561295869129325, 0.04986128071323038, 0.05036639695566508, 0.07211651412710067, 0.060117857365478436, 0.5792594268437355, 54.499038957780414, 42.64302007613644, 35.98919760796332, 17.87211887298092, 17.361220352111324, 9.362986876118569, 0.45567026181567105, 0.10735361686637325, 0.05281381421692429, 0.04587744730674932, 0.055920480780543826, 0.5009083666147724, 1.3537822856057076, 0.13409212321764039, 0.33956623546058134, 0.8489993527050942, 1.1913218805866859, 3.283955151996305, 0.3403975021454596, 48.861263336673865, 75.1974844163464, 72.06385581724106, 69.03599000746205, 70.60530677918466, 70.49129916775611, 70.37685225086828, 71.28043297798403, 69.25179096960252, 78.43840552914527, 73.68121377883419, 77.06654087189706, 77.52855685449417, 79.25269742165843, 74.85183731202157, 75.78028586602981, 65.9682729167323, 64.73569946904337, 67.31978831752654, 69.28643334296443, 70.47553123966341, 73.87001314470845, 64.93285740575483, 66.51113679332119, 70.05166422936225, 66.89629785476193, 67.30115705920805, 67.85441521675357, 65.09675756577523, 64.2582764164094, 58.06290841871693, 58.01237260141681, 58.61914757759341, 59.325185975720814, 59.791163552191954, 58.04621481126355, 56.11791487663023, 60.6341044364437, 59.37358017890685, 55.233310576408144, 57.9032914869247, 55.08739840599799, 60.782656361979825, 59.43583603828185, 63.775930789209184, 67.12984361956197, 64.38878543915288, 64.14806173693749, 64.82787124572262, 72.87381741308397, 70.96083825634372, 62.53111954658263, 67.43681615398776, 73.2538244801183, 70.22495454357517, 73.95166120221539, 71.17193237427743, 71.11253200038787, 63.94533403458134, 56.381992370851584, 58.733468978635734, 60.39120774115286, 56.74597263336182, 54.35247959629182, 58.62645103085426, 57.08360633542461, 54.60887316734561, 53.848545243663175, 51.4541422167132, 49.75132757617582, 49.76458518735824, 50.2142810052441, 50.035636655745975, 51.2292766571045, 54.12746890898674, 51.36756373989967, 50.276889877934615, 51.07995986938477, 50.510353272961034, 51.749747722379624, 51.62445937433551, 52.082062690488755, 51.72122032411637, 52.26589633572487, 52.43206362570486, 49.67792826314127, 49.69514746819773, 51.33287822046588, 51.15816016351023, 50.39325875620688, 49.64791820895288, 50.631903602230935, 49.6480986379808, 54.303885352227, 58.156817805382516, 61.75896567683067, 60.62986435428743, 60.09344885426184, 61.3735810402901, 58.3412084271831, 62.90726700136739, 63.70736383622693, 64.28235976926743, 66.0366633630568, 68.23093137433453, 63.478183669428674, 63.96152165628249, 63.26564219690139, 38.64803114245015, 0.8046454359446803, 1.6399881988763811, 5.089409149462178, 1.2503145731264547, 1.5414175655572646, 4.757049564392337, 5.609674780599533, 1.6409907321776114, 4.496448761032474, 7.48941037924059, 0.06362758576869965, 0.11146462852916411, 0.05719838821659646, 0.10262252597679054, 0.032083735455788916, 35.16040863529329, 27.711429557492657, 17.375076124745032, 36.79196557691021, 32.47769571119739, 2.9636134639863045, 0.48279357413130425, 0.10081167032401409, 0.10834033045196727, 0.10415070284638675, 0.04199771758829875, 0.05721639511325667, 0.07728366226318382, 0.0759115451646428, 0.076243000765962, 0.04879907299313815, 0.03852583775897661, 0.05157686950218293, 0.0887598125864902, 0.09435739488370957, 0.1627140567307511, 0.031167048052133575, 0.03784077512400766, 0.025580097140083392, 0.05687106182918914, 0.03502676563878213, 0.09415697096095932, 0.08089953597875373, 0.04654738736609298, 0.17083058974915938, 0.0530722156737841, 0.10163466325931012, 1.605630932796386, 58.29364576647359, 57.17905721356792, 45.60601380563552, 18.159403070326775, 25.749228577460013, 11.707676802912067, 0.1897957551503374, 0.12541750280727304, 0.09085949870847887, 0.07839032989596167, 0.17042152944111055, 1.408210932727783, 2.8315330416925493, 0.10807844329505198, 0.14907727799107953, 0.6551935103151106, 1.2459729996419724, 3.6779089416227038, 0.8167090531318419, 53.76275908562445, 80.64460539048719, 78.92862335328134, 75.92703742365684, 76.14317570963215, 76.70590246877363, 76.26081543584024, 77.64290178975752, 78.83526309843987, 82.07745505917458, 79.4840152802006, 82.56458205561485, 81.24053109076716, 82.8672399828511, 78.83700463079637, 79.68142817097326, 69.0617835137152, 68.54620364404494, 70.36866234194848, 73.9875901129938, 75.26737320807673, 76.33931775246897, 70.18432663333031, 70.86977651042324, 72.46346689039662, 71.19948310236778, 71.94160338371032, 70.5071690774733, 67.92097783857777, 67.06522649334323, 62.130873049459154, 62.91586875915528, 61.68173813050794, 63.47870926703177, 65.10510044713175, 61.5586345426498, 58.10659185532601, 64.52248727121662, 64.89002120110297, 61.81978987109277, 61.34936824921639, 58.19207206849129, 60.251716490714784, 63.60304055675384, 67.25044081288, 67.92974825828307, 68.47601675218152, 71.27265099556216, 69.39633815519272, 78.02908266744306, 75.15585237933745, 63.228575798773, 68.99668785833543, 76.48718326322495, 75.01397240546443, 75.28309406772738, 74.45118288840018, 72.88096397153794, 65.64348105461367, 56.17947647648474, 64.43281796670729, 63.680511290027255, 60.79257995851579, 56.73988511485439, 60.491216413436405, 59.90475147001205, 57.828821366833104, 56.56598683326476, 53.94582002393661, 55.536560781540416, 53.24230370983001, 55.14397859573365, 54.89328030617007, 56.24236775982765, 58.134068058383086, 53.260409370545425, 52.9946570242605, 52.50195241743519, 54.28485401215092, 54.94585967832997, 53.031750878980084, 55.140319024362874, 54.538168522619436, 56.09265089035035, 56.7020107084705, 53.80175528987762, 53.89980669944517, 55.580083400972434, 58.06075111512215, 54.75793500100413, 53.07520681811918, 54.937716837852236, 53.24048765244023, 58.38191478483139, 61.20436606868621, 63.76622292303271, 63.54032578006868, 62.25808335888771, 64.34652974528652, 60.80906960272021, 66.74218793069163, 69.04069685166883, 69.13498278587096, 70.51566493126654, 71.66744539814611, 68.58794550741874, 69.24115350169521, 67.61647639736053, 43.593637866358605, 0.9780506020592106, 0.6690859325951146, 0.4305795033372218, 1.8310801901163596, 1.7858021874581615, 1.3236054081109263, 2.4796729030147677, 1.3739150762557986, 6.192442399840202, 6.504389480237038, 0.04281012701892084, 0.15933864269285433, 0.13125389003224913, 0.12852221201624603, 0.09419501488727909, 36.745775745761016, 35.475308279837336, 20.18902174888119, 43.28333131728634, 49.38692762005714, 4.51551148006993, 0.5179437105694126, 0.10127978835014567, 0.09948443065607741, 0.08737080324921878, 0.06037264288733564, 0.06702679449752455, 0.059613664258992484, 0.09684009432432153, 0.0384437590987692, 0.05015475367526374, 0.05865158040016409, 0.03314869343152931, 0.02797080665796755, 0.18037849676705178, 0.2532437545878272, 0.2496259809742051, 0.0817542679367527, 0.19402046958284994, 0.14870915742170426, 0.18967645993876844, 0.21485845948899948, 0.15583457184895394, 0.08504661506101971, 0.22438152993638671, 0.18693746578308845, 0.24894632308954195, 1.6542382922864731, 71.59281838324763, 58.86483307807677, 56.2027596658276, 36.74416757399036, 33.25407397362494, 22.388380996642574, 0.6101966312816066, 0.21594881710986938, 0.24806354465263508, 0.22761376214123544, 0.2888145345833994, 1.8082988190074123, 3.0773707791682217, 0.44394574578731294, 0.8414444387439759, 2.9120286578132264, 12.423971218447532, 14.261118212053853, 0.7652573623964865, 60.13532407822148, 84.80740116488549, 88.07137796955725, 80.38209684433477, 85.25668513390326, 82.25838615048318, 84.0074965261644, 83.77876743193596, 85.4111166923277, 88.27534121851768, 84.65568388662031, 88.09492788007184, 85.05795432675271, 85.77951354365196, 82.76334424172678, 85.05823673740511, 73.07768652516027, 72.70226863122755, 75.05572211357855, 77.73619928667623, 77.90528482006442, 81.1901835472353, 75.23866930315572, 73.6454103839013, 78.52404655948763, 75.88688019783267, 75.18131640649612, 75.59602076007475, 71.97433948516846, 70.73643945878553, 65.37160588848975, 65.59387483904439, 64.29650775847897, 66.51195264631703, 68.66972692551153, 63.529311764624815, 59.74394606005762, 71.06684423262074, 69.74444066324543, 65.41359093881422, 66.79855239006781, 64.14883052149128, 66.91700796927175, 67.76670317496023, 71.6532934865644, 74.73957123294954, 69.03092230519941, 71.4814152256135, 70.40899215206024, 75.7194185256958, 76.94014641546434, 62.50011321037047, 72.86463122214042, 79.7186279296875, 77.43253723267587, 79.02941257722917, 78.03207935825472, 77.41087790458434, 68.53348731994629, 60.47425608481131, 63.751466966444454, 66.85541891282605, 63.41137393828362, 59.997644962803015, 63.06458150186847, 63.5752623311935, 63.17671814272481, 60.792175954388036, 57.837372133808756, 56.49090090105611, 58.12479557529573, 59.937083567342455, 59.12960090944844, 60.830650483408284, 61.8374679934594, 56.99500783797234, 55.64082914783109, 55.67176095900997, 56.60356313951554, 57.734970815720104, 57.26569060356387, 58.42311928349157, 58.007830496757265, 60.03004766279652, 60.024387682637865, 56.30412940056094, 58.08445007570329, 60.03229910327543, 62.30171188231438, 58.770068614713615, 57.71266429655014, 59.461676612977065, 56.046088434034786, 61.070507341815585, 66.11791133880615, 67.30336927598523, 68.19439841854957, 67.75809749480217, 68.29536807152533, 63.78625054513255, 70.59590093551144, 71.98678124335505, 73.78108516816171, 72.68189584055256, 76.05684434213947, 72.0013097024733, 74.15995474784606, 71.72113480106478, 56.797563568238296, 1.428309402638866, 4.334620102759331, 12.2974169254303, 4.80081586107131, 10.425757977270312, 10.741885323678295, 25.729865797104377, 2.416322457213556, 4.179227073346415, 10.892107198315284, 0.1882094168855298, 0.4063573966343557, 0.26793866929027343, 0.5452187695810872, 0.1744325819515413, 48.475533531558135, 44.82357940366192, 32.00099045230497, 54.367984725582986, 59.93021549717073, 5.193869221595026, 0.7809479462523615, 0.20075329459242283, 0.19012298194631455, 0.33346170980122786, 0.31894572259437654, 0.19661026045439706, 0.14919946901500225, 0.23307465137012545, 0.14821202764588018, 0.14340966759670165, 0.20067429560567104, 0.13368758282834484, 0.2208388329393441], [0.18663026452545198, 0.1133978897104821, 0.027496600148057746, 0.03895445629173229, 0.028643705731918736, 0.05960729806834172, 0.028365859048320886, 0.08036147412513533, 0.020787678996942217, 0.043212579818622726, 0.05325667432419235, 0.30261977605762025, 0.2491684732658248, 10.410546045149527, 68.145855165297, 33.481857776641846, 33.35981322873023, 20.619521487143732, 27.070159296835623, 8.38716197398401, 0.1329870720303828, 0.1324565254993016, 0.013231749969324278, 0.06881013993294009, 0.1066758358971246, 1.8812327183062032, 2.081038254883982, 0.5882381611774045, 0.07197397580790905, 0.3901834112982596, 0.3997394694916664, 0.3988251895193131, 1.6251713229763893, 51.81134462356568, 72.72335529327393, 72.7933225324077, 70.65661138103854, 68.35639230666622, 70.34490062344459, 71.30530864961686, 68.61776336546868, 69.1125468284853, 76.25387284063524, 75.14669756735526, 74.03887118062666, 79.3670266674411, 77.52920796794277, 74.28936942931145, 73.51085739751016, 66.06390030153337, 65.37667359075239, 68.10954970698204, 69.82997186722295, 72.44763620438115, 68.11959097462316, 62.653254309008204, 69.61926998630648, 68.40768906377977, 64.12305270471882, 66.35348104661512, 66.28731850654849, 62.986016427316976, 58.261525477132494, 56.633475134449625, 58.29100601134762, 57.50679085331579, 60.115598478624904, 59.602505391643895, 56.93283434837096, 53.61079077566824, 53.33975107439103, 55.490939694066206, 56.50731602022725, 56.11025841005387, 55.02157318976618, 55.08858296179003, 59.24075695776171, 58.27288466115152, 60.42100598735195, 71.44277203467585, 73.52675084144839, 72.79396580111596, 63.62319761706937, 76.62517224588703, 67.33832543896091, 70.43579762981784, 74.26115974303215, 72.44878153647147, 72.9725670045422, 71.82721138000488, 71.56977838085544, 65.06560610186669, 62.909851843310946, 64.03032787384527, 60.982257935308645, 59.89497692354264, 62.13893352016326, 61.81607930890976, 55.05175975061233, 55.76787471771241, 52.77907179247949, 52.36569712238928, 52.34613626233993, 51.696976154081284, 51.02425436819754, 52.240977518020145, 50.90917594971196, 55.61592601960706, 53.101137607328354, 49.92367259917721, 52.306767432920395, 53.40447410460442, 51.41447528716057, 50.86595535278321, 51.00044165888141, 49.89154446509577, 51.767021840618504, 50.35365458457701, 51.071326732635505, 47.90385984605359, 50.817992610316125, 52.7879677280303, 49.85765518680696, 49.53394589885589, 52.41325978309878, 48.953168392181404, 54.8427091875384, 59.60633754730225, 60.37221954714868, 59.61461374836584, 59.0071641245196, 63.968150461873705, 60.84983479592108, 62.06962131684827, 62.581314117677756, 62.966585005483324, 67.86677068279636, 67.13061240411574, 65.71677446365356, 64.53623910104075, 59.37404694095735, 27.98764286502715, 0.41031969530928525, 0.8941547812954073, 1.2442127134530776, 0.6640849106254116, 2.0028400445176713, 1.5559646559338418, 4.044551512887401, 0.41092015502433626, 6.55312640051688, 2.9849344876504715, 0.12625341198497242, 0.019908106637998454, 0.13166026903256295, 0.19499098040884544, 0.24025657244267004, 17.101559446704005, 48.10658362603957, 22.301155328750614, 17.156709932511855, 37.32584330343431, 7.242825675395228, 0.5436880646213409, 0.07501853179306754, 0.11939499452109299, 0.07302645804180254, 0.10355506948525868, 0.023758207905977487, 0.03832519167072831, 0.03258889383305946, 0.06359595782874573, 0.027792405847820546, 0.06426313614112235, 0.0803424445010962, 0.045260562666601716, 0.08276241666246807, 0.024096904953400937, 0.07300525272805845, 0.02972379011372405, 0.03166161334863113, 0.06906035957076857, 0.22190994643155607, 0.049833644091361956, 0.014132819713033257, 0.05956089612276805, 0.08972957264631988, 0.3504743775533092, 0.32766720460307214, 16.119884329457438, 80.07766600578063, 46.27699798153293, 38.30246640789894, 23.58448816883949, 36.35999102746287, 8.607614867148861, 0.15883041996388667, 0.11523755026921151, 0.05506507466517149, 0.11049230207478809, 0.1249833990849795, 0.9463441840583279, 2.6232924480592055, 0.3242750592049091, 0.06289521720440638, 0.290696352960602, 0.2696616929625311, 0.9573610187057526, 2.4534366592284176, 58.17164828700405, 78.45171020876977, 79.50703174837174, 77.17794402953118, 75.94007538210961, 76.50957999690887, 77.04234769267421, 75.41938858647501, 77.1375043930546, 82.47931757280904, 81.49852891122141, 79.05861070079189, 84.42884537481493, 81.49647358925112, 76.34969634394493, 76.10639956689651, 69.77276017588954, 69.84104079584922, 73.03048472250663, 72.70872485253119, 74.54805758691604, 71.0810745916059, 65.54337432307582, 73.49186528113582, 73.44285134346255, 68.61225635774674, 71.88138715682491, 69.48057497701338, 65.23646454657278, 63.32543873017835, 60.7495201787641, 61.94427413325157, 60.62448678478118, 63.179185313563195, 62.615815285713445, 58.018330681708555, 57.433634727231926, 57.03784012025403, 59.84702987055625, 61.31215672339163, 59.67091937218944, 58.167518031212595, 61.09970154300813, 61.5930768751329, 62.32333983144453, 64.06487611032301, 72.35326397803523, 76.35597213622063, 74.47939257467948, 67.39724728368944, 80.14254985317108, 72.27329469496205, 73.1713213459138, 76.27025265847483, 76.16343867394232, 76.22584358338388, 75.43976137715002, 73.55231685023155, 68.76772342189666, 69.13029947588521, 70.19299507141113, 65.61075672026604, 65.73759440452822, 69.02031621625348, 64.60827342925533, 57.39279893136794, 58.765918747071304, 55.126802536749075, 57.53680482987435, 56.10451213775143, 56.6465836955655, 54.75522072084489, 55.37435508543446, 55.7357269717801, 57.041809558868415, 56.77266436238443, 53.21406264458933, 56.48198535365444, 53.69551789376044, 52.45383670253139, 52.728049601278, 54.24954091348956, 52.65602311780376, 55.220774681337424, 52.7382516860962, 55.30967127892279, 52.64859022632722, 54.54626037228493, 55.505970216566524, 55.61142706101941, 54.285995421871064, 56.761214963851444, 54.01239833524151, 56.90476194504769, 61.65981208124469, 64.23540507593464, 63.88962461102394, 62.463580254585516, 66.77312758661085, 64.98274210960635, 64.92661299244051, 65.01483494235625, 68.96249263517319, 70.018630027771, 70.96953022864558, 69.72325201957457, 67.8911913594892, 64.17791881868916, 36.10688440261349, 1.251497167733408, 0.5931334630135567, 0.8460616813071313, 0.33892060720151473, 0.8391149798708578, 1.3271200969334573, 1.291085159586322, 0.3095255377552202, 10.0492702568731, 2.685157786453924, 0.14887987245475093, 0.4463853681039426, 0.10480311098358325, 0.2320970925352266, 0.21484617143869403, 17.153230790169008, 51.41456942404471, 28.61219794519486, 21.106789688910208, 51.296819871471776, 11.561523406736313, 0.5032929225314049, 0.10391754398663199, 0.11282159240856288, 0.045849343371247096, 0.022933142702846278, 0.04829993223651283, 0.01573233660535827, 0.02503134835992129, 0.11126372197102155, 0.023744653895377152, 0.10404612418384322, 0.05296883976928169, 0.07028978513253313, 0.16363628869575841, 0.17946895121807055, 0.10890527433084865, 0.17213175944503278, 0.2820277310186817, 0.12958383367907617, 0.4052819011192168, 0.22429483942687514, 0.1851278435318701, 0.19001340072962547, 0.21487768829589893, 0.4237192472623241, 0.6384540601603447, 18.696581471350886, 91.63412955499466, 50.840683521762976, 49.246997064159764, 36.021761125133885, 48.88345218473866, 17.17936162025698, 0.2629750324112754, 0.3106058136590066, 0.10731412503387659, 0.7464501490035366, 0.1640394960920657, 3.9857407202643738, 6.6484326412600865, 1.3366657976181278, 0.3335612093008334, 1.2866534941619443, 2.490933047186944, 2.0105414957769456, 3.3152296802689953, 65.77889304007253, 80.96167410573652, 83.71244799706244, 85.31324571178806, 81.62450759641587, 84.45044978972405, 85.35911390858313, 83.58792058883175, 80.48881669198313, 86.38602179865684, 86.28322432118078, 81.65636508695542, 87.71993360211773, 86.57029474935224, 83.57416091426727, 81.92131334735502, 74.0206164698447, 72.06661716584237, 75.8341556979764, 76.99479287670505, 78.7682141027143, 74.77533540418072, 69.72664094740345, 78.19776027433335, 78.59887753763508, 71.97976804548695, 73.61339599855485, 75.07580464886081, 68.36212681185815, 65.2400613600208, 64.42098025352725, 66.59181210302538, 63.98314568304247, 65.22404632260724, 65.59241963971046, 61.94221881128127, 60.0903933278976, 60.83859328300723, 63.89226828852008, 66.7091537291004, 66.02661425067534, 62.018873691558845, 63.680526979507945, 66.165709341726, 66.2607091472995, 65.05139927710256, 75.1022728027836, 78.26162430547899, 77.19725778025966, 71.95494728703653, 78.09947352255546, 75.0759772331484, 75.3760071723692, 80.81431065836261, 78.46618375470563, 78.80369586329307, 81.05883905964514, 76.22003847552885, 72.70932889753773, 64.32713362478441, 68.37110903955275, 68.45283554446313, 66.18862382827267, 70.33299230760144, 68.09130284094041, 60.91945294410952, 62.157635381144864, 59.13487649733021, 60.38526142797163, 60.65571277372299, 59.628977467936856, 59.23521464870822, 62.7750595923393, 60.415824536354314, 63.43099755625572, 59.46446934053975, 55.00185543490995, 59.58163838232718, 58.15510372961722, 56.2486513968437, 54.21855418912826, 57.86691150357647, 54.18989343027915, 57.2747120549602, 57.27548083951397, 59.105454798667665, 56.35853659722113, 58.44311160425986, 61.33900926959131, 58.02054682085591, 56.96113424916422, 59.11833978468373, 56.49319548760691, 61.40149654880647, 65.9698026410995, 67.44255065917969, 64.68628937198271, 65.55135242400631, 72.65096402937367, 69.60605944356611, 71.54409470096712, 69.87493791887837, 70.81628322601318, 74.1799274567635, 75.56392792732485, 73.54548408139136, 73.20887411794355, 71.7196992135817, 50.24079622760896, 1.9329496593244615, 3.4836991563920057, 5.733443210201879, 2.6727045063049566, 9.860255160639364, 13.750425615618306, 13.240049750574174, 0.7308371545326325, 14.04964558539852, 5.958770628898375, 0.6163057228249889, 0.5937292342705112, 0.20852076730901198, 0.5149998491810215, 0.32194241340602603, 25.468602603481663, 65.06429995259931, 39.717869374059866, 29.409778579588863, 62.90941646022182, 14.04591246958702, 0.6959894083199963, 0.25959670723926637, 0.1814959892221997, 0.1563327894696305, 0.2800618881179441, 0.10927666609566059, 0.11701053819589077, 0.1418694325031773, 0.1796754425571811, 0.14621672100357472, 0.19118537735794822, 0.16445264730963016, 0.16905490519298663], [0.3988042293537048, 0.18129458470690638, 0.06094135208836487, 0.03099646133881423, 0.07250362601611884, 0.07104857223889521, 0.15794563437661818, 0.16860757113224076, 0.03431404722974666, 0.042911005476790096, 0.24027583189308646, 0.5819181196631924, 0.9640691297188883, 55.19354166523103, 47.41508545414094, 37.28013592381632, 43.688857324661754, 14.913458381929706, 39.63182041721959, 3.260283648006378, 0.14839772735872578, 0.07730705858839136, 0.12629936193867078, 0.07622122854715394, 0.09155518315251797, 1.36834298170382, 3.3827751009694995, 0.16131240694272905, 0.11896828354726877, 0.03792390715511095, 0.11552074999218026, 0.07728812089490314, 4.431334474394399, 55.968947179855846, 68.9556049531506, 73.91087639716365, 69.11667316190659, 70.67237146439092, 68.22003502999583, 71.27341193537559, 68.10015170804917, 73.00495793742519, 74.30110516086702, 74.809326664094, 76.40320531783566, 77.765899473621, 75.40238118940785, 71.25547101420742, 69.64711881452992, 66.43489376191171, 67.07067074314241, 68.4598252081102, 70.54280773285898, 72.97190020161291, 63.35510361579157, 63.63567075421734, 68.98544634542158, 66.13626018647226, 66.1592060519803, 66.08455550286078, 63.289984426190784, 59.33740415880757, 58.554118602506584, 57.97523167825515, 56.137318841872684, 59.74361658096314, 57.683234753147254, 59.054966049809615, 55.72694086259412, 58.74226685493224, 56.118758186217285, 57.13100425658688, 56.720869464258996, 55.381638926844445, 56.868982084335826, 55.57445872214533, 57.46179734506915, 59.44241385306082, 63.85702579252182, 75.00141297617267, 72.83375432414394, 70.51282513526179, 56.85953309459072, 66.63144373124646, 71.24113082885742, 66.17946901629048, 74.09252920458394, 68.7403452780939, 72.16329574584961, 68.9043317302581, 70.6515593682566, 65.77520993448073, 65.66512077085434, 59.48515199845838, 64.17832674518709, 64.62677132698798, 66.92114999217372, 64.78215994373446, 55.642480465673636, 52.538159816495835, 52.99743013997232, 52.96222686767579, 51.40395941272859, 53.803814534218084, 50.251700416688, 48.15798628714777, 50.94093930336737, 52.89188700337564, 50.516174070296756, 49.73066845247823, 50.24081191708965, 50.30517408924718, 52.18489939166654, 50.906202793121345, 49.18020694486557, 52.79571048675045, 51.11859913795225, 50.902908002176595, 51.06242295234434, 51.78174641824538, 48.11974317796769, 51.404932160531324, 52.14447152230048, 53.955100351764315, 52.46596467110419, 51.773434915850245, 52.284088288584066, 58.17972052481867, 58.19061294678719, 63.09550546830701, 61.80806198427754, 62.14593102855068, 61.11288070678712, 61.605491176728286, 61.3929340147203, 65.32988755933701, 65.97984390874063, 69.3803741085914, 64.64836789715675, 65.89654061102098, 56.390390165390514, 19.4740834928328, 0.42143697940534164, 0.09410581160937587, 0.19695244128665618, 0.035739173782208276, 0.4045366201429598, 0.32676530461157527, 0.44481090420196134, 0.23998242021808702, 2.334491519197341, 0.7158633838257482, 0.09471852107033615, 0.2047698629359084, 0.16174722312679216, 0.2945635954458868, 0.25570551684546855, 7.647240181123057, 37.20793293368432, 48.342910351291785, 18.722004313622755, 43.406015211536044, 17.63011843927445, 0.526291556175678, 0.10130159121247069, 0.06925827072512719, 0.07722522507631972, 0.12000401909913748, 0.03170894800625261, 0.0781024034105001, 0.046720772215555754, 0.03310301160860447, 0.08018542712013568, 0.15045199212768387, 0.032250903501746156, 0.08590171474122232, 0.2988054855696617, 0.1718441700382579, 0.10142587365642672, 0.07884980645030737, 0.0875802593485963, 0.07316112097713255, 0.39561607784801917, 0.12206707855746632, 0.08543313706233617, 0.14198212403683894, 0.26800102884730986, 0.6826893865100799, 1.5063453249392973, 69.8805312187441, 55.38882470900013, 52.77888744108139, 41.01489913079047, 21.60752142629316, 49.60007313759097, 3.918755217905968, 0.21941109019662106, 0.05070801471329985, 0.05675039532023573, 0.029619925828169913, 0.20250570539745594, 0.2548611040918097, 1.3421351751012187, 0.06160097677380808, 0.01513126593518762, 0.0822730396964377, 0.15091040381981483, 0.023702128354700345, 6.830887083084353, 63.452115597263465, 70.9130245639432, 84.24148944116409, 74.63499299941525, 75.75876774326449, 75.01554919827369, 75.52300191694691, 75.83621886468704, 78.41323175737935, 79.66642902743432, 80.02076025932067, 80.54479675908243, 83.61091352278187, 77.84754753112793, 76.17448406834757, 73.50024346382388, 71.94168183111375, 72.39330353275423, 71.2009108451105, 74.7344486175045, 74.82401201801916, 67.8696418577625, 67.3820363321612, 73.44575389739006, 70.31575741306429, 69.28928882844987, 68.08207742629513, 68.35094805686705, 63.81768834206366, 63.135721529683764, 59.678952386302335, 60.32466865354969, 61.781868396266816, 63.51275544012747, 63.82343461436611, 59.32213829409692, 64.49282238560339, 60.817130073424316, 62.44122666697349, 61.694744709999334, 59.25434012566844, 60.84210380431145, 60.2506378389174, 60.5633762574965, 61.886646670679895, 68.13560208966656, 76.22781261321038, 76.03580474853516, 72.05852923854705, 62.44304272436327, 65.1849167577682, 71.35818219953968, 66.71182094081756, 78.47799793366464, 71.67819269241826, 76.20343116021927, 71.57683080242526, 72.65316840141051, 67.38759825306555, 64.80747492082658, 60.00227728197652, 63.33986128530195, 65.3318722786442, 70.11995269406226, 67.29870165548017, 58.96841895195746, 56.57949155376804, 54.882591847450506, 54.355786154347086, 54.49903503541024, 57.214711558434274, 52.108605369444824, 52.516171009309836, 56.06590424814532, 56.52200529652258, 51.512895399524325, 53.07282593942458, 52.41819804714572, 53.173905418765166, 54.13002237196892, 53.37693906599476, 52.51459029413039, 53.541380513098936, 54.956257881656775, 54.09073198995283, 54.24212371149371, 54.46856606391169, 51.3896623734505, 57.068320858863096, 55.28522706800892, 60.144247470363496, 56.567744055101954, 56.284097856090916, 55.75621351119011, 61.14150616430468, 61.751736748603086, 65.92537003178751, 63.82043792355446, 65.85275127041724, 63.96415356666812, 63.87217398612731, 66.63035331233856, 67.21317045150265, 67.9624294465588, 71.50192922161472, 68.11781806330528, 71.46157587728193, 60.70824899981099, 28.34621417906977, 0.9363548265349482, 0.14978744149688752, 0.20231577687926833, 0.241562461240157, 0.1577847405907608, 0.06175805927224218, 0.7100153750469609, 0.04626408805169406, 1.4014768360122558, 0.7966498682095159, 0.20406221219849205, 0.06833216235522302, 0.12796237794381957, 0.06877168231914121, 0.24787573053711848, 8.066734729274627, 40.621705055236816, 51.7416048819019, 19.939608035549043, 54.610355823270744, 28.942592913104644, 0.38037727136285077, 0.029217432808852004, 0.1307610656705595, 0.05274264464875864, 0.02026035195036281, 0.01968946897484843, 0.09895214510540809, 0.031180435438610377, 0.09765253056802096, 0.039316448157713305, 0.20866868356543206, 0.009024408495714589, 0.02908513133954858, 0.4823084566141329, 0.2861622462589895, 0.25287584852307077, 0.1663924125774253, 0.2182822443184353, 0.23920300236392408, 0.4685470047256639, 0.28450167407431914, 0.1925382273451936, 0.24107357457039819, 0.2942366904068378, 1.005938163688106, 2.02972311166025, 77.93296890874063, 64.40145861717963, 52.21986339938257, 66.80518904039937, 29.262273926888746, 60.46890597189627, 6.808263832522977, 0.49570883594213, 0.24955907085489845, 0.5128213709160205, 0.4219645075500012, 0.6041342404580886, 4.877438872091232, 17.94755977969016, 0.9108969280796667, 0.5899065168153855, 0.28328687313102907, 0.4040709306155482, 0.15173934159740327, 10.511052858444954, 71.8678863586918, 76.52143339956962, 89.56723659269272, 81.21249398877545, 83.97876124228202, 82.51283030356132, 82.23340849722587, 81.52321630908598, 84.46714339717742, 84.43285403713104, 85.41358778553625, 83.24833746879332, 89.4746765013664, 84.23343289283015, 78.897840592169, 76.9519841286444, 77.0720321901383, 74.68051602763515, 73.55652163105627, 77.9085325425671, 79.57326489110147, 71.62585258483887, 70.00612551166166, 77.62282709921561, 73.60911277032667, 73.53232060709308, 72.59197942672238, 70.97447241506269, 66.32352198323896, 66.30566735421458, 64.20643837221208, 64.5154466167573, 67.5829715113486, 65.64758777618408, 65.89844688292473, 63.177773260301166, 66.97429810800861, 64.00212210993614, 65.80021112195908, 66.22216793798631, 62.56870761994393, 65.1182835332809, 64.00366752378403, 64.7712282980642, 67.25848167173325, 70.3171302426246, 78.65237082204511, 80.62227925946637, 75.05714985632127, 64.40633020093365, 70.2872496266519, 71.69791436964466, 73.47794086702409, 81.40943619512743, 75.54900723118936, 78.05863380432129, 75.15347542301302, 74.87844667127057, 73.62820686832552, 68.92803069083922, 62.46971876390519, 68.54534856734738, 70.06193299447337, 70.49292302900746, 69.4247361152403, 61.52171719458796, 59.441394036816014, 59.79786688281644, 60.1233765386766, 56.958839662613414, 60.51268746775966, 56.65534627053046, 57.77487700985324, 59.038370501610544, 64.42908779267343, 55.515203475952156, 55.969092307552216, 54.33544082026328, 55.23759380463631, 55.198150450183505, 56.62640702339911, 55.7624069336922, 59.40486892577141, 57.875795672016764, 59.19433570677235, 57.550803769019346, 58.798580323496175, 55.150674081617794, 62.16769626063686, 58.47864827802105, 62.71833427490727, 59.360271576912176, 60.617497121134114, 59.41420024441135, 67.20816550716278, 67.18353302248063, 70.10825618620842, 69.93344399236864, 69.49088296582623, 66.58556768971106, 68.56492119450724, 69.31778092538157, 73.33370747104769, 73.05625469453874, 75.00855168988629, 69.21469319251277, 75.78455340477728, 64.83584934665312, 46.176130310181655, 1.7860946491841347, 0.48375636279102296, 0.6369400865608646, 0.5977000824866757, 0.5865470680498308, 0.8160140581669346, 2.8957402802282766, 0.6108653341089526, 5.126324046042658, 0.8096132403419865, 0.17118937936761688, 0.640473406641714, 0.3652886793978753, 0.6059441691444767, 0.5173119025365, 14.23768989501461, 53.966385010750066, 73.3577202212426, 35.90143849772792, 65.95189309889271, 28.86486722577003, 0.8840864247852757, 0.2132186636088356, 0.27824200028854035, 0.2575217427745942, 0.2146474022658602, 0.1963055106781183, 0.18154489627528578, 0.2269319438886258, 0.15951305026969603, 0.16366133977088237, 0.2940027577982795, 0.10671866021209186, 0.2779434711462067], [0.8233354072416983, 0.28401836452464907, 0.3290452129177509, 0.028796212770225062, 0.04268035555498735, 0.07862339682516553, 0.3204974183632482, 0.506880880003014, 0.09870585549863116, 0.9461893117235554, 9.14445202196798, 11.164380485011685, 23.926799297332767, 72.30122981532928, 50.18561632402482, 27.81726883303735, 35.426196282909764, 17.62547435299043, 37.256931181876894, 3.1608697051002137, 0.15269672167637657, 0.1077750341726407, 0.07072983369711908, 0.0713848771767751, 0.2537682490243066, 0.3651900992037789, 1.9893781023640789, 0.009682470361792274, 0.08058255943920344, 0.22692137187527073, 0.053228635506163684, 0.09163468009642056, 2.3987146923618936, 30.673413276672367, 46.427934708133826, 72.2958012550108, 65.77635918894123, 72.54549149544009, 69.75839645631852, 72.1830488020374, 68.73170821897446, 75.2567514296501, 74.47751768173711, 77.30982980420514, 78.214414658085, 76.84159294251474, 77.63062477111816, 71.21947934550624, 67.58854912173364, 65.59815022253221, 69.43131000764909, 69.99650001525879, 71.00789885367118, 70.59103719649777, 64.974289401885, 66.67760218343427, 69.08221121757262, 67.94668505268713, 67.36837863922119, 63.8919819554975, 60.12072109406995, 56.92082405090333, 55.539616307904645, 57.78200787882651, 60.19458324678483, 56.297700635848514, 59.14733786736766, 60.618830726992705, 56.85249244013141, 60.22352249391618, 57.61889219284058, 53.88313662621283, 55.998737581314586, 55.4043298382913, 56.950904707754816, 56.725811650676114, 55.87110365590742, 61.874714820615715, 67.6870241472798, 70.7374906539917, 73.00733489374961, 69.96603104376024, 69.08917734699865, 59.244820533260224, 74.1238767870011, 64.08238557077223, 67.73616360079858, 68.90224502932641, 68.8161176250827, 69.53904182680192, 63.19057195417343, 63.39840266012377, 48.80970378075877, 50.378114484971576, 60.029431850679465, 62.277793269003595, 68.44438675911196, 65.44080042069959, 63.277664261479536, 54.4832710296877, 53.948773568676366, 49.28702485176825, 49.49994287183208, 49.81254792982533, 49.14641180346089, 49.691236865135934, 54.1394752840842, 51.61230002680133, 47.94440930889499, 50.048384358806, 51.646201072200654, 49.61346018698908, 50.86966199259604, 52.202381395524554, 52.2752001977736, 49.7300918640629, 51.77291324061733, 50.26052967194588, 52.23254049977949, 52.99781453224921, 53.36612509142969, 50.072365730039536, 50.50582685778218, 53.385081906472486, 52.52651037708406, 52.98268987286476, 52.703585778513265, 55.888118897714925, 59.81600000012306, 61.405191421508796, 61.28124060169343, 60.911408162886104, 62.30919968697333, 63.54935899857552, 60.25123796155376, 62.216106153303585, 64.25740565023115, 67.09189861051499, 67.3871511028659, 68.02743880979477, 53.35267136173864, 9.292761741145965, 1.876774086586891, 0.17229596273072306, 0.08945069365924405, 0.06186828783322727, 0.10834252146343071, 0.04273431112749442, 0.15639718682054551, 0.04553183440058943, 0.11376767269065304, 0.2814203152252782, 0.05061094371241428, 0.06393377579027607, 0.035636495017716964, 0.05746614360701173, 0.07741869292071751, 2.145036382059897, 25.42895724696498, 17.589749405460974, 21.781092189973403, 27.58055771550825, 47.3243571096851, 0.6993651594365797, 0.15868460278837912, 0.06626325764603193, 0.09163686344700475, 0.04907002680063729, 0.05951496915170743, 0.03455762871571126, 0.32232037054434903, 0.05511259892955423, 0.17686227576867228, 0.45002823875796416, 0.30800853044756, 0.06259122202473302, 0.4790796411614265, 0.29098339078407137, 0.2531970538679631, 0.02917075890206522, 0.024756495164887562, 0.11795226709857104, 0.7620529085397721, 0.7008921258872556, 0.3896297135901067, 1.7851103794190193, 13.962607210682286, 14.697418155208712, 36.59517242062476, 78.33607089134955, 63.15343103101177, 41.78027514488467, 36.5629070035873, 20.45959076573772, 42.37613024250154, 3.9547652727173226, 0.29805364688077285, 0.20259809560112416, 0.0033653816377233357, 0.018480871428525256, 0.03942838509476954, 0.3614612428411361, 1.86232689407564, 0.22519183645565666, 0.09456377130963149, 0.11222346160080164, 0.010172920808526538, 0.11555598237581792, 2.94696667982686, 37.449919639095185, 52.59115103752383, 79.3044021052699, 73.56433499243953, 75.88381290435791, 76.74783260591569, 79.48752187913465, 75.36337714041434, 80.55955271567069, 78.88208050881663, 81.57328144196542, 79.5739552282518, 81.7773937409924, 80.22768882013138, 75.93515672991353, 72.17827135516752, 70.90801961960332, 71.38928659500615, 74.23772750362274, 73.82861644990983, 73.15374912754183, 68.21870926887759, 71.96415701220113, 71.10681318467664, 70.45073401543402, 71.56141588764807, 68.30250678523895, 64.05035157357493, 61.511503342659246, 59.493894961572465, 60.13293927715671, 63.205178860695135, 59.84853998307259, 61.93745705389208, 62.3362091279799, 58.12054372602894, 64.46529911410424, 59.63424521107828, 58.23291178672545, 59.35992248596684, 59.90485737400671, 58.91143475809405, 60.23683501828102, 59.57063613399383, 64.57915767546623, 70.07246063601586, 74.56846960129278, 74.74882018181586, 71.53642254491007, 73.86460027387066, 65.47317958647206, 72.28607377698346, 70.10917402082875, 67.0840617149107, 72.41766929626465, 71.6103906016196, 73.62961107684721, 65.2967199971599, 67.10375985791607, 52.953036754362046, 53.79223961983958, 62.88175982813682, 64.74835695758944, 69.76230313701015, 68.80528403866676, 68.25226122333159, 58.39549010799777, 57.171745915566724, 54.57260693273237, 52.512036831148215, 51.36881889835481, 52.82415943761026, 55.22586984019126, 56.0425151548078, 56.19664076835879, 52.58633044458205, 54.13620794973066, 54.43251555965793, 52.938006231861735, 53.50832669965683, 53.21884793619956, 52.87286350803991, 53.68558253011396, 53.74546927790488, 52.68158912658692, 55.73709195660007, 57.56399469990885, 55.77596264500772, 54.817303995932306, 53.9520134464387, 57.4023263685165, 56.36750313543505, 56.76455682323825, 55.52986529565627, 59.12818101144607, 62.39509174900671, 64.8670635684844, 66.91801209603587, 63.84518023460143, 65.99250531965687, 66.94118545901391, 63.80217536803215, 65.94644884909353, 67.32249475294545, 67.17932039691557, 69.41388683934366, 73.97754884535267, 58.15996354626071, 20.693942577608173, 0.9183927000530305, 0.11405020591712768, 0.06619736642366456, 0.09814739272358919, 0.1752732561961297, 0.04966783968190994, 0.08836707761210781, 0.12665124910493053, 0.200264944184211, 0.6026278664508175, 0.28267771065715824, 0.7737846564381354, 0.05121100889218431, 0.21451172809447014, 0.0680755305614683, 1.9640061283303847, 29.552478328827892, 22.14905561939363, 29.15013924721749, 33.43059632085985, 64.33337019335839, 3.27150579421751, 0.21468475671304812, 0.06092455561062502, 0.03547072508222154, 0.02969382458456582, 0.0699697595630442, 0.016198697417313536, 0.13303286876649628, 0.13298580032442847, 0.36893427732490724, 1.1494803644957081, 0.4292587064687283, 0.19121568379623277, 0.9141462440452269, 0.454469281098535, 0.49760845820269284, 0.11456427389695761, 0.13801818593375145, 0.18022434455492806, 0.9578820810683313, 1.1769223693878421, 0.3304850598496776, 1.3143020363584643, 12.976013441239635, 14.061481337393484, 41.56371716530093, 90.6293987458752, 69.71955714687225, 39.46289177863829, 58.377282465657885, 32.922519945329235, 57.65735495475031, 5.376734531694844, 0.39076943791681723, 0.3355901165594978, 0.2230438331682836, 0.15600085889379825, 0.4330135791772797, 2.200495754518817, 6.511104577972043, 0.25641719720536665, 0.368752469338717, 0.5045554047871021, 0.12589934912900771, 0.2720767391785499, 6.458446758408701, 65.64682291400048, 62.77459675265897, 85.59908451572542, 79.94224225321125, 84.67248732043852, 83.99010473682036, 86.49959010462608, 80.16644493226083, 85.41361916449763, 85.41833385344475, 87.16089387093821, 84.56812089489353, 84.98630831318518, 86.44983876136043, 82.22091967059721, 73.91161380275604, 73.88899741634246, 75.65705283995598, 77.42925813121181, 79.43451496862596, 77.5616616587485, 71.6341366306428, 74.09943257608722, 76.08088847129576, 73.86034057986352, 75.37166118621826, 71.70286440080213, 66.87433258179696, 65.01103416565927, 62.03551630819998, 63.767101533951305, 66.85151223213443, 61.26554327626383, 65.56445314038184, 65.05787903262724, 61.359268311531316, 71.06885248614897, 64.6386835652013, 61.28218197053479, 63.50114914678759, 66.36516186498827, 64.18275510111164, 66.24737308871362, 62.21254856355729, 66.30004267538747, 71.1939525604248, 77.400922929087, 76.50928974151611, 76.0291680982036, 75.21139314097744, 69.9407474456295, 78.23940800082299, 67.55910781122023, 75.37751336251536, 75.39878829833, 78.2831032045426, 76.12758036582701, 70.22376998778313, 69.09087181091309, 55.92478521408574, 52.60491463445848, 63.531359241854766, 67.11907279106879, 72.60279732365763, 69.9693101452243, 69.22234181434878, 61.54197623652797, 61.91065157613447, 58.86519393613262, 56.05158759701637, 58.172024834540586, 56.09267050220121, 58.78524818728047, 61.96323879303471, 60.380735012792776, 53.91996768213088, 56.415850270179014, 57.267942044042776, 56.506680596259336, 56.611439258821555, 57.05374925367294, 58.24769912227508, 55.27834723072668, 56.7563747590588, 57.14241050904798, 60.01266764056299, 59.26007070849019, 61.257435737117646, 61.74549233528876, 57.50169569446195, 60.38823850693242, 61.07678705646146, 61.28390389104044, 59.14720058441163, 62.868188427340606, 65.56969342693206, 68.14004221270162, 68.16079939565351, 69.13518674911992, 66.97843228617023, 70.71964386970767, 67.55283201894453, 67.81203008467152, 70.74323300392398, 72.50349860037528, 72.56238906614243, 79.24841419343026, 61.85312217281711, 40.78725261072959, 4.082374193014638, 0.430079952723557, 0.17309249498911444, 0.2593244089474601, 0.2834787015472689, 0.12703644577413797, 0.27023248975315406, 0.24211907008242226, 0.2755045536304674, 0.40830929673487143, 0.2637897209534722, 0.7385297191719855, 0.171338337503614, 0.3494848064597576, 0.23023767456893, 3.8181515710969127, 42.9370762455848, 31.13394268097416, 43.88768226869645, 39.943519407703036, 69.26730786600422, 1.8700202554464342, 0.18418675048216698, 0.15316084838442265, 0.18462237871942982, 0.17380786789280755, 0.15414925502432933, 0.11414055832691732, 0.5547911301255226, 0.291552348963676, 0.2699635622482146, 0.5356381352870696, 0.1879912810099702, 0.23926171534244092], [25.1463092911628, 11.930707673872671, 8.095106213323533, 0.5505038569531133, 0.05490936729456148, 0.12228136867164605, 7.220094559654114, 20.778095068470126, 31.369949733057332, 50.23247688047348, 55.94673871994019, 62.351816238895545, 55.94717018065914, 54.05519923856182, 38.220881108314764, 41.55976341616723, 29.98737112168343, 26.142106902214792, 45.617596564754365, 0.652526114736834, 0.01893423651645501, 0.11810659551091733, 0.07759493910857747, 0.0488243347424413, 0.10168786040477215, 0.1533186778185829, 0.4676835010609319, 0.24889049060162038, 0.10243865721408399, 0.08525279230408131, 0.11967066359976608, 0.12123860809351168, 0.2240196606444736, 7.323634835981554, 23.088667238912276, 67.10885893914008, 62.83949628953011, 69.30741017864597, 71.0985997415358, 69.96108101260278, 72.60698641500166, 75.79949763513382, 73.09910266630112, 73.94605221286898, 77.2180228079519, 76.19896750296317, 74.62666188516926, 68.53258517480666, 66.45431733900502, 68.76170650605233, 72.09121827156314, 68.63235458250969, 72.17611405157274, 67.17403304192328, 66.36054915766563, 69.92791345042568, 65.96689224243164, 69.08753779626662, 65.82587518999654, 64.85051901109757, 59.56975360070506, 58.532616169221946, 56.59336889943769, 57.53920924278998, 58.90079729018673, 57.87657230131088, 56.75515882430538, 57.83208477881647, 55.0725051664537, 56.50819463114585, 58.03628729235742, 57.4433151368172, 57.77311586564588, 56.59268248465754, 54.693259039232814, 54.870558015761844, 55.82296048441241, 63.50948026103359, 73.13383917654716, 72.26800733996977, 71.80719160264539, 65.5652964499689, 71.15124579398864, 65.09325096684118, 67.72408270066785, 70.79551035358061, 59.024857936366914, 67.5993356397075, 65.0593577661822, 66.10718757875505, 59.80094202103154, 60.3492070013477, 54.80017892775997, 58.96011529430267, 65.67981789189001, 63.21270981142598, 68.3799579066615, 65.6943698852293, 64.32619617831323, 56.63214937333138, 50.80207955452704, 49.58157916222849, 47.40886457504765, 47.814002267776004, 50.75067689341884, 51.19132772568734, 48.51949545644945, 52.26118556914791, 51.64370644477106, 50.688397499822806, 49.53616988274359, 50.428089403337054, 49.047317043427505, 49.82736664433634, 50.7761997561301, 49.29574820303148, 48.57653456349527, 51.06793780480662, 51.46565829553912, 51.49711178195093, 52.662738215538766, 49.57771954997894, 50.45181189813922, 52.357114976452245, 53.352243823389855, 52.981717125062026, 52.91718629098708, 55.551485400046076, 63.041372837558875, 64.30133619616109, 63.74712882503387, 62.402163782427394, 61.49456262588502, 64.80422327595373, 61.418029339082786, 60.499720111969985, 63.63358405328567, 66.9293712800549, 66.91121070615708, 71.85877077041134, 47.05358805194978, 16.57743077124319, 1.1821636365305994, 0.43652786963408996, 0.007066055540851648, 0.06587598487854966, 0.15601461783291834, 0.034818665515030586, 0.07022996132652606, 0.040323317516595125, 0.34620751296320273, 1.1366097196455927, 1.436635736496218, 0.13201374200082597, 0.006916510389982573, 0.08303748053168097, 0.05718609633585138, 0.3402057963032877, 18.095142879793723, 27.810855757805612, 11.226240184999282, 17.88806526891647, 37.17334547350484, 34.46681199535247, 0.1686829082187145, 0.06072693556967763, 0.0335092144086957, 0.050673919970229755, 0.06828839575210888, 0.3363497387016973, 9.66617432332808, 25.78814829549482, 33.62587936462895, 37.60059356689453, 39.55975078767346, 34.79227066040039, 36.88233698568037, 19.80821255714663, 13.662709651454804, 0.9971981423516428, 0.20410348901585226, 0.7724804683558403, 14.483262627355515, 33.25283450465049, 50.38404118630194, 74.58926600794639, 78.73667824652888, 79.28449999901557, 67.64246602212229, 59.2613729353874, 47.660610137447236, 36.65991114031884, 27.73978044909816, 29.972275880075273, 52.961183517209946, 0.5128277447675506, 0.07630232661481827, 0.03139813847449278, 0.06940879168048983, 0.049328661914313995, 0.04606053465977312, 0.047483351457143025, 0.08328029976016091, 0.13854084175921258, 0.06610053291003551, 0.12750105511757637, 0.07411637133167637, 0.04117640238555689, 0.32877665313501514, 7.029258012771607, 34.916382297392815, 74.3397875755064, 69.61948963903612, 77.2287779469644, 76.46910898147091, 76.55584827546151, 76.8099158810031, 81.94600858995992, 75.49235251642044, 81.5121473804597, 82.57995774669033, 81.2143139685354, 78.88934473837577, 74.19119250389838, 72.0610866238994, 73.0986947398032, 74.99403892024871, 74.011563639487, 75.07823651836765, 69.76395053248253, 69.59739885022564, 73.06614691211333, 68.46197466696462, 72.65626707384664, 67.46424921097295, 67.22656142327094, 62.829945318160526, 60.73627825706237, 59.24529121768091, 59.68786008896367, 60.95193801387664, 60.0340171014109, 58.97436134276852, 61.023584027444166, 58.255783127200225, 59.355192107539025, 61.412502719509995, 62.41808860532699, 60.573244940850046, 60.61046038904498, 61.406854506461855, 58.33009243011475, 60.240176877667835, 67.90046384257656, 75.88295782766035, 75.07535749866118, 72.3027987633982, 68.32238535727224, 75.91345033337994, 68.46585781343522, 74.37173135818975, 72.4738690160936, 64.79251500098937, 72.02656192164268, 71.57540305968254, 69.57090716208182, 65.90758600542623, 63.068503872040786, 56.1682035846095, 62.84059455317836, 68.88614762213923, 63.96596177931755, 70.09091931004679, 70.30804603330552, 67.53558927966704, 60.69503453470046, 53.45531586677798, 50.69496354749126, 51.45418144041493, 51.39156472298407, 53.48065437809114, 53.66961456114247, 53.56551093439902, 54.309094259815836, 53.604514983392534, 54.7724046245698, 51.95496220742503, 54.17993061004147, 53.42334462750343, 53.53461834692187, 52.34646574143441, 53.44597670339769, 51.874024098919286, 54.44407870692592, 54.24577543812414, 55.337174938571074, 53.98060752499489, 55.511571361172585, 54.103648354930264, 56.51697289559149, 56.49717669333182, 56.961424504556966, 56.80841676650509, 60.16047823813654, 64.95318705035795, 67.86263650463474, 66.70716116505285, 65.2081685681497, 63.56695475116853, 69.26503289130427, 62.12913543947282, 64.71923335905998, 66.33454384342318, 69.51782180416969, 68.60300740888043, 77.63959130933209, 47.67150255941576, 35.62737857141803, 5.679689088175374, 0.6186114636159713, 0.08279332064933355, 0.17850516664405025, 0.09193152384532076, 0.06966726974614205, 0.009654106914005693, 0.06288637654976019, 0.42317002350764893, 0.7276239366300645, 1.7376206502799065, 0.4892589884900278, 0.225750437126525, 0.1081713161341125, 0.05456493416380498, 0.323665130643114, 20.403165509623868, 30.496424167386948, 18.814803669529578, 23.516021236296623, 39.07228646739837, 51.39603622498051, 0.5589960948113473, 0.045319857871941024, 0.02690885940776958, 0.05050964390618667, 0.03137371942190634, 0.7353438965735898, 15.124064164776957, 35.95174289518787, 48.30458487233808, 50.99538964609946, 55.2715576079584, 48.34757404942667, 31.262078669763383, 17.812438049624046, 11.65497583727683, 0.8626337565722004, 0.2873104281963841, 0.46395829127680877, 12.567486820682404, 31.41287419103807, 48.899753555174804, 75.63486006952103, 84.65941013828402, 89.6478020760321, 78.64712269075456, 73.47197886436217, 54.194015841330256, 63.92261566654329, 51.34324504483131, 42.11903064481674, 69.02972205992668, 0.7379637334135272, 0.1435185746560174, 0.274988608735223, 0.1818476695447199, 0.24238392199960448, 0.2451712103380311, 0.29717001042539076, 0.955936095166591, 0.6009788775155621, 0.15946547620959822, 0.20868645680527534, 0.23735956499172797, 0.1356454430929115, 0.5416514964834337, 10.51458691397021, 57.52585357235324, 83.96409157783755, 78.54729836986911, 81.72623034446471, 82.1401188450475, 84.09165490058162, 84.20211668937438, 85.84264801394555, 85.23072688810288, 86.34886910838466, 87.15260198039394, 85.74255697188839, 80.64643321498748, 75.3648990200412, 76.10672120125064, 78.29315231692406, 80.24810083450811, 78.80699065423782, 79.11301397508191, 75.24776920195549, 73.32428593789378, 78.73873356849917, 73.5649625716671, 78.01664875399682, 73.26949827132687, 73.17382381808373, 64.71139254108553, 64.52682149025702, 62.73450228475756, 63.112077482285045, 64.59312915802002, 63.970076345628314, 63.03338296951787, 65.60067622892319, 62.352596790559836, 63.60710020988219, 67.16411729012766, 67.08589738415134, 66.61806060421851, 67.25055063924482, 64.16883460937008, 64.3577673358302, 64.45090401557185, 71.06537726617628, 78.53601763325354, 78.16782474517822, 77.64958550853115, 73.34221116958126, 77.41030523853918, 69.2986789826424, 70.53876769158148, 72.78800379845404, 67.64911836193454, 73.41442984919395, 75.36653072603288, 71.59275562532487, 68.57272671115014, 63.28115124856273, 57.43728645386235, 64.60881079396894, 74.36578504500851, 70.6549482960855, 73.44549502095869, 72.28413612611833, 68.7700140860773, 63.06678587390531, 57.77063692769697, 55.33599038277903, 54.566766523545795, 53.52229425984045, 57.71342523636357, 60.47749596257364, 57.30431810502083, 59.32294630235242, 56.855453829611506, 56.77407641564646, 54.32554075794836, 57.29630078038862, 56.09314903136223, 55.833950965635246, 55.48964531190934, 54.98644444250292, 54.937328523205174, 58.404664531830825, 57.80734639013968, 60.02204210527482, 57.998236379315784, 58.75732875639393, 56.01816900314824, 62.16427987621677, 59.56134011668544, 59.546270370483406, 59.13969709027199, 62.566785658559496, 68.49498533433484, 70.02756518702354, 71.34297909275179, 69.97513094256001, 66.44204816510602, 72.53960794018161, 65.56066020842522, 68.10865540658274, 71.29351016013854, 71.73039159467145, 71.48136815717145, 79.35045073109289, 54.27755055889007, 48.02422169716128, 12.18444089735708, 0.6612964118680646, 0.2527834123541271, 0.38776490236482314, 0.3061068244278431, 0.2771377917979994, 0.09981809259061852, 0.14440219578964097, 0.5975876820664252, 1.9538011017345616, 3.6529506550681208, 0.2779558204835461, 0.2451488558924006, 0.29121196077715966, 0.23986569906194366, 0.803616120209617, 33.026600037851644, 42.45256154767929, 23.676973735132528, 30.93376255804493, 52.46482718375422, 52.92006138832339, 0.3072527693884988, 0.17326271972588955, 0.1891555507937747, 0.19792636886479395, 0.1701215447317208, 0.742313274212422, 12.329941218899144, 34.84966278076172, 45.69653426447223, 49.58172821229505, 55.03369331359864, 48.303745485121205], [41.291845921547186, 46.71991594376103, 58.785369780755815, 25.24322517456547, 0.9044997261897211, 23.779643735577984, 26.771447273992724, 22.006924613829582, 24.10693414749638, 32.20726005492672, 31.115560493161603, 51.677128961009366, 54.5140027999878, 41.15705367057554, 39.47851457903462, 54.82550174959245, 23.51536620047785, 25.060066176999, 28.588750016304758, 0.22198186676588752, 0.14291842137613606, 0.060477324971748944, 0.012659168193837809, 0.1547558434427746, 0.045101315969781536, 0.04224735116886516, 0.018473187566644723, 0.08560734545631755, 0.0792381823844006, 0.06048355709701296, 0.051184992546275745, 0.12182840386465674, 0.45384936275020726, 0.5940930341039935, 14.243964706697772, 64.25852744810044, 66.33148439468877, 70.05966586451378, 73.56767685182633, 73.25669565508443, 72.37093033329134, 73.60900294396185, 68.98839596779116, 75.13970790370819, 73.92298867625576, 76.65951651911583, 72.76479905651462, 69.40031543854745, 67.86342882340955, 68.35553722996866, 68.56418378891485, 70.03810067330637, 68.26082767978792, 63.014037839828006, 67.79693680424845, 68.2456559519614, 69.48355597834434, 67.9589306923651, 62.76614012256746, 62.856405627342966, 58.00343744216427, 57.5115212317436, 55.314566396897845, 57.772621647004165, 57.74073669987341, 58.73586554681101, 56.205583772351666, 57.11411453062489, 56.501636428217736, 54.83241296583607, 57.195488022219756, 57.108203518775206, 57.51062300897414, 56.080981839087706, 55.73656635899698, 56.981271697628884, 57.207506164427734, 64.93969017459501, 71.36885889114873, 71.68657087510633, 65.28439591007849, 70.3299799273091, 69.07307993981146, 73.75822559479745, 70.39636212010538, 62.54554994644658, 70.3844851832236, 67.69687714115267, 71.84418739811068, 69.10395683780794, 63.69992310001005, 62.625833019133545, 59.788594399729085, 64.03123786372524, 61.708312188425374, 56.42899021025627, 65.04124033835627, 67.61630381307295, 67.35121434734714, 60.44505011650824, 53.63363073718164, 48.3714299048147, 49.231233058437226, 49.11660179015129, 48.227882923618445, 48.48991294060984, 51.716156544223914, 49.9978171625445, 50.69922716386857, 49.19204858041579, 50.819275225362475, 50.02845087359029, 50.042445890365116, 48.4715287916122, 48.32989200468987, 51.087694783364576, 52.03819490248158, 50.41387865620275, 52.558481616358605, 51.57345287261471, 50.44419073289441, 52.39669561386109, 50.95497746621409, 51.10298025992609, 54.86816144758656, 55.057784511197, 52.49592373448034, 57.457384678625296, 57.79120975925077, 60.29467036647182, 60.71947482324416, 61.80569679506364, 61.125396990006976, 67.90772022739534, 60.956907656884965, 61.3462499649294, 61.60161195262786, 62.869471042386955, 63.8095219673649, 77.95031362964262, 38.57371007242511, 32.9531144326733, 7.466208579078798, 0.6430084222266752, 0.022841133627920382, 0.11309372982190502, 0.07276915209067446, 0.01348226742383333, 0.21796725960748814, 0.07280633033763978, 1.3373812624523718, 2.6046021090399836, 1.550623736073894, 0.44816495970852915, 0.059180629229353326, 0.32308437470947543, 0.03435109524176486, 0.05212516246003009, 7.754196351574314, 27.941021573159006, 15.107020485785702, 25.929696829088275, 24.63028423247799, 41.617853718419234, 17.172466093494048, 0.26959167252625194, 0.09942004096604164, 0.07548372336332837, 0.16123752950900988, 21.861947928705526, 54.30916094010877, 38.67314607866349, 35.22249975512105, 30.08150604463393, 30.130588623785204, 32.262045760308546, 54.23426328166839, 59.81456441263999, 77.62201909096011, 37.64965457300986, 2.6484745548617457, 49.35748238717356, 45.33449557519729, 35.994269232596125, 38.912928412037516, 44.990864569141024, 43.387458478250814, 62.989777980312226, 66.1187977944651, 48.015055118068574, 49.077735024113814, 51.662671104554214, 27.695867553833995, 30.65171080250894, 32.30993790011252, 0.16237734576627133, 0.07231230321790903, 0.018765287316073815, 0.07212307183973252, 0.10627779193342694, 0.06016865665573747, 0.06635398543890446, 0.057956160256458875, 0.04776138774750214, 0.06313443198920259, 0.22338244403081559, 0.10748689318256033, 0.20377442360885684, 1.4305153681385903, 0.6328087276028049, 23.519221890357233, 72.60507229835757, 72.8651725092242, 77.48902720789756, 75.26189757931617, 80.38150848880892, 76.17360545742896, 80.88867095208938, 73.7389902914724, 78.78359763853013, 79.73847512275943, 79.90334803058256, 75.60965491879371, 73.46547557461646, 70.77183492722051, 72.70826201285087, 72.88432936514579, 73.36784778102752, 70.35406328016713, 67.14392492848059, 71.03573199241393, 73.43881914692541, 73.51327357753631, 70.70881028329173, 66.85570916821881, 65.68714880174207, 62.112614416307025, 61.42450909460745, 59.05316568190052, 61.70450748935823, 61.79072118574574, 60.503269856975926, 60.7157721058015, 59.41884825306555, 56.94745694437335, 58.50411622754989, 61.82336315031975, 61.59039005156487, 58.341467303614465, 59.48925872002879, 60.45533849347023, 60.97214214263424, 60.06256411152502, 69.61835999642649, 73.21977046228224, 72.02160404574487, 68.16893439139089, 72.70537514840403, 71.94779288384223, 75.68008499760782, 74.69569560020201, 69.0115144175868, 76.03381218448763, 73.20043317733273, 75.10967039292859, 72.19753019271359, 67.73561446897446, 66.66212451073432, 64.66862301672658, 64.8855693109574, 67.57432660748883, 60.75976933202436, 65.99097559528967, 70.89683301987188, 70.21077909777242, 64.32973415620866, 55.11342333209131, 50.415647645150464, 51.93524837493897, 52.90250093706193, 53.751074344881125, 52.97471961667461, 56.70525843097318, 52.54060737548336, 54.30582300309212, 52.45793950173163, 52.90084569684921, 53.11641523914953, 53.063502465524984, 52.4146169231784, 51.2097942444586, 51.935279753900346, 52.70479386852634, 54.50036079652848, 56.221041833200765, 55.74290098682527, 55.75311091638381, 55.339740168663766, 53.72436300400765, 56.17740938740393, 57.33286119276478, 57.95927155402399, 55.26640753592215, 59.427481389814815, 59.56086550989459, 64.30574886260494, 64.03855700646677, 64.24638771241712, 64.47675635737758, 70.68382478529408, 63.076603566446614, 64.85054646768879, 64.59423526640862, 64.91043713784987, 66.51840102288031, 80.14116917887043, 42.63914869677636, 49.56992580044655, 19.738784643911547, 0.7725484356764825, 0.03035037725743267, 0.12871919620421626, 0.08047829487270887, 0.03563887755116148, 0.14583404476363815, 0.07552775809721601, 0.10624370102079646, 0.47664878289065055, 0.40361115528691205, 0.5647897419910277, 0.15746909704419876, 0.22249588111956276, 0.05653104519531612, 0.1236564964957295, 8.842798221495844, 30.048607164813628, 23.07992623698327, 36.64187215989636, 34.266014099121094, 50.88330399605536, 31.212813700399092, 0.1317036602525942, 0.06288081858186953, 0.06453890864166521, 0.5859163631835292, 31.365411550767963, 66.39673694487541, 48.8016236982038, 48.65409943365282, 40.07217707172517, 37.89010763168335, 43.48375658835135, 71.23323117533039, 68.66761669035881, 90.67207413335001, 41.59109138673352, 2.683280687178335, 60.47256162089687, 55.58750452533845, 49.83631357069939, 52.945474424669825, 53.23327833606351, 48.976361367010306, 73.60194267765169, 79.33191360965853, 64.37316263875654, 59.71324174634872, 84.84151794064431, 47.15273380279542, 39.03035240788614, 43.233474070026034, 0.44178638907690204, 0.2187599767480166, 0.15088372863829136, 0.12145901158932718, 0.27271084547523533, 0.1659852368456702, 0.2182942412553295, 0.17585019701190535, 0.15711985288127778, 0.23375882917354185, 0.4341406477314811, 0.1660880152015917, 0.37892522831116954, 1.763326638648587, 2.276073944184088, 36.95177470484088, 80.19172853039157, 79.88396367719098, 82.70432826011412, 79.91419730647918, 85.75807386829008, 81.20040524390437, 87.75194798746418, 77.7896611921249, 85.81262619264665, 83.04591178894043, 86.61100895174089, 78.66369862710276, 79.53036985089703, 75.48175427221483, 74.58679491473784, 75.59655420241818, 77.07739799253403, 75.54198618858092, 69.23359901674333, 74.7150799535936, 76.97582429455173, 78.04055167782691, 76.75611665171962, 70.45589585458079, 70.4748801262148, 66.85084542920514, 64.735326843877, 63.33713523803219, 67.52763471295758, 65.93168504776494, 65.1875094444521, 63.57917685662547, 62.26612421774096, 61.16199662608486, 60.558822385726444, 63.83202852741365, 65.80172907921576, 63.537078057566, 65.37046447876962, 64.66966244482225, 64.84208983759727, 63.395013732294885, 72.38639231651061, 74.95137137751426, 76.01734607450425, 69.07211503674908, 74.73681772908857, 75.93058324629261, 80.03864626730643, 64.54984188079834, 70.16349884771532, 76.74853863254671, 75.89002593871086, 77.41158393121536, 73.78814543447187, 69.76023997029951, 69.6585407564717, 62.94931480961462, 70.3584171110584, 68.61885378437658, 63.81559771876182, 69.13852860850673, 75.04853633142288, 75.21646868798041, 67.99518123749765, 59.71825061305877, 53.939909012086936, 56.90917853386172, 57.94539420835434, 56.045484389028246, 55.56184045730099, 59.87393732993834, 55.90234925670009, 57.81969401144213, 55.00513845874418, 55.33852423391035, 55.35012660488006, 55.16904646350492, 54.635192271201845, 52.37080012598346, 58.01099192711615, 56.10575160672588, 58.94243717193604, 59.946207000363266, 57.655601655283284, 59.160524875886985, 58.89851839311662, 59.3190239321801, 59.77587023089009, 61.56440434917327, 62.0860521255001, 58.20430986342892, 64.06932015572825, 64.07948301684472, 65.55119160682925, 65.8612471242105, 69.32431559408866, 65.75048723528462, 72.8459450506395, 67.06900765818935, 68.31089281266736, 68.63834011939265, 67.86149117254442, 71.58035309084, 83.90831547398722, 49.37170490141838, 57.49870684839065, 30.110670828050186, 1.060683664775664, 0.18008096353901973, 0.24666468342465742, 0.2568543269749611, 0.1756842470457477, 0.36706367447491617, 0.18334085151793497, 5.207219989069047, 8.319576594137377, 3.7007969521707107, 2.274945772463276, 0.18923792056739333, 0.7688221840127822, 0.1868087936553263, 0.5544825499096225, 13.152051375758264, 47.165508962446644, 29.877748720107544, 44.812635990881155, 43.28942275816395, 66.94313095461938, 32.95087083693474, 0.35641511361445155, 0.28766295121562097, 0.18779291020285702, 0.6581949202283737, 34.64486014458441, 75.42425232548868, 54.75371453069872, 57.603179177930286, 50.10787102483934, 47.713773942762806, 48.79854071524836], [28.215171713982862, 22.568753150201616, 38.40881363038094, 33.01530753412555, 11.136456151162426, 11.59645897726859, 11.69389751649672, 42.11066815160936, 40.62590591369137, 47.917870552309104, 49.7066988483552, 62.91250336554743, 53.81699369799707, 35.832494997209125, 47.292244665084354, 33.55934812176612, 24.791321062272598, 42.09212318543465, 23.22304960220091, 0.3322545697371806, 0.12449550832952223, 0.11631672300638692, 0.026823132253822782, 0.11293924053109462, 0.0742099796151442, 0.01568022347430909, 0.08481927080861024, 0.08681630114874533, 0.0732070173046762, 0.04419837026826797, 0.05723125721898772, 0.10591443643094071, 2.1476160758926026, 5.638807694758139, 22.708777842983125, 56.56135059172108, 72.9765207536759, 69.1769443019744, 75.41770196730091, 71.2641159180672, 70.76890883907195, 76.23348436047955, 69.86448872473933, 71.30659518703338, 76.8691828943068, 74.01223828715663, 70.68147920793103, 66.08304146797427, 66.29603401307138, 69.1653968441871, 69.6831653964135, 70.22740210256269, 65.06996385512814, 67.3723166988742, 69.72688413435414, 68.87227027646958, 66.25081692972492, 67.30159636466735, 62.55565397201046, 59.39730659607918, 58.7564540678455, 58.47668317056472, 56.98723370029081, 55.76487802690076, 56.88302416955271, 57.0050020371714, 56.24966729071833, 55.39337858077019, 54.44422383462229, 53.468200852794034, 58.68369017877887, 58.27380249577185, 56.65673871194163, 52.69587832112467, 52.68753543976815, 54.53715655111498, 53.18585688068021, 62.68788099288941, 66.52733618213286, 70.31084660560855, 66.85565425503638, 71.05076251491424, 65.18768595110986, 75.7732177549793, 61.92706277293544, 62.675101910868, 75.27173488370835, 65.46702931004187, 69.52929081455355, 71.20510778119488, 66.97583567711615, 61.04565912677396, 67.03975462144422, 61.59791315755537, 62.773702452259684, 58.80950412442608, 59.85426664352418, 64.27091429310461, 64.59795367333197, 58.1424109397396, 52.30080150788831, 49.135029085220836, 47.477462906991285, 46.50623698388377, 51.16481250332248, 52.4612735163781, 54.30197908032326, 48.932732843583636, 48.44353483569238, 49.38242473909932, 46.53263845751363, 49.097091920914195, 48.92533525343865, 48.81085695758943, 49.631440331858975, 49.88899492448377, 50.57478604778167, 48.42977908349807, 51.60847571588332, 54.40683972450995, 50.85306644439698, 53.06519692943942, 51.15197458574849, 51.77193657044442, 55.5600675459831, 56.65630725122268, 52.97793596021591, 56.5196361849385, 60.934510923201046, 61.12658154579901, 61.419692424035844, 61.04844793196648, 61.80898374126804, 65.86212573512908, 61.83744053686819, 61.76608477869342, 61.33098802258892, 65.08559842263499, 69.13252738214308, 71.66470758376583, 36.17758120259931, 54.630767837647475, 26.02217455064097, 1.9244821201409064, 0.31578564055023656, 0.03163382350917786, 0.17946332813270632, 0.1619861046633413, 0.04018747097542209, 0.06519649553322984, 0.4097021977987982, 0.49430346296679595, 1.2107932615664698, 1.1789659242476187, 0.3455786160644024, 0.19210538766797514, 0.08283826702785108, 0.12185684870928527, 3.0052219667742333, 15.15593146124194, 19.99402503813467, 14.458456577793246, 30.719144190511397, 32.811048146217104, 30.610396477483935, 0.4910536873484812, 0.16111657954752445, 0.04091572181712236, 8.824104205254587, 42.07650822977866, 41.54909064692836, 78.96207332611084, 96.9058656692505, 99.79010997279998, 95.80263630036386, 53.197529854313025, 32.45596774162785, 29.031556190982943, 49.88264460717478, 37.05469769816245, 28.748433628389915, 23.661329361700243, 23.137126161206155, 60.214630480735536, 62.63620768823932, 64.76598016677364, 57.84319293114447, 74.1561814277403, 64.33380557644752, 49.03188251679944, 54.69341201166953, 42.11947387264621, 27.866673046542754, 49.039291874054946, 27.86823218868625, 0.5125614526050707, 0.16923066108457505, 0.2694425918161869, 0.05879831688118078, 0.08088449001192086, 0.09801430026850394, 0.07185837314013513, 0.06261223198605642, 0.10540140266980856, 0.04250261166523542, 0.052789353029502016, 0.13953718507001478, 0.08244580784512144, 3.166081799614814, 8.630804900200136, 31.20625549747098, 61.032279922116196, 76.5281641867853, 74.43567383673884, 79.13777197560957, 78.05800622509372, 74.63983320420789, 80.29687158523068, 76.20860868884672, 76.41605500252017, 80.28053099109282, 80.73183105837914, 74.2199670114825, 73.12830863460418, 70.80255493041008, 73.38839315599012, 73.03008464074904, 72.79541707807972, 68.85363117341073, 71.10333796470397, 71.08429877988755, 72.98041958962718, 68.84740244957709, 69.06862412729572, 65.33642222804409, 63.162927089198945, 62.049323051206535, 61.24184039331252, 58.875333263028054, 58.91152889497819, 57.85614459745346, 57.820615768432624, 57.3184778613429, 58.75488904214675, 56.91422662427349, 55.4574897212367, 62.466235699192175, 64.24645439271005, 61.675344667127064, 57.79121368162094, 56.02700610314646, 58.704498352543006, 58.38599012744043, 66.7456631506643, 67.87551756828063, 70.71895353255734, 69.00927082184823, 76.18909097486927, 67.62671378351027, 80.38961210558492, 67.32249475294545, 68.00858789874663, 78.54561959543537, 69.85863654844223, 73.882658866144, 74.44506399093136, 70.96124618284165, 62.23765565503029, 66.49729082661291, 64.8711310663531, 66.5182755070348, 62.46306642409294, 63.36895742724019, 65.819944566296, 65.8865777907833, 61.10788360718758, 53.617348978596354, 51.58038370070919, 52.7679204940796, 51.35010134789252, 53.171112691202474, 55.70811740813717, 55.80119917469641, 52.579729095582046, 51.08443921612155, 50.74300865973196, 49.13280510133313, 52.18906887115971, 50.50961194499847, 52.25886744837607, 50.44303755606375, 51.885967716093994, 51.603608054499475, 51.39351414095972, 54.33353847072971, 56.26747877367082, 54.92600071814753, 57.03568673902943, 54.7664543890184, 56.14224533880911, 57.729605013324374, 60.467505685744754, 56.47788255445419, 61.91559376255159, 65.11689109186973, 64.88737752360683, 65.33431199289137, 65.72967513915032, 65.04193459787678, 67.53122760403541, 67.30855464935303, 64.11426267316266, 64.95509724463186, 66.1695924881966, 71.47591606263192, 72.27886446060674, 42.858401344668486, 63.53045709671513, 46.72483851832729, 0.9140142317741149, 0.3325892275860233, 0.062055864461487344, 0.11969247412297035, 0.14623130731765302, 0.077623383953206, 0.0291429614017327, 0.0031817726267036055, 0.39508959158293666, 0.5031615537741493, 0.4782504275921853, 1.4938395830892748, 0.20992606367555358, 0.057452411480969, 0.11741173844183646, 2.8819693288495465, 20.23563127363882, 19.630931231283373, 22.71337486082508, 42.828524651065955, 41.97436971049155, 47.05713387458555, 1.216491362260234, 0.16601099272168454, 0.02645435859449208, 14.576871952702923, 53.609343421074655, 53.9846004978303, 88.09131145477296, 101.74608615136917, 106.85632259615006, 110.3819214913153, 59.76182422330303, 37.6309762462493, 37.53903196704003, 59.88558284697994, 48.15837460179483, 44.91813598140594, 51.46366180912141, 50.23417134438792, 97.03838686789237, 96.502136107414, 100.72856841548797, 78.13197428180327, 89.71332134739046, 77.37395271178215, 63.75217691544564, 68.7007999420166, 54.48855838467998, 40.372132485912694, 65.3240785291118, 35.32554434191796, 0.47819710787265535, 0.2926321652147078, 0.28127696485288683, 0.2726384654881493, 0.24024178694573142, 0.27968880329881946, 0.1699487765830371, 0.2581850829864702, 0.20985477153332005, 0.23339619379370447, 0.17759778146301547, 0.19593663934257724, 0.24907475006916832, 3.740593565087165, 11.242006151906907, 41.31916915216754, 70.75683578368157, 81.88701614256829, 78.74301679672735, 82.57440367052632, 83.17409484617173, 77.91177242032944, 86.10622344478485, 77.83265821395382, 81.72152350025793, 86.87594936740014, 83.5047035832559, 78.31776126738518, 75.54688915129631, 74.31392346659015, 77.46015071868896, 74.77986181935957, 75.78172929825323, 75.37854886824086, 73.59463922439083, 75.45599998966341, 78.25676841120567, 75.58538329216742, 73.87624971328243, 70.26212292332804, 68.52330484697896, 65.33419824415638, 65.47613705358198, 64.50177715670678, 62.71174469301778, 61.61799569283763, 62.47310769173407, 62.221566092583444, 61.776337854323856, 60.59017389051376, 60.12420023641279, 65.97854168184342, 68.34707275513681, 66.1489215973885, 59.690429241426536, 57.99772647119338, 63.29360085148966, 59.231535465486594, 70.86212004384687, 73.88046233884751, 73.35769668702157, 72.8073646176246, 78.03433079873362, 73.10311132861723, 77.59777099855485, 64.90597348059377, 70.4646348953247, 83.54127576274257, 71.91060881460868, 76.44535510770737, 77.9865720195155, 73.98023174655053, 65.36507906452303, 72.21350208405526, 69.08918519173899, 68.40258213781541, 67.71802656112179, 68.59699049303609, 70.4375470069147, 71.29856217292048, 66.88558193945116, 59.83497250464655, 57.15144372755482, 56.25495464571061, 53.52665985784223, 57.109466521970695, 60.11762634400399, 61.11701488494874, 54.8265137210969, 53.875248739796305, 55.88622047055153, 50.56421918253745, 54.740307869449744, 53.86528984192879, 55.11889111611151, 52.73219162417997, 55.33752795188658, 56.606767715946326, 55.55151285663728, 58.324404993364894, 60.56440784085182, 57.040134706804835, 60.43166306711013, 57.544386771417436, 60.20049033626434, 63.44927580125871, 63.822261825684585, 59.904476904099994, 65.4974865144299, 69.15248440157983, 68.16585140843546, 69.74517806883782, 68.09189904120662, 66.9912584366337, 71.26755191433814, 68.44759525791292, 66.80146278873568, 67.99999006332891, 69.31635318263885, 77.33366212537213, 74.26882405434885, 52.971291465144006, 69.76620981770178, 56.17359292122626, 3.5240941759078734, 1.019358798380821, 0.19909266112071855, 0.26643388874588475, 0.34983270230793184, 0.3119749047102467, 0.13867328303956217, 0.42920872689254824, 2.4096323645883992, 2.6428724296631354, 5.46573507208978, 1.2376367372851218, 0.4992315227225904, 0.4448712106433607, 0.3416080742834076, 5.737957858270215, 29.968133857173306, 37.02077311854209, 28.850301504135135, 48.80833095119846, 52.16023160565285, 63.37569605919623, 1.37849370798757, 0.19659792643881616, 0.1462109906659011, 15.304848167204089, 63.89115825776131, 59.47922921949818, 102.15444411000898, 123.58479207561864, 127.04657400808028, 132.67595967938823, 72.51476364751016], [102.25447239414339, 48.977789109753026, 48.282097924140196, 20.54648107097995, 19.88603630373555, 6.950087422324765, 17.742825784990867, 21.012725368622814, 42.025725303157685, 68.90657532599666, 62.426655061783336, 72.95902698270737, 54.505926639803, 29.46306593956486, 44.97174693692116, 53.32401844762987, 33.17768581451909, 39.40824531739758, 12.933034070076483, 0.30353843805290043, 0.40970829585867546, 0.2162422441066273, 0.06621749155343541, 0.056773171114224585, 0.09055578315089788, 0.08616077503369701, 0.04568724682734859, 0.05743858742437536, 0.025442605425092964, 0.041260936357561624, 0.176953072509458, 0.08297712046412692, 5.270026941453257, 18.14938925927685, 44.882293362771314, 38.57126643580776, 78.29870639308807, 69.74793941743913, 76.327527107731, 72.74624624559956, 69.3913096766318, 70.09926611377348, 73.96130238809894, 70.23678441201487, 72.94593411107218, 76.15095769205402, 69.19952146468624, 72.0606630079208, 68.93174909776258, 70.56141545695644, 71.43718657955047, 64.19338472427862, 66.02742225893083, 70.56988777652865, 68.96856446419993, 67.49727556782385, 64.88362381535192, 65.2883339697315, 59.510545422953946, 59.94379866507746, 56.952442276862364, 55.93188470409763, 51.63421038658389, 55.70207695807181, 55.366055350149836, 57.027943980309274, 54.034045896222516, 53.79151790372787, 55.792362074698175, 53.19354472621795, 51.765629399207334, 56.11789918714955, 52.95846139231036, 55.49244980658255, 55.11351746897544, 53.75981730799521, 53.12049058175857, 64.362019185097, 64.62001700555125, 66.70580402497323, 65.50794355330929, 74.22136337526383, 67.54919990416496, 80.12713493839388, 54.071143673312285, 64.72777628129529, 74.67508746731666, 71.0136490483438, 73.54211868778353, 73.65847972131544, 65.61365142945321, 61.621365008815644, 63.68067995194466, 61.94090873964372, 60.34053464089671, 62.00049346493137, 58.58179484644244, 62.06520472803424, 65.32675358556932, 56.267000244509795, 49.95778937493601, 48.45596874913862, 48.75497887211461, 50.88034652894544, 49.88804571090206, 52.33003885515275, 49.6418228457051, 47.50275042749221, 48.483111550731046, 48.82120024773383, 49.728797481906035, 49.9384520899865, 48.59158862021662, 49.67242910015968, 49.61221679564446, 49.05531867857903, 46.50945332742507, 48.55596173194147, 52.043905873452466, 54.726614875178186, 55.29295021487821, 52.639560930190555, 51.76508026738321, 53.870275174417806, 52.59140599158503, 57.35691708903159, 53.81886466856926, 53.571794571415076, 56.68394034908664, 58.02339838397119, 60.15265703201295, 63.39035003416, 63.325858423786784, 61.419990524168945, 62.27116054104221, 62.21829483585974, 63.76963930745279, 61.761452459519916, 69.28090280102145, 66.19609202108076, 38.40067078990322, 78.1429490735454, 41.838973414513376, 1.745651212911452, 0.394488702858648, 0.2578080757971733, 0.04008229476429763, 0.008788008126430213, 0.0688000658767358, 0.1312177306822231, 0.11849337798212806, 0.04429926404789571, 0.02764166272695988, 0.5774962601642455, 0.6039905223634936, 0.32061263798705997, 0.04180216215430729, 0.05043173659472697, 0.8387831105820595, 10.426309070279522, 16.584130179497503, 12.043766071719508, 15.400971731831952, 30.02459441461871, 29.31892275810242, 2.952811501679882, 0.28051492187284655, 0.12664310559029543, 28.432221951023227, 50.84378611656928, 83.79401760716593, 80.692152361716, 62.726367289020175, 53.6172862206736, 67.88540194111486, 104.17284873224075, 107.6094961166382, 46.12097786318871, 56.55659667907223, 29.222208876763624, 30.1606124062692, 18.70991949112185, 31.760223604017693, 34.571888369898645, 62.9529586915047, 90.29060009987124, 75.02727708508893, 83.38224718647619, 64.696220813259, 40.50108825006793, 57.21439384645032, 53.04726777538177, 35.2993703657581, 46.52409161290815, 14.46141992845843, 0.33035908435140887, 0.3717732153111889, 0.13205593812369532, 0.04844817408030072, 0.07971595311837812, 0.20042833541670155, 0.06651425869354317, 0.11445680708293954, 0.06023768500815477, 0.10096723213791849, 0.0460353686714605, 0.1765778886094209, 0.04848204665787278, 6.575155902293421, 20.537602786094915, 53.56709949431881, 44.620451619548184, 80.78905843919324, 75.67506436378726, 81.22266861700243, 76.7503115438646, 73.41489268887427, 72.86037152813327, 79.40520701869842, 75.50404902427428, 76.4260962701613, 79.1139788781443, 75.70307008681759, 75.17052988852225, 72.98332998829504, 73.4217882156372, 77.89381580968058, 67.11479740758097, 68.22691486727807, 74.11267449778896, 71.37580148635372, 69.19916845137074, 67.98535962258616, 69.3491049735777, 64.26242236168154, 65.4265308380127, 62.32287306939403, 59.17028765524588, 57.65628414769327, 58.195700260900686, 61.46685500298778, 60.228715712024325, 56.985990308946185, 57.883208951642445, 58.83075160364951, 55.01419521147206, 55.09944400479717, 56.97674528245003, 58.4277476802949, 59.339200604346495, 57.19860630650675, 57.308056123795055, 55.383243176244925, 68.46466541290283, 70.65685456798923, 70.88394411148565, 70.25908700881466, 76.22219577912362, 70.50196801462482, 77.52104943798435, 60.30753966300719, 66.92187955302578, 75.30348254788306, 76.18360750136837, 73.57858104090538, 76.78671113906368, 68.08954561910322, 63.696518482700476, 68.41605155698716, 64.88785997513803, 64.91319456408101, 66.16431297794466, 61.98829489369547, 62.049346585427564, 66.12352032815257, 62.00465902205437, 53.90482341089557, 52.173591198459754, 51.983630811014486, 52.79101540965419, 52.232030591657086, 56.205140544522195, 51.321495502225815, 48.73269980953586, 51.70025525554534, 52.79435334667083, 50.86309986729776, 53.080364734895774, 49.4494580453442, 51.141517546869096, 51.5905975526379, 52.24919096116097, 49.92983464271792, 50.01710737905195, 54.046809288763235, 58.91308215356643, 59.149314741934504, 56.36299633210706, 55.40485543589438, 58.50112738147859, 57.012999749952755, 59.11016556524462, 58.48939557229319, 59.08922010852445, 58.53622867215065, 59.29483467532743, 63.93411213351835, 65.9447386956984, 64.82110515717538, 63.775263986279896, 64.76538004413729, 64.21949202014555, 68.10655301617038, 62.550833379068685, 72.70252750765893, 67.03865635779597, 44.62674702367475, 81.24327674988778, 55.034987695755504, 12.305324423697687, 1.1559824285007294, 0.1433804490032696, 0.03190733988078372, 0.1312668982052034, 0.05321403770076652, 0.07168565095672685, 0.10479177288230389, 0.155948412514502, 0.023784423434746363, 1.0867392343859519, 1.1249353976980334, 0.5222614433976912, 0.20321717125273522, 0.011726082678163245, 1.0766743099497211, 13.768286128197948, 16.08924767663402, 20.45005548384882, 21.49928754375827, 37.86368262383246, 45.75195343263688, 5.667169372881613, 0.5216702073812485, 0.23388077504932883, 40.88710438820624, 63.49339854332709, 92.92216531692013, 81.42514921003773, 67.39286991857713, 58.618445473332564, 66.26203490841773, 109.96584430817636, 145.54007868612968, 68.34909669814571, 74.95664304302585, 36.718307387444284, 47.35697161766791, 59.06849038216376, 79.16988049784015, 59.599434175798976, 93.04719478853288, 119.6470069885254, 104.96504983594342, 95.4623628431751, 77.51053748592254, 50.57842600730158, 70.98977750347507, 74.51743172061059, 50.42952499082012, 60.071381599672385, 20.170441481374926, 0.3964451075561585, 0.6692937569272134, 0.41113760142076405, 0.3597796185603065, 0.2784871484243101, 0.2612377288601091, 0.29186295165169623, 0.23861647012733647, 0.1674188937871687, 0.23653122476272045, 0.30846830577619616, 0.22576877727143227, 0.1947756177715717, 7.9001099928732845, 23.29257949706047, 55.95774489064371, 56.87650519032633, 83.88030975095688, 79.14935865709859, 84.82264349537512, 83.97123029155117, 78.30932032677435, 77.65757929894232, 84.53481997213056, 80.88043397472751, 80.3036415961481, 83.40364763813635, 77.03042368735038, 79.28889305360856, 74.61898188437186, 75.98343326199439, 80.49943062566942, 70.90572111068234, 74.25475059017059, 78.64250998343192, 77.2026784958378, 72.68857171458583, 71.30553614708685, 73.98643693616314, 67.14956529678838, 69.59773617406046, 65.61761302332725, 62.87553894904352, 61.141965081614835, 63.13500373594223, 64.59456082313292, 64.80054017036193, 61.620631525593424, 62.22692012786866, 62.970311257147024, 57.76421600772489, 60.03771981885357, 62.628025624059866, 63.85402910171017, 62.94143869030861, 62.7432099465401, 61.94011642086891, 60.34071899229481, 73.00576594568068, 72.87024021148682, 73.7888514611029, 72.47743052821006, 80.55357502352807, 74.6691882225775, 73.42976631656771, 63.64890483117873, 69.44506968221357, 81.45240183799498, 77.5478078472999, 78.36180948442029, 78.71205360658708, 70.68640570486747, 65.6042730423712, 71.15995345577117, 66.11591093001827, 67.01904450693439, 69.08731814353698, 65.17905673673077, 66.05488669487738, 71.16005543739566, 64.14441001030707, 57.31274335615097, 55.52333062694919, 55.03511713397119, 56.43471294833768, 56.8645223494499, 58.83256373866912, 56.94759422732938, 51.998892753354966, 54.55891786083099, 55.2263326798716, 53.90339174578267, 55.84679672794958, 52.96964406967164, 54.99860771240727, 55.50147518034905, 56.44031801531392, 51.974683884651434, 53.492315584613436, 58.64519996027793, 62.88123423053373, 64.14921883613833, 60.19893315530593, 59.16916977974677, 61.321256622191406, 60.28010660602201, 62.68167972564698, 61.64583667632073, 61.65786266326905, 63.783347991205034, 63.34304624988187, 64.33270731279927, 69.19419488599225, 70.75936963481288, 66.4156113901446, 65.70010439042123, 65.20002965004214, 70.83171383027108, 64.88944069031747, 75.5694035560854, 69.44350857888499, 54.67330201979607, 77.26140422205772, 67.57020027406755, 25.45641383817119, 2.629624624406138, 0.424332577254503, 0.1572844545326887, 0.23839096448594527, 0.16012523112998855, 0.32163508957432163, 0.2186919481403405, 0.3178610646676633, 0.10713076188920007, 2.5108351534412754, 3.2163925709262973, 0.843321415445497, 0.5178191753164415, 0.23224045822937645, 2.061303339658245, 22.00681870983493, 28.402645318738877, 28.05954775502605, 32.1438588634614, 51.27732176934519, 63.23101551302018, 8.413611496648482, 0.722360544868054, 0.6865445248061611, 47.02761803903888, 72.72585776544386, 104.93216468441872, 102.32287068520824, 79.48324649564682, 68.32676272238454, 82.73225553574102, 140.6051564985706], [88.7619504620952, 77.40277428780833, 63.12617448068435, 10.65359571287709, 29.03346246288669, 12.471007300961404, 4.777040414271816, 7.965943053845437, 18.397345812089984, 59.76684877949377, 51.03812779149702, 76.38093409999725, 47.68871784210206, 33.77628657125658, 52.71730622937603, 56.37967032770957, 23.05395034051711, 35.8808538990636, 6.4021146585864415, 0.2987942087554163, 0.11863572477933862, 0.14353624064355128, 0.12254736205983548, 0.028580878861248497, 0.027956268224384517, 0.06965420794703307, 0.1437428852002467, 0.06911320431578545, 0.15352936731951852, 0.016681139372409354, 0.13357502919050956, 0.1277483329777756, 10.073479125576636, 37.29689621156262, 59.06900421265633, 35.480399516321, 70.03870471831291, 73.55955754556965, 79.80877184098767, 70.12373385890838, 71.27847179289788, 67.11379328081685, 71.00450992584229, 72.88186611667757, 70.70018891365298, 70.00476837158203, 70.9090551253288, 69.2098137640184, 71.46158372202228, 69.31843988357052, 70.25729840801608, 65.71088698602492, 66.11992743707472, 69.36819907157653, 68.5429794557633, 66.48558647401872, 67.67894406472483, 62.7220566042008, 63.98667973856773, 60.91328697819864, 56.21270287421442, 55.057062795085294, 55.885016302908625, 54.458673846337106, 54.28642688259002, 54.684896546025435, 52.70106369449247, 51.376294935903246, 53.271678340050485, 53.459336296204604, 52.92847879471318, 51.961826355226584, 54.57844734191895, 55.230780647647, 54.20473567901119, 52.0981522529356, 52.95418600882254, 60.46775279506561, 67.21129555856028, 63.50545198686662, 67.96572423750355, 65.2893812425675, 72.10754317622032, 70.55808928705031, 48.08950954867948, 68.35250916019564, 69.60851484729399, 74.74233258155085, 68.4978957330027, 72.84859657287598, 62.68184054282404, 62.93781442026939, 66.84762908566383, 64.12216624905987, 63.77476192289784, 65.1772681359322, 62.56552657773418, 60.248719799903135, 59.734375476837165, 58.29935281507431, 51.92363031448857, 49.658359558351584, 47.94569584631151, 50.27417559777537, 49.893780216093994, 50.73738398090486, 47.34778934909452, 47.78117987417406, 48.083386728840495, 48.53865231237104, 45.94134115403699, 48.34974704250213, 46.873531649189616, 48.26730666622039, 49.72706379428987, 50.290155333857385, 49.448293101403024, 51.442135841615745, 50.27381866208969, 51.787982986819365, 53.5300370185606, 56.52697886190107, 52.918143349309126, 54.24619513173258, 54.34407787938272, 56.481757856184444, 57.01170536779589, 55.465397219504084, 57.51716944479174, 59.61734764037594, 62.77631475079445, 65.52482151216077, 58.34793136965845, 61.03436270067769, 61.43511910592357, 60.90435966368645, 66.89374046940958, 64.25795870442545, 72.8875143297257, 59.10321512529927, 49.46430421644642, 88.31670653435492, 40.09121233417142, 12.885084075312461, 5.0193762106280175, 2.17524794801589, 1.5369047560999471, 1.1111330673579247, 2.3568789372521066, 0.06588644197871608, 0.030215423208691423, 0.036584260693240556, 0.10410900468066817, 0.0860619803349818, 2.6144604961718283, 0.41780535492204857, 0.22956999829940258, 0.15712326963342008, 0.5188030773593534, 10.853960187204423, 18.599245894339777, 19.103017468606275, 20.865638448346047, 21.47932856313644, 27.015938412758615, 5.430935313624721, 0.8158765300627678, 3.6865344787797625, 39.82606403289303, 51.842519621695246, 77.60181888457268, 45.661774220005164, 63.676800727844245, 49.71812471266716, 56.60681086201822, 34.470071484965665, 83.52258174650132, 81.23985644309752, 66.90094194104596, 22.74872326081799, 34.53975631344703, 20.268781185150146, 9.428786596944256, 21.04374739431566, 34.71628258305211, 74.89998048351657, 70.77443938101493, 85.24018764495851, 54.88759679179038, 51.42270834215226, 64.79249931150868, 55.16349630971109, 26.56500900945356, 43.898390339266875, 6.590693881434779, 0.2003881311224353, 0.20875388786437052, 0.030952493637619965, 0.04978700465853176, 0.008980125740861461, 0.05408941572832485, 0.06281783083273519, 0.02173618777775236, 0.17319338876874218, 0.09422127638132342, 0.11520477702781079, 0.16763971097046332, 0.053005171489090695, 10.687320251618663, 40.070725794761415, 66.44797094406621, 41.90408868174399, 70.3945892087875, 78.70657797782653, 83.88191007798719, 72.2353575306554, 74.64511271445983, 74.59975442578717, 73.26679968064832, 75.99948360073951, 77.98807820966168, 72.2677484635384, 75.5498230841852, 71.91317404470136, 75.66306191105997, 72.93868557099374, 74.01115571298908, 69.57476677433138, 72.06904119060886, 72.31523267684445, 72.20317840576172, 68.3697989679152, 69.9381822155368, 67.03038015673238, 66.36691124208512, 63.56460132906514, 61.10962513954409, 57.76316873488888, 59.29262638092042, 57.27449632460072, 60.26731967926026, 57.57596969604493, 57.19222853260656, 54.84736896330311, 57.89461128173336, 58.169922444128225, 55.880340837663226, 56.26166582107545, 57.700614775380785, 58.00790502179054, 56.6648619405685, 54.53561505963726, 56.46310306364491, 60.986627455680605, 70.69388958715624, 67.1099336685673, 72.90795772306382, 68.43116837163126, 71.90592550462293, 70.68522899381577, 54.4843771380763, 68.2617376696679, 73.53300309950306, 76.96391597870858, 72.84854165969357, 74.88728769363897, 65.70966320653116, 63.53780761841805, 66.26933836167859, 66.20192850789716, 65.92468753937753, 68.75718793561383, 64.65866411885908, 62.92552955688969, 66.49534533100744, 58.333673554082075, 54.00909177718624, 52.93922216661515, 52.91609979444935, 53.582459495913604, 54.06667609368601, 54.50782898933657, 49.330265060547866, 50.42339432624079, 50.222353243058734, 51.871329430610906, 48.96011490975657, 51.367881451883626, 50.34803382812008, 50.29477588592037, 51.41228268223425, 52.62869988718341, 51.39223937065371, 53.48703999673167, 55.39561825413858, 55.70216717258577, 58.154001543598795, 59.81564698680755, 58.4312621239693, 56.343557065533055, 56.78131711098456, 59.633166559280895, 59.96463821780298, 59.20109395057925, 62.952872399360906, 63.43786170405727, 65.45980822655463, 67.5507531627532, 62.13558773840628, 62.82688979179629, 64.44808383141795, 61.75938144806893, 69.9089527130127, 67.72420037177302, 74.65294176532377, 59.10820438015846, 55.86816187827818, 85.30967635493126, 53.06634226152974, 32.30128711269748, 6.8816023488198566, 1.9901293588261453, 0.9448496384486076, 0.5647732557788973, 1.8040247838343344, 0.17691820018714477, 0.036102824228545355, 0.025198114209718285, 0.14607772201059327, 0.07456986473933344, 1.8639392333645977, 0.8933717781497587, 0.1792989563076727, 0.07138964990454336, 0.43904906499289703, 14.977104721530793, 21.769948736313854, 20.98350174965397, 27.465520481909476, 31.710984130059522, 38.07385890714584, 8.075704699562442, 1.2844546379581576, 7.058162448867676, 53.35620933963407, 63.477826733742994, 84.21081650641658, 53.21571004006171, 63.90829509304416, 41.26347541809082, 61.031573895485174, 35.75155688870338, 108.42489411753994, 105.1482480572116, 86.72865652268933, 37.70073167739376, 50.70571868650375, 47.788510784026116, 25.245011814178962, 44.65884377879482, 55.661409824125236, 88.38123736842986, 91.03914522355603, 101.76181485576015, 65.34943272990566, 61.348622998883656, 78.85413754370906, 77.12472531103319, 32.852737057593565, 56.45017100918678, 10.961456664146917, 0.6699273422841103, 0.6159759372953446, 0.2635204870133631, 0.2264068519035655, 0.11642362291534102, 0.18438427859256346, 0.1652954053133726, 0.13926027492890436, 0.2204890525148761, 0.2591576469281028, 0.27714692356605686, 0.2279506722885755, 0.2575200573811608, 12.313953638076784, 42.75673743217222, 67.95995050860991, 55.01426973650533, 72.39956363554924, 81.79957866668701, 86.74921758713262, 78.18489490016815, 79.7336898311492, 77.04674859200755, 79.40286928607573, 80.40970248560753, 81.87782995162472, 78.56021865721672, 81.82915333778628, 77.50084923159692, 78.54677277226602, 76.87519981015113, 77.48719153865692, 70.83001936635664, 73.22676797066966, 75.48899496755293, 76.53150604617211, 73.58641009176932, 74.41959996377268, 72.50764846801758, 70.5625686337871, 68.2008703293339, 64.2056264415864, 62.71731838103264, 63.33666847598169, 59.44009573228898, 63.145398016898866, 62.06261596372051, 60.35101521399714, 56.8986391252087, 60.531954150046076, 61.41212617197345, 58.99585200894264, 59.107827832621915, 59.933663260552194, 63.54513068352977, 60.70424033749489, 56.57778532274308, 59.95851932033416, 66.37382245832875, 71.27393753297868, 68.23188058791622, 73.37178584068053, 74.23451900482178, 73.67322783316337, 73.7394452864124, 56.64724657612463, 70.3126665853685, 78.06290134306877, 79.78437469851586, 74.88553047180176, 79.12761303686327, 68.00727782710906, 66.4150151898784, 72.30527770134711, 71.13266944885254, 71.92487839729556, 71.48980909778227, 68.33505461292883, 67.54441461255475, 66.42998295445597, 64.10239358102122, 58.15294250365227, 55.711243537164506, 56.93670572773103, 57.2446313981087, 57.57352605942757, 59.56354056635211, 52.1894101173647, 53.200561846456225, 53.5227963232225, 54.95969387792773, 51.38011140208091, 52.813922051460516, 53.29719728039157, 54.3887262190542, 55.73066711425782, 55.24075131262503, 52.88938060883553, 55.20304949052873, 57.56008801921722, 59.66987994409377, 60.08531385852445, 63.080953474967714, 60.01176157305318, 59.699893920652336, 61.218121820880526, 62.82968644172915, 62.70158183190131, 62.1340540916689, 65.34383550766977, 65.68362259095716, 69.56867925582394, 70.66970425267374, 65.16109620371174, 64.74066126731135, 65.29777119236608, 65.07222706271757, 73.7403944999941, 71.11708194978776, 78.79991469844695, 60.686777945487734, 60.82359806183846, 83.65254555979084, 62.53029977121661, 45.232521795457416, 13.828988728984712, 5.5109467621772525, 2.943562552813561, 5.442356765270234, 4.598852040306214, 0.18729075489024963, 0.21971951719493638, 0.20157791163411834, 0.39880554702493454, 0.26601664661880464, 7.503568664673836, 1.7005227506160738, 0.49255595512447825, 0.49692133862164717, 0.8673824598231624, 20.62626208028486, 28.420060642303962, 39.065006548358554, 51.30549615429294, 41.99802552500079, 65.71045552530597, 12.671401193065028, 2.010907379369582, 8.448561776068903, 60.32532761173864, 72.58311487013295, 95.17406863550987, 61.430580923634196, 88.81491030416181, 79.54184670602122, 89.84832148398124, 50.151272050796024], [39.404130751086825, 55.85382561529837, 67.48623801815894, 15.914382530796914, 10.579223652039806, 3.277723731533174, 0.7952321152533255, 8.484337714410598, 27.509554970648985, 52.33930349349976, 53.47140935159499, 62.33597378576956, 52.77679681777955, 50.47742889773462, 54.142193486613614, 19.932139842740952, 27.354533095513624, 34.96331737887475, 1.2369937137249978, 0.04824514162816829, 0.2279723985421081, 0.2712969229586663, 0.04718119105804832, 0.050567563983701894, 0.04995277076358757, 0.10510188527405263, 0.053161798165209835, 0.11540638838684368, 0.06060299403484791, 0.06755857443016383, 0.10473935714652462, 0.09495875858251127, 5.027558274807469, 45.66988960389168, 59.05040825566938, 46.03866300275249, 56.99826340521536, 81.92907179555586, 74.33601425540063, 70.03290745519823, 68.86341356462049, 73.41338649872812, 71.742127326227, 71.01686539188509, 71.89518605509113, 69.73483085632324, 68.04464232537055, 69.87198045176845, 71.04913080892256, 69.11975614486202, 69.6846245181176, 66.40155361544701, 70.70185984334638, 69.0511852695096, 68.12224249685964, 69.0285296593943, 67.09520909094041, 63.51673664585237, 65.09409035405805, 58.577648901170306, 54.529096080410866, 53.895484247515284, 54.28270455329649, 53.69902449269449, 54.621393372935636, 54.80292458688059, 54.63188179077641, 53.44668273002871, 52.290469984854425, 52.92569783426101, 52.34503799869169, 53.40749040726693, 57.5850695948447, 54.21676951069986, 53.59192809750957, 52.221530406705796, 53.35105534522764, 53.8481020158337, 61.61410862399686, 64.92342018312024, 73.1784914385888, 65.18541097640991, 69.40925844254033, 58.27001740855556, 60.8390365108367, 70.4473529323455, 65.42627196158132, 74.5112657546997, 71.05076251491424, 71.17689809491559, 65.75018129041119, 61.23209722580449, 63.29757029010404, 67.96094679063367, 60.07697882190828, 67.4746827156313, 61.543823672879135, 63.85353488306846, 61.134473354585715, 52.40611322464482, 49.61335036062425, 53.20488822075629, 49.223011770556056, 48.28420423692273, 49.19258986749957, 48.24403132161787, 47.98812020209528, 49.18440388094995, 46.42601666911956, 50.20788754186323, 47.04769272958079, 48.55602056749406, 46.17971927888932, 48.52492401676793, 48.43273262823782, 48.874136555579405, 48.721081749085464, 47.31321365602555, 50.31857682812599, 54.440654477765484, 52.67929454003611, 57.59199257819884, 56.309624641172356, 54.61723173818281, 55.226607245783654, 58.681395592228064, 58.433780285619925, 56.60364550928916, 56.454858241542695, 61.64210257991668, 59.309319988373794, 60.19268089725126, 61.51128761229977, 61.13435568348054, 56.75205622949908, 62.284194577124815, 65.25085180036484, 68.18642816235943, 67.65996763783117, 57.02625736113518, 59.080457533559496, 65.53205436275852, 42.69146919250489, 24.00843951009935, 8.886119819456532, 4.250948592539757, 4.791351672141783, 4.018936229328956, 1.0134652533358144, 0.30664562938674805, 0.20122770220041278, 0.060799296404565537, 0.0505708045356216, 0.4504380957974542, 1.3761762000860707, 0.5091191744131427, 0.1688019736039062, 0.08611816522334853, 0.14700618993130424, 11.667159699624586, 29.797177353212913, 22.406959302963752, 16.46561380355589, 23.693865422279607, 11.630455140144596, 4.7111039007863695, 0.8079158959369507, 10.334389305883839, 46.246246599381976, 64.64363751872894, 60.43025493621827, 43.36159829170474, 12.986355750791489, 3.6480749037957962, 13.253244603833846, 34.05000917373165, 52.149613749596384, 56.150851018967174, 68.25194743371779, 20.274652973298107, 14.688368266628636, 4.388210465831142, 2.9434630226704384, 11.326816620365268, 52.04234869249406, 71.02772251252206, 77.68662052769815, 71.08659728880852, 70.7553139040547, 66.09931930418938, 63.12012226350846, 25.801494160006126, 33.5787050185665, 38.92483280551049, 0.8920888566682417, 0.018645923156591675, 0.24761136891620777, 0.17500173931400623, 0.049543396359489816, 0.0329493343709938, 0.040542533576127984, 0.07904353476459942, 0.10005620037836414, 0.09842300817610757, 0.04934223699233225, 0.07117468563299026, 0.017221694842221278, 0.11686295901815738, 5.686348782431695, 50.58944394511562, 67.1126950171686, 53.606491857959384, 58.753779011387984, 88.1510099287956, 80.64410332710513, 72.70015839607485, 69.30880654242732, 77.61736715993574, 76.7703156317434, 76.7191836141771, 73.10181694646036, 74.72813360152706, 71.81809579172443, 73.55732179457142, 74.31743791026454, 74.4923677752095, 72.23694216820502, 70.47919473340436, 72.31906091013263, 72.98435764928018, 71.74721071797033, 71.84494833792411, 70.2775849065473, 69.55240141960883, 66.17629974119126, 64.1410485390694, 57.788930862180656, 57.848731317827784, 58.34568777391988, 57.714860823846635, 56.64139047745736, 58.37575274129068, 57.72654556458997, 55.65941333770753, 56.41769378416, 55.904447724742276, 55.387632308467744, 54.02250236080539, 60.33959327205535, 59.320941971194365, 57.58356340469853, 56.1195348155114, 56.246694134127715, 56.46679793634723, 64.16572416982343, 65.65618168923163, 71.2302266397784, 69.68333013596074, 70.29877355021816, 57.45174038794733, 67.72860127110636, 71.25227820488715, 70.99061689069195, 74.44682121276855, 73.81561771515878, 74.6062655602732, 71.254255079454, 63.834225054710146, 69.24895901833811, 69.46379507741621, 63.58397783771638, 67.85940447161275, 64.11386651377525, 64.79734736104166, 61.65058274422923, 55.04468771719164, 54.45129586804298, 55.59811453665457, 51.888070106506355, 52.531935015032374, 50.9106154595652, 50.22499692055487, 50.26805277793638, 50.22260035237959, 51.63158632093861, 52.358789828515825, 51.963179572936035, 51.359303228316776, 49.07693486059866, 52.503568433946185, 51.03659022238947, 52.57378278240081, 51.98402697040189, 51.22082394938315, 54.13469783721432, 59.41185858941848, 56.2292121302697, 60.136991085544715, 59.86745757441367, 59.15016197389173, 56.816869474226436, 61.041799514524406, 61.78845405578614, 60.411098080296675, 57.89723534737864, 63.97606188251127, 61.40531693735431, 63.662362483239946, 63.34825907984088, 66.54320609185004, 57.81581478734171, 65.01277569801577, 67.36411110047372, 71.40124982403171, 69.9057363694714, 57.931332511286584, 64.10940677888932, 66.94039314023911, 53.13124964314123, 41.29470140703263, 17.047358174477857, 10.009322877853148, 6.8626234704448335, 4.563217797586995, 4.311653644807877, 0.5478840814002099, 0.10566728880568858, 0.08699513671378936, 0.046565179758134394, 0.3366017203417517, 1.06737204136387, 0.3767819900906855, 0.011138538247905673, 0.07309570472927825, 0.2088168296482294, 14.349938323420865, 34.806006800743845, 23.54920448795442, 27.135027454745387, 33.538587016444055, 26.744779079191147, 6.076260814743658, 0.8609505081849714, 17.67856167208764, 58.80523266330842, 73.87704987679759, 74.39077838774651, 42.11464543496409, 1.9381412839697254, 2.2245808234137874, 0.8188258459971798, 33.70773138538484, 71.22871260489188, 78.15190776701897, 99.79674662313154, 27.447883544429658, 16.72047176668721, 5.955517022840439, 4.461180769628094, 23.79972823204533, 84.7997211640881, 85.4401736105642, 91.57303471719065, 83.35344129993071, 79.6098998285109, 74.52345648119527, 76.01761279567596, 35.37901409210698, 42.88267689366495, 51.92765466628536, 1.8157757145743219, 0.10620598651228413, 0.5847271495769101, 0.592407089087271, 0.24776363655203776, 0.12429552873776806, 0.08315335899110764, 0.18837400321518222, 0.28880405450059526, 0.34868666541672527, 0.2715522140985535, 0.2735636239090274, 0.23278802723413516, 0.3062964158673441, 7.340431895948226, 52.327979610812285, 68.579802666941, 61.4976965996527, 66.69482138849074, 89.89113807678224, 82.1947103931058, 75.94635117438533, 73.54641760549238, 84.72691412894957, 80.33221998522359, 81.59734910534274, 77.93274141127064, 79.18452662806358, 75.40213015771683, 79.0293655087871, 76.00717144627725, 74.00197736678585, 74.7851570190922, 74.48638223832654, 77.37632182336624, 75.80010168014034, 75.48557466076267, 77.29340291792347, 73.10338589452928, 72.6365218623992, 70.28150727671962, 68.73940390925254, 59.20720892567789, 61.494464566630704, 59.68900149868381, 60.69648188929404, 60.060257757863695, 63.11278350891606, 63.38726312883439, 59.53963764252202, 59.16274101503434, 59.5926014069588, 57.83568551463466, 60.53809265936575, 65.21551908985262, 64.98575448989868, 61.66040043677054, 60.356847778443374, 58.14030854932724, 60.734219012721894, 64.88602822826755, 69.05209525938957, 73.83786539877616, 69.89405555109825, 72.86204245782667, 73.096710020496, 68.077817732288, 74.94469550348099, 72.43863044246551, 81.332534205529, 77.13273479092506, 75.7534646987915, 72.8642782088249, 66.4923329507151, 66.9822605194584, 69.67900768403085, 67.61719811347224, 71.11433629066714, 67.55333408232659, 68.10795722469207, 66.90294234983384, 56.75680621977776, 56.95699614863242, 61.437272487148164, 56.631961099563114, 56.21165952374859, 55.12080915512578, 53.701373992427705, 53.465812129359094, 52.88002575597456, 52.80207649354012, 58.23674002001363, 54.61956162606516, 54.31859031800301, 51.94314802846601, 55.423529840284786, 54.365933325982866, 55.397363708865264, 54.05875682830811, 55.514885763968195, 57.69088337498327, 63.15488230797553, 58.386052885363185, 64.45800742795392, 61.51078162654754, 62.80810948341124, 60.85478482707855, 66.05775002510318, 65.13356900984242, 64.07229331231886, 62.59924719410559, 68.09415832642587, 66.97062676952731, 65.46813149606028, 66.51086222740912, 66.38900987563595, 58.32856662811772, 65.47740397914764, 73.167524491587, 74.81176637834119, 72.83996735849689, 59.956891536712654, 62.2664576192056, 74.16488908952283, 60.92476775569301, 53.779440925967315, 30.54471835013359, 17.844779952879875, 13.084798416783734, 6.1087478456958655, 6.5746347173567745, 0.8757950858243051, 0.4972552303825656, 0.17975168362740548, 0.14910689495023222, 1.9382679029818506, 4.88888091618015, 1.7930817387757765, 0.33386047388757434, 0.25200854506223436, 0.4096247616314119, 19.195479500678278, 48.52218228001749, 46.323070141576956, 41.52396002123433, 50.37800858097692, 50.9129531921879, 9.913042418418392, 1.196098959734363, 20.1276994136072, 69.41399666570848, 86.34603715712025, 83.03951832555956, 66.63000029902305, 17.221564362126013, 4.811051286035969, 27.97454214865162, 89.26063276106312], [48.44342108695738, 34.03120925349574, 59.28911193724602, 19.066270743646932, 0.5167267952234514, 0.1940136820438408, 0.1944046779986351, 5.0323631782685565, 39.417466809672696, 56.42552283502395, 62.556858139653365, 70.27611794010286, 75.98655546865156, 55.611956580992675, 48.47561590133175, 19.809973701353996, 33.937472451117735, 22.907402746139034, 0.22651585089343212, 0.04324538370354041, 0.11896896536552137, 0.15788466909960394, 0.08210961782043019, 0.0777912951044498, 0.03195386631564508, 0.03445117313775324, 0.012480625657424813, 0.10070801096697969, 0.028927357446762825, 0.052189119310388644, 0.08503171465089245, 0.11048534599643563, 4.30602063094416, 48.73530426333028, 61.12774648974019, 57.48214267915296, 39.390406377853886, 82.53990250249063, 72.96973505327779, 67.48796386103477, 65.81775588373985, 72.5215022794662, 77.39413722868889, 70.40812923062232, 70.2755609635384, 74.07131702669206, 68.73558352070471, 68.48505389305853, 71.38240675772391, 72.2476267045544, 71.60831174542828, 66.76136047609391, 69.949431573191, 72.13052042068975, 70.33239610733526, 70.73735729340585, 67.16461150876938, 65.01276785327543, 63.091877275897616, 57.30338065854965, 54.75971183469219, 55.02302838910011, 56.896603415089274, 54.22235888819541, 52.84102562935122, 51.85739717175884, 53.468538176628854, 52.06718514042517, 54.16092280418643, 55.06238545140913, 53.385725175180745, 52.024101826452444, 53.78196300998811, 55.27593105070053, 54.047095621785815, 52.091456767051454, 56.06148373696112, 53.404607465190274, 58.832669642663774, 59.61779086820541, 65.80534158214446, 72.96838575793852, 61.64554642092798, 47.172569228756814, 69.55454303372291, 70.86195530429964, 69.45446768114644, 67.76890754699707, 67.64567452092325, 69.1984781142204, 71.86663120023667, 61.284645219003, 76.51423977267358, 74.46097312435028, 62.83063173294068, 67.66843211266303, 64.01058658476799, 64.36882841971614, 55.52704903387255, 51.353796220594845, 50.76982982697026, 48.770252581565614, 48.01502766147737, 47.40460488104051, 47.28492552234281, 46.57743584725165, 47.588085512961115, 49.141810863248764, 48.030615160542155, 46.92680920324018, 48.86780192775112, 45.381391432977495, 48.58238673979237, 48.22545105411161, 48.2940689979061, 48.72984824642059, 47.78017966978012, 48.669094654821585, 52.982289791107185, 56.326871302820024, 54.15889101643717, 59.56471727740381, 59.65677530534806, 57.43141466571439, 56.653424309146025, 57.60236724730461, 59.65739111746512, 60.35184675647367, 56.422659504798155, 56.318418595098684, 56.08716741684945, 62.18406038899576, 63.149622409574455, 62.143777647326075, 61.18575442221857, 64.25896283118956, 62.63182640075684, 68.6082241612096, 64.21255726968089, 50.62082290649415, 55.41408869528002, 45.851126640073716, 43.39269092006069, 30.45828696220152, 12.233595059764001, 12.683332062536671, 11.599520387188083, 4.2691871235447545, 0.1400743965660372, 0.6714088337556009, 0.11464118912455537, 0.06216252688318492, 0.005385353438360918, 0.09702960149415078, 0.7242547432261129, 0.8266188600851644, 0.026740777801962632, 0.07229460658685816, 0.1081842553591536, 10.72639000031256, 25.72238975955594, 23.004793236332556, 14.884007265490872, 20.12572842259561, 4.09201537889819, 3.2007163282363646, 0.4952714610243998, 17.470393642302483, 59.81003407509097, 60.33993059589017, 79.75287022129183, 16.770432956757084, 1.348811784578908, 0.07874628498909936, 1.2055190219994516, 2.836271510008843, 56.9511478947055, 45.950378294914, 70.13444977421915, 21.823675401749153, 0.6265200650499714, 0.32535092244225167, 0.7344808525616123, 14.381628132635548, 66.30193325781053, 78.1444081952495, 80.58092178836947, 75.83974115310177, 88.54183489276518, 63.59488987153577, 53.86057907535184, 24.782072113406276, 40.67386865615845, 24.1900570161881, 0.13005042719023843, 0.07112937919314831, 0.22567831760933324, 0.1309497224827928, 0.0742057737924399, 0.12594097068593388, 0.019855095268858057, 0.04166706637930005, 0.04459741780714643, 0.049624088400554274, 0.09228238445376197, 0.12579850897553468, 0.085564544123988, 0.12025382504948687, 5.301951112285738, 53.05139803117322, 67.02378273010254, 63.944369131518954, 44.74543402271886, 82.85255462892594, 78.3138075182515, 70.28291932998165, 72.5012706941174, 76.65273081871771, 82.76214399645406, 76.36461704008042, 76.29650115966797, 75.22271310129474, 72.69440820140224, 72.67350196838379, 73.54938291734265, 75.98465704148816, 71.300782234438, 70.86554035063713, 76.21379406221452, 76.2632159263857, 74.76492543374339, 73.67056062144619, 70.58325521407589, 68.34170695274108, 64.72101803748839, 59.853274283870576, 57.66652153384302, 56.90042772600728, 58.412473970843905, 56.08664181924636, 56.05298396079771, 56.34608307192403, 55.74758429681101, 55.07133237777218, 56.647277955086004, 58.22460812907065, 55.09108935633014, 53.56744858526415, 55.32941256800006, 58.61357781194872, 58.13580959073959, 56.59875431368428, 58.355368183505156, 57.607548698302246, 60.57901474737353, 61.2215970408532, 65.47984369339483, 77.24875850062217, 61.83116866696266, 51.51420547116188, 70.40639554300617, 71.24997185122582, 74.90401268005371, 70.42314406364196, 69.71222231465002, 72.94291388603949, 70.44510933660692, 60.27953786234702, 67.04851719640916, 73.3131620960851, 65.94651945175664, 68.89444735742384, 66.82923316955566, 67.52850547913583, 56.31213888045281, 54.684578834041474, 52.16119258634506, 53.48193699313749, 51.9093724989122, 51.71760782118767, 48.35186904476535, 49.9712509493674, 48.6695182708002, 52.08558890127367, 50.803640657855624, 50.60372529491302, 51.070369674313454, 48.96754387886294, 48.671146054421705, 51.55005985690702, 52.36612858310823, 51.30109133258943, 50.12825950499504, 52.61265739317864, 55.48867256410661, 59.066211485093646, 58.60689801554526, 61.80327277029715, 64.11991873095113, 59.74700943116219, 60.57471582966467, 62.87813948046777, 64.01839602378108, 63.816221375619214, 60.054138860394886, 59.99469534043343, 57.99352561273883, 64.02872362444478, 66.24960883971184, 63.48032920591293, 63.71717760639807, 65.52919887727307, 64.36793411931684, 69.06721991877403, 64.49756453114172, 53.187833755247055, 59.86914419358777, 50.62227810582807, 50.65757943737892, 39.77456331253052, 24.558102815381943, 17.327156528349846, 15.289502874497446, 7.227888309186505, 1.5757927274511707, 1.1375241221920138, 0.09488806398885866, 0.062182065955693686, 0.09498147308946618, 0.1266478476745467, 0.4546807213656364, 0.2740100080207471, 0.03147605153161191, 0.09836405004945495, 0.09212496104620158, 13.891736845816336, 28.266799911375973, 30.679467455033336, 30.269944552452337, 32.26696441250463, 14.586216999638467, 4.454422525821194, 0.8533485870688193, 23.868571712124734, 68.337721824646, 69.28788461992818, 95.85431744975429, 21.754826038114487, 1.5858088674083834, 0.02174417041392336, 0.9139062440203083, 3.1186762788603386, 120.43744302565052, 63.47435151377032, 88.89957858670144, 29.50109135720038, 1.03676799324251, 0.45507528729015784, 1.398081534331845, 13.193645169658046, 93.8387369340466, 76.83992985756167, 100.78749810495685, 90.15601573451873, 97.80582212632703, 75.05058380865282, 73.09881241090837, 33.764268429048606, 49.45696153948384, 33.4037123956988, 0.4151268051035943, 0.25027729360566986, 0.4740814077517679, 0.4540515486751834, 0.22790067739063696, 0.12418636886943733, 0.13022469687125376, 0.20152384114842262, 0.13698231248605636, 0.12684720673508224, 0.24437123068398048, 0.27011334775916995, 0.25063870324482845, 0.23605130132167573, 5.915830971733217, 54.97846634157243, 74.6023275006202, 67.15597444964995, 57.05240780307401, 84.97800857790055, 79.98403118502709, 69.82555527840891, 73.94875080354753, 79.78985817201676, 88.98045001491424, 78.87163915941792, 82.3146172492735, 80.11240251602666, 77.46503799192368, 72.56534653325235, 78.33916171904534, 80.41619008587253, 76.42097365471625, 72.53693288372409, 76.76650308793592, 76.31513241798648, 77.92901515960693, 75.30432977984029, 72.62553138117637, 70.69623516451928, 69.91704848504835, 63.78759591810165, 61.83484392781412, 61.68304035740515, 64.12925004959106, 60.301420765538374, 61.26539814856745, 59.210837118087284, 61.524823711764434, 58.10580738129155, 60.51311892847861, 61.77892269626741, 59.377122079172445, 55.65609109017157, 59.54014755064442, 60.31932246300482, 61.22406813406176, 60.456166113576586, 63.12588422529159, 60.33070910361506, 62.72806567530479, 62.0665697128542, 68.92400633904242, 77.822828754302, 69.12670658480737, 55.41646957397462, 71.09019017988636, 77.43234111416724, 77.13388796775573, 73.20505372939571, 72.01296698662543, 77.01526764900454, 77.04513257549655, 62.8418497116335, 74.58909342365881, 84.20877687392696, 68.4141609745641, 75.42353845411732, 68.55080850662725, 71.67583142557453, 59.813215117300714, 58.38064001452539, 54.45743437736265, 59.19139000677294, 56.8643105414606, 54.752914367183564, 51.922371233663256, 50.15260173428444, 51.44651320672805, 55.62795592892555, 53.206213981874534, 54.009939009143466, 57.5518588865957, 50.24351835250855, 50.77509364774151, 52.88329701269827, 54.856653213500984, 54.05089639848279, 53.35178882844987, 54.66177025148946, 61.53998367248043, 62.94154067193309, 59.18649881116806, 63.88277615270307, 65.74394864420738, 60.703628447748, 64.94826055342152, 64.69259262084961, 66.56177459224578, 68.27326159323415, 63.44222730205905, 65.59793056980257, 62.692493700212054, 68.69557534494709, 68.54573295962426, 64.31012622771725, 64.25288315742247, 68.7219415172454, 67.17428407361432, 73.67362007018059, 68.10250513015255, 56.75435866079023, 60.49550356403474, 61.16270265271587, 55.18652846736293, 52.4098708552699, 41.62330189058858, 32.48156709055747, 25.04799116042353, 6.836514703689083, 0.7628464530552588, 2.921898566907452, 0.5950104397150778, 0.1770807487229186, 0.32712643845908107, 0.6186151408380078, 2.8196818453650323, 2.234671365830206, 0.1528492804256178, 0.575314196607759, 0.3039893574051319, 17.146039124458067, 42.776537556802076, 38.14151979261829, 39.40368360088718, 47.58608118180306, 43.89050637522052, 6.088897710846317, 1.0998589497420097, 28.95068084039996, 85.0323647837485, 76.36842173914756, 104.05288696289064, 30.83848034181903, 1.789699675094697, 0.14043957535778323, 2.3617703780051205, 8.917832182299707], [5.9308163869765504, 30.072743469668975, 63.94290216507451, 6.816490513663139, 0.3332665412416381, 0.007986791240381859, 0.21498202947118591, 23.15514749096286, 56.38661684528474, 58.88098539844636, 70.78374324306365, 70.45693136030629, 64.73798228848365, 52.85967649952058, 54.39632385007797, 32.34628846568446, 38.0648962913021, 14.876488081870543, 0.13454546340771262, 0.08353272573121133, 0.08685852025425242, 0.3847868428114922, 0.05709693902322362, 0.04334695164054152, 0.13018199513035436, 0.032054128072735284, 0.03012145103345956, 0.09244032114023164, 0.10187027360042257, 0.03028990227668997, 0.030269564557520133, 0.04936534220412855, 3.1124188726948154, 34.43909260534471, 52.83849962296025, 58.489011180016306, 32.58824771450412, 69.58271349630049, 73.21082745828937, 68.7971882666311, 69.19927043299522, 73.4853070782077, 78.7042716241652, 76.34945315699424, 67.74108225299467, 70.04221131724697, 65.37436723709106, 71.20417425709387, 71.99114291898667, 72.33276567151471, 68.22141570429649, 68.83908702481177, 73.19545176721388, 73.42946037169426, 68.8807818197435, 71.45709653054514, 67.91828709263956, 64.51945135670324, 57.992709759742986, 59.73429310706354, 53.849153211039884, 53.90916939704649, 53.303002388246604, 53.68665725954118, 53.92298790716357, 53.10324392011089, 50.00896061620405, 54.36640793277372, 52.52631033620527, 55.649807453155525, 52.00097945428664, 51.782566193611395, 52.11061754534322, 55.75977894567675, 57.93872225669123, 50.364299897224676, 53.23978947054956, 55.94282419450822, 58.699740517523985, 63.4028898516009, 57.99489451992897, 71.94554928810366, 59.60596884450605, 60.008058855610514, 70.16385970577117, 64.09220718568372, 70.5070278721471, 68.51709965736636, 69.07708075738722, 68.91128217020344, 62.25474934424124, 59.855568870421386, 50.17316279872772, 57.852528172154585, 65.45307743933894, 63.76320269800002, 59.785868352459325, 54.26762696235411, 54.1762004360076, 52.33339248165008, 50.89026228074105, 49.06793302105319, 50.53734310211674, 46.325925627062404, 46.61627123432775, 47.756241444618475, 48.78640882430538, 49.689452186707534, 50.21982723666776, 47.925730982134425, 47.27995195696431, 48.13591511018815, 47.21901793633738, 49.71420234249484, 51.07216219748221, 51.86097045098582, 48.158300076761556, 47.19220461383943, 51.769175221843106, 57.59790359004852, 56.98489596766811, 63.21463569518059, 59.00903117272162, 59.23039013339628, 56.4457191190412, 58.43866755885463, 60.461622130486276, 63.243739681859175, 58.456114261381096, 59.583552498971265, 58.636555056418146, 58.477138165504705, 60.51962221822431, 62.08598544520717, 66.62442268863802, 62.413091505727465, 58.811026004052934, 59.618728314676595, 58.1836272055103, 44.69172108557917, 52.86448924772201, 36.48336918123307, 40.72379258371169, 30.89504876444417, 40.65387241301998, 21.174595702079035, 11.546965529841762, 4.444916661708586, 0.6394027834457736, 0.25546107351058917, 0.24202029070546552, 0.04785111962607311, 0.028422241204328118, 0.04346784797587222, 0.0909051422270075, 0.09119420252259701, 0.035308777925468264, 0.0849014490602478, 0.061194574790856535, 10.117127260854168, 15.934799448136362, 16.489163714070475, 12.73475335490319, 18.340657757174586, 7.29433375020181, 2.5803893179662767, 0.5123605537078073, 18.058841343848936, 61.09534378974669, 55.42302777690273, 83.652435733426, 18.51418145241276, 2.645340826242201, 0.15015026073782675, 1.2826927583063803, 0.5247905141403598, 2.1348968100163246, 35.41204829369822, 59.60058343025946, 3.8796629155835802, 0.3997406339453113, 0.2103475652514927, 1.335064367421212, 50.64098388917985, 82.60109147717877, 79.03006369067778, 81.00351010599445, 80.91626874862179, 77.83481551754859, 64.73106322749969, 71.48335287647863, 37.52506832922659, 42.810717090483635, 18.40137996981221, 0.18144331301652616, 0.12941650475465483, 0.3613116411912826, 0.25902799420779754, 0.12258922110401815, 0.029915957523870374, 0.09336657506684143, 0.08797792026833182, 0.0944854005149776, 0.07842540906201448, 0.05310824478886301, 0.04413884140611176, 0.06017118091544798, 0.11462831118654822, 3.598554244925899, 39.53334146930326, 60.40611274780766, 65.19608766801896, 43.64011010816021, 70.20254212041056, 77.44408469046317, 70.44707836643343, 75.39122596863778, 77.07504457043063, 80.12967663426554, 79.799742544851, 71.82976876535724, 73.72359891091624, 70.35804056352185, 75.75263315631499, 73.81409583553192, 76.71228808741417, 71.23096404537078, 73.25649169183546, 76.17737877753474, 77.8233386624244, 71.93874789822486, 75.0793347820159, 72.07615637010144, 66.3256557526127, 62.42950270252844, 61.191681123548946, 60.01361293177451, 57.02466487884522, 55.63918567472889, 56.46910821237872, 56.0732469251079, 56.26756506581461, 55.526637185004454, 57.25639458625548, 56.21767643959292, 57.111149218774614, 53.50873070378458, 55.11703975739018, 53.20210333793394, 56.25911628046344, 58.802663510845555, 55.37124072351764, 56.235911538524014, 58.40896737190985, 61.102007896669456, 63.39852425359911, 58.92968162413567, 73.51691353705623, 65.47885917848157, 66.85781940337151, 71.26717536680161, 68.65786567811044, 71.72673594567084, 69.94360293111494, 70.83733066435784, 69.76421725365424, 65.11844827282813, 63.36691779475059, 53.13841581344605, 66.05389825759396, 67.46089950684579, 66.17444053772958, 59.158257745927386, 58.38104794102331, 60.301083441703554, 55.426350024438676, 57.16872176816387, 53.44881257703228, 52.94734931761219, 48.97379221454744, 48.43397209721227, 50.391348561932965, 51.03431524768953, 52.81001537076889, 51.26953586455315, 50.546662653646166, 50.517805776288434, 50.775650624305975, 49.39529795800486, 50.712088615663596, 52.24489596582229, 53.16748057642291, 50.626161252298665, 51.63203347113825, 55.084943002270116, 61.07010333768783, 61.966141346962225, 64.32125791426628, 63.58628811374788, 63.48934673493909, 59.23091965336954, 61.07777941611506, 62.501678236069225, 66.11774659925892, 62.18045965317757, 61.59141771255001, 62.51319039252497, 61.23984782926498, 62.86771774291993, 66.19891612760483, 69.12266654352989, 63.37924972657235, 62.1989457837997, 63.070876905995036, 61.20739021608907, 50.771120286756954, 55.32109714323475, 46.803501652133086, 48.20629812056019, 47.075808278975956, 54.10657836544899, 35.0162576090905, 17.43406072739632, 5.894910520122898, 1.1134331697417845, 0.8440768394258715, 0.4395443255141859, 0.014700046533929005, 0.030251724284983454, 0.11252745295003538, 0.11749030841935067, 0.35447871913352325, 0.011505870704328822, 0.2077826875592432, 0.058144437855169664, 12.979928947264149, 18.244069391681304, 26.362389172277144, 26.199883414853005, 34.9252821553138, 16.24049230929344, 3.2845395851519803, 0.9559433883236301, 20.2752629018599, 65.73385246338384, 62.22830864690966, 94.99203928055303, 44.67855761128087, 4.833651982968854, 0.4873399688832222, 1.0970108187006367, 0.3450004648297064, 20.088454138848093, 87.9491255360265, 109.78418365601571, 12.369152172919243, 0.5131108908643646, 0.29286591396216427, 0.5238703506127481, 64.88691860629667, 91.31741385306083, 90.3335657427388, 95.55313433370283, 92.41126091249528, 91.31913969593664, 78.77846717834473, 72.56758228425058, 44.872863984877064, 57.19640977921025, 22.55310877676933, 0.29112533155468207, 0.3035084993368195, 0.7506598940780087, 1.2078924236759063, 0.37799412504799906, 0.29099203225585724, 0.36056066052086894, 0.18623819604756373, 0.22210045717656615, 0.2685144916176796, 0.3617412020121852, 0.14521892212571638, 0.13640376288563977, 0.4040032390865588, 4.635468836753599, 42.46572894434775, 70.01279354095459, 70.45484465937461, 56.074866863989065, 72.38750626963954, 79.60382799948417, 71.60728408444312, 78.30587648576306, 78.98719218469436, 87.75431709904825, 83.66627385539394, 76.92169558617377, 76.57382842033141, 73.01325767270981, 77.63970898043725, 77.41405502442392, 80.53839545096122, 75.8806122502973, 74.905134477923, 80.5794862008864, 80.46001080543765, 74.51188548918694, 77.79132427707796, 77.05606814353698, 71.5111703257407, 65.61454965222266, 66.29435523863762, 63.8650901855961, 61.97050302259384, 60.399028947276456, 60.09975994786909, 61.445399638145204, 60.17936052814607, 57.373504792490316, 61.87220058133526, 58.34999061399891, 62.97726561946254, 59.228613299708215, 55.911970830732784, 57.0799389193135, 61.37526765946419, 63.875053005833784, 56.90878237447431, 58.12510936490951, 61.6654916732542, 65.65222794009794, 65.45823143374535, 59.09158922010853, 76.01402774933847, 65.16485383433681, 67.67247215394052, 75.68127739814021, 67.79132781490203, 76.05267094027612, 73.8789326144803, 75.57363187113117, 74.15584410390547, 68.02941568436162, 61.54980136502174, 62.07450859008297, 68.38099341238699, 70.6699788185858, 69.58302728591427, 63.17532570131364, 60.95970038444766, 60.66900568623697, 58.15477425052274, 60.51333465883809, 56.32887171160791, 60.91973143239176, 50.065376066392474, 51.22628781103319, 51.91126308133526, 52.59320635949412, 56.655950315537, 56.96147157299904, 54.11518404560705, 53.024012042630105, 54.49685027522426, 53.21294476909023, 55.34253289622646, 55.258731457494925, 55.58932450509841, 54.423392126637125, 55.76627046831193, 60.286872694569254, 65.09667519600161, 63.14945374765704, 67.9966325144614, 64.59747906654113, 66.18709410390547, 63.3646349753103, 63.74595603635235, 66.99809905021422, 70.44531329985588, 64.9607729142712, 65.56187614317864, 67.14285019905337, 64.51422675963371, 65.64205723424112, 69.2774824942312, 72.04622084094633, 66.9483712411696, 62.83480513480402, 66.16142611349782, 59.38875582910354, 57.04221356299616, 60.14101543734151, 57.496624069829146, 53.29332982340167, 56.80617317076653, 62.58373814244425, 48.69263672059583, 29.896205432953376, 10.17612559180106, 1.3309674517762278, 2.245073246379053, 0.7632162590180674, 0.20572376497570546, 0.10355995712621559, 0.1333062395813965, 0.22228848579670155, 0.5251378890487456, 0.15971931178242932, 0.6473118138890113, 0.1779721073445774, 17.172542579712406, 28.23870985738693, 30.492958753339707, 31.31574453846101, 47.61021944784349, 34.48869097617365, 4.091070577982934, 0.9094724335497426, 27.04821167453643, 84.18932976261263, 73.88375712979224, 109.84323886133011, 48.75087607291437, 6.829345591606633, 0.28802126585956545, 1.783501962500234, 0.7877454137609852], [0.1731217135825465, 2.139552418262728, 6.729723272785065, 0.051006720055856054, 0.11978420549102368, 0.4689735318383863, 21.70601606369019, 61.6830325126648, 63.28417539596558, 54.40484716046242, 89.39608004785354, 59.2884490566869, 63.89217022926577, 49.934235542051255, 50.455612674836196, 49.231111464961884, 35.604832787667554, 7.637604878794763, 0.34936149694746543, 0.0822505779984978, 0.1466679774344929, 0.04383015776834181, 0.10437397917191829, 0.06063942917652669, 0.05482460349617947, 0.19442740016646926, 0.11634479246793256, 0.059682439802394766, 0.19458326841554335, 0.03264729654596698, 0.07215974446866782, 0.11757309188044841, 2.104376602557398, 11.670640803152516, 33.318655798512125, 47.73642563050794, 35.30882327787338, 51.62571061042048, 75.37141799926758, 70.2167881688764, 74.45764695444416, 77.79372476762342, 71.56034900296119, 75.17136143099877, 67.82639380424254, 71.36406575479816, 70.90202623798002, 71.81001570916945, 68.68750310713246, 70.68032603110038, 71.02001113276329, 72.34630569334954, 75.05366679160826, 72.76715247861802, 73.84749873991936, 72.5012550046367, 67.76525189799648, 64.073662219509, 61.689378907603604, 59.149506938072946, 55.38177620980048, 52.85389884825676, 53.97109969969719, 53.899638037527765, 52.516288680415, 53.59922370603008, 53.599965033992646, 54.37477827072144, 51.864841830345895, 53.12852751824164, 50.986556468471406, 53.24762244378367, 53.35767630607852, 53.64699817472889, 52.06056417957429, 50.20200790897493, 55.239456930468165, 54.82013594719672, 58.57529547906692, 59.48618750418387, 56.293080083785526, 64.7122319283024, 64.44380060318979, 58.320082541435, 64.75813934879919, 71.62964943916568, 72.16153067927208, 67.84053787108391, 69.3365220100649, 65.10515536031416, 72.69247839527746, 61.64918245807771, 50.84937549406483, 63.73471844580866, 69.8679796341927, 65.63111382146036, 53.696200386170425, 56.72014774814729, 56.81230383534586, 55.3793364955533, 51.51083615518386, 49.78438138961793, 48.405291726512296, 48.057126460536836, 48.26528664558165, 48.944182242116625, 51.18274950212049, 48.86930027315694, 44.4005282463566, 47.767757523444395, 46.94933145276962, 46.092572058400805, 47.31143289996732, 48.285682970477694, 48.0762872388286, 47.382223836837284, 49.952862877999586, 49.04001751253682, 48.93383895197223, 56.011222485573064, 62.85140852774344, 63.17035213593514, 64.4159870762979, 59.49269471629974, 59.60074424743653, 62.47355091956354, 60.77023813801428, 58.60584289796891, 62.51064869665331, 57.47337225944766, 53.86552518413913, 57.63676643371583, 58.6841530184592, 64.54087534258443, 69.27197548650926, 61.919394539248565, 63.12795523674258, 63.98446752179054, 70.23409366607666, 42.599077763095984, 44.76679917304747, 38.78869910393992, 42.441422016389915, 56.287698591909106, 73.75929247948432, 44.613477645381806, 13.823563110443855, 7.955719395991295, 2.1537680683597444, 0.283722409437741, 0.013307122487364518, 0.013318484528891504, 0.025396067498912735, 0.09058799714811387, 0.1428750148343463, 0.17383892509725787, 0.0044043318860443135, 0.11774802039707861, 0.02680632811520369, 8.793275356292725, 17.567386011923514, 19.371005565889423, 13.907888185593391, 18.95629140638536, 9.091512772344775, 1.0060716468480326, 0.6718671994824564, 5.731079491876788, 71.47028353906447, 43.319491647904925, 88.68213807382892, 54.27535795396375, 4.4795350105531755, 3.217502356536927, 0.19202451942668808, 0.05415716471390859, 0.447393233377126, 0.6936893059361366, 1.2266197800636292, 0.1735828219041709, 0.43824056644112835, 1.987446335054213, 47.54058168780419, 87.02088094526722, 80.2579616731213, 62.88534879684449, 90.63464687716578, 62.842390998717285, 72.36450549094909, 60.04314837917205, 56.05251719874721, 47.86405563354493, 43.141839658060384, 8.1029210455956, 0.23022557037972638, 0.031662120881880966, 0.16044734045863152, 0.09099998391203343, 0.05094311560594267, 0.07730840690313809, 0.0369186427504305, 0.051717668801786444, 0.0950492871925235, 0.030714380104214917, 0.13747383449827472, 0.055799052014105746, 0.020306589187032754, 0.04918070735349771, 2.3780474787758243, 13.710338011864694, 40.65658669317923, 54.23443586595597, 44.4473966475456, 53.81822924460135, 81.55499535222208, 71.89720999810004, 77.88712424616661, 83.11741659718176, 75.56188829483526, 76.70370594147714, 74.16364962054838, 74.32555721652123, 72.8560333867227, 74.135847860767, 73.72846264992991, 74.55732222526305, 73.31710800047844, 73.92263566294025, 78.8363927410495, 76.92986980561288, 76.05810734533495, 73.43643434586065, 71.36215948289441, 66.60299085801648, 64.65526342391968, 63.11772569533318, 57.4081353987417, 55.83811260038807, 57.865758326745805, 54.887549723348315, 55.45028040485998, 54.358798534639426, 57.0723726672511, 55.90982137187835, 54.9480640503668, 55.89839158519622, 54.32662725448609, 55.501569317233184, 54.80496029700003, 54.203837456241736, 53.67307016926428, 53.1270174057253, 57.295218206221065, 58.210213030538256, 61.75851068189068, 63.13678056963029, 56.221983202042125, 62.274741665009536, 60.970796769665135, 55.398481584364376, 62.777067845867535, 71.45624929858793, 75.46082450497535, 70.1945875537011, 74.60388860394879, 69.95048276839718, 72.58716275615078, 57.64725877392677, 52.40131616592408, 65.38605982257475, 71.38547405119866, 68.57733157373244, 57.729801131832986, 60.564278402636134, 58.29610509257163, 57.34087459502682, 52.38272805367747, 51.22110243766539, 49.794795282425426, 49.60900437447333, 51.59582214970743, 50.05876687265212, 53.49128792362829, 51.361107518596036, 48.299779968877, 49.56250075371035, 48.15500528581681, 50.4540398043971, 50.37545511799474, 49.60947898126418, 51.102262466184555, 50.43680490985994, 52.785163233357096, 52.95088337313745, 53.08414982211206, 59.703714309200166, 65.04913214714297, 64.97728609269666, 68.3338543676561, 62.22142880962741, 63.72268853649017, 61.80042905192222, 63.38726312883439, 63.75350659893405, 65.5817037243997, 59.46697965745003, 58.71815212311284, 61.900108245111284, 64.83356260484265, 65.97185011832946, 69.98723537691178, 66.49507076509538, 67.28098823178199, 69.02156352996826, 70.22722167353477, 48.9859397949711, 50.22662470417638, 47.37000173138034, 53.423505444680494, 69.343535207933, 71.82265358586466, 51.18321234180082, 23.5131912462173, 10.634163310450893, 3.5080266767932526, 0.427167960592816, 0.15503816216463043, 0.08768916640791201, 0.0218965012520071, 0.030786227660193562, 0.12045915193495252, 0.18893896241582211, 0.10574452579021455, 0.18593280275742854, 0.06735468778999583, 9.078236529904029, 21.222277995078795, 22.003759261100523, 26.600681004985688, 34.61985111236572, 21.592532088679654, 1.275608590052974, 0.5483915993282872, 4.751370462679095, 75.88419729663481, 51.78595904381045, 95.76323216961276, 75.14801548373315, 30.207723994408887, 3.881801833068171, 0.25630605316931204, 0.025248457677662376, 0.6415600870405475, 7.756365912575876, 14.366093585568091, 0.20150102705003756, 0.33229155646216485, 0.858226360813264, 43.155348300933845, 98.75527105023785, 82.79631568539529, 79.84430851474886, 109.2993865474578, 86.39895777548514, 86.7915399612919, 66.67725701485911, 66.33087250494188, 64.00433432671332, 52.62478928412161, 12.829852200323536, 0.3429071755418855, 0.24227567377590367, 0.36354969045327556, 0.8626708965147696, 0.1868597997893249, 0.4240181134833444, 0.2217059218955617, 0.21698092140497702, 0.1814383794102938, 0.269872673576878, 0.4349919859199755, 0.14357227741950943, 0.11862875337922767, 0.24071452448204642, 3.940740347869935, 28.293199423820745, 59.914478948039395, 66.37037861731746, 53.68604536979429, 63.84818477015342, 80.2757849231843, 73.98133785493913, 81.57492099269744, 87.84948164416899, 79.2516383817119, 81.31336950486707, 75.21269536787464, 78.35026987137334, 75.78244316962459, 78.5739077291181, 75.5054061643539, 77.78926111036732, 77.5850546744562, 77.95339661259806, 80.97157416805145, 80.18207165502733, 79.08035632102721, 76.26553012478736, 74.69185167743315, 71.52870332041095, 67.27262573857462, 65.48588414346018, 61.023438899747795, 59.811167640070764, 61.642381068198915, 61.47795531057543, 59.737517295345185, 59.080622273106734, 58.67036980967368, 60.55515496961532, 57.988916827786355, 58.575334702768636, 57.25760659863872, 59.857196654042895, 59.47995878035023, 58.03764835480721, 56.38300434235604, 56.23964563492806, 59.249684272273896, 60.34175057565013, 64.52636649531703, 65.6241359249238, 55.39894050167453, 67.07568353222263, 66.22964397553476, 60.17818381709438, 67.5382564913842, 77.99537381818219, 78.60264301300049, 72.24188435462214, 76.39882795272335, 73.09278765032369, 76.13333056049963, 62.405705682693, 52.58303957600748, 68.19780303585914, 75.73887348175049, 68.97604834648871, 57.63749991693805, 60.20827231868621, 62.83327148806665, 62.32857619562457, 57.62981207140031, 56.229416093518665, 53.06671488669611, 51.751830500941125, 54.96662862839238, 51.195826684274984, 56.22199496915264, 56.51478029066517, 50.903974886863466, 52.03511584189631, 49.55858622827838, 52.686754888103856, 54.035956090496434, 52.89788038499894, 52.466411821303836, 54.3108710935039, 56.670702349755075, 56.18603860178302, 53.9977208260567, 61.10041541437949, 65.68953360280683, 69.38800704094672, 71.81133362554735, 67.04243752264208, 64.67850738956083, 67.22346275083481, 66.42041237123551, 63.815629097723196, 66.51740474085655, 63.17077967428393, 60.7481316597231, 64.0891202803581, 63.88629059637747, 69.20473821701543, 72.8368922202818, 71.39459748421946, 66.3117862516834, 66.88513478925152, 72.74673261950093, 53.99615187798777, 56.704858349215606, 53.51958782442155, 54.27121593106178, 70.13584613800049, 75.83368501355572, 62.4566690383419, 42.49912400399485, 21.36828822474326, 4.933705272213106, 1.651713879358384, 0.15196454080362476, 0.09936012522948366, 0.11770020118884503, 0.27866831289664395, 0.3951034118090907, 0.24211839592504888, 0.12674941561154782, 0.7153639557861513, 0.47338745466643767, 12.827685090803332, 29.354892853767645, 33.446823166262725, 34.75522387412287, 44.675321655888716, 36.71171388318462, 2.1085379921620895, 1.1928820033227245, 11.98777815987987, 96.05194999325661, 59.39283901645292, 103.31275140085529, 86.90686548909834, 30.139017797285515, 3.7147147472827666, 0.3861484874881083, 0.16061365814699283], [0.1469943921772703, 0.12454946390202931, 0.5266872865538443, 0.116345910956302, 0.5246492475271225, 21.921356147335423, 58.381240137161754, 79.39322025545182, 48.68814560674852, 90.86266210002285, 54.71255317811043, 12.226485763826679, 47.72691780521024, 53.03275108337403, 21.024096319752356, 29.720871563880678, 36.91941515091927, 3.034887832980002, 0.07252552846987402, 0.04644647443426713, 0.048303230245026856, 0.2520638412886089, 0.10472061097501748, 0.017559426618860136, 0.08158307792919298, 0.0596893728981095, 0.02356046912140183, 0.01793188707632644, 0.12373940253089513, 0.13221212812969763, 0.07857122623752202, 0.08859603064915827, 0.16398298944677078, 0.9958207775508204, 11.472408137013836, 18.97424409466405, 38.46984178789201, 34.54137232995803, 77.03386752836167, 74.15652659631546, 78.98403859907582, 76.16543123798986, 70.41567587083387, 67.61333065648233, 71.46116010604366, 70.41617008947557, 72.07276744227256, 70.20732741202079, 75.48336244398548, 68.12921647102603, 71.3288507153911, 70.7496343120452, 75.21988115003033, 69.5762651197372, 73.18971726202196, 71.33393410713443, 69.02826293822258, 63.37240911299183, 64.69772700340518, 58.206129843188876, 53.617152860087735, 51.3112541937059, 53.799229283486646, 51.5110714973942, 54.01719147159208, 50.22260035237959, 53.69150530907416, 52.91679797634002, 52.50882048760691, 51.18492249519595, 52.61727010050128, 52.63022961155061, 53.63552916434504, 52.870153150250836, 49.47675774174352, 50.84913230711415, 52.29124661414854, 51.52566663680538, 58.52674830344416, 61.4002178561303, 54.883768558502204, 50.75406582124772, 47.216193829813314, 44.826148556124785, 49.75545783196726, 54.34365426340411, 61.633642027455, 69.15941915204449, 69.02412091532062, 71.26447677612305, 63.5074523956545, 47.926052616488555, 58.47628701117731, 60.25045740988947, 64.17531436489475, 63.539415790188706, 59.95047846148091, 56.913324479133856, 55.597075108558904, 49.57885311495874, 48.87945528953306, 46.06533904229441, 49.060492284836315, 48.85734488887172, 48.49379608708043, 45.997956645104196, 49.16975382835635, 46.56153455857308, 47.90254977441604, 47.85357898281467, 48.76564771898332, 46.873747379549094, 49.789433402399865, 49.258579823278616, 49.7362264510124, 48.32263169750091, 47.94528399744342, 47.341807734581735, 52.782456797938195, 57.848660715164684, 64.53794925443589, 61.00430165567706, 61.56505154025171, 58.83098302348968, 60.23434039085143, 57.60505799324282, 61.268845911948915, 62.53810136548935, 65.35430431365967, 54.24874074997441, 58.55779386335804, 59.450140922300285, 62.195286212428925, 61.249571384922156, 64.0788201362856, 61.736419893080196, 69.08408611051499, 69.8670147311303, 64.8428507774107, 39.94693186975295, 45.62209160097184, 48.38326369562457, 63.803665868697635, 75.49112089218633, 65.68357944488525, 47.20279501330468, 34.118462377978915, 18.75095925023479, 6.929174815454791, 0.3388556429455358, 0.042615743699453534, 0.08780015722638176, 0.025475976215074622, 0.12684919856368534, 0.03320367556185492, 0.07555878465814937, 0.15067542933167952, 0.05120602165979724, 0.14387287499923862, 5.358566603352947, 16.7533863359882, 17.61110474986415, 23.33197578307121, 31.58014366703649, 16.075506633327855, 0.41911312829582925, 0.22897225053560352, 0.2437593256153407, 51.919162734862304, 62.1561291909987, 51.46576812190395, 78.36228016884097, 52.029663747356786, 10.32549435092557, 0.9415072274784889, 0.0532910103849586, 0.1447345553747108, 0.16896504307946852, 0.1656683062713954, 0.22023495647215077, 1.3846928914708476, 44.23469435784125, 78.314160531567, 94.72843247075235, 67.66150520693871, 96.90974881572109, 52.42849034647788, 19.1499819678645, 61.684064096020116, 59.265409054294715, 27.705187105363418, 39.37451293391567, 43.369290059612645, 3.175289563594326, 0.016953271040092074, 0.06413799950913077, 0.05209259223192931, 0.05298173302904733, 0.09165762442975275, 0.05425278397817766, 0.13376858896545826, 0.057073002606029474, 0.03191632800735533, 0.12255635593206653, 0.0685114192686254, 0.11901149856707743, 0.05538425753794371, 0.06573628108467787, 0.3779594978738216, 1.4625659128350597, 9.889713141226, 26.81483849402397, 52.85725639712427, 41.56538809499433, 79.44968669645249, 78.45222011689218, 78.61339815201299, 81.8253407939788, 74.14020953639861, 72.12347584386026, 72.31992383157053, 71.80989019332394, 73.66146856738676, 74.20610535529353, 78.8290814430483, 73.4900531461162, 74.53338007773124, 74.3676285589895, 76.86131461974114, 74.22789804397091, 76.7895980035105, 72.52238873512515, 73.66006435886507, 66.83666213866204, 66.15154174066359, 60.46544644140429, 56.19200844918528, 55.46044718834662, 52.70772780141523, 55.59303898965159, 55.670474421593454, 53.52012911150533, 55.7231322411568, 56.921361415616936, 55.48483256370791, 52.615371673337876, 55.31142065601965, 55.995336886375185, 57.52140952694801, 52.641275005955855, 52.17826666370515, 51.63059003891484, 52.142529949065185, 51.368414894227065, 55.978274576125614, 62.03155471432594, 55.3993131268409, 51.40224533696329, 48.08186092684346, 48.342553415606105, 50.92469284611364, 55.56687678060224, 60.17150009832075, 68.20926420150265, 69.14157236776045, 74.70143010539394, 60.67583453270697, 54.2202486530427, 68.92019379523494, 67.67615918190249, 65.90572680196455, 60.7117477540047, 60.519065241659845, 57.03499247950893, 54.315122942770685, 52.99946585009175, 50.76299705813008, 48.077593388095984, 51.495707573429236, 50.05739796546198, 49.968462144174886, 48.27747737207721, 49.906080768954375, 50.30665674517232, 50.93478902693718, 51.35760876440233, 51.22817839345625, 49.39035184921757, 51.312313233652425, 50.405429870851584, 50.939491948773785, 52.3552793072116, 48.90169905078027, 50.61339001501761, 56.476176323429236, 62.191344230405754, 68.22101562253891, 64.16943080963628, 64.12268792429279, 59.697097270719475, 61.59115491374847, 58.9611311881773, 62.651308813402736, 64.5412636572315, 65.00396605460875, 56.477086313309215, 62.40524284301266, 61.21593706069454, 62.96778917312623, 64.25169860163044, 63.71392596152521, 62.1096844057883, 67.64799656406527, 73.87294707759735, 63.354362287829005, 47.5612525786123, 52.33738153211532, 58.12874147968908, 71.12070621982699, 74.212443905492, 66.47043828041323, 58.581269248839355, 46.409323061666186, 23.038174567684052, 7.693974731429932, 0.32047753072073387, 0.012836577877732775, 0.029113286985985698, 0.014906477543615527, 0.07311424405704584, 0.07694433127800304, 0.10383399443760996, 0.1051517959023195, 0.03181855795123885, 0.06339985464188842, 7.259603613807309, 20.71842405103868, 17.576032876968384, 34.11557159116192, 40.03762883524741, 23.492194798684892, 0.47961498340291364, 0.18923706254891812, 0.3222110344757957, 49.72217259868499, 69.18556567161315, 57.43934962057299, 90.3829562279486, 83.5049153912452, 27.368722269611975, 1.8274083613388001, 0.09432982337931473, 0.354507707900578, 0.4063333721170503, 0.5580034287225816, 0.252369832127325, 0.5735593036778512, 33.655273606700284, 96.89575379894626, 97.38475568832891, 84.1086309186874, 119.62954459651824, 96.41655783499442, 41.50896480006557, 80.9581361278411, 75.58642664263326, 45.52836264333418, 43.493907682357296, 53.43661792816655, 4.816379335618788, 0.2963810011504158, 0.24866089405071354, 0.2740158915760056, 0.7699406723822317, 0.3466762055552775, 0.1443365726980471, 0.2115176726252802, 0.15220654797890495, 0.10144657335214077, 0.18026094823595018, 0.3114711559347568, 0.29140942760052224, 0.2951813074609926, 0.2102473762727553, 0.49504951003097725, 9.960874742077245, 34.68271493911743, 54.211929305907226, 64.04223618968841, 54.99361845754809, 79.17872152020855, 79.16863318412535, 83.97493300899383, 86.52498352912166, 76.09544046463506, 75.74715752755442, 76.30224350960025, 75.38652696917134, 75.94453903936571, 80.48357640543293, 81.57697631466775, 75.72546682050152, 79.31938555932815, 77.21889357413016, 77.93209029782203, 75.54833258351972, 80.03319417276691, 76.0939734981906, 76.46227621263074, 67.65493915927026, 71.35775073882073, 64.91609319563835, 59.637355650624926, 58.07897836931291, 58.41724749534362, 58.90087573759018, 60.66084715627856, 57.74141919228339, 59.45496935998241, 60.40120978509227, 59.258454691979196, 55.33737890182003, 59.283914796767704, 57.22062649265413, 61.55841488992015, 58.05354964348578, 54.87461766889019, 53.56453818659629, 57.26524345336422, 57.44948110272808, 63.47565766303771, 64.10802218221849, 55.118742066044966, 51.23207330703736, 46.91093144878265, 45.48426343548683, 50.42720294767811, 57.60960794264271, 65.84705598892705, 74.80345879831623, 75.11658160917221, 74.3893349555231, 64.5854530795928, 55.846396646192, 69.80978735031621, 68.77604669140231, 68.84784175503638, 66.74085432483305, 61.40196331085698, 59.8546745700221, 60.12502001177881, 56.77843416890791, 55.00317727365802, 50.67494769250193, 54.24213155623406, 53.59198301069198, 54.649650127657004, 51.667605446230986, 55.445530414581306, 53.59582301109068, 53.58059637008175, 54.09156353242936, 52.63324591421312, 54.03961566186721, 55.312107070799804, 54.00359653657483, 54.673757014736054, 55.262524389451556, 53.78573240772371, 53.988138475725734, 58.18002646969211, 64.5684378377853, 70.50488625803303, 66.90098116474768, 67.65540984369093, 64.4297702850834, 63.29842928917178, 64.0520421151192, 66.12131595611572, 67.1448584525816, 69.78699837961506, 59.7584705968057, 63.8432425837363, 64.71183184654483, 67.27778757772138, 66.59454991740566, 67.8372117011778, 66.13757810285016, 71.83214572168166, 73.77031433966853, 63.693309983899525, 53.545695120288485, 56.09352557889877, 60.455130607851096, 72.43753217881726, 75.5405584458382, 71.63464653876521, 64.25115339217648, 56.72532919914492, 30.907098285613525, 11.741265039290152, 0.972377445188261, 0.08555024126244169, 0.18360383418058196, 0.13772246067322072, 0.1738830824052134, 0.21017852029012096, 0.2268269745212409, 0.2005546479936569, 0.2076851492447238, 0.2476964199975614, 11.111850142478945, 28.617087179614654, 32.93400856756395, 57.55067433080366, 61.33629106706189, 34.30996033453172, 0.35844717715536395, 0.1881277519128015, 0.26611216246120395, 81.46170570004372, 79.19144568904754, 76.79754472547963, 94.51005058903849, 94.22362342957528, 28.594584541936076, 1.5093357644734846, 0.17371642763816542], [0.23503163829445842, 0.05022836323346823, 0.15877340770056173, 0.41134573218803255, 16.723686149043424, 71.72433545512538, 80.85416978405368, 55.11109736657912, 88.0153351445352, 77.19269214137908, 6.232904589945271, 2.433063868553408, 47.90523659798407, 40.256995231874534, 26.192354425307244, 44.80549335479737, 30.532231484690023, 1.7795726056060486, 0.06239742476252779, 0.050774940154365, 0.035849252956048135, 0.03540869494299254, 0.06004662651027884, 0.048865002519901723, 0.10435435199929823, 0.024527860054325674, 0.029744869022960627, 0.03365548740651819, 0.09013628106444113, 0.08356802706276217, 0.011824772039788866, 0.0543132129936449, 0.11464218503885693, 0.31829390434488175, 4.971128606027173, 10.997772908979847, 29.61908409672399, 29.34186666242538, 68.4250965426045, 75.17759015483242, 71.43350739632884, 80.9185907917638, 70.8210292939217, 70.94641962359029, 67.80277329106485, 68.23830543025848, 66.13374202482163, 72.46834631889098, 69.81865190690564, 69.6974192896197, 71.67174431585497, 74.76551378926924, 72.64361350767075, 73.49644660949707, 74.1570992623606, 68.61842232365763, 66.87966700523131, 66.3504372873614, 63.32107313217656, 58.692197799682624, 50.92761108952185, 48.49203102050289, 50.42771285580051, 51.2029222519167, 49.84918286723476, 49.54120228367467, 51.09010704102055, 52.16425595744964, 50.38198586433165, 53.78648942516696, 55.81297805232387, 55.50442480271863, 54.70460253377115, 54.05328512191773, 52.85031380191926, 48.359097972992934, 46.18560675651797, 44.98683237260388, 43.24051472448534, 51.03090670800979, 55.3666554727862, 47.28443522607127, 53.88973013047249, 58.85337583480343, 61.14578939253285, 57.499652139602176, 54.05342240487376, 52.47770432502993, 59.59751613678471, 70.52755755762901, 61.60795834756667, 67.46046020138648, 69.51451132374426, 66.63406387452157, 59.74180444594353, 51.788751771373136, 60.32301733570715, 54.20493964226016, 48.21187180857505, 45.697856103220296, 44.980823301499896, 46.1837044069844, 43.04398436700144, 45.89701052634947, 46.11851853709067, 46.42236494248914, 46.25390698832851, 47.05098752052554, 47.58455145743586, 50.62379606308476, 47.857501352986986, 44.02481225229079, 45.31611534856981, 46.152188162649836, 46.614596382264175, 46.30499193745275, 47.687137126922615, 50.89804426316292, 55.07529397164622, 62.291199930252574, 61.635924846895286, 63.317119383042865, 61.856193388662035, 57.80949977136428, 60.49046724073349, 55.95427359304121, 59.69765816965411, 60.069067401270715, 62.63065361207532, 54.45928573608399, 58.67783800248177, 57.37239083936138, 58.61046737240207, 61.12531854260353, 62.030091670251664, 58.96950152612502, 62.306638379250806, 63.94471430009412, 59.306841050424886, 38.03922045615412, 50.87245079778856, 59.625059020134714, 67.07334579959993, 63.067311471508404, 59.2120255962495, 58.91659659724082, 37.0943489382344, 20.789664099293372, 2.0267711603833787, 0.13374859407063455, 0.04400834598908982, 0.016733129929390647, 0.11478144450173264, 0.016123233926332286, 0.09635067905389494, 0.06990592911719315, 0.055823566827682726, 0.08534171979033178, 0.286402307570942, 3.6094915290032668, 19.710614181333973, 21.286222434812977, 26.93065824047212, 26.322145654309182, 11.01083145987603, 0.40475679381239804, 0.14536055646115734, 0.5413446935915178, 12.11202217686561, 75.88951603058847, 44.68534723404915, 59.962112211412006, 77.44908963480304, 46.34536881600657, 5.659575173931738, 0.08535076728871754, 0.26241330610167596, 0.10208766637069565, 0.21709862315366346, 0.7350923132992561, 35.3318868144866, 90.436002362159, 93.67759812262751, 76.57718596919891, 90.54171808304326, 83.87892907665622, 8.398593721851226, 9.071929358666944, 70.27929505994244, 48.04690084149761, 37.662394431329545, 49.35215188610939, 33.67038257660405, 2.3643439431344313, 0.16386677390865742, 0.08207453099349815, 0.027175814236303972, 0.04259337010162492, 0.10317204084487692, 0.02459654366717704, 0.07598963250676471, 0.012405131522926592, 0.01730651801241742, 0.026884944057993354, 0.1015254344430662, 0.04644725201351028, 0.053537771135808966, 0.12978335361807578, 0.2344982419162989, 0.3843465874031667, 1.145047105608448, 13.92065255872665, 34.61562671969014, 40.42925396273213, 70.6084603648032, 80.02958559220838, 73.1133016463249, 83.69577792383011, 74.3225448362289, 73.59132089922505, 73.341567900873, 72.61185799875568, 69.29121078983431, 73.29844536319857, 75.17004351462089, 71.68251514434814, 73.26234386813256, 75.78180774565666, 74.30707500826928, 76.83425811029251, 76.5498862727996, 70.65006102285078, 69.08961665245795, 69.69011583635884, 65.49893386902349, 59.67064872864754, 53.50256866024387, 51.831897843268614, 53.87260113992999, 54.38451359348913, 52.806293041475364, 50.55664116336454, 53.76058609254899, 54.51188079772457, 53.46771840126284, 55.56484499285298, 57.93376045842325, 60.352870495088645, 58.95075259670135, 57.71351152850736, 55.66226882319297, 50.48984319933, 49.594499449576105, 46.62476708812099, 45.71291800468199, 49.126368491880356, 55.1276066226344, 46.03565454483033, 54.00661676160751, 61.994147069992565, 66.22513324983659, 62.83202809672203, 59.792944308250185, 52.879974765162316, 57.6026810369184, 71.3376917377595, 70.09328057689052, 68.77069657848728, 62.40031242370606, 64.64949753976637, 58.567650779601074, 53.38609387797695, 60.76141672749674, 54.809282748929924, 52.086377297678304, 47.79093873116278, 49.10967096205681, 48.00033838518205, 45.640205106427594, 47.396983715795706, 48.95772226395146, 48.64967892246862, 50.15973652562788, 48.906562789793945, 48.3052477528972, 51.700270945026034, 49.257493326740885, 45.95615594617782, 46.05224224828905, 48.15564070978473, 48.82274958395189, 48.61136128825527, 51.78332713342483, 54.98866450402045, 62.33984124275946, 65.66002953437068, 66.97304294955346, 65.83175090051466, 64.43276697589506, 57.775763465512185, 64.55450557893323, 59.30923761860017, 60.980245759410245, 62.209740146513916, 66.1510867457236, 56.859788048651914, 61.694827079772956, 61.97787707851779, 62.03862282537646, 64.20755624771118, 64.78243843201669, 65.01893774155648, 62.8128045605075, 66.49561205217915, 62.73183115067021, 44.72775197798207, 54.98546777233001, 63.03138648310016, 68.24818980309271, 65.75821822689426, 63.996924969457815, 62.85717048952657, 47.44980235253611, 22.581775419173702, 2.3315154208290965, 0.10342033760201547, 0.07018487705218215, 0.03036730971577908, 0.1494687182768699, 0.11013557323284688, 0.02679023452313437, 0.015891852390561855, 0.014413692443932017, 0.15318596074658056, 0.23894195024284626, 5.39946956980613, 27.027958516151678, 26.290066549854895, 48.13845288368964, 40.34327168618479, 11.05311559092614, 0.21371133475294038, 0.13273525892967178, 0.24779726781191366, 3.780386010485311, 72.77145924106722, 56.1230061131139, 67.19693183898926, 88.95351902131112, 78.8338275109568, 9.567753230371784, 0.1339353816283326, 0.37323435948741057, 0.24955470415373004, 0.5513564821693205, 0.4387507503551822, 24.14028213870141, 107.91628822203606, 95.99260453254946, 85.17449578931256, 99.14080081447479, 123.77388954162599, 24.20720365739638, 19.109138327260172, 84.41246555697533, 60.94540334516957, 49.53171799259801, 58.293936021866344, 44.70899912618822, 2.9717384086501215, 0.562392744806505, 0.19106974404665733, 0.17447418052582972, 0.23028619857805394, 0.17527261268227332, 0.15378386172796452, 0.16002024644084517, 0.1053063924454393, 0.10305928802418132, 0.2165757221800666, 0.27747315444773246, 0.15132645084973306, 0.13361103532295074, 0.24108161849360316, 0.5093676014052284, 1.8740126154115124, 9.113579046341682, 39.633310917885076, 55.658401366203066, 53.367717573719645, 75.43977706663071, 79.1829498352543, 76.10818816769508, 86.490278397837, 75.64393643409976, 73.42219614213514, 74.41737205751481, 72.78135930338215, 70.85374186115881, 73.46163949658795, 76.86502518192415, 77.05831173927554, 75.86045126761161, 79.86130806707567, 74.72199116983722, 78.30921050040953, 80.6623266589257, 72.93091927805256, 69.93006290928011, 72.38008514527353, 68.1655611530427, 65.5119522156254, 57.72843222464285, 54.83191874719436, 55.92549124071675, 55.02108289349464, 55.64446518498083, 55.130905335949315, 59.550071147180375, 59.37232894282187, 56.858199488732126, 60.608667865876235, 60.85486719685217, 62.64712364442887, 62.26297455449259, 60.80799487329299, 59.078323764185754, 52.66653899223574, 51.59330791042697, 49.75845060040874, 47.53986781643283, 54.14596288434921, 57.94422926441316, 47.16332812463084, 55.7751154130505, 58.73374746691797, 59.47396539872693, 58.86287973773096, 56.518180985604566, 53.1052404065286, 62.140659363039084, 72.49707375803303, 70.16165533373433, 66.79170393174695, 67.67358610706945, 68.1562259120326, 62.337319158738666, 55.888150276676306, 67.28217278757404, 59.52899232987435, 54.00649516813217, 49.329821832718395, 51.98714917705905, 51.58981307860344, 46.99990257140129, 50.47682093035791, 52.64392260582217, 51.74873575087517, 54.29104351228284, 50.83832617728941, 54.21864440364223, 54.545264090261156, 53.23136029704925, 49.962362858556936, 51.078481135829804, 51.56500016489337, 53.389627933502204, 54.21902095117877, 54.59333273672289, 56.06603760873118, 62.512249023683616, 67.1547192911948, 69.03649991558444, 68.53693900569793, 67.8985575706728, 63.262653350830085, 65.24878471128403, 61.87493839571553, 65.39575984401088, 63.85353880543863, 67.53970776834797, 58.03090187811083, 62.990664435971176, 61.76456682143673, 62.90235619391165, 64.89337874997047, 67.24282357000536, 64.71205149927448, 63.21713032261018, 66.43865139253678, 64.86027394571613, 50.66077224669918, 56.82021525598342, 64.71300855759652, 68.19292360736479, 69.00131625513878, 68.58291702885782, 73.19065078612297, 59.53383253466699, 25.074359293906923, 2.853050429013468, 0.19509639410722643, 0.12104747681728295, 0.09423229272567457, 0.2510340812225496, 0.24515245650564474, 0.23328226119760545, 0.2530905523247296, 0.24972623123997645, 0.24728463241650214, 0.41533245374598815, 7.7098951416630905, 35.8644191680416, 36.96029801522532, 61.592480674866714, 58.024143634303925, 23.89773649554099, 0.746304776159025, 0.5828175068862977, 0.572392582412689, 21.4210597930416, 98.40746664231824, 57.687208114131806, 86.03563647116385, 97.53691227205339, 81.49151571335332, 7.098000001522803, 0.17557307236617611], [0.306492350514858, 0.15110684408535882, 0.784345944562266, 9.065451564327363, 71.38192822856288, 95.84492729556177, 57.42710790326519, 90.74517926862164, 96.93649938029628, 24.542325081363803, 1.1543416520280223, 14.859212002446576, 53.45902642896099, 33.64888014331941, 19.881296119382306, 44.708755939237534, 22.648092892862138, 1.241923275013124, 0.3171591749114375, 0.08613356359062657, 0.12080369997889766, 0.03198981690671175, 0.0178632264461128, 0.09314366646351353, 0.05046230350290576, 0.016262696402507926, 0.028500089143973686, 0.032247950232798056, 0.09161669235195845, 0.07544646850757061, 0.07347288811879774, 0.08904039228875792, 0.06847090853918945, 0.03928950101497673, 0.2137563500793711, 4.006269670301869, 9.290548543776236, 22.78016890248945, 49.79657211611348, 77.77524255937146, 67.85005354112195, 71.68227195739746, 70.90095935329315, 70.46130088067824, 71.22901854976531, 72.2263203897784, 64.59026190542406, 68.36086380866267, 72.51535200303601, 67.57476591294812, 71.52937796808058, 71.92584330035795, 70.97386837005615, 72.90836564956173, 72.06091403961182, 65.81621046989196, 71.3637754994054, 64.42014086631038, 59.05039648855887, 53.89506847627702, 49.40845358756281, 47.089611099612334, 47.545115947723396, 52.38414795167985, 51.03188730055287, 46.604241325009255, 46.89615195797336, 49.14441923941336, 51.06816137990644, 50.84142877209572, 53.94438443645355, 56.367585505208666, 56.959592757686494, 55.88088604711718, 53.16336208774198, 52.10998604374548, 50.61776738012991, 48.158762916441894, 43.249430271887014, 42.534484171098285, 47.89231631063646, 43.74632397005635, 43.981579888251524, 60.92074340389621, 72.14337010537425, 72.46162337641563, 73.57943611760294, 60.220619939988666, 53.214537251380186, 60.67952156066895, 61.63716039349956, 56.80247437569403, 46.020886821131555, 51.50793752362652, 46.564307674284905, 54.78743122469995, 57.214672334732555, 49.25327677880564, 50.748315626575106, 49.65391159057618, 48.46258578761932, 44.5538301621714, 44.15850231724401, 44.5429063612415, 45.25665613912767, 44.301739431196644, 47.28986770875993, 48.754457196881695, 46.21664839406168, 47.58493584971274, 47.146485467110914, 42.12756964468187, 38.82545955719487, 44.50571836963777, 42.30611201255552, 44.193466324960035, 50.952929988984145, 51.260200623543035, 60.420547070041785, 64.83292325850456, 62.934241141042406, 64.22226905822754, 59.00495190774242, 52.3284306833821, 61.43002394706973, 61.12419674473425, 57.74073277750323, 63.207155735261985, 61.527424243188676, 57.568776069148896, 58.90284476741668, 61.4223910147144, 62.13139472469207, 60.39463589268347, 55.650964552356356, 62.454311693868334, 59.0092037570092, 63.50819372361707, 53.19327800504623, 37.76371317525064, 51.09288015673238, 57.341592388768355, 57.643336403754454, 54.74147281339092, 54.787482215512185, 36.60248764099614, 18.17463755607605, 8.041483000401529, 0.3090592966445031, 0.11515123514278282, 0.1914852394932701, 0.0886546516971242, 0.1278740020408746, 0.03106780902242228, 0.12838330495381547, 0.23214405372498498, 0.11706699887591025, 0.20054844268147023, 0.14610896307614543, 5.115317385042868, 19.99507427215576, 18.920678246405817, 27.85209555779734, 27.3339210402581, 5.223462523952608, 0.46822567680670374, 0.8278233954502691, 0.33728709324232997, 0.6139115448440275, 30.953166523287376, 71.93033833657542, 37.30223847973732, 68.18092899937784, 87.6429610098562, 25.730197237383937, 0.26681570696734613, 0.14211669504161806, 0.3048490306302425, 0.36666984399480207, 19.192861318588257, 94.85223031813099, 100.37717896123087, 80.9917979086599, 86.34616267296576, 98.244139148343, 35.340010043113466, 1.4476339398853242, 40.694304204756214, 68.23726207979264, 41.58567851589572, 32.36099539264556, 47.021612890305065, 27.35934388252997, 1.2842457717464817, 0.22216028864345244, 0.07676051614145118, 0.1103790512969417, 0.03678610187865073, 0.08756204943863616, 0.039539452522031726, 0.10498709465947845, 0.03425226606909306, 0.06521034640290084, 0.027502357298808715, 0.06497362523429817, 0.03848085307606286, 0.0216627984698261, 0.14097189921284878, 0.060782358200559695, 0.017079978152328444, 0.4141426272690297, 8.166085914258035, 19.05383094664543, 31.61723752175608, 54.39717892677554, 83.9916972191103, 71.63732159522273, 71.64521340400943, 74.52184046468427, 72.29375377778085, 73.65294133463215, 74.86311020389681, 67.06924300039968, 67.5026649044406, 73.60675934822329, 71.10559724992322, 74.98406041053035, 72.08333430751678, 72.93451216913039, 75.18763142247354, 75.59050590761247, 70.02955775107108, 71.41875928448093, 67.14277175164992, 61.48132462655345, 55.228293864957756, 51.87014095244869, 51.32598269370295, 49.510670554253366, 54.104342614450765, 52.999532530384684, 49.45611038515645, 49.777258365384995, 52.671014416602354, 51.80088366231611, 51.059136006139944, 55.26138297973141, 60.71186934748004, 62.03974070087556, 57.81725037482477, 55.61569459976689, 55.19524789625599, 50.97152202360092, 48.69330744589529, 47.760787471648186, 44.78445768356324, 49.691232942765765, 45.70297479629517, 42.905281512968, 58.823483451720215, 70.85076085982784, 74.80045426276423, 76.86271098352249, 64.72399511644917, 53.12178496391543, 60.51117735524332, 55.12126022769559, 46.39210777897989, 44.40408191373272, 48.575404920885646, 46.613702081864886, 58.20446283586564, 59.68838960893693, 51.547074933205884, 54.68275100954118, 54.73596580566899, 52.763629421111084, 46.272546091387355, 46.87320217009514, 47.64275550842286, 47.5520153968565, 47.95384260915941, 50.366476812670314, 52.2798325169471, 49.78078065379974, 50.711417890364125, 51.1678562625762, 45.56713527248752, 42.07698283656951, 44.543412346993726, 45.42956598343388, 47.70932989735758, 54.16770458221436, 55.35849302045761, 65.21408350236955, 67.61167541626962, 67.51879369058918, 65.99456064162716, 61.327426510472456, 52.88271650191277, 62.615407359215524, 62.35579744462044, 58.94559860229493, 64.22038239817466, 64.8160570667636, 59.92484185003466, 60.291740355953095, 62.8292824376014, 62.379896486959154, 63.07218697763259, 56.709333773582216, 62.982470604681204, 60.73047707157751, 66.25826158831197, 55.6200994214704, 46.74715680460776, 56.94139688245712, 59.51092197049049, 63.55500721162366, 60.06088925946144, 61.01450766286543, 41.48597186611545, 22.861783619849916, 11.851649361272013, 0.22157573291370947, 0.1904496724807447, 0.22072784212087432, 0.14217910056392993, 0.08811227676849212, 0.06054020546857388, 0.1164974814521209, 0.08584179900466435, 0.16042402074221643, 0.27983181659252415, 0.12684266383369125, 6.532185846759427, 23.59948927356351, 23.714801073074344, 44.59735278160342, 44.4321229380946, 3.548705822998478, 0.4220398906017504, 1.3923298687704149, 0.17957199004388627, 0.4037962114859012, 17.17697289682204, 73.17211366468861, 51.22247134485553, 72.11950640524589, 101.93730954200991, 40.57981414179648, 0.4437151839656215, 0.37893926304194236, 0.5886091315938581, 0.9346198518910717, 12.09323892670293, 102.94067536630939, 107.93561766224524, 85.75654414392288, 103.79717196187666, 123.0014571835918, 64.90785621827649, 3.8455895310448067, 53.627939378061605, 86.60153250540458, 53.43264064481182, 36.10336603656892, 57.41852967969833, 37.046539168204035, 2.170768601279105, 0.5168074489601198, 0.19775334024621596, 0.2912506941826113, 0.24608542902335045, 0.13643022356254442, 0.18291980959475043, 0.3254329551371836, 0.1226082354062988, 0.1701898031657742, 0.16412865340469346, 0.2051955167083971, 0.13862431469944217, 0.14521136849878297, 0.1853698660289088, 0.3109090006159198, 0.25504350962658084, 0.6523804967441867, 17.46034452992101, 41.48254371458485, 51.147138303326024, 61.0532057669855, 85.12413255630001, 72.47190783100744, 75.78223136163528, 77.50087276581796, 74.47608209425404, 74.28500775367984, 74.81637124092349, 67.98516350407755, 72.843748523343, 79.24146375348492, 71.63169691639563, 75.98669667397776, 75.31496724774762, 73.86617706667992, 77.18396094537552, 79.48705903945431, 69.9582882850401, 75.1308355023784, 67.04715221158921, 63.63736129576161, 60.850670260767785, 57.02165249855288, 54.08684884348224, 53.622467671671224, 57.38444036053073, 53.66560197645619, 53.976869506220666, 52.81856613774454, 56.093478510456706, 57.106081516511985, 56.16697588274556, 59.04828625340616, 64.59864793285247, 65.75181691877305, 63.44126239899666, 59.35217188250635, 58.89223867847074, 55.28824337067143, 52.08316095413701, 46.17427502909015, 47.44894335346837, 52.0250431952938, 43.32419456974153, 42.918503822818884, 61.44164985226047, 72.77502075318368, 74.93972193810248, 76.02779526864329, 60.46192023061938, 54.463953356589045, 70.9935978920229, 61.5945791429089, 50.28919827553534, 47.950904753900346, 54.79836679274037, 47.123127752734774, 57.622779261681345, 61.89250276934717, 55.816378747263265, 57.44151476890811, 56.411547430099986, 55.221774885731364, 48.1320829545298, 48.522331330084036, 50.995291586845156, 50.28148689577657, 50.61481383539016, 52.540599530743016, 55.18111167415496, 51.79669849334225, 53.9607407200721, 54.82615678541122, 47.72630199309319, 44.429969556870006, 48.25976394837903, 49.07363614728374, 49.282882828866285, 55.10211513888452, 56.75708470805999, 65.24907496667677, 70.37948808362408, 70.24804945914977, 67.66286234701833, 65.43133966384396, 55.37049155081473, 65.25100477280156, 64.26168887845932, 62.29528703997212, 66.58052352166945, 66.30298445301672, 62.88399950150521, 62.273102114277506, 65.60570862985426, 66.06488089407644, 64.55474484351375, 58.18715733866538, 66.35376345726752, 66.28777350148847, 67.50904267834079, 59.66708721653108, 54.81079286144626, 60.44681910545596, 61.297926364406464, 64.81737890551167, 62.278008999363074, 68.01564032031645, 45.428067638028054, 27.666267387328613, 17.829063015599406, 1.1570936850001736, 0.2682741851575913, 0.5039983362920823, 0.20385725303523003, 0.36900509449262775, 0.1897473077500059, 0.1830141763052633, 0.3240387670455441, 0.21453058917916593, 0.510127192903911, 0.3477738563331866, 10.180356848624445, 34.57410843141618, 35.19218375605922, 48.51567899027179, 70.12330239818942, 13.618272139180092, 2.7327265758668227, 2.206791158645384, 1.1458236123284986, 0.7954092960684531, 51.31278784044328, 93.58054299508372, 57.23111883286507, 87.0434267290177, 114.5382139759679, 40.56131624406384, 0.6336347542462811], [0.019142058933334007, 0.30535489380840336, 0.31272043083463946, 49.91833817574286, 109.39026001961001, 70.95708847045898, 95.95919378342168, 84.19335411440942, 52.62361257306991, 2.094829798706116, 0.1583608540315782, 44.54868401250532, 39.75635174782046, 24.75810447046834, 30.77256294988817, 51.75568619082051, 20.00949094372411, 0.42555381333635706, 0.03692152707146541, 0.09613957586548022, 0.01639351932211749, 0.07629422140457938, 0.05165177374897946, 0.024152377379998088, 0.03762091938105803, 0.035028079479572274, 0.14798537287260258, 0.09847284985646125, 0.05789600320220475, 0.025604060370354884, 0.2281047325701483, 0.11283785645519534, 0.38489633209763036, 0.08872340042744914, 0.059260765856672684, 0.5604101092584672, 1.8736996838162023, 6.64823014889994, 35.564322548527876, 66.7008775280368, 70.46457213740196, 72.61742776440036, 67.50282964398785, 68.4869287860009, 67.6879027581984, 73.51943954344719, 67.788527242599, 66.54825810463198, 73.16925817920317, 68.05515427743235, 69.53447618792134, 70.2696381845782, 65.90929615882136, 71.3298156184535, 71.90886728225216, 68.69220995133924, 69.35469042870307, 66.39599169454267, 64.28091241467384, 48.63874727679838, 46.09130121046498, 50.74003158077117, 46.965185673006125, 48.24969914651687, 52.30016216155022, 50.80258554027927, 47.23237360677412, 50.47450673195624, 48.09209439062303, 50.069584769587365, 49.969568252563484, 56.31820678710938, 56.52455875950476, 55.50631538514168, 54.05004132178522, 55.157483316236934, 47.113694452470355, 46.549347754447695, 43.48933812110655, 44.79399688782231, 45.52573073294855, 51.304201772136075, 45.83234633168867, 47.93214013499599, 65.07244279307704, 74.31597878856044, 72.99082956006451, 72.14115004385673, 54.46574980212797, 46.882674694061286, 38.400337388438565, 37.004236405895604, 41.23415177868259, 47.8328884801557, 53.3038103965021, 57.13283600345735, 51.928486208761896, 45.97475974790512, 50.09204818356422, 50.03409124189808, 49.35343057878556, 44.99975265995149, 44.1415302215084, 42.55495894339777, 43.950895186393495, 42.79094050007482, 44.34490903731316, 47.925177927940126, 47.11160775153868, 44.44127775007679, 47.05202302625103, 44.95219784398233, 40.22471804772654, 43.79572622237667, 42.71796480301888, 47.394987229377996, 49.53960195664437, 56.318508809612645, 65.04168356618574, 63.62578245901293, 60.18548727035523, 62.543274971746634, 57.099287971373535, 48.905570430140344, 61.011405068059126, 63.789847358580566, 54.54927275257727, 58.71119383842715, 62.419739923169544, 63.832071673485544, 58.21107987434634, 53.23398436269453, 49.471419395939, 62.39093795899422, 54.56888068106867, 52.729916649480025, 49.70227441480083, 62.49845404778758, 40.10257151819045, 40.83408178821687, 51.50101454027238, 57.500868074355594, 56.92636635995681, 53.07919586858442, 50.06337565760459, 28.13773039848574, 18.355715736266106, 4.52552774260121, 0.16385283110843551, 0.10870203120453704, 0.11545894967932856, 0.03660488761060181, 0.06686379396987539, 0.17702310826749573, 0.03148900990885112, 0.07456183613788697, 0.0721828803239811, 0.203839173360217, 0.08062415801349186, 4.256880196832841, 12.490373023094671, 10.440719858292612, 26.35759407474149, 16.784451507752944, 1.456416004127072, 9.342434637008175, 9.55982513966099, 3.833066873973416, 1.2429010483526415, 0.9639733380848362, 61.79145466896796, 78.7891830936555, 40.513949701862956, 98.81591089310186, 56.37595976552656, 0.9980612476506542, 0.27069002810505133, 0.2500778349537042, 1.8097266843242032, 73.54354643052625, 110.1557654719199, 84.83503034037929, 100.45812883684712, 79.85822508412024, 58.55758597773891, 1.7480004674965337, 10.828509888341351, 76.22196828165363, 46.35549245342132, 35.189438096938595, 40.99858991561398, 58.53776231888802, 23.544181892948767, 0.5987280499069922, 0.08739672000369719, 0.06913455518623514, 0.0415765684128048, 0.18094665821521513, 0.07878534781235842, 0.07305074302900223, 0.0429541209051686, 0.007887241945061232, 0.09971987245784653, 0.06645846451001783, 0.06478452409106879, 0.10573941598375959, 0.21637845453956436, 0.07973159663379192, 0.4699850436900893, 0.07560563859559837, 0.01833171410966785, 0.13865783870700868, 2.5161352561366175, 9.844297978185839, 36.175674930695564, 68.9314902213312, 74.9911363663212, 76.10853333627024, 69.5913819343813, 75.06424150159283, 70.9054308552896, 76.41239150877922, 72.43383730611494, 67.79597190118605, 74.72690197729295, 69.26716666067801, 71.3176013577369, 69.88304938039472, 67.11458559959166, 73.35543740180232, 72.23786784756568, 72.85361720669654, 71.39697444054389, 69.99677458117085, 65.70175570826378, 52.380413855275805, 46.678707522730676, 52.47466841051656, 49.453658903798754, 48.353626266602554, 54.157396593401515, 52.87415789019678, 49.86824166390204, 51.72082808709914, 50.45164715859198, 51.900923713561035, 54.55574466336159, 58.56990222007998, 58.0255086191239, 59.74932755193403, 57.87978472248201, 58.34671543490503, 50.47516569014519, 47.68397569656373, 43.63622303931944, 46.07992633696526, 47.93513682580764, 53.12733511770926, 46.94065909231863, 46.56226411942513, 65.71207546418714, 72.1335014220207, 71.51548493293025, 72.03216306624874, 56.41909799268169, 44.57376756975728, 38.52832040479107, 40.05435382166217, 43.582086486201135, 48.06014276319935, 55.03578393690048, 59.54061039032475, 51.470698541210545, 49.38724925441127, 50.688703444696245, 53.915488335394095, 49.77207299201719, 49.13099296631352, 45.337798210882376, 43.94635700410412, 47.81327662929412, 46.87693234412901, 47.93173613086824, 52.29532980149793, 49.45765579900434, 46.346247426925174, 48.34046671467443, 48.613043985059186, 45.32881990555794, 47.977325839381066, 47.48546061977264, 49.32980222086753, 49.476098783554576, 59.624023514409224, 66.13256531376993, 66.42708040052845, 62.75811103082473, 63.99943136399793, 58.94828542586296, 52.10966833176152, 61.35229433736494, 63.17985211649249, 55.056988270052024, 59.32624109329716, 65.18886266216155, 66.8074091019169, 60.81329399539579, 54.25571472414079, 54.23041543652935, 66.65704896373134, 58.0084776878357, 58.12718429873067, 56.15869968168197, 63.81002403074696, 37.56828892615534, 47.73027143170757, 58.333963809474824, 62.733215747341035, 58.729068079302394, 57.8424947492538, 56.29633172865837, 29.755566889239898, 22.61835152103055, 4.751115018321622, 0.10788335900513396, 0.02457411835841354, 0.03673058731721775, 0.03356919143228762, 0.19664314094810717, 0.17071019137097945, 0.09706446615558478, 0.054535868787957784, 0.08322709495381964, 0.2249363614546676, 0.1461037690000188, 4.603597127622174, 17.663372293595348, 11.438619859756963, 30.31895260657034, 42.77097171352756, 1.133813437434935, 12.836484928284923, 11.737620176807528, 3.4081758799091464, 0.7924684377447252, 0.31648841896845453, 55.648258116937455, 83.3555672245641, 50.50115531490695, 106.90470110985541, 70.40602684020996, 1.2534139810069915, 0.36934241832744696, 0.29901536301739756, 1.1955397768366722, 73.12134250517815, 129.02766120049262, 90.43196232088151, 116.0175358864569, 97.9881025129749, 89.693325104252, 3.6669679803232995, 15.079622730132073, 97.20780972511538, 55.78270912170411, 45.458924924173665, 43.253850783071215, 71.94655341486778, 30.67196592207878, 1.7996567343511891, 0.25120107306828426, 0.22515869549205228, 0.21965237724925243, 0.3451028448199073, 0.12889030960298356, 0.0757842596560236, 0.09217116380891494, 0.16906593685909627, 0.20177311083722502, 0.19940516370679104, 0.13833792038982914, 0.19744523500482883, 0.42197753104471397, 0.18108951829133496, 0.5418943769989476, 0.15862389798125914, 0.19260653174452244, 0.8653636036380645, 5.668239199346112, 24.660721825015163, 57.069144556599284, 70.53803813072943, 76.33671329867455, 77.30712336878624, 69.03590371531826, 74.41417924819454, 72.20447278791859, 80.25037580920805, 74.24518785169049, 66.77894838394658, 74.60491626493393, 73.82791826801916, 73.31546060500607, 72.45274313034551, 67.42755151564076, 78.2417457334457, 73.83280554125386, 75.67205198349492, 74.59034073737361, 73.1836768119566, 67.50872104398667, 54.29513062200239, 50.024301005947976, 55.78842401504517, 51.98490950369066, 51.78845759361021, 56.02125983084402, 57.60959617553219, 54.30963946926979, 55.08808089840797, 54.29349107127036, 54.83462126024308, 57.37720750993299, 62.34725452238514, 63.659295189765196, 64.24028058205882, 59.26464419211111, 62.92808301987187, 51.052413063664595, 50.00305744909471, 47.14107651864329, 48.961746615748254, 49.05438123210784, 55.86782455444337, 46.278127624142556, 47.779665839287546, 66.61681329050373, 74.77657487315517, 73.36672598315825, 72.15979699165591, 56.913893222808845, 46.798975236954234, 39.124038219451904, 39.06506930628131, 42.001677251631214, 48.1235674888857, 57.60929023065875, 63.90212128239294, 54.33668813397808, 52.30659484863282, 52.90363057967156, 56.14884668780912, 52.50947552342569, 50.15868925279187, 47.25014194365471, 45.5703829949902, 50.471231552862356, 46.72312836493216, 49.308237029660134, 55.65816210162256, 52.99170347952074, 48.9507600568956, 50.83161500192458, 51.37696958357289, 45.86156406710225, 51.184055651387865, 49.06406164169312, 50.96062567926223, 53.0755009958821, 62.70630828795895, 70.09421410099154, 69.08907536537417, 64.95885487525695, 66.85222610350579, 61.09581839653754, 52.73219554655014, 63.43540237795923, 67.36104380699896, 57.92395845536263, 62.33606400028352, 71.08735822862195, 70.23198343092396, 62.689512698881096, 56.64841936480615, 54.351063620659616, 66.46130700265208, 60.62766782699093, 60.32973243344215, 57.17633508866834, 66.56761107906219, 55.05019864728374, 59.71938810040874, 65.23384440329768, 64.04392673123267, 62.16446814998504, 61.37729944721345, 61.10286297336702, 44.51560666484218, 31.988413372347434, 4.328842451495509, 0.2009651025817279, 0.09703943806309855, 0.19861477547355239, 0.0963330590316365, 0.3323706780229846, 0.21362131942183743, 0.28326818058567665, 0.3176507888542068, 0.16488112028568022, 0.6912734936321936, 0.14046937617803776, 7.17475196046214, 26.495455580372965, 18.80113813184923, 38.017937675599136, 54.826807898859826, 5.311704085719201, 20.917956982889486, 17.5712417018029, 7.5296720381706, 1.77175605729703, 2.337766698291225, 79.01373094128024, 96.6246081936744, 58.81829415598224, 118.13852617817541, 73.13301547881096, 1.5373778920019827], [0.4959529728418397, 0.2687561770360316, 7.623836378897391, 106.0436467201479, 78.12956594651746, 95.67374721650155, 83.18716418358588, 62.82524631869409, 9.362576007843018, 0.6964190917149667, 31.31950609145626, 59.509866852914136, 44.296722719746256, 41.462959320314475, 34.981701527872396, 33.088891198558194, 19.163078761869862, 0.2842534615868523, 0.017662620577480526, 0.03216112182746011, 0.08740971285489299, 0.05628631074702548, 0.046019748138684424, 0.06655298443811555, 0.02892655113922252, 0.039383775794938694, 0.1393803362283976, 0.16714285698629197, 0.06256924296218543, 0.09729870519931279, 0.09613419792825177, 0.0556750338704836, 0.08222318269432553, 0.06849177677424685, 0.13809887031393667, 0.0472791392296072, 0.10005089138904888, 0.22778561098441003, 6.699624965267797, 53.90141094884565, 66.31577137977847, 66.94507645022485, 73.4101152420044, 71.64753544715144, 72.36962810639413, 66.04135451778289, 71.75395719466671, 70.31115255048199, 73.06067912809311, 67.25301388771304, 62.982847152217744, 65.74680020732265, 68.0125730268417, 68.05908449234502, 69.54183455436461, 71.18206777880269, 73.6683640941497, 67.71045638668922, 64.10782606370988, 50.453977046474336, 40.838568979694, 48.981731091776204, 48.19363278727378, 49.343852150824766, 49.28739355456445, 48.30356113372311, 47.51633359539894, 48.29617138831846, 48.72208979821975, 47.85914874845936, 47.44964545772922, 52.179400228684955, 53.40447018223425, 59.902621623008486, 57.99902869809059, 55.46718974267283, 46.874390648257354, 47.47082233428956, 43.00533725369362, 40.82375418755316, 46.3118286286631, 50.47636985778809, 52.287081057025546, 49.254375042453894, 55.90918594791044, 64.08384469247633, 65.66646614382344, 65.04938710120418, 58.38649219082248, 43.576218620423354, 44.28676774424892, 47.527233862107806, 46.144147303796586, 48.741850699147875, 50.70070589742353, 49.52255925824566, 50.81980866770591, 45.497128809652025, 48.451485480031664, 51.82958364486695, 50.383860757274014, 48.9271552331986, 46.30971447114022, 42.80758311671596, 44.505349666841575, 43.80861905313308, 44.65361525935512, 44.35392264396914, 44.56739764059744, 43.37954705761325, 47.328291246967936, 48.44808870746244, 44.092433914061516, 45.10123222104965, 44.22232320231777, 45.79560156791441, 43.7140703201294, 52.83496948980516, 60.035048684766224, 62.59461487493208, 61.51507662188623, 62.53041351995161, 56.706803844821074, 57.37102193217124, 61.120635232617786, 52.54297648706744, 47.56094663373886, 57.077432524773386, 51.56086598673175, 51.44929416718022, 55.19842893846574, 48.08136278583158, 54.94038012719924, 55.626685080989716, 52.62687206268311, 52.326253767936464, 46.083126991025864, 30.509456242284468, 5.740929053675744, 11.840048951487388, 35.22240169586674, 54.1786362278846, 51.66993533411334, 52.60965677999681, 31.606700074288156, 8.132632509354623, 3.536963227295107, 0.3071452719309638, 0.07741725267541986, 0.05067256399460378, 0.07014111810994726, 0.0548528874623439, 0.021357121727158947, 0.07264261734822104, 0.08049137199357634, 0.12081363613927558, 0.019077807139124603, 0.16796447096332429, 0.10663490381933029, 2.387440819894114, 11.504831429450743, 28.818661705140148, 36.0727793939652, 25.520838768251483, 7.653244839560601, 11.387809476544781, 23.98257932355327, 17.62643337249756, 2.8005026809630857, 0.2440147393292958, 15.81707048800684, 76.35994941957536, 56.967449265141646, 87.89538121992543, 79.08362757775092, 1.5047702481669765, 0.2963066599782436, 0.2747012644765839, 13.988649787441378, 122.20470613048924, 76.11865305131482, 107.19286195693478, 81.75443218600365, 73.12144448680263, 9.984267757784936, 0.266552877522284, 54.22214315783594, 72.41370770239061, 54.987617231184444, 53.85935529585808, 44.88720809259723, 37.33069919770764, 23.87068194727744, 0.24317841646411728, 0.12213179766530953, 0.04370482961436914, 0.01640872808263427, 0.08048997771355414, 0.00606361033973254, 0.04007340048349673, 0.05465306491861421, 0.08250426801462328, 0.0588772660722175, 0.03548421972100774, 0.033604691946698774, 0.02606982459133912, 0.14247871755111602, 0.05400287077551889, 0.17469596297990891, 0.031830997303909356, 0.08660568059572289, 0.07912834835869652, 0.0957373873661122, 0.16821256087672326, 2.6122235194329293, 48.024147172128, 69.18874279145273, 71.45250735744354, 75.81636382687476, 76.63358180753647, 76.02028785213348, 68.5309220898536, 74.18856451588293, 73.72735654154133, 74.76930279885569, 67.85861215283795, 65.5792365535613, 68.64966007970995, 69.37001905133648, 69.36717925533172, 73.39815201297884, 71.8942839099515, 76.01115657437232, 73.60981095221736, 67.5719496511644, 55.36138772964478, 44.03585372432586, 51.37301975680936, 50.79308163735175, 53.04686769362419, 51.65170023518225, 51.03211479802286, 51.062575924781065, 51.70596622651624, 52.06413745880128, 52.08213329315186, 49.1084824838946, 53.973166788778, 57.67976345554475, 59.94697186254687, 59.076237063254084, 56.611207838981386, 52.126628660386615, 47.92176938826039, 44.75534585214431, 43.33525173125729, 49.77277509627804, 53.61234403425648, 56.11302368102535, 53.25223907347649, 56.9748939237287, 61.41163979807208, 62.663860397954146, 64.37989734834241, 56.41582281358781, 47.28382333632439, 48.538111025287265, 48.95488639031687, 49.65252307153518, 50.912407982733946, 51.77657673435827, 50.26855091894827, 50.16242334919591, 47.101770447146514, 51.08693384355115, 51.77056766325428, 51.75869072637251, 50.412811771515884, 47.814167007323235, 46.29174609338084, 47.338971860947154, 44.89552743973271, 47.86941751357048, 46.788584878367764, 46.3053253389174, 46.95270076874764, 49.50770916477327, 51.075233413327126, 47.4588002697114, 47.751817011064105, 47.14483414926837, 48.695143115135934, 45.63233683186193, 55.04201266073412, 63.044043971646225, 66.16635261043426, 62.86569772228118, 64.60520613578059, 60.854325909768384, 61.55768925143827, 63.55561910137054, 51.59469642946797, 49.832952099461714, 58.56066896069435, 53.05806998283633, 50.217414979011785, 56.10566923695227, 52.195376042396795, 59.54847474252025, 56.35285700521162, 56.21440910523938, 55.41402593735726, 43.063819792962846, 18.835413763600013, 1.4489824997801937, 7.092332176623806, 29.341768603171076, 50.67442993963919, 54.521502371757265, 53.33376553750808, 27.715448025734197, 6.739492425995489, 2.9480752396968106, 0.28640236885797593, 0.046447317130983844, 0.10565107838521082, 0.0400021466456594, 0.14094890125336187, 0.058055261390343796, 0.06463547402452077, 0.15874857113005655, 0.06233190892324333, 0.04886671089597287, 0.1210225712988646, 0.10829782789392818, 3.2715170710317554, 19.88182956172574, 27.342495341454786, 33.65475977620771, 40.282969167155606, 13.329340546361863, 14.71362440816818, 24.942904979951923, 17.382246217420025, 3.448617477570811, 0.2254948242297096, 13.287164280491492, 80.26422177591633, 65.12736774259999, 94.40054585856777, 85.07962934432491, 1.7342596693385033, 0.5393138251477673, 0.31640224939873146, 13.213415876511606, 133.61393959291522, 92.53748278464042, 119.62801487215104, 99.5201567680605, 95.42540627141153, 23.33171102308458, 0.7767803053702078, 62.228014469146736, 82.40144283540788, 68.80931623520391, 66.36157681865078, 48.50655163488081, 46.00680551221294, 31.603167979947983, 0.5677954419966668, 0.28290680159003506, 0.20299761045363643, 0.35255396918904397, 0.2672362279507422, 0.2015194131602203, 0.3236816474987615, 0.19191856946676009, 0.16277304550092067, 0.23225012625898087, 0.1949606433270439, 0.15629270774943216, 0.1697191187450963, 0.21707317371281887, 0.19217766040275175, 0.22707060580292057, 0.13813804805038438, 0.2397877266330104, 0.22104003827177712, 0.13556480467800172, 0.2657778723345649, 16.71528639331941, 70.05917949061241, 68.16860491229643, 73.20346124710576, 73.7160679601854, 77.97340854521721, 76.15126363692745, 67.64565098670222, 75.07236080784952, 75.75105636350571, 75.42190674812564, 70.20639388791977, 66.1896828682192, 70.26665718324723, 69.66893503742834, 72.9323156418339, 74.70822365053239, 78.10206228686918, 78.35438051531392, 73.9944621055357, 70.3825318428778, 56.8162654292199, 45.705202702553045, 54.068401936561834, 55.65752667765464, 54.5317554473877, 55.42575774654266, 54.18382944599275, 53.80052366564351, 55.50697826570081, 53.19874578906644, 55.22181803180326, 52.75270954255135, 58.31901565674813, 60.78433905878375, 67.55749963944959, 65.36495747104769, 60.34743016765964, 53.80635230771957, 51.29775339557279, 45.65526308551912, 44.74012705587572, 52.152943841872684, 55.15195277429397, 56.408464447144546, 52.196462538934526, 57.30576938198459, 64.45293580332111, 66.96237410268476, 66.81064897967924, 59.95714256840368, 44.89200515131797, 46.18779936144429, 47.05670633623677, 49.46475136664606, 54.19791859965171, 55.82687108747421, 53.49500633055165, 56.52376644072994, 51.2427499986464, 53.44376056425033, 58.24947595596314, 53.47109163961103, 53.35105142285747, 50.90403372241605, 48.53653815484817, 51.01596640002344, 46.795766738153276, 48.74731456079791, 50.631240721671816, 50.17909342242826, 51.17194729466593, 51.14420044806696, 53.60257341015724, 48.259297186328524, 50.48408123754686, 48.62601526321904, 51.196819043928585, 48.06574390780542, 57.92682178558842, 65.4517791348119, 68.73770160059776, 67.22777735802435, 67.21592395536362, 63.187151647383175, 62.98435334236392, 63.52177296915362, 56.32807547046293, 50.51722526550294, 63.41265263095979, 57.31760317279447, 57.36557768237207, 62.576811236719934, 59.96554820768295, 65.84812287361392, 67.99492236106627, 60.24999457020914, 64.52714312461116, 57.47040302522721, 44.289203536125925, 12.848976696691206, 20.58379065605902, 47.97986753525273, 65.67272232424828, 67.66502749535346, 66.10448114333614, 51.432059272643066, 22.3645604425861, 5.21677537310508, 0.7046231579396033, 0.3297324857163814, 0.15959630870530683, 0.21066235077957954, 0.3503191987833669, 0.17705664759682072, 0.15731399488304892, 0.2411149892835848, 0.34896873899044534, 0.15003015347305806, 0.4039893882168878, 0.16149233035262556, 3.883584305163353, 28.975144663164695, 41.54968292482438, 53.65139515169206, 41.27172808493338, 28.7016515193447, 19.365506402907833, 34.09146470408286, 25.767104779520345, 5.599456025708107, 0.1974450358219685, 30.182395289021155, 94.96690473248883, 80.83634653399068, 109.95773284666001, 100.9866995965281, 2.3102252858300365], [0.3108444960126954, 0.4246218826982283, 23.711527855165546, 115.11157035827638, 65.53860472094628, 83.00033384753813, 69.52827099830874, 35.38483881181286, 0.32784659175142167, 0.5288985840255215, 35.09274382745066, 61.19691356535881, 50.173484433081846, 53.34718396586757, 27.38074629537521, 45.03377137645599, 17.073500771676343, 0.2088255477288077, 0.02562401121512296, 0.011323017008121938, 0.028910017046596737, 0.03879956097432202, 0.057738801960142395, 0.07642972703662611, 0.04925904750463463, 0.05149866341643276, 0.037933142345038154, 0.0531937018968165, 0.04768366046670464, 0.0962967464640256, 0.04279384765052988, 0.09228121233923782, 0.07426809504508011, 0.050675865833557425, 0.017745009503297268, 0.12091088334038375, 0.048838059207604784, 0.04820273483111974, 0.2254831030844681, 10.153298377990723, 67.85829836322416, 72.68667328742244, 73.55543121214836, 73.27050239809098, 73.67076458469515, 68.67273146106352, 67.33617598010649, 73.35032263109761, 68.8199850820726, 63.89977178265972, 60.48120652475665, 71.20637862913071, 70.22173820003387, 70.50140319332, 71.7107169858871, 71.87642143618676, 68.05003950672766, 69.26499366760254, 66.22284258565595, 59.21462612767374, 51.382021596354825, 50.64907966121551, 51.47129474147674, 54.892323247848026, 51.93069450316891, 49.47407484054566, 49.61400147407286, 52.86178281230312, 51.015844806548095, 48.85704678873862, 48.481899538347804, 50.25952554518177, 52.356016712804, 51.636446137582105, 53.06298863503241, 53.4316365180477, 48.09826820127426, 44.01261760342506, 45.249513503043886, 48.17762167223039, 50.054197311401374, 52.29495325396138, 54.25446348805582, 57.72568656552223, 54.45050354926817, 51.320389393837225, 53.499379773293775, 51.24746468759353, 47.35912499889251, 50.16614175611927, 53.1203297645815, 53.87898283620035, 52.849384200188425, 52.649868919003396, 48.72683194375808, 47.638287928796586, 47.67885700348885, 42.19995306384179, 44.33496190655617, 44.8911932206923, 46.06178929728847, 48.08093132511262, 44.3661408270559, 46.403278689230646, 43.91139691875827, 44.07758382058913, 48.053259003546934, 43.91010645897158, 44.621714622743674, 44.2200796065792, 46.29603324397918, 46.719158926317775, 47.28141892340876, 50.221125541194795, 47.860054815969164, 46.60199772927069, 45.71175698311099, 54.17353322429042, 58.61014181567777, 57.96143670235911, 57.7884287987986, 59.40258610633112, 61.671477210137155, 62.62315011793568, 63.12485264193628, 51.982489401294345, 52.22298560603973, 47.61067052041331, 48.727628184903054, 39.881820524892504, 32.93413016103929, 34.83810747823408, 40.086258380643784, 41.58810254066221, 36.65223506189162, 14.933060426865856, 4.890254726333003, 0.4472289534826433, 0.1789017090754163, 0.06569129640176412, 1.4038236391159797, 9.675656653219654, 26.739472112348004, 23.271734060779696, 2.0912528422571, 1.681770634266638, 0.06981859509382518, 0.0942118381780963, 0.07952393318015723, 0.026470076803478505, 0.05066845393289001, 0.09324371754642456, 0.039733866485016006, 0.1452265830049592, 0.05610320424180358, 0.03907369787714655, 0.054771199506977876, 0.04442948367326491, 0.0760181769428234, 2.330140139787428, 11.489689119400518, 24.196962348876465, 25.316781382406912, 22.621114830816946, 14.120231578426978, 13.7378240208472, 36.8640979643791, 38.134718402739495, 10.08935688003417, 0.548714398136062, 11.125546078528128, 67.24916996494417, 47.472073570374526, 95.83576463883924, 65.45857660232052, 0.639118166460145, 0.28336679142329, 0.5370637329836045, 32.49723892058096, 118.43974067318825, 83.32022666931152, 88.48076358918222, 75.58379865461781, 39.67746896128501, 0.5747776286255929, 0.799639388438194, 41.7635658479506, 70.6308021853047, 61.18447965191257, 64.19792682893815, 31.36835725076737, 52.72163652604627, 21.497606808139434, 0.6994254045909452, 0.09254119193722164, 0.04359280457720161, 0.04741024368652894, 0.05009627052312417, 0.10196254889090216, 0.10175984968701679, 0.0742823749239887, 0.01669266133479053, 0.07924289382513493, 0.022863041827334993, 0.05287828817663174, 0.04440391931923167, 0.13240009546279907, 0.016930931916220054, 0.03774790611538676, 0.06334581863014929, 0.048650459596706976, 0.045879680453048605, 0.034525407057616024, 0.11308883452006888, 0.13826158738905384, 4.0822094534674, 54.05542673603181, 78.08849873081331, 78.4908397736088, 78.19266903784968, 78.84489643958308, 73.62393932957804, 67.48158608713459, 76.4003655218309, 72.39661401317966, 64.30212459256573, 62.96203505608344, 73.4203996965962, 75.27381373989967, 72.0607885237663, 73.58284073491251, 74.46316180690643, 70.25718073691093, 70.75718095225673, 67.79710154379568, 62.525118320218986, 57.048960039692545, 53.506494952786355, 52.72896351352815, 55.181052838602376, 55.336194346027995, 52.00353291726882, 50.05719007984285, 54.537740984270656, 52.24321719138853, 54.087033194880334, 52.40664666698825, 53.44698475253198, 54.21088987781156, 53.19481557415378, 53.94278410942324, 54.61685126827609, 50.35225822079567, 47.920310266556285, 47.615804902968875, 50.64751071314658, 52.9926723049533, 54.60648052154049, 57.63384426793745, 57.47227791816958, 56.79038563082295, 53.16839448867306, 54.091775340418664, 48.81219056344802, 47.84237669360253, 51.82323724992814, 52.97235834983088, 57.421851927234286, 57.43585478874945, 56.13382793241932, 54.276291478064756, 50.70793482565111, 50.07054182790941, 43.55618315358316, 45.18416289360293, 47.05061097298899, 47.28041871901482, 48.6486904851852, 47.661394611481704, 48.9557610788653, 47.94718242460682, 46.01786659609887, 49.75696009974326, 46.710474798756266, 47.47262662456882, 48.387229211868785, 48.488724462447635, 49.810916223833644, 49.111875334093654, 51.31683180409094, 50.69745033018051, 48.29562225649434, 50.46754060253021, 57.500620965034734, 60.63037818478, 61.88341856002808, 60.28208740295903, 63.35855922391338, 63.59710601068313, 66.32625195287889, 66.09247084586852, 55.915073425539084, 54.66351570621614, 50.0588688542766, 50.71759170101535, 43.276777036728404, 36.110351777845814, 40.9616647228118, 50.60563548918694, 51.75781603782408, 41.73419121773013, 14.716086676043851, 3.96497005416501, 0.6706073219257017, 0.050816301241396904, 0.04070384871034373, 0.6101776323010845, 7.11290059551116, 21.521027280438332, 20.394928532262004, 1.3572985678911211, 1.7887172439405996, 0.05959106849566583, 0.06941174877987755, 0.08746901572111153, 0.04283192222036662, 0.05510876465949321, 0.011243925133209315, 0.05935720483502073, 0.08242674757756534, 0.10141548550417347, 0.050828305839170376, 0.06772547434534758, 0.059833960502498576, 0.18093365004226086, 2.246674308853765, 17.52827605893535, 32.45074118337324, 30.49840888669414, 41.56029685851067, 36.19753037729571, 31.382720970338394, 51.29896540795603, 39.50376287583382, 11.335627244364831, 2.745481388222787, 20.375044076673447, 76.74591064453125, 58.20049731962143, 107.36380669378467, 70.09713234439974, 0.43314252709669454, 0.6157320761872876, 0.7212847735612624, 35.184374317046135, 131.43248204262028, 91.11119131888114, 97.7240328634939, 88.20808825954315, 60.6376463367093, 0.6532167583223313, 0.99252279968031, 66.26787923997449, 87.89261987132411, 68.58509786667364, 72.61466641579905, 37.18010371731174, 60.405967620111284, 29.272054356913415, 1.0434528151827476, 0.27717257218976177, 0.1909195448482229, 0.13239278698400145, 0.1239982100143548, 0.17832383363237306, 0.19806394293423624, 0.258119260712016, 0.11440807623007607, 0.14046428935422053, 0.1576642349602715, 0.16696753010394114, 0.4215653450979341, 0.32245694869948976, 0.14033907994387612, 0.2034092448171108, 0.1443066646254832, 0.1377403564871319, 0.23353770555507755, 0.15194601679761566, 0.20703676306912977, 0.32992888001664994, 20.966802258645338, 75.24865565761444, 76.95796966552734, 74.99035189228674, 77.62376062331661, 80.09994506835938, 74.27327986686461, 70.19636830975934, 72.80323043946298, 71.01325681132656, 68.5803282645441, 63.659636435970185, 74.03711395878946, 76.85962800056704, 73.91556755188974, 75.69688843142602, 78.92134343424152, 74.10697137155842, 74.55538457439792, 72.45057013727003, 64.65054089023222, 58.078892077169115, 58.24714999045096, 55.176200866699226, 59.92574007280412, 57.719583357534106, 54.69378855920608, 53.46323120978571, 57.08259044154998, 55.808247673896055, 54.701174382240545, 54.24291603026852, 54.8758767497155, 57.76396889840403, 57.29886993285149, 57.98774011673466, 59.24498919517764, 53.949985581059615, 51.05435463689989, 51.32697505335654, 53.453331147470784, 54.47568908814461, 59.45276106557539, 58.61971632126839, 61.285304177191954, 58.86438592787712, 55.72264586725543, 54.46745211078275, 51.762632708395685, 49.72892692012172, 52.433346240751206, 56.90582882973456, 59.96189255868236, 56.556333880270685, 56.58795210622973, 54.46998203954389, 54.30794500535535, 51.732967822782456, 46.17393770525533, 51.59323730776387, 49.13589985139909, 50.867732186471265, 51.19053540691253, 50.70812309941938, 50.66285502526068, 48.927319972745835, 49.035942169927786, 54.16211128234864, 48.82960980938327, 49.337301792637, 52.837185628952525, 49.85422703527635, 53.122188968043176, 50.78298153415803, 55.40101935786586, 53.418473043749415, 50.73281834202429, 51.820377842072524, 57.822969190536014, 64.21108638086628, 64.57470578532066, 61.62502458018642, 64.872335233996, 66.5252887049029, 69.19690132141113, 68.7955722501201, 54.69460833457209, 56.89968247567454, 56.74628642297561, 57.47727109539894, 50.35316428830547, 45.352918947896654, 48.93212487620693, 59.42441017396989, 60.46304595085883, 67.46500230604603, 55.190733248187655, 22.61864765997856, 1.4057306464641326, 0.3954717162395678, 0.15428563399660974, 1.9158152755229705, 14.05544775147592, 33.66299675356957, 36.832205172508, 12.385270172549832, 3.2956465117393003, 0.30397461787346874, 0.17183079414309996, 0.246052379990297, 0.20044966330451353, 0.18401473309964905, 0.12302015322230517, 0.14689274763147678, 0.4398447239110547, 0.2000977071903406, 0.16226330591786295, 0.1270599646734134, 0.139638630432948, 0.28536205210032006, 3.62073328706526, 29.04207402660001, 45.20021715471822, 33.33608288918772, 36.39981877419257, 49.565442531339585, 49.36377386892996, 70.00354459208828, 59.98126906733359, 14.771035159787825, 6.710683597672371, 17.871491293753348, 96.14060340389129, 67.2725865148729, 120.03634929656984, 84.40985325844058, 0.9346082073546226], [0.38480801748171933, 0.6919264456918163, 32.39813435462214, 109.45242174210088, 83.98739830140146, 107.13269279849146, 54.58642152047927, 7.845366452970813, 0.0685767972120835, 7.6462443893955605, 15.234637741119633, 42.04826324216781, 51.10348624567832, 57.66434461839738, 36.28713692388227, 31.508846744414303, 15.456635067539832, 0.2822683745574567, 0.05305042047233832, 0.029849556853033365, 0.12441006654332723, 0.04454893210241872, 0.030372103510965264, 0.03913392770975348, 0.039120348801295605, 0.044851153788547364, 0.02616925322781167, 0.08103393078331025, 0.0479455437931803, 0.0494838138711789, 0.025691674015815222, 0.061615992097123984, 0.153197743178856, 0.05365934162851303, 0.0873964365511652, 0.04589714342728258, 0.042118594771431345, 0.05091575094528737, 0.03665495145645353, 0.12965953848775358, 8.90486482651003, 47.57544763626591, 77.87760073138823, 70.63626996932491, 68.06783922256963, 64.81382916050573, 61.80601842941777, 69.44308496290638, 67.20949126828101, 57.09263170919111, 65.812774473621, 71.67017536778604, 74.50247964551373, 73.00830764155235, 67.11206743794104, 68.37227006112376, 61.806842127153956, 61.58898192067301, 60.9714400383734, 57.178841483208444, 56.83381411337084, 49.79209669174687, 50.91527131295974, 50.49334979826405, 51.27655298479142, 50.845100110577, 51.160399836878625, 47.8870681793459, 50.53830016043879, 50.025905255348455, 50.10955764401344, 50.19367679472893, 48.706012002883426, 48.1712870444021, 49.83353653261739, 46.67406735881683, 48.24973837021859, 45.92117624898111, 44.886890380613266, 50.276105403900154, 48.982064493240856, 54.7241477043398, 55.241524019548976, 53.640898889110936, 53.747277490554325, 50.97314588485226, 50.857922338670306, 46.85392764306838, 47.03153648684102, 46.74096730447585, 51.09080130054105, 50.63983071234919, 51.17434778521138, 53.97112323391823, 54.038646836434644, 48.156946859052105, 48.25801849365235, 43.90683912461804, 43.9692283445789, 44.561227752316384, 43.825328350067146, 44.694560881583925, 47.80544757843018, 46.019102142703154, 44.97721864331154, 46.51231665765086, 46.83065229846586, 46.69378511367306, 46.007993990375155, 46.34922842825613, 45.656031870072894, 46.02264012059858, 46.49067694141019, 47.188839220231586, 49.615856755164366, 46.42749540267452, 50.27064546462029, 53.74823847124654, 54.94966045502694, 54.09314032523863, 55.85691252062398, 55.30117150275938, 57.20361125084662, 57.84007856922766, 57.03830295993436, 57.839945208641794, 53.70795180720668, 40.24527126742948, 37.38981323857462, 32.692143455628425, 27.59036167975395, 31.831602896413496, 42.78915974401659, 28.23067095971877, 2.1068702493944476, 1.364841163158417, 0.15260137437332064, 0.024449845490556572, 0.0136677669962087, 0.032812610659147465, 0.059944468685576034, 0.13723938094992794, 0.4293210966692817, 0.16954167746007445, 0.2287995743174707, 0.3389477267140343, 0.09139562235964883, 0.025863183865083322, 0.1020208481819399, 0.08502067532390357, 0.061983568744072993, 0.03810402974786778, 0.09763666488710912, 0.049146225736025846, 0.08212886194908812, 0.035458977123902696, 0.023857496731403856, 0.12771445656976393, 0.05057776827485331, 2.108397767428429, 15.128175789310088, 22.695847749710087, 22.22276479967179, 13.51831445770879, 13.224787808233692, 9.005747206749456, 17.259907491745487, 56.07170935600035, 23.30269725091996, 2.0484368623264375, 36.763304818061094, 57.02737915900446, 61.28040905921691, 75.49778107673892, 41.98661535016952, 0.130467209664564, 0.4369842128888254, 0.700843709130441, 35.45025610154675, 122.56714097915159, 91.83599825828307, 108.03711291282409, 72.60182457585489, 13.586886313653762, 0.06468796636909246, 16.21635110147538, 24.773823368933893, 51.47308334227532, 62.44805943581366, 68.50251628506568, 34.88365011830484, 31.002513862425285, 20.54533181651946, 0.24672382541241186, 0.14443979538496465, 0.10286592743209294, 0.0818757005336304, 0.10389195664996102, 0.0507086850402336, 0.04042553662833187, 0.01736310892738402, 0.03793711834136517, 0.013784244919436113, 0.047235483709242077, 0.010667558883376902, 0.05984264793955992, 0.06339492103565605, 0.020953010347101, 0.04711422348214735, 0.01595455285672459, 0.004059388828013212, 0.05032575216084238, 0.028259775023006146, 0.06034858006563398, 0.08229900241619156, 0.17506016117911186, 1.7136292279727998, 28.82642995926642, 67.70728711158999, 75.68228152490433, 74.20066110549435, 69.7711363146382, 63.743465331292924, 70.90533671840545, 71.56501662346625, 60.35400406006844, 71.7581384412704, 73.40676553787725, 74.13055266103437, 75.68345039121567, 69.07762204447101, 69.65894083822928, 63.872146529536096, 64.63566334016862, 62.0288678907579, 60.80235842735537, 59.42831685466152, 53.95349217999367, 53.235647447647594, 53.52094496450117, 52.93714331042383, 52.7394127076672, 53.78287299986809, 51.16320040918166, 53.05585384368897, 50.07952797797419, 49.147086451130534, 52.56993885963194, 52.52589848733718, 51.493695397530836, 52.196799862769346, 49.181599386276744, 48.30623619018063, 48.113251655332505, 49.675794493767526, 52.170610197128795, 51.782989809590006, 59.14620822475803, 55.78027725219727, 54.35284829908802, 54.93306882919804, 54.13107748954527, 54.02247882658436, 50.57998318825999, 49.174488129154334, 46.51644299107213, 54.61836530316261, 53.79940186777423, 54.54486400850358, 55.44716604294316, 54.36539596126926, 51.28160891994354, 51.645891204957046, 49.99494990994854, 47.69648413504324, 47.89017469652238, 46.69360076227496, 47.64184944091305, 48.00067963138704, 48.35599145581646, 48.45339567430558, 49.221289850050404, 49.567788108702636, 48.818066273966146, 48.67537829183763, 49.03117649016842, 48.17367184546686, 47.98438218332107, 49.78373027616932, 50.19193526237242, 50.87633394425916, 50.36719460641184, 52.6497551702684, 56.63902921061362, 56.10304124893681, 57.93499600502753, 58.8522893382657, 57.45443505625571, 60.17017825957268, 60.28942223518126, 60.53620599931287, 60.70455412710867, 59.0002921319777, 44.63281100796115, 44.084483269722234, 40.15311910260109, 38.1057438542766, 44.377327426787346, 50.14725554373957, 24.029269256899436, 2.027672079782332, 0.5579147463844669, 0.13530480975825943, 0.11689851315872324, 0.09060354107209752, 0.02083622407348406, 0.0580798528127132, 0.0995502376087731, 0.18041162240889766, 0.10572027144653183, 0.22337179540866808, 0.2196604058506989, 0.01912751475409154, 0.06673351305747224, 0.07137072753281364, 0.04226073089446272, 0.0575147825293243, 0.03947882815414379, 0.10299279159235378, 0.04190753371785245, 0.04225891143564255, 0.04229188385990359, 0.04457615503680803, 0.040137242420666644, 0.13838763949611496, 1.9170622215155635, 32.14683005886693, 33.17474403688985, 27.853389939954205, 37.701261197367025, 34.51905012130737, 17.76439097619826, 40.41931075434531, 63.90418837147375, 31.944590691597234, 14.220522661362926, 54.23024677461194, 64.08819852336761, 70.1128924277521, 87.86674791766752, 41.28577409252044, 0.31825486450426044, 0.5025469980412914, 1.117084406075939, 47.7400577452875, 126.06289063730549, 105.3243624779486, 111.71653932140721, 93.38022755038355, 23.608967681084913, 0.24244148584623493, 16.595912979495143, 33.721322398031916, 68.766797742536, 73.17380812860304, 81.53611306221255, 47.790381754598315, 43.47086375759494, 26.639404604511878, 0.6248550801988572, 0.36268722866812064, 0.2005719922242626, 0.3021497351507987, 0.1816407951616472, 0.12399324576460546, 0.13345505982156725, 0.10251709695665107, 0.19226444284281424, 0.1804893956549706, 0.23320355332426487, 0.1610806653456342, 0.253418070234118, 0.13189930378669693, 0.16220014962938525, 0.2068887395604003, 0.13111574905774287, 0.2545619927226536, 0.2829021744189724, 0.19949412183655849, 0.18414322136630937, 0.2379138296049449, 0.3160774587623535, 13.214644558968084, 57.8921833345967, 88.42748995750182, 78.7173488063197, 74.74580780152353, 69.85185084804412, 68.29180655940887, 82.87818339563186, 77.09788060957386, 61.37576580047608, 72.72255512975877, 76.27142936952653, 77.41531802761939, 80.76160184798702, 72.79278909006428, 74.91965509230091, 65.69633499268564, 68.96599923410724, 66.61549537412583, 62.62932000621673, 62.721287819647024, 57.01532179309476, 55.007460501886186, 55.006660338371034, 55.672839610807365, 55.99006522086359, 56.890272709631155, 54.557188095585, 55.36812636160082, 53.52231779406148, 52.61064129491007, 55.99828258637459, 55.06594696352559, 53.38549375534058, 56.5138977573764, 51.55133070484285, 52.29730667606477, 49.550910149851155, 49.85824354233281, 54.5433303617662, 53.633944526795425, 61.486419785407286, 58.93078773252426, 58.65937148371051, 59.35397617278561, 55.71152594781692, 59.13479020518642, 51.76108337217762, 50.56986347321541, 51.246633145116995, 57.81746218281408, 55.17844054006762, 59.13223674220424, 60.568451804499475, 59.94140994164252, 54.09441509554463, 54.614670430460286, 51.353243166400546, 50.508639197195734, 50.40352752131801, 48.686439375723566, 51.21093173180857, 50.85166223587529, 50.99666833877564, 51.15011930465699, 51.62994677020658, 52.70038512445266, 52.10378477650305, 51.36188807026033, 53.2164199890629, 51.370434914865804, 51.08062667231406, 53.27273737999701, 51.329924675726126, 54.60591177786551, 50.77100653802195, 56.51961657308764, 59.33100285068635, 61.97896357505553, 59.1501933528531, 61.085286832624874, 60.49989269625757, 63.99903520461052, 62.92575313198952, 64.37223303702571, 62.63720004789291, 64.87908563306256, 49.44334699261574, 56.42786056764665, 50.39343918523481, 48.827997715242454, 63.4906489618363, 73.21226304577243, 51.696258360339755, 22.766209187046176, 1.6456742873114925, 0.3910435135326078, 0.2844514799935203, 0.14865960685476182, 0.08653202124180333, 0.20756999090794595, 0.37442498269581026, 0.4003720436125033, 0.15427860130946483, 0.43506516263850276, 0.4913330642927078, 0.22291672385988698, 0.18982776230381382, 0.23778259874351565, 0.1973946885235848, 0.1448540344473816, 0.20919072652055373, 0.2507246429881742, 0.19141531098754178, 0.19770950469518864, 0.12089830417666705, 0.1704069124835153, 0.17356818962481715, 0.26987610565077874, 2.755605515933806, 44.417884734369096, 42.09763803789693, 27.113360281913515, 37.63583998526297, 52.99103667659145, 37.177934646606445, 61.63121015794816, 74.31760264981177, 44.73567908810031, 20.46474279895906, 68.43347472529258, 78.50334428971814, 91.19326299236667, 115.51368390360187, 65.77808895418721, 0.5714265761836883], [0.28740140879827164, 0.31740383275093575, 18.35047152734572, 104.92413951504616, 75.13597380730414, 117.66455481129309, 63.894609943512954, 20.70435647041567, 9.834519509346256, 26.800333569126746, 36.80631360700054, 44.48271759094731, 73.48444415676978, 59.73488538495956, 30.722448787381573, 37.52543310965262, 15.496994295427877, 0.4109412071204955, 0.022027241817164808, 0.15334464819921603, 0.04394825405230926, 0.08457016965915119, 0.04345180992517741, 0.07844040140269265, 0.028823343774063453, 0.08287022055517282, 0.050150180130355784, 0.028831401103807074, 0.05262920617937081, 0.05411534397412212, 0.041693412143016056, 0.018627268915635445, 0.03726045586048596, 0.0539180227074652, 0.050783282851860415, 0.08433305778570714, 0.053039212606006095, 0.03945773009270911, 0.05364734086117918, 0.047195244941019246, 0.2911454949888491, 0.4462845202895903, 13.820611526889186, 39.010662109621116, 54.55208116962064, 58.665525682510875, 52.975660985515965, 51.195861985606534, 58.8550663763477, 61.052978269515506, 68.67337472977178, 70.0032151129938, 63.975850074521965, 66.0170985806373, 65.82907584405714, 64.38397661332162, 63.09214007469916, 58.529929345653905, 56.38473410760203, 58.82739405478201, 57.04825401306153, 50.16261946770453, 52.03176613776915, 51.28786117799821, 50.25183769964403, 48.4378787779039, 49.76050592237904, 49.78068259454543, 49.12133609094928, 49.73595972984068, 50.44724625925864, 50.32165981108143, 49.064720599882065, 48.22366245331303, 48.64183810449416, 47.389390007142104, 45.810392825834214, 48.8547835811492, 49.99742100315709, 47.11875038762247, 53.18092646137361, 52.91964169471495, 48.026783004883804, 49.862687587738044, 53.33011381087765, 51.19816833926786, 47.12547333009782, 49.080300254206506, 47.88040407242314, 45.66416686581027, 49.647914286582704, 49.586639019750784, 50.086521563991425, 50.29112415928995, 49.03913105687788, 51.68095327192738, 47.45548978928597, 46.014038362810695, 46.28023393692509, 42.940912323613325, 42.850081997533, 45.618467330932624, 44.84796085665303, 45.6305129297318, 45.63349000869259, 46.09416846306094, 47.11551050986014, 45.09061436499319, 43.43876308010471, 45.5356268728933, 44.55279857881608, 44.875464516301314, 46.15773831644366, 46.76465449794647, 48.443354406664454, 47.01035176554034, 52.81484380845101, 51.556590603243926, 49.96585769038047, 54.82851412988479, 57.537471632803644, 54.390907056870006, 54.84000667448967, 53.37635855520926, 57.270193484521684, 53.231313228607185, 51.04714924289335, 41.588220211767386, 34.105632305145264, 32.205849962849776, 25.280925035476688, 20.474054505748136, 7.495500839525654, 0.37123183629685835, 0.360970548203876, 0.09279558675423746, 0.04430240117794564, 0.01603824796245223, 0.07202711932721638, 0.0988200638863829, 0.041945600626809944, 0.02673121127900818, 0.07749855758682375, 0.037844509802638523, 0.029104051796058496, 0.1044324699849371, 0.025690846640857, 0.06293555939449899, 0.07115608501818872, 0.08281176804655022, 0.02972804956258305, 0.05467252355189093, 0.07916028656425976, 0.0622109896052749, 0.07046389393508434, 0.03034810580673718, 0.08819503724695214, 0.05300696030439389, 0.1345204582978641, 1.889611268716474, 15.334824881246014, 31.184152941549982, 28.66095692880692, 0.5779412653177016, 4.354614875008983, 0.8737809487408208, 6.884669642294607, 22.653821514498805, 21.156815598087928, 18.816007837172478, 21.53142744495023, 43.72731616420131, 44.866368539871715, 42.4757545225082, 6.178393450475508, 0.39076995885660576, 0.1471297292699737, 0.3586018656290347, 16.81154331853313, 113.12606657705, 83.9421106153919, 121.31152752907046, 82.45696790756719, 33.781919094824026, 21.7950342547509, 46.781559913389145, 48.294684810023156, 57.49981295677924, 75.9338152793146, 61.568856239318855, 31.906271096198793, 43.45658240779754, 21.14329714928904, 0.38178540225471225, 0.05061891102682679, 0.10537117284031645, 0.02956842939789978, 0.03909746575499735, 0.04398207300372663, 0.1225216674708551, 0.02822640997868392, 0.02028912238235916, 0.08104790422704913, 0.06322184262136299, 0.05398788609571996, 0.06794890388846397, 0.03810869905376627, 0.047662635183622765, 0.011840631975041283, 0.03181883182767178, 0.021452078325373512, 0.09450066098642927, 0.06496798682717547, 0.049027489768641616, 0.05552488829820387, 0.03638090648417992, 0.18279821611940864, 0.4753426642667863, 2.7768922188589653, 23.571503162384037, 40.558664721827355, 56.94078499271024, 58.44911675299368, 57.36435390287831, 65.75051076950567, 65.43961586490755, 71.35862934973933, 74.18090020456623, 67.79602681436847, 66.46571574672576, 67.44867740138885, 66.93467432452788, 63.877084793583045, 61.72529212890133, 58.433490030227176, 61.99536692711615, 61.948792703690074, 53.70556308377174, 55.11223093155892, 54.52439708094443, 52.928004187922326, 50.61512762500394, 51.82099757655975, 51.7869004126518, 52.41903351199243, 53.652999401092536, 52.81279240885089, 51.518100384742986, 52.16643679526545, 51.45036497423726, 50.242212203241166, 49.83132039347003, 48.453481966449374, 50.002888787177305, 51.76827307670347, 49.08916481079594, 57.25380974431192, 56.12907794214065, 53.31896251247775, 50.62108962766586, 56.52682196709418, 53.42653743682369, 49.717352005743216, 51.65219837619413, 51.569071585132235, 49.08514830373949, 52.99973649363364, 52.21217555384482, 53.00582008977091, 53.23892262674148, 52.01651596253919, 54.393335004006666, 49.70927976792859, 46.771216623244754, 49.13944567403486, 46.71371859888877, 44.32378315156506, 45.34153230728642, 47.35809341553719, 46.571669963098344, 48.981742858886726, 49.0050535048208, 49.23297459079374, 48.89384646569529, 45.724332101883434, 49.0019352205338, 48.29472403372488, 46.0873592284418, 47.80645954993464, 50.81120690991802, 50.22519696143366, 50.91267078153549, 57.15568773208126, 53.59258313332835, 53.978834613677, 58.00253921939481, 60.17053519525836, 58.51488705604308, 59.034353994554095, 58.31901565674813, 62.901583486987704, 60.132335232150176, 57.98559065788024, 52.36516368004584, 41.19064877110143, 35.917214270560976, 23.73451098319023, 14.748451132928173, 2.9442774047774654, 0.7213350902161291, 0.2171292513488762, 0.07837362917921237, 0.030238666316314094, 0.07265599324337899, 0.19441048494510113, 0.014319621634879902, 0.013051514378598621, 0.06536265234312703, 0.07964322073084694, 0.06769745850995665, 0.11628372759948816, 0.1195657018932604, 0.036118827805283575, 0.052465991147102854, 0.02618689814792766, 0.05427121605363585, 0.0203621861029176, 0.0037307878618218727, 0.01393289183221397, 0.027138812189561226, 0.0816952791665831, 0.023600903242045355, 0.10708627516343709, 0.08176136957181078, 0.3122928005553061, 4.498238342423593, 33.08071305674891, 32.391268245635494, 32.367553595573675, 22.405502142444735, 12.36374322445162, 3.59899404068147, 18.944196777959025, 36.29941002015145, 39.78616568350023, 41.70652281853461, 32.676448091383904, 55.9311943669473, 57.544174963428134, 58.812375299392215, 3.327390743840126, 0.19164797189014574, 0.33955698111845606, 0.6033236581471659, 26.392348235653294, 129.27484112401163, 95.09250687014674, 127.9798549221408, 97.25293267157771, 45.90157616523005, 28.601821314904, 64.00360476586127, 66.32911528310468, 67.97908383031046, 86.14661601281936, 75.39390886983564, 42.90967064519083, 58.462229236479736, 27.23345737303457, 0.7063945370816416, 0.23674387544874223, 0.20725344337763327, 0.16729616650169896, 0.07946739589134533, 0.26252607424413005, 0.2201709268434394, 0.1612815642428975, 0.13500025916484096, 0.20893148236697723, 0.12040187154085406, 0.16646611023574107, 0.142810923918601, 0.1256744486970767, 0.12381608027123636, 0.17923340982487126, 0.15341912726721457, 0.13192761839637834, 0.1907876398294203, 0.23933997888478542, 0.22365163200564925, 0.16218559395882393, 0.1466191163466823, 0.6079866208376423, 1.0009945676692071, 20.341415636001095, 53.80572865086218, 68.42396689999488, 73.96365581020233, 65.40349475799069, 58.71084082511164, 68.64122698383947, 69.87715013565557, 75.87655651953914, 79.28352725121283, 69.43861346090995, 70.54613390276509, 71.72607698748189, 74.47269316642516, 69.48977685743763, 64.02876677051668, 60.79838114400064, 63.74519901890909, 62.567413237787065, 56.861529581008426, 55.89295910250757, 59.408889355198035, 57.97583180089151, 52.72213074468797, 55.185618477482954, 54.24080187274564, 55.683841859140706, 56.487194261243275, 56.79434330232682, 57.24470984551215, 53.78360256072014, 54.63998148518225, 54.02119621153801, 52.90405811802034, 50.381095486302534, 52.05092691606092, 57.27137411794355, 51.94069262473814, 59.65342952359108, 60.449768727825536, 55.09046569947274, 53.37209101646177, 58.84720986889255, 55.6964954253166, 51.71742346978957, 55.34316832019437, 52.924226945446385, 49.98405356560984, 56.995152965668716, 54.415598377104736, 55.846008331544944, 54.48942522848807, 54.59531353365991, 58.558276314889234, 52.20016133400702, 50.64539263325353, 52.03550023417319, 49.07002756672521, 46.97480724703881, 49.43138376359017, 49.722078461800855, 50.473851696137466, 51.74549195074266, 55.4505745826229, 52.41117700453728, 51.77589031957811, 47.68826676953224, 52.6597297576166, 51.57340972654281, 47.783909843813994, 48.75067995440576, 53.638419951162035, 53.92879301501859, 51.496743079154726, 60.233206825871626, 55.17548307295769, 55.193796619292236, 61.49282893826885, 63.45233132762294, 59.22794257440875, 59.953310412745324, 59.20027417521323, 67.06833301051971, 63.50287891203358, 67.85258739225327, 64.67048614255845, 56.10542212763141, 54.07931397038122, 42.220529817765765, 30.28235689286263, 13.079932716584976, 1.3532938279451863, 0.5048820646780153, 0.276533501643327, 0.19256340099438546, 0.12239632016468434, 0.273904747539951, 0.22600687739829864, 0.20077764086665648, 0.12507447161741797, 0.185007629014792, 0.13699188858510988, 0.2423792335415079, 0.21288095673005428, 0.14001431995101515, 0.25104518949745164, 0.15765301943306, 0.18660147494125753, 0.10421581265907134, 0.23197637240011848, 0.18549840026084455, 0.16112319854719026, 0.1321843497815632, 0.14498911107019072, 0.22113903215335262, 0.18786101541932554, 0.2866638193447744, 5.223317886552503, 49.5392567880692, 37.94865292887534, 52.70886921113538, 29.64667404851606, 21.930067731488137, 5.2979316634516564, 52.35855840867566, 50.896541995386926, 51.23434435936713, 56.966704014808904, 48.10589328888924, 85.26220783110588, 82.1224368003107, 105.0809637192757, 11.723919337795628, 0.5708862696924518], [0.23137497805779983, 0.5163788687317602, 7.107302392682723, 79.56299612599035, 90.54138860394879, 74.41591293581071, 73.24328114909511, 67.7446045414094, 74.70698418155794, 62.03801093562957, 54.48485566723732, 63.916963531124985, 87.3722311758226, 73.36887544201267, 23.394363041846987, 25.065331958955337, 8.510264581249606, 0.7243870006453607, 0.04456797321777671, 0.0744107329557019, 0.06575519579552835, 0.009719613177191106, 0.017132160231290806, 0.12374027587112882, 0.017346517378163916, 0.17053218318089364, 0.10538253392423354, 0.056124689177640026, 0.03466379701069767, 0.11090363000309277, 0.029352095744182027, 0.08678637775442294, 0.057709146696593494, 0.03204276507359839, 0.024635700336206826, 0.0068600075751272666, 0.022946003403875138, 0.0958013327251519, 0.03233516551253777, 0.0660046187019156, 0.11981676422780561, 0.14839221152567095, 0.3132417996323878, 0.32830146411734246, 3.8238220926254027, 12.268027586321677, 23.991569395988222, 34.21616469660113, 49.93051321275773, 57.91570578852008, 58.35174783583611, 61.70238548709501, 62.26737545382593, 62.45255839440131, 60.7570432847546, 64.05222254414713, 59.18483964858517, 58.634487967337336, 57.566014720547585, 61.0606582703129, 59.963771373994895, 53.94805185256466, 49.887775067360174, 49.67701827326129, 48.453246624239036, 50.13632389806932, 50.716795459870376, 47.618193626403816, 48.68536464629635, 48.286714553833015, 46.11593369514712, 50.21923103640157, 50.20915054505872, 47.19110242782101, 48.261470179403986, 46.450562861657914, 46.99033983292119, 46.589956052841686, 47.81208422876174, 47.216742961637436, 52.267543731197236, 50.90656757354737, 54.362705215331054, 50.49777815418859, 49.83494074113908, 50.23173555251091, 47.26720425390428, 49.72367486646099, 49.82908464247181, 48.18710204093687, 49.86829265471428, 52.24368003106887, 50.1257295762339, 51.346092685576416, 49.28254942740164, 51.06217192065332, 48.47459608508695, 45.7718006257088, 46.14255089913645, 45.02636594157065, 43.45465652404293, 44.25186649445565, 44.280142861027876, 44.12226353922198, 44.57544634419103, 45.3774376838438, 45.82314052889424, 45.313267707824714, 44.944545299776145, 45.53728211310602, 44.58247915390999, 46.05278353537283, 46.370083670462336, 49.40940280114451, 48.436992322244954, 53.87750802501556, 53.52368670125162, 54.34066933970298, 56.463589437546275, 57.92140107001028, 54.86762408287295, 57.959730471334154, 56.98626879722842, 59.50392053973291, 57.08389659081736, 56.25827297087639, 37.09452936726232, 19.50067912378619, 10.241479143019646, 2.6896780729293828, 1.0300034981581474, 0.8454268702095555, 0.41875974725811715, 0.06344934009135732, 0.03252877125276193, 0.08758841052411065, 0.10420082797927242, 0.11198502439524859, 0.05328159516436919, 0.05680876738962628, 0.015958480972556338, 0.011156388096541408, 0.0373057623003279, 0.10101011007904045, 0.049441725000618934, 0.008572541109676804, 0.08467425802542318, 0.02864376318851306, 0.049746915277454166, 0.02573024079714331, 0.06284780019233305, 0.06475263951166023, 0.10908825443156304, 0.08751025423407556, 0.06972638875125878, 0.05260736884308919, 0.08175743954075922, 0.050908833171331117, 0.12313930287716851, 3.9669584506942384, 20.705695959829516, 31.166304196080855, 20.587205079294023, 1.5442209570638596, 3.025888444915895, 2.0823902468527518, 21.191010821250178, 28.822193799480317, 11.91130861159294, 10.31108650469011, 18.02766046216411, 26.835719231636297, 19.807955641900342, 13.68966123750133, 0.10302913480348165, 0.1555807975631568, 0.14603685888071216, 0.2582515181312638, 4.444130226489037, 85.3881629820793, 99.59035934940462, 80.072143308578, 82.6251434510754, 86.86732015302105, 85.66365457350209, 73.498949081667, 76.57469134176932, 80.42015167974657, 97.8137610035558, 87.1555280685425, 25.870845587022846, 39.56757199379706, 13.843229874487847, 0.6239645183086395, 0.10232703054263707, 0.11598241755798941, 0.04541741533865852, 0.10329577936640671, 0.02758618838514292, 0.07524140209199921, 0.02656189627164314, 0.09962815641155166, 0.08628516472996244, 0.04472887083407372, 0.03700547498620806, 0.007393545679552782, 0.019297574781962944, 0.03200298404291032, 0.04845003567395672, 0.03671833374086888, 0.047513971991476514, 0.035513304249053045, 0.11883215738400338, 0.06908646018634881, 0.0676879283761786, 0.0585315803877048, 0.15812765686742722, 0.10412526106642139, 0.3608134695358815, 0.29922012299779926, 0.46224645248824553, 3.4499979067233304, 15.292389738944271, 30.48500026426008, 56.42307135366625, 67.5113647214828, 66.46933217202464, 68.19316679431547, 65.75542549933157, 66.39728607669954, 64.62168009050431, 68.00344174908054, 64.07721196451496, 61.51865774585355, 61.29496889729654, 65.4884768301441, 64.18616364079138, 57.742635127036806, 52.229532041857325, 53.10566794487738, 50.47447535299486, 52.92970649657711, 52.23345048965947, 52.33016829336844, 49.46394728076074, 50.69606181113951, 50.40199779695081, 51.84716763034944, 50.85925202215872, 51.0297143074774, 51.20721724725539, 49.65187195808657, 48.95729472560268, 50.001888582783366, 49.96711284883561, 50.171291828155525, 54.35308364129836, 55.258052887455115, 58.06585411871634, 52.565788991989635, 52.67251276200818, 54.08989260273596, 51.03260901666457, 54.54645256842337, 55.547657166757894, 51.0403556977549, 51.93427170476606, 52.97670041361163, 53.01811672026112, 55.39900718196746, 54.21449845837009, 49.800753362717174, 50.796600003396314, 47.17428330452212, 47.09288627870622, 47.434744373444595, 47.362415867467085, 46.842391952391594, 46.13370595439788, 47.92828052274643, 46.40898966020154, 47.481208770505845, 48.45228956591699, 48.7266162133986, 47.142182627031886, 48.41041434195734, 47.363541587706536, 49.367472664002456, 47.69115755634923, 50.09694330153927, 50.82548433734525, 57.48560220964494, 55.685446108541186, 57.979624732848144, 61.316604691167036, 60.131217356651064, 59.69546948709796, 62.675235271453865, 60.62932698957382, 62.50996228187316, 62.88892207607147, 59.35177180074877, 36.062620455218905, 16.011065033174333, 6.509159572662846, 1.0086953447711084, 0.6584518354746604, 0.6881330234389151, 0.20612816746917464, 0.12092529345423945, 0.0832429299912145, 0.05161428140596517, 0.19444572498961804, 0.07339778851958052, 0.020981187060956034, 0.027642721843515194, 0.022192431441057595, 0.0814643343009295, 0.03384178849838434, 0.022392340169678775, 0.05528848122565016, 0.04214071556024494, 0.030064716477007158, 0.05673909935379221, 0.05430757841696182, 0.009692843192287031, 0.05636862689448942, 0.0395028296888115, 0.05949683202010009, 0.12078106208073518, 0.018514663566865267, 0.06015865537788599, 0.09390320433604141, 0.1336255603499951, 0.2665804873310751, 9.020237422758534, 32.66949372906839, 36.85563348954724, 28.954383557842625, 7.984202667590111, 3.2403337378655714, 3.0350135939736522, 28.40170983345278, 31.047980016277684, 19.01446996196624, 16.169284620592673, 33.01480547074349, 35.9955479252723, 22.318137230411654, 6.293963636121442, 0.1130949785452216, 0.10737802442764083, 0.4646240523265254, 0.7789772003889085, 10.186535562238387, 107.96031290485014, 111.46892793716924, 96.39017597321542, 84.97800073316021, 99.84172836426767, 94.8971571460847, 90.29897043781897, 91.10172271728517, 100.06088687527566, 106.33906395204606, 90.3343423720329, 29.949626153515233, 50.81209336557696, 23.12819100195362, 1.1419492911907936, 0.21188891883338654, 0.183046413285117, 0.19676914708989282, 0.1830743295290778, 0.11365803018693002, 0.17239147857312234, 0.09983440260252646, 0.14802617471544974, 0.1566775290355567, 0.15862903077035181, 0.09529244349969011, 0.24542055663562592, 0.20866499102163702, 0.20801301955455737, 0.13227186766603302, 0.15968612485354947, 0.24357154214334106, 0.12452229076335508, 0.1598261197608325, 0.15782298369994088, 0.15838349959061993, 0.24116564301713822, 0.5115724024513076, 0.24011561226460243, 0.8490215386113814, 1.0319887077616108, 5.843404896797673, 18.95952343940735, 45.62466075343471, 66.6714911307058, 74.32197217018374, 73.47080215331047, 69.63109201000583, 71.36766649061634, 66.39831373768469, 68.48254357614826, 67.40723363814816, 70.0222856767716, 65.75885757323235, 65.40318881311725, 63.819214144060695, 65.85108034072384, 65.3414075605331, 60.36748132398052, 54.4470283292955, 56.58457886788153, 53.89102451262936, 55.86658508546891, 55.4026863651891, 52.948879041979396, 51.200192282276774, 54.01923894882203, 51.913922448312086, 56.49579994140133, 56.90484823719148, 53.145864394403276, 54.1397027815542, 53.307889661481305, 52.98299974010837, 52.48918118015413, 52.073092229904674, 52.34443395368515, 58.180705039731926, 55.75277751491916, 60.37056822930614, 54.171889751188225, 55.27961023392216, 56.388495660597286, 53.96782059823313, 57.28032888904695, 56.20133192308488, 54.88303115290981, 56.96125976500973, 56.98249939949282, 55.06993601399084, 57.210647982935754, 56.95025359430621, 55.058019853407345, 54.3069879470333, 51.31119928052349, 52.57662650077574, 50.79017123868389, 51.24143992700885, 51.746872625043316, 48.463735042079804, 50.10363094268307, 50.076197885697894, 51.69463057671824, 51.303789923267985, 52.63263402446624, 49.636857125066946, 50.94349276634955, 50.165341592604115, 51.39628725667154, 51.44123761884628, 52.70218941473192, 53.48565147769067, 59.72778981731784, 55.05852976152974, 59.44022909287484, 62.32445378457347, 63.32648600301435, 58.54789380104312, 63.70633617524178, 60.24632323172785, 65.06261333342522, 63.97032345494917, 64.53710202247866, 53.15497998268374, 35.782237668191236, 17.06774861581864, 3.6252886297241336, 1.1415626925806845, 1.0402157566239758, 0.5630155436454282, 0.31129130913365277, 0.18683428906144636, 0.2361699223758713, 0.2973646886887089, 0.19555036248939653, 0.08925699598846898, 0.13259051427725824, 0.32922567258919444, 0.15673127776432424, 0.20136048055944905, 0.09834037027171544, 0.15423361662655108, 0.11033255742081713, 0.12134242832901017, 0.15172475528332496, 0.1251167137055628, 0.1293497938182085, 0.14415966767457225, 0.33672070911815094, 0.23648299186700777, 0.39611244153591896, 0.25812637000795335, 0.2726085574155854, 0.18379590774495758, 0.355604378085944, 0.5038270390322132, 14.804210566705274, 46.85232731603807, 52.152661431220274, 58.78988442882415, 9.301349770638252, 4.603802561759949, 4.446913638422567, 45.638255688451956, 60.14277265917871, 31.48337683370037, 42.40659921400009, 62.499717050983065, 80.51113497826361, 70.09445728794222, 30.535806725102088, 0.32810212803944466, 0.33953366140204094], [0.09328248159539315, 0.14367531624532517, 0.21155691164876186, 46.4426592857607, 68.99496986019996, 90.97657557456725, 64.36114057417839, 50.01358901300738, 49.14405053661716, 32.448481898153986, 27.489319462930005, 41.549930034145234, 60.90612473026399, 33.63709734332177, 30.849598300072458, 33.55744577223255, 10.357302811837966, 0.5140736488805664, 0.03137401245053738, 0.06263182085428028, 0.0767659783483513, 0.05896718947276954, 0.05338157346892742, 0.07445860579009018, 0.01946238519233321, 0.054596539121121175, 0.09878576613001286, 0.03257801538453468, 0.053144971043953014, 0.07644331743640286, 0.060643435816370675, 0.024991101930819215, 0.03497709632821141, 0.034235002277719404, 0.04987159991757043, 0.043204141360136776, 0.043764408272240436, 0.07680033739175528, 0.09527857730826063, 0.14101624038190613, 0.10924428355910125, 0.05219302635880248, 0.1210054262511192, 0.052037426240501866, 0.06849589832727948, 0.08898005520384158, 0.3051309203428607, 2.9963909954793992, 15.859031023517733, 45.561404689665764, 60.13851688754175, 64.43364950918382, 61.49667286103772, 66.61571502685547, 64.87812073000016, 65.38685606371972, 63.664037335303526, 61.91466416082075, 62.46867149106918, 64.74278719194474, 60.73158710233627, 63.19720075976465, 52.632696782389, 48.14475613255655, 51.453887262652, 48.049956367861846, 49.36969664789016, 49.64404290722263, 49.73976050653766, 47.972870026865316, 48.64659593951318, 46.44031370839765, 48.57340451209776, 48.32434185089604, 46.06131469049762, 46.23292623027679, 47.700367281513834, 45.582667858369895, 49.42511581605481, 48.73221735800467, 51.677254476854884, 57.16248127721972, 55.76443479907129, 48.98425709816718, 50.185859510975504, 51.58407465104134, 47.64968633651734, 52.55118208546793, 53.66158546939973, 51.09035807271158, 50.20813072881391, 50.776344883826475, 50.84191122362691, 51.16187464806342, 52.565573261630156, 48.06348070021599, 45.26435575177593, 44.17327788568313, 40.47008975859612, 43.35724838318364, 42.471553664053644, 42.44913731851886, 45.985922813415534, 44.62723339757612, 43.89146735591274, 45.772538031301195, 43.3262106680101, 43.58934287101992, 44.027291190239694, 45.599106511762066, 42.52457234167284, 44.80063746052404, 45.25850749784901, 46.43955276858422, 52.11116275479717, 59.1164452798905, 58.277838614679155, 54.491963001989554, 57.36117286066855, 55.483083186611054, 57.97068172885526, 56.99936166886361, 55.945307054827296, 59.04932175913165, 45.20364138387865, 31.457047923918697, 5.986553267125161, 0.7263663266935657, 0.3446593718422998, 0.4267224651430884, 1.9877237201698366, 0.7809845958986591, 0.028137741047107888, 0.0022597738397082375, 0.09119354368698213, 0.08756140592477976, 0.08319801425621395, 0.039615440783241106, 0.15066655803351633, 0.02878834121680308, 0.06146792262311905, 0.049352303387657295, 0.009682876388392141, 0.022071667255893834, 0.05039402591665426, 0.06096450326543662, 0.061893036303621154, 0.021116483934043397, 0.04139085720864035, 0.04718744233551045, 0.046306280344123804, 0.06268746565066038, 0.050202829522951964, 0.062480836415723454, 0.0831338620534347, 0.10038004106571598, 0.06838088554720725, 0.09914614921135288, 0.23976944777513706, 8.169343932982414, 20.243881979296287, 14.339549926019485, 5.528508194031255, 0.5754794264512678, 1.0111537515636415, 0.7878971604570266, 11.070581905303463, 31.4489148893664, 19.465979876056796, 11.464226072834386, 4.893880467261038, 10.044028989730343, 9.910240865522816, 0.036801902442089016, 0.10531153289541122, 0.09585748697000165, 0.06339788196548339, 0.048326726161664536, 0.15599537370426042, 38.00591168865081, 81.2471991200601, 104.42154269064628, 68.73389690153061, 58.73041737464167, 71.89842593285346, 60.58347840462962, 48.83028837942308, 58.76884875759002, 73.88843259503766, 43.34718750369164, 32.479182289492705, 48.279050242516306, 16.544553464458836, 0.6005889694056203, 0.018793630654052384, 0.09369741779782119, 0.023962508233624603, 0.09740789571116049, 0.03604308086177034, 0.048796330398369225, 0.0297002999427458, 0.05147137153413027, 0.05163247216372721, 0.018011148448192307, 0.010681122470076286, 0.13840875287930812, 0.0694882503199962, 0.009478368259395563, 0.026053430309759516, 0.0684917154872129, 0.012430954431634278, 0.04434263611572885, 0.035043297816188104, 0.07910594794779055, 0.08120010291496593, 0.04366777777191132, 0.016424034519361395, 0.04254262443752058, 0.1078923681991235, 0.05704401000853508, 0.1401454282383765, 0.014451797657285728, 0.3837974555790425, 0.8912163131660031, 13.051469056837021, 42.39715022425498, 63.78206929852886, 71.12589159319478, 64.80995385877549, 68.36834769095144, 70.61974110141878, 69.60583194609612, 68.92428874969482, 66.70756909155077, 64.99079865794029, 65.29710046706661, 61.763131233953665, 67.70367853103146, 58.211409353440814, 51.45500513815111, 52.779028646407596, 48.73939921779018, 52.501183632881414, 51.22746452208489, 52.95953612173758, 51.24807265497024, 51.81551410305885, 49.37672161286878, 51.88492044325798, 52.04252127678164, 49.981084331389404, 49.445939679299634, 49.975455730192124, 48.66384652353103, 52.52358036656534, 52.49077758481426, 54.95284541960686, 60.277835553692235, 57.95521974563599, 51.47176934826759, 53.760546868847264, 53.17940458174675, 51.635787179393155, 54.46340814713509, 53.54109025770619, 54.3519304644677, 52.12513815972113, 54.50805648680657, 53.058042526245124, 53.95804997413389, 53.84354814406365, 53.494559180352, 48.638464866145966, 46.87473189446234, 45.22783064073132, 46.31070683079381, 43.4925623093882, 44.74810907917638, 47.46144786957772, 46.99365031334662, 45.00547932040307, 45.71189818843719, 45.19820890118999, 46.6717610051555, 46.733420664264315, 48.02033855069069, 46.55910268906624, 47.163814498532204, 49.82295790026265, 50.15183687210084, 58.03876230793615, 62.04165481751966, 60.13359823534566, 58.624556526061035, 58.84127924519201, 57.03128583969609, 61.959987148161865, 59.48772115092124, 59.8354196548462, 60.88625792534121, 44.04343174349877, 25.468033859806678, 2.443422603030359, 0.4574489954017824, 0.7336537840385592, 0.8915130036973185, 2.011694304885403, 0.7538072897061225, 0.08399946479907922, 0.007816535860089766, 0.03572927592622657, 0.08141072346798836, 0.09824532174294996, 0.04107901728862236, 0.08739391612189432, 0.057755878059974605, 0.029783265349725564, 0.0588080040629833, 0.026598681898547277, 0.047237280185424516, 0.03926660647735961, 0.03156452894120688, 0.10175838645908142, 0.0592399359260115, 0.05767727743894343, 0.10768445959735302, 0.12068506360294358, 0.11989949406274866, 0.05051340539789489, 0.04469881337436457, 0.12729622618926148, 0.061366829660631, 0.06692895740871468, 0.11710354126989843, 0.7855215524473499, 14.364494239130329, 31.83851411265712, 25.297651983076527, 12.40077922421117, 3.061093923545653, 0.9132597883862834, 4.25945621344351, 25.41347565189485, 55.3104635976976, 26.66647288107103, 38.33040545063634, 24.604094566837436, 8.132588872986457, 4.3526968359947205, 0.015026128986069273, 0.12307761747750545, 0.054588077679997495, 0.21090903109119785, 0.1958286975540461, 0.3578944293962371, 72.17980892427506, 92.52934778890302, 121.2072003272272, 85.43737303826117, 66.17494260111164, 75.36843699793663, 75.2937864488171, 63.785140514373786, 73.95605425680839, 82.52749212326543, 46.80468620792512, 43.18745290079425, 56.26963215489542, 28.373957103298558, 0.7353727627665766, 0.1791507489378414, 0.18375728159181534, 0.22110049793076134, 0.22581449739875334, 0.14151022919724066, 0.20735395411329888, 0.17320025291654373, 0.09035443226175924, 0.21024766738616654, 0.14529923878369794, 0.13517581587356908, 0.2260958355280661, 0.14514176174998283, 0.1502853220388774, 0.1530650720721291, 0.1535662161486764, 0.14457510183415107, 0.18653465675250178, 0.21407369434112505, 0.19652107249825232, 0.2102098992514995, 0.18606113780650402, 0.20862939857667495, 0.17062573783820675, 0.27296923161033665, 0.1458761336341981, 0.25235637962337465, 0.16125301980683882, 0.47681851733115416, 8.173353085594794, 37.6906668755316, 61.05615146698491, 70.56376103431948, 71.81383609771729, 66.50660253340199, 70.22126751561319, 71.36829406984391, 70.88862742147138, 69.88185697986235, 68.26038052958828, 64.68870162963867, 68.86593172627111, 64.394547400936, 68.90390026953914, 58.491576410109005, 54.55951798346735, 54.9842792941678, 51.79796149653774, 54.38962051945349, 54.42085043076546, 56.717056920451505, 52.504372519831506, 53.366395734971576, 51.8766010961225, 54.50398114419753, 55.04474655274422, 53.1056797119879, 50.274948304699315, 54.84299159819081, 53.18414672728508, 56.37992920414094, 54.915649583262784, 57.103037757258264, 61.907305794377486, 60.931427940245605, 53.42585102204354, 55.06083219282089, 56.316473099493216, 51.971275344971694, 56.485268377488666, 57.80324751330961, 58.5133534093057, 56.414497052469564, 55.802740666174124, 56.76529030646048, 55.67160798657326, 56.27206010203208, 55.04550357018748, 49.588031461161954, 48.84794296756868, 47.15487149453933, 48.32353776501071, 47.938980748576505, 47.1034296097294, 51.88903108719857, 48.15999846304617, 48.86778231590025, 50.08365431139546, 48.93389778752481, 49.240968381204915, 48.897243238264515, 51.809665849131925, 47.94685294551235, 49.50323374040666, 49.93638892327586, 50.756391786759906, 58.04845448463195, 62.279785833051136, 60.50978099146197, 60.318479153417776, 62.62305598105154, 58.426967128630615, 61.599270297634995, 60.8722472190857, 62.42283859560567, 62.50896599984939, 49.11053388349472, 38.778273444021906, 11.314461154322471, 1.946378506479725, 0.5691045330416772, 0.702347141360083, 2.660388754260156, 1.4591239104347846, 0.13119902281511214, 0.09843685138489931, 0.19134696062293746, 0.1744034093233847, 0.2063506394023857, 0.09628587567638006, 0.3087705427840833, 0.15176833036445803, 0.22610331254620708, 0.16883634030818942, 0.14927419323113658, 0.10740250093682159, 0.1432101016924266, 0.15969945478343195, 0.13497752167524832, 0.13230214346080058, 0.15671243200138693, 0.19260904451291408, 0.3247253656868012, 0.2335030630591416, 0.17568502845543046, 0.15594303457727357, 0.2809093345797831, 0.31920613120159796, 0.2241299619838115, 0.3230145074907811, 0.9392802405261225, 23.423023800696097, 41.50374804773639, 46.002592886647875, 26.0372737146193, 5.727444435319593, 1.8229344078610021, 11.93692365000325, 31.977973984133815, 65.05449010479835, 52.88606620603993, 90.9118486219837, 60.9864862503544, 31.295609051181426, 17.896861184027888, 0.19601626652142695, 0.35500226362097653, 0.2065776465761085], [0.014113769021576211, 0.03605513908569852, 0.3087414620864776, 4.685581038075109, 57.297199003158084, 55.628187348765714, 79.58965255368142, 59.11420168415193, 23.854635530902495, 5.810052492926198, 9.24897534231986, 12.677882909774782, 25.665758579008042, 39.16783540479599, 65.96956729888916, 62.464133308779815, 8.697600903049592, 1.017924743073602, 0.034842578949587005, 0.03676205054826794, 0.041078136287509434, 0.045991678677138784, 0.05318510639030607, 0.01730093514666923, 0.048527973628933394, 0.04296124169242479, 0.07784626191301693, 0.060950706021920334, 0.023867051763039444, 0.038411954958592696, 0.019043834970122384, 0.0446683039227801, 0.049851114726475174, 0.04829584515743679, 0.04783371793887308, 0.01723932635579859, 0.07045116155378281, 0.030698455051488938, 0.036893675944978194, 0.04100316309279973, 0.09479165182358797, 0.004965846563854646, 0.060619066559499314, 0.04760194569826127, 0.11946944294557457, 0.25407641555272764, 0.49194902962734627, 0.25667323911141965, 1.6806023808256274, 10.350102320794138, 36.408757855815274, 62.59478745921966, 66.22382317819904, 68.83459983333465, 65.132011828884, 65.06777125020182, 64.06902205559516, 65.60472019257085, 62.3880510945474, 60.40523021451889, 61.13563045378655, 63.94697358531337, 61.382555423244355, 54.843587798456994, 47.58141356129801, 48.12161807091006, 47.38051760581232, 44.45311154088667, 47.49954192869125, 45.839983186414166, 46.758841545351096, 46.84571419992755, 48.56949390903596, 46.082248380107266, 47.42492668090328, 47.244215242324344, 46.14448070526124, 46.711439701818655, 47.16365760372531, 49.69516315767842, 51.737137302275634, 51.78293097403742, 52.49611200824861, 43.51894809353737, 51.1272636536629, 49.549231375417406, 53.77661289707307, 54.20750094998268, 51.620238904030096, 52.14584042949062, 51.852305935275176, 50.00238280142508, 48.962884103098226, 48.42766884834536, 50.082242258133434, 50.20063900178479, 46.70401857745263, 44.74429261299872, 43.58564407594743, 42.131856795280214, 44.256381142523985, 42.85747566530782, 43.10517334168957, 44.085126538430494, 43.66746864011211, 43.711944395496005, 45.76217512930594, 42.781315003671956, 44.93605336835308, 41.87620847455917, 43.066730191630704, 44.05026451233895, 47.48335822936028, 49.89206614032869, 62.423521088015654, 60.11016599593624, 61.2173883376583, 55.78576072569817, 53.91663366748441, 55.93834877014161, 59.81435652702086, 54.811514577557965, 56.22632526582288, 50.53984165191651, 28.215501193077337, 3.7453737085865395, 0.5988608589095454, 0.6095748130352266, 1.0227071541932322, 0.5799118273200528, 0.1041613974338097, 0.048594378130210024, 0.2211302374639819, 0.06498798938287843, 0.0810060911481419, 0.021472109609373638, 0.058276545887272206, 0.0956751197396267, 0.08968704710564307, 0.026781317259695743, 0.04553832699574771, 0.16654654946779052, 0.08085480410485499, 0.0330613172733255, 0.06398896859478086, 0.07116615907439301, 0.051711176206628164, 0.020626930767790447, 0.022307116718542193, 0.008067674803427391, 0.025014504001686172, 0.05581077315934724, 0.09657807693245912, 0.07144326839836375, 0.025887302228159485, 0.029707562456267978, 0.13892492760092984, 0.04988725109386349, 1.3979766109297354, 12.799529337113905, 21.299556532213767, 6.6954873550322755, 1.3126209330174232, 0.7213997480369384, 0.6225193700482768, 2.2422819897051784, 10.266277347841571, 32.28302847954535, 30.091727741302986, 15.546439693820094, 5.964211446623649, 0.29935225784297914, 0.3976155673303912, 0.09617896044566747, 0.0472821997508647, 0.11923040053056133, 0.05768148709208735, 0.05715504296184067, 0.03094930862707477, 0.8775177417743592, 52.05682616080008, 56.04944990527246, 96.94278301731234, 65.85700311968404, 29.567232324231057, 33.45275378996326, 23.979647351849465, 33.2525913176998, 45.836398140076675, 48.034361024056714, 57.39633690926337, 68.12220327315792, 17.78591302133376, 2.093157643272031, 0.06902144230421513, 0.05036006140853128, 0.03818531933751318, 0.021994380475652796, 0.03105780391413118, 0.047773694950005705, 0.04256144721782015, 0.07921298575257102, 0.0993569306428394, 0.05202244539114256, 0.06974997659844738, 0.021103471930649494, 0.05705850056162285, 0.043096000388745344, 0.033630363553041415, 0.043102079296424504, 0.0309354079616887, 0.026413510786369446, 0.03743100235418927, 0.05148581229150296, 0.02993468645839922, 0.03724874237612371, 0.11848388615274623, 0.04672501251221665, 0.08067453595539255, 0.05896218691862399, 0.13726083141180778, 0.07109826836254328, 0.590379897865557, 0.5550543579363054, 0.8361869305372239, 5.415742993354798, 28.647526733336914, 61.97315062246015, 70.48857704285653, 69.55082462679955, 69.33896956905242, 65.35329234215521, 67.89862032859557, 66.88898655676073, 67.34190264055806, 63.2429002946423, 64.6602762129999, 66.20789051055908, 64.49596420411142, 57.3780978879621, 53.57194362148162, 52.67112424296718, 51.0285532859064, 46.6999706914348, 50.800734181557935, 47.49945171417729, 49.13190687856367, 49.461503644143384, 50.20620876742948, 49.60458386328913, 49.13993204793623, 50.23040194665232, 48.48682603528423, 49.571482981404955, 50.595390258296845, 52.89336965930078, 53.08803689095282, 53.69847928324054, 54.140475488478145, 48.12679167716734, 53.278789597172896, 53.61596438192553, 55.938478208357296, 58.182654457707564, 56.71437009688347, 56.30550615249142, 55.203535864430094, 51.27517231049077, 48.51741660025812, 50.690005671593454, 51.57455505863313, 51.611358657959975, 48.028155834444114, 48.30574981627926, 46.84664380165839, 45.711996247691495, 46.01503072246429, 44.56384005085115, 45.505530526561124, 47.10546924221901, 47.13392603781916, 47.35651662272792, 48.83155530498874, 44.85041233801073, 45.976226714349565, 45.902721497320364, 44.82683889327511, 46.62393554564446, 49.40979111579157, 52.96969898285405, 62.620471139107984, 63.797931363505704, 62.38824329068584, 57.57204732587261, 58.60113605376213, 60.65761120088639, 62.72790485812772, 56.55410989638298, 60.541348226608775, 50.92565774917603, 23.266276082684918, 1.2495747160527015, 0.4730901819082999, 1.0303598209734888, 0.4865377216089157, 0.05455715454093391, 0.1897357857876247, 0.11577424848632467, 0.1683214526142805, 0.044567731900080565, 0.025742410103820508, 0.04776902947454684, 0.04782496155389855, 0.056969691819000634, 0.009184700902551413, 0.024730833134643977, 0.09724447383515297, 0.0051131566532046325, 0.07547951754062407, 0.013109579055209555, 0.0629621732889885, 0.14285836008287248, 0.05905217160620998, 0.015972662217644675, 0.06616081636879714, 0.04727742319265681, 0.011258802560698843, 0.03261418239543996, 0.03365939828537164, 0.08633797117058309, 0.06021327744688719, 0.07797160155830846, 0.07648130007568868, 0.30679474074033003, 2.099493496841, 21.82359891553079, 33.244636750990345, 15.20556611399497, 4.93900292342709, 2.0093647847252507, 0.9192103916598905, 3.89598953627771, 22.45800698957136, 52.789477840546645, 44.763272962262555, 34.784594581973174, 7.0399803019339044, 1.2243672364181089, 0.26298048695729626, 0.06963516300123546, 0.12556806972791112, 0.057302560852540124, 0.13817843620575246, 0.1897070421687057, 0.8253350192981382, 8.32160347892392, 105.41190978019469, 83.03026937669324, 125.96233675556799, 95.91414928436281, 49.79590139081402, 48.05964854455764, 43.49274273841612, 52.86033153533936, 60.4242144861529, 59.46213160791705, 77.58425451094105, 85.06357116083946, 34.31486329724712, 2.7721400222470685, 0.22643571809655239, 0.12099723677120863, 0.10888062928232456, 0.2932875381121713, 0.15715248822685213, 0.1056905395741905, 0.15120450497394608, 0.18106661226239898, 0.2939927373682299, 0.14706514805795687, 0.19726760985870517, 0.12732939779638283, 0.15181814140129476, 0.1539098219044747, 0.19752636371601015, 0.2110667839165657, 0.13413378307896276, 0.10449420901075487, 0.15117334051718637, 0.1494667724135422, 0.09652517856128755, 0.18394816005902906, 0.3415451631430657, 0.17898617792994748, 0.24746166001404488, 0.10651565457303679, 0.36849319454162355, 0.31107416917239467, 1.308304854939061, 0.46169918991865655, 2.8805298189963064, 16.217618027041038, 43.60513041096349, 69.67480290320613, 70.73159140925254, 72.13521942015618, 71.61081421759822, 68.64474927225422, 69.61646941400343, 68.87681238112911, 70.22890829270887, 66.91120286141673, 69.75488201264413, 67.7573993129115, 67.22763615269815, 60.19087660697199, 54.75240445906117, 55.38922086838753, 54.39073055021225, 49.0156517490264, 53.4145781301683, 50.283036231994636, 52.75481193296371, 51.252622604370124, 55.49043370831398, 53.07780734954342, 53.157007848062825, 52.16509534466652, 53.04310614062894, 53.26819527533747, 51.30739850382651, 55.41564587623843, 56.60786597959457, 56.27453511761081, 58.33372062252414, 48.80878986850862, 56.52069914725519, 56.71649994388704, 58.79633672775761, 59.4218017978053, 58.37627833889377, 59.40253511551888, 58.80412655491983, 55.49448159433181, 53.26614779810752, 53.870738014098144, 55.36426674935126, 56.146571713109175, 51.2750114933137, 52.46070477270311, 48.68145012086438, 48.38784110161566, 50.08403085893201, 47.60588522880308, 47.32404332007132, 50.88305688673451, 49.790876834623276, 48.972191887517134, 54.52871953287433, 47.24088907241822, 49.73604602198447, 48.101790489689, 47.026017712008574, 48.94570019937331, 51.84472791610226, 53.67110898417812, 65.6584684310421, 66.07439656411448, 64.6902274316357, 58.64500384176932, 59.695759742490715, 60.94557592945715, 65.02428000973117, 56.84428291936075, 61.16939029385967, 54.3873377000132, 32.20773466171757, 5.602532634812017, 0.8983608491478429, 0.4913683962677756, 1.8547601517169707, 1.3661491510368164, 0.19576990796673685, 0.18675574972744913, 0.29170473917357387, 0.1376843401381085, 0.12302589122085802, 0.10888154092695444, 0.31952589630119266, 0.23958056113652645, 0.14464860030960652, 0.12170746156405057, 0.13179529969009662, 0.26322756563463523, 0.20477999061826738, 0.10786013888014902, 0.1698553751433088, 0.16880531374725605, 0.1939728189139597, 0.293516720975599, 0.14294000973384227, 0.13741840037607378, 0.10520548334405308, 0.13131081036502315, 0.1711655233896548, 0.20798214621120886, 0.2668232146290041, 0.1943658066973571, 0.19354731835905584, 0.28932275731236706, 1.8607791513204577, 33.449447231908, 44.45262124461513, 28.625033901583766, 9.543524749817388, 5.794742991847377, 1.5330924574405917, 8.42169059861091, 39.736410417864406, 65.20300280663275, 78.5609874417705, 64.40217248855099, 16.296174276259638, 0.8161007793199632, 0.503767621252806, 0.15251879009508318, 0.2576500778236697, 0.22897870099592596], [0.03559903714865927, 0.012354484492642506, 0.14099619952180695, 0.43493272135815314, 9.333049385778367, 29.074512027925064, 18.76415998704972, 33.83287852810275, 37.5542115396069, 13.035480495422119, 3.5674353857194228, 1.8101298304334765, 1.7907574893005433, 29.722524842908307, 100.57656088183003, 66.35933322291221, 9.119543990781231, 0.5275304735668245, 0.06292339774870104, 0.13380799652828326, 0.04787942274443565, 0.10938666099982877, 0.014053729753340445, 0.010843914238766078, 0.01583381261180846, 0.01474190557811169, 0.01125703002476404, 0.03173991136493222, 0.05891452475841488, 0.04870546470967032, 0.040859805059529124, 0.0502155082780988, 0.037681804218840216, 0.05384957275143074, 0.006887418201058022, 0.019157771396661, 0.057763581074053244, 0.08111455387646153, 0.08064829744398594, 0.07968460480051656, 0.04758185504244701, 0.05906076328228078, 0.04040423938403687, 0.04999305549708586, 0.07062571468733012, 0.041053073721066605, 0.03615767229348421, 0.42951142355318994, 0.6821643404902951, 0.6587260949515528, 3.3757030675488138, 27.867067244745073, 61.93525660422541, 64.08608436584473, 62.77099601684078, 62.19594909298805, 65.92981799956291, 61.249147768943544, 61.391200327104144, 60.76323670725669, 66.17678611509263, 60.71805100287161, 65.91481885602398, 59.36316628609935, 58.71642235786685, 50.716211026714696, 45.97530495735907, 48.59955495403659, 45.48911932976016, 47.621319755431145, 45.06402069522489, 46.12047972217683, 46.83840682429653, 45.55673314679054, 45.24535579066123, 44.49029561012022, 46.53364650664791, 46.61640459491361, 49.60447011455413, 50.914459382334066, 45.34502713910995, 50.19734421084004, 49.33315976973503, 47.099899476574315, 44.94978166395619, 46.3512170699335, 43.98326258505545, 52.62564828318935, 51.635104686983176, 46.476642700933645, 45.06993955181491, 43.40671339342671, 44.02653025042626, 46.190035112442516, 48.494149100395944, 45.01381435701924, 47.39458322525025, 47.24684323033979, 45.332055860950106, 41.202863031818026, 40.73927417878182, 42.239839646124075, 41.80414668975338, 43.337699290244814, 43.612818256501235, 45.18336665245795, 42.02532522140011, 44.055885268795876, 43.01498236194734, 44.1945488991276, 43.164518802396714, 42.724393567731305, 47.985649108886726, 50.60222694950719, 57.406005551738126, 58.46493174952846, 57.79655987216581, 56.201375069156775, 54.30807052120086, 53.59696049844065, 57.24892639344739, 55.94067865802396, 57.05044269561768, 37.99181076788133, 8.594726939355175, 0.08782431197863433, 0.6621919380080316, 1.7737281514752297, 0.09226055860879923, 0.1499041779747894, 0.06816966744560389, 0.12007605434665758, 0.09796813581018679, 0.10373916807434252, 0.09564672086027362, 0.08084134394002539, 0.06687711623887863, 0.029646070493805795, 0.026366365735509226, 0.07701536295034232, 0.010761401781271543, 0.02781881098335068, 0.027505626579025583, 0.04059931984351527, 0.08023023560282685, 0.03895907197147608, 0.06708785936596894, 0.03765201105946495, 0.11421565026525529, 0.04810471388120805, 0.02616272998913642, 0.10715605045158057, 0.04434627120292956, 0.06212362876882958, 0.0434828786209466, 0.11690791305755416, 0.04516750979687899, 0.20870347927895286, 3.288682588646489, 17.170563743960475, 14.590045232926647, 4.100900282782893, 0.7150040783228413, 0.655511467447204, 0.6340051730794292, 3.238786853128864, 12.545190107437874, 53.76652456098988, 40.06691717332409, 22.658542087001187, 6.79501896904361, 0.34019261959099, 0.07034701956135612, 0.02966113178239715, 0.0899867790060178, 0.05424635267005332, 0.05900508401194408, 0.03264165047796504, 0.09307079618015597, 0.059418239059948155, 2.5019213220765515, 20.268598794937134, 21.974153211039884, 56.90238498872327, 49.51044305678337, 19.544886196813277, 9.636210356989215, 8.918364644050598, 21.638765065900742, 58.59367178332422, 108.68838325623544, 71.504439538525, 31.480417405405355, 1.6637332473070392, 0.18882668456963955, 0.0836258054140114, 0.07290300297280473, 0.08542158445643802, 0.0287431362836111, 0.0511371273727667, 0.06003302461918324, 0.01454163487294629, 0.008668941783628637, 0.025730162273131074, 0.036145683017469225, 0.05736599293267054, 0.07695237520120798, 0.023644780927908518, 0.00970636464415058, 0.024884315019833948, 0.07748509742199414, 0.06257190128728267, 0.09130069640495124, 0.115116439429262, 0.036657812794850725, 0.0698735619023923, 0.06904258633092528, 0.02000339456924027, 0.00773111466250773, 0.09548792615532876, 0.0271106546279043, 0.033700066062832074, 0.11530216978562456, 0.01786554386208375, 1.2016515650095478, 0.6142584294561417, 2.095540483151713, 19.167956229179136, 59.551993108564815, 67.8179842425931, 65.1196720523219, 64.6255357803837, 68.38278985792591, 62.28024082799112, 63.66087590494464, 64.6428765789155, 66.18419154997795, 63.71635783103205, 69.32074623723184, 62.703582240689194, 63.45101733361522, 55.00641322905018, 46.162707959451986, 50.8583341875384, 48.68637661780081, 51.123851191612985, 48.02354704949164, 48.10981565906156, 49.18389789519772, 47.80834228761735, 47.0661239470205, 48.23921465104627, 49.315669921136674, 50.25823508539508, 51.57813618260046, 55.94141998598653, 46.674267399695616, 53.69123466553227, 51.682777174057506, 48.67209919037358, 45.09497604062481, 47.65860972865936, 44.92607093626454, 53.76216288535826, 52.92622735423427, 48.85148486783428, 45.20275885058988, 44.14994370552802, 46.05207750874181, 47.186419117835264, 50.09846125879596, 49.48063304347377, 48.621061309691406, 51.04383484009774, 46.85738717356036, 42.98305819111486, 44.848525677957845, 44.824865941078436, 45.86763981849917, 46.22334780231599, 44.15976139806932, 47.4601613321612, 45.52230258141795, 46.82872249234108, 46.25079262641169, 46.951331861557506, 44.783865405667214, 46.206669884343306, 49.79705456764468, 58.44314690559142, 59.03440106299616, 61.295835741104625, 59.43037609900198, 59.986732928983635, 56.34452196859545, 57.198112087865034, 59.97207503164969, 59.93028609983383, 59.09591167203842, 34.999567924007295, 3.9359307865942683, 0.03585014544847993, 2.789205519422408, 1.6707379875644561, 0.12972398180394404, 0.06492715434081132, 0.02218880976039556, 0.0854926850766905, 0.039646551613846136, 0.05264679938855191, 0.07055331937848561, 0.027987838707744118, 0.08214622150145232, 0.06340311434600623, 0.0903289904817939, 0.04401561999393087, 0.03697478550396139, 0.06014635200582205, 0.03659924154259986, 0.021996130986559777, 0.05180013433639562, 0.04954354957707467, 0.08896509350668039, 0.06308634848063512, 0.02563971601757071, 0.08243936504567824, 0.05257035147458796, 0.007041426771695936, 0.027217939496040348, 0.12355584786423754, 0.05416179571541087, 0.03774236729969421, 0.052029022255972515, 0.15416128260474052, 5.788603501935159, 29.264374356116022, 23.54763750107058, 8.53359091666437, 1.879493269708849, 1.8027247632703476, 0.7566055331018664, 7.1691728791882925, 28.90688953861114, 66.65010636852634, 56.74093238769039, 29.97127175331116, 8.1509627257624, 0.3804413163133206, 0.09723069957427441, 0.08133002376604466, 0.031795077356359655, 0.07400970124909956, 0.22689258229107628, 0.189257409844187, 0.29359323783747615, 0.7361130488495673, 19.81707907492115, 82.58793584762081, 61.81690692901612, 86.56346198051207, 91.95246911817982, 34.69083032300396, 16.992131202451645, 17.15185207705344, 31.9328922225583, 60.10553367676274, 111.39659158645138, 77.84162475216773, 46.49986313235375, 2.672930778034272, 0.2471464761202374, 0.3576585049590757, 0.17306021204398525, 0.2600004968623961, 0.10150928530962237, 0.11680141917519993, 0.17388099864605935, 0.16029505750104306, 0.10324769202739963, 0.07888147652509712, 0.22150526814643415, 0.25812826990600557, 0.13482346139367551, 0.1372109897314541, 0.07222087062414616, 0.10178762037427196, 0.13125808819407417, 0.21827165698332174, 0.1929025634402229, 0.20467227865611354, 0.20484372913356752, 0.15789959249236893, 0.19646432070482164, 0.11896919519189866, 0.19318796183553436, 0.20889224334349557, 0.08875767520118145, 0.14738840651848625, 0.17279073295574035, 1.116501076086875, 1.3759933195767866, 0.6039888676135772, 5.032924077203197, 32.93238862868279, 64.88972310096987, 68.11751996317219, 66.38897849667457, 67.33485806372859, 71.58009421440863, 66.46267983221239, 64.82721228753367, 66.59323200102776, 68.84919105037567, 66.17222832095239, 70.6835659088627, 65.91170449410716, 59.91800515882431, 53.56959019937823, 48.66090474590179, 54.344038655681, 51.353564800754675, 54.38578444142496, 53.48536906703826, 50.30460926794237, 52.31160763771304, 52.24188750790012, 52.27787525423112, 51.66157284090596, 53.75585963649135, 53.83673106470416, 53.56756625636932, 58.461907602125606, 50.293630553830056, 55.73019250746697, 55.750271120379054, 54.18624954838907, 47.86817412222586, 50.94872520815942, 48.75972101765294, 58.43015601558071, 56.67791166613179, 54.53627794019638, 49.330253293437345, 49.02655201573526, 48.70984808091195, 51.37906805161507, 53.584310854634936, 50.06107322631344, 52.031930877316384, 53.219208794255415, 49.66716135701826, 45.655533729061005, 49.53426753321002, 47.52854785611553, 48.72074834762081, 50.24895867993755, 48.295790918411754, 52.1284015717045, 48.03850696932886, 53.03601841772757, 48.24582384478662, 49.69533966433618, 48.286859681529386, 46.18464185345558, 51.59437871748402, 57.95590616041615, 61.31671059516169, 63.01626574608588, 60.254407236652995, 59.882617535129675, 58.37425831825503, 60.82903446689729, 62.59837642792733, 59.27916088411885, 63.48667560085174, 43.00569811174947, 9.47860069813267, 0.264320221519278, 1.9340313754735456, 4.824368223067253, 0.1575067272830394, 0.3326477567034383, 0.1457012051175679, 0.19658698670325742, 0.23091820579382683, 0.16172348972289793, 0.2907994683952101, 0.19649617464071323, 0.2579182698842018, 0.13678043299624998, 0.24693146588340883, 0.11443494293358057, 0.09898970639633556, 0.12922751086373485, 0.15590057798450993, 0.17671653520195715, 0.3793592937290669, 0.1316803252144206, 0.2973447091156437, 0.13002935977232072, 0.27247593227413397, 0.1527421506902864, 0.21545191716042258, 0.24754559260702905, 0.11348390606262031, 0.31735593693390973, 0.19515694569676154, 0.24865327913674617, 0.1721404622038526, 0.5133528827178864, 6.942579025222409, 39.34982553605111, 41.49356949713923, 15.253904423406048, 3.7392043106017576, 3.2670531686275237, 1.981198979962257, 16.098939853329814, 56.229063080203154, 88.47783750103366, 81.6730586944088, 43.55290797448928, 13.557062572048558, 0.4134335975733496, 0.1802917909357817, 0.29829977560908566, 0.241008855462555, 0.16124362756888713], [0.08913920230923161, 0.07465208129536721, 0.09987001803012625, 0.062379015669707334, 0.31895470114484914, 2.2718985811356576, 11.944032945940572, 15.265679378663341, 14.404567133995796, 11.076713550475336, 2.35232433003764, 0.4088593785080218, 2.8351450543249808, 3.5546281116624034, 36.72112757159818, 29.21473676158536, 29.963519188665575, 1.5200896777452961, 0.16383493529452434, 0.010124254115526716, 0.08085131074392027, 0.02116488728431925, 0.16869960893546382, 0.06240333896130324, 0.11013686026055967, 0.08052811357042483, 0.058798776533935344, 0.062409153568648526, 0.044992045018701785, 0.04671176302156622, 0.011037701924872256, 0.038623755287018516, 0.04372716490780154, 0.049925145633038015, 0.08497036632991607, 0.09743393503970678, 0.04321724912452121, 0.08388829011950763, 0.022192791502382007, 0.06139318691566587, 0.022805355406636675, 0.032405304692445264, 0.030010793463236866, 0.06899754036097758, 0.16012271836159692, 0.034771738799228784, 0.06477431213903813, 0.0880500091420066, 0.14200634773700468, 1.0202431702806105, 0.24472536248785837, 1.9046051415704914, 27.527011479100874, 65.7837018659038, 67.29597168584024, 63.75315358561855, 61.57350424797305, 60.286319640374955, 60.520026222352065, 63.672490043024865, 62.86194401402628, 60.19394390044674, 65.11858947815435, 62.791976774892504, 58.824248313903816, 55.03723913623441, 45.80859245792512, 45.92298838400072, 45.74726227791079, 46.27691168938914, 44.712921496360536, 44.6705206747978, 44.69238396613829, 46.27575066781814, 43.412145876115375, 45.64463346235214, 46.13598877383817, 47.46372284427766, 48.389994482840265, 51.51311505225397, 47.67962578804263, 46.46190243382608, 44.32042560269756, 43.23433699146394, 41.90468488201019, 41.78051048709501, 41.34061667226976, 45.15902442316855, 46.32915766008439, 42.67482265349358, 40.15609618156187, 40.55699379213395, 39.67631186208418, 41.82018918375815, 46.16455147343297, 48.41125372917422, 48.34585605129119, 48.56664626829086, 46.73768820301179, 42.662098484654585, 42.67581893551735, 42.00464648585166, 40.721345024724165, 42.30633951002552, 43.107499307201756, 43.61961964638003, 42.442422220783854, 44.80768988209386, 43.00173259550526, 43.54525935265326, 42.565616023155954, 45.333059987714215, 46.6731220676053, 56.967037416273556, 56.53517661556121, 56.537596717957534, 56.76969905053416, 57.09433794021607, 54.25904481641708, 54.411609326639486, 56.87261419911539, 57.115640332621915, 50.30954753198932, 16.42917008169236, 0.3979282844210825, 0.11669198351521647, 8.695528911006067, 1.426017390143487, 0.08981624783407297, 0.09985449708878033, 0.16595401110187655, 0.14157969805021442, 0.1212400406779301, 0.06480938364421168, 0.0026648832886900396, 0.14777028602698158, 0.06803922565473665, 0.01097238143800848, 0.031148727059424407, 0.0329309176172941, 0.01656870447820233, 0.05031909868722001, 0.03493069055219812, 0.013445316130415568, 0.06935735653725363, 0.09135866627818154, 0.0642736506978831, 0.06868051785615183, 0.016621129790080652, 0.03145921483425604, 0.12069796452358847, 0.05009873349580073, 0.06359234955462237, 0.09471204762737598, 0.10662441607564689, 0.06637981026283195, 0.13524038176382744, 0.39178891708293273, 6.013268530368806, 24.84189610327444, 8.581626222979638, 2.7691195520662495, 0.20321962273409291, 0.22000042631501154, 1.7942073364411633, 5.89666921284891, 17.495747843096336, 57.12924311237951, 54.845988289002456, 31.75695234729398, 3.3462416548882765, 0.6484293216659177, 0.2663194964970312, 0.11156258819204186, 0.049797871615737684, 0.1067394441774776, 0.09866238766980749, 0.017478606258068356, 0.05146187587430881, 0.1475264402406831, 0.34392536768028814, 2.4423356161963556, 2.1122681661959617, 6.997543688743346, 24.444416838307536, 8.901881863993983, 0.40582107380032545, 0.5815518070613185, 5.780044399922894, 21.478604885839648, 63.615933387510246, 33.47062018609817, 47.482507075032885, 8.257481551939442, 0.48247702660099157, 0.16283333662056154, 0.04687573648087921, 0.06539366358230192, 0.044753895096120336, 0.014579230637830353, 0.026382047555319248, 0.016080507287575353, 0.07883877478419773, 0.028102847657376723, 0.02853042048011576, 0.046152089827603875, 0.02697291393433848, 0.0062174795781292265, 0.05619731048242219, 0.06130073159452408, 0.021672899339107737, 0.042672365257937106, 0.09487988216982735, 0.07112455283922535, 0.02407845372574464, 0.14550096505591947, 0.05460665914260092, 0.05897753932062657, 0.0685085924041848, 0.043636732058779854, 0.10461269216912408, 0.12980720959603786, 0.07602280411388605, 0.053320979744556456, 0.1075221638705942, 0.9694816941215146, 0.7519486378277502, 0.34175568410465795, 17.75078231288541, 66.42380914380475, 67.34009050553846, 67.2294012192757, 64.10488820845082, 63.430503337614006, 61.31461604948967, 65.96817093510782, 64.34563152251705, 64.77857881976713, 65.67233008723106, 64.7688356522591, 61.173783348452666, 58.85447409845168, 48.09787596425703, 47.1190014193135, 49.272825871744466, 47.26861238479615, 48.34984117938627, 46.908028894855136, 48.157872538412775, 49.72186665381155, 46.53816115471625, 48.882981500317975, 47.70943580135223, 51.39705604122531, 51.609295491249334, 53.706759406674294, 52.193897308841834, 46.666477572533395, 47.113788589354485, 43.23000277242353, 45.158381154460294, 44.68152684550132, 46.175487041473396, 50.094880134828635, 50.71896060820549, 47.40858216439524, 42.80371958209623, 42.94541128220097, 42.82602217889602, 45.49624627636325, 46.39738336686165, 50.852736965302505, 50.649942582653416, 49.8897833208884, 49.73265317178542, 47.41590915187713, 45.66770484370571, 44.822673336152114, 44.17074403455181, 44.59719196442635, 46.021330048961026, 45.53692909979051, 46.19468704346688, 48.107117068383005, 45.32257941461379, 45.8994149392651, 46.895783255177165, 51.22720172328334, 49.31771347599645, 59.09604895499445, 58.056463964523815, 60.3950987323638, 58.0721926689148, 58.51943308307279, 58.75945468102732, 58.62181086694041, 59.393023367851015, 58.71746963070285, 45.66010329031175, 10.55924407897457, 0.27651002870932706, 0.15632088446328718, 11.439220962985871, 2.7872759584457647, 0.1447154951071547, 0.3387088911427606, 0.2882384364643405, 0.0566066580734426, 0.1378647232007596, 0.04337250833369551, 0.05262387420741781, 0.04386698744530159, 0.07465083257205064, 0.01189687527761224, 0.05241131545194695, 0.010740436827613702, 0.07823849126936928, 0.02044139576384858, 0.03558879072267202, 0.004904813296537126, 0.0815683537192883, 0.037846723796739694, 0.05394399308809831, 0.0901624582888138, 0.02843755338671467, 0.036625150636199026, 0.07647740068815409, 0.020558854279619072, 0.08690582618357674, 0.15921259058579323, 0.03104857638508322, 0.09082701658048938, 0.01794817219037683, 0.7601345018033059, 14.86337952075466, 37.42657369182956, 13.927351966980966, 5.852407716935681, 1.1563226941131777, 0.8779549634745045, 2.1104474509916, 9.814168291707194, 38.00793563165973, 67.1440347548454, 64.18968985157629, 38.99358410989085, 5.258407900410314, 0.35137305997552415, 0.18329750626317917, 0.08863654903947346, 0.04988874113487621, 0.10982750629585598, 0.19340592917175065, 0.4104526268859064, 0.2737334196365649, 0.30515356590190246, 0.7509897408946868, 6.735931894471569, 38.59360825630927, 48.220038183273815, 62.992645232908195, 27.824354594753636, 3.457015026961604, 0.826774774299514, 10.681400414436094, 37.71693891094577, 58.67412744029876, 38.26800446356497, 70.38023333395682, 8.342242010178106, 0.48343647511736043, 0.20829360691770432, 0.14273603116312336, 0.1167248486871681, 0.24788945883272157, 0.19571317149506462, 0.15155805455100152, 0.24261875859191342, 0.23174164306011893, 0.37296711737590454, 0.26484588040940227, 0.1475941624131895, 0.11248751678654265, 0.11618086497389501, 0.14861062319288332, 0.2729770457071643, 0.1485990246217097, 0.2929040651407934, 0.2572127948364904, 0.22756681627323552, 0.12194114902447309, 0.24625303373942453, 0.11288963633799746, 0.15921669681706738, 0.253581507431884, 0.1724252783723416, 0.3227101867237399, 0.2565547253095335, 0.21639063533756042, 0.21064427110456654, 0.23102233246449502, 2.129980854449734, 1.2518623158816369, 2.566639449327223, 30.600064954450055, 70.4095491286247, 69.17825437361195, 70.10073308021792, 65.48597435797414, 65.02138530054401, 63.095960463246996, 69.57164456767421, 69.10885980052333, 67.48270004026352, 70.22733934463994, 67.44770465358611, 60.94599170069541, 58.88338196662165, 51.8137215798901, 50.304005222935835, 52.31860906847062, 51.48819231217908, 51.82064456324424, 50.37118365687709, 51.40460268143685, 53.25908360942718, 49.79086506751276, 50.55592729199318, 50.79820817516696, 52.93995564983737, 55.14706550105926, 56.0163607904988, 52.20351103813418, 50.38000506739463, 48.1056579466789, 46.16992512056905, 47.1572837521953, 46.479121638882546, 47.86484402994956, 51.145902756721746, 51.3191460024926, 48.03914239329677, 44.862038243201475, 44.60014943153628, 46.057109909672896, 46.20347315265287, 48.65951230449062, 54.964957698698974, 52.06795000260877, 54.38421549335603, 51.43658568782192, 48.95691425569596, 48.214746905911355, 48.01551011300857, 47.53612979765862, 48.97631429856824, 49.08319888576385, 51.180972668432425, 49.18394104126961, 51.60436899431291, 47.72789839775332, 50.33746304050569, 47.439576733496885, 52.00308576706917, 52.22899075477354, 60.33385484449325, 60.47782151929794, 61.99802237172281, 59.58844761694632, 59.86584940264302, 58.209891396184126, 60.73164986025903, 61.56405525822794, 63.268395700762355, 57.48524919632943, 22.048303657962432, 0.4703194563907962, 0.20831271315053587, 20.227178565917477, 4.331909254673989, 0.23991146515454018, 0.4566148482263089, 0.37170913971720204, 0.25253098638307664, 0.27543722982368163, 0.15429294247540737, 0.11269241466277069, 0.2498219002999606, 0.2883941361740712, 0.1143946237261257, 0.25870822910820285, 0.11332254496312912, 0.2263290020487001, 0.13907619932245824, 0.275919129771571, 0.13323882384405983, 0.22263947664008987, 0.3412440905888235, 0.25333769228910247, 0.46897818965296595, 0.18452643386779294, 0.1712174488291625, 0.2860407447141986, 0.19085356935618386, 0.344632497477916, 0.3011136165549678, 0.3242321276376325, 0.24496649632290488, 0.1648591182404949, 1.0501565135294393, 20.580315436086348, 45.348216026060044, 35.6107202652962, 11.505943421394596, 2.57150809130361, 0.5362780332084626, 2.9557268033104562, 23.25569745033018, 70.25160312652588, 77.58575285634687, 85.3316730068576, 53.18603730970814, 4.755661045351337, 1.199863699655379, 0.523291188141992, 0.24959483183920386, 0.1931301068754927, 0.2860414495150889], [0.03325828996997687, 0.024531866694169662, 0.03213858352072778, 0.11437938623731175, 0.25117527122699446, 0.5401840397427159, 0.33460924822476606, 4.550692198737975, 10.432042594878904, 9.345455842633402, 0.9226620774115286, 0.683773247705352, 0.4447213332018545, 3.8303256275192386, 11.445449686819508, 34.78299817731304, 45.04990016260455, 15.661401421793046, 0.21231443471004888, 0.013278602949163366, 0.028395167657084046, 0.05854308319788787, 0.06298042533378448, 0.02946452297750981, 0.06262610200792551, 0.05192953807812545, 0.0310192390480229, 0.07372321500893562, 0.09469848021023697, 0.03942334423622778, 0.05688267189168161, 0.07998420646594417, 0.008845814248366703, 0.055408312698766116, 0.06705696303998271, 0.07454927995680802, 0.020446620483492172, 0.03789349346451702, 0.07172217802895654, 0.04725723677585202, 0.04928493744603569, 0.02209369802937633, 0.046475551301433195, 0.06520622484986821, 0.054222753331545866, 0.06273597816846545, 0.046647970880111383, 0.06519261912833299, 0.11330205977203385, 0.23492921233898212, 4.205097556114197, 2.3986904226964523, 1.2308004137969788, 38.67797059397544, 65.39841136624737, 63.5085859606343, 58.285589218139656, 60.28222468591506, 59.44329246397942, 61.95034988464848, 60.20809973439863, 63.55809803931945, 62.64422501287153, 64.3891933656508, 55.9347088106217, 52.73541581246161, 54.51127283034786, 45.27348702953708, 45.70695992439024, 44.93140143732871, 46.02717438051778, 43.65230083465577, 44.07156298237462, 45.91652039558657, 45.01288867765858, 45.370863791435, 46.893127810570505, 46.35000505755025, 49.96040559584095, 50.46602264527352, 50.208358226283906, 47.30441577972905, 44.52119604233773, 45.210168207845385, 45.51288104826405, 45.49892133282077, 48.229506784869784, 48.97919331827472, 49.308715558821156, 49.76775838482765, 46.27958674584666, 44.6563805303266, 42.42677196379631, 41.863900076958444, 43.37371841553719, 46.08935571485951, 48.220838346788966, 45.94938201289023, 45.23590680091612, 45.913543316625784, 42.017433412613414, 41.10546665806925, 40.31545031455256, 40.64267012380785, 41.80757091891381, 43.18224399320541, 41.81826330000355, 40.052525997161865, 44.286579470480646, 44.45500996805007, 46.73696256452992, 49.963990642178445, 48.468524256060206, 56.13964872975504, 58.99815444023379, 55.37180946719263, 53.40498793509699, 53.96350599104359, 56.57133302380962, 56.40710338469475, 54.096180162122174, 48.802416016978604, 24.737806204826605, 1.3158407086326231, 0.04531605041495735, 0.09839316905145684, 0.19565648098866786, 0.17016824545158496, 0.06473934788617396, 0.1693967029812836, 0.050580158469177065, 0.05088946646860531, 0.02222151213866328, 0.054768050885609085, 0.16038833636670344, 0.0339431878960421, 0.06533226163517084, 0.09807802346204558, 0.06380149538839056, 0.08454121919649263, 0.1293279296688495, 0.05761612447038774, 0.045028556769172993, 0.038485434281850056, 0.035590365033356414, 0.07466062317572295, 0.07405566652455638, 0.0920770192639001, 0.1070961193932641, 0.04685972524326175, 0.0673195320151506, 0.06523755018509204, 0.06288848329155196, 0.05982005217623326, 0.040813288200766816, 0.04813606219906961, 0.14926040364849955, 0.8613304265083805, 16.927837671772128, 22.441693852024695, 6.330350483617475, 2.317287268177156, 0.05364108958371705, 0.06159814607892787, 1.6793109404463924, 6.8904154243007785, 31.699011095108528, 56.0550118261768, 66.65045938184186, 21.248169560586255, 0.4585835716176418, 0.20320376471406032, 0.1028905648197378, 0.11151456980094795, 0.04354638347942983, 0.12329707868517407, 0.10113803144063681, 0.029545638282152436, 0.04696583991209346, 0.04273811092359885, 0.19786004097230975, 0.7382731103608686, 2.01964016883604, 6.70813258617155, 6.27430961978051, 4.543329419628266, 0.08800489422414573, 0.5396284727800278, 0.36346915929067525, 7.133059126715507, 26.87504295379885, 46.1969933971282, 46.20646592109434, 33.9935270432503, 0.4460066142341783, 0.09430681775894859, 0.1713693180992719, 0.04645775124851254, 0.08138054726465095, 0.01779775657210379, 0.053478797687397855, 0.04387995348342004, 0.015406710933142853, 0.04080376572786801, 0.014728234739102905, 0.044387735711831244, 0.06059070215410283, 0.03588256628943547, 0.07809018430810782, 0.08329699281603099, 0.027885663646063017, 0.0261740010577224, 0.045308638514289935, 0.09386545152313287, 0.019323554738695105, 0.040675909483745214, 0.12445322027610195, 0.059377939004691384, 0.019442426686685894, 0.0735896782228543, 0.09566848541820243, 0.017893536714836955, 0.06948613591732518, 0.11379610221352308, 0.11873244337977902, 0.2305952078031917, 7.395454904725475, 4.06464385409509, 1.0112774287981372, 27.807994388764907, 65.83805807175176, 65.95313256786716, 63.875119686126716, 62.642538393697436, 63.31183987279093, 63.70385331492271, 65.71431121518536, 67.5813711843183, 65.9421734656057, 67.91003442579701, 62.43939884247319, 56.87487348433464, 55.249513887589984, 48.63909636774371, 48.38231840441304, 47.821313565777196, 48.237724150380785, 47.80216063222578, 46.44932731505364, 48.50257435152608, 46.964813047839755, 48.543959279214185, 48.756057523912006, 50.60356447773595, 53.18790043553999, 53.348784292897875, 53.72862662038496, 49.36716671912901, 48.463178065515336, 47.84812296590498, 48.170118178090746, 48.482036821303836, 50.47565206404656, 52.173838307780606, 52.07643408929148, 54.06302828942576, 51.004081618401315, 48.00962263537992, 47.79195854740758, 44.70974437652096, 46.695554102620775, 51.61664209058208, 50.498888184947354, 47.26681593925723, 49.485496782487445, 48.71019717185728, 46.2066424277521, 43.78233917297856, 43.220283139136534, 42.51725712130147, 44.5074285230329, 46.98123601175124, 44.72311181406821, 42.280173378606, 45.43614379821285, 47.180766982416955, 50.315435009617964, 55.31950466094479, 57.60932160962013, 58.00151548077984, 62.71501594974149, 58.3266995799157, 58.17183656077231, 56.484860450990745, 56.754939171575735, 55.45253184533889, 55.84585535910822, 45.821583347935835, 16.923497569176458, 0.5845706837792551, 0.07881582278998629, 0.07621423416440526, 0.21037549681721196, 0.19655842694544023, 0.15248986261506237, 0.14645966280612255, 0.10524479897632714, 0.02872013066324496, 0.061479950203530254, 0.07601547265245069, 0.1276439534980924, 0.02808779019922499, 0.10635643851973357, 0.06986363340289363, 0.07685108305585962, 0.020812142099584305, 0.07267469344961067, 0.040887556594586184, 0.045793212109035066, 0.04136608192516912, 0.07937691324660856, 0.1013197781397931, 0.07998631320773594, 0.06142837333402807, 0.06472800978489461, 0.024772288067446604, 0.03378562659265534, 0.042608067498452244, 0.049981081542829355, 0.04398144481162872, 0.0756921069396119, 0.0946318535434623, 0.13271710264586634, 1.2285387996704349, 30.94763009778915, 34.591641426086426, 11.341083261274523, 4.738105497052593, 0.0658575221595745, 0.46688848565663066, 2.135545962279843, 10.90562270533654, 53.13831775419174, 60.38879940586706, 86.32990052623134, 31.25140590052451, 0.751517667405067, 0.17017889407373246, 0.12006730562256229, 0.07399104700814332, 0.028753147137561635, 0.12390739029093135, 0.27624361397277925, 0.21356957784343153, 0.1669955842437283, 0.23647341576795425, 0.2925371090250631, 0.9378535396629765, 2.034505706640982, 9.088530790421272, 46.1408015220396, 22.76005106587564, 0.427523517320233, 0.4698196606289956, 0.5668405900078436, 16.38033853423211, 34.86044145399524, 56.500867643663966, 60.50126944818805, 37.3370102913149, 0.7357939272638291, 0.15184918328398658, 0.2367906680991573, 0.20395796295375596, 0.19594109797429657, 0.1188828647437115, 0.2124142866100996, 0.16850663138733757, 0.16716651378139374, 0.15287759503529919, 0.16207258066823407, 0.12386199958141773, 0.22159626407008018, 0.17467989045525753, 0.20249196178009435, 0.15805487851462058, 0.15441994453149457, 0.16385333672646554, 0.12317665732435643, 0.16294236625394515, 0.1815563722723915, 0.22783753642391777, 0.31648100323734746, 0.13756901326198734, 0.12231346775567341, 0.15499095582673628, 0.22478345030498123, 0.15556644107545578, 0.21812462938889382, 0.4012075084592066, 0.21167646733022508, 0.8915172937896945, 8.43825770962623, 4.043028652667999, 1.5127129251918487, 41.16913457070628, 68.0892239847491, 69.84617910077496, 63.907200751766084, 64.57251318039434, 64.44891929626465, 68.2995806970904, 66.39640746578094, 71.15386593726375, 69.83547887494488, 71.92055594536566, 64.51579570770264, 55.281481204494355, 58.64323093045143, 51.068722278841086, 51.111672232227946, 50.18718527209375, 50.670087875858435, 49.408606559999534, 49.381040142428496, 52.380857083105276, 48.16508185478949, 52.03646905960576, 52.65342650874969, 52.10133721751552, 55.89231583379931, 58.70047400074621, 55.838967677085634, 52.20941028287334, 50.12681607277163, 50.73251239715084, 49.98230811088316, 49.53856645091888, 51.93766063259494, 55.065115421049065, 55.29115376933929, 55.75964558509089, 53.87165584871846, 50.66318058198499, 47.35474763378021, 46.20557162069505, 47.60645789484824, 52.927427599507, 54.2677132544979, 50.51238898308047, 52.485243120501124, 53.916131604102354, 49.01603614130328, 47.65200445728917, 45.20009948361305, 47.81558690532562, 46.02289507465978, 50.39434917511479, 47.389605737501576, 45.151713125167355, 50.555397772019916, 51.579340350243356, 49.634613529328384, 54.85702976103752, 52.92442698632517, 62.570511910223196, 62.7506624498675, 60.530475416491115, 58.05934298423029, 58.172558276884025, 57.2573124208758, 58.763757521106356, 61.49426844812209, 55.03899635807161, 32.46211801805804, 3.207930792723933, 0.12827989074491686, 0.2542658078093683, 0.3175192668793663, 0.40103161467179177, 0.22641782228264118, 0.7889077836467374, 0.16917466005731016, 0.0927097772458388, 0.1732865297385762, 0.21480395999406615, 0.2400765724239811, 0.0850747304878408, 0.19610137888981452, 0.26562496118487855, 0.11818937131113584, 0.20432455134728264, 0.2476320992554388, 0.22296748484574982, 0.17239829675564844, 0.1055018827619572, 0.16196955716417683, 0.20492366274758694, 0.16874070189172224, 0.19886231380364588, 0.1999458532419897, 0.16209125789182802, 0.3107241282780325, 0.12075682305881094, 0.3092559054493904, 0.29280848801136017, 0.22643977836255105, 0.32611786838500734, 0.4510658282426096, 1.1174547023350194, 41.97642111009167, 42.56002664566041, 33.55369206397764, 11.932451167414266, 1.867462870094084, 0.408322534734203, 2.7825698496833926, 19.36954056063006, 82.26007276965727, 66.70413309527983, 110.19469891825031, 33.83591444261613, 0.45987743283471755, 0.30769011366271204, 0.19381033166521983, 0.19669183349657446, 0.16967064070124782, 0.26699659564802725], [0.0488554225904086, 0.05977201846338088, 0.04589964853479497, 0.0727451965212822, 0.17646217868933756, 0.027740851960956093, 2.636476269652767, 6.25332837143252, 7.055005431175233, 4.339914321899414, 0.9328663072759106, 0.5868306431558825, 0.29849427001130197, 1.4747720836631715, 15.647281869765251, 29.917472524027673, 38.03873408225275, 39.34513045895485, 1.997176754859186, 0.035428088458795706, 0.036194816066492955, 0.02502389240919823, 0.10082005132590571, 0.012654885762341082, 0.10738659695151354, 0.038843166698972066, 0.07312261739805823, 0.10407168087699722, 0.06819244323959274, 0.054513073841770815, 0.03477008021887272, 0.030736249999233314, 0.1601698021254232, 0.0821869543963863, 0.017571609332076004, 0.10091459423664118, 0.059925446722416155, 0.08885348981787121, 0.03806885482082444, 0.06961429476617806, 0.08148815197449538, 0.0451962917201942, 0.07440953019766078, 0.024597079928724036, 0.0891351573649914, 0.07130935622919952, 0.13062425768904148, 0.2370581247152821, 0.11101405391649855, 0.12253382528621344, 0.9561632862014156, 0.8357470122075851, 0.1465318742538652, 3.389379146599001, 46.114250998343195, 62.62846885188934, 63.48237276077271, 61.45418182496102, 60.31838109416347, 61.437943212447635, 63.723069006396884, 64.39477882077618, 59.80821409533101, 62.9749474986907, 64.7449601850202, 54.04890775680543, 55.4903317266895, 47.126638274038996, 45.77265570240636, 43.38086497399115, 44.85704898834229, 43.63355974997244, 44.149037638018214, 43.742840905343336, 46.99814142719392, 43.58188644532235, 45.18035427216561, 48.764420017119384, 50.33966741254253, 51.278745589717744, 49.76419687271119, 49.62723555103425, 48.12883915439729, 46.0530855578761, 47.95374847227528, 47.02591965275426, 50.28021997021091, 48.863310813903816, 47.4020004272461, 51.125933970174486, 49.31519531434583, 47.340450594502116, 48.11928033828736, 43.46573329740956, 47.98137764776907, 46.737794107006444, 47.987347495171335, 48.50864618055282, 46.68757992406046, 43.7980600326292, 44.32283393798336, 39.948265475611535, 41.43532230008034, 40.04980779463246, 41.30905728186331, 40.81033968156384, 42.60297267667709, 41.092083531041304, 41.79505855806413, 43.811227429297666, 52.546949848052, 58.38260512198172, 63.48014877688501, 54.42665946099066, 61.57854841601465, 55.437371884622884, 53.25495335363573, 58.43444708854922, 60.43832717403289, 51.85390233993531, 42.64884087347215, 22.746907203428208, 2.280674394099943, 0.08977827285566638, 0.033630853849312956, 0.033716575257600315, 0.1529474162887181, 0.12230965263781049, 0.06264878970180308, 0.021827675912889744, 0.059254407326901154, 0.09545050276022765, 0.06929439943163626, 0.06874790294997155, 0.03697052988554201, 0.011378769056811448, 0.06507393678710346, 0.08476366814706596, 0.08546582603406522, 0.06514990972655435, 0.06351100633882227, 0.025147395358691295, 0.05581154307771114, 0.028870134509258696, 0.11890970080369904, 0.07702886908044738, 0.04133929949133627, 0.029770885368869193, 0.01902090404332886, 0.0957700303725658, 0.07781428540305746, 0.03361325297925261, 0.051842962481802514, 0.07301623076801339, 0.11041660492698993, 0.09429136576551585, 0.17746031464588258, 3.740141757072941, 28.627652083673787, 19.041332314091346, 8.675079634112697, 4.09214922978032, 0.42129080982938893, 0.31075066556372954, 1.1437096999537562, 1.5398003233055917, 14.538642571818444, 57.37535615121165, 67.7549909776257, 12.20919595610711, 0.12620917040734522, 0.05284895467001104, 0.019552092173046643, 0.13891942708963348, 0.054831107582656614, 0.04088791665591059, 0.045896729739803466, 0.1279795996003574, 0.01657654347288753, 0.14089930472114395, 0.11750346214901056, 0.16326773911714554, 5.057340341229593, 8.773771370610884, 10.509720233178909, 0.7657405493720886, 1.1529549715980407, 0.5093181734123539, 0.7220671638365715, 1.996353792567407, 14.10001862433649, 44.121420229634936, 41.33125789703862, 47.435709276506984, 5.289949149854722, 0.3666757581935775, 0.1719805336887798, 0.14183025476672959, 0.06885781358446806, 0.0655624480737794, 0.027888819928311055, 0.11273129362492793, 0.03482025514747347, 0.10618080520221304, 0.15168884108143468, 0.1565589233031196, 0.11558511669957831, 0.08857211338416224, 0.07363957352936268, 0.05227524674527588, 0.0589687561225747, 0.06225087214261294, 0.04818314979333551, 0.04319017557727714, 0.1016377582545242, 0.04295799347962584, 0.12428373098373414, 0.08172432155979258, 0.07470280397683382, 0.10235143044302542, 0.09238950652821411, 0.014328250657737017, 0.11094358148834399, 0.11957016052497972, 0.15958726886780034, 0.058858194313342535, 1.0367184733190844, 0.8703876695325299, 0.0842492554276701, 2.115641159396018, 36.414939511206846, 62.084679295939786, 64.67521652098625, 67.86222857813682, 63.270231370002996, 64.10610414320423, 65.92077301394555, 65.23035741621449, 60.680286422852554, 64.92150214410597, 63.48249043187788, 54.72800731658936, 57.133553797198886, 50.09867306678526, 49.147188432755016, 44.48425516005486, 46.96883347726638, 48.117276007129306, 46.6871916094134, 45.82436823075818, 48.53134493674002, 46.18340238448113, 48.55808765657487, 51.87529494685512, 52.795914449999415, 53.53605393440493, 52.36677969655683, 53.66556275275446, 51.92578369571317, 49.64289365276214, 49.95672641261932, 52.4997833467299, 55.640840914941606, 52.80381018115629, 49.937957871344786, 53.07400657284645, 51.933393093847464, 49.392756262133204, 51.242600948579856, 48.48551596364668, 51.18187873594223, 48.91647069684921, 52.98081890229256, 49.822165581487845, 50.69574802152572, 46.917517108301965, 48.471842581225985, 43.533594223760794, 44.483152974036436, 44.143993469976614, 44.91296629751883, 44.71994253896898, 45.80912982263873, 43.93014977055211, 45.86085019573089, 47.78126224394768, 54.878171336266306, 56.79778714333811, 68.9697176410306, 60.54547456003005, 57.48217013574416, 56.45270486031809, 51.79789089387464, 60.12897768328267, 61.28315471833753, 47.81896798841415, 38.02550392766153, 13.425370954698133, 1.1424616507945524, 0.042627491657772375, 0.09312940190636343, 0.03645740419385895, 0.16329859713873557, 0.09676424395893851, 0.10943407418146249, 0.11241737377619553, 0.06521834436083032, 0.09651158816151081, 0.04817763779072031, 0.05087556580321924, 0.029958101935804855, 0.04879284852875337, 0.024257687656509302, 0.06722200136151045, 0.05214380520966746, 0.06916650105267763, 0.06642055847952444, 0.15591608360409737, 0.060394411275704066, 0.06497246844153251, 0.11378560680896045, 0.018852770726587025, 0.0515897857445863, 0.060420488908646576, 0.06730962649828966, 0.014283323431417588, 0.21081182985536515, 0.10199954327676566, 0.07609298542862938, 0.04767406521545303, 0.09042609212619644, 0.1958897394398528, 0.1620719065108607, 7.332646971748722, 45.06489146140314, 29.026323749173073, 15.991054081147718, 5.417228100761291, 0.7641519281652667, 0.8599711413825712, 1.662869958146926, 7.987516580089447, 39.93558053047427, 65.4386862631767, 94.7192305903281, 16.79178830116026, 0.10258576141730433, 0.04270957414841941, 0.05419941063249304, 0.07449538567133489, 0.04332430225106017, 0.06869069150378627, 0.34104150629812674, 0.2361988804994091, 0.3081616561018652, 0.3236638436154012, 0.46106943500138103, 0.38900265530232464, 8.846913768399148, 11.695130121323372, 21.7425549030304, 36.301551634265536, 0.6133854569446656, 0.802168214032727, 0.2583690360188484, 1.2714826243539012, 32.22404976044932, 67.81384221969113, 47.947998277602665, 62.608378471866736, 4.02148233786706, 0.36189592112937286, 0.19475949928164485, 0.2021538565355924, 0.21969727000161526, 0.08544532552121148, 0.2388729103991101, 0.2708239709177325, 0.23564506021718826, 0.255048121475885, 0.285596352431082, 0.23464698554767718, 0.21263720287430674, 0.09000460587201581, 0.25835322396409127, 0.2523812161938798, 0.09416118444454286, 0.20413831537289007, 0.14581196610966038, 0.19104639368672527, 0.21670531361333786, 0.1774313412005863, 0.2855912349637478, 0.13611798144636617, 0.13888564261217273, 0.23029701573954475, 0.15956114526958237, 0.11076616318595987, 0.24635703783602486, 0.5586552776155934, 0.1984780441008268, 0.1967297854923433, 6.285563880397428, 4.700457607546161, 0.5614168713650396, 5.474029414115414, 47.152631821170935, 65.7837567790862, 69.34190350194132, 70.20456606341948, 67.52155503919049, 66.50350386096586, 72.12194611949306, 68.75000215345814, 64.07415643815072, 68.0219082678518, 68.79801196436729, 52.998497024659194, 57.51932674838651, 53.76074690972605, 52.48515290598716, 47.77734379614554, 51.055923584968816, 50.56372104152557, 49.542739852782226, 49.026191157679406, 51.58878149524812, 48.447190484692975, 50.59636300609958, 53.74809334355017, 55.50158892908404, 57.50697128234371, 57.100711791746086, 59.344260461868785, 53.873542508771344, 52.41782542197935, 52.60369869970506, 54.60252285003663, 58.61895145908479, 57.164364014902425, 53.49228812802223, 56.890974813892, 55.949249036850475, 50.899805407370295, 55.407950185960345, 50.42002501026277, 53.39124787238337, 52.49783785112443, 56.13735022083406, 53.84063382302561, 53.023741399088216, 49.869979273888376, 53.1349798171751, 47.128297436621885, 50.67277469942647, 46.23690351363152, 46.41654022278325, 48.2559004137593, 49.31073950183008, 47.25728850210867, 47.9255780096977, 51.196418962171, 58.15624513933736, 61.80229610012424, 71.1097941860076, 61.1370111280872, 63.38800837916713, 60.48672137721893, 55.5454174933895, 62.75967213415331, 66.39330094860446, 60.470106217169, 53.604993512553555, 32.96759974571967, 4.7965267492878825, 0.27006680025689067, 0.2652417333616365, 0.2819304378522981, 0.2955791522418299, 0.3691371986942907, 0.3092289697979727, 0.19855839140232534, 0.23676667422536882, 0.3096081526769746, 0.21296545622810242, 0.06881584728797598, 0.08751890336674067, 0.1437996216719189, 0.17447704569466654, 0.2314082109519551, 0.19537043907950002, 0.31406096212806245, 0.148627461805459, 0.23517829816668268, 0.1857158466572723, 0.15162415261710846, 0.2804330117519825, 0.12674537832818686, 0.13270433962104783, 0.190854488661693, 0.08809232017806462, 0.23379592315083553, 0.19950875411591223, 0.16366912322419305, 0.1320712752039394, 0.19742936166303773, 0.17895490622087834, 0.3176730666910449, 0.20473583331031187, 6.347259331134058, 58.71713230686804, 39.25651234965171, 36.76094747358753, 13.791304557554184, 2.8205001498422315, 0.5903080694617764, 2.6067427425615253, 12.455451180857997, 58.19216620537543, 64.5125009167579, 108.94281956457324, 15.350939939098975, 0.13625581598570272, 0.10627036088056142, 0.32143958393604527, 0.1704463966551327, 0.1328294877443583, 0.12367490558854996], [0.03760820615195459, 0.10577248799945078, 0.06944870486134483, 0.11709194269872482, 0.10540092769529551, 0.23109716393293875, 3.5087152979066296, 17.90652982650265, 12.65073226344201, 4.117417383578516, 1.6315372071919905, 0.43564564278048856, 1.715440137251731, 0.47998092828258393, 12.893234760530534, 28.646320604508926, 32.4323982192624, 46.279535755034416, 11.716027529008928, 0.31838905246507737, 0.06671697321918703, 0.048512594413853465, 0.0714495962846183, 0.01082421524540311, 0.024768991974152388, 0.01397502379521968, 0.04363925631849035, 0.04501400875949091, 0.04441325793102865, 0.01762483712105501, 0.03872867485868835, 0.020486535579566995, 0.05219483049586416, 0.041641892730108196, 0.03163546868299525, 0.07419956081937398, 0.04321186352641352, 0.015052382819234364, 0.12819556744709132, 0.04952866065826628, 0.08162098395968638, 0.09092588788799702, 0.10776896675628041, 0.022318182858608426, 0.03214051406229696, 0.05630775354802609, 0.09763478031081539, 0.1258562490223877, 0.45396167123990677, 0.1789045742442531, 1.2372720794331644, 0.38642881438136106, 0.017283937570849256, 0.1528672681700799, 7.436749617899618, 45.495151935085175, 54.482529701725134, 61.34748158916351, 59.92884266761042, 62.64388376666654, 59.64030919536468, 58.530372573483376, 58.57154961555236, 57.99557308996878, 57.472501493269405, 53.7567029460784, 58.426720019309755, 52.60868010982391, 45.13453706618279, 44.7032214749244, 43.380288385575824, 43.63017082214356, 42.62218836815127, 46.139314943744296, 44.40662360960438, 46.214122387670706, 45.89181338587115, 51.40938012830673, 50.67232754922683, 48.84069442749024, 49.16428604433614, 47.72908295354536, 50.3318226721979, 48.71066393390779, 48.23705734745149, 48.16397966877107, 48.61374608932003, 45.4094442244499, 46.10589634987616, 46.36500812345936, 47.202088986673665, 46.9762114555605, 47.483930895405436, 45.714938025320734, 44.66691601660944, 46.12497475839431, 47.53507075771209, 47.20783525897611, 48.60996884684409, 44.80241037184193, 44.146060559057425, 41.775278045285134, 40.83333261551396, 40.2355908578442, 41.297639262291696, 39.253292083740234, 42.09833229741743, 39.09521664342573, 42.62330232128021, 46.84032878568096, 47.7419836290421, 50.81212082216817, 56.54743009997953, 59.77213221211588, 49.52858401883034, 49.628745663550596, 46.27378163799163, 52.213701355841856, 40.11125956812213, 24.867065952670192, 11.497675065071354, 0.833856123349359, 0.1392431911681929, 0.0953816774211103, 0.03533886602869438, 0.06293067941442132, 0.02082192887281699, 0.09732783952307317, 0.0675606275458009, 0.17761219923775043, 0.05122562584977958, 0.12274442285659815, 0.05691456030152979, 0.04673018360570554, 0.05432249797928718, 0.026296816443303422, 0.038466343370776986, 0.03473995764169001, 0.09076667949557306, 0.05424700767522859, 0.0374779329004307, 0.08055671163263821, 0.04817921593184433, 0.03137403926361473, 0.05662381078206724, 0.016363779788896922, 0.029493222546373165, 0.03738632793688486, 0.06811204997281875, 0.02363530442028517, 0.10315045248717071, 0.06866363327830069, 0.04038794086344781, 0.06372735722951832, 0.06414900819260268, 0.15834242195612, 0.2845170264763217, 21.04690294111929, 48.249601087262555, 18.750480721073767, 11.939978195774941, 5.450594723224641, 0.9714568526514116, 0.667221274587416, 2.985093588790586, 2.8675212783198205, 12.324496969099968, 31.636704244921287, 38.72162657399332, 3.5152445733547215, 1.5806746074268896, 0.2650479131167935, 0.0970571117115117, 0.1728751252014791, 0.10675917094152783, 0.05438833174506023, 0.0549438948773088, 0.027637696306731914, 0.05645354008001666, 0.1287704628081091, 0.15821103787710591, 0.05735337163411802, 2.925967045368687, 23.045574119014127, 12.605770134156751, 8.399204631005565, 3.3471099695851727, 1.042697391202373, 5.205301950054785, 2.9587982643035153, 19.277437425428822, 45.6258374644864, 39.51796970059795, 47.5995074549029, 18.435235907954556, 0.607144782139409, 0.08345846882871083, 0.1314679196765346, 0.05959271941514266, 0.08267874453937815, 0.024365131487889637, 0.05013976516502519, 0.05956193800234507, 0.03520011984472794, 0.04434678065139921, 0.09942460685007035, 0.02583411657401631, 0.005811097226180738, 0.02817874015759557, 0.05526753638180033, 0.014625610558376198, 0.028645827795468995, 0.013154222828997, 0.007594701216270728, 0.113054636355129, 0.05995485683782928, 0.04505339333967817, 0.030517796197185115, 0.029934211483886166, 0.041562464734118794, 0.018406432580142733, 0.02811433706102112, 0.05151182097653228, 0.12305759193916475, 0.23974507085738644, 0.17182271957637804, 0.9278887582402077, 0.25245977084963556, 0.02910372812391049, 0.15572108358385103, 4.46245014667511, 36.997956691249726, 51.41223169142201, 58.22314116262621, 56.66546598557503, 56.22181846249489, 55.69427928616924, 57.17629194259644, 57.71360958776167, 58.316030733047, 56.67517777412169, 56.02519396812686, 57.86402071675947, 53.87669609438989, 49.65845761760589, 47.64895677566529, 45.676071259283255, 46.26574077913838, 46.85878745971188, 46.667509155888716, 48.524986774690696, 47.420290439359604, 48.98071912027175, 55.649544654353974, 54.79857860072967, 51.17363783621019, 52.23070090816867, 50.619281415016424, 52.48373300798478, 49.326950657752256, 50.57593137987199, 50.37190929535897, 48.862294920029186, 47.20291660678002, 48.69229939676101, 50.13557472536641, 48.81456751977244, 50.29168898059476, 47.51192877369542, 48.92750040177376, 50.175178896996286, 49.38665305414508, 50.637304705958215, 49.07256926259687, 51.23744695417343, 48.26706740163988, 46.497039025829686, 43.85290261237852, 41.66244714490829, 43.976241542447, 44.62218530716435, 43.81111760293284, 44.130924132562455, 41.48673672829905, 45.572504997253425, 49.407888766258, 46.515203522097686, 51.2313162895941, 52.04464327904486, 59.1469495527206, 50.17853644586379, 48.773084532830026, 44.81979039407546, 43.56300415531282, 24.672798802775723, 13.7445891288019, 6.1247800434789355, 1.1292778292009908, 0.5058666102347836, 0.2849740132449135, 0.03459597524676112, 0.08655311164235877, 0.08033978617599896, 0.12976829232948442, 0.12300497702052518, 0.0943894709850992, 0.07848656586100979, 0.04489148065688149, 0.06183829549099169, 0.051551339622106285, 0.02987685065055567, 0.09105702681887536, 0.012788417760372884, 0.026628825543147903, 0.055639046890240525, 0.0722294508088981, 0.048325228459772565, 0.046548153454017256, 0.05301247230700908, 0.11108552991983392, 0.0810881315039531, 0.04214680595924297, 0.048695972880288485, 0.023173240403975212, 0.07778573330611953, 0.03969652352914695, 0.02449329799762176, 0.08523913295639139, 0.04470919386573857, 0.10805645657162513, 0.10605205646565846, 0.20320077697115563, 0.045831570131403786, 31.38208554637048, 57.90432307028002, 26.626043050519883, 19.703808869085005, 7.661307271449798, 0.7478342553780926, 1.3515685979397067, 3.763773301916738, 5.811538090628963, 17.442684058220156, 45.13172864913941, 56.9201611703442, 3.690462242211065, 2.934035605961277, 0.17477569741106805, 0.05336453567349142, 0.09632268620114173, 0.035118581276507146, 0.019428912895701585, 0.1888750706829371, 0.238343313817055, 0.16524531848488316, 0.28994577065590893, 0.22636378244046243, 0.36944433866489323, 4.769229994666192, 37.46118468623008, 26.071625832588445, 29.08747938371474, 2.402373528288257, 0.5617876579203914, 4.045068775453876, 1.8337800065355918, 32.99752743013444, 70.4158249209004, 44.720962355213786, 64.57030096361714, 21.438433931719874, 0.8048593889801734, 0.3484052966438955, 0.2838159028080202, 0.18045145898096024, 0.15420531733862816, 0.16046633943915367, 0.11749742537616722, 0.18718149543048876, 0.18873423307893739, 0.10678416839049709, 0.22424758712370552, 0.1619976879127564, 0.07425869514624919, 0.1738828832223531, 0.21626050764274216, 0.15166254894387338, 0.1582395976349231, 0.11243657960045723, 0.08760709540858384, 0.2110980862691518, 0.16508361264582605, 0.23979345697068402, 0.1589245108827468, 0.2922666493442751, 0.1484228397208837, 0.1487239275968844, 0.23124737845313167, 0.20544742173965902, 0.27683702567892693, 0.570472949935544, 0.29737924435927027, 3.1433482323923423, 0.4447379419880529, 0.1163108317902492, 0.24752207370775364, 13.613595693342148, 52.51431572821833, 57.65906510814544, 66.35775643010294, 61.14218473434449, 61.63472460162256, 59.314540663073146, 59.55557815490231, 62.87839443452897, 58.98365736007691, 60.48971414566041, 57.30971136400777, 56.97779647765621, 56.15866438035042, 52.31269413425077, 50.448736759924124, 49.558645063830966, 49.30658571181759, 49.0167696245255, 51.31305063924482, 51.386320514063684, 50.317878646235314, 52.249983279935776, 59.05103583489696, 57.848750929678644, 53.24048765244023, 54.76128078276112, 53.801923951795025, 57.804408534880615, 55.02365989069785, 54.78542297117172, 55.36825972218668, 56.42754677803286, 51.80884607376591, 53.735992831568566, 52.81001537076889, 53.10602880293324, 53.724943514793154, 52.40597594168879, 52.24725723266602, 50.68814646813178, 50.15514735252627, 55.548457330273045, 53.249732678936375, 55.23115327281337, 50.66148219570037, 49.522527879284276, 48.00509622020107, 45.94491051089379, 47.55393343587076, 47.90285571928948, 44.99197459989979, 48.62002580396591, 44.910812916294226, 48.226102167560214, 52.867321198986424, 48.38438549349385, 52.47392708255399, 55.83337829959009, 65.26032040196081, 53.1185450861531, 51.08779284261888, 47.182724245132945, 56.95282666913925, 48.49359996857182, 31.217750003260953, 21.479330524321526, 4.1151041657693925, 0.40398154347654314, 0.3810792530496275, 0.1186371343811193, 0.2814495797839857, 0.140439820505919, 0.18676189375260185, 0.2615852263425627, 0.1883144322181902, 0.17541809277909418, 0.12763569507026865, 0.2929200304131354, 0.22014604430765877, 0.21986610045836819, 0.1733209270863764, 0.12446393784616264, 0.08442535605882445, 0.20196003629074943, 0.11663330884109582, 0.16783448116433236, 0.2008561802006537, 0.22928587161004546, 0.22576180587132133, 0.17673892029110463, 0.08427003939305583, 0.1714963354771176, 0.12363283970062772, 0.23492127566808657, 0.3206646706788771, 0.14627023990596497, 0.3065986222317142, 0.2730964941363181, 0.20054367761458122, 0.1697794711517711, 0.2935644942185571, 0.33243870663066066, 29.94526840025379, 75.59746419229816, 38.60046848174065, 45.18192714260471, 15.16694449609326, 2.7203000168646536, 2.478792085762947, 5.262463140872217, 8.104467440036036, 45.67882868551439, 54.338013895096324, 71.73345888814619, 11.165042384978264, 2.97425068674549, 0.28768139861283765, 0.12476234441442836, 0.2670337049470794, 0.36283977209560336, 0.1516016296321346], [0.04751243598518833, 0.07813309289274678, 0.021174949849204674, 0.0507142506690035, 0.05213745434077517, 0.17339194343695719, 2.3880600640850687, 24.664963868356523, 15.998882151419117, 6.414980032751638, 2.019747053423236, 2.867074618416448, 1.5031221172501965, 0.27280305181780173, 1.2372465840270443, 20.821172498887588, 27.97403027934413, 39.61437371469314, 22.29512860698085, 0.07336809495163542, 0.04548987193453697, 0.09053486895056502, 0.09125524440840369, 0.021991480832859393, 0.043159352029643716, 0.039613115706390915, 0.11648825775351256, 0.06080043787557272, 0.03084131321238895, 0.06954184583117885, 0.10684861170668757, 0.11542669737771635, 0.050177820582663825, 0.051766679276742285, 0.07009137602102372, 0.07382422370175201, 0.08653958252961598, 0.05093329435875339, 0.03618182321529716, 0.0281778687325817, 0.024549572901319594, 0.02755254371872833, 0.043758478751706506, 0.09995862375944854, 0.019896908347765287, 0.08418172477714478, 0.047147268684761184, 0.03682398875694602, 0.06925729779346336, 0.2368668938476232, 0.10350823086956817, 0.10141619796594305, 0.1934272723813211, 0.09026074736949899, 0.41008456760356504, 4.727249847304437, 27.868022341882032, 39.74127415687808, 49.24659698240219, 50.03734288677093, 51.493997420034106, 54.62817907333375, 54.267379853033255, 56.084370766916585, 55.915249932196836, 52.295749495106364, 56.341776309474824, 50.84841843574278, 49.54698385730867, 43.581870755841656, 42.43808407937327, 43.692281553822184, 42.76679831166422, 45.05647797738352, 43.25880081422868, 46.61267834324991, 48.30272959124658, 50.45311412503643, 50.29512105449554, 47.73280920520906, 50.38122884688839, 49.36490743390976, 44.987314824135076, 43.696792279520345, 45.70620682931716, 44.8454152384112, 47.31623388105824, 42.99487629244405, 43.20734716230824, 46.761516601808616, 44.903097614165276, 44.57255163500386, 42.7924741468122, 46.57961668506746, 47.13394172729985, 48.76273339794528, 45.752749673781864, 49.63286415223153, 46.95207318952007, 42.809591370244185, 41.62820485330398, 42.56767134512625, 41.136084679634344, 40.83682744733749, 40.479989820911044, 39.59453436636156, 39.751676282575055, 39.17227945020122, 45.61583934291717, 48.90007126715876, 45.52240456304243, 49.987630767206994, 45.07705473130749, 47.05736137205555, 45.83592745565599, 39.99094086308634, 37.75715497232253, 12.229740350477158, 3.1871311991445483, 3.159198775406807, 1.3577953605882584, 0.2651667180320909, 1.2737120015005912, 0.8775312862088605, 0.6536946746130144, 0.05566610511572612, 0.159603034957282, 0.21805344449896968, 0.269468117865824, 0.3873265162110329, 0.040779204949015574, 0.01792662213706682, 0.11891299498177345, 0.08081236283384985, 0.04414435723916658, 0.0793589331630257, 0.06966222888760029, 0.04874092691968526, 0.11412401082775286, 0.05966404603133279, 0.0261085867250879, 0.04217546913892992, 0.030727505105577653, 0.06593103595678845, 0.07592821523787514, 0.04248486140802984, 0.0943780715967859, 0.015521633697883978, 0.05751985020094341, 0.043859985401673664, 0.08628337208421961, 0.10556355283986177, 0.04101920497393416, 0.002190349276192607, 0.09617149874928499, 0.0666180482855247, 0.3581192915237719, 46.15237643641811, 42.67305366454586, 22.510539293289188, 15.661331799722488, 5.755623232933783, 1.7947405336364624, 1.2088910346069646, 2.7757726273229046, 2.3120893922544297, 10.541674802380225, 17.22833437304343, 7.461185493776876, 38.00252276082193, 48.520142647527884, 3.593930751085282, 0.24890241092972218, 0.21504959842610746, 0.052910241703953476, 0.13563974339875484, 0.08749052747002534, 0.024034001473938266, 0.0383305236426813, 0.041236846722782626, 0.137685964244508, 0.17498497731022297, 3.5209859426944488, 32.028243080262214, 26.520474418517082, 8.48402294420427, 3.8247337985423306, 4.553259880312027, 3.3278489257058794, 0.6015554046438587, 10.758866244746793, 32.80864177211639, 37.600440594457815, 45.691031179120465, 33.167726916651574, 0.7328092487108323, 0.10140019438920483, 0.09244210612509521, 0.14097623527050018, 0.04822448023685044, 0.10634339204238308, 0.010239315733704115, 0.03744131006721047, 0.09189923323931233, 0.03172845643524441, 0.0713603930067151, 0.12167998965108588, 0.10487785052147605, 0.0841395286542754, 0.06125853164121509, 0.02246332013108317, 0.06670087005101866, 0.0724887639103878, 0.045162334872950474, 0.04779375113186337, 0.05586094808794799, 0.029018606179423874, 0.06791091358829891, 0.1064015994028699, 0.06810266539574632, 0.024054618815200466, 0.11333222065361277, 0.056545616187635935, 0.06543140873433122, 0.07902049083983706, 0.1305712444046813, 0.1416957603707429, 0.03928293181102603, 0.11238073945165643, 0.12473129487085728, 0.19619933089181302, 2.9650745468754924, 20.342329548251247, 35.447216264663204, 45.36945958291331, 48.10901941791658, 50.669020991171564, 52.54459642594861, 53.142475466574396, 57.18057909319478, 54.43074264834004, 56.299877551294145, 56.20409327168619, 50.63116227426837, 53.07315541851906, 46.50276568628127, 45.28376756175872, 44.51855236484159, 46.325141153027936, 47.82612631397863, 45.45002506625268, 47.53918140165268, 50.994597327324655, 54.811726385547274, 53.068295601875555, 53.120725923968905, 52.17658004453106, 51.989706562411406, 47.04034613024804, 44.91164053640058, 49.373269927117136, 46.80965977330362, 49.144587901330766, 48.43915747058008, 46.64335912273776, 49.29282211488294, 47.606042123609974, 48.96481783159318, 46.5515011356723, 47.90709187907558, 49.782549642747455, 49.88157380011774, 48.41812179934595, 50.9317256558326, 50.3299948476976, 48.20583528087985, 44.83029450139692, 45.50535401990337, 44.15075563615368, 43.24496661463092, 40.944967192988244, 42.45039639934417, 41.55544880897769, 45.074869971121515, 49.80488361850862, 52.036453370125066, 50.13167588941513, 52.57250016735446, 45.49501857449932, 44.85114189886278, 45.22620677947999, 38.32203903505879, 30.761119434910437, 3.7704185324330486, 5.4306779080821626, 3.4902509854685877, 1.8165183908516362, 0.6472610682249069, 1.35281725996925, 1.0576771680385837, 0.8164834555598998, 0.15428157373061105, 0.031120973609147534, 0.16128119652069386, 1.1591530519147073, 1.3370151337115996, 0.17050311780504643, 0.023448716045447418, 0.17062487981973157, 0.09016877851418911, 0.17007694309276922, 0.01689144774460264, 0.056042219812591235, 0.025502423485440594, 0.028989324383738063, 0.0826538926471145, 0.015363487294845045, 0.012955034223024645, 0.023804456633966298, 0.12111970358678412, 0.04781555016374877, 0.10743801677299124, 0.0661602724463709, 0.04937820865081684, 0.056016513732292, 0.06744736910707529, 0.02877484849323669, 0.07671897885419669, 0.015706433257418537, 0.038408059401497725, 0.017387211968701695, 0.02015621761881536, 0.6773417250763986, 60.17279840284779, 47.8162693977356, 29.76582977079576, 27.720172520606752, 8.071090031054712, 2.3137154598389906, 3.6575724328717882, 4.356271586110515, 6.300283555061587, 18.999602217828077, 32.49844308822386, 10.023225718928922, 58.84288741696266, 70.86223771495204, 4.865477113954483, 0.1301458664238453, 0.1331832824695495, 0.0213409342893189, 0.06860302040173162, 0.22898217903510218, 0.14274228244058548, 0.14762849847395576, 0.11787583450636557, 0.2668983831761345, 0.29395375881464253, 3.2615758238300203, 50.3579770365069, 47.59813854771276, 28.842974516653246, 1.7095696974185206, 8.106148665951144, 2.624823888463359, 1.2149248656726654, 23.681539374013102, 63.7951700149044, 45.885874917430264, 52.30466896487821, 48.222623025217366, 0.30131653792435126, 0.21031194216301366, 0.35119428569751404, 0.23693008077961786, 0.09947164464862117, 0.19427911618784552, 0.20384396907062302, 0.2617250527105024, 0.18872047413981732, 0.20669246783419964, 0.19633474459330882, 0.37129413456686083, 0.27423024297721926, 0.1552239997733024, 0.16154208010242832, 0.12695312605149325, 0.146649238923865, 0.18552558106039801, 0.15258634372824623, 0.10874732232262051, 0.23667820639187293, 0.16453052780801253, 0.18049636705508157, 0.1506731004243897, 0.27407491098969217, 0.18497372196326334, 0.3538128048662217, 0.2292233281919072, 0.20699125744642752, 0.23896505545464256, 0.6655216012750903, 0.3535967374280576, 0.2738476586678336, 0.2459537691526836, 0.24266490772847207, 1.1821956283623174, 16.778142375330773, 36.128551575445364, 44.87650394439698, 52.304339485783736, 53.31442825255856, 55.65888774010443, 53.92922839810772, 52.57624210849885, 60.7044364560035, 56.857093380343535, 58.77219846171718, 62.996657817594475, 52.12713464613884, 54.61466258571994, 47.40952745560677, 48.64760791101764, 48.10060593389696, 50.203172852916104, 50.829112529754646, 50.33113233504757, 51.70391482691611, 54.08790788342876, 54.70130382045623, 56.03647470474244, 53.88838475750339, 55.64086052679247, 55.383545198748195, 50.44803073329311, 48.21730821363388, 51.69544642971408, 52.23458797700944, 54.36303077205535, 51.184290993598204, 51.02779626846314, 51.6957837535489, 50.40146435460737, 50.50486587708997, 49.40646102351528, 51.988514161879024, 52.44306979640838, 52.31879341986872, 54.44417676618023, 56.326173120929354, 52.57040954405262, 50.575064536063906, 49.084489345550544, 49.399549807271654, 46.460847316249726, 45.79426011731548, 46.757441259199574, 46.967664610955026, 43.29113683392925, 45.886106337270434, 50.551212603046054, 53.694811867129424, 46.9961331736657, 51.82400995685209, 46.19709537875268, 47.644316611751435, 48.53357676536807, 40.98741508299305, 45.85732398494598, 29.51999325906077, 9.521332959974966, 7.159089446067811, 2.589335018588651, 0.35369868840902086, 1.0959849963265083, 1.0113569180811606, 0.8489252566810578, 0.21983525775853666, 0.3270794619475642, 0.4025218701891361, 1.8136946520497723, 1.1391846330896502, 0.2086044087885849, 0.13855106137212247, 0.2939857200028435, 0.3795244929290587, 0.1723412844923235, 0.254391722020603, 0.12977719427116458, 0.09991867993507655, 0.18154976859448418, 0.20559769754688587, 0.1787895844468186, 0.12710836610846943, 0.11105820356357483, 0.22175472169633836, 0.1451556585849293, 0.12381765841236039, 0.25581659959448927, 0.1249546937704567, 0.21987042119426115, 0.14737061795688447, 0.24633191015210845, 0.21899755593509446, 0.09512703745595871, 0.11736832423916749, 0.17493747985891758, 0.1238796042819177, 0.9380231208858952, 62.260087690045765, 60.68085908889771, 43.27533752687516, 45.43377468662877, 20.01791423366916, 5.597012879387026, 3.9707008821348992, 4.757700187544669, 5.570891364928215, 36.35673938259002, 45.009244795768495, 20.32573203886709, 76.9106815707299, 81.55660352399273, 4.368895244213843, 0.2548736985772848, 0.26717546185658825, 0.14465543381389112, 0.12005422084081559], [0.0985277477171152, 0.03147233792039896, 0.0857665155443453, 1.4864834229792319, 2.7430455963457785, 0.49066423889129396, 2.6436583745864133, 25.182506884298018, 14.489946346129141, 4.920286353557341, 0.5455538870826845, 1.4916571518105846, 3.4404503674276414, 0.44829712519722603, 2.788645846228446, 22.719201541716053, 30.54276304860269, 36.938697522686375, 37.360921059885335, 3.3141711306187416, 0.08048482960270298, 0.028715189396133347, 0.1109144471645836, 0.036197608456976955, 0.059021608528470805, 0.07785422922742945, 0.03155008243817476, 0.013347947312849424, 0.0997320915602388, 0.05317166920811419, 0.08543368864564166, 0.059249546499021595, 0.018470921861608664, 0.08833523899797471, 0.03555194572395375, 0.019245057539533705, 0.036951013795670964, 0.05836689829706185, 0.06527154150629236, 0.008496265565495818, 0.023409729830980785, 0.11698266791720545, 0.02232887936125119, 0.09678095233656707, 0.0988457661362425, 0.05110617359018615, 0.09136988946627225, 0.055321537919582865, 0.308718693953368, 0.03090498661021552, 0.15872485304792083, 0.13431462579436843, 0.03915702909111016, 0.04919209908093176, 0.18906423311320045, 0.9073487152495693, 3.0915783393767575, 5.785270958177506, 25.170237710399014, 31.86838100033422, 27.005087175676902, 37.033905213879, 56.92636243758663, 50.73126508343605, 50.407959799612726, 51.39240018783077, 46.485985786684104, 46.272655917752175, 49.29523437253891, 46.73559365733978, 43.786414515587595, 42.18604826158093, 43.59004497528077, 43.86776447296143, 43.178772695602916, 43.68451918325117, 49.26520862886983, 49.87858495404644, 51.543368293393044, 50.22432619525541, 50.92810923053373, 46.05182255468061, 44.66504112366707, 41.693069088843565, 44.87192653840588, 40.604179905306914, 47.23640580331126, 44.445129517586004, 43.669641633187574, 46.28739226248957, 45.194302220498365, 45.84551765072731, 40.665757194642104, 42.41715431213379, 44.67626302473007, 46.682990750958844, 48.31803467965896, 44.29431046209028, 47.81401011251634, 45.26371248306767, 41.59133849605438, 43.93858286642259, 40.14634909168367, 39.67961842013944, 38.3122762556999, 38.00127544710713, 38.0997779292445, 43.89952782661685, 51.82748517682476, 53.653697582983206, 59.84348012555031, 52.79307073162448, 44.607166551774554, 39.64850617993263, 35.7625630594069, 31.407584874860703, 4.193026461908895, 4.085529984966401, 2.9604525239236894, 1.4536482816742313, 1.7237706386273908, 2.669420501878185, 2.6202182904366524, 2.5906205754126272, 1.5517238383331609, 0.9140742930673784, 0.14275360522010636, 0.14915347309602847, 0.22619967108532307, 17.716910685262373, 3.704197647110109, 0.7161242827292412, 0.16676575786644415, 0.026399793982085203, 0.008287395523380368, 0.036167482049354625, 0.057944473585173975, 0.06967568139155066, 0.07566799049175556, 0.03549410608567057, 0.06206549418669555, 0.02217531512160936, 0.02342537334639459, 0.022324060668207468, 0.02875283878717211, 0.1016420866512964, 0.03967297398635457, 0.1110056882363654, 0.027793436236078703, 0.05198739686860673, 0.04620413784117949, 0.10953460789976582, 0.027769241264210116, 0.04633115904946481, 0.02039984698527523, 0.03279135938012793, 2.1166134169024806, 66.79859945850988, 29.96013810557704, 21.80410473577438, 18.403197988387078, 12.276488138783364, 5.819454904525511, 1.6546976998929055, 0.28924921287163613, 1.0402414971782317, 1.1939145672705866, 2.3011199937712763, 5.813822871254337, 50.50335184220345, 75.27594750927341, 12.059578126476659, 0.09464224169571554, 0.14302339074352097, 0.06127737740415239, 0.08016113447205675, 0.03214399976235244, 0.004273324626527968, 0.07556481377011345, 2.086445242166519, 5.25021848178679, 0.6787667099025942, 1.9513035325273393, 34.44167744728827, 30.473170395820375, 6.0963247187675975, 1.6493255236456472, 2.7451602441649285, 3.6627048542422638, 3.2549467730906705, 2.3503192634351793, 39.28915039185555, 44.53908989506383, 37.85032303102555, 52.00496458238172, 9.658933627989985, 0.41455361811864766, 0.14241366136458614, 0.17920400737033737, 0.010582996183075013, 0.07211619237017247, 0.10669141046462521, 0.019297902284550573, 0.05137804670319442, 0.035431869102702025, 0.16400100783474986, 0.007840054280560223, 0.11865503785590972, 0.06365561309540946, 0.13307314966955494, 0.006552283462482475, 0.04310602081879493, 0.03596021696144054, 0.04666785469218608, 0.14209932016749538, 0.04418910060438418, 0.024287476985444947, 0.04924552222233146, 0.040545866058598605, 0.12299771450700299, 0.06288343477213094, 0.0921961076317295, 0.06981372277462675, 0.17587685687167032, 0.11864108739480858, 0.07693517652730789, 0.10040799561407297, 0.11250734314202301, 0.1095278203607567, 0.22284570750930618, 0.17835366509614453, 1.3496927244047965, 2.8012746524426246, 4.92623511821993, 18.30226952029813, 30.95997379672143, 28.103266492966686, 36.77090637145504, 51.82335492103331, 50.0240146729254, 51.180682413039676, 51.47139672310122, 49.45560832177439, 49.077448691091234, 53.18056560331776, 50.438538597476104, 47.835022249529445, 46.071065702746, 47.193816707980254, 48.12568556877875, 47.5383851605077, 46.824094095537745, 51.328018403822384, 54.671395747892326, 55.53989087381671, 55.39134679302093, 53.16049875751619, 48.703023156812115, 44.03229613457957, 43.51518654054211, 46.78479194641114, 44.58899028839604, 48.547289371490486, 48.73328424269154, 48.12564242270685, 48.74492583736297, 46.75507606998567, 49.29201410662744, 43.56633424758912, 44.364618947429044, 49.06035500188028, 51.327771294501524, 51.14227848668253, 48.539252435007405, 52.40599163116948, 48.07268650301042, 46.60567299012215, 46.87242554080102, 43.7267081968246, 42.57386084525816, 39.71273106913413, 38.98420180043867, 41.81787498535649, 49.367225554681596, 54.965118515876036, 58.079907971043745, 63.74778386085265, 55.26164185616278, 46.97823539856942, 42.096343655740064, 36.54982197669245, 27.509743244417255, 7.872987293427991, 4.929993729437552, 3.2755245076071833, 2.3841259268022355, 2.453793840062234, 3.5996824166467114, 3.6160725307080055, 3.3524784686103946, 2.2351069940674693, 1.2613719797903493, 0.12310306691835005, 0.068263505555449, 1.3795811851178448, 27.152619284968225, 9.616249415182299, 1.0598092213753731, 0.17783373654369386, 0.06834263477714793, 0.05490277127753343, 0.08131738331529402, 0.05338511662557722, 0.11507046649292593, 0.0755654649448491, 0.00613650935138726, 0.08686809635330593, 0.07547647617156468, 0.0947303418070078, 0.03123447911122874, 0.06213163821807793, 0.0868129839880332, 0.06156341165244099, 0.04727832717640747, 0.03889681966674905, 0.04487652279015991, 0.05089479461011868, 0.06827552547498096, 0.0492390143054147, 0.12491619785226162, 0.10489297309710134, 0.12118623066212862, 6.891863269190635, 80.13617992401123, 31.09391881573585, 29.006098047379528, 32.082107028653546, 16.21909774118854, 1.491973147757592, 4.4230033601484, 0.2999683151081685, 1.4972956815073568, 3.9419788362518435, 7.60797921688326, 11.644999288743543, 67.06757991544663, 95.04004124672183, 12.427506254565332, 0.11327935292595818, 0.13811970790547712, 0.11003067281337515, 0.02557386884525899, 0.24927359585079456, 0.3017949751548229, 0.1832886502867745, 3.8463921460413166, 5.417476680970961, 0.7236491047566938, 2.7931190642618366, 45.50939798355103, 47.05291340428014, 20.17292041932383, 0.279297485587097, 10.416735545281442, 3.224230447123128, 2.86453856095191, 13.277872185553274, 72.16977550137427, 54.08112610540083, 48.41180678336851, 69.14796583114132, 8.620490047239489, 0.5616341339003655, 0.2249126280507734, 0.21849618203216986, 0.15775398982148017, 0.22698469670309177, 0.2084470390071792, 0.14049974390335623, 0.19183667466765453, 0.16515449110058047, 0.31274016525956894, 0.17397403236358397, 0.2153788630159632, 0.14025554571661258, 0.15076356008648872, 0.1618786684928402, 0.17862110639051085, 0.15764713587780155, 0.2634883419640603, 0.283972644397328, 0.33210083121253603, 0.11326882687787856, 0.18259904858085418, 0.16999267342109836, 0.19471593952227026, 0.25587738101040164, 0.22854284293228583, 0.286719590545662, 0.26547995606257074, 0.30631740667646934, 0.12332701740125496, 0.3328531601976964, 0.2584837040593547, 0.1917475633203022, 0.43219423282050323, 0.2579976365931573, 2.4188195361245066, 6.672697894034847, 12.368400058438702, 31.45474353144246, 34.31224707634219, 33.21092397935929, 48.36732710561445, 58.49656566496819, 51.318640016740375, 52.32367284836308, 53.26528095429944, 52.37627183237384, 49.6908171715275, 53.57683089471633, 51.97810026907152, 51.28851621381698, 47.9132656897268, 51.32901076347598, 51.23797647414669, 50.75597209315146, 48.40400518909578, 54.22500648806172, 56.72112834069037, 57.65150670082339, 56.35284916047127, 56.54416276562599, 52.854432290600194, 47.55707133200861, 47.11960938669021, 51.067016047816125, 47.846899186411214, 53.35378923723775, 51.356400674389256, 50.68990368996897, 51.771191320111676, 52.22391913014074, 54.53662703114172, 43.501838714845725, 47.92520930690151, 51.00556427432645, 53.31740925388952, 54.78970227702972, 50.95857427966211, 54.268129025736165, 50.331155869268606, 49.02579499829201, 50.50841562209591, 47.170317788277906, 45.062247783907004, 42.682157485715805, 41.86522191570651, 44.412734662332845, 49.287958375869266, 55.41616362910117, 55.42307484534479, 63.45773635372039, 54.11634898954823, 45.88880885031916, 43.894660165233, 38.71109108771048, 38.395187316402314, 21.289876122628492, 6.365163970378138, 4.780220475889021, 2.2772300627923783, 1.9792919726141038, 3.4346692840899196, 3.3699771425416394, 3.233924585004007, 2.354237711237323, 1.1792875586017486, 0.2199207072056109, 0.15462802933348765, 2.3467800597990713, 30.56718960885079, 12.247230199075515, 1.3405452668666842, 0.6639770454456729, 0.15681416847773139, 0.22580354234143613, 0.1482106486876165, 0.12309806436420449, 0.29320152176003306, 0.23352661260193397, 0.17496150437622301, 0.28784197064176686, 0.18396358906982407, 0.16950144252229124, 0.11582508608097992, 0.11077809883582015, 0.2120674019979854, 0.18487736342414735, 0.1228054800641633, 0.18602087222520383, 0.13984067846209774, 0.154933238762521, 0.2841157496215836, 0.09982071261131957, 0.23578435032358094, 0.2521511293467014, 0.34526222175167454, 6.462455911021079, 92.46405601501466, 41.79783167377595, 44.047989537639005, 40.450536743287124, 32.84800275679558, 20.664089418226673, 5.034056171294182, 0.593290725542653, 2.7356136854617827, 8.447669436854701, 3.219936432376985, 30.007318335194743, 73.17114091688588, 99.21709091432633, 17.545352097480528, 0.3908826657120259, 0.3806258209290043, 0.21668553322313294, 0.23343857377767566], [0.10269987021362591, 0.07097252269065188, 0.28061138766427196, 10.303174103460005, 59.98565819955642, 21.373169614422707, 1.4543474441574467, 14.039595492424505, 6.764165605268171, 2.2770839545034596, 3.3197823262983754, 3.6935797910536494, 1.4475237457982957, 2.6414924908068875, 4.802296065515088, 13.232753161461124, 31.220393680757095, 34.62129846695931, 33.44701144003099, 13.387320041656496, 0.11651464182162478, 0.06009773606614721, 0.021781134156269893, 0.04282837140283758, 0.014329841247789804, 0.06769253256460352, 0.07781104485113775, 0.01905040225885328, 0.05282673045932766, 0.14270019357002553, 0.10433557518427411, 0.043775148824938846, 0.049017082464190266, 0.03943015858831425, 0.07600851657409823, 0.09478263496871918, 0.07082283677112672, 0.0688025709842482, 0.24012429970166377, 0.02172346114211025, 0.11936614364986459, 0.05282162448331233, 0.05270506037519344, 0.02818825305439532, 0.13247452856552216, 0.08086249562761477, 0.1842739312879501, 1.470097476436246, 1.0093007380923917, 0.07218418267345236, 0.07145246145345512, 0.027489841337345784, 0.05446599773882378, 0.08481507264678517, 0.32067150418316165, 0.45704287687136286, 0.48184151070252546, 1.3680571389775122, 1.564076485172395, 13.217281372316423, 21.127036963739705, 15.022716983672112, 30.245727839008456, 49.72832287511518, 47.672110526792466, 50.36784179749028, 49.07546397178404, 48.199124105515025, 49.049156635038315, 47.32759306507726, 46.74821584455429, 45.95058225816297, 46.07104609089513, 43.54571826996342, 42.83432975892098, 43.57835238979709, 48.55301210957189, 51.29185022846345, 51.354188457612075, 52.4034381681873, 46.673129912345644, 41.164819963516734, 40.996165890847486, 40.21833242908601, 40.37263062692458, 40.55838623354512, 45.970413761754195, 45.9265616632277, 45.06577399469192, 47.409680428043494, 43.127593609594534, 42.42772509974819, 42.080418832840465, 41.68719337832543, 45.30325781914496, 47.42796651778683, 47.10104480866463, 49.52214348700739, 49.85540766869822, 46.025911377322295, 45.27827624351748, 42.40151189988659, 39.720171805351015, 37.552430783548665, 36.61756523193852, 35.331561257762296, 40.34802952120381, 49.944786717814786, 57.87499550850161, 61.39074533216415, 57.94778293178928, 54.32440327059839, 46.239511889796105, 33.86588135073262, 31.5213434157833, 10.330975863241381, 5.202493533011406, 3.629701296167989, 1.7326402207536085, 2.606365704728711, 6.091844391438269, 7.527592691683001, 7.658020815541668, 5.657166838645936, 2.636418414692725, 1.126408247697738, 0.19774590919335044, 0.11315413585473454, 0.38077649510195183, 1.540897606361297, 3.051441951144126, 0.14515231844157944, 0.06948023704030822, 0.010494018901109455, 0.02953982750524677, 0.06369772111816753, 0.11347807613351654, 0.10608797832842796, 0.06372349997681957, 0.04941017749989706, 0.01985613714843508, 0.18280684226943603, 0.06463924317710823, 0.03393088452397816, 0.05898911107872283, 0.15949760593714254, 0.2979212975309741, 0.16625876087815533, 0.021185931719599232, 0.021697469694059224, 0.054796457425841404, 0.10497070037789884, 0.030950917411715757, 0.09705541865719904, 0.07243627922669535, 0.29652003078691425, 16.378324397148624, 58.19849691083355, 25.512717500809703, 31.466936219123106, 17.433417458688062, 15.963819103856242, 13.158434052621166, 9.267909603734171, 1.4567997835336195, 0.21931399621309774, 0.38048207219089236, 3.862716070105953, 24.832092139028735, 48.31095087912775, 49.97200012207032, 6.288702757127824, 0.022423044973683935, 0.02679715804275005, 0.05760512727823469, 0.042306665526402575, 0.055203418652977676, 0.11802826302065966, 0.2582322740026059, 15.63785151127846, 79.21931020675167, 32.752010591568485, 1.877927998861959, 23.334693985600627, 25.191189050674442, 0.5456314151806216, 7.602488879234561, 2.728143531468607, 1.6056846202381196, 7.74096864846445, 7.9640559034962815, 28.978610077211936, 51.056190306140536, 34.26792821576519, 38.854794963713616, 40.38488018897272, 0.4394549690186978, 0.27089252046519713, 0.15350313646899116, 0.11530249154255276, 0.10465930095843731, 0.1655533011522024, 0.03954420992804151, 0.06026915973052383, 0.060660531068401, 0.03277277408708488, 0.08816235593610233, 0.18360722028920728, 0.08891427123378362, 0.032044458127911055, 0.09764232627686956, 0.19306992300816123, 0.0994405797832916, 0.013754154900990188, 0.2602113242591581, 0.0061169190467485505, 0.13388933974408335, 0.03636756123253896, 0.08362579775313217, 0.03296274474010833, 0.14208196061513118, 0.1130258237882968, 0.7626233682517083, 1.173439672397029, 1.6816695106606332, 0.15426819783545312, 0.10585133376861773, 0.08799764703238204, 0.07726080986040254, 0.3325819650725011, 0.3249772553963046, 0.6922637082396016, 1.1462684336208528, 1.3151660609629847, 1.3472782604156004, 9.680923415768532, 17.777319108286214, 17.75681687939552, 34.04813820315946, 48.223230992594075, 46.94890391442084, 50.85891077595373, 49.58337953013759, 50.01048249583091, 50.49496581477504, 50.0389628256521, 48.935733456765455, 49.92556318160027, 48.14491694973361, 46.43422226752005, 44.810906225635165, 47.736347183104485, 50.58062253459808, 54.688603185838275, 52.87604062787948, 55.70448137098744, 50.58591773433071, 43.32654014710457, 43.7579498752471, 44.05475562618625, 43.925152670952585, 45.27302811222692, 50.33498802492696, 50.64830695429156, 47.19127501210859, 50.67683827492499, 46.47647796138641, 45.548100010041274, 44.00303133072392, 43.454648679302586, 46.571348328744214, 50.55656271596109, 51.73299527937367, 52.153351768370605, 50.583172075210086, 50.95884100083382, 48.138119482224994, 47.47346208941552, 42.31029325915922, 41.83501574300951, 40.431175924116566, 38.44334225500784, 43.08835814076085, 53.76632844248126, 60.57303313286074, 63.9375049837174, 58.89778883226457, 55.599444220142985, 43.9535584757405, 38.18022966384888, 31.102365639901933, 13.556323205271076, 5.848887880002299, 2.0938516576443953, 2.106150249319692, 3.31536965985452, 6.85496945534983, 8.522713203583995, 8.431863265652812, 6.3477692392564595, 2.516528718894528, 0.7323448768546506, 0.21610764245833122, 0.14572630215796734, 0.1342035736888647, 1.3385060020992834, 1.9785060276908262, 0.07037036992128819, 0.0238168959866368, 0.059200218097577174, 0.02674115701548515, 0.09107296144770038, 0.10612589968067986, 0.09011903642526559, 0.0831686347843178, 0.005686794193611751, 0.015901846965144, 0.09624118210687753, 0.042309714556341214, 0.09204197840224351, 0.12216890696436168, 0.22706102970386707, 0.43591150593373085, 0.08864807100185464, 0.0330730039446104, 0.04089639724923238, 0.0447010733337412, 0.10331021246290016, 0.10200211733219125, 0.09254814035469487, 0.05399194636171865, 0.16084946001008635, 26.649147772019912, 61.31943664243145, 27.878789248005038, 43.51277820525631, 32.844660897408765, 21.489499268993256, 10.455123782157898, 4.517211337243357, 1.5132156014442446, 0.2640557679678163, 0.8210888084384703, 12.993864147893845, 51.30260144510577, 62.45355467642508, 65.07082285419588, 6.435755846961853, 0.06903497141695793, 0.05105448180749532, 0.05878392974996279, 0.05998563442018725, 0.2690370248690728, 0.3716063307177636, 0.9145482869878893, 22.46278247525615, 101.70706641289496, 47.02729248231458, 1.5294522527725467, 32.2042025673774, 49.69598293304444, 14.418713162022254, 4.186013264040794, 5.253084263493938, 0.7489149296475995, 2.103044222439489, 8.735575329872871, 53.053712229574884, 62.581478857224994, 40.92735575091454, 55.556764910298014, 40.474031740619296, 0.173149936261677, 0.276154441338393, 0.24076784420157635, 0.13794995814321503, 0.17958832303843192, 0.2041842653265884, 0.23319613759315785, 0.16740496630870527, 0.12202685128056234, 0.2749214075025051, 0.24354206308001475, 0.4130140571824966, 0.2566604301213257, 0.13014010544265472, 0.13574868110158753, 0.29796612899630304, 0.23948484611126686, 0.29892104227216015, 0.4899351683355147, 0.19574157803529696, 0.32314636654430823, 0.2279881493098313, 0.19568761480191063, 0.13902798174850403, 0.3128908700760334, 0.13173496260518028, 0.5055937603596719, 1.5962949563418667, 1.4154377771962074, 0.3231106055600028, 0.1257625947736444, 0.17965708709051534, 0.19973415250499404, 0.2622296901479844, 0.4872189882782198, 0.8299257245755965, 1.4276086466927684, 2.225985767379884, 4.863920423292345, 17.524512544755016, 21.170508592359482, 26.700930903034827, 44.65837701674431, 53.44579235199959, 50.32251488777899, 52.55028778506864, 50.002210217137495, 51.818200926626886, 53.12591914207705, 54.1051310108554, 51.015852651288434, 52.17440312908542, 52.3546987964261, 48.55312978067706, 49.21240175923994, 50.01010594829437, 53.11658782343711, 58.611094951629646, 58.28615796181464, 58.38455453995736, 53.194807729413434, 45.529609957048976, 46.10721818862423, 47.194671784677816, 45.662911707355136, 48.1574724566552, 53.90037936549033, 53.19072454206405, 52.18040827781924, 56.627685716075284, 51.352156669862815, 48.13633088142642, 46.746262504208474, 46.823862675697576, 50.42667342770485, 50.51600148600917, 56.28804376048427, 55.76406217390492, 55.45711709607033, 52.28430794131372, 53.250375947644635, 51.0352683836414, 47.8823652575093, 46.49216744207567, 44.72160170155187, 41.754293364863244, 47.04895965514645, 55.3470043982229, 59.051702637826246, 64.74293231964111, 61.63513645049065, 56.595522280662294, 46.41869752637802, 35.601459549319365, 35.61321489272579, 22.732033575734786, 7.111888133710431, 4.6405301651647015, 1.9472284350664386, 3.3245063308746587, 7.196449041366578, 8.299196939314566, 8.646899365609693, 8.28131877606915, 3.381898206087851, 1.9044177258206954, 0.353816696592877, 0.18083710764204303, 0.3914966698615782, 3.2938010365732255, 6.3086078051597845, 0.2760935220266542, 0.18781241480140917, 0.09018821416482811, 0.15189936204302698, 0.2019127227005459, 0.245311327819382, 0.23501221030469865, 0.12697299071136983, 0.2213862946917934, 0.11372389842665966, 0.29594978557959684, 0.15818223297115297, 0.15373858593163953, 0.19257726718581494, 0.36460327585378005, 0.5410993615946462, 0.33201052476802184, 0.12485365443412336, 0.10223281704970907, 0.19338743580925852, 0.24636491321988646, 0.23650716960189805, 0.2238391856512716, 0.19688881002366546, 0.28096020281795536, 25.60143170818206, 78.32655522131151, 38.12408485720235, 54.45452790106497, 40.49844849494196, 34.36787413012597, 31.109700472124164, 20.69724521329326, 5.457249514518246, 0.5336260206757054, 0.6087173461433381, 14.010990627350347, 65.89960790449574, 66.84727607234832, 72.43298222941738, 8.836202756051096, 0.2308849116126376, 0.22559570268757884, 0.2765445333094366, 0.12774511540849365], [0.066542933364549, 0.1168696929310118, 0.16340476160328235, 9.61451768875122, 80.1077348955216, 71.59714083517753, 8.790544406060251, 9.190406510906836, 9.341563870829921, 3.074125998443173, 2.268124035289211, 2.9508873339622252, 2.794164130764623, 0.4201263868279996, 5.899464882189228, 9.437440326136928, 41.744977735704, 41.2332574782833, 29.329807335330596, 47.9280294910554, 3.5882114450777736, 0.5423883504925237, 0.15916590518768758, 0.1148753285768532, 0.023388706463118716, 0.10082209678066355, 0.1050902637202413, 0.04789344215344998, 0.1697341187466537, 0.04755077485535895, 0.1046749214912134, 0.1096504174112793, 0.024057355664309957, 0.09256212145931299, 0.028428896593170303, 0.06744933795304069, 0.11160637011691449, 0.593607947230339, 0.17188871039017556, 0.26047292796354143, 0.0795400899744803, 0.018667310416217775, 0.05266844903329208, 0.10944420952470073, 0.18875579079312665, 0.16555002229588647, 1.6371240106321152, 6.492777793638169, 0.5795802031793903, 0.23998531603044082, 0.07718123630770753, 0.05785119471951358, 0.03909882556106295, 0.28275358400517897, 0.5159815448907115, 1.1962963039836576, 2.201171382780998, 0.5398426096766227, 0.34349470369277463, 1.8211478908215801, 5.694021428785017, 9.535513308740432, 8.345533859345222, 32.77073206440095, 47.094427770183934, 47.15650712290118, 49.251774511029645, 47.8816003953257, 48.259097145449736, 48.27818339870822, 46.156898929226784, 49.21178986949306, 44.14093402124221, 43.71816135221913, 42.12919350593321, 43.4933271715718, 48.28857767966486, 50.21080578527143, 50.377510439965036, 46.78459190553235, 43.59144133906211, 40.09118487758022, 40.735912707544145, 40.31638776102374, 42.17640315332721, 44.71902470434866, 45.26628555790071, 47.342125446565696, 44.69027373098558, 44.11747824761176, 41.9180719314083, 45.54012190911078, 37.56030690285468, 39.77244523263747, 40.77802327371413, 45.94207855962938, 48.804679224568034, 45.885282639534246, 46.78776118063158, 45.68526137259699, 41.70864482079783, 41.36944217066611, 35.975284960962114, 36.594882165232015, 34.78498289662023, 38.70101451873779, 40.138990725240404, 50.91614207913799, 63.18886964551864, 57.20033214938257, 56.017655172655665, 51.853004117165845, 40.59710787188622, 41.58057551230154, 18.435630106156875, 8.781925978199128, 2.0371639704512012, 1.6624253820027075, 1.5688829820963646, 4.426202543320195, 6.726351015029415, 7.295230502082456, 5.2618340907558325, 2.137546371067724, 0.40868277991971663, 0.15455028673093166, 0.0284380417677664, 0.059140712218058694, 0.11366111752126487, 0.05982771688591569, 0.08686288695542083, 0.04909292899913365, 0.013111771981892808, 0.09204432263129181, 0.016705868690605127, 0.10592738331686105, 0.12063344459860556, 0.11290203930149156, 0.12293073543978315, 0.027604340838508743, 0.1671198283832881, 0.4997388261460489, 0.4037609101543504, 0.08232173224490497, 0.33924567362954544, 1.3214886765326224, 1.3227969095591576, 0.8235270517968363, 0.05539904303488232, 0.0428584250321071, 0.11845518083822344, 0.08330480691285864, 0.06418619793088687, 0.1819836348295212, 0.07551714777946472, 0.21863803087222963, 33.77085016619775, 41.428783709003085, 29.551382026364728, 39.80645218203145, 46.69805265242054, 37.514442628429784, 22.482784601949877, 12.226684824112924, 3.320217464239367, 0.9603119281030471, 5.307336526532327, 31.995126508897354, 56.723795552407545, 48.03108584496283, 53.673078014004616, 2.5013398306985057, 0.08698661015519212, 0.12971652010756154, 0.16821314310354574, 0.1403829767819374, 0.05993768114656691, 0.07778648407228532, 0.08100328726633903, 21.51812276532573, 96.06715310004451, 89.76481422301262, 19.9629775170357, 16.889319996679983, 15.80457675841547, 6.2001282841928544, 12.818846029620017, 8.048631520040574, 5.07348628774766, 0.5006729324738826, 9.95722399603936, 15.550851379671405, 61.92994179264192, 43.13152382450719, 36.434908297754106, 80.00132883748701, 11.075142641221325, 0.34753002586864656, 0.09973255887387261, 0.042994229438444304, 0.018867439395117185, 0.01755586047957261, 0.035494581060183626, 0.06385729340235553, 0.09654730318054076, 0.034136759162309675, 0.0851585788111533, 0.034616376168184707, 0.018216241676841053, 0.15417677290256948, 0.14407855428514943, 0.46173093660223874, 0.24600713483748898, 0.7595227959175265, 0.2583428051683211, 0.4417360111350014, 0.12549496195729704, 0.1451061539832623, 0.13193060613928304, 0.15191728850045513, 0.1631146900716328, 0.2140590314182543, 5.009544299494836, 8.602306919713175, 0.7267697179509748, 0.3047326159092688, 0.08070231430352696, 0.08929410528752113, 0.05992713977672881, 0.2869558520615101, 0.18142541720261499, 1.7038313924304902, 2.0454834401607513, 1.661902235880975, 0.8831663225446978, 2.11768961721851, 3.334788088836978, 6.449701834109522, 11.48156883255128, 35.606260530410275, 45.680456469135905, 47.68872176447223, 50.06349725107993, 48.030544557879054, 50.19504962428924, 52.33185491254253, 49.07995508563135, 50.133515481025945, 47.657527154491795, 46.70765461460237, 45.8489183456667, 47.33486513937674, 52.17709387502363, 54.64102483564808, 53.133705046869096, 50.432976676571755, 48.07237271339663, 42.483050131028705, 42.311560184724875, 43.40025324975291, 44.337625195903165, 45.865972811175936, 48.211373667563166, 50.36462545394898, 48.82913128022225, 49.54261433693671, 45.071790910536244, 44.62264030210434, 41.40837561699652, 42.21466979672832, 44.408992721188454, 50.27698401481875, 50.90890530617007, 51.694493293762214, 49.79384214647355, 48.29162928365892, 44.51644997442923, 43.05735572691887, 39.530446760116085, 40.63070297241211, 39.59440885051605, 43.84753288761262, 44.758797537895944, 48.958122345709036, 60.560658054967085, 59.22364757907007, 56.59437694857198, 51.205008952848374, 43.62333020856304, 35.8977710816168, 12.151989167736424, 3.045313002601747, 1.1563942773688225, 0.46232171296592683, 1.2025817796107263, 2.315403549901901, 3.6489392961225207, 4.701035666850306, 3.566997796297074, 1.6283950209617617, 0.16396212121171339, 0.15695348922764102, 0.07505960942756745, 0.06832299228276938, 0.09407329117699016, 0.0110345063806181, 0.046216908526877244, 0.06889458580483353, 0.03585399504029944, 0.10359429318698184, 0.03596626905604236, 0.23255775652585492, 0.1990473546808766, 0.040494396441405824, 0.11279599741101266, 0.05747518727495786, 0.2002813537875491, 0.3365252341233915, 0.33644620449312274, 0.40095914275415484, 0.43163572408018575, 1.6315351234328364, 2.2129470734826984, 1.7038681646508558, 0.1415853671008541, 0.015525671938854842, 0.1303762750279519, 0.03989463003592626, 0.029911092865551193, 0.08834481509702821, 0.06925124569886154, 0.5155233630249577, 45.02860953730922, 49.618657327467396, 39.35456768158944, 48.47457647323609, 57.78514969733454, 69.21969813685264, 38.81761873922041, 12.216691605506405, 7.443454909709192, 3.013146870559262, 10.55252407827685, 56.7615601324266, 72.31284787577968, 66.65563691046931, 59.31974564829181, 2.2557673435057364, 0.05270644316389676, 0.07012475447188463, 0.11073607891317337, 0.23521448816022567, 0.17236817417846573, 0.2650354412053862, 0.1410394834895288, 38.924052253846206, 107.51278615766957, 123.28406395450716, 26.064559682723015, 17.43648082979264, 42.43933139308807, 12.505587896993084, 7.282634790866607, 5.893171439247747, 4.033799805948812, 0.26164694238574276, 12.005837732745755, 37.69475006288098, 63.99846646093554, 53.44344677463655, 44.45792036671793, 82.35595118614935, 10.452868419308817, 0.6710885477162177, 0.22397315910746976, 0.14118404428084053, 0.1864383901439367, 0.223950038573915, 0.1864081449926861, 0.2022492498039238, 0.24241240514862925, 0.1316171842477014, 0.32062051337092157, 0.27190069217355023, 0.1467762563017107, 0.27084330697694137, 0.33137562173989515, 0.6306329153237805, 0.46005400077950576, 1.2254202702353079, 0.4743693035937125, 0.5588442868282718, 0.2722546554380848, 0.22723292451231714, 0.2633621519611728, 0.3198381537391294, 0.35657951608300215, 0.6670440937722883, 9.285834835421655, 14.812373999626407, 1.0924152717474969, 0.6008781829187947, 0.14944716056268062, 0.17208387894976526, 0.3216436697590736, 0.5823683955015675, 0.5532311912505858, 2.2425798446901384, 2.0722173346627146, 3.1477542798365317, 1.5155866742134096, 3.7276666587398903, 7.8472202631735035, 10.581679055767676, 24.75873597206608, 50.06128111193257, 51.098124365652765, 51.1705195519232, 52.1712613105774, 48.564908658304525, 52.595924562023534, 57.427433459989494, 50.358788967132575, 54.229834925743845, 49.986932585316325, 51.39386323190505, 47.88149449133104, 51.570444414692545, 55.04687247737762, 55.88416907095141, 56.415560014786266, 54.62644538571758, 50.45039592250701, 44.156184196472175, 43.818558339149725, 45.42685562564481, 48.772731519514515, 49.790967049137244, 50.10012042137885, 54.19616137781451, 52.06301566093199, 52.859864773288855, 48.9643196905813, 50.34623738258116, 42.3947811126709, 44.07974896892425, 45.77246350626792, 52.88148095530849, 56.46642923355103, 54.09027699501284, 52.95031070709229, 54.37669238736553, 49.68016793650966, 45.11967912797005, 44.34778021227929, 42.52392122822423, 41.03687617086595, 45.293906888654156, 49.41263091179633, 54.6968166289791, 63.64167198058098, 61.07531224527667, 56.11589877836166, 52.22013012055428, 39.56290045092183, 42.8488778298901, 25.209184885025028, 9.989073641838567, 3.4483387441404405, 2.5080306587680696, 3.5945921607555884, 6.091218283099513, 7.5794307358803295, 8.734470202076821, 7.14739146732515, 3.1384227160484564, 1.3615303150107785, 0.2412496675406733, 0.1299851871426067, 0.1687197570478724, 0.20287696692732074, 0.2017745970477981, 0.3277897173839231, 0.144676853632254, 0.17828123914378305, 0.34309998455066837, 0.0705023285662455, 0.3526026310939943, 0.5655433886474179, 0.19487864127562893, 0.3199519637611605, 0.1109176877165033, 0.6043453130029863, 0.8591679135157216, 0.6596099765550706, 0.7668790786016373, 1.3088256721535039, 2.6959376854281274, 1.807806193828583, 1.232818963546907, 0.23447493752164228, 0.11261333140634722, 0.29386581192093514, 0.1767832767819205, 0.11644045386703746, 0.33443706230290476, 0.15934248845423424, 0.4633903136897472, 50.105062607795965, 58.88653555224019, 46.663727991042606, 59.02949810028077, 67.09565624114006, 73.47950197035267, 50.4997314945344, 27.61900478793729, 13.24357694195163, 2.7057254698968705, 6.600672881449423, 59.41337654667517, 80.5730535138038, 72.75070990285566, 72.18847736235588, 2.8577854652558607, 0.1635788933884713, 0.28771771118044853, 0.20986920462981348, 0.3843343606398952], [0.08317868585788435, 0.08073322595127168, 0.3040868650761343, 3.3727889916589184, 38.782034997017156, 84.05948362042828, 54.42142309681062, 1.7645261484769084, 6.76474464516486, 4.599664951524427, 1.3508959114551546, 6.099876915254901, 3.6195033788681035, 7.922647931883413, 16.22263768026906, 25.277137987075317, 24.493264075248476, 39.41387391859485, 36.684535780260646, 64.3147389350399, 18.098149376530802, 0.14665591921056473, 0.10376169872019561, 0.13516199564741505, 0.04753640304589945, 0.055226929891373844, 0.13324987083192796, 0.08536362224408696, 0.06814940442000667, 0.12484996189032832, 0.042513210491667834, 0.08873632433073175, 0.010809112779585826, 0.16182914856941472, 0.2551751388537307, 0.14133677156942506, 1.610006949593944, 1.6521550234287017, 1.3199235282598005, 0.7911645560975998, 0.06045263012750976, 0.07524947665872113, 0.07414783456272657, 0.08172418366396621, 0.09516550273063684, 0.08246088445547127, 0.10696655860350979, 0.08337372418252692, 0.016435070015910654, 0.03723743874880095, 0.15934596649341046, 0.030518311391314192, 0.06644606154652373, 0.052358869072650714, 0.26215044601309684, 1.4419192916923955, 1.5668994885298515, 1.4187140594567023, 0.034464204293345256, 0.7623649208295731, 0.7629306001528617, 0.6004550572364562, 2.647469202356954, 6.77380532026291, 31.895663046067764, 47.40050992658062, 47.213589376018895, 48.455674571375695, 48.092196372247514, 48.39606238949684, 46.8419095008604, 46.39823844355922, 44.34485020176057, 41.335509746305405, 43.341209811549035, 45.357700317136704, 48.478279190678755, 49.8536543692312, 49.26744830223822, 47.7635488202495, 43.76295874195714, 39.90504095631261, 42.82806573375579, 41.84322526378017, 40.13283652644004, 41.689095727859005, 45.35474677239695, 45.587837542257006, 44.24954837368381, 45.774573741420625, 42.131550850406775, 40.890465859443914, 38.957215893653135, 40.87116779819612, 42.85895439886278, 45.84555295205886, 46.963601035456506, 46.408934747019124, 46.35579839829476, 44.916810220287694, 42.805237539352916, 39.8603847719008, 36.04642498877741, 38.30394906382407, 37.10016973557011, 38.94761785384148, 49.376141102083274, 48.5067085296877, 56.97185800921533, 53.547103251180346, 50.11368789980489, 44.6327482500384, 40.05059226866692, 15.64713478088379, 1.953878445971397, 0.1381860511197198, 0.1778537314385176, 0.09571274997846735, 0.1813650494741817, 0.36844146828497615, 0.06591296394265468, 0.07334075327361785, 0.05093883317444594, 0.023137529215384877, 0.06086840519621488, 0.13296064199699512, 0.16036345383092282, 0.0437010987661779, 0.033289435274538495, 0.06247864923469963, 0.12421024016915791, 0.03899908474376125, 0.01820651044498288, 0.05435947321295258, 0.08520491180881377, 0.09847105721071844, 0.193221363269033, 0.09054879642902844, 0.08405094590759085, 0.3974503374868824, 0.09535609008443933, 1.2154379607208314, 2.5294987713136985, 2.2443669745998998, 2.2495756370406, 1.8445887104157481, 6.438506899341461, 3.4385840546700264, 0.13613972302165725, 0.1374750449171951, 0.09907125645587522, 0.10981468964488277, 0.13137759791026193, 0.04150765497357615, 0.054337589911395506, 3.032419191252801, 46.18786996410739, 39.84857451531195, 42.66522461368192, 45.45629693615822, 32.298529686466345, 18.120502964142833, 22.43899133897597, 18.95180029253806, 10.18846340717808, 7.786658377416673, 18.817096294895297, 49.978550480258086, 33.02107734064902, 53.35073371087351, 40.88195823854016, 0.3033006137176868, 0.07604092975417454, 0.04430338177048872, 0.14061766015666147, 0.11003064983073743, 0.01940048337283154, 0.1189647442210586, 0.10845148214890112, 12.202163146388147, 67.92573175122662, 88.60607547144737, 73.94795848477271, 2.2575721240812734, 1.8572973123481198, 7.530715878932708, 10.923337109627264, 12.157674643301196, 7.819809269520545, 11.103662194744235, 8.184423485109884, 27.722335707756784, 31.32416390603589, 44.99996446794079, 44.12518962737053, 69.50666658339962, 31.352654041782504, 0.39186374855137646, 0.222883184530562, 0.20434842264700323, 0.05298837501135084, 0.05188070763383181, 0.060760068872402755, 0.11078928371951466, 0.04219935959084861, 0.10536653800837456, 0.026976397719174147, 0.04158880283695556, 0.04687553346757928, 0.0908646238366923, 0.3507065941249171, 0.3203385317277524, 1.0599469946276758, 1.300927366941206, 1.8600228693216079, 0.9498133366146396, 0.36019177386356943, 0.17672339934975873, 0.08237619343544207, 0.10453386938259487, 0.024437229937663483, 0.030635266204274474, 0.13224154590599, 0.023256797613876484, 0.008872539225605228, 0.031959899258048784, 0.055350239403666034, 0.03225045534031045, 0.1226353855623353, 0.037454371866319454, 0.15269555722273168, 0.042955856094317096, 0.5709926639833759, 1.151134011245543, 0.5458317012075455, 0.7669547680885561, 0.9451246946569413, 0.8708394775467535, 2.585017469621474, 10.550731555108102, 35.201216974566066, 46.09298782963907, 47.32605157359954, 48.02977969569545, 49.85279929253363, 51.27645492553712, 49.08024141865392, 49.52752890125398, 48.36061985261979, 42.728453220859656, 46.54830048161168, 50.147012356788885, 52.652795007151944, 52.84358301470357, 51.043591653147054, 51.35906004136609, 46.38697339642433, 41.763240291226296, 45.566801871022875, 43.49800655918737, 44.65639621980729, 45.227073623288064, 48.20489783440867, 52.13193954959993, 49.36577035534767, 49.61931236328618, 44.35021992652647, 43.974554923272905, 40.64451363778884, 43.321472444841945, 47.143273045939786, 46.77265221072782, 51.312885899697584, 51.63110779177759, 50.86998362695017, 48.02616327039657, 44.77718168689359, 43.214415273358746, 41.845394334485455, 40.88156207915276, 40.9958246446425, 45.566833249984256, 55.03663901359805, 54.99061784436626, 55.39937980713383, 50.24072170257569, 43.52801661337576, 37.35067582899524, 22.398204572739143, 3.328434094305962, 0.40973599759801743, 0.06951213694147526, 0.06157661900825559, 0.16236260623460816, 0.12346689739534933, 0.18659775175394552, 0.15337657874390004, 0.06329979972853776, 0.17583357290394847, 0.08842270325628981, 0.04335919755601114, 0.10094882304509802, 0.13258018741203895, 0.0014354936372969421, 0.037680402277938785, 0.08178895639796412, 0.024664832744747404, 0.0379015795225578, 0.08412002405572323, 0.09728164442123906, 0.06994453994857688, 0.09486600831751862, 0.12715315160852286, 0.08140882356993615, 0.08012463804334402, 0.3149296139036456, 0.2248552480652448, 1.8605826650896382, 4.591833449179127, 4.157681984286155, 4.589698208916572, 6.5760399064710064, 15.445751470904197, 5.601185300657827, 0.5730130523443222, 0.07984175241642422, 0.41350104395420323, 0.08451139539360039, 0.13208175528674357, 0.07936303939429984, 0.13365074932094545, 6.538490566515154, 58.25039379058346, 46.808408537218654, 52.568966111829205, 57.13403624873008, 38.26352903919835, 37.046182232518355, 61.46114795438705, 46.04873957172517, 16.859798277578047, 6.811871922785237, 37.4903122071297, 63.075956375368186, 45.91848158067273, 70.49796719704905, 43.47828488196097, 0.3052298376156438, 0.10941994752013877, 0.07618956613324343, 0.06107890700560905, 0.13867680704401386, 0.2541722991173306, 0.38124524898106055, 0.22593671906619306, 21.01036214059399, 93.20150867585214, 101.92967660965459, 104.79965917525753, 13.837093326353259, 13.666717333178367, 11.168095950157413, 10.30768875152834, 4.79206407262433, 2.4482983543026835, 10.5012204570155, 47.27706117014731, 43.871561327288234, 36.36172079270886, 58.65827714243243, 46.833637222166985, 90.63667866491502, 49.40706114615164, 0.3221262745078533, 0.3812819292708751, 0.17411090163213594, 0.11038829031730853, 0.12797139479868835, 0.23656248115003112, 0.2106252261587689, 0.24020964189642863, 0.19867466822747262, 0.12689628998839086, 0.16315305575488076, 0.1641558648477639, 0.5315226496708009, 0.4083535153298609, 0.5665853907985072, 1.7319171563271554, 1.5780618185958557, 1.9660214911545477, 1.8639573743266447, 0.49903448490846547, 0.17208427731548587, 0.18057273069937385, 0.18260821099242858, 0.24747456093468975, 0.21899220864138297, 0.23714671512284588, 0.22483365970753857, 0.14583329399747236, 0.11899517323341101, 0.19727451997178216, 0.15196495449110387, 0.298157804194958, 0.15420816718570649, 0.5772479251027107, 1.9765027996993836, 1.8697134525545183, 1.881850491608343, 1.728772641189637, 1.1873263336958424, 1.4437642765621987, 1.7694820631896298, 5.530378184010906, 27.47211398616914, 45.24544208280502, 51.58805193439607, 48.218649664232814, 50.72130226319837, 52.00216008770851, 54.55275973966045, 52.82134709819671, 52.81505561644032, 51.00382274196994, 44.45665736352244, 49.168957587211366, 50.18667144160117, 53.59015126382151, 55.79317400532385, 54.74671309994113, 54.2775466365199, 48.5451477573764, 43.641024020410356, 48.53782076989451, 48.28755001867972, 46.438368212792184, 49.83538396896855, 50.59092660104075, 53.42400358569238, 52.431577251803496, 54.07466596172702, 48.88479363533759, 47.322199806090325, 43.282358569483605, 46.5457195620383, 48.243835203109256, 53.549225253443566, 54.36692176326629, 54.847541547590694, 55.63313345755301, 52.678431618598204, 50.31245008591683, 48.95388618592293, 44.476771277766076, 43.478379018845104, 44.900242128679835, 45.56032211549821, 54.793503053726695, 55.966593757752456, 59.50377541203653, 53.91839088932161, 50.803424927496145, 44.79545600952641, 41.64307455862723, 21.260497570037845, 2.7704261916299022, 0.2606364724136168, 0.3058928101053161, 0.22709233205645318, 0.29995424973387874, 0.6691534096194852, 0.17948370607149217, 0.20911909729963352, 0.4887343101924466, 0.18232757766400615, 0.12955087657657363, 0.224662285838877, 0.29676462733937853, 0.21759265793427346, 0.15581381086620594, 0.1800355345251099, 0.18850315031745743, 0.14017688380854745, 0.12335844232790893, 0.3176119328746873, 0.18828642404367849, 0.22039399632523138, 0.2822729710850024, 0.20464779448605355, 0.09339727220996734, 0.4079549044610993, 0.4437352248257207, 2.0706412772978506, 4.242518928743178, 4.197556309161648, 5.033309450072627, 5.690142204684596, 10.754437888822249, 5.874834848988441, 1.374235975165521, 0.28339201103775735, 0.5953176716162313, 0.25492554740800016, 0.2815530935843145, 0.26500648308184843, 0.20074561839142155, 6.796458969193121, 67.37135179581182, 54.44582808402277, 57.975616070532034, 64.49064939252793, 47.94728048386113, 34.718063339110344, 52.290489596705285, 47.533670471560576, 23.641344885672293, 10.640733280489522, 46.51621549360214, 91.25449119075653, 49.409406723514685, 81.13012421515681, 56.676817324853715, 0.6654218872708659, 0.1491209756462805, 0.2788883946355312, 0.3071828715262875, 0.304995384067297], [0.0776180289986153, 0.07627016624375697, 0.09074396498861814, 2.4087162460050275, 15.621954144970065, 37.6075832305416, 82.69028617489724, 39.69464109789941, 9.788379688416759, 4.704568251486748, 4.468693579396894, 2.062509958782504, 5.509717099128231, 9.062540185066963, 34.77823641992385, 53.70042085647584, 44.75379651592624, 34.35100793838501, 48.286734165683875, 53.80227304274037, 19.32532564286263, 1.5235423440894775, 0.07032799759819623, 0.04581293887308529, 0.020977860324144847, 0.03682588865499824, 0.03236669386106153, 0.08464778202676004, 0.03562822126813474, 0.049181630489446466, 0.13881965179837522, 0.6484435402577924, 0.46970624897268515, 0.5204450795727392, 0.10799623439989744, 0.22792568250048548, 1.639956329618731, 4.266866060995286, 3.501583448340816, 1.5420202622490546, 0.460925686263269, 0.3015926666557789, 0.1610353895493092, 0.09988620546796631, 0.12870900723482334, 0.03766993751689311, 0.0683949432606178, 0.022899785319403298, 0.08834054798728998, 0.0009854567225932355, 0.025509460003025113, 0.0938257605077759, 0.08610907942056657, 0.11477624276472677, 0.10960115029686883, 0.31749741805176585, 0.13471014166791595, 0.20809267737692405, 0.05908654214093282, 0.1706850177217876, 0.20823968964959347, 0.26843969079275287, 0.30192579232877303, 0.9403002406320266, 9.843353667566854, 31.75530691300669, 47.934544547911614, 51.272607080398075, 49.56583869072699, 50.26197702653947, 50.13531977130521, 44.911424806041104, 44.69578858344786, 41.8407267139804, 43.98258793738581, 45.19034847136467, 49.31079833738266, 48.41012016419442, 48.64900819716915, 46.30277187593522, 41.921821717293035, 41.16609865619291, 42.26677456209737, 41.34211109530541, 42.178278046269575, 41.85273308907786, 45.39512757332095, 45.17396865352508, 44.74871312418292, 44.87513503720684, 41.03648393384872, 39.98153501941312, 39.614918924147084, 38.1976253755631, 42.014279826994866, 43.10185109415362, 46.71611516706405, 45.46854649820636, 43.884485537006015, 44.377205833312004, 40.5735775732225, 40.17890084174372, 38.754315607009396, 36.62230737747685, 38.56655174686063, 41.7613418640629, 50.58238760117562, 61.671830223452666, 56.689953342560806, 40.108004000879106, 29.950749912569602, 20.315167134807957, 3.5979720181034462, 0.3832243911681637, 0.01041255119602166, 0.05895571730610344, 0.10131043186711688, 0.05013167527654479, 0.048532474395488544, 0.04441929470387198, 0.04520232083215829, 0.04783800037036981, 0.06796721338985429, 0.05513991762493407, 0.06837363835544356, 0.37574479897176066, 0.04532104530822366, 0.10321006944943821, 0.0261376521009351, 0.0822995463386178, 0.04288923708842166, 0.1010683557439235, 0.03506909582703825, 0.0261843279229417, 0.10130735219366128, 0.07643174184786697, 0.0418619399950389, 0.2657619989927738, 0.4392582069962256, 2.541335749049341, 3.639202012169746, 7.53050652242476, 9.897797146151143, 11.825016467801987, 12.71047584472164, 19.43147478565093, 28.121336852350545, 7.329977308550189, 0.879754841087326, 0.45772224364261477, 0.3839490184139821, 0.3639883523987186, 0.11291012918997197, 0.0729499948060801, 0.09945979326843254, 11.129586119805614, 55.225618808500236, 45.93215888546359, 52.06514550793556, 47.60888191961473, 34.08397689942391, 17.702158651044293, 35.479462069849816, 38.9042599739567, 36.73084720488518, 18.247075888418383, 33.07083260628485, 27.11066757479022, 20.223273846410937, 61.3466892703887, 18.531855652409217, 0.32657120857507954, 0.24026447847004861, 0.16655896009216387, 0.10198183898483554, 0.06838551271826991, 0.08634920968043228, 0.0924224559698374, 0.04666869355846317, 2.037534021562146, 42.28940663799163, 61.668409916662405, 95.05526788773076, 47.60804645476803, 12.39060067361401, 6.105202023060092, 4.292989046342911, 14.888997500942601, 15.393581986427309, 8.043434379562255, 36.107602196355025, 51.55275060284523, 44.995343915877804, 44.79223574361494, 55.360171794891365, 62.20554321042953, 43.969240111689416, 2.382109093089258, 0.20720214613022345, 0.10445827182622687, 0.02868286048572871, 0.09413401130586864, 0.02415990036341452, 0.10537887202395547, 0.054372132815901315, 0.054542744427078196, 0.10030060540884735, 0.6152681333403434, 0.7020250779967154, 0.5451438155385756, 0.2113239136674712, 0.3099802875470731, 2.5735817993840864, 4.8090391101375705, 4.035335904167545, 1.9521013671352019, 0.6159905848964569, 0.4987394184835496, 0.18253937033155274, 0.03493090888725654, 0.036557715746664235, 0.049916937000929355, 0.03398857094467648, 0.0782966066993052, 0.061465421346046274, 0.020130934802094297, 0.13460857373091484, 0.07991621616266428, 0.02590946515180892, 0.17488564634996076, 0.1963130796268102, 0.6199306057345483, 0.3254571635155909, 0.16978589096857657, 0.1420977879916468, 0.4696427249620038, 0.18880947823486022, 0.3804267606427593, 0.4029885403090908, 0.6776567404308628, 9.258892074708017, 32.237525063176314, 44.778409388757524, 49.47116836424797, 48.16075548048943, 54.59410152127666, 52.52215654619279, 48.37882749495968, 48.564461508104884, 44.718644234441946, 46.977807860220636, 48.63071426268547, 52.35330243264475, 53.01581821134014, 49.8826289176941, 49.339059014474195, 45.27120421009679, 42.75757289701893, 42.25070461150139, 44.553822317431056, 44.87837883733934, 44.30575201588292, 47.63089818339194, 47.91851382101736, 47.67056511294457, 48.59180042820592, 42.65104132313883, 43.83191400958646, 41.148385232494725, 41.53767654972692, 43.199278846863784, 46.59007372394685, 46.62799127640263, 44.71452182339084, 47.1911887199648, 46.336872962213334, 43.71345058564217, 42.50055566910775, 42.069914725519, 40.01811896601031, 41.3410795119501, 48.71493931739561, 54.579404400240996, 63.72706982397265, 57.976753557882006, 33.17035490466703, 22.35307574272156, 9.707773020190578, 1.952859365171002, 0.08187669644793195, 0.1763431133041459, 0.016830277539068655, 0.07623899412611801, 0.026938043527245045, 0.011837346415456024, 0.10812771040946247, 0.0242025637999177, 0.0892212043606466, 0.03864427878250999, 0.04691643107141699, 0.07690230369447701, 0.175807970245519, 0.03709212719132343, 0.026618962161122795, 0.030608175420052106, 0.014203500900147183, 0.04789077999791311, 0.037385718896985054, 0.023593972061550426, 0.0809672734730186, 0.14051072960419042, 0.018354099198815324, 0.07026582190226163, 0.2510896685623354, 0.8731216228296681, 2.0966340889853816, 6.6998220643689566, 12.400978284497416, 10.715680949149593, 14.751011460058152, 21.124128526256932, 24.954046472426384, 41.84241725552467, 22.171246428643506, 6.1572803124304745, 1.4331969210217077, 0.4813803564156256, 0.6875619508566395, 0.27554509500342034, 0.040731102288250005, 0.14897688982948182, 21.541398109928256, 64.67884079102548, 57.511744806843424, 58.154660501787745, 62.50188219931818, 48.08663837371334, 21.16860624282591, 58.287570015076675, 75.39032382349815, 80.79656585570305, 53.743731667918546, 51.38011924682125, 40.20781263228386, 31.206504567976925, 72.4019641260947, 19.26457009007854, 0.2342517607875409, 0.2632658087438153, 0.07970960224948584, 0.1001487591213757, 0.0630819434750705, 0.14713864653341233, 0.23171694438544013, 0.29618571001675825, 4.628049673572664, 76.67864199607604, 71.81612676189792, 115.89333795732068, 72.52489905203544, 28.081422813477058, 10.889185032536908, 11.987056443768164, 7.825134867622007, 16.43700795788919, 27.79553890228272, 49.63188748205862, 63.918144164546845, 51.494013109514796, 54.092073440551765, 63.38390950233706, 71.30344160141485, 60.772081651995265, 2.694989697587106, 0.22331723462670083, 0.2179840062895129, 0.13925983059790828, 0.18392251143532415, 0.23247342556715014, 0.2542079988146021, 0.15029483685089698, 0.19314337551834124, 0.3520206494196769, 0.738958360687379, 0.654817391787806, 1.089775761769664, 0.6876832378968116, 0.6461641528914053, 3.517184920849339, 6.441123610542667, 4.396144440097194, 2.596639452442046, 0.7427873294199667, 1.0086165296454583, 0.5028383872441707, 0.17594663215981377, 0.3466818746059172, 0.17580386401424486, 0.11086043030504258, 0.17399448691116226, 0.1312029145417675, 0.0921794069149802, 0.16726512461900714, 0.18633392639458182, 0.15625333083012413, 0.2514671660479038, 0.31704582454216096, 0.7326687788290362, 0.35745209022875757, 0.5982846995034526, 0.20931031284553392, 0.5261531087660021, 0.45349831061978496, 0.408947478619314, 0.7426841220548077, 2.5621054345561616, 20.86341642564343, 44.22184075078657, 53.18666096656553, 51.96288931754328, 50.07806493389992, 54.87770065184563, 55.62970922839258, 49.21428449692265, 50.19060950125418, 47.38959397039106, 47.76622779907719, 51.85036828441005, 56.33471996553483, 56.35954464635542, 53.86176363114388, 51.0426502843057, 46.56383306749406, 44.9479224604945, 47.48793563535137, 46.774785980101555, 48.71453531326787, 46.87812866703157, 51.3390245745259, 52.3975859918902, 49.755042060729004, 52.63991002113589, 46.17053701031593, 47.294386279198434, 43.99499047187067, 42.55611996496878, 48.297963911487216, 49.38369166466498, 49.43845579701085, 50.9248968093626, 50.69489294482816, 51.69502281373548, 48.00015795615412, 46.10215440873177, 45.26191211515858, 44.02291382512739, 44.225696440665956, 50.57783372940556, 55.99363065535023, 64.67731891139861, 62.78075879619968, 42.71157918437835, 28.888815256857104, 20.84323779229195, 4.762516858116274, 0.4441732126137903, 0.24428343700785793, 0.22156692290258026, 0.19717577123834243, 0.14688056683348072, 0.11027936027535509, 0.10698385686884004, 0.10940615793750172, 0.20463556772278202, 0.16953109012496087, 0.16224447547668414, 0.2869805813797059, 0.7554367893645841, 0.19215190452673744, 0.27175335814395263, 0.21930256618126748, 0.24467480068485586, 0.10739531503209185, 0.11742795652319347, 0.12754070016765787, 0.1758119232592083, 0.17727263842619237, 0.11498720039643588, 0.15785721250839774, 0.42064165756587063, 1.3235550301690258, 2.9234976681970783, 6.626802730944849, 10.94775680572756, 11.921864690319186, 14.942002450266193, 19.476438876121275, 23.675547953574892, 40.50367309201149, 21.692107339059156, 5.103173236693106, 0.9100624438255065, 0.37097332758768914, 0.9167277152019163, 0.14090589307729276, 0.10824329009459865, 0.2095379482113546, 22.646257223621493, 75.99134860500213, 61.05592004714474, 67.06561873036047, 67.55328701388451, 50.87332548633699, 28.385418268942065, 60.57965801608179, 74.24699214196976, 74.63467136506112, 66.9127090515629, 64.84653780537268, 47.000008475395944, 35.84512502916398, 94.51013688118228, 24.97984782341988, 0.41234158520256325, 0.3106535869019647, 0.23284758290936872, 0.18587264953361404, 0.13618898247518849], [0.19009200135065665, 0.11245927878565366, 0.7004852412689118, 0.8889814814732921, 6.701892095227396, 22.845692096217988, 31.649565696716312, 53.616046751699145, 32.664677058496785, 26.449605034243678, 23.376188739653557, 19.433590904358898, 21.585895438348096, 73.67790329840876, 99.96452992962253, 46.671200106220866, 37.369405146568056, 31.949448547055646, 48.545292885072776, 58.09307144534204, 41.41704013270717, 4.930843412876129, 0.5162584397100634, 0.09556459623479074, 0.039511000016523946, 0.05077235077718093, 0.04342262963614157, 0.030402729790958188, 0.0328660223092283, 0.281637730978189, 1.319450269783697, 2.0157852144010606, 1.005997795972132, 0.5780444113958267, 0.4077535152675644, 0.7988138520909894, 2.5579957712081174, 4.033973370828937, 5.667792049146468, 1.3322923548759953, 0.480911479962449, 0.9596229392674662, 1.0577188432216644, 0.6896821145088442, 0.06816768327788, 0.05125991594527037, 0.044903370341466325, 0.05114857655679507, 0.20556895392796687, 0.14368481573558625, 0.5398521091668838, 0.9228551315684473, 0.2934418588636383, 0.39628398394392383, 0.24096143462004202, 0.6075748332565831, 1.1364951128921201, 0.3264374496235002, 0.020442881974421685, 0.06930324008628246, 0.13666409488406875, 0.16716936362847207, 0.02806746780181364, 0.09862112617420574, 0.28429044831183653, 5.96638051732894, 18.742604601767756, 37.03898860562233, 48.734825734169256, 53.30278273551695, 54.02976266799435, 47.23260110424411, 46.15226268768311, 43.251803305841264, 43.84632087522938, 45.67910717379662, 50.63612407253635, 49.01281587539181, 45.85764954167028, 45.49539119966569, 41.39196049782538, 40.10718030314292, 38.554588517835064, 44.7748714108621, 41.333352442710634, 42.66480492007348, 43.026525897364465, 48.0113680901066, 45.86450192236131, 43.99346074750347, 39.264486528212025, 38.20573683707945, 37.23358131224109, 40.7222471698638, 38.81249612377536, 42.83622426371421, 41.32591170649375, 41.79899269534696, 42.71818053337836, 41.119963738226126, 41.23570111490066, 39.92703760823896, 38.641551386925485, 37.309075170947665, 38.69163613165579, 50.13062469420895, 56.88370273959253, 56.26415652613486, 43.17730572915847, 19.945666136280185, 9.269653097275766, 1.9753838210336625, 0.13405607111992376, 0.08312443917196605, 0.05502234611119475, 0.11408967476698662, 0.05873629440283103, 0.07001786988468901, 0.04088483315201537, 0.21244116097448335, 0.03141362685710192, 0.03915435927469404, 0.05115641363626046, 0.05994443804205907, 0.23603234830642902, 0.0493617186082467, 0.25367959732970885, 0.10301350660982633, 0.07407872577107723, 0.06727559687269312, 0.177703149196121, 0.0881524350974829, 0.1466978701852983, 0.08273710511744985, 2.186764271989946, 0.9531501091776357, 0.9819611438339757, 0.4811185382066235, 2.017747134931626, 4.4737284318093336, 20.14200821999581, 17.853620975248276, 10.178176010808638, 18.97338313441123, 24.504556578974572, 32.35406848692125, 55.749059107995805, 35.98910347107918, 9.981305387712295, 2.6106361852538202, 0.6143644560248621, 0.4913606434579819, 2.2910203808738343, 0.06278190513952606, 0.3858521340354797, 23.865828014189198, 60.30916352425853, 49.23703424392208, 60.5992502550925, 40.15978320952385, 60.19029217381632, 47.975564695173695, 30.21797314766915, 18.712053260495587, 17.647716153052546, 26.536067801137126, 12.179605595527157, 11.223167007969273, 30.310974505639848, 57.42521732084213, 4.976407625982839, 0.2862630940733418, 0.24408387110358287, 0.056228505582698894, 0.09968543680565012, 0.11133555803568133, 0.17884458955978194, 0.1388430940888582, 0.3905215012210031, 1.1952967124600564, 27.03495014098383, 49.25523404152163, 61.4096825353561, 64.8909233462426, 42.08231333763369, 23.426691216807214, 8.229106145520365, 12.347135909142034, 3.088678236930601, 58.06565800020772, 87.8264965549592, 46.15674987916024, 35.47405704375237, 41.21057833394697, 52.67767852352512, 65.87906252953314, 65.6019353097485, 10.363847286470476, 0.32240200487356035, 0.1245060803428773, 0.04704581949138834, 0.05525876467506732, 0.011848425004451026, 0.09370818133315734, 0.037495028152461016, 0.15167037836245953, 1.7768492549657824, 2.565702738300447, 1.12096534621331, 0.826699146099629, 0.34146454004991444, 0.5090374481533805, 4.030870530874499, 5.974376759221477, 7.687957815585598, 1.678098437766875, 0.9944096435942958, 0.5089777852258375, 0.7543467381788839, 0.3214155287752229, 0.07278107241877625, 0.01231575587524041, 0.024103010674157453, 0.05658413891890838, 0.2283666580314598, 0.22008299527149047, 0.5413809142285778, 1.2960043020786778, 1.2633606214677136, 0.6695864638013225, 0.6929093671421851, 2.1386725816034504, 2.0577307958756728, 1.252654266934241, 0.9823425943332335, 0.1262635932934861, 0.0751703474370222, 0.15605545031928247, 0.04653380079675586, 0.3082175192333037, 0.5115009724132477, 4.165816980023538, 16.215306770416998, 33.31381951608966, 47.643226192843535, 52.68191076094105, 57.17642138081213, 49.051239413599816, 47.393563409005445, 45.75846064475275, 46.70111994589529, 48.99649881547498, 52.91490739391696, 50.41822856472385, 49.262251161759906, 47.87370466416883, 43.67157536168253, 44.470993626502256, 42.158619126965924, 49.81015136165004, 43.72237790015436, 45.832016852594194, 43.86264970225673, 51.796667114380874, 49.523202526953916, 45.96356530343333, 42.99047931548088, 43.63807439804078, 42.12935432311028, 41.77186558323522, 41.022787017206994, 44.83442867955854, 45.68148413012105, 47.75449991226197, 45.813420895607244, 45.579871208437034, 44.39081253543977, 44.15201863934917, 40.93399632361628, 41.71133556673604, 43.90043781649682, 55.94250648252426, 59.78289519586871, 48.765192724043324, 32.22052747203458, 15.911570191383364, 4.016375411902705, 0.8292343455456919, 0.13597977918482598, 0.06403499898771126, 0.1134486813398619, 0.04956540989599401, 0.050951508099153164, 0.060095112215006546, 0.03372125605481767, 0.029674699199536157, 0.07719254376546991, 0.06499355118120871, 0.06931096991343845, 0.040402737851705284, 0.14641142991040984, 0.011060942159665209, 0.24149316092652662, 0.0223663582977268, 0.08257198252625043, 0.10601915298931061, 0.1990909910490436, 0.05103757807744607, 0.3731708661202462, 0.49706435191535187, 1.7670367105353264, 1.0198410047638802, 1.684403770392941, 0.8089956509009485, 1.449800681683325, 11.820977407117045, 24.82214108590157, 21.361620195450325, 14.676526631078413, 31.468058016992387, 25.12013923737311, 48.72211333244078, 61.34938001632691, 59.849493119024466, 33.96938093246953, 9.357773065567017, 1.4706591108152944, 3.7324553824240163, 5.6770792411219695, 0.07438935910261447, 0.6706025415370542, 38.76825178823164, 71.26111922725555, 60.05163638822494, 70.04682402456962, 53.530205680478005, 69.40553219087663, 45.63832629111506, 39.18126952263617, 31.988281972946663, 29.4372175201293, 38.3381050632846, 18.18345896659359, 22.240425271372644, 38.702183385049146, 63.529327454105506, 4.313599630709618, 0.27967623945686126, 0.385852869479887, 0.061146092916568445, 0.04838209516639191, 0.10936086681941826, 0.26277514475007213, 0.24691582236799503, 0.9035431581639475, 0.9733896618408542, 45.39570023936611, 66.97755367525163, 61.02516082025344, 88.22581737272202, 54.219154311764626, 54.274530333857385, 45.889601169093964, 51.10970320240144, 48.66887107972176, 94.96098979826897, 104.07879814024895, 60.510043790263516, 43.80304144274804, 50.587792627273075, 65.26988314044091, 74.84283155010593, 75.77801089132987, 14.481055313541045, 0.7691744005968495, 0.28641312473243286, 0.1599948582870345, 0.13559482000287504, 0.11599695790679225, 0.19458729803802507, 0.10291304950031543, 0.6802627876881631, 2.505727246884377, 3.6983974422177965, 1.9165156637468648, 1.1803660878250677, 0.6746778228590566, 1.280098355585529, 5.6258413195610055, 7.847280569614903, 8.54024717884679, 3.5962775541890055, 2.176444025770311, 1.5216759087577945, 1.4874290819129636, 0.9611336646541473, 0.23333282300060798, 0.1573328559677447, 0.17293907822139803, 0.1691097724101236, 0.2689610289469842, 0.30926114549079253, 0.613607561155673, 1.563484452424511, 1.6566292220546355, 1.005365252494812, 0.9410725798337691, 1.814134692953479, 1.8105809030032929, 1.0560385978990987, 1.0164069696780176, 0.45404805531424863, 0.2537814257366042, 0.5134769889616198, 0.26142070129994427, 0.24722561300281556, 0.9848757100201423, 7.634815093009704, 21.986259606576738, 40.29106886156144, 51.20995506163567, 54.04467551938949, 60.89754650669714, 50.516464325689505, 50.96691323864845, 48.05916217065627, 49.68596519962434, 50.51818624619515, 56.84922902814804, 52.987337881518954, 52.58423982128021, 49.585070071681855, 45.879132363104056, 45.509362682219475, 44.40374066752773, 51.36321775374874, 48.32448305622224, 49.11590360826062, 48.32534205528998, 57.674534936105054, 52.72200130647229, 49.56925899751725, 44.063122041763805, 46.895869547320956, 43.53149183334843, 46.66282976827314, 45.75370673210391, 49.608384639986106, 46.9451266719449, 50.71061772684897, 50.98792537566155, 48.334085018404075, 48.44890848282845, 48.05263926905971, 45.81726481837612, 44.498026601729855, 45.95165306522001, 56.54058164165866, 59.2882647052888, 56.228047186328524, 46.35586900095786, 23.485303194292133, 11.773766779130506, 2.5883090736404544, 0.21694053324960896, 0.13651415615552856, 0.23564752702030445, 0.23208480448492114, 0.17328947151620544, 0.2411702701882009, 0.2164269479051713, 0.34279305908468466, 0.1779591451368986, 0.1806752026201256, 0.17413465035778863, 0.2771387417470255, 0.34059037244127643, 0.19864177241200404, 0.6191124238314167, 0.19511499472202795, 0.16297198321309783, 0.20781657928901337, 0.47809990663682267, 0.18844531067917425, 0.6629139605549075, 0.6675744104769923, 2.0190385753108613, 1.5433759314398614, 2.332129271761064, 1.0505185973259712, 5.268112334512896, 9.645851542872768, 24.466478209341727, 21.74324327899564, 18.91444952257218, 32.77125962318913, 33.51960666718022, 47.263540760163345, 63.04356152011503, 60.569801099838756, 33.045564697634795, 5.781814859759423, 0.8612166164863495, 1.5976784498460832, 6.6056121260889125, 0.3027352101860508, 0.5927333812559805, 46.24442661962202, 81.7496390496531, 68.39921674420758, 76.21150339803388, 56.34152920015397, 78.17009187513783, 65.53994224917504, 46.00703693205311, 34.03451973392118, 34.08115671527001, 43.438013907401796, 24.25884754427018, 31.864656709855605, 54.04389889009538, 92.67533840671663, 5.256923773596364, 0.36905121298566945, 0.5766433285128686, 0.19757902459992518, 0.20344541948889533, 0.24687204810400165], [0.24341909064640924, 0.3347698202536952, 0.16738111033074318, 0.5747311117668306, 15.229471979602692, 31.721170525397028, 20.662965659172308, 44.85805703747658, 59.16543176097255, 49.30878223911409, 63.51480683972759, 46.46572282237392, 36.006840428998395, 58.142073615904785, 22.44567309656451, 32.96123373893, 39.114534316524384, 26.829015901011807, 44.02205482605965, 62.90316027979698, 50.99947283344885, 10.511636311008084, 0.3380058675764069, 0.17596651980232808, 0.06075019016861916, 0.044980109368841496, 0.01924381456187656, 0.18621346672936795, 0.23283115798427215, 0.8554867078219691, 0.47537873168626144, 0.5759001006522487, 1.7260002609222167, 0.39564972442965357, 0.6549750220391058, 1.891368980849943, 2.5850510549160743, 8.240324124213188, 15.786986889377719, 5.222194617794407, 2.9684796544813343, 1.3386284535931003, 4.0038858498296435, 4.906366352112063, 4.095041732634268, 0.4650779747434201, 0.029604270821437243, 0.2102126724897854, 0.07326538554362713, 0.7259781959076083, 0.8658120408654214, 1.9374290060612465, 1.5622828588370354, 1.2673385176927814, 1.0438414975520105, 1.9830497258132505, 3.6265555552897917, 1.9847087658220723, 1.5073959072751384, 0.9819446576218452, 0.5033814210084178, 0.8989169064068026, 0.38731569904954205, 0.05921770022400926, 0.0662047132068584, 0.3530368803729934, 5.267310209812657, 12.292059948367458, 30.08058821001361, 49.293951757492565, 54.911511482730994, 55.08268371705086, 46.822721265977435, 44.849878895667295, 41.73172796926191, 43.893079450053555, 48.307416823602495, 47.35183331274217, 46.25201248353528, 45.58119696955527, 43.35064703418363, 43.38500307452294, 42.22041606903076, 44.76283365680326, 43.57612840590939, 43.50181910299486, 45.3308516933072, 46.54595098187847, 45.01107262026879, 45.31184388745216, 42.52870651983446, 42.28078134598271, 38.28770260657034, 38.377587641439135, 39.39169683764058, 39.68124228139078, 44.901936592594275, 42.77959700553648, 42.57248801569785, 40.68914236560945, 40.06066099289925, 37.30607063539567, 36.694400541244015, 40.54590917402699, 41.46651691006076, 57.655974280449655, 57.66426617099393, 36.03145330182968, 15.014225052249047, 7.5026263152399375, 1.8095598610178119, 1.0768418687005197, 0.3776171791457361, 0.04502368061953495, 0.11301624002836405, 0.14088568367785023, 0.04805380733863962, 0.03942901711730708, 0.027970555764172348, 0.08360011082503103, 0.04545627514861765, 0.0539564841517037, 0.04078835203883149, 0.20241409660347048, 0.6045144039296335, 0.9826562613729508, 0.5098898895084858, 0.24367055134667506, 0.033808390895325335, 0.2278164077189661, 0.5223634863092054, 7.9988326180365785, 9.042703778513017, 7.005538459747069, 8.032057054581182, 1.6383309974785776, 3.0075256238060617, 2.951878958171414, 4.786292795212039, 20.807442242099395, 28.03049279797462, 19.72720580716287, 8.877557285370367, 26.392089359221924, 19.46155740368751, 49.077232960731756, 55.30250510861797, 55.512089114035334, 40.966877552770804, 18.976509263438565, 8.829317035213593, 14.455436352760563, 4.386935695525139, 0.18716444231329427, 1.7866127697690841, 44.393389532642985, 58.157049225222686, 57.836823001984634, 49.19908139013475, 30.95203688067775, 54.61739647773005, 69.69864306911346, 28.160527213927242, 28.96989457068905, 30.631285059836607, 17.937698941076956, 35.641126478871996, 23.911219643008327, 45.628112439186346, 44.486557591346006, 0.4119989293957911, 0.21537244319915774, 0.017417102804287307, 0.07614960698711296, 0.07180471634191853, 0.11395342602965333, 0.09126300487907664, 0.15434163502387463, 0.06660749925480736, 0.618427602514144, 15.31107787163027, 58.33311265514743, 42.31176414797383, 72.16197782947172, 57.42707652430381, 56.72310913762739, 58.55203582394508, 31.187351634425504, 35.66568836089104, 63.15769856975925, 27.83949298243369, 32.619689433805405, 44.308207419610795, 37.534105470103604, 49.91791455976425, 67.47660467701574, 69.53173837354107, 29.97059906682661, 0.29559284989391604, 0.26382505292854, 0.04070982802659273, 0.06207816145052353, 0.04275966863778811, 0.14158835484375878, 0.2564467681992439, 1.2457386380241764, 1.1608290071448972, 1.4895770698785784, 1.342898443821938, 0.466731621493255, 0.6197514637343345, 3.957634976794643, 3.518650661553106, 10.402175707201804, 17.92514147297029, 5.800759417395438, 3.0786673676583076, 2.5014197489907666, 5.592473716505113, 6.347308360761212, 3.2771221380079947, 0.46633812809182756, 0.11220885996496487, 0.20690983762183499, 0.36051849504151656, 0.9393187287834384, 1.0860154345150919, 2.3250155631572973, 2.804777083858367, 4.684218504736501, 3.6436595407224472, 5.185602336160598, 5.507941246032716, 3.046435045619165, 2.510571374047187, 1.4173977365416865, 0.2472577580521184, 0.5816846160638718, 0.3996187033912828, 0.20769797355657627, 0.3401210056918283, 0.4060072638094426, 3.449985404168406, 12.06850838276648, 27.698734806429957, 47.04631205528013, 54.853393723887784, 59.78136939387168, 51.35137219582835, 48.127317274770434, 47.38347507292225, 46.94711923599244, 51.36965044083134, 50.21175107648296, 48.15021999420659, 48.839192159714244, 46.5197495491274, 46.63045060250067, 47.79760676045572, 46.49506607363301, 45.57327770417737, 48.65076149663618, 48.585944329538655, 47.931810655901515, 49.324546244836625, 49.451344705397084, 44.338370446235906, 44.879328050921046, 42.33285473239037, 42.2746899051051, 42.47697830200195, 41.90406906989313, 45.60983419418336, 46.27571536648659, 45.28168478319722, 43.424391515793346, 42.48643513648741, 39.77031146326373, 41.276281956703436, 44.86612535292103, 47.818477692142615, 60.22393434278427, 50.78269912350563, 28.697709537321522, 11.621498407856112, 2.4723086530162446, 2.7581582434715766, 3.190445847088291, 0.5858677625656128, 0.06512923301347802, 0.04721472272649408, 0.11678939159478872, 0.0825449702660403, 0.045208637227093985, 0.01413710693257951, 0.11246568328070064, 0.025458413649410493, 0.18055653560065454, 0.08056691592378963, 0.5995075596917061, 2.187554139283396, 3.18585618369041, 1.8021091963014297, 0.5149646091365045, 0.14139171539535447, 0.32033283203359575, 3.831927425438358, 12.365200384970635, 12.109336333890116, 9.492239759814355, 11.54427086153338, 2.444923399917541, 5.305390050334315, 1.8965617086618178, 22.32816476975718, 27.277707592133556, 35.259840719161495, 25.689110409828928, 24.00912004132425, 30.762264767000755, 33.002261730932425, 55.150799597463305, 60.64221197558988, 60.22430696795064, 57.14021398175148, 54.31558970482119, 34.41578588178081, 36.5199335159794, 4.900216075681872, 0.5427153168186065, 5.306352992211619, 60.58418050889046, 67.50785027780842, 68.72908807569935, 53.158898430485884, 41.34378594736899, 65.58044856594455, 62.055849875173266, 30.4043367216664, 36.07785886333835, 34.95773584611955, 31.423139033779023, 56.187434965564364, 34.05980333205193, 53.91575897893598, 46.967150780462454, 0.34639967845812925, 0.21948681032705694, 0.03509729552353102, 0.21474359226563286, 0.10246052902432219, 0.1546274317849067, 0.25254134389181293, 0.3608039394021035, 0.25108078194241373, 0.585164800286293, 24.329108961166877, 86.30276556937926, 43.110711728372884, 78.43944887961112, 88.7684694413216, 71.64011432278541, 90.76351242680704, 65.67673883130475, 49.51889968687489, 67.19331541369039, 36.54493078108757, 45.2027980742916, 50.32401715555499, 44.93535518646241, 58.954894619603316, 74.64430470620432, 80.29693434315344, 40.36702163757817, 0.42946245521306997, 0.2632858189603975, 0.13784195506764998, 0.22270390463452186, 0.2213587155265193, 0.32280147376079715, 0.6118312177638854, 2.9624330757125734, 4.310928496622271, 1.6760621147771038, 2.4840664479040333, 0.8746275065406677, 0.85837320454659, 4.64243104380946, 3.6560598688740886, 11.258306541750509, 19.12426887019988, 10.452739961685674, 5.885407597787919, 3.8711234254221765, 8.177002360743861, 7.155335737812904, 4.442738765670407, 0.8558996598566733, 0.3045799192642012, 0.7312752955382871, 0.4631579745440714, 1.028784866775236, 1.2501035005815568, 2.51090502065997, 3.577138594081325, 4.439935251589745, 3.6044811914044046, 5.758371343535762, 5.494739528625242, 2.109077072912647, 3.10598373413086, 2.228859638975513, 1.3634709076535318, 1.8109697079466236, 0.9182350698017305, 0.20111784519207096, 0.34611389701885564, 0.7657999365079788, 5.9111246178227095, 15.180078552615258, 36.9284366023156, 51.752842472445586, 59.1212619504621, 63.17444709039504, 53.16655097469207, 52.41741357311126, 48.70340754908901, 49.520174457180886, 55.589724586855986, 54.047876173450106, 49.819117899863954, 52.293160730792636, 48.827585866374356, 50.47887232995803, 50.59510784764444, 50.80013405892157, 49.62539988179361, 51.26744131888113, 51.561619081804835, 54.089723940818544, 50.80666088288831, 53.02158017312327, 46.098687033499445, 49.77778396298809, 45.356374556018466, 47.60614018286429, 45.07780782638058, 45.178326406786525, 50.214418288200136, 51.291167736053474, 48.38962970241424, 48.02109949050411, 47.1289328605898, 43.90063001263527, 44.00322744923253, 47.3646516184653, 50.93795437966624, 64.2889807301183, 61.00419967405258, 39.05931518923852, 16.35104235141508, 10.11425510529549, 3.679369043919348, 2.364235587658421, 0.5611432860455206, 0.20720320333155895, 0.2130471518443477, 0.20817777442355312, 0.14255292082746185, 0.15959831585566844, 0.14906955582480277, 0.18552780271537844, 0.14571766068618144, 0.2827850548971084, 0.14508338585015268, 0.48028990686420475, 1.4030430874516888, 2.358269172330057, 2.0230427023864563, 0.4278726695526031, 0.23197511601592266, 0.4049712371441626, 2.67613559961319, 10.623602328761931, 13.918210883294384, 8.446704533792312, 14.308087614274795, 6.962588506360208, 8.270426354100628, 5.077666063462535, 27.029856943315078, 34.30636352108371, 43.05671245821061, 32.84800275679558, 34.78153905560894, 45.121510874840524, 41.46521468316355, 67.67178181679019, 67.204619684527, 66.93588241454094, 67.51406331216135, 52.6390157207366, 28.07030289403854, 39.272794108236994, 8.512228708113394, 0.8265542022643552, 5.035434394113479, 71.64337773476878, 76.97743246632238, 74.79667309791812, 67.33282627597933, 46.563232944857695, 72.10425623001592, 82.44996255443942, 40.53806443368235, 44.16215404387444, 49.665776760347434, 37.226371995864376, 71.17741584777832, 45.582279543722834, 86.89665163716963, 62.55727391089163, 0.49383314626832164, 0.3185325866985706, 0.18859615339146507, 0.22501416534425753, 0.14399143476640025, 0.3442435393170003], [0.07032506348144624, 0.1256657152947399, 0.19666701224782776, 0.4108190620618482, 4.6838027334982355, 71.22542565868747, 55.73532296765236, 17.435914047302738, 49.67354305328862, 64.80263079366377, 56.0150860201928, 61.19401493380147, 49.648663459285615, 23.919856702127767, 32.65214900816641, 63.20570053592805, 29.655375826743345, 26.018803273477864, 45.204606286941036, 65.99913412524809, 64.0736504523985, 29.333188418419134, 2.4016363678439974, 0.4015950876618586, 0.0823420335748984, 0.07307211688208966, 0.041414004555272485, 0.15048438232512246, 0.9288996265780542, 2.2412393746837496, 0.7825070271088231, 0.32303071791125887, 0.8598985775343834, 1.501812168186711, 2.2257045824681563, 2.710617400946156, 8.600632067649595, 25.983135200315907, 30.637013681473274, 17.708028478007165, 6.8885861289116646, 4.508045738743198, 7.0763936254286, 17.24079966545105, 19.628679790804465, 9.176443853685933, 13.524981506409185, 16.307965901590165, 13.82910640008988, 12.522547245025637, 13.705264426046803, 11.912105833330463, 12.720872086863364, 11.532169368959243, 9.230079324014726, 8.069079326045129, 8.33481990521954, 7.151049567807106, 3.19141834974289, 2.8112595360125265, 0.37465113185105786, 0.10011898128375893, 0.3032165891941517, 0.20285501084741087, 0.13323035091161728, 0.03970834043537898, 0.37568354258133524, 7.225668737965246, 15.14550187895375, 29.885966085618545, 51.94736065403108, 58.38299343662878, 51.90360269238872, 45.144829365514944, 44.162122664913056, 44.69992276160948, 45.53482278700798, 45.58679811416134, 45.13459982410554, 45.199009064705145, 44.432770129173036, 44.840967270635794, 45.32371690196376, 39.62466993639546, 38.57169397415654, 43.69150492452806, 43.28990128732497, 45.29980221102315, 42.83095652057279, 46.74204203390306, 42.30208766075873, 42.62215698918989, 38.894622710443315, 39.665619480994444, 40.487638442747055, 39.18437996218282, 37.67542062267181, 39.68309756248228, 41.37787526653659, 40.68528275335989, 36.99810966368645, 36.12465273949408, 39.034145339842766, 42.667558423934445, 50.115241158393125, 55.18560671037244, 31.897367315907633, 16.464244896365752, 8.079765333283333, 1.2884827895510582, 0.9789725429108067, 1.015899696898076, 0.27099287798327787, 0.05747221102337203, 0.03602543402643454, 0.04429504673387255, 0.08628810650759167, 0.07160228526880665, 0.052314041437761444, 0.10383322068880643, 0.08483117581495354, 0.0264220392601865, 0.2537267270588106, 1.3770495403197505, 3.6093981275635385, 8.250949825009993, 3.8706583794086216, 2.822780517801162, 2.9862298503998788, 11.073361885163093, 21.788662364405972, 27.3045503324078, 32.96524632361628, 20.08864829617162, 14.511958687536179, 4.736232565295312, 7.048480568393585, 2.276736334446938, 20.901567359124464, 19.451902489508353, 21.679308645186886, 18.313552218098796, 17.22306662990201, 18.797529551290697, 22.64006183993432, 37.45777222418016, 45.657012462615974, 47.59593809804609, 53.73292946046399, 66.325161533971, 57.53530256209835, 37.20095503714777, 2.7844172860345533, 0.3791569852300229, 11.329746630883987, 60.48464644339777, 58.79879997622583, 51.06350944888208, 33.240216239806145, 37.935720874417214, 45.46822094148206, 97.95533503255537, 48.72930695933681, 34.90869837422525, 63.349945699014974, 71.28165675747779, 34.0160689046306, 23.670627340193718, 45.86271724393291, 14.239195104568237, 0.5940546071337116, 0.3096906756681781, 0.08272527671989896, 0.054926313159446565, 0.02051394429027794, 0.11919340614469782, 0.03100960357715526, 0.12075539047439253, 0.04332365873720377, 0.36817922106673645, 8.684571769929702, 69.27312866333993, 56.87619532308271, 39.96056210610175, 83.93813333203717, 74.10974056490006, 68.47934292208764, 62.3939032708445, 57.45794557755994, 32.824037075042725, 31.793801053877804, 63.75575019467262, 33.10446693051246, 35.78135513490246, 54.01593631313693, 71.12358523953345, 76.98959181385656, 57.81866635045698, 5.834415804955268, 0.38782306376003456, 0.08538059875248902, 0.1922966645009095, 0.05447555085523956, 0.37893797601422957, 1.0251969399471437, 3.107473744500068, 1.355300120288326, 0.3368094220997826, 0.9682417961378252, 1.8188358987531357, 3.569250217368526, 2.423157677535088, 13.003363147858652, 28.86630673562327, 30.948832304246967, 21.06172557800047, 7.389458091028276, 5.404776046353002, 8.632561141444791, 19.240106267313806, 22.490678371921664, 10.541331594990147, 15.548641124079305, 18.173284338366603, 17.81266554709404, 13.54974146812193, 17.460842670932895, 14.865032799782293, 17.973661192001835, 16.201184276611574, 11.911510613656814, 12.820497347462563, 10.603340345044291, 8.698795264767064, 4.730777528978163, 5.201901255115386, 1.7239455518222626, 0.19818552108781956, 0.14426417738920258, 0.18683513175816308, 0.9548507017954704, 0.3226179803811735, 0.5078574276018528, 6.747378841523202, 14.233305665754504, 29.481538341891383, 51.1578385291561, 59.23029991888232, 53.91075795696628, 49.411403209932395, 48.414042534366736, 48.139402097271336, 48.109133166651574, 48.27243320403561, 48.458330015982355, 49.095703401873195, 48.0596250103366, 48.17219703428207, 46.53521545471684, 45.01774457193191, 42.770069568387925, 48.81550496624362, 49.66383910948231, 46.9347127791374, 46.35407255541894, 49.88963034845168, 48.12487363815308, 45.283261576006495, 42.52966750052668, 45.16369204367361, 42.629315314754365, 41.18418862742763, 43.270787577475275, 44.776495272113436, 45.16837535365936, 41.98901191834481, 41.73797630494641, 40.978530914552756, 42.56119943434193, 46.46893132117487, 54.894323656635905, 55.318312260412405, 28.490839812063403, 12.038978818924198, 3.26643564047352, 2.037709057331085, 3.404047585302784, 2.9411446567504638, 0.612618449714876, 0.22249156038366982, 0.024772037173651403, 0.06854153418492887, 0.008661595000434787, 0.07185306415081986, 0.04731590378909342, 0.18488074953277267, 0.11669628126847169, 0.0552272976135775, 0.31883675424802693, 1.534020833430752, 5.6175626670160606, 12.132097848000067, 5.527568296078713, 2.5027859595514115, 4.2767239578308605, 17.40266803772219, 25.27420013181625, 32.33727878139865, 41.24880575364636, 28.479963079575572, 20.052766453835275, 9.753709858463658, 4.062928552589109, 22.099429791973485, 32.16921894781051, 31.732096287512014, 31.58885721237429, 34.90899255198818, 35.462152650279386, 35.95862665484029, 41.0287647093496, 48.53771094352969, 53.34724672379033, 58.34931988869944, 62.61418750209194, 71.84046899118732, 71.48525914838238, 39.55605983734131, 3.3118064317011067, 0.32763677559071974, 20.281040553123724, 72.81345998087238, 67.69639861199164, 56.31473548950688, 42.0224226674726, 55.76837678109446, 50.58782008386428, 95.2784429057952, 34.79839740260955, 43.974888324737556, 74.38388286098358, 86.33750992436563, 43.272231009698686, 33.202612476964156, 51.55392339152675, 12.81730846051247, 0.6586611306955737, 0.42668321079784827, 0.06745106931174956, 0.06236749370732616, 0.04853178108591707, 0.04345559822996298, 0.22138879213842655, 0.2755052890748747, 0.2484709655325259, 0.47008926229130843, 5.021635986143544, 99.68953255684146, 84.27013843290268, 32.11842033170885, 79.78488460663827, 80.99832473262664, 74.28583929615637, 78.04816892070156, 69.03331495100453, 37.57279572948333, 43.90336782701554, 74.12269223120906, 40.400208811606134, 37.78256800866897, 62.64492319476221, 80.02876973921254, 88.97283277203961, 70.06089748874788, 5.3388890527909805, 0.6478228251780234, 0.2542796586790393, 0.20253602715749897, 0.15760398980590606, 0.903718316506955, 1.2780896117610316, 3.1600403689569045, 1.8488639713295045, 0.800180369086804, 1.4440817433980204, 2.112512088591053, 4.737541656340323, 5.443939931931035, 15.639060581884078, 29.58903285764879, 31.65391952760758, 24.995633402178367, 9.697606236703935, 11.504417619397564, 14.174062186671843, 19.300175405317738, 20.92474464447268, 11.395396321050583, 16.257603649170168, 19.50515062578263, 19.713267664755545, 14.597005478797422, 16.60752711757537, 14.238485155567048, 16.641510532748317, 15.630487261279939, 10.817021266106638, 13.266069773704777, 10.77756320276568, 7.992264118886764, 4.991871570387195, 5.548448543394766, 2.009486868496864, 0.16917778569604122, 0.1782421380161278, 0.6435511801992694, 0.7399988919496537, 0.25896554272021016, 0.9708099067211152, 8.948042277366884, 16.445193944438813, 36.27979816928987, 57.29335508038921, 62.835260129744015, 55.792644485350586, 53.26106048399403, 52.142906496601725, 52.45510362809705, 49.957659936720326, 52.2599264883226, 49.149133928360484, 51.15636371797132, 51.448643053731615, 51.05816325833721, 50.45032924221408, 46.749255272649954, 46.743269735767, 52.34806606846472, 50.36990888657109, 51.52221102868357, 49.43615728808988, 52.814082868637584, 49.63193062813052, 50.14607883268788, 46.985476093907515, 48.67568815908125, 46.794272315117624, 46.05375236080539, 46.420768537829005, 47.21820992808188, 49.62169324198077, 45.66546909270748, 44.73174102844731, 44.9230585559722, 45.694255367402114, 50.284342381262014, 57.25212312513783, 59.81275619999055, 35.86428188508557, 21.014413948981993, 10.51957714942194, 4.228325832274653, 2.861700726132239, 2.185231605845113, 0.661124624311924, 0.3535317731720786, 0.18413985057944254, 0.16463905182336608, 0.10222778385204655, 0.31901782678980983, 0.20769981216759453, 0.25465403052587665, 0.16856845468282702, 0.17505072297588473, 0.6244315867943149, 2.444065381442347, 6.624196806261617, 12.719860115358907, 5.9385650292519605, 3.6239719390869145, 4.439184607998017, 15.28958426367852, 27.969580350383637, 37.650894041984316, 38.773817631506155, 27.17605152437764, 29.536824149470178, 19.597883301396525, 11.025532503281871, 26.800982721390266, 45.8087375856215, 44.804775561055834, 44.1323636424157, 45.80112426511703, 44.33942556381226, 43.717204293897076, 51.91037270330614, 58.7347633607926, 62.52243934139129, 68.26103164303687, 70.58175686867007, 82.40195274353027, 81.0802944244877, 49.064614695887414, 4.023069672046169, 0.6907436672237612, 21.44664541367562, 84.59374966159945, 70.84399084891044, 67.06620708588632, 50.81354464254072, 51.17257879626367, 54.66789699369862, 114.23000197256766, 64.07510565173241, 47.71574297258931, 98.89953582517563, 111.93292079433319, 60.936778053160644, 49.14956931144961, 86.03815463281448, 18.574897781495128, 1.055228138162244, 0.3684973620599316, 0.31413619196222675, 0.1981095404874894, 0.26523778034794715, 0.14704044938327807], [0.1340173683579891, 0.10420399958327894, 0.05544504278429574, 0.0077411614268297155, 0.22595781712762772, 43.44776099728, 91.69210218614148, 35.07176699176912, 15.96472321018096, 30.052870781190936, 57.02456289722074, 62.25630260282948, 37.073921234376975, 38.19100441471223, 39.489654110324004, 62.391981309460064, 25.91357392649497, 23.811960143427697, 47.776527943149695, 63.07392066524875, 72.5901202232607, 61.333737604079715, 15.216995900677098, 0.12126981851554687, 0.12023921575277083, 0.040541415087758534, 0.5525613852566289, 1.103951330146482, 1.3956555483802673, 3.956773526245548, 3.253540848532031, 0.20068505148012794, 0.6832858319244077, 2.3550145856795774, 8.570386671250867, 5.923524210529943, 15.154368396728271, 25.495845425513487, 32.73622697399509, 35.944761076281154, 22.420199263480402, 8.533617392663034, 9.574056479238696, 16.33026849838995, 31.695933995708344, 35.99510077507266, 26.290472515167732, 24.52620610114067, 36.73779372246035, 32.79918297644585, 25.33501059778275, 30.053782732256, 38.90493854399651, 41.300867372943515, 38.25296609632431, 20.134573367334184, 14.17089193098007, 13.157159282315163, 6.521928358462549, 4.423006301926029, 0.8994569064628695, 0.49811609870483803, 0.20840527189354743, 0.3911127065939288, 1.604391954118206, 0.23192741938175696, 0.39171895793368744, 3.4172493027102564, 9.54034076583001, 16.413735555064296, 34.84291630406534, 51.29889872766311, 53.17079497921852, 48.37115533890263, 43.989710961618734, 42.498669009054865, 44.69875389529813, 45.83364855858588, 46.7339894079393, 45.91930920077909, 44.93029925131029, 44.371761583512836, 41.72160825421734, 38.543174420633626, 40.498028801333525, 42.310618815883515, 42.538677184812485, 43.019642137712054, 45.184551208249985, 43.1854760262274, 43.83622861677601, 42.15677561298494, 41.21520280838013, 38.429359005343535, 37.21047070718581, 39.70512167099984, 40.79065330566899, 39.52961914000973, 36.621071830872566, 36.51884701944167, 35.31946466815087, 36.29524838539862, 40.73501840714486, 42.61584589558263, 53.63118710056428, 41.407179294093964, 15.9673531593815, 6.487115361998159, 1.2885846486014705, 1.3082511674973274, 3.3396947287744094, 1.7010253042944017, 0.4664500995028404, 0.1774825771609622, 0.10525575403364436, 0.077905802266492, 0.09507040057571665, 0.045684665111043764, 0.0053949553928818676, 0.13776530030994646, 0.1628755633869479, 1.0801836055132652, 1.0229189008955033, 5.7834720611572275, 11.136695415742937, 17.094985554295203, 12.269688710089653, 4.514331827240606, 18.388202767218313, 43.57171573946553, 28.114961039635446, 28.934010767167617, 47.2340759154289, 36.10982618024273, 13.75670729144927, 9.874354120223753, 6.072779220919456, 18.53179681685663, 20.356565790791667, 17.43136998145811, 22.45967595807968, 23.317788570157944, 24.16447727910934, 23.98256951762784, 30.906776651259396, 37.930955194657855, 45.9497977841285, 52.606726769478094, 61.16916671875985, 70.55428458798316, 69.71080241664764, 31.843491600405788, 3.359209010677953, 0.031309444645059206, 28.594366850391513, 64.58051873791602, 63.86144630370602, 43.94723169265255, 37.98348749837568, 38.7962967349637, 46.190803896996286, 88.88054724662535, 69.5343271378548, 47.44197722404234, 81.06989229879072, 27.612177902652373, 24.843431711196903, 25.779544576521843, 34.568146428754254, 1.7056684099858808, 0.11398374012881711, 0.2502581260858044, 0.08126042467812378, 0.04075038472130414, 0.064570295263923, 0.10347239327647033, 0.1347101876331914, 0.08605372190715806, 0.046645630481502706, 0.03592509949099153, 0.2535411652417914, 58.27596372173679, 75.90489172166394, 33.80463746286208, 41.11235041772166, 56.05269370540496, 55.03239108670143, 58.30783690175703, 46.55880851130332, 57.36889600753785, 42.43096889988069, 68.3294063998807, 26.871787386555827, 33.68984537739908, 59.17908160917221, 68.37309375885995, 77.54128102333316, 75.91836114083567, 29.95046161836194, 0.07126157532536215, 0.1716379085255246, 0.11745182016203481, 2.97291315851673, 2.6298680565049573, 1.7133134771739285, 5.2598591773740715, 4.019442215081185, 0.0885286685379763, 0.8364608222919127, 3.3135523767240587, 10.594066881364393, 7.5074243545532235, 19.12297841041319, 31.631767942059426, 41.41322758889968, 41.545325171562936, 32.91349849393291, 8.69317352771759, 12.044214202511696, 21.200475500475978, 38.45665085700251, 39.82196515606296, 29.879284328030003, 31.77432256360208, 44.01854038238526, 43.53857171150946, 33.71718037512995, 38.92829233600248, 44.737832469324914, 44.56315755844117, 45.54302838540847, 35.67027361162248, 22.333481542525753, 17.472311681316747, 9.496161149394128, 5.745966847865812, 2.1267319062063774, 1.9144803213496364, 0.7378855311582166, 0.6431900157082466, 1.2835772527802376, 0.9094538022914241, 0.7821059647587039, 2.9502599998827908, 7.924245317136088, 16.43755610912077, 33.90210443927396, 51.42443810739825, 57.57323188166465, 51.3204364622793, 49.14521940292851, 44.53429675871327, 46.66798768504974, 48.80330639500772, 49.81006899187642, 49.96845429943454, 47.547061443328865, 47.02142853890696, 44.566926956176765, 41.62839704944242, 46.80094034441056, 44.09242606932118, 46.27508386488884, 43.99844215762231, 47.62578341268724, 47.23579391356438, 48.281423276470555, 43.78617132863691, 44.39855137178975, 42.999657661684104, 43.45770420566682, 43.50789485439178, 42.36027994463521, 41.037386078988355, 39.07783269882202, 39.57015291337044, 38.99953042307208, 40.305683612823486, 45.695004540105025, 46.80394880233273, 53.9477772866526, 33.82352759761195, 13.664063849756795, 4.107502612375444, 2.277078806392608, 2.396091852457293, 4.844883689957281, 2.410547502579228, 1.1991188170448428, 0.24514433597364735, 0.28862714947712037, 0.07046803080987546, 0.1354112040491835, 0.20278188009415904, 0.01163685162957277, 0.051583542128003416, 0.044362332236262104, 1.9308514364304084, 1.3831694183811065, 14.533835707172273, 18.308500205316854, 17.949501352925456, 20.17438150221302, 12.250195510925787, 30.88979082722818, 52.30877568644863, 35.01969360536145, 39.54200206264373, 53.84234397642074, 40.67550036215013, 19.320085356312415, 10.768216194645053, 21.064510460822813, 29.722603290311753, 33.59859143534015, 34.524462992145175, 40.07536988104544, 40.05496963377922, 39.06199809043638, 42.83016027942781, 45.60211496968424, 50.65348056054885, 56.59553012540264, 58.99398888311079, 67.19326050050798, 73.42824443694084, 69.98325809355705, 36.562326492801795, 4.842662157550936, 0.039524015850357475, 42.0599832842427, 69.99252273190406, 68.30685277138987, 55.318724109280495, 53.30131576907251, 54.840445979948974, 48.600476711027085, 91.38816556622906, 59.970349188773866, 53.68747703490719, 85.76988020250874, 42.26438191629226, 33.23148504380257, 38.25095392042591, 38.674048223803126, 1.7188803010409879, 0.06399254622538725, 0.019051143448920022, 0.031547470078352964, 0.12738132323589058, 0.01936421868571591, 0.016095139566929113, 0.32621795011143534, 0.3640290163457394, 0.11848638359937938, 0.22283507420891718, 0.3390682476662821, 55.4309941107227, 122.16868308282669, 52.80547718847952, 34.15588178942281, 45.581295028809585, 75.15056502434516, 79.3932673238939, 51.972075508486846, 55.6668266173332, 46.16694019686791, 73.73032969813194, 35.76617163996543, 37.74599975155246, 65.17834678772958, 77.86361355935374, 86.75479519751765, 92.01025347555839, 30.677390560027096, 0.5069635255682854, 0.2920688454422259, 0.21440761674556041, 2.54000582041279, 4.326825862930668, 3.6914808327151887, 9.229782204474173, 4.912554381355163, 0.6467291580573206, 1.4799326970692606, 3.9487052108010943, 12.010917202118906, 14.9229662072274, 28.404202499697288, 37.66763864024993, 42.513981942207586, 43.39727224842195, 37.748310027583955, 19.103690155090828, 15.35802766200035, 27.38265452846404, 40.560857326753684, 41.09107548190702, 33.50684719700968, 37.353005716877604, 52.712603307539425, 50.62793024124638, 44.45746144940777, 50.06777263456776, 50.4028489512782, 47.624951870210715, 47.78131715713009, 35.71027394263975, 23.880780089286066, 18.3523307308074, 11.089035676371667, 5.6956531347767, 2.316240730785555, 2.7597722987974844, 0.5243246101083294, 1.6976516982240064, 3.239436250540518, 0.8885903476226715, 0.7435306185676206, 5.012915576657941, 11.91122918359695, 18.30254996976545, 37.57078747595511, 52.613877250302224, 58.09761355000158, 54.6139604814591, 51.39896231312906, 47.576498831472094, 49.92937964777793, 51.28910456934283, 52.861308205512266, 52.375691321588334, 49.67990513770811, 50.682408040569676, 48.91796511988486, 42.46259889295025, 46.69012554230229, 46.50258133488317, 48.564994950448316, 47.12661081744779, 51.736564636230476, 49.135409555127545, 53.11890202183878, 48.22558833706764, 48.15633104693506, 47.68797259176932, 44.513888666706706, 47.44648010500016, 48.49383531078216, 47.43368925586824, 43.6715361379808, 43.41483662205358, 42.70493861167662, 42.07516677917973, 49.390096895156375, 48.70075602685252, 58.71850121405817, 42.1365910960782, 17.544083210729784, 8.452152705961659, 5.778977024939753, 3.125908394013682, 4.654210411733197, 3.8972748479535504, 1.1183693500295764, 0.32283855241633236, 0.42107186190062956, 0.15917381121506616, 0.16771782129522295, 0.26842375616392783, 0.1444918893638157, 0.20590310615877952, 0.5450466143027429, 1.941086861395067, 2.0386680768382166, 14.028746216527878, 18.373450733000233, 18.94968809620027, 19.579083381160615, 11.709907650947573, 24.35917785090785, 54.49118245032526, 38.88510704040527, 43.91584488653368, 55.98406399449995, 46.86439252668812, 32.18061539434618, 20.604810637812463, 30.73855992286436, 45.204747492267245, 45.12616672823506, 45.25137662887574, 50.99167516154628, 49.446563336157034, 48.223230992594075, 53.68372724902246, 55.01670945075251, 60.91169841827885, 63.16086392248831, 65.86289451968285, 73.60378619163268, 76.22555332799112, 73.01081011372229, 38.84366719953476, 5.302370315597904, 0.12671655043959618, 40.72160782352571, 79.09084473886799, 71.39633901657598, 67.28260424829298, 60.81185448554255, 51.009537635311005, 59.14607878654235, 104.58243831511467, 88.58427493802964, 69.89505967786236, 103.94661426544191, 41.85069737895843, 46.53002615897886, 57.70151692052042, 66.30361987698463, 2.5052202805396053, 0.28137343064431225, 0.3706752580981101, 0.17732952811544944, 0.1606849043239509, 0.1636002825633172, 0.12617466580723563], [0.07426962722092867, 0.16649770370173841, 0.023817641007143165, 0.19492299776644478, 0.43386788978692026, 6.754966666621547, 93.89525828822967, 61.20895524178783, 38.803859064655924, 23.2286899705087, 56.107650033889286, 69.02164197737171, 45.75311445420789, 37.25547990491314, 49.7971212479376, 68.45809152049404, 44.315930566480084, 39.292633456568566, 38.340791886852635, 56.32782051640173, 65.94699013617732, 73.95874500274658, 46.6957776777206, 0.06922977991522321, 0.20925535369784604, 0.07930251078740244, 4.709248129398593, 2.2355879747098495, 4.632718764966534, 11.776471253364317, 6.452945143945756, 1.6422974943153321, 3.485772864472482, 7.120922332809818, 10.555231494288291, 6.438590249707622, 13.436694837385609, 36.7905221446868, 54.421411329700106, 42.92254386409637, 37.65470266342163, 15.688720730043228, 10.929515823241204, 17.46822653278228, 41.97802143712198, 50.087149143219, 24.760046043703635, 30.39493872273353, 42.339711035451586, 48.27078973093341, 42.07308007824806, 37.87430832462926, 34.94973421096802, 42.371497923328036, 55.87295501462875, 62.2411112631521, 56.05905971219463, 42.929376632936545, 26.80044927904683, 4.787754858693769, 1.130925837543703, 1.03701718632252, 1.088199949552936, 1.6127649886954216, 1.3495691697443686, 0.9563171166566111, 0.5067613396433093, 1.3506000176552804, 3.768168317694818, 10.327956618801242, 19.493438428448094, 42.71790988983647, 51.65210816168016, 45.587107981404955, 47.60087636209304, 41.303954278269124, 43.95620215323664, 44.53028809639716, 48.364267656880045, 46.96225174011723, 46.0554938931619, 41.36628858504757, 39.104744080574285, 39.49626330406436, 40.294861793518066, 42.20895882575743, 44.67234457692793, 41.31186177653652, 41.16574956524757, 41.30003975283715, 39.856058397600734, 39.84250660865538, 38.68643899117747, 37.6338238869944, 41.35857328291863, 37.27435042781215, 35.81542091984903, 36.86297224413964, 37.18626968322262, 36.019368479328776, 34.8637911581224, 39.64715688459335, 39.91821227535125, 48.607838999840524, 44.94087003892468, 17.349270851381366, 6.417934558083934, 3.372532076412632, 1.7948053753183735, 2.883297541449147, 5.330758469720041, 6.626807633907565, 0.746770067320716, 0.16062533332695886, 0.08882316039694894, 0.09399820689953144, 0.06598290777014149, 0.058985108269318465, 0.024290202343235576, 0.10345768438832414, 0.1438729056427556, 1.6073315254142209, 3.1876653769323906, 12.818714630219246, 26.89273088209091, 26.053559395574755, 29.296739793592884, 39.235300171759825, 58.846178285537235, 61.3989273963436, 49.232413691859094, 52.616936699036636, 42.004544504227184, 30.087450396630075, 17.812224280449655, 9.659180737310841, 10.783364388250536, 16.71523540250717, 22.516993553407733, 23.744101178261545, 28.033032532661196, 27.61994811796373, 28.800505053612497, 29.849744958262292, 34.247739776488274, 40.881334581682765, 47.64286533478768, 56.50700615298364, 63.935645780255726, 68.4974564275434, 69.21070806441769, 38.89022965585032, 3.161971155674227, 1.6268219053745272, 48.95586306048978, 64.59695346893804, 52.16642502815493, 51.32057374523532, 37.66934094890472, 32.48843319954411, 56.64989025362077, 83.29207189621465, 64.45978426164197, 51.32990114150509, 28.473336235169445, 24.582870621835035, 35.96343548067155, 30.416058724926366, 13.844110446591532, 0.8101107071964972, 0.29330331952341143, 0.22522929815515397, 0.07748096820808227, 0.22449242882430556, 0.018023057284975247, 0.09162517294528023, 0.05641190320133202, 0.01615405172830628, 0.12390653227245617, 0.16645825017363797, 0.6209646405712251, 11.826359879586006, 97.99208764106997, 45.28963934990668, 34.42796876353603, 42.893914484208636, 72.60965362671884, 71.6534346918906, 36.44625179229244, 45.558976742529104, 57.6862314439589, 75.85457555709347, 43.64825294863793, 43.3406489126144, 53.092645675905295, 62.602585131122225, 76.76458897129183, 77.13459399438675, 59.325185975720814, 0.5860073131418998, 0.12172859792988147, 0.2735522245207141, 7.098034812558082, 6.423409696548216, 10.565525754805535, 14.619150200197774, 9.044407067760345, 2.636329180771305, 5.108162981848563, 8.554702093524318, 11.61871744740394, 10.21463248037523, 27.128463368262015, 51.97149499770134, 63.46677349459741, 49.373999487969186, 43.56569490125103, 26.485304486367014, 13.240606727138644, 23.568782998669533, 51.81307831118184, 58.452623351927734, 34.01947352194017, 39.61247528752973, 50.74795084614908, 57.51776172268776, 53.09156702410791, 49.057303397886216, 40.992851488051876, 44.86969863214801, 59.454957592871885, 62.98784425181728, 61.72498618402789, 51.38950155627344, 34.16910017690351, 17.461078013143233, 2.272815190015301, 1.644008505728937, 3.3620608189413628, 0.48363363550555327, 0.2766409378138281, 1.458539967575381, 0.8426596380529866, 2.028200619163052, 2.8157952668205386, 9.468752607222527, 18.323809216099402, 38.41817240561209, 48.514918050458355, 49.272970999440844, 49.25643820916453, 44.68219364843061, 47.27424490836359, 48.49605144992952, 50.57532733486545, 48.9428682481089, 47.9575139476407, 46.24235953054121, 42.585333778012185, 41.06977701187134, 43.20807672316029, 46.38941703304168, 46.70100227479012, 45.12900260186965, 47.66560723704677, 44.830216053993475, 44.45490014168524, 43.2620995275436, 41.90424949892106, 41.07340912665091, 42.716925374923214, 41.425524219389885, 39.69449204783286, 40.81821580086985, 38.968696671147505, 41.25002168839978, 40.681356460817405, 43.20504473101708, 44.34186920042961, 50.42331587883734, 38.01327789983442, 13.967572931320438, 5.728181350615717, 2.949784657647533, 3.128741571018773, 2.237561662350932, 3.6546899810914075, 3.7837092386138056, 2.49636969739391, 0.6581656250261492, 0.08724092836341552, 0.1404922975287322, 0.06134312306981414, 0.007457779279173984, 0.011001600989050443, 0.09150690429152981, 0.6277605759040003, 2.5182584841405196, 9.855708153017106, 18.415216130595056, 34.05164872446368, 30.74832074103817, 34.56117637695805, 50.60918131182271, 62.33194943397277, 68.44990161157423, 60.91262802000969, 62.97885417938233, 48.33479496740526, 36.90642426090856, 29.91815305525257, 23.49503459468965, 27.70036062886638, 33.03129119257773, 35.8519224966726, 39.20539209919591, 40.424205872320364, 42.218199929883404, 41.95559332447667, 42.23574861403435, 46.826502430823545, 48.61267528226299, 53.65742775701708, 64.63396103151383, 67.43465885039299, 73.57506659723097, 74.78709466995733, 43.16747626950664, 2.3765868861829085, 3.557615241696758, 61.98086984695927, 72.12495065504505, 58.19199754345802, 58.364158215061316, 61.48605500498126, 39.223156513706336, 55.16583011996362, 96.37145842275312, 59.14474125831359, 54.04027069768598, 34.725245198895855, 36.654411977337254, 39.6386924097615, 45.48556566238404, 12.824592301922461, 0.747966941806578, 0.23990622511313808, 0.2799600597110487, 0.1483148672888356, 0.1943698669633558, 0.039239440999564626, 0.08061604514237374, 0.27808581028253804, 0.22596448209256897, 0.18532347174421435, 0.3405123846905847, 0.7420749289374198, 8.26629609830918, 113.42808123557799, 83.7453253038468, 58.78890775865125, 38.4614400709829, 63.96514592632171, 88.64574632337018, 56.7766220338883, 55.12355873661657, 56.27522545476114, 80.68651983814856, 51.29717288478729, 54.05299094415481, 54.135666662646884, 72.84604703226398, 83.6562482772335, 89.17895332459481, 66.00677490234375, 0.5906369356859116, 0.2423906022863042, 0.33940091368652164, 7.221412966328283, 10.052919041725898, 15.940462370072643, 15.030001805674646, 10.313660560115691, 5.272480383996041, 6.43556070904578, 12.006517283378109, 13.226543068885805, 22.408636116212417, 36.15150528569376, 53.83655848041658, 62.179934055574485, 51.10425110786192, 45.060678835838075, 36.279111754509714, 18.48170618857107, 33.439762899952555, 55.24699180356918, 59.9575936409735, 41.95678964737923, 45.87122094246649, 52.45360528269122, 57.417737360923525, 57.42142046651533, 58.19179358020906, 52.49620222276258, 54.23665200510333, 67.13496623500701, 70.9591281029486, 67.06846637110557, 57.01131313077865, 39.20897322316324, 21.40113611375132, 3.4924136823223484, 1.8240435806012925, 5.804862706891953, 3.442834923344274, 2.530602428220934, 1.5869393680364856, 0.968996974970064, 1.6571665867682428, 4.603523092885172, 11.47119318285296, 21.526108710996567, 44.20461370098976, 50.254159742786044, 49.551533806708555, 50.62700063951554, 45.68151550908243, 51.26955547640401, 51.94648204311248, 55.05936914874662, 52.05566513922907, 51.55574729365688, 50.30913568312123, 45.3678317992918, 45.33356597346645, 47.613204371544626, 47.72303858110982, 51.030094777384114, 49.38628827371905, 50.1042506771703, 48.8695473824778, 48.47877733169064, 46.909848874615086, 45.0536617155998, 45.609124245182166, 47.799795443011874, 45.922113695452296, 45.455767416184955, 45.89461395817418, 44.558262440466116, 45.878387112771314, 43.62507958565989, 47.53206229978993, 47.020028252755445, 52.928596465818345, 47.330487774264434, 19.837730353878392, 9.532779416730328, 5.689719569298529, 5.332883413760893, 5.097237219733577, 6.2605156244770175, 10.402767004505282, 3.0043612516695455, 0.6338425785783799, 0.21270178408632356, 0.3524980754140885, 0.12867749037761844, 0.12179239007133631, 0.08320460261236276, 0.23873735880178792, 0.9852553831954157, 2.9613872737653795, 9.117611242878823, 22.543200869714063, 36.87566895638743, 30.031609573671897, 35.74466528431062, 49.78110621052404, 63.02424384701637, 70.70949277570172, 62.549491928469756, 63.67542005354359, 50.887002791127856, 45.289043149640484, 36.44415724662043, 30.735418104356338, 40.848837744805124, 45.876033690667924, 47.02997146114227, 50.00539518171742, 48.433246458730395, 52.70215411340037, 50.639607137249364, 49.83346985232446, 52.42087702597342, 58.18520792068974, 59.384837381301395, 72.28929796526509, 73.16135068093577, 82.5496692042197, 78.98052415540143, 51.81898932303152, 4.398575819307759, 2.48255584509142, 64.47033935977568, 80.59643868477114, 65.73326410785799, 70.754819685413, 54.01644229888917, 41.406210468661406, 70.93892789656117, 100.17810298550515, 77.99818223522556, 71.92719259569722, 42.74650789076283, 43.09902306525938, 61.26924991607667, 83.37521045438706, 28.7165565259995, 1.8273740405997925, 0.5578278413703365, 0.463000834589043, 0.2981850462815454, 0.32006369002403756, 0.2961745557765807, 0.2260948702572815], [0.09288692741744942, 0.04681649107125498, 0.07927575899708657, 0.09252771645063355, 0.1959743768337273, 0.5255012598729903, 38.85728566877304, 88.75350167674404, 57.01573756433303, 49.959907454829064, 30.736012343437444, 71.91853200235676, 62.297369818533625, 56.24658038539272, 77.75023352715277, 78.70460110325968, 60.04532921698786, 52.947506212419086, 37.35496690196376, 42.80120534281577, 59.325256578383915, 63.94619303364908, 67.72558889081402, 3.7534258442540325, 0.0922901219417972, 0.8779466897249223, 9.759313944847355, 8.129356839964467, 5.327160185383213, 3.6351960464831325, 9.16102501653856, 9.102907257695353, 7.250941549578021, 8.291902311386602, 10.464322720804523, 7.304999655292881, 18.914131810588223, 49.32632307852469, 48.42781397604173, 43.90900427295316, 29.316728191991007, 16.74927569204761, 12.784286026031742, 18.92284535592602, 44.53411632968534, 56.690274976914935, 46.70319880208662, 54.415657212657315, 52.874805081275206, 53.22720650703677, 55.85534357255506, 56.37155494382305, 43.03752030095747, 41.04299899070494, 43.37540895708146, 49.570361183535674, 55.213718337397424, 52.86645043280817, 36.863568444405836, 19.46701930415246, 10.677746726620583, 0.7074544963336761, 2.858092881018116, 1.0567130004206011, 0.8207691965564605, 3.115126043558121, 1.049434919991801, 2.0199441525243946, 2.5514581607234095, 6.27324910894517, 12.574548067585116, 21.27289814333762, 43.46569407370783, 47.17277711437595, 44.15050460446266, 46.76168526372602, 45.45711671152423, 45.75237312624532, 45.349600622730875, 47.36434959596204, 46.727093881176366, 40.38763369283369, 39.160865352999785, 40.94518292334772, 39.667153127731815, 43.837562222634595, 43.14745649214714, 40.61668049904608, 40.078499932442945, 39.05549872306086, 40.56847456962832, 39.871034006918634, 41.00172781175183, 39.296700954437256, 36.14888122004848, 35.05222574357064, 35.18240920958981, 35.429636201550885, 33.43424020274993, 35.05309650974889, 37.706752515608265, 39.349735321537146, 41.810022400271514, 42.809257968779534, 20.142347505015714, 4.881818688684895, 3.040052368756264, 2.27928317842945, 1.3887847815790486, 3.104840853521901, 6.197727303351126, 3.8249152081628, 1.6342680348503975, 0.08598538686431224, 0.13175791459939173, 0.17837540667143562, 0.2928416136532061, 0.6192066832896203, 0.998685272230256, 0.31286589560970185, 2.357120163017704, 6.94316198748927, 24.185120713326242, 31.23035061743952, 40.55801753074893, 43.94098727933822, 48.16010828941099, 59.58937721867716, 51.584353139323575, 54.5020160367412, 48.30753057233749, 48.34119235315631, 33.722695227592226, 30.107179918596824, 29.192222356796268, 17.991304013036913, 22.833360164396225, 23.054379840050977, 24.696797824675038, 24.886060030229633, 29.672851947046098, 31.84526647290876, 34.65652919584705, 35.79435779202369, 40.5762565520502, 44.30833685782648, 50.40625356858777, 58.36989664262342, 62.118035131885165, 73.18794435070407, 69.33751044734832, 35.68247610522855, 0.6964909201187472, 12.466828996135343, 56.263983941847286, 63.40113655213387, 37.68258287060646, 50.65131148984356, 29.758171343034316, 31.743365257017075, 56.70825512178483, 65.39030774947136, 66.52980727534141, 31.297407457905432, 34.6512379184846, 30.459695093093384, 31.663556791120964, 27.732426005025065, 1.5927133420782706, 0.34046620491050905, 0.03492896685436849, 0.09915781673043968, 0.019746326105368715, 0.1774877712370888, 0.058264782607194886, 0.04667483375317628, 0.04869513018357177, 0.10235578182243532, 0.0792527150723242, 0.1667261817642758, 0.28983769097155143, 0.31825593702735444, 56.77374301418182, 84.55138806373843, 42.86433196836903, 41.915651829011985, 50.84045994666315, 101.84718132019044, 62.15442295997374, 54.796284014178866, 80.4381553588375, 84.81697174810594, 71.45240537581905, 51.16574210505332, 55.666446147426484, 49.55893924159389, 70.56954260795348, 71.99602234748103, 80.88836500721594, 6.8585177294669615, 0.07954132337603839, 0.865169385027501, 13.473592573596587, 15.972606193634773, 9.168622647562335, 4.800942357509367, 12.406999122711921, 9.493175245100453, 9.536794943194236, 18.278044962113906, 16.402157698908162, 15.849018193060353, 33.216164265909505, 54.804983831221065, 55.13880498947636, 51.297604345506244, 34.90090070232269, 21.866843046680575, 21.630686944530858, 30.072614031453288, 54.801030082087365, 65.54894016635033, 56.84088222442135, 63.806450751519975, 59.127455372964185, 58.07060018662484, 62.80228476370535, 65.16649338506883, 56.42582485752722, 46.51692544260333, 50.19636754066714, 55.01669376127182, 59.07348355939312, 58.00125660434846, 46.39446512345345, 29.044219563084265, 20.501824886568134, 8.474120920704257, 2.545518956838116, 1.1955727492609334, 0.8081332810463444, 3.0921713527171844, 2.8165326724129343, 2.6782046498790866, 3.0746949872662945, 6.626437950518824, 11.622901635785258, 20.129646870397753, 39.416486217129616, 48.76034075214017, 46.56356634632234, 50.291257519875806, 48.26326662494291, 49.106862545013435, 47.963993703165364, 50.000641269068566, 47.32781664017708, 43.52882854400143, 41.45363976878505, 43.71896151573428, 40.65701030915783, 47.35803850235478, 46.11214076319049, 43.58960566982147, 42.65676406122024, 44.27303944864581, 44.72914049702306, 44.208602751455004, 43.97877147120815, 40.19064834040981, 41.37259575628465, 40.07876273124449, 39.06376315701393, 38.469582911460634, 36.112787569722826, 38.74256418597314, 40.92717924425679, 41.47054518422773, 43.92704325337564, 38.94477805783672, 16.192157922252534, 2.8819587874797086, 2.779900921929267, 2.6267051552572562, 1.39700508886768, 0.573361407845251, 4.0605716984118185, 1.960174953264575, 1.6065963261550473, 0.5019381726461073, 0.7009391943293234, 0.26638979272496316, 0.4871678748919118, 1.114893272038429, 1.5004634857177737, 0.38924951947504477, 6.124021064850592, 28.384131731525546, 42.87882120378556, 39.76742852118708, 50.195037857178725, 53.04381216725996, 55.432645428565245, 62.4244350002658, 58.07532272031231, 57.472309297130955, 55.35189559382778, 52.35093724343085, 42.39932321733044, 41.971565215818345, 40.31657995716218, 37.37197037666075, 40.98892519550939, 35.74499084103492, 38.841745238150324, 37.512493210454146, 42.96067322454145, 43.631500505631976, 44.95753226741668, 47.60225311402352, 50.76297744627922, 56.33361777951641, 59.962080832450624, 64.7783983907392, 68.10816903268137, 72.8236581433204, 66.66694118130592, 33.127875635700846, 0.5676060037747507, 20.047887025340913, 65.25851611168154, 68.37006568908691, 44.5193721402076, 54.62281719330819, 30.440826531379457, 22.826658794956824, 58.43262318641909, 66.88387963079637, 67.34244392764184, 34.45900255633939, 46.45487354647729, 34.81280819062264, 40.58072413167646, 42.324100002165764, 1.7478210190611503, 0.42655607084593467, 0.08706452129709144, 0.19032061730902042, 0.02586696833942927, 0.1676313912556056, 0.03953382943666751, 0.13346995257081526, 0.19899644047742893, 0.20997046613164488, 0.17623019194410694, 0.24547971394513887, 0.472985718158945, 0.9732087425166561, 53.69637689282818, 110.39885044097902, 75.17524457746937, 74.49238346469018, 39.888288513306655, 94.95673010426184, 80.12916672614314, 66.08609307196834, 84.56714814709079, 87.67048035898517, 71.62382864182996, 64.23940197114023, 53.9166493569651, 57.79311210878434, 83.11354914019185, 78.77402705530967, 89.28282553149809, 5.885219324019648, 0.17730512055418185, 0.8597027654609374, 13.549601243388269, 19.80722215867812, 13.01993614242923, 6.404218519887617, 13.018250503847677, 17.757638615946618, 9.839445025690141, 22.036485556633245, 21.502280312199748, 25.176195790690763, 48.60643871368901, 60.19842324718353, 57.2079925383291, 53.05284146339663, 44.66688463764806, 32.10900664329529, 34.37857043358588, 39.994796552965724, 58.89479606382309, 61.156740650053955, 59.04846276006391, 61.868780274544996, 59.023783206939704, 57.11591882090415, 61.021818960866625, 63.697553988425966, 59.615657098831676, 56.008210105280725, 62.1425421007218, 61.65282241759762, 66.79652060231855, 65.36469467224615, 60.45708787056708, 40.6797129877152, 27.63774391143553, 11.00153838434527, 4.979931875582665, 3.307328801001272, 1.4180618428414868, 5.1722545104642075, 2.147478057492164, 2.949776077462781, 3.1159122336295346, 10.267180473573747, 14.225359924377935, 23.614439387475294, 44.38676857179211, 46.817143655592396, 48.03627906307098, 50.46721896817608, 49.4246215974131, 51.96370124816895, 49.84429951637022, 50.74469527890606, 55.076188272045506, 46.80770643295781, 45.95545384191698, 45.976760156693004, 43.72063636779786, 51.44827827330559, 49.492647263311575, 47.827679572566865, 46.914088956771366, 47.26982831954957, 48.454941088153475, 49.45112897503761, 48.93033627540835, 45.232878731143096, 45.54643300271804, 42.942802906036384, 43.26007558453468, 43.146938739284394, 40.54496780518563, 43.62614254797659, 44.99278653052546, 46.98633117060508, 49.56825094838297, 45.819888884021395, 22.332291103178456, 5.975208301698008, 4.795052918695635, 4.628113902384236, 2.6039103010008415, 6.059446594407482, 9.241072747015185, 10.34321169699392, 2.874156212614429, 0.31798075824495287, 1.153985451786749, 0.19816230862371384, 0.4450564200599348, 1.404746621847153, 2.0962533739305313, 2.185030584373782, 4.450605569347259, 25.078799416941983, 38.75129145960654, 40.46415129015523, 48.466923929029896, 47.932540216753566, 54.157184785412205, 61.46824352202877, 58.6729742634681, 60.166067615632095, 57.60928630828858, 55.85373147841423, 48.60701922447451, 49.68268217579011, 46.886495082609116, 48.57162375603953, 50.902939381137976, 45.53042188767464, 48.130184527366396, 46.27582519285141, 48.453246624239036, 50.57095781449349, 51.16150594526722, 52.82952916237616, 54.90706351495559, 60.6807610296434, 62.02367467264976, 70.56144683591782, 69.87689910396453, 79.00470164514358, 73.59780065474972, 44.70638682765346, 1.3663160969172756, 16.809009467401815, 73.86107014071557, 73.75634285711473, 52.05967772391535, 66.03957376172467, 37.15866796432003, 42.34786564303983, 73.35694359194848, 79.34490449966924, 78.18061951668032, 46.31941057020619, 48.98850894743397, 56.50923798161169, 59.254551933657744, 80.31835832903462, 3.6646233835527977, 0.5175637309589695, 0.2472103678531224, 0.45376362218972177, 0.22534945138519813, 0.29774178780855676, 0.1958742031767484, 0.20863931175441514], [0.023691066045073733, 0.07304078388598657, 0.10002485972138182, 0.02303606278503374, 0.10044089909042082, 0.07591241084399723, 0.5970660681205412, 76.14818849871236, 64.23331837500295, 61.47325238873882, 39.81297116125784, 35.17155993369318, 72.7204684288271, 58.95833846061461, 80.98021907191124, 89.59754082464403, 59.70259643370106, 64.17123117754537, 31.076995749627393, 35.58487184586064, 48.152118421369984, 58.80924917036488, 75.49207010576802, 19.773399560682236, 0.2572865231383232, 1.3466108446159673, 15.27238565106546, 14.982383251190187, 10.312378925661887, 3.762422045392375, 10.841622371827404, 13.544813010000414, 9.616229803331438, 13.363892705209794, 11.920687979267491, 17.320082533744074, 28.817249651878114, 39.5275834298903, 44.029056256817235, 34.597881917030584, 22.46610276160702, 15.659942300088945, 17.28145307110202, 25.29754019552662, 45.064424699352635, 55.77753551544682, 54.364007442228264, 52.728559509400405, 43.73201124129757, 44.08960588516728, 50.89789913546655, 54.953975062216486, 57.396340831633545, 51.2845467752026, 49.024018164603945, 52.7077748698573, 53.813012492272165, 49.814050197601325, 41.03517778458134, 29.337224537326446, 25.06147626907595, 32.06849248178544, 12.352684101750775, 2.8071957153658715, 1.383213790193681, 3.829352879716504, 2.830548771927434, 3.104612130311228, 3.9574099308060067, 5.513923350841769, 8.345076903220146, 13.477713023462604, 25.57024886531215, 43.805041851535925, 44.47848927590155, 47.649431382456136, 45.8138523563262, 44.78012346452282, 43.791866610127116, 47.91127704804944, 40.27754060683712, 39.82868025379796, 41.69856825182515, 39.14629374780963, 37.83011105752761, 43.9199359186234, 43.06190175394858, 39.57864876716368, 38.67962583418816, 42.47259701451948, 39.7602701956226, 37.42060776679747, 35.677196594976614, 38.056114104486284, 35.710089591241655, 37.039388687379905, 35.94943654152655, 35.05981552985407, 35.106891816662205, 35.776142304943455, 37.05676086487309, 38.89443835904522, 38.60492037188622, 26.557972277364424, 7.528687032961077, 2.4266412325443762, 3.6134788634315615, 3.0174742254518696, 1.8526913465992099, 1.2468284440617408, 4.665782384334072, 2.1481365253848415, 1.1682875166016242, 0.43900334486557596, 0.6176854778201349, 2.1960634762241, 2.693342056966597, 4.914721000579096, 3.39799365208995, 1.8968284298335354, 11.54147421160052, 40.088674560669936, 57.78799341570947, 50.131122835220836, 59.66916999509258, 61.54134473493023, 61.460590977822584, 56.95505065302695, 52.119839037618334, 45.32337565575877, 42.5561160425986, 34.445360552880075, 31.77092382984777, 31.24892500139052, 28.67886058745846, 27.349096690454793, 27.76424034949272, 25.69171682480843, 28.845735865254557, 31.157188607800393, 34.40238314290201, 38.80752255839687, 43.54900521616782, 46.152741216844134, 49.11056134008592, 52.284696255960775, 61.38693278835666, 59.990423879315784, 71.09781526750135, 65.63680910295056, 66.89371693518855, 17.966112590605213, 0.5473013029944512, 27.587827828622636, 60.09829690379482, 50.413651158732755, 41.77237549135762, 35.66254654238301, 26.28802299499512, 50.40749303756222, 41.7475978789791, 46.41250802624611, 78.94694082198605, 32.323028810562626, 36.902678397394, 45.03646604476437, 40.61391915044477, 19.584982625899777, 0.5021153534612348, 0.10214597332261263, 0.1612458185803506, 0.05172323443055634, 0.16628206527281195, 0.026787928598482284, 0.02192357096881155, 0.018393267359163974, 0.029828508587313757, 0.09698543652531602, 0.05868691237523191, 0.09459396283472739, 0.060550857921161, 0.16689242284384467, 2.2451543904119924, 95.21120563630136, 59.02574831439603, 39.40355808504167, 26.37672543525696, 51.808681334218676, 85.070890303581, 64.40354924048147, 97.65841161051105, 93.3821024433259, 65.05462738775438, 61.845744194522986, 39.45527453576365, 52.080364304204146, 55.92518529584331, 67.1992774163523, 81.90436870821061, 32.207866061118345, 0.28540014199191527, 1.6233839479184922, 17.0816534180795, 17.939416939212432, 12.453677288947567, 4.806667547072134, 13.577561859161625, 16.949865702659853, 8.051001121920924, 20.76921090002983, 30.524147479764878, 43.06620067165744, 43.69769050228981, 48.73752432484781, 47.68036711600519, 40.72589889649422, 32.06885333984129, 30.0652733156758, 30.68465086721605, 38.89749388540945, 51.932412501304384, 59.37853413243448, 61.83607555204823, 56.585928163220814, 48.574267433535674, 46.84200756011471, 53.901669825277025, 60.435914916376916, 62.10874303694695, 56.306812301758804, 58.16302691736529, 57.71497849495181, 62.38622719241727, 57.81540293847361, 55.55131281575849, 43.6617184454395, 37.38915820275584, 42.98813766048801, 23.792281612273186, 4.964854284640282, 3.53106128592645, 4.757151055720545, 2.426622356137922, 3.4868037123833937, 3.8085824587652763, 6.536496531578803, 7.8456915193988435, 11.888992286497547, 22.632672094529678, 41.7010118884425, 44.80314777743432, 47.94459758266326, 48.05957401952436, 47.49611377716065, 48.031364333245065, 49.8722856275497, 43.66831587206933, 43.73120715541225, 43.69542729470038, 41.67016244703724, 41.0253797038909, 46.369495314936486, 45.570543812167266, 43.03913239509829, 43.87909227801908, 45.03849391014346, 43.95093441009522, 40.14991060380013, 40.86121674506895, 42.96550950696392, 40.905115912037516, 38.957643432001916, 39.26681249372421, 37.88588323900777, 39.80147077191261, 40.11245981339486, 41.91528312621578, 43.432883447216405, 38.26392519858576, 20.04105229531565, 5.82697702992347, 2.9048786672853657, 3.084645059800917, 2.6209159820310535, 1.8413735926151278, 1.1119606874642836, 3.3162946037707792, 2.3034386048393864, 1.4364995567067977, 0.9179520462789844, 1.6095600445424358, 6.055983141545327, 9.34338188940479, 13.264042888918231, 12.417099225905634, 18.80880048198085, 35.05599906367641, 54.49847805884577, 63.02426738123741, 61.855459905439815, 63.9112368706734, 65.62061363650908, 63.66976399575511, 63.0229651543402, 57.21454289651687, 50.778109950404016, 47.997847680122625, 44.2383421621015, 42.97128323585757, 41.80087935539984, 41.113836996016964, 38.386452198028564, 39.176111605859575, 39.754331727181714, 40.98440270270071, 41.85468642942367, 45.63987562733312, 49.62381132187382, 55.590548284592174, 55.353876390764796, 58.727197108730195, 60.16118426476756, 66.71190723296135, 66.17749998646399, 73.25772331606957, 68.25072365422403, 68.90990149590277, 13.348962203148874, 1.6837350062785612, 34.941607059970984, 69.45641317675191, 54.89727720137566, 46.43174332957114, 46.573183997984856, 20.58000360765765, 32.39026608005647, 50.618924479330744, 47.05460002345424, 80.64129491006175, 29.080056298163633, 45.89984639998406, 43.304908275604255, 54.285654175666075, 29.28907940464635, 0.6681500182997796, 0.25107286059327666, 0.17453952782577084, 0.13064630569950228, 0.12654948964594834, 0.02986109222195322, 0.09095381179283704, 0.07470720898239844, 0.1404997592251147, 0.23112791470221936, 0.14660082216705048, 0.21770127388017796, 0.16322335198281274, 0.19086335995985618, 1.676815454998324, 109.17340786226335, 82.99619182463616, 83.60833260320848, 51.21526987321916, 44.42816526659074, 91.22030381233462, 67.33896086292883, 93.63879019214262, 94.15366403518185, 71.20724155056861, 76.66076383283063, 44.28805820403561, 48.964492274868874, 72.9824435326361, 73.92651880941084, 97.27682775066745, 31.367931673603675, 0.5077807575223908, 2.4038696673608597, 19.49048488370834, 26.240685870570523, 15.70988387830796, 5.153467828227628, 15.235544789221981, 27.231445197136175, 15.132280549695416, 31.091394770529966, 37.476572144416075, 47.88441273473924, 50.47025096031928, 54.1086454545298, 53.85857474419379, 47.4209572422889, 39.97879720503285, 40.07994728703653, 39.85981210585564, 46.1603819939398, 59.245903107427786, 56.55958944751371, 57.09796613262546, 53.87128322355209, 50.60323499864148, 49.36322081473566, 53.51441029579409, 58.66566688783708, 65.48108316236927, 60.02725101286366, 61.42592114786948, 62.51470050504131, 65.65802912558279, 63.911758545906316, 64.96185548843877, 55.41423382297639, 49.11649980852681, 44.939607035729196, 24.383826025070686, 5.478972090828804, 4.929250440289898, 8.463026496671862, 4.087388698131808, 3.8016180453761934, 4.811636699784187, 7.46996719029642, 12.118459766910924, 17.25346499873746, 28.257329348594915, 45.66708118684831, 45.05872157312209, 50.36051088763822, 48.15385603135633, 47.76079923875871, 50.060433879975356, 53.7567029460784, 46.41661867018669, 44.686665150427054, 46.86380417116227, 43.972075985324004, 43.262801631804436, 51.28397018678727, 51.10648293648997, 50.41080744035783, 46.22869791523103, 50.56639217561292, 46.43020968283377, 44.43118941399359, 46.411645104808194, 49.5884080086985, 47.25768466149607, 46.172584487545876, 44.825791620439105, 43.0492756443639, 44.81716240606001, 46.60822645310433, 47.071458370454856, 45.188183323029556, 43.7328153271829, 28.27478389586172, 8.86058715081984, 3.937369070706829, 6.015344444782504, 5.016274106117987, 4.1729860921059885, 4.199692039720474, 9.359253760307066, 5.3853965959241314, 3.497776052644176, 0.7828946063114751, 0.698044669003256, 4.447695170679401, 4.863213416068785, 8.335778924726672, 10.15176865362352, 16.368642026378264, 36.26513634958575, 59.33129702844928, 65.80768323713734, 59.2375563037011, 66.29081726074219, 64.67648344655191, 68.81358377395138, 65.23975933751753, 63.54377746582032, 55.448315297403646, 56.2126636505127, 52.687986512337964, 49.584622921482215, 49.59325998060165, 51.11764992437055, 46.676565908616595, 49.65302121254706, 45.93990556655392, 48.021491727521344, 46.35773997153006, 50.60785947307464, 54.733890871847834, 60.86864256089734, 58.117029282354544, 62.472633084943226, 61.745425654995834, 73.71542469147714, 66.82869188247189, 81.97361423123269, 73.93880367279053, 81.52789961907172, 22.03708567926961, 1.469365954399109, 35.36910226268154, 76.30004698230375, 61.93568022020402, 58.50173142648513, 46.74658806093278, 35.67194846368606, 66.00337028503418, 63.08022783648584, 54.47959969120642, 97.47016137646091, 43.45606073256462, 58.93398838658487, 70.50903612567534, 75.74426281836726, 57.71349583902667, 0.8701658717566921, 0.2757468212756419, 0.3330491867757613, 0.19262237444279656, 0.21955208101820564, 0.1320185989982659, 0.1589365537849165, 0.18258627023427718], [0.05512486399722196, 0.02870339930297867, 0.029169171184842146, 0.07443049036326908, 0.0707886845714623, 0.3153943228385141, 0.722370166932383, 10.891916963361925, 91.54190678750315, 62.673007365195986, 68.00089220846853, 33.76659831693096, 52.570570361229684, 42.1172655782392, 43.774004136362386, 74.414963722229, 66.401781112917, 73.63936993383592, 45.096568522914765, 27.087403997298214, 42.51544106391169, 49.456420252400065, 74.90792720548569, 50.33813376580515, 1.1914858846895158, 2.346301530638049, 9.52913651543279, 12.458074265910733, 17.41549614937075, 13.86791923353749, 20.47223060361801, 14.69008626476411, 9.783188431493699, 15.512273888434134, 38.17255358542166, 45.949393780000754, 44.376491961940644, 38.67675073685185, 35.13895327045072, 27.625462970426007, 25.535120118048887, 23.468829239568404, 24.025240982732466, 26.446227873525313, 34.501230793614546, 41.85659270132742, 45.77736646898332, 40.294826492186516, 38.03121489863242, 42.71205771353937, 45.60341719658145, 51.168115139007575, 58.34238513823479, 53.38620762671194, 56.76787122603386, 55.9262639476407, 57.635295544901204, 56.45234792463241, 52.52452565777687, 46.148799234820956, 43.62368714424872, 48.342537726125414, 50.70952730794107, 13.849640988534498, 4.436705670049114, 4.3776941011028905, 6.177256453421808, 3.4368876295704998, 3.7958126923730298, 5.7985285693599335, 4.701451928384842, 5.345853711328199, 14.867358765294476, 31.630956011433756, 47.0103713773912, 45.27274177920434, 47.35035065681704, 43.94203062980406, 46.32934201148249, 45.61303484824396, 40.88339382602323, 42.077516278912945, 38.36172949883246, 36.74283396813178, 39.08017043144473, 40.12245793496409, 39.682983813747285, 35.80705842664165, 39.784796776310095, 41.121481695482814, 41.49873525865617, 39.590133467028224, 37.32570209810811, 40.26237280138078, 36.580365473224276, 34.54665576258014, 36.49137866112494, 36.61517650850358, 34.15735267823742, 35.24741072808543, 35.205315851396136, 40.45207823476484, 29.83369265833209, 9.769329717082362, 2.5601486621364473, 4.320873175897907, 3.3587331781464242, 3.077869410476377, 2.6170252359682515, 0.9978666613178869, 3.2909156430152158, 2.1271748888877133, 1.6401705890893938, 2.076223545497464, 9.029716810872479, 15.848620072487863, 34.01875965056881, 31.397218050495272, 26.253180580754435, 31.472668763129946, 43.52041505998181, 50.61969718625469, 55.677173829847774, 55.431041179164765, 55.457815277961, 58.48160574513098, 55.639703427591634, 55.63250980069561, 50.80742574507191, 44.87320523108206, 40.60577238759687, 36.603738877081106, 32.579761666636315, 30.84844316205671, 32.82247989408432, 31.49313569068909, 31.681958590784383, 33.09777536699849, 34.90389347076416, 38.63897831209245, 42.53808490691647, 47.04972059495988, 50.16283127569383, 54.473453337146395, 62.87673919431625, 62.65110485015377, 64.14562202269032, 67.17861437028455, 68.08898079779841, 75.88516219969719, 45.84432525019492, 2.338746310241761, 4.501601774846354, 32.23700534912848, 62.077171879429976, 39.673228879128736, 44.15536442110616, 40.23780699699156, 52.32606941653837, 38.60720711369669, 32.99853155689855, 34.280130709371264, 59.76765286537909, 43.449102447878936, 28.357018347709413, 30.855250435490763, 56.56669678226594, 9.03135440041942, 0.7544079639257923, 0.2724299669986771, 0.23310124994285647, 0.11799477731748936, 0.12353131006802283, 0.13756642388480325, 0.12360067166868718, 0.15956902065344397, 0.05145312715021353, 0.0529289112666682, 0.048228720533511335, 0.04048666278381021, 0.10476410944735813, 0.25919956725931936, 0.4068858134410074, 16.625201317571825, 105.38491602866881, 54.82505067702263, 42.85572628821097, 25.14187897405317, 68.09510754000756, 50.63834805642405, 52.265527632928666, 75.33586563602572, 65.62281408617574, 80.38947090025871, 39.66942810243176, 40.40813199935421, 52.0649415446866, 58.65460580395114, 82.59301923936414, 66.77865812855383, 4.429816517137713, 2.7196457164902843, 11.857675102449234, 18.92842688868123, 20.625154010711178, 17.725094710626912, 26.681764241187807, 15.523609538232128, 14.792062005689068, 42.83931901378017, 56.81857570525139, 57.25646911128875, 55.15474157948648, 51.55742214572046, 46.937552575142156, 39.5845833132344, 37.57742020391649, 34.23978128740865, 35.1849744396825, 37.704399093504875, 43.956547321811804, 48.597797732199396, 47.328828611681544, 45.192909779087195, 44.464043186556914, 47.25850443686209, 51.58889524398312, 55.70428133010865, 62.10258883814659, 58.646149173859634, 61.36735231645646, 60.42441060466152, 62.86998487287953, 61.28294291034822, 60.53782593819403, 59.01061581027124, 55.39168019448557, 56.551611346583215, 57.12492458281979, 29.55173307849515, 5.675019996781503, 5.191581989488294, 5.45819333484096, 4.948564191018382, 5.519374464788745, 7.905825866806892, 5.5840916114468735, 4.176414733932865, 13.872192655840228, 29.700406597506618, 45.857061186144435, 45.62495100882746, 51.289335989183, 48.246141556770574, 49.24195681848834, 47.814465107456336, 44.98807968631868, 44.269591685264345, 39.06798754968951, 39.237775187338556, 40.70292557439497, 40.38027140402025, 41.641529144779334, 38.74002641247165, 39.675743118409194, 44.50527121943813, 44.48564367909586, 41.96872149744342, 40.636060930067494, 40.613840703041326, 40.047101359213556, 40.73346514855662, 40.36254229084138, 38.88347141204342, 37.454073429107666, 38.25504495251564, 37.57658866143996, 41.99871978452129, 28.29702373473875, 7.598645446761963, 3.2558099396767157, 4.6334012573765175, 2.5882159173488617, 2.080583259943993, 3.026294900525001, 1.7380731937385376, 1.2911290411026248, 2.133274909950072, 3.555547907467812, 5.920771196965249, 13.303651963510822, 29.54628686751089, 48.00611995881604, 48.33821527419552, 47.908919703575876, 48.96426085502871, 52.47591180186118, 53.34661914456276, 58.59433074151316, 58.245957589918575, 58.98580681893134, 60.68653083616688, 62.145130865035526, 59.308319783979854, 56.327294918798636, 51.508851435876664, 49.42011479408511, 43.96237204151769, 43.13869391718219, 43.023921443570046, 45.505632508185606, 43.717988767931544, 44.59389325111143, 42.55950497042748, 46.50052601291288, 49.791072953131895, 53.89875942660917, 54.935398717080396, 58.48030351823377, 62.027667645485174, 69.69628964701008, 67.33747036226335, 70.59321803431358, 69.50494074052381, 72.96568716725996, 75.0769264467301, 29.76778703351175, 0.7031845061048385, 7.767769223259342, 39.216755205585116, 64.84784395464006, 44.60473075989754, 52.217619803644, 52.34380637445758, 43.870223799059474, 41.455651944683446, 41.81602362663516, 31.689873933792118, 64.74732929660429, 33.9841761127595, 33.59890522495393, 33.490326173843876, 71.62557017418646, 7.052752519807509, 0.5348279819853845, 0.0703095042357041, 0.22359059011984259, 0.09436058180947458, 0.1054240329070918, 0.0755993260311023, 0.1438136870462087, 0.11347327276223129, 0.24924123629687295, 0.19266499957490354, 0.11579530824336315, 0.2797435326201301, 0.21754719827684665, 0.4770787114337568, 0.5920367928281908, 17.164454652417092, 121.0554438252603, 89.47883421374907, 90.57677622764342, 49.184184228220296, 65.21130254191738, 54.27992359284432, 51.098143977503625, 87.04308940518288, 73.26044544096916, 96.25436782836915, 57.594432292446015, 40.84991247423234, 61.68480934635286, 67.69903444474744, 88.79915806554979, 71.42447025545182, 2.81746766740276, 2.587257633286138, 15.038980110999077, 23.455308829584432, 26.069343013148156, 23.995687884669152, 30.860686840549594, 22.324481664165376, 26.40700613298724, 49.69552793810445, 60.163004244527514, 65.89058645309942, 60.51444468959686, 56.572239091319425, 52.06086227970739, 44.50924065805251, 45.90664386749268, 41.04791372053085, 45.88294490691155, 49.57247141868838, 50.82536666624008, 54.24557931961552, 52.401308321183734, 49.941593908494525, 46.68805845322148, 49.47231761870846, 53.737577469118186, 58.91235651508455, 62.76404949926562, 57.24794972327448, 64.68474003576463, 63.35003983589911, 67.47108982455346, 65.9827543074085, 62.78666588567919, 60.01027499475787, 60.261267462084376, 59.14507465977823, 59.52037488260577, 29.315871154108358, 6.458643367213588, 7.414101362228394, 8.79864017809591, 6.908270543621433, 5.099585738874251, 9.718123174482777, 7.02080040208755, 9.28121820572884, 17.77279857666262, 31.738670179920813, 47.32893059330602, 45.75174554701775, 51.30524512260191, 50.12772998502178, 52.23576468806113, 52.14647193108836, 45.98962945322837, 48.04941508077806, 42.82162127956268, 43.22937127082579, 45.07732145247921, 44.89774750125024, 46.58800271249587, 42.68899809929633, 47.07805579708469, 49.335885817004794, 50.57499001103063, 46.75354634561847, 46.17325521284535, 46.566621872686575, 45.9034392910619, 45.134843011056226, 45.01685419390279, 45.67176841920423, 43.65718810789047, 44.651544247904134, 39.464017498877745, 45.955920603967485, 35.72876399563205, 13.229905520716022, 4.593685298196731, 6.969808118958627, 6.386702195290597, 6.385272001066516, 8.571269204539638, 3.7117651249131853, 5.450840851952953, 3.622671428226656, 4.455567367615239, 3.983714080625965, 11.30860113328503, 24.21921003249384, 39.04344527952133, 46.97746661401565, 49.17105605525356, 51.42513628928892, 55.82898916736726, 55.90360049278506, 61.52174465117916, 61.13225721543836, 61.658250977916104, 64.10555893375029, 61.869780478938935, 60.241839962620894, 59.78362867909094, 54.85626489885392, 54.83984977968278, 49.203097897191206, 47.98554320489207, 50.67794438331358, 50.62269779943651, 51.81217616604221, 48.769523020713564, 49.1423874516641, 50.28242826461793, 54.379057576579434, 56.91468554158365, 59.50786644412626, 63.79050239439934, 66.57318084470688, 75.62408924102783, 70.34235892757293, 72.65103463203677, 73.45982736156833, 73.52043582547095, 79.98859682390767, 57.514255123753706, 2.352708722314527, 6.449796461289929, 45.89847357042375, 72.99839188975673, 53.4091103461481, 59.60047752626481, 52.56292173939367, 62.75923282869401, 50.022088789170795, 53.298774073200846, 43.506031728559925, 75.90027116960096, 53.59183003825527, 46.246164229608354, 47.62612465889224, 97.45876296874016, 18.92830921757606, 0.8567916313486715, 0.412629297183406, 0.2945546781824481, 0.15464505180716515, 0.22534713779966678, 0.18660794072333844, 0.42281866494205694, 0.2712236543095881], [0.06045384437686974, 0.12455717840742682, 0.051349996393846895, 0.12490233166083214, 0.0865056524954496, 0.0787276613916601, 0.17874683674064376, 0.8520629689578088, 28.902604349197883, 77.77977681929066, 49.375678262402936, 73.70713280093285, 32.39406293438327, 64.69078440820017, 111.47777680427798, 115.15990180353965, 111.54698310359832, 85.10393234991258, 60.1596623851407, 21.648425863635158, 37.29278948999221, 45.48846037157121, 65.70088886445569, 65.96216970874418, 19.21508742916969, 0.9359703729710273, 10.389683938795521, 13.24172362204521, 20.291805498061642, 21.925868834218672, 22.724408488119803, 16.820821685175744, 11.134339051861918, 43.163922602130526, 59.160811208909564, 52.50534134526407, 53.58583665663197, 48.09130991658857, 46.298700455696356, 39.134071642352694, 31.737685665007564, 25.384659959423928, 25.463809467131092, 25.768983594832886, 32.165318150674146, 34.094947768795876, 38.479424138222974, 36.078913980914706, 39.93445088786464, 39.85405798881285, 45.295028686523445, 46.45617185100433, 49.915835703572924, 54.84353680764475, 57.47201511936804, 61.13719155711513, 57.451269703526656, 58.773849779559725, 55.245968064954205, 57.5294582305416, 52.56209019691714, 54.48150204073999, 51.71015531786027, 51.753254321313676, 19.02846301755598, 6.498124964775578, 2.2456461575723465, 8.461742901032972, 7.994586652325046, 8.701773324320394, 5.0821007932386095, 3.2583795824358543, 6.513241289123413, 21.99045262029094, 38.33495540003623, 42.61272368892547, 45.87549240358415, 47.65360870668965, 42.71639977732013, 42.61116650796706, 42.48059472730083, 38.760395280776486, 37.48456593482725, 36.6808722865197, 35.36072407999347, 33.64671107261412, 36.061981108880815, 33.114916124651515, 33.06719656913511, 38.44668411439465, 38.977894629201586, 40.69643012938961, 38.722152171596406, 35.92022272848314, 37.58979135943998, 36.4772581285046, 36.18631239860289, 35.1437738633925, 37.848146115579915, 37.87585766084733, 40.846586304326216, 37.8845182541878, 15.334281632977149, 4.106336687841724, 2.084336232754492, 2.3480119291813146, 1.5979825561085057, 1.1460421618915375, 1.4413518963321563, 0.31790911370227415, 1.522341731094545, 8.718825828644539, 13.257122847341723, 18.49933332012546, 31.055469782121722, 55.93333598106138, 63.38454884867515, 54.60970863219231, 55.03066916619578, 55.833903897193174, 54.173992141600586, 56.292723148099846, 57.76357273901663, 56.24647055902789, 56.83339049739223, 55.11456474181145, 55.939945174801736, 54.60528812100811, 52.69458786133797, 44.413303406007834, 39.852845976429606, 35.874448668572214, 34.089472140035326, 35.798378221450314, 36.62281336322908, 35.9886759327304, 37.59278020551128, 36.45266486752418, 43.75541602411578, 49.49598912269839, 52.88821566489435, 54.12112251404793, 57.508124459174375, 59.96421067945419, 64.28723527539161, 66.4950942993164, 70.59073909636467, 74.99524701026179, 82.80671781109226, 48.36823709549443, 2.6207340821143124, 0.15666724813561286, 9.294876879261388, 34.42495638324369, 54.17580035425002, 43.52599267036685, 42.40843488324074, 45.81353856671242, 19.686787743722242, 13.772228110221125, 35.281676553910785, 37.173494523571385, 44.52898586949995, 40.307538893914995, 53.49163701457363, 44.58316556869015, 63.082361605859575, 0.29173234898236494, 0.19904260493574605, 0.07330064090990251, 0.18648502957676688, 0.225148368626833, 0.1722392722243263, 0.07317029871046543, 0.026604308814351118, 0.08468760327706415, 0.09318223899050106, 0.10660076694142435, 0.0830985147566084, 0.05370341083635727, 0.11912232084620385, 0.09906448423862459, 0.42900920695354866, 0.6297102390277771, 39.139613951406176, 88.10722058819186, 54.76106897477181, 64.34583940813619, 39.03447089656707, 57.18386996176935, 93.39120234212568, 115.28152665784283, 103.7141118511077, 99.0129158573766, 55.68372811040571, 27.279366754716445, 48.89119494345881, 49.89405870437623, 71.73171735578968, 74.90537766487368, 30.93021281303898, 1.9489758509782054, 16.57676200712881, 26.021443028603834, 29.887097689413256, 28.208672346607333, 24.92313623428345, 21.55652669168288, 37.08236609735797, 56.741673715652965, 67.669114605073, 61.115630288277906, 61.766590764445645, 54.4184930862919, 56.351272367662006, 50.61961481648107, 42.951824357432706, 38.69634297586257, 37.594549194459, 37.34741633938205, 40.18150529553814, 42.47115750466624, 46.08933218063847, 41.425418315395234, 45.32991424683602, 45.029998056350216, 49.73801112944081, 50.10756115759573, 53.82107688534645, 56.306647562211566, 59.65279017725299, 61.357758199014974, 62.938112520402484, 63.27243574203984, 59.75691733821746, 61.941661834716804, 60.090350181825706, 62.175552768092004, 55.92627963712139, 58.838831686204486, 33.25932994965584, 14.764449500268507, 8.593791454069077, 7.6106871231909725, 11.00492633158161, 10.897176861763002, 7.7142298509997715, 4.651521626980075, 4.745929154657549, 20.86321638476464, 36.051904539908136, 41.259258870155584, 45.57532910377749, 49.3128615040933, 47.62071963279478, 47.52331149193549, 45.3688516155366, 42.767586708068855, 41.40566918157762, 40.77134347731068, 40.34252643585205, 38.14817213243054, 40.02856031540902, 38.5074024046621, 39.126779956202355, 42.18679743428385, 43.42381492737801, 44.11113969741329, 42.782189692220385, 40.889163632546705, 40.762494610201934, 37.10596699868479, 39.0238687299913, 37.85466901717648, 38.60289642887731, 41.27518369305519, 40.55132988960513, 35.36689396827452, 12.065294000410265, 3.733017752247472, 3.4274227051965656, 2.673472800562459, 1.8277211703600424, 2.7075000972517076, 2.425541498007313, 1.9192875537180134, 10.589999383495702, 22.871054141752182, 24.662579067291755, 27.995487605371785, 45.740786444756296, 62.19832997168265, 60.78353497289843, 57.225517688259, 56.54870094791536, 55.16005639106997, 55.95799592233474, 61.20837865337249, 59.933553434187374, 59.93397705016598, 59.60024610642464, 58.266408827997026, 58.45539646763956, 57.86661732581354, 55.98836291220881, 51.50447014839419, 46.19871139526368, 44.64657068252564, 42.454063815455285, 43.0787601009492, 42.533829135279504, 44.03544972019811, 43.828007328894834, 46.50514656497587, 53.72153889748358, 59.40412367543867, 59.61463728258687, 64.48365580651068, 64.93450087885704, 65.82109774312666, 66.23331531401604, 70.02336040619882, 72.10264805824526, 78.43230232115715, 75.3885587569206, 22.401585655827677, 0.4811255555720099, 0.33787918727724786, 10.82375499509996, 43.61746234278525, 59.73154744794292, 49.5347382176307, 53.316922879988155, 45.475775426433934, 20.27679458741219, 23.14747533490581, 47.24225013486801, 47.228062921954745, 50.47193757949337, 38.01099115802396, 48.08634811832059, 54.22103704944734, 59.13294669120543, 0.5533464108743976, 0.0954777678294528, 0.07692533995836012, 0.16758367929968143, 0.16473490474445207, 0.21228092602424084, 0.12061377146071005, 0.06780366893977889, 0.06177082612750031, 0.24215251748119634, 0.22220561040505288, 0.14437558189515146, 0.18461756768726534, 0.2268435833074393, 0.38861541317835935, 0.4948951279924762, 0.9045341695027967, 42.62053705030873, 99.53132767831126, 66.34810739947905, 94.20105411160378, 42.31114049111643, 80.25076020148494, 111.8702805426813, 122.4616841346987, 108.28990182568951, 100.48224356866653, 79.21881598810997, 32.733655860347135, 52.51693194912326, 63.49309652082382, 77.98339489967593, 86.2328375539472, 27.975916939397013, 2.0588883853727773, 22.31916096902663, 28.37041912540313, 35.16649615380072, 34.45829652970837, 33.23977301197667, 25.691648183330415, 42.08476481899139, 60.06493714547927, 72.79740964212726, 64.30507813730549, 66.40330299254387, 58.83726666050573, 59.10942423728205, 55.55461152907341, 47.92226752927227, 46.069857612732925, 44.505757593339496, 44.16824156238187, 49.150938218639745, 47.39036275494484, 52.71429384908369, 44.79373408902077, 48.31073907113845, 50.57020864179058, 52.95752394583918, 54.175294368497795, 54.8024852814213, 58.983155296694854, 58.94406103318738, 62.30668544769288, 60.22952764264999, 63.00098811426471, 61.918323732191524, 62.58131019530758, 59.47234545984576, 65.31815967252179, 57.168462891732496, 61.49311527129143, 30.586232716037383, 13.276956312118038, 10.997441468700286, 11.076467421747024, 10.370424120656907, 10.781301221539898, 8.275405803034383, 6.201357456945605, 12.076696330501187, 24.231634140014652, 40.33197133771835, 41.563779923223684, 47.78136814794233, 50.4659128189087, 49.82023577536307, 51.78931267030778, 48.05671068929857, 43.252940793191236, 43.10720905180901, 41.44761893057054, 42.032479624594416, 39.11347135420769, 44.03826205961166, 41.20028211224464, 42.5899229511138, 46.60879519677932, 46.94835478259672, 48.680257720331994, 47.14502634540681, 44.834385533486646, 47.13416922476984, 46.26898457927089, 44.06967632232174, 42.80246834601126, 41.70429491227673, 45.000709718273534, 44.7164124058139, 42.7130030047509, 19.408036662686257, 6.750080373979385, 4.806009079179456, 4.527277609994335, 6.175059926125312, 3.233951306150806, 1.8187134472593185, 0.7550729282440678, 5.794515494377383, 15.669866877217448, 18.4801862701293, 23.317123728413737, 39.071156824788744, 61.452601109781575, 66.68743948782644, 62.9298637759301, 61.50787122787968, 58.024798670122706, 57.312245215139086, 63.42737328621649, 63.17278792781215, 61.92092426361577, 61.33689118969826, 61.54684389791181, 61.484403687138716, 61.426411444141024, 59.5741113539665, 56.22798050603559, 51.600556450505415, 52.43781382037748, 49.24966035350677, 50.04119073190997, 50.603839043648016, 51.177156202254764, 49.90421764312252, 50.435381089487386, 58.202066267690356, 63.03859972184705, 63.176012116093794, 64.86538871642082, 67.07499319507231, 70.07472776597547, 70.1830950090962, 72.75568346823417, 75.32540075240597, 81.63916941611998, 90.44802050436698, 57.5939106172131, 3.8356473032505285, 0.4727543289622953, 12.079792061159688, 49.837125501325055, 66.21268364690965, 58.25498296368507, 53.48829907755698, 58.02282571792603, 26.835070079372777, 18.599420439812448, 51.9840544269931, 46.066080370256984, 59.748209676434925, 55.1121211051941, 84.14577576421922, 59.924265261619325, 94.33537960052492, 0.6404710777344242, 0.24650303887263422, 0.14910971415379357, 0.23491982010103044, 0.20189828960405243, 0.3245372757796319, 0.18887588273613684, 0.25881538948705124, 0.2103132751560019], [0.0288171595292947, 0.09824650151835335, 0.140144907298588, 0.11893669774215068, 0.07986840461530993, 0.08357095351863293, 0.1631392968157607, 0.10299885900871408, 0.13803828808088459, 47.403741959602606, 78.74565262948313, 61.78200175685268, 39.89088119999055, 104.81661165914228, 118.04576996834048, 84.56250406080677, 82.59497257970995, 88.61488511485439, 61.35119215134652, 30.987842236795736, 33.94981615005001, 46.23415393214072, 54.52001971583213, 68.28970416899651, 46.82090913095782, 4.599701233448521, 11.611806231160319, 29.413551899694628, 21.628498261974705, 23.709333289054133, 18.97828217475645, 27.337192296981815, 43.98185053179341, 61.31305494616109, 61.077320498804895, 61.080399559390166, 55.03331676606209, 51.8319566788212, 47.166787655122825, 44.75117637265114, 38.51245049507388, 34.57526945298718, 32.04029848498683, 29.610413697458085, 30.55781710532404, 33.215862243406235, 34.37477750162925, 33.86044886804397, 35.715867242505475, 41.03937079829555, 44.04135288730745, 47.63459305609427, 50.91635388712729, 52.536120184006236, 55.16143314300045, 55.321610973727324, 59.96685043458016, 59.587827882459095, 58.23022104078724, 55.340916879715465, 55.76510160200058, 58.475071076423895, 54.37211890374461, 57.32522041566911, 52.34380637445758, 37.199162513979026, 20.94609018295042, 6.88339977495132, 16.805946096297234, 13.862040581241732, 10.523952553349158, 4.082914254357738, 3.7370967720785453, 11.350109615633565, 28.34091897933714, 37.4790903060667, 46.97657231361636, 49.79284586444978, 51.28948503924955, 45.299292302900746, 42.621827510095414, 41.935318593055975, 42.157261986886304, 39.22533735152214, 39.480616969446984, 36.83756705253355, 39.10320258909656, 41.19141363328503, 39.251166159106845, 41.455228328704834, 42.042979809545706, 44.449283307598485, 41.593570324682425, 40.79221833136774, 37.909401770560976, 35.345520973205566, 35.917751635274584, 40.00760701394851, 41.3875086076798, 41.14633775526478, 38.91796473533877, 18.84062267118885, 5.578772387196941, 0.6792203565278362, 2.5738696032954804, 1.9365219579588984, 2.280449348111307, 4.139215465514891, 6.599935966153299, 18.248576195009296, 38.24607841430172, 46.900952939064275, 44.598662853240974, 49.11481318935272, 66.6646348276446, 59.64212525275446, 56.26697671028876, 54.75404793216337, 54.05932949435327, 52.91282069298529, 58.44184860106438, 56.59305118745374, 52.942465966747655, 56.992764242233775, 53.43864187117546, 51.557626108969416, 50.51119266017791, 54.485612684680575, 48.307130490579915, 45.592869943188084, 39.711115052623136, 41.11264067311441, 38.1000485727864, 37.61259601962182, 37.21383217842349, 38.68099866374847, 38.49698066711426, 48.463076083890854, 49.99420858198597, 55.42640885999126, 58.076483741883315, 62.1571058611716, 64.52444061156243, 64.35423328030494, 65.2356839949085, 73.31028307637861, 65.45338730658254, 73.23090999357163, 22.52473827331297, 0.14894246183816465, 0.15537174749037913, 0.6040607573043916, 7.782028509724525, 38.923969884072584, 45.904412038864635, 45.815770395340465, 39.4055506490892, 46.742940256672526, 15.98697187439088, 33.042054176330566, 35.11173986619519, 56.62483807533019, 58.91936971295265, 52.833051450790904, 42.274768352508545, 77.33401513868763, 21.184476152543102, 1.3302894946067565, 0.14963232401397922, 0.42080324083085985, 0.09729025524950798, 0.4632916415650999, 0.24815225763426674, 0.20758621665018223, 0.10909381622989332, 0.022954081801036676, 0.06453459556665152, 0.038072654616928873, 0.10263244681540998, 0.11622626334428789, 0.11165633437133606, 0.094114997003588, 0.08263359131712107, 0.1265088027162898, 0.04536347508790993, 52.10245117064446, 89.14057685482888, 58.475996755784564, 39.290872312361195, 107.21991846638342, 112.07177269843318, 93.81743061927058, 89.24228391339703, 96.52918477212229, 64.71387932377478, 29.62723674312715, 48.16950628834386, 52.68845719675864, 63.94864843737695, 74.77583746756278, 57.48802231204126, 10.24729601798519, 11.068477553706016, 35.58509542096046, 38.25464879312823, 43.65909045742404, 37.0863002346408, 50.79302672416934, 58.42887732290453, 70.88086897327055, 66.64401100527856, 65.47874935211675, 60.9280703913781, 61.61571287339734, 55.08875554607761, 54.93584978965021, 47.787134032095636, 44.49509266884097, 40.81459153083063, 39.178821963648645, 41.638497152636134, 40.09843734002883, 40.69919147799092, 41.11238571905321, 42.02781592645953, 46.86859338514267, 48.36169458204701, 52.669767102887555, 54.240421402838926, 56.46927295192596, 59.26917845203031, 60.41627560892413, 61.54162714558264, 62.774502615774836, 61.087675556059814, 60.19337515677176, 62.04167442937052, 63.374899818051254, 62.748685575300655, 61.233940739785474, 57.08396719348047, 46.143343217911266, 35.47136237544399, 19.202826100011027, 19.96167136776832, 18.163205808208836, 11.81486145142586, 7.339127707865931, 6.262104184396806, 12.157129433847244, 27.569979083153513, 36.62857532501221, 46.85595943081764, 50.17994457675565, 54.27163954704039, 50.539798505844615, 47.14864669307586, 46.549030042463734, 46.193459341602946, 44.211364100056315, 39.33290050875756, 37.5364157461351, 44.86701573095014, 44.91761430617302, 41.73485409828925, 44.791043343082556, 47.829730972166985, 47.16520693994338, 42.98044981495027, 40.70499266347578, 42.5046153222361, 41.872792090139086, 43.07184888470558, 42.19130815998201, 40.99556576821112, 39.4770162336288, 38.56873258467644, 17.524904781772246, 4.721523677149127, 2.8175260126590733, 3.7244032467565233, 2.5031480433479434, 2.9772878269995413, 5.980284338997257, 8.942561745643616, 28.76502133184864, 46.31331520695841, 52.9601558562248, 49.88230728333997, 56.31570039256927, 65.9882770046111, 60.71408940899757, 59.04268903117026, 60.141764610044426, 57.17121247322329, 58.56967472260999, 60.10588669007825, 57.74844415726201, 56.432394827565844, 59.422417609922356, 56.14121375545379, 56.36736977484919, 54.94355724703882, 57.63107899696597, 54.80461905079504, 50.73481875081217, 49.2595878724129, 48.3603492090779, 44.66465673139019, 44.15208924201227, 45.84471748721215, 46.119334390086514, 46.06615881766043, 55.086853196544034, 57.32968799529537, 60.72733917543965, 63.257322849765906, 66.49659264472224, 66.80205898900186, 68.03727611418694, 67.76356527882238, 72.56336181394516, 67.16170111010152, 64.36221530360561, 15.466688102291478, 1.753688884838935, 0.1856039671768104, 0.897566446613881, 9.121567933790146, 50.37884404582363, 51.74655099068919, 53.364634590764204, 48.21642960271528, 44.19796528354768, 24.370721386324977, 42.848175725629254, 42.5384771439337, 57.21761411236179, 72.67349412364345, 50.114692026569, 43.922889463363155, 74.05061475692257, 7.042124857825618, 0.7735699679582351, 0.12085130468251244, 0.4889224307431329, 0.0465391940557428, 0.4430718539703277, 0.1423375888337051, 0.18569154634831414, 0.02290440866002633, 0.04783049270871186, 0.161391758329926, 0.26140737137006176, 0.4012279476850264, 0.14622019904275096, 0.17541772505689054, 0.12704956119940167, 0.33030536626615836, 0.2061553482687281, 0.24458452488385865, 61.88819208452779, 102.40032965137114, 77.68427495033511, 56.54072676935504, 115.54554139414142, 125.9693499534361, 90.67916577862155, 94.67577072881883, 95.14335647706064, 80.44047740197952, 42.0054623388475, 48.45313679787421, 63.07742334181263, 69.66918606911936, 80.90444672492244, 61.65736844462734, 7.698310421359155, 16.47909106746797, 49.170455932617195, 42.70707630342053, 47.731569736234604, 41.353623251761164, 54.87575907861033, 63.28679161687052, 74.29390368923065, 69.9473919407014, 69.45806057222428, 63.10593897296537, 64.27908459017354, 60.6070714612161, 60.43871156630978, 54.17925596237183, 47.870268667897875, 44.6815150783908, 43.45691973163236, 47.26119910517047, 45.87361358827161, 45.86378020624961, 46.73315786546277, 47.179233335679584, 49.04550490840789, 50.29409731588056, 55.26405803618893, 58.53360460650537, 55.63478477539555, 62.516975479741255, 58.82208316556869, 63.44021512616066, 63.492782731210035, 62.21196413040162, 60.645985295695645, 63.290004038041644, 64.67523613283711, 62.787909277023815, 62.9725823094768, 58.66239170874319, 48.01040710941438, 36.424443414134366, 19.739906441780832, 19.57094250186797, 17.668334091863326, 11.480974593470174, 8.360645771026611, 5.7764711206959145, 15.965910707750629, 31.514536142349247, 40.667843895573775, 48.441981577104144, 52.47526853315292, 54.36560384688839, 50.08524287131525, 50.87637316796088, 50.37587481160318, 48.80436151258407, 46.811228721372544, 45.567586345057336, 44.140369199937396, 46.529735903586115, 48.71398225907357, 45.00606767592892, 48.12761145253336, 53.26171944218298, 53.6517991558198, 51.321366064010135, 45.639883472073464, 46.761575437361195, 44.09055509874898, 46.86168216889905, 48.79918398395662, 46.00968453191942, 43.224648737138324, 46.091273753873764, 26.62676084426142, 8.042824941296733, 3.713215421284399, 5.5486240694599775, 5.046179236904268, 3.243556945554672, 4.062028858930835, 5.223876824302058, 19.978733678017896, 43.770222971516276, 54.922097959826075, 53.44996967623311, 56.0091632412326, 72.24765808351579, 65.5110304586349, 61.15901170238372, 61.50559233080957, 59.30118499263641, 61.59474780482631, 64.38575736937985, 61.35922516545942, 57.63097309297132, 63.70726577697262, 57.68448598923222, 57.636166311079464, 56.30434120855024, 59.4443005131137, 58.2291070876583, 55.051245920119754, 50.99142020748508, 51.456362278230735, 49.637806338648645, 49.621775611754394, 51.72862575900171, 49.49528309606737, 49.24250987268264, 58.96364150508758, 61.36806618782782, 66.27324504237022, 66.99335298230572, 69.42416344919513, 71.79147858773509, 68.80802969778739, 69.01173407031645, 76.45863625311083, 66.8856760763353, 77.4317684481221, 28.851578235626224, 1.5652003668008314, 0.3541788110329259, 1.5960180615225148, 12.057765010864506, 54.353366051950765, 60.18716996715915, 61.18979446349606, 51.951435996640114, 60.01360900940434, 21.354818805571526, 46.66362208704795, 50.47089030665737, 70.81033691283196, 76.63521351352816, 77.00578335792788, 56.97737286167761, 105.51547604222452, 27.279198092799035, 1.5267298827248237, 0.32181098336173647, 0.4848133802654282, 0.17831747510260154, 0.6038149962982824, 0.3491327124497583, 0.40338675281213177, 0.15241829468117607, 0.19700654241586887], [0.08187402280107622, 0.0930445270252324, 0.08718092069630662, 0.07999491637512561, 0.1389274097258045, 0.24304738478554835, 0.14220836512263746, 0.11536365600242732, 0.07595918051177457, 0.29111684330048104, 39.7554103789791, 58.92757923372331, 41.026172022665705, 69.38639886917608, 102.79761083664434, 80.9110676857733, 95.15892828664472, 92.90323595846854, 56.84351805717715, 29.98877925257529, 28.579416736479732, 55.47533258315056, 50.39967575380879, 67.42073443628126, 59.917789428464836, 25.866785933894498, 4.3406698684538565, 17.64671398747352, 37.702990962613015, 43.39051008224488, 44.288795609628, 55.381211388495664, 57.17940238214309, 63.72940755659535, 59.666349810938684, 60.455099228889715, 56.26854173598751, 54.729540963326734, 52.377719186967425, 50.81074799260786, 43.762091898149066, 42.482787332227154, 39.304404489455685, 38.13469094614829, 35.969844633533114, 36.851750343076645, 33.27317199399395, 36.50240444367932, 35.810996486294655, 41.33728265762329, 45.15507067403486, 48.82096098315332, 48.510850552589666, 53.27166657293997, 53.91476661928239, 57.56271992960284, 56.502887664302705, 59.27605436694238, 57.80692669653124, 58.62413683245259, 53.731678224379024, 55.39477102218136, 58.055538285163145, 62.227018187122965, 57.32409861779983, 48.76642042590726, 45.364595843899636, 38.76869109369094, 30.402756006486957, 26.66563153266907, 14.40802372271015, 7.72108615406098, 6.245640035598509, 8.886563047286003, 16.576518820178126, 24.440037512010147, 37.99812970622894, 45.96851141222062, 52.918696403503425, 54.02835453710249, 42.296976812424205, 41.46486166984805, 41.66162736954228, 39.478283159194454, 24.53586886006017, 22.926571369171146, 44.00294503858013, 45.7212765755192, 44.80494422297324, 46.74108497558102, 48.40573495434177, 45.19576526457264, 44.56136895764259, 36.93983893240652, 38.883832270099276, 39.7911431712489, 53.60772348219349, 53.877033418224705, 51.190562863503736, 42.64282003525765, 33.74272284969207, 6.014857090288594, 2.1639905004732074, 1.4488057479743035, 2.596716674104814, 0.5277243857422184, 4.165418859451048, 14.906409882730054, 25.736335746703613, 51.303684019273334, 42.855765511912686, 47.72126566979193, 45.74465782411637, 57.456031460915845, 56.886083618287124, 56.274805761152706, 58.86229138220511, 57.82303587082894, 56.274723391379084, 59.26278106627926, 55.10891260639314, 51.93045916095857, 54.65283116986675, 55.539526093390684, 54.495026373094134, 53.499234645597404, 52.40138676858718, 53.474739443871286, 50.077249080904075, 46.745242687963675, 45.985444284254505, 45.82455650452645, 41.05092610082319, 39.90318567522111, 40.36427205608737, 40.47101151558661, 44.90958913680046, 52.18349126077468, 58.407747514786266, 62.77688349446943, 60.05094212870444, 64.9833304651322, 63.308666675321525, 65.86840152740479, 67.34031800300845, 68.28605636473625, 71.78607356163764, 30.241991781419326, 11.852093569694027, 3.8435047912982205, 0.6458380445837975, 1.069314227469506, 6.3439704237445715, 42.92248895091396, 47.282634858162176, 41.341538429260254, 31.187569325970067, 35.412322859610285, 9.783300219043609, 38.05162299063898, 44.92540805570541, 32.27020625145205, 67.66602377737722, 48.546701015964636, 51.25016720064225, 50.90379053546537, 0.26626963949491905, 0.033005377533094536, 0.21068747846349595, 0.18713418184028519, 0.3945986517975408, 0.10959037910065345, 0.09039459825162927, 0.024278519502390298, 0.1419934468163598, 0.2214377298350296, 0.06011647840721473, 0.0811982183386722, 0.04127132450981487, 0.033364079051440766, 0.06202323294635262, 0.06121247443520735, 0.1538956799213925, 0.03318365002351423, 0.07168083226368313, 0.12095373829886799, 45.02556185568533, 70.42718410491943, 34.59885074246314, 75.65967298323109, 111.07533377985801, 88.95268747883459, 102.4498534971668, 95.6261061083886, 69.03716671851375, 28.350830808762584, 38.1482348903533, 65.12989767136114, 56.21486802254954, 71.53127639524399, 66.23435866448187, 34.67090076015842, 5.943841107429997, 13.959606597500464, 42.18941365518878, 59.33114405601256, 63.64970891706405, 63.863929164025095, 65.7767592706988, 64.75804128954488, 62.830231651183105, 65.51802404465215, 60.79052463654549, 59.008933113467315, 59.49290652428905, 60.188852663963075, 52.62443234843593, 53.4749081057887, 49.58081037767472, 48.45703563382549, 46.90784846582721, 46.994677974331765, 43.19306973488101, 43.371282623660186, 41.75861973916331, 45.173368530888716, 50.46311224660566, 52.58050180250599, 50.96889795795564, 54.91931307700373, 56.8774583262782, 60.573797995044345, 58.81228116250808, 62.83307536955803, 62.28529284077307, 59.763491230626265, 58.574318808894006, 60.61074279969739, 61.22100476295718, 64.69761325467017, 61.531452517355646, 52.93270318738876, 51.08035602877217, 48.2243331786125, 38.89535619366554, 30.711132749434444, 17.024061256839385, 10.193809597722947, 8.441576034792009, 10.810056117273147, 15.91913252107559, 24.298296782278246, 36.41533959296442, 47.54621813374181, 54.13123830672234, 57.954788284917036, 49.81720378321987, 44.015182833517756, 46.74084571100051, 41.43067821379631, 22.894194164583762, 22.30807438973458, 44.33762911827334, 52.6522066516261, 53.14316188135455, 47.66870983185307, 47.6506551619499, 43.620396275674146, 43.70792788843955, 41.56512921856296, 41.64222732667, 37.08464891679826, 44.64210310289937, 46.563252556708555, 48.520962422893895, 44.163052266643895, 39.82919800666071, 7.257891008930822, 3.9400571200155445, 2.3187674726209333, 3.138219733392039, 1.9868560183432795, 5.26126975974729, 16.98200168148164, 31.970811736199167, 51.38786200554141, 43.90752946176837, 51.686181791367076, 49.06850960946853, 58.393509311060754, 58.50584991516606, 58.53103937641267, 58.59487987333729, 59.94153545748804, 58.43389403435492, 60.83259990138393, 57.616326962747884, 57.11855073128977, 58.467634262577185, 59.88580642207977, 56.33109961786578, 57.5350554527775, 56.34615367458713, 55.921631628467196, 54.28519525835591, 50.110467633893414, 51.77343099348007, 51.39618527504706, 48.21635507768201, 43.31755791940997, 44.0547909275178, 45.34840037745815, 49.60532911362187, 58.769111556391564, 61.31239206560197, 64.94854688644409, 64.33346433024253, 66.47678467535204, 67.79667792781707, 67.41372123841317, 71.23450202326622, 70.03085997796828, 74.56031891607469, 36.66362170250186, 17.191879864661924, 7.555176759919814, 1.7437520503036439, 1.2881746383443957, 10.410111642652943, 48.866452632411836, 51.13405327643118, 52.13903903961182, 30.98833449425236, 37.17887209307763, 18.22845247484023, 38.467904137026885, 58.847998265297186, 39.75902680427798, 77.94688547811201, 51.028788628116736, 58.343212758341146, 40.31756054970526, 0.38063764932655525, 0.0519880710259801, 0.22569085080777446, 0.06682990224010522, 0.282280846468864, 0.13086338437372638, 0.028248666748104077, 0.034363195600528876, 0.1990571299627904, 0.1514054038712094, 0.18823224630567337, 0.14980938225503893, 0.11328329061788898, 0.09477365641824662, 0.2636194655731801, 0.22378111618661115, 0.17664300608298472, 0.17756122374726882, 0.18289019263559775, 0.30001038865697, 62.49870900184878, 84.43741967601161, 64.15241949019894, 82.2533655166626, 113.87016373295938, 96.10341148991739, 103.35830580803656, 99.80546212965443, 76.21803806674096, 43.73163469376103, 38.792005661995184, 68.598080911944, 65.18835667640933, 78.1679267268027, 72.17694559404927, 34.894593531085604, 5.8723765034829425, 21.772562996033702, 55.15872278521138, 68.27387348298105, 68.21952512187343, 69.74866113355084, 68.56564291061895, 70.61230428757207, 67.52110004425049, 67.30836637558477, 65.07032863555416, 61.85494215257707, 63.57214012453633, 63.89388822740125, 58.24790700789421, 60.389081816519464, 55.29885730435772, 50.13692794307586, 50.21592840071648, 50.11373889061713, 45.12475467497303, 46.180515520034305, 46.91912528007261, 50.40131922691099, 54.41380977630616, 54.673772704216745, 55.11419211664508, 58.014298485171416, 57.55183143000449, 61.11956050319057, 58.40848492037866, 66.09957818062075, 62.839308015761844, 64.21185124304988, 58.072808481031856, 62.66196981553109, 61.90455621288669, 66.56182166068785, 63.9323902130127, 55.96749982526226, 57.490834651454804, 52.0423290806432, 39.47754183123189, 29.600005688205844, 15.296368002891542, 10.507352102187372, 9.628053788215885, 15.236528323542688, 21.513088403209565, 28.645094863830078, 42.535198042469645, 48.308342502963164, 56.93890225502753, 60.75403090446227, 50.54282265324747, 46.57372528506864, 47.60777581122614, 45.65931489390712, 32.058666944503784, 30.311888417889996, 50.33546263171781, 51.78114237323884, 53.95657908531928, 53.95584167972688, 54.52711920584402, 48.51059952089864, 51.69259878896898, 46.5562040575089, 48.82485197436426, 42.663722345905924, 52.02794182685114, 47.69538194902482, 55.513889481944425, 46.78882414294828, 49.63772396887503, 11.856766093161799, 3.6322000911158905, 3.232222276349222, 6.332713711646296, 3.1673930969930466, 2.9140442657855252, 13.8871515950849, 27.382868297638435, 52.22423291975453, 46.6662226184722, 52.88237525570778, 51.368167784906205, 61.737455398805686, 61.153120302384906, 61.321723384241906, 63.173584168957134, 62.281193963943, 61.68613902984127, 62.873609142918745, 57.67915941053822, 57.70085011759112, 60.91644448618735, 60.88204137740597, 59.37350565387357, 58.66636899209792, 58.44042085832166, 59.09930844460765, 58.66024224988876, 55.42369065746185, 56.8794273561047, 60.50329731356714, 51.486513537745324, 48.45086966791461, 50.186538081015314, 47.602582593117994, 53.53068028726886, 63.62557849576397, 66.91923587552964, 69.76214624220326, 65.39904679021528, 70.23880051028344, 70.27940488630726, 66.61849206493747, 71.50347463546261, 68.9403312436996, 75.62621516566124, 40.313704859825876, 14.274531737450632, 7.0903150977626925, 2.7388052690413693, 1.6848548429627574, 12.796781716808198, 56.63562067093388, 62.241260313218646, 56.71795122085079, 43.99884616175006, 49.23381005564044, 12.56261915929856, 51.73201860920076, 63.19848337481099, 43.125663803469756, 81.70668909626623, 71.33553443416473, 70.09772069992559, 64.50116918933007, 0.307803004379234, 0.10740338193793451, 0.2248444921907879, 0.15853199807386245, 0.4715067394558461, 0.21338236127649585, 0.1532348065126327, 0.13629461067818827, 0.22643145864769337, 0.21357670246112734], [0.059039665220846096, 0.025226560969566627, 0.07716505653074673, 0.06772480018797421, 0.043440142406090614, 0.06653755542732055, 0.5123107273492121, 0.3324444063248173, 0.04823605582538632, 0.046896869016270486, 0.862272224358974, 35.97940737201322, 65.08858334633612, 38.42211831000544, 84.52975226986794, 92.7498399057696, 82.7433087748866, 75.23309953751104, 55.08427227697065, 40.716049824991536, 27.296360423488004, 47.10283340946321, 52.54098000064973, 59.59491952773064, 63.87623756162582, 37.00505618126162, 8.476621431689109, 5.813693923334922, 22.872397553536203, 42.43285948230375, 52.29010128205823, 59.169259994260734, 63.44726362536031, 61.0650787814971, 60.94133584730087, 55.53833761522847, 54.63343112699447, 51.59173896235805, 53.03695978656892, 51.54423513720113, 48.638002026465635, 45.62655918059811, 42.378436596162864, 43.63689768698908, 45.13540783236104, 43.56737367568478, 41.30427983499343, 37.41996449808921, 35.10198493157664, 37.326765060424805, 43.83198461224956, 48.440106684161776, 50.60239168905443, 47.76049329388527, 52.991989812543316, 52.234227118953584, 57.363220337898504, 56.56135451409125, 53.2848810380505, 51.07186017497894, 54.351279351019095, 55.54246787101992, 58.63788866227674, 62.52692261049825, 62.61083779796478, 57.8824637013097, 48.249899187395656, 42.09730855880245, 43.73285455088462, 38.30694575463572, 22.80809617811634, 9.758212739421475, 7.111386070328375, 7.869414014201011, 8.034624245858963, 17.349231627679643, 27.650013085334535, 44.710477859743186, 48.317489470205004, 50.94741905889204, 47.20136727056196, 44.15947114267657, 48.409876977243734, 38.30929917673911, 9.944865588218937, 13.574412195913254, 36.344842833857385, 57.33156288823774, 66.23245239257812, 53.67642771813178, 47.684140436110965, 41.157124273238644, 40.33832165502733, 41.930933383203325, 39.344993175998816, 40.07754679649107, 49.63284454038067, 40.698399159216116, 45.232863041662405, 40.479185735025716, 14.065652778071744, 2.6585479369086604, 2.6638725544175794, 4.144021839864792, 3.3581161402886917, 5.776857964454159, 12.144448411080146, 23.47410482745017, 42.32729281148603, 42.08799292964321, 42.26748843346873, 49.33957284496677, 50.03731150780955, 54.89693987754084, 51.87927223020985, 52.364547867928785, 49.04149232372161, 53.22271147081929, 53.97083297852547, 53.53657560963785, 55.91005671408869, 54.254557624939956, 51.45811557769776, 52.25202683479556, 56.00156561020882, 54.97654045781782, 50.64358834297427, 52.313058914676795, 49.39154817212013, 47.49232476757419, 48.41159889774938, 47.949371107162975, 41.986481989583666, 39.42532723949802, 40.5044928673775, 43.05157807565505, 47.74656495740337, 55.12163677523213, 57.80328281464116, 63.03740732131466, 62.72830101751513, 66.48741429851901, 68.67525746745449, 68.61906559236589, 69.13269212169033, 70.30676734062934, 57.99978571553385, 34.41023180561681, 24.152541506674982, 13.461684257753435, 1.868072063211472, 1.300672903176277, 10.582527268317438, 38.91749012854792, 47.812437242077245, 33.3171849096975, 31.02865645962377, 17.017383421621016, 24.254976164910104, 49.65627285741991, 74.72855721750568, 81.05584236883348, 48.623881493845296, 33.90652102808799, 61.44457594040902, 18.770947648632912, 0.8364214147290877, 0.1455076453426192, 0.27010899637976005, 0.02755607346883945, 0.4818418171376952, 0.10013605738359113, 0.09321354134308715, 0.10954210790054453, 0.1638658392813898, 0.043564447832684365, 0.04634566492431107, 0.04993950978161828, 0.07252986452752545, 0.11018755995938856, 0.0880456424408382, 0.013509977781664462, 0.22550047795859077, 0.2539761346434393, 0.03759189230960704, 0.04769250878223008, 0.9689881496371763, 43.09676378004013, 69.53954389018398, 40.3822482785871, 97.56412567630892, 108.07247700229769, 93.28900106491582, 82.66133908302554, 70.40052767722838, 42.11377074641567, 30.41470942958709, 58.99615795381608, 59.61846551587505, 62.83229481789374, 68.85187395157354, 37.436320781707764, 13.528505756009011, 8.684363884310569, 26.790570789767852, 48.604540286525605, 59.47874676796698, 65.42485598594912, 68.4948205947876, 69.12139569559406, 70.19344222161078, 59.86310766589258, 59.41177229727469, 59.577421834391934, 60.02891017544655, 58.32849602545462, 53.810357047665505, 50.46801128695088, 50.13087180352981, 51.40768566439229, 53.31602857958887, 52.42228515686528, 49.176943532882206, 42.712128316202474, 42.700427885978456, 44.7616373339007, 48.128066447473344, 54.33581344542965, 54.2276030971158, 53.96148989277502, 55.7868472222359, 57.47800457862116, 62.04039181432417, 60.43085505885463, 59.795956688542525, 55.06771595247331, 57.67534294436055, 57.462146436014486, 61.16677407295474, 66.62952961460238, 66.26208982160016, 63.82325418533818, 54.92453375170308, 48.05317663377332, 47.280536390119984, 42.90715640591037, 26.15189321579472, 13.37623836532716, 7.659451990358292, 11.20719119425743, 10.23754402514427, 16.522131235368793, 31.37140101002109, 48.85599559353244, 48.72748305720668, 53.33028639516523, 48.25992868792627, 44.95470423852244, 52.02724756733064, 40.42088362478441, 16.402821560059827, 23.507970571517948, 42.00947492353378, 58.287519024264434, 68.57676675242763, 57.25985411674746, 48.4784713868172, 44.5492252995891, 43.86199074406778, 42.745374325783025, 34.92405837582004, 36.904788632546705, 50.324723182186005, 45.73218468696841, 44.84667824160668, 42.345578901229366, 18.82939096420042, 2.5533923795146327, 3.845514515715261, 3.0263927146311733, 2.9348835733629044, 8.562978294587905, 14.083341686956345, 26.96305113454019, 46.00570332619452, 43.16606813861478, 47.55436881895989, 54.51166898973527, 54.10413865120181, 55.90217275004233, 55.061695114258804, 54.96556174370551, 51.82708509506718, 55.524209237867794, 58.06508533416256, 57.64457195035873, 58.095060087019405, 58.28158447819372, 56.73714337810394, 53.242954823278616, 59.3132149019549, 59.56031637807047, 55.6820297241211, 55.41438287304294, 55.39457098130257, 52.25231316781814, 53.52978598686957, 50.971616160485056, 47.04386841866278, 45.33684115256033, 43.99065625283026, 46.14308826385006, 54.38665128523304, 58.465567173496375, 63.75759370865361, 63.718821079500266, 65.69689589162027, 66.6847252076672, 69.50588995410551, 68.30926895141602, 72.2325098899103, 69.99017715454102, 63.60755520482218, 40.52592469799904, 34.76037786852929, 17.347954896188554, 3.8528255685683224, 1.8194088099464294, 15.962303107784642, 45.29718206774804, 55.09100698655652, 38.03783193711312, 31.835905736492528, 26.579570808718284, 31.928040250655148, 52.282962568344615, 79.21306579343735, 84.68269332762688, 61.512664364230254, 35.56299678740963, 67.06302212130639, 16.380967094052224, 1.160596238989984, 0.240404105655128, 0.40066116519512673, 0.16175388809173338, 0.5497574421667284, 0.0656500578888001, 0.16133376547405798, 0.08387489124171196, 0.02001014188863337, 0.057172337396731304, 0.1742542520045273, 0.20158969406639377, 0.23569654132569992, 0.19062935074250545, 0.21547949632569668, 0.15189888706851393, 0.4297449577960276, 0.40017552673816686, 0.16837858745167333, 0.1606248583524458, 0.9142545382342032, 64.49623877002348, 90.91929328057074, 60.81571802016228, 95.64974231104698, 106.6453069256198, 93.28896184121409, 89.54458882731777, 71.03989754953693, 57.3439379661314, 38.58032318853563, 60.51649608919698, 68.36276223582607, 68.73330854600476, 77.84013425150226, 42.76112656439505, 15.179555896789799, 8.509293794631958, 35.90388605671544, 55.35613567598405, 68.89416494677144, 69.9018846019622, 75.38241632523076, 70.7645393187, 71.82505407641011, 63.35665295200964, 64.97663497924805, 62.46543161330685, 62.99934464116251, 60.00324610740908, 60.54212485590289, 55.15196061903431, 55.76337575912476, 57.239544083995206, 58.908540048906886, 57.19591556056854, 52.8824144794095, 48.55561656336631, 45.27266725417107, 49.236496879208474, 52.56344341462659, 56.19571508899812, 59.00681895594443, 54.08766861884825, 57.352037660537235, 57.898843519149295, 63.77026296431019, 61.06636924128379, 60.79429795665126, 56.649325432315955, 61.115897009449625, 58.810614155184844, 62.58705254523986, 67.37208920140421, 69.53901829258089, 62.73021513415922, 58.04886633350004, 49.99793483364967, 48.78589891618299, 45.44813448382963, 26.84752360466988, 11.99537088794093, 10.940391575136493, 14.04916117268224, 15.747536670777107, 22.100951671600345, 38.236178351986794, 52.89374620683732, 51.611986237187544, 56.802023303124216, 51.61699118152742, 49.235975203975556, 52.09870138475972, 41.287072397047474, 14.09078928732103, 23.80733763017962, 43.4163506569401, 60.78223666837139, 69.88797587733116, 55.425926408460064, 51.43086687211068, 48.33015480349141, 50.70222777705039, 49.78385579201483, 41.96990997560563, 41.648765917747255, 57.335544093962646, 59.25441072833154, 56.93694106994137, 48.59460492287913, 29.665022896182155, 4.346829460513208, 4.077598707329843, 7.028612782878261, 6.542640434157464, 8.553171388564571, 13.008201391466203, 26.754167272198586, 47.216582144460375, 42.77867132617582, 46.96991997380411, 59.69488113157211, 55.910370503702474, 60.21502664012294, 60.267025501497336, 58.709566054805634, 53.12918255406042, 58.810006187808135, 60.580611152033654, 61.320028920327466, 62.70952463150025, 63.44379625012798, 59.156728021560184, 58.00730489915418, 61.609468460083015, 61.608468255689075, 56.35223334835422, 58.38274240493775, 58.28199632706181, 55.67519303291075, 57.45398790605607, 57.029971845688365, 51.37039176879391, 49.867872961105846, 47.84917023874099, 50.56259924365629, 56.988916397094734, 61.06046607417446, 66.50222516828968, 70.80485343933105, 68.23154326408141, 69.2497278028919, 72.39823002969065, 70.66671540660244, 73.11220338267665, 72.944655418396, 68.91589487752607, 40.81528186798096, 33.976127409165905, 16.465968778056485, 4.019166423428444, 1.6200993306213811, 18.705347968686013, 53.10187109055058, 64.7859920993928, 44.9665262622218, 40.9873366355896, 22.096442907087265, 36.13321527358025, 73.29811588410409, 93.49203863451558, 92.10254684571298, 58.605874276930294, 44.730305440964244, 84.73224070764358, 24.802690052217056, 1.2584887925655612, 0.3058760174580159, 0.4238561931396685, 0.28269995785047936, 0.7293145394613667, 0.1442753469511386, 0.24739330964944056, 0.2614183417491375, 0.30998519050978846, 0.17551835836662402], [0.06452153376754254, 0.2050817220081245, 0.1825033335555946, 0.04479507615249004, 0.19916399922822753, 0.12277855973450408, 0.20509025622760096, 0.2789856265148809, 0.12548821272268412, 0.25393611421027495, 0.07668389202726465, 0.9939139540637694, 37.352719383855025, 56.47060263541437, 36.601569806375814, 91.00770350425475, 46.98147135396158, 67.9516193943639, 60.55886160942816, 39.98395512180944, 46.18225705239081, 35.853911138349964, 67.58967876434326, 54.21320407621322, 65.46137717462355, 32.80872806426018, 16.754843496507217, 13.080394575672766, 29.886781938614387, 46.522675637275945, 53.59483849617743, 60.293007281518754, 68.93695800535141, 65.36465152617424, 66.50755959172403, 52.468392618240856, 56.35967800694128, 60.39823662850165, 56.503185764435806, 54.41867743769, 49.20429029772359, 43.83764067003804, 43.967800601836174, 45.808463019709436, 50.93805243892055, 48.55161966816072, 44.59059061542634, 37.07676887512207, 42.2297905337426, 43.08876998962895, 47.48437020086473, 50.264412818416474, 50.8003144879495, 46.41325719894902, 51.61159792254048, 58.31735257179507, 57.73909714914138, 54.95119017939414, 51.94819219650761, 46.20581873001591, 50.716422834704005, 51.08240350600212, 61.3511097815729, 62.9292401190727, 60.709182523912006, 62.125573927356356, 57.585144119877974, 52.07237051379297, 47.54970119845483, 46.97325398845058, 31.723718104823945, 19.669709743991977, 10.536773800849915, 7.729187319355627, 4.670234274479651, 8.770957070012248, 18.989398171824796, 44.58613088054042, 42.414130164730935, 42.343296081789084, 38.969406620148696, 47.600511581667014, 45.52360873068533, 43.67568992799328, 35.6138660061744, 44.023690454421505, 58.98687370361821, 68.70232182164347, 72.02656976638302, 74.79898729631978, 61.26035398052585, 54.57456811781853, 38.51856547017252, 33.984180035129675, 31.81745686838704, 35.2935613355329, 33.91296940465128, 16.40174683063261, 29.633843975682414, 25.522393988024806, 7.5212306072635045, 1.1340094333694828, 4.367465540286034, 3.3396179974079137, 5.783238189835703, 14.988562945396671, 19.064801816017397, 37.58799099153088, 42.43303206659133, 39.041778272198094, 43.722836817464525, 48.61107103286251, 49.28405953991798, 47.58516726955291, 47.03185419882498, 52.109138811788256, 53.68811638124528, 55.29514281980453, 59.63232717206402, 55.15304319320187, 51.39046253696565, 53.50994271616782, 51.98677655189268, 50.61476284457792, 56.47846698760987, 59.230017508229906, 56.41906269135014, 54.00693447359147, 53.17511743114841, 49.34236165015928, 48.80959395439395, 47.87003332568754, 40.94750496648973, 38.25144421669745, 40.17143264893563, 41.22151782435756, 53.376829239629934, 54.81205586464175, 61.45988887356174, 58.89165424531507, 64.78289342695668, 64.80747099845641, 65.89848610662645, 64.7235087425478, 71.23645536361202, 61.68276579149308, 47.749467511330884, 37.25258911809614, 36.821920717916186, 21.228842081562167, 6.181977025924191, 3.0220251554442994, 13.596654976567915, 37.944793316625784, 42.32628476235175, 29.566275265909013, 42.872757219499164, 17.252302015981368, 32.2285859815536, 49.08902360546974, 70.70245604361259, 75.57571857206284, 57.46213466890397, 38.02306421341435, 66.1836188839328, 7.488787212679464, 0.7556151346333566, 0.25642357105689667, 0.3805128995689654, 0.07832333550698335, 0.8326681967704528, 0.12270860058525879, 0.13204752647828671, 0.04190112156192622, 0.15445500071490967, 0.24899538336021287, 0.27921122408682303, 0.19772761501371863, 0.12279038047117573, 0.04362486535683275, 0.2055088926347033, 0.19942056207406908, 0.27474955865933054, 0.37417557511118155, 0.30795355597811364, 0.26718453233761175, 0.16375780556230776, 1.2022292565914894, 42.8604684337493, 62.49643402714884, 45.85968132941954, 101.66431257801672, 62.09342225905388, 86.13562553159653, 68.8098967459894, 50.5832269883925, 44.41326025993594, 45.38419985002088, 69.0311498026694, 63.47493986929617, 66.39253216405069, 41.432298152677475, 20.604222282286614, 17.405754943047803, 41.43599694774997, 59.6702447245198, 62.82131610378143, 69.08651798002182, 73.95042173324093, 66.92930852213215, 70.35608722317603, 57.72690642264582, 61.07386489068309, 63.029484133566584, 63.24006049863754, 59.167000709041474, 53.80145326737435, 49.17815554526545, 52.535104290131606, 54.081024123776345, 60.89814270696333, 57.63984941667127, 50.274246200438476, 43.951361948444, 46.529398579751295, 44.41629225207914, 50.58030874498429, 57.79126075006301, 52.091044918183364, 49.100888775240996, 54.22322965437367, 59.80733156204224, 57.310927298761186, 59.91726383086174, 55.37078965094782, 50.842629017368445, 53.393750344553304, 52.29023464264409, 63.103946408917835, 65.64003721360238, 67.67391558616393, 66.74584357969223, 60.380095666454686, 56.664587374656435, 50.64686352206815, 50.895204467158166, 39.88027511104461, 22.839620267191243, 16.60787424733562, 7.237772682020742, 8.346074165836457, 9.369323465131945, 19.740816431660807, 52.18811573520784, 44.08606398490168, 43.88208504646055, 43.37940192991688, 47.87899986390145, 42.96079874038697, 47.6512356727354, 71.99711276638892, 80.81231809431507, 69.63439464569092, 66.78203136690202, 73.92884085255285, 70.9035167386455, 54.33078496686874, 47.01689820135794, 34.04981697759321, 38.30936977940221, 38.677295946305804, 44.642844430861935, 49.83359929054014, 34.73892250368672, 32.73482668784357, 30.62113592701574, 11.217604106472386, 3.9266916436533776, 3.557362739116915, 6.411842136613785, 12.219528459733533, 22.54345190140509, 28.115818077518096, 47.44853934934063, 42.396605014801025, 43.00094812147079, 49.10523476139192, 55.35209171233639, 52.56839736815422, 52.52273705697829, 50.00569720422068, 49.963845514482074, 52.25976567114554, 56.98009498657719, 59.366331638828406, 56.53339978187316, 56.292781983652425, 58.20220355064639, 56.8014310252282, 57.59436561215309, 59.32053796706661, 62.03772460260699, 60.21753303466305, 54.709999715128255, 54.876959323883064, 52.59229636961415, 51.23736850676998, 52.598721211956395, 46.75230687664401, 41.55357391603532, 42.83372571391445, 46.11024625839726, 57.91434472607028, 58.72285896731962, 64.48574642981252, 62.54794651462186, 65.3727198416187, 65.37349647091281, 68.49342423100626, 68.37047361558484, 72.64015397717877, 64.11430974160471, 55.15159191623811, 49.93117217094668, 43.58896240111321, 23.738921688449, 7.904299084217318, 5.0143055665877565, 18.769684645437426, 49.100174903869636, 51.06032056193198, 35.214392215974875, 45.4150414466858, 27.000266582735126, 35.53335543601744, 50.868461747323316, 75.47674148313462, 77.60912233783354, 64.0428323899546, 43.40665455787413, 77.23924283058413, 6.263538300991059, 0.8021098687764138, 0.0685638579870424, 0.5663578320414789, 0.22637770991892586, 0.6603344505833042, 0.1925540853652262, 0.26896335785427405, 0.18300398733587037, 0.07084323003167106, 0.2137459159618424, 0.4539362984078546, 0.38897856949798526, 0.42748818534516525, 0.17796386423851215, 0.4947500309396175, 0.2883343506724604, 0.35221321328032407, 0.5685162388028637, 0.46711570733497226, 0.650015368817314, 0.6269205758167852, 1.7027868162239752, 66.97727910933956, 78.05642943228446, 54.70914071606052, 106.06121109377955, 58.77662289527155, 87.7115789536507, 75.17486018519249, 52.89048279485395, 57.938071143242624, 48.45579224248087, 82.56822201513475, 69.83329803712907, 79.251708984375, 43.73534133357387, 24.844404458999637, 17.203560683035082, 43.87220067362632, 63.342273542957926, 66.44531157708937, 73.24355571500718, 81.07917262661843, 72.13015956263389, 78.08966759712466, 60.774329170104004, 65.52458616995042, 69.77527049279982, 68.46909769119756, 64.06039284121606, 59.98942367492184, 53.14330700905093, 53.768991731828265, 57.6026104342553, 63.623283909213164, 60.040379185830396, 54.810071145334554, 45.865902208512836, 46.82579640419253, 46.73854720207953, 52.51604549346432, 59.733026181497884, 56.81060544906124, 49.88344477068994, 54.96701302066926, 62.1404593221603, 60.64673054602839, 62.7219860015377, 57.50428838114585, 52.24282887674148, 51.38239029915103, 51.76750821451987, 63.30992967851701, 65.774692181618, 67.77574031583725, 70.44512502608761, 63.9755049059468, 63.559208070078206, 52.46294836844168, 53.4793286169729, 39.70065409137357, 21.35612887720908, 16.598639026764904, 10.384122017891178, 13.167846760442181, 13.150495175392399, 28.052481605160622, 59.338169020991174, 45.731266852348085, 46.426263778440415, 43.987071206492764, 53.670614765536406, 49.216539859771736, 44.238138198852546, 59.51260858966459, 66.89983583265736, 62.51390426389633, 65.88183172287481, 72.88741234810122, 74.73363276450866, 56.84298853720389, 51.97178133072392, 39.0353455851155, 46.792679832827666, 45.453751317916385, 58.28189042306716, 64.56106378186134, 55.256683980264974, 42.64482044404553, 42.042109043367454, 18.49638762012605, 3.963622229714548, 7.570038620502719, 8.507601291902605, 9.89679596116466, 19.770232246768092, 25.40760974730215, 43.55719120271745, 47.33917190182594, 44.174854678492395, 53.314090928723736, 58.82711556649978, 56.48105967429377, 56.523782130210634, 52.81446726091447, 55.655369374059866, 56.45709399254092, 57.93890268571916, 63.71649119161791, 60.10623185865341, 58.9641200342486, 62.732858811655355, 63.039023337825654, 61.49396250324865, 63.68377077964045, 66.54628123006513, 65.27730818717711, 59.55048691841864, 57.55090182827365, 56.59278838865219, 53.93399015549691, 57.447865086217085, 50.7546777109946, 42.94915322334536, 45.386133578515825, 46.78603141538559, 57.790935193338704, 59.81383485178794, 67.71485728602256, 63.15851442275509, 65.47737260018626, 65.04593149308236, 67.4450139076479, 70.31636145807082, 76.0761502481276, 65.84216871569234, 57.203191557238185, 51.38167642777967, 43.84710927163401, 25.270666076290993, 8.914854122746377, 4.861848431248819, 21.2056863692499, 54.87980304225799, 58.500425277217744, 39.026355512680546, 51.15703444327078, 23.232459368244296, 46.31107945596018, 68.12412523454236, 82.69515775865125, 83.53412135954827, 68.77603884666198, 52.61912930396296, 93.4100297189528, 8.639844982854783, 0.833732691262999, 0.3833705607441164, 0.6766706933417629, 0.4179027093754661, 1.325223140658871, 0.2181383883280139, 0.35615268253511, 0.18929787460834752, 0.3584303232210298, 0.5306911071942699], [0.17753477839212264, 0.13511748593901435, 0.17371212222403096, 0.15120283490227115, 0.4028355372288535, 0.09258268325920067, 0.5524971564450573, 0.4688932151804048, 0.15458077703031803, 0.6346523641578613, 0.12493079182721915, 0.8838307352796678, 2.6282027652186732, 67.05211793222736, 46.16095073761479, 40.78069048543131, 6.415659583383992, 44.86897299366613, 76.60075156919419, 29.67711948579358, 63.378731973709606, 34.989722774874785, 50.967070133455344, 52.116559936154275, 58.38371123037031, 41.1498208199778, 30.78757189935254, 29.762884070796353, 48.37720755607852, 59.591287412951075, 56.85537538220806, 58.550980706368726, 67.62338761360415, 61.2740195182062, 64.15076424998622, 50.73901568689654, 55.75323250985915, 56.6442891090147, 54.64137392659342, 55.11921275046564, 50.773030481030865, 46.14715183934858, 50.33044984263759, 50.070581051611136, 57.022252621189246, 58.374481893354854, 51.52634520684519, 48.03499252565446, 48.68579610701531, 47.00609599390338, 46.56342514099614, 47.56431594971688, 48.12265357663555, 45.03115123318088, 55.72508558150261, 54.922458817881925, 53.34670543670655, 51.3217386891765, 46.83695554733277, 48.298909202698745, 53.335538448825965, 54.77415007929648, 57.30437694057342, 60.27534877100299, 64.46271819453086, 63.84284250197872, 59.132052390806145, 52.41773912983557, 51.40800337637625, 45.396990699152795, 43.71148547818584, 34.94365061483076, 26.39963992180363, 6.120756672274682, 4.99477461461098, 5.313795199317317, 10.941838929730078, 42.48366594314575, 47.69834726087509, 37.230992547927364, 36.26823894439205, 43.732411323055146, 30.468887167592204, 47.28212495003977, 75.85743888731926, 84.48306822007703, 71.61372461626607, 58.96610083118562, 72.56544067013648, 74.55747912006994, 64.95958051373883, 47.441875242417865, 32.70092760362933, 19.986270512304, 16.34925865357922, 13.050562008734673, 11.189348332343563, 4.039052104757679, 8.790093333490434, 12.692527078813123, 7.609010800238579, 2.70923966842313, 5.581628362978659, 5.1128879670173895, 20.14567759729201, 30.657774786795343, 40.50419476724441, 44.11399518289874, 37.07585104050175, 41.01420879364014, 45.77042387377831, 52.437923646742306, 45.12049890333607, 46.33364877393169, 48.741513375313055, 48.17918277555897, 47.69998288923695, 57.18545459931897, 56.938745360220636, 50.682729674923806, 52.32376306287704, 52.84254358660791, 48.6444111793272, 53.87557821889078, 59.044426641156605, 56.27424486221806, 52.8336751076483, 52.47604516244704, 53.707967496687374, 51.19786631676459, 50.07033786466045, 49.31622689770114, 41.42385328969648, 38.527398647800574, 39.8118572081289, 46.96276949297997, 58.69111914788523, 56.5989504321929, 59.2663465007659, 62.740664328298266, 66.60511678264987, 66.93687085182437, 65.18831745270761, 66.06929748289048, 70.14125900883829, 59.07897095526419, 51.828967832749896, 48.70602769236411, 43.314894630062966, 22.708038476205644, 8.68911583577433, 5.232559971271023, 14.399793609496086, 45.40148573537027, 40.86189923747894, 47.24768261755667, 37.6391230090972, 16.869861118255123, 45.608022059163744, 52.58636182354343, 78.33568649907266, 62.911797338916415, 59.49635821004068, 36.83915561245334, 67.33399514229068, 4.007051447706838, 0.5648384038959781, 0.36135576785572115, 0.3509533970106033, 0.3741598856304923, 0.6050798993918204, 0.18279570335101697, 0.14212172057840133, 0.09109103346183416, 0.10043862380928571, 0.1412083445897987, 0.4514496689361911, 0.5659888840971455, 0.11988824789202022, 0.12136071484776274, 0.2913902754024152, 0.0996628295510046, 0.2741898241783342, 0.3349239265005435, 0.04684327733552745, 0.26382002739175675, 0.09719989517883909, 1.328107308476202, 1.5604469444482558, 75.52636731055476, 53.53235906170261, 52.77242337503741, 16.906476443813695, 58.088537185422844, 81.20220168944329, 41.491043490748254, 56.102339144675966, 39.86042399560252, 56.97625106380832, 60.167012906843624, 61.85113353113975, 43.84760349027572, 33.60808357115715, 30.539662414981475, 53.156062556851296, 63.178063515693914, 62.00203103403892, 64.47935688880183, 69.17369657947172, 69.10662404952511, 70.21134391907724, 53.78587361304991, 57.06759522038122, 61.108071880955855, 59.39548661631923, 60.07610021098968, 54.9565520594197, 52.72061670980146, 55.204426242459206, 53.93983448705366, 59.44099003268827, 62.357107516258, 55.64659110961422, 50.906630331470126, 53.007946014404304, 51.986925601959236, 53.16980261956492, 53.15505058534684, 54.63635721514302, 51.271732391849646, 58.37667057591101, 57.29400227146765, 53.422575842949655, 55.425263527900945, 48.59158469784645, 50.60835761408652, 56.65027464589765, 61.694509367788996, 62.88150879644579, 63.453362910978264, 67.08100226617628, 67.1385512813445, 62.808980249589496, 52.886823223483184, 52.02862431926113, 49.973102308088734, 49.10134377018098, 39.78598917684248, 30.285963512236076, 11.672453918764669, 6.081099058351209, 4.261658133998994, 12.79462637439851, 45.1925685328822, 46.92551482108332, 43.84650914899765, 41.36930488771008, 46.4261814086668, 33.9442071607036, 43.78057018403084, 90.18351939416702, 93.99141127063383, 66.30368263490739, 61.20021227867373, 73.11096391370221, 69.17814454724713, 61.737353417181204, 46.31967336900773, 37.57690245105375, 39.10655229322372, 31.14103824861588, 24.24870429500457, 19.930425766975652, 10.46176435485963, 10.63078026617727, 19.977466752452237, 10.470648523299925, 5.207410714318676, 7.505290094883212, 11.039833464930135, 26.065167650099724, 36.614262596253425, 44.38294818324428, 43.84867821970294, 40.1224422454834, 47.77533162024714, 52.421810550074426, 56.31520617392756, 50.19315904186618, 49.66095224503548, 48.34314177113195, 48.49975024500201, 47.41912549541843, 58.35862375074818, 60.43180035006616, 56.637256299295736, 54.096125248939764, 54.73876245560185, 49.3161759068889, 55.16191951690182, 59.898879681864095, 58.67186423270934, 56.980247959013916, 57.557703218152454, 57.34881739462576, 56.58941122793383, 54.278950845041585, 50.264569713223366, 45.46624798928538, 45.492869115644886, 43.743095859404534, 48.63346384417627, 60.31230534276655, 60.470306258047785, 62.773557324563306, 63.672776376047445, 68.58112842805924, 70.0934688506588, 69.82630837348201, 70.27596104529597, 71.18952812687044, 62.64103220355127, 59.69279050827027, 57.86747632488128, 48.062476573451875, 27.403939270204116, 10.073688972380854, 6.183099314089745, 20.586808919906616, 55.375790672917525, 49.27723853818832, 56.282619122535955, 46.338281093105195, 24.035956898043235, 45.83843777256627, 48.99300006128127, 74.74969879273446, 70.14257692521619, 66.91254431201567, 39.36905691700597, 74.20530519177838, 3.1073948068003503, 0.47600180631683725, 0.1439174766381902, 0.15042430571010038, 0.5032253535764833, 0.11298118384494898, 0.26353917955871553, 0.15298400464798176, 0.13751341060044306, 0.10030186179304316, 0.3590159514738668, 0.6803452800358496, 0.6452716298161015, 0.32264592726865127, 0.25212638470674714, 0.4324859284585522, 0.26103823956462646, 0.7020503895417337, 0.6530045213237886, 0.24727963752323584, 0.6397405975768644, 0.145408314382357, 2.3989294421288276, 5.977799517493095, 99.0311784128989, 64.53537617960285, 62.11439124999508, 14.797538615042164, 66.9665631940288, 86.41756549958261, 39.58224165824152, 67.30245144136491, 50.770316200871626, 68.6838003896898, 71.63314819335938, 72.01272379967475, 48.547308983341345, 37.140244591620664, 34.876405500596576, 61.361319711131436, 71.68401348975398, 68.25138261241298, 67.72514174061438, 75.51148583812099, 72.40237205259263, 75.08659116683468, 60.24093781748126, 63.589551525731245, 68.80013004426034, 63.52040013959331, 64.37952472317603, 58.343228447821836, 54.26552849431192, 58.16901245424825, 56.436262284555745, 65.57857759537237, 69.99932412178286, 60.03824541645666, 54.42851474208217, 52.274317664484826, 53.393354185165904, 56.02484879955169, 57.63142024317096, 58.259956529063565, 50.04058276453326, 58.02780712804487, 60.05735128156601, 55.19504001063686, 58.773422241210945, 55.33000484589608, 53.709093216926824, 57.13878623900875, 58.367013700546764, 61.36295141712312, 66.9088259050923, 72.59171270555066, 73.97761160327543, 64.92572653678157, 58.725126097279215, 59.03511101199735, 51.853753289868756, 49.57136138792961, 40.77432447864164, 28.445224608144454, 11.706639336001489, 11.542959809303285, 8.005126060978059, 15.024624236168401, 56.36218832385156, 49.10330103289697, 44.6647391011638, 43.963391857762495, 50.737085880771765, 34.16333429275021, 49.87657277814804, 58.6314324409731, 61.15165333594046, 69.68481279188588, 60.04774931938418, 74.90517370162472, 73.17371399171891, 67.6830311744444, 50.88710085038216, 43.19667047069919, 53.57381851442399, 45.4545985498736, 34.71086971221432, 27.798694449086344, 16.589366543677546, 15.379809564159764, 25.155575890694898, 17.634252617436072, 10.584588473842992, 9.901964664459229, 11.06518864631653, 24.96469766862931, 34.94912624359131, 45.413319526180146, 49.150043918240456, 45.088311933702045, 52.35219240188599, 54.952425725998424, 61.408137121508204, 53.09568943515901, 52.362924006677446, 50.622968442978404, 50.453780927965724, 47.02156974423317, 59.34493118716825, 62.501823363765595, 60.084235206727065, 62.08286716092018, 61.385889437890825, 57.87610946163055, 60.316612105215754, 63.356382308467744, 62.10039623322026, 58.95230193291942, 62.76379062283424, 59.393521508862904, 57.8398314599068, 59.211068537927446, 56.637774052158484, 49.43437260966147, 46.73329907078897, 42.79778111365534, 50.15229186704082, 62.43954004779939, 61.35161184495496, 64.74824320885443, 66.68015172404628, 69.40033112802814, 70.03550406425231, 70.09544572522564, 73.13441968733265, 74.41106488627773, 65.81832070504466, 61.2390241315288, 60.28092245901785, 49.124517133159024, 27.055352349435132, 10.827485169133833, 6.717210421639105, 19.845565288297593, 58.866770728941894, 53.23149758000528, 58.97621270148986, 45.34823563791091, 20.994668737534557, 61.66256950747583, 68.60139139236944, 93.31930529686713, 75.56082925488873, 71.38865117103823, 51.805472835417724, 90.1461156722038, 4.737717672701805, 0.5987525034335353, 0.5709516629576683, 0.3813907750431569, 0.5432646325038326, 0.6895499796636644, 0.36054386787356874, 0.40003487299526896, 0.18961074491662366, 0.273830222506677, 0.5098010539527863], [0.15841354555901022, 0.2130821927060043, 0.05854705153333564, 0.15454357580071496, 0.1439275889987907, 0.060072868852125066, 0.19592481094502634, 0.07688214792118919, 0.0507362833577058, 0.16558048195175587, 0.48979129702333485, 0.34556767632884366, 1.0827264045515368, 29.040646283857285, 71.79904091742732, 41.87630261144331, 41.191652897865545, 44.169932103926136, 69.72900221424719, 19.95078875172523, 63.008876000681234, 70.89540527712914, 52.36858790920627, 48.659645665076475, 57.88599775683496, 45.1665122278275, 34.34093529178251, 30.397507875196396, 54.62662189237533, 59.51299690431165, 54.38795743450042, 60.269680946103996, 66.27857946580457, 61.65651336792977, 60.07332317290768, 48.91536458846062, 52.97730838098834, 51.54986766076858, 56.64718774057204, 55.16362967029695, 51.245295616888235, 51.758851543549575, 52.04040711925876, 51.454918846007324, 54.21758928606587, 55.12627693914599, 49.46456309287779, 50.01482063724149, 51.69573276273666, 50.30009461987404, 47.54533560045304, 47.243218960300574, 47.42530715081, 49.729225020254816, 55.71895883929346, 56.33632421493531, 47.94247558040004, 45.02813493051837, 46.10404499115483, 50.115900116582075, 54.51463037921537, 58.94355896980532, 59.321942175588305, 59.59451160123272, 62.927663326263435, 59.56466628659157, 62.52417302900746, 54.85429586902742, 47.99485491168115, 46.591262202109064, 48.82207101391208, 43.9759159857227, 34.031232787716775, 15.738079836291654, 8.311706358386624, 3.550563800719477, 11.030386436370112, 37.18039789507466, 36.62539820517264, 34.295192610832956, 36.089096453882036, 44.86077524000599, 37.0484140611464, 32.48380676392586, 68.66387474921443, 75.53831485009964, 53.763896572974424, 56.32472968870594, 65.64291623330885, 47.35648524376654, 30.530691954397387, 24.757737728857226, 16.37168284385435, 10.257575569614287, 4.545704414767604, 3.449523545080616, 1.2062549567030323, 0.6055396134334227, 3.3592609820827364, 4.983995451081184, 3.123433133286815, 3.1373641663982026, 3.9137885166752726, 13.75586005949205, 27.453535679847967, 38.74681603523993, 35.140035844618275, 33.93749990770894, 35.936841810903246, 44.84557605558827, 48.97729881348149, 50.239380251976755, 46.15691854107765, 47.51066184812977, 48.639892608888694, 49.94075452127765, 50.16565145984773, 54.07616430713285, 58.56316358812394, 54.9364891359883, 51.74471924381872, 46.76571746026316, 46.34298009257163, 47.73571568150675, 56.54624946655766, 54.65547092499272, 56.38588728443269, 53.17293267096243, 51.83537698561146, 51.5172335409349, 47.67917471547281, 43.39964136000603, 44.75868378916095, 44.34458348058885, 42.56566309159802, 44.53213553274832, 59.696477536232244, 60.38705787351055, 64.9326495201357, 61.59869370921966, 66.20024188872307, 69.3066413940922, 69.05633141917568, 67.63276207831599, 65.63177277964931, 55.88072522994011, 54.95300231441375, 51.51394267236033, 47.07636525554042, 25.99038766276452, 10.8406594299501, 5.369672304199589, 22.645241329746863, 47.75660230267433, 47.88431467548494, 57.12244172250071, 36.25520883067962, 23.91087643561825, 43.76319800653766, 47.98511174417312, 59.718991941021336, 57.1279840315542, 65.85999196575534, 45.052210438636045, 58.687134019790165, 1.5155942738056185, 0.24599480082190808, 0.2790275162025806, 0.1837606370569237, 0.38552893686198425, 0.0842155015937263, 0.06304501420668056, 0.046843223709372744, 0.14351033154995213, 0.052145678294642325, 0.2460890143148361, 0.26603736163627717, 0.16162032832301435, 0.10930547100161353, 0.04347587274687906, 0.10134919591608549, 0.05506666812805399, 0.07615963507804178, 0.09330066086183633, 0.08870401840296485, 0.06062433724441837, 0.4814374759312599, 0.5029713801078258, 0.8789763731821891, 29.113745535573653, 75.86792730516004, 46.67158057612758, 41.20777383927376, 46.088492793421594, 74.96945350400864, 29.454987818194976, 70.08445524400281, 72.76841548181349, 61.42320686771024, 48.2507424969827, 62.72612410206949, 52.032123073454834, 35.902940765503914, 31.424527552820024, 56.2312949088312, 66.24538836940643, 63.96285918451125, 65.36565565293836, 66.27849317366078, 63.82587825098346, 62.390043658594934, 53.89067542168402, 54.29223983518539, 55.962086954424464, 60.187338629076564, 61.24334658345869, 56.125304622034875, 56.69216555933799, 57.721619067653535, 57.55531449471751, 57.860678857372655, 57.16700769239857, 54.194262950651115, 55.73054944315265, 56.20837257754419, 53.66228365129041, 52.10772675852622, 48.75667725839923, 50.00029610049341, 55.1018209611216, 59.68541252997614, 57.39187717437745, 51.42251222364364, 48.200163533610684, 49.657163235449026, 53.57551297833843, 59.212209947647594, 60.10984436158211, 63.497485653046645, 63.745548109854425, 63.908977585454146, 61.251556104229344, 63.92426698438583, 57.76698520106655, 53.38730196799002, 49.548215481542776, 49.06640329668599, 47.018137670332386, 36.102809060004454, 22.545173821910737, 12.493531511675927, 3.8197043393888785, 12.823228297695039, 38.74480778171171, 41.71156698657621, 42.40857216619676, 41.992510672538515, 48.3855975058771, 43.076234094558224, 37.415065457743985, 51.59361385530042, 64.06688828622141, 54.97494797552786, 65.30774970208445, 71.59265364370039, 53.048130696819676, 36.753106655613074, 31.009699644580966, 27.094013191038563, 18.721286519881218, 8.632975932090513, 7.073587169570308, 4.262817684681186, 1.3885654965716026, 4.973520761536014, 6.118678306379627, 5.95230067929914, 2.093011534983112, 5.190020886159712, 17.741564742980465, 32.244208781949936, 37.87883866217829, 39.12858424648162, 39.763510073384936, 40.84070274906774, 50.44102145779518, 53.747971750074825, 55.15029753408125, 52.283590147572184, 48.72316060527679, 49.514008491270005, 50.61858715549592, 55.53104592907814, 54.827255049059474, 61.08754611784413, 57.362396640162316, 54.32946312812067, 50.395945579774924, 50.873505915364916, 52.28541797207248, 57.65207544449837, 57.159904280016505, 59.3735017315034, 54.7489566956797, 54.316099612943596, 54.68438271553286, 49.69647322931598, 46.177824774096095, 49.59166749831169, 46.45727403702275, 46.48310676697762, 46.383882568728545, 59.89459645363593, 63.480180155846384, 66.80489878500661, 65.91371274763539, 66.68836516718711, 70.63560316639563, 73.27298133603989, 69.42643057915473, 70.03442149008475, 62.2376399655496, 61.98593362685173, 57.00950491812922, 49.33963560288953, 27.72775838452001, 10.849550462538197, 7.782617355546645, 30.752284296097297, 54.58796301195699, 55.1722235833445, 62.65447808850197, 46.72507386053763, 28.244879745667983, 43.20944563035042, 43.74558264209379, 68.16119947741109, 67.34029446878742, 68.3280884835028, 50.918005204969845, 67.7353242135817, 1.711238788500909, 0.2655399867123173, 0.14204759391084795, 0.15024468873537358, 0.23384815502551295, 0.11312156179619413, 0.13488922238109574, 0.1685699408934001, 0.1137609004734024, 0.050859443482852755, 0.35523497048885594, 0.28347205190408614, 0.2227384858434239, 0.12215124097682777, 0.3028704400264448, 0.37283035535966197, 0.13449226626225058, 0.12502762534084821, 0.2150288067998425, 0.2771921533971064, 0.2623027136489268, 0.6101322186089332, 0.5493060631617424, 1.3402108848094942, 38.25310730165051, 93.59802892131191, 57.45959297303231, 60.95115353984218, 56.897262373278224, 82.80339948592648, 27.450448774522354, 75.11815055724114, 84.1917694768598, 69.59802642945321, 59.21262571888586, 70.01590005813107, 54.95991745302754, 40.14630594561177, 35.46369414175711, 64.69737791245984, 75.27015024615874, 68.32608022997456, 72.70197053109446, 73.42250993174892, 68.5230302810669, 70.4940918953188, 58.890642273810606, 59.824499776286466, 62.086193330826305, 65.52055005104312, 66.36656607350996, 60.59168792540028, 63.01230415221184, 58.84708043067687, 60.75581950526084, 61.72668457031251, 62.01050727598129, 58.39445460227228, 57.28265877692931, 57.02137793264082, 57.41699211059078, 53.89092645337505, 54.223770941457445, 54.48889963088497, 59.55591155636696, 62.5506333381899, 60.164871292729536, 53.998815167334776, 53.24902665230536, 52.94716496621409, 55.19860936749367, 60.0784497107229, 62.75720104094475, 63.08361284194454, 64.87077413066741, 67.2285775215395, 65.29675529849145, 68.91187052572928, 61.26997947692872, 56.41501872770248, 52.44088111385223, 49.83419941317651, 46.876971567830736, 38.690345671869096, 20.234560466581776, 15.609330977163008, 5.720999490830207, 15.302229004521525, 44.93399020164244, 45.53536407409176, 47.93256767334477, 43.35322010901667, 54.890346373281176, 42.8011308177825, 41.356670933385054, 55.82159942196262, 60.74281684813961, 55.87965834525324, 62.15514467608545, 74.45528568760042, 62.21222692920316, 52.868407695524155, 40.421887751548525, 39.456223749345355, 25.207231544679214, 10.521968814634509, 7.5831687546545465, 4.793289813303179, 3.132173154623278, 7.225844754326729, 7.633175542277675, 12.14753923877593, 5.1962697121404835, 10.812890029722645, 18.681182246054373, 32.41416900388656, 42.908748888200336, 42.0300869787893, 42.55480597096105, 46.408946514129646, 54.889420693920506, 56.07909125666465, 58.67284874762259, 55.76715692397087, 52.51076206084221, 50.36029515727874, 49.75704246951688, 53.5820907931174, 57.09253757230697, 64.86365502880466, 59.77720775911885, 57.881730218087476, 55.393225608333466, 54.58919855856127, 56.168517374223285, 60.00794118450534, 59.18103102714785, 65.40217291924262, 62.97793634476201, 58.921730979796386, 61.288151817937056, 54.31420118578019, 49.94552804577736, 52.76037385386806, 50.51761358014999, 48.519550369631865, 48.23447250550794, 66.09167068235337, 67.61082033957204, 71.1452288781443, 67.0856071287586, 67.58438356461065, 73.54400142546623, 75.56531644636586, 75.74476488174932, 73.04619773741692, 63.750223575099824, 64.14200167502126, 63.44956997902163, 53.38050842285157, 31.856898261654763, 13.84604319449394, 7.8203878191209615, 29.707645331659627, 59.20634600423998, 58.53218078613282, 68.73111201870826, 45.38086191300423, 31.422597746695246, 57.39122213855867, 62.52246287561233, 77.55311089177286, 72.71078017450148, 78.36113483675065, 59.91090566881242, 77.98690934335032, 2.0162546730810598, 0.29460566899468826, 0.3245348242982742, 0.22663540657489534, 0.4167954365332281, 0.14484787510047037, 0.25376052685802986, 0.2771461574781326, 0.3516299139347769, 0.13999389604695384, 0.4925868437895852], [0.11380331876176981, 0.07485147866029894, 0.028943954741642363, 0.04673620505679039, 0.06233698425574168, 0.07499665232195009, 0.052434451307260224, 0.011361685296099995, 0.008471827360711271, 0.03365307039911709, 0.251390342750857, 0.1119301341954739, 0.2265059683592089, 8.997858339740384, 67.2259416887837, 43.32692061701129, 53.992982602888546, 65.47093206836333, 64.35451961332753, 22.992686840795702, 26.150159528178555, 59.599328271804325, 35.60052994758853, 50.639552224066954, 55.47524629100677, 54.97680717898954, 29.60928405484846, 33.566059297130955, 47.85695614353303, 59.80764142928585, 60.064289954400834, 58.25862684557515, 56.629764572266616, 54.712600246552505, 50.85208977422407, 49.75958416538854, 49.247707013160955, 49.24713042474563, 51.54446263467112, 49.47760497370074, 48.97417660682432, 50.92122939325149, 50.77323836665, 52.37275346632927, 54.52937064632293, 54.1027932782327, 52.86033545770953, 52.15860774440151, 52.42299902823664, 49.809688521969704, 46.32687091827393, 44.375044607347064, 46.1422331871525, 46.66947818571522, 52.185530893264286, 48.12782718289284, 48.35582671626922, 46.32834180708855, 52.15472067556074, 55.35487267278857, 54.07803135533487, 56.06172300154164, 59.219321204770004, 58.0306508464198, 59.92170003152663, 58.713966954138975, 57.79664224193942, 55.66098228577645, 51.90346933180287, 46.654906580525065, 50.73561106958697, 47.99216416574294, 38.92937883254021, 27.929138752721972, 16.784180864211052, 7.8566643499558975, 16.577699453599994, 31.81467002437961, 33.96420340384207, 30.924735223093343, 36.934633947187855, 40.19063657329929, 38.946751010033395, 38.719120179453206, 35.285187075215006, 41.665647798968905, 41.03874714143815, 41.20583618840864, 39.75896404635522, 22.852956325777118, 6.4784282926590215, 5.410487507620166, 6.0477245911475155, 1.5644546261718197, 0.6116104618676248, 0.34736976027488714, 0.07704903251461445, 0.9900425134166595, 1.0109092162982112, 2.6862670817682823, 4.083721282020692, 2.6627549240666055, 5.014796843451839, 20.49572756213527, 27.3733094815285, 30.859270864917388, 33.83252943715742, 37.421129442030384, 36.99737225809405, 44.86726676264117, 46.50358938401746, 49.49915055305728, 48.20769840671171, 46.25666833692982, 50.05615457411736, 53.132551870038434, 54.45524177243633, 53.22883821302845, 54.11343859088037, 54.46517713608281, 49.12379541704732, 47.798261796274495, 46.51391306231099, 47.741654149947635, 48.867452836805775, 50.77037895879438, 48.046430157076934, 46.78878099687638, 45.35694329969345, 44.51310027030207, 43.62925690989341, 45.54577012215891, 44.13721169194868, 41.84005598868094, 45.69707947392618, 48.0595544076735, 55.54500172215124, 61.13890563288043, 63.3580610829015, 65.38329062923309, 66.68434866013067, 69.8956480333882, 69.21485008731966, 68.05192224441036, 59.694210406272646, 59.2671819656126, 56.75477050965833, 51.99798668584516, 41.663227696572584, 24.498792656006355, 7.820650617922507, 11.366716930943152, 29.788630508607437, 47.20251260265228, 46.09964016945132, 56.051065921783454, 28.676252211293868, 30.24773217016651, 44.040999873991936, 47.23085564951743, 52.03560613816785, 88.7113832658337, 38.42298515381352, 57.44265225625808, 63.49297492734848, 0.9099847318664674, 0.11547821679062421, 0.06821845958550131, 0.16046442421934298, 0.0813430625825159, 0.12582411929484338, 0.03063351186292787, 0.06622214170713579, 0.07345803367394595, 0.12022559470947712, 0.18859043837554995, 0.11448823967047277, 0.05801775755601064, 0.11721262452943672, 0.04121321291031857, 0.070080972547012, 0.03711793669349244, 0.04177501582871041, 0.04564802695606505, 0.031056145333775112, 0.074791785089239, 0.28985981559080465, 0.19136487175860714, 0.19882125149090446, 9.70255724845394, 74.43581504206504, 44.589300155639656, 49.69921496606643, 70.73132468808082, 71.39404835239534, 28.23366176697516, 38.708176766672445, 65.7966378427321, 42.895416751984634, 56.122147114046165, 62.19498418992566, 58.270703823335715, 33.459676773317405, 36.2477014141698, 48.67074597266413, 64.65696965494465, 63.42299592110419, 62.51250790011499, 60.50755700757427, 60.77333288808023, 56.96717862159976, 53.908177037392896, 53.50985642402403, 52.632430061217285, 54.298170458885934, 51.587506724942116, 51.756568724109286, 52.855836499121885, 52.67781188411098, 53.726135915325536, 57.24067372660483, 57.76842471091979, 56.723422927241174, 54.77975514627273, 55.488413687675234, 54.60226789597542, 50.06490930434197, 51.197803558841834, 49.402934812730365, 50.05427968117499, 53.50435726104244, 49.756218771780695, 52.922830581665046, 51.42873310273694, 55.43595198662051, 59.66301971866239, 57.14793712862077, 61.804633832746944, 59.68129796366538, 60.44644648028959, 62.51942303872878, 62.5103388294097, 61.10619306564332, 59.813179815969164, 57.30974274296915, 53.47650058807866, 51.672975170996885, 48.77235889434815, 41.63677130976031, 32.39267833771245, 20.936776514976255, 12.348006675320288, 29.443911044828354, 35.24643405791252, 36.184229620041386, 38.59028600877331, 39.009881557956824, 44.12305193562662, 40.34309125715687, 49.34113002592518, 44.86366994919316, 44.32647389750327, 42.53914394686299, 42.116771359597486, 39.99001518372567, 27.56058304540573, 15.860467591593343, 12.548179934101721, 11.90758235992924, 3.9158060858326578, 1.0781369863017913, 0.3623550529441526, 0.1519650004563793, 1.1643903966872924, 2.361439428021831, 3.6078370242349567, 2.932936852016757, 5.383035819376669, 11.27249179347869, 24.292250448657622, 32.56692178787724, 35.447871300481985, 39.35563456627631, 41.191652897865545, 45.116568688423406, 49.06526188696585, 51.29336426334997, 54.07672912843766, 52.70099309182937, 52.127558262117454, 52.98992664583268, 53.75563606139153, 56.087112503667036, 57.135801315307624, 56.67909229955366, 57.49934227235856, 54.2689174221408, 50.60923622500513, 49.58645466835269, 50.116527695809644, 51.67762317965108, 50.55239715883809, 49.52927435598066, 49.96031145895682, 48.249275530538256, 46.68995295801471, 49.672942930652255, 49.155715665509625, 47.26522737933744, 48.44008707231092, 48.058126664930775, 50.396498633969216, 57.59421263971637, 62.47652015378399, 65.33487289182602, 65.79448053913733, 69.35524740526753, 70.03531579048403, 67.77679935578378, 72.07387355066115, 63.69236077031782, 61.48494497422249, 61.599360512148955, 56.60064489610734, 44.529472243401315, 24.175403041224328, 8.728683725480112, 12.562326942720722, 32.96244182894307, 55.863815892127256, 50.68217269835934, 64.43667757895686, 38.116047920719275, 29.477910149481993, 38.18030811125232, 46.94265950110651, 55.878222757770175, 116.74817931267523, 44.46734974461217, 51.51501347941738, 70.85319272933468, 0.6775095902623669, 0.0684990163051313, 0.032019633048724745, 0.05972983000139075, 0.06477610478478094, 0.0718893307531553, 0.019504646432676145, 0.12788781460614937, 0.023835148031432784, 0.07557019936822115, 0.037695149470481186, 0.24798661410327882, 0.3030262010232095, 0.1926592845589884, 0.12744993407038913, 0.24056673079969423, 0.3047158845490025, 0.13635157697623776, 0.10618605290449436, 0.08296155355750554, 0.2410073386084649, 0.4190965807966648, 0.3726970254173202, 0.4645877091153976, 15.407696635492387, 85.9879247603878, 55.280426086918006, 73.09487435125536, 80.27013671013617, 79.26690424642256, 32.246481795464796, 32.0527284760629, 70.70979872057515, 48.05953479582264, 64.08463308888098, 68.1190339980587, 63.869063546580655, 35.13537214648339, 40.91612992748138, 55.8261219147713, 74.08676332043063, 68.06761172509962, 67.83706265111124, 65.98287197851366, 66.97305863903415, 58.78844099660074, 57.86226741729244, 56.356999028113584, 58.61798263365223, 59.41243125546364, 58.93566716101862, 55.683394708941066, 60.06239937197778, 58.607694256690245, 59.35362708184027, 60.081191447473344, 60.02708627331642, 60.23940809311406, 58.785008922699966, 59.006685595358576, 56.757559314850845, 51.31503143618184, 53.61022595436343, 54.3682945928266, 54.655035541903594, 58.87859667501142, 54.89749293173514, 57.165964341932735, 53.36140255774222, 60.040610605670565, 60.86568509378741, 60.40697566924557, 61.921587144174886, 62.83678593174104, 64.27129476301133, 63.86308193206788, 64.67897022924116, 63.72364559481221, 60.63039779663087, 59.05263616192726, 55.00751149269843, 52.999552142235544, 49.384358467594275, 43.22056554978894, 32.19167647823211, 23.001431765094882, 12.588668600205454, 26.749554564875943, 43.39415004176479, 42.748708340429495, 43.616242485661665, 45.0308217540864, 47.07945216086603, 43.521450565707305, 45.74943919335642, 40.28142375330771, 44.09459906239664, 47.55782834945187, 48.52886599879111, 46.03897286999611, 35.223594096399125, 23.123321379384688, 15.676280933041728, 18.113201472067065, 5.059780545773045, 1.1619772810128428, 0.456384715413855, 0.26428574756268536, 1.8894477549099156, 4.0635507385576926, 7.049812703363358, 8.669298060478704, 9.94230329990387, 13.028696756209097, 27.04186135722745, 35.78479897591376, 39.38119665268929, 43.60430671322731, 47.53399995065505, 50.00092367972098, 54.158820413774066, 53.93561009437808, 57.71021673756262, 57.08228841904671, 53.187417984008796, 52.86629353800128, 58.01304332671627, 59.163215621825195, 58.3946507207809, 60.615084863478145, 62.155972296191806, 57.318560231116514, 53.21444311449605, 53.46871076091644, 52.85910383347542, 55.771644115448005, 55.19501647641582, 55.43673646065497, 54.521161125552275, 50.237756390725416, 52.03857929475846, 53.53057438327421, 50.540143674419774, 50.09231098236577, 51.21146517415201, 52.069809206070445, 54.25678553119783, 60.792729008582334, 67.73086840106596, 69.05462126578055, 69.01550739042221, 70.59100581753638, 72.77661323547363, 72.47489667707875, 76.2990899239817, 66.9308147122783, 66.93152073890933, 67.56416766874253, 62.136807595529866, 50.15819895652033, 27.5584473148469, 9.913280702406361, 15.310521875658344, 37.28303455537365, 60.90126883599066, 59.224514422878144, 67.15395835138136, 37.670788303498306, 40.59924948600031, 59.482645603918264, 61.39495795772922, 66.32859753024194, 104.82673137418686, 52.57268451875257, 72.5159482033022, 82.84408230935374, 1.2825112261118428, 0.38534182754735796, 0.1672855791665854, 0.18068287882112688, 0.17231767366249717, 0.23028157140699126, 0.1347397739488271, 0.27700072334658715, 0.3089747511811795, 0.25595909194840544, 0.2249979089585043], [0.08616905644415848, 0.050616559136899254, 0.02703396156580458, 0.07742864440285391, 0.04172988175865143, 0.0132147514358944, 0.034910155565387783, 0.04536447483265112, 0.14065142931236377, 0.040544548387368845, 0.06789901624283484, 0.05653707047684058, 0.21428925616125907, 2.2781165184513217, 57.24873027493877, 58.151185281815074, 50.31806299763341, 63.6527487539476, 60.315000011074936, 36.64629267108056, 16.027571347451982, 36.123899644420995, 51.70926493983115, 42.27051258087158, 59.82106378001552, 55.082162041817945, 33.39320044363699, 25.26839110159105, 46.07075583550238, 63.376715875441036, 62.13228510272119, 64.67611866612589, 62.890098787123165, 57.37830577358123, 57.7802114332876, 55.433943733092285, 55.05126160960044, 51.95634680409586, 48.35698381547005, 46.90454190777194, 46.82656911111648, 46.14619085865636, 44.3638462405051, 45.538702011108406, 51.115041548205966, 49.8201455608491, 53.998689651489265, 54.93489273132817, 52.28323713425667, 52.91223233745944, 46.85983473254789, 44.03584195721535, 43.468427965717936, 45.449691664788034, 43.44142636945171, 44.1863589902078, 46.44921356631864, 50.31521535688832, 55.723226378040934, 58.456188786414366, 56.980604894699596, 57.15121623008483, 55.88734226842081, 60.56380379584528, 60.09749281790949, 57.79004481530959, 59.48684254000264, 58.63047930502123, 55.14259007669265, 51.924975687457675, 48.1574724566552, 48.49772237962293, 45.0047105358493, 37.707964527991514, 20.716596226538382, 9.654933791006766, 30.43878297651968, 20.547944115054225, 20.7410482821926, 27.042320274537612, 27.304073764431863, 29.979626401778194, 28.749498551891698, 39.07708744848929, 39.07754636579944, 32.91090580724901, 22.96048418168099, 20.48376629429479, 18.758266625865815, 10.890853020452685, 3.6649312896113244, 2.315614132150527, 0.7161738026526667, 0.056083021655438416, 0.3281126387657658, 0.3678339605610217, 0.17475132049331743, 0.3594819474364481, 0.6425277480194647, 1.8248316092837242, 1.2827731668949127, 3.0864515564134045, 16.107399425198956, 19.81102881893035, 23.19807783249886, 27.38843806328312, 32.21501850312756, 34.067526478921216, 40.28021566329464, 45.81841799520677, 46.47757622503465, 45.99256338611726, 45.41104062911003, 50.229539025214414, 51.23265381782286, 54.785446505392756, 54.2851834912454, 54.42026207523962, 55.57399196009482, 54.032669144292036, 47.82136063421927, 46.8654437218943, 48.28741665809385, 47.16124534606934, 47.25096171902072, 43.81540083116101, 43.56522421683035, 45.34603911061441, 43.04828720708048, 42.962967811092255, 43.35589908784436, 44.766175516190074, 46.281089013622655, 46.09501961738833, 47.11296881398847, 47.70298350241877, 54.147574978490034, 60.827991116431456, 63.33681360367806, 65.16050392581572, 64.59584343817927, 67.93414131287606, 66.30767560774281, 64.21980580975934, 58.520817679743615, 52.557430421152425, 54.31812747832268, 48.93452144438221, 40.39271708457701, 21.738220683989987, 7.750338700509841, 9.338657394532236, 26.94573190904433, 48.14135151524698, 42.71591340341876, 50.81935367276592, 27.2293447679089, 37.57891462695214, 35.28897216243129, 45.18691247509372, 23.40281771075341, 50.16199188847696, 39.93317611755864, 38.8122647039352, 58.51445951769429, 0.22249932851522203, 0.07230740025519364, 0.12223374864627277, 0.033359199071363095, 0.028215518123620463, 0.06441006031368049, 0.030499145786668506, 0.028679623764248627, 0.029744227424324043, 0.04582608877230556, 0.06268339389334283, 0.054849631588665716, 0.11945264263739509, 0.05815688678393922, 0.06430433251925054, 0.048447296909627416, 0.08155461776280597, 0.019020463542772398, 0.03825686428876173, 0.1287968775197383, 0.012509059010734482, 0.03657127933336362, 0.09543100582255472, 0.30578672224956177, 2.0815866512636987, 62.593810789046756, 62.439708709716804, 52.82587743574574, 67.64411341759467, 65.10096234659996, 36.11394074655349, 23.063220862419378, 46.14567310579362, 64.43867406537457, 47.20099464539559, 61.65476006846274, 59.543493332401404, 39.103798789362756, 24.080689568673414, 44.34540325595487, 66.04366871618456, 68.23144128245693, 68.40551607070431, 68.34164419481831, 64.54843767227666, 63.01349263037405, 58.66373315934212, 58.513204359239154, 55.229619626075994, 52.31932686221216, 52.90152426688902, 49.04827410174955, 51.85747169679212, 49.80379712197089, 47.71427992851504, 52.641984954957046, 53.39087916958717, 55.428291597673976, 58.61432698465163, 56.12531246677522, 56.57063484191895, 52.87369505051644, 47.453818859592566, 48.421122412527765, 48.007437875193936, 47.8492957545865, 47.24458786749071, 48.743490249879905, 54.47457513501568, 59.4222411032646, 61.234634999305975, 63.09537995246149, 59.68788754555487, 58.67772817611695, 63.65638479109734, 62.59462271967242, 60.579002980263006, 61.37575011099539, 62.2295638053648, 56.799932679822376, 54.61301519024757, 49.576582062628965, 49.43098368183259, 49.889273412766, 42.80743798901958, 29.850331352603053, 20.791562526456772, 29.20258329760644, 21.992535398852443, 24.079985503227483, 28.588918678222168, 28.41663641314353, 20.056945739253877, 23.72910595709278, 34.82011556625366, 35.43529618170954, 27.392729136251635, 19.663890907841346, 20.21858661405502, 15.922695013784594, 10.434672544079444, 5.582652591889905, 2.50692724700897, 1.1889584074097297, 0.2068783360863886, 0.16234690143216043, 0.28553114302696725, 0.17907348130979847, 0.1402048460177837, 0.4014425748778928, 3.057577273538036, 4.109638588082406, 9.512165400289721, 25.1446089436931, 23.758388411614206, 28.964452282074962, 33.839899570711204, 35.84373651012298, 37.95894915057767, 47.136710920641505, 49.23075845164638, 48.917812147448146, 48.47838901704358, 50.33763954716344, 52.867674212301935, 55.90755424191875, 57.84825671103693, 55.63174101614184, 56.74667473762267, 58.602379445106756, 54.81575858208441, 51.08615329188686, 50.04641925134967, 51.783044722772416, 50.2631341257403, 49.58892183919107, 46.34221130801786, 46.872182353850334, 47.96476641008931, 45.918085421285326, 46.51128115192537, 46.61833440103839, 45.267324985996375, 49.683462727454405, 52.901783143320394, 52.33856608790737, 53.23667510863274, 58.94712832666213, 63.809769076685754, 67.00894832611084, 65.39956062070786, 67.37197153029904, 70.73883210459064, 69.95543279955464, 67.59108297286495, 60.675379537766986, 60.57295076308712, 60.10710262483167, 52.107397279431744, 42.46188109920871, 21.801453213537894, 7.343882601107321, 11.26026576565158, 35.5550108417388, 57.732119252604825, 48.27253126328992, 55.94569929184453, 32.7706261604063, 38.81308447930121, 30.103596833444414, 47.27926161981399, 26.09068266807064, 53.05864264888149, 46.52502121463899, 45.61655321428853, 63.894076501169515, 0.1589437856549217, 0.015709045617240333, 0.10365967113043993, 0.020834373971146923, 0.041544193537124706, 0.04230752737531739, 0.045626944216388854, 0.02631169387079295, 0.043017365293757576, 0.06589197313352939, 0.10936387754496067, 0.16515358711682981, 0.23285746544359193, 0.09115095685927138, 0.11115921991727046, 0.1996542495344916, 0.1336771027455407, 0.15725166596952947, 0.17257256643666377, 0.17260933865702924, 0.1299867039966968, 0.3016082335624003, 0.255276553573147, 0.5009391633493285, 4.06841594846018, 80.43879078280541, 70.85636200443392, 68.83162667674404, 74.79302529365786, 76.86990461041852, 48.09428699554936, 21.57434601937571, 43.46063421618554, 64.64397876493393, 53.99197847612443, 71.19241499131726, 64.77556643947479, 41.73579938950078, 34.330619458229314, 54.099172930563654, 72.22749710083008, 72.14317398686563, 73.51070834744361, 69.41536165052845, 67.09951585338962, 68.08354439273958, 60.7933565878099, 62.91793584823609, 58.55602095204016, 54.79839424933157, 54.71458888822987, 54.02360454682381, 54.40657692570841, 54.48682077469365, 50.93293374584567, 58.48715197655463, 58.60627828105804, 60.03699025800152, 62.361296607602036, 60.9522282692694, 58.52949004019461, 55.9245498718754, 52.01243669755998, 50.57692373952558, 51.441084646409564, 53.17256396816623, 50.857514412172385, 51.572923352641446, 55.77688047962805, 62.66392707824708, 65.1768405975834, 64.87278238419565, 61.97783785481607, 61.39186713003344, 65.21676248119724, 65.17570311023344, 62.64417009968912, 64.55101859185004, 64.82365469778738, 59.01883709815241, 55.91630504977319, 50.50756054539835, 48.735876929375436, 49.43574936159196, 41.25011582528391, 27.954149746125747, 24.009602492855443, 41.342852423267985, 30.345003028069776, 32.39082305662094, 35.84056331265357, 31.9378089135693, 35.797464309200166, 35.82578382184429, 48.669482969468646, 46.5777261026444, 42.5217874588505, 36.18966994747039, 36.75737419436055, 29.13114909202822, 19.601746836016257, 14.874588674114598, 5.792306709674097, 1.3973876425335485, 0.1792801105447354, 0.46364036478823234, 0.4672216726166587, 0.19636708882547196, 0.6482584534152862, 2.7987802701611675, 6.838230740639472, 8.38231392445103, 17.504228007408884, 28.145716344156575, 29.140804006207375, 35.09725455314883, 39.42882991606189, 40.539017569634225, 43.43945733962521, 52.51864994725874, 54.22088799938079, 54.18575140737719, 51.71676058923045, 52.43473868216238, 57.46295836664016, 59.93116078838226, 60.87851908899123, 58.61087529889999, 59.16771458041284, 60.251732180195475, 58.847998265297186, 53.50655378833894, 55.07079893542875, 55.59790665103544, 54.52276145258258, 52.74337430154124, 50.90491233333465, 48.81705822483186, 51.15210010159401, 49.00423765182496, 48.43969483529368, 47.17515407070037, 51.58999743000154, 51.15955260492141, 51.992334550426854, 53.489197300326445, 54.553575592656294, 61.14314179266653, 65.95640382459088, 69.31196012804585, 69.94432464722665, 68.02597968809067, 72.08434627902123, 73.54942214104437, 70.284315693763, 65.64407333250969, 64.51887869065808, 66.59667584203905, 59.35898503949566, 48.8495550617095, 26.20735356884618, 9.737301603440317, 11.647430177657835, 36.75031785042056, 62.040180006334865, 55.46255742349933, 61.769638446069536, 37.614223803243334, 50.2785921865894, 48.528716948724565, 60.088247791413345, 34.23727881523871, 50.913906328139774, 55.156969485744355, 54.94336505090037, 75.601284580846, 0.5750408564363757, 0.17331723454258136, 0.12644089668268158, 0.10771056021293325, 0.14303244590278597, 0.1606147459918453, 0.2028905266835805, 0.10715671694807469, 0.18066394112763867, 0.15905169679993586, 0.20815120649433907], [0.08980488675015588, 0.056874279398471124, 0.0758176917330392, 0.08873510625093214, 0.09261496620432985, 0.1002169103031197, 0.003970188901744663, 0.049578299325320034, 0.025046612661812576, 0.05943960525215634, 0.10021119528720457, 0.0282102627604599, 0.02955308274155663, 0.23759976419950687, 41.351018797966745, 61.92111645975421, 33.65442245237289, 48.27680272440757, 64.78624313108384, 47.61323575050601, 25.938573152788226, 29.058016500165387, 41.752332179777085, 32.80508810474027, 49.43669073043331, 58.817544983279326, 35.31962940769811, 11.07311281465715, 21.421144124000303, 55.85084461396741, 71.36697615346601, 65.40033725000197, 65.04820646778231, 63.705685061793176, 64.93606982692596, 61.08952299241097, 60.323378193763, 60.007898038433446, 55.65997815901234, 53.677694643697436, 52.010299005816066, 49.92748906535488, 50.094542810993815, 45.012488595901, 44.36548186886696, 44.82621523641771, 47.69109479842648, 52.89540536942021, 51.61206468459099, 50.558755320887414, 49.94715975176904, 45.649308927597545, 45.441682184896166, 43.43617431579098, 42.412776947021484, 46.14381782470211, 48.23359781695951, 53.19921255111695, 56.418380198940156, 54.83812393680696, 57.90102827933527, 55.789204566709465, 55.302461962546076, 58.86995569352181, 56.41985501012495, 58.01374150860695, 55.50360894972279, 57.13231825059461, 57.8101195058515, 51.66662093131773, 48.24288991189773, 46.996674460749475, 46.34311345315749, 46.02353442099787, 41.66246283438898, 32.13118568543465, 24.39197474910367, 17.18856938423649, 16.773751281922866, 22.810722204946703, 20.02968918892645, 7.772265240069359, 12.648263131418537, 19.350881845720355, 17.996238354713686, 13.811855816072034, 10.068342781835987, 10.613846413550839, 8.589392515920824, 2.9678226574774715, 0.7738708260078585, 0.5366877370303678, 0.11526796395980543, 0.14507787001709785, 0.20889694712335066, 0.1232036236192911, 0.0487932124205174, 0.18817267530868131, 1.2141839054323014, 0.8269705250859262, 2.1878517491202203, 5.9239022289553, 17.758936920473655, 17.087464409489787, 22.347119623614898, 26.093798991172548, 27.790461394094653, 33.72748444157262, 41.55650784892421, 44.0360184638731, 44.43347223343388, 42.79300758915563, 47.01472913065265, 46.825133523633404, 51.12587121225173, 53.04896223929621, 52.96065791960686, 53.48057593068769, 53.74696762331071, 50.85850677182598, 50.23133154838316, 45.39983441752773, 46.784497768648215, 46.02054165255639, 45.53941196010959, 44.45440984541371, 44.19372912376158, 42.96828654504592, 43.71115992146154, 44.59836475310787, 43.73658080254832, 44.85536236916819, 52.725613809401, 56.15902523840628, 57.83910582142492, 53.04475745847149, 57.5266537358684, 63.15441554592502, 61.7827352400749, 63.38642374161751, 67.61298548790717, 65.49463887368479, 69.1228626620385, 56.04986567651072, 49.459291427366196, 53.625189796570815, 53.55296327221779, 45.52436574812859, 37.4369679727862, 13.777328172037679, 3.5502669263270596, 6.730460188081188, 38.3758500314528, 47.966041180395315, 48.66187749370452, 32.016944692980864, 30.79502832505011, 34.64618198333248, 33.9344875274166, 40.2071419069844, 24.794094177984423, 10.25907293442757, 34.88039062869164, 53.8610105360708, 54.774283439882346, 0.19282285965258078, 0.015997027644076418, 0.032520811599228656, 0.06885130949799093, 0.03363868709833872, 0.04270690816244291, 0.020995306061400522, 0.05064971159182249, 0.07257147076269312, 0.046427793380233555, 0.09249345699865973, 0.014511956626759663, 0.04199474516715254, 0.0831817731922192, 0.027785363584576596, 0.037402028908892986, 0.08389043516569561, 0.027987425020265005, 0.03195988776672992, 0.04085176113632418, 0.01984480479281516, 0.08639686801020177, 0.021674607715178883, 0.07782573841752545, 0.17147277061256672, 46.14780687516736, 67.12493281210622, 38.14641491059334, 56.98685715275427, 66.22953414916992, 45.37323682538925, 29.33087814238764, 38.75275842605099, 45.284814834594734, 42.108483391423384, 54.921082065951445, 63.277024915141446, 39.113820445153024, 14.103004528630166, 13.84830444089828, 49.66330958950905, 72.6640647457492, 68.59335053351619, 66.46952044579291, 70.13953316596248, 69.04992226631411, 64.71873129567793, 64.08422124001288, 65.59141551294636, 60.70157312577771, 56.72529389781337, 56.34616936406782, 53.91563738546064, 53.54748372108706, 49.95351791381837, 49.69655167671942, 46.297523744644664, 48.876148731477805, 53.519630970493445, 54.89244091895319, 54.63017555975146, 54.37156192718014, 49.86260521796442, 50.69967039169804, 47.836038143404075, 47.27278186428932, 49.04231994382797, 52.56408276096467, 59.53043183972759, 59.818933933011955, 57.73684570866247, 61.69916914355371, 56.9053973690156, 55.91165704111899, 61.90396393499067, 61.84370848440356, 59.675151609605365, 60.03049089062599, 59.83467440451346, 60.40415940746185, 55.71294192344912, 50.461657047271736, 48.29376697540284, 47.32026607759538, 47.465891914982954, 45.127233612921934, 44.74776783297139, 39.29501825763334, 32.194112270109116, 29.61099420824359, 34.85621706131966, 23.944538216437063, 8.093286233563578, 5.696330724223968, 10.502504052654391, 13.327334254018723, 7.6105812191963205, 7.799065814864251, 6.5016178354140255, 6.923621229587063, 2.784631790653352, 1.5031297168424054, 1.017136775678204, 0.2311637829388342, 0.15603729403547703, 0.1445586769090545, 0.03021992397524657, 0.21852970603973637, 0.035669819842423164, 1.6522245229251924, 2.148380692928068, 5.805515781525643, 13.818722905651217, 23.299314206646336, 24.81238615128302, 30.207510225234497, 31.320015999578665, 33.06770255488734, 41.1894210692375, 46.670831403424664, 49.75986265367078, 49.13202454966884, 47.21054953913535, 51.84939161423714, 50.95684059204594, 55.22818011622275, 55.203390736733716, 55.02314213783511, 55.62708124037712, 58.086258288352724, 54.38899294022591, 54.815554618835456, 49.33150845189249, 47.122449182694965, 47.694895575123454, 49.616817735856586, 46.290216369013635, 47.73706105447585, 46.95347739804176, 46.94329100270426, 46.99876508405132, 47.73116965447703, 51.181204088272594, 56.467245086546875, 59.37720444894607, 61.38705830420218, 57.9109557982414, 61.058634327303984, 64.11998541124406, 63.2940480016893, 64.5393495405874, 71.17124988186744, 68.39622005339592, 73.34757697197699, 58.43697701731036, 49.93085445896272, 54.42393733609108, 55.926071751502256, 48.774347536025516, 36.331291044912035, 10.663769360511534, 3.321779303012356, 11.27576599198003, 49.557986105642016, 52.31501225502261, 53.79356538095782, 36.39607683304818, 33.47453863390031, 30.542745397936915, 32.89942110738447, 40.751100124851355, 33.732756107084214, 16.07790025972551, 34.763005856544744, 59.24734261728103, 64.19626374398509, 0.962593705663758, 0.08186620104336932, 0.003520235299102722, 0.06619543588209538, 0.04868203008006658, 0.10090924694292969, 0.020450636699435212, 0.05231668827153983, 0.03877850121728355, 0.11430083158155603, 0.028703435692155076, 0.17469124387829535, 0.12862688260934046, 0.2315672048397603, 0.16387078820938067, 0.2070156343641781, 0.1378492635464476, 0.1574931215615042, 0.1574636118546609, 0.10176529657215842, 0.16429936843774012, 0.20519761578930965, 0.09832117210833297, 0.36822071238871545, 0.4719171480786416, 62.112363384615996, 73.17676559571298, 45.89296264033164, 62.90554900323192, 80.8623989166752, 63.73833879347771, 33.56292924573345, 37.51286191325034, 49.78156120546403, 46.51294423687843, 62.47066797748689, 69.8597740357922, 43.38797623111356, 16.48066197672198, 27.22528707596564, 63.199150177740286, 77.6935552781628, 71.62730386180263, 70.01958708609305, 71.9024424399099, 71.66737479548301, 67.30175325947424, 67.81011596802743, 66.00128358410251, 62.85384431962044, 58.900448199241396, 59.99544451313635, 57.16353639479607, 56.32389422385924, 51.91476575789913, 52.9964417026889, 51.49241278248449, 54.48487527908818, 61.53033856422671, 59.10163441011983, 58.86523315983435, 58.51852309319281, 51.006705684046594, 52.200204480078916, 49.06695242851011, 48.43071652996925, 52.67292853324644, 55.891876528340006, 59.3458019533465, 61.603192667807306, 59.327362891166445, 63.68997204688288, 61.38460682284448, 57.29171945202736, 63.911687943243216, 63.15681603647048, 62.121027900326645, 62.077116966247566, 62.733502080363614, 62.24879518631966, 57.98406093351303, 53.44470977783204, 49.53893907608525, 46.96549946261991, 47.76878126205937, 42.734481903814505, 44.98909558019331, 38.94695497328235, 33.59865811563308, 35.48969553362939, 37.70022176927136, 27.690629228468868, 14.275912411751287, 18.731565090917773, 32.55794348255281, 33.75379962305869, 30.484543308135006, 24.655661967492875, 19.892976937755463, 12.849121824387582, 8.5611867520117, 6.851463346712052, 4.133565781577941, 0.4254187367135479, 0.24479446361862847, 0.40372389278584914, 0.3580078716960646, 0.3715424696283956, 0.6310659082185838, 4.6642104944875165, 8.33410015029292, 12.773316137252316, 23.578651682023082, 31.699823025734197, 32.00284573339647, 36.591567762436405, 35.86780417350031, 39.07609901120586, 48.03090933830508, 53.49882671909948, 54.93960349790512, 51.94304996921171, 51.10967182344007, 53.46761641963836, 52.890298443455855, 58.2563675603559, 58.96087231174592, 56.10559471191899, 57.50455510231757, 61.22367197467435, 56.17684456609911, 57.305396756818226, 52.72102855866956, 52.629813840312345, 51.18519313873784, 53.40880440127466, 49.99273377080118, 50.30190675489364, 49.62861622533491, 48.66250899530227, 52.0019914257911, 50.37176024529242, 52.6992594042132, 59.072899126237445, 61.284625607152144, 63.91815200928719, 58.45978559986238, 63.203056858431914, 68.5671491007651, 66.70613350406771, 67.3153325050108, 73.40161938821116, 70.15777218726375, 74.14125288686445, 64.76062613148844, 63.24469281781105, 61.28758307426207, 61.66253420614428, 52.23854957088348, 42.6605099247348, 15.204221721618408, 4.922019060580961, 10.641651115109845, 49.27156679091915, 60.23557593745571, 58.41348594234836, 41.725977774589296, 43.40838824549029, 44.70728897279309, 49.29619143086095, 54.68281768983411, 39.312119791584635, 13.252400313654254, 47.015603819201075, 72.12328757009199, 72.83172253639468, 0.8122738330594955, 0.17304219365600618, 0.17009775004079267, 0.29429387120950606, 0.255432008134742, 0.18523082107065186, 0.12467894042211196, 0.1862917915587464, 0.22401746963301014, 0.29267665960135003, 0.18286719467611084], [0.019466282664647987, 0.04492472121191602, 0.02269057053772192, 0.11405095668329347, 0.05692366142607024, 0.012704985997369213, 0.034569801852828076, 0.08963548938833898, 0.050160120121173324, 0.2144886382044323, 0.03414291850922089, 0.11736028031596255, 0.09538382246729829, 0.2118548738860315, 24.52914787876991, 72.95160585834135, 39.261117212234005, 45.41209966905656, 62.132598892334975, 42.00690577107091, 30.388564871203517, 20.958600582615023, 32.15647908949083, 34.30969361336001, 40.97695019937331, 55.72343426366007, 43.62084734824396, 12.544806695753529, 1.4975597060495809, 10.166340258813674, 49.15076171198199, 71.0406663340907, 71.34258685573455, 64.58529226241573, 65.42431862123551, 64.22757210270052, 64.70301435839745, 62.65316017212407, 62.34915294954854, 60.13910132069742, 58.28743665449081, 56.65566790488459, 54.1403970410747, 52.49871253967286, 49.114656294545824, 45.515116799262266, 45.364831186109974, 47.44912770486648, 49.31828614204161, 50.04058276453326, 49.03126670468239, 47.55969539765389, 45.15681220639137, 43.515108093138664, 44.87761397515574, 44.735922275050996, 51.70470322332075, 55.06871223449708, 55.971229999296135, 59.56434072986726, 55.11607485432779, 50.374462758341146, 54.20686160364459, 57.07376510866227, 58.058907601141165, 58.048458407002116, 56.31670059696321, 54.665500425523334, 56.13065865732009, 52.3235708667386, 44.53490472608998, 42.85270606317828, 44.2792603277391, 44.80055509075042, 46.283760147710005, 37.962087046715524, 41.51130253268827, 33.66626801029329, 29.77156427598769, 32.26533662888312, 19.89568925672962, 3.6710582769686178, 1.3981960185112492, 5.021866425391167, 4.134967048322001, 3.3410754030750645, 2.0227259709950416, 1.7761879678695434, 2.218270465250938, 1.1787915013490187, 0.5641734395777026, 0.38838711897692374, 0.07058615390692027, 0.04133874790803079, 0.2406804642129329, 0.0392786493795293, 0.3646770654426467, 0.3316819956225734, 1.3076865913406497, 2.698587246479527, 4.282136828668656, 7.52441410095461, 13.201163372685834, 16.523835505208663, 22.10942202998746, 24.192294728371408, 25.634363928148826, 31.57998481104451, 39.62740382840557, 40.80222037530715, 43.09268843743109, 41.509364881823146, 44.994006387649044, 47.662998860882176, 50.53588790278281, 52.117481693144775, 52.352619940234774, 51.24522109185496, 53.904682205569365, 54.93883471335135, 52.14074527063678, 45.049821715201105, 43.217196233810924, 44.37835116540232, 44.78439100327031, 42.78514715933031, 44.29089015530002, 44.58068270837107, 43.33722468345396, 44.56389496403356, 45.084424864861276, 54.257554315751605, 59.2173521749435, 61.727688697076616, 60.12616142149895, 58.343248059672696, 59.64471401706819, 59.45013307755994, 63.70122140453708, 64.0499161904858, 65.28170908651045, 67.86835532034597, 65.87445766695085, 47.33308438331851, 34.129358722317605, 42.96836107007919, 43.582796435202326, 37.656244154899355, 20.90111824773973, 4.723311787651432, 1.55142022236701, 16.975723928020848, 45.162801665644494, 49.234174836066465, 40.98750921987718, 23.67543616602498, 38.87498340299053, 40.86271901284495, 30.987214657568167, 34.478179024111846, 22.245187028761833, 27.73459899810053, 42.90230835637739, 39.76064282078897, 59.71599917257986, 0.466431345670454, 0.06678290274595061, 0.07440899393611378, 0.012821013843941112, 0.037505623148453814, 0.1162220421998251, 0.021568979512179093, 0.11170205449865711, 0.024808841952753645, 0.08346335646966774, 0.06016643117031744, 0.11775595706797416, 0.02137947617278945, 0.0982240321595342, 0.038040153336741274, 0.057532168894765846, 0.02092657839849351, 0.05096592587388812, 0.06196861087735142, 0.01828541941640358, 0.07746475012672525, 0.033351813983773036, 0.0861814440858941, 0.0571523808063038, 0.11943883773299957, 30.57284958900944, 78.68686414534046, 41.63007582387617, 54.45953676777502, 68.73774082429948, 42.3854301821801, 29.22911617063707, 28.66165707188268, 37.921596419426706, 39.53476921204598, 48.701363994229226, 62.54796612647272, 49.157923959916644, 15.362219695122013, 2.6884677765830873, 3.85212101282612, 37.06702962998421, 66.78707553494361, 74.74816122362691, 67.40173447516658, 66.83940779778266, 65.84478885896745, 67.03849946298908, 65.81345696603098, 64.92993131760629, 64.7099647983428, 62.748312950134284, 60.59787742553219, 60.674740191428896, 56.338387381645944, 53.597344890717544, 48.57680128466699, 46.86623996303928, 50.38484527218727, 51.852753085474816, 52.301935072868105, 51.859742749121885, 49.354819097826564, 48.16515637982277, 45.89255079146355, 46.96325194451117, 48.49873435112738, 54.52955499772103, 60.34885398803219, 61.84637569612073, 60.12230965398974, 56.97785139083863, 51.42854090659849, 59.68184709548951, 61.532452721749586, 60.29827110229, 60.44814094420403, 61.55386101815009, 59.09553120213171, 59.67881510334631, 58.86915160763649, 48.31394364756923, 48.894446588331654, 44.80141801218833, 46.84047783574751, 46.137141950668834, 41.53442882722424, 40.96670889085339, 39.827887935023156, 31.03881932074024, 35.083094796826764, 30.023968796576227, 5.749126317039614, 0.8149360805269211, 1.1629724598700002, 3.5141247366705253, 1.8370244195384366, 1.864661807494779, 0.6197089918198124, 0.32921577473321273, 1.8861632601868723, 0.301010164041673, 0.17675042693172732, 0.1175391388636443, 0.06505748121848991, 0.18526993752006563, 0.11961533672987454, 0.20770926569258014, 0.6587059928044197, 1.303762750279519, 1.9397009164094927, 6.829382363826999, 16.787930650095788, 23.286564542401223, 24.69165755856422, 29.716431440845614, 31.251174480684345, 34.448051298818285, 39.83331649534164, 46.07698063696585, 47.14636779600575, 46.43796420866444, 45.64953250269736, 49.260470405701675, 51.696705510539395, 53.21439996842415, 56.88845665224137, 55.57752209324991, 53.43214642617011, 57.71705735114313, 55.6724238395691, 54.449530801465436, 48.11116887677101, 46.762842362926854, 49.18267411570395, 46.86361197502383, 45.524550099526685, 47.986719915943766, 47.965331231394124, 45.621820957429954, 48.94464115942679, 49.35836099809217, 59.93981745935256, 61.27397637213431, 63.985655999952755, 64.21598934358167, 63.14624917122626, 61.77542001970353, 64.77844545918127, 68.51475408000331, 67.52479491695281, 65.85091560117661, 70.74883414853004, 67.09658976524108, 54.25268273199759, 46.608587311160186, 46.42459677111718, 45.355040950159875, 34.15878042098015, 17.33672122801504, 3.1502589583396916, 2.8937898816600924, 21.528309160663238, 48.553851496788766, 54.35787677764893, 46.76821208769276, 24.89496773289096, 37.50684107503584, 31.10309716193907, 34.5294326351535, 36.61534517042099, 26.144723123119725, 23.41856602699526, 43.59110009285712, 51.22604854645268, 65.80413741450157, 0.8124542008003881, 0.11996476475389735, 0.04578524479462255, 0.06716194006824686, 0.07143929240203674, 0.08880952403189675, 0.008496633287699474, 0.09518999456157608, 0.02142098473174678, 0.053545500962964954, 0.08131686237550552, 0.2168331583661418, 0.06350765087371392, 0.18150691363599994, 0.15769584374802728, 0.19792950982528348, 0.13563644922068044, 0.10884934991237619, 0.12458630507030796, 0.09713687678618778, 0.3420657658528897, 0.22320207628992297, 0.16489503244238515, 0.16427646240880414, 0.40014987811446195, 42.637677807961744, 90.52769168730705, 52.170896530151374, 56.91790188512495, 79.49829270762783, 56.80037198528167, 37.751302796025435, 28.266301770364088, 42.07735153936571, 44.495351545272335, 49.981959019937825, 67.80383233101138, 54.189238394460375, 18.32529971676488, 2.717402611047991, 13.41323612197753, 59.55747265969554, 80.66933201205346, 76.510129128733, 70.5481892247354, 70.13641880404565, 70.26654735688241, 70.48819265057965, 68.62009325335103, 67.26719717825613, 66.42029470013034, 64.39999557310536, 63.55361869258266, 61.22330719424833, 57.15964148121496, 54.5802673216789, 49.832002885880016, 51.85408276896323, 53.282782570008315, 57.005617849288456, 58.51142360318092, 54.386274737696496, 54.01390844775785, 50.491718092272365, 50.42596347870366, 50.165694605919626, 50.10117161658503, 57.5303799875321, 61.78954055232387, 63.45810897888676, 64.60745757625949, 60.861350874747004, 52.44326983728717, 60.421100124236084, 64.75237738701605, 63.8474081408593, 65.10710085591963, 62.5198035086355, 58.95884444636684, 62.3282741731213, 59.303507035778416, 51.08957752104729, 48.387644983107045, 47.37683842259069, 50.07374640434019, 48.30156072493523, 43.19948281011274, 48.65875920941753, 45.2921300549661, 36.85428811657813, 41.67073903545257, 29.99619645457114, 5.971101580127593, 3.700434623226043, 10.69880691266829, 16.925990235420965, 13.336763631912971, 10.248941452272478, 6.27488277612194, 5.369246727035892, 5.053875907774895, 1.2545214377103315, 0.96221691297908, 0.2436841264246933, 0.23169140301404462, 0.3489532333708579, 0.36218050747148456, 0.40893427126349946, 1.559517465291485, 2.3791459875722087, 4.99303553373583, 11.661403621396712, 25.430475204221665, 32.74847261367306, 33.399809637377345, 36.56923378667524, 36.36544312200239, 39.12244965953212, 44.85101638301727, 51.96515252513271, 51.178046580283876, 51.06345845806984, 48.54972908573766, 53.47166038328602, 54.30734096034881, 55.66552831280617, 58.47390221011255, 56.64241813844251, 57.29118600968392, 60.89110989724437, 60.951165306952696, 57.24119540183776, 51.16581270771643, 50.60801636788153, 49.58112416728851, 50.59690821555353, 49.74372602278187, 51.34548079582953, 49.411030584766024, 49.35450923058295, 52.753556774508574, 52.10141174254879, 63.45825410658314, 63.78692127043202, 68.05593875146681, 67.16540382754418, 65.80363142874934, 65.07716532676451, 66.88365213332638, 70.22312671907487, 71.66988511239329, 70.66926494721444, 74.12149198593633, 69.82768904778266, 61.74142875979024, 53.22370775284306, 54.120440021637954, 53.956775203827895, 43.123027970713956, 22.594352499131237, 6.129051504596588, 2.8777125766200404, 22.413648905292636, 54.60175798785303, 62.34979229588663, 52.59599908705681, 31.49376915347192, 47.66416380482335, 53.51978394293017, 43.30715187134282, 48.72545519182759, 30.40592528158619, 34.98756939365018, 59.169385510106245, 57.925605850835005, 81.46164294212096, 0.9203481241579979, 0.29362164437770844, 0.136763364557297, 0.1558979732855674, 0.15858219215466132, 0.1790981646627188, 0.15295463283696484, 0.2591787909548129, 0.19498031646493943, 0.1818592681158935, 0.24046435080949338], [0.013715526832628154, 0.03946072549649304, 0.10191649168489442, 0.08339769507367766, 0.01046059831541272, 0.040726896465545705, 0.03457216523407448, 0.05740627000528959, 0.08141394103727034, 0.10593581794490738, 0.06341752829030156, 0.083379753294491, 0.1022042036657372, 0.09540754054943401, 31.57661745625158, 62.377629356999556, 55.72354016765472, 48.70005784496185, 56.68730966506466, 45.71601667711812, 34.486204193484404, 39.17000447550128, 29.35316308852165, 28.92078845731674, 37.4141986139359, 53.308834952692834, 48.468096717711425, 20.471736384976296, 1.9107453669271164, 1.856121581888968, 2.6927713521065253, 17.088788209422944, 49.62722378392374, 66.07352579793623, 66.33870940054616, 62.9280790975017, 63.27111390329177, 62.860394677808216, 62.06816219514417, 62.36246939628356, 61.092492226631414, 62.63096347931893, 58.6458706855774, 60.66131784069923, 56.876811135199766, 52.00271706427298, 45.97828595869003, 47.26631779824534, 47.06963446832473, 48.24664362015263, 46.46433038096274, 47.76392929015621, 45.08073391452913, 45.61628257074664, 43.83038428521926, 46.97406984144642, 52.70809258184126, 56.284666599765906, 57.49061892109533, 53.70708888576877, 49.16434487988872, 53.70824990733978, 57.11367914753576, 58.23532012201125, 58.405684348075624, 57.06488486259215, 56.23729221282467, 55.33682192525556, 57.02709282598188, 55.95747424710182, 49.58918071562245, 42.38619896673387, 39.337136668543664, 39.89923192608742, 38.8286288322941, 36.891236843601355, 28.093546859679687, 24.046231546709617, 19.658101489467008, 21.50169784022916, 23.405131909155077, 9.299910260785012, 0.7634549107282393, 0.22043449173290885, 0.7162334962237267, 0.5989903584122658, 1.168687966081404, 0.2505211547137268, 0.4292657238341147, 0.14624904991397936, 0.13315809349859917, 0.2172507375719086, 0.1218763609687167, 0.34630627701840094, 0.1474896067332837, 0.07484510480876892, 0.2182710594347408, 1.4841205626726153, 3.3529400825500493, 5.692303920945814, 3.2338632979700646, 9.267032954000658, 14.730069925708158, 14.800756919768551, 20.650904370892434, 22.744826386051795, 27.591122619567383, 34.09706584868893, 37.630587931602236, 39.31676780023883, 39.32963317440402, 41.547949237208215, 43.35153348984257, 46.133184279164965, 49.88089523007793, 53.493884532682365, 53.60134178592313, 49.665239395633826, 56.794943424963186, 51.52757290870913, 52.67700387585548, 46.34657690601964, 40.42642985620807, 44.70471589796005, 44.48697336258427, 44.02457298771028, 43.36374775055916, 45.73107465620964, 42.231410472623764, 45.54671933574062, 52.20346396969211, 57.05164294089041, 58.033733829375244, 60.7048051587997, 59.12516863115373, 59.40855595373339, 59.19064867881037, 62.24409226448306, 61.41006300526281, 64.20723853572723, 63.1355607125067, 66.09055672922443, 57.646795934246434, 49.8814522066424, 44.51137834979642, 40.541049357383486, 37.33170332447175, 21.163073739697857, 8.285211728465173, 1.0051292974141337, 3.7353770579061205, 30.899822288943877, 44.97057022586946, 50.29480334251158, 20.84630704695179, 23.86380014881011, 32.04084369444078, 34.391569168336936, 29.487923960531916, 31.199459991147442, 24.792527191100586, 41.77138313170403, 49.26838182633924, 47.226066435537035, 53.31520488185268, 0.5096393787572461, 0.06521559410518216, 0.10600603756404693, 0.11236647489450632, 0.07452491069993666, 0.0691940725570725, 0.07135284704066093, 0.007777504159152629, 0.05514818754407668, 0.06495558386368137, 0.03412172085635605, 0.05655449131623872, 0.04127331633841799, 0.16329073707663244, 0.10511395881973928, 0.02460643003183988, 0.033901612304391406, 0.11323571655779116, 0.08181617550191381, 0.08017605020394249, 0.05147598721387406, 0.11134258306194698, 0.08300505969072543, 0.04137955358131759, 0.2609713754105953, 40.69775589050786, 67.32237708184027, 56.853080795657256, 55.97822750768354, 63.22235099730953, 42.90177491403396, 34.51981890586115, 38.52712408188851, 37.43779951526273, 33.01530361175537, 40.53187885592061, 57.69110302771292, 55.36738111126808, 26.20095226072496, 4.333647845252868, 3.2483285088692946, 7.163420233034319, 15.414036166283394, 41.770104439027854, 68.17857557727446, 69.87161174897226, 65.74887906351398, 62.950362082450624, 66.05108199581024, 67.21157012447235, 64.73385987743255, 63.697122527707016, 65.53359193186607, 63.6610092655305, 62.8461290174915, 59.923978928596746, 55.67124320614723, 51.347112501821215, 50.30007893039335, 50.908987675943685, 50.966179755426225, 49.112695109459665, 51.22018068067489, 48.052278411003854, 48.11493435213643, 48.43937320093955, 50.699823364134765, 57.541409692456654, 60.455095306519546, 59.869603110897934, 56.52589628773352, 52.25318785636656, 57.820635380283484, 61.542293948511926, 58.862063884735115, 61.59220610895465, 60.78248770006242, 58.22418451309205, 57.11271816684354, 59.234300736458074, 59.02879207364975, 53.038948428246286, 48.647345112216094, 41.43569884761688, 43.73386652238908, 42.52691399666571, 42.739384866529896, 33.55331159407093, 27.468415191096646, 22.643999899587325, 24.574559119439897, 27.0023101375949, 6.0401436301969715, 2.108297011544628, 1.2257461946818138, 0.515511289479271, 0.9152814637749427, 0.13428140822197163, 0.18632879360548912, 0.23903861521713196, 0.10640133127209642, 0.4771481189996966, 0.13802353322746294, 0.06126082607454831, 0.05345320652028727, 0.09321237688944226, 0.05378745451209046, 0.43183006526481726, 1.8660025226493038, 3.9269326242708393, 10.64228948085539, 14.693127082240197, 21.66843387388414, 23.559994928298458, 24.40406153278966, 28.139120878711825, 30.61486601829529, 35.06937826833418, 41.206859927023615, 43.38813704829062, 45.1117520178518, 45.101294978972405, 45.58930058633128, 47.097251876708, 50.456526587086344, 51.74163626086328, 56.47515258481426, 56.41563061744937, 50.902209820285925, 55.45402626837454, 57.76906797962805, 56.12156660326066, 48.22432141150198, 43.24474696190127, 47.82989178934405, 48.48741439081008, 45.854013504520545, 46.783929024973226, 48.98261362506498, 44.85535844679802, 49.82552705272552, 57.12003338721491, 60.743573865582874, 61.6767410309084, 64.08716301764211, 63.74924690492692, 62.75645186824184, 64.22246517673616, 63.31543668623894, 65.04702191199026, 67.32143571299892, 65.2728876759929, 67.73250010705763, 60.912820216148134, 59.18473766696069, 55.84864024193057, 52.64757433245259, 42.50929863222184, 20.753227241577644, 7.912191383300289, 0.7758989365350816, 6.09859331961601, 35.17022632783459, 45.01642665555401, 53.565714897647986, 23.58241911857359, 21.942260419168782, 25.902055886483964, 22.661058287466727, 32.15507095859897, 35.534092841609834, 31.050862958354337, 33.25195197136172, 50.81967138474988, 55.294189683852665, 63.63421947725358, 1.039191282564594, 0.22144652452440033, 0.062354324655907775, 0.024699716558379513, 0.03442446731271283, 0.09960658337560394, 0.04636296702008094, 0.0117137256799446, 0.1368919907197837, 0.018589812961797562, 0.041913168294535535, 0.22423168313839745, 0.11790033399818406, 0.31531440454625315, 0.21472491504203892, 0.0947926783814065, 0.11829328347718525, 0.1793760400746138, 0.11288865574545438, 0.22769622384540497, 0.18036167347623458, 0.20075064392820482, 0.22766887450650816, 0.22631754137335286, 0.48669620987869083, 51.4423398048647, 81.01484575579244, 68.5332441329956, 60.720686835627404, 70.10820127302601, 57.256249458559104, 46.51517998787665, 49.07103953822967, 38.43807451186642, 39.694162568738385, 49.05808394955051, 66.75078576610935, 59.84653957428471, 28.86732655186807, 5.1420694205068775, 2.821482703570397, 5.944406909327354, 31.7430789239945, 63.67772640720491, 76.39388576630624, 70.82661474904707, 68.12584323267784, 64.88891901508455, 69.23029638105824, 67.61194998218168, 67.96533984522667, 66.25764185382475, 68.2813887442312, 66.15743314066242, 64.98416985234907, 59.361020749615086, 56.7940491245639, 52.26590810283538, 55.99547024696104, 54.255346021344586, 53.9376614939782, 52.40901185620216, 56.00462505894323, 51.73527025407361, 51.72795111133207, 48.95037958698888, 52.04701631299911, 57.72357240799935, 64.31101660574636, 63.71760514474685, 60.80878326969763, 53.519705495526715, 61.12874277176396, 64.82416852827996, 64.98259698190998, 64.45800742795392, 61.23097150556503, 61.167331049519206, 60.84183316076956, 61.760032561517534, 59.26974719570529, 55.30902801021453, 47.209380672824004, 42.048490739637806, 46.4863113434084, 47.42427164508451, 44.35542883411531, 42.20765659886022, 34.44798854089553, 25.949963715768632, 25.803394548354614, 33.70045146634502, 13.761800489118023, 10.44699368938323, 2.300829493230389, 1.0310852143072313, 1.9988000032401856, 1.6015934655743262, 0.2928418281578249, 0.5014020030296619, 0.2731826024190072, 1.032504744587406, 0.4494253582050724, 0.2599933875664588, 0.3937983657083204, 0.3588915387949636, 0.17991885933424198, 0.5136504925547108, 3.4002139587556166, 8.098525049224977, 15.796791834215965, 19.23367161904612, 29.15091979888178, 32.0392963194078, 33.438495974386896, 36.26685042535105, 36.33144401734875, 43.20944563035042, 44.69765563164988, 46.28836893266248, 48.7346217709203, 48.5580405881328, 50.43946819920694, 49.79605828562091, 52.666091842036096, 55.687195485638036, 59.442135364778586, 60.49809232834847, 53.857562772689334, 61.37828003975653, 59.29945914976059, 60.03060071699081, 50.39160743836434, 45.3892400956923, 51.39691091352894, 52.695760650019494, 48.72080326080323, 48.74099170008014, 50.714092946821644, 45.22590083460654, 51.42439496132636, 59.47742885158908, 61.962713195431625, 63.10310309933078, 68.88521409803822, 69.33208973177018, 65.35643808303341, 65.94435430342152, 68.26180042759066, 67.51505174944478, 70.79444346889373, 71.25289009463403, 70.7979892915295, 61.547930394449544, 59.25507753126083, 57.23165227520851, 54.62922634616975, 47.10288047790528, 26.63810826116993, 11.74089437530887, 1.0550790880956957, 5.470064388167474, 38.90149470298521, 53.35273804203157, 63.4362417651761, 30.48114065201052, 31.416651433514012, 41.15076611118932, 45.832475769904356, 41.15263708176152, 43.983666589183194, 35.222507599861395, 51.68198485528269, 68.78517012442313, 59.597457301232126, 73.35690436824676, 1.1481184440274392, 0.3460739072292082, 0.21526137577189555, 0.20597545550234858, 0.17651140749935182, 0.2331319700686201, 0.2173613453464162, 0.15865762117168597, 0.23108631612793093, 0.16770429218248015, 0.12039712945660276], [0.03446212053419121, 0.05725172708832449, 0.03708182713918148, 0.10897496534932045, 0.04407354773232534, 0.11099958251560889, 0.1109185457349785, 0.034727056721045126, 0.06481466965088922, 0.02982496734588377, 0.08827513940031491, 0.035430884679719325, 0.08543368864564166, 0.09155241757511132, 32.37252519976708, 68.78735880697928, 49.05368697258734, 43.7270337535489, 57.87187722421462, 52.10786011911208, 39.45939302444458, 57.71876750453826, 33.98959682833764, 26.871910941216257, 29.607917108843406, 47.26170901329287, 53.95200952406853, 31.93341389779122, 5.01704240037549, 3.8675202381226326, 7.607872332296065, 9.511803561641324, 10.09006682903536, 22.289384295863492, 42.11458659941151, 56.896921127073234, 60.45054535711966, 61.193395199314246, 63.876802382930634, 60.579571723937995, 60.64510276240688, 60.126173188609464, 59.90880720077023, 62.50292554978402, 61.45617438900856, 59.47098831976614, 53.65898101560531, 49.43742029128536, 47.49111275519095, 46.12733210286787, 44.7407389456226, 44.58168683513519, 45.22144502209079, 44.874503535609094, 46.34450197219849, 48.543598421158336, 54.07709390886369, 55.138373528757405, 55.04560555181196, 52.437217620111284, 50.73836065107777, 57.8487430849383, 61.3372245911629, 55.44573437783026, 56.73081267264582, 56.29956376168036, 55.46474218368531, 54.90528275889736, 58.46197036004836, 57.569650757697325, 51.967870727662124, 43.307018510756954, 40.53062369746547, 37.091218886836884, 37.11325868483513, 37.15342375539964, 22.924486629424557, 11.039839348485394, 13.753288945844098, 13.895059093352288, 13.725976501741718, 4.300737688618322, 1.8843744142401604, 0.17756323089763043, 0.04621316235692752, 0.01950933297555293, 0.06748837779366201, 0.03383890800778905, 0.09955951493353614, 0.15618833593062817, 0.25028691566999883, 0.265051620982347, 0.18568678128142513, 0.2504474723771695, 0.1850955605867409, 0.2579742555897082, 1.5264162156851062, 3.6686469999051865, 13.844164379181402, 18.31917493574081, 15.280931515078391, 11.59382216392025, 13.889778602507807, 14.474312759214833, 18.39214082687132, 24.50787490414035, 26.577254649131532, 34.49407246805007, 37.63079189485119, 40.7705746927569, 39.50424140499484, 40.126211643218994, 41.65495934024934, 44.332043663147964, 47.752856439159764, 50.81407416251398, 54.49733664912563, 47.612349294847064, 53.4187868333632, 53.664468411476385, 52.02928327745008, 44.91797908659905, 39.867703914642334, 43.09565767165154, 44.672972156155495, 43.32009569291146, 45.078600145155384, 43.53963467382616, 43.31394933885144, 50.78613904214675, 55.95970607572987, 58.78160038302022, 62.36286163330079, 58.997577851818455, 63.0838599512654, 59.2418356095591, 60.18392224465648, 60.804551032281694, 66.24648663305467, 63.697891312260786, 60.59527689410795, 60.1774856352037, 60.15661470351681, 60.704922829904866, 59.7687707408782, 57.08049589587797, 44.96523972480528, 18.266217054859286, 4.809100397171513, 0.7354084318203311, 9.288630504761974, 34.44996541546237, 50.987572362346036, 34.67729814590947, 14.760293749070938, 19.80483343524318, 21.871387112525202, 33.272273771224484, 30.547267890745598, 26.55959221624559, 23.678281845584994, 24.805294506011474, 34.434342615066036, 48.04541034083213, 53.06269053489932, 0.3510203224516684, 0.20201660422307832, 0.07491199194543785, 0.061862235738625454, 0.062207343026755325, 0.07957434176557487, 0.05337281325351327, 0.07328042384958075, 0.0689046215566416, 0.02151694298992234, 0.13908841076397127, 0.03471091907892016, 0.017509115709652825, 0.16316186576601, 0.12523860595519506, 0.046005579342524854, 0.03194167211111034, 0.025265911075797294, 0.1386070317558704, 0.09421808179467918, 0.04903410110742815, 0.026711697104356946, 0.06788026241044845, 0.1602736989697141, 0.09803735951502478, 39.714700098960634, 76.54536770236108, 52.21114789285968, 50.650491714477546, 59.97957460341915, 46.48853924966628, 36.33151854238203, 54.44502792050762, 39.735900509742, 33.97511936003162, 33.53475093841553, 51.957852994242025, 58.30997459350094, 39.41244617585213, 8.332368423861842, 5.288930314202463, 9.435917465917527, 13.298831370569046, 15.063873433297681, 23.263571608451105, 39.48792826744818, 57.04306471732355, 61.13539903394638, 62.432844561915246, 64.4233101414096, 63.63420378777289, 62.84867855810351, 63.175317856573294, 65.17387920810332, 63.22861110010455, 62.77828378062095, 62.7487640227041, 58.5599393998423, 54.10458187903128, 49.520762812706735, 48.53915045338292, 45.21458087428924, 48.302317742378484, 48.48763404353973, 46.75382091153053, 49.5148164995255, 51.30402526547832, 57.01154455061882, 58.2576854767338, 57.48333115731516, 53.926274853367964, 55.42471439607682, 61.26354678984612, 64.03407373735982, 59.41985630219983, 59.1854593830724, 59.33719627318844, 59.086054755795395, 57.6407515618109, 60.060634305400235, 57.727286892552534, 55.60501790815785, 47.66095138365223, 43.85833901743735, 41.73028845940867, 41.7659035805733, 40.746377591163885, 28.400611569804532, 25.987665537864935, 28.237876353725312, 18.86169952730979, 13.715549861231159, 6.05172589901955, 1.5623486811114897, 0.3061871717293417, 0.026419379019869432, 0.03782145821699693, 0.022390949720096205, 0.05377009879016588, 0.15500718156897253, 0.4229458661810045, 0.7918075796577239, 0.3533359610986325, 0.12337547246246569, 0.14825777841671822, 0.11178449322018894, 0.30649688575536976, 1.4839123093312787, 5.702244187555006, 22.412434931724302, 31.291357201914636, 33.56149365825038, 24.48471134708774, 24.445907338973015, 24.243311036017634, 26.17247389208886, 32.255205146728024, 34.177709779431744, 41.788488588025494, 44.12007093429566, 45.46881321937808, 44.68247605908302, 45.65223109337592, 45.05752132784936, 47.61080780336934, 52.37043534555743, 54.62042846987325, 56.74034403216455, 47.135800930761526, 54.88438829298943, 56.87090404572026, 55.44099615466211, 48.14809014720302, 43.8485840828188, 45.56902585491058, 47.14980771464687, 46.796002080363614, 47.569152232139345, 46.20195911776635, 48.92905758273218, 58.0605040058013, 59.788590477358916, 62.60755477413055, 62.932370170470215, 61.41326365932342, 66.64872569422569, 63.192144824612534, 65.5196753624947, 66.34853101545765, 68.65509648476878, 64.09713760499032, 62.465255106649096, 62.578556691446614, 65.7859101603108, 66.61078852991905, 66.97294096792898, 62.961615362475, 53.117768456858975, 26.535414726503436, 6.644036154593191, 0.7075677547724016, 12.657612100724252, 37.6323216192184, 54.34494472319081, 37.33096199650919, 18.44248837040317, 23.32203649705456, 20.637401611574237, 28.385335899168446, 32.53459165173192, 33.552527120036466, 28.100373744964603, 23.412947231723418, 43.21753748001591, 54.37570787245228, 60.55100902434319, 0.8576530818977665, 0.21219883204227497, 0.054981360407245744, 0.0023455931636084232, 0.12268091416767529, 0.0400908979316873, 0.07515679534164167, 0.039694455091751395, 0.04327775091834126, 0.0954867004146499, 0.1456131662933096, 0.12358138923563304, 0.14911216563515126, 0.3675474130338238, 0.3115972846506104, 0.09292251986241148, 0.14847557721359117, 0.1821074499598434, 0.4531328866799032, 0.3099144652726189, 0.12206559234689321, 0.2307220106764186, 0.14855440766099962, 0.2549929631453368, 0.22947688797308555, 54.875284471819484, 89.88865129409298, 65.36612633735903, 54.89939528126871, 70.93244029629615, 67.67376653609738, 53.40782773110175, 69.88460263898297, 40.78612296811996, 35.91699461783133, 40.273665305106874, 58.089709974104366, 65.0982206098495, 41.86850101717057, 11.035268806642103, 7.117144600037606, 11.43645667260693, 13.245718556065714, 16.481956358878843, 34.16814704095164, 56.55104260290823, 70.81283154026156, 65.9701713438957, 67.61795120854532, 68.05586030406337, 65.15629130025064, 62.785359736411806, 67.21269192234163, 66.8063029935283, 66.50355092940792, 63.30004530568277, 63.98973526493196, 58.407645533161784, 55.67136479962257, 52.590550914887466, 50.6133625584264, 47.46987312070785, 52.6129751051626, 51.773509440883515, 48.17660577835576, 51.056225607472086, 50.11220132150958, 57.09767979960288, 60.655755919794885, 61.941022488378714, 59.327025567331624, 57.51990333680184, 65.77169549080634, 68.99528364981376, 63.7615474577873, 63.879202873476096, 65.09456888321908, 59.28690364283901, 61.60495381201468, 63.71687166152462, 60.591840897836995, 55.61656144357497, 48.657700169471006, 43.35278472592754, 47.15753086151616, 49.02760321094144, 49.22234888999693, 41.408406995957904, 25.61174754173525, 26.271025403853386, 15.67166724512654, 25.41820799150775, 21.486314304413337, 8.534536207875899, 0.9121183786661395, 0.10078251301761597, 0.17294554400347895, 0.21373820911732413, 0.198971328115271, 0.2940050254185354, 0.4848119093766136, 1.0366325488974972, 2.553252645077244, 0.6187330570913131, 0.5129887458057173, 0.35985530804722543, 0.5696515198196135, 1.9999343036643922, 6.348870444682337, 28.095023632049564, 38.77462563976165, 45.932778619950824, 31.377906260951875, 35.12094959135979, 31.058054624065278, 37.08834378950058, 39.46431559901084, 40.96812878885577, 43.58426340164677, 48.79880743642008, 49.69913651866298, 51.64607947872531, 48.09418109155471, 47.691612551289225, 47.523189898460146, 55.33095405947778, 57.813571191603145, 62.482497845926595, 49.66326644343715, 59.958727205953295, 58.238328579933416, 57.570235190853, 49.38276598530431, 46.178770065307624, 48.74223509142476, 51.71459151852516, 48.92256213772682, 48.19040075425179, 46.5617306770817, 48.71333114562496, 56.67609560874201, 61.87871563819147, 64.36366265819919, 66.81253956210229, 66.3527593305034, 69.87030952207505, 62.055747893548784, 64.46966078973585, 70.07558284267303, 74.54115421541276, 68.77113588394658, 63.91171539983442, 60.86203728952716, 65.27071468291744, 65.408691898469, 68.6415329287129, 63.4242981480014, 52.757392852537095, 25.94832612622169, 8.28180613056306, 0.9806556074369339, 13.483308284513413, 41.86455119040705, 61.49298191070557, 48.02102104310067, 21.53061551432456, 31.39152276900507, 30.468457668058335, 47.28799281581756, 44.12835890246976, 38.086273208741225, 32.893770933151245, 35.34688595802554, 48.99801677273166, 60.14232943134924, 73.73707617482832, 1.4737960263606042, 0.4418121296311579, 0.23460368625819686, 0.1860278283035563, 0.3235269896686077, 0.15950969480458768, 0.33307572406145836, 0.3565196080073234, 0.23649950872265527, 0.2493488563284759, 0.505877856405512], [0.11269052242559773, 0.09367938408808363, 0.14130510149463532, 0.026248374788631356, 0.07762919089967206, 0.021869343435091358, 0.008861877196919053, 0.1160200707794678, 0.061293197119788784, 0.09983162170336132, 0.04370338553863187, 0.031202150200824105, 0.12427512015546523, 0.31423673334140934, 33.91022374553065, 65.12719908068257, 43.358468240307225, 53.342920349490264, 43.04234481626942, 59.13516283035279, 39.5987940603687, 76.05751114506876, 53.14219697829216, 25.278720663439845, 38.307863589256044, 44.08803693709835, 58.43630236964072, 35.99158633139826, 8.940771183659955, 5.068089106390554, 11.387227004574193, 15.105466246604921, 15.648360521562639, 19.453469476392193, 17.075305061955607, 19.192349449280773, 42.286872786860314, 58.07185926745015, 56.005103588104255, 57.99485921859742, 54.82815719419911, 56.4562036145118, 61.556253663955204, 61.58565575076688, 59.0974021727039, 58.626682450694425, 59.51703694558913, 53.58941778059929, 47.88194948627103, 46.452304394014426, 43.61780358899025, 44.851608660913286, 45.430421060131444, 44.94880891615345, 46.64140186002178, 50.88128789778679, 55.42147451831449, 56.89859205676664, 52.048848059869584, 55.51980049379411, 53.502804002454205, 59.195092724215606, 59.64806764356552, 56.54531986482682, 54.93326887007683, 53.63835719323928, 50.37281536286878, 53.48031705425632, 50.85251339020268, 51.993989790639574, 50.58386633473058, 43.57286499392602, 39.410975287037516, 34.014009660290135, 33.77537265900643, 30.72791853258687, 16.889871089689194, 19.183792798749863, 24.69818046016078, 12.332990861708119, 4.265722199793785, 3.626001765651088, 0.5538980554669135, 0.2110540975005396, 0.06374323057130941, 0.08239311631768942, 0.08460334126627253, 0.1310450238205733, 0.11158678124869063, 0.09983313089657216, 0.1298056774201893, 0.37314350145959085, 0.3173578981189959, 0.2227278218995179, 0.1678198642067371, 0.484694360845512, 0.34246459122627015, 9.04104559652267, 25.054374817878973, 22.79548183564217, 30.070552825927738, 19.869219141621745, 16.813041663938954, 17.390663623809814, 18.707775915822676, 21.545104749741096, 27.923266964574015, 35.169414397208925, 35.311059028871604, 37.65074891428794, 38.923789455044655, 39.1192646949522, 38.85552844693584, 43.61105318992369, 48.422812954072036, 51.27452511941233, 52.181843865302305, 48.75461409168859, 52.7317483963505, 52.10542824960525, 50.54427000784105, 44.44498046751946, 40.60884752581197, 42.26384455157865, 41.070832129447695, 43.370215738973315, 44.49506128987959, 45.06295381053802, 50.043752039632494, 55.5250015566426, 58.44719086923907, 60.75709427556684, 56.58333547653691, 58.74828377077657, 65.43894121723791, 62.73974257130777, 62.01124075920352, 63.959964475324085, 64.5724033540295, 62.59863138198853, 66.63090244416269, 66.05360015746086, 67.39083813082787, 67.84425627800726, 73.19341213472428, 70.65303417944139, 62.22560221149076, 34.01247993592293, 5.894128007273521, 0.9781554028872521, 13.200313198950983, 34.42594874289728, 51.61927007859754, 24.372978710359146, 17.453782404622725, 17.904927538287257, 25.653736514429895, 28.95097109579271, 32.713526256622806, 25.73780663551823, 23.31879661929223, 31.280674626750333, 36.57763550358434, 51.80514335632325, 50.91627543972385, 1.0165754477343252, 0.035247157643278765, 0.10650901259073328, 0.025122204472521142, 0.1087274729845024, 0.10407630038718063, 0.041724082473064625, 0.16542559429522485, 0.06956518853023168, 0.010481646581132327, 0.019427237078367222, 0.15047863666569034, 0.03532311143053155, 0.10247313883155586, 0.04614426040901773, 0.03790160633563515, 0.029009079876085444, 0.04373782119082828, 0.0730171270908848, 0.11651093395607126, 0.04964355086427062, 0.09230442480334351, 0.07221098808992295, 0.012079264533015029, 0.47425641287719056, 45.21167832036173, 72.35575860546481, 51.574653117887436, 61.569001367015225, 50.71413217052337, 52.024847076785186, 34.59484208014704, 64.98040437698364, 49.88017351396623, 34.035080632855816, 42.14890733841927, 48.699438110474624, 62.9369201198701, 44.36318728231615, 13.380077385133314, 5.219196456093942, 13.921489004165897, 21.48729097458624, 23.958115500788537, 26.79979032085788, 23.972296830146547, 21.362277192454187, 46.20887033400997, 62.29928785754789, 62.31618150588005, 57.289264048299486, 54.11661571071994, 60.50489764059744, 63.149445902916696, 65.13414952062791, 62.48345098187847, 60.56248980183756, 61.780405352192545, 57.577440584859545, 50.26101604584725, 48.8702690985895, 47.53038352535617, 51.40575193589734, 49.12597233249296, 47.246725559234626, 47.56861486742574, 52.63716436201527, 56.83389648314446, 59.635857305219105, 57.354163585170625, 61.45165189619988, 59.584960629863126, 63.1075079210343, 61.841892427013775, 61.707543403871604, 60.8589856855331, 57.94776331993842, 55.799814578025575, 55.988594332048976, 54.84911834039996, 56.821262528819425, 55.78611373901368, 48.44979493848739, 44.24941501309795, 37.63753052680723, 39.86826481357698, 35.941889901315015, 28.243016619836133, 40.68190559264153, 41.98761163219329, 19.7679925733997, 6.918011259648108, 2.7696113192266036, 0.9368472065656417, 0.015941409660773655, 0.2731443899533441, 0.20251952562360995, 0.36741681036449253, 0.09129853603700477, 0.1162187863261469, 0.0749812079893966, 0.2281261523885112, 0.11207731500748666, 0.13265478905410538, 0.27162683106237845, 0.10351131054302377, 0.21367667693524592, 2.080095660301947, 11.288003786917656, 32.51777056724795, 21.548515250605924, 43.95879876229071, 32.730729772198586, 29.370450935056134, 28.09749080288795, 29.572123519835937, 30.333998818551343, 36.44918180281116, 41.08346608377273, 44.15861998834918, 42.21171625198857, 41.87535732023178, 43.948098536460634, 44.08661703909598, 46.229603982740834, 52.22180105024769, 55.268960998904326, 58.1016339794282, 50.55768843620054, 53.64653925741873, 52.979171506820194, 53.23076801915323, 46.019247270399525, 43.82981946391445, 43.93559009798112, 45.58649609165807, 48.24925199631722, 46.340665894169966, 48.04301769502702, 56.86911152255151, 60.32196221813079, 61.78123689466908, 61.80216273953838, 58.937938213348396, 62.69347037038496, 64.93609336114699, 62.28064483211887, 66.03365098276447, 66.21832401521745, 65.28754949569702, 64.24285365689185, 69.00327744022493, 65.76748286524128, 70.30072689056396, 69.6016271652714, 72.06773896371165, 74.3689464753674, 69.37387866358604, 39.31297094591203, 7.893029624415983, 1.1771319710439252, 17.022488386400287, 39.718034113607104, 55.14941892316265, 27.0880433436363, 22.604750702458045, 23.92437331138119, 21.832663512999012, 32.31569005597022, 31.988950737061042, 33.075464925458355, 26.21888533715279, 28.249415966772265, 42.38479475821219, 54.56875124285298, 62.298169982048776, 2.6051230488284944, 0.1903725121050112, 0.08987625550118186, 0.02950273927361254, 0.044390528102315245, 0.03668890830369727, 0.09706569189626364, 0.2771618163153049, 0.07918605776203257, 0.012277343269107083, 0.043507355130127365, 0.2833413879477209, 0.29935863169450916, 0.1913956991366802, 0.09647173626768975, 0.18943923315213573, 0.09526603644894016, 0.1259712541415807, 0.3172043128119361, 0.6416870737748762, 0.2309171639142498, 0.1551211448085885, 0.13463126525523203, 0.2589123455747481, 1.3545507024372778, 59.83791428227579, 83.46326766475555, 57.92916736295147, 69.5243800070978, 56.938980702430975, 74.50396230143886, 50.65911700648647, 85.02593994140626, 59.43069773335611, 32.08143041979882, 50.50654072915354, 56.14981159087151, 69.71976111012121, 48.169459219901796, 15.50988712618428, 7.4147559077509, 15.724034809297132, 22.165284425981586, 23.93888411983367, 23.71121798792193, 22.05490500696244, 29.693501264818256, 53.6013888543652, 65.30161511513495, 63.7538831464706, 56.36281590307913, 52.36604621333461, 61.67199888537007, 69.8866501162129, 64.83309584279215, 61.239373222474136, 62.016112342957534, 63.502874989663404, 60.5388653662897, 53.71109754808488, 49.00136255448865, 48.84613867728941, 54.37482533916351, 51.407889627641254, 47.96163243632163, 49.076146464194025, 54.467640384551025, 60.55555112900273, 63.91315490968766, 61.386262063057195, 66.4665472892023, 61.34567337651407, 70.11480654439619, 65.02772777311264, 64.43509294140723, 61.71927913542717, 59.29600746400895, 56.74115596279022, 58.795426737877634, 55.21626787800943, 57.03854614688505, 53.671528677786554, 51.439888323507006, 45.60478610377158, 44.00111329170966, 47.268020106900124, 47.95756493845294, 34.19265793215844, 42.21202611923218, 44.784947979834776, 21.143328528250418, 13.010940186439022, 12.77631086687888, 1.5018234450009562, 0.3873131862811504, 0.31903593710833983, 0.3282492782079405, 0.4937554036657657, 0.4859263528018229, 0.3009063744496915, 0.257436829589067, 0.34933486773121747, 1.8916600942611697, 0.9420567270248168, 0.34673035264976565, 0.3930761899438597, 0.6706483842384431, 4.075081771419895, 14.119250005291356, 42.21222616011097, 30.04672442713092, 53.42235619022001, 40.70310208105272, 40.682513560018236, 36.387859467537176, 38.95072044864778, 37.65944480895996, 44.21554534666, 45.269482289591146, 50.656893022598766, 45.52390290844826, 50.52235180331815, 45.85742988894063, 45.004792905622914, 47.94347970716415, 57.73182115247173, 57.4668062117792, 63.000438982440585, 52.45639408788374, 55.98466019476614, 55.07526651505501, 56.70568596932196, 49.148529883353945, 44.78365359767791, 48.69496660847818, 47.02658253331339, 50.81436441790674, 46.131901664118615, 47.26633348772603, 53.916453238456484, 62.35102784249091, 64.68663061818769, 64.9964939394305, 61.11022526218046, 65.23659790715864, 69.1845537001087, 65.53301534345074, 68.41609078068888, 72.72908979846586, 70.26300153424664, 67.75222178428405, 71.16212644884664, 69.04683928335868, 75.85634846841135, 75.89213617386358, 78.73243424200243, 78.11718694625363, 67.08368516737416, 37.77547244102725, 7.344719536842839, 1.201129644628494, 18.527686172916045, 42.69491303351618, 62.698302730437256, 36.69181177693029, 25.408005906689553, 30.58113167362829, 31.199583545807872, 41.667769801232126, 44.49609679560508, 36.72115110581921, 31.203941299069314, 42.06883999609178, 51.18218860318584, 61.02910280227662, 71.60399713823873, 2.826743092267744, 0.726813109171006, 0.1910712455789889, 0.09143143697010894, 0.40391464867899496, 0.16743991523981097, 0.39187030626400826, 0.5162296960911443, 0.35675409219918713, 0.18696686823762235, 0.14109776745880806], [0.06295269295092552, 0.012721638833623261, 0.31167015493396794, 0.19371426423951504, 0.04274896638948591, 0.07240417248178875, 0.03174360199350744, 0.31538405726032875, 0.06627500943479038, 0.026429409026018074, 0.15384159411393827, 0.06971065330529405, 0.05604370219272472, 0.3356014853042941, 46.26701554944439, 63.19652611209501, 37.678013309355705, 45.16749674274076, 35.51143723149454, 51.4199548382913, 32.31244233346755, 60.73314036092451, 57.76478867377005, 20.594326142341863, 32.49794494721198, 43.913456163098736, 49.733665143289876, 47.04160521107335, 15.5714742214449, 5.499967067472396, 12.328917480284169, 24.693008815088582, 31.06752322566125, 33.99990481715049, 27.336221510364165, 19.591495721570908, 29.170035469916563, 55.37088378783196, 58.652389664803785, 56.86673848859726, 58.73611265613187, 64.23240054038264, 65.06024029947096, 64.05857286145611, 58.65433516040925, 60.260161353695786, 60.48365408374418, 59.321173391034534, 51.33705162232923, 46.13756556664744, 45.55073584279707, 47.68490529829457, 43.738636124518614, 45.201433089471635, 40.81388158182944, 44.34223790322581, 52.22729236848893, 54.5059972424661, 52.88646236542733, 59.00375166246968, 57.18187739772182, 60.910286365016816, 58.99359272372339, 59.84246423167568, 55.191874657907796, 55.74844721824893, 52.04703592484998, 55.000882687107215, 52.262962402835974, 52.698110149752715, 48.01725556773525, 43.681902962346236, 35.38280310169343, 32.14580435906687, 31.60195008400948, 28.0266841765373, 17.013510081075854, 39.617409629206506, 35.63658829658262, 10.251266437192118, 1.4078098703776638, 1.7368680455030936, 0.1399463373086145, 0.26519475685011956, 0.028850174088391568, 0.20374704362644305, 0.2788979247693093, 0.09207117401303784, 0.07566849610978559, 0.05889431535897236, 0.23817175608729166, 0.20102101167844189, 0.975936750971502, 0.6613306100330045, 0.2106190668118577, 0.06316303771229521, 0.5515459203912366, 9.868448011336788, 39.83017859920379, 31.001845098310906, 42.96104584970782, 28.954975835738647, 19.880233157065607, 19.863151234965173, 21.097056327327607, 24.26575287695854, 28.140125005475937, 32.70679546940711, 34.559638807850504, 37.13930322277931, 37.64008006741924, 38.483220992549775, 41.05586436487014, 41.79063020213958, 46.526276373094134, 52.09371605227071, 53.78490870998752, 48.97086220402872, 50.796023414980986, 51.1647536677699, 48.04085646906207, 42.05867713497531, 41.2307079376713, 41.702871091904186, 41.759357144755704, 45.79202044394709, 46.025232807282485, 47.43636431232576, 57.872336141524784, 55.40587132976901, 62.15468575877529, 56.239135726805664, 56.82306681909869, 61.716333435427764, 62.520662507703236, 59.16796953447404, 59.86834403007262, 60.20765258419899, 63.63809085661366, 65.90775074497347, 64.32938114289315, 65.91182216521233, 68.52628584830993, 66.49025409452378, 65.60850527978712, 70.71712570805704, 74.68174765186926, 46.5970947665553, 13.646023888741771, 1.782783433314293, 14.787669931688617, 46.28539185370169, 45.09847087244834, 18.164345256743893, 16.521813523384832, 14.812102375491975, 11.281363214215926, 17.317817364969564, 32.63950132554577, 26.91857930152647, 23.02827254418404, 25.213825048938876, 30.241054334948142, 41.82028332064229, 61.20233035856678, 2.772340798570264, 0.287666168784903, 0.0384948380111206, 0.04758136474617547, 0.37037228564581565, 0.10544817233758588, 0.21738763748397752, 0.30947448565594615, 0.13828683764703814, 0.23828941187070263, 0.19188389632730715, 0.1192820808219333, 0.3548337242776348, 0.35664877043135707, 0.18019146406121794, 0.0604442261429804, 0.07088645271235897, 0.07042975705717841, 0.2754130827323083, 0.12090190478991117, 0.0427043647505343, 0.13039495225154585, 0.06255050445155752, 0.1122469881609563, 0.8549697516906647, 60.04798858396469, 74.88454987925869, 44.115344478238015, 49.57550341083158, 42.36542609430129, 49.690040542233376, 31.275971704913726, 51.67235543650966, 49.72730305887038, 27.46690311739522, 39.390010218466486, 49.74428299934634, 57.2461336658847, 52.613516392246375, 18.443519953758486, 8.649329273931443, 12.462457514578297, 24.032263986526, 32.94614830324727, 37.85238619773619, 35.17035184368011, 29.838993741619973, 31.337911813489853, 59.98561897585469, 63.52176512441328, 56.363255208538426, 60.73049668342837, 67.70219587510633, 66.29863062212544, 66.45451345751363, 62.26589279790079, 63.33662532990979, 61.78290782436248, 59.90974464724141, 54.541482925415046, 47.962993498771425, 48.03099955281904, 49.698152003749726, 45.87750457948255, 48.132361442812034, 45.595646981270086, 49.32593084150746, 53.060898011730565, 59.6128055357164, 57.918204338319846, 61.37215721991755, 58.68504339648832, 63.64940689456079, 61.46287771963305, 63.44857761936804, 57.33912914030014, 57.7838945388794, 55.47805863042032, 56.6832813908977, 58.32596609669348, 55.56355061069612, 52.46289345525926, 47.786031846077215, 39.867025344602524, 36.76084549196305, 37.693432146503085, 32.72369500129454, 34.75920507984777, 52.87232222095613, 40.00154695203228, 25.464427240433235, 4.772312487325361, 3.1989811697313866, 0.045888490464177825, 0.1342295747130148, 0.03626507782046834, 0.016212467847752477, 0.21570204486770017, 0.09049621215390583, 0.214176488018805, 0.176200345158577, 0.16705644226843314, 0.14069612288186628, 0.20245142040714142, 0.5303308620087562, 0.14613324806334513, 0.16965907277359119, 0.927169616183927, 10.138308059784675, 58.19676322321738, 54.43202918575656, 65.24702748944684, 40.99819375622658, 31.516434569512647, 31.111997019860056, 31.206520257457612, 32.438544573322424, 36.34987523478847, 38.67521709011447, 41.16635753262428, 42.01000444350704, 42.52580788827712, 42.29625901868267, 46.1395542083248, 46.47726243542087, 51.783990013983946, 57.58614432427191, 58.55279284138834, 50.952557363817775, 54.38840066232989, 55.05464661505915, 50.15051503335276, 43.57867402415122, 46.75649596798805, 44.113363681300996, 45.71672662611931, 47.88180828094483, 45.00497725702102, 49.50060183002103, 61.93679025096279, 60.46684280518563, 61.353761303809385, 58.87760039298766, 61.326716561471265, 65.71569581185618, 63.43349610605548, 59.05863346592073, 61.69388178856143, 61.95707282712383, 66.13968049326252, 67.83554861622473, 66.25578265036306, 65.86373390689974, 72.07949822948825, 68.88151138059555, 68.04570921005742, 69.52013600257136, 74.09244291244015, 53.10196522743472, 18.69121370777007, 3.1795436191943387, 19.880748948743268, 53.23385492447884, 47.79295482943135, 23.713865587788245, 18.68592635277779, 16.959210749595396, 11.858684132176062, 20.735749160089803, 31.820865408066783, 31.28108843680351, 25.42528786966878, 23.185745900677098, 33.80788518536475, 43.838931129824736, 72.800704433072, 4.434811165255885, 0.2420195705828167, 0.07071264268409821, 0.06495755270964677, 0.21914332714532653, 0.07160610038666956, 0.01879575654804226, 0.16349398020294406, 0.1044848014510447, 0.08059813400670406, 0.08054399457309516, 0.20997873988122712, 0.40496023612156995, 0.4301644062563297, 0.2447209498214145, 0.18845508596108806, 0.19391206814156425, 0.18321760329267672, 0.6755328995566214, 0.3705027657410791, 0.1683554209528431, 0.5805550347412787, 0.29297512745664966, 0.16794574777445487, 1.544552765065624, 79.27840463576779, 85.54562261027675, 53.175815613039084, 55.15134088454708, 51.22061606376402, 66.3494880737797, 46.24625444412232, 68.17542199165591, 64.18286884984663, 26.00623796063085, 46.11507469607938, 58.086340658126346, 60.79944410631734, 56.80782448860907, 21.411581385520197, 11.32985253487864, 15.92557599467616, 27.07980048271918, 34.147487917254054, 38.22141847302837, 33.11496319309358, 28.831364300943193, 36.69232168505269, 62.54096077334497, 63.34134394122709, 54.00923690488262, 59.63237424050609, 72.15822804358699, 72.0471308308263, 69.35417267584032, 61.68487994901596, 62.93277417459796, 62.729163938953036, 63.90804013898296, 54.870095176081506, 50.63030719757081, 49.616515713353316, 53.49384530898064, 49.10996121744956, 50.24120415410688, 44.730521171323716, 49.5851485190853, 55.2081956401948, 62.10366748994397, 61.2809621134112, 67.21151521128994, 63.12035368334863, 69.41305529686713, 64.41080954767042, 67.89324668145949, 58.85476827621461, 61.4608576989943, 58.18829090364518, 58.8989459314654, 57.35641894801971, 57.4522267618487, 51.97826108624859, 49.18116792555779, 41.9501922207494, 44.7148395353748, 48.597103472678896, 48.67915553431357, 43.41509157611478, 68.13695922974618, 59.16305088227796, 31.73680901527405, 13.198295139497327, 5.5220813905039146, 0.48323940665971854, 0.5871565676023883, 0.16011643644061782, 0.2815162600769151, 0.5308039979107919, 0.23217593830439354, 0.423908838701825, 0.774619753562635, 0.3904152295041469, 0.561289884630711, 1.9595157499274902, 1.7551461679320184, 0.7760365872133164, 0.4476064203246948, 0.9864032280541236, 14.913696665917675, 64.5549919528346, 53.41821024494787, 70.80843064092821, 51.39821314042615, 45.523267484480336, 39.07255711094026, 42.59131539252497, 39.14800782357493, 41.91561260531026, 41.078100281377, 45.539721827353205, 44.493174629826704, 50.40521021812193, 44.218475357178725, 47.921863525144516, 47.55065825677688, 56.18805077768142, 59.73719958336123, 63.11079878960887, 52.1850602088436, 55.81821441650391, 56.97239537392893, 53.67141492905156, 46.097314203939135, 48.26952280536775, 43.78423760014196, 47.45429346638341, 51.04583524888562, 46.17975458022087, 49.28151784404632, 63.73715423768567, 61.16231041569864, 67.40877120725571, 60.643239636575025, 62.60043959463797, 72.30433633250576, 66.34150997284921, 59.34846524269351, 65.3628433135248, 65.99268574868479, 69.76296993993944, 71.8537893602925, 68.54161447094333, 69.82451977268343, 76.68503545945691, 74.32446679761334, 72.12276981722924, 76.43998930531164, 83.07809875857446, 51.95451113485521, 16.31142347089706, 2.615474428861372, 20.570527161321333, 55.080106719847656, 56.00378174935618, 30.60365588434281, 25.551719588618127, 23.272143948462702, 16.710820774878226, 26.659416537131033, 43.47610404414516, 36.832052200071274, 31.429809024257047, 35.823708888023134, 39.46519813229961, 53.47496301897111, 81.85910455642208, 5.378464296940835, 0.6474977587499927, 0.2526148270455099, 0.3327209947089995, 0.5403800969642978, 0.5601417946238672, 0.6269002285215163, 0.8028388167581251, 0.20679518490308718, 0.2511614510008405, 0.14241108730916055], [0.26636172326341756, 0.2818383234402826, 0.45863232545314303, 0.17224877171458738, 0.05314764469080875, 0.06969767577585674, 0.1338608719168171, 0.10459432904157909, 0.1544950977568665, 0.08650805801153184, 0.08214695694585962, 0.1511053578747857, 0.2735562388214373, 2.6114388002503306, 59.86894807507915, 62.573779244576734, 39.91151678946711, 45.02663266274237, 26.24886597356489, 33.675669931596325, 30.375752449035648, 56.430323816114864, 39.81404981305523, 20.963872248126616, 26.78485001287153, 47.72444671200168, 50.92937615609939, 47.15444787856072, 20.126232447162753, 5.605263094748221, 9.184482751354095, 21.433379957752845, 33.13423772012034, 43.29306271768386, 44.496967561783336, 35.92771053314209, 26.28977825564723, 57.64092022372831, 63.58908084131057, 60.60040735429334, 64.98800200800743, 59.0730756328952, 59.59397423651911, 62.17029286969093, 60.36834424541843, 58.01478485907278, 60.3275868969579, 55.59902844890472, 49.906406325678674, 45.663570665544086, 44.546656147126235, 44.52705998574534, 47.01951834463304, 47.431500573312086, 44.7814453032709, 47.029532155682965, 48.71096987878123, 56.46627626111431, 53.37352268157467, 51.649566465808505, 56.85448108180877, 60.25685479564052, 60.20454214465234, 54.637188757619555, 51.473550104325824, 51.612041150369954, 49.14215210945376, 54.64119349756549, 49.6182886246712, 50.842934962241884, 46.7887927639869, 47.438490236959154, 33.01840620656168, 34.21853773055538, 23.098575145967548, 23.43228647785802, 26.891915029095067, 48.866397719229425, 25.29046816210593, 11.485231345699681, 1.3384210582702392, 0.6745160863764825, 0.24467195083777754, 0.14796562312591463, 0.19976003095507625, 0.2323406931733893, 0.16541303045326666, 0.1691421166422867, 0.22430368008152132, 0.15793388258785973, 0.16572397021997362, 0.09830352910343679, 0.342516960996774, 0.2515531057912496, 0.21242570132017138, 0.5949497655514748, 0.21111602804833846, 1.0757146775722504, 19.756388241244903, 46.23352243054298, 35.83186349561138, 24.927513599395756, 19.26795509553725, 19.53635111931832, 22.10775306147914, 24.378150355431345, 27.968480125550304, 34.92890250298285, 36.799869152807425, 40.17248384414181, 36.62309185151131, 39.22396452196183, 41.62819700856363, 45.72266117219002, 48.373077300287065, 53.528507294193396, 53.67732986327141, 52.70846128463746, 49.63756707406814, 51.25809038839033, 45.3681142099442, 37.78190512810984, 42.54078349759502, 45.27133364831248, 45.29908833965179, 40.946642045051824, 45.54126331883092, 53.88560379705122, 61.84527743247248, 61.57745799710674, 59.434612258788086, 59.3730624260441, 67.15251491915795, 59.51988066396406, 60.714532636827045, 60.67650133563627, 61.91631547866329, 58.710868281702844, 66.13463632522091, 65.52248770190825, 66.68570580021029, 64.51785102967294, 66.91822390402517, 68.99449917577928, 69.81523160011538, 61.520254150513686, 65.50053419605379, 54.942458983390566, 27.869483424771218, 5.647281485219156, 21.541664831099972, 59.01454210281373, 41.431192044288885, 13.655798435211183, 16.423289468211514, 15.216526196848962, 11.550058318722634, 20.870474730768514, 30.677245432330718, 31.248985798128192, 25.857823318050755, 33.473012831903276, 46.73951210514192, 41.39930317478795, 61.45134595132644, 5.554171771772447, 0.4070923813889104, 0.0807296329989068, 0.11840370739059103, 0.39383164456775116, 0.1132676700851129, 0.1981602248645598, 0.05218798933070033, 0.24687073043277188, 0.4781501313611385, 0.2927399997509295, 0.1441786513333359, 0.2270803810848344, 0.188606373004375, 0.11303510877393907, 0.014070806810782563, 0.058712675912125464, 0.12490728824970224, 0.07811334314605883, 0.08566801195904132, 0.11716696568914961, 0.008884766946486648, 0.2658116108467502, 0.08459350469732478, 3.7645521375440785, 72.31027480094664, 68.22136863585442, 47.244446662164506, 49.605336958362216, 32.21452820685602, 43.41380896106843, 33.26162061383648, 50.56015560703893, 37.11650248496763, 27.56585471091732, 37.99006531315465, 48.079946810199374, 57.05820114381852, 51.701267227049804, 23.310651817629417, 5.564119392825711, 9.567386488760672, 22.871762129568285, 33.31011287627682, 39.464774516321, 45.04249080534905, 40.279152700977946, 33.79054830920312, 65.76205038255262, 62.85882180736911, 64.25534640589069, 64.3952573499372, 61.39901761085757, 65.45667425278695, 63.67179970587454, 61.78528085831673, 60.62491824550014, 61.23212860476587, 57.66365428124705, 51.441602399272305, 49.397518019522394, 49.586387988059755, 48.788169968512754, 49.10816869428081, 50.2446166161568, 50.00430476280951, 51.3094695152775, 52.012173898758434, 60.18172963973015, 58.898487014155236, 58.35338738656814, 58.35852569149387, 63.36492915307323, 60.88881138832339, 58.78131012762747, 54.85753574678975, 54.61786716215072, 51.952079265348374, 57.22869873046876, 53.10094541118991, 55.904055487725046, 51.42685036505423, 51.51659419459682, 38.54599852715769, 43.26473928266957, 33.0941040285172, 28.303311294124974, 40.06489323031518, 46.85302942029892, 30.507014566852202, 15.770740432123985, 11.956049126963462, 0.3901626043502362, 0.1792429706021663, 0.2942070274824097, 0.17449198440919, 0.11393343879570884, 0.19815743630451543, 0.2298286295826397, 0.07052764011126372, 0.055055575174910415, 0.15149456118383717, 0.1438356278043601, 0.08410090250113318, 0.6480506903702213, 0.2608000168636922, 0.42931181168363947, 0.20750589999220065, 0.45053238589917466, 26.086005241640155, 64.41123316364904, 42.5673379436616, 33.88378304819907, 26.527069883961833, 28.08061088285139, 30.564998965109552, 30.16699802490973, 36.480866709063136, 40.7172030018222, 43.258596850979714, 43.82756410106536, 42.14507126039074, 43.54105064945836, 45.885533671225275, 48.74833045467254, 52.4322283652521, 55.79004787629651, 56.19928444585493, 55.93137479597523, 53.48869915931456, 52.5583835571043, 48.05146255800801, 42.548302681215354, 46.75902981911936, 46.89026448034471, 47.03515683451007, 43.030248226657996, 48.53166657109415, 57.14923151077763, 63.22085265190371, 64.85745376156223, 63.93513979450349, 59.79477213275049, 64.33238175607497, 62.51678328360281, 62.61218317093388, 62.13849029233379, 66.1090938506588, 62.13587799379903, 66.79588517835064, 66.53580065696471, 66.58794464603548, 64.65598514003139, 66.95201904542985, 70.19088483625843, 71.81472255337623, 65.45474444666218, 69.63390042704921, 54.49158253208284, 31.285726639532278, 7.207996989450148, 24.566867351531986, 61.1112529231656, 47.74762007497972, 18.637636092401323, 20.31022494839084, 21.103730240175803, 13.282308386218164, 26.156543185634, 30.439934192165254, 35.612983472885624, 28.588430343135713, 36.12533523190406, 59.02872539335682, 47.03878502691946, 74.63858589049309, 10.902458333200025, 0.16847537500002693, 0.1698932811738022, 0.009005632638300379, 0.2147948588695257, 0.14692316132207073, 0.18655898770497692, 0.15626224809356276, 0.17710006946036894, 0.33980672578177146, 0.1791609532289928, 0.32655450785833023, 0.430916827172041, 0.5233214026497257, 0.26692700422098564, 0.0945290522049031, 0.19222204753708458, 0.22342306201256093, 0.18310546334232056, 0.3342849478846596, 0.26076551226358263, 0.18548041251638245, 0.6499361246824265, 0.3714868516450928, 4.541338326469544, 86.79538388406077, 79.32634384401383, 51.827904870433194, 57.3487977827749, 39.976718348841516, 47.00940647432881, 42.336573139313735, 68.31096341533046, 42.99089508671915, 29.061111250231345, 38.53411766790575, 61.37243178582961, 60.374533745550345, 56.34636548257644, 27.328233603508245, 8.129770159721375, 12.541226552378747, 24.612131503320512, 35.31773882527506, 43.63600730895997, 45.66976408804617, 43.948812407831994, 39.38386778677664, 69.5936647538216, 65.92690760089506, 63.31597797332272, 64.54034582261117, 66.01629057238179, 70.82550864065848, 69.01957096592074, 62.38496418922179, 61.42212037117251, 64.93113548524919, 60.60998185988396, 52.65155161580732, 49.76265930360364, 54.48802886470672, 50.89188614199239, 52.04824793723322, 51.57897949218751, 48.97944042759557, 53.108233174970074, 54.47727372569423, 64.00049040394445, 62.44469796457599, 61.06542002770209, 62.23998162054247, 67.65886152944258, 66.12040596623575, 61.6267700349131, 55.92271420263476, 57.56854072693856, 52.455170308389974, 61.193375587463386, 53.912209233930035, 57.75310785539689, 51.41124717650875, 52.172308583413404, 42.75699238623343, 52.3406998572811, 45.54497388101394, 46.46804094314576, 52.84979997142669, 74.12375911589592, 53.02075255301691, 36.86794188714797, 15.150322471895526, 3.7188217140013173, 0.7396860216413775, 0.6916641371865427, 0.2710746348865571, 0.6718632771122841, 0.4688637974041124, 0.3209232713185972, 0.49305709920102553, 0.22678228095173839, 0.4160889808929736, 0.39400070485088134, 1.0010390620558494, 1.1742975682981553, 0.5405297599011852, 2.082340481781191, 0.2871914700635018, 1.6108898506049187, 27.90784420505647, 65.60490846633911, 48.16428169127434, 41.40232339982064, 37.897407162574034, 41.975934736190304, 41.62550626262542, 42.06930283577212, 40.83887884693761, 46.39442589975173, 49.07710352251607, 51.15881519932901, 46.838626477026175, 46.12525716904671, 48.06155873883156, 51.78540598961615, 56.0632291916878, 62.5819456192755, 59.556558747445386, 58.91053261295442, 55.760610488153276, 56.014305468528505, 50.799620228429, 43.35188258078791, 46.75168714215679, 48.803875138682706, 50.251002234797326, 45.81053403116042, 48.65418572579661, 55.5659197222802, 66.26164267140051, 65.6701570941556, 64.96343228124803, 60.851937186333444, 72.97049599309122, 65.35421802151588, 67.43265059686476, 65.18857632913898, 68.83048134465372, 64.89743055835848, 73.71444409893405, 72.58216565655124, 70.87406758339175, 68.7859545984576, 73.61060327099216, 78.46559539917978, 77.82179324857651, 67.21895202513664, 75.33300230579992, 57.691024580309474, 31.80941600953379, 7.182090715054543, 27.42422380755025, 65.49514093706685, 56.6745384277836, 21.824379467195083, 26.452066321526807, 25.797044231045632, 17.712315628605506, 31.988772269218202, 41.429466201413064, 45.46487515972507, 35.10495024342691, 42.101760448948035, 62.07793674161358, 51.66540499656431, 82.76194787794545, 10.93559745819338, 0.7892334016580737, 0.24351157278062838, 0.40519389293847546, 0.7372042032018785, 0.4032137088717953, 0.4693479036852237, 0.6355153468828048, 0.3348273074915332, 0.7785259439579902, 0.43413307878278923], [0.2223781793708763, 0.3283291352131675, 0.2661839602214675, 0.028488739551375472, 0.11356102813395763, 0.11565787206974723, 0.05847218176049571, 0.07668495688947939, 0.11939196847379209, 0.15139659386008017, 0.02579780400640542, 0.17093568169061216, 0.05252612521871925, 1.8792806037010688, 52.27698879857218, 55.98689202339419, 31.964834044056555, 29.818440521917037, 38.14028424601401, 23.378610803234963, 28.775749014269923, 23.060418328931256, 19.468501960077596, 19.91945685878877, 25.008971421949326, 46.22688185784125, 46.57335265990227, 45.40262714509041, 23.554495765316872, 4.485529372769018, 6.985994760067233, 19.073048599304695, 31.032912231260735, 36.8251056824961, 43.74391955714072, 35.862006910385624, 37.67632669018161, 64.62674387039678, 59.9740989746586, 66.74561608222224, 59.14397247375981, 63.03383404208768, 58.627004085048554, 58.94631247366629, 57.333159292897875, 56.4227379522016, 51.178564333146625, 52.32809728191745, 48.28716562640283, 49.576193747981904, 47.624277222541075, 51.04886724102882, 46.26044950177593, 42.89336927475468, 45.52338123321534, 49.04945081280124, 48.49260760891823, 51.42619140686528, 54.7245595532079, 57.41023778915406, 54.08853546265633, 60.83445910484561, 56.98949298551006, 55.43968216065438, 48.70926364775627, 50.26308313492806, 48.55693447974421, 47.84112545751756, 43.47484104094967, 50.140771865844734, 43.98018352447018, 42.74301305893929, 30.914529215904977, 28.046284260288363, 16.95146406850507, 25.17212829282207, 36.474237903471916, 35.03056249310894, 16.129256832984186, 0.596495547121571, 7.099396365304147, 0.7254448761382412, 0.32664732707123606, 0.08801908983338265, 0.09051851297338163, 0.25083800867920925, 0.05369985618838861, 0.15219586871324048, 0.11204388293047106, 0.08804456991774422, 0.15372491892307036, 0.20697256490107507, 0.053833040574024764, 0.19356605686968376, 0.4847770983413343, 0.1977645864169444, 0.19710624109833472, 0.5978709507373072, 3.735605535968658, 9.487418186280037, 12.725196499978344, 16.75813828745196, 16.389789485162307, 14.55421438140254, 17.75938799304347, 18.783299192305535, 29.48932424668343, 31.181093492815574, 36.13121486479236, 35.0914494452938, 37.25442870970696, 38.790385723114014, 43.58234928500268, 47.43563082910354, 50.55766882434968, 50.55023593287314, 51.60812662493799, 52.62650728225709, 49.93987591035905, 47.00402106008222, 44.59761950277513, 44.113685315655125, 46.50674689200617, 47.34633414976059, 45.49425763468589, 39.855536722367816, 47.93030838812552, 58.3661860804404, 61.038453732767415, 59.53134575197774, 61.12846036111156, 59.936354006490404, 59.3491751916947, 62.14006316277289, 60.14900922775269, 58.30705242772257, 61.338840607673895, 64.0380588654549, 62.426976696137466, 61.02612572331583, 59.270221802496145, 58.742651247209125, 63.30776453018189, 67.05742882144067, 65.54100913386192, 65.44141231044647, 66.84442843160322, 50.30797073918004, 26.431428770865164, 7.492550726859801, 28.815696393289876, 62.12052583694459, 33.99180120037448, 16.287517605289338, 38.1732556896825, 19.257676524500695, 14.925933480262758, 16.733046885459654, 31.006924567684052, 30.810984526911092, 30.926376735010457, 29.270799198458274, 53.120086577630815, 42.59160172554755, 69.44983143960276, 16.544074935297814, 0.6237942016413135, 0.37611215345321164, 0.19022678686005456, 0.12571840682217192, 0.1970019152448062, 0.0722962613367746, 0.07440748474290294, 0.03020695027624888, 0.363039230747569, 0.2071342707401322, 0.1999217827594088, 0.3451664607611395, 0.275447526045384, 0.05813499965194253, 0.1488157049302132, 0.20008253864943984, 0.019736907054339687, 0.0065752033767620885, 0.058741450174561435, 0.07911786061501311, 0.032053452000142105, 0.1733348545648398, 0.022502800472260966, 2.5177603431286353, 64.6391228706606, 68.66279217504686, 38.089328735105454, 35.848164866047526, 48.25007177168324, 31.95100965038423, 32.048892398034376, 25.854983522046, 25.260434573696507, 21.985565347056237, 32.11442343650326, 49.86433498321041, 49.50146082908877, 49.01770314862652, 30.662311007899625, 6.918140207567523, 7.867432236671449, 18.81405253564158, 32.74171044749598, 40.27709737900765, 44.35438548364947, 41.39736552392283, 46.16358657037058, 70.50115216162898, 60.26671171188355, 69.48001015570857, 60.45302037269839, 68.61484512206047, 63.43652025345833, 62.97355113490936, 57.44545282856111, 57.501150485008, 52.26553940003919, 53.917751542983524, 50.1069845691804, 52.85315359792402, 48.38697425780758, 56.430123775236076, 48.299623074070105, 48.46186407150761, 47.664607032652825, 51.43681318529191, 48.73484142364995, 55.63628312080137, 56.7516012345591, 60.28769639230544, 56.942381397370376, 63.54356173546084, 58.384342731968054, 58.25529283092868, 56.11390229194395, 55.68996467897969, 52.803723889012495, 54.19442376782818, 51.46974540525868, 54.32391689669702, 49.87897719106367, 49.033808400554044, 35.046687356887325, 40.94900331189556, 31.568447159182643, 28.938278305915098, 48.00843023484754, 40.84839843934582, 21.6424834728241, 26.49841500866798, 19.7887634846472, 0.7182885730458844, 0.3511863490266185, 0.20334265645473235, 0.20221247758355834, 0.15978176327001664, 0.03162970578658485, 0.04029184279422607, 0.06805893709702839, 0.06514646233089509, 0.18208872677097399, 0.10729682676854635, 0.03685450969984935, 0.22250438469552228, 0.3476933251705862, 0.09290697593842784, 0.13741692948725917, 0.3400034571607267, 2.017916532293443, 15.755627539850051, 14.356256281175922, 26.134421017862138, 23.194537893418346, 22.47121557112663, 26.478034373252626, 27.084007224728985, 39.0825826891007, 36.85968137556507, 43.204503443933305, 41.97455013951948, 43.697753260212565, 41.09681783183929, 47.01414861986714, 50.77975734587639, 53.87271096629482, 53.38443863776423, 55.904447724742276, 54.03905868530274, 52.524145187870154, 45.28361066695183, 46.30458008858466, 46.36294103437855, 50.38070717165547, 51.44024918156286, 48.00523350315709, 43.28986990836359, 50.73479521659113, 58.28902129204043, 62.262833349166385, 59.103407321437714, 62.30548520242015, 59.4983115503865, 62.22026778805641, 62.6451506922322, 62.3220689835087, 59.590644144242816, 65.33303722258538, 64.13114847675448, 62.556677710625436, 60.974091560609885, 58.96015844037456, 61.013456467659246, 62.685021585033795, 64.75724897077008, 67.74188241650982, 67.46464929273053, 69.3750318404167, 56.74471355253651, 27.737444677660545, 10.738308122081142, 33.55859894906321, 63.990115734838675, 36.506985772040586, 19.805637521128503, 48.20318375864337, 27.044722726268155, 18.49159448377548, 20.916021293209447, 29.971407075082105, 33.74729633331299, 33.22027490985009, 29.474048576047345, 53.95842259930026, 50.80302092336839, 81.27325934748497, 27.200434938553844, 0.35638606356036284, 0.21031319854720948, 0.0929548794163331, 0.042720762862553524, 0.05324588014533924, 0.15690511843610197, 0.11030648744875386, 0.1522792190794022, 0.16086341813206673, 0.08097036080735345, 0.46186984366466927, 0.4869180689415624, 0.46189849535303734, 0.1367162041846783, 0.25632647707337336, 0.30256213560219736, 0.15430228874808358, 0.13142897176646418, 0.22473180065712622, 0.22206115686605055, 0.1350924348638904, 0.2503123344673265, 0.2648918456848591, 4.624311654798446, 87.01791563341695, 74.72621948488298, 43.53995630818029, 42.35976219177246, 57.97143874629852, 33.19178281291839, 40.08411284415953, 30.805453984968125, 23.928199583484282, 31.08775284982497, 33.73183435009372, 60.03367585520591, 57.63446400242468, 55.19665602714785, 35.76855251866002, 8.184262667932819, 10.455403251032676, 22.44601042039933, 35.45274680660617, 41.693406412678385, 46.43875260506907, 44.636062652834006, 53.761170525704664, 77.05125147296538, 62.90034009564308, 70.89542881135019, 61.2008398579013, 70.67117121911818, 66.83146107581355, 68.38411561904415, 60.79057954972791, 60.37703621772028, 56.22045740004509, 57.979871842169, 51.799824622369584, 54.63477257759341, 52.33757765062394, 59.523901093390684, 51.187475958178126, 51.68387543770575, 49.11225580400037, 53.73609481319305, 52.33080763970652, 58.40755531864782, 59.7257697966791, 65.93334028797766, 59.2332769978431, 66.50188784445486, 62.61414435602004, 61.9250427522967, 57.268161696772424, 54.7656463807629, 55.220256928474676, 58.226992930135424, 50.91202751282723, 56.61703648105745, 52.69130483750374, 52.063662852010424, 40.70037603378296, 50.90491233333465, 40.51549903808102, 45.80272851451751, 68.03891566491896, 61.024882331971206, 43.36670914003926, 32.437246268795384, 29.21259710865636, 3.5967671150161378, 0.5781300293822442, 0.4946047806691739, 0.18545530015422454, 0.38335980486965954, 0.20049809538308652, 0.3140449049251695, 0.2158296597941268, 0.2402369299482915, 0.4874842998481566, 0.35654807583458964, 0.17498704574761853, 0.8136134450474094, 1.0623091194898853, 0.40469354559336945, 0.2765949725383713, 0.598285312373792, 7.5019065603133175, 21.82936283849901, 16.89845519681131, 33.812462591355846, 34.870721986216886, 32.304889809700754, 37.37523378864412, 33.69579169058031, 44.79169445653116, 45.133474103866085, 50.81871040405766, 48.80634623189127, 48.33270042173324, 46.79409973083004, 51.68278894116802, 53.15255988028742, 57.34049412512011, 57.19435837961013, 60.379883858465384, 57.83038247016169, 56.22424640963155, 50.56198343153923, 48.821345375430205, 48.11229459701046, 52.11869370552802, 53.1820757158341, 51.82653988561323, 45.43199000820037, 53.37665665534235, 61.84134721755982, 64.13497278767248, 61.1821379969197, 65.80840495324904, 60.90444987820041, 66.33965076938753, 68.63178191646453, 65.04748867404076, 62.91614332506734, 69.11666531716624, 69.6779094203826, 68.36983819161692, 66.47701217282203, 63.18808909385436, 66.63466007478776, 66.6800497424218, 72.17216030243905, 72.32206544568463, 71.65398382371473, 74.4471977603051, 58.32748405395016, 30.58047271543934, 11.382284818157075, 35.961842998381584, 70.83590292161512, 47.554588471689534, 23.64249021776261, 49.66692209243775, 28.552693628495742, 21.769682015142134, 25.654597474682717, 42.75731794295773, 44.593281361364554, 40.46210381292528, 36.49080599507978, 68.75794103068691, 57.4726858446675, 89.99406107010381, 26.807234979444935, 0.9381713742210019, 0.5537990156200625, 0.28041594331302955, 0.23380502427537597, 0.294836996904304, 0.4162212076687044, 0.20978056825697425, 0.34534189489579975, 0.5633541545079601, 0.29888482163510016], [0.07023456551495098, 0.050518427104238546, 0.041244415671474514, 0.0999823495024635, 0.08151556260042614, 0.10033674943711489, 0.04481549622611173, 0.1671205638276954, 0.02453803944761955, 0.05826608112622654, 0.055295215138504585, 0.2052416352014388, 0.24395901409368365, 0.8075824944723038, 46.675640229255926, 58.56197118759156, 38.43487778017598, 32.34593741355404, 26.375068233859157, 32.69024110609485, 25.74816365395823, 10.787162223169881, 13.213406070586174, 31.75626201014365, 20.068132338985322, 38.65584058146323, 41.74840980960477, 45.23944477881155, 33.23057505392259, 10.550669777777888, 2.848756169119189, 15.360910604077002, 28.179478145414784, 34.835012728168124, 38.85883108262093, 35.6191219822053, 43.81167850186748, 63.27095700848488, 64.00217702311855, 62.38594478176486, 59.60038731175085, 63.658938254079516, 57.90648821861514, 52.40545426645587, 48.63655074950188, 48.260187564357636, 46.376504590434415, 47.839784006918634, 44.682436835381296, 49.64675718738187, 45.96897425190095, 51.083242893219, 47.95426230276785, 45.01545390775127, 42.9938917775308, 46.2459877229506, 45.09497996299498, 52.27092481428578, 54.4444081860204, 58.255857652233495, 56.207474354774725, 58.86223254665252, 59.06974161824873, 54.90930711069415, 51.90213964831445, 49.97180792593187, 48.01829891820108, 46.71228693377587, 46.91940376835485, 47.87061775884321, 42.86730904732981, 39.85733709027691, 33.85419268761912, 21.15606446419993, 17.08650342879757, 21.627947168965495, 40.93673806036673, 30.551531507122903, 9.111606094145007, 13.32386197582368, 9.134090100565265, 1.1763652702493053, 0.16567716224780007, 0.05843417230813254, 0.06841201936045001, 0.17975695431232455, 0.04323750448923919, 0.1820161169575107, 0.13264190345521898, 0.0638864238956763, 0.114028824403161, 0.09915063082570992, 0.0936357094155204, 0.040241116282319835, 0.12331196377354285, 0.21054133953106022, 0.11432808898990193, 0.2990933507680893, 0.15325133869003865, 0.7470188313914884, 7.8169459392947545, 15.909123612988381, 15.511560997655316, 14.513711987003205, 16.07019868589217, 19.831485940564065, 26.020558534129975, 28.11892459469457, 32.596586673490464, 32.666004780800115, 37.51633321085284, 35.90043829333398, 42.38866613757226, 44.868741573825965, 48.62329706068962, 50.11318583642283, 51.573139083000925, 50.096735415920136, 44.66422919304141, 40.20247428647934, 45.55852959232946, 47.2469412895941, 49.05406744249406, 45.831000958719564, 42.19153173508183, 42.02551349516838, 49.03318866606682, 55.93427734990274, 58.13761388101886, 55.94137291754446, 60.11926589473602, 59.576170598306966, 58.56890593805621, 55.668760345828154, 54.71772678436772, 52.754447152537686, 57.3949013217803, 54.799516047200854, 53.137576426229174, 49.604430890852406, 53.225916047250074, 55.81551582582536, 61.80525356723417, 64.2773901262591, 61.713175927439046, 63.14291515657979, 63.39348793029786, 49.0062851290549, 22.732484648304602, 10.259605396178461, 34.640133688526774, 62.77435748807846, 23.209931235159598, 24.85301798389804, 33.04447820109706, 9.158406834448538, 16.720864003704442, 13.896339747213549, 36.3942176295865, 27.202609892814394, 36.14579823709304, 20.92291681997238, 40.04282205335556, 41.20551063168434, 63.11103413181921, 38.86038041883899, 0.07520408594920751, 0.14749837077913747, 0.04815698406028171, 0.11646152128495517, 0.27062840399242216, 0.0497621527662681, 0.1170179539269978, 0.10412309303759568, 0.20776921973353435, 0.059273705081713784, 0.05618007733456551, 0.14402445315593673, 0.1602119522830171, 0.19460740018515818, 0.1408850708075108, 0.09330285187329977, 0.02057599932736447, 0.1504657817103209, 0.03581115157313405, 0.08245037372915015, 0.05558308799781146, 0.03199402464463586, 0.027131846535109708, 2.865905752105098, 64.46315357761999, 67.61911223011633, 47.267090505169286, 38.34944071308259, 33.601093907510084, 39.934482266826016, 28.01743522767098, 16.389642396280845, 18.926712812915927, 32.58328983860631, 22.72657952001018, 40.341608601231734, 41.315058508226954, 49.90097776536019, 39.675225365546446, 15.357361839663598, 2.7827777353025254, 14.22090607304727, 27.628047812369566, 34.895072060246626, 41.274305082136586, 42.76499009901478, 51.68505214875745, 69.6310684757848, 64.79985375558176, 64.11309772922148, 64.64195482192501, 64.49678005710726, 59.00446553384105, 53.10390287829984, 49.691256476986794, 49.882656374285304, 48.82023534467144, 51.17035089000579, 47.41445003017303, 51.154390765774636, 49.73334350893575, 53.19570202981272, 51.44346552510416, 50.195806641732496, 45.04996684289748, 48.054325888233805, 46.109885400341405, 55.059141651276626, 55.555603888727006, 57.411285061990064, 57.58169635649651, 62.898873129198634, 65.6004761880444, 59.42292751804475, 56.75032254188292, 53.71010126606111, 50.109432128167924, 50.90946620510471, 52.10436920965872, 49.76901354328279, 46.73073776306645, 46.669525254157286, 39.0401622556871, 34.18296575546265, 32.400456397764145, 25.052843132326682, 38.037784868671054, 39.45291719129009, 40.10159484801754, 48.25174662374681, 13.309010901758748, 0.5370908831396412, 0.15160627212495575, 0.2078071717293032, 0.046194887329493804, 0.30849337217307865, 0.19735036267628595, 0.10701347382799273, 0.08160850438739985, 0.12428857265941559, 0.09843518897410362, 0.1166908803486055, 0.13821519310435942, 0.054767729128680886, 0.05450205749741966, 0.11251203160011962, 0.045949444249873204, 0.5019963646848355, 0.09616664175184504, 2.0857424024612676, 14.170311420194565, 26.3250619365323, 24.90645439394059, 23.355368798778905, 24.851223499544208, 27.592707257116995, 33.36931320928758, 34.72801439223751, 39.965629808364376, 39.95616120676841, 42.35576921893705, 41.365190321399325, 47.48604897529849, 48.63810400809012, 53.092037708528586, 54.019462523921845, 57.55600483186784, 54.55914928067116, 47.168788063910704, 43.09773652784286, 48.27353539005403, 50.55623715923679, 52.2176472602352, 49.37896520860734, 46.76136755174207, 45.499501843606275, 52.07781476359214, 58.63903007199688, 59.763420627963164, 58.580363181329545, 60.94773715542209, 59.6129192844514, 59.933392617010306, 57.13844107043359, 56.08445705906038, 51.330564022064216, 53.99297868051837, 54.9178578776698, 53.20581390011696, 52.448749388417895, 54.12884173854705, 56.96670793717908, 61.49830456702941, 66.43538798055341, 67.39552144081362, 68.34879075327228, 67.98118622072282, 50.423743417186124, 23.087378740310672, 12.207534832339134, 42.30363307460662, 65.09598485885128, 25.70716311854701, 29.847564120446485, 40.443158764992994, 18.466308924459643, 19.233118564851825, 19.429603815078735, 33.942661746855705, 28.55415471138493, 39.118280180038944, 27.848694862857943, 51.52501160098661, 48.564179097452474, 69.1079576553837, 51.356953728583555, 0.29643407572180996, 0.08172945434888525, 0.08372634679319398, 0.03400732860750249, 0.12996775098145008, 0.1888001166404255, 0.055600405415339824, 0.06442342854795918, 0.08531438577319346, 0.05058025039972798, 0.3478781668649566, 0.5502031214775578, 0.22515731653378857, 0.2653986281685291, 0.30663655890572455, 0.3409575430616256, 0.1809713875334109, 0.29252261464153567, 0.23918250185107034, 0.2709351455973041, 0.20717927074480444, 0.27645814923509476, 0.2859865363326765, 4.083374642556714, 79.82879161834717, 73.67502427870228, 51.90959607401202, 46.440431379502826, 40.9284108684909, 48.7640630814337, 37.36975815988357, 15.126741182419563, 17.262535479760942, 46.41213147870956, 29.66191245663551, 48.73302144388999, 50.93190608486053, 54.23288652973791, 44.03022904549876, 16.349450849717666, 5.789321785972965, 19.653053399055235, 34.26820670404742, 38.863510470236506, 45.53299496250768, 47.061872097753714, 59.31505841593589, 79.69413665033157, 67.37877292017784, 66.05221948316021, 64.7496081936744, 68.66285493296962, 66.06076240539551, 57.17096536390243, 52.51115037548927, 53.08278091492192, 49.68837745728032, 54.150552057450824, 48.75635170167493, 54.829985018699404, 53.611410510155466, 58.50254727948097, 51.953820797704886, 52.20203622694939, 46.68649342752273, 51.11900706445017, 49.0721260347674, 60.549090985328924, 58.496746093996116, 61.394389214054236, 61.009679225183305, 69.78010285285212, 69.17633241222751, 62.19593340350736, 59.77066132330126, 53.765265480164565, 51.754195690155036, 53.739632791088475, 53.123475505459695, 53.04036832624867, 49.498424914575395, 46.970308288451164, 45.208191333278535, 44.83213409300774, 40.39059508231379, 42.48565850719329, 56.405789390687026, 60.1832946654289, 50.038405849087624, 63.20850110823109, 36.00132557653612, 2.3480587524752465, 0.47029034504967354, 0.5991406342194927, 0.16135282574161408, 0.2971808275868816, 0.25249052161891616, 0.36536648328746524, 0.30113013341061534, 0.2502099697988841, 0.23253437552240588, 0.3359556324299305, 0.22838830767619997, 0.13344304756291453, 0.7004221156239511, 0.7001365180457793, 0.3453420174698676, 0.7058777648114389, 0.16059265201610906, 2.971412116481412, 15.502223795460118, 31.857223818379065, 29.10161364463068, 33.58047008514404, 34.08853469356414, 36.62999914538476, 40.93875023626512, 41.00440679057952, 45.42456103909401, 47.06366069855229, 50.76569957117881, 45.475418490748254, 52.68409159875686, 50.627412488383634, 55.772679621173495, 59.17825006669568, 62.43354666617609, 56.478820000925374, 48.77412788329586, 42.7080019827812, 51.31298395895189, 52.12070588142642, 55.75221661598452, 50.58390163606214, 51.427909405000754, 46.89810922068935, 53.839684609443914, 59.1880089236844, 62.98734218843522, 60.214206864756925, 64.25542485329413, 61.59380643598495, 66.22832605915686, 61.678678681773526, 62.10697012562906, 56.95181077526462, 62.58671129903486, 60.825978940533055, 60.51402499598842, 54.93376701108871, 56.54868918080484, 59.2807690558895, 66.38007471638342, 72.59507025441816, 70.51129541089459, 71.64316592677947, 69.79454501982659, 54.75865671711584, 27.561657774832945, 13.615965785518771, 43.645319015749045, 70.78734397888184, 35.445200166394635, 32.58552755078962, 41.722914403484715, 16.89510941505432, 20.90062795146819, 21.664878245322935, 50.533742366298554, 37.0069153847233, 47.36645983111474, 27.628006627482755, 58.34562109362695, 54.09071237810197, 80.62439733935942, 55.95071600329492, 0.24370815094199874, 0.2182493178594497, 0.2727603041116269, 0.3723757894289109, 0.48542674090112414, 0.6750574347472961, 0.3832873942390565, 0.25554998567508114, 0.4998360886689156, 0.23154914048650574], [0.1243228627549064, 0.042137344773378105, 0.015748437858306836, 0.09267479001033692, 0.022472174192268043, 0.04483350695321157, 0.10942036886849713, 0.06588382195801505, 0.13130952333731036, 0.05542369957472529, 0.05527996232793216, 0.1275304116068348, 0.012796604367453727, 5.0453383787985775, 66.4403772354126, 55.130634692407426, 44.2667361997789, 33.20430301850842, 42.12320404668009, 26.9408622864754, 30.845044428302398, 18.406237825270622, 21.461724965803086, 22.71925057134321, 31.417998767668205, 21.273839512178977, 41.15630057550246, 56.682092912735484, 48.85384221230784, 21.719301131463823, 3.8536730456736783, 7.946754328666195, 22.626461021361813, 29.128507375717167, 33.704032590312345, 37.171035197473344, 48.75708910726732, 63.64457845687867, 64.73071413655435, 64.26816863398399, 60.34232716406546, 57.6151071056243, 57.76567512942899, 50.75341078542894, 50.114456684358665, 47.56415121016964, 46.53419956084221, 48.33938414050687, 49.354587677986395, 52.35356130907613, 49.99936257639239, 51.1287659214389, 50.824660639609064, 48.53601255724507, 45.72692086619716, 45.5619812780811, 43.64244391841274, 46.87668131243798, 52.78765001604634, 57.88256568293418, 57.98168005481843, 57.339972449887185, 55.68456749762259, 55.85772837361982, 52.17113971710206, 50.98450114650112, 49.157406207053896, 49.011144945698405, 47.84434180105887, 43.79434947044619, 39.20704733940863, 40.17087567237116, 31.83318361159294, 15.46638607978821, 16.0352837078033, 18.53026120893417, 32.02380491841224, 32.92304554293233, 37.65088619724397, 18.312287253718225, 3.7363507863013976, 0.1450448363058029, 0.09783068431481239, 0.20286346845809491, 0.3691069228995231, 0.07853769456907626, 0.012629243841905509, 0.05380628878370889, 0.03659533832462565, 0.03967047270928179, 0.02772844325180256, 0.12254455817803261, 0.22038509438355125, 0.12973354258123906, 0.07441906799231807, 0.3411083704521579, 0.8551474228020638, 0.1247080670849931, 0.16655528287012733, 0.42872777689368496, 3.4442175588300152, 11.398268476609262, 14.862153780075813, 15.717595258066732, 11.815339980586884, 17.02876025630582, 23.409052318142308, 25.04758715629578, 34.0127113557631, 32.94094331802861, 35.60439348220825, 34.47146784874701, 41.24911954326015, 46.18381031097905, 47.83337485405707, 49.01327871507215, 50.23327704398863, 49.3561880050167, 41.1320956291691, 42.07247211087135, 46.28492116928101, 51.08164648855887, 51.08140722397835, 47.87256325444868, 44.37164783477784, 44.09258688649824, 52.964752874066754, 56.74578435959355, 57.02650839282621, 56.88238090084445, 61.08659690426242, 54.929181760357274, 50.4652891620513, 50.15570825146091, 47.69877479922387, 44.732396064266084, 48.043484457077525, 44.80213188355969, 47.91105347294962, 48.566814930208274, 52.95713170882195, 56.93175569657357, 60.71304998090191, 64.08182859420776, 62.98393364875548, 66.33798768443447, 64.42973106138169, 43.01939895076137, 16.689663510168753, 8.973569062448318, 45.87240157588836, 50.63475908771638, 21.993396359105265, 17.485049578451342, 18.586496230094664, 26.160736199348207, 23.80617072505336, 17.044679195650165, 32.511420249938965, 30.082694522796142, 32.00452058546005, 26.629233898655063, 42.33394122892811, 47.231326333938114, 53.578909750907656, 57.19085962541642, 2.4717705528582297, 0.13675882931678526, 0.030196801526471976, 0.07765784258804015, 0.10915364769677963, 0.12201483136103039, 0.1269627864202184, 0.06303021721842308, 0.008058646457239745, 0.05981815227818105, 0.15749370378832664, 0.026198462245144674, 0.10437510532116699, 0.12654603458940983, 0.045513658964585875, 0.043436989954282204, 0.18381829283410506, 0.23633328296484488, 0.05791674886319426, 0.20789461300498058, 0.05032231242606237, 0.1559229783954159, 0.17896386944959242, 10.4516524845554, 84.12890957247826, 65.03357210466939, 50.65741469783168, 36.0384351207364, 51.82013857749201, 34.90016721910046, 33.671174895378854, 23.280535859446374, 24.82535154588761, 25.15450312245277, 30.99388857041636, 24.7413912511641, 44.20591592788697, 59.73323014474685, 58.694923846952385, 28.312866187864735, 5.320204352178882, 7.269228619913902, 22.178734233302457, 30.47427454302388, 35.783810538630334, 37.82170149587816, 53.45794385479343, 67.54979610443115, 67.12221068720665, 68.32447990294426, 62.795502985677416, 60.002085085838075, 61.12981750119118, 54.37111869935067, 53.91006369744578, 52.33932702772079, 50.00245340408818, 49.33699584776356, 52.24151096036358, 52.97570020921769, 53.23811854085615, 56.05813403283396, 55.756170365118216, 53.48836575784991, 48.33298283238565, 46.76696477397796, 48.42383669268701, 48.91427416955271, 56.66918831486856, 61.379464595548576, 60.358130393489716, 57.69667279335761, 59.898507056697724, 58.650620675856075, 55.91257487573932, 54.95453596115113, 53.62201659910141, 54.86237202921222, 51.659658724261874, 51.95642132912913, 47.46755892230619, 50.42185675713324, 38.90873147595314, 26.857888467850227, 24.306316068095548, 22.28514813607739, 23.562432681360555, 43.1636990270307, 56.70707448836296, 32.623521589463756, 3.0839157440970024, 0.08490481218623538, 0.020650888252402508, 0.19823142507624245, 0.15236143563543597, 0.10493551395953664, 0.249562181171871, 0.06810841871605766, 0.027586910423011552, 0.0264803845164997, 0.06201643774646425, 0.17366836328179608, 0.1615489289284714, 0.13325763896348017, 0.20986774906275735, 0.11594779038381194, 0.6809265875527937, 0.1364027516495797, 0.24191328354420202, 0.1963267926006548, 7.357739844629842, 19.82885403017844, 24.98286412608239, 23.085543071070028, 18.436098829392467, 26.763631951424387, 31.576976353122344, 32.49396962504233, 39.93260737388365, 39.590364886868386, 39.1692788370194, 39.690699115876235, 47.234499531407515, 48.74960130260837, 53.55254750097952, 52.942034506028705, 54.23009380217522, 50.18114089965821, 44.847062633883574, 46.013752029788115, 51.30498232380037, 54.064032416189875, 54.95424962812855, 51.020339842765566, 47.16903125086139, 46.20517153893748, 58.16026556876398, 59.23960378093105, 59.906704810357866, 60.652327768264286, 62.568425209291526, 54.573312959363385, 51.194857858842425, 51.63685014170986, 49.60146557900214, 48.17077321390952, 49.01355720335438, 50.12965194640621, 51.293948696505645, 52.43148311491936, 54.40754967351114, 58.58618397866526, 63.46970350511613, 66.2611327632781, 68.09838664147162, 68.7312218450731, 64.47763889066636, 46.8139273120511, 16.471091393501528, 10.432062206729766, 51.333650927389826, 55.7701143910808, 26.601902823294363, 21.201456093019058, 23.24641320013231, 31.60144998181251, 25.68189717108204, 23.174947615592714, 33.45959440354378, 29.820648816324052, 33.35671847866428, 30.180247791351814, 53.98062321447558, 59.633931421464496, 62.16093801682996, 69.71223015939036, 6.89345722236941, 0.29444871290076163, 0.09610568413571005, 0.08073737814782128, 0.2646771878484757, 0.28449683239863766, 0.056280208856708584, 0.03125684696339792, 0.054661737033917066, 0.07414799544119066, 0.4006359762241764, 0.17595037066888425, 0.1339410353572138, 0.4867297645297743, 0.07742465308476841, 0.16152449072368685, 0.23642619410830162, 0.4821237068503134, 0.24961881039123385, 0.4447067162442592, 0.2961580695644502, 0.32145652980093037, 0.42537574385923727, 13.607179676332782, 100.43772466721074, 70.8516316260061, 60.0072390802445, 44.68633567133258, 61.11531649866412, 38.776779020986254, 45.0872685832362, 22.879312692149995, 26.927449741671165, 29.899947374097763, 44.52797782036566, 32.565162604854955, 51.78948525459536, 62.89130295476606, 59.597727944774014, 27.398773508687174, 6.458651211953933, 9.74807047074841, 27.02993735190361, 33.56572589566631, 40.357706008418916, 41.4452027505444, 59.08135575632895, 74.32844408096807, 69.21123366202079, 71.08976656390776, 64.7155188745068, 62.459979518767334, 64.09251705292733, 58.19360963759884, 59.50477953880065, 55.49599562921832, 51.96113994044643, 51.274729082661295, 51.92448539118613, 55.12797924780077, 55.1836141463249, 59.43915044107745, 58.22853049924297, 56.4229223035997, 49.81289702077066, 48.947551558094645, 50.61504133286015, 52.923101225206935, 58.95881306740546, 66.51505131875315, 65.84172941023304, 63.79173794100362, 64.73214187929707, 62.44663169307094, 55.98167134869484, 56.96678638458253, 55.15724405165642, 57.16141831490302, 56.314068686577585, 52.77227040260069, 49.577758773680664, 54.77724090699227, 44.83099268328759, 36.1998837993991, 35.68382540056783, 43.616568042385964, 40.50312396018736, 56.64491668824227, 73.53145768565517, 58.5869017724068, 15.863057336499615, 0.26146308128391543, 0.21515855145069862, 1.0376407206058502, 1.4014507277357964, 0.2825700906255553, 0.29116927435801876, 0.2548939539420028, 0.3220082356804802, 0.16953633016636296, 0.15483836643397808, 0.41509033931839856, 0.29749455591363294, 0.3574717633666531, 0.21838309213278756, 0.42473069782699313, 1.4078429653759927, 0.20912927094726794, 0.4767883334669375, 0.3170087458866258, 8.697842128815191, 25.44390736087676, 34.87158883002497, 33.530793266911665, 30.442628860473636, 37.100934597753714, 40.696084960814446, 38.84975079567202, 47.04648071719755, 46.08999113882742, 45.585448818822066, 44.2541689257468, 52.233277905371885, 53.87613911782542, 58.240164249174065, 56.55013653539843, 57.36334977611419, 54.78510133681759, 46.660299839512, 47.24785127947408, 54.22133514958044, 59.826531564035726, 57.79519880971601, 53.091563101737734, 50.51813525538291, 50.70282789968675, 60.68254178570163, 60.56555317294214, 62.545389129269516, 62.44143063022245, 67.14531344752159, 58.82370310444986, 54.53150833806684, 55.617698930924945, 53.80139050945159, 46.75735888942596, 52.27908726661436, 51.16700118587863, 53.4114049326989, 53.11975709853634, 56.374504566192634, 58.83992994985273, 67.07412242889404, 69.69894116924655, 72.02926835706158, 72.71584003202378, 70.30803818856516, 51.42891745413504, 20.8620749750445, 11.697242317661164, 54.52047471077212, 64.22868605582946, 35.523337702597345, 26.21517085259961, 26.371304719678818, 38.874669613376746, 31.502933771379535, 29.11479869196492, 47.42015707877375, 41.3969026842425, 43.81182755193403, 36.51631709068052, 53.7172870482168, 64.29463678790678, 63.8947589935795, 81.97930166798254, 6.251017605104755, 0.5239305344800795, 0.14278331410980996, 0.2760910705452965, 0.5485925595125845, 0.47887013143589424, 0.2656934188017922, 0.26082373494582795, 0.20499262598253068, 0.15966346397274928], [0.04830317278843253, 0.08707022865212734, 0.0326535822973857, 0.13324718952419298, 0.09601793642486296, 0.05497642297057375, 0.11835936622153367, 0.09903550313244905, 0.06583768814321488, 0.09244176138552929, 0.12483211204169259, 0.05170386389739091, 0.3202010649106195, 14.12385682905874, 62.578195833390765, 46.582225061232045, 37.75864547298801, 40.187071138812655, 32.985721095915764, 30.991662625343572, 32.6248904966539, 20.76339598624937, 30.115340409740327, 19.677411317825317, 32.54934172476492, 22.20144279541508, 37.0297828028279, 50.304005222935835, 53.01382172492243, 37.70692509989585, 8.077267273779839, 5.101401305967762, 12.834641414303935, 25.541646942015618, 26.597956918901016, 35.07861152771981, 47.26924388639389, 62.53039390810075, 62.27384344224007, 63.94334539290398, 61.149896114103264, 60.33442751053841, 56.81269607236309, 54.7982059755633, 48.53898179146552, 46.568708573618245, 47.05946768483808, 50.78585663149434, 52.28976395822341, 53.34836459928944, 52.32486524889546, 56.01764732791532, 54.94424758418914, 52.33640878431259, 48.59529133765928, 46.01615252033357, 44.61393656269197, 46.0192511927697, 51.34519838517713, 54.78664675066548, 55.82927550038984, 56.648933195298724, 58.201426921352265, 57.59393807380431, 53.258416806497884, 51.520077259309836, 47.91602311595794, 49.669934472730084, 48.16083785026304, 49.610400738254675, 44.0846440868993, 40.861099073963786, 33.17892920586371, 6.40523539435479, 10.776746369177296, 16.100890251897997, 17.40528621981221, 36.78743131699101, 34.047883249098255, 5.192518455366935, 0.5240201361237035, 0.07386286517665272, 0.06956709608916314, 0.037835868330852646, 0.1031825592320773, 0.7310640391322875, 0.4319569600685951, 0.031012855620393832, 0.13883316558935951, 0.046472019636102264, 0.1383344729941699, 0.01610507764252684, 0.008150214073999275, 0.030933207374126203, 0.11227706477286355, 0.05390272393161732, 0.320670063937864, 1.0321752654929315, 0.4205160191462886, 0.493377078805239, 1.071762889623642, 4.702367311523807, 11.728618337262063, 14.556146148712406, 10.829632666803176, 12.306629592372525, 21.631463573824977, 23.83278596785761, 30.607833208576327, 31.861297199803015, 35.16005169960761, 33.87538133128997, 41.35589038172076, 42.774329262395064, 48.18297962988577, 47.045790380047215, 49.97733454550467, 42.463191170846265, 39.288232557235226, 43.7706583546054, 49.99490676387664, 52.61111590170091, 49.94996816881242, 48.042488175053755, 42.45776261052778, 45.36451739649619, 51.67394791879962, 57.000805101087025, 56.52094625657605, 59.73457944008612, 56.38691886778801, 52.98101502080118, 46.03906700688024, 49.338023508748705, 46.18397112815611, 48.55302779905258, 48.10360654707878, 48.42644114648142, 51.56758108446675, 56.327973488838445, 55.207987754575676, 60.93949233331988, 60.88282192907026, 68.29663891946116, 64.9306373442373, 64.00180439795217, 51.674242096562544, 37.679578335054465, 8.911254367520733, 9.654869071898922, 51.058249550481, 46.22916075491136, 18.85633372491406, 12.085135309926926, 23.33511760157924, 29.887470314579627, 26.417755388444473, 19.122821515606297, 28.425177374193748, 31.42696922825229, 34.70703363418579, 27.592513099793468, 25.980175772020896, 37.786137365525775, 45.076976283904045, 70.16628373053767, 19.29207963328208, 0.3497702814638615, 0.15537036853211542, 0.08636113766941332, 0.09829553880638654, 0.15748967416584492, 0.06253822023169169, 0.04438636058400716, 0.1554739742629951, 0.15479021014705782, 0.025553661361036283, 0.07917308789347449, 0.06466496840960557, 0.10303387688773294, 0.03690423263657478, 0.08607956205284403, 0.06385864554754188, 0.04520571460166285, 0.050474488131341436, 0.042006048794475295, 0.07865751072043374, 0.17925395630300048, 0.22498696922294556, 22.55440119774111, 76.4782637934531, 54.50325550571565, 37.964440468818914, 41.00168074330976, 38.46470348296627, 36.62641409904727, 33.13645778163787, 25.133771434906993, 27.40897559350537, 21.406252845641106, 33.2139402820218, 30.098809580649103, 41.97436971049155, 54.65460408118464, 59.74881372144146, 47.30254480915685, 10.502441294731634, 4.5891691792395815, 11.004929273359238, 23.69821336961562, 29.617385710439375, 38.01844366135136, 50.6108404744056, 68.03102385613226, 67.27534786347421, 69.46043752854871, 63.22763442993165, 61.70276203463155, 59.60965587246803, 58.09567589913645, 54.56462098706154, 50.699842975985625, 51.42484995626634, 55.50284016516901, 54.90117995969711, 55.47217899753202, 55.13349410026304, 60.38723045779813, 57.04639088722968, 58.219716933465776, 54.94594204810358, 51.053781970854736, 48.33603443637971, 50.020837553085826, 54.23885637714017, 56.4521518061238, 56.21311472308252, 57.31998797385924, 58.54221813140377, 61.60877027819234, 59.16577692954772, 55.80716902209867, 55.964848303025775, 54.85997546103693, 52.188939432944025, 54.94997424464072, 53.36117898264239, 47.231114525948804, 40.42881073490266, 18.585256761120213, 21.650753790332427, 17.730735078934703, 22.35511733639625, 46.21575801603256, 42.05539803351126, 11.550311311598747, 0.572105207510533, 0.019199607458205956, 0.010838129317327853, 0.033445629110980424, 0.13864368140216798, 0.4292044368001723, 0.07180869233824554, 0.04982920078140113, 0.02287925224781277, 0.06878119713116078, 0.05216083151378459, 0.03731465275068918, 0.03018236651475872, 0.03960285395864518, 0.08592288941144945, 0.14495992312027564, 0.2945536056593541, 1.0156844568348702, 0.8014497461338198, 0.2563638468423198, 1.309041402512981, 9.509689404118447, 20.225680220511652, 18.120787335980324, 15.587110750136839, 24.593776772099158, 30.542496327430975, 35.690548343043176, 38.87996481310937, 40.813124564386186, 39.4186003746525, 39.939389151911584, 44.68367630435575, 49.54432056796167, 50.88514358766618, 51.10376473396055, 49.816121209052305, 46.02888061154274, 43.29670659957394, 47.66504633811213, 52.00632172246134, 55.0063112474257, 54.51990204472696, 52.22126760790425, 44.716898779715265, 48.84091800259006, 57.39441102550876, 61.02842815460698, 58.3873825688516, 58.806742775824766, 59.139685323161466, 53.560851158634314, 47.722815006009995, 50.6022975521703, 49.87489400371429, 54.153564437743164, 51.42332415426932, 53.59615641255533, 57.45849470938406, 62.45817522848807, 62.49888550850653, 63.654823687768754, 63.50307895291237, 67.62206969722625, 66.45813772755285, 69.36056613922119, 53.710356220122314, 34.92344648607316, 7.97940904094327, 13.525781669924337, 57.14541504459997, 49.561073010967625, 25.355705022811893, 11.178004837805226, 22.84567052318204, 27.113370087838945, 26.668179112095988, 20.32545158939977, 31.027924937586633, 27.393382210885328, 37.51230493668587, 28.855871269779822, 35.736169430517386, 44.75285514708489, 57.469759756518954, 79.87709168464907, 44.43495096698884, 0.2762964127525207, 0.07426258687290453, 0.2162229846562109, 0.1832357289329652, 0.12027860033295809, 0.07744710712182908, 0.17837569778484685, 0.06260573556045852, 0.06357608167755027, 0.1554663287055108, 0.16475122241723925, 0.2384749124006879, 0.24100055106945578, 0.18679578548237202, 0.19722863130511778, 0.22522796516216573, 0.16728715730770943, 0.15790968953121096, 0.20870340267016044, 0.2347800703418832, 0.3946099592553031, 0.2220714530877529, 27.365129378534135, 90.25848373290032, 59.19555164152577, 51.00794515302105, 53.695525738500784, 43.26518251049904, 42.032338419268214, 45.2866034353933, 24.87051175486657, 40.157978919244584, 24.98094020351287, 40.96073512108096, 34.42806290042016, 50.30769225089781, 60.665255900352236, 61.2976949445663, 43.260609026878114, 10.809845289876385, 6.377271346507534, 16.290946737412487, 26.96524177828143, 33.52812997756466, 41.56255222135975, 55.81320162742369, 73.28038677092522, 72.2452340587493, 73.70825459880214, 65.73469577297088, 63.13339556417158, 64.1560947510504, 65.37945847357473, 59.262126030460486, 53.77137653289303, 53.337217223259714, 59.050345497746626, 58.16121870471586, 57.30387879956154, 56.56932084791122, 63.62776717832012, 59.39214475693242, 60.982956117199315, 54.87925391043387, 53.45400187277025, 52.635964116742535, 53.2074652179595, 57.43752571844286, 61.07881492184055, 58.895062784994806, 59.47170611350768, 62.09479116624402, 65.3900763296312, 59.59712782213765, 57.429696667578916, 58.492360884143466, 60.17753662601594, 57.0007658773853, 61.24397808505643, 60.375581018386356, 53.502443144398356, 45.665676978326616, 23.323574066162113, 32.02080822760059, 34.539014985484464, 34.23199930498677, 57.66671372998146, 56.21550736888763, 21.195564693020238, 1.3933213704055356, 0.14429852877172733, 0.20147459701664988, 0.15254180337632858, 0.26167666659720484, 1.9898552832103547, 0.6539124274446119, 0.1349340998117001, 0.21383986898487617, 0.204243790358305, 0.3103054459056547, 0.19743642499369962, 0.20720157922515947, 0.06656442213082506, 0.2912593356543972, 0.35282255961529674, 0.5706374443346455, 1.6573546153883782, 0.8656438692442833, 0.5640914988133215, 2.126511027736049, 11.733701729005384, 28.566421924098847, 28.130423022854714, 26.588360840274444, 34.8899180658402, 40.28075695037842, 44.009817031122026, 44.446871049942516, 44.57625043007636, 44.48729891930857, 45.67281569204023, 50.00414786800262, 52.08694604135329, 54.041961239230254, 55.72616031092983, 54.216863647584, 50.687507121793686, 45.70162942332607, 49.87570985671013, 54.080059220713956, 58.60509764763617, 55.776711817710634, 55.33271912605532, 48.95552965902513, 51.804586379758774, 57.778450289080226, 61.32145274070002, 61.09242554633849, 64.00491091512865, 63.692062670184725, 56.22819623639507, 51.7257506616654, 52.14377334040981, 50.577076711962306, 54.657475256150775, 53.03412783530451, 53.947934181459495, 59.55849639831051, 62.193485844519834, 61.3327334773156, 66.22301516994354, 65.72651370879143, 71.31553034628593, 68.48651301476264, 70.70582928196077, 58.16688260724468, 43.50134841857418, 11.297513573400437, 13.326863569598045, 62.685472657603604, 58.43931082756289, 35.71834618045438, 17.798866648827833, 30.210995251132598, 40.72153722086261, 34.75759690807712, 28.35414521155819, 41.175735919706284, 43.71297205648115, 47.31247232806298, 36.407349724923414, 31.864774380960775, 48.7919040649168, 58.24359632307484, 88.56907967598208, 45.49414388595089, 0.35308811633336934, 0.27015002804898447, 0.3040873247288889, 0.26575571707179474, 0.2336044931003163, 0.1089388749472076, 0.3014748423330246, 0.4006178659056464, 0.21387331638365023], [0.0546295651715369, 0.07999210483244351, 0.01467367204191584, 0.12158075828225383, 0.09937965281067357, 0.05296322817523634, 0.11742082424461843, 0.0034447473890688875, 0.028661620698028037, 0.05521949117762908, 0.1212152194291834, 0.11769471599930718, 0.17289994645022577, 29.369266379264097, 69.40011932003883, 48.20641971403553, 60.739561280896595, 31.624040872819965, 18.455675378922496, 30.71505315842167, 36.067080190104825, 25.553996524503155, 37.34044236521567, 23.525762442619573, 20.44383656594061, 37.08053042811733, 31.814919094885553, 54.16385673707532, 31.867580836819066, 31.78305768197583, 14.121206287414799, 2.8733410950629943, 5.502286168836779, 17.52657178909548, 19.678284045188658, 29.127160041562973, 39.271476191859094, 64.59270554204141, 65.73052237110754, 66.7687580662389, 59.882205686261585, 57.01049335541264, 54.61008517972885, 54.79549169540406, 49.74045476605816, 52.870333579278764, 48.7878091104569, 50.8878892467868, 51.76281313742361, 53.67580013890421, 55.367981233904445, 57.51568286649643, 58.03794645494031, 54.656780996630275, 52.60151393951909, 50.98754098338466, 48.399192440894346, 45.08516227045367, 44.4720644335593, 53.11826267550069, 54.12988508901289, 54.961961007887325, 55.95112785216301, 59.26821354896792, 57.628537301094305, 53.77076856551632, 50.415894754471324, 47.64822721481324, 48.43737279215167, 47.20821180651265, 43.673077629458525, 37.95532095816828, 37.007284087519494, 4.366312853751644, 12.246479065187517, 11.298006811449605, 18.073512969478486, 36.20122524999803, 19.151368525720414, 1.778446640218458, 0.45515492979076605, 0.06717343138711107, 0.02502826102558644, 0.033820253766832814, 0.16026672756960317, 0.10672893345115647, 0.4365338144763824, 0.11594163103690071, 0.024892012288253156, 0.032505267675245, 0.057102006694842736, 0.040360292750260526, 0.019393818407890298, 0.02739956362112876, 0.019622175811579632, 0.026782089093279456, 0.14269789530625268, 0.5804418988766209, 0.3972957715872796, 0.022262873225695184, 0.1447931151356428, 2.193348215472314, 7.453300058841706, 11.050629788829434, 9.562685528109151, 10.583758892551547, 19.757574758222027, 24.56037190652663, 30.050003528594974, 30.497289050009947, 34.18009065812634, 34.43340124622468, 41.160556347139426, 43.60207880696943, 44.32308104730422, 45.39368021872736, 41.41109381952594, 40.35037509856686, 43.19309719147221, 48.213315240798465, 51.831238885079664, 54.4481618942753, 54.131097101396136, 50.075613452542214, 41.84317427296793, 46.90286705570836, 55.62510436581027, 59.726264015320815, 58.30132576727099, 56.34923665754257, 53.77396529720676, 45.95191978639173, 43.95032644271851, 43.7539961261134, 46.835982799530036, 46.34878912279683, 47.51150908008699, 55.23608369211997, 60.75439176251812, 61.6474840717931, 60.98284236846432, 63.5477900505066, 62.42568623635077, 64.76607430365779, 63.646331756345695, 62.094771554393155, 45.42834612631029, 22.416800529726093, 2.3122408938023353, 27.428187362609375, 60.890458783795765, 44.3350128973684, 14.097847592446113, 10.894127218954026, 22.223262940683675, 34.33423588352819, 26.509132885163833, 26.14094195827361, 27.807945359137754, 30.513780655399447, 32.86533571058704, 27.794217063534646, 24.292266138138313, 32.015309064619004, 36.16262912750244, 67.0890352802892, 65.13827193167903, 5.180995022096942, 0.06277843476122906, 0.05583014752295229, 0.19978138948640517, 0.01865483658959068, 0.07274256883970193, 0.04048393168036015, 0.08289958470531049, 0.0370045326980612, 0.048752019872828845, 0.07027397307777597, 0.008536006376567868, 0.0037563883656290395, 0.039124704011145144, 0.07453352918908482, 0.09068556610615024, 0.017364236991852522, 0.04699164558382285, 0.03550784970303217, 0.062203562382849, 0.04216870458255853, 0.15467344302563898, 40.6007242971851, 77.83612558918615, 53.308525085449226, 64.70292022151332, 33.855283106527025, 27.94976649745818, 34.30845022201538, 30.68183264424724, 26.07155719111043, 33.329622745513916, 23.631299695660992, 26.37301879544412, 48.288518844112275, 33.150786199877345, 53.83491500731438, 31.162919190622148, 34.96381551988664, 19.052118832065215, 4.5166935843806115, 4.366776183728249, 15.22901894584779, 21.37223412913661, 30.266704674690004, 42.69428937665878, 67.3881866085914, 65.97880840301514, 65.61441629163681, 62.66187175627678, 62.93457062013688, 57.51614178380659, 56.691722331508515, 54.09224602483935, 54.30705854969641, 54.17885980298443, 56.182743810838275, 56.0959731378863, 58.42103650493007, 57.32061947545698, 59.5164603571738, 58.719277843352295, 58.742690470910844, 56.338132427584746, 55.89415542541012, 51.050753901081706, 48.36758205967565, 46.914536106971006, 54.39616303290091, 56.94046728072628, 59.66683226246988, 60.265617370605476, 60.65756413244433, 60.15455545917634, 58.492113774822606, 52.99831267326109, 52.74129152297974, 52.96043826687721, 51.85697355578023, 48.51840503754155, 45.65489830509309, 41.40061324642551, 16.515857404278172, 21.577479993143392, 15.08457374188208, 26.283233781014722, 40.939346436531316, 21.475733710873513, 4.4760877374679815, 0.27266959930139206, 0.07099761973105131, 0.057087420380764434, 0.011995591452315211, 0.21495941455566117, 0.12242470372227893, 0.06657775206070754, 0.007617322356259872, 0.18869982040937872, 0.03154854451666676, 0.03338932930942505, 0.05946347655187692, 0.06283723583985722, 0.05721667856578866, 0.05119978953453322, 0.0750900614225576, 0.2380405405476209, 0.7643723776263576, 0.790097426262594, 0.2371772513875077, 0.23535075988019669, 4.936236181566793, 12.106898580828021, 16.628894229089063, 12.303069060848607, 22.775260056218794, 30.391459580390688, 35.008624676735174, 38.661429958958784, 38.78786363909322, 40.37078319057342, 40.81943173562327, 44.77547153349846, 47.11671467750303, 48.13983355799029, 49.0445831514174, 42.761934572650546, 42.65595605296474, 45.76115531306113, 53.68082077272477, 56.01907899302822, 58.12234017156786, 55.60364115622736, 52.11633636105446, 44.55321435005435, 51.10533368202948, 58.7347202147207, 59.713837946614916, 59.40743023349393, 58.33884716033936, 54.53242617268717, 47.740375457271455, 46.85951702056393, 47.58343750430692, 49.423884191820704, 50.53802167215655, 52.12211793468845, 60.79093256304341, 64.22939208246046, 66.75240962736069, 65.90530318598594, 67.43316834972751, 69.09571986044608, 66.99133688403715, 69.34317434987715, 63.53250065157491, 45.53002572828724, 17.873652519718295, 3.138114074545522, 36.71548720329039, 65.87987053778865, 46.61957779238301, 16.722946782265943, 12.639765316440213, 24.387128660755774, 27.4858913113994, 28.180280270115023, 23.314782073420865, 29.540083639083374, 28.05751204490662, 36.65319996495401, 28.349053975074526, 35.35596624497445, 37.68265347326956, 49.70766767378777, 84.65926108821746, 76.3601141591226, 26.30294761350078, 0.17288073296508483, 0.09395876103231023, 0.10735663525279492, 0.07646725002315737, 0.07319318941764294, 0.042631034814422174, 0.05993969978824739, 0.028684605250976263, 0.1518981363023481, 0.21380167184097154, 0.1747359221260394, 0.09512136840531904, 0.28797235880647937, 0.13240999331878078, 0.27358614689400124, 0.169157239217912, 0.16079241710324443, 0.14586816631978558, 0.16592036452024214, 0.2106113906108564, 0.31999569205987843, 47.0793854805731, 90.7551028651576, 57.87145753060618, 76.8159249521071, 44.740578128445534, 27.63176033573766, 42.507188397069136, 45.64035807886432, 31.130267420122703, 47.583715992589156, 32.254726617567, 24.61779932821951, 48.38050234702326, 43.30104866335469, 64.82827524985036, 41.2507277150308, 40.5950564722861, 17.518774117192915, 4.905978527761275, 7.613786776219645, 20.014954805374146, 25.2418327331543, 34.854781473836596, 52.34064494409869, 70.90474051813926, 71.02583977483934, 69.30837508170836, 65.64658757179015, 64.70533640153947, 59.74879803196077, 60.94833727805846, 56.26657662853118, 59.41269405426518, 57.452199305257494, 58.14494086850075, 58.00732843337521, 61.24517440795899, 59.22277681289181, 63.05105716951432, 62.81363218061386, 62.75976627103744, 60.92546985995386, 57.68727479442474, 56.2001395225525, 52.36487342465309, 51.57781454824632, 57.90947706468644, 58.85217951190088, 62.017983313529726, 62.98819726513278, 63.80707833074755, 65.95975352871802, 60.65715228357623, 59.271810362415934, 56.600688042179236, 59.860903293855735, 59.07191461132419, 58.237512726937574, 53.178616185342115, 49.04755630800801, 21.61182034400202, 31.23045848261926, 30.823526305537072, 39.14062592291063, 54.01170799809118, 27.697022691849742, 6.266824266602916, 0.588067292926773, 0.1869862042968312, 0.22696260272735552, 0.16047818315846307, 0.26484067101151715, 0.42092354727848885, 2.034974429876574, 0.18762870691716674, 0.19993034762240228, 0.10685354531291993, 0.20269958692933285, 0.13696254741760994, 0.12897528407554473, 0.15004116981740923, 0.1335051619718152, 0.13520851250617735, 0.4372162149558145, 1.047070221074166, 1.278335250193073, 0.2733597219471009, 0.3726085882273413, 6.603656334261741, 20.711377513024118, 26.15655299155943, 20.671694893990797, 36.570175155516594, 41.71787415781329, 47.10064864927723, 43.885266088670306, 43.64484440895819, 44.35121620855024, 46.59392941382624, 50.67371214589765, 53.8279841792199, 51.81252525698755, 54.3034891928396, 45.6554356698067, 47.27863011821624, 46.78810634920674, 55.81196215844924, 55.612568470739554, 62.387007744081565, 59.62156418831118, 55.78820043994535, 46.7827287797005, 52.672453926455596, 62.87102822334536, 64.7362486008675, 64.11842430791548, 62.43722192702755, 58.800470905919234, 51.656999357285045, 48.64314033139137, 50.781443965050485, 52.388846951146284, 52.95773575382849, 53.84931402821695, 60.49580950890819, 65.14396329079905, 66.88504849710773, 67.47504357368716, 71.96571027078937, 70.88666623638522, 70.66360104468562, 69.58698103504797, 69.04312087643531, 53.60468364530995, 25.662153920819684, 4.373976184475807, 33.62541652494861, 71.89821412486415, 55.760932122507405, 26.220762191280244, 16.054016947746277, 31.77817236992621, 44.74045653497019, 32.168893391086215, 34.63937274871334, 38.68832957360053, 41.34017344444029, 44.43627280573691, 40.167855447338475, 35.497952122842115, 45.95683451621763, 51.237537168687396, 83.10270770903557, 90.48740894563737, 23.732722382391653, 0.3890464755315935, 0.25450953102159884, 0.39096433068475417, 0.11752889626809668, 0.08928740967906292, 0.12927016663935878, 0.23030084617916616, 0.13820793059083725], [0.024687123988124154, 0.03760629093214389, 0.030976104467446287, 0.0037498988827029548, 0.03253303453206055, 0.05344196034955883, 0.03271163260984806, 0.020206723880443363, 0.06691779550765792, 0.055980070929733984, 0.1340961681618806, 0.12125551565400056, 1.5911583674530831, 59.5588101879243, 55.16288441996421, 50.99611528458134, 37.13181934049053, 31.829025899210286, 25.121704263071862, 36.55240289626583, 35.74613617312524, 32.167630387890725, 26.91334293734643, 30.1056109705279, 15.530774727944406, 29.542005600467807, 26.945057261374693, 37.48755870326873, 66.515867171749, 29.56598501051626, 23.17525944402141, 12.917748593514967, 1.6125937527225864, 7.918170546331714, 16.17415620434669, 21.473488153949862, 30.067799322066772, 60.13710875664989, 65.74352895059894, 63.93455143897765, 62.757848232023186, 57.83821936576598, 55.77620583195841, 53.680334398823405, 49.886382625949004, 51.22098868893039, 51.1095816089261, 51.43417343016594, 52.84174342309275, 52.845677560375584, 54.0375485727864, 54.92439254637688, 57.772637336484856, 60.337859584439194, 54.83571167915098, 54.52236921556535, 50.04263024176321, 44.17220707862608, 42.08343905787314, 45.67609871587446, 52.41719784275178, 55.88785609891338, 56.665336547359345, 57.24931863046462, 54.949232916678156, 51.6170225604888, 48.496463298797615, 46.226940693393836, 47.568508963431086, 41.26869217042, 39.451340398480816, 34.931373596191406, 32.5641643616461, 3.2798810351279477, 10.727039152576078, 7.9640671803105265, 21.875295754401915, 28.24377952083465, 12.496879254618, 1.2046450688954324, 0.07239262753676984, 0.09914983409426867, 0.0594770209863782, 0.050841494042786865, 0.08230839465414325, 0.04502034430662471, 0.11160058615308617, 0.49346968351352605, 0.03507653837122264, 0.04004544210470012, 0.12407847304618168, 0.05191492112053018, 0.00714064090354969, 0.0664353363155838, 0.07318339115309139, 0.044172258161368876, 0.035428398724405036, 0.18916411565676813, 0.6586287711416522, 0.5822951574960064, 0.44527959679403617, 0.9718660048900113, 6.374196208292439, 10.775672620342625, 8.911401456402196, 10.172840606781746, 18.66294126356802, 25.06884836381482, 30.2938945447245, 33.750136129317745, 34.04572202313331, 35.904662686009566, 40.181383702062796, 38.66579555696057, 41.74549156619657, 40.531282655654415, 40.63114620024159, 41.11983430001044, 46.90978611669233, 49.860691101320334, 54.6143566408465, 55.922827951369754, 55.17166660678003, 46.21473819978776, 42.74797485720727, 49.51422814399966, 54.892417384732155, 55.513085396059104, 56.76594926464943, 51.72959850680444, 45.67135264796596, 44.367360684179495, 46.7217202340403, 46.59924422540973, 47.888491999718454, 51.205342354313025, 55.62789317100279, 62.39238531358781, 62.14505241763208, 64.64547318796959, 67.27327685202322, 63.97597166799731, 67.65351141652754, 65.46221263947027, 64.29688038364534, 47.98739456361341, 31.682166476403516, 6.3634670549823396, 4.299936544510627, 46.02350304203649, 56.799975825894265, 40.83547815199822, 9.270101228067952, 9.95149145203252, 22.775505204354566, 33.31487071129584, 22.90366472736482, 23.931062913710072, 29.447860871591878, 27.217722785088327, 30.709155874867594, 32.20460068794989, 28.467219298885716, 40.0394017465653, 30.771058720927087, 48.814108602462284, 62.69753002351331, 65.82593010317895, 7.389318356590887, 0.3644814985173364, 0.053507338293016925, 0.19667128701844525, 0.0660814726424794, 0.07624870046011864, 0.033630497618428165, 0.1696574333454332, 0.018368652954156843, 0.025135247119432016, 0.04679342033341528, 0.041775314603000886, 0.03394505715057735, 0.061035845203385244, 0.019731902584974325, 0.05762274347005352, 0.016556711371747718, 0.0338998579630448, 0.07665010754980388, 0.19698579675487934, 3.7356582428178484, 74.27529596513318, 61.77070925312658, 55.68674049069805, 39.9773733846603, 39.28354532487931, 33.472338184233635, 35.447588889829575, 33.29682780850318, 31.075114973129768, 29.777936166332616, 36.0577331819842, 25.061140906426218, 44.45305662770426, 30.752137207215835, 37.57090514706027, 64.57094030995523, 31.577903993668098, 27.809194634037635, 17.562188871445194, 2.9989773083117703, 5.499709661929838, 15.590559494110847, 19.07318195989055, 30.857543060856482, 59.17876781955842, 67.13101248587331, 66.84150234345468, 65.33246063417005, 63.168292891594675, 59.402805759060776, 54.97949792492775, 53.87405633926392, 53.28831703432145, 53.51163718008227, 52.10003891298848, 55.469178384350194, 56.88063544611777, 56.46686461664016, 55.80171692755915, 60.38050751532278, 63.01584605247744, 59.14065022622386, 56.627611191042014, 53.64061255608836, 48.08468503336753, 46.399215113732126, 46.50476609506915, 55.12384506963915, 59.403197996078006, 60.878068016421416, 58.3600514934909, 58.234849437590576, 55.174514247525124, 51.82977976337556, 48.41257164555211, 49.87503520904049, 49.7087816269167, 46.869075836673865, 43.220691065634455, 39.40204405015515, 15.862078705141622, 20.44806488098637, 15.571081003835126, 24.624359492332708, 28.574529463245025, 8.640571601929205, 0.6393633145959147, 0.1576357824547637, 0.06866505054096061, 0.07739397892428022, 0.0463748796873035, 0.0553476385351631, 0.07870309295192843, 0.13702620932411763, 0.1860127210496895, 0.020805586302172274, 0.03211247715948811, 0.08048960999135049, 0.02938353407737469, 0.02259458929690863, 0.026961834387733575, 0.09947914464939987, 0.05361770858026801, 0.12525559778535558, 0.11398278251891175, 0.38313144938119, 0.7734637575284128, 0.8639969640681822, 1.5859501953086548, 10.432298529532648, 15.021141171455385, 12.7870120733015, 16.21122456366016, 29.63042759126233, 32.40399633684466, 39.034929813877234, 39.53224320565501, 41.821683606793805, 41.34523722433275, 44.22507670617873, 42.88089613760672, 45.53987479978993, 44.57526983753328, 42.67713685189524, 43.84920381730603, 50.27597596568447, 54.386098231038744, 57.06481818229922, 57.45432915226106, 55.36358425694128, 48.344012537310206, 43.97060509650938, 50.78320118688768, 57.01741633876678, 59.20217652474681, 56.33350795315158, 52.30518279537078, 47.16460289493684, 47.19669180531656, 48.20581959139917, 50.70241997318883, 49.172938792936264, 55.51851395637759, 58.48192737948511, 64.61024245908185, 62.98633021693077, 65.61447904955956, 67.1124832091793, 67.44701431643578, 69.85019560783141, 71.56634238458449, 65.20739586122575, 47.46195777770012, 27.408271528059437, 3.595934346798928, 7.176567037259379, 52.977139719070934, 60.03763744907995, 44.774714516055205, 12.748750332863102, 14.806794428056287, 15.368952443522794, 31.210591677696478, 28.14911507791089, 24.237837368442168, 31.231486143604403, 28.195736369779034, 32.536323378163004, 36.74074334482993, 32.86775189061319, 45.03462253078338, 29.796928282706972, 67.349959188892, 66.50877552647745, 84.59779754761728, 19.599144343406923, 0.31710980820559687, 0.14229039781756941, 0.1885904996625839, 0.012248530702274895, 0.05165354724252417, 0.05867272825731386, 0.08300368073246173, 0.07286884311226106, 0.1747231284577039, 0.11424925854249347, 0.19994258970743228, 0.1265025207953107, 0.11174276441095338, 0.1365559539126773, 0.28070720994184095, 0.22328539601256772, 0.25030041413922466, 0.2044322326659195, 0.23088135696466894, 4.518442961477465, 84.57307092605099, 72.7247045886132, 63.281268919667895, 48.285200518946496, 43.61748195463612, 36.98615427940123, 46.74743137051983, 47.257621903573316, 41.396663419661984, 38.60936441729146, 40.5110393031951, 19.663461408307477, 37.13228218017086, 40.83419553695187, 49.512961218434, 75.72609439972909, 36.648740230068086, 30.38203412486661, 16.39520823955536, 3.9290205509431906, 9.178103016268823, 21.884495673641084, 23.82235638556942, 40.22999755797848, 63.796931159111764, 71.33376152284684, 69.30973222178798, 69.18852313872307, 65.3735984525373, 63.845223380673325, 58.444013749399495, 56.6690981003546, 57.45871436211371, 56.994462628518384, 56.580683954300426, 58.804287372096894, 58.73404948942123, 61.583263104961766, 59.137210307582734, 62.751129211918006, 66.87754108059791, 62.027036143887436, 62.20060494638259, 57.17868066603138, 48.894070040795114, 47.97232089504119, 52.02433716866278, 61.9686673533532, 62.54583235709899, 65.6769427945537, 62.2633550243993, 60.90197094025151, 57.78587533581642, 55.377536127644206, 53.26170767507246, 55.463557627893266, 53.05129212717856, 52.82312785425494, 51.785398144875806, 47.31118186827629, 18.140934590370424, 31.104399388836278, 31.174647077437374, 37.466056269984094, 34.41253031453779, 10.016752827552057, 0.8889073854492557, 0.2524779118116825, 0.17335884843862828, 0.2028999189215322, 0.09477724170973224, 0.19570987731699022, 0.28590324725354876, 0.5458822630105481, 0.8371685649598799, 0.1539503939209446, 0.0987533606108158, 0.20702248319022118, 0.16136831603944302, 0.12668022255022682, 0.11252368379744793, 0.3399237227295676, 0.20904114019245873, 0.22251632034538255, 0.3902598055860689, 1.2660763725157709, 0.708592719128055, 1.369072297407735, 2.6783005028001727, 15.599115164049211, 23.47080219176508, 21.39605860556326, 31.14900262125077, 42.61573999158798, 45.26677585417225, 45.3877809739882, 47.40384001885691, 44.63664708598968, 45.686214508548865, 47.8655892802823, 47.19862553381151, 48.22345849006407, 47.91891390277494, 45.59967133306688, 46.390585899353034, 51.93478945762881, 58.0571033108619, 59.897899089321015, 61.68074577085434, 57.33203357265842, 50.84286435957878, 46.882200087270434, 56.67431485268378, 60.42370850040067, 61.493997804580204, 59.972541793700195, 57.02676334688741, 50.79894165838919, 48.92996757261215, 52.695756727649325, 52.917453012158795, 50.56241881462836, 56.92223218179519, 59.92652062446841, 67.51334159604966, 66.25084830868629, 69.60678900441816, 69.73541921184909, 68.83345450124433, 72.78410496250277, 71.68912826045867, 67.89849481275006, 54.080953521113244, 33.672367295911236, 7.092417488175054, 5.773076799608046, 54.662911661209606, 66.82833886915638, 51.71961999708607, 20.075808417412546, 16.048382462993747, 30.962886156574374, 47.70556442199215, 29.22157737516588, 32.29672539618708, 41.15331172943115, 39.2255413147711, 41.597908466093, 47.682108648361705, 41.63814806169079, 49.853007178152765, 40.66125823605446, 67.2104718608241, 75.25322914123535, 91.90526731552617, 16.056777315755046, 0.520006632131915, 0.21120844889552365, 0.33282913568039096, 0.1916472824110139, 0.25534579259974344, 0.10931159970500778, 0.21950230062488588], [0.05390501836495054, 0.03762133689897676, 0.07321994886883805, 0.016094888673133908, 0.02518916630276269, 0.013313066372047029, 0.04908798390158242, 0.0595503279398526, 0.0704855052754283, 0.1602709410531867, 0.039415798270173615, 0.19866737507043347, 16.33456055195101, 71.86488182313981, 57.470952157051336, 46.78440755413425, 37.27660186829106, 26.445394369863696, 24.464989669861335, 39.07592250454811, 31.45512204016409, 29.41807439250331, 28.269671086342107, 21.911652203529112, 20.44653711780425, 10.607099936854455, 18.051069167352495, 19.22460506039281, 53.60278914051672, 72.61540382139145, 34.37829586767381, 32.60795370224984, 5.812639296054841, 0.9457360328205171, 6.8555950733923146, 10.587275297411027, 12.866112551381512, 54.64098953431653, 66.29931311453542, 64.4208743495326, 61.45619007848925, 58.794089209648874, 58.08743892177459, 54.881893665559836, 52.640290491042606, 51.24118889531782, 50.25049232667493, 50.24853114158877, 52.818648507518155, 51.434828465984715, 52.785465255860366, 52.37800159761983, 53.90818488213324, 54.8579122943263, 59.39085429714572, 55.385416169320386, 55.388267732435665, 48.247938002309496, 41.88663805684736, 44.147684420308764, 50.128330107658144, 55.8285302500571, 56.90063561162641, 54.61211696747811, 55.378234309534875, 50.4543653611214, 49.15101666604319, 45.891558431809955, 42.6233180107609, 40.372822823063025, 40.90526496210406, 34.19339926012101, 31.122379533706177, 5.356023926888743, 7.476694055141942, 8.63436347053897, 16.931030481092392, 16.444697764612016, 4.326233585034648, 0.3511592908011329, 0.06169995916406475, 0.14318034683744754, 0.10110400947591952, 0.019256617806311098, 0.0714245758530113, 0.01662653837082607, 0.1040847426761062, 0.44697136407898325, 0.02781846815900457, 0.03926139324903488, 0.03112469296601992, 0.03464480186061513, 0.03982477047811112, 0.0736260290948614, 0.012659091585045381, 0.023709532594488516, 0.055495344117404, 0.10536030971355016, 0.09903942550262136, 0.35315819805668247, 0.15595590485440147, 0.4282327615205319, 5.370315572907848, 9.167006631051342, 8.843632705750005, 8.155856372848634, 15.56432079884314, 20.81013494922269, 27.535177853799638, 33.509459495544434, 37.6132510554406, 38.82140382643669, 38.91768232468636, 38.6905574798584, 40.59788057881017, 39.41852584961922, 40.43513751799061, 43.92715700211064, 49.185768865769916, 53.995324257881414, 55.89907799997638, 52.01890076360395, 54.73877814508254, 47.23955154418946, 41.93963712261569, 48.28740489098334, 51.673885160876864, 52.82114705731792, 50.74304396106351, 46.843776549062426, 47.379642917263894, 46.49407763634959, 47.00914367552727, 49.108345200938565, 50.02006876853205, 52.93420545516476, 56.69756666306527, 62.03583402018394, 64.78464280405353, 61.80290798987112, 62.15510545238372, 68.93335726953322, 68.28659765182003, 69.7634720033215, 52.62849984630462, 34.628382267490515, 13.975552993436015, 0.8744042378760154, 19.387416762690393, 54.672093929782996, 52.156242555187596, 41.75997295687276, 8.684400166234663, 13.325014172061799, 31.80553678543337, 26.56513844766925, 24.365639955766742, 25.66351498326948, 26.226380986552087, 27.819847791425644, 33.62059200963667, 33.31467459278722, 28.516245003669496, 35.536214843873054, 25.102902381650864, 33.4262111110072, 70.42829805804838, 66.52695178985596, 61.68074577085434, 2.390996693603454, 0.08957729734961065, 0.12066156002542666, 0.058097763948382876, 0.0350199397953768, 0.02888164689554082, 0.0348068907436344, 0.08156283788623349, 0.07674552380077301, 0.05539223251323547, 0.04485734377897555, 0.056302471371788176, 0.08756373483206957, 0.017476698699136897, 0.07635030670151596, 0.044759001072135665, 0.30855989924842314, 0.10397535298139819, 0.2518434684363104, 25.536453723907474, 81.97173149354997, 70.06676535452567, 57.08706586591659, 45.87485305724606, 34.29613397967431, 32.26097103088133, 36.76887066133561, 32.693069134989095, 26.57839409766659, 25.6622931649608, 23.432461023330692, 25.785559531181093, 21.48820096446622, 28.064656642175493, 23.55038708256137, 51.70249492891374, 74.44471097761586, 39.67636677526659, 40.39436840241955, 8.75076666955025, 0.6571509568921982, 4.650499849550186, 8.679490339371467, 12.625073098367261, 54.87804189805062, 68.15281344998267, 65.59325902692734, 65.54342923625823, 63.09265782756191, 60.223597018949455, 56.704928951878706, 55.53718443839781, 53.03508881599673, 52.68654700248472, 52.061399644420995, 55.370762194356615, 53.82446189080515, 55.42234528449274, 55.54780229445427, 56.713864111131244, 57.78291394633632, 61.64102000574912, 59.81935362662039, 58.50689718800207, 52.382998697219364, 48.477726136484456, 46.540608713703776, 51.7307516836351, 58.451093627560525, 58.987591497359745, 58.05875070633427, 58.328166546360144, 54.2222608289411, 53.08121588922317, 50.00574819503292, 48.56477529771867, 48.467673101732814, 46.21801337888164, 41.45190215879872, 41.314438773739724, 16.314682960510254, 19.66136686263546, 12.876169508503331, 18.51589160580789, 16.569999840951738, 5.013371061894202, 0.29344801821054955, 0.016780703989488464, 0.053389598239934256, 0.04898173899780359, 0.026198469906023918, 0.125953373649428, 0.0366614248994137, 0.05861321471691613, 0.11869210118968641, 0.03664488889156811, 0.07978559817157446, 0.15482379544165828, 0.030795608406826377, 0.04571582573736387, 0.11507048947556366, 0.022262645314537713, 0.06152548646974949, 0.010624379295134738, 0.05653712410299529, 0.3030875187006689, 0.5261759688296627, 0.38817567870982234, 0.4016527587607984, 8.301023783222321, 15.457157723365293, 12.17484187695288, 14.17293352465476, 27.48479500893624, 31.702427479528616, 37.760932214798466, 40.36746486540764, 43.98028942846483, 43.88808235045403, 42.74815920860537, 43.61740742960284, 43.434895623114805, 44.00189384337395, 42.73668235348117, 46.80683174440938, 51.62544388924876, 57.011732824387096, 58.42580218468943, 54.93237849204771, 56.688819777581, 50.16370988661244, 44.72963863803495, 50.09589210633309, 52.34859558843797, 53.51329242029498, 51.58031702041627, 47.787134032095636, 48.60672112434141, 50.26398920243787, 49.915972986528956, 51.2039146115703, 52.41771559561453, 56.05952255187496, 57.59118849231351, 65.38811122217487, 65.0364472020057, 67.61653915528329, 64.93705434183921, 70.51477063086726, 73.54680199776926, 69.62732653464042, 51.331517158016084, 31.86148939594146, 9.31979863874374, 1.2971409314101743, 26.810329729510894, 58.95118013505013, 58.2686798803268, 45.54535827329082, 12.16545662572307, 15.42742713805168, 24.58241758808013, 30.912042433215728, 24.877197434825284, 26.32275950524115, 29.23952025751914, 28.8531118823636, 28.469327572853338, 37.70082189190773, 31.991849368618382, 49.279815535391535, 25.374059754033244, 39.87532507988715, 90.2125527781825, 66.64106922764933, 82.95133559934555, 5.699416158660766, 0.228701269915027, 0.15427124686539173, 0.07334522722709565, 0.04206830492964195, 0.01114792857063754, 0.07827283499101478, 0.1633296696649444, 0.2789033486718132, 0.20605430127151553, 0.12782353982930222, 0.1627016920716532, 0.15597030730737796, 0.16641456784019548, 0.14665841665719787, 0.21272908745994493, 0.3570553792580482, 0.17452046755821476, 0.3761439614238278, 32.344884257162775, 97.74147172128, 71.70712409480926, 60.95136927020166, 53.924278366950254, 36.09381506519933, 35.793400733701645, 49.78279675206831, 42.10308621006627, 38.32432577686925, 40.205400374627885, 28.103588127320815, 28.397556043440296, 14.172343207943825, 27.853927304667813, 33.46725087012015, 62.93402148831276, 80.60587590740573, 42.78221714881159, 42.06660032272339, 8.344981785743467, 1.8281685657078222, 9.618197852565396, 11.276738739782765, 19.02930828832811, 59.79937307296261, 71.59639558484479, 71.12644072501891, 69.22129846388295, 64.44817796830209, 62.98019562998126, 60.21913728406353, 58.026799078910585, 57.44254242989325, 56.46440921291229, 55.39362569009104, 59.5519381953824, 55.56223269431822, 58.763671228962565, 57.45920073601508, 60.08487063069498, 62.067758191016416, 66.98946983583512, 62.33196512345345, 62.727414561856186, 56.23232256981635, 50.804440821370775, 50.6584031351151, 55.08081274647867, 64.74621926584553, 61.94277578784574, 60.06987540952621, 61.67654491239979, 57.44624906970609, 57.45505871311311, 57.01105033197711, 53.23267821342715, 53.42650605786232, 52.484466491207, 49.099233535028276, 48.84487567409393, 20.44907489130574, 28.432433759012532, 27.33832193959144, 29.116073462270922, 21.682309258368708, 6.361464685009373, 0.906522811180161, 0.11491256044997324, 0.20992718216392303, 0.24748819729974195, 0.12560665757665712, 0.3342283799523308, 0.13725536154402843, 0.2485442341816041, 1.062028302300361, 0.4316349886357785, 0.2531204603972935, 0.19854133828513085, 0.12562880517854808, 0.19946114941229745, 0.19259117934251987, 0.09938274014500842, 0.08532669680613665, 0.16264405161623033, 0.14147200140981905, 1.2526508348603405, 0.7950217168658011, 0.6844912253079877, 1.5027524338614557, 12.649607523795098, 22.315103277083367, 20.518353754474273, 26.64310928313963, 37.70217510961717, 42.6088797661566, 43.6490374226724, 46.492175286816014, 47.170870842472205, 47.0640137118678, 45.85823005245578, 48.22909885837186, 47.813861062449796, 47.07854609335623, 45.0132966041565, 49.412403414326334, 52.79260396957398, 61.40848229008337, 61.49226803933421, 57.59412242520241, 60.327002463802216, 53.18682962848295, 47.622527845444225, 54.52899802115656, 56.97914969536566, 56.75672385000414, 56.5598875476468, 54.30277532146823, 52.311701774597175, 53.555861903775124, 52.38372041333107, 54.523863638601, 55.81746916617117, 59.8028326034546, 58.904460783927675, 67.40360936810895, 70.21396406235235, 70.13428503467192, 67.14576844246157, 74.92863731999552, 74.42085512222783, 74.81870112880584, 57.30314139396914, 38.42957081333284, 16.79153923065432, 1.8082300549553287, 24.193414565055605, 64.94826839816186, 63.273298663477746, 53.390875247217, 18.20140577131702, 17.616733351061423, 41.64290589670981, 34.6569763460467, 32.3583124914477, 34.42986326832926, 39.31514001661731, 35.810498345282774, 46.430645065922896, 43.98209764111427, 43.43364046465966, 48.391673257274014, 35.59919241935977, 43.77964842704035, 94.28448292516893, 77.15318602900352, 92.29435859187957, 4.7372558136140155, 0.3438298211943719, 0.23702852307788788, 0.10442422687887185, 0.10257320523622537, 0.09217939159322171, 0.19252914154241163], [0.016832443652674556, 0.05642779952576084, 0.07521098840140528, 0.06206690761891585, 0.01587771136508954, 0.08200271025059686, 0.055362343592869664, 0.01657114255302135, 0.07298624608665705, 0.1827430731106189, 0.04179722088719568, 0.4277357543187757, 37.578745965034734, 67.62144211799868, 47.16234360971759, 44.10866075946439, 37.790295077908425, 24.661757330740652, 30.20462924434293, 38.21486027010026, 30.061550986382272, 30.24670647036645, 28.39020552173738, 32.0319869825917, 30.147017471251953, 19.694661901843165, 5.6393573168785345, 17.953025602525283, 30.357958616748935, 60.22130635476882, 43.22360146430231, 45.94799741621941, 12.862809915696422, 0.6888160061451697, 0.8842065473718028, 1.5103114540538483, 2.7279866366617145, 38.702148083717596, 70.21691368472192, 59.71128056126257, 62.873165915089274, 60.33252516100484, 57.29987013724543, 55.29986927586218, 54.12109505745673, 49.52156689859206, 48.76616547184606, 48.11692691618397, 48.886025259571696, 49.27811714910692, 49.15646876058271, 51.62493790349653, 55.78263459667083, 56.62282589943179, 57.59024712347216, 56.835771376086825, 54.49578339053739, 50.297392106825306, 46.73225964269331, 43.963607588121974, 43.01183662106914, 48.014713871863584, 56.84611466623122, 53.649634007484686, 55.59570620136877, 49.58689789618216, 48.52040152395926, 42.99570783492058, 41.82966563009447, 42.23336381296958, 37.40325912352532, 32.17462397390796, 28.640656701980102, 7.865568620543327, 8.24876408423147, 4.1657674601001125, 9.885416184702228, 8.420075562692459, 2.2261585968156017, 0.10223778896033765, 0.07788028387773423, 0.015691529974461566, 0.0420082321450595, 0.040178978890781446, 0.06519281065031406, 0.04929024643535095, 0.09105727196701112, 0.07399555926601734, 0.16204077269761794, 0.04129982681103772, 0.041633320206235495, 0.019662366699307196, 0.030878014569621415, 0.060845698350139206, 0.05682153807532403, 0.032707725561434225, 0.09966455324883423, 0.012478920154183382, 0.05826731069734501, 0.14863631778186367, 0.48268190915546116, 0.4451213536723968, 6.289863288402558, 9.640827967274575, 9.179908287140632, 6.8358302500940145, 12.510494782078652, 22.22299425832687, 26.520913723976385, 37.067841560609885, 38.735809864536414, 41.180513366576164, 42.32476680509506, 40.210856391537575, 40.44155843796269, 41.497550702864125, 41.649169921875, 46.61531809837588, 50.476577743407226, 51.70160062851445, 55.57345851775139, 53.00915410441738, 52.52333325724448, 48.781501939219815, 44.55003723021477, 44.439132213592536, 50.32612346833753, 48.18747466610324, 47.5669204035113, 43.99119361754387, 45.70453197725358, 49.01327871507215, 48.85993365318545, 49.22566721516271, 51.093378297744266, 53.84597609120031, 56.97022630322365, 63.31715076200424, 62.74143703522221, 63.309560975720814, 66.6097765584146, 66.40769604713687, 73.54539778924757, 58.81696447249382, 38.133000404604026, 19.63975852535617, 2.6605917369165732, 1.6413441132153235, 36.27473831176758, 57.475643311777425, 52.33583611826743, 29.95475269133045, 4.8546925571657, 22.565921198937204, 52.41995134661275, 27.43908762931824, 30.458035930510494, 24.31853032881214, 32.81076965793487, 27.89790491903982, 34.090029116599794, 31.280123533741122, 34.82000573988884, 24.260202723164713, 56.6063323328572, 38.46378564834595, 38.37744643611293, 64.64922297385432, 69.5232738987092, 33.449925761069025, 0.597971277611871, 0.14771407049509788, 0.1423352446046568, 0.05522053688764573, 0.03836047768052067, 0.027078256769586476, 0.03582972537485823, 0.03408860670582902, 0.05051794829928587, 0.0803294133455042, 0.041164777001305934, 0.08792240187645921, 0.061636584540528644, 0.054131282433386774, 0.0439144887270466, 0.0914717868210808, 0.056299878164164485, 0.5441243057289432, 52.34568911214029, 78.56841641087686, 57.317132488373794, 55.95792139730146, 44.239354133605964, 34.339676210957194, 32.775927243694184, 38.62248866788803, 31.085083676922707, 28.17484582624128, 19.379624974343088, 28.85003282177833, 31.689056119611188, 21.815316830911947, 11.56875821851915, 23.497399783903553, 33.276439328347486, 63.962800348958666, 45.695683110144834, 51.51381323414465, 17.55102776711987, 1.3505341953808263, 0.9981566102754686, 2.7749830051775906, 1.862781398719357, 36.26546190631005, 70.9201083644744, 63.66167999082997, 65.2490004416435, 64.44942528201689, 60.53299357814174, 58.314030324259114, 57.45928702815887, 51.2749683472418, 51.226025012231645, 50.56559201209776, 52.22285616782404, 50.46120205233174, 52.0868597492095, 52.67537609223397, 57.96467265775127, 58.10332452097247, 58.045465638560636, 59.54458767367948, 59.911070408359656, 54.68672044815556, 50.766182022710005, 46.917838742656095, 45.68193912506104, 51.78089526391799, 58.51228652461883, 56.78700062536425, 59.446540186482096, 54.4586895358178, 53.571743580602835, 49.08647014248756, 47.879788260306086, 46.979361118808875, 45.080647622385335, 39.18376807243594, 39.09482832877867, 16.713307557567475, 23.219901900137625, 11.173565695362708, 11.486447280453099, 8.761651246778428, 1.3385705986330587, 0.11144683230668308, 0.09121044358659176, 0.11624946048663509, 0.0238418800290674, 0.03404231201256475, 0.08006538880328018, 0.08480404098067554, 0.05317198713460276, 0.08147474543582048, 0.15961618102606268, 0.13000427805367978, 0.032881144884853594, 0.06984284177662865, 0.023204150136500117, 0.05178748239432612, 0.042422609103302804, 0.08497916868016606, 0.10256310819738335, 0.04263714053517869, 0.11289851529703987, 0.3681514886838775, 0.058671468042678414, 0.7086650991151411, 7.180205035594202, 15.29568943285173, 12.27662051877668, 12.070769629170819, 23.237154445340558, 31.197975374037224, 38.796885090489546, 42.68988847732545, 47.59648722987021, 45.224041631144864, 47.202747944862615, 42.68897064270512, 43.710657858079486, 43.63641131308771, 47.769075439822295, 52.49463719706382, 54.59476832420596, 56.701434120055175, 57.972886100892104, 55.575305954102554, 56.0173100040805, 49.63043620509487, 46.15949553828086, 47.22274026563091, 49.90554340424077, 51.36701853044572, 49.29589333072786, 46.16577917529691, 49.207063413435414, 51.80770466404577, 52.780083763983946, 53.555501045719275, 54.194980744392645, 58.1749273884681, 60.03300120753627, 64.71444414507958, 64.2827755405057, 67.55192202906456, 66.85905102760562, 70.99832042571038, 74.39888984926286, 58.35916111546179, 34.31822084611462, 15.68784211912463, 1.8335134079379423, 3.638146649445257, 43.71283085115495, 61.503678214165475, 56.068967619249904, 32.56563328927563, 6.949087708227097, 17.345338675283617, 44.26120173546576, 25.87745281957811, 21.596279913379302, 21.00615147621401, 30.214360644740445, 28.14425526126739, 32.573505486211474, 34.84970984920379, 35.59244594266338, 33.8852107909418, 69.55495096022084, 41.16199977936284, 52.4910129270246, 73.04927287563201, 77.42366483134609, 53.443042770508804, 0.3931704187585462, 0.08916614562152855, 0.08357033298741426, 0.0690636920532392, 0.03141784225590527, 0.04792213214621429, 0.08775066028559401, 0.1447436105339758, 0.15403282498159718, 0.16738506334443248, 0.13034298084676266, 0.2946768232410954, 0.3086579278592141, 0.1361430784867656, 0.23423804781369625, 0.21471726948455458, 0.16635043095917473, 0.7980811043131737, 66.31985064475768, 91.42380422161472, 62.019391444421586, 57.80722087429416, 49.57730377874067, 36.11587055267827, 40.965449810028076, 51.052071817459606, 39.074898765933135, 39.993243294377486, 39.78938987178188, 44.29010175889538, 37.70533261760589, 23.94004318021959, 8.661153258815888, 34.87677420339277, 39.308146430600075, 74.35113107004474, 51.121744878830455, 57.09963313994869, 15.950935098432726, 1.6992163562005567, 1.976024147964293, 3.429231408142275, 4.746953873865066, 44.451707332364975, 76.447645771888, 66.97975804728847, 68.30199687711655, 69.77060287229477, 63.350067292490316, 61.70433882744082, 61.52170934984761, 55.75087908775576, 55.05376408177038, 54.20886201243247, 54.82690595811414, 55.13864809466947, 57.39192424281951, 58.59869241714478, 62.667500357474054, 62.68988532404747, 63.34144592285157, 63.99828995427778, 61.64242813664099, 58.45921293381722, 52.986518106152936, 51.3748279694588, 49.36073010967624, 56.63997450182515, 61.94985566600677, 61.45569193747736, 62.99587334356001, 59.732025977103945, 58.856321534802845, 53.67270931120842, 51.43239267410771, 54.37947727018788, 52.344990930249615, 49.923570617552734, 48.664246605288604, 20.288124353654926, 32.56861036823642, 22.499682172652214, 19.807661464137418, 13.620158799232977, 1.6017669078803833, 0.1716359166969215, 0.16119015463177236, 0.23560931455464135, 0.1122569396430927, 0.06871916699193178, 0.19412297214711868, 0.2119124990196959, 0.2170236384676349, 0.32706141291606816, 0.3706703857789117, 0.13983839552008337, 0.10118849365220917, 0.14830884583775075, 0.10580865501035606, 0.2361274657831077, 0.14446579640911472, 0.18910737918509593, 0.29748643538163555, 0.15350325904305906, 0.24217018346873023, 0.5811702339879928, 0.7279105760878133, 0.6695343698224714, 12.066336370283558, 21.25482386158359, 20.09537123864697, 23.80584320714397, 38.0877637094067, 43.5190422304215, 48.127387877433534, 51.27304638585737, 52.50500009905908, 50.297141075134284, 50.523646185475016, 48.54651666456654, 47.16476763448408, 48.624469849371145, 50.28119664038382, 54.331773404152166, 56.30798116807015, 58.36919453836257, 60.37250588017126, 58.01964467571628, 58.46923458960749, 53.595791632129306, 50.13773202896119, 48.87600360378143, 55.17653426816387, 54.13572942056964, 50.75484245054184, 49.58839624158798, 50.766558570246545, 52.950914752098825, 55.13706737949003, 55.95770566694198, 54.45670089414043, 60.0289454767781, 62.99814831825995, 68.55274615749236, 68.1968459775371, 68.96524613903415, 71.73192131903865, 71.1816127838627, 76.003751139487, 64.95495211693549, 42.05965772751839, 21.624065983679987, 3.3104237962153653, 2.7560308479493667, 44.15107727050782, 68.97666023623559, 61.22848864524596, 41.67872890349358, 12.69336352425237, 28.116773174655055, 62.66442521925896, 35.30573637254777, 42.15652065892374, 33.31586699331961, 44.708783395828746, 36.75400487838253, 47.69297361373902, 41.527996140141646, 49.29105704830539, 32.613911782541585, 77.31759609714632, 47.668898105621345, 56.00800614203177, 81.29048639728178, 86.99492269946684, 56.99611394636093, 0.7275600142536626, 0.28701830354909746, 0.28121255218021335, 0.1858274503460815, 0.17031747937923478, 0.11017916363573844], [0.09705269904506784, 0.03307188928668057, 0.021485077562711893, 0.013911085139449327, 0.05446752991467234, 0.028460559007080815, 0.026912291481670354, 0.11823017315398301, 0.055121378297166485, 0.11596449110056124, 0.1546550109501808, 4.017469017736373, 61.028608583634906, 72.25368284410047, 53.423215189287745, 39.88477406963226, 38.28261137008667, 22.20607707577367, 31.623111271089126, 36.058949116737615, 32.04746661647674, 32.48204954208867, 28.720392604028028, 55.53623522481611, 31.601404874555527, 37.11167796965569, 12.219942269786713, 8.394100646818838, 30.23891664320423, 57.658021757679606, 45.54102013188024, 47.33737545628702, 30.916876754453106, 2.9922139163940185, 0.2773209480989364, 0.20642246780616624, 0.14321600056944356, 11.94170403865076, 67.07015299027967, 56.81633210951283, 62.70089541712115, 57.01447456113754, 60.22223595649966, 52.63965898944486, 53.94618088199247, 49.31749774563698, 49.19846165564753, 50.21174715411279, 48.87020241829657, 46.5582162334073, 47.358085570796845, 48.40127521945585, 51.58022288353213, 54.28833315449377, 55.36565526839226, 55.455285349199855, 59.42610071551416, 52.59357506229032, 52.36093144262991, 42.39254143930251, 42.842198033486646, 43.63769785050423, 51.208962701982074, 52.350231216799834, 52.66574275109076, 50.5466155852041, 45.50138065891881, 44.9288675861974, 40.93742839751705, 39.491740811255674, 36.463008157668575, 31.811700790159165, 26.459265831978094, 10.770220525803106, 12.169085798725007, 4.637286855328468, 6.725812179426994, 3.1864219855877662, 0.3345674198241003, 0.07578625148462673, 0.08767374505799624, 0.06944960118421624, 0.093548551592375, 0.008088579427661195, 0.0122147596313528, 0.056099741524385835, 0.10134089152298628, 0.1911878441610644, 0.17621775067621664, 0.03303813162229715, 0.033685177144023686, 0.014200693187904696, 0.06084500504056774, 0.06301281170078343, 0.10013840161263944, 0.045051581541737246, 0.06509248377575029, 0.029294725334752473, 0.19879667539029353, 0.27605184684357337, 0.6748212345184819, 0.7086791951329477, 2.777100104478098, 11.415693606099776, 11.411601593417506, 7.009026917719073, 8.810360220170791, 18.215247815655125, 25.672842379539247, 34.29195665544079, 40.78180443856024, 43.11103728509719, 43.3733065666691, 41.7496100548775, 41.42852875494188, 40.24003490324944, 47.33263723311886, 52.55173121729205, 52.8776252654291, 53.46030119926699, 55.21396936908845, 52.85911167821577, 54.27608359244562, 45.32315208065895, 43.23143443753643, 44.232580200318374, 47.420572850012014, 46.109508852804865, 44.58775866416193, 44.178914331620746, 52.13070400299565, 52.02504711766397, 52.033656720192205, 50.97189072639712, 52.63168481088454, 54.18149171337005, 58.29767404064056, 59.80951632222822, 63.404031261321045, 64.34642384129187, 63.19292145390665, 73.00135720160701, 65.21038470729705, 44.57763110437701, 21.48208402818249, 6.321738429607884, 0.48915424894902015, 13.038798820587898, 54.09532508542461, 60.57560620769378, 54.12921436371342, 20.955364627222863, 5.086087392222497, 21.223692009525916, 40.863119094602524, 29.30067785324589, 29.67740581881616, 23.996405678410685, 33.594386654515425, 32.374668775066255, 32.66715795763078, 30.165566359796834, 42.27666285730178, 26.76187865195736, 28.29422708480589, 49.48511239021055, 24.84349839148983, 52.195517247723, 63.680954517856726, 62.19309752987277, 3.3600368759324475, 0.0681532425205073, 0.08825948056314262, 0.06065490415259715, 0.025325464835811048, 0.007123413980157385, 0.027233102291281668, 0.004410300189779411, 0.026613997911373456, 0.043045836951463454, 0.06875939426883575, 0.014970964909861646, 0.09920742092353683, 0.03142459149051818, 0.06637970301052255, 0.09466828102426184, 0.08514392354916181, 6.088043124445024, 75.67420144234934, 79.19432470875402, 72.79402855903872, 42.59184491249823, 50.01102770528486, 29.89906287962391, 37.04431518431633, 40.03632268598003, 33.73112047872236, 32.56128141956945, 26.164554626710956, 52.20783349006407, 33.847387375370154, 34.19956914840206, 12.1124840359534, 12.615656468176073, 32.28925131982373, 62.78721893987348, 49.136813763649236, 53.709481531573886, 37.461082704605595, 6.103547273143646, 0.623170912506119, 1.5983566521636903, 0.31513333200447025, 11.2654697702777, 73.16860706575456, 61.00712576220113, 67.16933404245685, 59.608741960217884, 62.723672620711795, 56.72376809581634, 58.10914924067836, 51.92445401222476, 51.92152400170603, 51.90216710490566, 52.618941030194684, 47.77448438828992, 50.877824444924634, 49.656453286447835, 53.31985289050687, 56.942024461684696, 60.45679761517433, 58.39904769774407, 61.219675079468765, 56.76254464733986, 55.48150639380179, 47.11833853875437, 47.09845996672108, 47.231149827280355, 54.33689209722704, 58.69613193696546, 55.870272113430886, 53.97767751447616, 50.98532092186713, 48.560095910103094, 47.07565530653923, 46.53864360624745, 44.34784689257222, 39.087826898021085, 35.79857433995893, 18.5860667305608, 31.13302484635384, 14.50907672605207, 6.857533214553711, 4.136728192529371, 0.6269115053357617, 0.02711030414267894, 0.0959620503107867, 0.04719164432777513, 0.052855853291769186, 0.04153338786695273, 0.031139869167799913, 0.042764406891599785, 0.04357308547403063, 0.021502360506283662, 0.19962997986905037, 0.08833276453397929, 0.08736313470909673, 0.03318316355768231, 0.018961342622435862, 0.05143429287859509, 0.11794322726106453, 0.06274244778098599, 0.04392805614418561, 0.01956327322630152, 0.13823026971470925, 0.18041033538118487, 0.38696786448840176, 0.9002582344316667, 4.447544649724038, 16.003956717829553, 15.305476727024203, 10.255643802304423, 19.806494559011153, 27.651248631938813, 39.108686062597464, 39.76073695767311, 46.593093948979536, 45.56221269792127, 47.985582428593794, 45.40313313084264, 45.70262570534983, 43.70711595781388, 53.28195887227213, 51.872545365364324, 56.75080891578429, 54.58344444151848, 56.30406272026801, 54.28924314437374, 56.47704316723732, 47.61902909125052, 46.88047816676479, 45.355950940039854, 48.250652282468735, 47.27936752380864, 45.99423823818084, 49.408057428175404, 56.802937215374364, 54.40055216512373, 54.31418941866968, 53.84734499839045, 55.35393914868755, 56.958659233585486, 61.40462267783381, 62.49908554938532, 65.79736348121398, 65.92497779477027, 63.90394126215289, 73.32274836878624, 64.94682888830862, 42.72615863430885, 20.080987907225087, 4.942472259844504, 0.4277352946660211, 19.951184911112634, 59.8894150026383, 65.54637885862782, 57.97093276054629, 25.033984376538186, 4.615984462922619, 14.908769188388703, 42.399974330779045, 19.417505264282227, 15.904427555299575, 24.027237469150176, 31.326348666221868, 29.90768817163283, 30.595383605649396, 34.04034837599724, 43.898037325951364, 29.023703605897968, 44.7630258529417, 44.83164771910637, 33.92551314446234, 63.164276384538226, 67.89596880635908, 76.71228024267381, 7.5837546586990365, 0.5469662467798879, 0.02801597903242275, 0.03942434015052934, 0.022984010941018502, 0.03373188169432744, 0.1488988561135146, 0.10961017481261685, 0.15051790633268897, 0.17942402782219072, 0.22916354269029635, 0.12591186700569046, 0.18699100000723717, 0.17651300096223432, 0.29980265625542213, 0.24004968273783886, 0.37470678047787764, 10.003747228653202, 91.45523025143532, 88.9155504780431, 68.83717290816769, 55.89493205470424, 53.64238154503607, 31.757964318798436, 44.72142519489412, 47.52194650711552, 41.62255664025584, 43.02795756247736, 39.416772550152196, 68.1249410875382, 38.37979201347598, 46.85502590671663, 15.680175846622838, 20.028284980404763, 42.90169646663051, 68.78062017502324, 56.40771527444163, 60.88994103093302, 40.61868875257431, 5.61047004115197, 0.40737430174504563, 1.0231557752816909, 0.17012257128953936, 17.59041032483501, 74.72677646144744, 62.69310166758876, 70.62313002924766, 62.91144824797108, 65.68552101812055, 60.31868311666674, 60.35340001506191, 55.640801691239886, 53.982717760147594, 54.33174986993113, 54.94704815649218, 50.47010191025273, 51.86876812288838, 53.434429245610396, 57.403208901805264, 61.993472422322924, 64.1107835308198, 62.31630702172557, 66.25058943225493, 59.72534618070049, 59.416965515382834, 48.423781779504594, 48.374783531312026, 50.937369946510564, 60.374584736362586, 60.341334804411865, 58.88708076169414, 60.89263962161157, 55.648505226258315, 55.28676855948664, 54.8315578891385, 54.565287789990826, 52.157685987411014, 47.15954695978473, 47.95876910609584, 24.953924878951042, 38.46304039801321, 23.960255153717537, 13.598957407859064, 6.6212770919646, 0.798297999126296, 0.1408851780598202, 0.16429167691498034, 0.2059688365026828, 0.2591334079061785, 0.12823734988248156, 0.08167926026808639, 0.3050927078771976, 0.2304829912440431, 0.4326955914016693, 0.7327521291951979, 0.18778986117291838, 0.3112193887993213, 0.1295378071165854, 0.21468604374076092, 0.3270467346714389, 0.2343616331176412, 0.12433021719897948, 0.16819979785190475, 0.11863289025401878, 0.25774032298114996, 0.6796012554437884, 0.6079941591428173, 1.518006286313457, 8.5532312047097, 20.936966749929613, 22.626647333944998, 20.25025190845613, 33.955072126080914, 37.659276147042554, 49.36930048850275, 45.881791730080884, 53.42636877490629, 50.71951366239979, 51.27853378172844, 48.348397747162856, 47.84802882902084, 46.01376379689863, 55.417010861058394, 56.721387217121745, 60.158293477950565, 58.51185898627005, 59.9697216095463, 56.35147240854079, 58.810774972361905, 50.173629560778224, 48.710099112602975, 49.65312711654171, 52.05923057371571, 51.58257630563552, 48.628521657759144, 49.72622048470282, 58.176410044393236, 57.57302399604552, 57.216382488127685, 56.37236295207855, 58.57044350716376, 61.49791233001217, 65.91168880462646, 64.82019908966558, 68.8020912293465, 69.68691518229824, 66.98564944728729, 76.49471421395579, 73.32618436505719, 49.423029115123136, 24.927484181619462, 7.624987104246694, 0.991617774050082, 15.882726061728695, 63.85050681329543, 70.80945045717301, 63.055403155665246, 33.63687769059212, 11.259573467316168, 28.57984231364343, 50.49789582529376, 39.11799384701637, 41.51519352389921, 33.233756096132346, 43.59233171709123, 42.51763366883801, 43.59013126742455, 41.81198750772784, 58.601489067077644, 34.44627446513022, 38.15138847597184, 61.951769782650864, 33.31605918945805, 72.36774536871141, 77.74775458920386, 85.6622346754997, 9.35490777415614, 0.7598602423264135, 0.17293032949730275, 0.2653226322464405, 0.2179463147636383, 0.14574830420315266], [0.054298408344508185, 0.07876774311185845, 0.025874299800864635, 0.04817505224397586, 0.0329249574532432, 0.033496102813871644, 0.05192535140761926, 0.07687780420265852, 0.06763311478519632, 0.11781093153742053, 0.10174749268879814, 14.730372928803968, 78.8763460036247, 57.32463206014326, 36.62818308799498, 49.871905157642985, 27.914594604123025, 31.17294869115276, 29.493356443220573, 39.5712080309468, 36.65459632873535, 26.72149000629302, 23.905534167443555, 49.795689582824714, 38.19473851111628, 31.750807954419045, 17.611322441408714, 7.616976643762282, 17.548499799543812, 51.522434603783395, 55.0591024275749, 41.77899252983832, 57.63965329816265, 18.820761749821326, 0.3637269631989541, 1.1960914827162221, 0.15872750371213884, 2.8006561436960777, 60.14648322136172, 57.0712391022713, 62.03862282537646, 59.99884520807574, 59.65537501919655, 55.54747673772997, 53.41103230753253, 46.98921411268173, 50.64413747479839, 51.14170189826719, 49.9266065320661, 48.791962900469386, 48.826805314710064, 47.38590694242909, 49.181422879618985, 50.49126309733237, 55.86564371662756, 56.188133147455034, 58.27780723571778, 54.46568704420521, 51.56125822374898, 49.12390132104197, 43.2024638114437, 44.52085087376256, 45.47551262763239, 48.15526023987801, 50.29417184091384, 47.413351766524784, 44.21705545917634, 41.792799272844874, 39.02470811720818, 38.771358305408114, 32.46339278836405, 29.449847552084155, 23.215687313387473, 10.011581182479858, 24.966305840399958, 8.87122756050479, 4.258340299129486, 1.3019064885954703, 0.1258192699582827, 0.0871690156899633, 0.04489984633701463, 0.02818778765598132, 0.030385816484809886, 0.031624182292650786, 0.029505556561954083, 0.05470469541427109, 0.015794378235906122, 0.08799050709292774, 0.059575501589044455, 0.15603804480164282, 0.16425534902561098, 0.032831368321973475, 0.05285134486433479, 0.014259311363040922, 0.08595880361333971, 0.019067099145162972, 0.05097024277934144, 0.046268201943847447, 0.043138736603601326, 0.2851163830247618, 0.4362387480514665, 0.4160801862036029, 1.0834031359803293, 11.4771738167732, 11.440204497306578, 5.744804355405993, 9.058949255174207, 17.521366803876816, 25.8741815628544, 35.75719725701117, 42.09089156120054, 42.363778698828916, 42.53711215911373, 42.08438434908467, 43.127393568715746, 43.49641015452724, 52.01237393963722, 51.103729432629, 52.71772984535464, 50.90296683772918, 52.67432097465762, 53.6404791955025, 53.6490652638097, 46.765941035362985, 41.42162930580878, 42.24667241496425, 45.422356667057166, 42.69690951993389, 47.21744114352811, 53.87062426536314, 56.38028613982662, 54.028801687302135, 53.82488942915394, 49.45592995612852, 50.87028957182362, 55.92032155682964, 60.86432795370779, 62.861575311230084, 63.21661256974744, 60.89232190962761, 70.27454899203393, 65.64855267924648, 54.30204576061618, 33.83181948815623, 11.749079381265949, 1.3075643849949683, 0.3859862913527797, 36.38080704596735, 59.21774441196073, 55.412625651205744, 53.77842110972251, 25.001585598914858, 3.1899084823746837, 13.077844054468217, 41.55835528527537, 24.24328357942643, 19.74011628858505, 20.208712047146214, 29.679484675007483, 32.96696039938158, 34.23241115385486, 28.98045555237801, 38.34987217380155, 51.81882066111411, 18.798112023261286, 47.19007868920603, 39.23381751583469, 41.18463577762727, 58.491003744063846, 77.73542265738212, 14.70111498909612, 0.7232834050251592, 0.138102256422562, 0.08847358681622053, 0.042489906097011226, 0.1366091050928639, 0.055288619121476534, 0.04220552276819945, 0.0666102801539725, 0.03393574918229734, 0.056363130213632706, 0.0722564937126252, 0.007673482825574015, 0.043931469065888275, 0.15331541428402548, 0.13858650059949967, 0.29817732411526865, 21.998520935735396, 89.98999749460529, 70.31611827112013, 46.54397410731162, 50.6024387574965, 39.497122303132095, 34.46091667298348, 36.463667115857525, 40.014820252695394, 32.692686703897294, 28.021341908362608, 29.32724406642299, 49.721148860070016, 35.960093621284734, 31.39546867339842, 14.655347793332993, 9.584725326107396, 22.57256373282402, 55.27279315456268, 61.55785006861533, 47.62545785596294, 65.84329051356163, 27.86389993083093, 0.9896650465746081, 3.3946498315180507, 0.3103044346695946, 2.200810769873281, 62.31173353810465, 60.726727285692775, 65.08287629773541, 61.63086891174317, 64.25336953132384, 57.56768172787082, 56.91803524571081, 50.4907492668398, 53.65228552972117, 54.099208231895204, 52.21019867927798, 50.86486885624548, 51.819809098397535, 48.0426803711922, 50.006528746697214, 53.787591611185384, 57.08610488522438, 58.78917055745279, 59.32116946866436, 58.491364602119695, 53.88106953713202, 52.97281334477087, 46.967166469943145, 48.319682075131325, 49.98577940848566, 50.689986059742594, 55.30828668225197, 50.51852357002997, 49.38665305414508, 46.473987256326986, 47.285580558161584, 45.46307479181598, 41.901817629414225, 37.065794083379934, 32.273189213968095, 20.089107213481782, 38.056933879852295, 19.36688707720849, 3.412657923275425, 1.7403854309551179, 0.04372970448927053, 0.054278800324086225, 0.017238158071714065, 0.07267085534911003, 0.07589878980070353, 0.03367755839961671, 0.035250490125749386, 0.055446693703772566, 0.0988711619509324, 0.0440977561107326, 0.08538443685298966, 0.32240657075758905, 0.08896946786872803, 0.04874901680816566, 0.07071912378793763, 0.04812289697809085, 0.08167421174866539, 0.04634074280939756, 0.14450816107132744, 0.04445157381856153, 0.0425546366961733, 0.22495267912745479, 0.5881125840448564, 0.9872718491861898, 1.3456865135700473, 15.277208205192322, 15.96128034976221, 10.448284149169922, 20.255849130692024, 28.531742288220315, 38.025354877594985, 44.97692838791878, 48.20973019446097, 45.57069286223381, 47.744650840759284, 48.33421445661976, 46.679743028456166, 49.35636058930428, 55.39427680353965, 54.49820741530388, 56.648807679453206, 51.96612527293544, 55.330863844963815, 54.40953047044816, 54.70100572032314, 47.59431423679475, 45.64048359470983, 45.11255610373713, 47.59491828180129, 45.176455436214326, 49.47218033575243, 57.07831505806216, 60.63105675481982, 57.704270424381384, 56.41923135326755, 54.315746599628085, 53.11401867097425, 57.468779163975874, 63.51766624758321, 64.93124923398419, 66.61413038930586, 62.6124930381775, 68.45117245951008, 66.00763782378166, 54.19486307328748, 31.395753045235914, 9.319199496699918, 0.9439066761443693, 1.4237715880717001, 45.676820431986165, 64.78343079167028, 60.472997003985995, 57.802004121964984, 29.924883842468265, 4.694856953236365, 10.968249228692825, 43.06225084489392, 13.528537134970389, 19.9325438468687, 24.13161958417585, 28.19517743202948, 31.855386187953336, 32.10892623470676, 25.492615353676584, 44.70712423324586, 39.67436636647871, 31.573967895200177, 55.5079000226913, 36.99074737487301, 52.79151747303625, 63.74761912130541, 89.70292706643382, 26.37004367766842, 0.7126825867641358, 0.12930968145449317, 0.08506566000681731, 0.021926936010018955, 0.12167576084574386, 0.23575419710288126, 0.1670875607599174, 0.11120700082110782, 0.16151554281673125, 0.22064061534981574, 0.1986371145974244, 0.1750709783406027, 0.22486506931243405, 0.26767715751644106, 0.3039830448406358, 0.47321925240178264, 31.07345581054688, 101.9369722181751, 76.77532057608329, 46.91501071376186, 68.52259882034795, 37.89211980758175, 42.60920140051073, 40.989764582726266, 52.420794656199796, 44.47342941837926, 35.581188740268836, 32.08240120641647, 59.260717899568625, 46.0648448236527, 40.28569913679554, 23.08478017007151, 17.50959380980461, 31.257611090137114, 63.00576556113459, 66.57429479783582, 55.41444955333587, 68.83887521682247, 23.648997429878484, 1.3745538097235466, 3.8619019331470614, 0.1992664711489793, 4.35086214734662, 70.75666319939398, 63.13896925218644, 68.50876854312035, 65.77530407136487, 66.25934416247954, 61.169331458307084, 60.27043011880691, 54.217565751844845, 55.56597071309244, 56.55862846682149, 54.918089297509965, 55.54477422468124, 53.77400059853831, 51.90306925004529, 53.908412379603234, 56.62575983232068, 62.67011657837899, 63.82521929279451, 63.80519559306484, 59.732504506264966, 57.734362848343395, 55.86070937495078, 49.28337312513783, 52.32263734263759, 54.06287531698904, 54.94452999484155, 57.853257733006636, 55.253542161756954, 51.57422950190883, 51.02835324502761, 50.89023874652002, 52.99622597232942, 48.514149265904585, 49.423974406334665, 42.857138341473, 28.161554874912387, 47.33663412832445, 27.70927421508297, 8.13447210096544, 2.902270536268911, 0.2769324802342923, 0.16323271357724745, 0.11765490240988233, 0.16723877119441188, 0.15078185426612056, 0.19374864626555674, 0.11754537481934794, 0.10392065430360456, 0.1692409573062774, 0.09792530383434027, 0.26269240725424986, 0.38023358391177275, 0.21221514971506214, 0.1388560716182955, 0.21425818363505028, 0.0882774300032085, 0.264888720046128, 0.1465160468773496, 0.2419975225723559, 0.2248555545004145, 0.178850396506248, 0.5449391781322418, 0.6872954748330579, 1.7430646549309454, 2.9334288643252466, 21.054455464886082, 22.04974512900076, 17.166051057077226, 32.643007924479825, 37.46369500314036, 47.444299267184356, 53.35846078011298, 55.331040351621574, 48.20705121563327, 51.81363136537614, 50.355403961673865, 51.524344798057314, 50.96786637460032, 58.62856126600697, 56.75299367597027, 57.86647612048734, 56.35276286832748, 57.47486668248331, 59.847386806241936, 58.79229668648013, 52.0978972988744, 48.1218534131204, 49.46265682097405, 49.501111738143436, 47.457176408460064, 51.45227516851118, 58.34671151253485, 63.1111910266261, 60.17130005744196, 61.42088090219806, 54.827972842801, 55.70699168789772, 61.48040286956295, 66.0316348844959, 70.48771412141862, 68.25943131600657, 65.79695947708623, 70.04942063362368, 73.49857253413047, 57.02078957711497, 39.41629794336135, 12.950185614247477, 3.0074390865141347, 0.7919379371789195, 44.801210126569195, 69.86818359744164, 65.66384992291852, 61.35617748383553, 35.13980050240794, 8.566540787296912, 19.05933403199719, 50.745679793819306, 34.12411059102705, 26.574428581422378, 29.04147586514873, 39.02832846487723, 45.16355868308775, 44.77327892857213, 36.651003437657515, 53.098709660191695, 64.65558113590365, 24.812144925517423, 64.03142613749351, 51.048992756874334, 57.511458473820845, 72.47083310158023, 102.54421003403203, 31.293894975416123, 0.9129280416715531, 0.4879306839598764, 0.19904295733619123, 0.0915746954119494, 0.21646810214846365], [0.009663766325120966, 0.05099142128000817, 0.052507336912376266, 0.01933662419868333, 0.025801942796416344, 0.026913300802510594, 0.02500504664626093, 0.09295811230737357, 0.08566289449170714, 0.08885422526227851, 0.13368451847664772, 40.715551683979655, 76.61356987491732, 50.98683495675364, 40.26631086103378, 39.17027511904317, 36.343116990981564, 33.24955148081626, 29.69982412553603, 46.22934510630947, 31.33214004578129, 33.247060775756836, 15.633005422930564, 44.098694016856534, 56.398250595215835, 29.221338110585368, 15.831293002251657, 8.611315623406442, 17.57069060879369, 45.822618853661325, 55.588300766483435, 42.06984804522607, 54.537721372419796, 25.809570320190925, 4.3013476171801175, 3.1764532817948252, 0.8923957821342253, 0.09273130431651108, 46.36408636646886, 59.803832807848536, 56.59604395589521, 60.976268476055516, 58.617872807287405, 56.495411626754276, 53.09654451185658, 49.77967062304097, 49.65621402186733, 50.95349088791878, 48.883248221489694, 47.44883352710355, 49.11238131984588, 47.670965194702156, 45.96468317893244, 47.36116070901194, 52.26742998246224, 54.08176152936874, 56.35882293024371, 55.3964223400239, 53.51871313587312, 51.926152398509366, 49.002354914142245, 43.812282546874016, 45.9309547178207, 45.44880520912909, 48.770942918715946, 45.621589537589784, 45.989433334719756, 39.926194298651914, 40.58527015870617, 36.69292180768905, 32.409891659213656, 24.607161860312186, 19.732489239784982, 11.585193930133698, 32.08257182951897, 14.812906461377299, 1.1670002437406972, 0.2790050238611237, 0.03264939562687951, 0.05173769050968751, 0.06454800210532642, 0.015380040539668934, 0.123807423477692, 0.03780980985010824, 0.016442257835860216, 0.09953925956881816, 0.06385936950063033, 0.07566319478134956, 0.0754922652436841, 0.1472128804532751, 0.03672880233235417, 0.06484006546557912, 0.04564643349318255, 0.1016128603969851, 0.039845669356685494, 0.15084497991108126, 0.07521407573574013, 0.0552600133983839, 0.034173125356075265, 0.28188024377149923, 0.18030260809727255, 0.04649835007805978, 0.3285705754833837, 9.56024581386197, 12.223548889160158, 7.505286662809311, 10.970688942940006, 18.248181996806977, 26.053884952299057, 35.11439923317202, 39.87608601970058, 42.493534626499304, 43.11227675407164, 44.65886731301585, 44.7259476877028, 50.26140828286448, 52.15643082895587, 53.6615619351787, 52.46540377216955, 49.391524637899096, 51.99593528624504, 53.594050099772794, 51.76421342357513, 47.03889877565446, 44.29821322041173, 44.90283873773391, 45.064067763666955, 45.1188789644549, 55.665657751021854, 56.974011390439934, 57.362867324583, 55.031367348086455, 52.68034965761247, 51.451584831360854, 50.268864708562056, 54.0330574589391, 58.36449161652596, 63.36500760047667, 62.573096752166755, 63.162299509971376, 59.46942329406739, 60.45900590958134, 47.430127743751775, 14.600706235055002, 3.3736043543584886, 0.0907685487501083, 7.323491669470265, 60.00656443257486, 54.373244623984064, 59.0731736921495, 49.989003596767304, 29.936368542332804, 2.589866009450728, 9.729679457602963, 32.945034350118334, 23.0183175686867, 15.687967634970143, 20.437903981054983, 33.256811788005216, 27.354593892251295, 29.92017895944657, 39.56277101270614, 29.965874571954053, 55.87088400317777, 33.347414616615545, 27.60373696204155, 35.74149208684122, 45.245967680408114, 52.77305487663516, 78.04869451830464, 39.14538768029983, 0.8929395206993627, 0.13474453901571615, 0.117763051042153, 0.10482331272214652, 0.04882293663197949, 0.015513434641874366, 0.05112740188656796, 0.05387445528721137, 0.01954836898573464, 0.03073350165880496, 0.023888078961341132, 0.03963288843571659, 0.05959545817947196, 0.12627406571541103, 0.06487620949384666, 0.16583105399002954, 53.65784745062552, 85.27974082577614, 63.81360123234411, 39.26846773393693, 46.971555602165964, 44.50928772649458, 35.32923136987994, 32.42201766660137, 41.26287529545446, 32.7781492663968, 33.150644994551136, 24.54876365200166, 48.44200511132517, 52.09785023043233, 28.680706062624534, 16.58706803475657, 10.855994916731312, 21.26771276996982, 51.16704433195053, 58.33361079615932, 48.90569986835603, 60.29726697552589, 31.02397903319328, 7.588166344550348, 2.351827414766435, 3.3498232691518726, 0.6455099750911036, 46.71460113217754, 64.23523641401722, 62.704045080369525, 67.03638138309603, 62.567017078399665, 61.48598047994799, 57.19485652062201, 52.84258281030963, 51.808932365909705, 52.261409144247736, 51.136367474832845, 53.4566730068576, 53.04660881719282, 49.974722246969904, 48.2440273992477, 48.30865237020677, 54.222201993388516, 55.75145959854127, 59.50495212308822, 57.4900697892712, 55.53131265024985, 56.87015487301735, 53.79219647376768, 47.82507904114262, 49.839706420898445, 48.53608708227835, 52.51528455365089, 49.19605332036173, 49.13879848295643, 45.806019383092085, 45.778692230101555, 41.89291777149324, 39.86594277043497, 34.65125360796529, 30.042490228529903, 21.531703972047378, 42.374424011476584, 24.314072555111302, 2.132739506421551, 0.6730352690623653, 0.07926064408234051, 0.06921789023063837, 0.10446863699584238, 0.04042007059099213, 0.03160238134554558, 0.04145519710296104, 0.04729074163122043, 0.016496092749519214, 0.019021493931030555, 0.15264125691065866, 0.04727066246672504, 0.5264378483256986, 0.029273904980190342, 0.03585124095421165, 0.06914166448217246, 0.1067398731867152, 0.12674796004449168, 0.0717615626091438, 0.03235996377864673, 0.046410816871831496, 0.06152560521337775, 0.24428360554720127, 0.44340280395361686, 0.1665714932906051, 0.5049430146332711, 13.998417469762988, 15.859958664063486, 10.779494970075547, 21.605360200328214, 30.27324522695234, 36.6860302032963, 42.45874712544103, 45.9851618736021, 46.31293865942186, 47.00124009963005, 47.79115446152226, 49.819365009184814, 53.591088710292695, 54.693686577581595, 55.156502723693855, 53.38348157944218, 51.83170956950034, 55.34328599129954, 55.2940563232668, 53.76850143555672, 47.51526671071207, 46.033689437373994, 47.01634906953382, 46.49227334607033, 50.08862003203362, 57.87810987041843, 59.531726221884455, 61.37935869155392, 57.480683557448856, 55.3078003083506, 52.662636233914284, 55.31051066613967, 57.37738009422057, 62.065494983426994, 64.51490532967352, 65.62399079722744, 64.79505277449086, 60.98505458524151, 58.51149420584402, 39.90905354099889, 11.111835433590798, 2.2561983139284196, 0.196411767073216, 12.763349394644461, 68.44449658547678, 59.19557909811697, 64.251506405492, 55.42010168875418, 33.83991918256206, 2.6169999857102675, 12.507224505947484, 39.33297503379084, 22.203419669981926, 20.02970487840714, 25.147429127846998, 25.402051748767978, 26.40159130096436, 31.00632836741786, 32.40505537679119, 35.56575813601094, 47.99707105082851, 30.815450145352273, 39.8689276941361, 37.778045515860285, 53.69352140734273, 58.272649318941184, 82.71458918048491, 52.00137169130387, 0.7874506231277221, 0.0070558996090004525, 0.08064180101838805, 0.046753568439594204, 0.054709617529184594, 0.07400481360814265, 0.12481157322444263, 0.12236810514643309, 0.12811480645811366, 0.18646866593870426, 0.20742423501947235, 0.1705080514112788, 0.2260582359327424, 0.28656775191906964, 0.2688449819482142, 0.2108757675535256, 69.19304170916158, 96.90295527058264, 68.14183865824054, 52.015794246427475, 58.52080983500327, 47.1519846300925, 45.3167546949079, 37.44868409249091, 57.885687889591345, 41.89762853807019, 45.06976696752733, 23.899470183157153, 49.989003596767304, 66.28092504316761, 39.131949640089466, 19.99657261756159, 18.77219888471788, 29.997265300443097, 57.451587415510616, 63.91593979251001, 52.9289573238742, 68.31122229176184, 35.90424299240112, 6.625144548954503, 11.155417869167945, 3.917391213678545, 0.5367348667594695, 54.722119838960715, 65.90027470742503, 67.63278561253702, 69.77394473168158, 65.4961411414608, 64.76214016637495, 62.34290069149387, 54.671615400621974, 55.536796123750754, 53.885376299581225, 53.45255059580649, 55.025679911336596, 55.39899149248677, 54.00103130648213, 51.531652173688336, 53.984965278256325, 59.715104872180575, 61.66463659655664, 63.91087601261755, 60.93967668471798, 57.16778824406286, 58.82163993773922, 54.505542247526115, 49.945073050837365, 51.28784156614735, 52.71958904881632, 56.635044082518554, 52.392251568455855, 54.24982332414197, 49.931878197577696, 52.39384405074581, 50.45108625965734, 47.32703216614262, 43.92849060796922, 41.77175967924057, 28.939456978151878, 50.902562833601436, 29.976196289062504, 3.279824405908585, 1.0738222565381759, 0.2151266362277731, 0.21883281638785718, 0.21388083936706667, 0.15092900443461635, 0.22433611624423536, 0.06953557923195824, 0.26288276478167505, 0.289555985120035, 0.13687821645890513, 0.22076967052154003, 0.15569062392798164, 0.6079706862088173, 0.19885394812351276, 0.29682729333158464, 0.1437996369936774, 0.2273050133859919, 0.3004155265948465, 0.2444664860564855, 0.23805619938479317, 0.1993179062922155, 0.13652322663655206, 0.8173450286830626, 0.7927157309266829, 0.2370464035700406, 1.0331239887783605, 17.910813054730816, 24.370231090053437, 18.461211804420717, 37.324588144979174, 41.62314107341152, 48.431979533164736, 47.88353804619082, 51.258788570281006, 49.18904012249362, 49.722329493491884, 52.675807552952925, 51.44205347184212, 56.442306656991285, 58.92978360576015, 59.44637152456469, 57.2465023686809, 54.88520414598527, 59.086984357526234, 58.36850420121224, 57.144465831018266, 51.02232848444293, 48.974545309620524, 49.33634081194478, 49.238916981604795, 52.131158997935636, 61.05621422490766, 62.485494536738244, 61.979602921393614, 59.50310076436689, 57.38600930859966, 58.32831167405652, 58.36087126885691, 62.27411016341179, 64.39843446977677, 69.3327957584012, 67.57163586155062, 67.05704442916378, 66.4616600159676, 64.34363111372917, 53.07287693023682, 17.65696902428904, 4.9606014547809485, 0.37527815949532295, 9.318016902092966, 69.04352095819289, 64.904043674469, 69.60998181373843, 58.45006596657538, 40.54423039959323, 7.96288017303713, 17.077236829265473, 42.54883220118862, 28.358640247775664, 20.246578608789754, 30.896205863645, 42.23028867475448, 36.439634753811745, 41.33832208571896, 49.982206129258685, 37.6253358779415, 73.4885077322683, 42.54596102622248, 38.64707016175793, 49.754438015722464, 57.17030640571349, 69.2010590337938, 93.34678542229437, 62.507134252978915, 0.9530952572822572, 0.25160118546937743, 0.17078935889707458, 0.3035489487792215, 0.1273650974936543], [0.06363325481933933, 0.030176283776639935, 0.018829089033627705, 0.027462128106684938, 0.05192417929309511, 0.06871910570489784, 0.05993554376125817, 0.021661603372664224, 0.13798423291694734, 0.08258193400838683, 0.7236910250879104, 51.157281552591634, 65.98047933270855, 49.05186699282739, 45.98882536734305, 26.39533119816934, 39.66696485396355, 30.642010781072802, 37.33562961701424, 42.27481542095062, 30.975469120087165, 34.564753578555205, 23.02744688526277, 26.07148462726224, 45.48141187237155, 33.323613674409934, 13.022532751483302, 5.63891310845652, 12.982415729953399, 47.05522760268181, 52.21144991536295, 43.5122408405427, 63.112952170833466, 48.76239215174029, 23.070845950034357, 2.787021739828971, 4.4874567274124395, 0.16491072192307443, 28.449007734175655, 59.779714153658965, 57.72531394035586, 62.31149427352413, 58.73937999048541, 58.232111623210294, 52.703213153346894, 51.042681663267075, 48.55079989279471, 49.42264472284625, 52.446360664982954, 55.91051563139885, 58.65118549716089, 50.90903474438576, 47.93709801089379, 46.03257156187489, 45.15665531158448, 51.44148865053731, 55.29395041927215, 56.826624408844985, 56.64977650488577, 51.61590076261952, 53.50099578980477, 49.766130601206136, 45.95145302434122, 44.68105223871047, 45.966471779731016, 43.72985786007297, 46.11898137677101, 40.671072006225586, 40.38333085275466, 36.17001102816674, 30.654527064292665, 24.241530279959402, 15.487389391468419, 11.428056916882916, 33.13439461492723, 22.423921592773933, 0.7460450417091771, 0.46188838299243684, 0.1601168960933724, 0.01895988705537973, 0.02683270643765648, 0.06822930739050911, 0.04594164930524365, 0.10175044978818587, 0.05938948394971029, 0.11673000445889851, 0.06926315070520486, 0.03696825843484652, 0.03905261130703073, 0.17983708710920426, 0.04891213224900346, 0.06427837746037592, 0.13445416104889688, 0.0296534632422751, 0.0740537896091419, 0.03242475566484275, 0.043558407229401415, 0.03416465242363272, 0.0622144255096153, 0.11176371691568245, 0.1430439985086841, 0.07328646062242408, 0.40777916389126934, 7.334015388642588, 11.196202674219686, 6.985186751811736, 10.093710710925441, 19.574700132493053, 25.145703284971177, 36.98588363585934, 39.10548540853685, 41.457260116454094, 43.203593454053326, 44.21786738980202, 48.38777834369291, 51.40850151738813, 51.25760009211879, 53.528797549586145, 44.90710235411122, 49.79127691638086, 52.77549066851216, 53.1522225564526, 49.14092832996, 45.32241859743672, 45.54158887555523, 43.24319370331303, 45.53783908967049, 51.93161233778923, 59.199140610233435, 56.96353473970967, 59.3189964755889, 55.87196657734533, 52.84985096223893, 47.44199683589321, 49.97952322806082, 53.77328280479678, 59.96027654217136, 61.51131506889098, 61.60252194250784, 62.12932763561126, 59.26353023898218, 40.25048017501831, 11.315949693802866, 2.461164954208559, 0.6946345971476647, 0.11270862508324847, 17.387264890055505, 53.40161861911897, 49.47060354294316, 53.62746084890058, 55.662876790569676, 21.565916845875403, 0.317582423167844, 13.934798586753107, 59.18338837162141, 30.25839513347995, 16.34206992964591, 23.818030011269357, 34.52738515792355, 32.16092117371098, 28.671480647979248, 36.905820215902025, 32.7591787230584, 35.840771198272705, 51.970133935251546, 27.999537452574703, 37.494007079832016, 30.548348503728068, 54.57885919078704, 64.15737344372657, 48.842561475692264, 0.6627098747318791, 0.09086433272328108, 0.04645100201389963, 0.09449575036283463, 0.08540862990963845, 0.028262508041676015, 0.07276082471493753, 0.06492267272645427, 0.03635310898384741, 0.07000391176270862, 0.028048194944858554, 0.025272713936564904, 0.03457131487647853, 0.12234942026195988, 0.0709450890820834, 1.2105644157817288, 67.49639695690524, 75.51048171135687, 60.168122937602384, 45.440509396214644, 36.465930323446955, 43.363441805685724, 32.389181544703824, 37.810993425307736, 35.913758662439164, 31.086972298160678, 34.98786749378328, 26.837601969319007, 32.98501899165492, 47.95637253792056, 30.976392838262747, 14.592139778598664, 9.830166659047528, 12.225679716756268, 47.45451311911307, 57.136244543137096, 46.00165151780652, 70.44900817255821, 54.13225812296714, 31.10464257578696, 4.094235930711993, 4.563377143875245, 0.39484836581733923, 28.260932045598185, 66.21879469963812, 61.48721210418209, 65.26869073990854, 63.200542619151456, 59.62561991906936, 55.66557145887806, 53.33236525135656, 51.22838235670521, 53.1514145481971, 54.846188329881244, 60.56232898466049, 63.72290034447948, 55.27684496295068, 50.61542180276687, 50.63679872020599, 47.75259364035822, 53.32871352472613, 59.10228552356843, 59.00005678976736, 59.42686950006793, 55.142684213576786, 57.757716640349365, 54.41266444421584, 51.180329399724165, 47.75351931971889, 49.94082512394075, 48.273609915087306, 50.71731713510329, 46.752055844952984, 47.102860866054414, 45.480243006060206, 40.401365910806966, 32.59299378241263, 24.90447359700357, 22.227848191415113, 36.0454483186045, 25.406742903494067, 1.268564503519766, 0.6130712996086767, 0.012481632105435335, 0.028794339685250196, 0.04796608261043026, 0.039956775088343895, 0.11044072137484628, 0.17199303624370407, 0.07534876165370788, 0.16050596150659746, 0.05919097141633111, 0.056912304172592784, 0.06998245363994952, 0.4195839046470581, 0.3242670612469796, 0.06072990799082383, 0.10270595295174469, 0.03232798343824764, 0.06895142186793589, 0.07686313361890855, 0.03898239168789118, 0.014321666132027825, 0.06406961850100948, 0.10878074673875686, 0.23964128126540493, 0.2565429888425335, 0.11990475708678847, 9.441273462387825, 16.569515428235455, 12.55534904618417, 23.065437001566735, 31.108708112470566, 38.76700055214667, 45.48390649980115, 45.22226479745681, 45.503279086082216, 47.30070521754604, 48.59241231795281, 53.810337435814645, 52.09435147623862, 53.9027641665551, 54.03279073776738, 46.56373108586958, 53.368290239764804, 54.35111068910169, 55.83055811543619, 51.50088510205669, 45.50305158861222, 46.911437434534875, 45.218369883875695, 48.85687420445104, 54.566107565356845, 60.966607678321104, 59.41151734321349, 62.76477513774749, 58.81298718913909, 56.07354110287082, 51.47657425172868, 52.580407665621856, 56.35342182651643, 62.86101048992526, 62.708736235095614, 63.57310110522855, 59.51088666915894, 58.98779938297888, 32.15654380859868, 6.374045197040805, 3.4466205008568305, 0.7202754373992644, 1.0014776933577754, 25.097926855087284, 61.23749440716159, 56.714381863993985, 58.177323956643384, 60.353921690294825, 19.148385563204368, 0.4633886589398308, 20.209561240288522, 70.81377290910291, 36.258625215099705, 22.722978784191994, 27.250802093936553, 27.033110549373013, 29.313943309168664, 33.27750621303436, 29.720542084786203, 35.29650311316214, 38.89922365065544, 45.79447977004513, 35.63520762228197, 40.91154075437977, 41.68526749457083, 58.76267886930897, 72.53004520170151, 59.18575356083532, 0.6698854832399277, 0.11474637299655907, 0.019713351765887874, 0.034868449738789956, 0.051553637885879126, 0.16760984886317484, 0.17915310848864818, 0.1626907216925775, 0.11745787225663663, 0.2994233201588354, 0.15232216596843737, 0.10194062345450926, 0.1939044838711139, 0.1729577401232335, 0.16297608944437197, 2.398513670890562, 82.31902599334717, 85.50961525209489, 64.61588674975981, 55.43886238528837, 41.16951504061299, 52.61372820023568, 38.64688973273001, 48.035753465467884, 50.70965674615676, 40.07032571300384, 45.933543482134425, 32.54233441045208, 31.30878821496041, 53.63146558884652, 42.88078238887172, 17.73240012507285, 14.709929535465857, 24.494456475780858, 57.58727004451137, 64.90332980309763, 51.5157744192308, 76.96070747990763, 60.59607313525293, 28.469396214331354, 8.684957142799131, 10.470849544771257, 0.2654958294043618, 37.93555613486998, 70.78575149659189, 65.56487675636046, 69.27103411766791, 65.93623499716482, 63.37913205546718, 59.423186394476126, 56.104053220441266, 54.681915544694476, 56.63326724883049, 56.191945691262525, 63.31358924988778, 66.55834644071518, 57.932003236586056, 53.99795224589687, 52.70703354189473, 52.25348203412948, 55.56056960936516, 62.07463410592849, 61.81982909479449, 62.54214532913701, 57.222144449910815, 61.93361313112321, 57.615593479525664, 52.83678162482477, 50.44435939481182, 54.211701808437226, 52.35802496633222, 54.51272410731162, 50.44891718895205, 52.898660936663234, 50.6937397679975, 50.44501443063059, 43.65803533984769, 37.71535819576633, 33.885987420235914, 49.39989889821699, 34.084071036308046, 2.174253136880936, 0.857759047179453, 0.1654288271862653, 0.06817727469869199, 0.18148074407250653, 0.19753551080582604, 0.14271733861777092, 0.3229516882809901, 0.18022108102037063, 0.22612473236456995, 0.10088830209907987, 0.13176632624480034, 0.1374447078353936, 1.0074964478131265, 0.24736554662306465, 0.2932637893865186, 0.2456156179429062, 0.2157699355795499, 0.14885684385174705, 0.12063099311724787, 0.17461256664847175, 0.158784837732392, 0.1559369365173963, 0.3600593019397028, 0.2600469217906075, 0.4002220129534122, 0.36319419501289246, 12.631453814045077, 21.53119210273989, 20.349711448915546, 33.94217145058417, 40.47150965659849, 47.58418667700983, 50.95982551574708, 50.338914317469445, 47.80852663901545, 51.74855924421742, 50.023210587040076, 57.12985500212639, 55.40507116625386, 55.619040381523874, 57.013446900152395, 48.96715556421588, 54.253757461424804, 59.185004388132405, 58.75100589567616, 55.27551527946226, 47.737237561133604, 49.621171566747854, 49.366731336039884, 50.49449120798419, 55.548755430406146, 62.24107988419072, 61.07200960959158, 66.22395653878489, 61.08570260386313, 58.90944219404652, 52.50830665711434, 54.5249972035808, 58.856345069023874, 64.22095506421982, 66.49178381889098, 65.91597203285464, 64.55960466015723, 61.47195016184161, 46.436658059397054, 11.924511309592955, 4.658677501063194, 1.5770016754827194, 0.8019762017553853, 21.906366809721916, 64.8130682206923, 60.162651231212, 64.17538888992803, 63.493724100051395, 30.42062632499203, 1.912474887024972, 21.110025644302368, 64.27892377299648, 37.287576660033196, 22.799190436640096, 34.076190994631865, 45.834029028492594, 43.12077653023505, 38.499141893079205, 48.26524349950975, 42.8490190352163, 48.88725296143563, 65.09872659560173, 38.67555441394929, 51.709433601748565, 38.26166591336651, 74.00958676492014, 79.09654786509853, 75.2381201713316, 1.3242633857073323, 0.3309376033083085, 0.14947205842021974, 0.23393156667870862, 0.16200369404208276], [0.015572819862544779, 0.03976843237215954, 0.0205513600244998, 0.0390914443039125, 0.03792831216067557, 0.059110784993296674, 0.06441097961918962, 0.052991676850304495, 0.06489426618622196, 0.012354612812369823, 3.0228064425529975, 69.6724416363624, 65.94960243471208, 39.612651794187485, 30.72989932952389, 36.01388892819805, 41.111797363527366, 31.896427908251365, 35.99084108106552, 41.56848284506029, 38.15083934414772, 31.838572948209702, 34.06050543631277, 28.81706137810984, 38.15396155080488, 34.63101810024631, 17.28179039493684, 5.879162203881049, 3.3296174243573224, 27.669793598113525, 60.504819193193995, 49.67642991773544, 59.825390154315585, 57.92607653525568, 42.988624034389375, 6.425378236078448, 4.557832383340405, 0.8666539408506886, 11.717311124647818, 57.93754162326936, 57.25219372780093, 60.90663856075656, 60.47976701490341, 58.76938612230363, 51.78064423222696, 50.978907846635394, 50.06381496306389, 53.58525222347629, 57.42535460379816, 63.282551534714244, 61.564133705631384, 59.91835032739947, 52.05340585400982, 45.73944499415737, 46.036144841101866, 49.718991556475245, 56.63527157998855, 54.09638804774131, 56.23469168140043, 53.57641120110789, 54.51242208480836, 52.664577807149584, 50.18948378101472, 45.23463987535046, 47.372206103417184, 47.957290372540875, 45.48089411950881, 42.293964432131865, 40.732578692897675, 35.0983920404988, 30.979240479007846, 24.289194922293387, 12.121580992975543, 11.394934461962793, 21.621608618767034, 10.73898276975078, 0.5208125566282581, 0.2595808645409923, 0.06701644464966751, 0.12387202001146733, 0.039790028390745004, 0.01111370550784012, 0.07129539810721913, 0.0215245425821312, 0.055847522397074974, 0.061179011714674776, 0.044958693380918235, 0.0649705149173256, 0.020613763631591876, 0.734842139626703, 0.5992700111481452, 0.0653007371170867, 0.06972310223406361, 0.06219117474111338, 0.10968636225668654, 0.023618799055956548, 0.06598656967041955, 0.10516013093893567, 0.015436591235019509, 0.07567049559926795, 0.015263982049580065, 0.05486314921008964, 0.11894480295238957, 4.958473078666195, 9.863872566530782, 8.242303940557665, 12.280967485520149, 21.0033195249496, 28.843047080501435, 34.44597244262695, 38.7279337452304, 42.40991753916587, 42.7788870565353, 47.80000332863101, 49.881393371089814, 53.58781745356899, 53.192752407443145, 48.204227109109205, 45.84432525019492, 51.7817581853559, 49.88090307481828, 53.82321849946053, 48.80760531271658, 44.03084093524564, 46.01738806693785, 43.954582214355476, 50.39350194315757, 57.62865889456965, 56.780968020039225, 59.42093495399722, 56.177146588602376, 57.85543857082244, 52.44344634394492, 50.753010703671364, 49.3270016485645, 53.519791787670506, 58.75888985972251, 61.750489434888294, 62.94915791480773, 60.52054397521481, 41.1380890107924, 5.2347893484177135, 0.8025825756692118, 0.735155193796081, 0.11943430249248782, 6.918832015606665, 43.217035416633856, 42.89680527102563, 62.81196517329063, 61.858919435931796, 52.75383918516098, 6.214357662585474, 0.6700805598689664, 14.493819686674303, 41.06771776753087, 30.722644905890192, 25.72753590922202, 23.77366800462046, 27.714822407691713, 27.314379792059622, 31.47208432997427, 31.27006461543422, 41.70935476979902, 27.138641918859175, 40.440146384700654, 38.898223446261504, 32.977213475012014, 26.199659839753185, 44.01459840036208, 59.768802119839584, 53.6768356446297, 0.855161028523599, 0.08110218921736365, 0.03917419329105366, 0.0403540414727984, 0.03993305317576855, 0.027264019684685815, 0.06334959927405562, 0.0377888267018622, 0.10059851401996228, 0.06026177081249415, 0.02085470594465733, 0.061344272201700564, 0.04696569052494822, 0.08644147731003263, 0.18993742012929535, 5.49117164265725, 81.33185955785936, 70.7666495538527, 52.598933019945704, 41.47951956718199, 41.6412506564971, 44.20160524306759, 32.861601614182995, 36.93406912588304, 36.26069622655069, 34.12416158183929, 33.88812903435, 37.31134230090726, 31.493286701940725, 41.98550924178093, 31.24041541930168, 12.982385331584563, 7.438745123724784, 6.192194309926802, 27.040955289717648, 63.664657069790756, 53.70226044808665, 65.69905319521504, 58.66437250568021, 50.19531634546096, 8.937395003534133, 3.787627441267814, 1.4393958593568494, 11.056903619920055, 66.55083902420537, 60.65631289635936, 65.9015690895819, 64.08480959553873, 62.639761355615434, 54.36776115048317, 53.59899228618991, 51.771403128100985, 56.57925228918753, 60.9712125409034, 67.46427274519398, 63.89888924937095, 64.80675712708505, 56.61047043338899, 48.6555193316552, 49.861173552851525, 51.3114816911759, 57.62696443065521, 56.848197444792724, 59.9690273500258, 58.14736097089706, 59.20765607587753, 56.519087053114376, 54.06016888157014, 49.45085440912555, 49.60948682600453, 50.51978657322545, 49.908877418887236, 47.657578145304036, 46.44636984794371, 44.55060989625993, 39.06189610881191, 34.81628341059531, 21.99173131296712, 19.24746463375707, 21.485941679246967, 9.046335893292582, 0.5818891308961377, 0.0985160801980284, 0.040964207521850066, 0.08504217175105888, 0.0647482498278541, 0.038127184755379157, 0.12315735190866456, 0.07710792169335388, 0.025792646319455197, 0.06828386817247638, 0.1458050100313079, 0.032305138696345596, 0.002930878113294321, 0.36345291822668047, 0.9357110675304168, 0.09117293592181899, 0.030952367233112458, 0.07363944329441556, 0.10488410945981742, 0.052951966682749416, 0.02824593372943421, 0.033803212140957196, 0.05900832073342416, 0.04765377154633884, 0.06910001228172934, 0.04234587007592763, 0.016421498768332026, 7.14092642068863, 15.736769764654099, 14.587763394078902, 24.295178497991255, 33.10770680827479, 38.33419053785263, 43.90702739838631, 45.514677493802964, 46.31628444117885, 47.43885893975535, 50.53852765790878, 52.4600262026633, 57.371414169188476, 55.040479013996745, 48.332798480987556, 49.13961825832244, 54.560098494252856, 54.43236650959138, 55.356802478913345, 51.75773366805046, 46.00758214150706, 47.63287898032896, 45.241637383737874, 52.40835682038338, 58.73539094002017, 58.50637943513932, 61.78461797775761, 58.127047015774636, 61.04821258975614, 56.85553619938513, 54.89362155237506, 51.70002775807535, 56.05572569754816, 59.999892480911754, 64.65496140141641, 63.041388527039565, 61.15699952648532, 35.911973984010764, 1.5990990832928689, 0.5238146406988944, 1.3213224660965706, 0.7628662487672222, 11.14432736750572, 47.82574192170174, 49.83418764606599, 70.41746447163244, 72.2224921564902, 54.21388264625303, 7.697219021858708, 1.1740895601049548, 13.63683867839075, 36.19362761897426, 34.55634793927593, 30.825440422181163, 25.59682292322959, 28.82899126698894, 26.83495633063778, 32.32144809538318, 27.032488853700702, 38.556082940870716, 31.76498732259197, 38.213483518169774, 39.378854997696415, 37.591026906044256, 26.55811152150554, 53.21417247095416, 64.69411842284664, 65.93614870502104, 1.396394792583681, 0.04775599831895483, 0.06161934373179271, 0.010137585960629006, 0.041182148044989, 0.08570617079854974, 0.11427136017910897, 0.15416347361620397, 0.19839498484807633, 0.15344246230538816, 0.19922833529210862, 0.19848460181345864, 0.21087400555129976, 0.24327154211219282, 0.5220541093618639, 7.840220303304735, 94.59649178289598, 84.72864781656574, 55.80219545672017, 46.13836965253277, 47.1812572786885, 56.847522797123084, 40.607941458302165, 45.476540288617535, 52.020089241766165, 50.067819703009825, 43.074249375251036, 47.61867215556484, 37.10519036939068, 48.083547546017556, 44.906717961834325, 23.03219883672653, 12.591822185823995, 12.662492509811157, 39.10216708337107, 71.14555051249843, 59.44905834813272, 72.1108615013861, 68.76163590338923, 53.369502252148045, 10.488954224894124, 12.741953845947021, 1.8468656463007775, 17.24680873655504, 73.97944727251607, 64.07856125985423, 69.70759391784668, 65.78276441943261, 65.56104852307227, 56.40827617337627, 55.901847193318034, 55.32400754190261, 57.50435506143878, 62.21097177074802, 69.85894249331567, 66.26009725755262, 67.17961849704866, 57.92044008931806, 53.24038174844558, 51.4195429894232, 54.747893733363, 62.3989474388861, 61.584745760886904, 61.9372138669414, 60.72885713269634, 61.55628112054641, 61.12451053434803, 58.1873809137652, 51.96323056374827, 53.73751471119543, 53.32248087852232, 54.06260859581732, 51.40575193589734, 52.12761709767004, 47.556741852914136, 50.448893654731016, 45.65024637406873, 34.58562058787192, 32.448189681576146, 37.371476158019036, 19.659305657109908, 1.2464954103192976, 0.3526352970830856, 0.20062852951307453, 0.3755545027313694, 0.16176799943129863, 0.18797588264269216, 0.17206161643468565, 0.09116686850545869, 0.1074966761253534, 0.20827368863167303, 0.2613788422557616, 0.14317575030990187, 0.12843273294669005, 1.771048069480927, 1.785072381457975, 0.3083149043302382, 0.12069392724022751, 0.24346614376671855, 0.39802205358301446, 0.13077729141279576, 0.1761959324921331, 0.27291269432152476, 0.13337325695301258, 0.32718533529869975, 0.17469603958870136, 0.1890485283107527, 0.16985568157847852, 10.439757897007851, 21.685260841923377, 22.195784776441513, 36.10456628184165, 41.19015063008955, 47.80522008096018, 47.32065046987226, 50.611895591981956, 50.18441215638192, 50.60611009597779, 52.16466388394756, 54.610073412618334, 58.60629004816855, 59.801016546064815, 51.40763075120988, 49.8504654822811, 56.92093387726815, 56.86300831456339, 58.2850871547576, 55.86819717960974, 49.28074905949254, 50.74605241898568, 47.93305796961631, 55.34056778877012, 63.28584240328882, 63.51392038406865, 63.77059244340467, 61.251775756959, 63.06405982663555, 58.791233724163426, 57.69447234369094, 55.31466837852232, 57.83949021370181, 65.0372983563331, 65.93946703018682, 64.69913121192687, 62.90316027979698, 48.62165750995759, 7.688941349906306, 2.498908696636077, 2.590181269953328, 0.9076944966950725, 8.036106411487825, 53.698891132108635, 54.059898238028254, 72.41764576204362, 72.69285494281401, 62.27752262546171, 12.517429532543307, 3.0905842636862113, 20.370674556301488, 46.814825534820564, 37.02684494756883, 33.833894421977384, 32.37171915269668, 37.92040794126449, 37.53805137449695, 39.63358548379714, 40.38525673650926, 55.732067400409335, 37.65386327620476, 54.54013755244594, 50.46964299294257, 49.14684326417985, 32.992420504170084, 66.85785862707323, 71.70672401305168, 79.18087097906297, 1.8252157564124756, 0.32290131033908936, 0.09770750503746733, 0.13334488105629722, 0.20666597651377802], [0.04394155844385105, 0.006110762572667051, 0.024816922265134995, 0.04839382780295226, 0.04519140024879768, 0.04379709341352986, 0.04911921730625534, 0.05956790199683559, 0.11078171477082277, 0.12023785211626561, 4.588010118853662, 71.43884966450354, 54.31127902000181, 40.6705464086225, 34.94482340351228, 32.715410955490604, 39.19844165925057, 34.26416666276994, 43.304963188786665, 33.15914869308472, 40.3086724588948, 31.416308226123935, 35.130873187895745, 33.80803815780148, 32.42562820834498, 34.71910668957618, 19.01901206662578, 7.243842059566129, 3.6351055868210334, 13.415927848508282, 44.22417848340927, 53.25789905363514, 55.2981944237986, 52.79707939394059, 58.98276305967762, 12.220305089027653, 2.164909315686072, 0.6703165762366787, 4.887869925268235, 55.75367181531845, 58.974024018933704, 63.451331123229004, 61.08121541238601, 60.334666775118926, 51.83319222542548, 51.576151463293264, 48.04309222006029, 56.190714067028416, 60.935958277794626, 65.31903828344038, 62.982219572990175, 62.06169420673002, 57.870057244454664, 48.64223426388156, 47.27841831022694, 45.75333018456736, 48.44488413103166, 53.29653832220262, 56.13590678861065, 55.54654321362896, 54.87585713786464, 54.22923480310748, 51.45731149181243, 48.39162226646177, 47.73608046193277, 46.89908981323243, 46.648399368409194, 43.73998541985789, 38.75574334975212, 37.86323939600299, 25.733464571737475, 23.00867049924789, 8.053248640029661, 7.411375314958635, 13.222119615923974, 2.81696928124274, 0.44785037336330263, 0.03542351874432737, 0.07236159331495724, 0.07194409071798287, 0.04245191196640653, 0.10204802898149337, 0.04351289777625953, 0.026764112840136214, 0.08867272371125799, 0.07807659390833109, 0.06934297706691489, 0.08246247791835377, 0.059704805739344134, 0.28543669970766194, 0.7726651261891089, 0.06440613028262893, 0.09515708342434899, 0.06536805326299322, 0.05578210231878104, 0.06443007053026269, 0.04861543022636925, 0.03966882178980497, 0.11127530522043667, 0.09833650152769782, 0.10677055500808263, 0.06537805071040508, 0.1874773126215704, 2.8825334147099526, 8.778435068745768, 8.178987570347326, 15.100782936619176, 25.12669155674596, 29.840158685561153, 35.653305438257036, 40.48457899401265, 43.55720296982796, 47.57099966849051, 51.240549548979736, 51.72932786326255, 53.31007442166729, 50.412635264858125, 45.056026904813706, 47.4393766926181, 51.62402791361655, 52.175724967833496, 52.4255838701802, 47.86604427522229, 44.43167971026513, 45.72392809775568, 43.3591664221979, 52.07444544761412, 56.752283726969075, 58.51246695364676, 59.47602072069722, 55.85231550278203, 58.09532288582095, 53.48072105838407, 52.3123921117475, 50.819879270369015, 55.64934853584536, 58.96916812466037, 63.37660997144638, 63.35156171552597, 64.99989071199971, 9.283716755528605, 0.3596668810613694, 0.5460814458708609, 0.8424546329244491, 1.305918705559546, 19.59784603887989, 54.48778175538587, 65.88598943525746, 58.48363361051006, 44.38701568111297, 45.19400412036527, 6.48267621955564, 1.4507649718753755, 9.477395549897226, 28.062138480524865, 32.02622109843839, 25.756037812079153, 29.674834705168205, 24.539853988155244, 29.914301287743356, 33.61796402162121, 29.260487287275254, 42.215144403519176, 33.78804975940336, 32.38534742786039, 39.39350112791985, 36.80360717158164, 41.12027752783991, 48.30545956088651, 63.21119577653947, 49.04956063916607, 0.43047402835180687, 0.08857584423235348, 0.0352806854812849, 0.04107296136358092, 0.027547966343380755, 0.06888107201384921, 0.04736326717501206, 0.12282990294718936, 0.10283102446626272, 0.042045464018179525, 0.024960247739668817, 0.0643604331379456, 0.07163091397453701, 0.08828485339519479, 0.339969044491168, 7.2489504564192995, 82.74054742628529, 65.81046811995968, 50.2262677684907, 39.13230657577515, 40.053161421129786, 40.97036061748382, 35.72129188045379, 39.8398825430101, 32.22961168135367, 36.51084930666032, 30.676078527204453, 38.58244519079886, 33.80200163010628, 32.519110056661795, 33.52239155000256, 14.574694056664745, 4.981150752113712, 6.676681551241106, 15.805110200758904, 47.87329281530073, 56.06663380899737, 61.52867940164382, 60.3127524929662, 69.28650394562753, 15.556792789889922, 2.7256486588908784, 2.039013000265245, 4.210747730347419, 61.61717983984179, 64.17536927807716, 66.6171427695982, 64.04730389195105, 63.35520559741605, 54.474755564043605, 54.664319792101466, 53.876625491726784, 58.95362377166749, 64.21003910803026, 68.19214697807067, 65.11694992742231, 63.65597294222925, 63.016716818655695, 51.778769339284594, 49.127258869909475, 46.615078833795366, 49.450819107794, 55.53213634798604, 58.0142867180609, 58.77981962696199, 58.20339595117877, 57.73224476845034, 54.71325528237128, 52.64956689650013, 51.87424767401911, 50.725875746819284, 49.11005143196353, 50.560822409968225, 46.30301114051573, 44.81804886171895, 34.607687842461374, 30.84280279374892, 18.058331435726537, 17.96645187562512, 15.578973793214368, 2.9817961012163474, 0.3057413392009274, 0.054360273774833455, 0.08096069277774903, 0.040814521602324905, 0.07699413465396052, 0.1387886712027173, 0.03223325666641036, 0.06081418915381355, 0.04760215254200082, 0.08685092066204356, 0.037496085353796525, 0.02077880961399886, 0.05571332294493914, 0.33226232254697435, 0.6932814407252497, 0.09087380923090443, 0.12568122857520658, 0.06025011861516584, 0.02263015492879335, 0.04046123249516372, 0.07970414770346496, 0.0802780318284227, 0.025808594354818908, 0.07393058734915911, 0.09214859485866563, 0.03379739753361191, 0.045353898988856424, 3.9942120592440333, 15.4824403409035, 19.994536907442157, 28.50465047744013, 37.768204289097945, 37.62264905437347, 44.67069325908538, 46.06298169782085, 46.39457887218845, 51.37037215694305, 55.473634196865945, 53.97192731980355, 56.271154034522276, 51.5781008812689, 46.49470129320699, 49.06184550254576, 54.90408251362463, 55.0017495309153, 55.344729423522956, 50.639869936050914, 45.808674827698745, 47.50155410458965, 46.95006493599185, 54.4236510030685, 58.57212228159751, 60.054805663324174, 59.63885791840092, 58.97320032119752, 61.2895913277903, 57.26664766188591, 56.269710602298865, 53.01963075514763, 58.31375575834706, 61.235717573473536, 64.10637086437595, 64.13564743534212, 61.502980032274806, 5.751212527675014, 0.3790785684700935, 2.581625109718692, 1.625361067633475, 1.4243334675988844, 26.28016060398471, 58.171577684340946, 63.558035281396684, 63.600675367539935, 46.89066456210229, 52.808124788345836, 8.555321828011545, 2.2049505864420245, 5.1154600612578855, 26.311108104644287, 27.193074610925493, 27.53127705666327, 27.886147614448305, 28.52015364554621, 27.286589799388764, 32.308782762096776, 30.651296992455762, 32.13486094628611, 34.587758279615834, 34.0670754063514, 38.74858110181747, 44.00723611154864, 37.66357898712158, 57.953988121401885, 68.98243396512925, 55.769325994676166, 0.3871855560329653, 0.0416843454924322, 0.007272410899355648, 0.04045409255570943, 0.01862749874201273, 0.17897372134029868, 0.14907303386397902, 0.22880260802565083, 0.21994542120204819, 0.15234772266159136, 0.13991212382191612, 0.13772152604595309, 0.29330509684739575, 0.4316016178457968, 0.5664297217322934, 12.052646317789632, 96.40573209331882, 77.03110617976036, 55.112540798802534, 47.60596367620653, 41.057605897226644, 53.74820316991499, 43.111331462860115, 54.968456452892674, 42.46873740226992, 53.9923942473627, 40.12358365520355, 49.763671275108095, 43.06158404196463, 44.99790522360033, 43.5574383120383, 24.770679589240785, 12.641546072498446, 10.822651828488997, 23.84681824714907, 55.933649770675174, 64.81034609579271, 65.46070252695392, 64.80452137608683, 70.2029343574278, 16.449296743639056, 6.817548573017121, 2.198585315096763, 9.172866652088782, 71.87353457173994, 69.16503598613124, 72.4363083993235, 69.4345655748921, 66.37699957816832, 57.91525079358009, 57.43178336851059, 54.56282061915244, 60.6284797576166, 67.12039855218703, 73.2692393948955, 68.10209720365464, 66.87743909897344, 65.68292833143666, 53.958720699433364, 53.627472616011104, 50.631064215014064, 53.694611826250636, 60.76749640126383, 61.12117259733139, 62.07514401405089, 62.8278233158973, 61.59806612999209, 56.046825839627175, 55.44605993455457, 54.212843218157374, 52.21843957901002, 53.746265519049864, 55.755762438620295, 51.058814371785815, 53.445929634955625, 43.54623994519634, 42.24313051469865, 28.477368431706584, 31.145749015192834, 26.93499049832744, 5.2393750894454225, 0.6398832737918824, 0.2554016710529404, 0.2295748859403595, 0.16947682045640486, 0.11413297405646694, 0.21091624763944458, 0.2048014870454227, 0.1417819912274999, 0.1354626391924197, 0.21045091051247813, 0.14125299219402576, 0.2234520507796157, 0.23558122977133722, 0.36685713717053015, 0.9014378872609908, 0.1786654628813267, 0.300369224240703, 0.1476626353518617, 0.12865383358251664, 0.13834380394508763, 0.25617376510654727, 0.1739627249058216, 0.17264372068307093, 0.08320263376639736, 0.17968330261928422, 0.1847564747496959, 0.304831379964467, 5.765907687525596, 18.36268186569214, 24.202606639554425, 35.57118669632943, 43.26964224538496, 44.28605779524773, 48.85343036343975, 51.422308260394686, 48.83350080059421, 54.03622673403833, 57.25479425922517, 56.88493436382663, 57.95460785588911, 54.58685298119822, 47.68021806593865, 51.23255183619838, 56.55139169385357, 58.15570385225358, 58.850994956108835, 52.68746483710505, 48.30793849883541, 49.699152208143666, 48.91188936848795, 57.26227421914378, 61.60797795941753, 62.499218909971184, 62.021285949214814, 60.59199779264389, 63.56571135982391, 61.43758235439178, 58.33408148058, 56.715040822182935, 60.37239605380643, 62.43998327562886, 68.0302393820978, 67.65801429748535, 67.45200357129498, 12.10897449524172, 0.442649923385151, 3.0604258948756806, 1.5306292089723772, 1.7067463263388605, 23.706387589054724, 68.09935938927435, 74.29883018616708, 67.21491198385915, 53.59867457420596, 56.29408813291981, 11.280161988350654, 4.266200238658536, 12.78287789513988, 33.78203676592919, 37.35257425615865, 35.999780162688225, 39.2437058110391, 35.531143219240256, 38.115800811398415, 43.38635236986222, 38.73706110062138, 55.37502581073392, 45.02572659523257, 43.1761250957366, 50.69425359849007, 51.32628471620622, 48.80488711018717, 71.06468692902597, 77.47199627660936, 72.92795396620228, 0.8953961501679114, 0.18073287371906543, 0.19761855473681805, 0.14117357951979484, 0.19766383053314304], [0.06280036402806159, 0.08487004711623154, 0.048795889897812764, 0.020216721327855222, 0.08437457975120315, 0.020275317477963625, 0.0799019209619972, 0.05593868686006435, 0.1024558405662256, 0.171096085180198, 2.892981383108324, 71.64761389455488, 58.03139217438237, 38.220610464772875, 39.37288907266433, 32.30141458972808, 38.43296758590206, 35.08791146739837, 44.066797302615264, 33.59332369219872, 33.04585887539771, 35.31041576016334, 34.11565788330571, 38.60783077055408, 41.45036066732099, 36.53653690891881, 11.47057835132845, 4.03468944853352, 4.439276293400796, 15.516598301549113, 46.609320794382405, 59.571644183128114, 57.50618288593908, 57.308601333249, 54.775891611652995, 29.668955072279903, 3.2791804017559176, 1.0172159585260576, 0.48430816060112375, 45.35695898917414, 59.638567663008175, 58.47536525418682, 62.48252138014763, 58.04759940793438, 53.38261081326393, 51.97306786814044, 53.091296380566014, 59.57530767686906, 64.3527663138605, 62.74906996757754, 62.088331022570216, 60.22672707034696, 59.845802168692316, 53.824956109446866, 46.275401576872795, 45.18529645858273, 47.32618101181523, 48.53126648933657, 52.82544989739695, 56.70282263909617, 57.249028375071866, 55.43210414148147, 50.86064838594007, 51.82567696417532, 46.1766480630444, 48.49936193035495, 46.02021217346192, 45.1708621363486, 39.25612011263448, 33.30816738067135, 25.831692487962787, 17.48837967072764, 8.166830183998231, 8.073549357152755, 7.874936711403632, 0.6755276288717025, 0.055606737132034, 0.05564289265162042, 0.02274205164623357, 0.07637173418075809, 0.07015961147243939, 0.029320891067806273, 0.07183844719322459, 0.015148115081472263, 0.021354430843324914, 0.06169047499556215, 0.04475811624058312, 0.045503002681559136, 0.041454894498230956, 0.06145430924070459, 0.29121410582334767, 0.01904053696160836, 0.023286328388137684, 0.0609032545358904, 0.04733926947078398, 0.06182474339561117, 0.0476843154718799, 0.016497460216464057, 0.07609757429529583, 0.08142056003693612, 0.08943444493437007, 0.08324211793801478, 0.008699337279634371, 0.9619749517690752, 9.900835021849602, 18.81177559975655, 24.916175988412675, 34.12838989688505, 34.44829448576897, 37.16910146897839, 39.261258417560214, 47.183775440339126, 47.13897412823093, 51.87994687787948, 52.81333761830484, 47.8843342873358, 45.86391748920564, 45.68396306806996, 49.51153347569127, 53.45989327276907, 51.7283433483493, 52.541152584937315, 50.114511597541075, 45.4314055750447, 44.39637053397394, 44.68840668278356, 54.43541811358545, 58.184007675417014, 59.27506200728878, 59.522685158637266, 59.714677333831794, 58.51592648413874, 55.257695951769435, 51.729814237163914, 49.661713184848914, 53.909730295981134, 59.43163125745712, 61.06434922064505, 67.20270556788292, 40.07965310927361, 0.11951959106109797, 0.11560672037904302, 1.230505255441512, 1.7797325647646383, 2.8679012579302636, 35.51356315612793, 60.68364397172005, 43.86697215418662, 41.64870708219467, 39.51363940392771, 47.45050053442679, 9.326724563875507, 2.1499761169956577, 4.37979894299661, 46.78368191565237, 47.276590485726636, 24.390350887852332, 33.95134979678739, 26.360961429534424, 30.59368129699461, 34.1722616072624, 26.428230077989642, 37.69872734623571, 31.278827190399173, 35.400273338440925, 42.996072615346606, 27.450733146359845, 40.31167699444679, 52.23025375796903, 64.72048851751512, 28.063609369339485, 0.3637964933389618, 0.12053242824490994, 0.05841891949756011, 0.101729819040385, 0.06813025222189965, 0.029682670344388293, 0.06696218264199073, 0.00433828505206733, 0.12336660882518177, 0.11790029569378785, 0.08321027932388168, 0.10229036557458102, 0.11558510137781983, 0.14355675647816352, 0.5210072042480592, 6.398260439595869, 81.92986411433067, 70.6422084377658, 42.13483779661117, 37.55290146796934, 40.917706720290646, 39.4591498374939, 37.03554476461103, 40.447489061663234, 30.89349550585593, 31.201680052664976, 31.537434939415228, 35.216553441939816, 37.07991461600027, 43.93275814671671, 37.04761389763125, 18.428662015545754, 5.349899145864672, 4.841012800893476, 17.61119104200794, 52.43875126684866, 66.83568154611896, 65.45918064732706, 60.36883454168997, 58.092942007126354, 34.80779540154242, 7.041499730079406, 2.893815867362484, 0.8561017844946155, 48.46675134474232, 66.10957237981981, 62.641126340435406, 65.46886497928251, 62.47684178813812, 57.067450092684844, 53.21920094951507, 56.06059335893201, 62.87636656914989, 68.2317001588883, 63.94906420861522, 63.8380572103685, 62.870165301907456, 62.02358838050597, 56.13393383641397, 50.21892509152813, 46.564127245256984, 50.65847766014838, 50.08993402604134, 54.79183996877363, 57.765577070174686, 60.83658895184917, 58.61425638198853, 53.20331142794702, 55.08515088788925, 51.20271436629757, 52.51001681050947, 51.02237947525517, 51.20819783979847, 46.4594352629877, 44.620090761492335, 35.17405456112277, 27.859828510592063, 18.57286991611604, 18.076835217014438, 10.282555184056683, 0.8982705120598117, 0.0968923491816367, 0.051261731573650916, 0.00908216673715581, 0.037781433953392896, 0.037892938050771915, 0.04856683726933214, 0.0696316619794215, 0.031148292304527377, 0.018124835896155527, 0.002213198566741701, 0.0716804338979625, 0.02558973069573122, 0.1440796421300019, 0.2647757067555382, 0.9684960147546184, 0.022631995455031435, 0.047791667372709325, 0.07995470441998014, 0.07700174956792787, 0.042138957388458714, 0.033881069656701825, 0.0307913355514287, 0.019428489632123423, 0.031558162750556104, 0.054377177504882704, 0.05149438864581528, 0.10463962782054179, 1.1391838976452429, 13.995966968997834, 28.09482555235586, 32.387955804024976, 43.53510041390696, 41.98223798505722, 44.82299889287641, 44.510825295602125, 49.60475644757671, 52.167578204985595, 54.40783600653372, 55.13223109706756, 49.310978766410585, 47.7978224908152, 45.00742089363837, 51.121764490681315, 54.87892835370956, 54.28891366527927, 53.715082676179954, 52.29071317180511, 47.0127091100139, 46.86461610178794, 47.72872994022985, 55.30714527253182, 58.86435847128592, 60.6279698494942, 60.03076153416788, 61.782707783483694, 61.10020360639019, 58.706585053474676, 52.96287405875422, 55.98785692645658, 57.60631315169796, 63.29268693923951, 62.602942066807906, 70.88285369257774, 35.64200116742042, 0.22905091244366863, 0.12479293430524489, 2.194278797795696, 2.107585101358352, 5.138843761336419, 41.320283105296475, 62.2327370028342, 44.380586916400546, 48.432603190022135, 44.83560931298041, 52.51138964006978, 15.473893496298022, 3.438616414223948, 2.666701318756227, 51.09542185260404, 49.6835764761894, 25.367081857496693, 30.593522441002634, 30.266677218098796, 29.99321153087001, 28.96389726669558, 29.72506065522471, 30.267024347859046, 34.028895055094075, 35.05920756247736, 41.83889496710993, 33.091632935308645, 39.64828652720298, 59.07480932051136, 69.92137093697825, 35.37677049636841, 0.5846195908323412, 0.16173288196084962, 0.10871626511817017, 0.07633266369661978, 0.06579186842446366, 0.2109868349807878, 0.17328455323173156, 0.11264252701714156, 0.2505648830124448, 0.26000898511659715, 0.2543421561319021, 0.2624455430815297, 0.33741604116174484, 0.37171716831864854, 0.9370057561224507, 12.021189889600201, 96.25410110719743, 79.63813304901123, 48.417686416256814, 55.164398454850726, 41.46147666438934, 52.28060522387105, 44.44636114182011, 58.87270135264243, 42.59200965204547, 45.84521955059421, 44.71135254829161, 47.37224532711891, 49.56509344039425, 56.3482835215907, 46.55459980810843, 14.898350392618488, 11.459906562682121, 11.091665625572206, 24.551426941348662, 57.3255616618741, 69.88891724617251, 70.07020135079661, 67.11149477189588, 66.00184056066698, 37.48661733442737, 7.500726907483994, 4.499642550945282, 2.8868595438618816, 61.18028663819837, 67.07470293967955, 66.7547316705027, 70.29049734915458, 66.59322415628742, 59.64900116766653, 57.134522622631444, 58.24276085822814, 66.16845500084662, 70.93153030641618, 66.45954193607454, 67.92652407000142, 65.29508829116821, 64.53198725177397, 59.27667017905944, 52.81236487050211, 51.66297704942765, 54.48586763874177, 52.30534361254785, 58.17499406876103, 61.89180066508632, 64.82921661869173, 60.553797829535704, 57.153875597061656, 59.507760540131606, 54.186171100985625, 56.07600435133904, 55.19702472994405, 55.10358602769914, 52.60326723898611, 49.85980464566139, 43.46327004894134, 37.87338656763877, 29.64757815484078, 28.444244015601377, 19.54908117171257, 1.7451866571941685, 0.23822913607282026, 0.1734384602957195, 0.13534803243894733, 0.16925730562258154, 0.16498746861132885, 0.1664189192196054, 0.18058126491885032, 0.09825410877144146, 0.1816794519583064, 0.18410583627560448, 0.2955196731753888, 0.12824701025120674, 0.24881991858203567, 0.2582615692048304, 0.5928909502202465, 0.10755708215818291, 0.14491202730324962, 0.20146312101954417, 0.18422295579746847, 0.15393023048677754, 0.12540371322463598, 0.11053865039420706, 0.18791436578237242, 0.24163985144226785, 0.15661641054095762, 0.2563117528634687, 0.15814575186419874, 1.4862988264329973, 16.082210944544887, 30.738334386579453, 38.14424191751788, 50.28451104317942, 47.398874298218765, 49.80190653954783, 47.246478449913766, 52.08826788010136, 54.77167506371775, 56.854131990863436, 60.69550914149131, 49.567101693922474, 48.68318380848054, 45.758256681503795, 53.0999138278346, 57.11293781957319, 56.37761892810945, 56.44147511451476, 55.94812723898119, 48.72605923683413, 48.678261233914284, 48.44768470333469, 60.14704804266653, 62.60533471261302, 62.988581657409675, 63.5706574686112, 63.99998049582205, 65.55051303678944, 60.11618291178058, 57.504755143196356, 56.82606743228052, 61.30593584429834, 65.6131415213308, 66.24950685808736, 69.79261521370181, 46.000223775063795, 0.42397398681890586, 0.44820329474826015, 4.028712982131589, 6.639259688315853, 4.576237124781455, 39.420785134838475, 68.63255854575866, 54.16040505132368, 56.40339674488191, 50.22738172161964, 57.76673809174569, 14.356751480410177, 5.804932819258783, 7.0211921488085105, 53.469001016309186, 54.63469020781979, 37.09099138936689, 41.647016540650405, 36.9084168249561, 38.478871084028675, 44.79865274121685, 34.99812841415405, 48.86044356130785, 44.737310794092, 44.08757409741802, 56.488355282814275, 37.7358918036184, 49.991000083185014, 74.02265610233431, 79.20746464883128, 50.74998655626851, 0.5551936633644566, 0.24131309962080372, 0.18543840025461492, 0.19878732911761732, 0.12849369056282506], [0.07343970885079715, 0.0709152193139157, 0.031160007704109437, 0.13266346116940822, 0.0844671921203694, 0.06947652151387546, 0.048259425337516496, 0.18328175549545597, 0.09831359549876183, 0.2740157690019377, 5.845580831650765, 72.08880993627733, 53.538172014297984, 39.328687883192494, 45.46443585426577, 52.30578291800715, 42.39429473876953, 36.29219678140456, 46.03906308451007, 36.94744440817064, 36.04751148531514, 33.10025038257722, 36.91113894985568, 41.45000373163531, 27.528682408794282, 35.14597431305916, 12.136088859650398, 1.8431643997469258, 1.9459789150184201, 10.556286611864644, 49.84529187602382, 58.29868208977484, 58.034322184901086, 40.148541696609996, 37.528272905657374, 37.42494983057822, 8.147143808103378, 1.219987910120718, 0.08472796078891524, 31.692698040316184, 64.15308237075806, 56.400301994815955, 62.32035883011357, 58.022766882373446, 56.343196207477206, 52.83692675252115, 58.423723328498106, 59.38406467437745, 64.78878874932566, 64.30201868857107, 62.93803015062886, 62.99973295580957, 62.15794132601831, 53.99247661713631, 48.14617603055893, 44.24270383773312, 45.47187659048265, 47.41605035720333, 52.259306753835375, 54.12729240232899, 58.98419472479052, 56.729730098478264, 54.132403250663515, 50.45340045805901, 47.69962203118109, 44.38623120707851, 47.96585682899722, 43.191645914508456, 40.6895895158091, 32.94716027475173, 25.8211491569396, 18.340977430343628, 8.492614896066728, 6.5349717101743146, 0.7847379364313618, 0.3485725796030414, 0.029170224555738034, 0.08667271328909744, 0.08930109200939056, 0.0731908222059569, 0.01227054711160881, 0.18702792544518748, 0.04257953455371242, 0.10675628279005328, 0.03314930247142911, 0.05321519449353219, 0.12076230824834878, 0.051436269385439735, 0.0631769958342756, 0.34043905475447256, 0.8257844984050721, 0.08546894401191704, 0.056519833498544274, 0.03435206051254946, 0.05365048948254797, 0.06826928185839808, 0.05645060213282705, 0.03713539200684717, 0.02600605734774182, 0.049084080683608214, 0.051824358036561366, 0.05262277870168609, 0.016974775128126625, 0.3929626250699643, 7.764465606981709, 22.170679646153605, 30.13363434422401, 36.70615196228027, 35.55401063734485, 37.87638325845042, 42.30809673186272, 45.607986757832194, 51.86366119692403, 51.154516281620154, 52.26384101375457, 50.20092925717754, 48.80023125679263, 49.65092274450487, 52.73259562830771, 54.86399196809339, 54.52204758121122, 50.286527141448, 51.87797000331264, 44.67810261634089, 45.84047740505588, 46.9851662266639, 54.47476733115412, 56.59306687693442, 59.34567643750099, 57.81998426683488, 59.702859232502604, 56.01343077998008, 56.99507451826527, 52.721095238962484, 54.43014252570368, 54.161107155584524, 60.81354894945699, 57.356854331108835, 66.28868349136846, 17.387755186327045, 0.1547784277147824, 0.11326921758271995, 2.8395800292491917, 1.8389621929776285, 14.988796326421923, 56.20651729645268, 55.90072539544875, 29.892200693007442, 28.414959599894864, 58.672993875318966, 51.98123032046903, 36.36264647206953, 2.4312777192361894, 1.5079697990609755, 32.73707224476722, 29.86427930093581, 23.374588412623254, 30.512853014853697, 28.101256278253373, 29.666025061761182, 35.06484793078515, 27.737587844171834, 32.981300584731564, 32.05757848678097, 38.260473512834125, 41.162093916246974, 34.27942076037007, 37.80869883875693, 51.70979838217459, 75.95148947931106, 16.668090474221014, 0.3866639114435642, 0.25232852466644784, 0.027487682884619124, 0.07158894767804493, 0.03529842424717161, 0.045385193680563284, 0.043066747321356694, 0.0827088900991986, 0.08682888031246201, 0.05916990782885302, 0.11370682232682744, 0.02395709390721975, 0.08312394121481527, 0.10842064710994882, 0.5088573255606237, 8.777005364817958, 84.88336963038292, 62.61405806387625, 42.33065428272371, 52.856922995659616, 47.53495308660692, 41.75550929961666, 36.52473841944049, 40.70982502352807, 34.584388963637814, 36.27498149871826, 33.32622989531487, 39.72495709696124, 33.76679835780975, 25.759589518270186, 27.336205820883475, 20.955352860112345, 8.525836390833701, 2.5257122132085987, 11.791504717642262, 53.083145695347945, 65.95736872765326, 63.527954624545195, 47.29414309224775, 42.00790597546486, 45.6671674789921, 10.339042217500749, 0.7169001152919185, 0.10585027656728223, 33.32494335789835, 68.5130282371275, 60.7983026965972, 65.15360055431243, 61.1298841814841, 60.92270458898237, 56.23928869924238, 61.68405625127978, 60.469357044466086, 67.3894182328255, 64.37319401771792, 66.00392726159865, 64.03687430966285, 64.97219093384282, 57.08970169867239, 50.32050271188059, 48.484143134086366, 50.189660287672474, 48.56604222328433, 54.93228435516358, 56.17076881470219, 60.17077838220904, 59.9064027878546, 57.32643242805236, 54.51762707002702, 50.8981187881962, 48.55605586882561, 50.982755691774436, 48.99728721187961, 48.80758570086572, 41.03334996008104, 35.76432812598444, 27.03021780137093, 17.94240970765391, 18.704300695850005, 5.785626422974372, 0.37503966100273595, 0.09740451726341441, 0.02873074098099624, 0.04789369113202538, 0.030667746417044155, 0.013961082910217587, 0.03553845491560717, 0.03585940745148448, 0.009443471996834683, 0.03918971423239958, 0.07085923360840929, 0.02377510205992768, 0.12605400695916147, 0.062367489876886534, 0.21208977176537439, 4.000398862746454, 0.19120471341715706, 0.09891433866634484, 0.02848304751809807, 0.04312803435529913, 0.043534501455724246, 0.09718700191907345, 0.05781353000671633, 0.06379697930007693, 0.03723912031179474, 0.06398640986111376, 0.06390556843290407, 0.09246129662759843, 0.28490515726227916, 9.055341655208219, 25.66661757807578, 34.60080016043879, 41.68752285741991, 40.03129420741912, 43.186468385881, 47.49250911897229, 49.852222704118304, 53.20578252115558, 55.58036581162484, 55.672843533177534, 52.33439268604402, 52.598019107695556, 51.96102226934126, 55.53399555144772, 56.6551854533534, 56.93092807646721, 51.73599197018532, 53.85998287508565, 45.144597945674775, 48.36378128297868, 47.14989400679066, 56.760273595010084, 59.16818526483352, 60.215540470615515, 61.382822144416075, 63.18586118759648, 58.65424102352512, 58.64100302419355, 55.333197655216345, 56.78356070672312, 57.24798894697621, 65.39610109021588, 60.9608417941678, 64.29413080215454, 16.130403145667046, 0.2043437495106651, 0.17511444616942637, 2.249436147751347, 3.457236395728204, 22.690570200643233, 62.547107127404985, 60.0501694217805, 35.848451199070105, 32.11559622518478, 62.207284742786044, 57.69399773690009, 42.76465669755013, 1.7904738529074578, 2.7779549360275273, 39.049944646896854, 29.337234343251875, 23.590120692406934, 29.290050191264, 30.991484157500732, 28.579257880487752, 34.51428836391818, 30.826099380370113, 28.622713819626842, 33.16859376045966, 35.78708571772422, 43.663969885918405, 37.581009172624164, 34.663864028069284, 61.6811615420926, 83.29611193749213, 19.511559778644195, 0.8501318145182826, 0.28160616815570866, 0.1583283719035887, 0.08162604013998663, 0.08467096384734878, 0.31347953203705053, 0.2906699995360067, 0.19300891176587154, 0.28560297143074775, 0.25920416378686506, 0.35019110888242727, 0.2104245417661244, 0.27769023312195656, 0.39632412695115615, 0.989963207994738, 14.089106590517106, 97.81720484456709, 71.34794481338994, 51.626600988449596, 63.01677565420828, 62.98060355647918, 55.63190575568907, 45.99434806454567, 59.96110808464789, 45.4297189558706, 47.814767129959606, 43.480289213119015, 53.17124212941816, 53.22624160397438, 36.409844352353005, 46.4720025370198, 17.154958594229914, 6.278212378101965, 8.518150506481048, 20.158333124652987, 61.917378440979995, 70.527785055099, 69.19912922766902, 51.21587391822569, 50.03207906599968, 47.27415469384963, 11.414017773443653, 2.1426385881439334, 0.23848335468961349, 41.68372992546328, 74.65038437997141, 65.57633399963379, 72.09441892562374, 64.40290597177321, 64.18568903400053, 58.13780999952748, 63.23510262273974, 65.24063010369578, 73.10824963354295, 68.37354090905959, 68.54382668772053, 67.87113235842797, 71.43105199260097, 59.335184097290046, 53.0592780728494, 52.7681323020689, 54.839912537605535, 52.299295317742136, 58.88468419351886, 58.96717163824267, 66.11571481150966, 63.825489936336396, 61.62773493797549, 57.42917106997583, 53.55786623493318, 51.7662295218437, 54.87112283706666, 51.0706050165238, 51.6687939243932, 48.171796952524495, 43.837934847800966, 36.57280314353205, 29.793076515197757, 30.286024308973747, 13.70263937980898, 0.7268885535097892, 0.22948281749361948, 0.22534842482737957, 0.27437524809952707, 0.09370127122008032, 0.11436860738021713, 0.24104925893968154, 0.1372871235493691, 0.21229978710893663, 0.11512625301557203, 0.22128662665284451, 0.213908709645752, 0.18549090792094508, 0.2504448217129515, 0.8097049257447644, 2.6103974109695804, 0.13828300720741674, 0.19414373312986669, 0.12402843218296768, 0.16140095138501737, 0.3008673958961041, 0.2365424556116904, 0.12815680339812272, 0.1287798397243023, 0.21563516539191047, 0.15484129288984885, 0.13609726642889364, 0.2623714164139763, 0.6778868119562826, 12.33547862498991, 28.81955796672452, 41.44393190260857, 48.74984056718888, 45.09098306778939, 48.62803920622795, 50.71578741073609, 51.64144323718164, 57.997542119795284, 58.99552252984817, 58.56803909424813, 52.66460134137062, 53.02214891679826, 53.399916310464185, 58.58946700249949, 59.48821144719278, 59.77921209027691, 53.52920939845424, 56.52995201849169, 48.62943949237947, 52.75280367943549, 51.144784881222634, 58.436153319574174, 61.68857089934811, 61.309383607679806, 63.452468610578975, 65.78634554339995, 60.03527225986604, 61.0133780202558, 57.75027982650265, 58.950831044104795, 59.21373574964462, 69.48826282255112, 62.74919548342305, 72.28498335807555, 22.434680654156594, 0.808151912304663, 0.31878582472282074, 7.807063527645604, 5.174062723113645, 17.943551117374053, 65.24744718305527, 62.882257969148704, 37.399128867733864, 35.81555035806472, 67.35542697291221, 62.077418988750836, 44.822155583289366, 5.990250591308841, 3.3282401821305676, 39.1250737251774, 37.061283357681766, 31.720905765410397, 37.50913958395682, 38.92062017994542, 36.73144732752154, 47.96851227360387, 36.480831407731586, 44.28563810163929, 45.05244970321656, 48.96829697393602, 55.12733990146268, 43.532021353321696, 48.51027004180416, 70.73667480099586, 92.14728539989841, 28.93249869346619, 0.9951262728821848, 0.36823391974453007, 0.2506967880312474, 0.32411975786089897, 0.18647143917699016], [0.061894036048362334, 0.10229659386940541, 0.021613678827341047, 0.058982771701149406, 0.03685772343869171, 0.05260434279578829, 0.06238258563943448, 0.07189356721937656, 0.18242012108525923, 0.23759991741709172, 3.6156937768382416, 66.23874387433453, 58.78988050645398, 45.620659935858946, 41.86915997535952, 104.24238451065557, 54.769219659989886, 41.5157034320216, 41.47596982217605, 39.082974926117934, 34.417350907479566, 31.447763673720825, 28.998096412228, 49.18631407522386, 59.98914910900978, 51.37271773430609, 30.428541667999763, 4.004842417855417, 1.1933167735415122, 3.270709307924394, 35.622267723083496, 53.46567092403289, 57.64712149097074, 64.16878754092802, 67.75064499147477, 46.308808403630415, 9.970072700131325, 5.984349875680863, 0.07078228773729456, 13.718709330404959, 62.63969075295233, 53.85619386549919, 66.69048324708017, 56.3833926570031, 60.391576443949056, 55.78315627190375, 60.258545337184785, 60.26178521494712, 65.92920610981604, 62.142781365302305, 62.66668058210804, 62.41652357962824, 60.49318936563308, 51.59876392733667, 48.461789546474336, 44.90636887088899, 47.266082456035, 46.70747810794462, 50.670852738042036, 54.4563518031951, 56.734185910994015, 57.97061504856233, 55.01663884808941, 51.914903040855165, 48.06328850407755, 45.91210772914272, 49.402240553209865, 44.560529570425714, 42.6126060178203, 33.70423263119113, 27.44609494363108, 16.50800678037828, 9.07518982887268, 7.444859118230882, 1.2832464253710163, 0.10125365709104847, 0.03774484942456888, 0.03870425580610191, 0.010069196334018583, 0.02628271084939761, 0.05081485716565963, 0.04174556357846145, 0.1265433609425541, 0.12320912413058743, 0.059563903017870845, 0.06038198149913262, 0.08472987600872595, 0.08242418884389824, 0.02999870842623134, 0.1431879617514149, 4.381065868562268, 0.37685976333675847, 0.04204084450799612, 0.03976611495618859, 0.0680629130933554, 0.04031018293913334, 0.03594464239393992, 0.013279884231216727, 0.03613828260812067, 0.09541025250068597, 0.024279569042846564, 0.029348271050220056, 0.05773267325674815, 0.0682365162778766, 2.6310592312966627, 19.753197393109723, 27.210358535089803, 28.272434396128503, 33.64862911162838, 36.285885687797304, 42.3990878751201, 46.78743954627745, 48.8315043141765, 48.98920320695447, 51.551032604709754, 55.849467862036924, 52.27616902320616, 51.2778591340588, 53.10669168349236, 55.516490013368674, 53.30355936481107, 51.249394493718306, 50.017134835643155, 44.901403150250836, 43.80733251571656, 47.75331143409976, 54.60429183898434, 59.46350051510719, 57.982852843499955, 56.853135708839666, 58.64736903098322, 59.44483395545714, 57.90305614471436, 54.34774529549384, 56.17545996942828, 53.424642932030466, 57.76873065579323, 60.31415277911771, 51.63765422759518, 9.603628208560329, 0.028596286804625587, 0.15246775331756762, 1.324062486810069, 8.788868573404129, 29.430659317201187, 55.59288601721487, 53.67447045541579, 52.54977787694624, 59.971596502488666, 50.399048174581225, 59.11696303275324, 27.392911526464648, 0.36795837323992486, 5.3212952613830575, 23.961867247858358, 23.20200804741152, 28.643880890261745, 28.524376077036706, 32.77274031792918, 29.112260918463434, 32.76235780408306, 32.4097288808515, 31.431536828317952, 30.769570181446692, 41.748974630909586, 37.92587180291453, 32.580720686143444, 53.192022846591094, 58.98439868803948, 71.81933526069888, 5.1195157920160606, 0.17841243936169535, 0.06107843969197524, 0.06622522138059139, 0.03241587287536071, 0.07641209935348842, 0.08055569273569892, 0.030333640151506955, 0.1050513387928086, 0.042724229410410895, 0.017887911714252927, 0.027011032554230867, 0.05337045753314611, 0.10666622915455412, 0.05018858028756035, 0.33794359994992135, 5.414016169886436, 80.48652602780251, 64.36147005327287, 53.964945500896825, 51.24239306296072, 75.27877946053782, 47.40847626040059, 38.33085652320616, 38.948057159300774, 34.55125278042209, 32.84582976372012, 31.098506027652373, 34.20902598288752, 45.47039785692769, 46.35027177872197, 40.44674773370066, 28.255026917303766, 9.097827788322203, 3.17017283170454, 4.347906151125509, 36.94245515331146, 59.86511984179097, 65.58917191720778, 67.46982682135798, 72.71099982723113, 51.65072748737951, 12.072020865255787, 5.827583036115093, 0.012849272912248008, 12.624013077828193, 64.52810410530337, 60.284036820934666, 68.56520360515964, 62.03470437757431, 63.79902570478378, 58.91613375756049, 64.03745482044836, 62.46974229812623, 68.50728588719522, 62.0026429237858, 66.55184315096948, 63.56563683479064, 63.17844006323046, 54.01998812152494, 51.45788808022776, 49.19984232994818, 50.43560858695738, 49.13505654181204, 55.16889741343837, 56.5727960678839, 60.528549532736506, 60.105188508187574, 57.48879109659503, 54.08477390966108, 52.731340469852576, 50.810128258120635, 54.53827442661409, 50.78147142164169, 48.68246601473901, 42.86206483840943, 39.08856430361348, 26.350182756300896, 22.3879946431806, 16.704792091923377, 4.829285404374523, 0.1340981906340007, 0.06515480502839051, 0.029125228381505417, 0.027710103106895284, 0.08123348136582682, 0.021038182087302692, 0.06739493038865828, 0.03569493986546032, 0.08078526630396805, 0.0254668808361936, 0.058865694314121246, 0.036176609986972426, 0.13086002890861806, 0.07044137095011051, 0.11868337544822886, 4.711160284857597, 3.233031510345398, 0.10053017131623723, 0.1258563026485424, 0.030996013177378528, 0.02743416972788832, 0.008667010284449545, 0.05361940929545991, 0.05315240592725816, 0.10232778896968212, 0.05749823503015984, 0.0289569552537174, 0.047938710288895715, 0.037229643804171396, 2.848969202849173, 22.43846574137288, 30.35128862627091, 31.050051027728667, 38.97214443452897, 43.6364701486403, 47.265290137260195, 49.98055481141614, 51.89600113899478, 52.31714994676652, 54.22151165623819, 56.754264523906095, 52.861202301517615, 53.34821162685272, 55.8748612865325, 55.008476395760816, 55.058984756469734, 53.6916700486214, 53.91882627241073, 47.48750417463241, 46.17877791004796, 47.475321292877204, 56.92877469524261, 59.9744676774548, 58.48848166004304, 58.95636943078811, 61.434593508320475, 62.8303453999181, 60.09182891538067, 57.80513417336249, 60.03530363882742, 56.4847388575154, 61.10230207443238, 63.69330606152935, 51.8360790898723, 10.350025834575778, 0.26697450167229103, 0.11678919241192842, 1.262907465138743, 13.116257786750795, 36.831620739352324, 59.172613620758064, 61.43640564334009, 57.593020239183986, 61.84631293819797, 57.30523986201133, 63.4517704286883, 23.669844827344342, 0.504588561072465, 13.324466020830217, 26.793294875852524, 23.50864718037267, 29.972085645121915, 26.68820281182566, 33.115186768193404, 26.9259141337487, 31.656986821082334, 33.392412047232355, 29.4924033072687, 33.587094968365086, 38.87211222802439, 37.90753864472912, 36.815448807131865, 49.721450882573286, 68.68014474068919, 77.9018331343128, 5.810119663515399, 0.26458899580663253, 0.10010298536789995, 0.10656772556925014, 0.06855938403356461, 0.0657459337925238, 0.17152792894311492, 0.1329223222790226, 0.17355320494501822, 0.2010697808357016, 0.21579700912679398, 0.2523114868710118, 0.19698913689822922, 0.20455667598833963, 0.39326032683733975, 0.703827100655725, 8.83686955898039, 97.73898493859076, 77.3874064414732, 62.30763466127458, 54.65377646107828, 129.2428110491845, 65.44302048221712, 52.580713610495295, 52.952930850367395, 48.05845222165508, 44.300990258493734, 41.34970480395902, 39.32679730076944, 67.12562314925655, 71.8220103171564, 64.67678939142536, 37.32655717480568, 8.465733912683303, 5.70734424937156, 9.508026319165385, 46.25902960377355, 65.07039923821726, 70.26341730548491, 74.92240075142153, 80.14410311175932, 56.938251141578924, 15.904858035425987, 10.395969536996658, 0.14841721663551946, 18.73865673618932, 72.71260015426144, 62.276134106420706, 72.10297753733974, 61.72852023955315, 66.82844085078086, 62.770705761448035, 65.91612892766153, 64.59283890262728, 71.78394763700425, 63.906855583190925, 69.78736708241125, 67.03767576525289, 68.72581681897564, 57.469528336678785, 55.917622966151086, 52.49799866830149, 54.340226111873505, 52.287634111219845, 59.32481335055444, 58.78713876970353, 62.91030683825093, 64.43292387070196, 62.13545045545025, 55.52367971789453, 56.484864373360914, 53.64562534516858, 59.07941810546383, 52.683899402618415, 56.89260259751351, 49.443907891550374, 46.555231309706166, 34.19581151777698, 31.015373353035223, 25.686394168484597, 9.414297361527721, 0.2732979752604039, 0.19855261509937627, 0.11635381698368058, 0.18079066739207317, 0.1978154699768751, 0.20825481222521877, 0.16183569096028805, 0.24565594481124034, 0.14079229755988046, 0.19467100080463196, 0.17005035984179667, 0.14472854924538445, 0.3067910635182935, 0.11840016040350161, 0.2415568534765513, 7.351593490569823, 1.0308243766907723, 0.14182031094547243, 0.22169594743078758, 0.18130587684291025, 0.08638202122622922, 0.12778503625022788, 0.15397195163513386, 0.17042410349653614, 0.21040871438960876, 0.11236791513980397, 0.11649736653893225, 0.19112733853680475, 0.08401446480063662, 4.436320787475956, 27.516848617984405, 36.436214447021484, 38.259904769159135, 49.06593653463548, 49.05888019069549, 50.795329155460486, 55.19806808040988, 57.22577264232021, 55.50957487475488, 54.476434338477354, 59.20208631023284, 55.175118292531664, 55.43011157743393, 59.294434593569854, 59.48342223321239, 57.804196726891306, 57.227298444317235, 58.30041185502083, 50.28325980709445, 48.290527097640506, 50.789249481693396, 60.470000313174346, 62.69168176958638, 61.28908534203807, 62.386670420246745, 63.79167126071069, 65.64256321999335, 63.861203116755334, 61.93242073059083, 62.68534714175809, 60.1770188731532, 63.29118859383368, 64.18917602108371, 56.422247655930065, 13.901228981633341, 0.414555364799115, 0.6012886834721411, 4.734581737749038, 12.213719429508334, 36.356711925998816, 65.19067087481099, 64.8613251409223, 59.948936970003196, 70.16557770390665, 59.435204536684104, 69.5321306105583, 35.86518010785503, 2.538069150140209, 10.146766651061274, 31.1954140663147, 29.623951758107832, 39.97312545776367, 35.76128436673072, 46.44739750892886, 36.30977684451688, 43.425105387164706, 42.31680047127509, 44.03890140594975, 42.86528118195073, 53.25607122913484, 50.02840380514822, 44.26239413599814, 68.22661676714498, 75.77146053314209, 90.3342874588505, 9.63724978508488, 0.6855156380803354, 0.24244248176053648, 0.24402154219006342, 0.1668410796311594, 0.2517490251170051], [0.02312029606752819, 0.035452572628855705, 0.028674625040542696, 0.08319996011954162, 0.030654236456499468, 0.03236357205277009, 0.025843110446247364, 0.005709563763136225, 0.10729491920961488, 0.10303942336430473, 0.3700946860255734, 54.4252238735076, 68.11298570325299, 35.18999507350307, 62.57088453538957, 129.9865395022977, 42.99363682346959, 46.76210495733446, 39.54653632256293, 41.422813861600815, 37.476038702072636, 33.89573451011412, 33.701031977130526, 30.716324006357503, 90.67896966011294, 89.75083489571848, 57.61774293838009, 9.564775170818452, 2.3609844330818426, 4.2339818900631325, 29.98535110104469, 58.526218783470895, 59.98079053817257, 57.65134196127615, 54.70765021539504, 43.033299830652055, 21.451691542902303, 1.9756084993000955, 0.2362092226863869, 4.882821344560193, 43.90404639705535, 60.35616136366322, 61.475778395129794, 63.46442791723437, 63.8705030564339, 62.10210638661539, 61.061752611590975, 61.37799370673395, 64.83907745730492, 61.18698212408251, 64.90395345995503, 60.765017463314926, 59.88069949611541, 52.64977085974909, 49.18554921304026, 48.87481904798939, 48.15841774786673, 45.835884309584095, 53.03733241173529, 53.97082513378513, 55.10577471025529, 55.94755065056586, 56.47547421916839, 51.099430514920144, 48.67208350089289, 45.98209850249752, 48.7398777469512, 46.575003977744814, 41.163925663117446, 40.017612980258086, 28.851744936358546, 16.74987581468398, 14.42224721754751, 8.65025201151448, 1.124256459936019, 0.04750051948752615, 0.031612461147409295, 0.01912207744504896, 0.08182600440998232, 0.11253761893679058, 0.07642174440045511, 0.032799606316632805, 0.08274778438311431, 0.09797918279805491, 0.04074049069576206, 0.05112289345913357, 0.09516009414989142, 0.026339108327163324, 0.02525739792373873, 0.06990755322359263, 6.27346238782329, 3.602187340298007, 0.09459975445943494, 0.08038867790732654, 0.029221291976770567, 0.05667619970476916, 0.025701730835041212, 0.1155530252764302, 0.02478872639908185, 0.030244494330198057, 0.07292498969623158, 0.04691139404331485, 0.03624591030060284, 0.08546420958854499, 0.27535823083692984, 10.33538656850015, 26.234794470571703, 20.761226915544082, 24.634120310506514, 31.97064503546684, 39.84721345286216, 44.76618336093041, 48.02310382166217, 50.69288861367011, 51.575241473413286, 53.80788595445695, 54.013320092232, 50.24197293866066, 51.10478062783518, 50.47426746737573, 50.774940675304784, 49.02817979935677, 46.819387251330966, 45.92581249052479, 45.769937499876946, 49.39232872378442, 55.879650500512895, 61.31242736693352, 58.14568611883349, 55.805129389609064, 62.45492358361522, 59.904939743780325, 60.214579489923295, 58.70750681046517, 55.533799432939105, 58.93635749816895, 58.04308475986604, 60.63830921726843, 41.08714918936453, 6.8054161917778755, 0.4107174788030886, 0.156992391172436, 1.6054013515672378, 26.860108529367757, 51.431937679167724, 51.74515854927802, 58.46942286337576, 58.06199842883695, 64.72550915133569, 55.29487217626264, 56.48488398521178, 10.76522832916629, 0.05989577996754839, 12.645046787877238, 36.01870167639948, 37.20605804074196, 22.38070687940044, 31.363791611886796, 31.248509230152255, 32.78486632531689, 33.818506963791386, 33.34732047973141, 30.535824375767863, 28.739531809283843, 33.821570334895966, 42.085431621920684, 29.761234714138894, 44.62557031262306, 61.057618433429354, 49.71937594875213, 0.6017139542006678, 0.13742069863984663, 0.06777854125586248, 0.07243726748011767, 0.034545949705305605, 0.0628391663814264, 0.10962438574361225, 0.03054501913157442, 0.07044463448466794, 0.1422100045507954, 0.027206842712457144, 0.03185076045713598, 0.03650418918339476, 0.02272334186390283, 0.0812670513386688, 0.15065822299690018, 0.8578586998966433, 63.194015795184725, 79.50831044104793, 36.038301760150546, 65.20861179597917, 138.84663243447582, 38.8262910996714, 43.91757857414984, 39.324137933792606, 37.77018116366479, 34.6629265815981, 36.02593060462706, 33.29482347734513, 36.67292164218041, 73.02235757150959, 75.91302671740132, 53.664503712807935, 12.593678447508044, 3.4384680996018075, 7.138721068059245, 33.98441929971018, 60.935499360484464, 66.6592925594699, 63.24699917147237, 58.48132725684874, 50.67680689596361, 27.132075871190718, 3.118186472885071, 0.40914902103043377, 4.024242951023964, 43.900712382408884, 64.96056895102224, 66.28969546287291, 64.75172235119727, 66.05436894201463, 64.84688297394784, 63.74088833408972, 64.90510271441552, 67.35186546079575, 63.656243585771136, 65.65944902358517, 61.479606628417976, 64.87986618472685, 55.57574525956185, 50.45398489121468, 51.47750385345952, 52.56267463007281, 49.473980703661525, 56.4627069042575, 55.51396792934787, 56.4747211240953, 60.444508829424464, 59.586831600435325, 55.23244373260006, 51.23042198919481, 49.739281977376635, 53.51941916250414, 53.10407154021725, 47.241987336066465, 49.478848365045366, 33.06541973544706, 25.946521835942423, 28.303864348319273, 11.168853948193213, 1.4690873435428067, 0.07244224705162548, 0.04152178929577913, 0.06788251470894584, 0.03380807679927638, 0.02501504217845298, 0.053237131421243956, 0.030251519356463707, 0.023775067585971088, 0.054092625636727586, 0.02627394488832403, 0.08784727163372502, 0.09527041847186704, 0.026351614712527203, 0.01252705058563621, 0.16940545170537888, 1.3032817696371388, 9.944123279663826, 0.8206776950147845, 0.01078332913288426, 0.09723437679631096, 0.13785989684683664, 0.0444580817354783, 0.09779278594519823, 0.07926132590059312, 0.05469316196057105, 0.02862820585799073, 0.04976458892586732, 0.035959362773404974, 0.011151335746680778, 0.7211587061324428, 8.612882610290281, 27.038284155630297, 31.213390288814423, 31.475671337496852, 40.771421924714126, 45.725971652615456, 50.88793631522886, 50.60392141342164, 56.28740833651636, 53.62100462759695, 56.18932947035759, 55.610654354095466, 53.43963815319923, 52.655470063609464, 54.75234562350858, 52.92300316595262, 51.43163173429428, 48.21038523027974, 48.085489119252856, 46.58768892288209, 50.69824657132549, 57.59584826807822, 60.694348119920306, 58.783012436282256, 58.29870562399588, 64.31231883264357, 61.543894275542236, 61.98697697731757, 61.56774620856009, 56.92460521574944, 62.585224720739554, 62.492817601849964, 58.946143811748875, 38.82273743229528, 6.8384082278897695, 1.1015604003783197, 0.30747505746060805, 3.5534933209419255, 35.76110001533262, 53.47377061843873, 57.162630327286266, 64.94319677352905, 61.86235935457292, 70.00631378542992, 60.67433618730115, 60.80585718154908, 11.383642938829238, 0.8755940643529739, 17.00396107089135, 34.758530432178134, 40.03700910076019, 24.0487418636199, 28.22866466737563, 31.36489772027539, 30.95118768753544, 33.72351892532841, 32.659940796513716, 29.39246327646317, 33.22340888361777, 32.35515106108881, 40.652636866415705, 35.663401619080574, 48.7225212589387, 67.32634652045466, 57.9263432564274, 1.0918536373684484, 0.06338055688707579, 0.07277840643279976, 0.06798920777416037, 0.09449653177251739, 0.014232674485913688, 0.1949846372008324, 0.10206757954532102, 0.09624184860337166, 0.27581573854531016, 0.1510967623682753, 0.21255293320263588, 0.14983259471914462, 0.15776362720756762, 0.2287535783984969, 0.47987842571831524, 2.0404251761013463, 82.58267987158992, 89.73529446509578, 47.425436589025686, 77.27994918823242, 149.77888999446748, 53.38227741179928, 59.964093008349025, 50.44419073289441, 52.50869104939123, 49.26813079464821, 47.8552185335467, 43.26216620783652, 43.613179114557084, 99.01981138413953, 97.64273781930247, 70.75253686597271, 12.708898071319828, 7.304954548035899, 9.39971104744942, 40.242592288601784, 68.69659516119188, 73.17649102980091, 68.33801208003875, 66.56968993525352, 54.69850717052337, 27.444751531847064, 4.293293030031266, 0.5743192628987375, 8.951109570841636, 55.682131705745576, 69.99089887065273, 70.99819490986486, 67.49402784532117, 68.93873876140964, 68.63918735134986, 65.29453523697393, 68.34216194768106, 70.68811585826259, 64.36537281159433, 68.90688127087009, 65.75887326271304, 67.51066653959214, 58.530247057637865, 56.07314494348342, 55.23815078120078, 55.05367778962659, 51.711159444624386, 60.454605010248, 60.85629886196506, 61.91825705189859, 64.01410887318274, 62.2925413808515, 61.32046430341659, 54.72530480354063, 51.053397578577844, 55.06828469614829, 57.83814876310287, 51.69913345767606, 56.92029060855989, 45.85796333128407, 33.28111871596306, 32.71433230369322, 20.516841680772846, 3.452556762964495, 0.22784087656726762, 0.18847292048796532, 0.16289807105016324, 0.24110516803639553, 0.17572933898097085, 0.2556971664870939, 0.15325561346065614, 0.14665896824050337, 0.21829260182717156, 0.12329796734716623, 0.21198484836326492, 0.3142525453961665, 0.16577272405547483, 0.178982439420877, 0.22234906802975365, 9.644460082054138, 7.860956403516955, 0.32646260795093357, 0.17908544760317574, 0.168891605891047, 0.24279514267559976, 0.11916097764286304, 0.1339305093091342, 0.15483821321639324, 0.17463557992971715, 0.14090391657044812, 0.1126170852371762, 0.177559431101526, 0.1737582866823481, 1.2600121430812345, 17.294047801725327, 36.744528432046216, 34.441171461536044, 38.34910338924777, 49.90826552914035, 49.31640732672907, 52.08927200686548, 51.842841256049375, 56.69158504855249, 55.95039436894079, 59.66601640947404, 61.461959885012725, 56.07611025533369, 55.67205121440273, 55.86694202115459, 55.057647228240974, 55.12741834886613, 50.344531151556204, 49.760388251273866, 51.215485603578635, 54.47308855672037, 60.392058895480254, 63.716648086424804, 58.924802195641306, 61.033672363527366, 67.91411369077622, 63.59546253758093, 65.97779643151068, 63.420826850398896, 61.83029397841423, 66.60739175734982, 66.499204943257, 66.64070052485313, 44.8424538489311, 9.68213640874432, 2.247425687889899, 0.566000038337323, 2.0910103907508235, 31.65881072321246, 60.062324846944506, 59.296556595833074, 70.00458009781377, 65.68885895513719, 77.69954081504576, 64.4972546638981, 68.7952898394677, 16.445528326496003, 1.8093353053254468, 16.906023410058793, 42.48498778189383, 46.69748390874555, 31.861408987352927, 39.944998141258, 46.19241991350728, 40.68894232473066, 47.3883270448254, 41.35644343591506, 43.91551148506903, 37.265505483073575, 42.62691482420891, 54.18397065131895, 38.22465050605036, 60.09463733242404, 76.24832660921159, 71.88190490968766, 2.0581715722237868, 0.22425299570445092, 0.24411308969701492, 0.2249159222288478, 0.3582901291308865, 0.2699134294544497], [0.09424028302272482, 0.11971069169380974, 0.04054481268770272, 0.09101680720285063, 0.09138722603599872, 0.05057909743740194, 0.01384465095226563, 0.025770079284425707, 0.22117327628356798, 0.11030598183072383, 0.26436744317893063, 48.04135461007395, 64.50553870970204, 36.56429944499847, 44.27924856062859, 42.6328101465779, 32.20946638814865, 43.6699358109505, 43.84038632915866, 35.63246980790169, 34.57492820678219, 31.141834489760864, 43.67775701707409, 24.121601850755756, 60.245370095775975, 64.18846607208252, 35.400626351756436, 14.670141993030427, 0.7495822228731648, 11.17221934180106, 38.97157569085398, 64.0692573978055, 60.177673908971975, 63.282908470399924, 63.114787840074115, 61.82829749199652, 34.866870218707675, 9.273145967914212, 0.5333099634416643, 0.8787124712140331, 26.69055623392905, 58.141253840538766, 64.02456591206213, 65.57321963771697, 65.25613915535712, 65.83254321928948, 64.85495128939229, 68.06030042709844, 67.53121975929507, 62.67957341286444, 64.51773728093794, 59.87137994458599, 58.092639984623084, 52.10776205985777, 50.60778494804136, 51.29015968691919, 51.715940813864435, 48.40362471918906, 50.83094427662512, 52.947470911087535, 55.93321830995622, 56.620711741908906, 53.278385593045144, 51.05027144955051, 48.32498904197447, 50.677308959345666, 48.99188218578216, 47.951246000105336, 40.843165997535955, 37.16640287829984, 20.37240824391765, 22.75265935928591, 22.1408559045484, 5.220100562418661, 0.31327480270016583, 0.03802861605260161, 0.07406721146957529, 0.02613792980780765, 0.058527240499613754, 0.028778464428239295, 0.047503783022083586, 0.05388125814797898, 0.045318739383571574, 0.005037808075412027, 0.05054229074307988, 0.051761918040292884, 0.021531017940311183, 0.037824480433858214, 0.1833088750079755, 0.08524841794203367, 2.243936004177217, 13.40174553855773, 0.6983780091808689, 0.21665455262747504, 0.06015985047504787, 0.03514764665235435, 0.018234112592894706, 0.06690253503620625, 0.038430164868552844, 0.061625169830456863, 0.014704806812768503, 0.08237737321084546, 0.0048322034830738225, 0.018739498881322723, 0.19536103151978987, 2.4636811546740995, 17.348133364031394, 26.67480987887229, 23.477181926850353, 28.040437967546527, 35.533771207255704, 45.78595253729051, 47.467939392212905, 49.73609701279671, 50.693586795560776, 50.94047646368704, 49.81381093302081, 52.874754090462964, 50.49134938947616, 50.66229412632604, 50.221015714829974, 48.58540304245488, 47.11509866099204, 44.801155213386785, 44.65697280822262, 48.47037953715171, 53.76219426431964, 59.38978349008868, 60.31028924449798, 55.517953057442945, 60.8010365886073, 61.063109751670595, 58.289354693505075, 60.08756529900336, 62.46907157282676, 56.45947879360568, 57.907598249373905, 52.49251911717077, 27.146596485568633, 1.9212732536177484, 0.20182430083232544, 1.647225094418372, 21.27364927722562, 46.865314283678615, 55.37731255254438, 55.84130540970833, 54.63231717386554, 54.393189876310295, 52.49721027189686, 52.41547984461631, 53.23941292301301, 6.148992344256371, 0.5548022230786662, 10.12030634187883, 47.16859979014243, 23.922912228492, 22.696169384064216, 31.927498963571367, 32.007238787989465, 32.15026997750805, 34.523733431293124, 36.662664644179806, 32.16445326805115, 26.830016105405747, 38.62650125257431, 39.021452549965154, 27.941553054317353, 40.49381617576846, 65.6986491910873, 38.942295197517645, 0.24893181338425607, 0.03692758299650685, 0.027757633116937457, 0.10225190796078214, 0.04831806170724092, 0.044234640701043035, 0.07676623881824556, 0.06557107422380679, 0.011058808604796088, 0.08538209262394136, 0.018998105266702273, 0.008652768709937171, 0.03113382473407734, 0.04785305782852154, 0.12626565407000243, 0.10346849388893574, 0.08211523324491517, 56.605610616745494, 78.53533514084356, 36.30243808992448, 51.97990848172096, 58.76282791937552, 34.115151897553474, 37.22950596963206, 43.078191357274214, 33.02428583944998, 33.714815185916045, 34.070166234047186, 40.45981707111482, 32.07657648671058, 54.78657222563221, 65.41396748635077, 40.72016046893212, 21.361684914558165, 2.003882536965032, 11.667783356481984, 44.719805256012954, 68.82680216143208, 66.48237797521776, 68.15689271496188, 70.26333885808145, 66.416348795737, 43.034994294566495, 11.923843526071119, 0.8292614957017284, 0.8972106753818451, 27.206740148605842, 59.328735720726755, 66.88551918152841, 68.46768563793552, 68.37554916258782, 66.99993471945486, 68.24349864836663, 70.1897708831295, 69.23104163139098, 66.00325261392902, 63.85558628266858, 63.75171407576531, 59.853184069356615, 53.13992592596239, 52.41353434901084, 53.47961887236565, 52.83724838687528, 53.06882119947865, 53.5772466659546, 56.49626278108167, 55.98887282033121, 57.77159398601901, 55.68690523024529, 53.28432406148603, 51.244299334864465, 54.01947036866219, 54.22872097261491, 51.86392791809575, 49.135746878962365, 42.6525749698762, 28.55924398668351, 40.268989839861476, 30.01695755989321, 7.206399113901201, 0.10747592280348463, 0.0317516842211086, 0.05551527006431453, 0.023335425047985008, 0.0878251470144718, 0.03331781117125385, 0.05376271753301544, 0.03943692314468565, 0.03968347322135683, 0.04042738290022939, 0.06134855080275767, 0.04507227740701168, 0.12056609014830283, 0.02574725560994158, 0.131543624485212, 0.08903608687462346, 0.7723337471965821, 9.333748548261582, 1.79512026809877, 0.30465398464472065, 0.08802019299999361, 0.01675067334285667, 0.013664966944845454, 0.05067005122621214, 0.021019939618605762, 0.07811696674194067, 0.06523178154302221, 0.052357145374821085, 0.08700819085201911, 0.06273002566529379, 0.20402295785325192, 2.385819164975997, 20.21424651145935, 33.41118058850689, 31.771394514268447, 34.55080170785227, 42.2326813205596, 49.16285437922324, 52.340550807214555, 52.75316061512117, 53.819857028222856, 51.8055748170422, 51.18126292382517, 53.48249004733179, 52.89034158952775, 51.58588286369078, 50.79025753082768, 49.38198151126985, 49.1114007273028, 47.35690101500481, 48.142222281425234, 49.03265914609356, 56.31697908524544, 60.46408537895449, 60.9507966041565, 59.07877483675557, 61.91928079051357, 65.62704632359167, 62.39808451744818, 60.59555146002001, 67.17742196975216, 59.97067474549817, 57.90462901515346, 52.910639855169485, 25.75878151001469, 1.9171111285686495, 0.27940020265598453, 5.055832189898338, 31.740819638775243, 52.65583484403549, 52.627511409021196, 64.56458999264625, 58.11484452216857, 62.266116373000614, 58.4354982837554, 57.7692444862858, 55.76700002916398, 4.453754742299357, 1.1847019003283594, 11.098760212621382, 44.249034543191236, 30.458867472987023, 21.137021357013335, 32.51607021977825, 30.543108217177856, 31.21370996198347, 32.08800235102254, 34.81473407437725, 33.11364527671568, 34.6644994520372, 35.135544730770974, 39.723078281648704, 27.609075307846073, 47.63489507859754, 74.09779302535519, 45.680260350627286, 0.24007957548864428, 0.10057857275129327, 0.014602355001824758, 0.10040355230411215, 0.048467077299832344, 0.057422292734225916, 0.20642043001228766, 0.1765185780823231, 0.1598983924956091, 0.2825440436361298, 0.1793011932844116, 0.15222378495720126, 0.12196064596214604, 0.1833532774640668, 0.28155995773211606, 0.23937763976714305, 0.3645794351975764, 70.6768508111277, 88.56435714229461, 50.53634682009297, 61.493515353049006, 44.88192465997512, 45.28937262873496, 56.4777531162385, 55.81038928801014, 44.324112630659535, 45.37952830714565, 41.17200182330224, 56.82840124253304, 33.12645966006864, 70.26441358750867, 72.74284162829, 46.036803799290816, 18.047017358964492, 4.994371100779503, 17.861808922982988, 48.56538326509538, 74.3195403006769, 72.31619757990684, 74.91307335515177, 73.30691768277076, 70.53302534164922, 44.878206253051765, 12.740541792684986, 1.3310474926425566, 2.4627356183144355, 34.19467010805684, 65.52580602707403, 69.42231993521415, 70.76214667289489, 72.41271926510719, 69.28636274030133, 68.3739096118558, 72.27438511386995, 72.45489258919993, 67.3292020059401, 69.33584736239526, 66.80172950990739, 64.72425791525072, 58.06180623269851, 56.052423061863074, 59.42407285013507, 55.914610585858746, 55.31317395548667, 57.17862967521914, 61.328014865998306, 59.54112422081732, 61.758494992409986, 57.55412993892547, 55.60038558898434, 54.23850728619484, 57.27719883764944, 57.140649364840606, 56.943828751963956, 53.230422850578066, 50.125757032825106, 33.74006740508541, 42.431745529174805, 37.00395791761337, 11.597468006995417, 0.5608317027649572, 0.07879480899822328, 0.08747264697787263, 0.14804129729107504, 0.2077686221849534, 0.10540655844153897, 0.1421328441750619, 0.18378771060416776, 0.0817944645701397, 0.1337422508626215, 0.18368637249354394, 0.20916250384142324, 0.1651043123415401, 0.11633890125179484, 0.28986266543788297, 0.06505712881804475, 2.386762495002439, 21.90362899534164, 0.5220810756567986, 0.2284109225917247, 0.10512297567460807, 0.17943939554595179, 0.16494262182424146, 0.28626140867990835, 0.18765766504070452, 0.19395604158841795, 0.22492462498766763, 0.16957950688177542, 0.1911769044255057, 0.22487358821015205, 0.6138517286988997, 12.200716772387105, 29.871927922771825, 38.22716866770099, 36.53088869587068, 43.05650849496165, 45.2204526624372, 52.11373582963021, 53.859488656443936, 55.146661496931515, 57.228188822346354, 56.77320172709804, 55.01968260734312, 57.62157509403845, 53.252439114355276, 54.71829160567253, 55.115678694940385, 54.338692465136134, 53.4271454042004, 49.63419383571994, 50.1358022228364, 52.95113832719865, 58.25752465955673, 64.78699622615692, 63.38036760207146, 60.17206099725539, 66.90241675223074, 68.45311011037519, 63.66208399495771, 63.69079574461907, 67.55869988472232, 64.45050393381428, 64.16721467048892, 58.50806605431342, 30.09209840528427, 3.2584781319864335, 1.345833725025577, 4.651827571853515, 27.04989633252544, 57.67606073810209, 64.51971415550479, 66.72757317942958, 65.58699892413232, 65.86072937134774, 62.54442422620712, 62.95072294050648, 63.009531036500015, 10.048105312931924, 2.1340375658004516, 14.320309719731732, 54.66044449037122, 31.531723968444336, 30.003539131533717, 44.87154606849917, 42.749402599949995, 42.19793696557322, 46.073744681573686, 48.48590820066391, 45.68727747086556, 35.90983236989668, 48.18381509473247, 55.300375261614406, 35.936006346056544, 57.664540736906, 80.12639753280148, 59.08200294740739, 0.3812742377481153, 0.15173741105583408, 0.07976751849656144, 0.2090829073060905, 0.13514102016004825, 0.1561254707555617], [0.1473898467637839, 0.04052931472899453, 0.010180764591261264, 0.03228690963418734, 0.0651437427187639, 0.12925709717937056, 0.10494632346014823, 0.10298554440059009, 0.2534198935233778, 0.14375518857231065, 0.18709400818953592, 32.26254978487569, 72.53616409917032, 43.19217935685189, 31.330963334729596, 28.33527272747409, 24.197185923976285, 48.11047853962068, 42.300687374607215, 40.67188393685126, 34.40750575834705, 32.26216931496897, 42.015903688246205, 27.76500717286141, 21.59440305925185, 14.647435392102889, 30.86652921092126, 18.311065435409546, 1.2560083837278428, 2.394435141355761, 39.78473401838734, 61.64138870854532, 58.59903366334977, 58.90929314397997, 52.14203573042347, 52.340531195363695, 49.39403887717955, 22.57956712476669, 1.4756634422848303, 0.2399911842639408, 10.227262512330087, 46.96184381361931, 62.74796778155912, 66.79316305345105, 62.74726567729827, 67.40378195239653, 65.16433608147406, 62.67580401512885, 61.4363899538594, 68.74163181551042, 63.360100715391106, 60.19359873187158, 55.53616069978284, 49.8675670162324, 51.712551886035556, 51.71484255021619, 52.70744539076283, 51.44203778236143, 50.00115117719097, 52.790885971438506, 53.135540716109745, 53.555983497250466, 53.193470201184674, 52.326622470732666, 49.374234830179525, 50.02677209915654, 50.59853992154522, 43.65277936381679, 43.581709938664595, 30.962972448718165, 24.737084488714896, 37.747596156212595, 21.674040902045466, 4.225048201699411, 0.01971300894154176, 0.05220778504266374, 0.02217835266022913, 0.06765566841368714, 0.020660720990910646, 0.071991863960941, 0.03721708762309244, 0.06546910792108505, 0.05563776752340698, 0.09004818095314888, 0.048952796196024266, 0.001731297062736215, 0.11676981038744412, 0.023991573609471805, 0.01776667446979592, 0.1707555744196138, 0.12665512550982738, 11.0982120613898, 5.0303990514047685, 0.3707028372633842, 0.00921278281302582, 0.10631100950582374, 0.0422958598562306, 0.0075413925092547174, 0.03343783416635087, 0.10227243145627361, 0.0955378138009579, 0.03901115062856867, 0.017266267752875725, 0.011512045372998523, 0.13848113286639416, 0.9901848219094739, 12.42293179035187, 21.661648173486036, 27.754632503755634, 19.64829948640639, 33.80041699255667, 39.46944213682605, 45.288717592916186, 45.383458522058305, 49.45344709580945, 48.03584760235202, 49.61367983971873, 47.52738291217435, 50.87574166636313, 47.5003420922064, 46.50788045698597, 46.64593611994098, 45.24633638320431, 44.41250716486285, 48.19104010058988, 50.13611209008002, 54.874802020288286, 58.62941242033436, 59.830810869893725, 58.64143056254233, 59.4226098060608, 64.49978851502942, 63.56224398459158, 60.72641741844916, 60.88598335942915, 62.221566092583444, 45.825792051130726, 38.32955037393878, 13.24859659517965, 1.6112763266409598, 3.1842029046627784, 18.60139927556438, 28.542726885887888, 37.638236553438254, 37.44386349954913, 43.07308835368003, 47.60125290962958, 47.943275743915194, 47.25513904325424, 58.11731953774729, 35.49904254175002, 0.8054425351081357, 0.5716979551699855, 20.16451281885947, 51.73156753663094, 22.75453425222828, 28.875720424036828, 27.208040414317963, 31.0976666404355, 31.26008022216059, 31.50054700912968, 35.74372391546927, 30.6527933766765, 28.45320074788986, 44.10655836905203, 35.00820498312674, 39.39314419223417, 44.51237070945002, 69.40430056664252, 31.798133311733125, 0.2852687119476257, 0.20655513891289312, 0.08848271858427795, 0.022968059075215173, 0.04236648933240964, 0.10605129037773418, 0.030598036246374253, 0.023579383832252315, 0.026366819642604362, 0.0427399801781341, 0.027732451806866357, 0.10336280439890201, 0.03832110076121265, 0.06317586585458729, 0.057952088499141324, 0.11672183030074644, 0.3096573048781964, 38.74506665814308, 87.16617338119015, 42.60992311662243, 42.15564204800514, 30.673862388057096, 34.6658879710782, 44.382246078983435, 38.425722968193796, 38.54819897682437, 34.169488491550574, 35.80356751718829, 36.03782715335969, 31.46218034528917, 32.834376442816954, 24.947886390070764, 35.02260792639948, 21.896874673904914, 4.203330528351569, 1.8455457687377932, 40.46093494661393, 66.10720326823574, 62.354510907203924, 65.78533357189548, 54.47713252036802, 56.632655359083614, 53.41798274747787, 25.357464205834177, 2.548848068521869, 0.5653671271377995, 9.097766991584532, 45.54471892695273, 64.62172715894638, 70.3206289968183, 66.55387493871874, 69.70294198682232, 66.9286495639432, 64.1822922614313, 62.179600654109834, 70.19963956648304, 64.01671724934732, 62.86277947887298, 55.88600866256222, 54.67221552325834, 52.92199903918851, 55.40840910327051, 53.9066747696169, 55.29484079730127, 52.68234222166, 53.67985979203255, 55.15145071091191, 55.42158434467932, 54.35987326406664, 55.17158031463624, 52.92003000936201, 52.86488540710942, 54.47346510425691, 51.355561287172385, 53.36439140381352, 30.937420168230613, 36.269337208040305, 44.524996819034705, 28.4245321443004, 5.326158510100457, 0.06272785763646807, 0.020105694120209065, 0.07430901180111593, 0.056395669798216516, 0.06488819110898242, 0.011991025568286498, 0.08610396961411161, 0.021100794453354135, 0.06938025490531037, 0.09308028800953781, 0.05289984206038137, 0.0503350256551658, 0.14619828892811654, 0.022546199353171453, 0.041442089338576606, 0.05643230795319523, 0.014702793916747456, 1.8168690752598549, 7.2985262736197445, 0.45798731006441584, 0.11339517775923015, 0.13851413593417214, 0.08678699062476236, 0.041771913172617074, 0.02888825823432736, 0.06701920256619492, 0.08475643627706074, 0.05518962523990101, 0.005255431629672286, 0.0200631053772785, 0.014603529989178625, 0.9063570910403806, 16.86759202711044, 35.50660879381242, 37.73382863690777, 27.34535082694023, 36.45392002597932, 44.27147442294706, 48.63861391621251, 49.63093042373658, 53.16984968800699, 51.021391037971746, 50.814211445470015, 51.57404122814056, 50.48498730505667, 50.45984098988195, 49.11418561012515, 48.56423793300506, 47.75877921811996, 47.32726750835296, 48.7607761352293, 52.52094061143937, 56.19814695850496, 59.14858910345263, 61.46769439020465, 61.102560950863754, 60.78633162283129, 64.50826867934197, 64.51059464485415, 61.23262674577775, 59.977378076122655, 62.34352827072144, 44.8519616742288, 36.81007515999579, 13.252496411723476, 2.275648121872256, 6.409981952559564, 27.55467203355605, 32.8801053954709, 39.40260887145996, 47.75451952411283, 50.94435568778746, 54.80887090006183, 53.948271505294315, 52.26581004358108, 61.075696637553555, 33.80813229468561, 0.28217567791861875, 2.7111128453285467, 22.710533103635235, 52.00136384656353, 31.034110515348374, 26.265814535079468, 27.256509142537272, 30.817364261996364, 33.13475547298309, 30.589058783746538, 32.1365495266453, 30.454580322388683, 31.874395954993467, 34.967957542788604, 38.754566638700425, 31.46459652531532, 47.01436042785645, 78.45382828866282, 37.22763107668969, 0.3925464554659782, 0.27631029426570863, 0.0869502209787888, 0.020150234472126733, 0.059154045978380795, 0.06832568125138361, 0.2104442455475369, 0.127574905993477, 0.15100360607668278, 0.09077829338850514, 0.18411596395796348, 0.2894092639607768, 0.20696043006835446, 0.1582001900720981, 0.3670717337198796, 0.20876660492391358, 0.31811249472441216, 48.36651125261861, 99.08351067573794, 56.143151406318914, 47.84800921716998, 33.82290394075456, 33.93633496376776, 62.322759320659024, 55.746937105732584, 51.926077873476096, 43.20731578334686, 44.19251318900816, 57.667796304149014, 34.964176377942486, 30.87341493175876, 17.532310216657578, 42.1526296677128, 24.37119403193074, 4.544459062237894, 5.577506932520098, 51.31276430622224, 77.22840924416819, 68.98876467058736, 71.36084941125685, 63.70098998469692, 65.3537473370952, 57.501099494195756, 27.193794365852114, 2.6817011977395704, 0.9153086139309792, 15.186923088565951, 54.70761883643366, 69.38094677463656, 71.826826987728, 68.75696828288417, 74.18432835609683, 71.45115806210426, 66.31337088923301, 64.33784561772501, 73.3497578097928, 67.18353302248063, 65.31297429915398, 58.144870265837646, 56.51592170038531, 58.44471585366034, 57.82551088640767, 58.08069636744838, 59.117951470036665, 54.86410963919855, 57.05011321652321, 61.18523666935583, 60.02350907171927, 58.075793404732984, 61.007302268858886, 56.40560111691875, 56.01645884975311, 59.405825984093454, 56.689310073852546, 54.98658564782912, 45.82920843555082, 39.15169092916673, 51.627616882324226, 33.743860337042044, 7.696321289385519, 0.11776914910203028, 0.23615691420291704, 0.1998261903082171, 0.12772381816419864, 0.1304902842328433, 0.2062212624737332, 0.19132278288804716, 0.1565907465954942, 0.16250424057004914, 0.24467426442330886, 0.16661543609394183, 0.11115930418694213, 0.340127716622045, 0.1497947040104097, 0.15346878508646644, 0.31386652901288004, 0.2964096834823009, 15.962155038310637, 8.075546824163007, 0.7675308049205811, 0.1897508164326991, 0.18245928349994844, 0.1377340745661528, 0.1849298098034436, 0.20841644145548346, 0.12971648946404457, 0.13415639799448753, 0.15810750875501864, 0.10885471252784615, 0.07428116450506835, 0.17861942099707742, 7.182125035793551, 24.361609720414688, 36.04464815508935, 39.66503504783877, 33.98321120969711, 46.116000375440045, 50.135280547603486, 49.027156060741795, 50.45689528988254, 55.81367231184437, 51.69141815554712, 55.57852622001402, 51.30186796188355, 55.58581398379419, 53.54261998207339, 52.68673135388283, 51.614092549970074, 47.84457322089903, 48.603183146445986, 51.13436314367479, 54.33034173903927, 57.72980505420316, 61.95509987492716, 61.824265295459384, 63.958983882781006, 62.09758781617688, 69.48498372108706, 68.73276725892099, 66.22991854144682, 64.18428090310866, 63.851624688794544, 50.10439580486667, 44.2274889638347, 17.24302561052384, 2.934159160621705, 3.8386533096913373, 25.262080007983794, 38.28920879671651, 45.61409781056066, 48.36813511386995, 55.059498586962306, 58.55159651848578, 60.05812398848995, 56.853618160370864, 67.69115832544142, 42.3820294872407, 2.2329440520655726, 2.1599587942323377, 26.137790333840158, 61.6977963139934, 30.81885672384693, 36.55128502076672, 36.08833943643878, 41.14851859308059, 42.53329569293607, 42.66092177360289, 47.36570673604166, 41.84455886963875, 37.06369953770792, 56.87758384212371, 49.06534817910964, 50.65841490222562, 58.52112754698723, 86.5601279658656, 49.06317518603418, 0.4671909984561705, 0.30945796880029863, 0.19420621526097098, 0.10486844296176588, 0.25508100196959516, 0.18549956471448947], [0.005472662563871352, 0.04715245126956894, 0.037355355002106204, 0.0187130420348577, 0.16721344432763516, 0.0325799880609397, 0.071065571729935, 0.04821134182894903, 0.1458723185163352, 0.10289376706726129, 0.38841279824414565, 14.036336983403853, 74.16918016249134, 52.618325218077636, 30.7561517530872, 46.49922378601567, 29.001214696514992, 33.360287835521085, 46.69479708517752, 36.837755326301824, 33.066302268735825, 31.64076585923472, 38.925836932274606, 40.992600456360854, 14.03709694262474, 18.38595524910958, 31.575558416305054, 30.29801303340543, 3.0553047503194506, 0.6836782528027412, 22.83556453643307, 70.65111221805697, 61.409635466914025, 68.1094398806172, 63.21301575629943, 58.874580167954974, 43.2986246385882, 35.772631783639234, 17.35711951409617, 3.5409539937973027, 1.8431643997469258, 19.639972294530562, 54.16074629752867, 63.46478093054987, 66.22533721308555, 66.8508924976472, 66.69395062231249, 58.93178009217786, 59.17324119998563, 67.141202803581, 60.40404173635668, 61.32816783843502, 53.547036570887414, 50.34619815887944, 51.78104039161436, 56.30177597845755, 53.51169601563485, 50.69164129995531, 49.80191830665835, 50.87445905131679, 50.68698544656077, 52.37808396739345, 49.8833231772146, 52.6119395994371, 51.458805914848085, 52.597956349772794, 45.399308819924634, 47.20390896643362, 37.725077829053326, 20.20528977917087, 43.43112622537921, 30.701919101899673, 22.774785449427945, 3.9801707094715493, 0.025143164638129455, 0.09592975970477828, 0.059758922190315304, 0.12069365910945401, 0.09619500998768116, 0.036312433545507734, 0.01142990734097698, 0.12447037298472659, 0.05467481032434491, 0.09436474166690342, 0.06753703203773306, 0.02060241786943328, 0.08316231455894248, 0.08184270512673163, 0.14722549026050877, 0.14330547963899953, 0.27794448238226677, 3.1264197730248977, 6.198146016367021, 0.5175852427078832, 0.45410915848708927, 0.09801958627518147, 0.04381374816500372, 0.05150660391776793, 0.18917041289950573, 0.10686570312827827, 0.1093038545560933, 0.043773229774688525, 0.08481691125780345, 0.05548012961122779, 0.3661731125846986, 1.7077590332877253, 9.294300290846056, 10.064758716091033, 33.50370537850165, 29.85076673569218, 21.057612972874796, 34.12613845640613, 40.9739338967108, 48.140308164781146, 49.38041256320093, 48.85619171204106, 50.22440072028868, 52.053943218723425, 47.336618438843765, 46.90949978366975, 46.850554404720185, 48.15875507170155, 47.47994576731036, 48.68119516680318, 48.22900079911756, 49.293936068011874, 55.50839031896284, 59.04563865353985, 59.245887417947095, 59.58240324451078, 57.357599581441576, 67.01037606885357, 59.671072344626154, 53.535214547188055, 45.80529766698038, 44.23972675877233, 30.80178264648684, 20.00399766429778, 7.617820443645601, 6.084640468320539, 27.327647209167484, 49.2214467448573, 47.08952480746854, 63.344626965061316, 37.862694186549035, 42.88280633188064, 61.7576006920107, 55.23021974871236, 54.377359190294825, 56.854014319758264, 13.985125537841553, 0.20087937734300093, 3.2558861807469404, 26.320957176146973, 41.3458961825217, 12.709444261366322, 30.113412564800633, 27.993640169020626, 33.860048786286384, 30.08518522785556, 30.42489190255442, 40.07199664269724, 32.031231926333525, 37.75272269402781, 48.58861154125583, 30.849092314320227, 41.64115651961296, 49.18088551490538, 67.7041962838942, 18.52695857324908, 0.7165861418170314, 0.3196628115350201, 0.12411789593076515, 0.03608931043756104, 0.0488382775426632, 0.06374334548449805, 0.018829154151101268, 0.04542027284661609, 0.04173484217796115, 0.11203036913948675, 0.13582458509312523, 0.07366129978289528, 0.08006554968174427, 0.08215104785537528, 0.0901027340742369, 0.2899483140678175, 0.5570023663101659, 17.740264477268344, 89.55845832824708, 48.48689663794733, 30.808036865726596, 44.295318511224565, 32.278545210438395, 35.4510994111338, 37.12709288443289, 36.05333228265086, 31.624260525549616, 35.642715038791785, 39.5941460517145, 36.27002362282046, 24.160137176513675, 25.00330359705033, 35.65242290496826, 32.91991549153482, 6.68816085784666, 0.9991560792250018, 25.40630752040494, 80.1558780670166, 68.69592835826259, 69.55072264517509, 69.79906359026509, 63.874092025141564, 50.1765085804847, 49.567792031072806, 27.126064838901645, 7.950100600719453, 1.952430110785269, 15.755435343711609, 52.239428181802076, 66.23398211694533, 67.8800988966419, 68.48412821369787, 66.27672810708323, 60.01134972418509, 61.378648742552734, 69.30206006573093, 64.81515884399414, 65.62424967365881, 55.608626488716375, 51.33950702605709, 54.76222215160247, 57.66295609935638, 57.8339086809466, 53.260789840452134, 52.637282033120435, 53.56272997394685, 54.09147724028557, 54.356378432243105, 53.32630126707016, 53.486255522697206, 54.16527271270753, 55.679758671791326, 49.05789959815241, 53.45181711258427, 35.12726068496704, 33.50175988289618, 57.34113347145819, 36.32843555942659, 25.895244690679736, 7.255515033198941, 0.06287026572071257, 0.10531856558255612, 0.09946562319753632, 0.1498425232186433, 0.05698879805183219, 0.07644312591442178, 0.07411896070886044, 0.013984429439710034, 0.029572639051043702, 0.1373178896404082, 0.05770574526620969, 0.009976779317273008, 0.05263293319712243, 0.08182441094709982, 0.07378240296196553, 0.07551619783043861, 0.04119611382784863, 1.0645343291182672, 5.8020312459238115, 0.42438577439996505, 0.3863272617661184, 0.10504419119247507, 0.12031736438192668, 0.009173549535203605, 0.09230797179043294, 0.07628298289473019, 0.17220409346684334, 0.04598795548982678, 0.02141216322929869, 0.06083600350745744, 0.09119087770100563, 0.43351429424458937, 12.072815145215682, 16.130215852491318, 42.85105866770591, 42.38519483996976, 26.53728569707563, 33.71452493052329, 45.29699379397977, 49.222690136201926, 50.252571182866255, 52.61423418598791, 52.59607753446026, 53.05330822544714, 49.76010191825129, 49.85630196909751, 48.79379856971003, 50.495730676958644, 50.29911402733096, 51.97693532513034, 49.48273151151596, 50.52846677841679, 53.91911652780349, 60.65313577651978, 59.00168457338887, 61.398597917249134, 57.16723911223873, 67.37561933455929, 57.68293665301416, 52.94889080908991, 45.230203674685576, 42.40421049056515, 28.016933164288922, 16.124791214543006, 9.01010888238107, 10.070884477707649, 37.172427638884514, 55.345388381711906, 49.893976334602606, 62.32761913730253, 40.08201437611734, 48.14921586744247, 66.52242537467711, 61.21793746948243, 57.30865232406124, 58.80382453241656, 12.45101203841548, 0.19462333481398322, 9.046005433605565, 29.6592923133604, 46.93726624211958, 18.86596510487218, 27.910440814110544, 25.887150879829164, 34.77101925880679, 30.518952300471646, 31.046652293974358, 35.353773640048125, 33.35540448465655, 35.18317407177341, 38.30977378352996, 41.65204109684114, 45.57438381256596, 51.425304951206336, 79.96008903749528, 22.80187333783796, 0.4162750483280228, 0.25368207945458354, 0.027289561056081327, 0.015765889341221945, 0.08079272800035055, 0.02028660961396752, 0.0650416385202158, 0.20902195735083473, 0.12286883553550129, 0.18796143422444023, 0.49218838613840843, 0.23036532013887362, 0.1843359997315753, 0.22138015066664066, 0.1988181105304149, 0.2879721749453776, 0.6608522647330839, 24.235103476432062, 102.46150293657857, 67.33744682804232, 44.951715392451135, 60.69972176705638, 37.629485745583814, 43.758636290027255, 61.10101553701586, 47.85967434606245, 44.05556755681192, 40.032498375062026, 54.574540661227324, 53.766708912387976, 17.93126625399436, 24.625396959243286, 42.054797910874896, 37.839995430361846, 6.391759601331527, 2.3225251032460124, 31.786458376915228, 81.01338663408833, 73.90521249463482, 76.1373706017771, 72.73710712309807, 70.07031117716144, 59.16921292581866, 51.07304865314115, 23.531902913124334, 6.615636233360537, 3.7956947761197246, 24.620242964836862, 59.612985964744325, 70.01145209035566, 73.66728936472248, 71.17928289598035, 70.23581950895249, 60.60405908092376, 61.624447991771085, 73.46132570697416, 66.28776565674814, 69.69970995380034, 59.323244402485514, 56.79561807263283, 57.72166221372543, 61.8753110208819, 58.4029112323638, 56.850947026283514, 56.40610318030081, 58.48287267069663, 55.31320141207788, 57.73688493236419, 55.862639181075565, 55.92659734910535, 56.9786907780555, 61.65363434822329, 55.83847345844392, 53.568625296315844, 49.857004073358354, 29.187580231697332, 55.46044718834662, 43.60184346475909, 31.079904187110166, 7.69349031871365, 0.1343666125209101, 0.23268060638539254, 0.13214458981829305, 0.2915225941086969, 0.17721740348685175, 0.12165944317295668, 0.2691370453084669, 0.24332616418119402, 0.3172187459084296, 0.19210206284638376, 0.20582986815321833, 0.1062017730287006, 0.15307408126611866, 0.13769717977171944, 0.18146661741118278, 0.2574834383783802, 0.19334926930887086, 4.842648429255332, 16.019847219990147, 0.7315379717657644, 0.844854633173635, 0.20797371924404176, 0.2973701125912128, 0.16464104365196922, 0.36178900589866025, 0.1805512649157355, 0.2578485558830923, 0.18589437578714665, 0.3115461712643024, 0.18669810927202626, 0.6700555547591179, 7.311516183037912, 19.5282494637274, 16.492227085175053, 48.78675791525072, 43.57746593413815, 34.62052968240554, 44.557893737669914, 47.20628592275804, 53.34061007345877, 54.20797163440336, 53.52416130804247, 53.69884798603674, 57.03964833290347, 51.55890087927542, 50.83291722882179, 53.05033506885652, 53.05432804169194, 52.06352949142457, 56.438188168310354, 51.7944666647142, 51.563901901245124, 55.13543959586851, 63.50147078114172, 63.13020275485132, 62.0004189398981, 59.96280254856233, 70.41995909906203, 62.97963865341679, 57.89163420277258, 51.99692372352847, 51.07966176925167, 33.71679206048289, 22.150271554147047, 11.11442223671944, 8.495208563343171, 33.3950125786566, 58.339768917329856, 53.103075258193485, 69.44852136796521, 45.0393097631393, 52.35186684516169, 70.54848732486849, 68.38088358602216, 63.357178549612726, 66.65699405054893, 16.585238249071185, 0.8253010049943001, 5.67417815808327, 32.52346388755306, 50.38554345407794, 17.46672034263611, 38.10646164801813, 38.980357877669796, 43.485258856127345, 41.33769842886156, 41.72807232026131, 53.47672416317848, 44.42666299881474, 48.15737831977106, 65.29910872059484, 43.1187290530051, 54.73450276159472, 64.41080954767042, 88.27011662144815, 31.362393286920366, 1.0285577370274452, 0.52198160680071, 0.27422506422285114, 0.11630949113638171, 0.2504749442901342, 0.20009039871154294], [0.09177596203141636, 0.007473341876550788, 0.06010610174628035, 0.03616267867806939, 0.05621749689922698, 0.04461429855455795, 0.0206041396520431, 0.11765343918194694, 0.030543586547156016, 0.08049799865412136, 0.17348355223094264, 4.499817586714222, 76.77974500963765, 57.66366604835757, 37.269427853245894, 32.78189316872628, 52.70382896546395, 45.726383501483554, 55.94911567626461, 39.17997514047931, 39.13010612610848, 37.011987009356105, 29.913193218169678, 45.30582697160783, 28.269886816701582, 33.50661577716951, 39.31054299877536, 29.90513274746557, 10.195075542696062, 0.1758565248981599, 17.566446604267245, 48.27198605383597, 57.1363151458002, 56.76654938728579, 49.82709992316462, 49.79966686617944, 42.08941675001576, 38.73948904775804, 46.44094913236557, 17.92363920519429, 1.7739756285182893, 2.7820452326728455, 21.209910761925485, 52.125542163848884, 54.26166888206236, 56.371507875380985, 58.581288860690215, 58.34107898896741, 63.81942595205, 62.79316525305472, 63.89095037214218, 61.792560777356556, 52.13252006038543, 51.47890021724086, 53.75007021811701, 57.261830991314305, 56.87472051189792, 53.90158745550341, 51.86419071689729, 50.67262957173009, 52.755317918715946, 51.06534511812272, 55.48777434133715, 49.63421344757081, 53.396864706470126, 46.06335824535739, 47.48695112043812, 41.03751159483387, 23.59043448202072, 42.01340906081661, 28.990010446117772, 14.470311941639071, 21.523406197947843, 4.942879205749882, 0.2722839199967923, 0.045827410273974946, 0.10748874711533708, 0.04167749283594951, 0.10109463255972632, 0.10965970239692158, 0.13665291000037424, 0.017980275104843804, 0.047545435222526716, 0.05871045425714505, 0.12125827357052796, 0.04708279855549336, 0.043901193271120714, 0.08654607895521388, 0.017719544740694187, 0.009496175015585558, 0.028563119027943864, 0.02874158304034462, 6.022100237108046, 0.1905628696324364, 0.03271864614479485, 0.02834312155872824, 0.09221135278142269, 0.049961002378333966, 0.12072745890867327, 0.15419728873718172, 0.07729788851593772, 0.06402018667769528, 0.0721085008474127, 0.023038297846552827, 0.3967053323022781, 1.0774043610980435, 12.655730343634083, 7.591628816819961, 3.931309008790601, 27.626516126817275, 25.542209802135346, 17.593014778629428, 37.31118932847054, 44.273635648912006, 51.713301058738466, 54.10695491298553, 50.872544934672696, 51.6603490614122, 49.08215945766818, 48.99598106261223, 48.311127385785504, 49.18009319613057, 46.69795459316623, 48.80219244187879, 50.66886801873484, 50.82097361164709, 54.04812328277096, 58.53815455590525, 57.89835714524793, 61.73549421371953, 55.785246895205596, 64.51916110131049, 43.56610282774895, 37.137640137826246, 30.888270908786406, 24.430655202557965, 12.184725269194573, 5.932403476007524, 17.878598628505586, 30.097450479384396, 45.47490073788551, 49.37163429875528, 56.487943433946185, 51.84625371809929, 44.29958212760187, 54.22146458779612, 49.83929849440052, 54.17313314253285, 51.36965436320151, 51.582584150375865, 3.2592140666900145, 0.5832879461588398, 4.206865564469369, 40.650263832461455, 23.30099298108009, 22.26827802196626, 31.32900214964344, 29.078069617671353, 33.806492743953584, 35.07323003584339, 31.345889914420347, 36.51970994087958, 26.402465989512784, 39.73193107112762, 38.029187033253336, 25.499377519853656, 30.800048958870676, 47.69555845568257, 67.14921228347286, 10.893471202542706, 0.6831548002458389, 0.2260277149898391, 0.09235104125353599, 0.024343895530628584, 0.030677448920605165, 0.019083382343993555, 0.029866389719949617, 0.032352701265124545, 0.11584480518415091, 0.007383131671832094, 0.09878532179901678, 0.09318852091148015, 0.029480706584910234, 0.09184786704398933, 0.1339411579312817, 0.13287827222337648, 0.4051410328717001, 5.979025258171943, 89.31898978448685, 64.8802701888546, 29.999395147446666, 36.90713028753958, 42.78338993749311, 53.35433052432153, 42.69318719064036, 35.80268106152935, 39.2943710665549, 34.85923336398217, 37.278323788796705, 37.877861992005386, 33.39219239450271, 39.15357366684945, 34.70418207107052, 30.524778981362623, 11.292872428894045, 0.6961847300971709, 18.03069245430731, 58.028799487698464, 62.395048602934814, 60.921429818676366, 55.074584022645034, 55.78850638481879, 52.957884803895034, 45.058254811071585, 52.06327453736336, 25.25232703455033, 4.683641916321171, 3.4748917193182054, 18.589624320307088, 51.70387952558456, 53.81109053088773, 53.08445184461532, 58.010611457209436, 56.78986787796021, 64.725948456795, 64.55761601847988, 65.27998324363463, 63.67508272970877, 54.399630408133234, 52.243833003505586, 57.010073661804206, 58.27418688804873, 59.1293655672381, 56.60117049371043, 53.28200594071419, 52.15939221843597, 54.99903525075605, 54.06409517411263, 56.444966023968114, 54.147555366639175, 56.937054818676366, 46.72093576000583, 55.41423382297639, 41.79444666831724, 35.388059077724336, 62.19564707048478, 35.02662443345593, 22.754763710883356, 26.91080516384494, 3.8422895919892097, 0.18144087685692697, 0.0530179345139092, 0.04204550615301536, 0.04525672456610107, 0.1046695358931057, 0.05234364690559526, 0.10325274054682064, 0.0867044752944381, 0.0867090565002253, 0.01561073738435704, 0.13423711301818972, 0.015516287361782406, 0.030952204439428546, 0.12514953291223896, 0.03235522935527467, 0.044273994637713324, 0.11733858470594692, 0.06767409282826609, 5.636159604595554, 0.12189406526064682, 0.09049982808890844, 0.035596830815437346, 0.07385489020136095, 0.04658453496954134, 0.1017997092417171, 0.047883142101308035, 0.09044539754188831, 0.013619823298687416, 0.029546590146398353, 0.048911745374601696, 0.5610200378202623, 2.2583387023018253, 20.87365773416335, 18.28361276657351, 11.488565360346149, 34.538387406256895, 39.430516535235995, 20.95816323834081, 34.414875891900834, 46.83397846837198, 54.78374419673797, 57.07253348442816, 52.84634044093471, 54.10422886571577, 52.9054937055034, 52.33149797685685, 51.31891850502261, 52.345328254084436, 49.198716609708725, 48.82511869553597, 50.99130645875008, 51.29575690915508, 56.40480879814395, 58.82671940711237, 58.15638242229339, 62.3815046587298, 55.67770334982104, 60.333619502282914, 43.65310099817092, 34.43388762012605, 28.493024572249386, 21.677600452976844, 10.041502983339372, 6.175247219301039, 24.976982532009004, 39.156837078832815, 48.93943617420812, 49.873383891197946, 57.4359606927441, 56.104818082624874, 46.15475339274253, 54.9234119538338, 56.62082156827373, 58.11762940499091, 56.431892764183786, 51.66099233012046, 1.4821431978094963, 1.2914574170304884, 8.929700293848592, 38.90663693028112, 31.3784416644804, 25.63035330464763, 29.43320885781319, 27.553638489015643, 34.064623924993704, 33.99193456096034, 32.6947400646825, 30.858549148805682, 28.65144714232414, 36.42361971639818, 39.74412179762317, 32.90706580685031, 29.684128761291507, 54.46450248841317, 77.67022502037787, 15.511808106976172, 0.8607296910016768, 0.2593706500145697, 0.0796916451485407, 0.0944239219590541, 0.08909578810656264, 0.023136847397132267, 0.1643883112457491, 0.12571920355361316, 0.20568949020197316, 0.11619746609921418, 0.3334962450448544, 0.14015379391850966, 0.19741161906671142, 0.2658237456794708, 0.30196403543795314, 0.378956729846616, 0.6902782534880023, 9.490758084481763, 104.34742558387019, 78.26444841200306, 50.42799918882309, 46.19473411190895, 66.61891568091609, 58.13116550445557, 71.62898263623639, 50.80224037170411, 50.63403344923451, 46.934720623877745, 41.45215319048974, 61.80704609040291, 34.518116597206365, 47.81160177723054, 52.878107716960294, 37.60314702987671, 14.425067401701405, 1.5519575870806173, 24.344049269153228, 61.059689444880334, 69.05084794567478, 67.19416264564761, 66.1315062738234, 62.295871473127804, 53.38079475587415, 50.329712437045195, 57.64439544370098, 23.634533689868068, 3.2773194822572895, 4.669708676876561, 26.906612150130737, 58.60472894483998, 58.95253727512976, 59.614656894437736, 64.25312634437316, 60.56042271275675, 70.20892773905109, 67.2035135761384, 69.48107704039543, 67.92876766573998, 57.22883601342478, 54.67782843497492, 60.597422430592204, 61.83189038307437, 63.32340302005891, 59.00368498217676, 56.502456203583755, 54.83054591763405, 59.12974603714482, 55.52600176103654, 60.50714515870618, 59.207181469086684, 62.308175948358354, 53.138070644870886, 56.57900517986667, 51.91815468572801, 35.08452646193966, 58.13120472815729, 42.403378948088616, 23.245399267442767, 33.28900268000941, 8.531070793828658, 0.26078080337855125, 0.09336522675209469, 0.15096294212966196, 0.11349476152850736, 0.17640265365762098, 0.13718080586723744, 0.24541170065922124, 0.21616385799021492, 0.15535673216706322, 0.27424623889307825, 0.24023472361506956, 0.08037618301328152, 0.09499931527722268, 0.17681712254641518, 0.08641598190391257, 0.0892229050758385, 0.24795370296605174, 0.17586023276371343, 14.477748755485782, 0.26895039564659523, 0.18763990712261971, 0.1170902726270499, 0.3059936272761514, 0.12282931305948766, 0.29799211469869463, 0.281456750366957, 0.3058541686304154, 0.12256822263401364, 0.19917182864681368, 0.15143316689758532, 1.1111570918752303, 5.480631253411693, 23.961157298857167, 15.967846397430668, 9.475210789711246, 40.18423526517807, 39.95207017467868, 25.635999556510683, 45.42956598343388, 48.85272041443856, 58.8287982633037, 62.16543305304743, 55.44612661484749, 56.931861600568226, 56.07619262510731, 53.337283903552645, 53.0211369452938, 53.76078613342778, 49.71542219961844, 53.48899725944766, 53.9043370369942, 54.15251324253698, 59.33902802005891, 60.9730129088125, 58.699685604341575, 62.59039832699684, 55.68111973424112, 66.24055600935414, 51.40691687983852, 38.51177584740424, 34.64375403619582, 27.231955105258574, 15.3901969809686, 8.67380682499178, 24.878952695477395, 35.580549393930745, 52.8674663266828, 59.5425166622285, 63.27018430156093, 63.17186224845148, 51.46230466904179, 65.48545268274123, 58.207381079273844, 66.81177862228887, 59.59384479830342, 61.56062710669733, 5.251607000827789, 1.7744773241781422, 5.721524598137026, 49.192542799057506, 31.779327507941957, 30.82016875666957, 39.95255262620988, 40.54581895951302, 44.534230078420336, 45.09579189362065, 44.80905486691383, 48.48172695406022, 37.22225742955362, 49.16094026257915, 53.04920150387672, 31.985432371016476, 40.94713234132336, 61.14118452995055, 88.58186660274383, 21.047267721545314, 1.2573323062350674, 0.4592159925208938, 0.2564393524681368, 0.13914582139301684, 0.2660933473417836, 0.12623386908202403], [0.10123792930596298, 0.0550999584788036, 0.022205786268797614, 0.08572317795046876, 0.031194272901742693, 0.022733854505443768, 0.08715738647527273, 0.02089498110205656, 0.04499736549933592, 0.11857955521273038, 0.2517370894671448, 0.25349190578826014, 50.80883387596377, 59.43101544534007, 49.35796876107493, 39.765275139962476, 52.28204473372429, 38.02026756348149, 44.85552710871543, 39.448539826177786, 41.864715929954286, 45.59656481589041, 32.63904633060579, 37.676318845441266, 37.633157084065104, 23.051412567015618, 43.802955150604255, 30.18003990573268, 20.15978636280183, 0.3083058338492148, 5.6781000379593145, 37.27810021369688, 41.90073897761684, 65.6517101872352, 64.30027715621456, 67.60881993078416, 54.010139050022254, 34.267026070625555, 53.50348257249402, 48.725055110070016, 15.447807773467034, 6.249263325045186, 8.169266956467784, 25.510275825377434, 39.68641196527789, 29.863392845276866, 38.3031096766072, 41.7331321777836, 61.77009344100953, 64.80824370538035, 63.91273129370905, 58.3391531052128, 54.630022587314734, 53.85964555125083, 57.856238734337595, 56.58208816282211, 55.96649962086832, 57.10641491797663, 52.47166387496456, 49.12816101504911, 51.018982702685946, 57.263109683990486, 55.877599100912775, 53.16654312995173, 49.255214429670765, 46.336335597499726, 44.076748355742424, 22.846851156603908, 24.432518328389815, 11.51267126683266, 2.7026334164604067, 25.811023558339766, 23.670609689527943, 3.6740419749290716, 0.48401652625010866, 0.013918224121293715, 0.07467022991829342, 0.04772114514883968, 0.14413516818275376, 0.0521248598553, 0.05421015118519145, 0.06742639361970848, 0.059208101142318025, 0.06363235849646792, 0.02805550916931562, 0.049925157124356884, 0.026113223472249605, 0.02742401331723217, 0.014242496690712871, 0.02755841769788775, 0.08406407665461303, 0.12617719389738577, 3.453374331997287, 0.266564583345767, 0.09382818134561663, 0.0882114238676525, 0.047568969443560614, 0.07212124088959349, 0.028089333866392414, 0.03046287726911326, 0.05422661441468424, 0.07058289803324208, 0.09587569687996181, 0.0929288400877868, 0.18604949327005496, 3.4298280987047383, 18.223021953336655, 30.72734586654171, 5.544833098688434, 2.2154990655760614, 13.164548047127264, 12.683203604913528, 17.274453601529522, 41.01872736407865, 48.34728771640409, 53.56618165969849, 54.9362341819271, 52.623302705826305, 53.15785900239022, 51.32396267306421, 50.05169091686126, 51.80580231451219, 51.43898617836737, 50.92935654424852, 50.36134635248492, 51.63257083585186, 53.87588416376422, 59.07747653222854, 63.124950701190585, 63.08251850066647, 57.197378604642815, 51.117728371774, 25.22661982044097, 21.058124842182284, 16.18306194582293, 10.449376529262913, 3.5050625906836603, 9.388249881805914, 41.682655196036066, 40.666592659488806, 47.896921173218765, 50.047529282108435, 53.80114732250091, 53.84998867588659, 66.19759036648658, 61.440975204590835, 53.55671305810252, 56.79617112682712, 58.10332844334265, 21.71956196908028, 0.2720875256965237, 0.3288496459924406, 19.46412067259512, 45.34227755761916, 14.70349390660563, 32.15087598369968, 27.207195143545828, 29.873561589948594, 33.782833007074174, 37.51401901245117, 33.18258485486431, 39.11130620587257, 26.057058149768462, 43.41789607078799, 34.27038361949305, 30.267526411241104, 42.454024591753566, 44.521572589874275, 67.44061300831457, 4.264095887061089, 0.35577285614225174, 0.08033210997499766, 0.07219759687300652, 0.03453492186963558, 0.058072031055006294, 0.026232547412115722, 0.05188084169921856, 0.09293491516502635, 0.050481647222993836, 0.01933692871863323, 0.1452488148765218, 0.09416945819412509, 0.02440894788671886, 0.017317162804125298, 0.09578830156955989, 0.028035765168287104, 0.12075537515263404, 0.33421995298516366, 60.351497665528335, 73.38980520925215, 42.06136395854335, 48.228647785802046, 41.14700455819407, 48.02096612991826, 42.82047202510219, 35.85334239467498, 45.79326775766189, 41.03744491454094, 37.35058169211111, 37.827483069512155, 30.27112714705929, 32.66856804970772, 39.020773979925345, 30.19989102117477, 21.949799214639974, 1.9005677969224992, 3.007179229490219, 35.73087030841459, 46.58073848293674, 69.76655498627694, 65.90349105096632, 76.02822672936225, 55.75184399081815, 44.54755044752552, 61.71390941066127, 57.96977566134546, 22.949685896596602, 11.08877189697758, 11.230628336629561, 27.12412326566635, 39.79038223143547, 29.07155848318531, 37.124005979107274, 42.02394846946963, 65.07986783981323, 64.25264389284196, 64.83992861163232, 59.34735521193474, 58.630710724861395, 54.883254728009625, 59.62464717126662, 57.41990250925864, 58.60261870968727, 58.79979625824959, 55.147410669634425, 50.55046343034314, 55.54083224265806, 57.797669902924575, 58.406327616783884, 54.16644550138905, 52.62470691434799, 55.37999153137208, 43.03486093398064, 31.320729870950025, 37.34742026175223, 18.15472956626646, 6.645088330391915, 29.426213310610866, 34.9302557206923, 6.70819289261295, 0.8157862542617706, 0.02823468372826615, 0.06603239705005, 0.054197549038837035, 0.14117230781384055, 0.020159622879638787, 0.043133891097480254, 0.07244223939074625, 0.007349908353775861, 0.09363164148864248, 0.029505045198264624, 0.13016359369841315, 0.0091820856698999, 0.08336011080011245, 0.042529669890721, 0.05926227504988352, 0.03421655488050273, 0.20577630328555263, 2.560290357758922, 0.12745911946460126, 0.17644262812550993, 0.0790803989155158, 0.03247098141019383, 0.07880658376961946, 0.06668756310377391, 0.019839957371474277, 0.06201949060684251, 0.08613302732907957, 0.06458974623632047, 0.1055456263824336, 0.3221272551003964, 9.73411467767531, 22.76356158717986, 31.825856624111054, 14.258097006428628, 6.889490235236384, 22.934718132019047, 25.42173027992249, 18.71757399651312, 40.93782455690446, 51.766519777236454, 55.833919586673865, 54.76460695266724, 55.26324610556326, 54.348478778716064, 53.72959152344735, 53.60080834357969, 55.19512630278065, 54.39702987670899, 52.214360314030806, 51.05291512704665, 54.08524067171159, 55.199221257240545, 58.593397217412154, 63.33287946639523, 63.26200223738148, 55.65889950721495, 50.79161859327748, 23.755774151894357, 19.067476872474916, 14.448468262149444, 9.221917852278679, 4.489990088247485, 16.219633144717065, 47.3647222211284, 43.93189914764897, 50.301063445306596, 54.4861618165047, 58.79157889273859, 59.58822796421667, 64.5930624777271, 62.21793790017406, 59.12457635325771, 65.58850511427849, 60.60532208411925, 13.784273709020308, 0.4589565338626985, 2.666849878526503, 20.23284835200156, 42.559606952051965, 22.842871912064094, 31.800692658270563, 25.575808825031405, 29.059716847635087, 35.20135425752209, 34.560835130753055, 29.665972109763857, 32.512724438021266, 30.667568945115615, 28.866610719311623, 34.444266211602, 29.40000403311945, 33.66640529324932, 54.584734901305175, 75.03514535965459, 6.930723661376584, 0.39843065423830865, 0.2706354213578086, 0.053300927393138416, 0.06194263283583907, 0.05636213812977076, 0.09373520125424671, 0.3153341696146996, 0.2545947506422958, 0.21322471570343743, 0.16718566597950074, 0.24811254363627205, 0.22631492135265183, 0.22619656076835049, 0.09870459911443534, 0.30238103241689746, 0.14274286466740793, 0.3195534448229498, 0.9163309429441729, 77.70025468641713, 86.36331127535912, 63.582757980592795, 57.42905732124083, 65.92043569011074, 45.86668276017713, 55.25791952686926, 53.065726449412686, 51.65954497552688, 60.663118208608324, 41.30524081568564, 50.544293542062086, 48.33050781680692, 33.052126822933076, 60.60139186920659, 36.513175272172504, 26.900589350731146, 2.2563302036254638, 11.070455408865406, 49.364797607544936, 54.57181853632773, 74.94764512585056, 69.8536394488427, 73.39033865159558, 64.40022307057535, 54.628026100897024, 70.64022371845861, 61.08338840546147, 20.533988321981123, 9.416243837725732, 11.148781218836385, 33.8084460842994, 48.22314862282046, 36.89659087888656, 42.790320765587595, 46.35903827605709, 66.83441854292347, 69.95875112472042, 68.26212990668513, 61.61478719403667, 61.80342966510404, 60.574221611022956, 65.18261432647705, 64.10338201830464, 61.41060821471676, 62.32142963717061, 55.4245614236401, 54.523816570158935, 57.69710817644673, 61.56494563625705, 64.03849032617384, 56.99156399696105, 59.03712318789575, 55.45566974147674, 53.95211935043336, 32.73858039609848, 39.50656344813686, 19.62579292635764, 5.066264713964155, 34.27152895158337, 31.59937308680627, 7.740994634166841, 0.7559448588759669, 0.09453613085732346, 0.18299891583381162, 0.1463839273539282, 0.28279222548007965, 0.10766692384476624, 0.11835408787573538, 0.25718337706019806, 0.06924471862974667, 0.23439789971997663, 0.1669743636082257, 0.274335901823736, 0.09020549710839988, 0.23290199047375112, 0.2892283752800957, 0.11345493261732402, 0.24208680245905156, 0.27203537043063875, 9.124414593942705, 0.6358982069838433, 0.377108312902912, 0.21461351053609004, 0.22016999221617178, 0.12124572505032825, 0.14003924845207122, 0.14415629688770543, 0.16129610459170035, 0.14033290527520642, 0.1375151572809104, 0.23108366546371292, 0.2747911112683435, 9.064690624513934, 28.199821518313502, 58.091981026434134, 15.784435387580627, 3.9788255816505806, 22.082863661550707, 24.64417530644325, 23.698923318616806, 48.47875771983978, 52.104969332295084, 58.553102708631954, 57.64508578085131, 56.816214438407656, 54.9341945494375, 57.61651523651616, 56.208858951445556, 59.19074673806468, 56.17872730378182, 54.4509820784292, 55.27006710729292, 54.95980370429255, 57.02264878057665, 61.64463250867782, 67.47911499392602, 64.58633561288157, 57.61790767792733, 55.46543644320581, 30.5169754259048, 24.679404074145904, 19.216907408929643, 14.521543979644777, 5.039898051369575, 15.791206379090587, 47.09566723915839, 48.00490010169245, 57.93635314510715, 59.430230971305605, 62.99565369083036, 61.0117345471536, 72.84129311961513, 67.63416628683767, 66.259446144104, 66.66491723829701, 68.73302613535236, 28.171411791155418, 1.1527858193843596, 1.6425870142636763, 24.28834180678091, 60.696042583834746, 21.99205098613616, 44.352902827724336, 36.23244731656967, 40.478314968847464, 43.69508997086556, 49.62449773665398, 41.978625482128514, 56.058981264791186, 34.397742978988155, 54.94283945329728, 43.93376619585099, 40.35572913385207, 54.44073684753911, 61.9431641024928, 84.63183587597263, 10.286902150800152, 1.0436620491166269, 0.5751454734033155, 0.1605176366865635, 0.1596551136143746, 0.17616853718796086, 0.15541143084485687], [0.007998331397351238, 0.06621297163468215, 0.059302368261400736, 0.09178487929485499, 0.09025458036170853, 0.06661447065491831, 0.05365137431410052, 0.0667681708751667, 0.08504846899379646, 0.15131721182936622, 0.17074120261015432, 0.3568168807654612, 27.585115509648478, 76.90479017073109, 43.89861391436669, 29.190994654932332, 54.4025957199835, 34.34265721228815, 29.23277770319293, 41.22179239026962, 39.536420529888524, 46.4777684211731, 44.613995398244555, 29.8067283245825, 48.860620067965606, 27.109212375456288, 32.1034368776506, 41.979068709957986, 32.374549142776, 5.022022339605517, 0.22521566179010177, 21.949059847862493, 51.2370547171562, 44.34964333811114, 58.11073780059815, 63.94220006081366, 54.30145348272016, 43.26725352195002, 46.60201341875138, 51.71889043623402, 42.28991262374386, 42.6116568042386, 21.276718531885457, 22.798068638770815, 14.01119557119185, 9.972225100763383, 14.10211120882342, 30.36511301994324, 64.77458584693171, 68.67665383123583, 62.403924926634765, 60.88763859964187, 57.008257604414425, 55.53678435664023, 57.747110551403416, 60.24891984078192, 58.06201411831764, 57.080021289087114, 52.99622204995925, 53.433095639751805, 57.35403022458477, 57.888735571215236, 55.31779058517949, 51.71882767831126, 44.68559434337001, 43.86654069346767, 25.831521864860292, 8.759863626572395, 1.600945293903351, 3.3121359107955812, 15.329549293364249, 26.706077052700905, 20.546934104734852, 10.565964079672291, 0.5232996457526761, 0.1294859582858701, 0.10721652543232327, 0.05535501596187392, 0.22853459982622057, 0.049872637966707836, 0.12023629695777932, 0.004644438205662394, 0.07548389956355095, 0.04879062687377295, 0.05740062010684802, 0.06203741706427067, 0.022344130256603804, 0.09177536448283542, 0.10371996225008082, 0.2173809571972778, 0.03567727770836603, 0.23796848231746306, 2.329794235767857, 0.06635913354975563, 0.0260179910823823, 0.06205538948697429, 0.029501063456278176, 0.020097918327777617, 0.046020548700565295, 0.0820606877847064, 0.12673864441533245, 0.10276478850432944, 0.03662469098344445, 0.0468246384163297, 0.5401704953082147, 7.973211205774739, 12.094442113753288, 12.938290046107385, 20.025757012828706, 11.224547682269927, 2.107301464965267, 5.549808625252017, 10.859014161171453, 27.646800664163408, 44.8332166671753, 51.51794741230627, 53.212787874283336, 53.64932414024107, 54.069821834564216, 49.87246213420745, 51.72922588163807, 53.27722064910397, 53.584899210160785, 51.60277651202295, 53.884736953243134, 53.633089450097856, 59.63890106447282, 57.18161459892028, 60.87494580976425, 60.566753418214866, 58.22204682134814, 31.543473428295506, 12.176364737172282, 8.199753088335838, 4.963575591964107, 2.547737792614968, 5.259704734048536, 33.540940438547445, 49.97255709863479, 38.76688680341167, 49.30507167693108, 56.011308777716856, 46.09689058796052, 46.084107583568944, 48.274951365686235, 39.39455232312603, 35.35850794084611, 51.2794320044979, 16.301841120566092, 0.2273155700775885, 0.1494782790541649, 22.982390619093373, 41.27224583779612, 29.520379612522742, 14.950755219305716, 39.401224274789136, 28.406326463145597, 31.055206983320176, 30.016604546577703, 34.12069028423679, 36.06753126267464, 33.845712523306574, 23.663196409902266, 43.91572721542851, 39.743419693362334, 35.83614280146938, 38.25283273573845, 54.97976464609946, 64.58118161847516, 1.0411903430377285, 0.05797558824621862, 0.0450918241403997, 0.05056841817173747, 0.06014893755256649, 0.04801150396346085, 0.06779464442403087, 0.041292958832796545, 0.027049480591930693, 0.05932652684409292, 0.007183442714684193, 0.012997717769335837, 0.057866382412612445, 0.05652812640032461, 0.026067352042563503, 0.1065316045236203, 0.12990021267004553, 0.21771913905057216, 0.26322226430619916, 35.71073678232009, 91.05857664538969, 47.074204029575476, 32.460641245688166, 44.557532879614065, 30.984296414159964, 39.201532486946356, 36.31443662028159, 37.783466231438425, 44.639471192513746, 40.40151888324369, 34.56739725605134, 33.96794926735663, 29.494003634299006, 37.20762698881088, 37.15687151878111, 45.04633865048809, 8.86529693680425, 0.06693207538656651, 11.99526204216865, 55.40943676425565, 48.13511886904317, 55.396489020316835, 65.99316427784582, 54.75343604241648, 49.35681950661444, 57.51551420457902, 59.58435658485659, 44.14125957796651, 49.875937354180124, 30.314741942190356, 25.1914498882909, 14.68552552884625, 9.125517760553668, 12.72923654125583, 32.29158316889117, 65.0678143962737, 70.69714515439927, 64.91334361414756, 61.99801844935264, 59.45822492722542, 57.64834134809433, 60.97885724036925, 61.46184613627773, 59.50217508500623, 57.2944611887778, 53.37931602231918, 52.90421501282723, 58.079484355065134, 58.264090707225186, 56.12156660326066, 55.67111769030171, 47.80522792570053, 45.30768225269933, 31.034653763617243, 19.87980757990191, 5.987797148766057, 7.855954400954708, 12.715540605206645, 23.3332525145623, 25.28623788587509, 6.160776124846551, 0.35302342786904306, 0.1672059519877357, 0.11968059209926475, 0.06403154010073313, 0.08835331867298774, 0.03629217818078976, 0.06406088509867269, 0.07143307176809158, 0.12226901167342741, 0.08593009829881691, 0.05327603336603892, 0.08289830533847695, 0.06571820140966485, 0.026372356543077097, 0.13407372178569918, 0.1154890416129943, 0.027623548577990265, 0.3592949913394067, 1.0272626194261736, 0.04495895768125211, 0.06564367637639085, 0.04907415984498878, 0.0468558143644083, 0.01592023690576635, 0.004482745294338994, 0.08068431889818561, 0.01228927317330794, 0.1700785518774102, 0.025388601972090623, 0.07039199658339063, 0.4405444992646095, 4.868879279782695, 15.128201284716207, 11.5563468587014, 19.829397278447306, 13.762855606694377, 6.507086109730506, 13.632455429723187, 22.903376433157153, 28.639660419956332, 46.92383996901974, 53.52023109312981, 53.93202112567041, 54.8302399727606, 56.60314344590711, 53.84228121849799, 52.816542194735625, 53.496292867968165, 55.24235948439568, 54.88851854878088, 57.60291245675857, 55.93932544031451, 62.16551934519122, 59.53542109458678, 60.663400619260734, 60.41970376045474, 56.74056760726437, 29.577948239541826, 11.686363623988244, 6.404934842740336, 4.267501484963202, 3.6119736538779352, 9.34576374869193, 39.96141326042914, 55.315280268269206, 39.64681956075853, 55.30186183990971, 60.76198547117172, 49.295148080395116, 52.23000664864817, 55.0862491515375, 44.4233250617981, 43.136438554333104, 52.682295153217936, 7.941180150355063, 0.3402864500399559, 2.371735404576025, 38.661037721941554, 37.67413016288511, 36.50172587363951, 21.773545549761867, 36.45042519415579, 26.315405061168057, 32.63650463473412, 31.174931449274865, 33.22172618681385, 29.588913225358535, 35.42076380022111, 27.829061438960416, 29.96199142548346, 41.568929995259936, 29.66695074112185, 36.47859957910354, 63.81668029292938, 72.73561662243259, 2.100451045459317, 0.1044698397538835, 0.09648164944542993, 0.10554271524832134, 0.04369638349500395, 0.029496694839889967, 0.0790120485509115, 0.09465610788714501, 0.15499025102584593, 0.20972838234757224, 0.12447672385361888, 0.26180978203492783, 0.1578164719525845, 0.12303742084411845, 0.22292951752822246, 0.2856238090222882, 0.27127718853373683, 0.2630915697063169, 0.4059495007799518, 46.40024277471727, 101.88077249834615, 61.73958916817943, 40.06934904283093, 69.35578869235131, 42.86326116131198, 35.97897591129426, 57.0884818415488, 48.75429245733446, 63.33226365427818, 57.10853692023986, 43.72104821666595, 64.38163103595858, 35.27112145577708, 42.90713287168934, 50.737250620319, 40.457153781767815, 9.074561269052568, 0.37491481931459525, 28.506984287692656, 61.26366446095129, 54.513390910240915, 63.04633071345668, 72.37572346964191, 59.307413716470045, 57.519605236668745, 61.11730121797132, 67.0205036286385, 53.22391171609202, 52.53128782395394, 27.50474810600281, 26.87466052270705, 18.003600643527125, 16.170299533874758, 16.341266824353127, 37.763089518393244, 69.01309121039607, 75.20285021874213, 66.70125407557335, 64.72514829327984, 61.90772156561575, 61.961485493567686, 62.18994394425423, 67.34309504109045, 62.3919185515373, 63.45572810019217, 55.63964066966888, 58.75636777570171, 62.5016664689587, 63.10526040292556, 57.70381150707122, 65.50287977341684, 52.01084421527002, 57.763498213983354, 35.1350309002784, 19.235670066648915, 4.681245348145885, 5.8640983412342695, 28.9877256654924, 30.029942566348662, 30.667013929736232, 14.965270930720916, 0.5138166110602118, 0.4362472056621506, 0.23036616283559033, 0.2699701506043634, 0.3125602878149479, 0.21175099236349906, 0.3311711375511462, 0.2024687952812641, 0.32372546772803035, 0.2167709826702072, 0.20329632345707188, 0.17586455349960636, 0.1917617206251429, 0.15863776417268863, 0.30780159477745334, 0.34714407077239406, 0.08307057553000989, 0.368456544895326, 5.497986760831648, 0.13606054017380362, 0.1976197957992554, 0.227503476123656, 0.10289588913081155, 0.12698142533941617, 0.1080783207209841, 0.18283094339553388, 0.21702111037748478, 0.32315402742355104, 0.14290191984224704, 0.27506947697651, 1.0440225394502765, 15.114470047335471, 20.52686333656311, 17.84378759322628, 42.77763189808015, 19.649435012571274, 3.9667552228896854, 12.409228009562339, 22.27432043321671, 36.35313472440166, 51.61707355130104, 55.60208789763912, 56.880235364360196, 57.482593751722774, 59.41216061192175, 55.65703245901293, 54.58528011075912, 56.56240570929743, 58.8447662322752, 57.84684858014507, 56.90536206768405, 58.29731318258471, 64.28496422306185, 59.979351028319336, 62.59621520196239, 61.984784372391246, 58.56776845070624, 36.53256747030443, 17.161101025919763, 9.883109831040906, 7.6321253276640375, 4.633325261454429, 9.397238973648319, 41.19691279626662, 58.287554325595984, 47.301446545508604, 57.952117150829686, 65.82993876549506, 56.56146434045608, 56.53817722874304, 60.07270736079062, 49.2061024327432, 45.108582742752574, 64.36210939961096, 22.824458345290154, 0.585564146599462, 0.932889412487707, 28.349359919947965, 50.02372049516248, 39.34030202127273, 20.85458128683029, 53.05564988044001, 39.7929003930861, 42.66939017080492, 40.48511243635609, 44.10889610167473, 49.10359521065989, 46.29701775889243, 30.86138894481044, 60.605282860417525, 53.75890731811524, 46.58688091462659, 50.84595518727457, 68.85301928366385, 85.6336876653856, 3.3601091946325, 0.28815202174648163, 0.1800367143005133, 0.26913676951681414, 0.14041340579428982, 0.1758761061055045, 0.17322348070240792], [0.019185402272869984, 0.05660518335418836, 0.01424387660658648, 0.06661151355553059, 0.08231556523711452, 0.006853102728904736, 0.025557794405387777, 0.04791813316724954, 0.051235098526963306, 0.1341818780788491, 0.13982624536560428, 0.21816609006735588, 13.813133528155666, 82.20384167086694, 52.07334718396587, 38.24878877209079, 42.23720773573845, 64.40380419454267, 21.426872745636974, 38.181818223768666, 51.27634117680212, 37.16776001837946, 46.839003024562714, 34.94505482335245, 39.67464485476094, 38.01975373298892, 27.83088730227563, 27.981863252578247, 33.251728396261896, 29.384902907956032, 0.03272976208057615, 1.1898272124028977, 27.64790088899674, 69.31611784042852, 40.78685252897201, 47.561287879943855, 35.651862006033625, 59.783475706654215, 55.6266733138792, 55.28527021408082, 44.83749989540347, 55.99204994017079, 42.53349965618503, 27.050053227332334, 11.226014648714374, 1.764268865508418, 3.987922293524589, 18.132144558814264, 54.066150496082926, 67.93228210941439, 61.91151057520221, 64.75324030845397, 57.90195395869594, 56.96547631294497, 57.67015757099275, 60.98016338963663, 57.670930277916696, 57.13370284726543, 53.333024209545506, 57.263039081327385, 55.35125232511952, 57.81210814752887, 57.16659976590065, 48.047924580112586, 45.14919104114656, 27.5550191633163, 7.820760934583603, 4.584607462729178, 10.891102090958627, 25.614350034344582, 13.744412622144146, 12.891257885963688, 10.772277808958485, 2.8155339389078082, 0.39353268641617994, 0.12452895572829632, 0.1684769071758755, 0.060416221798908334, 0.09809447903065913, 0.060660891129725406, 0.09732052338339629, 0.03601742840762581, 0.07734730118705381, 0.036862737484156125, 0.034430783707648516, 0.05485588669656746, 0.0988139428438679, 0.03781519927865556, 0.09454262728292136, 0.044250632786462386, 0.08285209491488435, 0.22075782680223066, 1.1436339491798033, 0.01333247616721858, 0.11977298996381222, 0.07437494898875875, 0.03827673660951757, 0.20317987809258126, 0.025455109895237034, 0.11958585000566899, 0.07824417564176744, 0.04970018008363344, 0.11575872754497875, 0.02351498839655711, 0.2816482723480271, 1.9711764661535143, 11.871044501181572, 14.363190051048035, 16.180782068160273, 22.93892095165868, 15.545083534333015, 5.932433384080087, 6.157754919221325, 20.924715226696385, 33.69400701215191, 51.21283800371232, 53.50603211310602, 54.837508124689904, 56.72416033283357, 53.68981476752989, 54.78530137769638, 53.30254739330661, 55.25861770875993, 53.537085517760254, 56.34612621799592, 58.992529761406686, 60.00086522871449, 58.14023010192379, 62.018787399415054, 56.97805143171742, 50.546682265497026, 13.593278796442094, 4.225022215997019, 1.7380541947580155, 1.1614421226324574, 5.078403959351202, 21.06884664104831, 49.2453065226155, 48.449222272442235, 45.494955816576564, 43.58180407554873, 50.69940367052632, 54.90590249338458, 50.31957703251993, 62.79152962469286, 45.35076164430188, 52.98654556274415, 14.204679227644398, 1.0627647273002132, 1.184693933013947, 49.844221068966775, 30.52604590692828, 35.90093251197569, 23.735836744308475, 22.205335747811105, 39.83192797630064, 25.817450361867106, 30.730497490975168, 34.097226665865996, 32.738825544234246, 40.94091146223007, 27.011317860695627, 30.87319135665894, 36.56442496084398, 35.01799129670666, 28.65903496742249, 46.55388985910724, 62.015488686100134, 35.95275094432216, 0.35675908709245346, 0.10776494479467792, 0.02747456745935544, 0.06089195856944688, 0.06989506599042686, 0.10731889776164487, 0.0692056021803329, 0.009997860141729396, 0.001955347256772521, 0.0058492091428037855, 0.030135150600765503, 0.03746507794506127, 0.047774606594635595, 0.03417604415106677, 0.11306032072752716, 0.08860939122255772, 0.18063285327967138, 0.1480587794175071, 0.3570788828355651, 17.396772715353197, 96.73685858326574, 59.72143950000886, 35.854691690014256, 53.453919502996634, 40.84235406691029, 33.06689454663184, 39.265518111567346, 38.42202809549148, 39.17875528335571, 44.735937964531686, 38.92142818820092, 41.35655718465006, 37.82247812517228, 31.92982885145372, 25.817215019656768, 40.759160595555464, 41.00507751587899, 1.7320929275405024, 0.7366534166278378, 21.258330460517637, 75.17633499637728, 51.940257241649014, 47.93595267880348, 40.05756232046312, 66.05693417210733, 60.21231628233387, 59.34049498650336, 48.3881470464891, 61.33815027052357, 50.01496968730804, 34.14666421951787, 12.979909335413288, 2.255828875687815, 3.2029420281610186, 16.931407028628936, 52.5004776062504, 70.5532020138156, 64.61220756653817, 65.44309108488022, 61.42796470272926, 59.656736081646336, 59.19122918959587, 62.10292223961123, 59.915510531394716, 58.84937501722767, 56.825612437340524, 59.499456882476814, 56.60479476374965, 58.08576406971101, 55.90382014551471, 52.299201180858, 45.19134867575861, 34.01923033498949, 16.886435093418246, 6.241872108751728, 12.216463127443868, 12.913661483795414, 8.545843420490142, 16.620637639876335, 14.699476418956635, 1.563712440190777, 0.13384194954508735, 0.09861024772568096, 0.03862013169113667, 0.12093315351634257, 0.08826748618195135, 0.035770840026558406, 0.0304349648555921, 0.06694401103642679, 0.09819325074673661, 0.042265254643655596, 0.11601417190245084, 0.06504088775405, 0.08349930897595421, 0.018669493766801975, 0.12479263553095442, 0.03497032028052115, 0.06850448617291066, 0.1604056499537922, 0.6267680323893025, 0.07578949969742568, 0.050721049699331486, 0.0248767001058666, 0.047546492423862226, 0.198240403626715, 0.11018978927524821, 0.07890277376939213, 0.07837825635027501, 0.049473253349142696, 0.09759099838594276, 0.010058301606125409, 0.1793263056465695, 0.8590790473165051, 9.835274565604426, 17.8402143139993, 9.47154631537776, 14.121441629625137, 12.152273539573917, 7.3296046833838195, 13.550946616357374, 29.78299798503999, 33.32255071209323, 53.18600593074676, 52.60170221328736, 57.35728971419796, 56.155044032681374, 54.704061246687374, 55.253310741916785, 55.60980319976807, 55.318724109280495, 55.07976155127249, 56.18389698766894, 58.57333429398076, 59.13892438334804, 58.671342557476414, 61.38359485134002, 57.96727711154569, 47.25560580530475, 13.213237408668766, 4.729719959920453, 1.0914726771654621, 3.3134114165459914, 10.584729679169195, 26.431338556351204, 56.525492283605764, 53.92950296401978, 45.48613832842919, 44.82735272376768, 55.28214408505348, 59.18342759532314, 56.392084629304954, 66.42743341384396, 49.819117899863954, 47.901447588397616, 7.52676114920647, 1.2561801099969496, 6.247101118487697, 62.225519841717144, 30.59997081756592, 29.877925226765296, 34.393338157284646, 22.85136776585733, 37.57632978500859, 24.497945424049135, 28.356110319014523, 33.63316712840911, 32.229499893803755, 30.00850485217187, 35.26262560198384, 25.719218523271625, 34.4479218606026, 40.211444747063425, 21.656747171955725, 44.16617447330106, 71.68955187643729, 43.820821546739154, 0.35024314157424435, 0.07258843961021594, 0.10126366986021881, 0.028932214444202763, 0.07485903994811159, 0.10439845568109905, 0.027706751472226558, 0.11498032092687585, 0.20806765694531704, 0.11854370229787405, 0.15321076667356878, 0.19101034158900862, 0.14597681290920705, 0.17690379773416828, 0.22841447723969338, 0.2181085721860009, 0.31569193267533857, 0.3728291602625001, 0.8112311567510329, 25.26320965059342, 110.59961303587883, 73.84160733992054, 50.61661420329925, 58.45437665139475, 81.65006576045867, 28.111617219063547, 53.676663060342115, 66.4501125581803, 50.07648421872047, 64.3145977297137, 46.5354900206289, 52.34295914250036, 48.49711833461639, 35.10479727099019, 41.66269425422915, 38.67390701847692, 39.61922568659629, 0.8299562455184999, 2.773417244034429, 33.52150509434362, 84.35838391703945, 50.230892242923865, 57.820380426222286, 45.38758877784976, 67.33910206825503, 65.63258863264515, 69.92830568744291, 58.79569738141952, 65.87175123153195, 52.49033827935496, 33.01505650243452, 12.777232623869374, 2.855666404770267, 5.572566707288066, 21.562121952733687, 56.854151602714296, 73.19014872274091, 67.33508556119858, 70.84682280017485, 64.7022141948823, 63.76217895938505, 62.84708607581354, 68.1957555586292, 62.71404712430893, 62.34061394968341, 57.76724799986809, 64.1785385531764, 57.861659449915734, 60.301365852355964, 62.06580877304078, 54.69727946865944, 57.08526157563733, 43.816134314383234, 15.97242380342176, 5.3569804949145166, 16.8525791552759, 33.64731119525048, 20.174224607406124, 17.455416071799494, 20.421855603494954, 4.793357474188651, 0.33976615376530156, 0.19798290615360584, 0.22012116177187813, 0.1907654692448916, 0.28056848674051227, 0.3168219736506862, 0.348207799177016, 0.243484836312071, 0.15034020457777286, 0.12737016899571305, 0.17862262324460093, 0.23058535591248544, 0.30467761079630545, 0.13159613215154217, 0.14353391173626148, 0.08432700569110532, 0.21577825529440758, 0.46545357233093637, 2.921886799796935, 0.1570228355065469, 0.17713245965780752, 0.1943900610410398, 0.13458503950988093, 0.2471642800035977, 0.14454542358796443, 0.2060909662395716, 0.13544927861902023, 0.18647442691989485, 0.3780342374117144, 0.09947119265674584, 0.897152330125532, 3.3034596279744184, 21.778334763742265, 22.003163060834332, 22.490723479178644, 36.945777400847405, 21.48657906439997, 6.999478888127112, 13.28449804936686, 34.990864184594926, 42.0847765861019, 60.3683913138605, 54.68390418637184, 59.37678475533763, 58.14134013268256, 58.712523521915564, 57.51933067075668, 57.93318387000792, 59.96155523484754, 57.21889280503797, 60.097269242809666, 64.42440448268768, 63.394260637221805, 62.19831035983179, 64.24675249284314, 58.2667383070915, 52.21957314398981, 17.851469555208762, 7.12385626569871, 2.6541796422773793, 3.175459941548686, 9.408073540656797, 28.269304344730994, 59.8035974656382, 56.03674534828433, 54.76238296877954, 54.2850422859192, 58.96473192399549, 65.23832767240464, 57.600151108157256, 70.84969397514098, 55.01027284129974, 64.40419643155991, 19.305666723558982, 1.7664843917854371, 2.318956236685476, 58.915212000569994, 36.70772875508955, 44.00151337346723, 32.63331574778403, 30.31442815257657, 55.28251671021985, 33.99148348839053, 40.6778851632149, 44.54861340984222, 46.09249361099736, 53.509538712040076, 39.04903857938705, 39.03734599390338, 53.757134406797356, 47.10376301119405, 39.400475102086226, 59.03950406659035, 77.1298243922572, 57.00664158790343, 0.47189848617680613, 0.1331050342489635, 0.17064565612423807, 0.14638424911085637, 0.1614144651760017, 0.2867299480543983, 0.20653747292535923], [0.03811899910590822, 0.10510701040226607, 0.062103086121139996, 0.07893475794023083, 0.025741992585901773, 0.08077623412734078, 0.011444039747960145, 0.05764304096960734, 0.05454795765540293, 0.0899500527509278, 0.1449135441573397, 0.28796356411710866, 5.7556580439690626, 78.3556592079901, 59.99080434922249, 45.33480152007073, 20.554833758261896, 64.82727112308626, 37.64360235583398, 30.26722046636766, 49.62868682799801, 37.25623692235639, 42.62419269930932, 37.49199490393362, 27.224896800133493, 52.26253486448719, 22.26106478321937, 35.9943006115575, 19.689658918688377, 61.3519177898284, 11.57753550237225, 0.21597857196484843, 2.8070809860383314, 32.13551598210489, 74.61752276266776, 64.69243180367255, 53.12660555685721, 58.55749184085477, 59.19655969066005, 48.22177579326015, 64.02342057997181, 42.779997087294056, 48.28790303199522, 36.78294020314371, 23.09126384796635, 9.475313751928269, 0.8585663199905427, 8.827616687743895, 45.446141919782086, 71.00804790373772, 63.821249854180124, 61.84566966948971, 60.575221815416896, 59.23176296295659, 61.42492878821589, 61.228853425671986, 59.69320627950854, 60.31904397472259, 59.23402224817584, 56.891284681135616, 60.129770002057484, 55.06401323503064, 51.990549871998454, 50.784687765182994, 27.379369543444728, 7.180056475823926, 2.6842914329421137, 11.576171498144827, 16.032012451079584, 12.322526958680923, 4.7378691742497105, 14.225773734431113, 8.716388075582444, 1.3983801247612124, 0.1420037890033376, 0.05296128997278791, 0.06594598999307041, 0.10771680382951614, 0.06516376825710458, 0.134557307127022, 0.20679011340102843, 0.09649183841482287, 0.04537886579430873, 0.08101749819733443, 0.018637341056619922, 0.045123831293876135, 0.0340694162033258, 0.09406770639602216, 0.07315888400039366, 0.02320465000887071, 0.4908741776260638, 0.16077358666206562, 0.7054307984728968, 0.029052534298370444, 0.21537500193282483, 0.05126414858105202, 0.12433591689313613, 0.17642194375155434, 0.16022909733076252, 0.1389083494582484, 0.08131359118006884, 0.03375387990907316, 0.03737668288991817, 0.1426150352363625, 0.13743234317629568, 1.5180891463833472, 3.142742226200719, 11.237264006368576, 6.2201838531801785, 13.826840250722825, 20.365128324877833, 13.776495648968606, 4.757642332584628, 5.25072495783529, 20.296518225823682, 38.878027162244244, 57.802361057650664, 54.11534878515429, 60.163980914700424, 57.563625997112645, 53.95649671554566, 55.846753581877685, 57.94204058185701, 55.94418133458784, 57.59465586754584, 56.15240819992558, 58.29642280455559, 57.054345453939135, 59.57252671641689, 55.68084516832906, 29.419925751224643, 2.289679910867445, 0.9332560928117846, 1.3063044461511797, 6.5575645623668555, 34.12603255241148, 47.968092579995435, 49.46817167343632, 53.426659030299035, 43.496084597802934, 42.494927067910474, 51.55729662987494, 47.10383361385715, 45.92255300091159, 46.988492396570024, 39.635205422678304, 5.222491247038688, 0.9116601968003858, 0.42068357789708727, 39.61210658473354, 46.014822836845156, 28.739280777592814, 63.37386431232576, 11.505365852386722, 35.546679727492794, 32.192256989017615, 31.583440419166322, 27.759602146763957, 36.6039232284792, 32.646608660298014, 39.81767800546462, 22.933113882618567, 43.84714457296556, 29.760024662940737, 27.718827147637647, 42.491326332092285, 52.33426324782833, 74.18027262533866, 13.85854280764057, 0.48732106183325097, 0.3001843825463326, 0.07616168819367886, 0.06808243301366607, 0.10806204901347238, 0.08132335114022417, 0.022693483587053996, 0.027546393947916168, 0.05109241848150569, 0.05314210970555583, 0.061696825864454435, 0.01565703207762131, 0.10566683681381327, 0.021596001348488277, 0.0107488839045888, 0.10332351174926567, 0.11976510691907137, 0.1293611625630048, 0.4146868867739555, 7.592226487974967, 89.27781274241786, 71.14447578307121, 41.07816696166992, 30.442234662271318, 47.66579158844487, 35.62620186036633, 41.44325333256876, 37.94161227441604, 38.06243304283389, 41.48185337743452, 38.910931925619806, 32.26730958107979, 47.34795016627158, 28.050969531459195, 30.780839150951756, 17.045371493985577, 74.80563963613203, 23.76233039363738, 1.7210624871715423, 0.8078432095146949, 22.029931276075303, 67.98073122578283, 71.85302842047908, 57.92783767946305, 64.46977453847086, 67.5120158349314, 54.46220005712202, 69.96846291326708, 48.239689257837114, 49.24857777933921, 45.75138468896189, 29.916864556650964, 13.664681623058936, 1.5968575713134583, 7.938502642416186, 43.432714785299, 71.06788758308657, 65.62492824369862, 63.86185030783377, 63.58043201508061, 60.0407047425547, 61.55145268286429, 64.92642079630207, 63.58715103518579, 62.07891341178649, 61.34084493883195, 59.47507542948569, 60.06365453043292, 53.86306193567092, 55.74040243702551, 50.732449639228086, 29.371327584789647, 15.739418345112956, 3.1967108528460226, 9.064503331338207, 10.311463052226651, 10.452867438716273, 9.923292552271198, 22.45235681533814, 8.950956598404916, 0.7168933737181848, 0.1531202304026773, 0.05450482690526594, 0.10229452543200986, 0.044210309748567884, 0.04490356569388702, 0.14807213999090657, 0.19550982111644363, 0.12655302131127927, 0.11140560911547755, 0.1037781083235337, 0.034242418008826436, 0.07835392539779987, 0.02559494392405595, 0.0880064647043905, 0.1344517708545731, 0.037735242681998404, 0.9061474893842975, 0.02836689326701866, 0.1719331588115423, 0.2986421556242051, 0.03896657963313403, 0.06163043285449667, 0.013709613591462616, 0.09175166172245819, 0.0307974565939437, 0.06986734892932639, 0.1139340363442898, 0.0984193462758295, 0.03637272849558823, 0.11451241740536307, 0.02789331494920677, 0.928246122935126, 4.752606009283374, 12.734817093418492, 7.866465372423972, 6.838550413808515, 8.794999237983458, 10.24917483329773, 5.7243624329566964, 10.597493071709911, 23.175451640159856, 39.106242425980106, 57.34329469742314, 53.55101385424214, 58.515094941662205, 57.148549018367646, 54.35582930041898, 54.801704729757006, 57.84533846762873, 56.278445720672615, 58.45207814247378, 54.489252644200484, 58.23777160336895, 58.96845817565919, 59.02689756885652, 53.61075939670686, 25.470063686370853, 0.49050878432969897, 1.3600917857500816, 3.0080218036328596, 12.489466955584865, 40.22469843587568, 52.69726684016567, 53.02008967245779, 58.376262649413086, 49.77476766032558, 48.847425214705936, 54.23292575343963, 49.48386899886593, 49.83432885139219, 50.05920225574125, 31.157286667054702, 1.0555563915160395, 2.4634820943878544, 3.4533419724433654, 48.3222355381135, 52.884916951579434, 37.316633578269716, 61.31897380275112, 18.213318009530347, 35.576148494597405, 30.967928363430886, 30.55071173175689, 27.959223331943637, 37.05874558418028, 27.423657025060347, 35.37446414270709, 27.16190745753627, 26.360373074008574, 35.99424569837509, 28.788284909340646, 33.17877231105682, 59.659320923589895, 81.69690670505648, 18.46532440954639, 0.7146852018852389, 0.35649227399018507, 0.04819139289940077, 0.08064703339891088, 0.0793644106916843, 0.09411331161015457, 0.07676612390505691, 0.2052887036435066, 0.3039954861085261, 0.18797401338815692, 0.23950874805450442, 0.10624431389113588, 0.22796787862335482, 0.21245380142523398, 0.16027291756003134, 0.19756267628362104, 0.4666103957401168, 0.40901596687974473, 0.8618981895908233, 10.428080020412322, 100.88731458110195, 83.99313280659338, 60.39064291984805, 32.03464242719835, 86.50476763325354, 49.9992056815855, 41.4492545589324, 68.72598940326323, 51.281859951634566, 57.764941646206765, 49.736893253941695, 35.73404742825416, 64.29854739096858, 28.020175003236343, 51.38981534588722, 24.735021322004258, 72.05320265985304, 17.681556401714204, 0.9304193611587248, 4.894181509171763, 38.15826046851374, 84.59201597398328, 76.23885016287528, 66.88087509524438, 70.02897724028557, 69.10968349825951, 59.906614595843905, 74.33717527697164, 56.02463306919221, 63.253886853494954, 44.72049167079311, 27.354384045447073, 11.89002190866778, 1.3799366499147108, 11.902256761827777, 46.419168210798695, 74.22029649057697, 68.5591317761329, 67.17257392021918, 65.60021731161302, 61.61140611094814, 65.95128120914583, 69.30589614375945, 66.90602533278927, 67.67077769002607, 65.92817844883089, 62.49570054392662, 62.893166080597915, 61.00364269748811, 58.69418644135999, 63.66026401519776, 36.61016371942336, 13.263380988951653, 2.255534452776755, 12.68679649599137, 19.13151937146341, 16.187575613298726, 10.651284456253054, 23.84523557078454, 14.304644753856046, 2.6843360499028237, 0.21333702419313694, 0.18878833420815008, 0.21799863856886664, 0.2433110875708442, 0.3327357342406627, 0.5113016976223839, 0.36794602390258546, 0.2038597504818632, 0.2636329180771305, 0.3228201356626326, 0.12579598088538455, 0.1248437106128662, 0.11176789209486977, 0.28943212402443735, 0.16581700393749824, 0.09023468505831496, 1.043708749836491, 0.40097648698476057, 1.7716871706708786, 0.9134715350885546, 0.35367141567891647, 0.09402793877187277, 0.22424818467228647, 0.2000418900241775, 0.37731898708208916, 0.42462154561954163, 0.283039978314792, 0.30958829567797724, 0.20869837713337716, 0.569490273633311, 0.32620740874159726, 3.3288128481757258, 9.347059111441336, 19.20438131978435, 12.997376630383155, 21.053253258428267, 29.679771008030063, 16.720909110961422, 5.302715974469339, 10.300653980624292, 30.910222453455773, 50.35037156074278, 58.890144132798724, 57.777312801730254, 64.21159628898867, 59.66618899376162, 56.259637955696356, 58.78058056677542, 61.45915539033952, 60.00047691406743, 60.5668200985078, 58.9411114108178, 60.543023078672356, 59.46224535665205, 61.845285277212824, 56.136848157452, 32.67648731508563, 4.410443930856643, 2.589634344462426, 2.5319183834137458, 11.958611415278527, 44.497893241144, 55.653604307482325, 57.9314580271321, 62.46741241024387, 54.480513603456565, 51.42565796452185, 60.444187195070334, 54.42827547750166, 55.56512740350539, 54.478485738077474, 47.73984201492802, 7.331459474179053, 2.287563301863209, 1.3886072943287513, 49.44954041511782, 54.63116791940505, 36.12414283137168, 74.02100086212158, 17.571586870378066, 47.81095066378194, 44.67909889836466, 40.97549107766921, 38.68957296494515, 47.102962847678896, 42.09124849688622, 52.005949097294966, 33.005093682196836, 55.801403137945364, 43.78178611878426, 33.39167464163996, 56.14949780125772, 67.58377167486375, 92.12836388618716, 23.823997897486535, 0.8685488133661209, 0.45043463308003645, 0.24558025532432143, 0.13900164364566728, 0.2433976248627709, 0.1492382790292463, 0.08199655856456488], [0.030114619444394787, 0.07638098086200415, 0.06673171275085019, 0.11889838568505742, 0.04679795940436664, 0.0709367310628295, 0.04329003130776748, 0.06798706272797239, 0.07819464039658347, 0.05244629885700922, 0.07349745655852942, 0.19355934593946705, 0.1837870364467944, 56.899043129336455, 75.36510298329016, 46.26237930790071, 33.292615182938114, 44.37599382092876, 62.2860812371777, 28.610905524223085, 42.852572702592425, 42.49967313581898, 39.35263787546466, 43.15980019107942, 29.441849839302805, 41.02604258445002, 29.87744473641919, 21.30325140491609, 22.5696905966728, 21.120333633115216, 49.77641113342778, 2.1824077444691814, 0.6687888130545617, 0.343560342106127, 9.67431422202818, 46.896210793525945, 74.20675646874213, 39.404813243496804, 49.78608762064288, 58.58534459144839, 57.363251716859885, 52.403053775910415, 45.72931351200227, 63.55440316661712, 49.705765324254195, 36.93035464132986, 8.928407872876814, 1.3165853460950236, 25.599172422962805, 59.223474994782485, 63.8438230945218, 62.974374832645545, 64.0007100566741, 59.27190842167024, 59.08010844261416, 58.2550064979061, 57.239881407830026, 56.5913135774674, 62.81520112868279, 64.28154783864176, 55.54395052694506, 58.77899200685563, 53.49230381750292, 20.042576136127597, 5.74531965678738, 2.4893376231193542, 9.078922944684184, 10.132701031623348, 11.746341566885672, 5.995026076993635, 0.7780203259279652, 17.037964097915157, 4.666934090275919, 0.6257092988779468, 0.17973790936652692, 0.044444288322401625, 0.1445190548416107, 0.03844876165291475, 0.014747535366745246, 0.08661893391681295, 0.09374557408474146, 0.0178299016214066, 0.02911643943779411, 0.08992419728348333, 0.15984758554447084, 0.10546165548505322, 0.10402262060632629, 0.11623085987183357, 0.04195026610226881, 0.018569084537786343, 0.9663814282225025, 0.12252650914653657, 0.10269880535141115, 0.02566126607088072, 0.13623019800551478, 0.021722227740552158, 0.04218152506397136, 0.14525676686917582, 0.1650157372557348, 0.19030615356901, 0.0907395906265705, 0.04778565741294334, 0.10310349129741231, 0.0651149301519317, 0.4361291361912605, 0.1997850820302002, 0.6349982681774324, 10.499731917535106, 2.2332129795705122, 4.938456243084324, 12.870334982872011, 12.834297226321313, 9.242040591855204, 3.076147980267002, 3.6942586062415956, 19.70405205603569, 41.972561497842115, 52.5160768724257, 47.98992841474472, 54.487715075092936, 58.90880284770843, 59.84470782741424, 56.178821440665956, 59.94047641754151, 56.43415204940304, 58.0248849622665, 58.06000586478942, 63.45283731337517, 55.54725316263015, 34.544467080023985, 4.134903800102973, 0.25457015921992643, 4.749261698415203, 8.623769148703545, 35.85483289534046, 37.73420910681448, 44.027608902223655, 54.20071524958457, 46.01958851660452, 52.17937669446392, 55.38818536266204, 49.67256246074554, 53.4187162307001, 49.783208600936405, 31.117882536303615, 3.232197516387509, 0.5447331311241274, 0.5974097045198564, 23.103931142437844, 50.84304871097688, 20.076159469542965, 55.88044674165788, 55.01403047192482, 20.321227196724188, 32.425896890701786, 30.67173254105353, 27.9363892539855, 29.484180058202437, 35.19796140732304, 37.208991973630845, 29.152069053342267, 33.19201423275855, 41.38254288704165, 25.544143530630297, 38.45607426858718, 44.788956642150886, 58.304098882982814, 63.95066453564552, 1.8959318005269574, 0.09657493597196956, 0.044496887919282725, 0.04436704750743605, 0.02307536884120876, 0.13147418627575522, 0.06452591579046942, 0.00579883981939225, 0.07217130473544521, 0.039757504127919674, 0.017276721022602533, 0.08838926351839498, 0.037219370565106796, 0.05307875423421783, 0.045282790707724715, 0.08528190364520397, 0.02911498387073798, 0.08909431721774802, 0.02071054351906623, 0.17504143799024244, 0.4649041340716424, 66.64361092352098, 89.20080092645462, 43.571892246123284, 34.90369735225555, 47.63872723425589, 36.51623079853673, 39.520836953193914, 39.45865954122236, 35.90868311543619, 42.35396885102795, 40.8358350876839, 31.696796917146255, 38.749679365465724, 29.983360498182236, 26.63865739299405, 11.602659263918477, 19.326151301783902, 58.72804826305759, 10.613631663783904, 2.8589793366770593, 0.3027514206065286, 4.24494001173204, 42.28427225543607, 77.03154548521965, 45.625225574739524, 53.576752447312884, 65.62703063411098, 64.49987088480304, 57.03933846565985, 49.719101382840066, 65.54288794917446, 56.25142451255553, 44.06698557638353, 13.295930777826618, 2.3195806289872816, 23.677205154972693, 57.84153376856158, 65.65861748110864, 67.41804369034307, 66.19264033532912, 64.18997618459886, 62.172465862766394, 59.85908723646595, 59.02598365660637, 59.69601469655191, 62.48343529239778, 63.240833205561486, 52.59072742154522, 64.48506001503237, 51.07490393423265, 21.164836845090313, 14.040845747916931, 4.707764983177185, 9.87985328320534, 9.643892318971696, 8.830550620632788, 14.692673067892752, 9.141683809218868, 23.524626916454686, 7.615999483293103, 0.4058711453070564, 0.18845009106782176, 0.06547308391741206, 0.13914787450865393, 0.0341721102895756, 0.2225127503756554, 0.07904912720644668, 0.9755381401027403, 0.8881750053936436, 0.5926698266017822, 1.0480981272074485, 0.22273224988772025, 0.3298453457893864, 0.2935641264963535, 0.2508112262453764, 0.10824350459921746, 0.0584093778724632, 1.8048723835137583, 0.3082169370064813, 0.2033258944509491, 0.09004638830740606, 0.06628514477802862, 0.05424526099476123, 0.06279497076907466, 0.46414383777206947, 1.085441420155187, 0.4424791470650704, 0.16540745333317788, 0.2676599665034202, 0.3977844437524196, 0.28790285930998866, 0.28437355352986243, 0.44007372291338065, 1.7230800563289275, 15.839970265665363, 5.795781439350498, 10.844856366034477, 13.837346319229374, 7.52536625631394, 10.31535698521522, 5.527439348159298, 9.337040397428698, 15.119072948732684, 37.7984183065353, 52.53438649639007, 48.562943550848196, 54.85966951616349, 57.344871490232414, 59.248915487720126, 58.03345926346318, 57.41987897503761, 58.01470641166934, 58.420142204530784, 59.14708683567663, 64.60139751434326, 55.52646852308705, 29.577952161912, 2.7718527086319464, 0.6196438437027316, 7.696031524289039, 14.293179665842365, 46.42984882477791, 42.38209616753363, 48.993957119603316, 58.60760796454645, 50.55992418719877, 56.18468538407357, 56.397842668717914, 53.46034826770906, 60.07725731019051, 54.58424460503363, 23.505958395619547, 1.5541641654506808, 1.493342177521798, 3.286389227836363, 29.770622907146333, 54.6465906789226, 34.539477825164795, 61.720251883229906, 62.614477757484686, 26.681534782532726, 30.67667864984082, 28.939456978151878, 29.266755234810617, 29.205148527699134, 34.785218238830566, 27.352548376206432, 34.69981255069856, 28.285935194261615, 34.21654124413767, 35.14888078935685, 26.560100163182906, 43.71188555994342, 67.788754740069, 68.48791722328433, 2.9734747928957788, 0.04629206558268878, 0.1699867745440814, 0.06611030819194932, 0.019445979419434746, 0.07182281899956927, 0.04783317018600722, 0.03296915306559494, 0.17474707636621692, 0.23924253250081695, 0.12752904030945034, 0.36340407246062834, 0.1823191353750806, 0.35138399971108286, 0.12069450946704996, 0.1824883029105202, 0.11970074021167333, 0.2731026228397124, 0.2483728296694256, 0.2732302224443805, 0.8191432515459677, 79.4627481891263, 96.95299686924105, 64.89133911748087, 47.699418067932136, 62.2680736357166, 78.11919519978186, 37.23773902462375, 60.89153743559315, 53.8855645733495, 54.337209809211, 59.71553633289953, 39.6096747152267, 56.29496674383841, 37.28390924392208, 28.207472101334606, 35.35383639797088, 29.327985394385557, 57.72919708682645, 5.668339219785506, 1.9055957851871368, 0.504113617202928, 13.390435384165857, 56.18974524159586, 82.71104335784912, 51.7742350793654, 57.45510970392535, 67.8693437576294, 67.30726811193651, 66.68943989661433, 58.643560409545906, 74.36118018242621, 58.7731162963375, 43.424983793689364, 10.180252905814879, 3.0373385788932925, 30.95220554259516, 61.505533495256984, 69.86394743765555, 69.45769186942809, 70.96604716393256, 65.8756971359253, 65.85062534578385, 63.05808605686311, 62.415531219974646, 61.96208561620405, 65.17956664485317, 70.64347928570163, 56.73206783110096, 65.59380815875146, 66.25112287459835, 27.926193052722564, 11.583697545912958, 5.761679862776111, 13.757991867680705, 10.564513783301077, 15.077048674706491, 16.606185666976437, 6.6258005653658225, 29.063213640643706, 9.696154959740179, 1.003270032665422, 0.3813973327557887, 0.21786420545991392, 0.21738795924090573, 0.09893797247880891, 0.6839200301516442, 0.35926894434998113, 0.3219575206598928, 0.7633441650579054, 0.5195778067554198, 0.6415369818287512, 0.2582845824860758, 0.1339196308606094, 0.19723779371669217, 0.2554451542035226, 0.15711519506669816, 0.21748781114095644, 3.1485213483533556, 0.36045389850774123, 0.2796433283196342, 0.24919398399370335, 0.3203450281533503, 0.12497682605058917, 0.296885454726796, 0.17406945627543235, 0.9068999103000088, 0.3816764339083626, 0.47325044750205936, 0.23271048381443948, 0.6382646219384286, 0.24665803378147466, 2.719970047473908, 0.7473903533912475, 1.0549489144356021, 17.670352151316983, 7.525285357429136, 12.828026337008323, 26.866294107129498, 17.070284428135043, 13.563704125342833, 4.0640667753834885, 8.181637131398725, 23.069186787451468, 46.20787012961603, 57.74147018309563, 53.21483142914311, 61.14281623594223, 64.59980895442348, 64.17004269938316, 60.85483974026096, 62.40922404873756, 61.50223870431224, 59.077711874438876, 61.10875829573601, 68.50130819505262, 59.662423518396196, 37.979059142451135, 7.163533981769317, 1.085107038097997, 8.120897758391596, 11.942146285887688, 46.28943973971952, 48.348276153687515, 52.66742152552451, 64.09438017875918, 53.27285112873201, 62.863410980470725, 65.23846103299049, 58.11200472616381, 63.38407031951412, 60.327806549687544, 34.885725052126, 5.990786485133633, 1.1304484115492914, 1.7206524769144675, 28.42561079609779, 61.456182233748905, 25.559132868243804, 59.86346852394843, 60.06818094561177, 31.159147831701468, 42.48484657656762, 43.468698609259825, 37.188540735552394, 40.18695739007766, 44.87243644652828, 49.16318778068789, 40.137351174508375, 44.12155751259097, 56.38958215713502, 34.983894132798724, 49.223192199583984, 60.33115233144453, 72.04018039088096, 82.17967987060547, 4.28670835110449, 0.4590552366308628, 0.2944579978864039, 0.16662240749405277, 0.1379601011473325, 0.25237913243472576, 0.20952674800590163, 0.15947830052145068], [0.0822154452062903, 0.13981365088012912, 0.07227553865842282, 0.02421225481215985, 0.027039209268085902, 0.11056992976415543, 0.041931562065597505, 0.0854127208191541, 0.016897915441903378, 0.0719008220720195, 0.3001205827439985, 0.18291081572251935, 0.3872569860710252, 19.622203957649972, 72.00882496372347, 64.90348669790453, 41.986411386920565, 30.26542009845857, 63.422752734153505, 39.30732273286389, 31.238499341472505, 50.216002925749756, 35.96152528639763, 43.767512613727206, 35.04953499763243, 37.48836278915405, 41.83660822529947, 15.29577180262535, 21.743070694708056, 28.505966432632942, 26.868369040950654, 35.87801802542902, 2.718000037054862, 0.8035412887411734, 0.23994198609744352, 4.9845102621663, 35.72760297406104, 74.31294287404707, 55.11007755033432, 54.84831425451464, 47.87004509279805, 52.355808827184866, 40.21269598314839, 53.06393392624394, 45.60549605277277, 46.41068412411598, 23.083030792974657, 3.265276089791329, 7.29379540489566, 34.556606815707305, 60.352815581906235, 62.48246646696522, 55.43661094480946, 58.34819416845999, 61.98860476093908, 62.888176825738725, 61.782150806919226, 63.3954648048647, 61.88390493392945, 56.78750661111648, 68.39049339294434, 47.24141467002131, 7.356684236757218, 7.2219900450398855, 4.386099250085892, 6.943313979333447, 8.392163976546257, 10.111885993711411, 16.89997119288291, 9.224909640127613, 4.633072758874586, 10.602835339884605, 2.860604178520941, 0.11359652864836878, 0.036517833209326195, 0.07598157326180129, 0.006508285117771236, 0.14294970840696367, 0.13703661279812937, 0.1180063988713007, 0.6441278911886678, 0.35993044595083884, 0.050645544073514404, 1.567799672484398, 0.5393807505888324, 0.17843148430749295, 0.2664372288892346, 0.02377963155477999, 0.17953302681205735, 0.521799523022867, 0.022996220467311722, 0.2296976438693462, 0.6643228881782102, 0.19702085293829444, 0.26219411302478085, 0.07828634878199908, 0.3525747148500335, 2.3438998143519125, 1.2773045248562291, 1.245416513373775, 0.6007470899531918, 0.825960330905453, 0.2979740656671986, 1.254280089370666, 0.7434595868952814, 0.3750548908306707, 1.9373832859339255, 12.099070510556622, 4.24239537408275, 5.39871157177033, 18.55475837184537, 18.355862825147568, 8.43943344008538, 9.95149733558778, 5.407827650347064, 2.0309169830814486, 10.138743442873801, 29.027090572541763, 38.56905421903057, 45.66258615063083, 42.74001244575747, 54.40543551598826, 56.64143362352925, 56.63021172246626, 53.32363797772316, 57.21006354978008, 52.54551033819876, 44.560564871757265, 26.51275911638814, 6.326392812113609, 0.09715946871907481, 2.1992785940247197, 12.259105174772202, 29.242124711313558, 41.63043275956185, 45.455877242549775, 47.51324669007332, 52.30523770855319, 49.71880328270697, 49.66206619816442, 43.18060444247338, 40.74829170780797, 31.926989055448967, 26.012254876475183, 2.8182889136575886, 1.2342160627726586, 0.16269898012040124, 9.090638083796348, 79.69893763142248, 37.82049732823526, 23.947576092135524, 7.624127124586414, 7.065688986932078, 22.671228993323542, 32.73626227532664, 31.690527008425807, 26.21226633748701, 26.88120303615447, 33.582921566501746, 37.82576114900651, 28.286011680479977, 40.57775097508585, 36.84177575572845, 34.63313225776919, 35.5692490454643, 47.640786478596354, 70.19162224185082, 36.05705068957421, 0.42036804160283464, 0.09496930761322861, 0.06476576259780316, 0.11602720305804284, 0.0895480634344201, 0.017866365491382537, 0.04233950388527686, 0.033303830066635724, 0.16642414393924898, 0.05682703092574112, 0.046668846776048024, 0.02973395801569906, 0.05218409377360537, 0.06901552044456044, 0.0668401908009283, 0.13033777144887757, 0.05245802766312996, 0.06919437133136296, 0.42034171882175636, 0.1987271912155613, 0.6452386573918405, 28.559245947868597, 90.39014985484462, 67.06623062010735, 34.779570025782434, 43.61422246502292, 40.46669298602689, 35.52609512882848, 37.954991479073804, 38.90987288567328, 38.45738434022473, 45.41047580780522, 34.758440217664166, 40.19297822829216, 38.219865214440134, 22.777674275059855, 24.129381871992543, 21.167766855609035, 25.931199096864272, 44.79767607104394, 9.210469434338233, 3.2736890835146752, 0.5004197250931494, 2.1902333632592232, 32.008238992383404, 77.14621989957749, 58.950168163545676, 58.80587593201668, 56.32269790095668, 58.996809067264685, 49.86335831303751, 59.06129283289756, 47.04076582385648, 50.72684457225185, 33.456307457339385, 7.944508281446273, 7.699003700287112, 35.72665768284952, 59.747962567114065, 64.60722223404916, 56.82136451044391, 58.69206051672659, 62.36685068376603, 63.466342033878455, 62.843657924282944, 64.97173201653266, 62.01579463097357, 60.06071275280368, 67.96319038637223, 38.496035375902736, 7.905528256970068, 14.050828180005475, 5.9281550588146334, 6.8794151371525185, 11.275643417912146, 10.145981196434269, 20.14597373624002, 19.18928803936128, 9.963236989513522, 14.93924698522014, 6.254674234697896, 0.2352511071630063, 0.030953443586646073, 0.1701433935593213, 0.0436688847689619, 0.41770983907964926, 0.06788012451462208, 0.6434400668067317, 0.672234921686111, 0.07343620016810394, 0.09423207056017653, 1.2982927599260885, 1.0867796838283539, 0.15496536849006531, 1.1151487163959013, 0.5904276404649981, 0.44039238484636434, 1.1667275164396533, 0.13421783824601483, 0.5207085525316577, 2.541411009527022, 1.1072130260928985, 0.7836300507187844, 0.271663511352193, 1.0995663654419685, 4.263493312943367, 2.5503915211846753, 1.3258210569620132, 1.172638037993062, 2.0864310235746446, 0.5950657819067279, 0.86181434892839, 0.5686639405546651, 1.3672420214260779, 3.541845597567097, 13.267923093611195, 7.430503243400206, 12.480132695167297, 25.818803579576556, 20.756880929393155, 7.914658063842405, 12.752766839919552, 10.7321225443194, 5.801452696323396, 10.217150642025857, 25.735353192975445, 38.401886724656634, 46.408538587631725, 46.07513320061469, 51.081968122913, 57.79131566324542, 57.16137124646095, 56.14514004799628, 55.9503786794601, 50.919523162226525, 40.80870797557216, 23.91006254380749, 5.613249530715327, 0.6449828453121648, 4.386476778214978, 18.596098192276497, 35.75597739988758, 43.65837658605268, 52.4115849310352, 53.184589955114554, 57.393363752672755, 54.01135498477567, 54.800029877693426, 51.227931284135394, 43.563545442396595, 31.63856148719788, 26.52357112976813, 1.6594346973203844, 0.7934025747160759, 0.8062153033191158, 11.23524594691492, 81.99946265066825, 53.0640672868298, 17.86315429595209, 6.823549799380764, 13.79272053318639, 27.412419434516664, 29.431920359211585, 31.93756376543353, 26.668179112095988, 28.564111648067353, 32.98469343493062, 30.83746248675931, 31.96117643387087, 30.369415860022272, 44.53101373487904, 31.458962040562785, 25.20975951225527, 51.710931947154386, 77.0663369086481, 40.971525561425, 0.5372157248277818, 0.17045401156910006, 0.07350841161584662, 0.07835544225188994, 0.06855789016211225, 0.08951888314538425, 0.07015250217650207, 0.04533614107077161, 0.36718830165843813, 0.2299485836298235, 0.26827492060199865, 0.12419356243504633, 0.14100810452815027, 0.2058548885848253, 0.21376044098888675, 0.1959220836720159, 0.1269690683411975, 0.3112008494715537, 0.6441077890415347, 0.545653417225807, 0.882512389892532, 39.53549877289803, 102.55881694055374, 85.37317952802105, 55.260794624205566, 42.83714994307488, 85.96858747543828, 51.461500583156464, 42.79312133789063, 66.96446080361643, 49.406390420852176, 61.44566243694675, 46.709478516732496, 53.73036423037129, 56.15378495185606, 19.586484893675774, 32.720757146035474, 38.43259888310587, 38.608779984135786, 43.39126317731796, 5.657358544488107, 1.4387432750194304, 0.6611334496448118, 6.873915974170932, 45.85871250398698, 83.71918662901848, 65.64709355754238, 66.01680832524454, 60.16323174199751, 63.709427002937566, 51.91912743353075, 65.557490933326, 56.40225141279159, 52.35387509868991, 27.441911735842307, 5.72632852100557, 11.596993400204568, 44.49896404820104, 64.00930004735147, 67.31284572232154, 56.56102895736695, 60.34268409975114, 66.20119894704511, 68.47462823314052, 66.98764985607517, 68.56279526987385, 66.64106922764933, 62.44010879147438, 70.8231238395937, 55.455948229758974, 10.24158210523667, 12.612764700766533, 9.33268754712997, 11.979603940440763, 9.08567334375074, 13.117738481490845, 24.70407578252977, 17.332510563635058, 10.52905261516571, 18.65270583860336, 5.35934127146198, 0.23857389096050496, 0.14622620517207732, 0.39408669055950263, 0.13260212817019032, 0.26721606451657515, 0.5958766706528202, 0.4320758569144434, 1.814535019859191, 0.6929796020830832, 0.15189016898793561, 4.596550589607609, 1.553817893708906, 0.2634050528849325, 0.7221398502588273, 0.32649199508370896, 0.302317600336767, 1.6666191311613208, 1.1263981966241714, 0.7833572008436727, 2.296934824797415, 0.8966555987154284, 0.6287944881666092, 0.2809167196673732, 0.7315763987360463, 3.716773746475097, 6.996316477175682, 4.750279063178647, 1.3953784084127796, 1.5968485008324347, 1.4068231491311904, 4.956158880264529, 6.178188996930277, 2.128738198549517, 5.074797830274028, 15.277799502495798, 9.419620998444097, 12.929221526268991, 23.72287723325914, 29.77838331653226, 9.538831633906211, 15.363128704409446, 10.049446763530856, 4.04125010294299, 11.605582410289395, 34.38061398844565, 45.27003142141527, 52.66549956414008, 51.16448694659818, 57.54002117341565, 61.99182110448038, 60.55797515376922, 57.583214313753196, 60.213206660362985, 57.95256037865916, 48.353771394298924, 32.97413441442674, 9.138860683287344, 0.7237694112043227, 4.04167837673618, 17.28772297982247, 35.04984878724621, 51.215822927413456, 53.65099506993448, 56.96622940801806, 61.673850244091405, 57.76449841837729, 59.662372527583955, 53.05616371093258, 49.28722097027687, 37.95022187694427, 30.556191282887614, 4.065985059545887, 1.7759593672329381, 0.8184950798749925, 13.088199111723132, 94.15575858085387, 47.11320807856899, 29.58743449180357, 10.47187622516386, 11.2100290290771, 32.64521033533158, 44.382552023856874, 44.62772761621783, 37.601064251315215, 36.49947835553077, 47.32162714004517, 50.36368016273745, 39.10097468283869, 50.919876175542036, 52.5465811452558, 45.255895199314246, 48.61159270809543, 63.18655936948715, 84.45003401848578, 53.88186970064717, 0.5810971798435335, 0.23966833949089053, 0.1656279640813028, 0.1597939593897712, 0.16292295358594389, 0.16888258137529896, 0.1884643249814549, 0.20853195219270645], [0.13958321163250556, 0.03540627410515182, 0.023940720693058064, 0.05572813908539473, 0.03725373726939002, 0.05109364039174492, 0.027222164470942754, 0.04680590756658105, 0.003647033144877623, 0.016559656979816578, 0.06676189661506685, 0.31125082904773377, 0.2824328076695242, 2.3979949374352736, 58.51762879279352, 65.81717537295434, 53.67067752345916, 31.272894605513546, 48.78283162270823, 56.249404491916785, 29.781627116664765, 45.320579005825905, 42.604820113028254, 35.669496982328354, 37.132595969784646, 34.21752575905093, 41.09471151905675, 23.195747944616503, 7.698773261039489, 31.85083623855345, 26.958779673422537, 33.64818980616908, 38.714986001291585, 0.8231535073249572, 0.9302004438734824, 0.08969783362361694, 1.3620512547992891, 26.87344066558346, 62.23055224264822, 63.569955364350356, 58.04279842684346, 60.07024803469258, 53.10451084567655, 54.4408231396829, 53.267148002501465, 45.50004705306023, 29.375438228730236, 17.613093391541515, 8.576485956868819, 8.274717427069142, 36.45999969974641, 58.98738361174061, 67.966736209008, 60.77614130512361, 59.79750210239042, 57.13431473701232, 58.83376398394185, 63.9852951418969, 67.80329888866794, 63.76230055286039, 19.424657706291445, 0.725886878227034, 6.925217634247196, 6.6073698382223816, 2.128129986024672, 5.434726774692536, 5.9619109765175855, 21.49575152704793, 22.969260484941547, 8.770961972974963, 12.293946608420342, 5.218486016796482, 1.7259017113716373, 0.8382641319786349, 0.3772150442725228, 0.12735834059816215, 0.0843188391938325, 0.13597646968499308, 0.5660795276203464, 0.4545752157367045, 1.01541847110756, 2.363804126939466, 1.0933272228125603, 2.1027201366040016, 2.7134574420990485, 1.3524410801549114, 0.3199449463957741, 0.10741724046848475, 4.706427945244697, 0.32743838946184806, 0.20434587923509462, 0.23394527965255324, 2.2731020133341513, 1.7087531089782717, 0.9147179907848759, 1.205721882081801, 1.5467393638626223, 6.995667324912164, 0.62627877799734, 0.55374845381706, 1.4735744124458683, 0.4784558004429264, 0.4090406042673896, 0.9180371126820965, 0.4812043400541429, 0.628922394206447, 1.5023718413806733, 4.330560939927255, 2.296797541841384, 12.7020231370003, 20.9210576165107, 34.587216992532056, 26.5623398365513, 8.365592860406446, 12.69601014352614, 8.122495143644272, 3.2115352057641555, 4.343244904471982, 11.990196301091103, 19.161366647289647, 32.781806876582486, 37.0611656865766, 40.04871737572455, 40.58015931037165, 36.043353772932484, 30.847803815718624, 18.971559232281102, 12.783025964613884, 5.301360795574804, 0.30538544539482365, 0.8752811327576638, 5.759768197613378, 25.664919191791167, 47.57771476622551, 49.61308363945254, 47.85863491796678, 51.117732294144176, 50.323385653957246, 52.01737103923675, 51.45464820246543, 55.32596480461859, 41.99119667853079, 14.39473081019617, 2.3259794856271436, 0.7198133331633384, 0.3418298720592453, 7.717405990246804, 76.98679908629387, 23.49979635207884, 15.222980456967509, 23.817592666995143, 33.45115346293296, 19.034140648380404, 29.442318562538397, 31.90817540691745, 29.908621695733842, 28.93479916357225, 28.304233051115467, 36.09921616892661, 31.494673259796638, 34.72931661913472, 38.537628189209975, 38.394061596162864, 37.928287982940674, 46.261139838926255, 52.21435246929046, 73.38764790565737, 5.221102727997688, 0.2396163067990734, 0.07458451234044568, 0.16714814299296948, 0.010580702707351697, 0.07000715997550758, 0.04683810624203855, 0.09519012479652321, 0.09107292314330417, 0.14754202246906298, 0.046335495107116244, 0.06351742232518812, 0.024945929556364016, 0.09060973872340496, 0.051769299297443325, 0.057752874995311426, 0.09645263003485818, 0.016130352798368663, 0.14645610815815388, 0.09949851901300492, 0.1703037510836317, 0.11616764995720118, 3.4464856693821573, 75.53309025303011, 80.27111730267926, 41.07282077112506, 39.92367613700129, 47.45517992204236, 37.60858343493554, 34.89819034453362, 42.400703891631096, 36.10016146013814, 41.9363776330025, 33.981116664025095, 39.52704606517669, 38.581095895459576, 30.156005582501813, 17.31457748720723, 39.07387502731816, 24.953244347726148, 33.906066033148, 44.734835778513265, 5.583747423464253, 3.147827824277263, 0.13493272085343638, 0.8576111002795158, 23.12473343264672, 67.18984803845807, 67.832732354441, 59.33105776386877, 65.85525374258718, 58.123512960249386, 56.231789127472915, 58.00654003697058, 50.95497746621409, 33.19337529520835, 24.481728384571692, 12.958004859185989, 8.872099307275588, 33.764221360606534, 58.669220555213194, 70.68896309021981, 63.744512604128936, 60.426858163649044, 55.40748342390984, 59.27012374324184, 61.70231096206173, 66.56244139517507, 59.510867057308076, 15.290025530322907, 2.5252937453408397, 13.026313916329416, 8.87026559922003, 5.990558987663639, 13.396874935396257, 9.183539421327653, 19.956144748195527, 29.137209153944447, 14.477144710479246, 15.36507223882983, 6.117001983427233, 4.547991156578064, 0.21135832633702986, 0.26498386816632363, 0.2002600565432541, 0.135602297021016, 0.5261096562589369, 0.5721683331554936, 0.18520774650237254, 0.21189835703661367, 0.717013557591746, 0.9927621868348891, 0.7998621668065748, 2.7885156725683524, 3.1456070273153247, 0.4637109061643001, 0.6138899105210459, 8.780472740050286, 3.434364319809022, 0.29156472894453234, 0.19158950405976466, 1.3849157311262623, 0.6853363735060538, 0.5598495780460296, 0.728609248274757, 0.8474901594942617, 5.0292218500568024, 2.250930815935135, 1.335259015041013, 1.320959892003767, 0.18094880326140314, 0.2883074150210427, 0.06545748636727372, 0.17701201531435215, 0.8347308118977855, 4.183213182034032, 8.931182949773728, 8.931390835392861, 20.98001672375587, 27.699266287588305, 43.52337644946191, 24.258973060115693, 8.634610579859826, 17.53985489568403, 12.592324249206051, 8.540845340298068, 7.361208200454713, 10.836685088373, 17.397780764487482, 32.6887761008355, 39.21552750372118, 40.15175019541095, 39.355265863480106, 33.91601708627517, 32.60480600018656, 17.79540711833585, 15.831293002251657, 10.477156716008341, 2.501209657038412, 1.6576758820203044, 9.986919280021421, 32.38908348544952, 51.70028271213655, 52.55947397601221, 51.50732563387964, 54.301908477660156, 55.69718576246693, 54.865910007107644, 55.14285679786436, 59.37991088436496, 49.256508811827636, 16.60358121318202, 2.3928438848064792, 0.4561170749366284, 0.17987626484565197, 16.166274201485418, 87.56986371932491, 30.70361944936937, 17.237398970511652, 11.739266591687358, 22.232600142878873, 22.936145874761767, 32.51485232383975, 27.74730943864392, 33.08238398644232, 26.769982268733365, 32.585896253585815, 28.984987851112123, 30.656423530270978, 30.43235617299234, 32.68721499750691, 47.56381388633482, 24.9666686596409, 43.883591236606726, 59.7476173985389, 77.45377294478878, 7.534622559624334, 0.412857131732087, 0.07939473245172732, 0.025447309204948046, 0.08453437037044957, 0.05437397525735921, 0.0443544760045986, 0.06910854650120582, 0.05796871643753783, 0.22232438467683333, 0.08862189377748197, 0.18400207732713994, 0.236691934687476, 0.1898448154210083, 0.12074993592837166, 0.2550905321033732, 0.27427636147026097, 0.254130348142597, 0.24542925939444574, 0.3546703636886612, 0.5647104978561401, 0.5225686140118108, 6.996135557851484, 96.07831616555491, 90.24201762291693, 70.73041469820085, 42.49680588322301, 66.51396089984526, 74.39633246391051, 38.902126204582956, 61.76258210212954, 54.805682013111735, 49.20529834685787, 48.111176721511356, 47.82207058322045, 59.40446099927349, 31.830932171114032, 10.863216000218546, 45.48815834906794, 32.83378220373584, 40.95693042201381, 46.84039546597389, 2.958582288795902, 1.68227122675988, 0.41158420003710255, 2.266049836912463, 35.229654158315356, 71.38893358169064, 75.89776085269067, 68.12534901403612, 71.70256630066903, 62.29705602891984, 66.33018216779156, 62.03199401978524, 56.62173155815371, 33.39841719596617, 22.914431633487826, 11.861897533939732, 13.029450831874726, 41.90455152142433, 63.36948694721345, 73.4251771434661, 66.41401890785464, 62.07369273708713, 57.71965788256738, 59.168047981877486, 66.15549548979729, 68.2896492558141, 68.69764635639807, 25.71657680696057, 2.2036385536193848, 12.19610014269429, 14.833266504349249, 8.05472933476971, 9.398956971783793, 7.917637103988279, 33.37602830702259, 33.320777800775346, 18.804719255816554, 19.483671726719027, 6.428990248710879, 3.0907615057883726, 1.4922491845584687, 0.8552447466119644, 0.39541968354775064, 0.2302649166555174, 0.6012736068617913, 1.1275863070641796, 0.8893631158336517, 1.8270032540444405, 5.661127451927432, 4.523620490104922, 4.234599173069, 12.824469727854575, 4.921338039059793, 0.29390426953473403, 1.0766513885990268, 10.173834927620428, 3.455169551795529, 0.3876601015367816, 0.37588110133524866, 4.387933938733993, 5.839021157833838, 2.2949410350091997, 1.9710624722703813, 3.6859669608454553, 21.468130196294478, 11.29714781238187, 4.269311658797726, 2.798674366166515, 2.031619455064497, 1.8148425581955143, 3.388102169959776, 1.8931585622410623, 2.827888914654332, 5.690711928952125, 7.652069599397722, 7.76250098982165, 24.488327772386615, 28.54543528249187, 48.34616199616463, 34.033048845106556, 9.742336946149027, 16.383677451841294, 14.308117032051088, 6.070668495470478, 9.0273476992884, 13.948381754659838, 25.59733871490725, 41.24058838813536, 44.13863158995106, 45.23833082568261, 46.21128259166595, 39.50716357077322, 36.183374543343824, 20.512374101146577, 17.190599210800663, 8.262360980433803, 1.7551003252306294, 3.0359525113336505, 8.47258335159671, 32.9273287711605, 58.339878743694676, 56.78813811271422, 55.609234456093084, 59.643690278453214, 60.11292734453755, 61.210528112226925, 60.97110663690875, 64.74998081884077, 49.982496384651434, 18.35401342761132, 3.7413635753816177, 1.229178391156658, 0.23772756298703535, 11.35725421290244, 90.5763683011455, 31.950466402115364, 19.011537990262433, 27.695953845977787, 41.84677500878611, 26.822394940160937, 38.62813688093616, 44.358017598429036, 41.29196751502253, 39.979005090651974, 38.8799608907392, 44.94330583080169, 45.358014106750495, 47.56220571456417, 51.22006300956973, 54.4813451459331, 46.967413579264, 62.533806370150664, 66.79653629179924, 92.99685508974137, 13.675621113469525, 0.8287070931926851, 0.1969935189211561, 0.4248803301203636, 0.23380114787047912, 0.19098722105545385, 0.22729745975905852, 0.2502380852257052, 0.15072603709995747], [0.10806315218008335, 0.023898867394534812, 0.042109221685677774, 0.061420233649832595, 0.04795195977954615, 0.02772719452848598, 0.0446130728138791, 0.07980141022633161, 0.04292084204573785, 0.04649297597127096, 0.19103105660648118, 0.09393183304177177, 0.03311400880075751, 0.1999561954289675, 44.964494474472545, 81.16533925456386, 64.00718981219877, 36.709482054556574, 34.35691110549435, 51.63493602506576, 34.01476667773339, 38.53101115072928, 48.053325683839866, 37.68614438272292, 40.15949687650127, 38.88416174919375, 40.39552550162039, 34.81633832377773, 12.363908944591401, 15.48035462056437, 48.512509715172556, 26.737777648433564, 33.20246734926778, 56.52151107788087, 4.12179131661692, 2.377417693215032, 0.16197749383507237, 7.199630573872597, 47.26789066868444, 51.87565580491097, 56.499173179749526, 54.26963913825251, 54.34536833916941, 53.38315994508805, 55.49756065491707, 51.675434497094926, 57.58561088192848, 54.14879483561362, 32.2104371747663, 6.3927593154291955, 5.717654689665764, 16.02907165404289, 37.93717607375115, 52.347324740502145, 56.05861256199499, 63.12763752475862, 63.25961351394654, 56.30370578458233, 37.93711331582839, 2.8839616477489476, 0.23431727662682536, 12.256360496244124, 6.649355869139395, 0.9282689829987865, 3.0381767403694893, 4.118065555249491, 17.377009853239983, 15.165455956612865, 7.905464518454767, 8.022414397808815, 10.737725650110553, 10.212000569989605, 5.447740218331737, 0.3427814145482356, 0.5811055148801496, 0.328827919738908, 0.469911897615079, 0.4768908973182402, 0.4698940937317187, 1.3875690919737662, 0.6436103834740577, 0.04084704969558985, 0.0030529894161924363, 0.30977451633061137, 3.3998393724041605, 1.7851271720663195, 0.17720606538557238, 1.4373844189028588, 2.2648226253447996, 0.7151466319637915, 0.5275562754081142, 0.2268927661521781, 1.6321837854000831, 1.0266554487809059, 0.7075009519054044, 0.46875783212242594, 0.6253891354126315, 2.887111556145453, 0.8121720965831511, 0.5189070201689198, 1.108177071136813, 0.5102927291825895, 0.29164955019950867, 0.08584618868847048, 0.17424033984782236, 0.43296215935580196, 0.6412375333809084, 4.1156454528531725, 1.255678291763029, 17.411981705696352, 27.043657802766372, 23.807386659806777, 36.081200722725164, 28.363337286057014, 3.9581488072872166, 11.209113155641864, 12.111229858090802, 10.786822938149976, 3.8439132080924128, 2.5548993051052094, 6.590480112260388, 12.300003728558941, 16.43836509796881, 17.120431930788104, 15.917341959091926, 10.011696892399943, 11.792829498167961, 1.8783321255637755, 0.40690131906059485, 1.5762263945033474, 3.173384027134988, 35.17685513342581, 56.31253503984021, 47.686407566070564, 62.67744356586088, 68.52614464298372, 45.778849124908454, 51.59771665450066, 47.748412393754535, 54.33351493650868, 47.45528582603701, 57.94513533192297, 29.0313502665489, 12.792539673466838, 0.4761310913149388, 13.086594862322654, 52.83900953108265, 34.899853429486676, 27.07040640615648, 23.121385689704653, 66.07043497024044, 29.936409727219615, 21.54447324814335, 27.76548766320752, 31.981527651509932, 29.377417064482167, 32.77707649815467, 25.40532692786186, 37.69744865355953, 32.93585600391511, 32.02072781901206, 44.9966343756645, 30.84368532703769, 37.65404370523269, 47.016957036910526, 63.78106517176475, 41.58812607488325, 0.7298742739423629, 0.15938388784566235, 0.07755362398682103, 0.019559875626357335, 0.14154271132523014, 0.14522999975710146, 0.11627826539258804, 0.028893707034688805, 0.10928523861953329, 0.052460149726680214, 0.0703921727836132, 0.048545045898325985, 0.06077583879232407, 0.0440573449727268, 0.06973932031542063, 0.05695897041850033, 0.06102631506960719, 0.020757966276799, 0.03277845462904342, 0.026849776791829257, 0.05436116626726524, 0.09093540270001658, 0.21269666661898937, 56.814861220698205, 92.87402214542513, 59.44929761271323, 31.702125457025346, 49.11769220905919, 34.694278086385424, 34.04733411727413, 39.94982657894012, 36.4036117061492, 40.86805735864947, 40.190871915509625, 37.950994583868216, 43.03061300708402, 36.38998539217057, 24.12621848044857, 31.66538069325109, 56.57843251382151, 27.583158246932495, 41.09124022145426, 57.94715143019154, 10.606689068578905, 6.121442596758566, 0.08569502421925146, 5.826741687713131, 50.89514563160559, 55.27083981421686, 60.32395085980816, 61.49167576143819, 57.64756864117038, 58.36531139189198, 59.07367575553156, 55.80733376164591, 51.350858365335775, 51.78116982983005, 37.88582832582536, 9.571448103074106, 7.104797959327699, 14.868006936965452, 33.243369825424686, 44.784524363856164, 55.2316592585656, 63.61981653398084, 59.03117687471452, 52.235168487794944, 35.390949864541334, 2.2099496472266416, 1.3938019833257123, 16.80562250075802, 13.47311600562065, 7.225187267026595, 11.666768443199897, 8.98337204610148, 16.403385400772095, 22.621630622494607, 13.149496932183544, 15.523736034670184, 12.390397690957593, 10.69486395005257, 9.59604234464707, 1.3328749494206522, 0.4885147493933478, 0.9069079389014553, 0.5316629356914951, 0.3510650006994125, 0.33567677642549243, 0.37548411457288655, 0.27700424735103885, 0.0610147548028298, 0.07171932052099897, 0.014217414014462023, 0.20170099132003325, 0.5036704506604902, 0.9067360900582806, 2.6906670005090776, 9.081155753904774, 2.7600738310044814, 0.6348676655081011, 0.22523237782860958, 1.523776828281341, 1.375995035613737, 1.0662709585120602, 0.7242773581416376, 0.4355825477790448, 1.2118665201048697, 0.33575053537084215, 0.34762152741032265, 0.04429936363932587, 0.4296323122276414, 0.22980321078531205, 0.09478820442792871, 0.20867835159503645, 0.14557734402197023, 3.096551169310847, 8.1682692035552, 7.227720627861639, 24.64912533760071, 30.571239456053707, 30.78324748623756, 37.03576441734068, 24.34867374358639, 6.675324901457756, 18.79931030734893, 14.133409761613416, 16.09534009810417, 10.18701114962178, 5.984858312914449, 5.781607464436562, 12.078734001805707, 17.05634040217246, 17.179475368991977, 16.08641964773978, 10.234395342488444, 15.018713224318722, 2.9886342633155087, 2.4004711787546835, 5.240619951678861, 4.676064387444527, 41.384535451089185, 54.9967328194649, 49.89700048200546, 61.32148019729122, 70.7564906151064, 51.30798293698219, 60.09119349141275, 55.21762894045923, 60.59309605629214, 51.535629457043065, 63.00131759335918, 29.21398562769736, 5.883237056193813, 0.9231804431446138, 23.4544204127404, 47.31435898811587, 44.36250871227634, 29.038706671807077, 19.206338582500337, 68.13031473467427, 30.82519723523048, 27.065638765212032, 26.701158400504823, 31.62530387601545, 29.424024628054713, 31.268007332278838, 28.287839504980273, 26.078888100962487, 35.0748578194649, 26.403460310351466, 46.84434529273741, 32.828447780301495, 31.157469057267715, 49.00830122732347, 72.49417120410551, 46.91190811895555, 0.6611780053184879, 0.2740936035350446, 0.06852304082243674, 0.021138248491972204, 0.03832047256911474, 0.03677301709690402, 0.01993300449553757, 0.016084146205215685, 0.04297770109147795, 0.24914925978068383, 0.16124488395308295, 0.17565441558197623, 0.1468883809303084, 0.09636208610308748, 0.11007334391075758, 0.12041094968275678, 0.2353687323029003, 0.2632229997506065, 0.1142238857104413, 0.3161185517186119, 0.17460030924168327, 0.2805277921499745, 0.6310208009616022, 72.94851503064557, 99.61935350971838, 82.66237458875104, 50.32002418271957, 48.598656731267134, 72.70855226824361, 42.740843988234, 54.14081281231296, 62.78968611071187, 51.01057706340667, 53.8721892910619, 52.110476340017016, 55.54954774918095, 53.102239793346776, 16.454074190508937, 25.355993317019557, 52.77369422297324, 34.04010518904656, 37.20959994100755, 70.4728404937252, 7.266403042501019, 5.146829707007255, 0.37623941597919314, 8.565853391924213, 56.79003653987762, 62.16395824186264, 66.5673678921115, 66.30580855954078, 62.70881468249906, 66.22168156408495, 65.78441573727515, 61.29618875442013, 66.26893043518066, 64.66630881832492, 36.09363855854158, 9.313743479790228, 9.557875721685349, 22.292277043865575, 40.503771151265795, 53.58296940403601, 62.29946828657582, 67.6426072274485, 67.40366428129136, 58.743706364785474, 44.53590100811374, 6.1163626370891455, 0.9788017972342431, 17.76721704390741, 17.983922112372614, 7.7836592351236655, 8.83770110145692, 5.955307666332492, 30.922952505850027, 30.849023672842215, 21.701154285861602, 25.691973740054717, 19.34924033380324, 15.101471312584417, 12.036628338598437, 1.2457511405791006, 1.8217927529927225, 2.956019510184565, 1.431436634832813, 2.241795860951947, 3.06965523189114, 4.037844750189012, 1.680509224534035, 0.3277645897000067, 0.19027501975576724, 0.34466718593912743, 7.156361927909236, 7.7337205986822815, 0.7671914586136419, 2.5266413246431663, 13.237688483730441, 1.3127867757312714, 0.8543834799239713, 0.4097270190475449, 5.209467997474055, 4.803079558957008, 5.982016555724606, 2.8197813755081547, 5.2528018528415314, 8.431351396345324, 1.671642216463243, 0.6214454373525036, 1.8449787410997578, 1.3608945233206595, 0.6884102859804708, 0.4439282176956054, 0.33069450828817587, 0.8716053816099322, 3.6782869600480605, 7.994567040474185, 5.972709751898243, 24.528255539555705, 35.65130110709898, 33.22648794420304, 41.83026575273083, 33.90379105844806, 5.358582292833637, 15.742548396510465, 18.625239441471717, 17.741066601968583, 10.157288409048512, 4.366889932463247, 7.9475103655169095, 18.67585566736037, 23.26009246610826, 22.325787813432758, 19.867308947347826, 14.283127611683263, 16.660475192531464, 3.4821937016902433, 0.723569002603331, 3.9622079701192923, 4.740381942641351, 40.024626178126184, 62.8619126350649, 56.51467830904069, 65.4663428952617, 70.62654249129757, 55.82467456017771, 64.61247821008006, 59.58257582879836, 64.63929545494818, 56.20947868593278, 69.45743299299671, 32.856755525835105, 17.058766388124038, 0.9185397889344924, 14.76276582287204, 58.93192521987423, 43.375938477054724, 30.491062287361395, 28.753752362343576, 69.25133597466254, 35.03393573145713, 30.57117081457569, 36.9928889889871, 45.33801786361202, 39.1459015107924, 46.30023018006356, 35.08123167099492, 47.10921902810374, 50.58767887853807, 43.09736782504667, 60.289029998164025, 41.569518350785785, 51.846300786541356, 61.4991557213568, 78.65327296718475, 69.05422902876332, 0.8825523490386625, 0.4061157112160037, 0.18970711877749813, 0.13469774636530107, 0.32596854252680657, 0.25075548568800576, 0.20610120117423997, 0.14026303805651205, 0.2756308049203888], [0.04081796133710493, 0.042534021270130916, 0.04591375987436022, 0.03477923496956787, 0.10124113921436573, 0.0676022567636063, 0.04688775640041117, 0.07543652468631346, 0.07826135133302982, 0.059803860907953595, 0.10443634638983397, 0.13206635691946553, 0.4857727981382801, 0.4115279385399434, 11.97447838321809, 77.69659119267618, 58.28883301827216, 55.62043282293505, 25.619213773358254, 47.204336504782404, 43.52703994320285, 36.008978120742306, 48.08719535027781, 43.41274207638156, 34.5749831199646, 42.36744611494003, 35.46349802324849, 43.27156420676939, 25.455141029050274, 12.981434156817775, 40.657382934324204, 93.03596896509971, 20.05706144917396, 32.375725853827696, 39.5791272963247, 1.0143677661976507, 0.5436701075203958, 0.723887388744662, 20.81029184402958, 36.66550444018456, 54.609806691446614, 54.8828193449205, 60.08740055945612, 54.879148006439216, 47.30707514670588, 55.56640609618157, 46.108332141753166, 53.654662486045595, 45.14225629068191, 12.817524190871948, 0.8005680095764899, 2.792184559568282, 13.234529995149183, 27.632627179545743, 17.94019356850655, 13.952225677428709, 9.513415655782147, 4.118297955682201, 0.19284271665157812, 3.4127054820137643, 18.084309293377785, 9.518378434642669, 3.8888294946762825, 4.6386229126684135, 4.78462137522236, 15.594847625301732, 13.978300613741721, 4.388627707958221, 3.8274662196636204, 3.424332367797052, 9.339943931948754, 9.801598075897465, 5.28266481814846, 2.4020548357117564, 0.013770521411882534, 0.17909260286438852, 0.3152268866617834, 0.07965565433785801, 0.062216735264707, 0.17206130999951594, 0.11809544127073981, 0.03625613374395236, 0.06231079554005016, 0.07664089151207479, 0.15060945383964047, 1.09051255449172, 3.304065634166041, 0.17693825636900243, 6.552152672121602, 6.1073750161355544, 0.6951986217210371, 0.02538080702746107, 1.0483128769743828, 1.211640738671826, 0.9946941992928906, 0.4775789974918289, 0.5930521351195152, 1.0577171271847141, 0.3459894536964355, 0.44184770675436147, 0.32692682658953054, 0.03697070225532498, 0.19098765006469143, 0.09767755099962797, 0.03774618624799675, 0.096323735741598, 1.8001260704571203, 4.991127300646998, 5.451115908161287, 19.719086500906176, 20.442961877392186, 30.632546101847005, 11.893888385065141, 31.445061160672097, 22.165351106274514, 3.3103063702583317, 9.628378364347643, 11.597710213353558, 14.147724451557284, 13.630628585815431, 6.10569526110926, 0.7021797051833523, 1.6857685100647712, 1.2831173548775336, 3.049440806911838, 1.0042321165242503, 2.871381626013787, 4.718902553281477, 10.049522269156672, 4.93768451675292, 7.870519632293333, 51.468556927096465, 47.94567231209048, 46.42740518816056, 40.9553732410554, 64.84708693719679, 58.564673700640284, 49.71044863423994, 49.12821200586135, 53.43203659980528, 51.93767632207563, 44.492280329427416, 30.516706743547996, 2.891773783391522, 1.1650450647838655, 16.5390896028088, 36.96305544145646, 21.926965136681837, 38.37632856061382, 57.61101607353457, 76.0869759898032, 32.91970760591569, 17.643117174025505, 31.739456615140362, 31.367719865614372, 29.893801020037746, 31.620298931675574, 27.169673750477454, 46.13096421764743, 26.095511105752763, 50.87703997089017, 71.74937586630546, 25.55851705612675, 36.81264039008848, 49.185984596129394, 63.52400479778167, 8.801277972036793, 0.47524975312332957, 0.14784588358334957, 0.05156312971526096, 0.028896317479290792, 0.036843864908141476, 0.09013240465954428, 0.12074599057556161, 0.053387594920012264, 0.08743390591154176, 0.03883729846547208, 0.04488027662098889, 0.043475750172811176, 0.027816604650128755, 0.040096076686055436, 0.0995670072734356, 0.04340914265823461, 0.16915057425297078, 0.11816182278937871, 0.042781666852533824, 0.13615023374797838, 0.15163541410959538, 0.4754431443589349, 0.33103691894681225, 18.378800845915272, 87.38054660058792, 70.8615787567631, 34.91064779220089, 32.84443339993877, 50.4007661727167, 34.00705529797462, 41.89518097908267, 41.08496050680838, 36.94597351935602, 40.16155219847157, 39.514145389679946, 38.028547686915246, 43.405015007142104, 32.89808357915571, 26.209230422973636, 52.390643396685206, 86.8793696741904, 25.607128950857348, 40.80746458422753, 40.88617870884557, 5.055957705743852, 2.163553891643401, 1.14421887263175, 22.017558159366732, 41.16747148575322, 61.53657905517086, 59.32788456639936, 62.421665806924146, 59.80625683261503, 52.12420855799029, 59.91358857001028, 49.376607864133774, 56.644649967070556, 49.052827973519605, 15.787692916008735, 2.6302620095591394, 10.237971563493053, 23.790010559943415, 36.90977004266555, 22.336127181206983, 17.930175835086455, 10.473438309084985, 4.118181265169575, 0.3941939122253849, 5.7157327282813295, 22.211627229567497, 14.59772817550167, 9.021369026553247, 19.087449581392352, 9.997069393434833, 13.227016695084112, 18.460392029054706, 7.3463620293524965, 7.60399506938073, 6.8438637545031895, 12.270564379230624, 9.844774546161775, 9.158070491206262, 4.753486091090787, 0.13328851230682867, 0.06144169560303131, 0.09599570455330034, 0.12530354722853632, 0.05983071995057887, 0.10082795735328429, 0.21631120734157103, 0.03875647235902087, 0.21451491502023515, 0.06986309714134663, 0.004303033995036517, 0.6674450948353737, 1.2858485502581443, 0.7571170959741839, 6.115870869928791, 5.006398068320367, 1.6656755559867429, 2.0207788819266908, 3.5538291738879297, 2.0974989716083776, 0.6213916886237361, 0.25036323334901567, 0.1923476553131496, 0.299910306930542, 0.22416514074129446, 0.43095464127198346, 0.26486920012581733, 0.015923562684967633, 0.12523643792636935, 0.1072823400458982, 0.03575151928910806, 0.09279608471138824, 2.9155646745235693, 5.016383932482812, 7.655888517056742, 25.44264828005145, 25.144087268460183, 31.431376011140888, 18.821499155413722, 32.80990281412679, 18.734591199505715, 6.847003611826128, 18.56270117144431, 13.126171577361323, 15.335913338968831, 16.442427692874787, 12.106249428564503, 2.422580843971622, 1.8652640138902974, 1.0201490946835088, 4.5179595293537265, 2.2593139015859176, 5.607924422910137, 10.131467446204155, 12.69931572098886, 4.341190563094232, 9.99990918943959, 54.56048288652974, 48.70851447505336, 48.59318894724692, 43.4014025042134, 63.272423974929325, 63.04361251092727, 54.50833105271863, 54.52165926656416, 58.326574064070186, 56.95164603571738, 44.83901393028998, 34.62805278839604, 3.794844602384875, 2.295088614186933, 20.495152934905022, 40.54669364806145, 25.16719787351547, 33.99448017920218, 65.55273309830697, 100.95262204447101, 44.94434133652718, 25.79236092105989, 29.344116141719205, 32.340514736790816, 25.724419586120117, 34.528440275499904, 26.918016441406746, 34.84483042070943, 29.704262287386005, 38.095157377181515, 78.75865920897454, 21.35197900956677, 36.79144390167729, 54.95031156847554, 72.65744378489833, 10.52733559762278, 0.38864277783901463, 0.18719572934412188, 0.10873703376179743, 0.14103879401039693, 0.041316822471637885, 0.08761058876951856, 0.14058147016311848, 0.037411336877173, 0.02245698266872956, 0.1244111697099382, 0.10926347406160448, 0.08526511099790374, 0.1459333450803834, 0.3213306462332126, 0.2685378113340947, 0.13640832876966846, 0.3771798348715229, 0.2838943195679496, 0.2492281974804017, 0.2623812529829241, 0.44166470367100935, 0.7826511129256218, 1.1842427378700626, 26.28513809173338, 98.85755077485116, 77.87630634923136, 73.84314490902808, 34.02332528944939, 68.27345771174278, 58.93268615968766, 47.963299443644864, 67.15573126269926, 57.250365903300626, 47.224732829678445, 59.82701009319675, 47.74534510027978, 65.2603360914415, 35.253353118896484, 19.107310502759873, 46.28768644025249, 99.3182017726283, 25.90219513062508, 38.16793695572884, 46.79905368435768, 4.017198374194484, 2.012118901456556, 2.105271148104822, 25.624287359176147, 45.710160578450854, 65.49500365411082, 64.51954549358737, 69.12483953660535, 64.27751171973445, 59.23610110436717, 65.20406576894945, 54.98138458498063, 60.07082070073774, 53.52411031723023, 13.987311278620075, 1.9323955019635541, 6.292167190582522, 22.65750462009061, 40.96761103599302, 25.423012894968835, 21.477624293296568, 13.743117259394738, 8.197895355762975, 1.1479519884432516, 4.99048158045738, 25.847036800076886, 17.440728756689257, 9.34104415678209, 15.012635511736717, 6.313312197885206, 22.80993380854207, 28.786559066464825, 13.681767467529545, 16.57570885073754, 13.531981956574226, 17.716436078471524, 14.831249425488135, 13.577779550706188, 7.21566669402584, 0.9509342764654468, 0.4427859499569862, 0.41994972695266053, 0.14543587822587262, 0.16454255538842372, 0.6646778013917708, 0.5545305989442334, 0.10579226072877647, 0.409456467436206, 0.14688384568979665, 0.2027887289202021, 8.960353616745241, 14.046795002875792, 0.5546953997785046, 17.82089860208573, 12.36638984372539, 2.038367402649695, 0.6850333704102425, 5.6216909616224235, 7.508582434346599, 3.0169312223311398, 1.0925239949457108, 0.819030054394276, 1.2860424624335383, 1.8789880194010276, 1.7058701669016194, 1.1641771178091727, 0.1291575823580065, 0.39350856996832356, 0.2862634617955454, 0.4002816145939212, 0.20144462765705204, 2.7025145196145584, 11.123042625765647, 10.582003631899434, 25.366754339587306, 28.47156136266647, 37.35647309210993, 20.228359199339344, 39.853171533153905, 27.172160533166704, 4.068064406033486, 13.240913652604627, 19.01548977821104, 23.431927580987256, 20.476837427385394, 10.298645727096066, 2.3943919952838653, 3.963679349230182, 4.812440785669512, 7.806573231374064, 2.930292193928073, 5.680620160795027, 8.844792746728467, 16.30806298025193, 7.1193342631863015, 10.449234343344166, 56.10417481391661, 53.179184929017104, 52.01059710594916, 49.81165755179621, 69.13754801596366, 64.44050188987487, 59.58940467526836, 58.419600917447, 64.51466606509301, 62.22752025050502, 54.75922546079082, 38.60338672514885, 4.597046769434407, 2.652579805543346, 20.6287782807504, 44.82277531777659, 28.8748888815603, 49.59812371961532, 66.18514076355966, 79.07954046803137, 38.33254706475043, 26.563424371903945, 43.8020412383541, 42.53315448760987, 38.855704953593595, 43.945011631135024, 37.455289363861084, 64.84425890830256, 41.01826452439831, 61.195034750046275, 96.322538621964, 34.50953445126934, 52.771776183958984, 61.8400606801433, 91.92018016692131, 19.29436049153728, 0.7028363957520455, 0.44763093513827173, 0.2895500096342256, 0.3340892583852814, 0.19684399388009505, 0.17400809263269748, 0.3047640255141643, 0.12646708922881272, 0.12453123867031067], [0.05249254375455841, 0.02205814005837085, 0.03482217802816341, 0.07147408811555755, 0.04980377815363388, 0.0304378108722308, 0.08547442154057565, 0.04420758247555745, 0.03957716703054406, 0.012404507161268305, 0.08006606296065354, 0.07186994106779176, 0.0465046166772804, 0.08505519524577164, 0.2166895322020977, 64.98160462225637, 71.19617262194234, 65.85148042248142, 38.34531830203149, 30.649673131204423, 44.05173540115357, 33.02844747420281, 41.376388688241285, 52.530060122090006, 38.13037633895874, 41.425806630042295, 39.797669995215635, 39.097738727446526, 41.19496337829098, 21.60862361231158, 27.30165562322063, 39.05239612825456, 65.68280673796131, 11.634610891342165, 20.16084344156327, 31.093503044497584, 1.2567304675617528, 1.9314069421060625, 7.115010340367594, 38.852300336284024, 66.35019410041072, 54.78394031524659, 52.75709867477418, 54.32509753011889, 57.984084467734064, 53.639706488578554, 55.513901249054946, 53.4278122071297, 41.66716967859576, 34.33779739564465, 7.6928470500053905, 4.545320022490717, 16.087563999237553, 17.517424821853638, 5.313684392359949, 1.65825332845411, 0.14305567368865013, 0.9217037320617707, 10.93225952117674, 17.32515808074705, 10.222029089927673, 7.057812867626068, 6.886698978562509, 4.832925363894432, 13.442150854295301, 17.237147938820627, 2.9159578921333438, 1.515174089900909, 3.528101612483302, 3.5280734204476882, 9.19524573510693, 8.855413544562555, 10.299437065278331, 0.42979613246936954, 0.12332391474516162, 0.12447960434421418, 0.03919933246628892, 0.10787385951487288, 0.059439348612701705, 0.1914148666565457, 0.0706218995694672, 0.11375921507996899, 0.03302310480766239, 0.0936190470031673, 0.11203048405267539, 0.2808900291640913, 3.945976466901841, 1.2422960227535618, 3.5379592641707394, 7.938862519879495, 2.452981173992157, 3.390981189666256, 1.6770447910793367, 0.9695972814675301, 0.11862857717900507, 0.10675754683512835, 0.23782743020884453, 0.2302051158321481, 0.2055237853839513, 0.1704839809286979, 0.12643446920499687, 0.13685391614994696, 0.060686650836179336, 0.09999462989188972, 0.009845073481330709, 0.16352296896999882, 2.7954158571458634, 8.974549654991396, 5.874371519011836, 16.046697805004737, 23.318494596788963, 17.02609500577373, 23.11638466773495, 6.569492490060869, 16.81515189909166, 13.210074997717335, 2.728798322139248, 5.224293576132867, 10.157025610246967, 13.686347815298266, 16.204132918388613, 14.490731800756148, 3.9864903832635576, 0.02450356549102693, 1.4600652792761404, 2.0313419473748056, 2.21362441778183, 5.577801110283022, 23.7371507383162, 6.925611832449514, 10.572244774910713, 56.12287275252804, 44.62942208013227, 58.45523957283267, 50.581379552041334, 46.47132004460981, 54.05976095507222, 55.78379169587166, 49.88204056216825, 52.82254734346944, 48.55598526616251, 30.125536611003263, 7.0578035519969085, 1.2156975725966117, 2.873483526129877, 42.7963416038021, 59.218626945249504, 103.73037399784212, 37.29020857041882, 21.3518613384616, 57.573326018548784, 16.94107370991861, 23.189360364790886, 34.672689360956994, 24.185459998346147, 43.43488385600429, 30.793730020523075, 29.253605488807928, 35.45955604122531, 29.629005732074862, 90.57414039488762, 35.84632919680688, 31.603330758310136, 45.17769882755895, 63.0400235422196, 31.613615212901948, 0.9180225263680182, 0.1714315857257574, 0.02274371980268869, 0.062397995498031385, 0.031420383752594074, 0.0316061792264302, 0.02281916222625202, 0.03929848339588892, 0.03713587464223947, 0.01992501994414676, 0.024858245047770684, 0.05515910046655805, 0.0698000940704538, 0.05264408743729996, 0.040778086460646124, 0.0398767227306962, 0.07181048498398836, 0.08037714062318688, 0.06531097971263432, 0.061993589174122586, 0.027499258473155, 0.02256221442122854, 0.12445096797760456, 0.08921626309353499, 0.4653810084827485, 73.13015999332552, 84.45308562247985, 57.426864716314505, 24.53872238436053, 42.0155938210026, 37.292585526743245, 32.869352217643495, 40.766095346020116, 41.1521860091917, 40.17369977889523, 38.76320762019004, 39.236924033011164, 39.38306370089131, 37.760755708140714, 34.00284267240955, 29.40196914057578, 38.55576130651659, 57.9695285520246, 14.207476858169803, 18.972451571495302, 35.69710262360112, 6.628441791380606, 2.3937347531318665, 4.525838100141095, 41.830081401332734, 69.05582151105328, 59.6641375941615, 60.9701927246586, 60.756552988483065, 61.48176785438292, 59.67677154848653, 57.292900085449226, 63.28238679516701, 45.80252455126855, 38.15362030459989, 7.955719886287567, 10.389302488296263, 27.65385896928849, 24.375198771876676, 10.389275031705058, 2.339222878217697, 0.2775346866298107, 1.557592316981285, 12.375862367691534, 26.258999416905066, 13.926958749371192, 14.96939628354965, 19.70822153552886, 12.751346941917175, 11.991979998926963, 20.82899566619627, 5.348352261127965, 6.946131712005985, 4.3365979579187215, 7.592284342935009, 12.290764585618051, 7.277799979332955, 14.662115843065324, 1.250109751859019, 0.06019372688305955, 0.13610158716478657, 0.17454548798982175, 0.08378903576803785, 0.018079653945601275, 0.12439869013765167, 0.14749279365904872, 0.13412083619304244, 0.04167098108859312, 0.008221497597743668, 0.17312056445066007, 0.12610537315448447, 2.1020888801543944, 1.3649976902431058, 2.786675100364993, 4.344988398013577, 7.981950246518659, 5.523393423326555, 2.545422858768894, 1.4244405973342158, 0.12090090121473036, 0.02044216376699267, 0.23825954976341418, 0.07732012804837958, 0.15770940350428705, 0.17676424715788136, 0.1647565850327092, 0.1695064987025915, 0.07904156591863402, 0.16054815762946684, 0.04884986079207832, 0.3205575103000287, 2.9546520738832416, 4.977826543392674, 4.039634086431996, 20.122757227190082, 28.976023274083293, 19.355384726678174, 28.67959995423594, 11.95678359077823, 22.733329919076738, 12.113789204628238, 7.3536370454296, 14.813896859845809, 17.058723242052142, 15.482381505350913, 18.40028758971922, 22.98508724858684, 7.740136615691647, 1.07914773206557, 1.3778193054660675, 1.789332198039178, 3.1382861685368324, 9.513648056214857, 21.452272053687803, 9.668289461443502, 12.523721994892245, 57.8355090079769, 52.68435047518823, 60.035154588760875, 55.68880365740869, 51.14587137776037, 56.2603832060291, 60.72958669354839, 55.38479251246299, 54.83699429419733, 55.00411864249937, 29.796345810736383, 11.657650893734349, 4.2792960520713565, 4.411713798199931, 48.05755792125579, 61.4765707139046, 94.2117464926935, 44.11443056598787, 20.49837516200158, 72.78499141816171, 21.49072108730193, 28.96359916656248, 28.55661992103823, 27.838586914923887, 35.66643361122378, 32.79633729688583, 21.18204624422135, 38.162096546542266, 27.44386115381795, 87.90879572591474, 42.2181018706291, 24.499114290360485, 49.550608127347886, 71.34401459847727, 42.355937880854455, 1.015772832737815, 0.1654776116652835, 0.021334916668673678, 0.05185412438285928, 0.03905682479061427, 0.027832771020550883, 0.09604815093259658, 0.015547868378850964, 0.023274302722946293, 0.013259123248468726, 0.1384580736198733, 0.1291543035016906, 0.16906563042392656, 0.24528233905232724, 0.16075841812116487, 0.1278116501447174, 0.2168757681764903, 0.20047955605531895, 0.1375006782191415, 0.11142240176277776, 0.28552265477276617, 0.27956923229559777, 0.28515343103678, 0.22370774028522356, 0.8431706493419986, 90.09328134598272, 90.4644238564276, 84.93861229188981, 55.45527750445951, 42.68602886507588, 65.43517574187248, 46.53514485205374, 56.48650784646311, 69.06261505619173, 51.523968250520774, 57.53563988593317, 54.21388656862321, 54.32611734636369, 53.74277853196668, 31.205686753795995, 37.144614111992624, 49.748099465524, 81.03375942476335, 14.58015791831478, 24.88026276711495, 40.263875069156775, 4.816047405042957, 2.8512973746945782, 9.604827473240515, 46.272263680734945, 76.79855669698408, 66.05144285386609, 65.9725953686622, 67.59454250335693, 67.82357754245882, 64.79014981177546, 66.93155996261105, 64.49041405031758, 51.454738416979396, 41.290884940854966, 9.436885310757546, 7.163275595634215, 21.8178879445599, 22.22427098981796, 9.43852388089703, 2.976025804396599, 0.3392448768981042, 1.501249920937323, 13.507809369794785, 29.292180038267567, 14.271807651365958, 16.213468159398726, 16.89107329614701, 6.421123445034028, 18.281004390408917, 32.03029447986234, 11.114952737285245, 14.30323858414927, 9.690811710972941, 15.09262832903093, 14.994844621227635, 13.148762468368778, 20.273229152925555, 1.316169942578962, 0.1838823071410579, 0.3959847500006999, 0.18174414042263262, 0.17063715254827855, 0.1119126137646456, 0.45634549171213185, 0.4116753951436089, 0.24692504606660337, 0.13758602041390636, 0.2790544212104813, 0.5314276547681901, 0.6422144487019509, 12.074690038158048, 1.7388656350874132, 11.549262077577653, 18.828653558608025, 7.934689118016151, 4.9241013488461896, 13.573685576838832, 7.965990122287505, 0.810649726660021, 0.27900027411599315, 0.4643428367712806, 0.30828239155873177, 0.4107677954579554, 0.41100068618693664, 0.3723151152653079, 0.49622174712919426, 0.23290317024915452, 0.2895764243458548, 0.12998619837866676, 0.4907944738384217, 5.515161348927406, 15.873284916723929, 15.733236689721386, 22.02204535084386, 31.36322286821181, 23.023779469151652, 33.99351919850996, 16.142023167302533, 27.37600414983688, 17.817690103284775, 3.5976991682283344, 8.335887770498953, 16.452797459017848, 19.812029023324293, 27.912554971633423, 25.393773586519305, 8.152847914926468, 1.386350338016787, 3.823030999591274, 5.131189746241416, 6.767007852754285, 7.875923677798241, 34.65256367960284, 13.13617362130073, 12.495228917367998, 63.79749598041658, 49.76850755753056, 66.2313227499685, 58.760619624968506, 56.07629068436162, 59.62741636460828, 69.03373856698313, 60.424379225700136, 62.185444985666585, 57.855246374684, 37.35298610502674, 10.851637163469869, 2.9371575674703045, 4.803691939000161, 53.54420854199318, 72.00283942684051, 127.18174672895863, 51.217250670156176, 26.431766094699984, 57.91400347986529, 23.6229391636387, 34.6814166345904, 46.8374889896762, 34.01125615642917, 58.58961997493621, 44.205766877820416, 39.58429305784164, 55.750055390019575, 40.92597507661389, 108.79308700561525, 51.51638630897769, 43.70435853158274, 62.3025591142716, 73.81506073859431, 62.30403392545639, 1.2496638274000538, 0.1626269525337604, 0.11272667411474452, 0.2332008873382884, 0.19482365148442407, 0.2377861840350013, 0.1340340997182554, 0.15636134922744768, 0.18270628556849497, 0.08340992949782841], [0.07531501548064333, 0.05280047662616257, 0.0790504755211934, 0.07390251788761347, 0.055600033862696546, 0.034087334999874715, 0.03177056828844211, 0.06910371248640361, 0.09386922067572033, 0.042080232918623, 0.06125345247827711, 0.04303449885018411, 0.04955497960890493, 0.1944102244752069, 0.38915415685023036, 16.049742544850996, 83.99775335865637, 58.228004901639885, 51.082258378305745, 36.19136441138483, 45.70057038337954, 47.703414963137725, 38.13211394894508, 49.60468584491361, 42.47648408336025, 36.56903374579645, 40.33867859071301, 36.523695068974654, 43.45482126359017, 30.045592823336204, 28.012412632665328, 15.715848822747509, 39.18596067736226, 86.04376362216088, 50.60857726681618, 92.60295498755671, 35.30193951822097, 0.9198524346274715, 3.6390894891754275, 21.348644994920303, 53.25260777627268, 56.056561162394864, 57.32960562552176, 58.1310478333504, 51.989726174262266, 56.46271474899785, 58.82796672082717, 53.5106683546497, 53.540239103378795, 63.34170087691277, 17.967312835877944, 5.922205313559502, 4.485508290029341, 2.888115928057702, 3.2281596814432456, 2.7902998607004843, 3.111506921629752, 18.649793478750414, 23.41054674117796, 13.288257641177024, 9.813477954556866, 11.272099556461459, 5.5077387536725695, 13.959143757820131, 13.449880865312393, 4.033270040827413, 4.684236155402276, 1.7275190761973782, 2.4247871771935494, 7.420825775592559, 10.142084321668072, 8.570224873481258, 8.192803628983038, 1.3403629992277393, 0.17322122840391052, 0.03452440348243521, 0.10701473787306778, 0.0775337363443067, 0.1365039212208602, 0.1036141884903754, 0.3547103228347917, 0.0037573167684322767, 0.12032612842778045, 0.10582370863806818, 0.1787124240710851, 0.11942279585186513, 0.20083149684773338, 2.704782875314836, 2.0587158010851954, 1.8782670387337286, 3.872443057837025, 8.368187508275433, 1.2277269916188334, 0.033066576466925686, 0.116078952297328, 0.13124875724315643, 0.04261064538431745, 0.06615163097458501, 0.14750969355865834, 0.1526625235114367, 0.04338444398355581, 0.09686645540979602, 0.019560680018677827, 0.01781445345841348, 0.12748280690322, 0.13723112252210418, 0.26417481803124954, 5.95462566421878, 1.9756933205550717, 10.591783081331561, 16.68075776869251, 12.99049581250837, 8.709714162734247, 11.577139342984847, 3.068789858971873, 11.35952820700984, 15.015013448653685, 4.927491747563885, 4.945083087490452, 14.862599949682913, 19.011653700182517, 19.587075210386708, 22.938444383682747, 14.849954228247366, 3.7690611472052917, 2.0127359393142887, 6.305542963166391, 9.75197813203258, 10.98995856700405, 3.778807256490954, 13.15474408288156, 59.6740690354378, 42.31841648778608, 49.571428068222545, 50.367512318395804, 49.41918519235427, 45.95952918452602, 52.967478921336514, 50.70960967771469, 52.429243441550966, 53.633289490976644, 30.886270499998528, 20.330058413167155, 1.864103972911835, 24.352835378339215, 72.89671621014996, 53.38220680913618, 47.6213982028346, 67.65070299948415, 43.17286952849358, 13.423745132261708, 24.17400275507281, 27.544930827233102, 33.30412341702369, 26.25532219486852, 36.14806144468246, 23.55306802257415, 40.09667619582146, 30.513890481764275, 58.1077842558584, 65.58761081387921, 27.94149814113494, 49.40646886825562, 46.851876243468254, 72.7958171598373, 7.420945407882814, 0.46924809775044846, 0.05802777032518099, 0.027222650936774673, 0.03780720515116569, 0.06969997403962959, 0.11696815821191958, 0.019988187723943306, 0.02572138865117825, 0.018797392145760598, 0.07842533245322206, 0.024536074432093772, 0.019334779842005625, 0.09398980291500207, 0.0503160190137644, 0.06805693760754601, 0.05268752462260666, 0.023087017208097443, 0.052121803164482124, 0.07706924957493622, 0.10860685244082444, 0.06510913852722415, 0.07707501821700605, 0.1000967494121963, 0.2805811118695044, 0.2967749235610808, 21.889082885557606, 92.82569070016184, 66.07937797423332, 39.963754915422015, 41.46245725693242, 44.226300485672496, 39.97749890050581, 39.626446770083525, 40.53882929586595, 39.58832133200861, 36.84485873868389, 38.93735301110053, 37.235664090802594, 39.04939551507273, 37.13392173090289, 34.86415593854843, 18.79131259456758, 42.74885739049604, 65.28859676853304, 53.02071332931519, 87.43480082481139, 44.839382633086174, 5.222824648503335, 1.8900688377118882, 24.979667394391953, 55.17687159199869, 63.0936227306243, 62.910208778996626, 64.78292872828823, 57.06617532237884, 60.49762948866814, 63.1583575279482, 52.76672809354721, 55.25037288665772, 63.698781690289906, 15.985265643365922, 9.579133006834216, 9.874191341861602, 6.517380860544021, 4.587736533534143, 1.7051614436411089, 4.759679513592874, 20.841178547951486, 29.17896278442875, 19.36431988593071, 16.67533116955911, 22.9208250968687, 13.442913755293816, 16.81064901813384, 15.643865485345165, 10.732103913061081, 2.4913990737930423, 6.557164970905551, 3.3670108500988256, 12.93463537769933, 15.283791903526554, 8.698314774420954, 9.252968315155275, 1.6745339838727828, 0.10657848144370703, 0.07151410088784273, 0.10348262055025947, 0.09216096717864276, 0.18313716406062727, 0.12883631572608026, 0.231875739090385, 0.178951014494223, 0.12353684122283613, 0.12335303374716353, 0.05396054824814201, 0.129589885773678, 0.4370082374061308, 1.0629667293640876, 1.1052389707296126, 1.2517229491664519, 9.114931283458587, 11.664373836209698, 0.8640458098342343, 0.07053720854943799, 0.07942629527420768, 0.09603758658012075, 0.14844533206234056, 0.11838082434429277, 0.19515037266237123, 0.18385215392035825, 0.08259544779937114, 0.2207839963657241, 0.026459604381553592, 0.01846877490020087, 0.03928715678592844, 0.3080090513873485, 1.469835535653176, 1.943206779899136, 1.0948237296073668, 13.746523837889395, 27.489401832703624, 14.126321058119498, 17.781951427459717, 15.999128280147431, 6.516639042285181, 14.731763409030053, 14.594454957592873, 8.959169060953203, 15.193451873717772, 26.462289979380948, 21.21060698263107, 20.708306297179192, 28.379093447039207, 19.47310290028972, 6.168790507701136, 3.8069357987373107, 3.9630211264856405, 6.133196469276182, 15.108661017110272, 7.168428119151824, 13.61660219007923, 62.944960978723344, 45.27832723432972, 54.829286836808734, 53.60352262373894, 54.85147568487353, 52.87191429445821, 55.340187318863414, 55.66555576939737, 57.23693570783062, 56.94210683145831, 40.01449077360092, 26.75532044902925, 4.522170684029979, 34.46169722464777, 69.5302321833949, 64.42620877296694, 51.23731751595774, 75.71631200851934, 31.243482712776434, 5.70194608742191, 27.92529679113819, 29.3687133250698, 31.004008285460937, 24.90626612017232, 34.46861628563174, 21.6396495603746, 28.26837278181507, 35.16221684794272, 46.253008765559045, 84.08745796449723, 29.492926943686705, 43.37043146933279, 54.335464354484316, 78.29855734302153, 9.184496479649699, 0.6464211294247258, 0.04815878819734339, 0.08489820850832809, 0.06747665664842052, 0.046463493077505025, 0.02231426431887573, 0.06391109192683812, 0.04191715961262103, 0.08338271805475797, 0.0588229657601445, 0.13081247017027872, 0.1702259165505248, 0.2429768740529976, 0.1425024049897348, 0.17497438997510942, 0.15455195680260658, 0.15763775896160834, 0.150765934959054, 0.20742291734824259, 0.28629667936794223, 0.20941258558342535, 0.21808218811788868, 0.20155882072304526, 0.4105798281248539, 0.7892535650922406, 30.46125423523688, 108.4038466791953, 74.30889498802924, 71.92443124709591, 52.82291996863581, 62.34187303050872, 65.04322898003363, 55.338920393297755, 65.82314522035661, 55.04677049575314, 50.33726692199708, 56.05060700447329, 50.30403660189722, 60.012906905143495, 39.336473787984545, 41.766821415193625, 21.88825330426616, 52.50231719786122, 103.87184604521721, 60.95574271294379, 106.0047838764806, 43.403626488101104, 3.178706438310685, 5.416277416290776, 26.56994923468559, 64.34938915314214, 66.2512170114825, 70.00674524614888, 69.34283702604233, 66.23275049271123, 66.0866500485328, 72.3249444653911, 59.96105709383565, 64.98549169109714, 69.98725891113281, 21.680479472683324, 13.80579379297072, 8.9338432973431, 6.6292091050455655, 8.665439428821687, 9.07136747913976, 6.807087611767554, 24.210206231763287, 34.48568251825149, 20.43111828065688, 18.100112522802046, 19.295880409979052, 7.634595440280053, 20.76608084863232, 23.99924155204527, 13.630272630722294, 11.768221528299394, 8.382294312600168, 7.72333808483616, 16.819058579783288, 16.190327155974604, 12.730934927540442, 16.444628142541458, 1.1967197973882, 0.34411977015195355, 0.1664525811229983, 0.2634486892530995, 0.21180471044874963, 0.22758039135125377, 0.2952692543547, 0.746744571914596, 0.5490826719230222, 0.23232121921835408, 0.29398152184101844, 0.47077745439544805, 0.24246911097678447, 0.421176815946256, 10.437527048972346, 7.397935313563194, 13.246464786990998, 10.11930613748489, 14.289629920836418, 4.187547401074441, 0.07007007111584948, 0.165079383840484, 0.38821508627264734, 0.21638400101613617, 0.5915909909432935, 0.6098926475932521, 0.7976138519663966, 0.25037049586253785, 0.5106028722178552, 0.1531560986392921, 0.23943586244938836, 0.18620612760705335, 0.9613189353577553, 1.3390106395367654, 15.531529784202577, 9.031607393295534, 23.631778224822014, 27.11894181466872, 18.32541738787005, 19.17351422771331, 21.407939464815204, 10.826143718534901, 20.565957600070586, 19.848132479575373, 5.841925182650167, 8.648972338245763, 22.425512113878806, 25.827185684634795, 26.85092822197945, 32.715014796103205, 21.215213806398456, 5.908359346851226, 5.982751509835643, 14.659544729417371, 17.956389034948042, 22.51453814967986, 7.683194587307592, 17.410163687121486, 67.24178806427987, 47.818603207988126, 60.018041287699056, 60.16247472455425, 60.09255455386255, 55.69764467977709, 59.81899669093471, 58.82032202136133, 62.57121401448404, 63.104001322100245, 40.27240622428156, 26.40252482506537, 4.843005364941013, 31.862542552332727, 88.14085883478965, 64.02500129515126, 58.373501300811775, 77.94593626453032, 56.07635344228437, 16.523798242692028, 33.99184434644638, 37.1289324760437, 46.83457466863817, 34.80789346079673, 49.9543769128861, 33.448447027514064, 56.65968833431121, 46.65363573258924, 71.26468073937201, 85.54708173198085, 38.18002570059992, 65.34673413922711, 57.915513592381636, 93.14138658585088, 19.576147487086637, 1.4140628638767427, 0.3170041493590801, 0.2061817936238743, 0.20862351502141646, 0.20426720200527101, 0.23834081637042187, 0.1617567532605702, 0.09987037043057143, 0.16962960903202334, 0.15214861641007085], [0.13056298597685753, 0.058912211172883554, 0.011663366890242024, 0.04191931615012788, 0.015821964104449558, 0.05414454341535607, 0.13484106609417548, 0.03761027458935015, 0.025242997385982065, 0.027065378831579324, 0.015112988034924193, 0.02304439016077067, 0.02313936591118334, 0.07552357525714944, 0.05265417681526273, 0.14800506133225658, 55.23258493792627, 73.69060393302672, 55.04884542957429, 29.96838685004942, 45.709976227052756, 40.72167450381864, 38.30154072853827, 50.07952013323384, 47.53213290245303, 35.41425658810523, 42.27039098739624, 38.86845657902379, 38.740732439102665, 39.76599685607418, 22.14169725295036, 22.355564486595895, 18.355921660700155, 78.69591697569817, 43.02177198471562, 54.345556612937685, 62.02279213936099, 7.8279579935535315, 1.6358626008995119, 15.516691457840706, 47.47288550100019, 60.67008826040453, 56.438219547271736, 56.35355126473212, 54.95728162027175, 62.367435116921705, 52.36437136127103, 46.098608586096, 46.929707834797526, 56.0379534382974, 16.180744805643638, 15.219129670050838, 20.114412384648478, 8.280398980263742, 6.05967850454392, 5.4483727005220235, 28.99503500230851, 32.62888935304458, 19.281840285947247, 14.802809299961215, 15.61934772999056, 5.680322060661932, 13.21397481426116, 21.23996788455594, 7.430041874608687, 7.794246202515018, 5.7115004908654, 3.373778899831157, 2.3073401374201623, 6.5113972848461525, 13.816478329320109, 8.0949051918522, 6.621081954048527, 0.9024026064622788, 0.6290903819664833, 0.0018472791834351337, 0.0940278545022011, 0.051440636086608135, 0.057718343582124486, 0.12548108044410908, 0.2714169229711256, 0.08988538726923928, 0.27839083585046953, 0.7753132163516937, 0.40692739669353734, 0.1335971384880043, 0.1791784353554249, 0.5715150133736673, 0.7708855345845224, 0.5717159122709305, 10.023444391066029, 6.190971511025583, 0.15656083852293032, 0.09750347284059371, 0.11714641155014116, 0.1264472705342116, 0.09735777057827481, 0.12856210221446332, 0.2639601601948661, 0.2081220032226655, 0.05126010363681182, 0.10085271731499704, 0.07702405804828291, 0.065104496034403, 0.06711503250464317, 0.17980869589073045, 0.1584915945967359, 2.076480951040022, 3.2886776856837736, 2.224999046133411, 14.439019272404334, 10.211639711933753, 3.638969121440765, 1.3599885783849226, 10.296664930159046, 9.624551111652005, 17.56148088362909, 18.544636695615708, 7.722966930558605, 4.82995661997026, 16.005228546357927, 32.89285505971601, 33.0644352205338, 37.958466699046475, 35.66746911694927, 18.92042329234462, 2.6624426053416346, 13.94625190765627, 15.102805899035546, 9.300233856324228, 5.899832114096611, 43.37256131633636, 49.604254384194654, 57.3347007843756, 48.53231376217258, 50.810787216309585, 45.74465782411637, 58.944394434652025, 55.321308951224054, 55.29065562832741, 49.732951271918516, 52.26516677487282, 41.326523596240634, 9.954129245973403, 39.168392381360455, 36.348121935321444, 49.083222419984885, 56.785976886749275, 35.60418559658912, 89.4916368299915, 66.9053977535617, 20.696688236728793, 31.278303553981168, 32.11106392645067, 28.976227237332253, 31.552230119705204, 24.20078862097956, 38.739088966000466, 28.60461404246669, 77.8569455300608, 30.433083772659305, 24.139717317396595, 44.24100545144851, 66.956984766068, 34.968459606170654, 0.7791965466833884, 0.2653432553333621, 0.12257160874263895, 0.09654393239367394, 0.11378082642031294, 0.11035381636071591, 0.08630453909356749, 0.05921026151026449, 0.07120034957845366, 0.07818822824065724, 0.026160527486354116, 0.09601127145992172, 0.07137469586826141, 0.04260994441386673, 0.06301132549021034, 0.08302147695494276, 0.030691077624778115, 0.059491768178920594, 0.045762802248880755, 0.0562245334168115, 0.02707894241827871, 0.029644159104434714, 0.08188655599951744, 0.02519707424536107, 0.08424478913507155, 0.036210256568606825, 0.22577892027554974, 64.08234242470034, 83.85787379357123, 51.40744639981178, 26.529258566517985, 54.581510713023526, 35.32215541408908, 44.46506300280171, 37.03985937180058, 40.023002316874845, 39.21446846377465, 36.67287457373835, 40.67939135336107, 35.82081417883597, 40.828331593544256, 29.489241876909812, 23.140138541498494, 21.40591944417646, 76.06071964386972, 47.84807589746291, 56.74601185706354, 61.27604346121512, 9.420162285527876, 2.975171708291577, 20.0377300477797, 50.41433365114274, 68.2477112739317, 61.88511302394252, 60.24722929923766, 60.00456402378698, 66.78788354319911, 57.069838816119784, 52.18381681749898, 51.93172608652423, 60.38299037564186, 16.97985614499738, 8.490019267605197, 20.554070857263383, 8.085709194983206, 2.5329352578809186, 6.29513152184025, 30.692326945643273, 35.446447480109434, 27.199728911922826, 22.357764936262562, 26.56298898881482, 14.795305805821574, 17.840220197554558, 21.89545869827271, 10.028668007543011, 8.08127691668849, 3.133584962737176, 5.146660064497302, 8.472512748933609, 15.766314037384527, 17.732810012755856, 14.16654202245897, 6.839754091155145, 0.6711263618161601, 0.8341989630172331, 0.1627423406969155, 0.9308329873508023, 0.5370905767044714, 0.20570732472885042, 0.19464598037302497, 0.31416346469233114, 0.12550183376597782, 0.2970859552583387, 1.0624866067401826, 0.6232275417254818, 0.2416097595086021, 0.1643513245207648, 0.5969618188758051, 1.3626578738612514, 1.132773273894864, 5.120334586789531, 12.14426798205222, 0.20463801920413974, 0.2567150521903269, 0.12639940536070254, 0.13659991203777253, 0.06879428957378672, 0.2234862336227971, 0.3050726670170984, 0.21931516066674264, 0.0690912712185133, 0.053590818894125765, 0.08733058363319406, 0.01824482824773558, 0.09939063851150776, 0.0642318759233721, 0.23660884479120856, 0.653827115893364, 5.009897803106616, 5.392496576232295, 24.198615627904093, 17.588427566712905, 10.677655531514077, 12.028586499152645, 9.557759031172722, 6.014198622395916, 15.926718384988847, 17.31080024473129, 12.009940531945999, 12.863004073019951, 29.680118137790313, 40.23624589366298, 36.87295859859836, 40.12282663776029, 38.83191185612833, 22.247989562249955, 7.233151639661482, 5.140323965780197, 9.831504187276288, 4.476658442328054, 5.622591635873241, 44.30909387526974, 56.91001792107859, 64.81103643294304, 52.41617410413681, 57.78563214886574, 49.50662659060571, 64.5351565268732, 58.68736151726016, 62.72291560326854, 52.53992488307338, 59.6430548544853, 33.8233079448823, 7.91127747105014, 47.57649098673175, 43.344539903825336, 57.135766013976074, 64.53584686402353, 41.82526080839096, 89.00005402103548, 46.655942086250555, 22.667806725348196, 29.106802940368656, 29.260916786809123, 27.564628970238473, 31.363897515881447, 17.343151953912553, 34.575379279352006, 30.673326984528575, 77.76964925950574, 44.89292298593829, 16.60896270505844, 47.84605587682417, 73.33841431525447, 36.18237826132005, 0.812536386712905, 0.2954242799070574, 0.1526482436325281, 0.04521715612481198, 0.014476308640423081, 0.06271907060797657, 0.11461163345243662, 0.027942181782676812, 0.21713249956167516, 0.0016864819964769507, 0.054003303615196105, 0.1794275518266424, 0.16577846971490692, 0.11388665380617304, 0.25532009801076305, 0.1414423691289079, 0.09603773213682637, 0.15981533324285863, 0.12736634621697088, 0.19666937179863456, 0.14957263044291927, 0.11606571429799642, 0.1443174051781816, 0.17955922701906774, 0.21104614550788559, 0.11294641111406589, 0.623633936047554, 87.35625928448093, 90.53066484389767, 73.22987448784613, 44.62072226309007, 66.6842309890255, 54.81597823481406, 57.26642408678609, 71.66368776752104, 61.77168984566966, 50.87706742748138, 58.22312547314552, 54.15892631776872, 52.386936756872366, 55.26061811754781, 32.48569538516383, 32.6204837137653, 24.092056597432784, 92.79557474197881, 52.41171829162106, 67.54341048579063, 72.22431213625016, 11.168364632514216, 2.61478262082223, 20.103492506088752, 55.71050220920194, 76.94014641546434, 64.28027306833576, 67.66377233689832, 62.57907444430936, 77.15843416029408, 60.645538145496005, 55.799171309317316, 56.08154273802235, 66.13112972628686, 20.220508575439453, 22.798976667465706, 36.02315748891523, 20.63160042608938, 17.670781650850852, 7.3930539238837465, 37.46127097837387, 42.83930724666965, 29.533682330962154, 27.161913341091527, 21.34892544438762, 7.935897698325496, 20.316000638469575, 29.6146478960591, 15.341389948321929, 12.331710207846857, 7.570140111830927, 6.587506955669773, 11.673628668631277, 14.203021045654053, 18.12721610069275, 13.888350859765085, 14.857238069657358, 1.2732472006351718, 0.9785481914877893, 0.20692554242428274, 0.6218574700816986, 0.38633519843701397, 0.4091264980454599, 1.6044026180621118, 1.2891223810372816, 0.21013298402390174, 0.7129354570661822, 1.4101309329271319, 1.3956350785109306, 0.6544938575356238, 0.3370846621692181, 5.544978716681081, 2.247336453968479, 1.7042252229106043, 17.97609894506393, 11.353358318728786, 0.6122282964567984, 0.5424136007505079, 0.31872125883256236, 0.4734547478297065, 0.28597167422694547, 0.3857939113532344, 0.7386642442114892, 0.16349770339025607, 0.17742862924933436, 0.22266518655082873, 0.3039315330886072, 0.1370012348577861, 0.15098949473711754, 0.4219877659793823, 0.396140112631744, 4.477239443409828, 6.6363605664622405, 13.93162048632099, 25.551356769377186, 18.80633919469772, 14.404153323942616, 11.49876940634943, 16.985837759510165, 11.133133903626474, 21.82664267478451, 19.80486873657473, 9.76574957370758, 6.568486402111669, 21.185311617389804, 41.45213357863888, 42.49377389107981, 45.49966266078334, 45.63245842533727, 24.516127570982903, 9.769990636456399, 27.17648102391151, 26.211020984957297, 16.564116285693263, 7.7736733709612205, 51.08303500759987, 59.2426279283339, 63.46993884732647, 56.80687527502737, 59.87737332620929, 55.054399505738296, 67.40043224826937, 63.886263139786266, 65.84306301609163, 58.76356140259774, 63.38243469115227, 48.36089049616168, 15.111916584353294, 50.85550615864416, 49.30132581341652, 62.13986704426428, 67.42308001364431, 44.510966500928326, 109.01344576189595, 89.45772401748165, 32.46820553656548, 42.97278158126339, 43.0746376898981, 40.94414741762223, 45.782771495080766, 35.558588043335945, 56.5933257533658, 42.927717470353656, 90.34789808334844, 46.43088825287358, 34.70146779091128, 60.678376228578635, 78.52911426175025, 57.20096757335048, 0.6912369665599639, 0.2720778729886778, 0.17860802160876413, 0.17941034549186308, 0.22613239324381276, 0.21327601295084725, 0.16767161087163035, 0.18399783320003943, 0.3004417268018569, 0.15334706903705675, 0.09034769068802558], [0.03749590915357394, 0.042302923186892466, 0.0968791418258221, 0.016035120408501358, 0.047827194700197834, 0.1363769804518069, 0.026495972490538994, 0.10694047330968803, 0.08319409188604163, 0.10575581792621844, 0.06505740460969749, 0.0601252960792232, 0.0704818740186672, 0.12856748015169175, 0.23149346121616904, 0.4811734513890359, 16.480897318932318, 86.07023177608367, 66.76712636024722, 54.9033490304024, 31.485430194485573, 66.6507339477539, 29.04180338305812, 52.32739910002678, 49.548180180211226, 36.796072298480624, 38.02748864696872, 39.648078641583844, 36.77939045813776, 46.94499723372921, 25.602933975958056, 24.126916662339244, 39.28115660144437, 57.96502174869661, 57.65154200215494, 59.98732912924982, 56.16361048913772, 9.620690518809903, 0.31953941009217696, 15.236657761758375, 47.725093903080115, 63.08043964447514, 54.422019297076815, 60.4290743027964, 56.410766878435695, 57.030152274716286, 49.26575776069395, 62.68959899102489, 57.96905394523375, 55.95195547226937, 16.12433425841793, 6.841932477489595, 13.013499532976459, 5.718221472155664, 12.576394523343733, 44.08235734508884, 44.93601022228118, 30.31913695796844, 26.458208753216653, 22.037189622079175, 6.463512499486247, 14.465395250628072, 23.99261078526897, 14.37987679435361, 8.156191735498368, 10.194316564067718, 6.283881183593504, 4.728079918892154, 1.9232633661839271, 7.687051257779522, 14.91254250849447, 7.57113149089198, 2.527516503487864, 1.051200354291547, 1.1958837196711571, 1.420292323154788, 0.38105228675469277, 0.03800849092283076, 0.5047646080774646, 0.19277700162943334, 0.09367179981763325, 0.09975901955077726, 0.10083659882507018, 0.12743172416042897, 0.8727526135983006, 0.09559922340896823, 0.335538788668571, 0.2597575244163313, 0.40963643681137796, 0.1987640400447192, 7.640309843324847, 7.585285363658783, 0.080691619716104, 0.05091630635903247, 0.026245888833317067, 0.120709371572781, 0.2795603763191931, 0.21861878674357169, 0.06188561291163487, 0.1401053924834536, 0.3685234703363911, 0.062331629301150965, 0.01253567003239427, 0.08777352801013379, 0.02854882382727679, 0.051134779313278776, 0.06266170977464607, 1.0808070172225277, 5.488296545320942, 0.3523120386225562, 12.69486677262091, 4.276697481832197, 2.4613193975340937, 7.237509883219197, 7.6911011049824385, 16.32666482079414, 17.848390494623494, 16.135264923495633, 19.60826777642773, 14.1274614872471, 3.8831805461837403, 11.811541165074996, 36.02355364830264, 45.60137756409184, 49.49463982735911, 64.17194112654656, 46.94456969538043, 11.366340383406609, 14.004561862637921, 14.144467903721718, 0.9040189294084426, 41.425555598351266, 54.29000800655734, 40.99403996621409, 52.58546360077397, 47.34631061553956, 45.53172803694203, 43.25355660530829, 38.85735234906597, 40.56080241357127, 47.26827113859115, 48.719818745889974, 13.970957936779147, 9.461567805659387, 59.37989519488428, 53.38885914894843, 41.83967551877422, 58.741007774106926, 63.335123062133796, 60.37203911812075, 72.1007025626398, 19.648193582411736, 33.154924300409135, 23.690211734464093, 33.85328269773914, 29.481661896551813, 33.78878324262558, 36.367110129325624, 62.08026662949593, 76.69735170179798, 15.64147185894751, 44.12604470406809, 47.07662413197179, 63.18128378160539, 2.9908180429089457, 0.04962483533628045, 0.06970404962738676, 0.04768265306108421, 0.11412735863198196, 0.06753511681792236, 0.02532140073937274, 0.0406070381793524, 0.07273523737826655, 0.09326709088899436, 0.007370768927954018, 0.028444999761338678, 0.042597476332899065, 0.022510696923540487, 0.07574750275741662, 0.05444936980042727, 0.0381801865484205, 0.15961153853324153, 0.027721203720918106, 0.027367010630006273, 0.09126840579894283, 0.056755064626134215, 0.08353746781546263, 0.04453270636018246, 0.14248244073842803, 0.1904397899465215, 0.2931299385043883, 0.49451373878025245, 19.390760583262292, 96.27080255939116, 74.85188438046363, 39.31737968998571, 36.704418274664114, 60.01268333004367, 28.25759803095172, 57.590027470742505, 29.586228362975586, 42.026599991706114, 35.62975160537228, 39.96984635629962, 34.17381878822081, 40.38171483624367, 29.89585045845278, 27.498437012395552, 32.96533261576007, 67.49918968446794, 57.252005454032656, 69.15959173633208, 55.31197371021394, 11.267118146342616, 0.9415936421963477, 14.673209286505177, 55.80357220865066, 69.1506330428585, 60.80875973547659, 64.87883852374169, 61.07832070319884, 68.34566854661512, 55.68998036846038, 65.63696992012763, 63.09444250599031, 63.78028854247063, 14.959834525662085, 10.104360926535822, 5.006241173513475, 3.1288884147520992, 14.044725952609895, 41.10448606552617, 46.63799724271221, 40.46785400759789, 32.58288583447857, 33.385975437779585, 17.199183317922778, 16.94158950159627, 21.735427956427298, 15.720314441188691, 9.586330556100416, 5.359205459394763, 6.71942558019392, 8.32378431673973, 9.986201486279889, 13.822877676256242, 19.122531260213545, 11.933438624105147, 7.424987410345386, 0.31012287183154014, 0.32189798030641775, 0.462519608798527, 0.28000326706997813, 0.2849863625822529, 0.03791754862533943, 0.08508272078489104, 0.046764060013717225, 0.04433140909719852, 0.06240091812346251, 0.07065870243334962, 1.4828422377186439, 0.18303075444794473, 0.5215926792833113, 2.2286343478387405, 0.3935458937719945, 0.9896825746663156, 2.4928947225693734, 7.309065191976487, 0.12204911379564194, 0.13518712333133145, 0.04967063207239394, 0.07981678561097191, 0.13561830825863347, 0.22388749515577672, 0.015610988278152242, 0.17178945603870577, 0.3436663993183644, 0.10082284754682934, 0.030172596978504333, 0.04238790148989328, 0.03957876432386618, 0.03077824693924237, 0.04276677410328581, 0.9022772744778664, 8.650211807220213, 3.7175322348071687, 15.83011531060742, 17.00313933434025, 10.963517869672469, 6.627683303048534, 8.504677164939142, 11.32036824380198, 13.979353770132988, 14.878138419120544, 19.573188058791622, 16.501946718462055, 9.54542023520316, 25.698012228935, 45.61935378659157, 48.78965262443789, 51.027404031445904, 63.3540367311047, 48.48763012116956, 16.877425409132435, 9.637188988347209, 5.114320612722828, 0.5039835967604192, 41.62564746795162, 61.99326453670379, 50.32810034290437, 55.29783356574274, 49.756591396947066, 48.361737728118904, 47.86494208920387, 47.09673020147508, 46.481749626898, 52.49246812635853, 53.44711026837749, 14.382460655704623, 13.37735624082627, 61.23044198559177, 58.37507417125087, 49.77778396298809, 64.28270886021276, 64.0927327832868, 64.7412496228372, 73.81291912448022, 25.683905424610263, 29.07287051600795, 24.281693389338834, 30.634430800714803, 26.26489277808897, 25.14309490880659, 36.694094596370576, 59.50854893653624, 88.29705545979162, 13.373469171985505, 38.31666538792272, 60.72368744880923, 63.455143667036495, 2.467962912013454, 0.26433489976390717, 0.0846812600690511, 0.08404401281187612, 0.03610291998953589, 0.02807958922799557, 0.026716580914874232, 0.15485214069485664, 0.07913886674589689, 0.035623391083772146, 0.04484513999834176, 0.08243057035630749, 0.1458629569219005, 0.12563697933670015, 0.3824298967036509, 0.14892174682069212, 0.1499529318102906, 0.27312551354688985, 0.1773623320003671, 0.1982941523554825, 0.22412358813228148, 0.3266329246182596, 0.17242086570589774, 0.1975997855826732, 0.32431517156862444, 0.43406691942964837, 0.35331153821560646, 1.1086931079626083, 30.368694143910563, 108.01738339085733, 85.9475871055357, 74.89031576341199, 44.396688245957904, 88.64020009194651, 40.64057950050601, 77.1475221264747, 67.50274335184406, 49.58825111389161, 52.7896818037956, 54.06031400926652, 51.700321935838275, 60.484446402518984, 34.94736117701377, 32.58880076869842, 46.091591465857725, 70.08690280299034, 65.13895442408901, 74.32227811505719, 68.98117096193376, 14.290311432653859, 1.032149157216472, 19.467152664738318, 60.19663072401478, 71.62978279975154, 66.40656640452724, 68.19297067580685, 68.51014137268066, 68.07590361564391, 58.603289434986735, 70.95908887924688, 67.0518982794977, 69.67630124861195, 18.067537238520963, 19.035856685330792, 22.5805575232352, 14.253500969179216, 16.743741227734475, 54.826682383014315, 53.54171391456358, 41.71153168524466, 36.88973457582536, 29.09837376686835, 10.45143283182575, 17.43525116674362, 28.044293657425914, 22.395788392712994, 15.101811578196866, 11.509296067299383, 10.127237169973313, 10.825624985079612, 10.417418037691425, 13.691173311202759, 19.60967786850468, 11.95772005665687, 11.429350318447238, 1.6038100950179563, 1.3726415316904745, 2.9421487835145768, 2.6824219332587336, 0.5896720939105558, 0.7640249414309379, 0.2750438283528051, 0.14727828904025017, 0.3338781551968667, 0.1370493451794309, 0.2845086607961886, 2.274587611036916, 0.2170656813729194, 0.5152044865873553, 2.3389583633792017, 0.8059001653905838, 0.9068449971175964, 18.16337250894116, 11.470401844670697, 0.15000442824056073, 0.12894131573698214, 0.21679338308111315, 0.2814106318739153, 0.47839549400152703, 0.6796942278742791, 0.1597319981984554, 0.5097592561956376, 0.9063573361885164, 0.18676572419222326, 0.13342293009402292, 0.2084104353261571, 0.2500023752931626, 0.0687561460560368, 0.3689055030624713, 2.5748960385399484, 8.176101686493043, 8.377664935204292, 21.328136882474347, 16.308676831183895, 17.575758311056322, 7.705208399603444, 8.930838761791106, 19.5903778460718, 19.433790945237686, 18.586164789815104, 24.668639129207982, 18.02697208619887, 4.10755556437277, 15.353200204910772, 43.52787540804955, 52.4337580896193, 54.42545529334776, 72.0798747770248, 53.03492799881966, 21.496545807007823, 27.089888818802375, 26.87057145180241, 2.8654544343871455, 49.28205520875993, 60.1964581397272, 51.385641944023874, 62.33481276419855, 54.78417173508675, 53.111688783091886, 52.40044539974582, 49.39864373976185, 48.3771526428961, 56.7187866856975, 60.05387213922317, 19.2043460184528, 12.594262880663718, 71.15836097348121, 65.30112481886341, 53.33646020581646, 72.82831007434477, 77.02821931531354, 69.4748483165618, 91.37285263307633, 35.02198426954208, 48.08928205120949, 34.71411351234683, 47.263313262693345, 41.73707808217695, 49.348813949092744, 54.905608315621656, 79.76102875125024, 91.99070438261955, 24.231232097071988, 61.59397117553219, 63.34223039688603, 84.99277237922915, 8.586149696380861, 0.7139465092651306, 0.35757788186592443, 0.16450359215659482, 0.27300542160387964, 0.21470784660308592, 0.14449909059030397, 0.30820618113202436, 0.1882525629574253, 0.20807519525049195, 0.15021234450321044, 0.23449608154835241], [0.05003262010793533, 0.04693607739623516, 0.062385240134092114, 0.10583594306221894, 0.030061100542004553, 0.10333573851253718, 0.058779731588137735, 0.057978510871649756, 0.0620465679845262, 0.07613530412556664, 0.13733362508637292, 0.058940181042999036, 0.06868070171725366, 0.10623099162213265, 0.3583808032976043, 0.19921679800796896, 0.45060893340456876, 63.41893234560567, 67.66868314435406, 72.40775354446905, 37.433873222720244, 87.00847841078236, 68.51411081129505, 25.21169520193531, 66.10084118381624, 35.02088208352366, 37.156130190818544, 34.933605424819454, 34.63422659904727, 39.54423781364195, 32.05812565742001, 21.368299991853778, 30.127725293559415, 45.758284138095, 81.01009968788394, 67.73890141517886, 81.8094002815985, 45.243398527945246, 3.7148385470913308, 11.75841756405369, 53.54722876702586, 61.92771388638405, 61.53462963719522, 60.987894381246264, 51.90706614525088, 37.2476783106404, 51.19274762368972, 57.14114358348232, 45.19926401876634, 49.77746625100413, 8.40016463110524, 4.383206992380081, 12.74472107810359, 13.683680603581092, 58.88171888166859, 55.9877117987602, 41.41381202205535, 38.71106755348944, 30.67820445183785, 7.304203904444172, 16.15156335215415, 25.222566050867883, 19.487205782244285, 18.646408473291707, 11.514525567331622, 13.493430941335617, 7.328248033600469, 8.09332496696903, 6.495890194369901, 12.755442876969616, 13.285313902362702, 7.4147259996783355, 2.893778849993983, 0.32525402764158867, 0.5495113134384155, 0.15836025648299726, 0.7594675150129103, 0.2164913758996033, 0.5535436938366582, 0.15792703376181666, 0.23685976922992738, 0.2939641163233788, 0.2761430419500797, 0.37939438055599894, 1.3160880631016147, 0.47940581075606814, 0.0787735500583245, 0.877343257588725, 0.15972182455082096, 0.6543894857168198, 4.893581876831671, 8.641056995238028, 0.1198266774055458, 0.014083695282498676, 0.06444036675196502, 0.06828350811115197, 0.015406179459645383, 0.11995128926730926, 0.2029211855223102, 0.24706340154572842, 0.29149363598515915, 0.20754645668691207, 0.22491829710141306, 0.02325105770010381, 0.17111001265866144, 0.015074083217299514, 0.05972500747790741, 0.7836413275330298, 4.279606409611241, 3.9121210190557667, 14.221828810630308, 5.601441725607842, 5.625077928266218, 11.720341155605933, 11.82085777482679, 10.249163066187213, 15.940847742942074, 19.9513594565853, 17.81430313664098, 22.12828274696104, 19.69981589624959, 5.564372385701826, 7.809187000797642, 36.229085845331994, 51.108357829432336, 45.99134745136384, 54.847341506711906, 50.75913352351035, 18.744750138252012, 4.73764265737226, 0.603392789921453, 23.941082608315256, 35.01061331841254, 39.86419731570829, 55.575643277937374, 38.619817533800685, 45.1419307339576, 37.278982746985655, 41.75606627618113, 41.29809425723168, 52.07653999328614, 49.4592482812943, 30.63292657175372, 44.019964202757805, 61.730936419579294, 50.858534228417184, 57.80095684912897, 57.228934072679095, 57.15376184832666, 47.59346308246736, 34.66238529451432, 17.855034989695397, 25.524482650141564, 24.984482103778472, 29.284048964900357, 23.254185376628755, 40.94334725410708, 40.36517812359718, 89.51458269549956, 18.536389912328413, 37.02204788884809, 56.55512579025761, 65.11275691370811, 18.132173976590558, 0.8493759002416366, 0.3567025191601246, 0.21206533356058985, 0.08058406863241427, 0.02510739790816461, 0.014861118435228785, 0.07778770981296416, 0.0472092681804732, 0.10783878034882008, 0.0608722739402325, 0.11034063198753905, 0.04972643008635891, 0.022470029146080057, 0.03907387407736913, 0.06625779543913181, 0.17330298530718974, 0.017930540676799514, 0.08866704699973907, 0.06539445265286392, 0.08112013865742954, 0.07665868007367657, 0.08949167170231381, 0.020339394987170255, 0.04805547357987493, 0.05119726910526234, 0.11860167217110434, 0.23801907476398254, 0.13439573918379125, 0.27820473777190335, 68.45631860917615, 79.64997860693163, 70.6870646630564, 32.401829227324455, 96.05106353759767, 48.836964253456365, 37.974226782398844, 47.32477288092337, 31.326538901175226, 39.13149856751965, 33.695807380061, 41.279008003973196, 32.57084415804955, 35.86709030212895, 24.875312735957486, 26.32624060876908, 56.01001439555999, 79.86686214323967, 71.80210036616172, 86.3145483693769, 46.78170504108552, 4.237298254043826, 10.748665140521142, 64.18555959578484, 65.88664054870605, 65.84227069731682, 63.743390806259654, 59.28516603285267, 48.235657061299975, 59.04356764208887, 66.00229555560698, 52.23435655716927, 51.99283661380891, 8.74116764914605, 2.565921655585689, 7.334138943303016, 17.13897297459264, 56.084009908860736, 57.70214449974799, 54.49712091876615, 41.421103708205685, 42.25417590910389, 20.650168926485126, 17.88672185713245, 23.09757298038852, 20.350278231405444, 14.595871913817621, 9.109968504598065, 10.279758534123822, 9.081188113458696, 8.586882199010542, 12.921089472309237, 16.252832085855548, 18.652560710906982, 10.370143671189586, 6.132224702065991, 0.1614088880559129, 0.5696140121548408, 0.3151397671430342, 0.20804565490013172, 0.34303376391049356, 0.4790270875298208, 0.13396708234663934, 0.24953481651121573, 0.218409261696281, 0.2184830512851477, 0.2997409095687251, 1.0159902178472089, 0.23135596375551917, 0.5905288253580371, 0.4939128500559638, 0.5490420386195183, 1.6081305857627624, 4.288081180664801, 10.563191944553006, 0.28222060131449855, 0.04565834232996549, 0.05635232837390035, 0.02706007175748387, 0.035680043285772685, 0.15305365736205734, 0.12048549769866852, 1.5464325609707064, 1.0921858130924165, 0.11510375301323592, 0.10872611700887642, 0.04903677475428389, 0.027691471848576784, 0.03486756107679779, 0.03973485856887795, 1.1273689832418197, 11.960107799499266, 6.976755126830071, 11.63502077902517, 13.192703800816691, 8.763073105965892, 6.378866280278852, 8.749719396714243, 10.571560321315642, 14.091243301668475, 16.99843249013347, 15.866878705639994, 19.858893502143122, 20.674640593990205, 13.806938144468493, 20.379607754368937, 49.41587078955866, 53.223668529141335, 50.63821861820836, 58.08567777756722, 53.66640213997134, 21.814265635705766, 11.465041925830226, 2.5423994468104456, 19.30458022702125, 48.74002679701775, 41.15602208722023, 59.04505422038417, 43.41978273084087, 51.727688312530525, 39.523649292607466, 46.69729563497728, 45.214180792531664, 55.95932952819332, 51.827273368835456, 34.90834143853957, 50.264695229068884, 62.45824583115117, 53.17920846323813, 63.35311889648438, 62.22700642001245, 56.14936444067187, 56.907103600040564, 45.36833778504403, 19.579838437418786, 25.078838640643706, 22.334797497718565, 29.762515368000155, 17.624081911579257, 37.90036070731379, 43.74739085474322, 90.28601092676963, 24.898897947803622, 28.75780417073158, 62.38998090067218, 71.39196165146367, 15.994898984509131, 0.7690962596285729, 0.2968032688142792, 0.17902367027296176, 0.02293590828025293, 0.0400084821927932, 0.009680258282910912, 0.06447651844111181, 0.029121535837710388, 0.03763960809597085, 0.020964938336082047, 0.11933609002059507, 0.0274708730003406, 0.18629822669731033, 0.1738109016009877, 0.18422424282518127, 0.2703598748532034, 0.08069420909328807, 0.2787230422179545, 0.12289803114629562, 0.35771988392356907, 0.20916688586435012, 0.15748595097853293, 0.3634972900392548, 0.1939893204478487, 0.16247019562269413, 0.20699410729350584, 0.5265927206604711, 0.46555147836765937, 0.7344619148681242, 92.27180496338876, 83.80142304205125, 101.8665264498803, 53.68674355168497, 106.37353374112038, 83.96771584787678, 39.453140766389915, 95.24915064534834, 49.001052687245036, 49.61745708219467, 47.66799988285188, 50.52260283500918, 53.386654776911584, 46.16198624334028, 33.42985107052711, 39.07764050268358, 58.766773823768865, 94.13708809883364, 80.05692451230942, 97.80116235056232, 57.42683333735312, 5.599941909313203, 17.922864537085257, 66.65253823803317, 75.02575520546206, 69.25230087772493, 71.80930968253844, 60.45792333541378, 49.43727908595916, 62.6486651359066, 73.03652517257198, 56.71398178223641, 58.98240612399194, 11.310223033351283, 8.86226200288342, 21.37918064671178, 17.570292488221202, 68.4241787079842, 63.63361935461722, 52.18256950378419, 45.31543677853, 41.80988511731548, 12.550016583934909, 18.590565689148445, 28.54743176890958, 25.933228923428445, 24.718421851435018, 17.041154946050337, 20.187237070452785, 11.168588207614038, 10.38480451030116, 14.41059091398793, 18.719144905767134, 22.397677013950965, 10.765719606030373, 5.773638679135231, 0.8081072340569189, 1.0142523014257032, 0.7888430645388942, 1.2215061125255402, 0.5367351731946391, 0.9276773792601402, 0.40516662020837113, 1.4354650315738495, 1.0708630733912992, 0.4576300985870823, 0.9074782147522896, 2.5767152828554956, 0.8268196976953938, 0.6107928928348326, 2.4698333922893774, 0.6611384751815951, 1.3745165472069096, 15.68357458037715, 19.96683712928526, 0.1995426458456824, 0.1401772668525096, 0.1704638787815648, 0.11949738217217308, 0.09546079132105074, 0.2980552403436553, 0.20921213101715813, 0.6047632292874399, 0.7006768245370157, 0.27872708716219474, 0.3446163177009552, 0.13689720011766882, 0.34431239529963464, 0.14843511244943067, 0.17947642823621152, 3.9443800622417085, 12.052659065492692, 9.519393347924757, 21.687343620484878, 12.543653518922868, 13.029139003446026, 11.372859362633, 12.045305602012142, 13.65583275595019, 22.196055419983406, 26.170585270850893, 22.396090415216264, 26.98063119765251, 26.33498553306826, 8.77361741758162, 10.938692208259337, 41.96795271288964, 58.215633746116396, 55.47289286890338, 61.773949130888916, 59.370328534033995, 27.097625693967267, 10.59406295899422, 2.596228093870225, 31.085617119266143, 42.61164111475791, 43.74581013956378, 65.41730542336741, 48.04859530541205, 56.19980219871768, 46.7402377436238, 52.544290481075166, 48.78016833336123, 62.266583135051114, 56.82373362202799, 38.566410541534424, 53.88727472674463, 74.10803825624528, 58.84258931682956, 72.04789177063974, 69.0121498415547, 71.55956452892673, 59.328735720726755, 44.55011175524804, 29.35433783838826, 39.05294918244885, 38.13613045600153, 41.77820805580386, 37.88523997029951, 59.96432050581902, 57.40465233402868, 107.45715125914543, 33.60977019033125, 50.33826712639102, 72.73889572389665, 82.07465448687154, 35.491507668649, 1.1318388917753774, 0.4754799165793004, 0.29317437160399656, 0.16336071154763623, 0.11288074971807581, 0.1191563351500419, 0.17587546259164813, 0.24442409075075583, 0.2343026290257131, 0.1915577267326655, 0.2118871415094022, 0.17936649461907728], [0.03894339398210568, 0.040090434448493105, 0.06830600811348808, 0.06655155951457639, 0.04476103503557463, 0.044125254836774645, 0.15372534793230797, 0.01016505021271446, 0.06850824766461888, 0.07123371270755607, 0.12258938198248226, 0.05122793177443166, 0.041125311981886625, 0.10603816729159125, 0.33432824717413995, 0.30237530207922386, 0.3449470225361086, 9.238748742688088, 84.05269792003017, 66.22918898059477, 61.22317775603264, 28.318200611299087, 108.85471528576268, 24.776631785977273, 42.44419905447191, 51.395569462930005, 34.92578421869586, 38.164822593812026, 32.030708289915516, 36.97204551389141, 27.636139662035053, 26.03414954677705, 80.0357594028596, 86.13058920829528, 49.4558907324268, 75.50184465223744, 58.558735232199396, 94.16743155448668, 17.545926724710775, 9.878786398518471, 60.75803956677837, 58.89400766741846, 57.56145692640736, 47.854673324092744, 59.22738952021445, 50.00170423138527, 55.63118403957736, 51.144514237680745, 44.473649071108916, 36.71043519050845, 0.4443295558373775, 5.802179805694088, 16.748171544844105, 68.78731958327755, 60.81860096223893, 51.131656708255896, 45.70680302958335, 34.97887349897815, 6.507251829870286, 13.085776067549183, 27.610324582745953, 21.844575751212336, 21.792557277987083, 14.587155426702193, 12.90979402680551, 9.440996935290675, 13.006547131846029, 14.301625509415905, 10.330385546530447, 10.457334037749998, 12.426458001136782, 7.405602566657528, 4.731623780342841, 0.2595891076470575, 0.031083582772783218, 0.06326608036855055, 0.16972863355711584, 0.1236617748415278, 0.07125713201540132, 0.10954735560282584, 0.1527786624407576, 0.04746386601078895, 0.024482413803437547, 0.06881270632748643, 0.12449466563280552, 0.08565177855592582, 1.4720352498754379, 1.389538244374337, 0.0839406522291322, 0.6813867306036334, 0.9091199105305057, 5.536983945677358, 0.06437626817534048, 0.04886859930270622, 0.1758369436908153, 0.1666175045313374, 0.09325174614787103, 0.12118610808806074, 0.09367789021663128, 2.2112697699377617, 0.7032623406379455, 0.12648042681957447, 0.03631266337188502, 0.24948711987705002, 0.16049335169936382, 0.1332640741020441, 0.06484967220814959, 0.5437653475711423, 3.638838947780671, 6.030164630182329, 11.928149307927779, 14.457554432653613, 11.793929723001296, 15.607893428494855, 16.053725711760983, 12.754782938188123, 12.114353045340508, 16.936394322303034, 25.466480601218443, 20.525153183167983, 21.081300166345414, 23.77389354090537, 10.004286554551895, 5.901916363546926, 33.131088056871974, 55.72239091319423, 47.16737601064867, 43.15330474607406, 54.442560749669234, 26.446363195296257, 1.7941444559443382, 1.2661008873293478, 39.56302596676735, 57.92154619770666, 38.87138658954252, 55.37749298157231, 45.346090101426654, 58.443350868840376, 55.15937782103016, 62.91031468299128, 57.96842636600618, 57.98693210847917, 46.79470769820675, 64.5527091333943, 51.90484216136318, 58.21504146822038, 50.712661281708755, 58.752900400469386, 55.083605474041356, 57.90568413272981, 43.467612112722094, 24.11101733484576, 22.312536085805586, 27.768203904551847, 21.33419498320549, 38.97467436329011, 40.374199574993504, 75.50418238486014, 49.95057613618913, 28.638803382073682, 58.29219841188001, 58.08814102603544, 39.6905618329202, 0.6495502615167249, 0.26795046704430736, 0.13083329244006064, 0.06998888111763424, 0.06769468527167075, 0.06322289982269849, 0.06762230528458472, 0.07957216607586992, 0.03519922352185653, 0.044734310058336106, 0.03756310272541258, 0.037712692883947206, 0.018906069378699028, 0.014517212947530132, 0.03118183929473162, 0.009055220552029149, 0.03781098962551163, 0.04741608127651196, 0.06892742033326818, 0.01423064148008463, 0.04273269851241381, 0.10806666086277655, 0.0755979470728386, 0.1737669128323755, 0.13545649516726696, 0.09094843385560859, 0.09329482327185332, 0.3174338633975675, 0.5123046599328518, 0.37181795484596686, 11.411031869149978, 93.762172268283, 77.38699067023494, 50.37451767152356, 35.73137237179664, 101.27117341564548, 25.813071035569717, 54.653415603022424, 29.35897407993194, 37.94137300983552, 32.72030215109549, 36.68425729197841, 30.398351184783447, 35.905039233546105, 23.679676248181252, 84.14153175969278, 91.60845371984666, 57.615467963680146, 81.3515341666437, 68.18314121615502, 90.52289855095648, 26.952627435807262, 9.440935157960462, 64.95873720415177, 67.87873391182193, 65.21289894657751, 50.356188435708326, 59.70203945713659, 51.17108045085784, 64.22451657633628, 56.31132694982714, 49.05456558350594, 39.97750282287598, 1.0980330864267966, 3.0356159229432387, 21.946274965040146, 59.172688145791334, 65.60942703677763, 61.56986036608296, 48.26558082334457, 47.51483524999311, 19.08552565882283, 15.625254819470069, 24.548432211722098, 19.10277428165559, 16.63222824373553, 12.642284458683385, 8.385846999383743, 8.501711853088873, 8.440137505531311, 11.262819228633758, 17.345625008306197, 13.932094112519296, 17.741280371142974, 10.327024075292773, 6.133696081176882, 0.4512600162096562, 0.0391234974226644, 0.11836452199326408, 0.5269263059862199, 0.364159281936384, 0.10247285537902387, 0.7024676929558478, 0.1318538900945456, 0.05457383993592474, 0.28143655628927294, 0.2740144819742249, 1.2390891174154899, 0.12907174986697015, 1.6789743520559806, 0.5616792411573472, 0.1316480882345669, 1.4035328934269569, 3.89622365274737, 3.8108971474632143, 0.24135823752130234, 0.12649558769959596, 0.11069322395468913, 0.1517246020657401, 0.1802392219824176, 0.10158621585897862, 0.33338969753634545, 3.566957837150943, 1.5202207094238651, 0.21982174396755236, 0.10189161680999304, 0.2269090685032068, 0.09276482066319836, 0.04759921459481121, 0.11825517060295229, 1.0050198387715126, 13.82745017928462, 13.056479884732155, 11.271909321508101, 13.607131627298171, 9.690965664002205, 8.408229024179521, 12.27950934440859, 12.717014435798893, 12.100282522939867, 15.842616884939133, 21.996453846654585, 17.04772883845914, 18.91376114660694, 20.631537668166622, 15.07647208629116, 14.404766194282042, 49.562998894722234, 63.087515600266, 53.991452878521336, 48.99071724184098, 55.060075175377634, 26.052451326001076, 8.805284673167813, 3.2759633227702114, 23.731129900101696, 63.35772768143685, 38.77843818356914, 61.98763201313635, 51.283644630062966, 61.36603440007856, 55.54930456223027, 64.45174732515889, 61.887658642184356, 63.39409197530439, 51.07736718270087, 66.2208814005698, 57.570933372743674, 62.097744710983775, 51.149487803059245, 66.22001063439154, 60.49955145005257, 63.01406921878938, 48.025214056814875, 24.373657280398955, 18.687561981139645, 26.8786064271004, 20.83629519708695, 28.60512983414435, 48.03596135108702, 81.23184696320565, 55.05905143676266, 25.68066554684793, 59.07495837057791, 68.7611730637089, 33.51274251937866, 0.7410155212686909, 0.37253697432817956, 0.1503185396112742, 0.18627578032112893, 0.03263336906750356, 0.015102591264181802, 0.06437503477378238, 0.03323295927276054, 0.06244190382741152, 0.06384252705761502, 0.023282892483797286, 0.038527212886800694, 0.06019409843570283, 0.097581698078542, 0.21915601356135261, 0.13505543281714763, 0.21663285701745943, 0.12015014270981474, 0.12267899894786459, 0.281866638049964, 0.34584978054608073, 0.2545291428724604, 0.23310837456055228, 0.26053093614116796, 0.17093018117931583, 0.11785167209323376, 0.31763580417440784, 0.45355334637626527, 0.7529967073951999, 0.9825800203027265, 21.93782029613372, 109.88063473855297, 81.9295346352362, 84.9316853861655, 42.012479459085775, 132.84595520265643, 38.147089558262984, 65.6741226103998, 70.66327156559115, 49.824930852459325, 55.014199133842226, 43.59151194172521, 53.20219747481808, 41.51803724227413, 37.688748836517334, 94.78726017859675, 100.17868349629065, 62.572763350702104, 88.09853646063036, 72.9027880391767, 113.19045620579874, 27.309982815096458, 11.399647189724831, 74.85564201108872, 72.28645032451999, 71.74240189213907, 54.867188699783824, 63.10195776724047, 60.44987070945002, 70.63247311499812, 62.52992714605024, 51.13296677989345, 47.41164553549982, 3.742994300780758, 11.657240025458798, 20.396901484458677, 74.16342212307838, 69.92280652446132, 61.605793199231556, 52.055927938030614, 42.24340508061071, 10.148642524596184, 15.062021093983805, 33.026670640514745, 23.88609293968447, 25.273941255384877, 21.91841829207636, 15.66044044110083, 13.64041195761773, 12.344308860840338, 16.90784142863366, 18.997474332009595, 15.527582899216684, 20.39123365955968, 12.622622597602106, 7.996577255187496, 0.5618561155373051, 0.17807321562882394, 0.2675340829357024, 1.5054879193344426, 0.5495082490867185, 1.0863977430328247, 0.7288426293000099, 0.34860500044399695, 0.1551918394022411, 0.34824141511513346, 0.2657275250361812, 1.1285744991994675, 0.3234801970181927, 2.802479555529933, 2.2927195026028544, 0.17979380314148244, 2.084842218506721, 9.325896943769148, 22.747603424133796, 0.30061424980240486, 0.22200650415353237, 0.28526408477656306, 0.33715839047105084, 0.2463804341612324, 0.1780557947894258, 0.16959257634176364, 4.128474545094275, 1.7622923586637744, 0.23983992786417085, 0.1909619248321941, 0.4239007794568616, 0.35664628830648243, 0.21417077300288986, 0.25066733961143806, 1.9122855100900897, 22.224518099138816, 14.943719467809125, 20.59574996271441, 19.170166484771237, 12.345699341066423, 13.529073519091453, 18.30763532269386, 17.800661133181666, 16.293987554888574, 20.85202390147794, 30.543629892410774, 25.91965360026206, 24.841282252342474, 28.968488400982274, 14.433581886752961, 7.573100520718483, 37.19220030692316, 67.06772896551317, 60.47470323501095, 54.61132857107348, 63.88878130143689, 33.8663520351533, 4.959313936771886, 1.8821820544619716, 44.427565143954375, 67.1751783740136, 46.61592998812276, 60.37420426645587, 54.48157656577326, 65.17403610291021, 65.94542118810838, 71.24020514949676, 69.08745934886318, 66.09054103974374, 57.18276777575093, 74.6313295056743, 63.0371759014745, 68.6218112514865, 59.12185422835812, 73.8470829686811, 69.1780190314016, 70.81744424758419, 59.54235584505143, 33.87959395685504, 33.42210438943679, 44.248587392991595, 33.658725292451926, 60.665914858541186, 61.3806373842301, 92.13315702253773, 67.85276782128119, 41.06696075008762, 75.09802095351681, 72.56509550156133, 66.15587203733384, 0.9941633310048812, 0.3815923174542766, 0.20534445952263572, 0.2566400062172644, 0.12895836885417664, 0.16974269893140564, 0.1920386614097703, 0.29426537273872283, 0.1393826804574459, 0.1644680456769082, 0.0963399155185588, 0.25220965846411647, 0.12330084783776153], [0.04175954851351919, 0.10059531943331804, 0.02895656646409583, 0.07420355979833873, 0.0651750986975047, 0.054452108564756574, 0.0444085426598547, 0.049241576869521415, 0.09022167688536067, 0.0782101996423256, 0.05594717511426538, 0.08988681985365768, 0.1211867975671926, 0.11407464412191223, 0.18486521326966826, 0.19747462213760425, 0.29360050035099833, 0.1833970210845432, 46.66502237319947, 81.20270375282534, 70.30344901546356, 47.68645071214246, 68.76902564879387, 97.90426577291181, 21.70715747341033, 66.6176526777206, 29.299909068692116, 45.0547246779165, 31.735091017138576, 34.31267069232079, 23.785182122261297, 41.344672403027936, 32.29836494691911, 44.61222248692667, 62.88454471095916, 65.38210607344105, 70.3598056300994, 59.92838767267043, 53.04900930773828, 9.48988143474825, 20.137003275655932, 59.61483732346566, 49.73894857591199, 45.381069798623365, 52.7442019216476, 50.829826401126006, 55.03132027964438, 51.79015205752466, 52.82772879446707, 13.251719782429358, 0.1358225013339712, 20.33378270364577, 67.69177805992865, 64.28596442745578, 55.008813719595636, 51.26416221741707, 47.41777227770898, 7.534620108142977, 13.96090784380513, 26.184954873977173, 24.20948059328141, 19.828999157874815, 18.128994895565896, 10.025838998056228, 7.414372496066555, 10.555120687330923, 17.331602534940167, 17.799205933847738, 15.215868219252556, 12.045017307804478, 14.523415930809515, 6.020379297194943, 2.3461686603484617, 0.6060702978603302, 0.32823288392636085, 0.33305945235394663, 0.09661515558799429, 0.29007168486714363, 0.13187822104702074, 0.034156428469765576, 0.045761549695124554, 0.16751971095800403, 0.07177610295794665, 0.1291322401694713, 0.048903513759855306, 0.10197944879051178, 1.427018084833699, 0.11462274938821794, 0.04210039252235044, 1.0397417627034649, 3.3333368118732207, 9.806926615776556, 0.47571391047489264, 0.15428195677457318, 0.09922222940311318, 0.11328775691048754, 0.12332813588962441, 0.26642965994054274, 0.6126101759652938, 5.78942867056016, 2.489510207406936, 0.25710456193454806, 0.2566724730234954, 0.20240985247636997, 0.02511966680627196, 0.07000897560388812, 0.048661452958420406, 0.354039229813122, 8.75504695600079, 10.289877268575854, 12.282833553129628, 14.838435207643817, 17.364211159367716, 16.864144263728974, 15.839784933674721, 13.010642086305927, 13.825695899225051, 16.0671196253069, 18.18780299155943, 23.393035319543657, 24.77817523864008, 21.19110103576414, 26.690165958096905, 16.333348539567766, 4.965581394010975, 21.27571636630643, 49.45758127397107, 38.02764161940544, 37.644547647045506, 58.73190787530715, 31.320418042521325, 3.6978541939489307, 20.938955391606978, 44.76979194148895, 44.558262440466116, 31.67864222680369, 50.067501991025864, 51.97003587599724, 59.91966824377737, 53.93088756069061, 53.02168607711793, 55.69101979655605, 58.717708895283366, 55.08630798709009, 57.50587694106564, 55.815731556184836, 61.28666916201192, 55.7936054660428, 58.944076722668065, 59.11158938561717, 48.75668902550974, 18.643707921428067, 26.475482871455533, 21.394526920010968, 23.896206771173787, 51.02780411320349, 53.92579632420694, 58.04854469914591, 24.559271681693293, 49.32317733764649, 53.3385233725271, 57.24059920157156, 1.2849951895975298, 0.0910998281512049, 0.04550511708423015, 0.06030883542412232, 0.08922463643454737, 0.03281367552136222, 0.04098800604321784, 0.056814172139932076, 0.0344182696614054, 0.052045830225031224, 0.04969459147222581, 0.03362428081492263, 0.03953754879353989, 0.08933846177833696, 0.00966026817613672, 0.09764943557280688, 0.045798034632518414, 0.060891410816581025, 0.012985241069879024, 0.006152562245035605, 0.025163180600371093, 0.12056890169098494, 0.031515030085199305, 0.07973515894263983, 0.05611445807341126, 0.0482012064857108, 0.18071675522913858, 0.0513825168262326, 0.20711070587558134, 0.19524849320371307, 0.44766271246537087, 0.2568858897974414, 49.693645200421734, 94.75945057407503, 74.90364397725752, 42.60632238080425, 84.8811887925671, 75.97852245453866, 32.828804715987175, 54.10111842616912, 25.535569229433616, 44.72048774842293, 27.981867174948416, 36.73980982072892, 24.847401149811287, 44.558548773488695, 44.01491218997587, 48.127795803931456, 65.8618825481784, 75.7309816729638, 78.43872716349941, 72.99210040800034, 61.80279424113613, 13.255617637788097, 20.934781989743634, 71.48366666609242, 55.11352531371578, 53.56633463213521, 61.82841124073152, 53.48740085478752, 61.22746098426081, 55.7238539572685, 58.61357781194872, 14.88186957374696, 0.22692872631934383, 27.19850709361415, 65.7627171854819, 66.2026031555668, 61.278973471733835, 53.576022886460834, 59.00751713783511, 20.824857565664477, 16.102930864980145, 21.72549847633608, 22.31840591276846, 15.65130033800679, 14.803732037544252, 11.90214007131515, 6.968403420140667, 9.196657788368965, 12.513606202217842, 16.2313453420516, 16.17542999406015, 15.922640100602182, 22.498542724117158, 7.889385742525901, 4.591649097781028, 1.3718049636771603, 0.7536910282027337, 0.3201300332382802, 0.3322398914925514, 0.31442467003099384, 0.21086803006549037, 0.032054480473180456, 0.12984733728151168, 0.38357749641422306, 0.21995605450243721, 0.12492704565726942, 0.07658909630751418, 0.05866531252620682, 0.524202710197818, 0.05415973493889455, 0.06149000510753644, 0.49372016362124876, 1.4257385341390487, 5.0120403978132435, 0.9022416054241119, 0.12186591919030874, 0.14523717034007275, 0.24705528101373106, 0.05423804827695412, 0.2929351070234853, 0.7933478453947652, 2.322166451523381, 1.4649307343267626, 0.29293924389827636, 0.24663175696567183, 0.14252672062045144, 0.10617669897093888, 0.08972410277854051, 0.12528218103632813, 0.6353683805754108, 14.796897307518991, 15.031960048983175, 14.792502291740911, 14.532145165628004, 14.966282902225373, 13.460296719304978, 12.938597952165912, 10.301801273899695, 11.114139826067033, 15.857885691427416, 18.17389818929857, 20.902024315249538, 20.353345524880197, 18.619202913776522, 24.302111287270826, 16.60010010965409, 12.422641534959117, 40.07391468171151, 63.20582605177357, 48.448492711590184, 44.49447293435374, 54.5359916071738, 23.903359213183005, 10.512283502086516, 18.00570499512457, 33.05035391161519, 57.97214869529971, 38.43791369468936, 53.16102435511928, 52.89833537993893, 61.113884833551225, 53.21388613793158, 59.991137750687145, 60.5187749862671, 63.240778292379076, 59.02013932504962, 62.305908818398755, 60.45277326337753, 61.29232129743023, 59.205522306503795, 65.07996197669738, 61.418280370773815, 52.265582546111084, 21.279536754854266, 15.32111619749377, 21.063806395376883, 19.957254778954294, 50.199462290733095, 65.51417227714293, 61.83209434632332, 31.285436384139526, 47.25500176029821, 63.99400280367944, 56.481526436344275, 1.6890420956957726, 0.20183003116999904, 0.03503299010316691, 0.03445706435389096, 0.10147723219087047, 0.014116598758846523, 0.032562957926382946, 0.03896370680341798, 0.05378772264286395, 0.05636585748664314, 0.07569918559203226, 0.07090441747418336, 0.03921470402048961, 0.10873427584527001, 0.12844671405130817, 0.1678655383687827, 0.09753836048466545, 0.24700917784244786, 0.1523507563697715, 0.11414904658111835, 0.13382098937947906, 0.18127212300896647, 0.2648281378130759, 0.25958389824917244, 0.16005740170517277, 0.2132349659598643, 0.3511162979468223, 0.24644475490335496, 0.4106466616353681, 0.3458046426455821, 0.45436797363142817, 0.26642215227888477, 74.25307966047718, 99.7569816343246, 93.22377204895021, 65.2827798935675, 88.45792755003899, 115.99219737514373, 37.81555121944797, 101.62723049040764, 41.7480371844384, 63.15596488214309, 43.27353715896607, 53.010711285375784, 34.6505711155553, 62.976512524389456, 44.16183633189048, 54.8428503928646, 76.67287611192273, 82.8100832047001, 85.29572056185815, 79.14405561262562, 64.01862352125107, 13.816600903387993, 26.388841636719246, 78.89685999962592, 59.32340914203275, 56.63542847479544, 62.15914941603138, 62.22018149591262, 69.63941527951148, 63.458979745065015, 66.28467482905235, 23.51905518962491, 0.1760389151111726, 26.857915924441432, 80.57573641500166, 77.39242707529377, 64.53580764032179, 58.891536574209894, 51.71578391905754, 12.498863973925191, 16.629692431419127, 33.73128914063977, 27.495224591224428, 23.747144937515262, 23.88310213242808, 15.698461936366176, 11.99250755771514, 15.388922210662598, 19.87903291179288, 23.606125923895068, 18.382836964822587, 18.964608792335756, 28.785139168462447, 10.573808820016923, 7.729874224432054, 1.3421768502842997, 0.34667602169417566, 0.7120801352204815, 0.41246229001591284, 0.31832087063981646, 0.37208553403615957, 0.1466976863241965, 0.13705562710041, 0.3485984733748821, 0.26762635056530276, 0.6723022148493798, 0.15254636926035728, 0.33545016761749025, 1.9919880719915515, 0.48324789491391956, 0.1565967220813036, 2.4361689148410677, 5.573124664445078, 25.784706415668612, 2.0785149451225036, 0.3436567466105184, 0.2357160306024936, 0.2944686618303099, 0.19553602132345402, 0.3863776703515361, 2.711291068023251, 17.353512894722726, 5.148644783804494, 0.5984888466135149, 0.30825475110642375, 0.440737706639113, 0.2502179524350551, 0.18918242515815845, 0.2923846268846143, 1.6667046878607044, 20.770266017606183, 17.815460235841815, 20.763288121069632, 21.148429570659516, 18.797537396031043, 18.36254458273611, 19.651160855447095, 18.467569966470045, 19.95840991697004, 22.097027340242942, 21.758693495104392, 30.266330088338545, 31.29153959212765, 27.488923303542602, 34.128660540426935, 22.391826798838956, 7.4611786296290745, 27.95928805105148, 60.97997903823853, 53.92531779504592, 53.50518095877863, 64.35513934781476, 38.016211832723315, 6.4977744029414275, 27.525703368648408, 49.8552978423334, 56.312656633315555, 42.10760085813461, 57.933878129528416, 61.81014868520922, 65.60660293025356, 57.34217682192403, 62.65775326759585, 65.9562861534857, 68.75473253188595, 64.29892393850511, 68.99218497737762, 68.68777767304452, 73.04865314114478, 64.86030924704768, 75.06971713035338, 71.85470719491282, 61.79492988894063, 32.755450510209606, 40.901464185407086, 32.41596741061057, 40.46784224048738, 80.6342032647902, 73.73909227309689, 76.34203203262823, 38.983162372343, 64.92606386061638, 65.63735431240451, 82.58599035201534, 4.82835138997724, 0.39094140933405974, 0.3172921677750926, 0.22522932879867094, 0.30097231929821355, 0.10512735003665571, 0.18835416153794338, 0.16517889866184804, 0.10941088469999452, 0.22687549853036482, 0.2032647606345915, 0.17441781177636118, 0.19741618495074012, 0.27779622904716], [0.037261072561265006, 0.043845318648363316, 0.029299909834780043, 0.058534204238845464, 0.026830860165758964, 0.021321446927745017, 0.11850139126181604, 0.00437827101127515, 0.0956224128904362, 0.014769185011485412, 0.024523491437937465, 0.06777643451407071, 0.02197911617376151, 0.022579169862212676, 0.052422358609375455, 0.07576930561974164, 0.13602911524714964, 0.050452600999344746, 2.3721597559990424, 82.570481300354, 61.967423962008574, 64.22347322587045, 43.05099364249937, 110.61845610218664, 52.95823781721054, 42.78929702697262, 46.96920610243275, 26.06122370689146, 42.82787745998752, 28.3642884608238, 30.64766291649111, 23.93607178042012, 36.91638708114624, 52.09788553176388, 70.6299549533475, 46.66038613165579, 78.66528326465239, 54.925220166483236, 77.08607427535519, 22.41201327693078, 13.796080043238979, 58.176292373288064, 59.42152330952307, 48.269922887125325, 33.57990134146906, 42.94561524544993, 57.34901743550455, 51.69961983157743, 42.19293202123335, 0.5034446692274464, 11.00935076513598, 69.00081419175672, 61.15748590038669, 45.66408057366648, 50.392093812265706, 53.93624551834599, 8.66510896913467, 14.841886893395456, 23.31326803853435, 23.165110311200543, 18.328392505645752, 16.027859641659646, 14.898141526406812, 13.974095832917, 4.122971950038787, 6.840168391504596, 14.156667455550163, 19.341438739530503, 20.81996440887451, 16.865062098349295, 18.782104830588064, 10.300518658853347, 5.414579030006163, 0.624629482626915, 1.9381532962283783, 0.9186644467615313, 0.6417045405795497, 0.3149582962355306, 0.17551566173713054, 0.4525619366716954, 0.12503773004056948, 0.059713822594212915, 0.07173980571209423, 0.02774696534259185, 0.06296135357490952, 0.03636954540026285, 0.5998192655463374, 0.09580742312414993, 0.10512999303999448, 1.7717821655734893, 4.719461000734761, 9.232645534699964, 0.5827471493713318, 0.08206268727418878, 0.08165811624137626, 0.2996404294765765, 0.06054837579628634, 0.12545170863309216, 0.15842445465105195, 1.0420454197352933, 0.6703830726685063, 0.22411488537346164, 0.18406201604633562, 0.09131873777556805, 0.1215376581756338, 0.11798969049367214, 0.062723406665628, 0.30476653828255595, 8.271053933328199, 15.879252802941108, 17.26751296750961, 16.26083372100707, 16.03287046955478, 16.80223161174405, 13.770447354162894, 17.75463015802445, 15.70568988400121, 17.830027918661795, 19.785099990906257, 16.778436553093695, 21.033914012293664, 23.043458000306163, 22.256952178093698, 23.97702720857436, 21.251721266777288, 5.470644898952977, 17.420220644243305, 39.326671784923924, 35.01326091827885, 35.35929241488057, 66.29650469749205, 28.101397483579575, 4.379595960340192, 11.16028945292196, 29.124479101550197, 57.687721944624386, 46.504989670168975, 44.17194427982454, 56.34330603384203, 56.79638293481643, 57.01142295714348, 54.69034471819478, 55.03861981053507, 56.752746566649414, 59.41556915160149, 56.45401100958548, 57.4174431831606, 58.073506662922526, 50.94033918073101, 52.537265516096554, 59.58488218245968, 19.489286599620698, 23.19627158103451, 14.731050518251235, 43.64444040483044, 38.78976206625662, 65.85759147520989, 26.916851497465565, 34.84099042031073, 49.771465024640484, 57.5361458716854, 13.865398130109234, 0.6134431893306395, 0.2735882000096383, 0.031969023365226966, 0.11901748171376607, 0.06122059496720472, 0.14454254309736914, 0.16095999117580154, 0.05766729914372968, 0.062387021288516066, 0.017580082264518546, 0.027505255026382305, 0.027244911536634452, 0.04999812316870497, 0.05096183113393284, 0.14587526029396444, 0.07607596295495188, 0.02267824992867968, 0.038214526439626376, 0.025762726755572424, 0.03096862936452512, 0.024628974084231644, 0.07243540588646166, 0.028575389841271025, 0.038346645963047786, 0.09503410332986424, 0.05848127905459655, 0.03160801592222866, 0.013286439071018851, 0.031298458944225026, 0.03921703292777942, 0.08281730686224277, 0.05672772294811665, 2.9677915236642285, 87.46460299338065, 73.48327529045844, 61.27105028398576, 55.48942173680952, 107.98070138500584, 46.9501276939146, 50.67808951100996, 34.38475208897745, 28.293483795658236, 37.11945210733722, 28.760808706283573, 31.288740981009703, 32.11735148583689, 42.0419599933009, 60.34167997298702, 74.80876968752953, 58.892728974742276, 87.75107722128593, 63.70198626672069, 81.88675726613691, 29.724462493773434, 15.700975195054086, 66.5188403283396, 63.328321672255, 55.32676889050392, 41.434184812730365, 55.5723524093628, 57.152577292534616, 62.38623895952779, 45.85671993993944, 0.979371460214738, 16.53172731399536, 65.60652056047994, 64.52258533047092, 57.34307504469349, 53.13816478175502, 67.45119556303948, 20.274831441140947, 15.486048921462029, 21.881057716185047, 20.001730534338183, 18.951068770500925, 13.821365602554815, 16.05519561998306, 9.242381838060195, 7.6202204438947865, 9.217509108204997, 11.809589785914268, 19.60892673461668, 20.256104084753222, 17.91571209507604, 26.307168083806193, 11.135222565743232, 6.851938934095445, 0.15257895864065618, 0.9953948939519545, 0.5428547448208255, 0.37224022250983024, 0.49348987759121005, 0.1812368369991741, 0.46557026284356273, 0.09964436683202944, 0.47166531965617214, 0.34877237533369376, 0.044215365928868135, 0.09282424610348479, 0.046512063051904404, 0.5089247106544433, 0.06241964897321117, 0.12651033489213837, 0.7607459012539156, 2.6027441313189845, 5.853080893716505, 1.4199681147452325, 0.5535432648274207, 0.5480486370863453, 0.4230462543426022, 0.2322653101216401, 1.1356363589725187, 1.1659564029785896, 0.39976024579617286, 0.05228271610253761, 0.07207690738141537, 0.19519826847939722, 0.014312873357876897, 0.006453091355656544, 0.25280150735089857, 0.07391746426301618, 0.2020820128100534, 15.12144696327948, 19.70148486475791, 18.316978408444314, 15.427064318810741, 17.874164389025783, 17.006522378613873, 13.047964419088057, 12.768032704630206, 11.358837869859512, 13.59297481275374, 16.33226204303003, 15.662254537305525, 22.532000541687015, 19.479751317731797, 19.943432346467052, 24.97243062142403, 23.598465534948534, 11.273319413585048, 36.69121949903427, 58.194617686733125, 47.16286920732068, 40.57136143407514, 63.3901382261707, 18.695294933934367, 12.02539957338764, 14.455312798100135, 19.12282543797647, 59.36577858463411, 53.94908735829016, 48.818278081955455, 55.57523927380962, 57.56443400536814, 58.683819616994555, 58.158798602319536, 60.11771263614778, 62.63172834150253, 62.1065112083189, 60.906650327867084, 63.66763022638137, 61.78131141970235, 56.0678340542701, 56.87697979711718, 63.41069929061398, 19.81201921739886, 20.972652473757346, 16.496141610607026, 31.955196780543176, 52.14449113415134, 71.08868398974019, 34.12560893643287, 39.84531502569876, 55.823007552854484, 62.23333320310039, 9.372663363333672, 0.2706502221765057, 0.25194842248193683, 0.15759476610729772, 0.13482226629651364, 0.01115511256014748, 0.17002311775520926, 0.05569713933753872, 0.061739290118097305, 0.06726330116150842, 0.00961002525723269, 0.025434165051387205, 0.06519026723840544, 0.09243744064963634, 0.037803995242762956, 0.313703628076661, 0.23955564795722886, 0.09404909045946214, 0.14991245172437162, 0.11606656465559237, 0.08892226919171312, 0.17876539139016984, 0.1300746202468872, 0.20189318745847673, 0.13974827293667103, 0.13699688347837619, 0.18787163339795607, 0.21224081366052552, 0.11111753707331036, 0.2591529584700062, 0.2886470677631517, 0.49377480101200844, 0.6759448097117486, 7.735309158602069, 108.76316716594081, 74.99054801079535, 85.58526992797853, 60.39017223542737, 131.4117327044087, 71.65161471213065, 66.12628167675388, 68.68326694734635, 36.8613209262971, 61.727904427436094, 41.623376415621856, 45.972174905961566, 41.048600135311005, 44.683652770134714, 67.16061853593396, 89.38726255970617, 61.99707315814111, 100.86716928789693, 69.46377154319518, 93.12328092513546, 29.554331648734312, 18.527654793954667, 70.18025521309146, 71.77796994486164, 58.096527053463845, 45.8932097496525, 56.115071158255304, 71.67915759548065, 62.81373023986817, 57.38072979834772, 1.3585912340110349, 14.055933144784744, 84.21975166566911, 76.06919980818226, 62.56446361541749, 54.20971708913004, 59.37948334601618, 11.076684132699045, 19.88090584355016, 29.590009527821696, 26.889534150400472, 22.06709965582817, 22.890797392014537, 20.108983824329993, 19.589660052330263, 7.200885242031467, 13.267375922972157, 20.1520122251203, 22.475357594028598, 26.783775283444314, 22.41215644344207, 35.78693666765767, 22.061735814617528, 9.923171939388398, 0.7761446975411908, 2.5268070447829465, 3.4943959501481827, 1.4036699312348522, 0.7421978094404744, 1.4505265653133395, 0.6742342885944151, 0.266194072582068, 0.3411496166260012, 0.4231556516981894, 0.1260336826465303, 0.15743149744887508, 0.23522795598593452, 1.0879758841568425, 0.2616647156255861, 0.5038845569135681, 2.646937721198605, 7.149284010933292, 19.63161764606353, 1.1965897463021742, 0.6326078899925756, 0.26064627833904763, 0.5579085563940387, 0.17618661686297388, 0.5997926669736063, 2.757242370036341, 1.258779905976788, 4.642939481043047, 0.36682247935283574, 0.9021732703812662, 0.18326450319540116, 0.1919675224851216, 0.38021228666747775, 0.2693814273563124, 1.0579713458015074, 22.397875093644668, 22.449177734313473, 27.1589558739816, 22.506830692291263, 21.370231759163644, 22.100951671600345, 21.46828905228646, 27.061563422602994, 22.90423739340998, 22.00385339798466, 27.677373578471524, 20.433752152227587, 28.710739651033958, 27.84683369821118, 29.936905907046413, 32.70622280336196, 31.0633223672067, 7.878105496206592, 24.18542273582951, 48.4608874013347, 48.5314469183645, 49.3056208087552, 76.16569795916158, 30.023774639252697, 7.255930804437207, 17.56735659414722, 34.60102765790878, 68.56703927440029, 57.298430627392186, 53.53213548660279, 63.769219613844356, 61.895468081197436, 65.56481007606753, 60.53508812381376, 65.81959155298048, 66.6175114723944, 64.83206425943683, 69.01108295686784, 70.90792548271918, 66.10095101018106, 60.252606868743904, 65.5877677086861, 78.0842782605079, 28.944769828550278, 41.73444224942116, 23.355464896848126, 63.869647979736335, 62.07068820153514, 80.7233508940666, 40.48404162929904, 52.67635276240688, 61.82816020904049, 83.93192814242455, 27.939815444331018, 0.6834697543132691, 0.6189900949116677, 0.25423688032934744, 0.34947582790928505, 0.16898992561524914, 0.3080812168698157, 0.2574564720834455, 0.19636304388123174, 0.2415114857496754, 0.20952054269371495, 0.14981571014129347, 0.16441467999210282, 0.10071936439001754, 0.19620921342603623], [0.034202646554237416, 0.06864045911859121, 0.03869840672480003, 0.06707643699501792, 0.016255788204650727, 0.030725386872467016, 0.07502707367342326, 0.06942755317375546, 0.06697290787293066, 0.05871782785341625, 0.04746325697088915, 0.07148151150754384, 0.08253377006058732, 0.11730083189303837, 0.19426342670715627, 0.020491361933489962, 0.26950795443788655, 0.2879185794341949, 0.45036240631053526, 26.873181789152085, 86.98091983795167, 56.63505977199924, 28.46164757205594, 57.18636851156912, 97.53157784861904, 31.212082178361957, 63.828164992793916, 30.93501183294481, 36.87277816957043, 29.56043093435226, 27.669256233399917, 31.328790341654134, 105.0061248963879, 58.27469287380096, 76.57411083098381, 63.1390320101092, 72.47542227468183, 58.797474215107584, 73.90199615109351, 42.44454814541725, 27.08810414037397, 70.53894027586907, 58.98992530761227, 60.53902618346676, 56.82813452136133, 40.41356448204287, 45.78083776658582, 59.40710075439946, 6.718209155144231, 1.6522168007589157, 55.58028344185122, 57.290856530589444, 40.371897143702355, 44.3285958997665, 54.98211414583268, 7.9145359800707915, 16.529320939894646, 22.801184961872718, 20.58544001271648, 18.85862046672452, 17.10057297060567, 18.10500175722184, 16.594075349069414, 14.835322806912085, 5.79531418700372, 5.003258210997428, 16.672538441996423, 21.8831757960781, 24.190478670981623, 18.405778907960464, 30.966161335668257, 16.09072150722627, 4.149625435952218, 0.48423406457708734, 0.41042964424817796, 0.6611415395332921, 0.24054390137955067, 0.06892191216109261, 0.46563663670132244, 0.27459067202383475, 0.02643830139159916, 0.08989848737274447, 0.04728132641063102, 0.15034555187148435, 0.044809742905800386, 0.045854794086828354, 0.363733428981035, 0.10427559049980295, 0.06287306960251543, 0.22923224545534582, 1.7100797281149895, 7.912356122847527, 1.4471449919285313, 0.48844785459579965, 0.03563713087069412, 0.12100619999992272, 0.05921066370642474, 1.376450520849997, 1.4035137718723667, 0.6319116079999555, 0.02896254578034484, 0.1791945232018348, 0.36672981335751476, 0.05798006986057567, 0.028291330184607257, 0.03669146703736436, 0.02941817465809084, 0.5179282662368591, 8.225263203344038, 23.485873899152203, 22.920915311382664, 19.338538146788075, 18.91358660113427, 15.341071255745428, 11.598932031662235, 9.137825177561853, 9.516758495761502, 14.913878075538145, 19.43072561294802, 20.62389296870078, 18.786611633916056, 21.565267693611887, 26.70579856441867, 20.135324501222183, 22.34239120637217, 24.562017340813917, 7.998399196132538, 8.218514765462569, 23.800914749022454, 31.985646140190866, 31.905637633415964, 70.3483993776383, 22.875837472177324, 1.4099438848995394, 2.45182603597641, 22.27899197609194, 50.357847598291215, 53.57989818819108, 47.47759234520697, 54.54645649079354, 50.680678275323686, 55.41151562044698, 60.0619286875571, 63.92448271474531, 57.19437406909082, 58.62790623018819, 58.260207560754594, 60.238807970477694, 51.94691350383144, 57.50667318221062, 46.649219143775206, 19.751240130393736, 14.077336538222529, 22.23249031651405, 49.789127457526426, 53.341759327919256, 53.2674264907837, 32.008315478601766, 48.81168850006596, 54.086401693282596, 30.84927470453324, 0.701809408924272, 0.15929413298445363, 0.14289056641920922, 0.048811119725747455, 0.09484296439275627, 0.06006627283509701, 0.033031187035263546, 0.0499100728531278, 0.054070864909238396, 0.11507619683059955, 0.0322562622867765, 0.05997520796353779, 0.022034556041621876, 0.035113563400603114, 0.08708306828573828, 0.1003045354398989, 0.021292530939043052, 0.03849224097305729, 0.09315422315511013, 0.052378611158459425, 0.051830597822704626, 0.06824494324504368, 0.016246859449893236, 0.0062874047322228795, 0.12305098060037821, 0.05432303424083418, 0.07300081707897686, 0.12054850076956135, 0.10352233454825417, 0.1352675625633809, 0.07143798239168621, 0.21709863847542196, 0.5067257625201057, 0.4620019478663322, 26.687600728004213, 94.86591939003237, 65.1304115018537, 28.241100542006958, 75.15205552501064, 90.59714117357808, 38.32301962760187, 56.00293451739896, 28.4510983574775, 39.50253125159971, 28.112823347891535, 26.70122115842758, 38.65212609691005, 91.60416264687815, 63.651148426917295, 80.61516407997378, 70.98247405021422, 81.61857697271532, 67.65066377578243, 83.42302414678758, 48.02606521114227, 32.17389833542609, 75.6132556546119, 67.44990118088262, 64.14350786516744, 56.706235101146085, 45.95884669211603, 59.04893344448459, 67.24047799264231, 7.250639036778481, 5.681387474459987, 57.349456740963845, 58.65123256560295, 51.71871785194644, 50.37587873397335, 74.04332699314241, 20.147681928450062, 18.23240622397392, 21.682670116424564, 20.27573750865075, 20.800191740835867, 15.30372734992735, 16.852759584303826, 14.265766220708048, 11.319914229454534, 8.220433785069375, 6.133720595990458, 18.951109955387732, 20.89337548901958, 21.617578383414976, 19.968814003852106, 36.18775190845613, 14.187451197255044, 5.443601627503672, 0.47733323648571974, 0.16424581889183293, 0.2798954018902394, 0.4280827921484748, 0.15653430123723325, 0.15173434670413696, 0.522729002179638, 0.24331304875593035, 0.4693884450581766, 0.2280281850647542, 0.24760425962027044, 0.13737801222070573, 0.12632294212498013, 0.2782863414575977, 0.14305866143155482, 0.010703876239037322, 0.2779769032232223, 1.7914982043927716, 4.520602716553596, 3.5051976673064695, 1.3014981943753459, 0.2739080570397839, 0.30580195207749644, 0.22685222477922518, 0.8814478953999858, 0.41932364925742155, 0.45309810628814084, 0.04146781840151356, 0.2859020827999038, 0.33448529519861747, 0.019201415425707257, 0.03579767225610633, 0.06051748713117935, 0.05230148525668248, 0.16778300005582072, 12.679183175486903, 29.458806245557724, 26.292661197723884, 17.683121427412956, 20.262575995537546, 15.13341509526776, 15.650793371662019, 14.02179773776762, 12.06393195736793, 13.791261411482289, 17.542427970517068, 16.9753199238931, 17.07560904564396, 21.539682072977868, 21.704274531333677, 19.954348302656605, 23.066666664615756, 23.66853867807696, 12.660167524891516, 22.110114328322872, 44.236682999518614, 48.44901046445293, 39.26520039958339, 63.58371503891484, 15.688293191694445, 11.345036029815676, 6.626728696207847, 10.95576628561943, 44.86541932629001, 54.16305265118999, 51.08026581425821, 57.92102452247374, 55.72613285433862, 57.84005895737679, 66.00675136812272, 65.712095076038, 60.080246156261815, 63.35414655746953, 62.61311277266472, 61.7558434701735, 57.32185894443143, 60.54394875803302, 51.79842825858824, 20.150407975719823, 17.407888712421542, 20.910512324302427, 49.69583780534806, 60.507764893193404, 59.003763429580204, 37.28134793619956, 49.730386041825824, 66.67454273469987, 23.098306463610744, 0.9480748073227945, 0.16803331162420013, 0.05258187726740876, 0.10344540399889793, 0.01752472092067042, 0.05613401629811814, 0.044842022020489945, 0.03720922756098932, 0.022583237789090604, 0.05654034167227726, 0.0701824868578584, 0.04683196987776507, 0.1576479479310013, 0.0435622529907813, 0.07091167232682628, 0.19350570446300894, 0.17513946660103338, 0.12212265823637286, 0.2252714329909894, 0.1127247742166923, 0.15231790651957836, 0.20071017916404432, 0.2726175666095749, 0.255981354463485, 0.3163343433651232, 0.19293286987850744, 0.47904804769542914, 0.24666793163745637, 0.2416124254945786, 0.3452222319620271, 0.3789381905188484, 0.41042575252152264, 0.7629780363171332, 0.8992609718153555, 48.03559264829082, 107.68154221196329, 77.8867712328511, 41.01283204170966, 78.55145608225178, 119.46351851186445, 51.346131909278135, 99.2638220325593, 45.47524982883085, 51.70534649202901, 39.629870999243956, 45.95547737613801, 48.27499058938796, 124.23499553434311, 75.72528639147359, 92.71284411030432, 79.90148098238053, 89.53885432212584, 74.466566424216, 89.62581326884609, 56.51800055657664, 33.42714463510821, 85.41230124811973, 73.92144326240786, 73.74485031250985, 67.31515207598287, 50.56005754778462, 64.28169688870831, 74.45133193846672, 13.873412512963819, 2.945925045397974, 75.07020350425475, 69.7422049122472, 56.52022846283452, 52.225131142523985, 62.324445939833126, 9.79439954603872, 22.742627897570213, 29.244970390873572, 28.19931749374636, 26.103508818534117, 24.446030893633445, 23.889358312852924, 22.22253926338688, 20.748759661951375, 11.35573527505321, 11.018099611805333, 23.11218184809531, 25.979814913965043, 31.321975223479736, 22.48237471426687, 50.336129434647106, 24.788249846427675, 10.791117933488662, 1.8868051805803854, 0.39551703800116816, 1.345275890442633, 0.43623635785714276, 0.19774439233926036, 0.8251871949722691, 0.6912902862794938, 0.1918362763019339, 0.4923611542870922, 0.2403622466109453, 0.34451902453457156, 0.17025478274351166, 0.1771157895845752, 1.3987147519665382, 0.36403152911413106, 0.13769791521612676, 0.5125117794640603, 6.924145846597611, 16.809964564538774, 2.3346592005222075, 0.6214035170212869, 0.16127313727573042, 0.7748831039474857, 0.21931940479384315, 2.6334013765858066, 4.247034557404057, 1.8301891992169044, 0.17504709171912364, 0.6040195111305483, 0.35886714655545454, 0.27819909936478066, 0.18190722521995345, 0.15847228918104403, 0.1470951174175547, 1.5264428142578372, 22.754459727195, 29.72227381121728, 30.983398191390503, 25.846160150343373, 25.966200367096935, 21.708053734994706, 20.41438544950178, 16.742284067215458, 16.58178852450463, 22.23234518881767, 27.80087528690215, 28.6407704507151, 26.448100805282596, 31.54182799400822, 33.73953788511215, 29.85895468342689, 30.534977143810643, 35.77222777951148, 10.784220445540644, 13.162232868133053, 32.27463656856168, 44.692835038708104, 49.563744145054976, 80.17600767074093, 27.948187743463826, 5.3624247447136915, 6.694732298774104, 28.733283473599343, 60.84172725677491, 64.39834425526281, 60.5300243439213, 64.03690568862423, 58.982814050489864, 65.21937870210218, 68.7408551862163, 69.2684139743928, 65.69565642264583, 70.98483531705796, 69.18871925723168, 69.30016948330787, 61.33218434549148, 67.7430748170422, 61.517794824415645, 34.15147304534912, 21.132885217666626, 33.901547462709495, 77.27076299728887, 65.42071004067698, 70.82873282894012, 46.04319726267169, 67.25348457213371, 73.47411263373591, 52.885928923083895, 0.9162763361969303, 0.28472659748888784, 0.21888803600543932, 0.2275288336339497, 0.36241474651521255, 0.20724858638019333, 0.14064226690078938, 0.12172817658152311, 0.1444818995772831, 0.18682396219622704, 0.18433849717820847, 0.12903690818817387, 0.4419080438392778, 0.15774536367145278, 0.17712106026949423], [0.04205134374299838, 0.028154202361380862, 0.010742826064327552, 0.0749684143210611, 0.20906622191109966, 0.05151840550224147, 0.028818099902221755, 0.05089963628580013, 0.07089158550145165, 0.030434193022008386, 0.10961692404722977, 0.23418828274213502, 0.029822437340513836, 0.018399413299536514, 0.03168264629259225, 0.035145068766489145, 0.01702631943889203, 0.1909851372962998, 0.19938136901586287, 0.30446044019153046, 56.57697339211741, 73.42242363960513, 66.12084527169505, 34.581047104251006, 105.89288650020477, 70.52466284844184, 51.56192894904844, 40.283541833200765, 31.08216151114433, 32.8278947261072, 32.97610736662342, 24.601705843402495, 71.15972595830118, 73.73027478494953, 76.24566724223476, 72.83635877793836, 67.24781282486455, 68.63766547172301, 68.53802157986549, 66.18807469644855, 55.79409576231434, 61.05312339721188, 63.39468033083024, 56.777261380226385, 70.60103139569684, 52.66251464043894, 39.47056393469534, 23.182792355937345, 0.8125415348237561, 32.50817448862138, 62.357735095485566, 38.295755232534106, 43.207547203187026, 44.74954074428928, 8.319989423598013, 17.892073931232577, 29.039667652499293, 21.390928145377867, 24.086135779657674, 16.079305448839744, 23.14364121806237, 16.276117236383502, 20.476868806346772, 10.561336663461502, 9.298122640578978, 6.90979193295202, 15.972021760479098, 28.056243158155873, 23.472598637304, 23.975799506710423, 41.6764578511638, 28.159066131038053, 9.682581597758878, 0.23174207206935654, 0.06598525966006903, 0.25801605334685696, 0.15649451063044612, 0.40091051149272156, 0.0902787197922026, 0.2688460238277912, 0.7712187521880673, 1.8982212389669113, 0.24611440246864674, 0.0347929862478087, 0.06100036001073257, 0.05974552714295926, 0.5700004881908817, 0.16786115634585583, 0.053739409307919206, 0.24018658264990778, 0.6301841103742201, 3.773244600142202, 2.5928467656335523, 0.94026671662446, 0.8817842999292959, 0.3265902381991187, 0.9715535023039388, 2.5409837163263753, 0.3247086649700519, 0.3216030058120528, 0.06845135797536181, 0.012162251007412712, 0.17705758222408835, 0.05994690484517525, 0.11711395240478939, 0.15298461751832118, 0.11511913605875547, 0.40799615063494254, 5.92798492600841, 31.611585386337776, 32.947709406575854, 22.595046758651737, 19.065815748706942, 15.243113983062008, 8.981499114344198, 6.452910823206748, 10.196087514200519, 13.58708635453255, 13.715328247316423, 18.342397328346006, 19.720806460226736, 20.08125658958189, 24.38072539144947, 29.076037829922093, 25.853128240954494, 26.33577589065798, 29.8017273026128, 16.792808117405063, 6.648421854742113, 16.908876934359153, 30.694868641514933, 33.192579054063366, 71.89300521727532, 13.514662731078364, 3.7036740106921044, 1.6554789870016038, 4.474721772055473, 20.710985276006884, 22.753769390044674, 33.21022971983879, 55.45288878102457, 53.04479275980304, 46.65494972659696, 53.24211543606174, 52.37291428350633, 60.220992565155036, 54.761092508992846, 62.83919034465667, 55.92942930036976, 63.56153403559039, 36.40919716127458, 14.257842052367426, 11.44808061661259, 39.73997192998087, 45.45359834547966, 50.79108515093404, 41.98182613618913, 35.21390584207351, 56.700830075048636, 57.45936939793249, 1.4832922071218493, 0.44924514368176466, 0.10123792930596298, 0.12449350117916062, 0.11192126289731073, 0.07684441809091838, 0.0648434822177214, 0.05453047169853122, 0.05412005158441682, 0.08103894099833504, 0.07177302328449103, 0.0972806485069375, 0.020606518355047992, 0.12455848075689809, 0.10197386400954378, 0.12806811339912877, 0.05805321593558597, 0.01046727572928273, 0.015296771570349173, 0.023836879390141657, 0.07963758232372423, 0.08226003152348342, 0.05790806908701217, 0.04758097021089447, 0.0853754966069133, 0.023234697892480803, 0.03468477249806447, 0.19169609753354905, 0.05349570524788672, 0.010020722120609737, 0.05316387426348464, 0.05356013324231871, 0.0343432275187825, 0.05662676022057572, 0.23321196496967347, 0.3824002644227397, 57.98629668451125, 89.42073606675672, 60.50101841649702, 42.77534907863986, 110.43556382579189, 67.35920813775832, 57.93268965136621, 31.88179158395337, 29.521093483894106, 31.62934195610785, 31.619945918360067, 33.249877037540564, 77.58717275434925, 72.7953072517149, 83.20433632020028, 75.89080256800499, 75.18343448638916, 74.1349692498484, 79.51587277074015, 73.7221162549911, 63.233435615416504, 67.023406182566, 72.09786276663505, 65.30959321606544, 68.40015811304893, 49.21802643806704, 52.057030124049035, 21.550054780898556, 4.00930386877829, 33.031769721738755, 59.83352515005297, 50.40863052491219, 53.49482197915354, 65.41334382949337, 18.49342034709069, 17.389908567551647, 24.68015128566373, 20.342280518624094, 22.73458311634679, 16.30990061067766, 19.556745483029275, 17.529729297084195, 13.325711373359928, 9.80469576774105, 6.676125555269181, 10.705368057374033, 17.334767887669226, 23.463357533178023, 22.945761565239202, 27.55316584340988, 44.59760773566462, 30.80297112464905, 12.409711441686078, 1.2346125898822662, 0.20380238581809307, 0.48411820143941914, 0.45745160010072494, 0.3353485230716967, 0.23176441119322855, 0.2167045322036551, 1.5651080685277141, 2.2282519167469395, 0.08289320319290124, 0.021889056792602907, 0.15212436206638813, 0.10961234284144257, 0.3146691440093902, 0.1798535579995763, 0.08951576516753243, 0.329780810542645, 1.0860129830337342, 2.0185830900746007, 4.559603333473206, 2.9655623916656744, 1.0799565983395423, 0.33998160833312624, 1.1080997268999777, 0.1998962413880133, 0.12874106035357522, 0.2595147971184023, 0.12290045964501559, 0.08995497869628091, 0.07023774477983676, 0.12481426219305686, 0.1000983045706826, 0.14853163952789, 0.10052467080494089, 0.40559854058008044, 11.541708573218315, 37.41965070847542, 36.77757832311815, 20.28188386271077, 18.683296403577252, 18.667789313101, 10.486665521898578, 9.439865331495962, 10.488112876492163, 14.384159041989236, 12.269424930695566, 19.01736467115341, 16.52561233889672, 16.548540553738995, 21.34448532135256, 25.200824353002734, 24.75947533884356, 26.728332581058627, 27.913517913510724, 19.873759285096202, 15.003831751884954, 40.718030621928555, 51.74351115380564, 39.857341012647076, 60.971753827987186, 10.14842777482925, 16.814096781515307, 5.7715563908700025, 3.0250914683265075, 13.670339642032502, 15.353273749351503, 26.238861968440396, 54.20886201243247, 58.36085557937623, 50.298870840380275, 58.29375167046824, 60.42964696884156, 67.30804474123063, 65.05978922690115, 68.3440839090655, 55.94715056880828, 63.42756155998477, 38.03668268265263, 17.812518458212576, 19.2707105605833, 36.39997566899946, 53.13617614007766, 59.26982564310874, 50.801071505392756, 42.17615212163618, 66.80038805930846, 52.102976768247544, 1.7736994691433448, 0.5152378267338199, 0.26503167205279876, 0.18477075462860448, 0.029089902152097034, 0.07784653770466966, 0.041555757634341724, 0.018905954465510386, 0.05100695371267296, 0.05199787312097127, 0.07485350879329829, 0.01186155862430291, 0.04026409892004825, 0.031090927640757257, 0.1924034571575542, 0.13362764410914915, 0.1404699584048602, 0.18211887999167367, 0.09481640412442147, 0.14463796700921752, 0.23825702167326407, 0.14297302812337875, 0.12161890180000376, 0.16025047118384994, 0.2077083617088295, 0.12808650717019074, 0.21287467480907518, 0.3597590567604188, 0.11325453933809074, 0.13135148963380244, 0.12621072556583152, 0.3023292142296991, 0.17210796475410464, 0.2700538993362458, 0.5319858570733379, 1.3593306007885164, 91.43072328259869, 90.67068561430901, 91.85215057865267, 50.71183366160239, 128.41731686745922, 86.90171149469192, 86.80304035063713, 59.087376594543464, 43.02126207659322, 45.21509862715199, 47.05817330268122, 41.99326768998177, 100.5379020014117, 86.46671279784172, 95.01860941610029, 86.23717569535779, 88.48460751195108, 82.8946416608749, 88.37605983980241, 79.17508940542899, 71.58705249909433, 71.1674451828003, 75.10801515271588, 71.21684351275044, 77.05302438428326, 63.02812307111679, 53.40790617850519, 35.1644172976094, 1.706970391734954, 44.434680323446955, 78.22679365834883, 55.97924340155817, 55.052316727176795, 49.74424769801479, 9.846308192899151, 23.64273928826855, 35.781382591493674, 28.17796999408353, 29.377477861219838, 19.99366221889373, 30.209312554328676, 21.98563006616408, 26.369831869679114, 16.959263701592725, 15.342410745159274, 13.910607368715349, 20.768065567939512, 32.88779127982355, 32.44246890467982, 35.63541943027128, 52.6004784337936, 42.535303946464296, 18.85342920980146, 1.1887952613253747, 0.2339131652467674, 0.39487750780197883, 0.3634684544897849, 0.28111777178222136, 0.2117544550809168, 0.2525935451229734, 3.488970821903598, 5.006174493220545, 0.7320465315734187, 0.10214489313863939, 0.2154159110279814, 0.21531155453093592, 1.954475504256064, 0.2796823988037725, 0.3425852960396198, 0.21594199892734328, 2.3448061270098535, 12.503533555615334, 5.9657990259508935, 2.6146583307173947, 2.6531331048857782, 3.7164165656412806, 2.43456294940364, 4.8421591135763355, 0.6360039884044278, 0.6358480741900783, 0.141501342577319, 0.26219402109422996, 0.46833007926902465, 0.22710420641927953, 0.32689636693366114, 0.7316183803542968, 0.23214791480812336, 0.6737893447279931, 25.37546592374002, 40.11921021246141, 40.05820166680121, 31.295499224816602, 25.594083147664225, 25.518193129570257, 15.817396044731142, 16.59172781052128, 17.019293615894934, 22.363420994051044, 18.266166064047045, 27.70831519557584, 23.73643490575975, 24.709749490984027, 32.08355242206205, 37.641429362758515, 36.31052601721979, 34.69713357187087, 41.00336344011369, 22.55663106518407, 10.338148897694005, 26.610839943731985, 43.13234752224338, 50.9256616715462, 78.44996083167293, 18.215763607332786, 8.070161409916418, 4.206360069013411, 6.3595226214778044, 26.074314617341567, 27.92396514646469, 45.20447292635518, 68.34307978230139, 64.4483034841476, 56.7168451124622, 63.14756708760416, 60.35451789056102, 71.01934432983398, 65.71085952943372, 72.48242762780959, 64.03289310393795, 73.75840602382537, 51.139093522102606, 27.838167221315448, 18.072306840650498, 64.86150164758006, 67.20840084937312, 70.32250388976067, 52.60229841355355, 52.99891671826763, 70.60808381726666, 79.86976469716718, 4.876299913852446, 0.9427789947198284, 0.32202371065655067, 0.3463195456612495, 0.17457890474507887, 0.22051119245588782, 0.18693461593601013, 0.11193187321506201, 0.15296304448237344, 0.18398215904110865, 0.23202144901358315, 0.20752721255825413, 0.12168207341023993, 0.30911804026653694, 0.1958496883631714, 0.22654917571813832], [0.04632658167411724, 0.026740344962285414, 0.028044490909744656, 0.045615721028298147, 0.05665402145936124, 0.1575742196291685, 0.015313086370306631, 0.12462755124415122, 0.1537342498739881, 0.049981951052623416, 0.07912330750015475, 0.045495020045388135, 0.051004172813507824, 0.06577630151784228, 0.06649066318547533, 0.0364778702327561, 0.051825185411519585, 0.2008659861260845, 0.3810503255696066, 0.48887189958364735, 6.533504743729869, 80.39557410824685, 75.08258250451858, 47.659774672600534, 53.37043969861923, 105.43435358232068, 68.29211250428231, 60.485462296393614, 33.21410894393921, 35.152744323976584, 30.195084156528598, 31.203107795407696, 77.16638872700354, 86.25110795420986, 63.05781149095105, 69.3598444231095, 70.11595972122686, 65.8310370291433, 66.14411277155723, 67.18354086722097, 64.76255201524305, 65.51629427940615, 64.08457033095821, 65.6411393996208, 51.73038690320907, 61.91183220955634, 29.304168762699252, 0.7621748084502836, 12.051715735466251, 71.18200502087994, 40.11829630021126, 33.76315839828984, 35.30566184751449, 8.155341071467246, 22.071061249702208, 30.367162458358276, 20.832459119058427, 23.615261124026393, 17.386209772479152, 22.639175384275376, 21.35947269778098, 21.751913678261545, 17.944496408585582, 6.636841547104621, 4.987436350314848, 5.306147558073844, 20.546494799275553, 21.155419234306585, 18.397875332063247, 31.242384449128185, 43.973429203033454, 35.953441281472486, 13.10775016584704, 2.152568803679559, 0.26206590054977325, 0.32147062581873714, 0.900380379490314, 0.2567904199203176, 0.14965164475142956, 0.1255933582902916, 0.10805598925799133, 0.936897890942712, 0.16962876633530663, 0.3758750952059223, 0.26838958864250495, 0.20400455642131068, 0.11522854873610121, 0.2239789660539358, 0.3201423825756196, 0.37168762796828825, 0.09806352141763895, 0.9702495593697795, 3.870333067832455, 3.81723667825422, 3.324457301247505, 0.506856273258886, 0.3408213019851716, 0.20030942324909473, 0.07980580757101698, 0.07888799593333276, 0.03765310656519667, 0.3006934020067415, 0.11032623719544181, 0.20385402014418957, 0.07851637434214354, 0.14080115353628514, 0.16684550761936173, 0.8461385352476951, 7.769209713705125, 38.9282178109692, 33.10068576566635, 32.93566380777667, 18.859230395286314, 15.830983135008044, 11.535477888199592, 10.612098017046529, 10.979740792705167, 13.069524707332736, 15.442181133454847, 14.372379183769228, 16.756945886919578, 22.795728944963027, 19.519439820320375, 20.533476452673636, 24.652222048851755, 24.266835451126102, 24.928545182751073, 33.035099814015055, 30.983255024879213, 8.95023782407084, 13.42564061764748, 29.02878699764129, 38.18105728395524, 71.94347827665268, 8.068568437330185, 7.376559867012886, 1.6287116297791082, 0.08857042799072881, 0.2390482526032194, 0.5611874127099591, 7.09197033797541, 33.08040711187547, 49.517036561043035, 53.03619100201515, 58.53620513792961, 56.46702151144705, 56.860729417493275, 47.43803131964899, 28.01902182640568, 25.711093333459672, 20.80582230321823, 9.35184342245902, 22.637949643596528, 49.95229021195443, 45.98427541794316, 52.54240382102228, 44.14928474733907, 49.802090890945934, 71.35153770446777, 13.342495195327267, 0.4579414367195099, 0.10882373193218824, 0.05686586775306252, 0.0493030324428072, 0.06397676481414707, 0.243307548244634, 0.019555394012000293, 0.048381409517699675, 0.03891648897420495, 0.03444753038967329, 0.016351604736560298, 0.046397103897986874, 0.07370271449608189, 0.010566200662945068, 0.038150581080586686, 0.03393596368691614, 0.10356941831208046, 0.08564892104796826, 0.03270129042287027, 0.06170979956345213, 0.1493049593221757, 0.13483073922895616, 0.02240360932304494, 0.09715471131306502, 0.1037070383467982, 0.018864275451989907, 0.08793022363416611, 0.04671126506441543, 0.04983373219147325, 0.04310771004266797, 0.06828910821387846, 0.04146412585771853, 0.11817573494608365, 0.1113133951120319, 0.33685505029655277, 0.3218361416891698, 6.611678071560399, 90.02544003148233, 81.46892286116078, 52.04285860061646, 65.56739099564092, 100.35663358626827, 73.7031319833571, 52.5244079866717, 24.904387304859778, 33.61381415397891, 25.840017718653527, 36.2319334860771, 84.60788588370048, 89.64301678442186, 70.09719510232249, 78.82021688645887, 81.30057473336497, 76.58408149596184, 73.95678381766044, 74.55960504470333, 73.69537353515625, 76.13942592374741, 66.90622929603823, 73.46360852641445, 58.96820322159798, 64.8478517993804, 23.757556869137673, 5.583786647165976, 17.330598408176055, 58.368708164461204, 53.28321795309744, 48.14621133189048, 60.02772954202468, 16.628700071765532, 21.970068062505415, 26.520362630967174, 21.916070753528228, 22.389857769012455, 16.22888307417593, 18.69823867274869, 20.184967979308098, 19.305664762373894, 13.106723485454438, 8.514853754351217, 6.89422502633064, 6.773787669597134, 17.083630292646347, 20.760330653959706, 18.0599945206796, 30.41344838757669, 49.89770650863648, 40.05066287133002, 18.452382549162834, 3.5455340964178887, 0.16105411273817863, 0.30733204416690335, 1.155024512160209, 0.6141063150378966, 0.20404460749799208, 0.1598253536729082, 0.1990173240342448, 0.5783632265463953, 0.012414315001918905, 1.1360695357284238, 0.4878668535140253, 0.3285300953974647, 0.1209873695587439, 0.23020491664928777, 0.1788002637124831, 0.4584453693561016, 0.08707776695730225, 1.7791412674611615, 10.05839761226408, 6.206993412586951, 1.649512203951036, 0.6050491333007812, 1.0062913608647164, 0.3205675000865614, 0.13459576474082086, 0.13848908485904818, 0.01813158513076844, 0.45729369405777226, 0.08042291437666263, 0.2565855526876065, 0.0668762352377657, 0.08149769743003192, 0.4548093628498816, 0.8221234561454865, 15.306216093801684, 44.38817670268398, 41.449376152407744, 25.72621407047395, 16.39871189671178, 16.484611803485503, 13.734876359662703, 11.784222837417357, 10.884769424315422, 10.804793277094442, 15.056008100509645, 12.27339142753232, 15.309951170798271, 18.167151712602188, 19.396387223274477, 17.139196549692464, 20.670057304443855, 19.39641860223586, 20.654057956510975, 27.138751745224003, 27.372479900237057, 12.124338419206682, 30.65582144644953, 50.73996490047824, 47.63053732533609, 54.14615115811748, 6.040791801867947, 18.913976876966416, 7.653946453525175, 0.5687772602804246, 0.14011696041111024, 0.5414010776627449, 3.6925273701067898, 29.841964937025505, 54.51798008334253, 57.169106160440755, 64.48691921849405, 59.22336124604749, 57.425758607925914, 44.99617545835434, 20.07646345323132, 19.342766461833833, 23.843515611463978, 18.458262182051136, 23.62675759100145, 45.702582559277936, 55.42510663309405, 62.37781763076783, 54.07799605400332, 53.88577245896863, 74.92016500042331, 5.679847944167353, 0.288215515113646, 0.14238327831750916, 0.02693339145832485, 0.15540795280568062, 0.07537039597668956, 0.198921287252057, 0.1263786137344376, 0.05461453452646252, 0.0038129946023541237, 0.049266796483988726, 0.05131102933157837, 0.027575989839650934, 0.038766446823795, 0.08544030764530744, 0.03996841962479296, 0.05994557951306624, 0.181896009692742, 0.15434212532014618, 0.15077880523618192, 0.20063059795047009, 0.1680220654534717, 0.2846705504963475, 0.21126915370264363, 0.3321426902567187, 0.33050969723732243, 0.15034864686669844, 0.2211038380741112, 0.12881196945184661, 0.21436286188902395, 0.22383457380196742, 0.2490413486356697, 0.21336736127493844, 0.41087615093396557, 0.4189905542279444, 0.675641990477039, 0.8016991843619655, 19.226793742948963, 110.57842439220799, 89.00716920052805, 71.33654640566918, 77.91453376893075, 126.66762598099248, 95.442397978998, 95.66267044313493, 44.978524792578916, 50.174163003121656, 46.99311687100319, 59.539547428008056, 95.03145125604446, 108.59624678088774, 79.09047603607178, 89.97946200832244, 89.90063021259924, 80.26757932478382, 80.02525529553814, 80.06236876210859, 79.17009230582946, 79.2409695348432, 75.26407057239165, 74.03115980086788, 67.85528598293182, 69.8627785713442, 41.44042138130435, 3.007616573764432, 19.110311115941695, 85.00486112410023, 61.2724191911759, 46.84109757023473, 45.78083776658582, 10.325178600126698, 31.81092219967996, 36.53545041238108, 26.801959391563173, 27.888903079494355, 21.652036405378773, 29.137705333771247, 26.69618091275615, 26.098966713874574, 23.179301446483983, 13.757737894212047, 12.971271295701305, 9.115738311121541, 24.524962709796046, 27.077713781787505, 28.012828403903594, 40.08465805361348, 56.16642282855127, 48.22552165677471, 26.7331963200723, 4.602274308281561, 0.32569192349910736, 0.3784271792298363, 0.8094215344998145, 0.40241703871757756, 0.31337041047311603, 0.1748035217244779, 0.7203792576347628, 2.237201049443214, 0.4120535974300677, 1.2459899148633404, 0.6327280738661367, 0.7892144026775515, 0.37153793438788385, 0.24891047017468562, 0.42879985044560126, 0.3836069141905154, 0.15693278953192696, 3.508375277442317, 14.942878119407164, 18.71129232068216, 5.94912895271855, 0.9047038732997833, 1.5593526031701797, 0.7696680676552557, 0.3463075027590798, 0.19633364142669787, 0.12659670364472175, 0.7547738475184288, 0.22680972222118612, 0.6596775148664752, 0.22251665742406923, 0.3838369550724184, 1.0209908108076742, 1.2633996000213008, 28.426520785977765, 51.09308804235151, 45.764944322647594, 38.25984593360655, 25.81595397764637, 23.762859913610644, 20.314782742531072, 20.00194626469766, 22.013667168155795, 21.230354155263594, 22.896863337486025, 18.999657131010487, 24.06866946528035, 27.087201995234338, 26.85705496418861, 23.985022960170625, 32.368192941911765, 33.35940137986214, 34.17038279194986, 45.64019726168725, 39.94800659918016, 12.935425735289051, 19.035958666955274, 41.377333979452814, 56.70614880900229, 82.22340645328646, 10.892712223914362, 10.670235387740597, 3.4606405227415027, 0.1812613364909926, 0.34266015815158046, 0.7904341985141078, 14.2819675707048, 52.07410420140913, 68.36978327843451, 61.10119204367361, 69.73604679107666, 64.67158048383652, 70.32762650520571, 56.367518824915734, 37.55552553361462, 32.25805082628804, 36.09673723097771, 19.3109913410679, 33.210335623833444, 74.13008982135405, 66.51027387188327, 68.71438703229352, 64.6094972087491, 60.502344177615264, 93.12026070010279, 21.61255382722424, 1.1244487786485304, 0.495729030019814, 0.22952171943841443, 0.10876534071059958, 0.18979377864349276, 0.23819034138033468, 0.24308916722093862, 0.21560208571534004, 0.16624967507537336, 0.08465916609331485, 0.18940889607033423, 0.13607143394408688, 0.20430282509375006, 0.19098771135172538, 0.16670975683917924, 0.2598333977643521], [0.04935491574747909, 0.1048588515409539, 0.0524231361886186, 0.14975515855175836, 0.04402163378413647, 0.03480830034541507, 0.11813119459416598, 0.08424723295555, 0.12641155551518166, 0.02520244069127066, 0.07626301864342344, 0.09526347005439383, 0.06756559945642948, 0.06478440917788014, 0.03584159207680533, 0.0653397539750703, 0.013426605390474923, 0.07765080224001601, 0.08945636270988373, 0.09176658511522318, 0.4684472907214396, 29.749602925392892, 76.16361910297026, 54.97824668884278, 41.56161477488857, 73.63755779881632, 77.90125262352728, 65.93905910368889, 40.89818116157286, 27.396049422602502, 38.746717975985625, 22.73631876514804, 64.8415485505135, 73.67240413542717, 62.58566010382868, 71.37149472390452, 70.59350828970634, 69.6227216720581, 72.39647280785346, 62.87393862201322, 66.17921798459946, 59.32274626147363, 75.01046580653038, 50.10853390539847, 25.611639676555512, 23.994850458637362, 5.323842350513705, 5.545481270359409, 62.45349976324267, 47.294366667347575, 30.874075851132794, 36.831048073307166, 10.767985755397428, 27.86071300506592, 26.479701380575857, 22.24786404640444, 21.7540592147458, 18.34289743054298, 20.69040067734257, 22.50758182617926, 22.907920499001783, 19.636314684344878, 10.770489208159908, 7.147823418340376, 2.44900903874828, 9.492674162310939, 17.752774876932946, 23.65960548000951, 19.4575350130758, 36.30728613945746, 46.08419779808291, 35.23162318814185, 13.23124206835224, 5.5136571199663225, 0.2736568721311708, 0.26147711601468826, 0.27488221444429894, 0.2575374935423174, 0.2961788458689567, 0.06462801998901753, 0.20013504631577, 0.06003547993098056, 0.11075993489113548, 1.3108841810495624, 1.4549894871250277, 0.23212772073043933, 0.34634173156753667, 0.23489414083380855, 0.3988815123035062, 1.1231244884191023, 0.27721253133589224, 1.304648470494055, 2.129856809493034, 2.5670392859366635, 1.0645202331004604, 0.12548257431556142, 0.07544861355375859, 0.10510496494750823, 0.2760784454163044, 0.10099442059835119, 0.0680573666167836, 0.1794848705251371, 0.661895431337818, 0.29613266608888106, 0.04559539288522736, 0.20609810617902588, 0.342397727072239, 1.039673734095789, 12.428116183127127, 38.438486360734515, 42.69630547492735, 32.68349855176864, 21.877511893549276, 18.439436766409106, 10.028968068861193, 7.014110799758666, 8.184948592416703, 8.53663859828826, 10.453699961785349, 15.347934422954438, 19.97044570984379, 21.148535474654167, 22.000650782738965, 23.705436414287938, 29.266141383878647, 31.98891151335932, 33.41356931194183, 28.738845394503688, 31.787074189032282, 42.14047816491897, 14.420185031429416, 13.789988602361372, 24.55845778988254, 47.80543581131966, 66.43874552942091, 5.954059862321423, 12.297830735483478, 4.721504065298266, 1.9099927621503032, 0.8067404106259347, 0.20693660473390935, 0.9149815250308284, 15.249387814152627, 32.00823703119832, 40.175256959853634, 37.27569187841108, 27.25511081757084, 10.768297583826127, 3.4938573596938967, 2.084498275672236, 15.163977223057902, 17.289766534682244, 47.19628780118881, 48.210910827882834, 43.9891500626841, 52.804010222035075, 40.91801266516409, 58.36306387378324, 38.074506098224276, 0.2545354860804735, 0.08546466158042032, 0.1503743414556788, 0.1061275391088378, 0.06623544865438054, 0.10306566953659059, 0.04677945838099526, 0.030679712710421414, 0.04647127653081571, 0.057873078021070654, 0.0599129096935353, 0.030988254621925376, 0.016320604988704288, 0.039837043206658096, 0.06321805814701704, 0.007249368889813102, 0.04565656117554154, 0.052293042967756914, 0.02312458424468435, 0.052903906156819676, 0.06568955738217601, 0.15062586344297857, 0.04919854571081458, 0.08105125203127823, 0.06843376859662033, 0.15958578265722723, 0.043472406199021686, 0.01895958445064964, 0.018291055908306472, 0.016990671452555447, 0.04118600529768775, 0.03999893673725667, 0.15684772312881487, 0.014137040857496041, 0.06737750954926014, 0.0886647257533285, 0.10987802213358303, 0.4193127095218628, 23.84200942131781, 83.89095506360455, 59.29545440981465, 55.66477129536291, 86.18748711001489, 89.83729962379702, 69.7140815181117, 30.812263219587265, 23.853058738093225, 29.73871050342437, 30.917117980218705, 71.9973559533396, 81.43539444092782, 73.28095159223004, 82.56529592698621, 85.91986379315777, 75.67570763249552, 84.27027179348855, 72.24425346620622, 77.27675637891217, 63.12040467416087, 88.01092640046151, 54.257644530265566, 30.630571188465243, 19.545249016054218, 20.41531309004753, 16.834093024653775, 49.09313032704015, 56.872049377810576, 47.16727795139436, 61.30082107359364, 18.348906501646965, 28.77778864675953, 26.90717108788029, 21.560964853532855, 22.75857037113559, 16.423833697072922, 17.778260477127567, 21.9469476515247, 21.415544940579323, 16.912820877567416, 9.352011103783886, 7.357454492199806, 4.069815008871017, 10.994863490904532, 15.375275304240567, 23.10206605542091, 16.832659398355794, 34.08085861513692, 49.100108223576704, 38.08523378064556, 19.978590511506606, 5.847918073977194, 0.2739420713436219, 0.47109706627745784, 0.21238018037571063, 0.5607117640395318, 0.23540240952805166, 0.08725087218467267, 0.4790254327799044, 0.5298244472472898, 0.14730939220997596, 2.725225042912268, 2.0636185186524547, 0.44069710397912615, 0.27847872145714303, 0.20685685498099174, 0.49944866268384847, 1.1221050398965036, 0.24392501511160405, 2.5445003663339927, 9.334116270465236, 3.403401374816895, 0.17976387974716004, 0.3398174816562284, 0.5334300247411574, 1.0551837663496695, 0.48721788511160885, 0.21913255594911116, 0.14077090838503453, 0.8495750831019494, 0.34882456124309574, 0.2412760516087855, 0.04555070314616446, 0.22393039607953644, 0.23246610176659402, 1.042031814013758, 20.455074156484297, 48.79886234960249, 46.80270933335828, 29.988124216756514, 18.330838103448194, 19.03710792141576, 12.728178481901846, 10.969802487281061, 10.709900356108143, 8.980435171434957, 9.403776584133025, 12.1013121451101, 16.1356306845142, 18.04510912587566, 17.38166766781961, 19.2351052453441, 20.56124487230855, 27.910150558717792, 33.03293858805011, 33.08758112692064, 30.694407763019687, 38.307628247045706, 16.04363835627033, 30.15125951459331, 42.08062671845959, 52.11441047729985, 49.568168578609345, 7.195949429465879, 23.365008023477372, 12.072557249376851, 7.4353890457460965, 1.72754273299248, 0.05198482281318115, 0.9357175639560147, 17.06820361075863, 33.44629756865963, 37.17880149041453, 36.13519607051727, 26.208755816182784, 10.133503156323588, 3.9746936098221815, 2.205007460809523, 18.446534295235914, 25.357071968816943, 42.01505253391881, 53.23031302421324, 53.29986056973858, 55.6511136024229, 48.996204637712054, 69.75496830478792, 28.762156040437763, 0.25289429592028745, 0.09175874803575779, 0.1845855605337889, 0.17033497682742535, 0.04439079240264912, 0.10399750058328915, 0.06190051332176213, 0.039155876128784114, 0.050171891062129895, 0.11152501157935589, 0.0421012084059898, 0.04908898747676323, 0.0740733708164865, 0.03221137336485329, 0.04373399075120688, 0.06155560521649257, 0.032973872167208505, 0.13472207731777622, 0.1627658902397079, 0.1004086621105671, 0.37933677074409305, 0.34252290583906636, 0.0985217722313058, 0.16053567039630107, 0.2628538985886882, 0.42746652037866656, 0.15581327460465894, 0.1280811292329623, 0.2048972020706823, 0.308828336457091, 0.130021101344497, 0.1784448295591339, 0.3424723133925469, 0.15276148674949525, 0.2055285964161158, 0.17155737736292426, 0.2677703444515505, 0.5788114799126503, 53.40645097917127, 100.85606113556894, 77.61683371759231, 67.77189639306837, 99.28515972629671, 106.36339049185477, 107.86877262976863, 63.653427323987415, 41.107043450878514, 61.26305649357458, 45.95501845882785, 83.09447857641405, 92.85279427805256, 83.99602751578055, 91.69505180851107, 93.22250904575472, 81.97919184161772, 89.39552307128908, 78.50438764018398, 80.60955509062737, 69.07671205459103, 89.17911806414205, 65.36275702138101, 39.18169313861478, 37.8725471804219, 17.71788735543528, 12.499792595063488, 73.55854557406518, 68.86585327886766, 44.833193132954264, 46.34419210495488, 12.30179330995006, 39.361949582253736, 33.34973665975755, 26.280119419097904, 27.063610899832945, 22.524946158932103, 24.417295609751058, 26.76680122652362, 28.65181976749051, 25.503794108667684, 17.246245876435314, 14.139671825593519, 9.285028788351244, 15.9677355904733, 21.94968350471989, 30.464135216128444, 31.186282788553548, 43.47273865053731, 58.820953522959066, 40.62808282913701, 27.670829103839015, 11.580190946978908, 0.311147253960371, 0.4781637677261907, 0.400781195851103, 0.424710565036343, 0.43879668498712204, 0.1793132208648228, 0.8667509582254195, 0.38303225631675414, 0.8109352016641248, 1.490463280389386, 4.413800989427875, 0.5006695310434988, 0.42470897157346055, 0.22424276076978256, 0.9653537672373557, 1.1598617751752178, 0.5161328012904813, 7.611459830114919, 15.64252011237606, 12.558842897415163, 3.441122808764058, 0.4606493123837056, 0.9875347705618028, 3.5848877266530073, 1.7424842667195106, 0.7165349058566556, 0.41013090060122553, 2.5783425761807353, 0.9121884297459357, 0.8064157732071415, 0.18536237368900932, 0.3064675292661113, 0.4571500372502112, 1.82217653239927, 30.519358265784483, 57.03196048736573, 54.3358487467612, 38.70301492752568, 27.47700910414419, 25.059850446639526, 17.471750782382106, 14.478707774992913, 15.152539591635428, 15.52861644375709, 19.104766845703125, 23.220117630497104, 26.637849384738555, 29.310915239395637, 27.690893988455496, 32.26952572022715, 35.88684728068691, 42.373925870464696, 42.22282832668674, 36.7289880014235, 38.138691763724054, 50.308727756623306, 22.789490415203957, 17.71123697680812, 35.57150440831339, 62.70330767477713, 83.0363961189024, 9.475998205523338, 21.36545038992359, 7.7729374362576396, 5.070490577528554, 0.7892175896033164, 0.42225626447508413, 1.5796657002741292, 38.49727484487718, 52.08030546865156, 50.05722145880423, 43.48509411658011, 32.620650414497625, 13.971008927591386, 6.68850161375538, 5.083137769852915, 26.817862641426828, 23.61628486264137, 70.9070311823199, 76.61469167278659, 62.803594835342906, 71.76248442742133, 60.266970588314926, 82.69862513388358, 53.27586350902435, 0.2727465145289898, 0.15071587877408152, 0.30040314661399015, 0.5321817917208518, 0.15354766149915036, 0.23163196991287896, 0.10025502317735266, 0.18491790479710027, 0.1781154270734518, 0.20025444877964838, 0.16459190677250587, 0.18425782811978172, 0.17792355269193652, 0.06132873210815653, 0.24298131736295842, 0.14338313031100458, 0.1674192308658554], [0.019556815105099833, 0.11781194277348057, 0.07283567150513973, 0.03651011487348907, 0.04890724460804655, 0.0694683856601196, 0.04644929363782849, 0.0762878705356871, 0.1821285480212781, 0.03176013608613322, 0.08544988374436095, 0.04981115174990508, 0.05349925223497614, 0.0763121555228868, 0.06380861234520713, 0.05047331218637767, 0.1296451360347771, 0.016395415389730085, 0.009939314744945978, 0.1890707601823153, 0.05474923193574913, 0.48808307416977426, 38.41412844196443, 66.0124231153919, 47.424299101675714, 45.761449490824056, 75.05697727203369, 64.80688656530073, 61.804206294398156, 28.035907629997503, 33.98588234378446, 21.319058556710523, 66.35844676725327, 83.7259566399359, 74.37155092916181, 72.02757389314714, 70.41583276564076, 70.77359999379804, 62.2571066887148, 65.14435552781629, 58.168569226418775, 76.76978218939998, 54.11864357609903, 6.498126435664393, 2.8512922265837273, 4.7481281334354035, 5.230405119157607, 44.76024489248953, 63.77682508960847, 34.213579854657574, 31.77688191013952, 10.14026532250066, 29.829991902074507, 33.13310807751071, 25.0149118515753, 23.69632867074782, 19.8784347503416, 24.492932634968913, 21.176960891292943, 23.005591438662623, 21.48509640847483, 21.281860759181363, 11.161288676723357, 6.134024579678813, 5.02788039945787, 10.083993038823529, 20.023205511031613, 21.357525240990427, 20.92109880139751, 41.51966502589565, 47.865557901320926, 35.034331890844534, 11.554402343688473, 4.606506055401218, 0.44762229366648587, 1.11573989112531, 1.391550175124599, 0.872598844430139, 0.7431682896229529, 0.4336354587106936, 0.22689195409897836, 0.035404948773042816, 0.16199286155883344, 0.5965453121931322, 2.9362358104798103, 0.17581664236082187, 0.6648323060043397, 0.2469110726228645, 0.900292003587369, 0.564093153563238, 0.4779613979401127, 0.20364015903924743, 4.0678479402296, 1.1576271273436085, 0.3201109729707241, 0.08850402348945219, 0.2895284978853118, 0.793014872939356, 0.8609307737600419, 0.10940084894818645, 0.20468257487781588, 0.826774774299514, 0.48408271624676646, 0.32199824589394754, 0.3298809841996239, 0.17193216289724075, 0.32205322036339395, 0.6907445865292704, 14.218625214792068, 41.58392913879887, 51.1321666163783, 30.90482919446884, 22.924778846002397, 16.177020515165022, 14.89057331315933, 8.895866909334737, 8.619735971573862, 7.40540546755637, 9.527355759374558, 11.618296773202959, 12.786511971104531, 16.672867921090898, 21.89856521544918, 20.844700836366226, 27.034126443247644, 31.93508286629954, 23.005579671552105, 27.800406563666563, 26.836405646416452, 25.879600317247455, 53.05826217897477, 15.66829400677835, 19.759971326397313, 32.19446528342463, 56.12525755359281, 40.702290150427054, 8.130080026964988, 24.51649823496419, 4.7505212695367875, 3.617352203976724, 0.7201476539334943, 0.1822591660123679, 0.33985946327447897, 4.392347585770392, 7.326797737229255, 10.629386844173556, 7.885422187466776, 3.576216101646424, 1.1181156217090547, 0.4736333076030978, 5.7269399204561795, 28.836626160529356, 51.79854200732324, 51.28468405815863, 40.29325362174742, 34.24191897915256, 38.193832443606475, 43.68275019430345, 5.189088342651244, 0.21584321955038657, 0.07720883845561936, 0.04000134225333891, 0.0772804370330226, 0.15421686994452632, 0.07827028391822692, 0.06222265329392207, 0.05415573212949019, 0.01717614516946337, 0.12352951742228001, 0.0904098357404432, 0.04974155649242382, 0.15453778417600741, 0.007234163959735945, 0.07238312038562952, 0.008902419527481881, 0.052381131587730306, 0.06369672137342634, 0.06000623452447115, 0.07321426449643989, 0.012901302731235423, 0.12627519952553895, 0.035134052422138, 0.05460840582306828, 0.042629326438351024, 0.06790115362814358, 0.004678956212310662, 0.029543066141946666, 0.04824075194436216, 0.03915372725215651, 0.013675334987290686, 0.05797424759235113, 0.06418288077017473, 0.21649217263104456, 0.046169326805900184, 0.09633415453736821, 0.2566926517794209, 0.1072538645577527, 0.7253153153484868, 40.727424698491255, 81.888898880251, 53.63583118684831, 61.13135114792855, 85.64654519481044, 74.86573034717192, 47.985300017941384, 25.084851634117868, 32.93590307235718, 32.16774021425555, 70.31921694355627, 93.42557014957552, 79.68334228761735, 91.41174685570502, 78.30900653716057, 82.44981350437288, 68.40694381344703, 77.7898730001142, 69.41472622656053, 90.62912417996316, 56.52553542967766, 9.417341120781439, 2.757594402759306, 13.677733309807317, 25.25210345945051, 32.55283459540337, 65.37008008649273, 53.9074396318005, 62.271662604424264, 14.527599138598289, 28.644253515428115, 32.086135302820516, 21.188280851610248, 21.387031270611672, 19.35031114086028, 22.27819965731713, 19.49902584475856, 19.45431474716433, 17.221733024043424, 15.352743248785696, 9.051817405608393, 7.541884827998377, 8.344814104418601, 8.512180659078783, 18.576921724504043, 21.10683087379702, 19.310781494263683, 41.22427132821853, 51.09913241478705, 42.98955755849039, 22.122012838240593, 4.581868177460087, 0.3858144118660881, 1.1794049845587824, 1.7191188301770919, 0.9169966427068558, 1.3085167855024338, 0.3927980693838289, 0.19404227244517497, 0.5158814631642834, 0.4726627354900684, 2.9990241316057022, 1.908372455546933, 0.4927646987620862, 0.835958881483924, 0.39230332980232857, 1.256361764765555, 0.6204011675811584, 0.44493697163078094, 1.5295564407302489, 10.066044272915011, 1.9610914395701502, 0.7291351523130172, 0.0779736316913078, 0.6917580289225425, 4.299239343212498, 2.0554392736765648, 0.11449360994682198, 0.25983661533363406, 0.60996521144144, 0.22258701493903515, 0.36716963975660266, 0.21627042082048234, 0.3493537747811887, 1.3990670298376393, 0.6547650526608191, 21.82849599469093, 52.4324401732414, 63.37066758063532, 30.7674442568133, 17.714317998578473, 16.6626658362727, 12.719737541291023, 11.267574121875148, 8.245532051209482, 7.277505801570031, 7.336025603355901, 10.563958767921696, 10.531980664499345, 13.050603193621482, 15.953778816807656, 12.78231111264998, 17.675298260104274, 21.759619174465058, 13.27034221541497, 11.60511859001652, 12.896559949844116, 15.879882343353765, 44.97017406648205, 17.92007769307783, 34.315322214557284, 43.71200715341876, 44.24363736183413, 28.72643501527848, 8.764665588255852, 32.64851297101667, 19.02378166875532, 6.6851224918519305, 1.3803141780437962, 0.6797419091866863, 0.180336193391873, 4.3797543260359, 6.297340796839807, 8.84137930408601, 5.963041599719755, 4.130657344095169, 0.6345261741549738, 1.6784482641566185, 9.547530470355865, 37.462467301276426, 47.49513318461757, 69.24004739330661, 47.60757969271752, 47.62380261575022, 48.86013369406424, 44.49714014607091, 4.294044163919264, 0.11024053493935256, 0.057918445747946544, 0.0672250350696906, 0.21450566067810983, 0.18770836473953342, 0.0376948123917945, 0.041539937918705326, 0.04859819324807294, 0.0999553602248911, 0.1819248605639704, 0.03143677420373405, 0.027763646907143058, 0.03086379406252696, 0.012877215011676234, 0.05416502094557209, 0.08511286634471148, 0.08439408434975533, 0.09245033390940198, 0.11958847002637003, 0.19366923359132585, 0.1442024153807471, 0.28714234850579695, 0.16290594643402487, 0.150124995158084, 0.1596243475233355, 0.2249120611457094, 0.08617390578071918, 0.12893034535790646, 0.21544601828340562, 0.19599559746922987, 0.276005421915362, 0.22414638690890806, 0.26088931207214633, 0.2958161185585684, 0.27918067250040274, 0.22493000292489607, 0.3308184919578414, 0.25166179834594654, 0.9218446922398383, 72.17980107953473, 97.64403220145934, 72.9231059166693, 74.12615960644138, 100.27886867523195, 97.67213990611415, 96.19877215354674, 43.77837757910452, 54.09555650526478, 40.92248416716053, 82.98223603156306, 104.49658547678303, 92.788067325469, 97.61540674394178, 88.67720373215215, 91.74011199705063, 76.94426490414527, 84.43656459931405, 75.13170626855667, 98.59798400632798, 71.47964231429562, 12.694995230244054, 4.787266033311044, 7.751623276741275, 16.130064841239683, 54.21816979685138, 88.12212559484666, 51.47370307676254, 47.01363478937457, 12.887559090891193, 41.364088135380904, 41.63344906222436, 34.024368639915224, 28.667028757833666, 26.00158799079157, 30.68892428951879, 24.30100125651206, 29.055588553028723, 27.743524351427634, 28.69736436874636, 19.051312784994803, 12.714517847184213, 14.934562694641853, 13.3634739921939, 25.823465316526352, 28.819848222117272, 33.9104159416691, 53.09582671811504, 62.26328834410637, 46.76994185293875, 30.450756011470673, 10.292572917476779, 0.5745685785528153, 1.8773621969646024, 1.5362250828935256, 1.390783719478115, 1.1364191169700315, 0.37349596319179384, 0.33867591871849956, 0.5704168722994867, 0.22478289872167573, 8.426295461193208, 6.925479452456198, 0.2267207334479017, 1.0615762491380016, 0.625467337667942, 2.249470223342219, 0.9793552804377772, 0.7275552338650151, 8.553001746054619, 17.95508876923592, 5.367689546077482, 0.2883525222780243, 0.253469719881973, 0.3267054271794135, 4.201803745761994, 3.580143619929591, 0.4948107051032205, 0.6560523255217461, 3.724877363251102, 1.2500702830091601, 1.489697560187309, 0.5463460832834244, 0.5401474513834523, 1.1283433245074366, 1.219560984642275, 36.30124176702192, 56.424671680696555, 67.64154818750197, 36.97785454411661, 27.718989925999796, 23.062812935921457, 22.312918516897387, 18.430321178128644, 15.422843848505329, 16.714027312494096, 18.347929831474058, 18.636824161775653, 20.34993894638554, 27.13680232724836, 31.10812956287015, 25.674054391922493, 30.443487859541374, 36.28945896702428, 29.719498734320368, 34.91234617848551, 31.603662198589696, 25.02205841002926, 59.95883703231812, 21.223456667315578, 23.118157579052834, 43.46743560606434, 63.649736373655266, 52.82468111284318, 12.884544749413768, 35.27480063899871, 11.938575948438338, 7.533527237753715, 1.1416503330392223, 0.8868561697102363, 0.30173932652800317, 9.711771876581254, 10.845227030015762, 14.00614453900245, 9.425019160393747, 4.957372363536589, 1.6316106290586534, 2.703820178585668, 13.295548346734817, 39.24598078573904, 84.37669354100382, 75.15777434072187, 56.607124651632006, 61.98702796812981, 60.51715112501576, 78.9004607354441, 9.946695373904321, 0.32236314889404083, 0.17162362864661604, 0.14921503592162363, 0.4102180201199747, 0.25746805533286066, 0.07288563575956129, 0.2114814979534957, 0.18423571882228698, 0.14452752777405325, 0.31132771363181455, 0.21149488917041212, 0.14356366659124054, 0.21371265242417015, 0.14168600041058757, 0.3436174922652783, 0.17500595279758976, 0.28761579084300226], [0.015316090392579716, 0.042937014161819415, 0.04013983945872995, 0.0933472236858741, 0.03915491851887876, 0.0817545360675262, 0.08286737836897373, 0.07222902179966051, 0.08632673266073389, 0.017903827190879854, 0.02792049383354043, 0.02428518638255135, 0.03444561133942297, 0.034569288573918805, 0.10673570566840711, 0.12854958433778058, 0.10868972017159385, 0.03873650810771412, 0.04606700044185404, 0.2595254610623083, 0.07857281203952529, 0.608750379854633, 5.5148235347963155, 61.05670059880903, 51.93541703685638, 39.7602427390314, 62.94047770961639, 65.05361541624993, 64.84220750870244, 28.270830146728027, 32.40563000402143, 29.517437834893506, 55.98159290129139, 53.80390867110222, 53.28532426587997, 73.74341472502678, 67.7123155901509, 72.02405944947274, 64.50423256043466, 63.629500865936286, 56.3432118969579, 37.253346135539395, 2.5294389551685703, 0.4596485870499765, 8.324810997132333, 14.81748680914602, 29.31643597541317, 83.51457226660945, 39.01071310043335, 28.23545821251408, 14.401378247045702, 42.59251956016787, 41.09166383743286, 30.419039726257328, 29.092688291303574, 25.750181713411887, 22.87386844235082, 16.928257365380567, 17.27422414287444, 23.3225836676936, 26.467241971723496, 18.053706961293376, 9.122718168843178, 8.24230884352038, 7.896002781006598, 16.8746111085338, 19.531914918653428, 27.83917134807956, 22.34762364818204, 36.44179990214687, 50.10246207637172, 41.6497935787324, 15.81882869043658, 9.138446873234166, 0.7040344959785861, 0.880260581691419, 1.9837634746105441, 1.6835993167854126, 1.6352980247428341, 0.6505675649931354, 0.14370611297988123, 0.15331887700144323, 0.6843893662575753, 4.876382773922336, 5.4873218363331215, 0.7440977687797239, 0.852082948530874, 0.5846532987010095, 0.49833792712419267, 0.19495944822988204, 0.9569079236638163, 0.38280911022616976, 6.997613310813905, 0.8579713454650295, 0.545855725724851, 0.8659934504858909, 0.899643709342326, 0.7041724530919906, 0.15084049063584498, 0.17394757168667932, 0.04760309099970807, 0.1332422559179606, 0.07569662685836516, 0.023551105611747312, 0.09651433841715898, 0.09204449117063515, 0.6041738931690493, 3.77154792989454, 20.254286066178356, 47.238971033403956, 49.36724908890263, 36.377931948631044, 20.628715522827644, 18.181727240162513, 17.21307635307312, 8.868419143461413, 11.142659379589944, 8.424583346612993, 8.590051474109773, 10.437005373739428, 17.228179439421623, 25.816483497619632, 32.47504615014599, 41.10050093743109, 52.85495396583311, 65.35817569301975, 72.5300765806629, 82.63893450460127, 75.25934019396382, 55.4151830365581, 36.3814385475651, 38.53897748454925, 12.399080837926558, 27.619577453982448, 46.29238151734876, 52.48638845259144, 26.012080331002515, 14.581456222841817, 23.908821113647956, 1.5351056139315329, 0.783145025132164, 0.30547660985781305, 0.43135956470524117, 0.2615016001847483, 0.33514416145701564, 0.7194051002302478, 0.8239418424425587, 0.35954737134518167, 0.24582684370538882, 0.5425330491796617, 4.909581715060819, 26.93192320485269, 47.75305255766838, 54.501996424890336, 32.30345029984751, 27.899797462647964, 32.18033690606394, 13.173085085807308, 0.06605706508121183, 0.08848530030058277, 0.016338167554368416, 0.04720938692410146, 0.2263022962236597, 0.18059352232563883, 0.10128655290651707, 0.026556324897213813, 0.20130025072684213, 0.03865348332892022, 0.1206371907685553, 0.023568472824990753, 0.05508698861024553, 0.0504005836292861, 0.03975921633443044, 0.03305815716063784, 0.08468273095786573, 0.07552249507317621, 0.0762359527570586, 0.07544427749610717, 0.11521782350516128, 0.04495181774179782, 0.04734699163706072, 0.03759699062474313, 0.0183448237892721, 0.13161024349110742, 0.02942642350981553, 0.022865529697869095, 0.10112978067369231, 0.0807888362736952, 0.09188273170542333, 0.06379700611315428, 0.1312427204703131, 0.09909655267913496, 0.14295836520050803, 0.08282633903887003, 0.050960329601601254, 0.15758189583016982, 0.16289171252039172, 0.7078530459154038, 3.7022447970605667, 73.6946439743042, 61.80334337296025, 56.97228554756411, 76.07169443561186, 77.86442156760924, 65.26991844177246, 26.711391864284394, 40.26857406862321, 40.692982366008145, 63.43467281710718, 52.14535405558925, 59.329645710606734, 78.2337127193328, 80.4115773785499, 84.77282154944636, 75.48087566129624, 75.32195691139468, 64.51704302141744, 35.41890459675943, 2.0137974307421715, 0.7330489423005813, 14.775196794540653, 34.619380427945046, 22.74688563039226, 70.95133043104603, 57.128082090808505, 61.76757920172907, 18.8897797753734, 31.829010209729596, 42.932086990725615, 25.677443319751372, 27.877820422572476, 14.139862060546877, 10.758306326404696, 11.264841210457588, 13.202387152179597, 20.077789214349565, 16.95140915532266, 13.599050564150657, 11.126562952995302, 10.890261723149209, 9.48526382446289, 18.119810665807417, 19.737407891981064, 26.871236293546616, 21.70224274358442, 37.53513313108875, 53.941925110355506, 52.671830269598196, 22.67557890184464, 4.0926284943857505, 0.6027432086486971, 0.9188332312530088, 2.1872830054452344, 1.1954170801947195, 1.7426384648969098, 0.24839780413575713, 0.2650920397812321, 0.27271930308591935, 2.612053631774841, 7.254615339540667, 2.266765424320775, 1.5936685617892974, 1.4030488484328794, 0.6915320636283967, 1.2460389444904945, 0.20911555797342332, 2.961508131796314, 1.2957537606839211, 7.301927949151686, 2.1924892164045766, 1.792144169730525, 0.3929520224130923, 2.655739765013418, 2.4630391117065185, 0.21987727002030422, 0.2283867601785929, 0.11917749449851052, 0.0840117605102639, 0.1564109457596656, 0.44641408107934466, 0.20983499114311513, 0.5505746434773169, 0.2906794070957169, 6.517958429551895, 28.73426014377225, 61.29560824363463, 61.582584534921956, 40.901338669561575, 16.40595063086479, 18.36539810703647, 17.46651245701698, 10.34116323917143, 8.667545741604222, 6.442704816018382, 8.942819641482446, 8.304866725398648, 13.337076440934213, 16.19626464382295, 17.84833754262617, 23.852784172181163, 35.25569869625953, 43.02519621387605, 43.711320738638605, 52.43594284980528, 41.30924555563158, 29.201483072773105, 20.6209433463312, 18.18968180687197, 12.154514193534853, 43.4488239595967, 57.63481701574018, 41.804511470179406, 18.944457615575484, 12.456364112515605, 31.377596393708263, 8.897110300679362, 0.5702398140584269, 0.24445602129543983, 1.1542457991069364, 0.7548279639693999, 0.7191049776250317, 0.5231383382793396, 1.227527073314113, 0.5348105151807109, 0.09232040539744402, 0.21883157532541983, 6.778538640468352, 25.149486411002375, 49.02819548883746, 61.16152594166418, 48.352198523859826, 38.89623088221396, 48.31289637473322, 18.21171964368513, 0.04130076526874497, 0.11950394754568416, 0.02238943669644575, 0.05158374131086373, 0.21434665146854617, 0.1672602522998087, 0.08361441368657736, 0.009345048850762748, 0.16458582403438707, 0.0873720060072599, 0.16807141683755383, 0.036094201908957575, 0.050165915576320504, 0.04627288657150442, 0.12677080478639374, 0.0775655749584398, 0.05857396803255524, 0.02302874856057667, 0.2104980249198214, 0.2175044505706718, 0.3262410859667486, 0.21195650311006656, 0.2361629050104849, 0.24119951942514992, 0.2794629299352246, 0.31046571149941415, 0.16398219271532952, 0.11716855149115286, 0.22684174469642102, 0.12917843527130543, 0.3138412174678618, 0.2306799830928926, 0.19000690430402759, 0.27655964056330345, 0.21791360280927152, 0.2812038800649105, 0.4377688707843904, 0.4857599585046692, 0.25598235037778655, 1.385164188761865, 12.409108377272084, 103.23582587703582, 82.88729898391232, 78.25334810441541, 92.66328888554727, 92.97835719200873, 103.86415035493913, 50.622023151766875, 47.23932012434929, 51.72048684089415, 78.39220785325574, 68.80890830870598, 73.59396457672119, 87.34779480964907, 94.16344642639162, 95.312787179024, 84.53366679529991, 82.15804407673498, 80.24690843397572, 52.194058126018895, 3.4215232153092665, 1.4434189854129669, 11.519864893728688, 25.79654609003375, 40.088694172520796, 100.7356757502402, 60.31514906114148, 45.72838783264161, 19.963273655983713, 53.79897825179562, 50.84710836410523, 33.610397769558816, 32.443492643294796, 31.62026559152911, 27.901368371901977, 19.28381323814392, 20.925778189013084, 30.942642804115053, 33.67017076861474, 25.644144358173495, 13.895058112759745, 16.31979577002987, 13.809182720799601, 20.225078136690204, 25.56925650565855, 38.86704844813193, 36.25205916743125, 48.2140604911312, 60.23828629524478, 58.465225927291385, 32.544801581290464, 25.431940209481027, 0.6824547184571144, 2.3244659410369013, 3.0565439741457663, 4.735290215861413, 5.021841420281318, 2.833313797750781, 0.4728957181496005, 0.29687212479691355, 1.738719159076291, 8.938331469412773, 13.099821094543705, 0.9122905339444838, 1.1718346875521446, 0.6936421762070348, 1.3967785719902286, 0.29468626144432253, 1.3984839449967108, 5.115573319696612, 16.476314029385968, 2.457927037631312, 1.263992368213592, 1.3923321976777048, 2.4563772111169757, 1.6400816003161094, 0.22189601895309266, 0.40878393416923864, 0.2062645924067305, 0.5430311901915459, 0.19912630770235293, 0.44598795233234284, 0.4215469283442344, 1.2388825801111039, 0.47675346114462425, 6.138037164365092, 39.508053948802335, 61.74297025126796, 64.88349829950641, 47.18144947482694, 24.938727655718406, 26.365099530066214, 23.514795495617776, 16.618490142206994, 16.135927804054752, 14.272388162151461, 14.567473953770055, 16.61079445192891, 20.930422275297104, 30.546477533155876, 39.47352532417544, 49.58641152228079, 65.61094107166414, 80.02442375306161, 88.07060134026312, 107.06797369064824, 91.12200921581638, 66.18030055876702, 42.98711784424321, 47.54776746995988, 14.671593269994183, 32.64779713846023, 55.94786836254982, 62.00882850154754, 39.97121526348976, 21.543829979435092, 31.357400109691007, 4.525673850890129, 1.4429588423621271, 0.4154276325097008, 0.8227924654080022, 0.5157143947097563, 0.6412020481882558, 0.8132838433788669, 1.1357930086312757, 0.5579919067602004, 0.6193895025118705, 1.2044428216834222, 8.184958398342133, 32.81498032231485, 70.79829523640295, 66.06009560246622, 58.451681983086374, 51.42355557410948, 73.03219487590175, 31.942523602516424, 0.17928919634751736, 0.20846328007117396, 0.1636996441670964, 0.097899233862277, 0.418980319293276, 0.3563942453793941, 0.1920925327126057, 0.17889410948320744, 0.26915549270568356, 0.1723609729519775, 0.2569202871452416, 0.14248719048355857, 0.17195376657670544, 0.18493508048836263, 0.15955772851744007, 0.20872129848407162, 0.2512148779726798, 0.20328389751094006], [0.10161589410516525, 0.08081746497942556, 0.06346113784539123, 0.1563528303297297, 0.036670522193514535, 0.13114452332017884, 0.07417929013289752, 0.014066803043768292, 0.17392815901867806, 0.0722085825738407, 0.03914600508587976, 0.11357744539817495, 0.09641755086880538, 0.1270714559922776, 0.06650179444301514, 0.34758116989847154, 0.202268754402476, 0.07942355267943875, 0.07418672118576304, 0.03769039589491102, 0.08797256531374109, 0.08820711845351804, 0.2223405950973111, 22.770272762544696, 63.29901372232745, 38.3670090090844, 40.695979056819795, 66.99772250267768, 66.2897268418343, 41.835839440745694, 26.238075533220847, 33.51171485839352, 27.94341814133429, 21.438337833650653, 19.324947134141002, 51.59291567340974, 62.094500910851266, 59.39494140686528, 51.70247531706288, 35.36216358984671, 12.768513194976315, 5.982470570072051, 1.4216450505679654, 6.052054887817753, 30.283308067629417, 27.66369627368066, 79.61587752065351, 50.39727526326334, 33.88579914646764, 21.212111211592152, 36.0310532200721, 45.7686548848306, 39.04199792492775, 39.697602487379505, 30.813463464859996, 47.04602572225755, 52.129641040678955, 37.9858369981089, 34.420986944629306, 26.422271997697894, 27.18271367011532, 20.745078517544655, 11.85892535794166, 12.96569956887153, 14.521829332074812, 17.483062897959066, 28.373274610888576, 28.102568311076013, 24.45572307032924, 32.92657175371724, 48.27031904651273, 44.15254031458209, 21.16797278004308, 7.653768475978606, 1.5454974434068127, 2.173857467789804, 1.1254038757854894, 1.0749749430725652, 0.152616941279942, 1.5183016898170596, 0.283936454403785, 1.5843955884056709, 6.955395369760453, 3.1536868647221596, 3.1118474323903365, 2.5851113613574737, 0.7061371928261173, 0.5591122950277021, 0.11571276226952193, 0.3491495663840925, 1.2558160650153316, 1.8263233356898831, 2.17681321886278, 0.2657075761066329, 3.598640782217826, 0.16834140154382876, 3.59217377439622, 11.740966939157056, 0.6345034366653812, 0.3796588034639436, 0.24162526512818955, 0.06712502995205503, 0.18095019754142533, 0.13343918647977615, 0.5945490709235591, 0.04540780859608804, 0.8037054767051052, 6.034194865534383, 29.57622043548092, 47.93570164711245, 51.24658607667493, 33.767394558075935, 17.888763450807144, 18.301861593800208, 13.76942067377029, 13.700781156939845, 8.427685941419295, 8.261068559462025, 5.756545480220549, 14.124580506355533, 21.8768568577305, 41.10960868097121, 55.275974196772424, 68.76702524000599, 79.59817978643602, 91.25476575666859, 96.49774305282101, 83.6229944229126, 87.19105689756333, 83.7882124993109, 82.38172115818148, 69.31911453124016, 48.12222603828677, 10.686835838902383, 31.740886319068174, 54.10837481098791, 41.41135661832748, 34.296832161564986, 52.12001162190592, 9.928762297476492, 0.48652414653089743, 0.632977879816486, 0.11350154140663725, 0.7816390801341303, 0.412570737422474, 0.38672020358424036, 0.4591321825019775, 0.7550709670589817, 0.6551450935582961, 0.8521887299514587, 5.405831654225627, 61.57526539218042, 46.81519423761676, 35.23461595658333, 28.59183692163037, 20.27497264646715, 24.0421110968436, 1.6436445833213869, 0.1756779804465271, 0.06869080641697492, 0.0854054200012357, 0.03546395669541052, 0.08522635460981438, 0.10844404343515636, 0.27185319472224484, 0.3936142594583573, 0.32513405827264635, 0.07264088598951217, 0.05039758439506254, 0.04152387688537279, 0.06543785919465366, 0.013983425864529227, 0.08979646744386804, 0.03484789176934189, 0.07435901435993372, 0.031100923172949307, 0.06754750445965799, 0.013653858669943387, 0.07600956611455449, 0.06551614571963588, 0.16057592065584275, 0.11940621004830446, 0.01996722181267556, 0.008732930235114069, 0.057273173719764724, 0.09649181543218513, 0.08486578766737254, 0.25055156840432075, 0.1627000986087707, 0.26551982327815027, 0.15430428057668671, 0.1480723391737669, 0.03871133062808264, 0.04615158804001347, 0.12500402983278036, 0.08869180696145182, 0.1189154924284066, 0.2375610920810892, 0.3389404335569951, 24.30177200225092, 82.87092701081308, 55.48624853934012, 54.865957075549716, 81.84809838571857, 83.6722593922769, 50.936365819746456, 37.25303626829578, 52.0451767213883, 34.0231958512337, 24.347659810896843, 18.857475134634203, 51.40111177198349, 69.08556092169978, 63.65560816180322, 55.58998346328736, 41.417820684371456, 17.140322269931918, 1.4594514283441729, 1.2863867729902267, 9.219026084869139, 52.40096707497874, 26.536809129099694, 59.33476832605178, 54.99398716034428, 63.46125079739479, 33.832913829434304, 32.618322487800356, 46.75819435427266, 23.852197777840402, 15.87297603007286, 10.15629408820983, 22.369673252105716, 22.85914582590903, 14.534437790993723, 13.036377737599036, 11.024976507309946, 20.759830551762736, 18.253904734888387, 12.999742800189605, 14.164258222426138, 13.64405191713764, 15.11021133392088, 27.097102057549264, 33.00137527527348, 27.789810280646048, 38.60410059652021, 45.989507859753026, 51.98614897266511, 36.74736822805097, 11.578514133730243, 0.9772797337462826, 1.608746520453884, 1.2225622106944363, 0.6305222309404804, 0.1588642350848644, 0.8316196981937656, 0.40878062466940573, 1.458072715228604, 3.7653037617283487, 2.224273652799668, 2.8957405253764126, 0.7850984267650113, 1.9104704332928506, 0.9864122372481131, 0.14050841601865907, 0.7299570727252191, 11.942957235920815, 2.516224244909902, 10.212636974550064, 2.1132946014404297, 6.089754258432697, 0.5968402866874972, 4.725740715380638, 7.70025787814971, 0.32824314950454625, 0.22761206142604354, 0.2377008878055119, 0.42400159662769693, 0.13887548428629676, 0.11580869179940033, 0.39140336035240086, 0.5734310299158096, 0.5585631632035779, 24.576610519040017, 35.99111172460741, 58.24118798778903, 60.661796369860255, 37.20923123821136, 16.268700034387653, 10.95579570339572, 10.13670479097674, 6.464162632342308, 9.256515118383593, 8.757357232032284, 9.307862866309382, 13.675523054215217, 18.358973264694214, 32.24123170298915, 50.64895806774017, 64.31204818910169, 80.28472008243685, 90.9998901428715, 97.71818853193714, 88.6462091630505, 86.83514102812737, 75.38451871564313, 67.14354838094404, 44.73115267292146, 22.316809508108324, 6.23797768546689, 45.67577708152033, 60.30639433091687, 36.51894507869598, 26.468151961603475, 41.68117254011093, 16.748638306894613, 1.6053037826092014, 1.5721218792661544, 1.0818357813742854, 2.547204350271533, 0.23766449862910857, 1.0885264868697813, 0.12594545230029092, 1.3402420186227368, 0.3643240214836213, 0.728826510810083, 8.50394662349455, 45.11271299854402, 50.757733237358835, 52.5350768335404, 37.38346684363581, 40.001409669076246, 27.99383040397398, 0.7599781585797187, 0.23518186813640982, 0.06706852330676011, 0.044364312573546366, 0.0512751342818862, 0.08694482005892262, 0.15319345308648002, 0.0515433952903315, 0.27421565666314096, 0.1016463461001554, 0.0865882137910493, 0.060526312464067054, 0.10592821069181928, 0.1581537498221282, 0.05756350955174816, 0.06360913454104336, 0.09601538535207511, 0.03905223975438745, 0.04405056892503654, 0.21404412334724782, 0.2226949260840493, 0.17408768916803022, 0.4133603595677884, 0.2703069534993941, 0.2968456794417674, 0.17466964019883066, 0.10553009778020844, 0.2935906024950166, 0.2027119822319477, 0.2690850739036837, 0.4248980727166899, 0.21473135018060285, 0.34577436685081453, 0.2583512934225221, 0.48440235877229326, 0.32596143323086924, 0.20215411700548666, 0.33163946242101733, 0.1607931831911687, 0.22538582523984296, 0.29205183829030684, 0.3161183678575101, 44.03186859623079, 110.4786471397646, 72.68728517716931, 73.53549772693266, 96.33374875591647, 109.37101687154463, 83.38053703308105, 43.803331698140795, 62.197835753040934, 48.55518118027718, 38.04762217306322, 29.82426328043784, 73.13838128120669, 84.36016467309769, 84.84610711374592, 70.93507612905195, 68.75531304267146, 44.17265030645555, 10.254025824608343, 2.0417847676623255, 10.616294953130907, 44.75442017278364, 38.81433179301601, 98.83931959829023, 72.76337915851225, 55.00658189096759, 33.25929857069446, 43.439335746149865, 56.40823694967455, 44.64857501368369, 45.595556766756125, 37.974799448444, 55.24021002554125, 60.1696095158977, 44.80883521418418, 43.324982966146166, 36.69735408598377, 35.53883890951834, 27.915145697132235, 20.882169277437274, 27.0765527602165, 23.063093385388775, 20.23545084461089, 35.53890951218144, 44.50997021890456, 37.55500778075188, 45.8382651882787, 58.46911691850232, 50.29126928698633, 48.132608552132886, 23.240749297603486, 2.3600918487195046, 2.2319019273404153, 2.036917351426617, 1.0717413165876943, 0.2075969878463976, 3.1028747654730275, 1.5939206966469366, 3.85291088011957, 16.822920153217932, 10.144670144204172, 5.395129957506734, 2.1590125224282666, 1.61508776728184, 0.9040667945819517, 0.5632367898379603, 0.4576857165703851, 9.126788608489498, 5.412635005289509, 6.41702849057413, 0.44934390773696287, 4.8391580100982425, 0.2630729997350324, 10.272253078799094, 37.9626283337993, 0.9364440604563683, 0.5455594029157393, 0.5099885616331331, 0.538778605480348, 0.5294025473056302, 0.2808572099574151, 0.6967344747916345, 0.8488051953815645, 0.38692621994883786, 21.536244115521832, 38.84644031524658, 57.925052796640706, 55.506613485274784, 44.39947705115042, 21.689406787195516, 19.0142346197559, 17.456196623463786, 15.91367454298081, 13.913215744879938, 11.789959303794369, 13.762830111288256, 17.92860688701753, 25.070646770538826, 45.39539429449266, 61.99066008290937, 70.686076225773, 86.17870100082891, 94.34466777309295, 103.05112146562146, 91.75540139598232, 92.60576340460008, 90.34198314912858, 91.11583540516516, 78.98195189814415, 60.62714615175801, 12.546012824581517, 37.929496072953754, 64.24886665036603, 49.1872868230266, 47.42678980673514, 66.55765610356485, 13.964852767605937, 1.0044716262528974, 1.903313946339392, 0.5078584388379128, 1.7272247758603867, 0.38692882464778044, 1.1830879675765191, 0.5877302755271235, 1.6561818267068558, 0.8307616797185714, 1.085960889054883, 9.176036907780556, 82.38820091370614, 68.96838403517201, 63.13911437988282, 51.774148787221606, 60.847622579143895, 54.28850966115152, 3.131093277085212, 0.2138547310906072, 0.10014202520852128, 0.21096817307895233, 0.27424654532824794, 0.1302823679701936, 0.2867644220109909, 0.5353303518026106, 0.40171193139206984, 0.49687800868864984, 0.16789052815687272, 0.10180698707699777, 0.2222430874263087, 0.339047011709021, 0.1954762051783262, 0.12608171635938267, 0.3261945691079863, 0.2034571712776538, 0.18371747566326974], [0.008942635313066985, 0.05680274210810181, 0.041036319378162586, 0.0760368618272966, 0.0449966836810833, 0.011657164450885068, 0.05235608051260633, 0.0786890045950009, 0.06418037949310196, 0.041862100873503, 0.0412318135251201, 0.0036738285064441905, 0.08158392062590969, 0.119902849527857, 0.1655145524249923, 0.1746243337589887, 0.16704493562781042, 0.13623870158147428, 0.12330663180158985, 0.1207789017127887, 0.030617956447625355, 0.16500452172852334, 0.11463734336317548, 1.7108145596519595, 40.04913314696282, 45.81708831171836, 39.16783540479599, 60.94305776780652, 60.73816099474507, 48.511654638474994, 26.773249603086903, 30.035080871274396, 7.7985034450407955, 4.795562826818036, 3.927835750003015, 12.526532373120709, 18.57327392024379, 17.70849916242784, 17.597558844474054, 3.219921478340703, 7.500207193436162, 2.3412639815961165, 0.654397759466402, 33.53095408408873, 24.123916049157422, 46.58882248786188, 83.5927451041437, 47.076867318922474, 31.77594642485342, 32.993255969016786, 38.02886539889921, 52.500414848327644, 82.36385868441674, 85.69294683394894, 101.97794529699512, 78.20325159257459, 72.3007748203893, 73.83071884032219, 69.29602746040591, 68.41395701131513, 45.19625948321435, 27.417771508616788, 22.049609807229814, 21.738681562485237, 19.92848615492544, 23.578726207056356, 28.77956940281776, 32.29953773560063, 21.244360939148937, 24.540156010658514, 47.01996549483269, 50.44826607550345, 29.949839922689623, 10.794271519107204, 0.8907956389650222, 1.3321109452555258, 2.14005301075597, 1.0814946577433617, 0.5034026876091957, 0.5313443044020284, 0.08611339249558027, 0.942935950813755, 0.3610371672097714, 1.635099209604725, 1.1281888811819016, 2.00510251666269, 2.2644031768844974, 0.9380459196625218, 0.3029408588284447, 1.9652019609366695, 7.398984547584289, 0.8823624205204749, 6.112621676537299, 1.949516157469442, 2.75694279901443, 1.550803797379617, 2.60229992289697, 1.3051165808593075, 0.0928504846148914, 0.048979149620619514, 0.1215476786056834, 0.1702367796772911, 0.23921380420365643, 0.26667876109000177, 1.0252524047128617, 0.25032374917739825, 2.216476471193375, 11.048626438263925, 25.081333268073298, 43.033033109480336, 50.239325338794345, 35.02268245143276, 12.778249498336548, 15.562008561626559, 12.126936008853297, 12.552890700678672, 4.663098012247394, 6.7288353462373065, 11.90087510693458, 30.464996176381266, 50.18272945957799, 63.73593045819191, 68.19244507820376, 70.81028199964955, 80.08059993866952, 78.3821273619129, 74.56041305295884, 72.49603040756719, 71.50163896622198, 75.73836357362809, 64.4464756596473, 72.15044606116511, 75.83047651475476, 59.31458380914504, 21.302457124956195, 44.46184273689024, 40.21405312322801, 25.47567071453218, 47.119825117049686, 23.763593396832867, 0.9630376689376371, 0.8604254008781526, 1.0704666688557596, 0.21419750947144725, 1.2762932887961789, 0.9345801991801109, 1.5206418739211176, 1.171166536308104, 0.4263763159753815, 0.2859985485913292, 3.5371985695054455, 40.9691172261392, 37.5797147904673, 25.974333401649233, 15.720293848745285, 26.02209414205244, 4.041436415526175, 0.18893637303863803, 0.07021967276570297, 0.08092480921937574, 0.05665459219486483, 0.15974692159122036, 0.0391594001332358, 0.04607787889037882, 0.03239406618259607, 0.07223944059543072, 0.15843141072940442, 0.07036526777571248, 0.04920747446557207, 0.09110496094029757, 0.06761443756160236, 0.004627000608090913, 0.10922298631480626, 0.02609069474161633, 0.03559685379807507, 0.15713923490576207, 0.011793146015054757, 0.08465769520450024, 0.14472358499563512, 0.06721696050296869, 0.05647071194083941, 0.07192005087891895, 0.05158592083100831, 0.03847535256476652, 0.11950997665764825, 0.05751919136532853, 0.09035428670505363, 0.07054956554765664, 0.12897433412651862, 0.25700535354835374, 0.14413648585398353, 0.12092383788718332, 0.190844391622851, 0.09470659308135511, 0.08879449338682237, 0.04351883878811233, 0.1099710481902284, 0.4599293429524668, 0.09841148621372639, 1.9418339503388253, 49.86265620877666, 65.71171068376111, 53.11961981558031, 79.23378375268753, 78.79440769072502, 59.95618943245181, 27.557782473102694, 34.58154524526289, 9.363341850619163, 2.9900004738761536, 2.950445822169704, 12.34893725764367, 18.859544184900102, 19.603390309118456, 21.54281604674555, 10.834690563140377, 2.4611897141702714, 2.484941871896867, 2.1621641468617225, 52.130354912050315, 29.927702065437074, 40.98567747300671, 77.64547486459055, 74.41630517282795, 55.51077512002761, 26.14352091666191, 20.722456247575824, 26.31310262987691, 49.67266836474019, 60.862853142523, 77.5244697447746, 72.27216505235242, 66.98047976340017, 57.50621034253029, 55.88370623127107, 51.023799373257546, 33.02484673838462, 26.54664251112169, 22.888700885157434, 22.447581329653342, 20.61833889253678, 23.61110341164374, 33.25512516883112, 32.190642933691706, 21.683662476078158, 31.58994959246728, 46.0297356882403, 51.24469549425187, 52.87839797235305, 36.08790013097948, 2.99821931027597, 2.0259846025897614, 2.332408740635841, 1.8835439749302405, 0.6266616993854124, 0.23493937066485807, 0.12810977326045114, 0.39894469923550085, 0.3897394480243806, 2.925068332302955, 1.2559426840274566, 0.8621587207721126, 1.4321934071279343, 1.034631036943005, 0.5939374876118476, 1.1690325217862283, 13.130402834184709, 6.795349428730627, 17.582071365848666, 3.4403991314672657, 3.34964725279039, 2.148708946281864, 3.8736119241483755, 1.9429014478960347, 0.014959306966873908, 0.5884430437318741, 0.11036886232754878, 0.11551383221822402, 0.008217826121366553, 0.4861623998130522, 0.26775842412344875, 0.2724351151095283, 1.5674426142246494, 29.88267521704397, 35.788635053942286, 62.10090614134266, 53.06309453902706, 35.83479742850027, 12.82488157672267, 10.816463308949626, 6.552498330993037, 6.488439652227587, 8.449182491148672, 9.629869845605667, 11.932603159258443, 21.553114229632964, 44.06332208264259, 63.35929270713561, 72.15825157780802, 73.58557854929279, 81.43209964998307, 85.80340077800136, 76.49964855563256, 74.37872886657715, 70.52181520769673, 69.717297861653, 60.948792272998446, 67.77967053074991, 70.1757287979126, 42.344115857155096, 16.10064510376223, 53.39521338862758, 39.464888265056, 29.30147997794613, 48.806871829494355, 26.32465401003438, 4.0432811552478425, 3.1422063323759266, 4.064193516969681, 4.144913688782723, 1.985461738321089, 1.0176338748105112, 1.258665789519587, 0.6718091606613129, 0.19006707284960056, 0.46679710668902247, 6.619327183692686, 39.689098788845925, 47.956360770810036, 39.36137299383841, 29.38275148791652, 34.749152045096125, 2.9882403102613266, 0.09514528567031508, 0.043537822446876, 0.053063497593205784, 0.07343464500961766, 0.1434512661709901, 0.04460039022829264, 0.024794937456927957, 0.2146846801042557, 0.06403999771141718, 0.2636455738496396, 0.060015151787909775, 0.07672519948814185, 0.10294822825779838, 0.05079627953349583, 0.08038484746770513, 0.05758983616326606, 0.049600427775012876, 0.06961601080312844, 0.07766051623489588, 0.11761778544995094, 0.17464348595709572, 0.28042443156723057, 0.17482731641540605, 0.1520060934126377, 0.2614612120293802, 0.2006292036704479, 0.12410544700199559, 0.24700905526837996, 0.20254595565699762, 0.2261719540242226, 0.32518207666374027, 0.3876925530212541, 0.3259717600960886, 0.24824910646965428, 0.4054926365854279, 0.27668573863564, 0.28888832417226606, 0.195465219477492, 0.30444806021067405, 0.21960114128887656, 0.4271366429184714, 0.2834780580334125, 2.957451910741868, 79.92953377385294, 89.67414471410936, 68.82356228366976, 95.85179928810366, 99.80779201753678, 83.63047046046104, 39.371735895833666, 42.245903630410474, 15.420613981062367, 6.808061830459103, 5.642327531691521, 22.209807249807543, 35.04357299497051, 34.13263390141149, 36.139483221115604, 37.927907513033965, 15.861955150481194, 3.757351646500249, 1.742949190158998, 48.0098658223306, 34.87155745106359, 65.9651428653348, 104.22791096471973, 70.35373380107265, 46.37157417112782, 40.10894144735029, 47.122162849672385, 58.84947307648198, 91.95391255040323, 90.44454528439431, 107.29430229433122, 84.96990496112456, 77.59936348084481, 77.6796857772335, 81.33284799514279, 82.45916443486368, 55.68889387192265, 31.948628771689634, 32.24651513561126, 33.3832807694712, 28.53608827437124, 28.375882987053167, 39.64095169498075, 42.835941853061804, 32.649872072281376, 37.01110055369716, 51.140325146336714, 57.17611935830886, 59.30606442113077, 36.14586883975614, 4.126024044329121, 1.163412255625571, 2.575165946637431, 1.3282177477113664, 1.0381870332264131, 0.9066629133397534, 0.34770021996190476, 1.2562553704746309, 0.7879867008136165, 11.77470128382406, 3.5284136860601367, 1.9637403877512103, 5.054089186653014, 2.2780861200824862, 1.3648046360861872, 6.389912655276637, 31.341538044714163, 4.297881222540333, 14.721495624511475, 2.1504115000847848, 6.311188234436897, 7.523269749456837, 15.802011528322774, 9.391334825946439, 0.3810434001347711, 0.4006600620285158, 0.2556267017198186, 0.27305681078184035, 0.3136964268501728, 0.8663378836166474, 0.9282027930021287, 0.41716674402836834, 1.9929865603485417, 31.39999704976236, 38.43319900574223, 59.95677386560748, 54.47934081477504, 38.22808650232131, 17.39921635197055, 16.397490078403106, 18.74023941255385, 16.198322907570873, 9.132287771471086, 8.440344410557902, 16.651800870895386, 36.273922458771736, 61.74917544088056, 69.33918922178208, 70.86903910483085, 74.81976801349272, 81.63744357324417, 83.28064995427286, 72.52191805070447, 73.8147783279419, 69.97314622325283, 71.6673355717813, 57.09249442623508, 66.82583639698645, 79.01543324993503, 70.00902806558918, 22.024698834265433, 49.47712644453972, 50.500810146331794, 40.1508362831608, 67.12927095351681, 47.01202661760392, 2.6500623793371263, 5.46281143542259, 7.062821734336115, 2.1585134008238396, 1.8976797067349958, 1.4971923515681298, 1.3524676787276424, 1.2646433590881287, 0.3740825720371739, 0.5650383222006983, 10.23332061306123, 75.16258316655313, 61.52940896249587, 52.35985279083253, 44.607966715289706, 56.488747519831506, 8.285814792879167, 0.4266629554331303, 0.1622522436082363, 0.2443671550962233, 0.1379116690687595, 0.3879959851263031, 0.2399323027460806, 0.15738487333780335, 0.3257564587458488, 0.173246800418823, 0.40462367837467506, 0.21410040016616547, 0.14590642475072416, 0.24908696151068135, 0.1798664435984627, 0.18862288986002246, 0.23753853845259837, 0.13030774080224578, 0.15315793725031038, 0.22823366516780472], [0.023621631666056575, 0.04680484653480592, 0.18768650059017444, 0.08235422969465295, 0.14473141441422124, 0.08366263892141082, 0.09244491766777732, 0.0810441044309447, 0.04189329980421932, 0.03594824683762366, 0.06310597182281556, 0.028623289488736662, 0.07557065136009648, 0.03943872345130771, 0.05564026880047976, 0.0413142484162123, 0.04417752884628792, 0.10263308266838712, 0.047151129767899556, 0.0942637789393625, 0.1396767356463017, 0.0560752343716881, 0.09021723357539985, 0.42510041185925085, 4.146519409072015, 34.94292497634888, 42.25812181349724, 45.95211590490034, 59.50368519752257, 59.190707514362956, 52.82245712895548, 50.20050564119893, 2.4377116320594667, 0.505764015739964, 0.7225232006561372, 2.1558023075903616, 3.473000401450742, 2.5602707459080607, 1.7351430606457496, 0.2890363323592371, 0.7369550714089025, 0.36447978248038604, 3.1884991257421436, 29.681073234927272, 31.50473413928863, 73.58418218551144, 56.34277651386877, 28.98546834145823, 28.39273545049852, 65.97170891300325, 96.88005647351666, 116.0099970909857, 93.50302911573841, 86.82750809577205, 75.58777593797254, 74.77378999033283, 66.56765814750426, 69.6815650693832, 70.95977137165686, 74.25402887405889, 78.5930645850397, 56.90859017833587, 33.977496316356046, 19.222994927437075, 19.817826286438976, 19.176783523251935, 24.9528403435984, 28.067070861016553, 28.592199740871308, 27.04472076508307, 44.80337527490432, 53.071398196681855, 47.000824328391786, 19.437740772001206, 7.025154723275093, 0.10984496543965033, 0.634241802317481, 0.3977480698977748, 0.16936832708456825, 0.5982948118640531, 0.10593520507456795, 0.5222341093805529, 0.1653079844770893, 0.4437990859150887, 2.2383431946077654, 2.309431496166414, 2.361670357565726, 0.5499919263585922, 0.23043681146396747, 3.2482120635048037, 12.89975864271964, 3.2056026208785275, 18.79932599682962, 18.853844981039725, 4.451504772709263, 1.4540041141933011, 0.4109131683024668, 1.2459716513272256, 1.0185748146426294, 0.2104199452385787, 0.10422061603035658, 0.19895154772506607, 0.07746901723646349, 0.08267888243520453, 0.47060327664498364, 0.18074303204494138, 1.4907163958395682, 16.346597325417303, 29.596059783812496, 41.698187781918435, 55.1611428876077, 32.333407402038574, 14.40371499907586, 16.227764218084275, 11.264296981596178, 8.006656765937805, 6.402606916043067, 14.643596372296734, 33.704813141976636, 58.232460714155636, 67.95036423590876, 70.26483720348728, 70.85633847021288, 79.00274830479776, 77.20862480901903, 78.75963195677727, 73.90037228984218, 76.59569955641224, 77.61696707817816, 73.24253589876237, 68.91595763544883, 61.38320653669296, 63.98391838996642, 71.51646552547332, 61.52254873706449, 34.01158955789382, 59.60028533012637, 22.529727528172156, 38.29844205610214, 39.87190869546706, 2.6970182984106006, 0.8451803737590391, 2.223254817147409, 6.193977027170121, 0.41924716303906134, 0.4086407983014661, 1.2428384130039525, 0.7849462510597321, 0.7278517405352285, 0.28522749641729944, 3.806234184772738, 14.20283865544104, 21.855836875977058, 15.900939587623844, 25.26338811843626, 8.446324063885598, 0.1884970062923047, 0.11399559150900572, 0.06070342816172108, 0.053516650091736555, 0.0222848178142862, 0.035054892556922096, 0.04605681530290073, 0.051386412383327564, 0.06402063866957061, 0.12646371078106666, 0.08147276892897584, 0.1003034629168049, 0.07753084819283217, 0.02061441097588789, 0.06502766507647692, 0.026064218742953196, 0.07549747464156921, 0.014653240476975278, 0.05735516811030046, 0.0680227700861231, 0.10412418088244815, 0.060807474393157236, 0.040901690916789156, 0.07218076592131008, 0.11286309139142114, 0.1079280908790327, 0.15296183406345307, 0.20418199770633252, 0.01584481746484075, 0.043567290018883445, 0.13661321132413803, 0.1635767636640418, 0.07532058493985284, 0.008145000845674545, 0.0752148035192682, 0.00542986793481114, 0.05032834919890569, 0.011087938140506947, 0.07889515885542478, 0.10432314923814229, 0.027521212637845068, 0.04483747911909896, 0.23847322700725448, 0.5123804719938386, 6.531031689336223, 50.95424398299187, 58.29075497965659, 64.07385833801763, 80.35909606564431, 68.76528370764949, 47.57927194718392, 52.61714458465577, 2.8695474276619577, 0.30567475083854895, 0.8092030462238097, 0.7324355203778513, 2.1292304560061424, 1.2884821766807188, 1.1268046522332777, 1.169524901816922, 1.1312194024362872, 0.5814626957139661, 9.565944037129803, 47.403510539762436, 26.78574235208573, 60.09860284866826, 65.33772837731146, 56.53409011902348, 20.848495729507942, 34.285386685402166, 73.8269219859954, 112.20520388695502, 95.3344072834138, 86.14988726954307, 79.44599966849051, 84.27876764728178, 74.28868693690147, 74.77659056263586, 69.41322788115471, 78.62177633470105, 79.15528928079914, 57.69498225181334, 27.565540921303537, 22.922584279890984, 22.33604677261845, 19.20531092151519, 22.206890967584428, 30.992068590656405, 27.439993696828044, 34.49806544088548, 49.731849085900095, 51.98108519277265, 62.4240819869503, 38.51248579640543, 9.60817031321987, 0.14850452001537048, 0.6658268107041236, 0.7021724120263131, 0.18590234310155918, 0.37868645402692985, 0.09920525289471112, 0.7666705188251312, 0.16649977213913397, 0.44271546986795246, 1.712853088974953, 1.735329128080799, 5.1554633340527936, 0.8010766306711782, 0.6652938586569602, 7.2070933734217, 14.952681103060323, 9.090809687491387, 19.591270185286, 9.633161694772783, 0.8911372528922175, 0.6914089992642404, 0.11000366055316503, 1.1974831886829869, 0.7283220572337028, 0.7616645938927128, 0.3141358242400231, 0.43835336522709945, 0.12736097594062168, 0.34430807456374174, 0.8169466629624368, 0.19050768065837123, 2.6571898162364964, 22.996309149649836, 43.198761094001036, 57.63123589177286, 56.765062808990486, 32.53071242763151, 13.549273725478882, 12.26564278525691, 9.092990525307195, 10.264466193414505, 13.382685761297903, 12.428891831828702, 23.239719675433253, 51.42511667743806, 74.4767959656254, 72.25087442705708, 72.3816619380828, 82.33873198109289, 87.11187993326496, 84.9643430402202, 78.6372696968817, 78.25467386553365, 77.1082592010498, 73.70943130985384, 67.41756516118204, 61.713642689489554, 60.908839010423236, 71.86352468306019, 58.98760326447026, 36.697711021669456, 62.24382162094117, 21.464998183711884, 43.39047478091332, 38.04184059942923, 4.648727918824842, 2.563618979146404, 1.6740365783053062, 7.379607548636775, 2.8208634593794426, 2.968783638169689, 1.8220162055184765, 0.5531952770486955, 0.2537399190928667, 1.6089265817596068, 10.03140680251583, 26.39060081974153, 32.50679773669089, 29.584645686611054, 41.05857864502938, 6.320051320137517, 0.1038523805477927, 0.053960594213417465, 0.06644340322142647, 0.021921113741794424, 0.05165368513835054, 0.08627150538227252, 0.05106973844850737, 0.007013041777686487, 0.08564522084329398, 0.11009759059356106, 0.03821903486706076, 0.23224323146766235, 0.03879260489596956, 0.047364565694043716, 0.01350841496229893, 0.1076985402934013, 0.1175108089322044, 0.015195119363676398, 0.029199291846805045, 0.04196172294717643, 0.26751030356653277, 0.19451004573174063, 0.30585358640359295, 0.12907079991794404, 0.3807810916294975, 0.3454313126783217, 0.3289758053518111, 0.30675444451551287, 0.10798678087491183, 0.10814644892009036, 0.2756514892943444, 0.2338224604365326, 0.20504876490562193, 0.19887676222189782, 0.23248032035846866, 0.09689151414579923, 0.2657559928634475, 0.30240055233720814, 0.1900903619224987, 0.22425022246616505, 0.3466079011559487, 0.2701850535888826, 0.34763206878016073, 1.1244930278870369, 11.493055493600908, 82.3502637493995, 76.54794077719413, 79.4479137851346, 94.9608721271638, 87.35680841630506, 74.14806212148359, 73.58764171600342, 4.0518721265177575, 0.5257921894231151, 0.8089628010507554, 3.595432528565007, 6.697904515650965, 4.936962310344943, 4.537686599839119, 1.71495572453545, 0.9038293073254248, 0.45898641129174544, 8.681280901355128, 44.66482931567777, 44.93893631042973, 88.01402507289764, 70.66904529448479, 40.9183225324077, 32.93422037555326, 85.60153991945329, 128.89536749932074, 143.45747270891744, 104.84852406286426, 82.48400088279479, 70.15737995024651, 75.82176100823187, 68.16468254212411, 70.49881442900627, 71.64482901173254, 77.76467569412725, 86.56201854828866, 66.5772601096861, 38.723348494498964, 21.764749634650446, 22.38373494917347, 19.57831459660684, 25.46368395128558, 35.628574894320586, 42.25316001522926, 42.22887269912228, 59.79031239786456, 56.59971921674667, 66.95495297831874, 45.148877251532774, 8.306909299665882, 0.1925320526765239, 0.8418694030373328, 0.7712900290085424, 0.17544685171977167, 0.9260734362948326, 0.2393583037079342, 0.8632459527542515, 0.30624496540234936, 0.5477041426685549, 3.683079851250495, 2.8705942102016944, 5.957772385689521, 3.5267165255162025, 0.7650200590010613, 11.131235476463072, 27.449134780514626, 8.794507961119375, 29.760797369864683, 35.76388882052514, 20.357169835798203, 7.543540558507366, 0.3021699905155167, 3.6742550086590553, 1.9035237931436109, 1.3663037169364192, 0.2245745534497884, 0.9454663085841364, 0.2651280459136732, 0.3155327702481901, 1.2514015599604578, 0.791330460098482, 2.0059155504549704, 34.95256616223243, 41.110357853674124, 57.196915764962476, 59.05147514035625, 35.826136835159794, 19.035062405370898, 19.543733019982618, 17.882385676906956, 13.73999014977486, 13.174742287205113, 16.50734978337442, 37.165453664718136, 64.87953278326219, 70.59919572645619, 71.14773919505458, 76.30613450081118, 87.40185291536393, 83.11709496282762, 86.47323962180846, 78.9988180898851, 78.36900311131632, 77.48843885237171, 71.19462720809445, 66.20130877340993, 55.357873285970385, 56.86468316662697, 67.908645906756, 79.27434890500962, 45.166492615976644, 70.77433739939045, 31.822365714657693, 53.83851182076239, 66.7838042782199, 11.170900444830618, 2.731936953721508, 6.518264864721607, 12.347731128815683, 1.9778617783900232, 2.1113518024644544, 1.84176288785473, 1.0336023953653153, 0.9832256179182761, 1.77454988802633, 25.72623956588007, 51.45427165492889, 47.532211349856475, 43.785986977238814, 53.69305464529223, 15.372498266158567, 0.20276655833567345, 0.18948113816159387, 0.2581367888037236, 0.12415049297194328, 0.2343102132961635, 0.28435559642891733, 0.13560280263904603, 0.1751618976554563, 0.3050790408686284, 0.217531907161878, 0.14956705332283052, 0.4351536917590326, 0.37800858878800947, 0.28313622960159857, 0.20056390233578222, 0.2991939840778228, 0.16341711094062175, 0.1779130266438569, 0.2322619853000487, 0.11142344364235479], [0.04302076672414138, 0.03613938194429202, 0.07337294428819612, 0.013557661966901394, 0.011615214433761374, 0.08886697296533855, 0.060668666922156854, 0.07161806668004683, 0.0351134714700522, 0.07510087858404844, 0.08912034122453583, 0.049807194905776175, 0.028037674642438372, 0.020932258940452052, 0.030473736565439936, 0.17259631516231647, 0.04405407377729013, 0.10269258471746599, 0.06498635761559972, 0.062019042445406805, 0.1921480128000821, 0.07740546258226519, 0.05521530833756251, 0.09330287485593751, 0.6641216215587432, 9.671454814172561, 48.36663284609395, 38.13490667650777, 51.23819220450617, 60.751559811253706, 53.49590847569128, 29.381625767677065, 1.1101360498897492, 0.05482479118772092, 0.43013272085978144, 0.5504533564371448, 0.7689613668668656, 0.5474164000441951, 0.04573109386969478, 0.4962011240422726, 0.814799962024535, 0.9806804899727145, 11.112048222172646, 48.02438643670852, 41.02497177739298, 62.464470632614635, 43.43909255919918, 27.915202571499734, 79.90083771367227, 101.0084609062441, 94.30882515445833, 82.04101624027376, 78.6000777829078, 85.8193334456413, 87.77478402660739, 79.31252141152659, 68.84246810790032, 71.45927736836096, 79.63398318136893, 78.73091236237558, 81.05126104047223, 76.60286964908724, 72.5807692927699, 38.83592836318478, 22.58947895419213, 22.408079139647946, 27.168546069052915, 27.388708706825014, 25.0619508758668, 24.124931943032053, 44.85214994799706, 51.579822801774554, 53.39486037531207, 21.39119682773467, 8.619939934822822, 1.0458161657856357, 0.8464895260910835, 0.06740781598754468, 0.3983838309443766, 1.3310668593452823, 1.1604880060880416, 1.3846801437677876, 1.2489020295681492, 0.3741365352705602, 0.05957991425548831, 0.7816537277352426, 1.0522224994436389, 0.36593507374486617, 0.6785778232639836, 3.152019367102654, 6.206603136754805, 15.695671169988572, 16.17051918660441, 0.8620558198421233, 0.7449461651905891, 0.9249886557940514, 1.3799502556362462, 0.2207423671479187, 0.002684554990170704, 2.4561381916846, 0.31747789813145516, 0.05142053776991464, 0.2943551888869655, 0.4359324354558222, 0.4023798068444575, 0.18380548384401107, 3.523837260661587, 10.078447787992417, 27.55115955106674, 40.51686794527116, 57.56370052214592, 32.42438677818545, 17.596366443941672, 17.559684438090173, 8.03302784119883, 8.550932695788722, 17.75776020942196, 37.14013868762601, 62.70787331365771, 72.87234260189918, 64.89901519590809, 71.26457875774753, 73.45030384678995, 73.56019296953755, 69.40077827822778, 70.38151987137334, 71.48431777954102, 70.03504122457197, 70.55995633525234, 67.549678433326, 66.87572110083796, 66.82419684625441, 75.90689997519218, 65.12994081743302, 76.67242111698275, 38.233656267966, 46.14410023535452, 47.21260093873548, 22.173758706738873, 40.77937649142358, 14.156653727254561, 0.7818079871996757, 1.85786348196768, 9.346721787606517, 3.057400521732146, 0.46794329679781393, 0.7877763024260922, 0.4041965996786472, 0.12156570465454172, 2.585022862880461, 1.3331913130898632, 16.08011051531761, 15.558578448910868, 30.03471805203346, 17.5523554894232, 0.9318868178994426, 0.03716779369560461, 0.09507001753175452, 0.23477145951361428, 0.06976588824463469, 0.008405700566307192, 0.042462154561954166, 0.0632078308732279, 0.01764780443702494, 0.03233349161042321, 0.0820177868609467, 0.05091415748240487, 0.088599776819108, 0.17113763778921098, 0.03151647607615638, 0.04293891022943201, 0.07276051061888857, 0.03835891869159476, 0.12005400633619678, 0.07662851153121841, 0.02976366882062247, 0.040421361449144544, 0.04242827049306324, 0.06921695560337075, 0.05122593994582853, 0.05606606429923446, 0.07916604754545035, 0.040532788937731136, 0.07787510512336608, 0.0611895032887978, 0.026495367281078815, 0.055642207002928185, 0.043556549466185035, 0.0900526932110229, 0.0443311371359854, 0.06269097050291396, 0.08375862973832315, 0.05641569916699683, 0.08412791476134332, 0.0855562933570435, 0.08290307806624521, 0.1039580470551887, 0.07626153243285033, 0.12943319014964566, 0.03622629461930164, 0.6331925070093525, 21.018936441790675, 68.75664664853004, 55.34238776853008, 75.18451706055673, 68.0504866569273, 52.210669363698656, 45.527829200990745, 1.45429277612317, 0.10682722253184165, 0.2374572565238322, 0.3442286159242353, 0.6940550669547051, 0.45994518565074094, 0.1324464131387011, 0.7910740964355008, 0.32844266944354583, 0.4085603897129336, 25.464925381445116, 45.314856267744496, 36.07068484829318, 62.023831567456654, 66.54651657227548, 24.50541557804231, 44.13548192670269, 99.05905862008372, 105.06625483112951, 91.59775349401659, 78.2788670447565, 86.40582976802703, 93.64212420678909, 87.0953667548395, 73.12400971689533, 74.17484406502017, 79.80754021675357, 85.34562095519036, 83.3028035010061, 82.4798902388542, 71.2351688261955, 30.628662955376413, 15.785644458186244, 21.190804896816132, 21.362789061761674, 25.70573929817446, 25.86749588289569, 36.96017249937981, 50.25929804771177, 53.97525348970967, 67.966963706478, 27.871970207460468, 10.681761272491949, 1.5925161204030438, 0.45531111979676836, 0.29250039809173156, 0.5163316164285906, 2.539319160484499, 3.542905127809894, 1.2964770702585098, 0.32573191328875484, 0.2693353701503046, 0.08362066496403948, 0.49176519916903594, 1.684377049246142, 0.14074694515476305, 1.4460915903891287, 14.557368947613625, 8.582484241454832, 16.352121983805013, 9.051922329010504, 3.634498109740596, 1.1152321893361308, 1.133538626374737, 0.6808034006145693, 0.20396750840929248, 0.16422303543696481, 0.2642689549153851, 0.326503670263675, 0.09798056941719786, 0.0721747751137422, 0.33342221030785196, 0.3858014190148923, 0.09610241294027337, 2.295104058519487, 10.221112235899895, 36.2273286234948, 51.60855024091659, 57.408178544813595, 33.97287184192289, 15.062483933664138, 9.478302597999573, 13.695449675283125, 16.185181986901068, 16.243327202335482, 19.074301796574748, 61.94737672805787, 76.98306498988983, 65.99150119289276, 70.93899065448393, 78.07099711510443, 79.75993833234234, 73.94689944482619, 73.47905482015302, 74.61651863590365, 71.17694516335764, 70.98522755407518, 68.33214421426096, 69.27387391367267, 64.43125686337872, 75.89463864603351, 65.26884371234526, 79.00968305526241, 41.931074588529526, 45.5650407268155, 52.87147498899891, 25.315263425150228, 47.69780597379131, 22.625347068232877, 3.357557937983544, 1.126311291610041, 8.236402734633415, 3.708369823232774, 1.8215252963765975, 1.7259422833881073, 0.254919863035602, 0.7567016311710881, 6.219399379145715, 17.06391057660503, 30.774302521059592, 28.126394748687748, 46.37374716420328, 20.55755196079131, 0.5492414053409331, 0.01147496192941382, 0.04854763527551005, 0.03509941758708127, 0.028783666165245157, 0.062480958989791335, 0.08476089490878005, 0.07144879955317705, 0.09868543159456984, 0.11510982809047546, 0.14675586304116636, 0.010380940493046036, 0.07099464730990511, 0.07371432072813473, 0.026357297169705553, 0.04898902066352387, 0.015330125123352535, 0.024962484716407718, 0.052155323341609015, 0.027150127308202848, 0.09483073762948475, 0.12022464476045101, 0.15116952539932343, 0.1488298622350539, 0.09269647795947329, 0.3428330488743321, 0.25860238640058425, 0.18324253179373282, 0.2163491593373399, 0.18294289948478823, 0.2194574538377985, 0.20483881084909364, 0.14990612383811705, 0.2130904970991035, 0.19413035723470873, 0.2495224978173933, 0.3373467868133899, 0.21321969016665415, 0.3372239675973693, 0.26787094711776704, 0.21242488926697164, 0.27589096837947447, 0.31506818388738944, 0.231412562331365, 0.179887940025618, 0.759325145233062, 36.97728580044162, 95.5077289765881, 75.05855406484297, 94.38436215923679, 92.09907947048065, 78.74936319166615, 48.886256679411865, 2.554239856619989, 0.28777841598756854, 0.7439546635554684, 0.8741304074083606, 0.9637255546066069, 0.7323114141341179, 0.19881401962089926, 0.9620673726162604, 0.5517794239905573, 1.8224182484611389, 20.159678497622092, 58.36335412917599, 55.15594182475921, 78.1428784708823, 60.02109289169312, 37.29954773379911, 99.25182742457237, 127.27626016063076, 108.49106450234692, 88.83969183891051, 81.6008400147961, 87.74662140877017, 95.58059876964938, 85.30048231924735, 69.61175472505631, 71.69868315419843, 78.77923596289851, 82.12773200004332, 83.00729213222381, 79.78256256349626, 78.57247998637538, 43.9276590654927, 20.209231761194047, 23.38617313292719, 26.063881112683205, 28.97113600084859, 31.421632843632853, 39.59003540777391, 63.68799124994586, 65.61884072519118, 69.1943831597605, 29.906727190940614, 18.423486448103382, 1.0788251171188972, 1.2185347945459428, 0.19640180793020034, 0.42807277171842517, 3.0841155398276547, 3.7881971655353426, 4.559099308906063, 1.4863010327662192, 0.613738531547208, 0.1681393688364375, 0.9493286174631889, 1.3143451824303598, 0.5185571937791763, 2.7165737652009536, 10.993618138374822, 16.563767194747925, 21.310645072690903, 28.275633089004028, 10.283128830694384, 2.2658853425133616, 4.522845821995889, 5.098747332249919, 0.31226436337155683, 0.21808169782161715, 5.247387511114921, 0.5354133957336026, 0.3292466633983197, 0.2901063733283551, 0.8159855596961514, 0.5644872291914879, 0.22356423669524733, 6.1125966714274504, 33.603251211104855, 35.039485885250954, 56.589497520077614, 61.51646514092723, 39.30945257986746, 23.151891923719838, 21.815985595026326, 13.636650404622479, 16.245386446675948, 22.648585150318763, 38.20574860418997, 69.96730973643642, 74.83941124331567, 65.34997009461927, 74.24682740242251, 80.05039768834268, 77.02872922343593, 75.94821822258734, 71.77283948467624, 73.96825282804429, 71.76726971903156, 70.08571040245795, 66.01609445387318, 62.59947469157558, 63.2072381050356, 72.38052445073282, 63.37698259661275, 74.29091484315934, 47.98980289889921, 55.527060800983065, 58.444511890411384, 35.22361763062016, 57.427253030961566, 27.310965368824622, 2.585616856813431, 4.411561806355754, 21.696982845183342, 5.051505815598273, 3.2266324085574, 2.8363796203367175, 2.629346871568311, 0.6467916708319419, 7.025013027652618, 36.64883044458205, 52.090829187823886, 42.732112792230424, 60.86595181495913, 34.23039505558629, 1.009589154874125, 0.1725790168969862, 0.1618821618537749, 0.3940995914801475, 0.3842958110955454, 0.16388376573881797, 0.19900595528944848, 0.16878766308148063, 0.31607185099874774, 0.36072386789225763, 0.31218665141251783, 0.17564765868648408, 0.29296198138786905, 0.4457783813197767, 0.13799287438873323, 0.20193892290755627, 0.18039207184507003, 0.1263562439670486, 0.2898938298946427, 0.3735785781135482, 0.1636427851213563], [0.09288202445473402, 0.02990851497968599, 0.040864305826084274, 0.08256310356720802, 0.018586078283166694, 0.0630152401995034, 0.11643152128184035, 0.027553520480831786, 0.07498274016524516, 0.03355825552716851, 0.056074265270463886, 0.07421780903373035, 0.05783254430899697, 0.03497052329382108, 0.13950548435170806, 0.02978950322064902, 0.06630546909065978, 0.10063435161306013, 0.06654485624523894, 0.07098269633828633, 0.03186659549453086, 0.036071150323315974, 0.07145348801127366, 0.03640992972519129, 0.3752634199636598, 4.373106398890096, 31.77837633317517, 41.38384511393886, 44.993378808421475, 53.57793308073475, 53.36174772631738, 21.89776505193403, 1.5287425489194932, 0.15016067953359696, 0.33915536718503125, 0.49461179803456035, 0.32265508968022566, 0.241250540880907, 0.24028075017756034, 0.779248150365968, 1.716050188387594, 0.5117006762133491, 19.336916246721824, 60.24649581601543, 34.58257682861821, 58.212656667155606, 32.79913983037395, 73.98617021499142, 94.5291760659987, 75.2223365537582, 87.86248037892004, 76.75432805092105, 87.28694315879576, 89.92642371885239, 84.12153551655432, 81.667190828631, 70.79809127315399, 76.49778150743055, 68.74127880219491, 76.56997665282219, 81.12958292807303, 80.22821441773446, 75.52093875023627, 79.68338151131907, 52.58990372380903, 27.292506694793705, 27.868753863919167, 23.689323317620065, 21.93107578062242, 24.574833685351958, 44.78161788755848, 41.88762257176061, 52.47162072889267, 22.776434806085405, 2.9601630039753455, 2.3626465374423615, 1.1672004071935531, 0.263572764853316, 6.395337783521222, 2.1802418606896556, 0.7677436547894633, 0.48664941722827576, 0.9562561360578384, 1.1249998716577407, 0.06165965527836835, 0.13427126521785415, 0.4744315405766811, 0.9207680016275376, 1.318223548512305, 8.10893354877349, 6.878135954180072, 14.56781323878996, 11.10889659773919, 0.7319082067378107, 0.09824267107873194, 0.046477121781677976, 0.2346323685900819, 0.2304716071774883, 0.06951206033268283, 0.531795193110743, 0.7270194013272563, 0.13526523365609108, 0.2714549515756869, 0.23973929455443738, 0.18024737315793193, 0.015334003443469205, 0.8831468332679042, 9.812212009583751, 25.983821615096062, 41.90458682275588, 48.69133449369862, 31.91521606137676, 25.847358434431015, 20.470322370529175, 10.706039763266041, 19.659929313967307, 37.532391394338305, 69.44831740471625, 68.23942722812777, 64.32162661706248, 70.23779638351934, 74.58446502685547, 72.67420015027447, 70.9909777487478, 71.8277212881273, 72.33093000227406, 74.23222834064116, 73.73546800305768, 72.47969765816966, 72.74577556117889, 66.62734877678656, 66.71874000180152, 66.68426236798688, 75.62164168204032, 70.49836727880663, 70.73640807982414, 32.12714172178699, 55.770330121440274, 32.35749271608169, 23.11485690455283, 34.57758757375902, 8.709235633573225, 0.5662882099709203, 3.3245399161692593, 5.521877917551226, 1.2195389213100558, 1.7426279235270716, 0.22662679574662642, 0.9018961304137785, 5.217425996257413, 4.806231183390464, 6.464769128830203, 15.34489066370072, 29.541680043743504, 3.0452014601999715, 0.11575353346885213, 0.08140454113843941, 0.047699809600148475, 0.107082391097661, 0.11632025467171786, 0.03674073032133522, 0.13081774085519776, 0.047887815237646146, 0.033210804009990345, 0.09837558733359461, 0.05010318829708042, 0.05189186570444896, 0.10087378473291475, 0.019039550623405847, 0.07066885309834635, 0.016770729524714333, 0.08336938812487549, 0.0761547857414811, 0.06683742522352165, 0.04112060437159192, 0.050386407172247294, 0.029501911898654316, 0.02318554569125897, 0.013517766023024678, 0.041751167511627565, 0.035682146197124835, 0.05991583231896643, 0.0684668176296738, 0.049157778341923995, 0.08570906661090352, 0.00869480012390282, 0.05709404321086984, 0.013119435733965328, 0.1033105418807076, 0.1415586153105382, 0.0644951113950341, 0.059001471907381094, 0.01730847919750358, 0.14752637895364917, 0.10834862718418722, 0.1325808768911708, 0.08939316045613059, 0.126977855369689, 0.11543823466185602, 0.012778207723562036, 0.4518802409931537, 6.621714926535084, 52.99854409310126, 61.60138837752804, 67.98122544442454, 71.35021978808989, 56.80123098434941, 29.421804566537183, 2.5910839053892323, 0.15348222226865832, 0.3275487674099784, 0.49102515823418097, 0.35770563468817745, 0.3760843597833188, 0.2853574862162913, 1.364079733048716, 2.102526224428608, 0.8628984552717979, 33.28001260757446, 57.15686836550313, 31.814360157135997, 65.25650001341297, 41.614982543453095, 48.82003530379265, 96.65564198647776, 80.6831544445407, 94.59327543935468, 85.51849549816501, 94.22395290866976, 92.61604001445156, 88.95686088069793, 85.23817154668993, 76.35208898975004, 79.30962670233943, 72.87249165196573, 83.1631592781313, 85.83316372286889, 80.97307251345727, 81.3852273264239, 76.61334237744732, 30.168378699210386, 17.54048639728177, 23.555162568246168, 19.40087245356652, 23.858759903138687, 35.83994357816635, 57.3406941659989, 51.6148260331923, 65.71694704794115, 30.720585661549723, 6.046495418394766, 6.6152792976748565, 1.6045818213493594, 0.638787032615754, 4.941989318017037, 1.1743717256092256, 1.434416900719366, 0.6852837892309313, 2.3527724608298275, 3.086805550321456, 0.04351018199456796, 0.39842446424788047, 1.0731935741439944, 2.500150126795615, 6.825902731187883, 32.59492947209266, 6.397498519189897, 21.227645758659612, 7.265799978087026, 1.2107569796423758, 0.09547625863624197, 0.4483939587108551, 0.528561627912906, 0.5241069798507999, 0.12377939998142182, 1.0575865858024167, 0.5087269373959111, 0.022387780031309496, 0.18956048954879084, 0.3143746598112968, 0.16837645772724383, 0.09147132716832623, 2.3439701718668786, 7.297212279612019, 36.47661485979634, 50.7221612622661, 50.62845583884947, 34.72439796693864, 21.145244606079597, 18.509329480509606, 18.432076438780754, 20.141468894097116, 19.632227574625325, 60.49924158280896, 78.29019484981414, 62.8114160414665, 74.48049083832773, 75.00935185340144, 78.67257102843254, 73.23070603032266, 75.6679178053333, 73.11951468067785, 76.87250121947258, 75.40382462163126, 76.35019840732699, 74.07262709832962, 66.13218092149305, 65.27585691021335, 64.89401417393839, 78.37003861704181, 73.08950854885963, 72.95028794196345, 37.75411121306881, 56.96025563824562, 37.7332010576802, 26.452815494229718, 44.823759832689845, 15.501720751485518, 1.4219736716439648, 2.179236508184864, 5.989971612730335, 1.2729682220566658, 1.7642876193408044, 0.28068030493394025, 4.504375380854453, 11.598797690483833, 17.076422937454716, 19.524827195752053, 33.20245950452743, 37.97397182833764, 1.9786059255561523, 0.0683934570500447, 0.09366405466871877, 0.10182266889680779, 0.01854282495896182, 0.1286759122364944, 0.09301663376390935, 0.1180025531099208, 0.08877164864492032, 0.0624318067885695, 0.19337864111988776, 0.19184876353509966, 0.07488382289246207, 0.09657489000669411, 0.08428616554386194, 0.07857353982305335, 0.04677199668461277, 0.08368421195735855, 0.022989727872153445, 0.004799010329729608, 0.15467658398612855, 0.035200537362646674, 0.1358171540402597, 0.07826267666513882, 0.13388861962143453, 0.11777329363770063, 0.1769878988664958, 0.1942230079082712, 0.29247284956997444, 0.10259549073394268, 0.2443444942154231, 0.2589324170783643, 0.2731670661559028, 0.18657291518344035, 0.10286800353036774, 0.2244864226949792, 0.2943323901103389, 0.1279592140006923, 0.11732171544985426, 0.16497894971361085, 0.16825771409898035, 0.31229810188374213, 0.2475013586902811, 0.14988945376488472, 0.13909054048840078, 0.4274701976007031, 0.6071659874531531, 8.616580424770232, 87.84078182712679, 84.37248091543876, 82.46232586522257, 87.62684006844798, 92.71232635744157, 46.383529555413034, 3.1130802823651225, 0.3527227230370045, 0.37996355324022235, 0.4921446578396905, 0.3992366400216857, 0.23077528443067308, 0.25606933200070936, 3.2914750710610425, 2.889491944543777, 0.78647542384363, 38.75699850820726, 79.09039758866834, 51.76944978775517, 73.9100605441678, 47.66400298764629, 90.89368804808586, 103.76868770968531, 76.14906710963096, 98.52057210860714, 85.0779741041122, 93.50261334450015, 93.65441691490912, 90.63541566171955, 84.40211834446077, 74.0187886453444, 77.9032922560169, 68.74592288847893, 77.16647501914733, 85.14983977040937, 81.14345242900234, 74.59613800048828, 80.65237168342837, 61.756569108655384, 28.976466501912764, 33.861096059122396, 24.844424070850497, 29.248021994867635, 37.071642337306855, 72.47605769864975, 61.82086067814981, 74.3389795672509, 36.6091517479189, 11.450096714881159, 7.860436689469123, 1.6518436852962741, 0.5880571805661725, 10.778555562419276, 4.889588413699981, 2.418756533053614, 2.5712604916864827, 4.041011818955022, 2.0452716321714464, 0.2586535917174432, 0.546405163984145, 1.2679332470701588, 5.90442717075348, 6.6922734629723335, 33.13018591173234, 12.739592579103286, 24.86224928209859, 19.957133185478952, 1.8976046914054503, 0.22000261732647497, 1.534863775295596, 0.8793355764881258, 0.5308393605293766, 0.18501895179431285, 3.0165210894999968, 1.7527052279441588, 0.2279968673904096, 0.4706237771578374, 0.4018359150617354, 0.23495054022679407, 0.14917921365028428, 2.1673061290094933, 34.31643616768622, 34.02898134723787, 55.18566554592502, 56.374645771518836, 43.057281201885594, 33.23945529999272, 25.532794152536702, 15.744896915651138, 26.444945258478967, 49.19922651783113, 74.48712748865928, 72.6871753508045, 59.928544567477324, 75.57364756061186, 76.7575522392027, 77.25789762312367, 72.91781071693667, 77.71559899853122, 71.65789834914669, 77.56510549975981, 72.16471564385199, 72.30816456579393, 74.02526055612873, 67.59486413771107, 63.47795224958851, 63.06102783449235, 76.64407022537725, 74.19698976701306, 71.81409497414866, 40.77778400913362, 67.96563794535976, 44.936755472613925, 39.035392653557565, 50.45291408415764, 16.18416609302644, 1.4933616667985918, 8.454300203631002, 10.020727169129158, 4.214333757277458, 7.910311097098936, 1.1028529439241657, 3.83602041871317, 19.588930491478212, 35.578756870762, 37.93369300903813, 47.003401325595, 57.55382399405203, 4.966159943611392, 0.16553333690089567, 0.1080761373703999, 0.30012137947543976, 0.17949626991345038, 0.17100859793924517, 0.22329270449136535, 0.2904277625343492, 0.28438155148779193, 0.16254704956325794, 0.4403705666622808, 0.32289006416836097, 0.20080345802970473, 0.3027900620814293, 0.2475017876995187, 0.28243152064181143, 0.1444097187730574, 0.2054507465612504, 0.24053795653725826, 0.24253965235285221, 0.29189619986761, 0.08155120867154292], [0.036807169296568444, 0.018368555277946497, 0.06231089130104069, 0.044190797489136464, 0.031281543722856915, 0.019772114540119807, 0.07101219072337113, 0.0058328019334904615, 0.01921261754638005, 0.020357068635583408, 0.040089116777263345, 0.07165916729718447, 0.0349778815683338, 0.03262674240695854, 0.025853544563776063, 0.01950248223429005, 0.04546557545601841, 0.056034984112146406, 0.05474580369228798, 0.083055023945147, 0.04769382262302022, 0.04576865516062226, 0.046216326300054796, 0.11222079561482515, 0.06525160023762334, 0.9262695548034484, 17.374219086862382, 39.53173721990278, 48.4507441520691, 60.91029420975716, 49.11610364913941, 38.67443653845018, 2.0880708194548085, 0.02684806267009868, 0.07030028819797501, 0.8705839106152136, 0.235526102084306, 0.983890153227314, 0.8174050286892922, 0.48959622039429607, 1.1503306608046255, 3.192529361094198, 46.01456003804361, 41.556146990868356, 39.366852544969134, 55.41556350646481, 48.439165315320416, 95.69867780131679, 75.93166582046017, 86.99190247443416, 78.89316512692359, 82.63205466731903, 84.61219264614968, 89.23156015334591, 86.92911317271572, 84.88311075395154, 79.37364762829196, 80.1125515660932, 77.13274263566541, 78.60145845720845, 79.77525911023541, 83.00898659613826, 82.98630745180192, 74.40920568281605, 74.0053584498744, 54.04496969715242, 26.426368913342877, 30.12423634529114, 23.892058864716564, 22.590912580490116, 40.4220328792449, 40.68081517373362, 48.2436155503796, 22.86044805280624, 2.850975985488584, 0.34443034219645685, 0.23898947833766862, 2.2476085683991833, 1.0237342023080396, 0.5905812870590919, 0.15174412198605078, 0.08317567513234193, 1.4969362943403184, 0.4207380314267451, 0.057728865799764474, 0.5433512923698272, 0.8560967589578322, 0.5025241686211479, 4.861022282031275, 31.293516466694495, 4.1664425980660225, 11.468782886382073, 3.3441162205511525, 0.5851597747495098, 0.608179613707527, 0.08086061871220028, 1.0672106113164657, 0.12434286531060935, 0.10339488050029164, 0.17078264796685788, 0.4576928871533563, 0.13909712884454958, 0.18502388540054523, 0.192346690042365, 0.07925027125184575, 0.18679290499177673, 2.261039499313601, 5.719447703130784, 23.557843508258944, 49.19094639439737, 39.53355327729256, 35.08509912798482, 21.816232704347183, 20.361796271416452, 20.741852368077925, 34.55511239267165, 62.268148160749874, 68.04745858715427, 62.80878805345105, 68.0876785709012, 68.73307320379442, 70.33186266499182, 69.81270559372442, 73.04604084261003, 70.70085571658227, 73.70983923635175, 72.03825058475618, 74.93880410348216, 68.75579157183248, 72.34181850187241, 67.04435948402651, 72.824081759299, 68.78313049193352, 75.97981683669552, 69.51910049684587, 79.27711025361093, 55.63794620575444, 32.92778376610049, 50.55040459479056, 30.293725882807088, 33.426591580913914, 26.460613166132283, 1.9318786071192835, 1.9323928053340607, 3.123641509202219, 0.25936669700088044, 1.6493957585865453, 0.9292655714577245, 6.353650343033576, 3.632312123813937, 4.789896472807854, 4.471047982092827, 23.771185144301384, 7.673481327872123, 0.14134118423586892, 0.04506728251374537, 0.0314077701149208, 0.11160464641908485, 0.14295335498548326, 0.010234549709205187, 0.051314580149107406, 0.07275193043413662, 0.0914057270593701, 0.050561914085260326, 0.06769496106332348, 0.03925266750757733, 0.05822394245995149, 0.1044534071679077, 0.06200638284245807, 0.09558963964903548, 0.06870756842075817, 0.10170991607611218, 0.06361806329580084, 0.04208066192786059, 0.03003484287839984, 0.051283473148942, 0.07534738269544418, 0.006384156370205024, 0.03605256886071256, 0.042851223805618864, 0.06788031603660315, 0.08696276949898851, 0.047051722198844924, 0.05494109099550594, 0.05223257181745383, 0.02303797992006425, 0.03873323308183782, 0.049407427244248896, 0.02202850011658044, 0.12046170300774037, 0.13384498325326752, 0.01916241771992176, 0.021988644392319748, 0.025596677197984634, 0.0156589990083669, 0.11947354151596946, 0.09272370472430222, 0.08396735805417262, 0.052331937251672636, 0.08412484274876696, 0.05638550381146132, 0.998487376397656, 25.838466421250377, 64.79279741164177, 62.876339112558675, 81.02117646125056, 63.055724790019376, 45.55069269672517, 4.473666164182848, 0.026660593294148004, 0.036042360739121516, 0.6715901820890365, 0.9262962759502473, 0.6524852975722283, 1.5585955857269227, 0.3829508671356786, 1.854859804434161, 11.147049492405309, 58.938581482056655, 41.59878707701161, 40.929669949316214, 63.21343937227803, 45.00327102599606, 99.09560726534937, 78.25838442771666, 86.54335591100877, 86.05189077315792, 84.38119642196163, 86.56442688357446, 90.1107515827302, 87.60831079175396, 83.5033150642149, 79.97786521911621, 82.4622787967805, 76.83863547540481, 80.64255791325724, 83.20808610608502, 86.11298561096193, 82.26603477231919, 80.30404167790567, 70.57003682659519, 24.316167100783318, 19.162433531976518, 27.932531602921028, 21.822985064598825, 27.462433576583866, 51.09919909507998, 51.332478138708304, 53.982235308616396, 29.246757030487064, 11.026849439067226, 0.6439957563434878, 1.2490445832090995, 0.7975023095646213, 0.38986407520790256, 0.6531444396222792, 0.17938970708318297, 1.003803475008857, 1.0572495071157333, 1.2559607024154356, 0.10983960282418037, 0.18435319074459616, 2.5184957875359446, 1.0603056463503069, 9.927055085858992, 41.25149649958457, 7.203596090116809, 21.70459616568781, 8.067309356504872, 0.4730283739345689, 0.8092895835157364, 0.1227626710709545, 0.07138451711545069, 0.29801420867443085, 0.07349141978568609, 0.2487448266436977, 0.09559718561508963, 0.030121958566709395, 0.2827298659230432, 0.10817192134357269, 0.1393313525665191, 0.20306357062391697, 2.1278272280769963, 5.205728998107295, 31.789639419124974, 57.47298786717077, 39.40463673683905, 35.91986187042729, 25.316763731741137, 26.364099325672274, 18.010329469557732, 15.24365625073833, 52.691979485173384, 78.19466944663756, 61.68186364635345, 69.67623849068919, 70.42421879306917, 73.26690950701314, 72.45918366216844, 74.4385842354067, 70.93907694662772, 74.52995192620062, 75.47929886848696, 77.71648545419016, 71.11876856896185, 72.1989030222739, 68.32382094475531, 73.4018704199022, 69.47128680444533, 76.63963010234218, 72.8861964133478, 80.03304512270036, 62.178847559036754, 37.82461973928636, 53.83840983913791, 40.29078645090903, 43.54021126224149, 40.19059734959757, 3.645460153779676, 0.15950333627481617, 3.7290522360032607, 2.23314703472199, 0.32413054437887284, 2.2019026596699995, 12.394075893586683, 12.08563345093881, 14.694246918924394, 23.639828889600693, 40.521437506521906, 6.314981656689798, 0.02709832061232338, 0.014719745527291972, 0.09689139923261059, 0.1517057409810443, 0.11497547925119439, 0.0365345684000321, 0.11033134700189676, 0.040522492716028806, 0.017618423049908974, 0.09902244899421932, 0.0461925775744021, 0.018185607735968886, 0.07208133536961771, 0.04017860733813817, 0.05603562379556318, 0.14103834967940085, 0.03946301226894702, 0.14944860080797828, 0.010499908202027362, 0.0036914152517584305, 0.06798546160421065, 0.03969892521478957, 0.19022104120062244, 0.150534882841091, 0.15123543960432853, 0.09562789041909481, 0.15874595110935552, 0.18861568863353423, 0.2284827203519883, 0.126059798583869, 0.18212900767403264, 0.19936423928987598, 0.1367642225757722, 0.12608792167156935, 0.15313296278397884, 0.2575536120322443, 0.31960658068137787, 0.17079646819301192, 0.3176434037666167, 0.10352938255715756, 0.18889259877464465, 0.3756432157130011, 0.14662115414056087, 0.28717244043946266, 0.17554235224041248, 0.22395966063824393, 0.19726197145158247, 1.0808974768846267, 46.12467273589104, 90.12095758991858, 89.43971249365038, 98.00672592655306, 92.83620265222366, 81.00643619414299, 6.987270510965779, 0.10684285838637622, 0.22058485947068662, 1.2775163328455341, 0.37646145890316657, 0.8632284859495779, 1.6489837871443842, 1.0680308769787512, 3.9042958905619964, 12.403085577872492, 84.58696396120133, 62.87395823386408, 50.03201238570675, 72.29762123477074, 68.27534044942549, 106.00027315078243, 80.93316631932413, 86.89585931839483, 84.08839933333859, 83.6775702814902, 89.36206525371921, 89.26004440553727, 87.54162265408425, 85.02841103461482, 81.01781106764271, 82.37800275125812, 75.85678777387066, 78.58051300048828, 79.64562477604036, 83.18798788132207, 85.44205634824692, 73.06250695259341, 76.95484745887019, 64.20415163040161, 30.59944129759266, 38.04637093697825, 28.87138620499642, 29.30357256243306, 60.92976485529254, 60.76931245865361, 61.39940592550463, 38.106724446819676, 14.899879136393148, 0.3233062031288301, 1.0853079369952603, 5.3476025981287805, 1.0957599503378714, 2.273091717112449, 0.36992541123782435, 1.7711305618286135, 2.537959323775384, 2.2927138641957314, 0.135763052911047, 0.5932498470910135, 5.517002901723308, 1.2195357343842907, 9.382552639130624, 46.73273424948416, 8.90657203812753, 28.62199994825548, 5.633579665614713, 1.3214490851086955, 1.3274575433423443, 0.20534141049269708, 1.8699735547265701, 0.4952289278228437, 0.28071992700138404, 0.7574082093854105, 0.6491975546363862, 0.10704995493494696, 0.391577783251001, 0.4258497071362311, 0.16719484371283364, 0.38355947802624396, 2.7756284802190723, 22.066785866214385, 32.05372868045684, 61.43444053588375, 47.08310388749646, 45.53889812961702, 29.735409828924364, 26.162138446684807, 26.92978355192369, 42.274034869286325, 72.44250574419576, 72.99224945806688, 60.12944052296301, 71.63780012438374, 70.26010682505947, 72.1923997325282, 71.39818253055697, 78.19868595369401, 69.02874146738361, 75.96368020580661, 73.00859005220475, 79.65760369454661, 67.65056179415795, 72.63845166852398, 63.76331644673502, 72.52063151328795, 68.09876318900817, 75.66038685460245, 72.01244138902234, 79.44209298779889, 58.593146185721125, 48.99729897899013, 61.32934847185689, 47.74661202584544, 52.64631132925711, 49.32070232206776, 3.2943151122139347, 4.461147919777901, 8.251931398145615, 4.8270246482664545, 4.1361182639675755, 1.7775706033552847, 16.664981995859456, 27.576174466840683, 35.47068772777435, 39.468473311393495, 64.20823089538082, 14.721296564225229, 0.19946646606249196, 0.12646442324283624, 0.22076862864196303, 0.2871736968236585, 0.16408939905945333, 0.12092781388351034, 0.25596246273527223, 0.19412622035991764, 0.1410301218950941, 0.10968632395229033, 0.16878377135482528, 0.15020273776063997, 0.1335221538019757, 0.25886674802149495, 0.1371125014679086, 0.32073867477236256, 0.1777014791244461, 0.37326055969442096, 0.11111215147520266, 0.17440094252026853, 0.22249044189530037, 0.21644565577228225], [0.02426408066023742, 0.040553810390373396, 0.04969175311646635, 0.03522478404545015, 0.07860480387124323, 0.0682705765469901, 0.0632691485506873, 0.05793605044844651, 0.04706886724659032, 0.07643743388114438, 0.015140078819146561, 0.026216350398176623, 0.10385804193755312, 0.05470395230898454, 0.11181853816754396, 0.07468111602769745, 0.07962977588777581, 0.04401973771652387, 0.03401079898579948, 0.03494011726410639, 0.09468713444807837, 0.2216877962552732, 0.058022702653561874, 0.06377410774509754, 0.0701492156593069, 0.26145416402047683, 7.212565079812081, 25.648504072620025, 33.19408132183936, 39.07920552838234, 40.98035481668288, 21.951748632615615, 6.241470556105337, 0.19049882468196655, 0.13088178580566762, 2.3250542965627488, 1.713561934809531, 1.389834015600143, 1.9574986710663766, 0.5309683084487915, 0.8829998056734762, 9.91323265337175, 48.121394495810236, 34.50035610506612, 54.82897696956512, 42.744770280776486, 67.14468586829402, 89.94350171858265, 83.1303604187504, 79.6831226348877, 78.97653902730634, 89.01087976271107, 90.71787172748198, 89.44564311735093, 89.85714681686895, 90.73432214798467, 83.9830836942119, 81.32559161032401, 77.40620243933894, 83.50362885382869, 83.08494721689533, 85.73522998440652, 82.52183606547695, 87.61708121145926, 73.93783876972815, 74.73275415359005, 35.68647300043414, 23.20997045886132, 30.924188052454305, 31.860730417313118, 33.804209924513295, 38.42152210973924, 49.47482401324857, 23.80245231813, 4.243607876762267, 2.3033091666237, 0.38200579042876925, 0.806017101051346, 0.12711099379004973, 0.3779650443503934, 0.07375036516497213, 0.378804462210786, 0.3891317564393244, 3.19225283399705, 0.12451590925094583, 0.13589865047364466, 0.826104049000048, 2.9199466974504533, 9.640055260350628, 30.119706007742113, 1.9213820993900301, 19.634386839405185, 6.477105473318408, 1.2435297307468232, 0.1503270585089922, 0.5749610607181826, 0.11643850800370979, 0.3281240687975961, 0.7027624835891109, 0.10006381529233149, 0.042835109146131624, 0.12249058728376705, 0.05605242027330303, 0.16124508313594327, 0.1010831029364659, 0.08913337238012783, 0.2962797243268259, 6.745658882202641, 21.75144103265578, 55.56139330710135, 40.92045237941127, 33.41291427612305, 21.974208124222297, 21.320058761104463, 57.56779547660582, 56.96268358538228, 71.91459394270375, 69.9838464490829, 71.95155835920765, 66.38518948708811, 67.67994819148895, 71.64624890973492, 73.24798799330189, 69.96994556919222, 77.4694545807377, 74.0486692613171, 72.69032893642303, 72.16598649178782, 75.29168405840474, 70.65723896026611, 71.10512656550254, 68.38333898975004, 74.17950384078488, 71.57230438724642, 77.29188103829661, 70.79452191629719, 78.39567522848807, 40.610812633268296, 40.77537567384782, 43.3524787810541, 33.05544907046903, 42.16081173189225, 7.57043085751995, 0.6637857073257047, 2.2871676327720767, 0.3076839849593178, 1.3524959933373237, 3.93984874410014, 5.5018816744127585, 3.1583603687824744, 2.7492223487746332, 8.020611088122092, 5.688712010460516, 0.2245768976788367, 0.08786300707968973, 0.06708750696552378, 0.07159070201939152, 0.2546319212283819, 0.08329018229438413, 0.05732456289772546, 0.1041807258321393, 0.2539766402614694, 0.06217653480088038, 0.055903109736860766, 0.027255085184268897, 0.08803386000856277, 0.037889406385440985, 0.12483650938637796, 0.08124234500311076, 0.1799696203201048, 0.03455060751988523, 0.11679715972634093, 0.046506018618181835, 0.12667530426575294, 0.03874325734232703, 0.051535837832958474, 0.060558514969964186, 0.02127199212179309, 0.06428377838024209, 0.12326579165434647, 0.042944357114573645, 0.02800144825971896, 0.14952824330858647, 0.02399910233854767, 0.025053266135434953, 0.04111353338005082, 0.030596080806947527, 0.06026261733965047, 0.07374293411210661, 0.08727638291255121, 0.14788507664155576, 0.07873848621403018, 0.014608986450419312, 0.043313921759686166, 0.060063093570211244, 0.036605948642376936, 0.15152692073775878, 0.08691218471334827, 0.021668576687994986, 0.032174953544932994, 0.10756264395651319, 0.24068201171053996, 9.26294388309602, 52.41096519654798, 53.30840741434405, 59.98232418490995, 60.838389319758264, 40.55282823501095, 14.309618319234541, 0.2659284239334445, 0.11458139596206528, 0.6681351255505317, 4.078531005690175, 1.0492825604254201, 4.746780308984942, 1.075625811373034, 2.3424723167573256, 19.47110641387201, 51.83112905871484, 33.286280555109826, 61.91785697014102, 46.341791614409416, 73.40690674320345, 93.88655062644713, 85.5004055269303, 82.6807548153785, 81.00910340586017, 93.7180926722865, 90.95671269201463, 90.40987153207102, 88.8197583536948, 90.94470239454701, 83.80310181648501, 84.47139524644422, 78.48699585083993, 84.08184113041048, 84.59786030554002, 88.80168407194077, 82.06257358674081, 86.21935244529479, 81.27369080820392, 63.96804848024922, 13.38244551612485, 24.536574886691188, 28.66788579571632, 29.842351290487475, 45.49343001457953, 51.099744304533935, 56.19125927648237, 29.035915905429473, 12.12892072816049, 2.7724660692676424, 0.6157907891658045, 0.822647889294932, 0.28672072435578994, 0.6252251925968355, 0.2442527015603358, 0.5568617738543019, 0.31570569161445866, 2.2622034626622356, 0.8525293019990768, 0.26842826076092263, 1.918879014349753, 12.287300152163352, 13.739736176306202, 41.585815798851755, 4.508092807185266, 7.75120456372538, 12.877423686365928, 0.8038659261599664, 1.2804009909591367, 1.1499663706748717, 0.18360086175943577, 0.37031280657937454, 1.9099179919688933, 0.08142194665607907, 0.10263276857233818, 0.13343100466074484, 0.4311017607969623, 0.06978048221959222, 0.10201943091927998, 0.02092483171802615, 1.7121730480463275, 8.127033325933642, 35.48763628928892, 59.94295535549041, 44.77487925560244, 38.81388464281636, 24.562507637085456, 25.15601715733928, 32.45679143936404, 39.199449708384854, 79.97924589341687, 75.06479063341695, 74.56031891607469, 67.8845468644173, 71.96284694056358, 75.60198276273667, 75.58361038084954, 68.72824868848248, 78.12339213586624, 77.38070703321888, 76.18348983026321, 75.46490376995456, 77.12582357468145, 72.38759256178334, 71.40282661684098, 71.3360051185854, 74.60989767505278, 73.65735792344617, 76.6937666554605, 72.4231606145059, 81.58391890987274, 48.5755382814715, 47.31897954017886, 52.18289898287866, 41.10983225607103, 53.35613481460079, 14.035673122252188, 0.4082698585285295, 1.4219696266997246, 0.506314403948284, 2.445167812608904, 10.632152115145038, 14.885368327940665, 13.05067281569204, 12.046249912631128, 11.531119154345605, 2.757559346575891, 0.3769295999119359, 0.09292604386686318, 0.049177696627955285, 0.04285008616505131, 0.21500550240518587, 0.0696060516601128, 0.08014132343833485, 0.027442782471377044, 0.23107025892503802, 0.07795048817511528, 0.06975484125676655, 0.08461382134907669, 0.09183737163942668, 0.007012856480169802, 0.1366991970327593, 0.14402155734358296, 0.15003744663009722, 0.04455393848700389, 0.06302719117112218, 0.03895201630169346, 0.11487423307112149, 0.011551664567612594, 0.08377607356035903, 0.1124510356795884, 0.09638605699423822, 0.13618437062588432, 0.43296611236949123, 0.15469670145502015, 0.10049556712469748, 0.2731324696252423, 0.27947586149938647, 0.2193042515747009, 0.10024490315587291, 0.08743658721927675, 0.22562528900321455, 0.2667375047120356, 0.20784775906753158, 0.2865581604982576, 0.12063234909287385, 0.2426848873015373, 0.08617523877370743, 0.25115952045927126, 0.20562429611961688, 0.3285307389113211, 0.4069453231509655, 0.18107614239617703, 0.18937868156260063, 0.1938426299321075, 0.6576543073019674, 12.693930306742269, 81.1117047648276, 77.09181662528746, 78.56509808571109, 83.52095788524997, 68.41399623501685, 23.82280549695415, 0.4050542504316376, 0.19283802819348153, 3.389095755354051, 7.176669509180131, 0.6639858707785606, 14.225637432067627, 1.932755502000932, 2.7216951549053197, 28.022216596911033, 81.57727441480084, 51.786594467778365, 69.64753458576818, 60.280149752093905, 79.9640114076676, 94.46195448598554, 85.04821900398501, 81.24323752618606, 77.4073399266889, 92.65687973268571, 89.05903862368676, 87.89236099489274, 86.68940928674515, 92.98481341331237, 86.34468001704063, 83.03372890718522, 78.77720417514925, 82.51199876108478, 79.84755623725154, 86.35402310279109, 81.9974857761014, 90.1595772466352, 75.3329787715789, 81.59767073969688, 48.897404055441584, 28.03437202207504, 42.38745412518902, 41.895349641000074, 51.046906055942664, 61.0972971300925, 61.80878370038925, 38.20177524320541, 19.213547898877053, 3.578370708611704, 0.9640505597476037, 0.7239559689356435, 0.4651416826152033, 0.6774578640057195, 0.30065292192082255, 0.6054468248640338, 0.987076772557151, 4.005551631412199, 0.44282857508909323, 0.35505962828474663, 2.4957144164269973, 9.489644131352826, 25.921510842538652, 51.65117855994932, 8.993490780553511, 29.612878907111387, 9.628984370539266, 1.8880287149260122, 0.6232098910597064, 0.7292033034947611, 1.6223238048053559, 0.6858489169709144, 3.755831482910341, 0.36653731078390156, 0.1994859093740102, 0.26523532886658946, 0.4548652259813201, 0.27407334817032664, 0.19770873860726434, 0.2666074229824928, 0.9433865943743337, 18.79270503597875, 35.00301176501859, 66.18583110070998, 44.757087384500814, 49.2704842167516, 25.98753413846416, 29.75700639909314, 65.06695931957614, 67.91721236321234, 82.25651125754081, 71.68833594168387, 74.46707633233841, 67.52176684717979, 70.21393268339096, 74.7980223932574, 76.68548260965656, 69.95165163470854, 78.3296460490073, 75.3318020605272, 75.96197789715183, 74.25675884369882, 75.75657121596798, 70.56649100395941, 70.82157842574581, 69.74219706750685, 73.97190847704488, 73.79014584325975, 79.15250439797678, 72.10111048913771, 81.09545830757388, 49.69906591599988, 56.477513851657996, 61.16195348001296, 50.3641116234564, 62.18144024572065, 15.058684137559707, 1.6430489959255343, 10.472140985150492, 3.6860240803610895, 2.6373154117215067, 11.734061606468694, 29.41280076580663, 29.410527752291774, 34.89424836251044, 45.23001932328747, 15.091982118545042, 0.5367434469442214, 0.25299305997548566, 0.20181968898302127, 0.31490188152078663, 0.35045789134117866, 0.16787473142387407, 0.2702237869943342, 0.3203364173250814, 0.4106177341553473, 0.16478813253343105, 0.27598151997212444, 0.10639025364071132, 0.17714480899514692, 0.1139471211260365, 0.23427636753166878, 0.38920971354649914, 0.2641454615419911, 0.12746076655363844, 0.21309350016376666, 0.19886919327320593, 0.17488249006771273, 0.15265657866914428, 0.16209240702371444], [0.05220936318378776, 0.0988798953532692, 0.04036401976801215, 0.10914759560217781, 0.07671276588113078, 0.06647276737156414, 0.030702373591221632, 0.024049554974020972, 0.028318474594984325, 0.02626236355412872, 0.05317394831968893, 0.04329877620142314, 0.12083361571234082, 0.041550222649088794, 0.12746199995519655, 0.13783231768156254, 0.05097933624300265, 0.04171268308475133, 0.0643863115880278, 0.08609130618072326, 0.12481787046718022, 0.032994464610613165, 0.10883589740842582, 0.06020723684360424, 0.15242154289397503, 0.05495351694163777, 1.344938321459678, 23.76635866780435, 27.499647063593713, 26.23919144753487, 43.786787140753965, 28.118412725387085, 14.607685112184095, 2.168298243514953, 0.11287338761312347, 0.6711057080857216, 5.391264951998188, 3.59598754394439, 2.663271696336808, 0.104919150321474, 4.218619436986985, 32.12195830960428, 53.9227839439146, 48.59736234911027, 55.63068982093565, 45.73948814022926, 97.4910048515566, 79.62952736885318, 83.0425307058519, 83.73735504765665, 88.59816012843963, 83.57458453024589, 83.03324253328385, 89.0619960907967, 90.58081626892091, 86.64601218315863, 84.12355161482289, 86.03507164985903, 86.90095839961883, 81.77707995137861, 80.87047899923017, 79.99803404654227, 85.86059677985408, 82.42234122368598, 77.26570313976657, 66.27129954676475, 65.06398616298553, 29.40272419683395, 30.478595033768688, 36.49887038815406, 35.614156261567146, 35.61614098087434, 46.04790018450829, 22.35406025763481, 6.8567051041510805, 4.082476419787254, 0.41484899097873323, 0.26201068093219115, 0.09420841376507476, 0.09404166706747587, 0.09606226227216183, 0.27889412497320487, 0.23238216917360985, 1.8229157766026838, 0.811065988194558, 1.1082936390753717, 0.5256661832813294, 2.983643292419372, 8.680387581548384, 31.744543929253858, 4.102183142977377, 6.351370465370917, 19.323458594660607, 0.45652481757344743, 4.009693654314164, 7.120344273505673, 2.0043090947212714, 0.9321946626709354, 0.8041962019858823, 0.5500394238098976, 0.18790221562789333, 0.45615804531881887, 0.0824667220454543, 0.12579975769885127, 0.33783214947869705, 0.5655132354267183, 0.3775754426756213, 2.407607931283213, 19.9052559175799, 56.09695373042938, 34.13257114348873, 37.4459933465527, 18.003061317628433, 51.147812950995664, 87.60578478536299, 46.684661680652255, 78.8069357410554, 62.921085511484456, 67.51130196356004, 68.49804478306925, 74.8275343064339, 69.07954400585544, 75.77286474166378, 74.42669945378458, 74.53381153845018, 69.40029974906676, 76.83635265596452, 71.12764881503198, 72.50251016309186, 71.37906489833709, 74.871582523469, 71.35044728555988, 74.48663327001756, 70.24681783491566, 77.77727434712072, 71.12924129732194, 81.67944431304932, 63.63597277672061, 33.13705398190406, 48.734060871985655, 33.75673747831775, 41.60763986649052, 24.214448275104647, 0.5028418806051055, 1.2261152652002152, 0.45350171205016876, 6.435960790803356, 8.160196965740573, 7.026072067599143, 10.31478726094769, 12.887973881536915, 4.503926269469723, 0.7951501744889444, 0.1628337196645237, 0.05342019579163002, 0.24877263563534907, 0.017717656333960833, 0.21740663646449968, 0.027378352561725244, 0.07675568212664897, 0.020976402841868903, 0.06198302099120714, 0.08632069588789056, 0.09065992514332456, 0.131145411982171, 0.03650788938806903, 0.07315967307095567, 0.056374686649970474, 0.04755048757238735, 0.08954605628405848, 0.03993055189869577, 0.042778296065666986, 0.03289521792002263, 0.02165406123704968, 0.018751555190031088, 0.051103166695083344, 0.061634650168519836, 0.04448686748923314, 0.020633967285374963, 0.055606618388405735, 0.092695459062534, 0.06279208261760012, 0.03259712544780585, 0.02079274283812171, 0.06362027728990202, 0.035717650541975614, 0.04416991393232057, 0.0522698458254097, 0.0477813903032051, 0.033966791064989184, 0.12879649447577615, 0.12646596307956404, 0.006565067075913953, 0.09441558692243793, 0.10896768751403979, 0.03403781507644923, 0.3298622610107545, 0.07232914949136396, 0.02584140398539603, 0.027476385002955798, 0.07734009229968633, 0.022891888868123777, 1.5067530062890824, 34.4822229877595, 49.81061812370054, 48.68473706706878, 64.02751553443171, 47.43397951126099, 29.2172961081228, 6.241011148498905, 0.0931597696316819, 0.9408537851225947, 3.1972053166358703, 5.206444830663743, 1.1697156270665507, 0.09544276527219242, 9.862127111804101, 42.740667481576246, 48.50768912223078, 54.12585681484592, 61.850741294122514, 56.53075610437701, 99.7261361152895, 83.87565781993251, 85.40754733547088, 85.2374968990203, 90.17876548151817, 81.83333458438997, 83.51323866075086, 90.17048143571424, 92.24623110986526, 85.73716763527163, 84.71233860138925, 84.06019749179964, 88.65617198328819, 82.70131587982178, 82.99661544061478, 85.32533445665914, 88.94094390253868, 83.78990696322533, 79.44348935158023, 71.74782260771721, 46.21547168300998, 19.09871658971233, 33.79503157831008, 43.35018027213312, 40.03458115362352, 51.43188276598531, 51.1554733399422, 22.19647511359184, 16.82423414722566, 5.394241540662704, 3.1784308918060797, 0.9935610020352948, 0.47311429835615626, 0.3593427952258818, 0.28882222610615915, 0.5074267636143392, 0.18261967166777582, 1.6155162862231656, 1.0943174987070023, 2.0318188830729453, 1.129771557546431, 27.422311652091246, 9.581720790555401, 37.19274159400694, 3.925128333991574, 7.971729040145875, 7.928617288989406, 1.50800546811473, 2.11318796200137, 16.29090359134059, 5.4220589899247695, 2.0794935764804965, 0.9631604881536577, 0.3575997613370419, 0.05270416405232203, 0.2981551382089815, 0.014952891938117965, 0.4138540266261947, 0.3473959604818975, 0.8964374168745933, 1.9620451883923624, 16.550015364923787, 32.360911061686856, 63.099510208252944, 42.59743036762361, 45.81832778069281, 23.274154163176014, 54.35041250721101, 87.59375879841467, 45.933884728339414, 82.47634441621842, 64.82588652641543, 68.6751005726476, 69.33393324575117, 76.33916870240243, 72.91205267752372, 78.66489887237549, 74.61460451925956, 74.93385407232469, 71.61715276779668, 75.98443738875851, 73.55872600309311, 74.09863241257207, 71.75780896217593, 75.72236030332505, 73.34442338635846, 74.27549992838215, 70.7635744156376, 78.23750172891926, 73.58357029576456, 84.09224325610747, 69.68813896179199, 43.89328341330252, 55.30086555788594, 43.56633032521894, 51.85641265684559, 36.7082739645435, 2.2321156965148066, 1.1708761583412848, 4.210793818196943, 12.523544507641947, 17.030186037863455, 17.1968142063387, 23.2329830046623, 19.77701206361094, 6.438712333479236, 1.7027631594288735, 0.16356795365291257, 0.07591452524666825, 0.10307058782106447, 0.029001763736408566, 0.15313605777919292, 0.1526621098239576, 0.05717490379127765, 0.03453738484231215, 0.0559324853783173, 0.041474751497228304, 0.034940967621702346, 0.05892354544372328, 0.012438816408957205, 0.06720702434259077, 0.07774540643778541, 0.18967497372819533, 0.010661182159017171, 0.0704548847410948, 0.07302507908353884, 0.038844177935032115, 0.039597050842618754, 0.06516802770596358, 0.02758726856911615, 0.14316844183110422, 0.1354050293805138, 0.18469259833856938, 0.20342237556413298, 0.2791044620736953, 0.1734036645821987, 0.165596860911577, 0.10751911484065557, 0.14125290026347484, 0.13402171973739901, 0.22927255700192145, 0.12221992075923951, 0.211161227235871, 0.24285298231388294, 0.34007332437942106, 0.22128964503926618, 0.16818885811634604, 0.1632603540295555, 0.20647016444033195, 0.18493834402292006, 0.40744248357030655, 0.24090508119233195, 0.15978982251498008, 0.10557402526178669, 0.23656960576772693, 0.19501650645848245, 1.9867688681810134, 47.81424545472669, 73.15175656349429, 68.79834144346177, 90.05985490737423, 70.30818723863172, 45.82763948748189, 7.981780113712435, 0.2916913786001744, 5.018011225808052, 9.033345983874414, 9.374992270623485, 5.056293558689856, 0.35634907683537853, 11.300284727927178, 62.10228681564332, 88.78066016781716, 64.70007650313839, 72.4029839423395, 61.095273187083585, 101.11770676028345, 84.23246014502742, 84.25471567338514, 86.10985555956441, 87.79683559171616, 80.38347751863542, 80.64101249940934, 88.01153829020839, 91.66361793395012, 85.56444214236352, 86.0127062951365, 83.69743316404282, 88.60540082377773, 81.52452638072353, 77.76072978973389, 77.36924586757537, 87.25819218543269, 79.22406411940052, 79.98529418822258, 64.15779705970519, 83.15421627413842, 39.00759089377619, 37.06801022252729, 54.602440480263006, 43.99264097213746, 60.533275988794145, 52.86797231243503, 32.04354424630442, 24.331350595720355, 12.04279136273169, 2.683813148929227, 0.8277983903404206, 0.9649068621858474, 0.37693998806418916, 0.33133318046889, 0.6769187832551619, 0.8098924640686282, 2.4525261790521684, 8.399068328642077, 3.4579110433978424, 0.9036410335571536, 31.042141568276193, 17.12135761014877, 50.10740818515901, 7.611854028317237, 22.30697416490124, 27.142154401348485, 0.7747026136325252, 5.738861474298663, 20.696401903706214, 4.259862178756345, 1.9438031027393958, 1.351263756232877, 0.8992196643544782, 0.40126787618763987, 0.6502119163351675, 0.12901531983046763, 1.295365446036862, 1.0580360649093505, 1.1210201368216546, 1.1967381834983826, 22.472382476252896, 33.76449200414842, 65.53669844904255, 43.83538138481879, 57.819474358712476, 25.918165060781664, 57.25943050076885, 98.10337312759893, 55.08849666964624, 79.63637582717404, 64.56284846028974, 65.64664640734273, 69.45763695624568, 74.36240396191998, 70.10827187568911, 73.96936678117322, 72.5514691875827, 73.43089595917733, 72.55114755322857, 77.57379747206166, 72.76849392921694, 74.25204415475169, 71.12135733327558, 76.29183353916292, 74.37902696671026, 76.66787116758286, 72.7096740661129, 80.58857041020548, 74.88418902120283, 84.91859251453032, 72.9435806889688, 53.99818758810721, 68.05361670832481, 52.01501761713336, 65.41329283868113, 40.75770539622153, 1.7684662918890677, 2.396784641088978, 4.848184364457285, 11.96470775911885, 27.43462593324723, 32.09507438444322, 35.88051657522879, 29.69490743452503, 6.431977623893369, 2.854623054304431, 0.19426885060966018, 0.16615697843653543, 0.3257120256462405, 0.2012707716635158, 0.4063105733404237, 0.40638951104014154, 0.19442243591671993, 0.12709047029455825, 0.11508617129537368, 0.25144073601451616, 0.1788409123377454, 0.19609453006377145, 0.1425129310378144, 0.1914453109906566, 0.18140629564802493, 0.3291426593017194, 0.14882629226532676, 0.14609414693568984, 0.10404467627766634, 0.14340952970087528, 0.15307472477997505, 0.1882670420191942, 0.21288353078547986], [0.0726782940628548, 0.04015135376023189, 0.03214326048750551, 0.01223205885429296, 0.08624678372495598, 0.0816927740590707, 0.040075216111877275, 0.030868089900562362, 0.04140835082639129, 0.03485508533495088, 0.04252608459923537, 0.033297578789173596, 0.028880727590031685, 0.0656521876132296, 0.06085074686956021, 0.0604107404398101, 0.09090105897837109, 0.019338499198878006, 0.07919297553598881, 0.07594423413637184, 0.0943880920268355, 0.04491476972977962, 0.027561120073040648, 0.04782329148222362, 0.046245089071171905, 0.07445601641290611, 0.1728266778011476, 3.220555186271668, 35.13372475101102, 30.484558997615693, 28.606065319430446, 27.63760074492424, 20.168164545489898, 11.662631323260646, 0.8298858267165, 0.2278566733002663, 3.4981560322546192, 5.012941562360333, 4.51686518807565, 0.05628685849989134, 25.239732303927024, 64.58115023951378, 50.960919857025154, 62.20282893027029, 38.70006922752627, 73.57192870109313, 92.88316911266696, 77.78497788213915, 86.52801944363503, 81.6395773426179, 86.94463791385775, 81.57012001160653, 85.37607423720821, 89.44539993040024, 88.20180462252709, 87.87171363830568, 87.32893605386057, 87.87624005348452, 84.1288075908538, 80.53328852499686, 80.5497311007592, 83.2442032906317, 84.15340869657456, 81.59291682704803, 75.28175261712845, 78.67708175413071, 67.15307189572242, 51.75742380080685, 22.50834276599269, 25.65175767867796, 31.90849900245667, 38.619499821816724, 33.88989410092754, 22.947801197728804, 5.963322049187076, 6.323236284717438, 5.222815823170447, 0.49861086892985534, 0.13392177590679738, 0.012955099340498209, 0.3006895715671201, 0.14300074518447922, 0.038653598242108865, 0.4221646710028572, 2.407609402172027, 1.4215127931487177, 2.8813839151013285, 20.256837567975445, 5.291161652534239, 22.76059235295942, 2.815818065597165, 3.8245472408110097, 13.664828711940398, 1.79595708126022, 6.2187002166625, 10.853125702950264, 6.64972064956542, 3.3225897627492107, 1.174746189386614, 0.3728639406542624, 0.16860236173435567, 0.8025233111073895, 0.28566082639078944, 0.3857610002160073, 0.283019753593591, 0.7072581939639584, 1.3600607745109068, 6.20242630281756, 16.961744600726714, 41.52746662016838, 37.2484863188959, 43.72706121014011, 20.158711633374615, 27.121709046825288, 23.270694632684034, 60.02336394402289, 77.29962379701676, 69.25132028518185, 75.44250703627064, 74.9611145450223, 74.37537131770965, 69.97251864402526, 75.3744068453389, 75.33645399155156, 77.06472873687744, 77.26525598956694, 76.56986682645737, 73.56457033464986, 76.27206479349445, 73.18942700662922, 73.94292216147147, 73.54775121135097, 72.13274832694762, 74.85344548379221, 77.68897394980155, 82.4543163853307, 70.14453811030235, 78.56090899436705, 41.69375942599389, 37.57434898807157, 52.662345978521536, 40.01284730049872, 34.61598365537582, 13.330334867200545, 3.372930196985122, 12.236351505402597, 13.421074978766905, 10.525155740399516, 17.87602359248746, 32.25746639313237, 26.180787355669086, 4.421162787945041, 0.4043869572060724, 0.11704786199956171, 0.04331363447671456, 0.13750737382759973, 0.06122509190332025, 0.11209033084132018, 0.10453946182444211, 0.08981399553557558, 0.03339441230280265, 0.13912412578300123, 0.039564055435719996, 0.0713866161963632, 0.04179354366515914, 0.015262513075985256, 0.07423539075159258, 0.0768736673278674, 0.04741919542392416, 0.012583703745246656, 0.09953287039552966, 0.0908777928881107, 0.03757430676130518, 0.0842912600285584, 0.034841475782976035, 0.08863888560764252, 0.11405084177010483, 0.08234574910133116, 0.012882547941239131, 0.06193731235520494, 0.05437714303092611, 0.13464660233547612, 0.02693883068258724, 0.035729172504356796, 0.036482328864475416, 0.152981614453658, 0.04097975144583372, 0.0405283073233741, 0.04272441327151272, 0.06698243800670871, 0.05669803704105078, 0.07299743097035155, 0.09552228519873274, 0.0363496003011542, 0.04281854249476906, 0.04523559586114941, 0.09548290061854547, 0.009175784596722693, 0.0399747092066513, 0.07332340904301213, 0.060855416175458706, 0.08596902322624961, 0.3124828210040447, 5.221823953813122, 50.00128061540666, 50.79106946145335, 52.94538421015586, 46.1139528982101, 42.77539222471176, 22.497864154077348, 1.6398440517725485, 0.42591810346611086, 1.5214267156777845, 3.961578920002907, 1.4477234189548802, 0.05421817595619829, 37.60829710191296, 71.92824379090341, 55.41285314867574, 71.15621935936713, 46.26237538553054, 81.45838737487793, 95.95357694933492, 80.42350138387373, 87.62982106977894, 83.03943987815612, 86.48873298398911, 84.90110658830213, 87.79568241488549, 93.47263859164332, 88.14951942813012, 93.18623496640114, 89.66751590851815, 88.9588769789665, 85.43920870750182, 81.73664031490203, 81.94557712924096, 83.49932209137948, 86.26315747537922, 83.61001922238259, 79.08977000944077, 77.82857110423427, 69.44497554532944, 37.97161840623425, 23.002437853044082, 33.024026963018606, 39.71349593131773, 52.960038185119636, 42.849242610316125, 24.78987370767901, 15.974895877222862, 5.84612996347489, 6.674250172030542, 0.8810488555219866, 0.19983297784722623, 0.01965182915990872, 0.2614270751514743, 0.19666521960208494, 0.22082489013912218, 1.8983637926078614, 2.087442504782831, 4.634458826434228, 1.2889445260647805, 20.754276475598736, 6.809966631474034, 34.09090772751839, 2.574965660610507, 2.756496384259193, 6.833508206952003, 0.9183898808494692, 8.212375765846621, 10.67776143550873, 0.6611173924419188, 10.822516506718053, 4.443282994531817, 1.3742694378860536, 0.7978249245112943, 2.037515758026031, 0.3337544473188539, 0.7125676735754937, 0.5123233831217212, 0.22229656036342346, 5.46451521496619, 24.97373284832124, 23.823978285635672, 47.273111343383796, 46.32700427885979, 51.0411911626016, 25.15235366359834, 29.773878474389356, 31.873219243941772, 61.28673191993468, 79.9061329134049, 69.73033582010578, 75.72277607456331, 79.9625522859635, 75.31779919901203, 71.92061870328843, 78.66850745293402, 79.8192367246074, 78.77908691283196, 80.19012820336127, 81.8187355226086, 78.27415235580938, 78.45699756376206, 76.67068742936658, 76.85028491481658, 75.72067368415095, 73.72752128108856, 76.45438440384405, 80.56447921260711, 85.26859344974642, 72.58813550395351, 81.87713176973405, 51.652665138244636, 45.62311926195699, 61.8948640361909, 47.094584664990826, 48.088113184898134, 23.463259473923717, 8.142552673816681, 19.723220679067797, 22.279988258115708, 21.660926457374327, 30.311888417889996, 47.11188231745074, 35.15475257750481, 6.526418001421037, 0.46513969078660017, 0.32075286272072023, 0.07703040891717519, 0.1219194763970952, 0.11168251159570872, 0.0955918996084121, 0.04064627720283405, 0.04813551444620375, 0.016848518092545773, 0.11601350540595672, 0.06036206704354095, 0.09413321457442739, 0.017430118638120832, 0.029158731321654016, 0.06595810950403252, 0.04104226805089463, 0.012035141699016096, 0.03419196728857295, 0.06689673575061945, 0.055162873449585134, 0.08416180649111349, 0.05931972015288569, 0.009049330293501337, 0.04092574607761156, 0.2003041372424172, 0.19068208823521293, 0.0945781277973325, 0.16843939951110273, 0.1467236567048296, 0.15430198231291387, 0.11059144917394846, 0.2075454607726105, 0.14274133249155938, 0.1567579223023307, 0.21187997092643093, 0.10813950816349638, 0.16324418957435316, 0.27586918083890793, 0.10170474498262329, 0.19340710894715404, 0.26350424594936833, 0.17218780643757314, 0.1324152027166659, 0.18374255738191067, 0.1575572124772495, 0.12912946693118543, 0.21194524161757963, 0.12283872828007707, 0.1931384112685919, 0.23706275188634474, 0.545955746164245, 6.144937103794468, 66.56067632859754, 80.69459207596319, 77.70445946724185, 71.09150025152391, 66.3301194098688, 33.98959290596747, 1.4859336782847683, 1.942690252777069, 7.513221127371635, 14.433540701866152, 7.962553145424013, 0.11809642952416213, 44.94065430856521, 89.64388755060013, 75.10006843074676, 82.12510401202788, 55.68401444342829, 83.64621485433271, 96.4071519913212, 82.62843824202015, 88.53307231780022, 83.37272367169781, 87.03112617615731, 84.14277907340758, 83.66716815579323, 90.96112143608832, 87.58704370067966, 90.18187984343498, 87.4663523704775, 87.84061708757955, 82.45564214644894, 82.55214029742827, 80.11623074931484, 82.30002603223248, 84.34576957456528, 82.37288798055341, 80.42555670584403, 77.43873457754813, 72.2466931804534, 70.98361153756419, 28.00308131402539, 38.96626087927049, 45.15958139973302, 59.70653841572424, 46.24305379006171, 35.657047379401426, 22.444678775725826, 13.143102488210126, 9.744843340689137, 0.5393811183110361, 0.18872672541727945, 0.12591774290006968, 0.607226845477858, 0.23684927382536475, 0.28310506514483885, 2.584848072259657, 9.58155507041562, 4.122340448441045, 5.534730544013362, 56.66290075548234, 10.072373997780586, 45.833209253126576, 5.071106389645608, 6.4025721050077875, 34.42696463677191, 3.3527542602631355, 13.963879039210658, 22.129200581581365, 15.962855181386395, 14.96819603827692, 11.368626144624526, 3.56444874598134, 1.2143708308858256, 3.263858152974037, 0.8725599271635857, 1.5328042858069943, 1.564523512797971, 3.5143130104387965, 3.070908184013059, 31.45104277518488, 27.732284799698864, 48.52626938973704, 54.857367084872344, 56.114816204194106, 34.39380491933515, 28.714177608489994, 34.061717448696015, 60.898609469013834, 74.2232382682062, 70.97781427444951, 72.95568512332055, 76.73775995931318, 73.13196428360479, 70.99049921958678, 76.15688831575456, 78.13747344478485, 77.90040539157006, 79.66524447164228, 78.31576870333764, 78.30981454541607, 79.72285624473326, 77.21914460582119, 78.36402170119747, 73.76682343021517, 74.65793102018296, 76.09012957542174, 78.86057807553199, 87.135280793713, 73.9382859199278, 83.32403136837868, 56.2246504137593, 57.02264878057665, 70.83150202228178, 56.37737966352894, 59.554691699243364, 22.434286455954275, 6.378694186287542, 19.718474611159294, 30.21423709008002, 36.971414012293664, 41.46867813602571, 62.55242193898847, 43.626279830932624, 9.57866036122845, 0.7050413806592265, 0.3783372098640088, 0.16965827604214992, 0.32886383394079827, 0.1763291551821655, 0.15649968938481423, 0.19424672599040693, 0.14802295714616776, 0.11598793339104423, 0.2227267646981824, 0.08360827732230387, 0.15234769201807438, 0.14782357510299454, 0.09052756813264663, 0.18740548421778988, 0.23624132177041424, 0.11196405656876103, 0.09862189226213003, 0.2791518369509328, 0.17753652507259002, 0.21948713208398513, 0.215897596471252, 0.1451341468360155, 0.22680468136264434], [0.024531818813674396, 0.1266535703513411, 0.07333647850300036, 0.052515878792732, 0.06477184533592194, 0.07035408289201799, 0.023182123193457242, 0.04093922156419966, 0.06604333678560873, 0.03818179150262187, 0.1435839066342, 0.06774869447033252, 0.015192370065638136, 0.04774590894099205, 0.08612338994299212, 0.062460021806820754, 0.09872129217030541, 0.06436166653950369, 0.0676867486007752, 0.022821667333764416, 0.22169841423390374, 0.038590897775946126, 0.03807644292171444, 0.07256459129313308, 0.14376563801159783, 0.06008473555407217, 0.1219330438142342, 0.134297480746623, 14.237344726439446, 28.68129441815038, 19.40664226009, 22.14691596646463, 26.560561041678152, 20.374842074609575, 7.538579250535658, 1.6292597810106895, 2.0979429348822562, 4.936448479852369, 0.28868993804339443, 2.1354493739143496, 47.6893061976279, 55.735456328238214, 54.338033506947184, 50.112801444145944, 48.231075732938706, 92.31445681664252, 86.3540074133104, 85.17273072273501, 81.954159275178, 89.47386849311091, 84.74057966662993, 81.34202634134601, 82.51319116161716, 87.47865292333788, 90.08424420510569, 91.54437788071172, 91.01371257535874, 90.15191293531849, 83.15168242300712, 86.56439550461309, 82.92294548403832, 88.29099932024556, 86.37679638401156, 84.88373048843877, 80.29120768270185, 81.0919830876012, 75.32926036465552, 55.19409471942533, 34.16418152470743, 32.5733740868107, 36.64034635789933, 43.49045207423549, 31.14063032211796, 22.40064428698632, 7.047261691862538, 2.5252197106038374, 4.456904405547727, 3.4993214664920687, 0.055096062921708634, 0.17202980846406954, 0.13480573411910765, 0.1228732941672206, 0.10897268240730609, 1.0342752044239352, 0.9003094091050087, 2.9511214504318857, 1.1613090071947345, 3.0640830147650937, 3.265066488135246, 20.831545206808276, 3.0717255078977157, 0.6710601718195024, 7.825354520351657, 7.97494440309463, 10.107796922806772, 4.68696024148695, 0.5304661224926672, 5.017383156284209, 2.9574575491489905, 0.7642726023350993, 0.5192787873168145, 0.49212342188242947, 0.509389297015244, 0.6302855404153948, 0.3826996515835486, 3.8430365583589, 7.588944444733282, 16.320151725123008, 18.685177180074877, 29.755317818733957, 52.87606416210052, 36.37719062066848, 27.132505370724587, 29.472440404276696, 46.233702859570904, 78.33810267909881, 66.16191248739919, 72.78724285864061, 75.78121154539048, 73.6575226629934, 75.95330161433067, 77.01855459520894, 73.81267593752953, 76.57134163764216, 72.36383868801978, 77.82903394391461, 75.20231677639869, 76.50049578758978, 72.0556894425423, 73.63733814608666, 70.57763837998914, 74.49670591662007, 72.95774044529085, 76.36687632529967, 74.21692325222877, 74.178664453568, 69.07140116537772, 78.46426963806152, 55.97626240022721, 34.51673984527588, 50.62909518518756, 43.82793280386156, 32.916652079551454, 27.233355391410093, 24.162255256406723, 20.560995801802605, 12.678266321459125, 18.024595129874445, 34.900029936144435, 37.21723287336288, 15.336494830346878, 2.028411323985746, 0.10056249256576262, 0.37085268406137345, 0.04245254398894407, 0.07426513028481314, 0.022191276563511744, 0.19889493382746176, 0.05928980441944254, 0.031086930577012322, 0.056647007924414454, 0.06566403899341822, 0.08028253642541748, 0.04745268495753408, 0.1035855521237658, 0.0095228138079326, 0.03530259942635894, 0.15105497993288503, 0.06754709843305812, 0.0480619125488785, 0.06245119264349342, 0.13597224087965104, 0.04135971573451835, 0.0877637757108577, 0.10707228639793974, 0.03558569572745793, 0.038871818387340155, 0.0695098539994609, 0.043488693228291894, 0.1074077639608614, 0.049577353206733545, 0.0633726661814557, 0.08334740140144864, 0.04646840370109966, 0.02924709764849996, 0.003146457170406657, 0.10744287377043117, 0.008958660914833027, 0.12002318661900298, 0.05601508880875284, 0.08813666134712198, 0.01539378128420081, 0.03589195086650791, 0.028144471129522692, 0.07615928267759663, 0.05566063141750713, 0.18485762899921787, 0.060922544629823785, 0.07101893229710479, 0.05374680971726776, 0.10854809349703212, 0.03558844981354571, 0.09484920800933916, 0.09654928734826465, 17.628451431951216, 42.94275191522414, 43.534108054253366, 53.33371846906601, 48.512670532349624, 40.511651192941976, 17.857380567058442, 3.74833902043681, 0.3952461799546596, 2.0112871138318895, 0.23612418692679177, 4.4342831161714376, 64.28075159749677, 67.64269351959229, 68.19797562014672, 60.1399407079143, 58.68057973923222, 98.91735907523864, 91.64185662423411, 89.65521535565777, 83.50406815928798, 90.80621919324322, 87.88531641806327, 82.91955655620944, 83.47113593932121, 92.40001155484109, 91.03850979958811, 91.68402994832685, 91.78390918239471, 88.68521321204402, 84.97621213236164, 85.82946885016658, 86.01194535532306, 87.87113312752017, 86.98529720306398, 85.99678147223689, 82.65698525213426, 81.83576645389681, 79.34691275319746, 50.34259742306125, 25.509099114325743, 36.11526258530156, 41.40900319622409, 56.14130396996775, 37.13878939228673, 21.172293270787886, 18.262537871637655, 4.891719731592364, 19.39596164611078, 4.009894675785496, 0.7027868145415861, 0.05504619825871722, 0.357993591817156, 0.07583354975307181, 0.03925856255415467, 1.2659044010985283, 1.0894944542838683, 1.1440119676051603, 1.4752093053633168, 24.345529963893277, 6.894091665744782, 30.108868498956006, 3.4409489987357973, 0.7297323331717522, 6.992855966091157, 3.7332131353116806, 13.175186495627127, 3.1387333187364765, 0.47674935491335013, 3.4724662236628996, 6.096021715671786, 1.8868933113351947, 2.144739752815616, 2.0071436200411092, 0.5212468978378081, 0.4948158838575887, 1.5549905598163607, 4.472056521523384, 21.919795044006843, 28.318975279408118, 22.731390307026526, 36.78228516732493, 64.50181638040851, 43.022964385248, 34.68415837134085, 22.09687044543605, 46.00838230502221, 80.36248499347319, 65.63143937818467, 76.02679114187919, 74.14573223360124, 77.25103347532212, 77.20474166254844, 79.5302443350515, 73.66054288802609, 81.4694013903218, 74.62901530727264, 78.7821855852681, 74.53054028172647, 77.23115490328881, 74.80210165823661, 74.94750392052435, 72.90938546580654, 78.17891720802554, 77.24796618184736, 77.4129096923336, 79.39693081763484, 80.46034812927246, 74.32650643010294, 83.63373387244441, 62.40475254674112, 44.041180303019864, 59.882637146980535, 58.700725032437234, 43.76993271612352, 35.93110730571132, 29.608209325421242, 29.2215459962045, 24.96379944585985, 28.737907948032504, 49.37373276679747, 47.748184896284535, 24.018278775676606, 2.732192643227116, 0.06684333176141785, 0.47359028410527015, 0.1048850211044473, 0.018644835311739195, 0.027611739332637483, 0.20973667141891297, 0.05347274176235642, 0.08234669138947803, 0.03077734678593134, 0.033752715455428246, 0.10112219640324194, 0.05092348077244336, 0.02476763599852641, 0.029160148584313934, 0.05070464775687264, 0.02335102451334317, 0.012463640530533608, 0.09450781624764205, 0.023209489769332355, 0.042794154085699594, 0.02418041045236732, 0.10821456945831738, 0.08229494215019288, 0.023647217087507732, 0.18618233291612518, 0.21410413867523595, 0.20870222289475704, 0.3235154983497435, 0.1478153013534123, 0.30313486293438946, 0.20593396418036955, 0.14754171603389327, 0.19114492791554621, 0.1035869310820295, 0.2344231499779609, 0.17592888956348743, 0.22211052357189118, 0.11086049925295577, 0.1490701840169007, 0.1265762950624189, 0.13636660762131214, 0.12673120570158766, 0.1627879229284102, 0.15321151743973457, 0.3379542332503104, 0.23984314543345284, 0.23073770015710787, 0.2025135348160421, 0.24839674693442163, 0.08332464092921826, 0.22871144356266146, 0.20920741191554457, 21.13242433917138, 66.0424449366908, 66.38158875126993, 76.53114518811627, 73.77349930424845, 62.4685420528535, 24.032022760760402, 4.4557982971591334, 4.539589929965235, 10.156551003456116, 0.5253826081752777, 4.25760240324082, 84.60011959075928, 81.39272689819336, 81.90216433617377, 72.70652048049435, 64.16200968527025, 97.45695083372055, 93.09944075922813, 90.5307746702625, 85.9927414309594, 90.44255272034677, 87.49558971774194, 82.60138173257151, 86.09122430124592, 90.98799751650904, 91.56447610547467, 92.3397639489943, 92.30999315938642, 87.18787193298341, 82.08597444718885, 87.23250850554436, 82.89162143584221, 87.61907377550679, 83.72456027615456, 86.16153670895486, 82.52799418664749, 86.53930802499094, 73.08175794539913, 69.10763602102958, 45.81871609533987, 44.87850043081468, 51.02976529828964, 61.00259542465211, 37.38611052113195, 29.172079024776338, 23.74542890056487, 10.630365475531548, 26.80794688963121, 5.1116440853764935, 0.642259004375627, 0.39126898853048203, 0.6631511413762647, 0.1874225066914674, 0.28822409529839793, 3.435473124827108, 2.921314133751777, 6.769990324974061, 6.034286550937161, 39.79060188416512, 14.284541626130382, 41.80876724181637, 6.8740905196436, 0.43810297704992757, 23.32433108360537, 14.458319294837214, 25.69520381189162, 4.826237232454361, 8.409602834332375, 14.517207799419282, 12.192910275151654, 6.815126999731987, 3.403456778295579, 3.6360442590328956, 0.6906890604765185, 2.397957184622365, 4.144656283240165, 7.2199425678099365, 22.278652691072036, 36.457226584034586, 29.067853804557558, 34.6970159007657, 70.14777014332434, 46.79352706478488, 43.11557938975673, 36.53722724606914, 60.61393168664748, 77.65482579508136, 60.93585629617015, 75.73591601464057, 74.61224325241582, 73.3667181384179, 75.13153368426909, 79.51220143225886, 73.90046642672631, 80.45567266402706, 72.53958440596058, 78.0940528069773, 76.14454853919246, 74.83951322494015, 75.17697826508554, 76.09512667502128, 74.16505382907006, 79.24822591966199, 79.85626389903408, 79.48938892733666, 81.05865078587686, 83.74592934885334, 74.79139358766618, 84.3195681418142, 67.41761222962411, 54.8004731055229, 68.20462795995897, 65.92186343285346, 51.61230002680133, 47.393210395689934, 32.759070857878655, 43.05762244809059, 38.00156178012971, 40.05122769263483, 66.1068110312185, 62.31400851280459, 28.46233790920627, 3.8161903860107547, 0.19883436691616813, 0.4980036369975537, 0.07338066645447286, 0.20274699245008732, 0.16264464916481128, 0.3611995472062019, 0.2859569653387993, 0.18023893086900636, 0.12608533995526452, 0.16032498089536545, 0.265508454533354, 0.12111395026647276, 0.32821173989965075, 0.14095872250055114, 0.10703082571947768, 0.29899716076831667, 0.2550375954278054, 0.23733915640942513, 0.22461792934806118, 0.1732046502612291, 0.11756533140977544, 0.15097241097640607, 0.24373447372307702, 0.27117232641866135], [0.045290577991475026, 0.08901289739315549, 0.03711943822582403, 0.03658176707704702, 0.10929011859961095, 0.08080041186223108, 0.004941978615768735, 0.04064501315775899, 0.07933237289469089, 0.07020888624772911, 0.13120018726875707, 0.07548910130055682, 0.059280779903694514, 0.08353622675302529, 0.03226016167431109, 0.07142838330999499, 0.10938598684245542, 0.056313778829550555, 0.03229803706128751, 0.053709600826785456, 0.10785692897174629, 0.06700583433191623, 0.04478667982883992, 0.13667907956386768, 0.04431528294639242, 0.06527591586834, 0.12854275083349598, 0.061018539277175744, 3.287904488463556, 22.2862660115765, 33.114614102148245, 24.52862620353699, 34.50574544168288, 31.117921760005338, 28.060628368008523, 13.84324066100582, 3.0606938417880767, 1.6603759435876724, 0.2969907764946261, 17.085750333724484, 53.43111092044462, 52.31687930322463, 58.33828233903455, 47.00468786301152, 66.4298652833508, 95.78122800396335, 85.5579859210599, 89.12186714910692, 83.58639086446455, 81.84503893698417, 83.98056553256127, 82.49362637919765, 84.71193067489132, 89.00439216244607, 86.62424302870228, 89.60520513596074, 89.25412162657707, 87.54444676060831, 83.92134558769965, 86.24346717711418, 86.0620104882025, 84.91916518057548, 81.53921173464867, 85.44306831975138, 84.35552058681365, 79.51175428205921, 81.98393790952622, 67.97790711925876, 41.41140368676955, 28.811515146686187, 42.074394072255785, 45.63644747580252, 22.34080460763747, 22.947387387675626, 13.007552239202685, 2.2143689326701628, 12.779284023469495, 10.786580731791835, 1.2860787443576323, 0.12644951517182973, 0.4439136007380101, 0.5445862261037673, 0.46684613631617644, 1.1256464498658334, 0.4016143317905165, 0.24158352865807473, 0.8024767942486272, 6.415835599745474, 3.106929025342388, 18.53808045387268, 0.55044348922468, 0.7325171547070627, 5.083955093737572, 3.7501415946791252, 4.278566000923034, 1.0613470356310568, 2.2416399467375974, 2.9371237370275685, 0.7124303293324287, 0.26819199924507453, 0.8667081798757277, 4.964025193645108, 0.6495657058492784, 3.634756986171969, 4.960684314850838, 8.215899525150176, 13.017433670259292, 23.210713748008978, 22.276789565240186, 21.016745798049435, 49.969317220872455, 41.58600015024985, 28.309171315162416, 37.50286379168111, 53.76402993356028, 69.9592924118042, 69.26569969423356, 71.22975595535772, 76.17763765396612, 74.14064884185791, 77.46495169977989, 73.9262991566812, 74.20293608019429, 75.88680959516957, 77.16691432460662, 75.3554774868873, 76.96670870627128, 72.41897936790221, 78.1320684186874, 69.93229866027832, 74.05389385838663, 72.18171519617881, 72.89129549457182, 74.70954156691029, 76.02446125399682, 74.01298353748938, 73.30523106359666, 74.43019036323794, 67.57744096940564, 31.965816597784723, 49.451270180363814, 49.12059868535688, 36.45485355008033, 30.558893795936342, 31.165202010062437, 14.337200426286268, 17.32702316776399, 21.54898789621169, 21.37069263765889, 16.814977353618993, 0.9325315574965171, 0.28570504498577887, 0.11728100553755799, 0.09763959134297986, 0.19979741604578113, 0.05343006683453437, 0.040364575181757255, 0.014990393857231304, 0.02448272215382707, 0.0616878894488177, 0.06210101768374444, 0.1407233649684537, 0.07010518858629851, 0.007687261874502105, 0.10777208473413222, 0.02819813558861854, 0.07797193863699514, 0.037499594036489725, 0.05304871209626717, 0.009570446282234645, 0.07221706316716249, 0.04893663557126157, 0.11017893380936115, 0.06948546942083106, 0.09747548764871974, 0.061400736712159655, 0.017042897581573457, 0.06191072527379279, 0.1327875214478662, 0.08149211264906392, 0.03942231384796962, 0.03409856967928429, 0.06739170515849706, 0.05917901278383309, 0.06311669322331587, 0.09838170071523036, 0.06324345013126731, 0.014852379287232556, 0.06854484368476176, 0.023695991990426858, 0.07363219610265187, 0.0776009758814208, 0.10027469631524817, 0.09322677168153948, 0.012771763008899026, 0.10281993917399838, 0.08275399735618023, 0.11596082920028318, 0.05442724901161367, 0.18828103078469155, 0.03744682206982567, 0.07718917297860307, 0.09178986652724205, 0.046544043392303495, 4.796781703349083, 31.490778346215528, 43.94907128426337, 49.907096662829005, 61.33624007624965, 51.02158323411019, 46.68494016893449, 22.81817666945919, 6.93531479566328, 0.842341864781995, 1.0959878155300695, 30.181432347143854, 69.46312827448692, 65.29182487918486, 70.95372307685115, 60.76680998648367, 77.2940226524107, 99.53406549269154, 92.59804418010097, 95.10414062007781, 86.30874326152187, 84.3629809348814, 86.40196231103714, 86.11044391509026, 87.27769420992944, 86.64404315333213, 89.086518749114, 89.28770495999245, 89.58790748350083, 90.42360767241448, 86.70331801137617, 89.39928854665449, 87.50016320136287, 87.16360815109746, 82.0964236413279, 87.9427085384246, 87.87139200395154, 79.52548257766232, 82.93363002038772, 73.10558242182579, 30.251385857982022, 30.661857974144723, 50.96221031681184, 56.395665753272276, 29.26593153707443, 21.74652826401495, 20.524662886896444, 6.398205526413457, 16.900304594347556, 24.056539535522464, 1.106564118977516, 0.10277691567617078, 0.5319506783158549, 0.6681143492460252, 0.9713383848148008, 6.464798056310223, 0.5671801201758847, 0.5545248992500768, 3.4953245712864787, 38.21170276211154, 6.045241240532168, 22.078778513016243, 2.540073726446398, 1.4064397374468467, 8.441501509758735, 1.000757202986748, 13.42082885003859, 4.1724340185042355, 6.36228544096793, 10.606101693645602, 1.672183993843294, 0.4503159200952899, 3.8412300617464132, 7.829075869052642, 7.488379776477815, 9.19660875874181, 12.066001007633826, 12.739659259396216, 18.450111496833063, 27.74208680275948, 21.654817365830947, 27.065458336184104, 58.88212680816651, 48.81024506784255, 32.38297047153596, 28.6312488971218, 54.78932965186335, 72.40048147016957, 70.3224411318379, 68.46270422781667, 76.59405216093987, 76.22767925262451, 76.71411591191446, 76.03562431950724, 76.2912687178581, 78.48311270436933, 79.94024184442337, 79.45656653373473, 78.03605664160945, 76.61332668796663, 79.4129183984572, 74.15085484904628, 72.83107142294608, 75.38387544693487, 77.6467300230457, 78.09710441097137, 78.47188688093617, 79.82257073925388, 77.48862712613999, 80.02625157756191, 73.24639551101193, 40.22824818088163, 63.81442100771012, 62.59186529344129, 51.36300986812961, 37.90216891996322, 36.87485702576176, 25.46461355301642, 31.110608500819055, 35.30074319531841, 31.412246611810502, 21.0482188963121, 4.587812529456231, 0.06845023182611312, 0.03923042797513547, 0.34338481604091586, 0.24387693543347622, 0.02771531633522001, 0.03793435276395852, 0.2510926103399646, 0.07061820702567216, 0.059673166308071346, 0.10090449719779915, 0.0826394672115003, 0.08458005219337442, 0.0929862890212286, 0.007725513602171334, 0.02231350206139107, 0.07280691256446224, 0.008618596400464735, 0.029992187102775902, 0.009750820726396577, 0.0326265930198133, 0.029305272450250004, 0.06205836573856012, 0.10680063928086912, 0.16095464388209005, 0.016624469933430516, 0.15577984252764335, 0.1607798992265617, 0.15375665028489408, 0.12028937152917347, 0.13811442189879958, 0.21434773931339865, 0.26607477737049906, 0.33912573490412007, 0.11400549702586667, 0.2335895084205174, 0.23375913560871156, 0.16092507288821284, 0.23496771591805646, 0.14498325815844923, 0.1332742017844031, 0.2855830531447165, 0.21792581425078456, 0.20314932650616094, 0.17143638143616338, 0.21560439930087139, 0.20689987847881935, 0.16268255519530467, 0.1737218975059448, 0.2231540119335536, 0.22406996197758183, 0.20834099711670032, 0.3776192935484071, 0.15832343829735634, 3.4045268499082137, 34.99113875050699, 63.82407396070419, 78.20005878325432, 93.29460220952188, 76.04558713974492, 63.111234172698, 24.07123665655813, 9.041223083772968, 3.5695586137233244, 0.6929865888049526, 34.93792787674935, 89.42979674185477, 78.57116206999748, 84.19049078418364, 72.88279964077857, 80.90729436566754, 101.66612471303633, 95.41415691375734, 96.75578009697699, 86.84097751494377, 83.99867903801703, 89.30872886411606, 85.57369893597019, 88.51935971167781, 88.70047123201432, 89.19001440848075, 90.1782947970975, 87.28017314787834, 88.23465839509042, 84.2180964254564, 87.88781104549285, 83.56905398830291, 85.71596330212009, 77.69557137643137, 89.71928335005238, 88.30809300945651, 83.98088716691541, 77.52779591468074, 80.37661337083387, 57.05308637311382, 39.111376808535674, 55.970657333250976, 61.56904451308712, 31.428304795295965, 29.460608574651904, 28.42965868211562, 10.842486273857856, 26.93636921144301, 33.1970937021317, 1.38555274855706, 0.2942745045067803, 0.472971867289274, 1.055060824559581, 1.372029029073254, 13.822956123659688, 0.9655736651151412, 0.2781779553380705, 6.215842279695696, 37.42610692977905, 16.564028032364384, 49.356548863072554, 5.673661385813068, 0.9888540352544478, 10.5103733078126, 11.813273872098616, 19.211725957932014, 4.39806051792637, 4.692139731299493, 7.929320373842794, 1.5978499309670542, 1.9444357075037497, 8.524787156812607, 19.253683551665276, 16.830686446159117, 21.258895281822454, 28.131156506076938, 19.18814859082622, 26.595970238408736, 36.42138396539996, 31.98350060370661, 26.86050664994025, 64.98682137458556, 50.909952579006074, 41.166639943276685, 47.43892562004828, 66.27653983331496, 67.7349005976031, 73.7118318003993, 66.15573083200763, 75.49352138273179, 73.19932706894414, 75.92403288810485, 71.37680561311784, 75.50984628738897, 76.38831600066155, 82.28680764475178, 77.96939203816076, 81.46758141056185, 77.29013166119977, 82.261979041561, 72.56643695216026, 78.83376475303405, 75.24250538118424, 78.80784573093538, 77.98572478755828, 79.72662172009869, 84.39508161237164, 80.92290539895335, 82.22685029429775, 74.52981072087442, 48.29296288951751, 71.99727750593617, 71.23709078757994, 58.642356241903, 48.302815883390366, 51.125937892544655, 39.65068701774844, 43.76928944741526, 55.27455822114022, 49.49559296331098, 27.791406685306182, 7.655608067589422, 0.7085189908262223, 0.09659270921181287, 0.4441084935059471, 0.36460882233035186, 0.22912687772224027, 0.13358164819017534, 0.49545238034859784, 0.12772623134116012, 0.2258327302913512, 0.3264611983491529, 0.2890209493137175, 0.16390677902006334, 0.1903582475478611, 0.15154524556090757, 0.10952248072792446, 0.19395277805386052, 0.13300421707812818, 0.19089797181227516, 0.056548163429984165, 0.12805998520625214, 0.2567409153186506, 0.1535468800894676, 0.38906590352135323, 0.34722193594901796, 0.15975599207224386], [0.028115007387954864, 0.10167476030126696, 0.08405655367119659, 0.0648621134760399, 0.02857832395802102, 0.09637006873925848, 0.09171319644778006, 0.12287933094006394, 0.0593841175038007, 0.06243757926107896, 0.022416295739071026, 0.02685915753846207, 0.09889825081993496, 0.08140524593932975, 0.08661632155699116, 0.06865780334919691, 0.0628652593361274, 0.021595815572166638, 0.09390582435674245, 0.09157091093760344, 0.012537695377344086, 0.026981022975016988, 0.12157446870039548, 0.06846921548487679, 0.0439283587489157, 0.2506307359304159, 0.25627003171511237, 0.08401430392217252, 0.22425699468341567, 6.397160214762534, 30.275292704182288, 34.65016711142756, 43.2920507461794, 42.20629161404025, 39.293633660962506, 36.39633570947955, 21.40657251881015, 7.003322810895982, 15.885965939491028, 38.9042874305479, 57.93612957000733, 59.74036101372012, 58.62509781314481, 47.330287733385646, 83.92435012325164, 88.29753398895265, 91.25301637957173, 89.55876427312052, 81.72826997695431, 86.36714735338765, 84.66940433748307, 83.4976197827247, 80.42574497961229, 85.30969988915228, 87.9386841866278, 87.13993272473736, 90.67373721830307, 87.029980844067, 88.79150159897344, 88.3953579010502, 89.94503928769021, 86.20799326127576, 85.84537013884514, 84.49722797639909, 86.62891849394768, 80.76368070417836, 86.7390194246846, 72.05116302736344, 43.05734003743818, 35.64300529418453, 47.79501407377182, 45.127908260591575, 20.7611818082871, 20.2846707067182, 16.147482125989853, 1.9323063906162017, 7.328250975378099, 23.532316723177512, 4.745714404890615, 0.2344292327160797, 1.3268760519642986, 0.26592897551675, 3.449245547094653, 3.411892325647416, 0.05008004095044829, 1.3981103392377978, 1.0564749615807687, 31.86119717936362, 0.571977301470695, 10.805835646967735, 3.088762813037442, 1.7098017301290267, 5.752321087544964, 6.3325337729146405, 4.01042468605503, 0.7297518837355799, 7.638588413115471, 4.127465025071175, 3.185776020250013, 0.5899594688127118, 1.4587493240833285, 7.114720084974843, 9.720777638496893, 1.590299368385346, 2.748088783794834, 2.943155852056319, 22.09024948458518, 25.945137239271595, 24.765876646964784, 18.36714356176315, 36.63095620370681, 46.26925522281278, 34.69006153845018, 29.121774627316384, 55.153886502788914, 76.20777714637019, 67.00180961239722, 70.70047132430538, 72.00233736345845, 72.4354454778856, 75.8927402188701, 72.85976748312675, 76.77193949299475, 77.44055455730808, 77.97051383603004, 72.1445546611663, 75.60286137365526, 71.86491320210119, 73.83243683845767, 73.09398789559641, 72.82579975743448, 74.26771010121992, 74.18810952094294, 75.0879483069143, 73.62390010587632, 73.39055830432524, 75.32772279554798, 71.14929245364281, 68.2514218361147, 37.82210550000591, 45.335342807154504, 52.999403092169, 35.487824563057195, 33.2436522360771, 13.531910373318581, 18.47698953843886, 22.704325952837547, 18.43699509097684, 14.974147254420867, 5.995385464160673, 0.4488901385376531, 0.12559535011889475, 0.15095284509081996, 0.1943019149644721, 0.02703006026305018, 0.14174486660668928, 0.0668355712907449, 0.14356052563075097, 0.14564452993292964, 0.04553521667877513, 0.04430779443693258, 0.07246670057816852, 0.08308536868782775, 0.04634219071557445, 0.06795839571784582, 0.012061595672651405, 0.05771999833204093, 0.01944290740685838, 0.0833262573747385, 0.02842394191952002, 0.04536065205390896, 0.04392538249732987, 0.08123674490038427, 0.10220424963101264, 0.100276205508459, 0.024359858887750777, 0.024675075340295033, 0.06541000423772682, 0.10994622694148172, 0.02814769635968391, 0.04566037246296483, 0.032552328456433556, 0.04319390259502877, 0.1840187320786138, 0.00873674248014727, 0.05358971189707518, 0.022403345022711064, 0.045811284123168844, 0.08518058085633863, 0.052053540899989106, 0.016770302430696545, 0.05771419521601451, 0.01266479510964165, 0.07873696935994011, 0.061066132489471674, 0.04036792681642598, 0.02251816819602203, 0.1826665256052248, 0.08468449296009156, 0.016740585880113706, 0.027027959266917843, 0.14511770658916043, 0.1676851859496486, 0.11253443201102557, 0.5660908044345918, 12.908740870414242, 40.53999031743696, 56.374947794022106, 63.54007082600748, 62.906768860355506, 58.664478409674864, 52.79280793282294, 31.28856839672212, 13.461635228126282, 25.575322451130038, 57.308809218868134, 78.40737173634191, 77.8764710887786, 71.51216660776447, 58.0229708456224, 92.84631452252789, 95.18703599129954, 96.65668533694361, 95.14372517985683, 85.34120436637633, 91.04580540810862, 87.76420147188249, 83.97340328462663, 81.7996100456484, 85.79055109331685, 90.96725602303782, 87.44001757714057, 90.49333172459757, 89.86787057692005, 91.22350446639523, 88.52223088664394, 90.65567078128939, 88.9135108455535, 84.66084572576708, 86.1678752591533, 90.43618279118692, 83.26015949249268, 86.49032546627907, 79.30043266665551, 38.536063163511216, 32.946211061170025, 55.21700136123165, 56.53332917921005, 24.234548461052682, 23.020041450377434, 19.77997345309104, 6.394086057139981, 11.295963256589829, 31.747118965271984, 9.114555716514587, 0.7753333184988268, 1.047506707329904, 0.31248101303654335, 2.460628079791223, 7.7014939150502615, 0.7463736014981425, 1.0518862787754306, 1.819308176636696, 39.759854424384336, 10.063887949912779, 10.565852292122381, 5.011238763409277, 3.583501659093365, 6.576645422366358, 2.262691797748689, 10.593147085558984, 2.051817945414974, 10.470950545803195, 3.674284426435348, 0.3246771327910885, 0.4023172634263193, 3.1069927638576877, 15.571249665752536, 9.918784768350664, 3.0290074646472935, 6.094596914706692, 6.494325168671147, 19.860578160132132, 25.31138420104981, 24.022326661694436, 24.191800509729696, 45.33032217333394, 52.76608090246878, 36.663982560557706, 27.19303538722377, 57.942523033388206, 79.44472882055467, 68.64995817984305, 70.82735999937981, 72.65065808450022, 76.85935343465498, 77.24337700874575, 74.48610767241448, 75.58217479336646, 79.19170456547891, 79.2722543593376, 75.12419100730651, 79.36151181497883, 72.70188423895067, 74.19153767247354, 73.12782226070281, 75.26749872392224, 76.9461319523473, 77.20747163218837, 77.38028341724028, 77.08926708467546, 72.16214256901895, 78.25704297711773, 75.80385931076543, 75.52481405196652, 42.659427350567235, 57.67849260760892, 59.66657338603851, 52.375761924251435, 40.01988403258785, 25.64934934339216, 26.872244342680904, 36.86782813841297, 32.08705313744084, 17.39397018186508, 7.515517184811254, 0.5810112554219462, 0.014398383134375177, 0.10790346115226708, 0.14637812040746212, 0.09849206334160221, 0.15470574129252665, 0.0066518777654686525, 0.10677848401809893, 0.16287184019963588, 0.013520552667849248, 0.03924480744547421, 0.04852700069726956, 0.06413758965209126, 0.04046746078998812, 0.04787547356118599, 0.06699857181839405, 0.03782257670536637, 0.012610941043784542, 0.06905222371701272, 0.027167594112876444, 0.04551298863765213, 0.045884529789609295, 0.06145404110993109, 0.07622099872077666, 0.06566492765541039, 0.03600614776294078, 0.1610578665690076, 0.6587880561428686, 0.3619357883449524, 0.11869688923921316, 0.11901211143741686, 0.29449826346770414, 0.22612508476501514, 0.3606712836171351, 0.15296938769038648, 0.2928569966987256, 0.1386966793647697, 0.153569326465649, 0.16227381664418405, 0.1243288075971988, 0.21590537992456268, 0.18864807883097282, 0.16498373010225836, 0.1689020400085757, 0.2157625964572353, 0.18429112230097094, 0.19437259423636621, 0.21351408243419664, 0.1191521829534923, 0.20480367805688612, 0.07634294459656363, 0.415602024764784, 0.2110230402960893, 0.17468592722810086, 0.3946594178916947, 11.737106346314954, 51.31451760568927, 80.44169333673294, 92.93233994514712, 93.24139133576425, 79.82351210809524, 66.46346430624685, 34.26449614186441, 15.363956324515806, 26.63453302075786, 69.76549594633042, 94.32566781197825, 86.34351115072928, 85.30864869394611, 68.89672233212379, 96.4360284805298, 95.92860714081796, 100.03453639245804, 98.52126244575747, 87.74895129665252, 90.58043187664401, 89.2076180058141, 87.91753476665866, 83.87265328438052, 87.21787022006127, 94.18694926846413, 86.5640111123362, 92.9044597379623, 87.53682951773368, 91.73421275231146, 87.82244866894138, 90.57679976186445, 87.65231978508734, 81.78935697001796, 84.79987805889499, 92.86246684289749, 84.46304844271752, 85.78887231888311, 77.85070896148682, 61.824814427283506, 46.284740740253085, 60.6276874388418, 64.00228684948337, 26.74756984556875, 29.68605268386103, 24.71454066614951, 10.384402467358498, 16.929084985486924, 49.118759093746064, 8.15567986619088, 1.7813854760700658, 1.6353123659087767, 0.694977130380369, 11.589027066384594, 15.420319803299444, 0.4409352960365434, 1.2444246440164506, 3.58089818589149, 60.191614012564386, 16.11664935465782, 42.11915616066226, 13.383160368088754, 2.5046503111239407, 8.16687431066267, 8.988128900527954, 9.536551756243552, 0.799603229088168, 17.986901152518488, 9.86595436449974, 7.9120423332337415, 2.6004225784732453, 3.6398416036559693, 18.08163619810535, 26.244125789211644, 11.418514770846214, 14.406152752137954, 18.55326198762463, 30.528452281028997, 36.92083112655148, 32.907948340139086, 28.82044638356855, 51.13278635086552, 58.21769691282704, 46.691490527122255, 44.67675724337178, 63.05150824208414, 74.62091169049664, 67.03523605100571, 68.04602299967121, 73.79345632368519, 76.83541128712316, 76.91364688258018, 74.23140464290496, 74.53762408225768, 77.36894776744228, 78.88201775089388, 73.41999961483863, 78.07730428634152, 72.38766316444644, 77.93804445574361, 72.91153492466097, 77.2132061373803, 79.17305761767973, 78.42168054273053, 78.56356051660354, 80.9884403597924, 75.05772252236643, 80.06013301111038, 76.12317162175333, 78.03734317902597, 52.97678670575542, 69.95742536360218, 67.85125378639468, 63.91654383751654, 52.366222719992365, 35.97876802567513, 42.971471509625836, 54.8595126213566, 49.18927154233379, 24.69906887700481, 8.5575242388633, 1.246941212204195, 0.15174767663401945, 0.2602771771771293, 0.3276622709968398, 0.4395981968170213, 0.15220484726371306, 0.10938663035631181, 0.1680978621927, 0.25615444436909696, 0.17359766868814347, 0.23274832855789895, 0.24980397384253242, 0.10037113912403585, 0.16611614595017127, 0.16790512979270952, 0.13414073915731523, 0.27860420665914015, 0.0981417236729495, 0.18027251616360682, 0.18470430416205239, 0.15230951019592825, 0.1282830470271649, 0.20844543022253822, 0.45574411269157167, 0.20264603738342563, 0.0949427473448938], [0.06168082611815584, 0.1030510679007538, 0.06652054061452228, 0.13800885498283372, 0.005302871624383355, 0.09996531170702751, 0.028572568722489863, 0.20193322321339963, 0.0780877787920256, 0.020388962791091012, 0.10387910935547083, 0.039527754359427965, 0.009435383065964186, 0.03379599559271047, 0.04319598252374319, 0.06869056126883916, 0.10822007763049296, 0.04109838399134817, 0.03653271063681572, 0.09175818113069381, 0.0304934173642147, 0.11180949066915821, 0.033875879411014824, 0.045817435809200814, 0.09295360004949955, 0.19002409531704842, 0.04641302320505342, 0.1587370185241584, 0.15596966379352156, 0.7928669260394189, 17.31582283973694, 42.72781779689174, 61.69222262597854, 66.41822368867936, 48.67437808744369, 47.36069394696144, 43.37975886560256, 22.99423029345851, 31.281139427615752, 50.69027239276517, 65.64316726499989, 75.68681578482352, 54.20867766103437, 50.76957879527923, 86.19665761147776, 84.89119083650651, 86.30656242370607, 82.5361527166059, 86.12185016755136, 84.66934157956032, 85.6840979668402, 83.52200908045616, 84.10740713919364, 84.44167152527841, 85.95093680966286, 88.68352659286992, 85.15642150755852, 88.77505902321109, 92.10719877673735, 88.02144619726366, 87.75305409585276, 83.31935590313327, 83.44389115610431, 81.83686471754505, 86.08587418833088, 80.45002445097893, 78.20991177712718, 82.3907426095778, 41.309033747642275, 35.25744022861604, 53.42851431139054, 34.3215391712804, 20.614471435546875, 21.715506238322106, 14.78425648904616, 2.7572460472583775, 6.249965429306031, 11.723167223315086, 6.089383104155141, 0.2895854948268783, 0.12244584774898908, 3.45033057274357, 2.8115367985540822, 0.6150720148317276, 0.42577928833423123, 1.2310345302666388, 0.6265350190862533, 31.714533875065467, 6.239438278059806, 0.4005442908213985, 2.412413815336843, 2.9693773869545232, 2.932022939766607, 5.624120869944173, 2.493070984078992, 7.417160320666529, 1.9931890527086875, 0.43039365040679134, 0.6746106522698557, 0.09616813562329739, 0.15477427551823278, 3.309979097497079, 3.847648530237137, 1.664289120704897, 3.494182916418199, 0.8286063985959177, 17.316821082945793, 19.66897429958467, 25.351870905968454, 25.687196293184837, 14.602653691845557, 47.79996410492928, 42.63887805323447, 25.988955997651626, 57.488693037340724, 70.10260797316029, 73.19635391235352, 70.7743844678325, 76.69166426504813, 71.07317493807885, 78.01678995932303, 76.32118071279218, 79.13482235323998, 75.02480599188036, 80.32215518336143, 79.25549799396147, 72.6021069865073, 72.20059748618834, 73.2674664835776, 77.89745576920049, 72.90304691560807, 73.37264091737809, 78.25402275208505, 73.58067558657739, 76.4122110797513, 75.76579663061327, 78.7445935895366, 74.4338381674982, 69.89600104670372, 31.69618306621429, 47.52327226823377, 47.30790668918241, 42.85705989406955, 27.804426993093184, 18.951298229156002, 17.389810508297337, 9.592439647643797, 4.471851087385609, 3.444014576173598, 1.1494822031067264, 0.05162494918031078, 0.06787980275769388, 0.06887668999092234, 0.09391569156920719, 0.0617759435948345, 0.1792564997149091, 0.03542317783520107, 0.05867141058608409, 0.032771364485304204, 0.09877222169551159, 0.05602211383501849, 0.0391106999238893, 0.07878950766978726, 0.05690668874810781, 0.06224937444072097, 0.06828885540486344, 0.10445428816902061, 0.03709314991870234, 0.09169486396375204, 0.01785952049577909, 0.025816515703955968, 0.037493580246284124, 0.11015619631976852, 0.05644976326654996, 0.14255681255411717, 0.005377870674560508, 0.07412940248726838, 0.11745082424773325, 0.05018111476073823, 0.1510015682828042, 0.09759649123635986, 0.024817797520588485, 0.04965266731056956, 0.20486628276205834, 0.0462396843208661, 0.05204000029592745, 0.04771560250270752, 0.034662621065733895, 0.07110846499281545, 0.02359352198489491, 0.023212820336583163, 0.11008801449450756, 0.11353279779394788, 0.02937389860650705, 0.05256681214837779, 0.08905133968519588, 0.05031769291587895, 0.07004253791585084, 0.13969958038820376, 0.019693954419645093, 0.09956857775368037, 0.14332982591323315, 0.15665989369153976, 0.1730042569819958, 0.1440659291561573, 2.3533554230966875, 30.706216058423443, 54.937450116680516, 78.7068368542579, 84.58453993643485, 72.61669035880797, 68.477734750317, 62.76573611843971, 40.711543021663545, 48.5606332748167, 66.45077936110958, 83.14430836708316, 91.48936271667482, 69.07490776431176, 62.327156297622196, 95.93053694694274, 90.56107890221381, 96.07708454132081, 90.43053457813879, 92.10505716262325, 90.61238350406771, 89.34323003215175, 88.30925403102752, 87.43602460430515, 87.02144576657204, 84.22893001187234, 88.31753023209112, 86.93205495034495, 89.95340962563792, 92.59825598809027, 92.02103999353226, 89.40121050803893, 85.62335614235171, 81.43102492055586, 86.40497469132947, 87.51732749323692, 83.81648494351296, 78.83352156608336, 90.12372678326022, 39.05381210388676, 33.87906443688178, 59.058758981766246, 43.57517919232769, 24.50718064461985, 22.007505124615086, 20.01676497920867, 5.310113074318056, 11.312546057085838, 18.424627857823527, 13.906163323310114, 0.30542482231413165, 0.11826372014418726, 0.6031447612950879, 4.6296019515683575, 1.8495246455554042, 0.7650459834164189, 0.8387156948447229, 1.009655038435613, 31.433062630314982, 8.078208642621195, 9.288560882691415, 7.390840726514017, 4.80238922180668, 3.1679669887788835, 7.393728081257113, 1.8659440548189226, 11.530572964299111, 4.223502297555247, 1.0196323224133061, 1.72923780977726, 0.07351425686670889, 0.2830200600287607, 8.924403132930879, 6.503133831485626, 1.0255589624566417, 3.2215553906656083, 5.714801655661676, 21.374411044582246, 21.16466426080273, 27.22394758655179, 26.900828615311656, 22.287075981017082, 56.877776038262155, 41.954950055768414, 25.134889310406102, 62.06479680153632, 71.03326874394571, 74.59749514056791, 69.50872190536992, 75.04036211198377, 71.52750307513823, 77.87095623631632, 74.89173566141437, 81.7306233990577, 79.29453342191636, 82.82647871202039, 81.66058555726083, 77.83807108479162, 74.09425504745977, 75.72709852649321, 77.64713794954362, 74.56729289024108, 72.10096928381151, 79.40871361763247, 75.4949648149552, 75.92513115175309, 78.92696026832827, 85.42584911469491, 81.87145217772454, 75.37581889860093, 39.425723398885424, 55.928621292114265, 59.7095194170552, 49.67046007033318, 41.56229334492838, 30.749344479653146, 27.364797938254576, 23.660533120555264, 15.045866812429121, 5.908183820786015, 1.5697281302944308, 0.044060217802442854, 0.17145441514590096, 0.0786332180723548, 0.19332768095116462, 0.05572521262952397, 0.15844412778894748, 0.038377243514743545, 0.12770980641606355, 0.07377517875283957, 0.08389719206118777, 0.10940896181930458, 0.04987394031617911, 0.09342863584958738, 0.15605345849067936, 0.09937841940911547, 0.0337357580992243, 0.10611566474601146, 0.048443581383194656, 0.05303685688563893, 0.08989824988548795, 0.024405766706613284, 0.11416151849252563, 0.06776237680066018, 0.038915044898467685, 0.08282470727159132, 0.055103405874462864, 0.20539091509436408, 0.211479582733685, 0.30540885704178966, 0.24291587813246637, 0.154820884307546, 0.2563299857560666, 0.10122204064241341, 0.4049263137482828, 0.17771704603106747, 0.12335169309329604, 0.2284456723399701, 0.07709679809669334, 0.20193732944467377, 0.17016789305113977, 0.11570109475043514, 0.16717854136180493, 0.23593959038055715, 0.15779119105108325, 0.23893326280578492, 0.1909626755983599, 0.18073325676302757, 0.18280518751951957, 0.17828058030816818, 0.15297114969261233, 0.1215950688046794, 0.3310993091473657, 0.31848527310836705, 0.24983236506100626, 0.21599165674659515, 1.1223930889560332, 25.647886299317886, 68.8099124354701, 104.24294933196038, 111.88405590672647, 95.21898761872323, 85.80629548718854, 76.1336051264117, 47.314621786917414, 63.6919803004111, 82.30677250892886, 94.76206287260979, 101.12428065269225, 76.53222776228382, 72.45791281423261, 98.80038615195983, 95.68478476616644, 101.32554531097414, 93.91683916891776, 93.3767209514495, 89.93891254548105, 91.3724760855398, 89.70906165338333, 90.34002980878277, 86.9763385095904, 87.25156337984147, 90.82204203451835, 87.58621215820314, 89.80253957932996, 91.92514588755947, 88.75767507860738, 89.3070500896823, 84.02933628328385, 79.39821735505136, 86.15136208072786, 86.93673041559036, 84.27709671758836, 75.9284730111399, 85.88509590395036, 51.701071108541186, 52.787771609521684, 62.70434318050262, 51.56191325956776, 30.18626274601106, 26.55972557683145, 25.794333873256562, 6.520738409411523, 13.401082657998609, 36.53973364060925, 18.70933701915126, 0.48723161340721194, 0.13001348643052962, 8.256002818384479, 13.654678598526987, 1.1946405734746688, 1.0622961266386894, 1.051915819125791, 0.8798654641835921, 54.17895786223873, 13.13595396857108, 30.08614032499252, 19.665259815031483, 4.515091786461492, 6.24893972950597, 15.306161180619272, 2.0080332626258177, 13.100744812719284, 7.813168696818813, 1.878776701707994, 2.2657019717078057, 0.1555192500593201, 0.22569976807121309, 8.789200994276232, 9.465060676297835, 12.695118784904482, 7.1927021972594725, 12.735573130269206, 29.377515123736476, 31.310918061963974, 33.62402800590762, 37.39358655868038, 27.16316261599141, 61.71234438496252, 55.543428851712136, 38.95095186848795, 66.21149909111762, 68.32203234395674, 77.71855646564116, 66.62235167718703, 75.50231533665811, 71.03408459694155, 77.32192639381655, 72.5338420560283, 79.67548185779204, 77.257199441233, 84.60914104215561, 80.5738458325786, 78.77986354212608, 75.03553759667182, 78.25270483570715, 79.21217933777841, 79.13750525443785, 74.24156358165126, 81.16138550543016, 76.23309996820267, 80.29030553756222, 78.24860203650691, 88.21364233570715, 84.23497046193769, 79.09781086829402, 48.62712137160763, 65.44486791856828, 67.09950800864928, 65.87413603259672, 51.50757666557066, 44.25559274611935, 47.398054522852746, 46.173765120967744, 26.86750415832766, 7.463291806559409, 1.1756620628218497, 0.18715492750127471, 0.2876250145416106, 0.3026010835122678, 0.2563201645088773, 0.2170551553248398, 0.2755050745702559, 0.15429153287362668, 0.21676879165874374, 0.1815974805504084, 0.35586990416049963, 0.23065257246696183, 0.1557931877792843, 0.2120723968912517, 0.22093378187667942, 0.17741621862496101, 0.19250263490023153, 0.21442969539953818, 0.2831377924209641, 0.19654722673998726, 0.14309636827918792, 0.22813779692496025, 0.316662535431885, 0.11954254305530941, 0.29975846830394964, 0.19110323741070687, 0.09888268391331358], [0.06166613638220776, 0.05091267893271101, 0.09001360740512611, 0.1090536502400233, 0.06626802271292095, 0.04846890824997137, 0.10016975759138023, 0.1452378598192046, 0.19360371775204138, 0.16722761695423435, 0.2168753085237357, 0.09309557912450644, 0.06472656187871773, 0.02156564511448866, 0.08041031989118747, 0.20799546081933284, 0.10759807552301115, 0.1124277159631733, 0.07264683083180459, 0.07785721697033414, 0.09035302265997856, 0.0546919362198922, 0.15840400010347366, 0.08812205205040594, 0.06924119462529499, 0.10286981915874828, 0.028539207508607257, 0.18741881414767236, 0.28683422794265134, 0.0359788941850345, 4.188228422595609, 24.05989512320488, 67.83173607241723, 90.72745800018312, 74.48919065536992, 49.274681152835974, 47.51687880485289, 54.576556759495894, 58.81106915012483, 62.345752254609145, 65.29358994576239, 79.64963343835647, 56.30801254703153, 57.84889605737502, 92.00172624280377, 82.51996117253458, 89.9531429044662, 80.15634875143729, 85.12742734724476, 87.84241353311847, 89.08367895310926, 85.3655779746271, 85.9097989912956, 82.8149704779348, 88.4140911409932, 88.88827431586482, 86.1442155222739, 87.75010447348319, 87.9584058638542, 90.57924732085198, 88.04309768061485, 84.91172052198841, 86.9552989159861, 85.33356358928066, 86.38039711982974, 82.77886113812848, 81.00984865619291, 84.82612656008813, 42.60133312594506, 31.890944434750466, 61.418621616978804, 22.507415125446936, 23.24436180053219, 20.711912916552638, 15.496440260641037, 6.5712595178234965, 7.260249824293199, 0.5178256104550054, 1.659049937321294, 0.3238711163641945, 0.9140317598658224, 2.5405037162765383, 0.0797460680346816, 0.5955918085190558, 0.06514978715248647, 0.5237423219988423, 0.04570478641037499, 19.918464499135172, 4.212189691682016, 0.5018900316809455, 5.909370337763141, 2.7437325014222056, 1.7564759739945013, 4.373571199755515, 0.8228142223050519, 7.188004668681853, 0.42610787876671363, 0.8186823730507206, 0.1267964457492194, 0.10435661195867485, 0.22945508511076051, 1.1269818943354393, 0.13608680166784795, 0.43614482567194973, 4.211086525071052, 3.056152717721078, 15.673051841797369, 22.112626606418242, 19.849366064994566, 28.592305644865963, 13.280872798735096, 29.58760903727624, 55.960427791841575, 21.29926431563593, 63.05301050986014, 74.15905260270642, 69.92010793378277, 68.97461275900565, 71.95635934029856, 72.25358086247599, 75.1436302738805, 75.01777710453158, 80.14839418472783, 74.4776039738809, 77.32183225693242, 82.15069355503206, 72.50326325816494, 71.5703510469006, 70.74260542469641, 72.82426218832694, 74.75413107102918, 72.41473536337577, 73.50792346462127, 73.59721229922387, 74.97715703902706, 76.59478172179192, 80.12919810510452, 80.50159577400454, 64.16069176889235, 29.90452281890377, 47.95905936148859, 46.53799249279884, 42.056229575987786, 21.530741030170073, 19.20243190180871, 6.825109431820532, 3.6809017100641808, 3.675011535806041, 0.2045072939607405, 0.18809493270612535, 0.07552860079393273, 0.019995528761477723, 0.05011873988194331, 0.10843773087066029, 0.06803216232407479, 0.24038296162841782, 0.04603572490234529, 0.19022785938314854, 0.01137465133421844, 0.022826026374053572, 0.025177075520097732, 0.07910915019531405, 0.14979986744301935, 0.0925926194195786, 0.15288458175716862, 0.0378133644980769, 0.09418851080080194, 0.029184659567451286, 0.06517549706322533, 0.09170060962318413, 0.03759162417883354, 0.08388115784093257, 0.0052022569880430265, 0.02848772256965599, 0.019418955667905753, 0.02967945660554594, 0.06052369627380564, 0.0268379005137831, 0.1441237381509235, 0.14665179765753208, 0.03374604282960777, 0.054603184933864304, 0.05457967369546814, 0.18582057087652146, 0.02983894845050189, 0.14146627107214543, 0.0515662323713543, 0.0481408387572775, 0.056020125836854985, 0.1259670713015141, 0.09628168517543424, 0.05323612018518391, 0.19695913689511438, 0.02429128444242862, 0.03287303201373547, 0.019700546606233525, 0.04255271381548336, 0.07074160846851527, 0.156454153118595, 0.1533170996774589, 0.27142528865125876, 0.1460300866634615, 0.019177438788897088, 0.0949378980083331, 0.2961425026578288, 0.17980131080314038, 10.171681546395826, 39.21771226390716, 76.65681008369693, 87.90131184362596, 87.55699834515973, 70.97691997405022, 70.00955366319226, 76.33475211358841, 78.09123654519358, 80.88477996087845, 84.27773214155629, 96.03765687634869, 75.0965069186303, 67.47923266503119, 97.1523238766578, 88.8563697568832, 96.62718911324778, 85.65513518548782, 88.74006363653368, 92.97110080718996, 92.09892257567375, 85.83879624643635, 86.94845830240558, 84.93297192358202, 90.04744452814903, 88.30675155885758, 86.04020995478477, 89.14377750888949, 92.78365073665496, 94.48033471261301, 88.31473750452842, 86.62674550087222, 88.20488760548254, 85.75149997588127, 84.33826215805547, 85.52896038178476, 80.6640995702436, 88.79762834118259, 47.71153819176459, 30.859449332760228, 66.68774543269988, 29.24377210678593, 26.456445647824196, 22.031970908564908, 19.96230090818098, 9.600435399240064, 9.758613801771595, 2.2572517154678224, 3.2654435259680596, 0.6718646254270308, 1.8744712875735376, 4.846578644167993, 0.4831195292213271, 1.1439118245916984, 0.12899541686619484, 2.014644294977188, 0.07702303149046437, 27.229280048801055, 5.20768282874938, 16.00352917948077, 10.160277255119817, 6.658899976361183, 5.4262319014918425, 8.32652016993492, 3.126923062147633, 10.290712733422557, 0.6908740247449567, 0.8950116966039905, 0.18571359435877494, 0.09796197646327558, 0.4463599033413395, 1.2054724438536553, 0.7520611608220685, 2.173979796709553, 2.336500508169974, 9.80995370495704, 18.928601434153897, 23.25259485552388, 22.759951045436246, 31.68030531175675, 17.559105888489757, 38.318132354367165, 56.76052462670111, 22.99691515584146, 66.74211732802853, 72.75351831989904, 72.39147570825392, 68.80408379339403, 69.15191958027502, 72.03066472084292, 76.26745993091215, 76.65280926612117, 81.35645281883978, 79.17797626987581, 77.30596234721523, 82.1003617009809, 74.95464263423797, 72.48594991622433, 72.1167685908656, 76.3220436342301, 75.54681854863321, 73.42607144386538, 75.84456566841372, 76.18558437593522, 74.15542048792686, 80.95587684262185, 83.21771160248788, 86.07461698593633, 69.55514707872945, 38.18906284147693, 60.42992153475362, 58.8260212252217, 50.954518548903934, 34.0084320499051, 30.169706421513713, 21.84254788583325, 8.27751603818709, 5.702306945477763, 2.67672959354616, 0.5288729660453335, 0.22717537598744517, 0.30952495552839776, 0.0611440972575257, 0.013347039498659152, 0.19289059714684564, 0.1831954786734235, 0.023783770344790914, 0.2416584060917939, 0.07028895009669565, 0.15574282515914212, 0.13401572892983116, 0.039744607037714416, 0.3288664386397408, 0.13680698560370555, 0.18945933529926887, 0.03539705806742272, 0.18046900239442626, 0.089392731446893, 0.10942924782753953, 0.1002537974366738, 0.03865712224656055, 0.03293867425752744, 0.008523613946782726, 0.11440331882406628, 0.04859309110249724, 0.09962851647287609, 0.3000687645568002, 0.11977522694055112, 0.35404995504406195, 0.30728948032183034, 0.15481808042574316, 0.14233901375724425, 0.13888340563543383, 0.422675958083522, 0.21684212159485589, 0.2915644531528796, 0.21891383784672908, 0.19312570953080732, 0.12276126146917382, 0.16620965464220894, 0.2433116085106327, 0.22595553418561337, 0.36046440923406237, 0.21914197883057981, 0.1913284059734114, 0.10232648662021084, 0.25325464835811046, 0.1260664329052933, 0.4117300018908516, 0.2804712242176456, 0.4027477741962479, 0.4976978759852148, 0.13907180197777289, 0.23934546407432328, 0.38526334950039465, 0.2342097944910488, 6.176719088708201, 37.519267143741736, 82.78883964784684, 112.07169425102973, 110.84061130400627, 90.56626427558162, 86.61687681751867, 94.94618677323865, 89.52955830481746, 93.55319623024234, 97.44303426434918, 102.89948263475972, 83.19794285681941, 75.97379992085119, 102.03117186023344, 94.45632980715845, 103.75984668731691, 93.43623899644422, 92.93057487856959, 92.74146172308153, 93.4082175839332, 87.75380719092585, 89.69180322462513, 87.66924873475106, 93.16489727266374, 89.0144334300872, 87.67569711131435, 88.22341688217656, 93.61073740067022, 92.67239662908739, 90.26799155819802, 85.03819342582457, 88.55601033856793, 84.561962773723, 87.67419092116818, 86.21721083118071, 82.30467796325684, 84.26011285474225, 56.30541986034763, 43.20900240252095, 74.03549794227847, 37.07532544289866, 33.78297029003021, 24.16346138523471, 26.57994931743991, 12.111581890813767, 10.135851675464261, 5.850488207032604, 6.092110622313715, 0.7153512693701253, 6.993075128524535, 10.745831228071644, 0.23735447816791075, 3.0000726301823897, 0.2259295331614633, 3.85136938864185, 0.16459063506655155, 48.38713899735482, 5.911149622932558, 23.4881979034793, 16.244770634558893, 4.846326631884422, 14.453146669172472, 15.57422576412078, 4.3876858488205945, 16.19872102814336, 1.2313428040473693, 1.7477657381565341, 0.1619605479701873, 0.4194693285371027, 0.7732095389116196, 1.693091942898689, 1.2431432547107821, 1.9842105022361203, 6.739488013329045, 17.014979008705385, 23.517721583766324, 32.714047931855724, 31.08098872246281, 39.997346093577725, 23.715244300903816, 45.56732354625579, 69.26475048065186, 34.620341408637266, 69.39531833894792, 74.55238003884593, 72.56675074177404, 67.02364936951669, 69.64028604568975, 73.1322310047765, 73.89418278971027, 74.32322732863888, 80.8298824679467, 78.89725223664315, 77.52210063319053, 84.89499553557366, 75.97138374082505, 74.08291939766177, 72.21085840655913, 77.86042859477382, 76.48312753246677, 75.82709543166622, 77.66074072930121, 77.69240994607249, 76.31087272397934, 81.10898263992803, 82.95926663183397, 89.38558378527242, 75.4826250383931, 48.013819571464296, 69.20556191475161, 69.25070839543497, 63.24801114297683, 50.49554632556055, 46.757276519652336, 44.40412898217478, 21.91999508488563, 9.863577408175315, 1.3977561001816106, 0.37315738297277884, 0.45404079280072646, 0.7042705736333325, 0.20034568985143017, 0.16292638565984466, 0.2034848423734788, 0.2825169854106442, 0.09980173661343514, 0.34857218123732076, 0.16831628918167085, 0.2329368168307889, 0.30503145148677213, 0.24940927002218463, 0.42910254710624296, 0.25440865256372963, 0.3505008535519723, 0.1588329480540368, 0.21118430180415032, 0.1654080662035173, 0.35554275397331486, 0.2088776263859003, 0.11550457021521947, 0.16521916424314823, 0.21563449123453712, 0.14210575530605932, 0.16210976657607865, 0.2602559105763512], [0.14600935632423048, 0.029341788031160835, 0.11901188927191882, 0.1773607538592431, 0.0749788101341936, 0.09897631517941914, 0.16052249368400345, 0.14507391700340858, 0.020233230522623467, 0.05562162605084239, 0.029838255140930418, 0.1172387328058962, 0.03330717787086483, 0.06040037910063421, 0.08382964608890396, 0.11111306311983256, 0.06588487149847132, 0.045573329553008086, 0.04123481275934366, 0.040766372976283875, 0.08951743523920737, 0.06366324333113528, 0.06047157548187722, 0.07797748511356693, 0.05848260821714517, 0.15716034828895525, 0.10012380763768189, 0.03144219810623796, 0.12319505875629765, 0.16751096223390874, 0.33919517311357683, 8.950176046740625, 51.560034444255216, 86.14267795316636, 91.74582296802153, 61.62051385448825, 49.54417936263546, 59.09462121225173, 51.30932438758112, 56.51716116935977, 61.376471827107096, 77.61554718017578, 61.59213550629155, 59.408838364385794, 96.371136788399, 86.5189273895756, 90.13093609963694, 81.82943574843868, 89.10799764817762, 87.89957031126946, 92.92442460213938, 86.38908124739125, 91.43257464132002, 84.1836109469014, 85.27522225533762, 86.401868174153, 88.6043574733119, 90.15949879923176, 90.9004266800419, 92.6748755670363, 91.62473155606179, 86.72866436742967, 86.4959030766641, 86.1336878807314, 83.60215094781692, 81.4023837735576, 80.44618052821006, 91.74776061888664, 42.35742053677959, 31.480784147016465, 56.12109984121015, 16.31261096846673, 28.906238425162535, 21.42652169350655, 18.69705411695665, 6.976780622236191, 10.991587331218104, 3.596088544976327, 0.6520899962032995, 0.9751463320947463, 1.0652051769918012, 0.3134920652354917, 0.16704150355390965, 0.8708417451670094, 0.17583836861435445, 0.9154230981103836, 1.3592477407186263, 9.74801653815854, 4.654074109369709, 10.021168435773543, 5.509301327889966, 3.6770595033322615, 4.968019637369341, 4.021267833248261, 2.9912693606268976, 5.356731914704846, 1.7843768961967963, 1.5803289485554544, 0.1562104452281229, 0.1625471108502919, 0.24665210426094072, 0.3691371067637398, 0.21017107391549697, 20.758983319805516, 8.80707327396639, 7.0522808547942875, 15.288989044004872, 26.48474947098763, 19.546515941619873, 26.875311636155654, 21.507212692691436, 18.406165261422437, 54.3112947094825, 26.369529847175848, 52.46679621358072, 77.99771155080488, 65.878034868548, 70.27212496726744, 76.01975440979004, 72.86547845409763, 76.92819887591948, 80.64088698356383, 79.47885344105383, 74.99097162677397, 77.0475487555227, 79.018186753796, 74.59087417971703, 72.04578938022738, 73.04034556111982, 72.47301393939604, 70.84326128805839, 76.73630868234943, 72.6087671710599, 72.08402464466711, 73.984020756137, 85.90603351593019, 78.90820349416425, 81.56416585368495, 62.43023618575066, 28.6371148017145, 52.79069377530006, 45.35155004070651, 41.95012554045647, 18.971490590803086, 13.05917847541071, 4.221705361720055, 0.7742894164496853, 0.5246443445644071, 0.0947773949273171, 0.08140564430505037, 0.42893648988777594, 0.17384491590482576, 0.04690079904732205, 0.016511207664265268, 0.2329349016109782, 0.25893214128671155, 0.11316105362869079, 0.28155900778308995, 0.03182192873810569, 0.03169682274963106, 0.14218098514022368, 0.12201200449658979, 0.34519195616725956, 0.20564393861399544, 0.20780249859296507, 0.15078645079366623, 0.10622642573810394, 0.08762256272377507, 0.03617950962976583, 0.06936265020481042, 0.02996607308065699, 0.07524537042744699, 0.05685810728238956, 0.10246196926961984, 0.1257157025317992, 0.024286245499106667, 0.057739024125640435, 0.052367257735421585, 0.11762700914855927, 0.28087446225746987, 0.0529508903292158, 0.049487920102453044, 0.3056944852634784, 0.14773306947562004, 0.047867628820841356, 0.11265227931641764, 0.08383739123781843, 0.10136228835871143, 0.00521619069097083, 0.10599037872687464, 0.09437869212800458, 0.033782152383918726, 0.07091979285882366, 0.04965851256143182, 0.008680573871148931, 0.026280743918652018, 0.05289013189594111, 0.043208795344276775, 0.07833958423185734, 0.17589102949826949, 0.21498656471169766, 0.3618091999763443, 0.09936930296281654, 0.1631282191843756, 0.2788666377384817, 0.5175911875501756, 3.1518127072242, 21.218061447143555, 64.19418096542358, 87.28334242297758, 92.18803098124843, 73.54551546035275, 71.79670318480461, 81.09093973713537, 64.64073104243126, 67.55004713612219, 82.51912963005805, 96.89301598456599, 85.35808624759798, 68.43329429626465, 103.75044084364369, 86.74018829099595, 98.23674940293836, 84.01352128674908, 95.52909020454653, 91.4119194399926, 98.50966007478776, 91.88418849822014, 95.1959397715907, 87.26096922351469, 88.48099108665221, 87.5973124657908, 91.65451019041001, 91.44733059790828, 93.51023058737479, 92.57746742617701, 92.68868231004285, 87.77431334218672, 87.34312718914401, 88.74051078673332, 84.65020825785976, 80.67182663948306, 82.41765791370024, 91.25381654308688, 49.916655478938935, 31.17375473822317, 63.01301410121303, 20.679657305440596, 30.605919091932236, 21.259318897801062, 23.08871038498417, 8.482484394504178, 12.451663151864084, 6.174435778971642, 0.27783628012384143, 0.3358693402861396, 1.9307428358062624, 1.8165648464233646, 1.0961402976705183, 1.0639426640925869, 0.11002317281259645, 0.6498851951572203, 1.992121677725546, 17.718966007232666, 2.5856600028853265, 26.759136915206913, 14.743648190652172, 5.078485348532277, 8.465905516378342, 5.9599752868375475, 4.224089672488551, 9.457343412983803, 0.8018015949956833, 1.1774838811928228, 0.13170166842399106, 0.5289051417381533, 0.8223337319589431, 1.0428233973441585, 0.3801787013728773, 25.127679994029386, 20.01046173034176, 20.672879449782833, 21.152753983774495, 26.464011899886597, 22.027760244184925, 29.34401219890964, 28.24204191084831, 25.010371708100845, 57.82564032462336, 28.22972959087741, 55.86662823154081, 75.781109563766, 68.70986061711466, 68.30980239375945, 74.8018741607666, 71.712262399735, 76.1783750595585, 80.05475151923396, 81.3558566185736, 76.84541333106257, 77.8017028685539, 79.433149983806, 75.03558466511389, 74.75094610644926, 75.74235654646351, 72.32419921505836, 71.73383543568274, 77.0677097382084, 76.19582176208496, 73.19630684391146, 75.79697947348319, 87.83146227559736, 80.62812359102311, 89.37518165957543, 66.6653016305739, 36.46935847497756, 62.54659329691241, 53.5431848033782, 55.98175764083863, 32.30061442621293, 31.059541202360588, 4.044826569095735, 0.7927854142842755, 1.7285300671092927, 0.3226446708844554, 0.18566862499761969, 0.5909084985333105, 0.07203009940924184, 0.1520827634920997, 0.06437347961529609, 0.2884161075757396, 0.24644683866250902, 0.05551701674478189, 0.23507064749156278, 0.07026703232118199, 0.1400507704144524, 0.19445383019985693, 0.03633902062691989, 0.24697200725636176, 0.06180710039071499, 0.22735244955026337, 0.13951648537430072, 0.18049246000666774, 0.05066372333995758, 0.08299862455216148, 0.033670537203790686, 0.028549203040799307, 0.05486521381704558, 0.027766619328289267, 0.08245978894973956, 0.10873151026786336, 0.08397878808600288, 0.30063278913017244, 0.09945400930460423, 0.33836553053509805, 0.39776115467952144, 0.15138065923125515, 0.09952848837260278, 0.440720699487194, 0.19933394817334993, 0.16149147233415037, 0.18839759872325007, 0.19727501026805372, 0.27318925206218997, 0.09832887129197199, 0.26050479722119146, 0.16827804607249078, 0.10613368313399055, 0.2258034657326437, 0.12277292132738138, 0.0662854818567153, 0.08992344651731754, 0.17234707611703104, 0.1665251756147031, 0.1520218748238779, 0.5083753643257003, 0.2661869939296477, 0.4595684542530968, 0.13206752137311045, 0.2037645563963921, 0.30158289137386507, 0.3904011028428232, 1.7864005940575756, 15.236237087557393, 60.68789189861667, 91.33730811457481, 108.4035328895815, 94.4024129067698, 96.48886280675089, 98.65761972242787, 80.21454103531377, 82.58168358956614, 97.71481529358896, 108.72381794837214, 95.24374561925089, 78.46849795310729, 105.98212826636531, 92.18352810029062, 104.9566088953326, 90.52889977732013, 100.78741181281306, 95.2895353686425, 103.7075379586989, 90.66223682895784, 96.95669174194337, 88.37263168827181, 90.47922688145792, 89.53138612931775, 92.0947805527718, 91.0302963564473, 94.94992871438303, 90.51702284043836, 90.45088383459276, 84.52328820382395, 85.98987025599327, 85.65529208029471, 87.07385647681453, 75.19666856335056, 82.59802418370401, 88.23718440148139, 54.37487240760557, 41.18260006750784, 73.55416036421254, 27.687077522277836, 40.907167311637636, 25.141002324319658, 30.44851633810228, 12.573700835627895, 16.660249656246556, 10.53061273790175, 1.5979867236268137, 3.288440627436484, 5.195608302470177, 0.8703028482775536, 4.246864424597833, 2.1407999771256603, 0.8010048022673977, 3.7998002719494606, 3.7381464963959115, 32.590875702519575, 5.640576193409582, 25.21839068781945, 19.73961030283282, 6.522964844780584, 24.861266728370424, 14.501957624189316, 7.08681732416153, 9.750557253437659, 4.091623877325366, 3.133357465267182, 0.25922699320700865, 0.4158097265228149, 0.7883753218958456, 1.0799679977278556, 0.3166597162283236, 34.734015618601155, 30.82420095320671, 23.062630545708444, 27.03986487080974, 35.38977315348964, 30.274370947191795, 38.03274462299962, 34.70333876148347, 33.6346850856658, 68.92372392839002, 40.572087072557025, 57.14999637296123, 79.0019638307633, 68.53006701315603, 68.9228060937697, 74.13353366236534, 71.01723409468129, 73.82064619371968, 79.9995323919481, 79.21596050262451, 77.8019852792063, 76.01870321458387, 81.20759102606004, 78.75865920897454, 75.79664999438872, 76.52668937560051, 77.20117230569163, 75.38327924666866, 75.8650561301939, 77.3503714223062, 74.33359807537448, 77.98712899607997, 86.56703918210923, 85.0073008383474, 90.70588496423538, 75.32821701418969, 47.26821622540874, 77.50346153013169, 63.12548806590419, 69.80861063926451, 48.33990581573979, 46.62153897746917, 25.770121082182854, 3.0228370860699685, 1.170621694576356, 0.3035135555171198, 0.17011645790790358, 0.7090993790376572, 0.26636895513342274, 0.32008379217117067, 0.11862774980404686, 0.4150037100959209, 0.45670769808273165, 0.25556539936411765, 0.37024600371237726, 0.17705108579849044, 0.12256829158192682, 0.3305693601648654, 0.13868370183533238, 0.4541428050687237, 0.3287829656995112, 0.3982172834296381, 0.3487789024028086, 0.31247592621272613, 0.27933192890017267, 0.2059514769503186, 0.18925584702482148, 0.23784379384690718, 0.18908166927435707, 0.2996681005724015, 0.3468779011839821, 0.23731997356780116, 0.3564309256692087], [0.09314012713730337, 0.060875047178518396, 0.09079336233797575, 0.06489023656374024, 0.04936476380774572, 0.028148280501726176, 0.23059044273630266, 0.1250762489414023, 0.06583599508890221, 0.04766989769714494, 0.011179804531556946, 0.06032364773413828, 0.12603633331074832, 0.07600988021060344, 0.12212094219942247, 0.080197332126479, 0.18618384977021527, 0.19167371244440157, 0.13987703699498408, 0.08302972772188726, 0.10684247534241408, 0.06159949056323498, 0.06529479993567353, 0.2307018012769761, 0.14754013789276924, 0.10895773603190338, 0.12089854932480282, 0.16431062993022705, 0.10494698995664235, 0.30603821359334454, 0.1674488171814911, 2.228612284506521, 13.727742548911804, 43.54583201869842, 71.20344469624182, 75.30531821712371, 48.60430886668544, 44.56988050091652, 44.17666289114183, 50.53384042555287, 69.20327125057098, 72.49824262434437, 61.72914389641055, 59.768303978827696, 96.18046252958237, 88.89498941359982, 95.37153643946495, 83.7369785001201, 84.4644683407199, 91.16124860702023, 92.96990840665757, 85.02540649906283, 89.60620141798451, 87.40011138300743, 87.69213184233635, 86.90430810374599, 90.37465649266397, 89.70106786297214, 89.66225993248725, 90.483212009553, 89.74459048240416, 88.11567721828338, 91.43058207727249, 87.0059524043914, 78.83893443692115, 83.78812620716711, 81.57794906247048, 86.70899760338568, 43.71627469216624, 40.531568988676995, 46.593878423014, 19.587993045007032, 33.420084368798044, 19.8782366706479, 20.94063416604073, 6.265784838507253, 5.567719638347627, 2.3541626959077777, 0.5740761985221218, 0.6313004536974816, 1.1932489900819718, 0.9578828777997725, 0.586750295854384, 0.21845541083283965, 0.5822211227590038, 0.09202393703162672, 0.3459549797398429, 7.089454627806141, 0.31244371987638936, 22.51752503456608, 6.31529446571104, 1.1520127447382098, 5.864693560907918, 5.496519794387202, 4.953024906496848, 10.242326374976866, 0.03934499642421161, 0.33238495790189315, 0.5004663032389457, 0.08379240655490468, 0.13472875760447595, 0.5536594650437755, 0.6780985586585537, 13.529640301581352, 9.833874279452909, 13.120149758554275, 22.804946514867968, 23.938025120765936, 24.045692220810924, 28.904122306454568, 24.926230984349406, 24.665248240194014, 35.79763689348775, 31.77603271699721, 45.161801461250555, 78.15652831908196, 62.48369416882915, 69.81825182514807, 66.12650132948353, 75.14235942594468, 75.37040602776312, 80.86807066394438, 79.08494549412882, 79.33396893162882, 75.18919252580213, 77.06733319067186, 70.55765782633136, 78.5807954111407, 67.07874298095703, 72.3716442046627, 68.76156530072613, 78.63723047317998, 69.23070430755615, 78.79230530031266, 75.28368242325323, 90.00888762935516, 80.25832253117716, 91.22370842964419, 48.6742211926368, 33.75763177871704, 58.073722393282004, 50.351465902020855, 33.79523946392921, 22.63148165518238, 9.58610894218568, 0.08988837501214397, 0.829149095281478, 0.3073566815545482, 0.2923405308636927, 0.40677843855754026, 0.42098094258577595, 0.13058705645943844, 0.10695466891892495, 0.2750478426535284, 0.20507314182337255, 0.0872516995596309, 0.08446995003689682, 0.20247559814203173, 0.11810942237535793, 0.12333798778033066, 0.11164303508497055, 0.3205375000834465, 0.1827913213280901, 0.12637073835057597, 0.18068536094600157, 0.22894379803009574, 0.027063773877377954, 0.08953125546536139, 0.002173346912323107, 0.08168832308823064, 0.03701932968631868, 0.05114000403292237, 0.008386791601116139, 0.04270325009260447, 0.12709266896690094, 0.11982489242068223, 0.0265492175164963, 0.0624397894247405, 0.07981757468153393, 0.1398038602764568, 0.04245919746256644, 0.07789261789331514, 0.3315834767155109, 0.08914684020583669, 0.013577850298925996, 0.09028097209069999, 0.08727991457788215, 0.24136226714378406, 0.06134416877983078, 0.06815668225528733, 0.13325766960699714, 0.0552906186109589, 0.01084949710451427, 0.23151630595807107, 0.06956239230930805, 0.08422683203412641, 0.05324449352619629, 0.08083974281626363, 0.030194018712087028, 0.11130653862510959, 0.28792746605411657, 0.1012182638289467, 0.11306235086052649, 0.1364724809724477, 0.1749305544240821, 0.3787641046989349, 1.4818372529360557, 6.344103294034158, 32.19583026824459, 67.35978864854383, 96.65992521470594, 86.10727463999103, 69.03821006897958, 66.36069036299183, 70.25867908231675, 60.13408068687686, 77.80315414551767, 92.04669229445919, 87.69071978907432, 71.60137699496362, 105.09935963538386, 94.41074402101579, 97.03106772515082, 87.67068432223412, 91.90606747904133, 98.32025666390696, 96.37334900517618, 90.05441065757506, 94.58007274135467, 89.05117819386145, 89.05645770411338, 89.05491229026549, 95.90496309341924, 89.45143253572526, 91.87823434029856, 96.05735501935406, 92.50379746960056, 90.4435254681495, 92.64635209114321, 88.80140166128837, 82.640589744814, 87.31838487809705, 82.46233370996292, 86.5507927248555, 49.753155400676114, 41.7319280101407, 52.50008929160334, 24.286353165103545, 33.92611326709871, 19.624545612642844, 25.939187003720193, 10.060800063994623, 11.227964066690015, 4.503814972216084, 0.13077741398686363, 1.6893640977721063, 1.4692334518317254, 0.2438057352217936, 1.2024112790822983, 0.25897645181225193, 0.7014802975520011, 0.24319856457652586, 0.9989082957467726, 11.37141985277976, 0.905610247244758, 32.54472313388702, 11.46827886181493, 4.093093540399305, 11.623003617409738, 12.15912199789478, 7.18730648679118, 11.426328132229468, 1.3219710054897493, 0.2057302154360279, 0.2488103118394652, 0.34407616442730354, 0.46604149884754614, 0.23093800150579025, 0.18839571414695633, 16.697396462963475, 10.896649302974826, 19.513817102678363, 27.283595069762203, 24.705719255631973, 26.20183675519882, 30.530468379297567, 30.257408657381614, 31.926061414903213, 43.00572556834067, 37.65813865969258, 46.664767419138265, 81.33198507370489, 63.84600000996744, 71.26766958544331, 66.0258690003426, 74.4439108141007, 75.5915492580783, 80.06471433947164, 79.06891084486439, 81.29575806279337, 76.392332507718, 79.81990352753671, 73.29865717118787, 81.17590611980808, 68.91194897313272, 73.3631487815611, 71.43133440325337, 81.7245594147713, 72.60654710954236, 80.24988159056633, 77.3165919703822, 91.02831948188044, 84.45727471382388, 97.43344014690769, 51.65741512852331, 43.15088072130757, 68.06649777197069, 58.842757978746974, 45.604793948511926, 36.986283717616914, 11.541381055308927, 0.35173333580455474, 0.8659403146274629, 0.42316254648950796, 0.2466445506340073, 0.379788272323147, 0.37220507439586425, 0.18698923800501133, 0.07835323591866801, 0.3809571692780141, 0.04496534302410099, 0.04168016265236563, 0.15165927008755747, 0.06925336010153256, 0.15336557772130738, 0.15885939340918295, 0.23805319632013, 0.2472754087178938, 0.18838523406415217, 0.08510817788661489, 0.30107849908451884, 0.18342625499973375, 0.06070947259544365, 0.06875557149009359, 0.016427445525844252, 0.029848526464775208, 0.05204930826420746, 0.002653972281428475, 0.008150031170507353, 0.08697138032725743, 0.1952255871747771, 0.04207889609519513, 0.15101449984696605, 0.17530737775227717, 0.3304158055013226, 0.395804719338494, 0.12494737763077983, 0.18078254686007578, 0.3755139307148995, 0.21197361751429497, 0.18396073922274575, 0.26943493093694415, 0.26653099805116653, 0.2618408852046536, 0.1801073782506489, 0.17774955880257393, 0.3499638259170517, 0.10144925465987575, 0.23953470311337904, 0.3874157501324531, 0.23699176617928092, 0.17124593197818727, 0.1269960882622869, 0.17108905249305312, 0.10076825612134512, 0.49398501553843105, 0.36616496140918425, 0.23722503995222433, 0.17622763321043985, 0.26082572677443105, 0.2769965558282791, 0.6083767740957199, 1.2042406970454802, 4.30040919011639, 22.6540627402644, 59.96066485681842, 94.7947048371838, 104.0207862854004, 91.68284539253482, 91.57373289908134, 86.96678361585064, 69.47659769365865, 99.31041979020642, 107.16247143283968, 105.56193259454544, 80.78170007274997, 107.2116893337619, 94.4061234689528, 100.88325100560343, 91.93166486678585, 98.62860202789308, 99.2189814967494, 100.40749888266288, 88.94844347430815, 96.87187440933721, 88.0419994169666, 92.92026688975673, 88.37529105524864, 99.9150453075286, 88.94379154328378, 95.00001738148352, 93.90367569461947, 91.66000150865125, 86.93518500174247, 88.99037361145021, 85.34923738048923, 81.40148947315832, 83.5171845651442, 83.49933778086017, 83.49095175343176, 55.30227761114798, 51.267209899040964, 62.35171425727106, 30.517387274772894, 41.06223037165981, 24.88930186917705, 29.492016953806726, 14.280917356091162, 14.39425620340532, 10.062980901810432, 0.6960771100655679, 9.809289843805375, 1.851826463976214, 0.8784009492205036, 3.850005384414427, 1.494614496346443, 2.4625198879549584, 0.8149797781821221, 0.6175593491042815, 20.627687861842496, 2.104441321665241, 44.23235662521855, 20.4975789208566, 4.472388452099216, 29.292366350850752, 20.85254949908103, 11.8228042510248, 19.893981064519576, 3.2804063875829024, 0.827075019478798, 0.5597296393206043, 0.7168575208033285, 0.5696592419858902, 0.820270381387203, 0.6486392297571706, 29.854700872975013, 22.109847607151156, 25.08926037819155, 32.77041239123191, 33.87792302716163, 35.180683366713986, 40.68054060782156, 37.35575922073857, 40.34520541467975, 51.983846541373964, 43.942838638059555, 52.74701818343132, 79.40526193188083, 64.44702479147142, 71.38967098728304, 65.38016057783558, 72.5560583606843, 72.32960424115582, 80.33255730905842, 78.36305679813509, 80.48259581288984, 75.83469698506018, 81.26816026626095, 72.25856227259483, 85.32188277090751, 72.43637115724626, 78.10650240990424, 70.33900922344577, 81.27107066492881, 73.20061360636066, 82.47063344524753, 75.29595159715223, 88.08582798127206, 84.07943279512467, 102.49372128517398, 65.94367181101154, 53.44602377183976, 79.71147352649321, 70.68933179301601, 63.2927026287202, 50.42916805513444, 42.421135517858694, 0.6786959846654247, 0.8188896457995138, 0.581453318797773, 0.27130433868977333, 0.306135659977313, 0.6375907710002315, 0.267603735649778, 0.2690213660319006, 0.47335564669582153, 0.46782605470188204, 0.18585890591625245, 0.19271949906983685, 0.2077675496618594, 0.24095778804152246, 0.25197290665199684, 0.3790725316972502, 0.43505376325018946, 0.5062650065989264, 0.17178302090014183, 0.45484926070897813, 0.3926649845896229, 0.13158542224236075, 0.18596922257734885, 0.2184334087876543, 0.17809045260712025, 0.1375978794549742, 0.16934033423181505, 0.2055195259350923, 0.15307926002048677, 0.272849599320081, 0.16317957771881936], [0.015508277912534054, 0.11473659005376602, 0.09827427220560851, 0.022296065900234446, 0.014492712498101738, 0.08659815761230646, 0.29874747739203517, 0.14433963704974423, 0.003787545161509526, 0.03074927540916589, 0.04741576335002338, 0.1506896019582787, 0.1630469678991264, 0.0850291635781046, 0.11335465936891495, 0.09628265810709807, 0.06840356174976596, 0.22757645365932297, 0.25644796329640573, 0.06368737510075012, 0.11318494025016985, 0.06290111991186297, 0.07578621318023052, 0.20652745249530963, 0.06594491746997641, 0.1141285460682646, 0.25508685488133664, 0.13401096386294212, 0.05276737396695441, 0.15943959775951602, 0.15279597602784634, 0.6636713457203681, 8.170815312093305, 24.023079756767522, 21.68032846143169, 43.932228626743445, 34.38947462266491, 24.424746151893373, 30.11600132911436, 39.78505173037129, 58.68785965827204, 84.63086312816989, 67.22566712287166, 51.01029857512444, 95.5586099624634, 91.04689582701653, 94.22181129455568, 91.57672958989298, 86.9884821676439, 92.16968213358234, 91.88291765028431, 95.16303108584498, 94.02301772948235, 88.65263400539276, 84.53170561021375, 89.2895798529348, 88.32493566697644, 88.51270737186556, 92.9322301187823, 96.41533405550065, 92.0723524401265, 91.7421280953192, 85.93162305893438, 85.50020940842168, 78.97836685180664, 82.5210359019618, 76.28684428430374, 87.57314282078897, 43.65129670789165, 40.53209066390991, 33.54290554600377, 28.088343835646107, 30.883495423101614, 25.800758715598818, 24.014852585331088, 11.39397152008549, 8.478289419604886, 4.199971998891523, 0.6849292437395742, 0.46909031428156367, 1.103103975615194, 0.5205189917356737, 0.290511051613477, 1.0248170216237347, 0.1238155669923271, 0.15061593494347988, 1.1996761613315152, 1.3753363225729236, 0.0739639121738653, 23.547713987288937, 3.0097912828768454, 3.890724244617647, 13.440056308623284, 9.13562668908027, 2.666349776329533, 15.546153360797515, 2.9289200998121694, 0.8053349150765328, 0.07294973433618585, 0.24918423935530648, 0.05495819773885512, 0.4851162301436548, 0.6059986533176515, 5.830843016024559, 2.0114432731943745, 28.03933382034302, 31.15070296872047, 25.778293340436875, 26.475686834704494, 28.274852537339736, 30.19041849720863, 22.809614135373025, 28.7930662785807, 32.19019382230697, 40.36972807299706, 68.98612099309122, 68.09600184040686, 68.12710623587331, 74.0879164972613, 72.89168773158904, 76.59394233457505, 80.44094024165985, 74.10348046210505, 77.67853260040283, 77.3614638851535, 77.4112387626402, 74.6096387986214, 74.96374253303775, 72.85585295769476, 73.07249330705213, 77.96386934095814, 76.45728695777156, 74.53215629823747, 79.00792583342522, 82.85803810242685, 97.62596576444565, 80.8529224703389, 88.0335977000575, 32.06004957998953, 42.28059699458461, 66.50492375896823, 34.52183500412972, 34.48137575580228, 16.064681872244805, 0.6446840097346614, 0.7335712304038386, 0.10029927241585909, 0.15315105778075036, 0.4837036252983155, 0.48258777227132554, 0.04088499020003984, 0.05399925101007666, 0.10850347653632203, 0.10614232460577643, 0.026250874150484323, 0.02413062048294852, 0.160911574418987, 0.17997478375271445, 0.2257979192560719, 0.25239230914702343, 0.19010041299606525, 0.21083798409710008, 0.18883520346735755, 0.1632130710828689, 0.09873058481682694, 0.06638766266405582, 0.027577332408738234, 0.12237201985572616, 0.14719037279005975, 0.05876962305797685, 0.05222058254143885, 0.07767817456155054, 0.14464611818473186, 0.03654403341633659, 0.1824983080188113, 0.14732420835043156, 0.053703376362400676, 0.45427420446949623, 0.19092841614638606, 0.03900729337586992, 0.01782318686075028, 0.12614589154479966, 0.3762006825737415, 0.18634186306547734, 0.023271337962679328, 0.021159333146868214, 0.08300188042583966, 0.06255996563742239, 0.2973943209696201, 0.11223803259312146, 0.062337520517288685, 0.012838505546472246, 0.03127696251706972, 0.10648395385473006, 0.03824625397101045, 0.034698305441246885, 0.10847782791261712, 0.08114351199999933, 0.0762939915782021, 0.043988389398662314, 0.08743087220336161, 0.3124985411282509, 0.3350523841236869, 0.18718616856682688, 0.3393826195068898, 0.47964345123017993, 1.0988285921273695, 2.102625019127323, 9.654840634715173, 34.01010297959851, 56.965719499895656, 70.35334156405541, 49.075820907469726, 42.595080867890395, 58.45390988934425, 68.19368454717821, 70.04658083761893, 91.4561951544977, 85.76354949705063, 66.23043629430956, 102.5008443094069, 102.02129533213954, 99.58006705007246, 95.85300737811674, 87.01247138361778, 97.98612563840805, 96.48263408291726, 95.95738164840206, 97.42306940017208, 95.75795265936083, 85.53261603078535, 91.63978561278313, 91.54174989269626, 92.75962229697936, 91.88493374855288, 97.28107959993424, 97.63209250665481, 96.79959297180177, 87.40046439632293, 89.0106208862797, 79.45602524665095, 83.81883836561634, 78.80351543426514, 91.16208014949676, 46.60856377693915, 45.85586486324188, 39.7390462506202, 33.62158829166044, 33.07157001187725, 26.075612921868604, 23.710833595645045, 18.622232944734638, 12.444022374768412, 8.893784130773238, 2.7413942785032335, 0.13886017784956964, 1.1420587498334147, 1.02983471366667, 0.7651498036519174, 1.570773441945353, 0.1106947408087792, 0.4220899314649644, 3.9378522576824313, 6.645512926963068, 0.05718333458888435, 25.048120598639212, 4.5907812733804025, 7.249236789441879, 30.343057532464307, 10.406338322547175, 4.172541393387703, 15.436259335087193, 2.875562382321204, 0.8016372844576837, 0.04903038941143502, 0.9686396715621796, 0.23992871745459496, 0.3584123354765677, 0.8886107562049743, 9.988987349694776, 4.863125162739908, 32.713002620204804, 31.459656300083285, 25.26165835319027, 27.885835786019605, 31.822789330636304, 30.615811309506817, 33.73843177672356, 35.970574194385165, 39.100962915728175, 46.19521264106997, 70.98265447924214, 71.47347634838474, 71.16436219984486, 74.41732498907274, 75.76643989932153, 76.98264137391122, 80.50424729624103, 76.41109712662237, 83.37330418248331, 80.33648752397107, 78.95043957617976, 77.50971378818636, 78.48603879251789, 73.03633689880371, 74.340438688955, 76.84758632413804, 80.26990921266618, 78.47300867880546, 80.24852445048671, 84.97958537070983, 98.00600421044135, 85.1173782348633, 91.41472001229563, 36.53026111664311, 56.264329110422445, 72.84008502960205, 46.969806225069114, 45.90873449079452, 25.74383924084325, 2.0685835038461993, 0.6302651931201259, 0.2927026453037416, 0.11626717243944446, 0.5507323963026847, 0.33814832928680605, 0.1416251730293997, 0.045628484053116654, 0.14246914145206252, 0.13481604566256847, 0.04229288360464477, 0.05373791543646686, 0.167486738533743, 0.04611999840445576, 0.13257271039389795, 0.25423899473201844, 0.32301018675488813, 0.31774685627991156, 0.33696613304557343, 0.16003785114134514, 0.19218841627720865, 0.0539856567798603, 0.14311049494051165, 0.10181428023403692, 0.05937643364192017, 0.0818741453751441, 0.20061457139109412, 0.19092896772969156, 0.008529121161348397, 0.12887697967310108, 0.09105845940329375, 0.0640613179383499, 0.10797334369271995, 0.6087031275514634, 0.39200354427579914, 0.1587556651042354, 0.15666910206838963, 0.20308051648880207, 0.3297547635532195, 0.2521198882811493, 0.14257204238205187, 0.11417782850443356, 0.12171506115625944, 0.3202779494947003, 0.21521027770734605, 0.4856411842328887, 0.17187885849946932, 0.20185503627984755, 0.19029335990067453, 0.27051198927144854, 0.21075903107562374, 0.1331615562160169, 0.2401841005250331, 0.18611179154005744, 0.1509088410004493, 0.2330074348156491, 0.2384492790987415, 0.3477323343676906, 0.49721545509753695, 0.26872280624604994, 0.3538250316294932, 0.6359687483599109, 1.2003253135950336, 2.1390540321027083, 8.695435754714474, 27.261816109380415, 48.6049246788025, 70.00455656359273, 62.878708224142756, 70.53259388093026, 83.96355813549411, 89.58501277431365, 83.10365692261728, 107.4780418026832, 105.69577170956521, 83.30890670899423, 107.88922386784708, 101.66240630611297, 102.26026181251773, 98.55664222471177, 93.73472352181712, 103.63072226124426, 100.8103733678018, 101.92165928502237, 101.26329729633947, 94.38087909452378, 82.81424876182311, 91.51459924636349, 94.45678480209844, 93.05604365564163, 91.89037015361171, 99.39998319072109, 100.03745463586624, 92.65139625918482, 82.45325734538417, 85.65220125259893, 79.60746011426373, 80.27901695620629, 76.2381362915039, 87.49958269057736, 53.86208526549801, 56.30473736793765, 47.7766691484759, 39.345012787849676, 40.531918079622336, 33.00121445809641, 32.08955757079586, 22.804571928516513, 17.47447486846678, 17.773637963879494, 7.829301405337549, 4.894193766578551, 2.6498162506088137, 1.088902789258188, 0.8118224540545095, 2.4617422780682965, 0.31678958345324765, 0.387665004499497, 5.007896413726192, 13.42669181285366, 0.182459237534673, 44.46813421864664, 7.657253011580437, 7.296829848520218, 49.084328528373476, 17.904197977435206, 7.434352069131791, 37.820371812389745, 4.95159863464294, 1.5617403460125772, 0.19764794186959345, 1.2231794937003044, 0.302351706571156, 0.8665170869038952, 1.1594366883077931, 19.105223801828203, 8.394485039095725, 40.884668596329234, 40.68090538824759, 32.77859641659644, 36.268235022021884, 38.59673830770677, 42.88836433041481, 40.1365117872915, 43.50119152376729, 49.21750084046395, 51.13329233661775, 72.95605382611676, 74.40196498747795, 71.7629001986596, 72.9027880391767, 71.17925151701897, 78.14303536568919, 80.65497613722279, 78.84796373305782, 85.01298827509727, 82.51702723964569, 80.91142069908881, 79.63111985114314, 84.0931454012471, 78.88851319589924, 77.24161978690856, 77.91953871327063, 83.12097810929822, 78.6698567482733, 80.68904584453952, 81.69842073994299, 98.0491816612982, 86.30986505939116, 100.55658817291261, 46.37224097405711, 64.01919618729623, 79.4514831419914, 63.75343207390078, 57.96495506840368, 55.93874492952901, 6.472715360503043, 1.135338871709762, 0.46459071218006076, 0.26968492074839534, 0.5579494961327123, 0.6333374508446263, 0.25617902046970786, 0.17648943609768347, 0.22270251035449967, 0.2334064593718898, 0.14261722624782594, 0.1320161321951497, 0.2216371578434783, 0.24217828867896912, 0.2758027763376313, 0.7970214514963089, 0.6273925472651759, 0.3792028892184458, 0.39370873342117957, 0.18678731254992947, 0.4459951229153141, 0.21704639127898603, 0.2613505889331141, 0.1913283753298944, 0.20167408631213252, 0.16857954763597058, 0.2494270892273034, 0.24830139963136566, 0.22618157608855158, 0.269408424294764, 0.30780619130499903, 0.21454258611606014], [0.01879695739086357, 0.18189397189886342, 0.13780683759720097, 0.017554295744987267, 0.09131104625280827, 0.03538452869942112, 0.21467410809090062, 0.044920201293162765, 0.049048403968974474, 0.051248313543657144, 0.1229704570986571, 0.05099969886003002, 0.43746136309158423, 0.07160194052924072, 0.18894331379523202, 0.05764481063271242, 0.13872605117578662, 0.09369887336487732, 0.0773437388782059, 0.055725683773597406, 0.08778693454880869, 0.2786855958402157, 0.023510529764837796, 0.010473391026138298, 0.04766599830961035, 0.09528955534821558, 0.0756128934482413, 0.13773336976526246, 0.2172739653577728, 0.16316730499027238, 0.7379666751911564, 0.5066531373848838, 1.3527521731392032, 8.999505735212757, 21.924188098599835, 20.644538364102765, 30.27811484952127, 24.401396282257576, 15.02879273506903, 32.055319201561716, 37.13103878882624, 74.33292342770484, 74.19695838805168, 43.679941777260076, 81.4316838787448, 102.68700784252536, 92.68696431190737, 94.80643272399904, 84.37086489892776, 98.94390567656487, 82.37295073847618, 92.97500748788157, 84.31373949973815, 92.65931160219255, 82.29841001572149, 92.42907631781794, 82.8027013040358, 90.88036767898068, 85.02604192303073, 93.5712940462174, 89.26100146385932, 98.93622567576747, 92.32474911597468, 87.43489496169552, 81.67742037004041, 89.08738167055192, 77.22545962179862, 80.76324139871906, 38.12241000513877, 37.019102188848684, 28.662100299712154, 25.77026620987923, 36.58366418653919, 32.87439246331492, 19.88762486365534, 15.94030547526575, 8.591017357764706, 5.68679936470524, 8.108206439402796, 0.5898645964841689, 0.043600438643367066, 0.29739107275682114, 0.20153007710412627, 0.4365838246960794, 0.21208100771952063, 1.6892320855009941, 1.5359874117758967, 5.219629387701712, 0.592171808163966, 12.724556173047713, 3.475174620266884, 3.417074266941317, 25.08830135868442, 11.188414808242552, 0.7619921730891351, 24.575806433154693, 11.909191512292432, 0.6412630900740623, 0.22422733175898754, 0.20821077749133113, 0.33226780773651216, 0.13584796609657426, 1.4631116125852832, 4.1733714649754186, 5.70006384003547, 34.375742404691636, 32.375468938581406, 25.038369586390836, 24.404710685053182, 32.48020406692259, 34.361182566612, 24.57287838382106, 24.18959221532268, 33.95984172821045, 29.625124546789355, 64.19244727780743, 73.73158485658708, 67.46956010018626, 69.96458761153683, 77.91667538304483, 76.62675688343664, 75.52968563572054, 75.35281811991047, 78.99877886618339, 77.66780099561139, 75.06134679240566, 73.74248120092577, 73.1584716612293, 74.02482125066942, 75.19445634657338, 79.81274127960205, 75.01525894288095, 83.90078452325638, 89.63779218735235, 93.84630710847917, 89.54082335195234, 87.8129957568261, 72.10218521856493, 23.61498263574416, 69.65234341159945, 48.2874951054973, 31.38577649670263, 33.18094530413228, 1.4987578675631554, 0.5749803048468406, 0.20692283047303078, 0.027826402914680304, 0.1313105805386459, 0.36063956757706983, 0.23105532021051456, 0.08492409461928953, 0.041470262221992016, 0.2039968802203094, 0.033610751702179836, 0.034821546005625884, 0.05979589359354108, 0.1771179039872462, 0.1445666595452255, 0.18529331852351466, 0.17909243432504518, 0.2201758144843963, 0.2638438374044434, 0.10398001079597782, 0.17353019166377284, 0.062027124673007965, 0.03473669410713258, 0.059230367487837235, 0.062435074153566555, 0.21763673863343655, 0.029662164085875117, 0.011546722342891079, 0.09795125123233565, 0.07767723227340369, 0.09350910572515381, 0.16201800456450832, 0.09715579915791751, 0.20284471462570852, 0.3238363972594661, 0.09015885001469044, 0.08446617322343011, 0.10327006945566786, 0.0443120232422746, 0.2816901926792437, 0.07879785802816192, 0.030380653052200234, 0.04642368331851979, 0.11001379589640325, 0.10747891820726857, 0.41620796966937285, 0.14141121999390666, 0.12225407295890393, 0.03933583401263722, 0.08821028239664533, 0.050670135495883804, 0.12506297263767452, 0.11889657005667688, 0.02398205305179281, 0.14088919236054345, 0.09049098743426223, 0.03949384730789931, 0.03908227040101925, 0.22865110647774514, 0.17096764287881314, 0.16993106463022772, 0.26038259087551024, 0.26687353128387087, 0.664340109834748, 2.024379495170809, 2.833427546485778, 7.394097764645854, 26.653546710168165, 50.22009395783948, 47.94843366069179, 37.10897545660696, 31.47360032604587, 52.71099513576877, 74.92312246753325, 86.21206468151462, 83.19528348984258, 53.808411552060036, 94.02896404266359, 111.05629459504159, 100.66924648900186, 101.51949867125481, 86.52505413178476, 97.56380404195478, 89.2953771160495, 95.50463030415197, 87.08051666136711, 94.7774071847239, 93.79357476388255, 94.70225457222232, 84.01330163401943, 90.04908407888105, 92.62881909647297, 92.29096966405069, 88.86736808284637, 103.38728427886964, 98.10097263705347, 88.93837867244598, 81.93451604535504, 91.96585224520777, 79.19960421900596, 81.73700901769823, 42.40006454529301, 41.935695140592514, 36.60981070610785, 33.589679810308645, 33.387473783185406, 33.382586509950706, 19.905595202599805, 30.23301543727998, 18.446520566940308, 11.438769890416054, 7.042045920125901, 1.7515629602055398, 0.19005602586173242, 1.1536860033389063, 1.0079063967831674, 1.22221949360063, 0.20708856593456962, 5.483564696004314, 11.733183976142637, 7.0066215242109, 0.3111019628422876, 17.79507567805629, 1.097858050657857, 6.350427625640747, 47.472399127098825, 17.748507338185465, 1.8697421348864034, 38.00734335376371, 9.04769891692746, 0.4115842613241365, 0.055883551512153885, 0.19728207359871558, 0.4635390879646425, 0.29595036780641926, 2.901794948885518, 4.664030555755862, 6.4592493734052105, 38.894281464238325, 32.468389887963575, 26.82618591093248, 23.451694365470644, 36.88211733295072, 34.35822902187225, 33.79869507205102, 38.87346544573384, 40.28101974917997, 38.7768574683897, 68.14424699352634, 76.15845726382348, 69.0470903150497, 73.69920961318478, 77.14204649771415, 81.56727237086143, 76.0967662257533, 78.45657394778344, 79.79804808093657, 79.51269565090057, 78.60138785454535, 78.22583660002678, 74.28590205407913, 75.20469373272311, 75.6310239914925, 82.42576153047624, 77.45078409871748, 85.20328598637735, 92.46447963099327, 97.00875728361069, 90.40843594458796, 94.12413643252466, 71.48774593107163, 31.001241053304366, 80.24944228510704, 56.41382240479993, 45.051300448756066, 44.94264295024257, 5.080313663328848, 0.302823371584377, 0.09663283689728669, 0.08709193958390145, 0.1530999903597178, 0.5542822025956646, 0.02169229477013071, 0.042181237780999754, 0.09066577805506607, 0.14616594469595343, 0.09677452485888235, 0.08489666867160028, 0.020214319642212604, 0.06124011105707577, 0.13546898240043273, 0.14473581175890662, 0.11814091624992511, 0.27068147856381636, 0.35291547075875346, 0.08128257994089397, 0.06494274423007043, 0.07870747497485531, 0.07054726728388379, 0.05304857037000118, 0.04553950294071148, 0.08158251868500825, 0.032007823803371964, 0.12426776571139214, 0.09677997940490324, 0.18820524936722172, 0.09644012747993393, 0.14243653675000514, 0.054273165747403145, 0.2767133790879481, 0.39562462738925414, 0.22925938028962384, 0.2706262283027172, 0.32824958464311016, 0.2119009923790732, 0.38671808918156936, 0.09764790339695831, 0.12629892526855394, 0.1428872875628933, 0.2428734521832197, 0.27348137670947664, 0.6224639665695929, 0.1496287234007351, 0.18840593375986625, 0.1654084186039625, 0.22058703516039158, 0.20130196676379253, 0.2407145551255634, 0.15976345376862636, 0.14630848301514504, 0.3354539367700777, 0.13324410985073737, 0.09936338876404109, 0.1577342707183092, 0.29908345291210764, 0.6089530560758807, 0.24739467328594578, 0.38971897815504386, 0.48663997902504863, 1.2565578832741708, 2.6167440510565236, 2.4229654813966444, 7.646440507904177, 26.01181753220097, 50.00839971726941, 54.002933656015706, 42.68942563764511, 61.45708045651836, 80.88541538484635, 91.53239896220546, 93.34212564652967, 108.91067966338127, 77.03406364687028, 108.93231545725178, 113.68259599131923, 106.08399221974035, 100.91000941491897, 91.41905815370622, 107.7108266276698, 96.32885363794144, 100.72749368606075, 89.56202768510389, 97.24802186412197, 91.6919296018539, 91.78170481035787, 85.19176990755143, 95.17547284403156, 94.64148136877245, 91.9309353059338, 93.74230154099004, 104.86504508603005, 96.55775531645745, 85.95317256066107, 80.24961486939462, 90.80955320788969, 79.11341405683949, 82.79738257008215, 50.661996026192945, 52.39956286645705, 43.3520394755948, 39.3106645922507, 44.86169307462631, 40.267656234002885, 28.71174966135333, 33.219176646201845, 17.824391472724177, 23.19830336878377, 18.255661956725582, 2.6794737817779666, 0.15147412195801735, 1.5905619220387552, 2.3106643461412, 0.7246747432697205, 1.101962320746914, 6.355095246145803, 25.199745701205348, 12.987735444499602, 0.4771884152245137, 27.130844246956613, 3.21756535960782, 11.231390257035534, 66.2783755025556, 32.539767219174294, 3.8507288165630835, 52.04763996985651, 22.199638505135816, 0.4191369383085159, 0.27040752552209363, 0.22789480915713697, 0.8186672351533367, 0.36650344969764836, 4.115012480366615, 12.283054186451821, 10.924688366151626, 52.12993914081205, 44.11224580580189, 36.546209473763746, 33.82664195952877, 47.19716248973724, 46.85712045238864, 40.93635759046001, 42.84176657276769, 50.17802261537122, 44.0195405867792, 73.4925477735458, 76.5618730360462, 71.28499861686461, 72.95690105807397, 78.90519111387192, 80.14320881136003, 78.75085369233163, 83.75386038134175, 84.39588962062713, 81.69604378361856, 80.8792023504934, 81.26723458690029, 79.60740520108132, 78.3846612130442, 77.53783718232187, 85.14079478479202, 79.69951029746764, 85.30079610886114, 91.20570475055327, 95.45667540642523, 91.58141289987873, 96.06577242574384, 86.2529436234505, 39.71622197858749, 83.40883301150414, 71.35737419128418, 57.635687781918435, 63.20334319145449, 27.125564736704675, 0.7465328864993588, 0.36510209102303753, 0.15362589439797789, 0.20596667613473632, 0.7197115966869939, 0.3706898750557054, 0.15463942872180095, 0.254923586222914, 0.5987949753480574, 0.12970319017767906, 0.23683667933988958, 0.13973025454869195, 0.21071997591324393, 0.3060499807038615, 0.24634461188989304, 0.27051952757662345, 0.47257650463331136, 0.4338545292135208, 0.2481546478285905, 0.3178702577227547, 0.17675923694285656, 0.1791190328977762, 0.22070810769594487, 0.0936541797953748, 0.3561882596583136, 0.3342992890506022, 0.18112702595610775, 0.30439630331050965, 0.2602626827936019, 0.2221750128533571, 0.33576646999966714, 0.21736401133239272], [0.05643765907734633, 0.06919400360915931, 0.050316854049601865, 0.12257948412650055, 0.1821342783589517, 0.12566386902284238, 0.07732536808978166, 0.1468587486493972, 0.17784680600368208, 0.106683925785605, 0.08070763861460072, 0.05477591860859145, 0.20418993437722807, 0.12641933896849233, 0.19559750754025676, 0.3350910868856215, 0.30440491413877857, 0.21486230525037936, 0.179715478312104, 0.46609150906724317, 0.06642784397568434, 0.23152700054549405, 0.060549475132457675, 0.06801906222056958, 0.10793848669216519, 0.11622984863577351, 0.3309843959587236, 0.1926542896657221, 0.18064330271895856, 0.14452248691551148, 0.1418308523153105, 1.0005243735448008, 0.8310860719892287, 2.4185050110663138, 10.31563155112728, 21.826568149751235, 15.419272530463436, 23.102826995234338, 15.60938883212305, 6.6841678850112425, 25.78315119589529, 42.021355782785726, 81.745402889867, 45.21627926057385, 69.03615474700928, 109.82088919608825, 97.00183822262673, 109.50215739588585, 94.70654564519083, 94.35932959279707, 95.19230765681114, 93.6880708509876, 92.58957970526912, 99.97916037036528, 93.52613187605336, 91.46483221361714, 86.93980555380546, 91.042126224887, 97.28371543269004, 93.84774269596224, 97.45375017965995, 95.14963226933634, 86.422240964828, 87.74091043779927, 84.16166920815745, 82.37455106550648, 76.94499446499732, 73.89357089996338, 28.99614699425236, 29.785163133375107, 25.70521370057137, 23.578102550198956, 32.252510478419644, 28.811779906672818, 25.81374176086918, 16.124364656786767, 5.8679917839265645, 4.520841490837836, 6.998818459049349, 4.054353761096155, 1.958224309548255, 0.25831262130410443, 0.05356595934098286, 4.196470793216459, 2.063966138708976, 13.22739520380574, 8.806073069572449, 9.145267874963823, 0.12479320243601838, 8.861040184574744, 1.9336229586793532, 4.181955572097532, 42.18425966078236, 25.14041985234907, 6.361480374490061, 24.238708134620424, 7.272754830698814, 9.572692475011273, 2.0087709133663485, 0.7382249387521899, 0.35695566525382383, 5.177359475243477, 4.123652481263684, 1.146483305961855, 3.0511232585676256, 12.766897178465321, 35.80597977484427, 34.39116908657935, 31.029199707892637, 33.90989034406601, 24.50741598683019, 19.840244593158847, 25.71643364044928, 26.764689030185824, 28.261326243800504, 42.3946399073447, 72.60727667039441, 63.88541983019922, 77.38630817782494, 66.0757537041941, 77.95879379395517, 73.19301205296671, 73.05641158934563, 70.8453558337304, 76.03287081564628, 74.31444906419324, 73.40056819300499, 69.62619689203078, 77.07636248680853, 77.69177452210458, 84.07036427528628, 77.44574777541622, 94.35623876510128, 90.45959934111565, 105.76007504617016, 86.28308311585458, 91.01048838707709, 38.50701801238522, 39.51918955772154, 67.12253232156077, 28.50068300001083, 45.85454302449381, 9.76129670296946, 0.36692985423630287, 0.14633425421291782, 0.3792296716522786, 0.011491384939290585, 0.18074125472095706, 0.26433287729178706, 0.04657304365067713, 0.04278881828330698, 0.10789341773957976, 0.09073949103514034, 0.007775052198989978, 0.08130942366176075, 0.318206325173378, 0.12550752579925523, 0.08473579786838063, 0.13375561143602097, 0.11441348481082148, 0.48666326809794674, 0.15633101214564618, 0.19571036761326177, 0.032965556282790444, 0.11276111742782016, 0.06970040304886718, 0.10704423991903182, 0.03583857752082329, 0.12349213233157513, 0.1335088698373687, 0.04165821040289537, 0.12102968059480192, 0.30074617014296595, 0.03374539548531175, 0.1935578137636185, 0.08925757821529143, 0.11754697594310969, 0.06808807142078876, 0.06132064221967613, 0.048910538786120956, 0.09744005608222178, 0.13844293572248953, 0.08916430701051029, 0.11584222346784608, 0.12032857990913814, 0.22981641814112666, 0.08206280218737741, 0.05397893052788512, 0.2558890408686092, 0.2281341350246822, 0.15205769709521724, 0.04720975847674474, 0.22858916060818782, 0.16795975186171072, 0.20573493453764147, 0.1628053744113253, 0.06834694019128239, 0.125390934878059, 0.013451471646887161, 0.0977516163801474, 0.06412210318470193, 0.09517091131138225, 0.4997406954005842, 0.43553710344337654, 0.16769022680819037, 0.17483778117645174, 0.37897603526230783, 0.791555138364915, 2.157306781699581, 1.561852256136556, 6.970855882090907, 27.170287601409424, 50.11036565226894, 46.75250299515263, 23.8396167755127, 12.462595778126872, 49.924661036460634, 86.13522544983896, 83.68572881144863, 51.54776134798604, 72.74231603068691, 119.97953768699401, 101.79618266320999, 121.04501032060193, 100.45431629303964, 93.40398142414709, 98.2022011664606, 107.05445720303445, 97.47385624916323, 98.18732753876718, 96.30691974393784, 99.7373305597613, 85.27495553416591, 90.68777930351996, 94.54016654722153, 101.55264269921088, 92.38626756975728, 95.3109593545237, 90.93135849122079, 98.39806864338537, 88.33776181743991, 78.41527138986896, 82.230725596028, 74.71431116903983, 34.7293479980961, 37.83840687044206, 39.62315982387912, 27.83058527977236, 30.57700534020701, 28.92309677216315, 28.718149008289462, 25.008412484199773, 11.514460848223779, 6.497882268121166, 8.776953393413175, 6.126113649337523, 2.158582777746262, 0.8899812568579951, 0.38471078560236965, 3.6983258589621517, 4.908114258320102, 29.083786472197506, 14.800064621433137, 8.75176981572182, 0.1331755143379973, 9.512444869164499, 0.3357849173968838, 7.561703583886547, 54.24417511109383, 37.63258049564977, 5.225927733605908, 28.92976087908591, 27.10586463251422, 8.927837168016742, 3.3871031913065144, 2.213897022508806, 3.4162262995396895, 13.106508735687504, 3.4115447055908943, 1.6497778219561425, 5.16487310009618, 19.306504149590772, 34.35127465955673, 35.39207950715096, 31.051865123933364, 35.19598453275619, 32.66932702833606, 25.782070582912816, 40.05108648730863, 35.01633213412377, 39.853791267641135, 44.86288155278852, 76.49956226348877, 66.75849714586812, 81.90975804482737, 73.53072028006278, 79.12281205577236, 77.23558718158354, 78.37134084393902, 73.53053200629451, 80.38241847868889, 79.5166572447746, 72.65956970953172, 69.04286200000395, 77.36759062736266, 76.36839820492652, 83.76507836003458, 82.18244906394713, 98.64458960871544, 91.35443318274714, 107.05797949144917, 88.8061006607548, 93.28113279035016, 41.166232016778764, 51.57668098326653, 72.81917095184326, 43.18433461650726, 54.780688670373735, 13.749162612422822, 1.4517764530835615, 0.1628374122083187, 0.22066194323762772, 0.04383175123122431, 0.24529620524375673, 0.38857481051837245, 0.07341763019681939, 0.10489696441518684, 0.04489806518259068, 0.07275222154754786, 0.10961174529286162, 0.11044337969994354, 0.27870275620971957, 0.06813663373430891, 0.035942474365114205, 0.2542233052513292, 0.09855912667849372, 0.33564585711686845, 0.1516317828528343, 0.1489459245555824, 0.14384333464887836, 0.13446490160159527, 0.0347851108639471, 0.09921913440789908, 0.12877714309480884, 0.011915412690160016, 0.16114818833528027, 0.16582144724745906, 0.10743026396319752, 0.38102017234890695, 0.15703723795952337, 0.05708666961459864, 0.0613992773146639, 0.11847877634629128, 0.1882525629574253, 0.1628586328438213, 0.22045983392144405, 0.21376514476874184, 0.3254277457392985, 0.2697828267851184, 0.20979889308012303, 0.16048680930849046, 0.3089000422868037, 0.15362400982168414, 0.19903246193162857, 0.3236009631185763, 0.39219102131262906, 0.13883233821440127, 0.21030351519584659, 0.5430936416791332, 0.2655485668970693, 0.3031333920455748, 0.42720779716487856, 0.19460778322912034, 0.2951920326919325, 0.1435991517838932, 0.14662406527467314, 0.1529481670548839, 0.24650559760630134, 0.538270719830067, 0.45638520571012653, 0.40470632393994643, 0.23902271123182392, 0.4103532806038857, 1.5752393055346705, 2.9968312815312417, 5.886786310903489, 9.193113926918276, 24.041236408295173, 41.422115679710146, 55.365325789297785, 28.29464677841433, 53.285602754162205, 87.48976892040622, 97.23608216931744, 95.93865625319943, 76.56288500755065, 95.66649867642312, 131.78440493922082, 105.8457866791756, 122.1821838809598, 99.6977146210209, 97.79521603738108, 104.44348442939021, 106.72566844571023, 99.46804415795111, 101.73833554790866, 96.95112197629868, 98.63960819859659, 82.59490197704685, 92.82176048524919, 98.90943588749056, 101.15991930807792, 92.33155835059382, 101.9549366735643, 92.45260269411149, 95.68640078267744, 85.79674059344877, 81.19546305748725, 81.0584468226279, 78.00648197051018, 45.67567509989585, 46.12856372710198, 39.531458731620546, 33.05558243105489, 41.64345895090411, 40.37393677619196, 38.98083248446065, 29.11345135781073, 12.677524993496558, 16.72698093998817, 10.100250282595235, 5.15619142401603, 2.8441199275755116, 0.9120632203355913, 0.82297804254678, 13.004189787372468, 11.995742532514758, 48.218826170890566, 26.145182040429887, 10.917868345014512, 0.26050611489242126, 15.228252122479102, 3.8760254075450287, 13.696713659071154, 66.76369820871662, 53.68415478737124, 7.278240265384798, 34.02268202074113, 47.14492436378233, 14.895282118551194, 3.0482199691957046, 1.1916459664221735, 3.8215738390722587, 13.957190417474317, 5.425573923895437, 1.4975003802007245, 9.774072843213236, 29.474580057205696, 53.638490553825136, 46.43335150134179, 41.38709675881171, 49.09601719148698, 39.25141719079787, 36.150018707398445, 43.09989383143764, 42.11644188050301, 50.837871182349424, 54.522824210505334, 80.61127308876284, 70.3398407659223, 82.28407767511185, 71.49806176462482, 82.58777895281392, 80.18729625209686, 83.43195930604013, 80.17067324730658, 84.6250109518728, 85.4011695615707, 81.5115668696742, 76.14094780337426, 79.11650488453527, 78.74016131124189, 86.04414801443778, 80.88393272892122, 94.93166615886074, 91.79427208438997, 105.10278778691446, 93.3818357221542, 101.23460123615881, 55.269463062286384, 55.65687164183586, 85.37543096849996, 57.175758500253, 65.9621383297828, 48.00883031660511, 4.640836110038142, 0.2949376608575544, 0.31288998141404123, 0.10908195718882546, 0.5561619985007471, 0.7249522509594118, 0.3120947821486381, 0.42429381320553444, 0.1665984442637813, 0.4125423615257586, 0.3239070918531187, 0.2078643525319715, 0.338921403932956, 0.14344809456698357, 0.1384133800503708, 0.33110228156851185, 0.21106532834950956, 0.5863858831505622, 0.17460968615787645, 0.3171679389572913, 0.31230481281395883, 0.29375433080619384, 0.2206651608069097, 0.22589700506819835, 0.17766816962149837, 0.24184706290402722, 0.3234984911978245, 0.1526526103336965, 0.24685144033883852, 0.6611292821265037, 0.26489840339749093, 0.2384484364020248, 0.3784977206059041], [0.1937419813006155, 0.07238926441078225, 0.046235972624872966, 0.14601386092122526, 0.05139062586691111, 0.2359037681092178, 0.031276577557887764, 0.02466138534908814, 0.06768864083794818, 0.017586714670723005, 0.03003770996245646, 0.07604943333013404, 0.14027462130592716, 0.19390028570928883, 0.16090463366239302, 0.04806933594086478, 0.06698251461550113, 0.15459111921729582, 0.05571541053453281, 0.08252661479937454, 0.2348038956763283, 0.06261173019846601, 0.14117619954049587, 0.05358192461332487, 0.007826742545265945, 0.09200692221882845, 0.29891102184211055, 0.30253893845985014, 0.33871517306373966, 0.18644433498622912, 0.123466981665021, 0.256805956183422, 1.8692786823357306, 0.4899726760002875, 2.1888644560690853, 8.663278202856741, 16.32232471819847, 8.632879834021292, 19.101677979192427, 13.848862398055292, 14.261694800469185, 28.62521040824152, 59.350787285835516, 72.77384404213198, 44.07747007185414, 100.68530467248733, 110.9238204648418, 122.77965499508767, 96.61810490392871, 98.7242058784731, 103.43287790975263, 100.76834124903526, 98.54911911872126, 91.24932935160976, 102.13171005249025, 89.93007936785298, 91.64189584793584, 87.65904272756269, 92.27114600519981, 92.93750178429389, 92.96513880452802, 89.55103720388105, 97.39951164491715, 93.13811532912716, 85.93149754308885, 78.49029848652502, 84.28345880200787, 46.73053772218766, 24.255205623565185, 26.051892388251524, 21.827782123319565, 19.034252435930316, 27.124799874521074, 38.18803125812162, 20.93231874127542, 19.868418978106593, 15.5535440867947, 0.47979406411609343, 2.732081836269748, 1.8629444222296438, 3.5049432035415404, 0.6033580401732076, 1.1225947232977038, 0.9709500701677416, 2.240274226473224, 0.7972721767521674, 13.807028358982457, 11.291786912948856, 0.29770449464840276, 2.9323867396000893, 0.9668991810852482, 2.765203065449192, 43.82379078095959, 22.14162665028726, 6.178098782416313, 2.9921626804336428, 18.926587297070412, 8.76169635403541, 10.424023309061605, 10.142262789510912, 6.069250068356914, 8.171350225325554, 1.0663677920256893, 1.007083802213592, 1.9966820459212027, 16.936933648201727, 23.596104268104803, 25.026400473810014, 36.9879860262717, 38.01675704217727, 29.73495483398438, 19.40597349597562, 20.440810457352672, 18.0609437342613, 27.3679397567626, 22.49164523616914, 49.067050487764426, 68.004453720585, 63.30960804416288, 78.4087916343443, 73.4391878497216, 75.5448808977681, 76.79796834145823, 74.96757076632592, 64.73785285026797, 56.448970763914055, 47.61688747713643, 49.29017451501662, 53.246735988124726, 61.495280419626546, 69.37482787716773, 85.81524633592176, 85.52462224037417, 93.8339045739943, 90.0454205851401, 81.94355318623205, 67.34877463309996, 24.654267564896617, 61.09979960226244, 39.357583984251946, 42.583623624617054, 28.713677506293024, 1.0286215981168132, 0.442378452468303, 0.170604701063806, 0.03126350235224011, 0.2559454709051117, 0.4420816700064367, 0.08280680379680089, 0.08398466398038211, 0.12244006378516076, 0.20055067965820914, 0.22282370546412086, 0.34241326333534333, 0.34418197649140514, 0.22606246473808445, 0.3176919737410161, 0.17727544230799522, 0.3535552461060786, 0.29566599596892634, 0.12115341911633169, 0.3431981050920102, 0.2877550962711534, 0.13951060181904223, 0.07083757630278988, 0.035280899985903696, 0.03712170967651952, 0.08144211775112538, 0.051262604913884596, 0.09397519361828605, 0.26344099773033974, 0.05354763451783408, 0.19069526494751055, 0.08365686261846174, 0.09438584738921735, 0.07981888469188445, 0.3511799751750885, 0.07833251324031623, 0.03935583656834018, 0.12118861319557314, 0.1869663932631093, 0.09601455031623764, 0.034179794151456125, 0.02737311635076279, 0.06932776256073868, 0.04990668291406286, 0.06993507110183278, 0.12269117208498141, 0.06172137132154838, 0.1967939989821565, 0.712980441749096, 0.07989924731514148, 0.16689013990183033, 0.12291897599014545, 0.14245740498506254, 0.12759697698657552, 0.1214172061712992, 0.041894923910618796, 0.09334538507485583, 0.04742232872353447, 0.08429635451325486, 0.0515691856403024, 0.22437154014985408, 0.43558355901510487, 0.14259704749190039, 0.11139594108587313, 0.13301043771207333, 0.33950084219536475, 0.485976271090969, 2.3215386271476746, 1.598835058750645, 6.584091061545957, 24.27085784173781, 33.94952981702743, 23.278145174826346, 17.025851818823046, 11.393607720252007, 56.474466170034106, 83.68762723861202, 82.90437698364258, 52.84463420990975, 105.43565580921789, 118.772593006011, 116.16849222490865, 102.67849629925144, 102.31063289027061, 103.33894498886602, 99.97630488487982, 100.13953039723059, 93.67261671250867, 101.17878590860676, 95.12706295136483, 98.63628987343081, 88.43173396202826, 93.99319202669206, 94.86376993117794, 100.57427021764941, 86.8223148776639, 106.44654473950787, 90.73007814345821, 95.29018648209112, 79.70401317842546, 84.69475069353658, 53.14119285152805, 31.637037646385934, 36.302445934664824, 30.19393097969794, 25.58231015359202, 33.75667864276517, 36.993696997242594, 29.364075122341035, 26.636880559305993, 15.67778810378044, 2.6822741089328646, 3.4779156215729254, 3.7215497224561633, 5.203374595411363, 1.328372313610969, 1.094461645810835, 2.194311647645889, 6.208743770276347, 1.267121684166693, 17.977275656115626, 13.89337835773345, 0.09942353432697636, 4.489799362997855, 3.917630968555328, 2.9396318476046286, 46.272742209895966, 42.4035515323762, 10.739121033299355, 2.9053464099284145, 48.12810567117507, 26.54811732230648, 17.574246237354895, 17.33251644719032, 7.227951557405534, 8.029805123806, 1.5850783259637895, 3.3160847569665606, 5.3507493195995215, 24.689800316287627, 23.968458790932935, 31.00017220743241, 40.69110747306578, 40.48395533715525, 38.395842352221095, 25.195295772244855, 29.212279396672404, 33.79607100640574, 40.631687487325365, 33.11813246819281, 46.970076868611, 77.6456396041378, 66.91801209603587, 85.93381958623087, 80.1583020917831, 84.052352751455, 79.01088330053514, 81.02258066977225, 67.86827687294253, 62.81138074013495, 48.92443310829901, 54.39417831359371, 53.50232547329318, 66.50935603726295, 70.47386815471035, 90.77333404171853, 86.2076324032199, 103.08229646375104, 91.55294433716806, 88.53038941660236, 65.3941281380192, 33.53104822097286, 71.44494502775132, 48.0616097296438, 52.25445478193222, 33.18191020719467, 2.859899132482467, 0.29874110354050515, 0.14350712930242862, 0.06698971584198937, 0.09672522710095491, 0.5522119265890891, 0.0899907703241033, 0.044576587876485246, 0.15886618094819208, 0.04359786075750186, 0.16849264262184022, 0.4622510796593082, 0.41560352629711556, 0.17253305162152938, 0.174074083446495, 0.17717997243087139, 0.34967822833887996, 0.2937146474517161, 0.07807527623710134, 0.39410654755849994, 0.24351236951206964, 0.05672456666586861, 0.12342910627804457, 0.031159925349657575, 0.06752713418175137, 0.04029267016918429, 0.028128881240263585, 0.05016837854899707, 0.2725668515889876, 0.0731758222043995, 0.08538763910051315, 0.23793946290689133, 0.05746209866277153, 0.02492251407895838, 0.32583352719103137, 0.17556037062839155, 0.14381993832367082, 0.23730996845951005, 0.24640055163012398, 0.24587749743894224, 0.2975943312048912, 0.17317265842951116, 0.1992055518372405, 0.12596344004475302, 0.27173840410767064, 0.18819116867117344, 0.26596372526499534, 0.37989203127161153, 0.7391243259752951, 0.1567381265903673, 0.2478130032578784, 0.21053743248264636, 0.240177849247571, 0.20928426585610838, 0.34467236469349555, 0.08480068551556719, 0.17816787345274804, 0.1767518212117495, 0.22610167311804913, 0.16787100823656206, 0.4095917892071509, 0.5934754446629555, 0.3342383390953464, 0.4214466014696706, 0.15473810084644826, 0.3299305041230494, 1.9559547281072986, 2.4595739428074133, 2.9344359328669887, 7.646641039079236, 23.84848721565739, 30.984939682868223, 37.37895611793765, 25.87763717097621, 55.56848103000272, 102.62680730512066, 85.94982285653391, 85.14121840077063, 75.25343310448432, 125.60434202994071, 121.2263414936681, 127.99237512773084, 106.97014193381034, 103.95153291763799, 104.6581792831421, 105.47855084942233, 102.77552004783385, 97.86198262245425, 105.87891501765098, 96.45943718571817, 95.53656624209498, 87.58399994142594, 93.24183064122354, 99.97243742788993, 98.56447912031605, 94.33594442182972, 108.95563002555602, 94.38309131130096, 93.56959173756262, 79.9273294018161, 87.08393696815737, 63.595148747967144, 39.054361235710886, 43.48814572057417, 33.45748809076125, 34.46596084102508, 39.54755613880773, 50.98627798018917, 33.77586687764814, 37.990806641117224, 27.906845961847615, 8.071379796151193, 4.649274108871337, 6.9003125448380755, 5.9970892437042735, 2.059155596840766, 1.2221644578441497, 4.563582087716749, 11.991620121463654, 2.7451474964618687, 20.153516454081384, 20.297724354651667, 0.3465096886840559, 4.579701558236153, 5.076894827427403, 7.325368523597718, 51.59711260949412, 67.68656915233981, 19.580850408923244, 1.849573675182558, 70.00097936199558, 41.69317891520839, 32.03742927120578, 26.474098274784705, 13.843578965433183, 10.947316519675717, 1.7282447146792568, 5.3475976951660655, 7.9901416263272695, 36.689564258821555, 43.272607557235226, 42.13412784760998, 54.29826459577007, 58.71666554481753, 46.86049369073684, 37.67969208378946, 36.07379528783983, 31.91420997342756, 50.54285795457902, 42.33010907326975, 58.70545541086505, 80.76712454518965, 75.5806136900379, 87.25382266506072, 82.45051168626355, 87.43670709671514, 82.8699307287893, 81.22503772858651, 78.82219376102572, 72.08869226517217, 58.63779844776277, 56.60056252633372, 61.14650326390421, 69.17623043060303, 75.33337885333647, 89.57631295727145, 91.05687433673491, 102.80816201240786, 99.72862289797877, 97.2661118353567, 83.92127498503655, 39.3654404917071, 73.5122694507722, 63.95111168584516, 56.74894186758227, 61.58206285968904, 10.844113076886824, 0.42864945206430655, 0.19476869233673622, 0.11000693174860171, 0.30483720223269156, 0.7565563196136106, 0.371737944623155, 0.22383319484370373, 0.24484114901673412, 0.1952516494859611, 0.23407271071787805, 0.4279465817155377, 0.3591286583292869, 0.45021157892000296, 0.3166587662792975, 0.3007555164156422, 0.6306266027592844, 0.426756969743198, 0.26172223350694107, 0.7399289021568914, 0.5403148262731491, 0.1532286471657215, 0.1940361743852977, 0.18019282769772316, 0.16131930173404757, 0.15528565452944848, 0.11583376585716203, 0.23594553522284956, 0.2253800336151354, 0.12508642258903674, 0.41360504805080356, 0.3686000178417852, 0.1421841414224717, 0.27864266427293904], [0.26543255054181625, 0.3291425367276515, 0.03571217684375663, 0.06974846740523655, 0.05338780942463106, 0.08530306299367259, 0.13518779748870483, 0.02753952022401556, 0.09726030887254784, 0.19366604666556084, 0.0670078874475533, 0.1696866059735898, 0.19592568428526003, 0.05553179458084126, 0.16920901143983488, 0.06394876813095424, 0.12673799324059679, 0.013237520526613922, 0.043556327300686995, 0.17079069189006285, 0.15666513373294186, 0.10730439571723824, 0.07117926683877746, 0.0901433980212577, 0.18946875818073752, 0.007109609554566804, 0.267429159533593, 0.0973436132734341, 0.13246055512178329, 0.07916234734077608, 0.16888808188659532, 0.0945180971475859, 0.7133873876544737, 1.7954051302325342, 0.7014780299317452, 1.6098704020823202, 4.557034181010339, 4.63916665123355, 8.593210943283575, 11.088817984827104, 13.028619289398195, 12.630530095869496, 21.963415722693167, 82.18691272120323, 54.286724982723115, 67.15615487867787, 117.05897223564887, 96.12419220709033, 109.71604424138224, 86.64569054880451, 96.36095431543167, 92.71893162881175, 97.00856116510208, 89.45791229124993, 89.67481151703866, 87.75448968333583, 86.50413220928561, 87.41092927994268, 90.96021144620835, 97.80573583418324, 96.26149869734242, 95.18210164962277, 92.54538243816745, 93.75118178706016, 88.82606552493188, 78.33218774487896, 64.76300308781286, 21.92703966171511, 25.224764539349465, 13.32917678740717, 20.979769614435014, 18.128887030386156, 20.97944405771071, 19.442171089110836, 20.41110242566755, 18.50224764116349, 12.743766961559174, 1.2659686299101, 0.466718843146678, 1.1057769483135593, 1.718197686056937, 0.37034982394787574, 0.6990541277393219, 0.4012705115300994, 0.37873125484874176, 0.5685905799750359, 13.442477391612146, 17.144199532847253, 0.4596548689709556, 1.2070933633273648, 1.9462862082066077, 3.2831464082964006, 16.828299683909265, 33.753344628118704, 5.311425597436967, 11.430743740450952, 16.070557582762934, 2.9278350741632524, 1.088661195770387, 0.9057461205990085, 0.8990816459540398, 0.6241260096430779, 2.5693966304102256, 4.077441567374814, 5.8838960143827626, 11.20938281859121, 26.355783900906964, 30.174715288223762, 16.481369964538082, 30.216592473368493, 18.821728614068803, 15.751789500636441, 18.71181203472999, 16.644613127554617, 22.51555600473958, 29.127956282707956, 16.551515671514696, 53.56037262947329, 79.43824122028967, 72.28226123317596, 79.89397356587072, 80.4483142975838, 75.25841451460316, 68.1503031330724, 50.15100925199447, 33.91602493101551, 37.29886524138912, 43.82355543874925, 48.40155370773808, 53.71680067431543, 63.90203106787897, 80.54024680968254, 99.206908441359, 98.48863617066415, 76.14122236928633, 78.98229706671931, 26.67200146182891, 47.04620615128548, 58.528889917558246, 36.60884972541563, 44.54074905764672, 3.5264399984190544, 0.5463443059594401, 0.29903580224321735, 0.16373267787839138, 0.12602912442338082, 0.8001666407912009, 0.6762077310873617, 0.1624614928638743, 0.03417896294605828, 0.17400026321411136, 0.03888183498695012, 0.3388356633724705, 0.2635176065227678, 0.6599985976372996, 0.20380584853551081, 0.06902918745312961, 0.2673949613686531, 0.15050813105077515, 0.2138516514171516, 0.05017833003113347, 0.10492257473449554, 0.1157077290718594, 0.12506874127974435, 0.025445340358982646, 0.008204361168487419, 0.10794793255627157, 0.20902090014949923, 0.03595101241503031, 0.07032973661778436, 0.08033108341717914, 0.028624371587929708, 0.0347275699999544, 0.34045118958719317, 0.057148324370744734, 0.3128628619015217, 0.2917912151784666, 0.22153171350158032, 0.04102272514794623, 0.045495475867703083, 0.06731470566122763, 0.061150559209167, 0.16197695757352537, 0.02742821339427704, 0.1272156873657819, 0.16696622775446984, 0.15551108356204726, 0.2351682624148746, 0.19620172108613676, 0.054304176986578016, 0.2653259417462734, 0.4902210723488562, 0.07012779584094402, 0.12183598813510711, 0.06382631663713725, 0.14059671531281165, 0.20025276338621495, 0.12200261225863812, 0.010346730836787292, 0.09418885554036788, 0.20392728879326777, 0.04280820796867052, 0.1337732161365209, 0.09025302520322223, 0.06147846399295715, 0.07397475997887312, 0.14204889626031922, 0.2043242755556299, 0.5839662710505148, 1.6737410522276357, 1.418826214728817, 0.6415784118636962, 4.998647464859871, 19.114431565807713, 21.527299150343865, 17.68379803626768, 11.059568870452143, 13.617887746903206, 64.58610419304141, 98.16198118271367, 70.27040696913197, 63.632819191102065, 129.81322565386373, 95.00364949626308, 118.32556832221248, 92.73695099738337, 103.06939971062445, 94.94279784540977, 101.9161601220408, 91.34323873827535, 88.83918193078811, 86.901303568194, 92.0914779170867, 87.57563744821857, 95.72125496402865, 95.5040733275875, 105.64070163234588, 97.39195715996527, 91.70236310651227, 97.7487124166181, 92.3641061782837, 87.55893599602484, 63.27112959277246, 31.17856944760969, 36.71893496667185, 25.593510481619067, 27.959615568960867, 25.895444731558523, 32.05822371667431, 24.9304396875443, 27.6083771259554, 23.04422482367485, 14.092855395809298, 2.8869519647090667, 0.7754262296422836, 1.680812472777982, 1.8024770410791522, 1.1443514977732012, 0.8902183763923184, 0.8083154261112214, 0.5753463110135448, 0.5023480603291143, 17.262972824035153, 21.992351047454342, 1.9333151751948943, 1.8077190436663169, 4.0760883496653655, 2.0725580905714343, 24.978941755910075, 56.35951718976421, 8.030473397624109, 5.5687335710371695, 29.34476725516781, 2.9272928064869297, 0.14216174101156576, 0.890543504107383, 0.36383004799004526, 0.6079312786459923, 1.9686537692623756, 7.879608744575132, 12.532895438132748, 19.11875205655252, 29.95701982129005, 26.673040889924575, 22.667124232938214, 33.91711927229358, 29.89195554487167, 29.253325039340606, 23.62661638567525, 31.1423679321043, 39.902067799722, 44.0856639031441, 26.99805044358777, 55.085225412922526, 87.9592844747728, 82.85721440469065, 82.5274528995637, 81.83651170422955, 80.08332990830945, 72.73401629540228, 56.68161438357446, 40.08972183350594, 46.211415952251805, 51.84358650638212, 53.846423241399954, 56.867307232272246, 67.89239944950228, 85.65327598202614, 106.06427054251395, 104.19850887790804, 87.17366510821928, 78.71289299380395, 30.06463004696754, 59.481770915369836, 66.55670688998315, 51.21425005697435, 48.74073674601894, 3.312884838350358, 0.5289147638024823, 0.17832003383626863, 0.06527969268180671, 0.08567270807801716, 0.9238849375997821, 0.5077565491439835, 0.07358040855897051, 0.08025638984456178, 0.1801109175768591, 0.03268784174935953, 0.2745191806987409, 0.33443445760396223, 0.7610204058789438, 0.2297738849395706, 0.1752874441444874, 0.1605786479288532, 0.0838227819411024, 0.11616932002887612, 0.10899608639339287, 0.23905366118396484, 0.06247163953019246, 0.061136030351683024, 0.10737011073938302, 0.0216607223715513, 0.16277080852418177, 0.0840607441721424, 0.01286123920562527, 0.1062142679227456, 0.1192473080910502, 0.060275836186783935, 0.09959382035078541, 0.4246028224306722, 0.16799710630889864, 0.2982548215696889, 0.36866970119937775, 0.3698293131686026, 0.25412783537420536, 0.14865721666043805, 0.22302308750729408, 0.250173871735892, 0.38942032643864233, 0.12808122882439246, 0.16743755568900417, 0.23930843138406355, 0.24921036295352444, 0.3063066508020124, 0.22871688278692387, 0.19748502561161596, 0.44411734948235176, 0.663090099490458, 0.38871727222877167, 0.3655737560362585, 0.15614566483324574, 0.3475815682641922, 0.48047241965128534, 0.2972491013426935, 0.10287125174316669, 0.21406068616817076, 0.17891591234553247, 0.13088757743037518, 0.33282392628250584, 0.23304393124436182, 0.1936547085642815, 0.14660115924573716, 0.2556750725113577, 0.22425426741040524, 0.9061830358639841, 2.0317036634491337, 1.340199485421181, 1.0714356168623895, 3.9617056615890998, 16.72557673146648, 25.787626620261904, 38.127081548014, 30.14176541759122, 63.32453266266854, 93.21955942338514, 102.58346511471657, 80.79755429298648, 90.27573431691816, 138.91817646641886, 96.24075720387121, 122.91639666403495, 94.91924009015484, 104.45489068185131, 99.17901254469349, 104.12945947339459, 94.40025560317501, 96.64058008501607, 92.89695232145249, 92.05076371469806, 86.38133848867109, 97.0892600090273, 99.03911729012766, 105.23784283668765, 96.0270586321431, 103.26802853615054, 103.74010147586947, 96.57153068050262, 82.45853685563611, 72.76079823893886, 39.65161661947928, 40.94626941988545, 29.074168820534986, 39.392151832580566, 30.563535921035278, 34.47603348762759, 32.427571742765366, 36.321469430000555, 40.583924785737075, 33.03022823026104, 3.602591834722027, 0.7770836761882229, 3.9838310162867274, 2.8655377847533074, 1.2570273419541698, 1.5758813485022516, 1.2712930022708833, 0.7749798148870469, 3.1835687064355422, 21.063308254365, 29.833816212992517, 1.9507161575940348, 1.7266168084836777, 6.9532689548307856, 7.606215621194533, 29.6198195411313, 81.10751567348358, 30.004133370614824, 23.101520845966956, 38.1609159131204, 4.522223636027306, 1.715389023865423, 0.7784358520180948, 1.1156694110362761, 1.059510140649734, 5.164792691507648, 9.263044884127956, 19.4471211202683, 34.359268449967914, 49.24500450011223, 42.4910556885504, 32.57724350498569, 49.582626435064505, 35.80868621026316, 34.15563860247212, 37.727305735311205, 32.03251650256495, 43.22353870637956, 49.37203045814268, 35.39027913924187, 70.53997578159456, 89.11825072380805, 83.9068014391007, 89.37471881989511, 88.58441614335584, 81.30530511179279, 81.8869298504245, 69.70410300839332, 52.65624277053341, 51.41715426598826, 53.02780105221657, 61.36148837304885, 61.45040458248508, 71.83826461915048, 84.7501894735521, 107.58145901464648, 108.92239186071582, 95.64144257576235, 91.55951822957685, 44.28792484344975, 56.41501480533231, 83.41414390071746, 56.0463551552065, 69.36415903029904, 28.688754766218125, 1.0229475219403545, 0.27087609554010056, 0.3184103497093724, 0.19719558227206432, 0.9179323118540549, 1.134091190272762, 0.4692228168489472, 0.22830806762701084, 0.23295964625093246, 0.13795012668255838, 0.232806827031797, 0.5359173590137113, 0.6940933713509191, 0.7114246091054333, 0.6207398397307242, 0.3468996580810316, 0.2964588356835227, 0.212516620635025, 0.1383889878108617, 0.5931480493276351, 0.205812661818439, 0.23318968713283542, 0.2414955204773334, 0.16735327069557485, 0.19619356991062242, 0.2686342464820031, 0.170523802179002, 0.33983105673424663, 0.2722688740299594, 0.1592039031487319, 0.5326481860491538, 0.7718934611447397, 0.2703781996763522, 0.3264454169379127], [0.22521938497741378, 0.1823662804259408, 0.2881051065219987, 0.18551085685049334, 0.11862460118267806, 0.019473763513228586, 0.16653628388960517, 0.0883272563618037, 0.05921784195027525, 0.04577702850163464, 0.28763310443009105, 0.49284360581828707, 0.33879313017091445, 0.07614566929518216, 0.14820631262996506, 0.13878382952703586, 0.018244602251797915, 0.06347377829614186, 0.12124896560224796, 0.06854788505382116, 0.2270798601450459, 0.114118809090747, 0.1357953358561762, 0.2870351574834316, 0.14997064376309996, 0.11728796161591046, 0.12675131550960003, 0.030627264415905363, 0.17773498781025412, 0.16171046622818516, 0.1452123950566015, 0.24202975955220962, 0.4139450685151162, 1.7524918264919713, 1.7494059017589016, 0.3306627922481106, 2.4551602957710146, 3.4072739799176497, 2.1433571173298747, 5.6237654051473065, 3.7610291136849314, 9.702720026816092, 12.763268986055929, 32.854662941348174, 80.46752606668781, 33.79239574555428, 94.4416993664157, 109.22619512004238, 98.6405574121783, 113.07658195495607, 95.14625118624781, 98.91688839081796, 83.22070829329952, 74.71628019886633, 61.62684455994637, 63.432213491009136, 63.193019513160955, 65.35736376239409, 71.3520162336288, 88.98623943328859, 94.34880979599492, 96.61666931644564, 99.88491365986486, 99.20371563203874, 83.7296122889365, 86.32567221118559, 26.05805050942206, 28.82960315673582, 21.67043036030185, 18.053253927538474, 15.648217355051349, 7.852805718298882, 18.018515456107355, 27.593168135612245, 32.83802620826229, 14.082519950405246, 7.336448729038239, 1.580034280496259, 0.4836166283536342, 2.7074236110333474, 0.7103530666039837, 0.8323012100112054, 0.5055984181742514, 0.4315506883205906, 0.6278632316858538, 0.8139156514117796, 6.459317034290684, 20.367923013625607, 2.181489419552588, 1.0915628916794256, 0.6347195347470622, 0.1349334409760852, 4.201573306514371, 24.707356845178914, 27.393184131191624, 10.662369074360019, 1.3898748327647488, 0.06461205471667551, 0.05722747657508139, 0.2674647060132796, 0.19349609772043844, 1.1751184468307805, 1.6649529818565616, 6.434499707914169, 7.346038924109552, 6.7231562445240645, 15.467499052324603, 26.409632159817605, 24.53813991238994, 21.48208598936758, 19.024717154041415, 12.739571986659882, 20.20161451831941, 22.297666380482337, 26.457638048356582, 44.63615286734797, 38.70235204696655, 26.264759417503114, 52.97628856474354, 81.86199142086892, 78.5397203506962, 73.66766591225901, 62.405670381361446, 46.70262613604146, 31.9581405193575, 35.68779483918221, 41.91970755977016, 45.57344636609478, 44.88636870538035, 49.54186908660397, 62.28362583344983, 80.3998730259557, 100.1617310124059, 89.7711370837304, 78.0382453241656, 31.78122397392027, 42.38969772092758, 70.12642460484659, 40.88430773827338, 57.878572710098766, 12.273960171207307, 2.0094216590927494, 0.9172601156657743, 0.21209256032541876, 0.1304227765649557, 0.6994293269611175, 1.2507204158652214, 0.07342971140338529, 0.17990431898543913, 0.15939026169719236, 0.05398383732104013, 0.4373333651211954, 0.6228549165591117, 0.4031151593212159, 0.028927273177091154, 0.20219873396619675, 0.08307580791053273, 0.17385826115646671, 0.2618379127835074, 0.2050158078031194, 0.0384928691651552, 0.22389034500285504, 0.14845970387180007, 0.1790284200180923, 0.060664518556046876, 0.09970806704293336, 0.26939135585581103, 0.04071708670967529, 0.10018785258815174, 0.11817230287218287, 0.35849767767133256, 0.12176032929170517, 0.43367106647741416, 0.17023964484612789, 0.43697005558398466, 0.29018803830108336, 0.2584054711605272, 0.1246289991503281, 0.14947133829757092, 0.20596569554219324, 0.08513482242462136, 0.008164556197551711, 0.1626973406922433, 0.15385610381922415, 0.09715339364183527, 0.09173437877888642, 0.42604312901535346, 0.3469356029264389, 0.292860857781864, 0.08080723004475718, 0.09912631519499326, 0.0679470805992042, 0.03884022492134283, 0.22788725553020356, 0.11594025973951626, 0.06954847249172388, 0.2395691464264547, 0.10414001591984304, 0.17181205563247207, 0.24079756841303843, 0.3052351695875968, 0.12704555455955768, 0.17808758743828346, 0.0531921275861321, 0.06107295833287701, 0.08892113538158518, 0.118102956593277, 0.12796681359290116, 0.40025005177144085, 1.3729985899502233, 1.8829975397356096, 0.3622441234127168, 0.8260585127338287, 4.830297866175252, 6.531093466666437, 4.731308029543969, 7.887056344939817, 6.392402379743515, 30.632665734137262, 59.57793958725468, 98.06304331748717, 49.870061643662, 96.47017663524997, 120.41772919316446, 97.38397121429445, 118.51865091631491, 98.77190189976847, 101.64519494579685, 84.86815083411433, 77.3162389570667, 65.05389390453216, 65.55619262879895, 65.65894696020311, 73.85639467547017, 75.2860515348373, 89.26049940047726, 94.51278840341877, 99.72345321409165, 98.2418877078641, 98.83055702332528, 90.77873122307562, 87.25484248130553, 28.680929637724354, 42.662761365213704, 35.74739917632073, 31.80498177005399, 19.034293620817124, 20.436146759217788, 26.637023725817283, 32.95011774186165, 35.56674657329437, 20.801517501954113, 8.771271840218576, 1.6150045394897463, 0.8151941602268528, 4.365400902686581, 0.9324976044797129, 1.4501848288120762, 0.19456152684025227, 0.3202450690009902, 1.3027977246430613, 0.26401354120143, 6.9341282786861544, 22.253112177694998, 4.279033253269811, 0.6855346983478916, 1.7224601992676336, 1.6798463439749134, 12.399982002473648, 37.97887479105304, 41.50336757782967, 18.998388244259743, 1.7842999196821645, 0.1888773229814345, 0.178757761154444, 0.38563376833354274, 0.5381105155233414, 1.0680898351054038, 3.002006603825477, 10.195409924753251, 18.827612169327278, 21.605764204455962, 27.720972684121904, 37.403208132713075, 22.65473346556387, 24.97204230677697, 26.9689013496522, 25.169782715459025, 31.0831440648725, 32.759523891633556, 42.42215533410349, 58.928991286985344, 58.79978056876891, 37.29617841782109, 52.787073427631015, 89.06911911502962, 86.35044590119394, 75.73677893607848, 69.58594552932247, 57.11649933168965, 38.792539104338616, 41.36100907479563, 48.442962169647224, 51.32094244803152, 48.719854047221524, 56.1698470577117, 71.0915865436677, 89.19882405188777, 101.25467592670073, 101.91084923282747, 80.37622897855698, 32.22829180379068, 53.41313077557472, 74.47947886682327, 56.24738447127804, 63.38261119781002, 14.409191608428957, 3.3795384101329313, 0.40562216673166523, 0.24599912155780101, 0.17901749560429206, 0.8901231976286058, 1.1035191339831198, 0.27367504373673474, 0.13275620377352162, 0.09912465278419758, 0.07306127673796109, 0.3953302351217116, 0.5574964010907758, 0.6448934888166766, 0.39403272732611627, 0.09288473640598598, 0.09843285240593458, 0.23955601567943252, 0.17431638173518643, 0.26355352072465804, 0.10776735031076017, 0.22625590193896528, 0.047227118029108936, 0.17066410352145472, 0.12391430040400837, 0.125695692315217, 0.18005336905198713, 0.07426593467713365, 0.06853856176378266, 0.0828407951180012, 0.2606728156247447, 0.21181857664017908, 0.22695101947794039, 0.26149320386109814, 0.42118803147346745, 0.24412724700185562, 0.4085394295473253, 0.2046683869294582, 0.4088873560390165, 0.3478291372378027, 0.17849462527421214, 0.18601960051924954, 0.34747557233898874, 0.43274529518619664, 0.12994789398245274, 0.18680441163239941, 0.559781120429116, 0.4251639971569662, 0.3880856480569609, 0.23661357921458062, 0.2501740862405108, 0.3283105652418829, 0.23044445702145178, 0.31540722375915897, 0.25021576142359164, 0.33753411063263494, 0.32243001304807206, 0.13359087188878369, 0.21194424570327808, 0.36606607477991815, 0.28772760903643024, 0.2245001663123408, 0.24714826876598023, 0.16295263183213052, 0.42401452819185875, 0.21246423554276267, 0.13184881859248684, 0.19751686422574907, 0.40272488348907043, 2.600351240365736, 1.5867376111207472, 0.4787061273330643, 2.3508519703342072, 4.628152145493416, 4.7393925247653845, 14.001811300554584, 15.350016220923393, 36.82024194348243, 73.92603243550947, 79.99769672270745, 109.72323002353792, 63.19067393579791, 115.58238813954016, 121.31048417860463, 103.57311048815328, 119.05265023631435, 99.70201353872977, 104.57548787516933, 90.97107641158566, 82.42704806789276, 71.40062224480414, 74.63682082391556, 72.77196130444928, 78.6076714915614, 78.29253258243685, 99.37287176809004, 99.04466352155133, 100.69525964798467, 100.90590661571872, 108.20825376818257, 92.12074664331253, 96.94803899334323, 39.160990868845296, 48.37787435900781, 40.24442795784243, 35.123436374049035, 26.48208618164063, 23.873725706531157, 33.294266500780665, 43.90024954272855, 55.012190880314, 42.7022635552191, 20.14522260235202, 4.972881905494198, 2.5389048601350477, 6.827698686430532, 0.6714638082250473, 2.449822195114628, 1.217534835300138, 1.134336093260396, 1.0482973100677615, 0.7582059827062392, 7.908885315541299, 27.963679144459388, 6.9873028705197004, 1.2562981488243228, 5.491317750946169, 4.239154025431603, 17.176270792561194, 45.16181322836107, 48.20807495424825, 26.93210363388062, 3.6668061825536915, 0.24219878919182286, 0.3623079232150509, 0.5595104156001922, 0.7095385006358548, 1.7668322569900945, 5.351008686327166, 13.265563787952548, 29.599136883212676, 40.95545953319919, 40.68897370369204, 55.72420304821384, 41.353019206754624, 42.327732116945334, 36.367855379658366, 25.15027088503684, 39.260724975216775, 38.645226647776944, 44.94223502374465, 67.97145874269548, 62.21629834944203, 46.08127170993436, 69.2676922582811, 102.72731411841609, 97.2195533014113, 80.95007957950716, 73.31538215760263, 66.41876497576314, 49.38502527052357, 50.21019781789472, 49.768374196944706, 58.08899218036283, 55.63573006660708, 58.3536188064083, 68.84446067194786, 90.31233787536623, 105.64784819079985, 115.04128148478847, 98.41908470276864, 46.93790166608749, 46.6910159203314, 86.65803817010696, 63.12476634979249, 72.7959583651635, 47.211196730213786, 7.227768186599978, 0.9834020632889964, 0.17536785273301989, 0.3909910518315531, 0.7022106551354932, 1.5280544181023876, 0.49069926443119205, 0.3226221172559646, 0.2877086100559081, 0.12428285764350046, 0.2616792100091135, 0.6203662952588451, 0.5814644730379505, 0.6991830756587367, 0.4169364579983296, 0.16622347486836297, 0.36863798515931256, 0.3624715595956772, 0.2559719928690503, 0.1987058020407154, 0.3082092148402045, 0.2619140619231809, 0.19568470366779836, 0.19673704800586547, 0.3176742311446898, 0.42144840943717193, 0.17677138709733564, 0.14632670058598443, 0.30423842791107397, 0.3998795716512588, 0.36232995590375316, 0.44613105755659843, 0.42324718388338245, 0.37941555522622605, 0.418413873882063], [0.051106767308327465, 0.05981864257445259, 0.13431212834773526, 0.022147328014515584, 0.02408120589661262, 0.0749437156463823, 0.10940844087951607, 0.038043164062283696, 0.23223871154890907, 0.2452242389441498, 0.4327320571868651, 0.06975571459700024, 0.2122526573798349, 0.07077725453963203, 0.0456043484530622, 0.009727747115727154, 0.19622566899464977, 0.06561704716014286, 0.07156250232289876, 0.07914232946331463, 0.07422887900423619, 0.31791619235469454, 0.40827981767154514, 0.6158784909113761, 0.23531885997902965, 0.0744030031285459, 0.24898602176577816, 0.3551030807918118, 0.3426639885912019, 0.2504670076192387, 0.20430290170254248, 0.09113257074908865, 0.3650308142025625, 0.7320353160462072, 1.247144562582816, 1.6959631178648242, 1.152567147247253, 1.34776218283561, 2.3894544666813267, 0.8067127701736266, 0.8082943433715452, 7.8070277360177815, 9.644018815409753, 23.16270785947, 49.279831224872225, 73.25927657465782, 35.99757186828121, 114.37660448012815, 102.22059880533527, 108.48739316386562, 105.94521091830347, 87.21634049569407, 75.55067816088277, 63.719178015185946, 55.435426389017415, 51.93344016228953, 56.99809082092778, 58.376729411463586, 59.37370569475236, 66.94037745075842, 84.67569581923946, 99.25407102031093, 91.5351132423647, 80.19767484357281, 80.454237076544, 29.76135042405898, 35.14174992038358, 46.02298136680357, 25.302941299253895, 15.201515286199509, 10.348494149023487, 18.214255456001528, 36.379053746500325, 32.15567304242042, 18.482029784110285, 2.424639843163952, 6.740757880672333, 2.0056637833195348, 1.2114453556076175, 1.0054209624086659, 0.43227148512678765, 0.2607637042960813, 0.5009640458851091, 0.19292200675174115, 0.35856184519587025, 0.39942681368800903, 1.8901394403749898, 14.713436134399908, 2.4422667295702043, 0.5589641642666633, 1.1768609597798319, 0.9951661094542473, 2.3548324406147003, 14.035732938397317, 31.02161776634955, 1.0408981264598909, 0.07193450695805012, 0.1299819082862908, 0.09875683098911278, 0.42515216875941525, 1.6870024632061682, 0.7455832439084208, 5.540137040999628, 7.1434391890802695, 7.831200813093494, 8.022564918764177, 11.693279743194582, 20.25795348228947, 24.38365932433836, 19.36874039711491, 8.087572811111327, 12.575238404735444, 14.333750701719715, 20.547583256998372, 23.946626878553822, 20.921290997535955, 41.98620350130143, 57.63747246034684, 36.563044286543324, 46.152705915512584, 70.22681374703684, 82.47810163805562, 69.6916377159857, 56.73251890367078, 39.51649881178333, 48.06337479622134, 46.80834577929589, 50.44092339854087, 56.0531133990134, 77.38932055811729, 100.5104846339072, 110.38767953072826, 93.30205471284928, 82.13727904904275, 40.294238136660674, 46.91867028513263, 70.74930483295073, 49.20721246350197, 61.77508269586871, 22.756709206488825, 0.8258695648081842, 1.7220885546938067, 0.19715191526038034, 0.2687204160517262, 0.384267496485864, 0.38460503482530195, 0.4103596238118987, 0.1404349022214451, 0.12184628435680944, 0.23907501971529377, 0.2166772747953092, 0.7690754220370324, 0.3683300178137518, 0.19486915710712635, 0.6206090532002911, 0.18209917621026117, 0.2445888149762346, 0.09872527582751167, 0.038163068313752456, 0.2101979636016392, 0.22881503397178268, 0.16349725905926, 0.0408619654274756, 0.2872850553643319, 0.24882972450746646, 0.11963764521022958, 0.08605614274499879, 0.050109497031136874, 0.2651098743081093, 0.22611664247608956, 0.18788114820997562, 0.14979419839237967, 0.13996165906710012, 0.40519980713725096, 0.11124645434920827, 0.19183313534144433, 0.12721188756967747, 0.19447722652506447, 0.18728497858730056, 0.041793942030879765, 0.128375306995886, 0.05801104279535432, 0.03353551037669663, 0.1383757498115301, 0.06293201240740957, 0.217679915348849, 0.44997776888551255, 0.2051025902431819, 0.23486611733753837, 0.03856200476988189, 0.07848693358321344, 0.06613830870558178, 0.05718868188259583, 0.04225438768644968, 0.07051724429813123, 0.12054041088108094, 0.10888997555500078, 0.20454389764176262, 0.38425965174551935, 0.602539980844144, 0.27319418566842235, 0.12002405229835741, 0.17934746499503815, 0.3800573224021543, 0.2922628801916876, 0.08611881639808418, 0.159845287280698, 0.06116885721923844, 0.4988441273810402, 0.9850247600866903, 1.1264636511764219, 1.701603241024479, 0.8023855991421208, 0.20099217612897197, 2.033111794340995, 2.099074293528834, 0.06881871245681279, 10.588622631565219, 19.328351751450572, 40.23597132775092, 74.07203874280377, 95.03517750770816, 46.16705002323274, 113.28283586809712, 112.89806704367362, 105.78560183125158, 111.54752439068211, 96.3884501303396, 81.27652275946834, 68.2256361746019, 61.12434187243062, 58.44015805952011, 60.60381589397308, 63.15234453447404, 65.09078771837297, 71.52266287034558, 90.9004423695226, 104.9161143456736, 96.91385945966168, 89.7283754041118, 84.40719389146375, 33.227288107718195, 55.25043564458048, 59.53453071655766, 38.95971052108273, 21.38303045303591, 15.678346060937452, 19.53100100640328, 33.53608062190394, 43.40547392445226, 19.941029894736506, 15.801090751924823, 7.617334069744234, 1.3875144239394896, 0.7658907638922815, 4.132338079714006, 3.2893942536846286, 0.24375508148824018, 0.40201707953406923, 0.12692399172773286, 0.6847859546542169, 1.3870300112232086, 1.7553302741819814, 15.174326396757557, 3.3007009760026014, 0.6253687268303287, 0.5424831615340325, 2.0726338413453873, 4.385482457376296, 18.916540145874023, 39.77687751093219, 2.4800835261421823, 0.06690496353492623, 0.3347590950227553, 0.2397879411376292, 0.2062771715704472, 1.210486458674554, 0.46562529860004304, 4.717893523554649, 8.987483670634608, 14.918373111755619, 34.581321670163064, 13.463397352926194, 19.77478219616798, 27.409348218671738, 27.265828694066695, 14.109501934820607, 16.36107675490841, 22.57530546957447, 29.486570742822465, 32.790465508737874, 34.99325683040004, 57.080284087888664, 77.077601955783, 57.113251609186975, 52.77561618435768, 69.78331919639342, 93.12961947533393, 84.37807421530448, 65.10813243927495, 50.35259162226031, 54.7329887267082, 57.68538028963151, 59.82176196190619, 64.09096379433909, 85.81864310849099, 104.56550152071061, 117.35573091814595, 103.88242075520178, 81.66599842809862, 44.248967862898304, 60.30234252252887, 77.91186655721357, 66.05801674627489, 67.91962069849815, 28.59962282642242, 2.9317777916308376, 1.1273573387053706, 0.19980440276765055, 0.2678572494656809, 0.4960559657023799, 0.35885265217192713, 0.24944728330498744, 0.05866806278185499, 0.07857670376618063, 0.18399574944088537, 0.1793839154584754, 0.7042549454396771, 0.38535236891719604, 0.2780440125253893, 0.2886908267053866, 0.18875055075172456, 0.3124593174265277, 0.10558468154481343, 0.16063990431927866, 0.19778740051532948, 0.21780324018289968, 0.08200045795209947, 0.015489423531107606, 0.1594389848891766, 0.23962861017113735, 0.1374718426696716, 0.12509617488831282, 0.03651504464928181, 0.1298392473930313, 0.1068246714590538, 0.17652009493641316, 0.1697844813667959, 0.1625300577330974, 0.29828990839662095, 0.12433303640254083, 0.20717766196016343, 0.4353060513254135, 0.24297341133557984, 0.3188456102244316, 0.23312935004791907, 0.3302565817871402, 0.1821523733557232, 0.22814366515846024, 0.22367092209958264, 0.18912979491776039, 0.4067926877929319, 0.611233301460743, 0.2603265745264869, 0.40554313710139644, 0.2836385381317908, 0.22295679025832685, 0.10534193126424667, 0.3108647820209304, 0.2719479138332029, 0.41378838821284236, 0.24053207298199977, 0.24151896276781637, 0.46450579899453354, 0.308004301642218, 0.643207605086988, 0.40601906156347645, 0.19797247203607715, 0.23751181730579948, 0.3205448851710366, 0.23955053048989466, 0.24826110340654853, 0.23809850275997194, 0.41241151370829154, 0.6530452772013603, 0.9272862454095195, 1.0496273612783802, 0.9573466775398102, 0.8730755962671772, 1.0592114276462987, 2.316079423312218, 1.576834852176328, 0.5008181214572922, 14.436087300700528, 55.48083174613215, 81.88339187252907, 89.08851131316155, 100.74020216541906, 60.0481572458821, 123.73903536027478, 103.26368254999961, 112.04387680176767, 120.50383306318714, 100.51177117132373, 81.95146852923979, 72.15530980017878, 64.23745255316457, 66.53831881861534, 68.29098286167269, 71.23492563924482, 71.91471161380892, 78.13515924638318, 90.88688665820708, 102.79314717938824, 100.58206788955196, 101.05363876588883, 100.35293871356596, 49.27286901781636, 58.52768574991534, 67.96719120394799, 39.657205996974824, 30.398821869204124, 26.189591115520848, 41.876769373493815, 58.1934448980516, 61.99414314762239, 38.52104048575125, 27.47726013583522, 14.771610767610612, 5.119817324223058, 2.527762632216177, 6.837686021481791, 4.360949012541003, 1.303549961697671, 1.3306123547015654, 0.2535633817915955, 2.315427819567342, 1.5420408546924593, 2.1935509529805954, 17.941176122234715, 5.225285935786463, 0.9246205045811592, 1.7814465179558725, 3.3843415975570683, 8.244672071549202, 25.465201908542266, 38.634153796780495, 3.9436706035367908, 0.18927159779254468, 0.4297247330748266, 0.30051615990457997, 0.5134514016249488, 2.031790936185468, 1.1055765397125676, 10.451807418177205, 17.824530716865294, 24.55036005666179, 52.79785210086454, 32.1660045654543, 31.51940968728835, 44.99162158658428, 53.92522758053195, 22.628379060376076, 21.53668342098113, 25.040566113687333, 36.47328868989022, 35.51006440193423, 43.066012397889175, 67.18177580064344, 79.40534037928428, 58.24115660882766, 65.58689694250783, 81.64308394155195, 92.60719114734282, 89.35054917489329, 71.66244045380624, 53.79446360372729, 54.12005562936106, 60.97046729057067, 61.52136418127245, 61.9358253479004, 80.08755037861486, 103.61455425139397, 115.23591733747914, 110.36394919118574, 101.17138047372141, 59.41672625080232, 56.54611218360163, 79.66090633023171, 72.70190777317171, 77.56148907446092, 59.52306170617381, 14.901823651406074, 2.0330137350866875, 0.1507966091195422, 0.1879388805959494, 0.5579398127813493, 0.6265906064260391, 0.2887669145580261, 0.20153530182376986, 0.18750824725195286, 0.15136386658395493, 0.13149434970992227, 0.5261559892565973, 0.3747026436030865, 0.27159965026282495, 0.5862818790539619, 0.31759069691742625, 0.4660474743333555, 0.2309326082468033, 0.18575410508821089, 0.33494157716631895, 0.34029172072487496, 0.25958117097616196, 0.2502979166925915, 0.19691678755466016, 0.21517630936878346, 0.1779381543277733, 0.25749790211839063, 0.14940953032383997, 0.34902257964976374, 0.2444284727736827, 0.31093351542949677, 0.5561151752068151, 0.2919240241810199, 0.45198890290433363, 0.22707042194181876, 0.40882772375499055], [0.4284142937150694, 0.19347971876061734, 0.1406307142948912, 0.05073849735180697, 0.3443430081730889, 0.09734432573520369, 0.024750276446162213, 0.27516854746687797, 0.4507336525186416, 0.22804661714021238, 0.1986307254241359, 0.3383786766038787, 0.2509119514856608, 0.08968559919946617, 0.035906058375633536, 0.1425499790498326, 0.07081963452360324, 0.23044165313964893, 0.23492300702679544, 0.09228838292220909, 0.157653555694607, 0.11232778745433016, 0.42686946209399934, 0.5719939715439274, 0.2606947563828961, 0.01263169628087311, 0.05302108696571762, 0.2618370547650322, 0.7066904921685496, 0.2318324091573877, 0.1800091198134807, 0.10363357817573894, 0.3252218519487689, 0.7041370291863719, 1.0067616162761566, 1.9433587717433132, 1.2148217808815742, 1.2469170651128216, 0.7500365436557801, 1.661372961055848, 1.6694738812023595, 1.2451132651298278, 13.792932341175696, 19.973030551787346, 33.78350373237364, 69.55171892719885, 83.05988327149423, 54.677518567731305, 116.70731606022005, 105.96299494466474, 105.54427408402967, 90.66622980179326, 76.82780973372921, 63.93840712885704, 60.601199673068145, 59.192009741260165, 54.171124889004616, 54.61463120675857, 53.68387237671883, 60.77560394041, 78.36276654274234, 92.39015856096822, 100.31715885285409, 73.29558203297277, 34.340421461289935, 47.8271225960024, 63.05530509641094, 30.645132987729966, 20.82385540008545, 20.713819188456384, 30.454666614532474, 28.99823565636912, 23.40072120389631, 27.934029948326852, 27.75145930628623, 10.752644385060957, 4.024684707964621, 3.2161317333098385, 4.101018199036199, 0.6138091954973437, 3.005593856496196, 0.5935819002409136, 0.1864502032197291, 0.2881826959069698, 0.30249039912896775, 1.2920066714286804, 0.9424360937649204, 5.513501205751973, 1.874821113963281, 0.21576169247348465, 2.3641537081810737, 0.5583409977055366, 0.9352732329599319, 3.7556137913657777, 14.677344445259342, 0.817784395429396, 0.17733459961750817, 0.16473194764506432, 0.6658549414527032, 0.2694550637275942, 0.34420912664744163, 0.8430804348280354, 5.938225253935784, 5.1889559626579285, 6.198134739552775, 2.8010608832682333, 16.797120763409524, 11.79122720995257, 13.440139658989446, 17.192360355008034, 21.463921493099583, 21.225637505131385, 17.571351528167725, 29.78469441013952, 35.516595148271136, 31.103442330514234, 21.11511099723078, 21.47027377159365, 32.39166244383782, 42.862433541205625, 36.014222329662694, 49.909379482269294, 69.3351334910239, 82.73454619992165, 83.31568456465199, 75.70647470412716, 81.2606450050108, 86.50898810355895, 98.5617805296375, 110.43193171101233, 109.14734763483848, 102.4129439938453, 81.94679306399438, 47.786333868580485, 53.73439642690844, 65.94380517159739, 64.42564002929196, 78.64834647024833, 29.617913269227554, 8.010435479302561, 1.384263514511047, 0.4260488287095101, 0.6094737507162556, 0.2627323051133464, 0.5465025490810794, 0.5993417169778579, 0.10908603277658263, 0.12806017672823322, 0.09954950982524503, 0.5039600012523513, 0.8762373943482676, 0.523087899050405, 1.1464096389470564, 0.27714808801970175, 0.08536562939444858, 0.09650070205210678, 0.11043065497952123, 0.10057458143320777, 0.36558684081800524, 0.2336264185367092, 0.2536090865971581, 0.2609263294406476, 0.13336029474533376, 0.230598088293787, 0.31455190191345833, 0.17124286762649016, 0.11940126112031361, 0.1244059986164493, 0.16686072212553796, 0.11184135226592903, 0.09655130215950551, 0.2183459981554939, 0.2704335418680022, 0.2557949193062321, 0.1392726089444853, 0.18758922274554932, 0.3216192775195645, 0.13608704681598371, 0.23187904859021788, 0.05128852932924225, 0.19202850308389435, 0.11711310970807269, 0.1927224255257076, 0.15354042962914513, 0.21625057914324347, 0.08263904586314194, 0.12317236723198045, 0.2571775547919735, 0.32986413026528977, 0.12407714005319342, 0.03602102519043031, 0.21129955207147907, 0.010447778791609791, 0.13726286920568637, 0.04778587574800176, 0.08180779450002217, 0.03246843799828522, 0.23108982481062415, 0.24031853363398584, 0.34634473463219984, 0.29042613842794973, 0.0984868539437171, 0.0328607784373866, 0.22847274588721417, 0.5105859569964871, 0.27222456350441904, 0.17419642768800261, 0.029130437779390526, 0.04666536490643217, 0.63750944310619, 1.1300672061981694, 1.4747147189994014, 0.8511692201418262, 1.0778578851492175, 0.39342978548619056, 1.873614985135294, 2.453075065728157, 0.9826661285854156, 12.818123332915768, 35.258801291065836, 57.55518505650183, 84.1722752971034, 100.16286065501552, 57.43674908914874, 117.7031901574904, 113.13912022498347, 107.36903129085418, 94.12353238751813, 86.22456135288363, 71.14594274951567, 66.41492889773461, 63.15358792581866, 57.193922996521, 59.46015081098003, 59.58430559404435, 66.71106784574448, 84.06888161936115, 97.24636662390925, 103.96257046730288, 68.26714269576534, 41.17286082236998, 69.30684535734116, 71.23119938758113, 39.43965173536731, 29.03184448519061, 26.804014713533466, 44.08278488343762, 44.295302821743874, 29.36691099597562, 20.165817006941765, 19.21085911412393, 9.971355315177671, 4.212137229980962, 1.3681784873047185, 4.750212382885718, 1.9413792005469723, 4.4656674708089525, 1.453677454302388, 0.7628798544887574, 0.3522268802888932, 0.8003846387709341, 1.8447397216673822, 0.68344101069435, 6.659537851810456, 2.610481251632014, 0.5405440397800938, 0.8031027800133153, 0.4484369209216487, 0.3485948574398795, 8.696237879414713, 22.46547322119436, 0.9087312281612427, 0.2326603050553991, 0.32152321009385976, 0.2607095265580762, 0.2008144590522974, 0.13175993707151185, 2.366247763556819, 13.715786184034041, 12.776737424635119, 18.89775199274863, 19.785176477124615, 40.53095317655995, 18.465057688374674, 29.551523231690933, 33.31250159971176, 21.476626050087717, 23.14803623384045, 20.37128644604837, 25.81943900354447, 39.10960389721779, 41.97540913858722, 32.61095823780183, 35.64594707181377, 49.690217048891135, 64.7873688513233, 50.315917461149155, 59.19672443020729, 77.15436274005522, 85.33579934027888, 89.33624036850469, 84.30325892663772, 88.3450888049218, 94.35193984739243, 103.62767065725019, 115.81590252537882, 115.59151941730131, 104.46472798624347, 79.03468424274077, 51.07080897977276, 61.520842506039536, 71.4511109936622, 78.44232005457725, 80.92562752385294, 34.55875627456173, 9.832973114905819, 0.7146722703210769, 0.3997231671406377, 0.47827252156792155, 0.4763445234106433, 0.3607602417469025, 0.284338895712168, 0.10390619056359415, 0.08187288133006904, 0.09248771900010687, 0.4371365111681723, 0.7483113749373345, 0.584912481567552, 1.3347710476767634, 0.32457980898118793, 0.061777540888156623, 0.22914777660081465, 0.07111236438035004, 0.08741050192545499, 0.37119901709018216, 0.15343003635925634, 0.27567422678393705, 0.22196832233138625, 0.08940164871033161, 0.12998799102440958, 0.21340611000214854, 0.18401389040293234, 0.06886400357489625, 0.1287928325754981, 0.16471659524306176, 0.09053374280131633, 0.19090086762462893, 0.08701462599058306, 0.23505157190224818, 0.2243486341209181, 0.19109856427436878, 0.23338362995174625, 0.5893092746696165, 0.3600167380946298, 0.38454166403220547, 0.19603161892342955, 0.39338777322442303, 0.24307398335827937, 0.2771287519604929, 0.3456889633690158, 0.7225780525515157, 0.2259353860732048, 0.605904516433516, 0.515054578502332, 0.2905261895108608, 0.23337866570199692, 0.14372457569885638, 0.20968506773633344, 0.06344334545334981, 0.298049234214329, 0.38678357437733685, 0.22622337384570032, 0.35679129342879023, 0.3451381461514581, 0.3347865822574785, 0.29563771200276195, 0.30083083818035744, 0.3731300489556405, 0.17229095251569826, 0.33598079075736387, 0.5368424255040385, 0.32681280206288066, 0.17065095745267408, 0.17883360385894778, 0.3851286405997892, 0.9839264964384418, 1.090349653555501, 0.8720153305799732, 0.5661516011722627, 0.8331910364570156, 0.4165246397737534, 1.4608783130684209, 2.161415464455082, 0.3903913275609094, 26.536703225105043, 65.07308213941513, 85.91547858330512, 98.73171329498292, 95.7915359927762, 73.1960322779994, 124.75981650813934, 106.66136510910528, 104.70382782720752, 99.76666988865023, 88.01456635998142, 72.98125113210371, 70.62171797598563, 66.84715840124315, 65.73401720293107, 67.46482187701811, 63.76727019586871, 72.41181711996757, 89.49475119190832, 99.75870747720042, 100.0684178260065, 79.35260803468766, 53.5728967574335, 69.16796207427979, 78.80655134877851, 49.77391650599819, 37.407969890102265, 40.76140026892386, 47.65197700069797, 52.78399436704574, 48.99334522985643, 37.39923084935835, 44.6421697831923, 19.417660197904034, 13.885266896217102, 17.665684530811927, 13.309881667937002, 7.10514557938422, 10.500762520297881, 3.650435925491395, 1.0952350881791886, 0.5330393811868084, 1.278611041845814, 5.788193614252153, 1.287511022340867, 7.854409967699359, 3.414829690610209, 0.5669693540661567, 5.065920525981534, 0.4117206556181754, 1.109515457384048, 12.987217691636856, 25.106026549493116, 1.1140515559142636, 0.2787205600930799, 0.8893895918323148, 1.4901402977205094, 1.5944513197868102, 0.7140837922211617, 4.080505183627529, 23.0799223146131, 19.90827222024241, 41.79328956911641, 45.09939262943883, 65.25078512007191, 36.71683257625949, 44.9793210337239, 50.50550130105788, 40.16737691817745, 46.438364290422015, 32.00023147367662, 44.37184787565663, 59.86399804392169, 50.31395235369283, 35.819127559661865, 43.7437391281128, 60.54425862527663, 71.24524931753837, 56.78767919540406, 78.1271105427896, 88.0680125759494, 90.77316145743094, 82.7036379229638, 81.13758456322455, 82.62038169368621, 92.91749769641508, 99.73335327640658, 114.12224661919379, 118.06721748844271, 121.95951877101776, 105.36446479059036, 64.54089887680547, 62.046738209262976, 73.10846928627261, 83.323105689018, 91.21077245281589, 58.9735847134744, 26.568341062914943, 1.7990356515492163, 0.18950925358841497, 0.24938762037744447, 0.5895774054431147, 0.796477345208968, 0.5125713811045693, 0.17456966572471205, 0.1250453066501406, 0.22744425752710914, 0.4560200575618975, 0.6772035841018923, 0.5551052261744777, 1.3450244910294011, 0.5214341910135362, 0.20677221758711725, 0.348623049475493, 0.2594497409318724, 0.3646258907693048, 0.5907548519392168, 0.6614149409917094, 0.4086136481454296, 0.408653668578594, 0.26872951717626664, 0.3277820565046803, 0.2049175493659512, 0.17798845566088156, 0.15839293779384706, 0.11472402621180781, 0.30848984816862696, 0.1267025233697026, 0.24496324811010595, 0.3864696315459667, 0.34594315134229203, 0.23351171985268596, 0.25804544047963235, 0.327664140251375], [0.14353806393281107, 0.12542357788451258, 0.12505385619137557, 0.13113801157282245, 0.23982151111047115, 0.03868583905240221, 0.0755987361434006, 0.1867613115257794, 0.1747423112993279, 0.1354241815786208, 0.045140865258872516, 0.12316908837566454, 0.08955521103475364, 0.042725719451423616, 0.04471460627692361, 0.34794625675966667, 0.30863997075826893, 0.12247901169523118, 0.14594678226257526, 0.15965442413524275, 0.3729871582360037, 0.06930003783875896, 0.1657426321218091, 0.28091687288495804, 0.34618833012157874, 0.17421096803680544, 0.16675192231853164, 0.519308082519039, 0.6339673589794868, 0.3447239377325581, 0.2762868519752257, 0.04039845158976894, 1.0421833155616638, 0.4220065504552857, 1.3264769507992653, 1.50920215873949, 1.0677065459951278, 1.085167834835668, 2.965146375279273, 2.6950595648058, 1.6498555339151815, 3.013825930895344, 11.728418296383275, 18.00407328913289, 44.0302094336479, 47.44580153496035, 90.12883370922458, 84.90029858004662, 55.67645211373606, 103.07798185656148, 111.51780851425664, 108.28411240731518, 103.57224756671538, 88.07880693866362, 77.89050532925513, 74.86416139910298, 72.56715866827196, 75.07362381104501, 92.79997564131214, 104.51623655134632, 98.52657333497079, 94.45975795868905, 67.86528802687123, 38.220967400458555, 42.81436097237372, 41.42922301446238, 22.461845028784968, 29.340562474343088, 31.304146089861472, 32.70156106641216, 19.94469338847745, 10.748660237558427, 32.2960566320727, 45.431593848812966, 36.172336993678925, 13.194612033905523, 17.82796867432133, 8.410527533100497, 3.7368153420186814, 2.4542157400038938, 0.45503802477352084, 0.4360630687686705, 0.8005713803633567, 0.9060057324747887, 0.08067485005144151, 2.691884896447582, 1.1207802593708038, 1.3766993462078034, 2.4362767800208065, 2.2307274226219427, 0.6707830931390486, 0.561914828515822, 0.7091858550425499, 7.605687572110084, 11.74478340533472, 0.4529815689930993, 1.4962035465625025, 0.5558295776286434, 0.630075571037108, 1.2108333432866683, 1.4036196758670192, 3.7164888843413326, 14.070915618250448, 12.098271327634013, 10.610047598038951, 12.208161430974162, 25.121847429583152, 17.241919502135246, 7.475582553494362, 6.5495315482539525, 11.300372000663511, 26.731372417942172, 32.39886587665927, 40.172487766511985, 41.188922928225615, 33.77706712292087, 31.911574140671764, 31.58437002089716, 22.96066264952383, 31.588661093865674, 39.39149287439162, 39.591008155576645, 40.98433210003761, 65.73008698801841, 84.15588763452347, 97.05693183406707, 92.17855453491212, 92.3025720350204, 98.70930871655865, 101.91800363602178, 96.2151990398284, 70.10926815771288, 45.10801792144776, 53.69271732145741, 61.1827616537771, 76.37404641797467, 73.57551374743062, 30.556203049998132, 14.842988098821333, 0.45216776911289464, 0.2828998148681656, 0.6809257908213524, 0.3017404603381311, 0.9759518275818518, 0.9778637991797541, 0.3858820114645266, 0.622354262778836, 0.7080479386833407, 0.5991288671089757, 0.6559599046745609, 0.598572809850016, 0.4426120479981746, 0.07430579423183396, 0.1997878399467276, 0.14639154226789552, 0.09037149303983297, 0.12111372810097472, 0.15099631291964363, 0.40846704956023927, 0.49124049022793775, 0.1368998814254038, 0.19451674134019883, 0.34310075063859263, 0.22974881854268814, 0.1639387708517813, 0.04772233641556194, 0.3863279052799748, 0.11387743010756471, 0.09617092418334178, 0.20868420450677796, 0.14110429452792292, 0.08832468230637812, 0.04911633681566004, 0.27244896597919926, 0.11773965471694547, 0.12300188202531108, 0.07143913918445188, 0.03272884277506702, 0.10902610171826617, 0.12026688684859585, 0.23458225111807549, 0.055760805074486046, 0.11789480284337076, 0.06818654436257578, 0.029549156540944695, 0.11098707996068463, 0.04412979007728639, 0.1162398307614269, 0.1209304568868491, 0.1923961027134811, 0.05156102297346919, 0.04850288041897359, 0.21890905745808156, 0.13857545361163157, 0.15577608869681436, 0.10865993467309784, 0.10269820014195097, 0.19423639912518764, 0.18535520310603804, 0.328613874772864, 0.16830125853659647, 0.0666778414480148, 0.25741832090481637, 0.42401688774266555, 0.7264308006532731, 0.414718296378851, 0.2960916344196566, 0.045872069369520874, 0.8431770231935286, 0.5407880847492527, 1.509111821651459, 1.2185976750427678, 0.9683177920599139, 0.8116265194069955, 2.3823797366311474, 1.9018450187098597, 1.9870914831276865, 2.5926496665323935, 8.206111740681434, 23.6777993940538, 61.79405127802203, 81.00566740958922, 103.14652919769289, 106.46504263724051, 65.70467002930181, 107.63177517921694, 118.50541683935352, 115.8779622662452, 110.97976130823936, 100.42127424670805, 89.46592961588215, 84.43574874631821, 80.05222551284298, 82.03054351191368, 99.09764689783897, 110.01376782694172, 103.56806632011168, 98.29564771344586, 70.84828976661929, 52.414252142752375, 55.00234965355166, 43.426356623249674, 35.00178014078448, 48.472238740613385, 41.47734657410653, 42.968972959826075, 32.6416939304721, 24.713465936722297, 33.59393558194561, 38.99742411028954, 44.678675282386045, 22.318015636936313, 36.37376639150804, 25.077595249299083, 3.0712543331807662, 3.9958942657516854, 3.0907752340839756, 1.5202618943106745, 0.7810410412569201, 0.0988109551009632, 0.1782123218741148, 2.9045754190414184, 1.4670369245352284, 2.5769079692902106, 2.132317851628027, 0.8401841321779836, 0.9316227320701846, 0.6886322063303764, 0.8515928361204363, 9.807979772167823, 19.031944121083907, 2.2286105684695707, 3.901550476589511, 0.8817531048290191, 0.39623458659456623, 2.372056058337612, 0.6272434971986279, 4.850692229886209, 9.463946723168897, 14.935484451632346, 23.680880415824152, 24.131945140900154, 49.51766806264078, 38.851194227895434, 24.782670274857555, 21.235408129230624, 20.829587944092292, 32.926618822159305, 46.81417049900178, 59.69013114129344, 56.55068958959272, 53.95865401914043, 55.79538229973086, 49.03063520308464, 33.83382381931428, 42.116916487293864, 57.64186551493984, 57.11573054713588, 51.361997896625155, 68.89458856275006, 88.94239517950243, 101.18829373390444, 100.50372246773013, 95.97528334586852, 102.52138183962916, 101.46336955408897, 91.72345761329898, 71.96934238556894, 52.73671411698865, 61.52493353812926, 62.88563512986707, 84.95685915793143, 77.99062775027367, 39.251946710771136, 12.0045139328126, 1.1956813498850793, 0.2918561181474117, 0.5505252461279593, 0.33974488716452356, 0.5036178050983338, 0.7833161385309312, 0.20334322335979632, 0.45891547154995704, 0.7417391985654832, 0.4089572232577109, 0.44002910595267053, 0.37553838424144254, 0.897189531355135, 0.20561871899952813, 0.22577508983592834, 0.08298923997508903, 0.11355958022778073, 0.16428639090830283, 0.09065990982156608, 0.1836584102843077, 0.3040876924510925, 0.10876113488789528, 0.10874142344560354, 0.2748601204685627, 0.16953628420108752, 0.15693899484411364, 0.12539765346915493, 0.27447778130731276, 0.08298367051587952, 0.1668434238602077, 0.15672142587361798, 0.1660696137696505, 0.054417439255743265, 0.04150513071386565, 0.16209219251909565, 0.04951069206600228, 0.05701913896407332, 0.16366374528696462, 0.29566942804282714, 0.35599535871897975, 0.2581866764493527, 0.30340382108284586, 0.14113794110955732, 0.20824143633006081, 0.24964140998500012, 0.14616664949684374, 0.27398313365636334, 0.15692070066448183, 0.3635921623677977, 0.2862634617955454, 0.3540188212308192, 0.16413666668438143, 0.3996219209605648, 0.2179324485722088, 0.24931689514027489, 0.1619394805522696, 0.21808509925200095, 0.4981972120942608, 0.23741826264848634, 0.15825893369413194, 0.2734843797741398, 0.34115179231570614, 0.6128591851842019, 0.4041271001821564, 0.5018935863289141, 0.4149808806757773, 0.32492693874143785, 0.22619424718281916, 0.11647146510621233, 0.7527864928687773, 0.8952169468806637, 1.2384274625970473, 0.9180697786711878, 0.49234050055665357, 0.5541731116752471, 2.1969489512905, 1.3435614469551271, 1.6709294482584924, 2.173149234825565, 11.104904605496316, 58.26588323039394, 98.73804400044104, 105.14289009955623, 115.52032055393343, 104.9970720660302, 76.67324481471893, 114.01433437101304, 115.23482691857123, 116.5267772059287, 114.40184100981682, 97.47624889496835, 86.03336149646391, 81.72179806617, 78.64551451898392, 82.96097678522911, 97.59461033728816, 105.02256747215026, 97.9623717646445, 95.53000019442652, 77.78748819904943, 55.0558860840336, 62.643805319263095, 59.75991010665894, 40.82212248156148, 51.31663176321214, 51.85064285032211, 49.65858705582158, 31.41019913458055, 20.692342250577866, 41.9682429682824, 70.12301214279668, 65.3335863544095, 26.745571397965957, 62.26261761880691, 43.301260471344, 15.592273569876149, 17.753212221207157, 13.865497169956086, 9.556972595953173, 5.289167617597888, 1.2203814954526964, 0.41945841944506096, 6.071295584401777, 2.3785902367484186, 3.5514860480062427, 4.216314063918206, 4.720376383873725, 2.898401363242057, 1.542786350173335, 1.4546359835132476, 12.765241938252604, 16.469877419933198, 2.366988846371251, 6.448489821726277, 1.3324159095364234, 0.5343788706006543, 3.34108030603778, 1.9069476545818391, 19.396579419412923, 31.476436199680453, 44.530397922761985, 45.93501437094904, 51.92565817986765, 73.55088910748883, 64.75456999194238, 29.805633983304425, 25.218678982027118, 30.800829510534967, 48.64975736987207, 69.61504951600106, 77.58934574742472, 58.27705806301486, 49.61247567207583, 53.912774055234856, 55.66810531000937, 41.81430955086985, 46.83374312616164, 65.98718658570321, 77.60597659695533, 70.250991236779, 79.19710174683603, 88.5052627132785, 99.53452048763153, 101.17441638823479, 98.94715339906755, 101.22840389128655, 109.35210320257373, 100.22564995673396, 88.7232288237541, 70.91457782253143, 66.468657524355, 66.35796823809224, 93.47607458791425, 98.9970459476594, 60.51001241130214, 36.85520987356863, 3.0653982345134985, 0.3221461315068507, 0.5365967257849632, 0.5685395278757619, 1.5946980613854624, 0.7740519291931584, 0.2579246743792488, 0.3109367023552618, 0.4550018654234948, 0.3267443750894839, 0.4712040121516874, 0.620577183942641, 1.1401489232817004, 0.875896270717344, 0.35717421481686257, 0.1682507580206279, 0.2027476359639437, 0.30698558856402675, 0.2627578311629834, 0.3461868898762811, 0.8454019263867409, 0.3389391771727993, 0.23738502975433107, 0.2828386197647741, 0.2211531128494009, 0.2405240597023118, 0.17449855744358034, 0.18167689322463929, 0.19506195079415076, 0.14477197110893267, 0.195470015187898, 0.32466423187044363, 0.25389269234672673, 0.15863517479550454, 0.2791582720894968, 0.3105615031334662, 0.14624168014814778], [0.07956436730080074, 0.01907179526413881, 0.11498192971151684, 0.12862211754245143, 0.1256943823048665, 0.22522897639822578, 0.3112523918670993, 0.06648550741374493, 0.1047673270166401, 0.05603168227319276, 0.16366245825925183, 0.18667371703251717, 0.16748966498961373, 0.013335777048562324, 0.1070020514570417, 0.1545275645630975, 0.11213042788327703, 0.08404716143324491, 0.1340352794936588, 0.18792817068676795, 0.18396817027561127, 0.18774357414053333, 0.09655633535716804, 0.7304125579614794, 0.2075669571997658, 0.1039931262212415, 0.32090439491214295, 0.28707707781464825, 0.9469447357039299, 0.6344677676116267, 0.8820852805529872, 0.6830272619282046, 0.5390296371713762, 1.1987661714515379, 1.1781229823827744, 2.833759967357882, 2.79419501942973, 2.4715920850153896, 1.8944387258060518, 2.0254453992651356, 1.4214738145951302, 1.9963928936950623, 0.7368218946841456, 28.025256433794578, 31.273961490200413, 52.43488380985876, 58.90844591202275, 83.97878477650305, 76.45046987841206, 55.16650869000343, 85.59077693570046, 111.2843333521197, 121.00046788492511, 121.55800142595847, 121.20740429047616, 126.09774481865668, 110.67005880417364, 109.50789190107777, 114.18331007803641, 113.34370320843114, 95.84597849076795, 63.18208002275037, 48.810225455991684, 58.72116450340518, 39.59934711456299, 19.398411166283395, 20.533074409730975, 25.215372423971854, 25.96408817075914, 15.877865264492652, 22.079235469141317, 35.935488593193796, 28.651025487530617, 14.019298207375313, 10.536757130776683, 7.671694688258633, 33.54647098049041, 27.40950119110846, 5.601523114788917, 4.181297594501126, 2.0053480325206636, 3.279608430400972, 6.422813005985753, 0.3328097996211821, 0.056860079958794586, 1.2157104428737395, 1.3191462860953425, 0.3449541624755629, 0.32825231191612064, 2.6372418672807756, 2.31367084287828, 1.41389322136679, 1.8752227891837399, 6.267099322811251, 4.9780280551602765, 3.7529169167241747, 0.5063882854677016, 0.6385595964327936, 0.5343690033881895, 1.0193390026688576, 3.4062735303755733, 7.970730306640749, 9.971549472501202, 6.627478849503302, 19.56108166325477, 44.8774492356085, 15.92413648482292, 19.404469267014537, 10.626580388315263, 12.690729652681659, 31.913145049925777, 32.50507385500016, 23.31971053154238, 24.93625460132476, 23.23227893921637, 21.199730250143237, 21.89566658389184, 30.378947219540997, 50.16986800778297, 41.32118132806594, 38.04718678997409, 45.79773925965833, 53.86958875963765, 58.715657495683246, 69.1544298971853, 70.82353176609163, 86.09494270816927, 91.40080344292426, 93.31411207875898, 88.31134073195919, 76.14354441242834, 68.30516615221578, 77.58541553251206, 80.58804481260239, 75.70104614380868, 54.43667719441076, 34.6305513381958, 19.022030330473378, 1.0051633117179717, 0.3789239412834568, 0.3698443284919185, 0.4839399174576806, 0.5718414894034786, 0.7647795686798712, 1.2916551290019866, 1.9927264581764899, 1.5873280504057485, 1.6510913256675968, 0.5846472312846492, 1.023299186941116, 0.9544950531375025, 0.5038937193251426, 0.07833996727581947, 0.11799304595878048, 0.14131732825790683, 0.2712609474697421, 0.21360167692745888, 0.18552777207186147, 0.27256599357051237, 0.15308050108292412, 0.11339340809612505, 0.15451089448986516, 0.13068510039198783, 0.13149585124225388, 0.06213695103783281, 0.051728631519982894, 0.25232795776138384, 0.701410185185171, 0.38172907947051915, 0.19663295197871425, 0.16546742269589057, 0.2902177318690285, 0.09054059928823864, 0.05060961071942603, 0.17629789879485486, 0.015383290667687694, 0.16760709094664744, 0.11121601001509737, 0.13280606077563378, 0.21559966487749932, 0.09860756641794598, 0.10703484768108015, 0.30782387261429145, 0.05779948378462465, 0.05219878350955345, 0.07330861588519427, 0.0967316852221566, 0.06575521877816608, 0.017574476416132623, 0.04150999920262445, 0.08209455653183884, 0.08947435045434583, 0.03437770530581474, 0.17010305136922868, 0.20201959196598301, 0.22590080486430278, 0.17457502834018201, 0.06592437865272646, 0.18193629059580066, 0.45063608356060525, 0.24449144520105856, 0.01637715376883505, 0.3416927116772821, 0.385899692773819, 0.8073327498089883, 0.7948594287999216, 1.0672104887423977, 0.9148287364552099, 0.42284633603788196, 0.9359901686829906, 1.4876628306604203, 2.561261634672842, 2.1701133203121925, 1.9645703367648588, 1.1669042682455433, 1.5227899844608002, 1.0320819866272712, 1.5943384290702882, 0.7843409190254828, 18.066138913554532, 44.46062287976665, 73.66868572850382, 88.33019164300735, 96.03408751949188, 94.48726946307768, 72.38535681078511, 85.5153811362482, 107.41377768977996, 121.9883168128229, 131.91070525876938, 133.3022523695423, 134.4241443757088, 114.97027089518886, 115.74070284443518, 118.15536883569534, 116.98957766256025, 95.89041894482028, 76.24290589363345, 63.664986548885224, 67.7293308319584, 47.340897744701756, 45.82538804700298, 53.245971125941125, 39.118244878707394, 35.64277779671454, 22.85406831772097, 22.9506782562502, 29.68481125370149, 41.39681639209871, 57.04688118350122, 46.73824125720609, 23.39300394058228, 46.14319024547454, 33.79061891186622, 12.148161915040786, 6.377545422123325, 1.6022237414313902, 1.8459322447738342, 7.629985674735039, 1.1835088869256358, 0.34739268162558157, 0.9203954990352354, 1.4429425400110985, 0.2106942506807466, 0.40661072658915676, 2.4238801290912013, 1.7458475765682038, 2.0287301391363144, 2.0014723630682116, 8.918740210994597, 4.825376272201538, 3.6842080229713075, 0.33311053509673766, 1.073546342311367, 0.3821414492784008, 1.0089169586858442, 3.442312022370677, 5.645495826198209, 8.1870882453457, 16.961979942937052, 22.64879695830807, 42.285245003238806, 41.385837677986395, 34.34603829537669, 19.551110998276744, 26.73867783238811, 23.842997858601233, 29.595879354784568, 38.97305442440895, 52.63373228811449, 62.61614084243775, 57.29127230182771, 55.42958597983084, 46.94736242294312, 59.716336496414684, 47.82643618122224, 42.22533472122685, 51.0451998249177, 60.476009384278335, 63.522235808833955, 77.44883860311201, 88.24350726219916, 91.64592804447298, 93.29118190273162, 93.14327716827394, 94.27189211691581, 82.19207456035, 67.29228465787827, 69.77008511943203, 79.37237678035613, 84.60535203256916, 57.03051705514231, 39.01584356061874, 9.342773922028082, 1.1208767251622294, 0.22829870603257613, 0.20461381082573246, 0.18746851793219968, 0.7418267777369869, 0.8965503075911153, 1.155633460129461, 2.0276524679314707, 1.4756131869169975, 1.4630413776443851, 0.8095944865096001, 0.8387929165074903, 0.5027524628225835, 0.1667503441774076, 0.17235315885514985, 0.11498495575881774, 0.11287381662236107, 0.20068862144985508, 0.22632590705348601, 0.09006159515270303, 0.2254936444543062, 0.2216444816440344, 0.22589679056357956, 0.1026624468185248, 0.12630082516660615, 0.278390376197715, 0.08207938033005885, 0.04966212083555518, 0.29081944796827536, 0.7862984881766382, 0.6649587411553629, 0.4281834867452422, 0.2805966481326088, 0.2749403758395103, 0.09965079430971416, 0.014873317427813046, 0.08399104549279136, 0.03911595911748948, 0.222719211071249, 0.27443013063842253, 0.19599804895058756, 0.21695891935979167, 0.20178811083878243, 0.1340299321999473, 0.3248949162662029, 0.31668821469910685, 0.10985374480726258, 0.15248974004099447, 0.149539397548764, 0.30189524074235274, 0.17939292465246495, 0.2900104284767182, 0.2634934287878775, 0.22493322049417805, 0.1301664129019745, 0.3205644357348642, 0.4740831237887183, 0.27266840420423016, 0.35221128273875485, 0.44706887174998566, 0.2320829199086274, 0.5595093737206152, 0.24880999008253699, 0.16329082900718336, 0.6867247699729858, 0.4462275846350578, 0.6219975722412909, 0.5341677980557565, 0.5721542371376869, 0.574965963680898, 0.23226609153132285, 1.0194307493586694, 1.4710400710182807, 2.533435114929753, 1.1568851865107015, 0.8850670173283547, 1.0876106134345456, 1.7100734768375274, 0.5469125593381544, 1.1772529516489276, 0.4421713329370945, 35.578909843198716, 75.28053668237503, 116.76943071426885, 107.32125682215538, 108.4369985518917, 105.89647154654227, 87.1071417100968, 92.90331440587198, 107.67884362128474, 128.11739675460325, 141.8185652455976, 131.92509251256143, 122.8344818853563, 107.0318643508419, 110.52156571419009, 118.38893028997607, 117.22954042496221, 102.92078110479541, 88.27090109548261, 69.14120366496425, 60.83338437541839, 47.6683372066867, 49.87635312541839, 61.41461687703287, 44.15241479873658, 43.7944749862917, 37.22306151543894, 38.692236254292155, 41.79150489068801, 46.29295026102374, 59.432851114580714, 54.9405134877851, 35.328850899973226, 66.71268386225547, 55.43834071005545, 33.43822925321518, 14.211297246717638, 8.977330615443568, 16.306902939273467, 23.88615373642214, 4.614426301371667, 0.6747245235789208, 2.2094939168422454, 4.164635366009128, 0.343021598434256, 0.5377160721728879, 5.845074355602265, 3.800792386454921, 2.7160072278591896, 3.0275858506079647, 11.003355422327596, 10.670308932181328, 4.033691695620937, 2.428329077459151, 3.85290916408262, 0.6473230907032568, 1.004655180919555, 5.010647956402072, 14.983259900923699, 17.665025572622977, 27.940625413771603, 44.653375994774606, 94.09096102560721, 47.335284832985174, 44.51368078108757, 23.940735478555005, 37.438313345755304, 58.27908985076412, 60.28201680029593, 61.22840235310217, 71.66670014781337, 78.8905998968309, 74.06693181683941, 67.94267639037102, 51.1919984509868, 66.73691626518004, 56.75781426891204, 47.73640601865707, 52.93689620110297, 72.3658077178463, 80.77965259552002, 91.88709105214765, 97.65542276443975, 96.36390393780124, 92.63067829993464, 98.77126647580056, 93.0524350750831, 85.42642962548041, 73.60285266753166, 73.8672596408475, 81.38993417063068, 95.87516092484998, 81.59802375301238, 55.66125292931834, 35.70535921281384, 2.0744043011819167, 0.5331537427921449, 0.2164136639405643, 0.5539734998056965, 1.1961286226587913, 0.7127996449989658, 0.960432418411778, 1.3226260413085262, 1.0526656046990426, 1.2076248444857136, 0.5420735802861952, 0.8401808839651846, 0.6695001103704976, 0.43655612295673746, 0.34412822776263763, 0.2555086016054115, 0.16440755537440702, 0.1947032224627272, 0.20715158432722094, 0.3133825453058366, 0.21640509907757083, 0.21970571229054084, 0.16846012985033376, 0.16970672344248142, 0.14199534671441202, 0.32047112622568685, 0.11027121676071999, 0.20344183419740972, 0.4350539471112913, 0.6733223988163857, 0.46822920081115543, 0.36735956827479027, 0.25137191067539877, 0.2757926946205478, 0.3126225554414334, 0.15286818747558903, 0.2791554528859354, 0.07959252103201805], [0.2471163535430547, 0.060109001389073755, 0.10400319261656654, 0.07254397586709069, 0.1679859673904796, 0.16524894974164425, 0.258021293388259, 0.19507365661763376, 0.1804529911568088, 0.391091225488532, 0.09909708894068196, 0.21093621189075135, 0.1096735762492303, 0.09068552014087478, 0.13418606091891566, 0.07192683841792807, 0.21788346491033034, 0.4521861245795604, 0.35985969007015234, 0.4066001545758017, 0.26063205974717296, 0.32975182177559026, 0.571436565970221, 0.4245065098568317, 0.3637379029345128, 0.36557663652685385, 0.14739968333273165, 0.3324012296094049, 0.8495949401009468, 1.455860130729214, 1.3613371382797919, 0.8481697714136494, 1.197694874098224, 1.4179944271041502, 2.126012396427893, 1.826477901589486, 2.6187929991752874, 2.0704179473461646, 2.4847298187594262, 2.412930097310774, 3.516228597971701, 1.7932711157106587, 2.60958033223306, 4.316326168275649, 46.54240123687252, 39.53786788448211, 50.934353643848056, 58.195206042258974, 73.80595299505418, 85.20385080768217, 62.390055425705455, 70.04057961125528, 94.2468438609954, 107.10168253990912, 114.5858629288212, 121.60056698706843, 122.59347577248852, 122.09163988790205, 110.81131904355942, 94.52507326679846, 69.84629677188012, 59.08807869880431, 59.00198267352197, 39.153114749539284, 35.261797981877486, 37.67709547473539, 24.29744170558068, 21.2575146075218, 26.339631580537368, 48.002264268936656, 56.38587551732218, 45.18910115764987, 12.032192137933547, 17.9542415372787, 11.425062187256353, 7.083487722181506, 24.75405070089525, 42.47016906738281, 24.802613565998694, 6.323894752610115, 2.551105147407901, 3.3712565706622217, 4.677324448862384, 2.648275984871772, 0.47156627980932114, 0.9342705770846337, 1.281101256608963, 1.31295433448207, 0.5576779332853133, 2.4070705665696055, 3.382914835406888, 1.413879370497119, 1.7047080421640028, 1.564982430108132, 2.402050913341584, 1.2064911569318464, 2.3612783656966303, 0.5293886351489252, 0.4027011960504517, 2.251314227619479, 1.4037313408428624, 3.5139516620866718, 2.525193724901446, 0.9660248602590255, 21.230373767114457, 39.80513426565355, 26.182815221048173, 26.068527160152314, 4.143144209538737, 4.887501712768309, 20.78967586640389, 32.57613935778218, 31.352255921210016, 47.37542244695848, 39.94125227774344, 30.96558474725293, 36.13626687757431, 31.673407823808734, 39.20670609320364, 53.599808139185754, 53.37694298836493, 33.96989084059192, 39.60598768726472, 45.888514672556234, 52.06109762191773, 61.322327429248446, 66.09094896624165, 69.35838530140539, 74.83268045609998, 78.59252329795592, 61.36640310287476, 46.34488636447538, 53.66029893198321, 59.158100851120494, 44.55786235870854, 38.383455507216915, 18.99599559845463, 1.2857010936544788, 0.1771021378977645, 0.2178201554042678, 0.02464925626202697, 0.4258505345111893, 1.3027353344425079, 1.8316648684201704, 1.0211766330945877, 1.3345558076135575, 1.1396754196574612, 0.7827911537981803, 0.8531302826539163, 0.2944955974817276, 0.40625357639885723, 0.34866555203353206, 0.2383841156599022, 0.26712912885892776, 0.07502743373474768, 0.22808668353865225, 0.2587800268684664, 0.3227084706867895, 0.10217022766629535, 0.32895061638086076, 0.5588449609856452, 0.19260789538102766, 0.10557614732533695, 0.3071596437404233, 0.3611242867285206, 0.24762108291108764, 0.26696965999660954, 0.7646110906235634, 0.2762778121377191, 0.04820296848793665, 0.27882716888862275, 0.10723699530166005, 0.08779779001469575, 0.16928097773944178, 0.06684281848250859, 0.17750713793981462, 0.2766108458801624, 0.043237420219567516, 0.18316402310325255, 0.06576209058684689, 0.08257397435485356, 0.25214878511765315, 0.21471984353998017, 0.397721164889874, 0.18568045339517056, 0.10245733443767795, 0.10409428813164273, 0.1673768355601257, 0.1390756170956358, 0.05024062447069634, 0.134908635049097, 0.44571856517464886, 0.12302442799292265, 0.07724646869446002, 0.21431185575502537, 0.32921651017762005, 0.06801923842079217, 0.2435700099674925, 0.3768465559809439, 0.5181619536972816, 0.2647796904127444, 0.2637320498545324, 0.03944077656694478, 0.6403766344151189, 1.299533699789355, 1.6934204414006204, 1.571026802543671, 1.0969457318705897, 1.5860975293382522, 1.3733337074518206, 1.7783035962812364, 2.6164898324397305, 3.2582611758862776, 1.9210890247937173, 1.6572815612439187, 1.8006088897105188, 3.592976144244594, 1.7988622092431592, 1.6237679724731755, 2.7174616917487118, 22.369065284729007, 54.37709639149328, 76.51834257187383, 84.55627533697313, 84.57932318410566, 92.2329342749811, 74.84496531947967, 83.27162850287654, 98.28675962263539, 103.9931021967242, 113.09711948517831, 122.4965226265692, 125.2425269157656, 121.82518543735628, 105.15089173470776, 99.96878962362968, 84.97436861838065, 69.67623064594885, 66.46448412249165, 54.989633329453014, 53.48881683041973, 45.346199927791474, 28.43016270668276, 31.66561407427634, 33.24735887588994, 37.23422850331953, 48.42367979788011, 56.67329503643898, 49.28871931568269, 34.10248656426707, 11.979759854655113, 11.047980227778035, 36.64473549012215, 45.3708206453631, 17.603077619306504, 3.347455873604744, 3.4468940861763495, 7.391111370055907, 6.926146255385492, 3.4897692693818003, 1.3566803042927098, 0.7755891918655365, 0.2939794687253814, 0.3652599970659902, 1.4461188018321993, 4.079672170262183, 4.723634402598105, 1.0962677747011185, 1.4799188461995896, 2.482104282225332, 0.7738569138511535, 1.7033787263977913, 0.5316246312952811, 0.42157987012497844, 0.5199050182296384, 2.1030184818852335, 4.628434556145822, 2.1355824893520725, 3.2955942951863815, 7.424798155984572, 20.70740022966939, 59.75632113795127, 33.375585079193115, 28.439446956880634, 15.15217383061686, 20.773576498031616, 27.460601829713394, 31.360687055895408, 42.50878480172927, 55.12861859413886, 62.33091392824727, 48.80514598661854, 46.8091106414795, 59.91293745656168, 57.47163464946132, 65.59938969150667, 64.86957780776486, 47.8612393717612, 43.49024418861636, 49.46337853708575, 52.79009757503387, 65.83062910264539, 76.22721641294419, 79.35952709567162, 81.39052252615653, 77.2115352076869, 69.3692502667827, 65.07812238508656, 66.94648065874654, 58.82727246130667, 34.606389537934334, 25.811394222321052, 8.8994284214512, 1.4830718189477923, 0.09867905008216059, 0.26238915901030263, 0.027750466364405812, 0.26216763702611773, 0.8464928355909164, 1.2961898792174555, 1.8649895705523032, 1.6683751272578395, 1.1559994662961652, 0.357255757215523, 0.5058579381194808, 0.5665932968258858, 0.27649424729808686, 0.5801486404192063, 0.27748050889180553, 0.3327366229026549, 0.392392287932096, 0.3442361235858933, 0.22614311847475269, 0.34464426458843295, 0.2544119927070795, 0.1749903705692099, 0.3218422703925641, 0.6437851128078277, 0.1760667087810655, 0.2668803647881554, 0.19035213416622532, 0.24939273784477867, 0.3295446716008648, 0.6512949195119643, 0.3298625061588903, 0.2364006527369061, 0.22490584051176427, 0.051479300544146574, 0.12498342972849646, 0.11152203149733045, 0.05555926266336634, 0.2882115008129228, 0.569859650586882, 0.14903384080577284, 0.3522082490305747, 0.3629023461572586, 0.40976707012422625, 0.37877979417962415, 0.3599276267472775, 0.355245542502211, 0.3359424863611499, 0.34679476532243914, 0.13762746577060994, 0.22666724518902842, 0.33995847247781297, 0.17322890460491183, 0.21123875533380818, 0.2767577509005224, 0.3613249711211651, 0.472425677242779, 0.5569605072659831, 0.4187536491982399, 0.3868831351639763, 0.4818042788294054, 0.824260964028297, 0.3794655348024061, 0.3221687770658924, 0.22213698424879583, 0.33843104637438254, 0.5034285813810364, 0.9030193378848415, 1.3093976027542547, 1.1664269648251997, 0.8205846612972598, 1.1457602415354022, 0.7505064926320507, 1.6179631097662834, 1.816476225372284, 2.1458120307614728, 0.6181721581566719, 0.7627041445624444, 1.2078433940487525, 2.293988144205463, 0.49585117507846127, 2.23140501206921, 2.2056830890717047, 63.79069066816761, 90.54894308890067, 114.20022333821943, 99.23048188609462, 88.38137857375607, 98.45748470675562, 87.66652660985147, 95.54929041093396, 108.52332207464404, 118.30899238586427, 123.94463815996725, 122.65510405263593, 117.52564014927034, 116.53777553189187, 105.05862189877419, 103.44346046447755, 86.8949414837745, 71.69272899627686, 61.796275261909734, 56.99309764369842, 55.22163368040516, 63.664963014664195, 49.97365536228303, 55.6324548875132, 58.598900302763916, 61.965035238573634, 65.42502464786654, 89.95297816491897, 66.75205661404517, 53.595736718946895, 31.610263547589703, 23.953710679085027, 42.11452384148875, 76.6447997862293, 35.84962398775163, 13.818938636010694, 18.714416488524407, 27.920915503655714, 23.187760037760583, 11.549547430007689, 1.559266188452321, 1.6969443232782426, 1.6594664440039666, 1.9783498683283407, 2.911376318623943, 9.889681762264622, 7.3112901564567325, 1.5853531370239875, 1.4871602769820922, 1.1152953149810916, 2.4074892795855, 2.267726405012992, 2.3747796541260136, 1.2197278079486664, 0.6763189057669332, 11.687377556677788, 17.43354101334849, 9.007298504152606, 4.719789989532964, 13.43752932163977, 42.590715269888605, 99.92178393948464, 55.77151859960249, 26.74947023391724, 11.821168622662945, 13.38423215573834, 34.94803974705358, 65.20091610570108, 85.83361087306854, 90.21315682318904, 98.93161296844484, 92.97564291184949, 105.99933178194108, 88.82271582080473, 59.86490411143149, 64.52170671955233, 68.81498013773273, 52.79108993468746, 50.12185819687382, 61.52514926848873, 79.0278200949392, 96.21781133836316, 94.79223374397525, 89.51739895728328, 79.92531330354753, 88.3369145854827, 77.48628154877694, 59.22546363645985, 65.63323190135341, 86.94574402224633, 71.67415265114077, 45.31548776934224, 30.970546545520907, 2.0155051326559437, 0.3367463883853728, 0.4330626088044336, 0.20653278446726261, 0.20719108382059684, 0.6442136930361871, 1.6394223969790245, 2.462024688720703, 1.8987431593479651, 1.1726677009174902, 0.4476038156257522, 0.6764167198731054, 0.533875520190885, 0.27901452335138477, 0.6259974705115442, 1.257776759805218, 0.6491497507499111, 0.34356999481397293, 0.32061671357481714, 0.15044273778555856, 0.2630602826754893, 0.4301457443544942, 0.30734172751826627, 0.39691110351873987, 0.38815609750247776, 0.22057630992945165, 0.3001425235021499, 0.5994418599913197, 0.5392318843833862, 0.4909558425987921, 0.9219330068557494, 0.6588369631959546, 0.5102417996573834, 0.3968422781796225, 0.14841706341793462, 0.2642902521596801, 0.42001815392605724, 0.2271928274703603, 0.5418497600382375], [0.08793815264418241, 0.094961968490914, 0.3777037470811798, 0.13035418105221566, 0.230746065837241, 0.3359840389701628, 0.3038991735346856, 0.12802356538633186, 0.20674132892201025, 0.880485259957852, 0.3610554613894032, 0.43102898244415566, 0.2565241584013547, 0.30477971499485357, 0.01990848010586154, 0.33224323163590125, 0.30291223778359355, 0.2320793039736248, 0.20399455131301958, 0.39791737532904076, 0.22947538644075396, 0.10421164514076325, 0.47806497302747547, 0.6089278671049303, 0.17823492146788106, 0.051435702480375774, 0.263588760769175, 0.9388525796032722, 1.2184978997515095, 1.3073463257282012, 1.1143872862862003, 1.7791469058682843, 1.8065184306713844, 1.9538728075642742, 2.251922194996188, 3.1156077596449085, 2.6875178275569795, 3.183861903605923, 1.8836251189631803, 2.1541117660460936, 2.952124106307184, 4.605671571147058, 2.2598939220751486, 1.7390016923027656, 3.2699164988533145, 37.93471282528293, 53.34510510967624, 56.537973265494074, 59.18050542954476, 53.6769768499559, 61.838954571754705, 63.59410147513113, 65.12895630251977, 74.88904491547616, 86.58254038903021, 103.3266052123039, 112.86597421092372, 101.31373897675546, 84.34100781717609, 83.25233828636908, 83.89364580954276, 65.57346674703783, 41.82690035912299, 46.63920925509545, 37.92722502062398, 25.971024882408884, 40.76768782831008, 49.099037416519664, 50.91754628765968, 37.31779067747055, 15.135914625660067, 10.136243912481493, 21.204364530501827, 9.707319986435676, 2.7251264933616888, 2.8218572899218533, 14.356638712267722, 27.71690518625321, 26.935733787475098, 5.62668364855551, 7.14277042496589, 4.382619617446776, 5.247593435548968, 3.320863919873392, 3.137197955962151, 0.49682925485314866, 0.7919573651686792, 1.3943221876698157, 3.3595259872175034, 5.053458665647815, 1.841044236094721, 1.4129321181005048, 4.963052445842374, 5.267918177189366, 0.6631387001083744, 1.4864563341102293, 0.8909704908728601, 0.8094981432922426, 3.609479271596478, 4.730347048851752, 5.41779782502882, 0.22742916559500082, 1.9739296022922763, 4.596484889907222, 7.836590640006527, 12.488877619466475, 28.078937991972897, 18.020623730074977, 5.997703094636241, 9.632995974633003, 2.5058684522105805, 9.725713941358752, 18.69492623113817, 11.111165688883874, 20.52533949575117, 43.26625331755608, 46.09739265134258, 45.311969403297674, 39.581147316963445, 43.92907896349507, 45.59206977967293, 60.11180946903845, 53.4370925349574, 47.21843742555188, 48.74138393709737, 65.13902110438194, 73.20430063432264, 76.74320420911236, 82.1427546778033, 69.02375221252441, 60.96237544090518, 52.83292985731556, 19.48194980621338, 7.478665536449802, 12.707982197884592, 3.2113861556976073, 0.32458462001335237, 0.6747408872169833, 2.4494713881323418, 1.9516779963047275, 1.4259655413127716, 0.7272651623333655, 0.9418090661206554, 1.1640015917439615, 1.3800022270410293, 0.5851082323539643, 0.8296146928783387, 1.0153379399449596, 1.4269156129129472, 2.149977342736337, 1.571243881217895, 0.7255864491866482, 1.0578781895099147, 1.2989822390579409, 0.8574507121116886, 0.5054646898661891, 0.14356452460971572, 0.058737156251745845, 0.34595326370289253, 0.24530552087291596, 0.20402001607562267, 0.6643828881844398, 1.1568702324744196, 0.4714326434318097, 0.5485459813667882, 0.4305167454144647, 0.4564740719093431, 0.2647699151308306, 0.22837536079027962, 0.33526351795561854, 0.27267971166199256, 0.1691948541349942, 0.04714834886873442, 0.01048344593014448, 0.07739351927152566, 0.355263652820741, 0.30464301426564494, 0.25818434754206293, 0.22059625885899992, 0.09294420781154787, 0.15407050118571328, 0.17274721916164124, 0.4214792981022789, 0.2077620185070461, 0.3013204602945236, 0.7238512293946359, 0.3837405505680269, 0.4919420735489938, 0.20686399492044605, 0.14999980106949806, 0.10258134875086047, 0.38882332944100906, 0.1526283559900138, 0.13888616355196123, 0.16061587980197323, 0.3576635917828929, 0.20105429053787263, 0.18595529509888542, 0.3083960177196611, 0.285420642504769, 0.21485073732272272, 0.10893840763357379, 0.16828146282463305, 1.0702272817011804, 1.3343736625486806, 1.4235239884545727, 1.1040462024750248, 1.984375854653697, 1.486473862201937, 1.881213719325681, 2.5334101098199047, 3.8389082637525376, 3.0875110866562014, 2.7421740947231172, 2.0810956195477517, 2.4496719193074012, 2.5839371017871366, 3.288782854234019, 2.2330582910968415, 2.3250819983020907, 1.3338614255189898, 13.474424116073118, 52.890941712164114, 68.78666846982895, 79.25490179369527, 81.12976335710096, 80.92473322345366, 69.06805146125056, 74.39945467056768, 88.04835365664574, 106.02503899605044, 117.21577290565737, 118.37309175922026, 111.14259458357289, 105.71699957693778, 99.69568283327165, 83.79462165217247, 74.82235677780645, 61.112170757785925, 57.522707831475046, 45.95690904125091, 40.320784737986905, 43.29500036854898, 51.439072470511164, 47.344431800227014, 33.694654203230336, 33.815722080969046, 30.313324005373065, 9.517434124023685, 8.556811348084482, 8.186488122709337, 6.791673677582895, 22.599843817372477, 52.88588185464182, 18.460182182250485, 1.810608359594499, 6.980113165993845, 5.532325640801461, 4.163891586565202, 5.216047283141844, 4.287233458411309, 1.1368453070040674, 1.0006123204385082, 2.2794135972376797, 3.9047418150209614, 3.7080109263620074, 3.1466770989279595, 1.0125045790787668, 2.610983805310342, 5.266440424226946, 1.236766706551275, 1.4151534053587145, 0.6721563517085968, 0.8506397614555975, 1.866583646305146, 1.5882001648987494, 1.5582542169478633, 0.7802037990862324, 2.316130414124458, 2.9895332215293764, 19.292775853987663, 58.11747643255419, 21.532996393019154, 16.12611403388362, 12.104667732792517, 19.937554674763835, 23.293777781148112, 17.263718074367894, 11.68639402235708, 31.619106531143192, 38.60917222115302, 48.028587295163064, 51.66146693691131, 57.16995339239798, 68.11194235278715, 77.30859817997103, 71.36906285439768, 67.13793939159763, 57.856611359503965, 52.29618880056566, 53.480266063444084, 61.33968783963112, 76.22446290908321, 95.0574016571045, 97.55579456206291, 88.67591719473563, 74.68887067610218, 63.74454006072014, 33.9474235042449, 11.08982309218376, 7.518555550805985, 2.94663229776967, 0.3743606619536877, 0.7721172201056635, 1.2005488886948557, 1.266858885365148, 1.141705001073499, 0.7829811436034019, 1.2844048728865962, 1.1813024311296403, 0.6481569620870775, 0.45017048596374454, 1.2984340878263598, 1.3182316384007855, 1.1920638214195929, 1.7472211415729217, 1.8752986625317607, 1.0399362877491982, 1.1023612993378793, 1.3064270202190646, 0.7508044701910789, 0.554179608100845, 0.6353879924262724, 0.3009743724138506, 0.04218458558522886, 0.17211133554097147, 0.2985020841081297, 0.387600040243518, 0.4639976375525998, 0.5003787547109589, 0.6109953851949784, 0.44162063829360476, 0.5419000766931042, 0.3724239916811067, 0.2578896181958337, 0.36038403128904684, 0.20650528191078096, 0.2566518192930568, 0.14705345755623234, 0.05735167857980537, 0.07892804701001414, 0.4218615759764949, 0.22963067246300561, 0.20676805006880916, 0.3061972840899422, 0.46095360250722983, 0.46442263248947363, 0.6637322037450729, 0.7339325174689294, 0.5020871920691383, 0.7817824917935556, 0.8649761470094804, 0.3663859930970977, 0.3415177984824104, 0.24519642995249843, 0.21676247909424767, 0.2161208498141458, 0.5223911880485473, 0.36154839300340225, 0.3051259254495944, 0.21035865820463628, 0.3437331715418447, 0.3417442540728277, 0.22896103500839204, 0.5270799525803136, 0.6072232908298892, 0.18796717988387232, 0.20642913277110747, 0.2126568300469268, 0.9320713531586432, 1.434385766906123, 1.1923643730340467, 0.7460071050351667, 1.6297918750393776, 2.0048827413589727, 1.1324283504678359, 1.170420305382821, 2.520068657975043, 2.3018314136612803, 2.1818220855728274, 0.7124724948117811, 0.8120129954430365, 2.009497655014838, 2.614023642193887, 1.0152281135801347, 2.6512332068335627, 1.44179095664332, 56.92700570629489, 86.16851068312123, 100.46307102326425, 96.0108906222928, 83.38875832096224, 91.88745975494386, 90.67145439886278, 91.91249232138358, 97.80543773405014, 111.01438799212056, 126.03497120641894, 126.8648741322179, 108.39502134630757, 102.86931960813462, 104.80298534516366, 87.36579848874001, 70.57086052433138, 66.08945062083583, 73.98448359581732, 61.721938502404, 53.13072012316797, 81.62635111039685, 102.40883334990471, 86.1676085379816, 54.350494876984634, 49.890430511966834, 44.78694054388231, 27.62837140790878, 14.278392330292734, 4.1354490095569245, 2.7278383220395734, 19.105920022533788, 64.06224812230757, 37.385969315805745, 24.865538189488074, 18.457083509814357, 9.266178857895637, 14.127691926494723, 15.325647515635337, 7.015986673293575, 1.7578779761829686, 1.842095186152766, 3.3115252467893788, 7.99472148379972, 11.159353967635862, 5.0540298608041585, 6.208021073572098, 6.266597749725466, 6.483181715011598, 1.5652448611874736, 3.060792636486792, 0.8273747130747765, 2.165266251371753, 7.523180515535417, 12.604687559989191, 11.26033538772214, 4.371573242448992, 4.953460289585975, 5.436727673776689, 26.17434290147597, 63.767940921168176, 29.478423979974565, 11.350673456345836, 18.928005233887706, 20.566034086288948, 16.90145580999313, 17.129722064541234, 44.64628827187323, 74.85610485076904, 82.93994503636515, 89.16744509050923, 93.6970530786822, 124.77230533476799, 128.99899651927333, 109.09178333897745, 88.43232231755411, 83.40061956836333, 69.66844866352697, 59.7677509246334, 58.520476433538626, 75.554074933452, 89.61621915140461, 96.97887666763799, 97.04121097441643, 89.37700163933539, 83.59048581892445, 94.26957791851413, 73.6265516281128, 39.35893327959123, 20.183708898482784, 6.274855319530734, 0.7509383210732091, 1.2128631698508416, 1.112145529158654, 0.46300889383400645, 0.4786831140518189, 0.3307100139077633, 0.5928007969933172, 1.2050018820070452, 2.667408080831651, 1.264596168071993, 0.8713803356212955, 0.7953202460081348, 0.6406899337326327, 1.3255245502917998, 1.7314067579084829, 0.7492042044478079, 0.6441923651483752, 1.1076475511635504, 0.6821281198532351, 0.4061489594319175, 0.6451181670831097, 0.5442439993062328, 0.31074300468448673, 0.19689899899305838, 0.19778421358956447, 0.3513336830562161, 1.18396645592105, 0.476650437640567, 0.4898634625058021, 0.4260089308504136, 0.9749670675204647, 1.1380842856822477, 1.1093342929117143, 0.4763590177941707, 0.1764295433437632, 0.4230874392294115, 0.25639767728505597, 0.13229238350064526, 0.26639567628022165, 0.6610136334934543], [0.14994326378068618, 0.584439897248822, 0.20483376999055186, 0.10024111868152696, 0.146125388001242, 0.15425908138915417, 0.29601597557625464, 0.23736290513507782, 0.3388207399797055, 0.5111707578743658, 1.205199103682272, 1.2873210325356454, 0.5825516437330555, 0.342426409404124, 0.26735733112981247, 0.24315670553234317, 0.17405703032930053, 0.08470044291067509, 0.1592267938559094, 0.1813591659189232, 0.3593961455889287, 0.39607422907025586, 0.17024929755397383, 0.3089666306491821, 0.2974910012656643, 0.6143837614405541, 0.4710146965038392, 0.967136790915843, 0.7179383176469034, 0.7648700896290042, 0.8770257294658692, 1.042161865099784, 0.7786655558213111, 1.8667217872796522, 4.381785133192617, 4.4807014253831685, 4.478016072703946, 4.652218828278204, 5.566841027429027, 5.997116209999208, 3.510347003898313, 2.4174886268954126, 3.025175554137076, 2.6679491227672947, 2.683335355212612, 1.099750961988203, 22.607043327823764, 41.501269109787486, 38.78527487477949, 57.092196326101984, 57.48322133095034, 41.32348375935709, 36.998615649438676, 47.760610964990434, 66.46186397921655, 85.01742055339199, 85.60921992025068, 96.48450113111927, 97.92281858382687, 90.27083135420277, 73.59696126753285, 84.40305186856179, 91.42736573373118, 53.59716053931944, 33.84365327896611, 32.51671937204177, 31.022947449837964, 35.75653829882222, 23.94734271111027, 0.22801808802591217, 22.238142451932355, 17.133917039440526, 2.8613658537787776, 5.37571128337614, 4.5572827612200095, 4.663720688512249, 22.127851286242088, 14.518667901715926, 23.15173306772786, 16.693354460500903, 4.839036906919172, 4.52874408614251, 7.6757381616100195, 9.757015435926377, 0.6043671311870699, 4.898257342077071, 1.3721856787320108, 1.0384212722701411, 0.6842626246713823, 1.3128787062821852, 7.659384329472819, 4.054584200343778, 2.142401529896644, 2.5366897015802325, 1.9495899470583087, 2.420541946926425, 1.2414805374799238, 1.6318747761749453, 3.482155703729199, 6.193991736058266, 1.3858219212101353, 1.044774653930818, 0.5265810148369882, 0.7124281229992068, 2.814735491429606, 30.184028956197924, 15.964905600393973, 2.08678134026066, 3.281029308995893, 0.9727945034542392, 4.913493298715161, 4.800963930545315, 2.5564515831009036, 8.149675207753337, 10.378535582173257, 5.649018114612949, 13.300501319669909, 8.03971548234263, 7.36293992688579, 9.252309356966327, 18.0857095795293, 22.40385670815745, 38.58766586549821, 43.2215775212934, 50.62649465376332, 51.860452698123076, 52.67531333431121, 60.19982353333504, 54.45367674673758, 47.011755974062034, 38.44063974195911, 27.502065204804946, 17.639610575091456, 6.751455164724781, 2.874816151395921, 1.4963274689451342, 0.47568522814300757, 2.53863004907485, 1.465319906992297, 1.0710468119190586, 2.672395129357615, 3.0800210756640283, 0.747023550493102, 0.6760537780580983, 0.15952581329451454, 0.7047112274073786, 1.6208318332510612, 2.2043896875073834, 2.100793762553123, 2.128752907437663, 1.9592873944390206, 1.7228319664155285, 2.039617535568053, 1.696292474385231, 0.8702839105840653, 0.560341161345282, 0.5699743799144222, 0.5883886821327672, 0.20021281956184298, 0.1793408153518554, 0.3721366780659845, 0.6399270940211512, 0.8093345681986501, 0.8131957126240578, 0.9539273513420936, 1.114447102431328, 0.3568955426735263, 0.37529829228597306, 0.05037933235026656, 0.1985332943619259, 0.19695751278871493, 0.45556855598284357, 0.11564161568399399, 0.1983956436836912, 0.46617004840124043, 0.32387868531288644, 0.18089808824081577, 0.46729981358493533, 0.4877531660660621, 0.2602915183430718, 0.1604716714111067, 0.19045494316566378, 0.07692351666910034, 0.3473361443367697, 0.29014017312757434, 0.7079363962815655, 0.9087982761763758, 0.866740784577785, 0.9659600185771143, 0.6375502602707955, 0.2767232463004128, 0.17596305708491033, 0.15770243210417612, 0.13597296100229989, 0.23569010618713596, 0.12482272746462016, 0.2754346251247391, 0.5647339095031062, 0.33459650052170603, 0.44022884039628896, 0.22514656065933167, 0.5307980530684995, 0.4517160530292219, 0.6636924284600443, 0.6021951799911838, 1.1563484346674335, 1.163885023805403, 0.8164548345150486, 1.0823754749951826, 2.4683926566954586, 4.529285373226289, 4.721552604629148, 4.9898657683403265, 6.394463585269067, 5.776625073725178, 4.848881565755414, 4.1827096477631605, 3.2484547601592157, 2.659766568291572, 2.3137750308359823, 2.367097446995397, 1.0543310185593944, 8.588883588390967, 31.62278375317974, 53.923384066550966, 54.96031753478512, 59.20980553473196, 56.25320919098393, 54.4484874509996, 56.60711680689166, 77.13677483220255, 94.69399406063943, 105.64889154126568, 107.59873313288536, 106.72208339937272, 98.67849457648494, 95.276458186488, 90.79228693439116, 88.77010899205362, 64.7385000413464, 55.0604203439528, 37.591328928547526, 34.33635004105107, 33.451694750016735, 29.38834086541207, 19.096400430125577, 14.572601472177814, 12.405714546480487, 5.74188317022016, 5.676042264507664, 4.6333120234550975, 4.022869386019246, 19.281910888610348, 37.65786017141035, 24.175724675578458, 14.020200352514944, 3.5071649810960217, 2.2691624827923316, 7.807006653278106, 9.549270041527288, 6.427700279220459, 7.904588359017526, 3.5232136038041886, 1.1302419968189732, 1.1460473100023887, 6.1616763088010975, 5.9710540213892545, 6.535759616282679, 5.5200172432007335, 2.413795715378177, 0.49937655848841517, 1.8586660969641902, 2.173042595386505, 1.4145627209255773, 4.116646637839656, 8.662121103655908, 1.0799242387856207, 0.4365965111121055, 3.454210287140262, 2.9107080448058347, 13.951199977628647, 28.31133842468262, 15.070782688356216, 15.081767286023787, 11.587986657696387, 6.825072169303895, 7.5697581710353985, 6.486334320037596, 4.80037312353811, 8.545038354012275, 2.6816234857805314, 15.96801603994062, 22.04426753905512, 20.64698003953503, 17.31289282921822, 22.42121123498486, 28.801224808539118, 36.99017078645768, 45.717307136904815, 45.55888260564497, 50.34591182585686, 57.36633077744515, 60.922712433722715, 61.78535146097984, 56.109881862517334, 50.77151644614435, 44.535587218499955, 38.69433079996417, 27.140128497154485, 15.48020164812765, 4.2698853054354275, 2.2133223952785617, 0.3835003666820065, 1.8135851934071512, 1.0596829700854518, 0.886522094088216, 2.6191482188240176, 2.528166146047654, 0.8856638304648862, 0.7773712349514809, 0.47108943604173203, 1.122134335098728, 1.573347987667207, 2.472795762362019, 2.750674851479069, 2.7126898832859534, 1.705043282239668, 1.7436964016768242, 2.134896564868189, 1.7553854325125295, 1.244532876918393, 0.7635518668159362, 0.4967553120466971, 0.6484520591555104, 0.3376824865418096, 0.22833831277826142, 0.37001102922424195, 0.5476581161060642, 0.9758701932526405, 0.8018390413734221, 0.9569850227525158, 0.8056396954963285, 0.6035452107748678, 0.28446392126141057, 0.08226086655932088, 0.2034603888469358, 0.2679383934986207, 0.3020395717072872, 0.17855582037760367, 0.28048256231892493, 0.7115124947121068, 0.3301448861677801, 0.13546919690505152, 0.2995022272150363, 0.3953294077467534, 0.4168372649338938, 0.21353533371321617, 0.4332025577464412, 0.8304684825481907, 0.680212900042534, 0.6458869516368836, 0.6854479771948631, 1.3570938691977532, 1.775199408012052, 0.8147730570166343, 0.5625623873164577, 0.34725705341946694, 0.19560613369028415, 0.20282038367323338, 0.2505480903651445, 0.32140158597500096, 0.2598968604879995, 0.45195835131791334, 0.6054704203721016, 0.3367470012557122, 0.48760479015688746, 0.22727435454726222, 0.2943038609960387, 0.8214676235952686, 1.1042421984095727, 0.8202808614700072, 1.687924710492934, 1.425625398274391, 0.7222121076718454, 1.3104782157367276, 3.160870440544621, 4.398538556791121, 2.8569105315592984, 2.515321364325862, 4.347636978472433, 5.078057810183495, 3.3563329327491025, 1.8381980662384343, 1.9478241450363591, 2.003394569600782, 1.0550817847251892, 1.8486526536364711, 0.8791800912830138, 39.72673785301947, 85.64623140519666, 96.35935398840137, 96.30935161344468, 82.47981179145076, 74.76370949898997, 74.15603237767374, 79.29572582244873, 96.39279611649053, 109.21712660020398, 109.61905187176122, 113.20754989500969, 106.81396099828906, 94.84332653783983, 91.31757074786772, 98.02708302774738, 98.53837966918947, 83.7608814239502, 93.8827145484186, 95.45398466048702, 73.5509910891133, 59.83415272928054, 35.98864063139885, 23.138275415666644, 24.548338074837964, 17.50173730234946, 2.3889722602982677, 2.135170150187708, 2.1981813109690145, 3.504600241299599, 15.741415812123208, 27.871991780496415, 59.9292702059592, 37.923545837402344, 10.503560150823287, 8.520817718198224, 23.391982163152388, 38.093764935770345, 9.261279817550413, 13.424126582760966, 5.505508886229608, 1.349384695772202, 4.652276683238245, 18.606045323033488, 19.86575961112976, 10.85710298630499, 8.808922671502637, 6.487925331438742, 2.795790198349184, 2.8492231763178304, 2.327496462291287, 3.1926955715302503, 17.176513979511878, 21.098233038379302, 7.414010167121888, 4.881189638568509, 6.102770643849527, 6.046909718744217, 11.716759051046065, 39.23589637202602, 28.020459375073834, 8.619153499603271, 8.423080098244453, 8.7759865291657, 12.194622389731869, 4.887282060038659, 2.0871797059812853, 11.499513676089625, 21.38135756215742, 28.74782762219829, 29.755625724792484, 43.82933309001308, 64.92602855928483, 94.66670220898044, 100.91371213236164, 75.9409147693265, 64.06058895972468, 58.868645621884255, 63.49493219006447, 76.20924411281463, 89.88541141633065, 112.17238149335309, 120.49205026318951, 111.7324092311244, 83.54762215768137, 54.92347863412673, 33.956566549116566, 19.38904650749699, 2.3116777885344724, 2.073070450175193, 1.8975669385925418, 1.5173646110680796, 0.39322900916299514, 0.40176543497270156, 1.2935941281818575, 2.027619127785006, 0.5836809799075127, 0.5187721274072125, 0.2318230322411945, 0.6794832779034492, 1.3455885768898073, 1.6848756805542977, 1.6364573302768892, 1.8165839679779547, 1.5890733825583614, 1.0144945077838436, 1.0036858039036876, 0.7937531365502266, 0.6448311599031572, 0.5076670087873936, 0.6544532242321199, 0.5534068398898648, 0.34120943277112903, 0.23782585206772053, 0.6019839235851842, 0.7326245908775638, 0.5933733404644075, 0.7553490263319785, 1.1433631830638455, 1.045110874599026, 0.7360022418921994, 0.5529182596552757, 0.36151747369477827, 0.4910817874535438, 0.29771423928679963, 0.503354546644034, 0.21418410293277235, 0.3473791371910803, 0.4965365173355226, 0.28153409460379236], [1.1068059576134528, 0.6701957794927782, 0.45888997614383703, 0.1059540584983845, 0.11261502446065988, 0.2511906236289971, 0.10734021032769835, 0.11506314269236981, 0.14810802354927988, 0.5767061477226596, 0.6396059499632928, 0.7186783585817583, 0.7821145449434558, 0.3277477664091895, 0.549944183759151, 0.34410260978244966, 0.05703247655483504, 0.06254884970164107, 0.3282055499092225, 0.11937509921769943, 0.3903185798516197, 0.4827306936344793, 0.28087001894750907, 0.3622376269871189, 0.8610280362829086, 0.541295541390296, 0.49169383041800996, 0.19411500483270616, 0.4129399918019772, 0.4360991668316626, 0.3827860969449244, 0.5990278660770386, 0.9842980184382009, 1.1378767677853185, 2.36402353452098, 6.4922070887780965, 7.582972145849659, 6.632275908224045, 4.555524068493997, 3.9811765522726126, 5.648307675315488, 4.0015706708354335, 2.7306045736035993, 3.1801005957588075, 2.125209536283247, 1.4102568164948495, 0.49789727335014655, 4.556065355577777, 19.32791244599127, 20.23620786205415, 19.65547154026647, 15.456737049164312, 14.771808847304314, 12.422357163121625, 20.461246005950436, 33.50017916771674, 57.40200473416237, 58.12948673002182, 67.24866005682176, 73.26566219329834, 101.9754114458638, 90.50636183831, 64.77301297649261, 37.368302960549634, 13.894223628505586, 6.335649605720274, 4.685730088141657, 0.40897174828475524, 6.454910251402087, 13.151368883348281, 10.570765060763206, 9.678169911907567, 7.474010173351535, 2.889664528831359, 1.1505737251812413, 1.7281898014968442, 1.3179130683983526, 10.303545748033832, 5.220706568610284, 14.341888639234728, 4.352392362010095, 8.430345308396126, 5.630410390515482, 12.292444340644344, 13.970884392338416, 1.7421350532001065, 0.3168002780406706, 0.14144063777019902, 1.2201505659088012, 2.754103248157809, 4.5114827156066895, 1.6710641571590978, 2.8013379006616534, 2.0093895446869636, 1.031081537085195, 1.4058472144026912, 1.7685291723858927, 2.567471972396297, 6.3392228849472545, 2.5976413728729373, 2.72063807614388, 2.294632393506266, 2.29638226089939, 2.166032094147898, 18.820510718130297, 7.523977246976669, 6.302972339814709, 4.2626269594315565, 1.8930286337291042, 2.109571046406223, 2.0187135088828305, 1.2170339976587605, 1.3953303593781687, 2.3697972634146294, 0.317768735751029, 1.4323392702687172, 4.191524194132898, 3.677851331810798, 3.712095339452067, 2.634277290874912, 1.9515606929217617, 6.908424986946968, 16.408366810890936, 20.224301507396085, 19.466142654418945, 17.36162631742416, 23.876365461657127, 22.40953237779679, 18.2350302896192, 18.005504954245783, 19.741583255029497, 23.673855450845537, 17.068521322742587, 4.85243131076136, 2.3675958331554168, 1.7254883916147294, 0.18002197476885012, 1.0563792312337508, 2.1068131298788133, 3.7271104176198286, 3.177395631228724, 2.176208438411836, 2.2393730619261345, 1.9153420170468671, 1.1423720491509284, 1.7047931085671149, 1.6509330825459574, 2.079789960576642, 1.7145427725007458, 1.498017520193131, 1.2910019317942283, 2.039278005400012, 3.0388795800747412, 1.8934674488921321, 2.034084174421526, 0.9733343196492042, 0.4215043338556444, 0.6480740407301534, 0.7742707239043328, 0.6544675653980625, 0.2253891653831928, 0.192084243641265, 0.35838873996849985, 0.539122548314833, 0.5758491711270425, 0.3936405822394356, 0.3054389489754554, 0.13466613757754528, 0.057691775652910435, 0.09817694073482867, 0.08735021846669336, 0.23425520818320014, 0.5496657567639505, 0.4292431702056239, 0.508996447127673, 0.8589098338157901, 0.8370010674961152, 0.5744329503467006, 0.31277773421137567, 0.1700854926340042, 0.2528893469922966, 0.2782627765930468, 0.040256641054105376, 0.0473524461830816, 0.13516804774201688, 0.5842435335920704, 0.8721963724782391, 0.9674046765412054, 0.7764733186171902, 0.4762363517957349, 0.28708461611982317, 0.25442481701893194, 0.07909195152141395, 0.062251113460309086, 0.1294546406115255, 0.3397500046318577, 0.3652438785760634, 0.6785410510436182, 0.47479641293325736, 0.6132876428384936, 1.031058002864161, 0.745299730089403, 0.27173457366804926, 0.5644747879235976, 0.6837255051059108, 0.40288720219846696, 0.4005340865302471, 1.3134158258476567, 1.4152846821854193, 1.5509625307975279, 3.183419656368994, 6.7664395993755715, 7.283179510024286, 6.186960397228119, 5.142937244907503, 4.873569453916242, 4.642026549385441, 3.427954676651186, 2.418598657654178, 3.300494806420419, 2.3317176680411063, 1.5042675719145806, 0.23862892671698527, 2.9722868050298388, 9.357786793862621, 25.673211082335442, 22.87528245679794, 19.83596136493068, 15.375468480971554, 23.259813977826028, 35.40878095934468, 54.725775487961315, 71.62806480161606, 73.74633296843498, 80.70563747036843, 91.2503727020756, 98.43263256934382, 87.95151818183162, 66.24032066714379, 36.93524975930491, 16.217013001441956, 15.533897915194112, 9.425291765120722, 6.686942471611885, 7.487009398398861, 8.811697748399551, 10.691113183575293, 11.655361210146259, 7.019044160842896, 1.4977728623536326, 1.9147642028908578, 2.622162070005171, 3.843965179497196, 22.033088784064017, 35.83985336365239, 19.26285405312815, 2.968833648389386, 5.774201048958687, 6.182370733830237, 5.598614677306145, 2.647409876508098, 6.902133505190573, 5.058345448586249, 0.5846195295453072, 2.9508243308913324, 9.20041149662387, 9.24890277847167, 4.731444331907458, 4.170600310448678, 1.5324251642150264, 1.022645622011154, 1.0003513602479812, 3.6174370252317, 2.622292979109672, 6.663080242372329, 5.7386432924578274, 1.5285987695378642, 4.485694602612527, 2.2684064459416176, 6.956090119577224, 12.994454464604779, 24.01421912254826, 16.02631030544158, 6.924155652523042, 3.711715359841624, 3.0089364513274166, 2.777210911435466, 2.444012184296885, 1.7830807980029815, 1.351143511072282, 0.3523499752965666, 1.7250485958591586, 1.5419951345651381, 2.8765498390120845, 7.145925971769518, 7.418213477057796, 5.174503989758031, 10.946958603397494, 19.13441211946549, 23.718643034658125, 24.37883480902641, 23.721998622340543, 26.65423312494832, 24.24547422316767, 27.96816437475143, 29.31009154165945, 26.27085478075089, 19.901019757793797, 12.170654746793932, 5.228203198602123, 2.817925358972242, 1.8579163113909385, 0.22877000332359346, 1.4294057051020286, 2.821635921155253, 4.405242377711881, 3.6091144911704527, 2.785071341260787, 2.6650419110252015, 1.928563591453337, 1.196912483822915, 1.5315858995722187, 1.65801283813292, 1.5475069226757174, 1.289309183916738, 1.05159945545658, 1.2026924639940262, 1.576268437408632, 1.758817506413306, 1.3733889883564365, 1.5441135821803924, 0.8894624008286385, 0.5362370321827551, 0.8283670114413385, 0.9575106816426401, 0.46603187678321717, 0.14362400367615685, 0.1712854008280462, 0.2900526245995876, 0.5115235873287725, 0.5536817122370966, 0.4268925979493126, 0.2866596824699833, 0.14217145500644562, 0.09579660596265908, 0.06816721596424619, 0.12409741840054914, 0.08926875543810668, 0.30967664093740527, 0.2849822257074618, 0.40776788707702394, 0.5163829136760004, 0.9817849436113912, 0.7956899906839094, 0.4479473600945165, 0.25567487332849737, 0.2181610645305726, 0.3174494915912229, 0.2823348709892842, 0.22200909353071646, 0.2675340216486685, 0.9021730865201644, 0.7768765260134974, 0.8001653537634881, 0.8102877654375569, 0.5650534600980821, 0.46884308238663985, 0.41937868501390185, 0.14637956065275978, 0.23691604604884503, 0.7827217155887235, 0.4930340552762632, 0.5574212631871623, 0.665335656414109, 0.37045407319261187, 0.5037926876496884, 0.9561413454432642, 0.5807023074838423, 0.525036275146469, 0.7722599576077154, 1.401177510138481, 0.6311841921940927, 1.1384634072742155, 1.662124707814186, 1.7146197490153776, 2.0687965375761834, 3.1368407751283343, 6.185042358213856, 6.010963157300027, 4.441542933064123, 3.6951438361598603, 3.948324005449972, 4.15068986915773, 2.7879596765964263, 1.7334922330994762, 3.1162463705385886, 1.106100053556504, 0.9725523583831327, 0.41892522224976175, 12.027328398919876, 55.62683805342644, 75.256680826987, 68.5299022736088, 59.571750087122766, 58.17182087129163, 66.87004935356879, 79.87991579117315, 96.80403309483683, 114.82031868350123, 106.74105198152604, 110.01579176995062, 111.53032871984668, 131.60112042580883, 126.37198125162433, 102.03754963413363, 80.35439706617787, 50.59937146402175, 32.09613342438975, 23.440376366338423, 15.620091019138215, 12.89508709984441, 9.648191236680555, 9.675592914704355, 9.883021577712029, 11.619700981724648, 7.621271148804696, 3.27091351632149, 1.897317500364396, 1.2797074668830442, 9.371723955677403, 46.872841312039284, 42.34968170042961, 18.087662919875115, 22.30863921103939, 19.668689927747174, 37.92158465231619, 36.38708676061323, 19.494385680844708, 7.798639747404284, 0.6146064785219009, 6.415638500644315, 22.917736230358003, 17.427400542843728, 13.729675296814213, 15.117170599199111, 8.036144654597006, 1.3070827914822487, 1.5998731385315619, 6.307766947054095, 11.175507268598004, 20.807079422858454, 12.00357746693396, 6.128611708841016, 8.052183226231607, 4.215540376401717, 8.309032282521649, 33.7438799488929, 39.04890129643102, 16.14052776367434, 4.979368034870395, 2.149421101616275, 1.966777405431194, 1.9291231420732315, 2.709291884976049, 3.4452216855941282, 1.5900301957322707, 0.3624380968751446, 1.6977099209062516, 5.923820349477953, 6.675527884114174, 8.494534896266076, 12.713251902211098, 24.67709379811441, 41.47706808582429, 45.756895619054, 46.96312642866566, 50.73497956798923, 49.765385350873395, 63.430381744138664, 60.559324449108495, 49.75671691279258, 42.649531210622484, 41.26215357934275, 42.75683156905636, 24.65665432714647, 4.0487849760440096, 2.0485845640782387, 2.12181227341775, 0.25832003703521145, 0.8955012574311226, 1.731073356443836, 3.5936721198020445, 3.0502480797229277, 2.389838613810078, 2.3919625772583872, 1.531464428670945, 0.8460295056143116, 1.414652690291405, 1.5392727645174151, 2.2839490828975557, 1.833399659202945, 1.3642547688176556, 0.6983811348196, 1.1955319320963276, 2.254649713154762, 2.04177753579232, 1.6244755925670749, 0.6862292030165273, 0.29083752764328835, 0.5842636970262374, 0.8979725957878175, 0.5531766457903771, 0.42692768477624465, 0.26251185565225543, 0.37553967126915533, 0.5760186297758934, 0.6110781226908008, 0.5804409182840778, 0.3256298397337237, 0.28167631116605574, 0.33785831904219044, 0.24401631747041982, 0.2092717786229426, 0.2794576592503056, 0.8587989655713882, 0.5127422187116839, 0.46784468596020057, 0.879799580622104], [0.3742482002464033, 0.19052180731969495, 0.20066969907812535, 0.07434569209093049, 0.07936696176447215, 0.07558813348652856, 0.20989042526531607, 0.11127902074686943, 0.04081226930382752, 0.2309640331734573, 0.3084471004624521, 0.340068084338019, 0.5735772607787963, 0.43578169999584077, 0.19282200163410557, 0.19284227232058204, 0.1921734469191682, 0.1591552259220231, 0.16666972108425634, 0.1303479297747535, 0.23938390636636367, 0.1968900357643443, 0.4098619118092522, 0.45790061955490424, 0.4303113112766897, 0.6520371054930072, 0.6460109353065491, 0.29323951972107737, 0.30122678306314254, 0.3167602576075062, 0.3868222158522375, 0.2682397112009987, 0.5134694812999618, 0.7251590334119336, 1.5674350146324405, 2.4330231739628703, 3.5058188726825104, 3.8080742666798257, 2.948335587016998, 2.3671734429174855, 2.3012935586514014, 3.2549021561299605, 2.822318658713372, 1.2843085296692387, 1.1414562982897605, 2.184256651709157, 0.36596185617869903, 0.7430580342488905, 0.19401772698808104, 2.222783152134188, 4.465737583175782, 4.256935110015254, 8.074623105987426, 7.2633484967293285, 6.721460800017081, 14.458563462380441, 24.20274784488063, 34.85928043242424, 40.26666387434929, 49.9638690487031, 48.42395436379218, 37.256429118494836, 20.688761126610544, 7.514859207214848, 4.054473148238275, 1.9669579570331883, 0.38979947867412723, 0.8306794938060545, 2.5234987706907335, 4.743409031821836, 3.9260782830176817, 3.306653908183498, 3.140073298446594, 1.4934390110354272, 0.7991701136192968, 1.2386469927526291, 2.939742654561997, 1.574792768205366, 6.059568187882824, 2.0348253798100258, 3.574857000381716, 4.0878223651839845, 6.188809304468094, 4.670144550261959, 5.231025834237376, 8.605039831130735, 4.976439985536761, 0.4881577524206331, 0.9257613014309638, 1.3003267540085701, 4.545344047008022, 6.202753820726949, 2.08577182023756, 0.18904550992433103, 0.4919504698726439, 0.63775428480679, 1.4929413603198145, 4.077817869763221, 1.8255779627830753, 3.077479870088639, 1.6342523453697082, 2.468519643429787, 1.41510731750919, 9.493745949960525, 4.6322799498035065, 2.8001771242387834, 0.769011928669868, 0.6175495431788507, 0.4371402496772428, 0.7675340531333801, 0.8813698157187432, 0.7139647728012455, 0.6864858731146782, 0.9057554975152017, 0.9646371992365007, 1.7188613020604657, 0.2701009064912796, 1.1999452114105225, 2.378091360292127, 1.9360701499446749, 0.7192573984784465, 1.0081605541129266, 3.0491422164824704, 5.566277186716757, 7.102422964188361, 9.697684684107381, 5.797839212802149, 3.964262066348907, 7.1646484251945255, 5.905845107570772, 3.8721540281849527, 1.5976058859978954, 1.4816482437233773, 2.1494887625017474, 1.2669099987514558, 0.31097080858965076, 1.0153722606839672, 2.5092149694119734, 2.5447241865819503, 2.5330340525796338, 1.459800641863577, 1.4595776796340945, 1.1400638568785884, 1.097319215055435, 1.6061391248818369, 0.8943918395426966, 0.7910233507713964, 0.6681000693671165, 0.4077074274180397, 0.46692951732585514, 0.7248332928265295, 0.502430368815699, 0.4699733378666063, 0.4160120043783419, 0.3995446073672464, 0.3715442469523799, 0.5537326417623029, 0.45120357085139523, 0.4877932171427435, 0.24215778816611538, 0.16312638057335732, 0.13804608685595376, 0.3216652734385383, 0.4069739441958166, 0.3294421383930791, 0.14018788483114014, 0.07460624625485751, 0.09132822194407064, 0.05666587283954986, 0.15585050647777898, 0.23067509545193565, 0.1161329844786275, 0.12578223726802296, 0.29877603714985235, 0.5047282955098538, 0.46182256071798267, 0.3240520663319096, 0.1080626235794156, 0.15925895422697067, 0.02077848402663104, 0.13303692903249495, 0.049215905263178775, 0.10133066424919714, 0.11321851788389106, 0.10897390814798494, 0.1637081783865729, 0.16540895486550947, 0.11207541510943445, 0.3567821616607328, 0.09762342688777755, 0.3937781716306364, 0.26966371543465123, 0.13960184289082406, 0.022432653631474224, 0.06086979947623707, 0.1208126019205778, 0.33808768576672005, 0.3297205960317966, 0.6492877691503495, 0.4275486756476664, 0.2990109503509537, 0.5294350294336196, 0.6846103060149378, 0.2741477199860158, 0.5006685504509557, 0.697253575969127, 0.5738901923741064, 0.41711486455413604, 0.7882806947154384, 0.9737076189729476, 1.4796217266590366, 2.6337921427142237, 3.0515039736224763, 3.416682765368493, 1.7668632682292693, 1.1325619562018303, 1.9186881665260562, 3.2882692688895814, 3.0036459094093693, 1.181935158468062, 0.848099965481989, 0.9209521691645346, 0.2009796888958062, 0.5611574433503613, 0.3387323027897266, 4.7651090545039025, 12.401621553205675, 20.22611168123061, 17.82201647758484, 15.131684349429223, 14.892906142819314, 17.989083951519383, 26.097795886378137, 36.66366484857375, 47.34974268944033, 50.73332040540634, 50.56301893726472, 38.2602499377343, 17.168384867329753, 6.748682049012954, 3.5432760369393135, 2.0475605803151287, 0.5551459207650155, 0.5917222677699981, 1.3091915557461402, 3.7940444388697228, 2.3892071122123353, 1.9401689042006771, 2.3908616169806454, 1.0060545477655627, 1.3268631816871705, 1.513001219399514, 3.2393232372499283, 2.694031168376246, 18.144456878785167, 18.465471498427853, 4.855253946396613, 4.156333179243149, 2.683681259232183, 3.0676979691751542, 9.111211895942688, 2.5753944246999683, 8.801001444939645, 0.3700480159492262, 0.10731358111145035, 2.1143627118679786, 3.2153232347580696, 5.637312291129943, 3.3894095449678363, 1.2859391324943112, 0.38352172521333544, 0.900688101687739, 3.3775367756043715, 11.168121445563532, 1.4811024213990858, 3.352549561569768, 2.5511470677391177, 1.5020272856758488, 1.410900452925313, 11.634750135483282, 23.993093236800163, 10.518002317797754, 1.18477777367638, 0.8483556549875968, 0.6380411694126745, 0.23282155124170167, 0.5156627910271768, 1.4029629240112922, 0.5915917876747347, 0.27818521785159267, 0.2764703147113323, 0.9980342200686856, 0.21447959836692582, 0.45939767793301617, 1.1784115217385756, 0.9487658186304955, 0.7182806670185059, 1.5026780314022496, 1.3515070657576285, 3.748579510758, 6.289845147440511, 5.813541441194474, 4.588299883950142, 3.447151246570772, 5.122098182478259, 3.9532735463111637, 1.2676938599155796, 1.1465753590868366, 0.6799128387243517, 0.8709567809297193, 0.32774896150635136, 0.15649273330646177, 0.6228244569032424, 1.45947594315775, 1.8581985994692773, 1.228300393108399, 0.6633292414969014, 0.6187136291015534, 0.8846328599799065, 0.5818512555091613, 1.0165147122836884, 0.8307547542837359, 0.5993832695868708, 0.3660500482205422, 0.21478693752038866, 0.15766615018008218, 0.41669848044553115, 0.3289206776647799, 0.4328155607706116, 0.26652428712094983, 0.2104829023441961, 0.3312896666747909, 0.325252618039808, 0.2492721862490139, 0.25971333646485883, 0.17297799548795148, 0.08723456217276473, 0.16955506867699086, 0.30197166567367895, 0.15031637924332775, 0.27201428769096253, 0.03316707571127242, 0.16673615622904994, 0.08723843091678235, 0.03127440569862243, 0.1376900857975406, 0.14144909538088307, 0.18147187277434335, 0.1989268337286288, 0.22551547796014818, 0.41028252472319915, 0.34948826917717535, 0.549850537171287, 0.38381044843023826, 0.337435040142267, 0.4082317992804512, 0.33829348762669875, 0.3321908925089144, 0.6014465588715769, 0.36815780124837355, 0.21853557427323636, 0.3613100477284001, 0.3895779260464253, 0.42361174980478905, 0.616269379613861, 0.5423549490590249, 0.5020562421169974, 0.5089784287396939, 0.3124457117049925, 0.26325189658711035, 0.3148552727314734, 0.4716102226126579, 0.792664617540375, 0.48481172551551177, 0.7823843917539044, 0.7097580920784705, 0.6372041111030887, 0.9822318486628995, 0.76646312350227, 0.34153931023132417, 0.6327842740762619, 0.6660318158326611, 0.6055213498973078, 0.711886958489495, 1.4334257668064487, 1.435019597411156, 2.5225056755927304, 3.728185637343315, 4.5903458902912755, 7.146941375347876, 6.813117765611218, 5.211844463502207, 4.166128808452237, 3.428541070991947, 2.811182559497895, 1.7356945213771637, 2.195077980718305, 3.093723385564743, 0.8615867288843279, 1.2971493890208583, 0.4698130722728468, 10.825375914573671, 30.487698854938632, 43.811533374171105, 42.61692454738002, 41.93260431289673, 52.42196352251115, 70.59405742153045, 86.45765212274368, 104.65843031483313, 113.10840022179389, 108.38711384804019, 96.52137925547939, 72.55623094497189, 51.31214064936484, 24.302978131078905, 10.179178176387664, 6.781753022824565, 2.628985523216186, 3.190515224010714, 4.787492550188496, 6.324070278675326, 4.375972180597244, 5.398563502296325, 5.149297858438184, 5.334570032934989, 3.4002392090136007, 1.922137155648201, 3.726084227523496, 2.3591318486198305, 16.927353259055845, 33.800879832237, 16.54867587550994, 16.9875047668334, 20.82401425607743, 21.47968549882212, 43.158364603596354, 35.81456976552164, 18.65359033307722, 1.7659563427009892, 1.9333988932832598, 13.179349110972497, 21.537252164656117, 29.039308755628525, 13.531825061767334, 2.0005324651156706, 0.832058942366031, 1.290420808138386, 12.456688688647363, 47.46850813588789, 19.383137456832394, 8.088458286177728, 7.491949623630894, 6.16972795417232, 7.738716227392997, 27.730372644239857, 33.48577230207382, 9.919833021779215, 0.7250269598537876, 1.0281208830495034, 0.633793487664192, 1.2422875651428777, 1.344013009821215, 1.9553226136392163, 1.172519999165689, 1.703517602816705, 2.327140997494421, 2.1967133639320253, 0.28277724080028077, 0.8796486306575038, 2.510254397507637, 3.4479874468618825, 0.96198046760213, 3.4505524318064418, 12.422758225471744, 22.693596309231175, 27.862436886756655, 32.59116791909741, 27.12306618690491, 20.348854411032892, 21.010264081339685, 17.336862433341242, 10.290728422903246, 3.333418691350568, 1.533088780218555, 2.4868216678019497, 1.2795793769821044, 0.3130257934812577, 1.3749041264095616, 2.9039282279629863, 3.371258531847308, 2.8082510780903602, 2.6046619251851113, 1.7850280096454008, 1.6799200109897123, 1.4325659097202363, 1.8404144505339286, 1.2552965961156355, 0.9970384896282227, 0.7369350918358373, 0.4465693211363208, 0.38746520876884466, 0.6080645166577832, 0.6853377218208005, 0.6778151674136039, 0.7186813003593876, 0.38003317531078096, 0.4749642474757087, 0.7230450597501571, 0.47854169422099674, 0.5719020409930138, 0.5168148034041928, 0.30967792796511806, 0.24994680327513527, 0.49471938742264626, 0.5545829380712202, 0.5363500454733449, 0.2199194508214151, 0.2931447393230854, 0.1724235776571497, 0.23378616319068019, 0.42276411948184817, 0.28866101056337357, 0.40406032795867614, 0.38254931448928775, 0.28439996824149166, 0.5949877022254852, 0.6878207660009784], [0.06562685308557364, 0.03627101883232113, 0.07549759721563709, 0.05231554680053265, 0.09503463193053201, 0.033877526500052026, 0.024574836565842553, 0.012234900082882133, 0.07785397641841443, 0.08704610454339175, 0.07981053433350979, 0.03305150368701547, 0.20496279451875918, 0.014917906617835886, 0.1168258267364675, 0.06238828916403075, 0.025364223139120207, 0.033244806822509534, 0.12410045210872928, 0.15959010339312016, 0.1383656680944466, 0.0863321029370831, 0.20106000555378778, 0.20843134952648995, 0.07690682361323027, 0.12452108800531396, 0.08352954646632557, 0.06436311444568057, 0.13143612702767696, 0.2142544144824628, 0.27630137700227003, 0.3505824572376667, 0.19579091409762062, 0.22500676493490898, 0.39937848886174543, 0.3936293973557411, 0.624154691974963, 0.4800688751762914, 0.6027183261129164, 0.5215548038963349, 0.5097957219808332, 0.598246946690544, 1.5665836151569121, 0.7983187754308024, 0.2394273129081534, 0.42514971727805756, 0.4550146437700718, 0.6900666293597991, 0.7637870251651734, 1.8261601896055284, 1.6506849926325584, 3.2909041210528347, 4.24650356654198, 3.6115980869339364, 1.74075388860318, 1.4563938182207847, 1.975419612661485, 2.6338220507867875, 6.3236476432892585, 12.304489939443528, 13.109457377464542, 8.372278540365159, 3.0012714045663036, 0.6834958013026946, 0.9859021452646103, 0.244639499353305, 0.14647587322660033, 0.4553513853780685, 0.6587935719759234, 1.518537644897738, 1.252803317000789, 0.20800322895088505, 0.49986391298232546, 0.20368571062722515, 1.3429448993936663, 1.163721264850709, 2.008051893884136, 2.4631523701452442, 0.1326038748506577, 1.8938908197226065, 1.591257529874002, 1.5355820593334015, 3.042693594771047, 1.3205906989112979, 4.929017059264645, 5.390313777231402, 4.753350769319843, 1.7054384610345288, 0.10934520798224596, 0.5056268247144838, 2.510659382227929, 5.286115523307554, 2.1585364447486017, 0.35189816728234297, 0.23941614334621739, 4.1445587142821285, 13.890412065290636, 7.0859642086490515, 1.8425400074451201, 2.7963920370224984, 2.646798477057488, 0.8066512379915485, 3.2503279370646325, 4.288494990717981, 4.091336073413972, 1.9332552364756985, 0.050601329308964556, 0.22997858363293835, 0.10697470211814489, 0.055041885183703516, 0.2268615557301429, 0.11765957554622043, 0.03624044809370272, 0.08509609668004899, 0.1448377474181114, 0.03935134346266428, 0.07671352430817581, 0.08319627523662583, 0.14304831924457706, 0.04656555131077767, 0.0518024057870911, 0.09763481095433237, 0.015271245520712148, 0.0980668768827473, 0.25895778991041646, 0.23100918639571438, 0.06737710352266027, 0.15428993941074418, 0.08312948769138706, 0.09532586791582646, 0.11619935833638716, 0.23191441120880268, 0.27057722931908024, 0.06428964661374208, 0.111266702053047, 0.0830501746085863, 0.3038692041750877, 0.23730370186028943, 0.24696403994194924, 0.08190573884114143, 0.06081701984869377, 0.0599984395798416, 0.02792246459472564, 0.19410662383081453, 0.17343469114313204, 0.12186883032442102, 0.16727087027843923, 0.028151827488815593, 0.08855872982812506, 0.14336765533493412, 0.1730010700562308, 0.13256603010719822, 0.0773907000679643, 0.020458077328399788, 0.019838509465297385, 0.04537998045223855, 0.036946386624608314, 0.05118464014583057, 0.028451863909140233, 0.08553216158742867, 0.05816142202445096, 0.1879645292196543, 0.04597899609155232, 0.1222665218876735, 0.1003617545469634, 0.04346191079445905, 0.035140970196094246, 0.04329127237020482, 0.059432484464900154, 0.07231673120611137, 0.06881198620483761, 0.02113115451779337, 0.10135593748981915, 0.10945214619559628, 0.07841540395372337, 0.09662581953190028, 0.06757943500434199, 0.11199493757298878, 0.03645293407082077, 0.09749851625172362, 0.09556121012616543, 0.06538199606321513, 0.1514721454511727, 0.09203679964787538, 0.13213130585368604, 0.04277459586099271, 0.018771101923419103, 0.08783964905887844, 0.020522631727339282, 0.27908543244965617, 0.027990479795863072, 0.03147702063283613, 0.041864862620470025, 0.13691166385767922, 0.2853186608802888, 0.22641668847251326, 0.03168137841707757, 0.13434287911701587, 0.10451657111726462, 0.07643162693467832, 0.024491400014789357, 0.044463812073151913, 0.062119534028874296, 0.02954881946225801, 0.14601032159501506, 0.16381049708973977, 0.23328514168820075, 0.3575163803273632, 0.23002700038975288, 0.1405097643334058, 0.1617396235345833, 0.07776210715453472, 0.2220290731037817, 0.14366785454894268, 0.023870596834909052, 0.1818934203155579, 0.22873670914240424, 0.3757509583186719, 0.4549574629674035, 0.3093497358983563, 0.3014482744038105, 0.08516839239746334, 0.4517897813310547, 0.7138969893417051, 0.956931580458918, 0.6871311030080242, 0.31798719338351683, 1.79406613111496, 4.915678549197413, 9.348610408844488, 5.189556085294293, 4.168090483834667, 1.5699319709693234, 3.3063060429788407, 4.658932455124394, 0.6964943521926481, 1.255607811673995, 1.510248818705159, 1.3023493487027384, 0.5758027155553141, 0.4837008980253051, 0.04594058827346852, 0.03734318569542901, 0.38137980466408117, 0.2016399034689511, 0.4353745089423272, 0.43129371178727, 0.6202177967756026, 0.6585638681727072, 0.43115137265093867, 1.7727373852845163, 0.7392502095430129, 1.5955837815999987, 2.8002928341588667, 3.9514631273285037, 10.971748963479074, 7.244184286363664, 2.8897206677544505, 4.101797279811675, 3.242905586957932, 6.871590008658748, 9.781979360888082, 21.734608181061287, 5.42210703895938, 0.10853053476180761, 1.0349891983693646, 1.0147338949384228, 2.004381781143527, 1.1051942311948346, 0.6976025443403953, 0.23344867081651766, 0.7531951548111054, 17.54030204588367, 5.602252675640968, 1.2249743457763427, 0.9070530665978309, 3.489535398060276, 0.183298226385828, 7.681907069298529, 10.95747349723693, 8.152362521617643, 4.107996831017156, 0.11601817854229482, 0.15608909690091688, 0.08257208977855983, 0.050857769580738205, 0.20723165583706674, 0.06550291538118355, 0.16328327538024995, 0.041796711438726035, 0.08837936566241326, 0.05037515717107923, 0.16986669792282968, 0.0197735452093184, 0.24235701699170376, 0.10300263582218079, 0.06622504518036881, 0.06970707567468767, 0.0712544966729418, 0.14052301765449587, 0.1936236053945557, 0.12109711165389708, 0.14335270129865216, 0.1504155569860051, 0.09802858014741252, 0.07191003044886936, 0.17802125954579923, 0.09669031647424545, 0.3165196447122482, 0.18376973818146414, 0.06682633227037807, 0.08021636175051813, 0.1490276814588616, 0.1675035465028017, 0.2364896721537075, 0.16158616080159144, 0.044805242139245235, 0.06683760142374424, 0.05799495494894444, 0.01610633402672266, 0.1883951165983754, 0.15762292749939427, 0.030782554268596635, 0.0497173021487411, 0.11854922579180811, 0.08620383683592082, 0.12871865994266926, 0.1512135294896941, 0.08554824943383856, 0.0779829932857425, 0.046441019888246254, 0.07034544142023211, 0.01992177939222705, 0.019624728799587297, 0.08763644423696303, 0.13455635717799588, 0.11014324177296893, 0.13410248072637668, 0.03371587811758922, 0.08272077212290418, 0.10387988310427436, 0.044589913975928104, 0.048962514021343766, 0.02141612390386722, 0.061742710700679215, 0.036970261754768516, 0.10017705840929862, 0.06366669072679455, 0.17631996212707413, 0.15980306051431165, 0.02749071276235965, 0.0661256605939519, 0.21583603364565682, 0.19350054103039926, 0.23895402378853292, 0.23704039744071423, 0.2772739715874195, 0.3196169688336311, 0.3203220761591389, 0.355002815204282, 0.19589352391419873, 0.1796147530718196, 0.1706369840089352, 0.21656424618296086, 0.3126214829183394, 0.28938729255910844, 0.3264133331756438, 0.2779579348862171, 0.12263933857602459, 0.45485646193546636, 0.5111144657336897, 0.3470603833275457, 0.2699518870682486, 0.31979868488927043, 0.4051875190869455, 0.34030431521035015, 0.42143186193800747, 0.34110349813295954, 0.30324824394718297, 0.20979184507121965, 0.26367076282058993, 0.24350689964429026, 0.48310721052750466, 0.758614093065262, 0.7506578716058886, 0.7170289406372655, 0.933767655684102, 0.7175675923785856, 1.2758515318555217, 1.4842648323505157, 1.8436105693540268, 1.6394791487724552, 2.3324567896704522, 2.5907071127045542, 2.513937993395713, 1.652690304383155, 0.9413141120345363, 0.5515129479669756, 0.929014784914832, 1.3664052082646279, 2.822055614763691, 3.8080786793462695, 2.182576161238455, 4.175756266040187, 13.298661728059093, 26.509238789158484, 23.57253082336918, 23.226958244077622, 24.8728455651191, 27.550375077032275, 35.75154119922269, 41.274265858434866, 35.01777948871736, 23.539502505333196, 10.00559074263419, 3.8696133129058348, 1.971531318080041, 0.19181133247911933, 0.41462943017963444, 1.0328170633123768, 1.2861950671480549, 1.9647251478125973, 2.4797604208992374, 1.7088735992870026, 1.2031432914157068, 2.281502994798845, 3.3769432719676726, 3.658765078552308, 2.0053585738905015, 4.213626750053899, 4.31682676076889, 19.74364838292522, 18.12006561986862, 9.408094133100203, 16.68010469405882, 18.74010605196799, 19.125351444367443, 39.04314325701806, 59.92980757067281, 6.1475851939570525, 0.15052507691566022, 6.799406140081345, 11.974841202459029, 20.412600771073375, 11.062861700211803, 0.8832334931338988, 0.9632350744739656, 12.41449575270376, 31.91329017762215, 18.350463682605376, 11.032790849285742, 7.941535124855657, 8.484970196600884, 6.4092381731156385, 17.919614853397494, 21.612944103056385, 12.365766186867992, 3.2029662978264595, 0.1369138242256257, 0.3436961235298265, 0.17887250580374273, 0.17569069750607016, 0.527090064940914, 0.19367183829026838, 0.4117202572524548, 0.28290067288664084, 0.8228683387560229, 0.28318008047438437, 0.39113716012047184, 0.2793775570969428, 0.36102212124293853, 0.18973834452129182, 0.09026609466321046, 0.32864739878043053, 0.16615739212401454, 0.28421046873254163, 0.7630732763678797, 0.41401131979880795, 0.5245730677439321, 0.5165914734525066, 0.30479718179952714, 0.37650141804929704, 0.35080799352257486, 0.3583127440464112, 0.6029959563766757, 0.2683366979322126, 0.4645167693736092, 0.27372183638714975, 0.4778310097754002, 0.4610485667663236, 0.5889785085474292, 0.49005777304691656, 0.31992582484118404, 0.2006243007077325, 0.23235938571874173, 0.6468224982100149, 0.6619565957976926, 0.48216029520957704, 0.5944777941030841, 0.31874065617880515, 0.30419853005197744, 0.3570749911089098, 0.22105555921312303, 0.36958388924118013, 0.28350922249017224, 0.24402408560197203, 0.12709925732304975, 0.23146258787282054, 0.18710087233733746, 0.1911847644876088, 0.17234917519794357, 0.32126264826905343, 0.31178093124781886, 0.3393255919218064, 0.3559405987541522, 0.3776626541249214, 0.30215509776626864, 0.20875408704723084, 0.17969574388717452, 0.20543372408757288, 0.3486078809345922, 0.16919246394067042, 0.2687130309641361, 0.23929386039174375, 0.4457698930655757, 0.4480015684760386, 0.1556924625389999, 0.2804444111402958], [0.053386449618565465, 0.029735697035287178, 0.043524515499631246, 0.09700663417818085, 0.05585235258143756, 0.01886916883860625, 0.052045067967546564, 0.052868673773182016, 0.047547699012342966, 0.0705598158040835, 0.060539891372524926, 0.13982362534490325, 0.005886372546815584, 0.022287841946367296, 0.06068862734302398, 0.12357226512845486, 0.1022604728237756, 0.0469608718319045, 0.08959016762673856, 0.07030706041522565, 0.029014750841944933, 0.021836311639016195, 0.014844776822193978, 0.06319544323149227, 0.07394253065989864, 0.06107363249025038, 0.016594739976309, 0.026790830156495495, 0.017561382058286862, 0.03840253973800329, 0.024980564391420736, 0.04741887366699596, 0.08157108099229875, 0.04605780355632306, 0.05283572050111909, 0.046477432047287305, 0.04371240239350065, 0.036409493055074446, 0.0317213126653505, 0.02933702679471143, 0.06429779778925643, 0.04553254303191939, 0.06543880914367976, 0.08602639555089897, 0.02145548358619694, 0.034167663149175145, 0.029024403549790866, 0.09899536012521676, 0.07871304443406482, 0.006678695630867996, 0.06110778085947518, 0.2535133409283815, 0.2063385045696651, 0.02567134395752463, 0.1074693650908528, 0.076591425214804, 0.17234620277679738, 0.20184282483833454, 0.2842382011154006, 0.4176365397870541, 0.328856663357827, 0.08914947554829622, 0.012847386420734469, 0.12924822588120738, 0.031732424770692186, 0.06287239544514207, 0.11616358203032326, 0.08006647664813266, 0.02968366817390967, 0.057455889520145235, 0.009351031039841473, 0.06556729741034008, 0.05316863549993404, 0.1997017010205215, 0.190938068854232, 0.11456726930074154, 0.17817927284106133, 0.887073677393698, 5.464273989200593, 3.880563589834398, 5.872541243030179, 1.0364141219085263, 1.7784191836272518, 3.6976958282532233, 4.048646467347299, 5.988920907820425, 7.24774677907267, 6.6520529889291335, 0.8975080400705339, 0.1716182353876291, 0.6027269062976683, 0.12735343763544676, 0.17668069760885932, 0.03640092436164137, 6.08567891582366, 12.84606041446809, 18.74618572573508, 6.020759276805386, 0.3476844998376985, 1.9749214716496009, 0.06415752709032067, 2.179309562329323, 5.163487032536538, 5.2918961163490055, 5.529094588372016, 0.8724920824170114, 0.04538422457933907, 0.1772657896001493, 0.004566099012135378, 0.07117950432603398, 0.026157528252130555, 0.07029773712518715, 0.0436700645443653, 0.07728347074120276, 0.0150814721353292, 0.05311336991707644, 0.07493763290826352, 0.034630165750821756, 0.048311622738237345, 0.041209451418610356, 0.04019459176267828, 0.0690270041025454, 0.038464041276564526, 0.07444708382770901, 0.08632209016791276, 0.026036076503054752, 0.05182449976282735, 0.02374406592289527, 0.0614831256379764, 0.07296739266284051, 0.07906030442926192, 0.056071557149651556, 0.053941966785538586, 0.05279082391831664, 0.026861112977888797, 0.024679097301897504, 0.05285005400618238, 0.06496789489662455, 0.1143300501749881, 0.04293641661323848, 0.085529932271569, 0.056845577914387956, 0.04013302510664348, 0.03549695210230928, 0.0677463808848012, 0.05510424857117957, 0.029214157782975706, 0.11578986901910075, 0.03794221282606164, 0.08802496572776188, 0.02618817751476121, 0.04013433128655438, 0.005844600166329333, 0.0831433462219373, 0.07413400667569331, 0.026187702540248155, 0.026174027870799747, 0.02131320382167976, 0.02638304346962081, 0.05281170747513252, 0.11098470508811936, 0.041936273506331834, 0.07003642453421509, 0.011699614340379354, 0.06301279637902495, 0.07008793628624371, 0.033767895487647866, 0.07103426937734889, 0.012601205981486749, 0.01576647539848402, 0.12916381831371015, 0.0317673985996554, 0.10214516893029214, 0.06783782113944331, 0.06173771963785253, 0.06826627113285565, 0.025236274964446505, 0.06115176196720812, 0.16036915352507947, 0.0520698968771725, 0.019382472645731706, 0.056100074772632895, 0.023270974070915294, 0.01785189026005326, 0.29753362639777126, 0.09640350081627408, 0.01940835684147333, 0.1475240960116348, 0.026360928426466645, 0.04219640249146089, 0.0683561255854945, 0.07477715280988524, 0.02398156658596089, 0.058368131698619936, 0.0937265367998231, 0.0500984232301914, 0.046969547777646975, 0.03793356369339651, 0.025158381059525475, 0.07850560314592817, 0.03710647218770558, 0.039703433642223965, 0.08481934741740266, 0.026902625367285746, 0.01625098866380511, 0.042773599946691145, 0.014501404723212605, 0.0493180860705193, 0.04015622990986994, 0.06427267776621927, 0.013634180743998338, 0.08973269828505094, 0.004943114341116481, 0.038292950860434966, 0.01413911121011141, 0.06483845668093813, 0.0356383451200541, 0.03317600446602991, 0.004554137506807644, 0.05553045392697377, 0.053873252529170246, 0.056197601595833424, 0.12563904011321644, 0.14717788555689398, 0.026879788286262946, 0.059672342763552745, 0.04221907103314035, 0.17988556515305273, 0.2533489844251064, 0.18932651097495712, 0.10056464527282985, 0.13838287442922592, 0.10044749510744888, 0.21772355171701602, 0.15388553691727502, 0.22306499251675224, 0.5104287557544247, 0.15625754431370767, 0.04541735405162458, 0.13822219514798734, 0.10147602943282935, 0.08103693384797343, 0.06647898034463007, 0.08012841485681073, 0.04087181348774222, 0.21168840298008537, 0.01777268059912228, 0.07707000034110201, 0.03580546720073589, 0.027515093510549878, 0.09166245844455496, 0.1092120772227645, 0.34282725724962454, 1.365926801677673, 4.812768793875172, 10.647508194369655, 10.747161892152603, 1.5532846965136067, 2.065614269625756, 2.8604715533794898, 8.981125508585285, 4.426156945766942, 13.01491060564595, 20.727157208227343, 1.5187501883314503, 0.5648918461895759, 0.8668743290247456, 0.8546197414398194, 0.3190761414026061, 0.26443108976367985, 12.42583336368684, 20.51573165001408, 23.69378305250599, 13.156511110644187, 1.1617506415613237, 2.485191922995352, 2.5819675816643626, 3.3002138666568266, 9.638062696303091, 11.971285573897823, 7.81463223118936, 1.6519437057356683, 0.08021070802163693, 0.21612510926300482, 0.07538593990067322, 0.07219982618886618, 0.02856835715412613, 0.029126101721739097, 0.019793898250246723, 0.058361535681591886, 0.08796117358630703, 0.04649926172268968, 0.060285730212326014, 0.013118294262958151, 0.05335203311856716, 0.01765523932033008, 0.11166692170644961, 0.01870594997589867, 0.0879996465218644, 0.09364753015219204, 0.02531960043275068, 0.005534151174698867, 0.05669565450760627, 0.08084611666779365, 0.014227440190171043, 0.0032208347317552377, 0.0829657517193306, 0.03473120891759473, 0.05392533118626284, 0.043374262675042116, 0.11079008045095591, 0.035386957198141084, 0.037920360168021534, 0.04122700249295562, 0.09194335224287165, 0.05523191329332129, 0.1165709875884556, 0.029399922613294858, 0.045787125540476654, 0.035767407952657634, 0.06578653645251067, 0.12896728611761524, 0.045563849214945114, 0.0052874699054706485, 0.02000817112744816, 0.10448532239083322, 0.029260259039039095, 0.03546350087309557, 0.026646953098656192, 0.035136369838108944, 0.03201718156736705, 0.03153358664994519, 0.1382833596078619, 0.005318321223791328, 0.06362799562573915, 0.01204620496625261, 0.028088359019508766, 0.05226884991110814, 0.04039609586940177, 0.0712211182220809, 0.030899669960021015, 0.05315432497750848, 0.03304965358467833, 0.03472868848832385, 0.046563138133816184, 0.026259929309749318, 0.018084725447660013, 0.09183238440703961, 0.025577410086688977, 0.0787845204374002, 0.055436374499432506, 0.03870264702146092, 0.1333633284535139, 0.2415410720653111, 0.3002051588508391, 0.25006609848670425, 0.19858214012797804, 0.11206202389251803, 0.1161010922383397, 0.15474963813058792, 0.46268968031771723, 0.2701129187499323, 0.11624815047628458, 0.42541089197320325, 0.16407674328694422, 0.12162770415025374, 0.34326481602845654, 0.2168527548952449, 0.28369093854581157, 0.14092611779849376, 0.18930921270962686, 0.205869045889666, 0.22488241354303978, 0.16664157501391827, 0.17675860875075866, 0.26329930210786484, 0.16484802528735132, 0.18896425863908184, 0.32782492678492303, 0.11465266512166108, 0.1302950390644612, 0.13859941684190305, 0.14367652666424552, 0.17923451299148221, 0.22732914515560676, 0.22058715773445947, 0.11974983878674046, 0.21636055872565318, 0.12869629017528028, 0.15541535321502917, 0.20009848860002336, 0.25063347852518486, 0.1745885880964418, 0.19576839111264677, 0.1502768031411594, 0.27261851655860103, 0.1925300302044038, 0.24090167976194815, 0.20119290648689195, 0.5194633838630492, 0.556661426540344, 0.25813746296109696, 0.25428862190775336, 0.4459390452792568, 0.38736641407012945, 0.2853425628235263, 0.29049189941536996, 0.6563705278019751, 0.3209563050298922, 0.33149111715535967, 0.49194614913675094, 0.640930240192721, 1.0274991873771915, 0.22258698429551818, 0.1631979485072436, 0.2865826753118346, 0.33349685791519385, 0.31007329062108074, 0.27818638230523757, 0.20052273277073138, 0.2628601498661503, 0.2413610567248637, 0.1193464398684521, 0.20190659399715163, 0.10184172150348464, 0.23929658766475417, 0.5315900654081376, 0.17344051341135658, 0.5557948278803979, 0.7433671047610622, 8.469926926397509, 17.379076942320793, 22.71942315563079, 10.336088672760996, 8.027599280880343, 12.083095677437322, 11.662201823726779, 13.214581801045327, 50.66889155295588, 43.456805982897365, 2.2983302079862167, 0.8716229097016397, 5.683706575824369, 4.536953606913167, 1.3507244303341837, 0.5419188305254906, 19.57438438169418, 46.36289004356631, 32.78445839881897, 20.01424877874313, 5.946069994280416, 5.51837278950599, 10.168214171163498, 12.26933373558906, 15.359205353644588, 18.518915753210745, 11.139926468172382, 0.8927156391643709, 0.10372394590728706, 0.24833840167810842, 0.23120444688585498, 0.18048061628735837, 0.24586519406687832, 0.1982687488799134, 0.1891864088153647, 0.16438199868125303, 0.24619933097593247, 0.3186957021394084, 0.23087147443044573, 0.083131410572077, 0.19946160906505203, 0.11049693690672999, 0.21488283640675007, 0.22351024281834403, 0.16329211603489616, 0.2992006337210056, 0.16628152901126494, 0.14414859004318714, 0.14247527015545677, 0.19846042407856834, 0.17291997198856648, 0.27967574916058974, 0.23586368638901944, 0.2257511878926908, 0.2613864724914874, 0.11938827592999705, 0.2650147874749476, 0.16776606951269413, 0.16433969530607426, 0.1988958531329709, 0.1845135789124235, 0.12493538835476484, 0.21925463972072448, 0.1561766147853867, 0.20253944390964126, 0.17891249559339018, 0.20649880080694155, 0.22819871623669902, 0.1485563382025688, 0.09599009678969461, 0.1639674072183909, 0.31264072704699736, 0.17616803156993083, 0.1845473480681258, 0.20401099155987465, 0.2143192714861324, 0.1612485918186365, 0.12979876730711232, 0.31695398592179824, 0.21866029338730922, 0.1565614973585452, 0.14569593443264886, 0.1897013884398245, 0.20472307028549336, 0.07338425940683774, 0.24715441279113295, 0.1116896668569215, 0.12953970701463763, 0.11044969992531885, 0.15265850921071347, 0.11240073434648015, 0.14782164456142535, 0.3497332028083263, 0.28409852796504576, 0.180781765450393, 0.12451746440943211, 0.19808928512277144, 0.17311694851565748], [0.07091226221452798, 0.1361389109684575, 0.12502784750634624, 0.13412633670433877, 0.02980259374805516, 0.0548449048261729, 0.16077876541643374, 0.09498843682869788, 0.03682192798042971, 0.07147352121049358, 0.09446531368960297, 0.08077531482183165, 0.016507653016296607, 0.06076900145759987, 0.03821807342671579, 0.04061209052921303, 0.06493386527102801, 0.038404956745404395, 0.03381232475681651, 0.07063016565817018, 0.0846911579250328, 0.11813566088676454, 0.011231080711548849, 0.041731708878350836, 0.001662353937600499, 0.037020245161388195, 0.03414934981734522, 0.06243072660459627, 0.05626595962131697, 0.010170455920630166, 0.04222292445539948, 0.03630955688535206, 0.10363965325297848, 0.041251195549604394, 0.009200920899128242, 0.016435836103834933, 0.09017781069081637, 0.0899699557152006, 0.051657144025328665, 0.012939448164205157, 0.0631023290747356, 0.10478591230968315, 0.018845983187577898, 0.0952437969164983, 0.057577157408119216, 0.07974338672694661, 0.03402726987617151, 0.039677367500600316, 0.07642300844553017, 0.07702107796625746, 0.008008389174187136, 0.03338591638772238, 0.07966808794486908, 0.027057490041179043, 0.08098054211586714, 0.04996588235841163, 0.055117701075129935, 0.06009220491133391, 0.04087277109764757, 0.006798269028114456, 0.09901189996350197, 0.08073569275438786, 0.023172843953474395, 0.01009340183959613, 0.04333179076052001, 0.02156766567138895, 0.041348235906973, 0.0314463215744904, 0.05364517666279309, 0.06898880695864078, 0.1077163671593993, 0.10049092463187634, 0.012714836930465555, 0.04619101858547619, 0.021471701667553956, 0.11386440661285194, 0.1844427770664615, 0.517986917928342, 3.1221985672750785, 10.75563911468752, 6.735748033369742, 5.879864308141894, 1.6810185197860965, 3.001248605789677, 2.6475530430193874, 4.443296722827419, 3.9371940349378898, 6.215645670890809, 7.707240187352704, 0.2188302576541901, 0.1255480441895704, 0.40644454679662184, 0.5426783607371393, 7.027658176037574, 13.909947429933856, 14.7397336652202, 22.27342417163234, 7.475521756756691, 2.4970950907276523, 1.4912315746468883, 1.8380628670415573, 3.792793202784754, 5.71524243200979, 2.944435525325037, 2.8488395194853506, 0.23521015210257423, 0.018257005215292017, 0.06443486624066869, 0.02275661114723452, 0.038085398489549276, 0.03810652336406131, 0.06231787419247051, 0.11920714210118018, 0.0995950154479473, 0.1364883389924803, 0.08005646387896231, 0.07098246651190905, 0.018309194955133626, 0.06763063266032165, 0.07809476551389502, 0.02438938966201198, 0.021829150632143985, 0.002308119254584815, 0.018431887766646764, 0.11048115549548981, 0.03929468359978449, 0.03203848264210167, 0.01760005609192435, 0.06352059392919464, 0.037273142276512045, 0.03400431788196007, 0.02021465672089929, 0.0393989903011149, 0.01458628535000307, 0.047903883931857925, 0.045080577969671264, 0.09602689965357704, 0.06939492548906034, 0.02198201198611529, 0.02979160613200117, 0.06788248406542886, 0.09297021649657719, 0.03317269879663664, 0.017065912778038653, 0.09661564588426583, 0.013109565648670881, 0.055160977381972544, 0.023091724818392147, 0.08279902800436943, 0.05480442857069354, 0.05082212734006105, 0.021556729766269846, 0.0163379856084864, 0.012177818871643997, 0.02993181554390298, 0.028799035804226037, 0.046963334804581064, 0.050612904897500435, 0.04798483644281665, 0.06959841376350773, 0.057813966676833174, 0.02966671081770572, 0.035879379363670465, 0.05251455346062299, 0.060166205174379775, 0.07735080986974702, 0.03739788054278301, 0.0465144417549093, 0.05208004754216922, 0.02580720199001653, 0.03402311384918229, 0.059937370880957574, 0.048989284963857745, 0.04465656745578012, 0.08516743478755798, 0.10164878992063385, 0.03129525286626191, 0.020141660033034223, 0.12256787023356847, 0.03289317629570442, 0.05083058495074511, 0.027493426628831415, 0.11632111269019305, 0.06374170988677971, 0.08871819869044328, 0.11792082685015856, 0.06794012452085173, 0.050654645198054855, 0.0943617845675157, 0.14808994387426686, 0.07620170862684328, 0.015205502727880113, 0.05493510401837769, 0.05266165766384333, 0.06583513707042703, 0.06147262257253451, 0.07517250014408942, 0.03628795703632697, 0.04622352752654303, 0.010739861304060587, 0.021341985744994976, 0.02188125418709411, 0.0037746451984745485, 0.040153556263014194, 0.07533918555465437, 0.010215761402862207, 0.0669946800917387, 0.055550709291691744, 0.04015495820391563, 0.017987346096384912, 0.06235151311322566, 0.07396921350230133, 0.06080305789627376, 0.03694300051598299, 0.08688955447606503, 0.05516740485965725, 0.025053597468462203, 0.013011421167081403, 0.05220186701344867, 0.08560923769349053, 0.02803857096530978, 0.08221984255097567, 0.02851781833376135, 0.025075827424805013, 0.008543028530003804, 0.0489467517623017, 0.07552141488920297, 0.02283847147238351, 0.06484626311688654, 0.06638558656578103, 0.03080928307627478, 0.022690492013709682, 0.018867598358361472, 0.07313325069844723, 0.06768599017373017, 0.04581010434776545, 0.08221758259159904, 0.1382870827951739, 0.04647188940115514, 0.056562110060645696, 0.05745981955119679, 0.045788627072808244, 0.030552534454111612, 0.021740041200011488, 0.024083408399394924, 0.08638477148187738, 0.07005621258529925, 0.0852963520634559, 0.04129484340909027, 0.14502461158460186, 0.04286201415403236, 0.12910740359896614, 0.14970029133462137, 0.7698768725798977, 5.600991143334297, 12.169761426987188, 13.810562414507713, 5.914283596700238, 1.8044832108482238, 0.7465262062126591, 7.1182688493882464, 6.683931562208361, 11.95150702230392, 21.676772832870487, 21.018887412163522, 0.3354832626158192, 0.7766778334494561, 1.132899892906989, 0.28318841551100055, 12.809624537344902, 29.681812601704753, 28.26369143301441, 37.27404056056854, 15.89400189538156, 7.105268153452105, 3.807794062360641, 3.0666041181933497, 8.497139350060495, 12.474205993836927, 8.766948407696141, 5.446804242749368, 0.38949613849962916, 0.004249155988931776, 0.07694023270760814, 0.06437789228173994, 0.058176828052608244, 0.0540525745600462, 0.2497887746581147, 0.0576056290658251, 0.03944204444245946, 0.07444360578853278, 0.025848323674572092, 0.058638805884026715, 0.05777014261712471, 0.13378902819127808, 0.09136063512414695, 0.04365647414458856, 0.031967560137291594, 0.028164552209237893, 0.0394859527718396, 0.040995452417841846, 0.07978453330935971, 0.05773747662803339, 0.03470088332711208, 0.039757450501764977, 0.10628243442624809, 0.10367281719922058, 0.017916147799922094, 0.058526654442351674, 0.049237777073416984, 0.028988529567516623, 0.04562394498216529, 0.11469928157185355, 0.03979481644027176, 0.05417288866855445, 0.03772311551015704, 0.021167612642109878, 0.04880951477154609, 0.04419715218846837, 0.036709236446768045, 0.027860848142975764, 0.06483446536285263, 0.030642913676978602, 0.013795783161185684, 0.030181996877335256, 0.11675376084543045, 0.03669255105177722, 0.02409879910579372, 0.05814502008199211, 0.033778157235393604, 0.06587078314154379, 0.03755912289864594, 0.05125750276830889, 0.06331353951545973, 0.034379570729910366, 0.07144761211689442, 0.04634736946994259, 0.00553013208592611, 0.049983862441994494, 0.0604560200665747, 0.1371390081100887, 0.015879700320862954, 0.026813311006633506, 0.05900921705629557, 0.030089886295759392, 0.08137144614011049, 0.0410935040112705, 0.05663410700376957, 0.023667397758653088, 0.055423508052744215, 0.03331175524621241, 0.0632915374702744, 0.3281556929071104, 0.4841585895947872, 0.27947138754590867, 0.2459670990825661, 0.12277973950990748, 0.09321518843212435, 0.3053826874782962, 0.3357139776550955, 0.1876320470605166, 0.41345823496099443, 0.23973561733240084, 0.13039273059656545, 0.2388978389001662, 0.3318649987059255, 0.2056404758965777, 0.12311898622541659, 0.10468184692604889, 0.13815785908410627, 0.20198072066470502, 0.2603595163072309, 0.29119090868100045, 0.3077949757777876, 0.13755225125820408, 0.09427065840892254, 0.07753970416923685, 0.0911586560429104, 0.10496701549498305, 0.1493597652522787, 0.14460047466620324, 0.08939820897555159, 0.15855020032294337, 0.08824720783459564, 0.1874871185470012, 0.12152749218887861, 0.143267159921027, 0.15203992385537396, 0.18669098465433046, 0.23417184249527995, 0.21127958782017234, 0.12742826144301123, 0.1297737468755053, 0.16160315263175196, 0.11112985576713279, 0.14370001492000398, 0.13460963093225034, 0.1708961515537193, 0.17907436997179063, 0.1940555410880235, 0.09102429954275008, 0.23956877870425103, 0.17557115714636543, 0.12639038084495452, 0.19965308508084667, 0.13162253154141287, 0.24327701197997217, 0.2097209972599822, 0.15082083281970796, 0.19414267592853118, 0.14966391747997654, 0.15389658390514313, 0.14559053605602634, 0.2342387679363451, 0.13799478960854394, 0.1565842808134133, 0.22618948211593015, 0.18182488608985178, 0.11603436598013486, 0.13017626479268074, 0.18806120951569852, 0.20322274837282397, 0.22068857245387571, 0.1836051978170872, 0.12942007472438197, 0.13904428409953273, 0.15742302451643253, 0.3903339322536223, 0.3651338377066197, 0.46288696327997797, 4.216479784057987, 20.80529474443005, 24.88501471857871, 20.183559848416238, 16.453976131254628, 14.153092215138098, 19.580324811320153, 31.78771157418528, 50.97406764184275, 60.23806664251513, 33.94124184885333, 0.8269614546049027, 0.8268904842195973, 1.5085487163835958, 1.1499390366577333, 16.513841306009603, 49.71354338430589, 46.5091513049218, 42.21610146184122, 29.207315637219338, 23.72095331068962, 18.67547127508348, 20.36551663952489, 24.934373824827134, 25.375662042248635, 17.071080669280022, 5.051754886104215, 0.16227439887100653, 0.2147211918547269, 0.18552982518749853, 0.08020166052325119, 0.13864820132092123, 0.17270879219135932, 0.38104220503760927, 0.24549109801169366, 0.18610943198925067, 0.1918844938758881, 0.2763363412551342, 0.19142913121369579, 0.21594106430007567, 0.23147640809897455, 0.2007844284056656, 0.22016268373737413, 0.15358930603871424, 0.09369004037111037, 0.18467612744819734, 0.18135749584724828, 0.21764436886916239, 0.256721334111306, 0.12950114214852934, 0.16465163098708277, 0.3444763994024646, 0.2619271160614106, 0.08441794798859666, 0.13734291007201518, 0.22139901175133644, 0.31751761212944984, 0.07933326155668305, 0.27534385902747033, 0.11379385757590495, 0.1270877430215478, 0.10957947000861169, 0.2825437065574431, 0.21100373488039742, 0.06922937388862334, 0.14324377891757797, 0.1762657997108275, 0.13449589751901167, 0.12247226246061826, 0.12726066438781639, 0.12402863136582798, 0.24628585294610073, 0.11476224633835017, 0.12397603942982613, 0.10476798585225498, 0.09571889400362008, 0.1473704647392996, 0.16647876600825018, 0.204920414534788, 0.10214148404737634, 0.13297522831107342, 0.33000135193428687, 0.1739707075419926, 0.2364409029964478, 0.21686343416090936, 0.2848147282436971, 0.41510394503993375, 0.1682131584253042, 0.10725728897077423, 0.14425199659120652, 0.2122890618779967, 0.18361417636755975, 0.24176602612339684, 0.22976567247702231, 0.1717940219227345, 0.10157083281345906, 0.2923931457823323, 0.22938310348939514], [0.14214569913043132, 0.051683175692995714, 0.05423967621379322, 0.02967120775382125, 0.018112239495460546, 0.01859963803942646, 0.06133899002546265, 0.0625728550667484, 0.06081625376076949, 0.01152068205673488, 0.09405517319758093, 0.062098278919415134, 0.044511206102587526, 0.07926499546175042, 0.09852034730776664, 0.02812616737379182, 0.08022105020861472, 0.06015478280342876, 0.08789924303850821, 0.03458551814659469, 0.07243427973721298, 0.015453859814442696, 0.09414610783419303, 0.026054560289447828, 0.03223159808605429, 0.04085578692836627, 0.03993745818133316, 0.08321540445209512, 0.0645646415350418, 0.004720642407905431, 0.07474935913999235, 0.0384989902076702, 0.028345793290364168, 0.03895300455511578, 0.03722228169921906, 0.041646730575350024, 0.022680061726620602, 0.0690862610034885, 0.04233481159674064, 0.06789486404628524, 0.028273727399327105, 0.0708073158297808, 0.012616858115389705, 0.03337462808215811, 0.034942495967111284, 0.045073047325375586, 0.03359003285426767, 0.10319144585199895, 0.019749241069920605, 0.04636925277149966, 0.022867776250707048, 0.07650252071119125, 0.10088306205767779, 0.05031968091404246, 0.04240606926501759, 0.03262918239699737, 0.034042419264874155, 0.04766781776843052, 0.06688911317577285, 0.10344345047469101, 0.03768880243202852, 0.08487164823999328, 0.03894430562673558, 0.04122881046045692, 0.02679736680170942, 0.03731238896087293, 0.01956611924294022, 0.0218507734638068, 0.014813146967020248, 0.048827667224911914, 0.03721099722409441, 0.11859706798267942, 0.1752038639519484, 0.06610809419784816, 0.04842433725453673, 0.08527246544197684, 0.14164213421604327, 0.24296196598199107, 1.644740150340142, 9.481705254124059, 12.229077469918037, 7.847412949608219, 1.570149417365751, 1.028997532783016, 0.2559013748841901, 4.201816493465055, 5.902525311516178, 5.379830752649616, 7.813288819405341, 7.934755798309081, 2.058740806195044, 3.3805935277092845, 7.212075273836813, 24.377099160225164, 14.943231132722671, 24.660945400114983, 14.20260625500833, 4.797944686105175, 8.649046863279036, 7.846164165004608, 5.946813283428069, 4.853932597944814, 6.000462972348736, 3.939686210886125, 0.9963189798497385, 0.06615349256824102, 0.07699594262146181, 0.0952593485013612, 0.07915666296837792, 0.06249631905267316, 0.05862822237935278, 0.030366616406207605, 0.055439243498708934, 0.09730705555768744, 0.0316262066799907, 0.021901218438400857, 0.014107013083693963, 0.02694729403893073, 0.011487996915445454, 0.08804910515825595, 0.029294129701391346, 0.02123531183197854, 0.04079933390922604, 0.05397177909711196, 0.03615435130233246, 0.0638408033597854, 0.06051920316812973, 0.0704617565497756, 0.057694479943283146, 0.044557608048161196, 0.17102758159800885, 0.05013259841249355, 0.07573245679058375, 0.025014816182515314, 0.0996655491631358, 0.017088209767074838, 0.05598308931615564, 0.0495962794089029, 0.07564809518836199, 0.0251534455380733, 0.05820859005794891, 0.012933166243226058, 0.038572262687188004, 0.02280539945669232, 0.04995306570743842, 0.12387182848948626, 0.04506367040918239, 0.014286297767783606, 0.0661363092160994, 0.03158574766148964, 0.041592882255152355, 0.019654303623904145, 0.06916202709919984, 0.022504143041348266, 0.03998294848227694, 0.021286047919983828, 0.047867138524569815, 0.025472570954251195, 0.02385152124559447, 0.041507781378083655, 0.03803236988343058, 0.019707950846021696, 0.07435283969126402, 0.05994495515140796, 0.0869806270085035, 0.051816980609850544, 0.054514843504875905, 0.030920815901950966, 0.03206776443778748, 0.07709144314210262, 0.09103323978882644, 0.02775210579256377, 0.055283796597993186, 0.022637130159343925, 0.0648690925370301, 0.08705452384967959, 0.02214382507748181, 0.10507542459714798, 0.04520304478524674, 0.06844439423613011, 0.0428855024097908, 0.0884106373714824, 0.07518188472116187, 0.09831570990143285, 0.10361042699866718, 0.09493040566843364, 0.014813103874574506, 0.03666634318388758, 0.08081100685822387, 0.1545029731407281, 0.036152646756700935, 0.037369757455082676, 0.12553521221683872, 0.07778839163121679, 0.08697861219726263, 0.15177727827141363, 0.05323755276960231, 0.06294614672961255, 0.0358569061744117, 0.04150606534113327, 0.05076539086838884, 0.05791168502201477, 0.02493133366618666, 0.10813829008369677, 0.041450661862449306, 0.02629817433414921, 0.08982358695638758, 0.035291223020683375, 0.0415186713179273, 0.012384086130036703, 0.05825214215644425, 0.11925440206522904, 0.06587098232440411, 0.02771907974214804, 0.06318972821557714, 0.028199196620393666, 0.03845302493221337, 0.03421705283765351, 0.06708414383953618, 0.0582462432794273, 0.017071382645818017, 0.005842071597374255, 0.012177940488101975, 0.07347638147973246, 0.06022843449646908, 0.052521942378652674, 0.062366394371154814, 0.057889433998254046, 0.12760368025591298, 0.07316434620729378, 0.04216559809602557, 0.08315210260691182, 0.08697255244178158, 0.03521212827294104, 0.06477690151622219, 0.04790361963152405, 0.06467782336497499, 0.02325195402297522, 0.07133623059358328, 0.01627953501508361, 0.15637055760429752, 0.06060966283022877, 0.07374743104822214, 0.03781790739946789, 0.04575088958165819, 0.02834355822884508, 0.06499972584987841, 0.03548230833163665, 0.06961580395938889, 0.11256565009394001, 0.14979389195720996, 0.13632499372526524, 0.10686868321030371, 0.26984111075439765, 2.1016598709167975, 15.405738392183858, 19.473275484577304, 9.273731381662431, 2.135429026619081, 3.5985677280733666, 2.3924594925295923, 4.0396269771360584, 11.93705112703385, 12.766070538951507, 27.840357865056685, 21.76015457799358, 5.5617439073901025, 5.916002085131984, 20.45253049942755, 45.56493482282085, 31.671468211758523, 36.99767035822715, 23.570891272637155, 10.406041203006621, 10.658333936045247, 9.064917141391385, 6.366220068547034, 7.32332791051557, 11.577879690354871, 6.013883852189587, 2.8230344912698193, 0.1403679308151045, 0.067572241438733, 0.03241143722627913, 0.09137663870088517, 0.019958871454300902, 0.023619961594381643, 0.03317738342429361, 0.02576776569889438, 0.06922210371422191, 0.044869099398173636, 0.015500447536338002, 0.013432286890043367, 0.15775158430539793, 0.021856277805542754, 0.0742849872838105, 0.03589418018236756, 0.08305991924698315, 0.13148627514320035, 0.03700292008298059, 0.0034136231519251822, 0.02746844833206025, 0.025791864909772432, 0.06687900081517235, 0.04589649991342618, 0.01585439260628435, 0.009613547346464569, 0.11193414083531789, 0.04370094171815342, 0.06908835242352179, 0.04918511618950194, 0.04613551168492244, 0.033304458258733634, 0.03239738717374783, 0.020252528277436094, 0.049395518407465956, 0.04788569700453551, 0.06478263951477505, 0.054922704885323206, 0.06319929282331178, 0.023793572439782085, 0.07575486486236896, 0.04900113251360674, 0.08866395966540422, 0.09791097032927698, 0.07447033459621091, 0.022357423797309883, 0.058905714747285655, 0.027003509570814432, 0.09220828842972556, 0.07144958862373907, 0.01985146784253659, 0.05631494328319546, 0.05092362249870935, 0.055673451898919965, 0.02455450650755196, 0.08499012373748326, 0.03156034227070068, 0.08717573428105924, 0.11679162091064839, 0.09623267087003878, 0.024226952208987167, 0.04633616926448961, 0.08455830295720408, 0.05482947581537789, 0.11632859736921326, 0.04338519091928198, 0.04287188519693671, 0.03203084857593621, 0.03791225878822227, 0.05823072616852099, 0.07378181307426385, 0.30697397467109466, 0.3702776891089255, 0.25276608344527984, 0.21166137539811675, 0.3037832184664665, 0.14283847244035813, 0.19954034758190956, 0.37100746446559507, 0.25030753875692047, 0.21157132942349682, 0.15291052149428477, 0.18064088188111785, 0.2623917330657282, 0.2674755538182874, 0.18052814438218073, 0.14809739024889085, 0.19250566860841167, 0.14789293670365888, 0.16314101285271107, 0.348633682775882, 0.1858455606646115, 0.28438749633008437, 0.14682579154689468, 0.16242044587289134, 0.16467829084684774, 0.18719298674935297, 0.1712932915336663, 0.21424800998741583, 0.2069498580549994, 0.20358926015755824, 0.17329500267101874, 0.14397995876929454, 0.14125734357343567, 0.14256500969490699, 0.13761200611629795, 0.2792691709774156, 0.14331884021239896, 0.19926769688965815, 0.22297571263005658, 0.22789917585830535, 0.11432929174794305, 0.14752480081252514, 0.08925449088095658, 0.16867861812633855, 0.13917461097721132, 0.1318327154243185, 0.1396741922343931, 0.24316779848548675, 0.13230295551400031, 0.23646800718720884, 0.2104988676165381, 0.2586209257283519, 0.31735324030441625, 0.2145676678347011, 0.15622159946830044, 0.17324889949973554, 0.24787946904618896, 0.12089214482975584, 0.17747715325845828, 0.20854874484000668, 0.13700414599189836, 0.12392141736082493, 0.20379155333484375, 0.17573448709182202, 0.24977178282795415, 0.12202595495769095, 0.2023079168171652, 0.17868297565127575, 0.1160967102154128, 0.14470556660765602, 0.14593080166847477, 0.25700058848146473, 0.2524115226321644, 0.13614697021342095, 0.3963426662789237, 0.29827602688343297, 0.28358721024086403, 0.397614739955433, 2.1853889909482773, 16.69911446109895, 29.330107396648778, 21.558391778699814, 15.655004036042, 22.9728376865387, 18.509845272187267, 29.70666866148672, 39.1468507243741, 54.23469082001717, 60.36825403090447, 35.20096594287504, 7.553517597336923, 8.342184155218064, 23.875749649540072, 68.00010773443407, 52.401218106669766, 55.99861206546907, 40.74916247398623, 31.248785757249404, 39.14829415659751, 40.256104853845414, 23.383139179598903, 22.75780550895199, 27.20785802410495, 11.465940148599687, 1.7136049583073587, 0.10031778110010971, 0.2275250951248792, 0.29747390218319436, 0.14307845714351825, 0.2854463217719909, 0.09410837034304297, 0.12479729334553405, 0.2441347240199966, 0.23155988103920416, 0.2106818860216487, 0.1490542953533511, 0.11783431254086957, 0.273247781179605, 0.07761416025459766, 0.25499153822179765, 0.14732563327397072, 0.14676004588123293, 0.28073616806537877, 0.17874843020352627, 0.10383960220121569, 0.29732558756105365, 0.08400569309390361, 0.1608267071987352, 0.1681541849768931, 0.25627176307382127, 0.28281882405281067, 0.24671067934363122, 0.2257520612329245, 0.10832159960221861, 0.15777681924162373, 0.12929716357781043, 0.1702998900004933, 0.15880003691680972, 0.11901401133546907, 0.17015172859593747, 0.1421946827923098, 0.20072308008468923, 0.20482569542382995, 0.1585735813263924, 0.15173967867608995, 0.2770050747259971, 0.18147024866794387, 0.24793144045097215, 0.23980387576645423, 0.18357400271681049, 0.13708666898310184, 0.22849307786072456, 0.10633282768990725, 0.16273566041021578, 0.2286474139339501, 0.11102019028077204, 0.1405795089780323, 0.13713398257330542, 0.18182470222874997, 0.12908491125750926, 0.2342852847951074, 0.16001045583717285, 0.23373731742462805, 0.20280475547957807, 0.2758965454995632, 0.15245826914906502, 0.08962459561805572, 0.1922520475401994, 0.15177928542177524, 0.15459588428418483, 0.20968086957450838, 0.13936524429628927, 0.12371403735972221, 0.18270247045063204, 0.12942051905537807, 0.2066694085876788], [0.0666431759694411, 0.06884723391023374, 0.08611999617348756, 0.06212032692987592, 0.14415615899187906, 0.02286461422279958, 0.09702147330127417, 0.16321756035810517, 0.009853714953116592, 0.05004515330637655, 0.13180631603444778, 0.07391343464053447, 0.02450621998568456, 0.07176880214002825, 0.037095379234562, 0.08839244278328073, 0.10712910713928361, 0.06584332655033757, 0.0469840842960102, 0.03909458143396243, 0.06113168280271273, 0.05288331371341502, 0.08791811944496247, 0.04607857986082954, 0.018529362878912402, 0.05131007555211264, 0.040330733247702165, 0.044878882340966694, 0.02701262410189356, 0.02189978010832302, 0.05977573398981364, 0.06940450158811386, 0.03258807028854086, 0.017280765966842734, 0.024300914167636828, 0.02165345794280931, 0.016149865057800087, 0.024600368361139012, 0.05473014102467606, 0.03384744222726553, 0.0017120554478042911, 0.008309798807116046, 0.14181462657307425, 0.05205793058379524, 0.03075473378562639, 0.03526968062825261, 0.07889964813066107, 0.030366919010937698, 0.08927912826860145, 0.04367467256322984, 0.04468542981832739, 0.06040827746713354, 0.06328494911412559, 0.013330289943804665, 0.0198164806070347, 0.006615022233041425, 0.047239126457322034, 0.0177632347350159, 0.05188527351786053, 0.05281659128564981, 0.11558992007086355, 0.05348517919980711, 0.07813192077822263, 0.1075766250611313, 0.08523687299701475, 0.09890754346645649, 0.04252150339344817, 0.03415092795846924, 0.06646247881074106, 0.03310824781956692, 0.07661730366488619, 0.019836757039170594, 0.05786812143220056, 0.0571162827433117, 0.04680011211143387, 0.04683540578210547, 0.17609318477972863, 0.0863879430858839, 0.5904283759094054, 2.06089565830846, 12.616643924866954, 11.101656882993638, 3.652160297478399, 0.5777388342445897, 2.623777351071758, 3.402291834354401, 2.007361924456012, 8.3317937966316, 1.7616930940458853, 12.901416824709985, 9.985172844702198, 11.389496095718878, 18.642382160309825, 16.969269667902303, 18.576531448671897, 29.416385812144128, 3.4525116557075135, 0.7923551180189656, 8.329691406219236, 3.6698744566209855, 2.3221058999338458, 2.3016102900428157, 1.3462597924855448, 0.7456803838572195, 0.015274922742748694, 0.07132398850855327, 0.08506601240726248, 0.045557820102981025, 0.06620430718025853, 0.13636939618135654, 0.03996669975740295, 0.04671223416563965, 0.059561087644749114, 0.07271184105305903, 0.06407979980952318, 0.055771400070478844, 0.021241017271794622, 0.05928104420402839, 0.04466692879495602, 0.010698135367654746, 0.04991291503932688, 0.10122897373812814, 0.014872126161090791, 0.05437540018089837, 0.03647246931288992, 0.026495972490538994, 0.008682651884643542, 0.07786315415174731, 0.02761708471112915, 0.043219459288182764, 0.0647708724042581, 0.04744676692831901, 0.04818367839400326, 0.05301832521875059, 0.05238121585740198, 0.04334185715584506, 0.10807647444908658, 0.02780252012364086, 0.06461517269452734, 0.0751099797085889, 0.028007469710803805, 0.032514613947921225, 0.028069972909326037, 0.04539879174121926, 0.015605133451190929, 0.05738878787885751, 0.03023628378286958, 0.019062650089542714, 0.0533636010462238, 0.01855315756984055, 0.07692711728234446, 0.027627388593710722, 0.08407307818772332, 0.04554665820192426, 0.022097375251412876, 0.03258447350573636, 0.06090721138001931, 0.024015239980672638, 0.06232881775846886, 0.014108917769795705, 0.02748472387001159, 0.08794201372732079, 0.06919555110676635, 0.07076665188275999, 0.05126823566012806, 0.1028970612453357, 0.03686136235633204, 0.08761356119066478, 0.1074323553832308, 0.049826251342892654, 0.0363527144485664, 0.007473913569664283, 0.013252660339217515, 0.084937171740157, 0.036277645492866155, 0.0021085478440527957, 0.1009293107856666, 0.04961655392581898, 0.13997960084628674, 0.09357669766271308, 0.15829906137960573, 0.18028128020946058, 0.09130469538391599, 0.10412310069847493, 0.018881148538522182, 0.021266344138571334, 0.17895095320718904, 0.05943401664074871, 0.02594539276023786, 0.13705640851009276, 0.11386659762431538, 0.05636146397239739, 0.1592176161225765, 0.2589937347558237, 0.06262096921883284, 0.1289062135882916, 0.06614050737792446, 0.04159279415504106, 0.056786654261691924, 0.05558141792613653, 0.024379687158450968, 0.039406482641014366, 0.0631365310701151, 0.03728021326805315, 0.025505918761595123, 0.026135317447985855, 0.018117473791203192, 0.09583819687606827, 0.09210613060502276, 0.02702273454727425, 0.03725793160077545, 0.04560566995473159, 0.036219901615573515, 0.03409829005719193, 0.07807484722786373, 0.0714877704458852, 0.10570557788014413, 0.023347192158501957, 0.0715783296994144, 0.016451709445626024, 0.059382183131791895, 0.026936896310578433, 0.04524840485124339, 0.07408762005187812, 0.11327108683725519, 0.10326077680914633, 0.026630089588222966, 0.026530354516580704, 0.0383719919820226, 0.0863988981432011, 0.03574150268949809, 0.02882496405002331, 0.0532073574140668, 0.03510016835324707, 0.004179203064150868, 0.05256138441543426, 0.11293472827322061, 0.12213232626597728, 0.056072024463285366, 0.04366278287864501, 0.08900421761697339, 0.05949505469611576, 0.04018231903413131, 0.026146383588052085, 0.07716137930871018, 0.02968126457304724, 0.03705604828052944, 0.010044552243104386, 0.07796397132258262, 0.016876227492766998, 0.06580958803815228, 0.08143149977249485, 0.03553961553881246, 0.15105516379398687, 0.34637262023264365, 5.419843831369954, 21.350490470086378, 15.403173162091164, 4.373509422425301, 4.571892119223072, 2.02501050647228, 2.920926554549125, 12.431009911721754, 21.6659745477861, 17.919430501999393, 28.467276173253214, 32.79952422265084, 35.20060900718936, 41.73827440507951, 30.19445461611594, 33.818503041421216, 41.35148556001725, 16.360075569921925, 3.6741598911823767, 10.817847905620452, 8.918867688025198, 5.939925601405482, 10.069545968886345, 8.670301206650274, 4.046918663286394, 0.0686647977319456, 0.18725148522325102, 0.056939136402140704, 0.08951904402384836, 0.06159984296368015, 0.03316855426096628, 0.026662228891866344, 0.014423385371393977, 0.048019467447433746, 0.06972584482883254, 0.11250951883172798, 0.059694103491041935, 0.040501701089763836, 0.039381856744688366, 0.04686485803235443, 0.05974626258736657, 0.03263770895559461, 0.02912329783993623, 0.014260930681390869, 0.04967891731329503, 0.010728521287561426, 0.03414669149224797, 0.01953661911219599, 0.08764573688348455, 0.025806583374017672, 0.05684966882390361, 0.07424472936338956, 0.04146138326294961, 0.05956238233334115, 0.08471753433226578, 0.012889158322415765, 0.06853451681954247, 0.09840941777633083, 0.06873806638102378, 0.008330770464043223, 0.020534841253632502, 0.03519009175379911, 0.02175776655935953, 0.011573800678184677, 0.03965596683443554, 0.011667791048004743, 0.0963277806858382, 0.04725961547885691, 0.0710928827644356, 0.053867591139409816, 0.010386289701977325, 0.05561797947232282, 0.02887743915761671, 0.08573013402882122, 0.040290617053547216, 0.01473181141209939, 0.00972749047627252, 0.05861781507490143, 0.04708321607341209, 0.09121765247395924, 0.031530602737480116, 0.028948256325337197, 0.031230173697094285, 0.08208502639806078, 0.08909703682987921, 0.05975262494757772, 0.07212825059410065, 0.06496415638755407, 0.12406191788613798, 0.1012346044843716, 0.06815402393019007, 0.09579875866972631, 0.028898575523447607, 0.04819576343100879, 0.08137709220811244, 0.05479945282962534, 0.05709314305755881, 0.4600172285591403, 0.2778824292604001, 0.19792852923274043, 0.19838255890194448, 0.2832981193017575, 0.24562481099799757, 0.2800169340785473, 0.3525942347703442, 0.2979996836473865, 0.24481216024967933, 0.2525223449112908, 0.21833960898220542, 0.12231007398616885, 0.30846897993356953, 0.31800389410026614, 0.15434603236856, 0.2499814764145882, 0.3366861738745244, 0.4775237165872128, 0.2438353521809463, 0.23679826769136617, 0.18437074947982066, 0.17856827696725247, 0.14415042865420544, 0.2035715328829904, 0.08429875236845787, 0.19888002575645525, 0.13654892122553242, 0.1448539118733137, 0.22886671426315464, 0.18310766967554248, 0.13466860438066144, 0.23355950841740256, 0.09073784394610314, 0.0980143309120209, 0.21900161620109312, 0.2100583977035938, 0.15058584300981415, 0.15839883667086402, 0.10067011259736554, 0.2271155138770419, 0.06992117426688634, 0.20318478105529664, 0.15734439325188437, 0.142960004628666, 0.12582087108204443, 0.2075810072522971, 0.20611902037935875, 0.23733776212940294, 0.16435274944430397, 0.19816400933890574, 0.11005167128337968, 0.15446934188085218, 0.13933789495739246, 0.19942917290233797, 0.21003164591327791, 0.14833991836395957, 0.193231996569422, 0.11025461563540083, 0.1810887522034107, 0.19945594001441233, 0.16227210060723368, 0.21231101795790658, 0.22096747442358927, 0.1692046140951495, 0.15337496995925903, 0.28536085700315816, 0.13884994291490124, 0.1295377151860345, 0.08636666116334739, 0.14537961672871344, 0.1764407282274577, 0.17546372097586432, 0.1594509052172784, 0.2082332545110295, 0.24579053113777793, 0.24482205810566104, 0.352767983511571, 0.4660745632023581, 4.158472341875877, 24.87041957916752, 24.367507003968765, 16.779432835117465, 18.9797628694965, 20.664020776748657, 14.325871640636077, 31.42029727658918, 49.83825122156451, 53.979579864009736, 56.877776038262155, 55.13152114806637, 57.90395044511365, 68.01649539701401, 54.883211581937736, 53.335899306881814, 52.676058584643954, 31.77485992831569, 17.8714128463499, 39.99145469357891, 29.303564717692716, 18.01667586449654, 26.93713015125644, 18.662492152183287, 4.3560725258242705, 0.1523663079546344, 0.2970029113273467, 0.2384229716394217, 0.24544617461581386, 0.16837587550042138, 0.33692743028363875, 0.1259181029613941, 0.1132780122720907, 0.15678435233571839, 0.13688521850253307, 0.25083149693185286, 0.20523976594690355, 0.15547262594824837, 0.1203594609133659, 0.15078239052766754, 0.21054615056322468, 0.12534081740605255, 0.19564361071153996, 0.08263490132747159, 0.12083018363844003, 0.09367053577255818, 0.13529768514056362, 0.26489031350901054, 0.14140460099424088, 0.1516718032859987, 0.13889151084567272, 0.20720465889861509, 0.1997834885673177, 0.13043086645343613, 0.2781816019165901, 0.16198480231387002, 0.09882320484687244, 0.23192243981024913, 0.10705507240228115, 0.2019993825665405, 0.11321795863970635, 0.09728208875223514, 0.1348789568029104, 0.1163589574336525, 0.13885738928952526, 0.15390743171015095, 0.19741489792302733, 0.0733013533716721, 0.14421471875281106, 0.19361948384152305, 0.08720607136286075, 0.09972676724916506, 0.18843095419147324, 0.2152517230640496, 0.15318200773289128, 0.09293219555289516, 0.10966098942463437, 0.16528679448510372, 0.06694928172134584, 0.264463908970356, 0.26869979296480456, 0.28958426908619944, 0.32979928858337865, 0.33346259846322, 0.23796892664845914, 0.30346703865835745, 0.3447218539734041, 0.11889836270241969, 0.23069257757836775, 0.23797605126615495, 0.12525027347428183, 0.2461189223874, 0.13961929437373916, 0.1052915916267422, 0.284302736362142, 0.16366595162018654, 0.43210901319980627], [0.05283115844753, 0.10410328966475303, 0.025653940355104786, 0.05006323681182919, 0.02355098686811905, 0.04605705279015726, 0.051067896007049474, 0.12440814366263729, 0.03605126268080166, 0.035603599202248364, 0.06173722168070175, 0.03483421709989348, 0.027316219000626477, 0.028583749775744738, 0.09855534220414777, 0.05189383838085398, 0.16375143171077775, 0.1203102780686271, 0.1226304979213784, 0.06971571714647355, 0.038915305368361935, 0.004483042153409653, 0.09038425606465147, 0.09957080706954004, 0.011129221661136517, 0.0342583219941345, 0.0701894122926939, 0.0470128087627311, 0.05871632249064504, 0.06892130695163243, 0.03131613259263818, 0.08116079494357109, 0.06841735899328225, 0.03545660991221666, 0.03462538919261387, 0.055126445968785596, 0.07183096251420437, 0.008406295242058414, 0.007616945057957163, 0.04472407895410734, 0.056695018654629115, 0.03183241073612965, 0.05324126063515583, 0.03996279653942874, 0.11524794608234398, 0.02358313000220205, 0.016468701275786566, 0.02291082656161199, 0.05008045080748778, 0.1387796160434523, 0.02231242953829708, 0.031389196313196616, 0.09880907818554871, 0.053604229263240294, 0.007985050784378884, 0.06410773520568205, 0.010520876028514918, 0.0017665913319140074, 0.02279078441431686, 0.05837620626534185, 0.040894577790412216, 0.11898671562272696, 0.056121295408135465, 0.047034190276697765, 0.04728151027173285, 0.1696596090351382, 0.08966204965667379, 0.03115911329645784, 0.019608413042019934, 0.05956922349850497, 0.07003552821134368, 0.06098038809854658, 0.03609895931496736, 0.04400391800088748, 0.01806571497581899, 0.020401555361346375, 0.09495703488468163, 0.033216867595911026, 0.053477361272539825, 1.0363111596915031, 2.998492160151082, 8.536112020092627, 5.27049615498512, 1.3007661820419374, 3.1491592238026285, 3.2862512094359246, 7.401587530489891, 2.4038267664371, 7.031990924189168, 9.432980591251004, 12.048173835200648, 12.948567636551397, 13.918944366516607, 12.17533903737222, 29.211049733623383, 23.468619392764186, 8.330010098795738, 7.264814482581231, 2.8911513522748025, 3.5436013485154803, 2.61367749302618, 2.9502077833298714, 2.322631987833208, 0.6620648899866689, 0.08481936273916114, 0.10677289923713093, 0.07817732680949473, 0.04032987139878735, 0.06565977188367998, 0.037328488298601685, 0.07314706326372201, 0.05094226141790709, 0.049875667844448364, 0.08150663001522904, 0.07279424913107388, 0.051645679519541805, 0.04227192726947608, 0.06880153676555043, 0.05642641673705751, 0.022275864161671172, 0.04888129721005117, 0.11067260086776749, 0.049919844304601994, 0.06500928662717342, 0.023388681565261176, 0.0648583519843317, 0.08432220998069934, 0.039829573849396366, 0.009742891716380275, 0.03549473427776848, 0.024168290941405202, 0.08698169187071823, 0.03027231098272868, 0.01734696745481943, 0.024542034596144676, 0.08020965082030143, 0.03133249623070081, 0.027207311941310767, 0.08718929403731901, 0.0933358779237155, 0.004538502131078032, 0.056601931310949795, 0.05029279888877946, 0.015748068220883368, 0.04959540223822959, 0.024286971367414922, 0.003931492843079351, 0.11297556075958476, 0.055454530783237956, 0.04529780603104061, 0.028712174840151306, 0.017264296991690513, 0.03682931689845939, 0.08160816730871316, 0.03737912671039662, 0.03585342430479584, 0.01622247295604358, 0.04904334778867422, 0.09246631450350247, 0.052026402235271475, 0.06951664153847002, 0.07810567460593679, 0.027268166135575984, 0.08178176283235512, 0.08160070561233067, 0.037616200279444456, 0.05555475040549233, 0.0589309228704341, 0.010434914260141311, 0.022353537816313968, 0.017680056738637148, 0.10613819539186456, 0.0724306331586934, 0.04373114473456818, 0.05628384011346967, 0.03392546062147425, 0.18523373220476413, 0.11153747582988394, 0.12842419106633435, 0.11262047134580151, 0.15038578680926754, 0.09108094408387139, 0.04126079463129563, 0.02665000595903445, 0.1867921848691279, 0.025112959706494888, 0.038305710054813855, 0.07971746231158895, 0.12304816139681686, 0.011863346481996198, 0.03743589765602543, 0.10425158896513524, 0.22464066683765382, 0.047034745690442865, 0.09900588617329636, 0.10024426730289575, 0.02879958738753152, 0.061268973419623035, 0.026568714454169237, 0.02699353127560068, 0.0756003296062831, 0.05772916840449457, 0.07122316367683873, 0.06572087505652059, 0.12007839857570587, 0.05683486034432727, 0.025719797103515556, 0.06748827820223186, 0.030621340641030864, 0.023667958918057626, 0.12648254122224548, 0.026692115897012335, 0.08976578562250061, 0.036768661887054487, 0.025537113861871824, 0.04431336772658172, 0.00694469620113171, 0.09489325040410604, 0.0577776043135072, 0.028421929023498972, 0.025251851447166938, 0.029629245287768786, 0.027154942170806953, 0.0527631834660086, 0.026580006590173132, 0.14860432595014572, 0.012078482165722357, 0.09601790578134599, 0.06140264044065149, 0.04303182903376799, 0.01625003296911957, 0.028353632285049366, 0.03155554656029469, 0.030706973949206934, 0.03679977271765952, 0.0606751173824793, 0.025208793475382754, 0.06519498634001901, 0.020760793141239596, 0.059430994423887426, 0.15897776931524277, 0.07823511282162321, 0.08926865584667652, 0.04351399328199126, 0.045391502414619735, 0.027549477451811397, 0.05305418579448616, 0.03118583252803693, 0.09664675671487086, 0.01868725934576604, 0.013174194741182992, 0.015392255811621586, 0.018754901079040383, 0.018774731264960383, 0.09307776758026692, 1.1144295743396206, 7.479261246419723, 17.626445139608077, 9.570354742388572, 6.4369129461626855, 2.5094167263277116, 4.353103781900098, 8.07742024621656, 9.699885133774051, 22.457395099824478, 29.155142230372277, 31.109531810206754, 33.18137676485124, 30.93643761450245, 30.315400900379306, 35.85893177217053, 29.84105298596044, 11.992452644532728, 9.679470177619688, 9.354100746493186, 3.4619819733404347, 3.949952279367755, 5.043255109940806, 3.1158288832633727, 0.9398231210727847, 0.31030284120671214, 0.0822746484810787, 0.06314461329771627, 0.09140982562976499, 0.04576053462862488, 0.08225306778425172, 0.06517669982126643, 0.04910170453630629, 0.025166785044054833, 0.04040568345977415, 0.0100729396311386, 0.11056899513688781, 0.07913250055524611, 0.05721868188571065, 0.04713591143128373, 0.0327884559068949, 0.029447019783659812, 0.08788663323127455, 0.04470362057608943, 0.03326353384181857, 0.03689721527118837, 0.061761939507578655, 0.014164101955811343, 0.025264489982697754, 0.033255309887951424, 0.04700528960975428, 0.06437606899248016, 0.06489723094648893, 0.07061436892517152, 0.020942700718859994, 0.012111882641611081, 0.0510216357877418, 0.018315101493029826, 0.030422615518252698, 0.08132669128357403, 0.020643202475302165, 0.03202539786035496, 0.07589247723620746, 0.04843594348658958, 0.05303318732448163, 0.024802876043043313, 0.029776021988401492, 0.02629261062059912, 0.026678592529928973, 0.060728808654652494, 0.04140411819060964, 0.12642256419865355, 0.04765137369113584, 0.024033963169542052, 0.04722029984658284, 0.0771769155718146, 0.010765029207593011, 0.07337134316443436, 0.02777777356846679, 0.04039868141614622, 0.04561864365372927, 0.09907648117551882, 0.0496235904434035, 0.06344978825279302, 0.06143224590848531, 0.06847237942800408, 0.04533794520783328, 0.05167210955292948, 0.0750013790844429, 0.04000119286619368, 0.05973775901140706, 0.049345883570851824, 0.022252301212340113, 0.0702900302806689, 0.05137949843981093, 0.026347475922516277, 0.06236794186876186, 0.41354823497033893, 0.3047866097861721, 0.21634237179833077, 0.29645004099415195, 0.24332305386422143, 0.26531779057075905, 0.16388401088695373, 0.26565336772511083, 0.33425065778916885, 0.16065933230903842, 0.1524202711880207, 0.1837678689269289, 0.2983895304702944, 0.13494575966990766, 0.17197212204337123, 0.17623751574466306, 0.45710790241437577, 0.15046890734905197, 0.3538526720818012, 0.23964650598504852, 0.17311311807603608, 0.18103662758104264, 0.19347841641114605, 0.2438365013128327, 0.14597955550397598, 0.15781250361713672, 0.2749953809524736, 0.0958497801254834, 0.13344473295634793, 0.14903898891662398, 0.16454845426544068, 0.16107744777635222, 0.20683460778767065, 0.055110959501396266, 0.17695123389843972, 0.10132249009104506, 0.16880022692343882, 0.09559552320429394, 0.17949424744133027, 0.13687191921616756, 0.15336111908958805, 0.2106434437296083, 0.15010139965001615, 0.26262805586861027, 0.1981172320102492, 0.11156485581229772, 0.1263171198567556, 0.16506829088734043, 0.16226923543839686, 0.34540140460575786, 0.13805501944115087, 0.10029374126104579, 0.2077560583429952, 0.12824133353968784, 0.14311314560472965, 0.13027050892912573, 0.13813849238138046, 0.09053185056414335, 0.17602812859319872, 0.1934326809620665, 0.1441582274292746, 0.21370321422094302, 0.10970785102296261, 0.12292047752247703, 0.24883104217869623, 0.2813593652700224, 0.1788728428824294, 0.15913152316164586, 0.13942981018654763, 0.07182220612922985, 0.0923915290003342, 0.17276761242218558, 0.28890358464371774, 0.09063370195367644, 0.110022590585774, 0.14935238016468866, 0.21600377625755726, 0.10939711809999521, 0.6240742220993966, 1.4329279935167683, 6.903459756605088, 24.511967897415165, 17.1728132232543, 16.455015559350294, 26.362104800439653, 22.65502372095662, 22.555077806595836, 23.195251764789706, 49.93689490902809, 55.69936660028274, 63.093108900131725, 61.99597097212269, 58.479742619299124, 62.09927835772115, 49.15474291770689, 45.17245461863857, 27.832834759066184, 39.55893885704779, 31.893823454456946, 20.37270438286566, 19.09397836654417, 16.385423887160517, 7.614624692547706, 0.6737267706663378, 0.3452231819110532, 0.15982437308036512, 0.2564462012941799, 0.14457329386664977, 0.15961395937108225, 0.23640760881525857, 0.19822039341013278, 0.09065981789101517, 0.18268871151151198, 0.19477598549377537, 0.10139130776928318, 0.17606569754500545, 0.1966686976412612, 0.18016157131041252, 0.14373412115439294, 0.0914302112294301, 0.15336156342058413, 0.3121880610142985, 0.16855992046335053, 0.12155631241659004, 0.11868683816564661, 0.13175322614129514, 0.2408400709710775, 0.1314838696271181, 0.08376274363047655, 0.1528348013638489, 0.14397193016784807, 0.2092581422578904, 0.2591357981005023, 0.10628227354778398, 0.1407168685428558, 0.1810462343236131, 0.14125355909908974, 0.13813329830525384, 0.19131172057842055, 0.19178974412141309, 0.13665022869263926, 0.16092485838359402, 0.18094854279150888, 0.1770017344144083, 0.13043002375671942, 0.23979691968810177, 0.19032792578781807, 0.1919097134903554, 0.1377514187967585, 0.2462394433396478, 0.1861667813312623, 0.08289580023096454, 0.14414137349494044, 0.17573591201536118, 0.16478014989726006, 0.15235533757555872, 0.10197813878016126, 0.22457869032457953, 0.16401138066524462, 0.2286529450887634, 0.15686879054673258, 0.1856844676958938, 0.14377055629607172, 0.2249058251900058, 0.12730241617968968, 0.16738651891148862, 0.2526744593295359, 0.19067877873538003, 0.14332150619837547, 0.08904444489387736, 0.12861054961479482, 0.2352961378111955, 0.16766445561041757, 0.19478908559728056, 0.13100089715613475, 0.16431266772410563], [0.10573114223417737, 0.043493481277818644, 0.050351102010256825, 0.05122161154905635, 0.003175436361362377, 0.1129082216310405, 0.09974639442178512, 0.008543244949842413, 0.07773368529254392, 0.03094920903564461, 0.05297126443756204, 0.04733532028753431, 0.06732461883896781, 0.0031924925907890526, 0.02224100716111641, 0.12089522450321144, 0.04431888739007615, 0.00920192638952886, 0.03407374460009798, 0.04523258130516737, 0.01776162020471548, 0.06075813066995433, 0.03866535769174657, 0.04831424658937801, 0.04772294545546175, 0.009452094316422459, 0.052884236849363775, 0.07709299830058891, 0.07460783971774002, 0.018054641174873518, 0.023443882030645208, 0.07220865152175389, 0.041939372331985546, 0.02573493691611915, 0.05044270697380266, 0.013079215160330698, 0.06754679965876764, 0.10355848623740097, 0.04487169260579733, 0.06834461894487182, 0.041792084267663385, 0.03530914947811154, 0.10098795481627026, 0.03483535091002141, 0.04905470121171206, 0.06890363330321927, 0.009845692097329566, 0.025935699832775903, 0.02198119418725612, 0.06007820465451768, 0.008704176082486107, 0.039570145834718025, 0.05104480611701166, 0.045346651797092734, 0.043794312514364726, 0.04381341491675666, 0.029160642711025093, 0.031038136521895087, 0.07190642983562524, 0.050365914320272785, 0.04793931932879552, 0.040291023080147086, 0.03769787674349162, 0.011855653044016612, 0.04110838909963927, 0.07688633076125577, 0.038569416670549306, 0.06836450658738613, 0.0745125690234765, 0.02849545814247141, 0.023657497987451575, 0.023312679897513122, 0.08253724043888432, 0.008830407262599517, 0.05449158890593437, 0.06204146200851087, 0.07368249743576012, 0.026849184988907752, 0.010309689528038426, 0.0509764634132866, 0.25017070013188547, 3.3261833892714594, 10.852087255447142, 2.5708920340384207, 1.204429338535955, 2.716540179906353, 5.014483544134325, 9.22713460460786, 6.016500563390794, 5.941238124524394, 11.319526895400017, 10.859550545292517, 7.646946003360133, 8.429547106066059, 15.932648028096846, 7.880599143043642, 1.6031722195686835, 4.702968905048986, 1.8522032566608924, 5.378667279597252, 4.403465544023822, 2.08210464927458, 0.5691265350868625, 0.09310236666351558, 0.04555040820231361, 0.02889167498646965, 0.03241342522444264, 0.12176324808669668, 0.12728363936466555, 0.018423751912890904, 0.06743775470362556, 0.05381874920379731, 0.0418595957659906, 0.05208760499954224, 0.026033523515047088, 0.038375975639228864, 0.10362980136227223, 0.04545209996943032, 0.048268825236347415, 0.03744675312191248, 0.06346927752958671, 0.01901729959964512, 0.008064687060522697, 0.04637763377339129, 0.01785584518896236, 0.07996690053973468, 0.03654463096491752, 0.03478524109889423, 0.09503983366753786, 0.03871583522507741, 0.006498683642055239, 0.027934616664424542, 0.013562432779449851, 0.039936944902423895, 0.07334917257990568, 0.0914831325832394, 0.012772540588142171, 0.10620931133387551, 0.026259569248424906, 0.1148977902747931, 0.04781954148183427, 0.035712173013317014, 0.04372107450880351, 0.00442868582115719, 0.06325111867138936, 0.031397906732895685, 0.025169996867677378, 0.070625837261398, 0.06289687195432282, 0.04515286602620636, 0.04376887073439937, 0.037180721429326845, 0.07702913721122089, 0.03480337823050157, 0.032088040869923375, 0.05077101012331344, 0.029758660520817486, 0.02661275493371631, 0.02644129871060291, 0.041041180206042145, 0.07818934672902669, 0.011915638686097678, 0.15912715646047748, 0.04331791307777167, 0.04448286851026839, 0.07752166279862005, 0.018986638845695604, 0.04816025908615801, 0.030396455530858332, 0.03029290342613334, 0.014359205397927474, 0.05300542429810571, 0.021466126462685007, 0.030662910487022133, 0.1354121539982096, 0.05658880439436725, 0.05291113036594564, 0.023082434087090438, 0.1430733856414595, 0.10535431890598229, 0.04100232039608302, 0.057715194960755695, 0.014814763412540479, 0.08957786425467461, 0.027113623218610886, 0.01172347223356126, 0.03311464848417429, 0.04287178560550656, 0.019132693508459676, 0.01226980975198169, 0.03471393746534183, 0.22109109037105115, 0.10587109883706416, 0.11275982273922813, 0.09339097496722976, 0.08951950367660293, 0.06393806588265204, 0.07526551853985557, 0.014847770310758103, 0.009717225855697068, 0.02257153579604722, 0.020795481602451014, 0.029601987879422885, 0.02288796841317127, 0.06355498361611558, 0.03860555303793761, 0.02503569782411139, 0.06895419510622179, 0.011255437519491441, 0.04258584328776887, 0.03666447775979196, 0.056102499440913244, 0.05394339936995699, 0.06414624644563564, 0.0061274336035093, 0.018875125172217528, 0.020784064977159424, 0.04667735035200754, 0.07252510712151566, 0.08534518250774953, 0.04893930921811731, 0.018781164488304528, 0.058611521662603465, 0.06031916611978124, 0.04507626489465756, 0.030624696106139212, 0.03023025084046587, 0.033971265018466985, 0.13931820649773846, 0.009871260281802427, 0.038203540738792195, 0.029701600376997265, 0.03695727656445196, 0.046206056891429814, 0.03574201213796774, 0.06075714624697163, 0.05467315940486808, 0.05938481847425142, 0.0397265809888561, 0.007289064214414647, 0.02518916630276269, 0.025457798863851258, 0.04237927533986588, 0.01890020306041885, 0.06323926346076113, 0.02875217803633742, 0.09886351639344808, 0.003147282390742593, 0.06180478297474404, 0.06348626552930763, 0.07705903762290556, 0.06899042340416102, 0.11185056064277889, 0.05697502762139325, 0.041650308205956416, 0.032893406122081706, 1.0343482585683947, 9.133370345638646, 18.054452211626117, 4.996762275695801, 4.995261478808619, 6.424669757966073, 4.249432596468156, 8.588078521913099, 13.844032979780629, 23.08753759630265, 34.20222459300872, 29.33188815270701, 26.978030666228268, 12.840646563037751, 12.80969415941546, 10.053641738430148, 8.518419188837852, 11.30453363541634, 4.774156001306349, 4.467802220775235, 6.425794987909256, 4.106642387567028, 1.5062543749809267, 0.4052105017246739, 0.10571333068993785, 0.09350437896266099, 0.04993089512290974, 0.04478232844943001, 0.027811690196094495, 0.05052793425537887, 0.04062841586287945, 0.01665201653996783, 0.047019033227115876, 0.029026117671521443, 0.05457849008962513, 0.037320900197711684, 0.04405131586076271, 0.04668041470370466, 0.027592091092599497, 0.04404061361246052, 0.0651737044174825, 0.03209054980787539, 0.05398215958848596, 0.020534033030872385, 0.05846363604970037, 0.06377655922645523, 0.0026594543587341304, 0.040802390600043925, 0.15678493456254083, 0.041621821226492044, 0.07276142226351846, 0.048553940179126884, 0.04434063662624648, 0.06224761243849512, 0.03555087703129938, 0.04688155491866412, 0.05023751798416338, 0.022819995346869675, 0.02345153141856915, 0.03790783463045955, 0.02250303412907787, 0.010822580605294677, 0.07127737205836081, 0.021527200907228455, 0.04237066068115734, 0.016211341698503783, 0.025017499405470107, 0.04519631470283193, 0.04533229913983134, 0.03790335301610251, 0.08194943649634238, 0.05060394166878635, 0.04168013583928828, 0.08508121925255946, 0.03260279832888515, 0.041402268088272506, 0.10203275318828323, 0.10353261544819801, 0.010943600472303168, 0.008179210501933291, 0.024810969761963335, 0.08828582632685862, 0.09249426139098021, 0.044578116221894185, 0.1649405687086044, 0.12208784720109356, 0.08333140548558966, 0.04113692970525834, 0.087367371175318, 0.06672922296509629, 0.062205550381012505, 0.07316956326605813, 0.0022509358184892806, 0.0901912019077328, 0.08537509824119269, 0.031401436483006806, 0.19482624086160816, 0.20159812103356087, 0.3940542084315131, 0.33130504972031044, 0.1941071907358785, 0.15612171692473276, 0.21748226466438464, 0.2319224704537661, 0.1900276346432586, 0.08858020327264264, 0.10587174235092056, 0.16488139607733296, 0.20621767718224757, 0.12054082456856005, 0.14740734421197446, 0.34817271235008396, 0.26730955788685434, 0.29533299287000014, 0.3314541304303754, 0.2809342784025977, 0.3056403381689903, 0.1635471773484061, 0.1730867799731993, 0.143692507258346, 0.14824461702617908, 0.08637843593474358, 0.11048851760044215, 0.15377934180921124, 0.18835607675775407, 0.07347097289898703, 0.15812774879797814, 0.23152286367070293, 0.20803519013908603, 0.16446043076294084, 0.10908460785304347, 0.12623111882637586, 0.20489001616595254, 0.21048772869811905, 0.14745664963078114, 0.12424467582135432, 0.11547732812863205, 0.13440778208596094, 0.1681895322737194, 0.15348939285162957, 0.1064538389384266, 0.1876452237728142, 0.1415388042768163, 0.11835739737556827, 0.1195612432615411, 0.16556100799672066, 0.22077253569037686, 0.17078761221660724, 0.2337726493996959, 0.14368214974960974, 0.1842918424236198, 0.11219428897264505, 0.08280306528773039, 0.140635755153433, 0.20340804971994894, 0.15165505660397394, 0.1875255761608001, 0.16339251951825234, 0.13131243447142263, 0.149993488505002, 0.16391994041060248, 0.16592122253871736, 0.1089212472640699, 0.16006569077651348, 0.14681973945229285, 0.17287009966469583, 0.16449029287022932, 0.0870771847304798, 0.13756916647957218, 0.2242040426860894, 0.1845377566473138, 0.15495513355539692, 0.2705042671051718, 0.2257603503042652, 0.11523666926809858, 0.13825391118805255, 0.6081884390404148, 12.811824006419029, 28.73183611900576, 9.033133195292566, 19.019327817424653, 39.22203863820722, 39.178139471238666, 40.95021924664898, 23.67366521589218, 42.76657865893456, 56.123908258253536, 58.060613832166126, 43.257486820220954, 24.67546993686307, 24.046966991116925, 23.171542998283144, 29.8239573355644, 53.029197415997906, 26.458932430513446, 25.168231418055875, 13.4008571217137, 8.935340662156383, 1.001431421647149, 0.506498571485281, 0.22937484506157138, 0.2720918770759337, 0.18451918667602926, 0.21935711164147625, 0.29054834477363095, 0.1363286403037848, 0.27392895591835825, 0.16432192206623095, 0.16580632467183376, 0.20015664999523472, 0.2069180347626248, 0.22231640204066233, 0.1936378852734643, 0.1083824652878027, 0.12948560588542493, 0.17551207644564493, 0.18264297606243243, 0.13249001886335113, 0.12049190985459475, 0.15424607321619987, 0.16349689133705633, 0.14761532176165812, 0.096583784287495, 0.09138730264479115, 0.3375663169689717, 0.15213075123967665, 0.12822596581592677, 0.16006627300333592, 0.13125343037949455, 0.18248172987612987, 0.12875295003816006, 0.14711407043280142, 0.129090519021115, 0.15842506752139138, 0.08972006549517955, 0.27964951831006235, 0.13651004992425442, 0.18668718485822602, 0.16585749934517569, 0.2174743279934891, 0.15049547527826604, 0.10790229669862217, 0.11219756782896097, 0.2080907161918379, 0.21775139135218438, 0.16019140580488792, 0.16701522673810684, 0.1330594520174688, 0.191633875872339, 0.2441761387331832, 0.09234504278508887, 0.17088125880447128, 0.1781721788668825, 0.12035602117858588, 0.07041717789346172, 0.1654279998113071, 0.26360034401859006, 0.21130810161271404, 0.3468557459212119, 0.1827157390934806, 0.4016390611087123, 0.3177480820205904, 0.15519694154781682, 0.16007799414857743, 0.20799693170814745, 0.10002046237669646, 0.20909046093302391, 0.17239042137178684, 0.22562933394745474, 0.12473053644381224, 0.2589124068617821, 0.17277038566047148], [0.031295147529172326, 0.09142189917545165, 0.1013389073552624, 0.024770399660713253, 0.07763721184023926, 0.036030133975850004, 0.04733406773377811, 0.06031245518956454, 0.04373116388676628, 0.028951445166322014, 0.0472015728272738, 0.028590240455683202, 0.09706181549136678, 0.0201576559488932, 0.030552285475536223, 0.08994403129984295, 0.0677350887487973, 0.04605685360729695, 0.08782670983383734, 0.06946272427035917, 0.06381443461343166, 0.0633630556084456, 0.04018644058716394, 0.08474323658212539, 0.03131866642844773, 0.1275670995575286, 0.02470759385746093, 0.03705194971013454, 0.09048015495101291, 0.006013728439762828, 0.04514319799660195, 0.01563725072980648, 0.021285255018982197, 0.018114587554948467, 0.02769479667016816, 0.05800361940336805, 0.02875468505906963, 0.02305606342551689, 0.04383757349944884, 0.030436751755675485, 0.011274998617028038, 0.026934546335870703, 0.04842970370044632, 0.030738550178225965, 0.008835598465896422, 0.03602251140100341, 0.06846838044903933, 0.06214987877155505, 0.02704111874223717, 0.034084427696202076, 0.014281278934269665, 0.023416061547674963, 0.04786724194643959, 0.061244420301649845, 0.04802650013457864, 0.0484732979337775, 0.03671534599796419, 0.010083300970314492, 0.058775985418188, 0.10356066958798517, 0.07554714012170032, 0.03953174950795309, 0.059401274042864965, 0.08488424272546846, 0.06519399042571745, 0.010986238053338903, 0.021856467412304015, 0.05153764197002015, 0.04537042350538316, 0.04607517460000612, 0.051073787223187186, 0.02617340542436127, 0.035821846160557, 0.030430353006287932, 0.03177814681323306, 0.0484105323501412, 0.04338257089858094, 0.010825869995319556, 0.17060794927660497, 0.06951903173279378, 0.0962480309329206, 0.24608982636803584, 1.5269563996022748, 3.9929828864912835, 0.673230468265472, 0.9927916658982154, 2.4551578442896567, 2.2981603203281282, 10.741417581035245, 10.013667883411532, 5.358775469564623, 6.1403332218047115, 10.087766358929297, 16.73221730416821, 1.0143965711036036, 0.9210041405693178, 5.941204294081658, 2.4651142906758094, 2.396794447014409, 5.412526159517227, 2.085102810975044, 0.34567505121231085, 0.10853868593732197, 0.05762028432781658, 0.04380957681625601, 0.02386593902032943, 0.02564293933251212, 0.051785057726045775, 0.03984936190048053, 0.043785762973129756, 0.07026380709102077, 0.07444507667734739, 0.051170256845052206, 0.04229577941699855, 0.04755656648006651, 0.08738021846980819, 0.05034095900613935, 0.054185333766884385, 0.019505720870989948, 0.017523619669279265, 0.05821884031437578, 0.020190758608101357, 0.07254756881945557, 0.03622456709103238, 0.028566484069151264, 0.00351327826314035, 0.015207743535058634, 0.038861989479271636, 0.042828241167890455, 0.07958715841654809, 0.024210199781302965, 0.019719275540762374, 0.05434674466209066, 0.0669473205362597, 0.013977460912428798, 0.02308982492033993, 0.0031316656884061355, 0.09909161141202336, 0.09017455481713818, 0.042441918349434296, 0.039141347271300135, 0.0201325818911315, 0.03100072078767323, 0.027962647821573962, 0.0834990025407845, 0.027274723848207828, 0.07162849313669628, 0.020215223625963254, 0.04346733086652333, 0.07282721389445566, 0.08710959791055611, 0.057236573869182225, 0.05035202131576596, 0.029714300199562026, 0.022289370291776234, 0.024865455850357973, 0.023499455963892323, 0.053325656711334185, 0.022424701638820193, 0.04205107561222488, 0.08371518489213721, 0.06217861089915518, 0.06587392410203334, 0.03612185002214486, 0.018198384167326075, 0.03285720846765945, 0.1107733107862934, 0.06368504236302068, 0.029064012210695978, 0.02498625642469814, 0.08706262905991848, 0.054423529654741294, 0.06908937898134032, 0.09539898334731979, 0.018061377002947757, 0.0610591036327664, 0.07548121825581597, 0.08097995988904469, 0.12548174694060318, 0.06870403675542724, 0.14500781893730164, 0.07240899883571171, 0.0625378103746522, 0.040994778260468476, 0.06684849519402751, 0.005780282297036461, 0.03420714349035294, 0.0656325374579718, 0.021363658372372873, 0.03096745150434154, 0.015721726287606985, 0.18741320638406664, 0.10042586078446719, 0.13087024852152795, 0.05971878301352263, 0.06507049705232344, 0.01009657344360265, 0.03467313562249465, 0.05101967843309526, 0.057708775143950224, 0.01457130162781405, 0.05126712483263785, 0.06793787222235434, 0.011097249939226577, 0.011466289814110967, 0.038727299730864265, 0.0891660460300984, 0.0029720313989767626, 0.023001339849865726, 0.046315159303166216, 0.02840414812277642, 0.033039591019792904, 0.015491812767821456, 0.037957473297513304, 0.03281663645118956, 0.046549911625803485, 0.11709455505854661, 0.027411778893081412, 0.025863915479051012, 0.03206920276786531, 0.020107982807882854, 0.057933932215335875, 0.05449564917193306, 0.04975152712675834, 0.04454118312306462, 0.05748195566176888, 0.014844019352758845, 0.05655867415630529, 0.05738992168898544, 0.021834503671514894, 0.0838526517092701, 0.03912475763729984, 0.023164974315272226, 0.06410166395888214, 0.07061400120296786, 0.027048342951363134, 0.09493499453510008, 0.07444018137551124, 0.02404411000409915, 0.07845937740057707, 0.07541580200796166, 0.042942043529042316, 0.04654687408718371, 0.011974584363821534, 0.046364736683186025, 0.06167445226662582, 0.025367911852475618, 0.06848519607897728, 0.0280584049816694, 0.043893517070119424, 0.01799958243575548, 0.07565922644590178, 0.06861350048453578, 0.01513366953605005, 0.07269231347186912, 0.0722876351867472, 0.0868970851203607, 0.9867260881489324, 5.9587480752698845, 10.350084670128362, 4.6262046887028605, 4.07198456987258, 8.767287692716046, 10.521439294661246, 12.700489490262925, 12.585746434427078, 16.94291526271451, 21.242935157591297, 22.127800295429846, 23.861215306866555, 4.645304179960682, 9.262278060759268, 15.864859665593794, 5.232014761817071, 3.172415937146833, 6.322919063029751, 4.701451438088571, 0.7061079589109267, 0.12433856755735413, 0.13332016705985994, 0.11966838831863097, 0.04120547925272296, 0.0869663088251987, 0.060280252683667414, 0.04585557932695074, 0.032760252379962516, 0.03677138916006492, 0.08407713845372201, 0.02759529717056261, 0.012414792849261676, 0.01095227929087536, 0.05241172530898645, 0.01229109837778754, 0.11756156225718799, 0.07739866738237682, 0.10699871897457108, 0.04043115588325647, 0.06357030920504082, 0.0410578158053179, 0.013514053369421634, 0.06449217727828412, 0.007897823534515357, 0.008376843949419358, 0.08812124765808545, 0.027034463353394985, 0.05767333974701263, 0.053430170256404154, 0.035008800876957756, 0.03801350496829518, 0.0303735954671978, 0.022618234600691546, 0.023354431689386407, 0.025311548848666494, 0.12166705808692402, 0.10282843508907866, 0.10852536366831873, 0.017309036526468494, 0.03458911109895956, 0.028589901461776708, 0.046261785957481594, 0.081198432843291, 0.07984755936289027, 0.06884374054929904, 0.02657525109938316, 0.026268469274885235, 0.07901697449626462, 0.07893644333366426, 0.056411650392317006, 0.01685613492173293, 0.02265462760753449, 0.08945691429318921, 0.03161799804788203, 0.031062295104587273, 0.037504845569210674, 0.020804462068143393, 0.03223060983263197, 0.07296705558415383, 0.05650390653059848, 0.09824790345925478, 0.04096041538662488, 0.025396448627655065, 0.03404191364684413, 0.12865231672842659, 0.05006549677120582, 0.06842566338638145, 0.06828673334131319, 0.04341021135088898, 0.028959577189638253, 0.04111852827331713, 0.0032928486724549365, 0.036789480326396805, 0.08664514178470259, 0.1329470362754599, 0.23584983551934843, 0.38322028493688953, 0.31248125818467914, 0.2511282027849267, 0.35369111946032894, 0.35003053685349805, 0.30355618064922674, 0.21323003235363194, 0.08460735556699576, 0.19779668550097174, 0.2389799328821321, 0.20142435697057556, 0.06699960603709183, 0.17523205598756192, 0.47340452310539066, 0.33269479450198913, 0.317689981912413, 0.3641922237171281, 0.2536315023298225, 0.1549014920789388, 0.18021288387958082, 0.17443590677313267, 0.19642200200788437, 0.2336927617509519, 0.11125688846673697, 0.1902831556095231, 0.12674617505962812, 0.2707351353620329, 0.10261526346326837, 0.22417845534941844, 0.14876636886788955, 0.18259619873377586, 0.1331367502890287, 0.24855048545906622, 0.16831310225590584, 0.09351063790100236, 0.16481361261779265, 0.14715880996757938, 0.12879945157516387, 0.13899333925256807, 0.13330406389169155, 0.16404916412167012, 0.1251634603907024, 0.11264419708881648, 0.12923380810647242, 0.13539932968635715, 0.12772070018634682, 0.15978177859177514, 0.16335827538803702, 0.10601527658441376, 0.14412068912098486, 0.11784402653574945, 0.1572375852734812, 0.20134194123168148, 0.1599494139513662, 0.11551876582445637, 0.09889377686645716, 0.11357962874875915, 0.1934087330535535, 0.1997839022547968, 0.13325783814634048, 0.10755544273002494, 0.14471275251238577, 0.18142449789710585, 0.10653250084649171, 0.11417367630788397, 0.15062024035761434, 0.12990678570443584, 0.1723373314786342, 0.13800401330715226, 0.12347458125722986, 0.11419905680081538, 0.1815764744195246, 0.15135081244572518, 0.12075775002519931, 0.2176131737688857, 0.17044581442831025, 0.4039449857607965, 0.21800357217509903, 0.20862717692169452, 0.8579342055224604, 10.66748776743489, 15.067321196679147, 7.3575246045666365, 22.222690274638516, 47.63427926648048, 51.577116366355654, 55.320751974659586, 33.01832775915823, 35.182377830628425, 29.964486052913053, 33.63190412521362, 43.87087883487825, 21.251417283088934, 23.171431210733232, 54.9840949427697, 28.9446109725583, 24.56276062996157, 25.298191308975223, 8.473365864446087, 0.9425619160456042, 0.2849778743280519, 0.3587714774954704, 0.2892004896796519, 0.13651772612525573, 0.2879846775003018, 0.224807107100083, 0.10549956151554662, 0.10330987538421348, 0.30536849952993855, 0.17580420109293154, 0.23329655639827254, 0.1422034008728881, 0.1173307246438438, 0.23353373721962978, 0.11965353387377917, 0.19162071448179985, 0.15843419928944882, 0.19092288499157276, 0.1838035686242004, 0.2107343936879789, 0.15990901047423964, 0.08413166859217229, 0.18578966688965598, 0.09718266586142202, 0.12046712691024428, 0.12642900699809675, 0.10089980107882332, 0.22992143347378702, 0.13304544793021295, 0.10664559840675324, 0.12748834571891254, 0.1871912553906441, 0.0704832146725347, 0.2020614510101657, 0.17147529870271686, 0.26592529829471345, 0.2218970608326697, 0.206763438219505, 0.16228189121090597, 0.10606386188057162, 0.12038840371514521, 0.136278384935952, 0.25239309055670617, 0.14717122059195273, 0.1335473121294091, 0.14670429000210378, 0.15956745783407844, 0.15565507744829502, 0.13838532591058364, 0.16439381175704543, 0.13337511088578932, 0.16655667715014952, 0.15753108887903153, 0.06597329336669176, 0.09674176693924012, 0.16612725422507332, 0.09522053848711715, 0.16843031370832076, 0.19191345199942592, 0.145536097848127, 0.2664664015173912, 0.3574728358897471, 0.121310398192896, 0.26535597239290515, 0.2816513673432412, 0.23410078017942368, 0.3129645370908322, 0.13994892668579856, 0.20343265646407682, 0.17704583043532987, 0.14761594995375604, 0.1978900256536661, 0.2351802746735273, 0.16384707012724492], [0.0670525044082634, 0.07973902768665746, 0.08326816492744031, 0.032806470464434356, 0.0519488396633777, 0.05766450292280605, 0.14127389107260013, 0.053761120239693316, 0.0350704824461812, 0.0736581894659227, 0.045994294867400205, 0.04838970624991963, 0.005087067050138308, 0.10254708163800741, 0.014764548264323704, 0.0955285058326779, 0.10227938753462608, 0.046199154439232046, 0.09274323230549213, 0.04984993112063216, 0.04381352599950568, 0.08112452068035642, 0.05104750657694475, 0.07529876675576934, 0.03599232370634714, 0.03722592061685939, 0.12139972404486711, 0.053456481546163566, 0.06904491523821508, 0.016823024601645527, 0.03500760194935626, 0.02504367471462296, 0.021430150973760796, 0.034409501785112005, 0.03185260481381368, 0.023730167172729008, 0.08697083640483119, 0.03767178378879063, 0.06286839263573771, 0.02406064218150512, 0.04882477907343738, 0.1038021634843561, 0.02242985549533079, 0.05974715891023798, 0.03563153842884687, 0.07189585016139093, 0.014831681506738309, 0.01647037709312093, 0.02195860991524833, 0.03942120302047941, 0.012710410857483024, 0.05245679809201149, 0.056248963960716804, 0.07133315858100692, 0.028525460060806047, 0.020464320944982673, 0.07365766086525495, 0.05715147682255315, 0.04342206656151722, 0.01871266856699461, 0.06857005563834984, 0.10341708172833729, 0.02416566134460511, 0.06598253238705859, 0.07123293129787331, 0.04107144833993047, 0.028959531224362796, 0.04219493160264627, 0.037508844548175414, 0.018175962689002196, 0.034387396318056894, 0.02474846081778167, 0.04961818569309769, 0.02922246792173434, 0.053905152430337284, 0.01867685204131469, 0.013102459225563273, 0.030131391024277098, 0.05006989411589119, 0.038469568600938205, 0.043804696836178346, 0.12788242900804167, 0.3310628433621699, 4.348983822330352, 3.882531393920222, 1.2461844399090738, 1.157092214111359, 1.0765681608069329, 4.675054867421427, 4.493719281688813, 13.824132834711383, 12.850883949187494, 12.876546056039873, 4.968569749786008, 2.039568873663103, 1.2542911210367758, 2.1901502580411973, 2.2319159007841542, 4.29030712573759, 1.3042572140693665, 0.032166143533803766, 0.12191332471106323, 0.10088654775773326, 0.08032109363064652, 0.04243390890018594, 0.02292142730326422, 0.030037198598767002, 0.08426035604169292, 0.025845148240125952, 0.053012847690091985, 0.03012479500724904, 0.07989176263612124, 0.05053422766767683, 0.0715513940479967, 0.03930985214068525, 0.03933478447218095, 0.04920375893913931, 0.06952754296963254, 0.04355965595271799, 0.026706744345926473, 0.03999997478639407, 0.05085577009125583, 0.01563774294129783, 0.007070474910564842, 0.02976088792145733, 0.06658590323622189, 0.022107035620138053, 0.03606086559293251, 0.02598884526730305, 0.08289417612456507, 0.04761273221623513, 0.0342784930891808, 0.047963385980936794, 0.046645779868647944, 0.03532562419892319, 0.07604698184877634, 0.03543841915445463, 0.0011201048149697243, 0.07784295241318404, 0.03382044145837426, 0.040487922998445655, 0.020254939539177765, 0.04591950936423195, 0.030856359179221818, 0.026741639650877447, 0.07748086095577286, 0.005049601999006325, 0.045377218705271526, 0.02701973339783088, 0.0417021532062321, 0.08027388729275235, 0.04282206266878113, 0.03389832195675662, 0.030850395184731295, 0.06531420494279554, 0.019271705907979803, 0.038675791809275266, 0.017925831151285, 0.04079296005769603, 0.043734798973966996, 0.07040859770870979, 0.058143798171752886, 0.04346463806746949, 0.0823541147814643, 0.034557368245817004, 0.03811356371208545, 0.018680994661765236, 0.03119296097617236, 0.019967185423499154, 0.11554337256858427, 0.09733438957482578, 0.034748323321823156, 0.016160337479725, 0.10361825641725333, 0.04041462753629012, 0.025631905751182668, 0.07142431538311705, 0.13843925850045297, 0.09500440976191914, 0.03049461820703601, 0.04557439441522283, 0.024963704711427132, 0.075956859265364, 0.051186003782335794, 0.02609436430277363, 0.04314600677800275, 0.028858415279237014, 0.027934135944252054, 0.028577360602456237, 0.12528638685903243, 0.013586851832036291, 0.0421182117274692, 0.08665651819037815, 0.08579332862169513, 0.04400874435481045, 0.03866371826358861, 0.055705053025796536, 0.06261901952506554, 0.020242396764637485, 0.042368013847378955, 0.047650075172104185, 0.03475836673451047, 0.05135228699674049, 0.01985439429840734, 0.06683554830810716, 0.029245107735116637, 0.041365499698346665, 0.018598473585781553, 0.03552329020514604, 0.014820368303316496, 0.030729104314119588, 0.03978416398768464, 0.029507914197541056, 0.08119989607122638, 0.04063865462798746, 0.005646683266311283, 0.05434112540716606, 0.03904934011159405, 0.02419046727159331, 0.02948468641167687, 0.09485280096170404, 0.014750318181130194, 0.05686507485206089, 0.04478871762271851, 0.07817674458267228, 0.026158460964178367, 0.020606196598119794, 0.06378257301666083, 0.03217230288071498, 0.021617089833823905, 0.011874300581703504, 0.01598635603929119, 0.03091151750977001, 0.03463902172722644, 0.09878738257553309, 0.03621631632408789, 0.050578733545637904, 0.03162845131760884, 0.01974112819880247, 0.051908811569334044, 0.09221584205665896, 0.03685192032266529, 0.048398148538845207, 0.021817950426691005, 0.0381542353199855, 0.017785112290913542, 0.04937022218420621, 0.020475940583574197, 0.043024834651019306, 0.04466007613847333, 0.11259251679744452, 0.03457180517275007, 0.0215831195800415, 0.004375538950215184, 0.08021966358947177, 0.034616069733014995, 0.036451271660025084, 0.007826484948201406, 0.5681704573573605, 7.089189377523239, 5.405586506089857, 4.147037652231032, 4.046439398680964, 2.299846204057817, 8.379332923120069, 15.574423843814483, 15.150821593499954, 15.22793637168023, 15.075407162789377, 11.906102645781733, 8.544388221156213, 13.068343093318324, 6.897601696752734, 7.095875057481951, 4.799997556594111, 2.6774265496961536, 0.4804638088230164, 0.16240786670917468, 0.04090060307193668, 0.0364481421908544, 0.13674019805846677, 0.09705934102737135, 0.010538937508939736, 0.06988275495748367, 0.03650913045050637, 0.01177484992020313, 0.046509500487797686, 0.09364568388029453, 0.1246326840332439, 0.07383277324298698, 0.026205395340859413, 0.04741204016271138, 0.017338038700061943, 0.06401751303083955, 0.022025596643347415, 0.07012588828201256, 0.10809230182560221, 0.023466073682591803, 0.014907472500307186, 0.03143231174157512, 0.028823897272588748, 0.04102733316681078, 0.018650502447159063, 0.03380901525698362, 0.03696141343924307, 0.1104190334257099, 0.032494304957048546, 0.015790133151195703, 0.01772973945574655, 0.04607615902298882, 0.01763059235658617, 0.052573952087832075, 0.035463876256178466, 0.046039750694387385, 0.03111566270461246, 0.026665182160814444, 0.021464261038589384, 0.03371986177479548, 0.0580226720100449, 0.07684238795791903, 0.0564908447314895, 0.048144293813816005, 0.060987807660093235, 0.07323370014707889, 0.07370571756074507, 0.04654009420905383, 0.07077882501987681, 0.014635283376030145, 0.04401321830828825, 0.06395917160496598, 0.056686557213505434, 0.03473531131842925, 0.0630009411683967, 0.09496821976837613, 0.02389935577558654, 0.0512627313183921, 0.09431957312288786, 0.019973610985964056, 0.04455164022323105, 0.06404570889689269, 0.18832232292381026, 0.06038023864910488, 0.02381707601729901, 0.025622898472412944, 0.049143448667300325, 0.09497200424272208, 0.024346109524729754, 0.09199481802962481, 0.09956371309536119, 0.09168626845724161, 0.08509382905979311, 0.06404789607791651, 0.25168355524299607, 0.3381497082450698, 0.31555952203850596, 0.31482426149229853, 0.5744607746601105, 0.2675073005018696, 0.23622736364843386, 0.2161504667732985, 0.16267210575601748, 0.14870022483650716, 0.28178558594757513, 0.12687708416412916, 0.09414246125567345, 0.2752070663677108, 0.1293781084278899, 0.24435168012015282, 0.3248529346479524, 0.1958409856043516, 0.23348991699036092, 0.26185084434766925, 0.17110510969594603, 0.17721092238301234, 0.06584581633609149, 0.16823198886648302, 0.06966497914324846, 0.15331503124006335, 0.28269067286483707, 0.18992162339629667, 0.2029174776567567, 0.09562035977479913, 0.1530129014844856, 0.09253669500110612, 0.1340926288356704, 0.13895213904400028, 0.08206127001152885, 0.1218312613726143, 0.22009687678467846, 0.16692375583994776, 0.1674448641678018, 0.15265022013937274, 0.259103101467894, 0.17063108513191824, 0.1493367672927918, 0.14143216483775647, 0.09679419799677788, 0.1918045296183517, 0.14013825765540525, 0.10395012570605164, 0.2040801233341617, 0.23068738350224113, 0.22285948177018475, 0.14495204773641404, 0.12676639211994986, 0.0907397361832761, 0.11483963654046098, 0.11126269541320302, 0.19368506096784147, 0.11826395763144379, 0.16095147227808354, 0.1315439615638987, 0.157954873396985, 0.24510580175105603, 0.10654534048010265, 0.21158694229539365, 0.15337271766076166, 0.16438714679210417, 0.1256477811764325, 0.12475605483257002, 0.12150150648648701, 0.09558211666561904, 0.20884874487115493, 0.14806077124611025, 0.102756982068381, 0.09361650359125868, 0.30425813169248644, 0.19864969376114108, 0.13244402294437732, 0.13646189363733416, 0.19496766069243032, 0.17294416504521526, 0.15886409718903804, 0.20441966882396131, 0.4822420214693393, 12.5531348682219, 8.67367934796118, 16.108893848234608, 25.341623713893277, 53.18664135471467, 57.1450424194336, 61.04747910653392, 48.909277069953184, 50.957730970075055, 50.458024932492165, 28.899690028159853, 23.259906153525076, 51.60417287580429, 37.21121595751855, 19.845992826646377, 27.180530871114424, 8.461013340180921, 0.8491376162536683, 0.2090918398912876, 0.21204457257784184, 0.3638044912968913, 0.3667355130516714, 0.1997416754884105, 0.0584874269101889, 0.16764406234987322, 0.18318674527108672, 0.25729620648968604, 0.2512059147439657, 0.2748403860436332, 0.28151089746144514, 0.250866997446264, 0.18098456424570855, 0.09818481611869029, 0.13477807834504113, 0.11896115126869372, 0.157791436199219, 0.17911043739126575, 0.2322306982692211, 0.16844321462896564, 0.08084951809817746, 0.0830807951429198, 0.1751577761024237, 0.16259485344973304, 0.1309682464888019, 0.13390723555799455, 0.12340094488594802, 0.2183781432047967, 0.10432547048455286, 0.13395842555309498, 0.12684851674543274, 0.1399281044160166, 0.16670954233456045, 0.17460577910946262, 0.1324512854578995, 0.11647775468807067, 0.0996334960443839, 0.06460962621795555, 0.12913744956735643, 0.169111994065104, 0.12004967027854536, 0.1791741759065659, 0.19821299300078424, 0.1962922113917528, 0.18235250616506224, 0.22819582042434525, 0.09874854957865131, 0.13375478406106273, 0.10290613938723842, 0.13527795071563414, 0.12788305720013957, 0.24870802377981527, 0.2255138538537487, 0.10593640783260908, 0.16643299991565366, 0.19753862112279863, 0.12869998271907532, 0.11468174581926678, 0.15276576152011273, 0.24723437704866935, 0.17740560064633049, 0.16665700402471328, 0.2177379541699925, 0.11817539786739696, 0.11435968245589927, 0.30500641573340664, 0.15844806548087828, 0.4045365588559259, 0.2766726538538933, 0.2108622384407828, 0.14631668015593483, 0.24498633800014374, 0.32698740882258265, 0.21030673276512854], [0.09791685388453546, 0.05615222620807829, 0.07100192514518577, 0.036549078105317975, 0.04837291360261941, 0.04507768981819672, 0.08419502406351029, 0.027338866474888018, 0.07653557740512394, 0.029616352028003144, 0.02576511503467637, 0.038437791273839055, 0.007060585673072286, 0.02983701024805346, 0.10773613222784574, 0.13097046814378233, 0.034913894074458274, 0.06026568935222684, 0.03873431326581105, 0.04400773694919002, 0.05987342169147827, 0.014913412554550075, 0.0321350441945176, 0.035577199812377655, 0.009430538517453018, 0.025971671491260492, 0.02837122357901066, 0.11408866353092656, 0.03805710303206598, 0.040506929639847054, 0.03184699321976833, 0.04809425678104163, 0.019662523747331673, 0.05116580587421214, 0.03578962833290139, 0.057140720948096246, 0.03764627306091209, 0.04021912572845336, 0.0634883875928579, 0.05135971038872677, 0.04937959910039941, 0.03003992395655763, 0.0347556509528189, 0.07176442011710137, 0.025296202192323345, 0.0764445968032364, 0.020070693478168502, 0.021529382342592846, 0.051487811780985326, 0.01177998270929581, 0.023180625491565274, 0.06403512922265837, 0.01548129150779137, 0.08850493513408209, 0.08081058550986552, 0.024340586030795693, 0.02912499089424889, 0.011967647437667175, 0.0416255176007267, 0.030106002870466442, 0.040348659705130324, 0.01014277141826648, 0.04432050383559639, 0.02890305522258484, 0.08742000907659532, 0.10006448178882561, 0.012008339155375237, 0.041230108979488575, 0.03229114610040861, 0.03289117680622205, 0.04489148448732111, 0.005421195819508285, 0.024476422995869673, 0.09371148317211098, 0.034445741574370095, 0.04982679526531889, 0.07253348046252805, 0.012712469718779528, 0.04509660835948683, 0.02111225321348156, 0.09975224733352663, 0.027426918705685005, 0.06295989800785338, 0.2275965558064561, 0.6630312639378733, 0.6994056088789817, 2.5924079504705246, 3.497234275264125, 4.388657616030786, 2.451676740761726, 1.6117737322084367, 4.353477877955283, 4.566201740695584, 0.5129355180167383, 4.356064681083926, 1.385735016196005, 4.057136437585277, 5.288703797325011, 2.706996562980837, 0.2743999161306889, 0.1154411304742098, 0.10527239346335973, 0.07577875148384802, 0.06106083116103565, 0.03894247084615692, 0.08618746553697894, 0.08071324637820644, 0.039450341174679424, 0.055214304762381705, 0.06650331129710521, 0.11773123541065764, 0.027742771011206414, 0.013754258322859965, 0.04765212445730164, 0.026112097323000915, 0.05851161230595843, 0.017144448281596267, 0.02361206705832193, 0.021190229472854448, 0.05625163377713292, 0.0407463321161847, 0.011465045878843916, 0.07253698148434201, 0.008249947230421729, 0.021227668189714034, 0.07580977038390214, 0.05505486654358045, 0.025147893315842076, 0.052896681947693716, 0.08327891314101797, 0.016575813774139653, 0.05771730553298708, 0.01905157245815762, 0.010255107678653253, 0.04753552587522615, 0.06604931227141811, 0.045852185557446176, 0.02933080233032665, 0.014804217254652854, 0.039935998783837405, 0.09747303616736205, 0.05536546157072148, 0.07148119741149488, 0.033819119956704884, 0.011168566021707751, 0.02854306476130601, 0.010555896780363495, 0.047890818302309325, 0.13154688801976944, 0.007930714561934433, 0.04659668895446005, 0.023871564020913456, 0.01511426357131812, 0.08301853517731352, 0.0438506659420748, 0.059906662246512796, 0.03338641434487316, 0.043126004222299785, 0.046403240262260365, 0.022370571781310345, 0.039778854998369376, 0.04277735377752012, 0.07290731604781843, 0.04378380178804359, 0.10209872868032226, 0.0740586772500988, 0.0525099377808792, 0.041909357007112236, 0.08549708242137587, 0.05929962183619219, 0.011134989345596443, 0.04642317003961052, 0.05171506410284389, 0.0971168895522433, 0.0138245468899127, 0.03380154589972189, 0.06063870139299862, 0.07136326583643114, 0.08499321873269736, 0.0799981186226491, 0.030386595979272842, 0.01861378576816811, 0.027585202046940406, 0.04168518818914891, 0.07524917022355142, 0.06721547429239558, 0.07800053669920853, 0.021877797215335795, 0.050426757023219144, 0.14060849774508707, 0.015852274373173714, 0.11033304005620942, 0.07764110356689462, 0.05705041067314245, 0.02945113942147263, 0.03867999763197957, 0.0331555116140554, 0.02599398188683535, 0.02285139920610574, 0.06166964889534059, 0.06293525295932928, 0.06529149043584062, 0.01984447537500772, 0.024933551490727453, 0.07889616243060558, 0.062008022270616026, 0.05816330277030507, 0.0319875703538738, 0.026515938657065554, 0.02506342446131091, 0.03796086323657825, 0.012999616709778146, 0.044769419867905884, 0.016011933799863102, 0.04824862732822376, 0.12605138693846044, 0.04761630218596228, 0.061514860830239715, 0.0809815380301687, 0.04803732495694872, 0.025661141581593022, 0.0988055695028555, 0.05584701294860533, 0.0316710572975177, 0.02334288099870807, 0.026121993263762806, 0.017280133944305203, 0.058204345930848396, 0.06183209400924464, 0.04356434441081459, 0.07358532684344439, 0.07762965821330586, 0.02421930282106323, 0.045923573460670254, 0.02949260776081393, 0.05158864427357913, 0.050873367130876555, 0.03568901800580564, 0.1280732538491007, 0.055058612713530186, 0.09966079941800526, 0.020922498980296717, 0.035511017476599065, 0.049616676499886866, 0.09564836794931082, 0.09507446084171535, 0.007434959435129479, 0.023114167364133943, 0.04695856590725241, 0.07228701465552853, 0.029898559667109966, 0.14123215460248534, 0.05704276894609775, 0.07521447410146076, 0.050761606394042896, 0.060460053519496036, 0.040078598390062975, 0.09396596225879847, 0.1088583897498827, 0.2593582700337133, 0.7215286346693194, 0.48408060184409546, 3.6374960262929243, 4.729658182590239, 5.189259456050012, 3.0160945317437573, 10.407836667953, 10.562566326510522, 7.895782147684406, 5.075039056039626, 9.040732787501428, 6.762509874759182, 11.255637368848248, 14.572856426239015, 1.8540684662518965, 0.3457487182271096, 0.06053287400713852, 0.06266698045956512, 0.044858569519654404, 0.06007709765746709, 0.030794566527249354, 0.08833541519819729, 0.07892470686666428, 0.019354723025894454, 0.06044262884965828, 0.03862099737049111, 0.02221749400750043, 0.04390795016661287, 0.03505683458981014, 0.07712239309424355, 0.030296973268231078, 0.054230329941117, 0.019911816418771783, 0.05010382031961795, 0.008137380186047765, 0.041255780585831216, 0.11446678920859292, 0.03938243897151082, 0.11057680157283623, 0.02770138502631697, 0.043880930245523496, 0.050570019295499216, 0.019184550000054222, 0.01490054706547169, 0.06949200415082517, 0.03587099836177884, 0.004392322021416359, 0.04501306264090442, 0.028781105516358253, 0.004933107317605567, 0.05082920216204179, 0.03176757479987798, 0.01862660241914132, 0.027183819855112704, 0.07201545946900884, 0.017536968751359853, 0.02886287965661576, 0.05832651014169378, 0.026694191995287136, 0.05166300842838903, 0.05598497389244938, 0.013589969809888112, 0.015800151666025483, 0.030471564706174598, 0.10273769963532688, 0.016770089841297558, 0.026705419013817466, 0.038866072727908055, 0.03873632041617267, 0.016227073314028884, 0.01565501535116064, 0.019532830807410424, 0.06132229313915295, 0.0321748845970198, 0.03731238129999369, 0.04065502592692933, 0.035957987645580884, 0.07611055182473314, 0.047987893133634524, 0.052384172956789696, 0.09330844431514702, 0.04022264590246543, 0.08453388773505727, 0.039871206897641384, 0.0940123029173382, 0.03561628561827444, 0.013687771467131474, 0.050873677396485885, 0.02866187925270248, 0.05976159966761067, 0.04022192961025623, 0.05168234831803749, 0.317672944116977, 0.30081217627852197, 0.26560461388960965, 0.24099794637051322, 0.31193077804580815, 0.267877351612814, 0.22065477265465647, 0.1912332118879403, 0.17415784750013583, 0.17163063069024395, 0.1949859089067867, 0.1561397506344703, 0.07173772961381944, 0.32008210677773724, 0.1904947184506924, 0.2526510170390529, 0.26064848467226953, 0.23177297605622202, 0.1832905655065852, 0.16280917420742974, 0.15879159462788414, 0.09671431034803392, 0.2113910842566721, 0.16589886809308685, 0.14925050579251783, 0.1497197346461396, 0.17082325062684475, 0.2222738535173478, 0.1837941763862487, 0.11531207530248551, 0.1914851322409607, 0.13315326714467618, 0.08830596677838795, 0.09035028006520965, 0.21233665125985302, 0.1422378135424468, 0.1574895056265016, 0.12149926950974811, 0.12828146122516165, 0.24573742592286682, 0.2526290456373846, 0.14680152188145346, 0.15682932169687364, 0.177327337103986, 0.13630979454084752, 0.22806881836825804, 0.15333994441936094, 0.11698020111408927, 0.12667133593030516, 0.11123068825972658, 0.15981378574525157, 0.18122729154363756, 0.16889747412454698, 0.14963321267597138, 0.1431483703274881, 0.15972291239567343, 0.19239401895432703, 0.11112921225327639, 0.07034450679296447, 0.09708751008034715, 0.10936612984345806, 0.10182430832496575, 0.21494305091759852, 0.16166005764276753, 0.23268189341310533, 0.12397074576226935, 0.15894724837233945, 0.122044003989187, 0.17899794504046443, 0.14120189412947626, 0.11940855427735275, 0.06818464446452356, 0.10831104291062202, 0.1553091581069654, 0.26264120193739093, 0.32393274047682363, 0.23056320064971525, 0.344403621049658, 0.3711983429328088, 0.2875608470170729, 0.29938379002194254, 0.23453702128702597, 0.3377261535534936, 0.35622046599465035, 3.8747923124221066, 5.9509209855910274, 21.0116074931237, 27.49229850307588, 44.272141225876354, 66.05774218036284, 70.7141290172454, 67.11228709067068, 58.53261224685177, 45.87795172968219, 41.7037889265245, 36.780602470521, 30.714592279926425, 34.99012285663236, 8.937536208860337, 0.8149012082046079, 0.42801828754525034, 0.3222932510318295, 0.3414661335127969, 0.2723644818029096, 0.2273037570017961, 0.2321292375845294, 0.13699817050608898, 0.0988890577648436, 0.1571075954744893, 0.2618242151314213, 0.21381049717385925, 0.2124507983605708, 0.2444717107761291, 0.2229506921984496, 0.11404435300538618, 0.15805025134355793, 0.14644441765642938, 0.14242941213230934, 0.1436721752848356, 0.0975509702918991, 0.22479575367704516, 0.11223968734303791, 0.1276349672867406, 0.11420314004945178, 0.12894134638049912, 0.1229757737488516, 0.2336584869772196, 0.12096425668606836, 0.2033930803619085, 0.1831045746803284, 0.15514420405510934, 0.10549113454837954, 0.10818000357117384, 0.36137023159573156, 0.24687958640917657, 0.14563887620404845, 0.1325419136593419, 0.177950702847973, 0.21237647251015712, 0.16030296352842163, 0.23551284876321596, 0.16758144232294253, 0.13649546361017612, 0.07745643807274681, 0.0876380300389663, 0.11741549227266543, 0.09006042303817888, 0.08598314988757334, 0.2768041758287338, 0.05427851687155424, 0.07468245668156494, 0.10676454121787703, 0.08436587699238332, 0.0897617560000189, 0.1304372862702416, 0.10167383333487857, 0.1062250237972025, 0.08994372486467324, 0.25005851421625386, 0.10299482172535313, 0.15433276372571147, 0.156672963151528, 0.24011974913939355, 0.1711586898853702, 0.26513736154283246, 0.2959161696414794, 0.2550075494594151, 0.16562782618547642, 0.3548379224394599, 0.2184167233926635, 0.10040765853538629, 0.22600105513007412, 0.1892800860467457, 0.1861472920544686, 0.15928095627215602, 0.2371808979660273], [0.04366939804787117, 0.021702033662868124, 0.02551256457433826, 0.020945902966383486, 0.030433145396771933, 0.04335248279535482, 0.09444591634336019, 0.03764794696302664, 0.06778188139921235, 0.010922866302632518, 0.04088893938328951, 0.05966128811480538, 0.05640734880862217, 0.12094464483520678, 0.05745599294201501, 0.014217020436790923, 0.09081801504737909, 0.0519102901190279, 0.04406877117411744, 0.03437493972840809, 0.05159390346717931, 0.07624873876451485, 0.07829708167381826, 0.034908470171954364, 0.018862323843002803, 0.01769284274609339, 0.025324662358710365, 0.015740550983126367, 0.046410916463261655, 0.042092157077164426, 0.07139393999691933, 0.07353874103676888, 0.061406490032471, 0.004777716915874232, 0.02133093875712685, 0.04411099027962454, 0.05813544015249899, 0.0456957504033081, 0.05407660673823088, 0.08292196213357872, 0.07453176718685897, 0.042374150211652445, 0.01101925069721596, 0.04951718083072094, 0.05534331779927016, 0.011449263509993833, 0.04195716855446658, 0.02093463381301732, 0.030396114621732025, 0.07635517135983513, 0.03049136616379744, 0.028090915837956053, 0.032895535846511205, 0.01695706509053707, 0.02086009537320464, 0.05591110003391101, 0.03845944091857922, 0.05354980254665979, 0.0330577549644776, 0.040484318554761915, 0.03578151163134364, 0.03236164917208014, 0.017145645293977954, 0.043004586947180574, 0.014364157198748041, 0.05384540523312265, 0.0776192317566564, 0.06294069218359168, 0.01905367536950977, 0.030309992932504227, 0.0683196138350233, 0.01358645442392557, 0.0808069848966214, 0.07527527083913166, 0.07534260230679667, 0.056951619804866856, 0.03382686510561936, 0.08874547142054766, 0.050967978989525195, 0.0790185449765094, 0.048454911823594765, 0.13419790463822504, 0.07366603420626733, 0.11836203986838942, 0.07125334754105538, 0.3915826249266825, 0.9286662455528014, 5.4348616061672095, 3.5969333254521896, 5.028156436258747, 2.9810454576246204, 1.2887378661863267, 2.330731191942769, 3.5276581395056943, 0.27375266376522284, 5.933199226856233, 10.144127876527849, 3.6407094280565944, 0.18017888489750125, 0.06245010096820132, 0.03137902075034236, 0.061420298767306154, 0.05998478789303092, 0.14648174146010032, 0.08321285337930726, 0.09854359807626856, 0.02579901059488616, 0.13492679133290245, 0.0749244025698112, 0.07905755417361375, 0.03577085917875652, 0.04267054196867732, 0.03902211334676512, 0.048052880372251236, 0.012128573782261343, 0.01697762305998514, 0.03322794522729612, 0.008731509142014529, 0.04983834787121704, 0.07063621009189276, 0.028302407815992355, 0.039531063859260855, 0.02453461311937821, 0.014361076567682528, 0.05809795547036394, 0.021095569733710542, 0.04253645359929051, 0.09374330646448559, 0.03969305315084996, 0.04445554598444893, 0.05251809278683317, 0.09715166994400563, 0.046312244338614326, 0.024761963117447112, 0.0633741715442269, 0.03486117190350929, 0.06974546434057337, 0.09792824561196951, 0.03641741057377189, 0.04841628950089217, 0.03501331696527139, 0.07831999536363349, 0.09257032626098202, 0.06753190690951963, 0.06141802731661066, 0.03135479321973699, 0.022964514003345565, 0.007951467404998238, 0.07953629017837587, 0.019712122194769404, 0.05060866843127916, 0.09017702162025437, 0.027985594070125974, 0.042166781701868584, 0.03752636497900371, 0.10634958203281127, 0.023063446597887144, 0.05920006487999232, 0.02558296039370039, 0.03417602116842905, 0.03028810580050753, 0.037218818981801315, 0.1256686877158861, 0.11232583393012324, 0.044851337649649194, 0.08321257758765452, 0.02145356836638624, 0.029690310156213182, 0.034085255071160295, 0.05635692873188565, 0.08856121195299972, 0.019781941532968514, 0.12241736459996432, 0.029170006220679612, 0.04342027774621402, 0.08585222546131381, 0.13153427821253577, 0.029740052245136712, 0.023377399005356337, 0.06552857932664695, 0.016355222586782712, 0.0741689402850405, 0.053860508656549844, 0.029590289716819124, 0.12292000254796398, 0.057404653559769356, 0.028208033444600242, 0.06392226148877414, 0.0965565805053038, 0.06504327028749451, 0.09511533163247571, 0.04096215823665261, 0.0791069208794544, 0.06931335244688296, 0.0266015317456256, 0.012957420586908778, 0.05722984761720704, 0.05880717285758546, 0.02138746838505951, 0.020326382983776353, 0.08117980924585173, 0.08461745260583778, 0.07031082190693387, 0.05082285895402874, 0.02402548449144008, 0.025540545935772603, 0.08294566489395597, 0.05711224929039037, 0.07135323008462306, 0.010752349494836264, 0.015713860479844435, 0.0465518115238557, 0.1051356697515134, 0.018140534952943845, 0.07518093477213576, 0.06498284127202726, 0.06910591881962554, 0.012498908345737766, 0.020262504657430035, 0.04640259674840397, 0.02491518453274283, 0.06958760426289613, 0.03669465013268975, 0.007110332071240391, 0.04220363053102647, 0.014199226129529698, 0.10104955594626167, 0.057356344055264234, 0.027269472315486883, 0.040791244020745646, 0.029549681311172825, 0.04999951744872717, 0.025649784328115564, 0.03073544943735244, 0.01226597069387114, 0.027590447834001917, 0.0069615185343390035, 0.08627653857993503, 0.06583551245350992, 0.025321368180635958, 0.012129981468822207, 0.07474769672919666, 0.0072480866501498376, 0.05289177898497832, 0.06260658591805447, 0.021737863595086723, 0.04621063043633777, 0.03494786624346049, 0.10365622373478067, 0.06037143629885489, 0.11650404682563198, 0.12567261774693766, 0.05810120368316289, 0.05390070528993684, 0.028644257315224218, 0.029356657797771118, 0.24435377920106535, 0.09842402707304686, 0.10329944126668478, 0.050479398754936074, 0.04548303459981277, 0.22307760232398588, 0.8502483824568411, 6.876449825302248, 11.01179930471605, 5.013290163009398, 10.325928753422154, 6.320012096435794, 8.111165867697808, 2.7571678450030666, 8.49328758255128, 17.64485674519693, 17.728420880533037, 1.8760376615870384, 0.15349739080955907, 0.15165419858549872, 0.08816061691651422, 0.056259616413303924, 0.1288385067375437, 0.15260770225957518, 0.08373652810170766, 0.03179080641618179, 0.10404178812619179, 0.08671584403923444, 0.11211067813658908, 0.03770178762234507, 0.01378967073715983, 0.07198657029338422, 0.056963773789785566, 0.012715893174191157, 0.03421210007922303, 0.07597662433381043, 0.16752956284871026, 0.07414768134514171, 0.05324714035997468, 0.009555589922163035, 0.024235402158791983, 0.008402245509768686, 0.06812501218049757, 0.039715070517793785, 0.038278092585143544, 0.051720411396555366, 0.04157938378592653, 0.06047954662672936, 0.01378676247587728, 0.07510957368198903, 0.047378738320642905, 0.012439096988659474, 0.04347011942656771, 0.029447140442507885, 0.018649303519557563, 0.10107122091276032, 0.016584945542197076, 0.013195050527311623, 0.03958002453850162, 0.01779221775641124, 0.08492709002307347, 0.0280754427771054, 0.035204226076002085, 0.0392181743987866, 0.022742386809700442, 0.024076030972684105, 0.016670823998508916, 0.04237832156040015, 0.033899976706673066, 0.02359499287370953, 0.043621636296231905, 0.03710659859221309, 0.0380951929236612, 0.023137220864995353, 0.0036271766246852256, 0.05486508741253807, 0.03567545058866663, 0.04759322378724333, 0.05757752896076249, 0.05876688812408717, 0.022644944256171588, 0.03556394649128761, 0.0968605105675036, 0.10599230926844383, 0.016092059893473502, 0.10778389014904538, 0.07696489307789073, 0.03916123491381446, 0.04596977239294399, 0.04499015278152881, 0.12992811359224782, 0.02540776757673631, 0.030890059387010914, 0.05394197827685745, 0.04984621942463902, 0.14605732875004893, 0.3041015433207635, 0.22883080006126436, 0.2999010525884167, 0.1636948331349319, 0.1970691317992826, 0.2134837913176706, 0.23047942127431595, 0.18013975312632902, 0.2804194060304473, 0.18617680176131188, 0.11821648316277612, 0.20282459715681694, 0.26252527751268884, 0.23733883465249694, 0.2790944110001287, 0.2807471690879714, 0.29473660874270624, 0.2702118053791985, 0.1671002471759435, 0.12567368260915243, 0.24327904977385076, 0.25318430616490306, 0.20302641535958937, 0.11306601276080455, 0.22876597370111176, 0.1162068659980451, 0.1618461863648507, 0.1613065080657121, 0.13603663823056605, 0.08382112719118597, 0.17741427276163332, 0.12423334538095421, 0.12356117983619053, 0.0889507063754624, 0.14199300248536373, 0.1700225355283868, 0.1522865582017168, 0.1415791924321844, 0.2206695121863196, 0.14859939234391337, 0.12247135081598837, 0.1461286821793164, 0.07621961976251296, 0.21157246323362475, 0.17189064093174475, 0.1499094793032254, 0.12740629770222212, 0.07283195597870697, 0.16008982254612833, 0.23726890614676863, 0.249379086157968, 0.11781827832061438, 0.09769212965282703, 0.17055770923053065, 0.10940276416799716, 0.14796580698701645, 0.15481893844421835, 0.14765927988675334, 0.18525011116458526, 0.13510505999288253, 0.11122165608309931, 0.301272104824743, 0.11050199308703024, 0.13100995231539975, 0.16744426661922088, 0.2749858201751786, 0.15961383679701438, 0.17044802076153218, 0.11649944263720706, 0.07497383822356501, 0.19964064381295638, 0.07504064109056227, 0.26940162143399643, 0.13729941159967454, 0.22203605982565114, 0.3003583764356952, 0.21079456223355186, 0.36248893446979985, 0.22833584597514522, 0.31779518110617516, 0.3656351350007519, 0.40350341268124124, 0.20142072571381447, 0.3951276508310149, 0.11646463160192776, 1.0161664793568275, 3.438468344749943, 22.5702711074583, 25.58011362629552, 35.63343863333426, 35.857492262317294, 40.571071178682395, 39.07954677458733, 34.63658002115066, 31.80013175933592, 37.91705823713733, 36.629097000245125, 11.01249062245892, 0.4937086416588676, 0.3249880419142785, 0.22446322555263198, 0.22964530474235936, 0.4672482711893897, 0.3268819338371677, 0.4006649037041972, 0.14703812047598824, 0.17928233219971582, 0.2378205813828015, 0.33411233295356074, 0.2434143409012787, 0.10268424968084983, 0.1503152607549583, 0.15794420945307902, 0.12120470104198303, 0.2212440321642545, 0.1704951658123924, 0.2912560261545643, 0.16751022678950142, 0.1614431015426113, 0.13654047893660684, 0.10240578438125311, 0.13194140797901538, 0.24697309510121424, 0.13131517706619156, 0.10391487800065549, 0.18337242966217382, 0.14683365160899778, 0.2816103050304998, 0.11911112064075087, 0.21352313759346164, 0.1567055678535854, 0.1740163970257967, 0.16503671274310158, 0.11408277997566808, 0.12107537773948525, 0.15325241121313266, 0.12449457370225461, 0.19285659816476608, 0.09059423310381752, 0.14605840127314293, 0.20230529679646417, 0.22632909397925102, 0.2846682522325747, 0.13734038198186507, 0.11180467963699373, 0.10531590725745886, 0.1108177668685394, 0.12366577382049254, 0.2445172623641068, 0.0978541649096916, 0.1539609352907827, 0.17923371626004098, 0.1243884245594663, 0.08535544042505565, 0.12509953035342117, 0.24196645004614709, 0.20518454632932143, 0.15127769701423185, 0.24758092458209685, 0.16007211059331894, 0.18298452870259363, 0.17673380282377044, 0.1960200356740144, 0.28973846726359864, 0.10065462996041584, 0.23471996308334414, 0.13994532607255444, 0.12040086030479401, 0.15511207432756502, 0.1502470023209049, 0.40886287186895653, 0.1784240838981444, 0.25816685009387236, 0.13714397235983802, 0.11810234372293758, 0.30945012405995403], [0.13144553458738711, 0.06365345272746298, 0.03667843971221197, 0.012900424602952217, 0.008396281515278162, 0.07799068480850228, 0.11358146735977744, 0.11326354087120104, 0.05441183915301677, 0.049211511748933026, 0.022785735894895853, 0.034229589866534356, 0.02200851479785577, 0.03589653207229511, 0.04149061717814015, 0.007945826603850771, 0.13155367555877856, 0.1038956951590315, 0.008429770091278179, 0.03501672222609482, 0.059460565417764656, 0.07532490567574579, 0.02794963773339987, 0.0673927317163156, 0.01711848747706221, 0.028563921505044547, 0.049367583011307066, 0.017858603105489767, 0.02018357844903104, 0.1070130754622721, 0.042707992176855766, 0.04625789806126587, 0.03564867581571302, 0.05484393189450907, 0.10945383924990894, 0.03337201189189669, 0.051848581736727115, 0.02432618740825884, 0.03265820563800874, 0.013692511636162958, 0.0817656520033075, 0.03412136845591088, 0.029716014321292603, 0.06614883475366139, 0.03221394742027887, 0.026375729245163744, 0.030275813919762452, 0.031184175862900676, 0.02980729369747062, 0.05003342833069544, 0.009838330949987135, 0.04064300600739737, 0.0687296394138567, 0.026617945179403312, 0.0382751852814709, 0.05272045874247148, 0.049166144022057136, 0.01950971984995469, 0.03301367809575412, 0.02682050074180288, 0.0425428236203809, 0.03883473590136536, 0.05993576592675621, 0.05302975525058085, 0.021123106764148802, 0.030671182321384553, 0.033484477429620685, 0.04528141941034025, 0.05985076464111767, 0.07619880515361026, 0.03663264297609849, 0.044632439516604915, 0.054843299871971535, 0.03142603556625545, 0.01597711606131446, 0.025597075563705256, 0.004810919166512547, 0.07816798819769775, 0.049180990806029695, 0.10004463245070751, 0.027086907817471414, 0.026743330789970297, 0.03566334256902337, 0.18099208722912496, 0.13223530995028634, 0.10161858307377947, 0.08153178068178316, 0.5373115164618338, 2.1936892165291697, 8.014940321445465, 1.5076873884085686, 4.185243989190748, 3.1669354054235646, 6.193477415269421, 5.273151599591778, 3.8319058524024103, 3.7915981056228762, 0.314808817159745, 0.042356668085220366, 0.073721491311106, 0.016248018157878713, 0.09733321746030162, 0.08123535062036208, 0.05323001829486701, 0.028591456620263, 0.12090034963142489, 0.05000983665306723, 0.076132255095628, 0.10237253616533934, 0.1445009598448392, 0.0360254991439081, 0.07865584830963805, 0.07740902489111309, 0.04755964998396174, 0.023820785798072338, 0.02145305317225716, 0.06962832183607164, 0.01363120640763232, 0.01638618977590194, 0.012563498176243759, 0.11251812199911765, 0.0316505472085649, 0.013546750002029925, 0.022651310446822358, 0.05221720409369277, 0.02268229295770007, 0.05274890741753963, 0.01140720432534093, 0.01707040205327494, 0.026356672808047266, 0.025846573163665114, 0.014765042391034865, 0.0207024670371245, 0.09106312487875262, 0.018973232307020697, 0.07242697125841534, 0.05710998933101374, 0.055479827006497694, 0.06284400422666823, 0.014840532695093464, 0.06273540743296185, 0.0358473492275563, 0.13273723543651644, 0.05779554226225423, 0.042032298797200766, 0.03586955045560195, 0.030715992719295527, 0.060779025718089075, 0.04666348416057806, 0.02824552770283434, 0.02913880728996329, 0.03149158779471632, 0.0418467101671042, 0.08577348694445626, 0.038954965740201936, 0.018102401011292974, 0.0658577366641933, 0.01991721350819834, 0.08006883619893944, 0.0025651269102273814, 0.06004425929859281, 0.016971921450608683, 0.07356175431801427, 0.00599403279803453, 0.029945204845599593, 0.04692945073569014, 0.03442174770058163, 0.06105314729915512, 0.10357635906867443, 0.010206598033677908, 0.05766897687628385, 0.02943770606972037, 0.056453850345626, 0.03408231712397068, 0.05885641698935821, 0.029543797755914352, 0.11021921471241983, 0.05538444522948516, 0.13320608124617608, 0.05716899725338144, 0.020908805158650203, 0.035403401275435765, 0.08828145196481098, 0.060006491163925785, 0.047405015136445725, 0.07862748773468119, 0.04034352308559803, 0.05409793462604285, 0.026275689653571577, 0.024707783464222186, 0.02860834311333395, 0.027686561224982146, 0.03739801843860938, 0.019067579865335457, 0.03781811424320744, 0.008432456187062688, 0.11547136796458114, 0.03417553087215751, 0.042329889481827136, 0.069184749267034, 0.029800002455651283, 0.03194847114143833, 0.0977780847179313, 0.014345047135476865, 0.03908778240363445, 0.047248399951645446, 0.06194395050706883, 0.025576707201018452, 0.058938660358469334, 0.06247927359635792, 0.024954877463319612, 0.09942231624717675, 0.06539791537028167, 0.047121930326665604, 0.033556677386044495, 0.057119193877423965, 0.05102958394995621, 0.03439662767754447, 0.0899474940172607, 0.046828384586279435, 0.04102780048044459, 0.06817346724170832, 0.06435074212570345, 0.030787112491746104, 0.034859927010632334, 0.044518798033917145, 0.04360932909372834, 0.03539608896619851, 0.036610005077936, 0.055843105900191495, 0.030284388358854962, 0.023764399811625484, 0.01202921122087226, 0.015972000509200078, 0.051036992020184, 0.08472017733560455, 0.036201105648351294, 0.08260615770855258, 0.03154872646254878, 0.10581077707390632, 0.06169424797858923, 0.024085733476245118, 0.0787075822271647, 0.06919885294572001, 0.07888718388013302, 0.11646378124433181, 0.056608377940832615, 0.04524905602597902, 0.041130084709654895, 0.01617383594895082, 0.020616466006744775, 0.06943562774047737, 0.12665979098528624, 0.02511173779625566, 0.030058649060646855, 0.03478778451080284, 0.07271528844871829, 0.17408635617504198, 0.06303097947590774, 0.07537266359694543, 0.0925113298299332, 0.039973138726406524, 0.12366389690507805, 0.5751664335689237, 2.280079664722566, 5.9386822100608585, 5.322334689478721, 7.978934924448691, 7.532036737088235, 5.303878957225431, 7.443573071110634, 2.878580891316937, 0.565584818682363, 0.039823609854905836, 0.05164269560707673, 0.0561423130303381, 0.08959724627915891, 0.0748175562870118, 0.05880201325541543, 0.06560915645452277, 0.03117490811423669, 0.038908268850777424, 0.039908503888234984, 0.03095117788161001, 0.10980419424032012, 0.10654567755878934, 0.04188825511523793, 0.05612559316139068, 0.028095567906876246, 0.005668004929658867, 0.023958141532456203, 0.024037272669374946, 0.03292539795379966, 0.07433544949538286, 0.05897551301806685, 0.036466218035427794, 0.015961861335522225, 0.04464930877269757, 0.028835909531241464, 0.015300037977736325, 0.01604455286606906, 0.0274772085474744, 0.015530803770337616, 0.03989197554126863, 0.012099673115317861, 0.07255730579697317, 0.08909121456165468, 0.024417493597514207, 0.007903133002635574, 0.03804117606412019, 0.05168181588693012, 0.06238991710086984, 0.02894009174328418, 0.019793381140897834, 0.053152179931320494, 0.03432296832362491, 0.06669456514740182, 0.042072882304989526, 0.08215021281953781, 0.06127920069341218, 0.01939043421448479, 0.053141772626869144, 0.033730230774850614, 0.01696885135325213, 0.028363445871359402, 0.03687305285805657, 0.04907768767988009, 0.04795256881944595, 0.045394834897090355, 0.056976847080213416, 0.005692032319794019, 0.059860298605335344, 0.04797750115094166, 0.01902800567838694, 0.07333118483544358, 0.054698313901861834, 0.02370132779281947, 0.020366106557870106, 0.06892838560405277, 0.11499904411574526, 0.07101736947773926, 0.07226926439832296, 0.02810226160011465, 0.036019519827659094, 0.11049016468947935, 0.06403409117352098, 0.03567195722773191, 0.040413206443190575, 0.009431470271890924, 0.0452932937731666, 0.041054142413720976, 0.04467624825455489, 0.30877051214056633, 0.2322278331003843, 0.2923012152314186, 0.17583945645920693, 0.20597874968042298, 0.24793986741813923, 0.2533042755338454, 0.25477229917962707, 0.13127408410993316, 0.2203612843708646, 0.09052049714110552, 0.22185331721219326, 0.10685870108465034, 0.28235144913196564, 0.08830471039419213, 0.1729597779171121, 0.3879384672449481, 0.24131901381957918, 0.1547618955373764, 0.14819826870676012, 0.24070819659579187, 0.2765355241154471, 0.06215069082475478, 0.2450837843841122, 0.07026274222880602, 0.19067782878635392, 0.26531742284855536, 0.15290535806167513, 0.13603378838348773, 0.26088238663731084, 0.16942547724371956, 0.11680666687748126, 0.12127901923151747, 0.3683121219998406, 0.16621088038288778, 0.08792254743316481, 0.2075535353393324, 0.17920662739103843, 0.15639349427675048, 0.14465370245518225, 0.16631462400959385, 0.09093310443624374, 0.2620643377304077, 0.18440559115861693, 0.12833779933111322, 0.10593491396115673, 0.10682367554475224, 0.09866855467759794, 0.22154924159328784, 0.22077400657919147, 0.17997107588716094, 0.1341850496828556, 0.17485167801139817, 0.24745455071810754, 0.18913266008659718, 0.1337054173552221, 0.12822222730685628, 0.13819907461443257, 0.14763030644145705, 0.20030000036762607, 0.21804579894148537, 0.12323461953670749, 0.11559089300252738, 0.20163287078180622, 0.13664469753782596, 0.053201370436938546, 0.12271187178069547, 0.24491452491812168, 0.17246566652770967, 0.35416281511706693, 0.10403601182324272, 0.10029295985136302, 0.1118557164145093, 0.14164587272511375, 0.31863024758715786, 0.11971232346108845, 0.1394889215307851, 0.15158286047798974, 0.16074648247130457, 0.3739224290174823, 0.16459930718185442, 0.3179883271936448, 0.17384486993955028, 0.2744752072518872, 0.3041045157419097, 0.1759382051926467, 0.45160815720596625, 2.94337427904529, 8.309235265178065, 30.486226004938928, 41.52449346357777, 35.31804084777832, 32.71376944357349, 27.99412262055182, 28.264501402454993, 21.859261105137488, 6.040675111355321, 0.3920533399908774, 0.35971385757288626, 0.1428270270867694, 0.2006991628196932, 0.23221822635781383, 0.19098348254638334, 0.2992414508856112, 0.14264155720030108, 0.2055990611833911, 0.24098769611408635, 0.2260489815906171, 0.25896097683618147, 0.3073820543866004, 0.1585511196284525, 0.1930716543668701, 0.14422202723160868, 0.27585499289055027, 0.1401673536747694, 0.09659204271531875, 0.18145535591869585, 0.25566431663690076, 0.11242727163217722, 0.11910237191665558, 0.1846149629883228, 0.14330005573649562, 0.10122254626044344, 0.1023990351466402, 0.10873416093208137, 0.11839209349765895, 0.14939759467397967, 0.18180435493348107, 0.08654655392972693, 0.24567857504852358, 0.1710820351276667, 0.1246622320444834, 0.11247293047246434, 0.13252234777375577, 0.1531117115049593, 0.1271510601884896, 0.14403085765098372, 0.14621456063562824, 0.17803711756583185, 0.15597988340643146, 0.17466352681719488, 0.18095706168922687, 0.3064981421395656, 0.1876707957877267, 0.18708931973143933, 0.11508143687200163, 0.12066017340628371, 0.10977001139713873, 0.20853613503277305, 0.08783777980434318, 0.12081164431067244, 0.18046851209815473, 0.12119518622996346, 0.22291618759834, 0.16913995627434025, 0.11702199887123801, 0.13316748573655082, 0.09299652395589698, 0.27308377707677506, 0.11359498881164098, 0.16334598733773156, 0.20082303923704933, 0.17889423205727534, 0.14574067396742685, 0.16945232096458637, 0.2381198612913009, 0.15831214616135245, 0.19615479053989535, 0.3160976834835545, 0.22778797053521682, 0.07823287584488431, 0.20551831551617195, 0.2160238630829319, 0.21757679991424086, 0.20274567477885755, 0.20335520497493206], [0.029124083080058618, 0.03357877519222037, 0.05965004194407694, 0.029455582731433456, 0.06453538463721353, 0.05215892395485313, 0.017285080957076242, 0.058987088606602726, 0.06666866371468191, 0.039566418816966396, 0.041171798197131966, 0.020118290520904046, 0.02455535303470829, 0.011160727027022551, 0.05064965413522817, 0.03857700094099968, 0.033585669983538895, 0.0496180975929864, 0.040098083836417046, 0.024678061167979916, 0.03600956834552269, 0.05456730520593063, 0.04314871106837546, 0.06223401054739953, 0.011866531492541394, 0.027027882658125415, 0.03197441853943371, 0.013874673938018181, 0.027353194234291875, 0.040887177381063664, 0.04720578248041773, 0.03577911377614064, 0.02928348874012309, 0.0419542727421128, 0.059263508451441606, 0.013751273452784988, 0.006136326447895338, 0.04856389932214253, 0.009175999101341493, 0.09063153392485074, 0.07766237782855188, 0.04373421291670492, 0.020828674276990276, 0.03334937016329458, 0.11795180744581646, 0.0342957990153903, 0.06133462332429425, 0.06386900305627816, 0.03647842564650121, 0.03840653871696803, 0.09492703488156681, 0.04318457547455065, 0.023299394017686288, 0.05608232834586694, 0.027790182277620323, 0.035644094609925826, 0.015812640814411066, 0.04991248219964966, 0.017125623586076884, 0.0303364402028702, 0.06050235306423518, 0.02860974122379576, 0.014880274463775418, 0.09979802108700238, 0.03450844587097245, 0.09268768327010256, 0.0286427328002549, 0.0367965130135417, 0.023818355384132555, 0.056500198665044965, 0.03338571720486207, 0.04046153126945419, 0.02084911350281008, 0.03213763357170167, 0.0343230027975815, 0.027970157398451722, 0.05859836027206433, 0.021186153885097276, 0.05758846869632121, 0.03421997929352426, 0.027377701386989608, 0.010677050712758736, 0.06505065537508457, 0.07751502081631653, 0.01599940347425159, 0.04747808843310322, 0.02298606022621595, 0.0296163979932786, 0.04192921783654921, 0.4952518185300212, 0.9825559344983871, 2.1252909254643226, 1.519873824811751, 0.37980831318324615, 0.3698404674087802, 0.09563292361675732, 0.19912233936690515, 0.027140495667774833, 0.07996178307240048, 0.017645900708533103, 0.06538629381647033, 0.034883618279690706, 0.056850438742267514, 0.05875951835825559, 0.051213598269368374, 0.018697986491925774, 0.06969454247624644, 0.049630408625929594, 0.06625295376345035, 0.04302047561073015, 0.05523964312047728, 0.029301907409042604, 0.06249297507888368, 0.062437472008769555, 0.028049144893884662, 0.08913036165458542, 0.053756562016543843, 0.0719495912292792, 0.09388975183209104, 0.024842099744766474, 0.045130438802223054, 0.04369011689578334, 0.013811351983026873, 0.023960435965789423, 0.0737584856969695, 0.021786067762502262, 0.08527487095805907, 0.04994306442958694, 0.011224070049431777, 0.04346325910920578, 0.028447255890275684, 0.022131950714655464, 0.008667017945328788, 0.0187857591006304, 0.018956104496253595, 0.02881393429913348, 0.017542243266718525, 0.03949047652103248, 0.06820992536602483, 0.05704378784303704, 0.026475232575208913, 0.05054086964998034, 0.05163136899711625, 0.029380107749133345, 0.047644118838492906, 0.03343804101009042, 0.054043875631665995, 0.02931375687401141, 0.003854869686502723, 0.016387651088617502, 0.04382764883038979, 0.01420508574454054, 0.02669349677049585, 0.05162884473740574, 0.02938671334226045, 0.04148773285710523, 0.02495127110441606, 0.017484480237227776, 0.030293543109550115, 0.04852830687718046, 0.05459439407493319, 0.03932327783155826, 0.023140179879602887, 0.004017232924759869, 0.019351474813095505, 0.025828916752230258, 0.07841725022562089, 0.01679126259630486, 0.06398611874770253, 0.029956680842705315, 0.03676165984342656, 0.010704313866764067, 0.013038308938003838, 0.0077104015602549964, 0.0411649493710889, 0.05994649881857538, 0.02112823572280186, 0.05677212923464756, 0.06448320638869079, 0.016597156983710105, 0.06198164203294343, 0.0668711713965862, 0.020466377891059366, 0.08411799392272389, 0.036831699431903904, 0.03639973309491912, 0.049987489868315964, 0.03182828726787721, 0.038076749356884154, 0.042995359418132616, 0.007986007436674328, 0.06411320507346142, 0.022581050608066783, 0.023464999244277997, 0.05180922013917758, 0.032482212259163784, 0.0331448974658645, 0.097872099027999, 0.036623028572648764, 0.026669016430875467, 0.04343177672595747, 0.009888596851528894, 0.01668315035321059, 0.015272077683719899, 0.030225376606047637, 0.04586800527308257, 0.03846735843727666, 0.08713312447071077, 0.013492369250724874, 0.04490004551987495, 0.03569218960981216, 0.01969112947042431, 0.013938875936512506, 0.009321682211462288, 0.018936986772103176, 0.04694630467002431, 0.010056665050797164, 0.04820807446395198, 0.031032875413075093, 0.04581105812723118, 0.05685452965178317, 0.030368125599418438, 0.027576206259489543, 0.033375765722725666, 0.06905808428963346, 0.033197171475377776, 0.01816038237584214, 0.03653348438561924, 0.030103049601518342, 0.05582634006596862, 0.04219148803742663, 0.035097261049574426, 0.014100269594740485, 0.061934286307904034, 0.03515765559108507, 0.047613479151961305, 0.05355117767448387, 0.043022425304497444, 0.010338887054052566, 0.05031718346740931, 0.047857554764637066, 0.061794636140186945, 0.027678685841120543, 0.03479773216249962, 0.04572029586040205, 0.053888543644138885, 0.021790951573019548, 0.035785686810530966, 0.024213547585532073, 0.04729849061057453, 0.07849496984553915, 0.01969441407239966, 0.08264406373904598, 0.04876593969041302, 0.0510377083123932, 0.04898063583119262, 0.01949142183988325, 0.07864085596895988, 0.04458962286251687, 0.031490710624043024, 0.020118288605684237, 0.030176530839995514, 0.056350769384974436, 0.08527005226501534, 0.034829551624434615, 0.2063852512548047, 0.6570071775105693, 0.8996049759368744, 1.2549240935233332, 0.5665998545385177, 0.39941109356380283, 0.047254896377243345, 0.11318651073041464, 0.06648651864980498, 0.0860417019876261, 0.02570292210176347, 0.046275927940563816, 0.07050410589022983, 0.0034875697888163554, 0.05044851008982909, 0.002903255137367054, 0.05702635551232004, 0.021584477470887285, 0.03765885988550802, 0.04995763925234637, 0.04167673440890447, 0.0593920273616189, 0.0077469966227879695, 0.04018841326356896, 0.045426217688908505, 0.08266855556998523, 0.014788635026272989, 0.036151895990535136, 0.03520499216392636, 0.009277877303951932, 0.038990378154501806, 0.007871505062681654, 0.05311816179704282, 0.013445139930192983, 0.02881011152039132, 0.020370833320362915, 0.048853116665756514, 0.03894293815979073, 0.008004841229487813, 0.016332450623233474, 0.10269316694428844, 0.022657180595542156, 0.02161671828118063, 0.019271991275731596, 0.03475930136177809, 0.025883400925405087, 0.027321451381149314, 0.03625374738006823, 0.06335670473955332, 0.026574958070752122, 0.03395177574167329, 0.022794814036798575, 0.08396602506118436, 0.030185978619321704, 0.05639524078897892, 0.030316483612442692, 0.035410116036092086, 0.10329685955037994, 0.029367854172784476, 0.14840937189517484, 0.008708512140137535, 0.02834310240653013, 0.017742192214955727, 0.022336871573521246, 0.018041018216360002, 0.017412895066363197, 0.038186614026105216, 0.012944856744950578, 0.05956614765548899, 0.056880921380774635, 0.11305385494544623, 0.07712967092952422, 0.02095411542893177, 0.018255471124223644, 0.06354532707783003, 0.033030409456020406, 0.021202655418986277, 0.04977206977444792, 0.011492224763177577, 0.05388934420601976, 0.07026788267877794, 0.016265366218924042, 0.007504669126994427, 0.032574793984813076, 0.0705777116179947, 0.03790258692817823, 0.020007290126335238, 0.16918941491073178, 0.1569417067953656, 0.24427972914230442, 0.1407277316696221, 0.16507664124571508, 0.24944766634894958, 0.15525692623228798, 0.13829111241765563, 0.25599515936788053, 0.1200354133822745, 0.14112661833003645, 0.13285689837028905, 0.13690630124220926, 0.10162947684406273, 0.2812904173568372, 0.14089395742743246, 0.14010399820343142, 0.21090572159136498, 0.14248499947209514, 0.07408506897909027, 0.18002709223618432, 0.19672973952706785, 0.1427845398504888, 0.09916746943828561, 0.19643746166219636, 0.09580733885447826, 0.07096656252660098, 0.1354773021152904, 0.13746508577417943, 0.13242545297309277, 0.14650585790795667, 0.186405586259019, 0.1425891567862803, 0.1416442332969558, 0.1327639872268323, 0.06722182516128787, 0.18315941125394838, 0.1031581669925682, 0.12754352703209848, 0.19436137870915476, 0.1325470158049176, 0.11645683282685858, 0.222122443899993, 0.09655819695082404, 0.13073777659766136, 0.1159640008042897, 0.19308521412312987, 0.13921783365789922, 0.18697534117006487, 0.14099911065591922, 0.16885883264964627, 0.14851613390830257, 0.14620331446489981, 0.22031879713458402, 0.15282989840113348, 0.10678621384525493, 0.045858521104579976, 0.24475410610677736, 0.16248493515435727, 0.13465625504332204, 0.12224589113987262, 0.14542665452726428, 0.16962654468032623, 0.1881479766340025, 0.09603718821440013, 0.2498627634298417, 0.11674138852545332, 0.05958070332605032, 0.13337158688133763, 0.15240095045057037, 0.14161780326356813, 0.11507109468502384, 0.16960595223692157, 0.11407948579759368, 0.2579022739683428, 0.11870050517421578, 0.17941252118156803, 0.12184502797261362, 0.20081301880699975, 0.14879007162826677, 0.1604817378064317, 0.19489627661964587, 0.2411120168624386, 0.172151233400068, 0.1774299469205641, 0.15912059874784562, 0.07305429767697089, 0.37658752633198617, 0.4137300123130122, 1.1101605647033261, 3.1228364427243513, 5.625592249055063, 5.519104311543127, 2.5035449381797545, 1.4117772252328935, 0.1450464144469269, 0.36077574736648993, 0.07727061578583333, 0.2519324725313533, 0.1100030630045841, 0.1708937920029125, 0.11206580070598472, 0.13554467188735164, 0.13534178116148518, 0.10143345026599784, 0.16534123269300308, 0.10477180863099714, 0.15994674796538969, 0.2235540324040959, 0.12059934602509584, 0.14024600026107606, 0.12234901423536002, 0.15453047569720976, 0.17692010008519699, 0.179039359753651, 0.16756684068710576, 0.1825949883148555, 0.2958659142736466, 0.10421349907354002, 0.0902433724953763, 0.11122600746250923, 0.13099510553142718, 0.12310659858368098, 0.10058817949386374, 0.1159500043779131, 0.13812571403480348, 0.13482594351855018, 0.16465356152865196, 0.21992090638847123, 0.19375486689950192, 0.1126217200691181, 0.09829224462831214, 0.11100348956402271, 0.13107508511072205, 0.10166005907400001, 0.138937522086405, 0.07727468371271126, 0.14206688400478135, 0.19510547991000837, 0.16222679416739172, 0.1143936048291864, 0.12845242140634408, 0.12958694399604875, 0.18990138335333717, 0.10245829204758329, 0.15390953079106348, 0.17291076361171662, 0.12836148676973197, 0.2808888034234124, 0.14581729808161337, 0.08087138224753641, 0.10269948716966376, 0.08667721788609221, 0.12453911405417228, 0.10494566462453335, 0.12260262764269307, 0.11591585217824868, 0.16153492484121554, 0.09287743558806759, 0.15594531751928792, 0.1468503523257471, 0.13210198000794457, 0.11031600226077343, 0.12883599396915207, 0.13257900763663555, 0.13182298610768012, 0.22344325609024496, 0.16350412320706154, 0.16742866906908252, 0.22990808822214606, 0.08007767685358563, 0.15972726377508334, 0.10458737296322662, 0.14430456554457066, 0.07780825629109338, 0.18577966178136487], [0.021001258564572182, 0.032858506986691106, 0.035124388222973195, 0.006987227008662999, 0.049381127445808345, 0.02565286400157117, 0.03476896173050327, 0.01696266136282394, 0.031958334523463444, 0.028757628751918677, 0.08720498351800827, 0.08006820034596228, 0.011339881476165067, 0.048210614045420964, 0.05782788266397773, 0.020790402439513037, 0.027960196340216265, 0.02332889797887014, 0.06274204175438612, 0.04634577217662046, 0.049900355027808305, 0.07481466813553726, 0.015542111228099995, 0.012216061980824077, 0.039811923183620944, 0.01641798817041901, 0.08084642310296336, 0.05606491899778766, 0.0784094131461555, 0.014110508359848492, 0.007004760367225015, 0.011790351709350945, 0.03367121519160367, 0.012422080260641392, 0.062305697224914074, 0.07754143552794572, 0.02288086677811319, 0.048214291267457514, 0.021156169203740936, 0.04046080731636575, 0.013707319158129396, 0.03581766715093005, 0.11069544560966954, 0.03359869347825166, 0.009303615942987944, 0.031059215431131666, 0.026193371590887828, 0.04557567378205638, 0.005716680241147838, 0.09272422566409073, 0.03426283042156889, 0.04098602570593357, 0.03711707484457762, 0.06044821363062628, 0.043247421497418996, 0.06189587465938061, 0.03258195307646548, 0.057086102709534674, 0.038022732497343135, 0.004046967191125957, 0.03432548492245617, 0.014243445682129072, 0.020151741750117753, 0.05605315954814996, 0.04107714037320787, 0.04227393441983769, 0.057251278926888784, 0.029039665936462344, 0.06108286768017758, 0.06142327884933161, 0.024714846794884053, 0.027539014605985537, 0.012937349083292629, 0.05983054758079591, 0.03128524392753119, 0.03208335049660697, 0.11215783850920778, 0.01719182124361396, 0.051350954003752246, 0.025693755859749454, 0.01408774597239831, 0.04374326041509067, 0.050918934040612755, 0.09075974639985832, 0.09082074998126877, 0.01318798240860023, 0.03541669290092203, 0.03580635203228843, 0.012758256878793962, 0.036525815845497196, 0.037992498837411404, 0.05874119736554642, 0.09871795202695555, 0.04164637817490486, 0.0849491456944135, 0.07572867997711705, 0.039797555204601064, 0.02392608841370431, 0.032800789922475815, 0.012525685991521084, 0.030051401868883162, 0.026484724404590747, 0.015772990018670118, 0.022576314269474918, 0.0312698187471758, 0.04783439975712569, 0.03136451679071592, 0.048607405455362414, 0.01562538977351881, 0.04188754265346835, 0.03439992185561888, 0.07225788799264739, 0.04084084055296356, 0.01878692738471493, 0.00892213480021324, 0.04215663103687187, 0.026570683300134637, 0.012974164396103834, 0.009298279182985425, 0.05859027038358393, 0.05908410981177323, 0.0338583896237035, 0.0018568472625056824, 0.02864545815804553, 0.03198198174246617, 0.023621748494465026, 0.03103869193564019, 0.09903027075192622, 0.042229692842210495, 0.02181818599872772, 0.0028130401445988326, 0.050242217933578845, 0.012192018311320534, 0.007345180154868192, 0.01872033902233647, 0.06365180180798616, 0.049148244377706325, 0.03426086540604311, 0.039536809518692956, 0.016100534741135857, 0.04500922454040378, 0.05238707643002272, 0.03187750075613299, 0.01408380157719817, 0.060910501727654096, 0.05151242235555284, 0.03203414083879081, 0.026069703932491042, 0.042130836856461344, 0.020821346645994533, 0.08399762618806093, 0.02552002435550094, 0.08856832124893704, 0.06457869924845235, 0.023568731379665198, 0.05105917026559192, 0.06234984304155074, 0.014033574937662531, 0.07690331493053706, 0.04805281142433805, 0.04087085587783687, 0.021575868557838183, 0.027577196428131674, 0.046694545195468014, 0.031925352523103356, 0.012074893043797103, 0.037342193611567064, 0.03474103782566325, 0.01831598823980218, 0.04259443113340005, 0.031885964112476475, 0.010050386960257687, 0.07959174728321453, 0.019394404465152372, 0.05593872133402094, 0.02815189643672878, 0.04229555725150051, 0.03691972293440373, 0.048097696515821645, 0.02973498648873741, 0.029295681029438015, 0.013061820176400006, 0.06499937344943324, 0.05670395890070547, 0.03824842583027579, 0.022248616329424327, 0.043642178943921486, 0.057375400492380706, 0.022850345835209857, 0.058616845973677216, 0.05884238225858539, 0.02923778968021995, 0.01918933038870173, 0.04476433687452828, 0.06951922325477486, 0.02034612698480487, 0.023541253721041065, 0.027758891416353085, 0.027495613809855237, 0.02689359510587829, 0.05871858628046128, 0.012085740848804915, 0.08997734080279067, 0.024907464281685894, 0.011519541543337607, 0.039970825140875195, 0.016978101864937815, 0.05603093150702696, 0.025672878048593, 0.03472500743584768, 0.018901020859278018, 0.0982098748546935, 0.03576083491826731, 0.024628891729779785, 0.04483156108988389, 0.06752599271074419, 0.01373416766704571, 0.02653749637125481, 0.0655878821928655, 0.011266832119755207, 0.03569092173429747, 0.02966301827391069, 0.015398916946123204, 0.07314475733906993, 0.03724459401001373, 0.11506125811607608, 0.018165584112848007, 0.062056883358426636, 0.04775196486603349, 0.02509972170716332, 0.06039820341092925, 0.05089653746014641, 0.031013979854422714, 0.06431582383811474, 0.014446787442260934, 0.02630359057577387, 0.10284432375262823, 0.05879749333666218, 0.03541088978489561, 0.01874408391754954, 0.0420191144240239, 0.041276633499130126, 0.016250461978357167, 0.03411220221389686, 0.12217221646419457, 0.10041474484868589, 0.06913824773003018, 0.019433170429340774, 0.005306482771336432, 0.04003642524983134, 0.07008778306865884, 0.03928657072866636, 0.0667033828194103, 0.036904550563063354, 0.028170309359988863, 0.025820995403093197, 0.08867147498794141, 0.03423523210409669, 0.031889591538797946, 0.053460162598639734, 0.09982819729033979, 0.047822529224738966, 0.017085055400046612, 0.03837956476115412, 0.00818331960603715, 0.10069428267137659, 0.14231194021000018, 0.022810513093586893, 0.11354137031782059, 0.06599308141777593, 0.11892158282740463, 0.13038811874726128, 0.021547619065630342, 0.05664312002819873, 0.0242255081332499, 0.04150612662816721, 0.06216945231802041, 0.022182027967045867, 0.0263015374601368, 0.06208073933638873, 0.056229378922932574, 0.021379357429161187, 0.04841302213589511, 0.025748251524243145, 0.04359007730419117, 0.04370635412933846, 0.03415442514984358, 0.04141536436133808, 0.01413041323934111, 0.02522953913637227, 0.02103842723543846, 0.05437012949597932, 0.018217588076367974, 0.01660058714239107, 0.020706082972127105, 0.03811368245571371, 0.03260512340573534, 0.031815905371801026, 0.03347674377202507, 0.017643194502940582, 0.07988890512816368, 0.05946454524453129, 0.0548233202989063, 0.05577836764015018, 0.032417899177920435, 0.04203010012485808, 0.005441378405873454, 0.01107039568465083, 0.06048168784247772, 0.05588749686496393, 0.042462981936912385, 0.061619853180262356, 0.004552252451708962, 0.04626625608051977, 0.02063450163170215, 0.01863090974849559, 0.011385647568761582, 0.055412189103662975, 0.013736804924725045, 0.017153244886186816, 0.054107721399275534, 0.06908884271979332, 0.0341589565599157, 0.03735802864896194, 0.037389212257919774, 0.04496845334107357, 0.09345397803812258, 0.02877984530172281, 0.0501884462221736, 0.017970476840292255, 0.05444368542802911, 0.07358954798790716, 0.054477374144499345, 0.05951450183807362, 0.0457747302378618, 0.04614388502593483, 0.04616101475192174, 0.00593713736311803, 0.04900323925539852, 0.05347305585840537, 0.03316269368834553, 0.06903307151890571, 0.06066417764692057, 0.019094739597471013, 0.057794059882120746, 0.010328279609130997, 0.0412450745070894, 0.024212748938871008, 0.0322840214827128, 0.02156428339320325, 0.015480403803409109, 0.03974038589325163, 0.19519901924556304, 0.1347597075566169, 0.11498651091730404, 0.1613702619027707, 0.156964689433094, 0.15568752893276755, 0.14357439182218046, 0.16640480788004014, 0.10999491182906974, 0.08924620947049511, 0.13095306262614267, 0.1663465085890024, 0.09457035966578031, 0.20435288127872253, 0.10460623404792241, 0.14662758927912484, 0.15229395861106534, 0.1386962503555321, 0.17873137708633177, 0.14708293661955865, 0.09865317163207839, 0.17521946150208675, 0.11206970775439856, 0.08516911252011215, 0.15527753399745112, 0.13273017210585455, 0.12791827426201877, 0.147183723146877, 0.11198164594750251, 0.060121595874548926, 0.10859467164282838, 0.1226001991439731, 0.14694550044594273, 0.12375193572933636, 0.27923408415048356, 0.17689944635475838, 0.09418144747014008, 0.11020692666211437, 0.12010734903836444, 0.3875657501480272, 0.11246539982816867, 0.11047013915113865, 0.21215275951450874, 0.12406010225775743, 0.09007538473534007, 0.1545305369842437, 0.06616651606295379, 0.22046654485166076, 0.16220355105976905, 0.34976966859352204, 0.09825265320438532, 0.13681355863809586, 0.23292302724815186, 0.19420863609881173, 0.13406075957802036, 0.11303170734355528, 0.15900772335308214, 0.13062568261258065, 0.1300419389360374, 0.12158074296049534, 0.1652758394277865, 0.16482357176080828, 0.16162881657721537, 0.10475909157145409, 0.23273213345917965, 0.1107141228332635, 0.13041503907692048, 0.17307579427236514, 0.19351025502527916, 0.17079352641538267, 0.12579675463418807, 0.13542062693065213, 0.0852495134477654, 0.1585835864346835, 0.10520408906403089, 0.15400785051526564, 0.27005864908137633, 0.1680823259295956, 0.16157831606124679, 0.038729892938487956, 0.17074529351966997, 0.20298449502837276, 0.15317194133756623, 0.20818316768254005, 0.1618616306974042, 0.08884703169666952, 0.16013165094679402, 0.14924975502635204, 0.21555725425001115, 0.2425867361166785, 0.37873444177450677, 0.23875669486099677, 0.34778090434208997, 0.22811839957871746, 0.49970566986068604, 0.2898953007834573, 0.2569284229989975, 0.15986811670084156, 0.20456700285355892, 0.12820502863295619, 0.1358646514915651, 0.10329614708861036, 0.059512517670349735, 0.17973072346179716, 0.13561467700187238, 0.1551969568695753, 0.16561445029031846, 0.13804648522167437, 0.1552261294977319, 0.18167441109976462, 0.1352926902472973, 0.15269767162540268, 0.09096157992438925, 0.07119582199882116, 0.11566346451159447, 0.17883576422689423, 0.059286686441590714, 0.09570452219416058, 0.12792972727648674, 0.1511143364252583, 0.16696135543527144, 0.14846145055226742, 0.10535619582139677, 0.08955781573369619, 0.1734163050329493, 0.14791351382530507, 0.17668846574041153, 0.2221126379745622, 0.16517952685394596, 0.13445227647260313, 0.09913671866900499, 0.11385581876722076, 0.11308258324260674, 0.1651848128606235, 0.08375443923737734, 0.21717095717547402, 0.1760852174653161, 0.11220582625678471, 0.1313705039360831, 0.11798982072861926, 0.16350283617934874, 0.15209348872303963, 0.134408762678504, 0.13762624002993107, 0.11257084417006663, 0.14162273686980048, 0.189128048237293, 0.06382466571766042, 0.12578360090452817, 0.1320787369003219, 0.19917089401954607, 0.11868897555095535, 0.18316786886463243, 0.16478039504539582, 0.1759382818014391, 0.23010572358485193, 0.1456685238067181, 0.14614884561348349, 0.15479963302852648, 0.10835344587723095, 0.1290139715157209, 0.08105604774168423, 0.14644568936238367, 0.13644569853861488, 0.27728356300823154, 0.09289022925640307, 0.16712612562602566, 0.14336050007372134, 0.11656393191867298, 0.16978130976278938, 0.15737105311164934, 0.15467191084979043, 0.12227245906908667, 0.17865849148121574, 0.07685368775480217, 0.19137731302649746], [0.024608272473297776, 0.015830728150303328, 0.05414591471274054, 0.03293379810788939, 0.07458853430204815, 0.034708739558775584, 0.06598494556402007, 0.03831626674641044, 0.044875262575524474, 0.059487275073244694, 0.05263551491342726, 0.08227957442643181, 0.02052522301974316, 0.028111552331416358, 0.0824677256206351, 0.062014614457204464, 0.07302517101408974, 0.04906865933369245, 0.028290724975147077, 0.03285820821240064, 0.049441679035343473, 0.02979623138784401, 0.0102786869073527, 0.026087735727008794, 0.014558459121373393, 0.08935591326125207, 0.0587535964986009, 0.018669746575816985, 0.029376039822255413, 0.04757129068997118, 0.010717979917723325, 0.03879646980954755, 0.03300688672630537, 0.03216593285962459, 0.012233588157311804, 0.03430817133536743, 0.022886428576443466, 0.05263632313618737, 0.05135742361627279, 0.11033369123094505, 0.06226263159225064, 0.028880380935245947, 0.030922608547693783, 0.04754386857272156, 0.0300081332229198, 0.01564512324083837, 0.04626616798040848, 0.013859545616733452, 0.040538680153868856, 0.06508643168114847, 0.059458600402238874, 0.009514418441892393, 0.029292593695103165, 0.05320741870110074, 0.06645736900428612, 0.10140747988536473, 0.03724387005692528, 0.06631961873462124, 0.028869824243649363, 0.05165405286055419, 0.04831647590523766, 0.022130077629680597, 0.02948842492074736, 0.007030989302532568, 0.0649460843734203, 0.08103625202972083, 0.036581778568365884, 0.07510468604103213, 0.029863706496994824, 0.06287809896973834, 0.016478915143037037, 0.060593057874469995, 0.026528136692039912, 0.028608685937680067, 0.03066705119225287, 0.005151304480199132, 0.09741430786708671, 0.06110554005229666, 0.07522548278493267, 0.06492728457575844, 0.05528975676204409, 0.013538626597202836, 0.0616991815848216, 0.058820836035715, 0.017321943192772808, 0.047850307572873375, 0.07365145555306828, 0.07087905230301042, 0.028190338728769172, 0.04429144612062843, 0.03771140968667404, 0.0596659995555397, 0.07357159088696204, 0.114994807649524, 0.08158183686675564, 0.048029361472975825, 0.05740383384569038, 0.043686983596173026, 0.01424374062597992, 0.07145430006447338, 0.0633175078509075, 0.012059646936494016, 0.014204560016702502, 0.024936784381767916, 0.037049808494386174, 0.10429534790737015, 0.019244758765243234, 0.041725028591651114, 0.03758709659920104, 0.06513321667068428, 0.06943535194882462, 0.06194083635965663, 0.11214152083642061, 0.059870790179458365, 0.047987376024285634, 0.036636875611880136, 0.0231137651679737, 0.028971430485046683, 0.09557106967775092, 0.03799735966529097, 0.007301648166180859, 0.05707252763151642, 0.008609642747849708, 0.021661748929369836, 0.04695119614142084, 0.03812098327363211, 0.03943225383878716, 0.05795284309574674, 0.026608152660511197, 0.033242110193016074, 0.10943414312937569, 0.047326345567501364, 0.0768638230980404, 0.045621631396633965, 0.04775453509101945, 0.014313775426407736, 0.05526911835336397, 0.030758269281396945, 0.04648399359035877, 0.021659525359169613, 0.12358597810229949, 0.024185236806290287, 0.05534618296810696, 0.03657067412390344, 0.06383699973324133, 0.034895956125711246, 0.03848723841891174, 0.023047695830163938, 0.05202002455330184, 0.014137744700776474, 0.011238740633181747, 0.10082364427827059, 0.058429774963447166, 0.10454830247908832, 0.0680238809136133, 0.042391988568969315, 0.06258361477164492, 0.04212316448589967, 0.06061923509884266, 0.03951351661535521, 0.0581114960744256, 0.03996567319958441, 0.07112174129654324, 0.022726220439278313, 0.043337973090068954, 0.030164269602767406, 0.041673091660824516, 0.09073336999262534, 0.045226180640560006, 0.010097550205706109, 0.025081354749178695, 0.0803502279544069, 0.05296545366065637, 0.04505763363633906, 0.02757445191814294, 0.03133003517324406, 0.04503017321469323, 0.027675722996073387, 0.03392464856827452, 0.035556346899078745, 0.016140407702374845, 0.025267002751089396, 0.029396285610874335, 0.03916367873429291, 0.04173534396555155, 0.08414100720396928, 0.0891148943393942, 0.049147911129459265, 0.012655511081609274, 0.01668962762661038, 0.04871529744817846, 0.04526269622147084, 0.07797749277444617, 0.022659972986026157, 0.03515639154601001, 0.08243696719047525, 0.03924791393200717, 0.030469618842846928, 0.02183610288005683, 0.03532190484205081, 0.017816393576081724, 0.013717048474767757, 0.04434748928272917, 0.02404774892173948, 0.018757314256001866, 0.05290522765848906, 0.03298139898106456, 0.03928666265921728, 0.02308596766764118, 0.03164970068140857, 0.0328977191970954, 0.054708633106201894, 0.02422408895537017, 0.05476591733073997, 0.029198795804874073, 0.08846722062556975, 0.018810137933600816, 0.0170449277145728, 0.022087598054279244, 0.06293525295932928, 0.034399806942430236, 0.08501249350487225, 0.028514853573494384, 0.01407851461291073, 0.024146170152591604, 0.1701535059199218, 0.036912088868238276, 0.03136372388971429, 0.05866313300606224, 0.0121948039985352, 0.021344578952618667, 0.05815023714075646, 0.056989410922171614, 0.07380218335217045, 0.03510855318557832, 0.04169675228636592, 0.03727262899760277, 0.022303606120629177, 0.026387720436398542, 0.029212250224044247, 0.03415924384288731, 0.01781998461322679, 0.06352133320404157, 0.049947239608774265, 0.026750288783542575, 0.016028351064080435, 0.032784855293650786, 0.14178548458843462, 0.050182298366581245, 0.08076516415683493, 0.02873447949006673, 0.06670797168607674, 0.029478255103552536, 0.06928383507916043, 0.021976971127573523, 0.05464949111844744, 0.0027428437474994894, 0.01060141772482424, 0.041516024484148914, 0.08592724845173859, 0.016752056131559997, 0.021387424335003864, 0.021544271261401234, 0.03442474693480519, 0.06148578013263403, 0.06650911824357125, 0.10538729899112256, 0.049666748006617835, 0.05844768226867723, 0.14293152147964125, 0.1182377421026749, 0.033631677393831556, 0.05983312163622149, 0.03590140439149353, 0.030398824657764167, 0.08203085632093492, 0.05437294103866143, 0.022663110116076086, 0.021431269462130243, 0.03178641481715585, 0.04881845501762244, 0.05054040233634653, 0.013243543892918576, 0.026919726364975496, 0.032228587360511866, 0.09681977001169036, 0.013938758150494147, 0.04153404670256761, 0.06254084408283234, 0.025256903797027566, 0.047258477838289355, 0.04694849568148775, 0.053655817624061346, 0.009023926817932197, 0.04610089217162421, 0.0845125062210906, 0.05225241732513232, 0.06446265991056158, 0.06673116882842395, 0.048069021844815825, 0.03350606195688729, 0.06614357939050083, 0.05952482870329292, 0.01940431572767275, 0.03478652812660702, 0.03820970008570341, 0.13935421263017964, 0.014389869982316611, 0.14252448364371254, 0.03045239335586948, 0.05668443514995518, 0.06632691955253964, 0.048459634755647955, 0.010523021074702904, 0.034388637380494226, 0.02568558170159738, 0.062438100200867465, 0.01484571336468141, 0.02265547796513044, 0.0432241017810039, 0.0785110500310698, 0.03450531640180177, 0.05009609049246196, 0.08403452098249428, 0.0411834542248999, 0.06670051765057348, 0.06465970538556576, 0.01197287598775039, 0.04313505938156478, 0.102969134797252, 0.03299230807310632, 0.045112929862713626, 0.09480567123260229, 0.0997278321113798, 0.061265874593969316, 0.020946228553751306, 0.0679139013312036, 0.05896231715357112, 0.04061551494223457, 0.1097915001634148, 0.014708094287573572, 0.0254273813428177, 0.038455802000938885, 0.027843898447651057, 0.05269476798393073, 0.039422390456762046, 0.03658897213397488, 0.0430452355724429, 0.027553564530887434, 0.02922889539941905, 0.024297009034442808, 0.020253976183612982, 0.08477177335730485, 0.10995797106936095, 0.14965562840863583, 0.15351942349826136, 0.16209600763695856, 0.06884795403288257, 0.14241399844327282, 0.14161833952511513, 0.16945403700153674, 0.15394374427776183, 0.15573989870327135, 0.19583896313223148, 0.20500577205131132, 0.07748332775888905, 0.27047650407879587, 0.13502161769616988, 0.1876626905774878, 0.09076582147709786, 0.11253387276684085, 0.11983080661945766, 0.14836834022595038, 0.143808584900633, 0.12439151189380115, 0.140070351621797, 0.08723142121227519, 0.09865642750575658, 0.11955439443549803, 0.1270217368859918, 0.09069498132673964, 0.10641687519608006, 0.08189705140408009, 0.14868082749026437, 0.05975682310940278, 0.06695504270253644, 0.14118887063476349, 0.1575054708988436, 0.09906992346288697, 0.23874220047746939, 0.24648855981086534, 0.17396528363948868, 0.14705472926218666, 0.220974154710289, 0.15661585895765215, 0.16125637527194717, 0.11157024141040542, 0.17235668285960154, 0.15345246741367927, 0.18642476910064298, 0.1091659204253266, 0.28304825206437423, 0.2240011366384645, 0.08069389499723911, 0.14144805350130604, 0.06965940202315969, 0.15709814194950367, 0.20913173775038413, 0.08039646902151647, 0.13621702129321714, 0.1493089889446574, 0.16189864806590543, 0.20364674739539626, 0.07467649651751404, 0.0864401672996821, 0.1282725592834815, 0.16608833695851988, 0.17775380292967444, 0.1360226494650687, 0.1758754779134066, 0.06597936078305207, 0.20984740176748848, 0.09821145299581752, 0.22359581483948618, 0.07808637685112416, 0.11297851019809324, 0.0847304582355484, 0.11665167962952007, 0.194059815858641, 0.21855114117985774, 0.15829066505595563, 0.18967213920287548, 0.10548328214715566, 0.10470988574407755, 0.15260463790787807, 0.22446722453159673, 0.13901220033726386, 0.126408000867213, 0.24494346771990103, 0.2565771870074734, 0.2138653797127547, 0.17596504891351347, 0.24630286009801974, 0.1540644184475945, 0.24853867238327382, 0.2228600639970072, 0.1922308269046968, 0.14242191979240987, 0.10205174450792613, 0.14432524991852624, 0.15882798380428748, 0.1841714900107153, 0.1334220107885138, 0.10116355749027384, 0.13973639857384468, 0.09072577806129571, 0.127069954459946, 0.16129055811512857, 0.11423535404666779, 0.1554162725205383, 0.09316859496456963, 0.11647822200170449, 0.14901168554300262, 0.22570703058473526, 0.31404364854097366, 0.07859073849695344, 0.21496318370824863, 0.21657193770572064, 0.1823754428375152, 0.1281784913472591, 0.17950937001695558, 0.1614047665028803, 0.22225528354606322, 0.27025335798821143, 0.15224106790077302, 0.08409783814943607, 0.0937915776645945, 0.17933192873193374, 0.13016431382106197, 0.11205139825300825, 0.16847653945367183, 0.12477722950279714, 0.23963021895577832, 0.10347613178554083, 0.16221783093867764, 0.08414280751059133, 0.24051393201995283, 0.21244512930993112, 0.19576736455482824, 0.07420008942004173, 0.16357377592113712, 0.1330035582425133, 0.1921324458934607, 0.0965726683517137, 0.22228520694038562, 0.10598550640767622, 0.15297859606723632, 0.2257734197642534, 0.10166391249625914, 0.13878934536009066, 0.16333112523200052, 0.1907776040776122, 0.10095178014448575, 0.14484329389468317, 0.10737302953437453, 0.19393642973755637, 0.12617746202815927, 0.11480316309438598, 0.1989915681582305, 0.30304912237390397, 0.18334736326529136, 0.16776879678570455, 0.15804422989247308, 0.09990862886150999, 0.15327182388113392, 0.1913842997483669, 0.2737323777569879, 0.10896805523624344, 0.25104111390969447, 0.15035105238278068, 0.1385092942584907, 0.2258210397896267, 0.0804960910951899, 0.18970658251595116, 0.1366563880395505, 0.22705805728272085, 0.15100562854880287, 0.11489377597406988], [0.034268265815391656, 0.08042451550042437, 0.04048663597073286, 0.006585828058661954, 0.05083602034456788, 0.02170171382115974, 0.012261135721459024, 0.0512846720765435, 0.047210474768953944, 0.022894024338212707, 0.041051426632029396, 0.012360568188371198, 0.05607231557669659, 0.04138523029283651, 0.025057240216542157, 0.03673402705199776, 0.058116797402861624, 0.01696683271157165, 0.02153851794108989, 0.04747853659453893, 0.03309445057605063, 0.040067788889451374, 0.04249560579116787, 0.07013191739397664, 0.019720298268141288, 0.02238790069015757, 0.06506848990196182, 0.07062600580074134, 0.05929174645233059, 0.01951599602527436, 0.023171928478404883, 0.0448473118576071, 0.06577246341734164, 0.022039278973675063, 0.025216933159578233, 0.0421472771033164, 0.07246532928078406, 0.022676457282936862, 0.05554063906592708, 0.0831373860578864, 0.03397794530516671, 0.05647886311635376, 0.08785625784507684, 0.015574008256437318, 0.03247406491408906, 0.030997085700472517, 0.06780955249503737, 0.09486817634634434, 0.02365904740027843, 0.03887314371944916, 0.06776210866988668, 0.03638582859909342, 0.03467579777803152, 0.0648096747576229, 0.03127279499876163, 0.038323862508179686, 0.020943623854808753, 0.12974481939548446, 0.07958315943758335, 0.0355365090522795, 0.05801678079390719, 0.03222477224264895, 0.0197775001382275, 0.016454997878041, 0.06530361760768198, 0.05371068101075869, 0.06258240435272455, 0.05023394801443623, 0.047645103261475606, 0.05666959602686186, 0.0443281302408826, 0.04758614513482298, 0.041165206010543534, 0.06391977170302023, 0.014160453462071959, 0.022741197458197995, 0.06474854094126532, 0.036700621788059516, 0.00963930322247888, 0.020557762604326974, 0.02130326574608203, 0.03963975641395777, 0.06651395991925271, 0.0369277706880483, 0.05443783634672723, 0.07406367980424436, 0.04712386852911404, 0.029931355891148412, 0.09278486918417678, 0.08231896666749831, 0.029554658967460838, 0.11750563017783627, 0.05316005914562172, 0.036452007104432395, 0.038914577584833875, 0.025383953733610052, 0.04425463942630638, 0.0789041450667766, 0.0172890282251061, 0.027935938166093924, 0.016653835998787996, 0.040800241723416314, 0.050626537432113004, 0.026282216722686446, 0.031571029197244395, 0.036713070716829076, 0.08775723331998433, 0.04713188563924163, 0.006959465418701932, 0.05483993674598394, 0.06735731547157611, 0.01288373633513167, 0.018281008665179534, 0.004235927086894311, 0.03466666984041372, 0.03916510365783207, 0.04077986378463046, 0.02011744399374772, 0.08970181728082319, 0.03448727503118496, 0.0673540749196564, 0.03289396919670605, 0.036279572203995726, 0.018820133465792865, 0.03522128302363619, 0.05500909279010469, 0.043394326517779025, 0.055174667373179435, 0.0520486532590322, 0.0472039515302787, 0.005386831509249826, 0.03135916375134501, 0.12165816380612313, 0.02402352139113411, 0.0776887618966641, 0.037594121625466694, 0.04598568786957091, 0.043106763924081484, 0.06576091847232272, 0.0124295802614201, 0.05116615444421769, 0.017423591569005963, 0.0385253704453428, 0.0189568744146175, 0.021203302763282292, 0.009768041425324496, 0.03294437778212371, 0.043219175835650776, 0.0217419219458656, 0.039799091210889245, 0.03950687080261208, 0.05281987780284497, 0.06309190261808616, 0.03161706916627384, 0.030267768081337697, 0.04803189722400519, 0.05252333665867487, 0.0247670078064285, 0.034583679535576416, 0.034843368020149014, 0.009386757550190293, 0.013629108284329696, 0.05488917321687745, 0.10574611925309706, 0.015569313095071384, 0.06180880110590689, 0.015422567995565553, 0.03605857882047853, 0.03142130688854283, 0.055156426819702314, 0.047751355826133685, 0.0731932890090731, 0.10419809304538274, 0.02466523685612746, 0.027563625180553046, 0.02022813220748738, 0.04391736538720228, 0.037974790715041666, 0.04041318346055285, 0.03828348201369086, 0.015928580560871673, 0.03713882791118757, 0.029103779834845377, 0.03783935786134774, 0.03499709122303513, 0.01936126541676781, 0.03445157150347387, 0.018924604876026995, 0.038289308112355015, 0.02277314332464049, 0.040405848168677864, 0.060553152354494225, 0.08224070312515383, 0.040057845068194216, 0.06067188449143883, 0.03560832213430155, 0.017224640450290134, 0.04033074090858141, 0.05827249328215277, 0.023587264961773352, 0.05364929055494647, 0.020830499481469877, 0.031145846568829114, 0.06481688364499039, 0.030471698771561348, 0.04435077579992433, 0.06460462366380999, 0.056526215010953534, 0.038087489909582564, 0.02915855320621162, 0.024371765809313908, 0.02705207379955438, 0.07025881219775447, 0.030747570863534367, 0.054098976505619865, 0.027156696512153553, 0.015289462133941632, 0.03378764906477544, 0.04510785453021527, 0.03306172713036499, 0.050814071925537246, 0.024868276969139135, 0.0640274376998986, 0.07480059510036823, 0.06160082738666285, 0.01871466039559774, 0.026285978214394663, 0.015697802319341612, 0.008810372148159771, 0.03958642903354861, 0.056866124392517155, 0.0717721576051366, 0.07191350082716635, 0.03924938482082179, 0.05068940260717946, 0.05279127974063159, 0.04288860889632375, 0.025146502866259506, 0.027351351792833982, 0.09564452984881017, 0.07007359512030117, 0.03948142136176748, 0.023002923736649177, 0.009862523049026007, 0.012548511581225021, 0.018108462681993842, 0.07373194841127242, 0.00985989249461601, 0.03401308958869308, 0.08214694928498038, 0.04084277875541199, 0.03765274267343264, 0.02787506865007022, 0.02888259875978674, 0.021321489062580853, 0.0745046400134602, 0.03156558039688295, 0.022735356037775357, 0.04948450718075038, 0.027116628198493874, 0.049926647165369605, 0.051007899831259446, 0.02831804941618635, 0.024196703227296956, 0.04954075718659067, 0.10742264138835092, 0.03957133327100066, 0.05006571127582462, 0.11501834187055789, 0.09077081637036416, 0.012225189918441879, 0.027036675432276343, 0.057920889568425, 0.11749737941089178, 0.06997607978841952, 0.035841710820433595, 0.08175992932651313, 0.03745116578835634, 0.007928931971095622, 0.02005337989107976, 0.025084924718905843, 0.09998014316924157, 0.043137939872160073, 0.07792185946938493, 0.05205829447555927, 0.023341360314178373, 0.039102242313205235, 0.01738700704018195, 0.0800049368051752, 0.020148008986706697, 0.08663210296823133, 0.022337990061890696, 0.040664697786973375, 0.003508026491016931, 0.016640833571493145, 0.01797195922042574, 0.020083263065786134, 0.037105177499113545, 0.07440379219910792, 0.03377236561068604, 0.0679154028635352, 0.05093063986409576, 0.06538772640088875, 0.05976210528564069, 0.041706489263883526, 0.027252218100212278, 0.03697637513640427, 0.04733042498569816, 0.02746202851525478, 0.1166712455151062, 0.0349058271686156, 0.05976050416187895, 0.04361001857286019, 0.02390342561768428, 0.07283444576446088, 0.033747191961494186, 0.02775122096101123, 0.03645135976013638, 0.09875578910953577, 0.009951730157368848, 0.046471196091583664, 0.021139345912923737, 0.040588962334779, 0.061300195332977085, 0.03490396174451998, 0.0489570441535644, 0.10101888178577346, 0.07303648613273137, 0.12379510478386957, 0.009210741188707612, 0.025184100546363383, 0.0261865476627023, 0.06367004236146327, 0.026648351209118005, 0.030763587846811262, 0.05845994350590533, 0.04010420487893205, 0.0474006790787943, 0.0388115310981389, 0.030304639893133315, 0.03163738007236633, 0.01454320822602078, 0.008648949761634633, 0.03640782681383914, 0.003540984311726906, 0.010612838180555452, 0.02713691229150901, 0.041588492571346225, 0.08220349423467152, 0.041222654943985325, 0.03225769870163452, 0.05181692698369584, 0.09959629481478084, 0.2669925200602701, 0.1550377944424268, 0.15836155883246855, 0.124492566551893, 0.12239213732461776, 0.05480810962316971, 0.12835076919967128, 0.10878767217359236, 0.11751552037293873, 0.16271843875367797, 0.10224919600953018, 0.1483268948692468, 0.10085134601761257, 0.08808512661245563, 0.13491787406946384, 0.2282627305436519, 0.19290798734272682, 0.1156332040385854, 0.1753580314858306, 0.1205546141511971, 0.0918289982984143, 0.15129789109191588, 0.19000854373218554, 0.14476184342657367, 0.10602297576805277, 0.18224264915672042, 0.16951622801922983, 0.17049991555752295, 0.11284364807990291, 0.17933157633148855, 0.13521704672565385, 0.20410586388841753, 0.11121987875911499, 0.09325579875299046, 0.11158787675442235, 0.17985426280046665, 0.07437265838586515, 0.12129136090797764, 0.15512972499334043, 0.17316467579334013, 0.158436129831018, 0.1464465014155834, 0.09591911108263078, 0.11439667684176277, 0.11074370148801997, 0.12628993905720212, 0.2056718855014732, 0.16602691202875108, 0.1374163625821952, 0.14826381518956155, 0.12761756942998018, 0.08105684447312549, 0.20153920887218368, 0.20215581772067856, 0.19156570936883652, 0.143349161972442, 0.1457210161512898, 0.1722128575126971, 0.15351772278306947, 0.13704280278855754, 0.14201255304919136, 0.13003688275573716, 0.1287026640268103, 0.15830566505751303, 0.183848675881182, 0.17441304670947214, 0.07639874644096821, 0.2949124718866041, 0.1509025437577117, 0.15259368285056085, 0.21886693794400464, 0.09156804576876665, 0.19984554168918442, 0.12875051387856085, 0.09979343988121518, 0.12330215018723281, 0.10041742615642087, 0.1016828578506266, 0.11760566593898882, 0.11369203682988883, 0.09484134794723603, 0.15477983731656306, 0.11652342885011628, 0.18956073469692664, 0.11119567804158696, 0.1200395119526694, 0.23111020274941, 0.17504814892045914, 0.1302753506048072, 0.10102655798677476, 0.22249367478634083, 0.3312801671845298, 0.2275070001281077, 0.2246287618313105, 0.11352262414631345, 0.10308834573914928, 0.312739062092958, 0.13378087701576372, 0.11827127377112066, 0.21617449129060393, 0.0900766411195359, 0.11716230787456998, 0.10060965293838132, 0.10564573875237858, 0.21167868898520548, 0.18704246579399034, 0.15575096101289795, 0.18005888488504196, 0.23356194457700177, 0.3958219409950318, 0.12020504057046869, 0.17496789354951153, 0.12803655057664842, 0.217587816258592, 0.1538704296634082, 0.16108964389610678, 0.09103371476333949, 0.15895129331657964, 0.1356807750679793, 0.17049528838646028, 0.10204775318984063, 0.16392970037075782, 0.14765379469721548, 0.1218686311415607, 0.21155465935026446, 0.14948863656290118, 0.1687242463231087, 0.1223385418134351, 0.17778182642594462, 0.11563435317047181, 0.23472647483070053, 0.17717876201195104, 0.40854206488978484, 0.13572300183436564, 0.14572123065590858, 0.2085195568900916, 0.18447038687525258, 0.18657633193558265, 0.1202978061572198, 0.13426600985469359, 0.09295861792540358, 0.1461933093566087, 0.11754518329736688, 0.15108167043616696, 0.11280482274390037, 0.08418171711626553, 0.21766341381496002, 0.1237780363449166, 0.1105590972809061, 0.30780594615686324, 0.20220418851221764, 0.22386926226317885, 0.21757928203911553, 0.1406441514770831, 0.11298764196615066, 0.20931828015994644, 0.1228499744508055, 0.11501478722258923, 0.09056513708445335, 0.15190380535298778, 0.1880772820403499, 0.19613692536950114, 0.20535860150571794, 0.09374006591256588, 0.09893290097675017, 0.1049197402091757, 0.12691443095043783, 0.09925741582147538, 0.18707779776905814, 0.12485347057302153, 0.17144580431763204, 0.24348357992787517, 0.11815114352371424, 0.16993573776656584, 0.20591534824380953], [0.04438308938857048, 0.04502740380684695, 0.068181786956566, 0.027195772741951292, 0.05695949901916808, 0.004781726428547934, 0.016769069029138457, 0.060619284894557736, 0.0025916639565219802, 0.039529773001108444, 0.015528039150540868, 0.0777923676275438, 0.020831154486645135, 0.04252584328153922, 0.018094594575344555, 0.048667742540278745, 0.03318043628467187, 0.08144107587154835, 0.031971831077469454, 0.04914714504153498, 0.02496421224467697, 0.03038727205186602, 0.04982646584751145, 0.021029584665572452, 0.016681905460333633, 0.054620391268643646, 0.02702615512985616, 0.08427154092538743, 0.03189870223943745, 0.0841988391813732, 0.10882902559974503, 0.044674352186942295, 0.01821279045074217, 0.04627244607094796, 0.06971607720779796, 0.028596660272488673, 0.03295602997945201, 0.07948045002957506, 0.014441073383955706, 0.08962129377910207, 0.05497924217413511, 0.04579715363140549, 0.03636495270315678, 0.044124025265656175, 0.06564621212742021, 0.07662360090762377, 0.07796755661406825, 0.027915186759444977, 0.024071986028443904, 0.058119034379600525, 0.06805086253030647, 0.08244612194117039, 0.031220976811563297, 0.020557680249875112, 0.04655831177989322, 0.0318427816514046, 0.03933022241859187, 0.07030722129368974, 0.0681053467034813, 0.05017680551616415, 0.06136867210208889, 0.03227038511766061, 0.03789471537475625, 0.011471867891809633, 0.05018271205406036, 0.01507279906241644, 0.021499999040257067, 0.06119993357588688, 0.03646832860765919, 0.022469276464694453, 0.055761889088898904, 0.03790602283251863, 0.032346522766015226, 0.026776967795505643, 0.015385599465169495, 0.03514753556960533, 0.014069931555329072, 0.044575825619000586, 0.03746867472786577, 0.08059343022684898, 0.010474857126903391, 0.03782878967843229, 0.023339215267990387, 0.03354601344213851, 0.04314150984188722, 0.020310440694072077, 0.06004808207733497, 0.06184867981280531, 0.05337862019997932, 0.03574158312873014, 0.016232851532197768, 0.009133535805308532, 0.053414473114835645, 0.04277054325587327, 0.0199644907092255, 0.04105552137198468, 0.041638426182250825, 0.08344454901112665, 0.04472625847425192, 0.039156159581316095, 0.04899051836541584, 0.013791592660239868, 0.04994872581934737, 0.09739833493386546, 0.04726845996394273, 0.020361578978237607, 0.045020938024766026, 0.012749028392136099, 0.04584059464715181, 0.09347714453695283, 0.04155920503000098, 0.015486838941973065, 0.03802113520402101, 0.019967059018991647, 0.05709069923708036, 0.024213990001308344, 0.04335629408277812, 0.10555876479033502, 0.054392457128532475, 0.09354674362487371, 0.00830812969305102, 0.008451452294755126, 0.030073528403356194, 0.02231311135654969, 0.020193545252925927, 0.03364445574040856, 0.024474410099848628, 0.04698705671715641, 0.032914921701435125, 0.04873264167878417, 0.06747870210317836, 0.06093843712381298, 0.07415869002861362, 0.05881621269509197, 0.06650863560817896, 0.02066155602674811, 0.04077759616437458, 0.02916568356956686, 0.03714476126216112, 0.06380420733964251, 0.04666688176052225, 0.035314190336653305, 0.05465621737042262, 0.03009701282867501, 0.026679004302188277, 0.01277086860124743, 0.0232556906168259, 0.04486253402466255, 0.035887312204126394, 0.01023932722502298, 0.06881330387606736, 0.044145035226979566, 0.022788635537689252, 0.013558534349525168, 0.025163722607577522, 0.06710750952122674, 0.04685967544754667, 0.01715232366545787, 0.0687044044776309, 0.07220706571975062, 0.027404223350928198, 0.04764452103465315, 0.03803254225321355, 0.06907887591589844, 0.03745558228523981, 0.03965189507711799, 0.03129166565955647, 0.034752077152652126, 0.031026853961990248, 0.04651018230605029, 0.07999894599760733, 0.02395638336066998, 0.020467435092394872, 0.08012802415196935, 0.039564308244735, 0.04478837288315258, 0.031969036771765644, 0.0228033559171543, 0.016114437321741736, 0.025519382756864353, 0.06903305619714722, 0.05278361503094916, 0.012212916232285001, 0.01670860745493443, 0.021019255885133342, 0.045600728687619975, 0.010259950311944611, 0.03774931188672781, 0.011623967945906184, 0.03411157019135933, 0.09551270909967924, 0.07092369224635825, 0.018473949824129383, 0.05699868058605541, 0.050239325951664686, 0.04047530553033275, 0.040925799703766266, 0.027420414619207866, 0.04321018962429897, 0.05100884211940631, 0.06382132940475019, 0.014457340303417898, 0.04146512560245972, 0.0071692844522335845, 0.06254688468611529, 0.06168014813034285, 0.10987789955951514, 0.06253094239641102, 0.011513889729676229, 0.03477407536739784, 0.04769627410437792, 0.03068994189943037, 0.007025332222016709, 0.03162663760444811, 0.013453894399947697, 0.030795939739853628, 0.05524725420400501, 0.02331601046476393, 0.08460239131724642, 0.043468652368192716, 0.014327567881874502, 0.04933814225237697, 0.024490643502964128, 0.018321191892027855, 0.05654539785257751, 0.03585726240529649, 0.04309058031668106, 0.004969955189153552, 0.03705082739132547, 0.0365237933733771, 0.004979671578058192, 0.04071844268530127, 0.03162847813068619, 0.031533469821536736, 0.04823726624430669, 0.060773548189430475, 0.013196047399223093, 0.04567047716268609, 0.012008365010842683, 0.02929294226510871, 0.03369995114964343, 0.038768867661635724, 0.0536103694579534, 0.014630112282541251, 0.027380476540495313, 0.0506770417785212, 0.014385506153977929, 0.031096177258258386, 0.020231876462217302, 0.059006696627024686, 0.026472558928353172, 0.07225656266053838, 0.07299655763011786, 0.020752500239459258, 0.047296265125154495, 0.06560762427867421, 0.012884531151353112, 0.03258340481308199, 0.011041801452877061, 0.05778496641845954, 0.00941194556353073, 0.029002556637410196, 0.009735093898921004, 0.040830280030927354, 0.028864829350383054, 0.05626186488136169, 0.07321087838781458, 0.06718837776251378, 0.0875316663915592, 0.048513762697937994, 0.04061882061162784, 0.007961849332787097, 0.08844575484193141, 0.09151612799013815, 0.04745652688847435, 0.05388497367441174, 0.03209785062579378, 0.02931946614426711, 0.0396034132028299, 0.03589162527914009, 0.06745262447023584, 0.024138231566476247, 0.03705490680952226, 0.009460159307045322, 0.05212101792435973, 0.02069646282301795, 0.03721126918530753, 0.028071058838958704, 0.036334722873664675, 0.019506121151930383, 0.09092768819461908, 0.037376541163652174, 0.04271649192237566, 0.07396564353257418, 0.0013447204776551396, 0.01207086725175501, 0.04738322376543957, 0.028222981735222766, 0.024930828048156637, 0.06820833956402156, 0.021198233176443367, 0.031001687973677635, 0.00606242721269448, 0.020213605265223214, 0.08583013148557755, 0.0069999349709119535, 0.03504122554835293, 0.07535347309444221, 0.09338804085047976, 0.04737745512336974, 0.06133695989246331, 0.05681823623637038, 0.07809222976286566, 0.05111581480671322, 0.10590833837106343, 0.04749470104974124, 0.02738846875276537, 0.0679422848887982, 0.07909746735446876, 0.031210278393700722, 0.05147256663129215, 0.041088455491849495, 0.01864583122604076, 0.00736062879666626, 0.03122898051515222, 0.04061307495219573, 0.052659899492057106, 0.07852375942973361, 0.04199365732230006, 0.03250665046394833, 0.03228928833719223, 0.05692423982245307, 0.04723566373990429, 0.019716147986811497, 0.028050407023739912, 0.012493423156199918, 0.04273405831847941, 0.010715538970074587, 0.03821058108681633, 0.06408924184318993, 0.04200010012174326, 0.01910393839822181, 0.07654284757952537, 0.022633686594124285, 0.04703172347358158, 0.02788055575482788, 0.07027768860420874, 0.023951880678895022, 0.04110690288906617, 0.02784000672099571, 0.042267273285336075, 0.02445077054172514, 0.11794209345093659, 0.2068893983960152, 0.1608114160837666, 0.15549661982203686, 0.17055996152902805, 0.1940790599872989, 0.10706189824568649, 0.24396785474832983, 0.085994150910166, 0.19243877381086352, 0.19858983165073782, 0.16947185620665553, 0.08782959798531187, 0.1664467128894983, 0.14047631693463172, 0.12429788828857484, 0.08397094334565824, 0.13643685788396867, 0.1497185855142532, 0.1178833038636273, 0.12826813129527917, 0.1363314288638292, 0.2263990378067378, 0.10350403270774311, 0.11861991272458147, 0.19643473438918593, 0.1359885891959552, 0.1093910506836349, 0.1444161079463459, 0.20131819250602878, 0.2864262401576965, 0.14290204241631493, 0.0764466192753565, 0.07516025805905943, 0.1358901162541682, 0.1483371298039152, 0.09230445544686049, 0.22537048815959887, 0.12305499490110144, 0.1816970260152894, 0.1822411782679058, 0.12071775257467263, 0.13911356909140465, 0.16508768823358322, 0.11731299736927595, 0.2095259206309434, 0.10566275356517685, 0.056503197899268526, 0.1375600040679978, 0.15749266190874964, 0.22749762321191452, 0.3241192369211105, 0.11147077255431684, 0.1348595594566676, 0.12160452999054425, 0.1229640142992139, 0.20457343799212288, 0.14713147595044107, 0.12019252269378594, 0.12890019213720677, 0.15366594547465925, 0.11357019054553202, 0.12877245463671225, 0.08983418961325962, 0.1074719238245199, 0.12007577089412559, 0.1089269546191058, 0.14297013231102498, 0.17725227580916497, 0.19435151149669003, 0.13288565731096652, 0.22974330270963333, 0.11809292850234818, 0.13962906965565297, 0.08540810130897068, 0.14257567363881296, 0.17494774543710295, 0.16690440445898042, 0.07571933370444082, 0.14098152127717772, 0.11213940643374959, 0.13516430923294637, 0.10856878553186694, 0.1616739085124385, 0.2605877798651495, 0.06294169192833286, 0.10183848861244418, 0.27156260225080675, 0.15849369367764843, 0.14175215976372843, 0.22084517614735713, 0.2880811739352442, 0.15449506711334954, 0.14988782965848524, 0.09356149847829535, 0.12333696122251211, 0.13687149020692996, 0.26906233641409105, 0.1417991515970038, 0.1408090442419052, 0.06501644954926546, 0.14939145064882695, 0.12667485993475686, 0.17973948750765095, 0.11309277221199968, 0.0984230847849, 0.18117452340741313, 0.15476779441439337, 0.2344687168876971, 0.16934770399764662, 0.20910417390686853, 0.12710989062343875, 0.16920629948858293, 0.12838653784485596, 0.26766045679969175, 0.18973396249836494, 0.1386790899860282, 0.28950796672894114, 0.12783967364098758, 0.14924868250325804, 0.11887524982974415, 0.1384907549307231, 0.18204110674560073, 0.10618018467099437, 0.13616877307574596, 0.08925072172836912, 0.11830224670589932, 0.16850652413502817, 0.21984840382731732, 0.20422171170432724, 0.1375925781265382, 0.11782185595122077, 0.2060031265981736, 0.20327260537493616, 0.1736691906567543, 0.1770993646594786, 0.15875946490033982, 0.1983872320382826, 0.2375495854404665, 0.17388331223159068, 0.15594827461867564, 0.1483904648452036, 0.14065101562488463, 0.11770217003481043, 0.17141097796059426, 0.18193462052412573, 0.12642141506676713, 0.09058340828144744, 0.0991542237780748, 0.1304747632914974, 0.20930444461203393, 0.2607353590428829, 0.09719784972408126, 0.15947512891744414, 0.0837883845933022, 0.23864193488993954, 0.11418854607449425, 0.18649033090520292, 0.11853876103076244, 0.15048629754493315, 0.07366256382797035, 0.16128020060639228, 0.09747715005951543, 0.13296828755447943, 0.09395283917265554, 0.14367700163875857, 0.2001045100511082, 0.11810100306907009, 0.11690071183106593, 0.160348882838603, 0.20070890745809003, 0.10120349365376657, 0.11751358217049031, 0.11488937096850527, 0.19561296719456875, 0.1496830390345666], [0.012779602003584226, 0.0037953920564764453, 0.0373639275259789, 0.07126214989130536, 0.05511344162627094, 0.04655902041122318, 0.012234149316716339, 0.03594094218926565, 0.0064392040968091506, 0.03841239545914916, 0.012026137293076083, 0.010418597544964043, 0.014724709777041309, 0.025834595378968987, 0.03508323014924123, 0.020435805237221143, 0.04362966106723874, 0.02050369594907088, 0.05591061356807909, 0.10178395081311466, 0.039176640941971735, 0.038177823167174094, 0.04078747103771856, 0.049804954098597656, 0.022520849503757014, 0.041251195549604394, 0.04108548690114291, 0.052328420908100186, 0.013534838292417268, 0.04059110738096699, 0.013266513124108316, 0.05948192011865397, 0.03640660873403953, 0.02983007140667929, 0.02412436345982696, 0.04652499461606626, 0.060480622980262966, 0.041672314081581376, 0.04027847839038699, 0.030892687068591197, 0.04868926578051141, 0.009040059672007638, 0.06362490446096467, 0.04488948116739912, 0.03255525491230431, 0.030271343796724276, 0.006299389698993295, 0.04738189077245132, 0.013301774236043135, 0.028264499870279146, 0.0554435680650415, 0.020838415084947503, 0.04646625099403243, 0.02747794973754114, 0.03712455952359784, 0.01918574126677648, 0.048342890616866856, 0.0711803853271469, 0.012973980535002006, 0.08595858910872091, 0.015519480033206846, 0.06164168285566473, 0.13590025925828567, 0.056218033160773985, 0.027463895854570215, 0.08967641380525405, 0.08687539717122432, 0.039397136368338144, 0.014123616124232932, 0.06181170074870029, 0.007549496283078747, 0.03509698525792168, 0.046080912598558975, 0.06056237605310256, 0.06433777225714538, 0.031634999454141624, 0.0631026853056204, 0.02272624150669623, 0.16776026256622809, 0.06251627181266105, 0.018901032350596883, 0.06375027091933355, 0.01888523370237841, 0.03284798476905112, 0.03884118253124818, 0.06087208241825143, 0.017831539134344748, 0.048599503258423465, 0.03358198893106273, 0.017244191014117772, 0.05267868396796046, 0.05702975311226422, 0.04240084837581362, 0.014285375589444755, 0.02172829132647284, 0.01923862431618956, 0.020471842013179295, 0.06718977204253597, 0.053620500970752015, 0.00929665124614633, 0.023097455156065767, 0.026080496196124344, 0.08592280514177777, 0.03689647216590182, 0.09716026545051606, 0.052654035088996735, 0.07565397108274122, 0.0949609112895785, 0.019528358769152435, 0.03165497328154743, 0.009681099064407811, 0.07880552656828396, 0.030899401829247514, 0.03919382046367373, 0.026661441736524145, 0.07176572246657265, 0.019178269994294932, 0.001504766419642575, 0.07328939473917408, 0.01815472290130152, 0.011703764621709144, 0.022837969684793104, 0.07311997439471946, 0.023379162922801993, 0.011936080784747198, 0.014062463155677243, 0.009023914369003428, 0.06931861547092277, 0.01505925462791516, 0.055795347978991855, 0.047184948719316916, 0.050140558066026825, 0.02762957385951473, 0.05164974361598011, 0.015929609991519923, 0.06060653719149771, 0.09261085231217647, 0.03956759476193017, 0.07794514088140381, 0.04643773720149071, 0.0500459308856197, 0.00802556773827922, 0.030819263286708348, 0.07739508975177042, 0.03581454151219899, 0.04023642016334399, 0.05328857039491977, 0.022106422749798627, 0.07594752831444626, 0.08268893350877109, 0.03990602559379993, 0.01354405911819589, 0.03798611349456253, 0.01958190448462002, 0.06447083406871365, 0.032290035272918405, 0.007846352002102762, 0.03192651889196808, 0.0541785883627111, 0.031630791716217514, 0.05521928050344991, 0.09504989240198367, 0.06669449619948864, 0.05993557057433552, 0.055499875527476115, 0.03502175542375734, 0.046181339064552906, 0.026618307155947533, 0.0715975355236761, 0.049474731898836555, 0.1052493725212351, 0.02870270982384682, 0.0364466023541266, 0.0738555796804928, 0.05902313687387974, 0.05164233554575232, 0.06977248426166273, 0.010519834148937897, 0.02806489949204749, 0.11553499156669264, 0.03257300133907026, 0.06415231003155632, 0.02487853680166506, 0.015521265018070418, 0.02289077804063357, 0.02904708741322881, 0.02855041154449986, 0.022692558535885428, 0.047848120391849554, 0.06557010129214295, 0.004032842923826989, 0.10415498527788347, 0.11318134729780498, 0.0867885917485241, 0.06440953937389197, 0.03810792530496274, 0.04971565122926428, 0.05151166009806818, 0.047548193139054125, 0.06963315585087385, 0.07283056935956402, 0.011114811547280801, 0.011611336113644705, 0.02954894969720514, 0.06463952662964022, 0.04058381039348822, 0.013994570528607697, 0.01891744578437459, 0.015753644383362225, 0.057832846913727066, 0.050126335643712557, 0.04502712418475459, 0.08708567298468083, 0.05322534132808928, 0.03863161151868202, 0.07801288603654793, 0.08292082066257155, 0.07491182340609451, 0.05845715111542133, 0.01897326486575748, 0.005962676340488778, 0.058840723678229324, 0.02681416136422946, 0.03170476516618604, 0.023272421977092183, 0.08605294049747529, 0.01743368286218855, 0.01350683682117491, 0.034456397857396834, 0.02575710941586764, 0.02984277314446386, 0.041720451216303536, 0.023600642772151098, 0.05730985400957927, 0.0477155641983113, 0.03482380213456289, 0.0818198067586749, 0.051601874612031445, 0.09370702454039166, 0.05160584294747922, 0.008937449855429512, 0.023288234031849334, 0.05316968887082992, 0.031665194809677145, 0.023545896213862206, 0.02702967147342861, 0.044683824864126025, 0.05475989587965512, 0.026814454392860496, 0.0230172457503936, 0.0504721362414139, 0.07211456060289376, 0.06772647792052838, 0.023245752541228168, 0.013037737244890343, 0.03359684720635414, 0.013033098582508824, 0.057338743185203885, 0.04695899491649001, 0.026201233568210757, 0.04656808706180704, 0.0400525092658016, 0.01948174231895997, 0.07553950988597448, 0.008485603536809645, 0.00826803265109418, 0.08160681899396643, 0.06004198784789732, 0.0674798742177025, 0.024922962240394086, 0.03934650944786207, 0.03531553865140004, 0.028976844811451533, 0.019598779486372106, 0.003790620286318083, 0.02211798301657602, 0.028747165906092817, 0.08294916591576992, 0.0356054493045855, 0.03760086702963999, 0.03348142456924243, 0.046455349562869924, 0.008157547450654449, 0.0384005364180813, 0.01383256687287001, 0.02973945086611615, 0.02203694432072582, 0.033837548201723446, 0.03293421562580812, 0.05660689556069913, 0.05996226490805707, 0.05564148304983974, 0.035132148693646156, 0.0015757482962667822, 0.03176858603593803, 0.06543118656883318, 0.10580061108715112, 0.00828147557894549, 0.12170702489393374, 0.034409172367304564, 0.04738024368341412, 0.028676779662829735, 0.026392832158073306, 0.10014305942721906, 0.030641375755470608, 0.016257287821762504, 0.056124137594334544, 0.005463734766723769, 0.06440078298891745, 0.061488756384219856, 0.03191736414127293, 0.09349356180117016, 0.036275703459978104, 0.04458320304571141, 0.014227126094122088, 0.01820091608791582, 0.0732134601041194, 0.021131503087798917, 0.06520690666812082, 0.026926703510745883, 0.012050976736410972, 0.018096887093457966, 0.021931582333279714, 0.09005292303740017, 0.07265051571472038, 0.04271438901102351, 0.02116264647714073, 0.04729184096739177, 0.01928705447954276, 0.002294563807569625, 0.04139841083557375, 0.06570569885474059, 0.027753936742702802, 0.009792605077006645, 0.03445613738750258, 0.06865556637245802, 0.0404456043015084, 0.062288364485627225, 0.049864471469435005, 0.011177484242756282, 0.03176518843599385, 0.05017588621065502, 0.057477431912576, 0.02902187354442093, 0.0669693379032035, 0.05017399780392166, 0.036373486922633265, 0.03910473592939877, 0.04414656740282813, 0.039778031453850775, 0.02970338344664103, 0.025494718556142142, 0.17783781213145103, 0.061390796721342115, 0.09928438211641005, 0.2696411924496774, 0.11439466969140115, 0.21708245869846116, 0.18867297668851193, 0.10028493124991657, 0.12377719364819989, 0.137365463700506, 0.16444762177284689, 0.11606522400172488, 0.11682723633824818, 0.09809292387217285, 0.1082093294169153, 0.19935435675565275, 0.19042357952604372, 0.13801843108188722, 0.33585386531006906, 0.18857617381839983, 0.31826920567020295, 0.1566794595771259, 0.12061940986783275, 0.18102409438260142, 0.14487709369390242, 0.11004358905577853, 0.08865265220764185, 0.07711880014187868, 0.12533062843665962, 0.18160167871223343, 0.05655908018290516, 0.14794512261306086, 0.13240665317543093, 0.14432109772197663, 0.16431372492544113, 0.11847788768429911, 0.1421961843246414, 0.2584364517561851, 0.16140085945446647, 0.17066332211177196, 0.1484865935579423, 0.20282726314279342, 0.15007382048474205, 0.1218103395114022, 0.16195806584531264, 0.12939252620262484, 0.1318234304386762, 0.10128515862649488, 0.1315437317375214, 0.15295060321448312, 0.12655695134233083, 0.11157709023644848, 0.15438577701007167, 0.10770557298054619, 0.1257412055987985, 0.181901341664695, 0.08485834129274854, 0.13439771569063588, 0.12059979035609192, 0.15472843281684384, 0.13400728664090558, 0.09227464696572674, 0.3265362136786984, 0.20140497494609128, 0.1581157518610839, 0.1825439668590984, 0.2502813385499101, 0.079777569570128, 0.18731856388190102, 0.0849122432391009, 0.15658497029254514, 0.16592748913793795, 0.1349529302528789, 0.09850317927738352, 0.21636775995214141, 0.12570686953803226, 0.20392995477924425, 0.19969937211323172, 0.3068459767007059, 0.18181085135907898, 0.09680827103194692, 0.2796953610114513, 0.21484802537147077, 0.2016017982555974, 0.09670930013300912, 0.22533624402938351, 0.12430205580688293, 0.156985986677389, 0.12214123586853667, 0.16550434813384088, 0.18808561707696608, 0.2669454209746853, 0.2650230305810129, 0.18927070913055252, 0.12562908863108005, 0.1664364779548299, 0.09738856731283088, 0.11314009346308247, 0.14371473912990865, 0.08894583405626398, 0.15541726843483988, 0.10148945129326276, 0.14619752284019225, 0.13818130137458925, 0.24536227266634666, 0.17822609613499335, 0.12267518383000167, 0.14569752789553136, 0.09706637371451625, 0.11745762710850086, 0.11402693216598804, 0.15774758532643318, 0.12762617259736986, 0.1189755000955155, 0.18830655683432856, 0.20464718161571413, 0.1384368989496462, 0.07484277590147911, 0.1938269404514182, 0.0908760232250056, 0.15416335104213608, 0.05691641040386693, 0.227675968480687, 0.12969798077979397, 0.09745211430614996, 0.1313810453059212, 0.16272954702858003, 0.21625359752966514, 0.09455895261658777, 0.12238765571026072, 0.08459416353293965, 0.1450046626550536, 0.10087951507058837, 0.16151169705535137, 0.09416755063519364, 0.18689776710685224, 0.19593906018041796, 0.1666648640868164, 0.11626975415574929, 0.18811705732537856, 0.1254030160846249, 0.07705699216814772, 0.1253724108720499, 0.1531215021086316, 0.09687484407256688, 0.13478933983752805, 0.23318198028831716, 0.1418850760185911, 0.2620042151501102, 0.18251303222871598, 0.14148764492523286, 0.16922738222825914, 0.13016760799913638, 0.08133079751484817, 0.1694864578424923, 0.12140334764074896, 0.21381199870619083, 0.04909669815172111, 0.12556347320036543, 0.18584955964357625, 0.18864179690999372, 0.14765079163255232, 0.23511008569790473, 0.09843630746247307, 0.15497051660091649, 0.1030127328610228, 0.18983744565517674, 0.16401890364866104, 0.18338229687463853, 0.12007749459195523, 0.17153266336648695, 0.14795109809887025, 0.13852593368820607, 0.08358316496014596, 0.15682674764144808, 0.1560295565474418], [0.005879728649292262, 0.030954483551003283, 0.03144477216166354, 0.04643810109325475, 0.07248109537026576, 0.07382399387537472, 0.012531138622322151, 0.027331418185044202, 0.07777825628797855, 0.049006491298637087, 0.04368387710964007, 0.06534057368914928, 0.01544249777291571, 0.0904474353357669, 0.0578368075882956, 0.017169978161672914, 0.03198626225874309, 0.033611000680755225, 0.053596035952890114, 0.06887445301418343, 0.032368321797900626, 0.016102637652488008, 0.015091505014307558, 0.036295506832820755, 0.05759359765497427, 0.044692090952829014, 0.04717536495938417, 0.06956609251398234, 0.04540221232380118, 0.0383587118478552, 0.042644246000676386, 0.07371070479313213, 0.015818793458052944, 0.025596606334851637, 0.023766629127485138, 0.009726017672238092, 0.034800608822655295, 0.06050967303435169, 0.039616892519857616, 0.06755299731007508, 0.05845872925654535, 0.05987829401067669, 0.030306622145637393, 0.0167115549782231, 0.04364420524648121, 0.06143730208878556, 0.06505266252544618, 0.061631026572637984, 0.07437144030606554, 0.04080062859781808, 0.05855799892977361, 0.051585288808470776, 0.027110913182578744, 0.03034944646060467, 0.05308099121095673, 0.03479089482777542, 0.08303287634325605, 0.03985783866336269, 0.012522976913098848, 0.052600362969021645, 0.05072607906655439, 0.020061012042025407, 0.03147628710364863, 0.033852555864160104, 0.02304589552354188, 0.013609012840465914, 0.015758855696467143, 0.004073108505127171, 0.08805711077706468, 0.02506604448201195, 0.07706167296536508, 0.050525747074355046, 0.06756310967067558, 0.021615482964402726, 0.02261474123975683, 0.019425354417293303, 0.04509985657228578, 0.04646078495669269, 0.018916084063089183, 0.035701915096010894, 0.07693288592441429, 0.017925685594579386, 0.002729337138589472, 0.05761821589042103, 0.012448364737323456, 0.012762667630018007, 0.018165712432575323, 0.04289491379994058, 0.06859880691814808, 0.03741395689787404, 0.03312597126369515, 0.053712669008922194, 0.032731382356536005, 0.014029245583280442, 0.059255747980768644, 0.018744660398712563, 0.038588940421299595, 0.008292280291507562, 0.018418063710053122, 0.04702696989801142, 0.07241080680321302, 0.016559953838887236, 0.008251660394542401, 0.08286528694894045, 0.015187456569213782, 0.05777642836854343, 0.007497619202871237, 0.018055933948245742, 0.06799889112552328, 0.029217003799614408, 0.034512751285106905, 0.02465054903539919, 0.029915302518695116, 0.03691003958304082, 0.013466403658141293, 0.020367910694931785, 0.05104235080521434, 0.02375344475430827, 0.06482361755784481, 0.026467096721453053, 0.04837614266322025, 0.027879925647510156, 0.14138151110420305, 0.033766060707069216, 0.019078352976770654, 0.01565114756475293, 0.06687045127393738, 0.05603822083362649, 0.08336812407980043, 0.10121532971219671, 0.07705892270971691, 0.095673204519816, 0.025711787654267206, 0.027331176867348053, 0.026896852894776294, 0.09499694806553664, 0.03427342541756169, 0.013161039096303286, 0.012885364271970767, 0.02256474059615885, 0.06839618432305514, 0.06280980606172835, 0.05698273829635113, 0.028056884297139706, 0.03422061131606179, 0.04348911840708987, 0.04311246361823813, 0.008097196959199445, 0.08983130912266432, 0.08522599454848998, 0.0599218231265343, 0.03677101760742165, 0.013991308909270072, 0.017548182363351508, 0.02891859914656849, 0.08686985069465253, 0.02137709172412513, 0.04487448116584171, 0.03445396169779762, 0.02278322504172402, 0.005886049353472528, 0.053268759361197876, 0.01144926829804336, 0.02639184198943117, 0.03359621901425623, 0.08767295598743424, 0.039718529404771906, 0.04032998631197599, 0.05120904004621891, 0.014916982524277223, 0.03077614977354965, 0.04232489841900045, 0.07798616488974902, 0.045016831793491884, 0.02693191673907061, 0.0627888037612842, 0.019338466640141223, 0.009975592838600278, 0.04510840994396037, 0.04476389637397182, 0.0666613245923673, 0.04672877400392487, 0.03520492321601318, 0.08317981966801229, 0.07685327406732306, 0.0635215898434962, 0.02738169653551473, 0.06178551586344839, 0.09933291378641322, 0.014130416112170826, 0.03374480942804967, 0.06149942798900509, 0.03402467666854782, 0.0067221241976855505, 0.08859460572561911, 0.01621349057513139, 0.04929842059350303, 0.039069775506974234, 0.007881592525424617, 0.04370946827675066, 0.04236189280486396, 0.03191213559118971, 0.03295357849809431, 0.049474164993772586, 0.019686538688538056, 0.03489500617668514, 0.019864412813237118, 0.06499465434781967, 0.0239035003112569, 0.010651954629969214, 0.07368152450409628, 0.050628636513025536, 0.06606953699261912, 0.019519973936821186, 0.021613161717992158, 0.041430318397620035, 0.026929651034034552, 0.01612577542302109, 0.031577745873120525, 0.04589089981069969, 0.010276373321821373, 0.042913736580240155, 0.06996448121724591, 0.01721318169016271, 0.0731040550876529, 0.02292461997468866, 0.04375305101876298, 0.027365020716622956, 0.03591942660991223, 0.04936712718899212, 0.0916021673249141, 0.023143906897354512, 0.05118596164749996, 0.04592296442077045, 0.02875804818505722, 0.031480362691405805, 0.06293189366378131, 0.017244859425831708, 0.05090822413143131, 0.023464122073604696, 0.0480689452360234, 0.03344502007108062, 0.022397097575688557, 0.02725555824356214, 0.04706528578554431, 0.04003459046925268, 0.023851950254832065, 0.0409256273339833, 0.013281534193083646, 0.07631590169283652, 0.03151397096864399, 0.016885230941097104, 0.016740329240659074, 0.06025192658266714, 0.08508574683219196, 0.028087815097082528, 0.01366022677581397, 0.02890198652993047, 0.03097162476830906, 0.06035647843213332, 0.01786248908648568, 0.016078226260780808, 0.050703433507512656, 0.022403458020679896, 0.10469882343445094, 0.0035160589229030117, 0.02634887020253847, 0.025829364913665963, 0.08724885737343181, 0.06542096695592327, 0.026824827223355253, 0.026959019014611844, 0.06519547663629055, 0.033021381109832756, 0.029731472060384772, 0.06420431207985648, 0.02782137163223759, 0.012362352215624865, 0.0438903263139148, 0.04231675490436535, 0.04311600677488793, 0.05004605345968759, 0.04488948882827836, 0.030094343012258894, 0.034777886654821136, 0.03554186783730984, 0.0701788709228558, 0.050697415886867436, 0.08297723537731556, 0.017711765117823117, 0.019793986350358016, 0.04991038694917675, 0.020874003699469953, 0.010564142759258469, 0.026002791897964575, 0.08571061410851057, 0.039454918550026995, 0.057189091739635316, 0.07509345519206218, 0.024473395033348954, 0.021679746249930996, 0.017157973563899438, 0.052028409385633086, 0.011955976088140762, 0.06602943995066228, 0.03326240386213026, 0.010689240129243945, 0.029211848027884003, 0.02379993288477342, 0.059451720932678837, 0.0593625674504907, 0.11524675098518211, 0.019259486805587527, 0.06321226269186986, 0.03825080070284106, 0.030861325344190966, 0.07796623128195924, 0.04064762168714116, 0.022234386246230815, 0.0334523017368009, 0.048090127567129756, 0.031374926010387084, 0.0427741285473589, 0.011314445441859144, 0.10828375485875916, 0.046503793132761796, 0.053059582883912715, 0.02707708848550195, 0.02417328200423189, 0.0355599551732021, 0.005054434577393676, 0.07952127485505997, 0.02717640220878586, 0.0341731674909111, 0.035634277193176175, 0.02118937145437925, 0.03326506984810675, 0.06030101366641541, 0.013321352570558028, 0.05876813684740375, 0.023207210657757618, 0.04592735410457657, 0.05438863434979031, 0.009847096911060714, 0.00993706723449812, 0.02522853173075184, 0.06893872013015133, 0.014030069127799043, 0.05404404034056971, 0.02986995011357771, 0.0363816725721042, 0.014830943189501284, 0.10453835099695191, 0.09155894464422619, 0.21756305629687928, 0.14209584212831913, 0.18438015703953084, 0.18634540239168754, 0.07266353920943315, 0.18075263878751188, 0.25068819252473695, 0.17932832811868962, 0.19649591417081896, 0.2665141441168324, 0.1885998612570186, 0.18559840537848013, 0.13472920193547203, 0.12214580175256538, 0.13439318045012413, 0.1287001972236941, 0.18418276682496074, 0.12080593695563656, 0.15285547041604597, 0.15937049662874592, 0.11896527282172635, 0.2221764224551378, 0.17491615197110563, 0.1051892192974206, 0.13898141892446628, 0.1605353026740974, 0.10767276143474926, 0.17408574330470256, 0.11463574223941374, 0.18784897251715585, 0.10635798601734062, 0.15587696715468363, 0.14460528569836772, 0.18618798664500638, 0.102472985613971, 0.12710004639361175, 0.08341576708781143, 0.15595542987988842, 0.13602718470558045, 0.12257394531080801, 0.08308966644108297, 0.09480974682035948, 0.1545944287171287, 0.15647587937212762, 0.1359684564053051, 0.13864207261752698, 0.20503427052209455, 0.09984639953942069, 0.12893224525595867, 0.1744505696960034, 0.13675050960192758, 0.109479840274059, 0.2795156674279321, 0.12486852420073365, 0.13768815525597142, 0.12088162644255547, 0.08981830861058929, 0.1684849817425974, 0.1527185092169431, 0.1610550933307217, 0.22877314428408302, 0.0976761260760888, 0.12719605253228258, 0.13864826260795518, 0.11398288977122116, 0.04418900867383327, 0.15003654264634655, 0.06498001440758668, 0.09820970631535016, 0.15201608319917034, 0.1351070977867611, 0.20721112468069602, 0.12947388474018345, 0.11806256077702969, 0.19251581161252915, 0.16999334757847173, 0.15412437248854868, 0.1248470047909406, 0.10516356301283646, 0.08708711322997847, 0.1093028509809125, 0.2499776612967253, 0.12166563316338486, 0.10668189565260565, 0.12842239842059153, 0.0873192455319147, 0.25402617550665335, 0.17521671890731783, 0.13995484088457402, 0.13828829321409428, 0.17598999273632804, 0.16684877115391916, 0.20121225786785926, 0.14844370795594108, 0.14082548448876028, 0.08207129044157845, 0.07407468082683702, 0.17941889503309805, 0.1677653340682868, 0.07224602895157953, 0.10659243190480817, 0.17773515634959747, 0.13657216433315508, 0.2995441781897699, 0.08383564455735107, 0.10029657578636562, 0.16734302043914798, 0.12361246176184186, 0.13282219458731914, 0.17839173966598126, 0.15011094510555267, 0.0877581756081312, 0.10260253874284607, 0.13048311364987206, 0.22446233689063982, 0.06425174058324869, 0.1516390147228395, 0.1193053315904352, 0.09320474665371642, 0.1948907148213156, 0.24626890708121563, 0.12437232905217718, 0.13744642387234396, 0.1466552910184668, 0.18555214898961206, 0.10856628808523379, 0.1301465099377017, 0.17002857230123014, 0.13955201653222885, 0.18747077023069705, 0.10823134678385912, 0.1301970870624627, 0.13775609193309662, 0.28620520846978315, 0.10326586363296356, 0.21790871516831462, 0.12039873058036452, 0.11767812253486727, 0.16071815253986468, 0.22739671411052828, 0.14420619985509303, 0.1760840376899127, 0.1715276225079452, 0.13286714862671592, 0.19573200193624343, 0.14640931550773884, 0.23570993254261635, 0.1409497286283201, 0.1839453561772262, 0.1387496926491299, 0.10740709746436727, 0.09979495673530525, 0.19917034243624057, 0.2735574032750822, 0.13778906435735766, 0.13872533105313778, 0.1277978682229596, 0.2886883445805119, 0.0632730862426181, 0.13930999403519018, 0.08503950576508239, 0.17156496163337462, 0.16535853095833333, 0.12897231165439854, 0.07710883333798378, 0.20064109335503272, 0.15022363663921434, 0.16716564044116006, 0.15899080813171404, 0.1709158400133733, 0.08064449764788151, 0.1424777676020899, 0.17918635670456196, 0.1481124668592407], [0.027990276782563137, 0.02985399824777438, 0.00710864763541688, 0.018151679617022316, 0.012852141911524438, 0.034195870506547155, 0.06049385331871529, 0.01973412807039436, 0.010905456954553243, 0.06041526418900298, 0.08694418420594546, 0.059733560849582, 0.04591451447096564, 0.04524439438095978, 0.09566348286405688, 0.039369147346024556, 0.12030631739405856, 0.00931434117392787, 0.08012954866693867, 0.06227526438212203, 0.03136386370076047, 0.0251182955088875, 0.11188102795952752, 0.10484903795464386, 0.020622755588603117, 0.013339678351316723, 0.05202536035569445, 0.06015800420315035, 0.03564836171966407, 0.03299080654077473, 0.007412881259956668, 0.01425205555278808, 0.036558160077660315, 0.014685729308234108, 0.03772810274254411, 0.00550472334350249, 0.05012910122111921, 0.013740882427702028, 0.021646306512036154, 0.040949345416119026, 0.014473010631909054, 0.04492876998659584, 0.0458331291203297, 0.036262009638331594, 0.04614905611942372, 0.0533130239214628, 0.02307824167092481, 0.061668423154661735, 0.008000664135080673, 0.02949124603952852, 0.06877077833539055, 0.09536119223001505, 0.03022172236664882, 0.016514603348989642, 0.04812999095226969, 0.08550058344318982, 0.017669668586383906, 0.046130041817143086, 0.053515508620729374, 0.04493471099844864, 0.06349617104616857, 0.03127061164817743, 0.08536983521715288, 0.05959473805682314, 0.021185230749148517, 0.07650350130373433, 0.06613139859250476, 0.04421898186387074, 0.03730951613115688, 0.037396394332209905, 0.010659381852395112, 0.061144445827531244, 0.10414523297860738, 0.05879603393916642, 0.02735400628749161, 0.04438899592646668, 0.08958375547081233, 0.040457233516198975, 0.04742114511769145, 0.02941148862573168, 0.025562754824697494, 0.037973982492281545, 0.061516668797741016, 0.03918004237235554, 0.04698794537914857, 0.027193342328011513, 0.04658029084244082, 0.03651841926658827, 0.03094025346780977, 0.05419519331846988, 0.013256033041304158, 0.02788485159286328, 0.01086678579374547, 0.009285933676085645, 0.031042112518222104, 0.04713223420924718, 0.045999262947589166, 0.006903167532366371, 0.03857413577216287, 0.029030470966151165, 0.04391086896160438, 0.04952434758325258, 0.042445967124114116, 0.015784345356927767, 0.08710660250677217, 0.02768583152623427, 0.027289913456526496, 0.04608640161853644, 0.01206274193170811, 0.03817697664001777, 0.005524345728073029, 0.0269782152627745, 0.06531143936538888, 0.01477782552566139, 0.010235131936027639, 0.09568884037435056, 0.08716415869252336, 0.036872110569909695, 0.034051351850071264, 0.03408523591896219, 0.037387890756250396, 0.02774669338137873, 0.05863204515809494, 0.013722267448751917, 0.014868777399251779, 0.04186806869843314, 0.051930227557257305, 0.04625012992971367, 0.044029279341620785, 0.017086922739362045, 0.04484522809845306, 0.03608319705592529, 0.014813559696889453, 0.022284785255549416, 0.017857340975634513, 0.022589778264744148, 0.02992220497089288, 0.043815793619761546, 0.05393166673339663, 0.0825354477931415, 0.027335767649234306, 0.04464745867036043, 0.012602921060827232, 0.025953452005201293, 0.013296526533761814, 0.024118227095553474, 0.03785140076351743, 0.04700902045794553, 0.030705175557804686, 0.01571848573568728, 0.02971338472449251, 0.010419132848901135, 0.018437847930697665, 0.01836514427146364, 0.02921990344240781, 0.06522219778308946, 0.037699014384059176, 0.05143734190853373, 0.0345138774343556, 0.013994161629178112, 0.029728306202037685, 0.05309335587005462, 0.04230392676207327, 0.05052196643044872, 0.05177963765398149, 0.045434610182118994, 0.029119373554544106, 0.036471814307714664, 0.031673131480572686, 0.019243125082744707, 0.035155192618408514, 0.048993517599639394, 0.030416542356232965, 0.014681501460501985, 0.025551121779567292, 0.016962640295406024, 0.014736998784956674, 0.023691035401556763, 0.05317123636843697, 0.05259091710491527, 0.002597110362858662, 0.049701390502553795, 0.01961148313937649, 0.012351604002047212, 0.02184744864221542, 0.0660583291262869, 0.04899822137949448, 0.04142266900969609, 0.009202237612748099, 0.05220193213092224, 0.034801689006628535, 0.03117790543324044, 0.05890306025262802, 0.016891156631191413, 0.07798410411323271, 0.021035487373029033, 0.031682173233299006, 0.0317539748240022, 0.06148797497453709, 0.06330714268129199, 0.0358132008583315, 0.0802222453057766, 0.0627130606482106, 0.08721551722696713, 0.05026230475895348, 0.041302109753052076, 0.05435950385646955, 0.07647874900290082, 0.036312716998039715, 0.04734378555909761, 0.03232242163991736, 0.07932946176057862, 0.03744971405173983, 0.04271600162610412, 0.056117713947089455, 0.02348158313261886, 0.020684366294693564, 0.011551326531316004, 0.03813577643144996, 0.08582883679698552, 0.04579023968788885, 0.039275780380252874, 0.06625175866628848, 0.08021635408963888, 0.08753570367492015, 0.060585764717430844, 0.05902110291044078, 0.05013361730943284, 0.03516800160850248, 0.027100429269334963, 0.018824276086243413, 0.08605427349046355, 0.03739228810093576, 0.07696005906308852, 0.037118043945801836, 0.04756147710366115, 0.03206607904435406, 0.030515833096879146, 0.02998586113174116, 0.020210667318033598, 0.03743495536787856, 0.06018672483943163, 0.10635530470960564, 0.04857427981351653, 0.02677469442959034, 0.042083695636040745, 0.0519840797078946, 0.03542857875506725, 0.010178339922980917, 0.052032982930541045, 0.026289063633509704, 0.08662297120017391, 0.040884346686183445, 0.020690652046112284, 0.02896853084225328, 0.0018027613353502427, 0.02100461019924091, 0.077274959504364, 0.023322219607390227, 0.0399748164589607, 0.05346804564338058, 0.02561538314987575, 0.09162336497777894, 0.010066582058976975, 0.06479422276419017, 0.06928084733625574, 0.02517393647482799, 0.0939010899333704, 0.010616481886245312, 0.01945986476306233, 0.032894968941447236, 0.03052635339929933, 0.045000774590598966, 0.10766312404866181, 0.05625287100913064, 0.050810275959872434, 0.027830505315514825, 0.012725003874830663, 0.015297979116439821, 0.05803333978439051, 0.036515818398085334, 0.05127569352607093, 0.01390914406417118, 0.04537630323020201, 0.058286669739191575, 0.1337264081643474, 0.02945488942186198, 0.059100324062690626, 0.03437008273096816, 0.030857661528693094, 0.06283208006812681, 0.04531067630816852, 0.04216679702362707, 0.04048471692048254, 0.00759762432050681, 0.02705365002545859, 0.012479903619556178, 0.007236060506153492, 0.038054743481259194, 0.020638617439075344, 0.027593504524819797, 0.02883458036869284, 0.010506421864603557, 0.06118136360460232, 0.024622234425717787, 0.02888535859153396, 0.016839420798444943, 0.07798612658535281, 0.06808144476024375, 0.04927542646445575, 0.028083456056793372, 0.0238046002754521, 0.023402963359389576, 0.054545647900311224, 0.05375772263974913, 0.11748303058407, 0.040024186995240955, 0.04238760271560281, 0.09736242839285443, 0.009357091752932438, 0.04524849295135468, 0.053318681480783614, 0.030776628578502326, 0.015594240638517566, 0.04218303808762182, 0.03197267377418617, 0.010875117957531925, 0.01665384557488705, 0.01507397500738021, 0.08715834408517807, 0.041271431762124264, 0.026868398474048705, 0.01927288376816338, 0.03661429900075159, 0.0594097278231094, 0.034738138182869846, 0.021067504102604526, 0.029411080683912003, 0.015573462418791269, 0.033516745052991376, 0.061979531460712035, 0.027400860224940607, 0.04193397524255899, 0.052208666043776664, 0.0373166254270942, 0.0646499760689274, 0.03639382272658329, 0.08097105794736455, 0.04357898818148721, 0.023720464669168, 0.022016334640342864, 0.021521868935275464, 0.08892880392170723, 0.17044884813649042, 0.08578370655736617, 0.09989538320129919, 0.103224134823728, 0.1996174007053337, 0.08042601703275597, 0.05818930762489477, 0.12280996167852033, 0.19433815092329057, 0.13970092870295048, 0.1803820820585374, 0.11856100822408354, 0.1401727928990318, 0.18321184231148613, 0.21365586998722247, 0.17773886421515098, 0.14221104643037244, 0.2173321880400181, 0.17185924664860772, 0.1256822168286289, 0.08008502363677948, 0.11705841869115831, 0.171391029031046, 0.10284652242497092, 0.20385330002154076, 0.12265726503345276, 0.17218530899093998, 0.1398606120698875, 0.129494032852592, 0.10934404352860105, 0.13671686302029318, 0.13333089229079986, 0.1796421024107164, 0.11664565051755599, 0.20333560844582899, 0.14171177160836038, 0.19023378890368248, 0.133320642034373, 0.10857879064015805, 0.15115757442770467, 0.1353972612489616, 0.10551221728805574, 0.13778555567466444, 0.16691566595146734, 0.12129886856963559, 0.15937615035762712, 0.18402004974984354, 0.23085134163979562, 0.17222335291725976, 0.13854275697902327, 0.32484861391205944, 0.10376643314356766, 0.1274160883058944, 0.175604083605351, 0.274614849758725, 0.08334413020601196, 0.17071592170865307, 0.11506759366320987, 0.13269090243885595, 0.21456855649669326, 0.14439445830160572, 0.26173170235368515, 0.1734350588653357, 0.0683410183316277, 0.1608681525554388, 0.29815103197770737, 0.10345831258042205, 0.12623979094167873, 0.12743458166838656, 0.1306261575870937, 0.1700783373727914, 0.20716315225487758, 0.13651378843332493, 0.11429789746480604, 0.15038492879079235, 0.15785390300856483, 0.16403718250653437, 0.11190414083220306, 0.100028399047592, 0.12499409367240245, 0.13368978916156676, 0.08168411726552634, 0.10419201030726395, 0.1073035300378838, 0.1995264813904801, 0.2501194641715096, 0.1845581039425827, 0.1802714589622713, 0.18173710773548774, 0.09851444076987044, 0.21221374011328145, 0.07086870245515339, 0.11084627300020188, 0.10317494431810995, 0.11391400314506986, 0.17781881315092887, 0.241913850449266, 0.12996162227805585, 0.16471327042147038, 0.118042535238689, 0.09808992080750967, 0.10158310554200604, 0.11257083650918738, 0.2548320846812379, 0.15892800424368153, 0.1368504687542877, 0.09877995918354682, 0.10512845320326668, 0.28143707722906147, 0.14342828353326167, 0.0813000544064468, 0.2259613870973549, 0.19931465807941653, 0.1049077662549192, 0.20533379557872974, 0.21128225380614882, 0.13264988609138997, 0.11203789978378242, 0.11677079864086644, 0.1442023081284377, 0.2449222930496739, 0.1267538359388709, 0.08671903862587868, 0.07946344287765604, 0.10773337431131833, 0.10965817788195227, 0.1619643784098087, 0.18449402834859588, 0.10593776380823505, 0.16412938884910078, 0.15802763642803316, 0.15865837193785176, 0.1285419847455717, 0.07776218376332715, 0.18251378299488177, 0.13343748576458425, 0.16260013945641058, 0.2157576934945199, 0.15638397946473093, 0.0809781519215434, 0.1357297587298578, 0.1396211636282744, 0.19075040795630027, 0.14388265028115244, 0.13648587218936414, 0.09568515549143476, 0.10008258444647636, 0.15821545054354977, 0.12149318677162933, 0.1379182880684253, 0.11749821444672924, 0.18887628110185747, 0.14628629710885788, 0.1074398553840095, 0.1472979621781457, 0.10226975014853863, 0.17684339936221802, 0.10929262370712335, 0.09331785953573643, 0.15678704896521184, 0.16126374503777874, 0.0918592817540611, 0.16897186126199462, 0.1452565063992816, 0.14642322766444377, 0.1775520766574529, 0.14079462646717025, 0.156516466710356, 0.15754417366077825, 0.13838053020017763, 0.1682379643522924, 0.13841445257346477, 0.12512638939604645, 0.13769498876025602, 0.1551454451175467], [0.04505355804858189, 0.027246905280457392, 0.030089905447957498, 0.050841202929375634, 0.08406393875878665, 0.05597350938666252, 0.02161500415945005, 0.022292072666929136, 0.021863875482531808, 0.07545525553606211, 0.07456606494322901, 0.0037412490318303993, 0.0592859509971834, 0.07353698669542229, 0.03417886718506775, 0.08293984262573142, 0.025514901142507315, 0.027435050729001244, 0.017158159340221076, 0.02270673882336386, 0.013055855224299575, 0.11287919455958952, 0.037547225553181865, 0.016570167706137704, 0.029710360592411413, 0.027740675760733507, 0.09424210631198461, 0.07795899941195404, 0.08023798841262057, 0.09387945561038871, 0.030845365817508394, 0.07371177731622612, 0.030353958718478683, 0.059880634409285365, 0.07395667264298086, 0.04495107463651127, 0.062389511074269974, 0.01753958111118165, 0.0270416071232889, 0.045732112766634074, 0.06622844661075263, 0.03450669152962585, 0.017509740071311113, 0.027368877969321706, 0.035334020522573305, 0.021358050608767137, 0.06317786917450928, 0.021640386567601276, 0.013718730037761553, 0.0022037862189820097, 0.05415559806410344, 0.035565019014381596, 0.03571436019434083, 0.038193531800061464, 0.03126295076893463, 0.00702918564427584, 0.020370475174258315, 0.01998741014470016, 0.08664986088631615, 0.07799446928284823, 0.0452535261490172, 0.028874690817188353, 0.03952024286733039, 0.05887325177149427, 0.0512221401497241, 0.03209216625339562, 0.04684907662111425, 0.032519176001510317, 0.034193139403097095, 0.08706257543376378, 0.024016733852124984, 0.04344687631894504, 0.035257810095865885, 0.014930319157429041, 0.006489314865546242, 0.033176873975823966, 0.004152250654559824, 0.0362238546292628, 0.08410782793596869, 0.043301817570482536, 0.06088989779293057, 0.04663235417777493, 0.03860494782847743, 0.021028247842144583, 0.03356696977730721, 0.078980355493484, 0.06032878435367058, 0.03278983486515861, 0.05106515724272017, 0.050315023099462834, 0.02742132626383776, 0.027165927871641134, 0.04907574564699204, 0.03072482571306248, 0.017515753861516714, 0.07384567416363186, 0.023808085975507577, 0.021062287043840177, 0.09716010457205196, 0.023123505975930922, 0.04350988322027749, 0.017106038548292655, 0.031947050048338796, 0.0405488001753486, 0.02093667926777515, 0.022454889333476464, 0.08360252400199253, 0.028839521635804447, 0.05729763873762662, 0.07345248719737416, 0.04232084964432063, 0.029136307928110325, 0.04762755218713034, 0.1606008031916234, 0.019580123330196066, 0.06857838301408677, 0.08676018520829179, 0.04727939203862221, 0.02285655114739653, 0.04711356081609284, 0.09009483570773756, 0.05102561178406881, 0.040639960807898355, 0.032752219948076436, 0.058979374101205226, 0.03556362856479903, 0.014786298458103933, 0.030238300509330247, 0.006007288034344393, 0.05860186512431791, 0.09285732578005522, 0.07859112920179483, 0.021529740488697446, 0.037413788358530695, 0.02436196754476236, 0.03686035112027199, 0.06975327843740102, 0.05023973197826455, 0.010509266923632353, 0.015590041519082604, 0.06896757866225897, 0.05989953379837736, 0.07863102706089135, 0.031157293837637674, 0.024150236164249723, 0.06279267633574144, 0.0577599574781714, 0.0569252280758754, 0.06521026213322917, 0.020441089328678868, 0.06976915944007135, 0.04005974113580681, 0.004909704767933657, 0.048974468823402166, 0.03116468658610698, 0.037076552623822805, 0.03550580807871396, 0.050609350249531775, 0.031029104345267823, 0.05324672667249557, 0.004433737213407914, 0.016401785410820477, 0.0060200290341350824, 0.05729909047424313, 0.04803885330235766, 0.012265881636149943, 0.09342605413328256, 0.01617918132744249, 0.08256769243387446, 0.0726270734242374, 0.03471477633161891, 0.055003707191997, 0.032384980379814104, 0.022237251415067626, 0.04994539716731637, 0.0768840095148452, 0.03237753783562972, 0.013370785351482131, 0.0731249922706235, 0.05691197475478534, 0.03962357663699696, 0.06318750656059673, 0.06775958824061579, 0.05771114618607587, 0.029738433884396672, 0.09253468785074451, 0.0818619569162688, 0.03361141436823434, 0.04179466215352859, 0.01801358269257171, 0.029946520601609544, 0.044266146066929066, 0.01963850114524605, 0.028422518911200668, 0.00911935934826972, 0.017872779562528578, 0.043318843874599666, 0.05377041671665446, 0.04210337643481551, 0.030502043514242096, 0.04693703117570089, 0.02442552602940029, 0.07342899128073647, 0.04720162262298888, 0.05925532280197067, 0.026353480136622826, 0.04884309623570693, 0.062417890801424944, 0.04093558647699895, 0.00621377889465, 0.012793764096474456, 0.062415182680612614, 0.015062534441840986, 0.05199536035257963, 0.05550566332174405, 0.08765962605755176, 0.0953195936557266, 0.023846823211398818, 0.052886573417532834, 0.043215115569652095, 0.00844158795512011, 0.046334794136665525, 0.07778971696332579, 0.061434406276431784, 0.03886983038917665, 0.07677692574478927, 0.04990104833737977, 0.05682918746324797, 0.030800988259274634, 0.07542304153884612, 0.017485953041262204, 0.03479921454263311, 0.032995203885460095, 0.026143870819660447, 0.056995597082160177, 0.10007938985983211, 0.062153303184576576, 0.046323230039448514, 0.011918137090340739, 0.034158090880561265, 0.03300163136314481, 0.01587722394164772, 0.004655454550013548, 0.032907605561758244, 0.08801533600255367, 0.06625149819639421, 0.03239086393507258, 0.019084309310381933, 0.04065629380244402, 0.09252609234423408, 0.02482551011076618, 0.035092515134883505, 0.0123388591718169, 0.007657776586711408, 0.06700591094070865, 0.04684677452690179, 0.03413783551584329, 0.043089308610726754, 0.027798802681988286, 0.035776045594003894, 0.0451774268050588, 0.04161845427006484, 0.07414374365321091, 0.02551822213365907, 0.005866909125489333, 0.02424031469760643, 0.037679211011216525, 0.06267102923424495, 0.03237338946951974, 0.08328911743216938, 0.08799956225219273, 0.052063063372887915, 0.040771095908337066, 0.06904211901729146, 0.042136337367757674, 0.04087346057677942, 0.019282400495402755, 0.04503171305142103, 0.005680381080075618, 0.02588207367807627, 0.022234713748818444, 0.03854750272547526, 0.12306666242018824, 0.04639702728919445, 0.03591317916288972, 0.07586393280014878, 0.039728630274053545, 0.0179903146870915, 0.04082998891751613, 0.08674386753550462, 0.016635942100096616, 0.05012578789084669, 0.04207256437850095, 0.05579294629334923, 0.032409583293502374, 0.014278858096428938, 0.053804139907081286, 0.035524205680215554, 0.018856401983348113, 0.05444048701094524, 0.02859550731016263, 0.0676987761811864, 0.03357882498793545, 0.08701199064812354, 0.0218839010208725, 0.019631079668479583, 0.048916433832698294, 0.03994630266641898, 0.02536169504897008, 0.012638827601838256, 0.0402228910506012, 0.028986673719520052, 0.030301901128804012, 0.050283444955223994, 0.036009269571232225, 0.01838115933952072, 0.03253755062037418, 0.035007215074954495, 0.015796490723357325, 0.015781447629354173, 0.027539962639791832, 0.045334716147232446, 0.048957013510047435, 0.0083758135611612, 0.028290374489921718, 0.006507054110237908, 0.04542045670771792, 0.043021084650629954, 0.04169309421652748, 0.03192582749761641, 0.11012441899266937, 0.04353676524554049, 0.03366095344385794, 0.03706321120262146, 0.035853703926888206, 0.008100626160270505, 0.03639123334939923, 0.054857618055276336, 0.02019950158653721, 0.07039546696168762, 0.04616391822515477, 0.027647421792930657, 0.016358947689314524, 0.04603401269583453, 0.11440905682261913, 0.005399929218730259, 0.04408973517016538, 0.024757257422372222, 0.026979180533559095, 0.03535509560137026, 0.01187918918027032, 0.026508080510182247, 0.1769339049895925, 0.1738246298965908, 0.14684848307121187, 0.14542028067573426, 0.14054711878059373, 0.15735997548026426, 0.15094679299621813, 0.11758541823515009, 0.16319195769967573, 0.21170150308359056, 0.19145205256439027, 0.09741133544594051, 0.13546844613888573, 0.1372973278405205, 0.12660565155167736, 0.20140102193240197, 0.1535995562951411, 0.09807658321674793, 0.07227316378585755, 0.08002503895230832, 0.08976232290508286, 0.22322052368713965, 0.11790745861587987, 0.07863576914514266, 0.16445393433734296, 0.1429279515099141, 0.1786399215099312, 0.16747935344615292, 0.20434330517966903, 0.1463668742367337, 0.15956984802840218, 0.15910815747995533, 0.22324894554913047, 0.26125179423439887, 0.13602378327519665, 0.1551871509441445, 0.08199232975922285, 0.15029889711689565, 0.10067884599970234, 0.17872578464448455, 0.39016432038718657, 0.14080283892971857, 0.1935948617756367, 0.15063406058376835, 0.10628385934978725, 0.14313720076555206, 0.19581927467257748, 0.14464930511049687, 0.11790091622500651, 0.18562776186773855, 0.15711942387204017, 0.22231361348061796, 0.12148261475827425, 0.2129942458122969, 0.12061228525013694, 0.07710266633019333, 0.11314760112474043, 0.19998752842507056, 0.2570651237282061, 0.25157117014450414, 0.17162180535735624, 0.1488447856278189, 0.16050910246708702, 0.08162360398038741, 0.12542246705702237, 0.18952164889102985, 0.1767412951636699, 0.10127533737930561, 0.2307934713579955, 0.21150946016273192, 0.13009263863486628, 0.15891213090189044, 0.13163555503612565, 0.154883734160854, 0.20695420943440931, 0.19785329939857607, 0.2003616091584967, 0.11333461850881578, 0.2257996199712638, 0.2068162523210049, 0.09130586749844014, 0.2307195591950609, 0.21653985394345177, 0.18846366614584, 0.19910177756701747, 0.1504767827329136, 0.1328200035758557, 0.09620798751711847, 0.27448072308494204, 0.15155603207888144, 0.05018866455723202, 0.1337412855918369, 0.14947576628577325, 0.24273699660214687, 0.20185572575897942, 0.2662298029228564, 0.1162429640610372, 0.13857116351925558, 0.2084766406445734, 0.22797725553954803, 0.11931239492109708, 0.07482123350904835, 0.07578491083075924, 0.1331080986006606, 0.15423735513562156, 0.20548080785139916, 0.17335835814235673, 0.11176059893783062, 0.1642769220615587, 0.15316811089794483, 0.12646202538763324, 0.15662476089933228, 0.11818982330301117, 0.3008368749532008, 0.08184040686295879, 0.14430902417628996, 0.21124004236152097, 0.16130065515397057, 0.1418583395500337, 0.20757264157216396, 0.16435127855548937, 0.1610728818923235, 0.12053910087073043, 0.10949257265536055, 0.21162431206434004, 0.16689461385530813, 0.1620656092681231, 0.1798729553458191, 0.044713889984714414, 0.10918441378781873, 0.1769233789415129, 0.20059402491296494, 0.1986987693535705, 0.10413031724672164, 0.1989985855236169, 0.12433249248011459, 0.21360510900135965, 0.12286160366549609, 0.14763540858703275, 0.12280719610111368, 0.16082073171292582, 0.11296278241300776, 0.14099883486426648, 0.08328550915804603, 0.1099180349058682, 0.1595073199320224, 0.13706976908349222, 0.19397692514523385, 0.11384729986950276, 0.13250682683240983, 0.20350387199751793, 0.191363952453098, 0.1780858101142991, 0.12243815622622929, 0.1759382051926467, 0.14330393214139248, 0.15630547077425067, 0.14613511731788037, 0.12267994123601145, 0.13785606640721523, 0.10475975040706897, 0.128208399419823, 0.10005688219661675, 0.20038583285866246, 0.13149742938337788, 0.1254722244677044, 0.13711040238699607, 0.11270853315269756, 0.25841659475718776, 0.3132655483580405, 0.10918828253183635, 0.16688797953388385, 0.15385588931460537, 0.09471245365397585, 0.16214468486366734, 0.0772481847314104], [0.07309847796756415, 0.010728245495908685, 0.027129760860735853, 0.03349172079094476, 0.04094241998128353, 0.06937098524142658, 0.03723268517323079, 0.050914973366044225, 0.050333512631515344, 0.03218905339317937, 0.03819957240334442, 0.03146068763829047, 0.06770290539509828, 0.11160219493772715, 0.015019088638045136, 0.0655308086425066, 0.0386547856783915, 0.02746473855128692, 0.01395669897207089, 0.06370132173141164, 0.05511565562037211, 0.031148152493481195, 0.030540981848213463, 0.05575153158016263, 0.02950894841623883, 0.020613823003406008, 0.025261396902703473, 0.02354590578996126, 0.01899291119057565, 0.08906859964612993, 0.024264118964633635, 0.05366632835038247, 0.052819962072516644, 0.02852481271651003, 0.036952660884708166, 0.11420244290944069, 0.032290992882823756, 0.010515191656116758, 0.0501878027083172, 0.041904867731875954, 0.04834200578531431, 0.084835481229088, 0.046550662391969276, 0.017802111781953324, 0.028285180413795095, 0.04637417488641316, 0.031449562126410105, 0.10846858123137106, 0.028093432436787316, 0.06835622517692466, 0.026848459120599494, 0.038927394235807086, 0.01942686552572395, 0.07004577080689131, 0.019881247595373183, 0.023694703047494256, 0.02658196777525929, 0.033819621744295286, 0.0818204349507728, 0.03354670292127036, 0.04700679114208587, 0.05610259520190378, 0.03023346840974785, 0.010131322234238108, 0.05696866909162172, 0.014224757924826156, 0.026170302768267935, 0.017753605009807695, 0.04529270005502528, 0.01845257980148158, 0.05000310657065242, 0.04650239885273961, 0.010496477085736491, 0.08266819550866082, 0.0366706409371428, 0.055211144649694045, 0.035920449337291147, 0.05824759542461365, 0.06202356619459968, 0.07757051622555142, 0.02373262439974614, 0.030841657951954874, 0.09191309943074182, 0.0991004444057903, 0.04946820866016131, 0.05302253487189451, 0.04137879515427255, 0.031230194764512203, 0.0588819545303141, 0.0610365538347152, 0.02393359799058207, 0.005706397425984183, 0.025751262249785568, 0.055219422229715896, 0.05918758147726617, 0.04874289576565066, 0.07683836599631656, 0.032439192591775814, 0.026999171597943194, 0.02572286337043249, 0.08886721811347431, 0.08134147678051265, 0.0756496886512445, 0.039638285525143147, 0.03793982263173788, 0.06713131187303413, 0.017250832996421286, 0.017870824123101852, 0.06408223596912238, 0.06748650853912677, 0.05013181700281078, 0.07767706373406034, 0.08225741150278239, 0.01187050365842879, 0.049005238744880886, 0.029093311243360082, 0.037342316185634945, 0.033882230279907104, 0.03191289784867437, 0.053859742568625565, 0.06728810708849661, 0.07330781149287378, 0.017071409458895365, 0.044570194872757124, 0.0293727264919829, 0.0334095808437034, 0.03853149914873704, 0.02171958090677377, 0.03586913676812284, 0.04464767700541885, 0.03783316787091955, 0.04879679388156341, 0.008915219899086703, 0.05828798357998172, 0.06283712858754782, 0.06585597466196745, 0.018897786053017746, 0.03920528113902096, 0.00416661097270046, 0.10016405789722359, 0.06328915876726951, 0.058595391681357745, 0.04891533066608733, 0.05985165713354946, 0.04838101115197905, 0.027705022028737494, 0.03984091578111534, 0.027845643212898608, 0.06022571105389826, 0.020104305585846305, 0.07790672157200114, 0.011814271847176696, 0.055851506054281234, 0.057076679828066024, 0.05783443271573033, 0.050929969537162015, 0.04464297705600339, 0.04560545545011278, 0.03305320057176775, 0.07358498210387845, 0.05033473454175457, 0.00952276880026705, 0.02689581101519927, 0.04820883672143664, 0.03249141680557401, 0.03593573662182016, 0.07347551580037802, 0.0630563484775203, 0.014380845466568587, 0.03309367299680749, 0.028522650433343746, 0.033114188831419714, 0.09219595441414465, 0.061055441732488336, 0.012103039114135168, 0.01735242774649974, 0.007957524287649582, 0.12256081456378584, 0.038577747876725854, 0.015111058450964911, 0.057569136467552, 0.06269112755093845, 0.05463067982946673, 0.06553282345374746, 0.0006921226139961472, 0.03580658568910534, 0.020229470946135062, 0.07537792662098523, 0.03361412631948629, 0.04832898229060154, 0.09964092709724942, 0.04168239962910453, 0.04461737439757393, 0.040093345582605376, 0.06779331143104261, 0.006212861504360673, 0.029466309877593192, 0.023192467295654842, 0.06009297866013743, 0.069240374911216, 0.008097345388734774, 0.04286859867974155, 0.037626462027190194, 0.06022656141149421, 0.007170882224360662, 0.029287187029577555, 0.05651984882030276, 0.04519291710288775, 0.03380862455214224, 0.050047214082892866, 0.058414177413308815, 0.08338267975036176, 0.01958928382655065, 0.03795083897608904, 0.06388864555065671, 0.04968097425937172, 0.01990860842558886, 0.12316200972324419, 0.015976377744077435, 0.04426239989697934, 0.060154936021013614, 0.036492318651008035, 0.0033888296738657504, 0.01977985202815504, 0.05382000558799314, 0.036914662923663855, 0.051155176404262745, 0.04521682670700454, 0.0286450234031485, 0.10519381582496629, 0.026771235542612213, 0.008901704192882585, 0.05206728068691108, 0.06721601821482182, 0.0398295623580775, 0.047393669374287135, 0.03153218279382394, 0.04743575058396786, 0.03209471349574385, 0.043338639586563074, 0.07322727266939418, 0.020678586161304868, 0.06732224396640255, 0.017771496993279266, 0.045984113558886514, 0.03791146588722064, 0.005615558550362626, 0.027689644728877374, 0.05139555564270385, 0.04807409717731419, 0.05564987554305023, 0.07340521957244604, 0.11440826009117788, 0.02033880892990818, 0.03913762791442775, 0.012550840488514833, 0.07711143803692634, 0.046802111600916234, 0.03578783185671895, 0.04680568540108301, 0.03516201463137423, 0.03873122976191583, 0.046216341621813276, 0.015252054060599016, 0.042392528660955935, 0.0623172460003726, 0.04645312790788951, 0.009737534846569742, 0.06417631156622403, 0.05998471128423849, 0.08510987094092755, 0.05919209373514018, 0.03491832589310023, 0.024588689350733356, 0.036842512762955124, 0.06158977273791548, 0.01663396750847178, 0.031336150470099626, 0.07833510261750029, 0.04476237951988175, 0.03249652661202896, 0.06670532868273797, 0.08571033831685783, 0.04311865360866632, 0.009025383342598236, 0.02586465092345832, 0.05337350656308475, 0.0187121476272061, 0.02079148645392589, 0.013348684672476544, 0.05206311699904261, 0.06014304633642878, 0.03094986404081987, 0.022984397815420263, 0.044955789907685215, 0.02024765978867729, 0.05711428325382933, 0.05718064562027013, 0.05342594528150174, 0.08572483270038521, 0.06472882949897359, 0.020090914368929885, 0.0360450611990546, 0.026975329026519775, 0.014152586696699504, 0.06408243898242232, 0.07114943537500597, 0.024490576470270756, 0.017372035766921697, 0.08858676098527447, 0.04715144769438813, 0.07271367966407731, 0.0760646018710348, 0.046211710620311, 0.015844851938797342, 0.06117376784283308, 0.039373567673347654, 0.04460661469267742, 0.037284511021308364, 0.05919203627854586, 0.08566007528814577, 0.010016027916853708, 0.07979880552738905, 0.03366882499727992, 0.020765694188735178, 0.02801005525754825, 0.030808444209997694, 0.03778604197225744, 0.028959360769799644, 0.037268296770390966, 0.02759100899340645, 0.04228933278711573, 0.020658583605601903, 0.019967352047622688, 0.04956376280695681, 0.07430314356761594, 0.07222023477116901, 0.053817366415093985, 0.07559695115853703, 0.06712722096351847, 0.08078662994047327, 0.06718507592356013, 0.040635348958594185, 0.03801862243562937, 0.024734847435367205, 0.04154719277134827, 0.06142284984009401, 0.0671202802069245, 0.03100388664602032, 0.06436253221885813, 0.023424544056216558, 0.046202613326210173, 0.11290432224350591, 0.1542368801611085, 0.1112609027674602, 0.11164177870077473, 0.13334993723659747, 0.16613856168283572, 0.13496143382883843, 0.09065098489724821, 0.1360523430330138, 0.2157436281202301, 0.1587634179140291, 0.14457595985262625, 0.1473440500276704, 0.15851114516056355, 0.20977610962525492, 0.10201913214498952, 0.10850102505496434, 0.18529736346775488, 0.13009366519268484, 0.1440418433518179, 0.24454295695308717, 0.13780953422669442, 0.2245905493656474, 0.12379266096339112, 0.1237835291953337, 0.12808194128616204, 0.11048434242125481, 0.1729567901742074, 0.12448844499886037, 0.16766267828643325, 0.08915833918558014, 0.15206261537969112, 0.1681683422817338, 0.1129307522768936, 0.13696398766290757, 0.28527640347038546, 0.09874687184609714, 0.09084926377381049, 0.1443327269366672, 0.09293787992529332, 0.11961827084662453, 0.16712485392007137, 0.1065647148437077, 0.07866541674781231, 0.12532695887550233, 0.09639644514649146, 0.19324514263820267, 0.2835551877656291, 0.09681487470985421, 0.19789641482695458, 0.0965718103332385, 0.10019754360039389, 0.08052704870821008, 0.18479240427334465, 0.16647418480246298, 0.14449218047722695, 0.09755327621655119, 0.1101798531148703, 0.18414964118311483, 0.18852971824667147, 0.1415714243006322, 0.17260017624545484, 0.09004631169861363, 0.15986471527045773, 0.18667552500001847, 0.12163081446722632, 0.07686667294511873, 0.10682873172505249, 0.20604683957513303, 0.09529913910814831, 0.1542774521775784, 0.2946041674623567, 0.08760323432544548, 0.201897140472166, 0.20956163564997338, 0.16702680998752195, 0.18638700096597596, 0.12382258435771351, 0.23973049986506664, 0.21254910276301447, 0.1633783009263777, 0.06628432506394964, 0.14774564863933673, 0.15737998569684644, 0.11691448609194449, 0.09072592361800133, 0.14616605194826282, 0.09549400889344754, 0.0769712056423868, 0.17834292454344614, 0.15935140571767287, 0.0994898698803398, 0.1415004998806023, 0.14363797711989573, 0.16793505318703192, 0.09985674938727772, 0.14289906999516871, 0.11226833137052675, 0.09308627115622645, 0.11470789240012247, 0.16822276516787468, 0.17226401686428056, 0.13017303190164028, 0.13554913051907094, 0.1596304149396958, 0.20175864709721458, 0.164522024232053, 0.1476548672203095, 0.12341988257943623, 0.14697390698617505, 0.1760374289005995, 0.11287158730650142, 0.2051771152764559, 0.08368024362191077, 0.17628122872162252, 0.12627829452075306, 0.09523254308489063, 0.09551917488176016, 0.15132850396537012, 0.11091345125028204, 0.11587933276689823, 0.1403380380642991, 0.11879458077131741, 0.21056856629588913, 0.14019549974510748, 0.12076577096576653, 0.10926623963901114, 0.12099942012179284, 0.1674424126864441, 0.16293757054353916, 0.09325822725171044, 0.14792875897499824, 0.10973148483542666, 0.1776238437741995, 0.12273315370323197, 0.17375781170783505, 0.26253643175286634, 0.14062126076990558, 0.11156388288063389, 0.14584035732813422, 0.14613419801237124, 0.24832642006297267, 0.13457373205211856, 0.09244195290751035, 0.24070707810742242, 0.197415235001714, 0.11985496137171023, 0.2692296806602709, 0.1922786767564474, 0.16737498162734896, 0.1242393208667636, 0.14015250689079686, 0.18149243457423103, 0.11277115317962824, 0.1320180474149604, 0.1434070935412761, 0.12025561003435044, 0.14446504564294893, 0.29028707814793436, 0.14070671021697984, 0.19005737417647917, 0.09491020392987037, 0.10199441814855223, 0.1750277556599148, 0.21121591059190614, 0.15797036369481396, 0.1752635881665253, 0.18546593345461354, 0.17700541163644484, 0.16781257104969796, 0.1430006838974453, 0.12369260221960084, 0.22374422139217778, 0.17823789388902728, 0.1194395961600446, 0.15501130312200517], [0.04106358827782735, 0.042573991907580246, 0.0252480861250191, 0.02463775153662409, 0.020916081078711058, 0.03029099203676226, 0.023716253100804264, 0.0779921020711622, 0.057792458758359, 0.036080435308958256, 0.03194497969572342, 0.03691872702010217, 0.02959385777132646, 0.0708653010247696, 0.022743461248014244, 0.060227848439207005, 0.06983086016149291, 0.07986419879260563, 0.09318875073785744, 0.02111665630382636, 0.053880300538073626, 0.017700561081930515, 0.027014409086757132, 0.0777430085825824, 0.02818729735970978, 0.022820077701321533, 0.05663123800449314, 0.011641449114728359, 0.0561555740123074, 0.05490513082834021, 0.03063959651626647, 0.009460514580320207, 0.013470576922108811, 0.04433959474666946, 0.01370985778198848, 0.04665461669285451, 0.015902441640895222, 0.06545115082013993, 0.0161171875773899, 0.03967071785741756, 0.029740935161469445, 0.014513480184119076, 0.046558572249787475, 0.02588723136502649, 0.03935224361597531, 0.05833450426918365, 0.03299839464166472, 0.05591485769517961, 0.03598380480862914, 0.022901777148006425, 0.015356778279848158, 0.01807199498157828, 0.049892801400874896, 0.04022597838493605, 0.06509216967970133, 0.03655575073113845, 0.01845288049099186, 0.013062749058008196, 0.06339119401790443, 0.03671625764259408, 0.023623299822511695, 0.05422333555836832, 0.020086160793359724, 0.02455657877538714, 0.07902329472163994, 0.044340165482173045, 0.06104870398919429, 0.031031463896074606, 0.058867908308222416, 0.051667011237793395, 0.024561460670684616, 0.049101287018387556, 0.030148639493892272, 0.045280687796372565, 0.06122174026865152, 0.042061157329308416, 0.030967740702532956, 0.020152180335454403, 0.038036081579423724, 0.015352013212959132, 0.005853350326839474, 0.02733671185260098, 0.010537906163071674, 0.045634141612437465, 0.05484063388599504, 0.03111210997186361, 0.06464401590487649, 0.0732913329416225, 0.04240182130747745, 0.004523261290629425, 0.0025790553463007054, 0.007886249861199289, 0.020089470293192614, 0.1119439161172317, 0.04268995463667859, 0.06288075346439596, 0.061661371315318736, 0.053672219566520185, 0.07102535211391027, 0.015439446827757265, 0.014467417232451901, 0.05946896557185439, 0.050711259095659184, 0.025461937653862184, 0.0336460568641703, 0.017904679463695616, 0.05354549330208571, 0.033454818335632165, 0.02749857473968258, 0.02528607834040398, 0.07771315413617319, 0.021137038073051843, 0.029351758665495345, 0.032084807978882905, 0.07382967824777288, 0.00657547198634054, 0.0031328356483079976, 0.05671850307994793, 0.0418399800846894, 0.0019783063133570157, 0.02189793766686513, 0.040766641107057376, 0.023276219857976805, 0.07487927999107108, 0.044743346065403, 0.04226011802412329, 0.03597731221347086, 0.027416511401233655, 0.026322874924047824, 0.022490255782500874, 0.04245527509239413, 0.04539282774672874, 0.011118717638084726, 0.040409096381476814, 0.02857902492847174, 0.016706349410777612, 0.03597795955776688, 0.03936017645643123, 0.09419706034203691, 0.03613234159626788, 0.00746687226403024, 0.01892828975894278, 0.04799077745466944, 0.043665035177142396, 0.08619824439407357, 0.028200171467277314, 0.03223862311231994, 0.0069256301879161795, 0.09223831907635735, 0.06641369433172288, 0.01045699387172898, 0.10248162708575688, 0.042190170366196864, 0.0612923774057098, 0.034724643544083646, 0.025499853260454633, 0.014361438544226751, 0.002417718905264572, 0.07217934099777092, 0.09183025468261012, 0.038098609675803495, 0.06318231631490974, 0.02112009029294695, 0.02654921368605668, 0.02895096827658915, 0.02659789665842489, 0.09068005793397466, 0.031078798553696087, 0.06277108031715598, 0.007084139525109241, 0.05914805900125254, 0.053957391965893976, 0.029722493509912205, 0.009753379460063674, 0.022086044811012766, 0.044965657120149945, 0.06003351491545478, 0.06211999368162886, 0.03298539029915006, 0.05393108450657418, 0.04741087187862685, 0.0434748959847756, 0.022131445096625436, 0.047500044513013095, 0.03810396463039421, 0.06557962376504176, 0.06605131176090048, 0.03039383167971767, 0.03196957303331264, 0.034950838664606694, 0.061753328679309744, 0.027987210515646205, 0.04833853923745694, 0.05091898766676745, 0.021647151123972672, 0.04553609001900881, 0.02713570761824808, 0.020154978471597838, 0.02743711533595718, 0.023605107149529844, 0.057040869048045534, 0.023198701336138675, 0.0492415385651252, 0.07080519376623054, 0.023253009309090918, 0.035970103326103384, 0.016165730738711935, 0.044179915210172054, 0.054826311872250615, 0.05353390239179135, 0.013369509815088203, 0.04269543599577681, 0.03815778996795416, 0.04809030759779196, 0.012393976325139165, 0.055681798426855, 0.010057247277619618, 0.02533027586797553, 0.05160593870846976, 0.04676489887999431, 0.036485014002650015, 0.12656384613364935, 0.0320090112396546, 0.018011768979410973, 0.017124861328592225, 0.060028615783179, 0.049463895585147605, 0.024439872941002253, 0.06259836579462694, 0.04865392997500397, 0.05537118041707624, 0.009580674513633694, 0.02424585159807917, 0.023558540495052457, 0.06727872251142418, 0.04037281062694327, 0.024913401463099068, 0.003435090132575903, 0.009701352513905977, 0.01826146576223114, 0.006875325024368302, 0.04245201155783669, 0.027919884793640628, 0.04872226118741017, 0.07676820766421096, 0.04662003548395249, 0.0647619244973025, 0.04082382957060491, 0.05213767650627321, 0.04138836359244682, 0.016859831295967583, 0.013865363096908457, 0.06644754009621759, 0.039237361070850206, 0.023152188307815985, 0.024767741335616, 0.008070876093340978, 0.009490053973070556, 0.015045539738850729, 0.048209346169906284, 0.04477653682472245, 0.02168247160772162, 0.04423224667627965, 0.02751689381717194, 0.029758798416643858, 0.046392193274392236, 0.01710256433955604, 0.06220517882836923, 0.05245952919546155, 0.0828530908291859, 0.055537812201486486, 0.06436086980806244, 0.05052552107841738, 0.031251285165067644, 0.02441091290224464, 0.045632666893183224, 0.05660950792052093, 0.07223779350639352, 0.07625555694704095, 0.027752848897850322, 0.013525951672495614, 0.011419598670345883, 0.041363975183377345, 0.039025859516714854, 0.051410203243816094, 0.09493199913131614, 0.10175281699987189, 0.04523473784267422, 0.002707651583477855, 0.02602023380478063, 0.07712803150136625, 0.008264298930073218, 0.02218746910652807, 0.03483838078776195, 0.05538838292141596, 0.06609787458493825, 0.027251591823334177, 0.026639449267437863, 0.026680480936662327, 0.046645212963583975, 0.028815619692566897, 0.021785926036236268, 0.059594657617591085, 0.02697400560963058, 0.05875657658062636, 0.0584934062264379, 0.013679809898378388, 0.0673056811454796, 0.041139224138591564, 0.05671272677699885, 0.08843895964204304, 0.037314786816075925, 0.038343585441790284, 0.02555409037027388, 0.008597336502956047, 0.051770172637677005, 0.014017556996775732, 0.03188526888768519, 0.01914843086964421, 0.06653309679560124, 0.16657152393412206, 0.04183925230116133, 0.04121444248143704, 0.004064553218232769, 0.025883377942767356, 0.04183362921579711, 0.060620675344140305, 0.039233021182759155, 0.036487791071375536, 0.084594332072283, 0.00814004042636483, 0.022854189681369933, 0.04436171170504344, 0.02813395082710251, 0.07335050557289394, 0.03299161093309522, 0.0277068663854152, 0.025883923780413407, 0.0716781969212236, 0.03314881983603681, 0.027609370205731645, 0.05249212623663968, 0.0803339409251367, 0.028168089620228258, 0.02649129552376126, 0.03591718963317333, 0.013529647089120363, 0.02717727554901954, 0.01906848576430592, 0.01567258174726439, 0.0271055007713937, 0.03485691628508991, 0.11866168749909248, 0.1869558365715127, 0.076271997193896, 0.23436007029827566, 0.10852905621211376, 0.1276065301029913, 0.0844131216346737, 0.14669972411807508, 0.24276240007771602, 0.13956137812666355, 0.08999687604485981, 0.14239945809446997, 0.062247715860364906, 0.1014000641542577, 0.20615934724769286, 0.08800435030171949, 0.10103349874336874, 0.19074981040771932, 0.16178612507158713, 0.08735227924320968, 0.2526380701531326, 0.09670337827335443, 0.18875801244810705, 0.12867343011161975, 0.15415872387107343, 0.1450037127060275, 0.14517746144725432, 0.17359684131318526, 0.08819368127132617, 0.12549679290743607, 0.12426909104350115, 0.1090002998769764, 0.12620607541213114, 0.10561134906545763, 0.0830288773642913, 0.15324174726922668, 0.16952716775478857, 0.1428720577349586, 0.09263528285608177, 0.15506479138087842, 0.12152532416005289, 0.11778412612094996, 0.13321594845864082, 0.1594446232962993, 0.17184850609590932, 0.2371444628243485, 0.1603838317697087, 0.16515236137615097, 0.0862590641143822, 0.09658233638131812, 0.15070261013123298, 0.08221048095654096, 0.1610735407279384, 0.09147708814951683, 0.16179815265199832, 0.1473033860806496, 0.16514379651315753, 0.16259195763737927, 0.1580817988442798, 0.10568446449695096, 0.12025659062689352, 0.19554708363308063, 0.20568429612584654, 0.12150316123640346, 0.1235103115980183, 0.12701725527163477, 0.18159528953894494, 0.1621808135701764, 0.16224318844897134, 0.13021925764699138, 0.14197282372943817, 0.1725613509094523, 0.13666579559926065, 0.12843228861569397, 0.17221155516322584, 0.07777597334596419, 0.16935254567332808, 0.1062825646611952, 0.10892873960396937, 0.1200843434179983, 0.09403690200058684, 0.11275340292242267, 0.0969237051603775, 0.1437065573108773, 0.13633711323622735, 0.2078865844035341, 0.12431732393921384, 0.25688118601758636, 0.15408927033985817, 0.10589340731741921, 0.07174679243396367, 0.18156087686938627, 0.1463135391954453, 0.24886594514452645, 0.12489631787062654, 0.17732077939135416, 0.1590207621695534, 0.275977689532503, 0.13691482013992726, 0.15721644124677106, 0.11948910842259085, 0.1937198413596038, 0.22081408829938984, 0.1531965634034526, 0.2066253432102742, 0.09741776292362521, 0.15120761529091867, 0.11904447099133847, 0.08918048678747109, 0.22924427303575703, 0.21303048177111536, 0.06131332991043888, 0.11423779786714625, 0.10030236741107318, 0.16213084931575483, 0.12458700221031906, 0.120071871506591, 0.18506513157438848, 0.1498802147445179, 0.09773311535677603, 0.11008543277820272, 0.13353647964615978, 0.12693939775589014, 0.18362120905470464, 0.1988740196271289, 0.12746100404089497, 0.256074526076836, 0.186183589300321, 0.1078955168204923, 0.20291046029137028, 0.15652970470968755, 0.1936741825193167, 0.07286021696223367, 0.10627968417059992, 0.15412259516456436, 0.14194017306210535, 0.11113058355066086, 0.1179838682254476, 0.23138653066369796, 0.09247694780389148, 0.14583275773592536, 0.12431079687009897, 0.06911283659358179, 0.23366112231967912, 0.2817499475373376, 0.12825991117185162, 0.16975802068989124, 0.15607389771649915, 0.17023503299682372, 0.1229637461684404, 0.0869027235274834, 0.30572564972023814, 0.12566591447760023, 0.16941377142023656, 0.14026418718839848, 0.12960942101574716, 0.06579323972184813, 0.15086693599099113, 0.13734188351419666, 0.1564310479067987, 0.10936381625792674, 0.15055893800191342, 0.20069357037784594, 0.1387891002119549, 0.08722019036330524, 0.1855255197733641, 0.2749253605161944, 0.10582900230562496, 0.16391059413792627, 0.06637702936366682, 0.1477624872519124, 0.1761770101204034, 0.13804225641633236, 0.08583548644016828, 0.13644750650611617, 0.17059489513837522], [0.07442746431596818, 0.011193612308782196, 0.050090195445884625, 0.04694433582405891, 0.04080829330750051, 0.020898870913492098, 0.027524512561578906, 0.018057410582719792, 0.10896744236590401, 0.05340197055991139, 0.009673289755629677, 0.05351489958082957, 0.03483150514864153, 0.03686048901609836, 0.021744070822493206, 0.05454392420248159, 0.05558087783414991, 0.011108825527762455, 0.015623627771292965, 0.002500435573071422, 0.05974281519170731, 0.06357234316847979, 0.018297841532095786, 0.06170116192210586, 0.08083931380702604, 0.02316799270169389, 0.05373000557864866, 0.04843154231146459, 0.02028721099298808, 0.020668339735317617, 0.052066935947345155, 0.04817135203930159, 0.058286275203910574, 0.035362779463250796, 0.04148684802555269, 0.01912554782334595, 0.04474099417547545, 0.05975429884969227, 0.05551396388440363, 0.014147912602751486, 0.029829075492377725, 0.046952778112984477, 0.0449068024153671, 0.07418561035827284, 0.034821067200673204, 0.010717203296090086, 0.028798039889924472, 0.028758117132970405, 0.026451037603340326, 0.010754741604379829, 0.04147827550167999, 0.04949518261597522, 0.022574496725874565, 0.026498450784974044, 0.009235682138692467, 0.06398306205688466, 0.03756836574945239, 0.056395168010626114, 0.039069641441587484, 0.046739725230802456, 0.03669186157264537, 0.04101401089780754, 0.031704069941394755, 0.03292324524673243, 0.0634874951004261, 0.02012998868350781, 0.030889946389042085, 0.09440217272288377, 0.12290981357857106, 0.015498225881357588, 0.03609175808847912, 0.08063204871911196, 0.04560376239580013, 0.07348591927438974, 0.042912572126595244, 0.03190666380819054, 0.02444745529623282, 0.0638289404882779, 0.0472063685376798, 0.0234211158127554, 0.05231661932362665, 0.009762305341991446, 0.04352025605077225, 0.03483027557752306, 0.0341962727027074, 0.05179774414207186, 0.05497130167279994, 0.04561369855617804, 0.010443687882094134, 0.06695573218166828, 0.04532066226426152, 0.03523994492547166, 0.0252707259384014, 0.04776996027137484, 0.022499326263524355, 0.042041365447784626, 0.05285988674469052, 0.034311319956736225, 0.02796771740841289, 0.0894101829298081, 0.06103323284356345, 0.0479051671291311, 0.06440533355118767, 0.04503301540089231, 0.011682659857005123, 0.03797001415683377, 0.01598188017059358, 0.08340921703605883, 0.04208477582001398, 0.021986516583110058, 0.027047766470200112, 0.020761097661189495, 0.08641435013663384, 0.03527364896370038, 0.016919438682136037, 0.03153252561817006, 0.0027707281509309167, 0.05228951896330523, 0.0069175666337081745, 0.02885844975319361, 0.05050112883890829, 0.01453780156049517, 0.05685327326758735, 0.02811263826104903, 0.03730786521168005, 0.023068811128576918, 0.030623357367491534, 0.08525376523574514, 0.040120572347434304, 0.02988598816427252, 0.014833997965099351, 0.01649552775967506, 0.028041976226133206, 0.04841112223784289, 0.060085493981117205, 0.006242272098578754, 0.061032708073335315, 0.01988112885174492, 0.05283946667106883, 0.01364618821460153, 0.051287284436365294, 0.07940900466975667, 0.015343202244220002, 0.05837791081097338, 0.023574352549809604, 0.04843815365025113, 0.031218454467072606, 0.034166789808941465, 0.08657970255421055, 0.027314171630648837, 0.01953582621119436, 0.013568431247896967, 0.048224721554546594, 0.06460415635017619, 0.05056840668041861, 0.04275593778959686, 0.05236484072802048, 0.07033905990782284, 0.0031792249055504203, 0.04832797871542074, 0.06388058247525366, 0.03559802974303884, 0.05275775190262545, 0.01267880877299655, 0.017293825850731904, 0.010907079145732907, 0.06541539749671375, 0.028776664121617234, 0.00818502702449839, 0.0536116756378643, 0.09508834235490331, 0.018834114570410985, 0.023178855828460188, 0.023040561636369077, 0.018352195470323487, 0.034538656548266454, 0.06448320638869079, 0.024086526377246748, 0.03742476256804601, 0.01539543124606773, 0.031424455509911624, 0.06752230782782839, 0.025430610403418544, 0.029206726730110186, 0.04296699501273613, 0.04731885705804152, 0.022359136003820647, 0.061251039301315625, 0.021633826939749624, 0.044468642257514505, 0.0695391338799269, 0.04746022709314862, 0.10298150711722913, 0.014370388366402158, 0.024008287732759793, 0.03393287635258129, 0.05102796750443597, 0.007333932068919944, 0.02423681559101228, 0.026525602856230353, 0.019409105692419316, 0.014920063155342736, 0.05801979534988923, 0.04438781615106329, 0.02090825357534472, 0.06311116589894218, 0.00822055147915718, 0.027963580533621774, 0.045003865755373434, 0.08575385211095696, 0.01763712517136047, 0.01873858532147302, 0.03788639949033818, 0.012992700851041705, 0.06276309768098497, 0.08264110663965826, 0.0371547089138579, 0.034337006884837346, 0.039411760986812656, 0.07779697947684797, 0.02122561315885715, 0.024833017772424127, 0.049357474481146184, 0.03146432272549118, 0.05461730010386917, 0.059346104220997904, 0.04284265128174617, 0.07116012996242893, 0.025897468214914687, 0.07588955078033671, 0.0462629848850831, 0.020316115490371184, 0.03927964912427049, 0.015727919150864886, 0.04216191321310978, 0.02432189731588287, 0.056499152955028324, 0.04338650476007212, 0.010430677793920042, 0.032523707411582434, 0.07019433823804702, 0.01118641299751377, 0.01596782533001275, 0.027701317993623596, 0.05128776707175759, 0.029654123993109793, 0.032858112451410106, 0.017809594545753735, 0.06399900434658894, 0.04907718972272931, 0.02234400576731611, 0.0427413399841997, 0.044712782987663825, 0.06279442684664842, 0.011749343980374116, 0.05220431849480637, 0.041235287733856714, 0.02709608172036467, 0.02016014573464711, 0.04109520472646241, 0.05562289775679669, 0.04208320917020883, 0.048406123514136964, 0.03478220739071408, 0.03657030257126016, 0.024728042659379786, 0.05386525457124076, 0.051873751555479346, 0.02124262605643561, 0.033443399795120766, 0.10577287870429217, 0.038388746324926615, 0.007552216852819848, 0.024215349807373943, 0.03532008538323064, 0.020979530395819776, 0.05817752136217971, 0.07965059049667851, 0.03705464633962801, 0.0629393898341204, 0.032673749561992385, 0.061375915463412964, 0.0662965058619457, 0.08173618826173967, 0.015118626442046897, 0.006975060574815519, 0.018566797765332366, 0.04064473736610624, 0.033820904941568454, 0.05192332127461991, 0.014423152672186976, 0.09686581189593962, 0.1151478490341575, 0.041953456858473445, 0.06203463616510553, 0.021626893844034885, 0.0533948497726552, 0.0793486446022026, 0.049015818419115204, 0.06453946788584994, 0.05773212550388229, 0.026543920018499898, 0.03142010604572152, 0.12271910365070067, 0.007679233751860598, 0.06179164839728225, 0.003612680804742981, 0.053981902949031324, 0.018971160039185517, 0.033454278243645545, 0.04487663387290893, 0.05162384601369981, 0.07126512997333082, 0.01645980124932624, 0.05651127629643006, 0.03257357973545309, 0.007398270526825781, 0.047486672448294784, 0.030722630871159416, 0.06226471152096506, 0.026252335463199886, 0.08409272068210187, 0.03687468462533528, 0.04453478245845726, 0.07118160340694651, 0.005269850840822103, 0.06826316847676231, 0.04023109585227024, 0.06613536692795254, 0.025639681543614116, 0.04191124924428521, 0.0631858364889218, 0.030216110772603465, 0.03684147471381772, 0.04668714095567984, 0.041951059003270445, 0.0935249254407902, 0.02719735279829512, 0.06366676350514736, 0.005161699814526665, 0.010993362671034712, 0.011890443011877999, 0.0390629151896123, 0.04906346908800545, 0.05790542225323378, 0.015993472996107753, 0.05994678227110736, 0.0499622625929694, 0.06447907717477891, 0.037007145057882995, 0.06092499611118148, 0.04081790771095022, 0.20496238083128007, 0.17574496717462618, 0.1311877919661422, 0.10695719700907508, 0.17684310824880678, 0.22155753066462858, 0.15919858649853738, 0.09226840334914385, 0.1837033643237045, 0.08034234490966605, 0.10131859070351047, 0.1409608981902561, 0.0911658879129156, 0.16747443516167904, 0.16110318833060805, 0.23584101018646073, 0.15114101160678173, 0.11105536137737575, 0.11075888535067921, 0.07533569219371966, 0.10401751079987134, 0.09602772702853526, 0.10146856773644687, 0.14935380508822782, 0.1422988247847365, 0.1022813257370745, 0.08009346592570506, 0.11342157714910085, 0.14861600113011178, 0.2430881100196031, 0.11993859519040394, 0.13076906362848897, 0.14491657786551984, 0.2251224901767508, 0.17602768426220264, 0.19113947336952533, 0.19948471427684833, 0.12892810838116756, 0.11789215217915275, 0.16501788230192277, 0.15086365713467523, 0.1600797255072863, 0.1075723273078761, 0.22383678013518934, 0.13366345105873, 0.14633083746077555, 0.08525332090474906, 0.2279212851558001, 0.1583017580090992, 0.15665365773583614, 0.1541676870997875, 0.09287155203280911, 0.16846310227147995, 0.10977425552423924, 0.14219327319052913, 0.3007500925131383, 0.14927249251594468, 0.10687847381397601, 0.12735351424423919, 0.11815583964269008, 0.11389865840394651, 0.18556474347508725, 0.10272908114617872, 0.17180695348689634, 0.2443396678615001, 0.08314438810151431, 0.1358490845849437, 0.16451834701001644, 0.14035663867910064, 0.1351462908449673, 0.13146810353763644, 0.16053881135679063, 0.12846095562582055, 0.14962781941698444, 0.1684170603872307, 0.09258781604829336, 0.11177861732580971, 0.2634349916010134, 0.19983233433336983, 0.1201391110437051, 0.23380428883096865, 0.12714469399783881, 0.13428674019392461, 0.12640339667878805, 0.19377516822949534, 0.10017939497746768, 0.10579925511152515, 0.1934674919973458, 0.18575428894931273, 0.1264692649185177, 0.11756003774221867, 0.17160931812419047, 0.11551917185105624, 0.23531077009054924, 0.19202076559585912, 0.09985078922322682, 0.17981807280692363, 0.14612318166802007, 0.10588523315926714, 0.15407551140073808, 0.1053786421975782, 0.18148057553316319, 0.13214774610054109, 0.19364808956461568, 0.129102255488115, 0.1442086973017262, 0.12441831731027174, 0.16410145728338152, 0.06824222363291249, 0.2881967612812596, 0.12889043217705143, 0.1932927933070929, 0.18176816493993808, 0.13183383391268794, 0.1174968125058278, 0.19693356488020192, 0.18450366573468333, 0.18304656650270187, 0.1545725186024943, 0.07882057253511683, 0.17150171341434603, 0.13388385455454552, 0.1180020704745285, 0.13176663267997005, 0.09547645781910229, 0.10280694632280259, 0.17472637667050286, 0.22252243372701833, 0.14873810022348358, 0.21480751464203482, 0.10179118268311986, 0.14360744085523391, 0.10139102431675119, 0.10521341235406938, 0.2181814118258415, 0.11502289243282811, 0.12389283462037003, 0.12080752275763981, 0.2352774912311185, 0.15168753873196342, 0.11336322423190841, 0.14424572999198593, 0.10292058014461111, 0.13965295627713203, 0.07780487784334729, 0.18882343635684062, 0.1147584925075212, 0.15474946959124458, 0.17847003385184274, 0.09820973695886713, 0.17360900678942282, 0.1309907081867418, 0.13791765987632737, 0.11507419734111718, 0.1638809618570151, 0.07184957078988514, 0.1871127773436808, 0.139615218785982, 0.0860313751224068, 0.23932170002691208, 0.209723862428819, 0.09532546955010585, 0.2362727926623437, 0.09676481852488172, 0.09740080939786089, 0.1742098648701945, 0.20189288102330702, 0.12027514527641958, 0.11111118620441807, 0.19177051531451364, 0.11894383768160498, 0.13321092292185754, 0.18118831299005017, 0.15180102699706632, 0.09166601309252363, 0.19877471931038365], [0.027097929907482, 0.02115072040337949, 0.027280255003021132, 0.0313901769057397, 0.0578516275591908, 0.06059022717958978, 0.009433222698017715, 0.013520140895589948, 0.06012855195290139, 0.07211665968380629, 0.07287235179495427, 0.047798642603259896, 0.0397349581603081, 0.02196994801652768, 0.06761601570272638, 0.03381900121307662, 0.036853544429064765, 0.06622413353573892, 0.033153650020399404, 0.0044281174796783635, 0.037801156887003494, 0.02616709477508501, 0.025911422506455454, 0.03381258522671077, 0.069426181876371, 0.03498944183511119, 0.03528404477683287, 0.07487535762089877, 0.04114579717298189, 0.0630717966405134, 0.05277252973868482, 0.02499021709926667, 0.07596746192223604, 0.07015720595635715, 0.048049459789669326, 0.040552780002115235, 0.037637386440990434, 0.10096634347592631, 0.05891877271595502, 0.021177305569571835, 0.019593667764697346, 0.031170556734826778, 0.04319301776347622, 0.049462650692270654, 0.08328513377496312, 0.07644902479143874, 0.08462434739715631, 0.018301744750069997, 0.10667126235221663, 0.04000587366341103, 0.05424711875797761, 0.044202422873387416, 0.03893216313313573, 0.0163760352804656, 0.03360390670657639, 0.06110611461823987, 0.03640586179831336, 0.015606099679585428, 0.03228404829579015, 0.02538517372862947, 0.025800075457100908, 0.03743627303910833, 0.015283151484665372, 0.018846822053854986, 0.03502587314635035, 0.08604106613464894, 0.016443682759399378, 0.05282976799794743, 0.0356781663703582, 0.033812489465720234, 0.022108286258674437, 0.055447701109393, 0.015990927668979332, 0.04521639386732732, 0.035402367056737986, 0.07150302325645763, 0.026972946493075262, 0.024160231696441773, 0.028658770850949714, 0.03386826066660785, 0.032299186193173936, 0.049601883342069004, 0.030555614127567222, 0.03158765138998147, 0.03761683230198199, 0.06486436577453729, 0.012772261923659715, 0.05677481437282217, 0.038002186019213936, 0.07113838072625861, 0.021991764285391378, 0.02383245714759875, 0.023778838653778358, 0.02698786414018081, 0.09154249673649188, 0.014851643842825247, 0.018985989586179777, 0.05230114051711656, 0.03998938362084089, 0.03585527057669336, 0.026421334459296158, 0.0122888365031911, 0.04281336374040093, 0.03360114879004898, 0.03821326239455131, 0.0441976769586965, 0.06522225140924416, 0.021334930075212352, 0.041479930251596436, 0.024660410502204494, 0.016401454077793226, 0.04272420259733354, 0.08167700796958902, 0.065242376539015, 0.02094637794089654, 0.015994328141753233, 0.03240974417196647, 0.022883232074579405, 0.05917114123041111, 0.01755632779320642, 0.03409556661462111, 0.08644071888298759, 0.0536076306936241, 0.017949587537816936, 0.02226471566715308, 0.04354817995561227, 0.03548706956808606, 0.05580038500709399, 0.039587110851801215, 0.04474119718877539, 0.06864818128486795, 0.059609320540461815, 0.047825064975768335, 0.05430766268663349, 0.014972240446255574, 0.028623563365169594, 0.012889669686105224, 0.007111745024655736, 0.06778191970360857, 0.01765520867681311, 0.042473029180039326, 0.048896270398531234, 0.033565161809805906, 0.043113344619351054, 0.01162115544561417, 0.07281529356635387, 0.013951974124797891, 0.03376294655965702, 0.04719326077329536, 0.036926617725722255, 0.03460303857742298, 0.017706055847567417, 0.04899733271750231, 0.08086473260435366, 0.049340325602961164, 0.03370401907652136, 0.058149137804585124, 0.03752234684784086, 0.051155410061079654, 0.02708553077442752, 0.015255962066622752, 0.030496904979489987, 0.022663077557339303, 0.07721216327721074, 0.03189542912878096, 0.03217478883602927, 0.031126184922252453, 0.034853652750532475, 0.0061493911198340365, 0.028450825860002832, 0.04182371986849655, 0.0036751308559154674, 0.055569122214951826, 0.11476061457107145, 0.05278133974981405, 0.08521619628393844, 0.036784152184883435, 0.04880593331050008, 0.05365781711354371, 0.05128340037058919, 0.07566734697789916, 0.030401904331219774, 0.003995044624447943, 0.009052047032802817, 0.07162519129774264, 0.06249353815350802, 0.03840872972843148, 0.01775116118932924, 0.03157294250183529, 0.09191256316919481, 0.031013849619475585, 0.005880756164720703, 0.040842951125194954, 0.041857014049685774, 0.030310829883561503, 0.05063015336711561, 0.0494458005883761, 0.03169561424593051, 0.0389249810588456, 0.053919482104960954, 0.010973232753214338, 0.03931465934241011, 0.0673180458045775, 0.050348493480874654, 0.06274549298048501, 0.060215299919007294, 0.01008021172075983, 0.03238139508832847, 0.061382653206707015, 0.02052553137013268, 0.08819823949447564, 0.038114099973632444, 0.02142014395024988, 0.05051884079171766, 0.0734448722834068, 0.0375997600325894, 0.006343179284745167, 0.0335768829550474, 0.011721392304846838, 0.058753293893870816, 0.03793553253936191, 0.018423307581894824, 0.049370497975858955, 0.020821394526489803, 0.02898975339297566, 0.04336537222468084, 0.09553278060329538, 0.03162291250191629, 0.042473029180039326, 0.019181849540121133, 0.018021222504396594, 0.06308268274991743, 0.030038462643842065, 0.02000885103048096, 0.024038061739936955, 0.029844994799444274, 0.023046460513386036, 0.024355022957728758, 0.013242491479632596, 0.046112195798946966, 0.04852547618230024, 0.01968070875943428, 0.054992273329727115, 0.061232216521016056, 0.04005407208516713, 0.04491868060863307, 0.024098569279416435, 0.04329732446480663, 0.026292022648117235, 0.05380137049923501, 0.08085292718944051, 0.09050718253298153, 0.03553093576263036, 0.022679544617271712, 0.0022940220397656727, 0.04043095286995654, 0.08048716617087204, 0.019254286983801473, 0.03565002030002014, 0.06679496863075803, 0.02628323753484555, 0.037207894568001075, 0.01624774619666559, 0.05802698125461898, 0.03702068183150503, 0.016957342797409625, 0.0251752445699587, 0.040327990652933236, 0.025317916954537074, 0.05034680042656199, 0.041749620014020515, 0.04771486322786059, 0.04840490926477698, 0.008246431844459187, 0.039518120803780137, 0.09728672358417705, 0.021736295030061758, 0.04793415972662549, 0.05021393013697478, 0.039906879781835505, 0.07990424986928701, 0.05203329702659, 0.1225496756453668, 0.032343400957723784, 0.007943323890363138, 0.11378150057768631, 0.017547954452194033, 0.018031283154062206, 0.09985530148110083, 0.02042921496585252, 0.03162291250191629, 0.06615258092361112, 0.01920847109548988, 0.021476807643569285, 0.024633160754737836, 0.018371027826722112, 0.04836828643155675, 0.03555370772617959, 0.030185815825637792, 0.022266831985043905, 0.023774600272337278, 0.01878969487734139, 0.018295631368434238, 0.025327569662383007, 0.014171897858050803, 0.038191892371903506, 0.04997455830415411, 0.03571434487258235, 0.03521831826336923, 0.033736099008350603, 0.025844996937760906, 0.08160619080186853, 0.07535462988720787, 0.03780779503886739, 0.021731608487184972, 0.08567510593322017, 0.04541397177343888, 0.02553952895405312, 0.07222333742726235, 0.039176100849985115, 0.09117803806739469, 0.015106487778886674, 0.013392915716394784, 0.019984152355802157, 0.016891125987674442, 0.01760699876373814, 0.041771058984581506, 0.04102802264594263, 0.02990221007606916, 0.03283684202019246, 0.03484956567145644, 0.024805917412102706, 0.07260606729335363, 0.04428838176893131, 0.03201409614825201, 0.07467664207421965, 0.024498884693809578, 0.013678776637290516, 0.01922344236875013, 0.04366360259272399, 0.05007928252340325, 0.011357736112850328, 0.017417784622539918, 0.019742363515580376, 0.04661152807755336, 0.020630318791635578, 0.05796274478216806, 0.03470722270468551, 0.044476272493240335, 0.02562561808454414, 0.02533669376956119, 0.023308227011453242, 0.1519913232374576, 0.1232979060601323, 0.16645342381971498, 0.1393586252966235, 0.21914939456168683, 0.15793051180099288, 0.06558465696270428, 0.18143565213728338, 0.15508682406958074, 0.1529238973894427, 0.15011822294083335, 0.11181463111913013, 0.13284647957451884, 0.20174059806571853, 0.12812796018777356, 0.11234461074514736, 0.06902046171167205, 0.07694839154400172, 0.19872109315568404, 0.12028163404113824, 0.1336674040724193, 0.2509113386153214, 0.09991211456156547, 0.1477789887858014, 0.1082139642488572, 0.15774888767590448, 0.12079321223521426, 0.171287193473789, 0.11013540469350354, 0.2887209186390523, 0.1727707533826751, 0.09528270652217251, 0.19018817602867083, 0.19228442241587948, 0.19271706291023763, 0.23439518776872467, 0.16653044629962216, 0.22882326175608944, 0.14985700228041218, 0.10881736574153747, 0.07997835355420267, 0.15299024060368538, 0.14002605641801513, 0.09744186404972308, 0.14331756850644467, 0.14004542312074092, 0.15675320320071714, 0.11071128064706443, 0.17560923171620216, 0.1127238242676662, 0.21233194747999792, 0.15521198751464968, 0.2294413721369159, 0.09721390692697418, 0.13752519303271848, 0.18702991727379062, 0.12976147414695832, 0.1270435550700753, 0.10070012792223886, 0.11135880880418325, 0.16370981781473085, 0.08844154135834786, 0.07506578409623715, 0.10265910667517494, 0.15491817747392964, 0.19698683863445637, 0.08510224836608095, 0.22831954362411655, 0.11281757044696039, 0.19815182854090968, 0.08362140806932604, 0.1973776660499073, 0.1417497542476462, 0.18185088711400188, 0.20211162976920607, 0.2772669235785162, 0.07661584809783005, 0.1292264843059163, 0.09104711364113516, 0.1101956575087482, 0.18563168423791088, 0.1838184613734484, 0.19337684847414496, 0.15092034764107198, 0.13748564757406712, 0.19149336002526746, 0.11796783400519241, 0.14311689943555864, 0.17244665222542901, 0.111137340446153, 0.08505924785089108, 0.14061280315922153, 0.08657595638426081, 0.1403021545059258, 0.18851879383287123, 0.2042493061913598, 0.08450938824323878, 0.142284958593307, 0.2131340108932026, 0.14514727758303766, 0.1551529834227216, 0.1251064098229812, 0.12637901976103746, 0.12976775606793742, 0.13074932920355953, 0.15451515393872417, 0.15064153760190935, 0.179972087123221, 0.10659233231337802, 0.22159339890124338, 0.0809045078893823, 0.1357566943812755, 0.19685835036779606, 0.12455982907164483, 0.20804407675900768, 0.12967440059348462, 0.1131025857983097, 0.07899606029593176, 0.10105068975638959, 0.10844929879831691, 0.13869494800606083, 0.1434038606502356, 0.1073755499636454, 0.08973087499579115, 0.15459876477478013, 0.12996131584288614, 0.20749802460833905, 0.12488291899283087, 0.13777034116848824, 0.162513954564929, 0.18956307892597493, 0.18921997878820668, 0.10310986514894233, 0.14955945373062166, 0.0746139760820135, 0.2155098180857397, 0.16409355125600295, 0.0674886076200393, 0.24779037302059514, 0.2398656684184267, 0.12203200705229275, 0.22148335803179975, 0.13485772084564934, 0.14963439245137478, 0.23128890041862768, 0.15632399478025977, 0.09578331433717283, 0.13751013174412713, 0.15707813173292146, 0.12395059764986077, 0.12979012583532643, 0.10199481651427285, 0.14464280868489898, 0.13585041757793198, 0.11682362040324558, 0.15168983699573627, 0.08483198786815328, 0.1102743883647265, 0.25470877516894574, 0.20177262054095346, 0.07896325641101407, 0.11769293867532285, 0.0986856384383094, 0.17311854197853999, 0.09991029127230568, 0.14551771173794426, 0.22004073786158718, 0.09450262217151542, 0.13466299661705572, 0.15162159388344135, 0.07568023257678555, 0.1298050492280914, 0.1100455885452609, 0.22446615200850273, 0.15720844328884157, 0.11887878149507508], [0.014762530580253131, 0.07281528590547462, 0.026399234737900477, 0.017347725881864468, 0.03922819099839657, 0.030128556498957258, 0.032401118021939075, 0.06896475945869762, 0.05168368514146536, 0.06369055053519626, 0.0271459482985759, 0.03537763007766297, 0.020545237066764987, 0.04445134016174463, 0.03595398483617652, 0.07908338665842049, 0.02095979214045069, 0.027251086205304153, 0.017196800815121784, 0.01729446553414868, 0.03053020299111884, 0.03465864123896726, 0.041590151151702295, 0.05851278442048258, 0.0012116298180884653, 0.03490678860896057, 0.028866079988919442, 0.03789988263780552, 0.038231407187037894, 0.016265312592769345, 0.03480422858809752, 0.08099053190239976, 0.04055996590684499, 0.01814663109760131, 0.046026907230336825, 0.021471584839145505, 0.06863275993495219, 0.04704215376067066, 0.057707863499320326, 0.01991314749654022, 0.020300016152642427, 0.041267245091618075, 0.020942832869026932, 0.03045914067526258, 0.06538083160957021, 0.021293565157740828, 0.03478949288687399, 0.07662259733244296, 0.056548998465821634, 0.02489582549089626, 0.019533780756436532, 0.051618445093833634, 0.06063811533573655, 0.03967830595830756, 0.0067488103917229085, 0.027513503878106995, 0.04354146136451633, 0.01842945160704755, 0.03415012356614874, 0.012847273422765636, 0.021654450026671254, 0.03967496198451808, 0.015405053310396691, 0.03530934100009261, 0.04847484160094492, 0.04348935206390677, 0.06194056056800389, 0.08283252902929822, 0.01633452097584884, 0.05153651965121108, 0.03481154855821402, 0.04418180361690541, 0.04045170236138567, 0.06596974637960235, 0.02756295102317968, 0.0769338741778366, 0.029957906583384163, 0.07114062536387675, 0.04832731221892661, 0.056197750982978655, 0.022635779929377382, 0.03696307585003876, 0.050311257777314995, 0.013423067021874652, 0.05658826430238063, 0.05754004044818783, 0.0586638952635469, 0.033553701134458665, 0.03580347920257238, 0.08028811354550623, 0.04085465311823834, 0.08587948286965971, 0.007793228592603438, 0.05419499796604919, 0.04360913757174727, 0.03182588941267422, 0.04787779480759655, 0.03846882166521203, 0.04091915389102313, 0.07590392258979621, 0.036062190925041517, 0.02817120759808008, 0.07400685140202123, 0.0503661135031331, 0.03237240504653704, 0.015319033127818859, 0.08645047884314291, 0.029866803407428727, 0.04322291434472127, 0.017253912669876893, 0.023380421222217625, 0.011323087871254934, 0.03820544829772365, 0.045087059073510675, 0.020762756241545565, 0.022971148324769833, 0.16673313784262828, 0.0364575382592457, 0.0709480231988334, 0.05900796833297899, 0.015815672607371406, 0.04040739566628491, 0.04929012769172269, 0.036876906280315695, 0.0291835161812243, 0.06075157678776211, 0.033644926884481986, 0.08467054249899042, 0.03293987701556856, 0.1290382411811621, 0.014131556625568099, 0.009838849974555836, 0.06553187350472135, 0.0413577928538284, 0.03778785377019837, 0.02754869795734844, 0.05435529037288601, 0.05945362083073105, 0.02311240727712791, 0.04307559563688213, 0.05776987831679083, 0.05084002698441187, 0.04957935652665554, 0.02374880034626732, 0.03370819425570869, 0.05223785399369175, 0.04870440750833481, 0.04358251601637852, 0.06362492361316277, 0.0455128928766616, 0.04851739395469908, 0.031754175922082316, 0.03374056913138878, 0.022199289843199715, 0.048729090861255125, 0.031033733431550286, 0.023439913695197434, 0.04098552391834317, 0.1273504575534213, 0.06600625046919431, 0.0811262903434615, 0.03523380473075855, 0.03804955706601182, 0.036225118674337864, 0.017451557608681823, 0.04928510981581865, 0.03566898097614608, 0.0855772688444103, 0.03920222061776346, 0.04351672438544132, 0.057055064657282446, 0.010328613814987965, 0.048364938627327644, 0.02649945819059447, 0.039223514031618834, 0.026422474015083526, 0.0950902192703178, 0.024338201582131368, 0.011634986205477149, 0.037384290143006274, 0.05696992164537792, 0.07422169309950645, 0.04426048084672901, 0.03356225450613326, 0.04043332391208218, 0.0343050878314722, 0.006407050429017193, 0.013390388583854563, 0.023535578924741958, 0.012830761355167676, 0.01730372562193342, 0.03533736449636279, 0.03137838872780483, 0.012288121168591805, 0.022823469555606286, 0.0023087754567724566, 0.04712216781392213, 0.05072565771819604, 0.03174452704467601, 0.08359041215190965, 0.05436381693148325, 0.020273383105954817, 0.04969258815230382, 0.05255127588527338, 0.05717890277024239, 0.025884994388287588, 0.02878967804023095, 0.026631503020443266, 0.07599659624599642, 0.02726484514442423, 0.03650684367805239, 0.08493469727616157, 0.00655957039505724, 0.007201363905257876, 0.060994748416687214, 0.029541156667795394, 0.009832582417725316, 0.020721753300618262, 0.014896313472080135, 0.04772821997082041, 0.07857501071186797, 0.05544037730883687, 0.02879464995085953, 0.02714835189943833, 0.03059338417745406, 0.022184703529121417, 0.0365900676397066, 0.07293678745026551, 0.03516230574478546, 0.017423373233947544, 0.05350039753642294, 0.04736449674613053, 0.039934619825573704, 0.007889515310976534, 0.03051613761682905, 0.011018482694071869, 0.018396766465758125, 0.045255456690586386, 0.05961112084708387, 0.050087464342434565, 0.030465323004811525, 0.018238289687301845, 0.07081821726094331, 0.07212948399565874, 0.03032440113114013, 0.03179919507895266, 0.04832157038993413, 0.007427659574820991, 0.015093960326104877, 0.04696891192466982, 0.025992147106256698, 0.04840466411664121, 0.035077702824867545, 0.02702153945011237, 0.0601352475613596, 0.06268228306585262, 0.0269380358663658, 0.039981745724235816, 0.12233777572551083, 0.045042265912578, 0.04874999740070874, 0.07890298061313168, 0.12300642492670207, 0.03361856196856788, 0.10607628782670345, 0.0372537870651051, 0.09185945795428369, 0.02996759376518669, 0.034752471687933134, 0.020066681092665083, 0.06889045659092165, 0.043363081621787244, 0.020223792319396333, 0.02524790034869746, 0.03743969362169024, 0.05217342599925976, 0.0426007398674565, 0.013029376352806727, 0.03538217297905395, 0.07130069177477591, 0.06513959818309353, 0.04423460239664682, 0.017106998073417815, 0.052498948249605396, 0.00766365822675007, 0.11873157003954535, 0.049361098077028036, 0.016999718950941198, 0.026426587907236912, 0.0637323099879488, 0.02780615329562176, 0.008656046608643187, 0.026373365863917336, 0.01522793090947333, 0.07149233632991392, 0.03191071641330998, 0.06367766493630987, 0.018936350919126023, 0.08057287608784053, 0.014627446296564756, 0.004343065919519793, 0.03325860406602583, 0.011170756075561289, 0.046178083190874714, 0.03563339236162363, 0.09315842131693518, 0.06605606150603102, 0.022534539494963906, 0.05176097958258564, 0.024310746906144966, 0.03101282306165705, 0.0575482682324946, 0.018010736675933003, 0.0542731044603692, 0.015148812221483359, 0.0062774044119813036, 0.013665847945958378, 0.08759313728660346, 0.040108023827234586, 0.020791685636786204, 0.05827676805277025, 0.03911971294831845, 0.07164152429228829, 0.03359285971870826, 0.03822459666539104, 0.051381693281714, 0.09253281859620925, 0.08150086903403844, 0.011385988477887887, 0.019214896657954783, 0.013897515807090508, 0.03840476522342332, 0.02915663798640092, 0.019584771568676638, 0.0562034506771353, 0.02608371185018651, 0.06173482382549875, 0.035041463035609455, 0.026800653318904584, 0.007950051578753179, 0.03602365670245021, 0.02996320599660037, 0.05231599879240798, 0.09031360743627434, 0.02125074084277355, 0.05323186456676453, 0.07467320233943962, 0.024937809024366642, 0.06729011423885822, 0.10105971427213761, 0.050188867570531946, 0.06321775554228695, 0.21509833693985017, 0.2690796806446968, 0.142893462231563, 0.11612741501941798, 0.12849870077784986, 0.13500582096317124, 0.19057817606916352, 0.1335562447146062, 0.17823234741245547, 0.12217849838517367, 0.12074539302698067, 0.12092670305602013, 0.0963289068350869, 0.15741920939856963, 0.08315199535460242, 0.18186371142585434, 0.10444267427608853, 0.13738855359054383, 0.15133720672418996, 0.07324224202743462, 0.09182308409963885, 0.23888599518085682, 0.17842428308100472, 0.1816518727930323, 0.13532756256961054, 0.14538597525848498, 0.1332183080094476, 0.17799285300556691, 0.14219822211851998, 0.08435598679728086, 0.15803128300655275, 0.24007248151446545, 0.13972343636616585, 0.1353858618606483, 0.17125595240823685, 0.17479815910900795, 0.11707239213489717, 0.11030725353667814, 0.14653549018886783, 0.14683201218083983, 0.07163154982751416, 0.12559964787214994, 0.11583656973896489, 0.18435510596440685, 0.14623245644953944, 0.15249821297343702, 0.21109598718823927, 0.16383046134104653, 0.23263448789235086, 0.10471604509098877, 0.18260873193221708, 0.12096958099714211, 0.22798246493743313, 0.07902448981880181, 0.10625712288122986, 0.2095642556706744, 0.18893485618454797, 0.06934453222540117, 0.09832217568351377, 0.12949070803100063, 0.11376035655097616, 0.1558840304853455, 0.1273556286469102, 0.15334110887300584, 0.16141680940505, 0.11549268053063463, 0.16116401571179592, 0.18530366071049245, 0.11568099260330202, 0.16329531828241964, 0.20124706890313857, 0.11153547634040156, 0.15151929050203294, 0.1593087499420489, 0.1767192471532091, 0.16742886825194284, 0.08496833619691672, 0.18152192895931585, 0.1293774649140335, 0.16400247872356447, 0.11991839345184066, 0.1412971341802228, 0.17852366000654238, 0.2457405055963224, 0.1481560112968568, 0.16207198311965312, 0.23788641897901414, 0.20678467417676605, 0.1865449836177211, 0.22800857321389262, 0.21204846430449717, 0.1620270903672903, 0.110614845499156, 0.14411561761892613, 0.20951829039521758, 0.10009285768554096, 0.10598477862414815, 0.14891806959865556, 0.17632537070781956, 0.1644456759095192, 0.10524676016141331, 0.11010374227959303, 0.2259200489929607, 0.09574910085047446, 0.18079557035478855, 0.08683921483856055, 0.1273633278305492, 0.13047536084007832, 0.13858769569666157, 0.2012499340719754, 0.1367111939696535, 0.14166231297196882, 0.1446626810056548, 0.19703729318514948, 0.1042097912079865, 0.09854116191666934, 0.28260753700329416, 0.11569097472895538, 0.1617805939167738, 0.14176322207335504, 0.17448142771759342, 0.15047929550130523, 0.18360815491647492, 0.14406969830874475, 0.17287051335217493, 0.10445481676968837, 0.2261470255231665, 0.2021028657233523, 0.2185968766289373, 0.1709091137613981, 0.23983395237836147, 0.16664146776160887, 0.08959113289752314, 0.13276257762505164, 0.11740996111785212, 0.14318426920761987, 0.12073298240260733, 0.20898828012568338, 0.09754818173185473, 0.12727112148798284, 0.18961310446743043, 0.14333601590366135, 0.1662584850865026, 0.10185263059552639, 0.1159240723016762, 0.17285246432067888, 0.12074877913560599, 0.12222332985050256, 0.11494069885943206, 0.11796621755967218, 0.1240010522005539, 0.1612344038702788, 0.1224340576558344, 0.1854136096493852, 0.12666912193620397, 0.15272206386491177, 0.11609595944924701, 0.20585252903401854, 0.21651782125474947, 0.12397182594624259, 0.16499702938862387, 0.15537419897173682, 0.13479566772378263, 0.1209126300208511, 0.1480190960630294, 0.21828903185744442, 0.08752736097742474, 0.1884553770744993, 0.07942021253608889, 0.15440908140472828, 0.26055125279291985, 0.08759637017764392, 0.15972012383562906, 0.1345119240783876, 0.15038073062896729, 0.11286513684617897], [0.022344917411946004, 0.010986095369463007, 0.03659854057214914, 0.06423420866110152, 0.01235585962046659, 0.01615309220318112, 0.06967645514035417, 0.015895097730531087, 0.06508308387691937, 0.050598230483310844, 0.008935130524238753, 0.051868722188256444, 0.037680708713108496, 0.0688283804864172, 0.06287398890802456, 0.07259799272663171, 0.04481199903473739, 0.019157844175013806, 0.0027506413255562827, 0.0310139415500265, 0.043692089572188356, 0.04103995829580292, 0.0599967043906931, 0.07351235696865667, 0.07563171622854087, 0.04452001228327713, 0.05856267206611172, 0.07571915750421825, 0.014097462840107901, 0.04016586346551776, 0.06372044328600168, 0.0252592901609117, 0.025914720514969482, 0.043227836459634766, 0.04691970992773291, 0.07176577609272734, 0.06961604910752467, 0.01254656954833697, 0.0006684744373835143, 0.06798910818273021, 0.01501875826262779, 0.06345408600604822, 0.04200767290087477, 0.03440835265322559, 0.025097036568988717, 0.046735546221175504, 0.023010230300227003, 0.04650551300015181, 0.03114515517447745, 0.01603297153187375, 0.031565321842208505, 0.027482448588876475, 0.035383019506210284, 0.020119520092022516, 0.025683141711558548, 0.025509804742591038, 0.009865044435906795, 0.09788397339082534, 0.016735857202401085, 0.04514839590316819, 0.03984451639435945, 0.10265245703199219, 0.05050543042260313, 0.05101631913754729, 0.11866231569119039, 0.06175628577869746, 0.01699368600853749, 0.03341450295861691, 0.04311316841912847, 0.013738753660882433, 0.08648096914252928, 0.03337108492550831, 0.0390182790767041, 0.08379101227488249, 0.01719196105466014, 0.036050113548915234, 0.019346884031209256, 0.04210588154232791, 0.028950414778063857, 0.06287599222794657, 0.08481399246281193, 0.014213429399645858, 0.149990807197267, 0.00020278730399666295, 0.08021347359904359, 0.040842568081232815, 0.019701743618615215, 0.05777498046236654, 0.013598670653488128, 0.0747804929532351, 0.022294554791803804, 0.02935740090305767, 0.04938380109266408, 0.05245062342334179, 0.04908296602567838, 0.07770298048853874, 0.03277973782631659, 0.027758809061901226, 0.05110003339547304, 0.10565117031576172, 0.021950531518086795, 0.03949578167990812, 0.06364984445333963, 0.02464639683884959, 0.034443634832578326, 0.038624984858136986, 0.033604148024272536, 0.06626888073139614, 0.04075243783694121, 0.03401531124367349, 0.09906311294124012, 0.03210690578505878, 0.012310277388971901, 0.028634937855625348, 0.03428026658272551, 0.06655142927962927, 0.06364409113302827, 0.019990602816124598, 0.030564558204083197, 0.05389242387947537, 0.03944713509671631, 0.05654580770961701, 0.014591248642142503, 0.03787050316590936, 0.04756405498952635, 0.027697267303723964, 0.020828794935838352, 0.013833954449622862, 0.01607886019853815, 0.05187790375202895, 0.05073167916928088, 0.032532149700508, 0.06104191645018517, 0.006176940599201067, 0.01773695600399327, 0.052831372952148806, 0.04515234125597824, 0.042302149438088944, 0.07215328634746614, 0.04843837198530955, 0.04404670784189817, 0.03132019285863686, 0.03881413962752108, 0.018151761971474178, 0.09366828347406081, 0.033602301752375024, 0.0163051625713706, 0.061255467289517966, 0.05284420875532012, 0.044948312889544234, 0.03255166579037905, 0.03633785234283536, 0.07379591675294984, 0.054060323539400296, 0.04389266288208385, 0.029629680042665814, 0.0855106728211526, 0.0037322395984383844, 0.04143273923546076, 0.011295832378128845, 0.01836521130415701, 0.024700543933337735, 0.04599867305988747, 0.08300882884331288, 0.019523392604183287, 0.03812507418314776, 0.011742644541476284, 0.04654892337238116, 0.029596389691916206, 0.037308880278179725, 0.03611444961279631, 0.04847376141697169, 0.0118712572974243, 0.036067614827545426, 0.02677745617655737, 0.049012030114329634, 0.06511768806845912, 0.01536395173564914, 0.021764082954295223, 0.01883464508629855, 0.02965002350749508, 0.02510034989926123, 0.037133829187481635, 0.04421672573493374, 0.018555930808126446, 0.00670039507132324, 0.041370398830622435, 0.030862340410690636, 0.04701405365560805, 0.00889272085436049, 0.02914328890432033, 0.06062424148342783, 0.08282149736318858, 0.06492849499467881, 0.051083026243554014, 0.024186412751254056, 0.026233650578726685, 0.039189128175137505, 0.037586713555238904, 0.01681592871224688, 0.07442811549070381, 0.09334664145905165, 0.051916487770335334, 0.06892173596087002, 0.027901033285043897, 0.05715969694598068, 0.04577263115694927, 0.02635247656144202, 0.05039359307697704, 0.12983062124300387, 0.022166909221860192, 0.023060274993880622, 0.04702184476979798, 0.058851058204327865, 0.048078161273752494, 0.013422637055027149, 0.03869718098412118, 0.03538427972084573, 0.03237302557775571, 0.016052868750487125, 0.0686916261310539, 0.015300978350663378, 0.045193051168274496, 0.07162860804988493, 0.05051812832994808, 0.015442317742253504, 0.057755571624804894, 0.062375445699980187, 0.008357959882085843, 0.03181301147466706, 0.005542255427327849, 0.03703457100557224, 0.010504647413448942, 0.041731118990649144, 0.06788513472964687, 0.060836742782304366, 0.06754703714602417, 0.07775672155642703, 0.031914437685402176, 0.021195191807383974, 0.015519857331509552, 0.06767634512676347, 0.05593602470452747, 0.02484266473461063, 0.045291072118186185, 0.07009866917806287, 0.03177341813552043, 0.034736173167344064, 0.03109588422962735, 0.0326977166227035, 0.030796453018762895, 0.0966204186120341, 0.02397583433306746, 0.08302064191910528, 0.017406682093297283, 0.06027888904716219, 0.10682028943612691, 0.01603437251516528, 0.060114386987181447, 0.05934609656011867, 0.018969488052290776, 0.10044472186916298, 0.02757273013553312, 0.05527501723038093, 0.01264368364166829, 0.05834316489316764, 0.026096796631933223, 0.02893438821868791, 0.0291922323465828, 0.009577336285503642, 0.025647055139885317, 0.05403988431358049, 0.05275486375115091, 0.039352419816197894, 0.06451894439035846, 0.12110777559780306, 0.04938346018353778, 0.07006648582436385, 0.07814620831801046, 0.0061364408822790276, 0.0726663047868398, 0.04987770180788733, 0.009954306128014241, 0.030762287412559798, 0.04595117177814246, 0.0458555371921149, 0.060786341857765956, 0.002827846230150411, 0.02336399821234086, 0.03241604524514368, 0.036869069200850306, 0.02821138890970859, 0.02012504550117639, 0.04648112459108234, 0.11014013145599635, 0.0487208898900257, 0.0189283644525154, 0.04972905010705994, 0.026156679809754415, 0.04534520006047622, 0.04251416044069394, 0.03839778999287275, 0.03238011572149492, 0.032232586339476614, 0.05152653369511809, 0.012880429708128496, 0.05180061314134829, 0.012086203374389199, 0.02890349955358092, 0.03366265798948946, 0.014858682275629573, 0.10754001371922994, 0.030809832744360454, 0.06765807392976939, 0.0958017081082348, 0.06812777775790423, 0.0729991929725774, 0.0575719824841907, 0.03602026293294565, 0.06761390896093461, 0.04143733193256682, 0.10896584890302151, 0.07057494604058805, 0.05894052578256496, 0.024231583210489443, 0.026669587166379058, 0.01575205762374906, 0.03938297906349744, 0.07066683062622625, 0.011864492741052904, 0.006181472966883091, 0.02438777513171156, 0.02179863543490008, 0.11046309114223528, 0.11861484888340197, 0.02104443911042425, 0.02446742146275938, 0.025278294887093287, 0.022326755382481123, 0.011698531283576404, 0.08286105048271918, 0.041265303058730024, 0.06564042050271265, 0.015328421535330917, 0.05452134376091342, 0.013183899159963815, 0.03656141212089889, 0.033169331840209426, 0.02179926362699799, 0.04443210369396595, 0.026310866495834726, 0.026165386399013862, 0.11846659554829521, 0.12862512060711462, 0.12822231157652794, 0.11847823242386503, 0.14847404503774259, 0.12512052116254646, 0.15671908164456969, 0.10645157897904997, 0.1729948953875611, 0.16451537458887025, 0.09654341911476466, 0.10551830768705377, 0.0892118274444534, 0.12633880780589196, 0.15115703816615766, 0.2085954608816293, 0.1817378891451705, 0.12173482622470587, 0.11269072160845804, 0.1311154885878486, 0.19646007657772113, 0.1757679498123546, 0.11182905655474433, 0.2090664977027524, 0.12660332264438753, 0.32467434423104413, 0.1122054661954603, 0.16826010429330412, 0.20913023621805255, 0.16088477666339568, 0.17432681585271514, 0.11529221830348815, 0.13967958549338003, 0.17499947169375035, 0.11783434318438654, 0.21788579381762013, 0.1786631033305199, 0.1383544678889936, 0.1557157975771735, 0.15419937249633575, 0.05779826187438542, 0.1145586891159896, 0.126806718988284, 0.06991825547189483, 0.1879511073592209, 0.08240913521618613, 0.1417420780466449, 0.18184935493815332, 0.13253564706012128, 0.13772892645530163, 0.1676596292564946, 0.1673241593544522, 0.11069052732519566, 0.14078937110400971, 0.14694985182535264, 0.173935161062306, 0.10974754969919882, 0.15018945379603296, 0.10234913217925257, 0.11332663587264477, 0.20133187483635642, 0.24063220067370325, 0.18821447306583006, 0.0950219761580229, 0.19911901454531378, 0.21628860774780476, 0.12934257726996176, 0.1763688691801602, 0.15740266189940516, 0.09191246357776466, 0.15482459217309952, 0.1242126533461194, 0.15221476044145324, 0.11820199644012798, 0.08335495502838204, 0.1895616080371603, 0.09002886787657777, 0.12107630470587362, 0.14243370222468532, 0.2030808995327642, 0.13511886489727806, 0.06591505536268796, 0.3587034182442773, 0.1325497890432035, 0.20153629773807144, 0.1523782282827362, 0.11498053543149464, 0.2151843379702299, 0.11079348954221896, 0.12525146091056447, 0.09938124627355607, 0.14212043355068854, 0.19322091893803692, 0.11230362504119835, 0.10699549374440986, 0.15007942824834777, 0.21257332646318022, 0.194727921137406, 0.18140127011124166, 0.20877746805067987, 0.06682294616175276, 0.08880267520585368, 0.1621234335846478, 0.09779887634419626, 0.21792081935751825, 0.10710414799471056, 0.1364110713644374, 0.15140906577148747, 0.18465343592388017, 0.11400708282786993, 0.1720790219523253, 0.1500486468355502, 0.09617071733960221, 0.09787114907897289, 0.10568645632555408, 0.18070613725050805, 0.21307871466682804, 0.22760418604218194, 0.18623957500582744, 0.14611233386301226, 0.06185842445120216, 0.2599036633487671, 0.11037902831430398, 0.13543722039509204, 0.1615085560948618, 0.14153589314270404, 0.08850567823936863, 0.1409249993101243, 0.21793053335239812, 0.16133519039759714, 0.12060525256299204, 0.18814511146516572, 0.13884942197511274, 0.10610393593989073, 0.10354939277373976, 0.14168158774414372, 0.09389596480515697, 0.09817385340049382, 0.19303655221817956, 0.1435832784421021, 0.11714351573778738, 0.19132983089695055, 0.10387856543304459, 0.1634304868357797, 0.22635478856823138, 0.2353056066579396, 0.18915740472655143, 0.13308154599320504, 0.17919296038246926, 0.1200646396365858, 0.18495611726276337, 0.15652311635353874, 0.1486678039955516, 0.09468643730806728, 0.13513844610462267, 0.1765565913651259, 0.12690201266518525, 0.14390837551364977, 0.24893975005515162, 0.09345808426939672, 0.10538677039045481, 0.07326383804602009, 0.09796347033472792, 0.2761180061967142, 0.18538766991226904, 0.12084034196431599, 0.11080975358885144, 0.11436658490809704, 0.14647052593288884, 0.1139874633161291, 0.1322757287491714, 0.1721988074601658, 0.13961086740657208, 0.10833898979809978, 0.15168450502378328, 0.08446605064936223], [0.05146066162494883, 0.022593583806508014, 0.033694063763945334, 0.011609208304435016, 0.05717137212594671, 0.049030270667806755, 0.045617521334920204, 0.05422509756059416, 0.06256444342133981, 0.045732407710484924, 0.022724837650574987, 0.027407640103070487, 0.006667364232857982, 0.005609846407277209, 0.011017435068835416, 0.060341440126179695, 0.0679282731406631, 0.0491829788041932, 0.0683986128217751, 0.0209627109354422, 0.08780756529660956, 0.03963224875229982, 0.029120158794666492, 0.0218155698084663, 0.04062605631207267, 0.0333157082599017, 0.04787112984265532, 0.028020276785677964, 0.049434136899728934, 0.021352488810436863, 0.054429608562420455, 0.024779757424708337, 0.016940306917193438, 0.06835185081487702, 0.03737608534133723, 0.027112324699579228, 0.030671674532875903, 0.018059034689119267, 0.024300234264604027, 0.01199989016318033, 0.031228038227005355, 0.041314696577648004, 0.09346863330011407, 0.036150321679850744, 0.015519816154283623, 0.0552781083951554, 0.00625710643362254, 0.10116949467168701, 0.05073224990478447, 0.04385530077401669, 0.027943809719515905, 0.06243644928139064, 0.04629872288675078, 0.026451068246857296, 0.08966591840069141, 0.039125833990833456, 0.03921830463373373, 0.03462484910062725, 0.013166113471191739, 0.06091935770405878, 0.015559635489367911, 0.10137599367167681, 0.04140471573919058, 0.009409269043845276, 0.06345260745635437, 0.01275401658213307, 0.012083158174890184, 0.07099460134462965, 0.03005898996977316, 0.0699560848935958, 0.05744403430951699, 0.0190414217931609, 0.09997823561031012, 0.06993552309370811, 0.038662174596421184, 0.02426855269849541, 0.030626017607808597, 0.028965372644785433, 0.02831431090711586, 0.07771156067329069, 0.035253198246561715, 0.037072944349699447, 0.04151606661898475, 0.04157444251881492, 0.06365147622061834, 0.0796948857004604, 0.056846845789902636, 0.03307576186113781, 0.001076502801058063, 0.03382380075392223, 0.03513987085992291, 0.015292492969292066, 0.06962096739199854, 0.030736968206662326, 0.0983875766096096, 0.0467401274269627, 0.02746587236141486, 0.02089327655642504, 0.05060682982026089, 0.05721963183473676, 0.04974885347990259, 0.0598094265367235, 0.051376135313823346, 0.058049737896409735, 0.04424803191795946, 0.02282858319250086, 0.034112255840051564, 0.01723951787777966, 0.035833295344585375, 0.009709575510163222, 0.012920932776685204, 0.022409579063194896, 0.038987218041814146, 0.015039849620793137, 0.02068870235234499, 0.09231498915581934, 0.07574611613827367, 0.022256016738772876, 0.04059483056827899, 0.020758577231918613, 0.07805509748117578, 0.033464865578759107, 0.04103682116575299, 0.06925747399368594, 0.052762187551707036, 0.02161078493020708, 0.033945137589809396, 0.05599100300441346, 0.039654082258141814, 0.06874160570723396, 0.04873538427355309, 0.011564336619490098, 0.05587818123580468, 0.03995985859223912, 0.053074467972281485, 0.007922587805472675, 0.04916640066151177, 0.04848728286883524, 0.11218851266969597, 0.045817225135021636, 0.08287919910564538, 0.01826080692661626, 0.040658500135665944, 0.027643319392096133, 0.024687897736927675, 0.08442026157412799, 0.07620966828037655, 0.061924013068839434, 0.0520780940179623, 0.030793174162446976, 0.08298132628683122, 0.05373613428204291, 0.022702511933241642, 0.009917699574162404, 0.017315126925466523, 0.02804204325882658, 0.03846632421857888, 0.0984063534246337, 0.05365946803302054, 0.023621463126713232, 0.06291047767585804, 0.04032855372755759, 0.049738503632045565, 0.018398086052207697, 0.02237410344664128, 0.006030823212988194, 0.0033744554703814852, 0.09057904158027903, 0.025980669193931168, 0.042869487341733716, 0.026067602936358705, 0.09942919571673679, 0.005311594493011194, 0.08710932211890336, 0.023365781281984622, 0.014805428631183122, 0.039062873054776466, 0.05955471762365872, 0.019798816534720605, 0.02091611746788746, 0.04133527369929418, 0.03306669904099357, 0.044950170652760614, 0.03201142058617646, 0.011305234192179577, 0.02882969081251612, 0.03115417011412642, 0.04574203743569313, 0.008302608114336769, 0.019961966449514996, 0.040858632945004976, 0.1098445670739297, 0.06616041034219727, 0.02763524865581384, 0.13046348647725198, 0.01203743517473941, 0.04764162905273899, 0.057149768446482, 0.060523336212481224, 0.030750694587045622, 0.01743008416416424, 0.057619931927371415, 0.026121686828593095, 0.023742035789895925, 0.04611799125409415, 0.027019530384530945, 0.028441221032652165, 0.012536863214336337, 0.038336142897605896, 0.08276794015640214, 0.051785908083641724, 0.034035850060923446, 0.046005207789881576, 0.01873216741988736, 0.030023527759758216, 0.02317162587367479, 0.04564585892723934, 0.046767882792459387, 0.007396116383343696, 0.03092226955378729, 0.04163649564068164, 0.04599870370340444, 0.024071932402289203, 0.019926197804330338, 0.023781458674479398, 0.05469812237988076, 0.03122975043351612, 0.09553270399450295, 0.03428206305890795, 0.04877910108095215, 0.007341573795964642, 0.0791639254819001, 0.05031700726718672, 0.0523474122277431, 0.10833248571162263, 0.04541772177382823, 0.03867845396481214, 0.041302971601966894, 0.08165003401377509, 0.01293300727998177, 0.014140466228127481, 0.03476476356867821, 0.03977293313871469, 0.03388676168997923, 0.04701691499400524, 0.04313656474433599, 0.021993943805535956, 0.06127756892613346, 0.0401160256156037, 0.03652712585584771, 0.026485593914384806, 0.014699237353558985, 0.06434049186927658, 0.04523373809793303, 0.04441110905440104, 0.027617015763215964, 0.06762163112721137, 0.056709693068818706, 0.03849046364907296, 0.028199131502920104, 0.0703308551061538, 0.029498543027007294, 0.12198693043882809, 0.027654282110292586, 0.018803934536633954, 0.005016146939352996, 0.0121326110656223, 0.04343728106769343, 0.06312996569660402, 0.030492421449913137, 0.09582454518925759, 0.02144671187946393, 0.15847516967163933, 0.029831540380274097, 0.022048594602834315, 0.013852749459235179, 0.022817955637771278, 0.07314731607273703, 0.06548938626844077, 0.06535169728580983, 0.037148281436173186, 0.041189414388950796, 0.03560905374826924, 0.009148706261429095, 0.03526021944238775, 0.024128021529665398, 0.016494782739168695, 0.04843408955381282, 0.07921592753020026, 0.032964311389913487, 0.04385166185637636, 0.04961241705102786, 0.044813301384208665, 0.008247334870599933, 0.06000162267516698, 0.059718361665164275, 0.02967020609386025, 0.048823212423632224, 0.018980445024827798, 0.04532807799536855, 0.030227985135429812, 0.05161809652382809, 0.05301154917106033, 0.02295731852251676, 0.0283644839204968, 0.03776513160236421, 0.020985775927622474, 0.029454086944761298, 0.01116595461949586, 0.011007616694475855, 0.021931927072845643, 0.07240509178729788, 0.026487507218975696, 0.029865841967083757, 0.05807021542662575, 0.06492843370764487, 0.03623285999281272, 0.010972022334293974, 0.02725228896334527, 0.04747518879030982, 0.05374089551849231, 0.09775779870969635, 0.08497605836319347, 0.051829529130050254, 0.040085439555226796, 0.014469077728027779, 0.055642180189850836, 0.03983444233815517, 0.04212115733553806, 0.008061749113333083, 0.07010629175290947, 0.03006297937263885, 0.0809951743952209, 0.0276830812705861, 0.06381674053808374, 0.038451052255808346, 0.025042705613398747, 0.013330242063309397, 0.08853898774231635, 0.05146296754960091, 0.025725937298228665, 0.01591040895530774, 0.04844959134296064, 0.010673635875836257, 0.03904436820096547, 0.007550322221622112, 0.05580875451766676, 0.1334678688116612, 0.027108762390731324, 0.04376057400217941, 0.03133103108754562, 0.06106575710638877, 0.12739157349231744, 0.13649030017756647, 0.1906788247006555, 0.16471267287288943, 0.12793158887014275, 0.16969339351259893, 0.10884355828766862, 0.29341020411060703, 0.31100914362938176, 0.14018532609747303, 0.15604795797938303, 0.13636893652860196, 0.08860785138582991, 0.09288257603803951, 0.08390350462568384, 0.17963384398289267, 0.14588163414549443, 0.11040371932810354, 0.2002495304951745, 0.17358231628614088, 0.20187264098034752, 0.1296316222437928, 0.16348258081463077, 0.11757158268723758, 0.19562531653190815, 0.09168003250153796, 0.16441820399655452, 0.09679014539165844, 0.05346533369212862, 0.13760057608446769, 0.13610482005582702, 0.13985117386666038, 0.14734431049756466, 0.16756961392539163, 0.16566931750745545, 0.19822891230785078, 0.14468980051817434, 0.1355295033464509, 0.1144219347606263, 0.08928220028117781, 0.16693368433944641, 0.15200171138971083, 0.13627194979738805, 0.09702413162637143, 0.22483900700125004, 0.1307938542337187, 0.12679852950837345, 0.13394999858592788, 0.11364312977680277, 0.1165504947364811, 0.13479713861259723, 0.22975378279243747, 0.11312264198016737, 0.21112814755930057, 0.18117510563423558, 0.16595742785401885, 0.23142432944188196, 0.08956828049474186, 0.17078899117487092, 0.1433392334729433, 0.13367967680096626, 0.10508594298434835, 0.15927367843687534, 0.11585079599171878, 0.13094927815179672, 0.13536318565808958, 0.10270655816120487, 0.12391748732977337, 0.1434471139744405, 0.22004482877110282, 0.12657829455190128, 0.15443541950756504, 0.16328171256088442, 0.15307290149071526, 0.13777470786965665, 0.1274438972975458, 0.1553224880368479, 0.20889239656108044, 0.13566361469847543, 0.12220968582457113, 0.10096905542717827, 0.13369247046930174, 0.15340187496715976, 0.11862853121372963, 0.13973652114791257, 0.20096430585028666, 0.2511322324074084, 0.13418849707851488, 0.0915843251371576, 0.12872270488690946, 0.1258767955005169, 0.13083833329860242, 0.11703617915871645, 0.13839672529889693, 0.24691668038647024, 0.10554520503407526, 0.22681732181339498, 0.10860672220587732, 0.14112936092480538, 0.17103853665532606, 0.10636583841856449, 0.12568564124165044, 0.10708073634774455, 0.12915954354309267, 0.15803446993231773, 0.1187857554384297, 0.19747927995218387, 0.10785996267992644, 0.1221279978692051, 0.07076861306784615, 0.13517624488280666, 0.15704278443609515, 0.1819866072506674, 0.13967071419521687, 0.1523328911993773, 0.20846649764045594, 0.2102550524737566, 0.058430031602901805, 0.22867677042320853, 0.08802387022203015, 0.1687282759455904, 0.20895679391199545, 0.15023849874494538, 0.17259420075964543, 0.1930704745914667, 0.1185992130288674, 0.2223093999970344, 0.14971682351202736, 0.08517531783229883, 0.17777880803952295, 0.12948310843879177, 0.0897383290312944, 0.11994224942980275, 0.10359241627156736, 0.15098017910795827, 0.12418214772497455, 0.17110788293423193, 0.14746127680184382, 0.1951738149528542, 0.17003943542799643, 0.16963141699952466, 0.10298791161227612, 0.09862934629763327, 0.09931482645052095, 0.10576515653801542, 0.1680748642332131, 0.14064165403044995, 0.2226076380259568, 0.1641071876210551, 0.08942046382975194, 0.2246715708245193, 0.19115428950998092, 0.13314726101534982, 0.1155325860506104, 0.19079430479436152, 0.2065351286963109, 0.20461011828193743, 0.14768068438335774, 0.14057992266551142, 0.237550642641802, 0.19219793108922822, 0.1273551996376726, 0.18294936526686917, 0.10226643298782649, 0.1444721242953693, 0.0988086644980696, 0.1576635914464151, 0.15088248757585404, 0.10628899213887992, 0.08553387762437906, 0.1613603793685475, 0.23552627062364934, 0.1473558784252213, 0.18314355323391576, 0.08192311371526412, 0.14972724230779758], [0.03774758435845856, 0.10277338401083985, 0.03695954035426821, 0.05557635025451741, 0.051102668737932566, 0.03071438776509416, 0.020640371780421947, 0.06114806559297347, 0.004509176285336576, 0.013105094568022798, 0.05504546281430991, 0.017884347490185214, 0.031710736821555806, 0.07461003072920346, 0.03892530664621342, 0.07200890175637699, 0.04003111243007645, 0.11799617925839079, 0.04482445945482581, 0.05028228816245833, 0.04737830165052607, 0.05443608583582025, 0.026283519072157722, 0.025563109140362472, 0.032796174242732026, 0.03305362958100534, 0.051080762453737764, 0.02622218798815964, 0.07395942289862903, 0.10531157119980744, 0.015158236060561913, 0.014643865476001897, 0.007960864430999444, 0.04808450065132591, 0.0485029187233698, 0.038462505270276344, 0.03359153438659926, 0.04799964492239299, 0.028212580176430847, 0.04376477216400447, 0.020524414796983043, 0.03202951749816778, 0.05042553128254029, 0.05296308261853072, 0.05466751716730576, 0.056212092148921186, 0.03884591695462023, 0.04293797943260401, 0.03701009066595185, 0.030663772335936947, 0.02238669984733626, 0.03891220654270822, 0.05230233944471806, 0.05651791827873357, 0.017253127429754506, 0.06252092962724067, 0.004198538644554755, 0.04651929875234923, 0.05207296122886962, 0.0381017774493704, 0.022214937189053145, 0.0069116289734900485, 0.026365653273739645, 0.04551562014967204, 0.049639019454198505, 0.055531036153796225, 0.02228113867702984, 0.06788671287077089, 0.038915071711545034, 0.00909829959123125, 0.01306587661195907, 0.04657566750181779, 0.037216099369670116, 0.049785150725755005, 0.03557153076173798, 0.06512088265510337, 0.04119506428739236, 0.013310585204782266, 0.07691312085596785, 0.018256154857696067, 0.039310691006962335, 0.039886965326243834, 0.04546604660009185, 0.05316850909542653, 0.04776928611400147, 0.022980843167451602, 0.05019208513981393, 0.06414748750807298, 0.052689447503296606, 0.036444982078166745, 0.017223050817847252, 0.018592281680133556, 0.012616184915626242, 0.04257421790351791, 0.08026921415641423, 0.03326508516986524, 0.005615762521272466, 0.022015675804727984, 0.050150597648274516, 0.019440160981649836, 0.05493989972878368, 0.05173918821157948, 0.027346174953685656, 0.07175383278198781, 0.02214967032834407, 0.0018271205373175984, 0.06903330134528299, 0.05641455003511041, 0.043079475872218616, 0.04622456940612005, 0.02074231318528614, 0.0451394671484107, 0.05168925460067488, 0.03707661391085675, 0.021585802802996292, 0.025977091563324776, 0.02971450321286196, 0.0815561805821715, 0.05135246319696308, 0.022507770467669736, 0.04327180990648847, 0.03285613594456546, 0.027443433646112684, 0.015257859091845252, 0.016845059205567645, 0.03986763309747462, 0.030324092780750607, 0.06398499259845385, 0.037808105304476716, 0.011292455845602579, 0.03988534505028398, 0.033881242026484786, 0.006264978944654427, 0.09436825034959663, 0.08646124237847906, 0.039418912417585814, 0.06746991507468686, 0.022972898835676814, 0.060310390582608606, 0.05745693139972226, 0.03454712181982975, 0.057592532792759527, 0.05108012660076061, 0.044594341964130445, 0.0548469809244477, 0.04575308825400087, 0.038972566610262285, 0.05132541263235673, 0.01288281415679282, 0.024696025929804293, 0.037481315178616394, 0.03074047497413572, 0.02631322604664151, 0.008902415697042261, 0.04088660664556008, 0.07574836843677106, 0.04762369493443159, 0.01861080377092285, 0.014282542979344727, 0.04619219836087958, 0.025468288522754467, 0.08023277901473545, 0.09909268393511735, 0.032618392048583876, 0.06314410767968624, 0.027306679290749376, 0.07078210387619273, 0.055323273108731356, 0.036839325837190115, 0.04473290045655543, 0.03252233228375835, 0.040403546074465405, 0.07656818976806057, 0.016263728705985893, 0.027731649329765674, 0.027979919273826866, 0.07696518419130195, 0.004184722727645309, 0.03462131360485669, 0.05735453225732331, 0.030825838236318483, 0.024618189481477586, 0.025813550943689003, 0.023032243836731203, 0.03220608352773613, 0.031114444624812856, 0.05821153566601777, 0.010560009714906976, 0.05170267646110827, 0.06577781071105311, 0.021976166735253027, 0.020894554008038777, 0.018354217942443588, 0.08709858156620495, 0.03830087987045127, 0.03538401159007223, 0.06515074476239181, 0.044504479850612344, 0.008055769797084073, 0.05876945451863351, 0.03812121693044901, 0.048682945555136095, 0.0343039961561801, 0.04196447703326422, 0.21303244295620152, 0.06753839567423829, 0.019067700524183533, 0.07306260973094933, 0.05777131473164886, 0.011186000267644564, 0.01774228606072645, 0.0549633305279478, 0.013976475531836192, 0.008852958975870524, 0.03548404735122477, 0.017856484872379133, 0.024056874944137472, 0.050224777941982594, 0.05485967883179265, 0.032225438739143075, 0.022741710737107262, 0.032562800878358465, 0.03477743083250619, 0.028100612595857635, 0.012734035093848024, 0.020778549144104607, 0.03560053485055124, 0.0705127090576195, 0.07611215294849488, 0.012528009153151465, 0.046983310547206676, 0.027889859892668265, 0.03611135461758222, 0.01605958446875335, 0.08583074435591699, 0.03886879617047887, 0.09542012737402994, 0.04711923752761176, 0.07725080475211143, 0.0662644527431938, 0.016206816034091097, 0.07748862142644583, 0.008293766502080666, 0.08116418105219642, 0.024805386896215142, 0.05663293488924542, 0.026842265299731688, 0.025605418261200674, 0.008826093229975913, 0.020323607830270644, 0.045879113547984636, 0.034979609096603054, 0.019017050621069728, 0.021311495445608612, 0.03561124092929306, 0.014991859957996397, 0.023206735683244564, 0.023915208049959714, 0.09320205002422295, 0.014778314864323025, 0.06192864407034171, 0.10295210466269525, 0.04058807367278684, 0.04664974820409571, 0.04279471716032394, 0.03663219481466278, 0.04457997781555018, 0.03413428086787462, 0.027991887482423938, 0.03547104300871011, 0.015790856146674245, 0.044262124105326595, 0.06785102849525791, 0.04137049076117335, 0.04684338841827647, 0.018642560030604084, 0.032805650750355374, 0.09642932564020158, 0.08888780289599973, 0.05794243962173501, 0.12725908624669238, 0.04058253868753391, 0.0400512567120454, 0.029040351585154573, 0.055833411057509726, 0.0791577508132304, 0.07148900384744329, 0.016106983286238486, 0.03205884142868942, 0.054761960486611055, 0.06340484953515473, 0.030451562150471637, 0.04782503433225136, 0.05111642767705264, 0.031500995354426485, 0.011192824195830092, 0.035814966690996965, 0.031772504575670726, 0.0501538343697546, 0.05626458066305327, 0.06042160739701602, 0.06680233839658961, 0.03637406914945572, 0.014118265957691738, 0.07232937931774125, 0.02591805108222029, 0.10707903563255265, 0.013494836053841058, 0.05493983844174974, 0.11704028538999059, 0.06308934005397944, 0.03321480298895509, 0.021104460184071815, 0.02559574831637644, 0.051429895533909725, 0.018617304026960366, 0.15129677260354643, 0.03631098563933084, 0.047607143604827505, 0.049579946414357236, 0.016210420477774837, 0.015292795574022158, 0.17899218405927383, 0.045900594653381456, 0.07041457319451917, 0.07275910101710789, 0.008813288070321565, 0.02459755490323709, 0.023865971579066208, 0.05800957190653971, 0.017493899288256804, 0.017671085849043824, 0.024504333494171023, 0.0833221051781889, 0.010062866532544215, 0.025116797806995533, 0.028330000387805126, 0.04354554461315275, 0.03344844065366253, 0.016673491899705222, 0.004509834642146504, 0.037089825097110965, 0.02077897240768277, 0.05004792654466245, 0.10102157841526693, 0.007962274990390025, 0.021590098641031695, 0.007133578051692777, 0.028918093528538465, 0.03006560513899932, 0.016436738172365774, 0.04196070788067676, 0.11228354587670296, 0.1695817591802728, 0.15717289680915494, 0.23040656631271686, 0.17488618261150776, 0.08658025413751604, 0.17235933352381955, 0.11682987168070771, 0.17940844559381086, 0.1430881711383981, 0.17300306188483394, 0.19410394252307955, 0.12604745690740887, 0.1488282687721714, 0.17432945119517465, 0.16998605442143258, 0.28817733329149986, 0.19751910120248797, 0.2498748063320114, 0.15255642033392383, 0.15840491940898282, 0.18167438045624765, 0.12528135366136992, 0.18571593858782323, 0.12490827650312455, 0.15848898989779336, 0.07928576410537766, 0.07132032660827523, 0.3037232797472708, 0.22543149940188856, 0.09405361803909464, 0.12254667258070362, 0.1300795538531196, 0.13526405388068768, 0.12808970941771425, 0.18174325176064046, 0.08554799662482354, 0.10004872336022316, 0.12040385570857795, 0.10265243404935445, 0.09341997139516378, 0.10208855503268781, 0.1489655210846855, 0.14949720142589462, 0.17163475224327657, 0.16955923619529895, 0.09829848824489502, 0.130573128980975, 0.13073638231763918, 0.19671766598138118, 0.0896544270818272, 0.18083713828556, 0.14477589347910497, 0.14075834454307634, 0.11888508639869191, 0.15454006711802176, 0.14002346704083105, 0.16026671224784467, 0.10489534030878737, 0.12114475466190808, 0.1527671864436519, 0.09758029613764056, 0.14304985142042562, 0.11177778228997223, 0.14289032127107346, 0.1458147087044293, 0.08565288172253678, 0.18997512697692842, 0.10388896124617708, 0.14083443239571589, 0.1516852098246736, 0.10333814402861942, 0.17370747973120984, 0.11212728692278748, 0.09193362292623328, 0.13449572897966833, 0.10460572076901313, 0.0916415442442221, 0.15244821807549847, 0.18453076992544437, 0.2257033840062157, 0.11356387798103595, 0.17320046742116252, 0.18441700586868873, 0.15701722774294116, 0.16093281037624807, 0.16132815771045225, 0.15488453089229523, 0.12987516159492155, 0.08758033595738873, 0.09379104906392675, 0.13638811937022594, 0.151414351778165, 0.14010376837705413, 0.10678784561253364, 0.25219611402961517, 0.15452621624835078, 0.15422816208053022, 0.17507496199780898, 0.15173183393574532, 0.14507315091548428, 0.2407659596252826, 0.1876663218342489, 0.19251765022354742, 0.16775891425148134, 0.1886362810769389, 0.20880621166959887, 0.1160968864156354, 0.10838936007912121, 0.15975110443128696, 0.15048249774882871, 0.10022057220339776, 0.13162087679149645, 0.108456400433375, 0.10735184720326817, 0.16125689621173567, 0.10358820278798381, 0.16698738710293848, 0.2679321422211586, 0.07209861065231024, 0.16015058864028225, 0.2482764558085511, 0.12827157103005918, 0.08788484058553174, 0.1424000709648094, 0.14514859525426743, 0.15848592554609622, 0.1267804804768774, 0.18794972840095722, 0.1613332138907525, 0.13985621472520215, 0.09946800573098083, 0.1457911744833954, 0.26338764736729287, 0.19596018888536962, 0.14865315639443938, 0.15267312616830872, 0.11943279329927699, 0.15437856046182497, 0.1301993240392016, 0.32340508975809623, 0.1436571599615197, 0.17499285269408457, 0.11931260942571587, 0.14411465234814153, 0.20614486818592395, 0.2827390589781346, 0.1456186974481229, 0.15635943400763697, 0.13063239354279735, 0.1375165668826911, 0.13931457524097737, 0.1663847210546655, 0.08124183938508073, 0.1253649338539089, 0.12129243343107163, 0.10556569022517051, 0.14815305419746908, 0.10069708655317945, 0.22595386411393845, 0.12367813081871118, 0.12035304109656042, 0.17857137196246656, 0.1445102141869645, 0.07654815656884063, 0.24788694606432993, 0.1288828172630841, 0.13247710262094775, 0.1057305753291134, 0.17592056984862975, 0.1074207414902987, 0.12984185209197383, 0.16024440376748963, 0.11759209086097057, 0.09071685313697785, 0.08855920480263811], [0.03413724945858121, 0.028622935173071684, 0.05947633150724634, 0.02339376455863878, 0.030189236408219706, 0.05550942098301265, 0.020769643371984847, 0.08374530746931992, 0.04552503153982182, 0.04210154548467648, 0.06696207538968132, 0.0994617697752772, 0.01768882844537016, 0.061417395294073134, 0.04146766901436833, 0.16996294920963628, 0.006482673362047682, 0.023221013646933342, 0.02288072313662739, 0.03214669256140629, 0.06699204474927918, 0.05115697671088481, 0.032054654758183226, 0.006213617537380948, 0.029345675927376556, 0.08449909968241569, 0.03960916652314125, 0.07558601908385754, 0.03312187269330025, 0.04970209913388376, 0.10810012358330912, 0.09309161078905867, 0.05156249386228381, 0.06641705745771047, 0.040047510542095675, 0.054831751096513004, 0.05212943340020795, 0.028243221778182254, 0.031717271551549915, 0.06273093730992367, 0.08569188325876191, 0.04334818887253923, 0.09117574746450109, 0.05454351051500248, 0.04715851102505, 0.045508687053957296, 0.02287961039391737, 0.06940428708349505, 0.0537397119126493, 0.022171503834186063, 0.014371760621396525, 0.020119843764170524, 0.02074897815022738, 0.05008432338194502, 0.03539660990598702, 0.02456392938902061, 0.027622951029409325, 0.041327980542255026, 0.07884006181191053, 0.029007658782985904, 0.0779059095188014, 0.06233319978139574, 0.06331215672675641, 0.09622329395384559, 0.089527141573208, 0.04331384898133336, 0.0318524822397458, 0.024861041268694307, 0.049656072571392984, 0.06978760683728803, 0.03990433636992689, 0.04114597337320447, 0.09509563551194246, 0.03287448375035198, 0.041432911605243726, 0.06895157508552074, 0.03400940853621691, 0.032561621102955074, 0.07329291108274653, 0.0776946684345603, 0.017999534555260214, 0.03162891480080303, 0.018833901981011997, 0.059762767951695196, 0.05965496788943007, 0.02737650820504754, 0.007609412498441675, 0.07068949150702647, 0.04714243850039859, 0.029121438161500042, 0.01779087135688432, 0.09314643970179944, 0.033494233559336395, 0.017183830946563713, 0.01973417978132925, 0.08016473508530086, 0.06304345904819428, 0.0581687305032486, 0.0583067374123681, 0.03251459862616274, 0.05084300706643732, 0.05776251238139887, 0.02221011083513018, 0.05317893172163637, 0.08684221790322373, 0.014909452837591451, 0.10946762117166674, 0.0825688262440024, 0.054027983137676795, 0.02902596828437621, 0.0433089881534538, 0.025479312527984865, 0.040646028224258654, 0.05911265807827154, 0.06409904010774148, 0.05093357781128538, 0.08533289445744408, 0.058456484618927204, 0.03362894245994187, 0.040371083098674015, 0.038733608464920716, 0.033238861980217124, 0.05645232583065668, 0.057911148760467775, 0.03556939720686886, 0.029812627584643425, 0.0494110623314496, 0.07601961718812104, 0.09979619013686335, 0.010805356075927135, 0.021330509747889255, 0.03362030098815599, 0.06646418718681221, 0.08348093052665073, 0.03591391077685741, 0.025315620605984045, 0.05020377181109883, 0.046690396829358036, 0.016978266573841536, 0.026300401734789054, 0.0610370364701075, 0.011614190748772554, 0.03620584390216297, 0.08939355882185121, 0.02649417984479618, 0.02186759866984381, 0.014490256228694513, 0.10567821321948882, 0.04440635547883088, 0.06532916663995673, 0.03521167245062609, 0.04484351972238191, 0.017263176588101253, 0.08013819013872454, 0.026954899376799023, 0.0327678021764563, 0.09350499949387966, 0.02928089361727959, 0.05751468293789414, 0.07422457359010175, 0.03801312958521228, 0.04539966125101332, 0.07499180298538939, 0.05914579904187591, 0.081505335326637, 0.0678062659778422, 0.038559415392697825, 0.022572468508095033, 0.049538206113802816, 0.02589567939961149, 0.061830519698560245, 0.012393470707109139, 0.04438531870443014, 0.042515213811589826, 0.048148166388273246, 0.03375859134980748, 0.009464790308547598, 0.06674768568407144, 0.004697971472201208, 0.057413413775183504, 0.02325958042826143, 0.04454233608539066, 0.015223987471883096, 0.09359907509098131, 0.08540220243195373, 0.02861374594841994, 0.0419338526684911, 0.048335153128831625, 0.03171417847155564, 0.02051238913179165, 0.010199700369529668, 0.06196232895637232, 0.03723075846210122, 0.02087751429738297, 0.021152942058359905, 0.009497312656153114, 0.017091193679539908, 0.030833016480168993, 0.047201863940685033, 0.07388217825322382, 0.08561752676483124, 0.06071660870445832, 0.023185685502305146, 0.023602153880581744, 0.027990633013447928, 0.04605702597707991, 0.05241783869062221, 0.08829784624639057, 0.03953572167384048, 0.011440278256251928, 0.0403630085319521, 0.07385889684120495, 0.06583875300542963, 0.02655547453961786, 0.012663106843378517, 0.026647732593119148, 0.05217840557076758, 0.02875042752543044, 0.06274219497197098, 0.022767774963511095, 0.07891805722348152, 0.10023356505459356, 0.009066075060306298, 0.02648937264307132, 0.07897930595302775, 0.02404906467774943, 0.058044191419837944, 0.047932068306592204, 0.025577212819048477, 0.054571848107321616, 0.05552524452908866, 0.037727788646495154, 0.01936407887466973, 0.03543508667198401, 0.08805646726320829, 0.0507082368787979, 0.00713661942075217, 0.09140588793783419, 0.028640277488457582, 0.07523765592204948, 0.033725369946971055, 0.030306354014863892, 0.02982674275464829, 0.023993599912031524, 0.052724756495726686, 0.007143329393358962, 0.044670613677871805, 0.02429460926402, 0.012961441590901346, 0.0276532996025297, 0.029221364755123377, 0.04143205358676853, 0.044065959631435336, 0.04600448766723276, 0.05790932547120799, 0.09995603438226447, 0.04623156378886873, 0.018196712180431333, 0.02566243627018506, 0.08319226093590261, 0.0228584069953931, 0.06423896606711131, 0.07127878932102073, 0.08051161203653583, 0.018204639275227825, 0.06245867349207402, 0.032590146386815656, 0.027961866411891197, 0.055372172500938184, 0.04501571713556205, 0.0653343147508079, 0.08121346348836538, 0.03323333465584344, 0.08283610665990461, 0.02004324071740191, 0.012945740618893217, 0.03662673260776266, 0.05670137335396102, 0.04770429504494514, 0.005726034174703303, 0.05812145521744125, 0.03484254830607003, 0.05217699979942653, 0.02509201294742525, 0.0454542450156183, 0.016733501482033925, 0.009624714035570863, 0.006884395505391783, 0.04229548830358733, 0.015683840366921598, 0.08272786609708302, 0.018736526460176515, 0.03026654808631828, 0.05578391794716159, 0.021832088579333598, 0.035263249320128275, 0.030920867612885854, 0.041578751763389, 0.06679792573014576, 0.03171856815536176, 0.003235855800730567, 0.043333583406262824, 0.03076543411870878, 0.013572860193709213, 0.027913537755187963, 0.05208406950377169, 0.02227813178192704, 0.009167317409939583, 0.026434327310491956, 0.03065484549639927, 0.008161305111923046, 0.051227667474097786, 0.03365959746823196, 0.02617919513384902, 0.033536291786379395, 0.06625094661308874, 0.022090873080155542, 0.020452956030625972, 0.014149236977250587, 0.047035864178812316, 0.041507363860164924, 0.03591760715109206, 0.016130710944473263, 0.03175511437978956, 0.018249409453522776, 0.011333575614938333, 0.02584077387807831, 0.011124421162680994, 0.02204210775333547, 0.05481269082895691, 0.023752190285332264, 0.016852266177715316, 0.07177976485822471, 0.029047719435766343, 0.04359411458755213, 0.02020789216452789, 0.016035001664873094, 0.047391409414910504, 0.023279803234242627, 0.07778153514429446, 0.02087090870425586, 0.009306546229298317, 0.050603815264278845, 0.007380433605923768, 0.06116975737254947, 0.02393122694845642, 0.06761334205587065, 0.02132580405281436, 0.01245591261859743, 0.035382659444885875, 0.02313740089565756, 0.03493629831580385, 0.23195273092677518, 0.11368156440796391, 0.25750694195589713, 0.15598326951505678, 0.16784119209454906, 0.1089950368529366, 0.10572361925076093, 0.14361445822062033, 0.1268847297216135, 0.1509862312025601, 0.12101852635462439, 0.18645881404799802, 0.10531561614404764, 0.21648098774735006, 0.11835693006193447, 0.32163922644911275, 0.19963500540583365, 0.08392844844849841, 0.105334653428966, 0.08206945183056016, 0.16983703499840153, 0.08383311646720094, 0.14660382523171364, 0.1001472192846479, 0.19364140927791598, 0.08528860691454142, 0.1343960915842364, 0.12966232704779795, 0.06984507875336755, 0.14028599005072348, 0.16769627890279218, 0.2527142959015985, 0.11015814218309619, 0.10791021038687999, 0.13362891581510344, 0.15416070037791807, 0.13912211863263962, 0.13403465130156086, 0.13968022900723642, 0.23207129069393684, 0.13514351760668142, 0.15436602726338372, 0.26743228517232404, 0.20286428051129465, 0.13994652116971631, 0.13821464152105395, 0.10309367005022303, 0.09474963190094118, 0.1856989314359042, 0.13666294575218232, 0.13406653588096942, 0.10999156402484064, 0.16430054821314352, 0.14571229807071148, 0.18069038648278485, 0.1172485234095685, 0.14003635263971745, 0.18465193439154856, 0.11810294127151852, 0.1608547306950054, 0.21351089550843164, 0.20134313632884335, 0.2051946893334389, 0.198858468042266, 0.20040590436227862, 0.1260777097195387, 0.18770252714955038, 0.11941086786288409, 0.1560436219217316, 0.1319479044046133, 0.11608007078569745, 0.09893672375549233, 0.15570171688112522, 0.15168571544270362, 0.18860427392346246, 0.1282505112730207, 0.07985090716711937, 0.11630983587594763, 0.23060115264548411, 0.24583214503382486, 0.17472118259437625, 0.15396088932550725, 0.13949538731286604, 0.14342129681139223, 0.11875069159413539, 0.10244564393595343, 0.12165460149727522, 0.2075932799808441, 0.13655909487316686, 0.09585049258725298, 0.1436378085805524, 0.240822512235853, 0.23927919746887302, 0.11082106104661381, 0.1791715099205894, 0.1971439632677263, 0.1826148912791283, 0.1846565922061282, 0.12399958131173927, 0.1370047435404793, 0.08824908475001013, 0.18090308313408207, 0.10153285017417324, 0.13650520824857298, 0.23908272655981205, 0.1383759949596659, 0.19178481051518073, 0.10389969413799625, 0.08858594893207473, 0.14034450384638003, 0.13144317503658035, 0.09478105682759516, 0.14632103153534476, 0.2518358382005846, 0.1797516529838885, 0.20103742128177998, 0.14755559754708122, 0.09346229775298028, 0.12292598569465261, 0.17749175489429506, 0.17010887363745322, 0.08085587662794898, 0.15035471428305874, 0.14295280340217775, 0.10067762791990273, 0.17097423123496194, 0.1301994466132695, 0.2059890612238838, 0.25305816212729104, 0.15372588419385497, 0.11811559704402763, 0.1490218438688786, 0.1999087286211791, 0.21182502710050155, 0.07706554170938269, 0.17495197424244496, 0.12943499811714695, 0.17038946100060018, 0.17863550884348733, 0.15230529671234472, 0.15113980118786136, 0.16806404707172226, 0.09877899391276222, 0.10727864750210317, 0.13804703680497987, 0.17431794455455196, 0.0756049108120703, 0.1713702527265395, 0.14419087809660744, 0.15837919417648547, 0.13326925285641225, 0.09365915170600338, 0.11368839025136926, 0.2577527336055233, 0.15686998564389446, 0.10597265145230679, 0.19401605691640608, 0.230345233313499, 0.3456649388517103, 0.19544045951577926, 0.05207427506965976, 0.12012607222723386, 0.14932732908956467, 0.1758399161119615, 0.14217810464962838, 0.09506941232229434, 0.11865676155373936, 0.0859071846090017, 0.11826753526205018, 0.1317832108226515, 0.19925683376289186, 0.2040353225123498, 0.15047980111933526, 0.21367005793558014, 0.2163263452389548, 0.08124528678073999], [0.09813615421373999, 0.0617362295968398, 0.04956405775080766, 0.04236272017982218, 0.03538106981244299, 0.016658258241330905, 0.03501792498413594, 0.0980799769862525, 0.03264204884368566, 0.01365378397637077, 0.045741891878987515, 0.06387660264848702, 0.035782009588494416, 0.012528681395305021, 0.06294179535020264, 0.031422115111302946, 0.05682494333614746, 0.030367796181611, 0.006808015102926161, 0.06743466736929071, 0.027087781157705094, 0.03483859912282036, 0.03564680656117778, 0.0660718582390297, 0.04320080121678691, 0.019498757131758238, 0.03355799505727426, 0.04541766048679429, 0.016086909867402528, 0.05088167535441537, 0.06305074071391456, 0.00950504727135863, 0.07936171406219084, 0.021302158749031446, 0.01759467623947609, 0.04761920565919531, 0.04724468059477307, 0.04007063490609008, 0.016405730763630524, 0.03763023117977766, 0.04576061123741731, 0.011273761385030324, 0.023696731265273788, 0.03256750465821355, 0.008750114544865586, 0.011880187009791694, 0.007610391654569897, 0.07346394021184215, 0.04864389805363552, 0.02952442530752911, 0.021170326508581642, 0.08209153048453793, 0.013988323081585189, 0.0263493949727666, 0.021478968011515758, 0.03489961419554968, 0.010136953938091475, 0.039191686908804604, 0.04151739195109375, 0.026927910099226623, 0.08260431143665507, 0.13012430870965605, 0.028647520849781654, 0.043691806119656375, 0.00922969037351469, 0.015345761935497004, 0.03959005262943045, 0.026436690691738363, 0.0434402649801585, 0.018981142164838892, 0.009935375137795365, 0.06460234838267488, 0.035022149959038344, 0.04930546860240641, 0.03891008447915797, 0.011609061790119496, 0.04401033015681371, 0.03439088584855199, 0.01789242205690713, 0.00989719427325913, 0.047022151204967694, 0.03433680387153741, 0.062012917572452184, 0.00914439031358568, 0.04551488470526473, 0.20177948468875503, 0.06977284432298715, 0.018098855939423366, 0.019351237325838978, 0.013012932275512047, 0.07921488565062323, 0.04983992984278068, 0.03013937174522829, 0.021285285662499168, 0.04707597654252764, 0.03300195312007301, 0.019976698320298907, 0.08733879609574234, 0.023891557000517368, 0.04780552973369918, 0.03708860701731136, 0.025568494738470164, 0.015291128375176943, 0.0020850526456225424, 0.022739257340529756, 0.021186837618569695, 0.06585536179162803, 0.05579107703881399, 0.05574488193697988, 0.024884531439672557, 0.08494171464154798, 0.02584566151903522, 0.027672417326680118, 0.026477320164802576, 0.02619473905783267, 0.04891947520175769, 0.05117621317866349, 0.032688328215191444, 0.009418301220472542, 0.03692827630607832, 0.06826265519785304, 0.03350997283574074, 0.06061769526211485, 0.06787981041857312, 0.04641411871078514, 0.016081635352043856, 0.023815813887443756, 0.0702357299685959, 0.033461682483433716, 0.009700210085288893, 0.028577412313391126, 0.051593531914536035, 0.05343977316853501, 0.013391372049227359, 0.029717163453179023, 0.009223308861105433, 0.04795935635845508, 0.04959694590539702, 0.02550940063121098, 0.015374749744941872, 0.023940613440748666, 0.054888939560060544, 0.019365482730790973, 0.03583978410930403, 0.03758199828406496, 0.04741256110249989, 0.01724325255641053, 0.010749627009875352, 0.031532016169700416, 0.03447545812495294, 0.03868592332207388, 0.022638602963378354, 0.024270046569947756, 0.04269234866144196, 0.023726512933330193, 0.03358614495805195, 0.048703380950516274, 0.04013722326846854, 0.02861541218965525, 0.0833051746350623, 0.027901623172745593, 0.03930615959689021, 0.051987431342563326, 0.05238533741043461, 0.0399838907704238, 0.05572017177098221, 0.055520000657246965, 0.07914105775736033, 0.031416128134174694, 0.045704529770920356, 0.03574475473273666, 0.021447001077655344, 0.029140814440324906, 0.04420437256715471, 0.04894395937181769, 0.028284843335108414, 0.041845545713459296, 0.06543492507790366, 0.06594075761254757, 0.02827169918154757, 0.04118775197815511, 0.02176672595763399, 0.027446944244025696, 0.007012101404759432, 0.057434940845855785, 0.0334904222719131, 0.017602136020638773, 0.016444136666494514, 0.01651921136785419, 0.06495998120836674, 0.03903575737269656, 0.056088878397619536, 0.016412481913463246, 0.09150392420950437, 0.016805442883783293, 0.028957966489777453, 0.006347409526502053, 0.04606018992020719, 0.025786519531280767, 0.022853069277780674, 0.08990232547324511, 0.03768099982651972, 0.037933027431849516, 0.012063644957848856, 0.0228826402716579, 0.046927006915211684, 0.0763856616592215, 0.005316349026191259, 0.04899231484159828, 0.026326847089935216, 0.022868103753294677, 0.003458113708127771, 0.025406143470336835, 0.05413818871602417, 0.0692090189324752, 0.024140926280749903, 0.0841475266122049, 0.07463398629859572, 0.026960947640961217, 0.005678092392401831, 0.055145640301728444, 0.02356794805476262, 0.024467965385185617, 0.043531073212263086, 0.03829573559003972, 0.01396684484901808, 0.01939893204478487, 0.0955999511924963, 0.0031713308482956624, 0.02920234279196349, 0.0032638081944652746, 0.027661626978266626, 0.08908348473449869, 0.027456204331810438, 0.06277209538365565, 0.0036557962331214863, 0.08639469998137606, 0.031142786047571612, 0.05094306197978797, 0.024960044726368882, 0.01142112127009539, 0.046549099572603746, 0.019114931759935234, 0.07041630455322805, 0.04726670945303575, 0.036620293638759085, 0.020868736844990524, 0.06509838265276725, 0.04338791053141317, 0.031044242242651603, 0.07115351862364239, 0.04001242371516363, 0.041589760446860906, 0.0825490152102805, 0.023289607244453604, 0.06013608642763669, 0.03425716137092921, 0.03325380452518021, 0.018109414546239763, 0.024059730536875226, 0.057955804025574084, 0.001574466056603518, 0.040175841760731516, 0.024613186927332033, 0.02908395730980462, 0.030233753777499643, 0.04350522157525824, 0.06256768397325951, 0.04941432203556742, 0.028938961763595863, 0.12431150933186855, 0.05093578414450731, 0.05415883861602314, 0.02725744281985587, 0.05682824517510111, 0.05257178022856674, 0.02277958420886388, 0.06871154441708519, 0.03982869667872306, 0.02925599001408104, 0.030661008673750108, 0.014626070211130767, 0.03703635215999619, 0.02495541947052604, 0.031179795755193602, 0.017022433457896113, 0.015122173429136316, 0.05024191149840913, 0.031065985733162493, 0.05461007589474321, 0.04672276021371927, 0.04453939813820105, 0.0871303588933041, 0.12437196132997352, 0.03308894623431467, 0.03188188277905987, 0.038642489967206796, 0.03286184713004097, 0.0814890329756083, 0.043493270603639465, 0.030412325042209802, 0.030521132510095358, 0.005389896818556853, 0.008987899618073097, 0.013016051210973774, 0.03108041882965594, 0.05770777156876941, 0.050761583411405166, 0.025553149997346827, 0.11592573471247189, 0.0573854209224303, 0.06406632432293508, 0.01981500588778046, 0.08547127291920685, 0.06793185843214875, 0.010791040765452049, 0.05329580992580422, 0.08415037645928322, 0.04333542584772072, 0.07114234906170638, 0.06347665878673715, 0.052001987013124654, 0.01924466491947251, 0.002029861995740043, 0.029289858761213483, 0.04533751619859569, 0.10655624957214441, 0.02672684649305959, 0.07071519375688608, 0.0329408690994305, 0.08835508833609282, 0.013020146908538957, 0.02904656264300068, 0.06609379899718108, 0.06773653665497419, 0.008432098998567991, 0.05784724936670354, 0.014842684444550787, 0.055884781083272356, 0.02512787352316082, 0.015046800911096076, 0.04163404798976356, 0.026898599575243654, 0.021342826526491873, 0.023021307931612098, 0.025979924173424804, 0.07494163954810751, 0.0537825055840996, 0.04687182943246538, 0.0587213441969887, 0.016119321132259026, 0.045696324969251315, 0.1920377114607442, 0.2309378329664469, 0.13543244000644455, 0.11692754789105347, 0.1492147601299709, 0.12092245126804038, 0.13244748566179507, 0.16144114035752513, 0.14356460121850814, 0.1014866857158561, 0.13792119920253754, 0.08992141638431819, 0.13031754672767656, 0.1692304925452317, 0.12598291399978823, 0.1150420216482974, 0.08192224803590968, 0.1840323531219075, 0.1119782598388772, 0.1352817351899801, 0.0650876727435858, 0.1882025220942113, 0.1030070408277454, 0.2494432690042642, 0.13678182727627217, 0.11789197597893016, 0.14534866677657252, 0.15531168619711555, 0.12588539866790657, 0.204276793426083, 0.1779627304283842, 0.132152633741498, 0.11239475119979152, 0.09926915994935459, 0.2229400282545436, 0.13424143375408265, 0.18867787965122731, 0.10147958408079802, 0.1676300276191004, 0.07637040118776983, 0.16971462946986, 0.13175874197434995, 0.22414140733740023, 0.12828551383028108, 0.08887626561186007, 0.0989121476548814, 0.13756279262804216, 0.13189086149777138, 0.21191127327901704, 0.0857574757068388, 0.15020523520727314, 0.15351381573465564, 0.09826240550366142, 0.17290552357031455, 0.11708635791775682, 0.17978451815584015, 0.16680709597083831, 0.130617868515753, 0.13065617291196702, 0.11471421262549777, 0.14026735879240498, 0.19513308971879945, 0.12562293694504809, 0.11305726403670927, 0.08660906670434822, 0.12511230103911894, 0.1501341422478999, 0.2422426247428502, 0.13870248631123575, 0.103407796742695, 0.11298270069903905, 0.2687625815310786, 0.13580471277236938, 0.173760523659087, 0.1552577536072462, 0.1735711314024464, 0.14373162370775977, 0.1869341256397386, 0.11794920274687391, 0.18492515198886397, 0.1795436141471709, 0.10045363147172237, 0.1431803008721721, 0.13801411034599428, 0.21939529346362238, 0.22606747495310925, 0.16534363820908532, 0.1256945814877268, 0.10942127285224777, 0.14766404495364235, 0.23143874721661692, 0.18253937033155274, 0.13881280297233214, 0.10815590244507599, 0.2826568424221008, 0.1701836284971045, 0.14036878883357973, 0.1687328724731361, 0.07939684685439834, 0.10863355060498561, 0.1715948084189046, 0.1591331932333208, 0.11978358495980503, 0.1003104419777951, 0.1398860768324906, 0.10559723006501313, 0.16984350078048246, 0.13336967166152694, 0.13195430889966028, 0.09138216985569847, 0.1905671290812954, 0.1252056105482963, 0.14154134768872492, 0.17667553417624968, 0.2083699552402381, 0.15329471458831143, 0.18943241496960964, 0.1859502235968267, 0.19850255891440377, 0.13232350199212953, 0.12752674970655672, 0.14247453471104946, 0.2706129596598687, 0.10447072841587568, 0.1712346091986664, 0.16155380124766983, 0.126728723576713, 0.22904173471033576, 0.09439721613401368, 0.06757106932420885, 0.10906305779973346, 0.1613716408610344, 0.1659618405204627, 0.16859678461426691, 0.18130918634274315, 0.0940069709453852, 0.1583192094920143, 0.15105761527534456, 0.16131525678980738, 0.1494782943759234, 0.10959679125657967, 0.1284036599099636, 0.15413977085582672, 0.21910966524193365, 0.1398364343349972, 0.14016113304082425, 0.12576152225055043, 0.13377687803679897, 0.2574800063044794, 0.13597735834698524, 0.2053689590144542, 0.09070052780331143, 0.18290168395446194, 0.11422121206358557, 0.10836095353888889, 0.13156987065749784, 0.3455750920599507, 0.13880459050978386, 0.1708537715697481, 0.20198069002118804, 0.11912565332867446, 0.11355237134041325, 0.1378569397474489, 0.1653970192156492, 0.09108512692393796, 0.12894513085484505, 0.13136797584593296, 0.13555464635212577, 0.11527406201968271, 0.06605312738928103, 0.23653922272064995, 0.09546925659261404, 0.09965233414644196, 0.12836678043728875, 0.09955751544405377, 0.1603841228831199], [0.005229699215100658, 0.03758451488289622, 0.06800983852196126, 0.04111173307342876, 0.02395514995911189, 0.035221780980786974, 0.008447751132470947, 0.03806425446283914, 0.06587625300932316, 0.04165295887017443, 0.02840583926186927, 0.04561937143725734, 0.09175785937376561, 0.020385456023617618, 0.05160548671659443, 0.05576263602462508, 0.0562381889340618, 0.03624571877862177, 0.010422264233291631, 0.02412188133495229, 0.013259038978797055, 0.0407578042828508, 0.04522425392943044, 0.0776944156255453, 0.035842610973744624, 0.04366677036629089, 0.017259464892108115, 0.05120293432546239, 0.05148682352756301, 0.04406017566760702, 0.006866737178737118, 0.025932206471841183, 0.007668756541886157, 0.03458724567486394, 0.019417051939413916, 0.07029428206864866, 0.05854998948052526, 0.06342623104912139, 0.09607631998557238, 0.10206515870748029, 0.052788085153987335, 0.03170960109620806, 0.04069048813694427, 0.08574458244707316, 0.008771656937296353, 0.022631060827763814, 0.049995989613835855, 0.07592866722975047, 0.019217853757342505, 0.022849388225304506, 0.04910652322935001, 0.06433291525970544, 0.05697858609980153, 0.04323089698089227, 0.025656589104102987, 0.055825957022006475, 0.06065654358075512, 0.06751773428292045, 0.023137820328796105, 0.040248792483321125, 0.026159654146120436, 0.04150110109138393, 0.0694016823845525, 0.07410840401726385, 0.012749479426401518, 0.031863684360418594, 0.017626258214154554, 0.06507959051598465, 0.03381450810740071, 0.0489792530424893, 0.012734148091816855, 0.10740181911856898, 0.05708084734637411, 0.04873868994294636, 0.033874477470113386, 0.032888575937719114, 0.010467630044947709, 0.026604952328207514, 0.01567198707151317, 0.07328161894674264, 0.08292545549451344, 0.019668911005400365, 0.03751624495752397, 0.034099845215678215, 0.11052376530583828, 0.026549016418416175, 0.0829347558019142, 0.07134357737677713, 0.12988915036041893, 0.02669267131075744, 0.033298884969084494, 0.026934034972181244, 0.04204929445780093, 0.07167797475572556, 0.0772580825873921, 0.03420243204961862, 0.0214005493363666, 0.06329398512119247, 0.03348435102511318, 0.09014473101424594, 0.01625457395529074, 0.021433782230521885, 0.05968754194797047, 0.02474912156861636, 0.04965589254073078, 0.03633255484483896, 0.04821758927597154, 0.03074129851865432, 0.06188554396372169, 0.08586806049870868, 0.042758653571288434, 0.08884839533317475, 0.05734659558642776, 0.051728788568007375, 0.02898942589038803, 0.05110869401945703, 0.027489768558992978, 0.06494737906201233, 0.05074409745453347, 0.013629616775189438, 0.011237294642224668, 0.050263932695792574, 0.07435713744451923, 0.03634131506025311, 0.02425522468383274, 0.0666914624913085, 0.05254164999050479, 0.0285803425997015, 0.06686275975117761, 0.06619159778159472, 0.06208158203310544, 0.005939247935349423, 0.029612665229867545, 0.04828547615738166, 0.08717332110409776, 0.024883744284330357, 0.025601197116737886, 0.03900717080180203, 0.02574556447084873, 0.023846930463708216, 0.02652422389796665, 0.01604466203359827, 0.017966870481388706, 0.018303738493892937, 0.09421120232511913, 0.0905782295270793, 0.0068320903735565805, 0.04652397188868734, 0.009951312639450115, 0.045738153369917024, 0.022196884327117476, 0.006298110332159747, 0.024489756756191774, 0.05361952037820893, 0.02786320960900236, 0.009904084276528129, 0.03923207889461229, 0.030431647694879965, 0.07495137652562511, 0.08997670494981351, 0.02409011741439181, 0.040969497358967225, 0.05422293336220807, 0.024973156321192944, 0.025352515400417393, 0.029726178392827995, 0.04955463869977863, 0.02123276075919069, 0.036964914461057034, 0.04964283457206142, 0.01612804687371658, 0.028057307560717868, 0.06668829854818122, 0.03855875655708294, 0.005007128648069357, 0.03678342823179499, 0.047100499016983856, 0.026632615763153282, 0.024656013157519124, 0.04434688790370861, 0.008419256492127335, 0.04811476495477462, 0.024345395147740364, 0.020895967440259074, 0.01348587186751707, 0.06695953197777271, 0.031856312679367206, 0.045660357141206344, 0.0283960544038564, 0.01915244708558725, 0.03804602540068088, 0.06366294455684482, 0.008698782823499172, 0.07521897103757628, 0.012781835149883503, 0.029349123323035818, 0.018048516301918897, 0.08002306244546369, 0.03430256740220132, 0.07670793186632857, 0.027410154786681937, 0.011008341605174205, 0.022037584004142595, 0.029281673111742543, 0.037294956630155925, 0.024370584118690704, 0.03669676453536076, 0.06558182243738445, 0.008532821366022672, 0.019906907710396958, 0.02687180373487213, 0.009395417216564379, 0.052772759565062104, 0.052608751631792516, 0.023258442787693876, 0.017879952060719653, 0.017259926460082495, 0.0274996338562379, 0.03443187921338024, 0.12393103176427465, 0.02860438243876542, 0.0352709676559654, 0.08172733228533499, 0.016003058671260315, 0.01078495036645402, 0.0459395463938915, 0.02273574482739693, 0.07710118011962022, 0.029317968442375143, 0.08091826682850238, 0.0475238123908639, 0.049782530705053965, 0.02355174912560371, 0.04634084240082772, 0.03012222286704327, 0.032250658353610386, 0.033704394459604256, 0.050263610938864375, 0.027799829239806825, 0.03808615308615469, 0.028903126085717833, 0.023946954733541897, 0.04040542298987989, 0.10241783494430204, 0.04505011448336225, 0.025682373708414457, 0.03606155890250399, 0.020098148154154904, 0.04572206552350714, 0.017788810580368006, 0.050403594354828524, 0.02321133795644968, 0.010807553790659915, 0.0757860139973702, 0.005207019182102334, 0.016387386788283626, 0.016941569047048688, 0.04110175860865463, 0.031456782505096446, 0.025088647906217846, 0.055387624494370916, 0.03605188704245994, 0.06888225945013185, 0.10245997744101672, 0.11151818573595056, 0.050727189894044594, 0.021318319373794144, 0.03814284742299107, 0.032617936226268934, 0.062207714579398596, 0.0662624838972284, 0.01977908402501095, 0.0368839236457021, 0.015474799870242997, 0.02438573159217354, 0.02134764713475541, 0.03752644924867538, 0.05487957413518622, 0.11860770128306844, 0.005559894122979454, 0.055022338450315504, 0.03602854817384674, 0.009904772798050075, 0.017029343570973125, 0.04258880038715659, 0.02193373312512713, 0.02770479220236021, 0.01314130275615401, 0.024804333525319255, 0.08922834430010089, 0.010111760179091607, 0.08617109423803707, 0.031745210778148424, 0.09518508393798145, 0.04167934676872627, 0.06699447324799915, 0.010581866203386699, 0.06351716568573348, 0.12073347269887887, 0.03185268333782593, 0.0447869441291738, 0.08495167378456363, 0.0822700672752915, 0.022537925603589224, 0.027474693863862948, 0.08117930362782172, 0.037085374126270894, 0.02869410857167696, 0.02129255966734021, 0.014166676968846832, 0.030769469486849926, 0.017127368351324432, 0.05486730906751849, 0.03229689559028034, 0.018083859768305576, 0.028102087315111875, 0.018607959669503956, 0.09695293907556804, 0.04880522850960974, 0.05511053049215867, 0.09269392688668544, 0.05141209165054945, 0.016211556203122583, 0.09019903132631894, 0.07486687702757698, 0.03398882375369149, 0.02672334355602582, 0.013278252463938009, 0.054095490805564396, 0.02980622692003606, 0.007142714128994774, 0.08235353255464185, 0.023146695457398895, 0.060626493781925216, 0.043748983091885046, 0.04254632847263448, 0.05219694872897479, 0.036364987177113374, 0.044444506657460046, 0.03560441508588772, 0.008612244573962546, 0.04206430595067721, 0.08523656656184504, 0.040859973598872466, 0.01906122325078374, 0.029513926072526845, 0.061742377452432155, 0.03618792893605367, 0.029690947924410144, 0.029203964983143156, 0.05275510123840744, 0.016894238219866832, 0.11185880374884415, 0.16922824024673433, 0.09929680806254187, 0.19285927947250106, 0.07840304695550473, 0.17056679503331262, 0.10545172698555455, 0.16177487890085868, 0.17985125973580346, 0.21669647295869168, 0.16760465478704822, 0.16082952640229659, 0.18816135252916044, 0.10511010539748016, 0.09333095963924162, 0.15456130307528282, 0.18927054059120918, 0.13005563658812355, 0.08050232705089354, 0.09599455542141393, 0.0979278319244904, 0.14354638364766875, 0.16383078309797472, 0.2287899828966587, 0.11857817625446666, 0.10941743475174713, 0.15145690030147954, 0.1601526877211948, 0.16573756061975034, 0.14338809456075394, 0.1479709704196261, 0.10051128724890371, 0.15838372941699722, 0.1239651533204221, 0.11657029044844451, 0.12108141451232857, 0.14627715001904196, 0.21766603383566105, 0.26696389901541895, 0.16609216739814128, 0.2265407947162467, 0.06842872773807857, 0.10508503133971846, 0.17739659145234093, 0.10736225833815914, 0.11066686286921464, 0.17665863427664005, 0.15396180863101638, 0.13279576455393147, 0.2095546795716209, 0.1457414553771096, 0.1434873489122237, 0.1900192076760915, 0.1003670328927617, 0.13205921698001125, 0.10582196195760082, 0.1481124515374822, 0.19081279815685367, 0.14391295671943696, 0.1335638136632981, 0.08246633134061292, 0.19095077059201657, 0.19150465216127135, 0.20450180877120266, 0.15520808046623585, 0.11284548669092118, 0.1832323275025814, 0.2067927027782125, 0.12664654532507544, 0.13474086179367958, 0.11479643684241081, 0.15243269713415256, 0.18452767493023028, 0.07506462730347149, 0.1774812748114909, 0.14642152694925187, 0.09995529127697791, 0.1265743262164535, 0.0690636384270845, 0.33512828811522455, 0.13603092321465093, 0.1659738834226324, 0.13387870644369435, 0.278797107598474, 0.19534891200882776, 0.1313785938245635, 0.16008920967578888, 0.2762627355273693, 0.23780717484412656, 0.18395295576943507, 0.09330531867641596, 0.23715817579819312, 0.16770744846472818, 0.1648000068962574, 0.16671968533867793, 0.12181468322993287, 0.1846671488977248, 0.14040058148243736, 0.11045327755592524, 0.1401295702183439, 0.16315267271091863, 0.10817409703327764, 0.3247300235013808, 0.1314311780996861, 0.11216639571132199, 0.20727504705709798, 0.11302003216358925, 0.13371805780597273, 0.18508223065685842, 0.17551347072566711, 0.1738162029294237, 0.15963092055772582, 0.12533327910087763, 0.17905359366728416, 0.15289071046056288, 0.2398409544219894, 0.19786586324053426, 0.20338031733709, 0.181166127083763, 0.16826385812413308, 0.08707069596576114, 0.1286510909877477, 0.20539831550371265, 0.1412072720667047, 0.13225577981962314, 0.192858804497988, 0.12164056676650241, 0.10389195664996102, 0.21552339316375796, 0.2149776014829836, 0.17066825571800434, 0.08289156376474327, 0.08646616832383218, 0.15219646626182143, 0.13595357897781557, 0.21615586003228543, 0.22036471644476538, 0.21042936812004737, 0.19221719053964462, 0.12584887925655613, 0.1276332665715487, 0.15674338195352785, 0.12887160173587262, 0.13799488153909484, 0.16689050762403398, 0.21994836297967743, 0.09262163883015033, 0.18173195962463656, 0.15151169090982408, 0.11269748616482943, 0.06664290017778836, 0.10454474017024042, 0.11684196054815285, 0.1052140252244088, 0.0748310317735999, 0.0823299523683325, 0.14291362566573007, 0.15431664523578462, 0.1640212785212263, 0.25388034300938733, 0.0986438483420399, 0.09941259459141763, 0.09042310438329175, 0.12130973935728112, 0.08009570290244396, 0.19051200139426416, 0.1746709731918189, 0.18280259814233552, 0.14960813095733044, 0.10782109903952769, 0.09820828905269023, 0.14148085738622374, 0.14969454567518928, 0.10012175452204482, 0.15258982176742247, 0.18244609146589236], [0.06254231880208658, 0.031779159964512915, 0.01537689000308033, 0.042448353487998254, 0.03566912653285169, 0.013062495291383277, 0.06090451092008622, 0.03425343818361721, 0.023738619037753633, 0.05407381434774688, 0.02902171266595683, 0.012591194169926307, 0.01611100716306077, 0.041772319199216944, 0.006264932500574017, 0.05987510708491168, 0.007344173706857669, 0.05525898684056536, 0.018466829036873196, 0.056217776521319346, 0.04197860752502757, 0.05729395385471083, 0.0292178254289132, 0.03742814867667133, 0.04112102188951066, 0.030306689178330765, 0.07951421918527735, 0.09351707303956633, 0.003098078478585869, 0.0433916911753195, 0.04326912859875349, 0.05653879800510984, 0.054927715100348, 0.03066738252528012, 0.04882854822602484, 0.05920344715817802, 0.01218528439846611, 0.08269985026169209, 0.036444909299813935, 0.012084408813426572, 0.011080733083579089, 0.04049762550200667, 0.023232091278318438, 0.05725047070412867, 0.024478723174862327, 0.03599900399304686, 0.049294685914872155, 0.02021214969816708, 0.11589518312605158, 0.03245189049912076, 0.055317910493261395, 0.04819922997886616, 0.07394002555238624, 0.03586709514380463, 0.032563340970345085, 0.09615131999335944, 0.053148521861482056, 0.04213041167766337, 0.03829566664212654, 0.029888123634361455, 0.045733698568637335, 0.04150606534113327, 0.05871349562620444, 0.010662042092712177, 0.03663122954387819, 0.013491922046899075, 0.07461648118952591, 0.0633401802230266, 0.06114516595018007, 0.06723609737931721, 0.0062923838249257505, 0.0249202081543063, 0.03489995893511561, 0.07171296965210669, 0.030469456049163016, 0.03149418674799944, 0.011786003202770748, 0.03660391850937759, 0.0449758499199825, 0.07214625366032124, 0.02547766543894766, 0.03347494729584263, 0.03182787549561791, 0.019020182005460226, 0.04932009705132054, 0.036439251740493124, 0.015714725201588967, 0.12585186699946083, 0.05969468954830401, 0.00290923924166559, 0.023745883466495622, 0.028814773165410566, 0.022606285544292583, 0.06601635516891557, 0.030948347186729796, 0.008384063370495794, 0.055818602577933384, 0.03974984324867687, 0.04983947785090535, 0.026780041723301815, 0.015429762518784453, 0.04018543318154351, 0.04175413610233415, 0.04946018771959409, 0.09130026739571365, 0.09467041840957058, 0.0740151328124827, 0.009741357625311902, 0.011034056303962585, 0.08586920196971587, 0.03722763282337016, 0.048724452198873607, 0.04315529942452427, 0.02942405055247007, 0.06622269329044127, 0.032671941594491084, 0.08603023365139963, 0.022421196786566608, 0.040085845581826665, 0.044840229374747125, 0.02482631067264705, 0.05531386554902119, 0.0853713597321222, 0.02012308048565061, 0.03569747944692931, 0.029716315010802883, 0.024625122577192324, 0.04831287146155392, 0.040185107594175686, 0.04321505045217853, 0.028361737495288256, 0.014692355968779134, 0.038850781612939415, 0.10107328935015587, 0.0433728645645803, 0.0691508881807808, 0.016811567756737915, 0.07043626114365555, 0.021712745487269376, 0.13315604038296208, 0.028875041302413713, 0.016769015402983756, 0.023081964858236815, 0.03044990740055519, 0.028403412678369114, 0.063534046433145, 0.07300273995966682, 0.020440505186636603, 0.04576843299512421, 0.061719965550207326, 0.04485755828359435, 0.11978622030226455, 0.028890615869914333, 0.016259959553398432, 0.09268301779464369, 0.017604953308980313, 0.07161705544398678, 0.020085626447032538, 0.006199849500966769, 0.01743860880754167, 0.03568144905711374, 0.027508026349448392, 0.023126622038562934, 0.03533882006341892, 0.014438072234512338, 0.06583683778561893, 0.01957993563865462, 0.0477281816664242, 0.042099404268928116, 0.023449591300900907, 0.022119281535607674, 0.039321197902843844, 0.02663296816359845, 0.027379306341190974, 0.018751415378984906, 0.11140715661308459, 0.0406129791912052, 0.058636687650916085, 0.03641089116553626, 0.06599687355300111, 0.03671560263741882, 0.07781412452459335, 0.021760438290995457, 0.07078483114920317, 0.02470440118603649, 0.045838028252605474, 0.03194314299992496, 0.004513688543210588, 0.03493872681452382, 0.034459469869973204, 0.055482910510392926, 0.059273004111263065, 0.010408191198122599, 0.020302402516526562, 0.013090180751356869, 0.03793783463357437, 0.011600511291274622, 0.06911315068963074, 0.006168887578702022, 0.04181274565898123, 0.03163538441332358, 0.03424074027627226, 0.0583569927802009, 0.023370569331511375, 0.043711609492499026, 0.009943030271378737, 0.03710941779577444, 0.016395149174176397, 0.02215459052803776, 0.02248809158411478, 0.0523907230085423, 0.006674003821136731, 0.017900990750340205, 0.03869702776653632, 0.01484735279283937, 0.032123177492570494, 0.05045402209244428, 0.028076386980472073, 0.045970998133622834, 0.007912044999219717, 0.015803567460557867, 0.018105021031994014, 0.042890834381743785, 0.03338330019746096, 0.03124184887706032, 0.04422592645090434, 0.05218348856414518, 0.021517693756088134, 0.0423640838163274, 0.019866100121890346, 0.04761717552619596, 0.005671656296227969, 0.056109474671463815, 0.06034165463079849, 0.03498390684985826, 0.015608364427011582, 0.05343915263731634, 0.018106861558232098, 0.050361421214596885, 0.04171957404563024, 0.04657570580621401, 0.017935868818312883, 0.08048199507738314, 0.03016204603256718, 0.017926968791852557, 0.046185663630885464, 0.011528413799110682, 0.04719933202009528, 0.018323082213981018, 0.028583634862556096, 0.007928670543591462, 0.027084065631272334, 0.029913199607342966, 0.02392237288727155, 0.08024321313226417, 0.07382226251666585, 0.04883434751161164, 0.02204426812128194, 0.011531040523081057, 0.025868115556095878, 0.06411664863868106, 0.047072498503351407, 0.022846059573273507, 0.09321033143468442, 0.02010477864513955, 0.020515302181123726, 0.030510068285248937, 0.022314442434318127, 0.00850566737954655, 0.04257382719867653, 0.054658036829242786, 0.06575510386497745, 0.044948604002955465, 0.039346363891156456, 0.008226508770378367, 0.035283152284401084, 0.062127459208450975, 0.04170942721107314, 0.04390766671408088, 0.02067045605320844, 0.08772537172321351, 0.12292741827907101, 0.08294705917397815, 0.04944288562382421, 0.019943126432237127, 0.04162805718219569, 0.028359324318326773, 0.059258931076094035, 0.08471846129865417, 0.06729288747714413, 0.1063530600719875, 0.043804880697280175, 0.014016788036021736, 0.03207896847368008, 0.016388426752640836, 0.032421032477530747, 0.052084502343448906, 0.05046306576039042, 0.03934973467802329, 0.0157870362407618, 0.02610910958009622, 0.022898563409164067, 0.03509342294907378, 0.026645687138361317, 0.03253687646300082, 0.07516969626228656, 0.060315580828295606, 0.032378840185100996, 0.02747762989583275, 0.09722986453843695, 0.03960348598118271, 0.03541048375829574, 0.013861778763032729, 0.0017040803528112932, 0.009760016654317659, 0.061600900165015654, 0.03251373677724793, 0.030202114346226862, 0.010107615643421249, 0.04978830700800304, 0.013144819099726457, 0.02014965033008447, 0.060491597189778284, 0.054772283521390734, 0.04072056857929115, 0.005496195348490391, 0.07291105455688893, 0.029415817022503867, 0.035089201804610996, 0.06206721405408556, 0.03908679798065175, 0.03991606900648725, 0.039758756681675875, 0.011940909053889975, 0.023535109695888335, 0.06802758111828758, 0.024599473953487414, 0.016004745979913543, 0.00920170996969025, 0.0486748748188538, 0.053612840091509205, 0.008541845881770696, 0.03559500369573793, 0.08939345156954182, 0.05865030486377017, 0.02122146670796698, 0.0768359911237513, 0.03131977342549832, 0.04514101081557813, 0.04481141297747532, 0.006399263145266882, 0.10074102935651619, 0.1894452546032206, 0.11701723380434899, 0.14917700731706235, 0.21363972085377864, 0.1065922020784309, 0.2280019695359853, 0.13948884492199268, 0.11861026767761478, 0.15712964348495007, 0.11873004552457603, 0.25129347859371093, 0.10241487018403508, 0.12998970706135998, 0.10153820512876396, 0.1003639915237023, 0.15971892873846716, 0.11766138351372174, 0.13575549928411362, 0.12413801339965676, 0.1898451371779365, 0.10173528124728512, 0.2993084376137103, 0.07599476529585739, 0.14560604167561378, 0.18259049903961921, 0.13458036637354281, 0.24713811044010425, 0.16484724387766855, 0.12894370593130589, 0.08552150530440193, 0.10433827181376758, 0.16204330078776807, 0.14261425382667972, 0.17506860346803743, 0.13985080614445672, 0.1016565503913068, 0.10183324091016285, 0.1197366007874089, 0.0774311112059701, 0.13057466115682356, 0.19213695049045548, 0.13000035568350746, 0.14993721168608437, 0.14007948338985443, 0.0650372564972889, 0.13118446714455081, 0.18615322157500253, 0.11637034916108656, 0.13770526966019986, 0.12427079941957228, 0.2029320792925935, 0.08357627782970668, 0.1409704896110681, 0.14332522938568748, 0.23799691950121235, 0.2358261174372127, 0.2507074826186703, 0.16724935852952544, 0.17129365925586995, 0.09004859464062799, 0.14451433573999714, 0.12213551319174229, 0.1650129793392074, 0.12457057728522247, 0.09725658568523585, 0.11968796952597557, 0.12771000559892387, 0.10516142562752771, 0.2087535661074423, 0.12489950479639154, 0.1175301526522925, 0.09562140165437615, 0.15851868346573847, 0.16205128342393907, 0.11230426855505475, 0.11861559964956776, 0.10766989626591245, 0.11399993522753639, 0.3292777359245285, 0.1890508878615595, 0.1576810582510887, 0.08903466961196355, 0.1655933522288838, 0.1418242792809202, 0.16210158475704733, 0.08294151269740636, 0.14539424900806722, 0.13694408469863478, 0.11841302301975028, 0.11351143160173971, 0.12490623870924597, 0.07408860830530044, 0.15612231447331368, 0.17414151450559018, 0.1237302324584415, 0.1480499694063779, 0.12150954274881272, 0.07008881728735662, 0.16146982268941018, 0.1494760573991845, 0.11673740486824706, 0.1176438017958595, 0.12984745985557958, 0.07580015598045242, 0.20257353482227172, 0.24875722194631256, 0.1874120419304217, 0.15183986765482735, 0.10796773592911421, 0.12497402982966554, 0.07039453233442, 0.13047658658075717, 0.19837639955503328, 0.16032390837227145, 0.19905211974776563, 0.15168971442166837, 0.09749769653764465, 0.1709609013050795, 0.15483724794560863, 0.11590475156422585, 0.11824740247140009, 0.16142954178635152, 0.21127912816741776, 0.13960591847858123, 0.14502428982767368, 0.16362688113604823, 0.19269659304090087, 0.11464786175037585, 0.10710582572726474, 0.18170355308440425, 0.09596469331412547, 0.10448232698704928, 0.1418647287233222, 0.1707272751316909, 0.16898217280545544, 0.11541171269791743, 0.0815412188850103, 0.19987258459291152, 0.15803142090237912, 0.2546959048918178, 0.08415885705260501, 0.16733995608745084, 0.13005986539346556, 0.13978372748580672, 0.1017640938141173, 0.14352223655629542, 0.16274925080999253, 0.11235080073557555, 0.10428372635355881, 0.18983623523625637, 0.18772236882678925, 0.16053930165306216, 0.13630017247651854, 0.0957773694948804, 0.19924940271002634, 0.10331349898009531, 0.1028923191610844, 0.11851528043588323, 0.07840940548527627, 0.13959361510651727, 0.2155641183978127, 0.09433729273657646, 0.1265675769818406, 0.19245846227051752, 0.16043782564661196, 0.153977636007532, 0.08132743438886059, 0.14145208312378776, 0.11322407968222134, 0.08780682985220226, 0.24642290607575448, 0.1410199022821842, 0.0853283362342946, 0.12043348032860987, 0.09587921322353425, 0.17255054906971995], [0.02115260306445341, 0.08470474832480954, 0.04303406984094651, 0.049877636690413764, 0.006734121134579783, 0.040101898954279964, 0.008810499510277183, 0.028053222396861643, 0.05908856844349254, 0.01146374352937264, 0.016931347518918977, 0.06651339301418874, 0.0262806155989247, 0.034387813835975625, 0.03001621353530115, 0.023296898486272945, 0.0074590351845648505, 0.07831195144042855, 0.025906979196494626, 0.01609516638000646, 0.03917415115621783, 0.08847010111616505, 0.033090332853457624, 0.03546678739029073, 0.0405845764814125, 0.03663090778694999, 0.02199002143536364, 0.017346571004318617, 0.08064528671844352, 0.03251727993389772, 0.010000969501092069, 0.03661005487365108, 0.04498708076895245, 0.04501842525637439, 0.02785857477706046, 0.027220932984604474, 0.011797387269325556, 0.07000422585875758, 0.01734906462051215, 0.05528127233828268, 0.0805616145953536, 0.030597722150325298, 0.03715847423600574, 0.057915124756794785, 0.04597214726550926, 0.06924532383920685, 0.03346839341365042, 0.01859215527562605, 0.020265375571926276, 0.035714387007418184, 0.053995014543855385, 0.07564361357400495, 0.05461096455673537, 0.04230157487214573, 0.04291207033900484, 0.03107624939612804, 0.017971982203063466, 0.10164093751940997, 0.01668362341250383, 0.039844029928527536, 0.053787408546815, 0.06673526739881885, 0.0929989064893415, 0.044916068248811274, 0.042658100700787, 0.0248166905235379, 0.010181065280771544, 0.020528360149793087, 0.061410649889899846, 0.04764355193342894, 0.028688843632417343, 0.04679382252957552, 0.05736712674279848, 0.0420799111616948, 0.04009542168088017, 0.01610368527772446, 0.09191673834838214, 0.03265315328814811, 0.0363575829373252, 0.03778798400514549, 0.023812096445791187, 0.0209170195364183, 0.023009764901813, 0.02360469154683092, 0.024845219637838103, 0.08295164804064459, 0.015561212672882024, 0.06415444741686506, 0.033651691440853386, 0.04533465102975888, 0.03151059252089791, 0.10872648473108008, 0.05033936171281723, 0.03700838228988071, 0.04343967892289643, 0.03754330318300955, 0.02259444948586245, 0.02422712074833051, 0.046242086006508726, 0.09332910570646487, 0.03883435668784284, 0.04712983635404418, 0.06790166690705285, 0.07785531707228192, 0.014451397376345291, 0.06178376918298103, 0.04830125373818221, 0.05693601459384926, 0.01570157147192907, 0.03911099486774014, 0.04961801715375436, 0.02584671297471129, 0.030443692512269464, 0.03736473574873902, 0.019998673552406893, 0.023469245286598325, 0.01986895379940829, 0.040892808127307126, 0.0833565025259891, 0.08213450801709006, 0.006904317621862697, 0.024874097322143858, 0.04452851968967626, 0.0674815213067397, 0.044390528102315245, 0.033448432992783286, 0.058689624326483864, 0.05455334325351062, 0.056477170062041095, 0.04524509535141049, 0.05616533014202311, 0.13375389539907057, 0.044762410163398714, 0.0916063195214637, 0.01859291753311071, 0.04626601859326324, 0.033035331570933905, 0.06552629638463259, 0.08226779965503563, 0.01276850426239112, 0.05186270839805084, 0.031875604688520395, 0.03628638272564258, 0.10111774543240186, 0.08653890837224261, 0.020687572372656678, 0.016281099749668952, 0.010850843504041193, 0.051399535469470486, 0.03190569279174651, 0.03966256668190322, 0.04526862957244439, 0.02990658252289699, 0.014330951117670104, 0.04910185392345152, 0.05347374916797685, 0.03513633153371273, 0.06395760495516081, 0.05002715407059558, 0.02796359777060007, 0.02281006301693138, 0.05528533260428137, 0.0531884043988201, 0.04735090251591417, 0.03771562317025758, 0.059534538867733175, 0.09811599077957292, 0.05998173120221304, 0.006989966251797253, 0.013721798219898296, 0.032894846367379355, 0.02310973171505236, 0.026664728253719308, 0.03791350368109923, 0.057733967945340185, 0.009539895653424245, 0.03747722043866112, 0.0353195223086063, 0.044992987306848656, 0.051830341183249994, 0.04301934563104184, 0.033787074498832226, 0.060118435761861266, 0.009048567078406773, 0.03252200286595091, 0.0379347434687999, 0.019803240692483324, 0.04103231656875822, 0.02559177615048905, 0.06842805358070521, 0.05129353954426704, 0.021115242871606064, 0.06080185130779302, 0.02497022028922314, 0.08138440068691008, 0.00880118675394765, 0.03856189368713287, 0.04611153696333209, 0.03997600772568295, 0.08660338233195006, 0.026091964532350822, 0.02626698880997156, 0.04317979125546352, 0.0747495659837319, 0.04790242453436217, 0.03702957611230593, 0.019648619251505985, 0.020401909677011353, 0.03128585871309042, 0.058417069395222974, 0.029970690675620592, 0.030343723783810294, 0.05194818082776281, 0.010847781067563882, 0.018195631996458097, 0.035877517770014467, 0.03464036238109393, 0.05343363680426152, 0.017308735836958213, 0.03161542207723664, 0.09074181228155091, 0.07419205315771603, 0.0885749708921198, 0.022270241076306953, 0.012817818299686957, 0.032196518920001485, 0.013602673462892493, 0.0357719661758071, 0.019443696477420388, 0.08370707202101908, 0.014935662620700898, 0.012408927488591404, 0.018333284589912624, 0.026591074645459175, 0.10444049092550432, 0.024864973214965676, 0.04568678717459402, 0.033791130934391296, 0.028574123880976153, 0.08928558638980312, 0.03156209469682748, 0.013259352117236103, 0.02913323783075377, 0.018005337671286637, 0.05469915659857854, 0.07534460945715828, 0.03251449903473258, 0.035327757753792315, 0.026206984973302292, 0.017051113874561364, 0.037366647138110096, 0.061443940240649454, 0.05753486935469893, 0.04956362108069082, 0.012780542376511281, 0.07752917046027799, 0.05188647627590164, 0.029395165207285075, 0.04167662715659507, 0.0712406458032708, 0.03553558208589112, 0.05293276851936694, 0.032238776329904795, 0.041582084245859616, 0.04696581309901611, 0.05145690396368023, 0.014773011620667194, 0.01897889369678113, 0.0409645714136141, 0.02088008452236893, 0.049380242614255804, 0.05801498048728513, 0.03556624475506044, 0.08587852525975435, 0.03827640719171013, 0.025073502347954822, 0.011808077068698984, 0.031028453170532183, 0.04761008538245674, 0.032123014698886586, 0.031975763023740826, 0.030458204132775148, 0.08474535098479641, 0.055008928081200975, 0.02311708041346602, 0.04520889386654862, 0.034717457639353896, 0.024523219476724346, 0.09515242560976937, 0.023385126917292515, 0.029058331668737437, 0.022893147167539405, 0.03717389941636113, 0.07992144854318711, 0.03291284560316032, 0.03759300696753687, 0.036661873060849406, 0.041443345722772425, 0.0712558756312055, 0.03870405279280197, 0.05692331668650431, 0.012919838228563388, 0.02277324291607065, 0.013947907155529867, 0.0933772007063512, 0.04794363240380922, 0.026905601618871577, 0.08707221281985122, 0.019724931184863372, 0.021995989260293787, 0.05255170489451098, 0.06867747648709244, 0.02205982736702408, 0.0460766033539849, 0.019732858279659864, 0.0231719323088445, 0.047150329206018686, 0.03196627502479861, 0.0471789502508698, 0.10701989364479819, 0.059872636451355876, 0.007430400733175057, 0.04311229890933441, 0.09218286963239794, 0.049988374699868506, 0.10270004641384849, 0.014246631650284175, 0.012868869441351103, 0.018169703750660824, 0.016257555952536005, 0.05365446547887499, 0.01944424423028625, 0.04134231787775794, 0.019439498315595334, 0.0175389816473809, 0.039294231607909166, 0.029802174314916618, 0.00839763749090414, 0.054899274086159085, 0.05145384344242273, 0.031835475087826776, 0.053214941684517174, 0.06205425950728598, 0.03516687545925379, 0.019228251485694802, 0.022442208663109812, 0.03238018849984773, 0.024085936489545053, 0.05432028398518601, 0.07619272241549147, 0.013366544097211334, 0.024226808567501368, 0.09743683085206056, 0.21192394437328463, 0.15677770269253563, 0.09518978771783652, 0.11209145699056888, 0.26735598281506573, 0.12943812375587802, 0.15433460233672974, 0.14263368181643948, 0.12305836568796828, 0.11029784597696797, 0.11228013678543991, 0.173563010870449, 0.17068731598556044, 0.12517514323154766, 0.11809914913629332, 0.13795388051338736, 0.16542924087374442, 0.12303216548095788, 0.11782082173252299, 0.13487955435149132, 0.12308709398512879, 0.10022390468586838, 0.2604828564630401, 0.09499161609358366, 0.1397001626150262, 0.0807793521051926, 0.11155396204201445, 0.27817035574586163, 0.11374148014452189, 0.15345118038596647, 0.10970464111455988, 0.16812845974439578, 0.14313945306404946, 0.11587103603467827, 0.14817343213625495, 0.13533876277506351, 0.13491914577541814, 0.07338586819147871, 0.13292740910283982, 0.17829023301601413, 0.19295831931935203, 0.16822811246158617, 0.10722235536142703, 0.19599538296461108, 0.1831677156470476, 0.21097984825891836, 0.0881486046578615, 0.14720808474286912, 0.19421551556837177, 0.14891872843427045, 0.15528078221025007, 0.22183870025459798, 0.14970099613551172, 0.11297558374222248, 0.11913437907013202, 0.14159126597787106, 0.19725478554685272, 0.1962505821739474, 0.1405018123407518, 0.10608532000333072, 0.18825205733939526, 0.18621251678034184, 0.14602003558989496, 0.15224184931045578, 0.18547878840998297, 0.10536132861048945, 0.09785172875009238, 0.14253183808778563, 0.2031876921894089, 0.1260026331029592, 0.1770190020362216, 0.18809291023400523, 0.07720280934365527, 0.14304907001074285, 0.16372638063565378, 0.15533627761948496, 0.2140797004704514, 0.18041698502436762, 0.18459587207724973, 0.10066519431289166, 0.09972854457314938, 0.13313615274044777, 0.1446171140959186, 0.10452114466217258, 0.15251220173893437, 0.15470103751267159, 0.13856377843166554, 0.21877781127489385, 0.24446277819093198, 0.11900399856629873, 0.2267876895324838, 0.15505090986769046, 0.16667117665131248, 0.1712827348420697, 0.1329810965445734, 0.14120483590710547, 0.0955063658916662, 0.17797396127735415, 0.12509764577712745, 0.14173072462360706, 0.17689477321842026, 0.20071995444595817, 0.24505511737398564, 0.10490255685703409, 0.07302512504881428, 0.14068365097045898, 0.13372303737748054, 0.09327734114542123, 0.16860176418577472, 0.16681048207946364, 0.08009992404690675, 0.12075161366092584, 0.10967340004900772, 0.120932693863588, 0.11661640128060696, 0.16170688093669955, 0.1349878638622261, 0.1654127546616139, 0.26284881176487096, 0.11991273972295946, 0.12951603489777735, 0.1691828112328245, 0.20917100741738276, 0.13174801674341002, 0.1600640819918725, 0.1364270366367794, 0.14946675709178373, 0.23998712399794211, 0.12003683064493442, 0.1450817617437532, 0.18876910540125064, 0.13209635692258037, 0.24388746148155582, 0.08803734570861825, 0.14019473365718318, 0.05657877630343842, 0.17461750025470413, 0.2237193082128802, 0.0887316971596691, 0.15876818298091813, 0.11488630661680815, 0.14050426382210948, 0.19499752279971877, 0.24099803830106414, 0.12006586537726464, 0.1688147213069662, 0.2352415157421943, 0.1335679658598477, 0.0970835111013824, 0.12768113940593698, 0.06762183797095092, 0.12445840669134933, 0.07890580747757228, 0.25619622680448717, 0.14698208880520638, 0.20574000603970022, 0.12079733378824689, 0.10602798598307757, 0.10011202520540646, 0.14489102117236585, 0.16018209017572865, 0.17609629509670122, 0.1071318420731733, 0.14152337526602132, 0.16778810220139642, 0.2975445967768469, 0.135652874145777, 0.10430601185127612, 0.13884140869542477, 0.13391465128910157, 0.1036660526428492, 0.16984138637781146, 0.1336986144944545, 0.12445463753876188, 0.07991990870645932], [0.09630516577031344, 0.02585309257190074, 0.09304758371605028, 0.07675970408825145, 0.0896230174769317, 0.026497962403922316, 0.03446845608132501, 0.051730585044189814, 0.038375335955812086, 0.10931330808107892, 0.022291858162310337, 0.009304159865414184, 0.01815333053649914, 0.03324554609735647, 0.07577276067628015, 0.02233468822293705, 0.03161277524345825, 0.05084774915068861, 0.047333500828714146, 0.03705653091592174, 0.03629628824250352, 0.03989932232446248, 0.08688445999136857, 0.01701864898355017, 0.013673580645944082, 0.01926528609117433, 0.013546105530563624, 0.08472394648819201, 0.04762828380109803, 0.06990022176215727, 0.03993484965195099, 0.09978842200531114, 0.046842384843095664, 0.038811565572095495, 0.061714664221771305, 0.03788292528160157, 0.03920566801342272, 0.030887527466421167, 0.06384039350274591, 0.026450897792294144, 0.05817524225060498, 0.09562101094953476, 0.04881285874533558, 0.05277720287502293, 0.022006126518751827, 0.01401845331964714, 0.06706360502228623, 0.022963885811247656, 0.06607475405138347, 0.07294593454008141, 0.04864836434623407, 0.07159202735150053, 0.08288974813636273, 0.030085088670133587, 0.024918771739448273, 0.0312539798793413, 0.04324230786052443, 0.024041445933342464, 0.04612099814919695, 0.04308333312491736, 0.03810412933929794, 0.04237833688215863, 0.05317333927978912, 0.07887337897573748, 0.05666594944834229, 0.04245744695165946, 0.07993758235487246, 0.018021220589176785, 0.058758687152857744, 0.01589269987532809, 0.03818544191158107, 0.016325211092349023, 0.09698803356337933, 0.03632362225964185, 0.02680634918262161, 0.03847176344284127, 0.028951797566767183, 0.04674883784666177, 0.013840163592249157, 0.031374669370932445, 0.04734627917529114, 0.06685622502118349, 0.08148616014589226, 0.05889722266264501, 0.033622009364227136, 0.05182828040673368, 0.041436810992778315, 0.008838875406992533, 0.12479609824837216, 0.0018865877533361557, 0.02956681486759936, 0.053380903141993674, 0.04011639716824697, 0.06423438486132411, 0.02005430494224833, 0.01463868480641395, 0.014029386351936528, 0.039937584585840666, 0.025951854711879167, 0.02283940418443132, 0.052532261582992734, 0.04852322771424248, 0.0677704896717783, 0.06901676150699777, 0.02617221032719939, 0.06736243293891031, 0.0754063944482515, 0.07075995627430177, 0.04349857576251511, 0.03368713449867022, 0.03231151254787561, 0.029748040626967148, 0.022461037189068816, 0.031685718305168614, 0.013890247547908897, 0.044805303426279176, 0.045268039684742696, 0.01274476032478795, 0.08835546371917571, 0.02236706501383695, 0.04314967633916005, 0.0586271345345003, 0.018079004686085448, 0.04719409963957245, 0.04579982727826123, 0.05959992447207051, 0.04893517234332619, 0.07510580452940158, 0.007096697142603057, 0.04016451898121065, 0.035219160960085934, 0.05112968099814269, 0.06453691681306209, 0.04352861023958653, 0.02956077809475603, 0.07987188265448616, 0.04574130199128582, 0.010727363537185857, 0.05801169780052959, 0.060017660725861795, 0.057889414846055934, 0.025920485326599692, 0.03814087091614643, 0.006397293820496529, 0.0300692881066953, 0.039036205534132264, 0.06190720893022034, 0.04592987070340784, 0.037539610639214516, 0.02761550657000513, 0.057015109341591604, 0.026022384596628048, 0.019689105083084395, 0.05056302874319015, 0.04420267951284205, 0.030151631067236586, 0.005343149654612306, 0.019687323928660443, 0.028199972284417, 0.03215899593347023, 0.0056786525941964604, 0.01546503033398861, 0.03254271405298383, 0.030952964781693397, 0.0401597845578386, 0.03404375608830202, 0.03258119847986006, 0.06689724136864947, 0.09659840124509028, 0.02264165007809718, 0.04787549654382372, 0.06897875588507422, 0.028157839363801385, 0.0093510894540457, 0.005517033418835772, 0.055085521551870534, 0.02414100097432252, 0.00861788681152487, 0.07763325882654998, 0.025088239964398167, 0.032727823878127726, 0.031857484793891354, 0.038765408774657596, 0.04123471699835312, 0.05149879365137989, 0.04101731656720081, 0.07591078673759777, 0.02969399503912897, 0.053628165680434436, 0.028310930544149973, 0.06279457240335404, 0.02936944955088679, 0.033217836697135246, 0.06368827908450077, 0.024160055496219187, 0.022228481623554425, 0.07668368518352509, 0.03230114737826009, 0.08445788415208941, 0.08056531480002789, 0.05959537774023991, 0.04326123023225416, 0.045258264402828874, 0.05664816471718012, 0.020522440205358213, 0.04758057184517384, 0.036712691503306555, 0.07145650639769531, 0.03635850990371358, 0.017418246190514297, 0.02711061057784865, 0.07682796252230484, 0.025581719331263054, 0.07288845496312266, 0.02730926483749382, 0.03671199819373508, 0.0710345221863639, 0.044105018624254776, 0.050112488604481184, 0.07754400192249207, 0.03369271161875898, 0.05506825393005725, 0.028742600022064104, 0.027969362582230282, 0.06107554771006108, 0.05408308401163067, 0.00656856905533782, 0.03314847892691051, 0.005750048637104732, 0.0708878546532604, 0.01656335335405123, 0.010777427383037585, 0.05609511052288356, 0.05787033159586211, 0.03516924650137944, 0.0585000635304999, 0.031229221832848368, 0.10286629515429659, 0.03363659184786581, 0.03142283140351215, 0.04563462424782976, 0.041563288278637395, 0.04556889007348688, 0.03341145392867827, 0.05224530419875538, 0.03558570721877679, 0.0375983466003691, 0.031958949309022676, 0.007596172583890298, 0.011139189422641312, 0.038138875257103674, 0.06672752224990437, 0.021455644464661038, 0.05418196681045717, 0.03043541110180799, 0.04859793660861831, 0.0530699786970452, 0.07826856788127654, 0.02089349872192308, 0.03021505740170758, 0.01964253842860701, 0.03812312448938047, 0.04009291274292816, 0.06438233559170077, 0.07326930791379944, 0.028049686901091088, 0.03794173019066934, 0.026965053872235363, 0.02555656866470893, 0.046039723881310037, 0.062110777643899766, 0.030879376290906823, 0.030014621987638455, 0.03236200540296493, 0.004857364683336909, 0.03927198058414844, 0.04735236191340993, 0.04224727839051236, 0.024126613843104532, 0.044705600913373694, 0.033100334131309105, 0.02078861170899003, 0.021126448822718476, 0.04133415138048511, 0.02377416934787987, 0.043799100563891476, 0.03146113005406674, 0.05015173528884208, 0.012870400659589758, 0.05004526438912557, 0.027305072421328198, 0.022066055661848476, 0.023416149647786252, 0.0381386645829245, 0.09669436141848566, 0.048003758814546375, 0.03793001670630709, 0.020583734900179892, 0.05244629885700922, 0.06588076526719717, 0.05697058431143242, 0.026345447704736746, 0.045249439069941166, 0.07122566878435112, 0.040022022796854864, 0.04564876240047236, 0.03577794166161649, 0.09290409544783254, 0.03986754882780295, 0.08320346880223482, 0.011433161299435363, 0.01800682005142012, 0.04905918665650872, 0.02232267787950414, 0.0910907346875437, 0.0034652390440310086, 0.06889815577456067, 0.03435784064593815, 0.0439940776015001, 0.007823832368763585, 0.05413193743856204, 0.08869149286540286, 0.025706603154239636, 0.01545926743757821, 0.056138034429280996, 0.04159998772065005, 0.039769064394697067, 0.03243315198849286, 0.0511601981106064, 0.04926338739272568, 0.04608483879917091, 0.029449103542813854, 0.012700443095978231, 0.05191214022136504, 0.02018595523681612, 0.04502949905731986, 0.004615040539178036, 0.059570054703902815, 0.030704809750820843, 0.02732183059467183, 0.02589572919532657, 0.041263839830794645, 0.05170404775849274, 0.024329265166494637, 0.05319789622820193, 0.0417680329372806, 0.009746191640114112, 0.04666411618311559, 0.06454087748763061, 0.08288354282417605, 0.023228347023588516, 0.045623845390735135, 0.3056761604403296, 0.1762219335162832, 0.20036992887335442, 0.14781367724701283, 0.16045602789569288, 0.11376447044312955, 0.1972272217033371, 0.1574645771254455, 0.2054262470694319, 0.13228256225345597, 0.21396953702693988, 0.11924002259489029, 0.15070392780246275, 0.11539471320687764, 0.14772761492959915, 0.11387957515375269, 0.18497592829648526, 0.1318830474009437, 0.1936502192890452, 0.14677285487132688, 0.21023058362545508, 0.12911921667475856, 0.19096272156363536, 0.13757328803260482, 0.1597374374227178, 0.13904725652067892, 0.14338339078089885, 0.2173205894688445, 0.22562977827845082, 0.1797117398030335, 0.17953845071456126, 0.16011107382514786, 0.0734518896487932, 0.11220224862617832, 0.17652859851237268, 0.20752496025975675, 0.08544253696116709, 0.12523823057211217, 0.13206525375285458, 0.14199807398742245, 0.16159630380570889, 0.20161066955376059, 0.18199805260425617, 0.18987636292173019, 0.09822523491757532, 0.11180526952469542, 0.1526012671210112, 0.14909186430515783, 0.17634412454020593, 0.19649773746007876, 0.14398121515349036, 0.17672908372215687, 0.14286781360785808, 0.11599240734452203, 0.21195362261947126, 0.11742835488891411, 0.18544151057158748, 0.08254222767127138, 0.13061068261102324, 0.14425637861413343, 0.07963965076111978, 0.11636669492168773, 0.12376265329939705, 0.14190485640879602, 0.14265323238026711, 0.22986351722671142, 0.1401463781874026, 0.14562577610054325, 0.12141575060424306, 0.10544169889462572, 0.21843382247513343, 0.1065456698979101, 0.15129102694411434, 0.11480092611764708, 0.09631918517932778, 0.15807868852730722, 0.09852367212935802, 0.12370020947268895, 0.12082771683532385, 0.14433554614022856, 0.12949668351681004, 0.22619737282155022, 0.1413705100816104, 0.15777421454268117, 0.1230401864215251, 0.13570135218962548, 0.12360051845110233, 0.19178064299687264, 0.2728811008555274, 0.08965566048338529, 0.08904176358614238, 0.21650092135513985, 0.1587713086196492, 0.17293766861961735, 0.09781324815365577, 0.14409333978208805, 0.11948009156772207, 0.12598643800423992, 0.1256777581969096, 0.1245196630817748, 0.13147536605115862, 0.1371659437615064, 0.17768975797920458, 0.16189330077219397, 0.14857814106489384, 0.16076290739640114, 0.1238813739450228, 0.21683852098161177, 0.11040415599822037, 0.16083839770045974, 0.08488013649419432, 0.10574713815003635, 0.1150868377918678, 0.1301530063632996, 0.16645921544442255, 0.13034328728193237, 0.19173676148056987, 0.11150457235353609, 0.1526132027708715, 0.19848437198708135, 0.1957895351393569, 0.16709503777805837, 0.1537161548772166, 0.15101377972431723, 0.11734594681089926, 0.14017924335935425, 0.19518363620004348, 0.22938213821861053, 0.10516965341183449, 0.08112775357139689, 0.11707244576105189, 0.18863661815562557, 0.155762636192864, 0.1939818740732247, 0.08391742444326801, 0.28702565799317054, 0.2350541153141568, 0.06597393688054816, 0.20960838233511295, 0.14481200686385556, 0.19573724197764553, 0.11346625539684489, 0.2710965143576745, 0.09143003502920752, 0.13838293571625987, 0.19436139403091324, 0.16441325506856366, 0.1210425278892921, 0.09436978252544519, 0.18002577456495455, 0.15650439316466933, 0.08826642898061583, 0.08192646918037245, 0.13188110153761604, 0.13848937597245942, 0.14653250244596314, 0.16095920976611877, 0.09872151433580345, 0.11774748413553161, 0.2345538139343262, 0.10018909365058908, 0.1299442167604162, 0.14565297222185522, 0.10458942607886369, 0.08843541265495362, 0.13476090265377877, 0.1516287797881711, 0.21591913886368277, 0.14481977499540777, 0.08923501692592137, 0.08601721781756609, 0.1977427529111024, 0.0864402745519915, 0.13198276140516804, 0.13443062682786297, 0.19994638950353671], [0.08325751630529281, 0.028283885725203062, 0.038931983102473526, 0.006586272868462989, 0.02563725496011396, 0.049282493625557235, 0.08579504465864551, 0.031154702545233795, 0.07899210728224247, 0.012495935924591558, 0.041524275251093416, 0.025476309463321686, 0.07480645567298898, 0.028843715967189883, 0.0003704166186751888, 0.06445479984845846, 0.07703110605718629, 0.04565517455639859, 0.028251683219305934, 0.03598998713817808, 0.01975893016694294, 0.034991667320531224, 0.009941145695085007, 0.01787472734107606, 0.017571149679321437, 0.029033629163619012, 0.028706028899778763, 0.036651021425401976, 0.028926443886913122, 0.026464700781469865, 0.0819087419058046, 0.03645362738039225, 0.03930663074096365, 0.033845902390537724, 0.098050176165998, 0.05662831537906201, 0.005063893369233777, 0.11880182030220186, 0.016401862019612905, 0.0544745740931361, 0.007839995387551046, 0.0410554715762696, 0.03737068059103143, 0.004922881001426328, 0.11162882415397514, 0.025218637705209757, 0.031319842373411504, 0.034599621825280695, 0.026340286187346906, 0.017322150036512364, 0.04392000839054104, 0.06637547420518053, 0.041272094428178766, 0.022275121056384618, 0.052432382869864666, 0.03378100708247193, 0.07131956818123018, 0.04101578056091263, 0.0399596747311373, 0.006779892015225825, 0.079257725287349, 0.041044217744661916, 0.038336093101890824, 0.045776852301412055, 0.033030447760416616, 0.09228187883573194, 0.04019263057759212, 0.018059298989453146, 0.012108034965011382, 0.0521986685963648, 0.09261403923794147, 0.05304598099281711, 0.06966352357619232, 0.03562477387247547, 0.060604327027836156, 0.012813015886011624, 0.030576809865212252, 0.045458152064032135, 0.04445120609635788, 0.09199828074704255, 0.019242895256367423, 0.015354852526328497, 0.039670116478397, 0.02149009352339612, 0.054934234508583625, 0.017342129609577598, 0.006136531855220036, 0.035552585407370524, 0.020190065298529885, 0.041434903433846856, 0.06182137643918396, 0.02490380238140783, 0.027767195809452284, 0.04125980254743369, 0.031536559071091395, 0.09842804137377009, 0.019268321714574294, 0.019698365170869137, 0.021027950983073924, 0.05839446597101708, 0.022931039791494127, 0.03710061927596408, 0.059756987818306496, 0.04089656578857572, 0.09881137644932156, 0.012393423784223777, 0.038065212072744485, 0.009015039240400638, 0.04620784570673301, 0.029189811508742072, 0.052705232744976405, 0.03036141275398193, 0.02324084191763353, 0.04588239240430055, 0.0021260723447231876, 0.07297434874119298, 0.035897596934509855, 0.02966801125195719, 0.005915791759522813, 0.04412520887149919, 0.09313590599284058, 0.0464341557404447, 0.03139415673250633, 0.013936699289197644, 0.03122122962057831, 0.058471070933005506, 0.05749717782882433, 0.03662649129006652, 0.030814350747893897, 0.042609419643638596, 0.05432718643738378, 0.048372499915140296, 0.0038804105790932815, 0.037681670153453466, 0.11655161322485055, 0.05220759735112229, 0.049339364162616195, 0.059204228567860784, 0.04253640763401505, 0.023669485348246755, 0.03137644861013659, 0.03774539717743474, 0.01086441953966935, 0.018376323409498702, 0.047030229602129235, 0.02509360641030775, 0.03383295167417776, 0.09274046672808547, 0.05045468475849879, 0.05882177066298262, 0.043776589070236495, 0.037184004116082386, 0.010700740066597299, 0.06901138356976932, 0.09011660026566637, 0.03169053699821234, 0.09227214185821433, 0.03137430164872879, 0.013645265078652772, 0.050080389520453836, 0.0306617058137612, 0.033091600728972305, 0.03168229197692727, 0.07530340158771123, 0.04621289422615402, 0.03608418147890799, 0.022348401196781668, 0.056701438471434586, 0.004714050221316998, 0.03903271600363716, 0.03280859635842424, 0.06789365362736487, 0.01851487998670388, 0.026230402365927736, 0.03344503156239948, 0.012984092895602508, 0.07141375869152046, 0.029481419046679815, 0.06436918186204088, 0.030585646689418825, 0.06936422834593443, 0.047149716335679256, 0.0395200475149097, 0.035840059900956775, 0.022526284897579782, 0.0441517346658774, 0.09147704218424137, 0.007251258254156358, 0.01998449326492846, 0.02352716919455317, 0.02599359884287321, 0.059483980895170284, 0.08208020004413782, 0.00774206780460513, 0.00012071980592971217, 0.02043888491067675, 0.09219357954157938, 0.03696276941486905, 0.008364594203510113, 0.06580758088779065, 0.020439509272335038, 0.029801574851115866, 0.01693228406140641, 0.02932759816758335, 0.03387380331274002, 0.033081465385734074, 0.016915478007567507, 0.0015850149676196218, 0.01738132075256398, 0.021071740568825797, 0.023224489770889766, 0.02218329584256055, 0.04346000323552759, 0.07344586053682912, 0.02661288516866344, 0.08481361707972904, 0.029575879602963408, 0.050893151351521095, 0.07486573555656979, 0.03616709517495286, 0.04370534672371803, 0.04187857176387503, 0.04072737527049838, 0.02192345030996348, 0.06094607118997843, 0.020076904536014604, 0.05378175864837343, 0.017681108194313223, 0.03344529969317298, 0.04694330160536113, 0.05969943546299493, 0.06509393168192718, 0.01557541019733875, 0.01071944984892804, 0.014777476955655844, 0.065131125250651, 0.10945485814684823, 0.02645230164841539, 0.0036441667790284324, 0.10577622650852127, 0.03548137753480866, 0.02091617683970159, 0.02872120510155876, 0.0682198538655235, 0.06448682998457263, 0.11243610462594418, 0.010501851192525318, 0.04349392943925435, 0.05710050133207152, 0.05692650361226932, 0.03185593921150411, 0.047949891342150594, 0.08773116334792107, 0.045658361482163595, 0.09118830364558006, 0.1179642333919483, 0.009665195079099749, 0.018628377827905843, 0.011465424134756529, 0.0038666803682703647, 0.04088020215051309, 0.05796043502707636, 0.010902369620218393, 0.032770636701776136, 0.032732968158539266, 0.05851840367540718, 0.05949090633000578, 0.07650877198865337, 0.022215816274946256, 0.06441743774039131, 0.026619100056949164, 0.1313689104732006, 0.03873823563598337, 0.03031781852065075, 0.02231060624903729, 0.0359132825847595, 0.020352523818972613, 0.10462070544881207, 0.03618923511596457, 0.03986874775540444, 0.07243345236225475, 0.011519521433529595, 0.05294981014524257, 0.0535491781850015, 0.017388656044438962, 0.014640550230509572, 0.01938251669578735, 0.10529990368072065, 0.011318476021950765, 0.05114435924277191, 0.04118916157993578, 0.09716508414355979, 0.05911718948834366, 0.0178755393942758, 0.007424007729446937, 0.01883623471874143, 0.10679768984236064, 0.011548839618391808, 0.02263599443399618, 0.010917316953231011, 0.050175878549775774, 0.03423044022413031, 0.01815695987804042, 0.00840991692272045, 0.07762486250289986, 0.09835091930243278, 0.11448096949607135, 0.025816758936871926, 0.03578436147842196, 0.05902437027543784, 0.058374233588936834, 0.007254878977208489, 0.03304223019269205, 0.018205759678817084, 0.04393025481652829, 0.057397862190320614, 0.08025851956899129, 0.055641912059077335, 0.013696278873530608, 0.0392935038243811, 0.03434133911204915, 0.019044179709688313, 0.01994548215260429, 0.025195034536262675, 0.06971135044530516, 0.03221680109779681, 0.05179255772682448, 0.0564242487082318, 0.028849122632715492, 0.02170669147744775, 0.08235631345380699, 0.030788719361167283, 0.04061037066182302, 0.11702869447969622, 0.04537651390438119, 0.007860764988788195, 0.0649100935627376, 0.034756160401288545, 0.1199646115363125, 0.05435006948368204, 0.04038522508175623, 0.023415774264703357, 0.032693200534389864, 0.08390351994744233, 0.03326526520052745, 0.02135305954594045, 0.0223089610752199, 0.032288288592451045, 0.012225961752025592, 0.02237943350337446, 0.042323944639534726, 0.0351701696373282, 0.18539067297693224, 0.10501788373315528, 0.16449727959209876, 0.10319225024431945, 0.14859185403873845, 0.12942949760585062, 0.17126493095870943, 0.22831071829122884, 0.12246470117280561, 0.12512206099927425, 0.1440042590782527, 0.1118630402150654, 0.18381522848240792, 0.07905992138529978, 0.1590837805622047, 0.1826356522618763, 0.19663506638138525, 0.09604334756131135, 0.12986324126681975, 0.1545447096108429, 0.12543087104155173, 0.12527189247550505, 0.12633200494512437, 0.12412867478785977, 0.17334119777285284, 0.11484521366054974, 0.10949677847806485, 0.13125704631449717, 0.11394363542598103, 0.17317333258688453, 0.08643958507285965, 0.12408942044261964, 0.09242254790038833, 0.10589340731741921, 0.17770517166824112, 0.11018972798821428, 0.10926373453149874, 0.1945542643267301, 0.1619197614490986, 0.21551957804589503, 0.18128128542054087, 0.11504555331362833, 0.2518473601629657, 0.07829772518767465, 0.18753925849112774, 0.09748122564727262, 0.11337784885038292, 0.18653654132879552, 0.141133482477838, 0.19519816122708783, 0.10552876478722019, 0.10957005478802229, 0.13601811422455695, 0.1477028549678864, 0.11447528512367319, 0.10477239851869884, 0.13690555047604347, 0.1342902488766178, 0.18469734808369992, 0.15431555739093214, 0.19085784412680135, 0.11019713605844206, 0.08750804790085362, 0.17659284264570282, 0.1432177625716694, 0.25300193127364884, 0.11603926894285026, 0.16230553268424927, 0.10514117792368897, 0.27672422689295584, 0.12382538057863714, 0.15761528194190996, 0.18417613250353645, 0.14373640409640728, 0.14898799810438387, 0.13517953906088107, 0.09298600556869661, 0.18261057054323537, 0.1957418385051912, 0.2284181851052469, 0.10483935460328095, 0.22390874643479625, 0.10537243688539152, 0.148712620139122, 0.20599249329778457, 0.19904763047252932, 0.09021617637406434, 0.06538850014969226, 0.17253594743388315, 0.1638683980150569, 0.18476053501569456, 0.23528912044580907, 0.13573395689168286, 0.10500499047338964, 0.10957361709687019, 0.2162674943646116, 0.32858157650597636, 0.13095692370928105, 0.17127001778252665, 0.17702644841084558, 0.0696089321507081, 0.17341966049805765, 0.20953836189883374, 0.195764422777199, 0.24891851409789056, 0.12167690997763027, 0.14680034210605009, 0.16843973658978942, 0.16758740248699344, 0.1602315488121202, 0.13147760302789752, 0.1321019646861861, 0.2081678765675714, 0.2271892881441501, 0.11619631696732775, 0.16518734095077361, 0.1378690745801695, 0.17621220419964484, 0.10077780923776089, 0.07486026568879044, 0.24619861085328365, 0.1516632843882807, 0.1795323373329255, 0.12254854183523886, 0.10948789951902245, 0.13360493726307346, 0.13359168394198342, 0.10365669870929373, 0.21140916393168513, 0.16550280063623385, 0.253588448188478, 0.11965483622325045, 0.10507502623142735, 0.17723159143520942, 0.2918677626838607, 0.13866859458146558, 0.13281704647646797, 0.15234658885146343, 0.13804950360809604, 0.10805544533556509, 0.11857007870510702, 0.10359980135915742, 0.11434593117765843, 0.17331000267257615, 0.19415645018940975, 0.1420053824662201, 0.11165173018291114, 0.22173791372727966, 0.17493812337277398, 0.09023593378163154, 0.14352114871144295, 0.18487881899120348, 0.12735397389699377, 0.15585456674377765, 0.2314185531389329, 0.13252210262562, 0.1702390932628224, 0.14064078069021627, 0.11517433269369988, 0.15404837656646006, 0.1394014342898323, 0.11791662102745426, 0.2759408866686206, 0.2104160228684064, 0.14779735957422566, 0.17343597817084483, 0.16453431228235846, 0.21717244338604713, 0.19591774761436448, 0.09227977975481942, 0.19402911105463583, 0.19035233334908563, 0.2011148114838908, 0.17873197463491272, 0.13346368597159464, 0.05148096678538188], [0.07830292692468052, 0.03321518986335686, 0.06912392188584612, 0.0031677153920980114, 0.028785018310431513, 0.01124043943315384, 0.021319073970399557, 0.06385845402556081, 0.041479229281145724, 0.020414174744679082, 0.014502546194219782, 0.057728287403381644, 0.0482356229857091, 0.057315955899896166, 0.02758288654618927, 0.035755020310922016, 0.04325526623776363, 0.014083563132331738, 0.10182578687465961, 0.02779273909606761, 0.0368640934597821, 0.05790557164037901, 0.015838783564827135, 0.019495775134512977, 0.03769797633492178, 0.037602805232088414, 0.02937556484774236, 0.05041540743062093, 0.12592636138921784, 0.03454394255494399, 0.058235261409032735, 0.04791763904053838, 0.018452349975104296, 0.12000429489079023, 0.012684465374707455, 0.022620678421170003, 0.044664507957115296, 0.04234887314059081, 0.030728598696089564, 0.007634356321256248, 0.045587502179607275, 0.05990190867094263, 0.06356246829513582, 0.028920041307085947, 0.04384003264168578, 0.014525259743564794, 0.03994876946953516, 0.03016441898991264, 0.02108354215329934, 0.013228155101739593, 0.07006299246342913, 0.09341540551113506, 0.04634769888775003, 0.08407496276401705, 0.020954753197128737, 0.03751478172958859, 0.03570766458588262, 0.04048069878931969, 0.04060862398135566, 0.018094799503864303, 0.05830293378582405, 0.020302716612575517, 0.018051032900750157, 0.08096729645565634, 0.0835675674100076, 0.04434765016119327, 0.04814752287441685, 0.01219264746102835, 0.035637330053554434, 0.06604594914543052, 0.04053651978592238, 0.047760089228470484, 0.029435942152274713, 0.07378187436129778, 0.02044418432389296, 0.022777004407778866, 0.08028038371835025, 0.01618748189010207, 0.02032930752442729, 0.05990672736398636, 0.05298221949487925, 0.0504929508503166, 0.027017858397636204, 0.08040328720404256, 0.02781191810725197, 0.0588989923257501, 0.043032093334101865, 0.0413959670150953, 0.046386141179790424, 0.028795642034721472, 0.05100009722575065, 0.1198708117308636, 0.025611947245535352, 0.033482730749153325, 0.042754555000893535, 0.046841193576373404, 0.015315587647379407, 0.023874704981403008, 0.07163588588516559, 0.021231954451650385, 0.023733731396796725, 0.10544696957954477, 0.030990221552670966, 0.031387045521349195, 0.01970664658133061, 0.023558096164056373, 0.006686153018005914, 0.03533303226915098, 0.06287636378058983, 0.029848848221703406, 0.0977800535638967, 0.022014595620754748, 0.0496385712927628, 0.05144600636295734, 0.02862877659349432, 0.029158152925271182, 0.08352102756860756, 0.12398183871541293, 0.016912281505703446, 0.04303763598023404, 0.008406864062342192, 0.026283049843304103, 0.05314727313816548, 0.031060745691760417, 0.041606058967449976, 0.04577276905277564, 0.07252752029847714, 0.05416015628725291, 0.02493911711949735, 0.0449316083423553, 0.06138919559758037, 0.043735159035291404, 0.048880561765643864, 0.025299797059908032, 0.019380465495370088, 0.013978008665294658, 0.035201468159474676, 0.05630295783762009, 0.049259342448485476, 0.06320582755330591, 0.002784026958491473, 0.04710341781197537, 0.017882415033396215, 0.0633081654086709, 0.07525762783423548, 0.04912356485522563, 0.03573279610023864, 0.07169889661693765, 0.004316952855010788, 0.02293232490398711, 0.047231339173571724, 0.07063646290090776, 0.013516155323163878, 0.06347291261678742, 0.06359937458088802, 0.01922816338558351, 0.10066062842886295, 0.032362637425502466, 0.08096191085754864, 0.037073982398836844, 0.023306135591419957, 0.08842764452340142, 0.05238520334504786, 0.03679402705822741, 0.023748727567914515, 0.027248571521692702, 0.036368947851681904, 0.019319220596263488, 0.0950195629810614, 0.01923400480600615, 0.01057837475767179, 0.03338163778666527, 0.07408848573123256, 0.02448113635182381, 0.04699820329645469, 0.03710259961324834, 0.06345261511723362, 0.10414257465351014, 0.03949631411101549, 0.060450040750325694, 0.024865731642010714, 0.0500415833366494, 0.056126558432175275, 0.06923591627949668, 0.027703683290089813, 0.02431392425581092, 0.02144748562826745, 0.0822617628821923, 0.059231980102917844, 0.03480423241853714, 0.056355986443738786, 0.029295592929326722, 0.10724306271802034, 0.027728261305920543, 0.06660142417756781, 0.05414885649036977, 0.06234577128423318, 0.034189217032924775, 0.014777611021042593, 0.046979154520217455, 0.01820481547545041, 0.021011644801605615, 0.04881950455807871, 0.05584263092567844, 0.03743961701289781, 0.009039613425791746, 0.08698966684601, 0.04285862421496742, 0.04053591074602258, 0.07038553846218894, 0.03177546167505845, 0.10383865225218958, 0.04353597234453886, 0.05872872545413914, 0.026156712368491198, 0.045992168973410325, 0.04351877750107839, 0.009667612086500852, 0.014269116330861807, 0.04192704214684425, 0.01655204781150866, 0.039005389647378076, 0.06227709533226106, 0.07204068674435539, 0.0391901815460334, 0.026940606091351762, 0.050546894931504806, 0.01351816917679483, 0.03371584364363263, 0.05354885259763368, 0.15599105296836746, 0.09582192516855656, 0.05846369733673431, 0.049300331982874104, 0.03946028499593658, 0.07306294680963601, 0.033413250404860706, 0.06386166010352393, 0.023098954773177544, 0.04596860793929908, 0.02507204678089869, 0.056606960678172696, 0.02888002853480078, 0.031240686338635224, 0.05442705365919298, 0.04548512218940643, 0.01734985752151378, 0.015977375573598813, 0.03645299535785471, 0.025687200062337424, 0.14740264043211937, 0.02309539246432964, 0.08684224088586147, 0.04071801750650329, 0.030116716610087507, 0.03279003787845854, 0.03183219048585142, 0.04306629915992099, 0.019477274111141602, 0.08231230170255707, 0.024602095889408263, 0.08294814701883063, 0.045480295835483464, 0.032225611108926036, 0.05763132748524508, 0.08621544306797367, 0.05995980959625975, 0.07059963705438761, 0.06935755572011394, 0.06617586999650925, 0.07720834049846857, 0.0793619592103266, 0.04170148670973797, 0.07047903949334737, 0.048757593162477984, 0.02752542803664842, 0.0330764590011489, 0.06121541621283658, 0.05892404723131369, 0.02463024962062557, 0.0243640685408947, 0.039497712221477306, 0.02084307672996675, 0.024168758255039013, 0.016358646999804244, 0.12172898097384362, 0.04772754964388667, 0.035320204126858906, 0.02607330263051535, 0.06420636902593317, 0.050337224327508485, 0.09162226947204721, 0.08011667072893151, 0.02226812858885575, 0.00927127841409416, 0.05355763962612518, 0.029590778097870852, 0.026898906010413365, 0.06312295599209686, 0.03051400789239955, 0.06471530804711004, 0.028283560137835242, 0.061763452531229106, 0.04074283109437074, 0.041131291298135635, 0.049239094744646744, 0.01985299618794553, 0.014221925314726129, 0.0073830670331634825, 0.0172486343240786, 0.023142801815523736, 0.019536364387961167, 0.040848964915400555, 0.042448970188777295, 0.03873928900687926, 0.07078296955554716, 0.0384933173265909, 0.06771380682626078, 0.04929450205377033, 0.03221182535672861, 0.028808705749050267, 0.019742549291902015, 0.06783405198685585, 0.05372465445449757, 0.03106859617776448, 0.06975514769193626, 0.05283988418898756, 0.030011764479680892, 0.024931768421083692, 0.01132325545298837, 0.035657727144538395, 0.025833733530054172, 0.10128348089394071, 0.06151203396579912, 0.061194513503822594, 0.0868777567220311, 0.032817222508451635, 0.06809608470047675, 0.05226256415968942, 0.06284351776083631, 0.003818923883485578, 0.06397330209672933, 0.008878228386052915, 0.038909253273760123, 0.07098358500027849, 0.013956002789669701, 0.033445173288665475, 0.007866521660734208, 0.06334746188874688, 0.06206257539170404, 0.06973827843584361, 0.06141464886886459, 0.19201734884371682, 0.18615361994072316, 0.1323359739035368, 0.1432401016955414, 0.10555740881470904, 0.0758094945922494, 0.13038945174024952, 0.1591560839404983, 0.10492073612347727, 0.07145118208662157, 0.13021253139501618, 0.17430136641187055, 0.11638358716041812, 0.14510935623078577, 0.14135554072356996, 0.10294897902396419, 0.151051823650637, 0.12475779385215814, 0.15705059853292283, 0.1639804153913452, 0.12653579965474146, 0.13448751651712004, 0.09933220898552288, 0.12643659892942638, 0.13401514670300868, 0.09827057200093424, 0.12958099915375634, 0.1283653938181458, 0.21189350003917373, 0.12137946101926989, 0.21293629892170432, 0.10380718136026014, 0.14140499935996148, 0.12986992155351948, 0.08361242951885348, 0.1321647685742186, 0.13304403832843228, 0.1398637070651016, 0.12103475209686065, 0.11776934828489058, 0.16052839256102042, 0.12503015343099833, 0.1965381256154468, 0.09697953764829906, 0.2154167843682151, 0.13622797635053435, 0.14187583699822426, 0.23572326247249883, 0.10720170163098844, 0.10739266436787383, 0.1765861776807616, 0.14443061765163176, 0.09705260711451692, 0.1925636921077967, 0.22872820556644471, 0.19566110815973053, 0.12989963044322309, 0.14563598039169467, 0.13758603573566483, 0.11170308871735489, 0.17150759696960452, 0.1548862622510041, 0.13320344590371655, 0.13700839011899887, 0.16217963379477301, 0.19177725688824732, 0.12613236243205686, 0.22819002879963768, 0.16662381709583346, 0.15734813176095486, 0.15775028195592666, 0.18577693450835445, 0.11174808872202713, 0.16052876028322405, 0.2581539491732275, 0.09776699942566695, 0.15348061348401731, 0.12356157820191115, 0.0635147142043758, 0.11492577546666707, 0.1254552249766646, 0.16244532840867199, 0.06979315331385982, 0.14845101643473874, 0.12757055461406708, 0.162121640938905, 0.1569756598121697, 0.11639507847928232, 0.12529372598134703, 0.202096262045445, 0.2068964004396431, 0.24747436175182944, 0.135702378747444, 0.12646751823805033, 0.13477840010196934, 0.17608091205118165, 0.1303498756380812, 0.21809427698533382, 0.17121879714390925, 0.08067797569017257, 0.13121276643247376, 0.20241501590897962, 0.1006543388470046, 0.13703227674047794, 0.07136018616297553, 0.15620745748521822, 0.1441439628721245, 0.15085403507034625, 0.10811061898787176, 0.17710550868463132, 0.10505138475808407, 0.07604932607782465, 0.13251831815127404, 0.299163953431191, 0.09031013705797734, 0.10450645109578487, 0.16966613610425305, 0.2086136937742272, 0.06802494577582806, 0.1315186193753635, 0.07309882270713007, 0.10587525103361377, 0.1362148149599952, 0.1065386372107652, 0.13359514665940117, 0.21322656963621417, 0.12462686942589861, 0.12388208640679238, 0.22787829230148948, 0.2081792912776432, 0.13131199014042655, 0.1397399991870888, 0.10656224804059153, 0.17325173402505537, 0.2089552464143884, 0.1564133972410233, 0.18685881919678182, 0.1364236198846371, 0.16110542530734695, 0.19869714524717103, 0.07097675915687315, 0.1417176858071358, 0.17003782664335546, 0.1281165454777018, 0.11156199064346091, 0.13217494222185305, 0.13420075448530336, 0.2355604994321062, 0.08404033558983957, 0.17810289387501058, 0.2241449619853689, 0.09270214701011296, 0.08644203655421735, 0.18986980520909835, 0.1775151358977441, 0.1616534692866187, 0.2171697007912782, 0.2339339262295154, 0.14380355936384973, 0.13377638774052744, 0.1388373331076676, 0.28728520858191675, 0.14110418727561352, 0.11897708589751875, 0.1092352360607155, 0.16135757548674462, 0.17115467558464698, 0.11913418754815094, 0.21409065552776863, 0.08338805002671096, 0.14079425874496662, 0.17332768398186854, 0.18357440108253112, 0.13384282288532104, 0.18811463648753782, 0.12555966574338176]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.05284892785693369, 0.026413047303175254, 0.05959823141775786, 0.026241478082093022, 0.031202912458308765, 0.07048600323257909, 0.05389188761792837, 0.013191027608099244, 0.014881859308168774, 0.034541854965350324, 0.021123464910253402, 0.0737243564799428, 0.05988839871039795, 0.06964876106189144, 0.07651805697429566, 0.028240496420391628, 0.03964367112325084, 0.028298332228235183, 0.047054464793613845, 0.060006062154688185, 0.04858574814974301, 0.06486001439512738, 0.0642891486565913, 0.05536210610561314, 0.027090144538951498, 0.00541572547292397, 0.1045202560001804, 0.08296470217887433, 0.026561978626095002, 0.024833017772424127, 0.06745786451163792, 0.019006193239962863, 0.01823507977889911, 0.0340225967398334, 0.04157883986350029, 0.07069541336668116, 0.04370489090140309, 0.023007156372430827, 0.007742187984648251, 0.02504550183432237, 0.18586060663144435, 0.038098988889326016, 0.12293566138513627, 0.020343782755756573, 0.006343586268954941, 0.013477738886590929, 0.007981702980149778, 0.028884665281962485, 0.04679964479780005, 0.030830275800619877, 0.04993111728840778, 0.060551221812925035, 0.0493077055791453, 0.07112109012180759, 0.023414381899900978, 0.021036667148432425, 0.03774990560486913, 0.04546075293253507, 0.02610386570825452, 0.01437485753183043, 0.1529404142450902, 0.023928729501823266, 0.06498990460268914, 0.037277497486361576, 0.1267857435009172, 0.023354142491194992, 0.046178845448359374, 0.04874044811473258, 0.04480444540780398, 0.04523895898713701, 0.03178783399503558, 0.04831740670206566, 0.017112686276255597, 0.03696304903696141, 0.03424800278979444, 0.029601003456440185, 0.022798994961645336, 0.04988843086926688, 0.04475633125571955, 0.06384040499406476, 0.08882242495254164, 0.0323657937077505, 0.10613500846609955, 0.06494031573135046, 0.06591598232907635, 0.0467154287522839, 0.04943527454029649, 0.0427359888600486, 0.15096361628703533, 0.03535096638745839, 0.05990394646482122, 0.02669753596907662, 0.042827501893043525, 0.034720165760166226, 0.04267868548331242, 0.06464842091044111, 0.036891117211311095, 0.01802803685648307, 0.019040967886065765, 0.011908714208872089, 0.044589174701081175, 0.01435183467448599, 0.03806638801770826, 0.031497417723820094, 0.01603005752493177, 0.013479525786674312, 0.02685111936091656, 0.02757466833798155, 0.028838259505949197, 0.0374966177849039, 0.029384213980407487, 0.022068512888865608, 0.05186313740728844, 0.06725447582862071, 0.04736684863605807, 0.06814150605350733, 0.009047052139536509, 0.03627805534990565, 0.028947949890167485, 0.01070058110335301, 0.06505219521181238, 0.007366073287783131, 0.01887657690883404, 0.051479189461397554, 0.026633228633492708, 0.05733908026389057, 0.0499677554433865, 0.0308731077764664, 0.021511978740173004, 0.0154498876485553, 0.016734265654738394, 0.0637277287821616, 0.026907532160440763, 0.016860972766974763, 0.10847448010838802, 0.04464257102940352, 0.05278490205866195, 0.0230055590791087, 0.036991076363671216, 0.009492259348682579, 0.013646986861262592, 0.036128733322144516, 0.03259213055453954, 0.06414164225721071, 0.019173545147021933, 0.013855939257829903, 0.03855827775213026, 0.020238363311716148, 0.0643351292538066, 0.05067314239098661, 0.01825987996022788, 0.056731852162028515, 0.021329559798863147, 0.07183353656962996, 0.054671703837811954, 0.07081319172416004, 0.022519505019449902, 0.052382326684892185, 0.05664675511539944, 0.03177493690483032, 0.042262400966137655, 0.1410351167883604, 0.06718465457520179, 0.049614060309625445, 0.04087137298718576, 0.07363598823787705, 0.0620626941353323, 0.013636712664588085, 0.032479358581645836, 0.0274217629339546, 0.02775453620650355, 0.06656546401040209, 0.07386722421694188, 0.07933983459107338, 0.07757782470434904, 0.05901783554544372, 0.026912188059800578, 0.03175020758663455, 0.02653682412910125, 0.05131584802462209, 0.036591714728743806, 0.052211025594583446, 0.08753956475805852, 0.019795083771309546, 0.043717726704574404, 0.01556393420023303, 0.02930834254760656, 0.019892399920330896, 0.0305674406098983, 0.02238336736486564, 0.030338497148946892, 0.04110985232757465, 0.03217940834621268, 0.03688135342071614, 0.0015218410830599286, 0.045337018241444905, 0.022052620394876408, 0.0990684066087969, 0.024476076341083935, 0.04354629920975816, 0.03395127012364326, 0.035000101948577556, 0.06554742508958425, 0.01839786963236909, 0.030453825940287886, 0.060498672011759014, 0.07807618788173122, 0.03152459660815376, 0.018657230614354054, 0.0955815191170381, 0.010540429465172273, 0.049016952229243134, 0.03348995495827929, 0.05150790626723921, 0.039652285781959375, 0.018590286021090804, 0.06286906679311106, 0.10356588664674952, 0.05957243340690771, 0.018724780417077484, 0.008387778896928556, 0.0409352915331481, 0.007375014970274343, 0.008248126813991657, 0.009434021344678778, 0.0666150758643785, 0.01712676697230387, 0.05107182220766141, 0.07807156071066856, 0.02517961510156672, 0.07296806682021388, 0.007038079925076737, 0.028881869061038862, 0.03284551413549531, 0.022065728159260847, 0.02048905792405769, 0.10412183665339986, 0.05286101289393921, 0.06606405180308127, 0.0290517567191273, 0.06586563503069263, 0.033416008321388115, 0.04203398036019456, 0.03315968296280311, 0.05485506698248848, 0.04522471358218501, 0.04721918135821339, 0.0061777382882522245, 0.008234568015341798, 0.06198477916299336, 0.009531544337439682, 0.020879691902307734, 0.028852935835358598, 0.03739716042013418, 0.0660701422020793, 0.11571764224959959, 0.03805928638265018, 0.06010024883453885, 0.007641824242103124, 0.05923331692634572, 0.10774219964420605, 0.03291331674723375, 0.01744881309869309, 0.09312081406073225, 0.02581854200651569, 0.017868238576357404, 0.014681872055535356, 0.034781628994331244, 0.01030936106784089, 0.07554254359415463, 0.03559630221476959, 0.01401068231526522, 0.08013362425469583, 0.0521685651713802, 0.05717480036940786, 0.05334732550827246, 0.03318887474315782, 0.014831924739654266, 0.047649619349789236, 0.0635096503631963, 0.03207767761552767, 0.026730571595591404, 0.0221585703548044, 0.01833057263866067, 0.09900840660256725, 0.04514763747612315, 0.03908004108515959, 0.08358593819843185, 0.055669613798419317, 0.035973485604289084, 0.09060352575033905, 0.05906853141383298, 0.01541482859231051, 0.02299626068692775, 0.023488962474549492, 0.009502021224057723, 0.002218870250808616, 0.002246406802441925, 0.05350897772117488, 0.025425215229211796, 0.011370007883787397, 0.0321875556912874, 0.03897866083969993, 0.04029213007719767, 0.10782098412633905, 0.04825718069989835, 0.0878191332242662, 0.01676851170017354, 0.06358777984015404, 0.011560146118544284, 0.05374538096328897, 0.041855707869774876, 0.047177234213919415, 0.03237547705911341, 0.026714809336549333, 0.044880452821211475, 0.02967768694244085, 0.00557349888690477, 0.028156715129772504, 0.02643136063500518, 0.04726621149588497, 0.062114477848574046, 0.05220827533893528, 0.01859376597548685, 0.0412446454978518, 0.06904749695451991, 0.14094718521641147, 0.005964771590961685, 0.0910160870802018, 0.07993585099616358, 0.030245915423297597, 0.0429078913293779, 0.04803889160675388, 0.0067785982842436966, 0.0858184333229738, 0.02314889221452177, 0.044544607536086155, 0.05899743079358052, 0.049296405782262166, 0.04706730059678516, 0.0316663324502447, 0.038326141619754416, 0.04392606048514286, 0.028505185543889963, 0.01359195780805162, 0.027074213740566087, 0.0314526935108006, 0.02715439058750147, 0.046575920310832804, 0.04191183913198691, 0.04008805574548822, 0.046917733420888265, 0.1658235310066131, 0.11512065291284554, 0.11908633003552115, 0.1355860099917458, 0.13462378823709104, 0.2730803143593573, 0.1641448791469297, 0.1412299329475049, 0.23363864529998074, 0.10165935427310968, 0.12410908591963592, 0.19235491782667177, 0.15767883659610826, 0.1029773855641965, 0.1470794739021409, 0.0965203905117608, 0.1344640129396031, 0.061873849631557544, 0.10740261585001024, 0.20205231924210826, 0.1406640391195974, 0.17004518108742853, 0.20674295302840973, 0.13787488152663555, 0.12839006184930765, 0.17801275596983973, 0.2755453401515561, 0.2179392667547349, 0.17720444127917293, 0.13721531046734703, 0.34052065844016693, 0.15158241614699364, 0.10982979689874958, 0.2333779302575896, 0.2257043339552418, 0.12808433914136502, 0.11828020635631778, 0.10503875962909191, 0.1594577233998045, 0.1366693808907463, 0.34421072011032416, 0.156663907992263, 0.1608102363083632, 0.1801668113518146, 0.07656741601925704, 0.12448293682668479, 0.10535122391076819, 0.12067809986371188, 0.1570708385758823, 0.16667249432254225, 0.17432231125572037, 0.20789113496580433, 0.16944816876803676, 0.13794091830570854, 0.11896423094214932, 0.08597490678150808, 0.14527066370412228, 0.13243771037988125, 0.09089721321699121, 0.1264559656321522, 0.3409112407074821, 0.1880567662057377, 0.21282561453840426, 0.16621517047526377, 0.18966902888590292, 0.10433275598071276, 0.13936259363207126, 0.13913665898144245, 0.1714766163739466, 0.09903669822961093, 0.16431574739756125, 0.13250506483018398, 0.14636765564641646, 0.12653544725429627, 0.1452606432740727, 0.15920915851189246, 0.0825675392162896, 0.1444114348100078, 0.1403052341793814, 0.17749569258622586, 0.11533301248545609, 0.20555966894232458, 0.19104024966157254, 0.20855390827261633, 0.15381632853419552, 0.11199257036130275, 0.12364529629027653, 0.1730331231749827, 0.2652217537885712, 0.17327243372076945, 0.12538731894305638, 0.09242909795214092, 0.17522416528194182, 0.09719055656704212, 0.10863790198439553, 0.21280188113451007, 0.14775697141885757, 0.11208570367025752, 0.15537266679588826, 0.1591959205125609, 0.19866326883915933, 0.13549607126943528, 0.10616396658963735, 0.13887039746247953, 0.11320542544126512, 0.11741145498930447, 0.10477209974440838, 0.11283969506621362, 0.2112925959931266, 0.1976563994802775, 0.08922027739425821, 0.15229555207394785, 0.13231666848784493, 0.10609436750171647, 0.19294393218813405, 0.11248914089294211, 0.12552405031578195, 0.14452685361667988, 0.11240151575616292, 0.11654874805601374, 0.2395319911621271, 0.10582958453244741, 0.10680608616601076, 0.1311387010519543, 0.17393448690493263, 0.11401938619993388, 0.146210576978422, 0.19197044894099238, 0.13705849226924682, 0.16219247342838397, 0.159797897081702, 0.12648294724884535, 0.06897369204389472, 0.27669655579713087, 0.22024667761739225, 0.16396109465389483, 0.16006932203327456, 0.1400813526443897, 0.0862655605399801, 0.12823394079121853, 0.07028697358985102, 0.10441441329256182, 0.15931437302741314, 0.09298036716157392, 0.08630699057492518, 0.13770281817884217, 0.11023289704274748, 0.10274341465124201, 0.21376820912043895, 0.1667603799292157, 0.2431011028707989, 0.1526449341326952, 0.23615496833958935, 0.2302438645593582, 0.15587002639808964, 0.20259374422171425, 0.06506005527391549, 0.11475404919756037, 0.19297725701284027, 0.15016679291523274, 0.19425170556191476, 0.2407068789245621, 0.1929677575225792, 0.1203091902237746, 0.17760162722439538, 0.17706311337890165, 0.19795819215716856, 0.10122777098008703, 0.10624196966208758, 0.08500785867293036, 0.1287846201129498, 0.1418844325047347, 0.17946649973671283, 0.19192908019308122, 0.16136614034973806, 0.186920887640407], [0.0417932333995498, 0.0045866847522707, 0.006043656143329797, 0.05400185187857959, 0.0023105956338000514, 0.0187889268741973, 0.05397219661503069, 0.012860141784673738, 0.07016462934834343, 0.051713880497000875, 0.0664414726798573, 0.02446993806159064, 0.03418286999447211, 0.012104792497871865, 0.05499722608815759, 0.024818506151918444, 0.14615822252967667, 0.023905838794645765, 0.0591943690162753, 0.0362986286411122, 0.050028624959410205, 0.035081456655696515, 0.02530034098233427, 0.08830650303993495, 0.025701213725692323, 0.021152913330062743, 0.026503372899887544, 0.058412220058662284, 0.01613503934124545, 0.06295211072410307, 0.03774216428639428, 0.04220419743609044, 0.02904410733120336, 0.025685679377807726, 0.04481132487736402, 0.01877302480410905, 0.04188385010967332, 0.05018548529234625, 0.02476321950164293, 0.022268507802378268, 0.09821008169843305, 0.03663348950325482, 0.031688807554723274, 0.07451346534634791, 0.03200812257766243, 0.048532535682522485, 0.055291327242288864, 0.07226657542970873, 0.009809002231415963, 0.01605722396033666, 0.053172806848681746, 0.07828732171366293, 0.030245871373241952, 0.06452806083665741, 0.047513278681905045, 0.03594808595915956, 0.006076295319343767, 0.014884441982083505, 0.06915087285902231, 0.05082066411212568, 0.03517252152725574, 0.03932382558442412, 0.06639449616834041, 0.0191759908827202, 0.0870016408002665, 0.10493040415308169, 0.04621431914969318, 0.012638961667225007, 0.057754476119073174, 0.018902131686768225, 0.015009434014979391, 0.04789551442128517, 0.02171076514998511, 0.01679195207543671, 0.030216162483538353, 0.06610045630124307, 0.005156104021044749, 0.10452587908554463, 0.057967862249502254, 0.032210235724285725, 0.05100399278284562, 0.03484553987941435, 0.1112191662973454, 0.013329992127124102, 0.0823465075283762, 0.033939602604556474, 0.04226469156903125, 0.018966475411528544, 0.0404737388805276, 0.009183373655222598, 0.020036834307135116, 0.011339762732536804, 0.05135725890736907, 0.03519358128429421, 0.09903458382693991, 0.055895054322336955, 0.023409480852405393, 0.05131022110881825, 0.010671169072720072, 0.011785240945286088, 0.019472453502878066, 0.08537686790429777, 0.054992185229615825, 0.0335568918906633, 0.009604505593738249, 0.008545849648784966, 0.03692979699060802, 0.02108529457942613, 0.019220343543096416, 0.02755276588422637, 0.017525996457064347, 0.02791483818943943, 0.009906155586753403, 0.031091854607145634, 0.03462781386089421, 0.058567383506846045, 0.0358172458025717, 0.043738441722046946, 0.031138315924533436, 0.06438042037189007, 0.02126338703918361, 0.03338911097436663, 0.02891819886562805, 0.025293553443325144, 0.03280828226237528, 0.024735634590709404, 0.040970320903485825, 0.027649578330437505, 0.07301512760140243, 0.030257446961777828, 0.048072377309924176, 0.040475830300560886, 0.03745560909831717, 0.05390666545398774, 0.0690051859184619, 0.03403656252269303, 0.012522688672517338, 0.024919834686443213, 0.05036466559695621, 0.04124372236190304, 0.027589955622510567, 0.05168167799110374, 0.02480145494994377, 0.01536743839331452, 0.05185590553728323, 0.09923287036438143, 0.05241613031455106, 0.08693769544122681, 0.03489951843455915, 0.01808168599382043, 0.031955678113586, 0.033136918660133116, 0.003520106979375405, 0.01607473098462628, 0.0025906962917126236, 0.030279236417564175, 0.031021334298495806, 0.07512144804481538, 0.02934721193366474, 0.008998428538982427, 0.013503361654828393, 0.08768404894057782, 0.06517214925899621, 0.05698539279100876, 0.024556465777418306, 0.02902276986729234, 0.053247734078116, 0.10818620122248128, 0.03636091925023544, 0.03338335382361566, 0.04836238372410017, 0.03447227502962755, 0.06177302863028261, 0.040502869373848366, 0.0346245541567764, 0.0395280301510807, 0.040688488647461905, 0.022714160300130327, 0.015887911825801338, 0.09476060994089612, 0.02967870009372071, 0.04261158001158507, 0.026860419668317325, 0.017598924197016225, 0.06762724655169634, 0.03606055149688356, 0.004119734531418691, 0.03997375925762519, 0.024136276127049522, 0.021496078585304564, 0.034722900694055904, 0.02234658365318131, 0.06632407736634055, 0.031637087043735294, 0.046910053389447356, 0.05004616071199698, 0.09260735895124175, 0.1006174517134505, 0.027936482088520165, 0.05544901111974351, 0.0437136626081361, 0.025794272341074485, 0.04821405378020099, 0.059666980148082784, 0.026351551510273453, 0.011574466217068896, 0.01824934050560959, 0.04590018862678159, 0.04258720692427408, 0.016250837361440063, 0.01678292372924907, 0.021528342378235633, 0.011610829538004774, 0.007802292370357581, 0.04158766136594838, 0.04659963073208929, 0.03125293991498409, 0.012764333871253317, 0.0026779434119816874, 0.049372355739075335, 0.004106717261170308, 0.04109991233675711, 0.042963130099158135, 0.033778670514302875, 0.0058367836754769096, 0.01842302412936284, 0.029012714963286158, 0.010832502401524014, 0.017336516100312435, 0.05013740178377879, 0.05054666510512752, 0.023651373114496953, 0.046371256091421655, 0.038964289030240434, 0.04559780606218884, 0.0680133548655337, 0.06494971563018138, 0.015591883960540499, 0.08381065476926104, 0.008766839201862534, 0.059044775027301044, 0.049705619307895826, 0.06283921617714149, 0.03202879546029914, 0.021032689236885598, 0.04926759321542998, 0.09065244046430435, 0.05000568828695724, 0.05553410816637259, 0.030047389483379743, 0.0032301405454129586, 0.023524093351537184, 0.0498421706499592, 0.05050470646951468, 0.06402537692338228, 0.02540192232587405, 0.0711493511053343, 0.03261245869761033, 0.03734671353032032, 0.015872702107674653, 0.044730705614652366, 0.02603099350967715, 0.05750612573577993, 0.02853558582794522, 0.04361034799066763, 0.06713552535661767, 0.05425148162870638, 0.03889014321048895, 0.01314468886477933, 0.012250904617230258, 0.08243187270577877, 0.012664096054410743, 0.04651162638178757, 0.053696661601744355, 0.06737584713846445, 0.02777876373710892, 0.08770645701236303, 0.04251140635460616, 0.06323484313343802, 0.011451599120552982, 0.12324257919024076, 0.038093174281980724, 0.041821977018468806, 0.046870703283216686, 0.0705666876127643, 0.03828956092137002, 0.014468235988920976, 0.07079642972037678, 0.055781585209432154, 0.04338065567877024, 0.07968747763023262, 0.04698349057786888, 0.04066675856348969, 0.024973261658282533, 0.07532774786194486, 0.07492987243759056, 0.017018968825258555, 0.04272059432321018, 0.05987675417394889, 0.030313928709215218, 0.023311819963818117, 0.034134200428642576, 0.010270536689448261, 0.00967725809107745, 0.0626098494526119, 0.05347846060871117, 0.02047941479231081, 0.08480558081740334, 0.034485018902247956, 0.021966625110156113, 0.042743140290821754, 0.004849010973327583, 0.04654299002140761, 0.05301906832403714, 0.049417922648811535, 0.018079600319446578, 0.027693320035694108, 0.03926924565025876, 0.09828598568997077, 0.06903491779080323, 0.03729604447500841, 0.027463922667647564, 0.04955018772893856, 0.016737527274076017, 0.013072848012070022, 0.037105889960883126, 0.049070042122395775, 0.017084429123168512, 0.08433530242332528, 0.02348054508348146, 0.03927938865437623, 0.03784816404203734, 0.049531824601393555, 0.05534303434673817, 0.07468516863281689, 0.06128409982568795, 0.04170093512643249, 0.08551581327112452, 0.023840930080041293, 0.003667486974248483, 0.08091826682850238, 0.012473859185833606, 0.03422093690342961, 0.06162045072884329, 0.046129279559658426, 0.012887289067880522, 0.1111229686366935, 0.0526970892303413, 0.059709528671397324, 0.02835412641176053, 0.06528618144652536, 0.05312980633349188, 0.18203082584565689, 0.11000281785644832, 0.15891853539693743, 0.13399285354441212, 0.08941547659736487, 0.1104104609018372, 0.09833471654283424, 0.08464968192481226, 0.2261127660711927, 0.19120244579690118, 0.15137469906720424, 0.11722420777885184, 0.12712989317914172, 0.09086628624748799, 0.12339706848105117, 0.13454648996553115, 0.25072110366196404, 0.09025669476437954, 0.251398294743511, 0.15177599124370084, 0.22596235236813947, 0.1248243285883819, 0.11097310651694575, 0.19091948356118896, 0.14300989227429514, 0.1760738180770028, 0.12809508735494268, 0.10710402542064268, 0.09294704999774696, 0.13486294556529294, 0.09698757391062476, 0.20410289146727134, 0.09580386081530202, 0.06707570155061061, 0.13436007013003673, 0.1306486346067921, 0.15338937241223552, 0.14123540281528427, 0.11083953142646821, 0.11920119725888777, 0.14188190441458456, 0.05995978661362202, 0.14854354453423332, 0.14835231366657442, 0.13312882893989164, 0.1681311716956477, 0.12260241313807427, 0.10822580796816658, 0.12585681592745165, 0.13138127513229847, 0.13834104602856023, 0.17193482888321723, 0.07046237708099427, 0.1628804663496633, 0.1205229900416828, 0.29737081739210314, 0.17085158055828464, 0.09764699175232842, 0.11875577075707337, 0.20675282024087446, 0.17384361355535446, 0.1185146828873023, 0.16142283085613482, 0.11290012408168086, 0.22533025322181566, 0.16747605926807851, 0.1835036298800861, 0.1793644568251987, 0.0821200366162004, 0.1757412133437972, 0.14716362099974387, 0.07925204091495083, 0.15054383074804661, 0.14770064863466448, 0.08559210796750362, 0.09594820710199495, 0.1619513855586129, 0.21243849498850687, 0.19285874321095406, 0.21073646212537445, 0.12934329739261058, 0.13563513154945067, 0.16422354105499484, 0.22328634596159383, 0.17777191324820443, 0.14969437713584594, 0.11507043584940896, 0.086466099375919, 0.09352925383756239, 0.0929882042410393, 0.24699601645190872, 0.1575898937880993, 0.1662221418753747, 0.11206416127782677, 0.14078912595587392, 0.1224634447886098, 0.14879373352854483, 0.17100977771464856, 0.1696584139379763, 0.13742169455414818, 0.11648698604755825, 0.24710087856698423, 0.13594337468666418, 0.07422864151697967, 0.14620585787680843, 0.11329033096591312, 0.12521063608507957, 0.1438793714248365, 0.144818993585725, 0.12569394563474964, 0.09363893464568163, 0.15379660943102452, 0.11942200678130312, 0.1482684576823827, 0.25265970447611424, 0.1987467877446644, 0.15945257528895335, 0.10689770262087546, 0.168143107345508, 0.22494682621571327, 0.08707759841795891, 0.14431182805809284, 0.19901542413619258, 0.10464561096723042, 0.16156549174939433, 0.13293870123884372, 0.13450342050242808, 0.170273597862932, 0.2383188449687535, 0.09461839337863269, 0.14535386085269913, 0.16957976735166966, 0.14000241494467183, 0.0645413371403852, 0.1689053341866501, 0.1366310305292568, 0.14104316071156534, 0.2308343498096351, 0.156706502480853, 0.08230860915876205, 0.17037781646415112, 0.208805552833984, 0.160453760275437, 0.1407689471999484, 0.09076915395956847, 0.21240615075634373, 0.12568914992434363, 0.18368064215587032, 0.06540261148925751, 0.14662368223071098, 0.20704532793212324, 0.19302323761005558, 0.11578661314542256, 0.16413626831866082, 0.1324433028217285, 0.09483167991763163, 0.1035510628454147, 0.16799925135508662, 0.17059582976564286, 0.1325933181590611, 0.06251519162868781, 0.16358267786281724, 0.21941394004369938, 0.14832304910786692, 0.14043565298761093, 0.12593566935749786, 0.21700771916056835, 0.2844354840776613, 0.1815006930020548, 0.06470934788305914, 0.22204975747773725, 0.07563024533972626, 0.13507764936695177, 0.12834444897429598, 0.10845136723571247, 0.11169504479414995], [0.03612658444551691, 0.07168060243730584, 0.03824875524808322, 0.0489781268932406, 0.02929152308722898, 0.04229484478973093, 0.017231642493918058, 0.048369611763665755, 0.017517287952585087, 0.025491194551690452, 0.06661561212592548, 0.05377753750391064, 0.04211453067499303, 0.04514356188836598, 0.05507896766967832, 0.04023548553607637, 0.030679605458112016, 0.007957193912232235, 0.07917392292931195, 0.013378925993287516, 0.0418588258476267, 0.052733340510918256, 0.022427300592103315, 0.03791570235344191, 0.01949398057355035, 0.059016659600479957, 0.054344921372830875, 0.02649022683110689, 0.06872981561407929, 0.028244861206340215, 0.0475732978403328, 0.0603245287352512, 0.041793168282076236, 0.013782053907972672, 0.0395666869477399, 0.060818624802895134, 0.038203211320984753, 0.026912596001620256, 0.01230762289431427, 0.01300616580392084, 0.011502731659059084, 0.06986863595703918, 0.06574667689781036, 0.020522126109309254, 0.08327203367145793, 0.1573328559677447, 0.022466091454149257, 0.05614743049767229, 0.018880685055327993, 0.012356549099598442, 0.017650548947013674, 0.04135266772561497, 0.052953418419365926, 0.10918806036633831, 0.041841971913292524, 0.04207900717794415, 0.017535779399857405, 0.06174612362238188, 0.03207898571065838, 0.01268478138597622, 0.03397469709236776, 0.0495701864542019, 0.049515966581360954, 0.06987930756182441, 0.028060377658074422, 0.01466896538923104, 0.08044169885256598, 0.014811685654304683, 0.06332844758646623, 0.05740907388709246, 0.03447081563213179, 0.0275104261198712, 0.1317232261381803, 0.059385760762398286, 0.028744463530939915, 0.09235857189783166, 0.00967787191902678, 0.08596978931417389, 0.08530464879567586, 0.03754146074155166, 0.014775464059634796, 0.011856069604325439, 0.003502538428649367, 0.09686529095615111, 0.02458559627073907, 0.004633530550035498, 0.023579167412413705, 0.05198226024907443, 0.059802922450246356, 0.059008604185956146, 0.036530588573265466, 0.047466853753693646, 0.03341861685077029, 0.041578000997223204, 0.06860742540729624, 0.018417761105323033, 0.03178590728390602, 0.03303369214277595, 0.033757453709239924, 0.09329476964569862, 0.0838657901171715, 0.018380247694890828, 0.07820254642396204, 0.048143370677867246, 0.030501080158677314, 0.04052047024390871, 0.014192325592551742, 0.050475277201903444, 0.05799526138411415, 0.06759040538341769, 0.041921127948068806, 0.011975449085566066, 0.04141405818142718, 0.01087006273484158, 0.021437616500582908, 0.013836687468292733, 0.011018386933081334, 0.03587695469539012, 0.060061994234039906, 0.01825190881537574, 0.03861463884071958, 0.03847093606788305, 0.07131810495329481, 0.01635007830637117, 0.04179547420672832, 0.028793301636112795, 0.07706459942123584, 0.024130499824100447, 0.038629941447007085, 0.06129967056274895, 0.02480784603845208, 0.02575902272045853, 0.04815287782900757, 0.03215435344064909, 0.06980461398920706, 0.05380849894737044, 0.02365197449351751, 0.058207437095622865, 0.04752156775324576, 0.10913597404836647, 0.016229745045664812, 0.06448268544890227, 0.08318061639945354, 0.028756211489258755, 0.027192691153275873, 0.007419397795362579, 0.015862245965118132, 0.03698855210396071, 0.026710302824334755, 0.02527960681266362, 0.08878208276244903, 0.02885175797517502, 0.07152851866257769, 0.017229273367012223, 0.05952802712037679, 0.031733003167075016, 0.04122719784537631, 0.025304395502673525, 0.02207674258839219, 0.056093766038576444, 0.07816233446881657, 0.05125972059284968, 0.08813935031573619, 0.040704201110788894, 0.03340897563424322, 0.050261040713878415, 0.05404919994273975, 0.040961438114003795, 0.026213657599122777, 0.018004759274903807, 0.10770259289852074, 0.0277688448137093, 0.12569726279546178, 0.01944809573732557, 0.04211435447477045, 0.017414752829579577, 0.01587536426321153, 0.043289518028858213, 0.02953573276529149, 0.052518544778708494, 0.02893477126265005, 0.09138623012169715, 0.040382168390938354, 0.023189203761097406, 0.02119269819119044, 0.0367070799092612, 0.07848662714804373, 0.04129005919000314, 0.024193671434336615, 0.059490879516928434, 0.01681178226135671, 0.03235916321676585, 0.023226100470750563, 0.07224140944139612, 0.028176279100138816, 0.012447044193263979, 0.023345242464734663, 0.006724967341494537, 0.028187316511907888, 0.06612474894932201, 0.05018127563920233, 0.030595942911121155, 0.059467506174358635, 0.04945588996633888, 0.02608595074214522, 0.021184275054462978, 0.07061302827130403, 0.06617282862744986, 0.1045322989023501, 0.023550617230695584, 0.030660755864735094, 0.06542308135859429, 0.031007696018223802, 0.03364618709911743, 0.04983930931156201, 0.03396527804133873, 0.04434406870014725, 0.018923250815620827, 0.03989888565434564, 0.026633266937888922, 0.06257160634343183, 0.022643006053723158, 0.014262969432879361, 0.01890989790310062, 0.013361828826037387, 0.03729515581301624, 0.01465264484361415, 0.039655691042782805, 0.02573930170206774, 0.04952366193456035, 0.02655389256805422, 0.09999852161854507, 0.055208735303172184, 0.022608447827458866, 0.04190382202185931, 0.02236438562132178, 0.07752946923456847, 0.013487673131749036, 0.06978751490673712, 0.0705900609553341, 0.019347870369411765, 0.04018259865622367, 0.0368472165428102, 0.05616312380880118, 0.027462254511192444, 0.05535716866894115, 0.014767663369345811, 0.02267833228313154, 0.06712944261849889, 0.049699287591201645, 0.07507230350447279, 0.11023886486767762, 0.005410602259930344, 0.026416536833670352, 0.09775858778025835, 0.045460231992746555, 0.01749667635698232, 0.018198188814905383, 0.045546750132475174, 0.05398130540045039, 0.03849730098379716, 0.028979531864845948, 0.01493052312833888, 0.004600143001880497, 0.11158588492581922, 0.05826368327102354, 0.049888266160363154, 0.03230332689840467, 0.05270720542138142, 0.004796322797530241, 0.04216369819797335, 0.04509578864540785, 0.15268340706825256, 0.043784698110915, 0.04689736314298165, 0.03310604914722424, 0.02708902988102167, 0.012192547869598194, 0.030459280486308762, 0.0480954863521601, 0.06395776966406454, 0.0764301713676222, 0.018131904972476826, 0.10705509538491888, 0.05772993066197923, 0.07910433150227032, 0.0371129188175884, 0.06311785001608153, 0.026484883367835034, 0.07533042150880061, 0.037789037376041376, 0.010293255026842798, 0.08352399998975378, 0.0547994987949008, 0.03542891200331431, 0.06229073169731325, 0.027861340354467114, 0.04653875355518634, 0.023691196280020862, 0.011703066524088142, 0.054418733944335294, 0.00470904670956154, 0.08739496566235058, 0.023213657287640438, 0.03384245116443884, 0.08366193412052048, 0.0364001965781133, 0.033430127321832606, 0.013512947329980953, 0.05227432360932712, 0.0243069586013594, 0.08089113199422437, 0.04966968212336783, 0.05261902487085712, 0.015838814208344106, 0.02397814791859879, 0.04982682590883586, 0.09096799208031547, 0.016643468913952672, 0.04578250603029325, 0.018076809844182386, 0.022969782773044803, 0.0065911720007387625, 0.03020823730396167, 0.01931411462024816, 0.011582946810390682, 0.024343817006616343, 0.03614795446816472, 0.01984847243875265, 0.07641475767858567, 0.04207141524661453, 0.04385021778063909, 0.028170181040261543, 0.04292173836860926, 0.03792028355922911, 0.027152674550551082, 0.12054398851168734, 0.07070241541030907, 0.03441440091738778, 0.022166426586467895, 0.059712826679911346, 0.04370504411898794, 0.027244555305749662, 0.07497829685528433, 0.04189155695419158, 0.027790312512567448, 0.021707061114871216, 0.04200651993854873, 0.09269817101378595, 0.008693573425614066, 0.009847620723678941, 0.02160941937848205, 0.11613596456065295, 0.1615895009449413, 0.12146657287713983, 0.1703057582339933, 0.1952058527498476, 0.18147430893394256, 0.14887711453822353, 0.13514429901636418, 0.09328129415911052, 0.12468364420196704, 0.14724127167174894, 0.14095510656554855, 0.26264356148819773, 0.1956415422741444, 0.09922578405108183, 0.1420680944237017, 0.2394705355888413, 0.17076253049796628, 0.12208879715011967, 0.07542707116132782, 0.1717073467349814, 0.10935035609309712, 0.08471408693660652, 0.20407410188307687, 0.14109418216732242, 0.1296759021258162, 0.1618124325309069, 0.18369510589588076, 0.24970588394470755, 0.1310067807113932, 0.236377333020491, 0.1297763209309309, 0.19257147556110737, 0.1200880129791556, 0.12013016313674951, 0.13075771020545116, 0.10854296836881869, 0.1088792043587854, 0.19999013312401312, 0.24117414659309774, 0.22863704110345534, 0.18555401824414733, 0.09389536725657602, 0.16241747345174515, 0.22925245485478835, 0.26981111075128283, 0.1044742754029651, 0.13284313943116896, 0.11956777799153522, 0.11307414095368117, 0.11321078039585583, 0.23860894714392003, 0.12947929332092886, 0.19958732409342644, 0.12582303911087014, 0.2028530649840832, 0.10357984476872992, 0.10999055278878059, 0.09982524019095207, 0.0896850859205569, 0.14778566907250112, 0.22827016159651742, 0.12631539615892595, 0.25991677877403074, 0.10387602968201523, 0.14753690500172878, 0.21748359765737288, 0.132057347725476, 0.22141243361176985, 0.16340722840639854, 0.18878571418744905, 0.09410613336630407, 0.1890172259581666, 0.11386241478424881, 0.1501790809655382, 0.15884758033339055, 0.17850832292629829, 0.14885601647678884, 0.17516427252802158, 0.13534476890438987, 0.17415453800030295, 0.0837739744794465, 0.20293275344996684, 0.18191765933748216, 0.19413245631562126, 0.10432209203680677, 0.15602958719095877, 0.08954990970631761, 0.24937822813949279, 0.1806889615592457, 0.19049488699003575, 0.16376879126314195, 0.13753832377974065, 0.12559501304020806, 0.18194943666458133, 0.11411530806893304, 0.2938422164128673, 0.12927413497480655, 0.18490986087389533, 0.11621178428251898, 0.14946812072828894, 0.17542903251465292, 0.2746381081881062, 0.21908813817126138, 0.18601532574863205, 0.2549834023680418, 0.10540523310942997, 0.21287214671892507, 0.18787616863846782, 0.22433749520249907, 0.15039067445022447, 0.12753172927806455, 0.16099935277335106, 0.15595319290314952, 0.11311491981389062, 0.10721969703632979, 0.1922225378333561, 0.10773486818277067, 0.17398740825874193, 0.15989140577373967, 0.11322367365562147, 0.18604117355519728, 0.12241660617291929, 0.1446256329936366, 0.18204472268060332, 0.12611691809950337, 0.18901857427291333, 0.12859924215703242, 0.1561639130476021, 0.19973318723420944, 0.06872205514340632, 0.1377971082805626, 0.13003816978344995, 0.18900910542616922, 0.25674437803606837, 0.16569639105469952, 0.09868271964331789, 0.2061710377494174, 0.14883585304262179, 0.2744141040790466, 0.15270884118733868, 0.16406977188683328, 0.11826937387306845, 0.16733396527988298, 0.2080896283469854, 0.1221559907219583, 0.12676726546018355, 0.14920270190604273, 0.08623242723725497, 0.19648699690738033, 0.18031838950851273, 0.1628863192614048, 0.15069229858777217, 0.15574722250382747, 0.16966837308099195, 0.11653731802418349, 0.09113513714363498, 0.12964017178502776, 0.10665523579284068, 0.14607214489050452, 0.23750633211626163, 0.1564940816212085, 0.14951466823056822, 0.12637357287589582, 0.1394737070246089, 0.19026979503612365, 0.19316959104711012, 0.15575347378128962, 0.13140015153875276, 0.07437456594479662, 0.12333593466469359, 0.1346996615851118, 0.2385664905511564, 0.09154808917833913, 0.10014558751736918, 0.10578138228025168], [0.15000994407361554, 0.09124118669499313, 0.03609964879409921, 0.03481970739460761, 0.03511136472826043, 0.05964207462966443, 0.013970621662484783, 0.020953625132660234, 0.04452064430581466, 0.0850623275243467, 0.01965601008475548, 0.018281288287271897, 0.019266877638837023, 0.03280776898346601, 0.05026266098983827, 0.06563071416871202, 0.007822206825949252, 0.05943310499611882, 0.05900456307215556, 0.023729860737559297, 0.07659186954580008, 0.06457596431456267, 0.05878093434617885, 0.03570634691465286, 0.05889099436782061, 0.013955575695651916, 0.07411946632689045, 0.028747985620171796, 0.05991606980622296, 0.04807632266273422, 0.08520866563964276, 0.04675169918505896, 0.028488220526806773, 0.0712106841045522, 0.014941595014064543, 0.02446045963874748, 0.03873664217310087, 0.05449474901862202, 0.012596312594870407, 0.03510467295024184, 0.06601216466796976, 0.024248218809765194, 0.03320097510192183, 0.027160632288864544, 0.03324553843647723, 0.004959077698238675, 0.06539816051841744, 0.021339907731500365, 0.043447680711265535, 0.025550051171693112, 0.03064766533732895, 0.02979111392050982, 0.030091263338803288, 0.0759591498682576, 0.019368458982376803, 0.02417451349057017, 0.031816592935713074, 0.03130992919567131, 0.0545560245612456, 0.061848741099839254, 0.011426618908562008, 0.04666899616319326, 0.024777258062855374, 0.009878239342792621, 0.019909410902689544, 0.08974626570218995, 0.0156595716590903, 0.06709983332022544, 0.046077603098726085, 0.011163860326632859, 0.04692537514793296, 0.05509036322755199, 0.01398075987855273, 0.03985773907193253, 0.03252133636945679, 0.0452011946829096, 0.05771259792269238, 0.07587831227048751, 0.03649565879435789, 0.04421281485608028, 0.04618368712404082, 0.05586798843597213, 0.026576381079071475, 0.03215070303168989, 0.046809749497521314, 0.03135132667187962, 0.027870249957026496, 0.02238170112363033, 0.07783179051212727, 0.029394424017218333, 0.04563190846613819, 0.047050699471466007, 0.03641215521061132, 0.08849784882078249, 0.03703263663356343, 0.07281885587520177, 0.024454164311229706, 0.018621513680104288, 0.03897376170742416, 0.07353281151623496, 0.03115439036440465, 0.051018353100986256, 0.008558973692537797, 0.11802855413407089, 0.11950281373555623, 0.060672489700899015, 0.037814463834248246, 0.008516911635055177, 0.05197813486560218, 0.008613192607768843, 0.07373891215050414, 0.14099449880661505, 0.03866808879519663, 0.05342882194165742, 0.01933548655811577, 0.08647984299328058, 0.08742564748371802, 0.0644961302919734, 0.0774475054875497, 0.03100348061942045, 0.030256832176218593, 0.036408692493193576, 0.008619901622765729, 0.04096082907410399, 0.03812912295782759, 0.03798415997035561, 0.022130996935189735, 0.020276154429020903, 0.0443028953046568, 0.05173558759833536, 0.03920366086306111, 0.029007789017933033, 0.03016576538943956, 0.019423176812368537, 0.0036611978711950928, 0.03981747349063235, 0.0047280959646037275, 0.029575272478283416, 0.037182062083194335, 0.012914246744326046, 0.03484735933823451, 0.04577361941037159, 0.01110978409527771, 0.04438227733537074, 0.05350177266424703, 0.032353191561396086, 0.02133609644407707, 0.017246004727278507, 0.07976234740307254, 0.02673094314823468, 0.05745388236978362, 0.029274435496077906, 0.06121314093170147, 0.04430247012585883, 0.01147998363575748, 0.07955449242745677, 0.058286286695229436, 0.06049953769111346, 0.06784715209036105, 0.048649793100212856, 0.03323018220403502, 0.08275267968495047, 0.10613687772063479, 0.05540853103382453, 0.043056152325363896, 0.08003207163945322, 0.02991479307022547, 0.02716962424587579, 0.03654748847287509, 0.021578877368160797, 0.03188279250846996, 0.033390712098128376, 0.09668245641214233, 0.03173164336100942, 0.011857543365969773, 0.007115268550302473, 0.08890834937412893, 0.1270626459811484, 0.010332859857308288, 0.04497675007329353, 0.04499445436522365, 0.044491142259850625, 0.026792957965705185, 0.057571744996934175, 0.11236890339322629, 0.023896827685436415, 0.015248763712964233, 0.005116755830033893, 0.03124596851487314, 0.057737794554521965, 0.07171576587303032, 0.020124382835121888, 0.03772854707354019, 0.041929432341168006, 0.07507945876568556, 0.03478184349895005, 0.09224307648236714, 0.011956966256782895, 0.041008935565309185, 0.02965686658787872, 0.007563562136173489, 0.026310054442634987, 0.0354984957694767, 0.034313794420731646, 0.011203559960478978, 0.034743343750315334, 0.10676909178014725, 0.04612867435019824, 0.03804255885282352, 0.02898796074723284, 0.021069197156917185, 0.022667794743733063, 0.004386498316776969, 0.04147682376506348, 0.06201996175091594, 0.057921199834034334, 0.008951291149001448, 0.06498189132300115, 0.04011397633040625, 0.0505968093902113, 0.1115664799186972, 0.029809321915250153, 0.03747000005997477, 0.05517829096906128, 0.0360044164042319, 0.031947224333341566, 0.03995526589513306, 0.06796813269536342, 0.054818413505751284, 0.10767717410119311, 0.022927864357047988, 0.03220635165850962, 0.008358414746790884, 0.03733534478552399, 0.05305297154512617, 0.06140008936786364, 0.014381824143891855, 0.03068680093894082, 0.020185221707628622, 0.013516578586742043, 0.03739067931629477, 0.09978194856235098, 0.022938229526663502, 0.03453671834581802, 0.06854643714764426, 0.006107198827404289, 0.05651786848301849, 0.031816654222747015, 0.025412153430102814, 0.014577123896038581, 0.0153982360854805, 0.06715973373502493, 0.044633535022336635, 0.06120542642630397, 0.0621212002701096, 0.01851414262707676, 0.07285421083290732, 0.04883147468189559, 0.006204004091541133, 0.02528758944883462, 0.05453239457922117, 0.06395399668103745, 0.0225163908720377, 0.026233041538826884, 0.03979251434605929, 0.04579624198677559, 0.0207273974534004, 0.017726993030538003, 0.04191970685496927, 0.009380788767650243, 0.019588835665114948, 0.10250170625025228, 0.02245613614157323, 0.028158088342376777, 0.008870780096209098, 0.0539785513143626, 0.05796279074744352, 0.04550172714516521, 0.04906832608544538, 0.03667651683152203, 0.0815059098925802, 0.05137787816385108, 0.05223771609786538, 0.04119758088622363, 0.037056546237680225, 0.0722610749184124, 0.08194863976490113, 0.049884167589968255, 0.050509203405630206, 0.08410423498360381, 0.025087550485266313, 0.09680199677184706, 0.1261179063529257, 0.0608090601951605, 0.06721811729573435, 0.014984303458233275, 0.04037718881943053, 0.022740885277368852, 0.04170254391107348, 0.09664120257741983, 0.029378156140146237, 0.07485178509546865, 0.006058746639023265, 0.02624616845540943, 0.029512257916071725, 0.038131440373798536, 0.05829062275288086, 0.055967595187887076, 0.003878128355286355, 0.024712751544411146, 0.06356489296341616, 0.022666329600577875, 0.03500796201068067, 0.023905055469743187, 0.03869426218912967, 0.06336259978613065, 0.009005466014176847, 0.06373601402306268, 0.059580511804069244, 0.03765588746436181, 0.07129109269308467, 0.03744951486887951, 0.026983932193909443, 0.015068316490449494, 0.0926807118699916, 0.039864538102260524, 0.0488370786150617, 0.06942456543085075, 0.03948804036143326, 0.03159214258043757, 0.01523469450823482, 0.03350038141492875, 0.05233990456608515, 0.042412136681377895, 0.05059866332298806, 0.04904785238566899, 0.0387849708298041, 0.05271848989650608, 0.07398817417842728, 0.04970071634518043, 0.012440335178267092, 0.07192106211497899, 0.022669884248546535, 0.04321149197377024, 0.06093043533544387, 0.025612985294672753, 0.05605540035532848, 0.04567439570241878, 0.034622861102463744, 0.03699472294219079, 0.07230514029581701, 0.018514439486147418, 0.16958001249980542, 0.20363461256267565, 0.09881492343641098, 0.10625529959197007, 0.13405185763634023, 0.12253777063902348, 0.10674242425950305, 0.1176812788171153, 0.23564334418023788, 0.16008337208580586, 0.10754776652902366, 0.10545040165344555, 0.08577738633199085, 0.11164534100962263, 0.14504281383368278, 0.13793688868322682, 0.26920970108720566, 0.20282631319376732, 0.1981736314032347, 0.15153196159630053, 0.1262583302694463, 0.1799572556610069, 0.09683488492643642, 0.07792651728396455, 0.1611127031426276, 0.14317331415030266, 0.1253889890147313, 0.20950853043506223, 0.17620507958194903, 0.142562328387172, 0.1722752477132505, 0.11237913066701544, 0.08887010626494886, 0.22047311788605106, 0.1088958131449838, 0.12104799009619222, 0.13409007010200333, 0.13075119845809477, 0.15408260537491691, 0.2511329678518157, 0.12074038281195587, 0.17082628433502492, 0.13620549933083598, 0.13832154143000805, 0.24252463702953633, 0.10086418565122351, 0.1432523744240884, 0.18390320601963228, 0.1574333973469273, 0.11980112837327105, 0.1351473633680613, 0.1298519950960913, 0.15859314721197854, 0.3244449775065145, 0.09782895295610351, 0.15625962807286173, 0.15515535829528687, 0.11111048906440697, 0.12621392015247576, 0.15203958677668727, 0.11821813791269258, 0.1395791360447484, 0.11954829637562076, 0.1005966371045478, 0.10224603206640291, 0.23191890048403896, 0.16180627318399568, 0.14142900855550844, 0.11544373517315235, 0.1233911849257927, 0.12869196943938732, 0.18720314507522892, 0.12407969112598127, 0.17393318455546133, 0.16216446525387226, 0.14949597568521578, 0.16399513960124987, 0.13231357349263084, 0.20301025090438707, 0.15033608302474022, 0.14009532608812855, 0.21489748400786232, 0.09571265038703719, 0.07750218884358484, 0.22664751076409895, 0.12543516879480693, 0.07702519951929009, 0.15996648239031916, 0.1264017419288716, 0.25750026166919743, 0.11846041321874627, 0.23798414115463537, 0.1213045989073092, 0.1844930630778113, 0.1647043071927563, 0.19946807484713294, 0.10138937722771399, 0.26632967014466563, 0.08831797137616143, 0.14672987733877477, 0.14261128140553353, 0.17095645799511866, 0.13148054480552673, 0.20782595620520655, 0.16713947087766665, 0.2780052484764207, 0.09555602371091805, 0.10871199800843194, 0.12068802070233131, 0.2158517078045876, 0.23522836967341362, 0.23840689911477028, 0.19754491836553623, 0.1750491601565192, 0.1870886915393414, 0.25233731935581855, 0.19070795136353663, 0.14711865163858862, 0.3177370197109638, 0.16212879620011778, 0.1478741828712725, 0.1622423610740131, 0.17240385855397872, 0.1956758323696352, 0.17755092752556648, 0.25315202321977387, 0.08914384480205276, 0.07896207663561068, 0.13900230248128215, 0.21669391422502457, 0.17112358773667968, 0.12020749205182638, 0.09313443510402596, 0.10251835334084689, 0.08687241708919888, 0.1125574529531502, 0.0806901871316856, 0.07815988298745886, 0.08389153067142734, 0.17442967081742902, 0.1375260204076767, 0.08807533600878331, 0.16146047641673397, 0.11493519834813573, 0.1395622974321727, 0.10864024621344383, 0.10408063644483205, 0.06705513208984368, 0.15228427525970245, 0.21960552331180344, 0.21120941416630823, 0.22280941026345377, 0.13498237867268825, 0.06940041833947744, 0.08771536661492241, 0.11992309723169574, 0.10702790692448617, 0.2047552766218301, 0.13338807309346815, 0.1805719033244156, 0.1413885744348649, 0.12917523302378195, 0.3877383037920921, 0.15288012312544932, 0.09376372270766767, 0.1874903054727662, 0.06327250401579565, 0.11569302018371322, 0.15371635406007692, 0.10566676786590008, 0.11735733087745406, 0.23567190393805507, 0.15819340253308897, 0.1073885964409959, 0.1475103523942732, 0.10963025397711224], [0.056257030866559476, 0.029305852761852647, 0.04681818029512802, 0.011051597802208797, 0.05418960853750187, 0.06091653083961818, 0.025146056620043614, 0.05321293070371594, 0.08008981934718548, 0.014263331409423582, 0.06650712641496813, 0.05424796528513393, 0.015105200751173883, 0.03206559449374195, 0.0368647369736385, 0.009976067813113332, 0.013143397049017012, 0.05604630306122765, 0.027367937596394654, 0.02060364169489232, 0.08066150479980054, 0.05163270965098374, 0.05113452650426377, 0.04342072973808935, 0.02329180017113686, 0.010890920436190022, 0.05922142724176088, 0.04098006937232229, 0.04453797321466189, 0.019044746614752278, 0.023860145480402058, 0.03213073494994352, 0.07580390981128139, 0.04062815922342482, 0.02862267661839724, 0.015213469084682725, 0.048556376338726094, 0.12025413148465658, 0.03570376136790841, 0.016759326305961417, 0.022006766202168602, 0.030731835417569648, 0.07772770214585528, 0.08193758511615377, 0.011012618291011501, 0.03900335185349949, 0.04149496855755006, 0.023950580244643555, 0.03903892897670308, 0.04090503106013902, 0.05015003840408979, 0.03279240509014457, 0.03949995685909544, 0.03551925292178508, 0.011255955586450235, 0.06281572409094342, 0.04910659600770281, 0.056468348559593005, 0.0248815685946254, 0.026470519219254775, 0.09158204985602249, 0.03072799540184919, 0.06437463640806175, 0.029037781360168612, 0.017675814526756446, 0.020248908511993867, 0.016071488517486764, 0.07067804615343772, 0.02416213159449399, 0.038527006043061134, 0.05569029434193527, 0.017803502231535893, 0.06620264476946285, 0.06493230245166248, 0.08284392075673228, 0.02699560928909529, 0.01163482532701305, 0.016024626919158524, 0.02235995571789963, 0.018244525643005487, 0.021529363190394737, 0.030450409188145594, 0.0613897739939632, 0.017994277276879838, 0.05291869548419791, 0.03336679483313234, 0.04077809412152537, 0.04298288367628571, 0.025298366390709436, 0.05569663371950869, 0.02175648719252598, 0.009013211163091324, 0.04506691862198134, 0.01148588634321406, 0.03263161089571734, 0.05721824138515419, 0.03879919708255799, 0.04582705021265053, 0.03643647850220723, 0.08232929353271762, 0.02018264956742285, 0.021412281972926953, 0.0830993727750836, 0.07690296253009189, 0.03056334395472321, 0.044127495643953164, 0.07407786009172279, 0.009677006239672343, 0.05236841835862687, 0.007194329781698124, 0.057556024872727936, 0.02352681296366838, 0.03003787467136018, 0.05552411837983997, 0.055356724337945064, 0.026964741691406217, 0.0018521558118781316, 0.014790742725674665, 0.0304146156451034, 0.048832769370487625, 0.03400607988418591, 0.038668954474551064, 0.03808698046111292, 0.015911806108159645, 0.01605548302552873, 0.03515691631623814, 0.03744790608423852, 0.028001432937960473, 0.048538415407341336, 0.06533138063405791, 0.05080091819587735, 0.041748497695211446, 0.03040396319251628, 0.008135145124528677, 0.025098854112589074, 0.07653560038776168, 0.023819789883770773, 0.025330513355232058, 0.02139468493330623, 0.008825140408120088, 0.06009741813965863, 0.026601349799743584, 0.06773806883082276, 0.040444585404569106, 0.03624839625591713, 0.03791939489723694, 0.00497201644447482, 0.0411035972196729, 0.04279520362615586, 0.01878278476426438, 0.06531668706767021, 0.046764933353950905, 0.05505301261080369, 0.004191480580747369, 0.04601806657569063, 0.032758092012016043, 0.04535413647611295, 0.07743702540474554, 0.0690887661110009, 0.02813364822237242, 0.03154053698263822, 0.03859259083025879, 0.03897818586518688, 0.04276257977190037, 0.02226573073365275, 0.023897538231986187, 0.03383230432988175, 0.04251349394419982, 0.03013950772583485, 0.00726416779329039, 0.037413098879398844, 0.04514878660800957, 0.009578528509835803, 0.03957771861384954, 0.05927984910686651, 0.03514693419058477, 0.045388821106884754, 0.04212342495579393, 0.07003882238941808, 0.03821106372220862, 0.029505895555860577, 0.11154073170356213, 0.05342045626152427, 0.020164504774936268, 0.05011987752251087, 0.03636448921996259, 0.03997010118778675, 0.04089732038518114, 0.05481916044147746, 0.0136462724842732, 0.05677852989925493, 0.04282528789894235, 0.05263799703830192, 0.05023008693129786, 0.01789788426380725, 0.06297775168692873, 0.04287231803661393, 0.015555790685597929, 0.0709057504671716, 0.033920634267551285, 0.02101597894403723, 0.034160860288407535, 0.0963803266565646, 0.0231198153473557, 0.025921808743488886, 0.07982701288476106, 0.01295059665872325, 0.03480970611675613, 0.040654711830880375, 0.041867934633046396, 0.02823771552122649, 0.01853137769015326, 0.02216056601384715, 0.07639955083328871, 0.057314431384926846, 0.024544296470741113, 0.0438170921387932, 0.059063459911774245, 0.038149611979362466, 0.12413529378752555, 0.01494304579307115, 0.013622302550732369, 0.022818714064816316, 0.05618041824369181, 0.0239742121418878, 0.023638045099834283, 0.015580750787780892, 0.04890989527226456, 0.030334580524434007, 0.03649685389151977, 0.0734054264161856, 0.07102274741496771, 0.05668635036976588, 0.09183406213959379, 0.04714470612065447, 0.05963882641686548, 0.02171344071206066, 0.09466170032899227, 0.025643084889217734, 0.05234732029719218, 0.04021459814882086, 0.060937000708954955, 0.026470049990401156, 0.0327691275085653, 0.020170177656015562, 0.0615488444905608, 0.022453177126965696, 0.036512566354846766, 0.0778830188116239, 0.03099599210996061, 0.06236582363565123, 0.02149140161852683, 0.01635101867929822, 0.017875552800814473, 0.039733008466540806, 0.027504157605430776, 0.006601786148929668, 0.0020377955544033963, 0.012139912841150598, 0.04671600331822711, 0.08237053204568164, 0.02096284500082895, 0.01891888411445243, 0.06509945517586124, 0.035912321144414526, 0.05604653288760493, 0.009796352204566282, 0.009672010388796129, 0.04103429690604249, 0.05170033989293922, 0.054593896117782405, 0.030267825537932017, 0.033870662352250475, 0.0346226925631204, 0.02981351624663559, 0.09305260925283355, 0.04577555761282002, 0.03531517859007563, 0.025956905146519986, 0.04648828751317436, 0.08916880394662581, 0.024087752117925597, 0.04664283043013946, 0.008656376984060533, 0.061098695056693214, 0.055250739904060486, 0.023437619261864214, 0.0015928005755525985, 0.02308413671750215, 0.022156649389334267, 0.010180267591720388, 0.0518449466495264, 0.13200222003844478, 0.019340167355333126, 0.03718025794613265, 0.044217641210003246, 0.09309763224014352, 0.037310542688975414, 0.012296300114793404, 0.06731921791910164, 0.02046772812102591, 0.07541407064925279, 0.022722430219272935, 0.03964148777266664, 0.04400553061596809, 0.023407734171938033, 0.02573955451108275, 0.02153373755244238, 0.048369711355095914, 0.04059836223360993, 0.04467215351459961, 0.02617422322322044, 0.01034922541059073, 0.052967629350361325, 0.03797835685432919, 0.018267378045786774, 0.05887808578629648, 0.03100755046151819, 0.055179321357319434, 0.01788515379772552, 0.06606933780975881, 0.017491712107232982, 0.04259926131776264, 0.046201885542682106, 0.0467526376427662, 0.01628067648609079, 0.0370589402624436, 0.0375636428173992, 0.0067171690452303146, 0.010774428148814028, 0.04156375176183159, 0.050887750431654916, 0.0818919339367459, 0.02117319550785807, 0.053909051817871874, 0.02549443510361016, 0.06709747376941866, 0.016429232425927635, 0.042046766367650805, 0.05228286548968285, 0.06293683876133253, 0.03631674279008181, 0.05535795773950316, 0.031473916061522986, 0.015282863244083861, 0.002790738367513123, 0.038519410281291896, 0.018318910865233313, 0.05086742228858414, 0.007898667667646924, 0.02591973647565371, 0.06016916993464674, 0.1660040059998151, 0.15105375419220618, 0.11838201944145466, 0.1557661448755572, 0.26050271346203746, 0.24636813078916844, 0.2061788058809696, 0.14831722683964238, 0.1147261712579958, 0.187633763097467, 0.19640691007577604, 0.18893465700168766, 0.07768102440862887, 0.09901880241569974, 0.16181376552389515, 0.12383363900646088, 0.13312452352575718, 0.10871005214510426, 0.09653499980847682, 0.12637847583861123, 0.1630683723957308, 0.1478830235259187, 0.12630369033544295, 0.1539104807400896, 0.07989190819282686, 0.09113221834864348, 0.19974187467127077, 0.12233326346763682, 0.19915664478415446, 0.19485519898514594, 0.1331126798064478, 0.2578717223819225, 0.17218494126873632, 0.18340062169778734, 0.12291620275185955, 0.15568881596048034, 0.17752581516340857, 0.2703702017184227, 0.12723722975821267, 0.04555967403575779, 0.11904093166512829, 0.1967427783435391, 0.08696023374795915, 0.20645594584845728, 0.04835297233395038, 0.10584495225620848, 0.12077247423510398, 0.07539273510056158, 0.10990778464944133, 0.14982150176600104, 0.14480278316524722, 0.13668413574416793, 0.12236566898683388, 0.10030581480673245, 0.1508824262888201, 0.22615768946707251, 0.12970236280272085, 0.30203246241134984, 0.12305183095797417, 0.20508189054746784, 0.16524447578816645, 0.1351309690864817, 0.25457400498130633, 0.18043508002113912, 0.2188370298714407, 0.24290195065400294, 0.10591073622626644, 0.15293845306000403, 0.2122885256164497, 0.13648072407851297, 0.20407837665369435, 0.1381237834932343, 0.13812202149100844, 0.17468379750367136, 0.22419451255231138, 0.09329541315955502, 0.07286678999662399, 0.11167521843866957, 0.16035020050983276, 0.10462493425415409, 0.1207772546237515, 0.09360382483611185, 0.10067050330220692, 0.14951725760775228, 0.17150024252553142, 0.16373940413036656, 0.12172325829704925, 0.15902382652125052, 0.08400344079540623, 0.19498676692526187, 0.14413659310629293, 0.1028762849408292, 0.1255084527656436, 0.11896950162706837, 0.1107912602263593, 0.12709379511614963, 0.2412682068684409, 0.13287375230462323, 0.1408494170755148, 0.17847115234021219, 0.15771262107356904, 0.08170502380497995, 0.2792477511590527, 0.20654871909608766, 0.19361991285076066, 0.16470881178975105, 0.2537398118405573, 0.11644357184488928, 0.11152452128308435, 0.08295629819434497, 0.14811137901438823, 0.09874662669796137, 0.15608413265116755, 0.09700655756938843, 0.12246222670881018, 0.13563769028311776, 0.23020643350337783, 0.1665695780707944, 0.1665330509985647, 0.1952148313003202, 0.17289669823742684, 0.13488267999022238, 0.1066756060707473, 0.21930523216724399, 0.09492497410505049, 0.13635318576087876, 0.21086913323210132, 0.1413266285653076, 0.15762400002248828, 0.24283104155573154, 0.11917972381437018, 0.13431459515085145, 0.18696187334435602, 0.09359526763399763, 0.18093608620186008, 0.07398305671109308, 0.09179073220659649, 0.19424295683781947, 0.07722813621043198, 0.13067026892977376, 0.11580168209489315, 0.09112116369989612, 0.24598727783849164, 0.23033138244382798, 0.15996530261491576, 0.15672234517912711, 0.19734486216498962, 0.18457702631431241, 0.10381998268947487, 0.0919071392666909, 0.09705196360066053, 0.12181396310728405, 0.1041215915052641, 0.10263505151435252, 0.10726671951312212, 0.11663513213035562, 0.168235206435765, 0.15095987777796485, 0.10578112947123666, 0.10790783551431472, 0.15855403076256477, 0.12778766393180818, 0.14573834506013703, 0.1897581708767722, 0.20353739600508444, 0.18467186799933835, 0.22763332802682157, 0.15006220659180997, 0.16627414392367487, 0.10029844504090087, 0.1064753889917366, 0.11677164899846239, 0.12636158359988084, 0.15072631289161023, 0.08705481496309081, 0.16327965944524736], [0.027778244712540222, 0.044686287836802584, 0.028091463590821916, 0.09687308207034104, 0.01833991125045765, 0.06730835479233535, 0.03182491456579057, 0.043029875509561076, 0.04085312860326902, 0.04493165047719114, 0.0778692215681076, 0.07162375871332423, 0.01716341853382126, 0.05790341893331178, 0.0322710631054736, 0.0009839474096811649, 0.04411893844183895, 0.07358200968273225, 0.019846074583549655, 0.03861708266119804, 0.05901500868100313, 0.043080621173665415, 0.0927012583481208, 0.046201663377184066, 0.015353389298393121, 0.06704858969897032, 0.049090695852834376, 0.018226139532822757, 0.04570169907604014, 0.025016631810895862, 0.03511229935552805, 0.09522869732351073, 0.018793852819550424, 0.034017532898653904, 0.029599477026251056, 0.03363599046884525, 0.036709554373256625, 0.08165800898906686, 0.03269319287351063, 0.036452918749062285, 0.09402727227537863, 0.04798862091716259, 0.04733854551769553, 0.007495998926911384, 0.0076242789134172905, 0.14994923926649556, 0.0272161411046381, 0.06608493535989715, 0.021822700171821544, 0.0139091297000226, 0.03579214110129303, 0.1144282549860016, 0.02747844194903249, 0.06046361582834394, 0.07173885576306813, 0.006450663814546481, 0.03700744383217346, 0.03321094190581672, 0.025580455286187992, 0.06325927367734333, 0.03839399019676832, 0.021199217599426067, 0.023095375227351344, 0.011524214679675718, 0.011980155738250864, 0.029926230762934977, 0.03039019850773677, 0.06270655656173345, 0.039999277646382975, 0.011509983638872304, 0.012448603182189889, 0.05337284006659062, 0.07793541156476544, 0.12621567449382237, 0.0730532251538769, 0.030329530089793187, 0.04441081028011057, 0.024083429466812842, 0.030124532622134978, 0.06744359995448782, 0.03107309885953944, 0.04886506380693567, 0.07231606470961725, 0.027918329635154338, 0.04951130876678133, 0.062244716626141346, 0.10357563128514637, 0.1297007233745629, 0.015012911096545718, 0.040796817310394785, 0.01945902206634562, 0.048391215443130464, 0.019708575207679983, 0.07669186700255641, 0.09343042083445097, 0.021379518307625286, 0.07925057002613622, 0.030849678892522093, 0.05016676593391646, 0.02830200945027173, 0.020178464812136466, 0.03320741407092541, 0.01862952312935264, 0.02642220971474965, 0.028021186515088045, 0.09235667199977944, 0.04929994510847235, 0.015823538415133953, 0.06923609247971928, 0.06393343488114976, 0.02402182642160164, 0.029936959824314522, 0.019891026707726623, 0.02562575981081013, 0.03893137789301334, 0.02261157921184936, 0.03574504967658751, 0.029517871425336892, 0.032179431328850414, 0.0005196560525819809, 0.02761175656961578, 0.041585945328997995, 0.04694040962344697, 0.03707104445164723, 0.028291628958897728, 0.01462998492042384, 0.07249359792519001, 0.009126921593692274, 0.044819315174414266, 0.03247243697724996, 0.01011791952600282, 0.014447304551609823, 0.03581996924514252, 0.03924948441225194, 0.007833060855421448, 0.031181134493841283, 0.010466322907426906, 0.08745513420792357, 0.05830784440941869, 0.009699707340088584, 0.03211950601619338, 0.05675071707716393, 0.0429877138606483, 0.00255212520113996, 0.011582173061587158, 0.04005484966441028, 0.04173738558986976, 0.02828243207336674, 0.03436605693892606, 0.04340384132979859, 0.02587102094454871, 0.0794898882328022, 0.02753503669443871, 0.024503222666680816, 0.07878197702549158, 0.0489786631547876, 0.026609357333772128, 0.05600452062583739, 0.030509497549745346, 0.05286688495787883, 0.07007720339442454, 0.061823448707019134, 0.031426667588792985, 0.023261558850325888, 0.014306538768353002, 0.03102789967200689, 0.0604692465745874, 0.03097390004944417, 0.06351499382646815, 0.05012464641983952, 0.024707934766587232, 0.0371917913998327, 0.019550328255600987, 0.11302708783337187, 0.043971826577739376, 0.057376702841851986, 0.0647196134612445, 0.06954481059144582, 0.017769585603908185, 0.10272657603866632, 0.01863162604070479, 0.033206249617280505, 0.07027255581511606, 0.014881857392948963, 0.026252389089354587, 0.009848552478116848, 0.01897343532032063, 0.04959221914290421, 0.014817942677426242, 0.026970971901450428, 0.06652760394518414, 0.06027538802534823, 0.022453738286370234, 0.02390072132731157, 0.004621673424187447, 0.05728386830718768, 0.07891874670261338, 0.007310661669414972, 0.030940326246162577, 0.08076477345199355, 0.0401161864940678, 0.0194059532406109, 0.010111649096342585, 0.08875944486428654, 0.020003434788856297, 0.0352418486539635, 0.02676710249826072, 0.038321897492653904, 0.004995379732140611, 0.05832254563668563, 0.01777926129439185, 0.05397366750384531, 0.06523753486333356, 0.05150070887119059, 0.012735878492915824, 0.05164210571937504, 0.032004954804095535, 0.047940100738478285, 0.0023487535156985566, 0.048279194236402555, 0.043362591325515704, 0.05381150201203362, 0.04503663899677415, 0.0776483660804168, 0.04099044220281705, 0.023139304624149398, 0.06451211854695313, 0.11978961407176911, 0.057377491912413994, 0.025416502894292918, 0.04433877120215086, 0.06393231256234069, 0.05168247855298462, 0.07758634360206705, 0.06273794701443085, 0.04751111831395857, 0.03875625402396245, 0.04724065863317059, 0.010691852489065741, 0.061598153739807114, 0.023817801885607264, 0.026480348127323295, 0.05977411754429341, 0.04481101461175469, 0.018165252779820756, 0.04380515648893291, 0.020889170325150894, 0.057608789178512754, 0.032672225047023065, 0.0718964706926096, 0.06797226957015454, 0.08594590269269482, 0.09331641162955955, 0.07169947118288086, 0.02155884225372105, 0.07116741545858883, 0.05526244572754349, 0.08631239149479136, 0.034167984906103344, 0.04813249222934247, 0.01881107447608825, 0.06116638275524301, 0.03298970337416376, 0.11856584223888575, 0.01917003646432873, 0.021809241922211745, 0.06074565875854704, 0.028546784118178393, 0.046798196891623164, 0.08517386226524269, 0.02047340866298445, 0.04971036139214712, 0.08202825928287161, 0.04272124932838544, 0.05630142183133191, 0.0765606974281611, 0.007396420903293597, 0.06356817948061132, 0.0247029360428813, 0.021507552667190472, 0.032955271552406976, 0.014551190862191782, 0.07166194053547037, 0.025529602369774255, 0.04486306645576993, 0.03531195719035403, 0.02158519759353611, 0.022481664106430068, 0.06038863114231537, 0.022722801771916212, 0.03217278168566766, 0.021189840683232875, 0.01433025589287882, 0.016712478114171855, 0.08872510114264104, 0.023191975084163492, 0.03454932815305168, 0.027710928566633698, 0.01276382633800348, 0.05033360073162664, 0.03372396034519038, 0.03591900526155387, 0.048675085493032975, 0.03175310914464776, 0.03310292350849317, 0.026448243297636512, 0.06148454673107594, 0.12747745194862928, 0.09249253769315059, 0.048545019085248636, 0.012312614914750861, 0.057132048832793395, 0.015942009124574403, 0.13311447245219063, 0.0468517885723662, 0.004248620684994686, 0.01705831127060998, 0.0485685111714467, 0.011575350091011535, 0.03790408846050982, 0.045362582595478144, 0.01248132854309534, 0.00520190698162262, 0.04670412129452152, 0.024682870284924587, 0.017390190135507334, 0.03764127433720616, 0.019251057923200632, 0.020465791833797292, 0.0488728549211256, 0.041318163125505375, 0.004537671883290093, 0.03424668128812506, 0.005584005782786276, 0.03158663249304218, 0.03949906053622404, 0.027204077135050492, 0.052290078207489946, 0.02944881434462244, 0.038616557890969905, 0.012686835459223198, 0.03865580074489117, 0.05263428534230879, 0.0639304164947281, 0.05652151506153807, 0.017655900071164774, 0.10442694649100305, 0.023425279500623866, 0.03605803106761268, 0.03488801562437608, 0.023873029164068645, 0.05856844453862118, 0.18943445276348822, 0.2583679941392714, 0.12939382855209614, 0.23702740458951843, 0.2443419201599975, 0.14796067419792377, 0.20274025087635364, 0.06799134515946911, 0.08479258796620755, 0.14131381957521363, 0.16328342859783482, 0.14903368758818797, 0.08690237878791748, 0.1931751375236819, 0.212026814659757, 0.0993863330973733, 0.12802548060614255, 0.3325496361620965, 0.16426849509439162, 0.21429671785764157, 0.2401065877488544, 0.1384802288826435, 0.15145388191505788, 0.28682717993374796, 0.21096173794038836, 0.14521708351469811, 0.14939996954654494, 0.17886964063490593, 0.1272834095382883, 0.10951411504779132, 0.13666049427082463, 0.24745084285255403, 0.054039386356429714, 0.11010318303540831, 0.10048101145413615, 0.1651969630151026, 0.16664422567813628, 0.15454860133749826, 0.23594041775551536, 0.10891499598660778, 0.35256582823011184, 0.09710552080744698, 0.08993426367880837, 0.13675463115496023, 0.1631772794550465, 0.12255142998671341, 0.09772183088165137, 0.17041844976765497, 0.09311514501009258, 0.24286534697298082, 0.15950609419134357, 0.31151963397860527, 0.17386760742914292, 0.12528687715530396, 0.09550463453295732, 0.15191951015543553, 0.15183701780774903, 0.14479319174443522, 0.16734495098071714, 0.11886442500737407, 0.16165717715217223, 0.0926099636501843, 0.06148484933580603, 0.16316480754363924, 0.132395391682944, 0.08022560077088495, 0.1901404947162636, 0.19380814065375637, 0.11745450913064903, 0.14486575559262307, 0.11357108686840343, 0.23380571375450782, 0.1589701850447924, 0.1300934966533415, 0.13224183701940123, 0.22759508491764147, 0.20853245781073648, 0.13602444211081152, 0.11052151300734091, 0.22694234736263755, 0.16214701377095717, 0.2002569768697985, 0.2273902023631719, 0.08732448557331678, 0.1386905046961, 0.17319213238454637, 0.18117440083334524, 0.3092685918654165, 0.12757546523766172, 0.13350693929579951, 0.12032067388175957, 0.15756864250907976, 0.15501406103853257, 0.23431663311296896, 0.23375806308561758, 0.15671825426961147, 0.13833487135989053, 0.12598655291742858, 0.15699723284811745, 0.16505275462423602, 0.098443845767648, 0.12518185416176436, 0.1251075512939884, 0.10512702827972752, 0.16801259660672757, 0.1623260485188615, 0.20616025123144352, 0.11700021899155072, 0.15260797805122792, 0.17029046711902465, 0.2059545413020157, 0.1414003875106573, 0.12143739258810399, 0.11235899787636534, 0.1260273470993965, 0.16113085942643304, 0.09709621283916697, 0.10038293687806976, 0.19274337036955744, 0.07559073818547112, 0.14561863616108894, 0.13309974824228596, 0.12670794727220652, 0.13816427890091174, 0.11320524924104253, 0.08601100484450018, 0.13120161219229623, 0.062495683199696006, 0.13584160756680275, 0.1863681245595217, 0.11884571714026314, 0.17558362905777272, 0.1441770731922119, 0.1649471570647532, 0.09443320694469637, 0.1488075077894234, 0.08662486343734688, 0.19513400902430858, 0.16897198383606252, 0.09773288553039874, 0.18931362537607072, 0.200853223101266, 0.15672675784557097, 0.12003431787654278, 0.13461730713325162, 0.14461032655690947, 0.11577902887497218, 0.18489184248591625, 0.12091832971500775, 0.08796223078764255, 0.13783198060287585, 0.22811139753508955, 0.14187226702849712, 0.20642983757199782, 0.10929163545370103, 0.13824625030880974, 0.15684580790900415, 0.14932542919151245, 0.0840352564269016, 0.14491815600664387, 0.13409364007173047, 0.2505782589076027, 0.1353073684919265, 0.11929066866756448, 0.10813356332120397, 0.14952058242934366, 0.15564887213610834, 0.20678000104042793, 0.12535054672269091, 0.17255552864122778, 0.1883368785943716, 0.18645334418021864, 0.14620731344386456, 0.24198468293874498, 0.1656362531526435, 0.15639904075332228], [0.048052439871694774, 0.04218339431850661, 0.09741115158483868, 0.016510468389418338, 0.019755007796770623, 0.03805735584108099, 0.08147499058395624, 0.042056633580115535, 0.014589314270133694, 0.05519783770244929, 0.009201904364501037, 0.04609029334519179, 0.06837323998972293, 0.04138747876089427, 0.032877391054024624, 0.0344113787005265, 0.04883941901367038, 0.005630426880558052, 0.01829289834976437, 0.06903016804567269, 0.023995815821352507, 0.007591904995347103, 0.0393217992818644, 0.10089888177331417, 0.0033259865238271175, 0.03076657942015558, 0.0292580584514766, 0.0500558823677561, 0.011309211146116499, 0.0063978080570157025, 0.022331805817121943, 0.023267637758005052, 0.017211672496951876, 0.03260623040278593, 0.027730668737222592, 0.0022866893813179266, 0.02776028761159509, 0.04041760378787595, 0.0321229993771281, 0.054737480146990675, 0.017080675292339538, 0.022724674856891076, 0.026985552469869296, 0.03356796569160877, 0.029158507240936164, 0.029950693865577062, 0.05846372414981166, 0.02790164424016351, 0.1064128379127191, 0.11353178655788784, 0.0319173239216569, 0.02235378679488936, 0.042462537605916305, 0.023148662388144482, 0.022492119291376685, 0.0378519676685814, 0.03634920959631282, 0.024898813233800957, 0.02892722912703551, 0.04656981075963667, 0.035076607319135825, 0.07382580184287603, 0.031148508724365986, 0.016126614289298173, 0.05203679038752472, 0.0462664399416216, 0.040950552004599766, 0.02047488146701888, 0.06512333413646107, 0.03397373182158317, 0.019662025790180893, 0.03885321394209901, 0.05050528486589751, 0.025757923384287187, 0.019111292842294902, 0.08724365563642594, 0.04168747496160288, 0.09215984102939406, 0.026723799378340764, 0.047534526130484964, 0.024245234897300124, 0.014700135591650202, 0.05393535544675204, 0.02747565530420792, 0.022560042561963204, 0.04113533241193622, 0.027550381435562047, 0.011457267213582752, 0.04848330687250822, 0.047545193904830564, 0.036515186375547806, 0.051854438478908235, 0.054484939262751615, 0.02203383400375324, 0.021429585983916637, 0.032604307522095984, 0.061607883056445475, 0.08537625503395835, 0.01647668008151795, 0.03725115555308519, 0.05884115268746692, 0.014601285351560482, 0.052733122175859834, 0.0365016381106069, 0.07360306177889148, 0.03262612570617949, 0.03046932581421589, 0.03427735927905287, 0.037513751341330434, 0.0318723660518205, 0.017816075649593147, 0.010174586092151943, 0.011791698108877868, 0.016070088491805138, 0.09722086300532665, 0.014064752800960936, 0.022850937638131362, 0.02479164327885355, 0.038523830608614994, 0.034155264016120665, 0.04668977629813937, 0.04022594391097946, 0.029451568430710225, 0.09242805607256391, 0.05333162453626433, 0.07949251591438249, 0.14004477960688455, 0.012069232611646576, 0.011928323186903953, 0.0486442887584769, 0.013631337600189352, 0.025808669048391526, 0.007705270207577175, 0.0355968231545581, 0.0651468223922195, 0.015262135777682548, 0.019035666557629744, 0.07827674970030785, 0.02214617696740935, 0.02011576434597373, 0.08584627295814215, 0.04800504584225917, 0.030109023172107917, 0.01261731202248484, 0.05599443507831424, 0.015932159149087965, 0.06250511757248352, 0.01822054709097551, 0.13463327240559364, 0.01260528156924392, 0.029043682152405385, 0.10606252888758337, 0.0042458627684672755, 0.030973499768503734, 0.07018357470271087, 0.06169040987808859, 0.027278188480845383, 0.0662883623473106, 0.03859929409959624, 0.03978891373281518, 0.015218757006580071, 0.06554894960455357, 0.03883737890470413, 0.04393690829015067, 0.03740078018557641, 0.04188815552380778, 0.04900895044087403, 0.05981119619982858, 0.053145706488360325, 0.02303888007337528, 0.04288665537211684, 0.018909183526111227, 0.018141358497462446, 0.018270691376059287, 0.01741355007153846, 0.014962899919238784, 0.019681015194603996, 0.048638106428927956, 0.09674716785910631, 0.04265648425526677, 0.021196258584818533, 0.04259049344146925, 0.08063827701393636, 0.029644984564173128, 0.0866092429045708, 0.03679136490269053, 0.08218558309900184, 0.03334459743552631, 0.042820519001613704, 0.023298645166740305, 0.028066263128552708, 0.03964504625107493, 0.007478071511873315, 0.009957876097741387, 0.04884786130259595, 0.019202696707760616, 0.08992382190040044, 0.03698069204185759, 0.04302715206699025, 0.11888789794137401, 0.0414447553245531, 0.015272139928363746, 0.027653981420782306, 0.06509858183562756, 0.07182854167636364, 0.044991489604956685, 0.002865900690179138, 0.06234214002747209, 0.0515283263408609, 0.054244556193870884, 0.040095724285610264, 0.058605147811073455, 0.05072661915854101, 0.0749808172845552, 0.03397300786849472, 0.05843033420763189, 0.031057198704670996, 0.03786087344070116, 0.03697926328787881, 0.05715087927397221, 0.06729574498510169, 0.02158574343118216, 0.04262197582471756, 0.01160483681521709, 0.06414192954018232, 0.11520057120510649, 0.024669806570595792, 0.03276845718163156, 0.030357509536007722, 0.021456709326875788, 0.046460405743170174, 0.025708566254545605, 0.05717184710045976, 0.031756696351353204, 0.027599179321118904, 0.020789069446524786, 0.08529987606790759, 0.06287711837719526, 0.03846841946905179, 0.017719175103270722, 0.010314915205291923, 0.08835290498550862, 0.08617447268578314, 0.06409381155765827, 0.07969378253384944, 0.04717993850429212, 0.04066755912537056, 0.01978825792790421, 0.1048645818786275, 0.04860396955102202, 0.005461521251427551, 0.07506868756947017, 0.029599113134487025, 0.030371197611994805, 0.013994610748223722, 0.0688174254291, 0.08119191343505537, 0.05337596570532169, 0.041658995643017754, 0.018029065329521414, 0.012189543847325108, 0.05421659015419503, 0.06408211722549412, 0.03670144150213849, 0.056277328366113294, 0.011121153797683938, 0.054607329469534664, 0.03151032439012441, 0.02975249351302703, 0.017233707100873994, 0.046233352604171926, 0.05984883026910886, 0.026840103016565406, 0.0697771497371216, 0.021770740258357218, 0.01718900970093185, 0.032818566992758744, 0.014137417198188845, 0.05133256406312989, 0.04287693371635772, 0.03337477746930334, 0.05358987277553928, 0.04263144467146166, 0.027210782319607756, 0.007076903824664413, 0.06330919962736868, 0.04370941848103558, 0.012221509823575618, 0.057806328780228095, 0.0731903012661684, 0.054484671131978114, 0.07574488273671559, 0.03828657317846533, 0.05107054284082786, 0.052748620134568026, 0.1061987316596412, 0.036930149391053185, 0.015316895742510116, 0.08144908149035708, 0.10889859404414894, 0.016902280227851965, 0.05423057125881315, 0.05773950676103273, 0.046328975698880615, 0.0353253215941931, 0.0846939847894734, 0.017628998893703667, 0.05850181021096726, 0.046122587781639836, 0.013209741220869606, 0.04199977453437544, 0.02009309005863484, 0.03770183358762053, 0.04910942287214341, 0.054712214567247903, 0.07808658369486371, 0.06121153214706048, 0.03828489927635078, 0.05052778486823363, 0.012329240937927559, 0.0875606628194932, 0.07896430595147033, 0.01832349207102051, 0.03971582894483882, 0.08645830060084982, 0.05710092268042988, 0.024632394666813558, 0.061473120529685295, 0.01903461893239329, 0.010324618666462842, 0.06961208843295613, 0.08190337162945541, 0.015341616442216741, 0.056653404758582195, 0.05924055645723016, 0.014377801224679477, 0.04530445184378375, 0.03558941891476993, 0.012775316699257782, 0.019485120766706044, 0.05094861228679938, 0.011346602940090723, 0.06026545952584955, 0.04201340706898801, 0.023418254474358215, 0.029147879686206583, 0.011308977489299592, 0.062385891308827754, 0.054464480884733706, 0.017963246885506857, 0.00683313368954846, 0.014826603301410234, 0.13173329253350535, 0.11867170792914207, 0.22397890476690185, 0.09198750188994793, 0.07840153010141465, 0.11592739712326758, 0.17349654508213844, 0.08252446975318656, 0.1153147949146167, 0.15163268683658493, 0.1316954324682874, 0.16677435337295457, 0.33241719488174687, 0.11103371173263558, 0.10785684470207461, 0.1082443702785719, 0.17982723521849803, 0.2383817561090954, 0.13323297093231834, 0.1913466082224923, 0.11379764205025089, 0.1069053328566013, 0.18075040181077298, 0.2559014361712241, 0.11644624549174502, 0.13223704130899522, 0.21764959358880598, 0.17098255094981965, 0.11516797416392835, 0.11419483565635259, 0.07256103664516442, 0.17494628987004682, 0.17452598339126957, 0.10880179117403685, 0.12862645360010286, 0.10394515379542306, 0.10073955846770156, 0.13494540726946247, 0.13643328791424153, 0.16451122239232063, 0.07084435618091976, 0.14799816654093806, 0.109811257570982, 0.1399071748939253, 0.12948608085993799, 0.09405630700770887, 0.2064313544260879, 0.09672338848993664, 0.1836553306108521, 0.3049342502509394, 0.17345796489427168, 0.12683864187208876, 0.12279449436332911, 0.1538470946252346, 0.2509876256508212, 0.14285195558782549, 0.11969330915880781, 0.17792471714558142, 0.1609179635922755, 0.126362725070888, 0.21147066547024637, 0.22320734697484204, 0.11016607119311249, 0.12858585094011601, 0.15008543437767416, 0.13050672447969838, 0.22781084592063583, 0.19103094935417178, 0.1604618501639174, 0.09375829114428452, 0.10985428872968882, 0.06499529786167607, 0.19077755811233676, 0.20650879059347416, 0.0505003244465878, 0.16445637049694217, 0.12496936435420668, 0.21862957326154556, 0.13046354776428593, 0.16277263181344157, 0.12956019220573287, 0.09153321941172884, 0.17405591184093108, 0.07946017168221936, 0.18281283307700388, 0.1842727361907882, 0.10816517976983901, 0.23608770581983754, 0.14134113827059347, 0.1436783805970223, 0.09588279085414064, 0.14096636805803547, 0.0748818617073759, 0.09279975427254554, 0.08280314955740206, 0.1872192329216388, 0.14928989803358433, 0.15648326445971766, 0.12167606728091357, 0.08574648234512537, 0.11825256590400973, 0.10577526123773669, 0.11949892966978012, 0.10342116497697369, 0.1045842549853748, 0.16932677447555528, 0.1467851888869078, 0.14155218017197427, 0.1008498827896772, 0.1970667875702343, 0.12478938731815546, 0.08553190877841366, 0.11152130371380238, 0.12043601607963925, 0.21087880126170575, 0.1505671504644617, 0.1673415035850579, 0.15662699787607118, 0.11523407989091451, 0.19257979527596505, 0.12351801844253657, 0.08535191642060395, 0.16031517496993467, 0.4421916802323634, 0.14446346750182493, 0.14580399879524786, 0.2304701056451567, 0.11547299973185986, 0.0757740400431137, 0.17586181090483743, 0.1052240839588546, 0.18636915111734023, 0.18406351757866724, 0.14048440682311214, 0.18554960557770345, 0.08879604088442941, 0.07978670899906466, 0.17568931854780645, 0.15662203362632185, 0.1309307847893046, 0.2611768401918873, 0.18827994293983907, 0.1323218319204546, 0.18316992198026952, 0.1986762923338721, 0.1778502074340659, 0.19006014741476507, 0.052101360108222694, 0.16369337756787578, 0.11133779501242023, 0.15495337155317107, 0.19526214489052374, 0.10994009823808748, 0.16596997637421856, 0.16432923054502857, 0.16811943522864775, 0.21572484364432676, 0.15112437217706634, 0.16611040029073917, 0.12784492900414815, 0.11156761372882514, 0.19581008161748611, 0.12316394792569262, 0.13452529997354554, 0.15489491904454847, 0.18725410524395206, 0.2546993522874771, 0.08683290227406448, 0.14836143011287337, 0.1804857031111756, 0.13805296632551378, 0.14580603658912644, 0.12072359016465566, 0.08308445704319785, 0.1694927550852299, 0.10957763905847266], [0.040178867808032426, 0.04797852004788095, 0.0075916895331184, 0.008406917688496893, 0.026062267133966092, 0.0704779363267364, 0.010793359139032904, 0.03792198044398139, 0.04242156339328616, 0.0076127028460764605, 0.11809334218982728, 0.027471572055571505, 0.04740912902859911, 0.0444243279015345, 0.03780568063619637, 0.032779668878403403, 0.05586776244003446, 0.01570991321181458, 0.06361158985284067, 0.026595916321140625, 0.02782520207185899, 0.012333473573709208, 0.024618218209774747, 0.022877953728781115, 0.02360176700617998, 0.057049602450382327, 0.051104070678834, 0.012872638593938564, 0.03155765521730627, 0.02352711173795885, 0.07912690811339887, 0.021825735795221502, 0.09248941205441953, 0.026948567660104845, 0.03126056440505049, 0.06135045070080988, 0.043131171485349055, 0.03188008630287743, 0.06071824430217666, 0.016572402767656792, 0.03572446489406209, 0.018314955936324213, 0.09193593651176461, 0.03803572534853893, 0.07187368723774148, 0.0191168048449101, 0.026277903647672747, 0.017750519590692657, 0.06910678449897997, 0.048766226973384626, 0.021971321229131955, 0.06794432268267678, 0.06014671589758608, 0.018272815354829355, 0.03686876659612021, 0.05739280217958074, 0.03004060769003005, 0.0908112351692492, 0.057518589986307975, 0.025206292198309978, 0.03657207606480487, 0.09996160384147398, 0.06066350731998683, 0.05485787852517059, 0.0074845076080471765, 0.003576578911311264, 0.06665662081251222, 0.010233791282160148, 0.035617377293566545, 0.034676498748482235, 0.060964706278736555, 0.022656368542342417, 0.05072864929154035, 0.09201834458977946, 0.01926501604518102, 0.03433447113380798, 0.04342467126045977, 0.028179119371118087, 0.04660433068150475, 0.01925845258688975, 0.03126183419578499, 0.01023226676719083, 0.02700825740072516, 0.049407074843803724, 0.02098642135669868, 0.02008222310142892, 0.013463740544994513, 0.03497458355981977, 0.023198391070529338, 0.008830780730462603, 0.018115838193484855, 0.03494688182047779, 0.03816692556645121, 0.04035445899071713, 0.06983138110128141, 0.07599947673659171, 0.04854415723633382, 0.01720501710810969, 0.04770465510626955, 0.022222814488134558, 0.04030585071192153, 0.07302471136133518, 0.021617963174057585, 0.05421709960266467, 0.029069928324691234, 0.025743501779112606, 0.08854520071538226, 0.05464230521371769, 0.005909390616110496, 0.021959443035865986, 0.05896830030025975, 0.049710012822141575, 0.0495594114275469, 0.05004508435846337, 0.01439794167620881, 0.04241469924548461, 0.04099585461400209, 0.02278253173215255, 0.03183060085340854, 0.06108546471824089, 0.04762058844789863, 0.03569061912956738, 0.04165554441691887, 0.05436574364261282, 0.05690915172078437, 0.015207407413981857, 0.031093486374424353, 0.03293379044701015, 0.027181243884467313, 0.06916650871355688, 0.04718536623723565, 0.017512383074649883, 0.08906289995197328, 0.046824374115995826, 0.0486120556090628, 0.013829627968070489, 0.04445864481010264, 0.06688444003943475, 0.01778778019210985, 0.007780783973078454, 0.05796630326057634, 0.02028828160086226, 0.02519794758559475, 0.031098241865214322, 0.0013492752294687015, 0.03419328495980271, 0.008981149425850281, 0.06373853828277319, 0.04939167647652569, 0.04932480466161524, 0.0690337686589168, 0.03906178904036361, 0.08246716637645038, 0.05243798297259116, 0.022415613920818415, 0.021158461721854347, 0.023472307723075635, 0.06889979520271863, 0.037337643049296834, 0.01623850143063934, 0.04702527684369876, 0.04994025288690483, 0.04104348230025461, 0.03599481732254067, 0.021940160602811846, 0.055011364240800185, 0.03829000525236611, 0.03854030915986627, 0.059054623087567676, 0.01630767342454243, 0.028913159922306097, 0.030345114233392863, 0.023187116171503742, 0.08184015405394378, 0.013135254491991816, 0.060617971053767594, 0.0254811090041673, 0.03198002630303944, 0.08136148699709485, 0.04457942240180508, 0.04472180750341185, 0.043141919698926716, 0.037515693374218485, 0.022851652015120755, 0.012242652892675853, 0.04200313382992341, 0.0660173817267341, 0.052183408124913136, 0.09406924623274997, 0.027330246070520054, 0.03140804782179335, 0.03554583617275761, 0.045339144135434786, 0.05627834343261296, 0.028521227425024397, 0.004823311117492737, 0.05686871376970122, 0.03806014440112537, 0.000530997685047858, 0.041749351883247014, 0.021150481000903155, 0.04217152378611988, 0.03921986362265964, 0.007595690906107907, 0.04114700376146263, 0.060680414880475694, 0.053095443459648284, 0.03620424277840122, 0.024566325329003796, 0.06588571419518802, 0.007872048027497988, 0.02519849150802099, 0.04155971447847063, 0.03881368380520613, 0.03834345520684316, 0.04141958933624049, 0.04024170233958191, 0.04619346623639426, 0.1300825109525073, 0.02420351949460324, 0.054156348830269235, 0.03660252805979502, 0.028776641138979507, 0.08158511572307156, 0.032010945611663406, 0.060224125251895, 0.024550361971881603, 0.03959837234428814, 0.011184485328774299, 0.02019685475275882, 0.010643891554566161, 0.07690270206019764, 0.014958953608818834, 0.04173266648825619, 0.06262580706407467, 0.02256028771009897, 0.04312536070844339, 0.015130345672068578, 0.01709239835280084, 0.018916329211224953, 0.01486753537920454, 0.09140372756988772, 0.04656095095279236, 0.011346463129044542, 0.033851387580075575, 0.025648692652823466, 0.017129588091085036, 0.007801356785480054, 0.04489408918626366, 0.050255233767412366, 0.05013836705456338, 0.007657301612198354, 0.07261922868389277, 0.06098110056031616, 0.03601999480217215, 0.03531923119519507, 0.06882676404089698, 0.053724217784380725, 0.031460840855875326, 0.03731788947216926, 0.03348558059623165, 0.04640076962870456, 0.07053557678215927, 0.027864031238301147, 0.06070815109377427, 0.010904469658740827, 0.04459197475244442, 0.07511571770714176, 0.03898369786780208, 0.017358732650116566, 0.026288353086959933, 0.04679818923074392, 0.046000358453320886, 0.019213948624148484, 0.025727348815229152, 0.00926500702682402, 0.044009927960653464, 0.06257221155289201, 0.020927078270864104, 0.07891034271808402, 0.04129093253023682, 0.020604055382371433, 0.004240214306440566, 0.054457294980003956, 0.02642081926516708, 0.031427136817646605, 0.008893002391672664, 0.04235169234415216, 0.04617653952370729, 0.040598948290872, 0.04486332309522456, 0.021299864315698226, 0.07622749514637456, 0.018518802356876193, 0.01998255506248003, 0.03769131136998054, 0.018056648325235132, 0.04304204098579865, 0.02244892725420575, 0.03847020445391536, 0.0382228882893199, 0.033100801444942915, 0.03240211776668026, 0.015803143239369797, 0.052017205349740483, 0.05551707037093659, 0.07679956364295176, 0.0590785212003656, 0.055330259830600796, 0.03594480710284364, 0.07507262526140099, 0.04546515793809968, 0.05209386010744399, 0.0633782854363803, 0.017329196130195935, 0.025781304387736226, 0.051102649585734454, 0.015126648340224019, 0.026920925292576996, 0.025983365823424635, 0.0360006932169199, 0.0538679818442512, 0.061151934336991086, 0.04991496432452433, 0.029270675919589498, 0.06664154420216238, 0.02847106398774251, 0.04626793764351357, 0.03401362201980045, 0.023837067081683108, 0.02293857809666905, 0.06102600480399786, 0.034768808512918414, 0.04451724670587048, 0.02384554001412565, 0.050086024097136916, 0.017295093726246588, 0.08977667939278389, 0.06603262687642729, 0.03726219104963445, 0.1102017785512632, 0.06403533606639793, 0.022099120016660423, 0.050770010378572254, 0.01668181161456291, 0.08795823946955704, 0.01635316947114564, 0.06911565579714314, 0.05050251545805124, 0.05812173866997323, 0.04969178759042294, 0.02599706539073058, 0.14851899907713936, 0.0933022466638396, 0.12564533735595404, 0.1366162450323182, 0.09668411882293802, 0.2912782427043684, 0.08794813476983579, 0.13342950312841323, 0.11466931987313495, 0.1328842017439104, 0.2600557777670122, 0.19372164932710512, 0.22746330247290675, 0.15427336126806276, 0.12055713458046799, 0.0984010904005939, 0.17548584559511754, 0.13042297574781603, 0.10786013121926978, 0.09274241259141315, 0.14903433110204437, 0.12484697414742363, 0.10835212054512194, 0.1548009966650317, 0.11559986389212071, 0.1967504392227819, 0.15854413290658306, 0.07560855739058987, 0.291441572649825, 0.138276326920717, 0.10389394081768491, 0.13406068296922793, 0.17680696422053924, 0.10717162501908119, 0.0988123876853816, 0.1392241462223953, 0.25323712026640294, 0.1420638196530842, 0.31008505773159767, 0.1525707461781079, 0.15743425536540248, 0.11094583378684138, 0.3816510610763104, 0.06847896778415288, 0.22080149381391465, 0.10958429636253465, 0.15365537346130417, 0.16001643132298224, 0.1555426463845276, 0.16843946079813665, 0.09703642733755613, 0.18081435483069191, 0.14376337039134196, 0.0961639834267478, 0.09780849074764598, 0.2140331682899306, 0.10154686958318758, 0.2633856555386897, 0.15378764620231045, 0.06843351578760533, 0.09017005022014342, 0.10812718946967395, 0.16165123230987982, 0.10601427300923294, 0.16359341841551567, 0.24583862613766427, 0.19494772708464056, 0.09976918553753246, 0.14029095430047284, 0.16071062955644824, 0.14913805940699193, 0.15486706408762163, 0.09207839822216381, 0.13064996759978034, 0.11610717497645848, 0.10684766175766146, 0.2229449158955005, 0.13043212283763195, 0.15701094582196207, 0.1721553702748591, 0.1536805930757715, 0.09491646286821175, 0.14569798754828592, 0.13145002386262342, 0.2221657585112318, 0.08791275682949251, 0.255738565878522, 0.10556370605744662, 0.15580979656548272, 0.0774998369536573, 0.10976503948651015, 0.18398436537433058, 0.1909037787587412, 0.12767678802652707, 0.1249005696586063, 0.1101818755869904, 0.14113610249853906, 0.11721224148547459, 0.16084426593395973, 0.14712542385583924, 0.14363446843720254, 0.17884448230747255, 0.08850531817804422, 0.17575285788024628, 0.11412066302352375, 0.07862839937931107, 0.11110386240386194, 0.1476207916294375, 0.13212945192090927, 0.14257578089112236, 0.12752448974718011, 0.12645919086231341, 0.18356851752727263, 0.1411400861557453, 0.09557905231392193, 0.24152432538328633, 0.18319511095121985, 0.09251223381368384, 0.22808326678650997, 0.11718565823450205, 0.09445634280000964, 0.11206010101182808, 0.13839906952794523, 0.13861646995909754, 0.10503727341851882, 0.0942623463549441, 0.12478420856378733, 0.12177890692386897, 0.15071338132744835, 0.1503500564684791, 0.10059882811601124, 0.09198371741560199, 0.09931459662414367, 0.14369992298945305, 0.1898340748683099, 0.14783108276465248, 0.16349856140873126, 0.12645878483571354, 0.14081785425303445, 0.0958456126071753, 0.12698907089690048, 0.0938004183192407, 0.15422108342810986, 0.1121050627121041, 0.11013658446890694, 0.13866543829921754, 0.15774029216939406, 0.13877808386760374, 0.1440113836959485, 0.1819299780313046, 0.17823364976192677, 0.22995501876838748, 0.12857641273688886, 0.15398607829645758, 0.15345586884406306, 0.2054775749603587, 0.08757134208515768, 0.12781634626369323, 0.11324952912306595, 0.11958067125130085, 0.17985489099256455, 0.1638637095569603, 0.13595094363535606, 0.14302755826182906, 0.1757775259114081, 0.11039920707022953, 0.10906735555298867, 0.09648204015027131, 0.12458578413051945, 0.1455411846719442, 0.15604794265762453, 0.24156148064761396, 0.13821004499350825, 0.14727055155221494, 0.1310659839861816, 0.14389849297942656], [0.024009888856521538, 0.03318261580481645, 0.050253981213656165, 0.03472029599511335, 0.01949927807154675, 0.05753475827194991, 0.041107144206762314, 0.010804204071210998, 0.06562591079742679, 0.06945199903941925, 0.039965634895188194, 0.017484811570255027, 0.03449660215166307, 0.021052371950880177, 0.021410399311853033, 0.06934666194983068, 0.03193497841787194, 0.025104479113173102, 0.014316636764804923, 0.05367842487870686, 0.054076782938453465, 0.002401404823514543, 0.03654191135278633, 0.02316932952512176, 0.10620846097627956, 0.030351430628328558, 0.011709495916992668, 0.03382278185698294, 0.022240976517599438, 0.023223888391869205, 0.016981076201303832, 0.03678847292077638, 0.06961860784119175, 0.0064060487690561965, 0.04233995970759181, 0.011533196102978002, 0.05862071471769483, 0.12720857040896533, 0.030715360696757996, 0.04764445591717959, 0.012637777103772087, 0.054289831990195866, 0.04364543481759968, 0.027926904074246847, 0.010076080591628149, 0.009933331598257347, 0.050537226901900385, 0.04026059406779466, 0.019486105189688747, 0.04708796581854263, 0.055037235030003136, 0.009665216146517665, 0.04120905688332935, 0.06737437624964984, 0.033076359409718745, 0.049546759485477404, 0.038796841362190825, 0.051004774192528385, 0.030154101700792392, 0.047320550112354184, 0.07090002012949798, 0.03461294026384431, 0.023471769546308828, 0.09634168518166389, 0.015239917312658604, 0.0282359994842761, 0.0030310486580410433, 0.007470700309626879, 0.02523399393765196, 0.012546100319483349, 0.035212737312840844, 0.03740214765252125, 0.012817905442188344, 0.09582862077701478, 0.024245286608235012, 0.030847095260997454, 0.012239966796891344, 0.03337637859306509, 0.0640267750338441, 0.05515080756477772, 0.09258231553699701, 0.05539350804962939, 0.034945250053199074, 0.01876947973223944, 0.07813175223887929, 0.03220356309846525, 0.021485458691454223, 0.012803725154709913, 0.12056606716566509, 0.02795534317321595, 0.05034913699473104, 0.029992162204918363, 0.028450477289997285, 0.052598639271192016, 0.04936978168364975, 0.07169410090653167, 0.07651873879254827, 0.04204012821578691, 0.06370407198705981, 0.025763276423658096, 0.03367551294485888, 0.10424464054766203, 0.08011216613193674, 0.0855716840634423, 0.06085319835091792, 0.03693611338554371, 0.016690491390745008, 0.06795667968089543, 0.030172108597452604, 0.0325248105781934, 0.011154988070859784, 0.022847591749122067, 0.05929850334782274, 0.017741339942139965, 0.032857373176563176, 0.011706195035648924, 0.021090689753632874, 0.061901513066503315, 0.03063162537141433, 0.06921769870865731, 0.023256560126619957, 0.046238190449413755, 0.13348060119296276, 0.0731672496805268, 0.02528001858492292, 0.04296842759715454, 0.05122548795395321, 0.05895472905268112, 0.03957415247456201, 0.021904566242629965, 0.043101857130926464, 0.09004855633623178, 0.016145195751901598, 0.05241993011065549, 0.024693141608769377, 0.026345064660774607, 0.01868166690391879, 0.04259169619951037, 0.04692791472940196, 0.039973272791793274, 0.015629290118663302, 0.011896560223953379, 0.04633932937717727, 0.02489363830987244, 0.009295813337479149, 0.07446104194968939, 0.03526976489792428, 0.045175335385025515, 0.009809436028703086, 0.02923919162112138, 0.04196166932102173, 0.06513332392299367, 0.04722440607785698, 0.021665326559976227, 0.014314708138455548, 0.04412548466315193, 0.04318855913175691, 0.035241940584514415, 0.05201059018051432, 0.01063043617778608, 0.0337173949716793, 0.07134503294383326, 0.01631884107125863, 0.022138623340475946, 0.03833719626850179, 0.004612908899528726, 0.011969354856128414, 0.03741732768474087, 0.013419674209979995, 0.12006121522356426, 0.03480048241814779, 0.07866043717630448, 0.04809068681131448, 0.027536494176714655, 0.145812364475381, 0.05536304839376, 0.058234843891114, 0.057700076215570016, 0.0480265116258975, 0.04433667978211757, 0.020025611119044405, 0.09442015280646664, 0.08845033604771861, 0.03855916641412243, 0.011430267402301393, 0.0774539865913891, 0.04417159166487475, 0.029930327418110067, 0.026430253637954596, 0.0563331340409575, 0.03803869393924552, 0.027372503480423364, 0.037534133110555916, 0.04335596466497068, 0.037229865969669436, 0.04854686152670653, 0.02948556358235017, 0.010604109566268182, 0.04395161334785723, 0.014889125652130575, 0.07222796459832499, 0.020073577799203417, 0.06880404187306281, 0.03056514617656508, 0.08091015395738425, 0.04452029190536949, 0.004262097129192685, 0.04524933947851101, 0.04444074133531221, 0.03894549306301821, 0.029950766643929868, 0.016628382727503777, 0.033609242508969, 0.07692668827310686, 0.05849307297819084, 0.061094550521022854, 0.049785828713567994, 0.0466810122522856, 0.03554610430353111, 0.052697104552099784, 0.0055357690566339565, 0.04500865763533981, 0.02142183317412292, 0.004930646738953768, 0.07621909882272444, 0.07683056722124738, 0.02437677219389908, 0.05098758317950753, 0.05217464790949899, 0.05312386915207871, 0.016914016694851944, 0.034436291879824096, 0.04109779410364647, 0.05661534551050394, 0.04438727222863705, 0.05038307085933705, 0.04243529934976851, 0.04002831620915283, 0.005331780431011031, 0.07788899429743329, 0.02477963102020083, 0.0705443178453753, 0.04352050885978726, 0.03579170826161581, 0.03679314222667487, 0.022346474485652103, 0.06036725728922795, 0.006618276670304758, 0.10875115276224191, 0.1082191200205876, 0.08079221472144127, 0.06120665982786206, 0.043782656486596794, 0.04096685818606808, 0.07184832206656856, 0.0635243286078255, 0.061234533936987, 0.026520364730048086, 0.062171348385633006, 0.012407759204506876, 0.04605102367819317, 0.05160612256957158, 0.032478868285374295, 0.01907326998339305, 0.12401068958664134, 0.012910709333335681, 0.04610140545053348, 0.030515344715827418, 0.023223174014879812, 0.04220852583286263, 0.02424386168469585, 0.030364994215027943, 0.022483295873708786, 0.05367913351003682, 0.07910232435190871, 0.04432918744221811, 0.01827593907834061, 0.010111797525877915, 0.07001959358251865, 0.0883773508511724, 0.029147971616757494, 0.056754497721070246, 0.010185630207190351, 0.12761310313738164, 0.06337808242308036, 0.015594718485860335, 0.02188546384023803, 0.04537373300521605, 0.047476460496264125, 0.08540741949071808, 0.010651790878675398, 0.0682207655101534, 0.024244727364050287, 0.02392142293824544, 0.06344647875296013, 0.06738324754781301, 0.06530057623862259, 0.047005971428006894, 0.047305442858487375, 0.08477611707583552, 0.08513203386457698, 0.036799332217103055, 0.061750670354212486, 0.017563128738754222, 0.018273525901379126, 0.040127765913043296, 0.05369864576946824, 0.09244321695258541, 0.00839449461519478, 0.04628864116966725, 0.02651870614969202, 0.033257106364133864, 0.053140060420358376, 0.014908966371759534, 0.02482267558544634, 0.04939356871369866, 0.04692247550513956, 0.023524259975660714, 0.022220539206999446, 0.02384051447734237, 0.014698220371839502, 0.048985971633585236, 0.023712179428266904, 0.04790127157203613, 0.02476682394532667, 0.05736714206455697, 0.0605016750764222, 0.025106721835571433, 0.07245322509158043, 0.04183957788852915, 0.05780554354010571, 0.04210598113375806, 0.04662242184783663, 0.060624505783761704, 0.012745126131771794, 0.03533973553848844, 0.08116081026532958, 0.025361901892709638, 0.012331768070467779, 0.004913395396508878, 0.017869904817592715, 0.02755030865720924, 0.0125790047534411, 0.05426043719654122, 0.08054718149886017, 0.05349517664721897, 0.011705138791923322, 0.050048052949169954, 0.03076319905718969, 0.09897298269694853, 0.08878690145549276, 0.030865780145470655, 0.14712125633753118, 0.18319160226852665, 0.07901047040978748, 0.13387386476801288, 0.1390829715397089, 0.3070905426096532, 0.12154675163929501, 0.19862101142925603, 0.21311056860271962, 0.2013418033358551, 0.11514943483616076, 0.08329941365387171, 0.13595327254264586, 0.07150245635139366, 0.15865526162087917, 0.15798922477950975, 0.19031016786973323, 0.08875949849044124, 0.08820964654366817, 0.1756010039318954, 0.180713108650619, 0.1592009000840687, 0.17659696419873547, 0.12563810548594884, 0.26207371464660095, 0.11302475126520281, 0.1474249795559914, 0.07566704820360869, 0.1858823941720109, 0.17607463013020255, 0.2308458564502578, 0.18544655143012925, 0.1015680825578109, 0.1101818219608357, 0.17376789342491858, 0.10748333087371242, 0.12777526096831407, 0.19961648139982455, 0.11272440649448864, 0.09651269132812178, 0.10153956876526918, 0.19147517309794504, 0.1870235587440191, 0.14421128667891026, 0.18305382901622405, 0.2061272481636655, 0.08900402609499232, 0.19614337582982358, 0.25130637951435586, 0.12418314363927611, 0.13283287385298362, 0.13741495298041453, 0.26632746381144373, 0.20654174769597672, 0.1134805582583912, 0.29547478042302594, 0.11865626359658858, 0.16491383224004702, 0.11933198378932093, 0.18584467200261934, 0.14979335569566296, 0.13478848181905287, 0.08051899712412589, 0.21355984852679316, 0.13876659254873955, 0.14570541860115144, 0.21236554809635688, 0.1328286144041246, 0.24918112903833392, 0.07887340195837521, 0.1884023484683806, 0.10935424781975248, 0.22380333273641526, 0.14179660818509518, 0.13022575407258927, 0.10549493434448397, 0.0953357351282912, 0.19212302301199208, 0.14691038297549372, 0.14056480008988612, 0.13787336467254546, 0.13190705659649066, 0.1849219190978235, 0.2472694485538429, 0.14927025553920578, 0.14518778831247361, 0.09999047003446088, 0.14828353429273253, 0.1979996681573891, 0.12335127940581692, 0.12516657070767495, 0.11638679706882085, 0.1294498755446365, 0.10300796013325454, 0.1013336290094641, 0.12539937716698454, 0.16978518616768623, 0.1337854735433094, 0.1863136097428299, 0.2639278006409445, 0.12713082780640933, 0.2063775903755619, 0.22243122329875348, 0.17899884902421506, 0.177291116466926, 0.24961943858333174, 0.10425053942467898, 0.29468243100470115, 0.1518276868568313, 0.11516104872909286, 0.14199625069816268, 0.08930848475785987, 0.154274694261051, 0.1613385458627055, 0.1414895295015266, 0.10464486786194387, 0.10468413752894248, 0.08283866539357171, 0.14995714529387413, 0.2353894013550974, 0.19710368236466763, 0.143642466395132, 0.19740267115975582, 0.22296081988080857, 0.18503808867066138, 0.1284032079180883, 0.17656249024214285, 0.1794273679655406, 0.11189506269030033, 0.2113952517749802, 0.10139976537996724, 0.21670945048812898, 0.13856223093405848, 0.09909717321035363, 0.13569030520175734, 0.12913095314175854, 0.1553344083649497, 0.11913914413702105, 0.08740998864654573, 0.1756904370361759, 0.16369025192914471, 0.17605019192541801, 0.1201319327998546, 0.1634664623247039, 0.10013182857824911, 0.16727626353742617, 0.1253123649005448, 0.14862968346043942, 0.10830400256259788, 0.19343030608950124, 0.17461077400272892, 0.18409215394527684, 0.14872529123338962, 0.08626015962011392, 0.0950651988387108, 0.1300957336300804, 0.3099903386206396, 0.2241772449304981, 0.12035656510101211, 0.2051777434685538, 0.1680308754646009, 0.14481364629201351, 0.11678795901037033, 0.10155779399698782, 0.0920516923971234, 0.08970477438021092, 0.12526330462987387, 0.12233404487731958, 0.15249369305468377, 0.17063083998378248, 0.12886440050938439, 0.20978606876827058, 0.11705952951864851, 0.25884655394381095, 0.30530135958425464, 0.2149350989249445], [0.025714980325691646, 0.04590533290719313, 0.08172342523692117, 0.024129442622764938, 0.031087242757841468, 0.02517217830304177, 0.014705940622896438, 0.07087702983089032, 0.03260323499900199, 0.04124311715244286, 0.05502804963579101, 0.047680841263143287, 0.026788070324748278, 0.06025260457048013, 0.04083327160427167, 0.013514157748901317, 0.04914984933190769, 0.02243581948982131, 0.06622303036912795, 0.03641569836726112, 0.046360082699046026, 0.029673186175885703, 0.10559526121904773, 0.012033125930165332, 0.06137323798611761, 0.05291286555509414, 0.09028035922036057, 0.06382486107008112, 0.0715324946589047, 0.03009225542266523, 0.028217080942985993, 0.06069546084730856, 0.013208079767683822, 0.0354252960683117, 0.05118316542657633, 0.04266530958815448, 0.05445092878935318, 0.039723708159140045, 0.07213898348591982, 0.09192765510130314, 0.030385839467447613, 0.023580969634255575, 0.0866370365744637, 0.03878104079875254, 0.013918871465589733, 0.022532842610211625, 0.015493157252128568, 0.03756641988612471, 0.027217520062901804, 0.04742257387167023, 0.06011888009285735, 0.06048344218382432, 0.02506227915986411, 0.03525560376264396, 0.029751530157462246, 0.06478319109808053, 0.07398029879456566, 0.03309935353876602, 0.05224568724271752, 0.0424539459298455, 0.028663478461244417, 0.02000183749553417, 0.06276647229829142, 0.011212408276004417, 0.039661168571441405, 0.08732591049685594, 0.03787617604698866, 0.05835075299405764, 0.06857297443334134, 0.03641685899046641, 0.04788073275478617, 0.03598914061102175, 0.013728742806931898, 0.026997269784671166, 0.04282166813350013, 0.01184549759097037, 0.03181536527981441, 0.014497999462389178, 0.0245144056351555, 0.019541175420125647, 0.06335007041812905, 0.009562778699722503, 0.04750088337929018, 0.03195151634093735, 0.023780941565130508, 0.09943252053832817, 0.01680707848150163, 0.026932995007824034, 0.02046802306487676, 0.03579116816962919, 0.02504877302975905, 0.07784463780661745, 0.013083253401301563, 0.04985196508407112, 0.03318353511032558, 0.06286050576055724, 0.0365056102764943, 0.07183406517029771, 0.018990212645862373, 0.02681493128259336, 0.0787573549596052, 0.028850020870806712, 0.03857910768279145, 0.07422902456094181, 0.02305157606550042, 0.03002968136101, 0.007352344513375073, 0.03777940382039355, 0.03359482856467366, 0.05783941228723815, 0.05175102427000961, 0.03573113751988258, 0.010658474995814746, 0.02855887490084335, 0.024266371263131022, 0.036572378669534965, 0.02015886253737394, 0.04311458568178839, 0.04815140310975333, 0.04543094445140131, 0.018722627710010258, 0.017704960341835697, 0.02174957899466878, 0.030805165353681774, 0.07372357507026003, 0.05691185601115708, 0.05568592764076687, 0.016550778020774166, 0.03293103253048274, 0.03959982791134427, 0.0624530504067098, 0.08049314165668142, 0.06659413102052866, 0.007057266118335388, 0.020959403350829117, 0.039928016147666404, 0.019671326097581657, 0.03976586214717358, 0.040198563928565675, 0.04616807808258361, 0.05831129946595719, 0.0429032756496341, 0.07488760736680801, 0.0068050149110926985, 0.016584259893504844, 0.03804951110073636, 0.06733776490774847, 0.02818951135381095, 0.10471198482499008, 0.06507004506044811, 0.0772698573587883, 0.03942329827095232, 0.018859872361645103, 0.018479996173071767, 0.0710559266829683, 0.04795014032072598, 0.014311561432306566, 0.029928818224899234, 0.03742948933053882, 0.0214207912945459, 0.021228717730170297, 0.038494060431877454, 0.039328016085369934, 0.07512672639061367, 0.035288074399314584, 0.020499972761758876, 0.016690924230422226, 0.06149459014376325, 0.01133618797476013, 0.028331996046847878, 0.07014291841656932, 0.04649195324389204, 0.044610161679766835, 0.03406597263810616, 0.043887599040904356, 0.08023336124155792, 0.01346074035316105, 0.043625190944200566, 0.04633945961212439, 0.036034673046801365, 0.06408412054541611, 0.049230162159449635, 0.030093994442253347, 0.030998200358402346, 0.06014137626475385, 0.07317163170345369, 0.011142343789669535, 0.02297703954090755, 0.08204118318615422, 0.04143993280106976, 0.026730560104272542, 0.02655716950915033, 0.06793532881044573, 0.046462704006943016, 0.058236073462232474, 0.06428203936065398, 0.018363393760556658, 0.05526801901719263, 0.04897140447170504, 0.028692344654231306, 0.0484063265274369, 0.04587599557013281, 0.01085256815948073, 0.042913495262544, 0.020247968139066812, 0.037699742167587244, 0.028192409081384543, 0.005838148748396986, 0.020923830058065154, 0.026097895968104565, 0.03820545212816327, 0.014553929626521085, 0.04438225818317264, 0.023967349909306056, 0.03958048419125619, 0.07904778655257919, 0.014608836105664172, 0.0586992234081751, 0.07326417512470677, 0.040573774641680146, 0.04008758460141478, 0.03312031370437434, 0.043342711343880624, 0.05846124585537661, 0.025472254942982428, 0.07923241374233077, 0.019640276554010568, 0.028907282112707055, 0.0151047027940231, 0.062024615735055945, 0.05386376453022804, 0.07281888651871875, 0.044793471198288665, 0.03942999770985015, 0.08403859657025145, 0.025505598919886737, 0.06061249352510899, 0.03555116048383136, 0.012436190642596734, 0.02990570152178407, 0.02506141922616911, 0.052474046561626665, 0.01055297319732246, 0.043061614532264016, 0.04216225029179647, 0.040688515460539254, 0.06158558606740929, 0.060291472041318496, 0.0398797832519537, 0.0371500204557613, 0.017398624763553663, 0.07367703522886, 0.03226985268655323, 0.07933061855334429, 0.05323514725352007, 0.05740898578698116, 0.04450695431460777, 0.0135594172658579, 0.09283802036436335, 0.041596869742798234, 0.0598833080561411, 0.0811645181308831, 0.024249076828240387, 0.03454694178916755, 0.052429923727627725, 0.0034224451331782246, 0.05491448476189568, 0.006461335898136661, 0.03174303700366328, 0.05937884298844203, 0.04000129245762383, 0.08355520275090972, 0.03991958151962008, 0.01577013538354227, 0.049816732700433464, 0.04280118294240486, 0.038894735907595006, 0.058426208824159644, 0.022339432222408154, 0.07041952978338926, 0.047082216328670906, 0.0328978800755595, 0.04268618548409112, 0.05556717252118453, 0.08330500609571896, 0.006248341908963818, 0.05023615051721854, 0.012046793896344402, 0.016838886452117757, 0.026292618281478365, 0.08629868618182598, 0.01198813550159215, 0.016452626835915352, 0.04271635402654929, 0.09566439450868676, 0.08068137712055638, 0.05446038231433881, 0.044196160104606426, 0.026338780824575695, 0.036549166205429265, 0.0549607526420826, 0.01275254569331845, 0.036503748682838295, 0.037500662729144096, 0.10859581311383557, 0.05805085638477918, 0.02254121020556458, 0.061918340187760136, 0.013032262589061453, 0.050359479181708834, 0.012557318719524532, 0.028322408456475507, 0.0068315124559787015, 0.01707153777862268, 0.04232971328160456, 0.04849124737384339, 0.04683393872373047, 0.029082917345447407, 0.019681518897414207, 0.09255164137650883, 0.03896050455589448, 0.09292332425473199, 0.032739491397214514, 0.061143028564871325, 0.0549336752643989, 0.002000793148556935, 0.008304599942939897, 0.039739987527531, 0.02357964047170695, 0.10498774583421408, 0.03264676794529923, 0.03579431679099798, 0.044909560331894506, 0.005853113797192853, 0.0440223730589834, 0.03297062012396994, 0.03407302447744916, 0.015312758867719002, 0.02631759849346934, 0.04918055796635248, 0.02460661580816152, 0.01453443843450758, 0.03988879244594325, 0.0507197626716187, 0.007057977622495063, 0.023605141623486436, 0.04626325301585659, 0.025441921691620545, 0.008366842671567875, 0.029156576699366974, 0.034130649611113534, 0.07722261271649793, 0.15802751385396527, 0.18692068845754672, 0.19828157319176584, 0.077838470798827, 0.168241074669265, 0.1317547583171437, 0.09316477984670671, 0.15176031708477006, 0.11435688623497564, 0.17714928294862473, 0.10489703336310004, 0.1138083826029493, 0.16917680510349814, 0.21198705469648685, 0.07904018696037032, 0.15721668639490682, 0.15554531237050412, 0.11788023951193018, 0.16037673779552983, 0.18207702094749098, 0.11152739411280041, 0.14239991774722455, 0.29901324861472656, 0.10608430876727067, 0.17828681626387183, 0.13403350216967447, 0.1750804625091053, 0.14701329922724157, 0.1601225345004951, 0.13470579028850602, 0.24323688429449838, 0.08902506286939306, 0.10157307745107721, 0.19231158789367447, 0.0819678379282836, 0.14943881020430597, 0.0907742944095404, 0.12710997489311043, 0.15708674256119037, 0.17254334784323172, 0.16061232515400456, 0.16294638055466837, 0.19044008105993274, 0.10999877291220812, 0.1358315411714777, 0.10902116045115456, 0.06980958589983564, 0.15943147722751866, 0.12311484168974623, 0.1870936251455738, 0.11643968011823394, 0.13534835419587551, 0.10989440109340415, 0.1798552740365267, 0.0857053051191953, 0.19507347275653195, 0.16284822936980956, 0.16664859237930468, 0.1935896217342346, 0.16435608958765385, 0.18660018791354474, 0.14878682341546784, 0.16722496629001635, 0.1016223292437292, 0.1240128499545878, 0.20639902551568326, 0.10542980154916164, 0.14683424915757873, 0.1861831909346004, 0.2506575796512827, 0.13530413560088606, 0.12177692275614509, 0.09188384253291354, 0.11916891431375859, 0.0934209596485861, 0.13562995279508253, 0.15624897945071423, 0.25145095562742603, 0.15346994954011134, 0.13224182169764273, 0.19271229784334862, 0.09858564864243231, 0.164981983421791, 0.12180436402559282, 0.10404150467365982, 0.2432227116678992, 0.15410388729745342, 0.14376468806257173, 0.2145737199293029, 0.16310183511626336, 0.1895391616609789, 0.21015584408756227, 0.21040076239695474, 0.16302000160419172, 0.15414841232761262, 0.219724711271063, 0.13445947769909136, 0.1182832170818602, 0.1597115436508771, 0.19450031641510226, 0.1348356115481546, 0.11132539204892614, 0.1006594026881841, 0.15132360100265474, 0.11344705723346242, 0.22362308756959057, 0.16055135987699032, 0.2232771222629855, 0.1595263035907861, 0.18444351251086882, 0.13233445704944674, 0.11517454719831867, 0.08961351032579139, 0.129110774385833, 0.15376556754833268, 0.11136825466828962, 0.040042963810265064, 0.12482978313440278, 0.21430771888023425, 0.1478789785816785, 0.29044308429283483, 0.15090611372743884, 0.07906124671740879, 0.14935941285183355, 0.24974164492901296, 0.10658722250692307, 0.1443886207116227, 0.19030540280284422, 0.15213968382487375, 0.13011909931177093, 0.1279384913223405, 0.19797172126991136, 0.10531866517398628, 0.18901869684698122, 0.11903269621994227, 0.13753202653700305, 0.1135582855391887, 0.1006670099412722, 0.18795999397914256, 0.20830846902343536, 0.14505389146506786, 0.10133088641469518, 0.11932479788459117, 0.17712242390599944, 0.13947792050819244, 0.13132374192918503, 0.1165723818684778, 0.18964079088501393, 0.2895979667382856, 0.2588809359698527, 0.15223915268096233, 0.12908365487331344, 0.16949365906898053, 0.13992139348579993, 0.1619568247828753, 0.13672083135574095, 0.09770155253429567, 0.0960025687011019, 0.11536721831127522, 0.15835186015934716, 0.08805642129793283, 0.11066959780310431, 0.13897533618634747, 0.22292936431063762, 0.15464480665902938, 0.16749721861654715, 0.07937227075378742, 0.12751057759047518, 0.13869951389008953, 0.08706567042897786, 0.19542023479457826, 0.12493460694508207, 0.14224742028501727, 0.11466987911731967, 0.14998971935241454, 0.17994699008282156], [0.06130566903119607, 0.0378117710351944, 0.06106065496081307, 0.06418074721530562, 0.03957878730650391, 0.08453770285292019, 0.014892958964581692, 0.03250795664385923, 0.027410380782619603, 0.04250219031687706, 0.04859963349337059, 0.03061857697884402, 0.06350873488812678, 0.03799036145210266, 0.04981832616331597, 0.10162730115435778, 0.029309447629437334, 0.06965966249305396, 0.02386875822389078, 0.028473134340357878, 0.022181116322415973, 0.04922755363006746, 0.02682047775916515, 0.06637218768798536, 0.0545254385008687, 0.07770624402309619, 0.028962886689471144, 0.05080262657194849, 0.07670952532921108, 0.02939422483435802, 0.015638741728429113, 0.010021165493995914, 0.07606973466012748, 0.014653683850361456, 0.032557495719482826, 0.034218221121738036, 0.01080249856796957, 0.018971516270070307, 0.04576155352556417, 0.03252335118069764, 0.06825509391004039, 0.03666509446057101, 0.030649446491752903, 0.033258558100750374, 0.04576023585433441, 0.023178350210430163, 0.03543848810236781, 0.04995308485963652, 0.012637624843797136, 0.056475101624645536, 0.026215754764815493, 0.03176896907990018, 0.024834450356842532, 0.032634878260714394, 0.022955826566284223, 0.005677744301201235, 0.011614549852487062, 0.05581617024877379, 0.0313321016954198, 0.06310783724691119, 0.0045983316827445265, 0.036016972585310864, 0.056100921299789226, 0.03231239737942815, 0.040879635245449124, 0.0336979056948856, 0.05004311551249797, 0.024064225557770942, 0.00855085794858995, 0.028115248705651012, 0.011802810214219556, 0.0224475578720411, 0.004553889007037205, 0.03587241945487838, 0.026708152032487338, 0.112010941149727, 0.024813285262714473, 0.04057159129109594, 0.027361686318932522, 0.06933468799557417, 0.023984410687379783, 0.030435252138563705, 0.060126617580892584, 0.07826060056686401, 0.034388487993348996, 0.027683198098994555, 0.044491647877880645, 0.07936908382802241, 0.10515427036631493, 0.03916542541476027, 0.02565040294411442, 0.03539027818929284, 0.012746301119125659, 0.06808542075657076, 0.03188523058328898, 0.04145389092305014, 0.03432663788478221, 0.021078319348875555, 0.023917163489386443, 0.028780272395740596, 0.026431354889345747, 0.035702589253384265, 0.06138391342134245, 0.12720713016366766, 0.03210777912529246, 0.010993449813536098, 0.02998202303124051, 0.06989520388625323, 0.012265607759717011, 0.010797974818776692, 0.054177952509733944, 0.06497842094470417, 0.024776945882026228, 0.050456967700513146, 0.03759542014449835, 0.01311294122358724, 0.016354872101557352, 0.00548584167019374, 0.020737299139821724, 0.06656062233472063, 0.11669324756029154, 0.09415563030709183, 0.06112652703098232, 0.02906057822157539, 0.02996658252912664, 0.05487952050903151, 0.03361359005793929, 0.031461652909075065, 0.03394277037812337, 0.042548167083652756, 0.0406218926242042, 0.05299223992492884, 0.015219592042417537, 0.05652156102681353, 0.1032138615846634, 0.06781375065686242, 0.08860348468466152, 0.06295606756823198, 0.029732521600841038, 0.042168689260800044, 0.05872533934551382, 0.03861284619497676, 0.010001466500632947, 0.02294862917023561, 0.017295900033786893, 0.0391789430361842, 0.07125871015652534, 0.02559068064475733, 0.04761630984684152, 0.0287479683831935, 0.022641360879905766, 0.06405505516956891, 0.023488282571516694, 0.0628138778190459, 0.062208955641835935, 0.028168587577379042, 0.01273768550280722, 0.013562559183957356, 0.0025995908119159964, 0.07298968582143707, 0.037683960756347064, 0.027967920421712825, 0.0672913246577786, 0.035677492212984836, 0.01489384283852433, 0.02358214557921935, 0.03328595723536226, 0.010944334001490667, 0.04149764986528505, 0.05595332296985773, 0.04270216990863124, 0.022956602230307557, 0.03459671452160805, 0.032847904329819065, 0.026262216082203294, 0.0024284977623591983, 0.054150580188199404, 0.028771611771756606, 0.046073642424157554, 0.05228014204711203, 0.029006590090331533, 0.017432589271676638, 0.04623813682325906, 0.024740121950725877, 0.02354888587198671, 0.08215383641541966, 0.05394842873717989, 0.019307269624644713, 0.04349687887776283, 0.0750586671394206, 0.07339572008218496, 0.06971302051698008, 0.032068361986368414, 0.012351795524028281, 0.020853384442987944, 0.050556428895722476, 0.021829152547363794, 0.0904702570950312, 0.10195956114799747, 0.03403210772141334, 0.015964312816879923, 0.03354543121531606, 0.022492850905344374, 0.0774821556443649, 0.03540087701572526, 0.033153550428969246, 0.024769643148888024, 0.034961586878184354, 0.06810798970682007, 0.0461198068824747, 0.0244544860681579, 0.08008231168552753, 0.011466548368785412, 0.04403390268224382, 0.07915558278440468, 0.05542004533532647, 0.05064010867969163, 0.024296664294876882, 0.02329825254667911, 0.023656053911714305, 0.08122012845330662, 0.0678471597512403, 0.03624117970767041, 0.05654804851679553, 0.017584778383494388, 0.012799795123658354, 0.04479422579489408, 0.09584673875642401, 0.013457798575531813, 0.015815408307037527, 0.038251310151310704, 0.03352088575822211, 0.04287620210239003, 0.0065141892616426755, 0.05022109688950643, 0.09488401904461846, 0.09374906744567618, 0.06397369663201033, 0.09017351293756116, 0.03379148333483646, 0.01828449436523501, 0.058840984148123575, 0.0215864309950942, 0.034473025795793345, 0.025370162235753193, 0.01379244301783582, 0.050618746317923076, 0.03362345727040403, 0.03656463352062049, 0.029863570516388264, 0.03176171039681762, 0.039845113942940394, 0.049236474723945704, 0.04151721192043155, 0.028548396733259002, 0.03794101006802052, 0.022340324714839942, 0.04069886530839628, 0.08230394368330318, 0.05604161077269143, 0.04096626829836638, 0.043301522626631686, 0.024641210423602213, 0.030949932988733057, 0.04821987987886514, 0.028351969874253678, 0.017187791621132244, 0.05199100897316972, 0.040607264175290064, 0.03137860897808306, 0.005693710052348193, 0.012241810195959144, 0.02788437470313042, 0.017834293220432538, 0.07098936130322757, 0.023240529736804388, 0.028814681234859654, 0.03569979303246064, 0.06608739450213409, 0.05229594261055032, 0.041251402393343954, 0.059907868834993536, 0.060609088264285564, 0.03408166594923504, 0.013519799986463642, 0.00930002299062307, 0.027490339294496565, 0.03933473467646588, 0.01895736662610885, 0.06487981776797003, 0.06270614287425434, 0.0260043891912867, 0.006267124469647365, 0.06801487171962377, 0.04252520742856207, 0.0346166787729148, 0.02443418856860409, 0.07604726530130833, 0.020848780254563017, 0.028487433371464574, 0.012810655377594935, 0.044004684088811766, 0.017238087208581068, 0.02828040960124664, 0.027593148293935006, 0.026066051608312036, 0.028015006100758914, 0.044227075582790765, 0.0251401481669276, 0.03652650149418943, 0.022976382620512478, 0.043751974665229364, 0.04654210518985506, 0.07581438223320631, 0.004441737565362165, 0.07488014567042552, 0.04047942708336538, 0.033205391598805305, 0.009648637046226332, 0.03348325551938146, 0.04068247102681668, 0.09090161056167657, 0.04111652878383475, 0.027180159870054454, 0.03889434520275362, 0.02463137193943464, 0.019289638111067396, 0.07188617447090727, 0.012420666828421096, 0.06234603175412744, 0.03965781310633306, 0.022105811794679013, 0.07383876405055485, 0.015541064560473447, 0.060759356410633174, 0.056129389127055486, 0.05926806667459108, 0.026951949938290545, 0.11090209016636496, 0.10932298377156259, 0.021743084484290694, 0.020296049732414466, 0.024902798806227026, 0.018718450615603118, 0.09100559167563917, 0.028045423621792468, 0.08577349460533551, 0.02916273413105838, 0.03222550768705626, 0.036253571179845644, 0.03011282679865197, 0.06769091611908329, 0.0958985339609846, 0.16949811770069986, 0.1347650088850529, 0.2389011330782406, 0.08337386207835329, 0.15523015912021362, 0.1501320278452289, 0.19669034728600135, 0.0868854329230324, 0.11048337715047021, 0.25066502602590673, 0.20566345853430612, 0.1172083957240947, 0.16052344363302956, 0.1267117547291902, 0.17838450779597606, 0.09395555878478674, 0.1365366944622609, 0.13065260294223988, 0.10464622383756984, 0.11328725895333676, 0.1988167162503927, 0.150275623365756, 0.12701811329010995, 0.11404919468106763, 0.21034361223780343, 0.13900314517799886, 0.12579945126368156, 0.15029548036475338, 0.09020334440133265, 0.09809752806059777, 0.1125683697060712, 0.1720679749644572, 0.09194997124253743, 0.0841763774834333, 0.1475262410578228, 0.11453343885800532, 0.11272545603494491, 0.2665952881497722, 0.13850532592304293, 0.13351838464938826, 0.22062466539923223, 0.17864580506518965, 0.12205075322379991, 0.1756091857509267, 0.10007170599795158, 0.22509019190986312, 0.15189896367730635, 0.09037997363315475, 0.14983023516833782, 0.14369068396908624, 0.4041423912971251, 0.1632667278810855, 0.09208946053179042, 0.12697009489901606, 0.11779361028945255, 0.14150296668371848, 0.10625461777371746, 0.11739908266932735, 0.21045728436400815, 0.13306692903560977, 0.15920728925735722, 0.17793089181425112, 0.11710485128024894, 0.2086714874472349, 0.11498834186744307, 0.13068796556082465, 0.20290482188424758, 0.09365519103143485, 0.13668856373237026, 0.19599593454791656, 0.08574377805475267, 0.17237370533327903, 0.07157570201783411, 0.10955962067049359, 0.2065420694529049, 0.19533188953515024, 0.19440516829490664, 0.22249537550153273, 0.07900711494467913, 0.1461530744188255, 0.14643945340668002, 0.13948555074391827, 0.1439680844064682, 0.1828557186790051, 0.1553385452397408, 0.11247361229071695, 0.19588741053256298, 0.29891328946236645, 0.17921978878157754, 0.0952210134616302, 0.13762617874289715, 0.1291155547744805, 0.1670197466568601, 0.1302208204663569, 0.10300484215540272, 0.20046834052810747, 0.15089983180645974, 0.10258556223444401, 0.13618668421141564, 0.14413564315726682, 0.14573439204644772, 0.16224254493511495, 0.13911793579257306, 0.12196836046754353, 0.0788527635496951, 0.15416399455599247, 0.24185466249623608, 0.13548914583459978, 0.043927703743740436, 0.1566389028824145, 0.11488787709705292, 0.11136670717068257, 0.22886702069832435, 0.0811995589925397, 0.11968072233421188, 0.1278155342104935, 0.18983761419452008, 0.14316798217834967, 0.18205662768694664, 0.15701140547471662, 0.23706287446041263, 0.1219517823248621, 0.12571474492189386, 0.1671019019258599, 0.12695183902378046, 0.10737929613359513, 0.09820616698913998, 0.09971971157938243, 0.16143577774205517, 0.1169575325724098, 0.10396972989603397, 0.12749589168496672, 0.16861831168493918, 0.12403726517673462, 0.19927678269244012, 0.1620834131514834, 0.17631602443514333, 0.09863567418388783, 0.16345374526516085, 0.22455566172157565, 0.11551361005272597, 0.09638688436919644, 0.213924674918094, 0.1262452301659411, 0.18332235815544284, 0.12526142005358012, 0.13731598974235598, 0.17229784730701678, 0.24442534713495165, 0.12787715066224337, 0.1350939210744635, 0.13429633161473659, 0.1303664997460381, 0.17598256168346252, 0.1417087379001802, 0.20850676322175613, 0.10470517430334322, 0.1482908121280132, 0.1696032709291866, 0.18939981026755226, 0.15790605827444987, 0.19284279326037054, 0.17184037024215346, 0.12122716273992293, 0.15876511862922102, 0.11427655425523559, 0.0765265299067382, 0.1521488922017236, 0.1008984221205596, 0.17666041160062437, 0.049483710449309125, 0.14129194010409618, 0.11647700392190488, 0.08654655392972693, 0.1669347721842989], [0.044318638411500764, 0.08567016466610855, 0.017582547152414918, 0.03442967288015831, 0.06886944279915864, 0.059797705391482006, 0.0046589541354126515, 0.07050862580898308, 0.027380514844891526, 0.05356440035205695, 0.06420726534880458, 0.013865754759359746, 0.043946066871285445, 0.028919405454108794, 0.03066538686623737, 0.07266253563425235, 0.023826883857949607, 0.015019381666676173, 0.0333319416630172, 0.07070565596222878, 0.015021372537669397, 0.03483083482170778, 0.0726261081534528, 0.03215463689318107, 0.023670933254423644, 0.07158795942462261, 0.048316970031948826, 0.05424557126037056, 0.04691998954982527, 0.023693419850221085, 0.048477817852530754, 0.06257423402501211, 0.02602599861641084, 0.09577802066961605, 0.040949755273158514, 0.07278910102022272, 0.02547075341065084, 0.01843436606108181, 0.028497214399037823, 0.023483538572045586, 0.06564935308790977, 0.032793741913572434, 0.028701834568393328, 0.04710445586111277, 0.04649778317299582, 0.05683684834249078, 0.03311262984249381, 0.04097624659358014, 0.06846357707775409, 0.0326423782614931, 0.035085306247516025, 0.021192631158497066, 0.008112311873945498, 0.034624623104689584, 0.026016422517357335, 0.023085209240596143, 0.03704987361185974, 0.023071101731470516, 0.016917008268196258, 0.03046564859217934, 0.07519254866506785, 0.015052961215617196, 0.06819283394443412, 0.02145184849899623, 0.028158412014524785, 0.033559370185098344, 0.03917085697814342, 0.020408806383549687, 0.05404677144401977, 0.04603696596478263, 0.06930250464187515, 0.0025727272206436725, 0.10235111634697645, 0.02103773775630661, 0.05987947378608008, 0.06386302374002915, 0.006000891200176651, 0.0549871520319533, 0.09851460930921378, 0.06014087064672382, 0.04348723383079614, 0.03386633012503867, 0.013156432992658548, 0.027691724657591794, 0.046426613604830164, 0.03672496806229315, 0.03118899264072459, 0.08739534104543348, 0.03735409861791038, 0.00789289136469785, 0.04365331786234052, 0.030176076932900378, 0.03919333782828143, 0.058672038778182, 0.06131487740804592, 0.033916623797267675, 0.028628192451452057, 0.0717017311422575, 0.053211019314344854, 0.031196902498542785, 0.02750823893884738, 0.1657204615372804, 0.015257519140328853, 0.020692400641799457, 0.04291835992086319, 0.06632065295331901, 0.04845669297801872, 0.03435138635517609, 0.047665293508720015, 0.03790891098399316, 0.02349963790977434, 0.03826657445320199, 0.031021054676403443, 0.027801432278788382, 0.01384237662874042, 0.02507118110154425, 0.1036541706191436, 0.02628132614547447, 0.06104803366226055, 0.01936943191404064, 0.02483884004064866, 0.01924673718730769, 0.07724151976646916, 0.058108358944375674, 0.05680036340509692, 0.028563595917676727, 0.0773301178349122, 0.05532423837951595, 0.06284413446161537, 0.014645361262674053, 0.06901896017934046, 0.052762880861278505, 0.05817513116785596, 0.07727670618483136, 0.04918809627152739, 0.04732222784490836, 0.05361775071510384, 0.04564717276802948, 0.04660855182596753, 0.02447469546760042, 0.07232859790805848, 0.024218931268419952, 0.04987402075541116, 0.04193468387388895, 0.015977094993896542, 0.02724616409039065, 0.04801264926490765, 0.02357368605331548, 0.06076862990495659, 0.05685868567877239, 0.03162640011719158, 0.07342623336420906, 0.08544032296706593, 0.04308164773148395, 0.06610561207297348, 0.035641401810871984, 0.01076292055058143, 0.024753007549612273, 0.023005708466253938, 0.03252292600189967, 0.045992858452542175, 0.045090395386420914, 0.08863711594453744, 0.0685031838234394, 0.06905141166381298, 0.034674663967903585, 0.021692359887604273, 0.04012572045828547, 0.031146153003998825, 0.04202236646726247, 0.03713017877852244, 0.07297645548298475, 0.050168865014828985, 0.03285937649648517, 0.014658541805411299, 0.02878380789151115, 0.059451502597620415, 0.017535007566273693, 0.04185990220116031, 0.021130080079479564, 0.057758582350347316, 0.07774867763322207, 0.05102373869909395, 0.07280729560842437, 0.02691438290170364, 0.07085479029844846, 0.010153540699262052, 0.03975900949069089, 0.07665864943015961, 0.015108228713694601, 0.026644202843008023, 0.017764820537019162, 0.025089984729645715, 0.038139377044694084, 0.009245240043157773, 0.08344996525275131, 0.04854751270144217, 0.08346430641869385, 0.02880986254181593, 0.03833559897517966, 0.027831141168491978, 0.019050333310940096, 0.058985625378667354, 0.022357816417371074, 0.03054086118936539, 0.04516319289142567, 0.03743326997444515, 0.07781508213449871, 0.05012784866736301, 0.06398780414113595, 0.011851117803504872, 0.07661600897629416, 0.036254478994035916, 0.009293418355105866, 0.049534555704843615, 0.0381746553936072, 0.06288792404736723, 0.10126221429316268, 0.07351947392547324, 0.017516167548995827, 0.05530028664056332, 0.0550776040331731, 0.02193158807893915, 0.05464673703235965, 0.028406444471329454, 0.059919383136495474, 0.02750321914772353, 0.04360924865449629, 0.059240391748326446, 0.024570385595002485, 0.0726050254137766, 0.011930915436917737, 0.05251232797520296, 0.004547392581439307, 0.03293508130516256, 0.03749610833643425, 0.054223320236609834, 0.03041904554852555, 0.032169430050998926, 0.04059715564512918, 0.025967494396853353, 0.07799475273538022, 0.00652182141258832, 0.05694537618828397, 0.03340229917798312, 0.027103466807954738, 0.03146145181099494, 0.046362273710509466, 0.07800707909008188, 0.03397516823644119, 0.04003751692512343, 0.025514470218049905, 0.015660412440587197, 0.004821454311886262, 0.0653841947355578, 0.07110411361340555, 0.01714476429286503, 0.027319863663926244, 0.006860886182215426, 0.018680806970223784, 0.07376564861906153, 0.0032505555915826514, 0.031001808632525708, 0.018204223672528903, 0.022694397146903703, 0.06211331722536876, 0.06277945365816837, 0.036697806414937785, 0.04699460651365019, 0.01632274428923284, 0.025358429599192836, 0.012058916280136235, 0.031227553676393245, 0.03080764173289701, 0.015374231677983078, 0.09103428166840347, 0.07346006380694528, 0.03761914971795294, 0.022440735859075384, 0.019993602050348155, 0.025444710251664924, 0.03923889707713839, 0.04058911172192424, 0.016333203304619077, 0.07671268927233835, 0.02948044611501598, 0.03144085553715066, 0.013904132891536481, 0.02793098349244364, 0.05237011907381877, 0.06233490815746689, 0.034472658073589686, 0.03049809433099243, 0.05220889587015395, 0.03086352784697327, 0.04574252773196467, 0.02430789131340721, 0.041384077330510464, 0.04062563113327469, 0.09704582723638705, 0.03670522980692406, 0.05537808286927401, 0.10925123963745371, 0.01783880930874617, 0.04393619965882071, 0.0325891696247122, 0.06301964903550764, 0.016598574246370023, 0.06894615118301685, 0.06211839638830674, 0.05903220735490323, 0.06859663888932237, 0.017794462394029383, 0.010704068718628298, 0.009459802118550626, 0.0301607072939195, 0.02936270606193331, 0.010452903919823228, 0.045927890366123575, 0.1297239358386686, 0.07966274831203685, 0.055572416393026236, 0.03420713965991332, 0.03305755578161728, 0.019413449410949985, 0.021563574761873292, 0.04063284002064217, 0.06132399768478448, 0.03870183113782156, 0.03873494145790896, 0.0601595517007574, 0.009826702692906463, 0.011890162432175732, 0.03489166220289565, 0.032858606578121265, 0.025476748048658335, 0.006884295435156674, 0.023278659848015637, 0.037161630518253774, 0.028492232912310192, 0.018024348143127658, 0.023885594921246655, 0.019806801086111415, 0.017125650399154233, 0.05204384222686772, 0.06904376610632866, 0.05849260183411741, 0.1107215309034913, 0.032459087895169374, 0.03768830830531736, 0.099103432148695, 0.02697384090072686, 0.1956772266496574, 0.10761251628038385, 0.10470071567162391, 0.17083727003585908, 0.20718363744597282, 0.16016358149147805, 0.08994159514024373, 0.18144600964601965, 0.12242952241532265, 0.1370845086151554, 0.20336691079841507, 0.1084558105456733, 0.14108543344322713, 0.14148327822406448, 0.16098450598937852, 0.11143474343923793, 0.1331628279219712, 0.05772923352196813, 0.1493084526831104, 0.13215290953315076, 0.3095915438907762, 0.16337252462342863, 0.11801998927107743, 0.12272554645014387, 0.171803598021788, 0.22190728044557959, 0.1850597996024355, 0.11327608939140074, 0.10840971503526935, 0.14414469831653182, 0.1589075803396202, 0.123652505177644, 0.12795647140592337, 0.23242347663448704, 0.16063991964103716, 0.24598989785919267, 0.1749166269456187, 0.185316898709824, 0.06615696294653801, 0.06260587345628489, 0.1891059082962813, 0.170728761342264, 0.2570224526308237, 0.12446052875489959, 0.15742046578276545, 0.09679734661814668, 0.13274066751041722, 0.085654528811574, 0.2353785382283311, 0.1791858817300489, 0.0586076261055085, 0.24339008655759597, 0.18958405441334172, 0.09158077048918895, 0.11443184793836648, 0.09392861547248979, 0.1518123497765872, 0.12240973436423849, 0.16105864797869038, 0.182198936179761, 0.22753749042749408, 0.142831148639802, 0.17364878207445147, 0.11782849027264504, 0.19418954518773865, 0.13596756774331295, 0.18165142846203622, 0.09794475480673775, 0.14973986743678971, 0.14037608199061888, 0.1420190035095138, 0.11231081094592811, 0.18146624968897912, 0.08346045299643472, 0.19363151142193427, 0.11287072162714698, 0.1251429522169694, 0.10072137154037915, 0.21669792852574782, 0.26901073273151155, 0.1549543061804387, 0.22365826632707353, 0.09461886069226651, 0.08523360180157809, 0.101348108071233, 0.1310684354675393, 0.08667724852960917, 0.21034227924481516, 0.1343321079208005, 0.09454889388214197, 0.1950405156540294, 0.11514899816604392, 0.08256491153470932, 0.10812545811096508, 0.15672136458658403, 0.16403538986079155, 0.07514068451259406, 0.12513510747662476, 0.16483912334567116, 0.14719334521120594, 0.25997101779906984, 0.21404302018063687, 0.13730514193734816, 0.17044785222218883, 0.11960136328613567, 0.1733423162612223, 0.09657928735137948, 0.18251828759187655, 0.16680697339677042, 0.1480681716554588, 0.0828085964425437, 0.13000616262997353, 0.09353417212203627, 0.13574056056959016, 0.22724280704654035, 0.13233494734571827, 0.1403713935325223, 0.1318116173628838, 0.14219184826698997, 0.07019446847299415, 0.10346081768793446, 0.13546973316659852, 0.13476594351232052, 0.19468623063256665, 0.14314421813093847, 0.15142867762234904, 0.16720866393898765, 0.18291574932875174, 0.10900915585338108, 0.14958321777803285, 0.18205290449963463, 0.22355302116803585, 0.303971124512534, 0.2714682202185354, 0.1536405573208486, 0.1178382732154381, 0.0888690030983379, 0.165553193899893, 0.07279020418683368, 0.04618167997367921, 0.14168402390374293, 0.11753022926108492, 0.10702085125470355, 0.27979786357572006, 0.16618026750943354, 0.1297869695530784, 0.11670499168817075, 0.08624999363335871, 0.12990995730844238, 0.16965102885038624, 0.16602148812624717, 0.13505253700479386, 0.1936470170415217, 0.13322999851117212, 0.143984800444976, 0.13127298094332218, 0.08630294563068498, 0.08152658660565654, 0.14931402980319916, 0.13262586157408454, 0.10125249263740356, 0.183608062985924, 0.13100451309113734, 0.1408773026759586, 0.09752642483480516, 0.07064268353485292, 0.13468924278934158, 0.14977774282376613, 0.10451050370090431, 0.25952411274756154, 0.09887694591476072, 0.21446845944850676, 0.13315650003571666, 0.19414089860454684, 0.18724200105474842, 0.15222730896165296], [0.025308790932139082, 0.04073974759047551, 0.028702129512244177, 0.0045957317718515, 0.04337003770013971, 0.04475697476957594, 0.029738700099950357, 0.09387527277032215, 0.02876247617325956, 0.08438274624847597, 0.029090482463699677, 0.0701948898213525, 0.0011214786260801879, 0.06739971077730579, 0.027949107217512308, 0.02247369870723736, 0.06699929194104287, 0.07467596025596704, 0.02468077694967149, 0.01871469103911471, 0.031884378310473215, 0.02947326978638528, 0.08397367827954792, 0.019917918309088678, 0.05001210810376271, 0.05191738409320674, 0.037775542737255176, 0.060724736897334944, 0.04266586500189958, 0.014259786337553976, 0.03904970400335808, 0.04999539206525491, 0.07170936137798332, 0.07041852620820846, 0.017172144275278817, 0.01546915763268067, 0.055590193463309165, 0.044746785800183014, 0.04229327047904653, 0.06430705979226098, 0.033672705232616396, 0.02973960599892082, 0.037936179883657925, 0.02154537251279239, 0.043353501692294114, 0.00782860126609223, 0.02066433501069344, 0.08370917110193161, 0.03625174022970661, 0.04776873453069599, 0.03149904374543938, 0.01685979682201099, 0.03041302984310014, 0.00803666930991195, 0.06250173529429782, 0.04714230826545147, 0.020626739245809374, 0.053101618128317984, 0.051159294126855756, 0.04140599127558451, 0.012740788158900555, 0.06248820618155503, 0.04417639886659961, 0.02142243455314348, 0.09676285733979556, 0.015131008338123081, 0.0896454791748716, 0.1052846815136652, 0.06499581880146457, 0.017154244630928003, 0.06392026582973138, 0.11077897983693308, 0.08254156117477725, 0.09909474471163365, 0.021108782835184567, 0.04248307259272664, 0.03597360434791735, 0.03947521988002043, 0.05564943121205415, 0.0263407860597175, 0.03211762143989965, 0.07696795742958784, 0.022400891626133554, 0.02728074338407286, 0.03766195871116173, 0.05083067688129602, 0.02665298221062028, 0.02112137732065974, 0.025879436420396935, 0.03999232922890975, 0.10174968370026159, 0.024397709376869664, 0.025738068300509648, 0.0385936671837924, 0.04589349301832338, 0.014487126759523827, 0.06793126854444705, 0.017194923899707296, 0.06580013451316664, 0.04378084085821625, 0.017491388435084975, 0.03139222619093714, 0.023243971386804216, 0.075949665699755, 0.0626256691682483, 0.016855309461994518, 0.0891761047645442, 0.02556154440577713, 0.07755650447741633, 0.052903055799223726, 0.022941989103151907, 0.0635899402081005, 0.03460013127375034, 0.017209856868571332, 0.03345024862116383, 0.0495691484050645, 0.06058494500335186, 0.028742111641012376, 0.05395269967735775, 0.002525992026822942, 0.03350939826979753, 0.06421620176444132, 0.04431216113810097, 0.018722267648685845, 0.07477144545484936, 0.06723066581593407, 0.018526926719313188, 0.006333090864392299, 0.009941486604211312, 0.0506717634327229, 0.05429075512614462, 0.05735706800835268, 0.04728060245754258, 0.054794622645262754, 0.04925653090580337, 0.05401244687457239, 0.024390343441477707, 0.023896450387133707, 0.037692717141321594, 0.022957084865699855, 0.04902392745979371, 0.01555217379298542, 0.07944971458205292, 0.019602809108853824, 0.02071219060810343, 0.008504282675623413, 0.06857948618069773, 0.02284669734147047, 0.043737012968068166, 0.00880946624918931, 0.011467113358629568, 0.028055459373600544, 0.019713656285837777, 0.08490638266648017, 0.04322978232296244, 0.0077864511084983195, 0.025664351489995758, 0.05633825150829169, 0.06023219981861692, 0.07118932557322326, 0.026752100581483498, 0.008489530695031488, 0.017394074201283437, 0.040426283564058044, 0.03142626730785255, 0.009674016581547838, 0.06250646971766988, 0.036138068103501876, 0.00557985598026144, 0.026676707953635245, 0.06586130663392044, 0.014969362828489995, 0.02472530581027029, 0.014770265195458649, 0.08764857140880439, 0.03414318663999438, 0.06024299782790965, 0.026812326583650806, 0.10731299122374867, 0.104510051709029, 0.04148469531848546, 0.031039268416803212, 0.03216738076580148, 0.04463276127353311, 0.009838561733974325, 0.03655617974037605, 0.0360059907149163, 0.044721765368576014, 0.053143741472834544, 0.05554474529720122, 0.09350225689911074, 0.015377636938806505, 0.03649808346263824, 0.05908212181360972, 0.06068119629015846, 0.06687712389975786, 0.0452484623078377, 0.03882317563458797, 0.024135113588624427, 0.09806667003900775, 0.07967423197002181, 0.052256312882227283, 0.043719607450428515, 0.0009826030450752908, 0.02627842267224145, 0.023744922026150653, 0.06253131011861467, 0.04610149738108439, 0.1667916822818018, 0.02176898974745024, 0.022784692100099018, 0.018909532096116774, 0.04222847859285051, 0.021281974247446465, 0.08988565540001278, 0.09149799468897044, 0.017322138545193502, 0.08083965854659196, 0.04517007619142533, 0.0266511072104256, 0.048571295901051456, 0.04093452927566344, 0.0550139268049069, 0.034244930777218074, 0.03628250632074572, 0.027463997361220183, 0.026001020319639676, 0.05268433386640203, 0.025170042832952835, 0.06603474893997754, 0.047608162501766804, 0.012668632252532388, 0.024602486594249646, 0.056846194615166996, 0.041505789549480525, 0.06934584989663094, 0.02811143933344753, 0.0373862628194113, 0.11277185031963934, 0.021504088034552914, 0.07324504590923749, 0.02133076638734389, 0.05778673608156462, 0.056528923131765864, 0.06953096738265407, 0.0028512305852341196, 0.04585386712043997, 0.0426426180638373, 0.05387595681954296, 0.07956992143825178, 0.07768553666650288, 0.03892461333664195, 0.039742825883290464, 0.020165751583033034, 0.016422044605978074, 0.0336410274969474, 0.030868783210133834, 0.06702795129029021, 0.03791415102539524, 0.0280222877664792, 0.04900092950030681, 0.07609850892256345, 0.06306514699733065, 0.045043955136451035, 0.022910878272546877, 0.05721605420413037, 0.03973471301217233, 0.019285993447767633, 0.010508781415410342, 0.0837072712038794, 0.03190941980949814, 0.04717087185370827, 0.03652705690793453, 0.05048413317830813, 0.024500884183291948, 0.09178555345222836, 0.030479577985862573, 0.018765936575589642, 0.033716464174851295, 0.04167026862682354, 0.05445616116987602, 0.005844908516718856, 0.060152549657129475, 0.06898499184077786, 0.010684550713537442, 0.05341930329919823, 0.005974354872089481, 0.037561038118456645, 0.09184556111933724, 0.0455654043734314, 0.05472880037080857, 0.03765006136569766, 0.03750394158546002, 0.02848558901478687, 0.05973359915397822, 0.02801616863918401, 0.051404063049102985, 0.03360309465337665, 0.03766716810904684, 0.02977999989994832, 0.0350651849481848, 0.07652766371686613, 0.05597610642472583, 0.016218711464335362, 0.017474942442570484, 0.03675669942411684, 0.09287398053152908, 0.045363858131872076, 0.01981202963619463, 0.07711829452384865, 0.018948332534261772, 0.013157289095913932, 0.06474427383152709, 0.0370895263228205, 0.06015536119981159, 0.07350012254450591, 0.03922482021152973, 0.02556165357330634, 0.06060203642494256, 0.10856926816725924, 0.054467506932034615, 0.07254334001411354, 0.05413522012531758, 0.0389326227858903, 0.05131634598177287, 0.03891188095534041, 0.005648879065824252, 0.09147808406381838, 0.06066085665576881, 0.012780780821377713, 0.02929705998770172, 0.08448347148876037, 0.02561114859887429, 0.050443316013702465, 0.057667268500212705, 0.09771803108554694, 0.0035075895814976146, 0.07811666030677096, 0.025332256205259793, 0.07753768169711675, 0.03870791770637997, 0.03677461055978652, 0.04556009155367652, 0.06785302798474027, 0.020936644793818557, 0.020576512606273738, 0.09909685911430467, 0.06429387541908411, 0.06497294341604556, 0.02704270071380081, 0.09171414639680617, 0.011542461936422175, 0.16772834734330255, 0.11180237371234164, 0.210796554062155, 0.1219677629189626, 0.1571544494119383, 0.14560032665969866, 0.15550927559454597, 0.15089822302181877, 0.1269248037809326, 0.17627139215267476, 0.11871850824043637, 0.11079431691717719, 0.13025917082784638, 0.17889009518248422, 0.2413767768490699, 0.2266010245488536, 0.15554327457662553, 0.17193181049679557, 0.15970892363017605, 0.13405867581886632, 0.15904500119147763, 0.1394886150956154, 0.1508474926794729, 0.23449746050661613, 0.21608389373267853, 0.19312600064421856, 0.17397132041233201, 0.09971821004705084, 0.14965645578359404, 0.1814720566354452, 0.2516385705600823, 0.14435630712297656, 0.18542972813931205, 0.1155055431468833, 0.11304498364728306, 0.2424134010629308, 0.14066684300140028, 0.23175483509417505, 0.17041987469119413, 0.15652703872371107, 0.14491049512740106, 0.28618158231819835, 0.12976688272770376, 0.11817324516032973, 0.12266884828286788, 0.09805505614607565, 0.11420049704611303, 0.16366533874984712, 0.09387696582463481, 0.1292671635746956, 0.12149358513734995, 0.1311434201535679, 0.09609507381795876, 0.12421425446988114, 0.1674395475176073, 0.12430237756381113, 0.15396525602667563, 0.10118492368248203, 0.14142759895372775, 0.23750277746829296, 0.17374607524083507, 0.2006901995909791, 0.21177976662593506, 0.09364379164312156, 0.2846634412004102, 0.11354924570168219, 0.13990613301434826, 0.17563716328192144, 0.15315415277596445, 0.17609156067332915, 0.15310025082961207, 0.22075595754769542, 0.14107476949932116, 0.27863466631500955, 0.1491101125195142, 0.15896408698491513, 0.17467196910612046, 0.15054413718321633, 0.14793099595173714, 0.11313290755835273, 0.13386631114107947, 0.17691404799059515, 0.13779205210026235, 0.14757432073595064, 0.12330324569296454, 0.07772048559760855, 0.12375921356461703, 0.2072048580814754, 0.1152324481236358, 0.14315106695698154, 0.1610944089629958, 0.14673821237539092, 0.1807182107961947, 0.12658741099820023, 0.1612280300187488, 0.1174105280229161, 0.12344980597375863, 0.07657265606065912, 0.2655926629179909, 0.21135035902261737, 0.13095883892909174, 0.09860604190297666, 0.1551932030387463, 0.2429303265507183, 0.19758477025935728, 0.10002138168220559, 0.15455181890678021, 0.13171063165270513, 0.21595450148226755, 0.1079648171341227, 0.12214214751316656, 0.19099224659223712, 0.15988714632488069, 0.19876563350760168, 0.10838685497160881, 0.19247511702199138, 0.14541625105325254, 0.14602653201549284, 0.11536837510404088, 0.08579832351496143, 0.1398903056378326, 0.1393515926094786, 0.17752092752245166, 0.1159765799680064, 0.18774340560119, 0.23652020841836932, 0.13076825157528923, 0.10836950308012386, 0.10224929560096034, 0.16442327549861324, 0.16646273944887424, 0.2120753846341564, 0.12380271969783692, 0.1570740255016473, 0.205177559607452, 0.07649820763617754, 0.1299285579232439, 0.16886638627657968, 0.1306178531939945, 0.17628533495289667, 0.15107080730940067, 0.09774614651236804, 0.20773414822836078, 0.1461324206883869, 0.09754713219139846, 0.16052676845462094, 0.20932514430774798, 0.07725313365940126, 0.1388349888786193, 0.1514905928483894, 0.09047381940387911, 0.21073379613939794, 0.23847125050040985, 0.12435768911194418, 0.12574024798889316, 0.23728770594443047, 0.09164055599079979, 0.11462422027703255, 0.20986725876648582, 0.15895608902698563, 0.11008812174681695, 0.2001450514240611, 0.0550990813081303, 0.1591046487972621, 0.08610580056425064, 0.1701726734397873, 0.18189081561661538, 0.19635572008067564, 0.08595145683014586, 0.09566653955487475, 0.22614293461365087, 0.14247537740776617, 0.1033520102200489, 0.15922950580716133, 0.22592997749245938, 0.1047175542841996], [0.04825697002571918, 0.00042523502763229304, 0.02008192049669883, 0.04736325951413282, 0.03455261083980722, 0.008170579563856365, 0.04603318915131592, 0.04167007327440285, 0.020189881437428055, 0.07417022731275329, 0.031328794110806725, 0.013177192060186738, 0.02823342925929014, 0.005168298704384436, 0.055345462845458146, 0.04697354675661172, 0.019071287730888977, 0.069130985216508, 0.0944999332029012, 0.013471419618825519, 0.02050577970822492, 0.009836657047872583, 0.02985691512754608, 0.10432137191415795, 0.0849673632652529, 0.024128555875992583, 0.04486677815176306, 0.06667044869954548, 0.062399914548281706, 0.06692485117744054, 0.013986701848015431, 0.024953850905501077, 0.04941026176956873, 0.07857749283674263, 0.027300971935713486, 0.00998070456027504, 0.04430956793047729, 0.03312390665673921, 0.020580375604631922, 0.022783236533042886, 0.02579888419037865, 0.014947747657706421, 0.11160807083210639, 0.08277691104599545, 0.008166592076210486, 0.02695131217009358, 0.012985130944739909, 0.006994347795919185, 0.05878135186409759, 0.02734154012174376, 0.11180094878880248, 0.03297538902129858, 0.0320281787595201, 0.022040625373201988, 0.04874162022925673, 0.021233687725579067, 0.04857844733182461, 0.0204585446420336, 0.06565290773587842, 0.05133209674949608, 0.014072461560699008, 0.029981712765631177, 0.01305058166655081, 0.031202803290779554, 0.033020434991246274, 0.04382659928993352, 0.013923398087612324, 0.010281915010343637, 0.028303181564795877, 0.041708519396882866, 0.02313701593647561, 0.04851757015492167, 0.03315196845740561, 0.08420705164392149, 0.01200363824834987, 0.031353188265535625, 0.04457837286134882, 0.12210014291227826, 0.04937338229689387, 0.02686125278893498, 0.01710577616317859, 0.0071579607151028134, 0.04439065450682275, 0.0564214026915931, 0.012428315258735131, 0.0665360079297135, 0.016142158213281826, 0.08256157139135946, 0.03802282442789405, 0.027930316995949517, 0.060705351042411024, 0.010509406734678534, 0.0414280392860453, 0.017428243637926156, 0.08192059328599323, 0.02565902334848239, 0.018904939399010712, 0.035129383116239504, 0.006786426745219938, 0.01855235317752006, 0.10882999853140886, 0.05646229263455157, 0.03155481303110719, 0.10320185698688993, 0.048479599006954706, 0.04772054760025875, 0.011895523132425884, 0.021452241119057424, 0.061434505867861935, 0.026959340771540042, 0.04780607748656504, 0.050980454731372096, 0.05771543627845184, 0.025054840446119348, 0.02410992078723446, 0.03475249467057086, 0.019797730605087934, 0.01073391454654836, 0.07364011745178893, 0.04386201553467301, 0.044200664701601194, 0.07015546693676902, 0.00952835645406477, 0.05358001322395379, 0.01732489646172091, 0.022102251401050918, 0.016154373485234477, 0.055944026492896586, 0.03468201458153706, 0.018331371285321734, 0.034759791658049634, 0.0474498082973784, 0.03801790231298055, 0.025691321615370053, 0.041725005609013384, 0.07352412407917362, 0.07297168275521648, 0.02523282373834762, 0.057778412536267316, 0.0415480392985046, 0.012628789934810373, 0.035948748625214064, 0.04110563118311186, 0.052409932663243626, 0.10570245224141306, 0.07464812828167793, 0.021628981433628548, 0.07254565359964486, 0.02470027771778405, 0.021011790358311227, 0.048951555133586934, 0.029925351677041863, 0.06201212084101093, 0.011080918859900727, 0.019169994329492894, 0.07224166225041113, 0.05113781302145893, 0.06455834429230421, 0.003828121966028947, 0.030490527297520352, 0.041732053617916764, 0.04503201565615112, 0.03444600587470397, 0.060655099505017844, 0.02041574714014367, 0.03451669280747733, 0.028478286281648665, 0.0700669761206354, 0.0621363228457349, 0.032135488525513685, 0.036599762482388366, 0.08985131933924653, 0.08793894171474442, 0.07049856707453728, 0.05746420157412368, 0.03138499815137156, 0.09299099280108368, 0.03269796177083927, 0.10335525077196861, 0.03147350428926368, 0.06451592600393681, 0.08661869642955643, 0.019255235017607772, 0.05623533525654385, 0.05112231506275074, 0.05809751496980748, 0.038488632698933926, 0.03739777712091323, 0.058521150100615725, 0.004332734266250965, 0.019099397412050637, 0.04813877798076119, 0.040448078765503825, 0.05992971000171477, 0.06114728801373032, 0.023994536454518958, 0.018910221575248628, 0.027089368874928164, 0.01760260141905277, 0.06514861503796232, 0.06472763440181172, 0.03907028495544388, 0.06211700976916379, 0.05734735018303318, 0.025699135712197712, 0.007965549058656419, 0.02408358459961751, 0.01937532887583779, 0.03297141685541118, 0.054225756396209045, 0.03259913259816747, 0.06958483868548948, 0.040520769018199176, 0.03984003861044203, 0.03528208742218633, 0.10387737799676196, 0.01740880224162773, 0.07024780351428256, 0.013067567751051919, 0.08913303530144115, 0.05389856024374885, 0.026192011784822233, 0.03725004472559498, 0.03281857465363799, 0.0232650330590625, 0.029064697859388207, 0.04400958705152716, 0.00870253186627862, 0.0594065064233878, 0.014668397526557167, 0.013474801897011219, 0.0150064826612511, 0.029372933335722457, 0.037039879994887503, 0.06154410623674912, 0.10764648461894644, 0.04962316909504514, 0.04713499978665383, 0.006915643274213278, 0.047303512316918185, 0.05249254375455841, 0.00317071199289433, 0.028220080177209554, 0.03427245631633747, 0.03664729057721073, 0.030226295911556775, 0.04883447774655877, 0.04659254058835007, 0.03455873571276184, 0.03312357340849215, 0.06485910275049749, 0.013054584475955176, 0.02172327536578861, 0.014093759762603911, 0.07674795996037222, 0.02241975271082934, 0.04830638652727489, 0.08713859433849012, 0.032526905828666304, 0.07418301332020953, 0.01550622288167717, 0.03787552487225302, 0.0240973818431338, 0.08889378604268836, 0.017587528639142553, 0.030872789849977822, 0.04656321474260861, 0.01258986500737768, 0.06219545717261011, 0.0215860192228349, 0.0809916657125277, 0.024755926344603784, 0.07420001281124931, 0.05786532904171656, 0.03457603780853172, 0.04069995698368838, 0.06480976668817383, 0.02631829946392006, 0.03586854688042114, 0.043089752941722834, 0.04384965853645437, 0.06837671036801993, 0.02814967861218799, 0.06816232066241003, 0.0349951530205867, 0.017233846911920175, 0.05550687757110404, 0.055787978213160276, 0.12413545466598966, 0.0012700114635780695, 0.054756793223561785, 0.036858822774863055, 0.04190134372742426, 0.015800579717653175, 0.04113294604805209, 0.060325769797688535, 0.0781912619488374, 0.009634406005422915, 0.07250549527065409, 0.04199406334889993, 0.07340234674273, 0.045387131883011717, 0.03967870815446781, 0.03570966024492537, 0.015142567647290568, 0.053744538266572266, 0.06520902873167107, 0.07999749809143045, 0.03861614037305117, 0.03244563539121901, 0.026230231911364584, 0.021941664050363248, 0.06267065768160167, 0.03191173914068889, 0.029534411263622107, 0.03772588491800331, 0.020269703968698462, 0.04979033714100238, 0.0672159416060294, 0.03245396276695594, 0.0265003755808838, 0.012959510091722254, 0.042970879078512235, 0.0880800934147931, 0.05074585945675931, 0.055657199343606356, 0.043577670510257446, 0.014091126335364197, 0.08115309575993208, 0.04317367021294852, 0.046570764539102395, 0.061083760172609365, 0.04802503690664326, 0.0317697428287037, 0.030439787379075444, 0.052127326658416184, 0.027483394707462964, 0.04148095680941497, 0.07194773729650245, 0.05158146986016824, 0.08534443940246299, 0.017402968482084332, 0.034208736953235445, 0.028654049834116336, 0.039961513342155565, 0.021330530815307173, 0.004448583039770564, 0.04410532122898487, 0.0517316384150857, 0.12579000539957516, 0.036056422282971685, 0.04176732813639026, 0.09188584202239591, 0.11885532388283361, 0.1684386947102124, 0.10382744438585736, 0.13588555037013947, 0.16404240722617797, 0.14011260903170034, 0.17171638657248792, 0.11746610770182264, 0.24186653685906243, 0.1486147907111914, 0.16337981778046778, 0.19158673082147876, 0.06363651069301753, 0.08166639765183772, 0.13005286334983765, 0.09229303307590947, 0.24301111818321292, 0.21456515506630947, 0.0967763404872629, 0.21707095205783847, 0.21727945054731063, 0.1267049365466641, 0.21494907236868338, 0.1435325174562393, 0.16083974601520648, 0.13274302706122398, 0.22481789361805687, 0.16708209089213805, 0.1745476636795267, 0.09199618932700927, 0.10409806494510944, 0.12667711223325423, 0.26824455287668014, 0.08914811191179099, 0.18145193916655358, 0.0955744864298932, 0.14994698696799819, 0.10083107533113611, 0.13771441675001575, 0.16792380701630347, 0.11792966750480476, 0.4167260902543222, 0.23141519767382454, 0.1048965813712247, 0.14359101593013734, 0.2227427299705244, 0.10952888522297145, 0.10870135704716367, 0.09997739291359341, 0.1942815829909617, 0.11200498864655534, 0.21482654426607395, 0.10663039156145628, 0.10593511314401705, 0.09747228540119626, 0.13567743492462944, 0.13189993197879485, 0.17722566191467548, 0.21984500239693353, 0.21461793852429237, 0.12599327150852452, 0.08795783344295718, 0.2126894041054672, 0.19982838131968053, 0.10841059603638227, 0.1264004549011588, 0.126661644918063, 0.09957931830637878, 0.12828284018342534, 0.1639424940390933, 0.16203383194102397, 0.13012997776029572, 0.16296442958616442, 0.10570088942204753, 0.1775484760442088, 0.10688798096511634, 0.19109795140402933, 0.2236920354827758, 0.14391203741392783, 0.18025057540545542, 0.17608230633120384, 0.18620344629931837, 0.15765701841202476, 0.08852823186785945, 0.11013069325276922, 0.11351820381899035, 0.17564830220034047, 0.13393447764458197, 0.10252433648753552, 0.17976075410842898, 0.18969849262747074, 0.13788977427588356, 0.1518126562117569, 0.22233616710910875, 0.10500780967695099, 0.12349587084064562, 0.17602576904239195, 0.13534533580945385, 0.06662488945068852, 0.23885654676104748, 0.15380169625484175, 0.12775418588951712, 0.169446345478777, 0.1628918657379766, 0.21384392925087484, 0.10280859341183979, 0.23006902797327888, 0.12591216577998093, 0.17383097310460385, 0.1667565188460773, 0.18098850193763935, 0.2988151689210246, 0.09116873009911469, 0.11827165681508281, 0.09766390697369653, 0.18637223079079585, 0.12770565421951394, 0.16972253549723856, 0.1902963782870962, 0.23239217428190095, 0.152898034261119, 0.17041078888841216, 0.15371431626619833, 0.1858727874294404, 0.18813443219950124, 0.1525559300376523, 0.24467268628218483, 0.134964544145811, 0.20073244167912394, 0.12883081521478393, 0.19442764531460502, 0.30598529223953524, 0.09212683030073682, 0.12288640193160504, 0.08966467733825408, 0.2134570548491132, 0.10996999864977215, 0.126668838483672, 0.13616728686517285, 0.1851767046196807, 0.1339166431177047, 0.12125861064921464, 0.11825956028675842, 0.2022598831043128, 0.1312104528469424, 0.11547276224460333, 0.1848159691378955, 0.10723136455541658, 0.08848744534677075, 0.18077025880977032, 0.08839124002523961, 0.2060332185318393, 0.13273426301537022, 0.1138404357217012, 0.20950387262048262, 0.1305640891434685, 0.1312771178181133, 0.27528793460899786, 0.0860629992319211, 0.1593289899850084, 0.12326170840571005, 0.12553258453525845, 0.16985833224269653, 0.15813744747109953, 0.11878911090353805, 0.13654291509620606, 0.16003492468547437, 0.22498326135739205, 0.06427594896165595, 0.1765012032082004, 0.14022012181099386, 0.1704855743915804, 0.1776654729920049, 0.1301516427267944, 0.13136065204537686], [0.047568402538496646, 0.04312192480410299, 0.01516076606593185, 0.05607784290107028, 0.03338021286312611, 0.04777461042507522, 0.06152464377303278, 0.08363250868334886, 0.0335477294790889, 0.025109435702043197, 0.024330873951135625, 0.022922963309552402, 0.03983471046892866, 0.04585472513891516, 0.058066113025791226, 0.0589716557653681, 0.0606458030280567, 0.053078899790923444, 0.017770424470185273, 0.04680939709707614, 0.012835278401091214, 0.020930713358064814, 0.016312877076768106, 0.030835586705154953, 0.035221509019573854, 0.04021285529879313, 0.0464119276993217, 0.04535073887616877, 0.035918511134842714, 0.04894336565367637, 0.019155264373928792, 0.08406068288510846, 0.03385610668168914, 0.0727536081666908, 0.060000408425807, 0.029658603692247026, 0.02468327056586502, 0.030355904581806356, 0.058364465967902256, 0.0563642218889248, 0.1147257958749129, 0.15957188582228077, 0.04935888025248724, 0.03137303568843392, 0.01749601752136744, 0.06882223646126448, 0.035037835609287984, 0.06501469520791885, 0.018867709441110492, 0.07751787066339486, 0.07281972921543545, 0.04249916426957615, 0.03022183344939784, 0.04914420326390574, 0.017952173084561384, 0.07002383004873991, 0.03390067767712378, 0.011437234971972724, 0.07415188716784601, 0.02159369159339657, 0.027262793944006967, 0.011468671389945574, 0.08075712023362999, 0.06446912569264251, 0.03784789591126385, 0.009509478132390689, 0.08334326452665752, 0.09077343639106521, 0.005151501269034681, 0.07578177753114894, 0.016066828787687327, 0.07217824549203919, 0.055796520093516, 0.03560347279774086, 0.06563144195224009, 0.022590530946129755, 0.014842641352105045, 0.031006937591178767, 0.035914795608409954, 0.03727093211285049, 0.04636687789893439, 0.02769431211955605, 0.025264528287093968, 0.0020723157156739506, 0.04565491025606471, 0.0635470201321427, 0.056606424416625695, 0.017021749724423694, 0.056095642953990936, 0.033413499383436095, 0.013424873074156143, 0.0657357295013724, 0.0213408979001425, 0.024283043251583175, 0.099742257546994, 0.03454100077731475, 0.02018377188623192, 0.07038414418216675, 0.04858693941646526, 0.01702321678279869, 0.02370490159298624, 0.02530244580890623, 0.07039035715523266, 0.04926640577914734, 0.0643512707263712, 0.029215542486898845, 0.015561637851679999, 0.025713676061000557, 0.016259078552285512, 0.031964606868343494, 0.006591534456087938, 0.09928575341379452, 0.02917138709416313, 0.05310569754651478, 0.05506883615687971, 0.05217158355780187, 0.07857032991465061, 0.07226113620544634, 0.014390928141262024, 0.03801233285377103, 0.04269406852883197, 0.06035093961644077, 0.01368295660452737, 0.04250755676278665, 0.0756477198052791, 0.05166398136005287, 0.053419617395247185, 0.058603378147968364, 0.01860264493452926, 0.03710135472037139, 0.08534021059712095, 0.032994514406328244, 0.02902695845301834, 0.008955480692337358, 0.018358711048119494, 0.01890810142691818, 0.03194500650880078, 0.05067897232009038, 0.08640140325071351, 0.0542252469477394, 0.0755873367550873, 0.05205725259598225, 0.020935419053139708, 0.04058186836060017, 0.04893154874744435, 0.03863187581901589, 0.05924917877681794, 0.06255079556496874, 0.01487982534472981, 0.03712368618336417, 0.03563634180013211, 0.03454070200302428, 0.03838370929682448, 0.06715326029206477, 0.008013055128450956, 0.05063979458364268, 0.04010487137542617, 0.018088801035417185, 0.009522622285951531, 0.028205647080716108, 0.037581657374938654, 0.06973843165342847, 0.021579913502078385, 0.05242307873202428, 0.015109092477829227, 0.06575446035112105, 0.017843321566620184, 0.04732278708909308, 0.057437534053479476, 0.027486162200089426, 0.08088940829639474, 0.059240318969973636, 0.03383230432988175, 0.03309396027977909, 0.023690468496492794, 0.01870542903611016, 0.0482585481668432, 0.07192185884642024, 0.017218852656022195, 0.03972569232686393, 0.04224747374293305, 0.04823466537580375, 0.028887513213821, 0.01056662871457276, 0.03626107884150359, 0.03769445616090971, 0.04169606663767369, 0.04968717574111877, 0.03526586551038969, 0.01687514347835414, 0.06475872991065826, 0.013106559711177985, 0.055663783869315545, 0.02439130296660287, 0.027378048041775346, 0.022325721163783344, 0.012805494817815, 0.03437695837008857, 0.05156517133957917, 0.04565955274888585, 0.017122181936077053, 0.025790721523545446, 0.0200049746255841, 0.053991149630277395, 0.03776156163263706, 0.05214934019492038, 0.05643031995503172, 0.016110668169154276, 0.024094005310607534, 0.023532315390184525, 0.08151426025095486, 0.08269985792257133, 0.08017980403477147, 0.02282353658829966, 0.010910696995955323, 0.052871711311801795, 0.07031079892429613, 0.0528539227502, 0.04518145259710089, 0.0446119275124323, 0.029893059155813632, 0.05277629889127228, 0.038746118680724216, 0.07741936707809087, 0.054878926790890195, 0.03864542408395679, 0.04659875356141598, 0.05291954584179386, 0.03210124822573797, 0.03016190430630119, 0.026912078892271367, 0.04812751648827426, 0.05562487809408096, 0.02704885048461297, 0.04170562741496871, 0.020298799988062634, 0.08690337470221905, 0.03675209523569192, 0.015481461962354521, 0.12602636650685342, 0.04016616990068748, 0.022973320184035168, 0.06953000211186948, 0.02076836783559092, 0.06223587597149515, 0.011999875799031749, 0.013419361071540944, 0.036464739485733935, 0.058830109530038414, 0.0030096920419319145, 0.014776949312597995, 0.061011621503219496, 0.03530715764950841, 0.03723479574546218, 0.11837937643811589, 0.05984377025836899, 0.014726109802722933, 0.07935959965951982, 0.05665738075490921, 0.009904487430298281, 0.04578180505984253, 0.06789779816303523, 0.042258118534640926, 0.06199045204407266, 0.016673162481897784, 0.04743775007345023, 0.07866913227424507, 0.05871035466571489, 0.07232254581345667, 0.019079720443715493, 0.06383693461576778, 0.05891020785296156, 0.024281767715189247, 0.03098176777242653, 0.01872952441654859, 0.043780699131950256, 0.03479382128364617, 0.02288004897925402, 0.0037650853787894335, 0.045104123682024024, 0.021291615463973537, 0.05569607064488435, 0.01770840773749496, 0.05765472764089223, 0.07980309561976502, 0.01794416363531303, 0.04327553309380047, 0.04357379410536059, 0.046517877659249696, 0.08025294244890252, 0.05415835981107047, 0.11102516985227985, 0.03816647357457588, 0.02671761130313239, 0.005702409938338303, 0.014218572722447496, 0.09938779632530867, 0.008775394488756937, 0.009606306857970214, 0.04686586160753523, 0.0822177358091839, 0.05237468495784749, 0.051885706357537746, 0.021065403106472185, 0.031755120125448996, 0.03645652702318565, 0.04592502136684714, 0.0829633385423691, 0.04197630543081511, 0.04295862933260299, 0.03925961975549017, 0.030738324182288303, 0.042986564728761875, 0.02853303667037718, 0.006518506645900949, 0.04632115011073409, 0.0167382933620003, 0.03515739512119082, 0.02389421915605424, 0.056068140397509264, 0.0325380907123608, 0.07464708640210091, 0.006630632710913497, 0.03983146608656934, 0.02482594869610283, 0.0845952283951544, 0.046877529126622026, 0.02945406013168395, 0.04012738286908116, 0.05364436460959335, 0.034816451520929416, 0.04450397806302194, 0.01890668224903845, 0.020930460549049804, 0.017584117632659695, 0.061492104188448964, 0.06070481478086403, 0.023273327876062646, 0.04291593525258284, 0.05230854092646511, 0.029186159184563066, 0.02614300130986639, 0.028018666085817164, 0.02230778896069575, 0.09906757157295944, 0.02370550680244642, 0.03505442141284866, 0.021167656692165523, 0.037788106579213374, 0.053063275427707744, 0.009698230705614532, 0.03440588201966978, 0.08026985767027063, 0.16152704945735394, 0.12952328208954106, 0.10657373935945573, 0.1005814609027678, 0.13161929865037242, 0.08736602286057127, 0.1942797903452189, 0.20082826395669293, 0.1707516520494415, 0.12718816182666248, 0.12949731170890794, 0.12058194050745619, 0.18308468703781405, 0.2030552662308178, 0.1727100792190721, 0.16916957323349294, 0.1871983800083399, 0.13456789446213555, 0.22980915562760448, 0.13928393172400613, 0.0983273008117272, 0.15710932683319817, 0.0937661971716631, 0.09976494907131118, 0.1564965484243247, 0.17724777121217022, 0.21061774914062795, 0.1855753154884423, 0.14829429016718942, 0.08145687260454701, 0.12109254576986837, 0.09814958373505263, 0.13913028512991246, 0.14701902956491517, 0.2181652320488807, 0.10229247997725203, 0.0903818811920862, 0.10312374666213028, 0.11461596184920882, 0.19856759977917518, 0.22738061094235992, 0.18579790999572124, 0.09814900150823017, 0.08412461292238967, 0.11345174569155901, 0.15759940860011887, 0.1976422574971953, 0.13386427334720089, 0.2034034072271278, 0.15455106814061442, 0.0869458006514657, 0.1448422060498307, 0.1002499133708977, 0.1334349883179511, 0.2202600228690332, 0.1263576918732255, 0.1316251822056309, 0.15219199230834363, 0.1762321684509516, 0.17118493605765606, 0.1262449773569261, 0.2129405583705633, 0.16049004219953092, 0.12079101356287157, 0.10889208995767179, 0.17837143833598784, 0.11923496641459004, 0.22571368022791802, 0.18957452427956367, 0.1166843456186114, 0.15318491886700356, 0.18431294048505445, 0.10998946494392811, 0.08604848952663523, 0.08247113471189815, 0.11192705452201829, 0.11688365871387145, 0.20134928035399607, 0.18186824666636606, 0.08995665642883509, 0.18033527408636388, 0.1335637983415396, 0.12074933071891147, 0.06330504360037946, 0.16336517017935553, 0.13012498286702942, 0.15208058780239475, 0.13466497312390036, 0.10370924468002013, 0.09831673645925137, 0.17938802168974954, 0.20799297869445818, 0.06670317597567074, 0.31688188172636494, 0.199694806229203, 0.11527676631005541, 0.2263521225822549, 0.07644020711943027, 0.2535434635055642, 0.15412512325471447, 0.09995287043913718, 0.12058627656510762, 0.10395028658451573, 0.11499968762960165, 0.1270988053311744, 0.14068366629221749, 0.12728891771046386, 0.13672541256152815, 0.22277931832978803, 0.17881209211003396, 0.1272377736806389, 0.21871669278029474, 0.22976000342638264, 0.26610171302191676, 0.14283194537124327, 0.21904661620576538, 0.17474107023689056, 0.18113065721286883, 0.13792035650582085, 0.1736990067987673, 0.13115802178940467, 0.10184258718283908, 0.11386610732804384, 0.20817506247230116, 0.11222019040536498, 0.14308164406928325, 0.17738940554761118, 0.13283393105431912, 0.10795363225042821, 0.21841641695749378, 0.14926486228021885, 0.11871388873025296, 0.17042437928818888, 0.19357518863774117, 0.1746675717614351, 0.1294175006689564, 0.14514537768498545, 0.21622896014202028, 0.14310026000584328, 0.12981669376454047, 0.22533391512209372, 0.1733988535500342, 0.14389444803518636, 0.19163372265475412, 0.1905501985381688, 0.12696756680886592, 0.1824221895226548, 0.1389209133002066, 0.1743545175920571, 0.14640240539466182, 0.1251637131997174, 0.19827015848169405, 0.19392729796949895, 0.1102924986832565, 0.08272541461572533, 0.1186472467417198, 0.1846158976155904, 0.0629036863064093, 0.1057659226259397, 0.16211155922182147, 0.11040698286266097, 0.09993583264370119, 0.13439212324878863, 0.11861642702452599, 0.20056822307167516, 0.10668898196590525, 0.16131590030366377, 0.24391634299630122, 0.17191002295622904, 0.12761743919503304, 0.09121553807128822, 0.09437042603930158, 0.15097906061958882, 0.1848470723076213, 0.053707758385327556], [0.06665057637878964, 0.051069654178835695, 0.035553673252223, 0.037496089184236144, 0.039382695610965454, 0.047236897141462376, 0.037329177777733535, 0.0347674104024566, 0.06552614316704773, 0.06566379384528245, 0.05722217524664537, 0.06391478447063316, 0.06907557407694478, 0.0640940490449148, 0.040326749590495904, 0.04534206676086591, 0.021264767912667126, 0.019727315633527694, 0.0435959531985704, 0.06779712654890553, 0.02526871112716054, 0.05949048115120781, 0.09503475450459989, 0.031695679363404075, 0.06254036144744005, 0.04005739690675851, 0.03441689070314169, 0.051738717067506046, 0.018392014805407777, 0.008231096679434903, 0.04461116142450802, 0.06174074951559306, 0.022838762585794734, 0.012288104889223413, 0.08342969456627485, 0.05227876308884832, 0.025813102782253298, 0.027000044938176874, 0.02484032625122176, 0.07426531414591497, 0.037745106064023516, 0.027484595550284274, 0.018206169535856576, 0.10050618510332801, 0.03804612882255066, 0.08261168120248664, 0.014319983611424125, 0.01665755727088019, 0.07709026336669922, 0.01015409515539725, 0.1002744664888709, 0.045091969697105314, 0.08627112999918961, 0.03580870775265559, 0.011801062576142291, 0.0824680473775633, 0.013152479978969261, 0.031358937755407344, 0.008841697483383601, 0.0331519493052075, 0.02159437341164918, 0.01756187618499802, 0.09008897513511682, 0.04931121043139889, 0.02429264616371403, 0.03479972782154237, 0.03893210567654141, 0.0213946255614921, 0.030349840995885675, 0.006625244239976089, 0.0562631021133594, 0.00835716123542478, 0.12061130465759386, 0.03933453549360556, 0.06806185589201989, 0.014626467619241487, 0.04205908506147323, 0.010391617843490696, 0.06296737119555473, 0.02924877155061451, 0.010536016798728417, 0.06427219513082696, 0.05054157445087068, 0.03317530732601881, 0.036437393977276744, 0.0957993638791865, 0.04570357982189425, 0.0276396268483011, 0.028955246877646255, 0.07104355436299117, 0.02012222821283485, 0.004820613051584412, 0.06991548989448818, 0.03470438817936567, 0.059664555479802435, 0.02425132338107834, 0.05515619699332503, 0.04241636548671992, 0.022602173567359007, 0.07570573564378485, 0.03768954170687545, 0.026656791582823764, 0.024431848169995413, 0.07337941773115628, 0.014827846279067379, 0.007927244183637442, 0.062289900491915406, 0.006766007150403194, 0.020983178889559164, 0.08057841490353308, 0.05915774235261544, 0.03303308693331576, 0.027798304724837505, 0.03217817111421497, 0.014914260996926217, 0.020412334218441, 0.01611343757700055, 0.03337111173858566, 0.0671086663139924, 0.04274712011758839, 0.014028680593436284, 0.01703201147216943, 0.10106641754147508, 0.04027016633640855, 0.03149188465378698, 0.06814260155923905, 0.033726940427215836, 0.04958188461680567, 0.0783075234522262, 0.03304532518790614, 0.026472671926322005, 0.08775450604697389, 0.016873990516028097, 0.056939764594238614, 0.056582089633710926, 0.0674775453104127, 0.012021902742074623, 0.015197153327115362, 0.03600685256383112, 0.08586388531952135, 0.030175630686684485, 0.01812180793363481, 0.043378786424235, 0.06785074504272592, 0.03487828247729809, 0.04930231615059799, 0.020611003799844655, 0.050032018728914766, 0.0798703658003961, 0.03344768605705711, 0.011518855894645377, 0.022653248649270787, 0.04875976502174332, 0.06702376845022363, 0.02932080105247517, 0.05237420998333443, 0.06314196646393788, 0.031119947051329, 0.029940024176011645, 0.07016082189135975, 0.09435389386189562, 0.10741508776141752, 0.0937241236228616, 0.002757986911737751, 0.038430620690867785, 0.035043983464880336, 0.04235512824849256, 0.06144751404081622, 0.016932977370977882, 0.030673721902853543, 0.04098367381600603, 0.05949502788303841, 0.021003156547404585, 0.11499597976404814, 0.015192770346578573, 0.05010528737799295, 0.06602594658972756, 0.08704634203064827, 0.04256917321453652, 0.007141246591814824, 0.041325237947486104, 0.021659374056804567, 0.040466055018647064, 0.08386850972930271, 0.025937266482581055, 0.021789733493219943, 0.04617063681625071, 0.003271824825787917, 0.0701208474234708, 0.03555265818572333, 0.02533830829986161, 0.031126594779291944, 0.04639633014918335, 0.019964176613176544, 0.06476269058522678, 0.03139157693142132, 0.06523680707980549, 0.02590242288856497, 0.03922354084469619, 0.057282841749369144, 0.015299852201414686, 0.023391081335683985, 0.01952361668490114, 0.012963482257609647, 0.03957950742915273, 0.03509288668752678, 0.05100735590883321, 0.013951168774867491, 0.0162352551330602, 0.07591403495039671, 0.060194389549114054, 0.044490724741931886, 0.0491007584177198, 0.016536881185827718, 0.05691147296719494, 0.018024035962298512, 0.0578486742902427, 0.07915074110872324, 0.047078811067847476, 0.027909234256273317, 0.016179981889323364, 0.01707500624169986, 0.06466506800103573, 0.02361794103748135, 0.041656115152422464, 0.013538095123705365, 0.049826730147845326, 0.03904161411487768, 0.026991878440904043, 0.01414740123906203, 0.0472876581273252, 0.04510881597056024, 0.04289631191040239, 0.08513931936073689, 0.05177346298531179, 0.05474299981048512, 0.017102196617352388, 0.03039487164407488, 0.07043631476981026, 0.039524253337614, 0.016839999194827773, 0.013918224121293715, 0.026861951844165885, 0.020510155985492374, 0.014034645545536713, 0.04594761713017379, 0.03765954936463987, 0.03565460916668658, 0.01726283950941457, 0.03323724936513651, 0.09843517365234514, 0.02534248922470837, 0.02723603449281185, 0.029067838819877758, 0.09733862604104704, 0.03484766577340422, 0.051977307490643956, 0.05074121313349855, 0.05611573744024481, 0.04734023091112895, 0.03045080755386622, 0.07218183078352483, 0.03329263752206199, 0.008843270836458092, 0.12384198170395629, 0.09708531906888371, 0.04271691710117363, 0.09220854123874057, 0.06872526505180905, 0.04081586608663201, 0.038351261642791575, 0.021388284268698866, 0.07182503299367043, 0.046261379930881724, 0.050821445521808443, 0.06614746345627694, 0.028194268759820732, 0.012390493497913404, 0.0585117502017848, 0.05444501459057774, 0.045098427818306995, 0.04637505205708646, 0.09464417989816397, 0.07557517127884973, 0.04182827043076677, 0.026510145117138183, 0.12570732152990757, 0.01330604900666062, 0.03640552471962668, 0.011835207114927472, 0.015525480416873771, 0.01009710491710012, 0.02105975895369005, 0.010715387667709542, 0.0663565518334508, 0.03273495232626315, 0.049690182636221575, 0.036769611836080594, 0.14242286974143598, 0.04663862460743516, 0.036634466265358274, 0.037158876432165984, 0.041102739201197704, 0.023453293420794993, 0.023509832624826702, 0.015167254830650507, 0.04006809915506071, 0.07649521989327285, 0.056270563809741894, 0.019598402188069398, 0.022897351075023897, 0.04587773842016055, 0.016276463002507246, 0.05861468943617037, 0.06689081389096475, 0.014222075659481269, 0.042053385367316586, 0.04108707270314617, 0.016185886511999755, 0.025992007295210517, 0.03904085951827226, 0.10478035051135287, 0.03934752834480136, 0.05435314915713765, 0.012532816354876325, 0.03984594514833824, 0.04019027868766458, 0.018758595538055225, 0.034911936719811736, 0.03676989145817296, 0.0451122097400648, 0.07361087587571914, 0.08550356352521528, 0.013723509468799158, 0.0356668014560015, 0.059177901956342885, 0.11920655221347848, 0.014019870582307059, 0.008660894987593976, 0.00651689259440548, 0.017332917402288126, 0.05133491595305743, 0.06451682998768746, 0.04737585399960799, 0.03856961968384924, 0.022120562817661032, 0.1318944621110155, 0.03209958581494228, 0.022577273794600082, 0.05812828872172583, 0.05167037436378099, 0.02855431667769388, 0.17244812311424365, 0.29970085849204375, 0.18202731716296366, 0.18402291491868036, 0.15569399471484846, 0.08194441095955911, 0.12106831440882337, 0.2636649405523654, 0.19188968795201472, 0.14289223649088414, 0.0928978748138874, 0.10161813108190414, 0.16782780087763266, 0.1448336718303542, 0.2767585782754806, 0.11032278979978255, 0.1711605284963885, 0.179891693856447, 0.16044456722034564, 0.10636927049246528, 0.1459492950309669, 0.06579586740342841, 0.22082185643094204, 0.11545905693163795, 0.2704938176658846, 0.21020409230503345, 0.10219210713741281, 0.14697182322702101, 0.10913873962577313, 0.10733096364645228, 0.18105467661253868, 0.15395685970302553, 0.11745786459575738, 0.10655736806051386, 0.17199325074832286, 0.06853568127318736, 0.13351063183959455, 0.1095355501879127, 0.15469641034160891, 0.17492965044033143, 0.11067763406543002, 0.15152995444593892, 0.10497344297266777, 0.10299708168472975, 0.1002473010110759, 0.135421852671331, 0.16362698838835762, 0.12875356290849949, 0.2069127027906718, 0.08774155916105356, 0.1688941646247141, 0.09678697378765191, 0.10086556460948722, 0.1317426388061816, 0.14940963757614936, 0.12771675483353678, 0.1745457637814745, 0.1985849286880224, 0.08596501658640562, 0.12126648603307626, 0.08337088199632783, 0.10943011350689397, 0.2142029946609851, 0.2367911737171873, 0.2234981692726574, 0.23072951833807656, 0.1503530595331423, 0.1197285645250832, 0.13541432968791456, 0.1061021049897517, 0.19346392202761867, 0.1750440580109435, 0.2177705129067744, 0.16596216227739088, 0.22080883293622927, 0.13533499362247606, 0.0903670956951476, 0.08205126490323775, 0.19119332935060226, 0.16271687593431244, 0.12643378738674427, 0.13728946777841738, 0.15871371412950178, 0.11810046680752309, 0.11789409038160117, 0.29778162438061934, 0.17181240803291722, 0.09241735382426171, 0.337750239357833, 0.20836399507618722, 0.12034498951247624, 0.19328946848550152, 0.22563520218095473, 0.17799404810272879, 0.17211093717525083, 0.1275753733071108, 0.19117612301582293, 0.12262272978982619, 0.24357031640266222, 0.12089699416631654, 0.0981517441029991, 0.10670815714664998, 0.1812373732607211, 0.1478129724461225, 0.1857707138744093, 0.13618817042198875, 0.22423634095297706, 0.22656944640461477, 0.07458740815279946, 0.10617207179987624, 0.44879443883415193, 0.07062176933452007, 0.14922481120353745, 0.09958030655980112, 0.14722912151726986, 0.07869010776161187, 0.14538398342988185, 0.09131481540539572, 0.13527153089882868, 0.14525241548976592, 0.19035245592315353, 0.14033054572439965, 0.30862305553690084, 0.10723644371835456, 0.1371299682725822, 0.16926856711506846, 0.10885678862612094, 0.16088767247574945, 0.1030994080487759, 0.19992898398589706, 0.18159680639303502, 0.2097894395551374, 0.12572539354404136, 0.13400420696744997, 0.13951460079800698, 0.2564088621687505, 0.08076099663852684, 0.14408684335649014, 0.1558931469316444, 0.25753075196858377, 0.1697349614433704, 0.127425572474397, 0.10563387971131072, 0.15372280452039935, 0.2275947171954378, 0.24475039824122385, 0.091503250052131, 0.14371768090753786, 0.13966509110985265, 0.11117792012350214, 0.07919516654745226, 0.10391155317906411, 0.1479924668467814, 0.14601070463897722, 0.23995549988842782, 0.15186851934319542, 0.14877053638619764, 0.1111335636326863, 0.10419466863236121, 0.20507461271218716, 0.2131220139563084, 0.1464821704693379, 0.2011347144481636, 0.20169821808174734, 0.094816358159146, 0.19123370218421185, 0.09995556706863065, 0.155885087686681, 0.1722089198207663, 0.0997723801241767, 0.28009136718127037, 0.17310216301871886, 0.1163726857292556, 0.18044215867355948, 0.1246142672795442, 0.14620538290229537], [0.027259666390056093, 0.021234497863558993, 0.06567853337694561, 0.010576157890740904, 0.06746554071263922, 0.019620785361997062, 0.04683374337130978, 0.06862601836121852, 0.04749917500321904, 0.03399283039353548, 0.0047974709718067565, 0.1131787042944662, 0.05514497763567394, 0.0294206912569221, 0.017285119261472456, 0.030513672728932677, 0.05318248253916541, 0.0980079034343362, 0.04369107833612831, 0.010512632922449661, 0.016443014347685442, 0.03710531539493992, 0.05838362582688851, 0.013356092742704337, 0.05396472342732934, 0.06850842386484146, 0.08027692866181174, 0.019762879350192605, 0.03319583465194991, 0.01576392911374569, 0.051755647610632644, 0.042196207139040195, 0.04032163212316171, 0.05446398292758292, 0.05075349352292476, 0.07060966514531644, 0.07903902250672541, 0.06924886316541704, 0.06388606000391227, 0.006108986206292626, 0.011557451404270627, 0.043111486856134675, 0.06574901346597942, 0.02422282874073473, 0.04305694905680515, 0.032674377754090295, 0.09068486130525989, 0.0027890024601571984, 0.0501023072959675, 0.06786256577939757, 0.08877761646985047, 0.041490287760332714, 0.03581125499500382, 0.00866452720196497, 0.06930057410030596, 0.005884533456992359, 0.013187616601616386, 0.028801828194710038, 0.02629943263356484, 0.027065472677350048, 0.04141483576067033, 0.07714781189157117, 0.024971606908366088, 0.00294423820788882, 0.08489088470777197, 0.05970507770055725, 0.04732816885676115, 0.028972937763037703, 0.031641442253584826, 0.028734573335837454, 0.051015694775889, 0.05802667098900965, 0.01589088807738717, 0.09874065121215198, 0.02649497274579781, 0.07542482652370969, 0.02034620933925673, 0.04723001384146271, 0.005904112749117157, 0.09319749946195273, 0.02211787767948643, 0.03858761891963021, 0.08126028678229741, 0.009572152743085979, 0.028671039749057065, 0.048503761420086514, 0.08466442145647542, 0.055718107164026275, 0.1025185525237072, 0.050647179671232744, 0.006114013658295716, 0.042359625184608084, 0.025486061762597774, 0.008235072675761918, 0.05190963894429226, 0.11170068320127265, 0.05309815541090024, 0.06785484361312083, 0.03761505880843728, 0.04097131298734777, 0.06873441214162497, 0.025727061532257546, 0.035062595571000735, 0.027303695378284303, 0.02709366662818338, 0.0393028462666177, 0.04669147701333127, 0.08622438331405002, 0.06331951500126912, 0.07262304380175567, 0.03704307075109213, 0.0029654272422645124, 0.04063524553672441, 0.03331125345862201, 0.02943773288279772, 0.038827641927186525, 0.07531364418325887, 0.014153284794320504, 0.02248765682921775, 0.022098145169776776, 0.00950749013422718, 0.07026573763258996, 0.055178593573791374, 0.0076236004467993505, 0.01797133677398726, 0.07727892017893254, 0.04998310784538908, 0.013348503684204434, 0.027216079817604155, 0.02016948434644409, 0.04623701067401036, 0.06843540036389906, 0.012768333807827966, 0.08756620163518576, 0.07389756129874338, 0.04069809539003238, 0.026794457582816966, 0.10852558583381677, 0.054805029949714104, 0.020046550217234803, 0.029897667174678177, 0.030063075133629387, 0.008408720867948668, 0.040605368107677474, 0.04424131332686351, 0.07398370022494948, 0.03394629821301468, 0.01324507989920676, 0.032582125446248444, 0.007419630973374532, 0.07287465771960636, 0.12236406786307213, 0.008669612110562382, 0.08729450855283968, 0.033596276470850554, 0.07540368249699955, 0.01110357878309104, 0.027149541250940774, 0.038409300463935064, 0.03619911381974816, 0.05681670406052182, 0.046132799733670495, 0.052183814151513006, 0.01682606405548511, 0.01848945352849701, 0.03892899919000845, 0.049740441834494, 0.06871564298748009, 0.032317897890724485, 0.05018043294248562, 0.004253026648169203, 0.08794692435091542, 0.024182919390319337, 0.02797744289461163, 0.11699584462950308, 0.03688986848799452, 0.06621488685449285, 0.05184623750767881, 0.03405164679392211, 0.03288016812275014, 0.043756709088601416, 0.01844845250278952, 0.05513162089271411, 0.04195778142480601, 0.03244021914959435, 0.028253085160207365, 0.03956703934818506, 0.04495256084708437, 0.0638233365551118, 0.020413441215491584, 0.01610592416968317, 0.03673368614287146, 0.05088925579442613, 0.04684847524209369, 0.05203171888546598, 0.01348010322544724, 0.02456660303587635, 0.022128510979875442, 0.0733270556215317, 0.04377525607724825, 0.05583094042395392, 0.07672302379843689, 0.0475082416538029, 0.09960462985139701, 0.015452389883237983, 0.04248107310324427, 0.019014547428777142, 0.04041085072282342, 0.053655488206253904, 0.029561783585156647, 0.026500155330605568, 0.0479113417978008, 0.053973192529332255, 0.056034470833237135, 0.06360218995400975, 0.04495619210384546, 0.06441454958891676, 0.026077519944538514, 0.058585624060323166, 0.03466788025933408, 0.03642730842975359, 0.05765999066493204, 0.02195628866883776, 0.04876321241740258, 0.07652700488125125, 0.04107148664432668, 0.046156785946579716, 0.010517183484719887, 0.009398846417635439, 0.029751884473127224, 0.02699962933547795, 0.06194704550228292, 0.019858919962820028, 0.04475899341125642, 0.022392495302483443, 0.02983619244919429, 0.022689618673476002, 0.021303445776744236, 0.06950361038287801, 0.06907342136987756, 0.06602747110469688, 0.0293134868280181, 0.030327741274489995, 0.05073991078402727, 0.024037274584594755, 0.02008557473609765, 0.04068355504122954, 0.08573831584785255, 0.04205590196614785, 0.06504187600747233, 0.012803301891131748, 0.06048395163229397, 0.018736375157811472, 0.05632819277384589, 0.05674343541144364, 0.16390359209429833, 0.03338346490636468, 0.04674967288249924, 0.02787988159745451, 0.04767536373448469, 0.004206701790192916, 0.0796712595488756, 0.04872277446631943, 0.027375489308108247, 0.062126103232825, 0.06657640374596081, 0.06333880509520251, 0.04109552265295098, 0.03730213104356681, 0.02368316576335459, 0.029002324895813104, 0.06319463500873217, 0.03413840625134688, 0.05862965879421081, 0.03374815723227878, 0.02134376881463874, 0.024586427476136916, 0.019160519737089356, 0.013453057448890422, 0.0421560641318079, 0.02531948551956204, 0.016163796366703127, 0.1524680137874619, 0.09154787467372033, 0.08412858891871669, 0.017544024421142477, 0.020017557619740407, 0.05209381031172891, 0.05944220612065927, 0.061195497926805294, 0.025843194715919036, 0.04911250637603864, 0.08224201313550435, 0.03387941490678537, 0.009606449541846111, 0.04398796038942472, 0.007633344606391245, 0.04228445663747769, 0.07211369492353932, 0.0026760080823629738, 0.01167213955458494, 0.04833071747975004, 0.04350709466023311, 0.01605632189180582, 0.01566024964690329, 0.026933839619760553, 0.05033881779039099, 0.05080258060667304, 0.013787051674068697, 0.057348572093272404, 0.021723961014480844, 0.07679633841279053, 0.03759216427082016, 0.010655208588427594, 0.011973554933173283, 0.029158275499339067, 0.012105243532137286, 0.02152172529378966, 0.040712528486525824, 0.02652778237637493, 0.027874566862479817, 0.05859347646154704, 0.05738956162766103, 0.032326608310423555, 0.10573177042627528, 0.059064417521679596, 0.08850567823936863, 0.016371392787644462, 0.027217196390753793, 0.03219330135071951, 0.07311405253506477, 0.09791156787785793, 0.04833021569215963, 0.06915140912056932, 0.037582875454738256, 0.05541548328173738, 0.03764161141589284, 0.08425579015766421, 0.0075975606394481044, 0.009987815771432174, 0.014034661824905105, 0.028041888126021916, 0.02927813570075218, 0.028386623861508507, 0.04217584452201282, 0.014320978568115783, 0.05645371628023925, 0.060109997303375316, 0.05388121601314314, 0.03326663649791191, 0.01904078785540356, 0.0574013134164195, 0.16687682529370632, 0.12098866424733594, 0.15152613932807601, 0.09482961148023607, 0.14175980532121274, 0.1287310552452841, 0.18272962060666856, 0.1573041429923427, 0.16676417972532012, 0.10730362196843471, 0.09474158797773624, 0.1969322931742476, 0.140010213719741, 0.10830965629147907, 0.12372555166122415, 0.19446095481755274, 0.14537836034451762, 0.2809991200845088, 0.1228112793497501, 0.12195529100755531, 0.09294460617726849, 0.1367893502596886, 0.2690562689977308, 0.15545338181959045, 0.1516088615021398, 0.1832746921647941, 0.2821008158066581, 0.2066442655820039, 0.1878217610740854, 0.13636115307529129, 0.1164728210818383, 0.14739756893006065, 0.19209101585851562, 0.1639292100744863, 0.11147046611914713, 0.12833104243562107, 0.23529469756589783, 0.15756746273367636, 0.13971032094090216, 0.08740376035172133, 0.2142028874086757, 0.16194999127859072, 0.17664141262010222, 0.08468203381785462, 0.10117275820624444, 0.19679586823669173, 0.17762986522528434, 0.1872680327224155, 0.1145628949386939, 0.14078583177779952, 0.16287435296802752, 0.08123077707545412, 0.09184743037387248, 0.10475760536088098, 0.065359496060879, 0.12429490054567015, 0.08794568328847809, 0.17115918018164175, 0.12431105733999323, 0.13163959998036587, 0.21509997636800815, 0.26366340837651686, 0.19678315117714867, 0.17947820556019584, 0.21714589077859156, 0.15666786100595229, 0.1730225818051446, 0.12552360598478587, 0.10761530484042822, 0.07334429259982801, 0.16912164677294994, 0.15812197249502907, 0.12758877218490647, 0.19782714515684113, 0.1083957645741682, 0.18102875219718104, 0.13330472272730645, 0.20066235995581075, 0.15851073147308442, 0.31361779558562464, 0.12271206330267653, 0.09692383539532462, 0.13791648010092397, 0.09221821692922423, 0.16531967497881384, 0.12922079993351815, 0.28036109141765103, 0.18039662240734025, 0.17146532423794272, 0.21676856183236648, 0.1599742964871468, 0.19653513787254212, 0.14406044396661943, 0.12796296783152128, 0.1402377571550108, 0.28857042832720664, 0.17663209699094298, 0.10919762880451257, 0.1625933978826769, 0.10392355011595834, 0.13274696475315478, 0.11470248381937705, 0.16698113582547636, 0.10432131828800326, 0.11731807653221393, 0.11250767255983046, 0.2824418475070308, 0.10043579694484511, 0.19090255301806236, 0.17631469144215509, 0.1583989439231734, 0.15699830537121143, 0.17208522726451198, 0.21638200918753303, 0.04493452713734681, 0.17252992598279832, 0.14867532697896804, 0.1555898374006633, 0.08613098187432175, 0.148949004229038, 0.06964314563740646, 0.20576295803391165, 0.17613429305774553, 0.11776334215556422, 0.07710625162167896, 0.14593984150598127, 0.08533539956495648, 0.09694290332375996, 0.10797679108837921, 0.11989734135568143, 0.11318347702223448, 0.18096201061721773, 0.11182097432714318, 0.25195041431053994, 0.1354469497117304, 0.20563335127888188, 0.1964865985416597, 0.15704217156575573, 0.21739011960885218, 0.15496967390419977, 0.11119180929756935, 0.06494348733535697, 0.14635219599210447, 0.1660705483969181, 0.16075438849868315, 0.22908583073125732, 0.12023694047163572, 0.1109822229632447, 0.14124373785190045, 0.1545744185005465, 0.14997396858469134, 0.22795718403593188, 0.06717289512556407, 0.15608283030169626, 0.15726007761493807, 0.2064119570798451, 0.07269036760854145, 0.14390584742349966, 0.21210409760955842, 0.17612922155568678, 0.16497469026475184, 0.22348840931250205, 0.16877200424430833, 0.13139681139540288, 0.10936591533883926, 0.24586609805062895, 0.07762513063367336, 0.13776905414077545, 0.1501875845414977, 0.10557398695739047, 0.17394426218684644, 0.2110091741046598, 0.17507220408128155, 0.1160989471921517, 0.14401199656628794, 0.11236439113535228], [0.06276510100090696, 0.12667063112941482, 0.025067528777365244, 0.05252092731215301, 0.0552182233021144, 0.033323461069695415, 0.035401432429470366, 0.061213749971601276, 0.07971622891003087, 0.02827770531087393, 0.024693202895803318, 0.014234862624547415, 0.03945231385108444, 0.03067142172386089, 0.015854309294222584, 0.02127100578359058, 0.06320179793082419, 0.05809659949473797, 0.022231601516626055, 0.05896844202652574, 0.022239599474555543, 0.08154601459541629, 0.023116297088563446, 0.04079944882241469, 0.02936002666941814, 0.007572702043915108, 0.0420719285255238, 0.06029542888544741, 0.032016273753176776, 0.04382650735938261, 0.03178333514370024, 0.01673261090482195, 0.02658536154476385, 0.030528877659009832, 0.029871593372175292, 0.07656054421057625, 0.022531593886895046, 0.06405561058331402, 0.01986974861562973, 0.062237607330204024, 0.0689924611980396, 0.04986061804717587, 0.022654717622865594, 0.03792507543919548, 0.024145436623404105, 0.019186691215802586, 0.011807008376044613, 0.022575559672869505, 0.08827046626397679, 0.024081684701565294, 0.0523003246334772, 0.027845693008613684, 0.049035165969642906, 0.06452419975351903, 0.08904066808041065, 0.06835720576946774, 0.030853999628415032, 0.045877014467072104, 0.10525593023386695, 0.03390035208975596, 0.022293553131842808, 0.045054852737173925, 0.033519303786658475, 0.031052939255811998, 0.054623850155621774, 0.0028631207486239053, 0.047099464798286084, 0.008426735425488123, 0.043988167233164274, 0.03652861206642082, 0.02104596745583319, 0.05914116037949439, 0.03400068279475935, 0.01792798194313242, 0.014283477606612348, 0.01249756864948018, 0.021281621847001296, 0.03108635218062949, 0.10490416564167508, 0.04679003039435033, 0.03739072145113061, 0.05295630274040084, 0.01544973347336054, 0.04888394787426918, 0.03435743078889866, 0.038395150819973606, 0.05146952143179313, 0.02764754628221835, 0.0019743050600687464, 0.031836400138995344, 0.012610258267922028, 0.06327402470032535, 0.03026278276417044, 0.06568320651328372, 0.03984958789641819, 0.04702983889728785, 0.05484596202750841, 0.05841004819939694, 0.07810360616854123, 0.054343324079508745, 0.04325243171244379, 0.05587108343118622, 0.011041528534054035, 0.025132138717679248, 0.05066584540350784, 0.02534421100731819, 0.03838776573238354, 0.005117629170267573, 0.03582822001208702, 0.056072886312200185, 0.014793003642661198, 0.01830313903009219, 0.03094921478130404, 0.05313506552709207, 0.032806458973115495, 0.03227792342283553, 0.024915657592036074, 0.03382977623973162, 0.05122112891366405, 0.01903744962727351, 0.07785871084178649, 0.050004784303206595, 0.05038464517002145, 0.040841116344616304, 0.056421241813129, 0.020205421530972087, 0.039959211247943105, 0.016639686354826537, 0.06361118765668043, 0.025212654558521126, 0.05025294316451877, 0.08714011885345944, 0.01592870217732965, 0.02231219013582074, 0.06321162300845308, 0.07306408061976395, 0.06403826252226869, 0.08763843606556616, 0.017651751705054796, 0.027418715819235773, 0.04402130819676865, 0.03156344301157421, 0.09535478773496806, 0.042705578999894286, 0.054191558231269164, 0.008909125669649052, 0.05959579525815864, 0.022121771321361585, 0.0572304489962276, 0.018032585503533483, 0.036321967509725404, 0.04334824249869393, 0.035801226904074994, 0.0208861998192245, 0.013727508447763902, 0.04966098319498762, 0.03948406819554587, 0.02830067645728348, 0.034117507372772506, 0.029486804644787507, 0.03129173652268946, 0.015177210143226531, 0.08751980735049134, 0.048372331375796954, 0.043667180223330375, 0.10647181136113022, 0.042613774853488134, 0.04172006434190177, 0.055308782555643594, 0.03508413413299188, 0.02978406974204606, 0.031041809913492015, 0.03464670941954659, 0.0074560790427870335, 0.02685423733876838, 0.021134534880759257, 0.05927377402962697, 0.11045893128480642, 0.022986433694079038, 0.013141063353677672, 0.07257835023225316, 0.02309093766304995, 0.03566811146635202, 0.03500855955926161, 0.06288247333178598, 0.014078397784502277, 0.03714024517384749, 0.08639319078816522, 0.03314837550504073, 0.03032514040598706, 0.012626593177687499, 0.06154663815733887, 0.06000071486097671, 0.07378660878466983, 0.03437767083185815, 0.04562874835345053, 0.05604341490975311, 0.028048656512832934, 0.06160538560981232, 0.0051953837429473725, 0.007108903317261608, 0.05323246211534547, 0.1288271379927474, 0.01960070045184224, 0.06048831450302274, 0.015916475414058134, 0.04097988551122047, 0.025880913054870985, 0.028843095435971217, 0.043187452134706324, 0.023661975771368995, 0.03150894543186071, 0.05114420985562667, 0.05049316535493539, 0.03793540996529403, 0.01256120757335016, 0.05620472621352923, 0.05141177372406087, 0.0170505833586738, 0.007174598708403327, 0.052070210973221454, 0.048311327794386495, 0.001073552644342154, 0.03441302962000332, 0.0071373539075495745, 0.042741822619591995, 0.07182907027703139, 0.05435622500015363, 0.04204545252686066, 0.05049766612149054, 0.10564306510552283, 0.0661608470123141, 0.013048623354294369, 0.059715247517752076, 0.11689101315794453, 0.03548661757621073, 0.012210302914853298, 0.05738128787807881, 0.03776341939585344, 0.004101612242764884, 0.02916358065821471, 0.05092698179425732, 0.03330358874893958, 0.027469800477246606, 0.03683600867647798, 0.024005460868319197, 0.05116067308511946, 0.03869960182196191, 0.039815565931700894, 0.026169057875390977, 0.029239034573096904, 0.02808404211405545, 0.024952343627510053, 0.04609672848375575, 0.03307591124828304, 0.055600665885234074, 0.062444987331306746, 0.036403230286293456, 0.07065714727486334, 0.02335803804828996, 0.05649074130961972, 0.007712579643984716, 0.03938411287362537, 0.017003825182215344, 0.0519995431926462, 0.03234435473718951, 0.026065371705279238, 0.10394350670638586, 0.050306998328456, 0.03416401274021595, 0.012873089628203983, 0.04858850989671004, 0.019799511759511886, 0.060142571361915725, 0.026853482742162964, 0.023822800609313195, 0.014914537746188863, 0.07389312564966179, 0.0781705928966403, 0.042505867538913604, 0.03353120496256217, 0.03458125869773569, 0.03593525781686749, 0.08347873185430804, 0.04010887801527016, 0.0977532098430299, 0.03127355725624629, 0.015203318419686009, 0.09469487193611362, 0.03828550448581096, 0.026894236704514875, 0.03203974285673711, 0.0033996695785918425, 0.04926408453273678, 0.03669381509685228, 0.021841289295304208, 0.09117875052916427, 0.054971914543139364, 0.024667818572432287, 0.04339567483252576, 0.10548955640725552, 0.011230913129815412, 0.04752981852019026, 0.008806025556799386, 0.0557439741227896, 0.04247366503301648, 0.034001996635549495, 0.03078698225679898, 0.025011836100489866, 0.03579358134659068, 0.058085721046213186, 0.049709656591256784, 0.06739977206433974, 0.12324992597343461, 0.02651848398419398, 0.03513108383143141, 0.0334701439245574, 0.029127676032423496, 0.05198363920733814, 0.061945800609405965, 0.02407962392504898, 0.04925587973106773, 0.06300097181191368, 0.053134008325756564, 0.08662543800329009, 0.04060729098836741, 0.03832992226366074, 0.03540042885428956, 0.029138950931449092, 0.06165903474714968, 0.07506762270725544, 0.014710246037030894, 0.03271042985180694, 0.02504722744737181, 0.029011567746619546, 0.04225484350876462, 0.05604647926145023, 0.03255071201091332, 0.13910682751767098, 0.044501342720562415, 0.049414413966118335, 0.0418836317746149, 0.02207963265508654, 0.076428524278585, 0.00540002067047622, 0.03943299311363409, 0.05071927237534716, 0.04918162282856722, 0.009519504308099709, 0.041316638610536055, 0.0386291753590828, 0.06416076764224038, 0.17251599850433488, 0.32203394559121906, 0.1954813073239019, 0.18199219969251465, 0.18385661255207755, 0.08840109191594586, 0.12213514546953863, 0.17146461943705238, 0.15709457197977653, 0.15579144109881696, 0.12113095741839179, 0.19795620032856542, 0.11555545377515017, 0.12558310803386474, 0.14952707885494157, 0.19624495908858317, 0.16685431763049097, 0.1930257810219642, 0.08510925040970888, 0.10432885659317817, 0.11132983535888696, 0.1658106454077267, 0.11939659564485473, 0.11924096488303716, 0.10251957908152573, 0.0991691318490813, 0.3068835762960296, 0.19483080674563685, 0.0980839146781833, 0.13721218482861597, 0.12236785233741808, 0.10315017669551796, 0.1615873405769948, 0.12424397868134322, 0.12267491569922817, 0.14152046413190905, 0.0808364256555515, 0.1936052805714069, 0.10680596359194287, 0.21885616674778924, 0.29939705866479105, 0.16496326023292157, 0.1477333146237558, 0.187749243191173, 0.1011733404330669, 0.17443457378014443, 0.1937818944814705, 0.20581681401498858, 0.21847284699399627, 0.13122244978383665, 0.1106283592901403, 0.11461790771253648, 0.08233329251168237, 0.12599514076305976, 0.16334401083088693, 0.2115739954094733, 0.1286252738246995, 0.18241363998141982, 0.20070997998118403, 0.11500615341168259, 0.06891176149609589, 0.1173864575403352, 0.14785167520805714, 0.13578736854176368, 0.11108073420942792, 0.2276602330347223, 0.1411269707304816, 0.08662462595009035, 0.14904392252285636, 0.09724438190460206, 0.13072499825108436, 0.08493924017755256, 0.15502579750553255, 0.12638010760588994, 0.08804243253243547, 0.1263442010648789, 0.1263162235338842, 0.13567764942924823, 0.27143399141007857, 0.13671675576798378, 0.12161708617162321, 0.16574321434863154, 0.18401609673615427, 0.09719494625084824, 0.22482950751098896, 0.11818774720473636, 0.1581126568658698, 0.1458939068740414, 0.08275163780537345, 0.17016714228497398, 0.06452560169442047, 0.18831735867406094, 0.141648814502743, 0.10153817448524699, 0.10716328232158577, 0.19164775738552695, 0.10817081051608247, 0.15076686958632163, 0.23140218950087027, 0.12119644261415928, 0.1414158471649693, 0.20814930659628686, 0.19202004547321028, 0.38175751665426844, 0.11193106116186227, 0.15704704388495416, 0.10122052378832333, 0.16673730536093637, 0.10230927262455226, 0.2263953299411843, 0.10787550660391008, 0.08431163030646502, 0.11926798480412654, 0.18067652029135536, 0.08894487644635862, 0.11051250381335137, 0.1433149791292606, 0.15506721221871916, 0.08605688585028534, 0.12403818448224377, 0.1578390562245923, 0.22300975757741162, 0.17188553878616902, 0.16536841349255654, 0.15635073124881715, 0.19109985130208154, 0.13580368621455086, 0.13562296607321309, 0.23758254254296904, 0.18874842102729505, 0.08754484310385682, 0.15127642530827753, 0.1288544873316442, 0.15378773813286137, 0.2855927977831133, 0.20155944891514319, 0.24079580641081258, 0.24887443339872747, 0.2587089339090932, 0.19208664915734724, 0.21440539509058001, 0.13804640861288195, 0.18635220525245513, 0.1380657446720908, 0.14107683793671671, 0.09798946369799877, 0.1604334129801681, 0.16240915373688744, 0.15723006229006475, 0.16236879622503636, 0.13363889027987758, 0.13127183181143579, 0.14508864121331325, 0.10120933890462884, 0.13517226122560042, 0.18594961072648727, 0.17780269466100201, 0.11945969064629848, 0.19486649112114984, 0.12282256382487475, 0.1865900142659103, 0.18951214940076877, 0.18666426350753154, 0.2536785094848564, 0.17348523762437607, 0.18903498387625142, 0.15117859588034693, 0.1581739898650877, 0.22974463570262157, 0.17668261282867, 0.0756269435007726, 0.16907231071062628, 0.12027741289667546, 0.10453344803423652, 0.08952521869251806, 0.13349924777303973], [0.014864991009686024, 0.049425399666952516, 0.028129455806206793, 0.0687240393111302, 0.030010262947349303, 0.05163193207174059, 0.028870988697294268, 0.12182983644907514, 0.05960974188882017, 0.06277304533268176, 0.07566366209498337, 0.04863822517255622, 0.038779849532030286, 0.0958633628643809, 0.05042751545026418, 0.022287541256857016, 0.02278046329475699, 0.041875909608338154, 0.028191627671701774, 0.02497282307294588, 0.03021481416879162, 0.07279389673062871, 0.0813902382768931, 0.0233331861560263, 0.08906687594830029, 0.11895326822395287, 0.0363367491762244, 0.03479452608453651, 0.0321615508366977, 0.016442686845097813, 0.012397973388884098, 0.000684754883085618, 0.04298583694523381, 0.05238453684855373, 0.01302345832359166, 0.024908774292036414, 0.05918250231432819, 0.05245796637609602, 0.01434567436996487, 0.06926560218656255, 0.08475097407016062, 0.019103350425739924, 0.02791803469130349, 0.035839025682258996, 0.0449870539558751, 0.03283995233716504, 0.02074305246013307, 0.023545038195387013, 0.04434655848590117, 0.017420266747414585, 0.019076449248278816, 0.048661487432377, 0.040133538385552746, 0.024795730357929587, 0.024051154182562907, 0.02919547864416194, 0.0613666687821669, 0.08684486856744175, 0.023654567701141202, 0.07425304907824724, 0.029334822376709313, 0.027523639221345226, 0.0276754567805197, 0.03218629930709158, 0.07033041077515773, 0.0662828311924973, 0.01740055338990304, 0.0549173882351287, 0.03543064336202318, 0.04697659195611074, 0.035252815202599576, 0.061056548729538924, 0.025823697778246096, 0.061334910607265855, 0.026195554941472028, 0.05343460590548573, 0.07313295192415677, 0.07643364174591918, 0.06928024212679557, 0.044736684930901376, 0.022424213257768465, 0.009923407886808198, 0.07140287258211644, 0.04096375169953512, 0.03814315002772116, 0.09061166926497415, 0.02233059731342139, 0.012239371163530216, 0.06732456521281312, 0.020347322081966747, 0.005133358391767909, 0.02398966030488091, 0.07705202791839838, 0.013458063833475595, 0.0129802614983712, 0.06169632790730365, 0.0685490571683453, 0.04033591966294954, 0.0244296437519933, 0.024928340177622535, 0.03383434595419996, 0.018431186796196045, 0.033398771343091806, 0.13057604011508728, 0.02367638205478509, 0.06297299045047934, 0.01985588625463988, 0.027702187503417654, 0.016985486952527877, 0.052846150788208174, 0.03750484939965029, 0.03345888243207047, 0.023873278142644033, 0.059563975796223655, 0.03288463058490907, 0.04079351547144113, 0.05565272922056818, 0.05136450992957239, 0.03810416381325453, 0.042577102224552826, 0.1224630694055269, 0.01325531387626524, 0.05241083664699428, 0.05149834548994418, 0.03680684370920062, 0.02781189703983405, 0.04686538280258256, 0.02606996823282492, 0.058356556110084064, 0.025963681194210247, 0.002800306087479957, 0.02505598957800577, 0.049114873587724664, 0.02775218048613639, 0.036150298697213014, 0.07467484176759759, 0.04654112076687236, 0.07237179760610865, 0.053798064829841744, 0.05157630259711897, 0.02619828412970228, 0.028552278883815296, 0.05452401740776916, 0.027896168626724716, 0.027379304425971165, 0.041437711146089344, 0.026376543213583292, 0.019536500368567727, 0.08652060653173155, 0.046480998186574835, 0.02222330861484572, 0.04752349446437532, 0.05465566578711714, 0.009640592165411481, 0.008476828957246918, 0.04039547533818311, 0.017949215985173662, 0.028675216843464205, 0.047392095063602736, 0.06384851786518289, 0.03371524609505169, 0.05199825233449379, 0.03310658923921085, 0.010250642343664603, 0.05126270833575437, 0.03131855726091853, 0.015352237293676985, 0.03431185621828322, 0.011598405507092756, 0.016181929667870847, 0.017258656669347998, 0.03911067311081194, 0.02032413068527897, 0.03489643876110354, 0.0491967415737529, 0.06586177394755426, 0.049038981087505824, 0.0671281019646314, 0.04052178408469885, 0.05156399156417578, 0.0043097367855690185, 0.041640195845355915, 0.014230142565323942, 0.02221366548309884, 0.048508629908845316, 0.06722325008482703, 0.04096148024883963, 0.03803976646233951, 0.01945913314909464, 0.07919510526041831, 0.10989769527147855, 0.0043794929215143765, 0.025142480904657035, 0.030984353319170977, 0.08004269727896299, 0.06105989270332841, 0.040778193712955525, 0.004535835187491631, 0.024526054002044183, 0.03522131749759278, 0.04391870604106977, 0.10126945382404713, 0.028185834131774404, 0.04476965735516241, 0.041460666970740405, 0.03874549814950555, 0.00880658480098411, 0.04050514082454386, 0.005928543293022461, 0.028989768714734146, 0.01265287190871013, 0.05100774661367459, 0.025332742671091712, 0.07611470402128274, 0.0220908826562546, 0.0885083748688621, 0.007222190484284394, 0.05306310305792478, 0.007239505507787991, 0.02254345292796291, 0.040374664559720025, 0.01935309125861574, 0.10477067482086921, 0.022276883058610464, 0.024297303978293657, 0.03208585560411936, 0.039165950184988405, 0.016498352708895842, 0.08052102725712523, 0.02822316176588497, 0.04162040013339251, 0.10111476535037642, 0.05488411320613758, 0.03856381656782281, 0.09979189238360814, 0.003753121240034459, 0.05956104167947366, 0.032936042745507536, 0.009914560528892663, 0.017790718139299465, 0.041320844433240356, 0.04856517868897608, 0.022535198330578786, 0.05097836714177843, 0.009634686585125184, 0.011054150790216462, 0.019630767487650438, 0.020276776875459382, 0.049916910187852, 0.029120294775273052, 0.07143794408729, 0.03947107151391045, 0.031015113664550648, 0.013008369264313051, 0.08215627257501887, 0.0526676484714112, 0.0142396382251454, 0.01932908589350841, 0.02042135107330978, 0.021337852700643485, 0.052478566480379914, 0.009430753022071817, 0.04945035115064633, 0.05451437236080247, 0.04318631449413877, 0.0293801000882541, 0.024798900046716296, 0.05462571174927777, 0.04340757217798983, 0.0400443121250118, 0.004522264897522907, 0.02562228943251314, 0.06961140661470352, 0.04297339950778312, 0.021658134909587044, 0.03606056298820242, 0.035569718963797056, 0.04945546095710128, 0.006900122332867356, 0.054638884631135774, 0.08358969969014007, 0.026588083072114858, 0.1093013494485809, 0.025044643815847176, 0.057218088167569334, 0.05325769322113164, 0.05127411155450729, 0.020980924675841967, 0.11836502761129411, 0.057730095370882945, 0.12180913675336108, 0.04260561601709455, 0.07687984199653711, 0.09531420805761892, 0.041519517845083634, 0.02832495952926336, 0.03856834031701569, 0.02920444187287602, 0.014630446488398218, 0.0310627470964626, 0.01761797871891289, 0.018351234029978514, 0.0625766855063698, 0.010911114513874056, 0.0629348622544879, 0.06291538829945269, 0.1078719672776999, 0.0439440367382861, 0.04563593042774066, 0.02576442938598414, 0.08974909256663054, 0.043235635234703945, 0.016408086483997684, 0.043632721588496244, 0.02371167955589631, 0.028578605495333195, 0.04796166611354678, 0.07098275762532028, 0.07883325895114292, 0.041864590659256906, 0.030003274310260054, 0.03964197806893818, 0.0133358622758439, 0.012637353840193922, 0.021305004765670148, 0.018511051462302287, 0.010179816557454967, 0.0430579794450633, 0.0453841939358221, 0.011367828363642819, 0.040894753990634795, 0.03194836580434875, 0.021167137667596824, 0.034678452272689154, 0.06286316408565448, 0.07918471710816508, 0.0034718379338887794, 0.07977914771125202, 0.045707693714047634, 0.020665415194666675, 0.061319178991740754, 0.04869548641445656, 0.05057971030774136, 0.031832833999707814, 0.04453109757554147, 0.005913934475111385, 0.0463374026660477, 0.030076652126867446, 0.07750454839439162, 0.0256222645346556, 0.03783802103791987, 0.030590237471305078, 0.10351801381236124, 0.1771603605800098, 0.12329786775573609, 0.17900267946383647, 0.08538819834469788, 0.26637416453130786, 0.2252813308469711, 0.18518539205674203, 0.16480717747922868, 0.15300053682538772, 0.19604934619799738, 0.17936874691757465, 0.11954126368847587, 0.17965241395417722, 0.18340518758181604, 0.04131368151114833, 0.09169504782485385, 0.14374432544554436, 0.08202526387908766, 0.19255710375164786, 0.08376240655178986, 0.09709579149080862, 0.18857264981394817, 0.13593048908777777, 0.24890487773283837, 0.24621194078316613, 0.08440495513740086, 0.14728705308610393, 0.1133331552808804, 0.15837927078527791, 0.09550014525772103, 0.12363068699356049, 0.16784960373995766, 0.13921055582261857, 0.12606493903384094, 0.10981835920604006, 0.13081740377651108, 0.17171790342657797, 0.0934034928439125, 0.1405081708705233, 0.177758522031288, 0.19842420344150838, 0.10092959423819858, 0.10489593785736831, 0.11311345658595524, 0.10921118856077233, 0.15137852950682565, 0.11605953196844748, 0.13790221554377388, 0.16771772936467202, 0.08493545570320661, 0.21908213204193502, 0.14129002488428546, 0.09894266859778474, 0.10095103703919919, 0.2002333047529382, 0.12381090917774748, 0.33201260852717585, 0.19484180776822954, 0.17391410896614676, 0.15069235987480611, 0.1402775630835564, 0.2219646297875912, 0.07118796193671804, 0.15636298865560563, 0.1437639526181644, 0.13833231262622342, 0.1387912299363844, 0.13420706704979943, 0.2964427784806298, 0.10402242142346599, 0.15084245182093114, 0.1734631742921568, 0.15898458749776886, 0.11105804268511073, 0.18188647955896395, 0.27510824102547865, 0.21775197357900683, 0.1908219299249111, 0.22650561595876373, 0.17181384827821486, 0.17746449748594917, 0.14560840122642058, 0.07358842183865848, 0.11491798435247715, 0.2180422289717582, 0.11131547887118594, 0.06974954758920977, 0.15070052637207895, 0.1017567393700442, 0.13532079035235992, 0.18538512650036043, 0.10485135920105443, 0.1342616278317667, 0.09133027505970771, 0.11231777468515981, 0.12621028123483544, 0.20155073083456487, 0.16107645186205066, 0.11678908515961901, 0.1888849838606773, 0.17019017088797786, 0.2089108592800556, 0.19879468356169042, 0.14176167457574798, 0.1443535951717246, 0.2800956879171633, 0.1522536623862482, 0.10353670635771367, 0.20397621116811232, 0.11209187067804799, 0.07148243847393221, 0.19427027553319934, 0.20043087882861016, 0.1568152103573084, 0.08626955951894484, 0.1932974817651895, 0.1600933618723385, 0.21367028776195743, 0.09108518055009265, 0.17587446667734655, 0.09919741581524573, 0.1226003600224372, 0.1422970168172352, 0.18056099423237387, 0.13150090742255413, 0.18732637797872867, 0.18106687273229324, 0.22567514600532673, 0.11075277196904344, 0.17414275556802752, 0.10671632364392282, 0.16115362755954266, 0.17096761223529616, 0.23522699071514994, 0.19640720118918728, 0.15788351996771752, 0.13119608103748293, 0.09899115430251246, 0.1633764929588764, 0.1604473711021485, 0.10234558519216315, 0.14253499437003367, 0.16470527246354089, 0.11950814570750921, 0.17129522207523548, 0.10589964327312286, 0.12999122391545004, 0.12936208186851395, 0.16370473099091362, 0.16857800013836355, 0.16165904640670747, 0.1281081568149309, 0.09704195849236943, 0.08149909937093336, 0.13455415084477396, 0.13023197470653441, 0.11793283910881128, 0.12285485443088318, 0.22362215294232293, 0.13017431892935308, 0.21403261670662513, 0.1516460320882259, 0.12910816968689043, 0.19472113359839688, 0.20812609413218117, 0.10552600687069279, 0.17852028921967555, 0.17609042686320123, 0.11285576759086502, 0.08986569880958527, 0.08325648974747428, 0.10274264090243848, 0.07838070017075346, 0.08627829292128164, 0.16134436813093003], [0.05003604069051724, 0.02939462511529846, 0.010611074263109796, 0.10525599152090089, 0.06582773666107847, 0.03126450209698129, 0.059989491672886, 0.02802497481987361, 0.03761123602969512, 0.05634220069154136, 0.018583163318614808, 0.013281082201208319, 0.06417220150451027, 0.042184099119396946, 0.043497487917662635, 0.04682420940709211, 0.06959872785955667, 0.03683115167903804, 0.01661707910018102, 0.06570788986620403, 0.02890467358332488, 0.04866550939397947, 0.006941280406599324, 0.04608734007624369, 0.023470833003821395, 0.028360919696429086, 0.02410270615420755, 0.06689499673103133, 0.02149074852857138, 0.055221000370839914, 0.022803131836436452, 0.028280920964936097, 0.06655302274251176, 0.013718042473849511, 0.10708245238469494, 0.033530852562117006, 0.031299678939244444, 0.031917015571267374, 0.05557738447321519, 0.04817648482839427, 0.056419889667942646, 0.027101044054894198, 0.0443539205908535, 0.03722427352782219, 0.06593282094165202, 0.039486274528767795, 0.03226840478037635, 0.07153923623263836, 0.031045496711627613, 0.0300866840482359, 0.03739834785641682, 0.04509081673477927, 0.04600047719694915, 0.03536675162913819, 0.032067130500030135, 0.06455887289297196, 0.0313388298626148, 0.010442388405452573, 0.028074276408240683, 0.053320684800705606, 0.02078782646886764, 0.02729964468838467, 0.04840389419827731, 0.051790336071844065, 0.04883139424266354, 0.02834472842814942, 0.03125486854133347, 0.029839065278910344, 0.11999966005884832, 0.06392301991581917, 0.13579912033052216, 0.07059396800374793, 0.020765313059992848, 0.026568521016968355, 0.024588193308802384, 0.029612282185905406, 0.04618934468336163, 0.03058032812400451, 0.051823254869950396, 0.02472379853227927, 0.0478737038980809, 0.04265596714591788, 0.04993711192641528, 0.036557175654677615, 0.010011052175785505, 0.034138536486294, 0.10269410923243531, 0.036212554832379666, 0.055315868868943185, 0.03937442952226247, 0.11049150534334684, 0.0695383448093649, 0.15776575693199713, 0.04968529116482504, 0.010327504902717569, 0.08784155661780989, 0.03133157500997186, 0.1066582618401416, 0.036320714955969204, 0.02530605408302959, 0.03999295359056804, 0.052978844877572796, 0.06085884058848024, 0.04309852847889547, 0.04646142464010947, 0.07129805643231639, 0.028237049024732366, 0.09541860285906062, 0.06824213936324082, 0.06464284379035234, 0.047745866806156216, 0.032297638695566885, 0.07029344703281118, 0.020779922356708877, 0.020945295841703494, 0.04144834444647835, 0.08080766671487401, 0.013117877702649324, 0.02910026923693236, 0.06590911818127479, 0.025910796229577353, 0.027403336604155844, 0.034990855267331485, 0.04299759256443189, 0.005770955176558346, 0.03663640063736708, 0.06086690366388329, 0.0747693233912991, 0.10308754900770803, 0.08903489943834082, 0.030423237964691176, 0.025423614105450052, 0.04129942078443785, 0.034096213958917126, 0.018940259882759665, 0.020022110097230445, 0.01113720238208771, 0.036679378169919216, 0.028140629198582425, 0.030833824702929107, 0.041242397029794035, 0.05013483155879283, 0.07827671905679089, 0.08318302957641502, 0.012176383414395876, 0.0151454012150005, 0.0021189798069592087, 0.00814999861177057, 0.03495643876733319, 0.057071991369969426, 0.04903760979012136, 0.03294990127605777, 0.030895965924907117, 0.01246055702663838, 0.023524570241270047, 0.022577444249163234, 0.05378886794431075, 0.03839993503906074, 0.023169463590508508, 0.019232978248187614, 0.05503069263912978, 0.014113362994976343, 0.03411325558479275, 0.06554314265808751, 0.004445204113219535, 0.043743865624550855, 0.04457415937776527, 0.07633754367669744, 0.06221153735814076, 0.0704585696240106, 0.011707424606767394, 0.02754347706814447, 0.046133757343575846, 0.03980899672775019, 0.07575360081729389, 0.02269104168179535, 0.05456760014978148, 0.03833470648274787, 0.02114502645488228, 0.05336421774700285, 0.015127633720816625, 0.011053683476582652, 0.03783134841209939, 0.1141391946904121, 0.04278607568853805, 0.04778396052819106, 0.05825636330090704, 0.14480117438060625, 0.031273243160197334, 0.005887126185811095, 0.03162216748140993, 0.015836792693833913, 0.033042984789297465, 0.04089989827104634, 0.08116506205330934, 0.009406090736569417, 0.04065886402742998, 0.03974753349358517, 0.056126730801958236, 0.05095332372753371, 0.014903295405900047, 0.045494185009550665, 0.06035096642951812, 0.06956269108359853, 0.09143751970822774, 0.041689505094602224, 0.04415622011067406, 0.006660038038277098, 0.014631908758723689, 0.05025263289890943, 0.02613560664617727, 0.022167635090168447, 0.07270343706852968, 0.04229920383002009, 0.030629510968743317, 0.011192518718270286, 0.03461681666874117, 0.014790707294108167, 0.020002959814343243, 0.05805283672206345, 0.038271619142183376, 0.05125171497404095, 0.03816359308398059, 0.030485861822061484, 0.037550446952903466, 0.0440688707655476, 0.0523335958320287, 0.030961489425070828, 0.07669033482670784, 0.034740758203570886, 0.07666823319009236, 0.019690489787007534, 0.07467799804984562, 0.02792663594347335, 0.02663045731042662, 0.050911123774224715, 0.035338804741660436, 0.011396305767008135, 0.09982248993530389, 0.04258513848687853, 0.03221361034159218, 0.08885727429221715, 0.039954109102367394, 0.04374565827029367, 0.11678021386145584, 0.06676545892391475, 0.04469397935956236, 0.04581026522622955, 0.025541702728538264, 0.05627532121575168, 0.044102766325757395, 0.046824707364242886, 0.10549465089195198, 0.023640125028548703, 0.042940185765825936, 0.037610814681336764, 0.009543203238037326, 0.10898549139740006, 0.04187716982297359, 0.035255952332649505, 0.06111916109559037, 0.07857317976172894, 0.06316578413750376, 0.03556254455038617, 0.06321068072030622, 0.02187956496322107, 0.04752553225825391, 0.05641277271112608, 0.07310493608876582, 0.06731499677463886, 0.03029005740949464, 0.03220525998321753, 0.04834225093345008, 0.03210860841547049, 0.02019795025849054, 0.07570305433604987, 0.01895371621714965, 0.04200203066331245, 0.015973887958323524, 0.021787718681979085, 0.042403265383214726, 0.05215613539480875, 0.02138741667412462, 0.008574463032756843, 0.01912983025484268, 0.00972506006233274, 0.02519968852040268, 0.04276277512432106, 0.05660335623448896, 0.029134971104682456, 0.02790571599748106, 0.04097797029140977, 0.056384278070782466, 0.0011958175239288398, 0.03856221927450069, 0.07713167041900658, 0.024564988505575928, 0.03980923421500672, 0.02101427822884533, 0.007867903970632582, 0.029574370409752575, 0.039387173394882874, 0.017593507955391562, 0.07185311011609531, 0.04730399112187086, 0.047910047109208764, 0.020963344873199542, 0.03167529567895878, 0.014358886513828993, 0.035461011087341655, 0.07010394752386116, 0.022501484716251012, 0.07306554384769932, 0.01857902069816426, 0.04238960220508518, 0.01838853102057211, 0.032690687765998226, 0.04115831121922501, 0.07212601361736175, 0.05167156946094287, 0.02389042127516962, 0.01369834443809645, 0.022451392142102126, 0.04039013187491125, 0.05841513502321417, 0.028029649871431535, 0.03601961175821001, 0.02750676421959314, 0.030280107842578046, 0.07141879955006224, 0.0934701961194796, 0.03638514295040119, 0.051638493614812056, 0.05794768732401633, 0.011889222059248677, 0.03835154126488394, 0.032062235198193983, 0.036364309189300385, 0.08051532756296859, 0.05235180957242847, 0.026480650732053385, 0.019356661228342883, 0.0655463602273695, 0.10574215857852852, 0.023771805966633464, 0.02907882835115156, 0.061744752324997425, 0.05021015715394771, 0.07962866506028561, 0.03726121811797062, 0.023424944337156993, 0.018445679264503623, 0.1461223083277864, 0.2100366714500612, 0.0912946749538664, 0.20009995948883796, 0.11328847703313637, 0.10399783766197582, 0.1306489563637203, 0.13106891044205235, 0.12660169853798806, 0.28544080593893606, 0.11033418918809584, 0.19880139449190712, 0.2725334807990059, 0.1190603519940088, 0.14596648604398774, 0.11702063523473279, 0.18911916161737136, 0.1385548458464684, 0.24096575535593495, 0.135535754623913, 0.164783428753576, 0.16717927680621225, 0.08833266494254913, 0.12827656592332548, 0.12206037528812887, 0.11592939661274995, 0.1759962440137902, 0.19954725769498657, 0.12065705542843189, 0.13783996323904685, 0.09177993802774338, 0.1757550642134682, 0.19212164405372836, 0.08629945993062951, 0.1807751617724857, 0.16297291784036547, 0.1526429423040921, 0.09778673385059643, 0.11629699624233669, 0.10036273513950648, 0.17217849080841388, 0.12407484178942059, 0.13018970197487262, 0.2102552516566169, 0.18893038223107017, 0.23595167924800228, 0.1446254184890178, 0.21110062968106041, 0.21031014951727084, 0.11610450132960275, 0.1697501759495466, 0.15974024130452066, 0.1746099619495292, 0.12026631228265264, 0.1394725272492055, 0.17192987995522638, 0.17174106992540822, 0.12812868797130164, 0.10298470936475262, 0.2232550895742832, 0.10469169115587589, 0.1169409237862114, 0.22008204532246436, 0.1419244529378991, 0.11221435281538195, 0.2060903074039567, 0.1522481159096764, 0.09338090091102547, 0.2812594061176623, 0.218519976723098, 0.24031159287739187, 0.18101493197102703, 0.06538811710573013, 0.0779615351629834, 0.15668420932225643, 0.08003790156855699, 0.12315013536041784, 0.10508021264667473, 0.17310688212033243, 0.18711769562815467, 0.16819071204912278, 0.17639853210458833, 0.12395587599565908, 0.09929083257673249, 0.09752708367042004, 0.1306224497215402, 0.1158687147882677, 0.09601420557667172, 0.09007387554212924, 0.11666558412534576, 0.22177312312827957, 0.22367774028210874, 0.21278141126517328, 0.17813375189660058, 0.1120332955953575, 0.19826507165787682, 0.13117018726564225, 0.10992257014637995, 0.27515218382881534, 0.17112522716483763, 0.1552522990612253, 0.13655010100093581, 0.18861300732579925, 0.13646308873449603, 0.21722729528142562, 0.14805744642451887, 0.13288509040590257, 0.17902953850646175, 0.16491047677493867, 0.11733602597227982, 0.13282522829549928, 0.12200563064505979, 0.16527216220574995, 0.09096902629901325, 0.08431376769177376, 0.1278295842630248, 0.23340164833972532, 0.14423463703884234, 0.11909689438799698, 0.12768215830287627, 0.11275293560878885, 0.24938233437076693, 0.14664649632909607, 0.10286989576754071, 0.09994838882478015, 0.13897237908695975, 0.15161768683502752, 0.1665828773571599, 0.13994089808435212, 0.1657064114847491, 0.07209158562604459, 0.09624433072824633, 0.09011256298230541, 0.1163849431360441, 0.17372079433933382, 0.10265106275196999, 0.2056403839660268, 0.13143585123602422, 0.095646575303568, 0.07246024245696683, 0.20926808607914757, 0.13709812965844909, 0.2259247374510573, 0.1490816600140064, 0.11861841885312913, 0.07179176179511894, 0.10857390299920114, 0.10950336683421366, 0.13047853244408486, 0.29684353439557937, 0.13706390084999223, 0.23091393102320934, 0.08546365034436026, 0.11081028218951919, 0.12091163410654954, 0.1701808552588186, 0.19997900952735256, 0.2068676568207241, 0.08556151807668709, 0.10899528966195161, 0.11863952457544305, 0.10694349935698895, 0.25174308027471265, 0.19713870790456572, 0.12956068250200442, 0.0638477134728624, 0.09346223646594633, 0.15878954151224706, 0.19933194102298832, 0.13942616360802806, 0.1174626986105596, 0.16170475121227004, 0.2091838470509937, 0.1508337490621113, 0.15152048559919482, 0.07509121055444402], [0.020051857291330254, 0.06643146757156619, 0.01943837216634664, 0.029052653041998708, 0.053062325478681636, 0.06553748892920633, 0.025406478633803707, 0.04192890757093987, 0.06904743566748596, 0.05540547817344627, 0.059462292946033904, 0.00886304356578377, 0.02994408444201033, 0.06029584640336614, 0.04117400836079352, 0.033157032298585104, 0.029072243825442372, 0.028645812473710508, 0.05434667571417747, 0.04003834046964203, 0.029573443443364197, 0.02965425614327673, 0.06660434297255932, 0.0428845371390062, 0.012518000214420741, 0.061640805684991425, 0.07447621815146939, 0.03385941618152204, 0.055275112991371465, 0.014820233280319842, 0.03988552891138581, 0.03054922686949853, 0.08867769562188657, 0.029942046648131746, 0.09592769126738272, 0.02924694826135472, 0.12324270176430865, 0.07313405509076773, 0.04898142873219425, 0.024686120412943345, 0.013495546600390828, 0.04355662990541708, 0.024448671460812612, 0.017776926641442606, 0.0449565215216529, 0.03621386484273019, 0.034324902695633715, 0.016979881104141954, 0.058305465706413796, 0.06492974371799538, 0.05758201440555915, 0.005846580982418551, 0.06961443266200443, 0.06684087261918091, 0.035175857840165976, 0.05658624183026053, 0.031743598163067814, 0.03199262653417405, 0.06993816609704687, 0.055014807806019826, 0.055511424302934646, 0.0769911086066596, 0.05626199894674844, 0.04358691719150351, 0.074705554232482, 0.04454474926235215, 0.05055488522855505, 0.005448229147136332, 0.027178729200855862, 0.03628308854756817, 0.06846095705705305, 0.07966904555477443, 0.04363774712527952, 0.017574395976900574, 0.0401648675512162, 0.03115777647302997, 0.040098122140813264, 0.04843243097345676, 0.0299966610562537, 0.07492708387754618, 0.015058838067606333, 0.036693884044765465, 0.060475260364793004, 0.015097376120637263, 0.03744618621684852, 0.008697243944381275, 0.009841836759850625, 0.01995884272600374, 0.06656111263099217, 0.035440135191405014, 0.024056800250564853, 0.02773915507620381, 0.02028415047173058, 0.055667093369148435, 0.04727667625693064, 0.0077052793048712764, 0.020316280199274905, 0.050401598695785775, 0.040040945168584585, 0.03924465422788936, 0.09296501475957133, 0.054716910686223745, 0.031341143448146126, 0.04013469134787879, 0.10772015163374525, 0.04754702102452998, 0.03878161153425613, 0.018943232303905874, 0.0278952531516552, 0.05212029397127129, 0.09339277527385181, 0.013798497985267352, 0.04901597163670006, 0.03143319082746823, 0.06688306874205029, 0.014446709875858601, 0.07924530700209641, 0.06359309649034854, 0.028584295613390785, 0.049551949731164405, 0.026586573878904025, 0.05939091270368907, 0.024719786146775852, 0.07597813352702126, 0.052445509786447214, 0.022096649383104617, 0.036353484366930304, 0.044350794952122435, 0.02946081128151667, 0.077286412518832, 0.024413186268159942, 0.035607054258786866, 0.04318434564817337, 0.032277697426897865, 0.0209211353437915, 0.006896904763585378, 0.048850090618455605, 0.06269977285316394, 0.01710446998326769, 0.042264764347384055, 0.05108519427237972, 0.09002529790685063, 0.06370769175250204, 0.07509195365973058, 0.03489104167167698, 0.01166095179806073, 0.09251028028947693, 0.08256173226982355, 0.011575294549637025, 0.06017100854566502, 0.041513270398061124, 0.014140197139744078, 0.019096576293269475, 0.05646343793599837, 0.053677348525173245, 0.03812062321230769, 0.03382795678091145, 0.037109739552702636, 0.017798871230033618, 0.03962317444083672, 0.03445604162651204, 0.013912905555879398, 0.04376379157146139, 0.03457874975978367, 0.042806886467001135, 0.0194833587644802, 0.03719415095063948, 0.05682029318244708, 0.06364963760960006, 0.04101576906959376, 0.06159296732455973, 0.04436240118417529, 0.03434039682390229, 0.014761087462125767, 0.07035196082846773, 0.02131274225370538, 0.026484530967389865, 0.02808107735378848, 0.00983999240317292, 0.07778901216243544, 0.02295955741447547, 0.027376883588130438, 0.019781236732078177, 0.00868769848884474, 0.07477827129825469, 0.07440181569226327, 0.05183067826193668, 0.05609180868392991, 0.04751062418724741, 0.018293241174110485, 0.06315197157222899, 0.03195639632101501, 0.0641005301487542, 0.024513421212172797, 0.04678057686936471, 0.09631628170609476, 0.045494185009550665, 0.032465764351429484, 0.06451918187761499, 0.08552643124975505, 0.03962221683093137, 0.04770460914099409, 0.026518828723759904, 0.032437495707023534, 0.02346783760003746, 0.015696997927021117, 0.05210896353087118, 0.012281593141867029, 0.0616013368351325, 0.012753329975830932, 0.09060878877437885, 0.07312879206672793, 0.09308538249423427, 0.04296518704523483, 0.055926655449213526, 0.02207856779287179, 0.02575583004903409, 0.054209974984968864, 0.01196748368637336, 0.030319496253204924, 0.13308450309259276, 0.04483161088559897, 0.00992828690927596, 0.06072169552827555, 0.029929350656006607, 0.03619054512631509, 0.03042237420055655, 0.12206627416514582, 0.044048247678625974, 0.004806436115740649, 0.039818025073937835, 0.0332218203543415, 0.05487786192867545, 0.0522097998539046, 0.021973102383555907, 0.00887478769366299, 0.02009393850101098, 0.041645117960269415, 0.043974094197995243, 0.030938072032445384, 0.04489424623428814, 0.03510467295024184, 0.04331228233152821, 0.021370821294464895, 0.04765737599002258, 0.03701668668297991, 0.04038401083239625, 0.022058569067608447, 0.05088443327094278, 0.029913756936307878, 0.014906306131442469, 0.07616443078844778, 0.09123275972782605, 0.028030609396556695, 0.049734002865490415, 0.06447094132102306, 0.08556193176416621, 0.0898535333333477, 0.030499657150357965, 0.007176330545917154, 0.05217416144366707, 0.08310275122282967, 0.026103875284353574, 0.008730529507081355, 0.021860709624184717, 0.02069508961041368, 0.0716889527956805, 0.05594119196757675, 0.02847622933557197, 0.03458194434642792, 0.020588881095811244, 0.0008187340849432193, 0.017081899117798578, 0.020792202746135094, 0.002503564084632202, 0.013725778046664933, 0.11471925348403955, 0.11682978741103604, 0.061751689251151785, 0.015363015193161706, 0.051303004560571526, 0.05649339963471698, 0.040404434736457565, 0.10485032498235665, 0.024164799495690295, 0.023035564827882958, 0.06520779533011299, 0.023405006898927595, 0.049755552918800426, 0.036714487979488994, 0.058967235438044996, 0.014026515437440287, 0.05181492749421347, 0.051127103112277486, 0.04320158262646968, 0.022188932334463445, 0.03425151530292726, 0.046670604947834246, 0.031219567209782622, 0.03640530255412863, 0.04565869089997104, 0.010408299408041903, 0.028576977558494098, 0.04559526265028023, 0.020118711869262403, 0.07669133840188866, 0.024922473859342358, 0.08167043493519868, 0.016784001998002493, 0.06188781541441718, 0.06695521124187978, 0.020492030345203898, 0.06876009140884684, 0.032457276097228455, 0.04792852131950279, 0.049218820227730664, 0.058274504262954004, 0.13699565773769734, 0.046588001517398704, 0.03304352871172371, 0.02341999540916614, 0.029047663894391833, 0.058652844445239154, 0.04245251717586671, 0.0757641958132867, 0.044007909318972985, 0.13156869088209447, 0.01106709193047737, 0.01647469208335444, 0.011777773503244165, 0.06983537241936692, 0.05513567732827318, 0.042073338127304474, 0.05687768082885493, 0.04284227972910289, 0.08316773080056714, 0.013246279784418164, 0.007374753542770182, 0.03710020941892459, 0.04845693812615449, 0.07392104189362257, 0.04921828779662329, 0.04809303104036278, 0.06557963908680024, 0.020378206916634115, 0.005318156036082656, 0.04116735105673152, 0.0894525092876246, 0.0571072084318486, 0.04705109783718663, 0.03529136474694937, 0.05248164615383553, 0.1325832977290115, 0.14424879434368304, 0.08112216112954963, 0.14763488764724425, 0.07871236261581221, 0.11109420203513677, 0.16462748389570944, 0.1299716733516224, 0.2028375900080127, 0.18175625993359476, 0.16929185618796658, 0.1089214770904472, 0.18873265493781338, 0.117873513259955, 0.196279218540557, 0.09640569182773752, 0.1910325121735373, 0.10118814891264324, 0.23231315997339066, 0.19726220127795974, 0.12077574543054066, 0.13863983564078808, 0.28800560702239314, 0.1843091866542255, 0.1125648993277742, 0.1820426082779323, 0.1446192438203481, 0.16640391921804798, 0.09000046133634546, 0.09483922588368578, 0.14678739522012973, 0.15765029216004958, 0.1746218669558725, 0.10318514860926137, 0.19621848308992004, 0.15768747806789415, 0.24279590876352405, 0.17632912453864852, 0.11536262944460877, 0.1515908584359192, 0.0873871668872814, 0.1048807769773468, 0.09620756616876011, 0.18700311951819928, 0.2598762067575609, 0.15773754957462513, 0.12525843997155467, 0.12771653266803873, 0.1139233340959876, 0.1709912230651225, 0.17943893589319723, 0.18953059679798542, 0.1802500851091839, 0.13953134748003176, 0.07302520931848595, 0.1621528207174232, 0.13074860908091068, 0.15935836179602533, 0.1846282929182053, 0.07974395363201058, 0.12074311008496631, 0.23682341069704105, 0.11016918151008506, 0.11292032582024414, 0.13390987090045406, 0.11540259625161849, 0.20356571061476586, 0.1334248606355921, 0.08516322896485368, 0.11005860437909443, 0.2146125759088224, 0.07222165203382892, 0.118389098093875, 0.07414537542048963, 0.08988806091609503, 0.12897790409624577, 0.2613319270312786, 0.23274486584048118, 0.15145299325306572, 0.24945322814727985, 0.1700140166306688, 0.17519508458433614, 0.12850128249415468, 0.22656373138869965, 0.12319534986970887, 0.12000593431894818, 0.08710741455997191, 0.14830775799289828, 0.21526149834596345, 0.14507796194764877, 0.06210246558992132, 0.19710144538792873, 0.12321501534672515, 0.11635770871033592, 0.10499563653983417, 0.10062960186792959, 0.12432802618751604, 0.11506167180355518, 0.06595450122990916, 0.19701680799405422, 0.23079028443223049, 0.24150140403259188, 0.1525771200296379, 0.16071882669723805, 0.13848176105849205, 0.24286125606346518, 0.11442898276952967, 0.12492688477880533, 0.08442992960373241, 0.14139096462918868, 0.3487541730846128, 0.138416888733064, 0.13047588177986685, 0.2074713494268156, 0.18917176121425247, 0.11147579043022088, 0.1760988538303683, 0.21168745303105926, 0.1702221933632128, 0.14287051023735156, 0.10963681168974408, 0.21170458275704615, 0.11952848534189886, 0.1613494855982642, 0.14992271730255696, 0.094236092521779, 0.10538770501772243, 0.1489231257789558, 0.07232547993020666, 0.17147346009169856, 0.13230313937510216, 0.11795122521899401, 0.1745275615323936, 0.0786481108216028, 0.2733596913035839, 0.07162675411710817, 0.16017718721301327, 0.1055775186227214, 0.2245629702003733, 0.11692673583785373, 0.12044322496700673, 0.24478701724400445, 0.18814753230300643, 0.10187048044416214, 0.0949070782911393, 0.14626460149884224, 0.14745522470724198, 0.13582509071115526, 0.13474397211065217, 0.17776146380891725, 0.153109367275911, 0.24103430490339958, 0.1278896302345299, 0.09176067091644773, 0.19269124574718938, 0.15565017448557963, 0.16267809656358537, 0.15514895380023988, 0.1110008925259594, 0.11558707022378523, 0.10403831008701556, 0.08376516446831726, 0.1682066773214648, 0.16040422503025303, 0.2164376118490773, 0.06463705216564479, 0.11576448852616934, 0.14423805379098462, 0.11595570407206975, 0.15452207937355966, 0.10351468132989061, 0.24423675160975228, 0.2020253529471736, 0.1405397949800376, 0.1045271278088612, 0.09785306174308063], [0.029990741111818823, 0.028111602127131437, 0.029249497418922764, 0.04852777061563346, 0.02264708738713976, 0.07879280184786167, 0.02803237522922216, 0.05703990760770056, 0.0384845302980994, 0.06071799915404089, 0.09616582203776607, 0.05305790515135854, 0.02078045287259644, 0.0477169240043769, 0.03715046478675739, 0.03696772217329952, 0.052879793539402954, 0.04254455114865015, 0.02269157985856216, 0.05445044998440051, 0.021183319359777436, 0.0683230842133203, 0.023357488380204287, 0.022576224254143816, 0.06545934030005048, 0.08578843331985897, 0.05949867446155799, 0.04271071561942658, 0.07883100665264553, 0.021278094012109984, 0.09106029035343279, 0.0542248179385018, 0.08139683429392115, 0.023085048362132043, 0.060473230231793663, 0.03754897989452847, 0.022008204532246438, 0.03576119881003134, 0.03401302447121951, 0.02309418779106871, 0.03880325734855668, 0.07501810278382993, 0.09652119490408129, 0.04176173186410339, 0.06288051597713944, 0.049386800326887643, 0.035868883959107825, 0.07428419055236925, 0.07487349602724276, 0.048778296688631664, 0.06608013198861191, 0.03570282291020117, 0.009905959276722805, 0.04076684795079693, 0.046799020436141765, 0.09939544188279299, 0.028262278215298732, 0.09176475416508414, 0.01393944571440619, 0.051093506326358167, 0.06734646000568906, 0.03475645151469977, 0.028969197338747404, 0.0411703541213947, 0.027187045085273927, 0.006155166465173206, 0.05372268560853216, 0.03602353412838232, 0.01763414891977464, 0.09235050499198899, 0.030781830315508192, 0.05528350548458196, 0.07001317376571317, 0.0729810826540474, 0.053608852603863326, 0.007798711388116523, 0.034288352640766295, 0.0821118394754106, 0.07288376650502605, 0.06932693518578045, 0.04235886675756305, 0.0969188021976621, 0.009021302009181631, 0.028279745019972328, 0.04743555523154717, 0.026008556709594788, 0.06305523381959047, 0.09132573215831673, 0.032491229114032565, 0.0423718519478796, 0.02193926427994044, 0.028085943927327474, 0.09922021459187232, 0.037306493914295594, 0.04480279831876678, 0.048640485131932844, 0.051694050311080875, 0.05141194226340421, 0.1465288099021681, 0.05689029063608858, 0.034829279663221496, 0.07226547226309776, 0.06495457262762132, 0.056456661888308106, 0.03354272309450373, 0.006851895661619042, 0.03219803960453118, 0.012313556245287821, 0.024327644890534784, 0.024920673552720297, 0.02122514393000353, 0.03970187465329805, 0.058324276995394504, 0.04351420012573081, 0.06512422279845323, 0.0457162241030845, 0.058018447035142494, 0.11157766480239169, 0.07812769963375985, 0.01929019927047193, 0.07518969881798952, 0.019537902309469158, 0.011183291189222327, 0.044512439504145615, 0.04303649067878724, 0.01826993677945387, 0.034962900718974496, 0.031461829109297644, 0.004864936026053564, 0.07480916762424093, 0.04822214749912101, 0.022875578856215845, 0.039595771475785205, 0.004631872448484384, 0.02047952970549945, 0.034872548309184855, 0.03617366437890357, 0.048415362534503785, 0.07228720617750961, 0.03283018471613046, 0.03699542774308113, 0.08599013660944278, 0.016402277622311827, 0.025939363648273775, 0.03271476590945836, 0.04654577475101237, 0.002356370105483239, 0.03406988351695961, 0.03465212183073163, 0.03138672759486062, 0.027999634546558225, 0.04987639945841605, 0.03559914057052905, 0.03203808810682066, 0.03630577241100612, 0.043614071177979635, 0.01991685727731355, 0.052322495218005874, 0.059575861650368864, 0.031892529485987565, 0.06229306826548231, 0.013042834602416524, 0.007498399654944097, 0.03541171332941421, 0.02539932528781074, 0.033210198800530166, 0.01217578107776541, 0.04414107072197142, 0.016320371331887382, 0.0388601393769345, 0.05878961795280057, 0.09547982094508987, 0.05876569302692529, 0.01677184609786397, 0.06851846727752878, 0.08730624501983966, 0.033006974826416666, 0.019778959535723253, 0.011516255026142444, 0.06907702198312168, 0.028292134576927752, 0.04662190856892736, 0.03886023513792504, 0.05938156260057323, 0.03520637112219007, 0.03662614655050059, 0.10663143344103329, 0.016732156997726812, 0.04202352326002814, 0.027865720462174188, 0.05523293602070021, 0.028321073548267447, 0.06390898518504635, 0.055295287916857394, 0.057161684944144184, 0.03844975756721632, 0.020039762678225676, 0.026452784283807682, 0.03773898502150851, 0.018856356018072656, 0.06040433594476312, 0.06543347717172678, 0.03779699319913503, 0.06722415406857768, 0.09877840402506052, 0.04002604092801771, 0.06126278342919485, 0.06803129664472035, 0.08745725627147383, 0.01768305980330033, 0.04812225346423445, 0.027220904256307313, 0.0996766267945209, 0.038801131454566797, 0.03652547876681051, 0.029503361720051018, 0.03503927968502526, 0.026720731196204023, 0.04963219744123278, 0.035662388789557645, 0.059951298359421, 0.06565339037127073, 0.04712287261481247, 0.051168399081835826, 0.07064980815254873, 0.022213692296176188, 0.026157572302186204, 0.021062901829399412, 0.03910791519428453, 0.047658674509054234, 0.016365011275235205, 0.04493254296962292, 0.08135267698596563, 0.08994786940034359, 0.021249578304348454, 0.07776242125058368, 0.06861117923812521, 0.03210368247011737, 0.05962154347329371, 0.04173824743878457, 0.050076539928634325, 0.029264003293769016, 0.01540982795338477, 0.018913634496951298, 0.028235195091955607, 0.13489536640624847, 0.029009771270437107, 0.045505511619511156, 0.035922640348754586, 0.04996125518734898, 0.02286359915629991, 0.02545171804095228, 0.06858931508876624, 0.024959998761093425, 0.054913898704633604, 0.038416497859983675, 0.05599001475099114, 0.017957853626519922, 0.07000140665519623, 0.007534474256493512, 0.05015393396118476, 0.035795320366178794, 0.04461345585784124, 0.04567095596763877, 0.02449666112360935, 0.037385347344341784, 0.039825073082841216, 0.0054446481648952735, 0.03510748066248433, 0.053062643405170216, 0.012900716673973347, 0.09005288473300396, 0.042761714092545935, 0.10255052137278742, 0.0846767861155733, 0.03729600234017257, 0.015605657263809155, 0.07262629967543387, 0.0222577212844044, 0.039258152697115176, 0.032031181824183276, 0.014446726155226991, 0.018677583655282375, 0.04556410968483937, 0.015157902812314852, 0.03459183071109076, 0.05127001681455201, 0.07993109359015381, 0.06990500981168402, 0.003201846284942041, 0.05741686117084277, 0.05996838595057207, 0.09514911610993648, 0.03964236494333994, 0.05438574619831578, 0.036480229783562884, 0.07700119798462238, 0.03292163646209144, 0.01461414605258934, 0.01109664377215649, 0.04698159834069591, 0.016604467377727552, 0.013311221057759419, 0.08149605034099472, 0.03859190901200618, 0.03153840151254929, 0.08966739695038527, 0.057008245193790046, 0.039935359100420634, 0.02313813442484506, 0.03892655153909037, 0.02861689456978873, 0.04373760668620948, 0.008282437019290463, 0.05345914753214006, 0.09318362560964401, 0.04826481093562419, 0.025056437739441474, 0.01797581072746506, 0.04402157249710253, 0.025709956704128175, 0.019435597012840936, 0.09027698077261449, 0.059703036076239044, 0.057656233003663446, 0.005513015766477874, 0.04323136429452608, 0.043592950133907224, 0.08338139272264897, 0.0478572559903466, 0.033867073230325215, 0.0618203996770805, 0.04730286880306179, 0.004125755982503536, 0.04242660042138831, 0.02122134987955853, 0.009966616203347522, 0.017647404156084505, 0.08453884432392736, 0.036150076531714974, 0.011060595504879471, 0.01342822087838525, 0.08319637482805599, 0.0385341574738343, 0.025700363368096373, 0.004798629200987278, 0.04878369377805822, 0.03630513272758934, 0.0711042668309904, 0.008358764274406337, 0.02425117782437273, 0.006324606919435845, 0.07028352619419176, 0.13155444164670285, 0.12652033233955023, 0.13562468211016349, 0.1188670986542298, 0.13805567827676574, 0.1506244385194394, 0.23344877806882705, 0.1775863667529437, 0.10284752600015172, 0.1789954935591067, 0.15589555244772665, 0.10788908934280758, 0.14354312011311132, 0.12444623355423251, 0.18951617902325046, 0.15997515450562202, 0.15498481180158355, 0.14341388108028522, 0.14413162885654357, 0.09130644972526258, 0.16954173874710837, 0.0976494585554446, 0.09246511174546135, 0.14751361592883064, 0.19819105224263286, 0.1325240178454307, 0.17674281201776, 0.3592956348532631, 0.08091345579633791, 0.18326045825116097, 0.11767403928623085, 0.38855507609344303, 0.11624481799381396, 0.17015313819771813, 0.11462865592611414, 0.16107041508920733, 0.17506445127148784, 0.10758692894371287, 0.10495756963087667, 0.14157208313624706, 0.14402091382972657, 0.18654270067570672, 0.08775432218587206, 0.15154570521366212, 0.17684816442910703, 0.16112860712793567, 0.20392223261296752, 0.10161946407489239, 0.12634204835781168, 0.2208291495879812, 0.21333861765601944, 0.15332983205876044, 0.09613117188095086, 0.14066547936489507, 0.16594117146826562, 0.1060992244991564, 0.2527618699616963, 0.1875611379622452, 0.19906296755277342, 0.14364252768216595, 0.10609213052497757, 0.09765664446017436, 0.18314493219217948, 0.27121191784258813, 0.10664641812083223, 0.12426766611996198, 0.2411530944969385, 0.10400167576247647, 0.2573900675821689, 0.251795970985005, 0.19622487226320853, 0.0942679847620668, 0.12059732355297574, 0.14704734417459658, 0.14383236426980267, 0.10536178826324402, 0.19030615356901, 0.2305170668349151, 0.15877639544346642, 0.18049691863838704, 0.26881210145450407, 0.1742362489383067, 0.17606044218184488, 0.1689124741261044, 0.17709619305547208, 0.149718800018872, 0.11164268268452537, 0.11148384967518431, 0.12733735744991612, 0.18555771078794234, 0.07194923882883403, 0.18215464097597908, 0.17530471176630066, 0.10146902738920144, 0.1845947229453633, 0.14737437178771343, 0.3718374134792436, 0.24989284004174897, 0.14347856954461144, 0.1929177013376067, 0.14938326882979563, 0.12516552882809795, 0.1805639513317616, 0.13166219957413214, 0.14644780376505467, 0.16280937339029006, 0.21782084488339964, 0.14901920852641906, 0.18936018820010847, 0.12364789332833984, 0.1614945060423305, 0.17688455360551036, 0.11989704258139096, 0.21282380657090297, 0.16891078873267099, 0.2090320084244013, 0.18153023335241503, 0.24031689420582789, 0.10056192566069866, 0.137259544384095, 0.08141384144584018, 0.13333674520254135, 0.13222683701784382, 0.12992846599269298, 0.05568646390231387, 0.12177156014067513, 0.14341423348073037, 0.15625550651982908, 0.18529803762512823, 0.19199436620598842, 0.12304422370488606, 0.1695591902300235, 0.1154809900289101, 0.13334642855390427, 0.12691031705828446, 0.10360648164585715, 0.09625193032045519, 0.12937812374964838, 0.17140524762292064, 0.11630484864356057, 0.17165321496225175, 0.05225802508873805, 0.16871903692522358, 0.1731778218621208, 0.1729719127498327, 0.16196568075927997, 0.10507442102196718, 0.1857416484985621, 0.08675567295041778, 0.11623338030110444, 0.1660587353211257, 0.13392502411959634, 0.11473702672388285, 0.1440206686815908, 0.10008026320006579, 0.10487243427985138, 0.17035992065023992, 0.13950654155304357, 0.06716660554370574, 0.14551302327984764, 0.12135506111888156, 0.13374408947363978, 0.18226644384764856, 0.1456687536330954, 0.12285366699460054, 0.1431440802351121, 0.14491696090948197, 0.12007124331449309, 0.12803458173068302, 0.1570922430724867, 0.19273160325904048, 0.13776108682636293, 0.0906368965403207, 0.10690320313217179, 0.1947844584262179], [0.03046437688622504, 0.019541499092273658, 0.06018744496208045, 0.012650118780232245, 0.011042255359972197, 0.05200118262080416, 0.04331602084059869, 0.02758452980478685, 0.01721088151117006, 0.0256965559111127, 0.09102699617224355, 0.042628859124717214, 0.02534645372971652, 0.033466344128452966, 0.02352927210590532, 0.03644556430498919, 0.03269258766405044, 0.02101414607867839, 0.06714061984131414, 0.06496306854270159, 0.04120553670931728, 0.05911723162317949, 0.04800726366679996, 0.05054928895626819, 0.036111952166163155, 0.02416579732521167, 0.041440231575360226, 0.057630105575005856, 0.013845319363979564, 0.01246506736929258, 0.06340792537817071, 0.04360007092116341, 0.09084790013730527, 0.016847313419284842, 0.06656311978135379, 0.03758410119541711, 0.015869514224299743, 0.030217472493888873, 0.026579790170334523, 0.08010998278135255, 0.06747315562660657, 0.0592449652932344, 0.04056995952381723, 0.07714785785684664, 0.05176592084969725, 0.05135745425978976, 0.039588095274783915, 0.03169750648310348, 0.006043762438029292, 0.05633678828035632, 0.07387141471788769, 0.05863494863132796, 0.04206474645123367, 0.04257767296005641, 0.017284590660804705, 0.025802193690211545, 0.041176892681828434, 0.07632285011030975, 0.019130987047608343, 0.055489518018739845, 0.015964866315405217, 0.04932971528520988, 0.010154987647829038, 0.03869268404800565, 0.013314329459512187, 0.03604849327295538, 0.05241315023252561, 0.028614100264084917, 0.009815408641682758, 0.07245318678718421, 0.03769360963375338, 0.03386505841908436, 0.031720272700993285, 0.07412413180234932, 0.040762029257753206, 0.04213210090153641, 0.033510263949151964, 0.07613054671955687, 0.032472850664729075, 0.04293187371184749, 0.04995271330699325, 0.01930095706014864, 0.0650639393396916, 0.0990132482782487, 0.01715215895655415, 0.04134385388404612, 0.034630832247315876, 0.024520836943279833, 0.0812627918898098, 0.015362790154833949, 0.0407295624515222, 0.039973939288287394, 0.1179403237878315, 0.046381073508171305, 0.017926664271902655, 0.03765478429775085, 0.06422725641318867, 0.05260738416484768, 0.010872302584410196, 0.03254730291965027, 0.043384313748608676, 0.011117652775869976, 0.035802073431231325, 0.021416934041847146, 0.022252952387075753, 0.08754478947770211, 0.09794070986249755, 0.03651534342357228, 0.006707765794764724, 0.03884785132662904, 0.0726434140796623, 0.047461552425257625, 0.02479794818247038, 0.04253898935031988, 0.005976351488742137, 0.0342401388972517, 0.0605717797823731, 0.0968557148570976, 0.03958126177049933, 0.028610576259633227, 0.06450684786203408, 0.034504531161679376, 0.03696307201959914, 0.014191301907562922, 0.033039342041217515, 0.026609355418552316, 0.028352276309423392, 0.031518967777130105, 0.016132595520766995, 0.09987447666184557, 0.042913357366717635, 0.04423468666631849, 0.050664868641404376, 0.015586760747546871, 0.022449134097945307, 0.05252904784415038, 0.04916333630981465, 0.030388786990736282, 0.006895828410051764, 0.07962168599929541, 0.006540000679031496, 0.035817513933345195, 0.07305461177301985, 0.05303231781468757, 0.043026657940279094, 0.04659631357137715, 0.07941717882790873, 0.0421239918608579, 0.055540987635932626, 0.032121721925514365, 0.03524011729525463, 0.03185392631548307, 0.045547845638206894, 0.051993410658812335, 0.007700084749939702, 0.03722904625559046, 0.039804530435151635, 0.026793367822744676, 0.007439159033369394, 0.05016174039713318, 0.037927641833741824, 0.059531501329113404, 0.011573525844141843, 0.023372308351099495, 0.05017024780353231, 0.019285077972698118, 0.03710238893906917, 0.04966518135681268, 0.042840249596103545, 0.03986709683592762, 0.008604695735078667, 0.04471416194592753, 0.048426643179188815, 0.031882924658636895, 0.032744953604114634, 0.05699231822584426, 0.022063236458287127, 0.03568361325549983, 0.03232478502116377, 0.03891720143597453, 0.01697161501543897, 0.044635971181935845, 0.03027105651375267, 0.02948425357199965, 0.02863562541953739, 0.03341326955705881, 0.09632710652846484, 0.03482082971341668, 0.017624210844176914, 0.01973806384710535, 0.07931629270916024, 0.026054018282241402, 0.02976165017894199, 0.022068440110512802, 0.11841581157979467, 0.07599089655183977, 0.045193235029376326, 0.024902300849076242, 0.06396693973651817, 0.06254629096797397, 0.026030704311485735, 0.05082116206927646, 0.04045989567173585, 0.0007598406568098243, 0.02207911937617727, 0.04286716992576276, 0.02621672961169914, 0.06373958399278984, 0.01775525975972414, 0.005533260118681938, 0.03118377941239986, 0.033400901067521305, 0.04570307420386423, 0.016890965109210343, 0.06996692503772436, 0.13738705205821222, 0.02460968207507845, 0.03411627014077479, 0.02269646941473888, 0.09750593198283065, 0.022451895844912338, 0.06039145034587672, 0.05401939146160599, 0.01854235764532801, 0.04849782806911296, 0.0728861720211083, 0.02602421554676708, 0.11380463643299957, 0.027802453090947483, 0.035778454940525756, 0.031441600557657025, 0.028948489982154102, 0.024837407456230254, 0.02891736382979059, 0.04978804653810878, 0.05442858200460192, 0.013563489023175453, 0.08323323131809313, 0.04895470758539535, 0.07966729121342783, 0.025436425010763833, 0.022715703967297753, 0.05320103335825186, 0.08159659938105653, 0.029003858986881473, 0.048134380636075814, 0.03468166218109189, 0.016514304574699174, 0.03033111972223607, 0.030190329998731617, 0.08271927059057259, 0.09096623773896888, 0.04834528081119061, 0.094644685516194, 0.018780501822250027, 0.057431386197887124, 0.06952591886323306, 0.03067145045215805, 0.04489634148476105, 0.06026657035333976, 0.026152516121885953, 0.0298364088690329, 0.013434006757433377, 0.03663628955461806, 0.05609170526206013, 0.0846036936667177, 0.03718923649660522, 0.018487875387372992, 0.0046360505005014286, 0.04863180152531113, 0.022026766842651754, 0.020845872950890375, 0.03422759420749161, 0.028915655453719442, 0.019327611174254168, 0.060220444199418834, 0.020774460149808757, 0.05110851781923444, 0.010787104988741058, 0.021932449927853963, 0.023865195915042877, 0.08281627264354499, 0.10889283306295834, 0.05683096861767192, 0.018490976128246517, 0.09020223357384244, 0.04848539063166227, 0.030267275869846347, 0.10853398215746689, 0.05513978355954732, 0.05415514990266773, 0.06131577373091733, 0.04701044538148469, 0.03553000879624198, 0.03174330513443678, 0.07577605485435455, 0.016014712783808432, 0.024282771290370056, 0.029743896091296792, 0.02132491922126182, 0.005193206138022605, 0.03229513358805449, 0.03713289839065364, 0.008728929340929515, 0.0884430505515587, 0.07629400689996059, 0.050516412292997685, 0.08358402297862115, 0.021116637151628252, 0.04005801743797718, 0.02689296308334076, 0.04725646685748812, 0.012785588023102572, 0.01266321313807801, 0.02770861498110237, 0.018112400373924645, 0.03783768395923319, 0.07773540899037354, 0.03236703477018783, 0.09584431025770404, 0.046906069732241096, 0.025859682843269362, 0.05458551128545115, 0.0017235431756313531, 0.041605664432168975, 0.048774370488019726, 0.0348949104156946, 0.027515306099948865, 0.018535219621093526, 0.05646736030617068, 0.017260962594000083, 0.047012785780093366, 0.026629365635134523, 0.04254001590813841, 0.014097589244615408, 0.032670689040734884, 0.01823516021813116, 0.025375737440622142, 0.09582592414752131, 0.024903639587723923, 0.01592163980427769, 0.03185737179592252, 0.06687660295996936, 0.025242037860856905, 0.08283494986713895, 0.05707480674309116, 0.04435426149997981, 0.008093695937385483, 0.033742319642295765, 0.02073763813372822, 0.032050877944716526, 0.0221753400194669, 0.10549170911432275, 0.12266753827251735, 0.09614627913481767, 0.15546286598809306, 0.09679147072376744, 0.20450547067148073, 0.23858872242271903, 0.0908533470224469, 0.14273973902867687, 0.0760974440603487, 0.3218432203415902, 0.1884496160933087, 0.17048457847727885, 0.13027060085967665, 0.18497182206521112, 0.2379724659746693, 0.13291153576104872, 0.109725532332255, 0.20352218149890824, 0.1196554184500729, 0.11725306631095948, 0.2357946005800078, 0.17897972746962504, 0.12788358580080733, 0.08003886683934158, 0.16336092605225502, 0.11634620973059248, 0.0984715321852315, 0.12257545450401884, 0.17881331785071283, 0.11503644452820863, 0.16809611551223264, 0.16504812745317338, 0.14692578134277176, 0.19024842118303623, 0.1672394913170607, 0.11057546857984797, 0.12906801135789964, 0.20538348404149856, 0.22179955316166725, 0.14661551573343817, 0.21680868951784027, 0.10272017154361933, 0.22030546720470154, 0.15344005678930592, 0.17547913466490087, 0.12698209183591028, 0.16537109480029152, 0.17467052886082282, 0.1191151196197156, 0.1443125022154662, 0.32702350688557474, 0.10874549137248148, 0.125272995642116, 0.1454505564705018, 0.16250923546331544, 0.18681271602549862, 0.168955497623932, 0.11767012457693778, 0.1313297174149944, 0.13723757298242661, 0.22150039582723574, 0.07962301899228366, 0.2146399558912362, 0.13535701098941988, 0.08493082087126472, 0.1700496856844233, 0.14472329388222388, 0.13259060620780916, 0.20254632337920128, 0.1419451219900962, 0.17834652515669025, 0.1290166528234559, 0.18519847683848875, 0.17307260734660013, 0.1661695729220106, 0.10288537074361118, 0.1834749628699595, 0.14985321780606625, 0.2344956525391148, 0.16673048717841027, 0.28352405395238633, 0.13506530002961237, 0.22974103508937746, 0.20038108311353192, 0.11077412283949314, 0.1372764596054631, 0.16270981260365056, 0.24203268600808037, 0.1365461786307635, 0.15475763608851742, 0.13389032033662643, 0.17262099851523677, 0.14889617480577963, 0.1708596091597311, 0.22015968067271097, 0.12830419105387506, 0.14863227283762348, 0.16492668719541642, 0.18212635700981464, 0.16263113537382695, 0.1926372365485276, 0.08226464337278759, 0.09875430289896266, 0.11690857189316904, 0.14544848803310625, 0.15363165537916845, 0.20019486246089782, 0.11299323440799791, 0.18986200643402917, 0.1481833606357536, 0.07689235987321985, 0.17148867459787479, 0.16361454712046733, 0.2109026878831848, 0.11450692455494597, 0.1578482186361667, 0.1408089676331128, 0.1372396107763052, 0.16694811743593987, 0.06721088542572914, 0.16211509854803163, 0.1508549543758554, 0.06806513474833581, 0.2134054358447752, 0.15857276927319267, 0.12406603177829136, 0.1537537238290233, 0.11740078338451924, 0.1874485843244099, 0.19712940759716496, 0.13675001930565606, 0.12222839369168206, 0.11818551788887671, 0.12211981605017379, 0.1666265596906024, 0.06919155978868086, 0.18923180718575755, 0.11856033406671017, 0.1815420923934829, 0.09912260732943974, 0.16269266755590517, 0.1327218370692384, 0.12852153019799342, 0.18919030054202005, 0.1140314367629828, 0.11538236386953823, 0.07570617997478093, 0.20434811621183352, 0.15603635940820942, 0.17529973219479286, 0.07813051117644196, 0.12728299585080918, 0.17020958355597912, 0.08392414303436395, 0.16699586003538103, 0.11924166202304826, 0.14504022445649872, 0.07694121330015122, 0.1000304751458668, 0.07907675999787547, 0.17295067679257164, 0.15407526625260232, 0.12726804181452722, 0.10658949778805818, 0.10328607303240608, 0.20862618100739297, 0.12464668812049974, 0.2860475475749662, 0.13691555558433458, 0.11848113589709806, 0.10469167583411741, 0.12487652981954238, 0.06960136320201621, 0.12583640734514884, 0.1864738446930724], [0.020452764508644902, 0.053114645453470374, 0.04913840014787932, 0.03409843178345792, 0.013968488107615662, 0.025687717171686313, 0.03636919683025729, 0.02452765129536631, 0.06227436805925062, 0.011126191783395988, 0.08627973316657929, 0.10248853719883388, 0.04714637619232939, 0.016033483853173113, 0.018725896990227125, 0.06154230976056668, 0.06698302789441041, 0.02148793507066946, 0.030445473666693416, 0.024428841274892612, 0.036386108221185785, 0.010915111577618989, 0.024940308386219606, 0.034750407080977194, 0.02131765862295945, 0.047141955865006295, 0.04051217351168875, 0.05516819393021926, 0.010563744393537843, 0.03190589963548607, 0.049582482165386604, 0.0266213619315456, 0.04383686103767926, 0.03925142644513999, 0.033078401034036954, 0.060922165416301265, 0.03164122774896603, 0.026659773580069025, 0.03403654720093455, 0.03502889536321163, 0.07429859300534572, 0.005259910850004564, 0.07001446079342596, 0.041470116665286404, 0.03593526930818635, 0.029888070008206754, 0.08331615267501724, 0.01025072948616599, 0.01719263712725332, 0.0486836082211906, 0.055692987140989116, 0.08242614236810515, 0.05301780044852246, 0.032885768225476626, 0.01188365834569859, 0.0753705645160329, 0.02002174620546641, 0.03438304110820736, 0.028815089176679333, 0.06095844734039518, 0.03889721803246968, 0.0757443311534101, 0.01669788030877469, 0.02164921956136823, 0.05316001701078588, 0.040512162020369884, 0.019946926228341558, 0.015225742770839604, 0.05063868375615247, 0.08843270070370167, 0.03288993191334509, 0.06073774507028922, 0.04140329464609104, 0.045047080775182095, 0.05606198488103767, 0.03561935763085081, 0.02425621293725506, 0.04420699641829537, 0.09021221569949582, 0.08620213612072891, 0.022400150436066815, 0.032214590934135263, 0.03359955149672685, 0.05423661952297534, 0.008487316700930317, 0.015618427949506911, 0.08537355840446488, 0.05100916770677413, 0.018122978132939147, 0.03643177855279177, 0.02921298949889118, 0.069840076199222, 0.06699289510687513, 0.014527459373517383, 0.03482777430045028, 0.03713819971908966, 0.025550690855109887, 0.03873984442062436, 0.05310887298096092, 0.031139296517076514, 0.015354980846055815, 0.038817322722846465, 0.02436786450655951, 0.03796201619890429, 0.050430962845923445, 0.029783650308907516, 0.05663103116075358, 0.0590009356458341, 0.05675308045841033, 0.01685350915537246, 0.0586352052707826, 0.04196743796309156, 0.06062449429244284, 0.014100991632609118, 0.054840630055555416, 0.08926708536643176, 0.03239422323062055, 0.006727377645626304, 0.04100890492179221, 0.027079974721756675, 0.042568847627168706, 0.029084528045308207, 0.03338666332344855, 0.07508860585550148, 0.022573242256898555, 0.019596636355403933, 0.06282788190630174, 0.14223111793398857, 0.03359127774714463, 0.026816616676026778, 0.023247123838612632, 0.10380079218697164, 0.05388879262271428, 0.039100078114819144, 0.03219661468099202, 0.020275208310434417, 0.03191194023876902, 0.05371834572044112, 0.0726792976380356, 0.03361076702393832, 0.07539736227162423, 0.027676000702945937, 0.011439416407337113, 0.06779590846910592, 0.05380184930418769, 0.09292328595033578, 0.04181134371807979, 0.03638444964082972, 0.027629566198635488, 0.03288010300527657, 0.10074374896864738, 0.09007432753400457, 0.05604977726996426, 0.07880691318742691, 0.07102639399348729, 0.09244372257061544, 0.0262422614069956, 0.046082031086928425, 0.022016554890621095, 0.028175394268586274, 0.020494238593645638, 0.021541323738112565, 0.13293480951218836, 0.008734053511533045, 0.008063966937873873, 0.0437630408052956, 0.0441462762894169, 0.018447429775410605, 0.00920066809011323, 0.02433853483037843, 0.04881384316831828, 0.017778432004213814, 0.03561684869289879, 0.0740217901165447, 0.0405074927144714, 0.021956056927240664, 0.038973122024007385, 0.052303262580666816, 0.05721312391782, 0.004837738468326749, 0.06764793858653115, 0.08938492501094457, 0.006085524763611536, 0.06913178194794925, 0.007289900207862019, 0.01802582669282152, 0.040801616851240396, 0.07055042356613182, 0.047952350484387535, 0.042944150270834085, 0.01802192347484731, 0.03321753792284477, 0.007653813518118114, 0.06473746330988023, 0.028573307997336792, 0.05315950373187662, 0.019506201591162432, 0.03554925675533953, 0.01447876012178078, 0.08845629621176951, 0.11353558635399227, 0.05628754031814395, 0.03269480548859124, 0.0726529901787158, 0.053052596162043275, 0.09146483840360757, 0.032371592993337306, 0.056332785470951954, 0.04295330502152924, 0.04548489236302915, 0.05090336713399138, 0.02255924391530214, 0.029771844893994353, 0.058266138582820856, 0.0762245686905038, 0.019089980276241418, 0.01820409918324121, 0.040771452139221856, 0.01665479743913297, 0.09822308221050809, 0.033688352578469825, 0.03157996752810094, 0.017718096834517295, 0.042507587406303615, 0.047019305188328996, 0.014178912350607496, 0.023927884889886748, 0.05363746215739558, 0.08065488580013476, 0.061301118468925844, 0.01986310471810641, 0.042039385110500364, 0.054671443367917696, 0.026679257111203288, 0.006851446542573432, 0.047700721244778366, 0.04685074286234956, 0.07484173402190208, 0.08504492200670705, 0.018574203920340347, 0.04728522962860523, 0.06386708400602784, 0.06990965230450516, 0.06642750689699765, 0.07570464779893238, 0.06969425136283522, 0.03053154364498633, 0.049339042405688, 0.12447559770437018, 0.05205665121696169, 0.046653417765253016, 0.012735198589883024, 0.07557266617133733, 0.0147729053259677, 0.047706206434316216, 0.07039754305996242, 0.07190306670963764, 0.019754703276820725, 0.08057209467815776, 0.052170874926471905, 0.018280110427088315, 0.018135543890117158, 0.025755481479028543, 0.022049299403724652, 0.026218215822272246, 0.02632036407087599, 0.017911482324463227, 0.05301266765942978, 0.04462960116084545, 0.011796542657389036, 0.017936629160577734, 0.03958673929915794, 0.05552815566320093, 0.041870887901994495, 0.06035565488761472, 0.07860848875415903, 0.05322926369826159, 0.0729084192144294, 0.048127983801908074, 0.01252395080237259, 0.016096355731508905, 0.05430672805936587, 0.04500208843138911, 0.06783386812575402, 0.044924985512249896, 0.047717575179112535, 0.04704118082900682, 0.013875830730783844, 0.039190740790218115, 0.024665560528275468, 0.07362605207749913, 0.031993760344301986, 0.04139411691275816, 0.04642615395207559, 0.05102954564555999, 0.04357623792583904, 0.0443965150794435, 0.029740626811079925, 0.0404630902583801, 0.012242194197531189, 0.04111592740481419, 0.02011613972905663, 0.023905446174584573, 0.0288060991348879, 0.03853003592080167, 0.015972279173682536, 0.008211051988896103, 0.06679663870243296, 0.07301113628331693, 0.022362977934760914, 0.022390392391131293, 0.044170821746510845, 0.02212139976871831, 0.026812918386572314, 0.022707671535411672, 0.025846938970648957, 0.10229041153985648, 0.04495286345181446, 0.029530456334713007, 0.01791056110373428, 0.02074864681720013, 0.027763936105334473, 0.017452386898859855, 0.0041206816076150826, 0.11095599211271732, 0.028528620173493703, 0.02327814082344694, 0.013910264467760442, 0.0528142087522053, 0.016487790271639824, 0.05954992191325273, 0.026149740968380245, 0.03560037397208714, 0.01969009716694634, 0.0328006443657702, 0.026892457465310732, 0.04267232695354089, 0.05347007577637992, 0.022262700855912223, 0.02990377098021488, 0.012078152747914917, 0.007845660607751099, 0.007758861409515263, 0.0023794863297934496, 0.11620918724445567, 0.045652163830856164, 0.04701069052962046, 0.00236655117459445, 0.02313488812726592, 0.023153605570475903, 0.07452504859576303, 0.021056058749015776, 0.10404698986319766, 0.11850337542953993, 0.337807726595671, 0.08053630305033538, 0.10188030169135141, 0.20633023082008287, 0.16008108914379152, 0.14151654176173672, 0.1172792895006076, 0.19051813009765842, 0.15049449468572296, 0.17070276031811393, 0.13087342012553446, 0.1302471279256767, 0.11619493800906405, 0.09736765311249802, 0.23393283838466292, 0.1614574580303123, 0.11561298697826364, 0.10930409204334983, 0.13023523824109187, 0.10272031710032495, 0.18489555035146976, 0.1221109600737691, 0.14914095521934573, 0.1473251276559407, 0.0812514461276512, 0.2422642284223149, 0.14640271182983153, 0.101535776630044, 0.11677731804910207, 0.11197408465968986, 0.17520941042852017, 0.09511429741377793, 0.19725115429009163, 0.09357842902142195, 0.16630844934092415, 0.113625310571684, 0.1074685070723776, 0.13830867115288012, 0.22955230166835172, 0.11897380704120283, 0.13805593874666, 0.17079317401493752, 0.15013205848874586, 0.12776825892468616, 0.25819363252770516, 0.11371558637268121, 0.10456031473774104, 0.10687316482466076, 0.15736061899412065, 0.1763601510995819, 0.16122145698435847, 0.16392180966513772, 0.05328912580866487, 0.16764507358593328, 0.16165605866380278, 0.08104168359310397, 0.11976973409013403, 0.1833741456991242, 0.18570463113006086, 0.21543186097856493, 0.2865976906351505, 0.10716321337367259, 0.18557018269934963, 0.17512894055295378, 0.08734591305255891, 0.192651730932055, 0.18639588758589762, 0.23991512705481824, 0.17874757218505108, 0.14921485206052182, 0.29558194080187433, 0.16727424106530606, 0.22731935455193444, 0.10066931586592429, 0.20744965381679997, 0.13554776688256573, 0.1529724673638421, 0.16251881156236897, 0.1516292087974087, 0.13727704183228556, 0.16153368377877822, 0.24205189949322134, 0.06364589143965034, 0.07309785743634548, 0.11572499669367269, 0.13975219530684335, 0.15626270774631731, 0.12846464050873635, 0.09136716985414106, 0.22166072270802914, 0.18217543260224406, 0.0637124453280722, 0.18146844070044257, 0.21026170211693934, 0.1755804574537662, 0.1884468428550228, 0.1730629393169957, 0.1533788770076729, 0.13588352789801939, 0.2053741990558563, 0.11395914104556847, 0.1161076422900923, 0.16748917469334218, 0.18687668436717603, 0.13984558142481313, 0.24170182795534212, 0.27482233701213715, 0.11834883251257482, 0.29625812064736123, 0.1351622407955508, 0.20742775902392405, 0.1024644130900983, 0.154619142713566, 0.15770451586333015, 0.1677857886158651, 0.19672212461310049, 0.2196784855257119, 0.1899033751819403, 0.14210149585720033, 0.09412889383853444, 0.15432957679994647, 0.11125597682210708, 0.12024229542622644, 0.11861191476665198, 0.08631373980953809, 0.23494428894933195, 0.10283656328195527, 0.10335774055772251, 0.1530595562390743, 0.1713337409760683, 0.1528932538724715, 0.10466158390045167, 0.08977166151687985, 0.13802144946830888, 0.1269816628266727, 0.1340986043214798, 0.22104454286877187, 0.11273824204240115, 0.20654012358957724, 0.13834859965549362, 0.15005361108529955, 0.1283468851338952, 0.08479474067327478, 0.125028628916029, 0.10128004115916069, 0.13917712374560295, 0.1816511220268665, 0.20928204420112798, 0.23203908435760007, 0.2697616214713743, 0.13528933478218896, 0.17716379265391058, 0.1109588496206749, 0.164683316383631, 0.20389301401953544, 0.06642092620172808, 0.15405320292038305, 0.08818150047333011, 0.10565455642438705, 0.10200872867097778, 0.18258037135726024, 0.0995465144214611, 0.3061563443512686, 0.10759503415395176, 0.0772460550069809, 0.11706993299266023, 0.2158313758310772, 0.0943383729205497, 0.13024634651599393, 0.1255985830099352, 0.10775817257742729, 0.11093288690092103, 0.2528140099058228, 0.12545505643732127], [0.07939153020420382, 0.04901430922590437, 0.03998631543870415, 0.03144907949101781, 0.03146516925264751, 0.035145880819688884, 0.05882403445279887, 0.008094188148876833, 0.04870282170633155, 0.02907278966308842, 0.06887763993994844, 0.07043020138817449, 0.052959225365831974, 0.037125302628884395, 0.06161279751047973, 0.05803061634181969, 0.04887024639174343, 0.04343396773742091, 0.0397590477950871, 0.01498341671146092, 0.04190545378913803, 0.06256332110253073, 0.01563146963880788, 0.03330549630787104, 0.04590499582850645, 0.03099870406121256, 0.02400360502032263, 0.016126177619181333, 0.057600369872224916, 0.054732535049439444, 0.056290305895550605, 0.0359615691066269, 0.04121592869201014, 0.023641705084892533, 0.0170810085405866, 0.06450485603343095, 0.04140391517730971, 0.033210938075377096, 0.0074528724860189665, 0.0460557351189275, 0.026991091285561843, 0.024811050201195384, 0.028842283382771478, 0.008246544842428018, 0.009434238722127293, 0.05127353698856408, 0.032458949999343005, 0.052689857360336094, 0.01652744106738077, 0.08033523561372873, 0.08129648443671965, 0.014369495873970371, 0.042999814219412305, 0.04941157177991925, 0.05398708553383908, 0.02046081992316871, 0.03536825316146978, 0.031551848270840226, 0.05062408595075531, 0.07861144585354675, 0.025455006473367254, 0.08791703926098925, 0.04745618214890842, 0.012056059729788574, 0.04034368396406213, 0.04383323361135779, 0.03464064200318629, 0.03010730905037734, 0.035583313194013415, 0.04378450658893393, 0.02172419467129775, 0.011730716552495236, 0.052893575461160754, 0.060700306353429635, 0.05945377404831591, 0.05747756214752313, 0.047274443110631365, 0.08214630577112399, 0.049558392530607606, 0.036153493283857266, 0.06611190931571108, 0.04758791862836769, 0.005570581528328119, 0.047014904013204004, 0.01889138155797076, 0.053984779609187, 0.03922233425621544, 0.055061148464559555, 0.04072824094985281, 0.00223413551030981, 0.04145581380374009, 0.02810790000723735, 0.029570086063036037, 0.01391661246382301, 0.050121574407263156, 0.0572489730022367, 0.04022051617803593, 0.01962012078072275, 0.12777624156085715, 0.07697207898262047, 0.02533196509184857, 0.02041864295249745, 0.11831361545069564, 0.01720725791528821, 0.03710946759148952, 0.011947934080155627, 0.05770563035302105, 0.03824933364446606, 0.03224611162177978, 0.013166958083128257, 0.03695614658476364, 0.05547013982469517, 0.030672743225530274, 0.035192098904160724, 0.03860538449859427, 0.10014794706817597, 0.028122794671705174, 0.025048868790749582, 0.0973301531086045, 0.06612734598738533, 0.05136475124726853, 0.026065116981044415, 0.0708241927467527, 0.03693061287424738, 0.028664273277465856, 0.03232705647185926, 0.0063382514241722325, 0.03691440628420922, 0.011258352484043327, 0.07464066658529543, 0.042840077226320585, 0.038530250425420465, 0.042790166598053715, 0.05081095777812505, 0.0738337078702546, 0.02246454395654221, 0.013174993387844055, 0.021555929204388972, 0.040049544505534634, 0.08604937818862739, 0.02443915664879305, 0.015056815595486233, 0.0023888206323458543, 0.06170843592694691, 0.00525224661912709, 0.0017366226905235842, 0.07465277077449907, 0.015950099013054806, 0.087699830351818, 0.07123467031746142, 0.049449021988097704, 0.025938616712547602, 0.014927360142821507, 0.03683070351760234, 0.050222314969306035, 0.030389150882500316, 0.02794281188999453, 0.06428104344635241, 0.024437588083768086, 0.07240915971417582, 0.019643158959825675, 0.05181741344952776, 0.05212836853799321, 0.009702243091117953, 0.010811410085748761, 0.060998337538612474, 0.05064681960990833, 0.024861449210513985, 0.08228670670500687, 0.04333424990275695, 0.06698022401260753, 0.09506279332262856, 0.051810288831831953, 0.017081979557030627, 0.040809009599709706, 0.026263210081285047, 0.0196286664915181, 0.00781014716560622, 0.030161377620853247, 0.04509059839972085, 0.019115581019451062, 0.06424316039849674, 0.08150707434622512, 0.03585240540785655, 0.07548653490601048, 0.021002118498267188, 0.013703889957058334, 0.023030619730331728, 0.07860134881470474, 0.031448075915837, 0.007292308596773975, 0.011914578611932456, 0.06925326817098164, 0.05839967536890219, 0.046858108797741514, 0.04591152289762132, 0.09644242574370678, 0.09735009437727352, 0.019452401151460026, 0.04746752025018777, 0.04115142791922535, 0.06027529992523694, 0.030759631002682353, 0.04492257999616765, 0.05037067938716181, 0.008145972819728477, 0.03205323749552331, 0.10244232677524129, 0.03255876359499751, 0.05101511254906655, 0.05981629451496467, 0.037370423951576796, 0.03265316094902735, 0.09327745605860988, 0.019375826832988573, 0.0523568082961344, 0.048049387011316516, 0.012935250959990006, 0.05583967382629072, 0.0036494585313653996, 0.03441234780175071, 0.0011809879769345806, 0.06006482875935974, 0.021390322062577453, 0.06437315785836789, 0.03693611338554371, 0.06433529013227071, 0.02098352171390528, 0.028504913582676844, 0.010035545921944564, 0.03007822069189241, 0.007626461306391585, 0.0355619776453222, 0.03897887534431873, 0.009081531841788561, 0.06840730791971569, 0.04423463687060341, 0.06438057358947492, 0.02334813444664882, 0.018024419006260655, 0.021655080133988973, 0.03890547646029342, 0.04343262708355342, 0.045340806546230475, 0.046549482616565885, 0.07666359069727122, 0.03751129602953311, 0.06409756921892686, 0.04776614898395154, 0.01967726519421464, 0.0610656728367171, 0.02801093242822155, 0.039564955589031024, 0.04619566490873695, 0.057067203320442676, 0.028410853307333686, 0.01889790671186582, 0.05080905404963321, 0.022471003992963704, 0.034424275790731755, 0.060824355140568755, 0.023240979813459902, 0.06284085943573905, 0.05307639468341105, 0.02657620296362908, 0.08071301655182916, 0.007822368183218303, 0.028826398549661524, 0.07703131290092584, 0.06303261507362609, 0.04306552158067784, 0.02925101044257322, 0.04770223809886844, 0.050726645971618356, 0.047832729685450756, 0.02132580213759455, 0.08627873725227772, 0.05739520386522336, 0.1352546769644945, 0.02173936704263812, 0.04243362927809358, 0.03267890916416242, 0.020261411066918124, 0.07495578919206897, 0.04327430735312162, 0.007347124581781006, 0.04377021521870648, 0.05438120329692479, 0.03917840294419758, 0.08370128805719076, 0.0406745994733947, 0.042150161424351316, 0.0038901482748183156, 0.07306063322410469, 0.0570048897286817, 0.03562526416874701, 0.05322947054200115, 0.045033658914748705, 0.06991303841313047, 0.03744408330549637, 0.04587350195393928, 0.036862607249209, 0.021209291655630357, 0.0333393152592884, 0.02249062541992434, 0.0351201287741142, 0.01466969891841854, 0.01959651761177567, 0.10317165780091479, 0.03571045697636662, 0.06888525485391579, 0.05458065045757159, 0.05738285835832358, 0.024495521567821987, 0.039494690004616015, 0.03724569334618507, 0.02366680404051177, 0.026314026608522383, 0.01544436415462124, 0.016102578280673876, 0.048715423852685964, 0.04058485610350486, 0.08610588483392231, 0.0007644383215172697, 0.052969510096215436, 0.044006312025650855, 0.04064498251424201, 0.037414539124696486, 0.029388532801080617, 0.02813697687440342, 0.021853891441658623, 0.03285023323710888, 0.022361033986653053, 0.06691414892913834, 0.03381265034418433, 0.11585872500173508, 0.04075203564078097, 0.06927067368862129, 0.040472068808852665, 0.03952243770923346, 0.022201331467517925, 0.09449624831998542, 0.10375347859676808, 0.04649259292730882, 0.048472416932664575, 0.03986010628361856, 0.04170470044858033, 0.06888612053327023, 0.0492851902550507, 0.02813528573531057, 0.023413583253239913, 0.02108595341504101, 0.14299294640941007, 0.21129628853692164, 0.1409124661116831, 0.08006244702565093, 0.1194024945218717, 0.14653654739020333, 0.14122576542919682, 0.14986705335397876, 0.23243259308078598, 0.14330871253004, 0.09375589328908152, 0.13402669930890684, 0.13269508527892251, 0.12139354171531817, 0.15545051665075366, 0.15137419344917422, 0.16471918462024582, 0.2101062015900689, 0.30612171717709113, 0.06679810959124757, 0.18823065284279086, 0.20354485770146694, 0.12778410928383951, 0.20526224296660195, 0.11638083690476995, 0.15902040976910822, 0.13051964072210173, 0.07044570700776193, 0.09485777287233262, 0.1505709962258416, 0.17044091146559487, 0.17725638204043914, 0.09241245852242555, 0.16505411826074123, 0.12481195626840477, 0.11476549455114912, 0.06195310142732436, 0.11348651076156287, 0.12238970116501856, 0.2531449752108705, 0.13550321120888958, 0.10777864244676406, 0.12572583787503744, 0.1464010570799151, 0.21065556324057041, 0.16902542612966032, 0.17521437467826953, 0.13798233301889512, 0.15073044976640135, 0.12806858837364182, 0.20815175807764455, 0.09550550021231176, 0.16020948547990094, 0.1747015400999977, 0.13419194447417415, 0.1264193313076131, 0.15075494925821983, 0.12781411694783357, 0.10596987055314165, 0.2869647999684657, 0.11115768774142189, 0.16918006863805557, 0.1462827577826477, 0.107682345194682, 0.10034287814050914, 0.20025002079144602, 0.13134404325917845, 0.14401400371664955, 0.1720518871180473, 0.28774700638267303, 0.1817319289811196, 0.23208878814212738, 0.2612467993411326, 0.2029003326090113, 0.21988862344334204, 0.18105080020764183, 0.10695878281107835, 0.1706906561289103, 0.19567269140914564, 0.15862227387485967, 0.200452865552037, 0.26817272447289964, 0.12890040664182556, 0.11970433316403821, 0.1075303073852293, 0.1784578224103297, 0.13751112765842868, 0.21211503734511716, 0.1016577301667102, 0.116508275630974, 0.1812104529310619, 0.1710988430967254, 0.17549422659700917, 0.19439212947843537, 0.19333393222862677, 0.18457691906200302, 0.16876301037207728, 0.1098419010879532, 0.18628397746191871, 0.19766177741750596, 0.1610785509429632, 0.24214530093294961, 0.2103406244948987, 0.19290614873170855, 0.23491252694399128, 0.1516741321932885, 0.11817433300518221, 0.22429255648486077, 0.2143003031491272, 0.09864605467526183, 0.14611309995093655, 0.14221283907611526, 0.14397013752210525, 0.14198318123817444, 0.1180855434147581, 0.20739089487300766, 0.16192422008081792, 0.2339384155047517, 0.20739785095136012, 0.2252078630150326, 0.2121456502185714, 0.09334936873206208, 0.16693567616804955, 0.20615070577590697, 0.10714711786638345, 0.09060837508689973, 0.1024060142076304, 0.13357205676936335, 0.12766524308150815, 0.25095374924280955, 0.1523467267472898, 0.16084262650580178, 0.1995526509539735, 0.22725305730296722, 0.15494060852835256, 0.1171235285038429, 0.09205428177430745, 0.09259045905163212, 0.15448939806270987, 0.12299580694807154, 0.07183513003251246, 0.11373800210534565, 0.16988738229678524, 0.16283303018539183, 0.06324897362520138, 0.13743612765064164, 0.2863410818240335, 0.12485790622210312, 0.2164942717119571, 0.1823724550946105, 0.21030521591103848, 0.11723867151886226, 0.0677680381904206, 0.11806508886717981, 0.1305708920042361, 0.14324932539414975, 0.10714220724278882, 0.21520748914730167, 0.06976948119699955, 0.18665477933902896, 0.12253337329433811, 0.1119043629977011, 0.16891448127646602, 0.136757526967314, 0.08756374249294882, 0.1778928172444144, 0.22767632088113218, 0.0996965297587937, 0.1736313765568118, 0.13024109115283336, 0.19541329403798427, 0.1185835158872989, 0.11352696786484412, 0.14262081153931158, 0.17308973707258704, 0.15953252422473124], [0.03970673931161723, 0.009691561910233671, 0.013780350319951052, 0.03590257650601768, 0.04442473775857399, 0.03305188290053799, 0.0692120066753799, 0.046345691737388416, 0.019938100895453847, 0.06142774131149054, 0.07892700513043711, 0.013871920809540299, 0.019821816409427314, 0.012527527475369074, 0.03447391062734589, 0.1376409182745603, 0.05122164985345257, 0.017477482024039474, 0.026514159417861415, 0.018928780055214322, 0.043245935286845893, 0.055481546873887705, 0.08516191895450316, 0.06182085549939544, 0.03252140148693035, 0.04564537629184704, 0.014683844731940378, 0.04272447072810704, 0.14792445356086378, 0.02662201502150105, 0.03502410731368488, 0.06417158097329159, 0.041009674840156114, 0.030037125820414196, 0.02024298282189956, 0.06015059613292256, 0.01699592681571601, 0.0888268759233817, 0.04753973935880969, 0.03301016558262129, 0.0478498823940754, 0.011228783405385913, 0.0402326088759207, 0.02390483521946496, 0.012738976360959633, 0.03212655210987695, 0.03541000112290344, 0.06248187063442123, 0.07083888631314039, 0.05005530014093365, 0.022247775547927427, 0.02272145345716948, 0.06608167182533972, 0.024148384146692774, 0.07789299327639804, 0.07677931593911302, 0.036221043086580695, 0.032639218148805445, 0.08611125511027153, 0.03960627071078747, 0.08968825752456343, 0.051273445058013165, 0.06089783829426574, 0.018841934412898078, 0.045480652066368255, 0.06316035640456023, 0.05784613853921333, 0.009942680743763284, 0.10613359120343963, 0.014340803965986257, 0.05172529137663303, 0.07190233892610959, 0.0871544830020397, 0.08515949811666243, 0.015041588640381253, 0.060118217426802845, 0.09445994341325376, 0.002646439003705558, 0.06731928686701483, 0.031547533280606714, 0.056811184397027384, 0.04810034334960003, 0.12478352674553472, 0.014693498397396218, 0.005707840065306594, 0.015064009161095227, 0.04899034599563287, 0.03387091899170511, 0.03358476983022786, 0.050846550223087116, 0.008392468312635057, 0.04065810943082456, 0.06395180566957401, 0.013891871654308371, 0.006001109535235071, 0.026822285726666454, 0.03771225621383037, 0.022865255821436163, 0.0029429418434794513, 0.027124133944932013, 0.03994749393314123, 0.05598276372878783, 0.043506209828680566, 0.01527937467119867, 0.03131698486545394, 0.08283622923397249, 0.026061922394400163, 0.0682363553994125, 0.06943308432856876, 0.03589450193929576, 0.05612334469333292, 0.08826638301534039, 0.006989397431513476, 0.029129870874326558, 0.03660085798812009, 0.017774109353101062, 0.02761214918967697, 0.07072391949834363, 0.03231593670563833, 0.031545489741068695, 0.03490686138731337, 0.025905278481302724, 0.03048771192439862, 0.01505623528388359, 0.043493910287056244, 0.03948889837990846, 0.08679897990077735, 0.07537850118692845, 0.04164884497802104, 0.027960826447533987, 0.02138329129065237, 0.03858310283131657, 0.037424862159476165, 0.016156037811249975, 0.04545751621105498, 0.033143621929470575, 0.05456693748372698, 0.006982610371309303, 0.08379347141711943, 0.03268622530383929, 0.03332440335784228, 0.01996897423880235, 0.0486277527506313, 0.06679209580104198, 0.0493934691222685, 0.035263356572437676, 0.025846624874600002, 0.047472499821695595, 0.06351800072157095, 0.07366711439024057, 0.04673304111366311, 0.023616899157904332, 0.06750649577307125, 0.029008294635963057, 0.0333966224664642, 0.03846615950967516, 0.036288508619632454, 0.017429040369367408, 0.09404877636341319, 0.044177268376393665, 0.03346219576234299, 0.06656506564468145, 0.07964153533741351, 0.025524226347765615, 0.07067666719517401, 0.026267927267678806, 0.03171468217436585, 0.09270122770460383, 0.03480469973217096, 0.07110292617712291, 0.01125694958553199, 0.035334303975105286, 0.06531683262437582, 0.06217587979570512, 0.007454829361860551, 0.026552316342150013, 0.10813492695770918, 0.06240620796057967, 0.02774732157347664, 0.05468819771082171, 0.01873080186816233, 0.044577036037920945, 0.04790792504565851, 0.022929132232562672, 0.005649267855445825, 0.05883994609898618, 0.03505100083026675, 0.025298328086313222, 0.09313196064003053, 0.029921825757370363, 0.016496267034521988, 0.05483776105627899, 0.01332370637570538, 0.008334307875033588, 0.05702628656440685, 0.012673586926182673, 0.030575484533103246, 0.08642411775766842, 0.054376043694754767, 0.020207001587315913, 0.025504578107727632, 0.04164166290373091, 0.025020186458864523, 0.031337665408969886, 0.09111950894997967, 0.0189175185627274, 0.028875602461818247, 0.1207971575880243, 0.06917167214616653, 0.05120170475434392, 0.01934238901031354, 0.04963275668541751, 0.04099641768862644, 0.04359297694698457, 0.04832684107485318, 0.023233648352024537, 0.03905941033735871, 0.02150923806062389, 0.050058996515168305, 0.02898398858134545, 0.05672360522552364, 0.022599794864354115, 0.05646802680266481, 0.05152064247898037, 0.012844107564418547, 0.05548392940733222, 0.07991257724502394, 0.08179215864548761, 0.03324949528060613, 0.018261795180038582, 0.04333162988205591, 0.05301855121468825, 0.03529885708684883, 0.0844667784328903, 0.04359583828538176, 0.04928494893735455, 0.0924242792590972, 0.028683063499028646, 0.0534366934950794, 0.016071559380619757, 0.029304542751502127, 0.0867229073698963, 0.03922996449194128, 0.015401733276854842, 0.01842430924185582, 0.0331753417999754, 0.028740627345659082, 0.03806257289984534, 0.07887753883316632, 0.0045507111785663, 0.024970639722361684, 0.0517088549602176, 0.046761953271925456, 0.08347993461234916, 0.11022533575493483, 0.07190185629071728, 0.03189391802035032, 0.13427403845614003, 0.022502585967642166, 0.055113162004178574, 0.029032416829478838, 0.04421993181289685, 0.06163565757414026, 0.07481274525484732, 0.06485169468026969, 0.09500788014021613, 0.08395484783836911, 0.03166479835917633, 0.049709790656643535, 0.03719323930600959, 0.07209954527957786, 0.021185579319154064, 0.04697882893284963, 0.04409451555881289, 0.019878596931155172, 0.012480595971517747, 0.061192050531146035, 0.06851773183312147, 0.00440242528472276, 0.015291481733232018, 0.03982672783275766, 0.06681061214617183, 0.034554805681710286, 0.027999443024577155, 0.09094735367163535, 0.09012955481246596, 0.025761659978137865, 0.07903241116793887, 0.04251035298371027, 0.06722788491676893, 0.05644558425692301, 0.04636043892993082, 0.03485347655030989, 0.07445242346054123, 0.018241779217796943, 0.10116386392544355, 0.04103178796809047, 0.027009092436562625, 0.014893771975391336, 0.017325011374909553, 0.03875016362496442, 0.034323404993741743, 0.023592407326965083, 0.02188289744569169, 0.041422925649150726, 0.03178305360638807, 0.046887116716994394, 0.0874630478961814, 0.0184372637886554, 0.014452342537321873, 0.029758026583060145, 0.0493843220324526, 0.043325390095912644, 0.052129222726028775, 0.08315365776539811, 0.026482351447245287, 0.07292045445571985, 0.03990481900531919, 0.039883062108269626, 0.05532602719481915, 0.021699789025249983, 0.014016209639638904, 0.006810884581007545, 0.05232238796569648, 0.051468349317268985, 0.11497197056850118, 0.08045532755673894, 0.04831198279956176, 0.027229168429790486, 0.07644182356495051, 0.1029159453126692, 0.019309594701494903, 0.09659017346078351, 0.012797621349173208, 0.02786105498671532, 0.024663629986706282, 0.03394152931568604, 0.056272348794605465, 0.01686648668480977, 0.07723604223781055, 0.018043877639537378, 0.04698296580764075, 0.023525428259745244, 0.03186307532051879, 0.026062904902163054, 0.04146207274208146, 0.030277353756490256, 0.03219775232155958, 0.030645920572081403, 0.042990058089696595, 0.08008601955108105, 0.0619082393184785, 0.16831616660760296, 0.10701708210211609, 0.14322519362453492, 0.119052943923781, 0.12470691795310668, 0.09366010165502948, 0.15160895343269074, 0.14837914206568273, 0.1063625825448863, 0.15769388256294115, 0.14084065302966103, 0.08637194717002493, 0.14210223130160762, 0.10252794476165887, 0.10285288861562168, 0.22598752601733132, 0.20543326443481832, 0.08595519533921635, 0.16146239163654466, 0.12524816673249006, 0.22880453856722002, 0.16175362762183915, 0.1726721885103372, 0.10095901967537019, 0.13409200064357252, 0.07404756897519674, 0.11710105914502375, 0.10747241412079143, 0.34502255880544264, 0.13649799170032625, 0.10015068200206566, 0.16227539478530809, 0.1975484423699879, 0.12159976492365523, 0.08422813438359769, 0.2317197329454845, 0.09101437104325141, 0.28088929371968396, 0.1504144538193941, 0.16642284158977771, 0.22906079497789184, 0.07677190786888523, 0.1963052655299825, 0.07802892791768236, 0.14047959579094765, 0.1542707565691202, 0.15688415827049365, 0.14790064354817714, 0.19232861036735197, 0.1119163369519576, 0.14928634338561567, 0.17382907320655164, 0.10361215069649682, 0.13608876285293411, 0.15817412776091408, 0.1860628691652129, 0.19911215039751223, 0.2646034901901599, 0.13451431427271138, 0.15665345855297583, 0.1855134615494359, 0.14621396308704732, 0.12748976298157247, 0.07929720179808718, 0.16104856626160685, 0.1557377230135664, 0.16686559444473636, 0.08879561187519182, 0.19156192489449056, 0.13635468729321035, 0.09708587065218918, 0.1393791564529942, 0.23487307341589084, 0.18604120419871423, 0.09397255827582653, 0.14146840079657494, 0.2525094899559214, 0.20502365254346402, 0.21539478232302975, 0.1560824779012511, 0.18374461049754776, 0.20616650250890564, 0.17987381336429428, 0.11173288187673015, 0.08811030792252672, 0.09058386027332276, 0.1459414196471053, 0.13225487583587248, 0.1010875768899437, 0.1561561602378084, 0.21532108466471397, 0.14987097572415106, 0.11673626339723987, 0.13748212356961545, 0.2771650951716208, 0.10180163978328628, 0.13342280751995503, 0.2001387848248405, 0.14655102645197224, 0.13907158747315407, 0.15946434239947027, 0.19479032665971788, 0.21389692721347656, 0.10169958921089288, 0.14252912613653368, 0.18294748069057543, 0.19755552102240825, 0.1476889121676645, 0.17398461969869752, 0.17265035500449522, 0.13743718485197715, 0.20699418390229826, 0.12199014800811007, 0.12622365712999337, 0.18971271121934538, 0.16111428128375163, 0.08555016465364926, 0.16331641634385433, 0.1615405172830628, 0.2516854551410483, 0.1340306829661131, 0.1411750197650925, 0.13648715921707694, 0.13224713834783725, 0.1540005267147095, 0.1654872030860955, 0.18060464592229936, 0.18188116290876943, 0.1454713634185253, 0.09654456824665109, 0.1383478795328448, 0.22089495654067687, 0.12183124605085581, 0.0839491175006955, 0.12415417785485908, 0.19385404464217926, 0.21349448590509354, 0.1185065393726672, 0.18569349221164183, 0.10373506184306838, 0.214871222513818, 0.1463251377666189, 0.20168295761029567, 0.12962976831101602, 0.11105188333819951, 0.09257440950961844, 0.07496033209345995, 0.10106716064676162, 0.14363924882585002, 0.25960249886397396, 0.21253276976846883, 0.12712368786695505, 0.1808751515683628, 0.1986410676111137, 0.2503669105710522, 0.11548512690370122, 0.11584959323367766, 0.10872022579273871, 0.18054887472141176, 0.10836554240555533, 0.19936656819716578, 0.18176025891255948, 0.20687047602428546, 0.1688611768786946, 0.16644305098922024, 0.11086838229769662, 0.09504858239163315, 0.17165965010081569, 0.08796702649804854, 0.21760814823210242, 0.1357081397286346, 0.13907288982262536, 0.18896796650463538, 0.14579229297176485, 0.10837746273365714, 0.11417739183431673], [0.02974753309371731, 0.04805676060758772, 0.05706396659896259, 0.02516474725017625, 0.022542845803282918, 0.048945587308656786, 0.026982534083447633, 0.0857929838821292, 0.049914765141664014, 0.068922302865934, 0.05974164690762278, 0.08521267994036598, 0.03217867290180537, 0.028753413353115324, 0.04702251892717135, 0.022969369085565693, 0.024585490933649486, 0.06229815508929953, 0.01759737478418937, 0.03064353803863689, 0.05579580763174642, 0.02359455045793326, 0.03714168158870551, 0.06273479456262243, 0.0670340187066505, 0.03766397735284221, 0.02133617688330912, 0.08611000638695494, 0.02342588854052367, 0.013357752280670309, 0.049212373597847844, 0.040513058343241294, 0.022228521843170448, 0.01177739524733155, 0.01874864788635844, 0.03563739900146762, 0.01388424524902216, 0.052813354564169725, 0.027576298190040455, 0.053239739950626135, 0.038292215416027654, 0.02394441706729272, 0.09201168728571746, 0.04557897562101003, 0.04049207136455563, 0.06833662864782157, 0.04481685603217733, 0.020795881883391452, 0.015176750490471963, 0.024606418540521015, 0.03992895460537365, 0.05851821598386573, 0.03996461982868853, 0.02563138098095454, 0.04458933940998489, 0.02329106281150974, 0.0049080495392122584, 0.060204816005763516, 0.0074623528240819375, 0.04192753244311579, 0.048618670778288964, 0.08211504938381334, 0.058004435287007404, 0.06463820895841045, 0.04617508395665115, 0.03887472952145242, 0.03927003089038115, 0.03160410504337521, 0.03567061657386442, 0.02410383230345624, 0.15175227316156512, 0.039678784763260234, 0.04644707581328769, 0.058614953736504244, 0.07704180830548849, 0.029504466801881794, 0.03269614614245873, 0.0692221190359804, 0.07869668845688144, 0.04270713415838057, 0.06000525393192807, 0.044373812063807444, 0.03711865298570164, 0.031829139540692976, 0.10083619279847031, 0.041625260961272066, 0.07099828622754543, 0.055521379615510666, 0.03642435133036587, 0.06458263694038315, 0.06728684304342156, 0.020362839192873048, 0.019259392959816803, 0.02645212161775318, 0.07652178016160766, 0.050743622480020414, 0.06871620989254407, 0.02055198821659771, 0.02197251441107402, 0.07633042671988088, 0.03852795599208724, 0.06300733417212483, 0.041359769360673045, 0.05750164412142289, 0.033434042031125676, 0.03093483914140492, 0.02555132670808704, 0.03494450694791252, 0.022841026375610984, 0.02188114885000452, 0.05553397793142546, 0.0065073658122621, 0.07789256426716044, 0.04023136398304374, 0.017091697382350123, 0.0031036850451792203, 0.07352310518223433, 0.06520597970173245, 0.02409808855924395, 0.10775920679612506, 0.031350572075274204, 0.004339954644937309, 0.0388156296685338, 0.012444245099510639, 0.04728671200873871, 0.047501852480514396, 0.02877968442325871, 0.020281653025097424, 0.008599253637986559, 0.05915580031972739, 0.005379126579951375, 0.004861554226672818, 0.031029385882579995, 0.016506438766936624, 0.060817073474848465, 0.04198110497166072, 0.058300386543475816, 0.034789646104458845, 0.015822385452807914, 0.016510487541616443, 0.046798262009096724, 0.05531849655052347, 0.020728424011218934, 0.02555414208120877, 0.043975913656815406, 0.008798957438087993, 0.0122864022588117, 0.040961392148728334, 0.07177148344776324, 0.03930717849382951, 0.004635639685852033, 0.09591944050043823, 0.05845289549700195, 0.02429092438110421, 0.06584957782779971, 0.06449603070054324, 0.04872306557973066, 0.01851042901586381, 0.030367989618811878, 0.06269062193290842, 0.039462866712241404, 0.04794974578544498, 0.048532646765271505, 0.04923186670508116, 0.018877567077476173, 0.04752126131807605, 0.08427534072149186, 0.0500015092773303, 0.08006150473750408, 0.04550474553158687, 0.06024741815523275, 0.06847634776345185, 0.04172011030717723, 0.02722393413404784, 0.04588852876857404, 0.02547834151154084, 0.08203038134642186, 0.03845580966181813, 0.03705114148737442, 0.06694432513247575, 0.024571502168152123, 0.0365835712141087, 0.020487244210896954, 0.05098359569186165, 0.019197701814494306, 0.05693879166257478, 0.048683366903494445, 0.03176419635213191, 0.045369864261198434, 0.05329892407321642, 0.04837956707624178, 0.047185982938014695, 0.032088596283668475, 0.04238120971187469, 0.0188387704697708, 0.0773726970017437, 0.052021223480903336, 0.022269503716679833, 0.04581795674898932, 0.049153890445708275, 0.024081414655571984, 0.050320370393174316, 0.03951472320383595, 0.11667781088861728, 0.02347912399038192, 0.02091366024087033, 0.1075543242416555, 0.03186536209297276, 0.04644698388273678, 0.046045369949311986, 0.05262880781365018, 0.013529203715734186, 0.06868467771358068, 0.030308470332754717, 0.04714964738776607, 0.050479973320879286, 0.07567044197311325, 0.07316913425682053, 0.1204466034147528, 0.02610676343582811, 0.0614986427488827, 0.05107911153426094, 0.03458469843251571, 0.018651201502389966, 0.012766054696253231, 0.07502292147687367, 0.011219907319173219, 0.06284994140808141, 0.04204539123982672, 0.007109192036648071, 0.0638846350803731, 0.03723284605169489, 0.04421358477444418, 0.011975795740351803, 0.03237702455672045, 0.047700525892357674, 0.06255193703597592, 0.01658675542491819, 0.019162325789370847, 0.025962938088923696, 0.08046044502407312, 0.052050231400156216, 0.1027009963628746, 0.019597320088876352, 0.07530973713484503, 0.025333326813133977, 0.038711012701594064, 0.012448618503948374, 0.06413785012198553, 0.057284155590159286, 0.04234175235333462, 0.04981277202586493, 0.04286518192759926, 0.04079084948546464, 0.06494174065488963, 0.027967786356326074, 0.036904596528338815, 0.1409379921613201, 0.05879240651284495, 0.03472265937635976, 0.16351515487317117, 0.07241030884606224, 0.06169373469967997, 0.02756981325576142, 0.029656357139409072, 0.0529604472760712, 0.04005917806118246, 0.0921317485852107, 0.05022011629696335, 0.04658186898356484, 0.060005962563258027, 0.07127433835018067, 0.058674455785583106, 0.07564932092904084, 0.007655624358449132, 0.09538559979128261, 0.11276213632475947, 0.03088515450907571, 0.06547898279442903, 0.08167290173831486, 0.03408639271172785, 0.017641974507921168, 0.05439847857961732, 0.05335189139230117, 0.058825409580622955, 0.06620927909088713, 0.060162236838932, 0.046896390211317814, 0.029801544207598896, 0.019914382813318122, 0.024353869995402715, 0.03094371810044733, 0.024842752834721923, 0.10094625665055168, 0.0935295066465774, 0.08428878556456297, 0.04887031150921699, 0.04728873448085882, 0.03436695326179747, 0.034595561559282006, 0.04465019360425011, 0.03133803887683297, 0.03462617443273625, 0.019728116195408568, 0.005135058149349906, 0.01929063594058877, 0.006338260042661381, 0.03184394993548913, 0.03126383368526736, 0.07546222693617306, 0.023998889749148683, 0.03304317248083892, 0.05600851577436251, 0.09883104958721707, 0.07993607316166162, 0.06134562817732654, 0.007743705317543279, 0.01583574506859746, 0.028960462021190795, 0.08497064978244805, 0.022205006774334658, 0.057817559629198045, 0.02072442311703438, 0.034054194036270344, 0.05235407336224472, 0.015995843080623497, 0.020012984074832454, 0.11563238432450641, 0.010194024615620655, 0.03215305109117781, 0.07286030123190534, 0.0823501770895335, 0.0705237330628499, 0.021110031558501146, 0.09027690416382206, 0.02312494430600876, 0.03227090988788874, 0.024206118447886362, 0.09542043380919965, 0.048331353332727194, 0.024463290333627694, 0.02658666580945494, 0.008375193987552439, 0.048956496400698546, 0.052889806308573296, 0.006308334733119175, 0.046110211631223086, 0.03897503724381809, 0.020144048312138167, 0.023136284322507923, 0.0831395540867121, 0.038672754270655495, 0.12338598318878682, 0.09989208902322477, 0.3383184314495133, 0.15850173760085337, 0.06425013562904731, 0.1218231714841339, 0.23757998380930195, 0.18397509571044676, 0.1318053354419047, 0.1479493360966444, 0.10740139777021063, 0.24097825791085922, 0.10209711223480203, 0.10266087633828003, 0.1010441243828785, 0.13248695451165401, 0.12152907799088186, 0.20104718124193532, 0.09681246919377197, 0.2157170142257406, 0.19065480018335004, 0.08970210073335518, 0.13392436528398147, 0.16700502244695542, 0.13272180642572143, 0.2338418577827754, 0.17738612669129528, 0.23747129125460503, 0.16855052822539884, 0.12179531652720706, 0.24133893210561047, 0.14116639361506508, 0.11671904174070205, 0.11500391643494369, 0.17252220381652156, 0.13030144355950818, 0.15555666579354196, 0.13441410997221548, 0.14266738968510784, 0.2662285465386606, 0.1902195856335663, 0.16537812748743644, 0.2139346800263851, 0.14990871321530114, 0.29007125585790605, 0.13960138323806948, 0.14275011185917164, 0.12386516352454502, 0.10497084593460446, 0.2931082122508557, 0.06561230507589157, 0.14634473429572198, 0.1937947034715645, 0.16641286712500358, 0.1134979714369101, 0.13510899768481333, 0.19574309488938701, 0.19612521954601814, 0.12239094222745589, 0.2817217248582071, 0.13878821154996274, 0.16759547705371536, 0.14409160842337917, 0.176406882462963, 0.2878298970960802, 0.30884647741913795, 0.17925643842787514, 0.08124995225619885, 0.1843535737885583, 0.23470848708623843, 0.3280161116873065, 0.15971715141448284, 0.1556921561038302, 0.08049991387393206, 0.29643171617100317, 0.17009626383021956, 0.2436463429682678, 0.17308265842016668, 0.24307861052934202, 0.15225101172203018, 0.18382701091468337, 0.24356645531952384, 0.13978997876326885, 0.0960252985298153, 0.3172433526525575, 0.16948336284727822, 0.16740038510291808, 0.11530988429102207, 0.17973381845701128, 0.18941635776671673, 0.1893752801322168, 0.1289661829510043, 0.09694028330305893, 0.16691437892375455, 0.1542784327701215, 0.20757155372731148, 0.14991798287918492, 0.19624920321568368, 0.11358257818726764, 0.24151493314533468, 0.19745484174739933, 0.13767030540733569, 0.18975596454355026, 0.19917785009789854, 0.06738621996895922, 0.09478509411095612, 0.14081722606093655, 0.15138258977282434, 0.23196301182671902, 0.11886125340336755, 0.11577217238804988, 0.11000216668171268, 0.20488745743228545, 0.17455878727618726, 0.14695826347076124, 0.10885178607197539, 0.1793111830709442, 0.2394931964696415, 0.13356822632974194, 0.2629081376137272, 0.11508139856760541, 0.16833279071555984, 0.18549853815667092, 0.19323579636552643, 0.12546349106536758, 0.12861134634623606, 0.11190376544912016, 0.11047051453422155, 0.12255854694352997, 0.13688701114827587, 0.09233450907613001, 0.11477007575693632, 0.2139224532631136, 0.12681313114421022, 0.110050008872584, 0.14931979078438976, 0.11427274679825192, 0.15318789128814975, 0.1413441719787736, 0.1336851926340211, 0.1588825599080132, 0.15900308086026102, 0.10174251311729032, 0.21854999204797132, 0.09457123300601399, 0.11880247913781675, 0.07947790661766645, 0.09074525201633092, 0.15198401475865997, 0.12653678790816378, 0.12704721697035337, 0.26174524678818645, 0.08271334107003867, 0.13216859901384, 0.15965195733212656, 0.28163010074246314, 0.21435734605596912, 0.1537089230072114, 0.18335585151949238, 0.22381411925438913, 0.1680546395120121, 0.13978473872186678, 0.16949468562679906, 0.15430970447919062, 0.14818694592723924, 0.11060805029926762, 0.12161484919488431, 0.13476602012111297, 0.1559000876882384, 0.11686207801704446, 0.12695254382467078, 0.1833537064733044, 0.12248900148176378, 0.14244963685351034, 0.16300202918148812, 0.14304746122610185], [0.035938597960217346, 0.006385666999830715, 0.02359772206193978, 0.07160449160202857, 0.06128184752719057, 0.04588568658237496, 0.04363482833028801, 0.033033385707606236, 0.017375984950171366, 0.030578242449630654, 0.02955738815569109, 0.03336919268833534, 0.049386516874355656, 0.07342090139225607, 0.03498349316237915, 0.043959653440622554, 0.04131646241031347, 0.024280289165495385, 0.007632375983971983, 0.03385408037912942, 0.024116015016672113, 0.04546850191188916, 0.034984726563937245, 0.039389720637231104, 0.08224859383077392, 0.028518521219431877, 0.05750165944318137, 0.1214954007657305, 0.05665803192964485, 0.061976195147801796, 0.10223281704970907, 0.017924254925380793, 0.015331951285442038, 0.0147333704010253, 0.029741281816255183, 0.02650683178686567, 0.03955901840761785, 0.05797631986018631, 0.020896214503614653, 0.022559113680355014, 0.039655062850684895, 0.029010200279674707, 0.040687236093705705, 0.03943533734268239, 0.017060699549713926, 0.05500669876534132, 0.05780047969892622, 0.006217787449713797, 0.009533012353424585, 0.05465493034270983, 0.025716615923409982, 0.015299628120696834, 0.020539091126392447, 0.02625394999350031, 0.040970025959634976, 0.004029622002910342, 0.024712245926381122, 0.020068739953961585, 0.011278384725653358, 0.03757116197037601, 0.034546777080263824, 0.0685110055811463, 0.1382807242654024, 0.05072729331591437, 0.05117631277009364, 0.10603142571785759, 0.06732513211787709, 0.02636582755874242, 0.03136329871091632, 0.0948771548968169, 0.06442812466693502, 0.03667117719868979, 0.03827089518909493, 0.04593296952906155, 0.04178017160044082, 0.03634491567349723, 0.12289443819393074, 0.034659840166568756, 0.1745052836955555, 0.05602197976963175, 0.02968060190699274, 0.2626939394300984, 0.04299427540371976, 0.01693025584362688, 0.020652361056436936, 0.06977662113645385, 0.05767988213788598, 0.06802119194499909, 0.02438100866012035, 0.08602580566319727, 0.055056513632617654, 0.06686151102786103, 0.07443844235592312, 0.1074908078918534, 0.11048435008213406, 0.13735637789772404, 0.16688284674479117, 0.1642478873292285, 0.059848294007561864, 0.04522258385775551, 0.03409724051673566, 0.08304861178922077, 0.02296518049983969, 0.043703197847090425, 0.04527217272909419, 0.019642620783058867, 0.05470953708995254, 0.05332428541394973, 0.035210293492362384, 0.020991347302051804, 0.041557243844914826, 0.053110719252858436, 0.017687748261396925, 0.08786193455659574, 0.04132270985733598, 0.028972152522915316, 0.01002628870698954, 0.02500729128387907, 0.030818085426524765, 0.0042550500778992095, 0.02682948312271507, 0.035314718937321056, 0.08181117294776825, 0.028448952775027965, 0.07588057989074339, 0.07580404770710776, 0.014941961778658292, 0.005755962357075224, 0.014279531296192399, 0.016548728735576716, 0.01690921140834689, 0.015040582192370729, 0.04262326285243035, 0.02698744662226208, 0.04357587020363539, 0.03271370870812285, 0.04818425295994647, 0.03146596598408876, 0.09749922105261395, 0.04948500896834078, 0.0416353426783556, 0.007785248829262152, 0.004857397242073691, 0.03018140315919394, 0.037175565657596436, 0.08300083854626264, 0.11444503231154335, 0.023857812742672624, 0.023591721678272854, 0.022353518664115862, 0.017529493648438685, 0.04078104356003385, 0.031174226295984084, 0.06461351028373165, 0.035329565721293615, 0.014348758831470004, 0.007595285358312991, 0.03028260911965082, 0.00940997480234552, 0.09633656771432969, 0.04184828830822822, 0.05496898425682899, 0.014168748279072106, 0.09307988198293794, 0.017705008222330964, 0.03377426167829864, 0.026879491427192287, 0.046916982654722474, 0.026769057937687444, 0.033766577816418106, 0.049913248287573944, 0.05010936679618974, 0.015923104947432876, 0.06664352836988627, 0.04875215776865521, 0.008185008829910188, 0.04281961118742343, 0.06998856702158529, 0.018881047031872215, 0.05898420428556781, 0.019750235069002357, 0.0536479001053639, 0.03320853638973448, 0.06290485842093345, 0.019433940347704678, 0.07893094282236793, 0.04858041617779001, 0.08106717133834478, 0.040783495041391546, 0.04093418836653714, 0.02601029381396309, 0.03453813560847794, 0.0455010644791107, 0.07259046974321527, 0.11146157949922547, 0.11958872283538503, 0.03177027334459126, 0.07795442586704608, 0.04927830312461142, 0.07977339439094067, 0.028534448187377666, 0.03870640851316914, 0.012529047202288866, 0.0024405847145845335, 0.018506462595635848, 0.05705660832444987, 0.030717484675528064, 0.04047217989160169, 0.06390563355037762, 0.035749152077422026, 0.05648272419949213, 0.015518534872230264, 0.023978663112727866, 0.059531834577360464, 0.03079403026570236, 0.057503115010237506, 0.01669739001250315, 0.027182996310594103, 0.04667573773692693, 0.045051535576461785, 0.10199512294944256, 0.029483456840558402, 0.012115214166471796, 0.028335880112623977, 0.013096385105933635, 0.033478279778313254, 0.039706497993921085, 0.01856694140681817, 0.02799890293259054, 0.0571469224298433, 0.04141429183824409, 0.046983682099849954, 0.017864308545305845, 0.05103856250042877, 0.0765776279712877, 0.03257959735609832, 0.0392925194013984, 0.022942284047002756, 0.0570017755812695, 0.1277169923207933, 0.06802113831884439, 0.002014462910254576, 0.03845535383950319, 0.1007722091350344, 0.07206786754390887, 0.090978610058946, 0.047974233785944606, 0.08733360968049496, 0.058607629935948126, 0.02833984461763213, 0.02376693364743504, 0.037852182173200195, 0.04129171010947997, 0.005286004762315462, 0.1878816078627302, 0.023445247582370238, 0.04381957809410749, 0.2666088325842734, 0.06354234316536496, 0.03271052178235785, 0.0602605105978587, 0.11020757017597077, 0.0282069341084289, 0.029028883248928095, 0.12870312367956485, 0.07431096532532284, 0.06923625335818337, 0.24231549502620775, 0.06408931079110311, 0.06813447336636244, 0.08684652331735819, 0.06719912597609144, 0.07670962492064123, 0.23934935580097863, 0.02977819767810645, 0.023903222604384346, 0.07726707645962316, 0.0992515322662169, 0.03219810855244437, 0.03286316480127073, 0.01618601100128745, 0.020250846714442296, 0.06783365362113522, 0.045137237832551046, 0.033245898497801636, 0.023457868880922758, 0.01625836609051593, 0.01592139465614192, 0.05495380805504899, 0.040560873721035264, 0.025326870607152104, 0.07236824295814, 0.018065176799052188, 0.012715332972396527, 0.031082299575510047, 0.04318096336998767, 0.07561484697244822, 0.04135346828749584, 0.07193071482282493, 0.011849746506120409, 0.018508996431445403, 0.027448983953124093, 0.08970230757709473, 0.014402527670045535, 0.038141380364616076, 0.002534557129218874, 0.009755976498126984, 0.04023776081721148, 0.028503438863422603, 0.032661679846745346, 0.0662628592803113, 0.06851165675588193, 0.08165039407509951, 0.017047697122419075, 0.03306082314661434, 0.1602081218433957, 0.04602270906851177, 0.02711117939813243, 0.03486872553044269, 0.008510493733469517, 0.055010713066064545, 0.031656426933383754, 0.03681330949128155, 0.03286215356521068, 0.02404285936556276, 0.014680700898621113, 0.00791992373471599, 0.037673331286397674, 0.028315322143175913, 0.044803629524164626, 0.04821453258515366, 0.0284858092650651, 0.08316210771520292, 0.08026261047850694, 0.049884883882177454, 0.013160124578843675, 0.06914924875262284, 0.05536226315363761, 0.04946191524786334, 0.06632731025738102, 0.025302104899779927, 0.06200920970689866, 0.015361820095999828, 0.027553378754565795, 0.01628786239082054, 0.0666008496116246, 0.043780254800954176, 0.01617576649052001, 0.06276970135889227, 0.029364349320530895, 0.07369631766191415, 0.015732984907264193, 0.08170169132250933, 0.23019592277705672, 0.16948909318495184, 0.1272462389522022, 0.10708222255831766, 0.17728845048094952, 0.1172964881745077, 0.2365518631714006, 0.12128674905867347, 0.12508633065848582, 0.17838584078896433, 0.1887305098916254, 0.17989238333557883, 0.12227821238939801, 0.11286784113655168, 0.15876527184680586, 0.1704470401689891, 0.22772423201991668, 0.14394689441448258, 0.13658422255708327, 0.10456481167385656, 0.15861265181053072, 0.07461867986186858, 0.17729962004288552, 0.2120629280445076, 0.0866357112423547, 0.19366862072098642, 0.16902371009270992, 0.18633763426013533, 0.17442633067407917, 0.3047703074351434, 0.1452414757542072, 0.17064939463330855, 0.26722154970611295, 0.21257882697447655, 0.06962977740312777, 0.10787777422416596, 0.1529119770613409, 0.14970635875098168, 0.15577233486598538, 0.17142852137406028, 0.09308503009378911, 0.15375064415556772, 0.20854823922197666, 0.17107762246122285, 0.17344468092966467, 0.11315317058394994, 0.17009194309432663, 0.10190795746541793, 0.14756528089844412, 0.08032398178212105, 0.11495746852409457, 0.10449907366907406, 0.31852075830101967, 0.11942800524975024, 0.10791293765989043, 0.12091270662964353, 0.14197863067590422, 0.08479872433048102, 0.17077651926346366, 0.18577667403846018, 0.1796773730987503, 0.1603756039854019, 0.1755504268071344, 0.14690089880699111, 0.1793397581505199, 0.19641961181356063, 0.1959595760150302, 0.21465471074465783, 0.194423922127293, 0.16780553836255305, 0.24018903413126547, 0.1307776744567579, 0.10827309091485317, 0.0709363020535919, 0.1826906114095642, 0.1678472441891509, 0.16200646728036866, 0.34104031120096484, 0.2769041043375769, 0.09082670248444043, 0.45454420449752964, 0.1583489030599594, 0.1418459902126943, 0.308619715393551, 0.14177736405643726, 0.12516617234195435, 0.11828838051446985, 0.26269026220806185, 0.35098566463397396, 0.15786433712609355, 0.2659581481449066, 0.22104019148936196, 0.2600817634694038, 0.2931422878417277, 0.3227764073639147, 0.35130668611776444, 0.3234077863875897, 0.08870929674876314, 0.17221281154742166, 0.21174612004430066, 0.18243236317028924, 0.19274171561964099, 0.18392209774784504, 0.1117743578769507, 0.16157943454961624, 0.1897975784395972, 0.2160072542967335, 0.2089019879818924, 0.06539137297940832, 0.1631907166372384, 0.13297761850539716, 0.12951537606216248, 0.16905441489671508, 0.07140112590164908, 0.20873550175418779, 0.08730815257877113, 0.11168305551813495, 0.09022560691641224, 0.13546455441223038, 0.146100903831182, 0.14785017367572556, 0.2385545855448131, 0.1629150322368068, 0.1298262545418355, 0.20056754891430179, 0.2308448605359562, 0.07906906847511569, 0.12059196859838502, 0.1678348948518115, 0.09172218265913187, 0.13877868141618468, 0.14853340153011585, 0.13156179609077592, 0.20323471466620124, 0.16770755571703758, 0.21883339861467963, 0.1201547545591189, 0.2308252793286116, 0.2653906608541166, 0.17820057008535634, 0.08325148719332873, 0.12639810301123128, 0.1563257414607271, 0.09430255064921034, 0.11005083624754222, 0.19458883021387363, 0.0876391944926112, 0.15811596636570271, 0.150090919567212, 0.0625817301953512, 0.16141046619703694, 0.11158105857189625, 0.190162435474415, 0.19950639456510547, 0.14064675617602565, 0.10729979918969255, 0.13262166341225948, 0.08507204918010582, 0.13269283298042514, 0.1952911643010955, 0.2152874227613211, 0.24197555117068753, 0.20445766678500563, 0.14518074030357023, 0.10918162522777435, 0.1686957784958424, 0.08715978433047572, 0.10238742125370812, 0.1760921582219101, 0.13868109713638985, 0.09682653456806176, 0.11225031298254767, 0.1405733649528796, 0.16196902090262982, 0.10850424262424631], [0.045650172002253034, 0.02390855457633734, 0.03723294564312504, 0.06060621926500913, 0.01611690412485792, 0.02463267811934554, 0.04603322745571214, 0.06739166685410085, 0.03706043030345633, 0.0658567713934087, 0.03297406368918958, 0.0864814211344046, 0.01945478943056397, 0.02162671955903211, 0.02744825616959603, 0.02390389293131809, 0.022332502957133037, 0.024621550692245368, 0.05361806864159242, 0.05503036322132234, 0.009777518890557751, 0.09046130918807561, 0.015888318810011112, 0.017308933104598717, 0.011259137724165716, 0.06750481037963783, 0.06328218353671894, 0.038992595979042595, 0.08534285360045972, 0.04421345453949706, 0.03977376051367291, 0.026384828454484383, 0.022425697553121758, 0.05712959352099607, 0.06310049046371734, 0.06326338373905709, 0.10192796768200013, 0.008169288705703954, 0.08277476599980747, 0.02483041115826176, 0.05867965369214935, 0.0731646526424635, 0.03915113787497244, 0.04972763667483965, 0.03829553257673979, 0.013070905021572066, 0.02004838116737383, 0.07461268905430071, 0.03522219466826609, 0.0778925029801265, 0.06855907759839489, 0.02950511797661743, 0.07975480909789763, 0.10552149461281878, 0.01644724123780766, 0.06731363313813364, 0.0707629133736895, 0.05384255155560471, 0.02620304345093187, 0.048115665108085647, 0.03237746122683729, 0.03306319801917961, 0.05435130671567975, 0.03166471408950466, 0.0749788101341936, 0.03455772830714141, 0.053349669737320755, 0.020726039562554612, 0.007646479662657986, 0.07712277613820569, 0.08879673036356127, 0.09002741230952163, 0.09281354385518259, 0.06734767042460942, 0.045082581289593256, 0.1697049307967386, 0.27242521725354657, 0.1773295587589664, 0.35295466381695967, 0.09325917720073655, 0.06004654224060717, 1.3759197751360557, 0.6570858700621514, 1.3231734570957001, 2.1468774445595282, 1.371974606187113, 0.31165648792539874, 0.3196019841538322, 0.8299183088444895, 1.7917643126941498, 1.1937828001476105, 2.334883756214573, 1.0129806567584316, 2.113094315413506, 4.5928895473480225, 6.228561545571973, 9.422175442018817, 2.6269909979835635, 0.21408717748859238, 0.21091670729219916, 0.1856867046726327, 0.1210270299305839, 0.04423122394890074, 0.04746806417261401, 0.03570944574030657, 0.012276266915573469, 0.026814450562420874, 0.10095083785633888, 0.04996522735323637, 0.06776799988602439, 0.05282491483094712, 0.029940414880853028, 0.062241211773887764, 0.028709282858237147, 0.011587637183707089, 0.06554778515090866, 0.010280699803373747, 0.03812251544948067, 0.024997278514708725, 0.01764223689303523, 0.047763731976550435, 0.024672876667952346, 0.061550510731796106, 0.03974594386114229, 0.05233428531116056, 0.04652485288980027, 0.03853815262235942, 0.06286822409639437, 0.0239689146438914, 0.05165240577151699, 0.06970640917819354, 0.03641114780499089, 0.027937114111057697, 0.057023046012487144, 0.05047507035816389, 0.03227628016423795, 0.011793133566125989, 0.04816794294803854, 0.009876672692987467, 0.011322597574983394, 0.0746059398196878, 0.03344136200124218, 0.03318880196480501, 0.07225054887033279, 0.019289643856726827, 0.025922262650584022, 0.05794430887627025, 0.008038811483270219, 0.01312981814055914, 0.05924901406791422, 0.020702806031030994, 0.0029859507377559863, 0.027709942228431185, 0.01361662392399364, 0.04795727642974065, 0.01735378946778515, 0.022784789776309364, 0.03735462338813851, 0.028632273784868663, 0.037349306737944, 0.04409517439442777, 0.03596209004641541, 0.057145543471579595, 0.10519488834806028, 0.0725922087628034, 0.03729400668112982, 0.027508643050227436, 0.030034547934548992, 0.10614765657772941, 0.046403439445120674, 0.03645953008784883, 0.030336781111996503, 0.06475110733581167, 0.04911496168783596, 0.0459781687165941, 0.06032815233113305, 0.08424608382366358, 0.052966150800667466, 0.090672243837147, 0.10318758476886059, 0.02487874939106405, 0.024517406784598867, 0.03309656114828202, 0.07356628955852601, 0.031081431980935798, 0.14149320672356314, 0.023296161126645825, 0.04861437302503375, 0.048203454953768564, 0.017612012809202555, 0.015077226093008876, 0.011988168060328933, 0.056793828675102805, 0.01700292119846469, 0.017618798432991873, 0.022099391977873542, 0.038905576051723574, 0.08535344859645252, 0.10403624164962, 0.02120042610312662, 0.005315888894631738, 0.03289528303749619, 0.03665721907670941, 0.08855160521042925, 0.05727689690707673, 0.03611739905130479, 0.042720958214974215, 0.04127497108833444, 0.020483553582321734, 0.05194494793672235, 0.0370640232558212, 0.05927561647108486, 0.023288314471081383, 0.03984738539363589, 0.014731029044806719, 0.03758150032691417, 0.019224972629378882, 0.012427682278587694, 0.036916183608193556, 0.010473903347437662, 0.012324981489068559, 0.02476993043185963, 0.05635003777100675, 0.02003812899572715, 0.08696542782408577, 0.07600262535796051, 0.012111096443878788, 0.014562343187149496, 0.020960069847323244, 0.13313722526354174, 0.12075070967717517, 0.02756797655996296, 0.018642519810988058, 0.08143517699453139, 0.044340877943942626, 0.028550503475050774, 0.07031164162101285, 0.06372057735138843, 0.03754681569614238, 0.07192879194213499, 0.07632021476785023, 0.09319874052439006, 0.09126837515542585, 0.021566009006252693, 0.05798594958539452, 0.12194694064918066, 0.031425596980918805, 0.034685427503239726, 0.08400227634176131, 0.057490371137617104, 0.008930362584520011, 0.131012863449512, 0.10758843047604447, 0.07888938255247571, 0.2279347070162335, 0.2147604002346916, 1.419443620308753, 5.135052300268605, 3.7886220072546317, 6.2468201787241044, 7.011609308181271, 4.483766757672833, 2.2356556355953217, 1.4180503208791058, 4.303545615365429, 6.0472789118366865, 4.628489959624506, 6.1680805586999465, 4.099397279562489, 7.715060412883759, 15.003049239035576, 18.434000361350275, 24.69138103146707, 10.618426761319562, 2.4264286891106637, 0.3620791693608607, 0.24927040892502955, 0.33950320174617155, 0.047975685522561116, 0.04578928207798351, 0.1228789325743433, 0.03773173016886558, 0.1297999164389987, 0.09019099506399325, 0.0882358544115578, 0.06700234863186075, 0.05682110140520719, 0.025921670847662517, 0.04545339848846198, 0.023121349438424074, 0.021392017032109925, 0.05801114238678448, 0.0585838582276577, 0.036786500244371356, 0.028460526448344032, 0.03954353577066814, 0.017190492081065333, 0.022134260469747168, 0.016184961460831187, 0.05087474225870064, 0.0224157364948863, 0.03691005490479931, 0.03543903202479405, 0.017479335956816233, 0.025295796165723475, 0.025801508041519313, 0.020508899601296555, 0.08723941917020468, 0.05326550731795931, 0.029103278047254974, 0.050826229740895575, 0.011260276322343178, 0.05959372682076308, 0.011479030813901656, 0.02273298691086952, 0.04090596568740664, 0.05690108098450208, 0.02186407466539212, 0.025499393607700066, 0.03592630224903265, 0.0633301789451751, 0.026925924016282927, 0.039858497498977574, 0.05471830496624593, 0.023311793150740768, 0.02431061667119784, 0.04783318933820532, 0.0825140969226918, 0.04875504592012975, 0.06358522876736618, 0.03321009920910001, 0.03643966542797224, 0.03302780092663823, 0.008930082004817744, 0.03125592574266897, 0.028130003559072653, 0.04615547593622919, 0.03852989036409605, 0.028437313984238335, 0.07303184363991022, 0.1026509938040568, 0.043422116357232296, 0.032997663027697036, 0.06225675186743179, 0.059472845807190866, 0.01976152912022606, 0.07112718052080563, 0.02408891082591107, 0.14522408555832603, 0.011226402787161211, 0.03442596501460479, 0.0541314471422905, 0.14538877914028783, 0.13788171503092014, 0.25256694655024237, 0.19081215464299728, 0.1613037348274262, 0.16677397032899244, 0.15283910677798335, 0.17108391970396045, 0.24518789573302194, 0.25265405074723307, 0.1240711415847463, 0.12340007920659359, 0.1190256328892804, 0.1844606728803727, 0.13725448820379474, 0.19026683793673593, 0.14627751774124562, 0.049620185182580066, 0.21947400133696296, 0.10895528455054569, 0.19747793163743713, 0.2767151564119324, 0.1521973549238136, 0.1104927157622672, 0.11744444273532399, 0.1715009166829048, 0.18511500389825913, 0.18159574919169952, 0.30196912226177036, 0.10531648948428132, 0.14724479567620063, 0.10989259312590284, 0.08715645950888434, 0.19672143513396864, 0.237671485350978, 0.2730908863727124, 0.2757812645887175, 0.15697051170131854, 0.20620921957156352, 0.1952987945368213, 0.1637538525486185, 0.08847432226062783, 0.1410380892095066, 0.13678322155629435, 0.12165173632843841, 0.08721891865735093, 0.16217396474413334, 0.08745683492311547, 0.13222038655752136, 0.2037047096077473, 0.1590711247896956, 0.06818000963258167, 0.20548575677939002, 0.22458517142841894, 0.1303418623583932, 0.18115236814464294, 0.16584415409353473, 0.3392987482009396, 0.10543488071209962, 0.1893627162902586, 0.14632893756272333, 0.14378336528616567, 0.18798358948721042, 0.15274244180369764, 0.10342512565154223, 0.1663635617061969, 0.20485788643840822, 0.15982028217084948, 0.24194179733674376, 0.2981509094036395, 0.16755174875499743, 0.24830912179764242, 0.3705995379676742, 0.12780718385211884, 0.2434449997400084, 0.2477900819071839, 0.3519483920066588, 0.27894557543819953, 0.4352622004526277, 0.2202398134695907, 0.7549586279257652, 3.669562137896015, 2.5531702753036254, 5.284413214652769, 6.1780330827159275, 3.522137648636295, 1.509929390684251, 1.4088365507702674, 3.5232545435428624, 6.005745914674574, 4.3353423091673084, 5.313248518974551, 3.8606754570238055, 7.377750306360184, 13.41285369088573, 15.674978706144518, 21.757202994438913, 7.003582177623627, 1.0965130454109562, 0.4687653091405669, 0.45814343878338415, 0.41175969545879676, 0.19788323811465697, 0.13490382401693252, 0.179755927754506, 0.12069381232703887, 0.1864695852442134, 0.15705165573425833, 0.16514566576769277, 0.19073700141762534, 0.12995673463709895, 0.12089514023353978, 0.16191605358354508, 0.18938537717105883, 0.09981142762567728, 0.31433246368842743, 0.15466368306548367, 0.1759245688275945, 0.10754827980793293, 0.2471616906264136, 0.15687041465313206, 0.10469651750979886, 0.1444232478858002, 0.12734694887072812, 0.08920356135575042, 0.2101471719722594, 0.16326718753384006, 0.1695766417129386, 0.20611206430100626, 0.13912077031789288, 0.20953447017217838, 0.20634742183310373, 0.12517378725592168, 0.18301845107588077, 0.14588931034649574, 0.17359952262092024, 0.17816522278853003, 0.14416049504953046, 0.11739910565196507, 0.14176055608737853, 0.23012565719264172, 0.1734635879796359, 0.12306089377811841, 0.1431296011733432, 0.11786435850925985, 0.08183770257258609, 0.17630608061388617, 0.2168945832959106, 0.0846103662925382, 0.1261697015574863, 0.1600600370476323, 0.13216455406959982, 0.11075880108100754, 0.11561081128855867, 0.13388466660774526, 0.0991706180596544, 0.12173174655125027, 0.13998476427889642, 0.11878789282373844, 0.13436866563654717, 0.10767122159802145, 0.12455275041922448, 0.11998400122167603, 0.2592884334585359, 0.13748049946321597, 0.11525575251829241, 0.1466113175716131, 0.207857427097136, 0.16419193226723902, 0.36068369424150837, 0.14788501535452184, 0.1099726033487147, 0.21551318887260654, 0.12948536073728917, 0.1089534612612859, 0.16208695247769356], [0.03827181449460407, 0.05808824530592369, 0.013558585102850152, 0.04420328089186261, 0.03317846360826685, 0.024063214321710893, 0.11455384744030815, 0.06370237510230753, 0.0567468828071029, 0.07311703261709021, 0.07915555980176696, 0.09273213169146931, 0.11826200410723688, 0.025726452492357745, 0.018408351630393057, 0.008754556897216508, 0.013079214202720794, 0.037524465080951495, 0.02880685756193294, 0.04796388393808757, 0.023237607111373258, 0.04211774441383539, 0.02480470124752291, 0.032160547261516896, 0.014742183284984242, 0.03812376034235762, 0.04022130141815832, 0.05833131734341864, 0.04993174548050569, 0.017290954936235663, 0.04193235496659914, 0.030125697075779882, 0.04582214341949552, 0.004157305398445216, 0.01487354533897052, 0.018035511959404234, 0.0043840588055430885, 0.0136303617956958, 0.0620054405543112, 0.0069995840068816425, 0.014788072909258548, 0.029301991678714275, 0.03965798930655565, 0.010011383508812758, 0.06297767890857593, 0.0249076443123481, 0.015153203820509296, 0.05774482341122724, 0.05541744829726316, 0.006258508374523973, 0.01783143188203535, 0.04150194378810064, 0.0405258022158617, 0.03255895511697858, 0.07533009975187241, 0.06553689138062539, 0.041851946378066655, 0.11367841578659513, 0.03659452627142591, 0.051637463226553895, 0.06535690668369494, 0.015250167569085477, 0.0729006510828772, 0.024269496901862087, 0.08059204360770603, 0.06093949432514849, 0.030965861871898658, 0.01357279890667527, 0.08913185552603776, 0.2820972918022064, 0.33640511153686437, 0.22815272031772524, 0.26690310227774805, 0.15979788175994353, 0.669080232900958, 4.7496397168405595, 16.66727658241026, 22.127106035909346, 35.953766838196785, 36.7133181325851, 61.30925416946412, 69.47985326090168, 70.17876471242597, 77.64896577404392, 77.86479811514579, 74.73677066064651, 66.73334690832323, 60.556272845114435, 70.46812580477807, 70.22698633132443, 71.58783697312879, 80.19516452666252, 75.296492884236, 79.67909828309091, 104.05046293812414, 104.07212226621567, 114.83086201452441, 92.27902996924617, 74.77627677302208, 26.315197175548924, 8.34492491137597, 2.206789197460298, 0.27408300087817256, 0.04241784020597416, 0.21694787237192356, 0.06254089770898705, 0.02845606207096529, 0.059507254646309925, 0.02755053082270728, 0.07593452780237121, 0.05926826968789101, 0.06052389162622633, 0.04183965066688196, 0.06442310679103098, 0.01601297472183022, 0.034821496209910804, 0.020709417369817535, 0.05136223081799765, 0.06775081653388278, 0.06091337455737014, 0.015676054040781193, 0.0919010182241759, 0.04935202759600455, 0.06234804273492867, 0.06562701396403775, 0.030876371311023835, 0.014932085947704413, 0.08489702107204546, 0.04787666099746862, 0.07977669622989432, 0.07599132556107736, 0.03476130085126047, 0.0788128350470816, 0.014084377100751286, 0.007884906334502083, 0.055698250165028926, 0.05204018415702928, 0.024388294156280257, 0.04720053094769678, 0.02656763235497619, 0.011631679578473973, 0.041119160295854655, 0.03883153365384187, 0.06278333006306522, 0.053799309722718694, 0.0645567125250255, 0.10159594517561699, 0.066054483364907, 0.013171312335367887, 0.05712080266206496, 0.03332506219345716, 0.06368247596847434, 0.05471512187092055, 0.039286984416145476, 0.03739624877550429, 0.04762293650738655, 0.048892865137707804, 0.0454451707041552, 0.030051756184548143, 0.03876740443370035, 0.008036695165379394, 0.05555844677972698, 0.045500187308437405, 0.046277494590368964, 0.025254957933699893, 0.006401914767094798, 0.02598141229921772, 0.013783956678854603, 0.0744376686071196, 0.03745138795385438, 0.029130665690548, 0.03380976219270979, 0.05416401353995166, 0.02999251460536353, 0.04719305009911618, 0.05996953125201887, 0.023565069479387135, 0.024475360048874736, 0.10365124416327286, 0.010462266471867841, 0.020079110869236534, 0.021458411957287503, 0.020353270754698786, 0.04689111186551952, 0.011833511187785096, 0.057976051729412816, 0.0706392438000729, 0.04875554387728053, 0.014352020450807629, 0.07358992337099007, 0.028446171875862826, 0.035836405661557956, 0.1514185192964731, 0.018213928091309724, 0.011519871918754953, 0.05662309065941842, 0.06443308125580512, 0.04761797608807684, 0.0634702772743279, 0.04666135826658818, 0.05126433627259347, 0.015673230049170313, 0.028327648497877583, 0.05726775747814006, 0.040381762364338485, 0.006746314860309565, 0.052657061136297645, 0.033771059430775144, 0.04440571579541411, 0.03241576179261169, 0.0931491899574476, 0.013131891366004223, 0.035872254745974656, 0.009466767773002146, 0.036307055608279286, 0.022963757491520336, 0.0364978612971402, 0.18017471737919316, 0.05637543358569665, 0.06290031551954246, 0.009609975461517612, 0.04264340330395968, 0.009359778806326852, 0.039836280949173436, 0.11880962673815028, 0.07788537836243069, 0.035141019991809325, 0.04002318342006014, 0.017084607238610907, 0.043401880144712426, 0.08743366076340599, 0.043548934552217686, 0.05725032131698343, 0.05534810201835729, 0.0371734474244858, 0.0896020956157196, 0.04018485478516068, 0.05603853876011507, 0.06878279825492252, 0.025603782663482334, 0.05238070640893233, 0.06153713100619855, 0.052045715311842586, 0.07758062858615192, 0.10664639513819449, 0.25039395347477933, 0.12232919554075888, 0.13919353334894105, 0.3879385591754991, 0.6571207423844646, 3.7620310341158225, 15.790557226827069, 33.19031584647394, 43.93614707454559, 63.73718561664705, 64.17247064651983, 89.18446033231675, 94.79434397912796, 98.84191620734431, 106.74720225795623, 104.42650841128443, 99.03433984325778, 91.99790585425593, 84.7870989768736, 95.12077931434878, 93.29772441617905, 95.0693884203511, 106.73774150110061, 102.11898588365125, 106.87026269974248, 132.0515497269169, 131.45393740746283, 143.1970900873984, 125.13263779301798, 108.07461861641177, 53.675611865135934, 22.152109184572776, 9.833694831017526, 1.25751702535537, 0.03288511705074099, 0.13992442719398007, 0.032166775556341294, 0.13994083679731817, 0.024179324522734653, 0.006096604310216443, 0.07806000044389118, 0.06018093704516369, 0.015797600593237628, 0.045323006493309816, 0.12254596011893404, 0.04418356178869163, 0.05675914404433101, 0.0801019235363891, 0.02533620730372927, 0.04870504719175158, 0.03069857187989739, 0.06278226137041085, 0.07193273729494504, 0.0539393199517602, 0.02773782208321556, 0.022076503185915853, 0.024694051338179458, 0.06825130943569445, 0.0778731209556422, 0.026830168771407297, 0.04514967143956212, 0.06192417777774315, 0.03094431947946789, 0.026611104014239488, 0.02176017207544177, 0.05090769553076356, 0.0509053398103964, 0.041063998134866844, 0.09668336039589298, 0.037528981169265126, 0.017100572510952913, 0.030672892612675508, 0.0698976706893694, 0.04242005420007533, 0.07370739529329924, 0.036389773951903466, 0.04795127413085392, 0.028263274129600297, 0.025412178327960354, 0.054184732387863824, 0.01823344801162039, 0.053146418950129906, 0.10517896138011448, 0.01341049743425702, 0.07131776787460813, 0.03059852079698636, 0.0076706540459136096, 0.06104180536743614, 0.024421065482461167, 0.047590534818629106, 0.08905338513995371, 0.010510427546837639, 0.012490715035387586, 0.007946306845218304, 0.04086184668384733, 0.03596641461274797, 0.025501799123782306, 0.0759391626343131, 0.04263041045276388, 0.09383933558579415, 0.08487932444099458, 0.006797213741998759, 0.05309381552280919, 0.03502802585341758, 0.018219365400352308, 0.03740991961451308, 0.0519839724555852, 0.11055247062036108, 0.11950953232665217, 0.18625635233136917, 0.15661670165436883, 0.10932917376199078, 0.0824778916073903, 0.21822693277030222, 0.28748782351613045, 0.14785069461551406, 0.23470620414422405, 0.22913758763142172, 0.14176362043907567, 0.17775807770029192, 0.19635794173565604, 0.07397732637341946, 0.13121298093709255, 0.24412905496935694, 0.1407478491385137, 0.08025569270455069, 0.17532060042985026, 0.17203743869979538, 0.09689381240957207, 0.19668789580464366, 0.1173948845075023, 0.20467640020914618, 0.08907769310979113, 0.160620384398968, 0.09605719077010309, 0.12417454047188645, 0.0817808818312422, 0.13824392140151995, 0.13056634144196588, 0.08483009563098032, 0.08402902047119795, 0.22624582022188172, 0.215951360521778, 0.12626028379365323, 0.07900824875480707, 0.18689807354202195, 0.10283489321028033, 0.14705164958873104, 0.33367216947578615, 0.1040898448216819, 0.1921647288385899, 0.26444714696657273, 0.1723758657012255, 0.12097106720771521, 0.1620001547158726, 0.37840195961536904, 0.1406211228740792, 0.09636473676730549, 0.13575258815000135, 0.11926836018720943, 0.15079460196918057, 0.17165808728145016, 0.17267779627394292, 0.13015502883541968, 0.18101385944793302, 0.1833912754251111, 0.24675672122788048, 0.12967440059348462, 0.11561320914376168, 0.3326815258591406, 0.09709806677194373, 0.22968855806656424, 0.17438790370379725, 0.18176726095618742, 0.17906405842832981, 0.1830348147139434, 0.5069982753165307, 0.4330654892950289, 0.2628216003218005, 0.3078268450354376, 0.4511507107846199, 2.1431134400829195, 11.860692385704288, 28.429064443034513, 42.737580576250636, 61.172128108239946, 63.93648124510243, 94.27503001305365, 100.15741640521635, 105.81909102778282, 118.14135812943982, 117.63008502221878, 108.70512393213089, 101.61001128535118, 94.64863577196675, 107.50340384821739, 106.40973721781086, 107.48184650175034, 119.65566758186587, 112.13708800654258, 118.80982414368661, 146.21835062580726, 147.46160076510523, 157.90340515875047, 137.635890899166, 112.6380374354701, 49.780662982694565, 19.036064570949925, 7.310155120588119, 0.7572405893475779, 0.1433123131432841, 0.4004249649663126, 0.15930488885891053, 0.20281485251842007, 0.2504026868771161, 0.11211152849418503, 0.1728790475716514, 0.12485305688554242, 0.11280342080299893, 0.15069050594202935, 0.18000798600335277, 0.16391885256575, 0.20489741657530108, 0.19803807980591254, 0.14678149634311277, 0.15265280951655683, 0.17359972180378053, 0.1432802753462907, 0.14566791093637868, 0.11500995320778702, 0.12917843527130543, 0.12933943630947223, 0.1445522724140075, 0.18926059676995202, 0.2083816763854796, 0.17375218862247083, 0.16884308188192307, 0.19264164921497146, 0.14399655223373445, 0.10552912484854461, 0.14040847218805744, 0.2200133425574149, 0.2874999277053341, 0.15640803462555333, 0.18278234277761754, 0.11921592912967167, 0.09042800734600714, 0.15068465303028786, 0.1430093100474727, 0.07140455031467062, 0.21114858678512036, 0.22986166329393465, 0.16591677922875653, 0.18785373758404486, 0.2573461554223492, 0.1588950318194205, 0.14190671034157276, 0.13771443207177425, 0.1651004819019187, 0.19509398859114419, 0.16877660077185402, 0.09472118705631265, 0.06594961358895225, 0.14500889146039564, 0.08470512370789245, 0.18227180646311852, 0.15667801933182826, 0.1137657498099631, 0.13124777665061335, 0.19628392232041206, 0.1883149378362202, 0.11932518092855332, 0.0935991440388945, 0.12260750762277073, 0.2069070337400321, 0.18892621471276208, 0.2412085592626564, 0.12983420653448952, 0.11312227425796371, 0.11926960891052601, 0.13151952335911413, 0.1055276386379715, 0.220731366125326], [0.008385093758753952, 0.042492100938914285, 0.024088217516339595, 0.018261615149376374, 0.039183876642416564, 0.062201723771830725, 0.012503875468316819, 0.054665824112993096, 0.05196813741819032, 0.02968257649861757, 0.028614406699254632, 0.11089285114599813, 0.04513510810812155, 0.033409611487220374, 0.08590204415902977, 0.036479551795749895, 0.08172352482835132, 0.025467007240701108, 0.025431794009261557, 0.03254526895621131, 0.0475050202540813, 0.04507995360801297, 0.008130099477937386, 0.01821349716685232, 0.012488255893150646, 0.04632860031579772, 0.06142604442673826, 0.016898156759599527, 0.06420613919955588, 0.03321547331588884, 0.059421805199235685, 0.04286179964941356, 0.03071411771910085, 0.09045743278317875, 0.04595425911247731, 0.02587516356499926, 0.026686653690112215, 0.036398101327640396, 0.09937864923549276, 0.030663295446204084, 0.05537360891579621, 0.05973310119682743, 0.08367316496949043, 0.041323564045371554, 0.051430596504360444, 0.06904854649497617, 0.017541285656813174, 0.02917475213537053, 0.04679911236669268, 0.022635188126455874, 0.02974299019232633, 0.08729841560125352, 0.03095272346399725, 0.02522806824755765, 0.02729560165936428, 0.033090110687959584, 0.007715882919353223, 0.06532781832521001, 0.014198292459871982, 0.058359949879588625, 0.014761630426942101, 0.05664710751584461, 0.05491340457792244, 0.0416780099452984, 0.15974152833223343, 0.14704097032306657, 0.10543642054882743, 0.05486933920051783, 1.8592735740446278, 7.8139556223346345, 21.586393579359978, 22.20420414401639, 30.708359633722615, 40.85554107542961, 62.036489056002715, 96.2010157492853, 104.24340432690036, 107.57056267030778, 104.83870244795277, 104.53990413296609, 102.5041312556113, 114.20105488069596, 100.7991946128107, 105.51407183370283, 105.21530489767753, 108.99147264419064, 109.08643322606241, 107.45665704050373, 107.01422152980682, 105.4572759136077, 109.61177195272138, 103.84533082285236, 107.41448371641098, 112.4165019681377, 101.07900865616338, 104.84620986446258, 109.27737420605077, 110.96366390105217, 107.11228862885507, 103.78387512699251, 94.94931682463616, 73.77174208241125, 57.48962656144173, 28.93668386244005, 5.550740188167942, 1.9157076554913677, 1.918990924473732, 0.14852624626890307, 0.35579979179366944, 0.18363887504223855, 0.05985300161785657, 0.11941758645398003, 0.10162597582224878, 0.024622843465617588, 0.04057353715442362, 0.10265323844167495, 0.046424744350294915, 0.019340207574949152, 0.047666940597757224, 0.03156750519279271, 0.025209134384509058, 0.00632457388189411, 0.06851571702188061, 0.01117349483989059, 0.009906279118431192, 0.015835233704908, 0.03283802562603547, 0.09979834284393058, 0.052029332521581845, 0.042785581561826894, 0.008519939597575896, 0.05647486413738901, 0.023478986094555548, 0.032202398644820336, 0.01898989854981342, 0.0680046214631969, 0.11097757280954432, 0.023526200093328956, 0.04739300287779301, 0.048682210110728784, 0.12004115138082735, 0.08698938339347802, 0.06381568333674824, 0.012191358518095748, 0.05300500678018697, 0.05646698875352741, 0.01629996274958455, 0.11949577338753209, 0.03352361686167217, 0.015886670763364003, 0.024046176526274894, 0.04244869439712456, 0.018129202597323927, 0.015964602972681246, 0.04322036327193341, 0.03736559759765383, 0.060408200858341116, 0.05091377443844273, 0.07365852654460939, 0.102090485574257, 0.10396836625952875, 0.028879168601105773, 0.030857776441881736, 0.03719811928608725, 0.006143420422074175, 0.04213372117749626, 0.03041672621733479, 0.07315830943445045, 0.02133945957006466, 0.036519962933755694, 0.0514018452245622, 0.042363670128848285, 0.058259580870189016, 0.04654435748835245, 0.04091525450348854, 0.03552548887748872, 0.06102666363961274, 0.04301133618179349, 0.06613421013518687, 0.03322686887376251, 0.04379364984831022, 0.022522079074875485, 0.03309317887009632, 0.033884773691815716, 0.04678393233447306, 0.02114951189967894, 0.07481001798183688, 0.02196779147902083, 0.04121000300191584, 0.008770692624121664, 0.06061641589528131, 0.04748442781067664, 0.05214161802864364, 0.04749084379704249, 0.04152820528214497, 0.014297553514611098, 0.0939774382559042, 0.0524505544754286, 0.01989697346523885, 0.030526100590284315, 0.044364718600146236, 0.06065371671631452, 0.03288530474228244, 0.02903656711080863, 0.028149125113662694, 0.03804980604458721, 0.03901186692077787, 0.013731360912413127, 0.008951911680220116, 0.019883143662985776, 0.043477316822616324, 0.02909150327585878, 0.0717447393183266, 0.040838377580287, 0.014650330300472919, 0.007524201496233864, 0.007725697463273161, 0.056325442518197724, 0.02699894943244515, 0.036898421859669114, 0.005083113078839116, 0.07736508208777636, 0.0507435305494695, 0.025184535301260413, 0.038828430997748534, 0.03102511111196251, 0.01793771125977078, 0.13504725099811632, 0.011787178190124613, 0.0463685441401697, 0.03743666374394971, 0.034835864188930685, 0.05307107420277692, 0.030674771443309806, 0.07093631737535039, 0.11768751477281894, 0.029489836437747847, 0.08167096353586643, 0.11841049492960015, 0.05272199474875966, 0.13954703696072102, 0.06496703687814936, 0.1105362065737286, 0.7688016528564116, 6.154182130290616, 20.52955604368641, 41.5176450052569, 43.33783265083067, 57.2031327216856, 68.45532232715239, 90.86723558364376, 120.71271496434366, 124.0426189668717, 129.3080008414484, 118.6922001069592, 116.03460604144682, 114.9421710352744, 129.84105094786614, 111.22070466318439, 114.01246732281102, 114.25778804286834, 120.1226257508801, 122.45148597225067, 122.66864407447078, 118.62269570750576, 120.11679710880404, 121.73304111726823, 114.67364557327764, 117.01715192487164, 120.59367102961387, 112.49173302804272, 114.44283762285787, 116.99092695789953, 120.7998308058708, 118.77393445660992, 125.60950386908748, 120.6548050911196, 102.6235282036566, 86.6738453219014, 50.85780858993531, 15.553621553605604, 6.579350386896442, 6.0401264698274675, 0.418153005622087, 0.031616421821977825, 0.04152428291197266, 0.09928833513009934, 0.1365030478806265, 0.06700431747782616, 0.12754440037233214, 0.015291076664242054, 0.025951232265440688, 0.05001907184299442, 0.03538356342863652, 0.0329049127627044, 0.03083945544917257, 0.05087499506771565, 0.05008834534354749, 0.07095357733628443, 0.022090976502025322, 0.013339877534177036, 0.01468630578939713, 0.031818602001294494, 0.014364264451057441, 0.027200748483019493, 0.061519499492621234, 0.05163031179578074, 0.04972377176126165, 0.07145520404822404, 0.016214346678386775, 0.055343313968830535, 0.09600569433983296, 0.1115458798144133, 0.061050079117018374, 0.0701696165807305, 0.05839367690045507, 0.009950511119959336, 0.09499427441868091, 0.07435303121324509, 0.002182203606935218, 0.04453128909752254, 0.022023825065022515, 0.05772808439008171, 0.03572340003184734, 0.025171326030226007, 0.07878561594313191, 0.017334604710941354, 0.04903023619385016, 0.045979815805631305, 0.030933841311883543, 0.051515980833961125, 0.02629421940524011, 0.0604422381448169, 0.023251676316102667, 0.03479939457329531, 0.01612133402828007, 0.026461477466528455, 0.04082625040844564, 0.0484064337797463, 0.04583527799695731, 0.01750965580163944, 0.07267814084526993, 0.054253235970052986, 0.043984696854867285, 0.0788076639535927, 0.021708510936267918, 0.036313329868379145, 0.02466906346530924, 0.00881707445988732, 0.026570566471726186, 0.038311685540623246, 0.024844993641900442, 0.1392222310025846, 0.12128173884364868, 0.09732475984961757, 0.10860742700676765, 0.10738196211957163, 0.11131814485716243, 0.07088290572526955, 0.18856311968017012, 0.10973529995328958, 0.10381774571273597, 0.10266454589943733, 0.19150149587902332, 0.11165876287005602, 0.08942712113381394, 0.14866797253489494, 0.11251074457240683, 0.14796235959135717, 0.1663652470996303, 0.14545476995408535, 0.08730168679669019, 0.15642237579149587, 0.17427821523479878, 0.15091162956049367, 0.14647552082615514, 0.1466131408608729, 0.13726699075871898, 0.15492879545256016, 0.17719431359681392, 0.15512126738265639, 0.12470840416367977, 0.1399791411935322, 0.16679581915659292, 0.11031928877796858, 0.12888946690626685, 0.10923019520217374, 0.15498873417175588, 0.10273965315953379, 0.1465950152205844, 0.2000797807329124, 0.08074359878176644, 0.15371589440732233, 0.1447614144173361, 0.19758072531511708, 0.13749519302960367, 0.21256969520641913, 0.2864685588546338, 0.23266931424938866, 0.09411027790197442, 0.12705103208821628, 0.13609256264903855, 0.1265416066012075, 0.19958093492013795, 0.11170723325302524, 0.17694368027150634, 0.08944929171834262, 0.1906724202056085, 0.1831998453745919, 0.24448995899048545, 0.11527997621845816, 0.18750774163392284, 0.27568541166763155, 0.21745880705214318, 0.2881663322689072, 0.12438807215902115, 0.2681590268208135, 0.29873852948507956, 0.17495192827716952, 0.5699105801120882, 4.910788334185078, 18.60485488368619, 35.3140204183517, 36.8787480169727, 55.46641703574888, 66.87970622893303, 94.5145534699963, 134.9604578941099, 140.84977119199692, 144.41580187889838, 137.24357543453095, 134.8469131223617, 133.55238976017122, 148.87988275097263, 129.63623262220815, 132.44017816359, 131.17091486530921, 138.30747912006996, 136.3768728317753, 140.76812313449, 136.4341708152525, 138.56216646009878, 138.80946405472295, 132.02876860095608, 134.69389361719934, 138.59475351149038, 125.00356828012775, 128.84777345964986, 130.5399545546501, 132.28300094604492, 138.55871477434712, 142.38423378236834, 134.6515633982997, 113.06085325056507, 90.01254327835576, 48.0716117735832, 13.694350431042334, 5.595659171381305, 3.8750690846673908, 0.27595507461697827, 0.41134548703989676, 0.32147804154984416, 0.15541185985409445, 0.20938482255704943, 0.1796651156919618, 0.25145546022442083, 0.09645867446858077, 0.2033327279552337, 0.12225259440921007, 0.1865379356088177, 0.13734370680345645, 0.08441248578169654, 0.14105255294951702, 0.18709135752531791, 0.16093589004970368, 0.11325476150358878, 0.08027097615864008, 0.1985859858893579, 0.11585367648231408, 0.1392297999512765, 0.13682829816975903, 0.13397581574897613, 0.18691797650629477, 0.1555720488390615, 0.17920327192593008, 0.09783478288520729, 0.12804421145589123, 0.2683408654505207, 0.2494019462216285, 0.1510125539836384, 0.19753243113237043, 0.2291080166375445, 0.1458132224938562, 0.17943841495340873, 0.11959354918930801, 0.1589993423511905, 0.15747545557397027, 0.1019662797390934, 0.14344841632391178, 0.30203819274902344, 0.12454115184805087, 0.1545332182919787, 0.08994776980891343, 0.08164636445261779, 0.2506405418558467, 0.11238405661236857, 0.10283424969642393, 0.16749213179272993, 0.13578519285205873, 0.11803698110123796, 0.17477644817723384, 0.21192837236148698, 0.17011455800985137, 0.1534171660821284, 0.12183391203683232, 0.10390546278006609, 0.18183210263809851, 0.1867555505445888, 0.13386893116178053, 0.2506457359319733, 0.2665580256331352, 0.15074270717318983, 0.10294600660281797, 0.14052870202689402, 0.11463778769417156, 0.14487759931193245, 0.0854340180634491, 0.20494027153378536], [0.026646380447932792, 0.03725724595208322, 0.018867630917098255, 0.054393269181732214, 0.035179722753743974, 0.03611086432131068, 0.024774699329188275, 0.053736750982821956, 0.10103993388193269, 0.00911356580834235, 0.07910228604751249, 0.06926181771221661, 0.09198817604732129, 0.06714752229351191, 0.08733071386814119, 0.07118732608374088, 0.03111138984921479, 0.02142980431897506, 0.029323549392903527, 0.023728340053029602, 0.10401700518184132, 0.0638074632133207, 0.02022564625217309, 0.0362726774126772, 0.054786161204139074, 0.04658209880994213, 0.05755595209437513, 0.05488026361431807, 0.032620410690264355, 0.04729622682075828, 0.02156444427166735, 0.06038201980352883, 0.015592385748130901, 0.05218487135284851, 0.08979409257130277, 0.05219213003593107, 0.030061194387775277, 0.034927921144351844, 0.03229989482450389, 0.0373995965797334, 0.04395368944613203, 0.034839686967672846, 0.03796189745527603, 0.07416113384909208, 0.045823633460508245, 0.06210197912408941, 0.11343738154297876, 0.03573000754019426, 0.09417211651922235, 0.06948746891031343, 0.01928688977063904, 0.00578586803561437, 0.049871925504938255, 0.007359235474253975, 0.0923238221495863, 0.07866763074191348, 0.021037812449879224, 0.09066019327409806, 0.04807058466418136, 0.05665171936514878, 0.05037476263579823, 0.16605761683275624, 0.21508434817435282, 0.12779519457610386, 1.1621032871546284, 6.183820049608908, 22.558339257394117, 37.48469537304294, 64.57085794018161, 90.97843477802893, 100.12644537033574, 98.99477881769981, 98.22458221066384, 105.07537826415032, 100.53140655640634, 94.82345581054689, 96.37221936256655, 71.9549943554786, 96.35605135271626, 91.58415855899935, 91.93857608302947, 101.77780243658252, 95.59212269321566, 111.95666682335639, 98.2760044836229, 111.71039688971736, 100.21804055859967, 96.74933956515406, 91.27279296998056, 93.40645251735565, 96.33201506830032, 106.33023077441801, 104.37353287973713, 98.51809317065825, 102.32017209452968, 76.84910820376489, 107.35065890896706, 98.72236236449211, 103.94510807529574, 88.643079111653, 95.74671114644697, 104.13178936127694, 103.99949566010507, 105.2724773653092, 82.07254425171884, 71.84563083033409, 70.130645075152, 40.84660199380691, 19.645785247125936, 5.327481819737343, 0.8565654821934239, 0.06553498382169394, 0.2762601921154607, 0.14897154253577033, 0.034287628687677846, 0.11598817087830075, 0.04595805890858174, 0.08745646720091182, 0.0957018791908218, 0.04301410942007938, 0.04350635155494656, 0.025499343811984987, 0.03229892189284006, 0.048085764696400975, 0.026777578750625256, 0.08629410497603879, 0.05594623282611851, 0.03508210016955291, 0.029160922333117456, 0.012501674880754324, 0.044821594285989, 0.11206768528227845, 0.010794787893011686, 0.11096143899785896, 0.029021614989746484, 0.052686176307859926, 0.05808130071889009, 0.05926674900336131, 0.004201216600655068, 0.08754869652611595, 0.027126623730685924, 0.028047834883534142, 0.041867455828093716, 0.012620904974849715, 0.07248266585051052, 0.015491520696800324, 0.048736261444226395, 0.030862056958158652, 0.04017756162812153, 0.02606059897751097, 0.04529831547951026, 0.07035704765228495, 0.02245206246903587, 0.007319858554945959, 0.055877595178542606, 0.014724473247394688, 0.049581398150973746, 0.023128596630187768, 0.02128731771071832, 0.036891902451433485, 0.06639876327807866, 0.056979800349161516, 0.021197357920989878, 0.01791121419368973, 0.041465355428837, 0.0686978007997236, 0.07684167549614945, 0.004247644401696181, 0.10065508195229116, 0.08631727913574827, 0.043285323697472775, 0.06069931810000732, 0.014636025523706792, 0.0344896805472672, 0.04114909901193554, 0.008434228722997492, 0.09241097997273169, 0.01717448467388749, 0.024317023081464634, 0.02759332257893778, 0.01636838589254166, 0.040290027165845524, 0.03297385684545002, 0.040146910450271064, 0.046264869461376826, 0.0342197532975866, 0.028351307208199176, 0.06080588476071435, 0.07119463456253852, 0.0650041461772015, 0.07127012486659712, 0.04874895552113172, 0.05295598864435189, 0.018154345602998813, 0.03064571564356166, 0.08253694166459384, 0.04064677515998483, 0.04827432574764375, 0.051502513008252274, 0.11551824488466787, 0.06905137335941677, 0.04279708820244959, 0.03781056444671366, 0.02146515544624098, 0.03755691273498439, 0.04471276766590534, 0.04603117050963544, 0.039221112345976215, 0.021153675587547403, 0.03717063205136407, 0.06287855096161366, 0.13609778736868214, 0.017893435208186988, 0.02781068662091369, 0.02063532517622075, 0.020484342652883743, 0.03598346772994246, 0.03454326073669138, 0.005394067688499608, 0.029578635604271007, 0.08433687290357006, 0.013613863134636514, 0.026550054467553576, 0.048093992480707747, 0.06290620290524056, 0.048387519068895816, 0.04400503265881731, 0.018602007166332295, 0.05567980276781225, 0.012221361394040288, 0.07631041650329867, 0.015192351871049933, 0.014225715534731507, 0.016764704243189866, 0.0674566617535968, 0.10085473978711713, 0.054275601907002355, 0.18153980945146855, 0.13428318554595595, 0.38646347219905547, 4.318301571953682, 17.399792940385883, 41.2363600730896, 59.65839524422923, 89.57533236472838, 109.85724956758561, 114.02855688525786, 116.52111330339986, 112.7670834141393, 121.5745302938646, 111.32849924025997, 104.3933016254056, 114.39059949690296, 92.61368659234817, 125.73239957132648, 108.4543981859761, 116.42822373297908, 119.89173150831654, 114.48181029289, 132.80290326764506, 117.63949086589199, 129.1124079304357, 121.98881887620496, 118.80401119109123, 109.06496217173915, 113.48981934209024, 117.26475546436926, 127.62342914458245, 127.40474131799515, 120.60029983520509, 130.05256868177847, 106.4686433730587, 139.0232018501528, 126.96085453033449, 122.3184548654864, 112.45205433137956, 112.48323717424947, 117.61638810557704, 119.8107502537389, 120.42502480168497, 106.82670870134908, 98.47320556640626, 96.54930653110628, 69.08799279120662, 39.7128212836481, 15.433261663683, 4.333580674663667, 0.6349279106624666, 0.19613660361257293, 0.16840135558478295, 0.05111452777900043, 0.25233701292064886, 0.055024958471016544, 0.08813617105085043, 0.0482843040428575, 0.041172671537365646, 0.04800788419801862, 0.033781413109071796, 0.05098572924673077, 0.017737850411644867, 0.0466227206221271, 0.04781948402523995, 0.05977510579771573, 0.04584775373880421, 0.03452816497414343, 0.03023824879839536, 0.01977160700686997, 0.03294805883459988, 0.030883775550812006, 0.09527601091371429, 0.052835444709466356, 0.03366515543612261, 0.02957039058298594, 0.0077555394607536025, 0.04259818496422903, 0.10538897672367674, 0.061112856191973534, 0.026603967905224814, 0.08305228901125732, 0.09552652932583325, 0.06954944542338772, 0.04504522684240534, 0.024815457121979807, 0.018387477649676225, 0.063412950914954, 0.023954100418655623, 0.0501220838557328, 0.07803924712202243, 0.04299091227773217, 0.013449498012872233, 0.06767573991730329, 0.03645533192602377, 0.05347226295740374, 0.03749107130833211, 0.014117903981147515, 0.04153030819349712, 0.04516453354529316, 0.01534397312019381, 0.03057246040102215, 0.041342202964569294, 0.05679260293442396, 0.08062890009774316, 0.034414286004199136, 0.07451254604083878, 0.05288800983239086, 0.09134371990277883, 0.08028804459759305, 0.00410044108585064, 0.10979025144009821, 0.017972941728188627, 0.05194845661941556, 0.019599595370011467, 0.14401637858921482, 0.1521867216234246, 0.1813331802165316, 0.21539352593883393, 0.06275527592327806, 0.11036468714836145, 0.1646945931978764, 0.16240630388980912, 0.13187249070934712, 0.12670582520865625, 0.15475631841728765, 0.12422492607466637, 0.1776805955676302, 0.2147927444668547, 0.14344512214583738, 0.21773985406804472, 0.154948131511769, 0.1174549151572489, 0.17170825071873205, 0.281180958714216, 0.1976328805810021, 0.22617170887608684, 0.14384728766256763, 0.1614007215586401, 0.23013668885875135, 0.13917678666691627, 0.11376386523366937, 0.10518558037978028, 0.13713824202216443, 0.16169131403007816, 0.21076485334384829, 0.11548541801711244, 0.0808804527285599, 0.16475938891451206, 0.1780722963233148, 0.14381350318510688, 0.14506391189511747, 0.14961559265371294, 0.09146264739214413, 0.15763032790874282, 0.1994618388914293, 0.156811885535717, 0.11713642942448778, 0.18719461085575242, 0.24964974502161627, 0.15916405125491082, 0.3296475418873372, 0.11125581594364298, 0.24468989261696417, 0.1777885526779198, 0.08758270316907475, 0.12821155570207105, 0.122566498936184, 0.07145402427282065, 0.19899170605405686, 0.14169865618309668, 0.18815698582799206, 0.22251368500292304, 0.13750230232554098, 0.2935383552985807, 0.2076931165591363, 0.3036971101837774, 0.33199535622712106, 0.2769697427509293, 2.8000454796898753, 15.38881140370523, 38.50075398722003, 61.45236184520107, 97.19262230780818, 124.22501702462475, 131.65063642686414, 132.44432018649195, 128.57818111296623, 138.11340024394374, 127.21772270817911, 116.52028960566368, 119.71051800635554, 92.68121411723476, 121.69514317666332, 114.17837573635964, 113.7107821433775, 122.58477595544632, 121.66243845416655, 136.09077515140658, 124.23323831250592, 136.04455394129602, 125.11535583003875, 118.19758922823014, 114.97989639159172, 117.84075552417387, 122.99544811248781, 130.39056716426728, 129.18517574187248, 124.41802901606407, 129.04005589023714, 108.40441934524044, 137.9604905651462, 130.35049623058688, 125.97113070949432, 115.98623537248181, 122.57381685318487, 132.05657036073748, 135.39764527351628, 140.08343419721052, 119.60522590144988, 106.97123235271825, 102.87426179455173, 68.58690215695289, 37.01058672320458, 12.180521468962393, 3.1131665745089134, 0.30143304457587583, 0.5031029940132172, 0.25004098612454634, 0.19460880978693887, 0.3459435803515296, 0.1832943040156557, 0.15953090011833176, 0.21173225385287117, 0.16104075216477917, 0.19725988769242842, 0.11886307669262733, 0.15560822351084602, 0.18266839485976005, 0.11978725452096232, 0.12412956344985193, 0.13246605563307964, 0.16550727458971162, 0.1999266704003657, 0.15774570075013947, 0.10861612210470824, 0.2160798641101968, 0.05984333358825215, 0.3336504125787366, 0.09749080940720536, 0.09886814356451074, 0.14683326856503565, 0.22842963045883566, 0.15286510780213342, 0.21398689657930406, 0.2219583785101291, 0.1396169348229324, 0.10555929339100277, 0.11749513477327363, 0.1971434423279378, 0.15929286127849934, 0.18364442151881036, 0.1604164977588, 0.1897103363467801, 0.11422930961294521, 0.10517704616030378, 0.22796498281100105, 0.14443086279976752, 0.14637537781269322, 0.2290011320503489, 0.08468406395085397, 0.18314798122211812, 0.10821640806933565, 0.14230300762480305, 0.1513843364532917, 0.15650790184736252, 0.1424359545231827, 0.11858020638746601, 0.15580613466520465, 0.1765614790060828, 0.1893123689918749, 0.16391011916341322, 0.15502794255172053, 0.19368090877129188, 0.23898667445586574, 0.23785329333716826, 0.09540302829156, 0.20698655366657243, 0.07615948952133618, 0.17064288288595217, 0.1273349212903169], [0.041405520131511074, 0.025963342200303753, 0.10751295549374436, 0.07983356293651366, 0.042228068735811024, 0.016079526695032275, 0.08443035095209077, 0.04489187902260212, 0.03934504621992669, 0.08106291955036503, 0.0049892275673036855, 0.035735362494784984, 0.06070001524001841, 0.0808950390426382, 0.09728676954945249, 0.0492497893320697, 0.016799442500116366, 0.07732417299261979, 0.027981855561055487, 0.03874981505495887, 0.08777842331196993, 0.030195045269905563, 0.015040794781769716, 0.019620927088263056, 0.03762645436631095, 0.04816667507252386, 0.08860556844381556, 0.05381922800874999, 0.04584246390168706, 0.02636416897838635, 0.01500272595759241, 0.03177554977516974, 0.10116060805176535, 0.015816840891455932, 0.06900893974929087, 0.017669283627201954, 0.033072042504265424, 0.05410382967262019, 0.026990786765611945, 0.010239016959413646, 0.061405796722899524, 0.0470008731128708, 0.032902928594980514, 0.05454713411088433, 0.03705517494029576, 0.05459699494343612, 0.05601111281242582, 0.02063335633025535, 0.05799967022011838, 0.053864948136071046, 0.027351671634542368, 0.05361054948861561, 0.04770685377861223, 0.047387494705617435, 0.03714982510334061, 0.0994424260551891, 0.047935672750275944, 0.16637810205499973, 0.05023253458221594, 0.1537602355763797, 0.07371293410899178, 3.4089505480181788, 17.72240004231853, 28.791613040431855, 52.65206936867007, 82.82014016182193, 89.33287497489684, 94.51915048783826, 91.10754351462089, 86.66544360499229, 88.00221089393862, 76.02786587130639, 76.69763411245039, 84.08999181562855, 94.53289447292205, 91.9670524904805, 78.32693961358841, 88.23119101985809, 55.79304456710816, 86.8241976153466, 70.83728359591576, 112.3686961204775, 81.58492303663685, 67.99075680394327, 70.36389273981895, 79.13843877853887, 64.70372822976881, 81.01483006631175, 73.27131040634649, 74.80532584651824, 88.21878848537322, 65.3439139550732, 73.9427338877032, 82.16484546661377, 58.53869192061886, 45.175992596533995, 56.76782023522162, 69.3808840167138, 73.60395093117991, 65.88495392953196, 84.3412039356847, 89.29174500126993, 94.6695576944659, 85.48641835489582, 100.09270514211347, 89.43096560816612, 96.67794458327755, 99.94007787396832, 104.89740463995166, 87.67881931797152, 68.86023644478091, 47.60790524944183, 18.970739456915087, 3.7895972065387236, 0.15412901498136983, 0.3268754374115698, 0.029086330267150077, 0.06746252232621755, 0.08434049649945191, 0.029626730604157336, 0.027091226638144544, 0.04312234232202173, 0.020862546854562337, 0.009810232760144338, 0.007176301338815041, 0.053434441196582014, 0.062485057560186234, 0.03030072135340062, 0.06997710634623805, 0.055338698289086746, 0.03442515679184468, 0.1085467451822854, 0.01757550105873135, 0.04588827212911941, 0.004093512299380476, 0.055175973553090334, 0.032501253374521775, 0.06276886249261518, 0.02900414818507289, 0.02296887304363472, 0.015257016395128544, 0.04308666943782761, 0.02110618388190145, 0.012307196757906388, 0.023526803387569326, 0.028523770836933006, 0.04855963221240429, 0.027505283754679467, 0.06208062059276047, 0.010244726229669347, 0.0131191800521206, 0.02604882612133459, 0.01975040552356551, 0.07330958115597887, 0.07581499510354574, 0.05798783033124863, 0.04577849939044926, 0.04465863206273606, 0.0649774250304026, 0.03399247799309031, 0.024658665736956943, 0.061657816667350075, 0.03027960413976783, 0.08332698515826657, 0.13792345150103494, 0.07471648630716148, 0.061110577080398805, 0.0657072923176231, 0.07323265826750187, 0.023354701735379717, 0.0594255666909439, 0.024176853889178847, 0.02996134823338399, 0.018568787678715684, 0.053685323500465, 0.060983919763877514, 0.01738815234162875, 0.02233012999978758, 0.032075097814442656, 0.0767127888637685, 0.012105253108236338, 0.03572585917408428, 0.033318899016106324, 0.051584844477474696, 0.11380579322576524, 0.0248765392274025, 0.05128303264838554, 0.056209510432616364, 0.02648030982292708, 0.10836638510227205, 0.02792144761300616, 0.04078088268156975, 0.02898926692714374, 0.03581979304491993, 0.02462950843055883, 0.03845303642353223, 0.010616372718716101, 0.017767264357497616, 0.09051163350382159, 0.08833359956981675, 0.013105444095638252, 0.03129804717196572, 0.022171831336773695, 0.08091382351854155, 0.022850610135543733, 0.016441244684580355, 0.07373512001527895, 0.09116861518592605, 0.0462736526594287, 0.057955593351394906, 0.037077939242965756, 0.022126670453637358, 0.03568611070213299, 0.01579113959920623, 0.05788393348695771, 0.04101073587193124, 0.03845420470761676, 0.044408305172598174, 0.02770190213566586, 0.030789542905685884, 0.04161750815147835, 0.08910455981329565, 0.0031129551878679666, 0.032153349865468285, 0.020623425915536862, 0.06263970389902111, 0.007474646620046829, 0.06562977188056515, 0.02940943167965499, 0.06792526241512069, 0.05524893193655918, 0.09664078122906147, 0.039734827925360976, 0.14723339628788734, 0.07398966038900037, 0.19414739503014475, 0.08406384682823574, 10.822252727323963, 34.35998624370944, 49.91304689838041, 75.21589602193525, 104.95518115258987, 104.56784709807366, 107.26329988048924, 101.09626708492156, 101.37536725690289, 107.57120593901604, 95.72524009212371, 98.57156292084726, 107.80627358344294, 121.2940965160247, 119.75771196426885, 109.33036542707875, 106.53521383962324, 54.9635221112159, 107.00996968054004, 101.74934171861219, 141.4644693559216, 102.57291393895304, 98.96907160359045, 107.64833542608447, 112.30092540864023, 91.07422690237723, 113.4963147870956, 100.67684804239582, 102.24923995233353, 116.29648700837167, 90.59320311392509, 103.86367967051845, 113.54770568109329, 84.1214256901895, 66.61944127851918, 88.45393457720357, 94.81620727046844, 108.23906790825629, 96.4527456222042, 108.5426672043339, 110.01955724531605, 120.08559073171308, 106.60533012882357, 114.84513159721129, 100.7638854365195, 105.74026707679995, 111.44720585115495, 120.18286551198652, 110.73356197726343, 95.09106343792331, 69.8716901963757, 33.622251172219556, 10.033108130578073, 1.0141570613749566, 0.10087770710308706, 0.0600578228852922, 0.05679326177003884, 0.14857196639622414, 0.07126395785880667, 0.0201899963506167, 0.07240159842636316, 0.09726114390838532, 0.06391554672811782, 0.05374840318015026, 0.023853750561454126, 0.045834573196066965, 0.014503979736248092, 0.0316729016541954, 0.03380884288720066, 0.032138135359292073, 0.011778126861299238, 0.06766302285776024, 0.04649200303960712, 0.023852467364180955, 0.07253532673442557, 0.010606123419899133, 0.054215950470778256, 0.02798235734864589, 0.012512339782270213, 0.03911603955672153, 0.046364246386914484, 0.05836738476289376, 0.039862764608715816, 0.018843018427310933, 0.025688745644724658, 0.022903378271768172, 0.006415698125267462, 0.016577937752909718, 0.006502836796214745, 0.007463495252699021, 0.06920013231255355, 0.0844784459519771, 0.015974997828203826, 0.0849330195436074, 0.013394306165977352, 0.022371607915227933, 0.08183885936535175, 0.02747259861339004, 0.030093484993783698, 0.03874788068295006, 0.008288562849854991, 0.01804748974410036, 0.06283441663629587, 0.06618242004826184, 0.0876878027714068, 0.08936078558045049, 0.09142903911490595, 0.021233065279140588, 0.026221645980953213, 0.07472263799319345, 0.025615480826086095, 0.0536184938203904, 0.03281506597094479, 0.04138758601320367, 0.03760923654021275, 0.06761421539610432, 0.08540664574191456, 0.15639000091581576, 0.15415850936645462, 0.20365846854063774, 0.18469995278264248, 0.1831188392374785, 0.10811582072487763, 0.2605824785367135, 0.14947141490636334, 0.09008117636004764, 0.18045786347600723, 0.14565896302942308, 0.2804198656832018, 0.1808767756747623, 0.09566721371224812, 0.12973337404189572, 0.1358176749800482, 0.13659787424389394, 0.20687467418611052, 0.19229542343847214, 0.059479476298175515, 0.16688693765430682, 0.18298330296191478, 0.09632850080848702, 0.0944782069493686, 0.2883662812171444, 0.2097131218761206, 0.1804865304861338, 0.11854211649587078, 0.17720076405713636, 0.3259498806249711, 0.23100647444446243, 0.14385929992122037, 0.19888517386730642, 0.10711131091680258, 0.07667139713321963, 0.09774153466306387, 0.21087169196576844, 0.13005649460659874, 0.19381106710962712, 0.17430280665716819, 0.15769425028514478, 0.11445689901349046, 0.12499291389699906, 0.17718302146081003, 0.21464547172429102, 0.15407523560908534, 0.19591428489694673, 0.18927622496360735, 0.1769793646470193, 0.18679670478788116, 0.16541721329333323, 0.22036237221571708, 0.1727776941392691, 0.18319883413853186, 0.1887906477936814, 0.25138439790856454, 0.14461628672096039, 0.3488655622688032, 0.10401442346553649, 6.868988006345688, 29.968922253577944, 48.46996376591344, 78.99116946804908, 115.91162404706402, 118.9739674906577, 122.49211388249552, 114.39660856800695, 109.14490007585096, 110.08766528098815, 98.06080756648895, 97.90842348529448, 103.15210680807792, 117.08363609929239, 116.71053240376135, 100.45625394390476, 109.23495769500734, 73.106884648723, 109.79343260488203, 92.68695646716704, 133.23969841003418, 102.12551270761799, 88.6844208932692, 92.72751377474879, 104.54958454255136, 80.73683600271903, 101.8027408661381, 94.77277094318022, 96.08209733040103, 108.56265560273202, 86.2563874644618, 94.3897593405939, 104.74138844397761, 77.01748771052208, 63.74723080665835, 73.0475470327562, 89.89648034495693, 98.21840055527227, 90.08012571642476, 111.456494023723, 112.10269666487171, 117.3486549623551, 107.72162099038403, 123.04181052792458, 117.0233649592246, 123.99983375303208, 130.9260020717498, 138.49327395039222, 125.28154665423979, 101.64041749892696, 68.16785966196369, 30.668700548910326, 7.6502054929733285, 0.7449031416927615, 0.48919987714579033, 0.181553675642898, 0.20562441869368478, 0.3597810588056042, 0.18367846646616537, 0.17721754138267812, 0.13211731708818866, 0.27946492176382776, 0.1509268134231529, 0.16585449628051252, 0.16090291762544265, 0.24762330456606804, 0.17808875189192835, 0.27136329681642596, 0.17986789916551885, 0.11827044639616244, 0.1672815342223452, 0.1640043632998582, 0.15790693161468353, 0.13338171456369663, 0.12131837316818776, 0.12374943828270321, 0.17554512547869838, 0.15580362189681302, 0.10403102459085566, 0.10417525596435993, 0.24581712971050895, 0.08884187592493911, 0.10483039903544611, 0.10354353986199825, 0.13972116874590998, 0.11788315064604245, 0.19427841138695517, 0.11096778986675125, 0.11825785957156651, 0.10599100691897255, 0.1904484160965489, 0.13500790472232527, 0.1463998619827532, 0.1394412402183779, 0.14747186413695737, 0.11284894174745969, 0.11359216194720038, 0.10892929118727485, 0.14007625049881398, 0.1552832030480908, 0.11222480225466913, 0.10836263127144306, 0.15066626692010512, 0.2446032174292111, 0.2274591962416326, 0.16004482254145608, 0.20210453579502724, 0.15120805962191475, 0.1768417139687846, 0.16694532887589547, 0.17083094214960454, 0.17505643799179987, 0.11683538751376253, 0.11703758109961787, 0.13445717943531854], [0.0750548213780407, 0.0756171145927041, 0.013539044115121567, 0.032108020442988605, 0.02249849697334632, 0.017158391081818172, 0.02910761602012621, 0.03175022099317322, 0.013291378422910649, 0.05682752505245228, 0.03621103797828959, 0.07234935889080649, 0.03433158681277306, 0.08181093546051173, 0.022942904578221422, 0.0664384696151941, 0.044486208653618256, 0.017414796879635226, 0.07997210227674054, 0.05876579261835545, 0.06873126352025617, 0.0633780364578049, 0.04634047084818444, 0.02963745391987745, 0.13389796589411077, 0.03853511891417927, 0.027686295009428458, 0.04030163722833799, 0.08397525642067195, 0.021042292149016456, 0.013788712169644574, 0.06576955994410862, 0.02822315985066516, 0.024467626391279123, 0.029299394640650962, 0.01118815967798113, 0.02542511180734202, 0.011949599363781031, 0.029772748877745003, 0.03172448235413721, 0.06882425127250534, 0.01219296442990702, 0.02580829749574825, 0.010748514267165336, 0.06927454243263892, 0.03792526313073693, 0.03897176987882103, 0.03226137209323145, 0.022584542053781693, 0.0254111843288786, 0.05373646369985035, 0.049949097371990644, 0.1017234834932512, 0.05883974308568624, 0.0933745883465294, 0.07262856729568974, 0.08519866819223089, 0.37317089676376314, 0.3282360095650919, 8.736107791623763, 29.641945631273334, 68.38963047150644, 89.1836601688016, 94.39431713473414, 92.47925912180256, 76.28274148510349, 83.77098544951409, 73.20569699810397, 87.2987102693127, 79.190841644041, 81.12577038426554, 66.53923665323566, 61.40151223828716, 62.47877551663307, 54.33832376233993, 55.3063411866465, 28.351627049907563, 59.54982011548935, 122.06940789376537, 70.56092123831473, 37.3540255331224, 40.92655950976957, 40.9458379591665, 37.61789906409479, 25.824414530108054, 35.337876273739724, 37.62776382507817, 35.25674596909554, 33.70437775888751, 39.049854432382894, 32.63514553346942, 38.87079823401667, 30.434095744163763, 35.1177607044097, 43.08472210361112, 41.43500066572621, 29.740754058284146, 49.058389894423954, 22.26820545811807, 44.750344830174605, 47.48622548195624, 58.19379791136711, 64.14615938740393, 75.61441667618291, 67.61158127938548, 83.30782413482666, 85.99550277956071, 94.06262582348239, 84.35901149626702, 90.05222981975925, 93.57469081878664, 89.27274504015523, 88.2647821980138, 79.86530888465144, 32.35620813985025, 7.730748422684209, 0.9951039031147958, 0.1329645950106844, 0.09493958340176652, 0.09705653714556849, 0.10126655801169335, 0.032906950556582985, 0.05051020698081102, 0.05450819769213277, 0.08420350465683207, 0.04002758842562476, 0.026782993077030106, 0.06018813444121231, 0.020462367420775757, 0.026450895877074332, 0.09743647845161539, 0.09948122840855392, 0.03529324549280348, 0.038794650350727385, 0.03016379271303454, 0.04798681294966129, 0.032009051459270625, 0.018602631527990587, 0.0501805899905101, 0.054591498262579405, 0.03340465489835028, 0.029089034557522788, 0.01162030700323803, 0.01976783402384289, 0.02996019910149757, 0.03426437408873632, 0.023018052057933905, 0.037374461234937754, 0.06299259081002205, 0.03766565891583601, 0.044887784282646837, 0.11048773619075937, 0.07153267852000653, 0.019393320450739517, 0.02954921974319845, 0.03762039844126951, 0.03537264284527591, 0.04273295898230807, 0.06462801998901753, 0.06986284433233161, 0.05342598741633758, 0.05916976227214741, 0.05394203190301215, 0.010548851644289831, 0.042284399180883364, 0.04436767952997358, 0.014238289910398666, 0.019609416617200743, 0.0034470461316466815, 0.10474327951669694, 0.01937912292628279, 0.049673439784636425, 0.015115094776715965, 0.05928996529790664, 0.07817613171233286, 0.04599287760474029, 0.03948601022843392, 0.02515662097251944, 0.03099345252849162, 0.04266038747324098, 0.01186721618362372, 0.005832907749385003, 0.03248342267808414, 0.0333989130693578, 0.03425709242301603, 0.022802112939497157, 0.011509592934030921, 0.08963065537353677, 0.050213949289172895, 0.09851015833837372, 0.018825126443839362, 0.1260638588498677, 0.025070102832790826, 0.01980522677542702, 0.058887531650402856, 0.06566133470304551, 0.06701862033937248, 0.08132121375491543, 0.03450107993558049, 0.004618966739789974, 0.10838068030293911, 0.04329847359669305, 0.023070021547497283, 0.0455692884392075, 0.09172192218923762, 0.022667721965380257, 0.026460623278492884, 0.07297207346005787, 0.02954641394617577, 0.05690347500926545, 0.059030230848058585, 0.033194670198305, 0.05760452206877451, 0.0921503262173745, 0.059176963498635646, 0.029178398713890105, 0.07584854209374997, 0.03605193683817502, 0.03944054291012787, 0.05916835267036673, 0.07872086619177172, 0.02982638269332388, 0.08630653092217061, 0.010596432407656986, 0.007877073564281268, 0.034332628692350084, 0.0928698666393757, 0.008511438894446098, 0.05795717532295854, 0.013370242386665798, 0.10548022545633778, 0.06441929167316807, 0.11308668947388088, 0.11579569128732528, 1.9912577756950933, 20.81698929109881, 53.89272289891397, 89.29876604387837, 103.06310822886806, 108.5581684112549, 102.4015534308649, 85.41787101376443, 101.57089740999284, 97.21321475121283, 108.70708511721705, 104.77053165435792, 111.38586782640027, 99.72069971023068, 91.41257055344121, 98.71732604119086, 75.94453903936571, 84.93358381332891, 50.846908323226444, 89.40238721909063, 111.57191368841357, 74.54573554377403, 49.139845755792436, 55.725987726642245, 69.3570516955468, 52.89818240750221, 44.265904657302364, 48.917725855304354, 52.830556823361306, 43.30644192234163, 43.40365786706248, 46.189074131750296, 49.17368796563918, 55.00964526207217, 42.44542675633585, 51.051397169789965, 53.486859567703746, 56.2720718691426, 46.94214174824376, 68.33346997537922, 43.56700105051841, 70.97983821745842, 78.23630148364653, 95.12444280808973, 95.00738359266713, 106.73396818099484, 102.51672990860479, 111.14772504375829, 113.49774252983832, 114.36164456029093, 102.93069685659101, 98.64814327609156, 102.84461652078937, 98.21434482451409, 104.91322748122677, 100.1905918121338, 52.92712557700373, 19.840564266327892, 5.0482556416142375, 0.16846782137309352, 0.18366740415653876, 0.03884464141822631, 0.01556373022932319, 0.036877461694060795, 0.1752502582366428, 0.023825818995734858, 0.03276055498469261, 0.05639872648903439, 0.04200138331901643, 0.02779517334044701, 0.02664817309367561, 0.024534818047897953, 0.04218915146925757, 0.0836824499551327, 0.04967405648541547, 0.010750860411433444, 0.02873975017498578, 0.008977024999987936, 0.012495118125732388, 0.015615221871543798, 0.055141246787482695, 0.0343638084708683, 0.01863822971861209, 0.02848651598117525, 0.04437898698773596, 0.05373960082990028, 0.03822578027123406, 0.021076762275169456, 0.040659764180741007, 0.02855849185688121, 0.07924555981111142, 0.06714271892222666, 0.035446911239095276, 0.028584969770764152, 0.01681985491285882, 0.01710649245538779, 0.049023529094073086, 0.004158746122547816, 0.04845219604190319, 0.024007994704128757, 0.04068080478558137, 0.05609083958270569, 0.07432467063828822, 0.03428702347821767, 0.0476885212945842, 0.05868936002614999, 0.0440977024845779, 0.013996906139166846, 0.04574576062300513, 0.07785924710333347, 0.05549047179820557, 0.06668698087695145, 0.06336921495535681, 0.01588759389931276, 0.04087184030081957, 0.06437951638813942, 0.04284610633828467, 0.060014722778672175, 0.24750417789384244, 0.13461168404788743, 0.11962628412631252, 0.1325942987516042, 0.0855752463722902, 0.06473395462718702, 0.15966245273668922, 0.11279975124184163, 0.15787046582948777, 0.09798029362554513, 0.11486608955648639, 0.18301966149480114, 0.17370648381690826, 0.19724125643410992, 0.17397869017816361, 0.1847954073380078, 0.1361728793070201, 0.1367901010258544, 0.12580360346023114, 0.21369239705945217, 0.1599050268170334, 0.17495200488596194, 0.13666305300449172, 0.0716778215381407, 0.25111053679739276, 0.07949926514899538, 0.1142441257534008, 0.09982833518616616, 0.20462760040836953, 0.07748681345894452, 0.06922117674783354, 0.1647444348782301, 0.10592441855659408, 0.11442715181939064, 0.1183487022776277, 0.14134886043687023, 0.14039272142033424, 0.11702987425509961, 0.12223691258940006, 0.15050638437030778, 0.2394316949310803, 0.10154273270839646, 0.10615386188991609, 0.1908865571022034, 0.13279032532966908, 0.1375604330772354, 0.22458006928284324, 0.12043659064558246, 0.19469701715054052, 0.09351973136466357, 0.20586930635956027, 0.22523001827780278, 0.18234113742026592, 0.18529773118995851, 0.23404703145065617, 0.2957373034329184, 0.2349518119327484, 0.39424836575504274, 1.034983437388174, 17.45307637799171, 51.75090874395063, 99.03812885284425, 117.81919817770682, 125.27844013706331, 116.71506666368055, 96.94923923861597, 105.03662524684783, 94.60098681911346, 108.42232888744725, 103.12367746906897, 102.81078215568297, 89.33299264600201, 82.56763365960892, 84.91785510893791, 73.01314000160464, 69.97590757185414, 39.30025462181338, 72.75609923947242, 134.77714200173656, 85.5106350683397, 51.98907113844349, 53.68091490960891, 60.27365430708855, 52.70611178490424, 36.55383063900855, 49.91734581608927, 49.2148728524485, 49.169883266572036, 45.80320704367853, 54.69967211446455, 47.49606670871858, 55.75529175419962, 43.16509931318222, 47.569756277145885, 61.00802398497059, 60.82986600937382, 45.04960206247146, 69.85469848878923, 36.31019261575515, 59.56641566368842, 66.48784575923797, 78.38648119280415, 87.90534404016311, 101.98141267222744, 94.42524110117267, 110.98741777481573, 110.22681528522124, 114.92721896017753, 104.09633113491921, 109.27902944626348, 114.679458525873, 114.3300694804038, 117.08521289210167, 109.64271160864062, 53.985337903422696, 16.678504367028516, 2.5723116868926637, 0.15466529185012465, 0.3404330792686632, 0.22894566728463098, 0.251930158945822, 0.12445050066397076, 0.2690183016802034, 0.12915689287887466, 0.19379507119376815, 0.18513437060098495, 0.14354796178879278, 0.15102815153377672, 0.1522536470644897, 0.07177351358076257, 0.16726723902167814, 0.17095622816874137, 0.11855055878479635, 0.17047380728106346, 0.13975915138519582, 0.09573418511858872, 0.195209177571439, 0.14866320746800593, 0.13690092330498083, 0.1709591852681291, 0.11067585674144569, 0.2048204247389109, 0.15029305952691263, 0.20117714039741025, 0.14989069482732206, 0.15274156846346396, 0.10073620300259321, 0.15915419936420458, 0.11490979487256658, 0.11384824981852887, 0.15428318251525203, 0.3300933437722345, 0.15441105791157292, 0.1479756435559642, 0.14747954033795865, 0.1214274640886053, 0.10681234510435213, 0.1614674631386034, 0.1149584950819131, 0.1563219263428642, 0.18435119891599303, 0.17113356220145381, 0.10841079521924259, 0.1978938560932875, 0.1589213239569818, 0.11241198817808783, 0.11260962354079371, 0.25199143065800594, 0.0965146295305702, 0.16859963446134524, 0.1014838205470193, 0.29474203264521015, 0.24344910597128255, 0.14970799817913963, 0.1598946846300556, 0.17154565621768275], [0.0549212723009048, 0.06760930477250969, 0.038540240211953083, 0.04075367889937855, 0.055685092604929404, 0.030235826045334823, 0.0535875860030853, 0.03309028688818216, 0.0979423109862593, 0.011806813023623922, 0.05550499682524993, 0.12513860849843872, 0.01158164541852931, 0.021965041223372665, 0.03898277473185332, 0.03774921612573728, 0.012076505658877714, 0.03253949648370186, 0.041241818633411205, 0.046732876404759385, 0.05718346099339186, 0.014006419993576505, 0.04875251782997962, 0.019222366015216517, 0.02580087793420159, 0.04219877353358654, 0.06303710817930198, 0.06128798389146405, 0.06401175588008857, 0.010055073503134473, 0.01007858282631083, 0.04659519891344732, 0.02992681682019705, 0.018768648526841597, 0.04981340404840247, 0.03067434626451183, 0.024424342423557274, 0.028667188242017746, 0.02918884240751786, 0.05089587479409191, 0.033369139062180635, 0.03254123167285035, 0.07645477045087085, 0.01707876773340808, 0.09448215230217866, 0.0514724325659054, 0.04352283393663745, 0.03997840558088595, 0.03752505879909281, 0.08244777669108684, 0.05104446903832498, 0.028595907591103066, 0.001006317536173869, 0.0230995197630217, 0.22171205059895593, 0.12573340682372933, 2.593583926077812, 24.176175748148275, 50.63361767799624, 72.2745341639365, 81.65409011225547, 78.28152641173332, 73.53489368192612, 66.23015388365715, 72.16720242654124, 90.35430723621, 71.6031499062815, 62.54791121329031, 64.2118198640885, 61.884057906366166, 41.35075992153537, 32.256554442067305, 39.361023902893066, 28.984572079873857, 34.57812101610246, 22.850863741290187, 44.07808980634136, 25.140855235438195, 74.39191587509649, 146.00891174808626, 56.186579888866795, 54.60309551608179, 34.16515035013999, 52.492679934347834, 56.45254012077086, 47.69308344010384, 46.96162023851949, 67.33829405999953, 39.314865450705256, 44.60099274112333, 32.169420949874386, 39.815661907196045, 50.99400112705847, 34.98118769737982, 49.40146392391574, 34.86816460086454, 56.94862973305487, 45.467142289684666, 44.688073281318914, 42.015876231655, 28.639676109437023, 18.028333148648663, 37.99179115603047, 23.085042968873058, 27.099449596097394, 49.75880753609442, 50.671339111943404, 55.14790881064631, 61.48166979512861, 77.19205671741118, 77.97009806479178, 89.4564296353248, 79.87513834430327, 81.7691489188902, 89.59827823023643, 75.54111542240267, 65.59069379683464, 27.11454483770555, 0.40928633462998176, 0.016582220184406447, 0.1576422942021201, 0.060645293579587055, 0.04221963410776469, 0.06693568366068987, 0.056783666518787225, 0.024880976791703896, 0.04339263729390599, 0.08965613545789834, 0.05759686501997133, 0.014278895443215246, 0.04678767084354355, 0.014036517672901674, 0.051945729346405116, 0.025423177435333212, 0.051611420067567984, 0.11139368878737574, 0.018585907828603542, 0.0049520162827966195, 0.034155309981396126, 0.029810011394382007, 0.08289262096607879, 0.06534254253511468, 0.01914215469432454, 0.03764055038411771, 0.042217266896078666, 0.01078867834181555, 0.04707177071982334, 0.03417792489692088, 0.1261835524271573, 0.09804903469499081, 0.04250486013329318, 0.07479877181110844, 0.03186449832883814, 0.023658315786310745, 0.08745652848794576, 0.05875859139186721, 0.013932148726927418, 0.057287740881644914, 0.03446733376251594, 0.038945883767859596, 0.0033421215325248462, 0.03333955657698455, 0.043227847950953635, 0.03587748712649749, 0.011782797124807634, 0.06922609503230742, 0.08371734526008369, 0.0766946402408423, 0.08511051445478394, 0.0683213681763699, 0.04438896911338933, 0.028803952173480106, 0.07414621045632709, 0.012505401898505948, 0.02237615847749816, 0.022098851885886926, 0.04561836403163691, 0.014070433342919476, 0.017158377675279494, 0.038754277517117804, 0.04055986631541483, 0.058112763949940284, 0.061021316345901265, 0.054460719393025485, 0.010996470115177575, 0.046951085058671814, 0.053615421807814034, 0.09451611297986201, 0.03915723593484971, 0.01810927665041339, 0.03392028186710612, 0.044068361317077955, 0.02451591482836633, 0.01574304651453971, 0.005246049925429566, 0.054509492380724806, 0.019591013270039714, 0.025025533752576, 0.04006514588611261, 0.028276106102331996, 0.04622773717968695, 0.009190443689153801, 0.04180799591385069, 0.019951842597595627, 0.030430519630411462, 0.043084512900320754, 0.031021418568167477, 0.012228709134844043, 0.051148285443383845, 0.024892586854196368, 0.1004597218707204, 0.024024930992914785, 0.031183926884325284, 0.035747198553215113, 0.048410145475739436, 0.06275852796651664, 0.04093658622174014, 0.028705456249055364, 0.11476033111853946, 0.06234559891445022, 0.08157557792841427, 0.0367845926854399, 0.04780501262435029, 0.03551233897826845, 0.040734415618522514, 0.08849835443881252, 0.09056298437738612, 0.044859393064173005, 0.0498759436361011, 0.015601093295000255, 0.14535591396833622, 0.3981207563511787, 9.233557485765028, 44.86588216597035, 74.75224048860612, 90.83166753092121, 92.55172098836591, 87.27696464907739, 91.51368925648352, 82.6260377514747, 97.13814843085505, 119.5071352681806, 100.63083864027455, 104.9963503499185, 95.34297373987015, 93.14775651501071, 65.22819619024953, 52.08578894215246, 60.17820342894524, 34.94769065610824, 32.72887252992199, 27.36554122740223, 40.252715926016535, 34.29320004678542, 95.96273960605745, 151.51196572088426, 53.184589955114554, 59.230821594115234, 38.562684289870724, 45.954261441384595, 49.51919778700798, 43.785535904669, 43.30099767254245, 64.88467108818793, 35.32594050130537, 48.53634988107989, 29.93371113654106, 37.546688433616396, 39.77614010533979, 19.206028715256725, 36.950535235866425, 24.628005335407874, 33.47300106479276, 29.20780004993562, 20.50897144502209, 28.333976384132143, 26.6660237696863, 23.55097151571705, 50.8772203999181, 35.63898094238774, 48.36649556313792, 72.23560071760609, 81.6951181042579, 88.548887314335, 95.13181686401369, 112.53584400300058, 108.33718992048695, 116.28055434073173, 102.08170767753356, 94.24965227803877, 105.94805071430822, 93.34021152988558, 88.35347483235022, 49.495996967438735, 7.394778786167023, 0.11666762191922435, 0.18855089291689858, 0.05247461346669063, 0.11942936122537622, 0.03533302460827174, 0.03839664086098633, 0.009766270804609503, 0.01614061071567478, 0.07998328716043504, 0.03327082699885772, 0.018013471609822685, 0.0732618538782962, 0.04810813063335034, 0.03782508947375802, 0.02983285422106424, 0.05566608979396763, 0.03385978773416531, 0.02079571908970754, 0.0214042725236786, 0.07480301593820896, 0.06486532338444265, 0.0365299335680902, 0.0360550471551476, 0.02307824358614462, 0.011707940758506378, 0.027046651812270287, 0.008163469310309137, 0.08837718231182906, 0.02213104098524538, 0.11693670264174862, 0.028486176987268755, 0.03827799682415301, 0.0707408806849872, 0.057817188076554775, 0.027835887083182895, 0.06160068949083648, 0.00335617158505615, 0.04324542200793663, 0.07918758227700189, 0.05076627953038101, 0.055105976099448825, 0.05940220100925334, 0.1010982791382459, 0.0495769510105733, 0.01946492094336258, 0.035439349951282624, 0.06921124058745562, 0.04205819639948107, 0.04496870231964896, 0.0912641616718423, 0.01723006243757423, 0.020628461028419195, 0.006743088193733486, 0.05700224672534293, 0.03983848728239536, 0.006091405446040294, 0.1124998048368481, 0.16035145689402858, 0.10716342787829139, 0.12436685152351858, 0.12260625123857491, 0.1263289482543065, 0.1273037108682817, 0.22195493111446982, 0.09788919044958969, 0.2729877709381042, 0.11011478926746116, 0.16314239181097479, 0.2265656772520273, 0.11453539238221223, 0.10714981449587692, 0.1735661365091801, 0.10214346821510023, 0.1035831695903213, 0.12364512775093318, 0.09721722408768632, 0.1353108771746197, 0.11354641883724159, 0.08247078231145298, 0.13494067284609043, 0.06665550998502201, 0.12340818441683248, 0.18023059583239018, 0.12003213452595858, 0.12793526609217928, 0.12937911966394994, 0.1348044011261194, 0.09526198384382072, 0.16841586529006883, 0.17761910935082745, 0.18246749596249673, 0.23951691455177723, 0.13266117822739387, 0.10977112988550818, 0.10014094502454805, 0.10831695710939747, 0.12501663964001403, 0.25721803487789247, 0.1466805106329341, 0.3127921060208352, 0.1572422890533363, 0.2611395470317333, 0.187941990912922, 0.093671539347739, 0.2449632940753814, 0.22493800088282556, 0.2548970642589754, 0.1633237861096859, 0.19033264488943163, 0.17216365934619982, 0.18682140346255996, 0.3914556075488368, 0.19931228320685127, 5.903835873450003, 40.28663266089655, 77.26782906439998, 102.04591997208135, 107.88888654401227, 101.02486425830473, 94.56362232085198, 87.75215979545348, 95.32766865145777, 112.69048736941431, 92.89415174914946, 83.34673404693604, 84.5088303473688, 78.65627750273674, 55.96129855801983, 43.91761387548139, 51.323150742438536, 38.70322673551498, 49.143909331290956, 31.627469024350567, 57.2042662866654, 34.13380276772284, 81.03481846470987, 148.89169692993164, 71.35433043203047, 76.6412147398918, 47.86831924992223, 68.84855562640776, 74.92103576660156, 66.48620620850595, 61.68667247218471, 92.44698586002474, 53.68537072212466, 63.20807749225248, 45.72056270414784, 54.806729285947746, 70.84483808086765, 49.6557786387782, 69.19834475363456, 49.709169941563765, 72.79603681256695, 58.09050229287917, 61.15169255964218, 58.0552480297704, 40.46508089188607, 27.105478279052246, 52.14187883561658, 34.59086871916248, 40.62779257374425, 68.35281510506907, 69.11883046550136, 77.43364334106445, 85.8278371441749, 102.95168938175325, 100.87543764422017, 108.87508023169734, 99.53921164235761, 104.90037779654227, 119.26003379206504, 102.92919066644485, 92.93396380639847, 46.19664822855304, 5.774190752736985, 0.14714658320430787, 0.43623188390366496, 0.19751389180460285, 0.1136052314071886, 0.20103097082145754, 0.14523427452771895, 0.13680450347883089, 0.22543036559176063, 0.2383898613193343, 0.16418902113312678, 0.14261374820864972, 0.1622303334936019, 0.08362898467889718, 0.15375240615779354, 0.11566465960875635, 0.1804869901388884, 0.1855145340725299, 0.11999081174332289, 0.10524624688250404, 0.13628577002354209, 0.11289401070004511, 0.14556062798346245, 0.10818311388814643, 0.09799668790712472, 0.1472913738219969, 0.14090278276032017, 0.1266330468558496, 0.19955525565291607, 0.15788672221524103, 0.2624894858848664, 0.2044243572820579, 0.22223495157255282, 0.19554970365378166, 0.3570429073466409, 0.13577906414866447, 0.27759900737193327, 0.21155401583640807, 0.13334636726687032, 0.18537576490592572, 0.1581960378755485, 0.1435730588291922, 0.14774911135675448, 0.16084202895722083, 0.1243608607159507, 0.14809294693893002, 0.1451754696186512, 0.17014337823756281, 0.09543711920419047, 0.2609487604950705, 0.16707049232096444, 0.15120136401345655, 0.16529871481320552, 0.11278288964662822, 0.20425045532324623, 0.14709835030859517, 0.1523308534054987, 0.23082319556945757], [0.04765778967750169, 0.018792274678426407, 0.08189808562277787, 0.036539276010326804, 0.05984314206627108, 0.06570970549458457, 0.01988233927066528, 0.07710635887398835, 0.07435827891552642, 0.015487786975779362, 0.06465404399580534, 0.023257954406642148, 0.014076400210239716, 0.026780903572216633, 0.08052040672590656, 0.023208327230907256, 0.021524033133661555, 0.11574716727820136, 0.06180386749967452, 0.06056285485805524, 0.05349516898633973, 0.055494191155077956, 0.034794564388932726, 0.04184189147406048, 0.05709620740925593, 0.01243705440673136, 0.021495728100079204, 0.0294531925371097, 0.04782289694694262, 0.06099857885630862, 0.09491041077360993, 0.020712384045304313, 0.07398358531176083, 0.03476809222070921, 0.0486471692490722, 0.0674336791158684, 0.0310771189059221, 0.03899005639757361, 0.0340739629351564, 0.060485085442421906, 0.07987375956990066, 0.038270378079746044, 0.09906102918208608, 0.02895536753649433, 0.017287141733592557, 0.01237152707612803, 0.059734342259264765, 0.08477376518590797, 0.08538534849761956, 0.05494152000474353, 0.011376741796641821, 0.1081256572938254, 0.1993452556311123, 0.24483240029263884, 5.372280680364178, 30.90618241217829, 60.95680567526049, 85.67233085632326, 85.64064595007127, 80.33177283502395, 73.53317568379065, 78.3436175315611, 65.32463550567627, 86.97100408615606, 75.42629980271863, 58.44905007270075, 48.237120105374245, 30.34754864631161, 30.01781459777586, 19.993277826616843, 34.516422133291925, 44.7617785392269, 40.69747347985545, 59.738831289352916, 58.73264528089955, 61.79918566057759, 77.46644220044537, 78.10808704745385, 38.75879887611636, 45.27866848053471, 58.59538193671935, 58.42662588242562, 67.11474249439856, 58.67664952431956, 61.7119364584646, 45.93413968240061, 61.29123087852233, 45.948197457098196, 50.19818752042709, 54.37585300014865, 68.89767939044584, 73.34665913735667, 51.497978625759, 65.52776328979, 63.20966212980209, 77.40984239885884, 94.04219027488463, 83.95724311951669, 103.73891692007743, 121.41160288164694, 122.72015263957363, 84.64416780779439, 65.84922113726216, 46.34594148205173, 41.95561293632754, 23.21096674088509, 23.82491965447703, 21.21931072204344, 21.302706195462136, 26.671499398446855, 40.725730234576815, 39.85262632369995, 51.21161814658873, 77.04081796830701, 77.06319901251024, 75.0521449119814, 91.37016973187848, 85.28241588223366, 59.66774617472003, 28.276903936939856, 6.064451538747357, 0.049516211729496724, 0.24721550064221506, 0.03907993383285019, 0.043279662307712345, 0.03662382913452964, 0.08007434437111502, 0.05233925339134951, 0.011648522021489279, 0.04820397589355708, 0.0235171162057668, 0.04989301973593332, 0.012949261750515192, 0.03772893394794195, 0.07028880453999005, 0.08567603289960854, 0.027839857333850478, 0.040037857834249735, 0.07836056738010339, 0.0029482326382065135, 0.058156113035135695, 0.020521430884517973, 0.010153869159459587, 0.03498231721741538, 0.05778445313955027, 0.03664122699129005, 0.03641307068568084, 0.05394116622365771, 0.049430187716479265, 0.03142324126055164, 0.03935192568948673, 0.09685632006655778, 0.0652979102526461, 0.044777896630788044, 0.010873683457893711, 0.009524100835645392, 0.013523418794295961, 0.04933287156745792, 0.0848888315921349, 0.07510649400853342, 0.02794788722249289, 0.06263521462378484, 0.08143700028379118, 0.030093741633238334, 0.03111820228608145, 0.013331630597672155, 0.011026187623370319, 0.05281967095910542, 0.007716856808626965, 0.037763722000583526, 0.04825771313100573, 0.03119167011801995, 0.01113929667495071, 0.002346935253890772, 0.03464877785694215, 0.030574580549352595, 0.06192939100606788, 0.02600132292436977, 0.12227143251126814, 0.035671723570915005, 0.058123979477151755, 0.029588707745255485, 0.027702133877262957, 0.03299749831879332, 0.012860795832239093, 0.046313324522587566, 0.03881354207894014, 0.012491536664686376, 0.036832339115320675, 0.0031761593568409166, 0.005319541218810745, 0.05687139124699658, 0.04913243232294918, 0.04518752384390082, 0.04450343797103532, 0.07149199159034798, 0.07536998228921045, 0.021185226918708895, 0.08552528211786863, 0.04005037571093248, 0.02522680803292221, 0.013243367692695992, 0.09509921314254885, 0.01641648855330723, 0.030139310458194346, 0.03680366444431486, 0.05959954908898762, 0.023037340236647476, 0.10576865755982938, 0.02828259678227046, 0.01789370716940011, 0.04923110061715688, 0.06381530412322571, 0.02009394041623079, 0.0566914908197378, 0.06018024756603184, 0.05652110137405896, 0.012192149503877567, 0.08024128259069498, 0.042489438783377416, 0.03496674648035438, 0.026637819415378957, 0.09020203439098212, 0.049368257168680436, 0.05123520194883308, 0.05010647864471521, 0.04891652576324921, 0.024899924061291163, 0.0612609486486162, 1.6476188023244183, 16.30958191810116, 55.26836087626796, 81.88795751140964, 100.05105741562383, 95.93671075759396, 91.7747857493739, 91.5731288540748, 101.49987897565289, 97.91031406771754, 119.25391489459624, 103.85582708543348, 93.56417102198448, 69.82907756682366, 34.71081479903191, 31.44214095607881, 14.03815107960855, 20.091342964480003, 28.225436556723814, 20.056292664620187, 30.676017730466782, 40.53620915259085, 25.458437781180105, 28.441274781380933, 24.836538145619055, 26.796311178515037, 38.73347997665405, 35.326517089720696, 37.13602804368542, 22.972880832610592, 25.011146376209876, 16.37029334422081, 22.498142642359582, 21.99651268220717, 22.686102621016964, 25.395615139315208, 27.427006729187507, 25.43962217146351, 37.1975935659101, 27.23240617782839, 36.9226275720904, 37.561809170630674, 51.77283479321388, 46.9158971694208, 56.415493334493334, 68.11925365078834, 74.08347637422624, 93.08200974618235, 50.185482963438965, 45.950805833262784, 32.79690604056082, 25.383763697839555, 22.923170674231745, 21.432064002560033, 19.485891788236557, 27.980208012365527, 44.54786031476913, 67.28226692445817, 64.38473755313505, 74.92124757459088, 107.50159955793812, 96.61148394307783, 90.5282957323136, 100.70060976089971, 94.74822475064187, 87.04828262329103, 55.339955899023245, 15.802819536578273, 0.09073642668344321, 0.23506851776713328, 0.005373848234153083, 0.062763745025281, 0.05467793596307597, 0.04635192386265244, 0.011292158028922014, 0.032640336637174895, 0.025502618837861285, 0.031069752970530145, 0.06806326549380057, 0.02878702546079313, 0.0468809956744794, 0.03763708000582072, 0.11432478715094829, 0.09753977008644613, 0.013589444082050074, 0.047223996220817493, 0.04091949863058906, 0.11932525753734574, 0.03990098473525817, 0.04999510478228331, 0.03827741842777018, 0.008795172963742047, 0.014325688093630298, 0.049139273488113, 0.0592843039081462, 0.04330385536436112, 0.08749226648961345, 0.09728123073375995, 0.04730516323639501, 0.05012120285461988, 0.07918672425852669, 0.024232734257595676, 0.05029552999222952, 0.032742061622200475, 0.06660526993894769, 0.07401979828794157, 0.0333945999943441, 0.014794769475326664, 0.03206656167974636, 0.04281092758080171, 0.08454328763388819, 0.033962960625367786, 0.014555886981167622, 0.05793351086697752, 0.01298859270454775, 0.02845775512527795, 0.06546864060745125, 0.04102732167549191, 0.033208279750279845, 0.029128080143803553, 0.036057897002225926, 0.01634293070603763, 0.028130610683752645, 0.16665439932577072, 0.15738108886345742, 0.20112584315000043, 0.10296391007760841, 0.1296074445089025, 0.10803565728448092, 0.072007040162721, 0.1746116933082381, 0.19133203723017247, 0.2147874431384187, 0.12948673969555285, 0.10555346346189899, 0.21269564006117084, 0.21490385785939234, 0.1872998560147901, 0.10926063953628463, 0.1109481473723727, 0.17363664724173086, 0.1850259538379408, 0.16437027753601152, 0.2122664776059889, 0.231117679767551, 0.1704291749985949, 0.15160728336101578, 0.21049618630880312, 0.1226006281532107, 0.09986734438327052, 0.11547032608500413, 0.16543973627830708, 0.18464919179677966, 0.21451745843214376, 0.15002685929498366, 0.19481183840863167, 0.17793115228414538, 0.14771328908541512, 0.18806808898525854, 0.17988279191476686, 0.16231821910027536, 0.23691897250471577, 0.13899484078489965, 0.2111831679940224, 0.15015943847115965, 0.19440688433185702, 0.14269910572517303, 0.13986039756526872, 0.11047427602592977, 0.2638303236134591, 0.2991189381047603, 0.14055784401153365, 0.15386080759907925, 0.17813514617662277, 0.16493221835022973, 0.3287537011408037, 0.8474085864520843, 12.284536842376957, 51.70118485727618, 88.44899239078646, 115.18626013109761, 107.49151906659527, 101.81449228717436, 93.01711020931121, 99.45008754730226, 88.7401185497161, 108.58852755638861, 93.1497569237986, 74.50921043272942, 60.12633400578653, 39.97889134191698, 42.00994560795446, 28.94680161629954, 47.4987417651761, 61.83569115977134, 53.09026871958087, 78.50038682260822, 74.72116747210103, 79.28186416625977, 94.09733095476705, 104.02907817594468, 52.61755251115369, 55.45346929181007, 80.82848610416536, 75.63922174515264, 91.82216013631513, 77.3328305828956, 82.63239199115385, 66.03019145227248, 84.72778489512783, 63.838735780408314, 69.5372610707437, 69.72520535992038, 91.26034336705362, 97.2571845208445, 76.57982180195471, 97.11328060396256, 88.43509151089577, 104.958052327556, 123.49500117763397, 109.55088107816636, 126.12626829454977, 143.25790251455, 141.42629684940462, 103.03480440570463, 87.41036445863786, 64.29563699230071, 55.075329272977775, 37.17691090799148, 35.88477234686575, 28.63685396409804, 29.802343114729855, 36.52535815392771, 55.35601800487888, 55.04927296792307, 70.04553748715308, 99.26885051112022, 95.81634106174593, 97.51455476207119, 113.26954687795332, 111.40813119949834, 96.38450422594624, 56.365487037166474, 11.011807149456395, 0.0881203436743348, 0.6220524854237034, 0.1261361086020066, 0.2218657278365666, 0.11904824780480516, 0.1494534731271767, 0.13275709243551378, 0.14389538266245397, 0.12118533433925723, 0.1515838563922913, 0.1543580599489712, 0.12479599099606277, 0.11412424831500939, 0.09851008939046053, 0.24874229855354757, 0.24373755339653264, 0.1546151896998767, 0.15137174196781653, 0.12328622321928702, 0.2437224767861828, 0.18821787449621386, 0.15876669677034502, 0.11268450097451288, 0.16340321410567532, 0.1676216312954503, 0.13870087752659477, 0.1079088161068578, 0.1828634255235234, 0.11810043616400612, 0.11751041056648379, 0.1158434262258872, 0.16882097258442835, 0.16847958848361047, 0.09829169304500665, 0.12212026038116987, 0.15303053682850254, 0.18848811967238305, 0.1353248352966001, 0.16033360704539285, 0.1706128215958034, 0.15681643609798726, 0.16805799497712046, 0.2429484215474898, 0.1405713118372425, 0.15526046555849815, 0.08794567562759885, 0.11330432739228972, 0.06522987398409075, 0.22240965026280574, 0.10742871646559048, 0.1977551022484418, 0.16756247398593735, 0.1303242270143763, 0.16503519588901153, 0.1119410892527911], [0.02301393625056071, 0.05147416009417465, 0.06255165741388356, 0.030780690759720824, 0.09417853633602781, 0.09476711402737326, 0.047047600645812294, 0.01608252209881621, 0.03293960888479506, 0.10116847577474772, 0.04252124675399354, 0.07151818413647913, 0.10639939306964798, 0.003477710476633342, 0.049476785014473626, 0.06809067611973132, 0.06443004754762496, 0.01600383625050346, 0.034994122632328546, 0.0869311607112327, 0.024779782322565877, 0.060127736069262035, 0.10005834542455212, 0.0945631661001713, 0.027189753206086256, 0.02181174511450433, 0.060314929653559966, 0.025444924756283724, 0.06535441689794103, 0.023045094961661006, 0.033324150548827265, 0.0680489013452203, 0.03895397748677962, 0.005984313057495222, 0.04490454628643009, 0.02008893594686543, 0.014643362730801588, 0.051806722692544424, 0.0690372237154553, 0.03338620750113361, 0.06918012975685059, 0.03670296601710781, 0.03182030654692602, 0.031220204977979584, 0.027153342962265018, 0.0439640469548683, 0.014499964477914958, 0.0673698256873796, 0.03953484450316718, 0.06759576799888765, 0.051486658818659284, 0.19707812567151364, 11.666031037607501, 50.52890216150592, 73.46132570697416, 85.24190564309397, 83.6074383028092, 78.14546723519602, 74.26348178617417, 69.24644085668749, 67.64688261093633, 67.55422838272588, 52.10244724827429, 36.64171918745964, 23.5117321245132, 21.040880141719697, 34.91462899792579, 76.94954441439721, 54.71690700900171, 78.61136636426373, 74.66151606652045, 87.54054792465703, 96.85637320241621, 67.81836863486998, 55.688748744226274, 66.95231714556294, 80.75861300191572, 91.47770543252268, 105.47556984809138, 58.93760873425392, 73.19961732433688, 74.31957952437863, 83.06644931916269, 74.5626566486974, 94.28098417097523, 74.19348316807901, 91.05587805471113, 79.10065850903912, 73.66148425686744, 86.80602919670844, 73.86478854763892, 68.65871291006766, 69.92256333751064, 56.726572590489546, 66.79201772136074, 48.51793435312087, 58.75241402656802, 44.47242921398532, 58.125870304722945, 67.0191857122606, 64.54261687494093, 88.35669117589151, 80.66811607730004, 82.86301951254569, 78.24955909482895, 61.26820656561083, 87.72310287721696, 77.78728423580047, 50.40137806246358, 37.985864454700106, 38.71787678810858, 41.77567812704271, 41.31190492260841, 38.60741892168599, 50.265444401771795, 61.59075090962072, 74.07681618967365, 78.41505958187965, 81.77963733673096, 83.89714456373646, 70.46592927748158, 22.304936493596724, 1.9856612889036058, 0.09233432521502818, 0.0732301761426272, 0.027366784634068612, 0.0917048077850092, 0.028712555968893633, 0.028753880666749134, 0.03703609552054155, 0.013111191670290165, 0.028299046605224573, 0.042860891835223285, 0.03288994723510358, 0.07766881296711584, 0.027152797124618967, 0.011465746849294634, 0.07754443093172966, 0.010106681016153626, 0.030121719164233056, 0.03248117421002638, 0.058846530624695366, 0.022212527842531284, 0.07306030380629724, 0.08346117311908353, 0.05174074337006577, 0.03087356742922097, 0.05591129921677132, 0.05507365484992343, 0.012218845752818931, 0.03617341540032818, 0.0275538269160015, 0.027012344479801196, 0.0631276329588746, 0.04176443998491572, 0.035794780274192174, 0.0231413270962695, 0.047796256239375765, 0.06587164882089823, 0.08188826437558859, 0.048762492294753754, 0.007505940832948733, 0.0941237304059248, 0.04099975017109706, 0.09752399633608519, 0.0335241416319003, 0.019251829756784345, 0.0476380514221326, 0.036266104378286874, 0.05021142119902277, 0.03437586286435685, 0.032046402076018915, 0.035895409753486034, 0.0671457143260106, 0.04201668209486431, 0.12059011466560826, 0.024078541825855934, 0.01489946783910836, 0.05664104776036355, 0.021705756850180127, 0.07361141213726613, 0.08251616536008735, 0.0715498388895104, 0.08923335451512568, 0.042545623671744144, 0.0827323706940778, 0.07996219675987959, 0.11115187313407661, 0.05311340822147266, 0.042911315742399425, 0.054923225825111714, 0.04922107635666767, 0.1383782166146463, 0.05688030467999559, 0.022950559711804795, 0.012912405260478058, 0.0728358094009661, 0.04774978534588891, 0.09540800020218858, 0.03273553455308561, 0.01362847721940207, 0.04776596512284972, 0.055864276739978985, 0.04233882589746387, 0.016360715437199802, 0.028604855498058662, 0.06591716976535898, 0.031563128915525256, 0.02041427050566962, 0.04173422164674248, 0.041356360269409996, 0.02824986759092539, 0.025065510135684765, 0.01281927195152328, 0.10273574611111995, 0.04036247993128435, 0.08974244292344778, 0.03133402074567013, 0.03041055154866509, 0.007426682333912581, 0.08979387040580473, 0.05912462054120918, 0.05623261564441266, 0.12686373125160896, 0.07423129218119769, 0.029985945401412827, 0.08605316266297333, 0.6124839859624064, 26.513027798744943, 74.94182432851484, 93.55910331972184, 97.64181998468216, 96.00840383960356, 100.11502342839395, 99.569107947811, 100.84042656806209, 93.23982238769533, 104.4071711263349, 82.55127737599035, 47.25957524391913, 20.76134066427908, 16.81469886533676, 20.049263777271396, 39.43308176532869, 32.32805532793845, 47.451767459992446, 44.70806560208721, 50.4893607477988, 63.0912143953385, 55.01082589549404, 50.22576178273847, 53.91332318705898, 63.347623655872965, 66.68481149981099, 95.44205281042284, 46.59934620703421, 51.46296754960091, 50.533346206911155, 66.16359126183295, 60.226754526938166, 67.99373780527424, 49.82165959573562, 59.93513414936682, 52.96592174037811, 51.88528914605418, 60.575614052434126, 60.98892204223141, 60.54019504977811, 62.86083398326751, 50.97353027712915, 62.70017762337962, 50.89108990084741, 61.07013863901938, 55.07734144887617, 68.79634887941423, 78.3621468082551, 68.80265605065131, 77.8551177055605, 65.51589419764858, 66.64233223084481, 53.26831294644264, 47.08390012864144, 59.30396595308858, 52.73216416758876, 32.499778655267534, 24.7476395868486, 29.706833401033958, 29.311140775680546, 43.65518769910259, 63.9539828608113, 81.40991472428846, 86.8673986004245, 95.7218982327369, 98.1216121489002, 95.76338121967932, 95.46460643891366, 90.16986954596736, 43.53477877955283, 9.320072224063258, 0.16077352537503167, 0.12567780416218505, 0.05910776277643539, 0.05432007714144645, 0.1002553525951601, 0.04534469061200658, 0.06507536937152186, 0.016117955580533996, 0.01962367734391122, 0.04312535687800377, 0.022890854649425998, 0.030678596137271776, 0.0544904129609706, 0.07316260718770566, 0.043418182495741114, 0.05475945920953828, 0.05048120672243738, 0.04858454922214151, 0.017932683807767687, 0.025895907310768965, 0.07917437492118728, 0.05082244526654963, 0.046948338633463274, 0.010333083938026141, 0.07032815847666034, 0.04392849664474207, 0.03478864252927803, 0.06856265522900128, 0.06513219777374499, 0.1089683693322924, 0.015468948873721305, 0.04616512098319588, 0.048892432298030586, 0.04441031615339941, 0.06242148375378982, 0.0969171014824702, 0.12373883562583117, 0.06511798684274958, 0.09811105717334057, 0.04658686387683115, 0.034422689988728494, 0.03762371177154203, 0.04913914325316587, 0.01434810669912446, 0.07613639197041912, 0.037849117821503075, 0.07314994375431731, 0.05939103144731733, 0.03845042406371044, 0.04374723258097807, 0.055518204181064526, 0.025163758996753924, 0.053649708072865204, 0.1182184826522585, 0.2214424182931262, 0.17292446126380276, 0.163536635978568, 0.22513310815538132, 0.20305848380009975, 0.23264504458394744, 0.18861786432323918, 0.18748650567666178, 0.19474465249767228, 0.17607136659564512, 0.25603813690043264, 0.17851880300910244, 0.10209140487976613, 0.09137247118257708, 0.1963506485786169, 0.3071138623260683, 0.17710023799971228, 0.11922152157151893, 0.11561345429189744, 0.23559629105992858, 0.1840634562916333, 0.18018395639956, 0.13426351240806042, 0.06668120457400238, 0.1469410724577404, 0.17276894541517382, 0.2918963530851949, 0.16638732575360807, 0.152602017887177, 0.1623464877446813, 0.12794756946424324, 0.11433466202429227, 0.09997687197380489, 0.13771283860889175, 0.18265840507322745, 0.11833626867061663, 0.15757527683050404, 0.20972614537083337, 0.10374603988302332, 0.17173242845362233, 0.11166197277845875, 0.1503391933417128, 0.09230087015537486, 0.16152130379792184, 0.17211504340652498, 0.11562059423135174, 0.2800528176369206, 0.16498970558806775, 0.1985532279697157, 0.28199295062691937, 0.39116921323922377, 21.583628308388498, 75.83812513659078, 105.44055877193328, 108.92659664154054, 104.24731100759199, 100.82180315448393, 95.01246698441045, 90.9987840344829, 87.52766686101114, 84.09445547288465, 66.34594225114392, 49.28063923312772, 34.15617596718573, 28.71234586161952, 44.645711683457904, 102.37197875976564, 71.52935443385955, 105.51282451998804, 99.88388599887972, 109.9222275518602, 123.4210801893665, 91.96462062097366, 74.76569421829717, 91.2467876557381, 107.92841619060887, 124.93185166389712, 135.95316271628104, 81.26000173630254, 96.97251458321848, 103.56535988469278, 118.95212773353823, 105.89119203629033, 136.14752400305966, 106.95980256603612, 134.469173185287, 116.0955047607422, 106.94174397376277, 124.30108747174664, 106.21697625806256, 99.7015271648284, 98.28187234940069, 77.56254811440745, 94.0388641049785, 67.72294521331787, 82.40227437788441, 61.70637453756025, 79.85261609477382, 91.59973036858344, 87.46685443385955, 114.39240378718223, 102.83394767392068, 102.98175827149423, 102.34698541702764, 82.5866493102043, 116.80865441599201, 103.7513037650816, 72.3472313727102, 52.21891810817104, 51.16874664060531, 52.878409739463564, 53.444270472372736, 50.62262719677341, 70.67321869634813, 80.36882354367165, 95.66944045405235, 98.97186433115314, 103.07937822034283, 108.95396694060295, 100.60821440912063, 42.036154885445875, 5.895695484453633, 0.20070061838674932, 0.19738733407951173, 0.18557577514119689, 0.18159257758769298, 0.1808338594292441, 0.22267626418221384, 0.20218482180949182, 0.1018551203812803, 0.19648370272930593, 0.10239301369555535, 0.14672240032063377, 0.1422281148693254, 0.11932862066333333, 0.11810930746216929, 0.16323911807229444, 0.13892999910298856, 0.10619576689937424, 0.12530287307116295, 0.15600047584983612, 0.1218681638279269, 0.3053459765449647, 0.16482263713354067, 0.12861263337394885, 0.160529894093352, 0.19333695061504844, 0.14127462651700745, 0.15755021043362158, 0.3378493404917179, 0.09935100112230548, 0.28532359448652117, 0.12420188214990402, 0.2041244185379436, 0.2335680886021545, 0.15838101746574526, 0.13461877802206626, 0.2518014408527844, 0.28950750707618655, 0.16082146715733314, 0.11168364540583665, 0.1914953518538706, 0.17601395596659955, 0.25984780021732856, 0.16396768301004366, 0.08362696220677707, 0.18557514694909896, 0.10329251583184927, 0.21870221371852586, 0.13480896701014813, 0.12030414936523284, 0.05732977995648981, 0.20337889241355084, 0.13877618396955152, 0.2171510848547182], [0.06599212380787058, 0.014871375394924996, 0.03811452515243042, 0.02708905860931883, 0.05554832675824723, 0.05259431853529908, 0.11214716690442256, 0.031042644949329477, 0.026210340438410643, 0.02879325184039772, 0.05988437674879547, 0.0258340610326418, 0.043802505824714906, 0.05651271271128809, 0.025537190470664252, 0.02474163305915652, 0.07388772472979561, 0.008912320256293302, 0.02181400890432058, 0.018592950091847492, 0.05563558034238316, 0.0398119883010945, 0.06278440258615921, 0.0900462887159759, 0.0075394116931655, 0.09841252043242417, 0.09299823999284737, 0.0784564279620686, 0.03313732851717261, 0.05551763344556094, 0.04971305419120097, 0.0321979170304633, 0.04826516333606936, 0.031482641802980535, 0.036623430768809015, 0.012418569662728378, 0.021902677835896615, 0.03100132025147398, 0.0810009736808077, 0.03882148641071493, 0.05990967297205522, 0.040488390312079466, 0.06400501813679453, 0.011180641482614223, 0.0361248645781269, 0.05077777851012446, 0.013384053994330668, 0.12524751555775443, 0.023972528663674192, 0.1442011283530343, 4.066764385469498, 36.579333889868956, 74.44843722927955, 80.47358220623386, 75.7346373219644, 70.5681933126142, 64.59284282499745, 59.39344698382963, 62.681154128043886, 43.839503795869895, 27.87845780772548, 30.659094664358324, 22.44977785694984, 50.40857561172978, 77.22741296214443, 77.3938940417382, 76.19166404970231, 61.72307991212415, 66.88820208272627, 51.77413702011109, 52.56050555936752, 56.91770184424616, 61.23154417161019, 64.98065933104485, 46.5270883037198, 28.35248212660513, 13.804737694801824, 9.624800182157948, 11.978192867771273, 25.782833483911332, 21.958602974491736, 19.17572448330541, 21.559205670510572, 20.62670138574416, 18.39515320716366, 20.774237417405654, 23.5930722759616, 24.14776013743493, 23.766025266339703, 22.463990565269224, 18.259335256391957, 13.891713311595302, 8.701144764500281, 6.037509758626261, 6.8267931092169984, 24.11218031760185, 27.5391080687123, 22.82454267624886, 27.578012097266416, 27.185865294548776, 27.633029222488407, 33.641474708434075, 38.458513982834354, 44.956100602303785, 46.560220564565356, 47.115796842882716, 58.37078702065253, 49.899110717158166, 64.99695285674065, 75.72850273501489, 155.86438455889302, 134.25948327587497, 39.11493047591179, 34.91708440165366, 16.318132685076808, 39.80664045579972, 50.2421376782079, 63.45030738461403, 66.69154228702669, 70.70877105959, 73.11166994033321, 82.70979604413434, 57.92700221461635, 19.281959918237504, 0.5060101138247598, 0.16199275430652404, 0.20183700257011, 0.041849521709786314, 0.03778238773285862, 0.10102438229706981, 0.043563796657948725, 0.10220981909022217, 0.08220203866761538, 0.02145655227885131, 0.06905072984556038, 0.05073912554390488, 0.04807471387809323, 0.047287715583919525, 0.018475192801786527, 0.025606059859837257, 0.03724473573627972, 0.010961012693212159, 0.02883179755430789, 0.07602146346001856, 0.022389775690352245, 0.030740656920017737, 0.08795455458664125, 0.024726922255790523, 0.07918381312441441, 0.03326369088984305, 0.020057014978280472, 0.02903424777961787, 0.011954799185567086, 0.06527382444830672, 0.04302460482464202, 0.01674870832733089, 0.09896706849817308, 0.1465853318692215, 0.02344934806798495, 0.034230513002483115, 0.050949010652520006, 0.07821610618022182, 0.039085434344146526, 0.024880180060262644, 0.0712356509100045, 0.015099567132100705, 0.04999703915429212, 0.026339022142271844, 0.03692910751147616, 0.07130223927238295, 0.034076644242891384, 0.05344986254649778, 0.06293448304096538, 0.013533375064481892, 0.06030504711933675, 0.060213725608322895, 0.05204310295202079, 0.028224157680186535, 0.01452628821660314, 0.034037041327645706, 0.07140330925223327, 0.08331993714936319, 0.07160988486101551, 0.04627081813410886, 0.031774264662676764, 0.04469916577480974, 0.02651445053127264, 0.03564147841966441, 0.058256125813650514, 0.016386586226402752, 0.09368110012503401, 0.04688111441810766, 0.03545122048366935, 0.051711482641797875, 0.06749268320779647, 0.0810939844156946, 0.0313858293567694, 0.016402614700998512, 0.0670660181992477, 0.05204005392208215, 0.009975080517300916, 0.03325946208450102, 0.04052246207251184, 0.035025842502833374, 0.048769291325081746, 0.049279923400571274, 0.03396843049314714, 0.05700054601015103, 0.05028143397442276, 0.06592080868299931, 0.01867849338469246, 0.034903877474848306, 0.05438221453298485, 0.18514449828334395, 0.023631772754954237, 0.02327471257998578, 0.045585081341766545, 0.09401493825979772, 0.10466561352293338, 0.024960598224894177, 0.06574415646853947, 0.012176752094209436, 0.07864761286445203, 0.12640887420744668, 0.03263518852632373, 0.08169879551015555, 13.564564105003113, 60.455381639542125, 94.08938423279794, 86.8051976542319, 91.02011388347995, 92.0772397133612, 92.90459309854816, 83.26688243496804, 92.08302913173553, 73.70732107470113, 42.544698023026996, 30.921987602787635, 19.319595060040875, 34.33117251242361, 58.28920564343853, 51.151021449796616, 51.42638360300372, 55.30834944017472, 66.44892800238826, 57.89207743060205, 54.077333173444195, 53.43083243216238, 64.80194045651344, 68.09626071683823, 44.77118046052995, 22.224871112454323, 10.571437747247758, 8.388310247851956, 11.705782298118839, 23.420839040510117, 20.31087213946927, 16.263695090047776, 22.369273170348137, 20.98097182089283, 18.19937006119759, 24.01778651821998, 25.252911467706006, 27.521983000539965, 26.29147271956167, 23.19052726991715, 15.676662383540986, 10.921214126771497, 6.146122149882778, 3.7580287456512456, 4.323108436599854, 14.522963877647156, 19.825490597755678, 12.94872453135829, 20.192999032235917, 19.841793929376912, 17.759548810220537, 26.589484599328813, 29.72675119676898, 33.55075420871858, 41.546666622161865, 45.623727229333696, 57.153181337541156, 50.274481542648815, 54.42614955286826, 53.44267799008278, 118.35213845775975, 110.02774715423585, 25.166801714128066, 21.24852845745702, 18.9997120441929, 54.746544438023726, 63.94466330928188, 89.46529419191423, 94.04299043839978, 94.20878118084323, 92.6951934445289, 98.44175600236463, 80.38633300412087, 39.012395797237275, 4.253845262912012, 0.09867256131744194, 0.27027431815381975, 0.010653960822720923, 0.02749420612329437, 0.05911743463647943, 0.049184166240475835, 0.18007792983083956, 0.026385056365641858, 0.012485382105824689, 0.05860505205008292, 0.0390859667752539, 0.06628414886372705, 0.02720259858535663, 0.032207516112154534, 0.0239545792236083, 0.02325373134695955, 0.0491909422881661, 0.022818407629646605, 0.042395236781768264, 0.0452786538329336, 0.008998469716208357, 0.05994260326148041, 0.027454256553262956, 0.021836235030223767, 0.04782674653876213, 0.05882581943766244, 0.06565997872741954, 0.0764049900575511, 0.0785362160193824, 0.09862055926914177, 0.03857774021584661, 0.057270576681701414, 0.05316379765469221, 0.044816867523496194, 0.028398113265152902, 0.05645699896699479, 0.042099369794971524, 0.028687748126685623, 0.01688683398007866, 0.017725610241834677, 0.05130898004638092, 0.013045712220182103, 0.0385296298942018, 0.04243930982005212, 0.05477101947631567, 0.03701635343473285, 0.05996643242636516, 0.058414311478695566, 0.028087117957071434, 0.09040245831373239, 0.023700188237032103, 0.10329748774247785, 0.09425977229951851, 0.14665755863872268, 0.05486435196813076, 0.15657859644101513, 0.15532392828214556, 0.1980355670375209, 0.10474887195854418, 0.0811338592921534, 0.09693263008469537, 0.14233044889425078, 0.15276714047837645, 0.15650237069254921, 0.1439048361874396, 0.25304876988933933, 0.14251843154911073, 0.12850980139187268, 0.17994118313635551, 0.20242450007748222, 0.160628903296686, 0.20747533308402186, 0.10987715645422859, 0.23852280821771393, 0.16112813215342262, 0.1300584557916849, 0.18083399732507047, 0.16346212626705248, 0.1450867566370195, 0.13739987637006468, 0.2512790148537005, 0.10610796556237245, 0.10171943088813175, 0.177119727276506, 0.12446475756024161, 0.09979658084170473, 0.1335444316388138, 0.16290331109156533, 0.214024220382975, 0.18659036666635545, 0.1953867567522872, 0.18130874201174707, 0.18207930388950533, 0.15717818281583248, 0.11168396716276485, 0.11923191738465141, 0.3426513941057267, 0.16616848507715812, 0.34974935194177015, 0.15918893379069146, 0.2400875274812983, 10.274617287420458, 61.39707603762227, 106.26679820399131, 100.75728016514933, 96.00136710751443, 89.56889183290544, 86.46218638266288, 79.27288978330552, 78.28332285727225, 55.89339840796686, 42.027647264542125, 38.72369366307413, 31.630803038997037, 66.44932808414583, 95.88673191685831, 101.68299090477728, 101.98681769832488, 85.51928781693982, 92.95420323648761, 74.38989193208756, 74.59886012538787, 80.84317930283086, 86.87896174769249, 89.44286607926892, 68.99850783809539, 45.96040387307444, 23.405239774334817, 17.569137350205455, 21.888616123507102, 42.6457029773343, 38.74066968117991, 30.757267667401223, 37.25720574778896, 39.212589648462114, 35.99581856881419, 43.98178777387066, 46.97254796181956, 48.9785578943068, 49.25741487933744, 43.1236594723117, 37.25140063993393, 29.247688593402987, 18.49084334988748, 13.34915832165749, 12.8404837846756, 40.070635580247455, 41.62411774358442, 33.71362670775383, 35.716612492838216, 37.35188784137849, 42.15683052616735, 51.1878054372726, 54.12042825452743, 62.87445637487597, 68.2332455727362, 70.92774129682972, 80.83637006821172, 70.90645067153439, 87.04137925178775, 101.02426021329819, 178.5388691194596, 145.76727805599091, 50.82315052709272, 48.098311347346154, 22.79417960874496, 52.85904499792284, 67.4123562535932, 81.86920858198597, 85.81106508931806, 90.53374782685312, 94.83010030561879, 110.23265177203764, 86.47061163379301, 34.24173855012463, 1.9930249260317896, 0.2136748996112616, 0.4189456921190985, 0.14293450922254594, 0.1399123536482934, 0.2098681321067195, 0.08686711576076285, 0.3872747286673515, 0.20029407084709216, 0.1071934815075609, 0.19646816646620152, 0.16480310189147152, 0.17438493128265106, 0.17968036084165498, 0.15162668070725857, 0.1129008288825712, 0.18290010581333793, 0.15083590943005779, 0.08941926107171083, 0.201380230306137, 0.25857876024899945, 0.0677556888530812, 0.16055767244148642, 0.13681360460337133, 0.16151545088618033, 0.24334182301836632, 0.18526437572173535, 0.16093909229722717, 0.15786392343861444, 0.2639900069803961, 0.23821735364054483, 0.22968100443963083, 0.15505339199256513, 0.1807633486966933, 0.17981025871009598, 0.17069260199223796, 0.24601758427677617, 0.14647264033555984, 0.14286528551770797, 0.07612755897665217, 0.1551141274432021, 0.19444558709379167, 0.11026173259221739, 0.10132653503528527, 0.22656458940717483, 0.2019747605006541, 0.18235875744252436, 0.1992294231369611, 0.27832973267762895, 0.17617121849569584, 0.21495540025493792, 0.11409689131523333], [0.037752357086226825, 0.11546107940375806, 0.049671225790535255, 0.017360423789209416, 0.07929769975523795, 0.008816698119194518, 0.08728383694805446, 0.021919941627270272, 0.01361159647199055, 0.05593986280502812, 0.043764703216091286, 0.012809594345819807, 0.030714516084821477, 0.03131432270991706, 0.07629709423429544, 0.04043566048025124, 0.0705266135534452, 0.042510184444366925, 0.030753182457579725, 0.013558778540051032, 0.059561539636624444, 0.01382273413436187, 0.04385299867980423, 0.06187407562749521, 0.056585119511451454, 0.08181579245795166, 0.07341690241329132, 0.04527164029798681, 0.04121736510686817, 0.0726858476897882, 0.0530102200085117, 0.012007266632281246, 0.08376207713398241, 0.03456410598911105, 0.020632584496671637, 0.03252560347919503, 0.05059087603923775, 0.08259394626703956, 0.039676655038830735, 0.010765562596310292, 0.04521999448057144, 0.10294340956475466, 0.09197789514737745, 0.05470048193068755, 0.06455979985936035, 0.003908640679700541, 0.03569326979378539, 0.42245857297412814, 1.556924778607584, 28.023879681864095, 69.73185769973263, 83.80398827214395, 80.189712432123, 71.8635795962426, 63.928303103293146, 70.25201105302381, 53.37623303936374, 43.37653859969109, 36.37069909803329, 20.80869151699928, 34.51066017150879, 61.98465101180538, 63.828765115430286, 75.12275541982343, 97.10574965323173, 74.89037852133475, 61.42923555066509, 37.17566751664685, 31.09323436214078, 25.69716891934795, 22.85450173962501, 18.717524966885968, 20.630863020496985, 17.90860672150889, 4.133753565049941, 0.15850690103346304, 0.08353545300422177, 0.12027385058782755, 0.3604113040191512, 0.38034834388282995, 0.7166624441742898, 0.4139265291873486, 1.0147875210931225, 2.535691213223242, 0.41125824494707974, 0.7260128843688196, 1.1173883897642936, 1.1070786849144967, 0.4033110633252129, 1.4356034176964916, 3.7966550213675347, 1.1945320954245906, 0.8337609445856464, 0.41209698865009897, 0.28907908006541194, 1.0524600479871997, 1.9267922735983327, 5.53508355732887, 2.5195754199258746, 2.616390057148472, 2.780658429668796, 2.520978157558749, 2.030332304777638, 4.2014257273366376, 7.647090640760238, 11.358016133308412, 22.567582322705178, 39.770613485767, 52.460893046471384, 50.43005451079338, 45.15293690466112, 27.725973706091604, 60.846563539197376, 90.3391041294221, 73.18380232780211, 27.331408762162734, 23.003830294455252, 29.01884378925447, 36.708662279190555, 43.95335059012137, 38.941314604974565, 54.65479627732308, 67.43950689992597, 77.57287963744133, 52.43717055166922, 15.591569504430218, 1.6930812789547829, 0.09963070748433953, 0.06511253229672871, 0.03767090278767771, 0.07621616470597445, 0.08931914870176585, 0.02460361657393796, 0.07490588622468133, 0.019403070834795796, 0.042236457398581895, 0.017548218752527912, 0.02917593191077392, 0.047109998507244934, 0.031457200023015185, 0.018568864287508112, 0.03509935630004733, 0.09391378401027572, 0.05885423746921363, 0.03402776017244305, 0.031062574726679636, 0.017266894029753826, 0.026667028432711962, 0.027122153607647748, 0.04062284640366993, 0.07088889653283743, 0.02594003589042733, 0.03147555740490075, 0.027134158205421224, 0.04955622450178189, 0.02904818291896053, 0.004514971740483757, 0.0428339408620471, 0.0097695276358976, 0.029615177998259187, 0.048755995869155855, 0.014553713206682476, 0.11788257608009924, 0.05480221840703199, 0.08677909991914227, 0.026807427451375033, 0.02137343173906688, 0.007036626752045367, 0.042255391261630484, 0.067356901784097, 0.015002653179239604, 0.016532533636857426, 0.08378560369413707, 0.0628034245493191, 0.10189723223447801, 0.02564077896456565, 0.01787628824522178, 0.007102611341378502, 0.0702519633717114, 0.05230490966970402, 0.08359607354167008, 0.03767121305328704, 0.07009433312041145, 0.006991125438587681, 0.023062963962494847, 0.056015130943588676, 0.013520690563675618, 0.07545933878469853, 0.04941100104441566, 0.07225481598007102, 0.07444820231607846, 0.03211669830395089, 0.03226285064292531, 0.064292672661043, 0.049222512771525694, 0.06747616635214898, 0.04933159603106399, 0.019435384423441945, 0.02703336210200383, 0.03694793412221536, 0.036201235883298426, 0.07431458126032546, 0.06296543682354593, 0.022862875203211463, 0.030821109558605862, 0.08131077963738673, 0.03911574461287068, 0.034584146849210226, 0.049272025034071944, 0.010554669124464835, 0.024083113455544078, 0.06106709392981664, 0.043011883934659344, 0.0389518094579539, 0.07433669821869943, 0.05294989824535386, 0.048109306578314116, 0.04486426155293181, 0.026492130559598728, 0.02096410904590401, 0.05786199655924594, 0.11347032332372282, 0.06786907752675396, 0.15463268714806727, 6.937581435326607, 51.41689538955689, 90.22908164608864, 98.63037493921097, 94.52030366466892, 95.39269370417442, 88.2457979263798, 98.75955427846601, 82.6794525884813, 67.5746560865833, 38.049677495033514, 16.00374883221042, 23.761185061547067, 32.69553042227222, 31.6800719307315, 74.82136049578267, 94.08147673453055, 68.56069287946148, 61.07619870093561, 37.2220338544538, 30.855234746010076, 20.28533358727732, 17.46875213038537, 13.257275819778444, 13.248424991484612, 11.864179372787477, 2.312841751883107, 0.3290456725705055, 0.4337544781306098, 0.3093653028049777, 0.27860411472858926, 0.6237700545499403, 0.6116968765854836, 0.7591759725924462, 0.9199698605845053, 0.843007380683576, 0.9124635472413033, 0.6880633400813226, 0.9543346649696751, 0.44440772744917106, 0.6933552303141164, 1.0610343491838825, 1.4000801045087077, 1.0284723029021294, 0.7393840604251432, 0.7075824636605479, 0.6987677334297089, 0.8444579834899596, 0.8023675807541417, 0.8298956326419308, 1.4141570007608784, 0.4489505675531203, 0.1231654494580242, 0.27979103007143546, 0.5621494352817535, 0.5265816277073276, 2.730961754437416, 5.171515143686726, 14.481436764040302, 30.044210187850464, 43.77704397324593, 48.58082171409361, 46.88074881030668, 36.189234564381266, 65.52859483226653, 72.79004343094365, 39.706408208416356, 11.395088414992056, 26.35477585177268, 38.30013652001658, 51.93148682194372, 71.20134230582946, 64.49233601170202, 75.30348254788306, 79.48930263519287, 92.2368174214517, 77.67645374421151, 36.59214827322191, 8.778544895110592, 0.1226575408251055, 0.08524491692021971, 0.08120197216950117, 0.03460583862878623, 0.12987028927572314, 0.07286054638004111, 0.03952782713778077, 0.05136465165583838, 0.06276855988788509, 0.06027212832123042, 0.04601399481837307, 0.033214458249389164, 0.05570719041110528, 0.08957454709396248, 0.00875245973152379, 0.018103220725371953, 0.03251428836055341, 0.07340205562931877, 0.04994149011890254, 0.051695597808687925, 0.014206676334593327, 0.03557576339751963, 0.06775455504295326, 0.03753766094544723, 0.017427743765555562, 0.025180582287571123, 0.015589526324953525, 0.10734703617110368, 0.005767395740540158, 0.05078097692720833, 0.031835722151182355, 0.01994728054400654, 0.0502842148735879, 0.07163082970486534, 0.022658978986944404, 0.05097868889870663, 0.00927539805190698, 0.05883877398446203, 0.04256486013952283, 0.02619381017622448, 0.0248387404492185, 0.08014116255987076, 0.014234757287457827, 0.02456297560955488, 0.059464257961559686, 0.05208592726698807, 0.09341558937223689, 0.009648099827069429, 0.03700942416945773, 0.13902044344332912, 0.16644282116284295, 0.1913736358044609, 0.08038729894906282, 0.2134023102060441, 0.08816448566053184, 0.17587555452219902, 0.10648491146463542, 0.06416555952220675, 0.15726891826958428, 0.10652789665806679, 0.22892449261440387, 0.1130193273626989, 0.15746077732934108, 0.30546426052047365, 0.07182968314737082, 0.14785709911056105, 0.1206793945523039, 0.07584511768072844, 0.13783259347321528, 0.2097888113630395, 0.09584047981808264, 0.2683408654505207, 0.13553987617694563, 0.11789868690914686, 0.1763634299558978, 0.10990311917398246, 0.11989469069146341, 0.22533868018898273, 0.17718299081729305, 0.1508168185189847, 0.13623136245915968, 0.15653473024647083, 0.15729585392100198, 0.21523644727083946, 0.0937504310821814, 0.16686678954189824, 0.13775204698885643, 0.12858972734501287, 0.1765473063794836, 0.21765461912558925, 0.16706949640666285, 0.2876713781827881, 0.16855826571343407, 0.24093733349394417, 0.22439951768084881, 0.1042206007085981, 0.4342437018790553, 4.304714481676779, 44.04888776040847, 99.7774407171434, 108.90545506631176, 96.67005277449086, 93.53876975274856, 88.00636860632127, 88.117716850773, 66.66663523643248, 56.933932612019206, 47.87573252954791, 26.56447752829521, 46.778743651605424, 84.31797565952425, 82.80405844411543, 97.42001779617803, 114.8083476097353, 95.71322979465609, 84.78706759791221, 58.253359102433734, 48.53264324126705, 40.89975795438213, 35.26064480504682, 27.80822384741999, 27.100949902688306, 22.347239255905155, 6.901474056705353, 1.2386809457694332, 1.1045781739296452, 0.8528969629156975, 1.285272819861289, 2.039096473205474, 2.112653293917256, 1.305804711676413, 3.300786042405713, 5.932984477089298, 3.002305929699252, 2.053323400116736, 3.908362407838145, 3.615404992334305, 1.8257583918110019, 3.7770752849117404, 11.625261922036449, 4.89260422606622, 2.433305584615277, 1.7285410987754024, 1.7512972196263654, 3.6659947422242936, 4.2477047924072515, 9.155573902591582, 5.470443387185374, 5.23955600876962, 5.1616788198871, 4.923689499978097, 3.183389012852023, 6.577543154839547, 12.03788055527595, 16.596340517843924, 32.296211565694506, 55.03669392678046, 71.3981354621149, 73.57902034636467, 63.6109519773914, 42.41939790787236, 81.58795895115023, 122.7561443082748, 95.58244228363039, 37.90190612116168, 36.46167455180999, 43.68406418831118, 48.584567577608176, 57.883514896515884, 56.51059904406148, 72.1100378036499, 88.1808199421052, 104.52511679741644, 82.12247602401241, 31.821847961794948, 5.560797635586032, 0.16233429162492677, 0.16970733631282084, 0.18967190937649822, 0.11655617144800003, 0.2490183506761828, 0.2100895928038705, 0.14055376842377648, 0.1611191076376746, 0.17423152983669313, 0.15166867764726763, 0.11645022148807203, 0.13013526376697326, 0.13523321118085616, 0.2722667596272884, 0.12611751564808432, 0.1754267189291216, 0.17462914479115318, 0.20654743206837486, 0.1087873580775434, 0.14837479068627282, 0.09711888138084643, 0.1604909002180061, 0.18150309851813703, 0.10965975602307629, 0.14944832501632555, 0.1627957983122718, 0.1266259375599123, 0.1413809135556221, 0.21965777050823937, 0.1710462741433613, 0.14962331481998967, 0.08463942400750615, 0.12409096794022668, 0.14845591939745412, 0.2476940604467546, 0.15212826911480198, 0.15083917296461521, 0.17496637669542145, 0.18610527979270106, 0.10051059010889261, 0.173127030232741, 0.1404601678011879, 0.12403908080511516, 0.09848372830498604, 0.23800746087105046, 0.17597637169303434, 0.18706868132275922, 0.12718718889499867, 0.09474583976571599], [0.10276534774851415, 0.11158845132036556, 0.05988279477723184, 0.04260740100195812, 0.043407936069753864, 0.05416181486760897, 0.08248420417188637, 0.011957700743580298, 0.02515502367919732, 0.054955872662004926, 0.03452651788510623, 0.06148736976507691, 0.02806714221444582, 0.050301585917270956, 0.037224269697382566, 0.05756266685503145, 0.0322250863386979, 0.05679586263854177, 0.017402868890654177, 0.07158363102785043, 0.06374930564854896, 0.00908808189354116, 0.057524630589590925, 0.04698253296796353, 0.018513229067227053, 0.026507852599024776, 0.020937845636639866, 0.013775711657569535, 0.03334205785405732, 0.03636966797433073, 0.072540199053624, 0.026304756944638588, 0.04229672936602466, 0.008697321510783607, 0.038038111712423064, 0.05177913586639109, 0.01500224619502983, 0.01165574910344496, 0.024858582126457366, 0.029046715860585534, 0.10293649179079842, 0.031155579715907097, 0.06513674833601521, 0.022974509535537615, 0.006361325034841655, 0.3526839896315529, 1.8433123466468628, 24.21263614008504, 63.03603056938418, 88.85152955209055, 79.80581437387775, 79.88244964230446, 61.4425245408089, 50.13040111910913, 44.64881820063437, 36.59396433061169, 23.477240762402936, 36.02903712180353, 67.40822207543158, 105.88928576438659, 71.13978462834513, 59.92409267733174, 67.77214742475941, 38.324867063953036, 42.245938931742025, 37.292656129406346, 13.508775253449718, 5.113857773042494, 2.1278090871149495, 0.564500834913023, 0.13144562651793804, 0.14240788506163707, 0.7848091519648029, 0.8377062973956909, 0.18927173568837105, 0.032238060037695596, 0.042811046324429974, 0.050959716731261824, 0.07174685372099762, 0.04348814164498641, 0.05329138959848112, 0.14734898363390278, 0.04708717674798062, 0.019060554839069807, 0.061457779619001576, 0.1233646093356994, 0.0612466304653114, 0.10413284533687177, 0.03646670450125972, 0.04293823990249827, 0.11380718750578743, 0.05174093872248646, 0.06570469527955979, 0.11977038526486967, 0.0524546530458235, 0.09442517834324991, 0.10718389008674892, 0.08786977163606113, 0.05055250269511054, 0.11383763183989834, 0.1778482922142552, 0.09622861060404009, 0.10137279908503256, 0.14519708861987438, 0.11968762478640965, 0.20613434213784435, 0.4218706771010353, 0.49939571068652217, 3.765743067187648, 15.78866566381147, 33.954177825681626, 35.96338056748913, 26.951695872891335, 33.46077111459548, 59.700486198548354, 90.93610455912929, 55.187116822888775, 35.7254417480961, 30.44835355974013, 28.640211512965543, 44.42149331492763, 47.38934686107021, 47.282870200372514, 64.68406146572482, 68.96795257445305, 83.8744967983615, 56.87245338193832, 20.058334258294877, 1.176067292690277, 0.2156137455735476, 0.06137565116307909, 0.0784714432853845, 0.042777851734670906, 0.03909726274169741, 0.04961409478358204, 0.022295405149399754, 0.07113547725302559, 0.059988913276503165, 0.07910326664005557, 0.04490286089299668, 0.014847972366448133, 0.046153809694993886, 0.017542651208538203, 0.04051837116299618, 0.05808641818622428, 0.11847867675486112, 0.06041433339217498, 0.03853901064083461, 0.008016650953645548, 0.02789052447394258, 0.016384881680771228, 0.04208225922118272, 0.06194809887317881, 0.017825467887544827, 0.04039767018008617, 0.02919028839847494, 0.033311467963240804, 0.047983817545877355, 0.10471249044302011, 0.04844170829821979, 0.06435182230967669, 0.027453831374464978, 0.07312872311881474, 0.035239136702711546, 0.08592484293565636, 0.00455142364033588, 0.0575485018893115, 0.07080439703478929, 0.04534491277750462, 0.051365141952109915, 0.07522186684993006, 0.07474181317393819, 0.021824100197503166, 0.036335757092362454, 0.05668063152341112, 0.011295765345435471, 0.04596131861269955, 0.03775808359346083, 0.04202903526264333, 0.03259804858375461, 0.07033666971349908, 0.009635722719042773, 0.05693326816864072, 0.0100550428596175, 0.028831887569638993, 0.049192803881822095, 0.042212923177548, 0.09683505346577975, 0.019297417733938466, 0.00509608390500709, 0.049092607242205454, 0.08185793495466633, 0.009473371450909445, 0.10977023356263677, 0.026645237061705802, 0.07175132767447541, 0.024697065894161502, 0.02586680363052555, 0.028581112518065402, 0.025650981340497255, 0.044577771482328256, 0.06321597055742337, 0.03561333617976597, 0.006839612878168063, 0.027356337110001235, 0.03264831161246665, 0.08976357928927868, 0.024761966947886734, 0.08127920915402713, 0.037503784537435546, 0.015991634385089482, 0.013512724206873007, 0.015596036157090098, 0.016761965478860566, 0.04287972610684172, 0.056782915752621434, 0.16391765746858813, 0.0643229024905351, 0.08236967402720645, 0.06175516729032802, 0.06554035409804314, 0.186784110302406, 7.068430233386255, 47.861584540336366, 89.58586785101122, 100.10897513358825, 93.90060840114471, 101.85040550847208, 89.6255700818954, 81.29899794055571, 68.19996818419426, 43.087836465527936, 18.515011033704205, 22.217004799073745, 48.799701736819365, 67.36759416518673, 67.58615647592853, 64.95572482385944, 56.992430840769124, 37.27364047881096, 35.64464484491656, 26.0941461209328, 6.670747495466664, 1.0064053547478493, 0.5645088635144696, 0.14430098025308502, 0.3776771178649318, 0.6279616586623654, 0.8744491612718952, 1.2413180042659084, 0.18768806340953997, 0.02222593438120619, 0.16296485859540202, 0.09558053086361579, 0.10642504169335289, 0.0746998468774461, 0.03830798150550935, 0.11928460125120417, 0.1202075303562226, 0.11327370685795624, 0.04969708125797972, 0.33205747063602176, 0.09832873339614562, 0.1818783283834496, 0.1650999456403717, 0.03284032772024793, 0.08673634455208817, 0.015205540074666422, 0.033283256775429176, 0.11606630418569812, 0.029688331734148726, 0.07818702548261612, 0.030922579819396622, 0.07392837335505793, 0.11543689400798852, 0.04087506170054117, 0.029731837867368615, 0.03928566674491571, 0.0731204110648363, 0.014191563335067083, 0.1236925409325669, 0.30082569006950627, 0.8869978653327112, 0.41648713210898064, 1.576107620231567, 10.002608760710686, 23.979453194525934, 26.356493849908155, 22.15438415927272, 38.437952918391076, 70.4017436119818, 90.9438237836284, 44.44764767923663, 26.15577243989514, 24.65330070064914, 35.93872454858596, 56.545013919953384, 68.387708510122, 72.81508384212371, 82.01869010925293, 79.17612491115447, 99.63150501251222, 81.91342938330867, 40.27052740896902, 4.5877630095328055, 0.15703962815384712, 0.029452447516603336, 0.12579856260168937, 0.006726524415200637, 0.04096717611255665, 0.02105853129779139, 0.05820763627848318, 0.08402835397470383, 0.029354279094766227, 0.042144760504485144, 0.04952381898258482, 0.04238308662728917, 0.021332890366113955, 0.012566422716894699, 0.052264502362137845, 0.03360827723818441, 0.014627004838398388, 0.02082258770843187, 0.05418069893494249, 0.04564407394237576, 0.010293303864947971, 0.07819696164299404, 0.03615212581691243, 0.013999497431570725, 0.039768646876778335, 0.029018094815734415, 0.01685687036614024, 0.08879045610346141, 0.04215491499992148, 0.06888314811212402, 0.0771305825741541, 0.02609301790324671, 0.0858773684669887, 0.04362962659328215, 0.024010430863727967, 0.04452245610375558, 0.013413413356418812, 0.04427353498495875, 0.02241122998267172, 0.03394750863193505, 0.020843413808653434, 0.09072147264716127, 0.03298361297516573, 0.03150097428700857, 0.025866621684643532, 0.0412463998391984, 0.006163157241028404, 0.10033835822175588, 0.14047415656668527, 0.1964571348000919, 0.10443906600196516, 0.13499275150318302, 0.15631258007018797, 0.30693729438128015, 0.11059254467968019, 0.12349224724476376, 0.22286440005465863, 0.1289092013311963, 0.24155824775657347, 0.13445504971088904, 0.18540063211994787, 0.0916938374059335, 0.18203202094281876, 0.12942194397891724, 0.22826533524259446, 0.08098766673356295, 0.17582534511964168, 0.12174457086310272, 0.10752779461683766, 0.2526302100910295, 0.08313545551631721, 0.11439762679078888, 0.06499574985355139, 0.122334121486112, 0.10670741404136343, 0.10114342469962374, 0.07641789863907522, 0.18245427328492367, 0.07417900668036553, 0.18686612767557945, 0.11579175359539448, 0.0982066343027738, 0.13397687295031163, 0.1307065355321092, 0.10604855544384449, 0.16513468006685858, 0.10598581284284593, 0.2716441446494672, 0.10490024327150277, 0.318460819581824, 0.18624487633426345, 0.2443409548892129, 0.46447285721378945, 4.482863631940657, 42.087553624183904, 96.37218013886483, 114.24071788787843, 99.88052845001222, 100.36769467015421, 85.61861791918355, 66.55811894324519, 59.18791870917044, 45.510574694602724, 32.05205578957835, 47.10241371585477, 88.5384459649363, 133.26086351948402, 94.24008953955867, 81.36522323854508, 94.87437602012389, 57.403244203136815, 60.26603314184374, 51.92884706681775, 19.05476643193153, 9.149791348365046, 3.7627659882268603, 1.781332156350536, 0.6683898344635965, 1.145390925868865, 1.3364251847228696, 1.5533385065294083, 0.4238938540220261, 0.11148432464969736, 0.2557165638333367, 0.30612009307069166, 0.15223374410021692, 0.16362401596721143, 0.17889328210824923, 0.29245323771911286, 0.10333108069795756, 0.19034861016177362, 0.11351156949756608, 0.5866010619267341, 0.1679790572774026, 0.3093294192466044, 0.2919990088670485, 0.08919740966971844, 0.2881368225620639, 0.15983681434825545, 0.18929254263639453, 0.330236479640007, 0.18003037109250025, 0.24327521933422935, 0.2228780670632278, 0.24972417812433936, 0.37548901753560193, 0.3383676449377691, 0.4876930128422476, 0.29543316652697904, 0.3990282641062814, 0.32706184192530574, 0.3415165420982146, 0.7567048793838871, 2.059550775635627, 1.9525819800553785, 4.432752901507962, 19.30169532375951, 43.56016828167824, 51.07763782624276, 40.511172663780954, 45.327937372269176, 83.80187803699125, 125.13594042870307, 74.79287624359131, 51.63818374756844, 43.02268589696577, 38.19427174906577, 53.462811516177275, 62.076014780229144, 67.98149216559626, 82.59864391819124, 87.36079354440012, 113.50810543183358, 88.02463900658393, 38.01576860489384, 2.927949558342657, 0.32916472263393864, 0.17734290401060737, 0.18675712868571284, 0.17431422136723998, 0.1386817866155217, 0.11676542070363799, 0.20632780998224215, 0.1662151245099883, 0.1375032369528086, 0.14653103155714853, 0.12588482410196336, 0.10751791208261445, 0.09224009640034168, 0.09181907745979487, 0.12234519145661786, 0.15484064937599246, 0.23274987605550598, 0.10281086103209566, 0.2727752581479088, 0.12939830250557394, 0.11667463162373151, 0.22599923184081433, 0.13340258279875403, 0.12914973761766188, 0.09336881204358033, 0.16031866833086938, 0.1006314098354309, 0.17798067220757086, 0.17320066660402283, 0.22695052918166886, 0.1823896154641144, 0.13415321106872252, 0.21686611546864434, 0.15282694130174576, 0.09435017067458361, 0.13958158752610608, 0.10020024022988736, 0.12590801358343134, 0.14021128115634765, 0.18754842090270213, 0.15645845853272947, 0.18240443160456998, 0.13912527491488766, 0.0704947749393121, 0.1402898358121034, 0.17023392983021277, 0.12041975203300677], [0.07283286762333686, 0.04850623971452156, 0.009850519408862437, 0.06021953255478894, 0.019033310837262583, 0.06926286725267287, 0.043829142701842135, 0.06967654707090509, 0.0552912621248153, 0.058239846445259556, 0.08836853317916395, 0.07816812609352412, 0.04702615401437206, 0.02859438690657337, 0.04002516375734441, 0.028603660400896787, 0.053938477255043485, 0.07031436123314404, 0.03396300659064324, 0.03461168387964849, 0.03239061878693681, 0.02903782541022426, 0.0211963237022921, 0.04883720118912959, 0.025604640681957527, 0.09217242019311075, 0.09621564839636126, 0.051726191529944066, 0.07934020231327704, 0.02929902308800769, 0.028627389974351374, 0.023659899673094193, 0.0949820476554094, 0.041643777306401925, 0.006661575002175186, 0.03442550919228985, 0.05257614692973514, 0.05243764206346485, 0.13084213309470685, 0.06099085285959225, 0.1202594711174888, 0.06952083970029509, 0.0394410485281579, 0.3385030892827819, 0.13796466703136123, 16.75007781674785, 64.10148359114125, 86.21864641866377, 83.78107378559729, 76.91110518670853, 71.46075217954575, 59.9498704941042, 43.52753808421474, 37.02823738898001, 39.23019716816564, 41.81977733489006, 71.48387062934138, 71.37748026078748, 55.16367673873902, 57.53471420657251, 33.310281538194225, 25.395923045373735, 26.238644276895833, 27.60611980192123, 7.991595845068655, 0.18819499911079485, 0.20652515423153678, 0.10405991376648027, 0.1446847443378741, 0.003875285211477369, 0.07555551346271269, 0.10208752081399003, 0.226805049084848, 0.32684111667256205, 0.07448404757005554, 0.025204346334982305, 0.0385053793809587, 0.04870889678357109, 0.0698490241061776, 0.026710410076644153, 0.21371170247514404, 0.2715979342258746, 0.0697279132662281, 0.18432718972044607, 0.2884853006370606, 0.16928059469547965, 0.07506834282990425, 0.12407085047133508, 0.10176948707310424, 0.13966735873010852, 0.19467205800596746, 0.45433490927661624, 0.1842267555935729, 0.2814273325906646, 0.15493700791510845, 0.09627911112000866, 0.19513088338557752, 0.16931847008245607, 0.2672281993492957, 0.10147684914690834, 0.1875900807640245, 0.12686397639974473, 0.2649690060605926, 0.1701214374794114, 0.06450646481807194, 0.04908305029535005, 0.015617225191465791, 0.04782514158456076, 0.2628960334245236, 0.7147624848350402, 0.18400820603053417, 3.5646970810428744, 12.75810028276136, 25.207325681563347, 16.685070414696973, 17.41832810063516, 43.45570771924911, 61.79442782555858, 60.243534426535334, 48.179853500858435, 38.130188065190474, 26.282617968897668, 38.19579362869263, 57.558895618684836, 51.480445631088756, 53.72383740640456, 66.5167457826676, 76.99061163010137, 46.56036176989156, 11.639872750928326, 0.07381842441616521, 0.30633772332822123, 0.06348741083075443, 0.0470466353750277, 0.0928742333405441, 0.033233598956177314, 0.04026650443613049, 0.04891354568122376, 0.021473034660542206, 0.03040475034785848, 0.12618608051730743, 0.051144631203985026, 0.06068485819043652, 0.018228263511592825, 0.02205207072679074, 0.059070396837928606, 0.08055481939546524, 0.05405103855375802, 0.09264084465441205, 0.05221571022224042, 0.019089679586731138, 0.019680612998443748, 0.017118816894869653, 0.028003568408049406, 0.09751786763269095, 0.015956125252189177, 0.059739298848134864, 0.031803693930288, 0.08378448520576762, 0.053448023935479504, 0.09983833263357801, 0.031507376866835746, 0.030465403444043575, 0.0162764189524516, 0.03900399153691627, 0.01820135275803266, 0.03127230853292971, 0.01845817798898826, 0.012792160099882995, 0.06966938414881307, 0.02326441061262402, 0.03822604074112831, 0.039959161452228026, 0.05356902752311961, 0.04606202087034622, 0.04234020102528795, 0.012492234762307378, 0.057076986263235735, 0.0454781009935804, 0.05731886703400843, 0.051381440472698985, 0.05163194739349908, 0.025072345555189158, 0.032707258247800415, 0.0454854209636969, 0.0746924388072183, 0.03310141048484272, 0.024197471230441046, 0.05582748536741542, 0.00494285099839251, 0.02802161552432564, 0.05430739838629962, 0.030313568647890806, 0.02421286768249927, 0.0965723465947855, 0.05001517628589946, 0.03556415333502716, 0.04576171440402827, 0.008730595582164824, 0.11689881193301371, 0.05656321705769628, 0.017155432067210638, 0.05544365999559241, 0.0715142924098238, 0.08206484764213524, 0.027814660702020894, 0.014554570267547765, 0.0195370864258298, 0.053533515517389586, 0.00741303543515143, 0.05154510749684227, 0.053614437384831334, 0.035626505231184345, 0.02663656877684257, 0.05919850589106641, 0.030487784702751427, 0.08079769225009988, 0.011089455952206928, 0.022562373384472825, 0.24825042414088405, 3.5781924859169996, 38.65008646442045, 89.40494460444297, 97.0829842167516, 96.77877303092711, 95.86227986120409, 97.14339656214561, 85.71526512022942, 62.811584703383915, 48.53657345617972, 38.61393790091238, 23.59770263395002, 45.85510784579862, 65.31982667984502, 63.407812426167155, 62.263531531057055, 32.64395713806152, 18.522049726978427, 13.710694947550374, 16.669888880945024, 3.3514135451086107, 0.23996578078837166, 0.17717750562775522, 0.0863065998700838, 0.04597823766450729, 0.01956709792026349, 0.05641919635837117, 0.16569686602921258, 0.1894884772839085, 0.272454573742805, 0.03249114101392127, 0.0718183680287292, 0.08848901582701553, 0.08883824466817802, 0.19208364609268405, 0.06523078562872064, 0.33150600990460766, 0.42811604036438855, 0.3550700777240338, 0.6299779407920376, 1.0878948626979705, 0.42507329234673136, 0.5595123154982444, 0.3482253579122405, 0.32650082041659667, 0.39668786549760454, 0.5410180337006046, 0.594870705277689, 0.4063231371823819, 0.36603668764714276, 0.1911229105486024, 0.09030020855847867, 0.1481421604271858, 0.09279246111550639, 0.2893384467930563, 0.16890269884419057, 0.168854879635957, 0.10234697947218534, 0.02053587738755009, 0.09903803888347842, 0.018519051335451585, 0.07458831979742936, 0.09897909607858428, 0.09925957618942184, 0.2331697841685626, 0.6854987228589674, 0.2715175256373421, 0.999050542952553, 3.682746694933984, 9.240300040091238, 11.878396003477036, 22.080878942243515, 55.20484201369747, 61.85563641209757, 40.85514099367204, 19.431717972601614, 27.155876813396333, 28.057472821204897, 58.97353764503234, 86.86127185821535, 82.71048638128465, 74.19814294384372, 78.83443940070369, 91.59550205353769, 69.83781660756758, 24.305194270226266, 0.8072550378499493, 0.22831709214275886, 0.0185718328782147, 0.02376493607317248, 0.0800199521284911, 0.0542122540965436, 0.057326390017424865, 0.07359700968428966, 0.06991968039543399, 0.0849509536619148, 0.05925021299551572, 0.01584748440842715, 0.008891293057991613, 0.04192885011434556, 0.02117701637138042, 0.10237908621709194, 0.030009724770582495, 0.08102806254981026, 0.08181583842322712, 0.08319439832121135, 0.056538962714013555, 0.015823678226180134, 0.04385723131558588, 0.010297175481795304, 0.0650266078751414, 0.060760620455708236, 0.03746610067244019, 0.03729921607901493, 0.06071779997118058, 0.01639704332656918, 0.06572944758039329, 0.04285964311190671, 0.026106499135494236, 0.028045036747390707, 0.03779623860252961, 0.03906392642567235, 0.030706705818433436, 0.03610337581185084, 0.038137557585873914, 0.0470748772063563, 0.04966476383889395, 0.040348004699955066, 0.04873014040171139, 0.021971292500834794, 0.028303851891729622, 0.06864357709644303, 0.12140928482216214, 0.11498317077395417, 0.10388716860043426, 0.23453679146064868, 0.12105532921850683, 0.12190714238151429, 0.08272230429875274, 0.187428267672658, 0.11467514980223872, 0.16370807113426347, 0.1423996419555718, 0.1364651724936501, 0.13050336901459003, 0.13002413505267713, 0.1472369356140975, 0.14347199651022113, 0.10118186699166414, 0.12368191529305712, 0.12578524033268615, 0.14723189475555576, 0.15089825366533574, 0.1460065524424276, 0.12842267421224426, 0.20666265169218664, 0.12294231102831903, 0.13531836951451917, 0.2394429717453257, 0.11752161077193676, 0.1994982433895911, 0.14858217068737553, 0.09251925883994949, 0.14476942769702406, 0.18691443718008457, 0.13939219526946545, 0.19454330926941288, 0.13193227621095796, 0.16209663582905648, 0.19768040867582445, 0.2782176693360652, 0.1121015923338071, 0.2547587394233673, 0.2230037054828098, 0.17468436440873533, 0.4068805733996053, 2.002746397929807, 32.530604562451764, 93.65812747709214, 113.75949013617732, 106.23792955952307, 94.88859853436871, 94.11924915928995, 76.48824230317148, 52.821994289275146, 44.727293060671904, 53.81826846830307, 57.10266513209189, 92.98933198375087, 95.52489326846216, 72.5809104980961, 81.68909334367322, 51.55808502627958, 40.672017297437115, 35.83078876618416, 34.85016484414378, 9.53351584173018, 0.5936180595909396, 0.6866695503554037, 0.28985908014639733, 0.32153914472268474, 0.11101540989212452, 0.1729621068244019, 0.2262264688409144, 0.2762646354254215, 0.3969396019895231, 0.3614285155650108, 0.27482987531731207, 0.4199703500395821, 0.30998779520873104, 0.7038240975910618, 0.7475805883446048, 0.7437988106281527, 0.7565842052140545, 0.8661822145504336, 1.4701476092300108, 0.9315353367597827, 0.7326681659586969, 0.5902614300289463, 0.7510050626531725, 0.6797178233823469, 0.580449253320694, 1.0535067079528686, 1.6617640949064687, 0.8419661139768939, 0.5821477008923408, 0.6987254453762886, 0.7718605500075125, 0.7830680486175322, 0.4552580145818572, 1.0420395361800348, 0.8236670313823609, 0.6123685824774927, 0.5480148066436091, 0.6509252974102575, 0.6842252395806775, 0.278208323063389, 0.23243717428657318, 0.31634742814686995, 0.29223922339658587, 0.5836932986013351, 1.0837297958712424, 0.6804168020044604, 5.831450002808725, 18.24831339620775, 34.819715484496086, 24.562503714715284, 23.582993745803837, 63.56494649764031, 84.13021179937547, 78.44509709265925, 62.00285080940493, 53.86004955537858, 36.85153461271717, 49.332245857484885, 74.05937733188753, 70.45748049213041, 69.40077827822778, 83.01992216417867, 101.1700233336418, 75.52149572680074, 20.38624244351541, 0.34438449949506794, 0.38782220574155934, 0.13862952409732726, 0.18329997306629536, 0.18544299678216059, 0.1522210730059493, 0.13951472337207488, 0.13312017214634728, 0.1335553713743725, 0.15583683946920981, 0.14858889693935073, 0.1921515061610168, 0.1824689362077944, 0.23825927397176144, 0.18170111692480503, 0.13562325718662432, 0.19421456561934566, 0.1308119492304902, 0.22105784215513738, 0.19347614879089017, 0.23311677088420238, 0.1008238051567347, 0.11325365067609858, 0.14004549972953337, 0.18026733740923867, 0.15344361143727459, 0.26887173373853007, 0.19500604169743677, 0.2036000466755321, 0.11231675578822052, 0.20232149189518345, 0.08914614306582559, 0.13346566247843927, 0.13440125501684605, 0.14420874326700164, 0.12015879184247986, 0.08719228944110294, 0.11977201703214839, 0.1219914963228568, 0.12485992103334397, 0.11733276243772238, 0.18187377782117936, 0.12553526584299343, 0.21217851539052304, 0.09783721904480651, 0.18162619352581041], [0.03461451840496833, 0.02465504980195434, 0.061883958161718426, 0.049467216576299364, 0.06270340027948541, 0.03565016968716537, 0.03553076722328702, 0.032455261285987594, 0.06060685894842591, 0.012307151750240837, 0.028834662723144697, 0.02293328059867265, 0.029399016714324395, 0.0276458187539491, 0.07489324577393071, 0.04621054233622648, 0.09240690438497452, 0.030420280865303455, 0.06418635880935096, 0.017867987682562203, 0.0705096830103186, 0.04109011024176594, 0.0446331711305726, 0.037200911676571254, 0.09393655980426459, 0.02858072755888345, 0.028409941662703792, 0.035132125711008426, 0.05747945055425648, 0.02393169043165061, 0.032678499307122924, 0.03377417357818734, 0.04295262703371625, 0.05549715591534492, 0.02221277107544724, 0.015238975982121645, 0.05854310235008598, 0.0954013275763681, 0.02521178696394688, 0.043629561475808584, 0.2651630408100544, 0.06950540302862084, 0.2604705990562516, 10.785189270973207, 49.543477258374615, 91.1109402871901, 81.37865343401509, 81.38106961404124, 66.06891309061359, 60.92752910429432, 49.53153756357009, 39.5565148322813, 40.678128350165586, 41.390991672392815, 54.07676835213938, 62.75915830366073, 40.94570852095082, 32.22901940345764, 30.56517154939713, 27.53826475912525, 21.351537742922385, 9.872802822820603, 2.1543605914038997, 0.34776591966229103, 0.6793568427524259, 0.05920756488077103, 0.0448932541504262, 0.02019415429282573, 0.07607418563096754, 0.04397133245102821, 0.05319957396075611, 0.0883268963004793, 0.19874746190203776, 0.26185427642157005, 0.02182545617312914, 0.16419593124620377, 0.07180257895660978, 0.11667263213424914, 0.04968566271746832, 0.1784821073975294, 0.036308373279509046, 0.08992563752878098, 0.3297278891888357, 0.5915810624437948, 0.12977065188029122, 0.2501573855237615, 0.4181657226816301, 0.14109041301473496, 0.4318896056182923, 0.15010942825146262, 0.0865929022491459, 0.142691153732519, 0.04171682762042169, 0.10017096801030059, 0.02656746764607247, 0.14119061731523083, 0.0558873666300168, 0.07003811758852775, 0.07440023755113925, 0.15025873878790488, 0.045824866862066334, 0.01686782925389707, 0.04262748399689313, 0.030619919547931324, 0.1286931951800662, 0.046106856166114735, 0.1845681396943908, 0.26243978210033914, 0.12436315897972354, 0.3404722416833524, 0.06821315059618605, 0.08900233304067966, 0.18927282353322353, 2.0972506365468426, 21.202258217719294, 27.20553009740768, 15.685150392593878, 22.00581262188573, 45.64811260469499, 74.46604867135325, 98.05124482800885, 57.55483988792666, 22.671723211965254, 24.564664940680228, 35.54526375186059, 41.528823760248, 53.57731334624752, 56.520102946989006, 69.7160348584575, 70.13377512654951, 36.68606550462785, 6.868605084957616, 0.013133167860008055, 0.10468010790646078, 0.01824671282402931, 0.034258103659076077, 0.024975646106946855, 0.02675598656247941, 0.08259285842218707, 0.029365871920280402, 0.07451898117940273, 0.019671757022039067, 0.04040061195771541, 0.025053905818851727, 0.022242543167404594, 0.04730586803728535, 0.015426277776338882, 0.028870852716687708, 0.023656172655342568, 0.062127309821305744, 0.03510401411462696, 0.12725346316132816, 0.017636701907782305, 0.05786596489469371, 0.08496388522607666, 0.026793344840106946, 0.05400043461591967, 0.0802369388721643, 0.005156959166690227, 0.07499447663224514, 0.03937267901135549, 0.013705850184534588, 0.07038474173074769, 0.09551293892605651, 0.04430514760315419, 0.11635593904723084, 0.012307421796234145, 0.040778232017351736, 0.0857690742780124, 0.01905575338300438, 0.03008111267380657, 0.030368554608656034, 0.06634424080050762, 0.034193606716730905, 0.06088869120444983, 0.09384448369664532, 0.07680258202937341, 0.08124350179587642, 0.13297847652387235, 0.046041007078583204, 0.03734097170132784, 0.037530099657634576, 0.07138538279480512, 0.023246702490254276, 0.05303994038953416, 0.014024408695648515, 0.034705246197840864, 0.03801131012639211, 0.02772235476802434, 0.01010606240015477, 0.018494254984562437, 0.01159970402612441, 0.05744054860946152, 0.033716448853092815, 0.0029775455562142477, 0.021750965613811728, 0.054377116217848756, 0.13043966114280686, 0.04632757375797918, 0.061446192539146835, 0.029008254416347034, 0.04311722485468753, 0.04701132638259761, 0.03722860958547362, 0.02210167683510771, 0.028816866500663663, 0.05445084068924189, 0.027450870444637634, 0.03690748084937373, 0.009208532940265874, 0.0460663492671184, 0.012750994365271783, 0.07324984928052272, 0.003240853566826592, 0.03549012625890394, 0.08505979943419657, 0.18839160791568219, 0.07399397346401408, 1.0415791479810592, 28.32732012194972, 78.84855993332403, 106.06337624211466, 94.03261184692384, 104.81241472305791, 91.7762605605587, 85.03369054486676, 70.7163098550612, 39.260901481874534, 30.64951035284227, 17.715490787259995, 33.636587435199374, 75.82621682074763, 55.075419487491736, 35.87891232582831, 24.831368461731945, 12.931650453998198, 6.295449724120479, 3.8140781896729625, 0.25930789209181265, 0.5621375455971688, 0.7994686427616304, 0.03886950863224845, 0.04070344268374386, 0.04424280336787624, 0.05425611263020866, 0.03432538533102601, 0.0347009216315083, 0.05278045108782188, 0.08041456401828798, 0.2870655252087501, 0.038923165430465055, 0.15171111891827277, 0.181585131213069, 0.21870198389214857, 0.12605091962482662, 0.3104160690019208, 0.11023496548014303, 0.17983022296140272, 0.1096332723635339, 0.5680632050479613, 0.14207517307612205, 0.6540433978361468, 0.5468451436008177, 0.644526869779633, 0.6863900201935923, 0.3107116563666252, 0.2361739673201115, 0.1201419379081457, 0.2571435711316524, 0.26838814839720726, 0.034257958102370464, 0.0905558750814488, 0.03611375630322484, 0.023480422509413575, 0.042754532018255804, 0.051530708874305414, 0.08222272304157097, 0.043513246346265085, 0.059660567992156556, 0.028649288597666932, 0.16861938420803319, 0.06781014238273905, 0.22524723993434062, 0.05146912306607251, 0.2027305215597153, 0.2737923471197006, 0.06326645958207308, 0.05067890720261682, 0.06567107168056312, 0.8009943221845935, 7.976695251080298, 7.050396646222762, 9.417711784762721, 23.40376300196494, 53.0055651357097, 62.13254005678239, 72.91975621254214, 36.37278972133514, 19.588444117576845, 30.490646516123128, 51.926736831665046, 66.80702470964002, 85.69792039932744, 78.07100495984479, 81.38263856211017, 86.48313183938303, 60.86945056915284, 18.002582788467407, 0.36799704535834254, 0.05517654811903354, 0.062218378523304585, 0.010027628403247125, 0.03865619911061179, 0.03695633044586547, 0.06465009864299529, 0.08820729465374062, 0.02141604346463517, 0.02172739117316181, 0.002519936101781505, 0.056469654739503904, 0.032956933963202664, 0.041833058480293527, 0.037966195208531235, 0.010516966107271371, 0.017698975279927254, 0.05953616680457227, 0.009208071372291494, 0.04014427127737192, 0.0883324274552926, 0.09248820929637841, 0.03892604209062073, 0.02841454393590891, 0.04033543702755724, 0.013839041273440085, 0.022783864725140796, 0.07949923450547842, 0.04713188563924163, 0.06543200628291215, 0.05343595805067209, 0.009529779462384121, 0.060041627786572904, 0.03764043164048945, 0.026060315524978984, 0.03350533800379884, 0.047603527669824904, 0.009201624742408675, 0.027112730726179098, 0.011546922483361297, 0.0747690552605256, 0.05040474348671494, 0.012019674383824872, 0.07566722440383128, 0.1208994226650365, 0.0984799974567948, 0.17058455295139746, 0.2632229997506065, 0.13130687267309235, 0.14261298212072543, 0.12554581487371078, 0.1857964544286651, 0.16684636563783692, 0.09012528004184847, 0.11397540509220093, 0.10386928810828155, 0.1620236889369065, 0.07428934632409966, 0.17828405834734443, 0.16694787228780408, 0.20374689040885818, 0.11504048947244884, 0.1093583157466304, 0.07018034181167042, 0.13355619874933075, 0.285191766076511, 0.15547008253633976, 0.14251173594065253, 0.2708390781715993, 0.13283196986923296, 0.1873703361038239, 0.13063175002894095, 0.12641828942803607, 0.14534693541786364, 0.09931218344718219, 0.12636395081156684, 0.15099645081547, 0.0949033551038273, 0.14123393192646966, 0.2728426432417285, 0.1128491945564747, 0.1791509481207017, 0.0709773413836956, 0.18033265406566282, 0.3392537022309919, 0.19922294203312169, 0.5936506030059631, 22.620853993200488, 83.81808527054326, 121.19857111284811, 100.87233897178405, 102.29789303195093, 89.44817696848224, 81.51574027153754, 64.26716842959004, 51.87478896110289, 54.67092898584182, 58.56520322061355, 71.7573304330149, 91.24489707331504, 57.70319569495417, 42.46498761638519, 45.12517829095164, 37.56908908967049, 27.895125919772735, 14.393289339157844, 3.5343857397956238, 0.792807171181325, 1.1074103703421931, 0.14709828902156125, 0.34666992363429844, 0.21814128414036768, 0.22908109630788528, 0.2837584155701822, 0.18612478439125324, 0.2666788223770357, 0.350554387776121, 0.4153892668264528, 0.18776079579707117, 0.43532057635245786, 0.4234561113820922, 0.5436031207922967, 0.38605989708054456, 0.7684300082825846, 0.2996943007794119, 0.3734559734021464, 0.8850684269301353, 1.3873343626337669, 0.32343686708519537, 1.08602364697764, 1.3249274920071326, 0.8572267692896628, 0.9067498183538838, 0.8575761666701687, 0.35607923002493, 0.28680447308767226, 0.3054737906542517, 0.6383091776121048, 0.0854140461512631, 0.36311786201211715, 0.12208708111316928, 0.12453582753697712, 0.19277314054629496, 0.2547451337018321, 0.16092588494141258, 0.1504625947845559, 0.20874169174461596, 0.11823916702621406, 0.32458204595792683, 0.3428181254815671, 0.536282874884144, 0.5281337831289538, 0.44902570545673376, 0.5488382592316597, 0.17575339414179328, 0.25812946500316747, 0.39637303400424223, 4.400094266860716, 32.25426377788667, 36.00132557653612, 22.350669368620842, 31.40099333178613, 65.80374517748433, 103.54956842237904, 120.7610385648666, 69.95726062405494, 32.924230098724365, 30.816793557136293, 45.875496325954316, 56.5735609300675, 73.91368481420702, 74.93734498177805, 91.4904688250634, 95.99026679992677, 61.26178172326858, 13.860715800716033, 0.22189375133283679, 0.18715157203616636, 0.23241406907477688, 0.1257549875205563, 0.09585299003388613, 0.31053827534760203, 0.15072712494480997, 0.21390982813412146, 0.12531772751601475, 0.2079939286434843, 0.09802447391613837, 0.14561073013371037, 0.07271525014432208, 0.126028404300732, 0.2715339505624387, 0.1304035324362978, 0.2264741144233173, 0.1871899530411728, 0.1731652426984041, 0.2659316108592095, 0.1615017685558527, 0.20028716073401515, 0.19557933593469282, 0.10640567499062709, 0.15660475068275007, 0.2250553961963423, 0.06572912582346509, 0.16678026757173, 0.1185787201768929, 0.15937941389218455, 0.1829545133777203, 0.21285950626817443, 0.16075310147097036, 0.2891161587209471, 0.15975176326690183, 0.12433087603459436, 0.12774512306937288, 0.0728816444414758, 0.10596113715080485, 0.09738512757805087, 0.19995680829930693, 0.19294215486414973, 0.14740034216834655, 0.22626688763979944], [0.026253174329476974, 0.08968641891354516, 0.04925930797452888, 0.08180931901499149, 0.0041920709472540165, 0.06147264172473262, 0.024926785019136248, 0.015261842749051511, 0.035992047914694396, 0.05243999012295277, 0.032900369861313415, 0.03926733426088768, 0.05304613037996235, 0.019242464331910014, 0.028573415249646194, 0.05368407094670881, 0.03979454447905864, 0.06480539232612618, 0.03975390351467556, 0.03430955795451038, 0.039242934360499346, 0.02478468528528127, 0.05059461071786862, 0.07341447391457136, 0.06676912082419281, 0.025574223160923972, 0.053083461844512535, 0.05709698115805945, 0.05193037311396292, 0.03727531413577738, 0.058844550287411104, 0.04050392274474425, 0.02692380003751286, 0.04937190757763963, 0.019901077781293183, 0.10603792980433473, 0.08185405088889022, 0.09159365608807533, 0.10278970934450628, 0.08701430423365486, 0.21681907767009354, 1.4011864580454365, 28.121538854414418, 84.09045465530889, 82.04471895771643, 71.66675506099578, 79.33724018835252, 55.360866054411865, 45.185939727290986, 38.45746670999835, 33.8054415487474, 48.13610730632659, 46.18186873774375, 69.40503797223492, 58.78647588914441, 21.48073277165813, 25.311068450250936, 42.585043522619436, 36.45337481652537, 8.763982115253325, 0.6063211456902566, 0.22872576940684552, 0.07573701501373323, 0.31902950196977586, 0.4453792495112266, 0.0800204883900381, 0.02603505760611546, 0.05630264374157114, 0.08568347927423255, 0.040898197555854436, 0.10474121107930139, 0.12054111568197129, 0.3026886933272885, 0.1841359588527872, 0.003242605035343478, 0.06734524192588945, 0.07018535968757446, 0.06006182186425694, 0.22055346518754962, 0.009943711132021442, 0.17160505867533146, 0.26162751439598303, 0.0807201641521627, 0.14188222617151278, 1.6910490009092516, 0.3805927565741924, 0.8167294004271108, 0.38029860945478566, 0.4138501655430563, 0.13778371706364617, 0.5702335014939308, 0.1346785482019186, 0.12536388431345263, 0.04209042188801593, 0.10492956911724423, 0.06577098486764778, 0.021683511572078835, 0.04292502488580443, 0.1178030331709212, 0.049104784209761894, 0.07011612066097798, 0.1342311681758973, 0.04306598123343241, 0.04307767556559655, 0.06226394926348041, 0.03043527129076181, 0.068129884499696, 0.05297417940211393, 0.05002883563358938, 0.19604672617729635, 0.050438727147036025, 0.03159064870898522, 0.13067377761246698, 0.3188823518012801, 0.7868543615744961, 3.497094050530465, 18.269800140011696, 25.54324334667575, 17.70305295144358, 22.839410420387026, 50.50410493727654, 77.17779497946464, 62.376558549942516, 41.52417182922363, 34.507263398939564, 22.49523812724698, 35.82810194261613, 43.90305403740176, 61.347662018191436, 53.81688779400241, 70.42179476830268, 63.12879070158928, 30.704188193044356, 1.596378674430232, 0.20395915805091783, 0.007550632487231446, 0.09974119268477925, 0.06722826796073107, 0.15987795326978932, 0.07060483113051423, 0.060141525651899085, 0.08061594555094358, 0.014835807847820464, 0.02120030927471817, 0.0716034420615723, 0.02979822130122733, 0.11982913654778274, 0.04022736117363938, 0.039016314061178316, 0.06648397523789637, 0.0663365416168686, 0.057117175235743486, 0.0268418918318686, 0.048419886283696666, 0.014384407775416492, 0.051894343998884006, 0.02799790318784935, 0.031475478880888516, 0.04171338788564167, 0.023096261974123698, 0.01540380554469002, 0.060805754525767225, 0.025880436165138118, 0.061431158063632835, 0.014989719699857938, 0.04312198609113694, 0.06063265695927605, 0.01422306391290359, 0.07409996938921752, 0.056565534473667224, 0.012755332338143022, 0.1362859692064024, 0.006580269133161393, 0.03067884511584717, 0.0835848733362171, 0.029329093954255505, 0.028334480086942355, 0.030711836692306305, 0.03820924809382808, 0.05653345071139836, 0.03729675693677799, 0.06460064766748298, 0.01724440360351676, 0.035537945467137524, 0.021175848087295893, 0.01952261310972033, 0.08310982221437078, 0.014200429845180725, 0.0281031119577106, 0.05503249294575184, 0.028141973682889537, 0.024745557344548648, 0.04129196291849498, 0.05767356574295029, 0.02119775437149069, 0.04854049150561614, 0.05078407575286204, 0.02679624639812016, 0.031156098740475795, 0.004178564817148952, 0.09783803109800625, 0.08413969719361875, 0.03890005638822913, 0.058828041092642856, 0.017745260397092472, 0.03961437975146598, 0.09037799712631012, 0.009255513282222374, 0.04446061365606804, 0.07542978311257978, 0.0037207810777134353, 0.034455114660123666, 0.006244330959875258, 0.05523180604101189, 0.10702544778224923, 0.11679183541526718, 0.33856713423325174, 6.669804165440222, 53.006290774191584, 101.0757609336607, 94.04333560697495, 95.04401853007656, 109.17540827105123, 82.9908730906825, 65.23502111434937, 64.25184372932681, 41.38843428704047, 30.205800071839366, 31.423107654817645, 71.55986262905982, 77.25129235175349, 25.6437325093054, 15.714837831835593, 17.360639841325824, 15.661292576020765, 2.3586601836066095, 0.3700177095109417, 0.22117854696848702, 0.019543054250759945, 0.20615320322254013, 0.7186913514329542, 0.1038553529689389, 0.10594576176616455, 0.007187753874478081, 0.16082316787252504, 0.005570776401943858, 0.11447981270330568, 0.13974827293667103, 0.24771604717018145, 0.23876573469850326, 0.08232439823088147, 0.06908715732635991, 0.05115185541311099, 0.12668328690192393, 0.07407904752800543, 0.15631146158181852, 0.25771219223257036, 0.17642643302679065, 0.14643317148570092, 0.4489909557084884, 0.08188539154587254, 0.545285020864779, 0.22924309326035364, 0.5106725555754478, 0.44041558198871156, 0.2926209803310133, 0.5331892892718315, 0.6929923497861432, 0.7777860868842371, 0.33112026931297395, 0.3001258227854006, 0.1757037363225414, 0.07498331473118837, 0.06821365621421607, 0.06696628887326488, 0.03208374120144835, 0.16481451660154328, 0.0978051812478131, 0.012868308281946569, 0.0886380582326843, 0.07111755079559742, 0.030599131752105973, 0.027244559136189284, 0.06239957746959502, 0.06592771879607631, 0.15492914785300532, 0.08975220288360312, 0.032510741373463985, 0.12933905326551007, 0.3110019117593765, 0.6031738726362106, 1.3351890252482508, 5.941965233895087, 8.612101078033447, 11.166331864172413, 22.065724865082775, 50.26796256342242, 67.50898776515838, 29.69702159204791, 22.437869541106686, 23.272249852457357, 20.51179555154616, 49.45979741311843, 68.04087685000512, 90.77142776981478, 71.12998654765468, 84.08156656449842, 79.68088688388949, 53.93362145270071, 7.637153806224947, 0.15850834127876068, 0.022084072134607745, 0.05369835465605702, 0.07373002553058249, 0.052955348960935116, 0.09839583503743334, 0.015273974708942397, 0.07704056724305115, 0.10169364436860047, 0.0460490586626674, 0.1624355224832412, 0.04974009709492807, 0.009119892736987002, 0.016453747239504612, 0.01279048619776844, 0.040078119585110296, 0.06486982798143741, 0.06926164917287327, 0.03882590673803803, 0.024710803765863664, 0.02285780944681216, 0.046100053305347125, 0.05142061437870707, 0.0645701190637004, 0.06525369165765663, 0.02361692214054206, 0.008519805532189147, 0.017070434612011718, 0.056252997413638144, 0.05138861871654949, 0.01562720635950926, 0.03766436805768359, 0.02317777181404733, 0.027739162737083052, 0.03746933356348065, 0.021133994788772637, 0.03092317736797756, 0.02197335902301054, 0.06084279104646656, 0.03889672007531889, 0.0551720665046765, 0.020007449089579528, 0.09680752792666036, 0.1490162973923068, 0.18664074460825614, 0.24335329901547204, 0.1380748917619067, 0.12108549010008575, 0.11531887816325312, 0.1448902397626831, 0.1268927353404222, 0.12117093954715999, 0.1558639896252463, 0.12397630756059963, 0.1548140814467784, 0.08191988082422365, 0.13221785846737125, 0.09249403156460294, 0.2235320916459445, 0.16388422539157255, 0.16839059971032605, 0.07378177476986762, 0.17976012591633106, 0.0956614297484198, 0.19938674695309133, 0.14747511234975633, 0.14160752236362428, 0.2629919476326435, 0.15199880025559856, 0.1945251989508829, 0.11263626807880019, 0.08271284311288789, 0.18031126489081692, 0.1250297857087947, 0.14827743623285525, 0.11597458813940326, 0.1367646515850098, 0.1735510139335548, 0.15147262042568577, 0.1495588561820407, 0.25326980157725276, 0.19390377907022355, 0.37148066165466465, 4.191069199192909, 52.160965088875066, 117.22069940259381, 104.2981057013235, 92.77239353426042, 101.42452239990236, 74.28991071639523, 59.69766993676463, 49.602202984594534, 46.53474084792599, 69.4146320896764, 61.44539179340486, 101.66777995324905, 86.37264651636924, 31.591563647793187, 37.84768719826975, 58.82646445305117, 49.83762756470711, 13.87192201229834, 1.690558949785848, 0.3737484657716367, 0.3272247735050417, 0.48001190887824186, 1.0756994783878326, 0.27077825079041146, 0.2888243098653132, 0.1719378472696389, 0.375870130956173, 0.09228501213534225, 0.2826888036103018, 0.25745898485183716, 0.48865718046023005, 0.5116286333049498, 0.3286570208447595, 0.3355216589425841, 0.2647083829487524, 0.2806000189194756, 0.6310090338510852, 0.49359562836827775, 0.975022103276945, 1.1350027736156219, 0.7868915628040991, 1.0243913831730043, 4.0887071048059775, 1.7165472262328672, 1.988799920485866, 1.6247348367206513, 1.6132956118352952, 0.3917541979782043, 1.358073603722357, 0.7818912149917695, 0.8877112464078012, 0.3490967369608341, 0.7167784605295427, 0.412236447295835, 0.4281111680451901, 0.27545956894755363, 0.2999978248150118, 0.3152363248650105, 0.584159754216671, 0.5041088368142805, 0.25029561842881864, 0.2763777406465623, 0.21501575266161274, 0.12255974970157109, 0.11951394499309602, 0.1774507232250706, 0.2119178003481319, 0.33272611217633374, 0.26817612590328344, 0.3606290568507487, 0.31513391423129267, 0.5371785848852128, 1.354858363347669, 7.564833635284056, 27.68253149524812, 36.59014394206386, 26.650463727212724, 32.54285412449991, 70.66109857251568, 102.32043881570141, 82.68505373308736, 57.548344442921305, 49.39572549635365, 30.200469570775187, 46.55874967575074, 58.28579710375879, 80.82058645063832, 70.18545627593994, 91.91131561033188, 90.02501641550373, 53.4803484332177, 5.861177156048437, 0.29327111318707466, 0.07528116971614861, 0.24593359039675808, 0.1634003489368385, 0.18448296603896927, 0.16253819358685326, 0.1662754922384216, 0.16912058957161444, 0.12268808475064656, 0.1606612628506076, 0.33905868688898705, 0.13039855286478996, 0.25643129322317343, 0.11386282081084867, 0.07693248755869365, 0.1529826716549935, 0.17100682061526085, 0.17479560037534084, 0.15997930670217161, 0.1409959237301542, 0.10439279429133862, 0.12031466775243321, 0.09898183101247396, 0.1389479562039337, 0.1995173189789057, 0.10556228879478671, 0.07635416778465433, 0.10504125707572508, 0.2817332468205883, 0.1696434905452113, 0.09377200411812914, 0.11702907752365836, 0.1872273534536362, 0.13844995308787594, 0.20888559370031282, 0.11147563721263602, 0.10215801622478232, 0.14574568418245162, 0.14055565300007022, 0.15772353016561078, 0.18229786877430257, 0.12537881536709686], [0.02155492945964779, 0.022430606261496584, 0.03948651584646395, 0.04119930841449288, 0.025533436639835278, 0.06256084280809568, 0.024520549660308227, 0.005035866521328929, 0.05712950542088478, 0.08694700340950683, 0.05170778626756323, 0.01909334723266863, 0.036504733105820995, 0.030201277395169583, 0.050794295365771944, 0.03958097831796735, 0.07699082515412763, 0.015549501103739587, 0.04656681152541311, 0.08183414792461742, 0.032288855497515014, 0.01747897014983239, 0.015554091885625837, 0.03331941612545521, 0.025737273484288205, 0.09272972617538706, 0.06335392000994856, 0.07534152212282343, 0.010773156442859722, 0.03551005986669371, 0.02884184288221502, 0.03523352127822657, 0.014316111994576792, 0.07844659139312084, 0.029971623387668404, 0.025922618881468813, 0.007060682870477679, 0.163245415315032, 0.16453688633778404, 1.6073545693389832, 26.13359928131104, 57.593683119743105, 80.53595573671403, 65.65239660201534, 81.01180984127907, 64.48336947348811, 52.317871662878225, 33.35439643552227, 43.114794915722264, 38.11821699142456, 46.313625074202015, 93.78215282194077, 65.72335620080271, 29.940496836939168, 16.19471138523471, 45.11357199761176, 31.24936430684982, 8.699974917596387, 0.05474252866641168, 0.4751201923335753, 0.007242438666928079, 0.2649013145316032, 0.04210866244149305, 0.06354538836486398, 0.09829658068596356, 0.09711496667155335, 0.03576360432611358, 0.05256977690864475, 0.11214702900859619, 0.06305786533161037, 0.049737680087526964, 0.16238103831006637, 0.23169892599746106, 0.09362879930244339, 0.060733458808352875, 0.1474013380826481, 0.018650925710737225, 0.03232802940352309, 0.07178970867948187, 0.07022200933387203, 0.035563571108204704, 0.18593068835475754, 0.12276953521875605, 0.03773811168127483, 0.027923776520295974, 0.07572800581974369, 0.020556017839079423, 0.20985702383181742, 0.08129691344595726, 0.03346181654882047, 0.09905890711853582, 0.05131586334638057, 0.021895141445941502, 0.06001106087839412, 0.047166263834843715, 0.07056822744949211, 0.061446648361461784, 0.05013836322412376, 0.05551577951278418, 0.023741225651915998, 0.06505612524286394, 0.1310375774459493, 0.014696157680103376, 0.032093577770396106, 0.054501187987625606, 0.04727073524507785, 0.03397499969709785, 0.08906368136165604, 0.12771366749920193, 0.105932240314301, 0.06815545651460848, 0.04576891563051651, 0.052680396174471227, 0.33584197562548423, 0.31232457788240525, 0.36771304124305326, 0.5036030655666706, 3.5597419017745606, 14.311419667736178, 21.031635115223548, 16.76859336514627, 27.116100057478878, 64.79828872988301, 67.97062720021894, 63.648720479780636, 54.26918414331252, 28.759790851223855, 30.83836267071386, 38.56209985671505, 45.926698946183734, 55.820101076556796, 63.85621386189615, 82.06361693720665, 56.01165786866219, 22.617604309512725, 0.2203825816151596, 0.07142790833548193, 0.02750329958695558, 0.0026209040961769083, 0.018023110911129944, 0.02811280488517256, 0.13782113279786803, 0.07601756407248397, 0.042349328962905754, 0.03444919280046898, 0.031032944360988277, 0.03608003311279801, 0.04527300393449203, 0.02878278899457186, 0.05215050464856529, 0.036851529617823904, 0.028383827640584884, 0.03093417839057023, 0.025817063456821828, 0.03464568669216768, 0.03291330525591489, 0.019371607603745598, 0.0752441217041304, 0.03312159690164751, 0.04889365803870944, 0.04138663989461718, 0.020184170251952547, 0.059408777874083295, 0.03430944687176136, 0.016870079637174646, 0.032125008442709525, 0.014015966406722945, 0.016874124581414848, 0.01932994008154398, 0.02771033676371219, 0.022093968075369636, 0.054501743401370706, 0.024226638112938213, 0.04121623895761948, 0.11606059683066224, 0.0309396501735694, 0.029866989183750366, 0.04942783199611211, 0.03508739000667007, 0.027927087935348673, 0.0637880084104836, 0.010305132262498863, 0.05347225912696412, 0.023145626764744524, 0.032352184155775655, 0.04369980407758586, 0.04710826714853606, 0.04448418618149815, 0.028097396941795468, 0.02295944633172645, 0.034916146372955655, 0.03412413403331753, 0.07631846808738287, 0.006967632394779715, 0.020413885546487667, 0.046967107787608146, 0.01273422565821919, 0.11016263911921172, 0.011615974776026224, 0.05140696269189639, 0.047412825402833765, 0.03709274389210247, 0.06132324308817906, 0.022545073203922763, 0.03348622794052766, 0.04402950150711883, 0.036310169755691485, 0.014881063534337428, 0.023897699110450286, 0.012001211664849713, 0.018587955198581183, 0.032900320065598336, 0.06594566823614222, 0.07241120516893364, 0.08626985063235607, 5.320556875198118, 52.28391962666666, 85.82913152633175, 96.67052345891153, 81.79206340543686, 106.50491745241227, 87.25288129621937, 73.26956887398997, 55.2106902676244, 48.14072393601941, 21.44079323737852, 20.45009078518037, 103.6494476564469, 83.3658673686366, 37.20148063475086, 14.052263767488542, 16.497259486106135, 12.246038779135674, 2.480318868352521, 0.19895254363936765, 0.3724551254943494, 0.02883605508794708, 0.22191319464435502, 0.20445642572256828, 0.1642482856949491, 0.037482138723134995, 0.11299102041389673, 0.01680453698481283, 0.05568506962229168, 0.057947204688624035, 0.05984215764328838, 0.07984821819850514, 0.0847030399487384, 0.10353390247591081, 0.16881896543406671, 0.029569097809613715, 0.11933628154257614, 0.0603341393082613, 0.08991437603629406, 0.011457212629818149, 0.03094596082284566, 0.06899646017700434, 0.1982630645075152, 0.5038757315806804, 0.04645854414951417, 0.4701426126543553, 0.376062817390888, 0.528988492104315, 1.253419741988182, 0.42778171959423256, 0.2537242908992114, 0.19242729781375778, 0.12272635084246436, 0.09295178442111901, 0.0823875468584799, 0.11217208008372015, 0.14896291638574294, 0.1236096042538843, 0.10379380546510221, 0.07049947105828794, 0.08316668126011088, 0.12390781930016896, 0.1474403166362355, 0.06415766498614704, 0.05761817758602481, 0.07692620563771456, 0.10079039606235682, 0.09535158548744456, 0.12852958944295684, 0.09972332751438504, 0.02621044577550023, 0.0013217403536527267, 0.07295908060886207, 0.12264155257012575, 0.29522681308369486, 0.17874858342111113, 0.4216922705452289, 0.5519216099093037, 0.9006293887092222, 4.118343062939183, 8.826639036978445, 16.583204500136837, 31.168598782631662, 60.85852284585277, 48.23483336356379, 40.24553798860119, 35.630485088594504, 15.67960023880005, 32.49128672384447, 56.964472186180856, 69.87383181048979, 79.4528010583693, 85.60587806086387, 96.0130165469262, 79.14865263046758, 38.69966522339852, 0.7890723393328729, 0.04680652809779971, 0.06413190911013274, 0.07056666463012658, 0.042007305178671114, 0.03807059767085218, 0.04074226801974639, 0.01441286985702332, 0.04229998523970285, 0.047549855549849813, 0.04746467040310945, 0.016825477998223037, 0.07696211983960483, 0.035725545078035326, 0.013491476758293087, 0.06381503982289184, 0.04597753669405657, 0.021402755669588526, 0.05053757547190593, 0.037465637189246, 0.047114721439298124, 0.021323023153649225, 0.01880594934787481, 0.03811514568364909, 0.050876247621471846, 0.06818813782545828, 0.027992224561110623, 0.012526987383382456, 0.03536531904471978, 0.050032095337707194, 0.01971657316560947, 0.015755580670590845, 0.01968704430656808, 0.04938742851898555, 0.09687793906778099, 0.044862564668179526, 0.039285241566117735, 0.017434627065555226, 0.009785626016016449, 0.0646284796417721, 0.023715464030242255, 0.09886724724163932, 0.133717245752773, 0.1870187783553716, 0.22413478833773445, 0.08426898985259956, 0.08688103557834703, 0.12162869240367606, 0.17624274046430666, 0.2006192904927077, 0.18564340538315235, 0.12661896615980134, 0.13472250632701382, 0.1466898109403349, 0.056280538274516026, 0.14026322191761387, 0.11692228486701367, 0.1731168106198311, 0.07182202992900726, 0.22409971683256089, 0.18203500868572345, 0.1171171393305544, 0.1466688201312096, 0.11035203137585234, 0.14411236940612718, 0.20078804434066821, 0.23023540694867412, 0.17473982917445322, 0.1574710888728019, 0.07268868987598727, 0.06211817805324832, 0.14286228245304478, 0.092348896207348, 0.1411182526499033, 0.1448722366964625, 0.10225896363056476, 0.12378926719388655, 0.1532369209153037, 0.3540418957990985, 0.22243416507638272, 2.8334576997064778, 47.668756900295136, 91.80989880715647, 108.93512387429516, 85.81607787839829, 105.85366279848161, 85.57314980414607, 65.64189641706406, 43.6797966495637, 57.414379812056026, 49.5773430024424, 58.68274488756734, 107.47140515235164, 88.07918348620015, 40.163768337618926, 22.644756917030584, 62.17504678233978, 42.665201079460886, 14.504294376219473, 0.5356063273164534, 1.105322688817978, 0.38002998838501595, 0.6886471603666583, 0.5543289033155288, 0.28215603542424017, 0.1450937893241644, 0.1741540477040314, 0.2240770406300022, 0.26204628869891167, 0.2801453917016906, 0.2468544127599847, 0.16883568147257452, 0.22901870610733188, 0.2761754627910353, 0.49515893803008143, 0.24234028563143747, 0.5021860480548874, 0.21513556881297022, 0.2495970381724258, 0.17616996211150002, 0.22269222945455583, 0.2676771268729241, 0.24455418780205712, 0.5565330914912686, 0.1411339114870756, 0.7123759677333217, 0.39826098108483904, 0.32940619354767187, 0.979336281457255, 0.5429003423740787, 0.3486940505043153, 0.3210026993145866, 0.13451020804143723, 0.22410157076533765, 0.13103115762914383, 0.1502046529804507, 0.22927142319179353, 0.16143421492268964, 0.29070061240946093, 0.32320483437468933, 0.2874979971637649, 0.23915941196103252, 0.2760145843269364, 0.16056648245261562, 0.2738147781741235, 0.263349159109977, 0.2532574828834303, 0.18096653053597098, 0.4410600764376502, 0.28644392146698894, 0.30542270791146064, 0.14578519899758602, 0.1994543925168053, 0.311305895447731, 0.94517286626562, 0.6876550458611981, 0.8166842931701291, 1.0589779240469779, 6.603725466036028, 21.57896068788344, 29.042882034855506, 27.77138690794668, 42.83289809380808, 90.65627482629593, 94.04840330923759, 86.41117203620173, 75.29342559076126, 44.15000646345077, 41.21146086723574, 49.032855264602176, 60.70797443389893, 74.17220038752403, 82.6811941208378, 101.65229443580874, 85.39953785557901, 37.20845853128741, 0.6175456820957123, 0.17757948728338366, 0.14774494383844639, 0.17164759187688752, 0.06945599801838398, 0.20830892867618994, 0.18003202584241668, 0.12215273484828011, 0.2644812225574448, 0.09293984877125872, 0.16366811198813302, 0.13006182657855173, 0.15219792182887756, 0.08677465660918145, 0.12884207670727085, 0.1496976253486449, 0.1591485149918064, 0.1502170789265825, 0.12887606036759194, 0.14698198155289696, 0.14688505610871702, 0.06693517804265985, 0.16421790264787214, 0.12394735709794107, 0.17331726518609833, 0.1625664622312592, 0.14156695034715439, 0.22810851704449425, 0.22305104971653034, 0.10595097882492889, 0.09555557171904272, 0.09359237182164386, 0.248015710122643, 0.15898190619003388, 0.11208768783798141, 0.0799465379227073, 0.11036788939588493, 0.08626752172506626, 0.07954951285594895, 0.2561928866611373, 0.1122697716158244], [0.06393427757786647, 0.03721969615247461, 0.006078395357866201, 0.020858498079882517, 0.02147856198491589, 0.01828930348217968, 0.013691548280598176, 0.023369973698150248, 0.0125660827653783, 0.12538142006603942, 0.04746780753315938, 0.07199937928347819, 0.02257016832910238, 0.10028813349744005, 0.010700102298400335, 0.02256028387965935, 0.07313717306861955, 0.025620745765345714, 0.07500062065739786, 0.03899258065728411, 0.042853004960042816, 0.04045760889928188, 0.05837920549956541, 0.04874638529614576, 0.05880682045714029, 0.05477101947631567, 0.04713509554764436, 0.027329217597481706, 0.08816665368935755, 0.04099882320470868, 0.07181188692488978, 0.04707562031164285, 0.10517458701806684, 0.06699209071455464, 0.031704043128317407, 0.031673757757450786, 0.03877107399485765, 0.24841919331060303, 9.404948392222005, 49.67888532146331, 88.82022903811547, 83.85479865535613, 73.43306110751244, 68.88512780589443, 59.98384214216664, 54.32032792798935, 37.55035192735734, 35.991845207829634, 35.2292933002595, 85.1893223485639, 84.03165832642587, 23.018770602441606, 12.86607038590216, 30.459342079777873, 44.877280573691095, 6.823815049663668, 0.3825918476908438, 0.5103218405237121, 0.06042414314804539, 0.670056596638695, 0.19052312499092472, 0.0222168619849629, 0.0406698382369453, 0.14524906002465757, 0.2087004762142897, 0.09357524209565694, 0.06950908025065738, 0.082930710857674, 0.08152146913832234, 0.020126347850647666, 0.07820292180704494, 0.08965711605044142, 0.13216493711356195, 0.18561447790313154, 0.06087623844524065, 0.05530826927673432, 0.10611185728902779, 0.022762450652437347, 0.0823642271420648, 0.12867494696570983, 0.2023579730021377, 0.22912338436130555, 0.10827895914835316, 0.2933099691665942, 0.034359016590901924, 0.1916249126436249, 0.3084016254832668, 0.14126410046892782, 0.2597615387170546, 0.25385291706169805, 0.19196545404772605, 0.5254459176813403, 0.7886506232523149, 0.42994196496663556, 0.21082762658836382, 0.17712326660271616, 0.030825374753124295, 0.036509348785564784, 0.14003803803315087, 0.058739125097711245, 0.746510332870868, 0.93393815621253, 0.06914950156163785, 0.15723029211644204, 0.04129841337881742, 0.08158251102412901, 0.015722410021079405, 0.021593764371749376, 0.10614302174578752, 0.012480065455630183, 0.034516018650103966, 0.008442143368865214, 0.023435238643639514, 0.008763546939007938, 0.0789559785757334, 0.2518084122528953, 0.05876115012553431, 0.3912696933313724, 0.5813983443283266, 1.007973996381606, 7.509266887941669, 17.29964110159105, 18.97410288933785, 35.06132956474058, 40.66382346614715, 60.787986863044004, 61.2391378802638, 32.58842814353205, 27.95941160571191, 28.868322833891842, 43.84450089546942, 40.92295877395138, 47.80011315499583, 68.33860828030494, 70.15153561868976, 36.247979902452045, 1.4200132220022141, 0.14726947902912094, 0.02816520146875372, 0.10801257505532234, 0.037524062884791244, 0.01288994835058768, 0.0407356834940372, 0.02935180080033118, 0.06079639676177214, 0.05714065583062269, 0.03835984182754352, 0.03801185021837873, 0.08516520547169833, 0.05982719211568756, 0.012454621760445017, 0.014852423337288203, 0.027527205360632752, 0.014016291994090765, 0.054677288618779955, 0.019425909831038406, 0.024687156546860937, 0.0736775025424938, 0.09101310699817636, 0.022777144218825048, 0.02187996907460113, 0.09582788533260746, 0.04122563502601078, 0.025360034553394206, 0.044271543156355626, 0.013156917543270657, 0.03452946349317509, 0.03333193400213796, 0.046454893740554976, 0.060464715164515286, 0.0418574124154064, 0.008439153710740709, 0.06755335737139949, 0.03421622163225566, 0.0500668527468318, 0.06466121457877659, 0.031146156834438447, 0.0543968812862952, 0.042104510244943445, 0.06272747842294556, 0.05321909005062715, 0.04166416673650665, 0.040899844644891645, 0.05594686101821642, 0.0542825005287605, 0.05623001094547011, 0.005022976613197957, 0.042994283064599, 0.07336919045736713, 0.048883959365588044, 0.03300076185335075, 0.004129899081759035, 0.08821779005830327, 0.042305949234193375, 0.04447244205361894, 0.06165097167174663, 0.03190421998771208, 0.025722246669653445, 0.10610939048591161, 0.003756585154464589, 0.04906693563586281, 0.0176822496653204, 0.04688479930102345, 0.016960018359485175, 0.020870901043376616, 0.004574151553829471, 0.0520292520823498, 0.06319566922742995, 0.04665313048228141, 0.041749397848522475, 0.0047914562239912495, 0.029942692077207952, 0.2945818283384846, 0.8989331474707973, 25.40364815342811, 73.66142934368503, 102.8380112494192, 97.09665759917229, 98.29341980718799, 91.08734330823346, 76.74270999047064, 78.88549297086655, 42.05001654163484, 19.958727628953998, 16.02224672994306, 55.83592391783192, 94.80647194770076, 34.995269006298436, 11.323525751790694, 12.132527347533935, 19.420282302364228, 2.607703478105607, 0.5259396460267806, 0.35234969950491385, 0.10852545559886964, 0.49264246177288795, 0.23598964656552962, 0.06662607688697116, 0.08392275641522101, 0.09050775709892474, 0.36685747424921683, 0.17961743437955457, 0.0786847068417457, 0.16025111469770634, 0.12741208166605042, 0.20883613506392126, 0.06475724370008515, 0.18365842560606618, 0.052771120136904145, 0.068174876843489, 0.11868423346670405, 0.19169404441791196, 0.3076242301012239, 0.19439396808945364, 0.23356940627338427, 0.303147028410627, 0.575938098613293, 0.6253762651355036, 0.9540230204020778, 0.7340251834642503, 0.45899450118022583, 1.2291942032114154, 1.334841650339865, 1.3317190759604978, 1.9056682264612568, 1.158282530884589, 0.25222830504419347, 0.9503021007103305, 0.9381531106848872, 2.180800553291075, 1.6093283795541333, 0.7196349878945659, 0.6028272944592661, 0.1875636660523953, 0.7448212009283804, 0.06666962132458726, 0.8417206594059545, 1.3856976311053, 0.050457929140858115, 0.13130495745328166, 0.02822151467684777, 0.12900529940041805, 0.046650836048948194, 0.02581638355378903, 0.06056816767781012, 0.02466635725971672, 0.1026402532513584, 0.06169299159439341, 0.03085141791211021, 0.1476174821296046, 0.1662087353366998, 0.287674657039104, 0.06566403899341822, 0.2472353882847294, 0.450906757746012, 0.2677644608962921, 2.0637999282729242, 12.463819557620633, 22.14209145115268, 38.605999023683616, 37.145575092684844, 51.14787570891842, 44.42404285553963, 19.193045669986358, 22.673937389927527, 38.52125621611072, 63.27822908278435, 63.251855065745694, 68.98906277072045, 80.29014864275533, 85.07883702555011, 54.75274178289599, 4.7418577344186845, 0.11652264744043352, 0.031099779786722317, 0.032410629003519015, 0.05724502381898704, 0.08751218477564474, 0.06296513804925546, 0.04205213281356039, 0.019007177662945563, 0.027522978470510537, 0.08766047641514771, 0.023345581458641157, 0.10321841214693363, 0.024869947040814067, 0.04192346068579824, 0.03969097322213554, 0.03110885984384485, 0.05196078297411723, 0.023359455310949878, 0.04075684284250583, 0.018933455106772242, 0.028529686950928265, 0.035532433464522326, 0.036920937183763713, 0.024120747524824356, 0.04029969519544994, 0.035335962555461356, 0.08211485786183227, 0.036930421352266304, 0.05076590414729811, 0.027266635874947234, 0.012562455339056831, 0.04332486149524489, 0.008841421691730859, 0.05139802627625966, 0.019048586630472736, 0.05391608833545639, 0.04594251498459809, 0.031088460837641073, 0.09649288029439988, 0.15840357109423608, 0.19630770168958173, 0.11265512150261672, 0.13670783850454515, 0.10622975822057455, 0.07218730065130419, 0.08216823120751689, 0.20053840692966216, 0.12749382324757116, 0.19506726744434527, 0.08771356630830035, 0.11263168687301298, 0.2607334591448307, 0.16295827023925322, 0.16708003777650096, 0.1508028910405213, 0.1432018126210859, 0.1275620203945906, 0.18788750673974716, 0.12016519633752686, 0.12629708665753567, 0.19727229831680176, 0.15837113493152205, 0.24213197100306713, 0.14569431032624938, 0.10697701570367622, 0.1471198160922335, 0.11978527035323844, 0.21498659535521464, 0.22770072844239975, 0.1655156096263278, 0.12575002327080698, 0.2816997841000557, 0.11162376797367489, 0.1608671719628957, 0.17732565171055256, 0.3490848779197662, 0.6542283621045851, 20.456097895099273, 82.9903788720408, 118.25223568947085, 106.47226764309792, 95.03154539292859, 94.39512514298963, 74.93836479802286, 69.25127321673979, 48.833755754655414, 47.32606334071006, 50.38391567045643, 112.84643296272525, 120.24384267868535, 34.426086025853316, 20.217996297344087, 41.085466492560606, 65.63613445528092, 10.97422888202052, 0.8475762064899168, 0.8361509550482997, 0.25917689105676067, 1.4476459521439768, 0.6583556761184047, 0.16343765741875096, 0.25602983250733347, 0.25902459277741374, 0.47648064191302947, 0.39799870322308234, 0.19616307961123605, 0.2066907211537323, 0.2536339078459048, 0.35141197724207757, 0.25742147718706443, 0.26351193747212814, 0.3423138864098057, 0.3023468342519576, 0.24932916786882187, 0.1955822623905636, 0.28638465690516657, 0.2473053474339747, 0.2680612740016753, 0.3458565221198144, 0.37279508467162814, 0.39306699688876834, 0.7225768880978708, 0.4392775430554344, 0.3053996639866983, 0.748696257510493, 1.0513188834151914, 0.777850193121741, 1.1838552812414787, 1.2074950385478236, 0.22966647941258647, 2.5797158960373174, 1.9579312349519424, 1.4432044807941684, 0.9175131698289226, 0.30509178857168845, 0.37969704657312364, 0.15163921390569982, 0.5382503112477641, 0.1966581409496646, 2.31579823840049, 2.262288283917212, 0.16671812251931237, 0.37139516624231494, 0.1284573473516972, 0.3513804450631142, 0.12549759729975654, 0.1653541949006819, 0.21151891368771755, 0.08967657468371815, 0.28192771057928767, 0.156168800688559, 0.15328340713054905, 0.2731958710618558, 0.31335386297395157, 1.0966171107945906, 0.25834994510777537, 0.8724046871066095, 0.9316196677184875, 2.351329273754551, 12.409256446746088, 26.114575785975305, 34.59421450091947, 53.94027379251296, 59.49805267395512, 81.28908218876009, 81.62891634048955, 46.74010046066777, 38.765866987166866, 37.41008796999532, 54.63445094323928, 54.41819498615881, 66.93155211787071, 86.16549045808854, 96.25366180173813, 55.85057789279569, 3.143431337610368, 0.26592912873433483, 0.25925359177973967, 0.2726609271860892, 0.20522254429036574, 0.2625333980446862, 0.20347869834832608, 0.1636552417110051, 0.14976119532460166, 0.11670921283263354, 0.22791743939442022, 0.15971705948393192, 0.13692706222495726, 0.15265280951655683, 0.0953894455526625, 0.17625202544994895, 0.23527857907597097, 0.12702647130936384, 0.11846652660038202, 0.1043078504622944, 0.17424971676401554, 0.15610942887442728, 0.27605028402420784, 0.12437856500788082, 0.15289527634459157, 0.17173840393943174, 0.08812133192775712, 0.13728395194536255, 0.12358609301548813, 0.16249814251017186, 0.10782850710975547, 0.1483363637159909, 0.175714829275685, 0.15979415857263152, 0.14016732303125246, 0.14592868726580374, 0.23534938092193297, 0.15429403032025985, 0.11778306125873521, 0.1626322538621964], [0.019252195563768188, 0.05353601296402274, 0.018752033994983763, 0.023204161627818982, 0.0998570864659644, 0.025586907661730246, 0.0696279924182642, 0.06211393009570818, 0.023463049550510706, 0.03821000652087312, 0.07439654500734422, 0.06464251437254491, 0.033345727415214625, 0.025059285671299985, 0.010017346545693376, 0.00968896678739017, 0.05367959699323101, 0.04528089464011212, 0.020121259111610633, 0.06328235973694152, 0.05842211791464399, 0.0440790712262594, 0.033086762883730476, 0.020422180363487814, 0.02089896284404301, 0.010789993140215596, 0.04833498075904866, 0.01943594366762667, 0.03258266170779544, 0.018159457324673573, 0.02436589566059411, 0.05608967895950041, 0.019516796587155234, 0.04279449116438628, 0.04352697847230781, 0.06576892409113146, 0.9926141786479181, 28.450974802817072, 85.27228832244874, 84.85698776860391, 72.42643971596995, 74.05585504347279, 68.27601509709513, 47.18690156936646, 41.325346885188935, 19.928360639079926, 58.16349760178597, 86.92639104781613, 59.97514232512444, 51.80122098615093, 14.762821716646995, 23.811010929845995, 48.36909609456217, 31.171844543949252, 0.9080860595549307, 0.5143736182681976, 0.41246455763616874, 0.2527756748660918, 0.05064530275581826, 0.18601747079482003, 0.08490965386191685, 0.13980298693622314, 0.15964803496195426, 0.05132128724888448, 0.15598106318183486, 0.010891486383644084, 0.12548870301895565, 0.06300318963645447, 0.007965108558099957, 0.09986258697726073, 0.07011058950616468, 0.306697876583184, 0.1527636624392002, 0.2451506791816604, 0.00874632815529983, 0.15278868287080719, 0.18439598441604646, 0.09106294101765079, 0.039906523550950715, 0.23471663826175276, 0.38252639313859327, 0.27037464502838354, 3.2014615785691047, 1.199291891628696, 1.2674254227069117, 5.135245476999591, 0.8241025370455558, 2.857711675666994, 3.2292013158721313, 0.39376649645067036, 0.2926651989260028, 0.7031799095772928, 0.5583614675748734, 5.02981020558265, 3.9621606565290883, 3.721740692853928, 0.7221582976560439, 2.06864895839845, 1.1622219388523412, 0.17574314388536638, 0.397282502944431, 0.282699253049589, 0.09274662607499669, 0.1897533751663662, 0.10450589185160016, 0.054549980127523025, 0.10691050395009019, 0.05063004611480621, 0.08308559851420504, 0.17769947197408448, 0.025941190767973184, 0.04431694918762773, 0.049988435986902446, 0.04164870708219467, 0.1784064179106105, 0.07913283763393279, 0.13012029440893283, 0.155032247965855, 0.41893521203629436, 0.24312912636706907, 0.5179217085242271, 0.12277351121508306, 6.09549758895751, 15.104890638782134, 35.317236761893, 28.907099385415357, 48.040440697823804, 74.85717173545592, 60.935279707754816, 32.61182312042483, 26.535936401736354, 40.394133060209214, 55.00067872385825, 53.06403590786842, 61.025972750879106, 67.81991404871788, 47.65658578565044, 11.918769940253227, 0.30163394347313915, 0.021263350650007208, 0.02090836465809374, 0.006482748534425252, 0.018514812954010505, 0.043935414418698325, 0.029995598109258764, 0.0329391147580839, 0.06646766522598845, 0.048213540501291716, 0.02572851326887406, 0.08064206914916154, 0.07329291108274653, 0.047297555983306906, 0.050904972088192744, 0.02887161880461199, 0.01393205775398641, 0.03519812801612481, 0.008822043497686186, 0.027275961080205538, 0.09297450658895316, 0.026113650566267393, 0.0347742285849827, 0.010096756347094574, 0.0643563345675507, 0.09598258912803666, 0.014821120027092197, 0.02408854884936685, 0.021453319387810848, 0.04389612176906198, 0.0658590083701476, 0.03782853303897766, 0.03208469115047446, 0.05523695798230268, 0.03916447929617378, 0.006328964523310143, 0.04048431089388267, 0.021282550728609486, 0.02352981411311175, 0.014923997974443822, 0.0567178710574104, 0.11945956041135135, 0.020333743173508875, 0.03108017368152017, 0.06647347983333372, 0.05204229472926067, 0.03208189875999045, 0.004849373907481711, 0.02987210282064494, 0.03363171952866739, 0.01757299020555952, 0.045655875526849306, 0.030923648512050993, 0.04685574924693473, 0.011367472132758029, 0.06963354655571523, 0.03988292421244326, 0.039035148332796754, 0.02997411891908175, 0.08985678920702589, 0.03850881145485947, 0.014058160614372503, 0.013923806987041909, 0.01707338596574001, 0.06437558635708786, 0.018682025050023393, 0.06483500928527887, 0.025239052033172022, 0.06913771912936242, 0.02519570486319642, 0.01974480733605883, 0.02149421507642875, 0.1607889084205512, 0.021060184132488027, 4.9961474441712905, 52.024956903150006, 110.22770958562052, 105.34409984465569, 100.02787620790544, 110.21648376218735, 99.65961271716704, 81.29298102471137, 52.81491048874394, 13.287114270271795, 35.01083689351236, 59.13322125711749, 63.219758310625636, 72.8536799646193, 14.752066577634505, 11.743412536959495, 19.12390212858877, 13.360877383139826, 0.26563565577230147, 0.4520962777878008, 0.47766142855248145, 0.3992363948735499, 0.05523018576505204, 0.19582794678788032, 0.03311488980187043, 0.03223367801476871, 0.20112222721499784, 0.27893414540636924, 0.273759895635228, 0.03176578981501441, 0.16327248886227608, 0.21697739740052532, 0.07715231648856595, 0.06666840324478765, 0.5207239355771772, 1.2739168227680269, 0.5353613630417855, 1.0576443181883906, 0.6267965308600857, 0.4986562213349727, 1.3923471517139867, 0.4533608131591351, 0.43358152612082423, 0.9003287145207006, 1.9988022095734075, 2.000209237298658, 7.596703383230395, 4.266850861810869, 4.968127012252808, 12.133373598898611, 6.212669572522564, 11.761176951469915, 11.031776916596199, 3.5335247795428004, 1.6575669136739548, 2.1804188576436814, 3.9089902322138514, 8.953982706992857, 3.304998177674509, 9.943336844444275, 3.7278299273983126, 2.8184205582064967, 2.482437928838115, 0.16986565604325266, 0.402494352310896, 0.3775209585024465, 0.07690005139597962, 0.017051171331155687, 0.05500453456695523, 0.06719702689517891, 0.0711274792950961, 0.0923231786357299, 0.2639018455820699, 0.2853086710937562, 0.09817130232770598, 0.06747467248069663, 0.0709696958262113, 0.11240730738087047, 0.10093259730286176, 0.08935985861406212, 0.12460810793263298, 0.28512140856154505, 0.18710842596427088, 0.163225726855378, 0.6323915467627588, 0.5893988763132404, 2.790830851562562, 12.97375709779801, 39.48787335426577, 33.08578075901155, 46.058145415398386, 69.21713290675994, 52.782331282092684, 24.930035683416552, 27.217383500068422, 56.96009089869838, 77.48459492960285, 81.38329752029912, 83.05725528347878, 80.63411697264641, 68.74675443095546, 25.182587292886552, 0.25132881056877876, 0.09290465469201727, 0.05733062648364613, 0.019415923874945413, 0.04507020130873688, 0.12820885141169833, 0.060172697769538055, 0.1144875118869447, 0.035853569861501455, 0.012551984832351728, 0.03723214891168379, 0.03629965519893073, 0.06320243761424096, 0.031374424222796675, 0.02138266692899408, 0.047824930910381584, 0.013563585741775892, 0.024120998418619557, 0.006629817306079091, 0.03875135489168667, 0.06973066352187626, 0.035938191933617476, 0.05224998499597273, 0.0743617492938234, 0.07323052088219313, 0.028053528832031355, 0.04674773084961119, 0.06072951345554283, 0.01722082533242722, 0.07836041416251853, 0.015613713635942869, 0.024901293443455815, 0.045850515485771244, 0.01512860282204084, 0.0754505287735693, 0.062811246307026, 0.02788271995321397, 0.03352322998727041, 0.13898429941506157, 0.15218704338035277, 0.1588083566316674, 0.12020787509578852, 0.30008727324105083, 0.10363643568369652, 0.15607369853363884, 0.10264195396655029, 0.09786811537079274, 0.12336549033681232, 0.16002006257974333, 0.1078272047602842, 0.09190124805055319, 0.12190694319865397, 0.13970710337162018, 0.16622946567593083, 0.11530780053186802, 0.1351967607174189, 0.09524567383191279, 0.16835145261739531, 0.09278198869358148, 0.20415878524222683, 0.1208247903794531, 0.18530157695133842, 0.1371342123996827, 0.08288816999523871, 0.12000454769980524, 0.11572742519239265, 0.1391912504069267, 0.10313795759312569, 0.15769402045876751, 0.16490975665228982, 0.24556735440367655, 0.10074590167571461, 0.21912019129001328, 0.1411029308914177, 3.559229542170802, 52.94512925609466, 126.82403441398375, 112.30353770717498, 97.51176987924885, 99.46131337073543, 89.7040488643031, 62.96625552638885, 59.625859183649865, 28.986452856371482, 77.00677179521131, 118.62385672907676, 84.31277459667575, 75.60056286473429, 21.506881252411876, 32.13230159974868, 66.91524290269422, 46.67243565282514, 2.2385540220045277, 1.1522167079871701, 0.9078713710750304, 0.9424941938730979, 0.27861186753838296, 0.5376667973975982, 0.11541462383202969, 0.40168177817137013, 0.507595272314164, 0.3541568702747745, 0.42138522250517724, 0.09830696117733756, 0.2626973408604822, 0.23520725629022046, 0.17452583017368473, 0.19648390191216625, 0.28468452394008636, 0.6396729979784258, 0.2843545545493403, 0.3188282353503089, 0.23762673049444155, 0.2374465159711338, 0.8645165555419461, 0.23756124529867406, 0.1724647778657175, 0.5396072674662836, 1.6264009860254105, 1.463958354246232, 7.001562647281155, 3.1687943637371068, 4.4868208131482525, 11.789486658188606, 3.969759268145408, 9.610340364517706, 9.099586971344488, 1.0174066224886527, 0.9617500896415404, 2.1744571001298967, 2.6697276724923045, 10.683544970327809, 8.338108812609027, 9.36841445584451, 3.25534317762621, 5.432176743784259, 4.227247180477265, 0.4895017157879568, 2.181092769868912, 1.3171978487122444, 0.1921674867551173, 0.482970632372364, 0.2112478871018656, 0.32434155563673667, 0.37254659639250853, 0.2561674525420512, 0.34063109767533123, 0.44774974005356916, 0.20932336698376366, 0.21005384714132358, 0.34386521445647367, 0.32281949214877625, 0.35177099668691236, 0.22470019186937043, 0.2916156278262216, 0.8116582048035438, 0.6379971040352699, 0.443378166565972, 1.309756131902818, 1.2392864616647845, 9.430578139520462, 24.9253680629115, 53.60702922267299, 44.97674011415051, 63.98036864496047, 98.1694023070797, 80.46056778200212, 44.951766383263376, 38.918388351317375, 51.14179211278116, 65.6815908032079, 73.11833012488582, 77.6696837332941, 93.61713870879143, 73.65180384728217, 21.227080937354796, 0.2980458021404282, 0.22814331275801505, 0.1759097680088974, 0.14642200192376492, 0.1333570312107763, 0.13535684245007654, 0.15360416814444527, 0.16917550275402685, 0.2330425369643396, 0.18877727189852347, 0.1306467040652229, 0.14257429468054927, 0.20736086422637587, 0.13431721517155248, 0.13510271576383423, 0.16521692726640932, 0.16188256021949554, 0.09036402368257124, 0.14540007127629173, 0.09651301308504998, 0.267816677449211, 0.14809559760314805, 0.09251533646977718, 0.1933398464274022, 0.2058205984893345, 0.22786566717249734, 0.13000156610242783, 0.15461099153805166, 0.11914929480201776, 0.2524797351009423, 0.20969199317116893, 0.07234008156604345, 0.11595443236611544, 0.08729758056541605, 0.16322235606851118, 0.12224114139474208, 0.1997131157305933, 0.1396562810987234], [0.12330686928884638, 0.05158066929828736, 0.06997404199454092, 0.08516538933280014, 0.07139400128395328, 0.050827053285414175, 0.0541284938733424, 0.04613025632176188, 0.013544634641749004, 0.030463708474511103, 0.05887091903376484, 0.021778872281673457, 0.04570947103803197, 0.07299438194041291, 0.07071807424748136, 0.08201689053807529, 0.035303549375385046, 0.14248063277092674, 0.07180023472756147, 0.007059519374442678, 0.06353874638256046, 0.03718334911090713, 0.026400761168089606, 0.01898744515323591, 0.027702402008036454, 0.023776228209176374, 0.024870709298298727, 0.03916227679339148, 0.052920721786757635, 0.05769410072976063, 0.017752775719629663, 0.016183994274826783, 0.06498324729862713, 0.17910035567418223, 0.08699318318958245, 9.959409736817884, 50.50527380358789, 87.12179568506058, 73.08105976350846, 67.64928310148179, 52.53352357495216, 41.584709690463164, 37.856116371770064, 24.624485008178223, 34.39967278511294, 71.89608820023076, 71.05260602889523, 43.5682915103051, 18.43641261900625, 10.392249168888217, 42.09712028503418, 35.06027444716423, 5.485354767691705, 0.7440803632620843, 0.01938437445900373, 0.37143966062895717, 0.09460148581814382, 0.20585030737903812, 0.0998709909617901, 0.2727350232101256, 0.1137084617549854, 0.06386234192177653, 0.051790159871621486, 0.016301885630274494, 0.22013398608373058, 0.13549106105441047, 0.06014934357916636, 0.09104730516311624, 0.06373802117342431, 0.2684368715891915, 0.21294006807429178, 0.23466356369035862, 0.162743964803315, 0.49945954113237323, 0.21682992547510133, 0.743939035361813, 1.9998714231675672, 2.3817997161419164, 1.6251476661812876, 2.053442787258856, 6.36612642195917, 7.62661341697939, 4.048094884041817, 2.920007984484396, 7.465481469708105, 7.664652562910511, 7.333702579621346, 14.040115206472336, 26.192993771645334, 16.23285153219777, 4.882068249487109, 1.0993814011735301, 4.827744893489346, 11.857894755178883, 5.6414940280299035, 11.877705666326708, 3.785060495138169, 2.3504168323932157, 2.423362376228456, 0.40526847925878345, 0.13463909467381818, 0.18925621474702514, 0.09073895477359334, 0.0545581006595204, 0.10794248567112993, 0.01537310457112448, 0.1026435474294328, 0.09289612047254078, 0.320062157848189, 0.07393961952578637, 0.19282287497433925, 0.2743197833338092, 0.04648133526526151, 0.08686071126571587, 0.09341956536856391, 0.007330824624777081, 0.018623714267666784, 0.07267304636057347, 0.01675288542173803, 0.05044053128409771, 0.4231002175759885, 0.049086405760458404, 0.2964559551929274, 0.6028096437934907, 6.038264324588161, 23.331091288597356, 31.66212904837824, 34.77502792112289, 40.446045629439816, 70.96828291493078, 46.796017769844305, 23.470896328649214, 25.843930282900413, 41.64838152547037, 37.32986765523111, 59.80224424792875, 63.7067166451485, 74.83518292826992, 24.092862644503196, 0.5041095416151709, 0.02418260146383076, 0.08227385941051668, 0.11399372225447048, 0.02552895885591786, 0.014208575275035636, 0.025851817035506812, 0.024352711287417242, 0.016939263122396606, 0.050695044844741785, 0.07433187186477647, 0.021616101580401583, 0.02753864688378188, 0.03576384947424935, 0.02250177008400281, 0.003441185559025936, 0.023029642968228268, 0.10238726037524401, 0.033091022332589475, 0.035100509262373375, 0.06461418444110502, 0.022195319592532133, 0.02895345614712325, 0.044743403521997314, 0.04474502379795717, 0.021417615860099756, 0.026501292971173124, 0.03860718097477671, 0.051277857724457025, 0.025930042273455092, 0.09161465455807986, 0.030340017833476587, 0.08906512926783293, 0.038883309706204364, 0.024292967920642228, 0.036185331897990364, 0.007239480131125499, 0.08762139060925092, 0.016206827525409962, 0.0310445639995798, 0.02909600787285355, 0.025829901175212958, 0.02383680086612942, 0.13131658666797225, 0.025163406596308755, 0.05621390011642249, 0.0371478715791337, 0.029883013827906504, 0.03797417018382299, 0.0317991835876338, 0.021586337149323478, 0.04357475171526594, 0.01369472371504432, 0.028612424446750554, 0.13379998324859527, 0.03446497421170916, 0.029141551799952026, 0.06129163046998363, 0.04283915025993221, 0.03555718193491621, 0.01786137442855585, 0.016533790021053246, 0.021709217652378064, 0.021852309470094984, 0.03098813013263768, 0.015562865507578658, 0.024429465636550903, 0.0161706643449443, 0.0256882515180135, 0.06494677385255214, 0.17333574322683198, 0.22025127414493795, 20.788607020531934, 77.1453099096975, 104.46915241979785, 93.9275158605268, 96.26432280386649, 79.1218157737486, 65.10896790412166, 51.72957105021323, 28.432829918399936, 30.577236760047178, 52.06017978729741, 75.62044143676758, 44.98741288338938, 21.585136459719752, 5.52322623229796, 16.050632922880112, 17.126945026459232, 1.8254756134363914, 0.525804998413209, 0.08246297587550457, 0.3964432995886572, 0.09139653400427873, 0.01447917189404008, 0.03771526310893317, 0.20111709442590514, 0.19366471367257257, 0.16664571188870939, 0.08051629283375318, 0.06153832610336043, 0.448981762653397, 1.16064281713578, 0.31750072755159875, 0.45273191626033477, 1.1698670060403886, 1.433483131470219, 2.3400796709522127, 1.1392218956062872, 1.2388008232078245, 2.2878408095529004, 1.983364250871443, 6.883056077264971, 6.275931519846763, 7.000206487794077, 6.060558586351334, 7.549322622437631, 14.195537163365273, 20.084763188515943, 14.19784841998931, 9.280076796008695, 14.265568141014347, 12.631560698632272, 13.160291294897757, 20.925195717042495, 32.48844300546954, 26.65542748666579, 14.327322917599833, 7.549053940080828, 6.906071074547307, 8.746982562926508, 4.996339640309734, 10.759776234626772, 4.572494203044522, 0.9540537864931169, 0.6849978852175898, 0.8221668473655178, 0.3785184662668936, 0.5693265146786167, 0.3693724489740787, 0.1340819036047305, 0.10534446701527604, 0.049569784258041656, 0.06178538179806164, 0.04830808341202717, 0.34235249724118944, 0.09632345994994526, 0.2263682870374572, 0.14127919240103615, 0.053230512421578176, 0.12401916251908388, 0.2048338465993443, 0.08736535636407715, 0.0606451403620022, 0.10356466856694992, 0.07081948130601837, 0.2195915192245476, 0.4723232666090612, 0.042564726074136076, 0.1466770325937579, 0.49180331970414815, 3.9802994122428283, 18.27465407309994, 30.15971810586991, 34.96966377381356, 41.96432844285042, 62.582671257757376, 28.54369571132045, 10.792765328961035, 29.821350920584898, 53.92612580330142, 62.38168508775773, 86.78492684518137, 77.89966798597767, 90.32074743701567, 44.098713628707394, 2.0158218640473584, 0.1307343445237606, 0.09890391987057463, 0.17076888902773782, 0.025670926439605897, 0.03078115041247539, 0.08105442363528476, 0.06891976711490462, 0.024067404822656707, 0.11619005802898638, 0.01969981499226584, 0.04442979010843462, 0.05548559947900715, 0.02569563277516394, 0.022473332900253516, 0.019498264920266888, 0.0626257764205577, 0.08302080279756939, 0.07364542644110418, 0.04119779539084242, 0.06002782671261699, 0.007073815532719657, 0.05578607831510806, 0.03525487980955551, 0.055648665124129866, 0.04625046317796073, 0.03875051985584921, 0.08352952348368783, 0.04661021806720284, 0.022362740447504387, 0.03688292773140054, 0.046949667796011896, 0.0370395046118046, 0.02936556356989088, 0.07282599581465607, 0.040895405165370435, 0.02921490280348207, 0.1623096848807989, 0.1510125233401214, 0.08808709545842103, 0.16456959829215081, 0.1714866214822377, 0.14158925882750942, 0.18527788951271967, 0.23183046329406, 0.22923817497587975, 0.22613633093574356, 0.13219853772992088, 0.1001922116284409, 0.09599403448162541, 0.11998282144627265, 0.16442689143361586, 0.19326578104688277, 0.19951932612926732, 0.27710230660534674, 0.216505563847961, 0.0743325766656668, 0.17346308236160587, 0.0797429194133128, 0.1782444516016591, 0.062269112696090055, 0.07713431342234535, 0.20765378560510375, 0.08241341764768285, 0.12128654987581315, 0.10399140252341187, 0.1358663675285155, 0.14058433533195527, 0.18806683260106272, 0.22797938526397754, 0.32307521229790104, 0.3562312218691073, 19.519765377044678, 84.42638212634672, 120.79438655607163, 93.57155292264878, 89.67064595991566, 74.24579189669701, 54.03606199449109, 47.99953429929672, 32.80536463183741, 50.40157025860202, 98.79917806194675, 101.1545221267208, 67.53189440696471, 28.61849334932143, 15.756495364250677, 55.71503646912114, 52.30754406221452, 9.682807134043786, 1.0199054174365536, 0.27788625970002145, 1.1380716605532555, 0.22871273059037425, 0.35358202853991144, 0.1538039945186146, 0.7410838563115366, 0.5384760313937741, 0.3228954574273479, 0.12967519732492586, 0.14293291575966344, 0.49531705857765296, 0.6677574135603443, 0.22320820499331723, 0.5035382238847594, 0.43623127103332554, 0.7751699885533703, 0.6429060115929573, 0.2782236141783576, 0.3488296787104299, 0.76737875178937, 0.46941366467264395, 2.550356955297532, 8.751228528638041, 6.119460328932732, 5.7841525923821235, 8.725455614828295, 18.06054561368881, 17.69033270497476, 11.954524305558975, 9.19532516310292, 16.831021808808853, 13.892095742687104, 15.372337448981503, 23.8727843376898, 43.17870209293981, 33.89123947389665, 15.542232951810284, 8.608014948906439, 13.381551215725562, 25.727314295307284, 14.442498414747178, 21.45644153318098, 11.174376645395833, 6.2875231042985, 3.849676395616224, 1.2430383313086726, 0.40939652871701027, 0.9080405845757454, 0.4560916408175423, 0.38290315517975443, 0.2639331938999315, 0.1825387574612133, 0.3690831128868365, 0.23931577050637817, 0.9200111067583485, 0.35747914845424317, 0.5876903163809931, 0.4951126969629719, 0.27351039612004835, 0.21982491557155887, 0.34356426447629934, 0.4557465028858954, 0.14490476478972744, 0.18003196455538276, 0.22636088662810866, 0.7883949337467071, 0.8419097299056669, 0.225637040791973, 0.5187990324151132, 1.5273227734911827, 10.668504641902063, 33.697686195373535, 46.920851122948434, 48.16590555252568, 58.82447581137381, 99.17102659902265, 63.517917279274236, 34.484670546747026, 37.2866274464515, 52.08384344654699, 53.24880699957571, 78.38896013075306, 84.93064988044001, 101.89086083442935, 42.77998532018354, 1.334219832093485, 0.13088428325230075, 0.2108601087163533, 0.2344210355752899, 0.13466432961004396, 0.14127130169541607, 0.11335810676457421, 0.1481369663510592, 0.0911969910826414, 0.22386276583758094, 0.16739263229312437, 0.15106162957606778, 0.18041235785330498, 0.1949661898036157, 0.11607850030545266, 0.13945627086345228, 0.18300023350504138, 0.15407425501654226, 0.2986266193611007, 0.24436677205226115, 0.16440571676338875, 0.13194706170789658, 0.16171697797554155, 0.12363866196885226, 0.11243606632154797, 0.10058596549976258, 0.11526237151795819, 0.179778297521895, 0.09272912096592689, 0.1329243294293842, 0.1282101001350149, 0.2459468896831236, 0.16544036447040497, 0.0865716203266094, 0.23635373751242317, 0.14547173114072892, 0.1906645448217469], [0.04513541071285163, 0.03772221918728563, 0.015309809429210522, 0.014139158132996772, 0.0578343561069379, 0.028916182139167385, 0.03812464900434979, 0.02367294232000507, 0.0289917471367986, 0.04567531500792792, 0.028247914066718473, 0.006772956046681371, 0.03754159863737803, 0.05123778366513791, 0.0041409398451627746, 0.02803740076600544, 0.04896437944543939, 0.030639205811425086, 0.028269718844263304, 0.013012876734137537, 0.08982325753858013, 0.10987485819045575, 0.046148803310408715, 0.028083498191629207, 0.022777939035046487, 0.045187087173783974, 0.021689904575806954, 0.07925537339742146, 0.05614130562471767, 0.04764109662163162, 0.04659933578823844, 0.048443581383194656, 0.044239647085628206, 0.3125852929247964, 20.250779467244303, 74.67001192031368, 86.31678412037512, 77.69196279587285, 70.89496597166985, 60.43285154527234, 53.032798151816095, 36.070484807414395, 42.64089807387322, 58.17741417115735, 56.666705454549486, 55.21090992035405, 28.892011988547544, 29.66303425450479, 35.81653095060779, 62.48403933740432, 12.31709545658481, 0.14813479066135424, 0.2873361993941569, 0.6986618294350563, 0.13537011109292507, 0.0591991302527247, 0.12152913161703657, 0.0923817383966619, 0.04130575250113203, 0.17016271429677166, 0.05136619149256618, 0.06984055117373505, 0.056794847572042104, 0.1369652440471034, 0.16025142113287605, 0.01970176277081332, 0.4603599456529464, 0.17572478841870062, 0.3207561109335192, 0.5958921762724078, 2.0130176145222882, 2.64813355380489, 1.9275209764319083, 8.81212430615579, 3.916089722225743, 6.524012607912864, 3.2090275854833665, 10.249068929303078, 7.955635555328862, 12.070437208298715, 8.704384642262614, 6.65679709565255, 10.321877925626694, 7.993139788027733, 6.1093445362583285, 9.153819622532014, 10.661143333681169, 13.067958701041437, 13.053559680138866, 18.090045759754798, 8.47301971527838, 8.577619521848618, 12.166676482846661, 4.507809415940316, 3.1905306683432673, 2.7217375655328078, 1.6251340604597524, 0.334037532128634, 0.9125690835137522, 1.40159597800624, 1.0746976805310096, 1.312278338497685, 1.1364234070624075, 0.6962903276566537, 0.683078988184852, 0.21614602346333767, 0.24239346745514104, 0.08860220531782798, 0.055625881669261766, 0.028534045991217418, 0.08368623442947866, 0.051676127684092334, 0.05948230316261611, 0.05234861498578422, 0.06963093419589343, 0.08262703360448923, 0.02991258482178373, 0.08653885474608791, 0.05627088173623047, 0.047658429360918464, 0.2063727793433974, 0.11523861513142625, 0.09482635560655787, 0.09985771465806231, 0.3976797654984459, 0.3070050471973035, 5.828552351843927, 20.0862850681428, 31.061910313944665, 23.48958838370539, 48.25463348819364, 77.27298305880639, 41.27769400996547, 21.53885837524168, 36.32616842946699, 34.87902564387168, 52.60673853658861, 56.22730978073613, 72.68959153083064, 31.402144547431703, 0.5173505746549176, 0.09512947361555793, 0.019571493349729047, 0.05151195504191903, 0.011296824461990788, 0.03822067429521873, 0.03243710883262177, 0.06763951161936407, 0.02468730593400617, 0.06763961887167347, 0.022053943811765602, 0.019779045720614737, 0.07473638161055504, 0.06974428456516997, 0.050734042550527284, 0.026511162098857666, 0.01637057307356548, 0.045785041781322616, 0.06204644924089794, 0.02242726420292691, 0.06581276730303803, 0.05482588669345264, 0.07153701457765795, 0.043484349509761225, 0.023457202384428635, 0.03943048417568207, 0.04858040468647115, 0.005548904591705651, 0.06499745822962254, 0.07182943799923505, 0.04255073730863872, 0.03460839736245332, 0.06223233281484535, 0.0483596143162539, 0.08993869932788996, 0.0686456838382348, 0.051841238783972884, 0.024129595840349797, 0.08456247813639142, 0.028855688006226576, 0.08810807094578782, 0.04930808862310745, 0.04958386112365031, 0.046742188203479015, 0.04779478918100077, 0.05518807008141472, 0.0517060817219317, 0.0380162820370207, 0.05312694116465507, 0.062156402010230295, 0.028534710572491732, 0.10572764887324265, 0.059683401242739735, 0.02125209873361934, 0.04333900347832711, 0.02968090259650302, 0.055027551678640235, 0.007696834143115989, 0.0325311461253272, 0.03248690837813962, 0.042918647203834794, 0.018581439620785175, 0.021182819487406843, 0.02683705207140696, 0.07022569421678782, 0.016864280351587844, 0.056788933373266653, 0.08193418368576996, 0.02599884846037434, 0.8712306726844081, 36.45322576645882, 99.5199449600712, 104.37706301289221, 105.94257508554767, 114.62463948034473, 90.87340154955464, 74.7485456159038, 27.4204759828506, 24.738871128328388, 22.598576891806818, 53.714153074449115, 72.38956159160983, 29.05735754197644, 28.189911650073146, 21.528926933965376, 33.32367643233269, 6.100650112475119, 0.11014003952544545, 0.18968942214644727, 0.6593750020669353, 0.045874022893727794, 0.11748296163615682, 0.05787318144294043, 0.2036653173666808, 0.12287448926438248, 0.1158095115134793, 0.06573618149324771, 0.06873433553283254, 0.43099227151082414, 0.805897959057362, 0.857202131902018, 0.3772280064802016, 1.4115431087632335, 0.357234429327711, 1.7788184073663529, 1.3832928504674666, 2.18043111505047, 2.851750163301345, 4.006401314850777, 5.588692061362728, 8.189319583677477, 10.249128745448205, 12.059001538061327, 17.00279416576509, 13.20774805161261, 26.48712838849714, 18.256497421572288, 15.382988645184426, 13.085945710059136, 13.343266921658671, 8.259202491852546, 13.272216127764795, 14.358414565363239, 14.689157643625814, 20.876481840687415, 19.227790024972734, 9.49597973977366, 12.784386046471136, 8.312297655690102, 4.404528016044248, 2.926647576593584, 1.7887731377155551, 2.871139664803782, 1.6542804577658254, 1.875369632917066, 1.7525169541758878, 2.1504590588231243, 2.2537078540171347, 2.339777158152673, 1.2574953297453544, 1.2089206975313926, 0.45719137535460536, 0.30043771250113366, 0.21153881665199034, 0.056782548030417775, 0.10052179797522484, 0.055269367331939365, 0.10368319769059459, 0.09235946055982383, 0.055392910501048456, 0.09275065569747841, 0.08539148486189305, 0.1213763660240558, 0.0395387860255376, 0.0808117806070274, 0.07673458406521429, 0.11964365133955596, 0.18238278195982982, 0.06900366140349258, 0.037206232157205386, 0.34387906532614465, 0.426886867611639, 3.104370169101223, 13.66755868158033, 18.73193575489906, 29.243856437744636, 65.15399671369984, 59.0900202720396, 16.288219709550184, 15.955302657619601, 40.98024106794789, 60.378310988026286, 80.76782272708031, 68.8222365225515, 87.72878246922647, 49.84850821956512, 2.0222246430573927, 0.14277920787853582, 0.04791937422968688, 0.058806119486689575, 0.057589116040617234, 0.0261266089435066, 0.017653435183268402, 0.07541351140506806, 0.04917598442144452, 0.04423305106860015, 0.03100602020088944, 0.041337970328787645, 0.04296999424695969, 0.005375701688124889, 0.10282855766314654, 0.04431667722641461, 0.07235639157795137, 0.024819846805785934, 0.08999318350106479, 0.08930581111100414, 0.08696610198145913, 0.10771238350219305, 0.045468892616730545, 0.019840658341924992, 0.08938412061862408, 0.02983678999777523, 0.022742965206083272, 0.021301275832698714, 0.08615329801555603, 0.028601710707129493, 0.03510591784311879, 0.07115677449732058, 0.05341169987654975, 0.009720617709981819, 0.05460846711010222, 0.07469454554901009, 0.1822937931865454, 0.14148117914315195, 0.23307869631436565, 0.16262005774244187, 0.2059964003461984, 0.1898677367717028, 0.14272610266362468, 0.1507513639667342, 0.11167195490411214, 0.1345993500323065, 0.1684285823496119, 0.15337621102169638, 0.14378350318199204, 0.20056970928224827, 0.11405131674461788, 0.21390025203506793, 0.12072136850967524, 0.1307709788482997, 0.1571986220416523, 0.13440494756064109, 0.15782653834790955, 0.17615520725807837, 0.12486458650880283, 0.19133507093835264, 0.08995390617318692, 0.14103899319325724, 0.1724233631525309, 0.17521452789585437, 0.2129436533657774, 0.14686178235757738, 0.1415111638245083, 0.12335551587203819, 0.14586819696330255, 1.0706464850133466, 38.21532310978059, 107.68271107827465, 114.94513634712466, 103.99962117595058, 98.92268565393265, 77.59802987498622, 67.0432141519362, 50.1253608734377, 59.69988607591199, 80.04667928141933, 79.44773335610667, 81.84685107200377, 44.38565854103335, 41.04379523184992, 46.68326923924108, 83.7188022367416, 19.825074826517415, 0.1922783243560022, 0.5486491887319473, 1.1403001796814705, 0.3571792097101289, 0.3668898031596215, 0.38206229707406414, 0.49110314598487276, 0.38729029557397293, 0.3288205652948349, 0.19097042840815362, 0.2712939505375201, 0.3868502853137832, 0.5852176297095515, 0.22583364959686036, 0.1156115850373622, 1.4686785590264106, 0.5573745624672982, 1.3145743959373044, 1.310138195272415, 2.6943162756581462, 5.95325920851, 4.849605243052206, 16.684001568825014, 11.960089168240948, 16.452934741973877, 12.51028101290426, 20.970187264104045, 18.667618689998505, 24.179364635098366, 21.92216611677601, 17.01370619958447, 20.44449552412956, 16.383999086195423, 14.124403999697778, 17.021778437399096, 21.001764305176277, 23.712614351703277, 28.324394033801173, 35.084769648890344, 20.353755412563203, 25.719336194376794, 24.241734243208363, 9.154637436712942, 6.554037861285671, 3.6268423786086426, 3.176951667954845, 1.4750000714294373, 1.4365157364837586, 2.2212443572859613, 2.5924116276925613, 2.246627485559833, 2.5190150112875047, 1.1535916213066348, 1.3568976281150695, 0.680568487413468, 0.5248673067938897, 0.4476044284960916, 0.15604576696791958, 0.38049037658399154, 0.4180265398275468, 0.34062392709235995, 0.3458414761529815, 0.21819625860981404, 0.40475474069676093, 0.20354131837525677, 0.21841079387212955, 0.47136651472218577, 0.218936805162699, 0.15910467944077908, 0.28929474913785536, 0.31755962439121743, 0.43465803287202315, 0.1066523553022454, 0.6809408674317022, 1.120698134745321, 11.30883647549537, 31.459503327646566, 44.37562904050274, 37.56711221510364, 74.57199973444786, 105.81542753404187, 57.931132470407796, 34.14502466878584, 46.90070190737325, 49.548380221090014, 71.52602826395344, 72.03123738688808, 98.43081258958387, 53.065973558733546, 1.13179991322179, 0.2939455157085773, 0.16287665123180037, 0.15475294763042083, 0.1256585370508894, 0.19817402976895535, 0.1463272674910484, 0.13991540267823205, 0.16154827009285652, 0.16969521680185873, 0.17411491593285916, 0.11437501953614336, 0.17085547228494, 0.18086598915678842, 0.16370131423877132, 0.15345318753632808, 0.14859879479533242, 0.12335146326691875, 0.2008443671248613, 0.16052695231572275, 0.1352449782913731, 0.20491522045866137, 0.1767602481789166, 0.17107258160268107, 0.19907796755433085, 0.0921490008852655, 0.12832233967680123, 0.07508076877603609, 0.15793968953432577, 0.10263528900160905, 0.13122244978383665, 0.2043365176406599, 0.15960098184164495, 0.10855059860454452, 0.15485574130810079, 0.16595834715952798], [0.059080382794021606, 0.012107665327587917, 0.026972251268283978, 0.07296438959817733, 0.011663882084371103, 0.06061848050223724, 0.03153146267117512, 0.019794200854976813, 0.051496621792114554, 0.01817455117200171, 0.019482272834847533, 0.05637587791669273, 0.10124835576261244, 0.09144035423354757, 0.08055832807815845, 0.04372997645048365, 0.054052486459934906, 0.029713400046250997, 0.015100858947863022, 0.05532908771607665, 0.05124130383914998, 0.033164252677271445, 0.026840913154545332, 0.007785093217652532, 0.06854632223445563, 0.017685172290751533, 0.04543202463537455, 0.07008893220054527, 0.0163197124962725, 0.007978571595759282, 0.03754236089486269, 0.013553549989967818, 1.9733788770052696, 34.439637814798665, 89.77461230370307, 81.13994583006829, 66.65351098583591, 59.89188609584686, 48.60951777427427, 46.24978849964757, 34.50570229561099, 60.57296253019764, 67.29783873404226, 93.06948169585198, 52.16973158621019, 14.705598258203077, 44.61359923885715, 43.43776679808094, 26.683562647911813, 0.7097792973922146, 0.535059524399619, 0.34405263020626964, 0.31751880722661174, 0.04465623803797268, 0.014318961841655115, 0.12324160625857693, 0.032654643329160835, 0.0150352971433031, 0.053744159053049745, 0.11686793092878596, 0.15027550079168814, 0.05666238713949438, 0.0256154635891078, 0.09088363047809371, 0.7613263507523845, 3.0252285061344026, 1.0650010911687728, 0.7101636283820676, 5.047195130778897, 3.091151046176111, 12.310737294535484, 11.243276019250194, 8.209294744076269, 9.42579088672515, 11.678678720228135, 19.742828607559204, 5.782613552385762, 12.01359716153914, 9.567334517355889, 23.41414159344089, 16.80083328677762, 19.662063083341046, 20.791652740970736, 15.378258266756612, 23.51819815174226, 13.900713189955681, 12.450911037383541, 13.165278588571857, 11.884767893821964, 10.523958436904415, 9.203565082242413, 7.6994851712257635, 1.372260081191217, 1.8079978996707549, 2.6486961687764814, 3.2542314308304943, 2.0928906769521776, 2.072467140613064, 3.3838630683960456, 1.920590025763358, 3.2498856898277038, 3.453101972418447, 3.777841127687885, 2.7715776524236126, 3.2812332722448536, 2.181194506345257, 1.8853836891151246, 1.068708466426019, 1.0628358202595865, 0.2815873836798053, 0.385214044081588, 0.08177473014521022, 0.0722044303772911, 0.031400390772990165, 0.11734590850650303, 0.05998253559453353, 0.08158238078918188, 0.08077255690530424, 0.13322016194222436, 0.026568714454169237, 0.27414437984266593, 0.05751423477645844, 0.1246289072197772, 0.0866702541468605, 0.09074132964615861, 0.02376209963263283, 0.25308857581788496, 1.8851336380166395, 28.839358091354374, 31.41837335401966, 9.979022568272008, 24.618034670429846, 68.68222359688052, 54.1923096103053, 36.079898495827955, 23.930615763510428, 35.14258930760045, 55.03665470307874, 56.747788690751605, 68.50168474258916, 41.97844113073042, 2.7846077661360464, 0.17562481394458204, 0.017583211733689232, 0.049935219689242305, 0.04414179084462024, 0.08728601263775941, 0.07989435967418455, 0.03322189696313393, 0.011554008796660891, 0.055962244063735976, 0.0640093427031271, 0.10030956863756142, 0.04508006469076199, 0.06741333948147875, 0.048309270848309806, 0.09033024686598971, 0.0756688944755062, 0.068127486644493, 0.10022735974240689, 0.04178265755575511, 0.026563326940841736, 0.06570338526920927, 0.04211089941823194, 0.02294409776016349, 0.056275642972679875, 0.01951425317524662, 0.05400570913127834, 0.07269378436068374, 0.048580289773282506, 0.07933988821722808, 0.017725692596286535, 0.03523887240237767, 0.03046504146749935, 0.008527517164756936, 0.06129861719185307, 0.11639130166581563, 0.03074732954583822, 0.05500649575204138, 0.02631270702207281, 0.005729617550969125, 0.022215450467962413, 0.07194784454881184, 0.02666126362108175, 0.030715806942973888, 0.011733472553802835, 0.015024366026233523, 0.08448308844479822, 0.06802348254789269, 0.08556804514580196, 0.06663980518257426, 0.04549138495818742, 0.06934073242929674, 0.07259541867120613, 0.03509539179503918, 0.04534738341106042, 0.025365720841012178, 0.10879138770002512, 0.0354915511824431, 0.05151857404158481, 0.03232052557230477, 0.03770955192345766, 0.027548138713163715, 0.052164650462087125, 0.0298650624726208, 0.02270983190335814, 0.08495311402986128, 0.015585993702012687, 4.471759892279103, 51.77663164754068, 107.56837398775163, 97.09039749637728, 90.88115215301515, 86.1163902282715, 56.6248223858495, 41.41950730354556, 16.40181743329571, 41.334187907557336, 60.6548184733237, 94.7932457154797, 60.58673397187264, 8.823834542305239, 26.32159652248506, 29.458927839033066, 14.217787788760278, 0.18344871669767365, 0.3018772836414076, 0.3941486517508184, 0.13037311874570387, 0.01113235783357654, 0.12488556965704888, 0.2326470057690336, 0.1621634693395707, 0.09526012225016471, 0.15226311591123382, 0.5297504737973213, 0.22610239324069795, 0.49923507737055905, 0.7886316242717928, 0.1189668203193334, 1.6847203792102876, 1.1061069177043055, 0.8067247211452454, 0.7065872848033906, 2.112821955834666, 1.4235421294166197, 1.213090912468972, 1.6748087949329808, 0.9125161928034599, 1.064646361816314, 3.0627273455742867, 4.34164849981185, 5.695050070362707, 8.393803527278285, 13.532956665562047, 31.849214338487197, 24.892308365914133, 24.042413119346868, 24.468343296358665, 20.6900280521762, 29.478088617324833, 19.281387252192346, 14.931329681027321, 19.235266062521166, 27.137220059671712, 18.411844853431948, 13.833660271859939, 4.953163170045422, 3.6299618886363123, 3.3328815717850966, 4.847653373595207, 2.8578389075494584, 2.3007919855656165, 1.8321055221942164, 2.6698330861906854, 2.095446591415713, 2.741958854659911, 3.447733473393225, 4.357501739455808, 3.3197377093376654, 4.311631581475658, 3.6048516102375525, 3.2869278182906494, 1.868559785427586, 1.9969221685201892, 0.849796022859312, 0.6684888743104473, 0.2281441401329733, 0.03298021154478192, 0.02168513950891793, 0.09306872774276043, 0.149850812289984, 0.28568010116296433, 0.12830689534424775, 0.3005445358012953, 0.1374586506356155, 0.400797161123445, 0.07473188467443952, 0.130634339406125, 0.0716699997804338, 0.03578665591175518, 0.05202775821089745, 0.24443824805559652, 0.3182853548036468, 16.432803177064468, 10.617575606992169, 10.795009905292142, 29.257121893667406, 52.59624619637766, 34.550205507586085, 15.034340927677771, 17.454470780587968, 47.883796922622196, 82.41972892515122, 79.3906314911381, 85.71561813354494, 60.38786980413622, 9.631384861084724, 0.10019483931002118, 0.03267152407657235, 0.034678540372800444, 0.024764270957319007, 0.08679958511023753, 0.05975866172042105, 0.031547776513522675, 0.06318933751073576, 0.027418317453515147, 0.039082925406194506, 0.014142683095058367, 0.043456241743819374, 0.10347328959934174, 0.05801019243775837, 0.012362937315277035, 0.03064653535764064, 0.030530057434413223, 0.09668179757652745, 0.010869911432476535, 0.04096165261862259, 0.11408674065023662, 0.03353275629060884, 0.017460681715860002, 0.04027273656139451, 0.00955776369664818, 0.08496007776909298, 0.04776046461155338, 0.044333964000425996, 0.034843590185647054, 0.05869041722748549, 0.06108878570939265, 0.07999354507774115, 0.027269255895648273, 0.053501826290401726, 0.18770654145027363, 0.1293546814591654, 0.1632263856909929, 0.1408590238180853, 0.10537126477086738, 0.16817555882998053, 0.1517849851159319, 0.15845546589022683, 0.17486186698079112, 0.0783707716712548, 0.1251944792907565, 0.1635698535509648, 0.3974876000035194, 0.19713339125437124, 0.22245386885779522, 0.1794328837985954, 0.14954089908109558, 0.14260734371360273, 0.10347785548337045, 0.17794929324619232, 0.11844958073549694, 0.17637748000842912, 0.15972830565466037, 0.13317651025229885, 0.18543495285895564, 0.18165711283443436, 0.17491855748718785, 0.14083916681908792, 0.08642309886072913, 0.11120159224036241, 0.1911524968642381, 0.14817427483297166, 4.860442261542044, 55.65496536993212, 125.54295693674396, 106.3040058074459, 93.10245313952046, 83.65085894061674, 62.37195760973039, 60.10372154174313, 45.81191470546108, 84.78463572840538, 93.76462767201086, 132.64494157606558, 79.68696655765658, 22.966510903450754, 64.6139177199333, 62.36418347204886, 38.428347033839074, 0.8813844633198554, 0.6789028896920143, 0.6275508516738493, 0.7743841662041603, 0.11479089802671825, 0.2590554814425207, 0.6286324452488654, 0.2473434526473284, 0.2754515403461072, 0.24245614876910565, 0.4073200014329726, 0.36437574774026876, 0.18557196002333395, 0.503285292295679, 0.26061790244233224, 3.1294179347253617, 9.413150068252317, 4.716532461104855, 4.435657416620563, 13.986126722828036, 13.913051005332703, 35.0329472941737, 29.429712064804573, 22.799643470394997, 28.395643887981294, 25.45531753570803, 37.98123605789677, 13.659371714438162, 23.189172091022616, 21.062931706828458, 39.227933960576216, 31.616684467561786, 32.90038601044686, 37.626363538926654, 28.415220437511323, 39.06015065408523, 26.56532672143752, 21.984178789200325, 25.54274912803404, 23.87442388842183, 22.584760342874837, 19.896848317115538, 16.539030767256214, 6.90943205548871, 6.249168697864779, 5.710948907559918, 4.632767794593688, 3.6271049322620517, 2.9387900089063956, 6.712898265930915, 3.69881909701132, 4.157352995487952, 6.029048715868305, 7.155484297583181, 4.9779952053100835, 5.072949413330325, 3.6739792170063144, 3.184490708574172, 1.9306251647010928, 1.9857819017864045, 1.0998501244091219, 0.7910223088918195, 0.2870460972189903, 0.1614618400532392, 0.11711936864641406, 0.27930085637396385, 0.3397746420195026, 0.36339034416502525, 0.18794867119962172, 0.39639197169773044, 0.43589483586049854, 0.6940335552057912, 0.17758334836652204, 0.342457298069231, 0.3740871379212026, 0.29769928525051764, 0.13769783860733434, 0.5971925645585984, 5.04138364907234, 47.52562569033715, 43.83192185432681, 17.684225574616466, 41.305287884127715, 101.67127086270241, 71.19487039504513, 54.126896242941584, 32.89452010585416, 48.198143512971946, 77.33938094108336, 75.1084779923962, 91.2854543808968, 67.13956325284897, 7.268377955882781, 0.3668890370716972, 0.14166738447402755, 0.15438711000305994, 0.12102363616107933, 0.14603152690875917, 0.26622140659920634, 0.12423273251061479, 0.12013730307620381, 0.20635355053649795, 0.20851483778847804, 0.17087359792522847, 0.2583049910683786, 0.23171394132077697, 0.12685505147542686, 0.16419289753802363, 0.3047528099869528, 0.2448033655603086, 0.14333433051022793, 0.13082733227600976, 0.10816619100589907, 0.1607089901282903, 0.18190763890743258, 0.1650596187720376, 0.08878684016845881, 0.1383861073202664, 0.23864191956818107, 0.20217903018478425, 0.1733105848993986, 0.1903641923901535, 0.16544371993551332, 0.20729084379009663, 0.2813526543398058, 0.16471129391462574, 0.16383737145412355], [0.050521564234288475, 0.003167632798243675, 0.006171171478326283, 0.00695280907224984, 0.06530868144886148, 0.04896921729068122, 0.0501971987767085, 0.040472942149086345, 0.010734388563451509, 0.040804275176337654, 0.015060027419108779, 0.04138425736117267, 0.017608622870137616, 0.05284304813211484, 0.013194707702965507, 0.022672102073087327, 0.05796205147259659, 0.09188450136852842, 0.028778933657092914, 0.02331295185872624, 0.015632295098546294, 0.03799925573290356, 0.05230491350014364, 0.07399056437275103, 0.02506025668774401, 0.03789127563997623, 0.014834136818535628, 0.019706489533306133, 0.029675141615312428, 0.07728330986273867, 0.11382613286015489, 3.4087139800671613, 42.11779509821246, 78.32257009321644, 74.1449869832685, 75.42768832175963, 64.82409400324669, 54.327490175924, 58.4642884808202, 61.32853654123122, 77.84091088079637, 55.64892884223692, 45.57230495637464, 36.260139249986224, 34.40510919017177, 55.12116216844129, 16.794051508749686, 1.687913188530553, 0.15557736548925602, 0.125848212760062, 0.8032184899333985, 0.04064115973549985, 0.007461615464454818, 0.2087632647805637, 0.07455815891585044, 0.0738747472003583, 0.09635124595895891, 0.11038648234980722, 0.04281280832665582, 0.0234845612994245, 0.05203187210305084, 0.17665673437858784, 0.5821318888375836, 2.463098437555375, 5.933670401573182, 4.1063820402468405, 3.1460615319590417, 1.6822054044854258, 4.156240513247829, 4.914278753342168, 3.546172707311569, 3.004455633701817, 2.525946084530123, 4.5360568550325215, 7.2366891272606395, 8.76603155366836, 12.776194176366253, 10.515690080581173, 10.289535041778318, 29.06895402939089, 7.074070111397774, 14.517470598220827, 11.19416598350771, 23.055364354964226, 18.802006936842396, 15.967499267670417, 18.93864074060994, 20.8380877202557, 19.138691425323486, 9.87890701140127, 12.68273586227048, 5.938652301988294, 1.3573054320389226, 0.8167599826570481, 2.1614250252323766, 1.9335148483514788, 2.5578239223649426, 2.5529008575024146, 2.412083355649825, 2.131615011922775, 4.711714319644436, 5.494868476544657, 4.998563624197438, 4.366479064187696, 4.317199876231532, 4.2047219891701975, 4.344409358116889, 2.975864496923262, 3.0523210523589968, 2.183406968270579, 1.2825774161085006, 0.8337074410050147, 0.27187167276297847, 0.082913420253223, 0.06567137045485359, 0.02740692955652072, 0.05316197436543242, 0.06964728251219758, 0.006458070448359415, 0.011742601449030542, 0.2309128278565984, 0.11868502253726607, 0.02595511058555736, 0.08066119070375159, 0.09153649060716552, 0.047438880053138545, 0.0711626503916998, 0.37409455365230965, 0.8563870756376175, 29.056645631790165, 47.65926868684831, 26.75805434103935, 52.54009354499079, 76.47791078013759, 64.40001126258605, 60.775450967973285, 27.72687977360141, 25.816338369923255, 40.69273525668729, 49.50235512948806, 65.04864185087143, 50.54540749519102, 13.322541117668154, 0.05042425191570675, 0.050739857157872575, 0.03570173506534869, 0.04917341802689818, 0.04069164876014956, 0.07703687469925612, 0.04612324661725471, 0.11078441906119547, 0.07035006859129475, 0.034708643797785044, 0.04027360224074895, 0.012467461394055957, 0.04981805037166323, 0.07056167739773951, 0.05501817859288666, 0.03651052473052856, 0.06397963764386312, 0.019432507763286273, 0.00769797609292812, 0.020255720948860533, 0.0475826939087241, 0.058971874100426515, 0.0243913795753953, 0.03130324890897159, 0.0845733029587615, 0.06007986323487374, 0.02330166738360159, 0.028837202304613688, 0.0364611005680936, 0.05720031492772603, 0.059049386876605214, 0.09115244306984449, 0.01323084981601325, 0.04002098091727784, 0.01072912170897208, 0.013019815575511707, 0.029769127197082967, 0.0704139526633005, 0.034681516624386274, 0.030068799725643573, 0.05327527110855426, 0.021687116015762575, 0.04279332288030175, 0.00904460257339862, 0.07765729100473466, 0.04173706766338118, 0.006448992306456691, 0.04293222994273228, 0.05354420627437292, 0.06238993242262833, 0.07930433407666222, 0.037755000089565595, 0.008218099040189579, 0.06335010872252526, 0.0240989925429946, 0.05822450553457584, 0.0315279693102404, 0.09615911110754936, 0.0369542237040737, 0.04834738372254276, 0.025554268485716274, 0.11341490452328037, 0.14310292599181976, 0.17718171911133876, 6.660788597599153, 64.64144099143245, 96.03016514931956, 94.7907667775308, 98.99460623341223, 98.0009521976594, 67.7692291813512, 35.15906326232418, 41.184843663246404, 66.61106309583111, 65.74508220918717, 44.79234164760959, 39.66988701974192, 23.95926671643411, 27.317070537997832, 9.407445961429227, 0.3045784177318696, 0.07743268934709412, 0.15810741682446774, 0.8968922279534802, 0.058356923832287716, 0.13099680624661908, 0.03259107718364366, 0.13946207780991832, 0.17355778615080542, 0.20651657404678486, 0.3730196403639932, 0.7955922991518052, 0.48690933553922566, 0.13362788925728492, 0.2260066016066459, 0.7114302475125559, 0.7092482452431034, 1.958803594593079, 1.061633246079568, 1.432335347898545, 2.093051984425514, 2.36393601663651, 1.8726581719613846, 1.5823951796177895, 1.68748393414482, 1.7397019579525919, 2.9007035493850712, 2.9898781449564042, 4.10416026269236, 2.8816359273848997, 1.2912056498950528, 6.298325802049329, 18.366202192921794, 12.671933654815922, 21.850943719187093, 15.957792382086478, 32.976181891656694, 24.669943317290276, 22.18074248683068, 27.712935747638827, 32.10717685760991, 21.348511634334443, 10.655876571132291, 16.211874696516222, 7.6458428367491695, 2.0361480765765716, 1.4611077717235013, 1.1887849651036726, 1.7709675383183265, 4.142239612917747, 4.422946485780901, 5.59179465616903, 6.159264051145123, 7.129484376599712, 7.789183893511373, 7.977861175614019, 6.906283372832883, 6.994746548514213, 5.814742667059745, 5.521451850091258, 4.297828760839278, 4.39341054808709, 3.507992110906109, 2.8617718190916124, 1.8773186831705033, 0.7380567671310517, 0.46762181566126887, 0.16678946062682137, 0.04355432781120462, 0.053207732797149694, 0.023792505662347523, 0.07540794960673779, 0.05191855237729127, 0.2836873532543259, 0.027914897561253562, 0.12663264849012898, 0.05681472372323756, 0.14409641945554366, 0.1468509958396035, 0.056905761781719424, 0.48011551460912155, 0.2488963281916034, 15.380532260864014, 14.633743378423876, 17.817405731447284, 64.28991425421931, 74.40677381330921, 54.38980879322175, 32.482622208133826, 14.642462807316935, 44.39162838843561, 69.77488610052293, 69.960312228049, 79.12777777641051, 72.22226465902021, 27.043496985589307, 0.42418754148867827, 0.058617520131050586, 0.06148123340080343, 0.022854358220713276, 0.060153016970763286, 0.01613330223687714, 0.009340704174622173, 0.07167911622673273, 0.04492895001725805, 0.032019081465419263, 0.039106815858113195, 0.03949417672570675, 0.06537683263060547, 0.07845773031153987, 0.03405308320878014, 0.048442267542404514, 0.04618424253778593, 0.041939188470883716, 0.010758140161933919, 0.054055045193602005, 0.06764640641068259, 0.06078131632098268, 0.047539153301547614, 0.03354171951932292, 0.02208763444345565, 0.04000655931210326, 0.06338145704038682, 0.05397082531764623, 0.03812259588871272, 0.018462311033339753, 0.031379637451121406, 0.026842814967817357, 0.02589832048773045, 0.10385821047689646, 0.15564681902047128, 0.08003971719693753, 0.1541493775983972, 0.13508917132933296, 0.13060007995415118, 0.1866916894552208, 0.21580866898500153, 0.14106870208296085, 0.19445307943369114, 0.20020954070552704, 0.13860185300150227, 0.12854659659487586, 0.14023280822701994, 0.20688803475950995, 0.1067216173114796, 0.11904171307481105, 0.19573806935260374, 0.17622594781700643, 0.18307276670971226, 0.23752520852271589, 0.11641072199469614, 0.19351577085833396, 0.20606282016923352, 0.19121507092589335, 0.24711217070298813, 0.10810537128559045, 0.19554161376530127, 0.21167651329550052, 0.26361784146678063, 0.3548095465427445, 8.639145820371567, 72.79510328846594, 110.43179050568612, 99.12449944403865, 104.8884145675167, 88.7462531366656, 72.80971019498764, 81.00070168895107, 81.44328624971452, 102.90309121531826, 75.38920202562886, 66.1525458674277, 49.66868715901529, 47.71907306486561, 77.16350970729705, 29.182241885892807, 2.870199521703105, 0.2964472524341076, 0.26356835218687213, 1.5599507646214579, 0.2306916889163756, 0.24064531609896692, 0.3754027866788449, 0.23996241000150484, 0.24270903439291064, 0.21530885790144244, 0.4886784164174911, 0.3279109737805782, 0.14906180301500907, 0.14409321720802015, 0.8891076714761796, 2.166057344405882, 7.809036479842279, 19.893014200272102, 14.281085037416029, 7.401758643888659, 7.7446488122786254, 12.681517966331976, 12.264798495077319, 12.325047081516637, 10.495935063208304, 16.96385483587942, 14.76878175812383, 20.786006489107688, 22.7631458159416, 27.079500421400997, 20.532342887693837, 21.196751209997363, 42.78300162284605, 16.055900666021532, 27.18453953343053, 24.873004421111077, 38.883443955452215, 32.85723013262595, 30.382824482456332, 36.12989694841447, 40.127274605535696, 29.52299975579785, 21.980840852183682, 24.43171424250449, 12.573993052205733, 3.5314098865755144, 2.432387749994955, 2.8671540464124377, 4.821821133936606, 8.8645742401, 6.481267598367507, 7.34581878108363, 7.39372072681304, 8.793784283822584, 9.38407059638731, 9.70029894382723, 8.836107638574417, 8.630564655027083, 7.430514520214451, 6.679263941703304, 5.092397995533482, 5.403640520188117, 4.293471497874107, 2.942702082857009, 2.050808793114078, 0.689704729424369, 0.6381519150830085, 0.33226253705159314, 0.18614128592514223, 0.16586149832414043, 0.3926681408718709, 0.2418341773051408, 0.13809358430725915, 0.3940787538886071, 0.452698668044421, 0.24223309460907216, 0.08378634679942362, 0.2963602554894263, 0.1902554691919396, 0.20753769264105829, 0.7908698267513706, 2.671289756413429, 53.422822952270515, 71.27882480621338, 32.70888609270896, 64.51798046788862, 102.58048411338561, 86.88576313757127, 90.43954818479477, 44.648924104629025, 36.889456087543124, 56.98027541560512, 65.3786700771701, 88.108930741587, 79.85464003778274, 23.68238856715541, 0.39071207325304713, 0.12281157812404057, 0.11345162311749113, 0.11914844444442181, 0.22150690757459213, 0.12447782702022984, 0.12826168083495673, 0.16162107908918014, 0.12653432876592682, 0.20642490396576546, 0.2574088520580723, 0.18469425308848583, 0.14534376381385714, 0.13514866571753256, 0.09696751772876709, 0.1417587787633942, 0.1006301228077181, 0.16341347968386066, 0.14999387154896415, 0.11793596474754235, 0.1661541132676986, 0.12753439526404106, 0.15200509749833616, 0.13420495264712842, 0.16439356660890966, 0.18886299713725047, 0.22106574818251595, 0.21851887355648705, 0.06035334130208339, 0.20962235577885183, 0.23235249092742322, 0.1668255280462965, 0.1617693324242869], [0.012989599152558274, 0.027044117976460728, 0.04333615746168841, 0.004491467205356927, 0.05116564116530842, 0.040937045874494704, 0.06059532932516548, 0.07186696864664555, 0.0349864196182499, 0.1210889528175035, 0.012621109903369461, 0.09159552534261058, 0.05756774601796943, 0.053917513258995554, 0.03291726976092304, 0.027827046428536697, 0.0147172988339838, 0.02258760257503919, 0.10044140470845085, 0.037687477099919514, 0.06381913456284712, 0.10509880560059702, 0.042894266455644564, 0.04910945351566038, 0.07405437183596435, 0.10193172917370835, 0.070673480269409, 0.017414641746830557, 0.05035482519756883, 0.009121690170779344, 15.298397829455716, 50.67017024563205, 81.7618219314083, 77.10969478853288, 78.14225873639508, 65.46886497928251, 38.95365830390684, 35.08931959829023, 53.51144498394382, 40.25593619192801, 37.81734766498689, 38.84334556518063, 106.52795745480446, 75.97799685693558, 35.04564792879167, 7.461582633756823, 0.28488762917057164, 0.18436197011220842, 0.3834665055957533, 0.18041523834390027, 0.07817008727861029, 0.364356258463475, 0.12750824102230612, 0.03633806684745416, 0.042493832297623164, 0.35139080257185046, 0.11006557577920538, 0.04288514234846638, 1.1918195313022983, 1.1998762022103033, 0.28174265438029844, 4.264466551042372, 2.6987762556922053, 0.7247318014983208, 1.5954940573823069, 0.38514448329806333, 1.4508370454272916, 4.500749639926418, 14.467558437778106, 19.80616900228685, 16.998771775153376, 11.478865338910012, 9.887966705906777, 6.016723157898073, 4.436514944799485, 2.4206125495895265, 3.988030894148735, 4.458992087071942, 3.8233805808328816, 6.954134327750053, 11.86804388799975, 21.09727401887217, 24.161794377911477, 26.703184304698823, 12.82693591810042, 20.504180269856608, 27.04847643452306, 25.56402406384868, 17.234784710791804, 13.616732608887459, 12.5407656738835, 3.1191447569477946, 1.0641695486922418, 2.23405628915756, 2.649912838974307, 2.260053023215263, 2.036128587299778, 2.9479303571485707, 5.655870985600257, 6.69242202274261, 7.492390890275279, 8.043067147654872, 9.706906176382496, 11.339830064004468, 10.010653541934106, 8.875118551715728, 7.16738869105616, 7.288031972223713, 5.702144167115612, 4.769170668817336, 4.393648341778786, 2.636639048014918, 1.592602167398699, 0.6725063006724081, 0.4956920126513128, 0.36158087513139175, 0.19236291578460127, 0.11164812190878777, 0.3806328689379077, 0.11955384285219255, 0.2503361444800131, 0.06453035910043024, 0.01634107294282125, 0.08316483498821337, 0.05786276264717022, 0.07653444359499602, 0.07511286019918419, 0.06647786185626062, 0.07383187692011557, 0.6661088536343267, 4.721004453397566, 33.52773381817725, 72.26142560282062, 81.38838875678279, 77.30016508410054, 113.40492356208064, 67.4329016285558, 24.189692235762074, 27.96870173946504, 49.0556207010823, 48.94506869777557, 70.58061153657975, 63.17970698879611, 31.445178831777266, 0.6065590006689872, 0.04093926369903549, 0.01668045180849731, 0.08916004756165129, 0.06545959310906549, 0.12381511500045178, 0.07061967025360755, 0.0386372460953651, 0.044982028419091824, 0.0842391966932243, 0.0347405283771936, 0.15350442349670396, 0.03912680309205767, 0.01994657765833601, 0.03283860019197868, 0.08051005687804953, 0.04289081522954568, 0.0729330642629535, 0.03284886960060366, 0.01417210853222998, 0.025398235527738452, 0.05170230873890462, 0.05390740855927429, 0.090102611500169, 0.03082998277198884, 0.03295017323727089, 0.0545189229230727, 0.05293321285036303, 0.035240799113507235, 0.09899748218876701, 0.05054709794480474, 0.04442894358127829, 0.05460899188033035, 0.021895580031278155, 0.019850422132519946, 0.06050216920313336, 0.05868271038296723, 0.02491018772425671, 0.03779091429145586, 0.04298266151078767, 0.04212861137104131, 0.10123990581280763, 0.0714739885241274, 0.045911825502351414, 0.046396659566990794, 0.05429262055024024, 0.028268240294569445, 0.007610056491103024, 0.10997264931399016, 0.057934928129637436, 0.10883261089123066, 0.0535950668516659, 0.04672469075528845, 0.08792731250005384, 0.005130003405464513, 0.034565461964737025, 0.024415220231598905, 0.08916880394662581, 0.10368829217529106, 0.09043317843949603, 0.07612057225478273, 0.4653805794735109, 22.431101491374356, 73.09150895764752, 97.96900841497607, 102.23192661039292, 105.16866007158833, 97.03706895151447, 55.12638676551081, 24.608887703188007, 49.01908774529734, 41.66318062813052, 50.91007809485159, 37.992304986523045, 100.14466085741597, 58.62756106161303, 20.877180022578088, 4.096096359914349, 0.12266888658726409, 0.2202470453395959, 0.4362473282362185, 0.020422291446236834, 0.2034554705624619, 0.6127059063123119, 0.28319304268206325, 0.49865000070102755, 0.5070449453928779, 0.8934985810229856, 0.6450734888353656, 0.36486316352121295, 0.11570599005227128, 2.5028646521029936, 0.30862471028681726, 2.140901468453869, 3.3218359322317186, 0.3433193614886653, 1.3323486163731546, 0.5266766838969723, 2.661276190511642, 7.760245136676296, 21.713286176804576, 28.231412287681337, 25.753917771001017, 19.932300659918017, 16.315438016768425, 12.282845320240146, 9.14502174623551, 6.9717281191579765, 4.981642519274066, 1.7531944210490875, 1.3691622667735623, 1.144004735735155, 2.182514383908241, 10.083437042851603, 27.474455641162013, 24.03189136135963, 17.224865036626017, 22.896057290415612, 27.947085557445405, 28.86695981025696, 14.470905200127634, 16.566304968249415, 14.8250913043176, 2.0911231588932777, 2.6169509560831132, 2.0480647274563393, 3.5414236976254374, 2.2797832806264204, 0.9558336232458392, 0.996086395555927, 0.9472061249036944, 0.9746768734147473, 2.9026865526553127, 3.6600459775617047, 6.145890730042612, 10.4719272159761, 11.014880326486404, 12.539788023118051, 13.96072349240703, 10.18627570521447, 8.31906472482989, 7.452086575569646, 5.899871337798334, 2.9082063080803042, 1.9452787719426619, 1.1202720672853532, 0.514181483416788, 0.7373112103631421, 0.7237825266295864, 0.38233903867583124, 0.5660813049443307, 0.24615517366797696, 0.2912749332045355, 0.08272568274649882, 0.07533841180585085, 0.13727364040190174, 0.03799438341370514, 0.058977160107104055, 0.1156727035319613, 0.06316256656822178, 0.052557688041199604, 0.660891427147773, 0.9139196658807417, 18.635266980817242, 63.16710049106229, 82.60668477704449, 83.23737052179153, 115.20213788555516, 66.23306428232502, 8.50415450911368, 33.7617463450278, 69.02489754461473, 74.8602782526324, 85.52412017699211, 79.85728371527888, 48.024555098625925, 1.5046234044336504, 0.12836758482960925, 0.04526035199242254, 0.06894882482987258, 0.05211289356192274, 0.03365253796800971, 0.06777687884506679, 0.044689087888165835, 0.04980472044178075, 0.12333777327571185, 0.028231150147715406, 0.08881268797502404, 0.037891865527677926, 0.05225081237093095, 0.017699086362676277, 0.10039111869710107, 0.014431871710375193, 0.07580972441862668, 0.012935393643865903, 0.04613178849761044, 0.020276671538369793, 0.024449247941975633, 0.05472367141215552, 0.008938803915835677, 0.020655203242636016, 0.0492939772835422, 0.01760661380455619, 0.0751243515180484, 0.06499334433746916, 0.06355688734460743, 0.04725177839939152, 0.039712427514455015, 0.12841456900200537, 0.09827151428908111, 0.12556277606035435, 0.17641722464994078, 0.2820609485910785, 0.22042725986290365, 0.18333617838159685, 0.20557725832106608, 0.1524000464668197, 0.1898220472878987, 0.1590740052802909, 0.24183146535388886, 0.19409959114366965, 0.30720012382634226, 0.17585791917818208, 0.23313040724925457, 0.14796151689464046, 0.13698926856440885, 0.25218249298632145, 0.12037040830980386, 0.17880878261020108, 0.2639765851199627, 0.16146093606948853, 0.18560398249856888, 0.23547656683912202, 0.1639859312244, 0.24629461699195448, 0.21809640670976332, 0.22818581531605414, 0.585606741088052, 26.983380779143307, 85.66514507416757, 112.4619230147331, 106.07499430256506, 107.76529265988259, 89.4964691900438, 53.12537001025293, 53.61022595436343, 76.27681870614329, 63.11250109826366, 56.53129739146079, 63.81048294805712, 136.7409158522083, 93.68011628427814, 50.89009754119381, 12.514297519960712, 0.3282587164111676, 0.319132648047901, 0.8591478113685885, 0.47118780173120967, 0.22903287873393108, 0.628463476896286, 0.42611881850227235, 0.42442168860185536, 0.4087650884063013, 0.7813921546743763, 0.6713621943227707, 0.5104847721034481, 1.9098196875664497, 4.265430473512219, 1.2110246814066365, 14.370626864894746, 12.771449089050295, 4.539852238470509, 6.189093186009315, 0.49276338109085643, 1.6416031122207644, 4.351304394583549, 15.767081841345757, 21.28144891031327, 18.570112489884902, 14.844694329846291, 11.883669630173715, 7.581502727923855, 5.921161472797395, 5.403793492624837, 9.308471814278635, 10.433061430531165, 12.302299295702289, 18.704692932867236, 23.26172613328503, 33.91128278547718, 41.677630639845326, 41.33325438345633, 24.703001053102557, 35.59073971163842, 41.50483454427412, 40.69306081341159, 29.353180739187426, 30.336124743184737, 25.372728109359745, 7.127725193577429, 4.356614303204322, 3.2433958832294714, 5.197760703102236, 4.640593413383731, 4.1357779983551275, 4.839714496366439, 7.6797316247417085, 7.8946824131473425, 9.409615032134518, 9.855405149921294, 10.859192629014293, 14.163934626886922, 13.863515392426523, 13.380966782569887, 14.48312436380694, 10.918690081565611, 8.766172758994564, 8.052529375399313, 7.453442735056724, 3.4050735302509803, 2.553658365241943, 0.8607560444262721, 0.7040963345958341, 1.9922543028669975, 1.0568846041156401, 0.9732878640774758, 0.8353530591534031, 0.6855153929321998, 0.47871424786506167, 0.2000524467157741, 0.13684398765044828, 0.30665022591429375, 0.14265064300308306, 0.10964215132257632, 0.31342860251184435, 0.24897014842398707, 0.25469941357451104, 1.0636575568106867, 9.038311704512566, 50.15440210219353, 84.7809643899241, 92.20343805128529, 97.44081420283165, 122.0873409701932, 98.01493152495354, 38.0225896066235, 36.4784348395563, 65.464346408844, 68.84329180563651, 88.0463218688965, 92.79558258671915, 50.58350547667473, 0.9890138718389696, 0.16100085430568264, 0.16760630953696468, 0.1659961306159535, 0.19939232407318008, 0.16539675874575493, 0.19384837559153958, 0.12178621540266661, 0.15072744670173815, 0.22785851191128456, 0.1582151900736555, 0.20902502170253187, 0.15566854527400387, 0.1543844746606004, 0.17015209631814113, 0.22525084054758474, 0.0818730192258954, 0.2096372025628244, 0.10451662474341931, 0.10503689037455667, 0.15028072551133173, 0.18564818577179987, 0.27089739278439556, 0.19925819739939707, 0.0949514271210759, 0.2135128413717593, 0.14010894713142227, 0.10100517647280809, 0.22678100924578407, 0.13506177602516067, 0.14929921366274357, 0.07066660846072821], [0.05980158562681848, 0.12467982908410412, 0.08405368850235978, 0.07953085861499272, 0.049431267900452505, 0.09798960159382514, 0.041728315108846274, 0.07528617993117341, 0.0693232579637439, 0.019691340144603484, 0.07003103893610739, 0.042933160739560286, 0.06257374372874057, 0.014771219932534283, 0.005083884912422829, 0.0627073341409766, 0.08758500909372684, 0.03218251100230602, 0.05441110753904908, 0.01281969425749154, 0.045685572925234036, 0.03787200852868058, 0.02552693446857795, 0.07697872862580322, 0.08871686569745503, 0.053583203980158416, 0.03718062566833631, 0.13075472246254646, 0.6177750181767249, 22.523681194551532, 67.26413772952172, 84.75866963786464, 79.85167472593247, 63.17368615058161, 49.70757353690363, 36.19674590326125, 41.08628626792662, 67.64052052651682, 32.12509620574213, 52.70542929249426, 56.40724851239113, 126.8907617753552, 97.24701773735785, 27.495457972249678, 2.295012373116709, 0.012409209025903575, 0.48341061198903673, 0.08551562941002269, 0.06268420594654257, 0.18452790475660757, 0.43592143443322956, 0.20020295234937824, 0.4280094009253287, 0.1575061144127, 0.19247917728799005, 0.355420149261913, 0.3879725734793371, 0.12792968897209053, 4.099272989457654, 4.442550491902137, 0.5281956830332356, 0.6443971864158108, 4.261115866322672, 20.585632208854925, 41.76799812624532, 48.97649864996634, 64.09341135332662, 85.91725933936335, 100.50798216173726, 102.56194699195125, 104.23519872849988, 95.10308158013129, 96.53437799023044, 97.75034412260979, 80.93996770920293, 73.62304502917875, 52.344936017067205, 25.603747867768814, 7.554700191943877, 8.937308711390342, 3.5973380650243456, 10.534578254145961, 13.880539459566917, 24.719449512420166, 18.885023901539466, 17.28792105951617, 16.460879502757905, 18.292920550992413, 15.356335159270996, 10.159266264207902, 5.573857167074758, 0.6721727766336933, 1.1005909620754182, 2.43336392987159, 10.819281531918435, 24.038871219081265, 28.138440347486927, 35.46663591938634, 42.91907256649387, 40.65000887840025, 36.59148147029262, 28.97909252874313, 20.635860120096517, 8.831479241771083, 7.011599992552112, 11.871001355109676, 14.948417486683017, 12.580755218382805, 12.084071367017685, 11.139421463012697, 9.272071238486998, 5.323998264728054, 3.829972859351866, 2.0158523849902616, 2.1145105361938477, 1.1854190811995537, 0.5752276593158322, 0.2405340648106029, 0.13025273568928242, 0.05076331477011404, 0.2010547808341442, 0.10449637703958059, 0.13122611168411472, 0.03613946621396369, 0.05607840597569462, 0.13040109627669857, 0.03604488882927164, 0.09656941247803551, 0.09925658078563791, 0.15809384174644947, 0.6633153906272304, 0.7754074145228632, 2.7781081536123833, 27.356384454234956, 43.72858701213714, 101.07749462127687, 51.25025741515621, 75.51483554224815, 44.527707176823775, 26.97442404685482, 41.28568387800648, 38.66235956068962, 60.339338317994155, 59.10316021211686, 35.18819470559397, 1.6267607409146525, 0.08204473783412287, 0.07008196846131357, 0.0919838629723076, 0.10384477329470458, 0.037387500051409006, 0.058920044421909325, 0.015878920826400002, 0.06732360760290777, 0.07500225242467658, 0.08071117794081088, 0.04318935969363778, 0.02885078504351118, 0.03108263856941654, 0.024963455732851744, 0.06802349020877192, 0.04215619436675503, 0.08178969184237142, 0.07707734712429586, 0.060684865851315765, 0.028735149817000476, 0.03449877784136803, 0.04316789390999944, 0.05018355858121669, 0.021339338911216588, 0.03453799388221195, 0.07559854462141953, 0.0448336027142021, 0.007230785511989868, 0.022288652084347223, 0.034622282706080906, 0.0688058804840811, 0.0284115715147627, 0.11293037689381069, 0.07741287065249297, 0.06310374250695591, 0.12135135325332805, 0.020827034848832318, 0.027296164733988625, 0.019563614135427822, 0.021606546548765995, 0.01200559081494688, 0.08221012855609579, 0.047586600957137924, 0.07604305947860403, 0.04057431090322714, 0.04728956951669628, 0.09269806376147656, 0.02504648625730507, 0.05164108299199612, 0.028592125031976934, 0.016027613704453315, 0.05669280849096756, 0.034318950192462054, 0.023902998523666494, 0.09049238171428443, 0.021253201900230303, 0.05476597861777391, 0.13183968682442943, 1.0882082845895522, 37.01178696847732, 88.26107948057114, 99.27360442376907, 101.57863232397266, 90.03843876623338, 80.86277546421175, 58.715233879704634, 26.41429978032266, 63.49473607155585, 43.21820036057503, 57.8311316428646, 52.45082432223905, 114.1645533038724, 73.6685602126583, 14.679247775385457, 0.829045765342251, 0.022886474541718924, 0.4727430521480499, 0.07932722478383973, 0.040484923764222094, 0.16525164637113773, 0.8642638691010014, 0.82526711326453, 0.6841265061689962, 0.7477688008258421, 0.1826121333626009, 0.24079073490875386, 1.3015136387078994, 1.0341933249465882, 1.3923880914526603, 2.442832286319425, 0.2798014182236887, 2.0713139637824027, 8.213749575999476, 29.25846334426634, 54.90053276861868, 65.69559758709323, 80.45730437001875, 98.26374315446424, 111.0336389849263, 109.84391350899975, 112.50375901499103, 104.72495371295561, 107.48426268177649, 111.61531863674041, 94.98889353967483, 91.21597351566439, 71.16822181209442, 37.18979197163736, 14.465179520268595, 13.597310992979235, 9.564645732602767, 2.237905114889145, 5.646206755791941, 22.39674937340521, 23.78523115188845, 22.49138047618251, 20.857366169652632, 18.152158452618508, 16.367101515493086, 11.9204104715778, 6.9407727737580585, 0.7912178758171298, 0.396925843050403, 5.63906902267087, 22.364144671347834, 39.95516492474464, 49.34219298824188, 59.835180390265684, 65.25544489583662, 65.07979331477996, 64.77047520299112, 56.873567335067264, 50.90489664385396, 38.003770074536725, 25.661787179208574, 8.770501094479716, 11.456261700199498, 17.350080820821947, 14.613739290545064, 14.177648213601882, 11.7657837752373, 9.807867004025368, 6.537938983209672, 4.0323889784274565, 1.6949075099921997, 1.0438283821267467, 0.7045648739703241, 0.3451749490153405, 0.07039085511238345, 0.024859687208288142, 0.20382532249054602, 0.47506629038722287, 0.3565060635728221, 0.07614467338088059, 0.3245795944765691, 0.09266406477939698, 0.06490467732111294, 0.11627016018234915, 0.09440975699333415, 0.13140373683023837, 0.4719725515573256, 0.6642867288281841, 1.2843402763528209, 21.71620245902769, 49.24788351981871, 98.89909651971634, 58.185129473286295, 62.60981013697963, 18.59539608801565, 40.9434570804719, 65.34528678463352, 63.377037509795166, 75.76417276936193, 70.9935429788405, 53.98395330675187, 5.364720802153311, 0.040545103801113945, 0.03943805695481358, 0.06657125563510964, 0.04868818176609855, 0.02745781503167124, 0.07944384634855294, 0.04433619331628565, 0.09015979996371655, 0.10564109625955743, 0.02390869821782314, 0.040097593540145506, 0.012744325569890922, 0.06107023489030619, 0.03635255740054193, 0.009243433990876281, 0.05196875028852975, 0.0875606781412517, 0.022030020801110134, 0.08601368615223516, 0.042810441114969795, 0.04073288344267396, 0.04999578660053592, 0.006270238617059565, 0.06135638788222306, 0.02977937170785041, 0.03920950611392337, 0.041749665979295976, 0.009990021147044196, 0.08457534841351932, 0.047455178573727615, 0.12600039612622033, 0.19772341685189357, 0.1682473565902441, 0.20577372923012704, 0.11696917710885887, 0.2246325922709319, 0.18863864062774569, 0.09951770951550815, 0.2311568575039987, 0.20882049154850746, 0.20320445419319216, 0.23798260897878679, 0.15839347405539406, 0.1815266633826879, 0.177030278850467, 0.14595479554226323, 0.2701350127256686, 0.07076437660162488, 0.16088437829767505, 0.1377658825367689, 0.10825037640789825, 0.1891115620251625, 0.1516553936826606, 0.18999757335310985, 0.14692132271105243, 0.12653983693810242, 0.12206074301033251, 0.21320157984812416, 1.8704754955345586, 46.56597075923797, 102.79482595382198, 113.3178234100342, 106.64074913147958, 90.18493144742905, 71.35125529381537, 52.415930917186124, 59.70287099961312, 95.71472814006191, 52.46280716311548, 73.75777059985747, 78.72249495598578, 159.82226002600888, 104.57456219580867, 36.05688987239715, 3.123129639894732, 0.29990779416215035, 0.6661957586484571, 0.1910313630416509, 0.1512459350088912, 0.44504682863912276, 0.9158813412631712, 0.35129118049817704, 0.6037630861805332, 0.5196665503805684, 0.6863611540006054, 0.4266863977236133, 3.850012003414093, 2.7824624747999254, 11.399795259198836, 9.581860034696518, 2.2818082042278784, 1.0371244386319192, 5.551122128963471, 26.29399480358247, 54.717008990626184, 67.12582711250552, 81.95211964268839, 104.05877836288946, 118.80246577724334, 118.43890128597137, 123.53722941490912, 112.73227630123016, 115.34768919790946, 117.1052718931629, 98.13024920801963, 90.44529837946739, 64.13142304266653, 31.490703821182255, 10.077912384463895, 11.129724383354189, 15.217751937527812, 24.913412678626276, 25.010595283200665, 41.503606842410186, 34.41627225568218, 32.951859274218165, 31.421069983513128, 33.40615603231615, 38.21693128155124, 21.944866834148286, 11.282040803663193, 2.757195301594273, 1.5889199198253694, 6.894294158104928, 24.802890093095844, 43.08470641413043, 56.57750291209067, 66.73618670432799, 72.09394039646273, 73.97697617930751, 75.91519971047678, 68.20462795995897, 62.60380498824581, 52.8638106776822, 38.75217007052514, 21.488954059539303, 21.304524214037006, 23.01947859025771, 19.490439776451357, 18.482790723923717, 14.052656004505774, 12.67798096902909, 8.528881130679961, 5.70437599574366, 3.1171534186409366, 2.350202572922553, 1.4721719199611296, 0.8703717961907388, 0.26673434842978755, 0.16501832663291888, 0.2951811848869247, 0.2594728461436687, 0.3512611498515452, 0.20736086422637587, 0.4235607896360659, 0.3834182727000406, 0.10136210449760961, 0.330575151789573, 0.35630513403204184, 0.49997239103240354, 0.9375055518842513, 0.9542734392227666, 5.7767554925334075, 40.867876929621545, 62.75063499327629, 121.0735651754564, 67.72161945219963, 110.60183309739637, 64.52607623992428, 41.287766656567975, 54.70201376945742, 57.415936993014434, 79.63804675686745, 83.40658157102524, 60.736764630963734, 4.752766826460439, 0.15207257452270678, 0.13127334866552584, 0.2137269629465957, 0.20749335147200093, 0.16028473063582377, 0.17026921584000512, 0.23361149514394425, 0.19035121486071618, 0.11864881722196458, 0.14224958065296375, 0.19888635364270982, 0.1629808698330195, 0.09857538306424696, 0.1550495002659098, 0.09278883751962455, 0.11065562435936545, 0.18527428889947553, 0.16808882235519348, 0.16514479242745908, 0.10837610675803117, 0.17531536038844817, 0.12913709716691127, 0.09665847019923311, 0.12832679064764133, 0.17912133116154902, 0.15049192063029737, 0.12257317156200448, 0.09694637370205696, 0.13723628595471382, 0.15240669611000246], [0.05194807357545342, 0.045341633921188694, 0.030191249304240754, 0.022683547426676078, 0.07249774246086037, 0.022939629552345124, 0.08826077525173465, 0.021389241878604217, 0.0335140292712998, 0.010289919671542462, 0.07612788073358036, 0.028463102418989427, 0.020646050407160676, 0.07073901143045196, 0.08381790196102473, 0.021046710561119744, 0.07050346237637344, 0.07659065912687972, 0.08717831599736407, 0.13006446192101126, 0.02549402333135086, 0.06098745525964807, 0.038387133709846005, 0.10352067213745848, 0.049728345306169604, 0.12850762570216773, 0.08653524647196455, 1.3693249225616457, 27.37999123911704, 82.39744986257246, 89.81310644457417, 77.63808511918592, 73.83554335563414, 58.95445531414401, 40.770339350546564, 32.68818382293948, 78.28404457338395, 35.67330560376568, 55.800422545402284, 115.41973529323455, 140.2038666509813, 67.33064543816351, 4.1329328090913835, 0.03179808233624264, 0.10281036307494487, 0.23977591355721797, 0.15322395870762487, 0.16116757035976456, 0.19667755361766587, 0.08447463849499341, 0.6173290937177597, 11.18206351034103, 5.91840208538117, 2.5966222920725426, 0.5774685584249035, 2.206423681589865, 2.312744918369478, 0.9987127901084962, 0.3719342776363896, 13.950582204326508, 34.52903647576609, 62.398629726902136, 76.76737385411417, 94.40650786122968, 92.65628353241952, 95.43096819231587, 89.2377810324392, 87.29513306771555, 77.22311404443558, 77.5189313580913, 70.43481703727477, 77.413419600456, 78.2553171342419, 82.98226741052444, 81.0085464292957, 85.9261788091352, 92.56730848743071, 86.74004708566974, 83.64407324021863, 111.56199793661796, 48.11535796811504, 8.71171457152213, 2.212222170445227, 11.218855342557355, 19.480145515934115, 18.247674049869662, 12.300472451794533, 12.47742037619314, 16.835803178048906, 4.834232003458085, 2.354070275060592, 1.2707058724857148, 21.94314883601281, 53.72331180880147, 76.18978915675994, 84.66485438808319, 85.30119619061871, 91.3335975523918, 91.86357252059445, 89.54312186087333, 86.20011714196976, 84.03429415918167, 74.56486886547458, 58.30016866807015, 53.504408251854684, 37.44673859688544, 23.105572654354958, 23.03542498619326, 14.325995195296503, 8.564631573615536, 6.860786820611646, 7.171353226707828, 5.586739701609458, 4.897107597320311, 3.251997886165496, 2.7546661082775366, 2.918323571643522, 2.6133639485605302, 1.072624217598669, 0.37316682117600597, 0.11201826495028312, 0.31236588534328247, 0.4676933682733967, 0.08716828024555599, 0.14518031129433265, 0.03025658128242339, 0.11913991788582456, 0.1001110675955011, 0.060101447762140346, 0.07011265794356024, 0.15395204867086104, 0.21715673858359938, 0.033226079803200505, 1.2904022994541353, 28.701229864551177, 49.51069801084457, 48.44338186325566, 27.476103036634385, 61.94430943458312, 29.440930043497396, 22.830808662599136, 36.53671733794674, 44.78151982830417, 54.424745344346576, 68.753846076227, 47.277394571611964, 4.147203372370813, 0.09955511758885077, 0.0736357813941375, 0.0671528542654649, 0.023705901337727427, 0.04233231031966787, 0.07319917256433157, 0.0589754325788348, 0.03346512987909298, 0.06660286442286546, 0.0117477122130954, 0.030481811132161852, 0.14444426933844245, 0.02054879554517327, 0.08448478915999014, 0.07752258976500842, 0.05815238984782369, 0.04175441189398689, 0.00653489183018645, 0.05664784679069154, 0.08756680684464593, 0.10106654011554296, 0.08673524138547721, 0.055580364555240645, 0.047098445901346785, 0.0150287288969623, 0.03626689344884888, 0.007355487389084433, 0.038197320104847034, 0.04218274697421059, 0.07235940996437304, 0.06079434747657469, 0.08555073155871323, 0.052215932387738466, 0.037643706666365746, 0.04590974940407661, 0.038653586750789996, 0.04968817931629958, 0.057864562953792276, 0.07412468338565481, 0.014754919496725404, 0.035467603273930094, 0.007681741253397758, 0.0636869422610729, 0.02010448178606889, 0.011875589524636106, 0.0859305962559677, 0.08659113258604081, 0.03453559985744857, 0.11311544075367913, 0.018165220221083973, 0.08381159705740791, 0.036611521932026075, 0.02386939216164812, 0.10047603188262832, 0.11797240755010037, 0.0608469317516973, 1.6155428847958966, 43.82390060732442, 98.78200592533236, 106.78696724676318, 102.47567838238132, 100.69087443813201, 81.05232792515909, 64.58761038318758, 22.36502524345152, 62.26561038724838, 43.58799357568064, 62.510146633271255, 124.19583459054272, 125.46174818469633, 48.40460138936197, 2.306510801276853, 0.054292850376617525, 0.065008673756834, 0.11714250450172733, 0.20970242728869762, 0.15858683464748247, 0.10948714109197741, 0.03172566787520003, 0.10178945898529022, 7.62268957591826, 8.206347573188044, 1.7993697884582707, 1.1498316617742663, 0.30103639489220035, 1.3801072730172066, 0.11525038990282244, 1.0709763318300247, 19.923914632489605, 47.66709773771225, 77.5317261295934, 90.51296710968019, 103.36651140643706, 99.06491079638081, 100.7990377180038, 95.65082488521453, 90.96109005712694, 84.68455253108856, 85.06750137575212, 77.21969373764531, 84.59225916093396, 86.43913069079, 86.9363695575345, 87.82085618665143, 91.24025298703103, 97.86151193803357, 95.05684468054002, 95.47657751267957, 126.86918089466711, 65.27415852392873, 17.27287288635008, 1.8660679772015543, 4.983426707406198, 17.60289719027858, 21.688043763560636, 17.530484353342366, 13.668894248624003, 12.522437418660811, 2.511393846042695, 0.7246543346874176, 2.1162736415863037, 30.86861591185293, 68.60299171939974, 91.18998389090262, 98.13631319230603, 99.62879857709332, 105.68915074871433, 102.5403033533404, 102.98754768986856, 101.34751842867945, 99.62585679946407, 92.84399247938588, 78.63713633629584, 73.33658649075416, 65.24641167732977, 57.42221670766031, 52.16440108514602, 42.636693293048495, 31.301637734136275, 20.818646492496615, 13.647054491504548, 8.132919822969745, 4.220859600651649, 6.681690908247425, 5.372913162554465, 4.113677403619213, 2.1245848988333056, 0.9806124613650384, 0.7422093926898895, 0.25610186009397434, 0.15870024630379292, 0.3928559856309045, 0.45511588995014474, 0.3639451143962722, 0.08564873718686643, 0.25140730393750055, 0.048071258821554726, 0.006995929767482824, 0.19906730361042485, 0.12480773512394198, 0.33497366092858777, 0.26928627923611675, 1.0466423150031798, 27.992133978874456, 59.36835558183732, 46.85711653001847, 30.586697516902802, 56.192298704578036, 21.64189119492808, 30.55138637942653, 54.49126089772871, 69.13851291902604, 74.35676359361219, 79.75738094698998, 68.37297608775478, 9.895748688328652, 0.03349266307909162, 0.08640068312806469, 0.0484592670334443, 0.04191547804962724, 0.03377434594797031, 0.052639111696231755, 0.041301470069635304, 0.024054297058272268, 0.019796282698911045, 0.09408580139279367, 0.07085056149310644, 0.05328304690098571, 0.03669003828338558, 0.043296466446331436, 0.08649547884781515, 0.08447495259104237, 0.014454067192761409, 0.013246539296702513, 0.09421340865834106, 0.06867920784580131, 0.06997198121802461, 0.05370762815038043, 0.04035455475170766, 0.014814725108144265, 0.05441963409764632, 0.07329321751791625, 0.045296802455859805, 0.030738354825805274, 0.02972054956180434, 0.2119168503991058, 0.21250738161465815, 0.2070324729767538, 0.15065384097397327, 0.12243247951471037, 0.16127672256721606, 0.2285474394598315, 0.2205786081932245, 0.18532220003826005, 0.16778634019917057, 0.1335712447161636, 0.1672218406512853, 0.1013656285020613, 0.10470535816444505, 0.1587517120905461, 0.22042106987247545, 0.14514634295577003, 0.2412301782638796, 0.14858607773578938, 0.27821987566928713, 0.21169152861881643, 0.14988759983210795, 0.12581099620870045, 0.1738082509367697, 0.13521821117929875, 0.24915045487784573, 0.3714440120083671, 2.3065218329429626, 52.97502163917788, 113.1685144670548, 118.61721223400487, 102.75313900363062, 102.99770662861486, 77.47177662387972, 54.480764635147594, 50.57762584378643, 114.93284363900463, 55.271369334190126, 78.11844210470878, 143.3818494119952, 169.102870264361, 73.00622878536102, 8.640495115710843, 0.12169477514802449, 0.1100823837482641, 0.34489514306187635, 0.29728274792432785, 0.45697432732389826, 0.4703028782481148, 0.2022564050651366, 0.7826077217055906, 18.4597271873105, 11.449651525866601, 7.614332475969869, 4.207324972075801, 6.898025803027615, 6.246023937579125, 2.6040593510673893, 0.49179694585261813, 16.73924226914683, 43.37109042752174, 80.65158720939391, 95.35932217874836, 111.57735793821274, 102.90016512716971, 103.33965101549703, 97.81276472153203, 91.79084393285936, 85.43308981003301, 85.38754324759208, 76.93734584316131, 87.38874435424806, 83.84617728571739, 90.7043238609068, 92.8806980194584, 98.75942091788016, 110.38858952060824, 104.08028864091443, 99.29824475319155, 140.78723292196952, 60.661117799820445, 10.694126544460174, 7.873314321041108, 21.27565949193893, 35.172909229032456, 31.58997116550323, 23.931745406120058, 26.209061761056226, 31.266973787738433, 10.799380406256645, 5.047989901035063, 1.8695468743962629, 30.14388349748427, 67.8299004031766, 92.87376326899376, 97.11838752992692, 96.04949458952873, 102.3783879126272, 102.93080668295585, 101.58177806485085, 101.91770553588869, 99.31781738035141, 94.82436580042686, 81.82125368425923, 83.3131036450786, 76.77452041256812, 72.655592426177, 69.22138475602674, 57.1798966007848, 42.099779652011016, 30.525232015117524, 20.45932992812126, 12.851575266930366, 7.95394697496968, 7.18061492327721, 6.5568168605527575, 5.948052752402521, 2.735201591445554, 1.6417401500286597, 1.3596054118487144, 0.6896572932600976, 0.4473707716791861, 0.759253868412587, 0.7431753376318563, 0.812753587961197, 0.2651072389656498, 0.3589014366509453, 0.21753382238168872, 0.2310752997835798, 0.41964145317193, 0.3982999596384264, 0.706781687275056, 0.34681269177986734, 4.271314028770694, 44.266563615491314, 70.90420707579582, 70.49997545057728, 38.7892835370956, 89.5249455974948, 43.26221719864876, 33.716584174863755, 49.82174588787941, 67.36086337797104, 74.14033505224413, 90.76971761641964, 80.48860488399383, 9.426754809194996, 0.1993774160021736, 0.19203596478027685, 0.185431903829017, 0.12492585822098679, 0.3154439346924905, 0.14851116965855324, 0.13398695466739519, 0.168130865260478, 0.0854516993727415, 0.18696492237429466, 0.18510512136403592, 0.21730522174508343, 0.1378636506776656, 0.13060936493979347, 0.13893684792903163, 0.13045381844764756, 0.12005356966607994, 0.16501720814454943, 0.1887250859891215, 0.1566083206524772, 0.21210259607722684, 0.2445274819770167, 0.2011629371272941, 0.21427819385163246, 0.21949539051180889, 0.1500240247696638, 0.08537400273546096, 0.1908382016324228, 0.11342353833418702], [0.009201047303635747, 0.09159085220627247, 0.06963127127458012, 0.03387845729688003, 0.06932108227403895, 0.02127824339925522, 0.050583851012972095, 0.022779396517322432, 0.05806599811260259, 0.0055670829005389205, 0.04808740795499856, 0.017440391877185435, 0.024879971301303278, 0.012870612291378841, 0.0832343727891003, 0.039668400441446615, 0.006931055048029991, 0.029357902690648075, 0.07633427248126076, 0.013515921666346973, 0.019452154088104447, 0.014765547051454985, 0.06168569843735426, 0.10737824659313887, 0.09657321993501918, 0.099572699306713, 3.4217602735565555, 36.13935770527009, 83.540648183515, 90.08127889325543, 72.65345081206291, 58.48019761423911, 55.8530842873358, 44.78566969594648, 36.81746098303026, 82.12058544158936, 39.912344409573464, 47.64767808298911, 73.08560971290835, 68.37530597563713, 50.031000414202296, 2.1729751796491685, 0.5232716375781644, 0.24084843665121064, 0.1500156284460137, 0.03872498997577256, 0.24427525518882662, 0.12781040908228006, 0.15377583312651805, 0.13375096894319982, 0.4937919000944784, 1.3389336630221338, 1.9697068030795746, 2.8554496938182465, 0.5654168309223268, 0.20281469930083523, 5.4638974416640504, 29.0624781962364, 59.84753585630848, 87.20459691939816, 92.61829145493047, 92.55543155054893, 91.34517638914048, 89.49545721853934, 91.78689802846601, 93.39816062681138, 93.11538127160843, 91.39368826343168, 97.78911282939296, 97.30216626198062, 95.86524517305436, 96.85097602105911, 96.68502053906842, 94.07710721415859, 90.93011117750599, 83.74840828680223, 81.47304919458206, 76.45374113513579, 76.84016519977202, 71.88638425642445, 90.72165289232808, 85.6284003103933, 30.20227582223954, 1.2202386966636105, 5.874767188102969, 20.76041106254824, 8.816033928625046, 4.646106304660921, 6.62294949254682, 0.8627126942719183, 4.908653584218794, 35.219781552591634, 75.09094499772596, 89.7829669521701, 92.75920652574109, 88.7524583262782, 89.80660315482848, 88.27617276099421, 88.62103539128458, 86.83526654397288, 86.28221234967633, 87.32590798408755, 90.4335940268732, 88.81899741388138, 80.03976022043537, 85.28748358449629, 88.63941561791205, 73.0523637033278, 61.973605617400146, 50.627086931659335, 42.63416728665752, 37.541985511779785, 27.805195777646958, 14.901636358230347, 5.686544900940311, 0.6396527119701909, 3.2004226407697125, 4.177781189641645, 4.661911985566539, 0.9760513577249743, 1.4562479550800016, 1.5780733405582368, 0.133336071045168, 0.6804552289747423, 0.4119398793385875, 0.11795056638337913, 0.10511484748173146, 0.12597094770641099, 0.19942215553695158, 0.027404501057800748, 0.13910535662885637, 0.41489593684673315, 0.15051245178666808, 0.04417533400438486, 2.057273594602462, 47.866240393730905, 74.5393499251335, 41.39049353138093, 31.25043119153669, 60.37990347031624, 45.78706256804928, 27.079802443904263, 29.182851814454605, 44.806450413119414, 56.21963762467908, 68.86790075609761, 54.033865467194595, 7.473380632938878, 0.1761021633302012, 0.0824304094778434, 0.05243766887654221, 0.06751993295526312, 0.042712347386705304, 0.04790874859017711, 0.020253516530858415, 0.06758900344251625, 0.019156122392403985, 0.01792059302510273, 0.020992186168328892, 0.017275079679224762, 0.05629712024763708, 0.08643130366239818, 0.0827585402575712, 0.029840580217780608, 0.11565002732940259, 0.043365184533139395, 0.03864711713826945, 0.05772895773031539, 0.03041404874003943, 0.05115537941756268, 0.0857160609936522, 0.0752015425372989, 0.09036253747199813, 0.035611275403249654, 0.038024371925501094, 0.035020920387919874, 0.048372097718980045, 0.022316819222103206, 0.017965719434282473, 0.06974960121536447, 0.1145686942242807, 0.07276767354098058, 0.023044809593909213, 0.016809516556320653, 0.08282160461549798, 0.048319704965838504, 0.022234876542502356, 0.023945106546424573, 0.02363008927674063, 0.04680794536045963, 0.01184217947264833, 0.022831394735182968, 0.05102800580883219, 0.08755679407547559, 0.044301294180895054, 0.056670132288408864, 0.04505689436149213, 0.07974479632872729, 0.028382797252326727, 0.08287824915661927, 0.12440805939296562, 0.08818846421256181, 5.794778783475199, 51.95540151288433, 100.13472157139933, 108.07245346807666, 94.23238600454023, 87.20549906453779, 83.47163015796293, 63.447781378223056, 20.741367955361646, 47.38833096719558, 46.120883726304584, 54.56901404165453, 67.9115092369818, 64.40369436817785, 34.366622894041, 0.9054125965602937, 0.3102600935005373, 0.15642629816166817, 0.05688405084994532, 0.14515008146484054, 0.1944024410218962, 0.11512552523204397, 0.14657241562681814, 0.19798119011665546, 0.4966149953824859, 0.4708707945481424, 0.20625441875909606, 0.5004646178455122, 0.3492521915224291, 0.343120638281107, 9.091797144182268, 40.999178271139826, 77.74546392502324, 99.14483301101193, 102.25567263941612, 99.65074816057759, 96.33978920598184, 93.40377746089813, 99.08894708079677, 100.29919439746489, 99.42316439843948, 102.02413512814431, 105.35017167368244, 102.31459448414465, 102.11099993798041, 103.23823421232163, 101.5338388566048, 101.59967191757696, 95.86204451899376, 93.15249473817887, 90.855131149292, 84.65188703229352, 85.03859350758215, 85.19119724150627, 98.73360387740597, 94.33369298135081, 46.994976074464866, 3.294651700604347, 2.7388670463715834, 14.778448439413502, 12.093921419112915, 2.802620515708001, 2.9011597700657386, 0.7651425104948782, 7.818875255123262, 50.39566709149269, 90.61170885639807, 97.81378453777683, 99.29010975745418, 95.14739651833811, 95.0392803069084, 94.97494559134208, 94.8454995309153, 89.4236150864632, 91.00401647629278, 93.15407937572849, 98.51980332405337, 98.11506179071243, 92.05748665717341, 100.41926599317982, 106.33711845644059, 91.12226024750741, 79.11421422035464, 69.22289094617291, 67.72795015765776, 63.937646189043605, 55.516882250385905, 33.67933342533727, 11.6621773089132, 13.790945660683418, 12.312636702291428, 13.028811485536638, 10.67433818694084, 1.7197743562921401, 1.168021530874314, 1.0755218685634675, 0.5885457608007616, 0.2674963301227939, 1.1034297774876318, 0.324911954061639, 0.15427876984880817, 0.27491892537763046, 0.24802355486298763, 0.05612349408047815, 0.20167710469855418, 0.3317051927649206, 0.12687443349991115, 0.041166163620448885, 1.0969814009243444, 44.047934624456595, 84.37803499160275, 41.542881534945586, 28.374688625335697, 48.85069647142964, 32.43171572685242, 33.08688294502997, 48.13411866464923, 62.06133727104434, 78.17528509324598, 83.63218061385616, 73.460525543459, 17.0432573364627, 0.0361968653516904, 0.07512069727864958, 0.06702024444577194, 0.0792329193603608, 0.11096202888556066, 0.06256322917197982, 0.012849451027690403, 0.0878867864488594, 0.05323347335140552, 0.04157206381581003, 0.024178753787231062, 0.07103191748742135, 0.0786970944834813, 0.06694128376341636, 0.0863631907850504, 0.0537080341769803, 0.07260537015334254, 0.017068276159285058, 0.04931470762277323, 0.08883469002020937, 0.05324131426131053, 0.04698527173229283, 0.08274226855005949, 0.029648144676860784, 0.07371032941004924, 0.07658004880912843, 0.03166749115823017, 0.048955527299474326, 0.12409567172008178, 0.1801240023586058, 0.1988233352500585, 0.2732523470636337, 0.1755935422355129, 0.14416455531552916, 0.14348725698167278, 0.16553074752371158, 0.2428596319570657, 0.13114299114433028, 0.19244295665093009, 0.08849099233386018, 0.08841963890459269, 0.12435004355445986, 0.13061891039533, 0.10616447220766738, 0.08323420424975696, 0.17824000829169828, 0.19847953031139992, 0.12160030884608147, 0.09410575032234193, 0.16067655396557626, 0.1355992173475604, 0.208028816287556, 0.1812377869482002, 0.14571153198278722, 7.805505856390923, 62.4782616861405, 114.65239417168402, 113.00270019039031, 97.7324188909223, 87.89924867691533, 73.82648268053609, 60.09795173521965, 52.574759452573716, 113.81304617851012, 58.56597200516732, 71.33163559821345, 98.27507880426224, 85.99507131884175, 52.350301819462935, 4.449342075855502, 1.0824560061577828, 0.37536527901407213, 0.4383159188493606, 0.2899389984386583, 0.3389058370263346, 0.30459766186052756, 0.4864360464196052, 0.44328623601505834, 2.0047872561600903, 5.090708924878029, 4.13869280968943, 5.947551179316736, 2.423901702127149, 0.46199198872331654, 6.951266584857819, 39.36153381101547, 77.93558905201574, 103.87946328809186, 107.86643489714592, 103.38917486129269, 97.16955092645462, 91.72017851183492, 99.17837712072559, 99.95795603721373, 100.1381261887089, 104.99569139172955, 106.03764549378427, 105.87583987943589, 107.23900471964191, 103.80970785694738, 105.16323151126986, 105.6054787481985, 99.5773841488746, 94.54965868303853, 89.53319826433736, 85.50036630322857, 86.72793480657762, 88.25950268776187, 112.46593167704921, 96.38413552315005, 38.42584848403931, 3.6045407624013963, 11.881463296951788, 28.67424003539547, 19.592917580758375, 12.189264432076486, 12.07275434847801, 2.1421507433537514, 6.0915266794543115, 48.6279058456421, 87.7269075762841, 94.1796693494243, 97.40719164571455, 91.9736969855524, 93.70141475431382, 95.92730491392075, 95.24926831645351, 91.45486939337947, 91.03205357828449, 93.4334227346605, 97.05755941329464, 95.15666900142547, 88.23499571892523, 97.43498556075558, 108.85670000506987, 94.63963001005112, 83.13092524005522, 76.9892466452814, 79.78353531129899, 74.61224325241582, 63.71284730972783, 37.60528079925045, 14.52714120188067, 16.174511178847283, 13.397409358332235, 13.96324557642783, 11.174562957979019, 2.9342464333580387, 2.245915330225422, 2.729610743061189, 1.9034985428856266, 1.3996128521619307, 1.3967566312320772, 0.46748152964057466, 0.2917330231397383, 0.21248383207186577, 0.4678820097638715, 0.20953260091764314, 0.39563357529620974, 0.5882444737419006, 0.2612970240654484, 0.19377928978252798, 4.211985238136784, 59.20473391009916, 89.68916739186933, 58.03135687305082, 43.80038599814139, 88.2213144917642, 66.0801310693064, 40.54874897003174, 41.20591855818226, 64.01128868902883, 75.28860107544931, 88.04239949872418, 84.19333058018839, 17.809056966535508, 0.2523364153720679, 0.12348781925656142, 0.1492580900629682, 0.16174895448550103, 0.3009148933474095, 0.18852164367994956, 0.10133234964263055, 0.30924233037137216, 0.12670259997849503, 0.19124494835494027, 0.11212943962985471, 0.12091431541428452, 0.13239896165267115, 0.16958255591171403, 0.2114067430938444, 0.14900739545062666, 0.1831511834696416, 0.16617588548650666, 0.15737830030341304, 0.13828020332561386, 0.10213017658961397, 0.14649076597584834, 0.29575492345517684, 0.17437802116957404, 0.140602185180591, 0.19268606699282126, 0.12271482888008318, 0.16061971024159463], [0.033618799455824404, 0.023019151394105247, 0.046225519355146155, 0.05239973986341108, 0.052607265421219414, 0.14381302821059383, 0.040291467411143166, 0.01841900982863961, 0.06107739015151897, 0.022531346823539466, 0.04755837444756781, 0.008694479324584527, 0.020629497162336786, 0.06036226239596164, 0.10757184467248379, 0.061124761198316856, 0.012542685482560868, 0.04054092862192662, 0.06546894704262096, 0.022887091242497968, 0.0418050273231441, 0.020059972077668197, 0.03207648060314598, 0.055560806330533764, 0.005481142678388185, 11.719796926744523, 58.45238408734722, 90.88714553463845, 81.65115617936658, 76.52347303205921, 72.75367521470594, 52.25655324997441, 40.2511195213564, 36.00859372846542, 100.73436567860266, 71.25516506933397, 33.71429351068313, 77.48967832134616, 69.64188637272005, 51.65344176753875, 3.0995682074177653, 0.21843147824608514, 0.03062906472252742, 0.123816478636957, 0.038333189628657796, 0.0816159584229031, 0.045403966665147774, 0.1650249915978601, 0.2826650855281661, 0.10677891302733653, 0.20465398447648173, 0.6284067251028553, 0.18517668929792222, 1.7249368083092476, 15.330520079981897, 43.61980399777813, 67.35534852550876, 86.17456682266729, 88.28769668456047, 91.12277800037016, 89.94586298542639, 92.33437461237754, 93.47856921534385, 100.19798940227878, 96.82991289323377, 93.32948776983446, 91.84941276427239, 90.50265912086734, 90.28897623861991, 82.89839144675963, 80.50920517213883, 87.71921188600602, 88.64772319793703, 87.84853243058728, 82.22380653504403, 88.07723014585434, 93.61810361185383, 94.19804173131143, 92.92150635873118, 94.26476909268288, 84.42777849012806, 85.94573574681436, 106.60099198741298, 60.4264816161125, 0.8589899359691529, 5.260439688159574, 6.947248606912552, 4.667474887063427, 0.6507494649098766, 14.898146429369527, 51.944269826335294, 94.83675264543103, 90.0450675718246, 87.79782402899959, 85.62604688828992, 88.95619407776864, 90.17875763677782, 91.22658744935067, 93.81962714656707, 93.01290542848649, 91.95902732110794, 93.79290796095326, 91.50168680375623, 85.36680959886121, 85.80935493592294, 87.67681890918364, 79.48418001974784, 79.38787798727714, 74.12031527488463, 74.83077418419623, 74.2559116117416, 71.43801027728666, 73.73734289600004, 69.15068011130057, 62.410683170441665, 54.74292801272485, 45.87828513114683, 54.44747155712497, 51.30249946348129, 39.510654480226584, 14.169686782744623, 1.6234535699890507, 0.5561298840949612, 0.427091290513354, 0.22909153042541397, 0.18194165321127062, 0.0821834457136931, 0.0945921931716223, 0.09813871294740709, 0.17225062564736413, 0.1904279768707291, 0.28297136748029345, 0.11539179441188613, 0.04720235423695657, 0.05303929304523815, 2.093850677051852, 55.655334072728316, 87.87849149396344, 56.740681355999364, 33.47991620340655, 53.587946891784675, 39.90306015937559, 27.325054522483583, 36.3296240375888, 44.87874754013554, 53.37855116013558, 66.01056391193022, 61.14131396816623, 11.176659464836122, 0.2372114189089306, 0.015352808029180574, 0.06059575450396346, 0.05649369840900745, 0.0244293219950651, 0.05224090302363039, 0.028466614932122252, 0.025678924397535385, 0.02419551770623413, 0.07264978793119231, 0.05223469005056447, 0.10309656586257682, 0.041451489237407525, 0.06029753562723918, 0.04882303622340964, 0.08847537946196334, 0.030744033452544003, 0.13190302697400894, 0.04242962263824959, 0.11225292534236947, 0.033116942917507504, 0.1493771248046429, 0.01607981014756426, 0.05010537164766462, 0.0588305193870779, 0.1121626188978553, 0.03477695585799313, 0.03313744343036125, 0.0396077799039983, 0.023438586447868618, 0.05009727409830497, 0.016382194627376816, 0.027689700270251884, 0.07339292386126134, 0.037215881034611695, 0.08765583392232658, 0.07130999208217667, 0.016921185362603397, 0.05809735026090376, 0.015133328626923745, 0.010846138766576207, 0.07949106800820559, 0.04752711422981755, 0.05229826768740051, 0.020396102730545308, 0.1057646892243816, 0.05289611504262975, 0.05142549818922436, 0.02586631333425401, 0.07390261747904363, 0.07829158882340116, 0.15485161975506814, 18.615825753058157, 78.03422881710914, 104.92660276351437, 101.77843786055043, 104.81412487645304, 96.78412314384215, 75.05915026510917, 53.04580080893732, 16.121427782120243, 64.95792135115593, 79.12081164698448, 45.63192106062367, 82.13585130630001, 70.40285756511074, 40.51773478907924, 0.6900349439632508, 0.315134680319217, 0.06874033400127966, 0.015179102380399503, 0.013157892390154304, 0.054906482973526564, 0.055308820860039805, 0.17190522724582305, 0.12584753860268863, 0.22862050892604938, 0.32770970716111125, 0.8781349022061595, 0.6326811279981368, 3.307080711087873, 24.865753919847553, 64.18625385530534, 85.94421386718751, 98.37663681276383, 96.35045805285054, 98.60282421112062, 96.83947563171388, 100.38257614258798, 100.867216356339, 106.49336214988463, 101.32253293068179, 96.30387598468413, 97.48153624996063, 95.23696776359313, 92.3233292179723, 88.06259970511161, 85.00198210439375, 91.97761935572471, 92.23513864701795, 93.42590747341033, 88.89885687058973, 91.9293192894228, 93.79627335456111, 98.1972432905628, 98.82248478551065, 98.40312850090766, 90.74659132188367, 88.20110644063642, 107.13455200195314, 76.9687169597995, 2.840110774963133, 2.1831083778412115, 2.3207475341135457, 1.3102540277665662, 1.6074897685358602, 21.829558957007624, 69.33681226545765, 99.2128312203192, 93.48577068698023, 92.7705264860584, 91.48631111268075, 95.03757015351327, 98.05070354092507, 96.72629956276187, 99.90958536824873, 99.19725941073511, 99.70938759465372, 100.55592921472366, 97.40264954105501, 90.49817192939021, 90.10833540270406, 94.18435265941005, 87.48108479284471, 89.06113316935878, 87.58606310813659, 88.25674133916056, 89.85661337452551, 89.8021787212741, 86.59793961432673, 85.17620594270768, 85.76944874178979, 76.18418801215388, 62.53294344871276, 70.69656464361375, 61.330513415798066, 55.232039728472316, 25.391765332991078, 4.984285216177664, 0.3036569365330281, 0.7282189724426116, 0.21210081875324252, 0.15806724317371845, 0.21165861748158935, 0.3661659726452443, 0.3474102710043231, 0.24381244615201028, 0.1399486815376628, 0.43435683774371303, 0.1411323180241931, 0.06175318312260413, 0.15413517432828105, 0.4213942316991668, 50.443045400804095, 97.58208228695779, 58.77025296611171, 22.716004810025616, 33.75094021520307, 30.91853003348074, 33.20034142463438, 57.64911405501827, 66.93470570348924, 76.5261402437764, 76.59434241633262, 77.56184993251678, 22.16414301626144, 0.3373009747555179, 0.03520219211256312, 0.07177474698232067, 0.05505158385682491, 0.053883755594612136, 0.04724662645810074, 0.045561141094132784, 0.03581596643573815, 0.01829273747130027, 0.03250091629583509, 0.09554215751948858, 0.09788539065348525, 0.030459922084945346, 0.054635992649221615, 0.041320426915321624, 0.10985028208984483, 0.03755818827137832, 0.12472868251103549, 0.020191453832892642, 0.1590916712678248, 0.018162864500716813, 0.14008990218562467, 0.04769713595329274, 0.1125829560201495, 0.05588170140981675, 0.16704389374823342, 0.022709602076980858, 0.08099994712298916, 0.14104843139648438, 0.11644543343854528, 0.15264286569529964, 0.2015440045825897, 0.1914005867776371, 0.14228947851206028, 0.14267523442545246, 0.20882844354116148, 0.1412661535845649, 0.09057336486876012, 0.19705115937657897, 0.1877525526910059, 0.09855724976307924, 0.14246282888756645, 0.15298227328927289, 0.1421638247707198, 0.13493354822839462, 0.3016014000581157, 0.16357777490010186, 0.10974391844243774, 0.12610664486043877, 0.12639738288858246, 0.19653262510415048, 0.22152301074276048, 21.925270672767393, 93.43885129497897, 119.93230450537898, 110.42411050488873, 102.42629574191187, 96.04491326116748, 72.5208511660176, 57.633765820534, 53.14944159600043, 144.31221992738787, 102.00902615824054, 54.72918795001123, 103.2115464056692, 91.69688747775172, 67.87145399278211, 6.377247321990229, 0.782136730849743, 0.11733119195747761, 0.2154535259450636, 0.1599685814712317, 0.5035628919159213, 0.1823633999353455, 0.34151804363054616, 0.4542720287797913, 0.7229090638218388, 0.49871245218861493, 1.5068340277479542, 0.9100647114457623, 1.932922693029527, 21.64942999039927, 64.25622109443911, 91.49133174650132, 103.49521221653109, 99.1421579545544, 98.56094114242062, 95.4054178730134, 99.35858649592247, 101.36130163746496, 109.01539125750142, 104.27780351331158, 98.64337367396202, 101.99855342988046, 97.22047898077197, 92.88829957285236, 90.07558361176523, 88.39313783953267, 96.07561757487636, 96.17260209975704, 96.25614073968704, 92.14326104810162, 96.88402591213104, 101.33965015411378, 105.78972816467287, 105.44555587153282, 100.27318908322243, 91.62602593821865, 90.54895093364101, 114.21151191957536, 71.4953867081673, 1.4756171092871697, 8.101735999507289, 15.376099982569295, 10.066217837795135, 2.045965156247539, 20.071393789783603, 66.81116673254198, 102.86638567524572, 96.12908732506537, 96.61827748821628, 93.95740432123985, 96.53512324056318, 99.78508933897942, 97.66282819932508, 101.52337397298506, 99.9601290302892, 102.09957015129828, 100.9385407355524, 99.8182176774548, 91.97244182709726, 89.32375154187604, 91.54490347831481, 86.22787183330905, 89.19898094669466, 85.07864875178184, 89.0403446074455, 90.05193171962615, 90.36564288600799, 87.55077746606644, 87.24642507491573, 88.6816438551872, 79.15401843286331, 64.32341521786105, 68.03001188462781, 59.20857783286803, 50.739902142555486, 22.459009155150383, 4.528065516102699, 1.0593093643265388, 2.2457040125323884, 0.43858925902074386, 0.44877611401100315, 0.7453244900511158, 0.31222805080394594, 0.43167408976343374, 0.3979057920796256, 0.3753016630728399, 0.6878379263704824, 0.35021185454341675, 0.20469343800458217, 0.3014567933015285, 3.5928116498454927, 69.53506454344719, 103.24140348742085, 73.48844497434555, 50.27410499511227, 77.26957059675648, 61.11450064566828, 44.34643483931019, 48.4908543094512, 60.25220678698633, 71.60092200002363, 83.8012896814654, 90.45246847214239, 25.6135263366084, 0.44481838122010237, 0.17905849662999954, 0.11675800497253096, 0.12137864896607016, 0.09355336262453949, 0.12318684629374936, 0.15155195649112427, 0.17846274069480358, 0.12005923105584038, 0.1047814460170846, 0.21890282150237791, 0.23047601984393215, 0.153970189632908, 0.21481751975032592, 0.09425457056251266, 0.15997844868369643, 0.14481957581254745, 0.323948338026962, 0.12376596279922994, 0.2695751863141214, 0.1426015980541706, 0.3558696896558808, 0.1621495265393488, 0.31008233045858724, 0.2333897586551405, 0.23496727158706035, 0.14661773738841857], [0.05481589690692002, 0.060599653891498045, 0.08812384469614876, 0.08514466665444836, 0.02406339243715329, 0.048019616834578976, 0.060530675334795836, 0.03228148956212305, 0.030008610112652667, 0.015638999325493654, 0.016422979233245698, 0.07885626457150906, 0.014649070085837476, 0.055291273616134166, 0.05330281579987176, 0.008792416962434449, 0.04771519647610765, 0.049739733203164035, 0.06267454557781739, 0.033676359472015215, 0.034941400461379564, 0.059798666831826976, 0.026036030537779295, 0.04569250219050915, 12.808615507618075, 79.10818161502962, 87.31467431591403, 89.42186570936634, 67.46090735158613, 50.30101637686453, 46.51041823048746, 49.27748956987935, 34.735694393034905, 82.5909560726535, 71.17680395803144, 31.52800163915081, 54.712192320054584, 69.70671530692809, 40.62344658759333, 1.8679106331640676, 0.0477405310037636, 0.0890344474464655, 0.1411198461127858, 0.206070312509133, 0.08947054299736217, 0.189463441530543, 0.14612946358899917, 0.1732701354569966, 0.43317534630337073, 2.8202915287786916, 7.200433679165379, 13.015380309474084, 33.41023921966553, 61.8422572074398, 83.47781181335449, 88.27228961452361, 90.75895463266681, 92.90512654089159, 92.23972782011955, 92.78168170682846, 99.98640106570338, 97.89577776385893, 93.31230778847971, 91.28386974334718, 90.5560504236529, 92.87473601679649, 92.60050742856919, 90.77727994611188, 92.76637661841609, 88.53253103071644, 86.04751340804562, 85.69093073568037, 87.59227614248954, 87.83360388971145, 89.40836491123324, 86.39055605857604, 77.16316453872189, 77.97544817770682, 81.93937193962836, 82.89209212026289, 90.3524794117097, 91.49730943864392, 86.77763908140122, 88.8500939646075, 55.54313075157904, 1.735330108673342, 0.9845475792404145, 0.36027677897964755, 21.420818567276005, 60.7168193786375, 92.10322149338262, 81.0303234284924, 83.57481987245622, 87.03206754499867, 87.98458376238423, 88.4260622147591, 87.96646241218814, 83.87211984203708, 82.83646506647911, 87.51695094570037, 89.40266178500268, 89.84488548771029, 90.7155575290803, 85.26099974109282, 88.14485965236541, 90.58783731152936, 91.87573971286898, 87.45346346209126, 84.40300480011972, 83.71758630198818, 81.84412110236384, 81.13822783193281, 80.76973684372442, 81.56666832585489, 83.60484169375512, 81.44211738340317, 78.42662272914764, 86.31923167936264, 80.52478482646328, 80.34208866857713, 72.70660677263814, 51.618564051966516, 17.563708789886967, 0.3507874930097211, 2.3231607723620633, 0.15973729952689142, 0.17512458917354384, 0.3311577463342298, 0.08538091284853798, 0.23400396198755313, 0.10610168364139334, 0.337403078954066, 0.08118121118675317, 0.1520923549129117, 0.057455916333222584, 0.20217389739569158, 2.89696749179594, 64.88959758512436, 90.46729503139373, 85.93851074095696, 48.869072775686945, 49.96878770089919, 36.309113963957756, 19.39664217733568, 36.725720667069965, 44.30230033013129, 51.845155454451046, 58.72791098010156, 58.170212699520974, 21.48651630647721, 0.697694352317241, 0.07834205103497352, 0.017018645153110547, 0.08651856873785296, 0.01155307225417346, 0.029580152458361084, 0.03922114298949319, 0.07589289092368658, 0.01894618174241435, 0.034699485216650276, 0.06291866332532899, 0.13995766008813537, 0.10868928350147702, 0.0700964705057202, 0.035862759086153204, 0.03597055531797871, 0.06064598305871891, 0.026950289442714666, 0.06344959290037233, 0.03634477777767085, 0.0401625233221679, 0.05182721937495855, 0.046990385369187405, 0.04489731441642489, 0.06274626289884891, 0.06959007872689156, 0.06431041525736933, 0.06288412808170242, 0.07066437914486855, 0.041128027763578205, 0.0646659413412694, 0.047062140994615136, 0.005762348178729055, 0.0307981901231312, 0.03574619497803431, 0.010398837264567133, 0.03782089131193296, 0.0785452175524927, 0.013593089702959745, 0.06639955234864066, 0.03441051685161168, 0.011208145954315702, 0.026897948400508014, 0.011172254735063161, 0.03823651316305322, 0.0325742960276623, 0.0941842053866675, 0.08257039672424717, 0.054150557205561674, 0.047553310606388316, 21.990589903246974, 99.63097157016878, 97.84896819822251, 104.0678233485068, 89.20903005907613, 72.78050422668457, 69.94991794709237, 63.3681062729128, 16.737388949240408, 46.42911141918552, 66.07697748368787, 40.73368480128627, 59.83033626310287, 68.61140128104918, 32.76043780388371, 0.34799927004402686, 0.07492559766697307, 0.017102545187357935, 0.08433674266862293, 0.21720146279661887, 0.11178696002330511, 0.03781112369089838, 0.09200981803118222, 0.159261804074049, 1.5607770364130698, 7.414398481768947, 13.278649795439936, 22.446753709546982, 47.560813273153, 82.48308304817446, 101.66118252661921, 99.81194972991945, 99.63134811770533, 99.65290546417238, 99.96904850006105, 98.79418880708756, 106.04017934491559, 101.60160172370173, 98.94066579880254, 96.12596511840822, 95.82575475015949, 96.63567712230068, 98.88084180893438, 97.16625613550987, 97.50751802998205, 94.65999495598578, 93.41831376475673, 90.87998328670379, 91.37872834359446, 93.45880831441572, 94.59632704334875, 93.06800688466718, 83.99325832243889, 81.3039715059342, 85.568709681111, 89.7237156283471, 94.7765285738053, 95.95591468195762, 92.12483375303208, 92.57022673083891, 70.30919136539583, 4.769415326656834, 0.9228588087904839, 1.0931676313761742, 30.605267978483635, 73.160354398912, 96.08222284624654, 87.61876783063336, 87.93327916053035, 91.12807320010279, 90.60921422896847, 92.3119935681743, 91.8083377038279, 86.76138477940714, 87.92257893470027, 89.91200508609896, 89.51113885448825, 90.6004830329649, 91.38776548447149, 88.1724339146768, 92.69571119739165, 94.47172118771462, 95.95453400765696, 92.58368046052995, 91.57785138776227, 91.95042948569022, 88.36137448587726, 87.56077166526549, 88.29845182357296, 91.34829075105729, 89.53836010348412, 87.36339799819454, 86.02011957476216, 93.46802588432067, 85.75725017055389, 85.03395726603847, 86.11445257740637, 70.44016715018981, 27.23713263388603, 1.0336636823992575, 1.68153639522291, 0.2252737772200377, 0.20167407099037402, 1.2910118602937268, 0.6510789440043512, 0.2954959244497361, 0.46444337815046316, 0.7757354840155571, 0.017190993868655736, 0.10497038628184989, 0.1521248217191427, 0.23602444227905045, 0.7385672268367584, 56.78561602869342, 97.934475867979, 83.62370829428397, 39.75371199269449, 37.70366168791248, 23.32380548600228, 23.963224387937977, 59.28726057852469, 64.02748415547033, 72.59627834443124, 69.84596729278564, 71.78783862821518, 34.24869291244015, 0.782405045484343, 0.06630025969277467, 0.06197323038753483, 0.0567888337818365, 0.11325059398528069, 0.0338050392606566, 0.021300218631363204, 0.005299109653870185, 0.04945162285660063, 0.006276989288087334, 0.07265321234421385, 0.016846225574432362, 0.022386548544971213, 0.03141956403851509, 0.024611995660609776, 0.02049679349687311, 0.06360479082251269, 0.07486467069435505, 0.03755516222407741, 0.06360406686942424, 0.035155656101602706, 0.03225958327792826, 0.09731778844950661, 0.07206083485676397, 0.014019334320760062, 0.014955007298398885, 0.13599137775599957, 0.1372496312063548, 0.2360390745584042, 0.21729714717836152, 0.220777178183198, 0.11825868694652474, 0.13478327242116775, 0.08690675314996513, 0.2621462784947888, 0.1281383483400268, 0.13151779200040525, 0.1734399465062926, 0.06439734325413743, 0.11545452935200547, 0.2589363700920536, 0.30413384158765117, 0.16532945026072765, 0.14390454507402836, 0.225300605619146, 0.10460581269956405, 0.26379713668457927, 0.1209624180750501, 0.19111771647247577, 0.11129661778649015, 25.14436967911259, 113.32338533093854, 108.1333129636703, 110.0974476721979, 94.52311992645265, 73.80072839798467, 64.54130288093322, 68.82593923999418, 54.39425283862699, 124.62397698433169, 109.12268377119496, 50.564101511432284, 76.40104801424089, 91.38537283866637, 53.320829560679776, 2.4882114125836283, 0.5615336231647, 0.20413695173638485, 0.3472975947924199, 0.311074904616802, 0.26427563520208486, 0.2235862080969157, 0.2169640215053674, 0.5873531151202418, 0.9257346415711988, 5.594503052773015, 9.357549490467195, 18.618155640940515, 43.82117456005466, 81.89100127066337, 104.26999799666866, 103.73577902393957, 99.85209126626292, 100.36789078866282, 102.11310232839277, 103.35304983200567, 107.5611803608556, 104.89858135100334, 99.93983468701764, 97.89139255400627, 95.77608969903763, 100.6436255670363, 100.80968303065147, 100.71406349059075, 100.78710586793962, 99.51378683890067, 96.71144162454914, 92.56495506532731, 94.94597496524935, 94.16716483331497, 95.2237101524107, 92.32041881930445, 84.73977950311478, 84.56330422432193, 88.87499317046135, 91.96327132563438, 101.65715033008208, 99.56909225833033, 94.84766467925041, 94.83731746673585, 71.46319973853328, 2.500337665119479, 4.1212902338274064, 1.2765059548039592, 27.476416826248172, 73.48164358446675, 95.64770267855738, 90.60665684361612, 91.76145753552838, 93.74032466642319, 90.97060572716498, 93.41569362148162, 94.42309948705858, 88.9135265350342, 87.95642114454701, 92.14588903611707, 91.05968275377828, 93.06627319705103, 92.72224210923719, 90.34281469160511, 91.60367627297678, 95.03712300331362, 96.83695747006325, 96.3563729870704, 92.00117711097964, 93.89546225147863, 93.15359300182712, 89.19932611526983, 89.98651442989227, 90.50360048970869, 90.43035414911087, 86.82714723771619, 86.27126893689557, 94.43872620982509, 83.97559196718278, 86.21335906367149, 82.0715165907337, 67.62913780827677, 26.79436960527974, 1.3562825514424233, 5.233694516843365, 1.3681056783083947, 1.0324244585729416, 2.0106690953816138, 0.5534304353979327, 0.39039739497726966, 0.2948083452159359, 0.5970835962122487, 0.14021909525317533, 0.27097237747042413, 0.268173367986756, 0.5892737281899298, 4.558684518260341, 77.39200345931515, 104.22963680759554, 102.69345621908866, 68.69492423149848, 75.67082035926082, 54.76660736145512, 30.90528222822374, 48.69135410554948, 61.06309798456008, 71.49148787221601, 77.17173099517822, 83.87583824896043, 40.896023857978086, 1.1686019190857488, 0.1534263284937028, 0.21425568618841712, 0.18716916141490783, 0.15355765128568297, 0.10844205160655322, 0.16119625269164964, 0.11579638842733637, 0.18601373228574955, 0.16164413833570096, 0.1156141437710293, 0.21073396467874128, 0.1882923842077294, 0.20987337214812157, 0.14460375352251917, 0.08950982798611926, 0.21265964925048814, 0.18956413612731043, 0.16942282657950156, 0.16146760103442978, 0.2045343521862261, 0.12826487542160098, 0.25739022079975377, 0.23390925819835356, 0.1977658581228987, 0.15503129801682888], [0.05343406198305949, 0.03659422366669582, 0.08936817066804056, 0.0876477133903292, 0.10058496192458177, 0.015618925906657694, 0.07021121515501892, 0.03621880994028142, 0.051199341373097514, 0.03729983277979397, 0.09348021654952919, 0.040389990148645256, 0.0695070424567788, 0.05257298298660786, 0.014596287585464458, 0.03932334294903182, 0.018067630195629694, 0.021541371618607835, 0.03152266032092514, 0.046602403970375184, 0.05631261820634527, 0.061714920861225944, 0.22947196968861167, 11.327115701090905, 66.92561364942982, 89.24797135014688, 89.36680347688737, 69.54251704677459, 61.10330620119649, 71.43325636463781, 35.42209740607969, 38.36367107206775, 75.52612412360408, 69.56405870376095, 76.21791255089545, 155.7114121221727, 112.13458553437265, 37.95610935457292, 1.6820644443073582, 0.25143290659593, 0.3119025860101946, 0.30002963278562794, 0.2081290205880519, 0.01673519262112677, 0.14641161377151168, 0.07674537058318816, 0.0813759200935883, 2.7629763849319953, 27.56649994081067, 51.0792891440853, 59.355705938031605, 76.37898075965144, 86.9810139748358, 94.8301552188012, 91.39771261522847, 95.01595004912346, 91.22756804189375, 93.26487848835608, 93.68227358787291, 97.16154929130309, 89.79786411408456, 91.29551133801861, 87.34647689327117, 89.63331284061556, 85.04845434619536, 88.7743922202818, 87.23577191752773, 89.04557704925539, 87.96981996105563, 81.2135922524237, 81.58304814369448, 84.01141105159637, 87.69625033101728, 91.45368483758743, 89.88406996573173, 91.84959319330032, 93.57249429149013, 88.98003424367597, 82.2270856365081, 86.4046295227543, 83.99429382816439, 85.27276685160976, 87.898785837235, 91.09951050050798, 73.05481126231533, 56.69179293417162, 4.519302450841473, 13.35429564599068, 60.406387313719726, 83.34165065519272, 86.33576839200913, 84.00169141830938, 89.127468293713, 80.96183100054341, 84.76251356063351, 83.958843446547, 86.00538715239495, 89.00271338801231, 90.07315174225839, 86.11956734811106, 85.20672982738864, 80.01826563189107, 82.19145482586276, 81.37860636557303, 80.13957669658046, 86.49687582446684, 85.42917528460103, 84.8745442974952, 87.41321994412331, 85.23801465188303, 84.78411797554263, 80.62409923922631, 81.31527577677082, 79.96097549315422, 81.88652192392658, 86.00251597742881, 83.71635467775407, 83.48268339710852, 80.56482438118228, 80.42869460198187, 83.75994005510884, 84.61762120646816, 71.11582679133262, 35.59281856782975, 6.2988847397988845, 0.6325592280876252, 0.19200383505273252, 0.8135024542289396, 0.3756999675064318, 0.43074589763437554, 0.20460495484932778, 0.09704876135313704, 0.12315083250042894, 0.04117757066964142, 0.11609998141084948, 0.03007996162670034, 0.13469816005278018, 5.374046727534264, 62.31140798138034, 73.66066055913126, 69.49264018766343, 34.60931170371271, 52.51548459452968, 51.003242231184444, 26.53416741278864, 40.33698412679857, 40.48286884061752, 50.907363814692346, 64.21750730083835, 63.71613425593223, 31.770698293562862, 1.7405201398557233, 0.2096412628288231, 0.08429581059082862, 0.013688202391588881, 0.0798998601854809, 0.03952014710633986, 0.07918470944728583, 0.008569182771738739, 0.012973563017083273, 0.10728044780872523, 0.048733407766708446, 0.07102880717044877, 0.05919967800559056, 0.043864463185591084, 0.06967672327112767, 0.1991945048493724, 0.030232556765117956, 0.07016834487477619, 0.07846356024064365, 0.07988469930545938, 0.09939827640811283, 0.05043698812744791, 0.02288950441945945, 0.1231202579313709, 0.03171679849225668, 0.03209397996655636, 0.03565213470269115, 0.028044942901619983, 0.08132279955691869, 0.13938104102928794, 0.01489426131405297, 0.04393616901530374, 0.0281769379357537, 0.015680172720984105, 0.07249416483025398, 0.043008953648348974, 0.028848854501941995, 0.03018378186219883, 0.05039828153507364, 0.06629639860963629, 0.045655496313326785, 0.0237216463597912, 0.05257426235344141, 0.03423076581149813, 0.008307119414600874, 0.07554679538213438, 0.027827825922999653, 0.46710826096034824, 23.229605843943936, 88.14222381960961, 100.04471102068501, 105.70239267041607, 92.4357835708126, 82.64916404601067, 79.23218342565721, 43.06873452278876, 20.51984033276958, 44.703919656815074, 78.02719992976036, 94.09085119924238, 162.4295065479894, 93.3243965333508, 29.30293517728006, 0.8617234602570535, 0.20709732998042338, 0.30682474074344485, 0.17453631025648889, 0.3021956391392216, 0.09004976675515214, 0.1767818825018983, 0.14383579634370344, 0.31932254592257164, 7.014914395347719, 40.20229385745141, 65.68530136539091, 73.61988359881987, 91.07982020224296, 99.79120039170789, 100.69660894332394, 99.37184410710489, 102.40791551528439, 100.05156732374623, 99.35799029565628, 100.8444195408975, 102.96409191623812, 93.98562969699984, 94.40460158932595, 92.11391387447235, 93.93954969221546, 90.27989202930083, 94.63915932563044, 92.92080817684051, 93.71361332554972, 88.29431764541134, 85.52109210721909, 84.95596485753214, 85.12378738772485, 87.39563988101098, 96.01264784413, 92.36995050984045, 96.33039120704898, 95.78220859650644, 94.82089058045419, 89.23269764069589, 90.22392765168222, 88.46365421049057, 91.00087858015492, 88.32286465552546, 97.79897366800617, 78.06834559286796, 75.08797968587568, 10.725953636630889, 24.24181661298198, 69.09419013607886, 86.49046667160528, 92.689709971028, 90.1321755686114, 94.05553417821085, 84.97296440985896, 86.62147383536063, 90.7461755506454, 90.50331023431595, 93.0530155858686, 96.3890463306058, 92.96416605672529, 90.46516910676034, 83.927135006074, 87.41887600191178, 85.70316068587765, 84.5240334541567, 88.85955472146311, 88.29476479561099, 90.37741784126528, 88.52663178597727, 88.83522033691408, 89.21834961060556, 89.04430620131954, 86.99954325152983, 85.17426044710221, 84.64047293509208, 89.71928335005238, 88.99179350945258, 89.13259090915804, 85.8397376152777, 83.42903321789157, 84.39583470744472, 88.93500543409779, 84.02408030725296, 54.97022151947022, 13.28081690496014, 0.8719425828706834, 0.3991182028285919, 0.431520473812857, 1.7596461071122078, 1.735466288462762, 1.3639665971840582, 0.2559386374008271, 0.278848190341265, 0.02627321327435634, 0.10462193118949091, 0.048367259873738216, 0.1910765775509419, 2.549902205505679, 62.551366821412124, 82.67384359913488, 72.94675780880836, 27.044220662886097, 35.13582321905321, 24.67157502328196, 28.422708242170273, 57.80802888254966, 57.040844655806026, 76.32566005952897, 78.02996127836167, 74.25236578910582, 46.901219660235995, 3.1161137453971373, 0.22720051899312005, 0.04401209598947917, 0.04687287514248202, 0.02893974317327863, 0.041302136566129424, 0.03499286624813273, 0.0027683630938671773, 0.07497286529190118, 0.0810282847153083, 0.047357073354144255, 0.04940011493501164, 0.010943480771065, 0.0701958397703786, 0.06019618602529649, 0.16685926655848182, 0.06968640662249058, 0.13292518744785942, 0.02695947292170698, 0.12652390230927738, 0.07501293935122029, 0.029102542602847663, 0.08615605593208345, 0.051454008151326454, 0.07111535212325473, 0.12142870515104263, 0.19696883556823577, 0.23018138242825387, 0.15465272800816646, 0.25808144661207355, 0.13450289956263958, 0.16496679955913177, 0.12250295194286494, 0.2507564816023073, 0.17587054430717425, 0.20602425530312524, 0.1345666533996982, 0.17817234740622584, 0.23502028487142057, 0.13029681638844554, 0.29830636396523447, 0.07450941274122846, 0.2310831598456829, 0.26499060974005734, 0.18172653572213265, 0.2444360417223746, 0.27592366501208276, 0.458122356043708, 28.32189548400141, 107.13520311540174, 112.60732527702086, 114.47519717677947, 93.69772772635184, 91.31205589540544, 92.1718551266578, 51.76138147231072, 56.63827611554054, 102.26646700213033, 104.34177737082206, 97.07594748466246, 190.23369819887225, 131.89757316343247, 54.89978751828594, 3.665567449023647, 0.335367338191117, 0.5372330077713536, 0.4765944519350606, 0.4017896739946258, 0.31663563042398424, 0.3699744715084953, 0.50805737655009, 0.30991026711079384, 4.167597245785498, 32.97478160550518, 63.33729213283908, 76.62664705707182, 96.45059616334977, 103.63861407003095, 101.34584749898603, 97.73838089358424, 103.79438707905432, 101.17310631659724, 102.54928558103501, 100.94595401517807, 104.10543887845932, 95.63763787669521, 98.66887692482241, 96.25495618389499, 98.46195620875206, 93.27706921485164, 99.81087500049223, 95.62883607802853, 96.43335342407228, 90.16118541840585, 89.41475052987376, 86.35712961996757, 88.21273234582718, 87.61733224315029, 97.68498174605831, 95.5033516114758, 100.33207170424923, 98.8100665615451, 96.56922432684131, 91.56489972145327, 93.1465405802573, 90.14794349670412, 90.7485995754119, 94.11868433798514, 100.3215205284857, 77.42535145052018, 74.08987768234746, 6.723668113831551, 21.876572485893004, 73.60326843876993, 84.57849948636948, 96.71716044026037, 90.70037795651345, 94.05762872388287, 87.6037294633927, 92.25983388962285, 92.73892002720987, 94.46761838851437, 95.50635614702779, 96.69166503414031, 90.1276569981729, 92.55340760754001, 83.60221370573967, 90.58196160101122, 85.3022866095266, 87.4496901419855, 92.56730848743071, 91.9906416246968, 92.1413077077558, 89.45453905290174, 89.28796383642381, 91.24666998463293, 89.06132144312706, 91.00889590478714, 86.82058903478807, 88.76663377208095, 93.57770319907897, 91.63808330412834, 88.93240882504372, 85.63853571491858, 84.34084307762885, 85.92457063736455, 89.37379314053445, 83.421690540929, 51.08877735753214, 10.996440283713802, 1.6461893435447448, 2.8009294838674608, 1.8945883887429393, 2.010593222033593, 1.6416033573689002, 0.9053821981914583, 0.19807791637797512, 0.3938295914521141, 0.10288444377722279, 0.42717225068519193, 0.35677670711471193, 0.3864109492109668, 8.298248706325408, 78.75764723747008, 85.51025852080315, 84.7211717790173, 49.460911366247366, 79.08237241929578, 72.44616139319636, 40.573785458841634, 54.4046078958819, 55.81788493740944, 73.01286543569258, 83.4030592826105, 86.97162382064327, 54.19239982481926, 3.817577679311076, 0.4076325040190451, 0.27946862962938124, 0.1814458411066763, 0.2119734796184686, 0.11714859490072536, 0.195686174556613, 0.09525612327119998, 0.1650984594297986, 0.15394106297002685, 0.13837542805460193, 0.07668008457028097, 0.15718474052846432, 0.09182522914582684, 0.14422996390250423, 0.25242405583060556, 0.09165910297944661, 0.2537750518850742, 0.17096028843474004, 0.1841511733589634, 0.2342028843779718, 0.3216307381949117, 0.21565606427048484, 0.15905030251991364, 0.1335025725946311], [0.08579103801880153, 0.025940815384890285, 0.05019711833747645, 0.041257220831128864, 0.0838311552821148, 0.0403373445864887, 0.06606764475544614, 0.058212972080875794, 0.03887770577303825, 0.05343419987888587, 0.04138581635009858, 0.02399467435034533, 0.1199709470834463, 0.05564828591060735, 0.026858860679391413, 0.024188778047720273, 0.010937002540055302, 0.05671836901456118, 0.032451078445921024, 0.05909259423553463, 0.11204685535161726, 1.8745380904405349, 30.684521429000366, 80.62769213030415, 86.63917941431846, 86.68671854080694, 60.443838104125, 60.90093151215584, 50.640670099566066, 57.951599397966945, 51.24357761875276, 71.13452080757388, 55.17421222502186, 75.74433342103036, 141.47011756896973, 82.06887291323754, 23.438613260945967, 0.879628160788167, 0.10335368029172383, 0.0846830680365524, 0.04036444494681012, 0.06853551273384402, 0.036090042051528735, 0.1811727154399118, 0.2221147676989917, 0.023413732640385147, 5.362722354550516, 45.121546176172075, 76.1736446811307, 76.49709117028021, 68.84253086582308, 79.3709647270941, 95.75738783805602, 102.02660622135286, 100.52273027358517, 96.40541830370503, 96.07962623719247, 94.15083208391744, 98.14156916833694, 90.17118746234526, 89.30255505346483, 86.36068328734368, 84.99890696617865, 85.37547803694203, 86.86145228724327, 91.32728253641437, 90.58895910939863, 87.93075315413937, 86.5092940484324, 84.05064259805988, 85.21170339276715, 85.2036625339139, 84.45156374285298, 89.76736376362463, 86.54813335787865, 84.83247295502694, 83.19417738145398, 87.98200284281086, 85.76493017135128, 79.59762280987155, 81.96440450606808, 88.46350516042402, 83.51300331854051, 86.27003731266146, 87.80810063885104, 74.08708495478477, 51.36521816253663, 47.41175928423482, 67.13386012661842, 83.62486931585497, 86.32245586764428, 87.13567303073022, 82.57140697971468, 78.70376956078314, 78.65573621565296, 86.13539018938619, 88.41259279558736, 89.78513994524556, 87.48302244370984, 87.59382940107777, 85.15780218185918, 84.67758640166252, 86.32185966737809, 82.4632986130253, 81.26506943856516, 83.36967206770375, 80.89309538564375, 84.32560859187957, 84.44464468186902, 82.01665047676333, 80.6909050480012, 84.41131238014468, 82.59915382631364, 80.5692409699963, 80.2006950686055, 81.64508435033983, 82.37419020745062, 84.87537583997174, 81.49655988139492, 84.28658100866502, 80.5723161082114, 76.3893985748291, 82.83888124650525, 84.66075943362328, 71.56230234330701, 25.973068437268658, 0.24430712444647668, 1.5856922994698248, 0.48172377831032204, 0.4039544852510576, 0.7901818185083328, 0.4218280826124453, 0.0514851228123711, 0.14620276288159434, 0.18787189386785033, 0.2985706949426282, 0.19312555631322248, 0.29046615886111415, 14.588329195976259, 75.71792018028998, 73.97153192950834, 63.1883244360647, 42.55909704392956, 61.13739552036409, 58.390763651940134, 32.315862640257805, 34.89288730006064, 43.052962672325876, 50.83934207116404, 67.54007647114416, 61.25056374457575, 41.17123303874847, 4.694103367867009, 0.1513092598367122, 0.05421354495469601, 0.10756589983019138, 0.06100577625235724, 0.0703761538851165, 0.07152857994961162, 0.06820475427253593, 0.04581290056868907, 0.06040892864186918, 0.07408188205332526, 0.061228010698311755, 0.15360197713298185, 0.06352643151917765, 0.06998247662258726, 0.08501273099212878, 0.09699353407467566, 0.0425380279099749, 0.07507250268733309, 0.05391669354491657, 0.016641017432594975, 0.018297605960059072, 0.04213564022774658, 0.042071124133203304, 0.07969549857079983, 0.05249531316240469, 0.029135848275355758, 0.023378130619324023, 0.0932204208126472, 0.0595359752825912, 0.047643701320574175, 0.08633386493930895, 0.07172066117486647, 0.020959548907534733, 0.015669355559493267, 0.04050834690250697, 0.05160251812588784, 0.0347818166858727, 0.018690434780212182, 0.025144001589186733, 0.012108685182137115, 0.012357852406679623, 0.04403319405091386, 0.017323707110218464, 0.03884495168383564, 3.7025551546004514, 51.52962823067942, 98.98336472049837, 102.04414706076346, 108.51564207384664, 84.32611065526163, 79.63332422317998, 73.36465497170725, 73.76472888454315, 26.418014264875843, 36.92421220964001, 56.089665966649214, 95.49709935342112, 143.97189940175704, 69.46115139992007, 17.878920262859715, 0.47110861888335603, 0.08556562430796125, 0.06795220572741763, 0.020865427345157634, 0.07448862111496349, 0.3503199035842573, 0.16974728013719284, 0.0984130796766089, 0.13320871658863562, 12.577178997378196, 57.68515279216152, 85.84609969969719, 83.74571754086404, 80.96091316592309, 88.34597526058074, 102.76434129284274, 106.03371527887161, 105.56048916232203, 101.20094730008034, 101.52276992797853, 100.81118922079764, 99.26568908076133, 95.00225313248174, 93.01992647109493, 91.07450146828928, 90.12614296328637, 90.68297832242905, 92.76447819125269, 96.95815086364748, 94.38571929931642, 91.0424243250201, 90.97455947629868, 87.90005668517082, 91.73116114831741, 87.6540691621842, 88.71058310231855, 91.16291953671364, 90.89342917165449, 88.52919701606997, 86.19963076806839, 88.30611613488968, 89.4496988481091, 83.27097738942793, 86.43703614511799, 92.1258927929786, 87.11757521475516, 88.20871583877071, 94.46548461914064, 77.47865646116196, 62.63946717785251, 56.52751230424451, 72.89393917206796, 88.28565705207087, 91.06540941422986, 89.74712433353548, 85.10690550650321, 86.60900069821267, 84.85756043464907, 88.82572820109706, 90.78958049897226, 90.5544657861033, 88.97982243568667, 88.43993956042875, 88.26790440467097, 85.99522821364864, 87.59145244475334, 85.86123220382198, 86.32420524474114, 87.92138653416788, 86.07925322748001, 89.99449253082277, 86.39581203460695, 86.51385184257262, 83.65424002370527, 88.21575257085985, 84.51469036840624, 85.53999793144965, 84.83386147406794, 85.45951874025407, 86.41498458000922, 88.23064188803397, 86.29058268762405, 89.49686142706102, 88.76806935956402, 83.573972640499, 85.14352475443195, 93.7642825034357, 86.79925918579103, 41.01276143904656, 2.0066693809724625, 0.775107353204681, 0.7365804237704123, 0.6328820268954001, 0.7012700217385447, 1.8299240715080693, 0.5326261840039684, 0.28911631193853193, 0.15622412755845055, 0.3420096575733154, 0.08955182492612832, 0.3107954357420245, 8.9227282808673, 79.30050326931861, 82.12559038592924, 65.8490171740132, 42.67656810822026, 52.42734501438757, 23.904408447204098, 29.978965482404156, 51.12576530825708, 60.2720461353179, 70.25037934703212, 84.17910022120323, 71.46776537741385, 61.73995787097562, 8.079684434398528, 0.08157915555902066, 0.03645478417315791, 0.03986919591684015, 0.01887559440107115, 0.038950361551777016, 0.0755351814892023, 0.05473014485511569, 0.015301564407925454, 0.053543899839203206, 0.09814425176309963, 0.01622801368695594, 0.039137987975752166, 0.029332035731884743, 0.07762015872304479, 0.11428268295862984, 0.0683057629653523, 0.04982904756381627, 0.049534528891766266, 0.07437733152220327, 0.005016670273166271, 0.006589817940332597, 0.02560847878245817, 0.05571034669335331, 0.2064368855809012, 0.13545255747533616, 0.15640443401230922, 0.3017381620743583, 0.2457401072306018, 0.17602832777605903, 0.14885846795814653, 0.1306127510484188, 0.14203355918007513, 0.10023489038670257, 0.14365575035973904, 0.13634601517790748, 0.2359910408455518, 0.16304053276056246, 0.12090797986715071, 0.05740565330451054, 0.07047743070870638, 0.10004390466717944, 0.10035559520005219, 0.13289800664830592, 0.135660320520401, 3.8002113853731467, 56.71014570420789, 115.02914567147533, 112.1141342962942, 112.74458469883089, 85.35912959806382, 81.24093117252474, 68.6318446743873, 85.42767693919521, 77.51468735356485, 102.75200151628064, 82.38338424313454, 93.1954211573447, 154.78629758281093, 90.63858493681877, 36.239193793266054, 2.8702051601102276, 0.22372028880542327, 0.18130822107195857, 0.26289180461918155, 0.13193249071557678, 0.3979640760489049, 0.6209761625336063, 0.5509917630303292, 0.21234654911583473, 9.08987714398292, 56.03439977092128, 92.3709624813449, 96.95837051637712, 88.45708816282212, 90.60053010140696, 100.03716438047348, 108.6224639031195, 109.18122906838695, 103.60951792809271, 102.63920199486518, 100.95863896031534, 105.58441562037315, 97.01485264685847, 96.90323768123504, 93.71344858600249, 91.49716038857737, 91.7246029453893, 92.61839343655495, 98.17847867165843, 97.29098750698952, 92.43266920889579, 93.32134492935674, 91.18912881420505, 92.5768712259108, 90.23302755048199, 91.1197263963761, 96.93803694940384, 94.98552814606698, 92.19236127791866, 90.75402029099004, 92.82401977046844, 94.38735100530809, 87.32713176358132, 92.307616203062, 98.26992480985581, 88.41111013966223, 92.72170082215341, 93.95909094041394, 81.56943751919655, 70.96251703077748, 61.73448224221507, 74.28018323836788, 90.11606247194352, 93.00342898215018, 92.66190821124663, 89.71383910025321, 88.66787633588238, 87.07730816256615, 90.14635101441415, 92.24090453117125, 92.47979256414598, 92.52095391673427, 91.31027513934721, 88.12855043718892, 86.80436611175539, 90.13365822453653, 84.50330765016618, 85.99139998036047, 88.71312479819022, 88.12259627926736, 90.38063418480658, 89.18542523537913, 88.58662051539268, 85.67577469733455, 89.09193946469216, 88.11020158952283, 87.12389807547294, 86.06066903760357, 86.55284804682579, 87.31755333562052, 90.79168288938462, 89.27032886012908, 92.12326480496316, 90.56635841246575, 85.27095471659015, 86.0893415635632, 94.01076424506404, 84.93880056565808, 37.71446389536704, 1.322584733847649, 4.434521400159405, 3.1900249277391746, 1.4553770663276797, 3.119776993989945, 1.3464081071076857, 0.2698639708180582, 0.35903951633841763, 0.5397322317284923, 0.6365924665043432, 0.3295051414639719, 0.31203447570723875, 20.273427232619255, 90.61195988808909, 86.67233128701487, 79.768967628479, 59.18110555218112, 91.03051600917694, 77.69733644300892, 50.30905723571778, 49.403040716725016, 61.20474653859293, 70.36362601864722, 86.74218085504349, 81.02885646204795, 74.0317403116534, 10.019300406978978, 0.19127810464030315, 0.18162702090076863, 0.11669547687615119, 0.10470286837869114, 0.18013169388136557, 0.12740378493383048, 0.1647055788987106, 0.14065792573796165, 0.15465922443376434, 0.14338104655185055, 0.1575713851038487, 0.30355244214015625, 0.13737652601013262, 0.22677604499603474, 0.21261414362778588, 0.20950598702315362, 0.17559423171464475, 0.18799601543334224, 0.19092768070197877, 0.10543840471655132, 0.15421248792159944, 0.14535831948441846, 0.12368072785677449], [0.014097030958040588, 0.03506140047383886, 0.0973352016280255, 0.016786499444635648, 0.028335403222891114, 0.061573206086552916, 0.03867703670215222, 0.020125459188655503, 0.044294958633761254, 0.04328825781422277, 0.061596629224837794, 0.04244085348721954, 0.03272876999671421, 0.055228404610628085, 0.11750840341612218, 0.027904333208777735, 0.04642390548401783, 0.08817692692842215, 0.061989739582303076, 0.1163281913426134, 2.274287549718734, 46.34700444436843, 90.99691698628088, 80.28009168563351, 74.65635422737368, 65.20939234764346, 52.09827776878111, 47.051493506277765, 38.99520012640184, 28.398122825930198, 53.1987654009173, 69.9324006419028, 90.27077644102036, 110.24004936218263, 44.98684021734422, 19.172617966128936, 1.6778617472417894, 0.08040070548773774, 0.032086677233418154, 0.1114272740819762, 0.14464737456892768, 0.014942484633666615, 0.21613375073479069, 0.47301535043985615, 0.11244351269617198, 5.085769189942268, 51.442437864119015, 82.64444935706355, 75.12242594072896, 68.54177136575022, 85.60234792770879, 100.78789034197408, 105.26256161351358, 98.7994840068202, 94.69951675784205, 94.40182455124395, 92.11080735729587, 89.64538589600595, 90.55257520368023, 86.05328713693928, 87.4857053449077, 88.14382414663993, 90.3530756119759, 92.02479762415733, 94.00997192628923, 91.33639027995449, 90.53804674456197, 87.19989791993173, 91.93352407024753, 87.82841067160331, 87.68153359813076, 88.05975990910684, 84.54958377345916, 84.27410787151706, 89.64370712157219, 88.32277051864132, 88.36669321983092, 82.88605951493787, 85.21120132938509, 83.10198599292387, 80.52483973964569, 79.01406042037472, 89.6379255479382, 81.74140207229122, 89.76537904431744, 73.0981848316808, 45.78286955433507, 49.78828807030955, 76.79556785091278, 88.94674116565336, 78.52187356641217, 88.56447481339978, 79.38803488208403, 81.9640201137912, 80.2206991564843, 87.97465232110794, 82.75291073706843, 83.76165805324432, 83.78931076295915, 85.63682556152345, 81.9678875707811, 84.01360757889287, 80.24121315248551, 84.16116714477539, 82.48684067879954, 81.65005791571834, 81.76003333060973, 83.7376453030494, 83.98138923029747, 85.1850861887778, 81.5992396877658, 83.0007339292957, 79.28741039768343, 84.85590519443636, 80.57770544482817, 81.14734342021328, 79.06156032316147, 79.26490383763468, 77.7488842318135, 81.11972993420017, 78.10484716969152, 84.99442761944186, 76.37778835911905, 81.18838710169639, 81.59314432451802, 87.30584113828598, 48.17563303055302, 1.5180293302382193, 3.1006093515503794, 1.8204240909507199, 2.285654578478106, 1.3962273564069503, 2.0981383179464648, 0.05077344628291265, 0.16009376023805913, 0.11627130931423557, 0.07174850847091406, 0.06999152412097301, 0.23387967188271785, 19.221475008995302, 73.34269754348263, 66.88784122467041, 67.5930755369125, 45.739574432373054, 61.27535704643496, 43.53046024999311, 27.26169255471999, 34.81626772111462, 45.855904086943596, 51.450941562652595, 63.52191809685, 67.62789049456197, 46.73647619062855, 10.152394271666004, 0.053090977167049726, 0.08638626535332973, 0.01460721774492413, 0.011995161485467708, 0.04911614529367897, 0.13273461541581538, 0.10367324620845819, 0.15968137510841893, 0.055080733502343784, 0.030738237997396823, 0.06720877868393738, 0.01668748832608183, 0.0262568477210739, 0.03574509947230259, 0.09913379987401348, 0.039572827142453006, 0.04930521962383101, 0.028362110963151343, 0.033171488377716274, 0.0144908623957646, 0.020919451865577893, 0.06975997404585924, 0.05005494391004886, 0.026601332562765288, 0.022206833894034068, 0.05677578347404638, 0.04484729653584861, 0.042467348638080785, 0.059218948947325836, 0.04298937627144399, 0.016225759473238743, 0.0410322591121639, 0.035568355327291835, 0.025642075568377495, 0.013739200864708232, 0.03934979596505723, 0.050187071094349514, 0.009901391477474283, 0.046227917210349155, 0.046837757672033006, 0.01118734379434177, 0.11474029025844029, 4.84724985976373, 71.24723403684555, 104.4142549268661, 91.74339894325503, 91.246944550545, 89.78601855616417, 70.6004273506903, 67.37594096891343, 45.489946949866514, 14.438238720740042, 33.515554858792214, 67.1310438648347, 98.34600310171805, 111.60629718534409, 45.75647200307539, 21.312629791998095, 1.541336298950257, 0.02923484024171147, 0.042254736256455226, 0.12263773745226285, 0.1181222313654519, 0.3171429338474428, 0.3581734079747431, 0.16458605386076436, 0.03570932316623869, 9.678302291900883, 65.95917301793253, 93.70132061742967, 84.07964460311398, 83.19405186560847, 96.36169956576441, 109.77127121340845, 108.85353072997063, 102.73191113625805, 99.13842385815036, 99.06627578120079, 96.83105038058375, 95.38923417368244, 96.3156666294221, 92.28852994980352, 91.59359578163394, 92.92662897417623, 94.57717803216751, 99.80931389716365, 96.02934929632373, 94.1193432961741, 92.68264970471783, 91.03987478440808, 95.38283286556121, 92.1620648907077, 90.89371942704724, 90.52307897998442, 87.30828085253316, 85.89119126719814, 92.6954758551813, 92.3423448685677, 96.53669218863212, 90.96963297936225, 90.01331206290953, 87.20221996307374, 82.91542237804782, 83.07488241503316, 92.36358842542096, 86.55430716852989, 93.0617703160932, 79.95927318449944, 49.74342792264877, 52.14256132802656, 81.80539161928239, 92.25226371519028, 81.03248857682752, 90.18315069137081, 84.09494184678601, 85.68795757908975, 85.17570387932562, 89.80352017187303, 90.14313467087285, 89.45235037034558, 89.07740316083355, 90.88086974236273, 87.25647418729721, 88.28169545819684, 84.03376071683823, 86.52648971926781, 86.96444588322794, 85.2932337791689, 86.92484563396823, 85.85045353058847, 84.57116465414725, 87.95287532191124, 86.332214724633, 87.47859801015547, 83.53929888817572, 85.98352386105446, 82.97811754288213, 85.75459080357706, 83.82137221674766, 82.87033081054688, 80.20947333305114, 84.55936616466892, 83.30205040593302, 88.95617838828795, 82.47747405882805, 85.54806232452394, 85.96112712737053, 97.35199605264972, 64.07398385386314, 5.946983906530566, 1.3964781429498427, 0.6322386356130724, 0.5769206523414582, 2.014407114155831, 5.077215971485262, 0.32821682672346797, 0.26813071221113205, 0.08515824939334586, 0.20273272789293723, 0.34255229297184175, 0.4152205742655262, 12.597640041382084, 75.67063993023288, 74.10610060538016, 70.9498477751209, 46.52457406443935, 40.73710510807653, 28.00647024185427, 35.57333615518386, 47.771232743417066, 64.26600740801904, 70.98223870800388, 78.31770635420277, 78.73727444679507, 63.70592432637369, 14.643514002523116, 0.017253458762781757, 0.07047478770536762, 0.03779354963391539, 0.05133953546324084, 0.053518707037813244, 0.061506901176706444, 0.09628159324488333, 0.06253226006764077, 0.06060041997942233, 0.021846571471542123, 0.034002103887858896, 0.05303908620149859, 0.03071468653938463, 0.1347874705829928, 0.08897276970768168, 0.04243399316985761, 0.043172344880839514, 0.02977593771872982, 0.054775704103972644, 0.03857489802964753, 0.00879229917641609, 0.0206386634043508, 0.20423245225702563, 0.14111690433515658, 0.21572055355195077, 0.15460330001529188, 0.13374767476512542, 0.20263339693267501, 0.17857838932785297, 0.04325425500170358, 0.09945273759864992, 0.21573791310431498, 0.1766928477633384, 0.19151148566555595, 0.08726504481127186, 0.16620642175116848, 0.3074492249758013, 0.10686243959372083, 0.2623294960827597, 0.15765415324318796, 0.09747397845550891, 0.3477834171104816, 5.757976164740901, 78.25358344662574, 120.05961679643201, 104.3070879290181, 98.74815587074526, 92.81397850282731, 76.60552901606407, 66.75837163002261, 57.34340452378797, 47.72307388244137, 85.83968270209529, 94.72751463613203, 108.54021180060603, 132.74944920693676, 65.35972502923781, 39.535102613510624, 5.184123602605635, 0.22552145344595756, 0.1813255193372888, 0.16130673789208935, 0.31969029876974325, 0.33349967711875517, 1.3982926068767425, 1.277274739357733, 0.16964983375322434, 7.11452151498487, 66.00864979528612, 101.44105126780849, 94.2122720902966, 86.03386355984597, 96.76251872893303, 110.3003675706925, 114.49074545214253, 105.10277209743377, 100.87601031026533, 101.33082482122607, 99.76550886707922, 98.51803825747584, 98.93879090586017, 93.40095335437407, 95.03593060278124, 95.66915804339995, 96.44051567200692, 103.05829155829646, 100.16871283131262, 95.6535940785562, 96.5682908027403, 92.78810654917072, 99.88028526306154, 92.40155696868898, 92.44591113059752, 93.28591023722004, 87.0706009095715, 85.33099835918796, 93.6628657002603, 97.96775325652092, 98.51929341593097, 92.00538973654471, 94.72946797647785, 88.16473822439872, 87.16589097053775, 86.89983660174956, 96.20802110241306, 89.97041702270509, 98.40551330197243, 80.62854720700173, 61.71001449708016, 62.138611885809134, 81.88918129090341, 95.2936303231024, 83.29474695267217, 95.09328349944084, 88.94240302424278, 89.48855384703606, 86.24356915873867, 95.55030238243842, 92.51250513138311, 93.76305087920159, 91.04815883021202, 92.38979770291238, 88.8238533081547, 91.96187496185304, 84.2986854430168, 88.49660211993803, 87.30729241524973, 88.16033732506537, 88.07741057488226, 88.91955129561886, 87.89141178131105, 90.14652359870173, 87.51773541973483, 88.61046852604036, 84.81574796861219, 89.55479483450614, 85.28515369661393, 89.66960260944983, 85.1169938425864, 86.23293169083135, 83.33314695665914, 86.86070703691053, 82.90073702412268, 89.76721471355808, 84.81085285063713, 88.33096827230146, 85.14750203778668, 99.23048188609462, 59.365511863462395, 4.585993530288819, 7.276042267199486, 4.368236776321165, 6.64366941298208, 5.335287336380252, 5.358736245862899, 0.43432714417576795, 0.46244361287643837, 0.3378597899310051, 0.22987750599220877, 0.33306021844187095, 0.40778201373834766, 26.911519035216305, 88.81788346075243, 79.6690962391515, 86.09559382161787, 61.829540883341146, 86.69916029899352, 67.60130466953402, 43.660157342110914, 51.13986622902655, 61.65610151906168, 71.82937652834, 85.77321421715521, 88.38084513141264, 75.34491062164307, 17.416482625469087, 0.12907884384114898, 0.17991827710741953, 0.058469351065615495, 0.07618175969729502, 0.2109188983036626, 0.2088569573337032, 0.17925830768241038, 0.2509878861207155, 0.14046439660652993, 0.09674186653067028, 0.20621934725392252, 0.13810812465606198, 0.0902236840357223, 0.23976688904146995, 0.18644920730542752, 0.18691290500423602, 0.1649735870981409, 0.1212951683649613, 0.18459725103551344, 0.1348831856082524, 0.15441177803422176, 0.10832699286120553], [0.08858637028043309, 0.055104719715253006, 0.03891429796274151, 0.060002162767153595, 0.052968552486310085, 0.05409079851702817, 0.0717619379922267, 0.047709638508216995, 0.02733848151570607, 0.041214917455950094, 0.0646347462409927, 0.017733901228395202, 0.05427035420472103, 0.02603773891385044, 0.09513751753876287, 0.09399649086258105, 0.03919292031036269, 0.05561020367989137, 0.027175450344539942, 0.2565792554448689, 37.52578220059795, 87.11300173113423, 76.26830716286936, 77.41895798713931, 66.08515170312697, 61.92122628611904, 49.27867020330122, 43.130001944880334, 51.39259630633939, 64.63771866213891, 66.67033010913481, 90.74065285344278, 50.21426531576341, 34.34605398485738, 28.874845735488403, 5.599064769283419, 0.0848048223903583, 0.07320058982699149, 0.08213088442120822, 0.10296043969931142, 0.03749538821378543, 0.47087070261759145, 1.1612826537701393, 0.0826665484196236, 1.8266434991551985, 40.97725614424675, 84.84839777792655, 78.55603741061303, 77.78095353034236, 96.80087950921829, 105.95467167515909, 100.83152278777092, 102.85368504062777, 101.45674074849775, 93.29480617277085, 88.76177003306728, 94.88958697165214, 93.08334335204094, 90.15642366101666, 87.6664089387463, 90.47015836161953, 91.3550921409361, 89.50945223531416, 89.64477400625907, 90.7361578172253, 89.35074529340191, 89.56982535700645, 90.67824794400124, 90.3355190830846, 91.77462100982667, 90.12133413745512, 88.52627092792143, 85.59879426033267, 88.05300558767011, 89.2013422135384, 89.19484676853304, 89.5947245628603, 91.09958894791143, 85.1496514966411, 82.77192638766381, 74.38646378055697, 79.09230386057209, 82.09138731802665, 79.53635538777998, 83.55323899176814, 85.38947305371686, 41.47472250846125, 36.95988224398705, 85.24898944362518, 79.8226256524363, 80.22808890188895, 79.38553240991409, 81.49121761322021, 81.97776409887499, 81.47606941961473, 78.18353776008853, 82.681562823634, 82.28051616299538, 84.11166683320077, 86.03484415238904, 84.19788052958828, 82.96084342464324, 82.33838681251773, 83.68743112010341, 83.96100075014176, 82.68506942256805, 86.40711630544355, 81.9793644259053, 79.01878295406219, 78.60771856000348, 79.59415543463923, 82.50188689078055, 82.53155569876395, 78.50543099064981, 78.68472253122638, 74.37576355472689, 75.31399449994488, 78.8884739721975, 77.52436776315012, 77.25649341460198, 79.95466832191714, 80.43966154898368, 82.04871977529218, 80.39986518121536, 79.9509342255131, 80.07948598554059, 88.2237777402324, 65.93244598757836, 5.692843737140779, 1.5945005945621, 0.10414906341822878, 3.024452857432827, 2.2086640904026646, 0.1576277998185927, 0.15456231431134287, 0.08875743771392493, 0.21167757049683603, 0.13146678586640667, 0.0387328538683153, 0.12654322304672774, 21.782725857150172, 58.636217732583326, 60.176297157041496, 64.43063712889149, 42.290332317352295, 37.138659954071045, 33.09433544835737, 30.32411836808728, 50.30914745023174, 53.438994884490974, 62.61157520355717, 58.96538695981426, 67.380734105264, 50.80430353841474, 10.764835111556515, 0.18201199540447804, 0.09395393467838727, 0.05269490204931748, 0.14808508687682692, 0.009389106567288119, 0.0753096605260526, 0.05945228400730318, 0.011308692121547798, 0.04744912264868618, 0.06728016275672183, 0.07929186982613418, 0.0023112736216130397, 0.15996072140912856, 0.019608284722292618, 0.052486644877541455, 0.013119460631822868, 0.035566152824509534, 0.05847968176127442, 0.05847128926806393, 0.14162338038365688, 0.05606695296122663, 0.02156037059912999, 0.023688740968223543, 0.0390363204473209, 0.019227684580630833, 0.04691861059156157, 0.021446037722090562, 0.026765509035378218, 0.018712454062375813, 0.04360316208593788, 0.05469096328822836, 0.057081709195288925, 0.03310670032195988, 0.04730939587217666, 0.05630349026872747, 0.023540679155097857, 0.06196363896672284, 0.06872377884123596, 0.05896508656141739, 0.0382960535165283, 1.93652244825517, 61.30395896973149, 103.1675531018165, 91.40838930683752, 98.99220574286677, 87.32868502216955, 75.0093126296997, 64.14360592442175, 50.015510974391816, 39.83392446271835, 38.240261539336174, 63.988652690764404, 97.15011950462096, 53.062412046617084, 37.32257989145095, 35.247395038604736, 5.131492259040956, 0.09017522131363231, 0.09504306655857833, 0.0331875111066526, 0.11507722338841808, 0.19484376895331568, 1.1329506385710932, 0.43862526515318506, 0.008418928989539705, 4.042985261447968, 58.48096639879289, 94.8998478920229, 86.76700161349389, 88.36695994100263, 103.63142828787528, 108.01666951948597, 104.6084200951361, 106.00995356036772, 102.89910608722319, 98.57033914135349, 93.50939904489826, 98.85073369549167, 95.86453914642335, 94.4848846620129, 92.80485506980651, 93.84564030554988, 96.4446420054282, 94.20321925993889, 94.7738221383864, 94.83070435062533, 93.16417555655204, 94.62766678102555, 95.99950790405275, 92.93433250919466, 96.18058020068754, 94.97303147469798, 92.03853376450078, 90.49344155096239, 88.98265438695108, 91.03516009546097, 91.76292450197282, 92.44020015962663, 95.76861366148918, 89.68401339746292, 88.58934264029227, 79.55075833105272, 81.30788603136617, 86.37740827375843, 84.36848009786299, 87.23992178517004, 90.93065246458977, 45.03506183624268, 38.163579202467396, 86.15399791348366, 84.86397743225098, 83.41262986583095, 83.42180036729383, 85.74294920890563, 84.76162710497456, 81.97343380220475, 83.86188245588734, 89.94450584534677, 85.4126464166949, 86.28968054248442, 84.98633969214656, 86.8163214960406, 85.89339563923498, 83.17709153698337, 86.53071803431358, 87.20585992259365, 86.1035091646256, 87.33667096784039, 85.41356425131522, 82.62857160260602, 82.79952418419623, 81.10742153659945, 83.08399015857329, 83.72687447455623, 82.0849467862037, 82.64996420952582, 79.79538086921939, 77.8009262392598, 81.91487281553208, 82.51563872060468, 79.91069855228548, 83.59442387857746, 82.63567893735825, 84.80728349378033, 86.75588561642556, 83.0915681777462, 82.4059457163657, 92.35307647335915, 81.66105624168151, 11.891299620751413, 0.45651188600928555, 0.5737144824477934, 1.3943713398710376, 5.083696707602471, 1.4519008657624646, 0.4687742570475225, 0.47171848615811723, 0.2834178435225641, 0.806412095985105, 0.11158379350578594, 0.3308717503903374, 16.22585108203273, 62.97080547578874, 69.79324279292938, 67.76998227642429, 43.39233006200483, 18.468660385377948, 19.434577380457235, 38.094674925650324, 63.77424024766492, 69.78830060651227, 82.69584025106123, 76.40360539959323, 76.3001254297072, 67.18165812953826, 16.517985290096654, 0.2045160120413188, 0.049577131041235505, 0.01699868664746323, 0.05258032593936209, 0.029944929053946853, 0.026643086269858385, 0.03732021837945908, 0.09272009645017887, 0.059353987265738754, 0.05902836925440258, 0.06622502985861033, 0.04445193387988595, 0.07982298326227935, 0.06720995845934076, 0.04893187816525179, 0.01948007990816428, 0.027712096850718224, 0.03068658643432202, 0.01386572315823287, 0.1041976027491112, 0.03635800811612318, 0.1662723053126566, 0.20589639522856285, 0.2049125391509264, 0.12352316655338773, 0.12213691513264373, 0.1880663423047912, 0.1719873518713059, 0.13274794534569787, 0.13585856875344632, 0.1877377671940673, 0.08827716953331426, 0.15117337116070334, 0.11728186355603319, 0.10175585070805204, 0.20603039932827796, 0.17712878243577096, 0.1605258338273533, 0.1455632173606465, 0.07885230389694053, 1.599865538939353, 69.278729807946, 117.55991381983604, 101.74316006322061, 102.9205692968061, 93.53225077352216, 87.6694683874807, 69.26935534323417, 63.85867318799419, 77.41373339006978, 92.16457520761799, 84.7692600373299, 110.55929891524777, 68.35741212291103, 53.90233662820632, 53.05727766406152, 10.19426655384802, 0.2928318996583262, 0.19943398393450246, 0.16400450119568458, 0.21435881694478376, 0.15233050100505352, 1.755725698124978, 5.931880329885791, 0.18532408461455377, 2.791371403201934, 57.88649197547667, 103.66272095711001, 93.08561832674089, 94.21417836220034, 108.22162905047017, 116.00889882733746, 107.9803248374693, 107.90787866038661, 107.75758128012382, 104.1635056464903, 96.88924266446023, 101.97129295718287, 97.98745924426665, 99.28132364826818, 96.58983245972665, 97.65231624726327, 98.80086468112086, 100.80920450149044, 98.62162020898636, 98.22239352810769, 95.9788134790236, 98.16398159150155, 99.01899553114369, 97.8847715931554, 100.79544482692596, 100.61000300991921, 96.67852509406306, 94.6383591621153, 94.18232087166079, 93.55611447365054, 93.7061059090399, 94.87375628563666, 98.31203537602579, 92.7992303909794, 92.21859408963113, 83.28079115959906, 86.85141886434248, 88.6142183119251, 84.13589923612534, 93.91836889328496, 89.3332907461351, 55.44215325386294, 49.33346571460847, 86.77854907128119, 88.8690939257222, 85.80144743765555, 85.83072400862171, 87.65620293155794, 87.5908640892275, 85.82540527466806, 87.48072393478887, 91.8340527626776, 87.25289698570006, 86.78130257514216, 87.93498146918513, 87.057068732477, 88.68369133241715, 86.16591407406716, 92.43591693139847, 91.32901622403054, 90.56533859622095, 90.59388560633506, 87.26962197211482, 84.63578178036599, 87.61465718669277, 84.3137316549978, 88.63277112284015, 87.94187699594806, 87.46677598645611, 85.05513022022863, 81.43166818926412, 80.5213096064906, 86.15392731082055, 82.46800545723208, 84.00132271551317, 86.22497712412189, 85.75541450131325, 84.4020712760187, 87.8132781674785, 84.95742397923624, 85.4963811751335, 93.0706976306054, 79.34877980139949, 8.559455025580622, 3.579076490094585, 4.576599944022394, 6.985834433186439, 5.411346506687903, 1.4084330369387905, 0.4308564594436077, 0.5038414108416727, 0.7243488801102484, 0.3465916907354709, 0.15404188014086218, 0.4111752623031217, 32.259727639536706, 75.4866886138916, 76.12800398180562, 83.86371812512799, 58.68555722698089, 51.30660226268154, 54.31796273877544, 46.93889402574109, 66.02976783629387, 71.05684218868133, 80.84490514570668, 78.40164507589033, 87.34500208208638, 77.90240580035795, 20.26803985718758, 0.4295095542986547, 0.14910334030226355, 0.1591648020210766, 0.20838009824435558, 0.1650184032417113, 0.16492880159808745, 0.09895060526868028, 0.15002442313538444, 0.10398442346242168, 0.17939911464289313, 0.11223363524843609, 0.1268693773196109, 0.372099967132653, 0.12322439226291834, 0.1321751107611964, 0.12856888975347244, 0.1060529221450129, 0.12763465319069164, 0.1878297590320149, 0.2080985609321825, 0.17180660108645118], [0.05124693458539344, 0.008663620345384605, 0.04618366031096347, 0.03147189741984251, 0.024696443447723024, 0.014827958319426305, 0.05911928856925619, 0.012274397661038225, 0.037220960197549675, 0.07107372290544933, 0.04273950137318142, 0.10967932956954164, 0.05430444128691189, 0.03179479390382767, 0.05468766911015396, 0.046122070672290946, 0.18148226092659658, 0.07945470947531924, 0.26934306167306443, 20.72831822979835, 89.44540777514058, 73.04142029054704, 81.76525792767926, 48.588815504504794, 58.08874507104197, 72.00159211312571, 52.69365825960713, 54.55308921875493, 37.08392720068655, 42.5275964890757, 71.9303697155368, 30.245939646997762, 34.90097914972613, 37.03965148618145, 7.997558338026847, 0.7634725001069808, 0.35202040427154113, 0.029113175903236675, 0.14606825316384917, 0.08228645389599186, 0.35536774884789224, 0.5780314185446309, 0.16319725902811175, 0.3155857835325503, 27.417161580054994, 92.05393298979729, 82.55489380128923, 81.36445445399131, 95.73900761142855, 104.12905154689666, 102.6868901714202, 105.6829769380631, 98.38281062341507, 92.53694934229698, 90.72060954186225, 92.61774232310634, 90.13055955210041, 84.97878520719468, 82.36854983914284, 87.62480828069872, 87.99548010672294, 91.0858057391259, 89.90952614815005, 92.99242281144666, 90.61017128729051, 89.22129138823479, 91.02682898121496, 92.09656130883002, 85.82622897240424, 84.76321174252419, 85.82495027972807, 84.34846032050349, 83.85226480422482, 84.33654415992, 85.26671855680405, 88.25155596579276, 87.31330933109408, 84.36859776896816, 86.95924482037945, 89.40518779139366, 81.16839870329827, 71.97914046625938, 86.00116668208953, 79.83396130223429, 82.54541735495292, 81.51507346860825, 32.64896404358649, 26.498697419320386, 64.82049326742849, 85.17848876214798, 80.37912368774414, 83.88094517492479, 80.5303624368483, 77.90254700568416, 76.38220494793308, 86.6866087144421, 82.14326458592569, 83.84226276028542, 83.95828646998253, 83.9552584002095, 82.90287863823676, 81.38180701963364, 79.11863865390902, 81.48150582467356, 78.60759304415795, 81.21544361114502, 81.6222640006773, 82.76429345530849, 79.16286729997205, 82.48482458053097, 79.14972735989478, 79.85340056880828, 77.60432135674262, 77.17952866708079, 80.64990059021981, 80.37684086830386, 75.24039514603155, 71.88905146814162, 75.0704937596475, 76.31509319428476, 77.25581876693234, 80.99495933901879, 76.98014674648162, 80.78005267727761, 80.6299671050041, 81.70466515325731, 76.73229217529297, 82.93917625181138, 73.215667663082, 6.992147487978782, 0.44849450009003766, 1.7528857795461532, 6.8449120079317405, 0.6902523290726447, 0.10382067216860671, 0.025371748037756454, 0.33632430458261126, 0.7048772539823287, 0.2498469054098091, 0.007288917700099129, 0.5069262630516483, 18.082781530195668, 59.263443946838386, 71.88283843378868, 58.779203814844934, 56.908798063955004, 48.57829178533247, 35.569374561309814, 30.555497023367113, 44.86569781457224, 51.55938333080661, 50.877467509238954, 59.71331234901183, 59.255603128863925, 53.21425876309795, 13.48786803983873, 0.1737543489904173, 0.06833964703424324, 0.0921898793369051, 0.041787855462321354, 0.053010116586641925, 0.013419131245163661, 0.021262969521264878, 0.04277011807707529, 0.06400935802488558, 0.08693885989487173, 0.11050484293410856, 0.04318061479998212, 0.013412035355765014, 0.050685338510741154, 0.050409152322719177, 0.08824375277805714, 0.08440588210378924, 0.049703072065547596, 0.05767476467055179, 0.09561251503445449, 0.03633787915591271, 0.01903508050036767, 0.0301136733258083, 0.0621677860767851, 0.04082809284990353, 0.03269350696955958, 0.07719382313230345, 0.0258756902504472, 0.0845562651633255, 0.06284748609628409, 0.029302137235419887, 0.015124510954915276, 0.042722187786092686, 0.019579788166729194, 0.08081568765544123, 0.03743474852413901, 0.07398902453602323, 0.017007056158035994, 0.32779789920295443, 34.09317093510782, 108.29247490052255, 85.10420691582465, 108.52855451645391, 67.01545161585655, 85.4478693008423, 95.62418414700417, 68.82611182428175, 51.5848316684846, 27.663937499446256, 50.24249461389358, 84.15924518339096, 36.79026719062559, 39.434156494755904, 40.00351598185878, 5.914150236114379, 0.5454648983094, 0.18292151030994233, 0.08509786634315407, 0.25829760598078855, 0.6751360660118442, 1.48506720219889, 0.3894923999905587, 0.03950740323371945, 0.6372885646358614, 43.9211832323382, 104.12869853358116, 91.46288671801167, 88.93733532198014, 103.56005684021981, 106.43560917146745, 106.6546029429282, 110.219252955529, 101.61310211304696, 95.66259984047183, 95.22023493243803, 96.706954433072, 92.49384249410322, 86.11174614198747, 87.4060106277466, 91.15945216148131, 92.45749781208654, 94.8781728744507, 93.38059625317975, 95.21619489116054, 94.03758541230233, 92.38687161476382, 93.0511171587052, 93.79410820622599, 88.96195996192195, 86.11759831828456, 89.483886226531, 87.28279329115345, 88.39916260011735, 87.96774110486432, 88.76639842987062, 90.318660736084, 93.50419798204976, 87.36887362695511, 93.01730632781984, 90.15770235369283, 85.48194685289937, 76.00978374481201, 90.34232831770375, 83.69904918055381, 90.03512828580796, 79.93293839116251, 36.99637989844046, 32.29395620284542, 59.04053564994567, 92.51320331327378, 80.14257338739212, 89.07268062714608, 83.59265881199991, 81.87934398651123, 79.52399207699685, 90.10060833346459, 83.99072447130757, 84.7677303129627, 87.72106324472736, 90.46830700289819, 87.51469950522147, 86.66558481031849, 82.98018070959276, 86.35430551344349, 82.57427815468081, 85.5687959732548, 83.39643832175963, 84.38312622808641, 84.53962095322149, 85.5477406901698, 82.18506920722224, 83.44011783599854, 82.55254037918584, 81.9985761950093, 81.00980158775084, 82.880827073128, 80.02923257889287, 74.8354967178837, 77.3844175954019, 82.07612929805633, 80.50317256681382, 83.71033776190974, 81.48988400736164, 83.43741924531999, 84.17099660442722, 87.12787535882767, 79.87817425881663, 86.28952364767753, 86.18943260562035, 17.178985072720437, 0.697944587276828, 0.8305083191202534, 0.3827010611853292, 2.3950842936192793, 1.6998577862977984, 0.17470250537078227, 0.3476921607169413, 0.16615555351299627, 0.406054699973714, 0.07414287031297723, 0.5803913983606523, 14.322611170430338, 64.25677807100358, 80.03582216078236, 62.10289086064985, 56.5016991861405, 24.26732966976781, 27.404256982188073, 39.786883477241766, 56.31293512159779, 72.95888577738117, 68.50647003419938, 74.4641580889302, 66.7555396787582, 70.67958078076764, 22.360820462626798, 0.4958910729375578, 0.07473471919975935, 0.01050267856748354, 0.06329415749097544, 0.023064727879940503, 0.019381243074613235, 0.05066734693583943, 0.0378799413691365, 0.05426884118107058, 0.020180487284256567, 0.1182832170818602, 0.0152134288650667, 0.06753213673589692, 0.025460627643511664, 0.05861772314435052, 0.04233137186196062, 0.016247750027105212, 0.044486503597469106, 0.03300988213008931, 0.10280063375830652, 0.13467340009106746, 0.14963731890724552, 0.11506197057784566, 0.1980397192340705, 0.16650945549049687, 0.19324330402718437, 0.1850550038920295, 0.1420149738870321, 0.16727644739852798, 0.17080094214648972, 0.08382233761010632, 0.16139796364211267, 0.1056820743026272, 0.07890625180856836, 0.2156012889838988, 0.14438558700344256, 0.2947036363184452, 0.15698044020081722, 0.5305257547766932, 39.82130227550384, 122.59845718260735, 96.48664274523335, 109.34394467261531, 71.36732132204118, 83.18124924936603, 91.66369638135357, 78.29992232784149, 82.7587236896638, 56.74795735266901, 55.40758932790449, 90.20025222532212, 48.980413175398304, 55.66375540148828, 60.309316496695246, 13.68495439329455, 1.5765360165988247, 0.4643833168571996, 0.135122649371624, 0.35712022093995927, 0.3213253142612596, 1.4345480549720027, 3.600417370757749, 0.4075352108526615, 0.38255516740102924, 43.29802843832201, 110.27833953980478, 95.11385240862447, 95.55678998270344, 111.14524610580938, 111.14403017105596, 108.35151441635625, 114.72800962386594, 105.29491332269485, 100.21280027204945, 96.36351954552435, 102.22308558802452, 98.05537116143012, 92.7065134048462, 90.336028991207, 94.94984242223924, 97.49860640495055, 99.46910319789764, 97.05530012807539, 99.183303617662, 96.20959789522233, 96.84003260827835, 98.01617883866834, 98.14937468497985, 93.53457281666418, 90.32495221784039, 92.37632828374063, 90.82287357699488, 90.21105443277668, 89.9432114631899, 93.42264406142696, 95.55606826659172, 96.44545785842404, 91.96959418635215, 95.41524733266523, 93.40167507048577, 85.94826959794568, 78.54876533631356, 93.14035108012538, 88.7908269513038, 90.60379351339033, 86.82118523505427, 40.08392849276143, 37.12718702131702, 71.17248150610155, 92.48119677266767, 87.01624470372354, 91.27713895613148, 88.57246075907062, 84.84437342612975, 83.1787310877154, 93.6071680438134, 87.77187362793954, 86.30260867457237, 92.54347616626372, 91.47084912946148, 91.81777492646249, 88.92371685274186, 84.72064618141421, 87.68649931876891, 84.70188156250985, 86.44383753499677, 87.8565497552195, 85.71615157588836, 86.48505380076747, 88.38219442675191, 83.6325728508734, 87.96066514907345, 84.2039680480957, 83.27750421339466, 85.9772559135191, 86.8774006443639, 82.32162260240125, 78.17992917952999, 80.6922935670422, 82.54034965269028, 84.39628185764437, 86.07788824266004, 82.14375095982706, 84.68158721923828, 83.9504966428203, 90.60039674082111, 82.25159260534471, 90.90674954075968, 90.10151047860423, 15.073242995046801, 2.4451572712390655, 5.210484871941229, 12.999092667333542, 2.8862817297058725, 0.8335999435474797, 0.22460070769152335, 1.232589750039962, 1.9286936425393628, 0.5435907408114403, 0.0933368968206548, 1.2471386790275574, 29.214670081292432, 75.36993534334245, 85.7231726184968, 78.15222155663275, 79.18910795642485, 68.50433626482564, 59.16172904352988, 48.439643844481445, 62.26674395222818, 69.90883504190754, 70.09658321257561, 80.80087261815225, 78.72089462895548, 82.95539133010372, 27.68135674538151, 0.7105921473233932, 0.22919216373514747, 0.2110757318235213, 0.14837143522116447, 0.17810332288424816, 0.1239809730360585, 0.1430932886057323, 0.19470751255510316, 0.12923325652316695, 0.2175627038964341, 0.1904513885176951, 0.15622500089868424, 0.06590344146975587, 0.14168747129940218, 0.2688350840922325, 0.23763053029054598, 0.10783890292288796, 0.16313908231114188, 0.11317744024939115, 0.2086392504673812], [0.029773593489681522, 0.11784601836435257, 0.04409323236153972, 0.03485914560094957, 0.059992452602713346, 0.0709951299452974, 0.015159081630108338, 0.021804137861416228, 0.036449053835484295, 0.02377807448107389, 0.03918905922722432, 0.09549159571648606, 0.0746479980467308, 0.07881344791742102, 0.04945564481820311, 0.12128870258288038, 0.034918762563217076, 0.04884871549063152, 0.12227456581087844, 55.7561585980077, 86.8788754555487, 70.89557001667639, 57.60700348884829, 52.788124622837195, 36.20671656823928, 37.01614864410893, 36.44318842118786, 38.41320276260376, 31.12476041240077, 30.253696134013516, 22.60038902682643, 33.66535409804314, 40.58779224272698, 10.031295995558462, 0.8022931170079016, 0.25157872377143753, 0.1175896623622506, 0.047035419847816236, 0.09320529057614266, 0.21923283685839948, 1.6383287911453557, 0.6788726138972467, 0.09612698904088429, 15.814669016868839, 85.3243617088564, 91.73417352860974, 90.5846994153915, 93.38936667288505, 102.35401430437642, 101.42107855889105, 105.36810475011026, 97.11696763192454, 97.9327029566611, 89.62309898868685, 90.28988622849988, 81.13630587054838, 84.87179079363423, 80.66161278755435, 88.58968780886742, 85.59423646619244, 89.5828240917575, 87.84775580129316, 90.88776526912567, 87.67216697815927, 89.47986971947455, 88.93297364634853, 91.09693742567494, 83.10593974205756, 88.70233828021635, 84.45845142487558, 91.23820550980108, 85.54484598098263, 88.98369773741692, 84.38641317429082, 87.08598444538733, 80.12808415197557, 87.07391923473728, 81.5114962670111, 90.23859731612667, 81.58403658097791, 82.58384089316093, 71.77531057788481, 82.58934790088286, 73.78732958147603, 98.23472545992945, 52.71028126439741, 47.09695377657491, 50.66079578092022, 24.165379424248975, 91.98737821271344, 74.00463673376268, 84.98852837470271, 72.5893279044859, 75.64318333902668, 77.2177403972995, 85.92950497904133, 79.44378745171332, 87.85464348331575, 80.22708477512484, 84.41672525098248, 78.80604144065612, 83.37488097529258, 79.56983673957087, 84.08614789285969, 80.37973557749103, 82.0956862357355, 80.32555195593065, 79.87560902872394, 78.074629229884, 78.01977096065399, 78.49408749611148, 79.37576570818501, 75.84165526974586, 75.95758484255883, 73.92898205787905, 73.1157256710914, 74.29160518030967, 73.28380707771548, 70.1245810908656, 74.75589613760673, 75.78307859359249, 75.99847947397541, 77.15273103406354, 78.83063470163654, 81.11716470410748, 79.84850545083323, 80.64371109008789, 74.65546777171474, 74.64497150913363, 70.8476935663531, 8.986135355887875, 1.4797594999113393, 7.492665456187341, 2.1104361741773547, 0.7064829742716205, 0.4622360643359923, 0.12809617519979516, 2.932472296299473, 0.38944165432645433, 0.0561923538935521, 0.06140018129841455, 0.6809278745805064, 18.999302156509895, 53.2578480628229, 54.973869323730476, 34.15172407704015, 40.39119128257998, 44.49843845059795, 38.46176170533703, 30.536146010121993, 35.16720218043174, 51.61611257060882, 53.36455614336076, 61.13437529533141, 59.45229038115471, 58.353638418259166, 25.78675977645382, 0.4509697914604218, 0.08806146981735384, 0.07033476981544687, 0.12214374097604906, 0.015206486193252908, 0.06156281410386005, 0.03384150504585236, 0.04241688259606881, 0.023729378102167, 0.025540172467909517, 0.05456214943420022, 0.09195408513469082, 0.049117800043595415, 0.0687788912065087, 0.06935801537286851, 0.01871276624320496, 0.029270279469088684, 0.067025515130691, 0.03500085654518297, 0.04800808721131856, 0.0843099985391863, 0.03071943436929536, 0.03721717955364335, 0.025093336364314444, 0.04760887113309676, 0.03626302470483127, 0.030568877024756327, 0.035751603558779724, 0.008275647565061528, 0.035791248608861244, 0.07345316135474751, 0.03909594890090727, 0.02743331937029237, 0.037887219204417164, 0.07086448897156986, 0.026499741643126455, 0.05327023408045212, 1.0354097499962778, 75.92747672911614, 97.37150592188682, 88.97268372197306, 77.92741483257663, 70.49158157840853, 54.97117465542209, 53.88849066149805, 42.787716311793176, 34.225166536146595, 32.801438339294926, 49.97531452486592, 31.104336630913522, 37.991273403167725, 41.06955735914169, 8.431672050106911, 0.7776003258843577, 0.13681786405223031, 0.0718597444375196, 0.21384178420468686, 0.1737205032259226, 0.9031384798788256, 0.7645594869409839, 0.9735716843316633, 0.30224488327099436, 28.730539775663807, 100.95226118641516, 95.97556575652092, 95.15949310794954, 98.05537116143012, 104.62723962722286, 103.64390926976358, 109.87575531005861, 101.46719778737715, 99.84365817039244, 93.28103080872567, 92.8268046532908, 84.35763082196637, 88.52779280754828, 88.6988316812823, 93.22713744255805, 88.90600342904368, 93.17551120635002, 91.9163283994121, 94.25277448469593, 90.81237731441375, 92.47958075615668, 91.6578677392775, 93.66748625232329, 89.9646354490711, 92.69735074812367, 91.68409270624961, 96.12804397459954, 90.41461759997954, 92.88359272864558, 86.60689046305995, 91.21424767278856, 84.76861676862164, 87.97535834773895, 85.52324941081386, 91.34409381497292, 84.98677115286551, 84.26820078203755, 76.73080951936784, 85.89407813164496, 77.21352777173443, 99.66211518933697, 50.93580884318198, 52.7257118686553, 59.54166550790111, 21.599545286547755, 93.03354494033321, 78.79253279778266, 87.74929646522769, 76.60221853563863, 79.94673728942871, 80.08864864226311, 86.10075566076463, 82.60178965906944, 86.90806573437106, 82.865553363677, 84.53118001261066, 80.72467665518485, 85.54717586886498, 82.86436096314462, 85.18898502472909, 83.2267330538842, 84.53128199423514, 84.71906938860494, 83.24263434256278, 80.3688863015944, 79.66833529933807, 78.59466491207, 80.70901070871662, 78.0874789145685, 77.95770337504726, 77.64512185127505, 76.21049927126977, 77.59100883237778, 75.94185613816785, 74.4674607246153, 77.04724281064927, 79.96628638236754, 79.68391495366251, 80.55270425734982, 82.7813792997791, 84.10495958020611, 82.88689890215474, 87.08267396496188, 80.19471737646288, 78.92972161692958, 87.08214052261846, 21.262547008452877, 0.23472408463637676, 0.21343561970899183, 1.109711575892664, 1.0682982110208081, 2.1163270838799018, 0.3626995167184261, 1.4218513427242156, 0.3541599652699886, 0.14112395234405994, 0.08466156394851786, 0.5097244145168413, 15.824505340668464, 57.80482822848905, 62.05318266345609, 38.22736086383943, 35.99313566761632, 28.101479853353194, 29.385901151164887, 42.27212859738258, 51.116359464583866, 63.77497373088714, 74.45338726043701, 77.11882606629403, 70.84293180896391, 75.27964238197573, 40.543096834613436, 0.4809177005963941, 0.04396867795637058, 0.01987310025029846, 0.0682882042301278, 0.11968010946387246, 0.03881556455106024, 0.025076128114315293, 0.05387089680880309, 0.03608626523806203, 0.04774700061628415, 0.044883540155546325, 0.09879260729517668, 0.031016082765774864, 0.08514090516274014, 0.047641353261086254, 0.05230358816803463, 0.05770009919820775, 0.021341849764388417, 0.0055906377101857824, 0.14574243596965267, 0.23133664301806883, 0.17763729627814986, 0.12916945672083285, 0.15299381057341255, 0.1326619902805936, 0.14745652705671328, 0.08276634669351964, 0.12172155758185733, 0.06699427406513883, 0.14020328319841815, 0.21802258647737965, 0.17204779620853164, 0.15745823391743247, 0.12292800050589348, 0.2047029987818772, 0.17023535475375193, 0.12276584267496102, 1.6607743093082983, 88.97047934993621, 111.01034795084308, 97.68764111303516, 81.14852797600531, 75.46944587461411, 55.11825961451377, 54.56898266269315, 60.28915551400954, 59.44592829673522, 43.69091656900222, 44.59769010543824, 40.55796261756651, 53.30294355269402, 62.165711541329664, 16.197135410001202, 2.90101366177682, 0.36183861775263665, 0.22703925748505902, 0.3894965981523837, 0.22682470690098502, 0.4877813887451926, 4.816348937249953, 3.9282005304290406, 0.3449769306086725, 27.372093546775083, 104.60288955319314, 102.7631724265314, 101.32497264492898, 101.86545956519343, 110.30159919492661, 107.4930174120011, 113.8187885284424, 103.90836331152148, 101.21076107025148, 98.41808842074488, 98.72185245636972, 88.43300480996409, 90.4980464135447, 90.12255791694888, 95.95352988089286, 92.66393215425553, 97.03627663273966, 97.31942469073881, 98.74309601322298, 93.60669735939273, 97.40254755943053, 95.30743706610896, 98.30448089107391, 92.26474469707858, 95.40560614678168, 93.64097887469877, 100.20874454129128, 93.0858144452495, 95.93888375066942, 89.98963663654943, 94.3685079390003, 86.08741175743842, 90.88187386912685, 90.25935449907857, 96.67301808634113, 88.12743648405998, 87.97906890992196, 81.28900374135664, 89.23869886705953, 80.5145788192749, 103.60314799893288, 59.79139497203212, 52.59754057853453, 54.882505555306714, 31.484479019718787, 96.82829687672277, 82.47166110623269, 90.52893115628152, 80.6334815486785, 80.73241941390499, 82.32128527856644, 88.62401639261554, 84.14667006461852, 92.66418318594657, 87.10550215936478, 88.41162004778462, 81.79586025976366, 89.64435039028045, 85.41825540604131, 88.06246634452575, 85.5053634028281, 86.74907638180642, 87.8134350622854, 85.58981203263806, 85.69376268694478, 85.02484952249836, 84.87108476700323, 83.91308507611676, 82.27160453796387, 83.63487920453473, 79.65034730972783, 79.76396268413913, 81.52295743265461, 80.01412360898911, 78.31368200240597, 80.24306451120685, 82.11970683067076, 82.98743709441155, 83.33549253402218, 86.47881723219349, 88.89182798324093, 83.78298005750104, 88.95773949161654, 82.04463266557264, 81.19499237306657, 91.98657020445793, 19.57019921272032, 2.6781921473241623, 16.50068763763674, 9.338660336309864, 1.1465026726645808, 2.5413830626395444, 0.2227728678694656, 7.273390254666729, 2.0114907093586463, 0.23604788456953343, 0.33661744046595793, 2.1788624121296793, 32.18770900080281, 68.90889736913866, 69.63548506459883, 49.31407351647654, 58.430140326100016, 63.47646174892303, 56.53376456229918, 47.634436161287375, 47.863992875622166, 66.50691632301577, 75.92262867958316, 80.60371075907062, 78.85216066914221, 88.4506005625571, 47.14451251491424, 0.911831494060255, 0.26968007907271385, 0.09388570688785085, 0.20477000083173477, 0.16042837212162633, 0.1792357387321611, 0.11279029005597677, 0.16849302566580235, 0.07398376917286266, 0.12067325052715118, 0.17145279103950148, 0.2023264561449328, 0.13728651067902967, 0.21892338330226563, 0.2009343518124473, 0.13900715947872208, 0.1734471936980563, 0.15944943432846378, 0.05792223405273211], [0.08279853004721865, 0.057345542215531876, 0.019821295469638803, 0.08084381074314156, 0.08642869130257638, 0.04148863301041626, 0.08211168625782575, 0.07498757418004737, 0.05390303036678703, 0.013900791790576713, 0.056075027527948546, 0.03216462284927407, 0.029844918190651847, 0.024571864144696344, 0.02292183332986409, 0.10569364989116307, 0.034940871860711806, 0.19037496358636888, 2.0241578812560728, 76.77240233267509, 81.12462505217522, 81.12923775949787, 52.95086768365676, 50.99161240362352, 52.42716850772981, 42.912745783405924, 47.35019376201015, 38.97765928699125, 35.089186237704375, 18.713973260694935, 31.235518340141546, 41.535629072496974, 17.691707495720156, 1.0994046902464283, 0.08430752407519088, 0.07128815091545544, 0.14070039765248377, 0.07644843490373704, 0.1181284060341216, 3.9716035175708035, 3.4914590754816612, 0.36217014996274827, 3.4640689194202428, 70.01081666638775, 95.44862670283165, 80.75418856836136, 93.74822431995024, 106.13939962079449, 96.60931879474272, 102.53897759222217, 99.2223233561362, 99.89742602071455, 89.00595326577464, 85.3376663884809, 82.4988901999689, 83.28443111911898, 86.0974608698199, 88.32235474740305, 87.39561634678995, 83.74439177974578, 85.49211363638602, 86.55316968117991, 90.4464594010384, 89.5005641445037, 84.37030007762294, 86.47452615922498, 86.72649137435421, 88.51607276547341, 85.21262122738747, 87.92738776053153, 83.73672746842908, 86.34577828068888, 84.36966465365502, 83.02291101024997, 85.21430784656157, 88.37990376257127, 84.21956339190083, 80.77824838699834, 80.6925916671753, 85.12912181115921, 77.68204704407724, 76.16883585529943, 80.62899435720136, 81.36470548568234, 86.79881988033172, 38.85901151164886, 53.626994086850075, 74.79501001296505, 23.674975287529733, 63.34902786439466, 81.3408104065926, 75.64155947777533, 76.29250034209221, 70.41886868015413, 78.85153308991464, 77.3646802286948, 85.13902187347414, 75.42275398008286, 81.24901909982005, 78.1904411315918, 80.26756363530313, 76.49343552127962, 79.78136231822353, 78.92553252558555, 76.73648126663701, 76.49629100676506, 79.57102914010325, 79.06825973141578, 78.53232276055121, 76.36238913382255, 74.97853771332773, 72.28607377698346, 73.6673128989435, 71.92567856081071, 73.6974210123862, 72.07773316291072, 69.95121232924923, 70.5334254234068, 71.20107558465773, 69.99174610260995, 74.38090970439296, 78.58138376666655, 77.93209029782203, 74.66111598476287, 77.09966921037244, 79.67199879307901, 80.1436951852614, 80.07775229792442, 78.53188345509191, 71.37351082217309, 73.29409153230729, 15.740386189952975, 0.188191122705898, 4.312436157657254, 2.966496651211093, 0.4075491230093664, 0.15950944965645192, 0.263685655569838, 0.7616895377155274, 0.22944958459946418, 0.08628948546585538, 0.03983737645490516, 1.9308927438912855, 34.64715473113522, 63.643982256612475, 64.84973845943328, 39.5674817792831, 45.79670375393283, 48.16875711564095, 29.410353206819106, 39.57682878740373, 50.7905948546625, 43.59102164545367, 44.9846907584898, 61.119501667637984, 62.35270269455449, 69.65544208403557, 29.878323347337787, 0.15063562340313388, 0.040787038198041345, 0.0161915325800017, 0.0288100004376423, 0.08547629845599014, 0.04812104687575371, 0.024197605295827793, 0.09285432271539204, 0.0071011122030716755, 0.025759457475355556, 0.04272725162727218, 0.008519093070419566, 0.04657692005557399, 0.045848408743979475, 0.028769665908428933, 0.029781851917505268, 0.03390853390878728, 0.08117466879587981, 0.04383122646099618, 0.05816802570235826, 0.05563077697109792, 0.06664606412091563, 0.04644695706965943, 0.02294407477752576, 0.03228442367887305, 0.029652649273855552, 0.04026140229055478, 0.022844845323913524, 0.07179478784241984, 0.025013171008697925, 0.027813212795844002, 0.02445412600683349, 0.02385687236974557, 0.05511234229009959, 0.11470714163395668, 0.21282633466105308, 4.364895407230624, 95.8545292577436, 88.79667128286054, 96.57155421472366, 63.711235215587, 67.38123616864605, 71.19560780063753, 47.67091028151974, 39.445170510199766, 35.529527202729255, 37.28056738453527, 19.031857828940115, 30.8875491926747, 43.24533531742711, 16.668314049320838, 0.9874391627888527, 0.03406893739837312, 0.04397635415737187, 0.05656680617962153, 0.19966574085335578, 0.23335232759916016, 0.9095169892234187, 1.2006288069871165, 0.17827080502625436, 8.90525314115709, 90.08000020057925, 98.04607514412173, 89.1640090942383, 97.02185799998622, 108.43829293404858, 100.10095780895603, 106.8119998132029, 100.24820358522477, 102.39534039651195, 91.25595031246063, 88.22842182651644, 85.72089764379686, 88.75876549751528, 89.82173565895327, 90.9819099980016, 89.52489852905275, 90.09430900696786, 89.46696512160763, 90.10703317580685, 91.3799991915303, 92.99119118721255, 89.2485518609324, 91.92713060686665, 90.36565073074834, 94.57844103536299, 89.75080351675712, 91.99392072616085, 88.29143862570487, 90.59516429901124, 88.65683878621748, 87.22977853590443, 86.13957928073022, 92.16976842572613, 89.0552496141003, 87.12652606348838, 83.9184351890318, 88.18469524383546, 80.44937333753033, 80.4492478216848, 81.60651176206528, 87.2645934935539, 83.83269217706497, 43.6490374226724, 55.6213035891133, 74.9361055128036, 29.552972547469604, 59.24531867427211, 89.63552505739274, 79.02862025845435, 80.62876685973137, 71.93794773470971, 81.491986397774, 80.99880326178767, 88.99565312170213, 81.49947812480312, 86.3239699025308, 82.02777431857201, 85.3071346590596, 80.11383025876938, 84.27269581825503, 80.93894789295813, 80.51457097453456, 79.89834308624268, 83.71052603567801, 83.6507648037326, 82.25021193104406, 79.77688297148674, 79.8403782998362, 75.71743380638861, 76.68582777823173, 74.85037034557712, 75.59423215927617, 75.11120796203613, 74.01268543735628, 74.11324716383412, 74.47079473926176, 73.94122769755703, 75.9869477056688, 83.6577936910814, 81.30593269102036, 77.58165790188697, 80.6607420213761, 83.20181815854966, 82.5730465304467, 85.64591761558287, 87.10288986083, 75.21336217080393, 84.802427599507, 26.204855019046416, 0.34535445873775794, 2.368863739313618, 1.0520115494728088, 2.466143422549771, 0.840872569430259, 1.1961068044747076, 1.4200242536683239, 0.3242588181409144, 0.11210014442763022, 0.1036073320034531, 0.5711469847348429, 32.34031469591203, 70.12361618780321, 71.11185735271823, 41.59371937474897, 31.952305993726178, 25.26403727069978, 18.324419144661196, 42.78484121445687, 69.38813255679223, 64.05084971458682, 61.01144036939068, 80.96559647590884, 72.43247232129498, 81.77268689678561, 43.23112849266299, 0.5336485743041962, 0.03908721549857048, 0.007747057909821912, 0.06077866182632505, 0.0386626074360984, 0.08637966167542242, 0.04572153309239976, 0.03936688355620831, 0.0211078041578613, 0.04221222986797652, 0.03914801989712062, 0.02057067693151053, 0.045992758861112024, 0.0437697708877104, 0.01466696973018829, 0.038336954950805635, 0.01997916320819528, 0.056637757412728765, 0.1299117346324267, 0.13489846140146255, 0.11367109964691824, 0.15550420409248722, 0.19339972385956397, 0.1462250560401909, 0.14393443782483378, 0.13005605027560266, 0.20282672688124642, 0.1365527823086708, 0.08121513356004031, 0.0931793814825435, 0.07173051306557271, 0.10465724784280024, 0.12126628685021594, 0.26602124314635034, 0.24720123608506497, 0.46938191798906176, 6.34659743116748, 112.02100153892272, 101.75790817506852, 107.98540822921261, 79.10184306483116, 72.33771570267217, 75.86594258585285, 68.67240198196905, 78.36447669613746, 63.838092511700054, 52.64440505735336, 32.77100074675776, 53.32199842699113, 64.20060188539567, 26.56548361624441, 2.3298545422092563, 0.17175757145929724, 0.31047453683230186, 0.37066278618670284, 0.2961659755918288, 0.32420381302795104, 6.911719777891713, 9.387789003310665, 0.5742726847529411, 7.705084844943016, 95.5335303275816, 106.73586660815825, 92.98773950146091, 103.16808654415993, 112.37095540569676, 104.49443601792859, 109.90784029806815, 103.32064320964199, 107.86270864548223, 98.11284957393524, 93.02937938321023, 89.23042266599595, 93.59093727604036, 92.73420533826275, 96.49895114283409, 95.30396969087663, 92.57430599581812, 95.18545135374993, 95.49135700348886, 95.76895098532401, 100.51277529808783, 93.73884201049806, 94.80990009923136, 94.2477067824333, 96.35240354845601, 91.15275275322699, 94.72000721962222, 88.4195432355327, 92.57711441286149, 89.71394108187768, 89.71565123527282, 91.27512285786291, 95.58043403010215, 92.21409905341365, 88.70504471563524, 89.8645208727929, 91.78856111341908, 84.43915336362778, 83.64495969587757, 86.31313631611486, 88.88858026073825, 91.35600997555642, 46.89218644172915, 56.07431773216494, 74.20364995156565, 30.166748954403786, 70.06048956224996, 88.38321424299671, 82.93783480121245, 84.13576587553948, 76.3448404496716, 83.44209471056539, 83.31496284854028, 95.92597130806216, 84.83423017686414, 88.12555374637728, 85.61562122837191, 87.57932447618055, 81.66387250346523, 85.82369512127292, 84.99394909028085, 81.24059384868991, 82.56023606946393, 86.58830627318352, 85.16391323458764, 83.32361559714042, 83.0278531966671, 82.70595212136546, 79.25759253963348, 78.98494074421545, 76.30564812690982, 79.28117382910945, 78.8494542337233, 76.88778277366393, 78.23295177951937, 77.57684123131537, 77.71355936604162, 78.86391993491881, 85.948026410995, 83.78453331608927, 81.09061810278124, 83.88703269343223, 86.47644812060942, 85.61586441532259, 87.40046439632293, 89.3615004324144, 76.22512971201252, 92.58349218676167, 25.235723641610917, 1.1982788169576277, 10.916867160028028, 6.016549593017948, 1.0649941044469033, 0.44601234457185196, 0.6408646017793687, 1.8722632383146596, 0.8289805559381362, 0.2808321435605326, 0.172725630803935, 4.954510504199613, 52.10886816824637, 76.49456516388925, 81.39899484572872, 55.07681977364325, 64.69492643110215, 67.09930404540032, 44.01281764430385, 57.960083484649665, 71.077207134616, 60.29314848684496, 61.05511203888924, 81.94417292071928, 81.89962264030211, 96.5274824634675, 48.69689641460296, 0.7441910476453844, 0.16273189125762832, 0.09173583434594255, 0.14383012729306377, 0.17792401234469107, 0.1602219727130667, 0.13249423234693467, 0.19185814045129285, 0.11681660303785918, 0.08755182216484701, 0.1412980841292489, 0.0790356210763416, 0.12799233198165894, 0.14803152200916123, 0.10531524842184399, 0.12549287053726374, 0.06614575508020579, 0.20035457647135183], [0.045812402611538294, 0.015343413876009085, 0.030368060481944875, 0.02918721064023914, 0.020221863693046956, 0.02914648349096458, 0.04842656657039639, 0.06157669178660839, 0.07737904020975675, 0.07227867195803313, 0.03671813838844819, 0.029899191689647497, 0.048226261391274394, 0.050249354042593515, 0.09253535434723863, 0.053408604881335656, 0.09727411377694338, 0.18295770030348532, 2.8166628460730276, 76.28733065820511, 70.25805934782952, 62.03539863709481, 57.67223642718408, 46.2500826774105, 45.39918330407912, 39.565332320428666, 49.572036035599254, 37.949551151644805, 39.05218432026525, 48.36838222319081, 39.523190375297304, 21.70534729957581, 4.653983894855746, 0.09739533953008153, 0.17867350680453165, 0.11850138360093679, 0.09979321771571714, 0.19324612323074572, 0.8206818012460586, 3.5782184716193908, 0.1076814488718106, 0.41621146303030754, 57.915999966283, 93.03281537948116, 77.85160326188611, 96.46751726827314, 99.78801542712797, 100.93403785459458, 98.37269875311084, 102.39978836428736, 95.79501121274888, 88.7243349321427, 81.82068886295443, 90.04996268979966, 84.04541800099035, 86.81863569444226, 84.39822735324984, 89.77922501102572, 83.69416190731911, 84.58544992631482, 83.4336929936563, 85.26613804601854, 82.9082993538149, 82.61096800527265, 86.94003305127545, 89.00413328601469, 85.18009693391862, 86.2346810679282, 87.29961241445234, 88.73580394252654, 87.07741014419064, 88.1102486579649, 82.74678399485927, 82.30148515393658, 79.8591350740002, 84.82965669324322, 86.5788455163279, 88.1623455785936, 80.56447136786677, 74.48992021622198, 70.29143871799593, 77.31205771046301, 75.0344628672446, 86.19497099230367, 73.09412910092261, 54.12660206517866, 65.7737978812187, 68.31734118923065, 51.191166908510276, 32.124237206674394, 88.31790677962765, 72.84552927940123, 76.06288479220483, 66.98648883450416, 79.51006766288512, 75.78552615258002, 78.30219730254143, 77.71588925392398, 81.83342087653376, 77.632829143155, 83.03309348321731, 81.61110093516689, 80.77624013347011, 80.20129126887169, 81.04434197948825, 79.35961338781541, 81.0284093118483, 82.67997034134405, 79.19153982593168, 78.59413146972656, 78.21647782479563, 74.64942732164937, 76.90784177472516, 73.73342837056806, 72.44058378281133, 72.075850425228, 75.642940152076, 71.67914190599996, 73.97535231805617, 73.87002883418914, 67.66458034515381, 72.40244265525573, 80.50414531461655, 77.29306559408866, 73.24789385641776, 75.55069385036346, 74.8416313048332, 79.67472876271894, 77.20271771953952, 83.06162480385073, 66.33514004368936, 58.13395823201826, 9.762543036091714, 0.32768767447240893, 3.1319086397847826, 3.2237835420716197, 1.594350318754873, 0.2601508952436909, 0.08493580044277253, 0.10434718141632696, 0.053222518294088306, 0.1058101105774122, 0.19467119998749227, 6.183701397911196, 33.8346004486084, 52.51415491104127, 56.198292086201334, 44.96070938725626, 47.34375715255738, 49.44027577677081, 37.4019725861088, 29.430669123126616, 42.86215897529356, 47.441557530433904, 41.88419442023001, 59.699933144354056, 59.32020456560197, 61.29067782432803, 11.947776848270047, 0.2004021964967251, 0.148351164534688, 0.11062229187378, 0.04397728495419987, 0.03545274116819905, 0.03410630716731952, 0.028632859842130737, 0.12853058535725842, 0.0309771271948252, 0.08565434495047217, 0.04831245011319557, 0.02628222821400531, 0.06229320233086906, 0.11171651057778828, 0.055790391390121756, 0.04588183699055545, 0.025085840193975358, 0.021341552905317758, 0.06441361496164914, 0.06426044334206851, 0.054750174223896, 0.046194098258931796, 0.06353308882323966, 0.02587786402493235, 0.0689024918322121, 0.0353715856439404, 0.01342638130975707, 0.05221440404232952, 0.04597146927769627, 0.036647443794795585, 0.0485590614769007, 0.053240578816903215, 0.008089585875671717, 0.08693326745302447, 0.18313370134320953, 6.947631038004353, 92.50395436440745, 80.55540284802838, 76.49542808532715, 62.54013707560878, 57.718261518786036, 47.292723194245376, 37.59802833680184, 31.02151970709524, 26.819141334103, 34.62203195018154, 36.26826247861309, 42.27425452201597, 24.300326608842422, 3.5135846753274245, 0.22592918076101812, 0.0887207957285066, 0.08038782754973059, 0.2920021957928135, 0.9770684160532491, 1.5292313743022181, 0.8519210894742321, 0.2526504348122305, 2.1005417502695516, 80.4429720294091, 99.88841241405856, 89.80668944697227, 102.35959191476147, 105.27013178794616, 102.23315823462703, 103.48768911054059, 106.94942397456016, 99.55841556672128, 90.75454588859313, 84.07980149792087, 94.34403234912504, 87.92156696319581, 92.78620812200731, 90.29879000879104, 93.80093313032582, 88.9056896394299, 86.85732595382198, 87.13786171328637, 87.14384725016933, 87.02132809546687, 88.56456895028391, 90.15660409004458, 91.4461931105583, 87.35398430978098, 90.68051507396083, 91.57585882371473, 93.280560124305, 91.90124296372937, 90.52081185002481, 84.26055216020154, 86.0959311454527, 85.89115988823676, 86.89907566193612, 89.735459204643, 91.65447881144863, 87.10336838999103, 79.68112222609982, 74.9609576502154, 81.79709188399777, 78.52848668252268, 87.19829759290143, 79.38611292069959, 60.58654962047454, 70.0493186519992, 66.78105861909928, 55.98691555761523, 32.81463711492477, 87.09075404751687, 76.27612836899297, 79.52501189324164, 71.89039291874056, 82.52136538105627, 80.07549301270517, 80.82243780935966, 79.80802659065493, 84.88677424769249, 81.70726176231139, 83.78951472620811, 83.3460750887471, 83.39996845491471, 83.02273058122205, 84.7533195249496, 82.46996664231824, 84.251844498419, 85.85615665681901, 81.68917179107666, 81.17653369903564, 80.3915419117097, 77.9095680482926, 80.27508674129363, 76.74105475025793, 76.51148626881262, 75.7748180820096, 78.72570345478674, 76.1667569991081, 77.74118854153541, 77.1671025983749, 71.82394796802153, 73.63766762518114, 81.32347353043096, 79.49044796728319, 77.40407651470554, 76.57592296600342, 79.01753564034739, 81.9721943332303, 81.61470167098507, 87.3706308487923, 74.56395887559461, 70.3324039520756, 21.102861435182636, 0.44484396855677333, 0.6243913825000487, 2.9030645710806695, 4.352888051540622, 0.9936040255331224, 0.46892833265085376, 0.17728691830510096, 0.24805458142392098, 0.11705747640301144, 0.2128453796068507, 4.119407005848424, 32.82558445007571, 58.72061929395122, 61.35693450127879, 46.816986760785504, 39.80507543010097, 25.420127991707098, 28.466270085304018, 41.98037485922537, 56.656562205283876, 62.05286102910196, 63.352883554274044, 77.35299941032164, 68.679548540423, 74.61070568330827, 20.894099166316373, 0.16777420536645, 0.08056303951889277, 0.03327813930809498, 0.04658532020966372, 0.025129616373188557, 0.11078882406676009, 0.043350877841153455, 0.040802834931040005, 0.017923638224601746, 0.042165195899865324, 0.07815996725713054, 0.02369957536669268, 0.017293105728083083, 0.05537883746587942, 0.02484143516349216, 0.01293412959879084, 0.05466085220236452, 0.24952334051411001, 0.15595366787766257, 0.21292327542699155, 0.08092409675760616, 0.09303294377581728, 0.08332812662927375, 0.09476571208647183, 0.17822235762592287, 0.1272386316991141, 0.2074511093838561, 0.08250161735040527, 0.1442074255957719, 0.2143869630151218, 0.17883034032439032, 0.33630463144471573, 0.15008656818780208, 0.2770198755446942, 0.5209801766660906, 11.070852548845354, 110.69469913359612, 92.48380907120244, 92.60812467144382, 79.24072634789252, 70.69305019993936, 68.97114538377332, 65.55317240376627, 78.54947136294457, 60.40369264541134, 59.95479699104064, 77.04255950066351, 59.22606768146638, 39.7630903797765, 7.598172310859927, 0.4209801458543347, 0.3078363445256987, 0.2617366972469515, 0.365977821451041, 0.7283113320027629, 2.6745090417323576, 7.798576989481527, 0.7434790148850411, 1.4432989854005076, 74.25958295022288, 104.35762374631821, 92.96903764047931, 106.97881037189116, 109.86655342963435, 107.15892561020391, 106.42240647346743, 110.98121258520312, 104.42986596015193, 97.44979643052625, 88.18322827739101, 99.30046481470909, 92.54997945600941, 97.07038556375812, 93.42503670723208, 98.42149303805445, 92.71293040244811, 91.41361390390705, 92.03819644066596, 93.52682221320369, 92.06974014159172, 91.89619879568778, 93.25762994827764, 96.70012166423183, 91.92738163855769, 92.82976996514105, 95.38305251829087, 96.28126744301089, 94.84709201320526, 95.02936455511278, 88.8083677907144, 91.60683770333567, 87.21692100647958, 88.76715936968404, 90.80663496448149, 94.29216292596634, 86.29847449641075, 83.10354709625244, 80.72953254945817, 87.27894936838459, 79.95322488969373, 89.17244219010877, 81.32498756531747, 60.04135585600331, 67.13850421290245, 67.60579186101114, 55.59836164597542, 40.544740307715635, 94.53061949822211, 78.0113535542642, 82.9362109399611, 73.97124167411559, 84.09292574851744, 84.15837441721271, 83.15406722407188, 82.7125338585146, 87.09038534472066, 84.71755535371842, 85.65104807576826, 85.82401675562706, 86.05839406290363, 87.14936210263161, 87.13534355163576, 84.21142055142312, 87.37172126770021, 88.08078381323045, 83.8302210838564, 83.83044073658606, 83.26148525361093, 80.01831270033314, 82.26088862265311, 80.4435682296753, 82.33340540239888, 78.91958621240433, 81.55392062279486, 80.1349953682192, 83.21516206187587, 78.72299701936784, 71.31582844641902, 78.47713501222673, 85.78592269651352, 81.92527494122906, 79.07476302116149, 79.47124404291954, 82.30687449055334, 84.65573095506238, 84.80930743678924, 89.71592580118488, 74.49404654964324, 75.68748258775281, 19.497133301150416, 1.8020937519688762, 12.915397132596663, 6.971384911767899, 4.008579210888955, 0.45212964857778243, 0.24262216002229722, 0.601807355640396, 0.46226339835313063, 0.254981579078782, 0.4199921375801487, 10.877092365295658, 50.22467528620074, 66.27908152918663, 72.59182253191548, 66.74008554027927, 68.68024672231367, 72.32873347497755, 62.99233928803475, 43.21743942076161, 59.83640024738928, 65.33850108423542, 62.55269258253036, 82.37191523275068, 77.97564429621544, 87.21179839103453, 24.243673855258574, 0.3393583498414486, 0.285472859057688, 0.26762423616263176, 0.10622267190727497, 0.17814133616705097, 0.18465409475949504, 0.12510159879081673, 0.28627069366555064, 0.11998613094610554, 0.19513575570477595, 0.14825168035684094, 0.13462965647059102, 0.07895443107812636, 0.21972157031057343, 0.20884528215373718, 0.18529843599084886, 0.12821520994146987], [0.019560371668288307, 0.06763519854435036, 0.038551283369381587, 0.010080765219285123, 0.05099907449837174, 0.05035422381854827, 0.07124300535407758, 0.06746967758743033, 0.051832689242737914, 0.030815928889017914, 0.04039496588971346, 0.05456391143642607, 0.07302762249544745, 0.04116480764482291, 0.07842031457731802, 0.0565648143510184, 0.10205461733764219, 0.17193277576758018, 3.8776318632787277, 70.09867775824763, 65.95395626560335, 65.2584651208693, 63.78253998294954, 62.7025741915549, 52.3252143398408, 38.421322068860455, 46.93668965370425, 56.934662172871256, 32.90844648115097, 42.351391853824744, 29.11351803810366, 10.490948750126748, 0.17676968638214374, 0.2054634023337595, 0.14198661331207524, 0.0641120367893769, 0.0759013791778876, 0.5419266752658353, 0.7630237564444543, 0.56982759746813, 0.22035985944732545, 35.51448491311843, 121.66065769810831, 84.83785444690336, 101.98113026157503, 101.89496363362959, 98.9519779143795, 97.92664681711506, 103.30686784559681, 95.24828772391044, 89.860653415803, 82.49942364231234, 90.54147489609258, 86.71399470298522, 86.88877551786362, 87.10208969731485, 85.79073936708512, 85.42883796076622, 83.23527597611951, 80.36342636231454, 79.9482121006135, 77.5604300345144, 80.14435414345034, 85.17926539144209, 85.96978772071101, 82.5590358241912, 90.30200635233234, 90.26110387617543, 89.53182543477705, 90.28797995659613, 88.30395098655455, 86.5265760114116, 84.03654559966057, 83.72708628254553, 84.85952161973523, 84.3998904382029, 87.9636618398851, 85.6737272201046, 86.68591053255143, 83.66133166897683, 73.3756140739687, 71.75911903381348, 81.90654170128607, 82.43250800717263, 79.65408925087222, 76.33504236898115, 74.21038073878135, 57.868060758036954, 69.95651537372221, 35.76584216087095, 64.40403561438283, 76.24200374849381, 72.31035324835008, 69.63586945687571, 73.16295885270642, 78.18667565622638, 75.13789576868858, 76.40741794340073, 79.31882073802333, 79.32525342510593, 78.11327242082166, 77.21351208225374, 78.38279416484218, 80.67283076624717, 77.49429102866881, 77.52206925422915, 77.01460869081559, 78.43049803087789, 79.5664321222613, 77.85822422273698, 76.21220157992455, 75.18520739770706, 73.09256799759405, 71.88100276454803, 71.65460355820196, 73.04660566391485, 71.35316941045946, 72.42396077802105, 73.31918685666977, 72.11965545531243, 74.44887653473886, 72.44907963660457, 71.31201590261152, 76.62982417691138, 78.98621943689163, 73.03068868575558, 73.4118018611785, 76.54354772260113, 78.68634639247772, 76.1832780222739, 79.76764186736077, 70.24778273797804, 66.68824749608194, 5.89866913134052, 1.044454122743299, 8.999952885412402, 2.3404321939714494, 2.231242969151466, 0.700746814329778, 0.19460393746774043, 0.12097107486859446, 0.15204199229276952, 0.11065736337895356, 0.2226347728602348, 7.806987041427244, 29.91038283994121, 39.06055465821297, 37.681617967544064, 41.75786272172005, 47.03460378031577, 38.454795575911, 41.02634460695329, 25.9570808564463, 35.05311219922958, 40.628247568684245, 49.921448615289506, 56.46169493275305, 61.79123501623831, 49.51081175957957, 7.345018127272207, 0.23887454982726808, 0.05647739988841838, 0.0673413655209926, 0.08958710327504144, 0.03002414254531745, 0.036396649591023886, 0.12695891001532156, 0.04168519201958853, 0.04444708071288563, 0.05907983504115574, 0.01181508485798634, 0.015461241071593138, 0.034698676993890155, 0.07652455339989356, 0.08498175039647088, 0.06768808925464269, 0.051688722169567505, 0.05698782895060797, 0.04286684816883456, 0.02384273038666335, 0.015768944116820012, 0.04641894123426849, 0.09026980252876397, 0.03573359666211951, 0.014288471542268753, 0.058322453706134716, 0.026215136148816636, 0.053529470573149385, 0.03130718085524296, 0.028051722779749867, 0.05117968355696048, 0.0331465445549017, 0.1365060356235312, 0.2452790755177698, 6.809956335252331, 87.29917310899305, 73.22962345615511, 79.37351426770611, 72.71634209540584, 69.95765286107218, 49.26351416495539, 20.699320147114417, 42.11657524108887, 58.23058582121327, 32.86288815159952, 44.73384341885967, 29.71888880575857, 9.78295014750573, 0.07272186914398786, 0.052005315665155656, 0.10864397706163507, 0.1446486309531235, 0.34500282438051316, 2.8789054674486962, 0.9822463124029099, 0.6841170066787351, 0.20299217122937405, 53.70004430893929, 117.91559434706166, 89.17408958558114, 107.17276373217183, 104.62261123041954, 102.52297432191911, 101.45539145315848, 105.50004543796663, 97.89103954069077, 91.30430529194494, 88.76052271935248, 97.48524681214364, 89.92764749834615, 90.95842284540977, 91.32162647862589, 91.05663114978422, 87.83629463564965, 87.49030236274966, 83.63500472038024, 82.29161647058304, 81.5201960840533, 85.06651293846869, 88.4869295550931, 89.55129608031243, 87.57758294382404, 94.99283944406818, 90.62990865399762, 91.80947519117787, 90.66615135438981, 89.29205094614338, 90.83449948218562, 88.37944092289095, 88.19748217059721, 91.37483735238352, 89.17343847213253, 92.64878396065005, 87.14838151008853, 88.20276168084915, 87.37725180964317, 78.24900211826449, 75.29156638729957, 86.82550768698417, 84.78618114225327, 85.12541124897619, 79.9720287322998, 73.56521360335812, 59.63444917432724, 71.96303521433185, 45.25332604685138, 65.87641100729665, 78.56597669662969, 75.72556095738565, 71.76563801303988, 74.67039631259057, 79.64560124181932, 78.44214747028967, 82.39132312036331, 82.14328812014672, 83.35890123921057, 80.73676540005593, 81.79016497827347, 80.1066993897961, 83.1241552291378, 80.19557245316045, 80.5276716909101, 80.56912329889114, 81.97452422111266, 81.22728916906541, 80.42099891170379, 78.90991364755939, 77.44313547688147, 75.6767588277017, 74.99371728589459, 75.28067788770123, 75.4144464000579, 73.32399568250104, 75.11143545950614, 77.04892158508301, 75.57774251507175, 78.28966925221106, 76.69840289700416, 75.5668540154734, 77.07982201730051, 81.56007089922505, 78.92352427205732, 75.01023830906038, 80.41712360997354, 81.98884871698196, 81.3974258976598, 85.14321096481817, 78.04250501817273, 80.27295297191989, 13.116666693841259, 0.8384370227013865, 1.7888287863423749, 6.559971426763843, 5.780977433727634, 1.5654173229009876, 0.39432341172810526, 0.14993915754941203, 0.35003583818193407, 0.09152906721517926, 0.22808718915668227, 6.161998433451499, 32.93997841496622, 41.46792111858245, 41.713394811076505, 43.65494451215191, 45.04742514702582, 20.110513548697195, 35.363348145638746, 32.73952764849509, 48.31602250376056, 60.72149876625308, 64.96298905341857, 74.11604773613715, 72.53485402753277, 67.53391050523328, 12.675611857445011, 0.21730969569856123, 0.0848205731580815, 0.032321812600017555, 0.012703890491637492, 0.0654956758502991, 0.049207378704581535, 0.019751642755563223, 0.041146245334417596, 0.033878288757536686, 0.026196736632095232, 0.06103150914573382, 0.015634933313835534, 0.016315416658237096, 0.04068688369326053, 0.012731098104268314, 0.059011657046334404, 0.14020513713119492, 0.22461149420949722, 0.16188312712455952, 0.11840703987306166, 0.13267153573613014, 0.12986952318779885, 0.2908841670761186, 0.16172604845656505, 0.14216543355536077, 0.14521598034808714, 0.1640967688252849, 0.17581506421969784, 0.17668272008097943, 0.1810999217653467, 0.23858211874481172, 0.16760342904636938, 0.24942503611166633, 0.5138326376195878, 13.074716944848339, 106.8462734837686, 86.43760096642279, 102.54233514108967, 86.14052849431192, 94.39249715497418, 76.04055081644367, 56.80718121990081, 67.16715320464104, 84.57241981260239, 52.57172353806035, 66.08668142749418, 46.560079359239154, 18.150775817132768, 0.31058825492378206, 0.320170727828818, 0.26262508344746405, 0.25567272828230936, 0.25842281539113293, 2.1875205539887954, 2.030557718488478, 1.3071014227405673, 0.3508132642074939, 49.52795643960276, 129.92491122215026, 92.90787220001222, 110.20018239175121, 107.94984017649006, 107.04781270796254, 103.7679659935736, 110.74001035382672, 103.71970515097343, 95.67916008733934, 90.5277152215281, 100.97695642902006, 94.6060388318954, 94.1055836216096, 95.83858874536331, 94.26236860213741, 93.4435110707437, 92.57757725254183, 88.94899260613226, 86.50450875682216, 84.33035465978807, 90.28031564527943, 93.29704976850941, 93.5887642829649, 91.28146140806138, 99.71282359092467, 94.54967437251922, 97.27899289900257, 97.39652279884585, 93.9875751926053, 92.31873220013034, 88.91617805727067, 89.05625374086442, 94.69867737062516, 93.33617933334844, 96.3414679804156, 92.75733947753908, 93.29028760233234, 91.26006880114156, 81.56125545501709, 78.47172214138892, 90.338806029289, 87.87262362818565, 87.74330308360439, 79.547714571799, 73.61506692824825, 59.49916662708406, 72.82008878646359, 48.47131306125272, 70.3839046724381, 79.28270355347665, 79.96565880313997, 75.57863681547104, 79.78105637335008, 85.316203178898, 84.47886343925231, 83.39564600298482, 83.55900487592145, 85.81457953299247, 87.41489871855705, 85.34457760472452, 84.49136795536165, 87.37573777475666, 83.54719854170277, 84.27538656419324, 81.21381974989369, 85.66487835299584, 86.48633249344365, 82.25025899948614, 82.7625205439906, 81.29698968702748, 78.66052150726318, 76.5047162578952, 77.24627171793293, 79.32845407916655, 77.70689918148902, 76.82808429964128, 81.23335315335183, 79.31194090074109, 81.65313305393343, 77.9159850458945, 77.8671750714702, 81.49896821668072, 86.65136229607367, 79.23122636733517, 79.08823244033321, 84.26123465261152, 86.23216290627757, 83.31660239927231, 91.17074074283724, 76.79017066955566, 82.33508417683264, 10.703858925450234, 3.010083744602819, 20.207564753870813, 11.008778099090824, 8.362652063369751, 1.2594588437388021, 0.3092322792978056, 0.6623430718337336, 0.6392681358322021, 0.21795893989263043, 0.4528361348615539, 14.398834589988956, 47.29407248958465, 51.085612004803075, 54.685057363202496, 59.35727488610053, 64.04410716026061, 57.60017464237829, 62.283476783383286, 40.074448124054946, 51.3933180224511, 59.66753436673073, 69.11552782981627, 75.9691793687882, 81.06399305405156, 77.989223541752, 12.62073495695668, 0.5233257540291356, 0.252760061994195, 0.22136038559819424, 0.264388342057505, 0.11875986166658903, 0.23834285416430046, 0.1849103052048914, 0.12552138432980547, 0.11946619473277562, 0.1908098717009829, 0.19986578173214392, 0.10212260764092208, 0.18455436543351222, 0.13389434995910815, 0.22869399207974636, 0.1082399346294903], [0.059135238519839706, 0.03276302178780879, 0.027404977947533615, 0.058212366871415615, 0.05005669442095584, 0.050116962557958986, 0.033696568871457735, 0.023842791673697294, 0.022806278542585434, 0.01421408823526074, 0.018484707613806092, 0.04796102259969039, 0.16144932217655644, 0.07738793449055764, 0.04801218578171346, 0.02059708589748029, 0.15860517479238972, 0.20436844818534391, 5.307301715497048, 68.91575367219987, 63.29395778717534, 57.67426821493334, 49.143199382289765, 43.68499379004202, 38.779242269454464, 48.56847017042099, 39.15763724234797, 44.89739448793473, 39.42764143789969, 41.1189753009427, 16.135995464940226, 0.747056522917363, 0.12829384886689726, 0.1433775685126743, 0.12296939223644235, 0.17047638133648904, 0.29002323746681213, 3.207130138912509, 0.6437816194468929, 0.27115844490547336, 7.2328844281934925, 94.73606540310769, 80.00913435412993, 99.17266614975469, 97.78840680276194, 99.86224236026888, 97.91569555959394, 99.4705544748614, 91.80934967533236, 94.15677839709868, 84.73286828687115, 90.75664827900549, 89.24488836719145, 86.14540792280629, 89.8110903463056, 84.87657608524447, 81.63825158149966, 78.09000492095947, 80.37909230878277, 76.60067312179073, 75.78460047321936, 81.75536571010467, 80.08842114479312, 82.37986979946014, 84.74905198620212, 87.14110159104871, 84.66727841284968, 83.96871212990054, 84.78573399205362, 86.16308212280275, 83.41390855850713, 86.40819887961112, 86.35828279679822, 85.67370368588357, 85.39376412668537, 84.554792681048, 83.60102914994764, 83.24804721340057, 82.07365036010742, 79.90984347558792, 73.16656743326496, 69.9251599465647, 82.4259654937252, 75.206466644041, 77.72214935671899, 81.62220124275454, 73.03901980000158, 60.89261216502036, 72.01823080739668, 77.10425053873371, 69.8754164480394, 77.51950402413645, 69.23177903698337, 70.82176669951409, 66.99740871306389, 73.16457486921742, 74.63012141566124, 84.1385821373232, 78.84045631654801, 78.69846651631018, 78.03667637609666, 81.10355407960954, 75.67467212677002, 78.59225657678421, 74.71263239460608, 77.36482927876135, 78.07755531803255, 80.07596369712584, 73.75824912901848, 74.09989541576755, 73.47825465663787, 74.61508304842057, 70.80403758633521, 72.74958810498639, 71.64862586605933, 70.42882365565147, 69.3599150257726, 72.44731457002702, 72.88334092786236, 74.24876505328764, 69.77316810238746, 76.53821329916678, 75.41073583787488, 75.91032028198242, 72.87649246954149, 74.55122686201527, 75.85093559757357, 73.86170556468349, 71.1463898997153, 77.78697044618669, 75.30236859475413, 72.63395663230651, 73.76578792448967, 55.57675723106631, 2.501215295445535, 3.648314413524443, 6.994179275728042, 5.454878441749081, 2.320345491170883, 0.16914847517205825, 0.3498140097625794, 0.015255409525707366, 0.13005617284967055, 0.053369729749618046, 0.2409277114296152, 16.93758476165033, 28.037229468745572, 30.801504158204605, 32.342817168081964, 36.76033166147048, 45.662111543839984, 45.21278442875032, 41.80912417750205, 35.60062016210249, 32.63162128386959, 42.282216933465776, 43.385442379982244, 53.5858170447811, 61.423026438682314, 44.804595132027906, 1.3300872473947465, 0.04458546300508803, 0.03829315770417452, 0.009048708804672765, 0.009074208041232441, 0.03440253038500105, 0.03203394740158993, 0.0348734867668921, 0.03737122834389729, 0.012978903607525414, 0.008446873961797646, 0.021547900602942514, 0.08060589447737702, 0.053529187120617404, 0.06217305676170415, 0.06856370476945754, 0.03528168139558646, 0.07390262513992286, 0.05602698615421692, 0.033314432723507766, 0.04722691118536938, 0.07118682046571086, 0.029316796327850995, 0.038032293274638154, 0.1110368833366421, 0.021422369435669917, 0.026254580100818027, 0.059730898694045124, 0.12122091912334004, 0.05262891123551996, 0.033966001994427175, 0.11651562241416787, 0.19887758959685603, 0.17021859274996867, 9.553526793756793, 85.93586706346082, 72.14386432401596, 66.91992621267995, 52.644303075728885, 49.68276062319356, 34.55388861317789, 40.30132193719187, 43.37974317612187, 55.3573751449585, 42.56144262129261, 45.775589635295255, 14.970310195799797, 0.1116226954505809, 0.0864573659735822, 0.10603315707656646, 0.0011911831707918958, 0.6387127527306158, 1.399531462980855, 3.8741036913087292, 0.9529938885281164, 0.6866306943758842, 16.04629674265462, 107.71148558585875, 83.23561329995432, 107.50880887431484, 99.9778816776891, 104.07857848751931, 98.68781412801435, 101.9204511950093, 93.27524139035134, 97.93089866638185, 88.92719991745489, 96.48927857798915, 90.97725806697723, 93.21202847265428, 92.38543602728075, 88.8083677907144, 86.60464686732139, 84.54202144376694, 86.31807065779164, 79.61295927724531, 81.49389266967773, 86.52832538850846, 82.77063200550695, 84.23504890934115, 87.1303778309976, 92.85054283757364, 89.15550539570471, 84.85110421334544, 87.80919105775895, 90.39187569772044, 88.62682480965891, 90.57766268330236, 89.61826662863456, 89.95675148502474, 88.55694386266893, 88.79220762560445, 85.8282607601535, 86.50268093232187, 86.59700609022572, 83.5054959020307, 77.9877644200479, 72.6052370379048, 82.03375201071464, 76.40890844406621, 83.26332092285156, 83.37062912602579, 73.51612906302176, 60.193418302843654, 77.72982151277604, 86.90727341559626, 74.64177869981336, 78.8824256773918, 71.62517793716924, 75.02220938282629, 69.57836751014956, 76.55130617080196, 78.86446122200259, 85.13517010596492, 80.15351680017288, 81.36701183934366, 80.415586040866, 81.03830937416323, 78.8778051253288, 81.68509252609746, 78.41395347349106, 80.33123939268052, 81.8208065340596, 81.09446987029045, 76.77110795051821, 78.57022070115613, 73.84248595083915, 77.69090375592633, 75.06359823288457, 75.33239041605304, 73.86102307227351, 74.023832813386, 72.7058458328247, 74.8908805847168, 73.9086877146075, 77.2088836854504, 74.77176604732391, 79.28358216439524, 78.28219321466263, 80.19205016474571, 77.67695580759357, 77.43158017435383, 80.67094018382411, 76.33774095965971, 75.67012217737015, 81.78721535590388, 76.5565856810539, 79.78151921303042, 76.11456594159527, 73.34243082231092, 6.895627273667244, 0.7157415452022707, 0.7142488994906027, 7.714518145207436, 6.488633319254845, 2.2818574790031683, 0.741286900254988, 0.10339960726278444, 0.07252109282079243, 0.029035902529534315, 0.14644878435759776, 11.92503494601096, 31.371867772071596, 36.75436965880856, 39.87066530412243, 39.60125338646674, 43.2484261451229, 16.03675263543283, 29.80811292125333, 48.700061767332016, 43.894668009973344, 58.042013952809, 60.60913855029691, 70.4509065997216, 69.38135470113447, 63.46496528194797, 2.8632275087218133, 0.05177116089109933, 0.07980382340329309, 0.05146394048126475, 0.029690093736374573, 0.04486434199216385, 0.030888578922097242, 0.11582306360885983, 0.045626492224513523, 0.022461165508796132, 0.02115887732455327, 0.06810728490592972, 0.09023189649827058, 0.03370514139533043, 0.07584592973392817, 0.06973291582037365, 0.21407081385052976, 0.23616252196652276, 0.15645698764391486, 0.28693164368310287, 0.13643760865013446, 0.2267133790038286, 0.11999986690258789, 0.14455550530504796, 0.19249192499105008, 0.13385169418348422, 0.22334813861356628, 0.13418206193995091, 0.2857066384486614, 0.2852217660796258, 0.16206858168926933, 0.2849569448059605, 0.3116205737235085, 0.4763223068608392, 14.480916069399926, 105.40820706275203, 84.61577769248717, 87.34270357316541, 69.88438298625331, 71.02242731278943, 61.744213642612586, 70.34035067404471, 56.59290998212753, 67.5457089947116, 56.73320139608076, 63.92731466600972, 26.949954340534827, 1.711809370786913, 0.3136879079524548, 0.3694549719652822, 0.2572626518386026, 0.5239103097588785, 0.9313995859796002, 9.05692138979512, 3.74092010240401, 0.8448288313323452, 13.051425910765126, 115.9772688342679, 87.72759791343444, 111.43123395981328, 102.7509032526324, 109.02796637627387, 104.42544152659755, 106.42556790382632, 97.4843603564847, 103.35625833080661, 94.38176555018272, 98.78344151281543, 95.90630454401817, 96.6459458874118, 95.6346490306239, 92.37943480091711, 89.95319781764861, 89.39724106942454, 90.11840020456623, 83.28464292710828, 84.70087743574574, 91.67576943674396, 87.27708232018256, 88.06690646756081, 92.33358229360273, 96.14634575382357, 91.55327381626253, 88.89000800348099, 93.56908182944022, 96.89160393130396, 91.29962198195919, 94.96595551890712, 95.98336342842349, 94.76988407873338, 91.75437373499717, 91.80462714164489, 89.19969481806602, 90.55222219036472, 89.19933396001016, 86.08197535237959, 81.67730269893524, 77.6639021596601, 88.01842597223099, 80.15804321535173, 85.42356629525462, 85.55459699323102, 76.40107939320227, 58.47118008521296, 82.84409015409409, 90.90403526060044, 75.51644371401879, 83.32595332976311, 73.1157256710914, 77.52146520922261, 71.84439920609998, 79.29123078623127, 77.79201461422828, 88.26259351545765, 81.38891435438588, 83.9304219522784, 84.76881288713025, 86.16047766900833, 82.76867866516113, 86.39773399599137, 81.27720525187831, 82.36847923647973, 83.68827050732028, 85.97217252177578, 79.1171246190225, 81.48417303639074, 77.40581804706206, 81.7885724959835, 77.30282445107737, 79.58410632225775, 77.91280792605492, 77.85896162832938, 76.59536223257743, 79.02900465073125, 79.68302065326323, 78.98911414607879, 77.28984925054735, 82.94800942943942, 81.3239049911499, 83.33148387170608, 80.26870112265311, 80.50329808265933, 83.97666669661, 77.44582622281968, 78.93202797059091, 85.71354712209394, 80.25449429788898, 80.07276304306524, 82.67211775625907, 75.19543693911645, 5.945139902253305, 7.038298095426253, 17.409608671742102, 12.56775354185412, 4.922980041273179, 0.7795564854337323, 1.1595561980239808, 0.21708118699250684, 0.24821870810081884, 0.19782731369618448, 0.4427552451529811, 26.06751911101803, 43.96348599464663, 46.91949006049864, 51.944214913152884, 52.49405668627832, 68.20086248459356, 65.1338827994562, 63.99194355933898, 55.80422724446943, 48.272668546245946, 59.89765198000016, 63.81673128374162, 74.86255322733234, 84.3608706997287, 70.17291253612888, 2.5940369598327147, 0.14251861541021255, 0.30453153315090364, 0.17894991132761204, 0.08796086715113732, 0.11184597943699169, 0.105901887910741, 0.19591917253790364, 0.1833955501957286, 0.08513636226134916, 0.1092653050117435, 0.1807783640200092, 0.1567159713275971, 0.10762547082718342, 0.17445208655009348, 0.18971114839997985], [0.07073700428009033, 0.034511946892786416, 0.01101634243593341, 0.029147151902678515, 0.019054238444134113, 0.06010706318662532, 0.04575278564927079, 0.025656583358443556, 0.04361815059617643, 0.08652998344792474, 0.04612102113183468, 0.04004579833558491, 0.06384293691465451, 0.0317702446162941, 0.09866568950876113, 0.07398076610819948, 0.1680741441105643, 0.25857054778645117, 10.836336978020208, 72.4841142469837, 61.83958999572262, 59.60172876234978, 60.320801196559785, 57.05565552557669, 47.05925587684878, 32.984148225476666, 38.26943220630769, 35.673682151302216, 42.25282269139444, 28.19921158975171, 1.2375032541251954, 0.13427336429876668, 0.08621204929846911, 0.1118474503258063, 0.026616527916743394, 0.5926634527502522, 2.8822615454273843, 5.033887999673044, 0.2380412759920282, 0.7857581816854016, 59.303899272795654, 87.02666251890122, 92.55736135667371, 104.25662271438107, 99.11189294630482, 99.82556035441738, 97.0589400875953, 93.66413654819613, 90.0213372322821, 87.63978389001663, 86.91124285421064, 92.89097462930988, 88.41744868986069, 93.33422599300262, 82.49112390702771, 82.98134173116377, 78.72289503774336, 82.6082694145941, 75.73995605591806, 78.28627247964182, 79.61423796992149, 79.97191890593498, 77.8403539042319, 82.73436577089372, 79.97806918236518, 82.85525321960449, 83.03723550611927, 84.86832341840191, 82.97979631731587, 85.3184546193769, 82.98604073063021, 84.96205237603958, 81.7922124555034, 84.03636517063265, 80.17932599590671, 86.29226930679815, 81.58365218870102, 82.30014370333764, 81.09938852248654, 81.06972755924349, 72.59304631140925, 66.5363968572309, 72.97194727005498, 73.71678183155676, 79.13203747041764, 73.92217282325991, 69.6438632472869, 65.71321687390729, 68.4073438952046, 69.82177411356281, 75.34044696438697, 77.97485982218097, 71.99377875174247, 73.06409159014302, 68.82269936223184, 69.67210431252757, 79.4514988314721, 74.3938535259616, 78.37807163115471, 74.76032057116109, 75.97414508942636, 71.47561011775848, 76.78934697181948, 77.36068725585938, 74.39837209640011, 74.58444149263444, 77.40661821057721, 73.97391673057311, 72.96929574781849, 71.70343706684729, 73.12392342475154, 68.06231652536701, 68.06898455465993, 67.55192202906456, 67.72563595925608, 66.58788973285307, 66.71227593575755, 68.29258318870299, 67.74604797363281, 73.57710622972058, 75.88436988092239, 74.68352056318714, 73.30134007238573, 76.12676451283117, 75.63407559548655, 73.1907606124878, 71.83955900130734, 73.97337544348933, 74.40874284313571, 73.76679989599413, 73.32551756212789, 77.08552514353107, 70.91435816980177, 72.33707243396391, 43.3577073004938, 0.10724924504756929, 6.7942761701922265, 7.385194474650969, 3.534297241318611, 0.4871498871474497, 0.16776735654040692, 0.08596539963036777, 0.15304320792277015, 0.0350960391393352, 0.04911545581454712, 0.3320210661378599, 19.1980270801052, 31.89863031910312, 24.02877699944281, 29.02577461734895, 33.473459982102916, 55.12322141278175, 40.460538787226525, 35.60952786476382, 58.2047805478496, 54.93932893199306, 51.865818500518806, 45.020282345433394, 57.577566100705056, 58.81381088687528, 20.876370053137503, 0.16288167676858364, 0.08900859963990028, 0.02048649727517078, 0.05340681606603246, 0.04686910982033418, 0.003988909217784361, 0.04466821199222919, 0.09098246348120513, 0.08731848710486967, 0.12488823564302538, 0.07280639928555296, 0.06524708031887008, 0.02304597979321355, 0.05076588116466038, 0.023459738135458003, 0.10331719918476959, 0.09965526826319196, 0.0432646393235172, 0.038388106641509843, 0.053613391674814694, 0.01474572835685385, 0.06839279821442981, 0.06297443069577699, 0.04776616813614965, 0.06687415913949091, 0.0385858990522402, 0.03370498817774557, 0.056163342143859596, 0.029149850447391792, 0.11052664579643358, 0.10339071298198355, 0.1328984663010605, 0.30540352506983665, 14.20061271036825, 84.68732956917056, 72.54742914630522, 80.37433839613392, 61.78864625192458, 64.70655233629289, 34.347677846108716, 35.79658569828157, 51.796219964181226, 40.316293624139604, 45.63873421761298, 26.893952700399584, 0.875919743651344, 0.11532018817360364, 0.02085697548013301, 0.10057478061606807, 0.1590656702436747, 3.873758032437294, 2.660311777745524, 1.4562352073769418, 0.9515959925709233, 2.3819492565047358, 75.58368882825299, 93.78136050316596, 101.23688405559909, 105.02976894378664, 103.32702882828252, 102.4274959871846, 100.6802369702247, 97.82323744989212, 95.77943940316477, 89.8967392213883, 93.2807719322943, 94.50770501167544, 95.1124325106221, 92.28703160439768, 87.69086099440052, 86.747632949583, 83.69102401118126, 86.02016664320423, 80.98502005300215, 80.48547483259632, 82.5807971339072, 83.99892222496771, 83.70410119333576, 88.18968449869465, 84.83295932892831, 84.79522612787063, 86.95581666884884, 89.76381794098886, 85.68888325845042, 87.07511948001, 86.93192943449944, 89.79340045682846, 87.52578412332844, 87.48486595769083, 85.68177592369818, 88.47999480462845, 83.37357090365502, 86.8002554678148, 84.89928660854217, 83.65479700026974, 76.52498706694573, 70.34737171665316, 77.53700563984533, 82.80550187633884, 83.09571804538851, 74.08783020511751, 71.25631040142429, 68.94672470708048, 73.4556382702243, 75.57298075768256, 78.1088166083059, 82.23668759868991, 78.12248214598625, 76.08729762415733, 72.27633060947542, 72.6907290181806, 80.42390931037166, 79.22604099396737, 82.16967782666607, 81.75025093939998, 80.84587004876907, 75.90600567479288, 79.28374690394249, 80.4855925037015, 77.20745594270768, 77.62547862145209, 79.78124464711836, 76.45586705976918, 75.45079892681491, 75.03080721824401, 74.21515034091088, 71.45193469139838, 69.75921230931436, 70.03224065226894, 69.56711815249535, 69.85014853938934, 68.47651881556358, 71.50493375716671, 72.36253646112257, 76.08469317036291, 79.33616545892532, 77.94843873670025, 76.64334850926554, 80.08893889765586, 78.7804126739502, 76.0757972348121, 74.53805554297664, 78.99865335033786, 79.57165671933083, 75.37606208555161, 80.20539406807193, 80.56848003018288, 78.4492548050419, 76.40624907708938, 61.569519119877974, 0.9672193445505636, 1.6283866859251455, 1.7885265186909707, 6.456357605995671, 2.9081589944901007, 0.5282201365597787, 0.17580859843761693, 0.2883075682386276, 0.015530249314202417, 0.12588686955672118, 0.13892180196219875, 16.357499553311257, 33.52168944574172, 29.17616809568098, 34.370090269273334, 40.613044461896344, 42.17983914959816, 34.782292150682025, 32.6185146839388, 52.256631697377856, 72.15840062787457, 59.480288259444706, 60.70391478077058, 67.93938944416662, 69.9945152959516, 32.55498797662797, 0.12356395307447642, 0.056805450228914145, 0.0854222969182076, 0.052424350437978585, 0.04773794928745878, 0.053323381430199074, 0.07705041147287815, 0.10655044262567837, 0.03840435153594421, 0.0900042994368461, 0.02098229788844624, 0.03532534457683083, 0.04627333856337974, 0.09873174927047185, 0.03462381488192947, 0.147431276798729, 0.17623054434455213, 0.0944682554672322, 0.10862664049190861, 0.135633185686123, 0.17242150921975413, 0.17307230091143042, 0.17646122874031145, 0.4358971954113053, 0.17467380771713872, 0.15057243647113924, 0.14832715533914106, 0.18835406960739245, 0.22591168331282757, 0.32707523314222214, 0.25628201333024814, 0.29642546489354105, 0.8953283054213371, 19.43350657340019, 105.5228187191871, 87.36823035824685, 90.34320692862235, 87.04760797562139, 89.14911977706417, 70.09004854386853, 50.98190453744704, 59.712006199744444, 55.04877874928137, 63.0652286929469, 42.90113556769587, 3.5638795120100824, 0.5960944234844178, 0.19698182841943157, 0.5603564831037675, 0.18446661772266512, 2.872385507629764, 4.2677760508752645, 17.428351717610514, 4.389056226899547, 1.5477806305693043, 83.32644754840483, 99.13403080355738, 102.23101662051295, 110.78473321853146, 107.40441106980848, 108.9945242481847, 105.01229870703914, 103.14116339529716, 98.65367381803452, 96.61360202297088, 94.82459329789685, 98.27942479041316, 97.86983520753923, 98.98090147203015, 90.43577486468901, 90.05184542748236, 87.3210677792949, 91.3794029912641, 84.48535888425766, 85.36087113042032, 87.03025540997906, 89.62628395326676, 87.78781414031984, 90.70298241030787, 89.39117708513814, 90.84516832905432, 91.36138362269249, 93.33399849553263, 89.92879283043646, 91.84016381540607, 89.08767192594468, 92.06185617754537, 91.37238194865566, 92.33610045525336, 88.66378138142248, 94.45338018478887, 88.18100037113314, 90.13276392413725, 88.0636195213564, 89.3975862379997, 78.62813841912055, 74.15069010949905, 80.69516474200834, 84.41488958174183, 85.37041817941974, 76.05338481164749, 75.29797554016113, 70.09899154786142, 74.20809007460072, 79.63947449961017, 82.68874860578968, 86.47593036774667, 79.79615749851351, 79.69775307563044, 78.09870473800167, 74.98791217803955, 85.41933013546853, 81.6138622837682, 83.83040151288434, 84.11732289098924, 84.91015157391949, 78.57495892432429, 80.68633156438028, 83.67243197656448, 78.55756713498023, 80.11440292481454, 83.06631595857682, 80.50835794018161, 79.89788809130269, 79.54301557233258, 79.64072965806531, 75.52923064078055, 74.14717566582465, 74.29298585461032, 72.8935940034928, 74.6241044998169, 71.40410530951716, 75.29683020807083, 74.3644828181113, 79.98481565906157, 78.7797615605016, 80.88536831640428, 77.19629287719727, 81.52928029337238, 78.98636848695817, 78.28753548283731, 79.10627534312587, 82.1149686075026, 82.23103938564178, 80.60435402777888, 82.75017292268815, 84.09943688300349, 78.94073563237345, 83.56665349775746, 63.66858728470341, 0.7357486361457456, 13.287489837215794, 11.358388758474781, 7.847921386841805, 1.3809712976217272, 0.44730133346972933, 0.27547749540498184, 0.5860362406219206, 0.3538996792368351, 0.18121642841687127, 0.8712228892310974, 28.301269700450284, 48.398815893357806, 39.93945190983434, 49.281847323140795, 50.60957354883994, 76.9730943249118, 60.64969978024883, 52.161216120566095, 75.7990034164921, 73.05588599174254, 69.98154009542158, 65.9211495614821, 75.20747861554547, 86.47811120556247, 36.367533745304236, 0.2514304091492968, 0.18690896731230522, 0.15939753953247301, 0.21748552819894207, 0.133906745261723, 0.08940032337822261, 0.20326874429179778, 0.1867458825149844, 0.1523119157120105, 0.2842444217493457, 0.12912483976012276, 0.17863609107030978, 0.1246222499157152, 0.22319541132498175, 0.1068412266190975], [0.057358347375186226, 0.0872774554356452, 0.05511732569204704, 0.04538446972747484, 0.029341102382468603, 0.00995069785389088, 0.04898476504510449, 0.027522001708407077, 0.039209598044474284, 0.06275287040719582, 0.04666558707193021, 0.03590877032688549, 0.04150017412499555, 0.09103184550880425, 0.05101128977032439, 0.04170949615898632, 0.11506875811685478, 0.2320474806812502, 6.812991269173161, 56.68939244362616, 55.093019162454915, 62.56782900902533, 61.08355314500871, 46.308129833590606, 32.42918972046145, 46.19686003654234, 42.17153549194336, 47.755955111595895, 31.809818052476455, 7.954976597139913, 0.0711853955421717, 0.1912119299654038, 0.06968166453823929, 0.06716949369518027, 0.16030543033153782, 0.3453834475048127, 3.6599908192311568, 1.9415147674660531, 0.04862915469153274, 27.24047645445793, 78.02862767250308, 92.31649644913213, 102.59898201111825, 96.76792375503048, 99.62329941411173, 93.71883007787889, 93.967469123102, 90.43541400663315, 86.39610228999969, 89.68365253940706, 95.05150241236534, 87.81222697227233, 87.53875932385846, 84.0211542191044, 82.92717379908409, 82.2590764876335, 81.44073670910251, 80.99168808229508, 75.10651680731004, 76.73937597582417, 72.36623917856525, 74.10469639685847, 78.16714225276824, 78.60977388197377, 76.32606014128655, 79.64140430573495, 80.23740845341837, 78.66229441858108, 78.61506123696604, 81.5711006041496, 82.77431118872859, 86.36997930465206, 83.09408633939682, 84.78108206102925, 81.89403718517673, 81.79664473379813, 78.29101854755034, 81.60981439775037, 79.53885001520958, 75.75013068414505, 69.39521635732343, 69.23703501301428, 77.48620310137349, 80.4234072469896, 77.46386128087198, 72.85462917820101, 70.07606137183406, 73.26985128464239, 80.98799320959276, 74.22616435635474, 76.81512478859194, 78.04775314946329, 72.93892875794442, 71.56976269137475, 64.87494753253075, 70.1642676322691, 73.7104275918776, 79.54729880056074, 79.85497736161756, 77.1789324668146, 76.43432540278282, 75.36929207463419, 78.01386387117448, 75.87284595735612, 77.11726496296545, 75.63460119308965, 73.47027655570739, 71.23326255429176, 69.38927004414221, 67.25735987386396, 65.53144247301164, 64.96329107592183, 62.39201268842144, 63.125915604252974, 68.7491156977992, 67.06797215246385, 69.11242915738013, 68.56889847786196, 68.53781761661654, 70.70327974134877, 73.561204941042, 75.95347419861825, 74.17241219551333, 74.03773369327669, 77.45479276103359, 77.24067057332685, 72.96360046632829, 71.75293737842192, 73.3412854902206, 73.15196052674325, 73.56111080415788, 68.82785335663827, 74.40926844073881, 70.66218899142358, 70.83842892800608, 24.624402638404604, 0.6802987018900534, 6.700398162488015, 10.945608327465674, 8.01186175115647, 0.4938595609799509, 0.08580806815335829, 0.11914141175727691, 0.10731597896665336, 0.05264141762088384, 0.08848153114799531, 1.4298131413036779, 20.791650779785652, 28.850795722776844, 22.376876684927172, 27.01143749298588, 35.953441281472486, 48.5646850832047, 116.29788337215301, 72.73943701098042, 31.96162162288543, 59.87879322421167, 35.38852583977484, 52.81824450339041, 50.52456402009534, 46.016568291571836, 3.996796165743182, 0.1574298580207171, 0.056906497226126736, 0.01623843248272615, 0.005237758938869041, 0.035618311920834166, 0.01988976457787137, 0.02506707870070973, 0.04771402819202312, 0.03506561778786202, 0.038050288679979505, 0.04461136443780796, 0.048327166662221, 0.005943832971576241, 0.05439479752714115, 0.07012485406331478, 0.04462551791220904, 0.10628280980933098, 0.020872534725875146, 0.05758902411006632, 0.0117333767928123, 0.008901054933366757, 0.06038226112122498, 0.05801679228522605, 0.08611960546864618, 0.04388448106305253, 0.022482556598861853, 0.034932590450250336, 0.05213503733337407, 0.06571854614923078, 0.06638288993628756, 0.21102337737477597, 0.2770799061944408, 12.851600762336487, 69.57277421028384, 69.21774479650682, 75.15501299212056, 67.48320994838592, 60.908674270876, 40.46300988043509, 51.61765798445671, 48.169439608050936, 49.03308276207217, 33.50220311072565, 7.1257885233048475, 0.14165653666901973, 0.15158209439006545, 0.20276285047011994, 0.16364793323220747, 0.8042006759393601, 1.0804565779624449, 1.7296309048129668, 0.488539019058789, 0.2831897944692643, 45.42331764774938, 88.81469849617251, 97.58393364567911, 106.58859729766847, 101.58471984248008, 101.96791971883466, 96.65686576597153, 98.73154071069534, 94.66232484386813, 89.16561726600894, 94.9029936329011, 97.42022960416733, 91.56071847484958, 90.67483548195132, 88.86308485461821, 86.82014972932878, 85.62083013596074, 85.348845143472, 84.57245903630411, 78.6770268409483, 78.2478097177321, 76.84803347433768, 79.33174887011128, 82.98631529654227, 81.2285678617416, 80.15363447127804, 80.73144666610226, 81.96790326026179, 81.79127108666205, 83.93792152404785, 84.98399411478351, 83.42904106263192, 86.68526726384317, 86.68048197223295, 85.3090879994054, 85.49296871308358, 83.1333492648217, 84.31036626138996, 85.40720216689571, 84.9804247579267, 78.41101169586182, 73.08311508547875, 73.4277109945974, 80.96775377950361, 78.06686293694281, 78.26113008683728, 73.57395264410204, 74.06133067223334, 76.96942298643052, 80.91236206793016, 79.6337321496779, 76.82426391109344, 80.12593469312115, 76.14667446382585, 74.27084015261742, 69.55921849896832, 73.7077211564587, 75.12922733060776, 81.75171006110408, 81.93281373670025, 82.8912135093443, 80.21924787952055, 80.42339940224925, 80.7181106075164, 77.47774647128198, 79.77420791502922, 76.79280650231146, 74.86019980522894, 72.28094331679806, 70.6985572076613, 70.05914811165103, 67.52820737900274, 68.03501682896768, 65.44978264839419, 68.17669283959174, 72.36140681851295, 70.4460193264869, 72.09480331790063, 71.67598832038142, 72.05272413069203, 73.11249363806941, 76.48060937081614, 79.94894166146555, 78.5914642580094, 76.87434473345357, 78.049863384616, 78.87465938445061, 79.60832303570163, 75.53026614650604, 74.7253800976661, 77.06797645938012, 77.58561165102067, 72.69671455506356, 76.72456510605352, 77.8247271814654, 79.11772081928869, 40.22861688367782, 0.5830154027188978, 0.6214763873046445, 5.136964455727608, 7.531830812654189, 1.573145740455197, 0.26305130412501676, 0.05246664615227811, 0.05522581906388364, 0.1059577816856965, 0.06050054126629426, 1.1148459584482255, 20.47075971480339, 28.458797970125755, 25.50763607025147, 34.57194720545123, 45.07969448643346, 34.96479611242972, 77.65573578496134, 60.71829026745212, 31.419057807614728, 69.69248494794293, 51.467309613381666, 71.69059522690313, 59.99329113191175, 65.75105597895961, 5.691329702254265, 0.07273208109601852, 0.05403893819499401, 0.08135320558663338, 0.0159324157885426, 0.0458527984277856, 0.01845372701814819, 0.027258432988498, 0.04748760324512278, 0.05750873043472248, 0.00559500058091456, 0.018129332832271056, 0.06495864821537849, 0.03396039806126106, 0.05196441423087832, 0.15718375993592126, 0.10812368844786, 0.18074332315835262, 0.11211099989351728, 0.1413221699335883, 0.09521106964037304, 0.13091624444050173, 0.11625371993549409, 0.11760931251750839, 0.19033552538002693, 0.14365225699880432, 0.12688574861855278, 0.12357991834681843, 0.13959982041870395, 0.16057400543603206, 0.14106828839548174, 0.37712387980953344, 0.565241979014489, 19.61939161823642, 93.94550385013704, 80.4141269191619, 90.01079390125891, 83.56851270121913, 70.77430602042907, 51.47056518062469, 66.06499856518161, 62.11022177050191, 66.59023531021612, 47.65289483531829, 13.771824106093376, 0.28850236907601357, 0.4578533059647007, 0.35645424538562376, 0.2254567803033898, 0.6468333460150227, 0.9118840170483437, 12.369738567260004, 4.656437337398529, 0.3898037687665032, 50.000013689841, 93.40202808380128, 96.19002526806247, 112.20946358096216, 103.32487936942809, 106.55978356638263, 102.39948241941391, 104.28951571064611, 95.96068428408716, 93.84535789489748, 97.77253689304476, 104.2318804033341, 96.15202534583308, 93.08845812274565, 90.30803111291702, 91.09692173619425, 89.58827618629702, 90.19577287858533, 89.17678033151935, 83.6606256423458, 84.27187996525919, 80.3588685681743, 81.8048660216793, 87.99737853388633, 85.5246457745952, 83.95298342550956, 87.43254938433248, 86.3408439390121, 85.66651005898753, 87.35097977422899, 89.39903751496347, 88.70963388873686, 94.507626564272, 90.65538837063698, 90.83606843025454, 89.34280641617315, 86.69075858208441, 87.41706386689218, 88.18823322173088, 86.72955082308862, 84.49913424830284, 77.64421970613542, 77.34973599833828, 85.34823325372513, 82.24342623064595, 79.57359437019595, 75.51481985276746, 81.14280916029408, 79.81081147347727, 88.07795186196604, 78.76891228460497, 79.48192073452857, 83.91991000021659, 80.25290966033936, 78.37704397016957, 72.27192186540174, 77.15966578452819, 76.8810284522272, 84.25784572478264, 84.97789090679538, 85.02899154540032, 80.86273624051003, 81.2698390406947, 83.04074994979366, 81.71124689040646, 84.65274210899108, 80.19041061401367, 79.13290039185556, 77.07366389612999, 75.02535512370449, 74.40127465032762, 72.61896533350792, 70.3039118551439, 67.5743579864502, 71.3425240978118, 77.44559088060933, 71.56897821734029, 75.43226180538055, 74.9304808339765, 75.03685551304972, 75.04336664753576, 80.68402521071896, 81.7244888121082, 82.14171132733746, 78.85242739031392, 82.79949280523485, 80.2184477160054, 81.4559555053711, 77.96412821738951, 79.36741890445833, 78.9356130169284, 79.44420322295159, 75.06147230825117, 81.08250664126489, 79.80315500690092, 86.28723298349689, 39.99410621581539, 1.9579714392462086, 17.37708241708817, 25.44375046606987, 18.83107758337452, 1.0529764525351986, 0.4280851210557646, 0.15754746783885265, 0.24351652170861923, 0.24208379939438837, 0.2226015399660795, 2.7769451708562913, 31.98381047095022, 45.28179460956205, 38.36228647539693, 48.47097965978807, 53.42371333029963, 60.41337305499662, 137.29447210988693, 89.01564936484061, 48.98430024423907, 81.43326067155408, 53.27957014883719, 75.02477461291899, 71.40185386903825, 77.25857227079331, 5.639929982923693, 0.24713374373893587, 0.1246068055831617, 0.1493394179570098, 0.11751778033231536, 0.16915187660244205, 0.07937992397215098, 0.10001287810624608, 0.2237630518333566, 0.1213766341548293, 0.10558316469072335, 0.14517985164157807, 0.15370676263926492, 0.2071913442904911, 0.23391618363318906], [0.0331901770926291, 0.02549571830088333, 0.016083257543223522, 0.012093666028381597, 0.027161727794596267, 0.04997357388117141, 0.04684390169718573, 0.0508855632506311, 0.014115697647925588, 0.07564290111223537, 0.02183243714933915, 0.04752437163504863, 0.025022772005608967, 0.07472177997471825, 0.05065044320579018, 0.018478676586622195, 0.07507116969434485, 0.06341848973064654, 20.57587923542146, 59.15076601889826, 55.304117202758796, 46.06382892977807, 37.72573286487211, 45.842552338877034, 18.084430886853127, 27.501912232368227, 44.317370076333326, 47.23330713087513, 19.35473165204448, 0.475765667375057, 0.09746733647320541, 0.01859797371341096, 0.04591952851643005, 0.07886698980244898, 0.859990630659365, 6.886136608739053, 1.6252071146042117, 0.15259273290153474, 11.194310130611544, 77.18765581807783, 91.45063323359336, 102.66781176290205, 99.31405190498599, 99.18870864375945, 97.10465923432382, 94.11407947540285, 91.35685720751363, 90.67088957755797, 87.2708143726472, 93.08355516003024, 92.09566700843074, 89.90154020247921, 86.08535643546813, 89.46396843079599, 81.94716176679059, 82.56018115628152, 79.8028882857292, 75.83430474804294, 70.6644247424218, 72.29580909975114, 75.20383081128521, 74.1489407324022, 72.21195667020737, 73.99388159475019, 73.18950545403266, 71.50845604558145, 73.2423319355134, 74.93929832212388, 74.24674895501907, 77.48044506196054, 77.63655539481871, 79.31518077850342, 77.67215482650265, 81.35736280871977, 81.15149328785559, 79.60461247351863, 79.35230993455457, 83.66456370199882, 81.65344684354721, 76.56203777559342, 64.24724278911468, 74.36394937576787, 78.34102092250701, 71.08248664486793, 78.53620590702181, 77.97467939315304, 72.46749124219342, 75.24855367598995, 73.66478689255254, 77.8814289646764, 74.48788058373236, 73.07770221464096, 69.62775799535936, 69.02867870946085, 65.86433795190626, 66.19842190896311, 75.88582115788614, 76.81547780190745, 77.70997431970413, 74.78085810138334, 77.0189703664472, 79.35689126291584, 78.60903647638138, 73.32398783776068, 74.12004070897257, 68.51130239425167, 65.1563815147646, 65.41596397276848, 64.70626600327031, 64.70147678928991, 65.61861715009137, 62.835064011235396, 64.18993696089714, 63.59572533638247, 63.125076217036096, 64.95247710135676, 65.97530964882144, 66.74976594986455, 67.39891821338286, 70.8170598553073, 73.58071481027912, 73.39528868275305, 72.36628624700731, 72.33864138203283, 70.76428044226863, 73.66964278682586, 76.40165205924743, 75.34899773136263, 70.91699400255757, 70.452099000254, 72.87879097846248, 75.73512369586577, 71.60992776193928, 71.83114159491755, 68.15743400204566, 65.17148263992803, 7.38232869294382, 2.4213823147358435, 6.492559121501062, 10.948593251166805, 1.1044499614546377, 0.07731216073396706, 0.16557286703778853, 0.07941322581421945, 0.23330098438647487, 0.08660813973795983, 0.17607918069247278, 3.460358602385367, 18.35459197721174, 21.15027504582559, 30.85966702430479, 28.18522245653214, 44.50109389520461, 36.24384180192025, 34.00128941382132, 87.86798738664197, 51.42437142710532, 45.08670376193139, 50.01065115774832, 47.58254320390763, 55.92128253752186, 12.169732009210895, 0.21767588572636729, 0.21138126300948284, 0.10164526591618216, 0.09893601129372274, 0.019350894501492865, 0.05765871129809849, 0.031779037390445034, 0.021533182138697277, 0.05881599052959393, 0.06266936299300964, 0.023762909770612756, 0.0065113317536851095, 0.08087972494503183, 0.05330808265435119, 0.03539427716825758, 0.022153136876201438, 0.007403887866530568, 0.04643880972458471, 0.06340960311072488, 0.08017250321685307, 0.022580018304588816, 0.035221302175834295, 0.030880722690433748, 0.03484311904157362, 0.030228816340827656, 0.10452515130201656, 0.05994170693860901, 0.025716288420822353, 0.06789053564951306, 0.0515232433474833, 0.08096411719077057, 0.14910963754500114, 35.91491968401017, 75.27083273856871, 73.85118576788133, 51.265993964287546, 45.110865562192856, 54.197545974485344, 19.25810798521965, 31.117631504612586, 47.134628142080004, 49.39978122711182, 18.71049607953718, 0.3049200010155478, 0.07965798324514782, 0.11110461317002775, 0.09536807936045433, 0.30046265632394825, 4.142940246289776, 5.798933063783954, 2.4520248511145195, 0.5653866164145932, 21.876639166185935, 93.03405484845563, 96.97196545139437, 104.26000379746961, 100.58394278249433, 102.87028451119701, 99.27785627303585, 100.23348685233825, 95.33972601736747, 91.92822102577456, 95.1353548419091, 95.16385478358116, 94.91035199934437, 94.81408134583505, 90.86404277432351, 92.28543127736738, 86.08065743600169, 85.17243262260192, 84.07121935198384, 77.33293256452008, 74.67984922470586, 77.21504965136128, 78.90701109363188, 77.19421402100595, 74.34794610546481, 77.3599341607863, 76.88214240535613, 76.15160096076228, 77.95243170953567, 79.35573808608517, 76.70434136544505, 78.80410378979099, 78.98039079481556, 82.43618719039425, 82.61517278609738, 84.0682226611722, 84.27210746272918, 85.27556742391279, 84.77800692281416, 87.9399315003426, 84.5461634666689, 81.16599821275281, 68.50156707148399, 77.73492059400006, 80.31995081132459, 73.36847536025509, 81.48629896102413, 81.16924593525549, 79.83588326361873, 79.95059690167828, 78.5239367331228, 81.2263713344451, 76.49864442886846, 73.58091877352807, 69.41174522522958, 73.03381089241275, 70.45393466949463, 70.23967912120204, 76.100264979947, 79.91825303723736, 81.4591718489124, 78.3752396798903, 79.94964768809658, 80.2099753964332, 79.59171572039205, 78.13042102321502, 75.37947454760152, 71.38438363229075, 69.2964118526828, 69.22063166095366, 68.25747013092041, 68.26216913038685, 68.62125427492204, 67.77959992808681, 68.49038047175254, 66.35285346738755, 63.595489994172134, 67.48550845730689, 67.88830449504238, 69.48416002335088, 70.23457219523769, 72.06918239593506, 75.78721277175411, 74.82440425503638, 74.3608428585914, 74.87188846834245, 76.56220251514067, 77.33371703855454, 80.35850771011846, 79.85697777040544, 75.70114812543316, 74.35491223489085, 75.3079854288409, 78.97379336818572, 76.75571656996205, 77.41691050990936, 72.39044020252844, 77.65539061638617, 15.864892025147716, 1.1230587887187158, 1.1860871098695265, 8.157273819369655, 2.3012018732486235, 0.16781958841508435, 0.18127210768720797, 0.031733815220274755, 0.2790444007804317, 0.08572251145397464, 0.23953361526852657, 2.508922262537864, 17.742882659358365, 22.56714301724588, 34.33392601628458, 32.75418162345886, 51.19329283314367, 34.891294817770685, 21.922758394672027, 62.31525582651939, 61.713301443284564, 47.085935838760875, 60.690037435100926, 59.050561228106105, 71.34836842936855, 16.155287642632764, 0.2610143069778719, 0.13772005515713848, 0.07080882502299163, 0.08477949552358159, 0.07641023009895317, 0.1183732783782386, 0.0547413335692498, 0.04304806243688349, 0.040158681391227635, 0.09193778278366213, 0.04975225107984678, 0.07588766620404298, 0.1138172232575955, 0.058920415974552595, 0.1473403574838754, 0.11094285370481592, 0.09040657986676501, 0.13605623475966916, 0.22878955388742112, 0.15163185946162672, 0.14061107180051266, 0.16417346954826387, 0.11217116077821102, 0.1888412249184424, 0.14740224206639876, 0.23864798698454137, 0.18537948809323773, 0.21099006787182825, 0.18047457951451504, 0.16918699407289106, 0.11705710101992854, 0.22976859893289306, 42.49081250159971, 93.09525951262444, 81.22749313231438, 74.27276211400186, 53.823708795732074, 68.47505184911913, 29.039061646307673, 43.284017732066495, 69.28853573337679, 67.5215393497098, 31.160481437560055, 0.8941920438120443, 0.27177266355964447, 0.23243190360165414, 0.24126210880856364, 0.3566448174176678, 3.5302442071899294, 16.13805078691052, 5.478118975316325, 0.9768272515746855, 21.470709154682776, 100.26301445499544, 95.40807723999025, 110.1145648956299, 103.70640831608927, 106.72245994690927, 102.21368758909165, 103.81345764283212, 99.54935489162322, 99.40080688845728, 97.2009377325735, 97.37919376742457, 99.27453010312973, 98.18335025541245, 93.11004684817408, 97.55202908669749, 89.62679386138917, 89.48400389763617, 89.66110675565659, 83.02429168455063, 78.00425406425231, 81.72029187602382, 84.051191729884, 82.04710375878119, 80.23643570561563, 82.75136532322054, 82.65309426092333, 80.00850677490234, 82.52586041727375, 83.38686773853918, 80.4517424491144, 84.65162815586214, 82.74399911203693, 86.59984588623048, 87.23405391939225, 88.8180011318576, 90.82295986913866, 90.8777161567442, 89.12112974351453, 90.38920848600327, 87.72014541010704, 84.70280724187052, 69.76760618148312, 82.04042788474791, 83.50157353185838, 73.43077828807216, 84.33683441531274, 84.02475495492259, 82.68415158794772, 83.40079999739125, 81.22850510381883, 85.01270586444487, 79.29557677238219, 76.85006526208694, 71.37107895266625, 75.72196022156747, 73.64268041426136, 73.72430493754726, 81.85029491301506, 85.17658249024423, 86.68898567076653, 81.39397421190816, 83.52429189989644, 85.51834644809847, 84.19121250029534, 81.12975551236062, 80.15521910882767, 74.78459219778739, 70.25254449536725, 72.68293134627804, 71.27870713510822, 70.09448082216325, 70.61685423697196, 70.40462263168828, 70.73926356530959, 69.26094578158471, 68.51101998359927, 73.09574511743361, 70.42090831264373, 72.64827328343546, 73.78975360624253, 76.67960689913842, 79.09827370797434, 79.29716925467216, 76.74743252415811, 75.98411575440439, 76.01205087477162, 81.05611693474555, 80.65332089701008, 83.02642545392438, 77.37380366171561, 80.18040857007428, 80.50132120809248, 82.98595443848642, 79.17404605496314, 80.12846069951212, 74.27158540295017, 85.56734469629104, 14.933394808923046, 4.969979351566685, 15.488133661208616, 20.89975522410485, 4.551422249886298, 0.20381016927140377, 0.6579840315445777, 0.13424178615452784, 0.6725461372444708, 0.1740377708788841, 0.4743799368941015, 5.182562499277053, 29.42582891833398, 40.08701539808705, 53.39352284708331, 47.44115352630616, 72.02483607876685, 53.95841083218975, 46.00234969969719, 106.57830499833631, 68.41577699107509, 60.87200403213502, 72.83134598885813, 68.718199576101, 83.08162889172955, 19.438199689311368, 0.3636314473565548, 0.2876519808365453, 0.20749725852041476, 0.11929911861736929, 0.19562478027036115, 0.23439023884073382, 0.18940135776515932, 0.12211228540587811, 0.16767427685760683, 0.198036516986547, 0.13246187279301305, 0.18037345590851, 0.1977888560823856, 0.16937300022090637], [0.03263379807674116, 0.07694252331050173, 0.013073193709245853, 0.07478914208590023, 0.027569629394659595, 0.11946793375236374, 0.01542295582757722, 0.020095543455212347, 0.015832684547339958, 0.05692280340759505, 0.0200093413267525, 0.08469242197010787, 0.05180873367334566, 0.014940392256023423, 0.07143328627271038, 0.03220666192411896, 0.011166741774838057, 2.177308418097035, 51.37042314775529, 60.004991562135764, 46.11414117197837, 60.76248753455378, 52.63066499463974, 42.28533914012294, 38.1385152570663, 36.51399112516834, 40.04245335055936, 29.97963228533345, 4.483968759736707, 0.049066709639925155, 0.06589619427799218, 0.07347662662786823, 0.023540972183728893, 0.2995451894258299, 2.4185434993236297, 5.005659191839157, 0.2719353499912447, 0.8690967194495663, 58.095828871573175, 88.24567241053428, 97.0523661951865, 96.50365798704087, 99.4133270940473, 98.70304076902329, 95.33264221683626, 90.9767246246338, 89.02631821170931, 87.17258253405171, 95.1229601521646, 88.66914718381821, 92.72408562321817, 87.88912896187075, 90.99071179666828, 82.18911709324007, 83.35932485518917, 79.32191156571912, 74.9677590400942, 67.18520395217404, 73.21500870489305, 72.04831538661834, 68.7620516746275, 71.44445865384995, 71.65378770520611, 68.57006734417331, 71.18431137454125, 72.14464879805043, 70.7133759221723, 69.86015842806908, 69.5195633365262, 73.01102192171159, 74.64161396026611, 75.72434502263224, 78.14724014651391, 78.18339655476233, 77.26476177092522, 81.07093564925655, 82.21879374596381, 82.00830367303665, 78.4775350939843, 72.72373968555083, 65.59904844530168, 72.58672345069148, 72.56420120116204, 73.21405949131136, 76.66645911432083, 74.69613490566131, 78.4176326567127, 75.19104388452347, 77.65460614235171, 74.97902408722909, 75.60882337631719, 71.30761500327819, 67.51905256702055, 65.41816050006499, 69.55323296208536, 66.52235477201401, 69.9931267769106, 73.64135465314313, 75.14513646402668, 74.28362707937919, 77.42812064386185, 76.94179381093672, 74.36474169454267, 72.08193794373544, 71.02924439214891, 68.49899399665095, 66.65694698210686, 67.19460979584726, 65.94168709170434, 64.2179387615573, 63.86645909278624, 62.762649213114095, 61.2978086933013, 62.5229767061049, 60.026133137364546, 60.53934389545072, 60.95059264090754, 63.75125908082532, 66.94313095461938, 68.3281433966852, 70.11530076303791, 73.79693154365786, 73.55142254983225, 73.46175716769311, 72.69498871218774, 72.510252921812, 72.23545166753954, 74.58892868411156, 73.05905526684177, 69.40051155705606, 67.14917305977114, 71.52849151242164, 73.87427283871558, 73.45080591017201, 69.04534093795284, 68.95777010148572, 47.14106867390294, 0.6066042917870706, 2.4665523296402347, 4.645068837750343, 3.0637400525231517, 0.46364732086658483, 0.12047785980206345, 0.0622847983463397, 0.04772848810159391, 0.07784866742909917, 0.05661912232397064, 0.3146913299156774, 2.7876081341697327, 10.41683360453575, 21.38269312920109, 20.90160854401127, 16.841331758806785, 24.736731475399388, 46.35977568164949, 33.29349379385672, 40.29141795250678, 53.82328125738329, 55.619181586850075, 54.40041880453787, 50.57147556735624, 12.988490500757772, 0.22432381287217143, 0.04853407551925029, 0.02133978515743248, 0.16824455270844121, 0.04330913371015941, 0.08311939065254505, 0.07247819189703272, 0.08891935805760084, 0.09011823203294508, 0.04042680067340693, 0.055983116129233, 0.0683847236477079, 0.04353721723741582, 0.05693162107960351, 0.06149386619067481, 0.0730809498758566, 0.030136950907387564, 0.043725153927000306, 0.03066235698849684, 0.03647311282674632, 0.06274088113118084, 0.020165075510439855, 0.03470502786278244, 0.042269437483722166, 0.07547505124802552, 0.013865431087211737, 0.11990468047799603, 0.04538065460961192, 0.06987717017651567, 0.08880922525760629, 0.15996933223739748, 4.608306423310311, 69.43387523774179, 73.93826238570675, 64.00781346905616, 85.81104155509703, 76.40130689067226, 28.319545984268192, 25.0440138770688, 39.813504603601274, 43.453079731233665, 32.05445628012381, 3.5017626516280638, 0.07852298568093008, 0.15789102762937546, 0.08220711016967412, 0.8034284593116853, 1.861183400596342, 1.3313637337376996, 4.33460686476, 0.7207162137473784, 4.7594024961994545, 78.9235713404994, 92.31442543768114, 101.54827317883893, 99.43075026235273, 103.12524641713789, 100.71555399125623, 98.16342461493709, 95.24073323895855, 93.10575577520555, 91.10094608799105, 97.19590140927224, 95.7766309861214, 94.52126072299097, 91.14187994310933, 92.4653111734698, 86.43682433712868, 86.31886297656645, 83.18288095535772, 77.34054980739471, 73.4245809431999, 77.65530432424238, 74.81408057674285, 73.00900582344302, 76.15787675303798, 74.72612534799885, 72.60778657851681, 73.26172413364534, 75.99640846252441, 74.48173030730217, 71.98821683083811, 74.5511641040925, 77.44755991043584, 78.49771961089104, 80.24559836233817, 81.83146753618794, 80.98249404661118, 80.94389007937524, 85.6311224352929, 85.71248808214742, 85.7358967873358, 82.06600173827141, 75.60393610308248, 68.23197472480037, 75.7298755645752, 73.66719522783833, 78.05282085172593, 77.45254916529503, 77.08038683860534, 80.02989153708182, 78.95637804462065, 80.53916423551499, 77.23395547559186, 77.5868824989565, 74.87966260602398, 69.56711030775502, 66.85970214105421, 73.75658604406541, 68.59835547785606, 71.62803342265468, 76.77390852282124, 77.85874982034007, 78.71038267689367, 78.59607696533203, 77.66297648029943, 75.06926998015373, 74.040722539348, 72.92496512013098, 71.76305709346649, 69.67291232078307, 68.63082485814249, 67.88773967373756, 67.3342461739817, 66.17710774944675, 65.59505155009609, 63.681456581238784, 64.59715350981682, 63.68617127018591, 65.7297771207748, 62.60065140262727, 64.48105919745662, 70.31804023250457, 71.32398697637743, 72.12762571150257, 77.67612426511704, 77.62088160361014, 75.83052358319684, 74.82573786089498, 73.9836363638601, 74.76927926463466, 76.5686430469636, 76.56357534470098, 74.45242235737463, 72.971037280175, 72.56465619610202, 78.26123206846177, 76.29217086299774, 75.49998544877576, 73.05575263115668, 64.74345399487403, 2.472244914500944, 0.35534197765011943, 2.694764651598469, 4.010586974120909, 0.4123160591529262, 0.18824110228207805, 0.07677672656192895, 0.01844217441225004, 0.3276475621086936, 0.07895447704340182, 0.7574543585219692, 1.8067999833053159, 9.461077509387847, 23.495928895088937, 26.768813402422015, 20.6545933600395, 34.01859491102157, 50.10492924721011, 43.27978549465057, 56.44775090679046, 63.42703596238167, 63.191897715291674, 63.24865833405526, 61.96321918118385, 14.860976088431576, 0.1165360309964707, 0.07935724010871303, 0.03377229283233324, 0.033804307646688916, 0.08879679931147445, 0.02391046596570842, 0.08143212030371351, 0.041579682560217, 0.0817166147152743, 0.04780924142969232, 0.06024515819585612, 0.027303166777616548, 0.008084169634047055, 0.09696508923004712, 0.11978671059853609, 0.1879994934725185, 0.14713689985294498, 0.14091445794028623, 0.07413808992432971, 0.24784165494624646, 0.15191014856100082, 0.160196078941226, 0.14974193587418527, 0.24660096023111577, 0.11085277708667902, 0.12139034712867391, 0.2583348991409425, 0.2543714053688511, 0.19586163933479017, 0.15517687004420067, 0.19467360550357451, 6.615316560191493, 86.45546344018753, 82.96649163769138, 77.77039450983848, 86.87897743717318, 73.77433869146532, 66.16628200777116, 50.65216264417095, 55.43313964720696, 59.36605315054617, 45.685535938509055, 6.9290017408709375, 0.19561428486579852, 0.2069558182190503, 0.15579608359163807, 0.4358990033788066, 1.5720210008082853, 6.193761296810643, 12.756437197808298, 0.8800963937274872, 3.672233762279634, 85.094267629808, 93.3357164936681, 103.04803848266603, 104.0034023407967, 106.9523657521894, 106.46497987931775, 103.27718334813272, 99.90118365133964, 95.81359540262531, 92.29194241185343, 100.73266336994787, 98.5390543168591, 100.7780844165433, 95.70038010997158, 96.81203472998835, 90.91756743769493, 90.70248819166615, 85.69837539426743, 82.45190020530455, 77.09904947588521, 82.19606753318541, 77.98754476731824, 77.7492529346097, 79.84720322393602, 79.31689093189856, 75.80169416243031, 76.84086338166269, 80.48663585416733, 78.90122167525753, 77.01726021305208, 78.52111262659874, 83.396924695661, 81.69510241477721, 84.85112774756648, 86.08129285996961, 85.78165515776604, 85.22166621300482, 86.81746682813092, 89.06955842048892, 89.53057812106225, 85.48487294104793, 80.23168179296678, 72.85455073079756, 80.83862935343097, 76.06023326996835, 78.93420880840671, 83.39342594146729, 79.31605938942202, 85.40746888806744, 80.61157903363629, 83.30838111139114, 80.00628671338482, 79.06837740252095, 75.97502370034495, 70.73086969314083, 67.66099529881632, 77.7287938517909, 73.72867445791923, 77.20915040662213, 78.78513520763767, 82.29935138456284, 79.90440707052909, 82.9054360235891, 81.53857631068077, 79.33719311991047, 77.43090552668419, 78.04543895106163, 76.18479990190076, 74.87200613944762, 73.44677371363487, 72.38822798575126, 70.64547969448951, 68.78798638620685, 69.6574503375638, 68.54776474737352, 70.0580184690414, 66.19087526875158, 68.293744210274, 68.62139548024824, 68.70902122989779, 75.5502623896445, 76.36874337350169, 75.9434643099385, 80.49120149304791, 79.68716267616519, 79.08816968241047, 78.23013551773565, 76.5146476991715, 79.89706439356651, 79.41536595744472, 80.08638151230352, 74.77764960258239, 75.19543693911645, 77.71825052076771, 82.87124080042686, 79.30238600700133, 79.85708759677026, 78.38208029347082, 68.62651809569329, 2.2967771945461153, 5.717621349519299, 12.478298006519196, 10.970707574198324, 1.251391631460959, 0.46370082444721655, 0.400267978228869, 0.239885556060941, 0.820006356844979, 0.4490609761447676, 1.2904715538024902, 4.187682232549114, 18.31671953201294, 36.24052347675447, 39.46453132937032, 29.96017340690859, 37.59537289219518, 67.04091564301523, 46.97339911614695, 57.259654075868674, 79.58242754782401, 83.85536347666095, 75.2222659510951, 77.81494479025565, 20.083637468276486, 0.5225588693734139, 0.2723950333893299, 0.0660671544591746, 0.2649481378255352, 0.18820555580239143, 0.23275695470792634, 0.1882705507018874, 0.22884137207461944, 0.19666155770180688, 0.15407474531281382, 0.14498543384815418, 0.18299111705874244, 0.15107050087423096, 0.27595476818180853], [0.10104302121626754, 0.059015395555404894, 0.092961912103478, 0.019221349033497034, 0.01914567486833661, 0.03683412410018425, 0.035124683166824044, 0.055265494757482124, 0.07222099319821404, 0.026236490849705956, 0.02925444826213343, 0.057282278674744794, 0.026915160480946786, 0.048439226173345125, 0.05764013366593469, 0.06722342628504961, 0.1470725637890639, 2.6198348787523087, 56.647897689573234, 56.62688555256013, 56.386467795218195, 73.89561837719333, 21.518487545751757, 45.490998145072695, 52.52814992781609, 42.02888673351657, 28.20205334694155, 11.115060602464984, 0.4405647239858105, 0.06676165912781032, 0.08894643160484492, 0.05083621186654895, 0.3020639026597623, 0.3606433367296573, 8.012414315054494, 0.597199367419366, 0.32367040132803304, 39.0182871972361, 95.44854041068785, 96.78307979337632, 100.08428773572369, 93.31003281377977, 98.89660189228674, 94.58954918769099, 93.3519394167008, 88.27758481425624, 89.72001291090443, 94.37845506975728, 94.34338908041678, 92.00680963454708, 86.62924012830182, 87.25905510687059, 83.80631031528597, 83.06267599905692, 81.05371644420009, 75.74950310491747, 70.1434398466541, 74.09455314759286, 72.20352357433688, 69.43818200019099, 72.63553342511578, 71.37768422403644, 69.46785865291473, 70.83508706861927, 72.15383498899399, 70.69450932164347, 69.0305143787015, 71.10419304140153, 73.43455945291828, 71.24228400568809, 70.8557108909853, 74.11130166822865, 77.26565607132451, 74.95030449282739, 79.81206663193242, 76.48320597987022, 79.15728184484666, 78.15794037234399, 74.23961024130546, 67.99206687558082, 68.37077171571794, 75.98815579568186, 74.64710527850737, 77.53228310615786, 70.13583044851981, 72.35267562250938, 75.49588264957552, 73.2877294478878, 74.09660062482281, 72.22223328005883, 71.6338385305097, 72.40818500518799, 73.1873324609572, 65.7640782479317, 64.8589168056365, 65.97975761659684, 64.88448281441966, 72.08003951657203, 74.95746674076204, 75.15107493246757, 72.52817815349948, 72.64644545893516, 70.5027211096979, 66.9996052403604, 64.03765878369732, 63.92833448225453, 62.066742297141786, 62.38015536339053, 64.26734885861798, 62.12387554107174, 61.3057711047511, 64.01445796412807, 63.197369421682055, 57.59561292586788, 59.72260052157987, 59.511502481276, 59.09022423528857, 60.755894030294115, 62.51644595976799, 67.55495794357793, 68.93054885248985, 72.74292007569345, 72.32703116632277, 70.64760561912291, 74.56232716960292, 72.24688929896202, 73.62627706220074, 73.49001392241448, 72.20063670989006, 72.22784226940524, 72.36838863741967, 68.10907117782101, 71.87113408119448, 69.13635561543127, 73.71840569280809, 65.3200424102045, 64.869558195914, 18.556454796944898, 0.7486807518909055, 2.957297712564469, 3.5604317486286168, 0.3019914000986084, 0.01749151100915286, 0.04652567643431887, 0.13108406366119463, 0.04663119738500926, 0.10833894383282432, 0.21583355152078215, 0.05818570318121103, 2.536856402312556, 14.03683610500828, 31.15257590047775, 25.2509424378795, 21.444007619734734, 18.145594366135136, 13.594120144844057, 33.75378001120783, 35.261476347523356, 49.018028705350815, 50.79255603974866, 43.30557900090372, 2.917140731888433, 0.05356889345773286, 0.051567170829061544, 0.05753723656638496, 0.023900133354829687, 0.028410956729203466, 0.0704836436817723, 0.013502713352922472, 0.009737657420637627, 0.06311422642019969, 0.03545475597943991, 0.026092424185105392, 0.09963453792396093, 0.02651196840639797, 0.016351472586393356, 0.03575014416128397, 0.06214080829053156, 0.05815446977653812, 0.04749300033454934, 0.09144599264067027, 0.0893151650445596, 0.03197374438206035, 0.00714333801184811, 0.06411443081414027, 0.049703478092147466, 0.0785912670976212, 0.09831194074884539, 0.04576556782628741, 0.05680697857432308, 0.056093494077363325, 0.058607495870561375, 0.2496734784255105, 4.179491833333047, 66.7944025224255, 67.59675472013413, 73.7146637516637, 98.5737672928841, 36.040106050429806, 34.96559235357469, 48.93028528459611, 47.3484286954326, 32.737121274394376, 9.715523623651075, 0.257211109443057, 0.02743657332875075, 0.13043580005966848, 0.027422052132146015, 1.4211917716649272, 0.9019745165301908, 3.3795286042075006, 0.40067749818967235, 0.8822541876185326, 66.97189761746314, 100.74339497473933, 99.1522619801183, 101.68134350930492, 99.45625351321314, 100.90913080400037, 99.94629875306161, 98.8927971932196, 93.17323623165008, 92.61605570393225, 97.60475358655377, 97.34627723693849, 91.01475592582457, 90.26322980080882, 93.3884959067068, 87.92344185613817, 88.55417466932728, 84.13479312773674, 79.52836944210915, 73.31062040021344, 78.82027179964128, 75.94144036692958, 74.39645797975602, 78.09908128553822, 77.41880893707275, 72.62200909276163, 74.98344067604312, 74.62382993390484, 74.40407522263067, 71.1827188922513, 75.18800012526974, 74.68783517037669, 74.6313295056743, 72.7629320083126, 75.95539616000268, 77.34954772457, 78.48036704524871, 81.19342342499765, 77.85815362007388, 81.59475249628868, 82.22536763837262, 76.2347081399733, 69.81409411276542, 71.8605201475082, 77.28855486839049, 77.52338717060705, 76.86780222000615, 72.81813544611778, 74.83030349977555, 75.95974214615362, 75.45929478060815, 75.48433519178822, 74.87173941827591, 70.81361601429602, 74.27935169589135, 77.41145841536984, 67.88810053179341, 67.98500660927066, 69.9928992794406, 68.43182732982021, 74.29453126845821, 75.83644636215703, 79.05243689014067, 75.59521275181925, 74.59311777545561, 71.1336971098377, 70.22172251055318, 65.79211142755324, 66.82103541589552, 64.1699524848692, 64.48316551023915, 65.64401057458693, 65.32876968383789, 63.49627756303357, 65.0136072404923, 66.55168625616258, 62.56333789517803, 61.49162084825578, 63.06584058269378, 62.659655617129424, 62.52399259997953, 64.60230750422325, 69.83964443206787, 72.21070935649257, 73.48401269605084, 75.24944797638925, 74.43911767775013, 76.18476067819904, 76.640422421117, 75.62044143676758, 75.75814016403692, 75.20835722646406, 74.93272442971507, 76.93292925434729, 72.37328375539472, 76.22938940601965, 72.99286919255411, 77.9007113364435, 71.79388692302089, 74.96261289042812, 33.552864443871286, 0.10518758753014189, 0.2641329283435499, 1.0727834413128516, 0.23894060192809952, 0.04687895405016119, 0.14096383996788533, 0.1513587797601377, 0.6579916924238205, 0.3380869196787957, 0.15264102708428137, 0.13571621429535652, 1.73488283589963, 10.5857063493421, 33.83747162357454, 23.76584287612669, 24.390282246374316, 23.675447933135494, 16.6516145583122, 44.14122427663496, 42.8967385907327, 58.139116148794855, 57.42412297956405, 54.04569925800447, 3.1754342009944305, 0.086695542709241, 0.0841329939242813, 0.017476070507038987, 0.04610709365337126, 0.01509873592670286, 0.03895282835489319, 0.06361619021082598, 0.05406288993394664, 0.03730887644774011, 0.04954184503144315, 0.0166239662306203, 0.02151139268291093, 0.0494219254582159, 0.027656160940926884, 0.18384892102931777, 0.1723947267859213, 0.1863343707255779, 0.13784247600743849, 0.19397631227489442, 0.1551343521644031, 0.18128499328609438, 0.11518776221501252, 0.12997781737677513, 0.3007708381741278, 0.20451726842551463, 0.15545074647713095, 0.14875005119510237, 0.126716481491683, 0.1655854615232637, 0.18080482469691386, 0.3298732620333472, 6.147041945688187, 85.3615536228303, 77.97437344827961, 79.83830728838521, 89.40703915011498, 37.81245646938201, 73.50446393412929, 77.66972295699581, 62.33410673756754, 45.044102899489864, 16.865901485566173, 0.8692892833102135, 0.14440478516682503, 0.3593940005427407, 0.18997747120597672, 0.9327964400572162, 0.9111057942913425, 15.947945271768878, 4.3190703565074555, 0.7400253066612829, 64.87710483612554, 102.32450239119991, 103.68000292008924, 107.92621966331237, 101.26477210752427, 106.12537322505828, 102.14493628471129, 104.04858804518177, 96.74202826715286, 96.09838301135649, 103.28929562722485, 102.58293167237314, 95.1529113708004, 94.71377849578859, 96.50806673111455, 91.7122474793465, 89.8350638727988, 91.37501778141146, 83.7134599685669, 77.47783276342577, 82.77963776742259, 79.75159152861565, 78.71824310671899, 80.94920096858856, 82.1024876256143, 76.71002095745456, 80.09167671203613, 78.92816835834135, 79.6094056098692, 75.79069583646714, 79.11379844911637, 81.50175309950306, 78.83254881828063, 77.53786856128325, 79.88331256374236, 84.90262062318864, 84.3961484970585, 85.84819424536921, 82.13590621948242, 87.00594455965104, 86.29590926631805, 82.24753687458654, 74.19030604823944, 77.56989079137003, 81.64946956019249, 80.13992186515563, 83.28228166026454, 77.97820168156778, 78.67040588009742, 81.43876767927601, 80.41818264992007, 79.99641018529093, 80.84857648418796, 76.59526809569329, 80.00052082923152, 81.5239066462363, 68.00831333283456, 69.55072264517509, 73.7075799511325, 71.77700504179924, 77.61542950907062, 82.58427235387987, 83.32822045972271, 78.35860883035969, 75.38288700965144, 74.84674607553791, 74.07039919207173, 69.71292049654069, 70.63996484202724, 69.2487628998295, 69.0115144175868, 70.82211971282959, 68.47123146057129, 66.27833627885389, 68.797117663968, 68.64640451246693, 63.91102114031392, 65.19842932301184, 67.20780464910692, 65.00629986486128, 67.0152319631269, 68.74725649433752, 74.2111102996334, 77.80275406376009, 78.0340091643795, 76.78400470364478, 75.64975723143547, 79.53469230282693, 79.38605016277683, 77.51024723052979, 78.98806295087262, 77.65687327231132, 77.14418811182823, 79.23895343657463, 75.08247267815375, 81.48666766382034, 75.15316947813957, 80.29884061505719, 75.7040899030624, 81.12773941409203, 36.71248266773839, 1.6111028843349027, 10.241370297247364, 8.272713095911088, 1.665100438460227, 0.16576737676176334, 0.3323310253120238, 0.3339072052509554, 2.1389640627368807, 0.6543506910243343, 0.6546376369172527, 0.5706054525029275, 4.865659994463767, 22.14562354549285, 45.942443340055405, 44.88989883853544, 38.05631806773525, 30.696419938918087, 22.020843144386046, 50.935675482596125, 49.93842463339529, 70.54560046042167, 69.16461237015264, 71.57659546021493, 6.231805345704479, 0.31633176930969764, 0.20518875981290496, 0.12100871276831436, 0.14544479548931122, 0.15300657359823105, 0.1422782629848488, 0.12457311303625185, 0.2283703965405303, 0.17222911389845033, 0.17530178531042992, 0.070694777513704, 0.17083371538789044, 0.0968311234347282, 0.2601014672508163], [0.07531234183378759, 0.07033858493330979, 0.0624539275773831, 0.020132239066785382, 0.06113968076064222, 0.10378089688357808, 0.03375764140078137, 0.03406295808212411, 0.04996861346186169, 0.05076530276827755, 0.13163383899917527, 0.05415286696065338, 0.020422235904862324, 0.07145618464076711, 0.022619023671253555, 0.03256912110373378, 0.2564289949594006, 5.732191483820639, 53.4687303727673, 54.35255804369527, 46.45841152437272, 23.668703417624197, 26.897733865245698, 22.536936844548872, 30.64771979085861, 26.23671643195614, 17.52961947071937, 0.8087118306467611, 0.10963386991211485, 0.01032908400145149, 0.19064694012124694, 0.09260739725563796, 1.538827943225061, 2.295578665310337, 0.8558736741542817, 1.3866576312049743, 20.013878114761848, 103.16676862778203, 95.09241273326259, 98.75361581002512, 94.15517022532802, 96.928662484692, 92.47199489224343, 93.772825425671, 90.3527775118428, 92.15016441960489, 87.51888075182515, 92.22259490720688, 88.51358598278415, 89.12628373792096, 87.03813937402542, 84.99887558721727, 84.80730702800136, 85.64616080253356, 77.1467141182192, 76.33491685313564, 74.27188350308326, 76.57304394629695, 71.65246194408786, 76.65462140114077, 73.01903140160346, 73.58732792638963, 70.68548787024714, 70.12884862961309, 69.1135274210284, 68.18051322813957, 69.33692209182247, 67.7114369792323, 65.21969641408613, 65.47225782948156, 65.8875976070281, 70.11679910844373, 68.92829741201093, 69.33970697464483, 72.21119573039394, 74.00818255639845, 73.98691546532416, 72.84829062800254, 69.19678365030597, 62.620859453755045, 67.2269771945092, 74.86593431042087, 72.2204682134813, 67.66603946685791, 68.61384099529636, 73.07186572782456, 70.59549300901352, 71.53072726341986, 73.2095330761325, 69.6044748060165, 64.58682983152329, 64.40178025153376, 65.65927251692742, 66.79954082735124, 67.71761078988352, 66.15158096436532, 61.053696063257036, 68.01356930886546, 70.25138347379624, 70.29337636886105, 72.887726137715, 69.11733212009554, 65.17975884099161, 65.15414184139621, 61.6753525118674, 62.40179900200137, 59.2123080069019, 58.91217216368645, 59.898769855499275, 61.980650194229625, 61.923473804227775, 61.86461863979217, 60.437166152461884, 62.02200766532653, 60.70163980607064, 59.701553083235225, 58.92395104131391, 61.73044612330776, 60.569738341916, 62.536516727939734, 65.30958144895493, 70.49507248786189, 70.8669759381202, 69.79809868720271, 68.02293592883696, 72.8082981417256, 70.65995324042537, 73.87537110236384, 69.11508067961663, 69.6251456968246, 68.48325744751962, 70.7234799477362, 69.77992242382419, 70.09121741017988, 71.3601198504048, 68.26128267472791, 68.6750848831669, 51.28025177986392, 3.735663881224971, 2.0219564509968606, 1.5289204038919941, 0.13186421695976488, 0.14524674643912625, 0.0763296070058019, 0.08642000386551504, 0.37491068243980413, 0.10278304437956504, 0.11578685829355834, 0.04245710987297278, 0.2513438871791286, 2.006015080598093, 17.5813437661817, 33.958241401180146, 20.683818940193426, 31.665780775008667, 40.96139015689973, 37.71363235289051, 41.67681870921966, 45.88676137308921, 50.39319207591396, 31.562218435349006, 0.1819204019322511, 0.012835144335704466, 0.056140746380532944, 0.0820078200570518, 0.08212994213306135, 0.0389664493981869, 0.018036829630633997, 0.039031700937137495, 0.03865733292073973, 0.14339624573626827, 0.05183858045887563, 0.06203938207979645, 0.017742345432540583, 0.031153794731043523, 0.004052161267252579, 0.009655186140369023, 0.0516288370765265, 0.03468669154831479, 0.05542979763460256, 0.020091218888879787, 0.10203691304571207, 0.03819757291386205, 0.041493746647310835, 0.04650056407216095, 0.03942625153990042, 0.04103075374939269, 0.042172799322513804, 0.007903299147954151, 0.04794945467203375, 0.06180212464964679, 0.04271395234090667, 0.2551770693952999, 7.98690616123138, 70.29130535741007, 70.30773224369173, 68.63955605414607, 34.74616712139499, 23.25468155645555, 23.294521070295765, 36.796695955338016, 28.0807932730644, 17.19122875121332, 0.4426569407505374, 0.1320659891972619, 0.025602367316042225, 0.08029089444467137, 0.038749523941547646, 0.37406547295470394, 2.904447451714547, 1.7823025752459805, 1.2330449901280867, 29.271675848191787, 113.87851838142642, 91.685512604252, 101.30257591124504, 96.5635447348318, 100.4752068365774, 97.90123770313879, 96.43291411861297, 92.86017617871686, 93.6813400637719, 91.02318902169505, 97.39291421828732, 89.9440900741085, 91.57767095873433, 90.51288866227674, 89.83446767253261, 87.4608688969766, 87.9672468862226, 77.80580566775414, 79.46070855663669, 79.82840722607028, 78.64005457970404, 77.12747097015381, 80.14424431708552, 78.0236384176439, 77.60529410454535, 76.86197357793009, 73.190674320344, 72.01791701778289, 72.33091431279337, 73.35324087450581, 68.63109942405455, 69.0610461081228, 69.74814338068809, 71.10588750531598, 72.61179524083292, 73.79977918440296, 72.55294399876749, 76.85376013478925, 76.10974927102366, 77.68097231465002, 77.22460454510104, 71.41979479020642, 64.735213095142, 70.71097543162685, 76.38848074020879, 71.17939272234517, 70.22320516647832, 75.01782417297363, 76.61303643257388, 76.17039695862802, 76.40969291810067, 75.75770870331796, 74.28385457684918, 69.85482400463474, 68.6420036131336, 68.48289658946376, 68.48552457747921, 70.01690418489518, 71.24153875535535, 63.725900957661295, 68.50219465071156, 71.27829136386995, 74.6625437275056, 76.06716017569266, 70.71502331764468, 68.76161236916819, 64.17846010577294, 66.0732041635821, 64.527276485197, 64.12326843507829, 60.84581436649446, 61.78901887709095, 63.49954489738711, 64.62897569902482, 65.91931389224145, 64.38421587790212, 65.44990031949936, 65.64106487458753, 64.22666211282053, 62.97234696726646, 64.16221364851921, 63.791918370031546, 65.50005958926293, 67.22820097400297, 71.46156018780124, 73.50776656981438, 73.11012452648532, 70.7195261986025, 75.82850748492827, 73.8065335058397, 75.04063667789583, 71.45595904319518, 75.87737237253498, 71.32632470900013, 72.71241972523352, 73.60857932798325, 73.87108002939533, 74.20915695928758, 74.62734437757923, 74.28465474036433, 67.86878678106493, 7.275889785059038, 0.6809135947015978, 0.8992671618057836, 0.049158272468635154, 0.15915956197967454, 0.04845197387640515, 0.25988061942400476, 0.5515165639019782, 0.09558969327519018, 0.08141530467377556, 0.11941132751563865, 0.14629853919388788, 0.8992222996969378, 18.56274627870129, 39.6511027889867, 19.818804917796967, 30.51306874521317, 35.426800327916304, 41.66221572506813, 49.598598326406176, 53.43730826531687, 59.940182239778586, 40.59969663619995, 0.3920685085317781, 0.07415037797463518, 0.016480250051245093, 0.017599632828346184, 0.023896107562787594, 0.014274432981056313, 0.029008396142613024, 0.049162183347488606, 0.02794149613398458, 0.06328639702030248, 0.06282332368315229, 0.046405427443284186, 0.06754489976071543, 0.04862700581490513, 0.048933494610772024, 0.19477918774129885, 0.17981994206145888, 0.1855259334608432, 0.23439926335648184, 0.14721707861510017, 0.23923885527878042, 0.12478510488665874, 0.07546609568019068, 0.16127814749075522, 0.12394742604585425, 0.2339862193912268, 0.09476283159587653, 0.15272146631633082, 0.1454759139807955, 0.18216190348950126, 0.15960346396651962, 0.2512040148459135, 9.63649178704908, 88.18792727685745, 78.5236386329897, 75.08266095192202, 46.29163626701602, 46.82442749700239, 36.35018510203208, 55.331134488505704, 41.701643390040246, 28.61014262322457, 1.4394443986877319, 0.437997134342309, 0.24204005577391197, 0.4091109617823555, 0.18339473814252885, 2.894355683557449, 6.302236405111128, 7.880396650683496, 3.1329745438791092, 28.339553994517175, 115.01973982780211, 96.83005409855997, 107.77517703271683, 97.89868816252678, 104.93550654380553, 99.32219474546372, 100.2999004240959, 97.10633016401722, 98.03783032201953, 92.67813897901966, 99.86386622152021, 93.08826200423702, 97.20326762045585, 95.3190629712997, 93.82263168211907, 92.79260943012854, 94.47780086148171, 84.2481182467553, 83.50202852679838, 83.34874230046427, 84.51377253378593, 82.26121810174759, 82.80811417487361, 83.23824128796979, 81.65957358575638, 79.47464866022911, 76.95325497658023, 77.8444645481725, 78.68446365479501, 77.16785569344798, 74.459396331541, 72.47565761689218, 74.95739613809894, 75.00320942171159, 77.00324950679656, 78.83444724544403, 77.88192318331811, 79.5250746511644, 80.95025216379474, 79.55155849456787, 81.13009283619543, 77.53561712080433, 68.70874666398572, 74.00156944028794, 80.7194834370767, 77.62000299269154, 74.32654565380466, 75.46836330044654, 79.86260244923254, 77.2118019288586, 79.61806620320966, 80.21487835914859, 76.62599594362321, 71.45769273081135, 68.98798804129325, 71.09616787202897, 73.32008900180941, 71.96838532724689, 72.56289112952449, 69.27881610008978, 73.64040543956142, 74.73112244759837, 75.68576458961734, 80.8773902154738, 74.76643946862991, 73.34157574561335, 70.10529087435815, 69.7707126986596, 68.57683735509073, 67.01095657963907, 64.60550031354352, 67.02896025873, 66.53385516135924, 68.83929883280109, 67.32873132151943, 66.18946321548955, 67.71677924740699, 66.13971187222388, 66.97275269416072, 67.30541675321518, 68.68996635560067, 67.42007547809233, 70.36721890972507, 71.34600716252481, 75.2846630157963, 77.78063189598822, 76.98967026126, 73.68398297217585, 78.9455601476854, 76.36424049254387, 77.75616415085332, 72.63255242378482, 77.64389022704094, 76.36933172902754, 76.65265237131428, 76.86858669404062, 77.9811591486777, 78.06260324293568, 76.61513882298624, 80.98631443515902, 74.9466331543461, 8.721705828943561, 5.466108187552422, 5.766295021580112, 0.25283964320776925, 0.5569081068519623, 0.15781425029760407, 0.8360271552397359, 2.271879214432932, 0.6191814943186699, 0.21789855684243867, 0.3216965911128829, 0.3706340425677838, 4.2350801537113805, 31.3912776208693, 48.40568004115936, 36.98338900842975, 47.3390503083506, 63.181323005307114, 57.73020513596074, 60.267707993907315, 62.58391072673183, 68.54876887413764, 54.70672845840455, 0.9775004283555093, 0.194391455321062, 0.12361613132299916, 0.16913379692742903, 0.16877131476517648, 0.14971775813929497, 0.11948800525597988, 0.057364035578024004, 0.14279995353952532, 0.34653827908539003, 0.1092658948994452, 0.11762143968934975, 0.08966705221081935, 0.17625913474588625, 0.1999376714229584], [0.059455168328338096, 0.03376156377095369, 0.0618565705184254, 0.045609190128743655, 0.03176250712825887, 0.11709925883840169, 0.018316926697509426, 0.047855758288454626, 0.06702177662162051, 0.0818606162624013, 0.04601897822032052, 0.027193738778512326, 0.05698742675444773, 0.01575099946480365, 0.1609354303969491, 0.06826680739440265, 0.1675365342488212, 21.562690696408673, 59.03625242171749, 45.313357922338675, 36.71127457772532, 42.97082431854741, 40.66619257773123, 27.034065646509973, 23.82842233104091, 22.215324063454908, 3.8731495747643137, 0.06829142946028902, 0.2061592859606589, 0.07990168347474068, 0.15769319308380927, 0.14642174145387066, 2.650703932008436, 1.7981275002802573, 1.2140694212528969, 0.21144492491599054, 54.85129133347542, 102.20511328789496, 88.19717622572377, 98.85385590214884, 91.55422302984422, 92.67951180857997, 91.52289113690777, 93.710797063766, 90.31878625192951, 89.59404207045033, 90.06512657288583, 92.58584560886507, 86.06777637235581, 85.00414725272887, 86.13018128179735, 86.03788791164276, 80.77358861123362, 75.84699753792056, 69.92186515561997, 75.31504569515106, 77.75682310904227, 71.25032486454134, 74.5096811171501, 76.68649458116101, 72.77509135584678, 75.04346862916024, 71.97309217145367, 69.45654653733777, 66.59523240981564, 67.32596212817778, 67.18629437108194, 65.10098195845082, 65.17560505097913, 64.26570930788594, 65.3437884392277, 69.67308490507065, 68.54825112127489, 70.23989092919135, 67.25875623764531, 70.61049215255245, 70.06882067649596, 68.28906090028825, 61.04763600134081, 62.14799419526131, 67.82080834911716, 67.78212593447778, 65.5374554664858, 74.55988745535575, 73.63422378416985, 74.17265538246401, 74.49313655976327, 76.0315921229701, 74.23171058777841, 76.84969655929073, 71.41487613801034, 72.32292836712253, 67.6588144610005, 64.37829702131211, 61.78246459653301, 64.34376447431504, 57.870449481471894, 60.294701745433194, 62.48319602781727, 63.43042489021056, 61.50976573267291, 60.865555655571725, 61.397060348141586, 58.789790291940015, 57.64698028564454, 61.16509922089116, 59.18156839186146, 58.7750147235009, 60.05151871711978, 59.803107169366655, 64.20839955729824, 65.3882485051309, 64.22868997819963, 64.34628263596566, 62.95538271627119, 64.45460673301451, 59.81791019439698, 59.362640688496256, 60.3024798054849, 62.05780713788925, 60.85851892348259, 64.13074055025655, 68.88067983811902, 68.90411207752844, 71.44816137129261, 70.79418459246236, 68.76903349353422, 70.54333333046206, 69.1246198838757, 70.75097576264413, 70.74964215678554, 67.49468680351012, 68.11403689845916, 71.82146118533227, 68.16996989711639, 71.2646964288527, 65.98928113137522, 70.96026559029856, 22.058282167680805, 0.21174878603027714, 0.24619214507120274, 0.044992129288373456, 0.06784934310182449, 0.027355850644169316, 0.3725280877082579, 0.042604819285653295, 0.04103636534343805, 0.07751637679194251, 0.08462527436354468, 0.07535754102132014, 0.12303772727928816, 3.528781408263791, 27.979286255375033, 31.445441630578813, 24.288669324690296, 27.62995800664348, 42.46636829068584, 48.216402146124075, 51.68267911480319, 46.863266806448664, 33.458052912066066, 0.05876303087138842, 0.14251555105851543, 0.043683919244475906, 0.024835902093459043, 0.02707843488502887, 0.07213118471085064, 0.04011935809807431, 0.06142072394610413, 0.010413360376391682, 0.022226302103409847, 0.046101616124712655, 0.0436233714853804, 0.07147033428472858, 0.06280299937052113, 0.06019419802713299, 0.0326965521690586, 0.014486628802373044, 0.050376777447039084, 0.05196748241301506, 0.07040683570648394, 0.12281242848163652, 0.04542173224411184, 0.010824252592189419, 0.07705685427232135, 0.03431293640225645, 0.021160225639300003, 0.045695317563630884, 0.02113468426790449, 0.059608692348363905, 0.07040924888344542, 0.05199221556165046, 0.015728992631568784, 30.07589117173226, 72.53228879744007, 58.32138476833221, 55.66492426779963, 46.575498196386526, 33.807006574446156, 31.02572644910505, 25.407556795304824, 23.801530561139508, 3.307972069709532, 0.053102464655474316, 0.10876519515389398, 0.015093853073795477, 0.1361705503997303, 0.05930612975310895, 0.8334599026749212, 1.3569073114664325, 0.22209754604245388, 0.6676671377593472, 68.21106064704158, 101.41336717913228, 93.51074834023753, 99.93028763801821, 95.37712189459032, 96.17060169096916, 95.38026763546853, 96.15790890109156, 94.5663679799726, 93.05691442181988, 94.05256886636057, 92.54888119236116, 88.62047841472011, 88.68053774679862, 87.63597919094948, 89.1025298641574, 85.12011604924356, 79.8658815506966, 74.39939191264492, 79.36962327649518, 79.88452849849578, 76.46688107521304, 78.58571406333678, 78.93951185287969, 78.64564003482943, 77.91703624110069, 75.34629914068407, 74.42874693101453, 70.81965646436139, 73.20719534350981, 71.64170680507537, 69.95101621074062, 69.43295740312146, 70.55946996135097, 68.40412755166331, 71.43877906184044, 69.60923656340569, 72.25629514263522, 70.03675137796711, 72.63728280221262, 69.87677358811902, 68.80341699046474, 63.76245352529711, 65.93359916440903, 70.56351000262846, 70.7666495538527, 72.07159073122087, 77.31436406412433, 78.09509615744315, 76.35194778442383, 77.0622262647075, 79.04307027016917, 77.46101364012688, 80.35153373595207, 74.9519048198577, 78.0352407886136, 73.56800633092081, 67.95326678983628, 65.20147700463572, 65.03918893875615, 61.085800663117446, 61.571601898439475, 64.37735173010057, 64.92911546461045, 64.53673724205264, 62.62493087399391, 61.759495196803925, 62.93635529856529, 62.26949745608915, 63.620393122396166, 62.8836896342616, 62.910871659555745, 62.62799424509849, 63.55509350376745, 67.36688813855572, 68.38307226857832, 69.05969681278353, 68.11402905371882, 66.54333160769555, 67.2624981787897, 64.10331533801171, 65.21545633192986, 63.288756724326845, 64.90127448112734, 63.123664163774066, 67.87611376854682, 72.72621862349972, 69.58495709203905, 73.72071204646942, 73.43583814559445, 70.39915484766807, 72.64669649062618, 70.26624141200897, 71.8625440905171, 72.17505501162621, 71.39684107995802, 71.37948851431571, 74.62128823803317, 72.80854132867628, 75.31633223256758, 71.88808656507923, 77.97183959714829, 32.98095149378623, 0.3428893716585252, 0.30696634443536885, 0.14047931999929492, 0.08755317047959374, 0.2301995387120593, 0.5301201571860622, 0.03158331341711024, 0.06051927211604292, 0.07590661921928968, 0.23367262896030183, 0.22863650484190834, 0.06865791060150632, 2.224394020534331, 35.20405284820065, 36.074050241901034, 24.4352835993613, 19.964264054452222, 35.899634207448656, 59.798416014640566, 59.830163678815296, 56.93461902679936, 38.76862833576818, 0.060655880914700616, 0.051632341928780086, 0.13952144962405005, 0.09496655735758044, 0.06116741314350117, 0.08521221262673218, 0.09646232870797958, 0.07427495919288167, 0.013186893606137846, 0.04999920718311783, 0.01727263968918593, 0.05793665565790669, 0.03185439554433669, 0.027161660761902892, 0.030384416459128264, 0.09999730353874546, 0.20239978608104492, 0.14975011769321658, 0.17534465559067267, 0.13896609716598066, 0.19357166463328948, 0.11389435298981206, 0.1252350359854679, 0.172988613466582, 0.1706210340583517, 0.11781610263090943, 0.10608707434467732, 0.20314807012196512, 0.1085718039182886, 0.3982298779151132, 0.15123542428257006, 0.13604062188777233, 35.7208368855138, 86.70508307795372, 66.8851504787322, 56.97332497565978, 66.68682759807956, 61.23191287440639, 47.21844527029222, 42.80696338222873, 35.406972746695246, 6.635183855410546, 0.11922363597418993, 0.5835815110514241, 0.26621337799775985, 0.6040599605729503, 0.2183124588261689, 5.801463482841369, 9.4280364436488, 2.1038983185445113, 1.4811020536768822, 69.46307336130451, 107.78910144682854, 98.01875975824173, 106.30238194619457, 100.84212103197652, 98.6059150388164, 99.36221861070203, 101.9570625981977, 98.9413090675108, 97.41277710083993, 94.85849826566636, 99.40418797154581, 93.04233889425956, 92.94208311265515, 91.31168719260924, 93.88207127971035, 90.72810126889138, 81.85781801900556, 76.24336873331379, 82.66127632510278, 84.48549224484353, 79.02127758149179, 81.44645552481376, 83.10317839345625, 82.37131118774414, 81.10903755311044, 77.991318087424, 77.27617586812666, 75.73801056031259, 76.10206927022627, 74.53000683938303, 72.88665140828779, 73.824796061362, 70.94988699882262, 73.74598779985982, 77.88978361314344, 73.79564500624134, 78.85562019963419, 75.19325610130065, 78.69139840525966, 75.40429530605194, 74.49274432274603, 67.95951904789095, 68.92042129270493, 75.27066015428113, 75.15722520889776, 70.99290755487257, 79.02141878681799, 77.93245900061824, 78.21392828418364, 80.73264691137499, 82.58270340581095, 80.53928190662016, 84.5192167835851, 77.18324707400414, 77.8253233817316, 74.48089876482564, 71.6987459121212, 69.25369724150627, 71.64329928736534, 66.39838434034779, 68.28447957192698, 70.1221570660991, 69.49522895197715, 70.51608070250481, 67.3761292426817, 63.874821585993615, 66.4938626750823, 64.6162829091472, 68.12313679725894, 64.73592696651336, 64.22401059058406, 65.61999390202185, 66.34047446712371, 71.21689058119252, 72.16592373386507, 69.88013113698652, 71.38188116012081, 69.04887891584828, 71.1450013806743, 65.0904856958697, 67.10315581290953, 68.21649705210041, 68.51439322194746, 66.38695455366566, 71.31425949835008, 73.92117654123615, 73.58422925395351, 77.75512080038749, 75.08328068640925, 73.24632490834883, 76.64436832551034, 71.93412734616187, 75.83039022261097, 75.80280811555924, 75.29629676572739, 75.63839804741644, 79.42529739872103, 74.44289884259625, 79.39542462748867, 75.1896632102228, 86.47822887666764, 37.06016548218266, 0.6500044597252723, 2.381011074589145, 0.4548607520278423, 0.29719982656740374, 0.555809720629646, 1.7698480693563339, 0.18755235859463293, 0.1871646261743961, 0.18307098938572794, 0.40888426104380243, 0.3225946913082754, 0.43873962675852163, 5.157868727560967, 45.696702926389634, 49.53481274266397, 44.2791622684848, 40.44188007231682, 65.12509276790004, 66.18415232627623, 71.3330868751772, 67.16389763739802, 50.22856627741168, 0.21990757645858874, 0.23210098426188194, 0.2117780352672262, 0.18091259794610162, 0.2285785426295573, 0.26317332660959614, 0.1820311322808266, 0.2026092498413017, 0.2520811855192146, 0.09516401652006373, 0.2815917350592152, 0.16472148288401867, 0.17800776107657343, 0.13084892063371598, 0.2822287524900129], [0.13774843105385381, 0.05819524863674756, 0.014668816002085807, 0.005545918764020767, 0.03297578355657958, 0.04692678091927402, 0.010514555803139605, 0.023075569939288883, 0.1227883886425726, 0.025021837378341346, 0.02142163590648242, 0.01615248890894075, 0.05094937454428404, 0.12023492566039486, 0.058553777785310825, 0.18154141823610953, 1.7444825917482378, 48.20059499432964, 53.986196902490434, 45.38002252578736, 41.78872000786566, 26.689783527005105, 23.567078728829664, 28.227954718374438, 27.82986552484574, 8.35543196047506, 0.2968465374602426, 0.04087082140388028, 0.10471917839059908, 0.09099760903946816, 0.09477988471307101, 0.11657651108238967, 0.046596780885010965, 1.0250234363540527, 1.075232838911395, 3.4107781273703424, 83.9259582950223, 84.38448336816604, 92.6390015694403, 91.34600793161701, 86.46851708812099, 89.67709433647894, 91.13091299610754, 89.89391511486423, 87.60617702238022, 93.6592649644421, 94.27494372090986, 86.68678914347004, 90.80613290109943, 85.940150291689, 84.65824911671301, 84.19166749523532, 77.01629530998969, 76.96325702051963, 72.58168712739023, 80.16733923266011, 75.86122005216538, 75.90959856587072, 79.45276183466758, 80.13192807474445, 78.7398475216281, 75.03246245845672, 72.50195318652739, 69.88595977906259, 70.20357762613605, 72.98422428869432, 68.83594128393358, 66.81525384226154, 67.92673587799072, 67.1228539559149, 67.42725341550766, 64.80212480791154, 66.01742805973177, 61.345273294756495, 64.18109986089891, 62.517850168289684, 64.15469838726905, 63.55641534251552, 60.72857864441411, 61.866352327408336, 60.44298302742743, 64.61506697439378, 74.20287332227154, 77.44358262708111, 75.75510424952354, 74.9011101261262, 74.3613370772331, 72.11352086836293, 73.52586438578945, 73.47107671922254, 73.2528595770559, 75.99128584707938, 73.32213647903936, 71.48663982268303, 63.79515432542371, 58.17446847115794, 58.121787117373565, 56.50064406856414, 57.036090743157175, 59.14268593634329, 58.72256871192687, 57.464535159449426, 58.93163496448148, 59.77718030252765, 60.71579171765236, 61.336110638033965, 61.96165023311492, 65.03117161412393, 63.23853861901068, 60.27918092666134, 62.85039655623898, 62.10995112696002, 67.55392243785244, 66.01083847784227, 64.01289686079949, 64.5776318734692, 65.33211546559488, 62.39029861265614, 60.66920964948593, 60.64625986160771, 60.14401212815316, 61.2990128609442, 66.67706874109084, 68.70318474308138, 69.84452386056223, 70.66500525320731, 67.92518261940249, 66.94240923850768, 69.16028991822274, 68.64183102884601, 69.4818615144299, 69.85445530183854, 65.45872957475724, 67.22528273059477, 69.93420493218207, 71.57920775874969, 70.38923125113212, 70.58956238531297, 53.88832984432098, 4.057171493768692, 0.030875586070901448, 0.1255457689084353, 0.06775847741312559, 0.026680668628203775, 0.11445502209807597, 0.07846139221181793, 0.06399636517368978, 0.050197022576485915, 0.12318064864244192, 0.2039267065664453, 0.0415250068650611, 0.44862516404640296, 6.214182136520264, 46.442361185627604, 26.24802658634801, 36.11529004189276, 38.460471245550345, 44.582224199848795, 41.032271308283654, 53.67788291746571, 32.83522367477417, 0.040439797355042356, 0.04008912443814259, 0.07551840416366055, 0.060803628631777344, 0.008697172123638373, 0.06617710339806734, 0.052398345583388885, 0.04639645272325124, 0.047862610944937316, 0.040432052206127875, 0.04697365783936074, 0.0936405434303226, 0.04376209468670911, 0.025219235253790696, 0.034390433856676665, 0.06510598990585535, 0.04699507765772362, 0.027612534148858923, 0.05565284413375682, 0.056447239006839456, 0.0131741602672264, 0.022906699262919928, 0.15970755999367084, 0.07922798575412843, 0.027099837466413458, 0.04820663804909395, 0.017050378430154056, 0.010558500521696143, 0.0790219847112894, 0.04435415807811003, 0.2019726460979831, 2.3739407572054096, 62.50628702102169, 68.9053358570222, 66.81179431176955, 53.24878738772485, 24.394789049702307, 20.337255962433357, 33.178725242614746, 28.68001768665929, 6.681404575224846, 0.4844841463190894, 0.21833824534570018, 0.19172335494189494, 0.19906457633741442, 0.09143869948363112, 0.08225497534318317, 0.06185718338876482, 1.0066520963465015, 1.6576887522974324, 5.894655566061697, 93.04906183673491, 85.64296014847295, 97.94414058808358, 92.03916918846869, 89.43873974584764, 92.45774099903723, 96.35483541796285, 92.12713226195305, 93.13037257040702, 95.11671573885026, 96.42461438332835, 89.77575763579338, 92.56851657744377, 89.97290380539434, 89.2109049520185, 87.52670195794876, 79.27282702538275, 80.45579033513224, 79.67674486098751, 81.60518600094704, 78.64585184281873, 81.33429927210655, 82.9079463404994, 83.0612325668335, 82.7226927972609, 78.37789120212679, 74.90813116873466, 74.52155805403187, 78.15615177154541, 77.50845078499087, 74.37308065352902, 71.34847825573337, 73.1144077547135, 71.61425021386916, 71.46985992308586, 68.5451602935791, 67.24529466321393, 65.10744210212462, 66.0394404011388, 67.14268545950613, 66.29762649536133, 65.52074224718156, 64.31361321480044, 64.9349441066865, 63.92369824071085, 67.94553187585646, 76.24023868191627, 79.31198796918316, 77.19578296907487, 76.90968528870614, 76.88629227299845, 74.42103555125576, 75.9667004308393, 75.95994610940257, 73.58517062279486, 76.26184309682539, 75.38239279100972, 76.05707183960946, 69.3751024430798, 62.04036435773296, 61.50851841895812, 60.42738376125213, 59.008309456609915, 62.91927729883502, 63.14142857828448, 60.97059672878635, 62.58314586454823, 62.22313504065237, 65.42455396344586, 65.02020858949231, 66.4445427925356, 67.90096590595861, 67.5444067678144, 63.84885157308271, 65.00831596312985, 66.08386516571045, 69.91431067066809, 70.64202016399753, 66.82616587608092, 68.27559932585686, 69.09382143328267, 68.46847795671033, 64.85365298486525, 63.721162734493134, 62.45292317482733, 62.35804496272918, 69.1539199890629, 70.67820010646697, 72.68099369541292, 73.04395414167836, 71.3175464445545, 69.5714484491656, 71.75979368148312, 70.77582005531558, 71.57235930042883, 71.79702481915875, 69.09583753155124, 68.57377790635633, 73.14515913686445, 74.30651018696447, 77.27138273177609, 75.00573542810257, 64.83699075637325, 7.424190188607863, 0.11453569115650271, 0.049194228805361256, 0.238961408876123, 0.02981190171633517, 0.010772993649175812, 0.0874618144946233, 0.031181745448960897, 0.12325636877287781, 0.12053335521129832, 0.324531759946577, 0.16183322415717188, 0.45829101796111754, 6.565889302761325, 53.679028249556026, 30.218153576697077, 32.38502579350626, 22.403676279129524, 50.489490186014486, 53.09802716778171, 62.44546282675959, 43.573975024684785, 0.23541353312471222, 0.02976382969908657, 0.03912547009906942, 0.06322320242742858, 0.07415475233668282, 0.07400685140202123, 0.11036104056984188, 0.030753785751820095, 0.06611598490346825, 0.020738379323794957, 0.12079357995741791, 0.019652966800476276, 0.032587587653148564, 0.038430804551969615, 0.025052214679758877, 0.25422411730452893, 0.12084041857310843, 0.1910383804070373, 0.15625231959406408, 0.15128810048824357, 0.12581269692389235, 0.14292338562588539, 0.3734356873939115, 0.2705337155249811, 0.17784361907791707, 0.14345794645768983, 0.18775590815611426, 0.09514324021555724, 0.23247492709948173, 0.2535970283732299, 0.24679334023066107, 2.9285303142762955, 72.9789290889617, 81.36887888754569, 68.73258682989305, 62.312627838503936, 45.81986534980036, 36.85338204906833, 51.99902611394083, 43.26500208147111, 13.452337249632805, 1.706947102662056, 0.3998089996316741, 0.44436427494210584, 0.40871495561253646, 0.22620403778649148, 0.4443252657450015, 0.2603787297923719, 5.635109389981916, 4.596304460879296, 5.778235206680914, 97.37664422681256, 91.44500071002592, 102.5459437216482, 98.92616871864566, 92.00091823454827, 96.11686521960844, 102.05493357873733, 96.57055793269988, 96.50999653723933, 98.68274642575173, 102.35443007561469, 93.40078077008648, 96.53365627411874, 93.16245755841656, 93.85872533244472, 92.23912377511301, 83.5125953920426, 84.41315589412567, 82.84601996021887, 85.78821336069416, 84.81597546608218, 81.48060367953393, 86.56906312511813, 85.98181370765933, 87.53026347006522, 81.46746373945668, 78.66966062976469, 77.14322320876583, 80.09586580338018, 78.85582416288315, 77.5767235602102, 74.06337030472295, 73.94778590048514, 74.7301967682377, 74.62311606253348, 71.59391664689588, 73.10898703913536, 68.38526879587482, 72.31782928589853, 71.28461422458773, 72.11759228860178, 71.66543714461788, 67.54564623678884, 68.08798451577464, 67.87736108226161, 69.64969188936296, 79.86684645375898, 84.49740840542702, 81.9045412924982, 80.24593568617298, 79.06839309200164, 77.45128616209954, 80.75509071350098, 78.6280756611978, 77.782334204643, 81.59119098417221, 79.0081690203759, 78.72513078874158, 68.33418384675058, 63.67804019681869, 64.79915165132093, 62.53049588972523, 61.016880696819676, 67.59238519976216, 66.18654497208135, 61.90148891941194, 65.4691905360068, 65.85343376282724, 68.40547684700259, 68.12271318128033, 70.03266426824754, 70.92002207233061, 69.52525077327606, 65.14773661090483, 68.74770364453717, 67.8674296409853, 74.48402881622314, 72.97059012997535, 68.11930071923041, 71.68448417417466, 74.42277708361226, 69.33282713736259, 67.3414162666567, 67.92126809397053, 65.31785372764834, 65.60096256194576, 74.16663846661969, 72.5192351495066, 76.20037171148485, 77.15124837813839, 73.70384585472846, 73.64134680840277, 76.21161322439872, 73.96416571832472, 74.77690435224964, 74.04261312177105, 72.74731313028644, 73.31583715254261, 75.43796493161109, 78.02487788661834, 80.63382671725365, 77.38504517462947, 69.64667950907062, 8.420710986660373, 0.24558276809271307, 0.34530659356424886, 0.6104810644061335, 0.5948860270361747, 0.3176655590293869, 0.3481801893682249, 0.18499736343660664, 0.2632631427578388, 0.3045038620550787, 0.8830709599198834, 0.45569119133776237, 1.0600552275296182, 11.283468546405917, 64.41984668854745, 43.9389084231469, 54.74999220140519, 56.957509979125, 62.53197462328019, 59.71589326858521, 72.8614148785991, 49.8475472388729, 0.32339840947139653, 0.16654160053979966, 0.12151073784597459, 0.19444698137381386, 0.18296140816903886, 0.1939451324963762, 0.14913444347198934, 0.2058277537505473, 0.14007340065173565, 0.16644455252155183, 0.28888832417226606, 0.20861531788062668, 0.08292649737409047, 0.11531504772363171, 0.12128176948716565], [0.06588949100865472, 0.03784719877125275, 0.03517864256977074, 0.05620958704140879, 0.010007689049797914, 0.005561384642797132, 0.05171288458269931, 0.014513076072739018, 0.08479762882474931, 0.044064917751858314, 0.019768393268027616, 0.04992196636815226, 0.0724626709556868, 0.06265973709824105, 0.08826999128946374, 0.17773227585900217, 6.369922295693429, 52.797302969040416, 46.45776041092412, 41.80315433009979, 38.059267690104825, 34.81711887544201, 44.734565134971376, 31.249307432482322, 9.460163597137699, 0.6076666412334288, 0.038557055841891036, 0.9089362332897802, 0.04560148328422539, 0.061758936442915476, 0.10592077197807451, 0.09527921316123779, 0.3268184711135203, 0.7392903525502451, 0.674485749294681, 20.48730819456039, 87.97425223935036, 80.83832340855753, 94.82007472745835, 82.27977875740298, 93.0066139467301, 87.07282881582938, 90.49986639330464, 84.13002352560721, 91.27714680087183, 90.58985340979793, 88.28342130107265, 87.12396867813604, 86.95409867071336, 84.49174450289819, 84.79389252201204, 78.80919502627465, 70.34793653795796, 77.38985400046073, 79.75148954699117, 79.26944594229423, 77.4503840169599, 82.91390834316131, 79.67353636218657, 80.97895606871575, 76.18490972826558, 75.62212021120133, 72.9237413406372, 76.390716491207, 77.43962103320708, 74.75015378767445, 72.6800052581295, 74.8789644241333, 71.68313487883538, 71.770125204517, 68.41290581610896, 64.99080650268063, 64.19627943346578, 63.343489477711344, 65.8753284331291, 63.462011737208215, 63.3907618830281, 63.16020104192919, 61.33569878916587, 57.29663418185327, 60.57570034457792, 71.47328022987612, 71.02123491225704, 72.9350220772528, 74.03164617476925, 71.80779564765193, 71.37483658329134, 73.79671973566856, 71.57739562373008, 71.0298562818958, 70.77372550964355, 69.75119498468214, 69.43036863880774, 71.59396371533795, 72.80082994891752, 68.63612790261546, 58.10300288661834, 54.544805172950994, 56.08747336172289, 57.78364742955854, 58.47618895192301, 58.192189739596465, 60.653010260674264, 59.88632025257234, 63.376045150141564, 61.314502300754675, 62.69644352697558, 62.37498175713324, 65.88924500250047, 67.78520891743322, 64.84263112468105, 62.79729550884616, 67.77469696537142, 65.4053931851541, 65.58069175289523, 66.059248370509, 64.90559693305724, 65.93734110555341, 66.84469515277495, 60.80847732482418, 59.542195027874364, 60.297494472995886, 59.085913550469186, 65.23403659943612, 70.86696024863951, 67.68947170626733, 69.21983149743849, 68.9096426194714, 69.5330092214769, 70.02977740380072, 67.73701867749615, 68.99515813396823, 70.1541086935228, 67.67576694488525, 68.6220387489565, 70.2018988517023, 71.37704095532818, 70.41036498162055, 61.556053623076416, 17.77599923072323, 0.14919357013798532, 0.07138237973014194, 0.07868913482994803, 0.125411412408275, 0.20891206969897594, 0.03883500403213886, 0.06415050206405502, 0.06236029248083792, 0.09250641154545931, 0.1273629830909833, 0.23478702642023566, 0.06745930475693557, 0.33750625567570813, 30.92360950285389, 44.59532099385416, 20.47040277911771, 40.22731857915079, 35.425301982510476, 37.47142599474999, 46.23076500431184, 48.14370885972054, 0.6961070181381318, 0.055980526752048926, 0.024971717991115108, 0.08640028476234406, 0.022048180915355202, 0.0387224197507866, 0.02359471708205679, 0.07237117707488999, 0.03938992365053104, 0.035136159163929766, 0.04855445728847577, 0.06152226890046751, 0.0346466213194353, 0.049293824065957344, 0.07079676679906345, 0.06488257568449744, 0.0566053863674883, 0.030992100383305264, 0.10837689582859317, 0.07585536027627607, 0.09352331665614921, 0.02325922036693702, 0.08171790940386635, 0.07816876960738052, 0.0902482601363332, 0.05178686186310746, 0.03025816516920684, 0.0711614476336587, 0.1057493138397413, 0.028408060916849685, 0.13472854309985716, 10.432278917681787, 67.33536797185099, 62.22381361069218, 61.75788310266311, 32.836902449207926, 25.671185178141442, 42.919715835202126, 36.44188619429065, 7.847479139604877, 0.41689895033355684, 0.034081945571327404, 1.7286499445476842, 0.34063943271194735, 0.3657307427737021, 0.03620754078691525, 0.06068832090785427, 0.0770343312873475, 0.9354452656642084, 0.9580750126511821, 27.395013916877012, 97.22395420074464, 85.44043248699558, 98.88729018549766, 86.4945302471038, 97.09018568838798, 92.84330214223554, 95.92698327956661, 86.64791061032204, 94.49925622632428, 93.31016617436563, 91.4799411835209, 89.58884100760184, 90.49177846600934, 87.74849630171254, 86.9262106187882, 81.50326713438957, 74.57591425987982, 81.92405900647564, 85.52808177086615, 82.69468707423057, 81.80919631834954, 85.51640879723334, 82.99955721824401, 84.04561411949896, 80.43893983287197, 80.30266100360502, 76.95067405700684, 81.81997499158307, 81.5027101578251, 79.20996712100121, 78.18388292866369, 77.2553716167327, 74.76149728221279, 75.22229733005648, 73.1332508210213, 71.34550509914276, 67.18581584192091, 67.77577953953897, 68.12651788034748, 67.04246105686312, 66.81770140124907, 66.04955227144303, 65.11697738401352, 62.5829654355203, 66.31431225807437, 73.63211354901715, 77.33949076744818, 76.91705934463009, 77.8497205242034, 75.45062634252733, 75.88713122952369, 75.86351071634601, 75.14397544245567, 75.3870290325534, 75.14617196975216, 75.14365380810153, 72.8458744479764, 73.8795837279289, 73.62626921746039, 69.01191449934437, 62.43087160971857, 58.1145424996653, 59.775917299332164, 60.17990573760002, 61.61643458950905, 60.59365695522678, 63.228854287055235, 62.528809270551136, 65.65240052438551, 64.67033317012172, 65.39338681005663, 66.44513114806145, 68.10528216823455, 70.01803382750481, 68.0494668406825, 66.08382594200873, 70.29823226313438, 68.06605062177105, 67.5058812479819, 68.09568020605272, 68.50748985044419, 67.66708281732375, 71.4778458687567, 65.60383373691191, 64.2620889602169, 64.2236497325282, 62.19189336222988, 68.13871645158338, 73.96961781286424, 71.30414762804585, 71.80784271609399, 71.0308604086599, 71.29605970075055, 71.41766886557303, 70.97530395753923, 71.80766228706607, 73.95846259209418, 71.31332597424908, 70.82357883453369, 72.9912139523414, 75.36874294281006, 73.50128681428971, 65.58976419510381, 26.279652657047397, 0.39535239038448183, 0.12190118987834263, 0.18065212805184627, 0.02754817701755993, 0.3163051400934497, 0.07955826158004423, 0.10071372598289483, 0.049410652474410115, 0.19944106258692282, 0.31139681476258463, 0.0712009854314308, 0.11254003211375206, 0.2982285294321276, 35.169806634226155, 49.418141841888435, 23.10511765941497, 24.320707244257775, 34.20968101870629, 56.69759804202665, 50.33610982279624, 60.90049220669655, 1.0627805393549705, 0.043667302797398264, 0.06265301084626587, 0.06417140860350863, 0.0397638435054931, 0.029400464620501287, 0.02840310432797959, 0.025915522992070165, 0.047463138227260886, 0.04208045891456066, 0.03188976773902053, 0.05820865517542247, 0.04759324676988106, 0.03474881361809469, 0.12310282943109352, 0.12161739260679293, 0.17998278171064394, 0.13991978470115893, 0.1883796722658219, 0.11435697050464731, 0.18630490698401006, 0.11420248121383691, 0.10756203108617376, 0.2759836956618294, 0.1772388386269731, 0.11170537165936925, 0.12041651148108706, 0.14317715991168253, 0.2011010678665292, 0.17180427217916136, 0.23485847178005406, 12.104111736820592, 83.18277897373324, 63.445784891805346, 58.852116753978116, 56.85356716955862, 49.5161069593122, 67.0910749127788, 50.300973230792636, 13.772338917178493, 1.436990343274609, 0.32530480394920996, 3.780077368982377, 1.0117594513200945, 0.7988957315683366, 0.34261578633900613, 0.2886830432520759, 0.8344674002259009, 5.019182053304488, 0.8187660911390859, 30.066765777526367, 102.30235668920703, 90.55132788996544, 103.30296116490518, 88.53912061260593, 102.5218839030112, 96.6497427417386, 101.1214408566875, 92.34630646244173, 97.6665230720274, 96.2573488297001, 96.38240183553388, 92.34445510372039, 93.99281547915552, 90.95196662410613, 90.44646724577873, 88.08319999325661, 78.63680685720136, 84.47767888346027, 87.18349456787111, 87.67289653901132, 82.59145813603556, 90.2448574189217, 86.11482912494291, 88.05685735517933, 85.67950879373859, 83.61937799761373, 79.22597823604461, 84.69753557635893, 84.71253471989786, 81.09613295524352, 81.73745616789788, 80.77871907141902, 79.28125227651289, 79.81400428279754, 75.8122374934535, 73.76736471729895, 71.97794022098665, 71.04134098176034, 73.97695264508648, 69.8809705242034, 71.20239350103563, 70.84612461828416, 70.50298783086961, 65.7923859934653, 68.76286752762334, 78.80429990829961, 79.14054901369157, 80.71473736916819, 82.38244287429318, 79.55320589004025, 77.71232774180751, 79.37501261311193, 78.0817130304152, 76.50670097720239, 76.37119093248921, 77.61367228723343, 76.23455124516641, 76.53210224643831, 77.43492987848099, 73.80787495643862, 66.20497226715088, 61.08795404434205, 63.38610995200373, 63.46258832562355, 65.40389091737809, 64.08131868608537, 67.50338662055232, 64.78119504067206, 69.33533745427286, 67.93725567479288, 68.29356378124606, 69.30667277305358, 70.70352292829945, 73.77411903873568, 70.19865897393996, 69.62588310241699, 73.2748483842419, 70.71077146837789, 71.01632410480131, 72.56304017959103, 70.30621036406487, 70.55833247400099, 75.69732773688533, 69.50061044385357, 67.17320149944675, 66.88877474877143, 65.43944720299014, 72.69885616917765, 76.46792442567887, 74.4436284034483, 74.14978011961907, 75.6294942671253, 73.65880135566958, 74.06144049859817, 74.48558207481139, 76.98090768629505, 76.73307664932744, 74.59311777545561, 74.72045360072967, 77.5403553439725, 80.35630333808162, 77.34784541591522, 72.48827195936634, 28.75421912439408, 0.7858249232653649, 0.3265677458576618, 0.5183930058152445, 0.4589988219161188, 0.48272906952807987, 0.20816370904926332, 0.09401899852579641, 0.17812075904540478, 0.35870038453609715, 0.3346472461858104, 0.5295673481399014, 0.1615239084968644, 0.596118693149859, 48.880357434672696, 59.68350233570222, 33.96454857241723, 55.685018570192405, 55.98633504682972, 57.23311139691261, 62.061145074905895, 69.48925125983455, 1.7517562595105942, 0.18327282291025887, 0.17100352643718644, 0.19185567364817668, 0.15192133344469533, 0.1460151939142135, 0.0863521131536653, 0.14415900883895738, 0.1470060213919609, 0.19098300757187028, 0.1966405515709231, 0.11745964191974172, 0.12043263763189317, 0.22560264344417283, 0.23494793552785154], [0.026155069109893618, 0.06591739193085702, 0.027508179567033247, 0.05618753520050838, 0.05690805238461303, 0.04158786054880869, 0.1010918363388027, 0.043815414406239026, 0.020412998799715313, 0.09162871993236965, 0.04573986940686742, 0.02564771780593982, 0.0056178161157144895, 0.034097248177614906, 0.06288876291364431, 0.1131992660943539, 24.497021705873554, 60.78925378860966, 46.723924606077134, 38.37249640495547, 42.564968832077525, 37.91359086190501, 36.270780640263716, 23.277870608914284, 1.4529605185793293, 0.10098731896329312, 0.016431320015521302, 0.2392414140124475, 0.40579815244963097, 0.3175021677968964, 0.1197941416514016, 0.07856445402027139, 0.2325271130088837, 0.4182430975619824, 0.6900547396752142, 43.54768729978993, 89.37507183321061, 82.1089203126969, 90.07244571562737, 81.00616947297128, 86.97316138975083, 84.40263609732352, 88.66502085039693, 87.30751206797939, 89.8200725740002, 84.14022953279557, 87.43231404212214, 81.42714961882561, 89.33635019486951, 83.63549893902194, 78.68148265346404, 76.64377212524414, 76.2482952302502, 77.64498064594885, 81.85198153218916, 76.91060312332647, 81.75135704778856, 79.31246649834418, 82.85297040016421, 78.73055150431972, 79.36792881258073, 74.7096670827558, 79.59285320774202, 80.89552725515058, 78.60856579196069, 76.85049672280589, 76.77874088287354, 75.94000477944651, 73.66331992610809, 70.05809691644484, 70.54818137999504, 68.95336920215239, 64.14400208380916, 63.98445575468002, 65.2822268393732, 63.482262934407885, 63.69987995393815, 60.28520568724602, 59.61860672120125, 60.194269457171046, 63.42087391884097, 72.7935500298777, 78.04700789913055, 76.52586567786433, 74.76807901936193, 73.30738836719145, 75.24743972286102, 71.55441837926065, 71.33971568076842, 72.54492667413527, 68.65616336945565, 74.82229401988369, 72.04537360898911, 66.0127055260443, 64.74772937836187, 62.36457178669592, 56.292476038778986, 54.23208636622275, 56.15658944652927, 55.5041463144364, 56.28444302466608, 56.12271193535098, 56.85723066329957, 59.88592801555511, 60.76034199806952, 63.30012375308622, 63.4847967855392, 65.05172875619704, 66.66786686066659, 68.50392833832773, 66.6899262705157, 63.99473628690166, 63.49655212894563, 68.26703286940052, 64.94394594623198, 68.91129001494377, 70.05082484214537, 65.32081903949862, 64.84816951136436, 64.58704948425293, 62.66331911087037, 57.14856863021851, 61.741256175502656, 61.45973590112502, 64.80977342974755, 68.99236540640555, 68.55867678119291, 68.08288543455063, 67.36870027357533, 66.56867011900871, 67.51615001309302, 66.50659468866164, 67.94269207985171, 69.824919854441, 66.95729855568179, 68.52737626721783, 70.65972574295537, 72.07751351018106, 60.50076738480599, 38.21432290538665, 0.3337249376120106, 0.1705033629531822, 0.17277838361840095, 0.08644341551248105, 0.07533091180507215, 0.23407243492622531, 0.06641107431102185, 0.09919679528402706, 0.043895685098945134, 0.2089265027954694, 0.035641252423726746, 0.054360162692084435, 0.062206534803995205, 16.24601402590352, 69.20298099517822, 28.54063234021587, 31.84878483895333, 42.5881225832047, 20.346946177944062, 38.38727589576475, 49.66999723065285, 1.7423341134863517, 0.06242825214060084, 0.030370272560826236, 0.07322358778647839, 0.01848317735317734, 0.01869999364228739, 0.08160999059797296, 0.011210394422373465, 0.019706123726322286, 0.05041505119973614, 0.043416286428128524, 0.04524473529008608, 0.03973175591278461, 0.07689026845318657, 0.03619126907940354, 0.02905257834842609, 0.05106026194088402, 0.003524086566739566, 0.06352995169318973, 0.03668066519763201, 0.07628992365132417, 0.010720416077322537, 0.05600240622316638, 0.05120429413152799, 0.06624104875710703, 0.01287214925527693, 0.02013826817874947, 0.009902444848370169, 0.019532495643943548, 0.06465959813325636, 0.0700683550788991, 35.425502023389264, 72.1989579354563, 72.58696663764216, 50.54010052834788, 26.091100400493993, 40.25554787728095, 43.18454250212639, 23.73710366987413, 1.0711170468599567, 0.23425785884741815, 0.16678647288391668, 0.23405685269784546, 0.3939155158737014, 0.9865807765914548, 0.23717070899663434, 0.00798960134664911, 0.3645066568447698, 1.6817124115843929, 0.40329960264986564, 51.0769239548714, 93.53335688191076, 89.50112112106817, 93.39687408939486, 85.71028371011057, 90.20208789456277, 89.24128763137325, 92.41665024911204, 91.17400415482061, 91.5159720759238, 88.0789089202881, 90.32348525139594, 86.03460096543836, 92.24488965926632, 86.80159691841372, 82.29436212970366, 79.34361011751237, 81.97325337317683, 83.01727064194219, 84.58657956892445, 79.92872576559745, 85.79993340276903, 84.09327091709261, 91.11293285123764, 81.17261132886334, 81.37677854107272, 78.61179782498267, 84.53776174975981, 83.25762564136137, 82.97996890160346, 78.96445812717562, 81.34175177543395, 79.41578172868299, 78.08015192708662, 74.13749525623938, 75.81071561382663, 71.12303610770934, 67.91809881887129, 68.05341274507585, 69.23157507373442, 65.85041353779455, 64.55902414937174, 63.72459088602374, 62.95031501400856, 60.68465202085434, 68.15513549312469, 75.24428613724248, 78.17272770789363, 79.14124719558224, 76.54085697666292, 75.98867354854461, 77.86205245602515, 72.73505180112778, 73.60355869416269, 73.60746537485431, 68.74789191830543, 74.4822794391263, 75.16325781422277, 70.15717598699754, 68.70021158649077, 66.37222997603878, 61.437178350264034, 58.80951196916642, 60.67103747398623, 57.77892489587107, 60.37564377630911, 58.02532819009597, 57.97512969663067, 61.965156832048976, 63.68916403862738, 65.59680092719294, 66.2432232210713, 65.35173908356698, 69.59601817592498, 70.0092790972802, 70.06235661045199, 67.57457763917985, 67.49152537315123, 70.49733177308114, 69.80060900411299, 70.93389157325991, 72.62846531406527, 70.55283331101941, 70.87412249657416, 67.62458785887688, 66.61804491473784, 61.82887800278203, 65.51562355410668, 63.38040290340301, 67.8644564843947, 71.87941028225806, 72.30274385021579, 70.08064270019531, 70.57664994270571, 71.32071571965372, 70.29763606286818, 70.48213651103359, 70.75403521137854, 72.33664881798529, 70.84876829578032, 72.06959032243299, 75.06183316630703, 74.17549517846878, 68.50848613246795, 50.05016511486423, 2.053103257090815, 0.5764353816067019, 0.007613737543579192, 0.2644826628027424, 0.1482034168176113, 0.7017555989084706, 0.36388471602432193, 0.09487340106598793, 0.04900750636513676, 0.18894925863752443, 0.19749028097477653, 0.10730058059937532, 0.050934397525364355, 20.297863598792784, 71.55068428285661, 35.063447644633634, 28.840846630834765, 34.31563208180089, 37.58850482202346, 48.52373161623555, 61.06669479800809, 2.9073029371999928, 0.09300489729690938, 0.05237547019796987, 0.07038045163837171, 0.05584107193675253, 0.01636961546366013, 0.049861150478283246, 0.02115833531734684, 0.03289389258791362, 0.045176319808008215, 0.05469637186897378, 0.06961053327446984, 0.015426809249836353, 0.014732134126637493, 0.0014883344321729496, 0.1735935777786278, 0.2173823361555415, 0.11601107690723673, 0.18638130127181932, 0.12550203294883813, 0.1077228635849972, 0.17026722401140199, 0.15121363674200353, 0.11842885805714516, 0.09956851646664644, 0.09706959128379823, 0.238236352621067, 0.10509274584511596, 0.1122185126728108, 0.17395255125818715, 0.11115846149022542, 42.225236661972545, 88.07639860337781, 72.44722043314289, 64.39135459161574, 63.64411953956851, 62.884305446378654, 58.61733152020363, 34.67401512207524, 2.5572823901330275, 0.37786689316553457, 0.29918681349485154, 0.7202207693649877, 1.4371208846569063, 2.190738858715181, 0.6962178250954998, 0.17615223483693215, 0.5115892870291587, 2.673812085582364, 1.1334718235077397, 54.55206155776978, 100.79684119070731, 91.42086244398548, 100.9533751395441, 89.60017665739983, 95.26809569328063, 91.13625526428224, 95.90908942684051, 93.51867152798562, 96.74797458033409, 92.39415153380364, 94.08619142347767, 88.1719083170737, 96.92223764234974, 90.00512215398973, 88.00801600179365, 83.16875257799703, 85.63573514261554, 84.99469434061359, 89.51834817086497, 82.46091381196054, 89.28684203855454, 86.95447521824991, 94.16950256593766, 84.68430934413787, 85.52870935009372, 82.09024983067667, 86.80896312959733, 86.4955343738679, 86.9498860451483, 82.0245030618483, 84.94242483569731, 83.71042405405353, 82.26080233050932, 77.63771641638972, 81.56584462811871, 75.03493355166528, 73.45880754532354, 72.73709143361738, 75.78517313926451, 70.83589507687476, 71.32946260513799, 67.66377233689832, 65.84139208639822, 64.67916634774977, 71.13233212501773, 78.21650135901668, 83.3450552725023, 82.32734141811248, 78.91542850002166, 79.54975420428862, 81.39849278234666, 76.48054661289339, 77.36159724573936, 78.36667322343396, 72.7457441822175, 79.67913750679263, 78.06902024053758, 73.75714302062988, 68.76085927409511, 68.94951743464317, 64.74625064480689, 61.63215544915969, 63.060647364585634, 60.67515988503734, 63.53628966116137, 60.408991767514145, 61.95852802645776, 65.71672347284132, 67.59920227912166, 68.17288814052459, 68.3510971069336, 69.97162434362596, 72.17913427660542, 74.43692115045364, 70.73936554693407, 68.77691745758057, 70.26773191267445, 73.39815985771918, 72.50996266641926, 74.39504592649399, 74.85383772080945, 72.33842172930318, 73.14160546948834, 68.30329910401376, 68.51281642913818, 62.9692090711286, 70.16294187115085, 66.92898688777801, 73.29453868250694, 75.18067313778785, 76.37251669360747, 73.67560478948778, 73.70024511891027, 74.57749889742944, 71.51098205197242, 72.33863353729248, 73.69702093062863, 74.7534485786192, 74.8411213967108, 74.68179472031133, 77.01454593289283, 78.28458586046773, 71.5881036943005, 56.07227809967534, 3.111223775532938, 1.0428544085833336, 0.8710946767560898, 0.8679230727495686, 0.27458365465844836, 0.5877497035168833, 0.3012815430279701, 0.2361190541376991, 0.11099561418016111, 0.4262355703019327, 0.2864256579308741, 0.24096184830752113, 0.3728917956111893, 23.062730566147838, 82.14697514810871, 43.23054013713714, 50.17568880511869, 58.76330644853654, 32.060428088711156, 52.002815123527284, 73.81812803206905, 3.4980883713691466, 0.1980673903298955, 0.21569724915729416, 0.19390235414668439, 0.14030347217715558, 0.10034256404446018, 0.3036243624744877, 0.08261702083531888, 0.12495414218715123, 0.2535698935389519, 0.12407576875580896, 0.14018339555590384, 0.12927605019461724, 0.1373456833103011, 0.17940892056832392], [0.054872836391892166, 0.0262212322934741, 0.0522775411786091, 0.03717569206210394, 0.04299958822347465, 0.015451323105803421, 0.032678384393934286, 0.06082711688753578, 0.06892045659403648, 0.08146241142023956, 0.06309408213823073, 0.08424197759238944, 0.07462282439753895, 0.05979367576900029, 0.21889951200254504, 4.2288607455069025, 55.072375728238015, 46.07373683683334, 28.73298537346625, 30.75870913843955, 26.355195545381118, 33.65907438339726, 37.51334044241136, 3.6820114956748102, 0.04340943760208545, 0.07398718592500494, 0.011134736536581431, 0.04808427848582787, 0.04833695343545368, 0.2060169468243276, 0.19452113868488421, 0.0998643336577281, 1.0832084883605282, 1.3321279830509618, 0.14441457577049732, 50.473910531690045, 84.98578271558209, 86.03787222216206, 85.6563118965395, 83.66158270066785, 88.51648069197132, 86.85222687259798, 85.64057534740817, 84.98231534034976, 83.96263245613345, 84.42707246349704, 83.42498533187374, 84.01153656744188, 85.66644730106478, 77.38349191604122, 75.37107283069243, 76.61770405307894, 76.79392830018075, 82.19904853451638, 77.4679954590336, 81.95786199262066, 81.0165794434086, 81.18955596800774, 78.46048847321542, 79.0685421420682, 74.87589713065856, 79.82106454910772, 80.46064622940557, 80.35629549334126, 79.19240274736958, 76.68905981125371, 78.52035953152564, 77.0918401595085, 74.40253765352311, 71.37390305919033, 67.84924553286645, 65.10858743421494, 62.55458316495342, 63.66083275887274, 56.85614024439166, 58.632703288908935, 58.299874490307225, 59.623419469402684, 57.954949102094105, 57.889665172946074, 68.41008170958489, 75.42959459366338, 71.05771295485958, 71.55440268977996, 69.86229219744283, 66.26549443890973, 66.54053103539252, 64.58844977040445, 66.49849891662598, 67.44058162935319, 59.32355426972913, 61.59445754943356, 68.12590599060059, 69.55819083798316, 70.44455236004245, 67.4835394274804, 58.434792257124386, 52.97140129150883, 54.26963521588234, 56.474124923829116, 58.18148951376639, 55.139620842472205, 55.55924777061709, 57.8005136212995, 59.319675045628706, 60.06947925013881, 62.6402908755887, 60.80810862202799, 65.4884179945915, 66.15993561283236, 68.6190499028852, 71.3181818685224, 68.19624193253057, 67.33226929941486, 66.64066130115141, 66.09670700565462, 68.76545629193707, 69.91880570688556, 67.35982787224555, 64.63411400395056, 66.51128584338774, 63.689799462595296, 59.16417660251741, 60.89922528113089, 61.10542820345972, 66.27563768817534, 70.12153733161189, 66.31326890760853, 68.64589460434453, 67.81322248520391, 69.1117701991912, 66.99663208376977, 68.09322480232485, 65.252471739246, 68.23789750376056, 68.11494688833913, 69.91347912819155, 71.30804646399714, 69.86765799983856, 60.245970218412346, 12.253523642016996, 0.6970491837109289, 0.14093328838146504, 0.06344560158228682, 0.06511653127569346, 0.04442796681917483, 0.03970778119119425, 0.051688748982644854, 0.1563123349220522, 0.04108673945489911, 0.6987950061598133, 0.04780318550465088, 0.08168653044248782, 20.619254765972016, 22.284702947062833, 39.1813362029291, 27.830434268520726, 36.10156959103, 34.14677404588269, 33.2230362584514, 56.08341763096472, 4.6654215262782195, 0.2664970756778794, 0.07834404286357664, 0.007215015113263602, 0.045919857934237494, 0.02692264899040663, 0.039954534281165376, 0.12017688683925137, 0.015274454471504977, 0.02798489693011488, 0.05257660275205009, 0.05134932606691315, 0.021507786324007377, 0.019034301005904714, 0.0729444100251121, 0.024832167414828174, 0.06340411409074742, 0.0022474431757619905, 0.055544036665871266, 0.038703198604766405, 0.012880173068673862, 0.020417453600995002, 0.05357993278472174, 0.05534297305970423, 0.07839952295105304, 0.016934563172981143, 0.06532102312532163, 0.013767396730761376, 0.05290284129460493, 0.4098060793213306, 6.924677327755959, 67.87763564817368, 61.67397575993692, 53.57155138446439, 34.38385778857816, 23.9049183553265, 43.48516864161338, 40.79286552244618, 3.877867940933474, 0.0656541717809535, 0.04181037078641596, 0.11871009659502776, 0.11962414674100377, 0.015098566429749613, 0.28255259317736475, 0.10742984261483916, 0.13434278718646497, 1.726048922827167, 0.9045812379448646, 0.46711895554777116, 63.05930199161653, 90.00382777183287, 90.13841998192572, 90.61675302443966, 89.7070533998551, 94.69042470378261, 91.40774603812926, 88.7268138700916, 88.44821576149234, 86.95383194954165, 88.81926413505309, 87.6313429494058, 86.16152101947416, 90.63070881751277, 81.31384018928775, 81.68471597856092, 82.04358147036645, 80.96401183835923, 85.95361971086072, 81.93082117265271, 83.51661189909905, 84.69715902882238, 86.06590147941344, 84.00642964147752, 81.57954938950078, 78.50878069477697, 83.57832647139027, 81.83196959957, 83.55143470148887, 80.80302992174703, 80.4404930914602, 81.97912123895462, 80.58848411806169, 78.474546247913, 73.65359244808074, 71.81714657814273, 67.17743765923285, 66.02348419927782, 67.24782851434523, 61.246100087319654, 61.87991196109403, 63.49264152588383, 64.61958946720247, 62.09568546664331, 62.448553654455374, 71.3864311095207, 76.50433186561831, 76.64367798836001, 74.8034901772776, 69.23756845535772, 68.57799837666174, 68.30424047285511, 67.17577457427979, 69.17931341355848, 67.10802739666354, 63.75449111384731, 62.4615563115766, 71.77491049612723, 74.11625954412645, 72.28054323504048, 70.49326819758262, 60.88422613759195, 54.309400204689275, 55.850448454580004, 58.937192963015654, 58.82373840578141, 56.106869482224994, 58.4623900536568, 59.928026814614576, 59.89606734245055, 63.63538049882459, 65.16643062714608, 64.36906768429664, 69.30892421353248, 70.6618595123291, 70.68137722630655, 71.97430810620709, 69.04443094807287, 70.9813287181239, 68.48052747787969, 68.94145304156889, 70.89155350961994, 70.82928196076425, 71.28746971007317, 67.54879197766705, 68.02546977996826, 67.6432583408971, 62.03138605240853, 62.8391864222865, 65.52000484158917, 69.55014997912993, 73.2388488708004, 69.86931324005127, 70.24950073611352, 70.86372037087718, 71.4680399433259, 69.10034041250907, 71.55430070815548, 68.3342073809716, 72.24452018737793, 72.19894224597563, 72.4027721343502, 75.52996804637294, 74.36590271611368, 68.04415595146918, 24.56827352123876, 1.001760287871284, 0.10790853265432582, 0.08793651321602446, 0.1784935221076012, 0.11156382925447919, 0.6135834140642997, 0.42308587641004597, 0.07796528133293314, 0.3084896336640081, 0.9567483322274302, 0.06045633416262366, 0.46567460401884975, 26.99113726615906, 17.27412804480522, 34.574151577488074, 34.0220622862539, 23.206863941684848, 36.29970812028454, 43.37459702645579, 65.39189238702097, 7.30647691795903, 0.3124524839222431, 0.1465415882487451, 0.04570726853524966, 0.06100725097161147, 0.09446881471141692, 0.05400660928458937, 0.019348130839306022, 0.06368122724515778, 0.08676015456477482, 0.020763696614472617, 0.041215139621448134, 0.023230808081045266, 0.02090608554651901, 0.024273972770559694, 0.08840479978149937, 0.1793256927762301, 0.14364657262640615, 0.15279566959267663, 0.21066316283277928, 0.13489761870474587, 0.11299709549113629, 0.15128757954845506, 0.17814921155091257, 0.20194417827071684, 0.1041507641334207, 0.12778289886491914, 0.2495257766737092, 0.22336376680722161, 0.6317043352511622, 7.329996920401051, 84.38459319453086, 65.85837594924435, 47.533960726953325, 48.3781881486216, 42.977068731861735, 56.18328509792205, 57.41947104853969, 8.146457883619494, 0.15178774303245932, 0.23511436046852222, 0.27612799598324683, 0.26934177464535164, 0.22158301074899014, 1.1433580349529944, 1.189557304305415, 0.2215892313829353, 1.999777041135296, 2.609547237234731, 0.9021538423915064, 74.74492134586458, 94.45379595602714, 99.0607766182192, 96.67894086530133, 93.20678818610408, 98.53285697198685, 98.32368481543757, 93.77399429198235, 92.35474740305256, 90.54614251659763, 91.12441755110218, 92.70747046316825, 90.33175360771918, 95.24645989941013, 84.35133149546962, 83.02884163395052, 87.51343650202598, 84.04213105478595, 90.45992097546979, 86.22071743011476, 88.46254810210198, 88.24079298203992, 87.53420152971822, 87.28611161631923, 85.30641294294789, 82.88128991280833, 85.87710211353918, 85.7776229612289, 88.00641567476335, 86.34404459307271, 82.63359223642658, 86.37736905005671, 82.60384498103973, 82.3835019142397, 77.039656946736, 75.10599905444731, 71.97744600234493, 70.55995633525234, 70.95845345527896, 64.21104323479437, 66.27486890362155, 65.96082825814524, 67.09571115432247, 65.4811655321429, 65.61669126633676, 73.13099938054239, 79.10648715111518, 78.65728162950086, 77.55018480362432, 76.1994852558259, 72.66753212098153, 71.88620382739653, 70.77019537648847, 71.15262646828928, 72.26072742092994, 63.63105020215435, 65.00063596233245, 74.02245998382568, 74.58107609902659, 75.66911805060603, 73.86860109144642, 64.90089401122063, 57.97941684722901, 59.969866737242675, 62.494904302781634, 63.69149784887991, 58.81562694426506, 62.40361505939115, 62.204605763958355, 66.23089128924956, 65.0155762703188, 67.28122357399234, 66.56967424577283, 73.91618728637695, 73.30452503696566, 74.0468571262975, 75.85537572060862, 72.23582037033574, 74.50335041169198, 70.84079019484982, 71.51641845703125, 74.21194184210994, 74.38719334140902, 74.46540540264499, 70.17893729671356, 71.80246906895792, 69.38646162709883, 64.27402081028109, 66.16107310018232, 69.79076385498047, 74.22276758378553, 75.10321417162496, 72.87584920083323, 73.74481893354847, 73.1496306388609, 76.18517644943731, 72.86337606368527, 72.85635502107682, 71.07561465232604, 76.485135785995, 75.9977577578637, 77.46431627581197, 79.77139949798584, 74.24423079336844, 71.05879552902715, 23.40003675030124, 1.0560633578608114, 0.4032987139878735, 0.38966406497263145, 0.21400373519187976, 0.09214959843384643, 0.6436554294440054, 0.39281918276702205, 0.3030791223770188, 0.5164734959121674, 1.3143454275784956, 0.17916423208530874, 0.40369757000477086, 32.40201161753747, 34.67162247627012, 48.92948512108096, 43.48244651671379, 51.06045784488801, 48.481205278827304, 45.06569554728847, 79.08565152075984, 7.878477140780419, 0.5658145837726132, 0.16503283633820473, 0.25192484229562745, 0.1776429040417556, 0.16828938417377012, 0.1318077716015039, 0.28254361462689215, 0.16439482299310548, 0.2245358200443368, 0.27089834273342167, 0.10753796060359287, 0.16064937316602276, 0.10713343553605581, 0.1826276849474638], [0.0169845963753159, 0.0376474911407117, 0.03949293183282979, 0.05150533604225324, 0.020689997040937026, 0.008136445558780145, 0.03588142864886792, 0.0530771914148523, 0.03535459764421948, 0.07174192777564449, 0.0326057784109106, 0.05354609085066665, 0.06332946648340552, 0.06081742204485401, 0.14154130172344948, 16.541817611263646, 60.71826673323109, 36.00595397333945, 42.277976851309504, 39.78523215939922, 25.13034720574656, 46.57563940171273, 13.29590920479067, 0.5325726191363027, 0.12666441049546967, 0.10241823331002267, 0.09157481798601728, 0.034243490531920426, 0.011784566787912721, 0.07420490045220622, 0.10666380065583414, 0.2680260339571584, 0.7833046165685501, 0.013650994458716485, 2.492848389571713, 58.99010965901037, 88.76946572334536, 84.33653631517964, 85.41596474186068, 83.69598188707906, 81.19514926787346, 83.82327064391106, 86.27995306445708, 83.12841492314493, 87.91131388756537, 87.41642059818392, 81.08260077814903, 82.17156840908913, 82.08211483493929, 77.49333397034677, 78.38200969080772, 75.46335051136633, 83.11980139824652, 81.51064119031354, 80.28779522065194, 81.81362075190391, 83.64372022690313, 81.07056694646036, 77.03228289081206, 77.16718889051869, 78.11266837581512, 81.84260706747733, 79.95595485933366, 76.90625713717553, 78.20897040828582, 78.72254986916819, 75.1972569188764, 72.77893527861565, 70.14705627195298, 68.74970405332505, 64.68755237517819, 64.21644826089182, 62.34558751506191, 62.340084429710146, 57.76396889840403, 58.60994569716915, 58.45591422050231, 57.30703630755025, 57.96344887825751, 57.86202423034176, 66.77655573814147, 71.49901882294687, 74.5004007893224, 70.0163785872921, 64.3829018838944, 66.88909638312556, 63.90780871914279, 66.16723122135286, 65.45716062668832, 66.88016906861337, 66.93975771627119, 65.9024320110198, 71.17063799212056, 74.2800106540803, 68.91318059736683, 67.42303294520225, 58.330896516000074, 52.521132807577814, 51.247060683465776, 51.80133473488593, 53.10121605473181, 54.38748282770957, 54.293549906822946, 53.590570957429954, 53.497559793533824, 57.332174777984626, 57.81273180438627, 63.33390712738038, 64.67920949382167, 64.87012301721882, 65.78851461410522, 66.78219610644926, 67.72140764421033, 69.97481715294623, 65.04498227950066, 66.09437711777227, 66.71693571152227, 68.12942043427499, 67.69977185033983, 67.10259883634507, 64.3681380825658, 66.40498176697763, 60.67537561539681, 61.032554488028254, 55.46561687223373, 63.5375879656884, 67.4326035284227, 67.89115998052782, 67.02301394554877, 67.55486380669379, 65.6294232799161, 65.84508695910054, 65.78180736111057, 65.4244480594512, 66.45757290624803, 65.62889375994283, 67.53328292600571, 69.04764729161417, 72.22576341321393, 66.53060743885656, 61.30336669183547, 5.649237767342599, 0.8642756362115184, 0.05281018679060283, 0.1145994220109236, 0.42398863442001805, 1.455601376871909, 0.11009647976607086, 0.15267248265445232, 0.23961687370413737, 1.6039618417139978, 0.08199912495911121, 1.9602093965776506, 22.737058131925522, 2.914655665236135, 8.60583411109063, 36.00695025536322, 33.21623094620244, 60.74349541817943, 26.37174402513812, 58.86052631562757, 15.192771342492874, 0.29335002024327556, 0.0774191755561098, 0.027978496265507517, 0.01596338680810145, 0.0589570694512898, 0.06721360503786034, 0.015716242055679043, 0.01481025881554571, 0.02313234088491769, 0.08045617791433489, 0.029304326331663518, 0.07760429304213294, 0.048835856704822475, 0.02366920381093458, 0.007177975240929594, 0.06253977539017797, 0.060441640596235954, 0.09409070435550906, 0.10237619040473815, 0.006629854174060447, 0.049197243361343304, 0.06464355625212193, 0.036103314524816896, 0.01776618225830457, 0.06538794090550754, 0.07347400660716719, 0.08088733985899918, 0.04002558127526314, 0.18106336404960002, 22.21099965033993, 71.59035513477941, 55.04099284448932, 45.61485482800392, 21.608205879888228, 29.739104701626687, 56.42348320253434, 13.16409501337236, 0.4322355709248974, 0.11021084137140744, 0.060995150612847465, 0.05200129370355318, 0.017406492486536022, 0.04907862230714771, 0.28768066316843033, 0.12990293994305596, 0.2951153626124705, 0.6062473561013899, 0.11931985661747957, 5.621771370210956, 71.05113121771043, 87.9477370169855, 91.94357318262901, 88.98950284527194, 89.07734040291079, 86.4211505459201, 88.7697873576995, 88.55324114522627, 87.31966357077323, 89.24462164601972, 89.4636546411822, 83.64497538535826, 85.49661651734384, 84.74774975930491, 81.71599295831497, 81.59912986140098, 79.56956217365881, 84.78681656622118, 84.87919622851958, 85.44804188512987, 83.93314407717797, 89.67329748215215, 84.63536600912772, 82.74368532242315, 79.3209780416181, 81.5473702646071, 85.42992053493377, 82.12626503359887, 80.1275271754111, 81.10131048387098, 82.37091895072692, 78.37404727935791, 76.17733170909267, 72.76402242722051, 70.08929544879545, 67.34602897397934, 65.97180304988738, 66.16170852415024, 64.02873931392547, 60.785382409249586, 61.12082742875623, 61.45066738128663, 61.73397233409267, 61.20818645723405, 60.247974549570394, 67.99718949102586, 74.89852920655282, 77.52948253385483, 73.51022197354224, 66.63523274083292, 69.54976558685303, 67.86791601488667, 70.91540152026762, 69.03889256138956, 70.8618454779348, 71.00170150879892, 68.99861766446021, 71.17488984138735, 74.85699130642799, 71.86696852407148, 70.22194216328283, 60.15053502974972, 55.19906828480383, 54.34907497898225, 54.65459623644429, 56.105688848803126, 56.268730009755785, 56.62916444963025, 56.78505905212895, 57.600727696572584, 57.487783047460745, 60.608777692241055, 65.07537672596594, 66.1982257904545, 67.9194559589509, 68.19631253519367, 68.9795627901631, 70.21421509404337, 73.21187080875521, 68.27192014263522, 69.2276527035621, 69.09665338454708, 70.07442182110202, 69.4898239258797, 69.99126757344892, 66.51668302474484, 69.38945047317013, 65.20921976335588, 65.6443400536814, 58.91422356328657, 67.0812846768287, 70.18871968792331, 70.69396018981934, 70.05793217689761, 71.28279424482777, 68.9290112833823, 69.04330915020358, 70.00129315160936, 69.65535579189178, 68.22317292613369, 69.59436293571227, 72.85688846342026, 71.98285887318274, 76.0802452025875, 70.11701091643303, 70.9722052851031, 14.009000024487896, 1.5152429765270603, 0.5214649571045753, 0.13167352235365298, 1.4729552908289818, 2.241646565737263, 0.5472396482383052, 0.20127395858928082, 0.49650253367520153, 1.2711098766134632, 0.20517898453099115, 5.805235822354594, 33.019575072873025, 2.026256226724194, 4.153652729526643, 41.411297782774895, 30.93162290511593, 47.09960922118157, 37.07061467632171, 65.77662983248311, 22.516087485897927, 0.34200818668450084, 0.0758362310608068, 0.09007827288681462, 0.041717953769670385, 0.026230532600874865, 0.061434616950610955, 0.0770759222007567, 0.08024798586003243, 0.019037053176772692, 0.030943626169896418, 0.06591211358505873, 0.023831627857420715, 0.04308954609798328, 0.09294823743402959, 0.06836383243001277, 0.16579952181106614, 0.13406514160094724, 0.17234673903834435, 0.20171455107629302, 0.1357445289050379, 0.10407858332919498, 0.10745362198400883, 0.1117648890302066, 0.14774863638224142, 0.1474364861966141, 0.24313566875794243, 0.1933859342769269, 0.2314895848112722, 0.3338280836901357, 26.90875964780008, 86.03312615425357, 52.88407364199239, 62.78980770418721, 60.00676839582382, 42.96236768845589, 77.31764316558838, 20.328813060637444, 1.1776459241105666, 0.4273861424336511, 0.18462578014981362, 0.27673789390152503, 0.1448511539567863, 0.13587891604871521, 0.3178870810135719, 0.33048787905323895, 1.121118808946302, 2.7595090096996677, 0.21593406225644776, 6.4767656980022315, 80.51618699104556, 93.99621225172474, 96.67488513454315, 93.29377066704535, 93.46914768218996, 88.74378204345705, 91.88691062311973, 93.23054990460797, 91.20324150208505, 93.18911398610761, 94.19981464262932, 86.42846968866165, 88.96613336378529, 88.20437769736014, 85.96690870100453, 85.1228460188835, 83.79165634032219, 88.2748156209146, 90.4712958489695, 88.40322617561587, 88.67289696970295, 93.66461507735714, 90.32491299413866, 84.77526126369354, 82.84547082839474, 85.30772301458543, 87.62716954754245, 83.4639266229445, 84.07926021083709, 86.21189994196739, 86.31130064687422, 82.08674323174262, 79.67195172463694, 76.10308124173072, 76.75199816303869, 71.54396134038126, 70.20206359124953, 71.3718791161814, 69.1051806173017, 64.22135122360723, 66.19831208259829, 64.4137042568576, 63.257860214479514, 63.863870328472515, 62.81616210937501, 72.74255921763759, 78.36439824873402, 80.2989661309027, 74.71351885026502, 67.17081669838198, 71.83110237121582, 67.56424611614597, 72.3970062501969, 70.83575387154856, 70.93263641480478, 71.72413933661677, 68.53604470529865, 77.08134389692738, 79.44950626742455, 74.5947494814473, 71.65720016725602, 63.88807919717605, 59.02908625141267, 57.14548564726307, 57.00969319189749, 60.00750972378639, 61.192273401444965, 59.40504151005899, 58.68702027105517, 60.72219694814375, 62.338994010802246, 63.36271693629604, 68.83286614571848, 68.53398153858801, 71.18381715589955, 69.87700893032935, 72.53197500782629, 72.24888186300956, 75.97667109581732, 72.6681753896898, 70.59914081327378, 73.30060266679334, 75.8272131027714, 74.83134685024139, 73.04096529560705, 69.55283288032778, 71.72657905086395, 65.90542870183145, 69.77780434393114, 61.65716840374855, 68.71833293668686, 74.29499410813855, 75.0626568640432, 73.90303165681901, 75.3941991252284, 70.48575293633246, 70.89703698312083, 73.18046046841529, 72.73966450845042, 71.4425523819462, 71.53086846874606, 76.15244819271949, 73.83642196655273, 79.43570736915835, 73.01588566072526, 74.313123303075, 15.400979576572297, 1.4629300803907457, 0.8732555349988322, 0.4108666514437045, 2.059920704172504, 3.362124312308527, 0.7275364800326286, 0.3792013570425972, 0.8679814792929158, 2.7067313126979338, 0.20367740623412595, 5.901766332887835, 36.54894336577385, 4.004733817231271, 11.889747342755719, 53.556128624946844, 47.65135334384057, 83.02631562755954, 38.13327889288626, 81.14579016162504, 22.128065055416478, 0.49573509743617433, 0.17750030443553003, 0.13751161795470024, 0.1329455040996113, 0.22966994213000422, 0.22351336845707512, 0.13326811904628433, 0.24393512747220455, 0.16215626811308248, 0.07216712955625788, 0.14279361033151228, 0.2663002523683733, 0.16048945997270847, 0.23896157741546634], [0.06870975943222161, 0.05892355693504215, 0.04801540718143506, 0.07468742093131428, 0.01831868678451546, 0.01904896201355563, 0.11584343388676645, 0.07349128188985972, 0.05941825821214627, 0.01224417357720555, 0.02838070200185382, 0.026775966135544643, 0.029021239606663588, 0.028450239802740758, 0.22907089201673386, 36.784058078642815, 57.04227239854875, 35.113167608937914, 63.880238379201586, 36.24548135265228, 45.94006246136081, 19.191023688162527, 1.415101924250203, 0.06867035186939663, 0.12347115684420833, 0.08414815480430281, 0.08058360131878047, 0.043080732256414435, 0.04653460518907636, 0.20198819768284598, 0.19058048965469485, 0.15172245701955211, 0.09150514228930397, 0.5682630620656476, 15.709156278640995, 77.29558375573929, 81.22472393897273, 93.03084634965467, 83.59491025247883, 87.64285902823173, 84.15513453945037, 88.44628595536756, 80.64147533908968, 85.74626753407141, 84.14164943079795, 84.9013654647335, 80.65189315426736, 81.36411713015649, 75.87871382313391, 78.09093844506049, 77.05336170811808, 77.95750725653865, 81.50486746141988, 79.99152291205623, 80.19953404703449, 80.17221866115447, 79.59650885674262, 78.69113952882829, 77.48055488832536, 75.6684983161188, 81.35598213441911, 81.19851466148131, 78.33086198376071, 77.777462620889, 77.209989793839, 77.6390500222483, 75.93960469768894, 72.91514350521949, 73.14383337574621, 68.14225442947881, 64.9448912374435, 63.99915679808586, 60.48130458401096, 57.212691537795536, 57.23661015110632, 55.27458567773142, 56.168501684742594, 57.69091083157448, 58.1032499959392, 54.743873303936375, 63.24665792526738, 72.77125527781826, 71.2297716448384, 76.15510755969633, 69.25292061221215, 68.16810284891437, 69.25893752805649, 68.20168618232974, 67.10958849999213, 71.00444716791954, 69.83012091728949, 68.52429328426238, 68.41866385552191, 67.013686549279, 68.67412782484486, 69.02758829055294, 56.63094128331831, 51.03162450175132, 53.41358577051471, 54.5592277280746, 57.46508036890338, 50.00350459929436, 53.79152182609805, 52.241369755037375, 52.695917544826386, 55.17443580012168, 55.183049325020086, 55.93288490849157, 59.86956388719621, 62.73455719793997, 66.24099531481343, 67.13866110770934, 67.40271506770965, 68.46241397242393, 65.89405382833174, 65.47829827954693, 65.26153241434406, 64.5726033949083, 64.14265671084004, 67.11960623341223, 65.44993954320108, 62.56408314551077, 65.4235145353502, 63.29314585654967, 54.12958306650962, 61.5595837562315, 66.26254481654014, 67.2169594610891, 67.94887373524328, 68.96401451480004, 65.66941184382286, 69.58909911494102, 66.99041120467648, 64.93766623158609, 66.03312538516137, 66.64798828863329, 67.95953473737164, 70.67854527504214, 72.13477226995653, 66.0599151734383, 63.61976162079842, 38.138676074243364, 2.855637967586518, 0.35246531749444626, 0.20895026684288057, 1.6241040705673158, 0.7770172410434293, 0.21146113533646832, 0.06779009386176063, 0.13161447229644946, 0.771423450881435, 0.7865046577588205, 6.11484811190636, 21.29766006623545, 0.06829042588510821, 0.6723153915616774, 17.94675765498992, 50.010200085178504, 40.745738244825795, 25.20758455799472, 52.905211294851, 31.32487777740725, 0.22053336304041649, 0.09509284695189807, 0.07370600867415629, 0.06150571374042381, 0.029084415047339378, 0.06805533648378427, 0.046279065070613745, 0.043436449862295584, 0.06839197083947159, 0.10084339402495854, 0.017519771992679567, 0.043910911096440214, 0.0031595828899768216, 0.02754340045935204, 0.05145083654731993, 0.04311494191267318, 0.06245106240854629, 0.031116813751718694, 0.02649405152506886, 0.09027309670683839, 0.014136676965732009, 0.03705299542015118, 0.006587342039922313, 0.03521664436125467, 0.031149372488500613, 0.10710443144724255, 0.04956066781174272, 0.07571345014918236, 0.2252716168520912, 45.755032493222146, 72.89218195023076, 48.988238303892075, 55.01670552838234, 30.877880550199944, 57.716017923047474, 25.4546840729252, 0.9666603455139745, 0.007338608556892724, 0.0829226209691936, 0.027848939306192824, 0.3020812162468511, 0.06394489938693662, 0.613409604036039, 0.6556774940221541, 0.739957032905471, 0.7128364785063652, 0.10635605547577144, 0.4342012299645332, 23.481443582042573, 89.09621484817998, 83.3332097145819, 94.34422846763366, 87.44888213373001, 91.8499069829141, 85.45709471548759, 93.15057277679445, 85.19984214536606, 86.86437837539181, 88.83733841680711, 88.83576162399785, 83.11947191915205, 86.12370937101304, 81.56078477059641, 82.26255170760616, 79.14940572554066, 81.85687665016421, 84.6491962863553, 82.1885758061563, 84.98774390066825, 84.00002048861596, 84.65011412097563, 82.6811941208378, 80.04894641137894, 80.34082566538166, 86.99888429334088, 83.92622501619401, 79.48627456541985, 81.06852731397076, 79.54614562373008, 80.80621488632696, 79.00980072636759, 77.11316216376521, 75.55980159390357, 70.32760297098469, 68.58696491487565, 66.72760455839096, 65.13741685498145, 60.182682775682025, 58.65479800008959, 56.56725768120059, 62.00077195321361, 62.99278251586422, 61.98672202325637, 58.38016540773454, 64.37580631625268, 74.14942710630356, 76.67726132177538, 80.49708504830637, 70.68900231392153, 69.99917507171631, 74.44646035471271, 71.93059721300679, 72.60778657851681, 73.27673112192463, 70.42470516697054, 71.2808487492223, 72.06187894267421, 70.10667154865881, 71.90382311421057, 70.742323014044, 58.817227271295366, 54.074501222179784, 55.82738491796679, 59.99143192845007, 59.302024379853286, 51.552119101247484, 57.3619455675925, 54.70389258476996, 54.826611780351215, 56.454054155657374, 59.21257080570344, 58.89495295862998, 60.97074970122307, 64.9939130198571, 68.15981095837009, 69.29212077971428, 70.47609606096822, 70.21162632972964, 69.02016716618692, 66.68858481991676, 68.46427317588561, 66.68663147957095, 68.51596217001638, 68.32799434661865, 68.03162005639845, 66.88294610669537, 65.14930163660358, 66.12915285172002, 58.450128724498136, 63.032476902008064, 68.08005348328622, 69.74124785392516, 70.32599479921403, 69.91138458251953, 71.20008714737432, 69.75637251330961, 70.35499680426814, 68.5733699798584, 67.18421551489061, 68.39053261664607, 71.5941676785869, 73.27971212325558, 74.15759348100232, 69.71230860679381, 68.60525100461899, 48.17861010951381, 6.215877581027247, 0.9215239771912176, 0.39793710975397023, 1.176708477639383, 3.7090775659007416, 2.1343187507121795, 0.1068978711602188, 0.2245386852131736, 0.7879082534101702, 0.2794317961219819, 5.039504833759801, 17.28529895505598, 0.053892772449480916, 1.162495646745928, 17.355544682471983, 55.06195399069018, 27.670134844318515, 32.56348579160629, 60.092519252531, 35.384528944569254, 0.08032742917778031, 0.05299484845431102, 0.02925110045790432, 0.0519496095817416, 0.056358112337728666, 0.07017213701000137, 0.04797974961899942, 0.03773367603219325, 0.11411341583176006, 0.10094281691577166, 0.04100319756675632, 0.04666475586653237, 0.04841633546616762, 0.021109899408334208, 0.11470443734358396, 0.21395125816906654, 0.07557732398591696, 0.24140251740332574, 0.09826334779180827, 0.20417281997299966, 0.18587750653105398, 0.22295047769383078, 0.1363471643097939, 0.09594888892024757, 0.09387695050287632, 0.198708345452624, 0.0991706180596544, 0.16941286743648593, 0.424909655966105, 56.86058036742672, 80.01690849181145, 52.88799208979453, 87.1721746075538, 55.62442579577046, 70.85235334211781, 36.43153505940592, 1.6407018250996068, 0.25343346860139604, 0.2927284471450314, 0.23000179609704405, 0.5153494304226292, 0.17319836834025, 0.29000540293993493, 0.45554100746108644, 0.8000678460924857, 0.6886121041832433, 0.7456451438127026, 1.0941981115648824, 25.767687251490933, 99.35879830391177, 91.30603897956111, 102.92224022649951, 93.22943595147903, 98.47009904922979, 92.766078518283, 96.6441180629115, 89.59106891385971, 92.7757667726086, 90.40240333926293, 91.05692140517696, 87.2019140182003, 88.23192058071014, 83.27279736918788, 86.41074842022311, 84.09468297035464, 87.69424207748906, 90.02259239073723, 86.70549884919198, 88.72398976356753, 86.48307692620062, 87.34537862962293, 85.40829258580362, 84.9388397893598, 84.01450972403251, 89.7512585116971, 87.05566452395531, 82.2121649403726, 85.16225799437493, 84.21977519989014, 86.01589910445675, 83.42901752841088, 79.53892061787268, 79.72398588734289, 74.85870145982312, 71.80901942714569, 71.83761350570187, 69.35915408595916, 65.56120934024935, 63.29126311886696, 62.18087542441584, 64.41764231651061, 64.64987408730292, 63.371958040422015, 60.15739133281093, 70.0456080898162, 78.58870290940808, 79.98145026545372, 83.47461115929389, 74.47513288067233, 73.94220044535976, 75.83093150969475, 74.07129349247103, 73.92688751220703, 76.16621571202433, 76.47005819505262, 75.9688263554727, 77.1510208806684, 73.06652345964986, 74.93293623770438, 75.28992683656755, 64.47034720451602, 56.90074543799124, 59.59500189750426, 61.50322714159566, 65.32489045973747, 56.391888510796335, 60.131248735612445, 57.06570071558799, 57.95877733538228, 60.85218821802447, 61.84304168147426, 61.33922107758061, 65.17813497974028, 69.40848181324621, 71.10474217322566, 72.39664539214104, 73.0730345941359, 71.36284982004474, 71.69541974221507, 69.91642875056114, 71.13936885710686, 70.42661143887427, 71.58373417392855, 72.64270351779076, 72.04307510006812, 70.19314412147769, 70.59417509263562, 69.45416958101335, 60.59572404430759, 68.58483114550191, 72.02008216611802, 73.40926801004719, 73.92907619476318, 72.6384908922257, 76.26489470081945, 73.021023965651, 73.49075132800688, 70.75157196291032, 70.88235162919568, 71.72810877523115, 77.33056345293599, 76.22566315435594, 77.54442676421135, 71.72982677336663, 74.73013401031494, 49.593467866220784, 6.4411250814314815, 1.2303907712621074, 1.3528475357640175, 6.163529628707517, 5.944452016584336, 3.099503243161786, 0.2881872924345155, 0.27765097877671646, 1.3566530928496392, 1.3145687575301817, 8.579164935696511, 24.276955166170676, 0.18551706216268002, 1.2597488539834178, 25.22737683788423, 70.01644134521484, 54.22707749951271, 37.427915142428496, 71.02435711891421, 42.59757549531999, 0.3955028806963275, 0.21644780081847023, 0.20482718163440305, 0.16522981286529573, 0.17383068199119261, 0.2663979439004775, 0.13747786412075644, 0.11419962370587934, 0.20862216670666972, 0.18262060629504343, 0.11722367917818409, 0.1393782218257266, 0.09688932313433579, 0.07096203494696848], [0.04335236022128694, 0.025733828003848755, 0.0865288113334006, 0.027362701385432196, 0.04923476251743494, 0.03743727661428913, 0.05819858111921818, 0.1105268832836901, 0.022377014580753543, 0.026024891619360255, 0.023885462771079714, 0.07880288356494519, 0.057014086614212686, 0.09279658266853902, 3.361464373527035, 54.66290381646926, 37.1020132495511, 49.73570085340931, 36.5225262026633, 25.95144048813851, 49.143752436484064, 3.523341080834789, 0.22803258240943958, 0.03424241034794719, 0.1302539461082028, 0.04675829903252664, 0.10312386923619818, 0.05229281697181925, 0.09646226742094564, 0.4004644644596885, 0.11023791491865151, 0.3492216399360088, 0.2903745041018532, 3.4647683270515937, 56.03376826932354, 80.55894867066415, 83.86358476454213, 85.30324366784866, 84.84127475369363, 84.38900978334489, 81.32883148808634, 83.019223982288, 82.36431367935674, 81.4897898704775, 83.94181251525879, 85.1628149709394, 82.9126061162641, 79.17014721901187, 76.02781880286433, 78.35236441704535, 75.23435469596618, 81.73985665844333, 80.33568736045592, 80.46067760836694, 79.39981768208166, 78.7883750854, 77.10657258187571, 75.47430961362778, 75.24851445228823, 81.71494960784912, 82.07816108580559, 79.31327450659968, 74.81163301775533, 77.46375145450716, 77.77754106829244, 74.47456021462718, 75.85922748811784, 72.56620160994991, 67.63110683810326, 64.21867616714971, 64.22168462507187, 57.21157366229642, 57.08710508961832, 56.11044276145197, 56.32740082279329, 52.57275512141567, 57.22134036402549, 60.768888842675, 59.10259146844188, 59.12130901890417, 57.82945286843085, 69.4153538057881, 73.70268483315745, 76.4425153117026, 67.3352659902265, 67.66180330707182, 71.83593473126813, 68.94520282745361, 67.13196169945502, 69.5940177671371, 68.54548192793324, 64.91213552413448, 69.91861743311729, 68.3070332004178, 68.97288691612982, 64.0222046452184, 54.67982492139263, 54.171517126021854, 57.348848773587136, 54.604311450835205, 54.63496869610202, 52.308120650629846, 55.55542345969908, 50.31528203718124, 50.01923330368535, 52.093931782630186, 55.738951160061745, 55.65885243877288, 55.76075953821982, 59.182097911834724, 61.82424960597869, 66.36512264128655, 67.68734578163394, 67.48306874305972, 68.38809290239888, 67.8545093536377, 66.03911876678467, 65.63207480215257, 63.4086988818261, 65.81072699639105, 68.41066222037038, 65.44096516024682, 63.60063614383821, 64.89350426581599, 61.39824098156345, 56.84711094825499, 63.00873871772521, 65.27468412153183, 65.24375623272311, 65.3255376508159, 65.99510977345129, 68.8976558562248, 69.45710351390224, 67.18507059158819, 68.10967522282755, 62.6207104036885, 67.00781868350121, 72.64604537717759, 71.67747882104689, 69.61330013890421, 60.667523030311834, 65.92940222832465, 17.69913254245635, 5.465914030228892, 0.010108939060310443, 0.10652651769980308, 1.7278362978850643, 0.8392157970416931, 0.12926891025516296, 0.0873522102952965, 0.5799492736977916, 0.19794765078733045, 2.703893723026399, 7.590209409113854, 0.20648881102040892, 0.40127866270561374, 4.1401122173955365, 38.988559553700114, 34.25736527289114, 34.46450171932098, 36.358994745439105, 31.866684575234693, 0.09666790840246024, 0.07189100082483023, 0.07948054196012598, 0.04218141398122234, 0.021696485271076524, 0.05289897638102693, 0.053596032122450496, 0.031804094211228436, 0.07806966081261635, 0.021227430702457507, 0.04719655878180939, 0.034347364393573616, 0.04332022666330299, 0.04761057950916791, 0.03338484386462839, 0.08858250153641548, 0.010516937378974212, 0.01325105442740624, 0.05968060119137649, 0.055488376547732664, 0.05600412609055639, 0.09284394988489729, 0.03797410123590981, 0.14185175119388488, 0.017137526677200393, 0.08178485016668997, 0.03944712360539744, 0.28936483086116854, 5.542801310939174, 64.0288059942184, 56.51635316110427, 56.53623173313757, 23.281494878953506, 32.75404041813266, 57.49475702162712, 3.9205803457767736, 0.2116638575229914, 0.05111077394817145, 0.07646516626400333, 0.06132053879780635, 0.17832554966932346, 0.2411527880617688, 0.6491694851748405, 1.316834294026898, 0.3286144569996865, 0.39292303364603753, 0.26454278538303994, 5.9608230090910395, 66.51908351529029, 84.67501332682949, 96.74362074944281, 91.53046915608068, 89.43507625210671, 87.77659616162701, 88.15599133891445, 87.03310305072416, 88.96763955393146, 84.9813739715084, 88.20789214103453, 87.34537078488259, 83.48280891295403, 81.79086316016414, 80.53887398012223, 81.78610140277495, 79.50268576222082, 83.0054799972042, 84.89870609775667, 83.93633688649824, 82.95649743849232, 81.51616388751616, 79.9312674614691, 77.00969003861951, 80.32809365180232, 82.97373233302947, 86.0110902786255, 82.17939745995307, 80.18109106248426, 83.0224952390117, 79.375993205655, 77.61588450401061, 78.5237798383159, 75.25027167412543, 72.64664942218413, 68.14304674825361, 66.20872205303561, 60.34184471253426, 59.14238391384002, 58.94123300429314, 59.26928827839514, 53.589664889920144, 59.75934528535413, 62.502745120756096, 62.33089431639641, 61.6197842936362, 61.81965651050691, 67.72052118855139, 75.36272602696573, 77.98949810766405, 69.3464534513412, 68.92982713637814, 74.17151789511405, 70.75553355678436, 72.74925078115156, 72.49861917188092, 71.63125761093633, 66.51993074724751, 73.18501041781518, 70.56774616241455, 69.73943571890555, 66.86932763745709, 57.33083724975587, 56.841211703515825, 59.23965084937311, 56.12821894307291, 57.6165662273284, 55.13672221091486, 58.745008591682684, 51.83283921210997, 53.59149271442045, 54.78152805759061, 58.627980755221465, 58.701431059068256, 58.64199930621732, 61.81420049359722, 64.15392568034511, 66.0440452637211, 70.54587502633372, 68.82409572601318, 70.3362714090655, 70.34004472917127, 70.58313754297072, 68.57766105282691, 67.10141428055303, 69.57247611015075, 70.20433072120913, 66.77400619752946, 68.48143746775966, 67.74647943435177, 65.26010467160133, 59.31506233830606, 66.16539555211222, 67.38626464720696, 67.5593666876516, 68.96621104209655, 69.24170263351934, 70.9871102917579, 71.61437572971468, 69.9680628315095, 69.31925573656636, 64.35770065553727, 69.1542730023784, 75.75835981676656, 72.85936740136916, 73.13981686868976, 64.9393097046883, 73.51535243372764, 21.247634157057732, 8.75926350393603, 0.5890269865912776, 0.09195246868917058, 3.7996068500703384, 3.0413590083199167, 0.8301071954831001, 0.47543110145676526, 0.38718273682940396, 0.11484747361992637, 4.115760672476984, 7.902370748981354, 0.1570296383673145, 0.7012721667847326, 3.1457286207906665, 47.45920035146898, 29.352107970945298, 38.49501163728776, 52.18173403893748, 36.97661115277198, 0.24159702712730055, 0.05860157401090669, 0.042242363936478095, 0.08585198031317803, 0.028755581381941037, 0.08067128008171436, 0.05241998756724981, 0.03801293423279159, 0.06759148556739092, 0.02448474845638679, 0.035987596943854325, 0.06272770824932283, 0.03174142247336286, 0.024324666723729144, 0.19552351876852975, 0.1725845786953165, 0.12621817194045554, 0.12864019721746445, 0.10717914034161838, 0.11670309179011853, 0.15079257949706049, 0.16258078807544324, 0.09863061034270833, 0.2952033401496949, 0.056661843217068145, 0.16870455786345467, 0.2304083283149427, 0.4419250816347138, 5.85143938179939, 80.07708549499512, 54.021741420991965, 71.09077853541221, 53.02722446380123, 42.52443898108698, 73.07945943647816, 6.5139409419028995, 0.38377808887631665, 0.19110631708416248, 0.23754290515376678, 0.26447693246506876, 0.29389332979917526, 0.23133609143476333, 0.38719337012979294, 2.503606470361833, 0.3336289314733398, 1.2981882042461828, 0.5835767919498106, 5.895326781657435, 69.32192294828354, 89.86270089303294, 100.47400659130466, 99.8579591320407, 97.62207477323471, 97.32282146330803, 91.76490137653967, 89.42630583240141, 94.08929794065415, 87.9430615517401, 92.33590433674475, 91.09891430024179, 89.11410085616573, 87.66694238108974, 86.43235283513224, 85.08207690331244, 83.51213255236226, 86.95827991731706, 88.1713984089513, 88.69884737076299, 86.20381201467207, 83.79357830170663, 84.27626517511185, 82.12773200004332, 83.08777916815974, 88.06950307661488, 90.22175465860676, 87.12919327520555, 83.73171467934885, 84.83242588658487, 83.4812399648851, 79.45692739179059, 80.44872222408172, 80.876142901759, 75.54811293079008, 70.76852444679507, 74.34151341838222, 64.36733791905066, 61.632892854752086, 62.965604412940245, 61.13218269040508, 58.615503695703325, 65.0326228910877, 69.69779583715624, 67.61328358804026, 65.6309804608745, 65.75091085126324, 74.32894614435013, 78.55964599117156, 84.91521143144178, 73.99898852071455, 69.6442868632655, 77.65382951305759, 72.57578788265106, 76.00881884174963, 77.79891798573156, 73.37463348142563, 67.39240707889681, 76.15635487341112, 74.25690004902502, 74.62803471472957, 70.79019946436729, 60.450066827958636, 59.54712544718097, 63.28954512073148, 61.77571027509628, 62.98097618164555, 58.71477888476465, 61.433773732954464, 55.44136877982847, 55.046899933968824, 57.6680394910997, 61.97789669036866, 60.31168168590915, 61.940073274797015, 64.39812068016299, 67.54373212014475, 70.77909915677964, 73.83869694125268, 72.5501512712048, 73.76945926297095, 71.59111607459285, 71.90158736321234, 73.43544590857722, 71.48911091589159, 72.305434596154, 74.94159683104485, 70.42063374673167, 71.35341259741014, 71.52164305410078, 66.37468537976666, 59.54988287341211, 69.08221906231296, 70.6023963805168, 71.3650228131202, 71.23513744723412, 72.56013762566351, 74.50541357840262, 74.9367566262522, 72.60214621020903, 74.8973838744625, 65.55011295503186, 71.86300693019744, 78.98779622970089, 75.19070656068864, 73.2541068907707, 70.26506470095727, 80.40463478334489, 25.144448126516036, 10.278883845575395, 0.5923923189120909, 2.1993335072071325, 6.479756505258623, 3.364425272710862, 0.24866929037436364, 0.651725399638376, 1.4815883050041816, 0.22361144303314148, 3.6681209120058247, 12.613260880593332, 0.29723607784798073, 0.8781070778927497, 7.429974704019486, 56.259583042513945, 52.029691203948, 48.5315175210276, 52.52398829306326, 46.32046176541237, 0.3014622478475494, 0.22243007416686705, 0.1623342609814098, 0.1494725487164913, 0.1292786548935598, 0.2597509667036995, 0.128557107321197, 0.13069786341680636, 0.3381641719850802, 0.13850517270545806, 0.14302280851669852, 0.08886824467129285, 0.1528046481431492, 0.06563550987911802], [0.036385012715454065, 0.038644619691636295, 0.06428839789042551, 0.06999802820745014, 0.0879425346671093, 0.041817388151802366, 0.07967682134720587, 0.03537831189591558, 0.022137564223920627, 0.050977819388912576, 0.046679028084561716, 0.023362782047761065, 0.0346300853115897, 0.18876884493135637, 17.082371211821034, 66.484158731276, 35.59385799592541, 37.05922019097113, 27.28502477369001, 50.31763153691446, 20.707329627006285, 0.24969031703808617, 0.11474219781737174, 0.02567372457574933, 0.09572607990834983, 0.028864394595486023, 0.05754750980544956, 0.21665352606965652, 2.664146875181506, 1.861287588554044, 0.3303245491077823, 0.09168795385067502, 0.05116936435262042, 26.660414780339888, 81.3279293429467, 74.75679828274635, 92.4818321966356, 83.83875616135137, 81.19271739836663, 79.17168478811942, 84.1452423218758, 81.25673047957882, 85.39997716103831, 80.65925936545096, 82.31113418456047, 79.97590403403007, 77.16219179091915, 76.30440865793537, 76.99142748309721, 75.35417525999009, 77.38379001617432, 80.98549073742282, 81.41817523587136, 79.72148341517295, 79.8915103174025, 76.89541570601925, 72.969421263664, 75.41196746210899, 77.63566893915977, 78.57931275521555, 78.3376241499378, 78.51125963272588, 76.43737700677688, 76.78942541922294, 76.3282488238427, 75.86393433232462, 74.3505270250382, 67.03630293569258, 67.71521029933807, 64.8799289426496, 58.26727567180511, 55.71486780720373, 55.885906680937744, 56.084013831230905, 59.141842626756244, 54.99165727246193, 53.92425483272922, 55.19391036802723, 57.171741993196555, 59.40320976318852, 60.33945206672915, 63.900367982925914, 69.93936677132884, 73.3560336020685, 68.35017142757293, 68.31254020813974, 71.27192927945045, 69.61465727898383, 68.05295775013586, 67.28443991753363, 68.62616508237778, 69.44514028487667, 66.55953884124756, 66.93959297672396, 68.39721633541969, 60.27940842413134, 56.87988627341486, 56.907848850373306, 53.0372461195915, 49.61615093292729, 52.72625315573908, 53.95548082167103, 52.003383867202274, 49.710899706809755, 54.395029467921105, 52.35187468990203, 50.93242776009345, 50.378773443160526, 55.651807861943404, 54.83765325238628, 60.05702572484171, 63.68923464129048, 65.01836115314116, 66.70712194135113, 68.51228298679476, 66.04373147410732, 66.34733077018493, 63.46902493507632, 65.65529915594286, 64.16421405730709, 66.63410309822329, 65.99246609595515, 64.85848926728772, 61.54629084371752, 64.90929180575957, 59.85296833899714, 62.954374667136904, 65.04717880679716, 65.68346569615026, 66.07286683974728, 67.21670842939808, 66.96867342918151, 66.37267712623843, 67.19801441315683, 68.22058416181996, 64.47738001423498, 64.6895331721152, 69.34877549448322, 74.66974519914197, 71.48145444931524, 57.61265954663677, 56.2857727081545, 23.46164934096798, 7.963995597054882, 1.2196448253047083, 0.5947897451058511, 3.03028836365669, 1.8808516355291491, 0.21810681018377506, 0.008320709814377611, 0.15463598132614167, 0.17680512560952097, 5.5092895607794485, 4.410444911449186, 0.15095089922749227, 0.5857022875739682, 0.24642060781198166, 37.953261713827814, 27.903972825696393, 26.84800017264582, 29.707511971073767, 36.01341824377737, 0.1648408087391046, 0.06813604384660721, 0.13142728637303078, 0.0909278337513247, 0.04648248439714794, 0.03167531291593707, 0.08541557066623243, 0.0354472904526178, 0.01652393621512719, 0.05967922223311278, 0.01946456854291741, 0.05566522028417357, 0.10644240890659633, 0.04100775195946617, 0.016241740067339232, 0.023822015369190805, 0.02956441509717655, 0.018069003408233968, 0.04073684028680286, 0.04223564151494254, 0.15910091028819162, 0.03159078277437197, 0.07579908345735843, 0.031242061466459307, 0.0907529052346945, 0.007526305365195919, 0.07334305153739068, 0.12153057186233422, 21.941475945134318, 76.83284605703047, 47.985598118074485, 42.57407265324747, 27.896839995538038, 59.254049870275686, 23.735513148769257, 0.3580293528014614, 0.030409040440234448, 0.04757130601172967, 0.0709865727431832, 0.1055547351678533, 0.0368252374802626, 0.40282465878032875, 2.8052082994291863, 3.5004133562887874, 1.416398757888425, 0.6104336282418621, 0.038920729270865845, 34.87419720618956, 86.70013304679625, 77.1317228194206, 93.8304058198006, 90.22959939895138, 86.98205732530164, 84.4438680525749, 87.8411348404423, 85.15925345882293, 86.2452793121338, 84.76074849405597, 87.38500241310366, 84.62697213695895, 79.35776202909409, 78.6561284526702, 80.99002499734202, 79.55708903651085, 80.65090471698393, 83.6244535446167, 86.02320255771761, 82.72566595385152, 83.12015441156204, 81.11663126176404, 77.85583942167221, 80.43868880118094, 81.36807087929019, 82.14429224691084, 82.81811621881302, 79.48859660856186, 80.29538892930555, 79.15619142593877, 80.22790062812068, 76.69085625679263, 74.38620490412559, 69.02325799388271, 70.41712714779761, 69.57910491574195, 60.687487894488925, 59.211174441922104, 58.13274621963502, 59.034032360199966, 61.938272906887924, 60.64535771646808, 59.132052390806145, 59.20280410397438, 62.50016027881254, 61.383249682764855, 63.01265716552735, 67.97460448357367, 72.2290111357166, 75.1863919534991, 70.83727575117543, 71.15834528400053, 71.8949350234001, 72.7285877350838, 70.05973646717688, 70.4453525235576, 69.97444060540968, 72.42897356710127, 67.18232493246755, 68.63852839316093, 71.25653005415394, 63.61263467419533, 57.22261121196132, 59.20443188759589, 57.421141978233095, 52.77716159820557, 55.12931285365936, 57.25430004058346, 54.58500162247689, 53.48737732056649, 57.0384676994816, 55.1918315118359, 55.36925992658062, 53.76431234421269, 59.777768658053496, 58.332638048356586, 63.12174220238963, 64.03046123443112, 68.89876980935374, 67.03931531598492, 70.52612197014594, 69.03015352064564, 71.00008549228792, 65.48685689126292, 68.53391093592491, 64.81294662721696, 70.13824662854596, 70.39207104713687, 67.2012621356595, 65.11270984526604, 65.63629135008782, 62.99750112718152, 64.84804399551885, 68.50736433459868, 68.33714915860084, 69.56300750855478, 72.33746467098113, 70.56493774537118, 70.86739170935847, 70.26817121813374, 69.55728869284354, 68.88084457766625, 65.71692743609029, 70.75623958341538, 76.3877276451357, 71.4177708471975, 59.36719456026631, 60.309602829717825, 24.880892307527606, 7.089399224327457, 0.7602095784198853, 0.49576092992098103, 3.1427174662390067, 3.3785776745888496, 1.0834709194398697, 0.3859182014580696, 0.44031111823935665, 0.0803359633972568, 4.886861385837679, 2.7836026587793907, 0.09967074323926242, 0.9351479009755197, 0.05423721707155628, 40.65018930742818, 35.71359619017571, 28.833454924245036, 40.05912734616188, 43.82248855406239, 0.5071762528630995, 0.05333021110404403, 0.05961687799783484, 0.017484064634528854, 0.03302403177405077, 0.05851743074374334, 0.11137953148253503, 0.02445304007720082, 0.0408241858014897, 0.03389015928992341, 0.09022173051151539, 0.03471738486100109, 0.07502642249868763, 0.05857422467200987, 0.14096074497267125, 0.1063971943973053, 0.18397990674261125, 0.16481111517115948, 0.21210863285007017, 0.2165998692714399, 0.23201908946277636, 0.13097733229158387, 0.2431394532322884, 0.13622097430690644, 0.1883025884988808, 0.08357734269192142, 0.19610444324151163, 0.37685072349925197, 26.590645620899817, 93.45859650642642, 51.756054893616714, 58.8863786574333, 48.608854893715154, 72.4375557130383, 29.8480014647207, 0.5529954200310092, 0.19565137884309217, 0.16421811715249093, 0.23285286891604626, 0.2269661420535657, 0.2888878032324776, 0.863928935460506, 8.082625231435223, 15.303524367270933, 4.897335094790305, 1.1029320041979513, 0.20839934237301352, 36.46580088523127, 99.23360409275179, 82.10697481709143, 100.28853339533653, 94.22689468629899, 91.69304355498284, 88.59395534761491, 93.34752282788678, 89.39541324492424, 91.74766648200251, 87.77721589611423, 90.43226826575496, 88.31574163129254, 84.24086970667686, 84.00949693495228, 85.39845528141146, 82.59954606333088, 85.55079229416387, 86.07335398274084, 90.89402537192069, 85.24469052591633, 88.43273024405204, 85.81564641767933, 81.86313675295922, 82.32693349161457, 83.75584510064895, 84.62368519075456, 88.74713174758419, 84.64816078062981, 82.80617652400848, 83.38944081337222, 83.51966350309311, 83.45462276089577, 82.00480491884294, 72.0960977000575, 76.22716149976178, 74.27160893717121, 64.79104803454491, 64.20274349950975, 61.57767372746622, 62.09596003255537, 67.2628511921052, 62.98377675394859, 63.87360957361037, 66.02818319874426, 66.53081140210553, 65.30530214309692, 66.44040076963364, 70.00534103762719, 76.84685676328598, 76.64632166585615, 70.55152323938185, 73.75300099772792, 76.88071466261341, 77.61175032584899, 71.61863542372181, 73.24412053631198, 73.92137265974476, 74.66766634295064, 69.8559065788023, 70.2242563616845, 73.06297763701409, 66.09871525918284, 62.64971633111278, 62.832620374618045, 62.7968797376079, 56.42273402983143, 59.57985370389877, 62.017128236832164, 58.00627723816903, 56.047735829507154, 59.66669497951385, 58.191887717093195, 56.6479447580153, 57.793535724762954, 63.88017562127883, 59.25177881794592, 67.55597775982272, 67.91438041194793, 73.15051709451984, 71.47283307967648, 72.88561590256231, 70.11866615664574, 74.25750409403156, 68.23163740096554, 71.808776240195, 69.5855297580842, 73.37646915066627, 71.47458245677333, 69.40956438741377, 68.1926804204141, 70.14784074598744, 65.25928881860548, 66.82783680577433, 70.57743441674018, 72.87529222426876, 71.54895059524044, 75.82911937467514, 71.83260071662166, 73.3587557269681, 74.20166523225846, 73.63155657245268, 70.25405853025376, 68.89625164770311, 74.50648046308949, 83.94258129981257, 74.05957345039614, 65.09266261131533, 71.86499949424498, 31.658551846781087, 11.113961358224193, 3.3554173044620024, 1.8031174905838507, 11.820547907583176, 4.3497521165878545, 0.2744177200140492, 0.14920328413286518, 0.47246266396776326, 0.19815264059410942, 7.239713764959767, 6.923221638125758, 0.19009187877658876, 2.7701535869029263, 0.236113814096297, 49.730119320654104, 44.20921071883171, 37.51770996278332, 46.36682810321931, 55.27373060103386, 0.5673711518606832, 0.21076958776722032, 0.2361658927533896, 0.25008515875426035, 0.1518929422262215, 0.19899401963958818, 0.26051346933649433, 0.1815058870781814, 0.12176395288758701, 0.1787437111019127, 0.13020269482606842, 0.12274973184591341, 0.27406970159180705, 0.28194119372675497], [0.0150906355045135, 0.05888625611400893, 0.06252370286552657, 0.04159290523779008, 0.06728953201203577, 0.11759496369068662, 0.068560280356436, 0.019671065627687404, 0.04974529883193393, 0.08650385984970678, 0.08341968945798375, 0.05594157501153889, 0.020924645941704515, 0.126532283311169, 38.62105700277513, 53.77807986351752, 44.28590874518118, 30.42762775574961, 15.007831588868173, 46.782093355732584, 2.927049619536246, 1.7928390421213645, 0.44989484752858844, 0.021082214905970523, 0.13087533534534518, 0.08245172970477613, 0.020129982937848376, 1.4420574326669018, 1.252222315919015, 0.8560194147209969, 0.8512246849075441, 0.2582902208931985, 3.279628287399969, 52.617172041246974, 72.99585019388508, 81.49059003399265, 85.46719874105146, 82.47315945163851, 85.09483245111282, 79.17340278625488, 75.38012566105013, 80.77612246236494, 82.5823268582744, 79.21296381181287, 83.38514189566337, 81.05506573953937, 75.55157246128206, 77.06404624446746, 76.10809403081095, 76.61982997771233, 77.6242156182566, 83.45892167860463, 79.01092252423688, 80.62889237557688, 81.25323172538512, 75.32998992550758, 75.17074169651156, 79.11248053273847, 77.74424014552947, 81.67942862356864, 77.04340673262074, 74.72876902549498, 75.18330897054365, 76.3769175929408, 76.18420370163457, 74.66782323775753, 69.03449166205623, 66.50174663912865, 62.21934210869574, 60.57835578918458, 56.33532793291154, 55.76989473835115, 55.34035598078082, 55.89985855164067, 56.0713053518726, 55.223520340458045, 57.28960921687465, 54.2887959941741, 55.29693142060311, 58.687918493824625, 59.59488814876926, 63.372330665588386, 70.14530689485612, 72.74733666450747, 74.84407886382073, 68.66891891725602, 68.89971902293544, 68.31679990214687, 67.96552027425459, 68.78884146290441, 68.7149283193773, 70.63382241033739, 67.65991272464876, 70.93975159429735, 71.05874061584473, 60.56621213113109, 56.63594230528801, 53.87308751383136, 52.59235128279656, 52.72734357464699, 49.09999447484171, 51.60319228326121, 50.29524264797088, 51.27163433259534, 51.19028045285133, 52.65331276001469, 51.576433873945675, 50.48550898028959, 52.51035805671446, 54.38263085580642, 55.681915975386104, 62.18080482175274, 64.24576013318955, 63.069186364450765, 65.54666519165039, 67.40652761151715, 68.48236314712032, 64.03719986638716, 63.46729516983033, 63.95905056307393, 65.09070534859934, 66.40058871238463, 63.41177402004119, 66.07154107862904, 61.24985379557456, 61.4918444233556, 62.61125356920304, 64.2220611726084, 64.14047195065406, 70.26184835741597, 70.91209103984218, 67.72194893129411, 63.76530116604221, 69.02768242743709, 66.35119822717482, 66.9941923695226, 63.91779115123134, 71.27662827891689, 68.36021269521406, 74.1065477555798, 52.18324415145382, 24.301779846991263, 4.765336061677625, 3.579567521810532, 2.264331103332581, 0.02985782485695616, 3.0766931897209537, 3.487491352904228, 1.93994851602662, 0.36821381759739696, 0.0658758316609648, 0.04363267562322078, 3.026539558364499, 1.155327024959749, 0.616140615555548, 0.7639703346836952, 0.43409664364111045, 28.324852951111335, 33.17277892943352, 28.65772293459985, 33.63736798686366, 32.74049255155748, 1.4303790657751023, 0.17114157548114178, 0.14677909082703053, 0.008856603639170287, 0.06335287813037153, 0.074287653269787, 0.061393255863579056, 0.05665536594366836, 0.1327301261405791, 0.012329985000824016, 0.12611340941681018, 0.05820225068037549, 0.1458249283173392, 0.011229441283390889, 0.016760033022071567, 0.03020260847293802, 0.0423525580235066, 0.021791259923409072, 0.08984564262772761, 0.037184253094657775, 0.045647119141874776, 0.025530115648683523, 0.032928822366821195, 0.07373260724688731, 0.0877326725411319, 0.06435799697834639, 0.03096816396611112, 0.047586784818239754, 46.301324521341634, 63.376060839622255, 53.80477159254013, 29.534839430162986, 21.39128508106355, 55.479992358915275, 2.4035921596711685, 2.3732614517211914, 0.5453421403804134, 0.03221421555105237, 0.22354038071728524, 0.05653106817795385, 0.16109899016878299, 0.6564130610035313, 1.145416666423121, 2.107188451674677, 0.9750632268767204, 0.16010572653143637, 4.822160909252783, 62.02526323256954, 76.95596141199913, 85.76630300091159, 89.57322212957567, 85.14998882047593, 86.03376157822149, 84.07376889259585, 78.62428665161133, 85.8529560027584, 86.9635437380883, 83.91839596533006, 85.90425275987195, 84.5476382778537, 78.66784849474507, 81.799100137526, 79.19851380009806, 80.75050154039937, 80.18358568991385, 83.04858684539795, 83.39364559419694, 82.9169991708571, 82.03568966157975, 79.13201393619661, 77.83188158465971, 81.72958789333221, 80.69264658035772, 83.29642572710591, 81.02466737070392, 79.30713991965018, 79.33953869727351, 79.07675558520903, 79.11870925657212, 74.99716112690588, 72.0072481709142, 72.28707790374756, 65.11184692382812, 62.2700426655431, 58.1665962742221, 58.855788092459406, 59.3217029110078, 57.7716528215716, 58.8704106884618, 58.7644596253672, 59.73365768309563, 60.52696489518689, 61.574222041714584, 59.74663680599582, 60.95499746261105, 66.46900269293016, 70.89600932213568, 75.79756782900903, 77.16405099438083, 72.22401403611707, 72.36606659427767, 72.70291974467617, 70.26730045195549, 71.93797126893075, 71.38591335665795, 72.96527139602169, 67.6853375281057, 73.09144619972476, 71.07433595964986, 63.30929817691926, 58.56319104471515, 57.435031091013265, 57.25623769144858, 55.14007583741219, 53.5686880542386, 55.07626671944895, 54.470370354190955, 53.71852651719124, 53.68882633024647, 55.31300137119909, 54.04740548902943, 54.129763495537546, 56.04317803536692, 58.552875211161954, 58.6006457574906, 63.382014997543834, 65.63714250441521, 66.43172448681247, 68.64794208157447, 69.96512105388027, 71.17881221155967, 68.19299421002789, 66.32455748896446, 65.65633466166835, 66.00798299235683, 70.33394152118315, 67.63458205807594, 68.83668653426632, 63.69738924887873, 63.74121781318419, 64.95573659096995, 67.35465034361809, 67.69675162530714, 72.30168481026926, 72.03209246358564, 70.45400527215773, 64.98534656340077, 71.62276960188343, 67.06725043635215, 71.43420557821952, 67.95259998690698, 73.39195466810658, 68.94042538058373, 78.01703314627372, 55.867883389995946, 27.84012644521652, 4.604881703853607, 4.715345453831458, 3.5016493931893384, 0.20550199784338477, 1.5053247732500878, 3.886541036828872, 4.831731492473233, 2.4392759223138136, 1.1314119662969344, 0.09119889098069361, 2.6888379502680997, 0.5865209597733714, 0.724514477675961, 0.423898205401436, 0.1712210800859236, 30.270419159243186, 35.93293120784145, 26.323720485933368, 43.00385852013865, 44.238852070223906, 2.497397848675328, 0.21149646731153612, 0.052950652841959274, 0.05963996788787265, 0.07838797800603413, 0.10677204887953498, 0.04277273426733671, 0.08194053455466226, 0.08423651538548932, 0.0673379487688503, 0.11930907776038494, 0.05675155211300139, 0.019124348895744454, 0.0053036439367720204, 0.1630898841446446, 0.06180803884842223, 0.20952503196895125, 0.1877133902763167, 0.17938989094428479, 0.16944657530515425, 0.11686774706768414, 0.14262710878204915, 0.12876513083615612, 0.23421918672900047, 0.18879165902974146, 0.1164638884966412, 0.2787550034061555, 0.1937168536166991, 56.58739905203543, 73.9815967313705, 61.50839682548278, 47.519177313773866, 31.078986352489842, 67.9152197991648, 4.42863098075313, 3.669172597508277, 0.7086271011540968, 0.14700087328110972, 0.3462391064292, 0.2803712650652855, 0.2649348385391697, 3.0521827888104225, 4.515225147047351, 4.68917687093058, 2.4989037936733616, 0.2860279050805877, 6.878176158474338, 70.40594839280652, 86.32598600079938, 91.15342740089663, 97.18667599462695, 90.2758284538023, 93.75107980543568, 87.35833029593192, 82.94974311705559, 89.57582658337009, 92.28168149148264, 87.71624657415575, 90.79333028485699, 88.28954019854146, 82.70474403135239, 85.48857565849059, 83.86408682792418, 85.23781068863408, 83.44946876648935, 86.71379073973625, 87.38210770391649, 87.26440521978563, 89.0902763797391, 82.31424070173695, 82.48294184284826, 85.68663181797152, 84.22664719243204, 87.53257766846689, 85.2148255994243, 82.1120503640944, 80.73419232522288, 84.34255323102398, 82.67098026890909, 80.15238715756325, 75.83375561621882, 74.56318224630049, 69.7173684643161, 66.41070058268886, 62.12376571470692, 63.24943496334938, 63.22936027280746, 62.52716579744893, 63.91211155922183, 64.04871594521308, 65.59740497219947, 63.965349889570675, 63.81797467508624, 64.99704307125461, 66.38004333742204, 70.97294269069549, 73.80412517055389, 79.51282116674608, 83.84048984896752, 76.67590418169576, 76.12513280683949, 77.44202152375253, 73.79035765124907, 77.06877662289527, 74.02402893189462, 75.1973275215395, 69.34183289927822, 76.01929941485005, 77.11509981463033, 66.04528473269555, 60.88815243013444, 62.50370610144831, 62.5683428395179, 60.44369297642862, 58.1966337850017, 59.01995497365152, 57.61512671747516, 57.21357014871413, 55.91065683672505, 58.264090707225186, 57.843687149786184, 58.94863059443813, 58.94367271854032, 61.214736815421816, 61.309654251221694, 67.94953269343223, 69.8238294355331, 68.5331735303325, 70.81563995730492, 74.22511316114857, 74.0812563127087, 70.27921661253899, 69.61903464409613, 67.12330895085489, 69.83865599478446, 72.92283135075724, 69.69433630666425, 71.45499414013278, 66.28494939496441, 66.71698277996433, 68.83521956782188, 71.49359026262837, 71.73639282103508, 75.03833816897485, 77.11553127534928, 73.11731815338135, 69.06427029640444, 74.77867726356753, 71.28591645148494, 74.80167804225799, 70.19920810576409, 74.962997282705, 73.9916144647906, 80.19054397459954, 63.70099782943726, 41.18987998654766, 13.578177671278677, 7.776236149572558, 6.040431434108365, 0.5029862115700399, 8.799284427396714, 8.743090591123028, 5.6311566214407645, 0.761747453962603, 0.4281990230083466, 0.15830853022634983, 5.887377608206965, 1.6638136558955716, 1.004240941857138, 1.4944343124666524, 0.48438222598164316, 41.661670515614176, 47.685089649692664, 45.071520266994355, 51.07965000214116, 53.754467195080174, 2.537207699591114, 0.4493553684123101, 0.23648810933434197, 0.16450840318875928, 0.1615446694796124, 0.2463513228201097, 0.13600427867664447, 0.17487050845257698, 0.2409007757781975, 0.07431482640846122, 0.21713121253396236, 0.1735249209788538, 0.22719878763441118, 0.09258282115502704], [0.04681070327698704, 0.04080753105001585, 0.13159064696200434, 0.019817045596878857, 0.05531629404774117, 0.06812426907521102, 0.04262875187240782, 0.06301831987295901, 0.054595999029134555, 0.05530637320912173, 0.01605403128891222, 0.10667366020741964, 0.11461147257397253, 2.2900853858840082, 56.59542422140799, 47.11677351305562, 36.098776863467315, 25.580070480223625, 31.368100335521085, 39.89575670611474, 0.6783503870810232, 5.970428403346769, 2.47860822466112, 0.17762827176240184, 0.14088482565937505, 0.11062629851362399, 0.18657015726691295, 0.48265696533264657, 1.2804927989359827, 1.7807707671196231, 0.5481072887778282, 0.4744044517076785, 20.839313460934548, 65.910904330592, 68.21184512107604, 80.89290711187547, 82.78755311043032, 84.40448745604485, 83.82128592460387, 80.88520357685705, 78.53261301594397, 76.99660501172467, 78.78169136662638, 75.32181570606848, 81.24197452299057, 79.42342250577866, 71.49132313266878, 76.28895451945644, 72.88207007992652, 74.46509945777156, 74.35275493129608, 79.86209254111014, 77.75946678653841, 77.78328341822471, 76.32412249042143, 73.37340185719152, 75.69058910492929, 80.17945935649257, 76.52458698518815, 79.69748635445872, 76.94391973557012, 73.87024064217844, 73.50460513945549, 75.5288697827247, 74.28376828470539, 70.44560355524864, 65.78267812728882, 65.2343935351218, 60.834321821889574, 58.59595068039433, 57.145713144733065, 55.179001439002256, 54.43702236298592, 53.237141870683246, 57.67135389389531, 51.81087786151517, 54.16686911736765, 55.14279796231178, 54.45629296764251, 58.80748018141716, 55.352840885039306, 61.49662579259565, 70.03501769035094, 73.92221204696163, 69.31383502098822, 62.67358787598149, 63.2898824445663, 64.83573952028829, 66.48571198986423, 62.012150749083496, 63.762092667241255, 69.541410938386, 67.72520449853712, 69.09817526417395, 64.25012180882116, 60.81933052309098, 53.91421748745827, 52.70141670780798, 53.78366139627273, 48.304702543443256, 51.68041982958394, 49.95506332766626, 49.41583548822711, 51.510510598459554, 54.678871785440755, 49.499421196599165, 52.38395575554141, 50.366547415333415, 50.35836142878379, 52.190653508709325, 55.74643504235053, 58.13249911031416, 59.69995667857509, 63.32441891393354, 63.980364722590295, 64.62746166413831, 63.15626690464636, 66.10738369726366, 62.98234116646552, 62.597168337914255, 64.12544535052392, 63.78394419147123, 66.24841643917945, 66.62960021726548, 67.39758460752427, 61.11729729560114, 62.87611945982903, 61.23799254817348, 62.488593209174375, 67.31534034975114, 66.21958701841294, 65.20330090676585, 64.42015655579107, 67.57785674064391, 68.08338749793269, 67.5382564913842, 64.37389219960859, 72.361202855264, 67.3839504488053, 72.55073962673065, 48.89592924425679, 8.20270271070542, 0.9620230008036861, 1.1509642461615226, 0.7269416280811833, 0.41775071753128884, 0.6591712226790767, 4.187022784063894, 8.95582720156639, 3.4118670753894316, 0.41896119773868595, 0.5933677020572847, 2.160351276397705, 0.2359403717902399, 0.16345366865636843, 0.1367935024562382, 0.5788678026968433, 23.042773546711093, 31.578215822096798, 28.74624102346359, 27.14534328829858, 40.39567062931676, 5.826812780672505, 0.5058914314835302, 0.21209694234834564, 0.09519630712607215, 0.0461639067338359, 0.08369909704572732, 0.2832120110190684, 0.09704555910561355, 0.11472705991998797, 0.04800665845733978, 0.17063977256897958, 0.013641194278945126, 0.03673670069885351, 0.01812942667804178, 0.08748372460925773, 0.02430381955608966, 0.20553152287198653, 0.06737933283851993, 0.07684405802959397, 0.14665037273399292, 0.043113750645950924, 0.0677292894632105, 0.0061237515934232266, 0.055191341276851394, 0.0027071869032712836, 0.040360051432564374, 0.20884794813971366, 3.204344520645757, 65.17830756402785, 59.26428725642543, 52.841002095130186, 25.80614216866032, 36.80923969514909, 45.117961129834576, 0.7042007677016721, 7.1666346153905325, 3.3113578106126482, 0.2561293473286975, 0.32067999243736267, 0.1103775650863686, 0.37846474818164305, 0.30896387273265474, 0.4288602488175516, 0.9878385703890555, 0.6604152268940403, 0.8998002977140489, 24.878742848673177, 74.96307573010846, 74.53626694217806, 83.27848480593774, 87.61155066951629, 87.3059666541315, 88.85096473078575, 85.34020023961222, 84.8236083984375, 82.21149029270296, 83.30445874121882, 80.14789212134578, 84.2275885612734, 83.2553114429597, 75.41892574679467, 80.24918340867566, 77.51979427952921, 78.10304287941226, 80.77854648713144, 82.01410093615132, 82.01059433721727, 83.16388883898335, 79.2151132706673, 76.45491784618747, 79.59282967352098, 84.05643201643421, 80.98402377097838, 80.67305826371717, 81.73236493141421, 76.83072797713741, 76.91404696433776, 78.88579107099964, 77.90624972312682, 72.79426390124907, 69.09207205618583, 67.10348529200401, 65.09044647216797, 62.096305201130534, 60.49698621995988, 58.855984210968025, 58.88095009711481, 56.725756737493704, 60.71128099195419, 58.22012093759353, 57.14544250119118, 58.39942816765078, 57.9671908194019, 63.55593289098432, 57.532694185933764, 62.73844034441056, 70.48565095470798, 75.2960692682574, 69.52420742281022, 65.49056353107576, 64.79098527662217, 68.084760327493, 69.75198730345696, 64.82124636250158, 65.66685053610033, 70.2997306085402, 71.40726673987605, 71.41027127542804, 67.94641048677506, 65.09705566590833, 55.72756059708134, 54.14953224120602, 56.991783649690696, 51.964521023534964, 53.975159352825536, 53.68413517552038, 52.85125909313079, 55.43596375373102, 55.87450827321699, 53.73657726472425, 54.16063254879367, 53.34451283178022, 54.14158944160708, 53.97012695189446, 57.453270112314534, 60.90829380096928, 61.27687500369165, 66.20904368738975, 66.17560155930059, 68.5693613175423, 66.31487707937917, 69.21222994404455, 65.80482382928172, 65.20565432886924, 68.05621331737888, 66.46979501170497, 70.02903215346798, 66.36037657337805, 69.3437470159223, 64.18270803266957, 64.43031941690754, 65.77840666617116, 65.54286441495343, 70.53440601594987, 68.55047118279242, 68.71779164960309, 65.84955846109699, 69.79423907495314, 68.14917349046277, 70.951534394295, 65.62106078670871, 74.08018158328149, 71.19944387866606, 74.80168588699834, 55.69366739642236, 12.039776040661721, 2.001912649120054, 0.8076824536246638, 2.6239928362830995, 0.9655186293586608, 1.2355420690390373, 3.0768701866749795, 5.6144551692470435, 4.840287652707869, 0.8460475852893246, 0.517133986276965, 2.656702461742586, 0.24893642523356024, 0.23243622433754707, 0.19156900354691092, 0.870825013806743, 25.422732445501513, 36.07202629889212, 26.64892419692009, 35.51218640419745, 54.52116897029262, 7.722532528062021, 0.5777252898100884, 0.2832930631214573, 0.07241285225797085, 0.2384324558079243, 0.022562940289536794, 0.13550163306776555, 0.0176852201712468, 0.049411648388711676, 0.021447991246297475, 0.10677167349645209, 0.039888834580779076, 0.03735225234601287, 0.03214726712734949, 0.27877964079380035, 0.14660570980800738, 0.20288717121847216, 0.2751942573776168, 0.25561801428275727, 0.19317139901461142, 0.23912904423571404, 0.14244663378884717, 0.1603069165421109, 0.2042275952595857, 0.133350963794416, 0.36337584978149784, 0.33385281300833153, 3.7970872175308967, 77.23982334136963, 68.11616282309255, 50.31033985076412, 44.20786534586261, 48.88439747595018, 53.43572362776726, 0.7531951548111054, 9.904787790390754, 5.136955140098449, 0.25030157859286956, 0.420545406279064, 0.3128541284991849, 0.7572164422562047, 0.97428206234209, 1.9454257382500557, 2.4593895914093142, 2.5953693399506235, 2.092355518571792, 27.068143198567054, 83.47521520430043, 83.34995039047735, 90.83558205635318, 93.5850380313012, 94.03513785331481, 92.83827366367464, 91.01353214633082, 88.83514973425096, 87.45588748685776, 87.47604062480312, 83.50085181574669, 88.36463789786063, 84.61358116519067, 79.18889614843553, 85.53589513224941, 81.85547244164252, 82.13293306289181, 80.53888966960292, 86.05730364399572, 85.47622803718814, 87.64625580080094, 84.01021080632364, 80.69381544666906, 82.89463381613456, 87.66791512889247, 84.64434823682232, 88.44583880516791, 88.45598989917387, 79.79150556748914, 79.92759612298782, 84.11715815144201, 82.00635033269083, 78.72530337302916, 72.73417319020918, 71.53359059364566, 69.74239318601548, 66.87234001774942, 64.71234175466722, 63.44854624040666, 61.596399122668856, 60.374941672048266, 64.88127039324853, 61.91311482460269, 62.57499910170033, 65.190557126076, 62.59188098292198, 67.97396905960576, 62.094395006856615, 66.41135954087781, 74.3759596732355, 78.3752396798903, 73.54842585902061, 68.0591001818257, 69.80058546989196, 70.71606666811051, 73.75073386776832, 67.24741274310698, 69.19830552993282, 73.6643240528722, 74.84948388991818, 74.14544982294883, 71.32851339155629, 66.13260453747165, 59.485622682879054, 58.99177274396343, 61.69199120613837, 56.27077356461556, 59.59692778125886, 57.39756461112731, 55.99507800994381, 57.65314232918524, 60.440892404125584, 54.002058967467285, 58.27257087153774, 56.11135667370212, 55.35420586985927, 58.033482797684215, 63.873350697179, 66.16296368260538, 66.21372699737549, 69.89352210875481, 67.64689045567667, 73.12116992089057, 68.91620082239952, 70.52735359438005, 67.27831317532447, 67.65403701413062, 71.4163823281565, 69.85210187973516, 70.82492812987297, 70.18531507061374, 72.74338291537377, 68.79035549779093, 68.44299824007096, 68.54908266375142, 67.86046351155927, 74.03505079207882, 72.13026154425837, 72.03697973682036, 70.36051950147076, 73.62900703184067, 72.2879643594065, 74.9636640856343, 67.84833554298648, 78.59696342099097, 72.6207382448258, 77.12144620956914, 62.19238365850141, 24.979051582274902, 4.282557502869637, 2.2245624373036046, 3.063136252664751, 1.2281910570398455, 4.211153205363981, 9.258910705966334, 19.419813579128636, 8.283530992846336, 0.593627191358997, 0.665765830105351, 6.0932338910718125, 0.3019732897800784, 0.6184120968945566, 0.2577357877406382, 0.884831491256914, 31.374085872404038, 46.67855455029396, 47.250742066291075, 43.03759090362057, 63.74885859027986, 9.800957748966834, 0.7099140062928201, 0.49657436207898203, 0.3242127302913897, 0.31400626345026883, 0.21479446050380507, 0.31071677383395935, 0.2504048012797871, 0.16234218233054684, 0.17755817471733018, 0.28621669978864733, 0.09712872561067344, 0.16063331596312985, 0.10703284819159778], [0.005726366944145412, 0.05684839328750969, 0.04102036942757907, 0.07523983161175445, 0.09020860742537246, 0.09939762523337718, 0.041381752253660274, 0.06965384788570866, 0.009637547923522371, 0.07157100589885827, 0.056127542855157975, 0.005055953825508515, 0.15481074130342853, 7.1735796620768895, 62.847972531472486, 34.119980335235596, 40.65857533485659, 21.511490037364347, 48.30095667992869, 15.931666454961224, 0.7463351745278605, 0.9775917460360836, 1.270833104368179, 0.0389626725847202, 0.10628930623492888, 0.04737491554190074, 0.13492112228226277, 0.4839002953902368, 0.48095140846506246, 1.7973349363573137, 0.6126530156020196, 6.006161195616569, 38.54659472742389, 70.72414675066548, 57.95310558811311, 81.89121307865267, 79.96509398183515, 81.94361594415481, 83.14426914338144, 77.79914548320156, 77.89354908850886, 78.41907608893611, 78.42652074752316, 78.91915475168537, 80.53404946481028, 76.30027447977375, 71.16576640836655, 73.88705976547735, 74.57465125668433, 75.38649559020996, 78.70805278901132, 72.50746019424932, 79.23239523364653, 73.87850115376135, 74.95522314502348, 73.26694088597452, 78.05266395691903, 78.8524587692753, 78.62580853123819, 74.86864074583977, 74.49978105483517, 73.46601686170025, 77.57266782945203, 72.05430876824164, 71.28015056733163, 67.18416844644855, 67.17686499318769, 61.48737292135916, 56.354288670324514, 54.06318518423266, 54.13856137183405, 52.688378749355195, 55.3040740566869, 54.74700335533389, 55.19659719159527, 56.85917223653486, 52.92162249165197, 54.77108278582173, 53.717773422118164, 57.5731965803331, 55.494238407381125, 56.15932726090955, 61.79540449573148, 61.55594771908176, 55.569779334529755, 58.40266020067277, 59.84142480358001, 63.816233142729736, 66.33666192331623, 62.145115175554835, 62.01600251659271, 63.32793727997811, 67.18961269624772, 72.5235419119558, 68.11155796051025, 59.16536508067962, 52.928200306430945, 52.33829936673565, 48.7209483884996, 47.0903524275749, 51.67641116726784, 50.7153598723873, 50.50231241410779, 53.057830718255815, 51.831074145532426, 50.15542191843833, 50.071596945485766, 48.978110744107155, 51.559198979408514, 51.117273376834014, 53.138356977893466, 52.61147675975677, 59.24003131927983, 60.24567996301959, 63.74530884527392, 66.89388951947613, 64.82538446303337, 63.415621865180235, 65.9726659713253, 62.11325376264511, 63.5902379405114, 64.26257533411827, 66.17234599205756, 64.5567334851911, 64.83156611842494, 63.4709115951292, 58.799164756651855, 62.21089332334457, 59.72300844807779, 66.284439486842, 64.95288502785468, 66.73730065745693, 65.2247601939786, 68.3884459157144, 64.2328594576928, 65.95956525494977, 64.93509315675306, 70.9973398331673, 67.65923023223877, 72.62347605920607, 53.070288165923095, 3.347370071757225, 0.07588802626536739, 0.6695352278409467, 1.1990733420656574, 0.923643344111981, 0.143506225318678, 3.0990953166638655, 6.6962350568463735, 12.122618459886121, 3.383609094927388, 0.8252038650455014, 0.3794546563538813, 0.1430647594914321, 0.1589889388771788, 0.5028599909236354, 0.4262771841979796, 14.056092981369266, 39.44609226719026, 17.768854633454357, 24.207068335625436, 42.525125395867136, 8.842446188772879, 0.7785540134195359, 0.4063072638405908, 0.16296545614398297, 0.17224602911981846, 0.037850462305810184, 0.14631988240345833, 0.02110524159375458, 0.08077903800914366, 0.0658996876389269, 0.02725282522489227, 0.08170855547031088, 0.0727340116375877, 0.09203201925922787, 0.072367706696593, 0.058186350525507045, 0.059345656059562206, 0.021963993598136212, 0.04310653792814382, 0.06541964162381426, 0.014258109562609707, 0.044152221131709316, 0.026392280574767824, 0.05018678381137791, 0.10690969189689045, 0.031040781440453667, 0.3176221371658387, 9.317478556786815, 70.12828380830827, 45.13146585033786, 41.79579988602669, 21.999103407705984, 58.97869163943876, 16.446621687181537, 0.6814277929163749, 1.7694217567482304, 2.24942609667778, 0.04111780048978906, 0.15434856045871012, 0.4782775471047048, 0.5222685526936285, 0.4461098522428544, 0.5995995515296536, 0.4515452767091413, 0.9615954011678697, 7.690369582945301, 44.22067580684539, 78.34773602024202, 64.70197100793162, 88.55174279982045, 85.4545137959142, 88.13180600443195, 85.62770212850263, 81.48159211681735, 82.40269799386301, 85.02968972729099, 80.94501972198486, 81.9263182916949, 82.72537569845878, 79.16232601288827, 73.51770585583103, 75.96483338263728, 79.52235252626481, 79.40004517955165, 82.21690316354075, 77.54458365901824, 81.17737308625253, 77.91297266560217, 77.78077310131442, 76.4049703844132, 83.70220276617235, 81.44233703613281, 79.92305401832827, 78.74501720551523, 77.53672322919293, 77.85377625496157, 77.8721486368487, 73.78351703766855, 74.23593890282416, 70.09927395851382, 69.87180786748087, 64.07752967649891, 60.58145053925053, 57.88853945270662, 56.24037911815029, 56.065739508598085, 57.51924437861289, 58.13551933534684, 57.980373905551055, 61.75758108015984, 57.325440068398755, 59.6391442514235, 56.486237202921224, 60.3919529914856, 57.6877337117349, 59.23346527161137, 60.61634002193328, 62.24966987486809, 58.268405314414736, 61.99666915401336, 62.73029358156266, 68.36443316551947, 68.35412517670663, 64.40509465432936, 65.3140490285812, 61.794600409846154, 66.70199932590609, 73.47274764891594, 68.7013412291004, 60.74456622523647, 54.932853098838564, 55.755440804266165, 52.69585086453346, 50.59102466029506, 54.98592276727, 54.8580534996525, 52.95208754078035, 54.918516835858746, 53.34946678530786, 53.72364521026612, 54.27737405223232, 52.42504650546659, 56.484519204785755, 55.21161986935524, 56.78545521151636, 57.95447841767342, 61.21865134085379, 62.75384349207725, 65.29713576839816, 69.44988635278517, 68.52070039318454, 65.94128700994676, 67.28008608664236, 65.63219639562791, 66.61919024682814, 65.04324466951432, 69.22098467426916, 68.9838146394299, 65.7991442372722, 68.03111014827606, 62.11785078048707, 63.45755984706264, 62.839464910568736, 67.32247121872442, 66.11114917262908, 70.6474095006143, 65.94810408930626, 70.39837037363361, 68.5023437007781, 70.80420232588246, 68.64865595294584, 72.51136687494093, 68.43897388827416, 75.4628013795422, 59.94203359849992, 13.603361248970034, 1.1368894336685058, 0.4823589264865845, 2.648908712210194, 1.7505242675542834, 1.5639738906775753, 2.8491748821350837, 3.229811979878334, 7.809821934469285, 2.2393397217796696, 0.27461270471253707, 0.6716477919009425, 0.19689841676623593, 0.20142938250735884, 0.4241963974650829, 0.5354444069727775, 15.01941042561685, 42.127683393416866, 23.60472171537338, 30.44197382465486, 51.46183006225094, 11.580620446512777, 0.6190328732613595, 0.4058902668616464, 0.1527824009498281, 0.21263778510112918, 0.03205879163297434, 0.12769606279870196, 0.044537988536420374, 0.060058144642220396, 0.053439432259408705, 0.06666959068107028, 0.05143969379846127, 0.032445187229783304, 0.04969643774412332, 0.18074891560019987, 0.20752540459075283, 0.21134318843964608, 0.20826451089834014, 0.15459384649030625, 0.2292254579163367, 0.13597046355566672, 0.1336228790422601, 0.16592045645079306, 0.26092795354704706, 0.21299355633316502, 0.16157975630654445, 0.5236923730661792, 10.431012972708672, 86.14423121175459, 51.37445142192226, 54.48826028454689, 36.343650433325, 68.22578522466844, 23.8828864020686, 1.1721823076086662, 3.9316343203667676, 2.467938152051741, 0.12704062861420456, 0.3136711765921885, 0.25419119084554337, 0.24526116438210013, 0.9857044945801459, 0.8161054984215768, 3.9065848387056783, 3.2323441149726992, 9.351864995494966, 48.43137941052837, 90.39894380877095, 71.18062434657928, 93.12048819757278, 89.52256079643004, 93.59488318043371, 87.96914531338601, 86.6875030148414, 84.69532335958174, 89.1732031299222, 84.55100367146154, 87.22525996546592, 85.80442059424617, 83.22115544349917, 76.52155107067478, 80.07492819140035, 81.42450594132947, 83.55458044236707, 83.80081115230438, 79.91303628490817, 84.99827154221074, 82.79579008779218, 82.35791237123551, 79.62075694914788, 86.9258576054727, 83.66090020825787, 85.29731304414811, 82.55379553764098, 82.6903881565217, 81.75321625125024, 84.33840336338167, 78.52987520156368, 79.28104831326392, 74.68486201378607, 75.4102651534542, 70.10009765625, 64.50047492980957, 61.77128191917174, 60.63950554017098, 58.86212664265787, 61.95728463511314, 62.75825615852111, 64.1101598739624, 66.9909054233182, 60.893475086458274, 62.7716745868806, 60.82471985970775, 63.76492461850567, 60.840805499784416, 62.07865061298494, 67.49715789671868, 68.0588020816926, 62.009785559869584, 65.3409839445545, 66.70545101165771, 71.11428137748473, 73.51977686728202, 68.06629380872174, 70.27655724556216, 66.40014156218498, 71.70711625006892, 79.70213044074275, 72.03026463908535, 66.45045772675546, 58.52847806869015, 60.06256411152502, 56.904852159561656, 53.704743308405725, 58.09522090419647, 59.788610089209776, 56.44493464500674, 58.21783419578307, 58.71475927291378, 57.82973135671308, 57.19391907415083, 55.29557035815332, 58.133746424028956, 58.36818256685811, 59.05120841918453, 60.80343315678259, 64.74849031817529, 67.0989667215655, 69.4189388521256, 73.00993934754403, 71.13175945897257, 68.03952755466585, 69.59413543824228, 67.62525466180617, 68.50751338466522, 69.60300783957206, 73.42109787848689, 71.17037911568919, 70.54839318798435, 69.15312767028809, 65.60376705661898, 67.54993730975737, 67.59511516940209, 72.30469719056161, 68.81468203759962, 74.84527126435312, 70.18350293559413, 73.30581941912251, 70.23238351268154, 73.632246909603, 71.80141787375175, 74.5882305022209, 71.44918903227776, 78.50902388172766, 65.25518209703507, 28.994750630471017, 1.9178865321220893, 0.9523891080771724, 2.800370546117906, 2.7212480047056755, 0.9958619624376298, 6.655499771718056, 9.39263116928839, 25.7015541292006, 5.958110690116883, 0.9547185669502906, 1.940233868456656, 0.42208686711326726, 0.5032170491833841, 0.6994394393217179, 0.6864542490051639, 21.471293587838453, 56.2568687623547, 30.14458952411529, 37.44242398969589, 62.8112748361403, 13.554729742388572, 1.2043453752994537, 0.5761877819895744, 0.22969911475816082, 0.23510280786262405, 0.31819244366019006, 0.2456266036437404, 0.16360777490321668, 0.1635867994158499, 0.17405116209580054, 0.22883518208419124, 0.18092208211460423, 0.165410517684875, 0.20689849952055564], [0.04696160344587219, 0.04240257207364325, 0.015556825861905613, 0.017810858590828798, 0.029045539915621765, 0.055808762178546, 0.010530389882924577, 0.03273922709688064, 0.0540728873813585, 0.06556267023927743, 0.0030966602583160445, 0.10895704655277152, 0.08706442170566128, 14.218401639692246, 55.719962966057565, 34.955531474082704, 58.3101079540868, 23.997898140261253, 59.20030163180444, 4.225964075134647, 0.21901440986942863, 0.10234199990067752, 1.2901391329303866, 0.11661876083141375, 0.019306622280348695, 0.23011395136915871, 0.1459241673470505, 0.2387685692238231, 0.5081782652245415, 1.259565360603794, 1.0069376939246732, 17.1862728365006, 47.5670616088375, 67.46482187701811, 57.89155183299896, 79.88386954030683, 75.14526982461253, 80.04252156903668, 82.62390398210096, 76.70284302003923, 78.74899448886995, 80.23035603184854, 77.828155332996, 76.86418579470727, 78.0919582613053, 72.71019966371598, 71.99361401219522, 74.70532894134521, 74.42239269133538, 76.69637110925491, 77.40544149952551, 75.19997119903564, 76.90654739256829, 74.63859373523344, 74.30765551905479, 77.04892158508301, 79.4962138514365, 77.05591124873008, 74.38663636484455, 77.07366389612999, 76.2217878526257, 73.00247115473594, 73.43272378367763, 68.9268304455665, 68.7749719619751, 68.97887245301278, 63.2661089589519, 57.021181814132206, 56.43650547150643, 55.67845644489412, 56.53207402075491, 56.26612947833154, 53.964463049365634, 54.498219182414395, 54.12317783601823, 54.28368514583957, 51.32704565601965, 52.8174953306875, 51.87121960424608, 51.13158218322262, 56.516098207043065, 53.99944666893252, 55.78059104181106, 52.5754850910556, 53.48635750432169, 60.170899975684385, 67.01571049228792, 65.33051121619441, 68.08224216584237, 61.20882972594231, 57.18584291396603, 55.11304286218459, 58.21130737181633, 62.21003432427684, 55.99876896027596, 50.79457213801723, 55.03764314036216, 51.881759012899096, 46.638381634989095, 46.23396173600228, 51.14159991664272, 48.65477015895229, 51.79100713422222, 51.26241676269039, 52.05999935826948, 50.04134762671686, 48.64513681780908, 50.20663238340809, 52.18431888088104, 50.98674081986951, 51.51171084373228, 52.47250326218144, 55.55848290843349, 57.95778105335852, 60.83862073959843, 62.45211908894201, 66.2836628575479, 63.37093430180704, 65.9581296674667, 63.26961555788594, 59.999319814866595, 61.481658028018096, 63.620695144899436, 67.56023745382986, 64.65864842937839, 66.25247216993763, 62.14897478780439, 60.85982507274997, 60.9557270234631, 61.92656855429373, 62.35858232744279, 66.3518964090655, 63.97104517106087, 64.29760602212721, 64.75876692802676, 69.9393432371078, 66.8250362334713, 71.52988787620299, 67.22744787892988, 71.81444014272383, 56.69224400674143, 5.909319346950901, 0.6450104857644727, 1.0613134503364563, 1.6604233797519439, 0.3013683561115496, 0.21021040486952952, 0.368856871801038, 2.929721979364272, 3.9536557322548287, 1.990875834899564, 0.13800320125395252, 0.09838316394316574, 0.051808308494547685, 0.03092555224054283, 0.10979188320737694, 0.04465197092823444, 5.147947582506365, 38.27214648646694, 26.20095422191005, 23.216958161323305, 45.099243579372285, 10.615948803963201, 0.38866787487941407, 0.13658655146437307, 0.056225575296388525, 0.11028832350406917, 0.11260068329471735, 0.13247478903541643, 0.07808804692279908, 0.07098055129209835, 0.06607623260107733, 0.08924188873460216, 0.05456859606408304, 0.10211758976501804, 0.05186213000166801, 0.0640959642647255, 0.04644883398507391, 0.05308944499120117, 0.02831490654047699, 0.03146467704115616, 0.09301063529546223, 0.07284217559161686, 0.0855088112274966, 0.04655761847032174, 0.09459233106744867, 0.04234266782840414, 0.03853591947606014, 0.18884822696207032, 18.844923550082793, 66.24154444663756, 50.176159489539366, 60.83618494772143, 27.21295710532896, 70.63082571952575, 4.1609924647115895, 0.1774383585659727, 0.19483263003489665, 0.5085946799766633, 0.4005713796904011, 0.07124514273938633, 0.537616971039003, 1.7314766251271771, 0.8768915108615353, 0.6669899773213172, 1.3859328507415711, 4.129481613636017, 19.03644504085664, 54.3963905303709, 75.98027967637586, 64.46861743927002, 82.12860276622158, 80.53967414363738, 85.45812237647273, 85.85815706560689, 85.32200828675302, 82.77569186302924, 83.15284344457811, 80.44989893513342, 83.2489493585402, 81.87381344456827, 76.0489054649107, 74.72830618581465, 78.64676967743905, 79.38668558674475, 81.84700796681066, 80.65842782297443, 78.68101196904337, 80.21399190348964, 77.55770006487447, 77.01169044740739, 80.19173637513192, 82.35713574194139, 80.00278795919111, 78.26395419336136, 81.60716287551388, 78.53584504896595, 76.73259812016641, 76.55256132925712, 71.88261878105902, 70.74069915279266, 70.82852886569115, 66.47959309239542, 61.41338917516894, 61.476970795662176, 58.668844007676654, 59.738337070711204, 59.81708649666079, 57.037714604408514, 58.25160972533688, 57.15225173581032, 59.31133216427219, 57.02799889349169, 55.63591441800518, 55.72248505007837, 55.421196030032256, 60.80061297262869, 58.32907653624012, 58.24375321788173, 57.35662291126867, 57.17555061463387, 66.29295103011593, 69.75780810079267, 70.10604396943124, 71.03107221664922, 65.5277515226795, 59.44113123801447, 55.32154429343439, 60.00412079595751, 62.48917764233005, 56.10926997277045, 53.964674857354936, 58.885045051574714, 52.65668207599271, 49.03638932012743, 49.9706704385819, 54.49266902862057, 52.09501827916792, 55.4125472038023, 54.54458552022135, 53.717702819455056, 53.62033390229749, 51.443618497540875, 53.13245381078413, 53.30688161234702, 54.81139298408262, 54.57030450144122, 56.37397504621937, 57.710667810132435, 61.09010742556665, 62.69345468090427, 64.79470368354552, 68.33370531758955, 67.1708010089013, 66.91093614024501, 66.81457134985155, 61.75650242836245, 63.61389375502064, 65.14130392382222, 70.26709648870653, 67.01553790800034, 68.41169772609588, 65.95342282325991, 63.099474906921394, 62.85796280830138, 64.4008820287643, 65.52600999032298, 68.71546960646107, 67.401334393409, 67.50101750896823, 67.47403944692304, 71.05792476284888, 71.08514601184477, 71.0002737660562, 69.24529552459717, 73.98928457690825, 60.96247350015948, 24.428511627258796, 2.2639187641682166, 0.9193134764509817, 1.5498895174072636, 1.794885906480974, 1.3160538649366749, 2.408447563648224, 1.9329372793436053, 3.6795852645750973, 1.452341274388375, 0.4145133218938305, 0.41593809221540734, 0.0778652838761768, 0.18657127575528237, 0.14396460636729194, 0.1991467928934482, 5.2403007688060885, 41.25305760291315, 30.751213489040254, 25.620374794929262, 55.799975395202644, 13.728055357933046, 0.49457475002254214, 0.16560449114730283, 0.025908911653283625, 0.05297168195548077, 0.08289630584899457, 0.1560884227435435, 0.1322585990231845, 0.059810736547074014, 0.042511866007360725, 0.13875355373226828, 0.046832816404921394, 0.1812206419004548, 0.0526724441818172, 0.1239516931555925, 0.13103411472853155, 0.19603756376572196, 0.11552244304649292, 0.11834995866182352, 0.20107543456458277, 0.1568238211855773, 0.1800786499534884, 0.14845987241114342, 0.21101067563699138, 0.14146999425945744, 0.2640231939092759, 0.1886859848614662, 21.43947728218571, 81.19424712273383, 49.78193775300057, 79.046890658717, 41.53920235172395, 82.43674416695872, 6.549847789349095, 0.5169332712408036, 0.5536655937471698, 1.5602101313491024, 0.24369054624149877, 0.12750903775374736, 1.231996736699535, 0.9755985078311736, 0.5171808095708971, 2.3355630616987906, 7.972077640794939, 6.473606228828431, 24.666677944121826, 54.97956852759085, 82.64251955093877, 71.42359948927357, 88.00101849340624, 82.68426141431256, 88.93655084794568, 89.60432652504214, 89.97116227303782, 86.746244430542, 88.96890255712694, 85.41965176982265, 87.12302730929467, 84.23089119695848, 80.8272466351909, 77.9142278240573, 82.43261783353745, 81.22291964869346, 85.81541892020934, 84.39787433993432, 82.86290184144052, 83.79662206096035, 81.6371690073321, 80.20160505848547, 86.916349780175, 85.63348370213663, 84.69959089832922, 82.73799788567328, 85.15723736055436, 82.73180054080102, 80.2592089868361, 80.7679953113679, 76.07447147369385, 74.9534345442249, 75.80942907641011, 70.14833496462914, 64.15069364732312, 65.01391710773592, 62.906302098305, 62.57559137959635, 65.03392119561472, 61.15571691143898, 62.20474696928456, 61.00835346406507, 63.33466022245346, 59.240199981197236, 61.39919411751532, 60.26672347899407, 58.799576605519945, 64.49015125151604, 59.54618015596944, 62.04830323496173, 57.30472995388893, 57.98371184256769, 68.21717169977003, 74.55456087666174, 70.03544130632955, 75.65103592411165, 66.14193193374142, 60.79726719087171, 59.99146330741144, 66.33848974781652, 69.85908369864188, 61.185566148450306, 56.49115193274714, 62.049075941885675, 58.61535072326661, 52.50347037469187, 52.39241630800309, 57.85932563966321, 54.556729178274836, 57.85881180917063, 57.806746267503314, 58.789292150928134, 56.35488094822053, 55.035309330109634, 55.4375680031315, 56.6751346280498, 57.56881137048045, 57.84683681303456, 59.14951478281329, 61.161965247123476, 64.71247511525308, 67.19955982700472, 69.05234629108061, 71.79827997761389, 68.685102616587, 70.05688882643177, 70.12104311297017, 65.22299512740105, 66.34810739947905, 68.6472438996838, 74.34687922077795, 68.57687657879245, 71.60233405328566, 68.29187716207197, 67.87240320636381, 68.26859397272911, 68.28406380068871, 69.84105648532991, 73.97293613803002, 72.27114523610761, 69.35032875307145, 69.52981641215663, 75.48140910363968, 73.31691188196983, 74.99860455912929, 70.3965425491333, 77.50297515623032, 65.02806901931763, 35.99181382886825, 2.724052989675153, 1.8618546161920795, 3.3559529531386594, 2.9068888819986776, 1.0532565342803155, 3.5773908515130324, 5.420695475993618, 13.312983282150762, 5.718011135055173, 0.49560881550273594, 0.2647393635444103, 0.2804276184929956, 0.5064433212241819, 0.23462040229670464, 0.389770980203344, 8.550738538465193, 54.510001982412035, 42.17932139673541, 37.90642861397036, 64.37153093276486, 15.817098925190589, 0.7799370779145149, 0.3724669232483833, 0.12475212480151847, 0.1507256080907199, 0.18928348747712953, 0.3364239266562847, 0.24072249179645894, 0.13454083623664995, 0.15998352018575515, 0.2038738005343945, 0.1183153238267668, 0.37768058058234955, 0.16130401061907892], [0.058017903112716256, 0.06549951395079975, 0.05361313886579968, 0.05745500851903231, 0.033369418684273, 0.17088132009150522, 0.17532956365856434, 0.059930395650407, 0.09056814014911653, 0.16233225383104818, 0.13050582049594772, 0.2503000617387795, 0.31909759186448594, 22.242572769041985, 54.22589686609084, 27.433470795231482, 30.46012067025708, 23.618936384877852, 55.59185443385955, 0.4333988601161588, 0.035593597924396876, 0.705194169234845, 0.053526785434974786, 1.890161626281277, 0.04910284217687384, 3.1565526464293083, 4.963069115915607, 0.3501058892617303, 0.31809456826698396, 0.10624002379875992, 2.706595745778853, 9.427199017617012, 40.35583896021689, 65.14223744792324, 63.75023141984017, 71.69848703568982, 77.93231779529204, 77.41563181723319, 75.90031823804303, 77.0986415493873, 77.80899847707441, 79.78446099065965, 78.06607846290835, 78.6577444691812, 74.63282785108014, 73.13564346682641, 73.68720716045749, 72.7707375249555, 76.19181309976886, 76.4010872379426, 76.74524384160196, 73.25864899543025, 77.01430274594215, 73.60272715168615, 74.228196144104, 74.52700230383104, 80.24699472611951, 75.30375711379513, 75.81110785084387, 76.5604688275245, 74.67646814161732, 73.9714377926242, 70.77566316050869, 68.31556043317242, 69.28480948171308, 64.20454386741885, 57.59885672600039, 58.45253705978394, 55.237229024210286, 52.618776290647446, 53.312216035781375, 54.85809272335422, 52.5153826129052, 52.97062466221472, 52.69548216173726, 54.97408505408995, 56.46242057123492, 51.820397453923384, 50.46432818135908, 52.78856785066667, 57.20629807441466, 58.63975963284893, 61.77270573954429, 59.29163009889665, 61.75953049813548, 67.60018287166473, 68.72448321311705, 69.28615877705236, 69.51964178392964, 67.44408822828724, 61.37723276692053, 54.19083872149068, 53.56683669551727, 50.478884097068544, 51.667856477922015, 53.99745410488498, 56.07658878449471, 49.61001634597779, 46.8654868679662, 48.585822736063314, 50.29153208578787, 52.31306675941714, 51.38448876719321, 48.648376695571415, 51.948066680662095, 50.95783295169954, 52.08700879927605, 51.261165526605424, 49.20260760091966, 50.73781151925364, 51.03079688164496, 51.72123993596723, 52.02632581034015, 55.238103712758715, 58.14844746743479, 60.29792593371484, 63.474900645594445, 65.98101277505198, 64.60559837279781, 64.3148801403661, 61.52905594918036, 61.45105177356351, 60.47103974127001, 64.63886399422923, 65.132353075089, 64.30486632931617, 62.93462553331929, 58.85246192255328, 58.888077043717914, 62.213148686193655, 61.71922814461493, 67.08699564779958, 66.89804723185878, 63.287348593434984, 64.33406837524907, 67.25270794283959, 68.37163463715585, 69.09218188255065, 68.29169673304405, 70.74863018528109, 56.03305832032235, 13.373406414062748, 3.4604586228247616, 2.1048274299790783, 2.2203262775175037, 0.6636067491865928, 1.9925108503910804, 0.2273399469953391, 1.2905073454303126, 3.9287704998447053, 1.110885835463001, 0.13058924747090186, 0.052433417088562445, 0.1444148055968746, 0.09987329688644218, 0.09585678216911132, 0.06478490713503092, 0.9464257571005052, 25.834045910066177, 41.574923376883234, 18.813260216866773, 40.245761563701016, 20.224138729033932, 0.3020519210446266, 0.19449300793630464, 0.02715238918279929, 0.05457769718862349, 0.07247996922101706, 0.0650117687520481, 0.019655226759852904, 0.07957518446229159, 0.0376455414469444, 0.047433712790089275, 0.10961744498701827, 0.0650790619153169, 0.06026522969947227, 0.04384001348948768, 0.013054176534135497, 0.09354892697545791, 0.02221686390018271, 0.04529384535647208, 0.08433489639672541, 0.12288034217612398, 0.03633502164795514, 0.16161315774004306, 0.05237038720459227, 0.08258549631723473, 0.06863380181452922, 0.16310220283846702, 28.577055469635997, 63.62588051826724, 44.06161192924746, 29.859831333160404, 27.734061633386922, 61.81023889972318, 0.5097748231022589, 0.09449048733879482, 0.8150538742061585, 0.21055534361831604, 1.7959986338692329, 0.1578470235390048, 1.8547161476266, 6.440939259144568, 0.15454380562709225, 0.37735327717758, 0.1395831350237131, 5.430682320748606, 19.016386039795417, 44.60667233313284, 73.13763603087395, 66.65275004602248, 77.82857110423427, 83.01596841504498, 82.66897201538086, 80.98380411824873, 81.92582407305318, 81.72381416443856, 82.31343269348145, 82.44662069505262, 81.07030022528865, 78.43278085031818, 75.88429927825928, 77.6271495511455, 78.26620563384026, 80.01444524334323, 81.10702145484187, 79.45833160031226, 77.99065128449472, 80.24851660574637, 78.04165778621551, 75.66510938828992, 77.93938590634254, 81.61191678816273, 78.16513399924003, 79.54368237526187, 81.15978517839986, 79.46343852627662, 74.65437735280683, 72.80232829432335, 70.29133673637145, 71.4082081087174, 65.89403813885104, 59.16666338520666, 59.73062176858226, 58.661658225520966, 57.15396973394579, 56.68780780607655, 57.75750875473023, 56.20735276129938, 55.49414819286716, 56.371880500547356, 58.27970566288118, 58.196951496985655, 55.21787997215025, 53.724676793621434, 54.48594608614522, 59.51082391123618, 63.30177114855859, 64.80607855704524, 63.19376868586387, 65.11678911024525, 69.16989972514492, 72.49762288985714, 72.95414755421301, 73.36478833229312, 70.45970839838829, 65.18479516429286, 58.926547650367986, 55.6104229342553, 52.58906825896233, 56.85251597435244, 59.459613446266424, 57.500601353183875, 51.26304041954779, 50.852760499523534, 51.5621054557062, 53.712870459402765, 55.86150169372559, 55.59259183945195, 52.150661022432395, 55.69865272891138, 53.61683907047395, 54.94934274304298, 52.94782392440304, 52.025615861338956, 52.97238972879226, 54.139483128824544, 54.377967157671534, 54.40922844794489, 57.51395702362061, 58.587137114617136, 64.68666591951924, 67.42667290472215, 68.83994994624969, 67.88354273765319, 67.20230548612534, 65.24372093139156, 64.0708145787639, 64.09372906531057, 67.51654225011026, 67.65348003756615, 64.76712157649379, 66.40150654700496, 63.63652190854473, 62.307226734776656, 64.53226181768602, 65.19477759638141, 67.58177911081623, 67.99580097198486, 65.54251924637826, 68.51153773646202, 68.15005994612171, 71.68696311212355, 71.23067378997803, 71.94691427292364, 72.3837721732355, 60.30289165435299, 29.627115149651807, 3.3420731559876478, 3.1510762822243477, 1.6591037473370953, 1.223672976897609, 1.7501799569975947, 1.8620281810722046, 1.5546726026842672, 1.868747078603314, 0.459975982385297, 0.49980388233257883, 0.1865873176364168, 0.10303170119802799, 0.0796824980587248, 0.04860547874423285, 0.0503919574792587, 0.8911905726117473, 29.52379599694283, 41.64627521268783, 22.888869547074844, 50.69583823603969, 27.31846494059409, 0.45011468411933997, 0.17362376164284446, 0.01859297690492484, 0.04894967821817245, 0.03722940248647525, 0.03861432857511025, 0.045012476583642345, 0.08436904859638984, 0.1420213477385621, 0.013827156376904778, 0.03161210683174431, 0.05467125567637625, 0.09208787472978716, 0.2604344090627086, 0.18289860428100635, 0.15718526146825285, 0.1301021994121613, 0.17785451284820036, 0.29436854946036495, 0.22891759782308535, 0.12854331773855995, 0.19514637368340648, 0.28782291037421076, 0.2708542467125001, 0.345147829502821, 0.37673577966709293, 36.67176846534976, 76.49498093512751, 42.38270413491034, 47.072152629975356, 38.45255198017244, 72.31732722251647, 1.0165656418088944, 0.1725980618427838, 0.9700461477041246, 0.30753563969366016, 3.0346024805499665, 0.2576387703659073, 9.711558107406864, 9.294522885353336, 0.45924289752879455, 1.2908728613007454, 0.40678769289966554, 7.493802943537313, 29.799417026581306, 63.38266611099244, 84.3921947479248, 75.85374401461694, 79.65451286685082, 87.5272197108115, 87.42081365277691, 85.53467919749599, 87.4225159614317, 86.082485260502, 86.25703073317005, 87.2957214232414, 85.6391554494058, 84.23246014502742, 81.33000819913804, 82.139083339322, 82.18239415076472, 85.50758346434563, 83.1998569734635, 83.8113780175486, 81.9890683697116, 83.25229121792702, 83.45850590736636, 82.16308040003624, 81.58474260760893, 86.54315194775982, 82.38163486603769, 82.23345556566792, 84.56702263124528, 84.32513006271856, 79.33954654201385, 77.39511782123198, 72.63518825654062, 77.70528316497803, 72.06932360126127, 61.808344394929954, 63.8760571325979, 63.02128637990644, 61.12820932942053, 60.14003484479843, 61.76968943688178, 60.20126696555846, 59.13860667136408, 59.80142055019256, 64.01242225400864, 62.078207385155466, 59.602058241444254, 58.6381200821169, 59.36905376372799, 63.27577367905648, 65.39476356198712, 68.90606541787425, 64.53146165417087, 67.34376968876009, 74.62873289662024, 76.07995494719475, 76.56918433404739, 75.98383334375198, 74.8930771120133, 68.78401694759246, 58.57638197560465, 56.96263259457004, 55.162856963373, 59.81899669093471, 61.92709022952665, 62.4309108334203, 56.519734244192804, 55.577427956365774, 55.16255886323991, 56.06407642364503, 59.988890232578406, 59.30080060035952, 54.885870948914565, 60.36421398962698, 57.282101800364835, 58.220677914157996, 56.13449473534861, 54.49701893714167, 56.03881635973531, 58.24444747740223, 57.823663450056515, 57.23705730130596, 61.41745275066745, 63.488911351849964, 67.28087840541717, 68.62651025095295, 70.05860682456725, 69.08090899067541, 66.8671703338623, 67.78644054166733, 67.90539818425333, 66.82009404705417, 70.72926936611053, 71.62597810068439, 67.32286345574164, 69.78627666350334, 66.42184011397823, 66.91485066567698, 67.69934823436122, 70.84890950110652, 71.12035320651147, 71.36718796145531, 68.58545872472948, 70.03641405413228, 71.25006598810997, 73.42948390591529, 74.00714705067297, 71.67143837098153, 74.87249251334899, 62.63110860701531, 41.233261400653475, 5.750792834066576, 4.114236341368768, 3.7509022893444186, 2.5103051431717414, 4.667053232269903, 2.5052295961687645, 3.77627095387828, 8.925294491552538, 1.6786973346625607, 0.3046520541031515, 0.1847419803661685, 0.20806457727186142, 0.25351352478948336, 0.33168631635846635, 0.19398032657561765, 2.4679440356069997, 39.39320302778675, 60.25497205795781, 35.98868377747075, 54.78971404414023, 30.575395207251276, 0.7652042265380583, 0.3053287242449099, 0.3174011667649592, 0.16218654390785003, 0.17003531387496382, 0.17056029860771474, 0.1479045352748325, 0.1372294984157047, 0.18827716970155317, 0.12004412380197357, 0.21165852555103842, 0.14319439688997884, 0.23766885000851848], [0.052488452845042756, 0.09577340115943263, 0.22055662146979765, 0.08306243201537479, 0.027170491840450034, 0.18074232724405107, 0.011400232925229977, 0.047414978109900995, 0.05706279448443844, 0.11520692207399877, 0.23463371690482865, 0.026505219171785062, 0.9276832628153986, 59.97824099756057, 38.59689912488384, 45.890899473621005, 30.068411211813654, 36.64961099624634, 44.88879273014684, 0.2511566246469175, 0.06514009614024432, 0.1604412883640297, 0.22268015590886917, 0.29211101092157826, 1.4104834559463686, 0.4773133488432054, 5.436268266170256, 1.0578477911410793, 0.08139494971762742, 0.10564263609628524, 1.9658802858283444, 13.227371669584706, 23.767362794568463, 51.012208769398356, 60.37965636099539, 71.29554979262814, 72.76333993481052, 75.706584530492, 78.93762911519697, 74.23320108844389, 76.65899092151274, 78.10819687381868, 75.12075501103556, 77.51377736368488, 71.78222963886877, 71.24686533404936, 72.04441655066707, 75.55637344237297, 77.08953380584717, 73.96360874176025, 73.48900195091002, 75.07833065525179, 74.70884338501962, 73.89829343365085, 73.61795379269508, 75.45654912148753, 75.28586326106903, 75.68003792916575, 75.99993859567951, 72.04760935998732, 74.01255992151076, 73.57572555541992, 68.65825791512766, 67.03287478416198, 64.83507663972917, 58.98357499030329, 57.5305211928583, 55.09104228788807, 56.538471406505955, 56.98698266859978, 53.803096740476555, 53.53742284159507, 54.469781998665106, 51.27064197294174, 53.577183908031834, 53.43531570126934, 54.33171456859958, 50.38351166632868, 49.79849799986809, 50.865414065699426, 54.35717467338809, 61.230571423807454, 57.5795155186807, 56.920490649438676, 66.87514059005245, 67.19722993912237, 70.47628433473649, 70.03169936518516, 69.76305623208323, 67.83497595017957, 67.18364284884545, 59.52545827434909, 58.83376006157168, 56.08276259514594, 58.31890583038331, 58.13301294080673, 52.62017657679897, 48.34624828830842, 46.07008511020292, 46.899776228012584, 49.575887803108465, 51.705334724918494, 52.23729441242834, 50.129365613383634, 49.06179843410369, 49.157355216241655, 48.06433577691355, 50.54276774006505, 51.72721762810984, 51.183271177353404, 50.09232667184646, 50.02712511247205, 49.149832110251154, 52.453597437950876, 55.77763357470113, 57.96317823471562, 64.16126835730769, 64.57636494790354, 65.11550257282873, 63.24880738412181, 63.45689696650352, 61.44082615452429, 62.30633635674754, 63.75100804913429, 65.47860814679053, 65.44041210605253, 63.001239145955736, 60.20977066409204, 59.27649367240168, 59.33734140088482, 59.24935479317943, 61.198227559366536, 64.29575858577606, 63.655302216929776, 65.52684937753986, 64.8323662819401, 68.5915070195352, 65.38817790246779, 69.25918855974751, 66.35791332490983, 57.03987190800329, 29.81242752844288, 3.110668760153555, 3.681295417970227, 2.339646003900036, 2.6903191353044202, 1.6418128364509152, 0.38440370691880105, 2.0842315545005183, 2.601242598987395, 0.20994080320721675, 0.12862081519298016, 0.5766772202426388, 0.12182527822592568, 0.06918434324043413, 0.019306344573476145, 0.07095595986972894, 0.2281857540290202, 12.724964099545634, 46.38054070934173, 20.638807781281013, 26.33829405230861, 32.596714150521066, 0.15531272807669255, 0.07508180299473387, 0.08528329026434692, 0.07763639978703953, 0.06836974662878821, 0.06534320137072956, 0.07375241061972995, 0.029706307987291968, 0.07633991854926271, 0.02968860369536185, 0.028806790529239564, 0.07825543713425437, 0.08351537383972638, 0.07143236696720123, 0.012071978079245217, 0.07035802824482804, 0.04807534590063076, 0.04404539783154765, 0.23230562166821575, 0.11249857909616925, 0.0826653456615825, 0.061378669549500754, 0.11025056303028138, 0.16082016480786188, 0.1504362107164437, 2.444003358963997, 70.70581359248008, 53.12094949906873, 55.11875775552566, 21.44122469809748, 44.9007285025812, 48.85988266237321, 0.2080637498969032, 0.06300417405943717, 0.12280816137189828, 0.3333718936529852, 0.0813374241753932, 1.6899730457413582, 0.7715674141241659, 3.1456984675699666, 1.702707265653918, 0.1515712006197822, 0.15278987796796908, 6.201453555014826, 23.431133301027362, 35.866046951663115, 59.34198940953901, 70.16691130976524, 73.42868374240014, 77.54113981800695, 77.37226609260806, 83.29590012950283, 78.23904714276715, 83.90642489156416, 82.87197036127891, 80.73394129353186, 79.55519845408779, 75.42348354093491, 75.1580410618936, 75.30087809408866, 78.68840955918836, 79.99590027716853, 74.4853545773414, 76.83098685356879, 79.52439215875442, 77.4871366254745, 74.72248538847893, 77.21785806840467, 77.73437146217593, 78.64185102524297, 80.01220949234502, 79.63250052544379, 76.51357296974429, 76.92935205275013, 75.35610506611486, 72.91148001147856, 70.44691362688619, 68.50319093273532, 62.84607018193891, 60.805492401123054, 59.54753337367889, 61.07857173488986, 59.00712882318805, 58.13176170472176, 55.93048834031629, 58.88200521469117, 55.757739313187145, 57.59713480549475, 57.11870762609667, 58.66757315974082, 54.676820385840635, 52.20902196822628, 56.10670082030758, 57.315210526989354, 63.66513952132195, 60.544756766288515, 56.15338879246866, 69.91446756547498, 69.97557809275966, 75.29248422191989, 72.30158282864478, 74.15809554438438, 70.84350447500907, 70.66034547744259, 63.298135111408854, 60.649727236840036, 58.907367260225364, 60.78337023335119, 61.6443814769868, 55.514568051984234, 51.477111616442286, 49.53040399859029, 50.90142142388129, 51.01391107805314, 53.178863294662975, 53.92767121714931, 52.734427375178186, 54.379700845287694, 52.01959502312445, 51.741934360996375, 53.13590549653577, 53.18691984299691, 52.70400939449188, 53.37677824881769, 53.161036122229795, 53.01375112225933, 57.05554569921186, 57.23074228532853, 59.85962460117956, 65.98797105973767, 66.04774013642343, 68.09548408754411, 68.79749421150454, 67.31857238277313, 63.571277203098425, 64.14977973507297, 63.98491467199018, 68.33076353996032, 65.29864195854434, 64.14671244159823, 63.16544917321975, 64.01883925161054, 60.93565233292119, 62.37398547510948, 63.19621624485139, 69.96937290314706, 64.85163688659668, 70.11079788208008, 68.35304260253906, 68.01928027983635, 66.98186043770083, 71.19842406242125, 68.21280217939808, 58.81323822083012, 41.88417873074932, 14.827432959310471, 6.2913984060287484, 4.226650489914802, 3.776993895730665, 1.4633512448879982, 0.6067774276579581, 3.478855519525467, 1.6457756560656334, 0.6800419092178346, 1.7160689422199804, 0.4736846048505076, 0.042079095278055444, 0.0143807046979125, 0.19053101569654482, 0.021542842507422454, 0.20362877497269263, 13.649831529586548, 51.3147254913084, 23.34923617301449, 32.5738839949331, 41.00437148924797, 0.2163952625086231, 0.1025624723444062, 0.11434352566157618, 0.02922023094499544, 0.029790987516002312, 0.13695094884643633, 0.03099829803461269, 0.023698500928378875, 0.05680058557059496, 0.10197450752340018, 0.09391936113036449, 0.09716398097694882, 0.050082657140709703, 0.12747560567673177, 0.13468824687504, 0.3309217299665174, 0.11061216419142102, 0.11980878925251386, 0.419171994491931, 0.23676983050761685, 0.20461969438099092, 0.1920768891971919, 0.22429277098947958, 0.38935759915940227, 0.2556216455395183, 3.5601032501266854, 84.59129425787157, 53.332937917401715, 66.1653406389298, 51.93804502487183, 56.113714018175685, 62.00290964495752, 0.4192849158519699, 0.20278474526299586, 0.34046880960945164, 0.4835735435687727, 0.5319631195837452, 1.9383404668300384, 1.0006963449620432, 18.09454275715736, 3.2528995410088575, 0.21392708043417624, 0.3754415507278135, 9.46386141161765, 40.8775887181682, 53.991684298361506, 73.07607050864928, 78.2069621547576, 78.93103953330748, 83.55295658111572, 83.24899642698227, 90.07653282534692, 82.13756145969515, 89.18152639942785, 86.1687695595526, 84.49612971275084, 83.154388858426, 80.87841787645894, 78.903167170863, 80.81096095423545, 81.6639901745704, 84.67367187623056, 79.24127547971665, 80.03630853468373, 81.16482150170111, 82.42571446203416, 77.8360471417827, 81.6628997556625, 80.44908308213758, 82.4236277611025, 81.62659429734754, 83.1690820570915, 77.86570026028541, 78.76506051709576, 78.04967511084773, 76.79161410177909, 74.00024367916969, 72.94157243544056, 65.71448772184311, 65.7998541862734, 63.07230072636759, 66.37699957816832, 64.06805715253277, 62.021195734700854, 59.94747392592892, 62.35499335873512, 58.8634680932568, 63.980451014734086, 60.39644802770307, 63.43592013082197, 57.801149045267415, 56.432516421041186, 58.366013496152824, 62.13614863734092, 66.66294036373016, 64.07350140233194, 62.26968965222759, 72.28923520734234, 71.74823837895548, 77.90062504429972, 75.21227175189604, 76.22949138764413, 76.11381284652218, 75.0104187380883, 65.00239710653982, 62.60803722566175, 61.33347872764834, 66.44844947322723, 64.8360925336038, 59.97160826959918, 52.93959479178152, 52.83485966344034, 52.582051138724054, 55.50969254586005, 55.7728482830909, 57.99908753364318, 55.92395759397938, 57.82781331769882, 55.112646702797186, 56.738390691818736, 56.64653662712344, 57.19207556016984, 56.7859729643791, 57.12062566511093, 55.07081854727961, 56.40245537604056, 59.62272520988219, 62.06518511618338, 63.97757199502761, 69.81876957801082, 71.11589739399572, 70.75484321963403, 70.77994638873686, 69.1921317192816, 65.64213175927439, 68.8665279265373, 67.81073570251465, 70.16361651882049, 70.02454496199086, 67.42634342562768, 64.84213298366916, 68.24271417433216, 65.85759147520989, 68.26680537193053, 67.32143571299892, 72.65067377398091, 69.59004048378237, 73.82504709305303, 70.94055960255285, 72.00221184761294, 71.06649906404557, 72.18250751495361, 70.88755269204417, 62.5712061697437, 55.577337741851814, 22.959762465569284, 7.311899594722256, 5.823666549498036, 5.361923661924178, 2.9870214337302796, 1.1158590331192941, 5.538266070427434, 5.507868191888256, 1.862748426295096, 1.0083783682315581, 0.8106766929549556, 0.369070855480048, 0.23216651542292488, 0.37461837393141567, 0.1608699298794231, 0.4987399087798211, 21.36087102274741, 68.7950623419977, 35.92107388281053, 40.02556362459737, 49.65883416514243, 0.33944663381384266, 0.18172155615062485, 0.1911645397664078, 0.1158852163221567, 0.198126471030616, 0.24163022937793888, 0.16631217252823616, 0.07652580212321013, 0.17357672384429365, 0.25435337165911354, 0.254389071356385, 0.3120128107407401, 0.14000408501634676], [0.036233465202272906, 0.010295583934132612, 0.12778989324766782, 0.07772207139961182, 0.04835838474513543, 0.20594044528420896, 0.16679324510116733, 0.14163648048716207, 0.29698265596262874, 0.3808954225913171, 0.17183300047632188, 0.42241150453206033, 26.45591808903602, 78.42092744765743, 29.06488064796694, 36.26153953613774, 17.20071892584524, 42.883579038804584, 26.273518070097893, 0.20971275415391694, 0.04738063821869512, 0.19019291045204287, 0.10125482154469337, 0.019410394635351918, 0.931985306162988, 0.266260048074107, 3.529346229568605, 1.0149488898534929, 0.12967133624178748, 0.27605996737557076, 2.2135822523024777, 5.9521320173817305, 12.903130900475288, 52.33585180774812, 53.71860104222452, 67.9189617403092, 72.87953622879522, 73.94641307092482, 74.79258598819857, 75.54316289963262, 75.16051999984249, 76.78460874865132, 73.58633164436587, 76.72016420672017, 70.81607141802388, 73.04300492809665, 73.17991133659118, 75.77971319998466, 75.54504563731533, 72.54299686801049, 75.13559725976761, 74.84087820976012, 72.33734699987596, 72.9572226924281, 73.71705639746882, 76.52883098971459, 74.19570322959655, 75.41621146663543, 71.82637199278801, 75.74914224686162, 72.67059941445628, 71.42265027569186, 71.41663335984754, 69.12399230464813, 63.26390066454488, 55.29064778358706, 57.756182993611986, 55.58053839591242, 54.38109328669887, 52.342833626654844, 51.605937942381836, 52.19855708460654, 51.727868741558446, 53.49282941510601, 53.61597222666587, 55.24132005630001, 52.84318293294599, 51.22931195843605, 50.60151700050601, 51.3606878249876, 54.46367094593664, 57.98303719489806, 59.120822645002804, 54.40534137910413, 63.72138238722279, 71.34532467011483, 69.54211696501702, 68.16766354345506, 69.34584156159433, 67.15041252874559, 69.62805609549247, 59.208499385464584, 58.00163707425518, 61.32083692858296, 55.68152373836887, 57.10741512237057, 50.99551516194498, 49.541335644260535, 46.84465515998102, 51.8173340828188, 47.46007111764724, 51.79405481584611, 48.08326905773532, 50.934035931864095, 48.0751262172576, 46.39933670720747, 50.50277133141795, 50.732112315393266, 47.31505324763637, 51.6316726130824, 49.00173910202519, 48.81513626344743, 51.31276038385207, 52.71221891526253, 54.014398744029386, 57.53557712801042, 61.227539431664255, 62.56982549544304, 63.94518106214462, 64.03546617877099, 64.75862180033039, 61.95160112073345, 60.07985784161476, 61.6644718570094, 63.6746395018793, 64.36579250520276, 61.740491313319055, 61.19287352408133, 61.06900899640976, 56.44337746404833, 59.45381226078157, 62.18895942934098, 59.86084053593298, 60.993719100952156, 63.7389781398158, 64.61675359356788, 63.49490473347326, 67.43667494866156, 69.90832513378513, 68.52561904538062, 48.781572541882916, 46.14815204374252, 22.508717352344146, 1.5547636752167058, 2.4687086526424658, 0.3648038376723567, 0.5451212006230508, 0.2726762183010578, 0.6633152680531625, 0.9471274936391462, 0.5320535179588103, 1.9849448434768187, 0.36301922053098684, 0.09076880155912331, 0.07399858531331824, 0.025178510019735947, 0.14826687954125867, 0.08247174758223758, 3.152167681724795, 44.783167223776545, 40.27634428393456, 27.812816942891768, 35.641326519750784, 0.3987019106505379, 0.08044389752490867, 0.13751653623917412, 0.017632775707170367, 0.08454210019760555, 0.035140809317630146, 0.06824990749479302, 0.06435545356643778, 0.048014215914712804, 0.10713467659849314, 0.16566927154217997, 0.20921951610474818, 0.03444800153374672, 0.045386423251681754, 0.03252137084341338, 0.050455787925109755, 0.029231377524293722, 0.09832916240538321, 0.24726629227159486, 0.1882294424238705, 0.2182971217459248, 0.334960668077392, 0.31546590609415887, 0.09649160092756634, 0.23710350776391648, 41.28133789185555, 86.13604914757514, 42.858334664375555, 46.23385190963746, 22.586072375697476, 52.81992327782416, 31.241807860712854, 0.1450573695042441, 0.06125496933236719, 0.1863031756253012, 0.3151353851201073, 0.04683350971449287, 1.6737099184143929, 3.303976890540892, 1.3772085188857972, 0.4628374740000694, 0.2482213127997614, 0.39568980614985194, 6.591778907083697, 17.60931811025066, 27.984961925014375, 56.9657979472991, 64.23969614890315, 71.67780045540103, 78.4772526833319, 79.07815194899037, 77.03495794726958, 81.80357163952243, 77.64555331199401, 82.88684398897233, 75.30407090340891, 79.43827259925105, 71.9394225458945, 77.78650760650635, 78.59112693417457, 78.74413859459662, 79.92833352858021, 76.36052208562052, 77.7374073766893, 76.89319564450172, 73.45455569605674, 76.65683361791795, 77.37376443801388, 78.72932772482596, 78.16547916781518, 78.19414384903448, 75.58204143278061, 77.43894638553743, 77.07719402928507, 76.84204793745472, 74.43437160984163, 70.06386280059814, 64.98572311093731, 59.643380411209606, 58.61398966081681, 58.64580400528447, 57.42157343895205, 58.19901074132612, 57.575102852236846, 55.72669375327326, 55.63592618511569, 56.819830863706535, 58.67965798224173, 61.26491569703626, 54.09927098981796, 54.22199410776938, 53.1433383880123, 55.72954139401836, 57.54235890603835, 62.00330580434492, 62.299597724791504, 57.49305863534251, 64.62260969223516, 73.78779242115637, 70.16990800057688, 68.87121123652305, 70.01112261126119, 69.47534253520351, 71.36005709248205, 60.68791935520788, 60.91090217713387, 65.7656354288901, 55.77862593435473, 60.64054104589648, 52.84017055265365, 53.390714430039935, 51.04265420667587, 53.888808373482, 49.9199620369942, 54.301273053692235, 50.47897823395268, 52.94197174810594, 53.1533286648412, 50.67263741647044, 55.544891895786414, 52.47275429387247, 51.74817092957036, 53.198243725684385, 53.21757708826373, 52.30869723904518, 53.04936624342396, 54.998439050489864, 58.49112925990936, 58.948426631189164, 64.74965918448665, 67.55029032307287, 65.16091969705397, 66.77064080392161, 68.28839409735896, 65.23804526175222, 63.5020826708886, 63.45713623108403, 65.24548992033928, 66.5975466082173, 62.56316138852028, 64.30721190667921, 64.21380066102552, 60.532758235931404, 62.22821451002552, 65.18481477614372, 63.49564606143583, 63.92242739277502, 66.12437540485014, 66.40099663888255, 64.1103167687693, 69.40293558182256, 70.29833424475886, 71.89352297013806, 51.27248548692273, 54.79011020352764, 38.741889538303504, 9.434451480065624, 4.805438864615656, 2.215112712114088, 0.8459541225625623, 0.5486236933258273, 1.0563058093670876, 1.5112042835643216, 1.0875061803287076, 1.5263416906518321, 0.9067530665666828, 0.3445327528301747, 0.11954897053299413, 0.07879726814046022, 0.08335554491608374, 0.06728506571943722, 3.133596484699557, 50.9458658003038, 40.698242264409224, 30.876960754394535, 53.299793889445645, 0.5993283564044584, 0.11037492208302983, 0.02072907518595457, 0.017557327537947608, 0.024175178071844484, 0.056511123078845205, 0.10215898149556692, 0.05240449343898124, 0.003220766741451958, 0.032178347314437555, 0.17902625965014582, 0.1966706894698643, 0.06072246544663945, 0.15258799847816268, 0.1745665247642225, 0.2297172557202078, 0.1703877449636498, 0.23118875740516573, 0.2569406344405105, 0.3152937814593315, 0.3529877281717716, 0.45952533882471824, 0.5645654314467984, 0.30299761062187536, 0.4713733175829534, 48.939173375406575, 101.93858038994574, 41.090836217326505, 53.990542888641365, 33.129201396819084, 61.53625742081673, 39.819384236489576, 0.2439989885615726, 0.31002625282252994, 0.30175458699945484, 0.8439557362468013, 0.1173430203550285, 3.4401694276640495, 6.056491578778913, 10.311455207486308, 1.532719587126086, 0.1775101563262363, 0.544016930845476, 8.320819985482002, 24.853522008465184, 52.46849459986533, 69.57669658045616, 73.1440059600338, 73.76957693407613, 83.47032793106573, 80.23613760548254, 84.59793090820312, 82.01840769860053, 85.68595717030188, 86.33638812649636, 80.58959807119062, 82.32998509560862, 77.20533001807429, 81.81120457187777, 82.49048063831945, 82.29236172091576, 84.78378065170781, 80.56397714922505, 83.64398694807484, 83.27550380460679, 78.94131614315894, 82.74005320764358, 81.12536245776762, 79.83100383512436, 81.7649833617672, 83.6505373062626, 80.32739546991165, 80.97991312703779, 78.14306674465057, 79.36341808688256, 77.64084646778723, 73.7478313138408, 68.9679604191934, 63.53741538140082, 62.18361716116629, 62.90501556088848, 61.01064805061587, 62.329854888300744, 59.43421217703051, 59.01899791532948, 58.27894472306775, 61.89489149278211, 63.584115120672415, 65.40129038595384, 60.15333167968258, 57.59924111827728, 56.003534640035326, 58.81041019193588, 60.77776124400478, 65.13833076723161, 65.05480389441213, 60.82685755145166, 70.65525424095893, 77.20533001807429, 75.59641299709197, 72.52418518066406, 73.74824708507907, 72.43045622302641, 76.29902716605895, 63.939732889975275, 60.61831297412996, 63.75867628282117, 61.26279761714321, 63.14766906922864, 57.290766316075484, 55.942886952430975, 52.66652330275505, 55.518863047322924, 53.19870264299455, 58.58190075043709, 53.21513737401655, 57.46219350445656, 56.92621730989026, 55.051477339959916, 59.01991967231997, 55.72701146525722, 53.45183672443513, 56.663265535908366, 56.054933378773356, 54.68369237838253, 57.96088364816482, 58.63879080741637, 61.93309537826046, 62.60322055509014, 68.91074088311964, 70.49547256961947, 67.46437472681846, 68.45976245018744, 71.73681643701369, 66.01301147091773, 64.69434592031664, 67.88187965270012, 69.02761182477398, 70.2905914860387, 64.65084683510565, 67.1249641910676, 66.75697526624127, 65.09376479733375, 63.62182870987923, 69.05106759840443, 65.21315390063872, 68.26269472798994, 68.42351974979525, 69.35069745586765, 67.628141526253, 72.66212709488408, 73.68999204327984, 74.67841363722279, 53.36195561193651, 61.99385681459981, 48.689596883712284, 14.236538679369035, 6.158057922317136, 2.7206326828848932, 1.4031091548742787, 0.6897145353497998, 1.5710465369686004, 2.8379956368477117, 1.7291442857634638, 5.7519724868959, 1.4843127588110587, 0.2676513250316343, 0.25812051709621187, 0.1585486528253363, 0.3008680700534775, 0.30513876508320537, 6.601863811092993, 64.42190593288791, 62.93683382772631, 45.76987081958402, 57.25388426934519, 0.7679756262129354, 0.28614459559321404, 0.18607725629643088, 0.11132089511281061, 0.17624816436681057, 0.18133399226973135, 0.2742000897565196, 0.14470328366564167, 0.0868780248528046, 0.1990093413980738, 0.2901175275685326, 0.31780599826766603, 0.17022098294429241], [0.1535345154303697, 0.09568057428564757, 0.22112741826042054, 0.012426055299358503, 0.16800571713716755, 0.398465434630071, 0.12964712786338023, 1.576976547798803, 5.498329968221727, 16.32203838517589, 23.384655175670503, 16.93176200312953, 59.585545063018806, 55.66387699496362, 35.616066455841064, 32.749621868133545, 23.339804833935155, 47.16082957483108, 15.157649459377414, 0.3373644987661993, 0.08083952831164484, 0.1383025424494859, 0.23970716482689305, 0.017883832296056133, 0.019178072726654432, 0.9163940685891336, 1.4319579423435274, 0.3753753607311557, 0.09362166702386834, 0.1928816032746146, 1.183948682681207, 3.6087580457810438, 8.803759851763326, 42.57526897615002, 61.4477099141767, 61.54399233479654, 73.57198361427554, 73.80835348559965, 76.38156952396517, 73.56213846514302, 74.84108217300908, 74.23062801361084, 73.67733847710394, 72.45170762462001, 70.25987932758947, 70.15370861176523, 71.40434849646785, 77.61349185820549, 72.79461691456457, 72.7515963585146, 74.10334710151919, 73.37649268488731, 70.22533109111171, 72.28210433836907, 73.76780402275824, 75.96288788703181, 73.71045897083899, 72.92573390468475, 72.6284182456232, 73.71941766431256, 72.0842521421371, 70.81566349152597, 67.75062930199408, 67.15921432741227, 60.42463810213151, 56.08580635439966, 54.34360327259187, 55.672235565800825, 53.976034041373964, 58.393968228370916, 56.834508372891335, 52.68747268184539, 50.714108636302335, 51.31287021021689, 54.78388540206417, 51.52803574838946, 53.127131154460294, 49.21224094206288, 50.021410219130985, 53.195768710105654, 56.1846108590403, 58.98492820801274, 60.113723585682536, 60.89272983612553, 57.55900936741983, 61.22837097414079, 60.33995020774103, 64.21598149884132, 66.29796381919616, 64.82250544332689, 60.75937709500713, 58.80828426730249, 51.19659546882876, 57.60222604197841, 58.69420605321085, 56.44003168229134, 52.8416375190981, 50.43783649321526, 49.83309722715809, 44.65823973378828, 46.7431285304408, 50.54827474778699, 46.68667385655065, 49.75187670799994, 48.57969599385416, 51.60780891295403, 50.261753451439645, 47.54201335291709, 50.3722309297131, 50.26081208259829, 50.178850235477576, 49.16492146830405, 48.5115683463312, 50.10137950220416, 54.79716654746763, 55.021255477782226, 58.32780568830429, 60.356565367790964, 61.64164366260652, 62.677106242026056, 63.38163845000729, 64.27473860402262, 61.857558373482, 60.02943969541981, 61.03026382384762, 63.82550562581709, 61.4593279746271, 62.87369151269237, 62.627366665870916, 56.94264419617192, 59.06728621452086, 60.58577299118043, 58.51582058014409, 59.813944678152765, 64.63808344256493, 64.17534574385613, 62.043533632832194, 65.63204734556138, 70.3324745547387, 68.64991111140098, 41.463708493017386, 53.43086381112376, 42.48325409427766, 15.070041360393649, 0.2588409461802052, 0.3837449938779877, 0.3807621232924923, 0.039224728280978824, 0.206086783399505, 0.8229022304857931, 1.0760886510533672, 6.032299380148611, 0.3575416305853475, 0.0318930197822591, 0.044877894087544376, 0.07287062809712465, 0.08649956975733081, 0.023551274151090654, 0.5793102950819078, 26.873640706462247, 35.428384965465916, 19.876865802272675, 38.382702412143836, 13.588352299505665, 0.16711472623771237, 0.2227173877819892, 0.024555977396366578, 0.014039632777923779, 0.058964454538879864, 0.03530393241934719, 0.048473830364884875, 0.14672505098485178, 1.7697806536189973, 3.713003613295094, 4.349591789707061, 2.1753847406756495, 0.3396618125900146, 0.1083707441425612, 0.08995255019756095, 0.02108552057536379, 0.13162214849745074, 0.4076268656119224, 0.29844502587952926, 1.389144168746087, 5.204751347341846, 20.97129141130755, 26.926565247197306, 26.826252591225412, 70.86568940070369, 63.47335523174655, 46.84165062442903, 29.472216829176876, 24.0145819417892, 57.331182418331025, 17.26756395832185, 0.37666594309191553, 0.23151206183097056, 0.09536676168922456, 0.4966018493137052, 0.062206718665097034, 0.04639270655330151, 1.383494607383205, 0.6794810715702273, 1.0296265828994013, 0.21488283640675007, 0.5421397702828531, 3.6517842402381286, 11.24954592797064, 16.730673851505404, 50.70722095427975, 68.49429499718451, 69.6473620014806, 74.6631242382911, 80.41387588747087, 79.0379947231662, 79.71706682635893, 77.97183959714829, 79.8241553768035, 79.01339361744543, 76.49300406056066, 74.40308678534724, 75.55112531108242, 74.20339107513428, 79.27950289941604, 76.55897048211868, 75.23495874097271, 76.60625857691612, 78.33104241278865, 71.29961336812666, 77.70338473781463, 76.68531787010932, 77.11936735337781, 77.82329159398233, 75.19425238332441, 74.40756613208403, 76.16834163665771, 74.79367640710647, 71.5665541925738, 69.665695159666, 67.9532903240573, 61.99695940940612, 58.06367328090053, 58.991784511073945, 58.38961047510947, 58.57325192420714, 60.330567898288855, 58.80513068168395, 57.12152781025056, 54.799586649863954, 55.14865798334922, 56.42502469401206, 55.80335647829118, 56.68664678450554, 52.71754549395654, 53.78845061025312, 58.21109556382703, 59.20220005896784, 60.61658320888397, 64.24510901974094, 64.84251345357588, 62.7346238782329, 63.31838238623835, 66.2870753195978, 67.48809722162062, 69.57875190242645, 65.62157461720129, 64.0593808697116, 62.32701509229599, 57.500224805647335, 62.61016707266531, 61.68147140933622, 58.49460447988203, 55.29279332007132, 52.96783977939237, 51.312932968139656, 47.81096635326263, 51.48640763375067, 52.015029384243874, 49.327433109283454, 52.998214614006784, 53.90379574991042, 54.04262804215955, 52.45021635486234, 51.51650790245303, 54.35858280427995, 53.42470568995322, 51.84299030611592, 53.254651331132465, 51.61222942413823, 53.60311077487085, 57.08819550852622, 59.13220536324286, 60.14423178088281, 63.40436466278569, 64.91615595356112, 65.7855296904041, 65.94328741873464, 67.39472127729847, 65.82668319825204, 63.39781430459792, 63.562114546375895, 66.17960237687635, 63.65156812052574, 66.13039232069447, 65.58905424610262, 60.922375109887895, 64.02502875174245, 63.86156005244102, 63.472441319496404, 64.98810006726173, 65.29328007851878, 65.75521761371245, 63.677942137564386, 67.18760444271949, 71.34490105413622, 68.90241761361399, 45.55866687528549, 59.24746028838619, 55.50344813254572, 26.447875268997688, 3.880258135257229, 1.2651694469874906, 0.7267819140707293, 0.16817483870733171, 0.7508034283115018, 2.1724216351586003, 1.1938904201792133, 0.6805336150911547, 0.7301017101253233, 0.14569539817110186, 0.14651154228035482, 0.11574486901442851, 0.15651360154151917, 0.006008909746719104, 0.383809682342314, 29.978363398582708, 43.85826841477425, 24.714166079798055, 50.95864488232521, 30.75466125242172, 0.1911267563099823, 0.06863125074174135, 0.08183149726039941, 0.07294895292650308, 0.04246604628860951, 0.05767298734656746, 0.0552133011872009, 0.28522795607005397, 3.1447605308025115, 6.1098465996403855, 6.736191751495485, 3.132192521326004, 0.2994763947302296, 0.17669664755944284, 0.3153326067953341, 0.09809230334095417, 0.1779332666868164, 0.7302597693858609, 0.4506976770297174, 2.11686959670436, 5.987099457171656, 27.3572140355264, 36.22193144213769, 37.6764561283973, 84.95401936192667, 74.71351100552467, 56.38149815220987, 47.505503931353175, 38.658060642980764, 69.2307827549596, 23.3657552349952, 0.4220551510732021, 0.3280626898331027, 0.3273720156040884, 0.8869482841222518, 0.2768921533659581, 0.20404736541451948, 2.2408201713715834, 5.571464030973373, 2.252841990801596, 0.3488773293793202, 0.5001382031027348, 4.49446649320664, 18.51764882764509, 31.300351196719756, 56.69315399662141, 78.64007026918473, 74.0575808863486, 82.65648318875222, 84.39516005977508, 83.61779336006411, 84.62865875613305, 84.02178964307232, 81.9656753540039, 83.31431957983202, 81.64574330852878, 77.64069741772067, 80.06414167342648, 76.53727977506577, 84.55475345734628, 82.41975245937225, 78.95237722704488, 82.6851478699715, 83.97954571631648, 77.38384492935674, 79.78509641462757, 79.42618385437997, 81.10116143380442, 80.25042287765011, 79.7917801334012, 78.16607536808138, 79.66737039627569, 77.94949777664678, 76.51950359344482, 74.57377264576574, 73.03831377337056, 65.53834192214474, 62.34316349029542, 61.254509648969105, 63.43941888501568, 59.77123398934642, 64.84492963360202, 62.64895146892917, 59.98642698411019, 57.6683375912328, 62.03355120074365, 61.72166001412177, 59.14985602901828, 61.24291512273974, 56.98795933877268, 58.05327507757372, 61.720789247943515, 64.1701642928585, 64.02612701539071, 66.71424496558406, 65.30173670861029, 64.85788522228118, 67.47247049885412, 68.13894394905337, 72.07237520525533, 74.88237688618322, 68.9872584804412, 66.46835157948156, 65.49378379698723, 58.82881395278439, 61.04807530680011, 65.80342354313021, 61.43779416238109, 58.0093131526824, 55.33700627665366, 54.374613531174205, 50.35044216340589, 52.975853181654415, 54.46645975112916, 51.71311278497019, 56.56229588293261, 56.84093713760377, 57.15923747708721, 55.60876377167241, 52.71579219448952, 55.50025532322546, 57.64861199163622, 54.783077393808675, 55.975399478789306, 54.07903155972881, 58.14266197143063, 62.31064704156692, 60.78472737343081, 63.19010519212293, 66.78312963055026, 67.74840139573621, 66.85428142547607, 68.72895471511349, 70.74721813201904, 68.54141835243472, 66.82736612135365, 66.4981694375315, 68.99167506925522, 65.54875189258208, 70.24117746660787, 70.45360519040015, 63.83490754712013, 67.2331823841218, 67.43028933002104, 66.69358976425664, 65.8898647369877, 68.16765569871473, 68.52961201821604, 67.47975041789394, 68.54852568718695, 75.0047234565981, 70.27519226074219, 54.589873206230905, 62.18648833613243, 64.93141397353142, 35.298060294120546, 9.96259960436052, 2.8948165620526964, 1.1996810642942306, 0.222158633893536, 1.1876434328094607, 3.631864238169886, 2.2124834983579578, 8.458625597338523, 1.5903551395862334, 0.19541341661205217, 0.26654714718461037, 0.21404268310195018, 0.30025850921388597, 0.2093589900722427, 1.834279128140019, 39.79966255926317, 56.596251841514345, 33.98104213899182, 59.976271967734064, 29.206907710721417, 0.32833106575473664, 0.4079572640119061, 0.14380518347024918, 0.1579728764632056, 0.15285144079356425, 0.11191527208974285, 0.11054389809648837, 0.43217661279824476, 2.4668509200696023, 5.476663285686124, 5.672865144668087, 2.7127472479497237], [35.63218739724929, 22.878620393814582, 17.76468711514627, 4.832958704040897, 0.2024024673887799, 10.528242645725127, 23.432521820068363, 31.813042240758097, 39.21275831037952, 36.40771058297927, 41.97926090609643, 38.50990095446187, 56.93987500283026, 44.85764126623831, 34.31358852694112, 32.70331436587919, 26.192599573443015, 39.33555203099405, 4.896593276531466, 0.1031970382938462, 0.11128706467007438, 0.12656632059764478, 0.18208727120391785, 0.043472344911987745, 0.10793582836706793, 0.09245392686176686, 0.4332127313940756, 0.10545443127592725, 0.061715633322995525, 0.042365489587668455, 1.4888780299694309, 2.754406496401756, 12.937417318744044, 32.99077310869771, 62.85582119418729, 59.68453391905754, 69.1449220718876, 74.47259902954102, 76.56691720408779, 71.82733689585041, 72.96635397018926, 75.43189310258435, 73.28720385028471, 71.76784238507672, 70.35662066551947, 70.92314427898776, 72.88782811933949, 75.25449214443084, 71.53117441361951, 72.34410132131269, 71.35427551884806, 69.91820950661936, 71.47286445863786, 76.23827749683012, 75.47704742800805, 71.78888982342136, 73.75078878095074, 73.66583808775871, 73.1988093160814, 73.47728975357549, 69.00918452970444, 67.90230735655754, 67.98563418849822, 62.541651110495295, 55.28049276721094, 55.2981944237986, 53.58270268286429, 52.75707906292331, 54.301555464344645, 53.312486679323264, 53.45282123934839, 52.453118908789854, 52.32756383957402, 49.90940301649032, 50.80754733854725, 52.82654031630486, 51.82944636191092, 50.99373440588675, 48.84455011736963, 54.2297564783404, 52.01121684043638, 52.614944134989095, 54.6985032481532, 65.21713510636361, 65.14411626323577, 64.99106930148217, 66.21808082826676, 67.35924736146005, 66.05906794148108, 68.89782059577205, 66.63423645880916, 65.09378833155479, 51.13345315379482, 51.09692804275021, 55.63697738032187, 54.77304789327807, 53.66204830908007, 49.94065646202334, 49.98656388252012, 45.54836280884282, 48.519620972294966, 46.3730489823126, 48.420196733167096, 50.46517933568647, 49.03010568311138, 49.034930198423325, 47.24278357721145, 50.06281475866995, 51.90601887241487, 49.65230341880552, 48.410249602410104, 47.703132552485314, 49.661532755820986, 48.283737474872225, 53.018304994029386, 58.61593515642228, 59.38573168170068, 60.929094129993075, 64.97157512172576, 62.636317514604144, 63.5227967077686, 62.7754008385443, 61.539830700043716, 61.62930780841459, 62.19266999152399, 60.5029050765499, 60.119713044935665, 61.133190739539366, 60.643949585576216, 58.516483460703206, 58.571518236590975, 60.64639714456374, 57.96229177905668, 62.54348285736577, 61.113955436214326, 61.59313571068549, 62.714211863856164, 64.42910348215412, 65.4866058595719, 68.80695496836017, 32.36460005083392, 53.82637208507907, 49.80564455832205, 26.62341506250443, 8.832460814906705, 1.2119020665845563, 0.09688620515648397, 0.2233450436183522, 0.11443612270898397, 0.7541080864687121, 5.783617679149875, 3.3544705423616596, 1.515644774321587, 0.10665660709022515, 0.09238592889760772, 0.40058915293024433, 0.08617546860008471, 0.26599323497183863, 0.14553773727628494, 14.64960152103055, 26.1573649221851, 15.977876878553822, 24.699472881132557, 50.13314677822975, 16.57031951412078, 0.3991092549216363, 0.20762249857427614, 0.14720574051382082, 0.11999792870013945, 0.09250294882804157, 5.860029372476763, 27.695757727469168, 34.42832569922171, 37.11653778629918, 40.08929429515716, 39.63027108100153, 46.38506712452058, 30.817883976044197, 25.430694856951316, 8.199296622507035, 0.13963449355815688, 12.374798424782293, 31.603105222025228, 48.56608929172639, 59.50181422695037, 62.507385284669944, 58.729122992484804, 55.07181482930338, 63.950338978921216, 56.573945322344386, 41.72784090042114, 24.64236709379381, 28.82737917284812, 48.029673791700795, 6.6209652635359, 0.08977019062806522, 0.1871133902140202, 0.08411799392272389, 0.2819915716686557, 0.034663322036184614, 0.1286565608555271, 0.6147124438035874, 0.36874603420015306, 0.29873206370299865, 0.20670045047037064, 0.09910094236294109, 3.6319144935377183, 7.998226611844956, 15.573047091884, 45.96738961435134, 65.75335448788059, 67.10362649733021, 71.44437236170616, 81.36454859087544, 78.77955759725263, 78.30705319681476, 75.77203319918725, 79.94760021086663, 76.39305422382971, 71.79649137681531, 73.39545342230028, 73.60933242305633, 75.8587646484375, 80.47588855989518, 73.14573180290961, 76.31682688190092, 77.71632855938327, 73.99195963336577, 73.67312585153888, 77.58251297858455, 77.29683891419442, 74.65430675014373, 75.77008770358178, 75.69924969826975, 77.11349948760002, 76.43277214419457, 72.34880032077913, 71.14383251436296, 69.38137823535551, 64.23559727207308, 57.89917692061394, 58.376231270451704, 56.9948430984251, 58.13832775239022, 55.007962565268244, 55.47913728221771, 57.581433557694965, 55.92197679704236, 56.933006932658536, 53.977297044569454, 54.1649510783534, 58.53904493393437, 54.56285984285417, 55.123107664046756, 54.27200040509624, 55.8677343399294, 54.702174586634484, 55.35486875041839, 55.600871962885705, 65.25091455828759, 66.47410177415418, 70.25812995049262, 71.10422442036291, 72.12628426090365, 68.56887494364094, 72.68275876199046, 68.9143886873799, 69.14044272515082, 55.06289535953153, 55.596663259690814, 58.07336937996649, 56.797245856254335, 57.237096525007686, 51.55604931616014, 53.85188710304999, 49.35632136560256, 51.06572166565926, 50.36136988670596, 51.725746739295225, 54.58183626974783, 53.780190098670225, 52.57054682700865, 48.821008051595385, 53.739546498944684, 53.04997813317084, 52.871329861302534, 51.72474261253111, 52.22564105064639, 52.32242553464828, 51.664859787110366, 56.157432756116314, 61.93989284576909, 60.79685534200361, 66.84230250696983, 65.90796255296277, 65.70101045793103, 65.06346841012278, 66.70352905027329, 63.20291565310571, 64.35484517005183, 64.05873367863317, 64.16604188180739, 63.98085894123201, 64.22701512613605, 62.88159116621941, 63.47251976689985, 63.38264649914157, 62.8787866715462, 60.272042212947724, 66.8818635325278, 63.26011165495842, 63.91173501168529, 65.56745767593384, 64.30115968950334, 67.49600471988802, 66.93396829789685, 41.27682324378721, 59.95929202725811, 58.4588756099824, 39.049709304686516, 14.70951376422759, 2.093699665800218, 0.7593383219453597, 0.08949684279580271, 0.11434996080014015, 3.3562287447914003, 10.60719995729385, 5.0164751275893185, 0.6916629727328978, 0.22894836391412446, 0.40341172727846336, 0.04862129462942962, 0.06793445547021205, 0.22511747996172599, 0.1886079664672575, 14.771669603163197, 32.74782346140954, 20.034605879937452, 27.751359285846835, 63.12643727948589, 29.22824932682899, 0.17583847586666385, 0.09183756316140776, 0.042022286028030424, 0.07587855741862329, 0.1491595098688718, 9.896738106204618, 38.59223150437878, 46.94020017500847, 53.33473436294064, 57.00641409043343, 54.50719356536866, 51.77224643768803, 32.91182364186933, 28.13570841666191, 9.211542202580361, 0.3544146741830534, 17.106130969139837, 37.3322210773345, 57.30864055695073, 63.70611652251213, 68.6245333763861, 70.23368573957875, 74.10380994119953, 76.97409845167591, 67.23741069916757, 52.45153427124024, 57.33832113204464, 44.13571726891303, 59.414772910456506, 9.673487582514364, 0.2055430448343677, 0.4294194930022763, 0.2900268534018148, 0.7245264899346137, 0.13092784301167534, 0.2384351064721423, 0.5783988343131158, 1.0179974907828917, 0.5434163791998741, 0.37043489035098787, 0.15202127727529696, 3.8809060617800686, 19.086461144108927, 27.335997935264345, 57.438349416179044, 76.71350402216758, 73.02825681624874, 77.33206179834183, 83.8859893429664, 84.01446265559044, 80.29631460866621, 81.0242437547253, 85.41796515064856, 80.95149163276919, 77.92956429143106, 76.50757174338065, 78.00642705732777, 79.0573476975964, 83.10469242834276, 75.9978126710461, 80.11633273093932, 80.34420674847019, 77.16900887027865, 77.81561943792528, 83.77952052700905, 78.49546817041214, 77.7333987143732, 79.65357934274982, 80.10538931815856, 79.7915683254119, 79.8381111698766, 74.77626108354139, 74.97616860174364, 74.24408174330189, 67.8929485813264, 59.72747995007423, 60.6995491827688, 59.73448138083182, 59.12385855951617, 60.116430021101436, 60.42883896058606, 62.0666834615892, 61.51976777661232, 60.38331200999599, 58.34598979642315, 57.5771503294668, 62.26277843598397, 57.37121412830969, 57.41808645186886, 56.28246615009924, 59.28941003737911, 59.130910981086, 58.416878792547415, 58.12038683122205, 70.71019095759239, 69.404402548267, 71.6810638673844, 72.7109919824908, 74.53387429637294, 72.48362787308233, 74.18517558805405, 71.501662500443, 72.15873010696905, 56.40302411971554, 52.37577369136196, 60.12664779540032, 60.94722724729969, 58.766165856392156, 53.34433632512247, 57.66094000108781, 52.60595406255415, 55.39623014388546, 52.67892191486975, 54.70228049062914, 57.98199384443222, 58.00610857625162, 57.23212295962919, 51.94589368758663, 55.815339319167606, 56.98587656021119, 56.21396979978008, 54.06209476532475, 54.681531152417584, 56.05055601366105, 52.676823446827555, 60.51593519026234, 66.33880353743031, 63.770557142073116, 68.494396978809, 71.54236101335096, 66.41888264686831, 67.71985438562209, 70.33645968283378, 67.06707785206457, 67.69157409667969, 69.6546026968187, 66.57066268305626, 67.52540680669969, 66.45189331423852, 67.40012630339592, 63.83740609691989, 65.68747043609619, 65.31437066293532, 65.25518994177541, 69.5246075045678, 68.34303271385932, 63.87834779677853, 71.86244210889264, 64.12168379752868, 72.06009034187564, 67.55902151907644, 51.31788692166729, 64.54622545549947, 63.987758390365116, 49.95133707600255, 20.627734930284564, 5.829697193637972, 1.2434024988643586, 0.29085410578596976, 0.187723717141536, 5.572943254824608, 14.144282571731077, 5.638494395440625, 2.673903770985142, 0.27110962978293823, 0.454773816370195, 1.0814268742838213, 0.1471713738095376, 0.8004120953621403, 0.24479568935930732, 23.55676289527647, 42.37094094676357, 31.611106857176754, 35.898516331949544, 76.21856366434406, 24.015184025610647, 0.4650669430773105, 0.2964970481491858, 0.2146015135991958, 0.19807158849172055, 0.2037372836662877, 8.833011907915916, 38.87659549713135, 52.19414049579252, 56.21316963626493, 62.893648532129106, 58.31838807752056], [25.194550521912117, 35.34783124923706, 36.11221098130749, 36.67973479916973, 24.29516673088074, 33.101097614534446, 23.68425169298726, 20.04508056948262, 14.489297193865623, 22.049231298508186, 37.41082929795788, 54.03746620301278, 59.68778948630057, 43.51010314879879, 40.192762497932684, 26.591922352390906, 30.80903707012054, 39.623148056768606, 2.027881068568076, 0.050906546398877144, 0.03673156024888158, 0.06065098944330408, 0.0613843692436574, 0.11141093342655128, 0.07761960713973931, 0.23783832397912782, 0.10201733183836746, 0.09502245879341518, 0.27129741325493784, 0.037176316423762235, 4.056371820549812, 11.009843022592607, 16.889749496213852, 51.55341348340435, 60.86648917967274, 53.00947181640133, 63.899763937919374, 76.77487342588364, 73.96338908903061, 70.39573454087781, 75.85040215523013, 73.22417136161559, 73.37487666837632, 64.85495128939229, 72.05366549953338, 71.95076604043284, 74.34363934301561, 71.80756815018194, 68.87822443439116, 71.07156676630821, 72.28365759695731, 69.23549744390672, 70.66018073789536, 70.59583033284834, 70.86372037087718, 74.33463358109998, 73.21741704017886, 71.9260472636069, 75.56581850974791, 69.82580631009995, 71.68881447084489, 67.28732678198045, 66.95890672745244, 57.21835151795418, 56.343462928648925, 55.647850190439534, 54.83341709260018, 55.7524754924159, 53.55696016742338, 52.42263817018079, 52.02047363404305, 52.41921394102035, 51.79100321185205, 48.72582781699396, 50.093577907931426, 57.07664020599858, 50.889658235734515, 51.20542864645682, 54.07963560473535, 47.83828958388298, 46.303313163019, 48.68762785388578, 50.052506769857104, 52.68753543976815, 59.84228772501792, 64.81843010071786, 70.1579761505127, 70.27690241413733, 66.41149290146367, 68.81427411110171, 64.6022839700022, 60.84645763520272, 51.82783426777009, 48.70256816187213, 55.1952047501841, 50.108377010591575, 53.87433482754616, 52.58141571475614, 49.07269477844239, 48.025908316335375, 49.30677790795603, 45.56317760098366, 53.54538525304487, 49.00057808045418, 47.14908599853516, 45.41477864788425, 49.52215917648808, 49.09398932610789, 47.898811755641816, 47.75568446805401, 50.375423739033366, 48.51118003168414, 49.75849766885081, 49.9962874381773, 50.49547180052727, 53.9271338524357, 59.72637776405581, 59.91462799810595, 62.347199609202725, 61.63856067965108, 65.33825397491455, 61.000728376450084, 63.77336948148666, 63.130281202254764, 59.15191135098858, 57.69323679708666, 61.19149677215084, 61.302931308746345, 63.6988248363618, 62.37280484168761, 56.411441526105335, 58.584552272673584, 60.28294640202677, 62.80390862495669, 59.01562075461111, 63.11521145605273, 62.168704309771144, 59.34965764322589, 62.041980374243956, 66.9085278049592, 30.373848138316987, 61.570178078066924, 53.638992617207194, 39.29912890157392, 17.55193187344459, 7.6366046744008225, 1.5007369484632247, 0.7144154776488582, 0.8239735891261409, 2.062972798462837, 11.33703439466415, 24.765337321066088, 4.9214566907575055, 0.9179834865273968, 0.32657865494970356, 0.512707989903227, 0.03016147338184378, 0.054252205581794825, 0.050133498565804575, 3.717970314525789, 41.97550719784152, 21.153008937835693, 34.599164532076934, 30.137760677645286, 59.54778048299975, 1.8295758385812084, 0.005372113045004587, 0.07135848544778363, 0.11943503793689514, 5.808833616395151, 39.682995580857806, 33.72088309257261, 25.981554485136463, 28.48357950487445, 25.308562055710826, 17.284696871234527, 39.28515741902013, 50.87483559885333, 51.885787287066066, 53.84628595844392, 34.520179763917, 60.81531009366436, 42.83671848235592, 37.9218945195598, 28.439933330782, 36.37914788338446, 47.18667407189646, 68.08682349420363, 66.88157327713506, 52.694529025785386, 44.39366409855504, 26.22570437769736, 37.49470526172269, 47.78212124301542, 2.854526711087073, 0.19902639451526827, 0.21962775518336605, 0.0966567158578865, 0.12551486492156982, 0.2105485867228239, 0.06986341889827483, 0.22247115180136698, 0.04447217775328506, 0.03513320206454204, 0.15135763062825128, 0.17385645318896542, 4.550821636953662, 15.806098638042329, 24.123608143098895, 62.070276352667044, 67.87143830330142, 59.103352408255304, 65.9833897313764, 84.94822994355233, 76.95665174914946, 77.52771746727728, 78.27452890334591, 76.84272258512436, 76.17674335356682, 69.44118653574299, 75.56692461813651, 74.37576355472689, 75.42188321390461, 76.14602335037725, 71.6518186753796, 76.68855774787166, 74.6420846446868, 75.50847345782866, 77.4260574771512, 75.63517385913481, 75.59393405914307, 75.07258046057918, 74.92576614502939, 76.04187657756191, 76.98466531692013, 74.12201758353942, 74.72712947476295, 70.89899032346665, 66.95231714556294, 62.26612814011113, 59.28981011913669, 57.23514710703204, 56.3497426432948, 56.87608941908806, 58.423366392812426, 55.95044143738286, 57.29934846201251, 57.312390342835464, 55.88245891755628, 52.889976809101725, 53.98571445095924, 60.19832518792922, 56.26380351281936, 53.359621801683986, 56.36567138856458, 50.10858097384053, 49.41538833802747, 49.04251998470676, 51.08567084035566, 52.395267871118364, 61.57825423825172, 67.12902776656613, 72.18603764810871, 71.93209555841261, 71.49787349085655, 71.33784863256639, 67.49796590497418, 64.76241473228701, 53.721358468455655, 50.93085096728418, 58.848425803645966, 53.94241148425687, 58.08177501924577, 52.27835770576231, 50.96570907100555, 51.31114436734108, 48.965127698836795, 51.332654645366055, 54.97002932333178, 52.05737137025403, 50.218501475549516, 48.67468403231714, 52.35557348497453, 52.382712364196784, 51.96388952193722, 49.638833999633796, 52.11151576811268, 51.39798172058598, 51.90263386695616, 51.74895540360482, 51.80935598188832, 57.52104474652199, 61.88404221688548, 63.21782458213068, 64.1545218806113, 64.55484682513823, 68.41149376284692, 64.50606430730512, 65.33750087984147, 65.16046470211398, 62.375491665255645, 61.13663850292083, 62.95248408471385, 63.96382408757364, 66.6891888649233, 65.05676507949829, 58.5267286915933, 61.68232256366361, 63.111077277891106, 66.3940461989372, 63.04120809801164, 67.72021524367794, 65.9570235590781, 60.94853731893725, 65.30538451287055, 64.19015269125661, 38.16419893695463, 67.73019375339632, 62.11889805332307, 54.38594525860202, 26.941134891202374, 9.420634931133641, 0.3415483500688307, 0.5090310130148165, 0.4925543310180788, 2.4980276342361205, 22.56540148488937, 39.79483019921088, 8.589940667152405, 0.9436208947050957, 0.3081048736649175, 0.3487163283411534, 0.08196318777458322, 0.11209566281327318, 0.1360731040157618, 3.877965755039646, 47.7009948607414, 27.36078731475338, 47.90880203247071, 38.366734443172334, 72.15231310936713, 6.680766699775574, 0.19542705297710436, 0.08547032297018074, 0.09333403165181799, 9.69084014815669, 54.793114739079634, 48.30354936661259, 42.04552150541737, 43.5906490202873, 36.52840975792178, 27.148610622652118, 47.472775674635365, 62.37567601665374, 67.26648330688477, 69.08594531397667, 47.84697763381466, 64.71881366545155, 48.4451469298332, 49.46377077410298, 34.41882964103453, 45.60769650243944, 58.54898029758085, 85.31949796984273, 77.69173529840286, 67.7326177781628, 60.957174378056685, 51.83793044859364, 46.675126398763354, 64.23454607686689, 5.168461578507578, 0.267234297409173, 0.5169339453981769, 0.17863195419551867, 0.32757095331626557, 0.5457056337787259, 0.16044525669947748, 0.39063972390947804, 0.3685128676795191, 0.2557546384031734, 0.32733830773542005, 0.26505637072747756, 5.603803482747847, 22.942666815173244, 44.33133763651694, 67.96880722045898, 74.73375043561383, 67.45092099712741, 73.17148608546104, 86.81294825769241, 80.85981799710183, 81.46147820257372, 83.53350162506104, 80.81824087327527, 80.97828926578646, 73.45149624732234, 79.33273730739471, 81.09425021756081, 77.83245425070487, 80.15656840416693, 73.3888481509301, 79.38781522935437, 78.53825338425176, 78.01246750739314, 81.20972479543379, 78.38815996723791, 77.2889627948884, 81.17745937839632, 76.41002239719515, 76.61662147891137, 80.79475372068345, 76.98584202797183, 79.04591006617393, 74.28633351479807, 72.48763653539842, 66.11416939766177, 63.40991873894969, 61.821021495326875, 59.10992630066411, 62.7608919912769, 63.16676316722747, 60.05526850300451, 61.997622289965236, 60.63752474323396, 58.7962818145752, 55.86471803726689, 57.68046163743543, 67.2743437367101, 57.476051238275346, 57.19406027947703, 59.58981260176628, 53.76499483662268, 49.67799494343419, 52.923905311092255, 51.432796678235455, 53.88646671848913, 63.78356764393469, 69.55323296208536, 75.06860317722445, 74.84297275543213, 75.18435232100948, 77.22702072512719, 70.73469792642902, 68.47425953034433, 54.5163405326105, 48.18712557515791, 60.09332333841632, 55.65771887379309, 60.27831016048309, 55.757809915850245, 53.89774353273454, 55.71021979854953, 53.07270434594924, 52.515853297325876, 58.97542822745539, 58.36178518110707, 55.56352707647509, 51.57836368007045, 54.69088992764873, 56.39770930813205, 55.54668049658499, 55.038462915728175, 57.44156968209052, 55.78138728295603, 54.44798146524737, 56.40099233196628, 55.662464941701586, 60.614782840974875, 64.93209254357123, 65.72867885712655, 68.28422854023596, 67.78906068494244, 71.71681234913488, 66.26478056753835, 69.59252726647162, 66.09181188767957, 63.90001889198058, 62.06373383921962, 66.65793541939028, 65.91678004111013, 71.50735778193321, 68.50175534525226, 61.6744464443576, 65.77849688068514, 68.32713142518075, 70.08597712362968, 65.0456843837615, 69.27238341300719, 70.2842450910999, 62.80221416104225, 67.01563988962482, 62.74483380779144, 48.291425320409964, 71.12458936629757, 64.76882388514858, 63.276154148963194, 37.716931066205426, 15.665365957444715, 4.222965423137912, 0.33976777787170104, 1.4070032104369135, 7.044744020508182, 34.27023849179668, 46.48840588908042, 7.535618841648103, 3.431936372672358, 0.6425541014440599, 1.5891495010545178, 0.2630048179097714, 0.45760408224117377, 0.305304117500782, 6.521453751671699, 60.58845589237829, 37.48029055133943, 56.62754451074908, 45.56699798953149, 83.96962211978051, 4.896232908771885, 0.2837823481569367, 0.23224407416437906, 0.3160292565101578, 10.092266298109486, 65.54228782653809, 54.462364796669256, 52.354031993496804, 57.277716590512185, 51.09437065739786, 36.581722613303896], [40.44245273836198, 18.050155255102343, 20.205497664790002, 27.75874903125148, 30.630732005642308, 16.819233125255955, 42.81319210606237, 50.40008760267689, 62.68283290247764, 44.56415384046493, 50.17792063374674, 43.92245408027403, 48.067230486100726, 51.82193110066076, 39.97616137227705, 19.76744736394575, 39.62257146835327, 21.43742588258559, 0.3098474172574859, 0.11986947873787535, 0.02764819362651437, 0.08279471492935574, 0.14589068930475943, 0.1265474058867943, 0.07494189235712252, 0.7176562134296663, 0.02552305806368109, 0.07804615723509943, 0.03357610537580425, 0.2715233785490836, 6.304069622870415, 11.88906288916065, 34.36694452839513, 57.62621133558212, 61.41615052377025, 51.506498013773275, 54.449369984288374, 75.69283270066785, 70.63365767079016, 70.46000649852138, 75.46442524079355, 72.30810180787118, 69.80727703340592, 66.52307648812571, 72.47234713646674, 68.09321695758452, 71.34788205546718, 67.97830720101634, 73.94483627811556, 71.98468669768303, 68.11106374186855, 70.7417425032585, 76.63234233856201, 72.64298592844318, 71.62329519948652, 70.52364303219703, 70.40402643142208, 72.06981781990298, 73.06952015046151, 71.47402548020887, 70.34976436245826, 68.18161149178782, 61.524658972217196, 57.02238990414528, 53.1497436185037, 53.01712436060752, 53.856872435539, 55.92840163938461, 52.8007193534605, 52.786398779961374, 50.54441121316726, 48.974384492443455, 52.42492883436142, 50.3528622658022, 50.11972050512991, 53.351620166532456, 54.176655430947584, 48.84526398874099, 50.6014895439148, 49.39629816239881, 48.54974085284818, 46.85900711244153, 49.66722803731119, 51.33286253098519, 56.18156317741641, 64.36303900134179, 65.46818248687252, 69.88000562114101, 68.6124760104764, 68.77976509832567, 62.36232819095735, 57.542923727343165, 54.48724046830208, 52.333094381516986, 52.35565977711832, 53.956441802363244, 50.68682855175388, 49.10144967417563, 48.4177452518094, 46.36283120801372, 45.2830340785365, 52.74497855094172, 50.09907707091301, 43.87425207322644, 45.040372725455995, 46.691451303420536, 46.81182099926857, 48.22052847954535, 45.942659070414884, 47.586465574079945, 46.32837318604993, 49.478420826696585, 48.2266983678264, 49.0594175554091, 47.05564337392008, 54.40994231931625, 57.30494176187823, 59.028207640494074, 61.0915312459392, 63.225139802502056, 63.89725754337927, 67.07234951757616, 63.080184690413944, 64.36394114648142, 61.50951862335206, 57.530768302179155, 60.17412024159586, 65.3183832476216, 60.80250747742192, 60.88533616835072, 56.72647845360541, 60.942947941441695, 59.72873510852937, 61.63859205861246, 61.58093321707941, 61.570566392713985, 59.57357398925289, 59.8135289069145, 66.39490912037512, 61.98217599622665, 35.438371319924634, 92.72167728793238, 59.70473412544497, 44.765269448680264, 35.25273730677944, 20.872255486826745, 4.918489908018421, 3.24253075545834, 1.2129292372734317, 5.087326370900677, 4.435084260279133, 7.9534287318106625, 8.189061687838647, 3.472721422872236, 0.29016900867704426, 0.468372275391894, 0.13199596876098266, 0.3505477994199722, 0.10183223733498205, 0.7721133590225251, 34.35282791814497, 21.14180664862356, 16.30678624876084, 32.03587209024737, 54.97741906873642, 22.912425341144687, 0.4165408501942312, 0.1310452383251921, 0.9647805496088921, 28.280057522558398, 30.57630715831634, 46.630854606628425, 69.57090716208182, 69.57588857220065, 72.27571871972853, 64.43639516830444, 48.677668956018266, 27.867408490950062, 32.80530775746992, 54.93788942213982, 66.34208263889437, 24.7736527458314, 50.691017643097915, 59.98563466533538, 71.03965436258625, 63.45231956051242, 62.39631552850047, 53.82369702862155, 59.63716345448648, 60.993738712803015, 47.330326957087365, 21.84115544442208, 49.87345841623122, 27.31349921995594, 0.19537397840571022, 0.05861328749526894, 0.050348543276589726, 0.05492584967625238, 0.04636305128975261, 0.28974916185102156, 0.18053396665040525, 0.3038355575934533, 0.059865320311679, 0.14260155208889516, 0.02563414081270176, 0.05264995950123957, 6.936510137973293, 18.17373344975133, 50.57193840703657, 63.30127692991688, 69.5264196395874, 58.952843220003196, 58.77396745066489, 82.17908367033928, 74.78978541589554, 75.45942814119401, 79.45244020031345, 76.89020679843041, 74.53436851501465, 69.830701428075, 73.8147077252788, 75.83711316508632, 74.58295883670931, 73.53239120975618, 75.28505525281354, 74.51765137334024, 72.34416407923545, 72.97892124422135, 75.8718575200727, 78.5880361064788, 76.92878723144531, 73.29368360580938, 73.37159756691226, 74.07370182775682, 75.73288010012719, 77.53358533305507, 72.54195351754466, 71.59879607539024, 64.51858843526533, 59.179473846189445, 56.71757859568442, 57.36347921432988, 56.596875498371745, 58.76842121924124, 56.363074779510505, 55.49103383095034, 52.150696323763945, 53.783543725167554, 55.38380799754974, 53.11139068295879, 53.70016590241463, 55.70412051293158, 57.460471583950905, 52.80059775998516, 52.29886385702318, 51.59440225170505, 50.28122017460485, 48.41521924541843, 50.591146253770404, 50.198819022024836, 55.240508125674346, 66.39017089720696, 67.22274887946345, 74.24316390868157, 71.37288324294552, 72.92377271959859, 65.03385843769198, 62.20902627514255, 56.56648497427664, 55.40138806066206, 53.934084292381044, 57.38766847118255, 53.5766504656884, 52.33103905954669, 49.64223077220302, 49.56598774079354, 49.775187353934015, 56.81226853401431, 54.198134330011186, 48.146070126564275, 47.758041812527566, 47.337387223397535, 51.15295910066175, 49.68726350415138, 49.71879151559646, 51.09752816538657, 48.278999251704064, 50.104027102070475, 50.39788715301022, 50.81641581750686, 49.98182565935197, 55.31441342446112, 61.28892060249083, 63.15852618986561, 63.82383469612368, 65.00575073303716, 66.92904180096042, 68.35192864941013, 64.00895095640614, 67.11864133034983, 63.684033578442, 63.16428422927857, 62.06907218502414, 65.25752767439812, 64.34446657857588, 65.94905330288795, 59.30858650515157, 63.38845945173695, 63.802865705182484, 63.79584858494421, 65.74762782742901, 65.32704384096208, 65.11904055072416, 61.52233692907519, 66.4962866998488, 61.06001500160464, 42.46897666685043, 97.15372024043914, 66.35441457071613, 59.21877599531605, 45.48630306797643, 27.10236195595034, 4.911402185117045, 2.7502071088360203, 2.753067497284182, 7.170347138758629, 10.9823501494623, 21.567093556927098, 19.94717428761144, 5.605311634079103, 0.5880528904737965, 0.23727816048889394, 0.21241125290191945, 0.39857452555048856, 0.21275827540986, 1.0404100365215734, 39.79106080147528, 24.30700836643096, 27.071255599298787, 42.3978993969579, 63.86493329078921, 33.10841283490581, 0.30250688534109826, 0.12709758725137482, 1.8222443158588104, 43.395303218595444, 44.39103218816942, 62.77358870352469, 80.16403659697502, 78.79391347208332, 85.47194480895998, 84.24984408963113, 74.47520348333543, 37.57670633254513, 41.27259885111163, 86.3264488404797, 77.14068151289418, 43.067334236637244, 96.94974914673837, 100.51718404216152, 123.45468705700291, 95.79312063032582, 80.47031094951015, 69.70809598122874, 76.02690881298435, 73.76145762781944, 62.88445841881537, 37.939996257905044, 61.7175179912198, 37.93392835124847, 0.4290273479155956, 0.1823819392631131, 0.36647789300449435, 0.3902999179497842, 0.43066475360143575, 0.34221683839155786, 0.45698315265678596, 1.4389011504188662, 0.20410489861763295, 0.22030333748027203, 0.20927427606957577, 0.252458269317304, 7.903195917606355, 25.676590204238895, 64.8256786407963, 71.38967883202338, 74.6388526116648, 64.90162749444285, 66.82194540577551, 87.15311188851634, 80.66718255319904, 78.3285556300994, 83.59743625886979, 80.57987843790363, 77.73845072715514, 74.42835469399729, 78.59522973337482, 76.6227246868995, 78.43007441489928, 74.75416244999056, 80.64040060966246, 79.62986469268799, 76.49443964804374, 76.32006675966325, 80.59303406746157, 79.8537535821238, 81.22062898451283, 76.43671804858793, 75.93977728197652, 78.70301646571006, 79.18802538225728, 80.01271155572708, 75.23507641207787, 75.67699416991204, 68.28069056234052, 66.34480476379395, 60.17830933293989, 62.26704989710162, 58.94184881641019, 62.529687881469734, 60.531632515691946, 59.364248860266905, 55.840642529149214, 58.33484242039343, 60.73006522270941, 59.211692194784845, 56.925142580463046, 61.4564097312189, 62.646284257211995, 55.222182812229285, 55.428244529231904, 52.348215118531265, 52.44723927590155, 48.91923204545052, 51.90717204924553, 53.79640517696258, 58.53741715031286, 71.01403344062068, 70.2031461654171, 76.60905130447881, 74.57045432059996, 76.14798453546341, 67.47844034625639, 64.00290266160043, 57.90982223326161, 54.21161943866361, 55.4294643863555, 61.12774648974019, 57.120468770304036, 55.48687219619752, 51.63679522852744, 54.362152161136756, 52.4338012356912, 58.37540757271552, 58.39416042450936, 51.65594423970869, 50.54008091649702, 50.90346497874106, 54.570939925409135, 55.2199980520433, 52.848991963171194, 54.69629103137601, 51.1302956458061, 54.46265897443218, 54.36018313131025, 54.36054398936611, 51.60520445915961, 57.561790327872004, 63.500160709504165, 63.487930759306884, 64.4471424625766, 66.98450411519697, 69.13920325617637, 71.97964252964144, 68.25114727020264, 67.8534189347298, 67.7321941621842, 64.49482671676144, 64.82853804865192, 69.05610392170568, 69.68520502890311, 67.82556226176601, 62.58993156494633, 66.63061218876993, 68.01824477411085, 69.81319196762578, 69.95813923497354, 68.15809296023461, 67.05731115033551, 63.948397405685924, 68.3436289141255, 62.68956368969333, 51.230053286398615, 90.27167858616, 74.10452381257089, 67.53318878912157, 52.013652632313395, 41.06253239416307, 18.51982770427581, 11.663003948427017, 14.346329742862334, 19.798479195564024, 13.570117200574568, 30.863155972573068, 33.48225785839942, 10.087785970780159, 1.4093902178349034, 1.105127796050041, 0.5700007946260515, 0.5705558100054341, 0.8509889136879676, 1.2475999252450083, 53.052068756472686, 34.10519299968597, 27.94571076670001, 47.483307238548036, 75.19832380356328, 34.076159615670484, 0.7113016060283108, 0.32448104492598967, 1.530332579728096, 52.42008470719861, 50.792179492212114, 80.5063496866534, 103.28133321577504, 109.3099141890003, 118.22175102849161, 116.95487253127561], [54.55950229398666, 40.06483831713277, 25.524976868783277, 10.378596378910927, 27.421003541638775, 50.54263045710903, 42.98266203172746, 39.9499991632277, 43.54749510365148, 38.57535746789748, 50.88431988992999, 35.577215379284276, 24.829770095886726, 48.30326695596018, 26.118119647425992, 24.14332393677004, 33.68895892174014, 9.000636358414928, 0.08422097146150567, 0.11087863255412349, 0.06575795371205577, 0.2237589915673579, 0.03866414727282621, 0.15160752850915157, 0.07645759731531143, 0.0712571626589183, 0.12599700235671576, 0.024601856486931927, 0.05414598749109334, 0.12271095247518633, 7.032369432910797, 28.250422054721465, 52.13552067356726, 62.96461597565682, 62.935488454757206, 54.364580108273415, 48.11966080819407, 72.99780353423088, 66.38056109028479, 72.22304913305467, 74.46288724099436, 69.42621092642509, 65.56645354916974, 70.62992357438611, 73.98497781445904, 70.88798415276312, 69.3490343709146, 71.12029829332906, 71.85011802181121, 69.53773175516437, 70.82300616848853, 73.54782181401407, 73.21653058451992, 72.93823057605375, 73.47190041695872, 70.81368661695912, 70.21310898565477, 70.2309008567564, 72.17324287660661, 67.90125616135137, 69.98128906373056, 65.66711725727205, 60.241890953433135, 53.57371653279951, 54.9034196330655, 54.655051231384284, 53.740287826907256, 52.501128719699004, 53.5196231257531, 50.86777533254316, 51.755517528903106, 49.71128802145682, 49.53236518367645, 47.329236538179465, 52.60464399091659, 53.07370455034318, 53.79004309254309, 52.09642248768961, 48.03756952285767, 47.91864325923305, 47.41576794655093, 47.03072063384518, 48.69546867186024, 47.547512515898674, 48.369402039435606, 62.064926239752005, 67.28001548397926, 68.71285730792631, 67.36710779128536, 67.37641949807444, 65.38888000672864, 57.43150488022835, 50.93441640177081, 54.96298474650229, 53.65103037126603, 51.91742512487596, 49.55922557461647, 47.61454582214356, 46.385290699620406, 43.34262578718124, 49.38480169542375, 51.02933383757069, 48.91807494624969, 45.20539860571585, 46.25767246369393, 47.672071303090746, 44.991754947170136, 45.61299170217207, 47.140139072172104, 48.889826036268666, 46.09830264122256, 48.275661314687426, 46.10244074175435, 49.026779513205256, 47.45283042230914, 52.04254873337285, 56.21903750204272, 60.26053005649198, 61.99707315814111, 64.8781285747405, 62.51005249638712, 64.04830801871516, 60.322440747291814, 64.59372143591604, 61.69865923543131, 57.20300720584009, 57.775116274433756, 63.3965709132533, 63.156792502249445, 63.81624098747008, 57.228008393318426, 56.849268251849765, 56.94325216354863, 56.721371527641054, 61.24023614391204, 60.669927443227465, 60.939206000297304, 65.89850179610714, 62.16957899831957, 61.2202359784034, 42.225974067564934, 94.50575167132963, 64.34533734475413, 61.42638006517964, 46.2019238164348, 32.34659048818773, 11.650190545666604, 11.263896899838603, 12.495185771296102, 3.5642521371764526, 1.232216021706981, 0.5107143226890795, 0.34078342659819516, 1.4315556542527292, 1.5051548855919994, 0.20270571563272707, 0.06215513796515523, 0.1889983955169878, 0.07370969355707208, 0.3555968091372521, 18.910572259656846, 33.44717225720806, 35.04052923571679, 33.1622120641893, 52.75661622324298, 35.51610877436977, 0.7539454306806288, 0.19330618452400933, 13.273871367977513, 28.013226524476085, 32.63591627920828, 64.8059687306804, 34.32460254238498, 18.01565604825174, 15.838852390166252, 31.881532707521995, 77.97098452045073, 61.339123018326305, 34.770811373187655, 60.846210525881865, 40.20543959832961, 68.65075049861785, 74.26512918164654, 63.54657803812335, 65.35985054508333, 55.72290082131663, 61.84231212062221, 45.41845783110588, 34.4173469851094, 62.471707405582556, 32.379697253627164, 30.312735649847216, 41.69919583105272, 11.256694447609688, 0.055957118935522535, 0.10371616245397638, 0.05580112811238055, 0.34436583759323247, 0.09681898094112835, 0.03124217446442814, 0.08339767209103993, 0.12649888953854962, 0.13292926303561658, 0.07201179756873077, 0.06971469058865501, 0.10751791208261445, 7.359713287122789, 30.39228523931196, 60.092754594741336, 68.20747560070407, 72.45755980091711, 60.46220264127178, 54.82161075838151, 79.20397373937791, 72.0306960998043, 76.69564154840286, 79.1989609502977, 74.10271167755127, 70.36310042104414, 72.97967433929443, 75.92938300101989, 73.5090531072309, 72.14366820550734, 72.96804058936335, 75.07103504673128, 71.30162946639523, 71.00279192770682, 75.41941212069604, 76.277540422255, 77.16973058639034, 74.48787273899202, 74.71037310938682, 73.14701049558579, 74.68301849980509, 74.52812410170033, 71.78463012941423, 74.30607872624552, 70.66199287291496, 60.2654996995003, 55.69097272811398, 57.373975476911, 55.19448695644256, 56.211145693256015, 54.71970758130474, 57.23611593246461, 56.84432214306247, 55.96421680142803, 52.73789475041052, 52.99271152865503, 50.76077307424238, 54.50678563887074, 56.00361308743877, 55.3866752501457, 57.04665368603122, 50.872313514832534, 49.94144878079815, 47.263634897047474, 47.85501849266791, 47.949782956031065, 49.03613436606623, 46.63843654817151, 60.93593082120342, 71.07661877909015, 69.74825320705291, 69.56070899963379, 69.80071098573747, 68.36772795646422, 58.91449420682846, 51.2107866041122, 55.20908209585375, 53.5520689718185, 56.268529968877, 49.7391172378294, 52.87359699126213, 49.38020859995196, 45.75347138989357, 51.91901368479575, 53.39482115161035, 51.08964812371039, 51.493216868369814, 46.531093043665734, 48.028959920329434, 49.363769946559785, 50.82220915825137, 50.952965290315696, 52.04808712005616, 48.77327672896847, 49.2571795371271, 47.917035087462395, 55.15383551197668, 49.33008855389011, 53.86494075098346, 61.040446296814956, 65.33880310673868, 65.3079262087422, 69.07542551717451, 65.596141969004, 66.9387222105457, 64.15942092095652, 67.67796347218176, 65.29969315375051, 61.936009699298495, 60.61696760116085, 65.98329559449228, 63.278574251359515, 65.78324687096381, 62.64850039635936, 60.52034001196585, 63.034920538625414, 58.74383188063099, 64.91618733252248, 61.73356440759475, 64.62310391087686, 68.0189194217805, 67.44803413268059, 57.171063423156745, 52.29636530722342, 92.95863551478233, 71.05016631464805, 69.76839065551758, 57.79614410092754, 46.37851284396264, 24.662282928343743, 16.010204072921507, 20.00144027894543, 8.554201010734804, 1.7723794690062924, 3.008763376743563, 3.255260072408184, 1.650371448166909, 0.3289857032077928, 0.0848254761207969, 0.13128168370214202, 0.1440767616394066, 0.07416578400279246, 0.5733272096803111, 23.016825106836137, 33.07411955248925, 36.14085997304609, 40.35499957300002, 58.468116714108376, 42.1856834811549, 0.5874506227912442, 0.1778775414512042, 19.454469680786133, 44.00638103485108, 45.63796935542938, 77.83906736681539, 48.63347168891661, 35.87762971078196, 25.721501342711914, 37.86010149986514, 121.41809048191195, 107.92094799780078, 57.74105441185736, 117.8120045508108, 70.48063816562777, 127.11200698729485, 99.84530556586482, 82.01850183548467, 95.36919870684224, 81.57163404649305, 79.37431443122126, 59.81751795737975, 46.020957423794655, 72.75656992389311, 50.507623303321104, 39.964492321014404, 52.05548471020114, 18.385384544249504, 0.10621170152819927, 0.49954212541061066, 0.4803726137165101, 0.5220995230540153, 0.2962016446455833, 0.5170676737062393, 0.28462164344326146, 0.39294022465905837, 0.3733502532685957, 0.24153779320899518, 0.10818982481836312, 0.18615990186170225, 7.469870111634655, 42.919147091527144, 69.97428371060279, 69.10812239493094, 76.26804828643799, 67.6554726016137, 62.35001194861628, 82.86134073811193, 74.21942572439872, 80.47038155217325, 81.9312055649296, 78.37864429719987, 72.03958419061476, 77.96148453989338, 80.88874155475249, 78.03819041098319, 75.21700997506419, 76.28091366060319, 77.8978636956984, 75.13916661662441, 74.01656073908653, 81.12602926069691, 79.83625196641492, 78.4839677810669, 77.15951673446163, 77.15682598852342, 77.89155652446132, 75.97291346519225, 76.01613798449117, 74.43313998560753, 76.27642646912606, 73.8644669132848, 66.0856145428073, 59.35904387504824, 62.86723921375891, 61.076638006394916, 59.362001342158166, 60.492997169494636, 62.12131031097905, 60.849152303511104, 58.33236348244452, 54.621711084919596, 55.89117834644934, 54.58633522833548, 60.31884001147363, 62.00772631552912, 62.828894122954345, 61.646605460874504, 53.8302081631076, 52.44447400493007, 50.441672571243785, 49.837780537143836, 51.36085648690501, 47.74514505940099, 48.60977272833548, 66.13026680484896, 73.56599023265224, 76.85051241228658, 71.22163664910101, 75.20562725682413, 74.71249118927987, 64.2041673198823, 53.77638932197325, 56.36743645514212, 56.6863408396321, 57.64050053011987, 54.75833508276171, 57.18923968653525, 52.84702293334469, 48.53763641849641, 54.603060214750236, 57.51177226343463, 56.66977667039441, 53.14048682489703, 49.019150503220104, 52.66136930834863, 52.04023061260101, 52.257541687257834, 53.905627496780895, 54.680793746825195, 51.16997042009908, 51.356188866399954, 51.551189499516646, 58.34486407618369, 52.72697879422096, 58.4564672746966, 63.07734489440919, 64.15203902029222, 68.44515554366573, 69.98168130074778, 69.3830805440103, 69.94232423843877, 67.996122606339, 71.42545869273525, 68.21132736821329, 63.568139306960575, 61.712995498411125, 68.09611166677168, 69.21632489850445, 68.7602081606465, 64.57889879903486, 61.37395366545647, 66.81795243294009, 62.800300044398156, 68.87365095077023, 62.401555815050685, 66.96133075221893, 68.84422532973751, 69.04332483968427, 59.07113013728973, 57.94329574031215, 92.18716021507018, 74.67770761059177, 74.16012733213364, 63.955222329785755, 54.52087087015952, 38.34969958951397, 44.716149607012355, 36.18489642297068, 11.051212260800025, 4.522873768883367, 6.478204227262928, 17.314457854916974, 6.52401751087558, 3.8220955143051767, 0.488178130359419, 0.2540188670278557, 1.5650226344023983, 0.22445823065936568, 1.1607034912993832, 31.39453907166758, 46.21753877209079, 54.517489787070986, 47.03857321893015, 74.02227171005742, 45.88700456003989, 0.7917110525792646, 0.2785268930658218, 23.746025100831066, 53.66908896353937, 62.27016425901844, 108.18731615620275, 70.06869516065045, 53.113916689349765, 46.38553780894126, 70.8745853362545], [18.719599900707124, 48.233625273550714, 34.74964234136766, 10.419603778469948, 53.47001298781365, 32.063405167671945, 12.73194101548964, 16.447486569804532, 35.889032040872884, 37.12663396712273, 42.72673522272418, 26.553116383091098, 22.55154767344075, 42.76579026252993, 25.86886282890074, 44.96915425023725, 29.56103890172897, 1.546230926629036, 0.16725927170726562, 0.08347682429537659, 0.09465700421001642, 0.09108932508576302, 0.08521731477230789, 0.11545621474543888, 0.4438744383233209, 0.1427914652853243, 0.31632849045338174, 0.013123024855890583, 0.05230513566564168, 0.07218896306209988, 1.7027419541151294, 38.957678733333466, 62.82549735038512, 60.72842959434756, 57.059091521847634, 58.60973388917985, 40.37381126034645, 67.062512213184, 64.29399744156869, 69.51865334664622, 72.36889070080173, 72.92098783677625, 63.69392579601657, 70.15626599711757, 74.67266344255017, 69.03176953715663, 70.01479394974248, 71.46862829885175, 71.82118661942022, 68.66579671059885, 73.6247238036125, 73.16722639145391, 72.65605526585733, 73.14184081169867, 70.4013749091856, 68.38460983768587, 70.52304683193084, 71.40812966131395, 70.92898076580417, 69.5427288547639, 66.8130494702247, 65.53638858179893, 57.19974771622689, 54.46644406164847, 55.524236694459, 52.59165310090589, 51.40913301898588, 50.11988916704732, 51.08608661159393, 51.02450147751839, 51.478664875030525, 49.716728348885816, 49.5531851245511, 48.07121953656597, 49.84058895418721, 52.86665047368696, 56.12369252789406, 51.1391798142464, 47.06884999429026, 45.82539196937315, 45.00037239443871, 46.609803245913604, 46.285705643315474, 50.551102776681226, 47.495788220436346, 58.515345973353234, 68.71084905439808, 65.15527540637602, 67.8643858817316, 64.67211392617995, 65.78385091597035, 58.314755962740996, 52.65386973657916, 56.36388671013617, 50.61677894284649, 50.249719619750984, 43.918696449648955, 45.47635593721944, 45.446498855467766, 47.23106353513656, 49.484233779291955, 48.576409047649754, 46.492814633154104, 47.18661523634388, 45.55319516889511, 47.128403340616536, 45.97797609144642, 47.294809895177046, 47.43601129901025, 49.84759822968514, 48.00846945854926, 45.9509313491083, 47.05715348643642, 47.575926165426935, 46.34490597632624, 53.11328518775202, 56.59644011528262, 60.89726017367456, 64.06937899128084, 63.784736510246034, 62.523463080006266, 63.605507727592226, 59.83867522208922, 62.13138295758156, 60.51128718160815, 59.6149157708691, 55.47296347156648, 61.61601881827078, 60.10268995838781, 58.88962245756581, 61.82860343686996, 60.26740989377422, 56.18615627288819, 58.41168557443927, 60.99162455528014, 59.67883863756734, 58.77248479473976, 69.95190266639956, 62.46902450438469, 63.500129330542784, 43.67619591374552, 78.26751570547782, 59.904955433261016, 69.16811896908668, 51.940935811688824, 38.26445079618885, 23.252318328426732, 17.548166398079164, 7.121073344061452, 0.6571186586253105, 0.9044170499809328, 0.8571006405738093, 2.104869595458431, 1.0067806152566787, 0.9477523149501894, 0.004509154739113706, 0.12807260267436504, 0.03363981707802704, 0.07397926457586788, 0.4930539429187775, 9.311900946401781, 38.71975168105095, 30.885658610251646, 32.688719226467995, 55.67205121440273, 37.832742967913234, 0.46594310251455157, 0.7593175456408532, 20.59015666284869, 21.175433128110825, 42.69480320715135, 29.698490519677442, 19.61645180179227, 16.02213102002298, 12.724592454971807, 4.930013831584684, 24.15937819788533, 68.13763387741582, 49.03413787964852, 36.63561597947152, 75.89636448890933, 61.947243367472005, 34.24432339206819, 34.63519934685, 55.60036597713348, 61.6452600879054, 57.05836588336576, 33.977425713692945, 37.723865816670084, 58.78650334573562, 33.8304348914854, 49.17360167349539, 38.0016206156823, 1.9707669461927109, 0.08003801648174563, 0.31090673299566396, 0.10528006966436103, 1.0309179007045686, 0.47330042707823944, 0.13720749637051938, 0.01611975205671643, 0.7358817515834686, 0.26822742315069326, 0.1544106901893693, 0.07817430842307307, 0.10148507693121511, 3.1646690109083733, 46.08566084215718, 68.67379050101005, 65.98094217238888, 66.43454859333654, 65.4858409973883, 49.33626628691151, 73.3015989488171, 69.38736377223846, 71.67251310040875, 75.36016079687303, 75.75577105245283, 69.20526381461852, 73.68898007177538, 75.15307534125544, 71.17232461129466, 71.09246515458631, 76.15964966435587, 74.89193962466332, 74.53180328492196, 76.4241978429979, 75.02436668642106, 76.22618875195904, 76.78416159845169, 70.62207883404147, 71.09924301024407, 70.32322560587238, 73.964808987033, 72.88355273585167, 72.69226658728816, 68.85451762906968, 67.73489275286275, 59.42792461764429, 58.054114464790594, 57.324600681181884, 57.17937884792205, 54.085942775972434, 56.35514766939225, 55.79946548708024, 56.19994340404388, 53.67663168138074, 52.81223935465659, 50.51902171104185, 51.67316344476516, 52.596583520212484, 55.51220286277033, 57.917353183992454, 54.13527050325948, 49.92633196615404, 48.47525896564607, 46.58331155776978, 49.09898642570742, 49.03199234316426, 49.556024920555856, 46.253597121084894, 59.543489410031235, 67.7915866913334, 68.88807742826401, 69.46006098101216, 69.42166882176554, 69.93650344110304, 60.59138982526718, 50.0252894432314, 52.17549354799333, 53.22376658839565, 50.978672504425056, 45.13242683103008, 47.30810280769102, 48.13887649966825, 51.477543077161236, 54.46433774886593, 54.469836911847516, 50.738117464127086, 49.859000559776064, 45.67734210721908, 49.60012805077338, 48.3711592612728, 50.11510779780727, 49.54599542002524, 53.411255882632354, 46.335531511614406, 48.16606244733257, 48.85576809606245, 51.58295285317206, 49.910858215824256, 55.36483549302625, 60.261110567277484, 64.26658791880455, 65.44255372016661, 68.36462143928775, 63.647932083376, 67.82757051529424, 62.77629121657341, 65.33554361712548, 64.55537634511148, 63.46050554706205, 58.31536000774753, 66.3890177203763, 60.358059790826616, 60.646856061873905, 63.53418334837883, 63.585436959420484, 60.532487592389515, 61.876468120082734, 62.41133428389027, 61.6898613591348, 66.01079140940021, 70.6264248201924, 66.64124181193691, 58.48828554153443, 51.25161847760601, 79.1742657076928, 69.31825160980225, 74.4291627022528, 63.4857459991209, 53.663436828121064, 31.448875665664676, 36.4204857426305, 23.419974157887122, 1.1319599949544477, 1.4813864255143752, 1.6286488718563512, 2.199257511285044, 0.2259380520591813, 0.5633769532845867, 0.04772566123715332, 0.07392422881938758, 0.045890750423554456, 0.020907163815272432, 0.5465113744139671, 11.096647035691047, 43.10688741745488, 31.0505001391134, 38.30239580523583, 62.97257838710662, 43.341413774798, 0.48265034633298076, 1.5469011616322303, 34.62368326802408, 36.48916644434775, 62.5594037578952, 42.531793425160075, 26.920542447797715, 18.441694090443274, 18.835094090430967, 8.513557411009266, 46.2402924414604, 101.0592555999756, 107.19681570606848, 113.58558793221752, 119.01454833246048, 73.77937501476657, 41.09846130494149, 53.423909448808246, 76.89852222319573, 85.81925499823787, 79.5655535113427, 47.446064333761896, 51.42328493056759, 71.20378202007663, 53.69528647392027, 63.38783971724972, 50.3297398936364, 3.429998721807234, 0.2946303063823331, 0.3734873523635249, 0.45498372446144786, 0.6086634748405026, 0.1897261024362618, 0.4465364406426107, 1.1202267148802358, 3.881523099637801, 0.551351701780673, 0.2604785050836302, 0.20773808592029158, 0.14645787016037973, 3.6842048360455424, 41.52779217689268, 69.1826238939839, 70.23934964210757, 70.91598987579346, 69.55759463771697, 58.009128801284305, 71.85052594830914, 75.97826357810729, 73.45040582841443, 81.82365417480469, 80.48743601768248, 72.44753422275667, 77.71147266510995, 81.7892942120952, 75.06819525072652, 74.97035564914827, 78.86555948565083, 78.3040015928207, 77.09965352089175, 80.93295451133483, 78.99935153222854, 78.36495522529849, 78.90188847818683, 73.89289625229375, 74.64406936399399, 76.23710863051876, 77.4357614209575, 77.58663146726548, 77.6165356174592, 71.13755672208725, 73.71825664274155, 64.78321113894063, 60.637371770797245, 61.51075024758617, 59.64347847046391, 57.264772768943544, 58.22741262374386, 57.340325463202696, 58.77442636797505, 58.9434766000317, 56.41783498948621, 55.283454156691036, 55.17509083594046, 57.372614414461204, 58.80568373587824, 62.75034081551337, 58.473125580818426, 52.54522792754635, 50.16317252189883, 46.93592086915047, 50.76346382018059, 48.213707477815696, 50.442280538620494, 47.888417474685184, 60.17636383733442, 73.0851076495263, 71.16089482461253, 76.37367771517846, 72.79204383973153, 75.54936024450487, 63.99472059742097, 52.04906379022906, 61.824814427283506, 54.62586095256191, 54.82507421124367, 49.681215209345666, 50.16880504546627, 50.55403670957012, 53.2819196485704, 57.07159211558681, 57.59212201641452, 54.62611198425294, 52.97757510216006, 49.84564096696916, 53.24897566149312, 52.47931641917075, 54.372283643291844, 52.66716657146331, 55.68963127751505, 49.20627109466061, 49.766114911725445, 52.40710950666859, 55.49338333068356, 52.00810640088974, 56.55776946775375, 62.15541531962734, 67.11794314845916, 70.726821807123, 67.34687620593657, 65.80128977375647, 70.91070252080118, 67.38500164401147, 68.00050781619164, 66.25985407060193, 64.63217243071526, 61.576202838651604, 70.412059445535, 63.62839083517752, 64.58711224217569, 66.07245891324936, 63.001615693492276, 60.75694130313013, 61.42098288382254, 66.0740827745007, 62.749093501798576, 68.27272030615038, 73.65020352025186, 64.03854131698608, 64.33677088829779, 52.249394924409934, 86.25253569695258, 72.46299620597594, 76.63352689435406, 63.64684558683827, 59.98122199889153, 45.20515149639499, 51.452102584223596, 24.51160311698914, 1.8776122480630877, 4.614447384111343, 3.0824524548745926, 5.6967102135381396, 2.922447208435305, 2.9625102973753408, 0.2465510725854866, 0.2318625317345704, 0.4546977898045894, 0.16129346924924082, 0.9573679441405881, 19.183792798749863, 56.95601555608935, 51.36697930674399, 51.08517662171395, 72.47644993566698, 54.0130651381708, 0.6737036654545415, 1.5535525208519352, 43.12860165872882, 53.44313690739294, 88.1031648574337, 67.62959280321675, 48.70568252378895, 39.90086755444927, 44.06349466693017, 44.61589382540795], [13.563182450109913, 31.87924400452645, 37.40095276986399, 30.65230896396022, 16.953831218904067, 3.940398366220536, 2.3943216377688996, 8.44990126548275, 20.26281329893297, 22.21823642330785, 37.11901672424809, 38.87589731524068, 35.72821486380793, 27.753387151225922, 29.939227950188425, 45.19964448867306, 16.05540938915745, 0.28998683296865035, 0.018262432948235544, 0.06292437068036487, 0.10602328986410173, 0.4077321873797525, 0.44455751296012636, 0.020858471266805165, 0.4249579501488517, 0.16079056317046767, 0.12750531456643535, 0.10314258476418835, 0.06811766539730373, 0.11617652125536435, 0.320825518499459, 19.320454059108613, 51.195430524887584, 60.75876912763042, 47.37088034229894, 56.403620319981734, 39.209608647131155, 59.856890709169456, 68.00483026812154, 67.64212869828748, 69.87830331248622, 68.97399302451842, 66.92012233118858, 70.14231020404448, 71.03383356525053, 66.20683931535291, 69.97741376200031, 68.7455306514617, 70.55939935868787, 69.75548605765067, 69.19004501834993, 72.74395558141893, 71.2240057606851, 69.66738962358045, 69.67239456792032, 63.19165452834099, 68.77009253348075, 69.19290050383538, 67.74951534886515, 69.49693126063194, 67.89615708012735, 63.87793594791044, 52.65474050275741, 53.89811615790091, 50.39336466020154, 52.675419238305864, 51.478770779025176, 49.096668304935584, 52.04938150221302, 51.47985727556291, 50.548623838732325, 49.58636053146855, 46.707360436839444, 48.622100737787065, 47.34468283191804, 53.49017004812918, 52.08684405972881, 48.80771906145158, 45.60747684970979, 46.58724177268244, 46.78012040353591, 47.98230724949991, 50.918770067153446, 48.10595212444183, 45.07619573223976, 55.387608774246715, 62.73403160033688, 62.72391580766248, 63.738989906926314, 64.03452480992964, 63.77438145299112, 54.40536491332516, 45.8189671270309, 42.352458738511615, 49.80356177976055, 44.7120624972928, 43.110013546482215, 44.68299773431594, 43.554061151319935, 47.697637311873905, 50.8158431514617, 46.93218285037626, 45.94769147134597, 42.962501049041755, 45.61226606369019, 44.544326259243874, 47.27521373379616, 48.574534154707386, 46.41987031505954, 47.90991206322947, 48.55593819772044, 45.80858069081461, 44.3836110638034, 46.722708671323716, 47.39287699422529, 50.898518869953776, 55.88609495470601, 63.751643473102206, 61.41868437490156, 65.52974408672702, 60.974024880316954, 64.5805226602862, 58.53655030650478, 60.40178245113742, 59.80273846657046, 59.69463009988109, 56.57034850889637, 61.56409055955949, 61.776588886014885, 58.02871319555468, 58.943931594971694, 61.3199818518854, 56.11035646930818, 56.958553329590835, 58.049050684898134, 61.29127402459422, 60.06137171099263, 69.86546147254207, 63.356307783434474, 61.7467200371527, 38.81669305985974, 66.58966264417096, 55.723618615058164, 65.17485587827622, 57.083367070844105, 46.490496512382265, 32.596943609176144, 17.935802475098644, 2.009787420111318, 0.14251642439874912, 1.8308564924424695, 2.7382129911453497, 0.2926271703214415, 0.1948959088974422, 0.32261145331205865, 0.024859976406479557, 0.08043917076241586, 0.011924947611987593, 0.11471687095059503, 0.16459595171674607, 5.647154498484827, 31.798766774515954, 34.07752460049045, 40.29629345863096, 58.793512621233546, 30.92749264932448, 0.9304420986483175, 3.418829527593428, 26.904598013047252, 26.226581027430875, 36.37541378698042, 12.705207120987678, 1.4227989628430338, 0.13907426878088905, 0.5680088434488543, 3.513941611013105, 15.700085797617513, 40.74138049156436, 45.648975526132894, 19.605365222500218, 35.056760003489835, 11.196842020557774, 5.254979258583439, 12.870281050282141, 46.005942590775035, 41.33832208571896, 50.68411427159464, 51.01712742159444, 54.47380242809173, 37.50854730606079, 38.86209841697447, 51.86426524193057, 21.495274959071992, 0.4668326531687091, 0.10383519719565108, 0.2539693777479472, 0.19330250730197276, 0.3944967314600945, 1.617534345676822, 0.03753761881061139, 0.24872529140162855, 0.300932421439117, 0.02531330893567253, 0.08395099441610998, 0.010834288343997493, 0.08051757220058672, 0.4267602792430309, 27.328051213295232, 60.71953365879675, 71.36744683788669, 58.12996525918284, 62.526765715691354, 47.97432522619925, 66.28345104955858, 73.62098970720845, 70.241726598432, 74.0160822099255, 74.71603701191565, 71.26999947332567, 72.35576645020517, 74.51583923832064, 68.5641759441745, 72.63690625467609, 75.52501017047514, 72.52153365842759, 73.86820100968885, 72.40822422888972, 73.11984415977233, 74.25147933344688, 73.17321192833685, 71.3848856956728, 67.81687028946416, 71.03017007150959, 71.11256337934925, 69.45889211470082, 69.46490903054514, 69.92403030395508, 64.28980835022466, 54.00676188930389, 56.73715514521445, 55.326639452288234, 56.17616991842947, 54.222951166091434, 55.39670867304648, 53.61618403465518, 54.97237097832465, 53.844352229948974, 53.66766514316682, 50.929042754634736, 51.53377025358139, 49.33254787998815, 56.759716618445616, 54.567888321415076, 54.707234444156775, 49.41442735733525, 49.28367122527092, 47.214581735672496, 50.686993291301114, 50.75045331831902, 49.73573223237069, 44.041156768798835, 52.8837598523786, 62.55557944697719, 65.75686893155499, 68.14765945557626, 66.84843709391933, 66.97502766886066, 54.93410041255336, 46.52782178694203, 46.06637062564973, 49.369739793962054, 46.588728350977746, 45.18881482462729, 46.93997267753848, 46.04232649649344, 51.82342160132624, 54.321167315206225, 52.08884446851669, 50.380899367793916, 47.66200650122858, 46.905765687265706, 49.430108993284165, 49.860691101320334, 51.761648193482436, 49.988999674397135, 51.307602467075476, 49.76855462597263, 49.62421532600157, 47.96446438758604, 51.56307428113876, 50.1830824728935, 52.581764805701475, 57.974062811943796, 64.92687971361222, 62.651324502883426, 68.19915233119842, 63.765693403059444, 65.97283071087253, 58.83476026596562, 61.01473123796525, 63.397578962387584, 63.09842763408538, 58.895866870880134, 63.156380653381355, 64.86745580550163, 59.47432625678278, 59.25809383392335, 65.08639858615014, 59.31741968277962, 61.52775764465333, 62.361406433966856, 65.00737851665866, 62.601890871601725, 70.81793846622591, 67.95174491020941, 60.19584624998031, 48.222391605377204, 70.25498420961442, 63.58854739896713, 67.6978498889554, 65.19194956748717, 58.06672880726477, 43.84390077283306, 31.507109134427964, 11.626404312349136, 1.0643907948847742, 0.7043971926454575, 3.744750296877277, 0.20968880624540392, 0.12318157560883031, 0.07852851683574338, 0.01355901794252737, 0.11201292531745088, 0.08456345872893449, 0.13492144403919099, 0.0849673479434944, 6.81553884860008, 40.25738354652159, 38.65646031595046, 46.67422033125355, 63.30064150594897, 37.627199003773356, 1.767935791323262, 7.76481322703823, 40.09826867811142, 44.6720229425738, 54.31149082799112, 17.3241735658338, 1.5235760519581458, 0.041832813332157756, 0.5308191358081756, 4.6114776595946285, 58.458808929689475, 60.331171943295395, 90.72363761163528, 81.57595649842294, 40.32400500389838, 12.653144521097984, 4.377241067347988, 30.20904975552713, 73.65480838283416, 61.45537814786358, 73.27234591207197, 62.732195931096236, 72.41627293248331, 49.009811339839814, 53.49397082482615, 59.6825138984188, 30.293343451715288, 0.821567276312459, 0.2100274017861774, 0.43254056584931194, 0.5788981397786449, 1.2868675084844714, 2.337810579807528, 0.17505070765412625, 1.124531270996217, 1.0241358162414644, 0.2659872288425123, 0.3036912266285189, 0.1668284085368918, 0.14748796730512573, 1.5355732340005137, 34.92801604732391, 58.6751707907646, 64.81700628034531, 66.17322460297616, 69.13666940504505, 56.33960331639936, 70.23935748684791, 77.04401862236762, 77.76259683793592, 80.54133722859045, 79.37149032469719, 77.37057162869361, 75.27724973617062, 79.35127442882907, 70.81851897701141, 75.63152605487456, 76.00492000579834, 75.87968657093664, 77.43594184998544, 75.6843525363553, 78.62782462950676, 78.46907846389279, 75.90809237572455, 75.76602412808326, 71.35517766398769, 74.15104312281456, 75.26891077718427, 73.03390502929688, 72.37972428721767, 74.00349140167236, 69.7137991074593, 58.90562180549868, 59.785138791607274, 57.9650374381773, 57.9179415395183, 57.65441709949125, 57.7890093095841, 58.409814603867076, 58.99966063037996, 55.47232020285822, 57.871747785998934, 51.83891496350689, 54.86894592162102, 50.728174255740264, 60.241604620410556, 59.18607911755962, 54.61173649757139, 51.5868006983111, 52.42972197071199, 48.601147436326556, 51.97836699024324, 52.48894583794379, 50.085701788625414, 44.68758298504738, 56.19544444545623, 68.00955280180901, 69.79362718520626, 72.57931801580614, 70.250991236779, 70.631696485704, 57.8225455745574, 46.75013780593873, 52.18398940178656, 52.610453021141794, 47.23843366869035, 45.8275806519293, 48.30888379004694, 47.316684953628055, 53.8911461061047, 58.465622086678785, 55.641805818003995, 52.63842344284058, 50.487509389077466, 51.681749513072354, 49.8018124026637, 52.575296817287324, 56.533603745122115, 52.21951038606706, 52.18846874852335, 51.37778151419855, 51.04149710747504, 50.06568985600626, 55.12112294473956, 53.879006370421386, 54.66280967958512, 60.46030813647855, 70.38297899307744, 66.28344320481824, 69.70637013835292, 65.8661187079645, 69.82832447175058, 64.11589437915434, 65.72219910160189, 66.44283263914048, 63.00276494795277, 59.39048559434953, 68.31373260867211, 68.33016733969411, 63.29912354869228, 62.23454521548364, 63.98917436599732, 60.362323407203924, 61.03684948336694, 65.42980993947675, 64.70495593163275, 65.72514087923112, 75.5347768722042, 67.67229172491258, 62.85341678127166, 47.92531521089616, 78.11583765091436, 66.88978672027588, 73.00044721172702, 69.1822002780053, 65.9869041750508, 53.98834636134487, 43.14109048535747, 18.56446623802185, 2.446645320423188, 2.6952144984276067, 6.904996835416363, 0.720643098315885, 0.43032510085932674, 0.5940198573854663, 0.15026950998412025, 0.4277123426718097, 0.28717351296255667, 0.4646623873662564, 0.5911559142893361, 13.555663266489583, 53.8408338639044, 49.17885372715612, 58.21956788339923, 75.42045547116187, 49.33808626667146, 2.0187366753816605, 9.468147581623448, 57.476835712309814, 66.46872812701811, 76.94397464875253, 41.053577623059674, 3.8938030600547795, 0.21143363277998664, 1.0502455023027237, 14.201190279376123], [9.790796849035448, 25.626685888536517, 41.52687041990219, 33.198086061785304, 0.7264091050432575, 0.2345072970755639, 0.662750385461315, 1.268640009145583, 15.427559518044996, 19.218901934162265, 30.06957615575483, 35.59334416543284, 33.06855763158491, 52.3537927289163, 69.2415222044914, 38.95219525983257, 10.030748824919424, 0.280693328428653, 0.0447741121564421, 0.24647083253629748, 0.18559935532750624, 3.31516103879098, 4.5659963065578095, 0.10724976598735779, 0.03523169032808754, 0.01903007603100231, 0.07340891211624108, 0.06475681469084756, 0.012066168259949455, 0.15085061831820398, 0.11031456967635501, 6.432027634113066, 23.548802445011756, 43.81302779720676, 45.22413969039918, 45.69201569403372, 37.743995420394405, 43.899445456843225, 61.15782322422151, 65.03050873356482, 68.0056853448191, 68.63844210101713, 66.68624708729406, 70.17765860403739, 72.94631850334906, 64.03943953975555, 74.38665205432524, 69.46427360657724, 70.30922274435721, 71.26915224136846, 68.58520769303846, 68.31672145474342, 67.16433694285732, 66.42323647775959, 68.26767613810878, 66.37736043622418, 68.3728035034672, 66.01132485174364, 64.96504045301869, 68.74307524773383, 65.15875454871886, 54.58423283792312, 52.165189481550655, 51.39493796133226, 50.14412156997189, 51.502701159446474, 51.45121612856465, 53.02987990840789, 50.79908286371539, 51.566686784067464, 50.80864952456567, 49.10763917430755, 47.878325216231815, 47.36702073004938, 49.67154264450074, 49.85210111064296, 50.86011494359663, 53.401285217654326, 47.14118242263795, 43.295478897710005, 45.249176179209066, 48.23609636675928, 50.408799186829604, 48.33125306713966, 46.09759269222137, 45.804038586155066, 56.28867526208201, 64.53666271701937, 64.60039338757916, 62.65658047891433, 57.46797115572038, 49.659787301094305, 48.74980134348716, 48.960118832126746, 47.18530516470633, 43.86001386950093, 43.81005856298631, 44.12560932097897, 45.734961725050404, 49.70103102345621, 46.649791809820364, 49.02750515168714, 43.74440593104209, 46.30223843359178, 44.543988935409054, 47.80265877323766, 46.03330112272694, 47.05009714249642, 46.265521126408736, 47.53544338287846, 47.000098689909905, 47.21648800757624, 47.43067295320573, 46.44998235087241, 47.38715033377371, 50.01548351780061, 52.726778753342174, 61.51932454878285, 60.66341238637125, 64.80182278540828, 60.645789177187034, 63.62594327618999, 55.60475118698613, 54.73757397743964, 60.54894978000272, 60.151915704050374, 58.801843735479544, 58.37843564248855, 59.623737181386645, 55.5884615836605, 56.58392383206276, 65.6047829504936, 59.247083740849654, 56.42288307989798, 57.45815738554924, 60.77093239753478, 58.84808063507081, 66.34915074994488, 67.51764835849886, 60.483461887605735, 43.55553596250473, 55.19587547548356, 52.929502533328154, 55.8216582575152, 57.00073842079409, 61.86641508533109, 44.003219604492195, 15.18475107608303, 1.7898155075888482, 1.5810891529244762, 2.3644076816497313, 1.4140539159697871, 0.18117908929144183, 0.12425514058239999, 0.016962900765300278, 0.10316923696307406, 0.08692931443933519, 0.059351995437135624, 0.12803886416217974, 0.12506071267829788, 4.015486014466132, 30.84691343768951, 25.41821583624809, 42.733697429780044, 57.09051362929806, 22.728879990116244, 1.3477262686337195, 6.346710199309934, 28.32620224645061, 29.676217340653945, 43.54711463374477, 4.109845493108996, 0.10776574152611917, 0.1146228489796481, 0.06105097160945016, 0.376080958352935, 2.7918415973263406, 39.36815084949617, 54.43422571305306, 29.795510345889678, 1.466962889798226, 0.23245370646397914, 1.6635067304295879, 16.67542334525816, 37.500333862919966, 40.482755091882524, 40.36589199496854, 53.49669687209591, 48.289797536788456, 63.55108091908117, 76.92420590308406, 48.915482259565785, 11.929010268180601, 0.1512180034431719, 0.13162248557613743, 0.4568122231191205, 0.08370986824194271, 1.1118862850050772, 0.7108856509289434, 0.19844533214646004, 0.07351311539570171, 0.007682531281569673, 0.08737010610920769, 0.13762168946766085, 0.029286911237924814, 0.13784531053275834, 0.07818900198946077, 7.480353136216441, 28.67908024018811, 49.8951961917262, 53.78749747430125, 57.19002416056972, 45.90857759598763, 49.595158407765055, 68.09156956211214, 69.19321429344916, 73.73170252769225, 74.43634063966813, 70.86165720416655, 73.48454613839426, 73.04961019946684, 69.08847132036763, 78.64423582630774, 75.56246096088041, 74.30611794994724, 73.71544038095783, 71.93489613071566, 70.26832811294064, 69.41446735012916, 67.83519560290922, 72.59390923284715, 70.35669126818257, 71.73374914353894, 68.11183252642232, 68.98493643729918, 71.27701267119377, 66.51011697707638, 55.32554903338033, 55.35027565494661, 56.55885204192131, 55.180539008109804, 52.87014922788067, 55.37448060127997, 54.49759944792717, 53.78875263275639, 55.53956923946258, 53.83648395538331, 55.12278602969263, 51.1682524219636, 50.19799532428865, 51.43616991658365, 52.012617126587905, 55.60641427193919, 57.80293764606599, 51.40859957664244, 49.452074266249134, 48.46702591065438, 48.28354920110395, 48.196131337073545, 51.26509181914791, 49.89378413846416, 46.328008405623905, 55.9479271981024, 68.92943489936091, 67.83328148626512, 67.12042993114841, 60.229731605898955, 50.97409902080413, 50.641976248833444, 52.951271687784505, 49.42285653083555, 45.750451164860884, 44.89336621376776, 46.740928080774125, 46.681127625127, 52.691355828315984, 50.38762623263944, 53.27168618479083, 47.57332955637286, 48.425472321048865, 47.847252199726725, 48.93376442693895, 50.8765261403976, 50.189193525621974, 49.48740305439119, 50.93832700483261, 48.48015800599129, 48.99297260469007, 50.5847567127597, 49.61742178086312, 48.57370261223086, 52.34495955128824, 55.32514895162275, 63.18843034005935, 63.618220129320704, 66.12581883707355, 62.10376554919828, 64.52287950823384, 59.04874517071632, 55.920831464952045, 60.84791675690682, 60.557680976006296, 59.784581815042806, 59.4715609858113, 62.090633453861365, 58.54597576202885, 59.215077200243556, 65.36646758356403, 63.2780094300547, 61.07578292969735, 62.26584180708855, 63.23458486987699, 64.28599972878733, 69.89539700169718, 71.47218196622788, 58.166141279282115, 48.59054919212095, 61.64041203837241, 55.64061733984179, 65.23945731501426, 65.74159914447416, 72.62284063523816, 57.63729595368909, 30.3557110986402, 8.979413394005068, 3.675199074129905, 1.575945822461959, 1.4697953313589098, 0.061155213193307, 0.0529382192349482, 0.05508372890612772, 0.035137760287691513, 0.03904857785410939, 0.049288580194115646, 0.06585808906463847, 0.22113563072296882, 4.32089033626741, 37.32954602087698, 34.82583045959473, 51.22897463460123, 64.77362094386932, 27.390283538449196, 1.5886793069301115, 8.488564068271268, 40.9417861507785, 48.45762791172151, 67.74477712569698, 18.727615264154252, 0.016871221108181823, 0.16116617607974237, 0.0923414881371202, 0.14758401940907204, 24.31352146210209, 72.59443483045025, 82.39049157788678, 67.77217095898044, 2.4439327563008955, 0.5356020372240775, 2.0125241313249838, 50.403774630638864, 60.00542694522489, 67.60038683491369, 64.1648102575733, 72.70030744614141, 60.09418233748406, 79.29392937690982, 90.77633073253017, 58.159653679017104, 18.572518863985618, 0.5583425298813851, 0.27734659672264134, 0.8860372523626975, 1.3642654327615615, 7.244518178124582, 14.103180054695377, 1.1892196127483923, 0.10808861694268643, 0.08952448324811074, 0.21644341879554335, 0.21891235163615597, 0.12659199220398742, 0.405450992045864, 0.4651592107069108, 13.36306312391835, 50.727174051346324, 56.22158704265472, 56.67082002086025, 60.84611246662756, 57.40167917743806, 55.11499228016023, 74.42237700185468, 73.1386480023784, 79.30898343363117, 77.60358395115023, 75.39560333375009, 79.36201387836088, 78.70784882576235, 70.34799929588073, 80.34272409254505, 75.70973811611053, 76.85836499737155, 78.08972251030707, 74.8836555788594, 73.95001380674302, 72.16260540869929, 70.74949310671899, 78.13401391429286, 73.03399916618102, 77.23872507772138, 70.93068307445895, 71.04192149254584, 73.80694927707796, 71.43648055291945, 62.37799805979576, 60.31987551719912, 58.79594841311055, 58.39209333542855, 56.16555206237301, 57.77477502822877, 58.51110981356714, 59.16447078028033, 59.37799676772087, 58.26235309723885, 57.47242304586596, 53.00780873144827, 51.55632780444238, 55.67990772185787, 55.127532097601126, 58.08668974907168, 60.551813110228515, 53.95397463152486, 49.08010805806806, 49.23967007667788, 50.23824668699696, 51.28643343525549, 51.26675490410098, 49.052133713999105, 46.443479061126716, 59.139897131150775, 70.70667651391798, 71.81549133793001, 71.00465897590884, 61.17840782288582, 51.46551709021292, 50.04081418437343, 50.06394440127958, 48.855987748792096, 45.950554801571755, 46.5537957222231, 50.121999402200025, 48.98233121441257, 54.08718224494688, 54.48376524832941, 57.63774702625891, 49.60885532440678, 50.8699522479888, 51.375443781575854, 51.503214989939046, 55.75772754607662, 53.70630048936414, 52.970895305756606, 52.495727615971724, 50.73959227531187, 51.26242068506057, 53.79037649400773, 53.115018875368186, 52.77804805386452, 55.986935169466086, 58.89167385716593, 66.74327834959954, 67.23781078092514, 68.13056576636531, 65.57875017965993, 68.37512554660921, 63.70941915819722, 57.700242150214414, 63.891185714352524, 61.7721801419412, 62.46766736430507, 64.956807398027, 66.05619676651494, 61.132833803853686, 61.77485519839872, 68.24211012932562, 63.457355883813676, 61.174003001182314, 64.56905757227253, 66.02027570047687, 66.05141931964506, 72.00369450353807, 70.67587806332496, 65.23379341248544, 50.86620246210406, 66.63166338397612, 63.57170866381738, 67.18808297188052, 66.66098702338435, 69.04011634088332, 61.208284516488355, 45.45834441338816, 14.544800692988982, 7.698088807444419, 6.958513163751172, 4.075431107513366, 0.30485577220397614, 0.1834421896285588, 0.332411740335726, 0.352631650504566, 0.2658442155488076, 0.4781801007207363, 0.4973557104747142, 0.37771085637711715, 8.092183557248886, 49.134801587750836, 40.55497769386538, 58.06817223948818, 76.51806016122141, 38.61247877920828, 1.6965007277265673, 12.719237439094051, 58.93470618032641, 68.21030755196848, 81.52076875009845, 19.1468224986907, 0.5161805438899225, 0.22825074892851616, 0.25698638521134853, 1.0576324285038057], [0.05476584072194753, 14.963990276859654, 30.122361452348773, 7.505714201158093, 0.10239896619872701, 0.17947966112725197, 4.5771368184397305, 16.20892507414664, 8.13211573708442, 17.699093318754628, 16.272453742642558, 19.390325200173166, 35.88948703581287, 25.958781203915997, 44.10383624415244, 32.204345733888694, 2.5979394730060332, 0.17794501847557484, 0.04828316257185033, 0.25540239117558927, 0.22150099337581666, 0.5496905167256633, 1.7298077791929247, 0.1797060094653599, 0.04142918841793172, 0.08532760845076653, 0.08930704451256222, 0.08074414270419268, 0.04203275844995533, 0.14324241528107276, 0.029545381642697804, 0.7088868356039448, 9.67197060585022, 18.06375607367485, 27.414817963877034, 35.48387865866385, 34.3027235615638, 38.31903057713663, 55.869887721154, 64.56727681621429, 70.9078235010947, 67.54578744211506, 63.32333633976599, 70.20351486821329, 68.97811151319935, 66.43627443621236, 67.23814810475996, 70.91373843531456, 72.42438439399966, 68.42928563394855, 68.49247501742455, 68.50395187254875, 68.55512311381679, 62.76612443308677, 67.87427025456583, 68.89312944104596, 68.46225707761704, 67.02364152477634, 64.72024533056444, 64.15322749845444, 61.38871354441489, 54.24892117900234, 50.78378562004336, 51.22663690197853, 51.008094203087595, 50.00082954283684, 51.83147814966018, 52.6757683292512, 51.14764036670808, 50.38313511879214, 50.63436685069915, 49.74866428682881, 49.25289630889893, 49.16802406311036, 49.73197460174561, 48.48364107070431, 51.10916976005801, 50.32230700215986, 50.854537333211596, 42.51196584393902, 45.01711307033416, 47.42210649674939, 47.18850974113711, 46.798496707793205, 47.25946933992448, 48.5299877966604, 56.61048612286968, 66.81445367874639, 65.45475621377268, 60.66939007851386, 54.64559439689883, 50.61309191488451, 56.23504077234576, 51.511930496461936, 47.35996046373921, 44.3160286257344, 44.44007750480406, 44.099690298880304, 47.60895644464801, 49.400530399814734, 44.22919519485966, 45.00699335528959, 45.18521408880911, 45.03127282665622, 46.826769151995265, 49.946265451369754, 47.66261839097547, 48.684085953620176, 45.701496062740205, 47.18385781011274, 45.953743688521854, 48.069462314728774, 45.00940953531573, 45.06562494462536, 47.5667360521132, 46.26399140204153, 47.12818368788689, 57.235731540187714, 60.921657316146366, 63.77223199413669, 62.046597003936775, 60.333544977249645, 54.135113608452585, 53.03473580268122, 58.1572453437313, 57.21274252860778, 62.33713480734057, 56.15055291883407, 61.102882585217884, 57.99522007665327, 55.09686700759396, 59.869053979073804, 59.1479262228935, 58.047442513127486, 58.627698344569055, 57.271295670540106, 59.61175826288039, 64.67776998396843, 63.78705855338805, 55.04793936206449, 39.763227662732525, 55.81448032009987, 52.97359781880533, 59.37993049621583, 71.87092227320518, 66.25483343678137, 48.17801783161779, 21.687879024013398, 3.573847480358616, 3.86239345515928, 0.9568593843329338, 0.17411968099974817, 0.185773165355767, 0.01805562942829584, 0.07620183120091116, 0.0525208545338002, 0.04121603211387992, 0.05811659822000131, 0.014124377424107685, 0.2620241334361415, 2.8774291853750906, 22.771100382651053, 20.18342060427512, 36.92997417142315, 62.42474486750942, 11.390379609600192, 0.9665312750204917, 4.233105240329619, 38.90777441763109, 28.934716793798632, 59.80363276696975, 29.461077297887496, 0.09599406512514239, 0.03552151288116171, 0.09020093122437116, 0.09582709626204546, 0.03713094486644672, 5.641943139414634, 22.481723600818267, 4.310574502714219, 0.06599355639228899, 0.23787895728263164, 14.999410260108212, 41.766468401878114, 28.21891757749742, 33.341319253367764, 30.843348003202873, 36.50004317683559, 55.75252648322813, 42.21139461763444, 50.570695015691946, 41.188981763778195, 3.1083226924942386, 0.07491180808433602, 0.2741450540000393, 0.2953313994071176, 0.28677205224671676, 0.19459413154230965, 0.5269436502168255, 0.09937209918374017, 0.009420519045013334, 0.03967171760215875, 0.051935934912293195, 0.06536476674579805, 0.05426574618585649, 0.10289896880426716, 0.08681899011735955, 0.3650342156329463, 8.872881820124965, 15.557188949277325, 28.470123813998317, 40.72331405455067, 46.324960724000015, 43.73562766659645, 61.51391952268539, 67.9701800500193, 75.27340581340175, 73.81218171888783, 68.52539154791063, 75.89474847239833, 68.03036489794331, 68.4684544224893, 72.71204317769697, 72.24522621400895, 73.20372012353712, 69.4149301898095, 70.1844129254741, 68.66629092924057, 72.26876043504285, 66.77151157009986, 70.40301445991763, 72.18376267340876, 72.68433555479973, 69.16317678266957, 66.66300312165292, 66.63961795068556, 62.7599859237671, 56.36767179735246, 55.60035813239313, 53.126397671238074, 54.38908707711005, 52.45563707044048, 53.30539503405171, 55.666571663272, 53.81605232915571, 54.54806466256419, 54.60458601674726, 53.323771338309015, 52.08695388609364, 52.337534504552046, 51.90028044485277, 50.88470820457705, 53.54663256675967, 54.64692015801707, 56.65019619849421, 48.23978731709142, 48.742615561331476, 47.59714618805916, 46.72319896759526, 45.877014283211004, 48.649749525131725, 50.161893829222656, 56.24445053838915, 66.99956601665866, 65.68243411279494, 59.8008910302193, 53.72341771279612, 51.81904815858411, 56.42143572530439, 49.6652001719321, 47.741461953809186, 46.342917334648874, 46.839709051193736, 47.44720574348204, 50.69989004442769, 51.18568735737955, 48.04310790954098, 47.108344339555316, 48.98299017260152, 49.49022716091525, 48.41776094129009, 50.223847666094386, 50.659693594901796, 51.62598517633254, 47.84766797096499, 50.070777170119754, 47.71964965328094, 51.152837507186405, 50.290598561686856, 49.33831376414145, 50.30855909470589, 49.49205106304538, 49.20108179892264, 58.87519598007203, 63.829306402514064, 66.09328669886436, 64.4296722258291, 60.05529595959572, 56.13576166091427, 54.4411055503353, 59.533707018821474, 57.067646211193455, 64.64637533310922, 60.77363098821333, 65.7490594925419, 60.27333659510459, 59.050008173911806, 62.106268021368216, 61.52556111735683, 63.81659792315576, 62.64263253058157, 60.8604879533091, 61.615873690574404, 66.18819236755371, 67.79010403540828, 53.45372730685819, 47.48488403135731, 61.125561729554214, 58.79566600245815, 67.4299127824845, 75.94232682258853, 72.71415341284968, 60.873023848379816, 37.699154884584495, 8.49662846134555, 3.8972812218050805, 0.9980652313078604, 0.4323070928935082, 0.16976704520563926, 0.07221716275859265, 0.030566253173615665, 0.04767013135396185, 0.08721711068984964, 0.1338411681354046, 0.2171858958899975, 0.2730841447989787, 3.9774596162380713, 28.561309114579235, 27.778680555282104, 49.984579163212935, 69.98466230207875, 14.594968788085447, 1.3208381759543575, 6.028750125438937, 51.96687836800852, 47.55948751203476, 73.67846027497323, 51.16440457682456, 0.9500358698348846, 0.21208074724962636, 0.08352993717116695, 0.1866726138659062, 0.10090766114092643, 38.296092556368926, 74.6219236620011, 18.971512163839034, 0.19223229779351145, 0.3010502151183544, 24.082991999964563, 73.55916530855241, 46.21718183640511, 63.21822466388826, 59.321279295029186, 59.10289349094514, 68.33226188536614, 49.828519821167, 62.78341816317651, 53.318044677857436, 5.737324395487386, 0.22729617273134572, 0.7868877017209608, 0.6890368846154983, 1.3190037324543924, 3.2913554387707866, 5.866091885874349, 0.9440371562396327, 0.22221169314317166, 0.28717599508743136, 0.14934448945906856, 0.21359303545567299, 0.13145860404737536, 0.1794067295568605, 0.5838582832967082, 0.9693700291456716, 20.291780002655525, 40.10912972111856, 46.84961303587883, 52.671316439105624, 54.71418880647229, 53.590712162756155, 65.22649388159475, 74.68572493522399, 80.20385649896438, 80.07125685291906, 71.86215185349988, 79.09103301263626, 71.43052639499788, 69.88643046348326, 75.02213878016319, 77.63148769255608, 75.17307942913425, 72.44099170930924, 72.17096005716633, 72.74459885012719, 75.40974740059146, 68.8618524612919, 73.54498201800932, 73.7501141332811, 75.20302280302971, 72.69755394228044, 70.65155152351626, 68.60117173963978, 67.14304631756198, 60.64441242525655, 58.545473698646795, 57.16232046004265, 59.29060636028167, 55.153917881750296, 56.601668634722316, 57.86881385311004, 57.82648755658058, 56.01717664349464, 55.134251117706306, 56.03141484722015, 54.92564770483202, 56.434391313983554, 54.73451452870523, 53.60440123465754, 58.83124582229122, 57.67885346566477, 57.04975235846735, 48.77262953789004, 50.1794268238929, 50.292595048104566, 49.37339936533282, 46.218507597523356, 48.854399188872314, 49.86449580038748, 60.97873956926408, 72.95581063916607, 71.25886778677665, 62.98809920587848, 58.24165867220972, 51.759314383229906, 59.423778672372144, 53.66084021906699, 48.806816916311945, 46.05194807052613, 47.45577612230855, 51.47762152456468, 53.09042169201759, 52.14107474973125, 50.75068081578901, 49.83641947469404, 50.33671779017295, 51.98652944257183, 51.267511921544234, 55.23738591901718, 54.13362310778711, 54.87096201988959, 51.717584286966634, 52.59870944484588, 48.40033777298466, 53.94061503871795, 52.809517229757006, 51.82610842489427, 52.43289124581122, 49.400138162797504, 53.5018704783532, 61.66480525847405, 67.64091276353406, 69.15191958027502, 67.50033501655825, 63.75531088921332, 58.24566733452582, 59.091459781892844, 59.82978713127875, 58.11589179500457, 67.64219145621023, 62.422611098135675, 69.16423582261609, 65.49256393986364, 61.18268320637365, 63.875888470680486, 60.0624385956795, 63.51707396968719, 62.490856416763805, 62.91226410096692, 61.534123651443, 69.99209911592546, 66.44778267029794, 58.6487889289856, 53.98373757639239, 68.16135637221798, 63.4649613595778, 69.91228672765916, 77.35758073868291, 74.29585702957647, 58.29095502053538, 52.25587860230477, 33.252406966301706, 7.3787000102381555, 2.3126571553368724, 0.5324860205573421, 0.24285158803386075, 0.2936206637851654, 0.1925709086560434, 0.23568713376598976, 0.1976390552496718, 0.4016245973687018, 0.40791641620378344, 0.5598031837613352, 6.132404150501375, 39.41189312165783, 31.61723359938591, 56.271032441046934, 85.74890336682721, 25.828236879840976, 1.6344249296572901, 12.636051812479574, 71.42629023521178, 61.91277750076787, 84.59155313430294, 52.3895098317054, 0.2664107528905715, 0.2308129299912722, 0.14367511706246486, 0.35805708518432033], [0.05446619692168409, 0.2226617085116525, 0.5073875399126161, 0.08957222584755191, 0.00563751750310222, 2.5330843079474668, 22.347351043455063, 23.745173946503673, 12.209347947951287, 7.887100471604255, 10.234245311829353, 27.426885135712165, 39.32076077307425, 13.643512591238945, 32.06690196068057, 28.417307138442997, 1.4691686101498143, 0.04067947562303274, 0.40442857110211927, 0.07061780865995154, 0.08826286667176793, 0.7315298205902501, 0.18819337500439537, 0.04783335404710905, 0.06850329107574879, 0.007537695177410159, 0.07160451458466631, 0.008159128464608183, 0.06918031361795242, 0.07241437677294016, 0.04698947755499713, 0.20276294240067083, 1.4849068753180967, 4.719929723970352, 12.108829367545344, 15.597453059688693, 33.372176539513376, 33.56348229992774, 46.527653125024614, 59.12713766098023, 62.94855386980119, 66.34800541785457, 62.7885486233619, 70.54248609850484, 63.21284709438201, 68.55348356308477, 70.56119580422678, 64.6766560308395, 68.33501538922711, 70.06382357689643, 65.4797181775493, 65.59401212200042, 68.70851916651573, 65.22720775296612, 66.46488420424923, 69.73814133674868, 66.56154709477579, 65.1096974649737, 67.20931868399343, 64.22461855796077, 57.591972966347974, 53.39792766878682, 52.59803087480607, 49.86371524872319, 49.21712429292741, 50.56746690504013, 51.243283440989835, 51.85059185950987, 49.680701378853094, 49.44777927091045, 50.846014022827156, 51.70457770747524, 50.16234882416264, 50.45242771025627, 50.29004158512239, 49.10408158456126, 48.6245326072939, 47.58083697288267, 49.921915377340014, 48.45583931092293, 47.31227228718419, 45.69995457126249, 43.653822714282626, 44.27931524092152, 45.421697708868216, 46.46815076951058, 50.569075076810776, 57.625701427459724, 58.150208611642164, 49.74352598190308, 46.02465229649698, 47.965366532725675, 46.14800299367597, 42.35874629789784, 41.4430062232479, 41.90448091876122, 43.7307325486214, 43.94972239771197, 44.95161733319683, 46.0683592673271, 43.2246095134366, 45.3318009068889, 45.533767669431626, 47.928155006900916, 44.30846629604217, 48.4055898266454, 46.040761470794685, 46.68863504163681, 46.34319582293111, 46.315299926265595, 48.24977367155014, 48.71084436293572, 45.40912259009577, 45.031229680584325, 48.19184026410503, 46.58981092514531, 46.530143830084036, 53.741252729969645, 59.781137974031516, 62.70945795120732, 58.21480220363986, 56.95720795662173, 56.646936708881015, 51.201419984140706, 54.1795148388032, 56.395932474443995, 55.7149854783089, 59.38557478689379, 58.682391874251834, 57.76738920519429, 60.2498729767338, 58.6554059674663, 56.95050462599724, 62.661381460005245, 57.679704619992165, 56.75691212377241, 57.64544663890716, 64.04102809967534, 62.76580672110281, 47.85347700119019, 39.361592646568056, 51.694230494960664, 55.27260880316458, 55.61901684730284, 67.6738057597991, 61.19123005097913, 55.463400733086374, 37.138044141954, 14.292918828225906, 4.215934084307763, 0.011960759349617989, 0.03216937259440461, 0.049784154811453436, 0.038527346952187444, 0.07013299757794988, 0.1392829204879461, 0.022679136675452034, 0.0727716648590661, 0.12240587328110011, 0.12909870084014632, 3.058172493211685, 22.570943793942853, 25.08051741507746, 36.46416917923958, 49.078303767788796, 6.576904298797731, 0.5089034746971823, 1.332250189396643, 32.2904456815412, 37.62861497940556, 64.91039399177798, 63.593901434252345, 16.568611321910737, 0.24922710963554923, 0.0866317735504239, 0.11485985360078274, 0.0363169189903044, 0.11987923869803069, 0.8499901801828416, 0.1461785238596701, 0.5263558462742837, 9.961778848401963, 50.245369711229884, 48.378423490831935, 31.847353173840432, 20.206144855868434, 13.549511028874306, 39.53319241923671, 52.91995156195856, 20.624922590871012, 38.87546193215155, 38.07196440235261, 1.438896002308015, 0.04659701071138825, 0.3727770356401321, 0.2790413670722516, 0.06921384528639817, 0.033006411751792315, 0.03899001809317739, 0.06330457628674566, 0.05922214353397008, 0.02709774030072074, 0.16512770866674764, 0.03437240397737872, 0.04765012879825888, 0.05210560806576283, 0.08656670204213551, 0.14865661911185712, 1.3785540144289694, 6.216850819126253, 11.367086614331892, 15.335300468629407, 42.96992609577794, 43.785041686027284, 51.71033182451802, 65.58775201920541, 65.6285172124063, 72.34473674528061, 67.44003249752906, 73.70607376098633, 65.82112912208804, 69.42771711657124, 73.75133006803452, 69.33929120340656, 71.23721630342546, 71.77326310065486, 66.2995719909668, 66.16359126183295, 70.26085992013255, 69.55458225742464, 71.15418757161787, 69.68664846112652, 69.93450303231516, 67.39651772283739, 66.9010909911125, 65.8650125995759, 61.12011355738486, 57.312602150824766, 56.76529030646048, 51.99829655308878, 53.13070835605745, 53.921085557629986, 53.6449428527586, 53.3192684573512, 52.93730412760089, 51.85787962329004, 53.68798694302959, 53.41739046958185, 54.427032086157034, 54.536081821687766, 52.879386409636474, 51.790709034089126, 50.90685782894012, 49.16023031357796, 51.453259683424434, 50.35635709762574, 49.49488693667997, 48.28463569764168, 44.528068034879624, 45.04411074423021, 46.06473891965805, 47.93200285203996, 53.406015596082135, 57.93822411567935, 57.84210251223657, 50.68791112592144, 47.852959248327444, 48.24010502907538, 46.70906274549423, 41.2978079242091, 40.461468388957364, 43.54937391896402, 44.790317704600675, 46.5485397461922, 46.38050540801018, 48.13132201471637, 45.03401848577684, 48.58011960983277, 49.452321375569994, 51.26518595603205, 48.82864882869106, 48.9091750883287, 48.31703055289484, 50.51740569453086, 48.85971792282597, 49.35643511433756, 50.49334587589387, 51.4517770274993, 46.81611599460725, 49.31730162712836, 51.548161429743615, 50.18432194186796, 50.079673105670565, 55.947378066278276, 62.57575219677341, 65.05110117696947, 63.82150088587115, 58.034557527111424, 58.881762027740486, 56.092909766781716, 53.49751272509175, 57.31319835109096, 57.03329409322431, 61.88414027613979, 60.760867595672615, 62.34233587018905, 63.01119412145307, 63.38307795986053, 58.889963703770796, 64.85491598806074, 59.97695446014405, 58.06326927677278, 60.56891856654998, 68.8082964189591, 64.9204078028279, 50.48097864274056, 46.63039176694809, 56.50766903354276, 58.77655229260845, 60.652974959342714, 71.55468510043237, 70.85924102414039, 67.69657119627922, 53.0809138667199, 21.786405040371804, 6.236720075530391, 0.3395819249412706, 0.02231871912015542, 0.06599097467598415, 0.03984189637365841, 0.07468555167677902, 0.04050372739232356, 0.025339618310212128, 0.08777385742794122, 0.04775248197538238, 0.1421681914718882, 4.696177321095621, 30.311343208436046, 26.98385930830433, 43.18944938721196, 56.685838776250044, 10.294686094407114, 0.8020669678526541, 0.949949271255924, 38.24419567661901, 53.05965069801577, 72.67904819980745, 83.90518542258971, 33.35470630276588, 0.31886960409822007, 0.07475888161289115, 0.12405201236927703, 0.18309495261599942, 0.37003315384349517, 2.5455606320211968, 0.3204547319441073, 0.6231343854338892, 8.778943015683083, 74.47605856003301, 65.35447297557708, 54.70604204362439, 67.55273003732005, 26.608402190669892, 57.4571571811553, 70.27367822585568, 32.607208451917096, 49.86312689319734, 48.32967627433039, 2.8044348570608326, 0.21974847531847416, 1.2082829446561876, 0.8432086473030429, 0.3793989770835446, 2.661761828968602, 0.7121674079568155, 0.2417450966013055, 0.1777838795415817, 0.12786588916975644, 0.19313389134983863, 0.14293784936589582, 0.22631305209811658, 0.1260476407685107, 0.3073956294646186, 0.47271078452467924, 2.0516361680723008, 16.843887182974047, 29.02772011295442, 33.42573650421635, 58.6991011711859, 49.862114921692886, 58.7038903851663, 67.20860481262207, 71.40294428794616, 74.96367977511498, 71.88132439890217, 79.21952201474097, 66.34287495766917, 72.71853862270233, 75.26818121633222, 71.614132542764, 74.68393633442541, 78.41526354512861, 70.41984142795687, 71.45572370098483, 75.64312842584427, 72.03964694853752, 76.15285611921742, 75.50959525569793, 72.67832648369574, 72.14452328220491, 70.99673578816076, 70.23986739497032, 65.0001338989504, 62.79973914546352, 61.71560387457571, 55.704740247418805, 56.72743943429763, 56.83082134492936, 57.90552331555275, 58.843216896057136, 55.22665039185555, 53.91285642500847, 56.167787813371234, 57.65626453584241, 56.173636067298155, 56.14495961896835, 54.419242258994814, 54.04197300634077, 54.69669111313359, 52.02269761793075, 55.501071176221295, 52.96890666407924, 51.00149285408759, 49.67886963198262, 43.499524516444055, 43.62753106701759, 45.85746519027218, 47.3670324971599, 53.29673051834107, 61.57863863052861, 61.507565283006244, 51.558485108037154, 47.76365080187398, 49.83989077229654, 46.222896729746175, 42.19237504466888, 39.95211332075058, 43.64071023079657, 46.45722696858068, 48.35664256926506, 48.341145284714244, 51.07581000174246, 47.23478194205992, 51.189174344462735, 52.153747927758005, 54.316762493502715, 51.01040447911909, 53.41751598542737, 51.52297589086717, 51.94490525030321, 51.81027773887881, 50.86249582229122, 53.70779883476996, 55.03751370214648, 50.27168489271595, 51.53542941616428, 53.859378830079116, 48.88524863027757, 53.440544220709036, 60.53820640810075, 64.82438818100961, 65.31060910994007, 65.65194160707536, 61.12774256737002, 61.21704316908314, 57.45419186930503, 55.595431635456706, 59.31808648570892, 61.350984265727384, 64.71518547304215, 64.79442519526329, 64.62765778264692, 66.02096603762719, 63.89120924857355, 57.1911185018478, 66.6655134385632, 59.50996098979827, 60.096841704460886, 61.30247239143618, 70.06502382216915, 63.23742466588175, 56.147211059447265, 53.50295305252076, 63.62307210122386, 63.14511560624646, 64.16638705038255, 74.28678850973807, 66.25964226261263, 69.03607629960584, 60.591468272670625, 43.85085905751875, 11.947684672570999, 0.5736592628302113, 0.17801968140467522, 0.21283416407963923, 0.06789028284049804, 0.25654177842361314, 0.3296890332093162, 0.09811547750066366, 0.26876956825294807, 0.2858568223253373, 0.3462448061233567, 6.221384588749179, 41.17985833075739, 39.72729090721377, 57.1859605850712, 73.98529160407283, 17.075281527734575, 1.167997874079212, 3.407365910468563, 59.26997469317529, 68.14350958793395, 82.05312067462553, 93.46148337087324, 23.332269960834136, 0.24670021458258554, 0.18569048914697864, 0.21137254492890453], [0.14114889616687454, 0.026688524859867273, 0.16406128363263223, 0.1293326487704631, 2.849828447065046, 25.76516124509996, 37.738076563804384, 15.229716147145918, 8.98171680588876, 7.449217852084868, 8.432880140119984, 23.288727729551255, 28.621972491664273, 26.919244143270678, 49.64303878045852, 24.610913607382006, 0.4289980527133711, 0.12621418828324926, 0.19085330888628962, 0.4013222684302638, 0.04135032732700629, 0.062030656338338895, 0.061087402920689315, 0.016184339014392708, 0.026504882093098377, 0.02332908183997197, 0.017131361584629745, 0.040791581099432324, 0.05354711740848519, 0.09408569414048426, 0.15908044041885486, 0.050186603780715704, 0.4721913156249831, 0.8806324101263477, 2.906322099508778, 5.693790499241122, 14.21239649095843, 39.959424618751775, 34.714721479723536, 56.59456129997008, 56.667274198224476, 69.14349432914489, 58.4550787556556, 68.34068713649627, 58.48809726776616, 66.84970009711482, 68.50808605071038, 67.86338959970783, 63.698377686162154, 62.04956231578704, 63.79993569466376, 64.27622125994775, 62.246896759156265, 68.00395950194329, 65.99609821073471, 64.11329777010026, 61.83335342714864, 65.0297752503426, 59.48017843307988, 61.429957266776796, 55.261885043113466, 54.48553423727713, 51.00925914702877, 49.877396475884225, 49.57304408473354, 49.292386731793805, 50.51291065831339, 49.462162602332334, 48.22745146289949, 49.22686746043544, 49.91427067787417, 50.82934394959481, 51.840079907448064, 49.978428886782744, 51.10335680746263, 50.92336316262522, 46.04925732458792, 43.99481788758309, 44.041584307147616, 44.91362917807795, 45.66433552772769, 46.76634503949074, 44.119976797411525, 47.50473122442923, 49.05565208004367, 50.9154321301368, 44.46189765007266, 46.306117657692205, 50.355050948358354, 49.38398192005773, 47.34352965508738, 43.616615110828036, 41.85411768574869, 40.1629917083248, 38.90962185398225, 45.86543152409215, 46.4413413693828, 43.895503474820046, 45.187881300526286, 47.91044158320273, 45.84742784500123, 46.07738856346377, 45.47568521191997, 47.29115032380628, 47.79743809853831, 48.23116594745267, 46.53971441330449, 46.049088662670506, 46.01042978225216, 45.34506636281168, 44.470926946209325, 47.77153084355016, 46.07001450753982, 45.63605916115546, 45.25880167561193, 45.44811487197877, 48.106634616851814, 51.16673446470692, 57.60123760469499, 60.02710196279711, 55.97080246094735, 56.234248453570956, 60.69796062284901, 56.46085162316599, 49.713555151416415, 53.47098573561638, 52.05623388290406, 54.52172594685709, 60.61594778491605, 58.32873529003513, 57.777006856856815, 58.35945921559488, 54.67802847585371, 61.442316655189764, 57.762831411054066, 57.38607991126276, 53.93058946055751, 61.27094437999111, 58.50834062022548, 51.04779251160161, 33.380503731389204, 47.789773787221606, 63.712623734628, 66.24653370149674, 74.03268168049475, 61.767108517308394, 48.592275034996774, 41.66849936208418, 31.86253078522221, 2.6549194993511325, 0.0742602886091317, 0.06243323171210866, 0.07299156273685156, 0.04701115401281465, 0.04470520637809269, 0.08321854541258467, 0.11020411511943226, 0.1362390233384025, 0.1141146032680427, 0.15852570083112488, 5.526609766867853, 22.721260786056522, 23.87685379674358, 26.61689216090787, 37.079110530114946, 5.388690406276334, 0.20726203888414368, 0.28675093886352354, 18.910274159523752, 47.694962255416385, 45.986687675599136, 89.02867163381269, 65.37737177264306, 4.772331118583679, 0.32288709174721475, 0.24673609814095884, 0.24837810035434463, 0.13677556067705154, 0.2612812732977252, 0.4100158648385156, 7.254646718502046, 46.69871553297966, 65.6368757832435, 28.20299863815308, 22.91865210379324, 8.161332982201731, 11.028015363600947, 44.644193726201216, 43.74584151852516, 37.05186574689804, 56.90097293546123, 30.857633275370446, 0.19734218085725463, 0.12700754127675487, 0.1331069494687742, 0.1869349683364553, 0.10680542733039587, 0.044467661664971424, 0.11191481243698828, 0.00456323575851838, 0.06369199078049391, 0.06024610814488223, 0.03731693186226391, 0.024257268223370758, 0.07310986203411896, 0.021400183529382753, 0.14418055123138812, 0.086405394568799, 0.3719234911184157, 0.4636951247530599, 1.4514370454895882, 3.131712276128031, 16.103553541245, 46.204551804450254, 41.87260381637081, 60.56083848399501, 61.82590876856158, 74.35422974248087, 65.59824043704619, 73.50295774398312, 63.07337153342463, 67.61868076939737, 71.16953188373198, 68.72627965865597, 65.79570431863108, 64.73602502576767, 65.42217700712143, 65.14206486363565, 66.29197043757286, 69.55783782466766, 70.48598043380245, 68.76065531084615, 65.40733475838938, 67.8143835067749, 61.167276136336795, 61.35417707504765, 58.34680564941899, 58.44615928588375, 53.457410412449995, 51.890851066958525, 51.30706902473204, 51.01875128284578, 52.8739421598373, 53.33868811207434, 52.46999294527116, 51.389685907671534, 53.18144421423636, 53.732466620783654, 54.90288619072207, 53.279785879196666, 53.38880423576602, 53.57023346808649, 48.83104147449617, 46.444181165387555, 45.77178493622811, 47.87244950571368, 48.41636849987892, 48.082747382502404, 45.361869796629875, 46.777009963989265, 50.87426293280817, 52.1359952803581, 47.432465476374475, 45.477928807658536, 51.015597697227236, 48.60932950050601, 50.23882327541229, 44.62191466362246, 41.46578342683854, 38.54828526896816, 38.607034529409106, 45.512641783683534, 46.44609528203165, 46.228654769159135, 47.511010939075106, 49.713610064598825, 48.04906206746256, 50.86843036836194, 47.27166006642003, 48.88069868087769, 49.05227099695514, 49.8489357579139, 47.70789823224468, 47.585641876343765, 47.32446693604993, 47.79029546245452, 50.151126923099646, 51.359879816732104, 48.97088181587958, 47.11801298203007, 49.7412000163909, 49.68642803930467, 50.516856562706735, 54.552057635399606, 59.60689452386672, 60.113405873698575, 58.80174959859541, 60.37043879109045, 61.77163885485742, 59.79825127509333, 54.47088418468353, 57.237100447377856, 53.10457752596948, 55.51152429273052, 63.31227917825023, 59.69932517697735, 60.28453103957638, 59.79670978361561, 56.562680275209495, 66.09477719952984, 61.07715575925766, 60.38123315380466, 56.10616345559397, 59.175731905045055, 60.612805966408025, 53.18817892382222, 44.09645826585832, 52.17450903308008, 70.50319963885893, 70.8989824787263, 77.74194948134884, 66.20150489191856, 58.650318653352805, 57.35598748730075, 46.793256421242994, 3.6780016076180244, 0.08140456412107715, 0.0372066458446845, 0.05334979614182826, 0.07711459431917438, 0.03473791218693218, 0.05281831881391907, 0.10353330492732987, 0.09414996891733139, 0.10695823888865211, 0.2554015178353556, 9.103736838986798, 30.27658904752424, 31.887990890010713, 35.34808228092809, 45.47098621245354, 7.739127585964819, 0.17929051401874713, 0.5859275787107406, 21.903691753264397, 58.471788052589666, 54.81925341390795, 90.20897557658535, 84.11041951948597, 12.174121141433718, 0.23729835456657797, 0.2501147910351715, 0.5729842474383693, 0.21934868467430915, 0.5959188974192066, 0.7135713100433351, 4.1837255416377905, 57.65847675261959, 86.03563647116385, 43.30682239224834, 61.213399287193056, 27.681299871014012, 12.343501833177383, 72.31765670161094, 54.84042636809811, 54.879097015626975, 70.98568254901518, 39.612989118022305, 0.841069668531418, 0.3654292105667053, 0.5873031049005447, 0.7429355214680395, 0.4986108995733723, 0.14495947878927956, 0.25367469436699347, 0.13045777146133686, 0.15387859616068103, 0.16887208597073633, 0.13196293504968767, 0.16674059953901077, 0.1593263239990319, 0.1272050234218759, 0.25249042968836527, 0.31067653889617614, 0.6503599245221384, 0.9979419217955683, 4.201537514886549, 13.885358091323608, 36.43461411999118, 63.438332388477946, 51.253713023278024, 68.4023154166437, 63.72642263289421, 77.324781879302, 66.54844637840026, 75.28231743843325, 61.282323175860995, 68.24047842333394, 76.17923798099642, 69.13824619785433, 67.911650442308, 67.37696078515822, 68.76791954040527, 69.40071552030503, 67.07331442063855, 73.57100302173247, 72.38751411437988, 72.25257673571187, 68.20312961455315, 71.9939434912897, 66.31119789615755, 67.78342031663465, 61.850129404375636, 63.50237684865152, 58.06044909261889, 57.39055533562937, 55.25410698306177, 54.49835646537043, 56.05649055973176, 57.59188667420418, 54.79640168528403, 55.21192973659885, 55.703740043024865, 57.9284260349889, 58.068352668516106, 54.61470573179184, 56.01500757278935, 55.44030189514161, 51.32010698318482, 47.57913074185772, 48.02175060395272, 49.043983028781035, 50.8761574376014, 49.447594919512355, 46.000545409417924, 48.538518951785186, 49.69129962305869, 51.34213109170237, 44.64896725070092, 45.79273431531845, 54.24995668472783, 50.954251827732215, 50.45340830279935, 44.31409881960961, 42.825582873436716, 38.96333871349212, 38.60255518267232, 48.24531001429404, 48.68593731234151, 49.60424653945431, 48.44505279294906, 52.361511953415416, 50.71623063856556, 51.00701162892004, 50.86377843733757, 52.69735705467963, 52.21943586103378, 53.557195509633715, 50.91872692108155, 51.82376284753123, 52.611249262286776, 51.67818407858572, 51.13173515565934, 55.46748784280593, 51.77520782716813, 50.63770871008597, 51.4975550097804, 52.25227002174624, 52.50993051836568, 56.10556333295761, 61.99285661020587, 65.46203221044233, 59.75987872769756, 61.55779515543292, 65.71539378935292, 61.959630212476185, 54.62339770409369, 59.111710979092514, 54.06751940327307, 56.98314659057125, 64.45539905178931, 62.39677052344046, 63.332718649218165, 63.027091487761474, 57.73611614781042, 65.14327295364873, 58.98667366273942, 58.7488603591919, 55.18921529093097, 64.0919836105839, 60.47138490984517, 55.921576715284786, 52.543380491195194, 57.50358627688501, 70.08942096464096, 72.50207085763255, 81.60153035194644, 67.56482662693148, 63.71543999641173, 60.463779434081054, 70.34775610893004, 5.437668062025502, 0.19188193514222102, 0.15678239115063222, 0.14246261438294766, 0.23347623466003328, 0.14571517856130678, 0.17280089128161633, 0.2489033608787483, 0.28986640394695345, 0.2771782718839184, 0.46172238706100377, 14.05220885430613, 40.90033062042729, 45.7798767858936, 49.66948732253044, 69.82155446083316, 12.726501668653182, 0.2066933564961918, 0.46937968101232286, 41.41638117451822, 79.8466697815926, 64.01270466466104, 105.36949326915126, 88.14177666940998, 7.364152429565308, 0.48282958026374545, 0.48594427925925104], [0.05643888098758556, 0.13930993274815623, 0.12688527364403973, 0.4229088794560202, 26.751923676460024, 47.82283936777423, 27.398410689446237, 20.69806302747419, 24.55591413282579, 3.078268756789546, 8.105389687322802, 18.047391945315947, 20.76962863245318, 24.17190624821571, 46.83233499526978, 19.907071974969682, 0.10118163716528686, 0.14606603150886877, 0.18011701563673635, 0.17175256124427243, 0.05187963511073782, 0.06984579887601637, 0.0307557373608072, 0.06283220647263431, 0.11129510859327932, 0.0006367779684707433, 0.016271029523904287, 0.026420034025044694, 0.007245544674656084, 0.020330062121032708, 0.040820313227032466, 0.11054790473633236, 0.1188947314456586, 0.1459679109675269, 0.19664214503380562, 0.03153969237070171, 1.7284964818146922, 7.850482694564327, 23.258666684550626, 45.14879095938898, 49.356623388105824, 62.463156638606904, 60.121603627358716, 63.8828859790679, 63.18267230064639, 66.1954487523725, 68.0616654119184, 64.59241528664866, 67.68158774222097, 61.158846962836485, 63.60724141520839, 65.54539826608473, 65.28835750395253, 65.99343884375789, 66.19127535050916, 66.05927190473004, 62.94154459430326, 66.46035778907039, 55.86059562621578, 56.47255597576019, 54.72867411951865, 56.21297744012649, 48.746326123514486, 47.07871867764381, 49.060735471787, 49.89003043020926, 47.486060742409, 48.51036025631813, 46.53632548547561, 47.338709062145604, 49.696637968863214, 52.55943867468065, 51.469914067176084, 52.83951943920505, 52.029981459340746, 52.54618890823857, 48.803216180493756, 42.88508915132092, 41.944928399978146, 44.0890645980835, 47.07941685953448, 45.87122878720684, 43.30993283179499, 47.32779310595605, 50.951580693644864, 53.66912426487092, 51.302134683055264, 51.2257622134301, 42.65912532806397, 41.91740905084918, 44.62306391808295, 42.805904342282204, 37.3468279838562, 37.652109976737734, 37.32186209770941, 45.29482080090431, 45.102503068985484, 44.32421853465419, 45.76578763223464, 47.07818915767055, 47.178731272297526, 46.6481287248673, 45.00345929976433, 45.236750110503166, 45.159538253661125, 46.711067076652284, 47.080338616524976, 46.8029329084581, 41.44726591725504, 44.523408259114916, 48.930418645181966, 47.981016789713216, 44.227947881144864, 45.196298706916075, 43.20262855099094, 44.77935860233922, 48.62684680569557, 52.55182143180601, 53.472742957453576, 53.59815682134321, 55.381156475313254, 56.00406416000859, 59.7442598496714, 54.87415090683968, 54.705190889297, 56.4441187920109, 49.0045710532896, 52.06739302604429, 56.15711896650253, 49.6904053226594, 58.89581195769772, 59.25664255695959, 51.70937084382581, 58.97502814569781, 55.137271342738984, 57.956804383185606, 53.28910935309626, 47.58655971096408, 52.321260590707105, 40.07429515161822, 48.93714943239766, 42.366830302822976, 55.89484576256045, 55.8470909057125, 63.890562057495124, 57.30324729796379, 62.517724652444166, 90.8484866542201, 24.799916936505227, 0.5169707789055763, 0.24361899362937098, 0.14741776300774467, 0.11526371983270492, 0.055621997603485664, 0.14958530153718688, 0.10926407161018542, 0.11873569925345721, 0.10068199462107114, 0.23583462101317224, 0.2708885980950248, 3.8577282861355817, 27.267738888340613, 24.822001841760454, 25.160935809535367, 30.13526801140078, 5.553703538833126, 0.2386604129306732, 0.0611743807131725, 4.53267086898127, 56.16371639313237, 44.26063691416095, 58.73082137876942, 88.8071204769996, 34.37467944237494, 0.02838175345752989, 0.12524316417834452, 0.11820021145526441, 0.31973038048994157, 0.0994751763139521, 1.282162748036846, 43.298240246311316, 68.61073447811988, 47.901129876413655, 30.504343432764855, 41.97105138532577, 3.549173810789662, 7.21379425256483, 37.67903312560051, 29.478143530507243, 36.733636010077696, 59.02293205261231, 23.769647575193837, 0.1621082190784716, 0.06343053263281623, 0.23539542280618223, 0.12852650976950122, 0.07091123565670944, 0.06637931230568117, 0.019554059103792234, 0.011095799160219971, 0.1034332998096943, 0.05841754053929641, 0.0385875461412774, 0.07023310994789486, 0.01986791575027089, 0.10146028632598539, 0.04563587680158596, 0.04618501245614983, 0.1669257170250339, 0.2093155375651775, 0.1274064049545315, 0.012784874603723087, 0.7068464676699331, 8.897945765526064, 27.71817211181887, 49.35139094629596, 54.53076701010428, 66.30973877445345, 65.58804619696834, 69.14482793500348, 63.878155600640085, 68.26559728191745, 72.49621868133545, 66.95843604303175, 67.13346788960119, 66.34421640826811, 64.49764690091534, 67.63008702185847, 66.00171504482147, 68.01110606039724, 67.88425660902455, 69.33148568676364, 65.01887106126355, 65.54674756142401, 59.40203305213683, 58.03370245041386, 56.24216771894886, 58.57370691914713, 51.2294884650938, 49.90167202488069, 51.90850565510412, 51.954464066413145, 51.10984833009782, 50.69343382312406, 47.677868566205426, 50.30174593771658, 52.71588633137365, 55.41013494614632, 55.23546788000292, 55.90819358825684, 53.40212852724137, 53.34134355668099, 51.48159880791941, 44.28156668140043, 44.19078342376217, 47.16469703182098, 49.565422919488725, 46.835610174363666, 43.559783889401345, 46.6893018445661, 50.845692388473026, 55.14010721637357, 51.16671485285605, 50.67885045082339, 42.336667276197865, 41.72914312731835, 42.801766241750414, 41.81003024501186, 36.58588424805672, 35.97985059984269, 37.90229835817891, 47.96309155802573, 48.00542962166571, 47.09320791306035, 48.318881911616174, 48.830547255854455, 48.8313905654415, 49.65482550282633, 48.3932343606026, 48.073741620586766, 47.39023331672915, 46.74055937797793, 47.288396819945305, 50.36316633224488, 46.347337845833074, 46.71164366506761, 51.182898552187034, 50.26764485143846, 46.99576054849933, 46.98133014863538, 47.11637735366822, 48.38952772078976, 52.664789615138886, 54.632215192241055, 55.531877471554665, 56.38522832624374, 58.42211123435729, 59.423813973703695, 60.44961967775899, 57.73868922264346, 58.052470991688395, 59.49669945624567, 50.417326419584214, 53.236820236329116, 56.232891313491336, 52.144263636681345, 62.69031286239625, 64.5894068287265, 55.55824756622315, 61.47289545305314, 58.08221824707524, 61.61950972772414, 57.71044423503261, 51.525678403915904, 53.70567683250674, 36.90189392335954, 57.84638574046474, 45.947110960560465, 59.86599060796923, 61.14692295751264, 67.56361069217806, 68.14558059938493, 74.90588757299608, 98.81231015728366, 21.74522799830283, 0.43975515291094786, 0.19929087871024687, 0.11664750445033274, 0.18988391654866357, 0.04172980898029862, 0.06529263190684781, 0.09896902968325923, 0.09946611349380786, 0.08946642910520877, 0.21811016564888341, 0.581428803984196, 7.868927150003373, 36.763344041762814, 32.08127352499193, 35.210348252327215, 43.70206394503194, 7.074703083884332, 0.03673092822634405, 0.040452116048864784, 2.730710722746388, 69.17468501675513, 52.13609333961241, 70.66139667264878, 94.08212784797915, 52.7125640838377, 0.09603201712091124, 0.1869283493367895, 0.3162136385517736, 0.30943719249579216, 0.31985433351609016, 0.7209503915040725, 44.588268572284335, 89.26983464148738, 62.124542344001036, 46.46899015672746, 78.64987619461553, 2.6173196588793113, 24.108881604286935, 58.67278598969983, 47.992803512081025, 50.52572111929617, 64.04855120566585, 36.393350785778416, 0.45349184483770405, 0.5993512777551528, 1.3328989739379575, 0.7408855314696989, 0.20238915278065592, 0.22908625974049493, 0.1498895610171941, 0.19195080644661383, 0.28156921207424135, 0.22942490124654388, 0.10590430874858173, 0.23492254737404086, 0.16808641683911124, 0.2509217267675746, 0.26183779020943954, 0.2201766725028715, 0.20001339155339426, 0.42503697977912047, 0.1849867454579761, 0.13823814509857085, 4.188318146813301, 26.45886378903543, 45.924078802908625, 56.51666302834788, 60.451725990541526, 69.8971071550923, 70.6448442705216, 71.40081051857241, 66.19372290949669, 69.74149104087584, 72.85455073079756, 69.43743674985825, 70.78089560231855, 65.53610617114653, 67.80230260664418, 70.3516863238427, 68.79870230151762, 72.19151327686926, 70.6493079277777, 71.3393783569336, 67.05666788162725, 71.6964630926809, 62.89679035063713, 63.093861995204804, 62.04343557357789, 62.47539051117436, 54.532269277880275, 53.13920813222086, 55.851872274952555, 58.63366034723098, 53.67238375448412, 53.2727962155496, 51.28183249504336, 54.29603276714202, 55.85011505311536, 61.20809624272009, 58.38572340626871, 56.9276568197435, 55.13639665419056, 56.00560957385648, 54.410197273377456, 48.46024413262644, 45.49121387543217, 49.63514304930165, 51.70847654342652, 46.1488502256332, 42.978014023073264, 47.75360953423285, 50.75787836505521, 57.685176326382546, 52.42701945766326, 52.24371533240042, 42.75742384695238, 43.616650412159586, 45.51156313188615, 43.46373288862167, 36.70695997053577, 37.936772069623395, 37.478282297811205, 49.71846988124233, 49.202301656046224, 48.00473536214521, 49.77949019401304, 53.01202135701334, 51.32041685042843, 49.75966261279199, 51.94483464764011, 50.121034499137636, 48.36556596140708, 49.452074266249134, 50.32918291707193, 53.67924005754533, 48.7859812859566, 50.71964310061548, 55.710404149947635, 52.93567634397938, 49.96839938625213, 51.442955616981756, 49.01584394516484, 51.610040741582075, 54.93282171987719, 56.92238907660208, 58.308072243967366, 58.18265838007773, 60.86499475663709, 61.12675020771643, 67.02992516179239, 57.367746753077355, 59.54252058459867, 60.016558631773925, 50.924586942118985, 53.5704452760758, 58.767950534820564, 54.19554164332729, 64.61629859862789, 61.87531886562225, 54.14360553987565, 61.37019603483139, 57.43432898675242, 60.954785654621745, 59.564634907630186, 49.553620507640225, 51.44153964134955, 46.60704581968246, 65.1399899298145, 57.12286141610915, 62.854232634267504, 62.84395210204586, 69.06716500559162, 67.97143520847445, 74.73140485825078, 100.03906280763688, 21.559519460124356, 0.5091933317242131, 0.3975807562951119, 0.17204981868065175, 0.3401647646340632, 0.16251125793543555, 0.26576533913612366, 0.19841153234724077, 0.4748998348030352, 0.26563541062416574, 0.636528727989043, 1.00871262771468, 13.875142278209811, 50.577351277874364, 43.06659290867467, 50.46838783448743, 57.39931006585398, 8.939707240750714, 0.3851484363117526, 0.14874056702659977, 7.4049749874299575, 98.04602807567966, 60.447627113711455, 80.68895170765539, 103.3780667089647, 49.82097318095546, 0.11425544853292166, 0.29683296238222434], [0.10532338427559984, 0.3248723013506782, 0.2777870666355856, 10.963765959585867, 58.316454349025605, 50.70484399795533, 26.72363554277728, 46.61857758798907, 28.611640968630393, 0.4139157733128917, 2.1298842660842405, 18.46974688191568, 45.36503122698876, 30.10090216513603, 33.0767200839135, 20.596238297800866, 0.3761144823605015, 0.2600722026921088, 0.3567790666655187, 0.013535879214384384, 0.07094026272816044, 0.18619049941339802, 0.0520273560147372, 0.1026265096339968, 0.026592105033717332, 0.12539175459213797, 0.07248851110137279, 0.034982179321589014, 0.0776956873314996, 0.10892468699884993, 0.043747201937461094, 0.09856255109151525, 0.07560783726794106, 0.1528896072939519, 0.04675025510932169, 0.057539799130491676, 0.03221287106674525, 0.735015704506828, 5.120807722691567, 27.77009644815999, 42.92223399685275, 56.007817868263494, 58.38892798269949, 60.34759882957705, 59.226597201439645, 60.27521541041713, 68.50883914578345, 62.94902847659204, 60.01634290141445, 66.06150765572825, 60.54661596975019, 61.666040805078325, 64.047621603935, 59.31975349303215, 64.6802959903594, 63.346768579175404, 63.691909697748, 58.75726599847117, 57.83096690331736, 54.52804880757486, 57.522939251315215, 56.57593396402175, 48.948606675670995, 48.56974101835682, 47.700422194696245, 47.62257491388629, 48.50939535325574, 47.46625669540898, 47.631478694177446, 47.89652109146119, 47.61311023466049, 51.72116148856379, 52.89567209059193, 56.73968899634577, 51.54510590337938, 52.45521345446187, 48.34402038205055, 43.15514826005505, 41.43294534375591, 42.160984316179835, 47.762089698545395, 47.73264054329165, 42.72727258743779, 45.79436209893996, 48.732366408071215, 49.94922684084985, 49.783977385490175, 49.00721080841557, 43.56724031509892, 40.06533253577448, 40.23225684319773, 38.3291934382531, 41.18183912769441, 35.43240539489254, 39.94636312607796, 46.900490099383944, 46.23665248194049, 45.09699213889338, 45.47645791884392, 46.441666926107104, 47.48609604374055, 46.99892982359856, 43.81274930892452, 43.267881101177586, 46.292565868746856, 45.0688648223877, 45.079580737698464, 47.80485530053416, 44.62864152846798, 43.33875440782116, 45.72250035501296, 46.34394499563402, 44.00356477306735, 45.6121797715464, 45.091720473381784, 47.06608864568895, 48.810217611251346, 51.654426282452, 49.133628799069314, 51.95997499650525, 55.33146396760018, 53.606558538252315, 53.451064017511186, 54.12447614054526, 55.77072235845751, 57.96942264802995, 47.49444676983742, 48.54266489705732, 51.449054902599705, 46.58157002541327, 55.04666851412866, 57.82547166270595, 49.488924934018044, 61.732787778300626, 55.083785903069284, 58.03191777198546, 52.29335684930125, 51.63765422759518, 38.86668759007608, 10.338151839471633, 47.55623978953208, 50.192005865035526, 56.49435650917792, 67.90928917546427, 67.36634685147193, 69.72889238788237, 65.46456213920348, 20.427617565278087, 0.8536189854625733, 0.08411548881521148, 0.11533891136247305, 0.04864046597973474, 0.17591042684451227, 0.060495186311703544, 0.08825861488378818, 0.009087371346991389, 0.1087560174205611, 0.03322955784237674, 0.12762511539603436, 0.2804759126757422, 4.954753691150296, 28.580711118636597, 16.96006190392279, 28.309322326414048, 41.35050496747417, 6.16062903596509, 0.3542679530237952, 0.3411694123379646, 0.11052169686844272, 41.14461583475913, 70.15002942854359, 50.154806106321274, 83.03682757962136, 72.5317475103563, 4.394438209072236, 0.06795343912897572, 0.11739783394601076, 0.3132414625537011, 0.1695951810407062, 18.88435905979526, 82.00751919900218, 70.38410079094672, 40.12712163309897, 57.60761930096535, 28.934171584344682, 0.16826422584633674, 20.83439676992355, 40.678701016210745, 62.751431234421275, 42.2067819103118, 44.20417831790063, 25.12785650068714, 0.28026082583012124, 0.15088513824007205, 0.18518016733709844, 0.0176975695085862, 0.022449381161300887, 0.22241482901717388, 0.027273026963455543, 0.04629214602192083, 0.04588698510140662, 0.013137607339529261, 0.0653759439686133, 0.04543231574878578, 0.0486404046927008, 0.06887273697723305, 0.1331120362925914, 0.05872819302303176, 0.03451476226590815, 0.03226591499462243, 0.09670835018398301, 0.02223330414703777, 0.03640346777354998, 0.6275136504442461, 6.995379030704499, 28.819805076045377, 49.891607223018525, 60.31417631333875, 62.664178109938106, 66.11834279952511, 61.894056027935406, 62.34015111000308, 72.7141220338883, 64.16841491576164, 61.525945509633715, 68.16879318606469, 63.9399133190032, 62.45590025378812, 66.98553177618211, 61.9951904204584, 66.53217638692549, 68.16269782281691, 69.44538347182736, 61.77606721078197, 61.34482222218668, 58.02528896639424, 59.38943439914335, 59.38443729954382, 51.50206573547856, 50.319196562613214, 50.370340347290046, 50.65475925322502, 50.807064887016054, 50.15370784267303, 50.44257079401324, 51.29989893205705, 50.72575807571412, 51.91161609465077, 54.89993656835249, 56.72463886199459, 54.958556390577755, 54.35082043370893, 50.09119702923683, 45.875300207445704, 44.0420824481595, 45.89736353966498, 50.14896177476453, 49.944931845511164, 46.214836259042066, 44.66078535203011, 47.92159288160263, 50.75817254281814, 50.69430851167249, 48.296963707093276, 44.362261602955485, 40.34018870322935, 39.91827503327401, 39.28424742914016, 41.443068981170654, 36.49657972397343, 41.61666916262719, 50.45597745526222, 47.277449484794374, 47.724862483239946, 48.11567960246917, 47.715613534373624, 48.12050019541095, 48.922162055969245, 46.08443706266342, 45.93897204245291, 49.03367896233836, 46.340203054489635, 50.046462397421564, 49.54095517435382, 49.47008971245059, 48.02315089010423, 48.296469488451564, 50.15218596304617, 48.3284995632787, 48.54877594978579, 48.286236024671986, 50.847943828951934, 50.37004616952712, 53.01196644383093, 52.899821958234234, 54.209795536533484, 57.09918206737888, 58.08529730766051, 56.43369705446305, 55.28315997892811, 57.616323040377715, 60.40694036791402, 48.714072473587535, 49.359008189170595, 54.457124510119044, 48.35388122066375, 53.98882881287606, 59.52253218620055, 51.0715542301055, 66.23689251561319, 60.31996965408326, 62.878421891120176, 57.66145775395056, 55.21866836855489, 27.496148309400006, 5.171349913843217, 51.22441291809083, 58.25978002240581, 60.795270704454, 74.63070977118709, 71.63529765221381, 75.2618662003548, 58.30972356180991, 16.882434275842485, 0.7017491024828727, 0.06107949689331074, 0.10245056988130655, 0.04047770338553575, 0.0669812735530638, 0.07312667766405691, 0.07004053842636847, 0.05237091963569965, 0.1702056765075653, 0.041191999935695243, 0.09709275778262846, 0.36758029352753396, 8.363708161538648, 37.7365860631389, 19.469600223725845, 43.560799783275975, 51.95360506734541, 8.359424933310478, 0.3454702299448752, 0.5865760568168856, 0.10028842461085129, 36.279468690195394, 77.05634270944904, 59.01802908989691, 84.81371618086293, 91.78416805882608, 6.980002849332749, 0.2037120487300619, 0.2520992192289522, 0.4025651694786164, 0.4898900610785331, 13.065427791687751, 97.03529604019658, 80.91695124103178, 51.1168929069273, 89.84426575322306, 52.61692885429629, 0.7940489690630668, 50.345582346762384, 57.27586523179085, 85.76712669864779, 49.23994464258994, 53.811710265374955, 35.461831015925256, 0.3360420777913063, 0.6474967781574495, 0.49803611912554313, 0.16463408757361675, 0.1035580265846464, 0.30870220774123747, 0.11891944544209589, 0.1997065273744445, 0.11539184037716159, 0.2430399690544413, 0.18958200129770464, 0.2751468212133454, 0.16614556372646364, 0.3117416156155448, 0.18503667906888072, 0.11283399537205697, 0.24952885634716482, 0.22425040632726687, 0.1294078173175935, 0.15778982741457803, 0.14674924404150055, 2.2097439679407307, 19.36244695417343, 47.17321641983525, 53.71057979522213, 67.7713394165039, 65.877807371078, 69.56023831521311, 62.717487042950054, 66.3555363685854, 76.48706559211978, 66.72847532456922, 61.747888903464045, 71.49805391988447, 64.99250488896524, 66.0593189731721, 69.23821172406598, 62.41079691917666, 67.53252983093262, 69.46525419912031, 68.61916757399037, 63.55859618033133, 63.45431604693013, 61.5677305190794, 63.570563331727065, 63.83191085630848, 55.88634598639704, 55.30978502765779, 53.994629998360914, 54.11767475066647, 53.05543415008053, 55.27883752699822, 53.6925055134681, 54.573007014489946, 52.98602388751123, 56.76366644520914, 59.32897890767744, 62.60630353804558, 56.87325746782365, 58.378439564858716, 50.348630028386275, 47.4571999426811, 45.08138895034791, 49.44270764627765, 52.16301256610502, 51.079728449544604, 45.52401665718325, 47.776441651005904, 48.67941048837478, 50.8054292586542, 50.86902264625796, 50.845374676489065, 45.045150172325876, 41.18191365272769, 41.44939968662877, 40.02169224523729, 41.59628852721184, 36.32670187181042, 41.01789582160212, 51.91136506295974, 50.941041284991854, 49.17657875245618, 49.87592558706961, 50.000731483582534, 50.47076086844168, 52.43918272756761, 49.683458805084236, 46.19290236503848, 51.03188730055287, 50.16271360458867, 51.11959149760585, 54.2414176848627, 51.46002577197168, 50.93477725982667, 51.55334680311142, 52.79715784134404, 50.36853997938095, 52.41278125393776, 50.72198475560835, 53.073712395083525, 52.37204351732808, 55.339951976653076, 54.266238443313114, 56.94952795582434, 60.09456280739077, 59.27745857546407, 56.01007715348275, 56.81347662402738, 59.217309028871604, 61.68792763063985, 48.31702663052467, 49.30812328092514, 54.60521751834501, 48.000911051227206, 56.4323438367536, 62.84740771016767, 51.87387112648257, 65.5406286639552, 58.461750707318714, 59.27420300822104, 53.151747949661754, 53.079686164855964, 42.22811175930885, 19.669264554977417, 60.54281519305322, 59.76161241531373, 67.73537128202378, 79.80160959305303, 76.27689715354674, 78.00998856944423, 67.80367543620449, 14.9526418793586, 0.672345667356445, 0.18944292569593077, 0.16540484863423532, 0.12686956118071271, 0.22946902791098242, 0.18530090279396505, 0.20842368864724714, 0.15907127800728046, 0.4741863924409113, 0.16203441416784642, 0.24180163389011738, 0.5691777710472384, 13.447952039780157, 53.08000387683992, 27.471723710336995, 54.65332146613829, 66.65664888197377, 14.24199273509364, 0.816863373883309, 0.7810497440157399, 0.22996465615447492, 60.57432359264743, 90.70126441217239, 70.18833529564643, 96.88010354195872, 95.68080748281172, 5.823055150047426, 0.3195575510542239], [0.10063014579035583, 0.08910923294963376, 0.38821070424972043, 43.67212449350665, 76.50556348985242, 40.21380601390716, 46.93811739644697, 52.34180204329952, 2.941888681342525, 1.2566825411012097, 18.403158764685354, 28.976593978943367, 97.11674013445455, 63.12915155964514, 32.029831640182, 18.516787867392264, 0.6025679277316217, 0.13903827797020638, 0.0578423923692636, 0.08634414583925279, 0.04540919904567061, 0.015193908944756035, 0.16339688621942075, 0.10831433708869642, 0.07792962760093712, 0.09683503048314203, 0.039707949730537595, 0.020345052546491067, 0.042469390262398994, 0.027809177427702857, 0.16334041021764278, 0.09504967789736488, 0.056256797209742575, 0.09854919817899505, 0.16119694217078148, 0.032631875196051215, 0.030566170819163806, 0.2661988529707155, 0.3771905294589458, 6.5465804549955555, 32.2469917035872, 43.257718240061116, 57.86760968546714, 58.49675786110663, 57.95975792792536, 55.24394804431547, 63.50673067954279, 59.04770574262066, 61.05638288682508, 64.60060519556846, 62.675984444156775, 58.95843651986892, 60.48300689266574, 59.955412803157685, 62.984572995093565, 63.830514492527136, 64.89149601228776, 59.73035896978071, 55.428597542547415, 55.568743828804266, 59.1831216504497, 54.485773501857636, 51.155583166307025, 48.8977139226852, 47.68117904663087, 46.992238260084584, 48.95552573665496, 49.04916055740849, 48.269224705234656, 48.36085127245996, 46.65446727506576, 48.02420993005076, 50.83008527755738, 52.083090351473906, 51.35137219582835, 49.789433402399865, 51.15777184886318, 44.539278168832105, 43.11543033969018, 40.765985519655295, 46.63550261528262, 50.72831938343664, 44.2789779170867, 43.9207439268789, 43.799876090018984, 47.07730270201161, 49.25803853619484, 44.82632114041237, 42.793046812857355, 39.55320435185587, 38.79494351725425, 39.39319126067623, 39.45744360646894, 37.60919140231225, 43.83431842250209, 48.589223431002715, 43.478182900336485, 43.62071006528793, 46.526099866436375, 44.926451406171246, 48.55749537867885, 44.99142546807566, 43.82786220119846, 43.772254759265536, 44.53442227455878, 47.67451886207827, 46.80274463468983, 47.71293063317576, 45.130622540750814, 46.14517888715191, 47.80557701664586, 48.46221316245295, 46.26952586635467, 47.26812993326495, 45.49965089367282, 52.74374300433744, 48.027030114204656, 49.83691761570592, 51.12612616631293, 50.15590436996953, 55.36750270474342, 53.25988377294233, 53.58240066036102, 53.444556805395315, 58.534867609700854, 58.42116986551593, 53.653575989507864, 46.61713807813583, 51.4063952046056, 42.60294129771572, 47.21706851836174, 47.20311664765882, 43.865214932349424, 52.99736345967939, 52.43112617923368, 55.35847340860675, 54.799602339344645, 29.36639912666813, 2.9318927661065133, 0.39991263600607074, 17.447310493838405, 46.54512728414228, 27.159738386830977, 16.398012734228566, 19.458042960013113, 18.08960449311041, 2.063607732134481, 0.3674530003580355, 0.09789957860184294, 0.046485246144114964, 0.04521533666599182, 0.020818297616055897, 0.015090312789975396, 0.02370134886023739, 0.0530977378929815, 0.035769304020270225, 0.029689660896697355, 0.1340399373082384, 0.12864767423560544, 0.17813759765798048, 6.139975795822759, 28.011657576407156, 34.016751397040586, 43.335110525931086, 46.75784134095716, 4.660204773949039, 0.12303244893348987, 0.5473077381330153, 0.7685082718249291, 9.5603124941549, 69.22938639117827, 72.66062874947825, 65.46843744093373, 103.65996745324905, 14.21557164961292, 0.27106470638705843, 0.20708191629138686, 0.13484149510341306, 0.7257256933277654, 57.61755466461182, 89.08682469398745, 52.16489530378773, 58.22029744425128, 60.729778889686834, 0.6019923199088343, 1.9529386705929235, 42.12057213629446, 45.563703198586744, 118.58511940125497, 76.26005449602681, 39.73559456486856, 23.56950471478124, 0.6535136940017824, 0.052420730672536366, 0.029972651860706752, 0.046822811296630296, 0.12823886673657164, 0.08778556325142423, 0.025745978158327843, 0.11681032111688007, 0.03319584614326877, 0.03272331928113296, 0.07108498439793626, 0.040097321578932386, 0.05639949257695868, 0.04401647801240606, 0.19366080662415874, 0.09683287011519556, 0.07607770963541924, 0.0706388301125938, 0.1270596812208814, 0.06658889864000582, 0.05346433777782706, 0.11636304834316816, 0.2852401521898085, 5.126981043046521, 32.034881691778864, 47.90020027468282, 59.635559205086004, 63.23284333752048, 59.10328572796237, 57.749036435158025, 68.52836470450124, 63.57734903212517, 62.580851277997425, 64.98710770760813, 65.65234953357329, 64.7423125851539, 62.20395465050975, 66.75681052669403, 66.51582794804727, 66.78392979406541, 66.4981694375315, 61.71791415060721, 59.74620926764704, 58.61745311367897, 63.97737195414882, 57.784529962847316, 55.54251493946199, 52.539136486668745, 50.568341593588556, 50.46230816072034, 51.20845279385967, 50.905457542788604, 49.904441218222345, 49.88164832515102, 49.86740619905534, 50.71634830967073, 52.93405248272804, 54.851412926950765, 55.676263839967795, 52.920767414954405, 52.30819517566312, 47.537326120561175, 45.53827447275962, 44.54354178520941, 49.270080212623846, 51.66724458817513, 44.55461463620586, 43.16811169347456, 45.62273879205027, 47.11462797657136, 47.73271506832492, 44.553806627950365, 42.83386691924065, 39.455513800344164, 39.744580714933335, 38.337563776200824, 39.93964410597279, 38.86904885691982, 46.0962708534733, 50.30851202626383, 46.25935123812768, 43.96285449304889, 46.67857416214482, 47.61118042853571, 49.37554097944691, 46.68390858557917, 45.44924843695856, 47.115639948075824, 46.229886393393244, 48.27063283612652, 49.561586841460205, 49.795654281493164, 49.31872152513074, 49.82249898295249, 49.037248319195164, 50.948258446108916, 49.42690833922356, 48.93654146502095, 51.862786508375606, 53.725759367788996, 52.503658648460146, 53.47927370379048, 57.200520423150834, 52.293180342643495, 56.19935112614786, 55.16004462395945, 56.67047485228508, 57.16165757948353, 60.440515856589045, 58.67412744029876, 55.60642211667953, 51.302774029393355, 50.00788588677683, 43.1523084640503, 52.666327184246434, 51.510808698592655, 44.97306485329905, 52.89767642174998, 56.22320698153589, 54.52151413886778, 43.57610094931818, 13.584129868015168, 0.5314168682502163, 0.42824020789515593, 10.284647768543614, 38.88920983960552, 28.88213742163874, 17.560519902936875, 15.773001678528326, 10.188203550154164, 0.6783893656346106, 0.5740109278309731, 0.10968299913069895, 0.05988317016031473, 0.07102316110244683, 0.037346115981739376, 0.030187564421324965, 0.03213596350002674, 0.04361225938003871, 0.0904245982547441, 0.05721469822850439, 0.021450337390565587, 0.015569361933176557, 0.28455860972885166, 10.246690011793568, 37.733812947427076, 34.060379920467255, 59.70642074461907, 59.49166313294442, 6.3980368644960475, 0.3231453859517652, 0.2992675285185537, 0.5773559128565173, 7.766307650073883, 72.72513604933216, 82.09381134279313, 71.04620472077401, 113.72915452526463, 19.49124582352177, 0.3986376205519323, 0.417262903384624, 0.24763881018565548, 0.4906851071263514, 58.54010005151072, 106.58618111764233, 64.83705351429602, 75.02352729920419, 97.78956782433295, 6.549676185654056, 5.846529554936194, 69.40873284493723, 57.2677969163464, 124.44996495400707, 81.60558608270462, 54.39315065260857, 31.600977336206746, 1.22441295654543, 0.4787928484860928, 0.1682380869263603, 0.2523202202733486, 0.23816383473815458, 0.1759870662804573, 0.31258756054505227, 0.17582716840890147, 0.16616814799847143, 0.1144085129001929, 0.11445711351810925, 0.14992412690433765, 0.14657791613811447, 0.16408331632133455, 0.20261041429494658, 0.3225158761826254, 0.27713209210384276, 0.3508077177309221, 0.26734587045446523, 0.15752192646745714, 0.10625012849848117, 0.46740816906094557, 1.8997986446465216, 20.64308708713901, 49.8978594810732, 54.082393030966486, 68.00410070726949, 70.10669508287984, 61.9206222411125, 57.145944564573234, 70.92730983611077, 65.17422829904865, 64.71513840460008, 67.57790380908598, 68.50186517161708, 64.774911403656, 66.08930941550963, 66.52082504764681, 68.29344611014089, 68.80878279286047, 70.06115636517926, 65.0974557476659, 61.26819479850031, 58.48735986217376, 66.50179370757073, 60.944567880322865, 58.583018625936205, 53.505384922027595, 54.99894895861226, 52.34804253424368, 54.10805317663378, 53.57437549098846, 52.15451671231178, 52.05577104322372, 53.19279555351504, 52.731842533234634, 56.61514197626422, 57.80596963820919, 58.658108480515025, 55.2214297171562, 58.150526323626124, 47.136393208657545, 47.86955087415634, 45.90538870903754, 51.64452622013708, 53.86436416256813, 44.513410137545684, 44.18262097143358, 46.58304483659806, 47.76014028056976, 50.27916485263456, 46.02554659689627, 42.697364514873875, 40.647541707561864, 39.14707822184409, 39.117315276976555, 39.72424322558988, 38.98324081974645, 47.55976992268717, 52.60217289770804, 49.140861649667066, 47.27372715550084, 49.363373787172385, 49.57058083626532, 54.65189372339557, 48.95077966874646, 47.83926233168572, 49.519641014837454, 47.36715409063524, 51.140736995204804, 52.06696941006569, 52.569123006636104, 51.768053423973825, 52.11224532896473, 53.517563881412634, 54.13882809300577, 51.96273634510656, 52.74210345360541, 53.33972361779983, 57.00224068857009, 54.036936683039514, 55.69780941932432, 58.264337816546046, 55.13581614340506, 59.85163473313855, 57.65892390281924, 59.094201518643295, 57.623791233185806, 63.68584963583178, 61.49884193174301, 56.147269894999845, 49.9809705826544, 52.23545874318769, 44.14405622789937, 54.89212320696924, 50.13125227343652, 44.75425935560658, 56.420643406529585, 57.53945242974066, 57.67258551812942, 59.09679812769736, 34.20706087543119, 5.784513940734248, 0.7560188936129694, 27.870258092880253, 61.56383560549829, 50.574636997715125, 35.018175648104766, 25.27946787495767, 15.554773749843722, 1.2537066878811007, 0.48549403406439295, 0.20707990914102525, 0.15271758991143397, 0.12517535773616645, 0.2087711554861838, 0.12537787307895001, 0.08603476889191136, 0.1877404331800438, 0.1566852971671089, 0.265706472940022, 0.2890544120342501, 0.29894969396052823, 0.7061437505387491, 14.461104177659559, 50.726389577311856, 50.83752601377426, 62.69871065693518, 69.59646532612463, 16.498842162470666, 0.47350527898919204, 0.868706382330387, 1.5111384612898675, 14.413057104233774, 95.63883812196794, 87.79251313978627, 82.58342512192266, 127.02199643658055, 20.624824531616706, 0.5197497168856283], [0.3544678100414815, 0.16849719318411044, 2.789016019913458, 70.72107945719074, 73.42858960551601, 45.786195724241196, 59.72864489401541, 31.875321634354133, 0.5963455777495139, 6.990353493921219, 39.068924996160696, 37.60699879738593, 60.07595116092313, 35.337123178666644, 39.0071790449081, 19.493128561204482, 0.36595459366517685, 0.0675414217215392, 0.10621420663571167, 0.020454846352579135, 0.0581920157457071, 0.04102572821260941, 0.07906496224384155, 0.048359449607350176, 0.11849811240550011, 0.09338239478247781, 0.03272325416365939, 0.042645601976302364, 0.03384023333989805, 0.011820970328464624, 0.06527767020968661, 0.13386434995599333, 0.04299139108268484, 0.2267802431578598, 0.07555990314651882, 0.038823447595801086, 0.022460359201255827, 0.05120812840158901, 0.03883849739307358, 0.2911213478974758, 4.077452599040924, 29.195060191615937, 39.687388635450795, 47.43642707024851, 49.62028903345908, 50.284820910423036, 60.124870961712254, 59.59649239816974, 58.60818847533196, 61.34903092538158, 64.55742382234143, 64.18108417141822, 62.82754874998524, 61.46836511550411, 61.89870011421942, 62.473954923691295, 57.05687930507045, 57.25871662939749, 62.05999189807523, 60.67978043710033, 60.94552101627473, 52.60746025270032, 54.91075446528774, 51.07387627324751, 48.80262390259774, 49.02946633677329, 49.84406809653006, 47.74706309841525, 49.452066421508796, 47.40687593337029, 48.75478667597617, 49.0645323261138, 51.803546951663115, 48.75254700260778, 50.28923749923707, 48.88796291043682, 47.47552133375599, 45.159357824633204, 44.33349494011172, 42.22560144239857, 51.024654449955115, 54.35243252784976, 51.19697593873548, 42.74606466293336, 42.800836640019575, 43.87511891703452, 41.85177995312599, 41.87017194686398, 41.525607416706706, 38.75743389129639, 38.1456422036694, 39.21548435764928, 42.014193534851074, 38.24368969086678, 51.43210241871496, 48.45017540839411, 46.792295440550774, 40.75277105454476, 44.5854679999813, 44.86665095052412, 46.29243643053117, 46.88436131323538, 45.32301479770292, 45.159789285352154, 44.15476822083996, 45.266971972680864, 45.82650592250209, 47.349185712875865, 47.06962270121421, 45.99723492899249, 45.43928169435071, 46.354182381783765, 46.14797161471459, 46.22598755744196, 46.86908760378438, 51.199337205579205, 56.99993825727894, 52.441634208925315, 54.158059473960634, 48.87057896583311, 54.31469148205173, 55.400215271980535, 56.80858935079267, 54.46514575712143, 54.10481329887144, 51.62812679044662, 57.347742665198545, 53.78672868974748, 44.40456436526391, 46.88138423427459, 45.89213894259545, 39.39675669516287, 36.58894369679113, 40.1675965709071, 38.37973710029356, 27.092093190839215, 7.514054631033252, 0.13846504501998425, 0.21395913355292814, 0.08644678629934789, 0.8130067646984132, 1.4568114280700686, 1.915274846457666, 1.413591198863522, 0.9658691299057777, 0.12924687756646064, 0.21014992988878683, 0.18693809397518638, 0.007663907205325462, 0.02777354667834457, 0.12120929756952871, 0.06421621325576017, 0.03813381141592418, 0.09356855414807798, 0.07709159635968747, 0.1719488176487146, 0.07335114908675033, 0.06847525225772012, 0.06997929735770149, 0.28854836499498737, 11.151720054687994, 30.035082832459484, 28.293428882475826, 38.199986642406834, 37.17480459520894, 4.797768669743692, 1.7224723341003543, 0.14152014237498084, 0.04011501820998327, 0.822987603324075, 45.0001488193389, 83.39357499153384, 63.78077883874217, 101.47133981027912, 24.1199662223939, 0.2686298644590763, 0.3917029313743115, 0.2800793242791007, 3.9003914162035915, 83.92611518982919, 90.05525004479193, 60.7156152109946, 70.25289750868275, 37.20363009360529, 1.0273964703083038, 14.41513203805493, 63.473829838537405, 51.60284319231587, 70.4460193264869, 48.44841426418674, 47.655762087914255, 25.089034841906642, 0.2580792402788516, 0.08397738614510145, 0.07955425494020024, 0.05499639871319937, 0.02278770091042163, 0.06413393158225283, 0.07725754632584511, 0.02481014430222492, 0.018866531580926913, 0.01915914843970489, 0.03816524400345741, 0.005560437087795788, 0.059536703066119266, 0.06589151348077482, 0.020078509490215973, 0.012431091369850742, 0.03325764262568086, 0.14024777758506038, 0.0620021463762368, 0.046818433104143034, 0.03544822124944579, 0.049310344752044453, 0.08612237870693208, 0.1844535329409184, 1.4594307133267004, 28.803454675982078, 44.308152506428385, 51.36364529209753, 54.486542286411414, 54.29123570842128, 63.89528066881242, 62.45593555511967, 63.285387408348825, 66.00883806905439, 69.1922180114254, 67.98204129742038, 66.50239775257727, 65.01236384914768, 65.46831584745838, 64.2582764164094, 58.87684729791457, 61.63533256899927, 65.77561786097866, 63.716028351937574, 63.527350579538655, 56.6936521376333, 58.9045000076294, 54.69673033683531, 52.24680223772603, 53.19463122275568, 52.18681350831063, 51.61613218245968, 52.33483591387349, 51.16844854047222, 52.302091967675, 51.237646995052216, 54.10671564840502, 52.18860603147938, 50.689840932046216, 51.54722790564261, 50.49210640691942, 48.051666521256976, 47.22978092009022, 46.15576928661716, 52.617258333390765, 56.96677853984218, 53.6039540844579, 45.18090340398973, 44.92718881176364, 43.35951159077306, 43.327254018475934, 41.47504806518555, 41.99826086721113, 40.312206514420055, 40.65810465043591, 42.51769642676077, 41.8899328477921, 42.1619374521317, 56.352378476050596, 51.74150290027742, 48.124783423639116, 43.79580074740995, 46.29963397979737, 46.75928085081039, 47.41990604708272, 46.37105641826507, 47.12424562823388, 48.251311240657685, 48.03087403697353, 46.6300779773343, 47.83483789813134, 49.374446638168834, 48.15091817609726, 47.72165006206882, 48.08603040633663, 47.31609267573203, 49.57309899791595, 48.119915762255275, 49.27051951808315, 53.627531451563684, 60.67610517624886, 57.77557911411409, 56.863529989796305, 52.22778266476047, 59.13347228880852, 57.62355196860529, 61.867905585996574, 57.36514229928294, 57.1283801909416, 54.11121068462249, 59.284091303425456, 54.696059611535844, 52.10458886238837, 55.12821459001111, 48.65846110928444, 39.05968389203472, 36.549618013443485, 32.94044517701672, 23.969968903449274, 9.699776288001768, 1.2128679502394892, 0.1796027101696499, 0.04193378372057792, 0.031607487321560906, 0.6071127290206572, 0.6416422729530643, 0.9010487145954563, 0.7319200964223954, 0.5517602411489333, 0.08466310378524565, 0.10070382812691313, 0.12054772702075782, 0.03487573906538948, 0.06029130350197516, 0.04045978458898683, 0.024458544418936776, 0.040637463361265204, 0.06218933613009511, 0.08441404094018283, 0.056246562275074186, 0.075604428176678, 0.03928955464113144, 0.11751509902458038, 0.17797046791641943, 19.322228931611587, 37.71271451827019, 29.234995803525372, 42.880958895529474, 50.48266918428483, 4.241237784585645, 0.6970835657369706, 0.030113713545424324, 0.023330529746148857, 0.22253371054126372, 51.19078643860356, 86.2528730207874, 71.22173078598516, 111.7133229778659, 26.189418531233265, 0.4103565288166846, 0.515213311920243, 0.3338214953339869, 3.2656219938109, 93.09448288333033, 99.32197509273406, 67.76814660718365, 91.93847410140499, 59.76415803355556, 1.3262107199238193, 20.92598999700239, 84.14517956395304, 62.059862459859545, 78.32748874541252, 58.56277919584706, 58.80270665691745, 34.185978135754986, 0.8189690737955032, 0.273686473768565, 0.2511338565138079, 0.1251929241322702, 0.12936741384046693, 0.1829136502478392, 0.11604193492882675, 0.1353230426508573, 0.1801755294323929, 0.1585160787667959, 0.10942288163688876, 0.09970612884048494, 0.16733413381922632, 0.1423492946571881, 0.08697176337121956, 0.16439675353467464, 0.14604890178288185, 0.21743050776422027, 0.12485556965393406, 0.09583235162520602, 0.23647119411297385, 0.1522705929293748, 0.18267083101935927, 0.6730357593586368, 20.676701799515758, 49.25974868958997, 49.343126512342884, 57.924860600502264, 55.617306693907715, 56.76590219620736, 67.1315694624378, 63.917034133788086, 65.06134248548939, 66.80815435224964, 68.75807439127277, 67.24391398891326, 70.14164340111518, 67.77469696537142, 69.8626216765373, 67.18885960117464, 62.03396304961174, 65.33021703843148, 70.20600949564289, 66.12098647702125, 66.87725082520517, 59.510792532274806, 60.64480466227378, 58.727530510194846, 54.19246258274202, 54.45893664513865, 56.1779232178965, 52.27678091295304, 54.14247197489585, 53.14016126817273, 55.18279829332906, 53.96771861660866, 57.91139118133053, 54.32300690681704, 54.4929200603116, 54.41245655859671, 52.33918190002442, 49.246977452308904, 49.498511206719186, 45.91401400104646, 55.111928909055656, 60.097179028295706, 52.460516498934844, 44.39045167738392, 44.22581018940095, 44.54668360371744, 44.429400813195016, 41.78403669787992, 42.40754450521162, 39.30911917840281, 39.645772287922526, 41.43852687651112, 42.79131312524119, 40.032553288244436, 56.73475073229883, 54.1675006189654, 49.86093821064119, 45.3002062151509, 50.30340902266964, 50.72100808543544, 50.781800900736165, 52.22957911029939, 49.930128820480846, 48.94012258898828, 48.591878875609375, 48.578456524879705, 49.50950561031219, 51.923116483996, 50.98053170788673, 50.816604091275124, 51.508239546129786, 49.865558762704175, 52.12956651564568, 51.54019901829382, 50.8421112645057, 56.349185666730335, 60.745142813651796, 58.17303288367487, 59.83613352621756, 52.19178315131895, 60.2729953488996, 59.24349084977181, 63.17807136043426, 58.23837172600531, 58.24447493399344, 54.28728588165776, 61.13130015711631, 55.65881321507116, 51.56016780484108, 49.490580174230764, 46.36881674489668, 40.01576554390692, 43.79295310666485, 54.878453746918716, 49.99747591633951, 31.20872659067954, 10.124269896937955, 0.22317860335592302, 0.2532593368162071, 0.18193342542696386, 1.3847740355037874, 5.7983554947760805, 4.458481198356998, 1.2843834224247164, 0.7488600164651872, 0.1360415871585569, 0.2710839811592333, 0.5496249395993449, 0.14457323257961582, 0.12543958912213005, 0.25505138501044244, 0.17378099352842377, 0.09402833713759338, 0.23799641388318232, 0.22449711728240215, 0.23353526939547833, 0.3674973108835759, 0.13344822631728265, 0.37046590159016274, 0.5169929035248295, 27.020507974009362, 48.32427517060311, 45.21680093580677, 52.0049096691993, 75.78690682688068, 7.446909046942189, 5.206117312754355, 0.18781829835666766, 0.172391310033779, 0.958941733885196, 64.10828498102003, 99.6229777797576, 78.64050957464403, 121.72198787812265, 30.610737723688928, 0.5595195473682496], [0.359755655330035, 0.316494271880196, 5.638511555810129, 83.83267648758428, 73.07567827163204, 66.68030077411284, 61.74498634953653, 7.54916915970464, 0.46629299019132897, 16.909457445144653, 46.4582860085272, 54.493226005185036, 82.12635132574266, 25.855546382165727, 29.881704430426325, 22.60065967036832, 0.12442395571739444, 0.07443215277406477, 0.08319232222293654, 0.09989726777759292, 0.044393343475436976, 0.045273950053078514, 0.06922762720815598, 0.01450480615359641, 0.06940885296752376, 0.03557199807537179, 0.04520689820750587, 0.037199705088090514, 0.08685872709799199, 0.024767379359071775, 0.0544454014649795, 0.09118946809922496, 0.04803395417008189, 0.042321891523897655, 0.06323616080466779, 0.05509025214480297, 0.05330526728122946, 0.04219425361483328, 0.05470695537364772, 0.07706779400788008, 0.1407793659957186, 5.802039090664157, 26.431695492036884, 33.163055373776345, 43.28280571968325, 51.6341946971032, 56.572898049508375, 56.41774477497224, 61.32276673470775, 64.6279166590783, 61.11513999200637, 59.022732011733524, 63.002831628245694, 60.449321577625895, 60.873937760629964, 63.55176733386133, 56.87867818340179, 59.03431477085237, 60.43931561131632, 65.20474433898926, 58.38360532637566, 55.6062142310604, 55.17089782222625, 50.57739442394626, 49.38504488237443, 49.77498731305523, 47.386699261203894, 50.4966720458, 47.77436671718475, 48.16937685012818, 46.58886563393378, 47.88580517615042, 48.46776723861695, 45.72692086619716, 47.1880155224954, 47.1749657969321, 47.955148758426795, 49.1983518292827, 44.94919723080051, 47.207007638869754, 54.30891383078791, 55.416795130698915, 57.33599908890263, 50.02046100554928, 49.283502563353515, 48.407500020919315, 46.18039784892913, 40.230378027885195, 39.60608182414886, 42.375137882847945, 45.184123669901204, 45.21315705391669, 44.144024848937995, 48.15538575572353, 54.0790903952814, 50.19530457835044, 49.85494482901789, 44.705437614071755, 42.688809825528054, 44.23765182495118, 43.73898521546395, 45.0163285962997, 43.24657870877174, 44.984839808556345, 44.761096046816924, 48.58252794511857, 47.46213428435787, 46.55321913380777, 44.25689497301656, 45.32851788305467, 45.66422570136286, 47.30099547293879, 47.69486419616207, 43.35665218291744, 49.899448040992986, 52.96491369124382, 58.55407937880486, 57.816069741402906, 55.906730544182565, 55.137855775894664, 55.73666834062146, 57.49435693986955, 58.810504328820016, 52.62683676135156, 53.976281150694824, 54.10509178715368, 53.97555551221294, 54.417226160726244, 50.48945880705311, 45.54800979552731, 36.70383384150844, 26.60197146477238, 16.586944480096143, 8.333046993901654, 2.088887898191329, 0.28100322631578295, 0.3288213007392422, 0.044469354719284086, 0.07411610320090287, 0.07714670872496021, 0.14634580681881598, 0.17829576417082743, 0.15025048036008112, 0.2669505384420195, 0.16073102281699259, 0.09104057891114105, 0.08971677897798438, 0.053166092088025425, 0.01606318412438756, 0.0977766904379091, 0.04723349571107857, 0.015671022758338482, 0.03717257408425212, 0.05317258085274408, 0.05510684560924288, 0.04801688573112892, 0.02477851061661157, 0.053136421502718044, 0.05645840473833585, 0.12271250763367261, 14.995891894063643, 32.77176757012644, 27.265187386543523, 25.228922251732122, 21.702650670082342, 5.2201123295291785, 6.909482556004678, 4.065621750008676, 0.7294786661382645, 0.9055021982039175, 55.621531086583296, 75.2100516903785, 73.43600288514169, 98.2772517973377, 19.93832934287287, 0.4857832475775673, 0.31933112610732356, 0.3108379689435805, 7.4146539261264195, 97.24216184308453, 85.22781648943501, 79.5165160394484, 73.17113307214552, 7.716208196455433, 0.43124563210914213, 25.84933727018295, 63.7797119540553, 63.179895262564386, 82.67464376265004, 31.314697265625004, 35.4669261747791, 33.18583257736699, 0.15247575127549712, 0.10628057283259208, 0.036091087761545376, 0.025410818521894758, 0.052204655573493054, 0.012252448284397683, 0.028470809263507688, 0.013388137242967084, 0.05559674351506176, 0.04705223930819381, 0.03360293760535217, 0.023929512826725844, 0.007667332097151949, 0.09326878394330702, 0.03392351092770696, 0.03859480482435996, 0.009596547855424785, 0.13703940135817375, 0.07949618547553979, 0.07100837560550821, 0.03879534366029886, 0.033781413109071796, 0.05366791798282535, 0.06450444234595185, 0.10997135462539812, 1.3348314766922307, 20.450869375659575, 29.668554990522324, 41.738780390831735, 53.41338572963592, 60.897879908161784, 63.207210648444395, 63.01906239601874, 66.09684821098082, 64.59139154803368, 64.18354349751627, 67.45475707515594, 64.56127558985065, 63.329259118726185, 66.32827589588781, 62.02610261978642, 62.653736760539395, 64.56744155576153, 66.23036569164645, 60.23830982946581, 59.90482599504533, 60.50069285977272, 53.94217221967636, 51.85304726323774, 53.72264892824235, 51.42317902657294, 52.83391829459898, 52.0456434834388, 50.801663783288774, 48.546363692129816, 49.01571058457898, 51.41896640100787, 49.855270385742195, 48.5317724750888, 49.86874764965427, 49.78552279933807, 49.29859976614676, 47.51298389127178, 50.99992390601866, 56.90196137274466, 56.1877409104378, 57.90894362234301, 50.82120895385743, 48.61365979717624, 50.46791322769658, 46.91267298113915, 42.58852658733245, 39.81917242850027, 44.033582671996086, 47.56474348806566, 48.7586227540047, 44.30643843066308, 50.22041951456378, 56.036306042825025, 51.323044838443884, 51.53837903853386, 49.12567030998969, 46.809259691546046, 44.07946655827184, 46.33095018325314, 47.49310924160866, 45.470456692480276, 46.72033955973964, 47.5866146241465, 49.96748547400198, 50.18805996064217, 48.92315049325266, 47.86134919812603, 47.702202950754476, 48.194742818032545, 50.947105269278254, 50.134154827364036, 46.9172856884618, 52.83288278887349, 59.63377060428743, 61.81402790930964, 62.255416147170536, 59.10137945605863, 58.923143033058416, 57.669447621991566, 61.569373992181596, 58.619171111814445, 59.72063541412354, 58.97866810521772, 58.676720126982666, 57.031328985767985, 60.75177161924301, 54.130030216709265, 41.00201414477441, 28.849919073043335, 17.863058197882868, 8.24828653566299, 4.064915968525795, 0.999289010801623, 0.19893614935778803, 0.06383749385995251, 0.031516420534781875, 0.06827199380965003, 0.0832994289756302, 0.05789983747226577, 0.23361656664600297, 0.03410270272363578, 0.14176766538331587, 0.15012943846804483, 0.053857555387601744, 0.11096663307398559, 0.036733123068247116, 0.011321822868569965, 0.042428523302078254, 0.06791602339475386, 0.030896448560299414, 0.0482337077658984, 0.005619053826517156, 0.05722934582961663, 0.019686205440290996, 0.07195414945242867, 0.04590431017981422, 0.10474088932237319, 0.1672334239007004, 26.80645246659556, 38.72588626800045, 38.28512168699695, 28.980796798583004, 40.577048870825, 1.659768589081303, 6.7101834954754, 5.136739900035243, 0.3153669275343418, 3.99181132355044, 69.25389336001489, 80.4754884781376, 81.77451472128593, 107.31085469645839, 18.595613779560214, 0.40791522110662154, 0.6167187974337609, 0.5142758041620255, 7.423842568551341, 112.53422798648958, 94.93635731358683, 86.35195993608045, 101.75675499823787, 19.4970646596724, 1.3653406524850478, 38.501852250868275, 78.31981658935547, 73.8114207790744, 99.84736088783511, 43.37979808930428, 43.533323580218905, 43.48489015333114, 0.2904847901194327, 0.3081596336297451, 0.19079804330343203, 0.23397020815360933, 0.18141755714051186, 0.13471251654048122, 0.23152816499913895, 0.10739975068117343, 0.1440503622495359, 0.09113044102465914, 0.07219914437061356, 0.12551710189830872, 0.286601459787738, 0.15554453096082135, 0.14811070485701486, 0.26447972102511313, 0.08980560687280471, 0.26644835248589516, 0.17387057985028914, 0.12157112855704562, 0.10790014399155494, 0.16485639096748445, 0.27131463491147567, 0.13792452402412891, 0.5599481888836431, 16.81168060148916, 43.72804572505336, 47.98005188665083, 53.09747411358742, 56.07981297277636, 62.663503462268466, 63.94111356427593, 65.72740016445037, 68.44640285738053, 67.02300610080843, 64.67762485627206, 69.52684325556602, 66.4954786915933, 67.54870568552326, 66.7287185115199, 62.03674401006391, 63.0739991126522, 66.91543902120283, 70.35109796831685, 61.87221234844577, 62.204374344118186, 62.021956674514286, 56.713687604473485, 55.24018256895004, 54.23476142268027, 54.43606138229371, 58.604340630192915, 55.16754811809909, 55.30468202406361, 51.250324095449145, 54.69207448344077, 54.79026709833453, 51.567502637063306, 51.927435013555716, 54.79641737476472, 53.02435721120527, 52.16507573281565, 49.90359006389495, 50.371736711071385, 58.2059141128294, 59.0186409796438, 62.80157089233399, 52.52185060131935, 52.18835892215852, 49.77181019321565, 46.200856931747936, 41.15030327150899, 40.216830161310014, 44.7162712004877, 45.93641073473039, 48.477549629826704, 45.675361310282064, 50.408175529972205, 60.01330698690107, 54.38961659708331, 52.71145013070876, 51.66526771360829, 47.95909858519032, 47.6877333271888, 48.654240638979026, 50.958119284722116, 47.947425611557506, 49.150667575097856, 50.89086240337741, 53.69072475740987, 53.63502317859281, 51.39666380420808, 51.408026910597286, 51.45832738568706, 51.99512335561937, 54.30537585289248, 53.005988751688314, 48.826409155322665, 54.19202327728272, 58.175625570358775, 62.852895106038744, 64.50552302022135, 62.61459542858986, 61.35727182511361, 59.648534405616026, 63.041353225708015, 59.368583079307314, 58.99820543104603, 59.34250324003158, 58.89721224384924, 58.75204140140165, 61.67354822158814, 53.74513195407007, 52.63010801807527, 51.333670539240686, 41.46532450952838, 35.75646769615912, 17.92907953262329, 5.0153876504590436, 0.4050407366406533, 0.6455390864322263, 0.13519567287256642, 0.16000754470306058, 0.21007329045284182, 0.26111549187091093, 0.7423464917848188, 0.4065962015621124, 0.4217201255021557, 0.1882955711334944, 0.17818129531318144, 0.18975732818005547, 0.10675788391381504, 0.18294171970938483, 0.14290565835131755, 0.1387823892817382, 0.13589324189289925, 0.12684095545762009, 0.09532351602589893, 0.19909767133574333, 0.13798389583826065, 0.1313967960736444, 0.18349993733629105, 0.31918851117933955, 0.3496630597979792, 37.85287649400773, 49.72109002451743, 45.15849882556547, 33.19844691984115, 57.29526527466313, 8.821341876060732, 14.969483556285983, 4.430933412044279, 1.7342920288924248, 2.5087332533251856, 79.27685922191989, 88.79523569537749, 89.96702025013586, 121.13408734721523, 26.342726330603323, 0.706695395131265], [0.28629704709014586, 0.22873937512838075, 5.165583539393641, 92.06013817940989, 56.975792146498165, 50.23823099751627, 43.74254280521024, 1.4701479769522146, 0.6648435828185851, 10.92332043955403, 50.8402834400054, 54.22736383253529, 80.86237538245418, 68.25564230642011, 33.76267594675864, 30.372704767411758, 0.578745780212264, 0.056394834762379054, 0.11358008840151372, 0.06693567599981062, 0.04245926258004001, 0.06977773196394406, 0.06597186078227336, 0.03311845211071834, 0.03997861625506513, 0.039793138707717585, 0.03434952859195971, 0.02434888276301565, 0.13563595892440888, 0.06523693731475262, 0.024693681700755993, 0.09141046914362139, 0.02046311818694155, 0.05219378861628714, 0.07868201787313146, 0.006545458097882088, 0.0369243884098626, 0.03331979916941735, 0.018753027994065516, 0.04877902064172011, 0.0536414573059207, 0.13991054568079211, 0.6232749778897532, 6.40436904084298, 11.037977203246086, 33.25207356483706, 54.11089297263853, 56.3631885282455, 56.1696627063136, 59.65473175048829, 59.45225115745299, 61.36731701512491, 63.569818081394324, 60.50967900983749, 60.30681010215514, 62.58355771341632, 61.54524357088151, 62.05478691285657, 64.60998358265047, 61.47260519766039, 59.430517304328184, 59.19189599252517, 57.78469470239455, 50.84466864985805, 50.354368455948375, 47.85914874845936, 48.64694503045852, 48.659606441374756, 47.4949723674405, 46.55501950171686, 48.15178501990534, 48.0798722851661, 49.64516078272174, 48.2353981848686, 45.68883857419414, 44.296585436790224, 44.61699993379655, 46.52598219533121, 50.30732747047178, 50.13853611484651, 52.70874761766004, 50.08918093096826, 49.42064431405837, 47.519800970631266, 47.28598063991916, 46.6001699047704, 46.99147732027116, 44.59865500850063, 43.38224564829181, 41.771634163395056, 48.78851905945809, 48.401141858869984, 45.859555813574026, 47.40439699542138, 48.61367548665693, 49.99866439450172, 49.815799574698175, 46.80173266318537, 44.92339980217719, 44.81957858608615, 43.945811794650176, 42.7427149588062, 45.25104322741109, 45.20793245684716, 43.162804726631414, 45.11329743169969, 44.37624877498996, 44.089935364261756, 45.33314235748784, 43.73741234502485, 44.418794724249075, 43.65574859803723, 45.42787936425979, 44.96476119564426, 49.03474192465506, 61.000638161936116, 59.29603099822999, 59.024222512399, 55.73030625620196, 54.17391369419714, 55.053332621051425, 58.3832444683198, 57.56448891855056, 56.931257555561686, 53.67080303930468, 53.122047762716974, 51.51108718687489, 47.45166940073813, 33.23075156058035, 17.04487531415878, 9.838406578187021, 4.813782236268444, 0.17477704572581476, 0.08303664549584351, 0.09462479787367968, 0.06589426373642299, 0.07383325587837927, 0.06250361987059155, 0.09569175150846282, 0.0671037250468808, 0.022349983168345307, 0.02630874826272409, 0.043877659050086816, 0.13514048389850125, 0.09260955762358443, 0.07667029396660867, 0.0377863215943498, 0.05385693485638308, 0.015317192601580775, 0.024190748808905486, 0.10920741174730564, 0.0665908445033335, 0.01544726379741464, 0.045980321423661326, 0.04533879556542924, 0.10511491642964464, 0.061236249973937396, 0.06641145735498398, 0.06753622764541257, 0.2520821814335162, 19.2621813666436, 31.69654000189997, 20.161969161802723, 19.045011497312977, 13.484522258081745, 3.3092556653484224, 8.638250539379737, 8.43375777044604, 10.422878957563832, 27.518721549741684, 54.186492735339755, 63.99092766546435, 81.13408580903085, 83.10495914951449, 6.2599802209484965, 0.31554398577540155, 0.16010290732787502, 0.08480111452480478, 4.464704038635377, 101.59582799480808, 66.65180867718112, 58.7580700843565, 62.62276180328862, 1.1035881431833392, 1.293339174120657, 21.841686925580426, 64.08350344627135, 63.43973659699964, 87.98646650006695, 67.48385321709418, 36.40043850867979, 39.69982647126721, 0.6940646890190341, 0.11117256516891141, 0.02629213756130588, 0.04091097590243144, 0.02728366983994361, 0.014460986881937473, 0.08187727867475442, 0.04628988223210458, 0.07002658796526733, 0.07209850340000085, 0.06710138081783248, 0.053446790533921415, 0.04803475090152314, 0.01775779934119313, 0.05921192009062056, 0.08246296055374608, 0.03803119010802719, 0.05803199146964377, 0.07409287541503869, 0.08635245789323123, 0.02834267914295197, 0.024278274354254527, 0.035579084388671384, 0.020038282213312004, 0.04053316815125366, 0.17257558482308544, 0.6347306889872397, 1.23938697240045, 7.2232726600862325, 26.893117235552882, 50.702553333774695, 62.04149400034259, 63.62553534969207, 62.57804678332422, 65.04040095113939, 65.07921672636463, 65.81393549519201, 63.92222735189623, 63.498811414164884, 65.68524645220849, 63.37449973629367, 65.63757396513417, 66.64575253763508, 66.25171907486455, 63.39867330366566, 61.841892427013775, 62.12036501976752, 52.792815777563284, 51.08748689774544, 50.48632091091525, 51.86654413900068, 51.933424472808845, 50.537445083741225, 49.896349368556855, 48.86826476743145, 51.53309952828192, 50.62101510263259, 50.98156329124205, 47.99780453405073, 47.89920791502922, 48.32655406767323, 48.36183186500303, 52.342190357946585, 53.57732119098787, 55.9614868317881, 53.81261241051459, 50.42975641066029, 50.69262581486856, 49.40944986958658, 49.23559081169867, 48.375430722390455, 44.50272167882612, 44.55024119346373, 45.97394781727945, 48.342804447297134, 50.5015318624435, 48.730722934969016, 49.71211564156317, 50.96550903012676, 50.7887670301622, 51.40805828955866, 50.2389056451859, 49.00460635462115, 46.067947418459006, 45.34287375788535, 45.95524987866802, 46.276633201106904, 47.161155131555375, 46.320912837982185, 47.12106850839431, 46.09645128250123, 46.49446595099665, 47.49704730126166, 48.82656605012956, 48.52270395525041, 47.470810567179036, 48.602539877737726, 47.24988306722334, 51.74590772198093, 62.36785481053015, 61.918519850700136, 62.36310482025147, 59.165282710906006, 55.7773825430101, 57.359862789031006, 58.65621005335162, 60.36601435753607, 60.43269857283562, 58.64257197226248, 56.85523809925203, 56.58526136029152, 48.7574891890249, 27.543434443012362, 6.1893069551837065, 3.226256596465265, 2.323586594673895, 0.25265365238151244, 0.15876375499271578, 0.13381271562989683, 0.06516306345621425, 0.11376910527507145, 0.08823400813966029, 0.06928727481394045, 0.04759333486999235, 0.04562988216357847, 0.07890564659910818, 0.011894183436168299, 0.08944614309697382, 0.07433088361135415, 0.022273165616957892, 0.017093068679734584, 0.06187793288019396, 0.045798180189224026, 0.056718763549842184, 0.0032734149370357516, 0.10206995441788629, 0.03296435735518894, 0.04267845182649551, 0.03245421940641057, 0.06130664962373915, 0.013100092013877247, 0.08090616263929876, 0.07286770164125389, 1.3601172811562017, 33.648927211761475, 38.51266230306318, 28.681627819615027, 25.74410007845971, 24.33278814438851, 24.32296652947703, 20.679029726213027, 13.161236586109286, 22.810543737103863, 51.77069710146997, 63.21426307001422, 71.60091415528329, 90.04140407808366, 83.6176678442186, 3.4961475335782577, 0.36644427706637694, 0.47605622920297813, 0.3805937984537694, 6.662075625311944, 115.4098822993617, 80.1226555916571, 69.48523475277808, 85.27460252085041, 3.3014499035573777, 1.9068948251585809, 38.965617610562234, 81.64546089787638, 79.36604607489802, 99.20461777717837, 77.75295565205236, 52.207139230543575, 53.300292030457534, 0.9981879279498131, 0.1832548964528307, 0.16444307121057666, 0.11223075475784079, 0.14261137333608445, 0.12087653195785901, 0.15002943335040925, 0.17357992609181713, 0.1797140687103233, 0.21685638615200598, 0.18622934007115904, 0.12723246469132363, 0.2441073593593413, 0.20304497000911545, 0.16087812702021292, 0.19376255842226167, 0.19368945831252685, 0.23900426383460724, 0.1765720050541624, 0.15825468956703143, 0.1550282030216148, 0.11396481009620814, 0.09219694266756696, 0.11250033343751585, 0.15110817707834706, 0.7962411449801537, 1.9835756911385445, 12.241572180101949, 22.16025398623559, 44.40354847138928, 59.84574333313973, 62.04741285693262, 63.624692040105025, 66.1031004690355, 65.05263482370685, 68.6799721564016, 67.28047047891926, 65.32764396359845, 64.79620202895134, 67.73837581757577, 64.46850369053503, 67.21167210609683, 68.7624909800868, 67.58599173638129, 66.36129440799837, 64.42378474820045, 63.907287043909875, 54.805768305255526, 56.02018510141681, 54.186492735339755, 53.02735390201692, 54.879524553975756, 53.77884472570112, 52.30824224410519, 53.54109418007636, 51.774752832228145, 53.29530669796852, 55.37393146945585, 50.286123137320246, 49.25459469518354, 50.64774213298675, 49.49228248288555, 54.10267560712753, 57.2304206509744, 58.21392751509144, 56.30003052373087, 52.823065096332186, 54.214698499248875, 50.43480842344223, 51.33680843537854, 51.45068660859139, 47.75020099455311, 44.49630075885404, 47.146018705060406, 53.04011729455764, 54.216553780340384, 51.51090675784696, 53.598470610956994, 53.81000795672017, 53.74002895047588, 55.11790267882809, 52.402218311063706, 50.79138325106714, 48.949885368347175, 48.12260258582331, 47.69800993704027, 48.65166364177581, 51.55202104199318, 47.342662811279304, 51.13697936457973, 47.52997559885825, 50.28456203399166, 51.06478029681791, 49.690840705748535, 48.44389177137806, 49.37721583151048, 51.37578502778084, 50.286374169011275, 54.810463382351784, 67.9877208894299, 63.15801628174321, 63.63671802705335, 59.47430272256175, 59.030678733702636, 58.584964121541674, 59.625859183649865, 61.162286881477606, 58.94968178964431, 58.69649279502131, 57.28281959410637, 59.299992592104026, 54.259299770478286, 53.526173483940866, 46.09638067983812, 27.77954347672001, 11.796788150264371, 1.2756516135508016, 0.24535015315538455, 0.19641215011717814, 0.25327859626662347, 0.19222615376835872, 0.14827659353613853, 0.13230804233781754, 0.09259676395524895, 0.2697139095154501, 0.2671580563389486, 0.2297577204843683, 0.148095628246665, 0.14460108753654266, 0.18751814510793458, 0.13186479918658733, 0.17006327608420005, 0.12083717802118872, 0.18860268046057996, 0.15813865789001988, 0.22663612669754415, 0.1320101873528573, 0.22990692376850114, 0.13318044794422965, 0.188247537420642, 0.12057470097657173, 0.21400532865476227, 0.17779969159633885, 1.4493733884826785, 45.37109521127517, 49.32391474323888, 35.427478897956114, 30.43086371114177, 30.62246757168924, 29.380403949368386, 29.098440447161277, 20.01312698087385, 20.839474278111613, 56.76824385120023, 73.28729798716884, 82.5233736345845, 95.79817264310776, 103.03142332261609, 8.026521119379229, 0.7926274775978058], [0.07545134848764828, 0.15172539879718136, 2.341897689527081, 69.54458805822557, 73.76525448214623, 47.904801214894945, 55.95897259250764, 6.81520446654289, 9.138559641376618, 22.82268935634244, 38.153239834693174, 52.805332060783144, 49.87824370784145, 50.56503503553329, 26.564230418974354, 25.121982751354096, 1.0849405825138092, 0.22117490038996745, 0.030923608292434967, 0.05028546359690447, 0.052719700315426436, 0.051881393282524044, 0.060941884519472245, 0.022803476576002377, 0.1130329637277511, 0.07468939743815892, 0.040479105326437184, 0.024256306783025785, 0.03505665838958756, 0.02786632758685418, 0.05089824583621756, 0.023008211658546524, 0.06149293539384681, 0.0572741543123078, 0.0757206360539121, 0.028068544155347253, 0.030704321369769114, 0.017913566083617268, 0.011159720579012027, 0.01275694303800382, 0.012169106536725116, 0.03942283478775813, 0.22018056422952684, 0.1293291247660114, 0.44999725816230624, 4.289237789569363, 21.092231812015658, 42.788591000341604, 53.897927884132635, 52.59584611462009, 58.093867686487016, 60.52874172887495, 62.30347302652175, 60.85321587900962, 63.920674093307994, 62.25175265342959, 59.48496764706027, 60.49937102102465, 61.60801718311926, 60.056174570514315, 59.95952344709828, 64.91928600495862, 61.54695764664681, 50.8276024172383, 47.370954867332216, 46.11478444068663, 47.314119723535356, 45.7812653049346, 46.50312654433712, 46.477748809322236, 45.716769772191206, 47.565429902845814, 44.17310137902537, 45.15867140985305, 47.11455345153809, 44.89498223027876, 46.88622443906723, 44.80114344627627, 49.379565331243704, 51.12495337763141, 53.34039826546946, 53.727312626377234, 52.70673151939146, 49.2644908351283, 47.14814855206398, 48.65322082273422, 44.80726234374508, 45.66397074730166, 44.86498394320088, 45.54749988740491, 48.023092054551654, 50.96515209444108, 48.10905079687796, 47.94328358865554, 49.669961929321296, 49.440201251737534, 48.78602050965833, 49.65371939443773, 45.83630008082236, 43.7518858909607, 42.71572512965049, 42.98504683279222, 44.26083303266957, 43.07070747498543, 43.42137129076066, 43.500932647335915, 43.81950755273142, 45.43797162271316, 44.12265577623921, 43.9665925118231, 46.98426800389444, 44.98942898165795, 44.325034387650035, 43.43531139435307, 50.015299166402514, 59.962347553622344, 55.872660836865826, 54.805752615774836, 56.938764972071496, 54.066440751475675, 52.42633696525328, 55.28164594404159, 57.88435820610293, 52.784649402864524, 54.641256255488244, 52.46761598894673, 43.21761200504918, 29.381311978063277, 14.70570416219773, 3.5633735262578536, 0.4569950116978538, 0.3735304984354204, 0.15721687025600867, 0.024053829744638457, 0.04520265024996573, 0.04554400370726663, 0.17100818425176606, 0.05550353359731455, 0.1433711793393858, 0.006878218442697319, 0.12394497456449656, 0.12372913695270978, 0.07301778592649968, 0.05870363990505857, 0.06494366353557957, 0.11303793563837967, 0.11781824001621817, 0.0334346012753104, 0.035625386742814895, 0.019476816373606844, 0.10583136185643174, 0.06497494290552794, 0.07285704535822715, 0.056087537743752046, 0.021696856823719798, 0.020476187646929777, 0.09067727703480952, 0.010764036166121163, 0.1921995398738692, 1.2986910030726464, 25.650608424217474, 25.131355254880845, 17.470685858880323, 15.16990980794353, 8.203843630129292, 10.038970112800598, 21.767448225329, 27.91020743308529, 41.439464322982296, 49.776454279499674, 59.069906357795965, 78.98912199081914, 82.15866381122221, 41.660285918943345, 0.027083625130715872, 0.036919837847592375, 0.09131349773416597, 0.0192194816941816, 1.7166055714891804, 74.5122463472428, 88.34996038867583, 51.020571262605735, 85.47242333812099, 19.55583941551947, 11.844418471859349, 46.886420557575846, 51.134014052729455, 62.19909483386625, 59.095025216379476, 54.38475285806964, 34.140521787828014, 39.45495290140952, 1.6306266044416737, 0.15138378486998622, 0.04823575322065623, 0.06488489693090801, 0.027596038360629353, 0.06396385623262295, 0.029307570714022846, 0.03529265560510178, 0.07189948141815201, 0.07186195843162076, 0.03818818067591037, 0.00967656190867626, 0.02160100581785364, 0.08218076440595812, 0.04212434809174269, 0.15411203847296778, 0.08890297909777972, 0.12754719659325578, 0.045709279516050895, 0.04737415328441609, 0.03239238078916266, 0.031189797033045082, 0.0727219304310218, 0.0355753114056443, 0.0397726496861827, 0.057779714885738596, 0.01051491107641449, 0.12608452024118555, 0.29638431065024873, 1.5159052442158423, 11.973561529190311, 37.812558451006495, 53.54026655997, 59.848743946321555, 62.42906731943931, 63.132348291335575, 63.36265025600311, 64.81648068274221, 67.25593997586158, 65.68967873050322, 62.3686118279734, 65.32114067385274, 64.12752420671525, 64.07379558009487, 62.66633149116271, 65.11085456417453, 61.58013697593444, 53.02250585248394, 50.28880996088828, 50.395729849415446, 49.382452195690526, 50.15789693401706, 50.05077308224094, 50.30912783838088, 47.49381526823967, 51.945642655895604, 50.40458263889436, 47.845004681617986, 51.06016366712509, 48.12337921511743, 48.730620953344534, 47.33144875495665, 49.97085478998, 51.058437824249275, 52.79391011884136, 56.8267067786186, 54.66764988437776, 52.28084841082173, 51.44104150033767, 53.12529548521965, 47.12449665992491, 47.17037662383049, 48.867037065567516, 49.562104594322946, 49.25698341861848, 53.810051102792066, 50.871760460638235, 50.934679200572354, 52.402147708400605, 52.99784198884041, 50.33392506261026, 52.65801960422147, 47.90969241049982, 47.525523708712676, 46.493897207321666, 44.70719483590896, 45.15744370798911, 45.80211662477063, 44.92174848433464, 46.50153798441733, 46.909417413896136, 47.488351406589636, 45.892915571889574, 46.10554333656065, 48.071780435500614, 49.84813167202858, 47.98454300049813, 47.66612106753934, 49.51390258727535, 65.11711466696956, 60.45849207908877, 58.03333766998784, 59.84815166842554, 58.257709010954834, 56.39281811252717, 58.89980885290331, 57.30593019916166, 56.047112172649754, 59.99045525827716, 56.322839106282885, 47.098703153671764, 22.366115662359423, 9.527366545892532, 1.6147873382414542, 0.27830396147985614, 0.23960783386663084, 0.05260749907803632, 0.03157690892206325, 0.022937314051593986, 0.016906934211991968, 0.06455037697789169, 0.09645189459045088, 0.01816586565016018, 0.01475439089605765, 0.10508332296364731, 0.09119830875387115, 0.017037400900716745, 0.03652808729619269, 0.061087337803215756, 0.09159033892736321, 0.039728185943057465, 0.09320297699061134, 0.06278486989979302, 0.017529242754643484, 0.12749975276810507, 0.02364819193439138, 0.026116059912789254, 0.04716072118871155, 0.06294193707646863, 0.03529479299041052, 0.10143806977618126, 0.04504259533038543, 0.2666905588440357, 4.501091376427682, 41.7331753238555, 31.765646280780917, 24.751414868139452, 17.085397320408976, 8.518636880382415, 18.600554004792247, 35.566303345464895, 44.74750111179967, 51.42754070220455, 59.33385441380163, 78.38737549320345, 81.25017227665072, 86.97756228908416, 26.087829143770282, 0.15855403076256477, 0.06324617740427775, 0.24239299248062798, 0.4141705128694735, 3.5369845551829187, 93.29410799088018, 103.32357714253088, 69.89302004537275, 98.66394258314564, 27.077166611148467, 14.367619387565123, 64.43952129733178, 70.37984894167992, 73.58073834450015, 68.39349792849633, 66.60807424975981, 42.489274932492165, 55.261512417947095, 2.763806211371576, 0.41732471135835497, 0.17785993675070425, 0.1589411196689452, 0.17195920580096785, 0.1739607943642524, 0.13053272550384845, 0.12461985972139145, 0.12406629224818562, 0.2608810383225641, 0.16491367902246215, 0.11396121714384326, 0.08538844349283366, 0.15910486330188092, 0.12913401749345566, 0.25779483779784174, 0.2058088007353006, 0.30545292241919425, 0.1518755826738573, 0.08890806592159695, 0.13975961103795037, 0.13626730730456693, 0.12500451246817268, 0.09205381446067365, 0.1616730658157218, 0.11215442175706548, 0.4854708675655627, 0.4074216459787661, 1.7110527210658597, 8.3803488169947, 33.24264810931298, 54.91917187167753, 61.17028067188879, 61.48084609739242, 64.7792063989947, 62.79311033987231, 65.12941129745977, 65.19547185590191, 69.249343410615, 68.1624860148276, 65.31390390088482, 65.36690688902333, 66.61745655921199, 66.46839080318328, 64.81819868087769, 68.73626601311469, 66.54042905376804, 56.25000069218298, 52.573994590390114, 50.76022394241826, 51.74700990799935, 51.86095083913496, 53.051821647151826, 52.42460720000729, 51.15172355405746, 54.68962692445325, 50.752885187825854, 50.42739906618672, 53.8853370758795, 49.49978597702519, 52.589891956698516, 48.0925807645244, 53.77423986311882, 53.95170357919509, 55.10464114527549, 58.15019684453165, 57.14916090811453, 54.2534593612917, 52.76101320020614, 54.93679508086174, 48.17687249952748, 50.67561057306106, 51.370113280511674, 51.29736115855556, 53.136234975630245, 56.421216072574744, 52.20196562428629, 52.273874436655355, 54.41957173808929, 54.1127678655809, 54.2103878144295, 53.92981675363357, 52.50414894473169, 49.9931416972991, 49.201980021692094, 47.6422534450408, 48.373826472989975, 49.39639622165311, 48.11942938835391, 48.19090674000402, 48.183509149859034, 51.93642900836084, 50.443135615318056, 49.23937589891496, 50.53421305071924, 52.95885362932759, 50.44860339933827, 48.568152458437034, 52.88182220151348, 68.51460502993676, 61.97109137811969, 59.163286224488296, 62.23330574650919, 58.22669483000233, 58.21783419578307, 58.84764525198168, 60.13266471124465, 57.452603309385246, 59.18002297801357, 59.59113051814418, 52.56570662221601, 51.840413308912716, 34.31750305237309, 9.285090565681458, 1.2356973703830474, 0.4346877264399683, 0.322125569706963, 0.0991519868013359, 0.18604744015441788, 0.12070850589342656, 0.23039542739429783, 0.22962869595616098, 0.21471503250781568, 0.16758505825794515, 0.21115460823620522, 0.34373427470845563, 0.2349329355262941, 0.19771787037532176, 0.22451127458724285, 0.26053206995129585, 0.14746539835487643, 0.25359837668797663, 0.1538964306875583, 0.14985137919504798, 0.21979205039960725, 0.14501630719150269, 0.13571310397838393, 0.1529337033148735, 0.1642797106216031, 0.14504166470179636, 0.220538143429064, 0.19006802279862667, 0.32704223007444416, 5.496551173348581, 55.362635043359575, 42.753811344023674, 32.37805181933988, 22.006846166426136, 10.791546452429987, 23.381009332595333, 41.625780828537486, 47.9633229778659, 63.657212411203695, 70.0149037761073, 80.56203949835994, 92.26996929414811, 102.49914200075212, 57.984562996895086, 0.21098940903621338, 0.1611249605494161], [0.06307362759065244, 0.012307576929038812, 0.19922404519973264, 39.70678867832307, 70.88020217034125, 39.32661294937134, 59.8178082127725, 48.112216149607015, 28.469249125449892, 64.91697572892713, 56.00252659090104, 67.85165386815225, 46.724418824718846, 45.73409095887215, 39.50681447982788, 12.24074750177322, 3.33316765965954, 0.17773198474559093, 0.18844298177188445, 0.058484285949699344, 0.06414540757935855, 0.045501627553735054, 0.06277447791710015, 0.009722915016144756, 0.09755827877069674, 0.03304964209335946, 0.023035200936118924, 0.052805617076134494, 0.03001728414317533, 0.08318027165988762, 0.024495192150014545, 0.04830670445376346, 0.13083937517817945, 0.07758428282555073, 0.03917339655961241, 0.05176267646733792, 0.06187576102092863, 0.04644987969509056, 0.05327040645023508, 0.028661668578523303, 0.04157507837179207, 0.10502833317244246, 0.04606817255637819, 0.03448233376407335, 0.041968702008166624, 0.07744467096222986, 0.204000496155312, 7.159938639210117, 27.345227272279804, 47.37586959715813, 59.01436559615597, 59.30475042712305, 55.752769670178814, 60.37583989481772, 62.30601080002324, 59.02878815127958, 59.24733869491085, 61.17462665803971, 60.40674032703523, 59.54509758180188, 61.48393300271804, 62.36594069388605, 58.01039964922013, 51.66939796939973, 50.23027643080681, 48.8060716659792, 48.334088940774244, 48.38106716832807, 47.859799861907966, 47.6036730120259, 45.42986800593715, 45.4185402008795, 46.8866245208248, 44.38679995075349, 46.819587292209754, 43.65902377713112, 45.097141188959924, 41.47402432657058, 49.16367807695943, 50.69487725534747, 52.00590595122307, 55.75630764807425, 52.573351321681855, 50.345276401888945, 51.056837497218964, 49.91347051435902, 46.6075086593628, 46.45185724381478, 48.31089596594534, 48.060888013532086, 48.11066289101878, 50.75353630127446, 50.12552169061477, 49.83367381557342, 49.858733838604344, 52.915452603370916, 48.001487639642534, 47.87268092555385, 42.2555487386642, 43.81566362996256, 43.7362434787135, 42.74083222112348, 42.61423380144181, 42.02887888877623, 43.15820770878946, 44.668924270137666, 43.661490947969504, 43.78194301359115, 44.034186717002626, 43.44068111911897, 43.950397045381614, 44.34458348058885, 45.1138347964133, 46.65171769357497, 49.50718748954035, 56.06690837490944, 56.53438037441623, 54.28730157113845, 53.33407932712186, 57.33377510501493, 51.91147096695439, 53.568405643586196, 51.8134666258289, 53.706755484304125, 51.45924914267756, 41.98488166255336, 26.9794289911947, 12.046058697085227, 2.435097127191482, 0.5988271510408771, 0.11125986854876242, 0.02518685080201155, 0.04775935378406317, 0.022404930824714325, 0.03860263807338573, 0.14038046401354576, 0.03438277680787348, 0.03791220899250719, 0.039257244882924903, 0.03270859507122829, 0.021540961761568344, 0.04869836690505186, 0.04134235618215415, 0.10947610942586776, 0.03193907124260741, 0.029617742477585713, 0.027656484613074895, 0.03737130878312934, 0.06741405194324833, 0.03744248218173462, 0.14461098539252437, 0.020361356812739567, 0.050115683191125436, 0.024328577602582595, 0.06340366975975133, 0.016951147061322006, 0.03754276309102293, 0.029836345666779146, 0.21494827563724211, 4.661083875163909, 40.91971497381888, 19.27504477962371, 19.888115159926876, 9.346551164504021, 8.784090145941704, 8.81007977070347, 12.699124505442958, 19.34131714605516, 42.99797496488018, 66.48520992648217, 84.23191885794364, 68.20598510003859, 46.612042919282, 1.6100210456117507, 0.2033834889410965, 0.02362140567011891, 0.016420807373980363, 0.025328142313106407, 0.07415705060045566, 34.703887893307595, 86.47020370729508, 49.460377923903934, 65.83341398546773, 66.36644055766445, 40.05725245321951, 80.03318632802656, 66.92536261773878, 78.55162866653936, 54.34506631666615, 48.85440311124248, 45.182711616639175, 26.192803536691976, 2.738089926781193, 0.0877451980786939, 0.1983817774922617, 0.04799228664788027, 0.0830208411019656, 0.12462170599328896, 0.035447627531304475, 0.03262597248859463, 0.046333809713682825, 0.015662768160954358, 0.05691667853464043, 0.043850003276020295, 0.04580464597130495, 0.07413945356083494, 0.02390236075546953, 0.025423351720335986, 0.1045266068690727, 0.12868375697683904, 0.05996089744111223, 0.07183739765276832, 0.02582818130782295, 0.029389000114714427, 0.06289338625426735, 0.051147435085787896, 0.007488864254311569, 0.007279434489206441, 0.017709602834656835, 0.07585175200215272, 0.02803050597468692, 0.11789012970703265, 0.11702850295771515, 3.2003380646628723, 21.398227676268547, 48.10658754840974, 64.11593752522623, 59.82473511849681, 60.07432729967179, 62.71946783988707, 64.90181969058129, 62.430993203193914, 62.04107430673415, 61.39530704867456, 60.23366182081161, 60.032785477176795, 64.01877257131761, 66.76842858714443, 62.38020635420277, 54.19240374718943, 50.60101885949412, 50.97419708005844, 48.91293271895378, 50.80426039234285, 50.48780748921056, 52.0892680844953, 47.344110165872884, 49.537966328282515, 49.26679326641945, 47.136393208657545, 49.56035129485592, 47.62494794784054, 48.056051731109626, 46.90076074292583, 52.18069068847164, 52.49026767669186, 55.02795096366636, 56.874638142124304, 54.39341345141011, 52.41607212251233, 54.457767778827304, 52.86158277142433, 51.36912092085808, 51.06607860134494, 50.04479146772816, 50.75961205267137, 49.891567999316806, 52.48445080172632, 52.043517558805405, 50.46726995898832, 51.57915207647508, 53.68925386859525, 50.478844873366825, 50.75850594428278, 46.03558394216722, 44.83513862855973, 47.25632752141645, 43.37922542325912, 45.111081292552335, 44.1996205237604, 46.23207115357923, 45.30157904471121, 47.53051296357186, 46.089559678108465, 47.85639132222822, 46.52129496297529, 46.52772765005789, 47.47032419327767, 48.828837102459325, 47.848730933281686, 52.95081277047434, 56.23397388765889, 59.81418394273328, 58.203509699913766, 56.09461992017685, 57.84926083780105, 55.80702389440229, 58.29628552159956, 57.81759946577011, 57.22869088572841, 56.14708554360175, 45.35681386147776, 21.944341236545196, 5.476915788265967, 2.0425726737706893, 0.35492663542109154, 0.04534472891640279, 0.045990311210193945, 0.0030888878175192665, 0.10306258986313498, 0.0738862002148263, 0.02608351458254601, 0.018126165058704156, 0.05768599551952174, 0.05473818111744139, 0.037758577720171986, 0.0094275105549323, 0.045138310355645035, 0.08585509829102986, 0.0626032266225065, 0.14130018321016144, 0.013716613719870728, 0.042596763871129484, 0.02437909344030965, 0.005188378826489733, 0.009200525406237331, 0.016415195779935006, 0.03436834754181966, 0.023771409516132647, 0.036879292644199826, 0.05857652676622233, 0.02145188297295282, 0.005531230464487547, 0.2135529997007501, 0.297067538504639, 11.27738985323137, 55.416779441218225, 32.542789405392064, 21.746865587849772, 8.271622677003185, 10.840977141934058, 8.868577018860849, 12.725932924978196, 20.435970252560033, 57.0065749076105, 78.5860513871716, 75.38356165732108, 66.94424490774831, 27.770676958945494, 0.5527608132650775, 0.08165695178773134, 0.040152299878818375, 0.1931347953335893, 0.17604936455045977, 0.4229364586212943, 60.24107117806712, 113.4045313250634, 75.78695389532274, 79.08545540225121, 79.232724712741, 48.92780242427703, 97.63403800226028, 77.42673996956118, 93.74789484085576, 65.70399145926199, 59.74337731638263, 54.13396827636227, 43.592245424947436, 6.2667973003079815, 0.36908400154882864, 0.3118756810022939, 0.13928943223530246, 0.16191580843540931, 0.2573365027145032, 0.14679171595602267, 0.08802401577873577, 0.12407769163649891, 0.10179486756603565, 0.10684217656812361, 0.16696742285163174, 0.2395804385624586, 0.16581911834016924, 0.0703389986207889, 0.07671959172453612, 0.22755956908147182, 0.2195787255562121, 0.19521017348574055, 0.3189021781567605, 0.17918896140350452, 0.18029663261146317, 0.1460486106694706, 0.11151190381497146, 0.09201200138176642, 0.1364925218325469, 0.10234291154530742, 0.24019919245714144, 0.14907680301656648, 0.32129693836454426, 1.6090140996440765, 17.413387875403128, 41.671370537050315, 57.733311653137214, 64.70093157983595, 61.979602921393614, 59.1594462240896, 65.99256807757963, 67.36274611565375, 65.83538301529424, 62.990723271523755, 66.53571436482092, 63.87764961488786, 61.61609726567423, 66.72326641698038, 70.7655434454641, 64.72621517796671, 58.29731318258471, 54.700746843891764, 53.5453813306747, 54.55662719665035, 54.420324833162375, 55.56837512600807, 55.25221247826853, 52.41624078442974, 51.89856636908747, 52.327375565805745, 48.34195329296974, 51.22281651343069, 49.117813802534535, 51.6845343958947, 47.9702930296621, 55.468444901127974, 56.29192690695486, 58.686671180109826, 61.96852222565682, 59.535342647183334, 56.94915140828779, 56.848036627615656, 56.133412161181056, 52.551648847518436, 52.05498264681909, 53.03953286140196, 55.18908193034511, 54.425871064586026, 55.439078115647845, 57.326938413804584, 54.083303020846465, 54.822724711510446, 57.550395842521425, 52.7915527743678, 54.38302701519382, 47.59473393040319, 49.64574913824759, 52.58769542940202, 46.30659226448306, 47.45302654081776, 46.672576858151345, 48.74753029115739, 49.32366763391803, 51.081862218918346, 49.574550274879705, 50.29574471135294, 48.94900675742857, 48.25215455024473, 51.35850698717179, 49.90029527295021, 51.72999074382167, 55.07874957976803, 59.054769931300996, 61.54936205956244, 56.3352337960274, 56.58276673286193, 59.57910060882569, 56.48504480238884, 58.772390657855624, 55.8104520459329, 56.49488602915118, 57.078075793481645, 52.49328790172454, 47.31654767067202, 25.748075400629354, 9.291607583722762, 0.8665405598378951, 0.35129522544241726, 0.15560535834200923, 0.15920246290343423, 0.2591667174091262, 0.22504989568504596, 0.2309032364357864, 0.1980566344554386, 0.18842006042118997, 0.1283485858490871, 0.11895900622250573, 0.1276443288811753, 0.14531399363711958, 0.1714317695868592, 0.2736418261643379, 0.23929298705151006, 0.13270208732255045, 0.18621538194917864, 0.1483855772042467, 0.14307111802120365, 0.1281138488482083, 0.1326215408381916, 0.14743035749321984, 0.11077928627210279, 0.17839720953376065, 0.1996897960141782, 0.13213856836720822, 0.09351509653272168, 0.3906052193093685, 0.6540327951792748, 12.726642873979385, 70.5058668505761, 40.539747130486276, 39.152757813853604, 12.874507404142811, 13.320134743567436, 7.535982641481585, 26.78044911353819, 35.93647703047722, 70.25720427113195, 86.86775945848035, 99.89182487610849, 97.10255684391146, 69.25703125615274, 1.9862236587270616, 0.3036331878073754, 0.2452873952326275], [0.05915353652991115, 0.27923678077997705, 0.2454946679814208, 7.106768460043016, 30.543894652397405, 45.79204790053829, 39.09562849229382, 43.619380381799516, 45.614066431599284, 68.66918563842773, 70.92592131706976, 70.74627676317769, 46.988237442508826, 65.23864146201842, 41.56122253787133, 17.060037236059866, 8.190008940235261, 0.10988546850820703, 0.052034645341336734, 0.1379392329122751, 0.09635159835940409, 0.013224131224917309, 0.02043227740232983, 0.03505066758201968, 0.0877456653923277, 0.02583433107863511, 0.05835136586439706, 0.027959485793666496, 0.04153011284107643, 0.13641252693149353, 0.05126389960247663, 0.012351863514331561, 0.03487625234429875, 0.006662110784917229, 0.02304226809722041, 0.03049513148594528, 0.027470298434397387, 0.023773506681825367, 0.03310717146603331, 0.026946480070511182, 0.018392145040354902, 0.02201037256107215, 0.04163013711091011, 0.011775287547929874, 0.04423580898512756, 0.02761577470077863, 0.08780918940300904, 0.10306004645122636, 1.0608512235264624, 19.242014500402636, 52.6897947249874, 52.88478359099358, 58.944053188447036, 61.63673285515078, 62.68762211645804, 61.37065495214155, 60.827885212436804, 60.857907033735714, 59.809755586808734, 58.68684376439741, 61.54762837194628, 58.828617834275775, 60.48567410438292, 50.86151522974814, 48.223497713765795, 47.09838936405797, 46.30902805636006, 46.28328946328933, 45.81634698375579, 46.218099671025435, 44.776926732832386, 43.93448398959252, 44.62082816708473, 47.340093658816436, 46.576855336466146, 44.4561396106597, 42.22934730591313, 43.89387569119854, 48.614989480664654, 49.25907404192033, 52.4573354567251, 49.45087009860624, 50.18317660977764, 47.75034612224948, 48.896203810168856, 51.01508386673466, 48.45134819707563, 49.32665255761916, 50.489066570035874, 47.97956551274946, 49.64904000682216, 51.601839065551765, 46.928872369950824, 45.54539749699254, 47.86809567482241, 48.606713279601074, 49.751794338226325, 44.7307643582744, 44.36115549456689, 38.72228945455244, 40.98845451108871, 42.0513109237917, 42.18553835345853, 39.48248794001918, 44.112257572912405, 41.06276381400324, 42.93878639897993, 44.77955472084784, 44.55333202115951, 43.65160265276509, 44.703633323792495, 41.30845323685677, 47.793162715050485, 45.565095639997914, 51.15259824260589, 52.47384471278037, 54.12749244320778, 55.338857635375, 53.03163320787492, 55.76721183715328, 54.09354432936638, 54.87020500244633, 56.44988859853437, 51.24404438080327, 49.167745574828125, 25.990830890593994, 9.528157884074796, 1.8053116889730578, 0.33281338491266776, 0.1080429581023993, 0.04828666742410391, 0.1086535914650848, 0.054353447931428114, 0.018622848588312348, 0.06812811483659091, 0.04679548877081083, 0.05357974892361991, 0.02469446502565857, 0.055062293766006354, 0.009945834153181603, 0.051252791327574564, 0.043668838803686445, 0.07397186416651934, 0.017960559832112446, 0.13190239878191104, 0.06608477448143306, 0.06053532548849622, 0.030765527964479504, 0.07086176169855941, 0.0762053092400874, 0.036554923356180234, 0.047669549127139395, 0.09458710634780508, 0.04504995360489815, 0.024994139469438986, 0.07496939491360419, 0.0651559694820354, 0.08680165354763308, 0.049379307986988176, 11.876396575281698, 42.4225514934909, 19.625728207249796, 11.945921567178543, 4.805242255810769, 3.675807041506614, 5.571357636682449, 19.71589957514117, 40.830367303663685, 46.2848231100267, 43.71451747032904, 35.82355591558641, 23.78717076393866, 1.7356294345471168, 0.22134662665907415, 0.06149647472005698, 0.22909776638111762, 0.0766605110238156, 0.2224462386220694, 0.3499053887301876, 7.297150992578076, 45.00549500988376, 57.78375333355319, 55.441266798204, 56.082590010858354, 55.678546659408084, 75.38274580432524, 79.46565858779415, 77.94753659156062, 56.6381545220652, 63.81667637055921, 46.30976546195246, 25.987461574615974, 5.231310206074869, 0.0741416292505399, 0.057937080836704666, 0.12601224750640894, 0.14605415714604242, 0.06419440273255592, 0.038799940187844544, 0.046581884305323326, 0.04085728846069786, 0.022791322591083667, 0.049233276306861834, 0.024071901758772232, 0.03696704801592616, 0.04714905750006438, 0.04427366521990588, 0.03453249720135524, 0.031136101930432265, 0.01816466672255868, 0.06822002240486684, 0.021072663704774553, 0.009058644007440777, 0.07506455069467907, 0.030477934727264993, 0.008704377180566231, 0.11572344153518639, 0.03087770047357246, 0.04748078889303631, 0.11455920239489888, 0.05089546493705242, 0.06280723583674239, 0.03920205973929936, 0.1552387086614486, 2.5871995331779605, 13.682144015066086, 50.00814476320821, 59.64086617192915, 61.85336535976779, 66.24783592839395, 64.51927092767531, 63.260962809285815, 63.537172194450136, 62.68193467970818, 63.64575909030054, 61.45948486943399, 63.808545297192, 64.05677641591718, 63.15454890651088, 53.92765552766862, 51.413129914191465, 50.56619997947447, 48.880910488866995, 50.055746647619436, 49.680701378853094, 48.230981596054576, 47.36602052565544, 47.34382775522048, 48.7739670661188, 48.13709966598019, 45.90649481742613, 47.1723025075851, 45.16045216591128, 45.12027140586607, 50.1516721325536, 52.533770684273016, 53.13759996045021, 52.63368521967242, 53.16986929985785, 51.42445771924911, 52.297993090844926, 53.52720114492602, 52.5837299131578, 53.83691541610226, 51.40654817704232, 51.52376428727181, 51.617763888451364, 54.0265816257846, 50.006646417802386, 47.7504010354319, 51.15144506577523, 51.80124452037197, 51.740632134099165, 47.047712341431655, 46.069892914064475, 42.05636685894382, 43.89611536456693, 45.41058563417005, 44.8644151995259, 42.28245619804629, 44.76064105187693, 43.263672397982695, 44.48468269840364, 45.70421034289945, 46.61552598399501, 45.75583657910747, 46.50544858747914, 45.85775152329476, 49.95146259184807, 48.580170600645005, 53.45294283282373, 58.847535425616854, 56.10381787823093, 60.14093698993806, 56.4380548077245, 56.336712529582364, 55.49152020485171, 58.75407711152108, 60.095766975033676, 54.29695060176235, 55.52657050471152, 24.347893191922097, 5.485989211067077, 0.7790325425805584, 0.27815610651047, 0.09861593975895837, 0.029964025710679354, 0.06203370153783791, 0.038578176885963454, 0.046368425396541436, 0.027807170277341243, 0.02033257680464416, 0.07002852616771575, 0.11425532595885378, 0.035964974367450324, 0.08909414101752544, 0.05894540959308225, 0.09038965698451766, 0.05169349106689615, 0.05867125353805962, 0.11507026731006562, 0.09449707569494363, 0.06425130391313184, 0.03449135061894213, 0.07536812069555444, 0.029842393930941343, 0.03142873794140835, 0.016525479882294615, 0.05647030208379992, 0.0580333014799943, 0.06450633458312481, 0.12267899894786459, 0.017928119838958787, 0.06768831142014073, 0.2828158209881475, 20.486692382443337, 53.45418622416835, 33.68500517260644, 18.31931221869684, 4.530328233395854, 8.03464287711728, 3.2149189854821856, 15.478696438574023, 51.12669098761774, 49.957216708890854, 37.05248548138527, 34.10611475667646, 8.452278221807173, 0.8939852613595225, 0.09333053829088327, 0.03187799488284415, 0.07801077163387692, 0.19230147553307397, 0.6710640329026407, 0.9169742116524328, 19.644110395062356, 79.79009351422711, 97.20651534295853, 78.54551761381089, 70.58990755388814, 70.67418359941053, 88.59570472471177, 92.38709911223381, 85.74778941369827, 65.09320389839911, 77.0785197904033, 60.56170140543292, 47.130992104930264, 12.343594008876432, 0.3178575406632116, 0.08269116282463074, 0.2268299622641456, 0.23980744573618137, 0.08757924811253626, 0.1098026160991961, 0.12225280891382888, 0.11011808344553556, 0.10741067509497366, 0.1363686913804662, 0.1818939872206219, 0.30189171673790105, 0.29650755887550695, 0.22228229580627334, 0.12855974266365652, 0.24877095024191567, 0.24996866742449425, 0.1018363282444977, 0.11835705263600235, 0.13697273638700286, 0.14261629162055833, 0.09614706054450044, 0.11187613265769136, 0.2051788159916478, 0.13009276120893418, 0.1339260353556564, 0.15282819768594158, 0.20363196189845764, 0.11958337554167356, 0.1456969609904674, 0.29242332964654894, 7.7343452361322225, 36.982608456765455, 60.7529208737035, 58.76682089221094, 62.737295012320246, 67.99664035920175, 67.68722811052876, 64.51043382767709, 66.67830036532494, 64.04336190992787, 66.99020724142751, 64.23120029510991, 65.60515557565998, 65.11808741477229, 66.32496541546237, 54.98991181773525, 55.06681380733367, 53.58635440949471, 51.43892342044462, 52.81352196970294, 52.47902224140783, 51.54175227688205, 48.63868844124579, 48.60806649731052, 51.441261153067316, 53.3262816552193, 51.24496221542359, 50.5023673272902, 48.12870187144126, 47.6904829086796, 53.508789539337165, 53.27325905522993, 58.059868581833385, 55.791612901995265, 57.3000584110137, 53.45424505972093, 54.838539708045225, 55.993913066002634, 54.49687380944529, 55.716287705206106, 55.24900005709741, 53.50755791510306, 53.56149442734257, 55.74159483755789, 52.73158757917343, 51.950149459223596, 51.25854930570049, 54.66353139569683, 54.02415367864794, 49.190511011308246, 49.32132990129533, 44.610198543917754, 46.34916959270355, 49.76325158149966, 48.49456487163421, 43.07700680148217, 47.500777475295536, 45.210831088404504, 47.321717354559134, 50.88223318899832, 49.99163550715293, 49.11584085033786, 48.8685118767523, 46.84435313747775, 53.10763305233371, 48.274629731332105, 55.59866366847869, 59.12985586350965, 57.7198383115953, 62.156364533209036, 56.92679782067576, 58.317191754618, 59.199160222084295, 61.43576237463183, 58.395894112125525, 58.10746262150427, 55.76101449228103, 43.20010646697014, 19.93378919939841, 4.826647120137369, 0.3282217603297003, 0.1467823083963125, 0.2102286684056444, 0.22024911377699147, 0.14715298769935486, 0.136402981475957, 0.1235839403084209, 0.11011842052422224, 0.14437640927010967, 0.3020902867278745, 0.1155143838015295, 0.11436282341638881, 0.14642932572432105, 0.12696120061821517, 0.14981120554429872, 0.22452310298479375, 0.1842402847063157, 0.15208768177657359, 0.13897803281584095, 0.10201589159306981, 0.15982798901536774, 0.15121719138997217, 0.12968714829654465, 0.1824511476461926, 0.1655241285240458, 0.269966350808259, 0.2198006305843592, 0.21693267318750584, 0.1144305455888952, 0.2441973134034103, 0.5452420586539853, 27.604745011175833, 63.99499516333304, 43.04680455115534, 34.743448918865575, 4.789212999805327, 9.29950527606472, 8.276692340450904, 46.17942902349657, 87.46734865250127, 89.44329753998788, 75.61715449056318, 67.36142035453551, 40.37953792079803, 2.3683641274129195, 0.37239356266875423, 0.29613759969511344, 0.2658336435354525], [0.16226393410996084, 0.09199329351465549, 0.03660133296263315, 0.2656622849885495, 8.769313596910047, 7.984600297866329, 26.866817743547504, 41.82210330040225, 51.96661164683681, 58.543724321549945, 60.20781732374623, 54.19625159232847, 37.62666556142992, 79.03550794047695, 60.23739199484549, 16.7221878036376, 11.808091440508443, 0.07990853230078375, 0.032412793201905106, 0.03441676812907381, 0.04750918011151014, 0.03604458239410193, 0.02345159270560309, 0.04043492120540431, 0.03541946613920793, 0.05639423338335849, 0.08766691155371167, 0.0631702849040589, 0.07959609866262445, 0.09351228499003957, 0.04291728356732957, 0.0416871378829162, 0.04088167686976733, 0.08399391066162817, 0.05192892137734641, 0.05240757694287647, 0.06266975752829064, 0.08372909704884214, 0.021953894644074386, 0.007653338064800107, 0.07564234186805065, 0.0654357371311034, 0.021212300465952967, 0.012867951093451872, 0.02640778619435526, 0.06336706607872922, 0.06710501207459359, 0.19814494907134966, 0.4140087457433824, 0.21124493000247788, 23.142107571324996, 53.74780701052759, 59.308500213007775, 61.75284677936185, 60.56473339757612, 60.958511906285445, 59.944520381189164, 60.89790736475299, 60.09825768009309, 63.148022082544145, 58.98947423504245, 63.83307187787948, 60.46026499040666, 55.46549135638822, 52.723515341358805, 45.69152147539201, 46.0007336831862, 47.83195103368452, 46.71280076426845, 46.58697505151072, 43.89881395524548, 43.661922408688454, 45.05267327831638, 45.84956161437496, 42.535857000658595, 42.687739018471014, 41.45528324188725, 42.884006577153365, 45.47298269887125, 50.24553837314729, 46.56479797055645, 49.777113237688624, 46.561860115297385, 45.503153570236705, 47.49567447170135, 48.05318840088383, 49.48739520965084, 50.6911470813136, 49.31416373099051, 50.54314036523142, 49.130396766047326, 47.42863724308629, 45.814723122504454, 44.62066734990766, 48.32578136074928, 47.643940064214895, 47.05681224023142, 44.54770341996224, 41.20660105059224, 37.41020956347066, 39.50201349873697, 41.205149773628484, 41.0193863222676, 40.323063635057025, 42.82768526384908, 40.78383230393933, 40.209075635479344, 43.15285759587442, 41.4863052675801, 43.10741693742814, 43.874695301055915, 44.630626247775176, 46.55213263727004, 48.510015087742964, 48.84247910591864, 55.6060024230711, 53.97546922006915, 54.25007827820317, 52.154034260780584, 53.93688878705425, 52.18042396729993, 54.70270802897792, 52.95737097340246, 47.81103695592573, 37.36240371581047, 11.06668895290744, 0.8204038032600958, 0.4397333653703813, 0.08467631114106025, 0.1380505914529485, 0.03053042515661688, 0.07906263333655174, 0.02972048635955059, 0.05036212984592684, 0.060708472850702466, 0.022958153558354226, 0.0433341158373702, 0.03218761697832135, 0.07277254586017902, 0.018467459144190918, 0.04855886995491963, 0.05684315324610761, 0.012644732224514649, 0.04562308313325048, 0.09855687437999634, 0.08609548135991059, 0.043019671218409654, 0.07916362670760962, 0.0432955471408223, 0.0973202016264681, 0.07311628951180367, 0.07346171855686173, 0.05297743527579212, 0.045381746284904025, 0.021767486299898837, 0.04625157783589056, 0.1152955201424418, 0.2405278135331408, 0.5250196050732366, 20.89355984041768, 39.3827538336477, 24.48620773130848, 5.947117757412696, 4.136662492828985, 1.6359405580066866, 4.616687057479735, 18.459538913542225, 14.296839237213137, 15.284005672700944, 17.49773060121844, 8.037392948904346, 0.21283024170946693, 0.08223383897735227, 0.046600718576941765, 0.05115917538322749, 0.09138488946782966, 0.10086099106457927, 0.0096338841080245, 0.04688247039373364, 0.04335648943519881, 20.525100231170654, 21.773257255554203, 34.962093599380985, 57.24461178625784, 66.91471730509113, 65.93028868398359, 73.06086740186139, 66.12960000191966, 47.78018751452046, 84.65178505066903, 76.20325857593168, 27.687842384461437, 5.345900289473995, 0.09894584020179126, 0.07927445664761529, 0.0478754582394275, 0.0407462248638753, 0.021844158294580637, 0.06423248113283227, 0.02040119146958234, 0.03826542532131557, 0.03125595447096614, 0.03599898101040914, 0.009847288433041786, 0.021556005813181404, 0.05185821912281456, 0.06966476463862965, 0.03278673603950489, 0.06683839049430625, 0.01251814864395607, 0.08360108375669488, 0.05493199753184473, 0.035126724791142254, 0.06602711104337247, 0.03264470716878291, 0.038796668992407864, 0.056206813803122896, 0.026506695806259112, 0.06544040260656227, 0.013556117342124063, 0.1317893395260457, 0.033855325272006374, 0.007285169614929587, 0.2878564956688112, 0.31078768293223075, 2.0308827849165088, 17.97205694260136, 51.21918439865113, 61.632810484978464, 64.00968051725819, 62.70032667344617, 61.395762043614546, 60.90446949005128, 62.22479420323526, 60.830003292329856, 62.84204190777194, 63.00609896259924, 65.91281060249575, 60.38162146845172, 58.88633158899123, 54.74446950420257, 49.719317113199544, 48.57345550291, 50.03639367318923, 50.657857925661155, 50.193045293131185, 48.0551064398981, 46.4259696006775, 47.88969616736136, 46.96537394677439, 48.74450222138436, 43.94336423566265, 46.07924384455527, 45.639848170741914, 48.155534805790076, 52.30534361254785, 49.98307297306676, 51.587934263290904, 48.662104991174516, 48.73360979941584, 48.24187009565292, 49.96242561647969, 51.56718884744952, 51.85843659985451, 51.437589814586026, 51.481037908984774, 51.81489044620145, 47.900094370688166, 48.489069631022794, 46.46046292397284, 49.29180229863813, 49.123869942080596, 46.901902152645974, 48.063139454011, 43.70250325049124, 40.252484506176366, 43.06725971160397, 43.29971113512593, 44.35915116340884, 43.28876772234517, 43.75363919042772, 44.02631452006679, 43.48286621032223, 45.320457412350564, 43.958865442583644, 46.28407001495362, 45.69590276287448, 49.0058615130763, 51.50865923973822, 54.85435862695017, 52.24230327913838, 55.73998666578724, 57.79485364114085, 57.07551448575912, 53.76978405060307, 55.19126276816092, 56.75789271631549, 58.90528448166386, 57.732421275108095, 52.569887868819706, 31.654476504172052, 6.539288278548948, 0.7926938514555655, 0.34461043414569675, 0.04547434716275142, 0.08102870606366666, 0.08837296882824552, 0.07924889229358205, 0.08077994965377354, 0.030504906767859098, 0.07629061313045603, 0.06995927948024004, 0.09064562228177825, 0.031107072943761468, 0.10428535812083753, 0.06764525727879617, 0.025692470747256474, 0.03803175701309116, 0.03470073010952723, 0.0601599270838403, 0.04863896444740315, 0.018208140297041788, 0.06381309012912455, 0.06884348774028402, 0.0449837597778007, 0.1034289867346806, 0.07547678260673439, 0.021746522303850904, 0.03528689462391119, 0.049505999777466066, 0.05333070523075519, 0.040438816762499274, 0.10720805249988072, 0.365423143150345, 1.6881308800751165, 37.73002786021079, 51.993648544434585, 34.87414229300715, 10.218105739162816, 5.542126663269536, 4.672437665923949, 4.600075329503706, 17.827429348422637, 12.086385565419352, 3.625269017873272, 7.8464063713627485, 2.0575846875867536, 0.09999884337547327, 0.0458797340792033, 0.02407288235131531, 0.03952547524785323, 0.09695270158831151, 0.2136144093087604, 0.14544436648007364, 0.11302597700588166, 0.4438428448573236, 42.20457361590478, 56.222983406436065, 73.66807383875694, 79.79103488306846, 83.15631866455078, 77.87964036387783, 81.514908729061, 76.4245665457941, 56.62919190622146, 98.03414329405754, 86.56972992804744, 49.137990474700935, 20.899855244544245, 0.1587835353829207, 0.26675705527586324, 0.10568011311754104, 0.1907624968237454, 0.16605571693470403, 0.10627380061534145, 0.13367842041677044, 0.11407534892280256, 0.175032336865702, 0.09125971836188147, 0.11541636285161781, 0.1410498256765066, 0.22172024773974575, 0.10611419385719685, 0.1370430785802103, 0.3229221785741468, 0.21501443499038297, 0.27092567675056, 0.1282269234258321, 0.16201838760847048, 0.16013754982381098, 0.1215709983220985, 0.20429868821895894, 0.22090681558174474, 0.12593959172767016, 0.1391870828886186, 0.11537366111071841, 0.18821787449621386, 0.2269259990463334, 0.11223480736296024, 0.28203916105051197, 0.7459825289345557, 5.901731521852556, 36.745226613936886, 57.485127602854085, 63.97648942086005, 65.45209684679585, 62.40978887004238, 65.84220793939406, 62.062608118980165, 64.42630683222126, 63.38416445639826, 67.42652385465561, 67.18326630130892, 68.83343881176364, 64.18213144425424, 60.40438298256167, 59.27199863618421, 51.40162168010589, 52.74154647704094, 52.14872337156727, 54.64239766520839, 53.486184920034106, 49.16732195884951, 48.414379858201556, 51.589969973410334, 50.28472285116873, 50.56796504605202, 46.63798155323152, 47.054239165398386, 48.46795943475539, 51.88728563247189, 55.1776207647016, 54.005589100622366, 53.22099739505399, 51.94210860037035, 51.47451500738821, 51.62498889430877, 54.32256367898757, 55.49052000045777, 55.50420514998898, 53.93335865389917, 55.679566475652884, 54.67631832245858, 53.128515751131125, 50.44751690280054, 48.44270721558602, 51.62434562560051, 51.616673469543464, 50.978370481921786, 49.16413307189942, 45.44180770074168, 42.63757582633726, 47.274543008496686, 46.428809396682254, 46.56888115790583, 45.90867173287177, 46.0558900525493, 45.4005600560096, 45.50393412190099, 48.4890539415421, 47.50197772056826, 49.08374017284763, 49.874325260039306, 51.400276307136785, 52.84279461829893, 54.90327058299896, 51.73802768030475, 60.02965934814946, 60.377208802007864, 57.253625392913825, 56.20268121842415, 55.313840758415964, 56.39492834767988, 56.46821391197943, 61.250842232857984, 51.59160560177219, 45.04116112186063, 20.281623025094312, 3.133432970892999, 0.691771328208908, 0.15656448510144988, 0.16821824524912143, 0.10813688814279535, 0.20178034270723022, 0.13487082094915454, 0.1270348752938932, 0.26621307156259016, 0.20914857636295983, 0.2877058521393807, 0.12293302604267675, 0.17030689204412122, 0.25451775880590566, 0.16149746314171823, 0.1488863075933149, 0.21628385800267422, 0.16857102873825258, 0.1873908825819531, 0.11339238919918576, 0.13182261838547646, 0.20804668145795024, 0.14453797721334044, 0.24635634835689302, 0.13859652102954928, 0.1519019667419695, 0.10684488085849632, 0.14639570978620361, 0.20943196760790966, 0.22437275056877445, 0.2581145722539194, 0.47970519791687694, 1.3063153552432216, 44.16515073468609, 58.484288646328835, 49.02446923717376, 24.03811420163801, 5.269403284595859, 4.944346662490599, 10.107453715416694, 39.66786699910318, 52.23772979551747, 44.27213338113601, 44.230034582076534, 16.390257227805353, 0.2371257243137206, 0.1885998459352601, 0.2025561139828736, 0.1484784270606695, 0.15384344804671504], [0.03590618094970142, 0.0447159469307911, 0.10173407082836475, 0.06726328583974993, 1.2230477265773283, 6.735101822883853, 3.6844377267745236, 21.448526190173244, 46.042102921393614, 56.66045711886499, 43.77118395220849, 37.55556083494617, 34.807520835630356, 39.34723284936721, 26.415103866207986, 19.616122322697795, 7.183158090037685, 0.7133031179828029, 0.06942101844376133, 0.042279097852447343, 0.057965571646608656, 0.051353466772143884, 0.05749225188347121, 0.006329628146974551, 0.043333322936368567, 0.023815239321500547, 0.08083359113023167, 0.08153645381812127, 0.03733501153727693, 0.05172894178559223, 0.024639241577636813, 0.024257699147828167, 0.11828497908408604, 0.09216602335894301, 0.08890769053851405, 0.04888781278784718, 0.2747869743935524, 0.04255642168103688, 0.018589309258987347, 0.055401904373279506, 0.03581335790635597, 0.023461314361362208, 0.052238087650508656, 0.06883725178458037, 0.054851470199683984, 0.05826354920563679, 0.035326026395083435, 0.042657028177693006, 0.1038752559332117, 0.5197125156560253, 3.101953743926941, 27.36479009351423, 57.04408845593853, 59.50643085664319, 63.10219703182098, 56.379423218388716, 59.30429543218305, 61.75583170306299, 58.88565301895142, 59.71372419787992, 61.12247090185843, 62.045028055867846, 55.76825126524895, 56.44714293941375, 56.59593412953039, 50.54783936469786, 46.18624610285605, 42.63832499904018, 44.31482445809149, 45.31184780982233, 45.21889155910861, 43.208684690537, 43.18205179706697, 41.89225881330429, 42.370984092835464, 43.65597217313705, 42.90752510870657, 44.94216834345172, 50.989051095901004, 49.42524525427049, 47.52290748780774, 44.39869257711595, 42.10551807957311, 41.687577770602324, 41.396141744429066, 42.91943734691989, 47.50125992682673, 49.57058083626532, 47.42395393310055, 45.282571238856164, 42.2423578077747, 41.965481619681086, 42.614657417420425, 43.382355474656634, 43.08590273703299, 42.50025364660448, 43.46103429794312, 48.604144127138206, 44.284280961559666, 40.19626125212639, 38.25255032508604, 39.407178432710715, 38.647717352836366, 39.45611392298053, 41.574370322688935, 41.242710390398585, 42.0363078578826, 42.01011426987187, 42.425304997351866, 41.124297957266535, 43.30944253552345, 43.33526742073798, 52.929612359692975, 55.074780141153646, 52.73856155333981, 54.62855562087029, 52.44772564980292, 52.56152145324215, 51.39527528516708, 51.9515379782646, 53.983149220866544, 55.043193294155984, 50.41376490746775, 40.929152196453465, 16.27821472383315, 1.5417202009308724, 0.3737422757812085, 0.12543741343242507, 0.09160642677377309, 0.2381945855074352, 0.03341194805538943, 0.007040625731010111, 0.06115718586971203, 0.0930951577761481, 0.032055870922763026, 0.08806176093076507, 0.08143142316370242, 0.014922203413481194, 0.028852654298046426, 0.05816399224943692, 0.17156862353365268, 0.07349056942809014, 0.2512277176062907, 0.1875418631900703, 0.06663124798046005, 0.04243999163830473, 0.042222043454286554, 0.06798278029647566, 0.05381730895849967, 0.05692853374526866, 0.028891244062012243, 0.04659543640070385, 0.01462492012163444, 0.04995582745440545, 0.06514424067591468, 0.05324820522218943, 0.04175948339604563, 0.5510797712110704, 3.558846865930865, 37.194565496137066, 43.25178761636057, 26.299509656044748, 8.993126980720028, 3.363618980492315, 2.7115166043081596, 6.19174765002343, 6.337734835763132, 8.508104335877205, 2.381445722233865, 0.48380879384856074, 0.28057489123555923, 0.07888582790450704, 0.06237774396375303, 0.03549112983408474, 0.07174367445611185, 0.09165363311166726, 0.05038063469973784, 0.030398317124514334, 0.11889908282506852, 0.06637333681987179, 1.3539331742832739, 14.272126343942459, 8.251220468551882, 30.36071800416516, 60.25968282453476, 69.1554497134301, 53.47550038368472, 52.3526160178646, 44.64741006974251, 55.761230222640506, 39.674782137716974, 29.454717174653087, 18.886855648409938, 1.5348956445532462, 0.15605811630525898, 0.052481431649216724, 0.0914581121516324, 0.06077024635047682, 0.12155425930095297, 0.028959988961897554, 0.02354369945673933, 0.026611567497433677, 0.01695826018769895, 0.04756982746203581, 0.023262263651216225, 0.0926147057344356, 0.014226043037319136, 0.04552860533998859, 0.1104836606030022, 0.07530610587808394, 0.05366757707369905, 0.1022272552513788, 0.25845045584344095, 0.038520839035270676, 0.017236622065425884, 0.02716570379092328, 0.042841245510405114, 0.05230751436864657, 0.01325703374365525, 0.024575401555686712, 0.06598122237670807, 0.03593442278103002, 0.022833164398288055, 0.053708693012595184, 0.288193175989774, 0.4344839164085927, 2.3014967864559543, 20.56494366738104, 53.84706651010821, 62.751184125100416, 62.9079455714072, 61.64033751333914, 59.303259926457564, 62.93372338817966, 62.31605991240471, 61.15125717655305, 62.4363080147774, 62.91595897366924, 59.00705429815478, 59.73257903129824, 62.10212599846625, 55.773464095207956, 47.469904499669234, 48.976557485518924, 46.22406167368735, 48.49947960146012, 47.22170475990542, 46.907334635334635, 44.67545501647457, 44.20237402762137, 44.531217698127996, 46.09642774828019, 45.035595278586115, 47.93505053366385, 54.25323578619189, 53.00740472732052, 50.74829209235407, 46.86832274160078, 44.26974465770107, 44.536909057248025, 43.31720098372429, 44.51818366204539, 49.46132713748563, 50.033820598356186, 49.77261820147115, 49.1235286958756, 45.596882527874364, 44.503749339811264, 44.548405524223085, 44.84250876211351, 44.34960803677959, 46.23689959126134, 47.981875788780954, 50.39884028896209, 49.20392943966774, 43.68360527100102, 41.25579149492326, 42.73396807332193, 42.804194188887074, 41.034350164474986, 43.702801350624334, 43.05909333690521, 41.928791769089244, 44.13870219261416, 44.393103199620406, 46.90600495184622, 47.51578054120464, 47.90564844685216, 55.98270685442033, 56.29181315821987, 54.18896382854831, 60.49722156217022, 54.30815289097448, 56.75136196997858, 54.981357128389426, 56.057879078772764, 58.67620237411992, 58.41165811784806, 55.799367427825935, 32.19479868488927, 8.0746304604315, 0.7826152600107655, 0.8925863235227524, 0.049199430542367126, 0.036860596268407764, 0.10989452366747203, 0.1319351107362778, 0.06690553810086942, 0.05822170165277297, 0.03216044767008674, 0.061909905559713804, 0.03285776771184418, 0.002549138176442695, 0.03936607150300857, 0.045778464916492664, 0.051614790854434815, 0.03190551659152393, 0.06743147278264647, 0.1660164472677054, 0.06284907572872697, 0.16687667207612147, 0.08098497010406949, 0.04198567085568944, 0.11522322442502746, 0.038044987351543484, 0.13774777221823895, 0.060765565553259474, 0.07226618472486734, 0.05197655289403854, 0.019691114148665822, 0.10263474507918281, 0.11276824204551597, 0.13545317034567558, 0.6248428840791026, 7.95121749562602, 52.061736968255815, 51.869580053514056, 33.041289314146965, 11.780926085287525, 6.3191344661097375, 3.7101775455859403, 4.42382215492187, 10.026481286171945, 11.135111758785865, 5.97911645327845, 0.3056364464423349, 0.11960893223482756, 0.02327194891779894, 0.016752061877219428, 0.04481154704286207, 0.04426911465763565, 0.03460548622834106, 0.1273222501960493, 0.16243420481201143, 0.33357113780033204, 0.1832675522253398, 3.293769167315576, 24.944338606249904, 35.85376208828342, 62.229175490717736, 77.14422733552995, 81.35479757862707, 61.925203569473766, 56.08580635439966, 55.97552107226465, 56.45471703621649, 47.380368555745775, 44.301484477135446, 39.87919253687705, 3.4274322659738603, 0.24945019443909972, 0.15731034830452936, 0.17545527868693875, 0.15632339723167882, 0.2631656044433194, 0.17280870537844398, 0.1789864843651172, 0.11675419751554729, 0.2557160275717897, 0.10958645673048113, 0.10979782038879012, 0.184967148928873, 0.12384749753701112, 0.11390362265369586, 0.17091610048326755, 0.3449403422494089, 0.261264450006908, 0.3046966097768276, 0.5723529909887622, 0.2280786549372058, 0.17240508429465756, 0.10729382370388317, 0.1330410505855276, 0.09244300244796662, 0.126045442096168, 0.1051145870118372, 0.34018802306344437, 0.15775201331463554, 0.08916953939103311, 0.226977510798362, 0.3700665859205108, 0.7967183258264297, 6.069900691509248, 36.232168828287435, 57.46338982735911, 67.00253132850894, 66.60565806973365, 61.374083103672156, 60.57941090676093, 67.8022712276828, 62.34397542092108, 65.71086737417406, 66.42608411850469, 67.47263523840135, 61.78292743621334, 62.661632491696274, 61.635587523060465, 56.374912492690555, 51.54350557634908, 50.33522728950747, 49.506571677423295, 53.28678730995425, 50.403755018788004, 49.686671226255356, 48.55735417335264, 49.36219315375052, 46.265595651442005, 48.65301685948526, 50.04284597212269, 52.09849349914059, 59.146686753919056, 56.02736696120232, 52.29265866741058, 49.65116593145555, 46.43827015353788, 47.60273164318454, 48.00769282925514, 48.69458613857147, 52.64511500635455, 55.73103973942419, 52.23586666968561, 50.526003529948575, 47.84766797096499, 47.34265496653896, 46.416026392290675, 48.50223702769126, 46.291283253700506, 46.911508037197976, 48.69857126666654, 51.56266243227067, 51.874945855909786, 46.47253597936323, 42.744664376781834, 45.956775680665054, 45.61634140629923, 44.97656752986293, 46.90716205104705, 48.10629729301699, 44.675341267739576, 48.32423594690139, 47.372206103417184, 49.891858254709554, 50.099645814587994, 49.61552335369972, 55.68055491293631, 58.845523249718454, 55.80487051317769, 61.976637609543346, 56.68212036932669, 58.18387039246098, 55.742214572045114, 57.070944924508375, 58.31575224476477, 59.4450379187061, 55.27448761847712, 46.90813479884979, 27.08536240362352, 2.681628388743247, 2.6179021308499, 0.10115221172811524, 0.14757041368753682, 0.503942228012508, 0.37539144857756557, 0.2326237779831694, 0.2857022870692515, 0.159199551769322, 0.1474616138805305, 0.1662461204274047, 0.15971126785922438, 0.13068916065798653, 0.13760526454256428, 0.15364254914945172, 0.2791212853645125, 0.26528552294738833, 0.44496307990724043, 0.31921305663643346, 0.24718752311122036, 0.16713896525963662, 0.16298355114075447, 0.27679528920881213, 0.2684494967181837, 0.21858170808803654, 0.16107488904268513, 0.15556069541602366, 0.11977643735947148, 0.19023049472560807, 0.28954522924557813, 0.1647710487727196, 0.20948783073934818, 0.9644179142290547, 9.278635324970368, 66.39598384980233, 63.46686370911137, 47.795484758192494, 15.551769214291728, 4.262073905237259, 4.1929293832471295, 9.032016300386, 41.785456595882295, 36.06169085348807, 7.994221871899021, 0.6710689971523901, 0.7924677023003179, 0.15410060844113752, 0.21588737685834208, 0.29883533235519166, 0.22032757650219628, 0.13096714332219095], [0.024585764810082414, 0.03716928756705696, 0.031239782354884574, 0.0742707610310566, 0.19176719049292226, 0.4058874170145681, 0.7337386052935355, 4.681868024410741, 37.510375130561094, 60.218964699775945, 47.859486072294175, 26.86129700752997, 28.654989042589744, 10.874825235336058, 25.268383256850708, 23.787292357414003, 27.562387335684996, 9.636400591942573, 0.14841661908693854, 0.06719040023463388, 0.07032914673008266, 0.05819386967848386, 0.027024691901920785, 0.08294430125745074, 0.03525342424249938, 0.04437473903019582, 0.05586990748622245, 0.04432137717583007, 0.0803858970081614, 0.0220162695228693, 0.02111132433187337, 0.05861419913989883, 0.09175756826035439, 0.0771825922833335, 0.11508191950739392, 0.27474205099767257, 1.1109471224969434, 0.40994299455515804, 0.10684201568965951, 0.020139210466896335, 0.05022014694048032, 0.021896185240738338, 0.05862012866043276, 0.049203123086162155, 0.02756712811758682, 0.05704633508538527, 0.02547397864081206, 0.017165414192864013, 0.034349605200752135, 0.37874988610706023, 0.6888926762246317, 2.905630291469636, 27.89548089427333, 51.57726933879238, 58.043735873314645, 60.04061845041091, 63.000278165263516, 57.40449936159196, 59.76952775832146, 55.06692755606867, 59.61517072493031, 58.671464150951756, 58.5688941709457, 60.139218991802586, 63.589567215211936, 55.65014477699034, 47.17349490811748, 46.44674247311008, 43.3302350198069, 46.08324073976087, 43.143942048472745, 43.0326134158719, 42.86165691191151, 42.91298504798643, 42.28210318473078, 41.195183031020626, 42.88572457528884, 46.2098862278846, 50.72540114002843, 49.48430830432523, 49.7614316017397, 45.34248152086812, 44.195086263841205, 42.295694197377856, 42.21055915278774, 44.73890719875213, 46.139338477965325, 45.81888475725728, 45.54063966197353, 50.21292778753465, 44.87037327981765, 42.84038982083721, 40.509544880159446, 41.932965170952585, 41.05284806220762, 47.43693305600075, 49.85212464486399, 46.81722210299584, 47.42615830513739, 40.766362067191835, 39.51771082416658, 37.645547851439446, 38.080872105013945, 39.31337887240995, 40.91884028527045, 42.54886358014999, 41.35341536614203, 40.87105012709095, 41.90534384019914, 41.05542113704067, 46.03387771114227, 51.04749833383868, 57.44764935585761, 53.797946668440304, 53.06580881918631, 53.97965831141318, 53.157243190273164, 53.76940750306653, 50.79238345546108, 50.42427685952956, 52.7733176754367, 48.86562501230548, 39.77033499748477, 16.13443632279673, 1.6863376214619608, 0.029309970484445655, 0.39080283935031584, 0.629122618946337, 0.033528309150208394, 0.023109498058235454, 0.05397315805537566, 0.05852964218525637, 0.07458866453699528, 0.027903027028866836, 0.020496757107696707, 0.10726334872625529, 0.039995700015776584, 0.011024039704352619, 0.04055803919571542, 0.01907422567807859, 0.036222594414627364, 0.012510539475648154, 0.2414430281327617, 0.03531996280916276, 0.21134476658077012, 0.19409513251195032, 0.03904996447325234, 0.005029544380733804, 0.007662223248306903, 0.024694769545608473, 0.021768436248924945, 0.061998116753755085, 0.025780890700257113, 0.09912131264084771, 0.01765402698618991, 0.07825290138322501, 0.13753835442325762, 0.4871418891895202, 11.06455812531133, 34.11135504322667, 42.12878165706512, 27.56805123821382, 5.252284590275058, 5.677164062376946, 3.311429148720157, 3.8422719413234345, 5.302028088800369, 7.328495633217597, 4.196285951522089, 0.1940009190190223, 0.17669493152249247, 0.020828228030774384, 0.031764249978286606, 0.06730219544542414, 0.034470762005977096, 0.05803756858973254, 0.05761237446999839, 0.021541697205975655, 0.040852167162924044, 0.017255862363644184, 0.12119510196029179, 1.4362593115337434, 2.7503742998646152, 6.664720283400628, 53.11645446285125, 69.98975353856241, 51.40499491845408, 33.910117841536, 36.55814132382793, 20.027359301044097, 31.63863208986098, 33.88046864540347, 50.12532164973598, 22.649636345524943, 0.1952602756359885, 0.10565691597519383, 0.031174038604442632, 0.05078037937862739, 0.04404160569632246, 0.05953065480195707, 0.036895346016653126, 0.030184898435348467, 0.03519163159052691, 0.059354810810257355, 0.004918509512208402, 0.057084589685884216, 0.04834585920757344, 0.03383244605614774, 0.06571567331951472, 0.22468076387961067, 0.3115986329653571, 0.19732927993660976, 0.8834265472908175, 0.39219264541902854, 0.15227191060060455, 0.0190147542725167, 0.020354795269668102, 0.07618419585689422, 0.002894601216652401, 0.035431030236424944, 0.055005890542581204, 0.04184965960561268, 0.055970169243312655, 0.0445136001273509, 0.07488815128923425, 0.17387039598918733, 1.28024434130038, 3.2470414811565034, 18.950868729622133, 46.82638868208855, 59.7571958264997, 61.22266784791024, 65.23889249370944, 60.53140109585178, 61.42729005505962, 55.81988142382715, 62.08244354494157, 58.7513392971408, 61.60057644690237, 60.77746314387168, 65.84431817454677, 57.9235662183454, 48.30706381028699, 49.61935550935807, 47.6296861710087, 47.83410833727929, 47.10285302131407, 46.4283779359633, 44.59619176003241, 44.73050548184303, 45.359300644167014, 44.96907188046364, 43.64092988352622, 47.970430312618134, 51.997398330319314, 51.654614556220274, 50.56822784485356, 47.72264634409259, 46.427475790823664, 45.12475467497303, 45.027911355418546, 46.11958542177754, 48.955549270876, 48.95141509271438, 49.08537580120949, 52.544168887599824, 47.177287840074115, 46.13738905998969, 43.91064774605536, 44.83653891471125, 46.28995357021209, 50.09233843895697, 51.822515533816436, 48.40467591439524, 49.84588415391984, 44.587272290260564, 41.73235162611931, 42.74214621513121, 40.71672447266118, 42.934369810165904, 42.98298366608159, 43.96564722061158, 44.386956845560384, 44.11882754295103, 46.525134963373986, 45.31963371461438, 49.16433311277821, 54.63868710302538, 59.55305214851134, 56.449810151130926, 56.655526699558386, 57.261736854430175, 58.18318005531066, 55.76737657670052, 53.7495759994753, 52.70849266359883, 58.837443167163485, 51.17575591610324, 29.437131227985507, 5.6561936005469295, 0.5799294166987943, 0.05409863559649356, 0.7157147627684378, 0.8611506716378274, 0.060111399244276754, 0.0926862047204087, 0.09410797197732235, 0.01915671228010568, 0.03254090991592215, 0.03218118567019701, 0.027590470816639644, 0.0777718747755693, 0.04987019414622938, 0.043169050702765104, 0.0459620617179861, 0.03885649662885455, 0.035198825156135906, 0.16421958804130554, 0.2129308596974419, 0.10560641545922526, 0.24014314546460108, 0.3566519267136051, 0.032364721184656504, 0.013502214438161783, 0.06944168749595843, 0.024418573781487443, 0.05349884620837627, 0.07797032985235415, 0.059345610094286745, 0.010880467166463214, 0.07305366182399374, 0.07419123344363705, 0.14656967303204924, 0.4305043960771253, 20.96402914293351, 49.82481318135416, 53.29507920049852, 33.97801014684862, 8.550978783638246, 3.949274935068623, 3.425278884749259, 9.889472896052945, 3.8289309797748445, 10.474131588012943, 10.797972275364785, 0.5534819165064443, 0.29386394266639987, 0.022966228125076142, 0.021486847225816983, 0.10019340672560277, 0.12051229545425986, 0.04373874815721666, 0.14355477997131888, 0.1343435073091138, 0.3003058534476065, 0.14341795666804238, 0.26143476667423404, 3.7192570970904444, 8.628921181924882, 32.957354514829575, 80.98762450679656, 80.53237853511688, 69.53780235782747, 41.00376744424143, 51.38325714295911, 18.879359999010642, 43.152963499869074, 44.00224685668946, 66.66979666679137, 25.0099814322687, 0.253377590148199, 0.31527695816851437, 0.1457095095106671, 0.26138395972309575, 0.07139287513470458, 0.11704685076350167, 0.2059607312924439, 0.14028102580097415, 0.12528580463220998, 0.10999650529195225, 0.22902521785468827, 0.10031639448096676, 0.1736507585812961, 0.13148887984214291, 0.28248367590769646, 0.4994096534867441, 0.820668685820795, 1.7931476836242985, 2.103258236762016, 0.612340696877049, 0.4615734902120406, 0.15190158369800738, 0.10316501581861127, 0.1537527738799972, 0.1875447283589071, 0.12617887929081917, 0.11976298485552112, 0.12235155764726863, 0.15933839754471857, 0.10678189310936198, 0.16608458312769092, 0.802312912719865, 1.8934407277453331, 6.4870800606666075, 36.24280629619476, 53.62889251401348, 62.27769520974929, 65.04224446512038, 65.55662801188808, 61.957335625925374, 66.4652293728244, 57.60645043465399, 65.29983043670654, 61.45841014000678, 66.17185177341585, 64.30139503171368, 68.76567594466671, 58.56866275110553, 52.851466978749926, 52.31564767899052, 51.502536419899236, 50.75786267557452, 49.681019090837054, 48.92266019698113, 47.77166812650619, 46.937838908164736, 49.75301811772008, 46.309161416945926, 47.74578048336891, 50.737427126976755, 58.0308351978179, 55.62302943198912, 53.73787556925128, 49.26567146855016, 48.12938044148107, 45.91822270424136, 47.3872366259175, 49.99928020661878, 51.25636454551451, 51.46746258581839, 51.749739877639286, 55.244591313023726, 49.358600262672674, 47.069159861533876, 43.14307128229449, 46.981698851431574, 47.97157956707863, 53.956528094507036, 53.959183539113695, 51.15290026510916, 53.42205024534657, 47.865275490668516, 45.727846545557824, 43.76019739335583, 42.19749373774375, 46.33165228751398, 46.3938767679276, 48.97686343039236, 47.03973816287133, 47.16895672582811, 49.27822305310158, 48.27401784158523, 49.80222032916162, 57.02058169149584, 61.71469780706591, 56.93979655542682, 56.24887104957335, 57.61407944463915, 58.73978399461316, 56.38354955180999, 54.209815148384344, 52.79469067050565, 59.51218105131581, 52.10022326438658, 49.10238319827665, 27.509276482366747, 3.3755422503717485, 0.3107465899759724, 1.562650826188826, 1.2075619639888888, 0.1528766297645146, 0.17481158096944133, 0.26561484882427805, 0.09558895783078286, 0.3100132599713341, 0.1774179499836699, 0.07766240847206886, 0.239720004460504, 0.1589751033292663, 0.20490052689227367, 0.14803493876130353, 0.1685526119845529, 0.12161494878631447, 0.2578473607859304, 0.4758414794360438, 0.25483429101445987, 0.5677093950010116, 0.4166296244628968, 0.10560455386556926, 0.10161775569882124, 0.17882545268343342, 0.13767523901356807, 0.10638571073932034, 0.15692641568039695, 0.1714707481404466, 0.16374738676653755, 0.18525790993965444, 0.15844054249746187, 0.36573598281510417, 0.6341301373416378, 28.970151485935336, 65.62683843797254, 61.58813468871578, 50.43689120200373, 8.27437323908652, 3.2657185821763934, 2.130491743164678, 13.850800048920417, 29.690075074472738, 17.01059379885274, 18.64503956610157, 0.6746226645285084, 0.49706101177200196, 0.0972911898767756, 0.18578048915632311, 0.19183577068390387, 0.18377281785491975, 0.1939299026684415], [0.07310598562922209, 0.1001255083528738, 0.14313798217523482, 0.0470332479885509, 0.03675225611415602, 0.2032815839254087, 0.3393341721065583, 3.561991381068384, 15.191102373984554, 54.92738139244818, 57.79475950425672, 39.22111688121673, 20.856195342156198, 13.983787029020249, 27.94974296323715, 29.311621266026652, 45.08109477258498, 38.7270276777206, 0.4501077280409875, 0.049373585310193806, 0.037409061596037886, 0.093821125675834, 0.06442359708730253, 0.046989071528397264, 0.10577418105376345, 0.0802281671654313, 0.03613916743967322, 0.04619779846360607, 0.020856801195130236, 0.020827896697747133, 0.026313948084510146, 0.05396945785070139, 0.10858492700443154, 0.036720858000579386, 1.568424677656543, 4.096114255728261, 5.710365454996786, 4.506080631286868, 1.3694291105193477, 0.04078672410199239, 0.04599208470373865, 0.0460468944642813, 0.03860566412068663, 0.02886588655171856, 0.04275830117084327, 0.011514114768003986, 0.058182857164572326, 0.13003968663754004, 0.37852434982215205, 0.10439054965372048, 0.9401321915849563, 2.4798339653399686, 3.2416526348360124, 23.28083984313473, 46.200197973558986, 51.94891783498949, 59.50519923240908, 61.41370296478272, 58.04718755906629, 58.55792330157373, 60.602199877462084, 59.34264444535779, 59.04110047125048, 60.21253985743369, 61.11821120785129, 55.20433995031542, 49.88157380011774, 46.90522440018193, 42.963646381132065, 43.88734102249146, 42.630280217816754, 40.78419708436535, 43.31381990063576, 40.42269575980402, 39.80226701305759, 42.81149371977776, 44.59904332314768, 48.19358179646154, 50.60905187360702, 47.02511556686894, 47.30649463592037, 48.61486788718931, 47.24859652980682, 47.131686364450765, 49.74716986379316, 48.22659246383175, 47.2599910151574, 45.83156578002438, 46.56040883833363, 47.13557343329153, 45.67217634570214, 48.31937220788772, 46.659005457355136, 45.336021377194314, 45.67377667273245, 48.11796634427963, 44.888208296991166, 46.257645007102724, 45.898300986136164, 47.15935868601645, 39.77983890041229, 39.15289117443947, 37.89516356683547, 37.691259153427616, 40.464978910261586, 39.42925745441068, 40.37506641880159, 40.60091257095337, 41.24697008440572, 42.25247752281928, 46.8344295409418, 53.29531062033869, 55.15914640118999, 53.20788098919777, 54.84232871763168, 52.418955064588985, 55.69559720254714, 51.19133557042768, 51.426340456931825, 45.92289032474641, 51.7481081716476, 35.88311318428286, 14.712909556204274, 1.4624058311024022, 0.1334884152897904, 0.027729025478625012, 0.09959198173976715, 0.8778664037104577, 0.08315358115660568, 0.07973639234419792, 0.01003317392220901, 0.025630526792918964, 0.011133221597711166, 0.06738680219578166, 0.0449286014472525, 0.08450120642420747, 0.035631496294011036, 0.056102644997618856, 0.06361043306007501, 0.08498910484054396, 0.08511245265723237, 0.4144379388420813, 3.0679139446827675, 2.957970399049021, 1.1057765805913558, 0.6440710168211692, 0.1637833316119448, 0.025574657915821, 0.06097874867038862, 0.02813257952971805, 0.06049551572951098, 0.04208382204054825, 0.038761214443272164, 0.07796056223131957, 0.03470039303084055, 0.10640419644093323, 0.05409350663784051, 0.2775176181908577, 18.395716067283384, 36.81832782683834, 45.23175301090364, 31.08486206300797, 8.018152252320322, 15.322719466301704, 3.7872251531770154, 3.5616528314928857, 3.6363276502778454, 13.642166237677298, 8.82066232542838, 0.5345376040185652, 0.04940792520139967, 0.04710569309311048, 0.07789838653538497, 0.13235838963620125, 0.04080018043638237, 0.03652848183147369, 0.05336807883014122, 0.12380691785966197, 0.189020014518211, 0.1444454797573628, 0.05685826816085366, 0.3512902918361849, 0.1339401620169801, 3.9218869853404263, 23.25600535638871, 71.23769483258648, 63.938987639642534, 41.67186083332185, 28.222304544141217, 12.387720673314988, 35.13197929628434, 35.91622583327755, 55.481424024028165, 51.53159333813576, 0.6779720009334627, 0.08678850747885243, 0.11837049747907347, 0.09946939235012378, 0.16507530825272684, 0.014745871040729747, 0.03593557957379568, 0.04989246049174859, 0.06338701500827748, 0.015230292375499924, 0.015423649137148695, 0.06638385520707216, 0.06091705560984631, 0.04382812763534246, 0.004893138116571091, 0.15561150236716195, 1.5626606321142567, 2.941006148053754, 4.240619520987234, 3.650787222769953, 0.9061656303463445, 0.06747680220512614, 0.09201167962483822, 0.07128412895385297, 0.07805221699058049, 0.03429582582846765, 0.06433469258368978, 0.052740442145976334, 0.03370779588998806, 0.12011091134721234, 0.2502004856303815, 0.17775870589238985, 2.5715463344127905, 3.2803068574397796, 3.7245395491200113, 19.810463997625536, 41.94571679638278, 55.18373181743007, 58.923123421207556, 65.22406985682827, 61.413004782892045, 61.2679555339198, 65.68931002770701, 60.5043367416628, 60.27794145768689, 61.7107597474129, 62.90553331375123, 58.36764127977433, 51.88479884978264, 49.96171174510833, 46.5346114097103, 46.27944946289063, 44.98551053385581, 44.37335798817296, 43.91213824672084, 44.68135818358391, 42.62577341448876, 44.7558989063386, 49.26070182554184, 52.065784854273645, 52.54602024632116, 48.88776286955803, 49.506199052256925, 50.33768661560551, 49.94570063006494, 53.071715908665816, 51.025117289635446, 51.569397141856534, 51.062289591758486, 48.74881290620374, 47.77443339747768, 48.94511968858781, 49.4084692770435, 51.3089164610832, 49.56331268433602, 48.9237545382592, 49.37164998823597, 49.211887928747366, 47.30421573885026, 48.16983184506817, 48.09411441126178, 50.562446271219564, 42.89367521962812, 43.34403784044328, 41.03360099177207, 39.24867937641759, 41.843201729559134, 43.49354682430145, 42.104510030438824, 44.24127217262022, 43.89148304539342, 48.24630237394764, 49.84602143687587, 55.90406333246539, 58.221336872346946, 54.76090423522457, 55.07316020227248, 58.67955600061725, 58.98164518417851, 54.20862274785196, 54.550649504507746, 50.179850439871515, 51.44094736345353, 29.434979807945993, 5.489465901928564, 0.6791294678564995, 0.07857341724898546, 0.008840798287682475, 0.14490007633163085, 0.5399739477903612, 0.4027062828742689, 0.117055285391548, 0.06260521845110963, 0.01920226578330321, 0.04339023943870299, 0.06688499162274023, 0.02431266021073586, 0.015756707777449443, 0.0732965040351114, 0.014554948523460377, 0.065056600217377, 0.05639300381224002, 0.09030347975391535, 0.8131349158863869, 3.0986030592072398, 2.2361331841638012, 1.5039731490035213, 0.8600884447655371, 0.09855639174460404, 0.06154837717692699, 0.0348550891653905, 0.015148312349112765, 0.0018821914859619294, 0.005494465905001327, 0.028831353223311807, 0.08820404644094168, 0.022149994000492078, 0.025182934177498666, 0.04018792296729742, 0.6410629266212065, 38.05935790461879, 53.471727063578946, 54.73283183190131, 39.45990293256698, 12.292002093407417, 11.346940340534335, 1.8418803138117639, 5.3682935910840195, 7.375732246906527, 19.838183387633293, 11.394046045118763, 0.6144084601152329, 0.5523098632693291, 0.09839637895985957, 0.04371934315009464, 0.14751891725726668, 0.07728738545049584, 0.014226771778457109, 0.19987025568562172, 0.25076984217570675, 0.3795909587173693, 0.2018791527277039, 0.10598413511029176, 0.39501561813296815, 0.687309141841627, 10.472944090443274, 54.01923502645185, 90.36692157868417, 78.79574914132395, 54.20380999965053, 34.49717506285637, 18.68196083653358, 45.772251698278616, 48.62604271981024, 67.79889014459425, 57.69667671572778, 0.4746827254852941, 0.2543040355967899, 0.13743326248180482, 0.2486089839329643, 0.23638038205042963, 0.18152718432247641, 0.29098967270505044, 0.16647040032811705, 0.1363531397956033, 0.14926539854176585, 0.1977486211446024, 0.16009933735814788, 0.15881503691836713, 0.12511411666749947, 0.3261712493915712, 0.6873972725964362, 3.3649609213875187, 5.420192432019019, 6.013499950208972, 5.535509134492567, 1.749026657592866, 0.27836711776833384, 0.16501492520253505, 0.18544728687453657, 0.14992711464724234, 0.1319425724326603, 0.2400171546445739, 0.4567464927752172, 0.20779350472073402, 0.5214810755945022, 1.0341652554850425, 0.1685794250619027, 2.56694098153422, 4.3774102195616695, 6.7809494272355115, 33.36189992966191, 49.08465408509778, 55.23693092407719, 64.27456601973503, 66.71517064494472, 60.845198554377404, 60.969031703087595, 66.96009128324448, 63.29091010555145, 63.18471977787634, 64.66759927811162, 66.64220671499929, 60.92026095236502, 50.9325611206793, 54.91959941002631, 49.35236761646886, 50.42513978096747, 48.957388862486816, 46.71021199995472, 48.58634833366641, 48.79725025546167, 42.68416573924404, 50.61168770636282, 52.280287511887096, 54.28103754597326, 56.75260928369338, 51.5987443154858, 51.32393129410283, 54.33326782718782, 52.89157321376186, 58.110035696337306, 54.822206958647705, 57.41002205879458, 53.53127648753505, 52.028557638968195, 52.24815545543548, 51.79094829866963, 50.838989057848536, 54.23073314851331, 51.65231996966947, 50.866661379414225, 53.35535034056633, 53.723017631038545, 51.73409354302191, 52.35771509908861, 50.141164102861964, 52.28757527566726, 44.52447514380179, 48.017514444166615, 42.11062892790764, 40.92762247208626, 46.48816662449991, 47.29958341967675, 46.58519429545249, 47.190906309312396, 48.465837432492165, 50.418926746614524, 50.077354984898726, 59.400028720978774, 57.995243610874304, 57.57157271908176, 59.20642445164343, 58.22877760856383, 60.448909728757805, 58.52484987628076, 55.66358673957087, 50.75142214375158, 55.338637982645345, 48.237120105374245, 29.193848179232692, 2.560945148429563, 0.6043578155579106, 0.10887097657447863, 0.1821731343384712, 3.271745549094293, 0.20750924013555053, 0.2888358318276944, 0.21235048680776553, 0.11855832691634856, 0.18259504960188944, 0.14264747139907655, 0.11276106380166546, 0.15060732411521097, 0.11013201092399898, 0.20246281979545472, 0.20648881102040892, 0.2701839504222716, 0.45288185498887495, 1.7844318093792086, 4.209301356346377, 3.572578348459736, 2.341769967348345, 1.5594575265722892, 0.2487893210303399, 0.12843942089426902, 0.20402692618869966, 0.16372308645757938, 0.32511478350047146, 0.13205515671401255, 0.13920471823263553, 0.21444513973209167, 0.1360358568208833, 0.15582173221534298, 0.17976374185133367, 0.73316520380397, 50.52380308028191, 60.303483932249016, 68.29413644729122, 55.354182335638235, 13.870637436066906, 17.992971020360148, 1.3711309288778615, 5.656358340094167, 23.27749602256283, 44.550653042331824, 18.372679987261375, 0.6450625184562899, 0.6058623509541635, 0.15297982180791517, 0.13895895722652638, 0.2328722049752551, 0.2147818813400884, 0.09164712902519012], [0.034635765853548245, 0.19767052614160124, 2.8384092017527554, 3.2827066125408297, 0.12581154779200593, 0.08356271807344691, 0.12242988247664706, 0.9733223073905515, 7.893082086117038, 33.36689702926144, 57.452285597401286, 36.788729621518044, 15.979208523227324, 16.967634039540446, 25.266765279154626, 34.58244739040252, 45.51193183468234, 45.12915949667654, 2.5883409428981046, 0.22585387431806137, 0.4346607601450336, 0.04782313060375953, 0.12959629026872496, 0.030372764261799957, 0.06803255302891617, 0.05015994775139036, 0.12525872342408667, 0.048433357939845136, 0.052355670655566844, 0.04152102703829447, 0.10891273602723114, 0.1562555831286215, 0.18626730738868638, 0.5841110923117208, 5.576642049897102, 8.816237891874007, 11.159616766437408, 5.634603404229687, 3.1532634938916857, 1.094723586593905, 0.13870821664890937, 0.05506683666739733, 0.05989851490143807, 0.024655174291242036, 0.1116144983097911, 0.016437939015187083, 0.1147939470566569, 0.07477974984794855, 0.15365103740365277, 0.4685955747000633, 2.431012468953287, 0.9510293939421255, 2.4050355918945807, 6.7059689087252465, 20.836083389097645, 41.18308644140921, 51.07079721266224, 55.588606711356874, 58.76014501817765, 58.39976156911543, 56.690757428446126, 57.43522328715171, 56.6717613897016, 60.61549278997607, 59.417091031228345, 54.62111880702358, 51.181827745129986, 47.204689518097915, 45.98905286481304, 42.90690929658952, 40.10056326466222, 41.701447271531634, 44.13529757530459, 42.75137947451684, 44.80302226158881, 41.49302428768527, 46.180429227890514, 48.23214653999575, 50.67336305495232, 48.32017629377304, 47.87110413274458, 45.575678194722826, 44.448836157398844, 45.29622893179617, 43.12191401758502, 44.671595404225016, 45.778621627438454, 43.650029782325994, 42.323166478064756, 46.4816084215718, 46.97052401881064, 44.431275706137384, 45.10287569415185, 45.64292330895701, 42.72164006387034, 44.44909895620039, 46.72213992764873, 44.76332787544497, 44.07275538290701, 47.85576766537082, 41.828131983357096, 39.68480379350724, 38.414489300020286, 38.91675272295552, 39.07416136034074, 39.955412034065496, 38.856630632954264, 40.68230175202893, 40.369826132251376, 46.81080510539394, 44.82157115013369, 48.86049062974992, 53.21690636296427, 50.36575901892878, 48.87716070298226, 54.85152667568576, 49.007453995366255, 50.18702053254651, 46.74345016479493, 45.61625119178526, 33.848830807593565, 14.712063304839598, 2.2291790669964207, 0.14754695607529533, 0.0183278396199908, 0.010726892393112425, 0.016418080100969925, 0.26010321393128366, 0.7753712551728372, 0.10484497768864517, 0.05485172683913862, 0.07676609326153994, 0.05817745241426653, 0.010388875248721771, 0.055684108181946704, 0.032935640549347285, 0.04700419793446218, 0.010915682313122578, 0.0424897222359094, 0.040165844313319654, 0.6266520773210834, 2.21847957661075, 5.462984510006444, 1.4377912422341685, 2.505606634001578, 1.3699505406041301, 0.7106195426275654, 0.17060785734605405, 0.0533868862886823, 0.018744823192396474, 0.11713721083417056, 0.02722835446137094, 0.04734336038029963, 0.03955717213572033, 0.07635272753935668, 0.12838834581235725, 0.1309435478141231, 0.8971523914125659, 35.620737998716294, 50.20566355797553, 52.718043634968424, 32.81363691053083, 8.34600748554353, 10.170636234744903, 10.527344422955668, 1.4200225376313733, 6.034189962571667, 16.88546822917077, 10.331938805118686, 0.08987079329428174, 0.5614939704537392, 0.1988934935821641, 0.06774771387778944, 0.13069512082203744, 0.033169983014945066, 0.04235477201760777, 0.029622141737490896, 0.14267354903201904, 0.8558704259414828, 1.8793863851216532, 0.11579523929544996, 0.062261187516513376, 0.21903302580598863, 1.154365431397192, 10.209875625948753, 50.696901198356386, 64.08891239473897, 46.4824870324904, 21.091451260351366, 19.421978727463756, 33.79560032198506, 42.490753666047134, 52.47397415099606, 59.163607858842425, 3.950569807521759, 0.2512254040207594, 0.2374048714315699, 0.0749647600816623, 0.09860922882874167, 0.07130234652469236, 0.018259426053132743, 0.06384163456518324, 0.04612702726116104, 0.03277403813215994, 0.031246255797844742, 0.038565812226865566, 0.05122413197832723, 0.10433382850380675, 0.09675896561314022, 0.3697595378804592, 4.505053950894264, 9.193981751318901, 10.49189894430099, 8.407768145684274, 3.2263642164968678, 0.755791518717043, 0.11080975358885144, 0.11056848951885778, 0.04475523958042745, 0.017290470385623556, 0.10596541192142234, 0.060140357367814555, 0.045402622180840665, 0.21750215230689895, 0.2307752384653976, 1.8927217082631205, 3.7184307027247647, 0.9211585838948527, 3.3236529702140443, 7.463684043576641, 19.547276881433305, 34.395193438376154, 49.72251384488998, 57.010967962203495, 58.30889986407373, 54.10351499434441, 57.57472238233013, 57.474144966371604, 56.114427889547045, 61.03619052517799, 59.84419399692167, 58.98906238617436, 51.814831610648866, 47.77368814714494, 49.59083987820534, 46.47310080066804, 43.0334214241274, 44.68498245362313, 46.78164228316277, 44.51444564327117, 45.858469317036295, 44.45149944674584, 48.57245922088624, 51.12122712596771, 52.154442187278505, 52.15470106370988, 52.09280214002056, 47.71227167498681, 47.26367804311937, 47.338383505421305, 46.000098259218284, 46.195793151855476, 49.72775805381037, 47.163528165509625, 44.12364421352264, 49.53313789060039, 49.17383309333555, 47.16851349799864, 47.29479812806653, 49.036161822657434, 47.52126009233537, 47.26175215936477, 48.53431024859029, 47.58657540044477, 46.18706980059224, 51.03129502265684, 44.39970062625024, 43.15951778042702, 40.75803095294584, 40.33239103132679, 41.81541565925845, 42.47726071265436, 42.220710246793686, 41.91281987774757, 45.36064209476594, 50.00545009489983, 49.18831448401175, 50.94413603505781, 54.37777888390326, 53.06704828816076, 50.02541888144709, 55.40297269821168, 52.65290483351677, 54.32013965422108, 46.647046150699744, 41.700949130519746, 26.825762294953872, 5.915487274046868, 0.8919725951648528, 0.04868822007049476, 0.02802182619850482, 0.15022567443309293, 0.013840744861461704, 0.20326862171772989, 0.9160415455698968, 0.4478485041087674, 0.04336274071266094, 0.09102937104480882, 0.09966469880553985, 0.04542993704578088, 0.05411898672220208, 0.04002137928299847, 0.036401322727362, 0.04113954589551976, 0.04659945070142708, 0.06286384207346747, 1.0406720998787111, 3.3156020602872296, 5.488544635234341, 3.2532731467677705, 2.0674249337565516, 0.9915968751715076, 0.4681999975394818, 0.18894608703351792, 0.10239143555443134, 0.06182235703172703, 0.05981200059214908, 0.04088116359085806, 0.04513051924145511, 0.04374736281592519, 0.029665927492803144, 0.1392190440768196, 0.3676352373534634, 6.630200974402889, 53.593081274340236, 65.32201928477134, 64.43155496351181, 40.41780064182897, 15.505962794826878, 10.246162453005391, 5.275214276006145, 6.522655958129514, 11.92245206525249, 35.01923468805129, 16.381660372980182, 0.05142231892433859, 2.634390549313638, 3.4240433381449793, 0.17186532938672652, 0.09646701716607618, 0.028037557814029918, 0.09670425161358812, 0.1646152724541964, 0.5417630388852089, 3.7321957705482363, 5.3888835830073205, 0.28639078560856085, 0.19304782903242498, 0.2933504492525132, 2.069421910470532, 31.39515292259955, 79.57783837472239, 78.8018366598314, 53.35448349675825, 20.882047683961932, 27.276656396927375, 46.201166798991544, 53.303037689578154, 61.927843324599735, 72.85393099631034, 5.0141859342975, 0.4399911999221771, 0.5875834317937975, 0.20980974088513085, 0.2192612587203903, 0.22975209739900407, 0.17444304671258698, 0.1687342361096413, 0.1731768719130947, 0.2395652853433163, 0.28283089759849733, 0.07691633076437059, 0.18906988684208165, 0.5944138717266821, 0.7837884777015256, 1.435560271624596, 8.538579190931014, 12.472043787279437, 12.360414112767867, 8.627300262451172, 5.4997003463006795, 1.4445754717434607, 0.19781136374560096, 0.16475804059976534, 0.15667121647106064, 0.17226058479037978, 0.26614133508936055, 0.12560190783152658, 0.17830115742981437, 0.2981803578234488, 0.6314198408396013, 1.4740457097368858, 5.593537659414354, 2.866561523368282, 4.985128525764712, 12.01012586393664, 32.02900598126073, 46.592725246183335, 50.761047640154445, 60.24439342560307, 62.038324725243356, 60.68812331845684, 58.78992757489605, 61.30864620208741, 60.84124088287354, 65.78036000651699, 62.71454134295064, 60.98068114249938, 54.62654344497189, 48.831492547065984, 52.65634082978772, 49.385746986635276, 46.890468443593676, 46.114713838023526, 49.60624302587202, 46.45518733609108, 50.27169665982647, 46.05886320913992, 51.49669601071266, 54.56882969025643, 56.977878847429835, 56.80731458048667, 54.86137574718845, 49.328594130854455, 49.64414488884711, 50.45142358349216, 46.50722934353737, 51.03828468630391, 53.60776662826539, 50.90077815517303, 48.41794529268819, 54.119439817244015, 54.88970310457292, 51.1562382021258, 50.11995976971042, 52.80284135572372, 50.62480018984888, 50.64421592220184, 52.373404579777876, 48.93322313985517, 49.37021047838273, 55.433767226434526, 46.77121270087458, 46.09148948423324, 44.072017977314616, 43.44288156878564, 45.408491088498025, 47.920023933533706, 45.00372994330622, 46.93616797847133, 47.39976467624788, 52.446074331960375, 50.33815337765602, 53.61699988765102, 57.79705409080752, 53.17714921889767, 54.897732196315644, 59.294968035913286, 54.868275196321555, 54.499466496129195, 49.03298078044769, 48.38414230654317, 45.64618279857021, 28.123305882177046, 3.419165380539433, 0.3254449980393533, 0.19441174132929695, 0.23561806327873663, 0.11577578066217324, 0.3394078697648741, 1.6409147362555228, 0.25186893319891346, 0.17654384366206585, 0.17080474194259415, 0.17855041179685824, 0.166087678122905, 0.1740348137794964, 0.19200441727955497, 0.06490213390920432, 0.15942508805423014, 0.17259538053504883, 0.12870785810293692, 1.7355351750889134, 5.708645495676226, 7.790307652565741, 4.563712506524978, 4.515636505619172, 2.3234713750500835, 0.8634848496125591, 0.4223325668323425, 0.25680774882916485, 0.21627336259811156, 0.22891002887439346, 0.12611824343161238, 0.15017943336598336, 0.22536622871073986, 0.27854043750032303, 0.28385475878753974, 0.3974428911122584, 5.456912680979698, 66.4650175648351, 66.87223803612494, 75.15409515750024, 55.7914520848182, 18.121271748696607, 13.886161196616388, 7.847464921013002, 6.476512705126117, 19.51101456919024, 57.205493988529334, 22.340328039661532, 0.17012640172916074, 1.3299819562704334, 1.2075839047470402, 0.4926568029388305, 0.14359973401071566, 0.10189562344983702, 0.21535514493382749], [0.04211834579285595, 0.6431381055904973, 10.770331332760474, 16.254124506827324, 2.9667697462343403, 0.10011822285671389, 0.26991128440826173, 0.49418386132005726, 2.6823601559285195, 19.056519731398552, 51.168797631417554, 18.57005757670249, 6.383084299102907, 11.036078776082686, 32.512461639219715, 33.06083448471562, 46.58959127241566, 48.504257048330004, 4.818168426713636, 0.10072126428806975, 0.15748687028404207, 0.05693095841354901, 0.02892029220088115, 0.06695370204866895, 0.07094316620139346, 0.08701238135296492, 0.04721994361569805, 0.0673472720588888, 0.03143039652176442, 0.054723384129183913, 0.10662787879306464, 0.43080914585340413, 0.6645564530645648, 4.620216210042277, 10.827094893301688, 17.603379641809774, 18.148585173391528, 12.902856334563225, 9.358906630546818, 2.9604466403684313, 1.2583599672202141, 0.08400949289000804, 0.17728864966380983, 0.05439318491206054, 0.061934175225155014, 0.009149723243148578, 0.055782198079771576, 0.20648867312458255, 0.6032914824543462, 4.284506920845279, 1.746800099649737, 0.40930689642986945, 2.021180066850878, 3.6487610734278157, 10.181283508577655, 13.743583040852702, 30.067252151427734, 47.140868633024155, 44.03625380608344, 44.97343747846542, 45.359018233514604, 44.97283735582906, 49.26027036482289, 50.75843141924951, 46.96169868592293, 53.73997403729347, 50.13871654387444, 47.62910173785302, 46.41568122371551, 41.1890955125132, 41.15574359893799, 40.09689977092128, 41.63447280083933, 42.67428921115014, 42.65810943418934, 44.30308480416575, 49.556683878744806, 49.53545601137223, 48.867790160640595, 47.07461980081374, 45.62227202999977, 44.39191472145819, 44.1496063816932, 44.9427096305355, 43.9022970199585, 45.93447700623543, 46.06180890913933, 44.364116884046986, 41.8837982608426, 45.61355652347688, 43.797965895745065, 44.75515365600587, 42.52595693834367, 43.32963489717053, 44.56788009212863, 43.13439107710316, 44.42716898456697, 48.26403540949668, 44.86632539379982, 44.331902457821755, 44.39149110547958, 40.96416327261156, 36.91394344452889, 39.248224381477606, 37.710353251426454, 41.05233815408523, 38.12064493856123, 39.53152541191348, 41.23550499639204, 46.00404024124146, 46.98744512373402, 46.741881216726, 45.51691716717136, 46.43104907005064, 42.138983741883315, 43.478735954530784, 44.6424953399166, 44.114222680368734, 33.93114959039996, 24.07190542067251, 11.545127899416032, 0.87201434998743, 0.29956841721169414, 0.016784555496527784, 0.12582705341159336, 0.1020963384859985, 0.056204664926495285, 0.03938212104502224, 1.3404739287591751, 0.8175850899950151, 0.13952583164697693, 0.08840172776892301, 0.02108806207205259, 0.034360908828074896, 0.07204929757262431, 0.10950846897978937, 0.07403991575683318, 0.06473275186914591, 0.13173626495465157, 1.0082089095827074, 4.193979107564496, 8.359562216266509, 6.153418248699558, 7.054957872436893, 9.998466737808721, 8.859549683909263, 3.4957793210783317, 3.0733736388144957, 0.22588592743681324, 0.06074788424396708, 0.09066855129335197, 0.07448865175848046, 0.09355379929465633, 0.08246352745881004, 0.04202702811228172, 0.09394795153169863, 0.41966514061054877, 12.857682397288661, 57.48130329193608, 70.6301667613368, 62.821586747323316, 32.25337732222773, 8.381234292061098, 7.849804614820789, 1.5763443107566528, 4.585400271800257, 5.710509111804347, 12.981398855486225, 7.2736461893204725, 2.926548291598597, 28.080228451759588, 46.56524119838592, 4.747788358119227, 0.07196796967858268, 0.09116709067095673, 0.0364112205833437, 0.04609138885092351, 0.9397752558992756, 8.353847322925445, 15.4253629907485, 4.5603784918785095, 0.15497256971655354, 0.3816282316561668, 0.604629929988615, 3.891584959722335, 32.321250015689486, 65.93052402619394, 23.832274098550123, 14.99167730731349, 13.124059381023532, 38.054898169732866, 41.68278071188158, 52.80771293947774, 68.23626579776888, 6.899866375230975, 0.2517485194989751, 0.10164360350538647, 0.033082740922128005, 0.06682070918501386, 0.059528065424773006, 0.04211282995980113, 0.018592342967167497, 0.009822471972344624, 0.018123571851080465, 0.03634957731851647, 0.10117720917708452, 0.04976467319553898, 0.22298424684953308, 0.6141109728524762, 4.284169597010459, 11.035028561469048, 16.056872433231725, 18.797280480784757, 11.092831550105926, 10.540698132207318, 3.180863496757323, 0.7475808334927405, 0.05779429736937727, 0.09942243882124463, 0.07510726775733695, 0.09323135288732667, 0.06270890079078174, 0.11439093118233067, 0.11965410077884314, 1.9342626727396444, 3.9833804340131826, 0.7894670891184962, 0.9309925787871884, 2.302615397399472, 4.171423027592321, 13.265298047373372, 18.051304509562833, 25.79448880687837, 43.992507611551595, 46.71609947758336, 45.50986866797171, 46.79885756584906, 43.00182281001922, 47.90872750743743, 49.5668153608999, 45.87923434472854, 52.44527809081539, 51.59778725716376, 47.23876314778482, 47.50395067276494, 45.43816774122177, 44.969597478066724, 43.30477099264822, 45.969150758558705, 45.86320361783428, 45.96767986974409, 48.92089120803341, 52.77415706265358, 53.48663599260392, 50.15470804706697, 48.80559313681818, 49.13864943288988, 46.216138485939275, 48.75574373429822, 46.794766533759336, 47.39767405294603, 46.853527561310806, 50.34116575794835, 47.00206379736624, 45.828894645937034, 48.43575285327051, 47.59161956848637, 46.75378953256915, 46.85472388421336, 46.22146506463328, 45.87080124885806, 46.89358280551049, 48.50643396377564, 49.43396076079338, 45.976277705161806, 46.10701422537527, 49.69668503730528, 44.09344588556598, 40.53378905019453, 42.586043727013376, 39.430787178777884, 43.85147879200597, 41.08126955647623, 41.17251565379482, 43.383375290901434, 46.874563232544936, 48.3005448310606, 47.14634818415488, 46.11314881232477, 48.26515328499579, 50.49858616244409, 42.50425446418024, 42.14624797144244, 33.02997719857001, 21.918267280824725, 12.796978815909355, 1.1814074771058176, 0.20407232455909255, 0.15550153810651074, 0.03766528736319273, 0.10288618279681092, 0.0258463739808048, 0.04604741157363019, 0.04295612422509059, 0.3477054600033068, 1.130675786445218, 0.6638625612662685, 0.09932968089537275, 0.06946490762094337, 0.0589125597428891, 0.037785570828184005, 0.05015175444104018, 0.014184200272504843, 0.04124044733602674, 0.0906157601744898, 1.0004140568837043, 5.623014271259309, 10.612428476733546, 9.326542173662494, 9.085228154736182, 9.583208349443252, 9.950349061719834, 3.2284651360204144, 2.9471542181507235, 0.2126630813243889, 0.12308133300393821, 0.17379789342803342, 0.045982389861056884, 0.0033474259731930594, 0.07948811090881787, 0.056758174943106796, 0.08036224021305961, 0.27928050907869495, 24.359956441387055, 73.29806881566202, 73.88202344217609, 70.37378495739353, 43.16036501238423, 14.004059799255865, 7.141057329793131, 4.395123643259849, 11.220884188528984, 9.159827713043459, 32.061010560681744, 8.958227692111846, 2.961664781455071, 59.850101086401175, 75.24211314416702, 8.150878885099965, 0.04984209404116677, 0.07893618286377, 0.05594278160001963, 0.11311629111127508, 1.7776886421826579, 21.319078168561383, 38.525610047002, 11.420689725106763, 0.3654280154695434, 0.5545546234615388, 0.8296723026902446, 10.0658118724823, 59.819279101587114, 84.3403959274292, 21.983239381544053, 13.427680250137085, 22.988025103845906, 52.03461377851425, 54.75616601205642, 61.87431866122831, 81.29291042204827, 13.493729041468713, 0.2543524829971214, 0.2935139324155546, 0.20782050165918567, 0.21088502189565092, 0.12471358291804792, 0.19583812043551477, 0.09877198420825506, 0.1251557152417879, 0.1414869707678595, 0.1396044782332836, 0.17901363452115368, 0.22888756717645356, 0.6209199623234811, 3.312012601283289, 8.175850654802016, 12.233193016821339, 20.378183933996386, 22.687465644651844, 17.081502406827866, 15.430326750201566, 5.841336336828047, 2.3526540542802503, 0.3902673745347608, 0.33877483599128266, 0.19027845182966804, 0.16218219252844013, 0.16435798948570607, 0.2830139619688834, 0.9429515790074103, 1.0283102599843856, 5.168342926809865, 2.6989932117923616, 1.3373973196552646, 3.5405311132631, 5.786103971542851, 19.43354187473174, 26.49769525374136, 36.7123963755946, 47.3429609114124, 46.480117920906316, 45.33631163258707, 44.932711508966264, 45.57717261775848, 50.755556321913204, 53.23857353579614, 48.81030390339513, 56.03629819808468, 55.17332576936292, 47.482044235352554, 50.98761158604776, 46.81422541218419, 48.876117352516424, 45.508021231620546, 48.53212548840431, 48.4508853573953, 49.125442812519694, 51.47404040059736, 57.2791325661444, 57.31721093577724, 53.23873827534338, 52.79429843348842, 53.69560026353406, 49.68092887632309, 51.250998743118785, 50.28652321907782, 50.76504453536003, 49.88469600677491, 52.65972583524643, 51.16195309546686, 49.08303414621661, 53.599533573273696, 49.99209834683327, 51.33249775055916, 47.86319663447719, 48.15697431564332, 49.33180655202558, 49.81625849200834, 51.558037957837506, 53.89775922221523, 50.81047734906597, 48.46570799427648, 53.32698375948014, 46.259837612029045, 42.440900341157, 46.059090706609915, 41.70805646527199, 49.467296984887895, 43.156525011985536, 44.586217172684215, 48.4263313201166, 48.574283123016365, 49.93795002660444, 50.556366597452474, 50.29714891987462, 48.684231081316554, 50.22363193573491, 46.137871511520885, 44.62420140543292, 45.80211662477063, 44.407917991761245, 40.09146336586245, 21.805000997358754, 1.2617265865687401, 0.30946403621665897, 0.19771071511410898, 0.20205786571868006, 0.18655086717297956, 0.1734926533554831, 0.23488370671627984, 1.2921986224189883, 2.439581867187254, 0.4337525782325576, 0.28491805818292404, 0.1327697482080229, 0.14165653666901973, 0.2502137389514716, 0.15817169160131486, 0.13100797580855508, 0.17074647329507336, 0.3330311990312992, 1.3039550689920303, 7.522515183494938, 12.5683517033054, 14.243596003901574, 14.629319925462047, 11.850773692131044, 13.23704521502218, 4.855179911659611, 5.080958402925923, 0.6886488151165747, 0.2836941561150936, 0.3412006993687922, 0.1609985866854268, 0.15444830510645144, 0.20297632853109993, 0.12563987514905392, 0.15362293729859014, 0.4271669493567559, 21.55791521072388, 83.46319706209245, 80.66154218489125, 78.51112627214002, 57.777701116377315, 17.4714821000253, 13.444949465413249, 15.431461295773907, 14.603301863516531, 19.624182793401904, 59.765879954061205, 11.797460836748924, 8.765860930565866, 78.3622331003989, 74.36314921225272, 7.582998621848322, 0.10630261318217363, 0.15056898907547997, 0.16044786139842004], [0.06656099771780354, 1.5059627712734285, 13.067759640755193, 5.9811124493998875, 1.8766594798334184, 1.867863196999796, 0.3180187868495142, 0.40801380130071796, 1.9627705817261052, 17.512306128778768, 39.3870331395057, 15.086645733925605, 8.28875853169349, 18.302704903387255, 34.72017357426305, 37.77632359535464, 46.717484074254195, 54.15491765545261, 4.444361646329203, 0.6032474170769415, 0.14891670596215034, 0.027107209147464846, 0.07254275778729109, 0.04244338923824891, 0.04987372581156031, 0.03441910086680324, 0.09310595961588045, 0.03314606958038865, 0.04556718935829498, 0.08540960284130228, 0.4424696782183263, 0.5687613869386335, 3.7651586340319727, 13.362924860369775, 29.770948463870635, 23.528104097612445, 22.30839014053345, 33.35371002074211, 16.77888762566351, 3.818829650840452, 2.4659465685967477, 0.5847037379299441, 0.041283719812429724, 0.08639987873574419, 0.0083955901209265, 0.06776872766955246, 0.08713299423576364, 0.32785066733917884, 3.791807216982688, 2.0245671560687404, 0.8388288919964145, 0.5544650218179149, 1.5079674701536856, 4.539173668430698, 8.971059726130578, 16.994827831945113, 11.843690872192385, 24.171019792556766, 44.30390457953177, 41.16687528548702, 46.10717896492251, 43.37036478903986, 43.67893765049596, 42.65051964790591, 46.07214435454338, 43.244029168159734, 47.177346675626694, 45.00835049536921, 48.1899183027206, 41.448819175843276, 41.735717019727154, 39.69661012772591, 42.25734126183295, 41.60389792534613, 45.58007517168599, 47.07397653210548, 48.475286422237275, 46.528806301855276, 48.782105984226355, 45.414888474249075, 45.55445424972042, 44.602408716755534, 45.13752983462426, 40.70454159090596, 43.903277612501576, 41.083811252347886, 46.292656083260816, 43.75167016060122, 44.15299138715191, 43.23337601077172, 44.46052089814217, 46.19721697222802, 44.33144746288177, 40.64813006308771, 44.185692187278505, 45.64783803878292, 44.3205903422448, 43.29793430143788, 47.85500280318722, 44.174584034950506, 44.380979153417776, 41.91211777348673, 41.10962044808173, 39.246102379214385, 39.86227143195368, 39.31665405150383, 37.432323886502175, 36.09935737425281, 41.602023032403764, 42.15616372323806, 43.565894942129816, 43.41471895094841, 40.04348101154451, 36.94446340683968, 44.91315849365727, 38.63546386841805, 29.193836412122174, 15.269934169707762, 8.310655163180444, 2.9633308081857623, 0.16731003269312844, 0.13788200614433135, 0.03229084349567852, 0.11880653174293619, 0.0904618454496226, 0.10288190802619343, 0.06581285923358894, 0.09525098282122806, 0.023485875140214642, 0.3137757016285774, 1.7428187713507683, 0.14922948433987557, 0.0540615224670018, 0.01606585394080368, 0.06375069609813153, 0.09622165452568762, 0.07184795434436492, 0.09671426438275846, 0.13538814480266265, 2.0169057865296645, 6.976438395438656, 3.941951869956909, 4.576849995120879, 21.04326298159938, 20.289503066770493, 10.864172077948048, 4.813037476231975, 2.450621132889102, 0.6136003905727018, 0.5960663540228721, 1.2589039509334874, 0.07495657060175173, 0.04160639604613666, 0.03287130831590584, 0.024235520902420246, 0.13181442124468665, 0.0800638719491901, 38.32249402999878, 72.23945248511531, 72.55231641953992, 59.58685905702653, 32.88545158601577, 13.187654729812378, 18.261188576298377, 8.463893340479943, 0.5495323961780918, 13.079176679734262, 8.245640896981763, 4.578149770536731, 3.9277950554124774, 41.97471095669655, 71.3875215284286, 14.606614305127053, 0.16329862778225254, 0.15607527667476287, 0.11602417701074194, 0.05399272394096179, 1.7576151773814233, 21.096719003492787, 23.63160760171952, 14.641234124860457, 5.725712708888516, 0.330068308018869, 0.35568972028070883, 2.750478978118589, 33.0098593619562, 55.97534064323672, 18.5925837486021, 10.688650915699622, 24.796233830913422, 47.14743860306279, 47.60726198073357, 51.583600044250495, 70.62298097918111, 22.856902230170466, 0.2999421761881921, 0.06481157465567512, 0.037664915810549454, 0.039601367748072075, 0.04176885265135958, 0.06895437130644437, 0.03355304995972303, 0.13908094906758878, 0.07269956066363281, 0.15811297862279802, 0.04452689558327679, 0.8073106864767691, 1.2531794968151277, 6.5523821307766825, 17.568280312322802, 28.778249525254775, 28.332385863027266, 26.421340434781968, 32.86699095079976, 21.080982454361457, 4.494947964145291, 3.1820267246615503, 0.296909938896856, 0.13989441186910676, 0.03657443944605128, 0.0898213729622864, 0.14967095016712142, 0.11488989190829378, 0.5686554829439809, 3.4431590091797615, 3.9384450258747226, 1.1980656606535758, 1.0080482762667442, 1.5664204690725574, 5.1975361474098705, 9.2410139114626, 19.66115701583124, 17.736563721010764, 22.9344553332175, 42.64547155749413, 41.76476609322333, 46.65290224936701, 44.81109449940343, 44.52260417322959, 42.876663900190785, 45.72019007898147, 42.074021447089414, 46.972602875001975, 45.51906662602579, 51.10743999481202, 43.61574826701995, 45.25815056216332, 42.56757328587194, 45.50177681830622, 43.34757974070888, 48.77305315386865, 48.13402452776509, 51.73124590227681, 51.59439832933488, 49.65430774996358, 48.021507417002034, 49.522312148924804, 48.28984068286035, 48.422761963259795, 43.33453001514558, 46.918156454640055, 45.45278641485399, 48.47216029320994, 45.400234499285304, 47.69604482958394, 47.89782724072857, 49.03197665368357, 48.24072868593278, 47.222144065364716, 44.46253699641074, 47.11696178682389, 47.937482403170684, 48.23803793999457, 44.40086557019142, 48.53510648973527, 47.893014492527136, 46.83545720192694, 43.4815953623864, 43.28221344178723, 42.751756022053385, 39.90012230411653, 39.470544322844475, 41.28330299931188, 40.686506532853656, 43.91984570410944, 43.388811695960264, 46.356480890704745, 44.283374894049864, 40.56803134179885, 36.40666723251343, 49.58293630230812, 42.20892352442588, 22.960648921228227, 7.06228191814115, 1.3681609592130108, 1.3884052922648769, 0.1562194237785955, 0.06957130191186744, 0.1017383915642577, 0.06269100497687055, 0.0189262347280859, 0.05659007610032155, 0.02489207932094653, 0.06303243504296388, 0.02208728204301048, 0.09304136308210512, 3.1612462526367557, 0.025734348943637266, 0.03526946995407343, 0.07242945338329, 0.012136486512909253, 0.06249977027877204, 0.049109962964130026, 0.0423575873907295, 0.11883259405412021, 3.4524743931908763, 9.920499824708509, 8.253284615855064, 10.868999535037625, 22.93449651810431, 25.15459529815182, 11.643773548064694, 3.5550595723813583, 4.044196783534942, 0.7976875802682293, 0.562969884805141, 1.3820745868067588, 0.23249614773498428, 0.11282012918062749, 0.06957234379144446, 0.03528044033314913, 0.16365251443799467, 0.13298658173411124, 50.93598534983974, 78.27776878110825, 76.31681119242023, 69.26705683431318, 43.2815662507088, 11.378932172252286, 14.175714485106932, 14.227407401607884, 2.266325628565204, 17.282149291807606, 26.241533102527743, 4.185662211910371, 34.58934683953562, 73.27085541140649, 81.90498844269784, 18.278615666973977, 0.19661559242635004, 0.20488275365243036, 0.08241564696354252, 0.19502053608096417, 2.7720485819924265, 30.34096887034755, 43.12113346592073, 39.606748627078154, 14.872583362364, 0.5188443848202305, 0.4895903674825546, 8.01574097525689, 59.28759790235951, 63.51116688020768, 23.661849075748076, 19.73280106821368, 28.741004659283547, 53.88709822008687, 60.642521842833496, 55.247442876139, 83.84077225961994, 36.021137468276486, 0.5832533802716964, 0.25016636407423404, 0.1409992179082286, 0.1261952582506403, 0.16987979802633488, 0.19501813056488193, 0.11550502986797404, 0.2210984907803997, 0.12643564131952104, 0.2052469518516333, 0.15619375983313208, 1.1493161152447424, 2.3470168728982252, 11.141934721700608, 22.38428996455285, 28.493167738760675, 32.064797609083115, 28.675130413424586, 37.67616195063437, 24.104404218735237, 8.302466234853192, 5.665424898747475, 1.1995674381333015, 0.41628108510086614, 0.2567280756850397, 0.1332551568386055, 0.5755469647626723, 0.18398908447594414, 1.0668037879851557, 8.887378900281846, 7.119208257044516, 2.3240391381325263, 1.913621567430035, 2.725366738534743, 6.612683669213326, 12.997883596727926, 29.063531352627663, 24.649082191528816, 33.57678305718207, 46.3974618142651, 41.18017604274135, 47.13578131891067, 42.50541548575125, 44.01314320102815, 43.013205528259284, 45.36818481260731, 41.907328559506325, 48.01565524070494, 46.39126054702267, 52.47385647989089, 46.109238209262976, 47.20883154099988, 45.31380899490849, 48.76650279568088, 46.37802647006127, 52.2510148632911, 52.49092663488081, 55.07622357337706, 53.27209018891858, 54.74265736918296, 50.502022158715036, 51.8653085923964, 49.035514631579005, 51.80157792183661, 45.411946696619836, 51.54362324745425, 47.29182889384609, 51.666891574859626, 50.55660586203299, 49.64378010842108, 49.428414529369725, 52.35027436287173, 52.44123020479756, 51.37851499742078, 48.068175777312256, 48.40106341146654, 51.9305689873234, 50.27217126661732, 48.25477861589002, 51.59999947394095, 50.277031083260816, 52.79643220286216, 48.62715275056901, 44.27152149138912, 44.33798997632919, 41.02372446367818, 44.27602044997677, 43.93284051649032, 44.34055128405171, 46.00621715668709, 44.78236706026139, 49.1264469392838, 48.485390447801166, 42.9086116052443, 39.81205724900769, 48.20143438154652, 46.43810933636081, 38.82299238635648, 28.693320405098703, 16.756492853164673, 6.540409586121959, 0.39681699727812125, 0.3710358710058274, 0.35969528760160174, 0.20144373899505985, 0.11566913356223416, 0.19558950958232726, 0.31420222874129977, 0.26549791316351584, 0.260574511222301, 0.7290392381048972, 6.831552415124833, 0.297007875577096, 0.2330345696499271, 0.24734847818411168, 0.13351266963347314, 0.19214828859173483, 0.14138396258556074, 0.19025448859939653, 0.2697922649883455, 4.1515709315576865, 13.888727407301626, 12.924691188719965, 18.840414785569717, 28.075121525795232, 28.430882461609382, 19.642045267166633, 8.440338527002643, 4.641552923187133, 2.1280333976591788, 1.0083595531121379, 1.7665182222281735, 0.6320480329375113, 0.27903670925767193, 0.1749795227642021, 0.08645780264369904, 0.26747478773036315, 0.1809696102094266, 53.63585472106934, 88.76599834811303, 83.71644881463821, 77.16252911475398, 55.147234162976666, 28.678374213557092, 28.72303039796891, 17.872499342887632, 5.868281058726772, 43.04825190574893, 44.67016373911212, 7.590935047595733, 56.25472714824062, 87.7961923230079, 91.4030078149611, 25.071741111816902, 0.4049948632957474, 0.3289979606145813, 0.2890693660705321], [0.10381955368023726, 0.2155822440381012, 5.26373153732669, 6.657303081404779, 6.961488771823145, 6.302811522637644, 0.1465748058211419, 0.0973850433083792, 3.3688401454879395, 31.674478630865778, 30.57217101896963, 8.33046019077301, 26.512653212393484, 12.884080929140891, 23.39504357307188, 36.69166272686374, 53.14057703941099, 57.847378100118334, 29.066843794238185, 0.4869943712988208, 0.18305592809713658, 0.056312154723151084, 0.006043512023039043, 0.1380318682640791, 0.010976050041555878, 0.021605866645733197, 0.08056448742506966, 0.02429264616371403, 0.06654433530545042, 0.7303941718512966, 1.41023303712568, 3.8931926411967126, 14.09483717333886, 22.953453333147113, 22.51799571898676, 11.304980785615983, 32.915797002853886, 39.26675365817162, 21.150675127583167, 9.438630765484227, 10.034840837601694, 6.638933150999009, 0.05939688435905884, 0.7642087412457313, 0.05275103714196913, 0.23140335395451517, 0.583892604035716, 0.9520214471605517, 2.407347583963025, 0.6589342870058552, 0.28065867061095856, 0.5349991566711857, 4.086490475362347, 8.197550677484083, 7.6744771195996195, 9.768239298174459, 13.860127445190185, 13.340915460740367, 25.52041515227287, 39.17507217776391, 40.59955543087375, 43.236239340997514, 46.19637366264097, 41.7558152444901, 45.06651924502465, 44.3174877474385, 43.37912344163464, 43.00236017473283, 47.53705547701928, 42.51160498588316, 42.65692095602713, 43.773007854338616, 42.55731236550116, 42.97729230696156, 46.85241360818186, 46.668991811813854, 46.97765881015409, 49.867967097989975, 45.59155202681019, 48.13033357743294, 49.139971271637954, 46.418666147416644, 45.056811378848174, 43.77563584235407, 42.96247751482072, 45.090751647949226, 46.13618489234678, 42.36068787113313, 44.620145674674745, 46.87328846223893, 43.374993185843195, 43.82717970878848, 42.63645795083816, 41.95121595936437, 45.69513397832071, 45.8022342958758, 44.854052297530636, 45.933668997979936, 44.420042037963874, 47.94340518213088, 41.840256029559725, 42.341444723067745, 41.029188325328214, 41.31050855882707, 39.94574339159074, 36.86036386797505, 37.40547918504284, 37.335390352433734, 42.28958706701956, 40.2204308971282, 39.16707446498256, 36.84803193615329, 35.55624638834308, 34.92563516862931, 39.14547005007344, 29.8115175385629, 8.795756255426715, 0.8472762677458026, 0.1065207567186125, 0.084398428068286, 0.0439560106925426, 0.03381970601396696, 0.017000531004140937, 0.04783445721372001, 0.09515484644761009, 0.03701315501764898, 0.03508514153861231, 0.031201114066906517, 0.06868433297401474, 0.03949653627651353, 0.033967652913904, 0.014306993633058044, 0.03105993555378049, 0.05530183030773075, 0.06041598048121218, 0.03870811305880066, 0.07680369285686363, 0.2092470646265053, 0.5405350305861043, 8.7897579708407, 9.578506408199187, 10.273566092214278, 21.253737365045858, 33.759565507211995, 42.35300394796556, 28.159038674446847, 7.3515831943481205, 3.177793016356807, 1.5176476345908259, 2.4056683192330026, 0.20016265612456108, 0.13430865030855904, 0.10551514374392648, 0.12747005153928073, 0.4209279905884497, 0.08738912807236757, 2.703834887473814, 59.59438608538721, 66.90197744677144, 71.10529914979013, 56.917066420278246, 32.60967954512566, 26.809911997087543, 36.308003933199, 10.357853904847177, 10.283364172904722, 20.242024737019694, 4.05673929760533, 12.162046124858241, 59.02730549535444, 47.25051849119125, 66.76391786144626, 5.560084744807213, 0.23715183259018008, 0.139213283095629, 0.05807677313925759, 0.15461548081328794, 0.20856792768163068, 13.783806946969802, 15.560796549243314, 12.154345531617443, 15.440853411151519, 0.7305273485760535, 0.2694564733293749, 7.366038109025649, 43.31824041181996, 46.479388360054266, 13.79037005286063, 20.38664644764316, 19.18448901945545, 30.20083042883104, 44.076834647886216, 60.54186205710135, 65.45262244439894, 56.19073760124945, 10.626411726397853, 0.23963558157124829, 0.30545390301173736, 0.026162938748095787, 0.13164882367897418, 0.02439906152205602, 0.009271580061214346, 0.09166312494104908, 0.11231706988426948, 0.018588456986171585, 1.400411054491997, 2.7862877663104766, 6.3480761647224435, 20.684991728874948, 28.408430814743046, 26.191428745946578, 20.273031073231852, 35.35886879890196, 45.3707931887719, 25.79265117645264, 8.98097743911128, 9.942914209058209, 3.95879011481039, 0.22728910940068386, 0.2997654243823021, 0.13731398259199437, 0.24408679755945362, 0.8762346977187742, 1.194163392628393, 1.099161380721677, 1.1829207765479242, 0.5694694360417705, 1.5612593653701967, 5.171104275411175, 10.826678141470879, 9.49397050565289, 9.2901994528309, 16.78087038378562, 18.321979430414018, 27.789098370459776, 42.32448047207248, 44.13350505213584, 42.716956753884595, 46.60834804657967, 44.06409871193671, 44.02252158811016, 43.759436453542406, 44.69734576440627, 41.873188249526486, 47.080715164061516, 46.246819265427135, 46.10110321352559, 45.86008925591746, 45.71594215208485, 45.45274326878209, 48.34345163837556, 49.120178991748446, 49.89578062488187, 49.65245246887208, 48.33058626421037, 49.98750525136148, 50.57014588386782, 50.75094753696073, 47.045131421858265, 45.89390008680282, 46.290463478334495, 47.439627724309126, 49.18774181796659, 47.36635000474992, 46.71198883364278, 49.17444498308244, 46.31982241907428, 47.46235393708753, 45.33740205149497, 45.846666905187796, 48.135228695407996, 48.07095281539425, 48.609835486258234, 49.06633269402289, 47.25060478333504, 49.401275650147475, 46.24574453599992, 46.38916992372083, 42.914102923485544, 42.72444848091372, 43.12260827710552, 40.96510464145292, 39.87607033021989, 42.74699034229402, 42.753787809802645, 39.98442972860029, 39.8829540898723, 38.85967046983781, 35.592979385006814, 38.411143518263295, 33.648319244384766, 15.002514816099598, 5.297750744127459, 1.7037552739343338, 0.3569637551423042, 0.08792994784251337, 0.052019637678900076, 0.04008203429440337, 0.04340723509930315, 0.09463965997941072, 0.10464491382721933, 0.098949839180756, 0.0543154308181857, 0.038914543110877275, 0.08197157643735409, 0.04808882138721886, 0.11496938119131712, 0.06168087591387092, 0.053219863799430674, 0.038433953173338406, 0.05970223551435817, 0.031671210515102556, 0.04361249303685562, 0.05428913868062439, 0.40383209504427453, 11.591954135125684, 14.687807367693994, 14.316458932815062, 25.141641670657744, 42.635642097842315, 46.87149593907018, 43.231924733807965, 29.03240538412525, 6.486123492640834, 1.9925743437582448, 2.74152371671892, 0.20608359647374, 0.12141190484286317, 0.03370751243745608, 0.019218642827904513, 0.5793556474870252, 0.1503452607580731, 4.919383718121437, 72.63101485467726, 71.33893120673396, 76.12758821056735, 66.64619968783471, 43.91018098400485, 22.238430746140022, 27.68035654098757, 17.943519738412675, 13.36131472741404, 28.40612642226681, 4.614500826404941, 38.025162681456536, 88.1857385943013, 70.10407493960473, 70.84671297381001, 6.9024767125806505, 0.1576018141162011, 0.06016689082307201, 0.024182712546579783, 0.28803723113190743, 0.4566926214723818, 26.488979747218472, 46.115714042417466, 32.95574634305893, 35.53345741764192, 0.7736781395731435, 0.2349079304164456, 14.770639000400422, 64.17153712241881, 53.38412092578027, 18.239388042880645, 35.22442171650548, 16.371982905172533, 33.752093392033736, 51.74039286951865, 68.78720191217238, 75.90635868810838, 73.22335550861975, 11.98226526860268, 0.3887074663033409, 0.28959759901608195, 0.243908038603202, 0.21788311250988515, 0.12823584068927074, 0.16654037479912082, 0.33971418236051837, 0.24791411154212492, 0.10612217649336785, 2.4220807417746517, 4.4900229380976775, 9.229405656937631, 24.924848348863666, 30.753866972461825, 30.183032674174157, 26.26137245085932, 39.70989519549955, 46.28809828912058, 34.34428891827984, 16.973856879818825, 19.08013043865081, 8.227049842957529, 0.8427035195692893, 0.9109924132785491, 0.31382868426942057, 0.4307973480993702, 0.9978287859309105, 1.6127544473255835, 3.8901934989037055, 3.1005188918882802, 0.39787995959481887, 3.583337654990535, 6.756115921082036, 14.71161223226978, 11.433451156462393, 14.694832332672613, 25.74646919004379, 22.17527274162539, 36.82516451804869, 45.37213071700066, 41.52931013414937, 46.11710648382864, 46.77005560167375, 43.458229803269916, 44.21181517262613, 44.186421748130556, 43.183522685881584, 44.11819211898312, 48.99140757899131, 48.36993155940887, 48.97074453292355, 50.796972628562685, 47.02939487272694, 49.45130940406553, 51.10127795127131, 52.057724383569536, 53.33138858118365, 55.39155467864006, 50.728276237364746, 54.11140680313111, 52.85572275038689, 52.96005387460032, 49.239579862163914, 49.01611458870673, 47.176738708249985, 51.52830639193135, 52.491413008782175, 50.82753573694537, 50.09296994055472, 53.056704998016365, 49.08628579108946, 51.31371744217412, 47.85391238427932, 47.644210707756784, 51.72713133596605, 51.23736066202964, 52.572315815956365, 53.17102247668851, 50.366908273389264, 52.82959192029892, 46.842086007518155, 50.372376057409475, 47.354284794099875, 47.80396100013487, 46.758759175577474, 43.81299641824538, 44.50290210785405, 44.38177147219258, 45.05383037751721, 41.965395327537294, 41.54543107555759, 39.29506140370523, 37.65926437993204, 36.26783101789413, 39.78613038216868, 38.50410761371736, 21.267375446135, 5.035618745511578, 0.6471233562596383, 0.32264509989369305, 0.25391709990799427, 0.14604416735950979, 0.1218570325703871, 0.21602574765922564, 0.2583003945408329, 0.25305898950224925, 0.13167923736956813, 0.3117467943699129, 0.17427174945271787, 0.19476248702454954, 0.5193380518786369, 0.13948325248014543, 0.1235120812611234, 0.1368983645713137, 0.1297881493284818, 0.1011522576933907, 0.29564757921522666, 0.29607530142511096, 1.6116230886790062, 14.1484942167036, 21.81697991586501, 26.382077509357085, 34.81909575000886, 42.04449384443222, 47.3006110806619, 46.73463267664756, 35.95488079132573, 10.571731925010681, 3.1183085566566837, 5.985749671536108, 0.5224732513869963, 0.3307345287213403, 0.28280013150745825, 0.17259461444712457, 0.7947287648435563, 0.15127118526687547, 3.56566860310493, 80.12227904412055, 80.17903574051397, 81.84649021394792, 74.89528148405014, 48.42342876618909, 40.681783999166186, 59.65872864569388, 36.598196568027625, 31.488077794351888, 48.290534942380845, 13.701929430807791, 39.84843723235592, 102.0725763997724, 79.9444309357674, 83.8271459456413, 10.952564650966275, 0.3328971642880671, 0.3845433800691559, 0.1257139481904526], [0.022762119319410096, 0.0907546442542826, 3.71041631987018, 5.815051063414543, 4.240614127728247, 7.3052649055757835, 4.1925616610434755, 2.410801966344157, 11.41961205390192, 35.973716012893185, 22.975018524354507, 20.174057906673802, 25.930544061045495, 28.97799622627997, 28.044093616547126, 32.418007043100175, 48.94664549058484, 64.43559500478929, 45.67060739763322, 12.460684603260411, 0.7248000139670988, 0.08632668669545844, 0.05467766017142323, 0.05448641015156623, 0.027888611169351686, 0.0317606512802623, 0.059696589446356224, 0.13663715923265105, 0.18329341535366353, 2.790616346943763, 6.671273583366025, 16.201159761798, 29.030795251169515, 37.6808060369184, 33.25570175724645, 39.89301104699412, 49.659822602425855, 55.04722549069313, 38.515917870306204, 21.194646858399917, 19.221067082497385, 13.432882293578118, 3.1277210193295635, 2.909646308229816, 1.540599506228201, 0.8719870159702917, 0.5428264302111442, 0.4372520678706708, 0.8209004120961313, 1.1074590322471436, 0.39170562800380493, 4.136220735888328, 6.871037444760723, 9.32382102935545, 8.672118244632598, 5.4689631827415965, 8.710401558106946, 14.152406780950486, 18.089965351166263, 30.23350181118135, 40.346739061417125, 40.19579449007588, 41.35817712353122, 41.803621092150294, 45.2797039862602, 44.48129769294493, 44.69501195415374, 43.71066570281983, 44.619110168949256, 42.895675628416, 42.95616249884329, 44.594081524879705, 46.59787139584942, 42.88053527955086, 44.00857756214757, 44.4539430833632, 47.791986003998794, 48.66805522672592, 47.274095858297045, 44.73717743350614, 44.87545274919079, 44.95593978512672, 46.46538157616892, 45.86131303541122, 46.99439556367936, 42.29629824238439, 45.97286524311189, 43.88917276936193, 41.53535450658491, 43.085396751280754, 43.53040925918087, 42.85588318301786, 40.898844042131984, 43.925474305306714, 43.14528742144185, 43.68218145062847, 44.66144823258923, 43.455841079834975, 45.48665215892177, 45.79790399920556, 44.4168649181243, 42.807971431363015, 39.98334715443273, 41.19222164154053, 39.10457934102705, 37.356178914347005, 36.13094422125047, 40.117668720983694, 39.04264511600618, 34.91237755744688, 37.14394730906333, 37.67520096994216, 34.297906890992195, 37.10662203450357, 19.803590043898552, 0.924134191966826, 1.0676810505890078, 0.07257445850559781, 0.055006039929726434, 0.08128465603916876, 0.056033608984322324, 0.07762128487229347, 0.07659052123105334, 0.02997422425617134, 0.03757819465752091, 0.2625895063242605, 0.3477025182256776, 0.3072165181079219, 0.08114779443149606, 0.061000156997432636, 0.08096523567914002, 0.04438856691722909, 0.06633064273985163, 0.022295029766316858, 0.11099699313842482, 0.23661170996004538, 0.07058861304915721, 0.3596988422495704, 9.633603942009712, 20.024488126077962, 25.90670781750833, 29.841892373177316, 37.47973357477496, 39.7421056993546, 45.968429042447, 50.29690181055377, 34.79103903616629, 10.626613728461727, 5.686809660926943, 4.7480835164746935, 2.7243633472150375, 0.22297117738954483, 0.14557679243866475, 0.2300980933491261, 0.6437643365033212, 0.4096594194491064, 14.78334551857364, 72.31284787577968, 65.2146718578954, 68.43016424486714, 49.45662029327885, 44.54051371543638, 71.12962568959883, 53.42260329954086, 39.1070935803075, 38.306757480867454, 14.391773343086244, 4.749621575878513, 71.63831003250615, 54.309741450894265, 54.10167932510377, 51.43114536039291, 0.8152784298985236, 0.21454704474777947, 0.1541723908796426, 0.07099705282598734, 0.18880155688572317, 0.13779617365329497, 5.257474866605574, 18.708342698312578, 14.658520010209854, 13.236686318151413, 6.446646798041559, 1.504658950913337, 15.38825442714076, 51.70759008776758, 33.341264340185354, 16.88847864827802, 14.127568371834295, 13.447415655659093, 27.88678696078639, 39.20127361051498, 60.71983568130001, 72.34421114767753, 60.115414127226806, 38.40725252705236, 2.535007985368852, 0.024710231115140265, 0.08094116519655913, 0.12290449692837654, 0.13234879821538925, 0.019547018755768097, 0.02633991654992344, 0.22733723504408715, 0.26707881220406104, 3.6848243253846324, 10.184072313770171, 21.448137875526182, 31.791773188498716, 41.127314259929044, 37.30622753020256, 44.02906410155758, 52.765516081163966, 56.86304361589494, 42.823762893676765, 27.48899978976096, 24.05341144531004, 14.210026398781809, 2.8053865221238907, 2.7497106838610867, 1.0044542820222917, 1.0769078135490417, 1.1777876197330415, 0.9570036540108343, 0.4196986952616323, 2.0971432616633754, 2.9182262478336214, 5.742295019088253, 10.035880265697356, 11.009120325888357, 8.404835193387925, 7.841098914223333, 10.591016257962874, 14.656790244963862, 21.886398023174657, 27.721188414481382, 36.538345121568256, 44.982078459955034, 43.26466475763629, 43.17136726071758, 45.28130823566068, 43.27130925270819, 44.3471565554219, 43.14391459188154, 44.09492069675077, 44.53193549186953, 45.31663310143256, 47.261171648579264, 48.40641744675175, 45.58048309818391, 47.70937696579964, 48.221893464365316, 49.883115291595466, 50.267444810559674, 50.238325134400405, 47.52369588421237, 45.720496023854906, 46.23894706849129, 51.288849615281634, 47.11891120479953, 49.10872959321546, 46.4233612245129, 47.942616785726244, 47.3884407935604, 43.98372542473578, 45.58433094332295, 44.054139814069195, 45.65552196195049, 45.27465197347826, 47.41821158316828, 44.16660201164984, 44.540133245529674, 44.662989724066954, 46.137836210189334, 47.855328359911525, 49.12710981984293, 46.92725635343983, 45.15405478016023, 42.927682169022106, 45.959235006763095, 42.541403232082246, 41.674045593507834, 38.996439595376295, 42.53475089227, 39.78179616312827, 37.33817915762625, 37.574537261839836, 37.32532947294174, 33.9050030708313, 32.96624260564005, 11.297479252661429, 3.2119823559637997, 0.911644078310459, 0.1315400238719679, 0.15895513907795952, 0.08872343873184535, 0.052069234211118, 0.14599267092923965, 0.05378223745332611, 0.09747891206174128, 0.26906353151125295, 0.372971959051586, 0.602690072790269, 0.4692404062276887, 0.04864812685897754, 0.02793193152624994, 0.056543513276283784, 0.0772999263098163, 0.0440013975716166, 0.03886160260486988, 0.13842137800830026, 0.1378347844846787, 0.0630165655316124, 0.5645827756774041, 9.810888209650594, 24.770469742436564, 30.460514868459395, 40.12924755773237, 45.95981943991877, 47.916658539925855, 51.28201684644146, 55.45709356184929, 45.45950935732934, 23.299300478350734, 10.631995220338146, 9.011854337107751, 3.374262331954895, 0.46172879155605073, 0.16590101313927483, 1.6425752471531592, 0.7750084359318979, 0.27434739314260026, 23.151552638699933, 80.60305180088167, 70.32712444182366, 75.15698202194707, 58.73588515866188, 56.27055391188591, 69.83774600490447, 53.027055801883826, 40.98401046568348, 49.164662591872684, 24.070487483855217, 8.498960310412992, 79.59057038830173, 64.40816587017429, 69.19989016748244, 54.35985757458595, 1.0026859059449167, 0.08585015702391825, 0.04165694252738068, 0.048269231262947285, 0.2915861181193783, 0.3790402027868456, 11.442876611986469, 53.83899819466376, 40.578492303048414, 37.84615355153238, 10.903723297580596, 7.680885782164912, 24.010020225278794, 72.7367070413405, 34.61534430903774, 35.6842960849885, 37.214126356186405, 35.58872753574003, 40.04699153284873, 44.981199849036436, 68.14462354106288, 80.82139445889382, 72.28673273517241, 53.06846818616314, 3.019155206218843, 0.2297232005625002, 0.2681319379518109, 0.20884603291990297, 0.18104430378204395, 0.1274163717584264, 0.2124515491267366, 0.4208644359342514, 0.4668379544971451, 4.34744184055636, 13.550938771617028, 27.19647530586489, 36.802932523912006, 45.421787923382176, 47.86841338680637, 53.54938214825046, 61.22321697973437, 62.3056342524867, 51.842488242733864, 36.70844262646091, 25.340580363427442, 19.146065481247444, 6.270441182198064, 3.8780719041824345, 2.0750674268891736, 2.7299277196007394, 1.103433822431872, 0.7431620383454908, 1.2771096320882922, 3.7708267040791053, 5.82951823549886, 8.36921516926058, 13.543710823981995, 17.135384005884973, 15.616605993240112, 12.186287353115699, 16.176010504845653, 24.191010152139974, 28.22495802756279, 36.474826258997766, 41.103007331971206, 43.42885909541961, 44.24585742335166, 45.76627792850618, 46.695805134311804, 46.19788769752749, 43.68389552639377, 41.995954513549805, 45.52883725012503, 47.925891799311486, 46.22930196023757, 51.83609870172317, 52.513699916101274, 49.16625899653281, 50.50446187296222, 50.73039039488762, 53.58884903692431, 55.19737774325956, 53.66857905541697, 50.45058419627529, 49.25686182514314, 49.934521875073834, 52.608840927000976, 52.336130296030355, 53.64135388405093, 47.58057417408113, 51.19392825711159, 51.9392256582937, 48.62717236241987, 50.63335880156487, 47.95208930969239, 51.87881331289969, 46.28710200709682, 53.18583726882935, 47.750146081370694, 49.09588775327129, 49.32173390542307, 50.31503100549021, 50.4900118612474, 53.11619166404971, 50.69499100408247, 45.943063074542636, 45.13896542210733, 47.02907323837281, 44.86155971404045, 45.324536677329775, 41.84789680665539, 46.64711283099267, 42.239533701250636, 36.26176703360773, 39.22897731104205, 40.06108068650769, 36.438889503479004, 38.85484987689603, 28.0635505337869, 10.708310815595812, 1.8091786556666898, 0.25904291760056253, 0.3524774829706838, 0.18631630637232335, 0.13284294024830864, 0.18844768555173952, 0.20909021578488812, 0.16312244288142652, 0.3442491164370891, 0.5671060241518483, 0.5897878038306391, 0.4561055529742472, 0.14632463214858887, 0.0872970902691445, 0.12837487032576916, 0.17242278092570845, 0.2686936949049273, 0.10346287846445076, 0.295309703797102, 0.4725083228080504, 0.1773457538576857, 1.0407018853772072, 11.373418300382554, 31.286666047188547, 37.39464167625674, 46.27975540776407, 48.64960047506517, 49.46772060086651, 52.47995184313867, 60.60540445389287, 54.96035283611667, 34.13928231885357, 15.66214765271833, 12.241034815388343, 4.352832157765666, 1.2717251984342453, 1.603599757917466, 2.8028399232895147, 1.4557049519592717, 0.46256584986563654, 21.739462114149525, 90.74657563240298, 75.9558746891637, 84.85836059816423, 68.91633418298537, 61.551029066885675, 86.63523350992511, 61.450247687678186, 58.001860649355, 60.886826669016195, 41.05360507965088, 15.687176296787879, 96.56097165999874, 77.05802932862314, 69.73505835379325, 76.37642337429908, 2.293622873483166, 0.3193702885220128, 0.2473485547929041, 0.20627626758669654], [0.021620577449099194, 0.0837569903101652, 2.153652358439661, 8.392704283037494, 2.895012435413176, 7.39184485327813, 6.332206255005253, 9.366762157409422, 11.469659536115586, 50.007077878521336, 13.89575041109516, 31.047856461617258, 54.565232876808416, 60.3200912475586, 26.302863282542077, 34.73960891846688, 37.39968584429833, 64.50016506256597, 50.349037954884196, 25.005894322549146, 1.6375228666490125, 0.19815143017518907, 0.18813522893094248, 0.05882301555585958, 0.008660135602939033, 0.10018015340451272, 0.021726289921770656, 0.0631940872558663, 0.6131091137086192, 7.06716085633924, 18.999047202448693, 31.298035037133005, 34.1963331930099, 32.5619266494628, 29.956178472888087, 36.12678650886782, 48.40172236965549, 54.83625296623477, 56.32913843277962, 46.69604832126249, 36.30406587354599, 23.25395787915876, 5.236904486533135, 9.32986540179099, 5.701192502052554, 7.190413984560198, 7.952733001401348, 8.464036506991233, 3.6391341061361375, 5.706313646608784, 8.06453133783033, 11.796542021536059, 12.17227174389747, 13.849190896557225, 9.15688495482168, 5.25636532614308, 5.971002540280742, 10.337654679052292, 16.024786464629635, 19.03807282447815, 22.464608338571367, 32.71999228385187, 40.50185311225153, 37.00051799897225, 39.28274516136416, 42.157650301533366, 43.6225143555672, 43.533449096064416, 44.71334903470932, 42.9828542278659, 44.599874865624216, 43.118144619849424, 42.80220162483954, 41.70534218511274, 40.37127740921513, 45.88030515178558, 45.7329652386327, 46.92686411642259, 45.9749754782646, 46.965613211354906, 44.60041615270799, 42.81479243309268, 44.1136186353622, 45.05640737472042, 46.21342028340986, 44.403995621588926, 46.50175763714699, 42.12269806092785, 46.17466334373721, 46.696177759478175, 44.26409644465293, 44.56339682302168, 41.31232853858702, 40.871493354920425, 40.799486483297045, 41.434545670786214, 42.3817039305164, 46.72673302312052, 43.20729224912582, 44.34788219390377, 43.01990885888377, 41.35794178132088, 40.54398721264255, 40.00426907693186, 38.48973997177617, 38.645650263755556, 38.22075951483942, 38.451465483634706, 36.61330553793138, 35.50735404414516, 34.5808352962617, 30.88041832370143, 28.806931857139837, 19.81857938151206, 1.0062518920148573, 0.4594513347312328, 0.1568151184267575, 0.02107486429233705, 0.05453266270999467, 0.10000566155799936, 0.10535467130642746, 0.13488241952032815, 0.5450680647646228, 1.7299759508140626, 3.0040923241646063, 2.2403632152465085, 3.029928731341516, 2.19677857333614, 0.15534476587368598, 0.015179411688398932, 0.017957286721455957, 0.01683993599257402, 0.0470528636698521, 0.17786548322727605, 3.002432180989173, 9.525281806145946, 5.756601373995505, 13.552996054772409, 24.331552597784228, 39.076165691498794, 39.40187538823774, 47.88758593220865, 53.12319309480729, 48.964382448504054, 45.92544378772859, 43.24697486815914, 31.933710036739228, 10.758404385659004, 16.455778460348807, 27.95546962368873, 12.840678922591671, 2.808265296682235, 1.2614628071746519, 2.7228547055875105, 0.3419341519474984, 0.1868307497352362, 33.13127240827007, 73.12950887987691, 61.89661341328775, 61.205966395716516, 36.19511811963974, 27.410560231054983, 29.291046473287768, 37.62093105623799, 70.86732895143571, 60.21841949032199, 40.91235660737561, 26.19082077856987, 50.934357566218225, 38.97348196275773, 60.522273740460804, 22.12549590295361, 0.35164940321157057, 0.11632886549998676, 0.07246607238607061, 0.0975495913336354, 0.10824553473221679, 0.022751516662538055, 3.5755037011638766, 13.282002441344723, 18.6268574191678, 16.425044728863625, 8.668095854020889, 6.351756328536618, 30.662397300043416, 66.721619021508, 24.125528143298244, 29.92922982861919, 47.87983925111833, 35.423874239767756, 29.07383934144051, 42.20536985704976, 47.37312786040768, 75.06532407576039, 62.5035099829397, 43.07894837471747, 8.78732414014878, 0.4163403496626885, 0.2854833697840091, 0.05872129440127362, 0.07288369755711287, 0.11255975121692305, 0.07788304945514088, 0.031067973731326002, 1.0089206359078808, 10.49687349027203, 20.251977751331946, 33.83310602557275, 36.24601479499571, 38.67022783525529, 40.1494046180479, 47.640233424402055, 56.28584723318777, 60.17970177435107, 60.2299512586286, 48.51198803993964, 38.122202119519635, 29.584522131950628, 10.27219424324651, 10.207399629777479, 5.291875033609329, 7.343390343650696, 8.952893268677498, 9.636145637881372, 3.934773687393435, 6.858207371927078, 10.962760852229211, 14.186571605743902, 16.952228930688676, 19.524903681970414, 14.84783418716923, 10.739988857699979, 13.217554957635942, 14.040292693722634, 17.88135213236655, 17.234596437023534, 22.95970755238687, 30.326059941322576, 41.54720790924565, 41.63411586515365, 39.98124868639054, 44.771380501408736, 44.76246103163689, 42.21538759046986, 44.73249020115022, 44.37571533264653, 47.0689441311744, 46.896873674085064, 45.211866594129994, 45.0789806150621, 43.5477892814144, 48.27679095729705, 46.374810126519975, 49.74873881186209, 48.27362168219782, 49.70031322971467, 47.09969551332536, 46.07885552990822, 46.21515397102603, 45.47256692763298, 47.10185281692013, 48.202889580880445, 48.743811884234034, 47.93626254604709, 48.17652733095231, 49.931152559095814, 46.43744645580169, 45.35159318677841, 44.98520458898237, 44.49573201517905, 44.150092755594564, 45.264724454572125, 46.429040816522416, 49.331633967738, 47.53756930751186, 49.71338256712883, 45.612481794049664, 44.45102091758482, 43.66599382892732, 42.67497954830047, 43.40111617119082, 44.41859076100011, 42.756105930574485, 41.66172150642642, 37.9501748085022, 36.90809519060197, 36.40841268724011, 30.65767868872612, 27.381622945108724, 14.161461572493277, 2.0176390246037514, 0.10116634605031821, 0.4095686227083207, 0.037265259231771194, 0.11581799210680109, 0.03236264508638171, 0.05551523559035794, 0.08270103003709547, 0.649171078637723, 2.4075718945072544, 4.627035250586848, 4.619805832062998, 6.334745499395556, 4.726878693026881, 0.14831834532801183, 0.08879519818771271, 0.06772512960578166, 0.011904583079740407, 0.12218346263492301, 0.3293395438982595, 3.942960409387466, 9.305514347168709, 6.383230407391825, 15.439233472270352, 30.807568142491004, 49.13482904434205, 51.04625886486423, 58.71857573909145, 64.0738034248352, 56.758645811388575, 56.85412414612309, 53.18722971024052, 46.18637554107174, 26.510372354138283, 25.265402255519746, 37.71597400788338, 21.96609470152086, 8.68211930797946, 5.383725666230725, 7.898133608602709, 0.9459870032245113, 0.621722761181093, 43.17826278748051, 76.006528177569, 67.84131450037803, 69.96938859262775, 54.1117480493361, 35.41933997984856, 33.785131515995154, 51.48238720432405, 82.72924315544867, 73.86958952872985, 51.898699729673325, 48.68988321673486, 65.5152234723491, 54.873374277545565, 69.6909709130564, 24.4852271387654, 0.3998246584688464, 0.14291627632994808, 0.1384241359248277, 0.08158400489558136, 0.3379028747158666, 0.27044969100144606, 5.361351976471563, 48.352057318533625, 41.93622073819561, 37.57176806849819, 49.819827848865145, 23.67456147747655, 62.99591256726173, 77.82613923472744, 25.804443782375706, 40.592785419956336, 70.02531374654463, 70.0921352448002, 37.55452140685051, 51.074417560331284, 51.44799586265318, 86.4167731808078, 73.91155104483329, 62.04782078343054, 14.91692771834712, 0.43107586702512163, 0.5342808726333803, 0.19064946821139706, 0.266751968452046, 0.16612967506291407, 0.2747125412908293, 0.1635103131974897, 1.5492904979375102, 11.981993644468247, 24.60280606823583, 38.4607458114624, 44.26608508633029, 46.50725680012857, 47.027155199358546, 51.59609671561949, 61.49392327954693, 61.75597683075936, 61.73528632810039, 55.254271722609005, 46.70911765867665, 38.21811191497311, 17.088419506626746, 11.34403778660682, 7.4147877770085495, 10.474844478791761, 10.531401134306385, 12.75115768755636, 6.040409370776146, 8.623333765614419, 13.22313060683589, 17.517736650282338, 19.440976727393366, 21.577987940080707, 18.048358809563425, 17.92094845925608, 18.299719979686124, 18.199291613794145, 27.636857455776585, 29.641935825347904, 32.280471094193, 37.52555862549813, 44.52147845299014, 44.715118023657034, 42.257760955441384, 44.36849817152947, 44.7974407288336, 43.422791188763036, 47.14991361864152, 48.68798086720128, 48.91117549711659, 48.45156000506494, 48.70653760048651, 45.687975652756236, 44.260515320685606, 51.94736065403108, 48.81207289234285, 53.11475215419647, 50.16017583108718, 54.481282388010335, 48.150525939080026, 47.423459714458836, 50.275583728667236, 50.01543252698837, 48.652518718473374, 49.65965001813827, 52.95433113651892, 49.36724124416229, 53.501662592734064, 53.16890047442529, 52.126667884088334, 49.21741847069033, 46.43206888629545, 48.66601559423631, 46.82998941790673, 49.65888515595467, 49.89737702954201, 53.93737516095562, 50.68036056333973, 50.822770057186005, 48.6997244434972, 47.8981057290108, 46.09856936239427, 46.81649254214379, 44.358837373795055, 44.258130519620835, 43.83707584873323, 43.95588051888251, 40.756909155076556, 36.643621536993216, 37.51818849194435, 34.19745106850901, 31.725167420602617, 28.635979275549616, 4.751762209400054, 0.571526964345286, 0.8214719749746785, 0.11766041824293715, 0.2695226633260327, 0.33574639849605104, 0.2061074677734606, 0.243750500282453, 0.8323843765162653, 2.501696276087915, 4.502371539992671, 4.439527815388096, 4.541175548107394, 3.3145493941922344, 0.2840267302047822, 0.4421087282319223, 0.16255538459987412, 0.1261863103436847, 0.22768937501936193, 0.4764457695907163, 5.602312982082368, 11.956904203661027, 7.509424763341104, 20.61530690039358, 36.96955480883199, 52.07826975853213, 55.65622445075743, 56.1700314091098, 60.77959299087525, 58.41380365433232, 61.82747771663051, 57.62967086607411, 57.18412491583056, 43.70795926740093, 36.48792305300313, 40.658414517679525, 21.606609475228097, 9.033053767296577, 5.933262965371532, 9.21093717698128, 1.4638643399361642, 0.4976047196936223, 46.89222958780105, 84.79881901894846, 76.78900180324432, 75.82146290809878, 57.61072974051199, 44.48380408748504, 41.661780341979, 48.51440814233596, 87.31287002563478, 83.41006463573825, 62.388109930099986, 61.06270966991302, 79.82817188385995, 57.50542194612565, 92.12089569337907, 40.1184610397585, 0.6836001118344646, 0.4160089093831278, 0.1631532242942241, 0.19967836598234795], [0.06947063795861698, 0.15524382612878276, 1.2037252730900243, 9.1392921440063, 15.287410290010515, 7.376311286803215, 20.568799357260428, 45.24221789452338, 53.03456714076381, 60.39307086698471, 21.026424246449626, 41.818985016115256, 47.366714785175944, 65.07143082157259, 29.368505439450665, 36.43433170933878, 34.39280863731138, 63.51858015983336, 54.554983723548155, 30.978081418621926, 3.0249473212226747, 0.12364123602427783, 0.1594384639493881, 0.02192880143411458, 0.08363715117617, 0.15595500087065084, 0.07980451288242495, 0.7236492886177955, 8.099587030949133, 19.221049431831606, 27.422607791039255, 47.7274198685923, 53.99809737359324, 40.81154777157692, 16.448245548432876, 20.512103457604688, 47.64041385342998, 63.54096512640677, 50.43088213089974, 59.49781340937461, 41.06872189429499, 19.59301760119777, 9.756824220380476, 16.833057518928282, 12.145393702291674, 16.372688931803552, 16.15376086004319, 17.774296922068444, 18.93231591870708, 22.28795066956551, 16.47973237499114, 10.521121582677289, 14.28714313814717, 20.975127489336078, 22.713386627935595, 10.413164227239548, 6.63419149575695, 10.833852156516045, 10.672041639204949, 9.783123712385855, 9.288621679429086, 16.250200175469924, 22.832397222518924, 35.495206463721495, 36.17156036438481, 41.34497834790138, 44.345724890309, 42.73527422258931, 44.633320916083555, 41.949525417820105, 45.09918082144953, 46.63107818172824, 41.42922301446238, 42.27492132494527, 42.978512164085146, 46.60455119225287, 44.190724588209584, 44.70016594856016, 45.300912241781916, 44.836346718572806, 46.48626819733651, 43.08858171586068, 43.07212345061764, 41.91432999026391, 42.5113029633799, 42.80812832616991, 43.232246368162095, 45.72166096779608, 42.70931205441875, 47.55479635730867, 41.135512013589185, 41.70780543358096, 39.29280211848598, 39.69994806474255, 40.166478695407996, 41.05163604982438, 42.88994112322408, 44.86812968407908, 44.886015692064845, 44.67484704909786, 41.49678584068052, 41.978068505564046, 41.10349370587257, 38.92419345917241, 40.62210905936457, 44.24418257128808, 38.44477784249091, 40.29392042467671, 39.215492202389626, 35.18988916950841, 32.688648623804895, 28.605600518565026, 16.738640185325377, 3.5335713576885963, 0.2861094168357311, 0.2699421730733687, 0.0855271360506454, 0.06729770617018785, 0.08069164269874174, 0.17697879774195535, 0.18722539226855003, 1.0738234822788546, 2.6350764737975214, 2.4121747959044675, 3.990596369389565, 5.149152730741809, 11.267104418047014, 11.38935390980013, 3.373966928451292, 0.42501519223855394, 0.019115370345271884, 0.708441585302353, 3.2317471792621, 10.229966986563898, 20.017537686132616, 19.402529654964326, 18.135847276256932, 28.471502527113888, 39.15805301358623, 51.95298141048801, 47.13062340213407, 52.300472028793834, 52.32916416660432, 45.14128746524934, 43.22841421250374, 39.70168959709906, 31.705194711685184, 18.222827796013124, 20.594237889012984, 31.740764725592832, 44.46498847776844, 29.508800775774066, 16.038123503808055, 9.401598688094847, 0.21132734574137196, 2.354151173945396, 50.07367187930692, 65.52347613919166, 59.222015873078384, 49.41166600873394, 27.80086548097672, 28.71132604537472, 15.862362096386573, 28.054878173335908, 34.78909354056082, 54.70041736479729, 51.091315131033625, 46.15765594667005, 34.87014147543138, 29.725354832987634, 59.96086097532704, 3.8535330660881537, 0.1748814635098942, 0.030799390965952512, 0.030086262699877544, 0.0840867835006887, 0.12301668284400818, 0.21890983886776433, 1.9407044303032661, 14.839877659274688, 30.856684061788748, 29.16841356985031, 44.825222876764116, 55.27347172460249, 72.55612111860707, 70.39781339706914, 29.036874924936605, 32.66108612860403, 49.49541645665323, 61.12445954353579, 26.430750200825354, 39.61300088513283, 44.89397810351464, 71.02325885526596, 65.6560444062756, 49.348598218733265, 13.36336220464399, 0.2968779470651381, 0.18724183251540508, 0.061988536824261954, 0.05032119010725329, 0.05653606690165978, 0.16390117125645762, 0.8599134089965975, 8.985714681686895, 21.401469515215968, 33.844178876569195, 53.00278809762771, 57.11096486737652, 49.79567389334402, 24.456876247159897, 26.725047596039314, 58.280882373932876, 67.28965666986281, 58.056503188225534, 59.95260438611431, 51.839954391602554, 33.05122075542327, 14.236114082797883, 20.246111846739247, 13.657130079884684, 17.08818808678658, 19.10088566041762, 21.599615889210856, 24.580940815710253, 28.584790383615804, 22.357672760563513, 15.983408401089331, 17.98049396084201, 25.962244656778154, 31.96969189951497, 21.035557485395863, 15.811974348560458, 20.139137045029674, 17.301323798394975, 16.198184644022298, 11.52892949119691, 12.64225406031455, 20.228569046143566, 32.7754859770498, 40.96783068872268, 43.41780193390385, 46.21514612628568, 41.87301958760908, 46.47403040239888, 45.775695539289906, 46.701869118598204, 51.092048614255845, 45.57485057461647, 44.58618187135266, 46.276523374742084, 48.582857424213046, 47.37852504176479, 48.1191469777015, 48.918102402840894, 46.19702477608958, 47.23223240144792, 45.119498698942124, 43.756106361266106, 44.31791528578728, 45.97286916548207, 44.788819359194854, 48.03075244349819, 47.112647179634344, 47.03126584329913, 49.652636820270175, 42.40877612944573, 42.83574965692336, 42.234120830412834, 42.14702067836639, 43.779354249277425, 43.75707518669867, 45.372942647626324, 46.745885956671934, 47.27868895376883, 47.529038152387066, 44.17613337116857, 43.3712237881076, 44.0236629978303, 42.86971738261562, 42.72679405827677, 45.92568697467927, 42.44246928922592, 41.68690704530285, 46.21897043720369, 37.87561055152647, 35.34588967600177, 31.133103293757287, 14.784213342974263, 2.1969099727369126, 0.17599964544417399, 0.18714702147389614, 0.051910202018916614, 0.04808360815889413, 0.14641549017640854, 0.1961944432508561, 0.37952384941520234, 1.1843119922184175, 3.8007521821606547, 4.454496560558196, 7.358445380964588, 13.666267241201094, 12.647576716638381, 13.085050429067305, 6.615178296642919, 1.455501233858447, 0.06951186114982252, 2.7607957922643234, 7.240718872316423, 13.580673279300814, 25.675609611695815, 25.99649871549299, 23.03151830550163, 38.866899398065385, 47.82620868375225, 61.2415736721408, 56.038981099282545, 61.85765251036614, 57.92788474790512, 53.14060841837237, 53.190755921025435, 51.05287198097476, 46.75179696852162, 37.208721330088956, 28.927121123959942, 43.651422223737164, 51.21294783007715, 43.427423507936545, 33.94079862102386, 16.682346328612297, 0.04423807660538343, 4.513918997779969, 61.282072144169966, 70.38019411025509, 69.76962227975169, 61.03595126059748, 42.000567220872455, 34.768803119659424, 20.76099353451883, 37.78633740640456, 44.56134542342156, 79.62700136246221, 79.07081711676814, 58.36188324036137, 58.0221785268476, 43.6031182350651, 66.0960715816867, 6.413463056087495, 0.15222334062620518, 0.105786093720986, 0.10326180336696487, 0.07806688757433046, 0.28913178691460245, 0.30822708001059873, 1.5439792410019906, 44.86799632349322, 75.24509414549797, 50.64408256161598, 71.22670435136365, 79.44672922934257, 92.79855574330976, 78.24716644902384, 31.517313180431245, 47.44988472230973, 51.98832981048092, 72.08736650405392, 39.059730960476784, 50.86137010205177, 46.95467764331449, 78.95120836073353, 79.11703048213836, 66.54934067879954, 23.81843793776728, 0.417226682747564, 0.2328771998685214, 0.14544785984100836, 0.2539144186002593, 0.2366243657325545, 0.2400121597513076, 0.9112077759158228, 10.459823762216876, 25.794908500486805, 39.2995289833315, 56.3767481619312, 62.41735904447494, 62.62220874909432, 33.06594925542032, 38.05052472699074, 64.01246540008053, 66.12716028767248, 58.83509758980044, 64.00997469502111, 53.08427533795757, 42.49924559747019, 27.324868209900398, 25.936786513174734, 16.164556203349946, 16.378479330770432, 20.981979870027114, 23.60178189892923, 26.63337003800177, 30.680361755432624, 27.81306012984245, 21.554834188953524, 24.573676586151127, 33.2315242675043, 35.596329089133974, 26.176817917054702, 24.411190440577847, 24.89032364660694, 21.020981957835538, 20.10942509097438, 22.28017260951381, 22.63038339153413, 28.50185186632218, 39.48522967676963, 44.63224618665634, 45.16809686537712, 47.12613228828677, 41.89835417655207, 47.57214107821065, 46.67759749197191, 49.08389314528435, 53.705398344224506, 46.5684183182255, 45.99242218079106, 48.93257987114691, 52.08151748103481, 50.385249276315015, 48.46650815779164, 53.14660964473602, 52.80769332762688, 50.862009448389855, 48.720120768393244, 46.77074986119425, 47.161692496268984, 47.57896207994031, 47.41700349315521, 50.48253974606914, 51.09549637763731, 50.55046343034314, 54.50707589426349, 46.094533243486964, 47.501420744003795, 45.86271724393291, 47.30398039663992, 47.971085348436915, 46.92488331948557, 48.96487666714577, 52.997877290171964, 49.633130873403246, 51.10334504035212, 46.92920969378564, 48.31093126727689, 48.48144454340781, 45.05069248137936, 45.85025979626564, 49.61838276155534, 45.286976060559674, 43.79150575207126, 46.75722945121027, 41.412239151616255, 34.55289233115412, 34.502603623174856, 24.429758940973592, 5.171671057901075, 0.4458020074713615, 0.375611377098868, 0.22103847545241156, 0.10768678850464283, 0.21696126358884, 0.338386889066427, 0.6330829870796973, 1.8252846430386267, 5.095413807899722, 6.721587296455138, 8.879323332540451, 14.850012083207409, 15.474667183814512, 15.770212873335808, 7.246815706453017, 1.0149631084453676, 0.2168381379376496, 2.7342859631584537, 6.202118887055305, 13.789935650364047, 30.950569914233302, 35.659757737190496, 29.86805065985649, 47.26125401835288, 51.224577657638065, 59.919503504230136, 54.77396180552822, 60.36118199748378, 58.85865534505537, 54.06421676758797, 61.07344127470448, 57.92069504337927, 56.60456334390948, 47.37121374376359, 38.315123896445, 46.24505027647942, 50.078264974778705, 44.128962947476296, 32.82266228429733, 21.546008856065814, 0.22872281230745778, 3.527885146679417, 64.55995375110258, 75.9327797735891, 77.29592892431444, 65.66350083197317, 48.335904998164025, 42.672528066942775, 26.109751270663356, 42.2034792746267, 51.78067953355851, 73.3979872734316, 72.29489126513081, 71.55691300669025, 60.82887364972023, 52.80830913974393, 92.56320568823045, 9.37459218886591, 0.23411530520646806, 0.21590288247792952, 0.4131290623016896, 0.18529281290548463], [0.06534376061491429, 0.035548241688839854, 0.09694987472387091, 9.750435659962317, 30.08052545209085, 16.983990323159002, 20.307296899057206, 49.965128129528416, 57.50827350924092, 69.04053211212158, 31.406400319068666, 45.16333118561776, 66.50773217601161, 66.70716116505285, 60.256886174601895, 37.93322624698762, 32.988337316820704, 62.94826361440844, 58.399565450606815, 31.620885326016335, 4.648020911601282, 0.9304186257143175, 0.21126175329329508, 0.06402021349077264, 0.060161034080890886, 0.20152489834975815, 0.3894162202073682, 4.8097480785462166, 16.54731873543032, 30.658274888992313, 41.00540307260329, 69.26203620049262, 58.280227338114095, 30.366064194710027, 13.680974168162193, 30.338325192851407, 55.65436524729575, 55.76301097869874, 53.644782035581535, 55.58848119551136, 29.981762132337018, 17.8194434027518, 20.925466360584384, 30.599892370162475, 24.841113590425064, 15.720844941754496, 22.423970622401086, 29.66153394791388, 32.37456679344177, 34.96993441735545, 44.13475628822081, 36.829361454133064, 31.03402618438967, 35.45652012671194, 37.56913615811256, 30.857272417314594, 12.919540136091172, 16.133640081651752, 21.303800536740212, 17.12169885635376, 8.989132046699524, 3.349961287552311, 9.239390050211261, 14.609204050033325, 24.705564322010165, 34.77580062804684, 39.83294387017527, 42.052377808478575, 44.66217387107111, 43.958402602903305, 42.057135643497595, 48.12273986877934, 44.17685508728028, 43.12394972770445, 42.16394178328976, 46.47192801198652, 46.33306041840584, 47.37683450022052, 44.801206204199026, 42.24815114851921, 43.01774371054865, 41.133868540486986, 42.38085669855918, 41.20355336896835, 41.86346077149914, 41.82108348415744, 43.97981482167398, 43.45426036465553, 44.162036372769265, 45.36032438278199, 40.81318732230894, 41.648036356895204, 39.688114273932676, 39.485339503134455, 41.98352844484391, 39.75360608869983, 40.90832441083847, 41.90306494312902, 44.2495640631645, 43.998159746969904, 41.58183067075668, 38.30717717447589, 40.811328118847264, 37.96355793553014, 39.91113631956039, 41.871599689606704, 39.94095417761034, 38.19394619234147, 39.8235184146512, 41.60133269525344, 33.46759996106548, 21.923187894205896, 6.340327032150761, 0.22108675431339975, 0.011607519080561977, 0.05139320375277631, 0.2010790198560684, 0.1207635263281484, 0.1834343142446972, 0.051341458343930786, 0.35986073194972934, 1.7648558727195187, 7.10983036025878, 8.505101761510296, 13.723007267521275, 32.686969849371145, 33.94468176749445, 28.066600176595873, 16.779597574664702, 6.540647870109928, 7.9372567995902035, 24.04582754258187, 39.85994938881167, 48.25887357034991, 40.25509680471113, 24.08122301101685, 28.844466978503814, 42.31177199271418, 50.00685038105134, 47.99050892553022, 50.54639201010428, 45.92664011063115, 42.031730451891505, 40.453141197081536, 41.14543953249532, 42.097092828442975, 37.576769090467884, 28.341101369550152, 23.848224416855846, 32.73732523764334, 42.981650060223, 40.26395351656022, 41.88273137615573, 14.89237956462368, 0.22636197447296114, 9.814403633917532, 62.95026794556649, 66.72460002283897, 58.05301620114235, 31.853929027434322, 29.90855109307074, 28.947548827817364, 21.2240057991397, 34.73860086933259, 21.449096895033314, 35.306473778140166, 14.252417414419114, 25.993653035932972, 22.398335972139915, 48.5786840223497, 39.96075037987002, 0.4871260771347631, 0.07135843182162893, 0.08071627242550736, 0.020804088600280306, 0.03551919546519076, 0.18590248099738554, 0.21557291308718346, 0.6845316134633557, 18.50990410773985, 41.87824026230843, 38.435066053944254, 59.065462312390736, 73.81210327148438, 67.90016574244346, 86.35216389932941, 41.85287429440407, 61.7466768910808, 73.24024523458174, 67.6867966498098, 58.329680581246656, 39.32305928199522, 37.456619047349506, 70.32674789428711, 67.85511339864424, 55.2402453268728, 22.812685351217947, 1.3072407894557523, 0.12084308455908492, 0.08291919655617207, 0.036622691493962085, 0.14067793595454386, 0.3401493509450267, 4.8943737053102065, 19.07881840582817, 37.73687631853166, 47.82759328042307, 71.12994732395296, 61.28182111247894, 42.17839963974492, 18.049478646247618, 38.25226791443364, 62.998493486835116, 64.66064099342593, 58.16631778593987, 62.813294856779045, 38.6277211096979, 25.715251045842326, 28.888283775698756, 34.85898625466132, 27.907995216308105, 17.786097372731856, 25.478534044757968, 33.899962825159875, 35.48055641112789, 40.091706552813136, 49.47334527969361, 51.24305202114967, 41.61065224678286, 40.62441933539606, 47.985241182388805, 40.53050994873047, 28.15921125873443, 33.06317221733832, 34.53123300306259, 27.452284443763, 16.318127782114093, 9.087720820980689, 4.844502239458023, 11.908402135295253, 24.645993325018114, 35.95973276322888, 41.45109415054321, 40.478687594013834, 45.670756447699766, 46.272989319216826, 45.08652725527364, 50.95702102107387, 49.06043344928373, 46.36281944090321, 45.17060325991723, 47.959282936588416, 49.4602131843567, 48.991893952892674, 48.80128245199881, 44.16681774200932, 47.045715855013945, 42.73093608117873, 44.97825414903703, 44.83516216278077, 47.67416977113294, 43.70713949203492, 47.30905202127273, 46.99997709643456, 46.39727354049683, 47.247000125146684, 43.83355356031849, 44.039662345763176, 41.517550868372766, 43.88567401516823, 43.46077934388192, 42.149217205662886, 42.33613383385443, 44.97836397540185, 47.94289135163831, 47.68754113105036, 44.986926509488015, 43.29970329038559, 43.86037472755679, 41.68846422626127, 41.87534163075109, 44.94830293040122, 43.27158774099043, 40.29517166076168, 41.30751579038559, 49.423994018185525, 34.90923573893886, 23.785080140636815, 5.113688620828814, 0.2433710109682814, 0.21040692174386597, 0.05268993779956814, 0.1266445534964723, 0.0954226631250593, 0.32570758233627967, 0.0753944741201497, 0.4928062820146161, 2.6888433435270866, 9.049798365562193, 10.535317620923443, 13.165890478318738, 32.95749964252595, 41.62763610962899, 34.368113394706484, 23.509466955738684, 9.184135621593846, 14.49722626516896, 36.48629919175179, 46.681774816205426, 52.867960545324514, 50.18294911230765, 34.157364445347945, 37.08355457552018, 53.26953280356623, 58.95662830721948, 56.58542217746858, 59.663721822923236, 52.320550641705914, 52.08841300779774, 50.47345553675006, 54.092132276104344, 54.47843474726523, 54.4203209107922, 47.136040195342034, 39.89386220132151, 41.73809789842175, 50.796611770506836, 47.61527538299561, 53.958202946570616, 19.414565447838076, 0.07187289816717948, 13.219186663627626, 71.85302842047908, 69.20474606175577, 64.89595182480352, 36.36258371414677, 36.66501022154285, 34.6354543009112, 27.228779946604085, 35.52094505679223, 30.43223850188717, 58.71372768955847, 22.828272850282733, 47.35270407892043, 29.623930185071885, 52.55779127920828, 48.55767973007695, 0.7126675714408198, 0.0962205743417144, 0.043064360957472556, 0.021425860881384824, 0.061973847088313876, 0.2233835012321511, 0.33252922757979364, 0.47036624904121127, 28.37981124078074, 87.82888135602398, 52.28358622520201, 65.91151622033888, 80.56229053005096, 82.63658108249788, 86.05781355211812, 47.04278192212505, 56.103519778097834, 72.0607336105839, 75.52645360269855, 71.56193364051082, 51.67365766340687, 48.02289985841321, 73.5794282728626, 81.72593224433162, 64.3841648870899, 41.10049309269075, 1.5252670837986855, 0.517070186474631, 0.36127250942011035, 0.16275939381411, 0.45995741241401245, 0.5355595040225214, 6.711712239250061, 25.970497323620705, 47.49847504400438, 57.63031413478237, 76.39256000518799, 68.68974670287102, 49.77947450453236, 25.77896014336617, 51.82815590212422, 63.57121444517567, 64.31441337831559, 60.01054171592959, 66.2146056082941, 45.93806989731328, 37.06321708617672, 44.58904912394863, 42.81995427223944, 34.73517271780199, 19.317171035274384, 26.854028855600667, 37.877438376026774, 39.237830100520966, 41.92816418986167, 50.211656939598825, 53.690873807476414, 44.37677045022288, 43.94188550210769, 50.60030498812276, 45.90945620690623, 34.50563169294788, 37.802164170049856, 36.394190172995295, 27.90023284573709, 16.462013067737704, 13.852276821290294, 16.140913136543766, 18.773693307753533, 33.03731595316241, 39.50836773841612, 40.27039404838316, 40.43862058270363, 49.36198919050155, 48.80960179913429, 49.209181493328465, 51.832949038474794, 51.12111729960288, 48.18046931297549, 48.50324899919572, 51.90600318293418, 53.668904612141276, 52.83231796756868, 51.539622429878484, 46.69866454216742, 49.506838398595015, 45.345219335248395, 47.57866397980721, 46.23946482135404, 50.66440828384892, 45.95546168665732, 51.29987932020619, 48.56668156962241, 50.842005360511045, 49.53673078167824, 46.43793282970306, 47.518357538407855, 45.90360795297931, 45.83948896777245, 46.00903734084099, 44.29808378219605, 46.50598202982257, 46.59389019012452, 51.343692195030954, 49.91233302700905, 47.598264063558275, 44.66066375855477, 46.93911367847074, 44.546048179749526, 46.08027935028077, 46.518894472429835, 45.82876520772135, 42.89227493347661, 45.030154951157115, 51.42614041605304, 36.56156947535854, 29.366424622074252, 8.565274842323797, 0.36948635092666077, 0.30940627318716823, 0.2581473608170786, 0.23720240971494108, 0.19762221663709612, 0.4340527008377737, 0.19763527077532586, 0.8980273251091281, 4.027507588748009, 10.813131255488242, 13.350872397422792, 17.539117490091634, 38.97823979777675, 42.551350362839244, 38.71442117998677, 26.212517369178038, 10.768567246775474, 17.019538764030703, 39.133679405335464, 49.88486074632215, 51.50598810565088, 56.392543546615116, 45.289145131264966, 43.69563910268968, 53.52211383081252, 58.41266224461218, 55.72925506099578, 62.60532686787268, 57.983386285843395, 57.09528715379777, 58.483323743266446, 59.98783119263188, 63.29099247532507, 64.97782737978044, 58.853666090196185, 48.567956339928415, 48.92271511016354, 57.25075421794769, 52.012617126587905, 63.727489517581084, 22.860828522712957, 0.3404253877459034, 12.179132949921394, 78.00913349274667, 75.97310958370086, 74.12172732814666, 45.00242379403884, 46.00185155868531, 45.92083108040595, 32.66072527054818, 50.86372352415516, 36.067648933779815, 58.00821488903415, 24.281952265770208, 46.08967342684346, 40.38201293637676, 73.72922358974334, 71.42548222695628, 0.7476492911096543, 0.1532562876180295, 0.14746651684324588, 0.18037823629715752, 0.27856351206860236], [0.009780851373028372, 0.12739132068330242, 0.1871990235221963, 1.3666178742724082, 42.830325018975046, 38.78916194362026, 16.380891588426408, 45.544158028018096, 71.01639470746441, 64.43456734380415, 47.81800700772194, 18.528268644886634, 35.70382556607647, 71.88073604337632, 74.37474373848208, 45.18606916550667, 34.113900661468506, 47.64989422213647, 65.58061722786196, 45.0731715848369, 10.70960617834522, 0.9520625094732932, 0.09711974706020086, 0.012122465188675111, 0.11673938903597095, 0.40619317802690696, 4.977815266578428, 22.568651168577134, 33.160360705467966, 39.71691623810799, 45.751949510266705, 62.68042848956201, 55.45932146810717, 31.081953625525202, 21.56669935872478, 36.236573649990945, 56.020420443627145, 57.83775260371547, 56.02301313031105, 55.186061705312426, 43.35656589077365, 26.336201467821677, 38.17313801857733, 45.11430548083398, 44.10975902311264, 33.722750140774636, 35.28744243806408, 44.10205156572404, 44.28998408779022, 50.159614932152536, 55.97623494363601, 56.76176409567557, 53.50414937542331, 52.35002725355087, 43.70235027805452, 34.00457243765555, 30.535818492212606, 33.535539334820164, 39.12233591079712, 39.73567693464218, 22.10158709556826, 10.459664906224898, 1.3932141180961364, 4.420795556037657, 13.854676331243208, 17.727555997910038, 39.515200507256296, 41.685008618139456, 41.44057435374106, 43.391486752417784, 46.60876381781794, 44.84277156091506, 46.211647372091974, 42.16347109886908, 43.36394386906778, 43.51828521297824, 43.68521344277167, 45.232172704512074, 46.11238787251134, 41.65002892094274, 42.09562193962836, 41.83022652902911, 40.41915385953842, 42.1641339794282, 42.42617576353012, 39.72001098817395, 43.60828399658204, 44.74473976319836, 42.98423097979638, 43.523505887677594, 40.68580442859281, 42.139077878767445, 40.160418633491766, 38.60482623500209, 39.41423477665071, 40.08581515281431, 40.70001909809728, 43.50601996144941, 41.8896504371397, 43.835224490011896, 40.53807620079287, 41.69002925196002, 38.11058013669906, 39.45332904015818, 41.9599824566995, 45.15879692569856, 41.23514413833618, 39.20066564313827, 36.0363523421749, 44.094983454673525, 35.20374690332721, 15.243618988221693, 0.4159889298100626, 0.2181703495162149, 0.03308234255640738, 0.14156471337041548, 0.15192419861353215, 0.11963294909125376, 0.09609299771968396, 0.3299020975828171, 1.123276970559551, 2.603786501192278, 7.801759992876361, 12.660523479984654, 13.745261815286453, 26.729032724134385, 45.66131138032483, 42.34186833904636, 32.40723817579208, 27.955983454181304, 39.16889444474251, 64.099930332553, 58.449430542607466, 61.65685069176459, 53.688108536504934, 46.62175863019882, 51.16418884646509, 51.70973170188166, 45.171215149664114, 42.47320105952602, 44.759546710598855, 42.482752030895604, 41.42299821299892, 38.150243143881525, 42.43262021772323, 42.53329961530624, 42.50999681411251, 38.86335357542961, 32.720476696568156, 32.40875809423385, 38.342003899235884, 42.355600557019635, 43.36259065135833, 14.913339730231995, 0.021931147578382687, 20.616995480752763, 65.88481272420576, 58.62861617918938, 39.342125923402854, 39.32652273485738, 37.48977484241609, 28.44250248324487, 17.297091560979045, 40.52248085698774, 30.97592607621224, 26.402864110085275, 32.38491400595635, 34.07878368131576, 43.21624702022922, 64.36573366965017, 9.562877724247596, 0.5394685749084719, 0.1497626662134163, 0.1814658819667755, 0.05340082908890421, 0.11137075211492278, 0.03840080454885479, 0.0911501907713471, 0.3946224311667104, 5.125427784458284, 55.5145876638351, 30.996145894450528, 34.61299480930452, 84.29319412477555, 94.10374010762861, 65.74141479307606, 24.023793628138883, 22.20919143769049, 46.10103261086249, 71.53726193212694, 72.39674737376552, 54.73440077997024, 31.677557691451046, 58.67211134203019, 74.90511094370197, 60.07401743242818, 39.29136260863274, 5.841051474694283, 0.14429187912854458, 0.10694224297279313, 0.21126146217988384, 0.6429219462217823, 7.964903135453501, 27.325889987330285, 39.987061638985914, 46.199307595529866, 51.42832909860919, 68.27022567872079, 63.10299327296596, 39.20309751264511, 27.093158114341, 46.47018255725984, 63.01533222198487, 63.047272082298036, 62.08371047050723, 61.73116391704929, 50.884272821487926, 32.28335403626965, 45.381050186772505, 52.56813456935268, 49.304526467477125, 35.83894729614258, 36.833848645610196, 46.610940733263575, 49.173170212776434, 55.58495890709662, 60.493232511704974, 59.63097787672474, 61.023227091758486, 59.16913447841522, 48.091145177041334, 40.061115987839244, 42.940163150910415, 47.093815880437056, 44.261566515891786, 45.78613688868862, 32.95629547488305, 14.234824603603734, 6.718523435054287, 2.4494588855774175, 11.817966988009792, 19.850046596219464, 36.66442186601701, 40.90191918034708, 46.40536931253249, 45.405812109670336, 47.987041550297896, 47.27221312061433, 48.44594317097818, 44.48385900066745, 46.18892115931357, 46.69064721753521, 46.140707385155466, 46.713828425253595, 49.25937998679377, 43.8264815268978, 43.746214143691525, 43.38741140980875, 44.078509499949796, 44.26959953000469, 44.7617510826357, 42.05575889156711, 47.43517975653372, 46.403282611600815, 47.73934779628631, 46.679421394102036, 43.62125919711205, 44.85991231856808, 43.84178661531018, 39.85323429107666, 41.91145097055743, 43.91148321090206, 45.36576078784081, 46.793111293546616, 46.976293825334125, 44.97055453638877, 44.19741615172356, 44.52785230452015, 41.55457804279943, 41.94293583593061, 45.73897823210686, 46.08512739981375, 42.01368754909885, 42.40871337152297, 38.73631192791847, 42.84339043401903, 34.412828414670884, 10.112486116347775, 0.4626279949180542, 0.11796377373919373, 0.19512945846203836, 0.29369788544793285, 0.2298528992480809, 0.17645539115032843, 0.08690151310856305, 0.3663944507077817, 1.6216668078014929, 3.9083374027282964, 7.739498740242374, 19.5408873404226, 18.941098105522897, 38.165183451867875, 51.993009198096495, 48.23919111682523, 37.71018066713887, 35.637921902441214, 51.18551477309197, 67.7765404793524, 63.88569831848145, 66.37965894514515, 63.43493561590872, 55.59221136954523, 62.42842012836088, 59.08734521558208, 52.59896439890708, 52.16887650951263, 54.379696922917525, 52.34351611906483, 50.88296667222054, 49.936283019281205, 52.77942088342483, 52.08333353842459, 53.0525629751144, 51.232657740193034, 50.76376584268386, 51.09502961558681, 50.979496202161236, 59.47930374453145, 54.67465523750552, 16.324959570361724, 0.20596610922967235, 27.43475929383309, 73.3092632601338, 61.75053258096019, 43.5999724941869, 48.131290635754986, 43.288030316752774, 34.97347631762105, 21.08684639776907, 35.93231147335422, 37.14077018922375, 20.934748649597168, 36.37375462439753, 51.83383157176357, 45.606343284729995, 75.49796150576684, 11.621900450798774, 0.4168317797443559, 0.085404577304519, 0.07631960955839004, 0.06091632782631825, 0.09504534950059268, 0.15376403537248412, 0.20924769281860323, 0.4310039160472732, 3.2992291065954396, 87.3513484770252, 74.20576018671836, 40.13853965267059, 76.88191490788614, 90.94260784887499, 76.58868635854414, 64.59844789197369, 27.20398468355979, 44.27589493413126, 79.32672823629072, 78.71309695705291, 67.58138687379899, 45.98285551994078, 62.145919261440156, 86.84191888378513, 66.9968125127977, 56.404702894149295, 8.029880629431817, 0.3256967038877549, 0.13218315468440134, 0.409397907675274, 0.6217050492282837, 10.867235449052627, 31.877606414979507, 45.15630229826897, 52.74070708982406, 60.733073680631584, 71.65186574382167, 71.36884320166804, 54.0807613249748, 41.25942753207299, 55.71361264874859, 60.565133479333696, 63.9690016162011, 60.56313307054582, 64.20868981269099, 57.45621973468412, 42.89483231882895, 51.99989688011908, 53.23867551742062, 48.761356646014804, 39.924229191195586, 37.85224107003982, 50.12125807423746, 51.17645409799392, 59.38944224388369, 58.35712540534235, 59.07581736964565, 58.42028733222716, 58.86799843080583, 53.771615797473544, 45.414245205540816, 50.405159227309696, 51.81050915871897, 50.6312289545613, 50.31389351814024, 31.61282289412714, 15.075442464120927, 9.458035711319217, 12.870711530408553, 15.376759921350788, 25.237545582555956, 41.40146047838273, 40.66792234297722, 47.4806635610519, 48.2009558523855, 49.881514964565156, 48.29702646501603, 49.493914188877234, 46.38906794209635, 49.79756839813725, 50.13353901524698, 49.146619689080026, 49.86357012102681, 51.003438349693056, 46.798033868112874, 47.4140146470839, 46.81891656691029, 47.59209025290705, 47.165399136081824, 48.37552093690442, 44.98579294450822, 49.968014993975245, 51.0891656721792, 50.349022265403505, 49.43077187384329, 47.803980611985736, 47.92952391409105, 47.94635480450046, 45.7959153575282, 46.131489815250525, 45.852056241804554, 46.9859310888475, 47.88589931303456, 48.719905038033765, 49.65027947579661, 48.2014500710272, 47.823878795869895, 42.97344446182252, 43.96417240942679, 49.729546654608946, 48.205831358509684, 45.715396942630896, 46.311467770607244, 41.3680693411058, 44.841751744670255, 40.718905310476984, 15.468820891072674, 1.1320004443968497, 0.27793412487353053, 0.1934385491955665, 0.4955902761749683, 0.2524456595100703, 0.31581420030805374, 0.1899301269722562, 0.5097740570143346, 3.3376259236566486, 6.973022011018569, 13.828785746328293, 22.343516926611624, 24.46195963890322, 39.27099766269807, 54.634803956554784, 47.11383565779656, 39.137531172844675, 35.9726373610958, 52.92255601575298, 71.11559929386263, 66.26093664476949, 67.10870988907354, 65.97112840221774, 59.2151281910558, 60.22255759085379, 60.26737851481284, 52.214540743058734, 56.91745473492531, 57.325083132713075, 57.75546519987045, 54.23411423160184, 52.527926352716264, 59.91061541341967, 57.32578523697392, 61.962948537641964, 57.28002294417351, 58.3536188064083, 57.80948800425376, 60.042822822447754, 67.516126478872, 59.341836437102295, 18.959754859247518, 0.3117395012128738, 26.893609493009507, 79.23601950368574, 72.70895235000118, 49.87176787468695, 58.81905117342549, 58.06680725466821, 48.63594670449534, 23.277590159446966, 59.22667957121327, 43.958665401704856, 40.5066187920109, 55.713189032769975, 61.484191879149414, 71.23808706960371, 117.15595676052956, 15.975919615837837, 0.5165281026594101, 0.27157967068975974, 0.25846715656019026, 0.1902527112754122, 0.2160745627817608], [0.21082355100060665, 0.12889224014455272, 0.254485429895501, 0.48601626088061645, 22.665680800714803, 71.3879608338879, 46.8262121754308, 24.85834260140696, 42.388066014935895, 59.02751730334375, 82.92245911013696, 60.568200772808446, 45.18853633634506, 55.111987744608236, 69.83920512660858, 51.56421176848873, 36.783493257338, 33.98171678666146, 63.42758117183563, 52.91080851708689, 35.48808736185874, 3.479990555394081, 0.12777163737243222, 0.051063364596977356, 0.16553235630835259, 2.2614229109979447, 10.555296213396135, 33.75333286100818, 42.71152819356611, 53.987530508349025, 57.335901029648326, 33.01132632840064, 28.368128461222497, 44.69358813378119, 46.69354584909255, 51.92723497267693, 55.13986010705271, 53.35394613204464, 55.16929749519595, 56.183708713900664, 53.038163954211825, 43.70765332252749, 49.00961914370137, 53.29254142699703, 50.23532059884841, 52.285064958756976, 59.00821139735561, 57.4357920308267, 56.157087587541156, 58.56439521235805, 57.15669578121555, 57.22601975164106, 56.83435540045462, 52.69224228397493, 46.155204465312345, 39.95175246269473, 47.92814716216057, 51.89888408107143, 51.784562680029104, 51.91457748413087, 48.13279682590116, 26.26831308487923, 8.544248977015096, 2.8659540462878446, 5.9568570025505565, 16.129300959648624, 24.85551457251272, 39.566940492199315, 40.49898193728539, 40.41085804662397, 43.99802246401387, 50.33327787153183, 43.8880862728242, 43.91672349745228, 41.65692444770567, 44.58754685617263, 43.89114964392878, 45.92788742434594, 44.56724074579055, 44.07227685374599, 42.143765111123365, 44.272070623213246, 44.58402064538772, 39.48591216917961, 39.86444442502914, 43.03100916647142, 44.65498808891543, 45.44549865107383, 43.997583158554576, 43.35596576813729, 40.67162898279006, 42.01773543511668, 41.535060328821984, 38.23088707462434, 41.07178918776974, 41.34505679530483, 42.163051405260646, 44.852142103256725, 42.57471199958555, 42.80104060326853, 39.57460088114585, 40.94078202401438, 38.59987620384463, 41.62281159431704, 41.08288949535739, 44.40836121959072, 38.993960657427394, 39.006614223603286, 39.75241761053763, 36.27129054838611, 19.639036809244466, 3.229036576324894, 0.1930292743828989, 0.051043316075998935, 0.2624093530879867, 0.30668420957461484, 0.7971904811359222, 1.830553734494794, 1.8521704068106992, 2.4992129254725675, 5.442665161625032, 6.6595672695867485, 7.079658998597053, 21.847492033435454, 21.0511940140878, 41.133782248343195, 54.70190786546277, 56.54493155017976, 55.451398280359086, 51.781973915715376, 56.67491105294997, 60.12632223867602, 57.79954479586694, 56.09994649887086, 55.51642333307574, 53.806254248465265, 55.02878642851307, 48.86970427728469, 42.2896812039037, 41.563815224555235, 41.983363705296675, 40.27010379299041, 40.302526104834776, 38.83355140686035, 38.29208781642299, 41.059822036374, 43.07895229708764, 42.05304461140787, 43.57229232788087, 45.63445098938481, 42.92840388513381, 50.74445993669572, 48.744827778108665, 13.666625157479318, 0.668842745644431, 34.94464297448435, 68.18787943932318, 46.722869488500784, 52.35599317858296, 43.66094966088572, 24.687694003505094, 39.98599083192887, 23.477183888035437, 42.00178315562587, 42.1237688679849, 86.3154975829586, 48.67343671860234, 41.34027934843495, 60.53025576376147, 34.52724003022717, 0.6116871319470868, 0.02829499208488532, 0.06482416148027105, 0.05846488860345656, 0.10561702577697654, 0.060496025177980625, 0.03301743575702271, 0.08398094079307011, 0.06208725874462436, 0.5761571997596372, 37.83471592010991, 68.77363051137617, 24.422845763544885, 31.841804981231693, 73.12263688733502, 81.51903506248229, 61.757067249667266, 36.92626360924014, 37.538898606454175, 66.95073250801333, 63.73575395153415, 63.09158702050487, 36.17512972124162, 39.88154595898044, 74.73326406171246, 60.8089990000571, 61.07406885393205, 21.27606349606668, 0.18758911549323992, 0.04058148914707765, 0.15414016922154736, 2.619192345488456, 15.188898982540255, 42.58209782262003, 54.61032444430936, 62.23148184437906, 64.26636434370472, 40.11158120247626, 43.371392450025006, 54.66500620688162, 55.86898557601437, 59.69899962025305, 63.058611654466205, 60.29720421760314, 57.89158713433051, 63.811086993063654, 60.74086743016397, 49.779466659792014, 59.76893548042544, 61.67345016233383, 55.67646388084658, 58.06362229008829, 62.28905831613849, 63.928856157487445, 59.899750448042354, 62.02426695054578, 61.79367865285566, 62.877998275141564, 59.028611644621826, 54.05404998410133, 52.535998590530895, 47.843118021565104, 50.92839164118613, 54.73179632617582, 55.51816878780242, 52.383728258071415, 50.11343686811386, 42.00052799717073, 11.55746473420051, 4.906705146835697, 1.3206220778726763, 14.06535271675356, 28.90839965112748, 40.307178035859145, 43.26244861848893, 43.589574290860085, 45.288058634727236, 53.307493502093905, 46.598412682933194, 47.73658252531483, 43.779369938758116, 44.9685384381202, 46.470778757526034, 49.798898081625666, 47.37353186453543, 47.65955109750071, 44.739275901548325, 46.5293554336794, 45.34714914137318, 43.55064084452968, 43.77743621026316, 46.235232583938114, 45.622958444779925, 45.94732276854977, 45.730627506009995, 47.57403166063371, 43.651504593510786, 46.26742347594231, 41.09954387910905, 42.773113327641646, 40.87582365159066, 42.207640909379535, 43.766124094686205, 48.43808274115286, 45.72688556486561, 45.98660922819569, 43.84225729973086, 43.016594456088164, 40.051772902088786, 44.81059635839155, 46.47201038176014, 44.0864013087365, 39.756010501615464, 43.352600374529445, 40.15998325040264, 38.27478231922273, 17.655529514435802, 4.518259590671909, 0.5957553836126482, 0.08054111408249987, 0.45866686069676954, 0.5087553439361434, 0.9065201758377014, 1.9288162166072478, 1.7131386865531246, 2.854400214649016, 6.474507883671792, 8.025392457362145, 17.509984085636756, 28.685699239853893, 36.93537135278025, 48.358403713472434, 58.179336132541785, 59.15462170877765, 61.63676423411216, 58.66651804216447, 64.87032698046777, 65.85250808346656, 63.60048709377166, 63.07862750945553, 61.22404067747055, 63.52231425623741, 59.72651896938201, 53.612908855561294, 49.929454172811205, 50.74485217371295, 49.33760381514027, 49.668240008815644, 47.76451372331189, 45.35114995894894, 48.10818003069971, 49.734520219987445, 53.29034097733037, 51.53230720950712, 56.505115570560584, 56.10812071830996, 61.158078178282715, 60.29429381893527, 56.715201639360004, 15.931854728729496, 1.448964971688486, 41.875110210910925, 75.10361425338253, 51.8034920384807, 62.83202417435185, 56.62814071101528, 30.351118003168416, 46.26164582467849, 27.545146557592577, 42.994166343442856, 44.28027229924356, 97.34906996450117, 66.71092664041828, 46.59594158972464, 74.92961006779825, 44.98993104504001, 0.5372281048086383, 0.04867341925179766, 0.023773372616438616, 0.1069312496110797, 0.07292700450747244, 0.02289170883746157, 0.3661666774461347, 0.21355424076318744, 0.45290324416372085, 0.9429339896286688, 35.87430746324601, 108.47525735055248, 71.74397868494835, 39.66314838778588, 63.183464619421194, 75.60534815634452, 92.80309000322896, 76.23470029523297, 54.39826934568344, 65.5767850722036, 74.12408075025006, 73.83857927014752, 51.8936594840019, 46.27864929937547, 81.30033939115464, 69.22523652353595, 75.06310401424285, 29.72291707992554, 0.3035255677757725, 0.15205074101686478, 0.3712710599985815, 4.076536725605688, 26.37491918379261, 47.8534613117095, 56.9392042775308, 66.22937725436303, 74.23156153771185, 46.97434048498831, 52.654516927657596, 60.746750985422445, 62.95619464689686, 58.62340727160054, 60.190507904175796, 60.3941495187821, 59.58012042507049, 59.83962835804109, 60.67526578903199, 54.70770512857745, 59.808649478420136, 57.33606184682539, 53.357644927117136, 55.020474926117934, 64.35004418896091, 66.22299163572251, 63.12055764659759, 61.54369423466345, 63.75736228881344, 65.40332609607329, 60.89438507633825, 56.717500148280976, 57.63716259310323, 53.28133521541473, 58.84875920511062, 63.06527576138897, 60.50554483167587, 56.62921151807232, 56.913520597642474, 45.52740166264196, 12.044582905307895, 5.669992008516866, 9.46833977776189, 18.21461239168721, 29.041628837585453, 38.64701132620535, 45.35515469889487, 44.528864276024606, 49.22239988080917, 56.57136832514117, 47.190678811842396, 50.57961840783396, 46.80978528914913, 49.21042096230292, 48.997314668470814, 53.23374509811402, 48.22742792867845, 49.6674673018917, 47.24725507920789, 50.446842255130896, 49.3444993419032, 44.709159943365286, 45.55774904066517, 46.958537255564046, 50.24134535943308, 50.797949298735595, 50.997539104953894, 49.391418733904445, 47.270389218484205, 49.17387623940745, 46.23218097994405, 44.913205562099336, 43.80801108575637, 45.71686390907534, 46.81497458488711, 50.16589856916859, 49.29811339224539, 48.445190075905096, 47.0809583510122, 47.397324962000695, 41.616174943985484, 47.461930321108916, 49.89379198320451, 47.40544819062757, 41.46745827890212, 45.10825718602827, 43.58837012321719, 42.97652744477795, 22.275569708116596, 5.594153961827678, 0.7116071218925138, 0.3855038398215848, 1.013395631265256, 1.0145445180035408, 1.1408007721747122, 3.21528204987126, 3.1493644127922678, 2.8333196813060395, 10.037079530377543, 10.83270094087047, 24.160743182705296, 40.05776236134191, 45.06764104289394, 54.01166485201929, 60.23359906288886, 63.27343594643378, 59.56414461135865, 57.09140400732718, 62.76770122589604, 65.61946830441876, 64.74705473069223, 61.98411364709178, 61.19525440277592, 58.91972664863833, 57.63122020229217, 57.29627724616759, 54.672168454816266, 55.04002794142693, 52.60010188625705, 53.54064310750654, 53.44600808235907, 52.02097569742511, 53.95156629623906, 57.448186720571215, 60.20497360537129, 58.777630944405836, 63.76705838787941, 63.3421637165931, 66.0140940450853, 67.21775177986392, 65.57827557286909, 18.90341393409237, 1.6629906936037926, 40.34778241188296, 84.12854086968207, 57.27162514963458, 74.51515674591064, 60.608597263213134, 42.177854430290964, 59.438875875165394, 32.27741949019894, 54.331722413339925, 65.34298043097219, 124.72575464556296, 77.78750388853013, 73.61986790933918, 94.09577769617881, 59.77886692170174, 0.995615772422283, 0.34742393801289223, 0.1568812164928644, 0.2275201155533714, 0.13644245032581592, 0.15714848924788738], [0.052582892333908435, 0.03851559516342898, 0.03179869712180188, 0.07814155816431008, 0.2887713885115039, 55.583170306298044, 75.40004345678514, 53.33073354536488, 25.951707209310225, 26.924876666838124, 43.61930193439607, 72.95831311133601, 57.69597461146694, 26.867557110324984, 42.37498491041122, 50.125760955195275, 41.445041933367335, 21.723011693646832, 48.992301879390595, 59.08430537869854, 52.114543837885705, 30.783847608873923, 0.6550147973241345, 0.048774190457357515, 0.4926455261245851, 8.342981376955587, 12.591874157228778, 38.477121706931825, 62.620863376125214, 67.77894096989786, 55.08473119428081, 31.35322866901275, 33.16069018456244, 50.17335499486616, 60.04515663270028, 53.248359849376065, 51.383374814064275, 47.87774862781648, 53.23791849997736, 50.53626445031936, 57.041385942889804, 55.16213916963147, 57.647254851556596, 56.261242205096835, 58.844095506975734, 60.041857919385365, 57.889610259763664, 59.85531783873036, 61.28941089876237, 59.100944072969504, 61.571641122141195, 58.65721418011574, 61.503890022154785, 61.23806315083658, 57.45509009207449, 53.15814925778297, 53.76431626658286, 58.369724058335834, 61.48327012215892, 56.51954204805436, 49.28718174657514, 45.34907110275761, 28.445397192432036, 9.552176517824973, 1.4007595325669935, 6.932729953719724, 24.425065825062415, 39.140010110793575, 40.78141612391318, 41.42233533243979, 42.99139715010121, 45.89690462235482, 44.7743889593309, 44.21379989193332, 40.45802847031624, 43.26040506362916, 44.06188257278935, 45.3494123489626, 43.63122986209008, 42.361695920267415, 42.58441202102169, 43.05957186606623, 40.91992678180818, 41.812838662055235, 39.7172692514235, 42.85469078248547, 42.951447809896166, 43.08458482065509, 41.40733618890086, 44.67219944923155, 43.13473624567832, 41.438342525113015, 38.95066945783554, 40.65832038079539, 40.06887835841025, 39.67136967566706, 39.50451204853673, 42.570142438334805, 41.73137103357623, 42.7492182485519, 41.20145097855599, 40.173935121105565, 39.19804549986316, 43.21597245431716, 44.96292160403344, 38.7997680325662, 39.61638196822136, 39.05902885621594, 34.54918176897111, 27.014069403371504, 9.311489097533688, 3.6102448692244873, 0.5226230368979516, 2.8828550490640827, 3.271185385604059, 3.311239649211207, 3.2880444680490806, 5.099405800142597, 5.987950611499048, 11.518272411438728, 21.522051019053308, 21.929659804990216, 18.152513427119104, 19.80894015681359, 41.810489162322014, 48.113891001670595, 52.88028071003576, 52.02673373683807, 53.006251550489864, 51.96439158531928, 58.14095574040567, 58.133628752923784, 56.24285021135884, 53.928961676936, 53.67059515368555, 48.343534008149184, 44.86097528088478, 41.187197085349794, 39.248565627682595, 40.082940055478005, 38.6427398650877, 38.61842509238951, 36.67706366508238, 39.156801777501265, 43.913009012899096, 43.197925629154334, 42.181329650263635, 43.58394176729264, 47.81987405592396, 47.35216279183665, 54.170273734677224, 55.61283519191127, 55.01463451693135, 12.821480881783271, 2.4997983392207854, 44.87159705931141, 65.99668656626056, 48.26929530789776, 40.101587003277196, 23.409181756357995, 22.646286641397786, 51.94549752819923, 40.35858461933751, 18.5970179880819, 45.72811718909971, 52.33164310455323, 25.700791228202085, 29.751440555818622, 61.350764612997736, 9.157344852724384, 0.6083836995305554, 0.11394339027784525, 0.2501035448644431, 0.07054180507698367, 0.08801066286621556, 0.038092274128669695, 0.02242598483609336, 0.05847189447752411, 0.03779434636535664, 0.08985782342572367, 1.3738042692984305, 73.6868227681806, 69.30060878876718, 31.316456448647287, 28.063048470404844, 37.151352743948664, 62.668892798885224, 72.28407336819556, 46.851566376224646, 30.711897611618046, 43.05058179363128, 65.87412818785637, 51.846477293199115, 26.092600707084905, 60.39814249161751, 65.87376732980051, 64.33848104169293, 51.56632200364144, 2.030588852301721, 0.03840518657178168, 1.0344721809510262, 12.271791100502016, 22.011029374214914, 53.37348738024312, 69.89613440728957, 74.65345951818651, 62.03387283509778, 38.029069362148164, 36.57946332808464, 59.486869996593846, 67.52648938086726, 60.35466694062757, 57.2059097597676, 56.227192109630955, 58.439181389347205, 58.158618173291615, 64.92446353358608, 65.05500393529093, 64.28866694050451, 62.62591538890716, 64.4655187668339, 65.94511524323495, 63.35264036732336, 64.59796936281266, 66.5059357304727, 64.96923738910307, 64.32830641346594, 60.20513442254836, 61.799271952721384, 64.65998987997732, 61.07369230639551, 58.473070667636016, 56.86650314638692, 59.111146157787694, 61.90052401634955, 59.714128202007664, 49.60246186102591, 44.924454919753536, 36.17748706571518, 20.303694202053933, 5.489440896818715, 6.221941565313648, 22.113775860878732, 38.47698442397579, 43.357985788776034, 42.55050313088202, 46.55518031889393, 48.39166541253367, 46.5580318820092, 45.81829247936126, 42.62426330197243, 44.71505918810445, 46.716805504214385, 48.945715888854004, 47.16986279333792, 44.68052664110738, 46.276574365554325, 45.08166743863014, 44.761935434033795, 43.65975333798317, 41.71594435168851, 44.525087033548665, 47.45192827716951, 47.01605489177089, 44.620486920879735, 46.4640244360893, 44.689497101691465, 43.20839835751442, 41.15263315939134, 42.556272937405495, 42.56553757575251, 41.8781735820155, 43.133351649007494, 44.66393109290831, 46.32026172453358, 46.80296820978965, 43.387454555880645, 42.874824308579974, 41.899750540333415, 48.44233066804948, 45.988205632855816, 40.56266946177329, 40.55222419000442, 40.2652596658276, 35.48466313269831, 28.651164731671734, 10.462140902396172, 5.640509513116652, 3.3417061692284, 5.9381016992753555, 3.9450966302425634, 3.4636323105904365, 5.39989318578474, 6.713107622438862, 8.124062620824384, 14.086219726070283, 27.466807019325998, 37.78250917311638, 30.421053863340813, 33.67011585543233, 49.261682418084916, 54.09525448276151, 57.67083221866239, 57.241203246578095, 55.975776026325846, 54.81744520125851, 61.54294113959036, 62.8720009711481, 60.23053176941411, 56.14813281643776, 59.27542678771481, 56.14964685132427, 52.02634542219101, 49.40421742777671, 46.949213781664454, 44.505690913046564, 46.59198391822077, 45.32155175362864, 46.365216009078495, 48.002550601959236, 51.731398874713534, 49.759588087758715, 52.005537248426876, 51.14831501437772, 58.211499567954775, 58.70628695334158, 65.01396809854816, 62.06944088782034, 66.80666385158416, 13.936261630827381, 3.6253312854997577, 49.28309071448542, 72.89143669989802, 52.21853763826432, 55.22220634645032, 30.8516183207112, 24.529089043217322, 64.82490201150218, 36.85390764667142, 24.093388242106286, 57.496302435475016, 60.24415808339273, 36.30605059285318, 37.0688731439652, 78.77999690271194, 8.739296678573854, 0.5097769375049299, 0.13023726071321196, 0.03522630089954023, 0.05460912211527748, 0.055423569339778156, 0.03308199398640183, 0.16402274941004094, 0.09205268065054571, 0.1381696415163817, 0.19217663384493322, 0.5252371127566984, 81.00365131132065, 101.58057781957812, 74.80131718420213, 39.440306771186094, 39.81142182503977, 56.080213054533935, 84.49530601501465, 66.25299776754072, 37.18874862117153, 51.20882541902604, 71.52221572014594, 60.12382761124642, 33.796863325180546, 64.30177550162038, 76.39533704326999, 70.854338061425, 57.45318382017074, 1.5281057766368313, 0.296432941911682, 1.3865672941169431, 15.608733796304273, 35.257738328749134, 58.86666874731741, 72.21690670136483, 79.82373960556524, 71.06223937003844, 49.41025787784208, 47.946982383728034, 59.86196625617243, 65.1737968383297, 58.959224916273556, 55.04961421412807, 55.60442170789165, 58.68098766573014, 56.74625504401423, 61.92958093458607, 60.9761861062819, 61.97717889662712, 59.844358736468905, 64.37150347617366, 65.88916655509703, 63.81806096723003, 65.01897304288804, 67.63908493903376, 62.279683851426654, 63.94909950994677, 58.09512676731233, 62.509879912099535, 64.46645229093491, 65.73670010412893, 62.007945968258774, 60.944999341041814, 64.43163733328542, 68.41594173062232, 65.73859853129234, 53.32123356480753, 53.61981614943474, 41.37194464283605, 20.48371530348255, 6.751942519218692, 13.198995282573085, 26.91895192669284, 39.14214388016732, 44.82175550153179, 45.510535470901004, 47.757669187361195, 49.28906056188768, 49.57445613799557, 46.75178127904093, 46.19426734985844, 48.42663726499004, 50.033785297024636, 50.080814515390706, 49.79938445552703, 47.8115233298271, 48.7535079833, 48.502578273896255, 47.53591406729914, 45.76714869468443, 43.39580135960733, 49.319502076795025, 48.69887328916981, 50.287692085389175, 48.758822794883486, 51.549459734270656, 49.734520219987445, 46.437430766321, 45.27060016509026, 45.79979065925845, 46.46859007496988, 46.08258178157192, 45.49008031045237, 49.2769443604254, 50.52552500078755, 49.79965117669875, 50.29215574264527, 47.14595202476748, 45.53481494226764, 51.511224469830914, 49.592106803770996, 40.04844673218266, 43.20139300438666, 42.25481917781215, 40.12208530979772, 31.801483015860285, 13.164389191135285, 7.588272248545001, 4.111961121520689, 8.166827732516873, 5.217605934989068, 4.995003092673517, 9.735092328440759, 9.656255629754837, 9.370907122089017, 12.499506262040908, 27.941711910309333, 41.4346751090019, 38.45502699575117, 43.06595748470676, 54.89583376915225, 55.76330907883183, 59.098410221838186, 58.39319552144697, 58.3397767620702, 54.54908447880899, 61.757620303861565, 62.10167492589643, 62.964961144231985, 57.19259723540276, 60.63768556041103, 57.50916780964021, 57.028191089630134, 53.0672836303711, 48.80309850938859, 49.57960621003182, 52.630045260152514, 52.15561497596003, 50.14511785199566, 50.68414172818584, 55.93285745190036, 52.72237785400883, 53.21335269558815, 56.32100343704224, 66.29307654596144, 62.430369546336514, 71.26022492685627, 71.60292240881151, 71.35441672417426, 17.13193428131842, 3.664175743056882, 53.149539655254735, 77.68982118175876, 60.065694162922526, 59.570232129866085, 34.18042798196116, 34.02186224537511, 70.82865438153668, 54.12267969500635, 28.272740341001942, 70.08062701071464, 63.515014725346724, 41.983402928998395, 53.69396855754238, 94.78073335463002, 15.302879137377586, 0.998175364107855, 0.4397936411682637, 0.38389202147241563, 0.34495204807289187, 0.2116375653854301, 0.13996492260165755], [0.05804267456574787, 0.07099115394897039, 0.02135419718650801, 0.10014250018303433, 0.4898798261438647, 7.850557709893874, 77.73349285125732, 57.99178800275249, 37.26299908853347, 30.664511457566295, 36.83012631631667, 54.18866180604505, 57.947837844971694, 38.71116169037358, 18.475018547427272, 22.560198460855794, 41.89599290970833, 24.314994312101796, 32.28517205484452, 51.055445055807795, 56.37235902970838, 64.00266731939008, 10.362549962535983, 0.3850951472357396, 4.859299380933085, 16.097012988982662, 18.431509656290856, 51.25963187986805, 65.99880464615362, 54.6471280436362, 59.90480638319447, 45.980200075334125, 45.805234909057624, 52.87395392694781, 48.289530815616736, 44.79590708209623, 45.45531634361514, 48.16183413228681, 46.95701537593719, 46.22979617887928, 48.52148409812681, 55.44232191578035, 54.550559289993785, 58.31068846487231, 55.00522867325814, 57.11448323342108, 57.19368373194049, 57.61007862706339, 57.53703232734435, 54.846251087804, 58.918012572873025, 57.59114534624162, 55.441737482624674, 59.102638536883944, 60.21988253439627, 61.7749571800232, 58.67383718490601, 60.23592110603087, 57.07078018496114, 59.27869804443852, 52.87377742029006, 43.66607619870094, 36.64721442807105, 38.801007501540646, 11.102102072008195, 1.8220643771271554, 13.43131628728682, 33.51194627823369, 40.16804372110675, 37.7022143333189, 41.98156725975775, 40.23308054093392, 45.89199773726925, 44.312863273005334, 43.164534491877404, 41.31436032633628, 43.06627127432054, 44.4397323362289, 44.4312168705848, 43.588126936266505, 41.92120982754616, 40.321871234524636, 40.34573101228283, 39.87699993195073, 40.444868918388124, 42.10151726199735, 43.44712165094192, 41.627745935993815, 40.41248190787531, 42.149417246541674, 42.48291677044284, 42.78093061139507, 40.22039951816682, 38.87492848980812, 41.39616920102028, 39.25693596563032, 40.49856224367696, 42.54743583740727, 44.77101964335288, 38.71560181340864, 38.67746853059338, 39.02067592067104, 41.82262105326499, 43.06662821000622, 41.287978464557284, 37.982000920080374, 37.43621487771311, 35.93591613154258, 28.494826901343565, 19.640170374224265, 7.125914529446633, 1.6400480150215089, 12.205330460302292, 7.8563137881217475, 6.896933913230897, 8.907227073946308, 8.970942055025409, 11.372513213465291, 20.270834545935354, 28.27367582628804, 25.314157316761634, 30.127185967660722, 29.53732817403732, 36.55790990398776, 44.82066508262388, 47.68104960841518, 51.964858347369784, 56.52988533819876, 54.53577195444415, 53.6701480034859, 58.219128577939934, 54.12692369953279, 53.141765517573205, 47.00962220468829, 46.16484957356607, 43.45131858702629, 41.60814585224275, 38.317720505499075, 36.63439219997775, 34.615544349916526, 36.93157842082363, 39.27709694831602, 40.48739525579637, 43.027612393902196, 41.383982396894886, 43.29702823392807, 47.863388830615634, 46.77379362044796, 53.76460259960544, 55.348530200219926, 61.24687671661378, 57.17937100318171, 61.8511688324713, 10.986961876192401, 4.130529376768297, 46.227658487135365, 63.06281643529093, 45.29461683765535, 33.19058649001583, 14.93465388974836, 25.124959830314886, 58.63462917266354, 58.60158712633195, 24.392294422272716, 46.010241508483894, 30.38149872133809, 35.55884691976732, 57.32756207066198, 45.129332080964126, 0.14496096499985264, 0.02529422185503908, 0.05844711153317363, 0.08118654315870616, 0.08417475337703383, 0.015141896362746916, 0.032377943862229586, 0.023400483149734717, 0.06040986709957642, 0.08524089495861724, 0.07128554621651288, 0.4568568707233476, 19.2510732143156, 95.17266442698818, 61.21188132993637, 26.890204875699936, 19.960265198061546, 36.606664965229655, 76.71621830232682, 66.17186746289654, 27.488158441358998, 26.76058623098558, 33.812588107201364, 56.256982511089696, 31.665945514555904, 39.24059929386262, 54.52706821503178, 63.097223466442486, 72.94672642984699, 16.172343088734536, 0.6105531992450838, 6.47370477837901, 26.741764737713723, 39.394313058545514, 65.60975651587209, 77.07155366097727, 65.7988618266198, 67.71038578402612, 54.13667078941099, 55.780842073502086, 62.8598298565034, 53.52648335118448, 52.052558622052594, 51.102921424373505, 54.629092985583895, 52.38409303849744, 53.42918503669001, 53.4225130850269, 62.122224223229196, 60.84231561230075, 63.50924491882325, 59.152072168165645, 63.32431300993889, 62.768191522167584, 63.856170715824256, 59.986058281313994, 58.77492843135711, 61.740102998672, 61.194289499713534, 58.63355052086615, 59.476550240670484, 62.07051953961773, 60.436126724366225, 59.70251406392744, 61.25039116028817, 59.53567997101815, 59.994985595826186, 58.92835586301742, 48.37774099842195, 41.805331245545425, 41.97940211142264, 21.843840306805028, 9.086095979136806, 14.64351204133803, 33.52692188755159, 41.5000335631832, 42.3791818464956, 41.864327615307225, 40.40326433797037, 46.07005765361171, 47.16099823674848, 43.52778127116542, 44.114964008331306, 46.48200065858903, 47.383063224054155, 46.99204998631632, 46.03264216453799, 43.87984145072199, 43.28627701728575, 42.95795502201204, 42.68385587200042, 44.3466035012276, 45.58018107568064, 44.95785390177081, 46.037839305016306, 44.0848284382974, 46.6976329588121, 43.49871258581839, 45.55470920378163, 41.51289109260806, 40.37089301693825, 43.18339717003607, 40.081120075718054, 43.228425979614265, 43.74586505274619, 44.46489434088431, 41.811661951003536, 40.3494062731343, 42.00291672060567, 45.44987209381596, 46.88254133347542, 43.16012182543355, 39.81022550213722, 40.04772109370078, 38.331146778598914, 30.193364197208037, 19.297463086343583, 7.610450310091819, 4.49364181487791, 22.548615701736946, 9.820120488443683, 9.651581145101979, 12.214902024115286, 12.264771038486112, 15.268769225766583, 26.371573402035622, 35.11798820187969, 30.708783249701227, 36.3010181919221, 39.453619295550936, 48.40034954009518, 50.83926754613077, 51.766574690418864, 55.16968973221318, 58.66687497785015, 58.634723309547674, 56.97338381121236, 62.987177448887984, 58.581912517547615, 56.98259745874713, 51.97675881847259, 52.52676140877509, 49.28331428958524, 50.33246986327633, 46.06576265827302, 43.90304227029124, 43.1888767211668, 45.545534779948575, 47.858768278552645, 49.90562185164421, 50.26195349231843, 50.153590171567856, 50.614943273605846, 54.605668590914824, 54.91286077807027, 60.649515428850734, 60.96478769856115, 67.82112213873094, 64.14378635344967, 62.982094057144664, 10.348833434043392, 5.7440154687050855, 51.274372146975615, 67.17842609651628, 50.17462584280199, 43.228425979614265, 16.592482866779452, 32.11217003483927, 67.77941949905889, 50.50674077003233, 25.433562109547278, 54.96375353105607, 42.3456455815223, 35.906145341934696, 64.42101947722897, 47.726627549817486, 0.16917594708502295, 0.13536540731307, 0.05194216703755721, 0.1532620639209786, 0.029611326491219864, 0.044401008185119405, 0.038267129866947094, 0.0965769278005727, 0.24313249715393592, 0.13877819111991313, 0.2840373328616542, 0.6487401082150398, 12.210508969522293, 112.70455298885223, 74.90312622439477, 55.50726459872339, 41.18389052729453, 49.03340047405612, 72.5611888208697, 72.34889445766326, 52.82791706823534, 29.404138211281072, 40.366370524129565, 61.143890965369444, 37.870358497865745, 45.745787466726, 65.11320798627793, 69.04189709694155, 83.5127365973688, 14.68321034985204, 0.4150420451356519, 6.99592718193608, 30.693460510623073, 53.63614497646209, 72.56727633937713, 77.85121102486887, 71.38077505173223, 70.58974281434091, 60.891584504035215, 58.78698187489664, 62.705468900742076, 55.23750359012235, 57.38155349608391, 54.626382627794825, 56.093109807660504, 51.57159366915303, 53.23561999105638, 53.36047295601138, 59.91958979637393, 59.26208288438859, 63.39127963589084, 55.99033586440548, 63.85272687481296, 62.140643673558394, 65.25026736720916, 60.94954536807153, 59.12083833448349, 65.14059005245086, 63.89230358985163, 60.427305313848684, 60.89882912174348, 63.28309282179802, 64.71406759754305, 61.95837897639122, 64.56072253565635, 64.1407935850082, 68.06536812936106, 64.21299265277001, 48.96842641215171, 43.40992189222767, 49.825801618637584, 21.499107114730343, 11.145520748630648, 21.42708847599645, 36.40283507685508, 43.24373499039681, 44.60033770530455, 44.1849704711668, 40.63693169624575, 48.22024214652277, 49.25783849531605, 45.8408147288907, 46.81317421697801, 48.860176840136134, 50.18802465931062, 52.05142113470262, 48.81982349580335, 46.4315785900239, 46.99843168258668, 45.45910535320159, 45.6167846341287, 48.85264981177546, 49.45395700393185, 50.3328424884427, 49.555883715229655, 48.64423075029927, 49.0058889696675, 49.26705606522099, 49.035887256745376, 45.368871227387466, 42.29290539218534, 46.460812014918176, 44.017163630454775, 46.589622651377034, 48.16539172203311, 50.56079495337702, 45.50009412150229, 44.136184030963534, 43.539866093666326, 48.03087011460335, 50.561850070953376, 45.6897367969636, 40.328558875668435, 40.76860174056023, 42.21153582296064, 33.096684948090584, 22.841281390959217, 11.695118354212854, 8.01177006575369, 21.210399097011937, 15.081377010191641, 12.017763699254683, 16.00786732089135, 20.12222574603173, 20.406003344443537, 26.306095315564065, 32.849361858060284, 34.3865014660743, 42.77389780167611, 47.35009962512601, 52.38068842118787, 53.23533758040398, 56.31703792079803, 57.75981118602138, 62.60051019730107, 58.99827603370913, 57.035074849282545, 62.52964473539784, 58.559041177072835, 58.62268947785901, 53.029966200551684, 54.74395567371, 52.897805859965665, 56.030202834836906, 50.07934362657609, 49.63685320269678, 45.29031791994649, 49.22617320091494, 51.162004086279104, 53.555854059034786, 54.03312021686185, 52.7349215938199, 54.31176147153301, 58.26085475183303, 58.638037712343284, 64.98145949456, 65.31442165374756, 72.75183954546529, 68.69586560033983, 77.05351860292497, 13.262199374937243, 5.4666308433778825, 55.846541773888376, 76.28080383423837, 58.57379321129092, 46.35745756087765, 20.870408050475582, 38.61320049531999, 75.73551593288299, 74.38432216644287, 34.27315281283471, 66.35805453023603, 45.85580602768929, 60.75900839221094, 85.25160958690029, 64.65037222831481, 0.17001731080874322, 0.1304103506188239, 0.21240809661967142, 0.171983536753443, 0.2439570222650805, 0.14627351876228087, 0.08364652043148395], [0.06889971093304696, 0.1686287458024679, 0.10286428034305574, 0.10592628015025009, 0.08873437846740408, 0.940768289710245, 25.40182621248307, 79.52585912519886, 50.107753353734175, 28.472330147220244, 33.51850840353197, 42.65448124177995, 46.29746490909208, 51.76937918509207, 47.267945581866854, 40.58414051609655, 47.25056163726315, 20.141153143298244, 24.597938406851984, 40.346401737582305, 53.35717816506663, 63.75072956085206, 30.464199935236287, 1.1128364791793208, 5.937694263073706, 21.849641492289884, 36.16894414347988, 61.84950182514807, 68.6718136264432, 52.57642253752678, 55.87434353366975, 54.07865501219227, 51.97830815469065, 45.52287916983328, 43.46779646412019, 40.94738337301439, 43.68091452506281, 44.15526636185185, 44.35412268484793, 43.765461214127086, 44.20992459020307, 48.05107816573113, 52.414840498278224, 52.886823223483184, 55.9313787183454, 55.0905284573955, 56.78007371963994, 55.93468919877083, 55.52479367102347, 59.01512261359923, 60.454295143004394, 60.259180761152706, 60.32773594702444, 63.05150431971397, 61.72821429467971, 62.74614780179916, 63.518223224147675, 59.63229971547281, 59.095542969242224, 55.68491658856792, 59.99675066240373, 54.8474984015188, 49.702105752883426, 38.939533848916334, 29.91111240079326, 18.12991665255639, 11.22657358646393, 30.430112577253777, 35.061164825193345, 39.942119121551514, 37.25049065005395, 40.94750888885991, 45.342877680255526, 44.13918464414535, 42.86784248967325, 41.67326504184354, 42.83245878834879, 43.99836371021886, 44.13576041498492, 43.45798661631923, 40.653633148439475, 38.51474900399485, 38.083033330978886, 37.09254464795513, 39.21181694153817, 40.71383368584418, 40.59197741170084, 42.97843763905187, 42.441567144086285, 42.20925692589053, 40.38248754316761, 42.90921172788067, 39.49260765506376, 38.862051348532404, 39.90928888320923, 40.024747771601525, 41.965340414354884, 42.316643576468195, 39.001891689915816, 39.05799335049045, 39.656864750769834, 41.11780251226118, 39.90764148773686, 44.7188913437628, 40.0075364112854, 38.254091816563765, 35.68903823052683, 31.040817768343036, 24.50552344322205, 14.569190971312986, 4.983921416344182, 12.197877956974892, 21.151467446357977, 8.30278100505952, 10.457676264547533, 14.981741943667013, 13.66004930388543, 16.652940319430446, 35.82334410759711, 34.67479567373953, 23.794968435841223, 25.939704756582938, 33.56652213681129, 45.62164837314237, 50.45883686311784, 48.616393689186346, 52.88659572601319, 51.586133895381806, 55.06057331638952, 50.40117409921462, 56.55405890557074, 54.5359484611019, 50.43242362237746, 44.347854737312566, 40.68388638957855, 41.048600135311005, 39.50996806544643, 36.8120716464135, 37.079126219595636, 38.793413792887044, 44.183017130820986, 48.489155923166585, 50.289527754629816, 49.08315966206212, 53.177706195462136, 54.855170557575846, 54.52470694818805, 55.24168483672604, 58.16110887835103, 60.52266205510786, 63.94972708917434, 62.284245567937056, 48.626878184656945, 4.346093525809627, 6.994806364659341, 48.91969880750103, 58.23661058179794, 41.91867989878501, 23.7370938639487, 22.665094406374042, 29.56699698202072, 62.41971638894851, 71.18715901528635, 40.918793216828384, 47.13285915313229, 30.490211133034002, 45.581436234135786, 72.78770569832095, 8.913457758965032, 0.3663166161746748, 0.19449578117459052, 0.07752946157368922, 0.08956235097420794, 0.07339220373861252, 0.056260194809686755, 0.04682191880419851, 0.1278386547440483, 0.09251200398730655, 0.007018087903082732, 0.10372432895124921, 0.08928878863732662, 0.09786973947719221, 44.38930242292343, 87.43454194838002, 48.02592008344589, 26.884952822039207, 29.602547384077507, 38.33988581934283, 64.14854418846869, 34.55147635552191, 42.30337027580508, 49.6544607224003, 57.19733545857092, 29.965225419690533, 30.427564997826856, 46.343929306153335, 56.96375439243933, 73.4448988206925, 36.28366562627977, 0.6189692573201272, 7.820515296151561, 35.196710171238074, 54.63666708238664, 71.19573331648304, 72.35646463209584, 61.27294871114916, 65.69927677031487, 62.94639656620642, 60.90947835676132, 54.27429106927688, 51.46450511870846, 50.34762197925199, 52.28515125090077, 51.793831240746286, 50.40762639814808, 49.49792677356351, 50.58472533379832, 52.32855619922761, 59.37600028130316, 58.03196484042753, 60.83876586729481, 60.38190387910413, 60.5347704118298, 59.300333838309015, 60.736819544146144, 62.04489861765216, 62.859955372348914, 63.35071448356875, 63.73397319547592, 61.78688903008739, 62.1093313924728, 62.20957540696668, 63.10300896244665, 62.61688217040032, 64.42241976338049, 61.27602777173443, 59.93668740795505, 52.83609128767445, 51.4785825052569, 42.949612140655525, 37.312817112092056, 28.794068444159727, 16.245312902235217, 30.398111920202936, 35.50737365599602, 40.72022714922505, 40.04922336147678, 41.73235554848948, 46.55422718294206, 47.05952652039067, 45.56857478234076, 42.58459637241979, 45.495830505124985, 47.52953237102878, 47.6034455145559, 46.59747131409184, 44.220954295127626, 41.744452138100904, 42.84176657276769, 40.33220275755852, 43.93410351968581, 43.656874318276685, 43.71829471280498, 46.5275276091791, 44.545087199057306, 43.942999455236624, 44.123808953069876, 46.22825076503139, 43.64116130336639, 41.63052297407582, 40.60162251995456, 42.737831607941665, 45.581671576346125, 45.30245765562981, 42.577202704644975, 42.24359335437898, 43.29577307547293, 43.44285018982426, 45.57103803080898, 48.031380022725756, 40.26651090191257, 39.10908222198486, 37.85027596258348, 32.939794063568115, 26.661262012297108, 17.2521843448762, 7.2584283736444295, 23.207289518848544, 21.894903682893325, 11.45766688931373, 15.709948597415803, 17.86001051625898, 16.53516919382157, 27.815841090294626, 46.35828518098401, 40.68655752366589, 30.60052779413039, 37.941580895454656, 46.88800127275529, 53.00338822026407, 55.24704279438142, 50.66606744643181, 58.13051831337714, 57.1730246082429, 58.09370294693978, 53.34822339396323, 59.31075557585686, 58.022002020189845, 54.79672724200834, 49.57213801722373, 46.51710194926108, 45.65664768218995, 45.135611795610004, 43.09132345261113, 44.93471584012432, 47.40844095906904, 52.50364688134963, 58.36350710161271, 59.896381132064334, 59.84983828759963, 61.74764179414319, 62.28333950042725, 61.873985259763664, 65.02361712917205, 65.2470588684082, 68.93888781147619, 68.71304558169457, 71.94887545800978, 50.75044547357867, 2.7343244514157696, 7.367297680147233, 56.35980352278679, 60.02149689582087, 52.60008619677637, 24.48374644402535, 18.481810131380637, 42.11549658929148, 69.23687027346703, 68.8383339297387, 35.661040352236846, 54.46644406164847, 34.298157922683224, 48.73969731792327, 80.44927135590585, 6.209124730479333, 0.36370753520919435, 0.22044749990586313, 0.09991279637981808, 0.06141946756190831, 0.10084676481182538, 0.08706780015340737, 0.036969633562670606, 0.26754214218066585, 0.23812309418234134, 0.18197162257086846, 0.275437903981055, 0.1920866951226227, 1.3000600328368526, 39.673530901632006, 109.8831529002036, 66.09807199047458, 41.27010422368204, 45.346286219935266, 51.746802022380216, 60.282558087379705, 58.9940869423651, 65.60779140841576, 48.70481960235104, 68.065093563449, 30.09671111260691, 38.42227128244216, 56.79712818514917, 66.29103691347184, 82.24162194036668, 37.13946403995637, 1.3148568065897113, 11.807308927659067, 42.900962983408284, 64.76260692842546, 72.3772845729705, 77.01448317497008, 67.7239179611206, 66.87802745449927, 61.21253636575515, 58.322820355815274, 54.5856370464448, 55.166665584810325, 52.88479928047427, 53.76211581691619, 52.89382465424077, 54.02429880634431, 50.69849760301652, 51.52960469645839, 55.716256326244725, 61.5950890510313, 58.72538497371059, 62.615493651359316, 60.45073363088793, 60.50265796722905, 60.34221341533046, 62.25453753625194, 61.902579338319846, 64.50279305058142, 62.211768011893, 64.45001363754272, 62.805544253318544, 64.86118001322593, 65.29733188690679, 69.32896752511301, 64.51115162141862, 68.45667946723201, 65.32458451486403, 67.43163078061997, 57.544386771417436, 53.93662206588253, 43.04602007712088, 41.35351734776651, 29.10451227618802, 21.271252709050334, 34.87141232336722, 38.841831530294115, 46.431504064990634, 40.389849831981046, 42.56062676829677, 46.639754464549405, 50.31803554104221, 47.29018149837371, 45.8000809146512, 47.63267893945017, 51.38796398716589, 49.533530127617624, 49.3616008758545, 46.81202104014736, 44.99890935036444, 44.416209882305516, 43.84166894420501, 44.975226079264, 48.42775121811898, 46.55784360824093, 49.3434363795865, 50.69520281207178, 47.15828003421907, 47.72895743769985, 51.21784687042237, 46.04026725215297, 43.92720799292288, 44.41389568390385, 46.42420061172978, 47.50986560698479, 49.254696676808024, 44.45539043795678, 45.40761247757943, 47.337995190774244, 47.36774244616109, 50.522649903451246, 51.010820250357355, 40.90582193866853, 40.29214359098866, 41.544564231749504, 35.31415377893756, 28.528321981430057, 21.80686608437569, 11.653589279420915, 23.167285265461093, 30.498467722246726, 13.900363118417802, 18.331683374220326, 23.823737059870076, 23.494014778444846, 31.697561779329856, 44.91615910683909, 42.66529913871519, 36.13082262777513, 42.40395945887412, 49.969713380259854, 57.4869671944649, 56.89730159697994, 52.77983665466309, 58.984277094564135, 57.958051696900405, 58.57439333392728, 55.99040254469841, 61.601608030257694, 60.508867079211825, 57.20614117960776, 53.2575499626898, 49.623489687519694, 50.06261471779116, 49.44743017996512, 46.98262060842207, 48.210412686870946, 50.854074493531265, 55.94423232540008, 61.62248680668493, 62.66395453483828, 61.58352590376332, 65.43610142123315, 64.68801129248835, 62.662824892228656, 66.0184008075345, 69.2573921142086, 70.48583922847625, 72.74762691990023, 76.6112478317753, 62.274992696700565, 5.25646387569366, 7.646341958353597, 61.91926510103288, 70.35052530227169, 60.11521408634802, 32.03435805536086, 32.66001139917682, 43.33166276254962, 82.00093746185303, 83.98322489953811, 56.81237051563879, 66.36413420400312, 46.53063412635557, 71.91679831474059, 101.41540681162189, 13.320961383081253, 0.6142260699022202, 0.47536218418709697, 0.24669468342777223, 0.2307867451060203, 0.25699839747000125, 0.1986549031590262, 0.2161714116171483], [0.033812968270672907, 0.03620573664985357, 0.03576788675761031, 0.01851974081458344, 0.04229348498366533, 0.06271659231354153, 0.1554227842678947, 54.51120615005494, 68.83912624851351, 43.745888586967226, 39.411194939767164, 44.75851512724354, 56.568795250308135, 59.083046297873224, 137.9591412698069, 55.441235419242616, 41.75951011719243, 32.1803290613236, 11.778234358756773, 37.108512616926625, 49.48300215505785, 67.58643888658094, 50.41379628642913, 1.1244316182790266, 2.4114594536442913, 21.783074948095507, 39.56015479180121, 62.923368330924745, 63.76878423075523, 53.33610327013078, 56.71734717584426, 55.832852701986994, 49.63300143518756, 47.28353308093163, 46.00361662526285, 48.042382271059104, 48.04364135188442, 49.99734647812382, 44.22997182415378, 44.52457320305609, 45.281445518616714, 43.300950604100386, 45.583009104574884, 48.49866374846428, 50.48914109506915, 49.376607864133774, 48.2437292991146, 49.38648831459784, 50.71972547038909, 56.55980517787319, 56.319756123327444, 58.44814400519095, 58.324193185375584, 59.276964356822354, 60.640423374791304, 62.20853990124118, 61.759781529826505, 60.6062359963694, 59.03504433170442, 57.7248550230457, 57.78700497842605, 48.94665725769536, 54.34940445807673, 53.3442461106085, 43.70712380255423, 33.25509378986974, 13.166916178118798, 20.179723770387714, 34.84142580339986, 32.11068149535887, 38.94786496316233, 41.64047010483281, 38.83132742297265, 41.90205297162456, 42.408423116130216, 43.865693461510446, 41.59559819006151, 42.71783928717337, 42.256792130008826, 43.78659886698569, 40.96095085144043, 37.493544240151685, 37.719229575126406, 37.6986292869814, 38.74342710741105, 41.3442527094195, 43.52509052522721, 43.567930652249245, 41.399440457743985, 44.437496585230676, 39.50657521524737, 43.68492318737892, 41.11697881452499, 40.68661243684831, 40.12930247091478, 41.12469803902411, 41.86295870811709, 42.122207764656316, 41.87989942489132, 38.2812895313386, 39.68509797127017, 42.49311885526104, 44.03703435774773, 43.495421717243815, 36.18641830259754, 34.45231099282542, 28.286552967563754, 26.816683969190045, 28.73251468904557, 12.54980085357543, 7.1549086897603935, 21.09119630629017, 10.187903488835982, 12.150233907084312, 16.39159377544157, 14.187368827481425, 14.003604804315875, 24.79905793743749, 36.67005438958445, 29.951852098588024, 26.977434465962073, 36.49224158256285, 44.5848443431239, 49.37268941633163, 47.11058401292371, 46.47841953462171, 54.08825305200393, 55.21359282155191, 55.524636776216575, 49.15412710558984, 53.68897538031302, 53.026451756877286, 47.969214377864716, 42.86726982362809, 39.136162265654534, 38.31717137367495, 37.75204020161783, 38.10662638756537, 40.208785380086596, 47.215315218894716, 51.45043165453019, 53.19870264299455, 55.81702986071187, 55.25563278505879, 55.122523230891076, 58.613424839512, 60.40052337031211, 61.2541840922448, 63.41145630805724, 67.50791303573116, 64.2576253029608, 72.80155166502922, 31.607470820027014, 0.10051052882185868, 8.509916470896814, 48.9330348660869, 57.559950736261186, 30.47059339861716, 31.629571414762932, 31.01082144245025, 33.47277356732276, 69.10316451903313, 65.03581962277813, 36.739790208878055, 52.15324978674612, 46.28155577567316, 59.39083076292469, 49.43526298769059, 0.06349747722607947, 0.23339627040249689, 0.07491730859563236, 0.021965234660573547, 0.09892638156851453, 0.11110634452873662, 0.07932242141255448, 0.045110692885974725, 0.08137472499642642, 0.03287350698824852, 0.0624475384040946, 0.050699216193489494, 0.071674044724674, 0.13413413547940795, 0.6780539416978437, 79.00141469893917, 72.99464994861235, 35.537211125896825, 35.82366574195124, 42.21552879579606, 51.9057168499116, 58.60234806614538, 122.56900018261327, 65.05652581491779, 39.485680749339444, 35.25997407974736, 16.3229013066138, 43.74149553237423, 54.55233612368184, 75.09638140278479, 59.53528381163075, 3.087052904790448, 1.3847136064883203, 33.427999711805775, 48.24364692934098, 70.84572453652659, 70.41552682076731, 62.870863483798125, 63.42067387796218, 62.427549362182624, 57.54588903919343, 54.13371724467124, 54.77232225479619, 56.90411867633943, 57.17372671250374, 57.37394409794962, 51.570660145052024, 49.49587537396339, 49.290743258691606, 48.48142885392713, 51.82936791450747, 54.95408488858131, 54.24588134211879, 52.08118015719999, 53.86048101609754, 53.34025706014326, 54.24911337514078, 59.47166296743578, 59.43993883748209, 64.04795892776983, 60.97859836393788, 62.49143300517913, 61.698078724645804, 64.39829326445057, 62.21326243492865, 62.7563577313577, 61.16440888374083, 61.51308405783869, 61.81107436456988, 52.9511736285302, 54.34919657245759, 56.56137412594211, 47.68129671773603, 39.01396866767637, 18.902080328233783, 21.744592574334916, 36.851428708722516, 37.66770139817269, 39.65701772320656, 41.93733861369472, 39.08884671426589, 43.546769465169604, 43.35322795375701, 45.28601900223763, 44.570653207840465, 45.86907148361207, 45.13142662663614, 46.8046469842234, 44.19408213707709, 39.78278852278187, 41.36540212938863, 42.1508018432125, 42.60340021502587, 44.415284202944854, 47.42933150260679, 47.708639560207246, 44.149108240681315, 46.22409305264873, 42.67553260249477, 47.618785904299834, 42.3427547947053, 42.666165982523275, 42.66153758571994, 43.79489467990014, 43.86978057123, 43.114292852340206, 44.157568793143, 41.98774107040898, 43.28288024471652, 44.99782285382671, 47.790005207061775, 43.582741522019916, 38.275115720687374, 36.18570443122618, 31.129126010402558, 30.332794650908443, 29.70236974377786, 14.722367371282271, 13.421770218879947, 22.836996201545965, 15.118238464478525, 27.658561891125096, 30.429488920396377, 30.692291644311723, 28.807988935901275, 36.99696433159613, 41.05057308750768, 38.968288744649584, 39.13976300147272, 46.36248211706839, 52.1715437212298, 54.8200535774231, 51.86796403700306, 49.799788459654785, 56.94129097846247, 58.005708494494044, 59.94802305775305, 53.754835897876376, 59.1669693300801, 58.71766967158164, 53.95625745096515, 48.90884168686406, 44.30989403878489, 43.78606542464226, 46.87819142495432, 43.341048994371974, 47.152027776164395, 56.72266590979792, 60.29004981440883, 60.371093826909224, 61.85645618746358, 60.40328079654325, 61.965517690104825, 65.96113420301869, 65.11019168361541, 66.19667253186627, 69.47017285131639, 68.27792921373921, 70.57957603085426, 75.15211043819305, 24.55679862729965, 0.12237404232784627, 11.60790837580158, 56.13393775878414, 62.50227835870559, 39.26839320890365, 35.055332260747115, 32.65624592381139, 30.683381980465306, 72.57239111008184, 72.99026473875969, 35.25164296550136, 54.82276393521217, 45.37918313857048, 68.57428781447872, 49.054483213732325, 0.1426187584236745, 0.1507407919533791, 0.0659461508715345, 0.06590709570915469, 0.10064231892747265, 0.12403278356237758, 0.0295847911207426, 0.040605812438673554, 0.134750529823284, 0.14443277801957824, 0.11978949149770123, 0.1658911612485686, 0.16178440903463673, 0.23246977898863055, 0.3009293264439029, 78.54944782872354, 87.28597041099303, 57.983103875190984, 51.863786712769546, 55.41539876691757, 77.70678151038386, 73.10203659919001, 144.20513922168362, 60.824319777950166, 55.82532175125615, 46.96504839005009, 19.05871625869505, 54.27774275502851, 59.691123500947036, 84.1146243003107, 60.871298005503995, 2.250750632055344, 9.113334878798454, 50.52107311064198, 58.139633901657604, 77.62957357591199, 69.04272863941809, 64.24039040842365, 61.5640317240069, 63.449013002457164, 58.987038443165446, 57.86877462940832, 56.419898156196844, 60.53787692900627, 56.209808165027255, 60.26598607340167, 51.78320161757931, 53.76022915686331, 51.70472283517161, 50.70793090328094, 54.27372232560189, 54.9438435800614, 55.5349329979189, 52.71869474841703, 52.00070488837458, 53.34422649875764, 54.17273698314544, 60.37454551266086, 60.968137402688306, 67.60194793824228, 61.92488977985998, 62.80607769566198, 63.967381677319935, 65.70837274674447, 64.08708849260884, 65.5905722033593, 63.7524240247665, 64.27036123891031, 65.14839949146395, 54.68028383870279, 57.94269954004596, 57.261560347772416, 50.76564858036657, 42.084556933372255, 25.046445746575635, 31.530211894742905, 41.63315880683161, 41.754324743824625, 42.50858868322065, 44.097815405937936, 40.3309593662139, 45.963992841782115, 47.44677428276309, 48.84003939167146, 46.730588712999904, 50.65772064270512, 47.880235410505726, 50.151805493139456, 46.06202463949881, 43.87023556616999, 40.55967277096164, 45.36452916360671, 45.07626633490286, 46.46010991065733, 51.388152260934156, 51.90575215124315, 47.316669264147365, 50.83092466477425, 44.900650055177756, 52.03870873297415, 43.93009877973988, 44.531809976024014, 46.1291128589261, 46.326835616942375, 47.00791597366334, 47.70529377845026, 49.80358139161141, 45.11223054701283, 45.469068173439275, 49.187467252054525, 49.91898144445112, 45.61965188672466, 37.880305628622736, 38.780293464660645, 33.80064841239683, 33.60820908700266, 33.51914774987006, 22.3651134967804, 16.56783861498679, 26.729783858022383, 17.646702220363004, 25.896643015646166, 34.817130642552534, 35.56918236517137, 32.4584545243171, 40.994279230794604, 45.53195945678219, 44.558850795991965, 42.19090807822443, 50.50339891064552, 55.93369683911724, 55.32290143351401, 54.45530060798892, 53.30177860875284, 59.69118233649962, 63.20495136322514, 58.88291912694132, 55.7704399478051, 61.274549038179465, 60.27823955781999, 56.45543090758785, 51.59311179191836, 47.907421358170055, 49.23328445803735, 50.85199955971011, 46.820748313780754, 49.583963963293264, 60.8220761822116, 64.43812493355044, 64.33982641466203, 65.92073379024383, 64.04486025533369, 63.71104301944856, 69.13487295950614, 68.49817029891476, 68.45062332768595, 72.31966495513916, 73.90257666187902, 71.69236029348066, 79.62132961519303, 41.459609616187315, 0.2148767689903898, 12.032996223818872, 61.58722862120598, 73.73520128188595, 44.23041505198325, 42.198282134148386, 40.37082241427514, 46.19075682855422, 86.09371108393516, 78.91935087019398, 52.40955314328594, 73.57425074423514, 69.98432497824393, 84.41993374978343, 67.21812048266011, 0.12490878978203382, 0.271942459287182, 0.19282302819192412, 0.17844081525841068, 0.17451738788475915, 0.20544097127933658, 0.22290613652477342, 0.15412437248854868], [0.15473546550398873, 0.0667530482995414, 0.02022078733951334, 0.04193639991083934, 0.056219695571569674, 0.08247770774628847, 0.2676632453597361, 2.67541584468657, 63.59682360003072, 68.79784722482005, 59.673798391895915, 35.50559682230796, 64.32702379841959, 48.385197424119525, 33.06464702852311, 26.340041468220374, 39.528144328824936, 56.08481399474606, 13.886048428473936, 26.89106191358259, 49.2922455264676, 61.13865852355958, 68.02168861512216, 13.3571619179941, 0.5837279870625466, 15.661944670061912, 34.503858781629994, 56.3390306503542, 65.25213833778136, 59.918111062818966, 53.98991138704362, 52.06224687637822, 46.93100221695439, 48.114565649340236, 48.51704005272158, 51.04609412531699, 51.3317564225966, 52.73166994894705, 51.66583645728327, 47.568101036933164, 41.03561709004064, 41.562744417498195, 40.334493421739154, 43.86996100025792, 44.306426663552564, 43.30816776521745, 46.427099243287124, 48.199500653051565, 52.29757339723649, 55.2406414862602, 59.4809119163021, 60.18989601442891, 61.422438083156464, 63.04983339002056, 61.29756158398044, 59.603909600165586, 61.26251128412063, 62.64673925215199, 58.90816350137034, 60.31320748790618, 58.80068663627871, 50.14243102842762, 56.85112353294127, 56.43925113062705, 49.736516706405155, 47.72391326965825, 26.52285137484151, 19.007276335070213, 29.404273533052017, 30.532247174170713, 32.21594418248823, 36.387741796432, 36.693419948700935, 38.049155819800596, 41.21052734313473, 39.31022920916158, 40.384378125590665, 43.08462012198664, 41.484355849604455, 41.97909616654919, 40.16923612163913, 37.802721146614324, 38.16932155239967, 37.57350175611435, 38.589831013833326, 42.53642574433358, 41.6587052037639, 41.5133382428077, 42.969118087522446, 42.854628024562714, 41.124686271913596, 41.9920870565599, 40.47320019814276, 43.34191191580988, 43.382053452153365, 39.21868108933972, 42.14213340513168, 41.99029061102098, 40.3398003885823, 41.979888485324004, 40.634346854302194, 42.48677246032223, 42.004701399034076, 39.599794264762636, 35.82339902077952, 28.124576730112878, 23.169566123716294, 29.879294133955437, 27.162941002076675, 10.269482904864896, 10.81009534097487, 16.236761154667025, 22.72779937713377, 42.97886125503048, 36.54626830931633, 26.98413387421639, 30.330592240056685, 33.73528603584536, 35.308258456568566, 34.29553777940812, 41.80502530067198, 41.84281733728225, 48.066791180641424, 46.62140169451314, 47.40837035640594, 47.543229287670506, 54.84221889126686, 52.071527204205914, 55.70692892997496, 47.7407951508799, 53.09786242823447, 52.55611250477453, 48.63302061634679, 40.50074700386294, 38.26118346183531, 40.50315926151891, 39.89397202768634, 40.59365618613459, 50.42797957697223, 52.159149031485285, 55.90671877707205, 53.86459950477847, 57.10554415179838, 55.56415857807283, 60.7775455136453, 60.29767097965364, 64.67403196519422, 64.58672392752864, 70.79972297914567, 65.55602396688154, 82.1644453848562, 52.62584832406814, 1.960449764324773, 0.40327766189171427, 15.727160938324468, 58.70848348063808, 49.17891648507888, 26.122506818463727, 42.28198159125544, 66.52160167694092, 65.2329775594896, 68.45733842542096, 65.83455931755805, 46.56447241383214, 41.5811481783467, 38.43892174382364, 80.65730602510514, 10.312047485382328, 0.5309692890413347, 0.23048858368589034, 0.07798946672870267, 0.07475854453420447, 0.04909613890753639, 0.03220365885945578, 0.03687227910925304, 0.05922748316680232, 0.1081399754771302, 0.041599033941184325, 0.050608465417979226, 0.004989023117588894, 0.07064241540407942, 0.18727060677784105, 0.4976800108148206, 5.472912519208847, 78.09059327648532, 70.67911009634696, 56.68465029808783, 31.745314674992716, 71.23282324883246, 53.15809042223039, 43.95568440037389, 24.621625600322602, 37.65142356195758, 53.87481727907735, 17.51726596586166, 35.48603988462879, 55.16735199959048, 64.68462236465948, 74.42269079146847, 19.145253550621774, 0.7444398730031906, 30.108466456013343, 48.38919824169528, 65.13514188028151, 69.43262007928664, 69.1874013408538, 62.29794640694896, 63.17266633433681, 56.00491139196581, 58.61710010036346, 55.136592772699174, 58.514965503446525, 58.38320916698825, 59.52688993946199, 58.820902532146825, 55.29346796774096, 46.949284384327555, 46.96912373265913, 45.63500404357911, 47.65213389550486, 48.08661876186248, 49.68933059323219, 50.153076341075284, 53.08304763609364, 55.15693810678298, 60.43856643861341, 61.51572381296466, 64.26606624357163, 63.54634269591301, 66.25824589883128, 64.04066331924932, 63.0837618920111, 62.28858763171781, 64.49390888214111, 60.461108299993704, 63.54736251215782, 60.439817674698375, 51.478256948532604, 59.30103986494003, 59.257599615281634, 53.63601946061658, 52.037724218060895, 38.25630795571112, 26.437039721396665, 31.430921016200898, 35.956991026478434, 35.493515922177224, 37.463749916322776, 38.68322264763617, 40.0990649192564, 44.87418974599531, 43.381429795295965, 44.37015341174218, 45.057650766065045, 43.850455053391, 44.53224928148332, 42.697541021531634, 43.989883545906316, 40.612397270817915, 40.238560092064645, 40.159669460788855, 43.93968897481119, 47.05014813330866, 42.34972092413133, 43.87923348334528, 44.60500140343943, 44.46154463675715, 44.628668985059186, 43.48259556678034, 44.09986288316789, 45.081522310933764, 39.277516641924464, 42.7496144079393, 44.865854709379136, 42.117108683432306, 44.39793163730253, 44.53610889373287, 45.52732321523851, 44.586276008236794, 39.82995502410397, 36.3318911675484, 27.70925852560228, 29.74728088225088, 33.73837294117097, 27.325937055772354, 20.345132081739365, 18.92040171930867, 26.074153800164503, 35.169465388021166, 53.810117783085, 48.63929248625233, 44.376844975256155, 44.50403959520402, 45.94952321821644, 46.30558813771894, 43.83532647163638, 48.80223558795068, 51.175532341003425, 53.301056892641135, 52.448514046207556, 51.560175649581424, 52.87253010657526, 59.132479929154925, 57.278324557888894, 58.5839678395179, 52.58493408080071, 57.393775601540845, 57.74032485100531, 55.16679894539618, 45.8650432094451, 44.30397125982469, 47.39643850634175, 44.897210136536636, 48.74162712404805, 59.549286673145915, 57.60527764597247, 62.61446991274434, 60.39459666898174, 61.46845925238825, 62.74202931311823, 64.88681662467219, 65.09876189693328, 68.97626015447801, 69.58170936953637, 76.37251669360747, 75.68912998322519, 85.18014400236069, 37.63302372347924, 0.18568949323267708, 0.14765296732225727, 20.886993792749223, 65.57438850402832, 57.34182773097869, 31.749297841902706, 40.47673425366802, 68.20650285290134, 52.290132661019605, 72.08529549260294, 76.55109436281266, 46.69994715721377, 38.953936792189076, 45.678106969402684, 83.3213641566615, 6.694180715468622, 0.39525454563479273, 0.2560881624418882, 0.06017506498122408, 0.1242326099365469, 0.063823263776759, 0.05888194303899523, 0.028676894576018377, 0.018050917987561515, 0.21151413329907004, 0.13462132143397487, 0.19010405957458482, 0.1374383033403466, 0.13996072443983248, 0.2895924202617138, 0.5970720742498675, 3.741441042192521, 88.76002065597042, 79.81706373153195, 85.0754088740195, 39.84890007203625, 85.81628184164725, 57.08378676445254, 44.304696898306574, 35.046240206687685, 54.057525204074004, 76.36619383288969, 19.777141501826627, 43.06253325554633, 64.00853518516787, 73.14792048546576, 80.6485277606595, 15.700796727211246, 1.7745671709699018, 49.703729614134765, 59.18978967974263, 71.34759180007443, 69.90885857612857, 70.23512132706182, 61.25922433791622, 63.1051270423397, 57.722862458998165, 60.7759020405431, 58.25836796914378, 59.68369845421084, 60.14893862508959, 63.39320159727528, 61.47211097901868, 56.03572160966935, 48.37272428697156, 51.9470743210085, 48.256033774345156, 50.374745168993556, 49.966053808889086, 51.455095352665076, 50.764738590486594, 53.1856450726909, 56.016709881444136, 59.688381764196585, 62.00169763257427, 63.749435178695194, 62.88212853093302, 66.61256928597727, 65.82545157401793, 62.890134088454715, 63.0425024801685, 66.14312433427381, 60.52589801050002, 66.73770858395484, 61.69482315740278, 53.09818798495878, 60.41079998016358, 62.3856427592616, 54.04193378263905, 54.479191764708496, 36.877692899396344, 32.01071204677705, 37.6862032182755, 37.620440759966456, 40.15685319900513, 41.322314893045736, 38.55023076457363, 40.112926575445364, 46.13816176691363, 47.7831292921497, 49.01952705075664, 48.35977262066257, 48.184042592202466, 51.60190182347452, 47.13452616045552, 44.77590299421742, 43.88087695644748, 43.54916995571506, 42.85213731950329, 47.38190220248315, 51.26195000063989, 46.562197439132206, 49.70057602851622, 49.30303596681165, 47.16158659227433, 47.46070261924498, 45.31350305003505, 50.54035940477925, 52.17971401829874, 42.563909792131, 47.998400734316924, 47.76152095487041, 43.46401922164425, 46.87119391656692, 49.44280962790213, 49.42906564281833, 48.86940617715159, 40.66841656161893, 37.572791807113155, 35.29001159052695, 31.659420651774255, 33.568016559846946, 31.64530992507935, 21.134279620262888, 20.619331252190378, 27.36610016515178, 32.360734555029104, 54.76881957823231, 52.90452095770067, 48.65777469450428, 49.968638650832645, 51.78756329321092, 48.61410694737589, 45.64332731308476, 52.092704080766254, 55.000349244763775, 57.171028121825195, 57.20749439731721, 53.10909609640799, 54.68907779262912, 60.37580851585635, 59.330963626984634, 59.539641564892186, 53.62958677353398, 60.461390710646114, 61.616336530254735, 56.989649880316954, 49.92074258865849, 45.953512268681685, 50.54005345990581, 48.64246568372173, 51.98914566347676, 62.063176862655155, 62.3291959301118, 67.3428753883608, 63.85724936762164, 65.51321521882089, 67.7543398641771, 67.32753892098704, 66.86292632933586, 69.84017002967097, 69.90226114949873, 79.07346863900462, 72.40871060279109, 87.57878318909677, 58.69126035321144, 3.3507778759925597, 0.5163745786393843, 21.130198394098592, 71.8708908942438, 63.607539515341486, 38.995031464484434, 52.50872635072278, 82.96554242410969, 94.03794627035819, 85.92265652072045, 75.5631277638097, 63.27196897998933, 58.056201165722264, 59.03726047085178, 106.17259856193297, 14.247751755099143, 0.8619704470038415, 0.3742383023904216, 0.13969172032610064, 0.17054396561316906, 0.11256679156494719, 0.16185476654960265, 0.13963242512076132, 0.17286283715117365], [0.07897919103983911, 0.07476737752797143, 0.022072174789143667, 0.011413335901564889, 0.04925262385738954, 0.07589050072936282, 0.10598704624440401, 0.40125926535937095, 8.000671719351123, 63.94221182792418, 62.736224205263206, 49.910838603973396, 31.025043956695068, 47.360278175723174, 32.68749152460406, 130.91541167228453, 76.73773642509215, 62.14760195824408, 26.031201885592555, 19.989524118361935, 43.18159680212698, 60.46833722822128, 66.13327134040095, 28.72370308445346, 0.16392636022740797, 17.387107995248613, 37.83670848415744, 44.79488334348125, 57.14591710798202, 58.725432042152654, 55.260888761089696, 48.54958788041146, 50.397032076312655, 48.1198686938132, 50.085666487293864, 53.238946160962506, 54.29101213332146, 55.436422671041186, 55.52425238393969, 51.93211440117129, 47.83770907309748, 41.025901379123816, 39.861369286814046, 41.037225261811294, 40.64740442460583, 42.637442465751406, 43.16541702516618, 48.50845006204421, 54.772451693011874, 54.32034753984021, 56.51865951476559, 57.88109871648974, 58.307111263275154, 60.49406405418151, 59.78712743328464, 62.348431233436834, 58.5224493857353, 58.8930662985771, 60.9686630002914, 60.656414877983835, 50.89181946169946, 53.15509765378891, 59.582787636787664, 58.63961450515255, 57.852759591994754, 56.58929355682866, 48.149776766377116, 28.583068463110155, 24.514499787361395, 31.779335352682303, 29.38875859783542, 25.037377226737238, 32.20381621391543, 36.189540509254705, 40.16001855173419, 41.22530291157384, 41.08768263170796, 38.88161613095192, 42.0639213438957, 39.63043974291894, 40.119524002075195, 40.18860478555003, 39.293833701841294, 37.64230012893677, 39.43741206199893, 41.72411857112762, 37.99334833698888, 36.05385788025395, 39.171867601333126, 40.71686567798738, 42.102442941358014, 40.28393799258817, 42.470859404533144, 41.743526458740234, 42.24650375304684, 45.362791553620376, 45.77939041199223, 45.24551268546812, 41.216359907580966, 41.38365684017059, 40.9417861507785, 42.836067368907315, 40.68578873911212, 41.23129629319714, 29.763919576521847, 14.122707574598252, 29.71468794730402, 34.7696856529482, 26.726220384720836, 31.04983921973936, 25.42378167952261, 45.08934351705736, 49.26527923153293, 50.1482714376142, 46.235695423618445, 44.534198699458955, 44.05325728078043, 45.18824608095231, 43.70771608045025, 43.00403894916658, 44.64171478825231, 45.960109695311516, 49.06319087551486, 47.22318349346038, 48.646811669872655, 50.14999728049002, 53.787999537683305, 51.718611947951786, 53.99180981420702, 51.75360341225901, 52.37268286366617, 54.62790450742168, 49.52060984027002, 42.625640053902906, 40.013231692775605, 37.62218229232296, 41.83080311744444, 51.39807585747012, 51.845088774158114, 55.01362646779707, 58.189145980342744, 59.072989340751406, 56.085633770112075, 55.767564850468794, 57.328723092232984, 59.703729998680856, 65.00689606512746, 67.94760288730745, 70.85644829657771, 73.22814864497032, 50.02108466240668, 4.95543961563418, 0.6858375788696351, 0.3118327800785342, 27.494296950678674, 62.683080011798495, 40.802875411125925, 31.34313641055938, 43.80099004314792, 32.95583655757289, 43.20125179906046, 71.56533825782039, 53.255451494647616, 39.12060614555113, 47.17979031224405, 55.080538180566606, 50.39984049335603, 0.11634061728874523, 0.05444641653147917, 0.038754005555904684, 0.03823303895431661, 0.11019966414859218, 0.05548492149119416, 0.16889712172410182, 0.05685605416675249, 0.078857398381637, 0.0531343722175206, 0.11374902611057605, 0.005721132169597813, 0.04868351629063968, 0.14689763527243369, 0.046287974673173124, 0.054219976262820345, 0.4424979621844907, 11.521062197223788, 78.8007854646252, 66.42580955259263, 46.693134000224454, 40.22808344133439, 62.71218399847708, 30.559366441542107, 102.2066822359639, 80.82948238618913, 64.83970111416232, 26.865407651470555, 26.43239759629773, 50.439978107329345, 67.97516930487849, 70.81526340976839, 33.636003002043694, 0.2686691188043164, 20.333998434005245, 54.02671498637046, 54.03958428290583, 62.88783165716357, 63.56492688578945, 61.41356960419686, 56.791181871967936, 57.36508738610053, 53.77505179374449, 56.97550189110541, 58.39522338682606, 59.550333945981926, 60.49762948866814, 61.050648381633145, 57.89883959677912, 56.47014764047439, 47.48881424626997, 45.826647127828295, 46.07889475360994, 46.28190878898867, 47.200288618764574, 48.0972287731786, 52.385136388963275, 58.01725202991117, 58.425292276567035, 59.445453689944365, 61.520258072883856, 59.66507111826251, 60.77200712696199, 60.919041095241425, 63.97810935974122, 61.77455317589545, 60.96439153917375, 62.21196413040162, 61.08584380918934, 52.61062168305921, 56.07768704814296, 61.171273031542384, 58.27652462067143, 59.85070120903754, 58.00687736080539, 53.512147088204664, 35.309152756967855, 30.25233703274881, 33.95552712102091, 36.270074613632694, 28.46901966679481, 32.71937058817956, 37.259731754179924, 41.65954851335095, 42.88243370671427, 44.141134062121, 41.9476701367286, 44.724366972523356, 42.12393360753214, 43.58391431070144, 41.77117916845506, 41.377082947761785, 40.115028965857725, 43.80887008482411, 43.932209014892585, 40.45013666152954, 37.05373671747024, 40.2930300466476, 42.01221666028423, 44.456414176571755, 41.98421878199424, 44.06429090807515, 44.41199333437028, 42.96034766781715, 45.89285281396682, 46.9365406036377, 44.09072768303656, 43.70242872545796, 42.21795282056255, 45.511892610980624, 46.131901664118615, 42.68952369689942, 40.98542644131569, 27.507117217586888, 20.98011870538035, 34.81175307304629, 32.42980749376359, 34.70311126401348, 37.33242504058346, 39.329664553365404, 51.60983677833311, 52.31871497246527, 50.2425612941865, 47.61316122547273, 48.87093197914862, 49.750903960197206, 50.45667563715289, 51.36963082898048, 49.04552059788858, 49.13598614354288, 51.859711370160504, 52.358519184973936, 52.09381411152502, 52.993523459280695, 53.80615226684078, 57.293759084516964, 56.26740424863754, 58.20234083360242, 55.14622219147221, 56.52242106776084, 58.84915928686819, 54.96284746354627, 48.68490572898619, 43.919163211699455, 44.78638356731784, 48.111161032030665, 59.50101406343522, 56.61809944337415, 62.75160381870886, 62.06682074454523, 63.19279593806114, 61.52917362028553, 62.60234194417154, 58.74214133908672, 63.34697646479454, 64.9283702142777, 70.85357712161156, 72.97968218403479, 64.46766038094798, 38.469029857266335, 6.298564086037298, 1.0478806808110208, 0.9563326222761985, 33.830580019181774, 69.51088705370503, 48.202618937338556, 36.634152935397246, 48.6698712841157, 42.20401271697014, 53.06764056605678, 77.5792024981591, 61.54465913772584, 36.764622734438994, 46.79781421538323, 63.245575351099816, 42.95556237620693, 0.24047619452880276, 0.07240431803849436, 0.02296567079611123, 0.07316276040529052, 0.09157595945702446, 0.0546554091476625, 0.10047356507951215, 0.08085425252154951, 0.1069008589031235, 0.13566346148089056, 0.434903058433725, 0.09908965788781644, 0.1742563817289568, 0.3049650469854955, 0.1276535295971459, 0.4158047929165825, 1.0354734885115777, 12.614351299501235, 94.6595242715651, 74.28398009269469, 68.42838348880892, 41.75484249668737, 61.65381477725122, 41.74320874675628, 137.70029621739542, 91.85784586014287, 83.23835895907494, 36.52494630505962, 30.670897076206824, 58.91993061188729, 73.0703987613801, 78.00650550473121, 35.2023034711038, 0.281922010885131, 31.124478001748365, 64.64430039928806, 61.95990870075842, 68.4677170168969, 64.30855335727816, 63.87926170902868, 57.91494092633648, 60.53526070810134, 57.85487374951763, 59.87551020037744, 60.85148219139346, 61.74523738122756, 62.419869361385224, 65.35844633656164, 60.42234351558071, 57.87098292381533, 48.56892908773115, 47.34995841979981, 47.79723805765952, 45.93238246056342, 49.49234916317848, 48.99953080761818, 53.57792131362423, 59.856286664162916, 58.21147603373374, 62.58828024710379, 64.48593078121063, 62.31518914622646, 62.41962225206437, 61.89098481209048, 66.35754462211364, 63.10060454953102, 62.00448251539662, 65.41660331910657, 65.6099408672702, 55.27835507546702, 55.75043585992629, 62.75607139833512, 62.466110183346665, 61.853839966558645, 62.211650340787834, 59.153825467632664, 39.86555053341774, 35.930087489466516, 40.08223010647682, 40.64972254537767, 35.02503587353614, 38.16590124560941, 38.46100468789378, 43.49548447516657, 45.69904065901234, 47.576157585267104, 46.834331481687485, 48.84328319180397, 44.37931999083489, 45.10913971931704, 45.099953528373476, 44.1273469309653, 42.608958213560044, 49.48270797729493, 48.466084541813025, 46.187716991670676, 40.91254488114388, 46.364239338905584, 45.179805140341486, 49.076876025046076, 46.06807293430452, 47.061852485902854, 46.587551639926055, 46.760736050144324, 52.86370085131738, 52.811156780489036, 46.688905685178696, 47.336014393837225, 44.81008252789898, 46.27888071921564, 47.91960816229544, 43.255172621819284, 44.07425372831283, 37.440823662665586, 26.620147728150894, 35.9139940046495, 37.608234343990205, 36.61393311715896, 38.225387911642756, 40.273575090592914, 53.341080757879446, 57.04064461492724, 56.19239284146217, 51.79294478508734, 51.847956026754076, 52.099313274506606, 53.75303160759711, 53.5781527334644, 53.467890985550426, 52.62493441181799, 53.66563335541756, 56.85282584159606, 53.693560631044456, 55.913218144447576, 56.76641602669993, 59.7390744763036, 58.63218553604619, 61.17159074352634, 60.399531010658514, 59.48923910817793, 63.317425327916304, 57.43810230685819, 52.28509241534818, 49.25588123260006, 49.11354626378706, 51.394502578243134, 61.645464051154356, 61.332709943094564, 66.7807448294855, 67.3473233561362, 66.96032662545481, 65.32855003110825, 63.69142724621681, 63.523620405504786, 67.43791441763601, 69.51727267234557, 74.53072855549475, 75.09591856310445, 77.44751284199377, 56.12682257929156, 8.481776406688075, 0.8858634423344367, 0.8867754546865341, 35.07557953557661, 74.63064701326432, 55.423533762654955, 42.20865288088399, 55.74666253982052, 43.88310878507553, 64.71302816944738, 86.93056444967948, 66.6815245536066, 55.04610369282385, 68.24793877140169, 73.6694231340962, 70.8529338529033, 0.3146791337959228, 0.11184339772068685, 0.1333165970901328, 0.1220758809077163, 0.3728112644485889, 0.14051716474275436, 0.2619041640671992, 0.1792154833674431, 0.15498894867637467], [0.0724582659501222, 0.051715159863834424, 0.02145217983202348, 0.056665236986572706, 0.017976134399613066, 0.08071981175171752, 0.04885466033292394, 0.0467131381493903, 0.29390570978003167, 9.198577788568313, 77.1927470545615, 58.149667324558386, 42.53454692902104, 44.33058846381403, 110.56848510619133, 118.25452635365149, 78.32975587537213, 66.82592268913024, 33.55387641537574, 19.168825034172304, 39.41797279542492, 56.880215752509336, 65.40535396145236, 39.345746271071896, 1.3450888424150407, 6.399242503027763, 45.26054713033861, 44.28441039977535, 54.324713137842, 51.65780736554054, 53.47594753388436, 50.02876466320407, 49.641709096970104, 46.40801299002863, 49.20326655910861, 50.60996970822735, 55.00307136966337, 54.775197352132494, 54.49719544379942, 52.54594179891771, 53.860755582009595, 46.444494955001346, 43.148001701601096, 41.318090500370154, 44.339547157287605, 43.43408369248913, 43.97136603632281, 49.96451623978154, 55.012183035573656, 59.89438072327645, 62.388290359127915, 59.31139492219495, 58.97741686913275, 58.36834338403518, 58.07265550859513, 57.49067383427774, 60.095629692077644, 59.94124520209528, 60.41420459747315, 55.424051515517704, 54.414139255400634, 56.64425773005332, 58.940683872469016, 54.28084927220499, 55.88414553673037, 57.957361359750074, 55.2597551961099, 37.31781813406175, 30.71534537499951, 31.2100778472039, 34.43793550614388, 25.170345575578754, 26.61669408121417, 37.11201529349051, 36.230827377688506, 37.725289637042636, 39.34887632246941, 38.94117732201853, 37.847753878562685, 37.92203964725618, 41.09563719841742, 39.24314883447463, 38.12183733909361, 37.68723480163082, 36.452096123849195, 35.477987258665024, 33.349058089717744, 33.900264847663145, 36.33623323132915, 39.87761966643795, 44.20582963574318, 43.24621000597554, 45.52742127449282, 45.67725973744547, 47.326102564411784, 45.15000297177223, 46.07769450833721, 42.74022817611695, 44.92349393906132, 43.895060246990575, 43.93983802487774, 42.09437462591356, 40.53818602715769, 28.562825110650834, 11.107032491314797, 18.205045730836932, 36.86555316371303, 31.624999892327097, 35.94653398759904, 39.286463568287516, 46.58208385590584, 52.21505065118113, 50.951596383125555, 48.4156624732479, 46.50489945565501, 44.372083217866965, 48.73891676625898, 46.76474471246043, 45.31002783006238, 45.903862907040505, 48.50519057243101, 48.56467723846436, 49.58959256449054, 49.689307059011156, 50.99729591800321, 51.62547919058031, 54.05451674615183, 53.13780392369917, 51.25416409584784, 44.33638964929889, 51.11036608296057, 52.395962130638864, 48.534400463104255, 43.54261175278695, 39.67097743864983, 40.95379644824613, 48.47519228535314, 54.136521739344445, 53.169755551122854, 57.505716123888575, 58.33889030641126, 60.06736117024576, 60.227056549441436, 62.7281637345591, 60.36596336672383, 59.69867798589892, 57.01172890201692, 60.92380285263062, 56.59740501834501, 33.89250247709213, 21.636313584543046, 9.095444948442521, 1.555620590525289, 2.674061401236442, 36.248678084342714, 58.76640512097267, 38.670165077332534, 46.128387220444225, 58.23930132773615, 22.815689886769942, 22.036516935594623, 68.70500472284132, 49.390442063731534, 50.75514447304511, 47.20157907855126, 66.25473929989722, 7.171626812027347, 0.36777607495746306, 0.19770817170220037, 0.12282971908608753, 0.12036854671614787, 0.1008958633868925, 0.030450987584528424, 0.04921819586607237, 0.009451023708548277, 0.13007727091110524, 0.027492440290628906, 0.0876888063465876, 0.04444468668812225, 0.11900949907759506, 0.004429979552139318, 0.08505773099680101, 0.07908443619887676, 0.0180446686253192, 0.40740056323908996, 11.417856793249808, 88.38224933993432, 61.990887580379365, 32.20546949294306, 50.812607196069536, 95.09194204884191, 104.15249947578677, 85.30271022550522, 72.27251022092759, 34.672991383460264, 23.280151467169485, 45.22797969079787, 61.36431247957292, 69.78715527442195, 45.73478129602248, 2.1505259842641893, 8.258831827871262, 56.65600522871941, 54.80089279913134, 64.40252157949632, 57.936780683455936, 62.94480408391645, 57.38167901192942, 58.09429914720597, 54.04944119914886, 56.06965795640023, 56.981977724259906, 60.14700097422446, 59.0221397338375, 60.252551955561486, 58.909524563820135, 59.933929981723914, 54.95448497033889, 50.16467086730465, 46.69256917891964, 47.59021928233486, 46.24329697701239, 49.66345471720542, 54.283336054894235, 60.20199652641051, 63.936414564809496, 64.29478583797332, 62.91492346794375, 60.194540100712935, 62.79695426264117, 60.883771142651966, 60.20281630177652, 61.20626057347944, 62.454809834880216, 62.588233178661724, 59.31576052019673, 58.01733832205496, 59.84568841995732, 60.92454418059319, 58.53904493393437, 57.164258110907774, 61.87513843659432, 60.82363728554019, 46.91257492188485, 37.54837897516067, 32.47563450567184, 36.732886837374785, 35.56982955624981, 29.951754039333714, 37.287490367889404, 37.80492159628099, 38.52866557336623, 40.862440524562714, 41.8495677363488, 41.647946142381244, 42.15517136358446, 43.117269931300996, 43.92669416243031, 42.79372930526734, 41.921515772419596, 39.91481550278203, 37.83587301931074, 39.321749210357666, 37.281744095586966, 37.19895462835989, 42.47315791345412, 46.190784285145426, 46.24467372894288, 46.93394007221345, 46.45524224927349, 46.4074795476852, 44.919995184867616, 48.17849243840864, 43.95147177480882, 42.33990323159003, 44.415943161133804, 44.158753348935036, 43.35118439889724, 37.70326552852508, 28.290614581877186, 14.726656483065698, 26.315212865029615, 37.443447728310865, 36.38223478871007, 39.40895918876895, 41.22568338148056, 51.7393377519423, 52.495782529154134, 52.89163204931444, 49.11491124860702, 52.20185187555129, 49.07927651559153, 53.89422908906014, 54.12901040046446, 52.336055770997085, 52.742825169717115, 54.67097997665406, 52.88330093506844, 53.94952666374945, 54.137808276760964, 55.58138170549947, 55.06105969029089, 60.189511622152025, 56.732813081433704, 53.0201877317121, 48.88034958993235, 55.38175267557944, 56.51123446802939, 56.450127863114886, 49.560037505242136, 47.090642682967655, 45.66217037939256, 52.874416766628144, 58.94794417965797, 61.37497348170127, 61.23212860476587, 62.83792341909101, 64.6838967261776, 65.87957243765554, 67.70243906205701, 64.59247019983107, 63.92587123378631, 60.33038746926093, 62.682346528576275, 58.169188960906006, 41.333332830859774, 29.45530356899385, 16.317473726887858, 2.803306195043749, 3.5567287860378145, 41.49327924174648, 62.15466222455425, 46.52057716923375, 50.296627244641705, 71.09193171224287, 31.279207660305886, 33.140427220252256, 77.07531129160236, 58.271417694707075, 49.61016147367416, 53.45793601005308, 63.3002963373738, 1.6499859527234109, 0.059319172400019826, 0.015602398517301247, 0.04490552304853355, 0.08507965643319391, 0.06739316838643244, 0.035991308639847466, 0.024740424555455966, 0.04953971530701365, 0.015574500467928668, 0.11185613776286764, 0.19367815085476447, 0.23795441694317326, 0.24827374385729914, 0.13269813430886115, 0.19434751251772528, 0.14294177173606812, 0.15961302474381464, 0.533850024784765, 16.916980551135158, 105.22813889288135, 66.94248768591112, 60.97602136673466, 53.672579872992735, 121.68189341022124, 116.393918683452, 86.63291931152345, 83.94407180047806, 45.79506028083063, 28.451482749754383, 52.43370709880706, 68.91038786980414, 75.34599319581064, 48.51301962329496, 1.2909120850024687, 12.22206231086485, 65.81435126643028, 60.168707370758064, 69.91037261101508, 63.361846170117786, 65.70299125486805, 60.13322561017929, 61.99950502764795, 58.25513201375162, 59.85458435550813, 58.71789716905164, 64.57706312979421, 63.060729734359256, 63.40596106744582, 61.03742607178227, 65.22568979570943, 56.88132186089793, 52.489663631685325, 49.44381375466624, 50.86948548593829, 49.47365122456705, 50.8783814214891, 55.94422840302991, 62.80876059685985, 64.56531563112813, 65.79698693367743, 64.37023262823782, 62.42981256977205, 62.26621835462509, 62.521219484267704, 61.26436264284196, 63.57228132986254, 64.11884007915374, 64.47060215857722, 60.82129170817714, 58.458149971500525, 60.51069490371212, 61.868619457367934, 58.978428840637214, 59.31531729236726, 64.0879592587871, 63.632552469930346, 48.12402248382569, 41.222153248325476, 38.32856585902553, 41.03712328018681, 39.45789467903876, 34.77418853390601, 39.97443552940123, 39.77834055500646, 40.095491640029415, 44.43736714701499, 44.74404550367787, 45.06722527165567, 47.79565342010991, 46.672965172798406, 46.31350348072667, 46.218868455579205, 46.627167578666445, 43.212830635809134, 44.864285761310214, 42.99402906048683, 40.65498244377875, 39.997844234589614, 46.95383825609761, 50.79506635665894, 49.66182693358391, 50.169032542936264, 52.16331066623811, 52.577289381334865, 48.64262257852862, 52.44836499614101, 47.9070173540423, 46.87832478554019, 50.67894458770753, 48.97107008964785, 46.9258992133602, 43.81453398735293, 36.86231328595069, 20.68834927774245, 27.509896216853974, 41.945069605304354, 38.645740478269516, 41.03270276900261, 47.10739512597361, 53.81196914180633, 55.08458214421427, 57.23557072301065, 53.47564158901092, 54.31053376966908, 51.867528653913936, 58.45946004313808, 58.96804240442092, 54.39779866126276, 53.72198604768323, 58.33472082691809, 55.5164860909985, 57.252789928067116, 56.10841489607289, 57.657700123325476, 60.12521613028742, 62.82230454106485, 60.02944361778998, 55.125480698001006, 51.60937393865278, 59.43896216730918, 60.01590751832532, 59.82511558840352, 51.59266856408889, 48.96519437912972, 50.00942345588438, 58.29967837179861, 63.7248379953446, 64.72673685319963, 65.90666032606556, 67.09899810052687, 68.19133896981516, 69.13073878134452, 71.13139860091671, 65.88762114124914, 61.992864454946215, 60.19403803733088, 64.01845485933366, 60.94466986194734, 43.88401093021516, 27.1197517841093, 14.122837012813939, 2.414266154650719, 3.8025228871453196, 43.91889649052774, 69.19258671422159, 51.7040442651318, 54.77213790339809, 76.1740682971093, 32.1891269376201, 31.12755313996346, 87.49602902320125, 60.421562963916415, 77.57878672692084, 62.4575751058517, 90.24977607111778, 10.456115161218952, 0.558572662693839, 0.19434933580698507, 0.1601272229585917, 0.4087206553066931, 0.18147616286671933, 0.23812594402941967, 0.20039102693478908, 0.08213312905882636, 0.1556160376076737], [0.07496882034766097, 0.02791786998239977, 0.022556417050861546, 0.04536002769225067, 0.08047612684388315, 0.013837460259486352, 0.04246366758560462, 0.07362968333426022, 0.0896659720268461, 0.1622349146993891, 14.7027329667922, 64.18299828806232, 54.46460447003765, 47.41203777251705, 89.81748380968648, 89.27032101538875, 95.58567431665237, 67.1839487937189, 44.87815918460969, 19.892706294213575, 36.113144505408506, 59.79198724992814, 63.25240811993999, 45.429181591157, 6.637208779012004, 7.287803984457447, 34.47766911598944, 42.6915947083504, 51.204004826084265, 52.94455266767933, 54.53949820610785, 53.94409810343097, 54.516434669494636, 51.14260012103666, 48.401530173517045, 47.85186490704937, 53.297263960684504, 54.300182634784335, 56.28893806088356, 58.20719672787575, 54.15195626597251, 50.745130661995184, 50.07659796745547, 44.401536295490885, 41.838083036484264, 41.27979247800766, 44.41304845194663, 50.103336764920144, 55.05770998616373, 54.694098426449685, 59.52765480164559, 59.2158224505763, 59.230590174275065, 58.849386784338186, 62.1940428210843, 58.132448119501916, 59.20398081502607, 59.0098274138666, 60.85638515410885, 56.954917292441095, 57.5673875501079, 57.93416054018083, 59.951737542306226, 56.26219926341888, 57.121449362847116, 54.3224028618105, 59.006846412535644, 51.161325516239295, 37.971947885328724, 29.256455090738115, 33.25209709905809, 32.38602992027037, 26.679079378804854, 31.55579555419184, 35.879206503591234, 37.11798514089277, 37.51166166797761, 37.65066654451432, 38.48806511971259, 38.35804247087048, 39.60594454119283, 39.86773921597389, 40.97417708366148, 37.8140881753737, 37.58251144040016, 32.60157985071982, 35.10363232704901, 35.58748806676557, 38.06921874323199, 37.76932216459705, 44.16178141870807, 42.8257829143155, 46.159585752794825, 45.81427597230481, 45.54515431004186, 47.233428724350475, 46.77306013722574, 46.41520269455449, 46.884000455179525, 42.92603477354973, 41.47580900499898, 35.05754055515413, 28.029463175804388, 14.767315772271926, 11.995320877721234, 29.386532652762632, 35.299723379073605, 35.0515079498291, 38.098491391827984, 43.86304978401431, 50.85933831430251, 53.260695703568004, 47.6973117551496, 44.977834455428585, 47.92122025643626, 49.75571278602847, 50.69916048357564, 49.06972162185177, 50.891925365694114, 48.761136993285156, 49.210554322888775, 47.966700138584265, 50.50621909479941, 51.486313496866536, 52.91656263412968, 52.3529847206608, 52.08939360034082, 50.978303801628854, 50.91961337674049, 49.134907491745494, 51.230853449913766, 51.38681081033523, 50.57613926549112, 43.84532851557578, 42.24252646969211, 40.886508187940045, 51.11360988309307, 58.38016148536437, 55.986935169466086, 56.846969742928785, 59.14452160558393, 58.63485274776336, 60.15229617395709, 62.03981914827901, 65.41053933482017, 63.816825420625754, 62.77318862176711, 61.30137805015811, 56.4872609415362, 49.84295414340112, 41.783671917453894, 25.41332267945813, 7.33456697194807, 4.271543487425774, 37.6135766121649, 58.486226297193966, 43.436766593687, 59.01693474861884, 22.38930863718833, 10.650141085347823, 33.52312503322479, 59.18543584885136, 57.526288955442375, 41.495103143876605, 65.53145031775198, 27.49281821712371, 0.3619428976408897, 0.08841334932273434, 0.015472242094185806, 0.06597009878004752, 0.019327105556224144, 0.021325953439959598, 0.09899689996194455, 0.04069061071101216, 0.07179026026278734, 0.11550345938772925, 0.018739251817967144, 0.06405053908125528, 0.05245287572183917, 0.05530370722314524, 0.11813949132638595, 0.03977823829759033, 0.047620960000541904, 0.05469588540314187, 0.0604068027478793, 0.3132634339553695, 14.220537370251073, 76.98956043489518, 51.82737927283011, 36.836845336421845, 92.84716175448511, 96.25069648988786, 103.34132194519044, 70.84506557833764, 53.443831166913434, 24.154891006408203, 44.165723400731245, 65.79759882342431, 70.14559715024888, 49.978126864279474, 7.765052491618742, 12.737314662625714, 39.191604968040224, 50.61644946375201, 59.31466225654849, 60.07968525732718, 64.15019158394107, 59.06576041252383, 61.5209601771447, 58.82573881456929, 54.44529856404951, 51.640192001096665, 57.26105043965002, 57.56710906182566, 61.38020592351114, 62.145468188870346, 60.827241943728545, 56.906527011625236, 56.97644325994677, 50.84640233747421, 47.47800419407506, 45.57089682548277, 46.6709255403088, 52.31286671853835, 57.115514816776404, 57.899486787857555, 60.29552544316938, 60.29228556540705, 59.17529652195593, 59.63262134982694, 62.13312056756789, 60.22849998166485, 63.22212349983954, 61.43618599061043, 62.38372079787716, 61.13561868667603, 59.20971924258817, 61.240659759890654, 59.118112287213734, 58.90663769937331, 59.01047460494503, 55.138267624762754, 59.59034996647989, 55.355876799552675, 43.93175401995259, 32.96295958180582, 34.986835910427956, 37.33431170063634, 33.61797186636156, 32.73887653504649, 37.9639462501772, 39.98751271155573, 40.57308335458079, 39.146642838754964, 41.54748247515771, 40.62260327800628, 42.45867652277793, 41.84203286324778, 43.65742345010081, 42.9917658528974, 41.778070772847826, 38.66983167586788, 38.490422464186146, 40.30429509378249, 40.31567781202255, 41.845033476429606, 45.80095168082945, 44.93339400137625, 45.53441486051006, 45.65964045063142, 47.89735655630789, 48.46463718721944, 44.83234982336722, 45.40509039355863, 48.59389105150777, 45.02049023105253, 44.03241772805491, 36.197346025897616, 32.01064536648412, 18.407820501635154, 18.37705735237368, 36.89868542455858, 38.698708165076475, 37.09842428084343, 40.56490913514168, 49.42648080087478, 55.945718903695386, 55.938466441246774, 50.161807537078865, 46.391495889233006, 50.5445328066426, 51.65784266687209, 54.39597868150281, 52.00311322366038, 51.9316162601594, 51.93353822154384, 54.02260434242987, 52.940289051302024, 54.7344203918211, 54.98083937552668, 55.56813193905739, 56.251597096843106, 55.98413067479288, 55.49889818314583, 53.44740052377024, 54.49009987615771, 54.53017865457843, 58.628498508084206, 56.15593833308066, 48.278304992183564, 45.094572036497055, 45.76118669202251, 56.962440398431596, 63.84423886576007, 61.44603113974295, 62.887000114687034, 62.99549679602347, 61.58300030616022, 64.3769359588623, 65.27648056707075, 66.07645188608478, 66.94022840069186, 69.14502405351209, 66.63247923697195, 64.2510788671432, 62.152857934274984, 54.30050034676829, 33.76278969549364, 10.984752601192845, 7.299021963150271, 41.96843908679101, 62.394495548740515, 48.00511583205193, 66.39552885486235, 32.68468899111594, 18.279115769170946, 43.81867208788472, 66.4897834101031, 64.97524253783688, 44.146115472239835, 73.08202466657086, 18.785933063876247, 0.686697987539153, 0.18733261393443232, 0.05846089345493144, 0.05589365621187514, 0.006150653249689288, 0.041179696563631296, 0.0739607941960135, 0.044246231611337394, 0.10732989112335829, 0.028884625062346462, 0.2298806622744568, 0.15361846334511234, 0.15382567480687173, 0.17035316375474777, 0.32375727569864643, 0.26160649294334076, 0.13619998349778115, 0.19762811551411308, 0.1524818340136159, 0.34491077125553166, 23.02608386162789, 101.04290716109738, 68.03835084361415, 63.444643482085205, 99.14814349143737, 97.44996901481383, 100.64265281923356, 81.42900882228729, 60.864806482868815, 28.522308987955896, 48.78890737410515, 73.54081646088632, 75.80425154778266, 57.242109314087905, 8.106788992881775, 12.802940818571276, 50.86245267621933, 61.0912331458061, 65.74875354766846, 63.919140446570616, 67.76114125405589, 63.36808666106194, 63.62781816913236, 61.865748282401796, 56.916689872741706, 55.453253561450595, 61.17173979359289, 60.241337899238836, 64.10442536877048, 66.88579374744047, 64.67875057651152, 59.68077628843246, 59.42924253402218, 51.503677829619384, 49.37669807864774, 48.29291189870527, 48.280921213088504, 55.17840131636589, 61.2147250483113, 61.305371022993526, 64.49401870850595, 65.61161571933378, 62.217537818416474, 62.50114087135562, 64.49804306030273, 60.662133693695075, 63.645370775653475, 64.19323567421206, 65.07023449867003, 63.61263075182515, 60.369469965657885, 62.64953982445502, 62.51434356935563, 60.210084453705825, 63.40772613402336, 59.57632357074369, 61.56065848565871, 58.54019418839486, 48.03927183151246, 38.008174896240234, 39.255284647787775, 40.8453272235009, 37.00378141095562, 35.75664812518705, 38.24683150937481, 41.3333289084896, 41.24958630531065, 42.196250346399125, 45.9438750051683, 44.44890283769177, 47.407126965061316, 47.52095414746193, 46.868365887672674, 47.29244862833331, 46.47446186311784, 39.97233706135904, 39.508607002996634, 43.977190756028705, 42.028686692637784, 44.45930888575893, 47.84882114779565, 48.26762437820435, 51.9677883578885, 50.773975772242395, 51.96163415908814, 53.288775951631614, 51.023034511073945, 50.39490222930909, 51.831321254853286, 49.248114939658876, 45.69933483677526, 40.181670035085375, 37.23928443847164, 22.00078022095465, 21.48711839029866, 39.292119626075994, 39.925464737799864, 39.08983515154931, 42.75613730953586, 51.78845367124004, 57.679861514799065, 60.81070523108206, 53.13854525166174, 49.70805206606465, 54.656886900624926, 55.22991772620909, 56.58037016468664, 54.4383010556621, 54.7541146124563, 57.08371223941926, 56.739838046412316, 52.89356185543922, 56.799332557186005, 57.05496518842636, 59.43667150312855, 58.58534851381856, 58.166713945327274, 57.32844068158058, 56.25184028379379, 55.47387738381663, 59.32808068490798, 60.09894409487325, 59.73626998163039, 50.509455050191576, 50.640030753227975, 50.4475639712426, 60.586702592911266, 68.62870677824944, 65.00100858749883, 67.24145074044505, 66.11045883547875, 64.23273394184729, 66.72167393469041, 68.09342092083347, 72.17613758579378, 70.91705676048034, 71.04102719214656, 68.61235833937123, 65.50440557541387, 63.19738118879257, 52.783045153464045, 31.896212177891886, 9.053322615162019, 7.470900224101159, 45.46836606917843, 70.22906518751576, 55.11805957363498, 72.66146813669513, 30.138480432571907, 15.596690158690176, 51.578187173412694, 71.77367102715277, 72.83816306821763, 63.405427625102384, 87.56161105248236, 37.05068511347617, 0.7669343595062533, 0.328021964599048, 0.16949047214321553, 0.14842797250997636, 0.054634380034141006, 0.14371645516685902, 0.18546964132016708, 0.11638354119514266, 0.12988781736743066, 0.1903487633793585], [0.05667608862202014, 0.03633609800148876, 0.03113762069974215, 0.026370897145581343, 0.07369187435195332, 0.05694029702534599, 0.014344877638523618, 0.07154033173837009, 0.0018403158033071388, 0.016943355947132074, 0.28246835414921084, 10.174710596761397, 64.0642406863551, 46.60951299052085, 53.42286609834241, 100.01053148700346, 100.88190171026416, 65.12074285937895, 43.99628093165737, 23.882256861655947, 31.381775679126864, 56.838375829881244, 62.35148675980107, 39.178174772570216, 12.182540509008593, 14.252756699439018, 22.278038840140066, 37.35992870023174, 49.490187937213534, 55.49639178860573, 58.426061061120805, 59.646537919198316, 57.723133102540054, 58.507516922489295, 53.49863844533121, 49.052400435170824, 50.63412758611864, 54.87223679019559, 54.778605891812234, 53.8197942703001, 55.091203105065134, 56.00101255601453, 52.651724200094904, 50.37803211519795, 46.00946487918977, 43.78207637417702, 43.86873722076417, 48.107917231898156, 54.52175732581846, 55.13472180212698, 50.36466860002088, 55.0190903294471, 50.04492482831402, 52.00956160022367, 51.385422291294226, 53.314663594768895, 57.68157166819419, 59.695457719987445, 56.84773068274222, 59.73512072716991, 59.71012346206173, 59.85097969731977, 58.38486832957114, 56.79457864453716, 54.72318280127741, 53.66590399895945, 52.46620785805487, 56.95778062266689, 45.92997412527762, 36.53245372156943, 31.019831126736058, 33.326786871879335, 31.285828621156757, 29.181800619248424, 31.205773045939786, 35.63058707021898, 36.08862576946136, 36.02705240249634, 34.51968162290512, 38.30179568259947, 37.860289773633404, 34.94663161616172, 38.03861248877741, 37.743265859542355, 35.36890614417292, 32.017699749239036, 37.459741254006666, 39.571321779681796, 38.418556797888975, 43.51222122869184, 45.66725769350606, 47.06088366047029, 46.61376483978764, 47.90667218546714, 46.35193486367503, 46.88641663520567, 45.60075782960462, 48.08748168330039, 44.14864147863081, 39.65683729417863, 34.169629696876775, 26.822502805340676, 22.21255487011325, 18.07496032407207, 26.132026410871937, 36.655549464687226, 35.63192067607757, 36.45835622664421, 42.64275335496472, 49.3270291051557, 50.14716532922561, 48.69528039809197, 46.30118331601543, 43.10186286126414, 48.511709551657404, 47.986665002761356, 48.31073514876827, 48.68175998810799, 48.07325132431523, 50.33986353105115, 51.322064245900805, 49.5120826075154, 53.13361090998496, 51.26106354498094, 51.70384814662319, 51.89746418306905, 50.68924080940985, 52.1357128697057, 48.61817052287441, 46.85469642762215, 50.69754838943482, 54.0837227144549, 52.56997023859332, 43.22366422222507, 41.220121460576216, 44.65340345136581, 53.536442249051994, 54.01711302418863, 58.65692392472298, 58.37417594848141, 59.11544899786673, 59.50089246995988, 60.89750728299541, 61.381786638690585, 62.88934961442025, 60.103741153593994, 63.132493419031945, 58.93893057300199, 61.60014106381325, 64.71895487077775, 58.93360399430799, 40.60446231595932, 17.53269853130464, 7.19638285136992, 40.94110365836851, 54.19680856889295, 44.32252407073975, 43.67584682280018, 18.78233232805806, 23.547868920910744, 37.92842918826688, 64.14486892761724, 54.18015026277112, 33.47407579421997, 67.17830058067076, 5.830976376610418, 0.41553463967096427, 0.2615926420736698, 0.07947336371627547, 0.07358139681239283, 0.07231434101178762, 0.011697565055181904, 0.0409303694182346, 0.062052428557146946, 0.007418430609358175, 0.048408521369339964, 0.010337715897138321, 0.054380299313174146, 0.02186543638667753, 0.0644017405988228, 0.06595971062779427, 0.1229693845755631, 0.09838365423943728, 0.05235023909218369, 0.07447767371852552, 0.03402575302208143, 0.23843599513413447, 11.474879230222395, 73.60323705980855, 43.55549281643283, 60.62713046227733, 108.92705948122087, 107.41611542240267, 74.87248466860864, 51.018272753684755, 31.539511834421468, 33.68344406927786, 61.13412818601055, 66.87468559511247, 46.005691559084006, 15.762623087052377, 20.78744011540567, 33.206676052462676, 50.52178305964316, 58.26985659137849, 62.22435097540579, 65.89111989544284, 66.2698168908396, 63.880544324075025, 64.53934561821723, 60.59794018345495, 52.77802451964348, 54.60328378985005, 58.671107215266076, 58.83688619059902, 57.999668044428674, 59.236352136058194, 60.416860042079804, 54.43659482463714, 54.376684542625185, 50.145761120703916, 49.59286774358442, 48.718159583307084, 52.184766031080684, 55.69203569043068, 59.27682315149615, 53.543310319223714, 57.89183032128119, 54.727591545351096, 54.8254664482609, 52.050256190761445, 55.703653750881074, 59.39622009954145, 61.34938786106726, 60.520010532871375, 58.88665714571553, 59.96283392752371, 63.41821847423431, 59.59924982440088, 58.28254938125611, 56.78300765252883, 56.27697875422817, 54.78801958022579, 60.522811105174405, 51.66495784636467, 40.70930727066533, 32.73897851667097, 37.65563226515247, 36.15785168063256, 32.78273451712824, 35.46978950500488, 37.54236990405668, 40.02464578997704, 40.71071147918701, 37.44286721752536, 41.115915852208296, 41.19286098787862, 39.6899381760628, 41.29704698439568, 39.37762729583248, 33.88173557096912, 31.272286638136837, 40.24512221736293, 43.463634829367365, 42.64982931075558, 45.43094665773454, 46.988202141177275, 48.81544613069104, 48.85998464399769, 50.90101349738337, 46.4153988130631, 45.54149081630092, 45.59097151602469, 47.086261395485174, 45.16133469920005, 39.982119452568796, 35.97956426682011, 26.877719971441454, 22.185872947016072, 23.891974533757857, 33.55581406624087, 39.87562318002024, 36.302210592454486, 40.38963802399174, 47.42659368822652, 52.322594196565696, 52.15687013441517, 50.85722023440946, 49.459864093411355, 47.66676041387743, 49.73261002571353, 51.213724459371264, 53.09590124314832, 54.025769695158935, 51.73152831292922, 55.34997755481351, 55.16466125365227, 55.307780696499734, 56.45086526870728, 55.77723741531373, 55.801705160448634, 56.419250965118415, 55.582546649440644, 55.73021211931783, 51.90581490916591, 50.2631772718122, 54.996638682580766, 57.047500917988444, 55.86550643367153, 47.200390600389056, 46.737931389962476, 48.1594846325536, 58.88654731935071, 59.371018871184326, 62.55153548332953, 61.51100127927719, 61.342256992093986, 63.34917299209103, 63.947577630319905, 66.84052175091159, 68.2196584824593, 64.70585023203205, 65.65045110640988, 63.713725920646425, 67.86360140769713, 68.23998420469223, 65.19374601302609, 46.46801740892472, 22.357666877008256, 10.753640667084726, 44.06910757864676, 59.280329750430205, 51.197944764168035, 53.683131048756266, 24.314668755377493, 28.9088075776254, 43.18483275751914, 73.12427643806704, 59.31054376786756, 36.98854300283617, 73.41586543667701, 5.514689193617913, 0.31353763214522795, 0.2616197002991553, 0.07265396311037964, 0.03826166382960735, 0.03450894382812324, 0.1188383014091561, 0.00410948092335715, 0.09075541800308613, 0.05221708918050413, 0.09270856682691844, 0.1475693718079598, 0.13377208232639298, 0.1283728708362868, 0.11524640624561619, 0.1807382516562939, 0.27953837427400774, 0.199383897106013, 0.09459940971986902, 0.18184056024878256, 0.1997195049038818, 0.2002636878000152, 24.71548007380578, 92.92512278403007, 63.755659980158654, 67.98913294269194, 106.80048373437698, 108.76403793211907, 78.53557832779424, 57.91330922034479, 32.84973840559683, 42.221832044662975, 69.80621014871906, 72.40433323767878, 50.45953504500851, 16.707222000245128, 22.801951785241407, 39.92361337907853, 60.54840457054877, 64.50488759625343, 70.40728199866511, 69.44382236849877, 70.70927312297206, 68.52366570503482, 67.1645095271449, 63.00700110773887, 56.344106197357185, 57.223905594118186, 61.845210752179554, 61.8220805352734, 60.34908540787236, 62.23050125183598, 63.724814461123565, 59.71611292131486, 57.46450378048805, 53.38218719728532, 51.42301036465553, 51.76178155406829, 54.279119506959, 61.18670755817045, 61.95686101913453, 56.10819916571341, 59.640066008413996, 55.26617219371181, 57.15565635311989, 51.985238982785134, 55.226905345916755, 60.8955107965777, 62.535822468419234, 62.49579468081075, 62.63962015028923, 62.2935337405051, 66.93924780814879, 61.90867077919745, 61.097661910518525, 58.78084336557696, 59.895828077870036, 57.790876357786125, 61.986106211139315, 52.761405437223374, 44.77388689594884, 35.72786969523276, 40.80127508409562, 39.25158193034511, 35.03499869377383, 38.090270103946814, 38.36358870229414, 41.52410514893071, 40.898039956246656, 40.22859727182696, 43.97275063299364, 44.426572784300774, 42.419884281773726, 46.38972297791512, 45.648724494441865, 42.64343976974488, 41.33228948039394, 43.445289904071444, 44.48482390372984, 43.45150293842439, 46.05690202405376, 49.65559036500993, 52.33563999975882, 54.18652019193096, 56.39949006419028, 50.86963453600484, 49.46944644374233, 50.83192094679802, 50.19611650897611, 48.40372670081354, 40.883138871962025, 41.93764848093833, 31.880446210984264, 28.200790343746064, 23.644794610238847, 35.706092696036066, 42.18216511511034, 38.423942212135564, 42.35776962772493, 49.454757167447, 57.65430335075625, 56.32411779895906, 53.15295211730465, 51.76945763249552, 50.67434756986557, 55.04341294688564, 54.40265063316592, 55.170784073491255, 57.8640167943893, 54.099671071575536, 57.80620105804936, 59.14893034965762, 58.89277996555452, 61.267131836183616, 60.495001500652684, 58.90215443026636, 57.956431758019235, 57.86725274978146, 57.66852978737124, 54.26699546075637, 52.43239310479934, 57.74976991838025, 63.24755222566667, 61.0696130414163, 51.806822130757, 49.682729244232185, 50.84807718953779, 60.49831982581847, 63.141620774422925, 67.02171956339191, 64.97994545967349, 64.98329124143048, 68.71976067942958, 67.35645463389736, 69.21572869823825, 70.31934245940178, 65.48144402042513, 69.93392252152967, 67.43581202722365, 74.70217535572668, 74.59973873630648, 69.95647615002048, 48.2731431530368, 21.959012862174742, 11.424783698974117, 48.06319044482324, 62.88187357687182, 58.10254396930818, 57.0045627317121, 27.28830191396898, 29.642226080740656, 57.635687781918435, 79.37149032469719, 69.05917121518043, 50.02881565401631, 87.31967926025392, 8.674884496196624, 0.6949374776694083, 0.562991151405919, 0.24069129669618225, 0.11323691931583228, 0.14951309008944422, 0.22695403786436205, 0.15982875510329203, 0.15412100170168186, 0.17453920606884266, 0.1733408147288907], [0.048307167936957655, 0.10384358585842195, 0.08996997103695908, 0.02261092037623448, 0.01476490162237878, 0.06516942964686502, 0.12368468853134303, 0.12047206817735588, 0.11980475963003213, 0.05555804458356673, 0.04522141557367099, 0.06838936614052904, 21.908245625034457, 60.67825855747346, 39.42497814855268, 75.26174852924963, 119.41981546340452, 67.62380338484242, 40.463198154203354, 35.38373270342427, 26.885562750601, 52.53300974445959, 60.40559891731509, 44.47576322863179, 20.224403489020563, 24.70075745736399, 35.04340041068293, 46.213820365167436, 53.9078789372598, 57.434568251332934, 57.93820058145831, 59.84247992115637, 60.18653062082107, 61.32023288357643, 61.0947044434086, 53.389043500346524, 46.397379444491484, 53.073018135563025, 52.77711060739333, 53.80133167389901, 52.2614562126898, 51.45808419873638, 52.07297063642933, 46.24064153240573, 46.40629891426333, 45.646351460487615, 44.179667426693825, 46.545672493596236, 49.64990292826007, 51.43363606545233, 55.31115393484793, 54.16482556250788, 55.549065297649754, 46.95015122813564, 51.82322548281763, 58.67424118903376, 55.86802067295198, 57.0518704383604, 56.43566216191938, 55.53987126196585, 56.61667954537177, 60.57067578838718, 59.4747067266895, 55.68943123663626, 50.83573741297568, 51.10269784927369, 48.83385381390972, 55.92815060769358, 51.594100229201786, 42.07620620727539, 32.708089851563976, 36.411036752885394, 36.7986257614628, 29.359444764352617, 30.992186261761574, 32.073085577257224, 38.37393983717888, 37.801112974843676, 31.77291443271022, 36.13895370114234, 36.32412095223704, 39.21455475591844, 36.3410577466411, 37.50215776505009, 19.331417083740234, 19.85633611679077, 39.323267167614354, 40.290245163825254, 43.42827073989376, 47.31751649610458, 47.43960026771792, 48.269993489788426, 43.21654904273249, 44.41078132198703, 47.60271203133368, 44.1026948344323, 39.52448475745417, 41.214994922761, 40.92867758966262, 35.25485146430231, 26.459585505147135, 19.696707417888028, 19.403567121874904, 31.406851391638483, 40.98858002693423, 38.26690619991672, 36.07008472565682, 37.729392436242875, 47.151902260318884, 49.227436204110425, 46.02138888451361, 45.533944176089385, 42.12232543576149, 42.187727036014685, 46.50293434819868, 50.758804044415875, 50.472714208787494, 50.88821088114093, 47.47748644121232, 52.443775823039395, 51.485548634682935, 51.94003758891937, 51.171519756317146, 53.93091893965199, 49.91779296628891, 51.84131153168217, 53.47499832030266, 51.79636901424777, 48.07567142671155, 51.34902269609513, 56.74604715839509, 53.52154508713753, 50.46029598482194, 43.22679819599275, 42.68695062206638, 45.166272963246996, 56.582684363088305, 56.32441982146233, 59.48783882202641, 56.33141732984974, 54.901564351974, 55.19769937761369, 58.93645947979343, 60.17515182495118, 65.64255145288283, 61.24334266108852, 60.87319251029723, 57.42089879128241, 61.68330315620669, 61.518763649848204, 65.17942543952697, 46.38820502065843, 24.95366011896441, 11.21987025583944, 45.383689941898474, 50.38470798923124, 46.30509391907723, 26.998170075878022, 21.31910170278242, 36.66261757573774, 37.842101743144376, 66.7846985786192, 50.016507256415586, 43.4548879438831, 64.33248373769945, 3.586723395893651, 0.3282938645251336, 0.2601355734852053, 0.10065309778456727, 0.04470856950408028, 0.03915046754803869, 0.1250828143149134, 0.05371868662956742, 0.10314400202684826, 0.06204879346994623, 0.14957365700073783, 0.04473441731064551, 0.03406968433409929, 0.06651565297356536, 0.11171913059848933, 0.03207328410128192, 0.05751286347907397, 0.03649418790554328, 0.04838670701569608, 0.13230375224544158, 0.09501518861901376, 0.04281051006288298, 0.1433154234602567, 22.407282898502967, 68.82974393906133, 40.239862318961855, 86.5003667339202, 127.5669627035818, 76.57044733724287, 46.94477365862939, 41.517495955190356, 34.11987835361112, 59.6114601627473, 65.5258099494442, 51.12849920026718, 23.38777934351275, 31.95268842481798, 48.578009374680065, 61.01457826552853, 61.619737225194136, 62.496739972022276, 61.87775857986943, 66.26264679816462, 65.19737028306531, 66.86197711575416, 67.13073007522091, 56.44117701438166, 50.744879630304155, 55.85068379679034, 55.74397179388232, 60.91767611042146, 56.739269302737334, 56.280854055958415, 54.40614154261928, 51.963022678129136, 52.08147433496291, 51.80707316244803, 47.38742489968577, 49.525524570095925, 52.466988409719164, 55.117906601198264, 57.84385581170359, 59.927277641911665, 57.960012881986565, 49.471521377563484, 56.49039883767405, 61.93714326427829, 58.443460695205204, 57.55009774238833, 58.936498703495154, 56.502758226087025, 56.83162150844451, 62.36726253263412, 62.68767702964045, 58.81579560618247, 52.51733595325101, 52.65560342419533, 51.92289683126634, 57.75845404594176, 54.271066880995235, 45.95790924564485, 35.90558052062988, 35.976045900775546, 39.48014628502631, 35.81131027590844, 32.84372345093758, 34.34979200363159, 38.58734815351425, 40.798545114455685, 33.64219250217561, 38.28913034931306, 39.65067132826775, 41.88775985471664, 38.50337413049514, 39.16273240120181, 19.956678190538963, 26.709603263485818, 46.41185299042733, 42.79208975453531, 43.35537349024127, 48.9890149331862, 46.91560299165788, 46.13027388049711, 40.028168078391786, 45.12125199840915, 49.17746520811512, 46.68446163977347, 43.84474408242011, 46.07042243403774, 44.38883173850275, 37.05269728937457, 24.837063743222146, 21.281121392403882, 27.843376128904282, 36.45470450001378, 41.818937947673184, 38.30118379285259, 36.37818690269224, 42.83290593854843, 53.253796254434896, 55.063883796814956, 49.512008082482126, 47.71455057205693, 45.56681363813339, 47.06794392678046, 51.28187171874508, 53.986871550160075, 54.330314282448064, 53.07447333489695, 51.44415586225448, 55.7698162909477, 53.71084259402368, 53.100419813586825, 55.81821049413374, 60.16159611363565, 54.86701611549624, 57.06333552637408, 56.26873785449613, 54.47776402196577, 52.7719291563957, 55.82734569426506, 59.10092053874847, 57.4566472730329, 52.488718340473795, 44.741629323651715, 46.53459572022962, 49.165462755387836, 60.49914352355465, 61.91047114710655, 60.489200315167835, 59.255387398504446, 58.95439255622126, 56.82118408141598, 61.30051905109037, 60.36394726845526, 67.51311409857966, 63.617984787110366, 66.27166824956095, 61.71898495766425, 66.36775847404235, 66.85380289631506, 74.4657741054412, 52.887254684202134, 28.794670527981175, 14.868795333370088, 49.20977377122449, 54.73193753150202, 53.818197865639966, 32.53793743348891, 25.369782409360333, 39.17132631424935, 43.831800260851466, 72.31312244169175, 49.13355819640621, 44.54600503367763, 70.84656392374347, 3.0569418495701206, 0.2944948007502864, 0.07897761289871509, 0.18761972836669416, 0.02827950944793561, 0.0369617045526543, 0.17636532985395, 0.054581286310548746, 0.04695254062572795, 0.1099053638116006, 0.3365699736581695, 0.117957093452494, 0.1906502955863553, 0.3623224788856122, 0.16674654438130318, 0.11041572392587701, 0.2880397132567821, 0.20020445388170982, 0.3135877649389929, 0.19656901428055382, 0.1776437620602308, 0.17910521267162216, 0.2760243596088502, 45.79267547976586, 80.41818264992007, 54.75112576638499, 86.07083582109021, 123.8244253589261, 83.00928469627135, 51.17569708055066, 43.57079006010487, 38.16811346238659, 65.75921058654785, 71.27085455002324, 54.13928701031593, 25.519371801807036, 31.104952443030577, 52.89901394997874, 65.63424779522803, 67.53527549005324, 68.78090258567565, 65.9698732437626, 69.30999109821936, 69.74130276710757, 71.63465438350555, 70.95344066619873, 58.28315734863282, 53.41516256332398, 59.76196542862923, 59.29681939463462, 66.54130766468664, 58.781678830423665, 59.920111471606845, 58.15931243281211, 53.275675235256074, 53.94037969650761, 54.409757967918154, 52.40269291785456, 53.0832790559338, 55.28971033711588, 56.091093709391934, 60.3278693076103, 60.63633234270158, 58.218916769950624, 48.69963815135341, 55.13620838042229, 62.58845675376154, 60.008113768792924, 59.60565897726244, 60.45146319173998, 57.87043379199121, 58.6462236988929, 62.44987549320344, 64.92513818125572, 59.544972065956365, 53.59626623892016, 57.34390266479985, 53.752517777104536, 61.33249813510526, 56.62857217173423, 49.49343958208638, 38.50242883928361, 41.962430015687026, 41.71990986793272, 38.23836703454295, 37.67378107193978, 38.77064443403675, 41.936711034467145, 44.53830542102937, 34.686825583058024, 39.766165517991595, 42.28736700550203, 44.75176472817698, 39.01189373385522, 45.016430577924176, 22.270429442005774, 33.75327010308543, 49.802824374168154, 41.68754639164094, 43.73177197671706, 45.91599479798348, 49.38641771193474, 48.17148316291071, 42.25241476489652, 51.22032580837127, 54.93222159724082, 52.292372334388, 51.6247574744686, 53.165958696796054, 50.054303215396025, 41.77300307058519, 31.44034843291006, 27.671815579937352, 29.302901837133593, 38.244023092331425, 45.29759391661614, 41.30191072340935, 38.74669444176459, 44.99605778724917, 56.988688899624734, 56.29536290322581, 51.9829914646764, 52.17888639819238, 49.97644416747555, 51.43929604561099, 53.5602157346664, 58.40480573715703, 55.718233200811575, 56.85581861003753, 52.25741224904215, 60.530440115159564, 56.654710846562544, 55.969916005288404, 57.18407000264814, 63.07905112543414, 56.234283754902506, 59.60893415635633, 59.539747468886844, 58.30910774969286, 57.638966883382494, 58.747695415250725, 65.90736635269658, 61.39351060313564, 59.43644008328838, 50.50197901264314, 52.93127544464604, 52.74874794867731, 65.15194923646989, 65.31666524948614, 65.42145921337989, 64.28749807419317, 61.93766101714104, 61.91873950342979, 67.15781796363093, 65.61788366686913, 74.29147181972381, 68.0801554649107, 70.29970707431917, 66.99055241000268, 71.77797778960198, 71.34081394441667, 77.69106065073322, 56.583021686923125, 30.531856898338567, 16.037550837762897, 52.488290802125015, 61.5392384221477, 62.51253143433602, 35.19822028375442, 31.98146881595735, 51.29477239424183, 59.563207164887466, 79.78075042847665, 70.18569946289062, 60.90257106288787, 80.93922245887019, 4.585511078757625, 0.5258344774765353, 0.41337617162254553, 0.24305507630830814, 0.19843040875369505, 0.23450463108958738, 0.26144478710428365, 0.11103637005773284, 0.28137352257486314, 0.19419020402335352, 0.3559769113217631], [0.3003854040176638, 0.1532556594259316, 0.05785637730432134, 0.10678266685816551, 0.04894856739068224, 0.26948769907316855, 0.2995506133283338, 0.06170384706028047, 0.05413322829671445, 0.07846196677776114, 0.2308657440927721, 0.4264892986224544, 1.0094001456614465, 62.63965545162078, 45.37531960395075, 38.27180524026194, 20.316624295326974, 47.309644299168745, 34.420025963937086, 26.149592745688658, 28.38599289617231, 38.884051922828924, 59.55752757287795, 48.897062809236594, 24.81442382258754, 36.231384354252974, 58.58213609264743, 58.24216465796194, 57.62779597313174, 57.32448693244689, 59.00819963024509, 60.043034630437056, 67.84995940423781, 63.92674199996456, 62.68841835760302, 48.75060150700231, 44.710552384776456, 47.09631443023682, 50.53529954725697, 51.735854687229285, 53.10635435965754, 48.574318424347915, 47.68720380721554, 46.93432446449034, 47.46191070925805, 49.20787534406109, 46.07355640780541, 43.96502356375418, 48.58048046788862, 52.064768960399014, 55.23997468333091, 60.92160240296395, 60.96208126314225, 53.22304879465411, 56.40282015646658, 60.635410585711085, 61.82767383513912, 54.74297115879675, 50.79003787809803, 55.1702388640373, 55.27754314484135, 63.37431930726575, 62.87502511855095, 56.522797615297385, 50.816054959451, 49.31391662166965, 45.945863646845666, 51.33956586160968, 56.700406459070024, 45.76732127897201, 35.786540508270264, 33.4807595129936, 37.30785923619425, 32.31973794198806, 26.88225619254574, 24.608709235345167, 25.898084486684493, 33.496347012058386, 31.512824027769028, 31.578472737343084, 31.967815045387518, 35.18376242729926, 30.37878836354902, 33.609307350650916, 26.799588318794008, 43.0520801390371, 58.169259563569106, 52.84195523108206, 50.272147732396284, 57.79263357962332, 50.117826000336684, 51.72654298044021, 38.00627254670666, 33.87692282276769, 32.50637804308246, 24.4781001921623, 22.31899034592413, 22.000119301580614, 33.688468625468595, 33.993095582531346, 17.92009730492869, 20.17150052132145, 27.008858534597582, 35.49845810859434, 36.382050437311975, 35.3207080594955, 33.92086121343797, 39.83714472862982, 49.030027235707934, 47.679810139440725, 42.61156266735446, 41.59812811882266, 40.27772103586505, 45.1657905117158, 46.762124569185325, 49.382075648153986, 51.79961281438028, 49.40752398583197, 49.70629484422746, 52.220373307504964, 50.769857283561464, 47.83555569187288, 53.66509599070395, 58.564693312491144, 57.59220438618814, 54.494543921562936, 52.035100152415616, 50.924265307764855, 53.41254242004887, 54.12575875559161, 52.917107843583636, 48.34854287485923, 41.93318482368223, 41.02809398405014, 43.36425373631139, 47.5829589751459, 59.931054884387606, 54.549955244987245, 57.05761278829267, 57.54827776262837, 55.444055603396514, 50.4673719406128, 53.92409401555216, 51.75397995979556, 56.21528771615798, 58.616625493572606, 60.783240795135505, 56.65067080528506, 63.505597114562995, 65.43663878594676, 69.03526044661, 53.71278808962915, 23.596827945401593, 15.429348118843572, 45.78057496778427, 50.97784488431869, 38.12334352923978, 20.92900041610964, 23.650017246123284, 35.19069325539374, 46.14424536305089, 56.843631805912146, 81.53178276554232, 56.447990171370975, 59.40657907916654, 1.447322111456625, 0.17743509503141527, 0.059851071076287385, 0.06458451385579764, 0.06184329421469762, 0.22039364392478622, 0.21299914877501228, 0.29611553636289417, 0.11629962392391698, 0.34501646074556536, 0.32013573293243686, 0.08570076987868355, 0.05534918986320977, 0.024752151446356892, 0.05141976785155074, 0.0937450071796775, 0.34020457056260883, 0.24568157811318678, 0.09033498128936177, 0.09857516089874892, 0.1188621573871182, 0.49229848829488604, 0.7940254348420328, 0.9105744357070616, 67.49516533267114, 48.19131466650194, 45.973128041913434, 36.43383356832689, 56.64284175442111, 42.04573331340667, 31.206632045007524, 32.371932921871064, 43.85707601424187, 65.54078948113226, 55.77182062210576, 29.120411603681504, 38.94195002894248, 64.4088444402141, 63.308670597691695, 64.7240343401509, 56.46891601624028, 60.98136363490936, 60.84335111802625, 71.91048329876315, 67.12250878733974, 67.73733246710994, 52.0233565761197, 47.030202880982436, 49.7727241054658, 53.07412816632179, 54.689352358541186, 54.49529701663602, 51.55278590417678, 50.9688469671434, 52.080580034563624, 50.53882968041205, 54.20336677182106, 50.83905181577129, 47.85654429466494, 49.860867607978086, 53.414252573444, 56.98498618218207, 68.40278610106438, 62.767332523099846, 57.1390490378103, 59.741400441815784, 64.3220070869692, 62.92517262120401, 56.45830600492416, 56.50124811357068, 54.77306750512893, 59.10218746431413, 64.29644500055622, 65.03520381066107, 57.96793999210481, 53.194537085871545, 53.38145763643327, 47.06992472371748, 55.24428144578011, 58.20705552254954, 51.58100343519642, 40.06954908370972, 38.74469795534688, 38.802219513923895, 38.788381391955966, 30.50569861165939, 28.982393203243134, 27.263016354653146, 33.84579097071002, 32.75176152106255, 33.93091032581945, 32.59173274040222, 38.18389707996, 32.94665821136967, 35.33095329038559, 47.29334685110277, 75.48446070763373, 74.4789924929219, 54.24621082121327, 56.66310864110147, 55.84940118174399, 49.41265444601736, 50.77671358662268, 37.637667809763265, 38.37239834570116, 39.832488875235285, 31.81508383443279, 27.08856894123939, 31.649983429139663, 41.37108564376831, 39.84760568987939, 23.597943859715617, 27.567196161516254, 32.51796864694165, 37.843137248869866, 39.11911564488565, 35.615689908304525, 35.9556770324707, 42.74198147558397, 53.1203297645815, 51.20112580637778, 46.063189583439986, 44.65667078571935, 42.81225858196136, 49.75885068216632, 52.75452167757096, 53.11321458508892, 52.83350644573089, 51.996252998229004, 52.813937740941206, 58.09146719594156, 52.29662810602496, 52.23114413599814, 58.09355389687323, 62.64896323603969, 62.66466448383947, 58.658485028051565, 54.38051277591337, 55.66903491174021, 55.562946565689586, 56.98579811280774, 58.24589090962564, 50.367261286704775, 44.98005059457595, 46.4886490760311, 46.57137186296525, 51.99859857559205, 60.70185945880029, 58.53685625137822, 62.22965009750859, 59.49100809712564, 57.60059433598673, 53.30872904869818, 58.33015911040768, 57.60201031161893, 59.57396622627013, 61.014562576047844, 62.40718441624796, 59.826209929681596, 65.32112106200188, 69.81391368373748, 74.04809659527194, 59.540853577275435, 25.09027038851092, 18.26555221311508, 51.416146216853974, 53.78163745326381, 43.43193031126454, 21.125052244432514, 27.778235366267545, 31.997613291586603, 50.75976894747827, 65.74450169840168, 99.12692346880513, 58.99211006779825, 64.73523270699286, 1.8013694618017444, 0.11300743767811407, 0.07214718828758887, 0.07247709639130101, 0.06902869715685807, 0.3680770862246714, 0.39013079637962006, 0.18300004964393957, 0.16907689191641348, 0.42178861376258636, 0.5056690821243871, 0.37907320585462356, 0.21657327069870888, 0.17764305725934046, 0.30820734558566926, 0.1236007099730834, 0.3113202366136736, 0.6943195817932006, 0.33863822719262493, 0.3563255426143447, 0.2819908975112823, 0.523746918526388, 1.1861227789232809, 2.9634318092176994, 95.87995406120055, 59.329359377584154, 54.08520144800986, 30.794494882706676, 60.8588719367981, 44.874876160775464, 32.57546667129763, 35.06469103597826, 51.68635829802483, 69.31123841193416, 60.39878968269595, 29.14402427211885, 42.088534216726984, 68.1459100784794, 67.58900411667364, 67.60901604929279, 64.7843211696994, 63.702421649809814, 65.63636587512109, 77.80029081529187, 71.57517556221255, 74.40532253634545, 56.10233129993562, 48.683874145630874, 51.85622830544749, 56.66290075548234, 60.17243754479193, 60.213132135329715, 54.02585598730273, 56.34505933330905, 56.0867634127217, 54.19386286889353, 58.82478175624725, 53.13266561877344, 51.87003504845404, 54.71121564988167, 55.82604346736785, 56.10893264893563, 69.65406925447526, 68.40931292503112, 57.90828858652423, 60.25012400842483, 67.95369040581488, 66.3322296450215, 58.216775155836544, 56.403384977771395, 58.26958987020678, 58.96061343531455, 65.85022526402628, 67.26149405202558, 59.12791821264452, 54.66179770808066, 57.5427629101661, 49.81816084154191, 56.15853886450491, 60.94923942319809, 53.692976197888775, 41.47330653282904, 42.5689108141007, 44.84587807809153, 39.45034411645705, 36.69121949903427, 36.96614234678207, 33.813356891755134, 36.12166389342278, 34.22344461564095, 35.76661094542473, 33.97297774591754, 42.38854846646709, 36.53684677616243, 39.27893261755667, 37.381242859748106, 72.7722123361403, 70.74118552669403, 57.411944020179014, 51.48928665345716, 56.6924048239185, 44.8497651469323, 51.36122126733103, 40.227734350389056, 42.7370471339072, 48.509336517703154, 42.0289259572183, 37.84968760705764, 44.749081826979115, 53.82182213567919, 47.295437474404615, 30.083567250159483, 29.780613183975223, 39.284133680405155, 41.78373075300648, 42.09283705680601, 39.211875777090754, 37.025982026130926, 42.51782194260628, 55.85178990517893, 53.43518234068348, 51.275086018346975, 50.59245632540796, 47.896760356041696, 54.34412494782479, 56.74075588103264, 58.817776403119495, 60.905685424804695, 55.5498811506456, 56.03787891326412, 59.36109919701854, 53.068044570184526, 51.84828942821872, 59.4259948115195, 68.65217039662024, 66.35832125140776, 59.76979840186335, 59.6695073189274, 60.77840059034286, 59.78156943475047, 62.43369179387247, 61.93422109849992, 56.48834351570376, 50.79233246464884, 49.12333257736699, 53.75313751159176, 55.60412753012873, 65.83373561982187, 61.176372112766394, 63.955332156150575, 64.66573615227976, 60.70405990846696, 53.59357549298195, 61.28190740462273, 59.759051107591205, 61.26924991607667, 65.28955774922525, 69.37662432270666, 63.706700955667806, 70.50002251901935, 76.54235532206874, 82.26079448576897, 65.93169289250528, 29.080525021399225, 21.010499423550023, 54.4025957199835, 61.02832225061233, 51.1582503780242, 26.417241557951897, 31.55832744413807, 44.28993701934815, 70.24483311560847, 71.54600097287086, 103.48866185834332, 74.60778743990006, 77.07575059706166, 2.169512462231421, 0.3635135311032496, 0.11776286718105117, 0.16437262176505982, 0.14176440184875844, 0.6147921782347464, 0.6143206357955933, 0.33969503016241137, 0.19098530583564313, 0.5597945422895494, 0.7191058969305408], [0.1664783369990126, 0.06289721669388876, 0.1535514612952548, 0.01514280800737681, 0.1576209050272742, 0.34163360033304463, 0.1908484365670912, 0.12292927987272702, 0.12043060749889382, 0.17108732113434424, 0.5348771341866063, 0.6631196398408182, 0.31513664150430315, 24.00849246209668, 54.76265361232143, 29.024739111623457, 19.72891203818783, 52.10001930113762, 36.2350635374746, 23.18553605387288, 31.481427415724728, 36.80897297397737, 58.179677378746774, 49.22835011636057, 33.37411026800833, 31.429365796427575, 69.75496046004757, 58.362408837964466, 65.18845473566364, 54.686269375585745, 51.399542823914565, 58.28375354889901, 61.18569166429582, 57.261348539783114, 59.115292103059836, 44.43720632983793, 46.430645065922896, 44.908730137732725, 46.97954939257714, 48.84080817622524, 48.13061206571518, 44.330706134919204, 46.63714608838482, 44.8730287244243, 48.3084797859192, 48.1121337798334, 46.58622587880781, 45.58852395703716, 42.82234691804455, 45.68067612186555, 51.18807608081449, 62.84601919112667, 59.02681912145307, 56.53007361196703, 55.24180250783121, 58.620959712613015, 58.78538939260668, 48.59336937627485, 53.35258506959485, 53.166401924625525, 54.37686104928294, 61.759044124234116, 60.30940278883904, 54.35418190494661, 51.004081618401315, 48.3494960108111, 44.24532005863805, 52.39740948523245, 53.57312425490349, 49.72296099508963, 41.479825512055434, 40.87496465252292, 35.42406251353603, 35.93692025830669, 28.39987220302705, 18.49487554642462, 20.301438839204852, 33.94139089891988, 32.526456655994544, 34.296816472084295, 29.72863393445169, 31.266448190135343, 30.363814715416204, 31.332014529935776, 55.53714521469609, 104.12634511147778, 67.66988338962679, 40.37062629576653, 58.0678153038025, 57.11903710519114, 51.20657005617696, 48.41923575247488, 32.06834931527415, 17.80066309436675, 11.426525231330626, 7.960054105327976, 5.638710616096374, 10.050997080341464, 25.212497326635546, 37.310769634862105, 29.679529782264467, 24.62384173946996, 22.825013360669537, 35.86411322316816, 31.84323076278933, 33.45184380008329, 35.75867991293631, 47.72857696779313, 52.58435749238538, 48.338791862610854, 40.684584571469216, 38.13871922031526, 38.574180756845784, 44.99110775609171, 52.037026036170225, 52.968259473000806, 46.94682898059968, 51.05433110267886, 52.47678649040961, 58.43076006058724, 52.13223764973303, 50.08391711019701, 52.36790541679629, 59.79835717908798, 56.719657451875754, 54.71301994016094, 48.69128742525655, 49.749393847680864, 51.6203095066932, 49.671844667004, 51.28281700995661, 42.58233316483037, 42.25794922920966, 41.10679634155766, 40.2713942527771, 47.67266750335694, 56.98403696860037, 55.724277573247115, 57.69504108736592, 53.866811721555656, 53.49514361350767, 52.566985314892186, 55.60255073731946, 51.52753760737758, 53.979187626992505, 50.895796745054184, 54.373295614796305, 53.485808372497566, 60.51251488347208, 63.94117239982852, 69.39917010645713, 51.131288005459695, 19.842868658804125, 13.690297642061788, 46.311287341579316, 45.61316428645965, 29.237796375828406, 19.281483350261567, 26.75574798737803, 39.319862550304784, 39.112800628908225, 56.583398234459665, 83.67372635872134, 47.77807335699759, 56.18199463813536, 1.8893838938205474, 0.04912928370158038, 0.2786067194275318, 0.08058203849941492, 0.29545234936860304, 0.8969196232576525, 0.6465723858244958, 0.14485941238461003, 0.10228252849511563, 0.17239282688786908, 0.8007934232873302, 0.3453170123600191, 0.04280605526160329, 0.16430597211564743, 0.19052931498135292, 0.18125851728743125, 0.3635795065952886, 0.32978601994053014, 0.317773025843405, 0.30091758997690293, 0.20322579740276261, 0.42228503873752016, 0.5593334799332004, 0.2518147861044253, 28.54595695772479, 62.487847958841634, 30.371326054296187, 28.585294408182946, 64.12612392056373, 46.09812221219463, 29.676778239588586, 37.45872928250221, 43.2489360532453, 65.97759246826172, 55.8847927278088, 37.64186474584764, 32.333056349908155, 71.19694925123646, 65.84871122913977, 69.1226351645685, 56.79406481404459, 53.049468225048436, 60.576096503965324, 61.35703648290327, 56.89801546835131, 59.52628197208528, 48.694193901554236, 50.17843054186914, 48.09619718982328, 52.01574717798541, 53.78432035446168, 52.8787588304089, 48.33088828671364, 50.024814836440555, 48.327040441574596, 51.38277076905774, 53.95797152673045, 51.344009907014915, 47.30376074391027, 45.583452332404356, 46.791220711123565, 54.923094241849846, 62.96865993930448, 62.42104999480709, 59.84554329226094, 61.750650252065356, 62.77774249353717, 60.69924323789535, 51.62225892466884, 56.78507474160964, 54.81221668181881, 57.13484425698557, 60.97788449256652, 63.079184486020004, 57.76432191171954, 54.58475059078586, 53.36180263949979, 47.86272595005651, 53.668830087108, 54.14824178141933, 53.30408104004399, 47.72924377072243, 42.51326414846605, 40.93409438287058, 40.43901281972086, 37.924879443260934, 26.795526704480572, 23.523713004204538, 35.651646275674146, 34.26630043214367, 34.213183695270175, 32.7662193775177, 35.730427080585116, 34.03251932513329, 31.051398361882857, 59.89988380862821, 116.20992029866865, 66.23748871587938, 38.7502206525495, 62.80988239472913, 58.08560325253395, 53.731999858733154, 47.99756526947022, 36.30255968339982, 30.439720422990863, 22.07886088278986, 13.209873976246005, 11.644723742238938, 19.13815994416514, 36.63953442727366, 42.61566546655471, 39.85802742742723, 28.626930367562082, 30.30125291116776, 37.322999585059385, 32.49364995187329, 34.94689049259309, 40.20815387848885, 50.50494040212324, 57.39621531578803, 50.737780140292266, 45.673859042506066, 42.189335207785334, 42.15158631724697, 50.02208094443045, 56.10475924707229, 53.679765655148415, 51.118163754863126, 51.20769185404624, 53.48569854613274, 58.34403645607733, 56.187521257708156, 54.85938318314091, 57.04946602544477, 61.850027422751154, 62.009052076647365, 59.53385214651785, 54.76334787184193, 52.095947880898755, 53.53280228953208, 53.17981250824467, 51.62766787313646, 46.66673644896477, 45.60202475517027, 45.08181256632651, 43.61314773559571, 51.286225549636356, 61.39645630313505, 60.23794504903979, 64.28761966766851, 58.051486476775146, 56.15653845571703, 54.571991120615316, 56.42957464341195, 54.88421963107202, 58.68953843270579, 55.923235877867675, 57.23314669824416, 58.090031608458496, 62.90625502986293, 69.99297772684406, 72.12437014425956, 51.78644934008199, 20.112878737911103, 15.463477642305437, 53.02820897871449, 47.6229985298649, 33.67689371109009, 18.563648423840924, 29.33286874525009, 33.28855552980977, 51.237486177875155, 59.487764296993134, 82.21331027246292, 53.49027202975366, 67.14323459133026, 2.6635948015797526, 0.21381432761348065, 0.22236587599881236, 0.1912384059640669, 0.4454294435920254, 0.7291781145238108, 0.4505260733346786, 0.05760241915742236, 0.14227381967488797, 0.0853448530899421, 0.5536638164231854, 0.5108412481363743, 0.19552266075005456, 0.5443400360884205, 0.26503718788585356, 0.20486059838966017, 0.6261680936140399, 0.7325172772811306, 0.6079239854889532, 0.3401068177434706, 0.4493671048793101, 0.6858934726445907, 0.5381218536246208, 0.3887419402599335, 46.73392665001654, 80.88011234037339, 41.03903347446073, 26.985489053110925, 63.72909376698156, 46.73676252365113, 29.50045789441755, 37.9907948740067, 46.21806829206405, 71.15096338333623, 59.04240662051786, 38.46952015353788, 33.462057652012, 77.09822577814903, 68.8074884107036, 74.02201283362605, 61.41098083988313, 55.59301545543056, 65.43533655904955, 70.33404350280762, 64.60610043617987, 66.39710564767161, 51.249429795049856, 49.07216525846913, 49.395235200082105, 54.130332239212535, 55.55518811748874, 53.44780060552782, 50.85809492295789, 51.099869820379446, 52.61075896601523, 54.25265527540638, 57.734915902537686, 53.347682106879454, 49.8374314461985, 49.08046891612392, 50.123940975435325, 55.619695417342655, 67.62111263890421, 67.3899281409479, 61.13594816577051, 63.630807015203665, 64.87502597993421, 62.88169707021406, 51.68594644915674, 59.71618744634814, 56.259975279531176, 54.287419242243615, 62.61489745109313, 66.59488724124047, 59.67594785075034, 54.36488997551703, 56.37481835580642, 50.74271840433921, 56.80755384506718, 57.579527285791215, 55.55434873027187, 46.852798000458755, 46.15152528209072, 42.430725712930005, 46.09302705334079, 38.79005232164937, 32.78253643743454, 31.307376161698375, 44.71458850368377, 38.23486828034924, 37.856685115445046, 35.73431022705571, 39.92074220411239, 35.646441290455485, 38.66085337054345, 46.040141736307454, 92.26527029468168, 65.77199359093943, 44.03427693151659, 63.41837144667103, 56.13064689020957, 56.15863692375922, 49.36555462498819, 40.09995529728551, 41.94670131129604, 32.82995593163275, 23.890254574437296, 24.398227007158344, 34.045192503160045, 49.852418822626916, 50.6746692042197, 46.74211263656617, 37.99222261674943, 35.48908756625268, 42.28626874185378, 38.23814345944313, 38.816159617516306, 40.337062574202015, 50.979339307354344, 60.76049104813607, 55.23233390623524, 48.52852083021595, 47.09072505274127, 46.65603622313469, 54.602016864284394, 62.628206053087794, 62.128821649859034, 55.06084395993141, 53.09838410346739, 54.243025856633345, 63.55920414770804, 58.139025934280895, 53.02822859056535, 57.403883549474905, 67.33940801312848, 65.22952587373796, 64.8120758610387, 59.233194628069484, 55.65444761706937, 59.69496350134573, 61.25013620622697, 61.90978080995622, 51.8164986179721, 49.38184815068399, 49.2173949364693, 48.32181584450507, 54.6267121068893, 63.85600205390685, 60.61935240222562, 67.40819854121055, 60.64144711340628, 56.599315212618926, 54.773875513384425, 60.61060551674136, 57.690416612932765, 62.368537302940126, 58.255834118012466, 63.240692000235285, 60.86579492015224, 66.91512523158904, 74.77010296237084, 80.40194403740668, 59.24915867467081, 25.425880147564797, 18.74467561321874, 57.15577794659523, 56.95270507566391, 40.19940307063442, 24.351595909364764, 36.42588292398761, 53.56491081176266, 65.19787626881754, 70.42635256244291, 86.32670771691107, 61.27361159170828, 73.89396313698062, 3.14100829343642, 0.4865415214050201, 0.32632143326824714, 0.34814825882354095, 0.3327078179967019, 1.3841525849796112, 0.7148658760613011, 0.11443229226936256, 0.14819816145445072, 0.29604876413941383, 1.1496056351930866], [0.08356146168925109, 0.12751926502753652, 0.31159149302590283, 0.19862585310493747, 0.05932477633318594, 0.13059554471363946, 0.08429441631080643, 0.09855652197955117, 0.11976190467154789, 0.18526264436302647, 0.08452097915353314, 0.8075781430928939, 0.3468576764627811, 16.218104400942405, 52.685060424189416, 44.4031483896317, 67.49292173693257, 46.171372475162634, 46.6996882807824, 21.380614273009762, 44.36970626154254, 47.405844350014966, 51.11340591984411, 57.808578014373786, 40.138437671046105, 31.620818645723407, 61.41071804108159, 69.7625933924029, 67.32800176066738, 61.06123093635806, 57.87137908320273, 57.33797988583965, 52.16188684586556, 51.24250288932554, 51.462069326831454, 50.2248086467866, 53.800139273366625, 48.91830244371968, 49.97660498465262, 50.0672431145945, 49.02461044249996, 45.19515337482576, 45.610230353570756, 43.99157016508041, 45.850377467370805, 45.28371264857631, 44.30259058552404, 43.14181612383935, 43.47776320672805, 41.034660031718595, 51.035495881111395, 54.44101925819151, 58.632703288908935, 56.9165486674155, 59.715195086694536, 56.235660506832986, 52.2122500788781, 50.18578498594223, 53.138290297600534, 52.98788701334308, 56.539969751911784, 57.45512931577621, 60.56765948572467, 55.71642106579196, 53.94440797067458, 48.116315026437086, 43.18322458574849, 48.43847890054026, 54.59595680236817, 50.35823591293828, 50.24183173333445, 38.883192923761186, 41.62823230989518, 37.44732303004111, 32.59667100444917, 23.14424526306891, 20.194140441956062, 29.482501283768688, 30.420547877588582, 20.97045594646085, 21.11182797339655, 23.530063321513516, 27.980188400514667, 21.74926607839523, 40.58384241596345, 61.62423618378178, 30.986971470617483, 32.72821161054796, 46.672270913277906, 56.73473112044796, 48.55289443846672, 36.11332101206626, 15.096670331493502, 6.399745056706091, 4.798342806677665, 2.42240825968404, 5.194571816152142, 5.968757963949635, 21.028420732867335, 38.17379305439611, 39.90559008813674, 19.24764702397008, 32.58414883767405, 30.833243977638986, 28.632064750117642, 32.80392512198418, 41.226467855515025, 47.69176552372594, 52.13411254267539, 44.93268797474523, 45.0257501294536, 39.00864208898237, 40.81550544308078, 46.726615352015344, 48.0358515247222, 48.21953611989176, 47.9086608271445, 47.570183815494666, 51.93109850729666, 50.968450807756, 53.518050255314, 52.028204625652684, 53.36524255814091, 54.54873538786366, 57.227812274809814, 51.25961619038736, 51.04985175594207, 50.88082898047663, 48.09245917104906, 41.35296821594238, 38.64476773046678, 41.62529837700629, 44.32404595036661, 43.4457919674535, 40.465316234096406, 46.40906418523481, 55.86438071343207, 54.065083611396055, 59.196700895986254, 57.91084204950641, 54.91273526222476, 52.794506319107555, 51.955091645640714, 54.089367005132864, 54.21106246209914, 50.71333200700822, 54.30966300349082, 56.15426740338726, 62.87007508739349, 65.03000667018276, 67.95256860794561, 44.0862875600015, 13.266901316181308, 12.36303915900569, 45.874339226753484, 38.80214498889062, 24.949304326888054, 18.136810218134237, 28.81103857871025, 38.780842596484774, 41.15699875739313, 48.613973586790024, 28.598979557714156, 55.33201309942431, 65.08425304966589, 2.4992129254725675, 0.10441218397670216, 0.23593055054305062, 0.11325741982868603, 0.05965823908486675, 0.028858034150494687, 0.10439177539439932, 0.051538174401127526, 0.09546281379317084, 0.05922981590453175, 0.17895801653785093, 0.017475932611212615, 0.19747258434372564, 0.3450533555399987, 0.2128773407950517, 0.061798818980253516, 0.14070804320996808, 0.014619679122622457, 0.16356162576665803, 0.07495651697559703, 0.09410693009774532, 0.15722483757042116, 0.6524981678493562, 0.40444907161497307, 21.454231277588878, 64.1491521558454, 45.47124116651474, 57.57280826568604, 56.759716618445616, 53.66220520388696, 26.393140554428104, 49.98849761101508, 53.487895073429236, 57.41491717676963, 63.59816112825948, 46.00253012872512, 32.6524333800039, 60.41879377057476, 74.28809073663528, 71.845105232731, 67.55851161095404, 65.98670805654218, 60.61659889836466, 56.925162192313906, 54.9046669467803, 55.454002734153505, 56.13288656357796, 58.29016270176057, 55.2298745801372, 54.92735393585698, 53.07398696099558, 53.508185494330625, 48.085806831236816, 48.71305265734273, 47.392241570257376, 49.43740460180467, 48.14708994280908, 47.537149613903416, 47.144881217710434, 48.231503271287494, 44.25794616822274, 53.372083171721435, 59.29966311300955, 61.686256700946444, 57.6470705001585, 60.282216841174716, 57.12866260159401, 53.07673654248638, 54.29425985582414, 56.81310007649084, 56.32175653211532, 58.47563589772871, 57.66951822465467, 65.14944284192978, 62.84106131522887, 56.881502289925855, 52.96360361960627, 46.65995859330701, 49.44855590020457, 58.83045742588659, 55.85404526802802, 54.935096694577126, 42.92078664225917, 42.35028966780632, 43.24221311076995, 34.32533210323703, 34.13683868223621, 34.17014352736935, 38.76116798770043, 33.715191733452585, 25.403728562016642, 23.894012205062374, 27.19333544854195, 29.746508175326934, 23.771071395566388, 27.849140051872503, 45.26828204431842, 30.712840941644487, 36.486165831165934, 48.08231199941328, 58.962613844102435, 52.059897376645, 38.618585909566576, 19.742506973205074, 9.733954841090787, 5.369234469629103, 4.635465894975971, 8.128691507923989, 13.402572178071546, 32.64201556482623, 43.097658080439416, 41.58010090551069, 27.965889400051488, 40.289386164757516, 34.790729168922674, 32.670827334926976, 36.964977402840894, 44.45146022304412, 50.64918556521016, 57.312229525658395, 50.50943543834072, 48.427806131301395, 45.32905132539811, 48.425401718385764, 52.4466234637845, 54.51306143114644, 52.88146134345762, 50.435149669647224, 51.02685097725161, 54.819677029886556, 55.21920965563867, 56.59727165775915, 55.34441563390917, 57.04024845553983, 59.183168718891764, 59.64454535515078, 54.998595945296756, 55.532909054909986, 53.038077662068034, 49.26869953832319, 45.583707286465554, 41.65358258831886, 46.47039044287897, 44.17421925452448, 46.49383837176908, 46.46798995233352, 49.14265417283582, 58.159332044662975, 57.242097546977384, 64.47291635697889, 62.4887461816111, 56.96968893851004, 58.20976195796844, 58.07672300646382, 58.57628391635034, 57.54308062215006, 55.830746389204464, 58.45106617096932, 61.26020100808913, 66.50996792700984, 67.63266009669151, 68.77631341257404, 43.02361157632644, 11.153899911911259, 14.897425693850364, 53.10201621824696, 44.83157711644327, 25.417260739111132, 17.148072873392415, 28.300161630876605, 34.51379414527647, 48.876968506843816, 59.82602165591333, 38.20257540672056, 61.71629028935587, 72.2162320536952, 1.77765027649941, 0.12105601103675943, 0.26595352097384395, 0.1594569879553972, 0.09533024993875334, 0.06602466722289402, 0.0543794681077763, 0.01021668358120106, 0.2007684478115651, 0.05702081286618787, 0.044633400956949884, 0.3109303285037318, 0.23468504479575544, 0.3899893765487979, 0.37199951768402134, 0.23435360451619472, 0.3215821375769954, 0.24598948417171357, 0.2696383119590821, 0.16455662076271352, 0.3874599074404086, 0.2956138713465583, 0.6413939378915295, 0.6897616650789016, 28.0014221514425, 75.94846140953803, 61.03049524368779, 88.43630744564919, 61.851062928476644, 62.05204517610612, 28.470486633239258, 52.37574623477075, 59.521222114562995, 63.53690547327842, 66.22190906155494, 46.481102435819565, 35.659318431731194, 65.58961514503726, 77.40576313387963, 73.45508913840018, 69.12640063993393, 64.63930329968854, 64.36806355753254, 60.82569260751048, 57.151545709179295, 59.48928225424982, 56.61458892206992, 59.41325103082965, 55.246980036458666, 56.531858290395434, 59.033675424514286, 56.02397803337344, 49.037581720659816, 50.24012157993932, 49.5139104320157, 49.483912144937825, 50.29954156567974, 50.000394159747714, 50.77644294308078, 50.902621669154016, 45.51832529806322, 56.66713691526844, 61.63659557219475, 64.08392706224996, 61.95049108997468, 65.98476256093672, 59.495303092464326, 55.968966791706706, 54.5725324076991, 57.96558657000142, 56.751267833094445, 58.93262340176491, 60.556880812491144, 67.3346148767779, 62.52174508187079, 57.6033046937758, 56.78715752017114, 48.29402192946404, 52.40463056871968, 59.43582427117133, 56.37545377977433, 58.05534216665453, 44.475665169377486, 45.856774853121856, 48.46430770812496, 46.94136119657948, 40.89243096690024, 35.470546522448146, 45.09326588722968, 38.15959015200215, 32.53154004773786, 34.069342536311, 35.851487113583474, 39.70356056767125, 31.636925858836022, 43.65685078405565, 56.177115209641, 40.29455584864463, 44.932460477275235, 54.674164941233975, 61.98291340181905, 50.286123137320246, 45.03529717845302, 30.758564010743175, 17.29924886457382, 12.035655590795702, 11.243743761893242, 16.583524173305882, 26.88406832756535, 45.553595250652684, 49.212495896124075, 52.13254359460647, 34.06182727506084, 43.851416034083215, 38.33052704411168, 34.9313892856721, 40.18125034147694, 46.16595960432484, 55.03597221066875, 61.75158377616637, 56.230114275409335, 54.9951324924346, 48.85818819845877, 49.39460369848436, 56.106014405527425, 58.07553060593144, 57.724505932100364, 54.16809681923159, 55.6647006926998, 57.80185114952826, 59.079696593746064, 60.264515184587054, 56.23909258073377, 58.620296832053896, 62.333914541429095, 64.06389944015011, 58.882154264757716, 60.59084461581323, 54.12466833668371, 53.13278721224878, 48.80780535359537, 48.73683398769748, 50.25719565729941, 49.02407700015653, 49.33261063791091, 48.72648677518291, 53.4732214866146, 63.42526697343396, 59.40867754720873, 67.62482320108722, 66.0288578464139, 60.73330902284192, 59.789233746067175, 58.91535712826637, 60.89410266568584, 58.67237806320191, 58.38898681825208, 62.962960735444106, 63.46413766184161, 70.92796094955938, 72.19625150003742, 75.20190100516044, 50.048796207674094, 18.35452921928898, 14.981142801623191, 57.91508213166268, 50.31656072985742, 33.13362583037346, 21.724776760224376, 37.200127417041415, 52.538638345656864, 62.62448764616444, 65.9531561020882, 37.63956623692667, 70.5551710436421, 87.20334176094302, 3.403912018383703, 0.4079852415429008, 0.3242195331521573, 0.2872948306462457, 0.1537669465065964, 0.14475026017715856, 0.2610147666306265, 0.17204232634075228, 0.2495970381724258, 0.20709938309606046, 0.1377627109327624], [0.02275491426248224, 0.10168154784027608, 0.20821171211859874, 0.3308763469178831, 0.1184334469238116, 0.1277345510560178, 0.06315963245147178, 0.03054944137411733, 0.04434163637098767, 0.07260926187999787, 0.0024693577800081264, 0.5581345829752185, 0.26738236688317796, 8.741213736995574, 63.86682387321227, 46.980467227197465, 48.7579284944842, 50.4818650983995, 52.059414925113806, 23.0732915478368, 26.29051370005454, 36.6630058903848, 46.34757318804341, 55.26303429757395, 52.33476531121039, 30.218643872968613, 47.33871690688595, 72.7014684677124, 73.33671985134002, 65.96618621580063, 69.72206746378254, 63.847792533136186, 64.41528889440721, 59.50762717954574, 59.206608803041526, 57.55457316675494, 61.25794172286988, 58.149027978220296, 57.130859128890506, 54.5708026424531, 52.58079205789874, 49.346531129652455, 48.57023131462836, 45.73518530015023, 44.73056823976579, 44.19785937955303, 43.77951898882466, 44.182283647598766, 43.7532312639298, 44.06996265534432, 44.587578235134, 47.07846372358261, 51.558269377677675, 48.66218343857796, 51.05133833423738, 47.22080261476579, 50.81856919873146, 51.97570370089624, 55.53972613426947, 55.776390183356504, 55.733848156467566, 54.18161722921557, 57.61888434810024, 54.77861373655258, 53.45753985066568, 47.799544411320845, 44.15882002922797, 45.471939348405414, 53.192999516764, 53.337695752420736, 52.33729523997153, 43.89582118680401, 31.617474825151508, 44.081361063065074, 34.41229497232745, 27.18685765420237, 42.450282650609175, 37.7896047407581, 30.941654366831628, 20.781213352757117, 16.140185536876803, 16.938802657588838, 16.587730915315692, 13.566357608764404, 8.104765540169131, 8.766533617050417, 12.175693031280273, 16.1445991839132, 19.8510330723178, 28.142192094556748, 29.84754646978071, 23.244220595205984, 16.41039565686257, 8.742817986396052, 5.561425705109873, 3.9459352820150317, 3.229137577356831, 21.087507317143103, 28.658493680338708, 35.99666972314158, 23.805590214267855, 30.48326461545883, 38.12315917784168, 29.997718334198, 31.308556795120243, 36.51669363821707, 42.962308852903305, 45.46143916345412, 48.201053911639804, 42.88319072415752, 39.453517313926454, 41.86346469386932, 46.513458067371005, 45.02256516487368, 50.567988580273045, 50.28145551681519, 50.35206210228705, 48.067289321653305, 48.94961080243511, 49.60507415956067, 51.867407060438595, 51.94682721168765, 54.41592785619921, 56.271777691379675, 52.298275501497336, 49.35764320435063, 48.70103451513475, 48.95076790163594, 42.732038267197154, 40.813320682894805, 41.738368541963645, 44.47646533289264, 41.38662607439103, 44.30498323132915, 44.261052685399214, 46.496234939944365, 50.87720471043741, 56.63220036414362, 56.86277689472322, 56.14763467542587, 56.133290567705714, 56.048838015525575, 58.70245479768323, 59.64082694822743, 55.58843020469912, 52.42257541225803, 54.10037709820656, 60.42206894966864, 62.5573915819968, 68.03205936185776, 62.42212472423431, 28.71419918152594, 5.372532202351478, 17.310837507247925, 51.58931493759156, 36.99443832520516, 25.442579638573434, 18.33580186290126, 34.32660295117286, 37.342595746440274, 36.705916620069935, 59.54558395570325, 54.97409682120047, 48.063433631773925, 54.58801008039906, 0.895415639444705, 0.09733879458039038, 0.1514076408479483, 0.039309522722877806, 0.02589803128953903, 0.03793541379573365, 0.06056725603318023, 0.12252362099506202, 0.13777237896236683, 0.1041527866055408, 0.11431597713981906, 0.05021644290536643, 0.09464788776371749, 0.09106657227441188, 0.24335415703394722, 0.031576602486893535, 0.19924949464057723, 0.04479661598921784, 0.1109180094734315, 0.07283431552951375, 0.2322873428103424, 0.07693909123660096, 0.3714021529641844, 0.3543826210643015, 11.159073518168542, 77.46801899325463, 47.27874386695124, 47.584323959965865, 57.23765742394232, 55.18304540264992, 27.126566902283702, 36.00044696561752, 42.66763294896772, 51.99495469370196, 59.11810052010321, 56.003875886240316, 33.373227734719556, 45.2238533573766, 72.52820168772053, 75.24366640275525, 69.16629114458638, 71.76871315125497, 68.53142415323566, 69.2074760313957, 64.34960488350161, 63.771812300528254, 59.99829607625162, 63.429169731755415, 61.12819363993984, 61.95616675961403, 58.514184951782234, 60.35408642984206, 54.79549169540406, 52.89640557381415, 48.64263434563914, 50.190640880215554, 47.65516588764806, 46.865133854650686, 46.49927477682791, 46.033112848958666, 45.93048795577019, 48.22303095171529, 47.35890142379269, 51.67892540654829, 50.35055983451105, 52.10587539980489, 47.76602383582823, 53.01735185807752, 54.63541584630167, 55.167465748325476, 57.945484422868304, 57.84683681303456, 58.784016563046364, 59.7101430739126, 54.521149358441754, 54.22526144212293, 50.131503305127545, 47.345428082250784, 48.98594763971145, 55.29938682433098, 56.88897832747429, 54.20587708873134, 50.25101400190785, 35.55335952389625, 50.672139275458555, 45.390550167329856, 38.87989813281644, 49.43902061831567, 46.39803055794009, 36.642872364290305, 26.286493270627915, 23.41537714004517, 25.03609068932072, 22.693778699444188, 19.756584359753518, 14.848141112635213, 13.700190840228913, 14.257006587520724, 13.569587680601305, 19.29635697795499, 25.28675367755275, 31.251305880085116, 30.759379863739017, 20.014954805374146, 10.140779152993234, 7.413593415291079, 6.942800639137146, 8.878801657307534, 24.354121915755737, 34.17193997290827, 41.17501028122441, 29.88496784240969, 37.90201986989668, 42.37399255075763, 34.12179247025521, 34.054315936180856, 40.036177558283654, 47.902200683470696, 50.926563816685835, 50.48847821451003, 49.76571482996787, 43.30648506841352, 44.507707011315134, 49.22302353766657, 51.62927212253694, 52.422273389754764, 53.46027766504596, 54.55576035284228, 52.41167514554916, 50.73850970114432, 52.430957517316266, 53.290917565745694, 55.64320610415552, 55.35062474589194, 59.34566467039047, 53.96559269197526, 54.286419037849676, 52.62726429970034, 49.781482758060584, 46.52643326790103, 46.13326272656841, 44.02955832019929, 47.306722133390366, 45.24788964179255, 48.035372995561175, 47.459157205397084, 49.308715558821156, 54.86456071176837, 61.26285645269579, 59.96793693111789, 60.06104615426833, 58.77117080073203, 60.88410846648678, 61.77478067336544, 64.22512062134282, 59.19211172288465, 56.893626336128484, 58.17355455890779, 68.06940817063855, 67.52104513106808, 73.4983136576991, 61.67321482012349, 22.903143052131902, 4.4733543357541485, 20.72137563459335, 56.9027066230774, 40.239273963436005, 25.239206706323934, 23.817112176649033, 33.64573832481138, 41.428607202345326, 38.186183821770456, 72.13288953227382, 66.47277601303594, 47.660453242640344, 65.01471727125107, 1.1280057555244816, 0.1095482212821803, 0.10166009737839622, 0.13522889044496322, 0.04689444434799014, 0.002979429174898072, 0.0717672010162665, 0.11711833442771628, 0.2044366912976388, 0.26039380640272175, 0.2889192128373731, 0.17004738742065045, 0.26608746378652515, 0.18524543802824714, 0.5419337232747387, 0.23076685746350598, 0.30461350455880165, 0.2078443116718723, 0.19896305436568879, 0.21784661608117245, 0.44371460173879906, 0.14655239008847745, 1.150176952923498, 0.5298303920895823, 18.038986306036673, 92.08352335037725, 59.0476861307698, 68.93378088551184, 63.179377509701645, 68.74189853668213, 31.82269911612234, 32.94368505477905, 46.30119508312595, 60.1767913756832, 64.73806465825727, 58.394525204935384, 35.21208586231355, 52.55485342394922, 79.09706561796128, 77.27754869768697, 71.2511799412389, 73.27079265348374, 69.83344708719562, 70.9203358619444, 65.32749099116172, 64.8410660989823, 61.682906996819284, 65.65815856379848, 65.70203419654601, 63.127747351123446, 60.05523320167296, 57.850053156575854, 57.34061964096562, 54.16164452029813, 51.190488338470466, 51.215862151115175, 50.95207883465675, 47.72717275927144, 49.54785070111675, 47.290322703699914, 49.13796301810972, 51.65128838631415, 51.86777968560496, 56.51464693007931, 53.048111084968816, 57.391241750409534, 49.65693573797903, 56.00716283244472, 55.62373938099031, 60.837389115364324, 60.84723818686701, 59.51760961163429, 59.0775667467425, 63.206586991586995, 58.73089198143252, 58.93488660935433, 54.34028102505592, 48.39503472851169, 51.70275380534511, 58.30850370468632, 58.109663071170935, 55.81383312902143, 50.315846858486054, 41.66793454077936, 50.812211036682136, 48.96455503279164, 47.072089872052594, 60.193453604175204, 51.734430866856734, 45.95291606841549, 34.8395352209768, 31.649659833600445, 32.79772581592683, 30.57287508441556, 28.620026996058805, 23.553938788752404, 26.18049513909125, 30.960564113432365, 33.64296913146973, 36.91704211696502, 41.21820342156195, 36.44399642944336, 35.95983474485336, 29.576104725560835, 20.035486452041134, 14.874435701677877, 11.617213218442856, 19.117777347564697, 33.17022546645134, 37.57793403440906, 44.571778928079915, 36.26817226409912, 44.78718373083299, 45.11932219228437, 35.62377391322967, 36.59996947934551, 43.13290449880785, 51.1253652264995, 55.20768180970223, 57.07793851052561, 54.7694432350897, 46.49055927030502, 49.017707070996686, 53.42740428063178, 55.12817928867956, 55.751090895745065, 56.13393775878414, 55.753142295345185, 56.41794481585103, 54.40978542450936, 55.79534699839931, 60.490522153915904, 59.193472785334436, 58.98140984196817, 62.76857591444447, 58.76949202629828, 55.72725072983773, 56.132004030289195, 55.17002313367782, 50.242514225744436, 48.48285267429967, 47.265611771614324, 51.86566552808208, 47.79862657670052, 51.02950642185827, 51.0923388696486, 52.80523400152884, 57.67164807165823, 62.54536559504848, 62.9092909443763, 62.24436683039512, 59.94733272060272, 61.911102648704286, 65.39991363402336, 66.30991920348137, 62.62511914776218, 57.94468818172332, 60.60571432113648, 71.58418916886853, 70.49188752328196, 76.20416856581166, 69.833023471217, 32.41964855501729, 7.624659586337305, 20.40256734817259, 62.88813367966683, 47.50984207276375, 33.46971804095853, 23.4697509965589, 46.13920511737947, 54.394974554738695, 53.69507858830114, 75.09360436470278, 73.89972117639357, 60.06857710499918, 74.93812945581253, 1.8942823212954307, 0.1511942547175192, 0.2758607845152578, 0.27316299056814564, 0.14921186431761713, 0.1473083043651235, 0.19344273203563309, 0.19276929478491509, 0.3812067300802277, 0.44247068945438633, 0.2362774657986818], [0.12265035492037574, 0.03267385681430179, 0.06275518782316677, 0.030937744529857755, 0.06350679285523873, 0.07167192266112374, 0.09094311720541409, 0.13802146479006738, 0.05735428327874792, 0.07497956090035938, 0.026170003993977464, 0.09649353146913553, 0.15917810130744212, 4.043231880472553, 60.932694865811264, 56.93543880216537, 50.61276635816021, 58.92064056088848, 48.889841725749356, 29.406168037845244, 22.899954165181807, 36.9685193031065, 35.691956473935036, 43.776055535962506, 46.54853190145185, 33.06132478098716, 22.01812690304172, 37.4538851553394, 66.23764561068627, 67.52626188339727, 66.17142815743723, 65.7278786936114, 64.96108670388499, 64.17199996209914, 63.73762884447652, 63.71153723809027, 64.65301198344078, 59.17926988294048, 61.84284556296564, 59.66861694089828, 59.70371823157034, 57.920279272141, 55.391103606070246, 54.657600771996286, 46.530802788272986, 46.262442065823464, 46.121315187023534, 45.88037183207851, 45.50279663455102, 45.210203509176935, 44.75702854894823, 42.439821689359604, 43.92774535763649, 44.58172998120708, 46.57046971782562, 48.059797594624186, 51.98355236361104, 56.631357054556574, 55.55547445051132, 55.79011847895961, 56.614824264280266, 55.585825750904704, 55.81599043261621, 51.57830092214769, 49.248405195051625, 45.66468854104319, 45.058290112403135, 43.970860050570586, 48.7157630151318, 51.79120325273084, 51.23400703553231, 49.175951173228604, 33.66107479218514, 35.09501095741026, 41.48137092590332, 46.3133583530303, 42.790069733896566, 40.99338100802514, 26.848153145082538, 16.420621275901794, 16.303716994101002, 16.82796039888936, 11.688915125785336, 8.49781301713759, 6.355050629185093, 2.544549886257418, 0.5565568708604383, 1.2761463224887848, 2.256657231238581, 3.6691323932140105, 9.700048892728745, 17.17667087431877, 18.03227513067184, 11.921547958927771, 4.653503894805908, 5.529459368798041, 14.573040777637114, 25.213846621974824, 29.94403285364951, 22.755322648632912, 33.82876788416217, 37.94519339838336, 37.53745125186059, 33.44727816120271, 33.79970704355548, 35.330208040052845, 43.339464356822354, 45.096733262462, 42.87888396170832, 39.6937781764615, 39.82749177563576, 38.000969502233694, 42.997429755426225, 47.63915869497484, 48.80757001138503, 47.71629994915378, 52.186299677818056, 51.81114458268689, 51.312968269471206, 50.7645110930166, 48.24675344651746, 52.98631022053381, 51.29110105576054, 50.53413852568596, 50.81207767609627, 51.68079637712049, 49.72740111812469, 45.52609551337458, 39.78556948323404, 42.3776795787196, 41.60864007088446, 44.6930625361781, 47.1994766881389, 48.53434554992184, 46.446766007331114, 48.399498385767785, 53.268607124205566, 56.385914741023896, 57.12463432742704, 59.69294740307716, 59.727566242218025, 60.824888521625155, 60.703424484499045, 62.62514268198321, 58.096044601932654, 57.20569010703795, 56.12006825785483, 61.75165437882947, 61.01928510973531, 72.58334236760294, 45.99222606228244, 8.86262188034673, 1.8966875922295356, 28.146559653743623, 53.3963587207179, 39.12707413396528, 24.862414021645826, 13.95157358338756, 31.558715758785127, 34.173873701403224, 46.15037602763022, 45.382976070527114, 68.11296216903195, 45.124684072309925, 54.93266090270012, 0.817342454627637, 0.06652673826582971, 0.09713756626531964, 0.05481624164648595, 0.05953849188142246, 0.1457784114585769, 0.023532989547557892, 0.009581388890623085, 0.030415783929187926, 0.0965506203412529, 0.15250215066536782, 0.09073806611160118, 0.07849588915104828, 0.022606264476874666, 0.01859084526527553, 0.03004768825767021, 0.10580013611263807, 0.11404651337333264, 0.07118708093560512, 0.07484626160153458, 0.037402902249126666, 0.05076377442286861, 0.24065444786702436, 0.19298288009820447, 5.821743117224786, 68.1212148358745, 63.8576808283406, 57.535561438529726, 63.06359306458504, 57.18208920571112, 31.493302391421413, 31.734649750494192, 47.0510345889676, 37.958145064692346, 49.56404224518807, 52.29276457140523, 37.15294522623862, 21.976471331811723, 38.06380195002402, 65.92209093032345, 71.3874509257655, 69.29976155680995, 68.18848348432972, 67.40638640619093, 67.04045280333489, 68.23095490855556, 65.52836733479654, 68.51351461102887, 64.008856819522, 63.41532376504714, 62.722982283561464, 62.80946662349086, 60.9579510073508, 59.51256936596286, 59.67817183463805, 52.43016127617129, 50.85251339020268, 49.65583747433078, 50.305291760352354, 46.98228720695742, 47.93221466002926, 48.54175882954752, 46.530465464438166, 47.39377129462458, 46.54987335205079, 51.251073268152055, 52.94939287247197, 57.95171706907211, 59.60228573891425, 59.02058255287909, 59.0154520926937, 59.9005937576294, 56.57324714045371, 54.741429667319025, 55.36945212271906, 53.662742568600564, 47.55310973813457, 50.231641415626775, 49.23179787974204, 53.187115961505526, 58.338733411604366, 54.61079512873004, 52.290752395506836, 39.399070893564534, 42.46184579787716, 46.155200542942175, 50.05312650434433, 50.42541042450936, 43.75991498270343, 33.03437809790335, 21.807272049688525, 16.359730401346763, 16.623930469635997, 13.260952061222447, 10.220958282870631, 8.619053479163878, 5.641132679677779, 3.970445682925563, 2.6556593564248856, 3.00982290698636, 3.658135538139651, 9.571377500411003, 20.861516037294944, 21.907637657657748, 14.654965362241192, 7.0178174395715045, 5.881662224569629, 17.165933385972057, 28.528822083627027, 31.413705733514604, 28.70639562606812, 39.555173381682366, 41.93992737800845, 40.0663641191298, 34.8113961373606, 36.379893133717204, 39.54004872229792, 48.6293649673462, 49.03837403943462, 49.35652140648135, 45.293726459626235, 42.48125760785995, 42.88394381923061, 48.46090309081539, 53.2967540525621, 52.11503413415725, 52.150409990741366, 54.21876991948774, 55.143790321965376, 55.772714922505045, 53.758193446743874, 52.63082188944663, 55.433747614583666, 54.37110693224015, 52.22924178646457, 52.5158925210276, 54.24490859431606, 52.823606383415964, 48.334143853956654, 44.05339848610663, 45.73795841586205, 44.332471201496745, 48.941260076338246, 53.2715057557629, 54.19487876276816, 52.98268987286476, 50.76385213482765, 56.55251349172285, 58.88842613466325, 63.397061209524836, 62.86358356475831, 62.368502001608576, 63.48171380258376, 64.31796704569172, 66.05310593881916, 63.257605260418316, 62.653226852417, 61.400327682495124, 66.39680754753851, 66.04626532523864, 72.2969622765818, 39.75612032798029, 5.011301031035762, 3.1381094167309427, 33.20248696111864, 59.42548098102693, 42.20558558740924, 30.664419281867247, 20.54617904847668, 33.557288877425655, 35.30386932434575, 45.2739381021069, 50.580038101442405, 65.61202756820187, 55.51444645850889, 64.36593371052896, 1.5608574450016024, 0.05469262186858443, 0.07326393763745025, 0.09833627936219978, 0.12171678485408907, 0.09879640709128111, 0.029608725622716933, 0.041904216557140314, 0.1688631687072977, 0.1782007079811827, 0.08796043814189973, 0.17137572259431885, 0.1777557641147606, 0.09481707062091559, 0.1931396829745462, 0.1813797430405694, 0.34663027092333765, 0.20211780443787578, 0.19619761485486262, 0.14062728222099044, 0.17260206082174856, 0.27918290947714164, 0.33481652097355935, 0.37953947760885764, 7.319586459667453, 84.63314594761019, 67.81586616270005, 67.82409529532156, 75.94396637332055, 66.05364722590294, 42.54624735924506, 28.204555819111487, 46.63889546548167, 45.18864616270989, 54.725850012994584, 56.714201434966064, 40.485587043146936, 26.326477912164506, 47.09185077298073, 72.69001514680924, 71.90651386014878, 67.67518643409976, 70.3650616061303, 71.76382587802026, 69.20396943246165, 67.72238039201306, 70.00717670686784, 70.11007616596838, 65.71921025553058, 66.90955546594435, 64.4553323714964, 65.60590082599272, 62.69518052378009, 60.985893972458385, 60.86074682974047, 53.10358908868606, 52.43565259441253, 52.6354032178079, 52.652041912078865, 51.09527672490766, 51.951412462419086, 49.96144110156644, 47.108705197611165, 47.89750560637444, 49.78935495499642, 54.75376944388113, 54.86550208060972, 58.29490092492873, 62.788713362909135, 59.47584421403947, 61.46248156024564, 61.48871437195809, 58.91721240935787, 57.672573751018895, 56.001291044296764, 54.72967040154242, 52.03257414602464, 51.32797918012066, 50.26233396222515, 54.99533645568356, 57.64115164356848, 59.48798002735261, 53.98838950741676, 41.218736863905384, 42.91674267861151, 45.39182493763585, 53.40209322590982, 55.010457192697835, 57.409943611391135, 42.34621040282711, 39.13334208150064, 38.09464354668894, 33.68915504024875, 29.446378215666744, 22.233406189949285, 22.334383687665387, 24.052097451302316, 18.948203479090047, 19.228470556197628, 20.28315863301677, 20.453503247230284, 26.09127494596666, 32.247119180617794, 32.631472233803045, 18.399116762222782, 7.816829248782128, 8.296242413982268, 18.75684868904852, 31.638965491325628, 35.63322682534495, 34.88121824879801, 41.79997328789004, 48.315869531323834, 41.07330322265625, 38.29869308779317, 38.65684470822735, 44.31643655223232, 53.79806433954547, 53.62277753891484, 53.54983714319045, 48.63675079038067, 48.605038427537494, 45.5612438724887, 50.62343912739908, 56.13664811657321, 54.268450660090295, 52.9186571798017, 58.00877971033896, 57.72855381811819, 57.17260883700464, 57.820953092267445, 55.131258349264826, 59.92760712100614, 57.980338604219504, 56.21938659298805, 55.38006997877552, 56.66915693590718, 57.32360832152828, 52.6749328644045, 44.95988961189024, 48.43458790932932, 46.56595506975728, 53.78428505313013, 55.18560671037244, 53.617772594574966, 51.753858366320216, 52.71544702591435, 60.54836534684705, 62.66154619955248, 65.02495073503064, 65.68878050773375, 63.62120897539201, 66.49250553500268, 67.59662135954827, 69.13954842475154, 67.20978152367377, 64.98476605261526, 64.16080551762735, 70.3945186061244, 69.60201155754828, 80.15373645290252, 51.0214969419664, 10.939856171607973, 3.7109382402512336, 35.094199026784594, 65.73202463888353, 50.22732288606706, 35.159004426771595, 18.030062913894653, 43.2104262228935, 45.94774638452838, 63.57015932759931, 58.48073497895272, 83.98756304094869, 62.56954700716081, 75.81017432674285, 2.4397931848802874, 0.23268131118628288, 0.13565425310404072, 0.21843062022760992, 0.18645974867526563, 0.22219808742163644, 0.11409800214272355, 0.1084016711120644, 0.3276765508757484, 0.22550645344440015, 0.3263984404263958], [0.05592937506134472, 0.1288242421803936, 0.016617992660030723, 0.11995871265929554, 0.0631382815810221, 0.02699465550962956, 0.0537816092612282, 0.0713931126219611, 0.04218892930375953, 0.1285883024214737, 0.042283303675151644, 0.15333127230405807, 0.07904444640922932, 2.189829604279611, 53.71098772172005, 56.15484006943242, 34.895593735479544, 56.20072395570817, 52.37420474329303, 35.683064460754395, 20.37087263599519, 24.735129187183997, 43.4935115229699, 49.40228369928176, 52.249108591387355, 27.600369607248616, 17.18609436865776, 21.20225625653421, 35.98864455376902, 54.6112971921121, 66.2189123707433, 61.67492105114845, 63.88075220969416, 60.89739353426042, 64.529119999178, 61.72799856432023, 63.089633680159054, 65.93645464989447, 61.81367489599413, 61.78435517895607, 59.03981785620413, 60.64536556120842, 59.95826044390279, 59.61004810948526, 55.37538666878977, 47.77264087430893, 46.62607715975854, 46.33347618964411, 45.36231694682952, 45.17033261637534, 43.733929280311834, 43.6459348278661, 46.56499408906507, 46.3729509230583, 45.185174865107385, 48.83918823734407, 54.86680430750693, 57.981409411276545, 57.65544868284657, 54.9182540370572, 54.30309695582236, 54.85023621589907, 54.849647860373224, 53.448710595407796, 51.504179893001435, 47.70190485062138, 46.77220506052817, 45.04592287924982, 46.29852002666843, 52.03831649595692, 51.712340078046246, 48.98268422772808, 39.57047847009475, 34.43328357511951, 37.696181727993874, 39.54579891697053, 45.10280901385892, 30.557579801928615, 21.646829458975024, 7.743620170700935, 5.702724187604844, 7.93564078307921, 2.8900133746285595, 0.6153972038338261, 1.8540467706418808, 1.499993536741503, 1.684387835764116, 3.1731736900344973, 1.9423290269990123, 2.2587272620970205, 1.5393070852564228, 0.3739444617061846, 2.6146017014980316, 3.48533429445759, 0.9214050190583353, 1.6706277934774276, 10.35704295481405, 18.455236073463194, 27.547115587419082, 35.13906309681554, 28.891233398068337, 38.06711635281963, 35.506295004198634, 32.85479041837877, 34.09406523550711, 36.04081207706083, 42.17058235599149, 41.70857421813473, 42.77352909887991, 39.98897575563, 38.03075598132226, 38.95865540350638, 44.20806146437123, 48.13265954294513, 49.73964675780266, 50.89051723480225, 52.28495121002198, 51.55068351376442, 54.82511735731556, 50.946442388719134, 50.098896641885084, 51.470321993674006, 50.33399174290319, 52.9442741793971, 49.8834643825408, 48.0606173699902, 43.67555264503726, 40.61908883433188, 40.843201298867505, 40.93068192082067, 46.6295680692119, 54.58323263352918, 52.8880391582366, 57.499581536939075, 56.57480824378229, 51.70343629775509, 52.901084961429724, 59.14105423035161, 59.56357194531349, 58.25738345423053, 61.64588374476279, 61.072201805730025, 61.9354134990323, 62.88285024704472, 59.15825382355721, 55.98830407665622, 57.44030275652486, 58.13355815026068, 59.826351135007805, 61.209284720882295, 17.182115124117946, 0.49512241095785176, 6.0089985401399675, 39.248220459107436, 50.61222507107643, 38.293350819618475, 17.392154124475297, 19.951020171565396, 36.211525394070534, 39.59419704252674, 38.09700089116251, 40.43316848816411, 59.8548157753483, 42.44106115833406, 57.73473155113959, 0.7664834095105049, 0.05137506279072935, 0.024315847136500864, 0.09448522431475502, 0.012412457238702525, 0.1297408663817952, 0.13839534634063322, 0.10894056800152026, 0.06305769296182741, 0.02966061275782845, 0.054977077975749016, 0.05958829908781956, 0.07517807726417819, 0.01760636674120061, 0.1266487593191766, 0.053203006034656886, 0.11135336957992086, 0.07058489752272445, 0.13662916127472155, 0.048161281813536926, 0.11076327503448534, 0.0852020696226147, 0.18100469703635863, 0.027481042817535422, 2.747846087140422, 62.78012729460194, 62.58076106348346, 43.79355322930121, 63.28079431287704, 55.50152224879111, 35.54895470219274, 26.10878832878605, 33.89869982196439, 52.476562915309785, 52.163820574360514, 57.96202113551479, 29.864995133492258, 22.064783496241418, 25.992441023549727, 39.03587510508876, 56.371260766060125, 66.47680036483273, 66.11353397369385, 67.59653506740447, 64.1500739128359, 66.0438334557318, 62.59324596774194, 65.020110530238, 67.12627426270517, 65.51853003040438, 63.27970781633931, 62.36132406419324, 61.45677058927475, 64.55641185083698, 62.1783729522459, 59.444116161715606, 50.18278045039023, 46.97098685849098, 50.716650332174, 48.63751565256427, 47.842564967370805, 46.61445909930814, 45.88379213886876, 48.96814792386947, 48.0262730967614, 49.75910955859769, 51.32832434869582, 58.96937993264968, 58.748805446009484, 60.537323874811975, 58.31890190801313, 57.82249066137499, 57.71511970027801, 58.35823543610112, 56.097757816314704, 54.927177429199226, 50.97044337180353, 48.01895003164969, 48.66242270315848, 52.36749356792819, 56.63585209077405, 53.05709331266342, 54.27908420562745, 43.29265871355611, 39.021166216942575, 45.86340365871307, 39.89609402994956, 50.50057480412145, 35.597042960505334, 30.56730727995596, 17.668275256310743, 6.230549206656795, 4.913182941175276, 4.19231160994499, 6.605365016768056, 3.6735904120629836, 3.423727342197972, 2.5991904639428665, 3.826664830407789, 3.1550817576146897, 4.831517233002571, 2.6110544079734437, 0.9983220239800792, 4.4107523272114415, 3.828680438380088, 2.2592550660333326, 3.5118267180458194, 11.933981872374012, 26.801635796023955, 32.170864382097804, 41.63460223905502, 31.58916904080299, 44.32985890296198, 38.35076647420084, 37.01696449710477, 39.10181014768539, 42.01216174710182, 47.70616846699869, 46.747953045752745, 47.182084898794855, 44.70137796094341, 42.80282528169694, 43.710912812140684, 47.95028894178329, 53.36894135321341, 53.32793689543202, 54.565432917687204, 55.07562737311087, 54.124664414313536, 55.47648575998122, 51.983524907019834, 52.268418419745664, 53.788407464181226, 53.04997421080067, 55.65875437951858, 51.26175780450144, 50.37297225767567, 46.92904495423841, 45.54191050990936, 46.25292639578543, 46.52095763914047, 50.64729498278711, 57.990572067999075, 59.348916315263324, 60.39326306312316, 59.244440063353515, 55.03913756339781, 56.859521327480195, 60.15090765491609, 61.73122667497205, 63.318386308608524, 65.99687484002882, 65.31508845667686, 64.99009655367944, 64.89097825942501, 62.48204285098661, 60.305554943699995, 61.83200805417953, 63.64844591386857, 63.756260102795025, 62.65893390101772, 11.314418008250575, 0.64594829995786, 8.277935731795527, 45.02629533890755, 55.212894639661236, 44.276526435729, 24.080699374598844, 25.4810090603367, 36.91686561030727, 41.360879636579945, 39.00071497886412, 51.99725712499311, 70.1189564120385, 49.33714489783011, 64.99441900560933, 1.5655769143373737, 0.03538090510353927, 0.06484181214604648, 0.06966375340256961, 0.06003502410866561, 0.09306990751816381, 0.09759607754888074, 0.1904739574679444, 0.09755552851504858, 0.1043047554670803, 0.07289118989701233, 0.233412113100771, 0.273406422666965, 0.32814950291668216, 0.22387883836223235, 0.1367283543391574, 0.251241798302339, 0.20549049120276205, 0.21237582899630073, 0.16325166659249415, 0.2213997318739853, 0.2406176603249004, 0.31102523147579164, 0.2514935960812915, 4.448711554850302, 75.7102244900119, 70.28948537765011, 46.11791056971396, 68.34159712637624, 65.84162742860856, 49.00182539416898, 26.77687975668138, 31.687826456562167, 56.759951960655954, 59.715979560729004, 62.663472083307084, 32.1820294087933, 26.201544538620983, 27.910878158384754, 47.76047760440458, 63.64482164382935, 70.75840473175049, 64.99869831146734, 68.32569583769768, 66.025923913525, 69.48516415011498, 64.25194178858112, 69.69849401904692, 68.93300425621771, 68.02658373309721, 68.19377868406235, 64.00957069089337, 64.7290785081925, 68.4988449465844, 65.65851942185434, 59.662317614401545, 52.9874163289224, 49.67480997885428, 53.09516775992609, 50.19303352602067, 50.03009042432232, 49.377961081843225, 48.21951258567072, 52.490416726758404, 51.578928501375266, 50.014440167334776, 54.77374999753891, 60.89839766102453, 63.33631154029601, 62.92350953625095, 59.684973224516845, 59.49570317422191, 59.25136304670765, 59.94490085109588, 58.35154779495732, 56.25340530949255, 53.975386850295536, 52.0195597217929, 53.84539165804463, 54.04968830846972, 58.18867529592207, 57.79938790106005, 57.26224676255257, 47.03127368803948, 40.35605861294655, 45.67916208697904, 48.746180995818115, 53.77586764674033, 44.85559771137853, 43.162604685752626, 27.852354434228715, 15.518283940130665, 15.938516874467174, 14.746402675105681, 16.907388394878758, 13.007895446592762, 11.34360142292515, 9.563056192090436, 10.619519141412551, 7.8114958059403214, 7.713235039864817, 5.4529638348087195, 6.984340010150787, 9.434887843747294, 7.242225552758864, 3.0406475884299127, 4.434051696331271, 12.47853236813699, 35.99119409438103, 41.78590766845211, 44.29806809271536, 36.64131126096172, 46.04044768118089, 38.72271699290122, 39.48764977916595, 43.02481966633951, 45.61956559458087, 52.48259552063481, 52.61368505416378, 51.26705692660425, 48.744113906737304, 45.785360259394494, 49.057162192560014, 52.17231250578358, 57.623453909350985, 56.78126612017232, 56.767702564116455, 58.094389361719934, 58.87200709312194, 59.52312838646674, 57.186592086668945, 56.46606053075483, 57.93861635269658, 56.075898447344386, 60.00883156253446, 56.55881674058976, 54.187904788601784, 49.90427647867511, 47.097577433432306, 49.66070121334445, 50.11278575466525, 52.35183938857048, 59.42900719181184, 60.05488411072762, 64.19316507154896, 60.52324648826354, 57.766812616778964, 58.78368316158172, 66.12700339286559, 64.7558565293589, 65.79329990571546, 68.71430858489006, 68.21105280230123, 69.81376463367094, 69.48510923693257, 66.07398079287621, 66.92981843025454, 65.30811448251048, 70.20252643092986, 68.42391983155282, 71.2074141348562, 21.933156597998835, 1.07051937570495, 7.771094412572923, 46.72949044935165, 63.35584886612431, 50.80534688888058, 25.338727043521022, 24.989661593591016, 49.57060044811618, 54.06868826958441, 53.6270764566237, 51.95360506734541, 75.45566266582858, 52.79204307063934, 82.66421810273202, 2.321281957049524, 0.19632676195713783, 0.2778445845169406, 0.29030540297108315, 0.11555300229379248, 0.1877627723039158, 0.23252437041411478, 0.48120541257723687, 0.199663411946066, 0.1844943501055241, 0.14789868236309098], [0.04891865165723909, 0.016787208075965607, 0.0277340529306281, 0.07125413661161739, 0.08208757747084865, 0.020203360754455772, 0.02445114784002785, 0.06492281062228066, 0.037597193638043064, 0.1977642646600162, 0.04617648972799221, 0.0840564847232834, 0.16541451666383974, 4.437727447479002, 63.23994674990254, 58.775418727628654, 45.56927296423143, 54.55181444844892, 57.79914079173919, 34.14129841712214, 35.10041206113754, 18.41147222826558, 35.24228811264038, 49.61927706195463, 58.97663239509829, 31.21176250519291, 21.308880006113363, 25.08053702692832, 26.966041941796583, 38.55837752742153, 53.977653980255134, 58.859177020288286, 62.849867036265714, 61.9536485979634, 61.92460736920757, 59.70603635234218, 57.8308766888034, 60.68501287891019, 65.06107576431768, 56.97335635462115, 56.89313211748677, 58.13413866104619, 60.66114525641165, 58.87557644997874, 59.99551903816962, 54.60057735443116, 47.842513976558564, 46.18293562243062, 45.3917896363043, 44.572794821954545, 45.38981276173746, 43.85812720944805, 46.94018056315761, 46.90517340936969, 49.40901056412728, 51.82404525818364, 57.957141707020426, 56.09031315772764, 53.89844955936555, 54.097101919112674, 54.433896233958585, 56.609376092110914, 55.954810957754816, 49.61524878778766, 48.641175223935036, 47.68900025275446, 46.07897712338356, 43.969546056562855, 47.171176787345644, 51.011137962341316, 50.438683725172474, 49.147780710651034, 41.19401808707945, 31.308325375280074, 39.82242015100295, 33.0359156670109, 39.30312187440934, 28.3851868491019, 18.32733346569923, 8.08981836803498, 6.815081892475006, 1.895182872972181, 0.8127584909239124, 0.6007633310171866, 0.6295281552499341, 0.07084866159505422, 0.2832497944754939, 0.46351441993348064, 0.9158639970325655, 0.4942585702144331, 0.17653435949356328, 0.01084255634792029, 0.07280693554709997, 1.5937474994890153, 2.290953700580905, 1.076133635736281, 5.301344615797843, 29.313154912764027, 31.862273869975922, 29.1244359554783, 21.997067697586555, 24.361166492585216, 39.00620237473519, 37.58199368753741, 38.259904769159135, 38.19918647889168, 41.46291617424258, 41.15797934993621, 41.670464469540505, 38.39367720388597, 38.09441604921895, 37.570916914170795, 41.83962845033215, 47.70894942745086, 49.01126653917375, 48.23479806223224, 49.487191246401885, 49.71734416100287, 51.164514403189386, 49.535644285140506, 46.34205441321097, 47.189286370431226, 44.970966385256865, 44.43300939375355, 45.35077733378257, 43.622035826406176, 41.46616389674526, 44.71085048490956, 41.31219517800116, 44.79303590713009, 50.73484620740337, 57.61246342812815, 58.403629026105335, 58.03470657717798, 57.35090017318726, 59.06041029960879, 58.81779209260018, 58.08787038249355, 57.64123793571227, 64.25643682479858, 63.05020209281676, 61.42420314973401, 58.18389784905219, 60.84892872841128, 60.67851351153467, 59.19994861848893, 56.42120430546423, 54.021776722323516, 54.970252898431596, 41.28930030330535, 1.8645652191292856, 0.5992015535312315, 12.342515357079046, 53.1824444186303, 45.0411375876396, 39.14665068349531, 14.24434615719703, 33.344433615284586, 36.02315356654506, 43.528926603255734, 30.016127978601766, 49.35809427692045, 71.05651270958685, 34.63870202341388, 53.25540834857572, 0.19818224223150363, 0.3109704715109641, 0.06460806339859002, 0.10508171417900633, 0.011921675458941008, 0.09826111081506937, 0.06252312063870412, 0.007529310345078909, 0.0945397544532053, 0.11806600817268896, 0.061011575537944035, 0.04168424207056242, 0.0776898344197581, 0.1239169204247094, 0.061963401479466315, 0.10374677532743062, 0.05127622978761793, 0.025528912890642404, 0.04046901594847441, 0.0237446979454328, 0.16653993046812474, 0.04982898627678233, 0.2002827480675713, 0.2846428487570055, 7.6154175016187855, 76.90311139629733, 63.09807854314005, 53.124365883488814, 56.24838075330181, 60.563776339254076, 32.836494522710005, 36.637133936728205, 22.907561602131015, 42.983148405628825, 53.49208416477327, 64.60933639157203, 35.30828591315977, 24.160745143890384, 32.1702975996079, 37.30348187108194, 46.86365119872555, 55.12501001358033, 60.41319262596869, 66.12366937821912, 66.94964208910542, 67.4139565806235, 64.74506608901486, 61.86034325630435, 62.961093687242084, 63.637204400954715, 58.11978278621551, 59.61107577047041, 60.24781373239333, 62.266775331189564, 61.03524131159629, 62.029267972515484, 56.89632492680704, 49.53742896356891, 51.26679020543253, 48.43430942104709, 48.703536987304695, 47.6543382675417, 47.12875243156187, 47.40094923203992, 49.619818349038404, 51.66524417938725, 56.26520772134104, 60.38940737324377, 58.81228116250808, 59.110408752195305, 56.12376313055716, 56.39714840919741, 58.28479689936484, 56.09587507863199, 55.74507790227091, 49.89919700930196, 51.38405730647426, 49.65209945555657, 49.822628421168176, 49.85407014046946, 54.54422858453567, 54.811600869701756, 54.13763177010321, 46.98323642053912, 37.18222179720479, 47.61328281894807, 42.024976130454775, 40.094993499017534, 36.86978932349913, 26.187498531033917, 17.071600383327855, 11.143345794370099, 0.35340546059512323, 2.033938311280743, 1.1417020592958698, 1.020806949705847, 0.6713238899265567, 0.791972503066063, 1.7754199187601767, 1.295559235638188, 2.374896589786776, 0.34652562331288095, 0.050775870951193, 0.13635769035787354, 1.2509042769670486, 2.597927951043652, 3.201073509070181, 7.8303736832834065, 37.27817866110033, 37.16562624900572, 32.49569154554798, 24.86092548216543, 31.566674247864757, 46.3019521005692, 39.99636942340482, 42.26468001642535, 42.94204196622295, 47.5381576630377, 44.74984276679255, 44.68628468052034, 41.89996234832272, 44.359947404553814, 41.36018929942962, 46.444157631166526, 49.993494710614605, 52.87915106742613, 52.37243183197514, 55.41947803189678, 54.09173219434677, 55.47789781324325, 51.47585253561697, 48.415132953274636, 46.91294362468105, 48.411955833435066, 46.28655287527269, 46.638005087452555, 46.218138894727154, 45.233541611702215, 45.88151324179865, 44.43321727937268, 49.17023235751737, 56.70538786918887, 61.01544118696644, 62.093237907655784, 62.23524339737431, 61.59496745755596, 60.621737203290394, 60.84500243586879, 60.65713659409554, 64.24195151175222, 64.47558356869605, 65.50709632135207, 63.3382256569401, 62.55521074418099, 66.15374611270043, 64.34394098097279, 62.506616500116166, 63.611108872198294, 60.451604397066184, 63.4352925515944, 38.58654014525875, 1.4346494237261436, 1.2112097682491427, 15.8886900255757, 59.68960946606052, 49.29870959251158, 46.228333134805005, 21.531568650276434, 34.789191599815126, 35.32738001115861, 43.65561523745137, 33.885324539676795, 48.132502648138235, 67.47760880377986, 40.47691076032577, 65.16048823633503, 0.8229447636873493, 0.030198850811669425, 0.054547505663527604, 0.12642400444395122, 0.02895135132055129, 0.11503490469148082, 0.05125365317648938, 0.030970900815220612, 0.04281986016599883, 0.08930795615719211, 0.06362927499257269, 0.15307697707847243, 0.21698217778917284, 0.423031545454456, 0.15184276346718112, 0.14012322701033086, 0.21258124781231727, 0.07828857809785875, 0.16219736106934088, 0.2334853664280907, 0.2882805713001759, 0.13610852792138053, 0.18014047324897783, 0.5032555680842169, 7.831244939757933, 87.0907618922572, 71.44052843893729, 59.82051072582122, 69.93613473830685, 73.80183450637325, 50.11937141418458, 45.14884979494157, 24.91647997210103, 43.967118109426195, 57.9850140694649, 68.63149166107178, 37.636400884197606, 28.60839128494263, 35.60790400351248, 42.44501882983793, 51.8713725766828, 64.1751927714194, 66.50104061249765, 70.30026405088364, 68.94704634143461, 67.65304073210686, 65.17063148560064, 63.34993000953429, 64.22047261268862, 69.25910226760372, 61.869027383865856, 61.70725314847885, 60.25938472440166, 66.31651663011121, 62.55650512633785, 63.07661141118696, 59.61623760961718, 53.56811538819344, 53.986161601158884, 52.1776508515881, 51.16325532236407, 50.96103360576015, 48.420479143819506, 51.73124590227681, 53.53030766210249, 53.659957685778224, 57.383216581036976, 62.09768587543119, 62.034904418453095, 58.92289984610773, 58.49718147708524, 58.105795614181034, 58.841867600717855, 57.55835040923088, 57.866472198117165, 51.409336982234834, 53.15398762303015, 51.714854317326704, 52.195681987270234, 51.809591324098655, 58.76205913482174, 58.43058747629966, 55.13116029001052, 48.575408843255815, 38.11990361059866, 45.6715448441044, 42.44479917710827, 51.76797105420021, 46.33318985662153, 39.83567383981521, 28.042408958558116, 13.80018186184668, 1.7910787559324697, 2.0940649365225146, 1.6293734071716186, 1.7475159322061848, 2.0237750824420684, 1.9312833874456345, 2.8374913671324333, 2.5019311280019823, 3.862223812649327, 0.887780684617258, 0.1622894141943224, 0.17121174913500586, 3.4930150306993917, 10.299719475930738, 7.7214313226361435, 11.767906758093066, 47.07109359002883, 37.79367616099697, 37.69192595635691, 29.89976694506984, 34.12983332910846, 48.79228061245334, 45.83380545339277, 47.061636755543375, 47.576389005107266, 52.63027667999268, 50.60646703166347, 49.910736622348914, 46.89096658460556, 46.20017051696778, 43.670869335051506, 49.643972304559526, 54.56317755483813, 56.53758495084701, 53.86599979092998, 58.97962908590994, 56.735919598610174, 60.76650011924006, 56.118903313913655, 51.48943178115353, 52.378523272852746, 51.34572790515039, 49.701183995892926, 52.14227499500398, 51.07736718270087, 49.57939047967234, 50.20100378221082, 47.968288698504054, 51.95700183991463, 57.566579541852406, 64.3038425907012, 66.48651999811973, 65.04095008296352, 64.0510497554656, 63.53788998819167, 64.94586398524623, 65.02959874368483, 65.95921224163425, 69.21059039331251, 72.38705127469956, 65.46130657196045, 63.879402914354884, 71.62564862158992, 68.92034284530148, 68.28032970428467, 65.10378253075385, 66.71079327983242, 71.00478449175435, 50.61244864617625, 2.7417102744502406, 1.4101346101491683, 16.571804131231, 61.692053964061124, 56.355124135171216, 50.2522103248104, 19.89943119787401, 45.7631714113297, 48.87226166263704, 58.322569324124245, 44.529401640738214, 60.42153942969538, 86.87582385155463, 47.578636523216005, 80.08378490324944, 2.2162195559470885, 0.23089229670022768, 0.19307027540860638, 0.3941882738182622, 0.22614891009946025, 0.1604266101194005, 0.1361166637751364, 0.09218450906055589, 0.2076950471007055, 0.20652189069697935, 0.12747059546170697], [0.18842177645814037, 0.04653610289096833, 0.08708979453771346, 0.05028030016429482, 0.018145154463127255, 0.11730827826766238, 0.04893924410064374, 0.06991396537951886, 0.12723501576411148, 0.15277541422795865, 0.06915451943754189, 0.2584566764773861, 0.3327238139125609, 10.143818009284235, 74.82360409152123, 54.47974089653262, 38.58267661063902, 49.291657170941754, 57.521531120423354, 33.38554397706063, 38.256496229479396, 21.876394018050163, 26.4885227910934, 47.11021531012751, 59.775062222634595, 37.835453325702304, 22.574489616578628, 28.928790092468265, 38.23577434785905, 40.80819806744976, 43.337040332055864, 52.02189353204543, 56.644944144833474, 62.94716927313036, 63.56596239151494, 63.619734164207216, 62.651755963602376, 59.85824000450873, 58.5247165156949, 57.094243803331935, 55.11871853182393, 52.781762538417695, 59.06449348695817, 61.330011352416015, 59.005865819992565, 54.63708677599507, 48.00580224683208, 47.33044855056271, 46.1036096080657, 47.48109502177085, 47.45994560180172, 42.92801557048675, 44.40583129082957, 45.69058010655065, 48.644187604227376, 56.509234059241514, 58.15872015491609, 55.586465097242794, 56.693252055875725, 52.84287306570238, 56.221732170351096, 57.09540090253277, 54.36951052758002, 50.23376734026017, 49.54519525651009, 48.07262374508766, 46.017870518469046, 45.511625889808904, 45.54144374785885, 49.82282061730662, 50.14246632975917, 49.604199471012244, 45.78938068882112, 32.530253510321344, 40.440570000679266, 39.789527154737904, 32.807996542223044, 27.17091714182208, 13.27423026484828, 6.763954287575138, 6.810090676430733, 3.1760514840002987, 0.6221986549996561, 0.17039004322742263, 0.12286847547417688, 0.0682669069858328, 0.16884879689783822, 0.1448226248424861, 0.5290331703520591, 0.44601225264130107, 0.0667596519774487, 0.09310114092283672, 0.3789398759122818, 0.9631575463760285, 2.640295922756195, 2.9688034951686864, 8.808922671502637, 39.716496544499556, 26.228985440346506, 20.48796323037917, 33.388097440042806, 20.013834968689952, 29.702463880662, 38.58470447601811, 38.71688050608481, 41.402841152683386, 43.04136422372634, 40.89806741283786, 38.176989786086544, 39.80695816778368, 37.89560679466494, 36.96216506342734, 40.184329402062204, 43.648017606427594, 49.99783677439536, 47.74765929868145, 50.86875200271607, 53.392428505805235, 50.931556993915194, 52.17566613228091, 45.03038637099728, 44.49288437443395, 40.24996242215557, 43.970079498906294, 41.62440799897717, 41.70414586221018, 41.06533296646611, 44.3566486912389, 42.45466393809165, 48.98280974357359, 56.19408730537661, 57.093835876834014, 55.58998346328736, 59.2523475616209, 59.42486909128005, 58.69808527731127, 59.92684618119271, 58.975502752488666, 63.19842846162858, 60.957994153422696, 61.78100547482891, 61.76147991611112, 62.224598084726644, 60.17482626822687, 60.27515265249438, 59.00272400148454, 61.297973432848536, 55.19127061290126, 56.33744601280459, 20.946327486345847, 0.40832247344716904, 1.0642752075387587, 20.83507533996336, 58.05831532324515, 44.593097009966456, 34.34035870336717, 18.934257491942375, 47.628858550902336, 32.67834847973239, 45.02619335728307, 29.593725973559966, 35.48289414375059, 50.24129436862085, 41.263267532471694, 53.53725025730749, 0.6849735542651146, 0.0452131686371661, 0.011545580871883902, 0.06819617408778399, 0.0308858324968887, 0.06338190520182252, 0.05062456092526836, 0.053699664666407534, 0.0491268168984642, 0.12412197917940156, 0.026682172075755177, 0.10204140998182759, 0.03862496570593888, 0.05986535861607521, 0.10590792468358433, 0.058733367946960276, 0.07445087596293419, 0.02359305658648091, 0.13561049416180582, 0.11312474872195914, 0.09478079635770091, 0.05235166784616248, 0.28277800688820504, 0.14419182804563355, 11.997460530650232, 83.81702623059674, 58.560017847245746, 38.249384972356985, 49.79846269853654, 61.555076952903505, 34.42293636260494, 37.766654952879875, 23.89244325699345, 31.3914619722674, 52.76342545786212, 66.85791354025564, 41.63666540576566, 25.344553724412, 26.976801003179244, 45.354221174793864, 54.70968592551447, 55.11657299533967, 58.355634904676876, 63.71970753515921, 64.93323395329138, 66.25974424423711, 67.6410618136006, 65.10977591237715, 62.942729150095296, 61.60695814317273, 61.79093299373504, 55.98437386174356, 54.25679337593817, 62.90756902387066, 61.585079162351555, 61.201239939658876, 55.550394981138176, 51.28469582526915, 49.71089186206941, 51.2028516492536, 48.72227022724767, 49.17546087695707, 46.40721282651348, 47.51868701750233, 49.85223839359899, 51.39676970820273, 57.30960938238329, 59.22740128732497, 58.88355062853906, 55.833244939004224, 53.02143112305672, 59.00476363397414, 59.14079927629041, 56.07478449421545, 53.196247239266675, 52.3997119165236, 52.387897737564586, 49.46064464507565, 48.01558856041201, 48.35210438697569, 51.629703583255896, 54.39327224608391, 55.91899971808157, 51.63985859963202, 39.55483998021772, 44.68460198371641, 44.27293746702133, 40.68197227293446, 33.822750968317834, 24.54063846218971, 18.412084118012462, 8.885059798917464, 2.9941569605181297, 0.9108523111189566, 0.24674510733494837, 0.4993711958729452, 0.05660955005535676, 0.0922873103991151, 0.3260126079042112, 0.5487202204042866, 0.9296666338078438, 0.05995275009603751, 0.14066422298069925, 0.20516360148547158, 0.7362365422229613, 1.7650018584343696, 2.050555187367624, 15.22863357297836, 46.621750785458474, 30.288909212235485, 25.33405157827562, 35.01268432986352, 25.485745322319772, 33.96210493579988, 45.80246571571597, 45.20453176190777, 46.440046987225934, 47.16376350771996, 44.89805344612368, 43.11271998190111, 43.08090563743345, 41.66266287526777, 42.24275788953228, 43.92783557215045, 47.15945282290059, 52.92259131708453, 52.161286723229196, 53.49135068155105, 53.44598062576787, 54.10445244081559, 53.835224874557994, 48.306028304561494, 46.46847240386471, 44.12635849368188, 45.039623552753085, 44.02524371300974, 42.74264043377292, 43.37052168384675, 47.324211981988725, 46.886373489133774, 55.516278205379365, 58.855113444789765, 61.48878497462119, 58.132397128689675, 60.640795999957675, 61.99980705015121, 60.55751231408889, 63.46095269726169, 62.6964121480142, 66.26267817712599, 66.43477609080654, 65.09966011970275, 65.33107995986938, 63.49783474399198, 60.930757214946134, 65.59212938431772, 64.79753171243976, 65.85207662274762, 61.155760057510875, 60.743201240416504, 21.044267108363492, 0.24766933112855882, 1.722154131820125, 26.97398081902535, 63.96134907199491, 46.60052684045608, 41.11278972318096, 24.387813114350845, 40.5725577569777, 29.880770906325314, 42.76842217291556, 32.933071121092766, 39.026798740510024, 53.52584792721657, 43.11114318909184, 64.83565715051466, 1.3914519932962235, 0.05224586727337972, 0.026565787998298486, 0.10939145671023477, 0.04697761851392927, 0.06881865116977884, 0.07995576928219489, 0.029182110409883243, 0.0657469526894631, 0.029300794666332584, 0.06498385250808732, 0.3409195144570643, 0.09984459923279863, 0.3290542833987744, 0.21552480276553862, 0.12649937217394192, 0.1873290133211882, 0.11667336757865646, 0.23395241959200752, 0.3564563597882948, 0.19923475510891409, 0.1551059303024123, 0.460452979370471, 0.5058008492473633, 16.410243665018392, 95.55257735713836, 67.29868596599948, 48.68360350208898, 63.3700047000762, 72.66903046638735, 47.46168713415823, 49.199603065367675, 29.157328951743345, 34.25910288287748, 58.88764950536913, 71.79406735204881, 42.9043048427951, 28.361666356363607, 33.87998619387227, 50.45675800692651, 60.95094565422305, 60.242659737986905, 65.42245549540367, 69.33134448143744, 70.76457069766137, 70.23534882453181, 67.17695128533148, 66.8310139256139, 64.11507068141815, 62.103914599264826, 61.18402073460241, 58.29531277379682, 54.722123761330884, 64.66844651006883, 65.07890685912102, 64.88830712533766, 58.764702812317886, 53.96163109810122, 51.458719622704294, 52.30180171228225, 51.53580988607099, 52.44491723275954, 49.34360896387408, 49.79189665086808, 52.81642060126028, 53.840253353118904, 59.70838977444557, 60.861276349713734, 59.89461606548679, 61.89569557866743, 55.77907700692454, 61.82129213886877, 62.56490292087678, 57.47036772389566, 54.67158794403077, 54.09430134680964, 53.384211140294234, 51.26941427107781, 50.43043890307027, 52.102333499539284, 54.49601873274773, 56.79484536570888, 59.751759421440866, 54.49768966244113, 43.23540779852098, 44.1546505497348, 50.50448932955342, 47.08752832105083, 42.94952584851173, 34.094469239634854, 26.52062935213889, 23.863613836226925, 8.5447088749178, 2.1273413444719007, 0.6167553245059906, 1.0179073375559624, 0.1569754453075509, 0.4399110977688144, 1.2377596790752103, 1.4731183143392688, 1.405490646439214, 0.12997663760137174, 0.24915140482687184, 0.6510755119304503, 1.8321094445643888, 7.484090664694387, 9.527020396724824, 18.615884588610744, 51.87588330238096, 32.26312245092085, 29.478480854342063, 44.7211584737224, 31.457881427580315, 41.712390684312396, 49.82888067922285, 49.15238557323333, 52.241726690723056, 53.70761840574203, 48.06683040434315, 47.56311570444415, 47.13343966391779, 44.89837508047781, 45.26723084911224, 47.63703669271162, 51.51947713667347, 58.01349439928609, 53.20645716882522, 58.07669162750245, 57.949336190377515, 55.8578028986531, 57.07266292264385, 49.246314571749785, 49.72020749122866, 47.685638781516786, 49.67632009137062, 47.12676378988451, 46.45306925619803, 45.239174135269664, 50.76546422896847, 50.15570040672056, 57.46459399500201, 64.53388567893737, 63.318103897956114, 62.573755710355705, 63.034955839956964, 63.90502383632045, 63.40729075093424, 68.7956428527832, 65.81046811995968, 70.5556966412452, 68.24487147792694, 69.75443486244448, 66.3384505241148, 65.59305506367838, 66.5634298324585, 69.34562975360502, 69.41533811630742, 70.27230539629537, 63.81895134525915, 69.14078004898565, 27.967038654511978, 0.7263731295543333, 1.6505562898612793, 26.688293026339625, 66.45809850385113, 55.898595548445186, 45.764104935430716, 25.5460988321612, 61.50703968540315, 42.56214472555345, 59.26089440622638, 46.15861300499209, 46.12551212310792, 67.46049158034786, 55.26907474763932, 76.48987400916316, 2.3547505611373536, 0.13638477922687609, 0.1281505904250568, 0.18781071408621727, 0.2667974434312313, 0.26467556374207624, 0.15193107808309217, 0.11771412866730845, 0.18756457003614596, 0.15104256930851168, 0.1926160618783005], [0.08402098420887225, 0.07072743584191607, 0.047201852449366165, 0.09233571183417114, 0.02788262802266306, 0.05799779330470389, 0.05055058364486022, 0.12445009463737089, 0.01567688716139885, 0.2670466977982752, 0.2797278124959238, 0.41540452729790445, 0.339857256941257, 6.972034064031417, 68.72176893295781, 57.91761206042383, 53.7211545052067, 48.95531785103583, 49.802914588682114, 32.99467978938934, 33.0316363611529, 25.079085749964563, 21.587042731623498, 35.48307457277852, 60.07684546132242, 44.330184459686286, 19.780185261080344, 20.830994113799065, 40.51813879320699, 52.48917333541378, 53.60621336967715, 50.46048425859021, 53.87844154911657, 58.00997211087135, 61.26165620742306, 62.96696939776021, 62.33686416379867, 62.48890699878816, 59.99259295002107, 62.41017326231926, 57.81771713687528, 57.00771631733064, 61.098889612382465, 57.73034241891677, 57.069179857930834, 54.190913246523955, 51.104843385757945, 47.072548789362756, 48.70882826466715, 46.988190374066754, 48.096491367586204, 46.12993655666229, 44.423466267124304, 45.89820684925203, 49.899357826479026, 57.93692581115231, 59.78599779067501, 57.7906527826863, 47.951708839785674, 50.669483830851895, 58.09460901444959, 56.598499359623084, 53.8195118596477, 50.3261548472989, 48.36578561413673, 48.772233378502634, 44.96146248232934, 43.22050279186618, 46.28359148579259, 49.716853864731334, 49.9082733738807, 47.763642957133634, 48.92506853226693, 36.348996623869866, 41.07905341732887, 34.90667443121634, 27.40157408099021, 20.929918250729962, 12.272261784922692, 4.7958967185789545, 3.058394107126421, 3.085723221302033, 0.10200718883424999, 0.5143041187717069, 0.10155364946131745, 0.17880188781888257, 0.05837591132149101, 0.008405548306332241, 0.10083226276741875, 0.017678428801798055, 0.029875607672898524, 0.14523269638659494, 0.018315338980286353, 0.2458890347230819, 0.051119882733591145, 0.3215797780261886, 11.659749361776537, 25.630623948189523, 23.66713643074036, 31.132293324316706, 28.59562004766157, 41.53486813268354, 31.852662101868663, 39.88826497908562, 41.58470576809299, 43.00535686554448, 43.96006961022654, 40.82086732310634, 37.618377593255815, 37.50138113575597, 37.50446804108159, 38.66257921341927, 37.12730469242219, 43.75880102957449, 48.07849945560579, 51.65560691587387, 48.64683520409369, 49.74186289695002, 50.87520430164953, 48.78771889594294, 47.42120827397993, 41.65355120935748, 41.06123801200621, 41.21082152089765, 39.65778258539016, 41.14021101305562, 42.385332122925796, 43.68462116487565, 46.20825452189292, 55.86889143913023, 53.75167446751749, 57.551392124545195, 56.85420259352654, 54.051531822450706, 58.275747991377315, 58.37102236286287, 61.159400017030784, 61.22415442620555, 62.44443908814461, 63.398991015649614, 64.37691242464128, 59.69865837404805, 61.67176746552991, 58.77837227236841, 63.136451090535815, 59.55288348659393, 60.02257946998843, 56.01183045294977, 55.230631597580455, 18.441305775796216, 0.2092302719792051, 1.6736953321003145, 28.174936040755245, 55.9186270929152, 39.814159639420055, 30.012184035393503, 31.351143929266165, 62.46956579146847, 34.7109716938388, 41.28831186602193, 29.049463772004653, 31.067174134715913, 58.929826751832046, 46.66453207692793, 56.44092206032046, 2.0766371104025074, 0.08677039716032245, 0.08939771101840081, 0.03342770265355226, 0.14775819715953645, 0.035848291515703165, 0.09367876355686496, 0.012242190367091569, 0.08718422253526027, 0.022208687826810826, 0.10845753424350293, 0.03842597436760703, 0.010860647514252173, 0.04472121761571016, 0.07125032149375447, 0.05362389474025658, 0.033161138529859246, 0.03439185111933658, 0.023773958673700694, 0.23137769000905178, 0.22967000341703817, 0.2370436150099962, 0.5406648365239943, 0.4579008034160061, 9.627932194740543, 78.5636938771894, 64.38079164874169, 62.92159541960686, 53.55597173013995, 54.44418853329074, 32.37595727366786, 37.12114264888149, 29.627458357041885, 25.863234227703465, 39.82975106085501, 64.80904779126568, 52.06693803110431, 20.779983689708097, 21.476814323855987, 42.47076526764901, 57.9946631000888, 60.3634883511451, 58.28652274224066, 58.91396860922537, 62.863713002973995, 63.45550844746252, 65.05662387417209, 64.65790317904565, 64.57269753179243, 63.160730561902454, 63.31325192605296, 58.44107197177026, 60.179721386201926, 63.198024457500836, 60.20695047993814, 60.63622251633675, 53.931711258426795, 52.73341540367373, 49.05464795327956, 51.199564703049205, 50.26981784451393, 52.07062898143646, 48.91472131975236, 47.489551651862364, 50.03562488863545, 51.24298534085674, 60.44505796124859, 61.60368688644902, 62.94182308258549, 48.68443112219534, 52.91956716968168, 61.37356142843924, 60.34173488616944, 57.67359748963387, 53.47808522562827, 49.85998507468931, 49.69963858204503, 45.96666005349929, 47.57508285583989, 50.695563670127626, 50.47369480133057, 53.67168165022328, 53.85720975937382, 52.23208158246933, 44.08469900008171, 44.883948602984034, 41.26760959625244, 32.18963880692759, 25.646672325749552, 19.59609862296812, 18.737780086455807, 6.892005945405653, 3.4073134487675083, 0.03684859167063429, 0.30240775356369637, 0.15659707448174878, 0.09462916457484807, 0.1589106600130758, 0.06387850254653923, 0.10586412743695321, 0.0960682530797297, 0.0767715631293193, 0.21688562006719653, 0.08184296559662589, 0.15382161454087304, 0.09861219358900863, 0.27738438017906686, 15.042747547549588, 32.733073388376546, 33.86020175872311, 49.21316662142354, 40.35655283158825, 41.394623787172385, 36.70455555762015, 43.558697392863614, 46.891880496855705, 48.074043643090036, 46.660299839512, 46.91262591269709, 41.79262668855729, 40.49754634980233, 40.59470738134077, 43.37921365614861, 41.391952653085035, 47.636562085920765, 52.08813059714533, 54.41259776392291, 52.13872524999803, 52.55697150384226, 53.89909282807381, 52.21538797501595, 50.43797769854146, 44.54460082515594, 44.100102147748395, 43.45055372484269, 45.210117217033144, 43.81291012610159, 46.55561570198306, 48.061033141228464, 49.619171157959975, 58.495161456446496, 57.48926962575605, 61.65581126366893, 61.09497900932067, 57.77659108561855, 60.54299954445132, 59.82710815245106, 65.16727001436296, 63.42445896517847, 67.82971997414866, 68.09030655891665, 68.5147148563016, 64.15096036849484, 64.0369096109944, 64.31471540081886, 67.3780119803644, 63.98991177158972, 65.88791924138224, 60.23244980842837, 62.14551525731241, 22.6180043912703, 0.28678789494499085, 2.7712655788467777, 33.09610443730509, 58.50426527761645, 43.12844476392193, 38.93702745437622, 31.815075989692446, 50.28656244277955, 29.374616492179136, 40.88411161976476, 33.21597206977106, 34.617831091726984, 68.16134852747764, 55.44597364241078, 65.41394395212974, 6.811103628527734, 0.19097477978756353, 0.1423800454264687, 0.06442587236843764, 0.0637187655534475, 0.014909674045479587, 0.07935360885195195, 0.045414615287295276, 0.06782011684751318, 0.04233188514086989, 0.11901896026345993, 0.2815329607936644, 0.17815881829348304, 0.209102611087503, 0.12964987045814916, 0.14858364157619017, 0.12795870838266227, 0.12174875370316929, 0.26513690189007794, 0.5650617951346982, 0.5770163214014423, 0.47265899698099784, 0.5668120915370604, 0.6156068667769432, 13.824408381215989, 91.64234299813548, 69.57821061534267, 65.67727227364817, 64.87827370243689, 63.98015291460099, 44.95423747647194, 45.77141231106174, 35.172214969511955, 27.976305254044075, 45.85468422982001, 70.06772241284771, 52.95077746914279, 23.521520399278213, 25.693991799508375, 48.03704392525458, 63.09561529467183, 65.19018842327979, 63.49369664346019, 64.09550589899864, 67.02582236259215, 69.79993435644334, 70.76862642841955, 66.15371473373906, 65.36510259874406, 66.21236201255553, 65.31954819156279, 62.07956452523509, 59.253912587319654, 65.09728708574849, 60.54324665377217, 61.50885966516311, 58.8559724438575, 56.675358203149614, 52.501611171230195, 54.27866843438918, 54.590869488254675, 53.20547265391196, 51.77276811292095, 49.73639511292981, 54.55083777827602, 55.49801172748689, 63.91586526747673, 62.98339628404187, 65.74611771491267, 51.04873388044296, 54.05286150593912, 64.92342018312024, 65.61065473864156, 60.31288977592223, 53.99102926254273, 52.447698193211714, 53.78881931304932, 49.04583438750237, 49.12361106564922, 53.66899874902541, 57.111149218774614, 61.17520324645504, 57.366589653876524, 59.230998100772986, 47.2378021670926, 48.00068747612738, 43.6874335042892, 39.82301242889897, 34.78698722777828, 24.593192338943485, 26.162438508002992, 23.122460419131865, 16.879953376708492, 2.6157347761815597, 1.4100170616180667, 0.7838926656592278, 0.1906886919131202, 0.35976160017232744, 0.12206782166275287, 0.20194696683076122, 0.17162422619519696, 0.14068835475031408, 0.5205131694674492, 0.1542931110147507, 0.6434207613910399, 0.3538619570674435, 1.5963265804513809, 22.83125581279878, 36.67183514564268, 38.13693061951668, 50.293222627332135, 43.52055626530802, 56.64765450262255, 43.909855427280554, 50.534844552316976, 50.83370170285625, 54.138514303391986, 52.85497750005415, 52.27484326208792, 43.55189600298482, 45.094109196816724, 44.227253621624364, 46.51336000811669, 42.73356406919418, 49.66470595329039, 54.640185448431204, 58.26131366914319, 55.8885895821356, 58.72403175600114, 54.99514818191529, 56.0104811576105, 51.183949747393214, 46.313162234521684, 48.345263773395175, 47.954795745111284, 45.18814409932783, 46.86085062642252, 47.93266181022891, 51.26382489358225, 52.16184762216384, 64.58278586787563, 58.79151221244567, 65.16691307867727, 61.371945411928245, 59.209911438726614, 63.46126648687548, 60.73882779767437, 68.7510847276257, 69.12958560451385, 72.25161183264949, 71.3688902701101, 73.01317138056602, 65.46031421230686, 65.31637107172321, 66.4322030159735, 73.15935811688824, 68.19650080896193, 66.6634032034105, 62.229285317082564, 67.79914117628529, 25.62789397854959, 0.4745619593849106, 2.655028835419686, 33.127491243423954, 62.89232669338104, 50.063771816991995, 40.06085711140787, 37.93832532821163, 76.32744866032755, 44.74698335893693, 53.46771447889267, 44.480015077898585, 42.79091304348361, 77.39240354107272, 59.940095947634795, 83.95164981965097, 8.943469774338508, 0.344662344263446, 0.208006477163684, 0.24212193525125905, 0.38963614872867064, 0.09385426663943837, 0.1686361615335749, 0.15121847841768496, 0.20752540459075283, 0.21552797436954516, 0.17360738268302334], [0.0748614224815561, 0.03777238645500714, 0.07131855694517013, 0.03950535011808238, 0.08560935260667916, 0.12530648900616553, 0.12080391448351646, 0.03227198624142236, 0.1805087930012134, 0.4582985562662925, 0.07219026541157116, 0.3664616212969826, 0.3337597792908069, 6.290701695026891, 75.0841671420682, 46.119938435093054, 33.723891550494784, 33.42144935361801, 41.899130805846184, 42.72231078916981, 34.5977799354061, 28.80860278683324, 24.832174508802353, 30.301009724217078, 59.374392109532515, 54.10138514734084, 17.800590530518566, 9.901068402874856, 36.62199358786307, 55.16690877176101, 59.574636951569595, 55.888797467754735, 56.9732229940353, 60.6577798628038, 59.261843619808076, 60.2130340760754, 59.43596547649753, 61.73478034234817, 64.66403776599516, 62.644895738171, 61.81436131077429, 59.64079164689588, 59.69144121293099, 55.03034360947148, 56.56899136881675, 50.29624285236482, 48.157892150263635, 43.79529868402789, 48.161971415242846, 47.68311669749599, 48.39627811985631, 43.488647783956225, 45.48059209700554, 46.49158693129017, 50.819204622699374, 59.75588575486214, 63.73917818069459, 60.05388782870386, 52.789548443209746, 51.662455374194735, 55.76246184687461, 55.38006605640535, 54.73343195453767, 51.27673341381935, 50.75122210287279, 45.973465365748254, 45.05430106193789, 45.121491262989665, 44.5818123509807, 48.12148863269437, 48.37528167232391, 49.37954964176301, 44.69532182139736, 36.30436789604926, 41.38874807665425, 30.54401820705783, 18.06166937274318, 9.272500738020867, 7.463084411236548, 8.30421757313513, 3.411371876155177, 3.418641498973293, 0.5310974402293083, 0.05753934713861635, 0.07793694374061401, 0.07857234472589147, 0.14654034718630776, 0.09759112862088988, 0.26596268338541834, 0.05851707451285855, 0.036252893192032655, 0.033048826209720106, 0.06294882037646829, 0.35604904616071337, 0.34315394778405467, 0.703035027029053, 2.6908187472051193, 17.17249551127034, 32.519004152667144, 52.005968709145826, 52.888250966225904, 38.6993278995637, 32.23168465398973, 36.88012084653301, 43.06126632998067, 44.991700033987726, 43.167542949799575, 41.61070715996527, 36.16508453123031, 36.87351557516283, 37.033752241442286, 37.4949445263032, 37.25421297934748, 39.97303132087954, 46.60797149904313, 51.81289395978374, 49.216885028346894, 47.96884567506852, 52.631308263348, 48.926908123877745, 47.79503760799285, 43.711873792832904, 40.72293750701412, 40.18546296704201, 41.20373772036645, 39.655150675004535, 43.75369410361014, 46.81004416558051, 50.36975983650454, 55.90502823552778, 54.867545635469504, 57.01586308017854, 61.175175789863836, 58.88101285503757, 57.8221062690981, 58.98733262092837, 60.91371059417725, 64.10436261084773, 61.676948916527536, 61.91321288385699, 61.763896096137266, 62.077509203264796, 61.69214417857509, 61.81493397681945, 61.10594203395229, 57.926912000102384, 61.45408768807689, 60.01566040900446, 61.036100310664025, 32.89473387502855, 0.4177474693184899, 4.112333991835195, 38.67804119663854, 54.46543601251418, 32.77817672298801, 32.57883206490548, 68.82557838193833, 46.50684102889031, 34.26189561044016, 34.75509835827735, 21.705133530401415, 35.01613993798533, 40.12822774148757, 34.07606940115652, 52.85333010458177, 4.44354530303709, 0.09058578315401271, 0.07462641734990381, 0.11497633726966959, 0.03785156930286077, 0.017654944376479235, 0.04676612079023354, 0.08044843276542041, 0.1260292623192072, 0.08858501430480711, 0.07178782410318814, 0.105606691250878, 0.02972460599736341, 0.06102013274005825, 0.05539099911167737, 0.043428808135250886, 0.08559711818252841, 0.032469786313031955, 0.05812038269434726, 0.14268300255700467, 0.2538095871287008, 0.2415885695166165, 0.3305935378997557, 0.40220133900161714, 11.581002877604577, 84.61050602697557, 54.290749334519916, 38.38430666154431, 40.073024303682395, 48.00413523950885, 38.147226841219016, 32.97680947088426, 30.51084868369564, 31.761321867665938, 37.983887580133256, 59.89002689238518, 58.938208856890284, 22.135009611806563, 8.71467007744697, 36.38594535089309, 59.97338902565741, 61.84288086429719, 61.7548668000006, 61.951503061479144, 63.27899002259778, 59.48707788221298, 61.85682881262995, 62.60965324217274, 66.06455925972232, 68.46133924299671, 63.57114384251257, 62.2156354688829, 62.57399105256604, 62.48239978667229, 58.74180009288173, 59.58120692160822, 54.47627744367046, 49.72011335434453, 45.51311246810421, 49.56315578952913, 48.70318789635935, 51.878299482407115, 46.104107749077585, 47.32165459663638, 48.07612642165154, 50.746821203539454, 59.68341604355843, 62.02048970806984, 60.49031426829677, 57.6688043532833, 54.82022223934051, 59.71059806885258, 56.95276391121649, 56.39769361865137, 52.83278080724901, 52.97984223211966, 48.14690559141098, 49.07265555474066, 46.87906219113258, 48.10900372843589, 51.7461391418211, 54.47135879147438, 52.67446610235399, 49.00027605795091, 42.85809147742487, 45.57280309738652, 34.12383994748516, 24.980961776548817, 16.57338288522536, 12.49044950931303, 13.617508257589034, 7.1612550846992, 2.3386837974671395, 0.6831342690894682, 0.08116981179843988, 0.10597550896026435, 0.048367041538679795, 0.3210219740867615, 0.12308265067516796, 0.10914726618437037, 0.07626253600803114, 0.036787327619329575, 0.03299507748095259, 0.07634119791609627, 0.3521342142935722, 0.20689664558777887, 0.6415385140045997, 1.7604474963680392, 24.86137459355016, 43.58735422934256, 59.58621578831827, 66.78229024333339, 44.52085479613274, 36.645833753770404, 42.76763769888109, 44.72112709476102, 49.12410136192076, 46.18677954519949, 47.123127752734774, 42.05757494895689, 40.45567897058303, 41.06177929908999, 41.22387124646095, 42.695685740440126, 43.55958777089273, 49.64542358152328, 52.31031717792634, 53.69319585061843, 51.05012239948396, 54.177047667964814, 53.98705982392835, 51.69799597032609, 47.914944464160556, 44.392157908408876, 45.004824284584295, 44.53290431730209, 42.584223747253425, 46.317904380060014, 51.332568353222264, 53.55572069844892, 58.28904090389129, 59.22604022487518, 61.19489354472007, 61.86677202101677, 61.470659702054924, 60.973879752620576, 59.30791185748193, 64.28493284410047, 66.24370959497267, 66.330488112665, 65.0826488002654, 65.57498078192434, 64.93151987752607, 64.30241484795847, 66.32362396486344, 65.47872974026588, 62.93021678924561, 64.96802929908999, 63.79276167961859, 67.8441229174214, 42.30619045995897, 0.6655135113866099, 5.484748761500082, 46.58381754352201, 55.65549881227555, 36.752271190766365, 37.298308264824655, 58.974455479652654, 42.74224819675569, 31.239213212843868, 34.4397750977547, 29.406491633384462, 40.31660349138322, 49.753845737826445, 38.81300995426793, 65.6325533313136, 7.082821409548483, 0.11420276466636889, 0.05822732090769757, 0.040780618381235874, 0.048820860533704685, 0.06144229698205187, 0.12113837314949882, 0.09014893683695024, 0.06794133493977209, 0.07060788016045286, 0.07249927463670892, 0.31925295449553, 0.25883760603685535, 0.18696228703183515, 0.31215159522910274, 0.25015773792420665, 0.25260652265241074, 0.20985561423003676, 0.14283848776211663, 0.40483343324834303, 0.4837931043678715, 0.30519772320985794, 0.5374578086118544, 0.4936040859789618, 16.24788499647571, 97.58403562730359, 61.075194574171505, 43.59625016489337, 45.46067430127052, 58.98804256992956, 55.38610258410054, 44.98756193345593, 39.39633307918426, 32.96175149179275, 39.799133039289906, 71.8192175895937, 61.05325675779774, 23.144817929114065, 11.062502803341037, 39.96606126908333, 61.91343253658664, 67.09827638441517, 66.52417475177397, 65.79972867042788, 69.86506139078449, 63.60666090442289, 65.33554361712548, 64.06457801018992, 67.03104695966168, 70.79940918953189, 66.91507031840663, 65.65443231213477, 63.03776033463017, 65.16847025963568, 58.43325468801684, 61.909196376800544, 57.1848270200914, 53.867101976948405, 48.076275471718084, 54.9151945883228, 54.43545733728717, 55.70919605993456, 47.26683162873792, 49.231052629409305, 52.03482166413338, 57.476961228155325, 65.20933743446105, 64.42363962050408, 63.859755762161754, 59.06163015673238, 56.69183215787334, 66.69855548489478, 61.05994439894154, 59.509353022421564, 55.228568430869814, 55.79338581331315, 51.39362788969471, 49.54346941363428, 49.88385661955803, 50.23947831123106, 55.922792650038204, 59.64410212732131, 59.079406338353316, 55.186952083341545, 49.04573632824806, 50.540622203580796, 41.425363402212824, 31.238362058516476, 19.996272556243404, 15.879102772282017, 21.664568378079323, 17.429836334720736, 12.732798053372292, 2.5787159367915127, 0.26005213118849263, 0.42852222018184205, 0.23902919233566333, 0.3552900675323702, 0.4028061194525611, 0.4792516432221859, 0.17052164181105553, 0.1117488701317099, 0.2830518373558598, 0.21481071688955833, 0.5423285956344297, 1.0335960215137852, 1.6103062754677189, 13.921959688586574, 31.010211513888454, 47.15818197496476, 62.41755516298356, 67.33181430447486, 53.23931878612888, 42.904293075684585, 50.077998253606985, 53.234168714092625, 55.30423879623414, 50.646161417807306, 51.22093769811815, 42.04833776720109, 44.58701733619937, 45.48225125958843, 43.056045655281316, 43.16915504394039, 46.13406681245374, 52.20932791309973, 57.68463503929877, 56.37710117524671, 54.514940246458984, 58.091439739350356, 55.27414637227213, 52.13708962163618, 49.81259499826739, 45.96476554870606, 46.94977468059909, 46.939745180068485, 43.59205322880899, 49.50023312722483, 54.95177069017964, 59.271806440045765, 64.7602770405431, 61.918111924202215, 63.69259611252816, 67.5213981443836, 64.28310109722999, 63.1044327828192, 62.16495060151624, 65.44280082948747, 70.30784991479689, 70.9092120201357, 71.33620123709403, 69.98234025893673, 70.30312738110943, 67.60284223864156, 73.89451226880475, 73.36219956797939, 67.51261987993794, 70.21714118219191, 68.07056134746921, 70.60424773923813, 43.489357732957416, 0.6682319590641607, 5.474486860536761, 46.77517037237845, 64.64646946999335, 42.40046070468041, 40.89803211150631, 76.92886567884877, 56.38973512957173, 46.517007812376946, 45.08204398616668, 37.17667556578113, 49.57332257301577, 57.02317045580957, 45.79539368229528, 76.82910411588608, 12.520838072223048, 0.40001847871368934, 0.6351177778936202, 0.17421688223558088, 0.17588185176493662, 0.11341277479885087, 0.20718818800824307, 0.33243861470010977, 0.24956164491032404, 0.16262365835568598, 0.22941097376808045], [0.0752368898341252, 0.03465192647831094, 0.0436465303233314, 0.05019874244387593, 0.14873878970261545, 0.15925760591222396, 0.17474116216744148, 0.03187962090446344, 0.15065656824698373, 0.39950728356357545, 0.14739072010401758, 0.3377923435501514, 0.24319485671097235, 9.808185696601868, 72.69618111272013, 51.65111580202657, 54.585895922876176, 33.57803429326704, 35.0877506502213, 55.86564763899773, 39.156891992015225, 43.34748952619491, 33.22628005858391, 22.63051086856473, 54.501835607713275, 58.69220172205279, 27.411150547765917, 5.532477142349367, 22.742188592110914, 53.10745262330579, 59.37958532764066, 63.58078895076629, 57.124610793206, 58.00675184495988, 56.17871161430113, 59.9103133909164, 58.84301685517835, 63.8273177608367, 67.88142465776014, 64.78006147569226, 59.838651687868186, 63.52011772894091, 61.023525191891586, 56.32342353943856, 54.958987851296705, 51.842060704385084, 48.03523963497531, 43.949185032998365, 46.35729282133041, 46.74572906186504, 44.5112959800228, 46.62294710836103, 43.11378294421781, 43.912404967892556, 46.702528076787154, 50.19756778593987, 60.68593855827086, 60.112280153459125, 58.207432070086085, 54.99614446393905, 54.014665465201105, 51.10070136285598, 49.09623292184646, 52.64511500635455, 49.72889161879017, 46.94955895023961, 43.5446866866081, 44.225037482477006, 43.15123765699325, 46.22661121429936, 45.12813575806157, 45.39719074003158, 43.64688011907762, 38.24010856689946, 35.72477102279663, 24.97683740431263, 17.99379864046651, 7.815705489727759, 5.422949367953885, 6.643700301647187, 4.100465635138174, 2.383016876636013, 0.12187668272564489, 0.18216456947547777, 0.055512018021075964, 0.07632050588126145, 0.15733405106490658, 0.17000110038826544, 0.11913214209339312, 0.12697896619717922, 0.006011397617253205, 0.08051352725634653, 0.06922953476708743, 0.1856210049722464, 0.32224780669616115, 0.46861717837952804, 2.2513144727676146, 13.478277844767417, 34.63665454618393, 52.78555547037433, 77.80350715883317, 53.5747088924531, 30.243798032883678, 35.27878184472361, 39.79858390746578, 42.16262386691186, 41.764824928775916, 43.858566514907345, 39.34504416681106, 38.180159061185776, 36.85744170219668, 36.790063227376635, 36.76432855667607, 39.45494897903935, 45.854052728222264, 49.17905769040508, 52.701157831376605, 48.32127847979146, 48.61198494511266, 51.990228237644324, 50.2408472184212, 45.63637687313942, 42.334949278062396, 40.086379974119126, 40.186894632154896, 40.55684081969723, 43.42883948356875, 47.67697034343597, 50.74698594308669, 53.6783653689969, 56.051160058667584, 56.489602596529075, 56.66038259383171, 54.88119156129899, 55.836006287605535, 54.74490880966187, 59.81083816097629, 62.68283682484781, 62.204711667953006, 59.82176588427637, 60.2010904589007, 57.89283052567513, 58.302263213742165, 60.197642695519235, 58.253680736787864, 57.45545487250052, 60.89542058206374, 60.32371159522765, 61.91966518279045, 49.91202315976543, 1.2344131618738174, 9.364198888501814, 53.26531625563099, 46.27757064757809, 27.362673974806263, 34.05989354656589, 89.39816674878521, 40.56951007535381, 31.342065603502338, 34.7222916541561, 21.18753952364768, 46.68696018957323, 53.40329739355272, 32.026564305828465, 53.20879097907774, 4.197919618698859, 0.1269742241129279, 0.06748070925353997, 0.05875464603905717, 0.02844622933245715, 0.1349599782617823, 0.040419538159884756, 0.18128686254062962, 0.03799089005277042, 0.08985128869572956, 0.056647360324859626, 0.047051894568627885, 0.03309412881912243, 0.03910041902394545, 0.05532699629604336, 0.0428012250772407, 0.08164033534065371, 0.028071288665335987, 0.10182446920342984, 0.14270446834064301, 0.2493745049521808, 0.1774920306859478, 0.17798991122793767, 0.35380290701024, 13.353570007508802, 83.76276416163292, 55.46766042709351, 53.51376310471566, 42.1153240050039, 41.82894783635294, 48.44981847270843, 41.10832214355469, 36.67226660636164, 34.783472784103886, 27.692255050905292, 59.03038455593971, 58.19915194665232, 33.30988145643665, 6.888076220789264, 20.750616904227964, 52.30212334663638, 62.949644288709095, 64.80297203986876, 62.30668937006305, 61.527279115492306, 57.209286920485965, 61.0468005364941, 60.92313212733115, 64.74078678315686, 67.84176165057768, 65.41420675093129, 61.959951846830315, 65.47686269206386, 62.34525803596743, 57.92371919078212, 59.387551661460634, 54.66584559409849, 50.392807683637066, 47.76908720693281, 50.84417443121634, 47.37983119103217, 45.71974292878182, 49.97568715003229, 45.582440360899895, 48.06385724775253, 50.21994490777293, 53.083200608530355, 60.535574497715125, 60.07230335666288, 58.869355570885446, 57.29199794030959, 59.10402313355477, 56.05629836359332, 50.85268205212009, 54.18700264346216, 51.44368910020398, 49.9376872278029, 47.85150797136369, 48.45772989334599, 47.93675284231863, 48.61893538505801, 48.965221835720925, 50.945300978998986, 47.901416209436235, 42.24772361017043, 38.63435383765928, 31.719564314811464, 24.000092706372662, 21.241976138084166, 13.620436306922668, 8.437020201836864, 6.355714980633029, 3.0031244793245873, 0.6928597859317257, 0.21439735116737507, 0.046279731567107865, 0.056637473960196784, 0.06029008542217555, 0.12974141796510066, 0.14875834026644308, 0.09277560718117223, 0.038209692424824165, 0.04283871742025499, 0.06291556066923565, 0.11129447274030217, 0.1831266839778231, 0.5863310925422177, 2.59459589758227, 22.097399965409313, 48.080746973714525, 55.19807200278006, 77.37931066943754, 55.337265153085035, 36.006569785456506, 39.02888151907152, 44.55789766004009, 46.12592397197601, 46.764246571448545, 47.34805214789606, 44.23526702388641, 41.3035463517712, 40.70195282659223, 38.99878517273934, 41.48518346971081, 43.03897942266157, 50.38130337192167, 50.894349390460604, 57.020205143959295, 54.13527442562965, 52.64502871421076, 52.958312342243815, 52.358197550619806, 48.66642744310441, 46.97751760482789, 44.22218199699156, 44.3865018506204, 42.45529936205956, 45.80721962836481, 51.135457484952866, 56.498125906913515, 58.69551220247823, 60.005827026982466, 59.3078883232609, 57.63509942639259, 56.55378826202885, 56.51550592914705, 56.37830926525978, 62.01528472285118, 64.56494692833193, 67.18144632154896, 61.56631062107702, 61.814137735674464, 60.8736788841986, 58.08883920792611, 62.70085619341943, 61.826740311038115, 63.427922418040616, 63.97592852192541, 63.607327707352184, 66.10157858940863, 54.38027743370303, 1.7301871459330282, 12.405821431067682, 61.208209991455085, 50.36472351320329, 33.698929586718165, 37.313193659628595, 79.22491919609809, 35.67315263132895, 27.62221132555316, 34.59680718760337, 32.815966798413186, 48.943542895778535, 55.261088801968484, 39.78099599961312, 66.12848604879072, 10.238709949677991, 0.00904728866918313, 0.14007117899675525, 0.11460916664932044, 0.04546953996102657, 0.09787144785326335, 0.0421304346603011, 0.1933747800367494, 0.1205526989313864, 0.034564500524392056, 0.07025395520031452, 0.11258328543795694, 0.2070026568347408, 0.18860024430098074, 0.1488037692803529, 0.2703622037604932, 0.48565043857501405, 0.22479383845723447, 0.24000167966850344, 0.25543763122010615, 0.38199610707740633, 0.17337484435448725, 0.5109027190314186, 0.46565915968629623, 16.370614978574938, 93.40620933040496, 61.39682892830142, 64.98128298790225, 45.92730691356044, 52.02934603537283, 71.6674610876268, 54.91581432281002, 52.706276524451475, 40.883154561442716, 28.897911233286706, 70.0539941172446, 67.13806490744314, 35.612657916161325, 6.758889527090135, 23.994181694522982, 56.87821926609163, 68.21631662307247, 71.0693859284924, 65.17271426416212, 67.42988140352311, 63.33964947731265, 66.32891131985572, 63.1235739492601, 66.41057506684335, 73.96760171459567, 67.71381393555673, 65.3032938895687, 67.6774614087997, 66.06530451005506, 58.54842724338655, 62.33804479722054, 57.48983836943104, 54.99950593517673, 48.83234762376355, 53.91234651688607, 51.08646708150064, 46.85372760218959, 50.82919882189844, 45.51907054839596, 50.96233975502753, 57.22130114032377, 55.55367408260223, 65.94211070768296, 65.24094389330956, 61.97163266520347, 63.652376128781235, 64.6271086508228, 58.98141376433834, 52.18037297648769, 56.30983644916166, 54.42654571225567, 51.095951372577304, 51.076872964059156, 49.689628693365286, 49.2976152512335, 54.570688893718106, 54.730266601808616, 56.73824948649253, 56.4886494605772, 51.171986518367646, 47.865797165901434, 39.89030068920505, 32.245244287675426, 25.782137263205748, 19.961724319765647, 16.136569111577927, 16.024044156074524, 11.674474919995955, 1.8422514680893192, 0.32773884914575085, 0.2184373618013436, 0.14976668051413952, 0.1790192576065179, 0.3295549065355332, 0.42578088179711376, 0.20525897943204452, 0.08264582574127183, 0.15504404571988892, 0.20690009298343814, 0.8586489349122971, 0.43277872726321226, 2.249397659494031, 4.24142066509493, 33.51444875040362, 45.328639476530014, 56.659841306747936, 75.83242201036023, 61.83599710464478, 39.88479368148312, 45.90301567508329, 53.323163370932306, 54.18697126450078, 50.32069490801904, 56.06419409475019, 48.0654771866337, 45.900725010902654, 44.0246985035558, 42.072413275318766, 41.984701233525435, 44.306783599238244, 51.60675379537767, 57.210000791857325, 61.02882039162421, 55.83375484712663, 55.59757717194096, 55.04265592944238, 55.7674079556619, 51.38065661153486, 49.92079357947073, 48.4512815167827, 47.288659618746856, 45.027876054086995, 48.61829211634975, 55.518863047322924, 60.43160815392772, 63.923470743240856, 65.74185802090552, 63.9087579327245, 60.8678973105646, 59.089569199469786, 59.19191168200586, 56.37332393277077, 67.22691443658644, 72.22296284091088, 72.53475989064863, 68.46112743500741, 67.46675952788323, 66.6152992556172, 65.1522591037135, 71.7406838940036, 68.58163833618164, 68.19795208592569, 68.61742604163386, 68.81039096463111, 72.36854553222656, 60.26573111934047, 1.8590096720764715, 12.073717290355313, 64.79855937342491, 56.081872217116825, 38.78896582511164, 38.717359035245835, 94.976287041941, 48.117668244146536, 40.107807882370494, 46.427593461928836, 35.08021185475011, 61.49275441323558, 71.31403984562044, 43.724884294694476, 80.4077491452617, 17.613340500862368, 0.2538634124662607, 0.28132743472533844, 0.2571892606154565, 0.12127817653480077, 0.34029123042860343, 0.17056627409352412, 0.54344414222625, 0.21555546160426833, 0.11949002772809998, 0.17132961942303568], [0.03664726376413338, 0.08521795062528503, 0.07199626130562636, 0.07915254141534529, 0.10700877004813765, 0.2215563355674667, 0.051901085572617675, 0.010347947001367087, 0.06425713767267524, 0.17470230618792196, 0.07347326350188063, 0.34436062819534735, 0.046464121269602934, 14.9676674988962, 79.71216386364353, 54.22534381189654, 42.92206141256517, 31.037479831326394, 45.57710985983572, 41.402362623522365, 38.94275019245763, 75.84046286921348, 70.70349939407842, 17.971241089605517, 43.26551591196368, 60.501383196923044, 37.49698023642264, 11.540933905109284, 11.500931612906918, 42.90952943986462, 59.354827327113, 60.81802829619377, 61.817310933143865, 57.60370477553337, 54.88043062148556, 54.69741675161547, 60.63324151500579, 64.47432448787075, 67.04924675726122, 67.41514113641554, 60.10821265559043, 60.69760368716333, 61.32943084163051, 56.08249195160405, 54.58933191914713, 53.08227492916969, 47.703144319595836, 45.28306153512771, 46.76882397743964, 47.39989803683373, 48.016318121264064, 49.200909214635054, 47.1630927824205, 47.06486094382502, 46.611262367617705, 47.63175326008951, 50.99527981973464, 55.39428857065017, 55.36116415454496, 56.23373070070821, 55.00897061440253, 52.600035205964126, 47.241646089861476, 50.86825778407436, 47.38786812751524, 47.52036579193608, 40.58263040358021, 45.16963835685484, 42.548483110243275, 43.40099850008565, 42.60827179877989, 41.356384600362475, 39.94186024512015, 33.50748654334776, 21.900944132958692, 24.10471408597885, 7.829293560597205, 12.779612521971426, 2.971359899928493, 1.4707048309426156, 5.5971339825660955, 2.3989331193508643, 0.5941309707780039, 0.2968302963962478, 0.3165919940558172, 0.0674136535775277, 0.1624973611004891, 0.25242094551363303, 0.023253348302997412, 0.17348624886043612, 0.07435778861925488, 0.04765284841039008, 0.18218684731231582, 0.2097447459856349, 0.13341117830526444, 0.38051176575883744, 0.5884582429162918, 8.159810612278601, 40.15313871445195, 42.7701872394931, 64.87394732813682, 56.77427253415508, 35.92624356669765, 33.39843680781703, 40.79180648249965, 41.68641282666115, 40.97497332480646, 38.89630540724724, 41.03746060402163, 37.75216963983352, 36.03396754111014, 33.654077283797726, 36.80317963323286, 39.74236065341581, 46.657922883187574, 47.289765727135446, 51.61700687100811, 52.61575606561477, 52.251124689655924, 49.87387810983966, 45.42827552364719, 46.242418366093794, 45.455108457996005, 42.66091392886254, 41.552067725889145, 40.260897990195986, 43.987212411818966, 52.29845200815509, 52.01788094735915, 52.203930731742616, 54.995195250357355, 57.11718574646981, 49.63734742133848, 50.25479516675396, 50.520029760176136, 52.307442080590036, 59.306056576390425, 59.57045962733608, 58.23125654651273, 52.625730652962964, 52.95444880762408, 52.92320320683142, 52.54295687521658, 53.415476352937766, 54.80870223814442, 56.823294316568685, 57.389625733898534, 58.71556728116928, 58.35949451692643, 49.27898791528518, 2.1767700727908843, 16.94405863361974, 56.58090752940024, 39.27113886802427, 22.023645677874168, 45.111379392685436, 86.63375085399997, 48.044433670659224, 30.88792181784107, 33.424222469329834, 20.47776310674606, 46.705465932046216, 54.26847027194116, 31.587407896595618, 52.408192080836145, 9.918063052238958, 0.33926298721663417, 0.24369321222747528, 0.1949225534354487, 0.005278783426019213, 0.12278185391257848, 0.08406272833986629, 0.06486565280225008, 0.08052262072000774, 0.16174000657854543, 0.014806360385621027, 0.04291607697884883, 0.03994021609786057, 0.015910204026787993, 0.07249746666920763, 0.16885363857351965, 0.19111020881081783, 0.09528246137403673, 0.0736214632108327, 0.02327471257998578, 0.20829369884825524, 0.20437001100470945, 0.302095097760039, 0.5932940350424859, 19.46046502359452, 86.12971844211702, 54.475787147398925, 49.218806989731334, 36.65936200849472, 46.09727498023741, 39.505112171173096, 34.05641440422305, 61.81147052395729, 65.83431613060736, 22.069190279130016, 48.1584491268281, 63.00301205727362, 46.446534587490945, 12.978787537544006, 10.83008570055808, 38.28813798965947, 63.761292503726104, 64.16213912348594, 65.97361518490699, 60.68108266399753, 57.33870552432153, 55.363007668525945, 63.27565600795131, 65.81823441290086, 68.90062901281541, 67.12577219932311, 60.40053121505245, 61.85764466562579, 63.14695519785728, 57.84313801796206, 57.49265855358493, 55.807584793336936, 50.0602573733176, 48.37212024196502, 47.495968649464274, 49.42415875773276, 49.64321528711627, 50.05760977345128, 46.856936100990545, 48.38244784262873, 48.790656751202, 47.87177093567387, 51.55683379019461, 56.41242211864841, 58.44033456617787, 58.25374349471062, 58.736265628568596, 56.72678047610868, 51.04272873170915, 52.57120186282743, 51.05067937604843, 50.284338458891845, 45.09060259788267, 47.04836345488026, 47.321752655890684, 47.50858299193844, 47.56031905451129, 45.12033024141866, 43.66487595342821, 36.40041889682893, 29.91234402502737, 30.859506207127726, 25.815683334104477, 32.00876851235667, 16.309211254119873, 5.778681376288015, 5.263591802889302, 5.367346338687405, 0.9749532166507937, 0.1697863965866066, 0.11952696082692955, 0.06160635471103653, 0.09563759675309544, 0.23695945259063478, 0.12900136170848725, 0.20690006233992117, 0.03949453295659154, 0.06255602411505196, 0.018917129773105827, 0.08559693432142658, 0.10514233471645464, 0.4100264368518707, 1.13297748229196, 9.78974271205164, 56.338406993496804, 53.994731979985396, 65.9227498885124, 56.02454285467825, 40.938636487530125, 38.24031645251859, 45.37624920568159, 47.30900887520083, 47.76163862597558, 44.160926342010505, 45.38603159689134, 42.743271935370664, 41.07626068976618, 38.60086464112805, 41.595068670088246, 41.36694362086635, 50.36566880441482, 51.06882033809539, 55.65559294915969, 57.14352838454708, 55.21798979851508, 52.11013117144185, 46.662963128859, 49.114338582561864, 49.65126006833969, 46.3898955622027, 43.960646198641875, 43.78861888762444, 46.309812530394524, 54.1793030308139, 56.41003339521347, 56.313731362742764, 56.0255705156634, 58.3829620576674, 52.86776834918607, 51.94705863152781, 51.67196319949243, 53.28808561448128, 56.64284567679129, 58.519444850183305, 57.96733986946845, 55.98974750887964, 53.93698684630856, 54.656086737109774, 56.09737734640799, 58.50769735151722, 56.90768018845589, 62.74994857849614, 63.05420291039252, 64.10051868807885, 63.30862352924963, 54.74152772657333, 2.5187029377106698, 22.316305483541182, 61.962434707149384, 41.78304433822632, 26.70866777819972, 46.06177753017795, 74.48623318825999, 37.47941194042083, 29.125600899419478, 32.82216610447053, 31.375531265812537, 53.89713556535783, 52.05111911219936, 35.4410110750506, 67.3460760424214, 26.547497587819255, 0.4045339848005003, 0.11624697070088118, 0.05421578576187453, 0.026153379886020577, 0.1886026038517875, 0.038286125017029625, 0.1513597143874053, 0.1384794627947192, 0.08583251401902207, 0.060298225106371034, 0.1493688357333022, 0.1814571179209217, 0.17466407840050038, 0.19778550061727726, 0.29745707889237716, 0.8887227889030211, 0.19422610290348533, 0.15700265675062136, 0.23010209232809084, 0.27788552425561414, 0.30578577230053566, 0.5022086323268953, 1.2796281614611227, 26.289509573290427, 98.92484295752742, 64.19480069991081, 54.91219397514097, 39.86533480305826, 62.9692090711286, 56.28462345369401, 52.46272871571203, 85.40920257568361, 79.48293270603304, 24.680602358233546, 58.699277677843654, 71.78790138613793, 47.93388558972267, 12.992376589005994, 12.522840442196017, 44.04856612605434, 66.39633686311784, 69.99034189408826, 70.56144683591782, 64.95964327166158, 61.70710017604213, 57.65655086886499, 67.01629884781377, 68.62406269196542, 74.2236069710024, 71.86988676747968, 61.124381096132346, 64.50997491036692, 65.3540179806371, 58.69666537930889, 57.174860277483546, 58.213888291389715, 54.983604646498165, 50.10139911405502, 51.73092034555251, 54.70485748783235, 50.38182112478441, 53.902881837660274, 49.2640083835971, 52.756020022976784, 54.040662934703214, 53.32633264603154, 56.44041215219806, 60.6698097721223, 60.01830016413043, 63.70348068975634, 63.827325605577045, 59.35188554948377, 54.218530654907234, 54.1524112609125, 53.009118803085826, 54.027825017129224, 46.39830512385215, 50.69592452818348, 49.07296542198428, 50.73353613576582, 52.858923404447495, 50.645114144971295, 53.23003845830118, 47.201928169496604, 40.56654868587371, 43.1299784106593, 28.438329081381525, 37.71066311867007, 21.207980955800704, 6.553220047104744, 14.476121952456815, 14.290645814711048, 1.910599748934469, 0.5903439223766327, 0.4888806942730181, 0.18898875813090033, 0.20531884154244778, 0.48195758834481245, 0.3695315501141933, 0.3951177529750332, 0.17887739344469963, 0.22170515580763742, 0.354523703816437, 0.3854868020261488, 0.24987097589239, 0.6567038066925541, 0.8881598062092259, 26.597854937276534, 52.55908173899497, 44.55449696510069, 63.32235574722291, 55.94458926108576, 46.0261937879747, 44.87167942908503, 54.273443837319654, 56.04385268303656, 53.76004088309504, 49.52933319153325, 49.66212895608718, 46.56279363939839, 43.763413736897135, 38.01679626587899, 42.47858647377261, 44.98502023758427, 52.352604250754084, 53.25254109597976, 60.10364701670986, 61.28479034669938, 58.7955875550547, 54.13007336278116, 48.84083955518661, 53.56522852374662, 53.975763397832075, 48.96676724956882, 46.77859067916871, 44.04499676919753, 50.13238191604615, 59.76878250798872, 63.38565495706374, 61.12046657070037, 60.53973613246795, 62.749399446672015, 56.10005240286551, 56.0019225458945, 54.80887874480217, 53.89691983499835, 62.26443759856686, 66.90468388219034, 67.74397696218183, 61.651084807611284, 60.009749397154785, 61.44507015905073, 59.96223380488735, 66.23604528365597, 64.37891283342915, 68.18974648752521, 66.21982236062327, 68.83769850577079, 68.56128907972767, 63.911868372271144, 3.7010717632309085, 22.46798157691956, 69.10351753234863, 50.91750314158779, 31.672656689920736, 51.4968607502599, 88.28834779800908, 57.86344805071431, 43.038932354219504, 44.47607309587541, 33.755819643697436, 60.16231782974736, 71.04735005286433, 44.27249031682169, 73.29996724282542, 33.25010061264038, 0.62441767463761, 0.35577209005432747, 0.35128459214202823, 0.15683712047194281, 0.266260140004658, 0.1478341624381081, 0.32896753160222886, 0.3745932156039823, 0.5378632836284176, 0.15880136990979796], [0.1081599320675577, 0.12395580704774588, 0.1449463327204989, 0.060298665606927496, 0.10623058559553278, 0.07800603721050486, 0.2859953923090812, 0.0019714228936561174, 0.018099198763769482, 0.16879088065076261, 0.2345529712376095, 0.37769259284100226, 0.5192007689226059, 16.202585543355635, 75.20252073964765, 38.71722175228981, 25.435729219067483, 34.595971722756666, 45.214376911040276, 27.946248131413615, 43.27767133712769, 84.37910972102996, 69.72505630985384, 33.39761311008085, 26.023708197378344, 62.42033220106556, 50.325899893237704, 23.94842528527783, 5.222285322604641, 28.845414230900428, 58.14733743667603, 62.1950783268098, 64.00993154894921, 56.38469880627048, 55.46269078408518, 56.43851372503466, 61.56289815902711, 68.43083889253678, 66.18845908872544, 65.06561394660704, 63.39851248648859, 62.66389962165587, 57.904656471744666, 58.71987012124831, 58.84214216662992, 55.086386434493534, 46.242794913630334, 46.854814098727324, 44.88319550791095, 45.84589027589368, 46.50140070146131, 48.43387796032814, 43.94874572753907, 45.82417603461973, 46.28744717567198, 45.24286900797198, 44.0339356853116, 50.98594065635435, 54.2038139220207, 51.269292677602465, 52.516814278018096, 54.060623876510135, 49.19701037868377, 48.01782431141023, 47.593274808699086, 45.668030400430005, 42.748512221920876, 43.401967325518214, 42.19659943734446, 41.229911696526315, 38.00535078971617, 36.845631445607836, 37.245540618896484, 25.871877170378163, 17.07183768672328, 18.791461644634126, 17.868461262795236, 28.05549006308279, 9.102692507928419, 1.368744289202075, 6.023703015619709, 1.2208670113355884, 0.8214675010212007, 0.10856355315134411, 0.24996813116294725, 0.044683392024448806, 0.13759083144607084, 0.10715736046193108, 0.20819611456846038, 0.0665542791267076, 0.14758023493472608, 0.027063388918196003, 0.21058526701263844, 0.1782684301536891, 0.23979376340585373, 0.0649184515819915, 0.35959474622241916, 0.324562679255201, 44.83931595279325, 43.11861922664028, 53.50682443188083, 43.27345086682228, 37.002557631461855, 37.70358716287921, 38.93816886409637, 39.42734333776659, 42.93883738979217, 39.62444636129564, 40.32129464610931, 37.777527762997536, 38.32008177234281, 36.470758761129076, 38.50768873768468, 40.49857401078747, 45.65235660922143, 46.371472189503336, 50.45569112223964, 51.10891872836698, 52.776698758525235, 46.68192386627198, 44.4331584438201, 44.97381794837214, 44.551704237538004, 42.76745334748299, 43.499257795272335, 42.633661300905295, 44.38644301506781, 51.0076548976283, 52.88707817754438, 48.37540326579925, 49.088090081368726, 52.75076404694588, 47.527845751854684, 44.36612121520504, 44.961160459826075, 49.26618137667256, 49.4716037473371, 48.46248772836501, 49.60206177926833, 49.213515712368874, 50.76600159368208, 50.0762253422891, 53.912170010228316, 53.935578715416696, 55.36323124362577, 59.479095858912316, 58.008916993294996, 55.400925220981726, 57.95501578238703, 42.33541996248307, 0.922176132519399, 32.467022941958525, 58.15923398540866, 34.30183318353469, 16.543100226309992, 33.14193341039842, 62.22784188485915, 41.0891652876331, 25.30437884792205, 34.12168656626056, 20.024674438661147, 45.82816508508498, 78.31264649668049, 26.893866408255796, 56.46525644486951, 38.352664901364236, 0.5113566720918302, 0.3201565705239773, 0.21077836713483258, 0.25101079214965144, 0.11078644153331557, 0.09796636614708171, 0.06511504506512035, 0.14732704287575138, 0.07326462711658209, 0.01810080180275104, 0.05134102167381395, 0.11954430505753526, 0.08411669923413186, 0.021704839459890803, 0.1470497803341958, 0.23543653108419912, 0.15884618605336837, 0.08935121714227623, 0.04137298820780651, 0.20003105754092818, 0.1368119192099379, 0.14412631220634908, 0.3580189340056912, 21.70436082347747, 79.30146032764067, 47.015894074593824, 32.41108013737586, 41.870015052057084, 45.00953897353142, 29.94452314992105, 32.84411176558464, 69.88591271062052, 65.4524027916693, 34.075979186642556, 30.887464861715998, 62.85853155197636, 58.46342555938229, 30.740697614608276, 5.646458277779241, 26.303706592129124, 57.055090704271876, 65.33352751885691, 67.53792701228973, 61.884736476405976, 60.67307710647584, 58.1737232208252, 62.33583258044336, 67.97312182764854, 68.11027142309374, 66.53723624444777, 63.401426807526626, 63.78314402795608, 62.165742920291045, 60.8598917530429, 62.21658076009443, 58.81998861989668, 52.61134732154108, 47.94169502873575, 47.15779758268788, 46.44059219667989, 47.79339805726082, 49.72141165887156, 47.30173680090135, 47.411194462930005, 46.07043812351842, 48.05696956572994, 46.80799276598039, 53.28491241701188, 56.241041998709406, 55.203696681607155, 55.51951023840136, 54.642978175993896, 51.36086433164535, 50.61313113858623, 50.96498735489384, 47.65159653079125, 48.09645998862482, 47.873924316898474, 49.76180814927625, 48.28682830256801, 44.31544027020855, 43.786583177505, 42.81443157503682, 30.466008147885724, 27.31774518566747, 33.84178230839391, 39.888182609312, 42.25110077088879, 19.945211141340195, 6.418707265007881, 6.498959449029739, 7.5428418863204225, 2.399142475858812, 0.14548542879281506, 0.12690865464748877, 0.016502020354833336, 0.1711595325820869, 0.12148125112176904, 0.14529522448297472, 0.054797254157282656, 0.09169364588395243, 0.012539653689600529, 0.06191089381313613, 0.32896115775069884, 0.2880102648369728, 0.12338414457776856, 0.15837717170436538, 2.9467874765396123, 44.39250307698404, 53.99588123444588, 63.12134212063205, 47.44365207610592, 39.69736714516917, 40.893529230548495, 40.3621147524926, 45.90731459279215, 49.321816275196696, 48.21828880617696, 44.7948911882216, 40.8903834896703, 44.04710308198006, 40.20244290751796, 41.32309544471003, 43.519736489942, 48.322106099897816, 49.13420538748465, 53.63409357686197, 52.767230156929266, 53.77540480706, 47.90400497374996, 44.84882377809094, 47.89069244938512, 47.36634608237974, 44.2897879692816, 45.45274719115227, 43.60954699977752, 45.38936168916764, 53.718863841026064, 54.585327179201194, 52.425446587224165, 52.80744229593585, 51.588452016153646, 49.64856147766114, 48.13666820526124, 47.55910704212804, 50.589683209696126, 52.25544321921564, 49.612487439186346, 51.45826855013448, 52.32768543304936, 53.13596040971818, 53.43493523136262, 56.1898668350712, 56.69662921659408, 58.88013816648915, 63.427102642674605, 62.14295002721972, 61.00722382145544, 65.10835601437476, 43.48991078715171, 1.3649568730785002, 40.224388568632065, 60.975770335043634, 40.52299468748031, 16.50577299056515, 31.269693951452936, 52.413644175375666, 41.309018058161584, 26.447196698957875, 34.24859485318584, 25.86633093895451, 52.93484872387302, 98.47322125588694, 41.03751943957421, 67.38133815027052, 64.75043973615094, 5.26160708358211, 0.3728092419764688, 0.12828114712911268, 0.15584762598718369, 0.12159903714012717, 0.10876222273274776, 0.018240162772276712, 0.09019455737284116, 0.10342279674425241, 0.02860530557471418, 0.17692270478413952, 0.32769374188876926, 0.17461532456499917, 0.1797254834203951, 0.3416320681571961, 0.4184280618304207, 0.478812889346192, 0.2558017221669997, 0.19607441259487984, 0.15980293794024378, 0.3136697363468909, 0.4381574612231024, 1.0714782726380134, 26.424533244102236, 91.67405928334883, 48.034055079183275, 33.396867859748106, 46.22304185744255, 58.20771448073849, 38.64152393033428, 53.95422958558606, 89.7985387617542, 74.8934301253288, 41.974624664552756, 38.31571225197085, 72.95503400987195, 60.57094643192907, 27.754810971598474, 5.837749819601736, 31.918367685810214, 64.8426232799407, 71.43644132921773, 73.7829992848058, 64.78515271217593, 65.59271381747338, 63.35437013256935, 67.10226151251024, 71.03881497536936, 72.76597576756632, 70.9383709199967, 65.70623897737073, 63.63432930361841, 61.98435291167229, 62.3511141346347, 63.00993111825759, 62.39773150413268, 56.04056181446199, 51.42705825067336, 50.11746514228083, 50.29167329111407, 50.22851136422927, 52.66476215854768, 49.26553026322396, 51.961579245905725, 51.495727185280096, 53.33017656880041, 50.29141049231253, 56.31618284410047, 59.57948107873241, 57.95534918385168, 59.1943004054408, 59.40923844614337, 54.3430188394362, 53.63584295395882, 54.49814073501095, 51.77776521252048, 49.77660332956622, 50.650244605156686, 52.032691817129816, 51.249574922746234, 46.94287523146599, 47.204497321959465, 52.333345413208015, 39.45638064415225, 39.89840430598105, 43.86008447216403, 43.31939358865061, 50.993506908416755, 26.613297308644942, 7.335989321431807, 13.917376399040224, 13.237873815721082, 2.8164598634166103, 0.2344630938023329, 0.35602731990718073, 0.07426790352309905, 0.3407089015649211, 0.310255037320237, 0.4250170308495722, 0.1751793491383714, 0.253440440001507, 0.107121515207954, 0.29147855937480927, 0.5641424896255617, 0.571164941835788, 0.22460936448506771, 0.9988196746956919, 7.697023883942635, 54.74230043349728, 42.124525885428156, 62.41422899307744, 48.626078021141794, 46.16554383308657, 46.15682048182334, 49.52463026969664, 52.98569048604658, 58.40626485886113, 53.01454736340431, 48.51903653913929, 47.87853702422112, 47.183151783481726, 41.176767503061605, 42.05090691966396, 46.714201050419966, 51.503819034945586, 54.49940373820644, 62.00937763337166, 59.932015865079826, 61.304931717534224, 53.69348610601118, 46.68641890248945, 53.455896377563484, 54.38986370640417, 51.048726035702614, 47.01919671027891, 46.79144036385321, 47.01030861946845, 57.60232017886255, 58.88721019990983, 55.7472469729762, 57.303831731119466, 57.592008267679525, 53.02880910135085, 49.86576664832331, 49.44839116065733, 51.61701079337828, 55.06878675953035, 55.033383446355025, 59.9532437324524, 57.721473939957164, 57.85560331036968, 56.30066202532861, 61.99004427079232, 62.40411712277321, 65.01335620880127, 69.07370751903903, 62.45960689360096, 63.75498925485919, 66.94922631786716, 54.392177904805834, 2.4136672577550335, 40.861314804323264, 67.38332286957773, 46.7374607055418, 24.31959721349901, 37.57452157235915, 66.22129717180806, 50.04845103909893, 35.37915529743318, 46.70743888424289, 31.687596997907086, 53.15660384393508, 87.0359036230272, 47.95221874790807, 71.4205635747602, 74.58260582339379, 4.38727350965623, 0.5058559769343945, 0.5388857965027133, 0.3956053832605962, 0.2211106256131203, 0.28888421794099195, 0.1528307564196087, 0.22981160710896217, 0.6629315499336489, 0.11783888608577753], [0.05534720186504626, 0.18151508013327278, 0.026763544019852436, 0.08560407426088087, 0.11573318617358325, 0.175807970245519, 0.17452598339126957, 0.20467022554047648, 0.045545152839153044, 0.29416519908174393, 0.3563781881765012, 0.6733452588800461, 0.6608247468548437, 27.452360929981356, 68.14634153919836, 42.651264898238644, 34.67117532607048, 29.00043610603579, 33.261499020361136, 22.640979674554643, 36.294777700977946, 58.56217122847035, 46.15095653841573, 41.365833590107584, 25.315918460969005, 51.26880238133093, 52.605475533393125, 41.5754097507846, 8.410746205237604, 13.099949552166848, 49.87822801836076, 59.030219816392474, 65.54159748938777, 55.54148335610667, 53.797040600930494, 54.425816151403616, 62.20036175943191, 65.70307362464168, 68.46237474872221, 65.36200392630793, 60.19908220537248, 64.03445420726653, 64.95059436367404, 59.954291005288404, 62.90894969817131, 58.48079773687548, 51.64569508644843, 45.772506652339814, 45.04612292012861, 43.59567357647804, 45.079490523184504, 43.698145497229795, 43.58575390231225, 43.79400430187103, 45.340155555355935, 39.68805543838009, 43.0157668359818, 42.69704680288992, 52.44865525153376, 51.42954503336261, 48.7221250995513, 45.84736900944864, 47.25530378280148, 48.631871361886304, 46.30690997646701, 47.69730783277943, 42.74491933084304, 42.14397691911267, 43.1898965374116, 39.99136447906494, 36.0900652793146, 35.89908115325436, 31.593462074956587, 22.413217444573682, 19.123931546365064, 31.302837979409006, 34.21680796530939, 38.0556865661375, 9.602040629233084, 4.167219227360142, 9.102126706031061, 2.424148076003598, 0.9321768281440582, 0.32983753169255875, 0.15460788122107907, 0.34136516312437676, 0.19497806416644206, 0.10293221702018093, 0.1364398303051149, 0.12998037611044225, 0.39618381028694494, 0.0402367074463156, 0.03221465988204845, 0.1473425944606143, 0.10264529410990016, 0.2413250812359395, 0.9787756889577836, 0.7880173443305878, 20.200792781768307, 49.01709910361998, 49.549945246788766, 30.485386617722053, 33.93864523979926, 39.59789191522906, 34.084608401021654, 42.60229018426711, 40.305934644514515, 43.85199654486872, 41.107808313062115, 37.74381891373665, 38.076843830846975, 36.3735035927065, 36.98182790510116, 41.122999652739495, 44.76752481152935, 47.361403895962624, 47.585092744519635, 51.70079654262912, 44.99675204676967, 41.63814413932062, 44.90962836050218, 44.60070248573057, 43.67999276807232, 44.60719400836576, 42.440868962195616, 44.01068387493011, 48.73067978889712, 50.03136911699849, 51.10878144541095, 47.035588295229026, 47.16790160825176, 44.28034682427683, 45.10301689947806, 45.39484124029837, 43.34231591993763, 45.77335388429704, 46.342360358084406, 44.95797941761632, 46.1444571710402, 47.39429689222767, 50.6763558233938, 52.69422700328212, 57.88175767467868, 54.03393214748752, 57.5393347586355, 57.702293549814534, 62.977477427451845, 55.46098455306023, 61.48678456583331, 26.1757412264424, 1.7332723352216906, 46.896959966228856, 55.209333127544774, 33.79292526552754, 11.148839073796427, 25.960407026352424, 35.183319199469786, 18.935065500197872, 19.535103805603523, 36.331663670078406, 18.43197837952645, 30.521342985091675, 55.29731581288, 38.93581544199298, 39.187647296536355, 59.18126636935819, 14.283510042775063, 0.08179960502011162, 0.2098820749069414, 0.05776530477188288, 0.060004698518182964, 0.1884070369264772, 0.05451703068589973, 0.23850117389473224, 0.10935614005692544, 0.006980120585555392, 0.14779026560004682, 0.0853933924208245, 0.033964217009563605, 0.050535330834287795, 0.08790518021992139, 0.20239356544709977, 0.20663594586714623, 0.03352085511470514, 0.016066798144170356, 0.11608285934574182, 0.09978475244415384, 0.08678292269788443, 0.2828837576652727, 34.426446883909165, 71.32884287065076, 45.55912971496583, 32.265001266233384, 33.082540881249216, 41.67720702386672, 30.640192762497936, 29.51771632317574, 51.3956126090019, 49.56614463560043, 45.177683138078265, 27.466312800684285, 54.96255720815351, 57.34771520860734, 50.10695319021902, 11.580444920447565, 10.083352711892898, 47.60176281775198, 62.446714062844556, 69.95020820248511, 63.380426437624045, 59.88877173393004, 59.348378950549716, 61.72488028003324, 65.11352569826188, 70.73163847769462, 68.36581383982013, 62.98629491559921, 61.9646155449652, 65.20933743446105, 60.66107073137837, 63.111116501592825, 60.63715211806759, 54.891311276343565, 47.32357655802081, 48.709416620193, 47.798779549137244, 48.010395342303866, 46.21186310245145, 46.90513026329779, 45.41240561393, 48.152753845337905, 45.586719666757894, 46.5029029692373, 47.551591780877885, 53.958795224466634, 53.65702375288933, 52.93461338166268, 50.51590342675486, 51.048369100016934, 50.756058385295255, 51.79905976018598, 49.51753470205492, 48.3299155389109, 48.17506428687803, 48.09400458489695, 45.13487831238778, 40.78156125160956, 42.7456332022144, 38.18336363761656, 27.10697074090281, 26.191271851139685, 42.723409052818056, 50.69254736746512, 46.681308054154925, 24.685377843918342, 15.169404802783845, 15.160099960142567, 8.565161093588799, 1.2225852546191986, 0.34087839085728894, 0.05200367623699769, 0.12841402507957914, 0.28157488112488105, 0.21209323448279213, 0.050656502961271235, 0.23288607116668458, 0.18955463663704936, 0.04221214559830485, 0.03177498478532559, 0.07303516080062236, 0.02793884930020619, 0.06861780589867024, 0.49016618980996074, 1.711205816076648, 14.601966296472858, 51.62062329630698, 55.57517259351669, 39.9193105389995, 36.12418989981375, 40.97460854438044, 34.75556512032786, 47.23111844831898, 45.421697708868216, 45.620055890852406, 46.26863548832555, 43.714011484576815, 41.15509640785956, 39.884009207448656, 40.8652057955342, 45.67367469110797, 46.93524622148084, 49.85337195857879, 50.83438027289606, 49.28605602633569, 46.03727448371149, 45.37517839862455, 45.32502697360131, 46.3008616816613, 47.48347982283562, 45.37558240275229, 45.40972271273213, 45.163837171369984, 48.979001122136275, 51.28480957400415, 52.851412065567516, 51.01803741147442, 47.65053356847456, 46.66832893125473, 47.54321752055999, 50.24696611589002, 47.8807923870702, 48.63305199530817, 49.37367000887471, 49.30880577333512, 48.95523155889204, 50.75615644454957, 53.53208057342037, 53.100725758460264, 58.59127521514893, 57.53165083546793, 62.8129457658337, 63.455214269699596, 66.14988650045088, 59.178995317028416, 68.01725633682744, 23.998174667358402, 2.602463681851664, 54.65778512339438, 58.89154834132041, 36.53471692915886, 13.57244904964201, 27.84752403536151, 35.07379093477803, 21.182462015459617, 19.96402871224188, 34.04833824403825, 26.34598582021652, 36.03706621354626, 69.80834391809279, 48.96040124277915, 53.75178037151214, 74.04679436837473, 32.83036189694559, 0.6783401521463549, 0.20883198286737167, 0.14552924902208392, 0.09182747378344498, 0.08279947233536551, 0.03891396854493407, 0.14421013754702386, 0.07599823567415438, 0.08347241162893274, 0.4606048486405804, 0.23001875728368762, 0.2061502308013939, 0.19004620461454316, 0.42497223002776024, 0.5649621424175079, 0.27177398123087426, 0.3247199417842973, 0.09596457840093682, 0.2058672685656817, 0.41495998179720295, 0.47050616733970185, 1.151947657908163, 37.51842775652486, 80.24155832106068, 50.267334984194854, 43.67389740482454, 40.859745856254335, 48.45188948415941, 30.944392181211906, 44.83180069154309, 66.56173536854406, 52.66436992153045, 53.18247579759168, 38.398893956215154, 65.53906363825645, 61.53968164997717, 48.88416997848019, 10.116027036020833, 14.88795905343948, 54.400752206002515, 66.45516457096224, 76.34778222730084, 67.8450878204838, 64.52439746549054, 63.57787070735809, 68.48992547681256, 72.38757687230265, 74.55121901727493, 73.86091324590868, 65.6533105142655, 65.34387080900132, 66.56648143645256, 62.69098751006588, 64.92303971321353, 65.4405572337489, 57.845824841530096, 49.8381688517909, 48.68862413590955, 50.64490233698199, 51.02548207006147, 47.86507152741956, 50.66950736507293, 49.02745023850472, 53.541631544789965, 48.20906731390184, 50.96165334024737, 48.233268337865034, 57.99781276333717, 54.589426056031265, 52.997853755950935, 52.28649662386987, 52.611872919144176, 54.827627674225845, 55.385561297016764, 56.07534539315009, 50.15615147929038, 51.65474007206579, 52.80800711724066, 45.84042249187347, 42.388489630914506, 46.93879596648678, 46.011100507551625, 35.38341106907014, 40.41766728124311, 58.508995656044256, 59.14678481317336, 58.809398220431426, 29.282558464234878, 15.393201516520593, 25.331843283868608, 11.154533374694086, 1.372663472448626, 0.9676977511375182, 0.49255886625859047, 0.4701553910009323, 0.4284480322272547, 0.30400330020535377, 0.33708257841006406, 0.38521634234536084, 0.6088981428934682, 0.30884837731719017, 0.1330498605966568, 0.44691139471627056, 0.2781178634012899, 0.2702353396002324, 1.5002796246159462, 2.1838992257272047, 29.99545708779366, 46.51639592263007, 54.789957231090916, 41.54684705118979, 39.785334141023704, 48.17064377569383, 43.93344848386703, 56.20486597861014, 54.59239136788153, 58.499425072823804, 51.802891915844334, 49.40172672271729, 45.96571476228776, 42.70147515881447, 41.67574790216262, 49.519029125090576, 51.12638896511447, 54.300414054624504, 57.48843416090935, 59.06782750160464, 51.794690239814024, 51.01491128244708, 48.61319303512574, 50.90711278300132, 50.90139788966025, 50.80876719567084, 48.01157205335556, 48.143375458255896, 53.766230383226954, 57.34764460594424, 59.010592276050204, 56.038588862265314, 51.34499442192816, 50.9375072294666, 52.79234117077243, 52.12143544227847, 48.34872722625733, 50.68270614070278, 50.86560626183787, 51.99334259956114, 51.478311861715014, 53.7682072577938, 56.618805470005164, 57.06038198163433, 62.5811807570919, 61.21787863392984, 66.15253802268737, 68.49737798013996, 68.46608531090521, 63.12562142649005, 70.77559255784558, 34.4217243502217, 2.892368022472628, 56.09437673322616, 64.96137303690757, 46.3612191138729, 19.733958167414514, 29.966690424949896, 45.04177693397769, 23.817504413666267, 26.86441529181696, 50.50948642915296, 30.798195638964255, 38.817085296876975, 60.727813782230506, 60.697611531903675, 53.012778374456595, 83.9910617951424, 36.69764826374669, 0.6392062972149541, 0.2876170472271981, 0.34599634848775407, 0.3100681731537465, 0.4319884922475584, 0.14329417218123713, 0.21400393437474005, 0.30850464898732405, 0.21177743771864524], [0.11858249699035961, 0.0795786931449848, 0.26728298995764027, 0.09320394992227517, 0.0926852394496241, 0.028497926860807404, 0.2018872579379428, 0.044973195425324866, 0.1355971182666479, 0.5781091917907039, 0.6089689907047057, 0.82119777678482, 0.7975506650344019, 40.247079480078916, 61.4776336762213, 36.11661188064083, 33.34725772180865, 50.11598248635569, 36.82106564121862, 24.371094011491348, 20.464650623260006, 32.725791508151644, 16.00254172278989, 32.82968724927595, 20.621057095066195, 40.58583890238116, 61.93958690089565, 33.753419153151974, 10.406030416488647, 1.5762943005369556, 29.79076231679609, 55.76214021252048, 60.693512655073604, 57.66525460827736, 54.038611535103094, 56.026606021388886, 62.542004123810806, 65.15647957401892, 70.5828159086166, 65.70083787364345, 63.97554020727835, 56.085010113254675, 60.22516204464821, 64.38984447909941, 63.67398838843069, 59.80623329839399, 54.794805280623905, 46.66359855282692, 45.40191327371905, 42.57438252049108, 42.36070748298399, 40.990462764616936, 45.10095765513759, 42.23581529432728, 42.61716381196053, 41.0866000575404, 40.60144993566698, 42.003046158821356, 47.23479370917044, 51.6249849719386, 47.62343391295403, 46.405969435168856, 43.8353656953381, 45.468354302067915, 47.16752898308539, 46.93594832574168, 45.73933124542237, 44.839790559584095, 43.240781445657056, 39.31398683978666, 36.29219678140456, 31.924921966368156, 29.512736874241984, 20.41576808498752, 23.075568483721828, 41.49825280712497, 51.447893881028705, 39.01070917806318, 23.246124905924646, 7.754426300525666, 11.69352783310798, 4.638529266080549, 0.7917621659655726, 0.6279437015614202, 0.1076260760366436, 0.23547759339694055, 0.473707618131753, 0.11842662108040626, 0.09785038809622489, 0.0728697777395287, 0.28494775175086917, 0.09926860070516987, 0.1486621809101874, 0.07244105961534285, 0.23387879854248417, 0.14288845201653821, 0.29659222691289844, 0.8650822348652348, 4.4252959855141185, 37.12051899202409, 42.58872662821124, 35.582243857845185, 39.8324574962739, 37.41513998277726, 28.366920371209424, 39.444782195552705, 38.55949540292063, 39.24258009079964, 40.05771921527001, 38.78689873603083, 40.4132624595396, 38.17432257436937, 36.969809762893185, 39.45368989821404, 41.47396549101799, 46.90061953759963, 46.251667314960116, 41.602125014028246, 41.082650230776885, 42.38893285874398, 42.48179497257356, 47.104892653803674, 45.10469175154164, 44.57577974565568, 43.216662791467485, 41.32878288145989, 45.48820541751, 49.05925281586186, 48.2454865209518, 47.382353275052964, 45.60932036369078, 39.563410359044234, 44.058525023921845, 47.890343358439786, 46.35662994077129, 48.088195554671756, 46.66930560142764, 47.16564624540268, 47.664893365675404, 50.39184278057468, 53.04598123796525, 52.97610421334544, 56.970496946765536, 55.676554095360544, 63.46594587449105, 58.227404779003514, 61.06314897537232, 52.69505854575865, 64.13146618873843, 7.4891098276261365, 4.279932946928086, 56.59339243365873, 49.60379938925467, 24.678970652241862, 8.365303585606238, 21.408606267744496, 28.463753884838475, 18.92396911498039, 25.590060757052516, 30.21823790765578, 22.33558197175303, 19.62849347822128, 30.232060340143022, 31.086738917135428, 47.67767637006698, 65.0698148050616, 45.42623196878741, 6.658917136730687, 0.4802156269790665, 0.07352191008507244, 0.2811655450251795, 0.309539572485993, 0.09303855920030225, 0.05751841761652501, 0.07383883299846804, 0.16394831630731785, 0.03845729204195161, 0.022099342182158463, 0.08896637287351394, 0.1445551529046028, 0.13538835930728144, 0.09660627662895188, 0.1884610308033805, 0.08549484544463697, 0.018764931085189025, 0.08680480982988112, 0.25849678884110144, 0.20639931662909447, 0.2666572799846049, 45.98119635735789, 64.62424532059701, 41.9386016168902, 27.299719933540594, 48.85150055731497, 46.87140180218605, 30.2562201792194, 21.00173096502981, 34.2773772055103, 19.59528865352754, 35.200456034752634, 23.418246353826216, 43.938469117687596, 62.85032987594605, 38.399658818398755, 13.500138194330278, 1.4485712637824397, 24.530440299741684, 56.37172752811063, 67.45703989459624, 63.23991929331134, 64.85788522228118, 62.575152074137044, 65.54336647833547, 67.7991254868046, 71.4542567345404, 65.9710499548143, 66.06553985226539, 59.364193947084495, 57.70561187498031, 62.45714756750292, 65.21182813952046, 63.07112009294572, 58.25026435236777, 50.04266946546493, 50.908328717754735, 45.69048989203669, 48.57983719918036, 46.255373954772956, 50.49560123874296, 45.784438502404, 46.07707085147981, 46.95416381282192, 45.28445789890905, 45.15369392210438, 50.28205171708138, 51.00259111773584, 52.85733092215754, 49.5528595678268, 48.23457840950259, 49.47834630166331, 50.781549869045136, 49.831543968569854, 48.30995851947416, 46.94352242254442, 50.35590994742609, 45.21556538920249, 45.79664491838025, 39.818348730764086, 35.306226668819306, 24.002118610566665, 32.28997303593543, 53.43034213589084, 61.95083625854985, 47.18993748387983, 46.934057743318625, 31.283543840531383, 26.1078606882403, 6.786826608642456, 1.4262381460397475, 1.2842824213927793, 0.09164201155785592, 0.18048179606276174, 0.14427482601135008, 0.19009089818404568, 0.0820312470257763, 0.14305958073706398, 0.05918841651310364, 0.00957581655858385, 0.16555221330734993, 0.03130067102310639, 0.1059992117206416, 0.0593845465130383, 0.9262872054692238, 2.1432914176294884, 5.201352613587534, 31.38025183831492, 47.000094767539736, 42.89316531150572, 44.83951991604221, 38.487245344346576, 30.394534718605783, 43.33844061820738, 41.70588347219652, 45.16346846857379, 47.33211163551577, 42.87258855758175, 43.05232724835796, 43.440245736029844, 39.24667896762971, 42.35031320202736, 44.27749133879139, 49.18712208347936, 46.82963640459123, 45.09132039162421, 43.505478674365634, 43.920696858436834, 41.54457207648985, 48.7954459651824, 46.392496093626946, 46.68492055708363, 43.83123151717648, 44.12079265040737, 45.6163453286694, 47.11966822224279, 49.378369008341146, 49.3728502335087, 47.16692493807885, 45.11084202797183, 48.8202824131135, 47.60021348153391, 49.89816934831681, 51.83871884499827, 49.43934617503997, 48.5979389375256, 53.15237945125949, 51.95342071594731, 53.49784220418623, 54.48549893594558, 58.36151845993535, 58.914317700170706, 66.39635255259853, 61.38236714947609, 64.9645148554156, 59.75093180133451, 65.81996025577669, 5.389637658672949, 6.816866080607138, 62.10120816384593, 54.638043834317116, 26.99311806309608, 13.806396857384714, 23.070549811086348, 29.58454566617166, 15.687318482706624, 26.40658251700863, 27.766648684778524, 31.45658116186819, 29.78053669775686, 45.54942577115951, 38.87455978701192, 57.83845470797632, 79.23421521340647, 69.49113399751725, 17.47642428644242, 0.20974071636315317, 0.3733455954540161, 0.20944191142916682, 0.05963894899093336, 0.33620366105629557, 0.07406967827269147, 0.0474047240230345, 0.1150124736370579, 0.13096118315814004, 0.14857158335226198, 0.5212096353211711, 0.2731563715684799, 0.3336648150317131, 0.22903310856030834, 0.41060697828089043, 0.3180761515132843, 0.20593021034954057, 0.5524605680857936, 0.6338102190244583, 0.9619489660666836, 1.410474508039413, 52.28441384530837, 73.74272438787645, 46.118997066251694, 45.69603220109017, 62.95810876354095, 50.24320848526494, 32.52748627816477, 26.068368304160337, 40.10284608410251, 21.59371272210152, 37.451645481971006, 35.185229393743704, 54.91749701961395, 70.48026161809122, 42.924030442391675, 12.50452591526893, 2.4138675437819574, 34.47860264009045, 63.432523358252745, 73.94233380594562, 65.88818596255395, 66.19089880297261, 67.49889942907518, 68.067870601531, 72.92782060561642, 79.23440348717475, 69.08532557948944, 68.21936822706654, 61.219408358297045, 61.18402857934276, 65.33206447478264, 67.94367267239478, 67.54301040403305, 61.45380135505431, 51.09359010573357, 51.68578955434984, 48.481009160318685, 49.53885670631163, 47.20920808853642, 53.71010126606111, 49.38562147078976, 49.33173202699231, 50.67888967452511, 46.834739408185406, 46.15911899074432, 54.41545717177853, 53.713117568723625, 55.31880255668394, 51.794776531957815, 50.164286475027765, 52.6917362982227, 54.20645367714667, 55.241563243250695, 53.95115052500079, 50.899071924148075, 54.075442591021144, 46.945275722011445, 47.27506860609978, 40.94313544611777, 42.57368826097058, 33.22070244819888, 45.98484808398832, 69.26084379996024, 69.27035162525793, 57.28154874617054, 47.79338629015031, 31.81735488676256, 34.50412550280171, 9.960278541811052, 1.4590959635473069, 2.5699776314919998, 0.22363031943959577, 0.4279756317696264, 0.9892433304940501, 0.40108180875259064, 0.22905981438534878, 0.3615286892219898, 0.4158128828050629, 0.1963305004662083, 0.2362677977690774, 0.14774868234751687, 0.3183436081294091, 0.2765482718185071, 1.3557736239125653, 3.396314387359927, 11.333750390237379, 42.39990765048612, 45.84039111291209, 46.68249260994696, 46.60028757587556, 47.38612267278856, 36.51076301451653, 53.560211812296224, 50.687028592632664, 53.02614188963368, 54.561149689459036, 48.345569718268614, 49.82605657269878, 47.499887097266416, 41.031965363410215, 44.85234214413551, 46.40897397072085, 55.770220295075454, 56.10097808222617, 51.64492237952448, 48.32781707086871, 48.28649490110336, 45.477269849469586, 55.60756352639968, 52.7440175702495, 52.538799162833925, 48.654707401029526, 46.89789741270004, 49.38203250208209, 52.78556723748484, 54.55147320224393, 53.964961190377515, 50.73779190740278, 46.65519683591781, 51.88291218972976, 52.76365687770229, 51.34336271593648, 54.770580722439675, 51.42034707530853, 51.45447561817785, 55.95892944643575, 57.01001482625162, 56.532176002379394, 58.36197737724551, 63.84334456536078, 61.476578558644945, 69.38884642816359, 66.49093658693376, 67.97727169529085, 60.874737924145116, 74.26226585142075, 10.860659595458738, 5.425757294700992, 67.51260419045725, 59.795580141005985, 38.178197876099624, 16.274194294406524, 28.99270707561124, 36.3120831981782, 27.666761605970322, 34.846705313651796, 43.217231535142474, 33.91806064113494, 32.98341081988427, 41.2587607291437, 45.03986673970377, 62.21343894158641, 82.0260484756962, 76.43973042888027, 15.978498574226135, 0.8220451313161081, 0.41485631477928936, 0.4012436065221987, 0.6396858682555537, 0.5201102072192777, 0.21478439410848005, 0.1971632227181427, 0.3579023354236157], [0.02116658416907153, 0.14446320703193066, 0.16037451614054943, 0.04884329158812762, 0.0458789641608394, 0.06947465225934021, 0.3075512066002815, 0.06257090154254148, 0.3226106259371004, 0.2217485929929441, 0.29617290102666427, 1.2743774561151382, 1.4260868896399777, 54.82110869499945, 52.64904129889704, 47.58652833200271, 47.55241940098424, 40.18034035159696, 36.48323582064721, 33.49004376319147, 14.08702185077052, 10.819136404222059, 25.889104220174975, 25.467186627849458, 24.53754371212375, 28.68956473565871, 59.48854092628726, 46.317618047037435, 19.505929216261833, 0.40088872395215497, 3.101505858282889, 37.60105640657487, 62.022870586764434, 60.53554311875374, 60.90859582347255, 60.440229523566465, 65.93818049277029, 66.86797834211781, 72.10139289979013, 67.66702790414134, 63.737707291879964, 56.119260249599336, 55.391621358932994, 59.04712915420533, 63.872217132199204, 63.36758067530971, 56.87232786609281, 49.36249517625379, 49.11204399601106, 45.02444005781605, 41.16321179174608, 42.598560010233236, 48.20500373840333, 42.51204429134246, 44.140620231628425, 39.72581609602898, 38.879823607783166, 40.71600667891964, 43.904454323553274, 43.36246905788299, 46.87614787009455, 44.686131708083614, 44.27458094012353, 46.70879210195234, 50.490506079889116, 44.360516148228804, 46.19904087435815, 45.199683712374785, 44.22337047515377, 41.84011482423352, 36.72971756227555, 30.241393619968047, 23.07633334590543, 17.249373966647735, 27.889703243009507, 59.888787423410726, 56.662465372393214, 51.84131937642252, 46.2978022329269, 19.592968571570612, 16.817150346694454, 5.298995606360897, 0.8686270769084654, 0.8420509352318702, 0.32654074891921014, 0.0964076376910652, 0.19942161927540458, 0.3336080632382824, 0.026729343939692746, 0.17865383366663612, 0.1815613824874163, 0.21144343870541743, 0.1590833668747256, 0.056964107038032626, 0.2119604867672728, 0.10910035095988743, 0.31406362811403893, 2.0883336182563537, 2.890750780220955, 14.398056980102295, 42.24653905437839, 36.23559697981804, 46.93536781495618, 34.62568759918213, 27.297058605378677, 35.18649631930936, 39.02921099816599, 37.5599774237602, 40.81056325666366, 39.202175755654615, 40.98924290749335, 37.21751920638546, 36.94118038300545, 38.03985980249221, 41.70302014197073, 45.12150303010018, 42.86529687143142, 39.121645573646795, 40.393811425855084, 40.30250257061374, 39.87391302662511, 46.089826399280184, 44.84936898754489, 42.7461862564087, 40.83651365772371, 40.84472710086454, 43.444038667986476, 45.189007020765736, 45.852158223429036, 44.41615104675294, 42.390109569795676, 43.525608278089955, 44.43128355087773, 45.223735686271425, 48.73761846173195, 48.84255363095192, 49.21300972661665, 50.575244965091834, 51.40897220180881, 51.57805773519701, 49.89286238147367, 51.03495067165744, 53.96167424417312, 56.07914224747689, 59.98861958903652, 59.7549561531313, 57.02875198856477, 60.53062054418749, 41.48502265253375, 0.7799003669811834, 16.25985803142671, 54.065758259065696, 48.17963384812879, 21.800213744563443, 9.29208807406887, 25.60403027842122, 22.312436065366192, 28.94585044153275, 24.064578433190626, 27.614286176619995, 28.121954625652684, 22.85427228096993, 42.88321818074873, 48.158245163579146, 27.86818512024418, 62.71544741046045, 73.73560920838388, 47.72940066552932, 0.41157010401929583, 0.052544315976481286, 0.44839092500267497, 0.7151249976408097, 0.16105382162476742, 0.08740138547915606, 0.04438067238116938, 0.0396807651005445, 0.025125075387017384, 0.09769492587375064, 0.05290467224474396, 0.03806350369667334, 0.004754995226845025, 0.11636116376687443, 0.12902673454053942, 0.06848803060429712, 0.024438294799878232, 0.09011230251241116, 0.05725759532182448, 0.7549122336410707, 2.5554467208923834, 65.58761081387921, 61.42465029993365, 55.29003197147001, 51.17349270851382, 43.34177071048368, 45.07045730467766, 33.15252380986368, 17.695653400113507, 18.605198091076268, 28.20752505333193, 36.239295774890536, 36.255059780613074, 33.21094359121015, 62.354612888828406, 52.25986373039984, 24.858258270448257, 2.0467870153727072, 2.1129202602371095, 33.444756077181914, 64.15115648700346, 65.5495559784674, 66.1926560248098, 64.79082053707492, 66.56385344843711, 70.3179931640625, 68.81540375371134, 68.06154774081323, 63.1446566889363, 58.38187948349984, 58.13292272629277, 61.65030817831717, 63.345984105140936, 61.75943243888117, 59.508956863034165, 52.71657666852398, 51.26640581315564, 46.43033912104946, 49.63192670576034, 47.804270867378484, 49.45810294920399, 47.87247303993472, 48.255013958100356, 42.28774747540874, 43.31554574351157, 47.37992140554613, 45.914221886665594, 48.06129594003001, 50.28091422973141, 49.08438736392606, 48.20922420870874, 51.913600813957956, 52.524160877350845, 49.00845812213037, 48.36675836193947, 46.92779764052361, 47.2838351034349, 47.211467373755674, 40.48177842170962, 39.916474665364916, 30.07268071174622, 23.34961860410629, 39.20496063847696, 62.038524766122144, 63.36483501618909, 61.89086321861514, 68.670056404606, 41.77970247883951, 22.265377429223832, 4.162709482254521, 1.9418940116320889, 0.8766407856056768, 0.02800685684046438, 0.23600472317587948, 0.19100553055684413, 0.13370940101242837, 0.14792414712569407, 0.07915459453098236, 0.1296585578952105, 0.11056962332898572, 0.06293304279566773, 0.04605206938820981, 0.05480352075650327, 0.04131437099028019, 0.410508367443277, 2.1097629973965306, 4.879016645493047, 10.252775569115917, 41.29991423699164, 45.038627270729314, 49.4683599472046, 37.53429766624205, 30.07843678997409, 39.79048029068978, 42.7813934510754, 44.93935600403817, 44.85260102056688, 44.37209106260731, 43.913028624749955, 38.72591764696183, 40.839243627363636, 39.62654482933783, 46.160268245204804, 44.24611629978303, 45.44620467770485, 41.34651591700893, 40.89542765771189, 42.49522516804357, 44.617384326073434, 46.84368241217829, 47.69846493198026, 46.08393107691119, 44.50184306790752, 43.08716574022847, 46.05743938876737, 47.198358812639796, 47.66408143504974, 46.84561614067324, 45.00400843158845, 48.09248270527009, 46.656334323267785, 48.36880191679924, 52.919461265687026, 51.405053754006666, 51.47408746903943, 54.93351597939768, 53.50482010072278, 54.350977328515825, 53.529205476084066, 54.336303741701194, 57.97046992086596, 58.385268411328724, 61.64587197765228, 63.76599150319254, 61.67439545354536, 66.05173310925885, 37.14469648176624, 1.111643833498801, 22.09378746248061, 59.674080802548325, 52.86477165837442, 23.540885140818936, 15.451188856555572, 26.513180771181663, 26.34083967055044, 23.787029558612456, 24.560267963717063, 26.99776803293536, 32.13067773849734, 29.192998986090387, 46.929550939990634, 62.109496132020034, 29.820138908201653, 74.96347581186603, 72.89332728232108, 73.82173661262759, 2.315951946281618, 0.1646071059569236, 0.2365502237432426, 0.5181548444013442, 0.03220956156691236, 0.05594054079284111, 0.11234155405432948, 0.10485387963032532, 0.168220313686517, 0.3768460656846724, 0.3767894977523435, 0.16255195252597332, 0.16335341839059708, 0.4011344543147472, 0.40210340232137715, 0.23884127096783733, 0.2675128163349244, 0.33782730780301556, 0.2638739293381091, 2.0595120422301756, 4.965463232609534, 76.7084441646453, 65.54685346541866, 57.53917394145843, 65.07780859547277, 57.59560115875737, 49.67391960082516, 45.584448614428126, 19.696166130804247, 16.96918925931377, 28.99471729032455, 32.62118385684106, 36.74524622578775, 40.894247024290024, 74.10013860271823, 57.37181817331622, 23.61969732469128, 1.5576173220911336, 5.186543705001955, 46.4352342390245, 71.82940006256104, 71.5725475741971, 69.11362155791252, 68.71573632763278, 72.66622989408432, 77.82460166561988, 74.0169059076617, 72.20683405476233, 68.50586598919284, 58.949795538379306, 57.43919272576609, 62.52183137401458, 68.45791893620645, 66.11810745731478, 61.628778288441325, 55.71875487604449, 55.74421890320317, 49.6155115865892, 50.41654194554975, 51.637195310285016, 55.25390694218298, 51.24653900823286, 51.31387433698101, 44.68339389370334, 43.8633204275562, 47.0214795297192, 49.20134067535401, 49.52938025997531, 52.611841540182795, 49.5016412581167, 50.885257336401175, 54.609571349236276, 59.972027963207616, 53.945867092378684, 54.507864290668124, 51.89533433606548, 50.74520910939863, 50.41778925926455, 47.30137986521567, 39.94303695617184, 36.22685009433378, 28.510636014323083, 55.0233696353051, 79.57113112172773, 74.72650974027573, 66.73746539700416, 61.875824851374475, 52.12991952896119, 26.472154740364324, 5.005402766889142, 4.165137919687456, 1.3239787687217037, 0.24669284481675396, 0.5452251434326172, 0.6721195794882313, 0.6881652604187689, 0.22810286331561305, 0.20125338146763466, 0.2506734683148323, 0.3675108553180772, 0.2261824800723022, 0.17604485995346503, 0.40933009357221667, 0.11586959578938062, 0.6347329566074956, 4.954194753400741, 5.310515117260718, 25.22086766458327, 49.07526393090525, 44.606899830602835, 54.916108500572946, 40.37419173025316, 37.0803499990894, 46.65715802100397, 52.0454316754495, 53.849164978150405, 54.01675608850295, 47.06537477431759, 49.86842209292997, 41.189068055921986, 43.205789981349824, 42.5391008007911, 49.66794190868255, 51.481543894737, 53.50291775118921, 45.32625467546525, 46.692416206482925, 47.05401559029856, 47.08756362238238, 52.70413098796722, 53.81651124646587, 49.4273554894232, 48.68575296094341, 47.681116288708104, 49.5703572611655, 52.308622714011904, 52.123902613116854, 50.29624285236482, 47.500495064643125, 49.30214558878253, 50.00711710222306, 51.65294362652687, 55.50722929739184, 54.80184593508321, 52.104682999272505, 56.57819717161117, 55.44618545040008, 59.21213542261432, 55.099063534890455, 55.789545812914454, 60.964732785378736, 60.20875477021741, 65.62775235022268, 65.88935482886531, 64.12018545212285, 68.82690414305657, 48.79320236944383, 1.6043670715824252, 18.90249413828696, 68.04505025186847, 58.05780933749292, 34.25194063494283, 16.875099443620254, 33.669766764486994, 30.91289947109838, 42.56314885231757, 32.94789768034412, 40.00145281514814, 38.568724739936094, 32.776627386769945, 53.07910565407046, 66.91010459776848, 39.01755371401387, 77.11878684259231, 87.35691039792954, 75.09748751117338, 1.6051095027116038, 0.32994346633072824, 0.6393823135764368, 0.9757856784328338, 0.19275015790856656, 0.09697743090650729, 0.25245135920422695, 0.4783378229025872], [0.19033243038481285, 0.2865083341396624, 0.2768900696068041, 0.10714291204367915, 0.08101483987223718, 0.413592851931049, 0.3983094897722045, 0.05399813635214683, 0.35567384693891774, 0.030768741703321858, 0.7776124607170782, 1.2511046855680406, 10.81479924340402, 59.16887952435402, 50.33025764649915, 31.137443396352957, 21.623512929485692, 40.73346122618645, 25.247771201595185, 32.93404779126568, 22.056775977534635, 11.702310019923795, 24.310573800917595, 22.402550558890066, 20.921973489945938, 29.472179566660238, 38.575549664035925, 59.60711417659637, 50.103030820046705, 15.886680791454932, 0.205060945703618, 8.307404498900137, 48.82347522243377, 64.05640379075082, 64.66170395574262, 65.01274431905439, 65.81911302381947, 73.65598509388586, 70.0312679044662, 68.60579229170277, 60.961614501091745, 53.94432167853079, 54.599196680130504, 64.0649349458756, 62.16663329832016, 61.572598180463245, 56.26526263452346, 49.51556174985824, 47.114459314653956, 43.789195476039765, 43.542007707780414, 44.59196344498665, 44.50696568335257, 46.86719702136132, 44.565091286936116, 41.18166262103666, 39.547614974360314, 44.23050918886739, 40.30669166195778, 40.33881587366904, 41.29691754617999, 44.73973874122866, 43.00113247286889, 49.1333620778976, 47.79027585060366, 47.67985328551262, 42.70904925561721, 48.02337446520406, 46.46174553901919, 45.855476548594815, 30.510493709195046, 33.35194887653474, 21.224564736889256, 24.389731153365105, 36.82633730673021, 64.76208525319254, 59.115492143938624, 71.31539698570006, 51.47798238262054, 27.174814016588275, 14.054363216123274, 3.636001603257272, 2.266076558059262, 1.4781958225273317, 0.9402570332730971, 0.41957244397171084, 0.4836689368371041, 0.34694148648169737, 0.07917835857839355, 0.16079615561231492, 0.13816308380374986, 0.24968867760992822, 0.10594411467712735, 0.05002318190470819, 0.08933239436197667, 0.059351206366573615, 0.10756097388483825, 1.4220841108791291, 1.7831512780920153, 7.322915081054934, 25.933948678355065, 44.15860429886849, 43.448110088225334, 40.39051271254017, 23.162801996354137, 33.316039577607185, 37.35283313259002, 37.69153371933968, 39.500942691679924, 42.67614841461182, 43.182377353791274, 37.9579528685539, 38.12048412138416, 38.34701276594593, 45.14151888508951, 41.486368025502856, 40.45621633529663, 38.92818250963765, 37.717146796564904, 39.026963480057255, 43.57535962135562, 43.20347578294816, 45.26068441329464, 40.9099208154986, 39.11527172211678, 40.92041707807972, 40.863330902591834, 41.41876989795316, 44.820445429894235, 42.88282202136132, 41.075252640631895, 44.43929695313977, 44.64434277626776, 48.34008624476772, 50.78837479314497, 55.35326057864774, 55.5612442570348, 55.00986883717199, 53.47244877969065, 50.62074838146087, 52.571547031402595, 52.41642121345767, 51.96989467067104, 57.51938166156892, 56.27065981588056, 61.8969036686805, 56.12896811577582, 61.773525514910304, 11.905120092053568, 1.1883204093863888, 33.32027181502312, 54.92848750083677, 45.958964363221206, 13.285254086217574, 13.182434055113024, 29.014599784728023, 16.418854248139166, 24.011816670817716, 21.07450858239205, 26.751605964476063, 26.342908720816336, 30.999752513823974, 28.652647387596872, 42.73892987158991, 53.99442603511196, 45.78912573475992, 67.69913642637192, 72.15732589844735, 25.3727202646194, 1.3036907993016706, 0.5645880463623232, 0.4310165718197823, 0.12058529597256454, 0.2015332333863743, 0.23708731266519717, 0.08577477397216905, 0.04334993172256697, 0.06813697081299559, 0.07847846831165015, 0.10567923977730737, 0.011641361972226972, 0.3246299724184698, 0.0552653108963803, 0.07719659637058936, 0.11864762978568194, 0.15087464283550941, 0.07966821051893697, 0.1998345866318672, 18.702745476076682, 73.27073774030133, 57.20170497894288, 41.08190498044414, 30.731101535981704, 48.72372934895177, 34.60307513513873, 31.151752202741562, 25.268720580685525, 19.26483485006517, 31.0087739652203, 31.803750145819883, 34.39676630881525, 36.23092935931298, 42.49056539227886, 65.1616688697569, 61.86500695443923, 23.222284740017308, 0.3556762677767585, 6.579927465608043, 46.59960508346558, 65.55125828712218, 66.44823766523793, 67.41551768395209, 67.54792121148878, 70.98631797298309, 68.33141465340891, 70.17955703120079, 61.53935609325286, 58.56670156601937, 59.42494361631332, 65.51048524918096, 63.44868744573286, 65.50659033559984, 58.892976084063136, 51.56244277954102, 46.95383825609761, 47.85129224100421, 48.128490063451956, 49.546399424152995, 46.64361407679897, 49.17565699546568, 46.493081354325824, 46.2060893735578, 46.79224444973854, 46.85242929766255, 44.97829337273875, 46.856547786343484, 46.51643122396162, 49.67753210375386, 48.46326043528896, 52.19530936210386, 48.59082768040319, 49.755591192553126, 47.9338385212806, 51.395565540559836, 49.97039587266984, 46.23564835517637, 39.451826772382184, 40.814834717781316, 30.413338561211866, 28.23354997942525, 42.150507665449574, 62.74987797583304, 62.98518880721062, 73.99376392364502, 59.8733058283406, 30.01184867274377, 12.794948989345183, 4.013109058141708, 2.614565174425802, 0.6925653017336323, 0.7860619815126543, 0.34207275257475916, 0.15074181851119767, 0.26891546203724803, 0.050502366070906, 0.09439425903462595, 0.09298944530347664, 0.03002415595185613, 0.05008336194160004, 0.03498548499098228, 0.06878266801997539, 0.07928942600565572, 0.18403869632992054, 1.761708293230303, 4.785667177169554, 5.344496571248578, 24.457913714070475, 49.75150408283357, 44.420489188163515, 42.888532992332216, 27.20665385646205, 40.28010975929999, 43.23368980038551, 42.92822737847605, 46.544891941931944, 45.95610103299541, 46.035109335376376, 42.432651596684615, 42.135080983561856, 43.62969229298253, 45.41582199835008, 43.294851318482436, 44.129821946544034, 45.623083960625436, 43.00334076727591, 45.72175902705039, 48.08300625893378, 47.575267207237985, 49.355619261341715, 45.19276857376099, 43.263852827010616, 42.899907865831935, 43.889725823556226, 45.031516013606904, 46.18348867662492, 45.647598774202415, 46.95090040083855, 48.85847453148135, 48.193691622826364, 49.63004004570746, 50.69333184149958, 57.52706558473649, 58.28971555156093, 57.14530914060531, 56.721100884099165, 57.5257319788779, 55.97357949902935, 57.750060173773, 56.03690224309122, 63.62726511493806, 61.7388988310291, 65.58732840322679, 60.692516373049834, 60.18313777062201, 8.312910526029526, 2.1141013839552483, 40.37628627592518, 62.876425404702466, 49.964253440979995, 16.469022343235633, 13.219039574746164, 28.36567305749463, 22.671436878942675, 23.148055845691314, 19.21875092291063, 32.25014921157591, 30.68510586215604, 36.48859770067277, 30.6871376499053, 60.3445315361023, 54.514296977750725, 63.17825571183236, 73.7281096366144, 77.90393552472516, 48.34013331320978, 0.7763671081873679, 0.22816716873597717, 0.16021585933143095, 0.06456964408918735, 0.13932275706000868, 0.0971947623897464, 0.08067599152244868, 0.2675708551560679, 0.36107556353653636, 0.373046453441343, 0.3954330441211501, 0.21435313257238559, 0.7587548080951937, 0.39724999017292456, 0.24039106683865671, 0.2992276613029742, 0.447554019910674, 0.8714313877205696, 1.4020778166670955, 20.34436525837068, 81.69403553009033, 63.31498561366912, 44.555540315566525, 34.13795655773532, 61.20864929691438, 34.66836298665693, 42.00283827320222, 29.7178219210717, 13.868336965960841, 28.678552681399932, 32.36997565915508, 30.010109101572347, 44.06672669995216, 51.49744910578574, 70.38724653182491, 60.745644877033854, 20.076079060954434, 0.32191394557875974, 12.186826679014391, 57.10936454034621, 72.53975699024816, 71.39861399127592, 73.9386938464257, 72.71071741657873, 79.29283111326157, 74.60985845135104, 73.78682751809397, 66.25680246660787, 59.777807881755216, 59.99392655587966, 64.92696992812618, 67.58061024450487, 69.36804217676963, 62.76024872256864, 56.73259342870405, 49.90414311808925, 49.89488240211241, 51.03057722891531, 50.54588994672222, 51.450945485022764, 54.06146718609718, 50.31314434543733, 50.54947499305972, 48.350704100824174, 49.863883910640595, 46.18104111763739, 48.638602149102, 48.15573092429869, 50.6357906710717, 47.80310200106713, 57.25137395243491, 55.7245913628609, 55.59048552666941, 52.26970887953236, 56.426366144610995, 52.23357600550498, 51.454083381160615, 41.185483009584495, 45.788870780698716, 33.17313978748937, 37.4210000038147, 58.816070172094534, 79.4644348083004, 71.76708144526329, 78.24660162771903, 57.76122323928341, 42.50138721158428, 13.813459084879968, 4.775843110776717, 4.806150774801932, 2.8400793960017543, 2.759504597033224, 0.9440060837134239, 0.9294564192814212, 0.844428749574769, 0.41939379226776863, 0.22148197907353603, 0.2380599072503467, 0.3212353755389491, 0.2588627950078057, 0.1637981324306419, 0.2900942078521175, 0.27589246991180605, 0.22160784731949532, 3.224236820974658, 7.602133414437694, 10.606587086954425, 41.97411867880052, 51.22405990477532, 47.43390498622772, 45.200346592933904, 32.91288660418603, 50.17462976517216, 51.90434009798112, 53.76228055646343, 54.92192929790866, 52.436750858060776, 50.30176947193761, 45.365576436442716, 42.728488522191206, 47.8101622673773, 50.938883981397076, 48.14812544853457, 50.190601656513834, 51.425540293416674, 46.3261805811236, 47.49049302070372, 50.88855212734592, 51.36049955121933, 53.46681625612321, 48.56748957787791, 45.09532513157014, 45.36950665135538, 47.907566485866425, 47.59532620829921, 50.90440634758242, 48.37301454236431, 47.888456698386904, 50.94354767953196, 49.01532226993192, 53.79685232716223, 52.59767786149056, 59.2372307469768, 60.89821330962643, 59.89193316428893, 60.448627318105395, 59.06165761332358, 59.622740899362874, 61.12309455871583, 59.1951790163594, 65.6446812998864, 64.19605585836595, 67.90709264816778, 62.9585833703318, 68.252088639044, 14.506873334607771, 1.3193104127722404, 40.4163650543459, 67.02757958442935, 58.23138990709859, 23.949862833945986, 20.01612759405567, 37.47706244068761, 24.01473491422592, 37.26161449186264, 30.99408272773989, 39.5581583053835, 37.53139903468471, 42.431263077643614, 37.2796142485834, 56.490422371895086, 67.90903814377324, 62.15437981390185, 83.10862264325543, 86.62431363136538, 46.552536641397786, 1.338733131847074, 0.5273453867243183, 0.4516388007229375, 0.14951112890435805, 0.3137495933521179, 0.3902826656497294, 0.16649776498877233], [0.24575048006109654, 0.5324139470054258, 0.022375317696001262, 0.061350669035868305, 0.2571196691884149, 0.2602422435677821, 0.15624796821465417, 0.19727994387428607, 0.15969084395516306, 0.44796268185300214, 0.5254400954131158, 0.674832940341965, 24.674748220751365, 66.77246078368157, 45.969735191714385, 33.05911256420997, 36.563785614505896, 38.64779972260998, 25.610121719298828, 29.969353714296897, 25.298469797257457, 17.482272540369344, 10.157445303855404, 22.500547055275213, 9.236467884432885, 10.048985885035608, 25.887339153597434, 47.53710646783152, 58.24919354531073, 49.35024953657582, 8.39494493699843, 1.5574413057296508, 28.175475366653938, 58.76345942097326, 62.16520555557744, 59.75794499920261, 67.84988095683437, 72.56589566507648, 67.18838107201361, 68.56638816095167, 55.63063098538307, 55.83801061876359, 58.97946042399253, 61.307053719797445, 58.66632584602603, 63.70062912664106, 56.739288914588194, 46.33518634303924, 47.37082542911653, 46.447440655000754, 46.175114416307025, 45.09789428403301, 44.051821693297356, 45.27701716269217, 42.25919262055428, 43.017469144636586, 42.362782416805146, 43.60288681522493, 38.20016314906459, 41.61170736435921, 39.47395678489439, 44.36722340122346, 47.04677881733064, 46.81490790459418, 44.20893223054948, 44.91476274305775, 44.21533746104087, 47.20201053927022, 46.422733645285334, 41.68792293917748, 33.30641408120432, 36.355986287516934, 23.383433357361827, 28.720088620339673, 41.74659767458516, 60.82687716330252, 63.47096258594144, 73.47211222494803, 36.216993178090746, 23.17021135360964, 6.585130979937892, 1.384929827144069, 1.969705087042624, 1.699958297033464, 2.3236292504495193, 0.4130398896673034, 0.3648878928394087, 0.2157888732730381, 0.15352757467377573, 0.3966748726464087, 0.04024466709984888, 0.08694579299058645, 0.23999237936110268, 0.05195720151307122, 0.11420763698556732, 0.2494148318205149, 0.09686168268202774, 0.7831519505669995, 2.1868932199093605, 6.27311525806304, 14.561201103271978, 42.04132849170316, 46.15401598715013, 40.888771395529474, 23.266899739542318, 30.87556831298336, 35.07100997432586, 35.54793488594794, 39.59681718580185, 42.60301190037882, 38.19061610006517, 40.69171936281266, 38.942958078076764, 43.30314320902671, 44.254761203642815, 42.20692703800817, 38.44874335873512, 37.87033888601488, 39.548007211377545, 42.12576535440261, 42.840770290743926, 41.3909093026192, 42.98986350336383, 39.69400959630167, 39.01752233505249, 38.70535266014838, 40.15672376078945, 40.33628202253773, 43.42085746026809, 42.37354147818781, 43.964623481996604, 43.75645937458162, 46.75500938969274, 50.98888635635377, 55.72711736925187, 58.46744598880891, 57.82857425751225, 59.459982149062625, 52.57253939105619, 50.79120674440938, 52.57371610210788, 50.72059231419718, 52.85243972655266, 55.371134819522986, 57.46160122656054, 59.43945246358072, 59.30859434989191, 37.86927200132801, 1.8494097936537959, 8.554634432638846, 55.727521373379616, 56.05403123363372, 44.95754011215703, 9.580433272546339, 23.497546872785016, 19.95224198987407, 5.656425510683368, 11.783839425733014, 24.309865813101492, 24.179294032435266, 31.540308075566447, 29.355198798641084, 46.30619218272548, 34.06756962499311, 42.13464560047273, 23.851813385563513, 65.4005333685106, 69.76730808135002, 61.23895745123587, 3.299811088269757, 0.967021816440167, 0.08216505960351037, 0.08704236603432125, 0.1731702375916704, 0.06494291276941377, 0.11160987879960768, 0.05634140396010011, 0.2380729001015425, 0.0634078142954217, 0.033004971506494674, 0.21925522194754696, 0.1982031257883195, 0.073674384564642, 0.06706561983352707, 0.14198048460868098, 0.05480927790725424, 0.17034534965792011, 0.2220370557399527, 39.518146207255704, 78.23322634543143, 57.44351125532582, 47.9705205271321, 42.25550167022213, 44.07684641499674, 32.362570224269746, 28.959702291796287, 22.51741716938634, 22.07373042260447, 17.417335740981564, 22.3504065698193, 16.929624311385616, 17.87234440926583, 28.93429906137528, 55.183496475219734, 62.50909936043524, 56.50954392648513, 13.911529125705844, 1.6764238308514319, 25.646431099983957, 54.528562638067434, 61.537120342254646, 61.556610599640884, 67.2369243252662, 69.35271355413622, 67.48095066316667, 67.85694122314453, 59.21936435084189, 58.78084728794714, 59.885680906234256, 63.005894999350275, 63.78812936044509, 65.28314075162335, 57.8887826396573, 50.49024720345774, 48.212122840266076, 49.69409627299155, 49.40752398583197, 49.04750923956595, 46.76135578463155, 46.47806259893602, 46.42587938616353, 46.68545399942706, 48.5645438778785, 46.108618474775746, 45.73501663823282, 44.456006250073834, 43.79170579295005, 46.85728126956571, 48.33641490628643, 48.660375225928526, 49.2086951194271, 49.60235595703126, 47.04836345488026, 49.56628976329681, 49.573499079673525, 45.66848539537, 40.82566438182708, 42.10366672085178, 29.93004764280012, 31.097733320728427, 43.99381768318915, 55.23857047480922, 61.15497950584658, 71.00884806725287, 44.10382055467175, 22.248907396870276, 6.282937853567063, 2.7718132397820874, 1.8925653037524994, 2.2856624232184504, 2.379796365576406, 0.9765721749394172, 0.3298185020685196, 0.1671703901862906, 0.050153045299192595, 0.07208312801536053, 0.1007809961635259, 0.028742374026126442, 0.06745335991464316, 0.04265579477613492, 0.18263002917651208, 0.14657103666855445, 0.02439119379907366, 0.7104950073745944, 4.809538722038269, 6.627041505229089, 12.776684472637793, 38.31251944265058, 47.62948613012991, 44.8815167334772, 28.17350241445726, 34.95291525317777, 41.87832655445222, 40.109267004074596, 46.57592181236514, 47.255131198513894, 47.39902334828531, 45.86042265738211, 45.4251140932883, 45.7652267333, 44.173085689544685, 44.640079159890455, 43.581658947852354, 42.204718743601155, 44.59830199518512, 47.583359056903475, 47.357085366402906, 46.65167846987325, 48.813861493141424, 44.76779937744141, 43.029624569800596, 43.9743862613555, 44.10914321099558, 44.7301838474889, 44.24581819964994, 45.12389175353512, 45.91212734099358, 47.73158934808547, 48.445817655132664, 53.83479341383904, 58.66382729622626, 60.37093693210233, 60.22859411854898, 59.985109067732296, 56.06393521831882, 57.79745025019492, 58.614142633253536, 56.16362225624823, 57.670165415733095, 60.01014947891236, 61.1583213652334, 64.61213696387507, 61.0955830543272, 34.47170711332752, 1.7755211649402496, 11.920090798408756, 58.7233845649227, 58.91705943692116, 48.40285985700546, 10.313032000295578, 18.0886003663463, 21.78658154702956, 10.293926135186227, 14.48592689729506, 20.867150522047474, 29.019769468615134, 31.901156325494092, 34.53839917336741, 42.32512374078074, 44.98401218844999, 47.2172018789476, 24.20119458629239, 88.70079286636846, 71.60206733211395, 81.02869172250071, 9.446525516048554, 0.5923809808108115, 0.08800923028179715, 0.033696852323989716, 0.15374624681088234, 0.11864459607750179, 0.016147984311945977, 0.33324757290463297, 0.6171050896087001, 0.15647217150657408, 0.22548268939698898, 0.47936453393870787, 0.30158145112856743, 0.17391398639207886, 0.3004789586749769, 0.18509378326275658, 0.6837692027611117, 0.44203169043025664, 0.8278057447844936, 44.73465534948534, 86.09433081842239, 60.45249869746547, 48.80001944880332, 53.337625149757635, 56.851762879279356, 36.259244949586936, 38.86622867276592, 32.16773825307047, 23.217156241017005, 15.381545212961013, 32.51897081252068, 13.452560824732627, 21.75859151347991, 40.01852297013806, 62.01667716426235, 68.75968256304341, 58.26714231121925, 10.487926563908978, 2.3032655302555334, 35.29074899611935, 66.88942586222004, 68.13848110937303, 68.20591449737549, 76.60575651353406, 77.41830687369071, 74.11141933933382, 73.75009844380041, 60.297714125725534, 58.105564194340865, 57.865421002910985, 66.6504672265822, 66.06353944347751, 69.84710478013562, 60.6833968623992, 52.94954976727886, 51.532632766231416, 52.89284406169769, 52.50871066124209, 51.356628171859256, 51.32895977266374, 50.5039401977293, 47.58690095716908, 49.205686661504934, 47.47017906558129, 50.1305893928774, 47.00757080508817, 46.41994876246299, 43.81602841038858, 49.317038828326815, 51.20857046496484, 51.999869423527876, 53.30713264403805, 55.72492868669572, 51.09794393662484, 57.19553116829165, 55.3168962847802, 50.3385809160048, 42.006133064146965, 46.942545752371515, 36.30855698739329, 42.714242473725356, 62.042639332432906, 76.51842886401762, 74.92990816793134, 75.35217485120221, 46.980486839048325, 28.048361155294604, 6.703200205679863, 3.6090127546941084, 3.571770830500511, 3.5920335496625597, 3.2978643669236094, 1.352466820709167, 0.5935814712316759, 0.8141829241668025, 0.5383928648887143, 0.3108599709887659, 0.2426380640076053, 0.14804238513592752, 0.3461653474838503, 0.28449753719952803, 0.4833051982906557, 0.3602013652843814, 0.2920294378794009, 1.0730520010955873, 5.544101086355025, 10.337180072261441, 34.801641202742054, 51.79769477536602, 47.69791187778596, 49.32085137213431, 32.39794019729861, 41.70539709829515, 47.858074019032145, 50.08112830500449, 56.419321567781516, 53.319978406352384, 49.133020831692605, 48.31128820296257, 47.060675774851155, 49.24014076109856, 51.26395825416812, 53.38024170167985, 46.86545156663465, 44.929644215491514, 46.58453141489337, 49.00937203438052, 49.17853993754233, 48.680257720331994, 50.618316511954035, 47.961012701834406, 47.00133815888436, 44.82092788142543, 48.32627165702082, 45.795931047008885, 48.77413965040638, 47.054576489233206, 48.1540011590527, 49.11156546685004, 51.30813198704874, 57.64538780335457, 63.30263799236667, 63.72632065126973, 62.64189120261901, 63.968578000222486, 59.120630448864354, 57.70071675700527, 60.439841208919404, 56.676656507676654, 62.32975682904644, 61.68811590440812, 65.82552217668103, 66.63973562179073, 64.13227027462375, 42.880621571694654, 3.853236927140144, 9.543603197220834, 64.60565328598022, 65.03955371918218, 59.41516906984391, 17.047383669883974, 32.05561730169481, 25.53729311112435, 10.742389348245437, 21.672573935601022, 36.34349353851811, 35.986244063223566, 43.814918379629816, 37.47290472830496, 62.13758030245381, 38.95330921296151, 61.59297097113825, 30.02209390363386, 82.07863961496662, 80.54889955828267, 89.29393368382608, 8.952472594476516, 1.36679683241152, 0.29519574055748604, 0.24598450460020574, 0.28983769097155143, 0.22358075355089482, 0.1585331318839904], [0.1336042784274586, 0.3168332811084486, 0.04621162635063933, 0.06280216816512328, 0.07354769660460372, 0.2583318654327624, 0.07831641007214785, 0.15232636413026243, 0.014890947026170552, 0.42036788838524974, 0.497368733969427, 0.7960307465926294, 47.26376433526316, 64.98264012798187, 40.06822332259148, 26.496359686697684, 38.679935701431766, 29.15354386452706, 27.529992480431837, 32.176526323441536, 27.75955900069206, 35.27037228307417, 30.294155382340957, 25.01725939012343, 20.556657660392023, 7.219679769008391, 13.612724927163894, 45.51162981217908, 65.59636554410382, 53.28742665629233, 39.86738620265838, 3.960983700329258, 7.25507180536947, 40.09298524548931, 49.37095572871547, 54.855401977416015, 63.54072978419643, 75.51252134384649, 69.54971067367062, 65.28300346866732, 55.66319450255364, 62.78521068634526, 57.86622116642614, 58.51579704592305, 59.21315131648895, 64.55165401581796, 53.15789430372177, 47.12439075593026, 46.91258668899537, 45.637063287919574, 45.97057850130143, 47.03398012345838, 47.38502833151048, 44.99434763385404, 42.11694786625524, 43.56577727102464, 43.26785364458638, 43.52682421284337, 40.39950670734529, 42.1308526685161, 40.576064355911754, 43.518669605255134, 49.425774774243756, 47.690973204951135, 42.854945736546675, 45.320363275466434, 44.27918580270583, 45.10135381452499, 44.55066480944234, 39.86888062569403, 35.35027488585442, 37.01985920629194, 20.222018687955796, 31.48875048083644, 45.52135336783625, 50.42157042411066, 62.59109258651734, 62.75360030512657, 28.08261521400944, 14.74514751665054, 2.1305785256047405, 0.17828292453721648, 1.0270372057153334, 0.7485820184792242, 0.4874394990263447, 0.42680440590746943, 0.21799467023341887, 0.2222301711839053, 0.09652741553802645, 0.21238235606541558, 0.08102717388781809, 0.05963604551770034, 0.12540675459369538, 0.04668208860581921, 0.09351649081274387, 0.1014755544583163, 0.1446149996932476, 0.47882922234073766, 0.8617229699607819, 5.743605090725807, 15.76070308685303, 32.1954890220396, 44.358017598429036, 44.72979945521201, 21.71504339864177, 24.653528198119133, 35.29741702541229, 32.43879168264328, 39.77154700986801, 39.45097561805479, 41.527839245334754, 42.748778943092596, 43.65221454251198, 41.623078315488755, 41.40775196013912, 37.72453261959938, 36.756119035905414, 39.335171561087336, 42.19825467755718, 44.637510007427586, 46.19507928048411, 44.031013519533225, 42.8538513952686, 38.55875015258789, 41.26243991236533, 39.93787511702507, 40.21875212269445, 43.078705187766786, 44.88590586570002, 41.9305254567054, 44.4771086016009, 42.73330127039264, 48.07435351033365, 52.34115092985092, 61.92205390622539, 59.48484213121476, 59.58498024171399, 53.62975935782156, 53.3323456395057, 53.10898234767299, 54.43204487523725, 48.14713701125115, 54.8749706822057, 55.417669819247344, 58.06790551831646, 57.38893931911838, 49.23311579611994, 15.65202989885884, 0.6078606146958567, 26.275002687208115, 58.81519940591628, 46.36956199522942, 37.92092569412724, 6.805697131541468, 26.79489520288283, 27.866423976036813, 10.32411269603237, 9.16483756034605, 17.12024365701983, 26.20450592810108, 38.539412867638376, 27.57715309819868, 34.83949991964525, 36.228403352922015, 62.30171188231438, 41.12019123569612, 30.35992176302018, 62.53376322407877, 59.89856589225031, 16.68933795344445, 1.0548699767358842, 0.39066246139907074, 0.15844333105750624, 0.2841427772035522, 0.25697604302437077, 0.022483246077993707, 0.026636193393759673, 0.14145186861916897, 0.04198248776036405, 0.022753606167351528, 0.07843765880792372, 0.11927428970774336, 0.01782162595660456, 0.04869423003026074, 0.12366247198153889, 0.12130859022539471, 0.31814583487087683, 2.0024283182236458, 68.37531382037749, 69.87365138146185, 55.21298877654537, 36.546154560581336, 41.475177503401234, 36.749521609275575, 33.56346268807688, 37.82046202690371, 30.70266042986224, 37.95860398200251, 34.52085833395682, 29.974939169422274, 19.261736177629043, 8.99149037176563, 19.12181935002727, 50.53915131476618, 68.3454724281065, 55.77629604647237, 45.829161367108746, 6.175882152972683, 4.687220098510866, 34.232568048661754, 46.94807629431448, 54.52641710158318, 61.28982274763046, 72.13073222867905, 67.83408949452063, 65.4651544170995, 59.159171658177534, 61.560462367150095, 58.078888154798946, 62.99457503903297, 63.315193499288256, 63.056972103734175, 55.57021471761889, 48.29474756794591, 48.800631338550204, 48.955325695776175, 48.97639274597169, 49.22839326243247, 47.737374844089636, 48.21112263587214, 47.2652469911883, 47.12687753861951, 47.65121998325471, 48.344993129853286, 44.64906138758506, 47.485770487016254, 45.95338675283617, 45.93947410583497, 49.57025920191119, 50.20163136143839, 48.52615956337222, 49.15709241744011, 47.54369997209119, 48.88940634266023, 48.29221763918477, 44.56952356523083, 42.22313819393035, 42.73070858370873, 28.63569490371212, 35.44733393576838, 40.59268343833185, 47.5090419092486, 55.83369993394422, 60.65880752378895, 34.132351490759085, 14.528804286833733, 2.1250239591444693, 0.664366647120445, 0.7423496787105838, 1.4364350827470904, 1.2151952640664194, 0.575226862584391, 0.16122081347050207, 0.1215471423441364, 0.020241312750224626, 0.1754854625511554, 0.08878182995343402, 0.07112665192013787, 0.06174061161976668, 0.15416857576177967, 0.06526696030050516, 0.16821953227683423, 0.038119068053821405, 0.3039922072522102, 3.843341522639798, 7.4744435952555754, 15.850591063499452, 24.038930054633852, 46.414402531039336, 43.16227128428798, 29.063807879724813, 27.81623724968203, 44.581192616493475, 40.261913884070616, 46.73682135920371, 45.95728558878745, 46.86330995252056, 46.007138913677586, 49.04213951480005, 44.96676160443214, 44.2512781389298, 42.29035977394351, 44.42049703290386, 44.24066028287334, 48.11516184960642, 49.50442221856887, 49.95859738319151, 48.38323231666319, 48.444209483362016, 42.553437063770915, 46.006036727659165, 44.58686436376264, 45.73722493263983, 45.43255090713502, 47.56124081150178, 44.05384563630627, 48.62903941062189, 46.31989302173738, 52.00377218184933, 56.5643512049029, 62.09585805093089, 62.357001612263346, 62.85388746569234, 56.953207139045965, 60.489627853516616, 57.15422861037716, 60.27541545129592, 56.59307472167477, 59.72801731478784, 62.06029784294867, 63.93679503471621, 56.555600397048465, 50.06130072378343, 12.130856417840528, 1.3921067839668644, 33.87819759307369, 62.67106971433086, 50.5724012467169, 39.50143691032164, 8.717987422020204, 24.344719994452692, 26.557201531625566, 9.569866407302118, 17.54235540666888, 17.266448044007827, 28.12818923304158, 37.44560110953547, 31.013965222143362, 33.12287461373114, 36.98029818073396, 78.15002502933626, 32.85333325785975, 36.47911733196628, 66.86589164118614, 76.10521501110446, 30.990991900044104, 0.717763159303896, 0.18201319050163994, 0.10141410654590977, 0.10852877275958177, 0.04709331311225411, 0.10288815164277632, 0.17741634119902888, 0.35559941383619464, 0.15102934663093862, 0.21144382174937956, 0.32040364920131625, 0.20334817228778718, 0.2533624675725737, 0.2649978416100625, 0.2955003677596969, 0.2956075281385453, 0.9135459988347946, 2.1676196734751425, 78.82467269897461, 80.29436911306074, 55.85225666722944, 39.69025196567659, 54.17070911776636, 42.79266242058047, 39.67258168805031, 45.29868041315387, 35.4398775100708, 47.626771849970666, 42.050381322060865, 32.26907660884242, 26.57922956251329, 14.059894738658784, 27.7315709283275, 56.83927797502088, 72.73247872629474, 62.60875109703311, 46.24689771283058, 5.010276311828244, 8.860049786106233, 45.40605529662102, 57.419569107794, 65.49525076343168, 71.13464632341939, 76.07438518155006, 74.95936516792544, 68.18506317753946, 59.85250157694663, 62.002297755210634, 63.28430875655144, 64.22339085609683, 63.98286327239006, 67.84336197760798, 59.861742681072606, 52.03482166413338, 51.07158560906687, 50.12801631804436, 50.774297406596524, 51.93440114298175, 52.445682094943145, 53.782241498270345, 48.7679736844955, 49.48164109260806, 49.595566334262976, 51.28616671408377, 45.432150825377434, 49.552192764897505, 46.46752319028301, 46.57928720597298, 53.88370536988782, 55.17191763847105, 51.20082378387452, 53.87205200810587, 52.454632943676366, 54.12105583375501, 52.65344219823038, 48.23318989046159, 42.0241367432379, 50.13020892297068, 32.85856766085471, 47.153039747668856, 64.3925940605902, 65.38550676838045, 75.84836252274053, 68.6681422879619, 45.11330527644004, 19.571830918712003, 2.307272231386554, 0.8118178575269638, 0.8684376999735833, 1.3822529320755315, 1.111144589320306, 0.8094807377746029, 0.6019410226614245, 0.5283246922396845, 0.4703256157377074, 0.5257225060655225, 0.20061723737707063, 0.22246703024833436, 0.24236119983177035, 0.1816397226385532, 0.29808971430024794, 0.44784534782651936, 0.23106648977245056, 0.5891535443163688, 4.8224781309404685, 13.226643089325199, 27.849175353204053, 48.12680736664803, 52.51870093807098, 50.84536290937855, 34.444434873519405, 36.106586302480395, 53.64923000335694, 46.77386422311106, 55.490300347728116, 52.95400950216478, 52.89456598220333, 50.466473717843336, 51.015115245696045, 48.125387468645656, 50.69932914549305, 46.36956199522942, 47.21612714952039, 46.962494927067915, 50.39623583516767, 51.40453992351409, 52.403751957801084, 51.96192049211072, 51.818095022632235, 45.94780129771079, 47.48378576770906, 46.27784913586032, 48.42161663116948, 49.21098970597791, 49.66792621920186, 45.84807111370949, 51.12108199827133, 46.376414375920454, 54.01130399396343, 57.95146603738108, 68.01217294508412, 64.2509533512977, 64.43046454460391, 59.132695659514404, 61.93797480675482, 57.58305349657613, 62.65299151020666, 57.38242818463234, 61.46665888447916, 61.43546035212856, 64.23282023399108, 59.56297966741747, 54.32239109469999, 19.6592644722231, 1.5002975204298574, 29.826661809798214, 68.82710026156518, 54.31827652838923, 50.172758794599964, 13.155403041070509, 37.04710398950885, 35.13510542531168, 14.305405693669474, 17.510996057141213, 25.954325391400246, 36.12693555893437, 53.128147048334924, 33.43930006027222, 46.962479237587225, 44.90939694066202, 80.28694014395438, 54.82443878727575, 39.65981437313942, 78.53108329157676, 82.9292683447561, 39.96840292407621, 1.477607834723688, 0.48533805856300943, 0.3353108315458221, 0.45595589003735976, 0.26667545159016887, 0.313411932438612], [0.21380346448671436, 0.2775090992931397, 0.1382027518364691, 0.10008694348676551, 0.066677343490864, 0.13786080083058727, 0.200770684788304, 0.039201737982371164, 0.18382124993349278, 0.3043899907460136, 0.8405142241427976, 5.623917396991484, 62.630253530317745, 56.562786179204146, 34.70371530902001, 37.586018039334206, 38.27697100177888, 27.406102457354148, 27.936428477687222, 28.93600921477041, 22.104793633184126, 38.64936474830874, 38.26117953946514, 19.794580359612745, 25.046528116349254, 10.742524670016381, 14.423776941914713, 35.966549842588364, 65.30534136679866, 60.33520021746236, 56.842192296058904, 29.315239652510616, 1.9654418383875203, 9.252449581699988, 22.571281117777673, 34.885195532152736, 43.83111384607131, 58.99799362305672, 64.96805283331102, 61.36399084521879, 58.30497749390141, 59.28267925016342, 57.44250320619153, 62.49606924672281, 61.68371108270461, 61.753219404528224, 51.47641343455161, 46.686069811544115, 47.91247729332217, 47.603598486992624, 49.42868517291162, 47.12255116431944, 45.00265129150883, 45.66430807113648, 42.42085702957646, 45.6551807157455, 44.8090313326928, 42.04827108690816, 43.487933912584865, 42.936617328274636, 44.718236307944025, 46.5130619079836, 46.15807956264865, 46.5754589726848, 43.621702424941525, 45.62216220363494, 48.156444795670055, 45.69348658284834, 42.64825644031648, 42.26723347940753, 37.726807594299316, 38.11156857398249, 15.131913808084304, 29.767928238837953, 42.64706011741392, 47.81299421864171, 49.920397420083326, 51.379005293692316, 19.93205355059716, 8.343931571129831, 0.9153320255779451, 0.25109641013606904, 0.19967249774884796, 0.19879315138584186, 0.1339491252456942, 0.04725879959521755, 0.12600991859911911, 0.17669646369834102, 0.06592949612006065, 0.23680553020488834, 0.12170136350417331, 0.07044761456669339, 0.18185271040326167, 0.22917451306937203, 0.2313558258596928, 0.0725679774017584, 0.06557897259030612, 0.3735925822008041, 1.7976207790836212, 10.216948639961982, 19.483381471326275, 22.095085767007646, 39.399423906880045, 43.88698800917595, 23.964312845660796, 17.344999390263713, 30.911981636478057, 32.17192930559958, 40.33811769177837, 38.214067951325454, 43.277255565889426, 44.93854799578267, 47.866899351919855, 40.22603596410444, 39.492776316981164, 36.717824935913086, 40.30487168219782, 42.2975298666185, 45.51644256038051, 46.26302257660897, 43.88813334126627, 45.16895978681503, 44.17836912216679, 39.85568185006419, 41.04186934809531, 41.644431698706846, 43.44586649248677, 42.53439787895449, 44.388612085773104, 43.438939586762466, 47.267125806500836, 43.77603200174148, 52.9482828417132, 56.29758688711352, 62.48883639612506, 60.04203442604312, 61.59610886727611, 55.60922661135274, 57.26441975562804, 53.828521543933505, 54.15177191457441, 50.90662248672978, 58.18596886050317, 54.945667482191524, 58.97086258857482, 51.60161941282211, 35.59390506436748, 2.5431878432150814, 5.167800168837271, 50.91589496981714, 57.71711226432555, 51.635500846370576, 34.287814632538826, 7.1806085494256795, 20.1185602911057, 32.83501578915504, 57.220838300643436, 30.69131889650899, 15.204434510200256, 30.446131537037513, 34.60248677961288, 40.74592651859407, 33.12854636100031, 42.970369323607414, 36.77593485001595, 67.6764965057373, 38.99901659257951, 48.631153568144775, 65.58235091547813, 42.17783089606993, 1.4584571075054908, 0.30218322851484825, 0.127025529021217, 0.2094261606614436, 0.20711386215782937, 0.05666906359575449, 0.1393202902568925, 0.08954480756074192, 0.08606664581044067, 0.04571013753452609, 0.07487236987799406, 0.046662645294300975, 0.06496112267937391, 0.05328168326448049, 0.1354102541001574, 0.13036927298432396, 0.38030764929229216, 10.603277587121534, 82.0038321710402, 64.20934877087994, 49.27977631168981, 41.29556432847054, 41.04132021627119, 35.28933694285732, 36.67921704630698, 33.61524189672163, 26.58609567149993, 38.71680990342171, 35.019250377531975, 24.596253748862978, 26.515914663191765, 10.316438578790235, 18.206671553273356, 39.89885537855087, 67.50683830630395, 65.65929212877828, 59.88380993566206, 36.55381887189804, 2.225435409815081, 5.596754983548196, 15.294389167139608, 29.315800551445257, 34.4007122132086, 52.565255549646196, 65.05288977776804, 61.11748164699924, 58.14676869300104, 60.63622643870693, 63.43351179553617, 63.950860654154134, 64.51916110131049, 61.46110088594499, 52.90024165184268, 48.034788562405495, 49.856054859776656, 48.4063115427571, 50.790516407259055, 51.63029978352209, 47.22577618014428, 50.05282840421123, 46.29419757473854, 47.29296638119606, 48.665399782119266, 45.35279735442131, 47.617558202435895, 47.311942808089725, 47.10554376725228, 46.16109194294099, 49.19398230891074, 49.805193485752234, 50.15402555465699, 49.147619893473966, 50.324617278191354, 49.54733687062418, 48.104120377571356, 48.43816118855631, 40.21590840431952, 43.60172579365392, 24.439796286244547, 32.01899020902572, 35.602867680211226, 43.22104015657979, 45.25612269678424, 46.86732253720684, 26.351453604236728, 8.131561212001309, 0.4646493332280267, 0.16376129892324248, 0.17178037023592382, 0.1308399420832434, 0.03812405528620847, 0.07303677724614259, 0.11000208241204101, 0.08557962839521709, 0.09346610520996394, 0.2159606148639033, 0.08358253676804804, 0.09494300781478805, 0.10224326648899626, 0.11207680938945663, 0.08425780496890507, 0.053287965185459585, 0.07414403476662214, 0.11732588296816235, 2.223337677217299, 11.396686780837275, 20.348991693988925, 15.720805718052773, 39.32485964990432, 43.0033133106847, 29.190674981763287, 22.015363593255323, 36.46700505287417, 39.635664339988466, 46.20871736157326, 46.51942007003292, 47.564213968092396, 46.52667645485171, 49.61292282227547, 45.0025846112159, 42.8768325621082, 42.161007850400864, 43.95284852673931, 46.318296617077245, 50.21521845171529, 51.952451890514745, 50.72340465361073, 48.65857093564926, 48.683317169066406, 44.04908780128726, 46.02547991660334, 45.087456857004476, 45.85877918427991, 44.822834153329175, 47.52794381110899, 46.851782106584125, 48.73834410021382, 45.64167207287204, 56.32234488764117, 59.839973526616255, 65.22181449397918, 64.40504366351713, 65.31186426839521, 61.169115727947606, 61.48751412668536, 58.55662107467652, 60.65120204802483, 57.04375897684405, 63.852817089326926, 59.876863418086884, 62.58991587546564, 54.946753978729255, 34.57101760372039, 1.5316692499383804, 8.464363044308078, 56.5740708381899, 60.05202862524218, 58.199069576878706, 39.4974753164476, 7.165851121948612, 21.74723429064597, 30.37477577886274, 60.075147075037805, 42.4027866701926, 15.319090293299768, 31.28124729279549, 34.74497472086261, 35.04097638591644, 37.04588805475543, 40.357560880722545, 47.26403497880506, 63.40469806425033, 46.86926018807196, 65.18757612474504, 68.70868390606296, 68.6569086197884, 3.42485232699302, 0.17331607008893646, 0.01116551794937902, 0.05319862784216962, 0.062131737809508085, 0.030946160005705974, 0.29267512742550145, 0.508442810706554, 0.25181228865779215, 0.1876409796457137, 0.27368043699572164, 0.18899844148226325, 0.40784847952665826, 0.27245540111776323, 0.41500858241511934, 0.4960592752022128, 1.503973394151657, 13.377091480839638, 91.10463311595302, 77.41754593387728, 47.76564728829169, 49.273378925938765, 51.163427906651656, 41.70514606660412, 42.10952674188922, 38.02125207839474, 28.5600951410109, 49.176688578821, 50.19389644745858, 25.59668367908847, 32.13017567511528, 17.332590972223592, 27.540045515183483, 47.496964931488044, 74.00778247464088, 67.28446345175466, 65.21984546415268, 34.3837518845835, 2.7664957315691057, 11.332543280816848, 25.317912986201627, 41.32761793751871, 47.79411585100236, 66.00862626106509, 70.29747916806129, 65.24623517067202, 60.43122376165083, 64.18335914611816, 62.96049748697589, 67.02867784807759, 67.09200843687981, 65.2230304287326, 57.99419633803829, 51.20723685910625, 52.231567751976755, 50.45065479893839, 54.96343581907211, 52.53284108254218, 50.36735542358891, 53.82963549706244, 49.009540696297925, 49.21795975777411, 51.95379334111368, 49.00967013451361, 49.92659476495559, 48.47637684114518, 49.62566660296533, 50.25346940563571, 54.63846352792556, 52.76050329208375, 54.021537457743, 55.15583199839438, 57.06595566964919, 56.33283722785212, 51.98910643977504, 50.96909799883443, 42.76312305081276, 50.58162273899202, 32.49606220952926, 44.750862583037346, 62.632767769598196, 68.50633667361352, 70.43071423807453, 62.28166464836367, 34.56852689866097, 11.7599747450121, 0.6566691795183767, 0.32191511003240464, 0.5053748737179464, 0.37619381842593996, 0.463522601752512, 0.15469020502942224, 0.29116480040454096, 0.6695314893318761, 0.694517293764699, 0.5467169924128441, 0.3151776118864936, 0.1257121402229513, 0.46247051788433907, 0.7830122161296107, 0.3312823122307178, 0.12221183087075911, 0.49590636405252647, 0.2768499265995718, 2.7559715221005106, 14.702667267091813, 25.93855157975228, 35.294314430605986, 52.05527290221184, 45.89240566376717, 37.28354446349606, 28.46341459981857, 42.517068847533196, 46.71362053963446, 51.72279711692564, 51.784311648338075, 52.13725828355359, 51.349430622593054, 52.38789381519441, 48.66862789277108, 47.95110871714931, 44.83513862855973, 45.50440872869184, 47.407107353210456, 52.28450405982233, 54.38956560627107, 53.4758847759616, 53.689265635705766, 50.566172522883264, 44.78188853110037, 48.20360737462198, 48.04424147452078, 50.10166191285657, 48.73465707225185, 50.44358668788787, 47.55045429352791, 51.14733834420481, 46.095298105670565, 58.341463381244296, 63.739091888550796, 69.32672392937445, 68.36009502410889, 67.96827377811556, 62.51985842181791, 62.186437345320186, 57.60139842187205, 61.513068368358, 58.24923669138263, 64.54730018492668, 60.30171102093112, 66.47353695284936, 60.16735023067844, 44.886729563436205, 4.157217673717007, 6.366638291266657, 58.638818264007575, 64.992681395623, 60.13630074839438, 43.09811307537941, 15.265668592145367, 28.563723333420295, 40.07697020807574, 63.8324325315414, 36.20925041937059, 21.44538829403539, 43.23469000477945, 47.21144383953464, 50.34784163198164, 45.97764268998177, 59.11796323714718, 45.06285182891354, 89.45583343505861, 46.09810652271394, 72.70886605785739, 77.6640433649863, 75.00290347683814, 4.035913473175419, 0.5760173427481805, 0.46131087527159725, 0.2992179473080943, 0.34402465267527493, 0.22297316921814797], [0.14124991252057015, 0.08142547066053075, 0.06139439733458623, 0.021775262092330286, 0.008018570961505777, 0.026868222273826122, 0.14708279872373228, 0.027528226172791857, 0.2264885934850862, 0.062403112965365576, 0.6923550259201758, 11.273124275668975, 70.27537268977012, 54.78956107170352, 34.29237242667906, 43.42326187318371, 36.579624145261704, 26.564444188148748, 25.01571397627554, 38.72896140621555, 27.02118850523426, 31.00238834657977, 45.804983877366595, 33.05591191014936, 18.544189545416064, 11.732290656335893, 11.457705132422909, 37.986405741783884, 57.310837084247225, 60.685118782904844, 51.195999268562566, 52.28379018845097, 9.247821184896655, 0.26017507297858117, 2.956091828884617, 6.486416199514943, 9.269666825571369, 8.423932233164388, 45.97372424217963, 57.270530808356504, 59.96183372312977, 60.80649260551699, 64.45328097189626, 58.591381119143584, 65.56782637873005, 58.147619847328436, 49.80202813302317, 49.32864119929653, 50.41860118989022, 48.25109158792804, 48.71259374003257, 48.010685597696614, 45.60177372347924, 45.6507602045613, 45.194659156184045, 46.46369495699483, 43.286688866153845, 45.27578946082823, 43.48649832510179, 45.623303613355084, 44.9533784774042, 45.75004323836296, 47.660912159950506, 46.26832954345211, 46.910692184202134, 46.44725238123248, 45.285367888789025, 47.48948104919926, 43.66143603478709, 46.92822125650222, 36.22864261750252, 36.149591169049664, 9.50303118075094, 16.877378340690367, 38.27867723280384, 40.41083059003277, 41.84316642822758, 37.42047440621161, 12.403388580968304, 2.365762125099859, 0.10746292995228883, 0.12560004623787058, 0.11546994304104198, 0.07711500034577425, 0.10098292161860775, 0.04405089451240436, 0.010714920354075732, 0.14894114416693488, 0.047135179817316034, 0.09501577850671546, 0.3099227696657181, 0.09400594438756667, 0.09320591876824057, 0.041104056872427464, 0.15012989812079938, 0.06844309188665883, 0.07094099817256774, 0.2948368743302361, 1.1135491248100036, 12.044315203543633, 21.42966155082949, 21.213170251538678, 32.366926016346106, 41.141540696544034, 20.8400430217866, 15.373801473648319, 24.748355419405048, 30.984064994319795, 41.43181962351645, 36.1976598155114, 46.026036893167806, 44.14973974227906, 48.34819378391389, 39.6841722919095, 38.23462901576873, 37.27281678107477, 42.9198335063073, 41.95654646042855, 46.26353248473137, 45.54787643494145, 45.99337139437276, 46.6182049628227, 43.25001470504269, 40.20997778061898, 44.22983454119775, 42.8547300061872, 41.93902131049864, 42.373478720265055, 44.83174577836068, 45.85106388215096, 47.58591644225582, 46.14747347370271, 54.039733332972375, 58.297893693370206, 61.16589546203614, 61.54941697274486, 59.49926468633837, 57.49670643960276, 59.79222259213848, 60.290293001359515, 55.328526112341116, 53.368058819924634, 58.023033603545166, 60.88222965117424, 60.10367447330106, 50.180634913905976, 13.991465068632557, 0.2148837557122592, 24.222902944011075, 55.729141312260786, 53.71127405474263, 57.135193347930915, 40.98197867793422, 4.678781119085127, 14.662102114769722, 55.49505426037697, 43.41570738823184, 10.736147876708738, 15.997207299355539, 30.705127600700628, 33.72655483984178, 44.82272432696435, 26.22451982190532, 37.377818630587676, 18.842309290362945, 33.11784613517023, 25.111386468333585, 40.61074987534554, 52.837542564638206, 72.0959564947313, 13.319468921230687, 0.4393443152789147, 0.3081548225975806, 0.11503042307712379, 0.09836081715841448, 0.16094782569956395, 0.08312947236962857, 0.06175118363312176, 0.07505683618928156, 0.054253013804554946, 0.026227424199122096, 0.0753942596155309, 0.06476468241382992, 0.027501554821708032, 0.1614108339192406, 0.22552272515191188, 0.32901377266933846, 20.286892729420817, 83.17426743045931, 62.7474892523981, 39.90195012861683, 36.31107122667375, 43.610433455436464, 36.00957039863833, 32.980335681669175, 37.844353183623284, 30.642650127410892, 34.08891908584103, 45.64031493279242, 36.32773345516574, 22.161252229444443, 14.512830434306977, 13.72426046479133, 41.71202590388637, 60.98927113317675, 64.77926915691745, 56.687494016462765, 58.12190478847873, 12.295723442108402, 0.15024652734639185, 2.3715689489918375, 2.55425137858237, 5.693094278535535, 6.8958140765467, 46.30876133518834, 58.41308586059078, 63.08302840878887, 64.03734891645371, 67.59012591454291, 62.72259789128458, 66.11002737475981, 58.24517311588411, 53.256330105566214, 50.12006567370508, 50.228844765693914, 51.21355579745386, 51.05927328909598, 50.08253251352618, 50.35256024329893, 50.08995756026238, 47.75970489748063, 47.75157382411342, 46.830209070636386, 48.07691874042634, 47.1948443689654, 48.24206229179136, 48.001879876659764, 47.425668008865856, 48.94745349884034, 49.96994872247019, 50.303577684587054, 50.368312481910955, 48.17560165159164, 52.959936203495154, 50.226236389529326, 47.84254143314977, 41.964128401971635, 41.70248669962729, 17.250403588817967, 22.110271223129768, 31.195402299204183, 34.96322324199062, 36.811797080501435, 38.44852762837564, 19.54140509328535, 3.2998508022677515, 0.08771054026099943, 0.11729860257717872, 0.06001360812074235, 0.09428968037208242, 0.047652622414452415, 0.11537719277604935, 0.04748582592113845, 0.015941424024922234, 0.01476227968645793, 0.044240363377837405, 0.23061570831604544, 0.030061686599266627, 0.22796741897060027, 0.007882662175688893, 0.09251738958541425, 0.06249314744866664, 0.1138565082463526, 0.10272790137077532, 1.1377948883079714, 13.787010542808043, 23.353617460496967, 16.518775647686375, 30.922987807181578, 41.28727243792626, 27.28501889013475, 21.558948755264286, 32.31111853353439, 37.64610875037409, 44.90082656183551, 43.55846597302345, 50.714092946821644, 47.461577307793405, 50.28566814238026, 45.30900016907723, 43.48184247170725, 44.48017197270548, 46.916144278741655, 47.52275843774119, 49.780925781496116, 49.55619750484344, 50.61752419317923, 50.91220009711481, 45.34173234816521, 42.99149913172568, 47.196636892134144, 45.19740873767484, 44.91406848353725, 47.29334685110277, 46.51205385884931, 49.12461519241334, 49.04189240547919, 48.27560247913484, 56.36867984648674, 61.18961011209796, 62.19655706036476, 64.97560339589273, 65.16708566296485, 61.433526623633604, 62.03406895360639, 65.06568062689998, 60.294380111079064, 59.5761666759368, 61.92839637879403, 65.65877437591553, 61.34453981153427, 50.721561139629735, 9.773231494811274, 0.46670652445285554, 33.75632562944966, 60.68025504389117, 59.020217772453066, 64.52118504431941, 41.989423767212905, 3.7367207148382744, 17.992833737404116, 61.08628311464864, 52.215411509236986, 20.097253976329682, 15.439280540712419, 30.190532245943626, 33.26493501663208, 41.24461666230233, 29.499496913725334, 34.43275013277608, 29.71057926454852, 40.40665718816942, 31.087319427920928, 52.78467685945573, 58.60479954750308, 81.46522014371811, 22.785097360610965, 0.8439862571897045, 0.2913032784577339, 0.025384016935863805, 0.05889064962825468, 0.08173932156134998, 0.35532110941506206, 0.1764410653061444, 0.45267062922639234, 0.2935942490735362, 0.25010800349616236, 0.2104662782362392, 0.2681844302963826, 0.19645037790459974, 0.41476867432075165, 0.2617109566926956, 1.4618280169463929, 25.808083741895615, 91.90034866333009, 72.81673908233643, 41.11925771159511, 59.323315005148615, 50.63269984337592, 40.244333820958296, 36.16867742230816, 51.82120153980871, 35.808858794550744, 39.35135526041831, 58.07567965599799, 44.97402975636144, 21.264702350862567, 17.061610106498964, 24.964701590999482, 46.849142351458156, 68.19917586541945, 69.55706119537354, 60.683600825648156, 62.231383785124756, 11.564912334565195, 0.3921145044507519, 4.818040949683036, 8.950122114150755, 11.64700165871651, 15.444506118374488, 60.08344681032243, 63.35515460660381, 65.70552510599937, 63.834170141527736, 70.17753308819186, 63.519097912696104, 69.27165385215514, 63.20770486708611, 56.915913243447584, 52.64311459756667, 55.06436232597598, 52.93635491401919, 53.921014954966886, 52.75800474228398, 52.65333629423573, 54.70424559808547, 48.96675940482847, 49.8221145906756, 50.107094395545225, 52.78076625639393, 48.25695553133565, 50.97671916407924, 50.52427768707276, 50.52679977109356, 54.13901244440387, 53.41398977464246, 55.89264923526395, 52.77192523402553, 54.88356067288307, 57.52951314372402, 56.65619742485785, 53.55113937008766, 45.34336797652706, 46.07540776652675, 22.97068234412901, 35.519023095407796, 61.39278888702393, 60.04170886931881, 66.80064693573983, 55.817480933281686, 26.18810061485537, 6.589793697480233, 0.20835683981497444, 0.26679952719038535, 0.23990093910646057, 0.2711615399006875, 0.18117121390758023, 0.1736714276334932, 0.16328321409321603, 0.26684840359995443, 0.13613601515610374, 0.2581964823747835, 0.6969868547974095, 0.09051159519942538, 0.8501900372005279, 0.14223468790371574, 0.2687627960356974, 0.22589148923514352, 0.3865357602555906, 0.31096866354346275, 1.3454007934178076, 14.39322756182763, 25.381804473938484, 30.379147260419785, 50.24997849618235, 45.28454419105284, 34.6630403303331, 28.54813583435551, 38.01878882992653, 43.83815842290079, 55.57481565783101, 48.58372034565095, 54.93076247553672, 50.74952371658818, 53.24558281129407, 47.056094446489894, 47.744686142090835, 46.3740844880381, 48.141382894208355, 46.652447254427024, 52.15759185052688, 51.28718653032857, 51.83962883487825, 55.37128779195971, 48.941832742383404, 45.62200923119822, 49.08081408469908, 48.05697741047029, 47.66213593944427, 48.07752278543288, 48.43340335353729, 51.1144414255696, 50.00581095295568, 50.75008461552282, 58.83278339139877, 65.8740811194143, 67.90692790862053, 69.40856026064965, 67.78534227801909, 63.42768707583028, 61.87577386056224, 64.76866306797152, 60.49085555538055, 58.87819659325385, 62.16398569845385, 66.56310035336402, 63.56003569018457, 59.19020152861073, 16.29081827978934, 0.32639139241749243, 29.486335400612127, 64.00593465374362, 61.52998162854103, 66.26142301867085, 50.58432132967057, 10.88142462315098, 22.362236438259004, 64.30092042492282, 49.34822951593707, 14.383085293154563, 20.864359755669874, 41.928615262431485, 44.63971045709426, 57.46094226837159, 34.69919281621134, 54.01841525108584, 23.948591986010154, 46.48440899387483, 32.181101768247544, 60.19912927381454, 68.04209278475854, 94.7320096723495, 25.966855402915712, 1.3363756647994443, 0.5876370579484971, 0.21078008317178298, 0.14960169581876648, 0.2815978944061264], [0.184470463484045, 0.08191736039495276, 0.04685267723435837, 0.10177403763537446, 0.0664603720689493, 0.021328380023459756, 0.0062661108395625515, 0.06039864774192534, 0.0998844511266197, 0.01940472558471224, 0.60583415891855, 28.066100074398904, 80.0934103996523, 46.07464290434315, 35.250874180947584, 49.75291613609561, 26.46046215488065, 27.339208395250385, 30.157639249678585, 44.04701678983627, 30.81582473170373, 32.984128613625806, 31.47759329888129, 37.24268121104087, 28.77825148643986, 9.024313745960113, 6.800580889947954, 25.48858511832453, 62.40618421185402, 55.16109189679546, 38.017941597969305, 60.282789507219874, 19.991104833541378, 0.2831806014141729, 0.0969545248775713, 0.09853872575707014, 0.14864998479043284, 3.5513156700518826, 17.449695294903172, 61.99593567079114, 63.20291957547588, 65.74980866524481, 59.0336165889617, 62.85607222587832, 61.16628769905337, 51.41244349941131, 48.492862562979425, 50.77726664081697, 51.34184083630962, 55.24852152793638, 53.78497931265063, 46.20260238647462, 47.17783697189824, 46.906016718956735, 47.3785799549472, 45.691262598960634, 44.46287432024556, 45.85527650771603, 43.924046562563994, 45.5657781324079, 45.892515490132, 44.404940912800456, 44.44021871013027, 47.50131484000914, 45.58886912561233, 48.31506544543851, 45.283285110227524, 44.54786031476913, 43.215399788272, 46.984424898701334, 37.184316342876805, 33.54517267596337, 5.9285512182020375, 5.426729061911184, 26.70372166941243, 34.41982200068813, 30.757134306815367, 28.407473756421, 13.518632169692749, 2.551572644902814, 0.23019131092775255, 0.12687232675811938, 0.11511000429069805, 0.027540793845189676, 0.06734084458120408, 0.03591603284040767, 0.03539945592262572, 0.011366512607632866, 0.10897307311214748, 0.17162036511205858, 0.09762099072817834, 0.06489797405177547, 0.02354145098868157, 0.1005592137094467, 0.08505234539869332, 0.04568105300648078, 0.07046893479362612, 0.16284285143258112, 1.308052474933286, 11.936194089151199, 22.304603092132076, 18.174319844092093, 24.75036563411836, 35.94807940144693, 21.48312737864833, 14.82690049755958, 26.625409587737053, 32.52533878049543, 35.652234631199995, 37.157805042882124, 42.396299069927586, 46.3551551295865, 46.14059363642047, 38.62981173299974, 38.283635108701645, 41.671499975266, 45.7037631926998, 49.00738731507332, 48.41758443463234, 46.18008013694517, 47.850409707715436, 47.607269825473914, 43.78365708935646, 43.84115119134226, 42.70406000075802, 42.00622327866093, 40.67344896255001, 44.33722119177542, 46.273401168084916, 47.79703801678073, 46.048896466532064, 48.14681537689702, 53.498697280883796, 60.03642935906688, 61.03412735846735, 63.58449559057913, 60.816012197925204, 66.1019943606469, 61.60821330162787, 59.20424753619779, 55.820689432082645, 59.83488621250276, 60.553472272811405, 60.35040332425026, 55.23930003566127, 31.4048509828506, 1.1415489642850816, 3.934787415689038, 48.619963046043154, 56.03877713603359, 55.968860887712054, 55.60374706022201, 21.901522682559108, 0.38980572995158935, 14.586588644212293, 40.60335620757073, 17.963529709846743, 13.589259347608014, 18.16433152844829, 27.884017767444735, 33.71643120242704, 31.903521514708, 31.123171852480983, 39.70782026167839, 30.20650805965547, 38.219237635212565, 40.31737227593699, 31.322312547314553, 55.37553571885633, 64.84762822428058, 31.602434496725763, 0.473780028762356, 0.24404973422567694, 0.10826605822770827, 0.04416215729208724, 0.14488077091593898, 0.09536961153630288, 0.07155588332323298, 0.07218730065130419, 0.029732655666227785, 0.035662810137916, 0.016060652203797814, 0.07232200189103043, 0.10011019425526743, 0.05506598630980138, 0.1457514604854007, 0.0322418560033604, 40.7364853735893, 87.1504682110202, 61.439084622167776, 33.10330590894146, 45.61305446009482, 34.970381567555094, 36.22012715185843, 33.7885243661942, 40.73675601713119, 31.068046862079253, 34.943834966228856, 35.968648310630556, 37.24803524632608, 27.421521294501524, 11.32631455698321, 10.09907357154354, 24.436044539174727, 66.36356938269832, 58.93765188032582, 43.04756549096877, 64.97349316074003, 25.786751931713475, 0.9851757713383245, 0.23536827265014573, 0.6165392264243096, 0.22809776117003736, 2.7540240653099555, 26.448396944230605, 65.63956260681152, 64.60363718771166, 66.19477410470286, 63.47013104346491, 67.04966252849948, 62.12429131231001, 54.629022382920795, 50.67319831540508, 53.5119156683645, 56.60477907426896, 59.67831696233442, 59.516519192726385, 50.36104825235183, 49.7797373033339, 51.13528490066529, 49.07752713849468, 47.26769062780565, 48.0107444332492, 48.331002035448634, 45.49539512203586, 48.801702145607244, 46.85296274000599, 48.60828615004017, 48.448794734093454, 51.568785252109656, 51.15612053102063, 51.933459774140395, 50.08558019515007, 52.101403897808446, 49.25990950676703, 49.15827305086198, 39.20779258974137, 39.01456486794257, 14.159182675423162, 15.10199789078005, 25.74924034457053, 31.88743587463133, 26.605568278220396, 31.708291422936227, 18.16606717724954, 4.2945692712260835, 0.12755536309052862, 0.14745251275599003, 0.10682220465593761, 0.09507623816569967, 0.03990012288634335, 0.033419658730347315, 0.016787947350812536, 0.028910578206001274, 0.11011967690841806, 0.06850297697969983, 0.09864289073213454, 0.07453856238674733, 0.04323598380470949, 0.06138187945790349, 0.04059254762626464, 0.026309493283230453, 0.04974346022091566, 0.045745006026399714, 0.9964871514708766, 12.030103475816789, 20.64345775112029, 14.063317987226672, 21.45793007266137, 41.859157931420114, 28.661643343587077, 23.135453270327663, 34.788356134968424, 40.27652863533267, 43.845673684150945, 45.605970659563624, 47.07913837125225, 47.840925416638775, 47.355622322328635, 43.3804609698634, 43.07901897738057, 45.251741409301765, 48.23175822534869, 51.249378804237615, 50.40200956406132, 51.86250017535303, 49.21965814405873, 49.58545446395875, 45.08104378177274, 46.096725848413286, 45.32207342886156, 45.76259482291437, 42.62629508972169, 46.64917207533314, 50.474867590012096, 49.205023780945815, 46.66445362952448, 49.99847219836328, 55.45759954760152, 60.777482755722545, 63.30133184309929, 65.37373573549333, 62.136289842667125, 67.37197937503939, 63.29817433511058, 63.10773934087446, 62.15204600364932, 64.76845518235238, 63.59337191427908, 63.98084717412149, 54.77300474720617, 23.50535435061301, 0.5647459217617589, 7.433581813689202, 55.81500984007313, 58.666274855213786, 62.06605980473181, 55.42182753163, 21.704103908231183, 0.9842075587761019, 22.403378178996427, 42.99695907100555, 19.742487361354215, 20.156383706677346, 16.139208866703896, 27.416612448230868, 32.80575490766956, 33.51634325519685, 37.1304347438197, 36.37365656514322, 27.19881303848759, 47.8846323874689, 36.489288037823094, 43.10795037977157, 59.93750718332107, 77.08863950544789, 40.17508437556606, 0.3366473791820388, 0.05707979780591785, 0.023315041363539717, 0.0644367125125662, 0.10294528648016915, 0.46112667709108324, 0.197269402504448, 0.24065040292278414, 0.1913732374387403, 0.18724465171896643, 0.1657595473431772, 0.29615463749054943, 0.22237163698000295, 0.2443027424235498, 0.31745353653546304, 0.6888539428191801, 50.65900718012164, 97.21899632484683, 66.55376511235391, 41.43931135054558, 71.80006073367211, 36.2415668272203, 42.999155598302046, 41.59388411429621, 58.19238193573491, 39.595750301114975, 38.72465464376634, 41.19390826071463, 50.33043807552707, 35.16788075047155, 13.803653159449178, 18.094711419074766, 38.265627507240545, 73.64471220201062, 64.67524397757747, 47.751052148880504, 72.22057803984612, 25.462789650886293, 0.8593524487749223, 0.47157700504026107, 0.38980340104429956, 1.6746900206612003, 3.865933394239795, 37.58729673201038, 70.14905668074086, 66.38656231664842, 71.70699857896375, 64.53116747640794, 69.67625418016988, 64.21405169271654, 59.265177634454545, 55.15820503234864, 56.77381361684492, 55.37795189888247, 61.457182438142844, 60.33946775620984, 53.133312809851866, 53.5264519722231, 52.803064930823545, 51.03191867951424, 49.19372343247937, 50.99475814450172, 51.68660540734568, 47.410712011398815, 52.361053036105254, 49.3260524349828, 50.18412582335934, 51.13176653462072, 54.87959515663886, 52.78280588888353, 57.9914192999563, 55.94963342912736, 56.12651271204795, 55.547849362896336, 56.21954741016511, 44.53785827082973, 48.07791894482028, 20.451675422729988, 25.832943724047755, 48.974258976597945, 56.27790051121866, 58.96399844077326, 51.04764346153506, 24.522742648278516, 5.792919580013522, 0.1847469599376763, 0.2676027857007519, 0.1869027007130846, 0.1389483852131713, 0.14302956541219067, 0.21619807147691328, 0.1636245828722754, 0.10680197993473661, 0.32597700013749065, 0.7300768888765766, 0.247722911317983, 0.18863441182240365, 0.10805546065732356, 0.20373760542321592, 0.14818377432323274, 0.20665420940326107, 0.23224739898597044, 0.18761503990859757, 1.4256576352542447, 10.820086598396303, 23.383423551436394, 24.187095626708, 42.5462552039854, 46.867542189936486, 35.035437999233125, 29.16382831911887, 42.235901586471066, 48.209039857310636, 50.87325096130372, 49.08779982597598, 50.70399284362794, 51.11767345859159, 52.360107744893725, 48.77839149967317, 45.582420749049035, 47.79612802690076, 50.30113797033987, 54.57914160143945, 50.497244711845156, 53.6776711094764, 51.84493580172139, 52.392267257936545, 47.54658683653801, 48.76616154947589, 48.086273593287316, 48.22650224931779, 44.76174323789535, 47.57693813693139, 51.86182160531321, 52.03865381979173, 48.985720142241455, 52.08292168955649, 58.375839033434474, 66.50581805936753, 68.5288667678833, 70.85032939910889, 66.09249438008955, 70.07778721470987, 61.72748081145748, 61.93316598092357, 60.239663047175256, 66.0526744781002, 64.96737034090104, 65.66669364129343, 61.1319669600456, 35.409985126987586, 0.9806160160130071, 4.9839920190072835, 55.87652044911539, 64.66615192351803, 63.42452956784157, 60.65019792126071, 30.685792276936194, 5.189459987225072, 21.00340189472322, 51.65914881613947, 22.18931874921245, 16.597776105326993, 22.38540784005196, 39.418286585038715, 45.160377640878, 43.91527222048852, 42.79796546505344, 58.36024761199952, 38.65382056082449, 57.22154432727445, 49.87307402395433, 46.86719702136132, 72.38117556418143, 83.98517823988392, 50.17503376929991, 0.42083700998656215, 0.34944769716070545, 0.37106053903698927, 0.2091353996506622, 0.5451509861215469], [0.045860612524613265, 0.023308883931848313, 0.04984569082397127, 0.054027060001728036, 0.012351937250294273, 0.015690341580569023, 0.07781228591357509, 0.030247146909635876, 0.09948102156481436, 0.13919010127504028, 0.17748633099179115, 41.9105488254178, 72.6510424767771, 52.03608858969904, 51.127216585220836, 34.4249681503542, 28.4405569876394, 23.697903502372004, 31.348049179200206, 43.62420489711147, 36.43843450853902, 39.25876771250079, 32.3566690183455, 36.01846633418914, 35.36144971847534, 21.21970884261593, 6.001235679272683, 7.266558956715369, 37.803540921980336, 70.0345705401513, 40.59705295870381, 56.28576878578433, 46.39947791253367, 5.991392001028984, 0.15737137486857755, 0.8144596964120866, 0.3275517091876076, 2.7220817535154285, 20.941087199795632, 59.896455657097604, 65.87052745203819, 62.84314801616054, 61.99718690687611, 63.1727251698894, 57.383165590224735, 50.25550903812532, 50.60005003406156, 54.76659951671478, 58.41865562623548, 59.14822824539677, 60.33184659096503, 54.107994341081195, 45.45526143043272, 47.941726407697125, 46.27212639777891, 47.232114730342744, 46.03235975388558, 46.84806369966077, 45.63063060083697, 46.1613743535934, 43.836562018240656, 44.059093767596835, 44.420418585500414, 47.55442765451247, 46.01268906747141, 44.01145265948388, 44.29647168805523, 46.15722840832126, 44.01250385469006, 43.13762703249532, 35.78117470587454, 23.887281417846683, 2.6961195853448685, 8.8121017525273, 8.530810936804741, 27.108102344697524, 23.943747858847342, 21.001554458372055, 12.778765290014206, 2.1861415957250903, 0.37616771014948047, 0.2383943352728121, 0.1019506362236796, 0.1156556121103706, 0.04801016330959336, 0.05638253905119435, 0.029884712627878594, 0.03070728421481627, 0.4207117086456668, 0.14681367203593254, 0.025262143838429646, 0.032274583279485666, 0.10385643315291214, 0.08363204136971505, 0.037678812645495906, 0.08563402063784101, 0.018139556275620576, 0.037261470926985625, 1.1816517672231122, 6.9853171706199655, 12.853695308008502, 10.706819334337789, 8.79119355832377, 27.034063685324888, 25.03344308945441, 15.824256270162522, 25.817154222919097, 32.73529148870899, 34.40584267339399, 39.97444729651175, 43.42084961552774, 43.076245861668745, 42.92978063706429, 39.79943898416335, 40.80800194894114, 44.95732830416772, 46.85278623334823, 47.953634723540276, 47.39105701446534, 47.37780724802325, 47.071423069123306, 45.28605430356918, 43.37909990741361, 43.38565418797155, 42.774737188892985, 42.55943436776438, 45.461243044945505, 49.25825426655431, 49.95533789357832, 48.312582585119436, 45.383011371858665, 46.64204120635987, 50.67562234017157, 57.49874999446254, 56.585998765883915, 57.121217943006954, 56.440290558722715, 63.47593615131994, 65.40537357330322, 64.27469153558054, 65.28141098637735, 61.84520290743921, 59.99309501340313, 58.62636473871047, 30.03935233239205, 4.296974664734257, 0.1754866423265588, 21.115365951291977, 49.49770319846369, 49.78382049068328, 44.892236571158136, 54.21328252361667, 13.194959163665773, 0.20093520983092247, 25.283247078618697, 29.591278414572443, 19.975648733877367, 28.71456592313705, 19.9348247051239, 28.83119760021087, 30.657317830670266, 40.46639096352362, 28.617128364501465, 40.46254311838458, 47.31144074470767, 26.591745845733154, 66.43028889932941, 43.88447376989549, 50.41841683849212, 71.05977612157022, 32.02563666528271, 0.5801037783103605, 0.22293160128737652, 0.10015540876455846, 0.04433399464394297, 0.0831707491869888, 0.09775654232550053, 0.04354090978121085, 0.07508837602912419, 0.08612973315100517, 0.04751108384000198, 0.04137034520446774, 0.11581367137090814, 0.04121816566874904, 0.03402715879342249, 0.11405980499881892, 0.23726438622801538, 55.95718791407924, 78.16279626661732, 59.32897498530727, 53.11281058096117, 34.597662264300936, 36.589018221824404, 32.08492917399253, 37.85902677043792, 38.92897482841246, 34.11565396093553, 37.087861337969386, 36.82992235306771, 34.48104627670781, 28.323556607769383, 15.094958216913286, 8.561769223982289, 9.92138529977491, 41.581893428679436, 73.1887758931806, 44.405670473652506, 59.437393219240256, 54.37738664688603, 8.660282492637634, 0.09646719336629876, 1.4981329849650784, 0.6138019636273384, 3.1921116286708466, 30.875130968709147, 64.99432094635503, 66.183760089259, 68.22368283425608, 64.16031522135582, 63.02158840240971, 59.3984519281695, 53.596117188853604, 55.03881592904368, 57.110290219706876, 62.576238570674775, 62.40914560133412, 61.867674166156405, 57.30455344723117, 49.14871031238187, 49.79295961318478, 49.242270608102125, 51.562383943988436, 48.603485168949256, 48.91148928673037, 47.86810744193293, 49.74820536951865, 48.90084789645288, 50.48852920532227, 50.43262758562642, 50.11281321125646, 49.673303788708104, 49.27250815976051, 50.37396853969943, 48.19358571883171, 48.41309332078504, 46.99376013971145, 42.40992930627639, 33.49074586745232, 11.803178671867618, 19.890803944680002, 18.78335802785812, 19.139575919797345, 17.547464293818322, 21.663581901980987, 20.035229536794848, 4.768591138624377, 0.17867198995044156, 0.2272187978509934, 0.10906956954708985, 0.04670570326608516, 0.06285479840552134, 0.12545473468039306, 0.0328666313491281, 0.010112763754272414, 0.38028531016842015, 0.2552460173084851, 0.05060332879844693, 0.07392563076028902, 0.0537878567082507, 0.10925507773795437, 0.040371623190660635, 0.05510894085971579, 0.01854506385092053, 0.1751598905050947, 1.5854990001647704, 6.6485439385137255, 12.459450037248674, 10.278093487985673, 12.253808013854488, 33.80790871958579, 31.96323960058151, 23.28240486883348, 32.24293793401411, 37.85801872130364, 41.80111861998036, 43.63987868832004, 45.885514059374415, 46.19881729925833, 47.500761785814845, 43.55755598314347, 44.5343477495255, 47.46616255852484, 49.8627503456608, 51.07737894981138, 50.41971906538933, 50.614394141781716, 48.85410108873921, 47.98626492100377, 46.873127645061864, 46.83816363734584, 45.84845942835654, 46.744689633769376, 48.23288002321797, 52.20155377541819, 53.60642125529628, 50.59914788892193, 48.32849171853835, 49.04290437698365, 53.52215697688442, 59.21480263433149, 59.582426778731815, 58.903087954367365, 57.894548523810606, 62.26500634224185, 65.12705787535637, 64.55165793818813, 66.81082156396681, 64.37213105540123, 63.453484504453606, 56.6629203673332, 24.43268502912214, 1.7866095828433193, 0.2164191797736191, 26.56043944820281, 58.57296559118456, 53.42663157370783, 53.479179566906346, 54.72799554947884, 14.0907226070281, 1.3098511268054287, 25.626168135673772, 24.54916569494432, 18.69121370777007, 31.27835454479341, 20.5676697146508, 28.237144831688177, 32.12279573563607, 40.05199255481843, 29.780438638502556, 36.73948034163445, 43.342296308086766, 36.467569874178984, 68.22018408006238, 49.82677436644032, 54.66229584909255, 77.62157194076046, 39.200802926094305, 0.5788291305784257, 0.19923568973618172, 0.047556803967323036, 0.05740669135364795, 0.03649581584238237, 0.1277050719926915, 0.13126703610102977, 0.21243474115767788, 0.1827782212245849, 0.16742205006941674, 0.17186853163425, 0.13307858889381732, 0.1976778192986404, 0.27635426771256233, 0.27328295993708795, 0.29348696612062, 67.59238519976216, 91.07824340943368, 65.51592557660996, 64.54759044031944, 49.59101246249292, 39.47329390433527, 37.88653435245637, 45.74253974422332, 59.06069271026119, 44.14767265319825, 49.92443746136081, 40.746703147888184, 45.75491874448715, 43.91488782821163, 28.08363306906916, 14.440688240912653, 18.448856338377922, 50.81039890166252, 81.36989085905014, 52.087055867718114, 68.54981222460347, 55.397540215523016, 7.916445193752167, 1.462366607400679, 2.1634717670179184, 1.2911877540811416, 3.545762819628562, 37.55923217342746, 70.2056957060291, 69.4346518670359, 69.75808266670474, 65.8978977511006, 67.93441587878813, 60.32298595674577, 56.726521599677305, 59.03883726366105, 61.314125753218136, 64.81214254133164, 65.17543246669155, 64.64770501659763, 57.694570402945246, 50.108733946277255, 54.12409959300872, 50.63691639131116, 56.30169360868393, 50.62652995509487, 55.2159462436553, 50.47477345312796, 53.271321404364805, 52.16984141257502, 52.7311247394931, 53.26478673565773, 53.81214957083426, 51.98240703152072, 53.200224522621404, 55.14895216111214, 56.365891041294226, 53.825811186144435, 55.57867919245074, 46.44126684434953, 40.66019919610793, 17.267899320971583, 26.71138794191422, 36.80884745813186, 47.81943475046466, 39.398196205016106, 32.518068667381044, 21.308448545394405, 6.0101929018574385, 0.4447032841703584, 0.4326223533961081, 0.2525779935381105, 0.17000468567975108, 0.1656726576508053, 0.20602531250446074, 0.14490622035678358, 0.2853414903004324, 0.6840350046273201, 0.3286701056265062, 0.17760305214793454, 0.19971368263565725, 0.3355467559829835, 0.13338238872107, 0.1705054926776117, 0.15374195671850635, 0.16740927172283973, 0.43148498862020435, 2.0178622319813697, 6.590298212343647, 13.30183590612104, 14.622487156621872, 26.44246239815989, 40.97980960722893, 37.182566965779955, 31.40488824536724, 38.549520815572436, 48.72482761260002, 47.30781255229827, 51.14776196018342, 51.14065462543119, 51.20768793167607, 50.74399317464521, 48.34828792079803, 46.75125960380801, 48.72991884908369, 52.24480575130832, 53.07694050573534, 52.955586294974054, 52.44816887763239, 48.90117345317718, 49.66530999829693, 48.96355090602752, 49.44100141525269, 49.42076982990388, 48.87615657621815, 51.228323521152625, 53.31622077572731, 55.1558869115768, 53.912154320747625, 51.1353398138477, 52.41160454288606, 57.74095243023288, 62.25691841494653, 63.178742085733724, 63.438493205655014, 59.155857255381925, 67.31741136120212, 66.83416751123244, 67.51461244398548, 66.9895718174596, 62.39953187204177, 63.35085568889495, 64.79468799406483, 34.19773740153159, 5.897252665412042, 0.2366114801336681, 25.844473531169278, 60.53397809305499, 56.95906716008341, 54.61578438358923, 60.669896064266084, 20.630661018433113, 2.1432823471484648, 34.06373746933476, 35.94948753233879, 27.08757265921562, 36.14695925866404, 27.790159371591386, 39.14131626006096, 41.52153207409767, 57.20111662341703, 37.14690477617326, 58.62920061234505, 58.665455079847774, 39.644473983395486, 85.3074876723751, 55.927691690383426, 68.66482396279612, 89.00728687163323, 51.8919885543085, 0.7475362165320305, 0.2406938094645739, 0.19436573008856467, 0.13568863513008242, 0.17430280665716819], [0.035478577483445406, 0.07202747172766155, 0.07537134592571566, 0.0522306144628073, 0.04024960836696048, 0.14018106664861404, 0.06339490571389757, 0.046026581642969, 0.07120195836309465, 0.05710995868749677, 1.7035732514435247, 56.356391060736875, 70.512966340588, 36.98741336022654, 27.965101003646854, 35.621459714828, 31.389145812680646, 24.52782996239201, 30.06282771787336, 42.74579009702129, 31.505442127104732, 37.85478668828165, 35.39175787279683, 35.746371515335575, 26.017728544050648, 11.318689469368229, 5.980301989663032, 6.278536463937452, 29.4238422378417, 53.15514472223098, 47.69039269416563, 51.7319283946868, 57.79418291584138, 22.69897387873742, 0.5773464133662563, 1.4582522862380551, 0.21176219256895207, 4.1340781411817, 24.120034863871915, 59.97033742166335, 62.81964909645819, 62.39846106498473, 62.533896584664625, 59.3716739070031, 53.11665058135987, 48.32548326061618, 51.64405945808657, 58.4890543260882, 60.289685033982806, 58.88288382560977, 59.86484527587891, 58.633683881452015, 51.425979598875976, 45.14236219467656, 45.660828928793634, 46.583931292257006, 49.27903498372724, 44.984161238516535, 48.36712314236549, 45.29091019784251, 44.7519883032768, 45.36771020581646, 47.48165592070549, 46.720782787569114, 48.79901924440938, 42.15498308981619, 47.87430870917536, 44.840002367573405, 46.13235273668843, 38.45424644408688, 37.24185751330468, 16.59458329600673, 5.473529311918444, 15.690792722086753, 5.570403029841762, 10.071599329671553, 12.968338343404955, 10.18387423407647, 5.83530814416947, 1.693294190110699, 0.18070299629001849, 0.029472951859896703, 0.1166343966859483, 0.04905870785155604, 0.1349872356701282, 0.06772804840077316, 0.118075538306467, 0.04069827542069458, 0.6647580874062354, 0.4446200870217816, 0.03604205047351218, 0.027173943066548918, 0.17856027900932298, 0.033314972815494386, 0.009924077256132039, 0.15426876474051707, 0.004246555599233797, 0.06495421256629691, 0.157905905056865, 1.2267940803881616, 3.373748256314186, 4.74427342414856, 1.3974671931036058, 24.048957593979377, 28.04994579284422, 16.246367039219027, 24.652455429877005, 32.49791749062077, 34.781295868658255, 40.02951345136089, 41.9374680519104, 38.9765884799342, 39.686776745703916, 42.160184152664684, 47.07170155740554, 46.680009749627885, 47.76630232411046, 50.104846877436486, 48.91101467993952, 48.291119375536525, 44.180240092738984, 46.045574218996116, 43.19172828428207, 42.862751253189586, 40.593322784669944, 41.588294736800655, 47.620817692049094, 51.096041587091264, 48.8894534111023, 51.37459262724846, 46.41262961972145, 44.26577914145685, 48.08495175453925, 55.87138214418965, 55.52158124985234, 61.47296213334607, 59.124372390008745, 58.571533926071666, 56.42115331465199, 63.10359731797249, 64.94627191174415, 67.0149338629938, 49.08211631159629, 25.47364284915309, 3.8057311407981382, 0.07100399358258133, 1.8816687142656696, 32.88441411910519, 61.588828948236284, 62.605275877060436, 49.3997420034101, 47.82487507789366, 6.478477322286175, 1.191582473055009, 20.564775005463634, 33.376973598234116, 22.607043327823764, 33.156654065655125, 18.406182912088212, 32.07377591440755, 29.502664227639478, 35.31151794618176, 41.23090013380974, 29.001269609697406, 40.032820009416156, 34.29005038353705, 24.976788374685473, 23.723132187320342, 48.64400717519945, 70.63926666013657, 25.495451227311168, 0.537128268230346, 0.05717789153418234, 0.15169201268544122, 0.012625039934421019, 0.05705191220547404, 0.052279448737540556, 0.01789606288976727, 0.10199761273519647, 0.07994098378525627, 0.028578546123519063, 0.1034336215666225, 0.0721965549934295, 0.021824701576523726, 0.09013593632487521, 0.06561631171573555, 2.246497311899739, 69.31563146652715, 78.4540165624311, 47.40274959994901, 34.26627297555247, 39.943864576278195, 38.391563046363096, 32.30782570377473, 34.94899288300545, 39.910285165233, 32.7642640759868, 33.599556338402536, 35.906980806781405, 34.906164523093935, 26.21618478528915, 9.455223371905666, 6.844194214190207, 10.03599891739507, 35.906321848592455, 57.22205031302668, 51.6101937140188, 60.02090461792485, 63.27637380169284, 27.845604035162157, 0.9057589295891024, 1.6516226842518777, 0.16369173813971782, 3.8684226284104013, 29.361706010756958, 64.86726360936319, 65.3090911526834, 65.73764931771063, 64.14434333001414, 61.73605903502434, 53.98657345002698, 51.57797536542339, 55.815413844200876, 60.7865708874118, 65.03182664994272, 62.07778769154703, 61.894789511157626, 60.92427745942147, 53.201609119292236, 47.37200214016823, 48.872673511505134, 49.88885371915756, 52.91891605623307, 49.23593598027384, 51.85986042022706, 49.8190119958693, 48.63785297639909, 49.15385253967778, 50.448791673106534, 48.69679443297848, 52.77533769607545, 48.84788805438627, 51.985395877592026, 48.78647158222814, 50.5534169750829, 42.691892808483495, 42.2456447539791, 23.10735341041319, 14.701645489661926, 24.479118047222016, 15.612868955058438, 15.368233669188717, 11.06488662381326, 15.126477403025474, 11.743679258131213, 2.643654207068105, 0.0654604358057822, 0.10976973560548599, 0.15013293182897955, 0.06275636376813054, 0.11865772682452395, 0.02641838502078768, 0.009509073063400725, 0.05465207283475226, 0.18927357429938932, 0.4848385385928616, 0.08736108159345966, 0.02570289337346631, 0.06467480497855334, 0.0827130269739897, 0.022641575384524562, 0.06774645749359362, 0.04160279543289254, 0.14383607213535618, 0.10403542959642026, 1.7246708225819374, 3.9272574455507345, 4.632072554480645, 5.063367553295628, 31.97276507654498, 35.7989901111972, 22.58944561404567, 28.51945938602571, 40.85106957343317, 41.582395492061494, 45.54262438128072, 44.66719842726185, 44.2897879692816, 44.87808858194659, 45.212164694263095, 49.51675415039063, 50.047191958273615, 50.82604523627989, 51.4313454012717, 52.63027275762251, 50.06827469794981, 47.958678891581876, 47.424244188493304, 44.04482810728012, 45.48650310885522, 43.03817925914642, 43.803370921842514, 51.16191779413531, 53.24908548785795, 53.655231229720584, 53.68735544143185, 49.718548328645774, 47.32281561820738, 52.25181110443608, 57.69092652105517, 58.73892107317525, 62.27455339124126, 62.296942280184844, 61.957402306218306, 57.44154614786948, 62.18248751855666, 63.04561684208532, 59.08927894407704, 40.69777942472889, 16.54451031838694, 2.7922544267869767, 0.3091187757109442, 3.0463673847336925, 40.705694767736624, 66.88608400283321, 72.99283781359273, 58.31920000814623, 50.0883533108619, 9.120565768211119, 2.0607863222399065, 15.450907426495707, 26.600769258314564, 23.404333706825014, 33.69371283438898, 22.80567607572002, 32.38918350588891, 29.47355631859072, 36.62213479318927, 32.96527378020748, 33.160541134495894, 37.50640961431688, 41.09109901612805, 23.241567111784413, 22.569849452664776, 59.52712135930216, 78.95675459215718, 33.53775155159735, 0.568933297068842, 0.13222732731411535, 0.15312675747179216, 0.03733314611318131, 0.07401699440613871, 0.13432415592814648, 0.10974362732902651, 0.2943369866378846, 0.09176224139669249, 0.14200190442704386, 0.29130661860108376, 0.2133459261348171, 0.21093503211534795, 0.17599710203226537, 0.1881913218887583, 3.1116616101034227, 81.14035375656621, 89.77311395829724, 52.820162542404674, 38.621174673880304, 51.19659546882876, 43.04179568444529, 37.97187728266562, 41.065160382178526, 56.1290700974003, 41.01915098005726, 49.51383590698243, 46.66406139250725, 44.95389623026694, 32.50716840067218, 16.10984992596411, 13.568625719316545, 15.688245142659834, 40.25454767288701, 65.33908551739108, 58.50778756603118, 62.363336240091634, 69.7695359876079, 27.209130833225867, 2.1309969934724995, 3.953678776179591, 0.9667642883235409, 3.821816045430399, 36.07735287758612, 69.7812952533845, 66.55825230383104, 69.5651569674092, 64.33652377897694, 63.62570008923931, 58.201085675147276, 56.940937965146965, 57.47203865358907, 64.530963513159, 68.85560804797758, 66.17076135450795, 65.83974469092585, 66.07282761604556, 55.162990323958866, 49.90510802115164, 51.88495574458953, 53.52389458687075, 56.436191681892645, 52.609931345908876, 56.19043950111636, 53.09477944527903, 51.32010698318482, 54.045507061866026, 54.65705556254233, 50.00309275042627, 55.36433342964419, 51.086270962992025, 57.01257221160397, 53.16200494766236, 56.78900103415213, 49.29390468905049, 48.918204384465376, 30.198684892346783, 19.761732470604684, 34.80054686146398, 25.728549841911565, 36.57918091743223, 20.757381031590125, 18.060157299041748, 14.166818549556119, 3.3644885209298905, 0.27961084619164467, 0.19145687891831323, 0.2290709379820093, 0.18280325697795038, 0.36187214176020316, 0.14962087866039048, 0.22604519711627116, 0.1385001318469163, 1.240614551690317, 0.8428004143699523, 0.14129422304611053, 0.18189976352357096, 0.2155924636510111, 0.15452200276476724, 0.10989153592456734, 0.24794503085074887, 0.10404432387722116, 0.201748626667165, 0.38706920259902555, 2.084190369613709, 4.897886187799515, 5.378609424637211, 13.337388269362911, 39.99306286534956, 41.54797669379942, 29.377995614082586, 35.60068684239542, 46.41152743370303, 46.53858477069486, 50.14250947583107, 50.01010594829437, 48.50781071570612, 48.42631563063591, 46.673506459882184, 54.774091243743904, 52.50721623820644, 53.709893380441976, 53.697718343427105, 55.00191034809236, 50.65575161287862, 47.88567181556456, 49.01942506913216, 47.645795345306404, 47.38124716666437, 45.814221059122396, 48.70463132858277, 53.500113256516, 55.44902132403467, 56.19704869485671, 58.06594041086013, 50.92787781069356, 50.60733779784172, 54.27359680975638, 61.860574676144516, 59.94492438531692, 66.7767204776887, 62.57798794777163, 63.06400883582331, 59.9365383578885, 66.07621654387444, 66.25781443811232, 69.0174215070663, 54.360245889233006, 29.168870525975382, 5.684779834362769, 0.42684111684080095, 2.981659798852859, 42.64312598013109, 69.06480373874788, 70.78018173094719, 56.910594509493926, 55.79667275951755, 11.226079367822217, 5.533942637904998, 28.551267846938106, 34.95398606023481, 28.189580209793586, 42.143459166249926, 23.082695430324925, 41.53481321950113, 39.808523193482436, 49.597013688856556, 55.05498393889397, 39.67430753092612, 52.378413446487926, 45.869204844197924, 33.09171530508226, 32.17291185932775, 71.82983152327999, 88.67599564213907, 46.57420773659983, 0.6656197831034661, 0.35955395970133047, 0.2947368232473251, 0.21473150339818772, 0.2033277943490013], [0.03657280767877256, 0.056712830198868636, 0.05367762814726561, 0.0267917437163452, 0.049326903742527774, 0.030102779555525032, 0.1008369971907908, 0.06897230542475177, 0.08084047826067095, 0.14422716002070135, 0.7379327834613862, 50.25169257194766, 66.46515092542096, 35.29429481875512, 35.4895660954137, 36.98616604651175, 36.75734281539917, 25.249573530689364, 38.30050522281278, 39.74845601666359, 34.45203642691336, 36.07268917945124, 43.67945148098854, 34.718090795701556, 27.151974055074877, 7.682427763938905, 3.345334116489657, 8.146173511782, 35.8133420636577, 62.27628707885743, 46.671380535248794, 57.08437904234856, 58.07093751045966, 42.1628592091222, 2.9477577728609887, 1.717614356067873, 0.6619555539181156, 4.140820695507911, 24.817402862733413, 59.580418525203584, 64.12566500325357, 62.53010757507817, 62.17218737448416, 57.404240485160585, 47.91959247281475, 50.35730238883726, 54.90406682414394, 60.09086793468845, 60.11127210432484, 62.26929349284019, 61.16958248999811, 58.7882056543904, 51.62300417500158, 47.44894335346837, 47.60135881362423, 49.084987486562426, 53.14993973701231, 48.718426304478804, 49.29008037813249, 46.05830231020528, 45.65529054211032, 44.402603180177756, 47.45741959541075, 47.39164536999118, 49.46507692337037, 47.52272313640964, 47.43885501738518, 46.28021040270406, 46.188097461577385, 36.68292760848999, 33.30462940277592, 10.01591932389044, 11.682131386572316, 12.496717456848392, 12.876171469688417, 0.7089463453139029, 3.046866261189984, 2.6220269933823617, 2.142590048813051, 0.2126067738619543, 0.04059500293806195, 0.07098932299883136, 0.028837347861319303, 0.11633847990343649, 0.01755069896218277, 0.033364933239476334, 0.044833472479254975, 0.07639997218164706, 0.09693043907323191, 0.1625324785709381, 0.043042412538441925, 0.02192397124975199, 0.10129654269304969, 0.12340694335439514, 0.027580835345772006, 0.03636142486826547, 0.008291976729167566, 0.07737758464270061, 0.08813197288902537, 0.07411177480413068, 0.1797881800561182, 0.28718350274908927, 0.7802709083883994, 18.27624067183464, 33.33895798652403, 19.831281977315104, 22.673607910833052, 31.26746604519506, 34.035567006757184, 40.087788105010986, 40.77799189475275, 40.49802487896335, 42.10946790633663, 44.85208326770414, 45.56056530244889, 49.2395680950534, 47.448045130698915, 45.93238246056342, 47.28201904604512, 46.84517683521394, 45.86953040092222, 45.99742712513093, 41.75142611226728, 42.42096293357111, 42.590107302511896, 41.37487465335477, 49.194170582679014, 53.730089664459236, 53.03692840760755, 53.61179882480253, 50.42353945393717, 43.73514913743542, 47.94968097440658, 52.46928299626997, 58.87096766502627, 61.56307466568486, 62.630912488506695, 61.56980545290055, 52.64558176840506, 55.58442938712336, 46.95856078978508, 15.996429689468878, 6.868952705014137, 0.3844040133539708, 0.05792852363459045, 0.7052802162305002, 6.477631070921499, 40.934623902843846, 54.35839845288185, 33.84766586365239, 34.51064055965793, 58.0763150799659, 12.545312681505758, 2.1714003480249837, 4.76157009601593, 38.111360688363355, 21.339111674216486, 41.57716305025163, 18.198548324646488, 25.772682389905377, 35.263351240465724, 31.502967111526, 38.20251264879781, 24.632492526885002, 32.50154568303016, 25.643799189598333, 49.348739424059474, 51.16423983727732, 50.940311724139804, 72.27132566513555, 20.776579072398526, 0.6965738414756714, 0.11400429426782555, 0.07323754590845878, 0.0806675109291269, 0.02251253744977857, 0.015991771323305946, 0.10621760040521623, 0.08908905419370822, 0.004334458921690502, 0.025118931361864653, 0.02790156954659089, 0.03823116969978137, 0.08889017010768575, 0.06168924542444368, 0.09155212646170009, 1.6335134688884982, 60.87062728020453, 78.16915050629648, 40.450234720783854, 35.646908052505985, 41.4273638110007, 40.35076733558409, 31.024869411222397, 38.24333667755127, 37.5468296389426, 35.874589873898415, 33.363370818476525, 40.92466892734651, 36.94551067967569, 29.252824937143636, 12.75140577746976, 4.866674907745854, 10.672332875190243, 39.085810799752515, 64.818637986337, 47.806965535686864, 60.228519593515706, 62.84359516636018, 49.82344427416402, 5.015747037626082, 0.6914486519752011, 0.19809703793256514, 4.422765566456703, 30.039658277265488, 66.13181221869685, 68.98985508949526, 64.27739404862928, 63.3376020000827, 58.664403884641594, 49.786115077234086, 53.7208995511455, 59.695920559667776, 62.146860630281516, 64.21236115117227, 64.40562417430263, 65.07451380452802, 60.72865709181755, 54.911601697244954, 49.033412241166644, 51.04201093796761, 53.40461138756045, 53.94949920715825, 52.52207809878934, 50.94066473745531, 49.25533602314611, 49.85846711743263, 48.1886003863427, 50.66892293191726, 51.18270635604859, 51.468203913780954, 52.66682924762849, 52.8150438493298, 51.436770039220015, 52.43194203222952, 43.006255088313935, 39.98995242580291, 18.75930997633165, 20.700857716221964, 22.947159890205633, 18.736352343713087, 6.140479330093631, 4.482715562466653, 5.41787087917328, 3.39882813634411, 0.20634592030077212, 0.11005235310163229, 0.06918399083998895, 0.03037406278083161, 0.016979597651609973, 0.07387125383942358, 0.015715184854343534, 0.07074530867318954, 0.022026853027543234, 0.39101332966839114, 0.24839872344126626, 0.06625393435599343, 0.022709054324114998, 0.14251519865807027, 0.07589142769575119, 0.05309184284640416, 0.009797514742991377, 0.01988837029784918, 0.004177826978716879, 0.21749101338847993, 0.047507632613903096, 0.3243617497144207, 0.6313478898617529, 0.47138465568423277, 24.610352708447365, 39.85530138015747, 25.982560573085664, 31.44875603337442, 37.67565596488215, 39.67867312892791, 44.315659922938195, 43.33946827919253, 45.11697661492133, 46.00843721820463, 49.121571433159616, 49.49955455718502, 50.67055856027911, 48.97132896607923, 48.37361466500067, 50.389548194023874, 50.722628024316606, 48.498530387878425, 48.25857939258699, 45.401979954011985, 45.411377952944854, 44.86124200205649, 43.67015938605032, 53.07477535740022, 56.07828324840915, 54.939305397772024, 55.354554960804606, 53.210956127412864, 46.50266370465679, 51.34280573937201, 54.15380370232367, 59.389281426706624, 61.72144428376229, 63.2879134147398, 60.44542666404479, 56.32232527579031, 56.048104532303356, 40.82438176678073, 8.096612403469702, 3.0068173908418228, 0.2521775747018476, 1.1541711514995945, 1.0411600672429608, 9.415776095082684, 47.63843697886313, 53.00150156021119, 35.289631120620236, 39.21322115005986, 61.74468824940344, 21.19580395760075, 4.655651882771523, 4.755622802242156, 41.188263970036665, 23.56616089420934, 37.00238504717427, 24.481218476449293, 27.749492237644812, 30.324410584665117, 30.519779920578006, 36.4352063978872, 28.932934076555316, 31.924547380016698, 32.85996598582114, 49.12904747070805, 49.0194760599444, 59.67436321320073, 77.7094957905431, 25.145046287967315, 1.115976213928192, 0.240168257826759, 0.21549089571400998, 0.05200609707483842, 0.0753893030266608, 0.17970197984287817, 0.19256476463089067, 0.26033300966505085, 0.15228116494272986, 0.09180875825545481, 0.13830808892605767, 0.3948865169959684, 0.35782474603864456, 0.1910035540499995, 0.3806858822222679, 3.197344070480716, 75.9547842702558, 87.62202339787638, 47.26820053592805, 49.50790136091171, 48.85549745252056, 49.47886013215589, 34.9311343316109, 50.97516198312083, 52.29008559257754, 45.32918468598397, 47.85551271130962, 58.20554933240337, 45.20343742062969, 34.36029611095306, 11.214335791526302, 12.01976901100528, 17.041303996116884, 46.30790625849078, 70.5589129847865, 56.03174824868479, 65.09455319373839, 67.28158443204819, 47.607713053303385, 4.769273631034359, 5.986859211998602, 1.138188105917746, 6.082123777558727, 34.1625851200473, 70.05401765146564, 71.30926239875056, 67.30166696733045, 66.77105657515988, 62.570708028731815, 52.12370257223807, 57.331198107811716, 62.085875618842344, 66.15806856463033, 65.38480858648977, 66.92061654983029, 67.75965859813076, 63.3434110303079, 56.108673772504254, 54.56569963885892, 54.81320904147241, 56.014254477716264, 57.078287601470954, 55.373331346819484, 54.69817376905873, 54.6862615308454, 52.582337471746634, 50.951666985788655, 54.5683668505761, 53.43977151378509, 54.77975514627273, 55.16526922102898, 55.00517376007573, 55.98433071567167, 59.45279636690694, 49.044630219859464, 46.22989031576341, 23.963073376686346, 26.434201886576993, 34.68134995429747, 32.40324716414175, 19.45922947699024, 6.816498848699755, 7.566409447500783, 4.144644025833377, 0.5621168305796962, 0.15842424014643317, 0.11380415379760728, 0.1672855944883439, 0.22017555401450206, 0.23987265514029613, 0.1336395184719755, 0.1697833015913925, 0.23642840044152355, 0.9706991610507812, 0.8623094255885771, 0.10833722779587393, 0.08004714058892382, 0.2781132055867103, 0.31068928659923617, 0.1159657015194816, 0.1276732333785584, 0.07751522766005609, 0.21219138566765094, 0.3607346544102315, 0.21028883695121736, 0.4252271534454438, 0.8076701962178754, 1.7754169769825476, 34.71031665802002, 45.461560756929465, 32.88717742889158, 38.63874689225228, 42.64327503019764, 43.81604409986927, 49.682156578187026, 47.73242481293217, 47.95876518372567, 48.859584562240116, 51.45562879500851, 51.2985457143476, 54.93043299644224, 52.97480983118857, 51.06024603689871, 52.9542762233365, 53.27508687973023, 53.22531592461371, 52.51631221463604, 48.03221156520229, 47.8842205386008, 48.470901212384625, 46.294279944512155, 55.74004550133982, 58.381310739824855, 58.50364162075905, 59.39390590113979, 57.845020755644775, 48.813594771969704, 54.33085949190202, 56.78890689726799, 63.36182263589675, 63.85382906083138, 66.15551117927798, 62.033763008732954, 56.80117999353717, 56.17390671084004, 51.13007599307645, 19.209064629770097, 7.920697533315229, 0.6447367165838519, 0.6280026596880729, 1.075635249576261, 8.06136304332364, 50.8469004784861, 63.70304922903738, 42.86087243787704, 42.84037413135652, 67.73988200772193, 18.243547716448386, 6.749091936695961, 8.723242417458566, 44.859735811910326, 25.516212332633238, 53.876539199583, 23.766684224528653, 33.04914582160212, 45.65596518977996, 44.549762664302705, 53.28051544004872, 32.36296638365715, 42.61219809132238, 35.713870756087765, 71.56806038271996, 62.01428059608706, 71.70286440080213, 89.024717884679, 39.206133427158484, 1.1588479650597419, 0.3868008879644256, 0.37895676049013294, 0.1803001106506394, 0.24076818128026303], [0.01847074757660589, 0.05158089146378541, 0.06809194016480638, 0.05127507299485226, 0.06552409771228991, 0.04121728466763612, 0.03304994086764994, 0.027380938108469692, 0.11748201934800995, 0.13381945720363048, 0.40234306526760905, 51.45429911152009, 60.463673530086396, 43.02871850229079, 37.57891854932232, 29.462526613666167, 39.195397899996856, 27.93736396297332, 40.75592856253348, 40.64989905203543, 37.55463515558551, 33.34220570902671, 39.776010667124105, 29.65026890077899, 29.378285869475338, 8.932987240052993, 2.260442808751137, 4.106093746039176, 25.41886498851161, 63.779272648596, 51.63463008019232, 57.7638747615199, 59.47203559260215, 44.565911062302135, 9.012651558845274, 0.8987550473501607, 0.3066205629898656, 3.099587819268627, 27.942129642732684, 66.75901489873087, 63.38561965573219, 63.7480309701735, 59.99566024349582, 53.10795468668784, 50.70578928916685, 53.448694905927105, 56.83765019139936, 60.3632765431558, 62.20237393533031, 60.15601850325062, 60.833411832009595, 59.040790604006865, 52.10623233549057, 44.54817018201275, 46.03793736427061, 50.6237764512339, 53.604848384857185, 52.44107330999067, 50.49335372063422, 48.05370615374658, 45.91119773926274, 43.47640606664842, 49.69168401533558, 46.54118922448928, 47.2001709476594, 49.62410157726657, 48.78675791525072, 45.753840092689764, 44.21928336543422, 36.39664165435299, 28.982320639394946, 10.584707125540703, 17.541898450543805, 14.759662247473194, 13.562931418418886, 0.40486193171912627, 0.016414106019862717, 0.15715501631700224, 0.050283502411818316, 0.11613120715464316, 0.03365251115493236, 0.06627726173328777, 0.01221832672825023, 0.0891589060906441, 0.05444936213954803, 0.016470438380154873, 0.03734602405118846, 0.04062932367706972, 0.1916514346075635, 0.5224054679274559, 0.01923685273786466, 0.03132324380379531, 0.01692337828928665, 0.10639557795178507, 0.04757847276426131, 0.0501086428431013, 0.036120639603224494, 0.08193470462555848, 0.037888192136081, 0.061985951277517506, 0.10267220677868014, 0.1512437593191862, 0.4828212758706462, 11.477079679889064, 36.5227105540614, 22.483741660271924, 21.05430837600462, 32.84449027430627, 32.758070653484715, 38.968127927472516, 39.22566683061662, 40.80007091645272, 44.636333296375895, 45.91130364325739, 45.88669469279628, 47.7937549929465, 46.822525147468816, 48.94783396874705, 47.894281418092795, 45.06705660973826, 43.67649401387861, 43.56281980391472, 44.3348716920422, 44.147021539749645, 42.73670588770221, 42.2262054874051, 50.928489700440444, 56.069324554935584, 55.097635792147734, 56.01068119848929, 51.810038474298295, 48.95015993425923, 46.256786008034986, 50.54472892515121, 55.12227612157022, 58.08088071884648, 60.26977116061796, 63.36799644654798, 57.746918355264974, 58.56058659092073, 15.362974751380184, 0.3659628674147591, 0.22928746507292797, 0.13577189356569322, 0.7027977849206617, 1.517269371017333, 23.137371309341926, 60.147616786341516, 56.17951962255663, 34.4015908241272, 56.152400355185236, 55.76124198975102, 43.67215587246803, 5.4768623459723695, 3.3546215536132937, 37.88769929639755, 23.663125807239165, 41.241443464832926, 21.601975194869503, 35.30481461555728, 32.60232902342273, 29.629080257108136, 32.229670516906246, 32.21512440712222, 42.84381012762747, 32.33756315323615, 28.52502719048531, 36.65892270303542, 51.68450301693332, 63.991115939232614, 8.55918045966856, 0.5230104935265357, 0.14446023461078444, 0.14936163450681395, 0.0680000938835644, 0.03197286912660686, 0.06052448534436765, 0.08247695698012268, 0.039236721387433435, 0.07045106196235265, 0.1078812905677384, 0.07816244172112596, 0.07714588901088124, 0.09240891919621537, 0.11543011412985864, 0.013451463028398013, 1.4796684273789007, 62.69642783749489, 71.1901713955787, 46.11506685133904, 39.33925082606655, 34.74177798917217, 41.555205622027, 31.985546119751472, 39.85469733515094, 39.74745973463982, 35.99285717933409, 34.845050073439076, 34.13537171579177, 33.97950456988427, 30.086161898028468, 17.220915209862497, 6.896391155258303, 3.756352177550716, 27.01419884158719, 66.0149569665232, 58.30510300974692, 62.20478227061611, 61.958398588242076, 47.41150433017362, 11.233012157101786, 1.864645750291886, 0.7988616559774646, 2.9592196739489034, 31.71549877812786, 69.47233799965151, 66.49308604578819, 66.34621681705599, 61.23432513206237, 55.592740889518495, 52.278596970342825, 55.708101718656486, 61.12879768494637, 63.94245109250469, 65.13865632395591, 62.23726341801306, 62.30373974769347, 60.88417906914989, 54.00333373777328, 47.90609559705181, 50.702019891431256, 53.23513753952519, 56.6113765008988, 56.080534688888065, 55.06646863875851, 51.145118282687285, 47.714597640498994, 48.12201423029746, 51.454761951200425, 49.6773006839137, 53.43557065533054, 51.90943917920513, 51.54605119459091, 51.628271918143, 49.569431581804835, 41.7823383115953, 33.45928453630017, 19.7658529204707, 25.635926992662494, 24.21129861185628, 25.167735238229078, 2.234689751940389, 0.12535899667249573, 0.3267046610914892, 0.09156508866937892, 0.07879601941714365, 0.028012966391660517, 0.048624933547069954, 0.064045655270738, 0.13163822102210215, 0.08552135974769631, 0.03491208993739659, 0.051703580444858926, 0.05530538112525979, 0.2443351019774714, 2.4003858672034357, 0.10216562347787042, 0.03621125248290839, 0.03009342753718938, 0.02801704772507712, 0.028514972317122647, 0.022901802045863964, 0.07952291428321794, 0.1128877824052207, 0.0552354219760145, 0.021424901356259664, 0.178394160503822, 0.2818318883017186, 0.8133704419578276, 13.503402586906189, 40.874293927223455, 28.517102041552146, 28.61219402282469, 40.25588520111577, 41.22801719173309, 45.86727111570297, 45.16901077762727, 44.49245683608517, 46.49991412316599, 50.363660550886586, 50.92859168206492, 49.112428388287945, 49.84711185578377, 49.22533773606824, 50.483124179224816, 47.56155852348574, 47.318916782256096, 44.527099209447066, 47.04952055408109, 46.232773257840066, 44.131834122442434, 44.307815182593565, 52.43702150160267, 58.13197351271107, 58.56229674431586, 59.72668370892925, 55.54176968912925, 49.45135255013743, 48.993282471933675, 52.92062228725803, 57.231966064822295, 60.85274911695912, 64.75117714174333, 63.017571895353264, 59.409634605530776, 59.48041377529022, 13.046213080806117, 0.3995246277941812, 0.33417889067242224, 0.4279338033689607, 1.5604715818359007, 2.583266866783942, 28.898126963646185, 64.04295398342994, 61.489110531345496, 38.53150929174116, 54.81252262669226, 60.91762511960922, 48.44873589854087, 4.750736999896265, 6.618105855680282, 45.03548152985112, 27.97085512068964, 37.71674671480733, 26.079670613811864, 32.91974682961741, 28.657687633268296, 33.46867861286287, 35.553810596466064, 34.6248992027775, 41.75873741026848, 33.793831333037346, 39.449822441224136, 40.631079519948656, 59.7125514091984, 70.76773212802026, 10.783335951066787, 0.7170251408411611, 0.1869711583299983, 0.12488137149522383, 0.14108914130878064, 0.07905424467378086, 0.19917855489878886, 0.15845990920018765, 0.240539304852005, 0.20295572076593676, 0.2606622436113896, 0.14899397359019326, 0.22911593798668156, 0.2852085587238112, 0.3166503699556474, 0.2652090060855112, 2.96424251410269, 77.6966304163779, 81.955775291689, 58.78031776797388, 54.51831740717734, 38.4061699528848, 54.03755249515657, 37.870503625562115, 54.577607954702074, 51.04314842531758, 50.107784732695556, 43.83942927083662, 55.33385269103512, 38.144893030966486, 36.650328789987874, 11.986371990173094, 7.996934190873177, 12.510831125320928, 36.86258392949259, 73.8797406227358, 62.710803324176425, 68.95751122505435, 68.64003458330708, 52.671477256282685, 13.106451861320004, 2.878025140493147, 1.4948321878910067, 4.965508830162787, 36.2800492009809, 73.13786352834394, 67.77024115285566, 70.1728105545044, 65.99596485014885, 58.20587488912768, 56.61201584723688, 58.69150746253229, 64.30773750428231, 69.2270565032959, 67.51767189271989, 63.972872995561175, 65.7430111977362, 66.46736314219814, 58.52104125484344, 50.203117939733694, 54.04182003390405, 56.1961426273469, 59.359220381705995, 59.065842782297445, 58.813395115637014, 54.349227951418975, 51.49624101577267, 52.3051945624813, 56.45125750572451, 51.803852896536554, 55.26557207107545, 56.35246476819439, 55.48051011177802, 54.233129716688595, 54.746367931365974, 48.19989681243897, 41.96032370290449, 25.91404461091565, 33.40803876999886, 35.44010892991097, 38.706533293570246, 5.576086053925176, 0.13377542246974286, 0.7333241210829827, 0.2787830422241842, 0.20743306035236006, 0.11227719500781068, 0.16568528277979744, 0.13886915640004222, 0.19536902947771936, 0.18225945712577912, 0.08981882188949855, 0.22299408341848084, 0.16991054879561548, 0.8617284857938368, 2.095972679315075, 0.17899786843167198, 0.10415142296903557, 0.141652537690055, 0.15494921935662148, 0.21752036987773835, 0.18225380339689795, 0.21725121254642166, 0.2404303977926893, 0.20207744692602467, 0.20429056768696155, 0.2975364456013326, 0.3043072532501913, 1.2662282417858801, 20.70407602094835, 47.484323132422666, 32.8536529310288, 36.272675145056944, 45.672752934117476, 45.093822863794145, 49.380455709272816, 49.167478853656405, 46.66492039157499, 51.3130820182062, 53.111865289749645, 52.95404088112616, 50.62426282513527, 53.61082607699979, 53.59681929311445, 54.417222238356075, 50.4207153474131, 52.30881098778018, 48.042150851218935, 49.70851882811516, 49.459483623504646, 48.65666466374552, 47.56194291576263, 55.23379695030951, 61.11366125845141, 62.722621425505615, 62.85588395211005, 59.09806505326302, 53.20735931396485, 53.12024347243771, 58.10052394866944, 60.34849705234651, 62.787034588475386, 64.85105245344101, 64.77746878900837, 59.54508189232119, 59.28925314257222, 19.761563808687274, 1.3938283367503075, 0.9800589168744703, 0.6393463993745466, 2.51823470477135, 3.537260837131931, 27.84706904042152, 68.08144200232722, 62.2173652341289, 42.51736302529612, 64.52953184804609, 66.04440612177696, 50.79872985039988, 10.568580300577226, 7.547122172770962, 43.84248871957102, 30.64730205843526, 54.25305927953413, 27.287019298922633, 46.5827271246141, 42.25434849339147, 41.841542566976244, 43.000387222536155, 44.292266907230506, 57.95305459730087, 42.32881076874272, 39.70691419416858, 48.4396359997411, 72.77328706556752, 81.56630746779904, 17.707194974345548, 1.223308686767855, 0.5886003062609704, 0.28671254253675865, 0.22873358350367318, 0.19947584297868515], [0.03947234321986476, 0.03732440121952565, 0.04262235120780045, 0.018777741990502805, 0.04842802596789214, 0.05321203055040491, 0.03396449280121634, 0.015729907149028395, 0.06290669703195173, 0.03760154501745298, 1.2085850897335237, 61.85687980344219, 64.41810515619093, 37.23678981104205, 37.9210590547131, 34.37785263984434, 36.8641254209703, 27.694598667083252, 42.24682538740097, 41.540849747196326, 38.40979030055385, 29.63754669312508, 42.77526670886625, 38.95478794651647, 32.40283139290349, 20.849272358802057, 2.694554314497979, 1.7530464741491503, 9.351733596094194, 56.50856725631222, 43.56600476849464, 55.27566040715864, 53.968577615676395, 44.697698777721776, 13.633350710715018, 1.4630095083867352, 0.1532808024316065, 2.596760310472981, 29.903514769769487, 63.57451315849059, 62.351404390027454, 62.71960120047293, 56.62754843311926, 53.23895400570285, 49.8067702785615, 56.53177984299199, 59.56499576568604, 62.79671107569049, 60.87807586116176, 59.74847639760664, 59.854129360568145, 58.48956815658077, 53.50908371710009, 46.353503811743956, 48.62945910423033, 55.382654820719075, 56.77472752909507, 56.06445297118157, 51.65509700775147, 49.63107162906278, 45.081592913596864, 44.971339010423236, 47.708906281378965, 46.09168560274186, 49.80054939946821, 48.968893174202215, 46.64850135003367, 46.21531478820309, 42.558128218497004, 32.23384784113976, 20.615295133283063, 9.331090161877295, 21.471858409143266, 15.411383663454364, 15.793787298663972, 0.9490056960813461, 0.029891762552001787, 0.1284747988346123, 0.011281380129437293, 0.040544820348581964, 0.05396170504090767, 0.07040014009802573, 0.051327055890954314, 0.10007769680551945, 0.043246398770040086, 0.014204345512083702, 0.0047158864383105075, 0.02847062348718605, 0.17751389483530677, 1.1359121506252596, 0.2723098750556669, 0.0495831984575958, 0.028814677404420033, 0.05837285463067313, 0.020683186519290173, 0.05496806878175947, 0.034945154292208534, 0.04130120959974105, 0.05693166321443935, 0.05211940913971874, 0.09109766778325842, 0.06899076048284769, 0.07589669071979101, 5.236999113713542, 33.00831394810831, 24.947268616768625, 19.59698115625689, 30.9971421764743, 33.022261896441066, 37.77388780347763, 40.11571145826771, 40.43706340174521, 44.38036726367089, 45.02862914916008, 46.412570784168864, 46.86077217901907, 47.608109212690785, 47.157307286416334, 45.23224722954535, 43.917966888796904, 44.93171914931267, 45.08311087085355, 43.88445808041481, 42.972110855963926, 41.61495116449172, 43.89760978760258, 50.13168373415547, 53.87019280464419, 55.80100697855796, 55.94576989450763, 55.81458230172434, 52.21875729099397, 47.436525129502826, 49.04905857578401, 52.785414265048125, 59.30787655615038, 60.07623749394571, 62.077709244143584, 62.284155353423095, 64.0479040145874, 8.241116442987996, 0.3262323832079288, 0.38855164401954223, 0.16188193202739762, 3.46285788762954, 6.334015938543505, 40.62955371795162, 55.92183951408633, 43.7794993769738, 68.6635374253796, 65.1616806368674, 57.190106530343336, 37.949304042323945, 0.5073268351054961, 6.288388967514039, 29.529332422441055, 27.999557064425563, 37.63215295730099, 27.083267857951505, 34.095465521658625, 30.263633458845078, 24.176471887096284, 42.888109376353604, 29.739247868137976, 31.567472450194824, 41.25800371170044, 26.80623281386591, 28.443116334176835, 56.511407052316976, 61.581796138517326, 3.310724347829819, 0.06682634759213656, 0.0788167727390124, 0.08821387534901019, 0.07825213529530071, 0.05188292545837261, 0.040863516755522265, 0.030377544650447466, 0.12255537533952345, 0.06127388404321767, 0.07647601406901114, 0.05783417224583607, 0.10352281718364648, 0.05513902130206266, 0.04789700446229789, 0.049414345018205144, 2.007107583265151, 71.84146527321109, 73.34272107770367, 42.60327862155053, 45.61627080363613, 37.83210754394531, 37.4505550630631, 32.046015339512984, 41.29044955776584, 42.69430506613947, 38.65293410516555, 33.243656158447266, 39.66507427154049, 34.73789876507175, 34.43882980654317, 20.202983425509547, 7.10443219830913, 2.943180366869896, 10.72622428017278, 59.51146717994445, 47.76629055699995, 58.703521682370095, 60.6344025365768, 48.28696950789421, 19.29149716131149, 1.4006894202001634, 0.04260000442304919, 2.8640058540528823, 33.250571297061065, 69.11817935205275, 63.71407108922159, 64.28561533651045, 57.224282141654726, 54.956473612016254, 53.05297482398249, 60.945979933584894, 65.04804565060523, 65.30571399196502, 63.525852234132834, 62.135524980483524, 63.33270688210765, 61.286355372398134, 55.74298335659889, 48.33099419070829, 53.885372377211056, 58.90605326621764, 61.40802729514338, 58.71720683190131, 54.42942473196215, 52.38411657271847, 48.10140217504194, 49.027226663404896, 50.58531368932417, 50.23845457261609, 52.328854299360714, 55.24834502127863, 51.92587783259731, 51.78044811371834, 48.42726484421761, 37.71948845155778, 28.34942856142598, 18.986589754781416, 33.01560563425864, 26.603954222894487, 23.291218434610677, 1.4204505662764273, 0.0812987290743378, 0.023896097986688538, 0.06385448185967342, 0.023690654272814433, 0.08026048075407743, 0.11590828322955679, 0.06771661070806366, 0.07413984426567632, 0.041926256906721866, 0.04184063125942503, 0.02470214314187967, 0.05637005181802858, 0.1954095402071553, 1.8693473238137461, 0.9146790735183224, 0.058742924893815676, 0.027748602855529998, 0.03029216032084679, 0.04714656005343122, 0.011815874886158253, 0.01948267120056816, 0.025236912732643467, 0.02547419506065067, 0.0591432020038126, 0.11535804823882158, 0.06698809939646913, 0.08436206953539964, 6.621113823306176, 37.454606871451105, 30.28166263334213, 26.922442836146203, 36.99093172627111, 38.863545771568056, 41.59511573853032, 44.717094898223884, 44.73864439995059, 47.10776382876981, 49.135605673636164, 49.484339683286606, 49.745789189492505, 49.801220124767674, 49.074777557003884, 47.5632647545107, 47.19175354126961, 47.53990311776438, 47.52823014413157, 46.97881590935492, 47.477815920306796, 44.33298110961915, 45.62098941495342, 53.83426781623594, 57.44130688328897, 59.892796085726836, 57.441946229627064, 59.18401595084899, 55.903980962691776, 51.08050507883872, 50.39762435420867, 55.51841197475311, 59.84352719399237, 61.16053358201058, 63.761504311715406, 63.42003453162409, 65.00493095767114, 11.093155145645143, 0.4021465177497556, 0.4074810944016903, 0.16075569084815441, 0.8237809026914259, 8.620174296440618, 48.474231304660925, 57.516200619359175, 49.19437454592798, 69.53991259298017, 66.84237310963293, 66.5760833986344, 36.80595667131486, 0.3942876201002829, 13.671473207012301, 38.06824991779943, 30.502750950474894, 35.81720167590726, 29.885787617775705, 30.807736804408414, 31.71836603072382, 29.59134509486537, 39.34404004004694, 27.764709072728312, 32.611458339998805, 37.84949541091919, 30.406513637112035, 33.166671799075225, 65.78196817828764, 69.77110493567683, 4.053231718078736, 0.34289911629692205, 0.07873840194435851, 0.04555881984772221, 0.03394386588385509, 0.06904482330766416, 0.14662328386499038, 0.2194997418912188, 0.3325896259517439, 0.1937287892665594, 0.19837715032119907, 0.21427546657862204, 0.2932095503614795, 0.13431747564144675, 0.1101286324762529, 0.2767290685686373, 3.0641246899481747, 86.0834893872661, 83.34692232070431, 49.793375384423044, 53.86865915790681, 44.73628705547702, 50.04462280581075, 35.90858505618188, 56.64761920129099, 52.70748461446455, 51.5047800156378, 37.46273010007797, 58.30838211121098, 48.67459774017335, 42.41429882664835, 27.32741382814223, 6.765867423626685, 6.9801568023620115, 16.555371361394084, 68.28282433171427, 55.45998434866629, 67.30671113537204, 64.08759447836107, 55.03588199615479, 18.61015988934425, 2.5406233485667937, 0.46880955837907334, 3.430369385788518, 36.388004595233554, 70.61166101886381, 67.31349683577015, 66.10782300272297, 60.4695531629747, 57.86756261702507, 56.517949565764404, 63.93848557626048, 66.89795309497465, 70.69452501112416, 66.61523649769445, 63.34976919235722, 66.02149163523029, 63.60010270149478, 58.228632480867454, 52.17901583640806, 56.961298988711455, 62.40316790919151, 65.27520971913492, 61.15605815764397, 59.444069093273534, 55.63436508178712, 50.36823011213734, 52.01280540035617, 54.20693220630769, 52.1617260286885, 54.68605756759644, 58.42631601518201, 55.495191543333, 54.86916557435067, 52.84578738674041, 42.46384620666504, 34.05397468997587, 26.477002789897305, 39.23272317455661, 36.26858803533739, 38.25776315504505, 3.7414001024538472, 0.1574777844812601, 0.24945348861717412, 0.14530542877412614, 0.20703510831921332, 0.23774178157891, 0.17475654521296102, 0.1794503659250275, 0.16011766218129667, 0.13286603013834647, 0.216146192002681, 0.19005145997770373, 0.10638230930893652, 0.6296138958104196, 4.305511703414302, 0.4876634112048534, 0.08582339757272313, 0.09116330619661078, 0.13666345137021235, 0.13351161243213763, 0.15129577668924488, 0.13110729144705882, 0.23224989643260358, 0.13785252708100504, 0.09972557981288242, 0.16043948039652842, 0.1652010998898937, 0.11674379404153555, 11.12571179866791, 42.72113015574794, 35.50593806851295, 32.149616902874364, 43.17301073381978, 43.5521117333443, 46.20364965931062, 49.0417629672635, 47.55992289512388, 49.24557716615739, 51.5004732531886, 52.29162708405526, 51.727778527044485, 53.281146941646455, 50.510812190271196, 52.528671603049006, 50.44259432823428, 51.985662598763746, 49.38961444362518, 51.63351612706339, 50.54208917002524, 47.42976296332575, 49.15299746298021, 57.10674831944128, 57.97988360927951, 62.65830239941997, 59.085827258325395, 62.09064129860171, 58.48778347815237, 54.288756770472375, 54.49051956976614, 58.18323889086324, 62.53083321356005, 64.61829116267543, 65.35803841006371, 65.46422873773884, 66.99265480041504, 11.790478037249658, 1.119686776111203, 1.1773240446083009, 1.2196212910836743, 7.720820413481805, 8.567042850678968, 48.561162794789965, 62.07245719048285, 51.42814474721109, 73.14124461143248, 78.2084212764617, 65.73587248402258, 45.45479859075239, 2.596118022357264, 11.492959395531686, 36.69205496388097, 36.35932422453357, 50.30984170975224, 34.979920771814164, 44.44857728096747, 40.64993827573715, 32.02160446874557, 54.627971187714614, 38.74173656586678, 44.992645325199256, 52.75604355719782, 38.30057582547588, 40.88165229366672, 76.49098011755174, 82.99184583848523, 8.176247794781963, 0.6946911037929597, 0.27596540148219756, 0.2676610083829972, 0.1627942048493893, 0.1839931447419428], [0.03354537758916136, 0.04491459735999665, 0.07646035523183885, 0.041764145041064876, 0.10341407866367411, 0.07666705341468896, 0.006982206738734197, 0.057567627274341164, 0.07106024741886124, 0.042357361394791834, 0.2907584673695026, 37.894465384944795, 66.21011057207662, 31.600257581280125, 27.184141412858043, 29.405489467805435, 35.13706661039783, 29.813231614328203, 42.919280452113, 41.74580143344018, 38.88838614186933, 30.20759651737829, 27.979417654775805, 51.27723155483123, 28.127406720192205, 36.25661696157148, 5.654552088629815, 3.6464414817671624, 9.15395494430296, 49.81896100505706, 43.885109193863414, 50.97329885728898, 60.147852128551854, 62.50067410930511, 31.184982522841427, 3.516303613301247, 0.20891493486781276, 1.7044495334548337, 28.268202158712572, 65.09878150878414, 61.701530410397446, 62.39571148349393, 57.71595124275454, 53.86667836096979, 53.87536641090147, 59.34542932818013, 59.86736735989971, 58.376890228640654, 61.633394918134144, 60.271304807355335, 58.5527418505761, 59.49705246956118, 52.653469654821585, 45.01217480628721, 49.10911790786251, 56.58231566029211, 57.9679556815855, 56.86619720151348, 54.605488161886896, 51.17269254499867, 44.51099787988971, 45.34694910049439, 45.95179427054621, 47.2098199782833, 50.0541933890312, 51.846924443398755, 47.4307043321671, 49.21337450704267, 38.836465727898386, 32.4640792031442, 18.02135132974194, 16.423002154596393, 24.140066408341934, 18.892368539687126, 2.7809163255076257, 0.14010332404605805, 0.06156392876178988, 0.013197515415207995, 0.015842445465105198, 0.010703805375904327, 0.028635449219314803, 0.04202102581339498, 0.017079905373975635, 0.018078606320364822, 0.05710320562244423, 0.02868285474006928, 0.009364155083594304, 0.06061960282104631, 0.09203712140480358, 2.279347407241022, 0.5776284562964593, 0.09676908563461997, 0.011326881921699932, 0.02153133969723938, 0.07105636335308514, 0.06824073742233938, 0.015773060881803115, 0.027462359848282034, 0.03140840405267814, 0.023180841911403884, 0.017284667269597133, 0.09713367453866428, 0.07794978337422495, 1.9672235750382947, 28.50665676978327, 25.222687644343225, 20.617915276558172, 28.56989126051626, 34.134528406204716, 33.5226268922129, 41.520939796201645, 40.4690581752408, 41.90993693567092, 44.85002794573384, 45.44333742510888, 46.652553158421675, 47.22892584339265, 44.904752854377996, 43.84313591064946, 41.91371810051703, 45.68774031054589, 45.76237124781455, 46.99638028298655, 42.91456968553605, 42.73010846107237, 44.09578754055885, 51.961649848568825, 55.06876714767949, 53.66841823823991, 55.65678534969207, 55.81749662276238, 57.13307919040803, 49.03494196553385, 48.060993917526744, 49.292241604097434, 55.3144173468313, 58.11636247942525, 61.34279043443742, 60.182984798185295, 66.70600798822218, 18.38736338000144, 0.24395339100831942, 0.1263951688944813, 0.11274649280934565, 2.727233051292358, 15.306319056018708, 51.39897800260975, 54.64875190488754, 52.50718093687489, 51.31706714630128, 49.54469319312803, 54.0056557809153, 11.951490352230689, 0.5247765406966209, 18.44537131247982, 40.62947527054818, 30.40087522998933, 31.744008525725338, 31.35887884324597, 38.22991040445144, 24.9604203239564, 31.822916807666903, 42.64032933019823, 35.5958858613045, 36.470707770316835, 39.21778678894043, 43.11134322997063, 47.9320538428522, 56.72089692085021, 46.631368437121, 1.0107547116856421, 0.18711461595469908, 0.15681876500527706, 0.016556845437134468, 0.05868735287578837, 0.12345985704732519, 0.04311954227065848, 0.035075933161762454, 0.014476939705350708, 0.046122591612079454, 0.035705875770579425, 0.05725859889700528, 0.09608188178390266, 0.034216574032700835, 0.03865093608657199, 0.056533029363040006, 0.2880039216289597, 51.451659356394124, 77.53693503718223, 36.67917782260526, 36.59748269665626, 30.34450488705789, 32.55225800698803, 32.533305114315404, 38.383683004686915, 41.073060035705566, 37.308114190255445, 33.34607316601661, 32.45784655694039, 36.08696268450829, 34.34888201375162, 37.72888645049065, 7.3948224225351895, 5.422553208566481, 13.154968638573925, 54.46793848468412, 53.049538827711544, 56.715911588361195, 67.15023209971767, 65.46165174053561, 35.286508913963075, 3.5658384907630185, 0.06123001784867337, 2.7455801829215023, 30.921471811109978, 68.57567633351972, 64.73888051125311, 64.41992513595089, 61.525568962097175, 55.93310456122122, 55.632372517739576, 63.083981544740745, 63.51244949525403, 63.66087590494464, 64.3277023684594, 60.84850511243267, 60.4936678947941, 61.810427173491455, 53.696929947022475, 46.39316289655624, 53.82825874513196, 58.818478507380334, 58.76426742922876, 57.37909024761569, 57.592918257559504, 54.69313744575747, 47.296202336588216, 48.53537321090699, 50.32334250788535, 51.22931588080622, 53.800405994538345, 53.92650235083796, 50.95663270642681, 52.1617966313516, 42.38226482945104, 36.96358888379989, 23.33865361828958, 26.94501607648788, 28.61161743440936, 26.788762577118415, 4.492528352045245, 0.11582551509021752, 0.055950496105417136, 0.019333557931766398, 0.0941731277552824, 0.051940906822921774, 0.04101805584204774, 0.038598351811449376, 0.048671458066711505, 0.027619993930021604, 0.04360045013468593, 0.05906521425312085, 0.04706333226133739, 0.026309012563057968, 0.048641021393479845, 0.24188435606418118, 2.5514005509115036, 0.2671508551124604, 0.028698488679384033, 0.023185859787307923, 0.03528611321422843, 0.012564303526174159, 0.04238196813891973, 0.04488508765315337, 0.04231199749835557, 0.05206521224951552, 0.04583096109150399, 0.020958252303722887, 0.08647032052038178, 1.4823536574840548, 31.968503421352757, 29.235297826028642, 23.610324821164532, 32.397730350494385, 41.73485017591908, 39.816940599872225, 46.11812630007344, 44.405925427713704, 47.08085244701755, 48.30143913145989, 50.042555716729936, 47.99161895628899, 48.81588543615034, 46.44791133942143, 45.63286242946502, 43.46781607597105, 48.52642628454393, 47.82847581371185, 49.49556158434961, 46.385557420792125, 45.399650066129624, 45.614866595114435, 53.965941782920595, 59.28420505216045, 55.84173294805712, 58.61906128544962, 59.127129816239886, 59.95753088305074, 51.68693880881033, 51.375816406742224, 51.97719812393189, 59.174821915165076, 59.889681723810014, 64.60722615641933, 61.98660042978103, 68.46725417721656, 21.004474662965347, 0.5321431196024341, 0.31911971648373916, 0.25719967941122673, 3.273244139648253, 22.119165197495494, 53.22158967295001, 58.049489990357436, 55.6609744410361, 57.64983184875981, 57.397039013524214, 60.74336990233391, 11.292312510551946, 1.2346933661930024, 23.140828878648822, 42.68674273644724, 28.501259588426162, 31.787144791695383, 28.74685879676573, 34.004195890119, 28.076190371667188, 32.32011645070968, 32.446440304479296, 34.7615388901003, 36.356876665546054, 36.258660516431256, 44.18088336144724, 48.055734019125666, 65.7354017996019, 56.48903777522426, 1.2607086089349564, 0.09150853605880853, 0.09397870996185849, 0.03066847420057222, 0.0440280650922608, 0.020655331562363335, 0.14919989802423986, 0.19384776272120016, 0.16889359771965012, 0.17858433417014538, 0.24938636399324865, 0.18391411511167405, 0.1526567625302461, 0.18931229238308248, 0.14098947326983177, 0.14451812021434307, 0.7317307194875133, 65.99030094762003, 88.25232475034653, 44.427282733301965, 36.24217087222684, 37.866259621035674, 45.12123238655829, 39.38558578491211, 56.165544217632664, 52.81744826224543, 52.02033635108702, 39.507445981425626, 41.3089160765371, 68.87951881654801, 35.986244063223566, 43.41556618290563, 9.626579957623637, 9.503968627222124, 15.523875278811301, 59.79634108081941, 56.26749446315151, 62.967993136375185, 70.49065589904785, 71.37158886078866, 37.07516070335142, 4.830657253342291, 1.4010446398488938, 4.262966734747733, 34.13033147012034, 72.84494876861572, 64.84238009299001, 67.62361511107414, 63.06287134847334, 58.83304619020032, 58.5129141038464, 66.20271298193163, 65.44178493561284, 65.25453490595665, 67.5525103845904, 64.54077728333013, 62.51001719505557, 65.94212639716365, 57.38102789848082, 49.54482263134372, 55.63036426421135, 61.148523284542954, 61.71590981944915, 61.24998715616042, 62.85417379871492, 57.62468945595526, 50.60624345656365, 52.233917251709975, 52.44959269800494, 53.34130825534944, 57.578119154899355, 59.10396037563201, 52.88170060803814, 58.021684308205884, 45.61265437833725, 44.674862738578554, 30.67934193918782, 33.53138946717785, 39.86209100292575, 39.370955344169374, 14.657162870130232, 0.21376197316473533, 0.12320232893069907, 0.11195096412613509, 0.1551077229481551, 0.15431019477546215, 0.25322090984592516, 0.091900926293625, 0.12481158854620111, 0.1496741830581619, 0.1401961126154469, 0.29160848788676724, 0.19481314075810297, 0.24244318656142683, 0.39352030643532354, 5.305064983906285, 1.7660780587503988, 0.18602459541251584, 0.11522356916459338, 0.10529611154549545, 0.10545746498410741, 0.13210680636186756, 0.11978096493910398, 0.12072397320861779, 0.11048346142014188, 0.1871126700913714, 0.11766002753809576, 0.18892698080068637, 0.2484741677800494, 3.131384022774235, 39.731134829982636, 33.864037836751635, 30.37841573838265, 40.95980159697994, 46.64096255456248, 42.74389166985789, 50.226240311899495, 46.365274844631074, 50.34179333717593, 51.08971480400332, 53.946326009688846, 51.4683961099194, 52.93767283039709, 48.82343992110222, 49.192793830748535, 47.87993731037263, 52.35018414835776, 49.88757894885156, 54.32732151400659, 49.31449321008498, 49.987164005156494, 49.44122499035251, 56.52060501037106, 59.33665890847484, 60.271293040244814, 60.926654415745894, 62.12180060725059, 62.36455609721523, 54.16227994426605, 53.55130018726472, 56.15835059073664, 60.61271182952389, 63.52229072201637, 65.21866090836065, 65.0718975836231, 72.26049992345995, 22.069976714349565, 1.130150679138399, 0.8186155701837232, 1.030421230581499, 6.623419686671227, 20.601731577227195, 60.322460359142674, 62.09283390352803, 61.74235051678073, 59.50343808820171, 57.830205963503936, 61.41434623349098, 18.23781321125646, 1.9782564668886125, 25.1762899275749, 45.1762044045233, 41.129859878170876, 40.9368831880631, 38.962530705236624, 50.32523701267858, 33.229782735147786, 41.290845717153246, 57.89321491795202, 45.71713455261723, 49.91806753220097, 50.960386414681714, 58.17804567275509, 61.10121950026482, 76.36005924594018, 69.51152247767295, 2.7481586510135285, 0.6971751285656806, 0.325152566956897, 0.17063877665467803, 0.23483072407543662, 0.19175006076693538], [0.008521997501262495, 0.07289089878360111, 0.01920872390450489, 0.06655214940227809, 0.05398358834246474, 0.03200871629580375, 0.06917863588539824, 0.06272103945394197, 0.0551793328486383, 0.09082548440464082, 0.13051136697251953, 30.88324635259567, 67.59931995022681, 34.530311246072095, 35.479571896214644, 63.90789893365676, 50.07335808969314, 33.81632220360541, 44.50318451850645, 49.8561058505889, 38.302784119882894, 38.54454332782377, 26.58321665179345, 59.42654394334363, 32.638956116091826, 29.308451990927423, 10.269581944711748, 1.4574605803335867, 19.94835884340348, 51.61044866808, 49.73864655340872, 51.74670396312591, 60.4097919310293, 53.45085613189205, 30.385913348967033, 2.4557280588534574, 0.24581202756493326, 1.5053567650818056, 23.15588685774034, 58.300529526126006, 63.25306707812894, 63.32041025161744, 60.735105468380844, 56.503099472292014, 57.37256734601913, 61.72336232277655, 60.988910275120894, 63.868847816221184, 58.93096816155219, 59.86475898373512, 61.81483983993531, 58.39771801425565, 51.61927400096771, 46.75151848023938, 52.935684188719726, 59.36066773629958, 59.298588383582334, 57.04504551426057, 55.232055417953006, 49.926088779203354, 48.160422079024784, 44.63188925097066, 46.72345784402663, 48.2472005967171, 53.332078918333984, 51.54684351336572, 49.71240589695592, 46.036482164936686, 35.744567225056315, 25.994208051312356, 17.456171128057665, 20.816338177650206, 19.268380672700946, 10.903140825610008, 0.9792332579531978, 0.10408909405551611, 0.055763992000251054, 0.023014792353816094, 0.0761464813483819, 0.04444248801577957, 0.027119529756507086, 0.049798572586188396, 0.0345208220213892, 0.08628159476023528, 0.08199017705215562, 0.09327577066517646, 0.033739577047526836, 0.05284332392376758, 0.03640154872329966, 0.6016692146658897, 4.080576031438766, 0.07592471421606119, 0.054423702024524255, 0.048437678675738075, 0.055311586437446464, 0.010227436582828242, 0.07892887438497237, 0.07688835323337587, 0.13233894632468302, 0.013675136762040277, 0.012412275292820508, 0.023765058647240364, 0.06499239438844305, 0.13269726096862747, 15.031559967225599, 31.43646332525438, 17.179153734637847, 18.569278986223285, 34.2325758934021, 33.76239745847641, 40.30365966981457, 41.61609649658203, 42.5609484026509, 43.498135997403054, 45.287042740852606, 45.314801354562086, 43.54818936317198, 46.46187889960505, 42.577579252181515, 44.169841889412176, 47.40659352271788, 45.980396193842736, 45.37077749929121, 45.77305186179377, 41.95996284484863, 44.74437890514251, 51.162733647131155, 56.845345881677446, 54.57234021156065, 55.630199524664114, 58.21682614664878, 57.2758730765312, 53.000972040237926, 48.50158591424265, 48.450893202135646, 54.85009893294304, 56.41425386551888, 60.04780031019642, 58.31368123331378, 62.042607953471524, 23.51964746752093, 1.2452033570697232, 0.22461411423019825, 0.14451093430961334, 3.8063283216568733, 33.692261557425226, 56.72867890327208, 53.56319281362719, 63.56113787620299, 59.7563878182442, 54.721762903275035, 39.281599829273844, 8.221845838331408, 0.1410418277185771, 29.198268690416892, 44.563687078414425, 26.36828841701631, 29.389091999300067, 35.55779180219097, 28.777892589569095, 30.694729397373816, 35.692799783522084, 41.61823811069612, 32.88354923648219, 33.289614569756296, 39.34006667906238, 29.010104748510546, 45.625421693248136, 61.61028039070868, 41.96560321315643, 0.4505854604705688, 0.056266859774627996, 0.09974314620898617, 0.04125532476351627, 0.050503925059831915, 0.054678077689341964, 0.02893338081306748, 0.030250850944749774, 0.05438547806754228, 0.029068714075331247, 0.03370817893395021, 0.08093138225376606, 0.06365836718149724, 0.056544382786077846, 0.1198319404295856, 0.048194162307247046, 0.016789538898475228, 42.75895357131959, 77.11904571902367, 39.719814869665335, 35.9115582127725, 59.38036195693478, 43.73028539842175, 29.883755830026445, 41.62178393333189, 46.76744330313898, 38.522460383753625, 36.99568171654978, 31.524189095343317, 53.566413079538655, 35.54323980885167, 33.75154033783944, 13.973268212810641, 3.253969857769628, 19.589811063581898, 60.781385514044, 53.63698828604914, 58.39839658429546, 64.78989093534409, 60.25567808458882, 35.16578620479953, 4.231346547603607, 0.41486639649637286, 1.630748688213287, 23.58640620785375, 59.5993596507657, 64.92460866128245, 65.40460478874945, 62.33034910694246, 59.084328912919574, 62.17315619991672, 61.73812220173498, 62.68079326998804, 64.23835862067439, 61.872612430203354, 61.95946939529912, 61.015794200281945, 60.10075622989286, 53.43771619181479, 49.1180177657835, 56.617130617941584, 62.194607642389116, 62.91471950469479, 59.09602542077342, 56.59063108505742, 53.66999110867901, 51.10754982117684, 46.65757379224224, 48.213123044660016, 52.11353186638125, 56.495756795329434, 55.18170395205098, 55.01697617192423, 49.77077860986033, 42.749418289430686, 30.22833016610915, 26.67850475157461, 27.682839401306648, 25.16454831246407, 16.18941716609463, 0.812829216161082, 0.15283686980124445, 0.026930420952398452, 0.046196852345019586, 0.08034370088529202, 0.044239723694420634, 0.004126077739431733, 0.06470801489007089, 0.04205223240499054, 0.07374060520481679, 0.07234987216971575, 0.07081984902822203, 0.053270705224525546, 0.08364239887845132, 0.021483227460374756, 0.34251647070050245, 1.582491645409215, 0.22132493104905854, 0.08756504484242009, 0.019005099649450952, 0.10412135401800757, 0.026212925985155087, 0.07049036993374748, 0.0436590405391349, 0.02038272300494775, 0.037996505477255395, 0.04440169000337201, 0.021044356755972392, 0.07044000731360528, 0.36829759697279624, 15.460037723664316, 36.20950145106162, 23.32586276915766, 25.000120593655495, 39.800662763657115, 41.09781803623323, 44.60143204658262, 46.143453044276086, 45.033975339704945, 47.20698018227854, 46.428291643819506, 47.66056699137534, 46.165402627760365, 46.554784159506525, 44.49100163675124, 47.15930377283404, 48.16738820845082, 49.15887709586851, 49.1514402820218, 48.27160950629942, 45.53595242961761, 49.50713649872811, 54.871036544922866, 57.85592102235364, 56.290632524798, 57.25896373871834, 59.79653327695785, 59.890305380667414, 55.015415068595644, 50.61746143525647, 49.98848976627473, 56.49255221889865, 60.046443170116795, 62.82064145611179, 62.55732882407404, 63.67939341452814, 25.60377532436002, 1.7222536619632476, 0.14667292636248375, 0.535902711412599, 7.56210905890311, 41.10483907884167, 64.96470312918386, 59.00120212185768, 67.40952430232879, 63.5544070889873, 59.1367200113112, 40.65665729584233, 6.068244961000258, 0.748853765187725, 31.07604261367552, 43.69144608897548, 29.358644600837465, 31.047776053028723, 33.42798794469526, 30.162891303339315, 30.90903397529356, 30.48447466665699, 32.783617050417014, 35.70413151094991, 33.11211162997831, 42.920947459436235, 32.15534160214086, 46.59137987321424, 71.15251664192446, 51.82511214287051, 0.3322671642226558, 0.06958332949227865, 0.070899200415419, 0.025695533183733785, 0.009827410366626517, 0.0534904039194507, 0.14126025470754794, 0.31648572233896105, 0.1911002190242852, 0.3322148863827029, 0.13198470726849573, 0.12445253845784934, 0.17115824555437412, 0.2120668504146799, 0.3158066926463958, 0.12659242121322503, 0.18950992774578834, 55.789047671902566, 92.50961826693629, 47.80705575020083, 46.59078759531821, 82.26931387378325, 61.92412491767638, 42.90564629339403, 57.652267640636815, 62.19092845916749, 52.23578822228217, 50.15092688222086, 36.07781571726645, 80.00846755120062, 41.813497620244185, 36.363725123866914, 14.664498682945007, 6.167633408500302, 26.064765607157064, 61.71254834821148, 60.537912230337824, 62.51621453992782, 68.98040217737999, 65.84318068719679, 38.3818708696673, 4.673257441289963, 0.8944512879656208, 2.9482894991674735, 28.238131307786514, 62.29647159576417, 68.62704369329637, 68.0612417959398, 66.45209727748748, 62.05808562617149, 64.47729372209119, 66.66296389795119, 65.10855997762373, 67.9802683861025, 65.24002998105942, 62.39699409854028, 66.15380102588286, 63.85731604791457, 56.26479195010278, 52.89728418473275, 59.15885786856375, 64.88851893332698, 64.79931246849799, 62.964408090037686, 61.266190467342255, 56.45754114274056, 55.24862743193104, 52.585797002238614, 50.227985766626176, 54.5833699164852, 58.06503042098015, 60.99350337059268, 58.334371735972745, 53.11958451424876, 47.11104685260404, 37.799438122780096, 32.425932192033336, 35.3269838517712, 35.98554588133289, 30.44697484662456, 2.7303206920623784, 0.24559766084196108, 0.1574718089954507, 0.17491878731356514, 0.10451606549923459, 0.13543798648301633, 0.15627714084281077, 0.13118635172084456, 0.14718880997069422, 0.14352605167415836, 0.19422397317905582, 0.2069886067822095, 0.17091652949250516, 0.15265467877109207, 0.07788270471557494, 1.1254644273750245, 7.2682298864087755, 0.15231927015608357, 0.21519671795108627, 0.0915284696665983, 0.2566802411550476, 0.11472378106367205, 0.1928569965304867, 0.2127238933838183, 0.18080782776157703, 0.12181440743828013, 0.16161704946669841, 0.12708801881320056, 0.1720950944769767, 0.6798999684472239, 23.582748597668065, 41.415537864931174, 27.21850137556753, 31.149420353674124, 44.43347223343388, 44.57695645670737, 48.8614006196299, 49.5745228182885, 49.1476159711038, 50.854933492599, 51.12341580852386, 52.3524316664665, 49.51794262855284, 51.25053590343845, 48.27718711668446, 49.387037446421964, 52.15259867329752, 51.71992594195951, 53.133403024365826, 51.16475759014007, 46.42325139814808, 50.18310600711454, 57.92338578931747, 62.16827284905219, 58.297854469668486, 59.40103284774288, 64.3111264321112, 62.35895887497933, 58.00685382658436, 52.81234525865125, 52.56465542700983, 59.06831387550601, 64.08337793042584, 66.18827081495716, 63.870801156567, 66.94013426380774, 27.81692954801744, 2.658043667193382, 1.0662209482923632, 0.6007378356110665, 6.704300430513198, 39.149725821710405, 69.82906972208332, 60.79475295159125, 73.60342533357682, 67.39648634387602, 66.79342977462277, 48.301799989515736, 13.997913445195845, 1.433962273501581, 36.303857987926854, 51.352282185708326, 37.98099287094609, 37.05562729989329, 49.31192013525194, 37.20803099293863, 41.183470833686094, 46.491049566576564, 54.15037947316324, 42.58340397188741, 43.6485549711412, 51.95883750915528, 39.481683854133856, 61.20720586469097, 80.35955890532463, 64.12647693387925, 0.5562098023872222, 0.23725272636980782, 0.30537989891825185, 0.14973430563845944, 0.11665362549284775, 0.1522770893549727], [0.07334555664490308, 0.010096445123875334, 0.07893371606065382, 0.03926523134953553, 0.07016391688657385, 0.021160589531064037, 0.026164570515374505, 0.07862048569105326, 0.08818042028935687, 0.09885174162205189, 0.06650618412682126, 29.79110944655634, 68.86849695636381, 38.137036523511334, 56.975921584713845, 92.6437319478681, 73.50894328086608, 36.781524227511504, 37.08459008124567, 44.10650737823979, 42.20316156264275, 39.487496806729226, 25.727712415879775, 29.598564217167517, 43.92265019878265, 31.82034569401895, 18.252761363983154, 0.7610424692111631, 10.149288735082074, 61.455327157051336, 49.94617915922596, 58.308962621996486, 62.827933142262125, 58.21204085503855, 47.17590324340328, 10.341054393399148, 0.45344446996046656, 0.90736924640594, 12.914375355166774, 54.10070657730103, 63.62011071174376, 64.44817796830209, 62.54671881275793, 58.425417792412546, 62.427031609319876, 60.91050601774647, 60.70238505640338, 62.45303692356233, 60.17561466463151, 61.40256343349334, 60.09349200033373, 55.89104890823365, 51.14747954953102, 46.63020349317982, 52.362547459140906, 59.59305640189879, 56.44878249014578, 57.954968713944965, 57.30892296760314, 52.08540454987557, 44.74485743430353, 43.819519319841945, 45.70337880042292, 49.11184787750245, 54.635882608352176, 50.51331858481131, 52.3839989016133, 41.234422422224476, 31.636302201978623, 19.912898655860655, 23.412405944639637, 17.080386492513842, 18.261712212716382, 8.93323434937385, 0.6873794380695589, 0.08066540418733513, 0.09327990753996758, 0.07504751289924307, 0.05380236258309695, 0.06346252446453418, 0.013716844503857918, 0.033652813759662455, 0.026836297474801544, 0.03731305545736705, 0.05124622212362386, 0.11100854574432296, 0.08181762340809069, 0.009594395148357557, 0.0638087693932316, 0.12317693311600916, 3.4466192751161517, 0.4479179423182242, 0.03436763508005008, 0.040359162770572214, 0.05222380394116045, 0.017831366764561787, 0.10241945138982228, 0.07210915968302758, 0.03999310680815289, 0.023195326718832218, 0.009950965984664377, 0.11329706487876755, 0.08220804479694174, 0.4007170896135992, 4.96876145562818, 26.211470096342026, 27.142203430975638, 18.540355428572624, 24.372472724606915, 34.94199537461804, 37.509751473703695, 43.41992785853725, 40.359294568338704, 43.53896394852669, 42.80713988888649, 45.02068242719097, 41.11154240946616, 42.33680848152407, 41.48921174387778, 45.95247284058602, 46.16696373108895, 48.095530386893984, 50.09703351605324, 48.80031362656624, 44.076995465063284, 45.382760340167636, 51.17342602822089, 57.30280014776415, 55.767313818777765, 55.473151745334754, 56.70472106625957, 58.20935403147052, 55.42245118848739, 49.92389617427703, 53.15481916550667, 54.755279556397475, 56.07854996958087, 58.352285200549716, 61.24844174231253, 57.832524084275775, 20.3987685326607, 1.1712850654317488, 0.2254427302508585, 4.473067512435298, 24.23202245466171, 38.37557938791091, 53.291309802762925, 49.24477308027206, 55.44065490845711, 51.68775858417634, 54.695486945490686, 52.440653616382235, 2.4746132906406157, 1.390856160752235, 39.17211078828381, 34.44096357591691, 18.148200781114642, 32.907665929486676, 29.25165803201737, 28.894130068440592, 34.787069597551906, 31.628143672020208, 29.500073502140662, 31.442776380046723, 39.29238242487754, 28.669576337260587, 22.71746785409989, 39.20077154713292, 58.668592975985625, 26.253135473497455, 0.3956948316866352, 0.19280519366504686, 0.020520626492197477, 0.10505622643376551, 0.046703968076936664, 0.030578794032936136, 0.0803034812692673, 0.017183072519518675, 0.0489215896044287, 0.00607955310824177, 0.04237894209161882, 0.031917578645891724, 0.04245114204804263, 0.057548459754475666, 0.04775865664405208, 0.05997129325424472, 0.05603722108888531, 37.42174525414744, 78.42053521064021, 40.185062885284424, 55.59928732533609, 92.81248015742149, 55.83587684938985, 27.418512836579357, 30.585662011177313, 40.23828944852276, 42.38968203144689, 40.11285205041209, 27.952125803116832, 33.23629386963383, 25.390080675002068, 31.50038423076753, 21.108413550161547, 2.428900762911766, 8.929450242750107, 64.09614132296655, 57.34566773137739, 65.01706284861412, 65.13189023540866, 64.06779435373122, 52.54025043979768, 14.079384996045022, 0.6071859670262183, 0.9543982196238734, 11.256387522143703, 55.387377354406546, 67.5473956138857, 65.99831827225225, 64.04083198116672, 61.94306212086832, 63.86746714192053, 64.24639947952764, 62.59501887905983, 63.79340102595668, 60.912318152766076, 63.63485882359167, 62.83857453253962, 58.09899422430224, 53.81862148161858, 48.339293925992905, 56.27043231841057, 61.46063020152431, 59.82624915338332, 59.28151822859242, 58.83539961230371, 55.73673109854422, 47.340183873330396, 47.78518461412, 50.12222689967002, 52.225809712563795, 55.7032811257147, 53.29245121248307, 55.1072181424787, 46.4225257596662, 36.55469356044647, 28.1629414327683, 30.143142169521703, 22.249138816710442, 28.05538808145831, 15.097399892345553, 0.7386595863969095, 0.06667057127361337, 0.12461716309189798, 0.09226432010050743, 0.04163221703962453, 0.027595299085782423, 0.00731876161279938, 0.02572635673136721, 0.028958508496983882, 0.06240196000303953, 0.02322344597609293, 0.05211785015079284, 0.09390585500025943, 0.06453101027516589, 0.05181223852559925, 0.18301716404816798, 0.3301604224308845, 0.7411141933933382, 0.12426319216648418, 0.02831960648989245, 0.04258707668932696, 0.020984165227761673, 0.08086078725154362, 0.06724864589951693, 0.011944872601288221, 0.03752767881979385, 0.03316142581283085, 0.09937355475079629, 0.25570153318826233, 0.1568417169994885, 6.127288889500403, 30.131345641228464, 27.940280245196437, 25.307546161836196, 29.615789305779245, 42.832199911917414, 42.264836911232244, 47.266968911693944, 45.465326232294885, 47.115283012390144, 45.29114946242302, 47.025178324791696, 43.09730506712391, 45.23627550371232, 44.67724361727315, 50.4345573917512, 48.7840397127213, 51.69816070987333, 50.30689208738266, 49.86829265471428, 46.76257564175514, 49.39340345321163, 54.14607271071404, 58.67018938064576, 56.98676301587013, 59.36132669448853, 59.34633931806011, 61.08447097962903, 56.55984440157491, 53.26466121981221, 54.19820493267429, 59.48987453214584, 58.636429540572635, 62.45832820092479, 63.81705291809575, 58.66901659196424, 21.134330611075125, 2.1398497829514165, 0.8471449296320639, 7.358159047942008, 34.67592923871933, 47.01117546327653, 56.80590252722464, 55.55912617714175, 61.337448166262725, 55.378873655872965, 60.59150357400218, 48.56744643180601, 1.1701510101556778, 2.693799258239808, 42.91576600843861, 46.55530191236927, 25.786532278983827, 31.49774447564156, 29.55006018761666, 33.49598223163236, 33.932518497590095, 32.74029447186378, 27.98691918773036, 35.2092735229, 31.16367424688032, 31.43294299802473, 20.064859121076523, 44.73488284695534, 71.01460610666584, 33.715568280989125, 0.3458273494916578, 0.1919632783580211, 0.07671626690294474, 0.03454599950102068, 0.0195303391064367, 0.08466413034306419, 0.24435399370568417, 0.13318991679097378, 0.19034203712738332, 0.10334695403974864, 0.11809171042254857, 0.09281554334466496, 0.10235785025983088, 0.13399775650712753, 0.18073956932752364, 0.26974124353258844, 0.19420803855023078, 50.16353337995468, 92.08195440230831, 52.312686289510424, 73.06890826071464, 111.60039794060492, 91.50788414862849, 46.4913986575219, 47.977184634054865, 57.32622454243322, 57.54318652614471, 53.43005580286826, 34.62149458546793, 43.1111628009427, 54.900442554104714, 40.848959338280466, 24.039634120079782, 4.621625811822953, 15.805547545033118, 70.6432439434913, 64.81843402308803, 71.2796014355075, 73.64959163050499, 67.8053306764172, 56.713236531903675, 14.3094329872439, 1.0808126556296502, 1.9984927100519982, 16.52741662917599, 60.833427521490286, 69.64657752744614, 71.10819385897729, 66.82039214718726, 63.879885365886075, 67.26702459396856, 65.37652061831567, 65.01558411505916, 67.57459332866054, 61.46499972189627, 66.68566657650855, 66.97465112132411, 62.59418341421313, 56.81699106770178, 52.79181165079917, 58.78132581710816, 64.47419504965505, 61.09365717057259, 63.20204880929763, 65.01077136685772, 60.215505169283965, 49.79921187123945, 49.712645161536436, 53.92638467973279, 52.98159945395685, 59.63041305541993, 54.981557169268214, 57.6672314828442, 52.32559873211769, 43.6622283535619, 32.49199275047549, 36.82863189328101, 30.1765235008732, 32.85235658768685, 23.05398368066357, 1.4521853601740253, 0.15234782991390075, 0.24150217012051614, 0.1490667672647584, 0.10465778410434724, 0.19909787051860364, 0.10744486559903431, 0.18212696988015406, 0.12337692036864259, 0.11051225100433636, 0.09197153661760593, 0.22893215349364668, 0.20641362715152003, 0.14204886561680224, 0.19839300834123166, 0.31756409834469523, 5.652892926046926, 0.9278472669182286, 0.22241749500315036, 0.19289851849598272, 0.1329696818345016, 0.15019457126336713, 0.1616767890030338, 0.143410372397592, 0.10763169912200783, 0.14362478508583962, 0.08806764448602354, 0.26385226437161047, 0.2637801295326602, 0.4037276619384366, 9.854372585973433, 39.330197995708836, 34.4626856619312, 29.68879834298165, 34.36464994184433, 47.61081172573952, 46.282049994314875, 52.07584573376564, 46.24300279924947, 50.19826596783054, 48.34886843158353, 50.73486581925423, 46.24869023599933, 48.21832410750851, 46.21259658567367, 52.48551376404301, 52.11335928209367, 54.01520282991471, 53.64460945129395, 53.0344690815095, 49.405358837496856, 52.19946707448652, 56.07265856958205, 62.01034253643405, 60.73881995293402, 61.13029210798202, 62.47142891730032, 63.60099307952389, 59.169797358974336, 55.20707384232552, 57.72428235700054, 60.48466605524863, 60.86666176396032, 62.841555533870576, 65.69482880253946, 62.46256043834072, 24.981355974751136, 2.8605144543032495, 1.8461743285579069, 8.434676585658904, 33.792046654608946, 54.55121432581256, 65.20181432847055, 61.02669446699081, 64.69927241725307, 62.34096696299892, 64.43557147056826, 60.62738541633853, 5.179591794167796, 2.8041176353731467, 47.03477636460335, 44.0543241654673, 27.464149613534254, 41.459036950142156, 40.35425824503745, 37.83018166019071, 48.54630485657723, 42.354239494569846, 41.19182548215313, 42.95939453186528, 49.403899715792754, 41.551659799391224, 30.799401767792244, 55.97074362539477, 77.54921205582158, 45.98717012713033, 0.3897526860237122, 0.36008252972556704, 0.20157826403456353, 0.18666447801215036, 0.08286947744988626, 0.09559902422610791], [0.056339722397106315, 0.12453475501388313, 0.0481425930986241, 0.015718765357779642, 0.03483641194179654, 0.018739117752580393, 0.04122512174710151, 0.07193191758086605, 0.04319784411739919, 0.07665638180990374, 0.05060935791041102, 16.32866522958202, 77.17456294644263, 36.08316190781132, 31.477703125246112, 67.90841056454566, 78.24479733743976, 47.2941077909162, 46.79856338808614, 41.51271066358013, 43.02239564157302, 35.65141485583398, 33.29626298719837, 26.304028226483254, 98.73220751362463, 112.22000691198535, 16.84656616180174, 1.6689670374316554, 3.0742958861012615, 45.812495216246575, 55.744328729568, 56.740104767584036, 57.9832725371084, 53.53386917421895, 54.10078894707465, 15.248313084725412, 1.6682112457290774, 0.274289109173321, 2.9730394098066517, 29.50678663869058, 63.047880049674745, 64.27365602985506, 63.453523728155325, 61.548907064622455, 63.57061040016913, 61.23098719504572, 62.862053840391106, 65.43124160458966, 58.29011563331851, 64.20077054731308, 60.075001947341434, 58.79256340765185, 49.12366990120181, 48.25778707381218, 56.302619288044596, 60.6345868879749, 57.70719259015976, 59.21308855856619, 54.70586945933681, 52.84848597741897, 47.611050990320024, 45.18672027895528, 46.49724298907865, 55.30165003192041, 51.67732115714781, 54.71918590607182, 45.62255444065217, 34.34734444464407, 27.913833664309596, 18.934820352062104, 19.746688219808764, 18.73531291561742, 27.436081132581158, 10.205552193426318, 0.10489992917545381, 0.0453191913754469, 0.020178834449559934, 0.061169971877168265, 0.04359286203379593, 0.017241544180339383, 0.03138526436692524, 0.042354526869472, 0.0755986825172459, 0.06303672896577947, 0.05755327461707977, 0.08092602729917535, 0.0497639607337694, 0.05848862200735077, 0.03418925916776061, 0.10031446393939758, 0.1289761727375369, 0.8097429237058087, 0.07407557714970843, 0.02907372045991642, 0.05528394598513842, 0.003615686263430924, 0.012933205505232177, 0.03905814246184403, 0.037364521244120215, 0.04677242952428999, 0.0294463379654072, 0.0020671987271447096, 0.09219128127780654, 0.11825081156266314, 2.876565038196502, 20.128756492368638, 26.424003724128973, 21.97932093374191, 22.716271531197336, 30.55444778934602, 35.31908812061433, 39.984829810357866, 43.04565921906502, 43.49357428089265, 43.045867104684156, 42.32170343399048, 42.22031408740629, 43.1268326697811, 42.8013426257718, 48.4691910589895, 47.40165133630076, 50.04168102818151, 47.92529952141547, 48.74713805414016, 42.81685952217349, 47.136040195342034, 50.64577702553042, 56.15538527888637, 55.019157009740034, 61.18210661795832, 61.79581634459957, 59.069886745945105, 54.852428820825395, 51.78528439614081, 52.769493364518695, 57.9147957986401, 57.557452186461425, 60.06759259008593, 60.9977787540805, 47.59601262307937, 12.386028170585634, 0.617441677999112, 1.3125574396502588, 11.099394655996754, 50.05214983417142, 41.06823944276379, 42.45861376485517, 49.2824984365894, 50.465261705460094, 48.79140984627509, 67.91568263884514, 26.164364391757598, 0.18936113814913458, 5.878690538867827, 41.91744042981056, 19.122680310280092, 25.703972270411832, 36.27254178447109, 32.24895484985844, 32.62754398007547, 32.009596132463024, 30.92334866523743, 28.196875818314094, 34.67756094471101, 40.46780693915583, 40.132962042285556, 36.71786415961481, 45.204747492267245, 69.38913668355634, 20.689539717089747, 0.4243194311857224, 0.12565412438444554, 0.02210258081885836, 0.1198330129526796, 0.02655962673616746, 0.0885364366695285, 0.05400646372788376, 0.055327394661763986, 0.02802909637290624, 0.06693371481472446, 0.0594515179193789, 0.07673103707812487, 0.02685879747713766, 0.026220069755049005, 0.06995015537306186, 0.12696432625694623, 0.15222191570266602, 22.708628792916578, 89.53103311600225, 42.28994400270524, 36.211952932419315, 76.70097597183721, 81.68841869600358, 44.74858760833741, 34.16729980899442, 37.16990555486372, 40.44477085913382, 37.895410676156324, 35.33656620210217, 28.60460423654126, 68.95091379842451, 112.35197113406275, 21.215392274241296, 4.09464287661737, 3.124612295819867, 47.57158410164618, 61.7009420548716, 62.054904583961736, 62.61090840062788, 58.43734964247673, 59.18665570597495, 21.44462735422196, 2.7156676976911487, 0.2325819495825037, 2.6773956610310465, 27.209344602400257, 65.11183907908779, 65.4126456476027, 66.21754738592333, 61.916629268277084, 65.94169493644469, 62.33501280507734, 66.23744164743732, 65.93548974683209, 59.57628042467179, 65.96912014868953, 62.551155013422814, 59.99973950847503, 51.666150246897054, 50.66963288091844, 56.30719277166552, 62.70313901285972, 57.81216306071128, 60.194273379541215, 57.856893770156375, 54.602228672273704, 50.61856362127489, 48.41194798869472, 50.789892750401656, 58.094652160521484, 55.676601163802616, 58.924802195641306, 50.23246119099279, 39.97219977840301, 37.003538224004934, 28.225420867243123, 31.066464185714725, 25.81591279275956, 32.429156380314986, 13.662825361374887, 0.07407141729227959, 0.07160561009039802, 0.027518416416921446, 0.07918871608712981, 0.023450516352069475, 0.04360487812288827, 0.02935543014187246, 0.045432442153293284, 0.06142197266942071, 0.03963116856832658, 0.04071621336944161, 0.05655402400260491, 0.06758489721124211, 0.0246059684638655, 0.04457255059312429, 0.07037883519285149, 0.2751134810668807, 0.9861108276151842, 0.09334802807819459, 0.03166647800695031, 0.046427069427145105, 0.05174616344213005, 0.022417963895526145, 0.03562529098182436, 0.04717269131252843, 0.10954858900438394, 0.08816309138050965, 0.06270341943168352, 0.0777204932584878, 0.1367869907088818, 2.892867389225191, 26.02375134345024, 25.071044891111313, 25.65164196875788, 29.93592139213316, 36.55547411211076, 41.427234372785016, 44.509001393472, 47.92025535337387, 46.230957200450284, 49.57489544345487, 46.992575583919404, 45.30368535749374, 48.070140884768584, 45.960749041649606, 48.72381564109556, 48.625681861754394, 53.31048234816521, 50.17117415705035, 49.54514034332768, 45.53444623947144, 48.58907830330634, 53.33802130914504, 59.08976924034857, 57.48948535611553, 62.43215422476492, 63.85070685417422, 60.90595999071675, 57.1800809521829, 54.98600513704362, 54.91162523146599, 60.16154120045324, 61.659588506144864, 60.62618909343597, 65.16800349758518, 46.42149417631088, 11.964807779558244, 0.8158610244431804, 3.883979483958214, 18.79318552632486, 53.20376642288701, 47.60910941708473, 49.49718152323077, 52.27678483532321, 53.439818582227154, 52.85486767368933, 70.10340813667544, 22.776352436311786, 0.08036220956954264, 9.964799073434646, 49.038240678848766, 29.897656709917133, 29.199094349338164, 34.178294212587424, 33.19914510173182, 33.60241966862833, 30.081912009946763, 30.468294889696185, 30.51426506811573, 35.23212525152391, 30.163216860063617, 43.54744803520941, 38.26646689445742, 51.200027542729536, 76.45713006296467, 26.761349131984097, 0.3234064687163599, 0.14011518308712592, 0.13199652034428813, 0.13808935550191712, 0.07779271236710972, 0.03382350964051101, 0.14716734418705588, 0.2671657785052254, 0.1448716085043646, 0.1928036461674398, 0.15253785036263928, 0.2631413041343612, 0.16981739250402297, 0.1864558416268518, 0.12835009504229794, 0.25559702347363195, 0.45935977190252275, 31.32684288486358, 102.54257832804035, 50.6563635026255, 43.04900892319218, 70.71039492084135, 94.08990198566069, 59.29847463484734, 60.486191857245664, 56.780611084353545, 57.078981860991455, 49.571698711764434, 39.55780529206799, 37.621778288195216, 119.04590375961797, 122.51156099380987, 22.424770785916238, 4.624101317697956, 5.958298963885154, 55.80014797949023, 68.96163755847563, 70.58430640928208, 66.71273877543788, 63.460725199791696, 63.81932397042552, 23.072409014548025, 2.0891237306979398, 0.3547364004677342, 5.188192571363142, 32.49454621345767, 70.82165687314927, 68.57044389170986, 71.33874293296569, 65.37630881032636, 70.13107653587096, 67.2100325553648, 68.00321425161054, 66.9763534299789, 63.77903730638566, 69.21346156827866, 66.30667932571905, 62.92445090509231, 55.31844562099826, 53.917112196645434, 58.13788452456075, 66.0793387505316, 61.92134003485403, 61.95409967053322, 58.816513399924006, 57.77960738828106, 53.452723180094075, 50.897895213096376, 53.730878060863866, 61.61908218937536, 57.22550592114849, 59.64513371067663, 56.23880232534101, 45.5857273071043, 42.70928459782755, 31.78841171726104, 37.1214799727163, 30.313751543721846, 41.50303417636503, 17.126317447231663, 0.2548053175691636, 0.2130832652290983, 0.11490905942815928, 0.15732752399579172, 0.1225009601142618, 0.12974135667806672, 0.10105827402683998, 0.248003468037613, 0.1424365980370391, 0.17668196931481364, 0.15686577216031092, 0.2064672226627027, 0.2705121731325504, 0.1453574001789093, 0.13025892567971062, 0.31421206531024753, 0.9565221830721825, 2.765482779472105, 0.15490250331499886, 0.09478178461112323, 0.1587106191342877, 0.19892557734443297, 0.09163274955485137, 0.11907466251643435, 0.17288074828684333, 0.1991396529539939, 0.17726508479925895, 0.13802068338038462, 0.22691432386636737, 0.3306692580301916, 3.889442365015707, 36.422999981910955, 34.65675277094687, 35.752537481246456, 32.26219481037509, 44.71516116972893, 44.15297962004139, 50.42098991332516, 52.143922390476355, 48.91632949152301, 51.58789503958918, 50.310355540244814, 46.998953357819595, 49.37789832392047, 49.334246266272764, 54.07190461312571, 51.76584512956681, 57.15396973394579, 53.53046063453921, 53.981576350427446, 47.104245462725245, 51.48590949273879, 56.30846754197152, 61.29170940768335, 58.82283626064178, 62.29349843917355, 68.91197250735375, 65.83775212687831, 60.92439905289681, 57.33637563643917, 58.13612338035338, 62.71036401871712, 66.66148124202606, 64.88363950483262, 66.82328685637444, 52.268147776203776, 17.548590014057776, 1.8098537936325998, 2.699293273110544, 17.921848643210627, 56.71218533669749, 51.71108491959111, 54.036595436834524, 58.91662405383203, 62.07960767130699, 56.194565834537634, 76.67406066771477, 32.6573637993105, 0.4570974836186056, 9.241718957501075, 50.03944919955347, 26.419965644036573, 35.47062889222176, 46.75177343430058, 41.70187088751024, 43.1988081624431, 42.55496678813812, 41.45269839994369, 39.734719876320135, 43.51714772562827, 51.12803243821668, 53.89135006935366, 45.6374280683456, 61.46643923174951, 85.02713234193864, 36.91815214772379, 0.7543084337826699, 0.25953851520053806, 0.14316487186137708, 0.30691584391940024, 0.323517122456143, 0.16627368427092032], [0.04447773189073609, 0.04462553323396752, 0.06868097750890641, 0.0925511357584788, 0.01424567499798873, 0.09160530828540364, 0.050767229479407115, 0.104213529717057, 0.008686533077589927, 0.11229943454025254, 0.13966391133444925, 8.197466836821649, 75.7675773866715, 53.929801064152876, 38.541448577757805, 38.92119676836076, 26.259026873496275, 18.10672563891257, 35.849875019442656, 38.33521819883777, 38.619841068021714, 32.50646237404116, 41.26724873819659, 19.91885477496732, 34.71270538145496, 21.99869352002298, 23.087937678060225, 9.531682133674622, 1.8864901652259214, 33.30801440823463, 59.76093384527392, 61.175677853245894, 70.34098609801262, 57.85304200264716, 58.404256605332904, 38.56763824339836, 9.39516305923462, 0.950947882186982, 0.07493560277526418, 10.153862218702994, 48.36677797379033, 65.87943123232934, 67.79091988840412, 61.928204182655584, 63.684202240359404, 62.174517262366514, 67.80175347482005, 55.12602198508478, 60.16356514346216, 61.142251414637414, 58.25799926634758, 55.13228601024997, 50.43560858695738, 49.81680370146229, 55.30828275988179, 58.55322037973712, 58.1132520398786, 57.28583589676888, 58.098503928030695, 54.97403798564788, 48.77892494201661, 46.18591270139141, 51.70569558297434, 53.16351113780853, 56.71577822777533, 54.75968045573081, 38.97361924571376, 34.99599464478032, 28.870117318245676, 26.992614038528938, 27.68555368146589, 27.220097780227665, 25.9875851292764, 9.117952489083814, 0.03201865628662129, 0.04984703530827838, 0.07746362397747655, 0.06818548716124027, 0.0313074566468957, 0.05728714333306398, 0.11465376828827205, 0.16688638607100134, 0.039431039589427175, 0.0495914300723422, 0.03363846110240106, 0.048712485905496344, 0.01748572896054435, 0.06371668945517271, 0.07197213719689077, 0.023076856967001673, 0.008799855676179212, 0.29595998987074823, 0.1173209723445677, 0.012267771958103104, 0.048298189386485085, 0.11576859475744349, 0.031774680265375686, 0.08214712548520296, 0.03621055917333692, 0.1044374265738072, 0.048084535125282504, 0.08384228653965459, 0.08823342591283784, 0.056015253517656564, 1.7680800610011624, 16.608305708054576, 15.574911198308392, 14.371451543223474, 25.747512540509625, 26.40175800169668, 32.05100263318708, 39.38114173950688, 40.51201205099783, 47.73739053357033, 42.996374637849875, 45.788780566184755, 42.63802297653691, 45.04908823197888, 44.09653279089159, 48.20174032641996, 48.835556122564505, 50.48193962343278, 49.84245992475941, 48.57458122314946, 44.34099843425136, 46.480886705460094, 53.801492491076075, 57.58501860403246, 56.745741213521654, 62.25148985462805, 55.54595093573294, 60.386744083896765, 54.43402959454445, 54.97447336873701, 52.60254944524458, 57.31829743231497, 57.39007680646835, 61.376385534963305, 58.5074031737543, 32.04718616700942, 3.286010228818463, 4.611563951738419, 25.614863864837158, 48.45058333489203, 43.45558612577377, 44.3385979437059, 61.237914100770034, 57.06160968349826, 56.410127532097604, 59.0565977558013, 54.592795372009284, 8.921242683164536, 0.2641169017841739, 18.01847231003546, 33.74249535222208, 19.001161359971572, 32.29680188240544, 32.63844620796942, 31.679971910292107, 33.6436673133604, 34.17654875786074, 36.4319625977547, 28.371878247107233, 32.343858557362715, 32.22256710452418, 31.82640575593518, 27.89341380519252, 48.54675985151722, 66.86658982307681, 11.358062221157937, 0.6084849457106283, 0.09333342644235781, 0.10339869561815455, 0.040411800671849525, 0.06825884774086938, 0.0543285155999324, 0.0993791395317643, 0.03907382811209367, 0.07287294934353522, 0.043184510357077086, 0.044741480641307375, 0.032884488858643084, 0.02474534667036947, 0.06695220051633735, 0.08843456229735767, 0.09620906004021246, 0.22127944074811476, 11.789014993175385, 90.79655447313863, 59.66345902412169, 35.14522514035625, 44.826136789014264, 38.023452528061405, 32.30988298693011, 36.80797276958343, 36.8123972031378, 40.58345410131639, 33.02343860749276, 42.661757238449596, 25.09242573092061, 33.37353760196317, 21.90935761697831, 22.883284091949466, 14.797456245268545, 2.0088643148060767, 36.0749327751898, 75.08105278015137, 70.90994158098775, 74.2941939446234, 64.1048489847491, 61.49320156343522, 45.93492807880525, 15.893559648144631, 2.1345430612564087, 0.09250624300611597, 9.262357488755258, 47.82662053262034, 69.02892189641153, 69.1154807613742, 64.33040095913795, 67.06426943502119, 65.97013212019398, 68.22362792107367, 56.55385101995161, 62.49170364872102, 62.399877040616936, 61.972326924723966, 57.850104147388095, 52.56425142288209, 54.23007419032436, 58.966308716804754, 59.36880273203696, 59.738941115717736, 57.98244883937221, 61.22840235310217, 57.82581683128112, 52.27152885929231, 50.102301259194654, 54.87156606489613, 57.66447013424289, 59.04367746845369, 55.520859533740634, 44.08216907132057, 43.28336269624772, 31.205629879428496, 38.806800842285156, 32.26946492348948, 27.63878922308645, 33.333600028868645, 14.127911579224373, 0.02947277565967412, 0.07625265347380793, 0.0983251864090562, 0.07364292899447103, 0.044674451778372454, 0.03265505318620032, 0.10602250079353971, 0.08194620360530193, 0.046930270449769114, 0.05465220306969939, 0.03800909230185132, 0.01828181497271984, 0.03409579261055878, 0.044427595266531554, 0.10406264103949071, 0.04463906617714994, 0.12234066387698536, 0.7880110317660917, 0.39814183909085493, 0.02263719336159768, 0.06253996691215905, 0.04965572400138744, 0.026238540134903406, 0.06940308432545393, 0.06092622951273957, 0.03313597637198625, 0.05469642549512848, 0.04190725792619971, 0.011551754582943696, 0.08041598128094789, 1.6767595612233686, 28.094084224393292, 19.921378820173203, 8.450675933591782, 29.473166042758574, 32.572605302256925, 34.98572195729902, 45.02695037472633, 43.907925621155776, 50.1689854744942, 46.71122004908901, 49.65386059976394, 45.788031393481845, 48.83506582629297, 44.76368481113065, 50.424433754336455, 50.23171594066005, 52.83682477089667, 51.038896576050796, 49.78898232983005, 46.513191346199285, 49.178928252189394, 55.5082961820787, 58.2278048607611, 58.37464663290209, 62.13186540911275, 55.77418581131966, 63.94280802819037, 57.13277716790476, 58.58245380463139, 57.62577987486317, 61.84955281596031, 60.66611882179015, 65.56649669524163, 58.76786424267677, 33.13817185740317, 4.317535238881265, 9.348950674456935, 35.70777931521016, 58.23051129617999, 46.55306223900088, 51.32388422566076, 63.91452773924797, 61.98937746786303, 62.982490216532064, 60.980881183378166, 57.672765947157345, 8.182756477786649, 0.38220543294183673, 27.4701645681935, 40.093691272120324, 26.6523229306744, 30.19677469807287, 31.387696496901977, 31.375186097237375, 33.20950800372709, 32.6072790545802, 34.33134117434102, 29.58460254053916, 30.591576945397165, 30.576789609847534, 42.86693249979327, 27.97709953400397, 56.65964518823932, 74.69492681564824, 14.288450268007095, 0.7587307835778883, 0.17139001779498594, 0.15230328956198308, 0.00614754484793652, 0.0745017595228649, 0.07532649147774904, 0.28012090753163066, 0.18915846192788696, 0.14411935612799662, 0.16296352560241378, 0.20360851960797466, 0.20123931609334486, 0.11357273395744064, 0.23712531062624148, 0.16778954244669408, 0.19857495422324828, 0.435357716295027, 17.04468115683525, 104.2559245324904, 70.05631616038661, 54.545177798117365, 45.51765457276375, 28.68880967940054, 29.81621457684425, 47.1303919822939, 53.086781732497684, 51.36824623230965, 45.5100255627786, 53.79989216404577, 29.776861436905403, 45.40089737984442, 26.17109125660312, 30.540576327231626, 16.113215319571957, 3.026109813682495, 40.030129263477946, 75.10027239399572, 77.79654887414749, 79.96693749581614, 69.23850982419907, 69.33035604415402, 47.83520660092754, 16.144278530151613, 2.378619899672847, 0.4042012268497098, 14.523526737766883, 54.727881800743845, 74.07260356410858, 72.09342264359998, 66.0297913705149, 69.74793157269879, 67.47586727142334, 69.5417796411822, 60.75494089434224, 64.31276206047305, 66.58399874164213, 63.26696403564946, 61.694407386164514, 56.853492644525346, 57.584481239318855, 61.32828943191036, 61.62054523344963, 62.552080692783484, 61.92892197639712, 61.72068726631903, 61.37058434947845, 55.48229086783625, 53.31895074536724, 57.241309150572754, 59.0569233125256, 62.0288678907579, 60.298012225858635, 49.251464643786036, 48.541633313702, 39.22558838321317, 41.81109712969872, 41.5881613762148, 36.96696604451826, 39.39877279343144, 14.979515018001681, 0.14586263516497228, 0.20650189580215564, 0.12044335520195386, 0.1753074543610696, 0.1403955099803786, 0.13334506491739906, 0.32623817483263634, 0.2524726870920389, 0.15110371844662776, 0.1716821271205141, 0.16009152326132023, 0.07514941791493086, 0.08856797650937112, 0.14504785469222456, 0.22929581543130262, 0.10814236567145395, 0.16176861230163805, 2.334730048333445, 0.6611170247197151, 0.12746384622709406, 0.17405229590592847, 0.1336056573857223, 0.14512214989912126, 0.23513038702789815, 0.15108150189682362, 0.1415509697530539, 0.15672206938747438, 0.19426439197794085, 0.22099462457962576, 0.11087220507643877, 2.3872228832014146, 33.545682584085775, 28.065886305224513, 25.884116926500877, 40.31626224517822, 36.89616726290795, 47.778308699207926, 51.109966001202984, 48.883605157175374, 53.8649917417957, 50.429266114388746, 52.15627393414898, 48.23809285317698, 51.26823363765594, 48.41273246272918, 52.41864911971554, 54.43427278149513, 53.91335064365018, 53.34467364895729, 51.580375855968846, 50.262698742651175, 52.771705581295876, 57.07177646698491, 60.767982775165194, 60.64248261913177, 64.97187322185886, 58.894599945314475, 69.08505885831772, 61.345598851480794, 62.58266341301703, 60.59826966254943, 63.41602586930799, 61.47706885491649, 68.88326860243275, 63.52733489005797, 38.606089238197576, 5.475481181375442, 6.424070615922251, 30.97462384931503, 60.05891630726477, 51.667213209213756, 54.896461348379816, 71.16786879877891, 67.10055920385545, 63.81906117162397, 66.69971650646579, 62.59193981847456, 12.17430353164673, 0.6676996198873366, 24.276362888274658, 41.453800585962114, 28.86668916671507, 42.526035385747115, 43.11271213716076, 39.335406903297674, 47.06445693969727, 42.81886777570171, 51.05261702691355, 39.93967548493416, 41.406928262402936, 44.031193948561146, 42.918523434669744, 37.703736212945756, 66.82601682601437, 85.56541489016625, 22.1629584604694, 1.3113442015263344, 0.32980002402778597, 0.2614046134535344, 0.1455516341112314, 0.236480065411137, 0.2123597717934078], [0.06286455070479743, 0.021807853387848988, 0.04071852312453332, 0.04891091799964348, 0.048543567348632126, 0.10195368525361824, 0.041274641670527, 0.12902639746185274, 0.11017687303284485, 0.04101744297170832, 0.12258395041909911, 2.175142534317509, 69.72675861850863, 59.47953908674179, 44.0197955408404, 36.81791597797025, 23.18612244821364, 27.706654071807865, 27.770992709744363, 39.801109913856756, 36.288592123216205, 34.123275126180346, 42.31784382174092, 23.096661029323457, 8.27937916401894, 17.140135957348733, 18.579457536820446, 18.30972202362553, 0.7287640593224957, 23.268307870434178, 53.56617381495815, 33.8923926507273, 47.52972064479705, 52.91399740403699, 53.40383475826633, 50.846441561175936, 40.47530651092529, 14.733731458264014, 2.254054983777385, 0.4829771900849958, 17.298664431418143, 53.18553132395591, 65.73943399613904, 66.61377737599035, 65.06025598895165, 59.62984038937477, 52.35002725355087, 54.74009998383061, 61.42419138262349, 58.827174402052364, 61.62082372173187, 56.84000753587293, 50.489062647665705, 52.25231316781814, 60.699164790491906, 61.46722370578397, 59.442711953193914, 57.813147575624534, 54.46589100745417, 53.9354649666817, 51.341103430717226, 46.954599195911044, 53.19939690251505, 57.37221433270363, 55.95625046760806, 50.907524631869414, 44.49302165738998, 34.216039180755615, 25.55024281624825, 35.867635511582904, 20.008053395055956, 16.255986652066632, 26.524290884694746, 12.970726086247353, 0.3350542533782221, 0.09951197917783454, 0.05158308630568847, 0.10954570851378864, 0.07292671339406122, 0.031385750832757166, 0.06891386823788767, 0.012276961182754849, 0.07386556180614619, 0.052255558285621874, 0.13985885006766166, 0.02157041784225693, 0.050495888797506217, 0.08006627746527234, 0.03653238121900828, 0.02491474594740618, 0.10026620806104715, 0.047406700529879144, 0.23910658253777414, 0.04298089184768258, 0.010107880901365031, 0.027574660677102306, 0.053588160569028515, 0.03937541011480555, 0.045332245513676636, 0.03575990795187893, 0.05539009895836634, 0.037758654328964414, 0.09120042315654217, 0.11316080081967578, 1.1241492076266197, 22.28763491876664, 16.85644268989563, 3.668343261364968, 7.815204406938246, 22.42925209383811, 24.502730715659357, 34.372247572868105, 37.327086694778934, 43.6879434124116, 44.53056658467939, 45.78009643862325, 45.73776229735344, 45.21123117016208, 46.53434861090876, 48.40838647657826, 48.64294813525293, 47.15900959507112, 50.508725489339525, 49.2222547531128, 45.65863240149714, 46.34659259550033, 56.53971087548041, 53.23715363779376, 59.00680718883392, 54.56476611475791, 58.44104059280888, 59.924335864282426, 55.47520314493487, 54.003863257746545, 54.69476130700881, 56.65993936600224, 57.89987118013444, 56.601527429396114, 49.844162233414195, 17.647298420629195, 8.752298355102539, 34.96138757274997, 50.394360942225305, 54.04949611233127, 43.00697680442564, 30.94885976083817, 51.77299561039094, 51.78415475353118, 51.11194679814001, 57.990983916867165, 43.40657611047068, 3.539362982396157, 0.13147812396768602, 26.140855666129823, 25.073274758554277, 25.56865049946693, 35.32462258492747, 31.007846324674546, 34.20582925119708, 31.785283627048617, 35.138055047681256, 32.830328556799124, 30.389251285983672, 38.01749052539949, 28.522126597742883, 24.823296223917318, 38.36198445289366, 52.503356625956876, 65.42512662949102, 4.481897257989453, 0.331752659572709, 0.07995273557401474, 0.0525475220544444, 0.041022962635202755, 0.03402719326737908, 0.042656273581087596, 0.04553131729124054, 0.09342283656400058, 0.12954552928286214, 0.05174330210373287, 0.01361682406446386, 0.040597546349970565, 0.06279534998259718, 0.0032415181481009053, 0.13459588731488875, 0.04906621168277437, 0.12314363127394069, 3.4071666050341824, 80.37214186883743, 69.48277934905022, 42.920896468623994, 41.57893203919934, 23.42612051194714, 40.71203724030526, 30.98813641455866, 35.812530133032034, 36.681880335653986, 34.85431471178609, 37.38343546467443, 21.785981424393196, 13.353184634639373, 12.380726106705206, 16.165321065533547, 20.77666340335723, 0.7550679027072845, 21.8085370140691, 66.28217235688241, 42.307143595910844, 52.637493841109745, 57.15375008121614, 61.57657938618814, 58.39475662477555, 48.437772873909246, 21.43565885482296, 4.889260895790593, 0.34965331515958237, 14.598766623004792, 51.12426696285125, 66.13454218833678, 69.89647957586473, 64.75395025745516, 62.093308510318884, 55.07613728123327, 56.87273579259073, 64.64510448517339, 60.95228710482198, 61.102007896669456, 58.156158847193566, 54.269286124937004, 56.165454003118704, 61.982897712338364, 64.18739918739566, 60.19772898766303, 60.109871818173325, 57.09409867563556, 57.49695354892362, 53.992990447628884, 50.58574907241329, 54.64732023977465, 58.70765978290189, 57.27911295429353, 53.33763691686815, 50.88267641682779, 32.61882455118241, 32.9962997282705, 37.870307507053504, 15.620391080456397, 14.073838764621367, 29.31407274738435, 19.40599310782648, 0.6590400684264399, 0.03035586819262995, 0.0438882157416834, 0.048323232800729816, 0.056744902469818635, 0.06851000966684473, 0.022369064503319325, 0.06988126108603132, 0.0160116829060679, 0.05366944632823429, 0.030712168025333556, 0.007641188389125972, 0.07008556907455768, 0.07175620765455308, 0.08111941087390147, 0.07381313840948767, 0.17838748021712228, 0.9751556477239056, 0.4675721425202585, 0.054605038866641066, 0.019435798110921058, 0.06881999948452558, 0.07700027101823399, 0.013523667772871353, 0.027065340527183106, 0.04260504528159096, 0.029780553398473613, 0.06891593667528323, 0.06303722309249063, 0.045476369634871526, 1.7097975626107187, 29.582464848795247, 19.98328951097304, 2.4775420754186572, 5.808766936102222, 25.904787817308982, 30.582688854586696, 39.67907321068549, 44.229297176484145, 46.54058517948274, 49.08954920307283, 50.2302215176244, 47.820944862981, 45.52889216330744, 51.56884408766224, 50.38816751972322, 50.395996570587165, 51.024383806413226, 53.34703099343085, 52.95475083012735, 46.34221130801786, 47.30742423765121, 58.77336340565836, 56.79275866477721, 59.99197321553385, 56.19521694798624, 60.084164604063965, 61.55381787207819, 57.05452196059689, 58.19929315197853, 59.82915955205118, 60.39764042823546, 60.465579801990145, 56.13142351950369, 49.721274375915534, 14.796003007119703, 14.475402197530194, 42.61002902061709, 53.74448868536181, 58.32351853770595, 47.39265734149564, 35.7447672659351, 57.64226167432724, 54.21810703892862, 52.64819014456965, 63.270713821534194, 42.66713873032601, 1.7218184014481885, 1.2188066638285115, 35.84063391531668, 26.34695072327891, 28.184220290953114, 29.394944175597164, 30.225908102527743, 33.28549215870519, 32.982241953572924, 38.494988103066724, 26.72356886248435, 32.983579481801684, 32.44276504362784, 30.433634865668516, 25.851696575841597, 31.93124482708593, 63.6677400527462, 71.78008802475469, 5.452408329133065, 0.43312901330571024, 0.1914902497082949, 0.10461818501954118, 0.0557799113073176, 0.05216724750015044, 0.11738940697884369, 0.287615055398595, 0.24095970326133315, 0.2510392752986762, 0.16517102327798644, 0.2034746227605689, 0.2562276670528997, 0.2696358298342074, 0.31126066561668153, 0.28022460519306125, 0.2804425725292775, 0.5152198696328748, 5.201373206030938, 93.17321269742905, 76.642744464259, 60.53551173979237, 50.06931804841565, 26.145888067060902, 37.2882983761449, 36.25467146596601, 53.31095695495606, 47.37825439822289, 46.48088278308992, 57.4840489510567, 30.020501421343898, 15.905654276570967, 28.17652656186012, 24.931434008382983, 25.37183577014554, 3.2551855473749103, 29.82075275913362, 66.11047452495944, 48.19998702695293, 63.03677974208709, 62.597893976396136, 63.01847011812272, 66.29296671959662, 53.01293526926349, 18.240050923439767, 3.7262151366279976, 0.9581020402331507, 22.551465303667133, 59.35791423243862, 71.6299004708567, 71.02308627097838, 67.26827190768334, 64.90903292932819, 60.84595557182067, 58.38861811545588, 66.00182487118629, 65.4969177707549, 64.05787860193561, 60.59930516827492, 55.29756684457102, 56.98489204529793, 66.19728442161315, 67.69622602770406, 62.031746910464385, 62.05138621791717, 58.966395008948545, 59.77963570625552, 59.102371815712225, 53.24102893952401, 57.64252055075861, 64.41910143821471, 59.06869434541272, 58.96680293544647, 54.1229268043272, 40.993016227599114, 36.545142589076875, 49.231072241260165, 35.84831783848424, 27.27769974739321, 40.92630847807854, 18.984110816832512, 0.3824890080478884, 0.2040312622463511, 0.18328098940753168, 0.15060254372656345, 0.1941702091285298, 0.14227924357739188, 0.08666905904969863, 0.19822016358375552, 0.17112087578542773, 0.15335987802715073, 0.16818128916765415, 0.1696395528532805, 0.18031034558530779, 0.31745448648448915, 0.1782413719282035, 0.15287016398243367, 0.3312243346966082, 1.304271677809377, 1.415033773068459, 0.21747137089410137, 0.1747251662515825, 0.12763312867572232, 0.10395089945485515, 0.13686542279056965, 0.17629045242023084, 0.10273791413994567, 0.1443850047766201, 0.16385086992334935, 0.16428069121414618, 0.19124689421826796, 1.8755075287434364, 36.30563089924474, 26.950650561240415, 7.971757967625895, 20.440067168205015, 35.12857467897477, 35.91615523061445, 46.9176818478492, 46.63236471914476, 51.43365959967337, 50.84863024373209, 52.69428191646453, 50.77759611991144, 49.23015440663984, 54.59544689424577, 53.434644975969874, 52.58024684844479, 52.304676809618556, 53.95009540742444, 56.347499047556234, 47.96821417347078, 50.33225021054668, 60.80068749766196, 57.05105458536456, 62.66325635294761, 58.715320171848425, 62.091700338548236, 65.8301897971861, 60.7738898646447, 60.515621400648556, 62.44408999719928, 64.09312502030404, 66.27088377552649, 64.01845093696349, 54.39881847750757, 19.409364384989587, 12.189349743627734, 43.27030512594408, 57.61212218192316, 65.35685385427168, 52.890565164627574, 40.143677957596324, 59.78368359227335, 61.697541359932195, 60.36284508243684, 66.68763560633506, 51.97260895083028, 5.758717982999741, 0.9571729900856173, 35.40541164336666, 32.51112803336113, 35.98898187760384, 43.9228267054404, 41.41905623097574, 44.815758197538315, 43.49618265705724, 48.735402322584584, 45.260947212096184, 40.54250455671742, 47.544762934407885, 39.5706549767525, 33.39675411101311, 50.39644764315698, 70.96294849149643, 83.76498422315045, 10.541566937200486, 1.2185361428606896, 0.3665234292707136, 0.394548365786191, 0.18488692420144237, 0.15239649181885107, 0.3220988485601641], [0.16066040483213243, 0.04349498281015023, 0.04749193164189497, 0.02393908892577935, 0.056105805110306516, 0.0210680365337119, 0.0584999026520358, 0.032319261527229706, 0.10365332026154765, 0.023400969615566636, 0.05934550667241697, 0.07518585305660963, 53.09520306125764, 68.53972388852027, 53.0698331709831, 43.37527167412543, 55.927730914085146, 37.239190301587506, 35.74549290441698, 48.361984837439756, 44.853911092204434, 36.712404220334946, 36.68873663871519, 35.64761407913701, 15.774809891177764, 19.01395809265875, 21.23386271538273, 27.948595669961747, 2.99909497941694, 1.7046476131485355, 27.571701003659157, 44.45033842517484, 73.26328523697393, 65.35999959514987, 57.80123533741121, 34.2925646228175, 40.96660298685874, 52.54165857068954, 32.82172091545598, 4.917003820019384, 0.45220729924978753, 16.916009764517508, 52.05024050128076, 58.26177258645335, 58.02698735267886, 51.56061103267055, 52.76171138209682, 55.56258178526356, 58.267730666745095, 63.11682747256372, 61.24905363205941, 58.50125289732411, 53.02934646606446, 52.07615560100925, 56.81763433641004, 57.21939486842002, 58.30917050761562, 57.94311923365439, 58.77829382496496, 55.207301339795514, 48.469528382824315, 55.617024283255304, 57.64408949882754, 54.81612336251044, 54.98542070388795, 46.68861150741578, 39.310805797576904, 16.445615599232337, 32.69893503958179, 15.226602765821642, 5.35908680769705, 8.358229591000466, 19.589142299467518, 21.52551643310055, 0.7792275579225633, 0.014058728477046376, 0.0523657217291334, 0.04877664576915484, 0.028139376644826228, 0.028118835912356456, 0.03877206990915922, 0.06506110481437176, 0.02096380835639373, 0.03315750727309816, 0.08692027460182868, 0.06853882989455616, 0.0688034136809649, 0.04771560250270752, 0.1560307363228452, 0.05759645133249222, 0.25646425032567594, 0.681960009519131, 0.05369172799551199, 0.0751081717410876, 0.05829017076100554, 0.01747869435817965, 0.012901367848708987, 0.012723514791427842, 0.035051893322698535, 0.037459290150793335, 0.03307365894978566, 0.021320793837789568, 0.04030727946590032, 0.0809498219901035, 1.5128784001834932, 21.140663277718332, 12.029891667827485, 4.841062811113173, 1.7919370195557995, 4.989498046136672, 16.064805426905234, 26.23073481744336, 37.065899987374586, 40.106650783169655, 44.51846999506797, 46.99621554343931, 46.28083405956146, 45.50956664546844, 47.63155714158089, 48.85541900511711, 50.31412101561024, 49.36581350141957, 52.876248513498616, 48.02137405641618, 45.57654896090108, 49.20596514978717, 56.94924554517193, 57.76062703901722, 56.17813894825598, 54.38287796512727, 57.469418510313965, 55.10771628349058, 55.68921550627678, 53.22559833526612, 55.520318246656856, 53.20233083540394, 50.08490162511026, 42.04751799183507, 33.1465696519421, 12.953669659553036, 29.387250446504165, 50.11982640912456, 49.61055371069139, 53.01368051959623, 47.43812545653313, 42.218235231214955, 49.15481352037, 59.03625242171749, 49.83357183394894, 55.46622483961044, 12.379244431372612, 0.2601994345745733, 8.217822467127155, 31.374976250433157, 25.561974625433646, 25.02949522387597, 34.28680266103437, 32.09260329123467, 33.80812837231544, 34.806434339092625, 33.301185561764626, 42.250233927080714, 32.58997159619486, 34.6660291764044, 33.915471876821215, 37.80730639734576, 41.58665126369846, 52.86882346676242, 47.27212682847054, 1.2510458500154558, 0.023989972485710057, 0.09916594492331629, 0.032603269472958586, 0.05472184812289573, 0.01509803591386205, 0.010308194698976174, 0.061637653233183015, 0.08613170199697057, 0.045708268279990846, 0.0348673120982224, 0.047433329746127136, 0.07239022968156685, 0.04795164185305757, 0.05673882739257909, 0.13178409948464365, 0.12725130279338168, 0.01883036457002163, 0.30524243210111895, 61.42576033069242, 80.91530384555941, 50.50730559133714, 45.199040443666526, 39.37178688664591, 36.727952495698005, 42.614088673745435, 39.4542900208504, 42.045231250024614, 33.05618255369125, 35.584326636406686, 36.38993440135833, 20.662255710171117, 16.798564195632935, 18.24237688895195, 38.44264799548734, 6.439615459211412, 0.43204885997599174, 22.697914838790897, 44.40583913556991, 76.67577866585025, 68.63960312258813, 65.66313605154714, 44.172909182886926, 45.31381291727866, 59.86861075124433, 40.876239422828924, 9.404173724112972, 0.9700900292204273, 14.448901684053483, 51.69332050508069, 57.60258297766409, 57.07466333143173, 52.6957175039476, 55.12403334340742, 57.08642259720833, 61.53504540843349, 64.54717466908117, 62.34308896526214, 59.90432785403345, 54.050037399415054, 56.00741778650592, 59.15370387415732, 57.38663296545706, 62.357805698148674, 62.72757145666308, 61.647319332245864, 55.855563225284705, 51.798518473102206, 59.35940081073392, 56.25002422640401, 57.18688234206169, 52.096606839087706, 52.49578645152431, 33.79906769721739, 19.203877295217207, 32.22356338654795, 13.712837542257002, 9.930859784926138, 15.001702885473929, 19.76624123511776, 26.029164214288038, 1.664699130961972, 0.005198624773672032, 0.04999920335267821, 0.047117253359887874, 0.09104123008587668, 0.020412190576955196, 0.01011130818721628, 0.08965476416051389, 0.0334066275747553, 0.05407372241719596, 0.06047858901682401, 0.009104296144458556, 0.07241501262591732, 0.057933081857739925, 0.030606702616017674, 0.031211839297846444, 0.9824136260055727, 1.1649628175843147, 0.1809337113292948, 0.026625899087277152, 0.05006635862012064, 0.06711961371043036, 0.08521469475160684, 0.027453904152817787, 0.08192469951726737, 0.1168687966081404, 0.039860883862861705, 0.045448104820905194, 0.1147859490987274, 0.1617184182208392, 2.738781734820335, 25.20250704980666, 16.793286646566084, 9.713493797086901, 4.449077806165142, 6.108756671028753, 19.29117552695736, 28.9691787381326, 40.85656481404459, 45.448165862791, 48.046218349087624, 50.91412990323959, 49.62715318126064, 48.25035025996547, 49.84677060957878, 51.910788474544404, 53.0206976398345, 53.86719611383254, 53.30128439011113, 49.71388855288106, 47.25972037161551, 50.2056674803457, 57.27648104390791, 58.897325992584236, 57.976008307549264, 56.48440153368058, 58.01042710581134, 58.425362879230136, 58.13703729260353, 57.01880093543761, 56.164398885542354, 57.0578363633925, 52.73849879541705, 39.12735654461769, 32.58868701996342, 20.390498215152373, 37.33561784990373, 54.18937175504623, 54.95794450083087, 59.305452531383885, 53.48596526730446, 44.06748763976559, 53.6557960510254, 65.62277878484419, 61.69387786619125, 53.64074591667422, 5.270381425657581, 0.35406359140911414, 14.382435160298503, 34.730626690772276, 27.180728950808128, 26.738793542308194, 27.941711910309333, 32.467515199415146, 32.267113462571174, 37.19279650718936, 27.46336513949979, 30.783694636437204, 40.607353102776315, 23.414078835518133, 44.06247877305554, 33.29850658293694, 42.6133002773408, 59.39958941551947, 55.61702820562548, 1.1393671458767307, 0.23516251675544247, 0.03862611100738568, 0.07060559721843851, 0.05950212951809649, 0.01429101974222689, 0.12156889924118597, 0.2954392645868563, 0.21433454727934254, 0.13779674055835894, 0.18410329286369587, 0.18429335927770985, 0.13902148532290615, 0.13596575977581163, 0.149460076805084, 0.2719414786946389, 0.32239483429058907, 0.15048833533881173, 0.6706146150827409, 75.21030272206953, 90.00295700565462, 67.61664113690777, 58.986716808811316, 65.83379053300428, 46.87251183294481, 47.063739145955736, 64.64375911220428, 60.75456042443553, 48.77427301099224, 53.45187987050703, 49.973471010884936, 19.715979983729703, 29.948219983808457, 30.935978697192287, 36.62232306695754, 6.1655030712004635, 3.575941780882497, 38.28933039019185, 50.273093023607814, 75.94690030620944, 70.49227191555885, 65.08411576670986, 46.06949675467707, 52.6819460622726, 68.89705965595861, 39.318772131396884, 5.591636290473323, 1.783265517123284, 22.174125448349987, 58.30876650348787, 60.9245284911125, 60.11389224759994, 52.66185568225, 55.7000804716541, 57.58991372200751, 62.64270313324467, 67.92964627665859, 65.09509448082217, 64.40598895472866, 57.98850890128844, 57.90791203898769, 61.060309179367565, 58.589066920741914, 65.03478411705264, 63.589798635052105, 67.64936154888522, 57.351523830044655, 56.07084251219227, 61.45948486943399, 62.93589245888495, 59.014479344890965, 59.477597513506495, 55.4467777282961, 48.89280703759963, 29.20432482996295, 45.28029234178605, 28.129167864399573, 14.405285908329873, 17.374779985797023, 31.925829995063047, 34.880578902459916, 2.2315866668378157, 0.12361735706367802, 0.3860974353888343, 0.09089358962110936, 0.1455663276776191, 0.1601399859834102, 0.15695345858412404, 0.15781569054290173, 0.08575628060967692, 0.22786511558919187, 0.17820872126087067, 0.11935636070707153, 0.23031308826419616, 0.15495684959234732, 0.42059183120727545, 0.22418069232615734, 0.9556831022904766, 2.557856772215136, 1.0765214600870687, 0.3042770387424577, 0.2359785995776615, 0.14153396260113488, 0.17994102991877065, 0.21306244295931634, 0.21494072201030873, 0.21708184582812173, 0.14667179255235582, 0.11160689105670299, 0.14442818149203254, 0.4665398543640491, 5.18928446115986, 35.81657017430952, 24.713548306495916, 11.334830022627308, 6.604344710226982, 15.079342280664752, 30.851877197142574, 38.96513908140121, 47.52710050152194, 48.16141443867838, 51.81179961850567, 53.10646026365219, 51.55365667035503, 51.22345585976878, 53.50421605571624, 53.602243931062766, 55.75270298988589, 53.32144929516701, 56.68623493563745, 50.92885055849629, 50.420209361660866, 53.18671980211812, 60.604745495703916, 60.14990745052215, 61.234042721409956, 57.114518534752634, 60.69329300234395, 59.36285249648556, 61.225237000373106, 61.98887540448097, 61.617293588576786, 60.089228383956424, 58.25124886728103, 47.28967159025131, 38.07017972392421, 21.174717295554377, 36.77393444122807, 59.336882483574655, 58.71619878276702, 64.04575847810315, 56.047555400479226, 51.35171736440351, 59.905990938986506, 68.05325585026895, 57.01801646140314, 66.53919742953393, 16.018800927746682, 0.3942503269401289, 10.353708940167582, 40.46911308842321, 33.84929756964407, 34.7061393337865, 41.0373233210656, 43.46013607517366, 41.457966143085116, 47.223324698786584, 41.65082516208772, 56.975650941171956, 45.62311533958682, 44.106927071848226, 45.678475672198886, 47.678099986045595, 56.09467875572943, 68.62359985228508, 70.52769091821486, 2.9157073507385873, 0.8414340812352397, 0.2328858260185488, 0.19884234955233915, 0.21019252437737682, 0.14068081644513916, 0.2111365132394337], [0.03616843199838073, 0.04618164166928299, 0.029760702145135695, 0.04652980181779112, 0.08116470199198493, 0.05079557856304511, 0.08362660214545266, 0.04815323022945274, 0.09980434897325693, 0.17373974735458053, 0.03292489233576963, 0.2968534628950781, 15.252700255763147, 69.13146834219657, 54.603958437519694, 42.933161720152825, 49.105579929967085, 53.174246664970156, 39.948265475611535, 42.293968354502034, 31.90598084080604, 43.44474077224732, 29.572794245135402, 31.266546249389652, 20.185909348149455, 8.769307713354788, 17.298672276158488, 32.22052551084949, 18.574050549537905, 0.1905403006821871, 23.881845012787853, 57.53744025384226, 61.49668462814824, 71.51368064265098, 58.920311081794004, 29.26094424340033, 51.15659513781148, 54.32069270841537, 54.32173213651104, 30.50407671159314, 12.552393540259331, 5.062284979128069, 20.70661379444984, 45.21915828028033, 49.4902350056556, 50.959601940647254, 53.37340893283967, 56.379725240891986, 61.61438318990893, 61.40503060433173, 63.78708208760908, 59.7512024448764, 53.07856044461651, 56.954470142241455, 63.286403302223455, 62.86338744624969, 64.0946900460028, 60.87681285796627, 55.955666034452385, 56.03694146679294, 54.93888962653376, 57.36613465893654, 50.66955835588517, 61.64362053717337, 44.84146933401785, 46.436226598678104, 8.13981289825132, 4.614732736541379, 12.491510510444643, 8.790759155827185, 9.681665724323643, 18.46892514536458, 10.503778822960394, 14.688566346322338, 1.0797061795188536, 0.05810154076184958, 0.0869563956474585, 0.062589785609875, 0.05164770582210153, 0.0982570888534669, 0.05158225893073025, 0.1554738976542027, 0.03494948651942034, 0.02481390387871333, 0.022722024192673065, 0.03717275794535395, 0.0577549472631466, 0.013054417851831646, 0.08764587477931092, 0.14267819152484018, 1.1169924755250256, 0.8058082961267041, 0.13145532519105943, 0.015234092171604355, 0.07466554146019683, 0.07783652493549932, 0.01530355049086915, 0.03865490442201976, 0.023395394410697684, 0.06349061690871755, 0.056450732367774176, 0.03009630419734505, 0.09193225928972806, 0.05188489047389838, 1.9588243096105515, 13.910519115386473, 9.633740244373199, 9.183866939237042, 5.299477567595821, 5.944209810226194, 1.9460303961269318, 10.353419665367374, 38.31786563319545, 39.47634550832933, 46.94441280057354, 45.367643525523526, 48.21912034865349, 47.71118517844908, 49.83517608334942, 48.714143076250636, 51.33820872153006, 52.032334881444136, 53.32359483165126, 47.37611670647898, 46.416030314660844, 48.84851955598401, 54.8026970894106, 57.53435727088683, 57.25570032673498, 54.347282455813506, 57.40986516398769, 54.85074612402148, 53.841736009044034, 49.20408633447463, 50.67345326946628, 50.71283386599634, 39.63804914105324, 20.523425379107078, 20.844914605540616, 34.11002143736809, 43.53557502069781, 62.17404657794584, 46.08341332404844, 49.15470761637534, 47.62037838658979, 62.219157757297644, 51.06825551679058, 45.66948559976394, 52.24248370816631, 13.616426664014018, 0.11901011960881373, 14.949446128260705, 43.521501556519546, 39.67570781707764, 19.047817953171272, 24.80422369895443, 38.08999161566458, 29.856917012122373, 35.72951316833496, 32.679295732129006, 48.076236248016365, 46.8024936029988, 26.930216973827733, 37.4412041325723, 25.127140668130693, 23.63171938926943, 45.29910795150265, 62.61628204776395, 28.3353570584328, 0.5674078627940148, 0.1650175299014776, 0.038222474601840785, 0.029479182069940917, 0.036476203991520795, 0.04692150640391535, 0.03134582999102291, 0.037018697663781144, 0.029155488854514498, 0.0402437056595039, 0.026779319685433182, 0.05508313901842602, 0.11413931726447998, 0.012077853016014542, 0.07999932138069023, 0.0319613682316436, 0.05815997028783445, 0.162708280427802, 0.23193794542983656, 20.591541259519516, 86.75693681163173, 55.5402321200217, 52.48012050505608, 44.870169316568685, 36.27671126396426, 50.483606630756015, 30.121463229579312, 34.69435653378887, 45.21755795325003, 30.86674886365091, 35.95476704259073, 27.67611449764621, 18.016020828677764, 13.236954019915673, 32.84159164274893, 29.38040787173856, 0.1453288863863676, 15.663488122724718, 58.9296777017655, 63.83637843593475, 67.01007012398013, 55.86450230690741, 30.693468355363418, 59.57024781934677, 56.15504795505155, 60.8760872194844, 37.41435943111297, 18.151811322858258, 6.907101677310083, 20.124894918933993, 46.62990147067655, 49.23188024951566, 52.87018452921222, 54.29116510575818, 57.40768824854205, 63.00602443756596, 63.28545016627159, 64.03845894721248, 60.5383123120954, 55.46462059020997, 59.66956223210981, 64.9537597164031, 65.65107476326727, 62.57278296255297, 62.7855440878099, 56.30538848138625, 59.065234814920736, 57.166646834342714, 58.29298288591447, 54.57738830197243, 63.358727885830795, 46.634639693844704, 49.47553788461993, 6.2552106188189605, 6.879449948187798, 18.51489140141395, 16.287700976094893, 17.38570378672692, 22.225412399538104, 18.200030980571626, 15.88987163959011, 1.61651685833931, 0.047913084647828535, 0.050103149992684205, 0.063305675622917, 0.012308480912789464, 0.010738619284013347, 0.028658715309575204, 0.1182818764279927, 0.03469663153913233, 0.03912553521654299, 0.03715582740222735, 0.05835614242260495, 0.14379193014915914, 0.02688349040615703, 0.00515130064975951, 0.17429980359250502, 0.9445353585385508, 1.2554891599762825, 0.19430389147131674, 0.032563758488263816, 0.05554301393849235, 0.02907972084358335, 0.023838922929679675, 0.059525165781979604, 0.01754133162208863, 0.09487438165853102, 0.11058319840700397, 0.08901589279693943, 0.08156253145106378, 0.020401093793371995, 1.0212757342284726, 10.349812065401386, 15.005211445593066, 17.982974859976, 11.3411646504556, 9.223753521519324, 4.78304801448699, 10.553733148882467, 43.4567863710465, 45.475755814583074, 48.77839149967317, 49.42178572377851, 50.770535853601274, 50.39973851173155, 53.98620082486061, 50.652492123265425, 54.121957978894635, 53.84212824606127, 54.35880637937977, 48.70782021553286, 49.30249860209804, 50.7149362564087, 55.89354745803341, 59.574636951569595, 60.363029433834946, 55.55208160031227, 60.59237041781026, 57.19904561196604, 57.483860677288426, 52.8934088830025, 54.763108607261415, 52.0210619895689, 37.78044208403557, 20.31698711456791, 26.154023062798288, 42.57299792382025, 49.11178119720952, 65.54187597767, 46.82707117449853, 54.68333936506703, 52.16134948115195, 60.53326422168363, 49.98504592526344, 55.13317246590891, 50.14862052855953, 7.728712712564777, 0.2694998032623722, 29.078910966073316, 49.03827205781014, 40.50788179520638, 24.969649660971857, 24.699400317284372, 34.07093109623079, 28.577730117305634, 34.218733849064, 30.249195214240785, 29.40836064277157, 48.05702840128253, 27.48698369149239, 30.839660975240893, 33.229319895467455, 18.794756435578872, 50.14254477716262, 70.34698732437627, 33.90425389812839, 0.6261171640888338, 0.14030069893886968, 0.012841978797598953, 0.04993413950526907, 0.01510620432635469, 0.044717065419160554, 0.09886104192945266, 0.18923128624596905, 0.1729995838456577, 0.09105924081297652, 0.14556258916854858, 0.22483270975851247, 0.2634039190748046, 0.17268639178045336, 0.20529703868012275, 0.14581725211633792, 0.1711236643454721, 0.40360655875936635, 0.46128666689319, 31.022861157694173, 100.51217909782164, 68.95016070335143, 59.477919147860625, 60.23287734677715, 68.7361091183078, 49.751190293219786, 55.11215640652565, 40.00968979251, 61.07971706698018, 41.361413078923384, 45.613176053570164, 25.16078087591356, 17.293941897730676, 26.421571854622137, 42.46211644141905, 24.956890190801314, 0.26412633998740104, 29.05397253651773, 68.91282758405133, 66.7434823128485, 75.86847643698417, 65.14943891955961, 40.237881522024836, 65.70976126578547, 66.82222781642791, 64.88617335596393, 39.838031184288766, 14.956575036048891, 7.4003617898110425, 26.022829586459746, 52.924776077270515, 52.64727230994932, 53.331063024459354, 56.272773973403446, 61.89974346468526, 66.48059721915953, 66.68606665826613, 66.96588070161881, 64.48913143527123, 56.635224511546475, 60.85504762588009, 67.03394166884884, 69.97871598889752, 64.56371530409783, 66.8790158917827, 57.04364130573889, 64.32205807778143, 60.69489725174443, 63.06588765113585, 55.015838684574256, 65.54754772493916, 48.99476905022898, 60.03713146332772, 14.576177693182423, 13.238097390820904, 27.78181060667961, 15.244932001636876, 18.464359506484, 28.158768030904955, 24.885501092480077, 26.74595186787267, 2.405650668567227, 0.20539742684172047, 0.2347854789226286, 0.1957111796664615, 0.1185682324332095, 0.13949443736383993, 0.22151729572684536, 0.34730798294467313, 0.18618250145546852, 0.05456394974082228, 0.2142518557487957, 0.2199124028125117, 0.19973326384300188, 0.19139563784964625, 0.17682335850211883, 0.3746700389010291, 2.502374355831454, 2.015788278752758, 0.4269410453496441, 0.12129932056151091, 0.11709055607958187, 0.16255650308824357, 0.13602942168231935, 0.12956302673105272, 0.09227414900857596, 0.22155645814153457, 0.2020548473322584, 0.19788735966768958, 0.0900803260024517, 0.20359822338627231, 4.881341140116415, 23.246962331956436, 19.469864983712476, 18.8453471660614, 12.765204675735967, 9.868128338167745, 8.304244049133795, 20.45701769090468, 51.169421288274954, 47.4594670726407, 53.7414998392905, 51.02135965901037, 52.107448270243985, 54.11984382137176, 57.13038844446982, 52.835189142534816, 56.722438412327925, 55.69453031786027, 57.69257783889771, 50.45582056045533, 49.63082059737175, 51.5008419559848, 57.920918618479085, 59.14067768281507, 61.629135224127005, 55.069237832100164, 59.18706363247287, 60.40179029587777, 59.24215332154305, 58.42167977363833, 59.630460123861994, 60.232794977003536, 46.407581529309674, 27.119736094628614, 28.280332088470463, 41.75836870747228, 52.53600643527124, 71.28619886213734, 55.70118658004269, 60.625549747097885, 58.578974662288545, 66.9184749357162, 55.68135899882163, 54.70665393337127, 64.0937957456035, 19.304762617234264, 0.27065080440332817, 20.984878501584454, 51.719596462865034, 49.27140597374209, 24.85042529721414, 31.472541286099343, 48.74477286492625, 41.66351795196533, 45.60010279378584, 41.71528147112939, 60.21937654864404, 62.966922329318145, 34.5579953347483, 48.23994813426849, 32.91988411257344, 31.372726771139334, 61.84016266176778, 77.93365924589096, 49.52914884013515, 0.6997433617230385, 0.33409946267643287, 0.11815958581263981, 0.2070733667501519, 0.16466696806732686, 0.17927241902197563, 0.19338748177453396], [0.02293549650799363, 0.06637026480729542, 0.07455892500377471, 0.04110661560609456, 0.02920848873233603, 0.07152263510731921, 0.0512368873422665, 0.020491664538220055, 0.11787446320898111, 0.08346221499866055, 0.04159700380818498, 0.21690616654532574, 5.119958039252989, 71.10846058014901, 55.79155406644268, 37.35963060009865, 35.68790858791721, 51.10556510186965, 42.720341759343306, 48.78299636225547, 39.61854319418631, 32.80755723676374, 37.90825643847066, 26.50265705200934, 26.999119289459724, 10.992564001391012, 25.66734713892783, 34.13715639422017, 44.76241396319482, 3.2413270781117105, 1.976149050939468, 38.50486855353079, 70.13928997901179, 55.172796249389656, 72.528531166815, 46.06910059528966, 42.98170105103524, 62.22178966768327, 55.53452114905081, 59.79450933394894, 55.25111421462029, 25.430383028522616, 9.182584324190694, 32.624682611034764, 37.88758947003273, 39.53257660711966, 47.240885150048044, 57.275359246038626, 60.27463097726146, 64.88900922959851, 63.651395536238155, 64.20621871948242, 57.79554005592101, 59.699219272982695, 57.86979052328295, 58.3116102218628, 58.459805211713245, 62.34031192718014, 63.335036769990005, 55.46388318461757, 52.99417849509947, 56.05097570726949, 61.69346209495299, 49.995400982518355, 45.95835247347432, 19.695534629206506, 1.655895125962073, 8.63425168298906, 16.84687799023044, 15.779132343107655, 18.994973821024743, 14.538923021285767, 8.540255023587136, 7.728467074132736, 1.845725952617584, 0.054161676971782605, 0.06057078386807154, 0.05473626589763069, 0.012141615471562311, 0.07832593254504666, 0.14103021382564498, 0.036947665991441864, 0.03544485046257896, 0.059724229898664265, 0.06996199909237123, 0.044227048769713416, 0.009677210210582182, 0.08522318300580786, 0.03066894151420603, 0.14604986705366643, 1.353658240649008, 0.48142681198735393, 0.10213892531370926, 0.08810424050616641, 0.0725250611562402, 0.052022525830374616, 0.06465229731533798, 0.03833704688135655, 0.0611885188658151, 0.09949943831851406, 0.08172272809691007, 0.030641096133378246, 0.04283766021891948, 0.06381309779000378, 0.6038211250016766, 3.9862731820152657, 9.604687248506854, 11.973391886680357, 15.861478582505258, 6.1938142488079695, 7.174649488541388, 3.4108825604761805, 21.67068139199288, 48.13964136185185, 45.599534050110854, 47.970446002098825, 51.051342256607555, 47.5925648596979, 50.153158710848906, 49.53993535810902, 53.73480827577653, 52.73240735453945, 52.24349960204094, 47.47010846291819, 47.92365604831327, 49.59424449551491, 55.6562009165364, 57.36949613017421, 60.90651304491105, 52.59768962860108, 56.50777885990759, 55.96809602552845, 51.8104346336857, 41.577257187135764, 44.26936811016452, 28.1388267009489, 21.026385022747903, 15.87526963603112, 31.567082174362678, 41.24611108533798, 42.99200119510774, 47.55689090298068, 54.11085374893681, 50.589828337392504, 58.23419832414197, 42.02190491460985, 43.8353656953381, 30.154520965391594, 6.648220833270781, 0.1752463358664705, 14.654245607314573, 57.52184098766696, 39.16619193169379, 25.172130254007158, 11.068559923479635, 32.03052982207268, 30.333634038125318, 35.15188532490885, 30.91328778574544, 41.01539727180235, 40.823056005662494, 23.724410879996515, 29.505143165588382, 39.336862102631606, 34.8172483136577, 38.9918621893852, 49.51274156570435, 60.33605529415993, 10.505431121395482, 0.31766427200167413, 0.11362377839583544, 0.0785487951830991, 0.05437755671840522, 0.09032783368902822, 0.11491967740678981, 0.11579959067485987, 0.024633459529028307, 0.05455097987226421, 0.06288803513011625, 0.05320469908896954, 0.0943124408443128, 0.06630815805927401, 0.042470926268687176, 0.04332459336447139, 0.0643702237416179, 0.11253135999844921, 0.05313634872436524, 0.28210627035267893, 7.827643223347203, 81.39469592801987, 65.118354135944, 38.82028987330776, 46.7154562088751, 31.017122730132076, 52.76773222031132, 44.86572134879328, 33.316090568419426, 37.963828579072036, 38.0943807478874, 33.52164237729965, 34.665966418481645, 20.84034308310478, 32.2578017557821, 31.324146255370113, 52.32542614783011, 7.136626032090957, 1.2419117530507426, 34.80166473696309, 77.46253551975374, 65.10648504380258, 73.0354190641834, 47.90406773167272, 53.46831067915886, 72.16741423453055, 58.25635187087521, 59.777007718240064, 60.07124823908652, 33.940253411569905, 11.868583213898445, 36.389216607616795, 37.8675304689715, 37.90382808254611, 47.76970694142003, 57.10084907470211, 60.75446236518122, 67.71066819467853, 64.60117786161362, 66.59843306387624, 60.69645051033267, 63.23080370503088, 59.827316038070194, 59.800565473495, 59.642474343699796, 60.83587508047781, 62.5844245572244, 55.88784433180287, 55.51933765411378, 58.75909774534164, 63.37858684601323, 53.63384254517094, 48.77789335866129, 15.966380411578765, 3.518045145657755, 20.083258959554858, 21.714103990985503, 21.870224129769113, 26.599851423694243, 15.70819922031895, 15.471959767803071, 9.54233136869246, 1.4770607866587178, 0.09827991061273122, 0.06382087741287486, 0.09589000740238736, 0.037336214295318054, 0.03791835684809954, 0.030602111834131425, 0.052854857377467625, 0.008066090916643941, 0.06831199126017672, 0.049253841937189145, 0.04387760542393212, 0.013005068382969307, 0.020450751612623854, 0.15034342214705484, 0.5432875538545271, 1.7349899656349614, 0.05675193132652391, 0.16366255018980275, 0.06480504758656025, 0.0910806606313394, 0.07722058258349858, 0.06025509435623404, 0.03912693715744442, 0.01955429659104876, 0.13733531047980632, 0.03793489668638476, 0.03617004461346134, 0.08898676613405829, 0.12596317957485878, 1.0632264638139357, 4.245225364162076, 11.961424735284622, 20.891365274306267, 24.75515288691367, 12.735674131301142, 18.255057911719046, 8.5243772691296, 17.61389159387158, 51.49580563268354, 50.405465172183135, 49.25630877094884, 53.32983924496559, 50.20511050378123, 52.14569922416441, 52.405850425843276, 55.11043056364983, 55.252298770412324, 52.70735125387869, 48.38616624955208, 49.81213215858706, 53.29806804656983, 58.08382249647572, 57.2637451079584, 61.16914710690899, 54.90711450576783, 58.24035644531251, 57.51881684026411, 52.41820589188607, 42.65643850449593, 42.03805723497945, 25.610659084012433, 19.887364026038878, 21.2606878049912, 38.68812953272174, 45.404392211667954, 44.40586659216112, 52.417017413723855, 59.670272181111, 56.12315124081027, 63.47441427169308, 46.68834870861423, 50.242035696583415, 29.940916530547607, 1.939660099244887, 0.7004230962164941, 24.64234748194295, 65.78271342862037, 36.44087814515637, 28.755015365539062, 16.592476983224195, 29.05584154590484, 30.453984122122492, 33.78575517285255, 25.472746587568714, 32.734620763409524, 32.26142994819149, 30.08872320575099, 19.685334505573397, 39.03899731174592, 33.8498741580594, 33.06962843864195, 55.62695964690178, 71.09554813754174, 12.387889335232398, 0.372387403321843, 0.09531402419651709, 0.13668882420226453, 0.07888908377818524, 0.026993925810881683, 0.02461530516044267, 0.0424419911277871, 0.10892759813296218, 0.1223102272037537, 0.24310775251398165, 0.20279168601958983, 0.30881758058263414, 0.2872844424939925, 0.25384686496709624, 0.18540620924003665, 0.26446921029879206, 0.2461115985868439, 0.19043059689143013, 0.6841641976948708, 13.293222381222634, 96.48053953724524, 76.29591280414213, 50.45776213369062, 49.112071452602265, 66.62843919569447, 54.623315334320075, 66.8264953551754, 53.67404291706701, 43.26220543153825, 55.46886067236624, 43.80821112663516, 37.031422353559925, 14.528906268458213, 35.74506928843837, 42.74619802351921, 55.751071283894206, 5.561696348651763, 3.700745716210335, 48.942558380865286, 83.6493056820285, 64.2368838094896, 80.15950233705583, 57.06122921359155, 56.25898684224775, 72.37221687070786, 63.37621773442915, 66.94233863584458, 65.89491674976965, 30.740207318336736, 13.363091561102099, 40.301902447977376, 44.53326517535795, 44.39713931852772, 51.58322349671395, 58.54357134911322, 62.85846879405361, 67.857270702239, 67.44792430631577, 71.01114657617384, 63.821312612102886, 65.2070899163523, 63.836237230608546, 61.56322763812158, 61.84084907654793, 62.9746219419664, 68.15988940577354, 58.85909465051467, 58.81482678074991, 60.724660196611964, 67.80310277015933, 57.235445207165135, 56.20963558073967, 27.76494441493865, 3.2806596256071523, 21.968736417831916, 26.32264183413598, 24.024160369749993, 28.68957454158414, 24.971332357775783, 17.94975434580157, 16.486912273591567, 3.6407645863871423, 0.29557369769580905, 0.28464456479395595, 0.14457323257961582, 0.19645400916136083, 0.11076250894656105, 0.2567027028529875, 0.16823038008184205, 0.08378476099742037, 0.1731322396306261, 0.20730785094201568, 0.16716395504772666, 0.12827622118375956, 0.2062865331648819, 0.12682201776413188, 0.6078598179644155, 2.455560377528591, 0.4662381995829844, 0.4303685840099089, 0.22693778147860882, 0.3433745504627305, 0.09865049798522266, 0.22439744924345326, 0.17914557018347327, 0.18193046832757612, 0.19881211972284704, 0.25359252377623515, 0.24043585233871015, 0.23873732815827095, 0.27471097847146375, 3.2536984787833307, 12.771593236154127, 14.49757339492921, 21.16258932698158, 24.236533180359874, 14.572857406831558, 15.52117374635512, 8.761663994481488, 30.177478598010158, 57.383950064259196, 54.80992601763818, 52.626028753096065, 59.275281660018436, 52.579713406101355, 54.375276411733324, 53.920461900772594, 59.74702512064288, 56.11490641870807, 56.53524721822431, 49.48607729327295, 52.86292422202326, 55.271902776533565, 61.567377505763886, 59.73624252503919, 64.99005732997772, 55.09473716059039, 58.60607431780908, 58.602277463482274, 59.870638616623424, 49.29088054164764, 55.44227484733828, 32.369958008489306, 25.783009990569084, 21.745318212816795, 36.667010630330736, 48.706086527916696, 55.96316560622185, 55.85332355191631, 63.35423284961332, 57.54557132720948, 68.86913238033172, 51.584961106700284, 53.46551795159617, 39.93931070450814, 9.684830096460159, 0.4000244541994987, 18.95445965951489, 67.25244906640822, 47.22555260504446, 35.525620522037634, 14.884708389159172, 39.79539109814552, 40.312598751437285, 45.791847859659505, 41.04328924609769, 54.72888592750796, 53.16762962648946, 34.132104381438225, 40.06467357758553, 56.64822324629753, 46.48706443848149, 55.15886399053759, 64.55273658998551, 80.62655464295419, 21.601110312246508, 0.752416196609697, 0.3947390603923029, 0.35318550143030386, 0.19477468314430407, 0.21177153884162828, 0.22309342970050153, 0.4502833460367495], [0.08543115289461228, 0.03878768278105605, 0.005775402316958794, 0.10021200734040431, 0.03215708837453877, 0.021628012332404335, 0.05338303286642317, 0.05408081256093518, 0.016379325628100384, 0.08009254662019592, 0.12164988239566166, 0.17642160667286766, 0.6281608415226783, 53.937830155895604, 60.01415029648812, 60.99919865208288, 28.738545333185506, 50.205541964500185, 37.72965523504442, 25.904797623234412, 53.97732057879048, 41.31466627120972, 43.0163198901761, 25.884975925568614, 34.94512934838572, 13.017291484340547, 15.812013572262181, 47.50294262363065, 57.20470951449487, 36.544554233551025, 0.2512386573418494, 3.9975495059644026, 27.691182282663164, 65.78552576803392, 57.41157139501264, 67.37943187836679, 53.69209758697018, 52.733909622315444, 56.225870270882886, 54.496183472294966, 60.02052807038831, 37.56447245997768, 25.435354632716027, 21.160894863067135, 13.427287032527309, 16.80968999862671, 33.59401795171922, 59.32953196187174, 60.74727658302554, 62.064141765717544, 58.38001635766799, 61.332188267861646, 59.73192399547946, 63.57282653931649, 59.77686651291386, 64.34802416832217, 60.41184333062942, 61.038057573380016, 53.85815897295552, 57.242128925938765, 61.96707487106324, 58.10331275386196, 53.53268461842691, 49.402009133369695, 22.772537931319206, 5.37461890328315, 22.37858291595213, 23.312391388800837, 12.019583679014637, 25.389447212219242, 25.87614274794056, 9.599753887422624, 9.310789935050472, 6.631305611902668, 1.0552923669738155, 0.0281937976157473, 0.16403819374259443, 0.032499399441745014, 0.0717969099059701, 0.042505151246704405, 0.04136049714420111, 0.04654867439380577, 0.0341141787207415, 0.053430369439264463, 0.15875250882198735, 0.026698798098931872, 0.02402715456311501, 0.038470009101494666, 0.06005210020849782, 0.07649924185487532, 0.6074651907528601, 0.013368690101009224, 0.16568787215698152, 0.03273075799487772, 0.1320414743836849, 0.02845705798526685, 0.048387695269118396, 0.10447285047942594, 0.05039315257642058, 0.13422569830811795, 0.03795944597391832, 0.05472551768405303, 0.10339733964252858, 0.21941812288376594, 0.3730204064519175, 3.4134227854590264, 14.329065430548884, 14.448061316244065, 26.90568058721481, 18.536499738693237, 4.824449612248329, 22.163942975382653, 8.566581972183721, 24.880923686488984, 51.73853366605697, 47.14093139094692, 48.04026811353622, 51.96056727440127, 53.52389458687075, 52.559085661365145, 49.88098544459189, 51.74879066405758, 55.3161314225966, 50.13630428621846, 47.40521284841722, 51.26333459731072, 57.58379874690887, 56.54057771928849, 60.042822822447754, 52.91961816049392, 56.07523556678526, 48.85888245797927, 36.5299787059907, 26.11456794123496, 16.999687648588612, 14.344374441331434, 15.090380810922193, 24.20826465852799, 50.340267535178896, 53.67227000574912, 44.92509034372146, 48.17232647249776, 50.85326648527577, 44.30035483452582, 49.94497106921289, 57.798670107318515, 45.87420194379745, 16.43645686487998, 1.1354789738693545, 4.516508252389969, 64.8111972501201, 42.83505931977303, 43.292180184395086, 14.848389202548613, 22.012427699181345, 35.10921778217439, 31.32049845110986, 27.692880668947776, 33.27350931782877, 27.48495190374313, 26.372302962887673, 27.430707485445087, 41.47628361178983, 37.23345579639558, 28.620715372024048, 35.74733641839797, 59.34935562072262, 48.928959523477864, 1.0899080191889117, 0.12692259744771067, 0.0949719735992051, 0.06522647255370695, 0.05468943494281942, 0.04054766636522066, 0.01767399315271647, 0.06305074071391456, 0.06684513206803991, 0.056152873552374305, 0.024685346664139823, 0.015007714147589382, 0.05284372995036745, 0.026032280537389943, 0.03022757336317051, 0.028833262697463075, 0.04081710714906935, 0.11381449598458507, 0.030339849294133248, 0.1523922783352675, 1.5116131906547856, 66.04139374148461, 74.26302679123418, 55.007676232245664, 37.08418607711792, 41.57598241682976, 33.12339628896406, 41.511757527628255, 36.52492669320876, 41.03391478138585, 40.54552085937993, 32.49051401692052, 38.850892205392164, 20.37680522088082, 29.15391648969343, 50.08136364721483, 59.87426288666264, 47.64109634583997, 1.0394658484766561, 1.6994195840051098, 19.626002773161858, 64.20323771815147, 65.99860068290465, 68.6021052637408, 53.9702485453698, 57.72292521692092, 61.56954657646918, 58.65089524176813, 63.036379660329516, 40.763941964795514, 31.493061165655817, 25.451073531181585, 12.634947665276067, 14.639768139008554, 32.85413146018982, 57.37592489488664, 59.72769960280388, 64.60303314270513, 59.33573322911417, 62.53447709545013, 60.825853424687544, 62.64117340887747, 63.07478750905683, 66.12473626290598, 59.94978027959024, 61.96561182698896, 56.948798394972286, 62.41265220026817, 62.80843111776537, 58.95378458884455, 53.38814135520689, 50.31403080109627, 19.646208863104544, 9.507106523359976, 29.391417964812252, 26.03753847460593, 17.653019197525516, 30.08987638258165, 28.580344377025483, 12.39169599548463, 16.208298475511615, 8.799852190479156, 1.1666279862965308, 0.06229126412842063, 0.03995154270782106, 0.03739535628307251, 0.0014404299966577863, 0.04623676552587459, 0.1176865571629136, 0.05073366333700476, 0.021994706063020616, 0.08205034559772861, 0.04724564203511804, 0.12411204301902365, 0.05165148263556823, 0.15895366818914491, 0.4268504631134772, 0.16025587976459535, 0.40201907136267234, 0.11098188588455801, 0.10164866734656597, 0.13959992767101334, 0.03923821525888578, 0.03948674950328085, 0.03699034858014315, 0.15585225315824633, 0.06702297171878238, 0.15379187500765248, 0.07414238001670569, 0.10000637401976895, 0.04472215224297778, 0.2013245663575588, 0.5285607086073968, 2.4821030564846533, 19.19194152278285, 20.076889030395016, 34.28314701203377, 26.581890890675208, 11.00815640341851, 36.30327355477118, 16.509954237168838, 21.01307838193832, 48.93506665383616, 51.03557825088502, 50.39306263769827, 52.37338104555684, 55.633996378990915, 52.80728540112896, 52.244793984197806, 53.97856789250528, 57.02902263210666, 51.733446351943485, 50.09921043149887, 51.95786083898237, 59.363107450546764, 59.610201081921986, 60.9509378094827, 51.03445253064556, 57.160869183078894, 49.77313203196372, 34.21459967090238, 23.62032098154868, 14.61794799373996, 13.577387313688956, 19.51654903350338, 31.91530823707581, 55.286474381723714, 58.63331910102599, 51.66565995062552, 51.81451389866491, 54.79341283921273, 47.57069372361707, 52.65490524230465, 61.92089680702456, 45.56534274931877, 6.9031391028435, 1.295160869917562, 11.032446661303121, 72.16863801402431, 52.92638032667099, 47.80281566804456, 18.178071591161913, 25.95011864939044, 32.455565698685184, 32.999947532530754, 24.219282596342026, 28.426854187442412, 27.643245035602202, 25.758228455820394, 34.95913613227106, 31.80328142258429, 49.42530016745291, 21.79312994403224, 35.30725825217463, 66.53693029957434, 58.33683498444096, 1.968469172716141, 0.20391806509465943, 0.04715019131019231, 0.10930726364735635, 0.044949098129666624, 0.04521198120088347, 0.054445301873549345, 0.03774241709540929, 0.19807710432477538, 0.18908108704753462, 0.12007502778883904, 0.22060612607146465, 0.16991356718203715, 0.11383449854028803, 0.18588329815576154, 0.33986638870931446, 0.1071852843667711, 0.26622057922424813, 0.31158953184081667, 0.24906857540049862, 2.383209317922592, 83.57910310068439, 81.02528710519114, 78.18666781148603, 38.95078712894071, 68.02071586731942, 50.34751607525734, 35.25936219000047, 75.05550246084891, 53.041513658338985, 59.008627168593875, 36.304920950243556, 54.86389783120925, 15.104707267976577, 21.728665790250226, 54.95229236541256, 70.1280249318769, 45.06878637498425, 0.695871553353725, 5.680032295565452, 35.89128740372197, 73.63898554155904, 68.64209775001773, 78.14962494757869, 61.038751832900516, 62.88388967514039, 65.27162075042725, 65.44102007342924, 68.61568450927734, 43.980046241514145, 31.986703218952304, 25.660296678543094, 17.13946327086418, 20.995015867294807, 38.9434915204202, 61.456503868103034, 62.12340877902124, 67.70654186125725, 62.688234006204915, 64.11522365385487, 62.62136936187745, 67.89994608971381, 64.39688513355871, 69.9562878762522, 60.55191116948282, 65.53896165663197, 59.559822159428755, 63.270039173864554, 67.90920288332048, 63.55861186981202, 57.368868550946644, 58.95661261773879, 31.063355707353164, 9.512683153152466, 33.58987200644709, 35.664696001237445, 20.44099480875077, 30.87831004973381, 37.82071305859474, 18.889660143083145, 19.82365296732995, 13.179686434807317, 1.6392060537492077, 0.09098555081553998, 0.22158457356835567, 0.18068716891350287, 0.14011015755034265, 0.15126214542936894, 0.1577195771519215, 0.17138273995970527, 0.1759366117297642, 0.17120678488525654, 0.2896719401882541, 0.1814676592907598, 0.19953938231112497, 0.16249933760733376, 0.33624947311416753, 0.347237870577843, 1.8566088138088104, 0.24520134823697232, 0.2166606813308693, 0.267187443471724, 0.2506055163159486, 0.12197618222525045, 0.15837282032495545, 0.23057030994565259, 0.12180426443416266, 0.271204594042032, 0.09468603128146741, 0.14975869787796853, 0.24920533741674117, 0.40625403605161176, 1.2921641791059126, 6.765826729036148, 26.784806866799634, 22.761845550229474, 34.02380381861041, 28.391937248168457, 9.883813896486837, 32.735169895233646, 16.16446500824344, 30.255982875823978, 54.83753165891094, 54.277217157425426, 52.48236802316482, 56.7937235678396, 59.55399743972286, 55.37425310380998, 52.99779884276852, 56.725133080636304, 59.92349255469538, 52.098799444014034, 48.43929867590628, 54.304548232786125, 61.801907785477184, 62.019677777444166, 62.555214666551166, 53.08089033249886, 57.871210421285326, 57.16351286057503, 40.97160400882844, 31.614664446923044, 20.65386183800236, 17.86866718722928, 18.918697449468798, 29.53960118755218, 60.968494338373986, 62.72343335613128, 54.745532466519265, 60.8052296023215, 62.03393167065036, 54.857147432142696, 58.30551878098519, 67.48049566822668, 54.53828619372461, 21.889763416782504, 2.871646631148554, 6.809238541510798, 76.08219854293331, 49.47778932509884, 52.44280699760684, 22.670352343590032, 28.360803434925696, 45.191540871897054, 43.139537226769235, 36.82268165772961, 47.94145184178507, 37.9691041669538, 36.19313732270272, 38.02171491807507, 51.27978501781341, 54.22477506822156, 35.658584948508974, 49.75137464461788, 71.28775212072557, 76.62450544295773, 3.6174196197140605, 0.5933966908243395, 0.19094291052991347, 0.23806127088685192, 0.26324285674960385, 0.16240840297072165, 0.1488105108540866, 0.17832564159987435], [0.08032313908540434, 0.016631665414259318, 0.05894452093109008, 0.023649722195020127, 0.02119346427911472, 0.13433244499948718, 0.09022817331095857, 0.1527413233153282, 0.03694801456144741, 0.06270258822628567, 0.10547280972523075, 0.2804765561895986, 0.25223657879377565, 23.022563534398234, 77.95628347704488, 49.46781081538047, 36.71422812246507, 42.585420070155976, 57.744207997475904, 18.742045664018203, 39.9968401078255, 43.06277644249701, 38.833292530428984, 34.455578327178955, 40.662387878664084, 39.282725549513295, 8.324139291240323, 37.31824959478071, 62.54891141768425, 63.467675639737045, 16.37571700157658, 0.3872017358099261, 0.7864995709350033, 12.983367885312727, 59.29951798531317, 56.73154223349787, 65.93072798944289, 38.24051649339738, 52.07856001392488, 63.04232989588092, 59.385963101540845, 52.40465410294072, 49.92206834977674, 18.702253218620054, 5.3446235579829064, 2.4182306903023876, 13.457775615876722, 44.38876898058, 63.96322788730745, 61.27633763897804, 68.24601681001725, 65.29299766786637, 64.37495123955512, 59.47929982216128, 60.47801763780656, 59.80024776151104, 57.50360588873587, 57.861730052578835, 66.74414911577779, 59.90202150037212, 54.12907708075739, 53.14467591624106, 46.27070649977654, 20.394763792714766, 14.838369507943431, 30.51332958282963, 23.4487251312502, 9.062370542557009, 5.863645307479366, 31.30366756070045, 13.16684949782587, 7.9566421335743325, 10.850485947824295, 4.80560262357035, 0.8162171633974199, 0.03159412100250202, 0.023659089535114267, 0.09920648629626921, 0.13632508565581616, 0.027736837660232862, 0.10291555460782782, 0.07852313889851494, 0.010092285266446491, 0.03490874596360711, 0.014075966412952591, 0.01676738938136447, 0.07101029848619815, 0.07185008406879441, 0.27294673926887975, 0.10748030482641152, 0.11582215962510918, 0.06647321936343947, 0.050446119895505334, 0.0546337709942412, 0.08870348980229709, 0.07521507931092093, 0.07069834748343115, 0.05662303703326372, 0.02647702905139135, 0.014074935067084529, 0.1476575178845275, 0.023005844446860498, 0.11178152845992197, 0.045828287444648244, 0.0899368990212679, 0.44830809557630175, 15.925422041646897, 23.232592728830156, 18.6084948432061, 37.14474355020831, 15.054967691821439, 5.5200898070489215, 37.99483883765436, 13.065281683398833, 20.39947455929172, 46.80396056944325, 51.9345070469764, 50.95964116434897, 50.56284243060697, 52.76802247570407, 56.394896968718506, 56.08490813163019, 49.69543772359049, 53.43957931764665, 54.3286237409038, 57.974847285978264, 54.52136508880123, 57.60591699231056, 60.15386512202602, 53.2788876564272, 48.67892803684358, 30.411630369001823, 17.662530945193385, 7.608874988171363, 4.799114533009068, 13.30557196371017, 26.336183817155902, 41.426057661733324, 50.22737779924947, 48.027085027387066, 55.049641670719275, 40.55507183074951, 40.14559207424041, 45.032598587774466, 46.27621742986864, 48.30715794717112, 13.916392864719516, 0.48794076567695993, 1.3898011657499498, 40.98260625716179, 30.39631155229384, 30.863281488418583, 62.08420861151911, 16.42737069437581, 24.579669967774425, 32.841005248408166, 32.62151921949079, 36.25053728780439, 20.00985376296505, 28.733799265277003, 32.86016602669993, 24.81419828630263, 43.93250711502568, 19.142647135642267, 36.16127198742282, 42.48077907869893, 60.62771881780317, 23.14025229023349, 0.5567942968299312, 0.10138033739020748, 0.10984921722763008, 0.020771106599920222, 0.04052253102042502, 0.09136348497122528, 0.08716129352368655, 0.011142231749310609, 0.05317796645085177, 0.049551049577853376, 0.07763298303489724, 0.06684549979024357, 0.023273268504248514, 0.006876301307666807, 0.05727131212610872, 0.16511427148455576, 0.022135558988778822, 0.07271053870358775, 0.06528234334602472, 0.08587523874255919, 0.23258205683481312, 30.796169734770256, 90.06238091376521, 52.40758803582961, 36.260245153980875, 51.973844497434555, 34.75030129955661, 32.93003128420922, 35.98640488040063, 35.33485604870704, 41.53503287223078, 31.79312836739325, 42.916934874749955, 37.57649060218565, 19.683849888463175, 50.62008550090175, 69.48294408859746, 69.48757248540079, 25.74043658471877, 0.9204623019022327, 0.3665290370343193, 8.542974206709093, 58.62118328771284, 63.33132228543682, 70.74670822389665, 44.78224938915622, 55.87739513766382, 71.51001714891004, 65.21640554551156, 55.5111163662326, 54.3013632682062, 22.24854457762934, 6.649903530074704, 3.035538946428607, 11.011652215834587, 42.068031987836285, 63.50094126116846, 60.32038150295135, 69.5987795245263, 65.74680805206299, 66.76393355092695, 60.63746983005155, 63.523141876343765, 59.36200918689851, 56.53919312261767, 60.173586799252426, 68.40441780705606, 59.27846270222818, 54.84577648101315, 54.489966515571844, 46.94904511974704, 21.858492320583714, 20.619231231750984, 36.707626773465066, 24.563788290946718, 17.1865277905618, 9.696646236604261, 35.336644649505615, 16.690324429542787, 11.69172844579143, 20.272040674763343, 6.652311375064235, 0.7659950131370176, 0.02348948149911819, 0.11186719241161501, 0.06563055329024792, 0.03404046957110686, 0.024520955686908097, 0.26351791295793753, 0.5855585081923393, 0.029900769830771515, 0.07815455101550588, 0.19648249231038556, 0.24789725760779074, 0.22168742853306958, 0.26816742314446357, 1.1923207366658797, 0.41066130923648037, 0.23050165314587856, 0.13607661269845503, 0.054224967325647036, 0.06022964108494982, 0.10237054433673622, 0.05529550242147619, 0.16083617604547934, 0.005429914857696502, 0.14144953971187915, 0.09199486399490027, 0.10809405616694882, 0.04196056232397114, 0.1371999274218275, 0.05174710573027692, 0.24641935142778584, 1.408992342410549, 21.7075869729442, 27.90036424513786, 20.996547552847094, 45.51500697289744, 14.646366546230933, 11.972834910115889, 49.29390861142067, 21.085516714280654, 20.20493676585536, 44.00452575375957, 53.17498407056255, 54.08553877184468, 51.14094488082394, 52.961626745039425, 59.64656537578952, 56.995584426387666, 54.275079465681515, 54.04352626492901, 56.928139271274695, 58.211087719086684, 56.74625504401423, 57.326083337107015, 62.249591427464644, 55.365612122320364, 49.3519518452306, 31.810804528574792, 16.347524965963057, 5.714835976400684, 6.912497387778375, 18.974952082480154, 34.33022329884191, 45.35205602645875, 53.94806754204535, 50.39871869548675, 58.59336976082095, 46.75293445587159, 49.735540036232244, 49.585729029870805, 54.643590065740774, 45.77803719428278, 10.373580648053078, 0.541163590406218, 4.9522115049823645, 48.22329767288701, 37.72364224157026, 28.910290233550537, 55.54427608366936, 22.27925085252331, 26.53774657557088, 30.570300048397435, 33.00910234451294, 30.946357288668235, 28.624747568561187, 19.948439251992014, 38.73123638091549, 24.123561074656827, 42.28815147953649, 28.501747923512614, 24.742375766077352, 46.94337337247787, 71.01979148003363, 27.795638922722112, 0.46909328670270983, 0.04771760965306913, 0.09776714498237257, 0.026739716770187504, 0.0479270389393693, 0.018906869940579902, 0.09526657271048716, 0.06393873620958579, 0.25389384147861316, 0.11886473144254378, 0.20147686463690576, 0.17206907813106814, 0.19084857446291756, 0.21538912859414855, 0.2628823664159544, 0.3427634880908074, 0.09303596982311818, 0.11807087283100813, 0.29160805887752966, 0.45367680910614233, 0.3324463675099035, 43.359750855353575, 97.66267914925852, 66.36127087377733, 46.41048016086702, 58.78888422443021, 75.45985960191297, 25.248873387613607, 57.200551802112216, 56.81693223214919, 52.14958629300518, 46.41048408323719, 60.34622992238691, 50.63370004776986, 10.86117244535877, 46.954242260225364, 68.54674493112873, 73.62399424276045, 23.432513975328018, 0.5459455725166106, 1.4036655185684082, 16.62895110345656, 69.70971199773973, 66.22580789750623, 77.01514213315903, 49.84942213181527, 60.64575387585548, 70.94302285102107, 68.90323346660983, 64.0291746970146, 57.65949264649422, 24.301697477217644, 7.965921480809489, 4.456555314602391, 16.23897925499947, 48.39079856872559, 64.32652173503753, 62.442505359649665, 72.38742782223609, 67.99212178876324, 68.4530944208945, 64.12131901710265, 66.24096393585205, 63.24718744524064, 58.315614961808734, 60.42303385273103, 70.55988573258924, 65.77465295791626, 60.381252765655525, 59.00445376673053, 55.163849323026604, 30.25045821743627, 20.29091315884744, 44.63620778053038, 33.9291609487226, 15.167096487937437, 10.780144122339065, 42.757533673317205, 25.1133398086794, 16.15444531363826, 24.414506804558542, 11.972386779323703, 0.8902766603615977, 0.0773201510310173, 0.1554227689461362, 0.16447990471797605, 0.13028101965544686, 0.09114508862577139, 0.20572541972562192, 0.33921414145058204, 0.13697276703051983, 0.2425650251849044, 0.07823364193280859, 0.231577072052225, 0.27540349131149633, 0.2987422373506331, 0.6575543481496073, 0.22489114694537657, 0.38347720018317627, 0.18692395199210415, 0.11764181762813561, 0.12560973725011274, 0.18984060193742477, 0.20142234982021395, 0.19560351366958312, 0.09299837788867374, 0.28128036628327063, 0.12863189282436527, 0.28484374765426884, 0.1255363383660874, 0.2373553668299029, 0.10147346303828302, 0.1413154283598546, 1.6058689716362184, 28.089504857217115, 33.621290191527336, 20.65971793666963, 49.319286346435554, 20.742352470274895, 9.824324288675863, 45.252027742324344, 21.880006520978867, 28.476760464329875, 50.91922113972326, 54.66092301953224, 57.31133914762928, 51.59193508086666, 57.63242436993507, 59.74750757217408, 59.87547489904589, 55.18846611822806, 57.761603709190126, 59.83896939985214, 61.66518572838076, 58.75643445599464, 60.52009290264499, 64.56530778638779, 55.54924572667768, 53.213486056174006, 37.15043098695817, 21.03313934418463, 9.84270549589588, 7.796931064897969, 17.1801382495511, 31.644209700246012, 49.69788920494818, 58.5384879573699, 56.69080841925837, 62.9044468172135, 50.91904855543568, 52.05015813150714, 53.88812980344219, 57.236625840587, 58.93613392306913, 20.17621717145366, 1.446614123640522, 3.1713434140528403, 49.14658831011865, 37.58027176703177, 38.5962244772142, 68.63977570687571, 21.402630536786972, 29.392008281523182, 44.421830638762444, 42.87981356343916, 48.618727499438876, 26.353487353171072, 38.060479702488074, 50.08161467890586, 31.47782079635128, 58.23643015277002, 29.83684232158046, 46.892433551050004, 59.788127637678585, 79.01104019534203, 41.59569624931582, 0.7416801178647626, 0.19091542329519026, 0.2719372192457799, 0.18964503501211444, 0.18966636289992642, 0.1502460370501203, 0.21382663098554458, 0.12982202573649346], [0.045229831049519206, 0.08106429850862873, 0.013433090324753956, 0.04755626387533642, 0.051597419810751756, 0.01441194097541513, 0.016944625737866568, 0.03833527338781184, 0.04669846373520071, 0.024686639437512047, 0.054067038300056616, 0.04641689194907104, 0.2100145315090495, 5.842214457450375, 70.5875619765251, 57.29343352779266, 42.71145366853283, 31.035118564482662, 60.10710262483167, 31.720150709152225, 31.204335497271632, 49.223086295589326, 34.20067917916083, 40.29603065982942, 34.92011247142669, 45.66646145236108, 24.03991653073219, 15.416841641549142, 60.37415327564363, 51.43056484960741, 66.05159974867298, 10.233402982834848, 0.2200461157988156, 0.4337136609660041, 13.077582236259216, 50.467740643408995, 64.91756800682315, 59.65460623464277, 51.73969076525781, 47.01260320601925, 46.549414434740626, 53.28586163059358, 55.23323997374504, 49.51581278154927, 25.24314476597694, 4.181782007217407, 1.0129795535918207, 16.283058850995957, 60.38053104954382, 62.80508533600838, 59.10509001824164, 61.22066743912236, 56.98691206593668, 62.93489617686119, 66.07897789247575, 65.00440143769788, 58.47197632635794, 60.28322881267917, 50.65100946734029, 53.4701463483995, 57.487743823759025, 31.643995931071622, 17.837986407741425, 27.401191649898408, 35.798142879239975, 18.648675603251306, 11.378970415361467, 3.0547896940861983, 16.705219630272158, 19.664753829279256, 3.7869324463029064, 7.004232310479687, 11.60947536268542, 3.7885469919250863, 1.1577921120389816, 0.049929734499704455, 0.06052085791804618, 0.0681267512000857, 0.013080321199771379, 0.003074505713753282, 0.21829310744520158, 0.09217055093857551, 0.1484379469747505, 0.06852311743122917, 0.19088773687760677, 0.13348956442167684, 0.059963938810171626, 0.044615194877429355, 0.4781049934606399, 0.025433513876651565, 0.07287775271482046, 0.013913078883272267, 0.034308404992184335, 0.05887589094439342, 0.16029430673487727, 0.09742570725540001, 0.04749414563599614, 0.017159111204466993, 0.05516693371558382, 0.05291709052999655, 0.017028791987667644, 0.1453574155006678, 0.08241304992547921, 0.08538805278799227, 0.39844269714047836, 2.0610653008184125, 11.920465384760211, 29.71185403485452, 13.470843972698336, 20.444105248297415, 35.56166318155105, 12.89353580244126, 7.149792448166878, 43.39303216626568, 18.587396414049213, 19.29158345345528, 36.920317296058904, 52.45936332210418, 56.25406034531132, 54.785324911917414, 47.898670550315614, 54.78321467676471, 58.85940059538811, 57.58941558099563, 52.6390588668085, 55.41022516066029, 55.884663289593114, 57.5588014818007, 54.73339665320612, 49.50972918541201, 31.44161928084589, 18.10682762053705, 5.566479188780631, 1.1584207944331633, 6.371214226368935, 36.09225003950058, 47.03301522039598, 54.167590833479366, 53.59997287873299, 52.379539166727376, 49.79692512942899, 55.19772683420489, 55.084499774440644, 59.76943362143732, 45.26439497547765, 10.168946673793178, 0.8286101371049882, 0.7407804854935216, 40.39607855581468, 63.16538641529699, 20.619833315572432, 44.51205299746606, 23.5357899819651, 14.300850841306872, 30.413997519400816, 35.91632389253186, 30.07748365402222, 23.903390592144383, 24.299187160307362, 44.21604741004206, 18.056974295646913, 38.61197279345605, 30.91671593727604, 25.07392587200288, 49.50781114639775, 45.27280845949727, 65.71132236911406, 8.155093471850119, 0.5507442247002357, 0.03700042263634744, 0.07950007720219512, 0.040970569882061214, 0.00544240496369199, 0.042476671928119276, 0.13998715447322016, 0.03758546866236195, 0.05241687341983761, 0.0851919036358595, 0.039695772762981155, 0.058200618913096774, 0.04797782290786986, 0.09046847977104688, 0.033965435089363206, 0.09401211139535713, 0.044650312347878376, 0.07450643265920301, 0.23047376754543475, 0.13723971802861462, 0.20861484290611362, 7.703450687469975, 79.56949941573605, 65.58810503252091, 33.51304846425211, 41.75038276180145, 38.96098529138873, 32.60147198554009, 40.849249593673214, 27.60150121104333, 36.62992854272166, 39.37359509929534, 39.944931460965066, 38.09707541619578, 33.05254259417134, 28.681431701106412, 70.8165656366656, 66.38620145859258, 73.32475662231445, 19.059787065752094, 1.0532137559306238, 0.45426635972915164, 7.685587723408976, 48.2827490375888, 69.36891294294789, 65.51122265477335, 56.33925422545403, 51.08136800027663, 52.354416385773696, 58.78689558275285, 59.749888450868674, 52.42935326791579, 31.704325906692016, 6.638717910935802, 1.1119472043168162, 14.652772757314867, 57.320215471329234, 62.56620122540382, 56.90864901388846, 57.74601228775517, 57.47946370032526, 60.875165462493904, 66.35741126152777, 63.161640551782426, 57.8436557708248, 57.66641562984836, 49.69406097166, 57.985186653752486, 57.52594378686721, 31.74577359230288, 20.976653291333108, 32.17669498535895, 42.38090376700125, 21.80496177365703, 24.54896761525062, 5.843852046997317, 15.31723697339335, 24.672477168421594, 8.36936519991967, 13.255939272142227, 26.667308345917736, 8.907392794086087, 0.16940802576080446, 0.09199723120658629, 0.05964435757167878, 0.07898256948758518, 0.08900474621764115, 0.2669683116818628, 0.6533281168630046, 0.31557665176449284, 0.2251737874241606, 0.09523807423970393, 0.5347663272292383, 0.4514225187801546, 0.029573633050125454, 0.08342071601580228, 3.2506919820462508, 0.7660325820888243, 0.1663541847900037, 0.03865755125579815, 0.13669731245646555, 0.0562152982268843, 0.1893161994314963, 0.05024349730041239, 0.07242668014500411, 0.06537630402993772, 0.10286733703387362, 0.5063315030307539, 0.21504713162299127, 0.39961186988699826, 0.11998311255968387, 0.34352507141809313, 0.3161188887972986, 4.279965306482008, 21.897255143811627, 30.46063057837948, 17.602710877695394, 27.708523081194972, 30.72437074876601, 15.665995497857372, 10.066834630504733, 50.16661636291012, 28.46753897205476, 23.297686423024825, 36.26451269272835, 48.65596648185484, 60.26914750376056, 55.71604844062559, 50.8186633356156, 55.93672883126044, 59.07132625579835, 59.38271930140834, 54.60755917333788, 56.54024824019402, 57.86318525191277, 58.50062531809653, 55.810408899861, 46.28061048446163, 30.49051315553727, 16.163788399388714, 4.450730594896502, 2.3567159137418194, 10.299860681256941, 41.70649928431357, 50.36204061200542, 54.77604458408972, 59.34867705068281, 57.5485013377282, 55.49131231923258, 59.50294386956, 56.36660883503576, 60.72525639687816, 42.702675404087195, 6.602165833596261, 0.5369330690272394, 2.5036898207279945, 47.883122274952555, 68.18350991895123, 26.438873429452222, 42.368077616537775, 30.74456899396835, 21.414803612616755, 28.729506231123402, 34.554696621433386, 26.223547074102587, 26.48398460880403, 20.328707156642793, 33.862684619042184, 27.25842522036645, 26.646770815695486, 38.96157756928475, 19.685846374880885, 42.420853107206284, 54.151603252657004, 74.25719814915811, 10.424432216152068, 0.734707921022369, 0.08672306058748115, 0.04050887933361434, 0.031534025235281836, 0.056715270188907464, 0.0532725400051042, 0.062224357839553594, 0.03484096633450639, 0.12954487044724727, 0.21894062028056194, 0.1475294279835878, 0.20068163472798564, 0.12508708908553087, 0.25419558819022875, 0.16366674835162778, 0.1292157437532179, 0.20238567474147967, 0.1979538867430341, 0.4464192291901958, 0.36030619675593994, 0.761647372236175, 10.832017467867944, 95.3084647270941, 75.69185210812476, 54.40075612837269, 41.89246669892342, 80.6768943417457, 40.66765169943533, 44.097356488627774, 68.3828761500697, 45.675714323597575, 53.12325193035988, 47.34833455854847, 58.24851889764109, 32.610105122289355, 19.97779034799145, 68.43326291730328, 60.79218379912838, 75.02013837137531, 14.50102900305102, 0.7998420033724079, 1.1208965821612267, 16.714874544451316, 60.643486745895885, 73.65476915913244, 70.76523750059067, 62.640008464936294, 57.652746169797844, 59.46322594919513, 65.60416713837655, 65.08313517416677, 54.928911116815385, 29.770112999023933, 6.123825436638248, 2.280354475782764, 20.700516470016975, 68.44693629972397, 63.26157862140287, 57.90432307028002, 61.99719082924628, 57.925574471873624, 62.80795651097452, 71.88951430782195, 67.10980815272178, 61.295961256950136, 63.41170341737809, 56.43869415406258, 60.04080280180901, 64.2529655271961, 39.63494654624693, 24.809397305211714, 34.538869857788086, 47.29144842393937, 26.19959512064534, 20.07836776394998, 5.448837011091171, 22.793789332912816, 30.832775254403394, 13.125360627328197, 13.348381692363372, 28.8160474454203, 7.846541693133693, 1.2569732867902326, 0.11724915160166642, 0.27362304168843454, 0.22725052921281708, 0.12801520736707797, 0.12309907560026455, 0.306110164571193, 0.5218275311973788, 0.4414178088547722, 0.23729185814098006, 0.3205749158176684, 0.22462785784755984, 0.13445075961851305, 0.20490535324619663, 4.8791897200769, 0.24336934089660647, 0.2200365550215206, 0.10545162739412439, 0.18574069854953598, 0.11664831650353248, 0.40438303483590005, 0.28817095943996984, 0.17323092707703192, 0.11504985872776279, 0.11901859254125627, 0.41577142212660084, 0.2548560325897509, 0.29756761005809235, 0.1356572714904624, 0.2605695469725517, 0.7341282682553415, 3.628925402318278, 23.467246563203876, 37.47695261432279, 19.904363578365697, 28.64789151376294, 45.9293818473816, 20.11780131247736, 11.712781767691336, 50.5583748509807, 27.556831298335908, 28.58329203820998, 42.552707502918864, 53.44101490512971, 62.46678090864613, 54.377061090161725, 51.90957646216116, 59.085450710788855, 61.787485230353575, 62.466506342734064, 54.41068756964899, 59.21204128573018, 59.80867301264117, 61.53786167021721, 57.480114813773866, 50.18311777422505, 35.08942157991471, 21.889818329964918, 7.417000974378279, 2.59022809324726, 8.652970214043895, 40.70235290834981, 52.81918587223176, 62.44324276524206, 64.69024704348656, 61.41310676451653, 60.49431116350236, 65.34095648796328, 62.706186694483605, 68.30577019722232, 53.87440543020926, 13.316809554253856, 1.815040637889216, 1.7812784689088024, 44.88547440498106, 70.57711278238605, 27.140285391961378, 46.48562492862825, 31.392903443305727, 18.38243688306501, 38.75222106133738, 48.42478590626871, 40.214170794333185, 33.67572484477874, 28.929143105783773, 64.2881570323821, 27.274575579550962, 49.416094364658484, 44.627633479333696, 32.506644764254176, 67.86022816934894, 61.2413618641515, 88.00964770778533, 17.277520895004272, 1.1380567065169735, 0.20898042006358025, 0.1898780483151636, 0.1960951122905939, 0.11338137285483461, 0.2520746737718582, 0.2704606920240387, 0.10814846373133122], [0.12776986770932713, 0.040273678849541375, 0.046242469050470865, 0.0182387646618149, 0.01892254409951068, 0.04277884764897247, 0.061743411671129934, 0.021428105519002965, 0.04883561538712633, 0.008928680063916311, 0.07429649392443319, 0.05177090425164469, 0.05924098163602814, 0.15332324370261163, 39.92860655630789, 69.42265725904896, 43.85141995645339, 27.05403051068706, 51.73916516765472, 52.018983133377574, 23.185230108999438, 44.934405972880704, 41.13238196219168, 31.8268136824331, 41.98088868971794, 44.05020175441619, 42.81947966544859, 14.388623679837874, 31.212497949600223, 41.90369644472676, 37.07099514622843, 55.4338848975397, 9.258824413822545, 0.7056272847037162, 0.2720013561268007, 7.364229406079939, 52.08224311951668, 53.15173226018106, 67.5078659672891, 53.39764525813442, 51.82553575884912, 60.864912386863466, 50.01955493803948, 44.66770833538425, 42.68256148984356, 25.79507520121913, 1.1833289481939808, 0.548284408305922, 12.6553028052853, 49.000821267404866, 63.452809856783965, 62.811906337738044, 62.074465444011075, 57.35351247172202, 51.97076935921946, 52.494515603588475, 56.613761301963564, 50.89725978912846, 63.09437190332721, 42.24885325278006, 16.929253647404334, 20.937339375095984, 38.73203262206047, 31.982108162295436, 14.422213877401045, 15.394418431866555, 3.979491649135467, 10.675988524190842, 14.555597997480824, 11.728384956236809, 2.234886851041548, 7.161588486163848, 16.719230336527673, 7.349136125656867, 0.30370284052145097, 0.17749932384298694, 0.1872507497788437, 0.0642619831787963, 0.1194548642923755, 0.23353122445123814, 1.032925418788387, 1.1217042226945202, 1.4344180038859768, 0.42952941129765204, 1.0621632563491021, 0.35190270252285466, 0.5009481112562841, 0.5270419546192693, 2.6818703499532517, 0.2323187677369964, 0.015071448832449895, 0.04734378172865799, 0.07510462475399818, 0.027972022822547345, 0.0344386016349158, 0.04251429833652031, 0.049741322835606915, 0.004120439332309029, 0.09459520389716472, 0.05890452731100302, 0.057568646171280456, 0.08598907174722803, 0.5855795909320155, 0.34715007690172045, 0.1852713624436048, 3.2394181095784713, 11.031762207708052, 22.48912315214834, 17.1928330006138, 8.78215249507658, 23.231765108723796, 26.65487639365658, 9.368964568261179, 9.549506364330169, 37.086151184574256, 23.88709902763367, 25.220730381627238, 24.1302526381708, 38.02333877932641, 51.434330324972834, 64.83710058273809, 52.161376937743164, 51.16559697735695, 53.443544833890854, 58.872673896051225, 57.80128240585328, 58.08792529567596, 57.4213969322943, 51.33724774083784, 27.871915294278054, 12.38088398210464, 3.1244247574960036, 1.8183619048326247, 9.43988690453191, 41.44950559062343, 48.69671990794521, 45.655804372602894, 48.91497627381356, 46.893935818826, 49.43139945307086, 49.48801886650824, 50.94696406395205, 48.1509260208376, 27.602464152920632, 11.610231399536135, 0.25248385665397494, 0.2884372822459667, 26.049346770009688, 54.35084396792997, 29.713936813416023, 39.15648798788748, 59.19252357175274, 17.117986332985662, 19.028525775478734, 34.45182461892405, 30.2401678792892, 29.753644927855465, 19.613186428623816, 43.48680819234541, 25.854910958197813, 23.28761769879249, 46.27654298659294, 29.18092004714474, 38.21159685811689, 37.84105839267854, 55.25096908692391, 29.288895053248254, 0.8602603548957456, 0.11318828805439896, 0.0477231522992013, 0.028355430676451618, 0.03871239932073701, 0.09273810717727869, 0.05164409754797817, 0.05303652363739187, 0.06384319355410915, 0.09299663120820638, 0.0476434025462837, 0.036392845964479836, 0.06383346040703117, 0.08523242202617469, 0.051040201928586736, 0.11449982291988789, 0.05786180503726487, 0.03785813084593223, 0.02382112479197883, 0.07088079898347778, 0.05490730268760555, 0.012851617141296307, 0.09461323760690228, 47.01476050961403, 84.2259725447624, 36.43175078976539, 29.13618737651456, 54.96132950628958, 29.641992699715402, 35.84580752157396, 38.419266746890166, 32.7189960018281, 31.622126756175874, 38.32527106808078, 42.83373748102496, 37.879042625427246, 27.310102447386715, 35.9003794577814, 47.63767211667953, 52.101831436157234, 57.803035705320305, 17.59496223541998, 2.7356752176438612, 0.2776156774451656, 4.446738602653626, 52.03906566865983, 58.01354146772816, 70.64482858104091, 58.43656516844227, 58.20549441922096, 69.81108957721342, 52.35005863251225, 49.119006203066924, 47.940130003037, 29.489469374379805, 2.585627398183269, 0.5985906443768932, 9.889181660067651, 47.2511068467171, 61.18065534099456, 63.276703280787316, 65.68288126299458, 60.24331085143551, 53.147484333284446, 52.67028877812048, 53.7561498918841, 56.205850493523386, 64.5565216772018, 42.43223974781652, 17.376431303639567, 25.333145510765817, 40.922319427613296, 41.14201138096471, 16.7044626128289, 28.412472817205614, 8.894760800946145, 9.011588596528577, 15.94353456651011, 16.568556408728323, 10.160711657616401, 18.339506541529012, 26.461795760739236, 13.453604175198464, 0.6910224619411653, 0.7045959464965329, 0.6575875657220042, 0.25282655842602253, 0.2675785466788277, 0.1359203307619018, 0.5387100252893664, 0.22956770003562976, 0.9167780318567831, 0.7411350309848787, 1.822959045248647, 4.64976538573542, 1.7890995524583326, 0.8435758179233921, 2.9084637136228624, 1.6360855631289946, 0.10129098089471941, 0.0617626098345124, 0.0443624394885715, 0.048420931993713306, 0.05516859995681913, 0.056861707895633676, 0.2235726789841729, 0.06874404952771242, 0.22559067715079556, 0.49967042981616916, 0.17076908821059814, 0.06156423136651997, 0.41809944075442135, 0.8145048036690682, 1.5776513180425091, 13.065973001141703, 23.949643181216334, 24.106239887975878, 19.356120171085482, 17.28357703455033, 22.99378510444395, 26.357125351505896, 13.111445038549363, 12.46710846501012, 52.59911344897363, 28.386857778795306, 29.949235877683087, 26.642069855043967, 33.860562616778964, 49.06004905700684, 65.17076876855666, 55.52376601003832, 51.28379368012952, 54.007820929250414, 59.311190958945986, 60.09309191857616, 59.34333086013795, 56.08251156345491, 50.80910451950566, 27.16161131858826, 12.328633108446676, 2.175115568022574, 2.760898509333211, 15.244844728900542, 46.48073373302337, 51.58002284265334, 50.722788841493674, 54.568782621814364, 51.578893200043716, 53.998458231649096, 54.58027124404908, 54.91377076795025, 54.20325302308606, 30.17545073263107, 10.45575136138547, 0.08094756203072687, 1.2909250778536643, 40.22495338993688, 56.8199485348117, 33.271485374819854, 41.6949204475649, 66.07587922003962, 28.40625978285267, 25.165303368722242, 32.03457182453525, 31.325507317819905, 26.273221931149884, 24.214389439552065, 22.847923924846036, 33.30283687960717, 24.17307315334197, 38.854257599000015, 35.0468324845837, 26.08863519084069, 42.0792381994186, 64.23953533172607, 35.83642128975161, 1.1994478058430458, 0.13958106658631755, 0.05149398644965503, 0.027527565421957164, 0.032402240340748144, 0.17199475228065447, 0.03655079414226836, 0.029269743207541686, 0.029501034727981015, 0.2444479773722349, 0.16929596241924072, 0.10226568988253994, 0.12244459136479324, 0.2043504757626403, 0.1293026028020728, 0.2579628868449119, 0.20736123194857953, 0.1301897326183896, 0.13690694475606566, 0.2674757683229062, 0.28468924304169996, 0.20528692631952225, 0.33224335420996914, 62.44112468534901, 91.45808573692076, 59.704247751543605, 39.02887759670135, 68.748746995003, 66.02895198329803, 31.6211598919284, 64.98484057764854, 55.60754783691899, 43.53390801337458, 54.1633782079143, 59.56195200643232, 53.64495069749894, 19.740924296840547, 38.19681344493743, 48.90795130883494, 48.00664555641913, 64.49961200837167, 15.114228821569874, 1.7809128304643018, 0.9131575003266336, 8.994449800060643, 61.84661496070124, 62.84113976263232, 77.24496949103572, 63.10825317136703, 61.42144964587305, 71.15147329145863, 58.817207659444506, 52.70241691220192, 49.29583449517527, 29.955766624019994, 2.1455521737375567, 1.0403424982101688, 15.538707721617916, 57.75202528122933, 65.45758032029676, 63.8326443395307, 64.62834419742708, 61.804794649924006, 53.32703082792221, 53.43457437330677, 58.51588726043702, 57.06941912251135, 70.12007820990779, 50.78170676385203, 23.237634935686668, 28.048235639449093, 46.84529842868928, 45.88233301716466, 18.423755130460187, 24.350111292254542, 6.503267682367756, 18.829124243028705, 24.563523530960087, 18.540688830037272, 10.535912840597092, 14.888156152540638, 30.659765389657792, 13.592478632926943, 0.3582242149258814, 0.5480348475037083, 0.3897334112515373, 0.15038750284621794, 0.32290366988989616, 0.37425294999153386, 1.4510223774179336, 2.9087811804586843, 3.5449746683720624, 2.722246983358937, 4.922591236329848, 2.4763685512927274, 0.7502644088479781, 1.8954188280528592, 8.806005408686977, 0.9490940719842912, 0.16551528786939962, 0.1932958729805485, 0.23246725089848044, 0.24931193089052556, 0.24342076071808416, 0.09046987405106907, 0.2598318655885035, 0.11509939397294676, 0.21075357652960286, 0.48142613782998056, 0.21531592123210433, 0.16995856718670938, 0.7223673477288216, 1.7811699908587242, 1.2065645787985095, 12.740585919349426, 22.170299176246893, 29.03834777493631, 23.041853750905684, 16.257518337618922, 28.732579408153413, 33.99765337667158, 15.532402511565918, 15.443646138714207, 47.633459491114465, 32.450517608273415, 33.88918022955618, 32.323542641055205, 40.47895431518555, 56.780277682888894, 66.99775388163906, 55.565072490322976, 54.402442747546786, 56.596820585189334, 64.77584492775702, 62.77378089966313, 60.87631471695439, 60.33218391479985, 55.73696251838438, 30.297626679943455, 16.189639760601906, 4.265748675792448, 2.7897377360251645, 12.346692681312563, 46.227623185803814, 55.75051822969991, 52.94257187074231, 57.167623504515625, 57.04631636219641, 58.62816902898974, 58.659571524589296, 60.59466500436107, 59.49626015078638, 36.35590784011349, 15.95880239240585, 0.5354367460935346, 0.9090584396354614, 31.47093507551378, 65.19916280623406, 35.21561207309846, 43.070060283907004, 60.53490377241566, 22.84168343390188, 25.30229606936055, 46.58386853433425, 44.408647552613296, 41.414737701416016, 28.35536114631161, 57.94608062313449, 39.391994937773674, 29.22143420865459, 64.36432946112849, 43.068812970192205, 50.24511475716868, 54.35053410068635, 76.1651566720778, 56.86346330950337, 2.1078437326415895, 0.4400705666311326, 0.14679819705986208, 0.11279087994367847, 0.12593307231943454, 0.266753010331623, 0.1743612591657908, 0.18563957494353095, 0.13188516180361473], [0.04980919439525855, 0.023061971878632907, 0.0283802155360219, 0.044115559994092876, 0.04326357063086283, 0.04548596105568352, 0.05145650176751999, 0.039814198464756055, 0.03764004476608769, 0.04491471993406454, 0.03262470844351957, 0.17333010481970926, 0.21649093156860721, 0.21647652911563076, 17.889969579635128, 75.30084671512728, 61.407462473838564, 38.901431945062455, 27.233055330091908, 62.31199633690619, 29.910871175027665, 27.38011283259238, 48.13864507982808, 32.618553907640525, 42.34915610282652, 37.27633514711934, 47.7014067096095, 27.43625567805383, 23.47491087452058, 40.51231799587127, 24.589032665375743, 52.13505783388692, 84.97102675899383, 8.979760523765318, 0.5651444100564527, 1.3451159312840433, 12.822367337442214, 58.79721533867621, 55.26575250010337, 69.12189775897612, 55.44806818808279, 48.151239810451386, 53.03162536313457, 55.003608734376975, 48.15825693068966, 46.9887787295926, 30.601347569496404, 6.283517874056294, 0.45730779007557903, 2.61817914824332, 22.492545420123687, 34.37306342586395, 51.69607008657148, 59.23537938825546, 62.60471105575562, 56.65751926360592, 52.538814852314616, 41.467650475040564, 15.393937941520447, 5.879319098687941, 26.838706116522513, 40.18180731804141, 27.19824625599769, 9.917356045015397, 16.05806483376411, 3.243575086516719, 13.82536445894549, 11.484825380386846, 7.586778806101892, 10.314613696067564, 4.284206859527096, 11.563632661296475, 20.997483038133193, 7.436171558595474, 1.843557862504836, 0.3967802250577558, 0.6791638498825412, 0.7651540937442934, 0.29036595456061826, 2.4196444596013715, 1.1941541995733016, 0.682579682719323, 2.0032545900152576, 0.8668939408756072, 2.4846111670617135, 0.6913181718799376, 1.0836226661359112, 0.3317426697861764, 3.1089362982780706, 3.636079315216311, 0.3363448970260159, 0.1922007196492726, 0.09409946074048359, 0.1167701474661308, 0.08845389835656652, 0.1086316507069334, 0.0669426703825593, 0.13330279218573726, 0.025683053611447255, 0.46731498212583605, 0.6289755913519091, 0.16581613059726455, 0.6708144721004271, 0.3001563743718209, 1.1750522568341226, 13.8421316108396, 15.280523588580472, 17.058250596446378, 17.186178699616466, 7.1619655239966615, 13.598084680495726, 19.551844481498964, 9.390617032204906, 8.792153558423443, 9.62646326711101, 28.98969077294873, 29.209625913250832, 26.129839689500873, 20.381176702437863, 22.956126428419545, 34.49999916938044, 58.41661991611604, 59.90992115389917, 55.26621141741353, 55.71559736805578, 49.88715533287295, 61.01755926685949, 45.19905221077704, 24.393237752299157, 8.415590332400415, 11.80835129753236, 2.982128522088451, 9.574202587527614, 31.293314464630622, 46.57425872741207, 53.232066323680264, 47.82589097176829, 51.69583866673132, 49.2936771915805, 51.34335879356631, 48.66714523684595, 51.566663249846435, 47.741301136632124, 39.350594320604884, 12.551181527876086, 0.21675867929814324, 8.167073861245187, 53.25857762367495, 46.76875337477654, 28.61986617888174, 44.42637666579216, 34.137933023514286, 12.245933855733565, 26.310372660236975, 37.382137160147394, 30.469671641626668, 28.04549390269864, 19.758886791044667, 36.628987173880304, 19.666052133806293, 45.004808595103604, 36.38612577992101, 33.286213874816895, 30.476877035633212, 51.631315677396714, 43.25951076322987, 7.3671143093416775, 0.3506497504009355, 0.10113440784475497, 0.017979744588956237, 0.0660939981800414, 0.03260240762404377, 0.05400440295136744, 0.012868878059840251, 0.03533425417939021, 0.06022513265751543, 0.0499252490549078, 0.06025360431522132, 0.041584581692492774, 0.04790656140915329, 0.023490854711722464, 0.024141115887511163, 0.0139589196694414, 0.03263777407306818, 0.14444714982903775, 0.07824792181171718, 0.02430658130305669, 0.2792248298083582, 0.22980799117395956, 0.19156406994067854, 25.03516697114514, 84.94597065833308, 65.04082064474782, 26.56947070552457, 40.98377904584331, 42.69664279876217, 29.94712564253038, 36.86516092669579, 35.29575394045922, 31.633107431473274, 37.336174826468195, 38.16586986664803, 41.47307511298887, 33.11271567498484, 31.774867773056034, 39.790590117054606, 36.44196071932393, 58.59400518478886, 89.90986347198488, 16.14392061387339, 1.8542312446140476, 1.3614166888498491, 10.534340950750536, 60.98574884476201, 60.21624649724653, 71.30780327704646, 59.1531547423332, 55.57289369644658, 56.15248272495886, 58.86467618326987, 49.245604622748594, 50.7702063745068, 36.28822342042, 11.395950355837423, 0.5506157670770923, 1.7422267386028845, 19.976013514303393, 34.16950025866109, 44.9929081240008, 54.51156700811079, 57.98234293537756, 54.998172329318145, 50.57252676256242, 37.86726374779978, 11.459227012049768, 8.21289400900564, 29.947504151252012, 44.515296797598566, 33.236470376291585, 19.86871119468443, 25.353353561893588, 10.681174878151188, 11.042057448817838, 7.862844534458653, 9.76943660166956, 14.540780263562358, 11.94992728771702, 23.278049076757124, 28.809928547951486, 12.928980300503394, 2.994240801180563, 1.3875309714386541, 1.0669277103677874, 0.6875383553485717, 0.7241742733505465, 0.23254120902669048, 0.43332951383725293, 0.5048869676407307, 0.38706099013647727, 0.11073931946509308, 1.4928680610272194, 0.2678662893031874, 4.112772806998223, 2.0183054598108416, 1.0798956790278036, 2.2758010943089766, 0.48801951951557593, 0.09822321244545522, 0.5471090455689739, 0.38695762955373336, 0.09947883821423016, 0.3425495656988313, 0.47097869037139806, 0.2593318246785672, 0.13681924301049403, 0.2807181190338827, 0.5251198706607665, 0.7812874151333686, 0.472041346252926, 0.26954711685257576, 0.991664597344014, 14.7388481901538, 22.72393976488421, 22.45633213750778, 22.026448211362286, 10.962763794006841, 17.574428627567908, 13.66393441154111, 17.74648339517655, 12.919024344413513, 16.61337144913212, 43.72186799203196, 32.79207171932344, 32.01121999371436, 29.447082281112674, 25.622255571426887, 32.68983121841185, 55.57811044877576, 61.53504540843349, 58.17405662228985, 57.95765161514283, 50.11638649048344, 59.606494442109145, 42.407587651283514, 18.873772582700177, 7.255761161927254, 13.51612283337501, 4.339226926526716, 13.677225362870002, 36.550865327158284, 50.518798135942035, 57.12114341797368, 51.37145473111061, 55.49588580285349, 55.32507834895965, 54.4037724310352, 56.65573458517752, 56.37877210494011, 52.39792723809519, 41.50101023335611, 11.008874197160045, 0.7495534792542459, 11.545313231406674, 59.402472357596125, 66.81073527182302, 29.68763339904047, 53.44268191245295, 42.6985373035554, 19.280145822032807, 29.004170202439834, 34.91018103015038, 29.150800166591523, 28.805968915262532, 20.36971945916453, 26.37149299344709, 30.659896789058564, 28.36009740829468, 40.87740044439993, 29.90486602629385, 29.304963042659146, 54.256287390185946, 61.12480863448113, 11.711720766559726, 0.4967670485136971, 0.07622167287815003, 0.11387045870745376, 0.09424898578154464, 0.08906660015664755, 0.009685379580684729, 0.05358671266285162, 0.022533313754285057, 0.09647212697253113, 0.11327472575489553, 0.15092468369872342, 0.15194112915665875, 0.14896025039976643, 0.18557911528454674, 0.12603425721247352, 0.13630078534685797, 0.1836088137520898, 0.1886321135586308, 0.24756882039289324, 0.20658089478890743, 0.6155704622787814, 0.4898435442197708, 0.7221467756936628, 33.94448172661566, 96.98495634140508, 79.44669000564083, 52.95450372080649, 39.69560207859163, 80.91510772705078, 41.15217816445136, 40.47519668456047, 64.19496151708788, 46.58629255910074, 59.019829457806004, 50.683655354284475, 62.64979085614605, 34.72677492326306, 30.12577783676886, 50.99806470255698, 31.719674141176288, 60.4823479344768, 98.27840497416835, 16.16917185245022, 1.5981303804343747, 2.779674650199952, 16.084813437154217, 70.03092273589104, 66.67350722897437, 77.73436361743559, 64.30071646167387, 59.28875892393051, 62.35828030493952, 64.28524271134408, 53.5205723393348, 54.649991373861994, 35.53463020632344, 9.149329489277257, 0.6845487125458256, 4.3367597556883295, 29.43652914416406, 39.65474667087678, 54.30654079683366, 61.2728153505633, 65.64400272984659, 60.07805355133549, 55.602939051966516, 48.08402215280841, 20.265525617907127, 9.4000611189873, 33.3872345186049, 52.527353686671105, 40.977464029865885, 14.731302530534807, 26.122820608077514, 7.547871835770146, 19.913808645740634, 26.43581005834764, 11.922205936524177, 18.116770828923872, 10.63350631344703, 19.704693363558864, 30.888998508453373, 13.942415829627747, 2.4706232595828275, 1.0373157767518875, 2.123337830266645, 2.5585505414393643, 3.7051574020616473, 5.967945543027693, 3.254809244986504, 2.0540818884488075, 2.8409768833268076, 3.496250250647145, 7.723166481141122, 6.732401761316485, 4.630415843379113, 2.335706718506352, 6.261779608265047, 5.545865662636296, 0.9230333542631519, 0.43012119889740025, 0.6017304404127983, 0.37065604461296914, 0.2205868972645652, 0.39798969402909284, 0.5754216327782601, 0.2574159307104926, 0.23985858976600632, 1.2004263146269707, 3.7929523039248685, 3.2342339619513485, 1.9324971158658306, 0.5046283057139767, 2.4038164702153977, 17.924509971372544, 21.574824548536732, 23.387247862354403, 26.237759782421975, 10.71885806898917, 22.324866056442264, 24.85458104841171, 16.262790983723058, 14.222106318319998, 13.799457203957344, 37.832884173239435, 39.263078397320164, 36.1570672065981, 31.144593877177087, 30.049370065812145, 39.95844010383853, 62.561364942981356, 64.22181014091738, 58.68916188516925, 57.27331569117885, 53.07495186405798, 64.55216392394036, 48.44240127071258, 25.85435594281843, 11.770710272173728, 16.44227570103061, 4.703152275854542, 11.432900063453182, 36.86359197862687, 52.533931501450084, 58.84878666170182, 58.175272557043264, 60.26025941295009, 58.968677828388834, 60.158030679149014, 60.00254400314824, 61.50948724439068, 55.90990766402214, 47.29719469624181, 14.98460723507789, 0.7369729672228137, 10.417616117385126, 64.00174948476976, 53.56549132254816, 33.27312100318171, 49.87653747681649, 38.410763048356586, 16.74513366914565, 35.555214804987756, 48.84689961710284, 41.962092691852206, 38.94177352228473, 28.73572122666144, 49.19054239026962, 30.295216383472567, 56.196009266761045, 51.74399752770701, 43.620702220547585, 47.53578070671328, 64.03320689355174, 72.70538299314438, 19.872572768119074, 0.6384386158277912, 0.1872319346594234, 0.23601077527048128, 0.19769306444833357, 0.1713977246395042, 0.15155966333564252, 0.18437344610931414, 0.11020396956272664, 0.1290514638587352], [0.030067842115738222, 0.16144811175763607, 0.03594013779694515, 0.026802009294530558, 0.0675824610516429, 0.042499957170577786, 0.0698126732341705, 0.04886799409324604, 0.03133741259995488, 0.04269933921375102, 0.04878087840493649, 0.06335334161356573, 0.07673475260455763, 0.22842590727152365, 1.7295552766130817, 56.007527612870746, 62.5498253299344, 52.645318969603515, 28.82164074528602, 44.5320100169028, 51.59191154664563, 24.588981674563502, 44.08071779435681, 29.326602758899813, 33.49062427397698, 41.70520490215671, 41.59687688273769, 42.161788402065156, 19.13543978045064, 25.888225609256377, 34.1313434416248, 19.930608157188665, 43.5270477879432, 68.43620469493251, 1.5063171329036837, 0.4307118526870205, 5.518613034679044, 51.6909670829773, 65.26618434536842, 58.51004292888027, 54.92155667274229, 45.69855820748114, 60.221529929868645, 52.0208070355077, 51.90791729957827, 51.442277046941946, 53.31440079596735, 39.786812874578665, 5.887230029029231, 0.4367799738482122, 1.9145598719196937, 17.203076270318803, 17.513429887833134, 15.389003599843672, 4.702210907013186, 3.8838216085587782, 3.0664776217552925, 0.05292349885548315, 6.680174421879554, 41.16652619454169, 33.05712784490278, 17.741127398706254, 10.133017763014763, 15.594398513917001, 9.255467845547585, 10.86815720604312, 17.640249921429543, 3.261664322307033, 6.434668369831578, 9.545816394590563, 6.935354999957546, 23.140362116598315, 22.562169451867383, 15.185191362134873, 3.150998079969037, 2.0975499624206178, 1.6293439893953263, 0.8426035604169293, 0.2681919073145236, 0.03832120035264281, 0.1838941355386088, 0.018202588074810563, 0.2385959849362412, 0.18509051972819915, 1.7154956633044829, 10.255156447810512, 2.5137803631444133, 0.4562274835282757, 1.5875518706537064, 5.239913925047844, 0.5034291942513759, 0.2185965395502506, 0.6107908090756786, 0.15162914751037476, 0.10355834068069536, 0.17180813326229974, 0.8940105116175068, 2.364705781782827, 1.5071704935642982, 0.5189735778877812, 0.3430325688133317, 0.02794111692046206, 0.09715697127244166, 0.0153479625230595, 0.28388187830005923, 11.032269174052823, 17.005188772755286, 18.114727274064098, 22.022470928007557, 9.64908161470967, 2.73527194896052, 18.955628525826242, 7.807984304043555, 7.524102272525911, 11.76268510280117, 3.5545325038894533, 18.51367154429036, 21.916902296004757, 26.46464732385451, 26.387127560953942, 22.952043241070164, 20.01486655204527, 36.707693453758, 41.12718089934319, 53.124205066311745, 45.370122463472434, 30.570531468237604, 18.6196167238297, 5.355447338473413, 0.6863014604295454, 1.0264909543818044, 9.656316426492507, 28.601038802054624, 48.662426625528646, 46.04562128743818, 47.0160392022902, 51.31328598145516, 48.559080016228464, 51.68250260814544, 48.21517836663031, 52.363100513335205, 49.08359112278108, 52.31323934370472, 31.98653651821998, 3.4960006898449314, 0.882346363317582, 47.102927546347345, 13.935118259922152, 19.231394683161092, 40.491525511587824, 18.948327033750473, 28.715330785320653, 15.837349141797713, 36.140514804470925, 30.98046818087178, 33.080489481649096, 20.19207335287525, 31.600785140068304, 26.056887526665967, 34.20271096691009, 48.455243110656745, 40.262827796320764, 31.182078007728826, 33.75960473091372, 56.61965270196238, 43.4203593192562, 1.61371665375848, 0.20448265657309564, 0.04315515386781866, 0.031277632844003464, 0.12192651674511934, 0.10429640510870565, 0.039771351167151046, 0.0737295275734317, 0.0328718215948151, 0.11083734041500477, 0.006948372465558351, 0.15263146630698635, 0.11344281310636191, 0.04495422325788006, 0.019530681930782817, 0.03149745985865593, 0.03556197381488258, 0.05960368979421835, 0.05663327962881135, 0.08997492762582918, 0.06256956471911361, 0.08736635993925795, 0.07038554612306819, 0.10133205852921932, 3.01861122250557, 65.67640935221027, 78.07583731989708, 39.12101407204905, 29.108232644296464, 49.730939096020116, 35.85051044341057, 32.34526472706949, 44.20479805238786, 30.49391777284684, 32.2081406270304, 35.86773749320738, 41.26593474418887, 35.971040956435665, 28.58573175245716, 29.151243394420995, 35.60746469805318, 30.268067698324884, 50.968493953827895, 70.78007190458237, 4.130402390033969, 0.543481404742887, 5.767293755085238, 55.0836839214448, 69.60735382572298, 62.748187434288766, 58.3043420699335, 49.53946075131817, 62.522094172816125, 57.88317365031089, 57.09709928881738, 55.56039310270741, 55.03456407977689, 42.92762725583969, 9.501906441104028, 0.30576845871344693, 7.329812078706681, 35.08369099709296, 25.673950449112926, 25.825265684435447, 9.052406741726784, 8.7304066265783, 3.014789608217055, 0.3742409070893642, 10.294601763448409, 48.08569700487199, 37.095690388833326, 24.27582356237596, 20.81247268184539, 29.23382301484385, 13.838040578749872, 12.3810879453536, 8.228635461099687, 3.4683982354979364, 12.350143386471657, 11.215665475014719, 18.040659196915165, 28.640956763298284, 28.409946810814645, 19.914465642744496, 2.005159268456121, 0.06528507061903516, 0.44722227319594354, 0.30554791732180503, 0.15829904605784725, 0.01513839438332305, 0.172792173201038, 0.036448440965144865, 0.18491271072097365, 0.14889573047478355, 0.07401109552912175, 1.7874059465623673, 2.6551357200068813, 0.9256634873247916, 2.009063252518254, 4.337163269519806, 0.40531000122427946, 0.39762301370501524, 1.4386274425252792, 0.6538159003661526, 0.47849686275566783, 0.5168535980966784, 0.47333392044228895, 1.063253675257006, 0.30234517950204115, 0.08208788390601836, 0.23792479998402058, 0.009189826988374755, 0.0505451405901582, 0.026823986441858357, 0.45431857628207056, 16.500930824587424, 20.716019638123054, 24.030222392851307, 26.77901548724021, 12.546764939062058, 7.51999996362194, 13.610035161818228, 10.279167236820346, 14.203989871086614, 14.321312865903302, 11.450598778263217, 31.13361320187969, 27.36975581415238, 30.4644529281124, 36.99273993892055, 30.917892648327737, 23.257150688479026, 35.95204099532097, 37.35508065069876, 52.63766642539732, 43.45824157038043, 30.38092801647802, 16.93175808075936, 6.072410027826987, 1.7576534204906034, 0.8727456268764312, 11.795847762015558, 34.35546375090076, 51.12225086458268, 48.880910488866995, 50.019127399690696, 53.73464745859946, 52.261605262756355, 53.85370316043977, 52.790803601664884, 55.264097259890654, 53.32829775348787, 58.53947247228315, 33.6446871296052, 3.15175705859738, 2.234356595623878, 50.47735829507151, 12.883468058801467, 24.2035597755063, 48.75458271272721, 27.997048708700365, 27.86055414907394, 23.31483502541819, 33.23558784300281, 32.197114844476026, 26.42430966900241, 22.822287313399777, 22.331955740528723, 32.71280650169619, 32.98182225996448, 33.47376592697636, 48.93613353852303, 24.211443739552653, 38.32240381548482, 62.71870690007364, 52.59286119091896, 1.6895820344648056, 0.15654897948186244, 0.014740877105073344, 0.0674122209931093, 0.036631129952448035, 0.0554140736799567, 0.004245317888431131, 0.09326886055209944, 0.012347648115528208, 0.09466514006377229, 0.17908141798069402, 0.28163754711708716, 0.2971488970421976, 0.11796270887697898, 0.12212691002435262, 0.15885982241842056, 0.26597291832008674, 0.2125602416814335, 0.08541815238253725, 0.29254047981192993, 0.18992920766674704, 0.2421310363757995, 0.2985878246686151, 0.6366814552776275, 5.306275525400716, 84.97276829135033, 86.87698487312564, 68.63630048690304, 39.120504163926654, 59.89503575909523, 70.38570111797702, 36.05573669556649, 62.50965241462954, 39.0398366989628, 50.08629406652143, 54.54076120930334, 56.395253904404186, 50.849850100855676, 26.952662737138812, 33.11034264103059, 40.60246582954161, 27.870924895809544, 52.804116126029726, 80.41415829812327, 4.307264512585056, 1.1128144158471016, 6.937011711059078, 60.95499354024088, 75.12083345843901, 66.12569332122803, 63.785462148727916, 56.206242730540616, 69.77731012528943, 60.62644796986734, 58.097162477431766, 58.38088712384624, 58.61975946734029, 45.02841734117077, 8.827501958416356, 0.6267540589455636, 4.407475677228743, 27.14766533144059, 25.474888201682802, 20.832859200816003, 6.031345263604195, 7.125938063667667, 6.716321024202532, 0.978438794132202, 9.197708983575145, 50.90935245636971, 46.8071690682442, 26.458897129181896, 15.94448378009181, 25.063198189581595, 12.345973906978486, 18.180256351347893, 26.527436625572946, 7.226826817758623, 16.81166687319356, 13.375633339728079, 16.259980605494594, 27.639259907507128, 31.523026112587225, 22.45053683557818, 3.864967755732998, 2.835392899090244, 3.077256294988817, 2.2707583971561927, 0.5599924994091834, 0.13298881871085014, 0.3571578818223169, 0.1604038266645324, 0.47318232696383233, 0.29070232844641136, 2.4924196254822517, 23.677050221350886, 7.088032768618676, 0.864661438090186, 2.807984111770507, 7.767065157813411, 1.013676387167746, 0.27655069265634785, 0.7469677792922144, 0.2536757975336044, 0.4320131602787203, 0.6143939963752224, 2.432646871574464, 5.32084075673934, 5.933471341286936, 1.9976661931122504, 0.9748749531084492, 0.12924704610580398, 0.20604616541775966, 0.09950444087265961, 0.24413978020029686, 16.789670221267208, 19.893930073707335, 29.092401958280995, 26.92576704486724, 17.200701275179465, 7.773643462888657, 29.00745910982932, 12.577125064788326, 13.085040623141875, 16.050057315057327, 7.70419103484, 22.69784619731288, 32.154470835962606, 37.33035402913248, 39.66619606940977, 31.92357659339905, 26.77493229989083, 42.36422584902856, 44.76372795720255, 59.89009357267811, 49.77319478988648, 38.79257832804034, 23.008892113162627, 7.055188311684517, 2.6442192735210543, 2.232146830328049, 13.716452006370792, 35.43389981792819, 53.964623866542695, 52.414377658597886, 54.44199985073459, 60.295964748628684, 59.346311861468905, 59.41842071471676, 56.65944122499036, 59.678093387234604, 57.81164138547836, 62.409329952732215, 37.20254751943773, 5.494070274214591, 1.7772528913713272, 47.881765134872936, 16.477061240903794, 24.658323295654792, 51.631915800033084, 22.74378107440087, 34.967082854240175, 21.54724048029992, 47.80453366618003, 42.17896446104973, 44.56140425897414, 30.14188308869639, 43.64572301987679, 37.42018415081886, 46.37519059642669, 63.44093291990219, 55.58692009218278, 42.19610129633258, 51.0298986588755, 67.55742119204614, 71.05372782676451, 3.5978435604803027, 0.3491862160303901, 0.18429784855294615, 0.13221929871266888, 0.2513873396861938, 0.21895307687021073, 0.12783356792023107, 0.1529237901371333, 0.1381715873797094, 0.1509246990204819], [0.02877364765041538, 0.049799434435103214, 0.05598957425043468, 0.006941061113930999, 0.08620585164716167, 0.00917499648377059, 0.0971708298029919, 0.04935020813718439, 0.02308801886805844, 0.08944268037955608, 0.01620075819382985, 0.07312490034007257, 0.05779255451934953, 0.11182574705491144, 0.24376577607566313, 14.931316933324261, 54.547491996519035, 62.28768548657818, 47.03371732465683, 32.21473805366024, 53.414162358930035, 32.84970702663545, 35.11125349229382, 34.979383407100556, 29.621649326816684, 44.59322644818214, 37.76224228643602, 45.52903729100382, 28.492502897016465, 24.18993934508293, 33.47088298489971, 52.025027505813114, 22.36183439531634, 46.11481581964801, 45.58653139298963, 1.0194100956282308, 3.1476331766574615, 26.965988989799257, 50.51469533674179, 60.40336708868704, 63.5124965636961, 64.19103914691557, 57.79811313075405, 49.0670818667258, 52.414981703604425, 56.791005365310184, 56.2428423666185, 49.244251405039144, 25.44634903630903, 0.27017763785777554, 2.3814511154928515, 3.278413333239094, 15.400263744015849, 4.036669755174268, 0.26777757632155574, 4.487474868374487, 0.5908735649239633, 20.848387864328203, 46.17815817556074, 24.679896331602528, 14.342839814001515, 9.609100895543254, 11.123410347969303, 10.633537692408408, 18.231796295412128, 23.89050756731341, 5.447827491068072, 0.6227547735456498, 5.432565058431318, 6.470543348020123, 18.819828225720315, 32.938315330013154, 25.13312032145839, 16.29997407236407, 1.3428655939717449, 0.05583656733975776, 0.2784028174656053, 0.11032637509126818, 0.07549936687874217, 0.016977866292901097, 0.11437985355094557, 0.11019814729450211, 0.08438797862899881, 0.11705291051898273, 0.20045188495949393, 0.46551960911000934, 5.029173801022192, 3.3854155915398754, 2.591600677659435, 2.0730015635490417, 0.1907764549457258, 0.3969391116932516, 0.5739199778726024, 1.1913324219565238, 0.23816161308317418, 0.09108953959038181, 0.495972829840837, 0.1671339856881288, 0.034723869795280124, 0.05980410988652899, 0.03780481112640231, 0.09219878893946448, 0.19138509647980814, 0.0439030701865352, 0.9917907873469015, 10.632903249033037, 14.156214421795262, 18.504297079578524, 28.488441282703032, 18.471376626722275, 0.950241978130033, 7.5129073377578495, 14.272506813849173, 11.783441305160524, 13.703842566859338, 16.87793335606975, 4.3064408148488695, 8.55477269618742, 17.043490717487952, 15.393589831167652, 22.369800729136315, 32.58766720371862, 22.88534921984519, 14.896120525175526, 11.163698973194247, 7.340269607882346, 11.854012589300833, 1.462540049706736, 0.4691700180692058, 3.4667954569862736, 0.6786640541207406, 11.44950443698514, 37.62412386555826, 51.35022686373804, 51.54343105131581, 51.908023203572924, 59.399510968116026, 46.63009758918516, 54.29254578005884, 48.6154797769362, 53.69191323557208, 51.67410481360651, 53.166778472162065, 28.369105131395404, 1.1579680058263964, 5.179349587809655, 49.682356619065814, 67.87620790543096, 57.87868645883376, 11.07277156845216, 26.99974882987238, 29.76000701227496, 22.926747875828898, 37.01264204517488, 31.01235705037271, 32.21515186371342, 24.94399932123, 32.72532082373096, 20.108734753824052, 50.65148799650131, 85.51221186114897, 37.302673862826445, 29.039650001833518, 52.04123866173529, 58.610133970937426, 17.749787992046727, 0.6047032292812102, 0.15991302477496286, 0.1694209879684833, 0.019983093239246838, 0.04008218751198823, 0.0664701626726216, 0.09244388344907954, 0.14000339553721491, 0.037027898379751754, 0.03150456532415363, 0.06430534375531059, 0.014709825646282445, 0.021199244412503416, 0.040061116263630896, 0.11591081898058615, 0.0050706904843419555, 0.10301222724299278, 0.0482618423449176, 0.08177367294387472, 0.02130578234491329, 0.07194530113690323, 0.09908573551764412, 0.13029644866624188, 0.1623133927463524, 0.25684049142704857, 21.990262385337584, 68.53676642141035, 66.83954115836852, 26.817531201147265, 38.63553447108115, 45.67354133052211, 32.98249690763412, 38.32738130323349, 36.61368208546793, 30.591884851455692, 34.99506504304948, 39.58734073946553, 40.85356420086276, 33.69837261015369, 31.068433215541226, 32.46613648629958, 47.321854637515166, 27.427659803821197, 49.53538540870913, 50.642721499166186, 6.089907230869417, 3.3054713135765446, 26.079250920203428, 54.14722980991487, 66.14117099392799, 67.2404230794599, 65.92799017506262, 61.61430866487565, 54.61419974603961, 54.55895316216254, 61.34948592032156, 61.27626703631494, 54.58427990636518, 30.140553405207974, 3.0808352126229197, 6.202507691998636, 7.919825786544432, 28.96926699146148, 10.916579846412906, 1.3331770944979884, 5.1926106310659845, 1.1716937273740768, 25.720375622472456, 49.01225497645717, 33.183718419844105, 21.153789489499985, 20.51960106818907, 24.676678026876143, 13.186408396690124, 19.590115047270253, 17.40535290010514, 4.041847774097997, 5.380790262453018, 8.772281850537947, 11.40136028489759, 26.54706220473013, 34.23010872256371, 30.618698173953643, 15.350861491695529, 0.7840172621992327, 0.20231297299746545, 0.13756772623427455, 0.026254790774997205, 0.07561041898424588, 0.030354807160854824, 0.12900860890025093, 0.016223551224797003, 0.06872501990367329, 0.02388960539153026, 0.06460116094639225, 0.026736300018045212, 1.6365655631788316, 1.6734865884627066, 2.831946606597593, 2.2094887687313944, 0.3217927504691386, 2.1716121560142887, 4.096803612286045, 4.506852847914542, 0.2451115933757636, 0.23818955997065192, 0.43959859518274186, 0.11862918238846526, 0.07859549590296323, 0.1862918988110558, 0.041156729247661374, 0.019804535381075357, 0.18903616365165482, 0.021600594045594338, 0.8337998618521999, 6.605122810409916, 13.74012351036072, 22.796209435309134, 32.97722131975236, 17.86885546099755, 4.57238192519834, 7.101373730167267, 10.496603827322684, 12.315904036644968, 18.106555015810077, 16.696800262697284, 11.771801671674176, 23.35917545903114, 24.678739232401696, 20.015803998516454, 28.80128560527679, 41.72654651826428, 32.32690215110779, 17.551420004137103, 9.606885736988438, 6.1021092341792205, 12.508342381446594, 2.2501576187149173, 0.7243693499795852, 8.410691292055192, 1.4462503238070397, 13.8149211483617, 43.904183680011386, 51.541685596589126, 51.79726331464706, 54.65054835042646, 65.09847164154053, 52.517477158577215, 58.45086220772036, 54.2540555615579, 59.063434447011645, 54.58963001928022, 53.772717983491965, 35.3106197234123, 2.3626156487772545, 6.907456651810677, 59.20232949718353, 61.571550907627234, 50.30451513105824, 10.074427358565792, 26.028454265286847, 28.323129069420602, 27.12990680048543, 35.33831165682885, 29.63705247448337, 28.42999404476535, 21.177117786099835, 24.468213858142978, 30.127595855343728, 32.3443135523027, 87.7666098071683, 41.046407530384684, 24.79276449449601, 56.07992279914118, 67.57164370629096, 18.141691607813684, 0.535985755343591, 0.14860470899410788, 0.15655588959493946, 0.04652812025479732, 0.006320846385337533, 0.04519290944200851, 0.0359588494944957, 0.20151786566261323, 0.05319122743282107, 0.019449468949929844, 0.10420899447654525, 0.1432097646137399, 0.1327109586207136, 0.2443474359930523, 0.15462332555363256, 0.18875185310119585, 0.2213979085847255, 0.20446016423163876, 0.2622605175260575, 0.30766474083065987, 0.16795080395475512, 0.3244147629987809, 0.2588915079832077, 0.2377049327497521, 0.5321238141867423, 33.791301404276204, 85.15225595043552, 77.62862436233029, 61.9858669465588, 40.76592668410271, 72.31873143103816, 45.50214552110242, 50.0050578578826, 46.888726911237164, 41.39380793417654, 61.614904865141845, 50.263412614022535, 60.89353392201086, 35.870710649798, 33.59330800271804, 42.65747401022142, 63.24665792526738, 29.225817457322155, 55.193353391462765, 52.10984876078945, 3.6528660789612806, 5.047767306527784, 32.99201650004233, 61.23348966721566, 68.90553197553082, 74.17573052067911, 70.7136583328247, 66.68640398210096, 58.33209283890263, 61.10476532290059, 63.58107528378887, 65.50065186715895, 55.46126304134246, 33.37429461940643, 2.467600583068786, 4.558818369142471, 5.3092511334726895, 24.98446641429778, 6.9069560593174355, 0.7248286350119499, 7.623680464683041, 1.935881385880132, 22.103371773996663, 60.44767025978335, 37.091203197356194, 20.996406347520892, 15.000304560507498, 20.819089720326087, 12.46885686151443, 25.83413612458014, 30.767732551020963, 9.528157884074796, 7.283315322091503, 10.285705827897596, 10.591641876005358, 25.70070101368812, 38.3188932941806, 31.507405273375976, 24.070040333655573, 1.1300271244779712, 0.21299824479126164, 0.3540195566752265, 0.1647889599083893, 0.7611915805647451, 0.1509614252755719, 0.2947392440851658, 0.11687009129673244, 0.32910702089148186, 0.1634953285176908, 0.6512517734400688, 0.6124191442804953, 12.080593205267384, 9.051845842792142, 5.431499154336992, 3.123181611299515, 0.31586246384728345, 1.0230942430996126, 1.1398378302974086, 2.6064027220972124, 0.416698633663116, 1.3284072472203163, 2.553703227350789, 0.4263398501901858, 0.2753285679125017, 0.22241881267438013, 0.23956249678327193, 0.17061256112590914, 0.5283856115514233, 0.15434921929432502, 1.8258030087717119, 21.35447952055162, 19.437764306222242, 26.805446378646362, 36.32842771468624, 20.586128388681722, 4.225316884056214, 14.62287449067639, 23.225914893611787, 20.01631194545377, 19.12331573424801, 20.623190864439934, 6.023829512057766, 14.326097176920984, 24.16427919941564, 24.56545529826995, 33.85682852037492, 44.234415869559015, 35.49645377743629, 20.824516319459487, 12.480565136478795, 9.730304095052905, 18.640373906781598, 5.656561813046856, 0.5173582355341604, 6.00711384127217, 2.5184894136844145, 14.26362656777905, 45.75548356579196, 60.50942405577629, 56.29020106407904, 58.92231933532223, 68.1610268931235, 55.756527300803896, 64.53573311528852, 57.451340306189756, 65.43046105292537, 58.870928441324544, 61.66871978390602, 36.18491211245137, 2.0151507710256884, 8.46210866205154, 58.64651787665583, 76.44033447388681, 69.09989326230942, 13.90913942167836, 36.81667258662563, 39.69793196647398, 31.835034970314275, 50.181113443067, 45.127927872442434, 46.00634659490278, 35.2572048864057, 47.3144962710719, 32.05091241867312, 63.10856303861065, 104.32892768613755, 49.44472766691639, 40.17470782802951, 65.79960315458237, 80.66427215453118, 33.93495428946711, 0.7597358909345443, 0.34105434593173767, 0.38153697526262653, 0.08193170922177453, 0.10797928087413312, 0.24901550082910448, 0.2173079336963354, 0.42749912508072396, 0.1785222657265202, 0.10784883908326588], [0.023223018882075147, 0.06860217770501491, 0.13359945207353563, 0.07636135368938408, 0.07656868006433211, 0.025557026402243686, 0.06586026475434342, 0.013482901361590673, 0.03951137923004647, 0.06703630164866486, 0.032153794196464365, 0.08508036123408426, 0.100468922586691, 0.06883810980305557, 0.21364430205956583, 3.477527552074002, 53.69995017205515, 55.37542197012133, 54.588072838321814, 34.62389507601338, 41.38858725947719, 36.49507353382726, 41.368277226724935, 44.827505696204405, 26.43834194829387, 37.87604985698577, 41.43318068596625, 40.31449325623051, 39.59495798234017, 24.526433598610666, 34.56400440585229, 52.589111405034224, 66.88503280762704, 44.546334512772106, 65.64943913490542, 27.73375176614331, 2.3818551196206004, 4.324444003643529, 38.82582041525072, 60.93859018818025, 58.64931060421852, 56.85893689432452, 57.70814572611163, 57.86913548746417, 59.141344485744355, 50.18651062442411, 46.037627497027, 59.86784196669056, 43.12391050400273, 6.525117735708914, 7.421340096381403, 10.598621733726995, 3.135533400120274, 16.29041035329142, 15.368077754974367, 12.256447768980458, 31.723908339777303, 40.95821695943033, 24.706103647908858, 11.914907386226039, 9.98489925938268, 8.060710458986222, 12.046458778842805, 21.314432121092274, 25.05328439897107, 6.230242771487083, 4.012066197972144, 1.8436951454608672, 7.032435622907455, 4.497736279041537, 30.644291639328006, 35.75085086207236, 26.559888355193603, 3.658235558579045, 0.3524350416996787, 0.0364959997034842, 0.0829347558019142, 0.10365026357072978, 0.09849941778567531, 0.07312320728575991, 0.04099511150871554, 0.061875128998391093, 0.03438281128183007, 0.017973531615890322, 0.05228571533676117, 0.05326147003459835, 0.8050040876673115, 0.6549233570694923, 0.908345610143677, 3.012583520143263, 0.6988812370165702, 2.7751754464641696, 7.914183947347826, 3.172439226219731, 0.8119867033054753, 0.060572258587325775, 0.08825390344305385, 0.057048840192897673, 0.25527260055945766, 0.08266347640704724, 0.05564832421500356, 0.0287100623527001, 0.10728649990332705, 0.046390151650074034, 0.0855907979571531, 0.44022130209111404, 5.0206254855279004, 13.089626854465855, 30.777691448888472, 28.299196727814216, 2.92060639108381, 1.581058631981573, 10.664620514838926, 13.144366471998154, 11.954146777429889, 18.156571119062363, 19.03740406036377, 8.718582641693855, 5.118383697925076, 15.977305193101207, 13.33705977086098, 16.25304879680757, 27.753330276858424, 32.66767767167861, 17.799651122862294, 2.2963641199373432, 0.6594398437488465, 1.165132950390539, 2.225529301551081, 3.1416052291470193, 0.24356506103950165, 17.63427419047202, 40.39361530734647, 43.91286388520272, 42.21340679353283, 50.01926468264673, 50.10523126971338, 52.27031292453889, 47.41745848809519, 50.94763086688135, 51.04208154063071, 51.76376235100531, 33.47877871605658, 11.879350120021451, 1.3702705814953775, 20.74511185769112, 56.88658568166918, 54.098976812055035, 88.71323462455504, 59.39436874082012, 36.384172439575195, 27.112936665934903, 27.090573272397442, 34.181541935090095, 31.579998539340114, 22.106837188043905, 30.419663383114724, 30.232691841740763, 23.30203240917575, 73.89403373964372, 53.69536884369389, 34.45451928723243, 49.497479623363866, 50.844217577288234, 38.0252960420424, 2.07498824404132, 0.17879824124036298, 0.1098970594185014, 0.14749673135097952, 0.04479736292494401, 0.05274298172744532, 0.08592358655146054, 0.1088700955733657, 0.04149396115192964, 0.07662938487145209, 0.03285091888580111, 0.041262411076815865, 0.1182058651841456, 0.07835558014771632, 0.08214046052026172, 0.059045115936427355, 0.07407602148070451, 0.058529649846135616, 0.0367530949804331, 0.008065257796026286, 0.0629285611813107, 0.056052822469463276, 0.055967893962177544, 0.041652916735338594, 0.043699394220546375, 0.05478251079517988, 5.30277039735548, 67.59364820295765, 67.41529803122243, 47.14970181065221, 28.06110493598446, 44.11147702124811, 29.568450220169563, 39.88673133234824, 43.98634949038106, 32.23198275412283, 33.752046323591664, 34.437304004546135, 39.2252863607099, 36.48476554501441, 32.155155289557676, 34.306602785664225, 58.58903554178054, 62.71623188449491, 49.171134502657004, 74.65885669954362, 36.45506535806964, 5.2234203584732555, 3.8741505146026616, 43.08179993783274, 67.65109523650139, 62.889224098574736, 61.71766704128635, 65.18051978080504, 61.221471525007686, 62.194642943720666, 53.637317765143614, 52.5705115256771, 63.71892306112475, 46.97698024011428, 8.657884943869806, 9.608342897507454, 13.783114648634388, 5.256743834864709, 9.795823366411271, 2.937106086361793, 9.648403044669859, 34.18185572470389, 40.86031459992932, 30.75098599157026, 21.250579857057144, 21.31187277455484, 23.984248292061594, 13.588612156529582, 16.2430977436804, 22.192227186695224, 7.606357807113279, 6.173735635895883, 4.04584099208155, 11.910975210128292, 12.721767367855197, 33.39254148544804, 34.95644930870303, 30.31015276908875, 7.673197936627173, 1.0469299963405057, 0.06344835566837462, 0.07118737204901635, 0.1555124165550355, 0.0657093684158979, 0.04395916314435102, 0.12536269687717, 0.01663745512374707, 0.12735215060773397, 0.04348148051048479, 0.012757098170808487, 0.3059710123606267, 0.5849875581841315, 2.1863462944184584, 0.15029100641127557, 1.7637567510527952, 1.622443927391883, 2.942227721214295, 13.397322085595901, 4.623221726186814, 0.18156314448964211, 0.08883921759984187, 0.16406414880146905, 0.039893044233923, 0.07229505091785424, 0.10811255719032019, 0.10201842734409917, 0.07109875099793558, 0.16746184067620387, 0.11239783853412637, 0.04273261041230252, 1.2335009656606184, 1.4050404318878729, 18.753132243310255, 30.188061152735067, 26.930705308914188, 3.529050335768731, 4.789786156146757, 8.253568007100014, 11.075457411427653, 11.854620556677542, 19.11464337379702, 16.88986324494885, 14.01155839043279, 20.364932206369218, 29.625171615231423, 18.184606259868993, 20.16349888616993, 30.351604377069783, 42.844535766109345, 25.685529285861602, 4.907576403310222, 0.9652519081869434, 0.8614611517517798, 2.2226892603981883, 8.12212202818163, 1.9558929507770848, 19.268423818772842, 43.9048897066424, 49.75914485992924, 48.468579169242616, 54.205249509503766, 52.23923990803381, 57.407182262789824, 53.121726128362845, 55.53926721695931, 55.29821403564946, 58.66259174962198, 40.98170018965199, 14.511203631278008, 3.4889649383483397, 26.61017902435795, 63.5997457658091, 55.62407278245496, 85.32623660179877, 59.246977836855, 10.146804894170455, 27.791216450352824, 28.419236944567775, 33.97303265909995, 28.311724778144594, 23.1018973935035, 20.460889070264756, 37.611654650780466, 24.79751056240451, 61.45079289713214, 67.08999233861124, 24.74736305975145, 48.702309285440755, 59.71066082677534, 44.802743773306574, 2.368223902679259, 0.21080157959893828, 0.0717245145971256, 0.1197997417541281, 0.07175407793012357, 0.038706557900314374, 0.051300039800304564, 0.056424344469222336, 0.047670307554184436, 0.04543789669931416, 0.0243505739021085, 0.1986194486098905, 0.1609013854495941, 0.332256255130614, 0.2618946339334211, 0.10732160205201757, 0.23071972773440425, 0.1697659267172698, 0.1728063305058787, 0.14075426895531917, 0.2526186881286483, 0.1953910008793877, 0.23202601489761185, 0.24669073041408296, 0.27508467616092774, 0.3089759156348244, 9.653938489575541, 88.77660443705898, 72.5187958440473, 73.03610940133372, 49.36630772006128, 57.26591417866369, 50.32066352905766, 56.56190364591537, 62.491907611969985, 36.04943736906975, 57.84394602621756, 55.09940478109545, 55.25719388838738, 49.43224276265791, 33.31136018999162, 46.48264000492711, 64.55304253485896, 79.75725543114447, 55.929264560822524, 78.13228807141705, 37.34005012819844, 4.287944878301313, 5.712457058891173, 47.97745527759675, 73.05188517416678, 68.20866800123646, 66.97426672904723, 68.21609697034283, 65.61409857965285, 68.88260179950346, 58.74550673269457, 55.884424025012606, 66.95802811653384, 52.64486005229335, 8.28072943995076, 18.876214258132443, 21.209579321645922, 6.696264964918937, 25.408621718806607, 30.13144370048277, 21.5062399448887, 35.601855708706765, 59.913749387187345, 33.7360312861781, 19.02900822700993, 19.10512182020372, 16.84156317864695, 15.814117923859628, 27.68299629611354, 29.958808422088627, 10.918344912990447, 10.622498181558425, 4.58757963872725, 12.599173688119459, 9.00919791190855, 38.55587505525158, 43.79323159494708, 34.11913310327838, 12.21511677388222, 0.5604941950690362, 0.09335394227697004, 0.2585586887453833, 0.2654792206181634, 0.15459714066838065, 0.12489158344725448, 0.1879698765133658, 0.1824081394701235, 0.16965344968822696, 0.11942165438085796, 0.14646150141714082, 0.5003044748258206, 0.9351819765663917, 17.516983555209254, 1.415444763918077, 4.075277644780375, 1.0439879735631328, 4.517493257599493, 15.88389002507733, 7.822041098148593, 0.907653434382331, 0.46192460362949683, 0.24627708890024694, 0.2644851142841001, 0.4450296989131359, 0.3015101436645754, 0.24683159866159965, 0.10409920641611661, 0.21768599808696779, 0.5896267415054384, 0.1049549266275379, 0.8151293798319755, 11.123079888282284, 23.195898955868138, 36.24248466184063, 32.008642996511156, 4.110787597394759, 8.065922798648957, 15.050162788360351, 22.509601846818004, 19.796449368999852, 22.364899727606005, 22.25616378168906, 11.112155106759841, 11.864441190996478, 24.786798569463915, 18.216808918983705, 25.980318938532186, 39.32354565589659, 47.62762300429806, 26.50752667457827, 4.869240137838549, 1.1489593021331297, 3.5319634310660826, 7.80694781772552, 8.429223510526842, 1.558683716481732, 21.74214501534739, 47.96926144630679, 55.86848351263232, 51.9389981608237, 58.98451635914465, 58.043912379972404, 62.59708596814064, 57.235319691319624, 62.215733528137214, 61.240710750702895, 62.5527867194145, 45.61130900536814, 16.625440582152336, 3.663618766492413, 23.78667654529695, 68.05964931364983, 61.721201096811605, 102.5712194750386, 66.90582921428066, 50.85170145957701, 36.928409145724395, 36.816150911392704, 47.515419683148785, 44.91965001629245, 32.88036819427244, 45.534356024957475, 45.148983155527425, 36.86406658541772, 92.92037671612155, 69.73228916045159, 43.60125903160342, 66.86105928113385, 64.6359928192631, 66.01165433083811, 3.9226001212673807, 0.24286294145689857, 0.2191264272457169, 0.3412394940612778, 0.10497734236020236, 0.15917425554606224, 0.29296241039710663, 0.2355384667434039, 0.11989212429691708, 0.23442524905887344, 0.0968059957508118], [0.0977934601025716, 0.0557071942415449, 0.10387884888557658, 0.02121791205999832, 0.06407310803150458, 0.09318249179951607, 0.07374818181438793, 0.07063142970324525, 0.02653143661577375, 0.037513284027696624, 0.09464411861113003, 0.07994325906639138, 0.12849041170650913, 0.02756587747905043, 0.04006646355734237, 0.14394223659990296, 23.586380712447628, 78.37593001704063, 49.23480633766421, 47.168215397865545, 43.33128621501308, 41.21348481024466, 37.315884405566806, 47.90098082634711, 30.31364367854211, 27.76863144290063, 43.05063670681369, 38.340129006293516, 44.75523602577948, 30.108937140434023, 33.16405950054046, 29.852924039286954, 46.90657761789138, 74.53305059863676, 62.88228150336974, 77.62907935727027, 15.975938247096156, 1.6816621562165601, 30.217849593008722, 67.77116683221632, 56.063189967986084, 55.39671651778683, 55.31686098344865, 55.05786688097062, 54.77678198968211, 62.47479823327834, 61.310383812073745, 54.03972548823203, 55.74124182424238, 19.671821940329767, 8.094669359345591, 12.59097005090406, 18.426477255359774, 11.132884833120531, 6.30401078731783, 42.270041896450905, 39.72748702572238, 22.23725207390324, 16.389963050042432, 24.935885898528564, 10.933839255763639, 13.494076171228963, 18.429903445705293, 23.80137170514753, 16.11021960935285, 5.718242064599068, 6.104545026056229, 2.273225813142715, 5.686982735510796, 8.655190275561425, 40.17718676597842, 29.53680257643423, 25.958088905580585, 5.463828309889763, 1.3792594281896469, 0.18229198521904408, 0.26327095685466645, 0.12434320238929604, 0.2735585677287271, 0.04965159861791519, 0.15851866814397997, 0.010654464525531137, 0.06630181485126097, 0.1725447421232539, 0.1526912824521142, 0.08290290186602263, 0.1407865212569314, 0.8967616252841488, 0.881727731996967, 2.24542920147219, 1.6221450918143796, 3.427502133192555, 14.887038277041528, 7.6252582380848555, 0.10877782028288611, 0.236751597615019, 0.05230038209007152, 0.04928258938654777, 0.0532715555821215, 0.09829405259581343, 0.0561426347872663, 0.13143347636345895, 0.028201950706481457, 0.15805564460254487, 0.2695029901881372, 2.055009896716764, 3.3638646189243566, 5.515713912825431, 26.529652764720304, 33.69125350829094, 3.3144172593470547, 0.9097740270437733, 6.8370932532895, 9.72700636233053, 16.171329156044994, 13.973732033083516, 23.202551295680387, 25.34240230437248, 10.468184294239169, 5.889622184538073, 20.281334730886645, 27.98710942268372, 27.015846237059566, 29.577148076026674, 40.272025754374845, 47.48428390872094, 12.301740357952735, 0.46275556387920536, 2.0231639281395943, 8.866032381211559, 0.7464193829124974, 8.53271818930103, 39.47867931858186, 47.31664572992633, 50.16287442176573, 47.15854675539079, 47.980538260552194, 50.522598912639005, 52.96463128059141, 53.60431886488392, 52.855550166099306, 50.899217051844445, 43.24327607308665, 10.84153902146124, 12.392725617654863, 48.02495910275368, 59.239042881996404, 51.11945813701999, 35.556446429221864, 54.38983624981296, 57.410963427635934, 23.095564726860296, 27.862636927635442, 34.60083546177034, 27.30610751336621, 17.159585029848163, 32.85599850839184, 24.119403362274173, 36.424443414134366, 69.8061473907963, 23.376630006297944, 41.36937549037319, 47.0723016800419, 59.14382734606343, 11.774747371673586, 0.1785039255816129, 0.14816486727326147, 0.05192712107072434, 0.012948759962924787, 0.03379130330417426, 0.12233952240597819, 0.031794294031457074, 0.027897585889384634, 0.0671388042129336, 0.020966612238196597, 0.016392249531382998, 0.04153804951197198, 0.00960598605865192, 0.056732036023130344, 0.07467767629291742, 0.05033314873975131, 0.08113744458363903, 0.050625491722096364, 0.01701285927406242, 0.022550209823455063, 0.04380765776600569, 0.09331864860629843, 0.025842081973209016, 0.14473323770348104, 0.08388626764738753, 0.03170645247483927, 0.1164166744978678, 35.2347767737604, 90.53291628437658, 55.13203890092912, 39.54778363627773, 44.12518962737053, 38.35222559590494, 29.445634926519087, 40.6252077318007, 33.53624143908101, 33.455040531773726, 32.839677526104836, 33.64009403413342, 39.18437996218282, 32.917005092866965, 37.0078920548962, 32.375237518741244, 46.28678037274269, 83.40741311350178, 69.07678265725413, 77.29580340846893, 22.816592031909575, 0.8152124237629675, 34.298099087130645, 71.34897247437509, 62.54125102873772, 65.07365088309011, 60.062309157463815, 58.5075443790805, 60.27115967965896, 66.85069637913858, 67.09003940705331, 56.594004323405606, 59.518390163298584, 19.42981562306804, 8.86782588497285, 13.26641200050231, 11.212778610567893, 3.888724816422309, 8.671961349825706, 46.528618028087, 37.668419191914225, 30.10901362665238, 28.74223824470274, 33.541007118840376, 23.5246249552696, 17.79900000941369, 16.289868085615097, 24.503591675912183, 17.74012327194214, 6.572606851977687, 7.414347981252979, 6.124822208958288, 14.51994953616973, 17.908161532494333, 43.10668737657609, 34.77699302857922, 31.003833739988266, 10.861895142063018, 2.1942329550943067, 0.5096113092957005, 0.09936929530193729, 0.2624085257130285, 0.07691036293944044, 0.024726950984087684, 0.057897114029694954, 0.07144851610064507, 0.12171731345475682, 0.11788668997225263, 0.14998025050567043, 0.22082714243761956, 0.04660042746353053, 4.766173978005686, 1.1375406696911783, 1.8984388079374068, 6.1936245041508835, 8.599253354534026, 13.389824475011519, 4.799447934473715, 0.0811401412131325, 0.2801277410359152, 0.23668105623895125, 0.08638841806039696, 0.015581174051359057, 0.1484265475864372, 0.1928471139962635, 0.1884745445943648, 0.6353040904768052, 0.08712685021061091, 0.16882627391286437, 2.847501991256591, 4.188952590188673, 11.340484119230702, 30.785771531443444, 33.166691410926084, 6.562800436250626, 3.987711956424098, 3.863343404185388, 9.484519554722695, 14.231190527639082, 13.098153106627926, 19.013006917891964, 23.071098942910474, 13.238556308131065, 15.87780446775498, 36.36801619683543, 42.11861487357847, 35.59264598354217, 32.909642804053526, 44.58797439452141, 52.08573795134022, 16.731619142716934, 2.1333531122053824, 1.7246312311580105, 3.228850999186116, 1.418644192238008, 10.127548998402013, 46.05398378064556, 52.43652336059078, 56.68492094162972, 52.30556718764767, 55.69505591546336, 55.076278486559474, 59.511882951182706, 58.92771259430916, 59.44840331231395, 53.17407408068257, 49.50369265771682, 11.53456005357927, 14.916996359825136, 55.91169626482072, 62.84186540111419, 58.414913685091086, 43.33160392699703, 62.572763350702104, 39.18892206684236, 29.248910411711666, 29.37582458219221, 32.60619059685738, 25.55725601411635, 14.666297089669014, 25.564690866777976, 40.04665420901391, 25.77100165428654, 78.8986329109438, 32.849795279964326, 31.676173094780218, 53.01192329775903, 67.9327606385754, 11.98159062093304, 0.2688755335346345, 0.045419633163199316, 0.05693038001716618, 0.01624897576778406, 0.01034884619706821, 0.03670508425021845, 0.05032192938210023, 0.10811048875292463, 0.07044933826452301, 0.01988080709481672, 0.024119297703427654, 0.2060895719595494, 0.1459901734826065, 0.16795330140138828, 0.17834047306208842, 0.13060616269227, 0.1554880396372849, 0.20844968967139724, 0.10619713819675869, 0.10923083105515088, 0.20019832517831557, 0.17752601434626888, 0.24834580208745696, 0.24758731375538537, 0.17616459949603006, 0.17528427254048087, 0.2771993852671116, 52.10851907730103, 103.64765905564832, 67.27070377719018, 65.42576989819928, 60.52968309771631, 59.5972768722042, 55.51958476343463, 68.75696828288417, 40.62410554578228, 42.54203081130982, 61.18470322701239, 51.83589866084438, 61.17289297042355, 39.59989232401694, 45.730925606143096, 40.57634284419399, 58.22767542254541, 87.54761603570755, 76.61861404295891, 88.53088363524407, 21.576383690680228, 3.0768106156779877, 38.05948734283447, 78.1804390876524, 68.29760382252356, 68.23453995489305, 65.88732304111605, 61.29096415735061, 64.78829453068396, 70.88696433651832, 69.01418947404431, 63.04778199042044, 61.43950823814639, 25.694160461425785, 18.152293774389452, 22.7650579714006, 29.769961987772298, 21.298511220562844, 11.510892471959515, 46.237480102046845, 54.94162744091403, 31.297942861433956, 27.55487403561992, 32.94626989672261, 17.121394872665405, 18.67512414532323, 20.632775175955988, 27.898505041676184, 22.234445618044948, 10.954641545972517, 9.800489025731242, 7.075429702958754, 12.075946177205733, 14.410108462456735, 54.226175354373076, 40.43016787498228, 36.180601427632, 17.0738184836603, 1.947201346197436, 0.5604105382677048, 0.45562120154500013, 0.1845554379566062, 0.3609897310455, 0.13751897239877334, 0.34745960706664675, 0.2119994653208602, 0.2757896609123676, 0.2803274754795336, 0.33000490658225556, 0.3768618470959125, 0.19458199670958906, 9.622446760054558, 1.6030686444813207, 6.839095132966196, 6.471932847653666, 14.173051195759928, 23.98179484951881, 10.924278478468619, 0.18536427358706153, 0.3168018715035531, 0.5783834512675963, 0.15640233493139669, 0.13107934455958106, 0.3398064499901187, 0.35776002693080133, 0.294831603645317, 0.7763584667155821, 0.30584362726057734, 0.42663062652272565, 6.698123187788072, 4.8226791524118, 21.940879744868127, 33.126365523184504, 40.80099267344321, 9.012892784610871, 5.0994999370267315, 7.640201978145107, 16.447886651562108, 21.773892679522117, 18.329541760106242, 28.789745992229832, 28.96580157741424, 11.589735054200696, 9.657098939341884, 28.865026081762007, 38.49597261797997, 33.899570588142645, 38.592078531942065, 53.19237193753643, 61.32376301673151, 15.906498566750559, 1.8478441550847025, 6.941164030182747, 18.41973666221865, 1.989097898044894, 13.838041559342416, 51.43445976318852, 55.29088704816757, 62.10066295439198, 58.036302981838105, 59.514840418292636, 59.86863820783554, 64.02589951792072, 62.59168486441336, 63.239982051234094, 59.13375469946093, 53.44277997170725, 15.808143173494647, 17.051162873545003, 58.34124765088482, 68.43225879053917, 60.5902954839891, 44.72290392844908, 63.541647618816754, 79.47867301202591, 34.90219900684972, 38.65737422820061, 47.8473973274231, 41.01311445236206, 28.79319963916656, 47.15815059600338, 41.211978620098485, 49.36127924150037, 88.52066193857502, 37.4467582087363, 57.34308681180401, 58.490705643930745, 81.26291213497039, 26.43319775981288, 0.5743603252114788, 0.19092334464432734, 0.19313284947026163, 0.11561415909278779, 0.14659265566977764, 0.21733960377112513, 0.19868809008790603, 0.11432047407593458, 0.22206544695842653, 0.08609846144193604, 0.11058749616025917], [0.024478167761117223, 0.10588536339421427, 0.0425546366961733, 0.03486729294602429, 0.04865044044450887, 0.025060499920659972, 0.012344511943088185, 0.06750408259610977, 0.07916083048668601, 0.037187926486254706, 0.026852584504071745, 0.04592069297007496, 0.04130009494181122, 0.06852897800384991, 0.027327377071243622, 0.20111862660175372, 1.831226543553414, 58.782357400463475, 64.01175152870917, 46.89150787168934, 38.10338650980304, 38.339046432125954, 33.96410534458776, 56.356826443826, 40.78475406092983, 28.114109885308054, 33.48495252670781, 39.245121786671305, 41.289527800775346, 36.36460765715569, 27.785566276119603, 50.36923031653128, 68.71514797210693, 58.15828869419714, 51.46143782523371, 79.06062679906046, 27.60506860671505, 3.1435394479382426, 24.7142307989059, 55.5001494192308, 64.35226032810827, 54.874284267425544, 59.94873692912441, 58.77911360033097, 62.43118539933236, 51.147495239011704, 37.40909561034172, 54.812506937211566, 52.42101823129962, 13.349252458541626, 6.483828415793758, 14.206821822351026, 7.1289965318095305, 7.630393110936688, 43.630166899773386, 42.58065439039662, 23.928040727492302, 21.91548239800238, 38.474364280700684, 16.07460742996585, 11.244002638324615, 23.09815545235911, 19.391188121611073, 14.132392887146244, 13.578251215719408, 10.99182757639116, 7.720092813814841, 3.335115851894502, 4.894039323253017, 18.62536495731723, 38.502844610521876, 26.624007340400453, 21.652591420758156, 8.48286388381835, 2.27162377007546, 0.37490939541209134, 0.37196305189882556, 0.27662089695372893, 0.18174391059625536, 0.5158507583602783, 0.12569539354092654, 0.06385307608833236, 0.050589274915476004, 0.18322088214899265, 0.23714219520409263, 0.2098581116766699, 0.4302185533508178, 0.6174737311178639, 0.4334960613519915, 1.6021672347860954, 6.0371111477575, 4.669855765758022, 9.386954519056506, 1.9057113725331523, 0.14683591922925365, 0.0763083097615069, 0.4440018234233703, 0.03464048495516181, 0.04403420145653429, 0.14372685864087076, 0.0662704818551579, 0.07022989237861288, 0.5721377509255563, 0.4200594000999005, 0.20743290713477522, 1.6354883822702593, 4.731617896787582, 2.900869514672987, 20.425701487448908, 38.47401518975535, 4.6495280823399945, 1.8804347611242727, 6.054005286385936, 5.0211329421689435, 11.913543381998617, 18.925432159054665, 17.617437416507354, 20.602449370968728, 27.78918270141848, 15.22649392004936, 5.175717963326362, 18.1599384738553, 25.67072626083128, 34.50719279627646, 35.154258358863096, 41.6101933294727, 55.54987330590525, 34.009836258426795, 8.352681398391724, 12.078159374575462, 5.126203433159859, 8.38940949209275, 41.71189254330051, 44.73163904682283, 49.28082358452582, 49.47152529993365, 52.66538581540508, 50.937546453168316, 48.99914249297112, 52.70059301007179, 56.346173286437995, 45.831424574698175, 45.720339129048014, 27.138122204811346, 20.417895970806, 66.62119850035637, 40.3513753029608, 55.83375092475645, 37.727556767002234, 41.14896182091006, 88.98056768601941, 23.048131504366477, 32.86021701751217, 35.916433718896684, 25.39955908252347, 24.06457058845028, 28.860950739152972, 22.247630665379187, 53.92451763153077, 55.39901110433764, 25.15017870933779, 43.90524271995791, 55.50321671270556, 41.07536246699672, 0.7226121281423877, 0.038205387010689706, 0.08557806557585156, 0.020135062100786357, 0.08178074393541583, 0.06499186578777529, 0.09891915735938857, 0.11115234044771041, 0.039647497732432625, 0.04455442495283581, 0.0941202064014731, 0.07689602943437715, 0.12019271421576701, 0.023378211058556073, 0.04429309320966563, 0.15305256951720486, 0.021947440353312322, 0.06462127841528385, 0.027137703277290832, 0.06294727287886125, 0.03912215293835729, 0.04149630921141755, 0.005974272038832668, 0.02701353191608383, 0.03514563950199274, 0.027542891010882396, 0.12231797235266817, 0.05752101848502794, 4.151695957106929, 74.70564273095901, 76.56937260781565, 46.01175162100023, 37.541377544403076, 42.25018685863864, 36.97770157167989, 39.511097708056056, 32.551279375630045, 33.273003332076534, 32.03381284590691, 33.97467220983198, 35.86278353967975, 38.795480881967855, 34.73092479090537, 46.75933968636298, 86.15031088552168, 75.57363187113117, 58.78040798248784, 84.55990745175271, 28.269127838073242, 3.698210394190204, 26.66195038826235, 57.3332691192627, 76.36900224993306, 62.51768150637227, 63.812867749121885, 61.594994914147165, 68.09648036956787, 65.2768139685354, 48.806801226831254, 56.03255233457012, 57.3028354490957, 14.750365249572264, 8.88632280211295, 10.219192235700547, 1.5794152814534403, 11.14857235262471, 49.284789100770034, 40.40832419549265, 33.016594071542066, 36.466004848480225, 43.18413457562847, 31.604432944328558, 15.327729313604294, 20.068897201168923, 15.403919393016448, 14.890504671681313, 13.795699573332264, 12.697383953678994, 9.54538199209398, 8.252943369650072, 13.811274324693988, 24.779840284778228, 44.28406130883002, 29.745033364142145, 30.84932177297531, 5.941401393182817, 2.461159560949572, 0.07738773530769734, 0.12527982148552133, 0.321354701394035, 0.10181044979441552, 0.29433153209186375, 0.041981212223970124, 0.28976482068819387, 0.06446265224968234, 0.050649749896218704, 0.03298399218868825, 0.17738198981650416, 0.39519914215610874, 0.7304017101564716, 0.6173515247721827, 3.267228449544599, 8.958116885154478, 6.296779897905165, 5.472435951232911, 1.5229565626190555, 0.12669361376714322, 0.142116220067105, 0.25620609401695194, 0.06699146252245673, 0.08222459229610621, 0.3368793812490279, 0.5495511500104782, 0.11302950867121259, 0.2186377397588184, 0.20592565978727034, 0.2774758817207429, 1.906050289830854, 4.055725364915786, 5.509843105270017, 26.486732229109734, 36.68033884417626, 10.424325331564873, 3.6187642572387575, 3.9892894846777764, 3.9936918548999296, 9.066306641024928, 16.2139819898913, 16.292875562944722, 17.508974075317383, 24.697468549974506, 17.41519412686748, 13.542652764628011, 33.85518112490254, 48.75113102697557, 56.22553686941824, 46.94292622227823, 44.82863141644386, 59.83898116696266, 42.76178160021382, 15.087688103798898, 5.8012001937435524, 1.055785972745188, 8.945999703099652, 48.61636623259514, 59.33273653830252, 55.76901612743255, 53.479716931619954, 59.45845242469542, 55.96351861953736, 54.384846994953776, 58.338611818129024, 62.67946358649962, 51.996092181051935, 51.77063434354721, 22.856525682633926, 24.38570680156831, 69.2853899924986, 48.31603819324125, 61.84926648293773, 41.10539213303597, 48.94901067979875, 86.13710818752166, 32.87647131950625, 33.57580246463899, 31.628630045921575, 21.84913354535257, 17.508350418459987, 35.28318274405695, 29.904199223364557, 44.87380143134825, 72.40099137829196, 22.426749621668172, 46.4704296665807, 63.516085532403764, 40.30080418432913, 0.638796593393049, 0.1236876915960062, 0.034457305671587106, 0.02258254639473894, 0.08705511373738128, 0.06343837737316085, 0.05972081314652197, 0.08836040498628732, 0.007917522527878324, 0.036827405509088314, 0.09668583485988841, 0.071377522732702, 0.24121937642414726, 0.1734705134144714, 0.19422709881778688, 0.1625365541586953, 0.12033585774441881, 0.15913120140471768, 0.1409309747959337, 0.14487629696246118, 0.14815933611844817, 0.22026639672056322, 0.17376135103404525, 0.159307616131921, 0.22055228541214622, 0.32112318962331743, 0.2832725626086035, 0.4179510648452467, 9.905418311395954, 93.19219696906306, 79.77580039731919, 63.71762475659771, 52.332792359013716, 51.310175541908514, 51.161702063775834, 76.78241222135483, 54.605735271207756, 37.050928300426854, 49.65070309177522, 52.711501121521, 57.371010165060724, 49.02510858351185, 41.08278359136274, 64.11898128447994, 83.80077192860266, 67.94151536880001, 61.38854880486766, 89.8774568496212, 34.53723422942623, 4.64387986929186, 29.888348925498228, 67.10401873434743, 77.68856602330362, 64.61224286786972, 67.9876345972861, 65.62279055195471, 75.00471561185776, 62.06887606651553, 45.3978261639995, 58.13833559713056, 59.36407627597932, 19.08269370755842, 17.436065058554373, 28.984523050246704, 20.930616432620635, 15.965826376791924, 51.603608054499475, 58.04588533216908, 34.49229955673218, 34.098179801817864, 43.978532206627634, 22.971762957111483, 13.87495400444154, 27.70408688053008, 20.192422443820586, 20.234560466581776, 16.962621250460227, 16.411199742747893, 10.901752306569009, 7.693618286040522, 9.836599346130125, 27.24707388108777, 53.84685862448908, 35.59818437022548, 39.481989799007295, 22.4626059685984, 3.42439855779371, 0.4094667943014253, 0.34521355984672425, 0.26593118184997194, 0.2163359213380083, 0.4601897209161713, 0.3489657665692991, 0.40399802968867365, 0.14125184306213934, 0.4473681976237605, 0.7971698886925175, 0.46431115137473233, 0.7445458995719111, 1.053990752946946, 0.5363066542533137, 9.268145926537054, 13.492136559178753, 13.973616323163434, 19.562083828833796, 1.8380486484496825, 0.3635573819760354, 0.1929314143114513, 0.5944462925676377, 0.19385563810506176, 0.16541149827741808, 0.3410079210035263, 0.48366709822608583, 0.22090447135269645, 1.709705754633873, 1.4393258695640874, 2.275099970640675, 2.0217339790636495, 10.02189995781068, 16.006144419793163, 29.431930165137018, 43.793062933029674, 9.967051494506098, 4.3132289667283334, 9.108134796542506, 5.914385088028447, 17.926653546671716, 25.99164870477492, 21.916892490079327, 25.108209348494007, 33.12897782171927, 17.851600954609534, 6.408305139310899, 24.25879066990268, 34.98734189618018, 45.510162845734634, 43.36642280701668, 50.47968033821353, 66.4279668561874, 45.21996236616566, 15.792106563045134, 27.326284185532604, 16.74042682493887, 13.257216003633316, 49.422174038425574, 51.86581065577846, 56.17025498420962, 57.581162914153076, 61.23371324231548, 63.38043820473456, 56.93811385862289, 66.6522087589387, 66.64933758397257, 58.51157657561764, 54.23673829724712, 35.526495210586056, 27.44662250241926, 76.42981467708465, 53.65755719523276, 66.96937161107218, 43.73089336579846, 54.428561810524236, 103.52073115687217, 38.3670364656756, 44.02043488717849, 48.95203874957178, 37.1042803795107, 38.27804180883592, 43.5568578012528, 35.414378181580574, 69.53151872081142, 69.44567372722011, 34.465525457935954, 60.1785917435923, 68.97632291240078, 70.17916479418355, 1.027987216028475, 0.2390723537293173, 0.18699590296995255, 0.136019661722164, 0.2254172042012215, 0.23154285856552664, 0.1310502178966999, 0.3615364420317835, 0.13517037664930667, 0.12983374688173496, 0.32455465065375455, 0.1716979698187882], [0.09531734901810847, 0.07192864638542937, 0.02221759934459002, 0.03096816396611112, 0.06044697256818895, 0.04020129120157611, 0.024066466364949465, 0.05411337512815672, 0.0797169873370759, 0.017868108341410276, 0.012247270487639452, 0.15841719213752978, 0.041755760208733624, 0.030169915670769352, 0.08578417387099997, 0.0537951575261691, 0.2666491288090906, 26.522465021379535, 73.3344841003418, 56.19515811243365, 36.092858006877286, 42.690123819535785, 25.668096311630745, 41.043571656750096, 53.400202643486764, 26.463511797689623, 30.49073280826692, 31.29550510837186, 38.01063814470845, 41.0872237143978, 29.976200211432676, 26.196472913988178, 44.10813123949113, 38.88380873587824, 60.80511585358651, 70.85462831681775, 38.02941453072333, 3.8157903042531784, 26.964147437003355, 63.7278699874878, 54.131920799132324, 52.43642530133648, 61.1886412866654, 52.108711273439475, 65.33724984815045, 20.884208909926876, 44.51210006590813, 64.86238418086883, 53.41675896798411, 14.793052404157578, 4.477941057374401, 10.71375604598753, 7.163980641672689, 52.54695769279234, 51.83159974313552, 35.35442083112655, 28.290559668694776, 19.670190234338087, 15.305301200958992, 7.944144971909062, 23.091283459817213, 21.628790478552542, 22.17160532551427, 18.00350062308773, 18.693272952110537, 14.948653809485899, 11.438658102866142, 2.3720786119661024, 11.33536542615583, 20.078293238916707, 35.61290502548218, 20.469586926121867, 9.660141718003059, 4.321115382256047, 0.19059516789932407, 0.15249508733470596, 0.11289459292686756, 0.08422786625282419, 0.1715718870682101, 0.3527218343750123, 0.2018708636563632, 0.37829685235215776, 0.023461415868012175, 0.1068095488834285, 0.33053280244911876, 0.08023755940338297, 0.5456047553208567, 0.9339493717397414, 0.15784886215002308, 0.17693298568408336, 7.539676043295092, 5.280379547226814, 1.7532226130847008, 0.2805516021626611, 0.14436036738897526, 0.17687520733283413, 0.020298744446688124, 0.04889573796742386, 0.1155290237417625, 0.08653823421486924, 0.25579473544513026, 0.14591535733592126, 0.04018790381509931, 0.11467579331609512, 0.35585176319845263, 0.5629578725464883, 3.92188968196992, 3.5326640644381126, 15.253011103599304, 37.216385641405665, 9.383403793458017, 3.046372287696408, 6.451302161139827, 5.303342082808095, 9.009077299025751, 13.370588191093939, 15.463848306286721, 21.37123392474267, 22.409132296039214, 26.847968793684437, 18.256830823036935, 8.739840907435264, 9.162259582550295, 13.016254017429969, 29.317902941857618, 45.32588205029888, 43.323166908756384, 54.06329501059748, 55.17236086630053, 21.31067841283737, 1.4180135486587402, 4.547127254547612, 29.617991716631, 18.272890967707482, 52.00845941420525, 45.78945129148422, 63.5041654494501, 47.98420175429314, 51.58201148433071, 45.68505740934803, 53.494688618567686, 48.54917210917319, 55.768325790282226, 16.877390107800885, 34.34601868352583, 68.3772514712426, 40.24286685451385, 55.39786577224732, 56.98709249496461, 69.69820376365416, 41.92144124738632, 20.166570102014852, 33.65785844864384, 33.36625768292335, 29.41090233864323, 23.855810280769106, 26.41683363145398, 48.48945010092951, 84.72195625305176, 26.042249241182883, 37.993160063220614, 47.926036927007864, 53.00461984449818, 4.467761035888426, 0.5137792872565409, 0.21101773896765327, 0.03802599220146095, 0.05064109693311396, 0.013874065855728283, 0.07790535027461667, 0.05800329381600023, 0.018547540230135766, 0.030745561797952944, 0.09092306868443567, 0.06730434049161212, 0.04029691046584518, 0.013532912538897608, 0.04151356917235159, 0.029325301819030317, 0.05190686570600637, 0.04379309443456512, 0.031232441317350156, 0.060889507088089184, 0.0848210174890776, 0.036069698586699464, 0.06532384998976223, 0.018553795338037516, 0.06431297399103642, 0.037172328936116356, 0.025363570049164758, 0.1320024038995466, 0.16370361250254417, 0.34644941288617354, 35.15876123982091, 82.58702585774084, 60.15842291616625, 31.925759392399943, 41.14248598775556, 30.45771625734145, 47.578656135066865, 31.04669151767608, 29.366867849903723, 33.06944016487368, 32.61340775797444, 35.38139497080157, 36.816539226039765, 38.27466464811756, 30.74349818691131, 74.11237639765586, 44.223950985939275, 64.69729946505639, 75.76392958241125, 46.917834820285925, 6.82039866524358, 26.952627435807262, 70.12898199019894, 60.66041177318942, 57.15321271650253, 66.25541394756686, 56.491653996129195, 71.1321673854705, 32.499200105667114, 46.150799643608835, 67.97857392218806, 60.94181829883207, 14.518360976249943, 3.79712644123262, 0.9581483119437773, 14.380127826044637, 57.53871894651844, 51.1878485833445, 46.43761119534893, 50.36814381999355, 30.554318351130334, 30.11818805048543, 11.980536483949232, 20.209435724443008, 17.837588287168934, 18.763626544706284, 14.303093456452894, 14.979616019033617, 21.46581599789281, 12.5105163551146, 8.481800921501653, 18.718817387857747, 25.3561286387905, 39.370382678124216, 26.928238138075802, 27.6160708550484, 1.9265221203527145, 0.5551736837913913, 0.11192303256041582, 0.14710064857236801, 0.035956558891602104, 0.3249636190312524, 0.19313265028740131, 0.3135303083446718, 0.18383035105803322, 0.03184384842883916, 0.01731452171600634, 0.21139675330731178, 0.06517845416261304, 0.3453600358578467, 1.3181361532019031, 0.15457800379203213, 1.0262756530315646, 4.3581023523884435, 11.290522929160826, 3.3124043480042493, 0.07599409879936327, 0.09309094429256455, 0.17715311338824613, 0.03435668768361211, 0.09175780574761092, 0.2225744051318015, 0.23042441616135262, 0.273290436955229, 0.043559119691170996, 0.013494033576740373, 0.16842875088895523, 0.48025227662536407, 1.2226503414492453, 2.800624029290292, 5.888330253862566, 20.642571295461348, 37.50383261711367, 15.26690511934219, 4.945882270413061, 6.453337871259259, 2.796721761265109, 6.462732928414499, 9.998309843001827, 15.057318172147198, 18.00609919332689, 18.81216979795887, 22.662631157905828, 18.852681998283632, 14.099848981826538, 13.917014560391827, 24.51038129868046, 51.14339636218164, 62.465788548992535, 49.928901118616906, 58.2626158960404, 60.26680584876769, 29.216186077364032, 8.130840476482145, 4.008113674579128, 27.739639243771954, 27.355250889255156, 54.21843259565292, 50.79242660153297, 68.65130747518232, 52.82373582163165, 62.87941425077377, 54.38882035593833, 60.33762031985868, 52.889321773282944, 61.548656032931426, 19.608256009317216, 38.05438041687012, 72.06102386597665, 43.07777950840612, 64.77533109726446, 55.22410477361372, 64.8394500824713, 51.70901390814012, 24.879488099005915, 33.898036941405266, 26.736922571736, 26.485006386233916, 18.221449082897557, 38.09694597798009, 39.08575196419993, 81.86602361740606, 34.142553575577274, 33.352639213685066, 58.26866419084611, 59.720576578570956, 4.619394473491177, 0.4633918458655958, 0.24467823275875664, 0.05732901769900515, 0.07795023536610027, 0.04614202726271845, 0.10990852009384863, 0.042239460463245074, 0.05027246691526906, 0.036627123312604044, 0.029141944420013218, 0.06144640321332601, 0.018940049208580487, 0.20857866823432908, 0.1459427066748181, 0.09722423379219348, 0.13891866100170921, 0.148492231965065, 0.1403282321388683, 0.16269142649346785, 0.10265111637812468, 0.29947057246200504, 0.22892430875330205, 0.13460609160604017, 0.36109269326252325, 0.19835905532442755, 0.20610412763011074, 0.2225634347527258, 0.22300447157073408, 0.30420735538486515, 57.323408280649495, 92.66023728155321, 74.77738288141067, 56.57826777427428, 61.04398035234021, 37.939227473351266, 62.87824930683259, 77.96859971938595, 38.261136393393244, 45.38929108650454, 46.12314301152384, 55.472026025095296, 51.58671440616731, 41.84006775579145, 36.46099598177018, 62.121369146531634, 45.91042503233879, 73.67051355300411, 82.52016513578354, 44.81875881072014, 7.039507166031869, 34.78262162977649, 75.25307224642846, 64.21961753599106, 59.56093219018752, 69.6974192896197, 61.36433993616412, 73.22085303644981, 28.30533523713389, 48.88810411576302, 74.8825494704708, 62.46260358441261, 19.651135360040975, 11.561523406736313, 23.825168724982973, 13.52095127105713, 60.4783510392712, 60.60413360595704, 47.37684626733103, 41.385853367467085, 26.378576793978294, 23.10978331873494, 10.145644853191992, 23.931357091472997, 25.865281704933416, 26.518199443817142, 21.543704463589577, 22.989968638266287, 22.05495599777468, 14.102007266013855, 6.63304518307409, 15.979545847062143, 30.195433247473936, 48.751013355870406, 32.89905044340318, 44.082506395155384, 7.376000929263331, 2.2848789297765304, 0.32078301594141995, 0.179267255589366, 0.12417111605886491, 0.9606494357989681, 0.7930761599732984, 0.7005685303480395, 0.5852376705696506, 0.14045439149823882, 0.5709661266976788, 0.7034159259450051, 0.2731418158979185, 0.8857515322104578, 2.3838104211515, 0.3139279079773734, 3.303231885356288, 15.058309551208252, 30.51876598788846, 8.799186368142406, 0.32569578458224574, 0.18697955465364843, 0.31399759133496596, 0.24435076081464369, 0.2390701167525784, 0.25779358141364594, 0.32629569271399134, 0.6318511789844883, 0.17492528373916305, 0.14749778855231502, 0.28847037724429564, 0.8956412983036811, 2.3406327251465093, 6.542587482160138, 15.48435151576996, 22.60964189806292, 47.73699437418292, 17.090906289315996, 4.698081141518009, 9.782515745009146, 7.101283515653304, 14.439308547204542, 20.959175209845267, 20.555922215984715, 26.863779867849043, 24.775651193434193, 30.648335602975664, 21.37201447640696, 10.526754106244734, 10.25474165716479, 17.48021133484379, 39.116852437296224, 55.61510232187087, 50.296556641978604, 64.44402417828961, 63.94517713977445, 29.332196058765536, 8.238940508134904, 7.864185494761314, 30.952344786736276, 20.95825541403986, 59.69689330747051, 53.39856701512491, 69.70829209973736, 58.70297647291615, 65.35445728609639, 56.29144837779384, 67.71799518216041, 57.27435511927451, 66.20792188952046, 20.416074029860958, 41.043822688441125, 82.30194014887657, 48.69770050048829, 69.5124089333319, 68.45691480944234, 84.24156004382719, 55.712847786564986, 30.312221819354644, 48.755347574910815, 45.98211026960804, 45.82981248055735, 33.99567257973456, 41.14259973649056, 64.03933755813107, 100.47107265841578, 39.19266400798675, 51.3615938924974, 59.997362552150605, 77.12967534219065, 14.684670452148685, 0.9516301294488292, 0.3468794946468646, 0.3005722988276713, 0.3201061925820766, 0.3290063875817484, 0.24337268103995632, 0.2381963015443856, 0.1518372782776433, 0.1949306433239291, 0.18673526453635386, 0.13911525448483808, 0.17147802597572728], [0.14963761002065676, 0.0390106909758141, 0.09211120976796074, 0.0429290468474069, 0.06334789472842409, 0.02811679811847787, 0.02330901225157563, 0.08189704374320085, 0.05040421488604719, 0.03347678207642129, 0.010975308851489137, 0.024365809475702625, 0.12312398877956214, 0.12084568159714823, 0.05479081135783946, 0.0396122002313214, 0.09619110293926732, 1.3191314546331283, 71.86147720583024, 65.62916440348472, 50.21408488673549, 59.40330390007266, 66.08427309220838, 22.09007101674234, 58.14565473987211, 30.69286431035688, 28.5176472510061, 32.98675660164126, 28.77333675661395, 43.71590598937004, 31.81214401798864, 21.33252601469717, 27.951925762238044, 51.43820954907326, 84.58011550288047, 66.27929333717593, 75.61636217178838, 26.17928508789309, 10.369875969425326, 55.26868643299226, 64.61052094736408, 68.33642744248914, 63.88403523352839, 67.5259324043028, 54.29021981454665, 33.88850558188654, 72.39238569813391, 57.95598068544942, 48.21942237115676, 8.846652930782689, 7.2786280897355855, 9.632655709020554, 63.785022843268614, 57.57714248472645, 47.48566850539177, 42.55290754379765, 11.759469739852413, 8.760742237490993, 8.336921315039358, 19.292528744666807, 23.83313309761786, 22.78857650295381, 17.689120692591516, 17.64045192349342, 25.497581074314734, 16.626423135880504, 10.633804413580126, 6.4737984249668745, 18.651768392132176, 24.046300188187633, 43.90235585551108, 20.195240666789395, 12.364527698486084, 1.420492486607644, 0.24638654754286815, 0.0785766271573882, 0.18715880390617157, 0.23612008069551763, 0.02547282759370583, 0.23125473289720475, 0.14089473883711523, 0.1850211274840178, 0.344035194045113, 0.0870427873826796, 0.2988710320524631, 0.03187803510246018, 0.12000058702523671, 0.914009819107671, 0.13488173004119627, 1.06135843501937, 3.878994641765472, 4.826693207986893, 0.5202732307295646, 0.09488715234422877, 0.06400917416378375, 0.055641272375660564, 0.05399414503406133, 0.09811950712314538, 0.14926737504861048, 0.039504124377403534, 0.820061760323663, 0.4730906722045714, 0.07532077646183391, 0.141982599011352, 0.025382756721228365, 0.16264388307688699, 2.8676480199060137, 2.4033504436092996, 14.951110193806311, 36.37091482839277, 21.059366272341823, 3.6996155833044364, 4.455527163320973, 4.341374914492331, 5.227321645905895, 10.18309074063455, 13.758698874904265, 15.346526292062576, 23.1009050338499, 22.28924701290746, 24.462942192631385, 23.973757913035733, 22.242380572903542, 16.0785464702114, 9.725242276345531, 25.186711665122743, 48.411371400279386, 51.151535280289195, 53.67854187565466, 63.40940490845711, 21.705041354702367, 2.8864391148090367, 6.784243727883985, 48.254052977408136, 58.26241585516161, 55.475058017238496, 56.51463908533896, 62.65583915095176, 28.293636768094956, 32.911894244532434, 44.35737825209095, 52.576806929803666, 45.46704423043036, 36.41612406699888, 50.59045983899025, 59.67497902531778, 47.81202147083898, 49.724875111733716, 61.09619102170391, 47.29098558425904, 27.559982922769365, 24.990124433271347, 32.22312604227374, 30.605675904981553, 24.09971110282406, 26.905855132687478, 36.82145395586568, 78.1122761387979, 53.679318504948775, 25.415117163811964, 53.96105450968589, 59.30384828198341, 31.277946618295488, 0.36055149810929454, 0.2769144924898302, 0.05988832593204514, 0.24687937190455778, 0.012183569319125627, 0.0870994319238009, 0.038109262128390615, 0.006845861282800475, 0.06318215160600602, 0.06651068872381603, 0.1500296018897526, 0.06951979015983882, 0.03960937336688081, 0.2066868907141109, 0.050225957717385986, 0.06487416403908884, 0.006658351208428823, 0.03994545996970227, 0.011646511040688043, 0.08368786619675737, 0.08914255011346071, 0.09329781101475801, 0.03406472008434996, 0.02289402816865233, 0.061952281713245384, 0.02493198292570249, 0.016187818968788754, 0.017608676496292316, 0.08584517745241042, 0.0668790621022063, 1.9426672088523067, 79.68031421784433, 75.7292950537897, 46.771251924576305, 60.79883613894063, 58.732739417783684, 29.990085401842673, 58.04293963216967, 25.41095356787405, 38.977612218549176, 28.91877235904817, 29.359954672475016, 35.366913580125384, 40.84424464933334, 23.33302893946248, 31.645935543121833, 43.908231566029215, 87.44208858859155, 69.80007556176955, 77.2601882873043, 29.73232488478384, 11.105608670942246, 60.321726875920454, 65.06990894194573, 66.6431402391003, 75.48907341495638, 66.80972330031857, 64.32672177591633, 33.05049511694139, 73.17998978399461, 63.05400679188391, 49.935263203036406, 10.03440643510511, 3.7016233465363904, 15.605585113648447, 68.94760331799908, 58.15278953121555, 58.405076380698915, 62.77687957209926, 25.49505702910885, 17.394468322876964, 13.040353059768679, 16.634509101990734, 24.488027711068433, 18.052991128736927, 16.730740531798332, 12.807286804722203, 25.9060606264299, 22.501729649882165, 14.492718481248426, 12.675410835973679, 22.891483806794692, 30.02549852094343, 44.708234264004616, 30.061097952627367, 23.855078758731967, 0.7906134018013555, 1.006278797022758, 0.15500537360147124, 0.09487484131128558, 0.37782632114906467, 0.12623095794791175, 0.13581571379496207, 0.28668039748745583, 0.2736842674353431, 0.3209211569159262, 0.15369312627421272, 0.3317021284132235, 0.20812080812550363, 0.560953296240299, 0.09213158004586736, 0.09710414951006252, 1.4284479113355761, 4.568717450864853, 8.1872691646699, 1.52310291605611, 0.30592464871944924, 0.0535026804784373, 0.05595418481877255, 0.0943241466677958, 0.16124234054117434, 0.23728389082656753, 0.18449107124920816, 0.411642269501763, 0.3958847295613058, 0.1842066534464398, 0.16628074760158218, 0.1436917871356972, 0.3341804228482708, 2.349311214300894, 5.653697992524793, 18.586264810254498, 35.48995048769059, 26.732968822602306, 7.0735964851994675, 7.368410652683628, 5.685683940687488, 4.549213465183012, 5.794703277849383, 9.683521005415148, 15.41633467520437, 19.405220400902536, 22.17372536659241, 19.532116920717304, 21.886133263188025, 24.739412415412165, 19.13949158883864, 14.66797096114005, 43.55369637089391, 66.1868195379934, 57.845271787335804, 55.128638205989716, 62.94225846567462, 27.091808819001724, 10.69753900651009, 5.2553852238962735, 40.70424741314304, 63.3172566659989, 61.11877995152628, 59.651562475389056, 66.162932303644, 32.53794135585908, 40.75438707105575, 54.36357598150931, 60.83789902348673, 49.414274384898526, 46.076380514329486, 57.30732264057283, 66.34875851292765, 50.08431719195459, 53.214466648717085, 65.37540274281656, 50.47878996018441, 38.10907002418272, 30.03796773572122, 27.091487184647594, 24.87204540160395, 22.66496300697327, 26.537217055597615, 45.24111570850496, 63.96060382166217, 63.33843354255923, 25.796620615067024, 56.26373291015626, 67.47506710790819, 29.907307701726115, 0.4362442945280383, 0.19373286485431657, 0.1218972675081703, 0.3441415883360371, 0.030989334805898612, 0.022218742730817007, 0.10654882618015814, 0.06003988110610555, 0.08788372209716229, 0.08096942618008583, 0.17992701050975632, 0.022344612891996102, 0.162040175149037, 0.26226456247029767, 0.17581354736560778, 0.20360248283513133, 0.13026539146179153, 0.19120741004665054, 0.08564390317206422, 0.15198573079561034, 0.18798342094786707, 0.18330862985983973, 0.10465350933372976, 0.10679488596055778, 0.413465099108796, 0.3182652220129967, 0.31880206578681547, 0.3036577332644694, 0.2059326158656228, 0.4631443994660532, 7.463070192644674, 104.37308572953748, 78.35253700133293, 69.47036112508466, 78.67748968062863, 87.51046334543537, 33.50470166052542, 87.17220598651518, 45.8045014258354, 41.946136489991225, 45.24522635244554, 43.354008505421305, 60.24839032080866, 44.52256102715769, 29.628344812700828, 37.28361506615916, 61.48849079685827, 95.69216666683074, 75.70168941251694, 85.39408576103949, 31.309888439793742, 14.923135849737353, 62.10976677556192, 75.86028652806436, 77.98606211139311, 74.82306280443746, 73.53823554131293, 63.99295160847326, 38.12017425414055, 82.31420932277557, 68.42334716550766, 56.810009248795055, 12.804772565441748, 17.117052808884655, 17.97898384832567, 73.114054741398, 67.95435720874418, 58.97096064782912, 53.129241389613, 16.879084571715325, 14.362323207239951, 10.782356339116252, 22.011976626611528, 28.089728432316935, 23.94939999426565, 21.642148110174364, 20.804057236640684, 32.54262074347466, 22.10608801534099, 16.655148613837458, 8.96858863292202, 25.334669351577762, 36.04862151607391, 56.645010825126406, 34.997979364087506, 38.8041179410873, 0.9803856380524175, 3.0081208434797104, 0.5224826895902234, 0.23900389611240358, 0.3657020297983001, 0.211180379433978, 0.2736724083942752, 0.5882150559656082, 0.3367041003319525, 0.9862139736933093, 0.3294878278768832, 0.584732542835897, 0.28772537205969134, 0.5572030813463273, 1.1384422019604714, 0.20002077664098433, 2.812626236869443, 13.088502114818944, 17.09284197899603, 3.772846969865984, 0.353482375822721, 0.2309162292869822, 0.13689563729830329, 0.21869931790617206, 0.35233980164893214, 0.24136943772675531, 0.1500282995402813, 1.9711443517477283, 0.5220653861761093, 0.19724655776254593, 0.6293501164163313, 0.18589342583812055, 0.7197028939281741, 4.90118686229952, 13.145794214740878, 24.160254847618845, 45.221774501185266, 32.06651168484842, 8.629311457757028, 8.659110684548656, 8.480678143039826, 9.705600027115116, 17.05570693938963, 19.381754821346654, 19.325041271025135, 29.109854544362715, 28.803713552413452, 27.838088773912002, 29.730944210483184, 30.14524063756389, 23.525531022779404, 11.236708990989193, 32.55759243042239, 59.06748625539965, 62.70887351805165, 63.23350229570943, 70.28328803277785, 27.840175474843672, 5.063544550249654, 9.180730023691732, 54.9674758603496, 69.50945146622198, 62.83496595198109, 63.23345914963753, 68.30162817432036, 40.34496615009923, 45.683845396964784, 56.00242068690639, 63.05928237976567, 55.78875741650982, 46.70074732072892, 60.58861670955535, 71.98695382764264, 58.0926517517336, 61.155101099321925, 81.58853161719539, 56.97030082825692, 40.54524629346786, 37.089932349420366, 43.5385520996586, 46.04910827452137, 35.405031173459946, 40.72972320741223, 53.07059018842636, 92.35572015085529, 68.19795208592569, 34.64822161582209, 72.92571821520406, 73.40847569127237, 55.302359980921594, 0.4228084912944225, 0.29636433107718346, 0.2697828267851184, 0.6117354874168673, 0.14371792605567363, 0.1810939616012958, 0.16062760094721473, 0.12309522217800542, 0.17792341479611012, 0.259760006541206, 0.3404028034738956, 0.14315822221819433, 0.1877771594351338], [0.061772025055101806, 0.021190116474885615, 0.1117248532752837, 0.03062895938543783, 0.05501447072733314, 0.03443579775311294, 0.05125387534198742, 0.057296914784538175, 0.0971025177427838, 0.0749691114610722, 0.03873503338845988, 0.053250813751571605, 0.1916972160219185, 0.030759885726917176, 0.08301809084631744, 0.2633495881192146, 0.38707910045500726, 0.8096321780354747, 25.79920349582549, 78.62442001219719, 63.875743342984116, 51.05532346233245, 75.23488813830961, 53.05705016659152, 21.538497517185828, 64.71596210233628, 22.46515747039549, 46.717127138568515, 22.806995953283003, 43.74772817857804, 31.66789689371663, 49.15853584966352, 130.0535257401005, 70.75205833681169, 62.86976914252005, 67.11712729546332, 77.2942344604, 58.90798307234242, 10.489730854188243, 29.774353081180205, 78.57308403138192, 61.462014798195135, 53.673846798558394, 55.26460716801306, 66.48182099865329, 65.20033951728576, 60.73682738888649, 58.62890643458213, 47.30272523818478, 0.7868019611604753, 7.703249665998644, 74.0355920791626, 63.89187997387302, 62.79489109593054, 49.07287520747031, 15.306480853788315, 15.129440753690659, 19.046288228804066, 18.867233991622925, 20.83469290887156, 20.167317313532678, 15.970877408981325, 18.75785085462755, 20.244285983424035, 23.32355445431125, 19.22018454920861, 13.658916719498174, 9.835216710644385, 22.481174468994144, 22.949405447129283, 46.02987297119633, 24.798936343962147, 11.095688016183916, 1.3553066167139238, 0.3986212569138696, 0.14523917749043436, 0.31000109449509655, 0.2386440033273351, 0.20213953069140836, 0.10800953368626295, 0.17061481342440651, 0.11250378083317511, 0.20957738641769658, 0.23041594322891007, 0.9271390339539898, 0.08630798648922675, 0.8142784706527187, 0.19256291069811393, 0.77187807809922, 0.13649707239481712, 1.8230828450572107, 4.930156507799703, 0.72753292538466, 0.0393606361091858, 0.13798740452095387, 0.3324803818137415, 0.07411716806311762, 0.0411459963558422, 0.03959278373288051, 0.1608054252761987, 0.25017989318697686, 0.1910634161604028, 0.11224296619935382, 0.14127170006113668, 0.026185716457304456, 0.4978219209419143, 0.9527469630683623, 1.1492618149326694, 14.738272582331012, 38.0293047043585, 25.20931040087054, 5.690072582614038, 7.8065472456716725, 3.7414383455630276, 5.695704615885212, 9.67684611197441, 18.992247773754983, 14.37833530287589, 14.803747727024941, 21.622889272628292, 24.177275972981608, 22.53091404514928, 17.325091400454124, 22.298443009776456, 19.809857991433915, 9.771734129997993, 21.346866200047156, 40.13636273722495, 40.50880355219687, 45.68077418111986, 59.823829050987, 12.072854368917405, 7.353844931048732, 57.46591975612026, 46.156236048667665, 37.67467929470924, 45.60189923932476, 51.460535680094075, 37.640056533198205, 37.86905234859836, 43.93123626708985, 55.55099902614471, 54.35653924942017, 52.05236642591415, 57.52171154945128, 55.73846086379021, 54.79639384054369, 55.78193641478016, 58.687938105675485, 53.23858530290666, 30.07441047699221, 27.073614904957434, 37.06587253078338, 27.017387728537283, 21.619682735012425, 35.41793969369704, 56.773123279694595, 86.81498789018201, 33.121744971121515, 47.87118258014802, 56.039565532438225, 48.93556087247787, 1.222465622328943, 0.16439966466878692, 0.012356359492837182, 0.21290069115498375, 0.013041031422964748, 0.044418329433087385, 0.01058295309062927, 0.06003571358779746, 0.02791232925148741, 0.011738387965447, 0.033929405974284295, 0.06365264450470287, 0.12451691282612663, 0.019598628184007063, 0.05913603142084134, 0.007929052151138745, 0.05566697462552017, 0.0496597076585937, 0.09291180229235081, 0.029816458024264827, 0.05757228508892079, 0.02871172093305617, 0.0213896325834456, 0.07225742833989282, 0.07497337090993121, 0.1922067717438744, 0.28601448322015427, 0.07024758900966376, 0.033598034642636776, 0.28145233770051314, 0.44086172095229553, 1.0359083813044334, 29.67507789211889, 88.13829360469695, 67.87823184843987, 53.21362726150021, 78.74506427395728, 42.36956027246291, 32.85541603642125, 41.09646089615361, 23.792348292566118, 44.73412975188225, 23.38663597260752, 39.38426002379387, 35.865337002661924, 53.6158545555607, 102.53991111632317, 72.4172378355457, 68.41733024966332, 73.38610249180948, 76.23250376793646, 67.16790629971412, 12.362876380643538, 35.580745512439364, 82.11279561442714, 67.85829051848381, 63.84419964205835, 58.100892651465635, 71.13533666056972, 56.163045667832904, 64.36083855167513, 61.29505518944033, 52.94986747926282, 0.3455218642709717, 11.509594167432478, 84.43969465071156, 67.77847813021752, 70.89160842280235, 70.09244118967365, 27.371356141182687, 18.500890501083866, 18.592887732290453, 17.87289942464521, 21.45393317745578, 17.53799569222235, 16.133319427890164, 16.09587550163269, 16.14529540461879, 30.988773799711662, 23.655683109837195, 17.681368127945934, 17.027612963030418, 22.19513758536308, 27.2034728142523, 49.63487632812993, 31.442046819194672, 28.300467575750044, 0.7604652679254933, 0.965681407720812, 0.28134064208115306, 0.5374947646933218, 0.16684402140878862, 0.34400629720860915, 0.07792794986838296, 0.3612819476233375, 0.23894993287901725, 0.4348267254329497, 0.2687601606932379, 0.23531499889589128, 0.07141638637310074, 1.504691065319123, 0.23994039263456102, 0.9462138265371324, 0.5340834058100178, 1.1878645564279249, 8.849060285475947, 1.3614811628095567, 0.09285042332785745, 0.03262797963895625, 0.3163504312115331, 0.05168432482488213, 0.023956779811170795, 0.16791651385926432, 0.12527082761329028, 0.11246039727402311, 0.26076143667582546, 0.034927695148414185, 0.9217810762986061, 0.104430447512817, 0.39452415740778374, 2.2653281208007567, 5.54982872739915, 19.406006836122085, 39.853755966309585, 29.83508706092835, 12.391008600111931, 11.074174796381305, 6.764329364222865, 8.623949577731471, 7.121457246042068, 8.26249041864949, 12.494698416802192, 15.315418954818481, 19.257639261984057, 23.874823970179406, 20.773894210015577, 18.116204046433975, 22.805560365799938, 20.276633770235126, 16.579031098273493, 38.84647169420796, 60.747194213251916, 44.68698678478118, 51.61129590003721, 50.40674386485931, 16.754921943910663, 15.929778814315798, 35.68525314331055, 55.34317224256454, 42.850811558385054, 53.81533453541418, 54.03055498676916, 39.620833858366936, 36.955116564227694, 47.33006415828582, 62.170504677680235, 62.86078299245527, 53.632465793240456, 64.9947484847038, 62.7059748864943, 57.22714154951034, 57.807122815039854, 66.38875099920458, 57.90127538865613, 37.70248497686079, 31.52428323222745, 26.046636412220618, 25.06615565669152, 17.38820625889686, 41.16379230253158, 55.46513442070254, 83.89246909849106, 43.64104755463139, 41.49840185719152, 70.49683755443942, 47.61618929524576, 1.9684858427893732, 0.15911485308841353, 0.014063349902449597, 0.22704255166313342, 0.03179341111512434, 0.04397053188914734, 0.0055511597630327515, 0.035640011361289414, 0.12338255877576529, 0.02629164918025415, 0.03354756093974556, 0.02052206099183569, 0.055024429870348786, 0.04666308196441782, 0.1983001431630504, 0.19974360602997965, 0.2501091373062903, 0.0812212162981591, 0.16465184549170156, 0.13690121441839204, 0.1976344740438846, 0.2378784976298771, 0.13731140853656879, 0.3232602991404072, 0.2159570142506592, 0.302941563629335, 0.5051977541898528, 0.146715245059421, 0.175831918154032, 0.5248678583771952, 0.49414791647465, 1.150407759893325, 48.00286439157302, 98.03704584798506, 81.06773499519595, 71.76906616457048, 97.36270412322014, 68.99383237285, 38.40831941173923, 86.05041596197313, 32.800608758003484, 64.82473727195494, 33.1876015663147, 64.17517708193871, 43.71252490628151, 63.02427130360758, 150.68103513410017, 85.17848876214798, 72.89637888631513, 77.89302349090576, 89.1725363269929, 69.32517851552656, 13.977897590206517, 37.40279236147481, 92.28501550612911, 71.66719436645508, 69.01995535819762, 60.25792168032739, 71.19337989437965, 71.33337713056996, 73.98174578143706, 64.93627771254509, 59.89542799611246, 1.6104716278852957, 12.559644041522859, 82.5362939219321, 74.85120188805365, 72.9358143960276, 56.15827214333319, 18.337411995856993, 19.373270734663933, 20.297414487408055, 23.55002034095026, 24.57246065139771, 21.117789976058468, 19.443439975861583, 24.426128787379113, 23.518474678839407, 34.302911835332075, 26.374360246043054, 20.68884741875433, 13.888109633999488, 28.77595493870397, 28.49112222271581, 66.53642039145193, 35.92576503753662, 42.18746815958331, 1.231988401662919, 1.7291045717654692, 0.3314156421730596, 0.9453425087755727, 0.40150364740721645, 0.4625741849022527, 0.2863426139998821, 0.5725665763020515, 1.190805230890551, 1.111587449427574, 1.0501295472345045, 1.4163334259102422, 0.15395578717993152, 1.7240627326311606, 0.6230912393619937, 1.1791447598126628, 2.2559281606828017, 5.218127119925715, 10.975634071134753, 0.9983501547286588, 0.14659388141045648, 0.2055380499411014, 0.7325966439900861, 0.19059244062631361, 0.09704047228179633, 0.424495539477756, 0.7918985296160944, 0.8501769217752642, 0.3735161572694779, 0.17781651488715605, 1.491394843305311, 0.23849084702951295, 0.5628739093099872, 3.5223916221049527, 13.288489061017192, 25.43331107785625, 48.09033716878584, 37.60479834771926, 15.69322753337122, 10.841243863105776, 9.216523612699202, 11.206729335169639, 17.0389643023091, 26.01659890144102, 19.836645818525746, 17.71701462807194, 26.365199550505608, 31.805723098016557, 28.537918060056626, 24.141780484107233, 30.278981693329353, 29.538981453064952, 14.477841911777375, 28.718131357623687, 52.1017372992731, 50.00826635668355, 61.99065223816903, 69.04963201092136, 16.889645553404286, 9.77637037154167, 66.93190513118621, 57.329417351753484, 44.705166970529866, 55.002663443165446, 59.464120249594416, 40.74892713177589, 41.124956915455485, 50.646875289178666, 65.30458042698523, 67.06837223422143, 58.02827389009538, 71.59496784210205, 65.955336939904, 69.59564947312879, 65.257206040044, 75.85981584364369, 68.29908647844869, 42.15304543895107, 39.27681061529344, 49.68609463784003, 41.59222495171332, 33.21991405179424, 52.01918709662653, 75.24053635135775, 101.99178341896304, 46.069912525915335, 65.35863068795973, 71.93163271873229, 72.99116688389933, 5.010589611145758, 0.5894901939938145, 0.18083473276947776, 0.5965565277203437, 0.17093977260012783, 0.15656548101575146, 0.10298019710687861, 0.3096979688252172, 0.3111932805228618, 0.05402321807078777, 0.09906116707791245, 0.2624704256173103, 0.22270024273424383, 0.1315023936331272], [0.011943391178764645, 0.021561910435857794, 0.06357502447621477, 0.01703007518494081, 0.04924932584887551, 0.025717927848980315, 0.03208118055256144, 0.040765093609450326, 0.026928777693800872, 0.04234300873753044, 0.045895565286158554, 0.047952139810208357, 0.045716561181771184, 0.129537194246246, 0.06451867625958498, 0.10322677782706677, 0.1017390197563556, 0.10777042998421578, 0.468492581839523, 64.83176223693356, 62.77768365798458, 49.961617608224195, 51.958849276265795, 108.54294961498631, 36.119726242557654, 57.54877590364026, 42.41123545554377, 30.88971434100982, 28.716095647504254, 27.412909730788204, 45.94220799784507, 23.13398434269813, 49.1879379364752, 55.46002357236801, 69.42774065079229, 72.81080845863589, 63.62043234609789, 60.163537686870946, 22.81205777199038, 13.199002146720888, 51.81954629959599, 62.90005768499067, 58.22592996781873, 49.67911674130348, 63.00372200627481, 67.32484817504883, 64.80895365438154, 64.86463169897756, 19.73424057806692, 1.1224024045851924, 60.57004820915961, 65.10311572782456, 63.70172346791914, 58.479758308779815, 23.85359218043666, 18.65689689113248, 22.18045811499319, 15.574782740685249, 18.734673569279334, 15.529750008736888, 21.809309720993046, 19.657858302516324, 17.284349741474276, 24.808085272389075, 25.00281918433405, 23.89319831325162, 12.587125147542647, 15.736217691052346, 25.99841675450725, 22.570906531426218, 45.2167538673647, 31.3097099719509, 15.420585543878618, 2.3487414900333654, 0.7261417710012006, 0.21274591075076213, 0.355766237142586, 1.011687500342246, 0.08937750927983754, 0.5967406952573407, 0.055191781777407856, 0.011166912229401211, 0.14590982618110795, 0.12190325065485894, 0.46085284662342846, 0.024547092691664735, 1.4369441328510162, 0.029887137296158942, 0.4683381385139881, 0.40615812184349187, 1.7079279403532706, 5.252744978474033, 0.9577295376408486, 0.2541032899171114, 0.07556548026660759, 0.1993002096611646, 0.03698580567875216, 0.21934836291738097, 0.07635385368860538, 0.7102649971362084, 0.2243586392292092, 0.5738834508003727, 0.4252334966534569, 0.6531806602593392, 0.8493098941060805, 0.22020060508962602, 1.6235245403743561, 2.800780188652777, 15.103114785686618, 33.78528448843187, 30.933099677485806, 8.378746528779308, 9.69650895364823, 4.6186570678987815, 4.773349954235939, 7.841504879536168, 18.15319003597383, 17.61838859127414, 18.095805760352842, 19.765658763147172, 21.627197996262584, 26.623724929748047, 25.829966645086966, 18.53521712364689, 18.504836405477217, 20.57396315759228, 16.45140011464396, 16.402355778601862, 25.480301072520597, 26.583465722299394, 41.13947360746322, 63.25746013272194, 9.523182357511214, 9.677414855649396, 34.48581195646717, 29.418454862410023, 43.88137117508919, 46.988013867409, 53.49551623867404, 63.0401372909546, 57.70064615434217, 50.73939615680326, 54.418881400938965, 58.07014519168485, 56.698672771453865, 51.61417099737352, 57.32142356134231, 62.31875458071309, 56.636883674129365, 53.86727063886581, 36.00673844737392, 31.576374269300896, 36.88432562735773, 24.20654469920743, 28.905771663112027, 33.61828957834552, 76.84352274863951, 45.51510895452192, 32.81071278356737, 50.75597209315146, 63.65875390268142, 14.929610702299303, 0.8426103632776969, 0.28218732245506783, 0.07293667253707686, 0.0658246263441059, 0.015963138787135962, 0.060926777265605435, 0.06768127107211659, 0.07553600886416051, 0.08154242930393066, 0.11526865343893729, 0.05309947308213, 0.05406309294724657, 0.015557122720976271, 0.14390796182617066, 0.09999318198571283, 0.018670068332745184, 0.05674795533019689, 0.03323371769980558, 0.09641153707859978, 0.029906950245100646, 0.08432150517980899, 0.055269807832495826, 0.03862026958696304, 0.040641791758037386, 0.05923819307598376, 0.024064125966340787, 0.07674076639476322, 0.09973644293964871, 0.03975369284049638, 0.21908701968289193, 0.049961496505045125, 0.10226665515332453, 0.8414070536532711, 72.18967760762861, 73.1481009144937, 52.876393641194994, 62.36857652664185, 92.73912399045884, 32.33933802573912, 53.91620612913563, 23.841927051544193, 35.461372098615094, 30.848625552269723, 28.66112166835416, 39.579084150252804, 34.150912146414484, 52.261609185126524, 63.85480965337446, 73.72724671517649, 77.36037346624559, 67.35668997610769, 67.41847515106201, 29.156252261131044, 15.59599687976222, 52.96492153598417, 70.53538660849296, 61.05529246791717, 54.541502537265906, 63.716275461258434, 65.35635571325979, 67.38877496411725, 74.61964868730115, 19.642539485808342, 2.273504056276814, 70.86499906355336, 70.73289363614975, 68.05146724947038, 75.28960520221342, 41.93605599864837, 21.508658086099935, 23.372888065153553, 15.898391027604381, 19.994183894126646, 15.81874239829279, 18.108149459285123, 16.954194038145005, 15.713318893986365, 25.601372872629476, 31.66295078492934, 24.795778835973433, 19.050255706233365, 19.926232753261445, 24.660890486932573, 29.391241458154497, 57.14867845658333, 35.27374944379253, 35.381567555089156, 5.008376904072301, 3.8661302481928184, 0.1864183799273545, 0.18069816993609553, 0.7457397097060758, 0.14501764018449093, 0.37320175478535317, 0.02720587552645274, 0.191458196589543, 0.2460090347355412, 0.4293105552994436, 0.5455539483697184, 0.022479685684365612, 0.6650330823275351, 0.08503665591800406, 0.15554082309526784, 0.3709485676259764, 1.4547786597282657, 0.4494180344045163, 2.5984707090162464, 0.8751842992440347, 0.1384584873073524, 0.16597167708941046, 0.14749700714263225, 0.10050945629876468, 0.19740002049553781, 0.9636639611374949, 0.6257860915314767, 1.6896534951463824, 0.6717093853700546, 0.5638871678421574, 2.6792749666398574, 0.12515631279036885, 3.6211429296001314, 6.193911817766005, 19.403014067680605, 34.303880660764634, 29.37970380629263, 10.463937347935094, 13.11657844051238, 5.940995427869982, 6.863398138553866, 9.974202955922774, 12.667356248824829, 9.324912428855896, 17.459740484914473, 18.99554256469973, 22.679083539593606, 26.918557728490523, 25.001458121884255, 20.6599062104379, 22.00699913886286, 18.00262201216913, 22.118541540638095, 33.032032520540305, 50.470090143142215, 30.29397495331303, 48.66179512393091, 45.97350851182015, 13.197494975982174, 18.981373002452237, 28.554599900399488, 39.12186914874662, 46.33193862053656, 55.98364430089151, 53.782774940613784, 63.04785651545372, 56.332696022525916, 53.253368716086115, 59.2877547971664, 63.322857810604965, 64.87336289498114, 56.59451423152801, 65.26776113817769, 65.50410747528076, 63.00432605128135, 60.18795051882344, 44.63302673832063, 31.407961422397246, 26.756891358283262, 25.98289005218014, 21.432854360149754, 45.19807554060414, 74.80665945237683, 53.782504297071895, 40.517036607188565, 56.12883083281979, 69.55340554637294, 12.809862821332871, 0.6526347766480138, 0.2965955670562483, 0.22229464514361275, 0.13915398789028968, 0.012167907609123618, 0.028404370288274465, 0.046510205288688024, 0.0210934687375782, 0.027214683622362155, 0.07505540360486315, 0.01567031891505805, 0.05926324032066811, 0.03751182463020086, 0.07273091664237362, 0.18759887545339524, 0.21064312197268012, 0.21632749437084123, 0.12131746152355788, 0.2220460955774592, 0.11812339581909681, 0.14974633321887063, 0.19203809450470632, 0.09943995159119369, 0.2739044104612643, 0.2543058895295666, 0.11076400281801341, 0.19710110830924205, 0.25785934240106617, 0.09160613566036187, 0.39412422886779236, 0.18931082149426784, 0.4024153226806272, 2.938594625842187, 96.90005271665513, 79.81155672381001, 75.2202969212686, 73.00352234994212, 134.13878410093247, 54.14064022802538, 86.95584804781022, 61.78513573062036, 47.74842416086505, 42.331352464614376, 43.526231934947354, 62.461544544466086, 31.847980753068004, 59.444331892075084, 67.04587351891303, 83.29426842351114, 85.34460113894555, 74.69284011471656, 71.74211948148667, 30.064573172600042, 17.793622439907445, 60.91833506861041, 73.85552390929192, 69.31701998556815, 56.45359523834721, 67.24862083312004, 76.37202247496575, 80.21820452905472, 75.99339608223208, 27.37094036994442, 1.3823561394406905, 75.50004036195817, 76.29289257910945, 79.04043443741338, 66.77940337888657, 31.60451335291709, 23.62117801943133, 29.70337583172706, 19.744124950901156, 24.924560054656, 16.74121718252859, 29.26213468274763, 24.5942807966663, 22.787117381249708, 28.43471069489756, 33.604392620825, 30.65491145656955, 17.591055554728356, 18.51020024668786, 36.56080461317493, 29.434891554617113, 69.17705412833922, 41.39389030395016, 53.41012624002273, 5.916205067788401, 4.030026240694908, 0.5333488807082176, 0.6780395392448672, 0.8432881365860663, 0.24452231854440706, 0.982560285877797, 0.18183303726536615, 0.3473739277931952, 0.7431689024932924, 0.37977552462008696, 0.911420380636569, 0.1387888703855776, 2.3002634461848968, 0.1794624088271972, 0.5115739959141901, 0.9545011818408967, 3.4573369064638695, 9.376810289198353, 3.1029269820259464, 0.9819074563922422, 0.17873960487063856, 0.4534545210340331, 0.2129997769671102, 0.7577084545646945, 0.2440449691587879, 0.9070952933642172, 1.0291546727380445, 3.4256017448440677, 2.1985774703564185, 0.5827760155643187, 5.378708954780333, 0.2164454719111804, 5.655309106073072, 14.90065380450218, 27.210146727100497, 40.43012865128056, 40.77701130220967, 20.51100519395644, 14.76966723319023, 8.86252676287005, 11.100867505996458, 12.820022740671712, 25.47291328830104, 22.58490547057121, 26.037654184526016, 23.66875833080661, 28.36307840962564, 35.18146391837828, 36.329616192848455, 27.571493118040024, 25.82463614402279, 31.069745248363866, 20.57444364793839, 24.197762512391616, 39.43567445201259, 37.036682251961004, 58.63158149103965, 68.15611608566778, 11.546827266293189, 11.976506248597177, 41.37238002592518, 34.965439381137976, 52.6201569649481, 55.95332830182968, 56.82875033347838, 67.29895268717121, 61.49618256476618, 56.12151169007825, 62.51038982022194, 66.04273519208355, 70.18876675636538, 62.560298058294485, 66.69734739488172, 69.60317257911929, 67.78043147056334, 67.93573379516602, 48.465123561120805, 44.278793565688595, 52.98722413278396, 37.3015599096975, 40.480789984426195, 54.10038102057673, 97.74075000516831, 56.6799512986214, 49.95352968092888, 66.08619505359282, 81.59291682704803, 30.904070215840495, 1.3932504000202304, 0.4221662644657397, 0.4952401739935722, 0.2679084854260568, 0.16967281639095277, 0.17212596782032522, 0.16660285693022514, 0.1878044015217212, 0.194167343959693, 0.38208423783221557, 0.2340396463630661, 0.1283315480536511, 0.22759001341558274, 0.26078304035529015], [0.062115278410454916, 0.12739659136822148, 0.07297771186718056, 0.16115322919382205, 0.07951588925695227, 0.09093168717358383, 0.07211187163427954, 0.07669359070038603, 0.07971608335332525, 0.028394294316850366, 0.0405052021115778, 0.01311993369111611, 0.07010922586965947, 0.21955246406216777, 0.1580708437869626, 0.13319402302224792, 0.07950711755021926, 0.06122774639797788, 0.4115245371095596, 18.5487041934844, 84.42322069598784, 58.4156903143852, 50.22965669631959, 75.74725166443856, 86.8532153098814, 31.01233155496659, 52.09103315107284, 29.267504407513528, 40.321428006695164, 20.975484425021758, 44.36928264556393, 22.054928541183475, 34.287241966493674, 50.75756065307125, 51.55494713014173, 70.95227179988738, 65.85763854365196, 69.0187551129249, 60.148581689403905, 19.583133228363533, 48.461554204264, 62.345434542625185, 64.43187659786594, 52.83489888714206, 48.2615956952495, 59.57138530669674, 61.002524821989006, 54.284065615746286, 4.171847133867202, 26.64041461483125, 72.62815152445148, 49.999252750027566, 60.561332702636726, 32.43696385814298, 22.470266357544933, 20.509036164129935, 15.774170544839675, 21.142108671126827, 12.986482247229546, 19.178962399882657, 22.8702441723116, 19.431872906223422, 21.63265989672753, 28.960237695324807, 30.859684674970566, 28.8899350935413, 16.503758853481663, 17.962833489141158, 24.624922352452433, 21.483558839367284, 45.05627009176439, 39.945162880805235, 13.18100925414793, 4.218079130495749, 1.06532983481884, 0.39977976571648355, 0.7698942168105034, 0.3349299632733868, 0.2165557119634844, 0.30032905058995374, 0.10652098654498977, 0.10788086155850081, 0.03351594066067088, 0.054352080464483275, 0.07889265374791238, 0.06350839780944009, 0.6362780640202185, 0.14025237411260605, 0.7655909477222351, 0.32079907314431283, 0.5906109499835199, 5.494778752326966, 2.8492874051294024, 1.1369559913873672, 0.09883495663563091, 0.6395029877462696, 0.5675114991684114, 0.08448683461474796, 0.4779389668856898, 1.7207169508741749, 4.410255657088372, 1.099431533967295, 0.6474264819295176, 0.16841704506547223, 0.5254977052250217, 0.1378184055248576, 2.5455618577618755, 9.09065475386958, 17.30651309413295, 33.138697455006266, 39.46714755027525, 13.115404671238316, 13.493293658379587, 12.549141895386482, 12.887916026576875, 12.316432576025687, 11.808377773531022, 14.754704371575388, 19.0977006958377, 24.071817167343635, 22.89990709673974, 23.851780045417048, 28.248890369169175, 27.476240319590417, 22.306625073955907, 23.730086549635857, 19.718484417084728, 16.36806445737039, 6.550873489149156, 16.990248464768936, 16.5151592223875, 46.2589511563701, 59.6392580001585, 5.380184256261395, 13.39146794811372, 40.90291546237084, 58.48246082182854, 48.18465448194935, 47.20156338907058, 48.98344908991168, 57.70105408084009, 59.40309993682369, 56.48695107429259, 57.99781668570734, 60.314968632113555, 54.080290640554125, 57.91252474631033, 57.848535199319166, 56.88496966515818, 51.94211252274052, 43.56234519712387, 35.12022003050774, 37.42400453936669, 18.453400404222553, 33.06059914250528, 49.10632125792965, 62.21968335490074, 30.052007859753026, 39.930920754709554, 63.235267362286976, 35.36378745109805, 0.19530227257599755, 0.06552689393321354, 0.025792958500284343, 0.013718405408003639, 0.05085974225714322, 0.03404124715035001, 0.04725433713305862, 0.09090976173719091, 0.039526907832271634, 0.05498280448298301, 0.057195082547203194, 0.031151149812484943, 0.0580943318744821, 0.03137966809463838, 0.11101058353820156, 0.050839142152859326, 0.03355023841704092, 0.07304443046450615, 0.27987649484026816, 0.07105403444579533, 0.10162113414656732, 0.04428044509803576, 0.2593622536909196, 0.09538142461209528, 0.10001018913763185, 0.1083397099207486, 0.022304806963450486, 0.08688060656910943, 0.12702908366918564, 0.10389259250293817, 0.14647745136772433, 0.10344496732878108, 0.1339740384249918, 0.546520138459821, 22.442699939973895, 97.08404325669812, 66.20620389138499, 54.76304584933866, 90.84774924862771, 74.6963624031313, 40.000931139915224, 47.30098762819844, 22.89996789347741, 44.08686414841683, 22.731262829995927, 41.03415012359619, 32.93723667821577, 38.87701519073979, 59.44459469087663, 57.50253115930865, 75.50165637846916, 71.95232714376142, 68.51054929917859, 64.8251961892651, 18.78103990708628, 54.31486406633931, 66.78113706650274, 69.96538777505198, 54.702778631641024, 52.3326668431682, 60.147581485009965, 72.79719783413795, 58.051847334830995, 8.171247263108532, 35.94987976935602, 80.42343078121063, 53.058219032902876, 77.3760158784928, 52.20041628806822, 28.29460167115735, 19.772093411414854, 16.780080026195897, 19.460914134979248, 16.734829602702973, 16.990407320760912, 19.812601689369448, 21.420863674532985, 19.17235908969756, 35.128484464460804, 32.09979495694561, 29.916099694467363, 22.78620150781447, 18.854539240560225, 26.353528538057883, 29.414524647497363, 58.83968676290205, 41.84149549853417, 38.75731622019122, 11.244657674143392, 7.115979656096428, 0.2784657592494642, 0.9694246971799482, 0.2669960134212048, 0.3094477032221133, 0.600867335113787, 0.043219470779501626, 0.014851400609909287, 0.037778568784556085, 0.15160849377993615, 0.2689260034070861, 0.11174349985536068, 1.369861061534574, 0.10790997289962347, 1.2042136081764776, 0.5560763192272956, 0.13725885490496315, 4.215142255829227, 1.2414443781298976, 0.8318433958676554, 0.08340082837328797, 0.3081440360796067, 0.2503633865666005, 0.04681488611705361, 1.0325824565464452, 2.2325824585653122, 7.443055318247888, 0.16331925086917418, 1.0093275818132585, 0.5870696013012241, 0.23917917702947897, 0.12777065677988914, 5.10865229752756, 8.460290643476672, 22.89946779128044, 37.050285031718595, 38.7085807708002, 17.56332439761008, 17.724949582930535, 15.916127985523595, 17.58820595279817, 14.318020036143643, 14.150301448760496, 9.741488733599263, 12.615172055459793, 22.03663068432962, 21.304039801320723, 24.401223697969993, 24.62968214865654, 25.350119567686512, 22.182030985432288, 22.840696957803544, 18.076843061754783, 18.886386925174346, 16.775059392375333, 37.19283180852091, 22.821524412401264, 46.20666596197313, 38.527912478293146, 10.817611582817571, 18.02312424105983, 20.729392959225564, 67.09966490345617, 50.43213336698471, 57.479702964905776, 49.7156536194586, 61.98103850887668, 60.342048675783225, 61.04195248696112, 58.68234088343959, 66.59003134696715, 63.791796776556204, 62.9323858599509, 64.71604054973972, 62.618827666005785, 54.9607882192058, 51.9390687634868, 26.227975430027133, 43.464737015385786, 16.27780875852031, 36.942961139063684, 52.875075724817094, 64.66093124881868, 38.9592045353305, 41.16748325286373, 73.41163712163126, 31.499356569782382, 0.22025879712835436, 0.04806959258031942, 0.12767501070254272, 0.11338842852461724, 0.07333397339548796, 0.08810968739130805, 0.06900731564289139, 0.0296552884467547, 0.03676031918955907, 0.03876885617031686, 0.043929879433445396, 0.0748626022569595, 0.052940724342460596, 0.060015841267041625, 0.17500501817032216, 0.1717085265103848, 0.24292298742840368, 0.1494482637292916, 0.4178067951673462, 0.19588013269728233, 0.2434989016863608, 0.17464739300550955, 0.32434287330796646, 0.12948326165637664, 0.22439531951902375, 0.21786717788106014, 0.24065421804064707, 0.33055875750799335, 0.32894945192721586, 0.40882300465337695, 0.348334479476175, 0.37468171408099515, 0.2445194074102948, 0.6823474048606811, 37.38210578118601, 108.27123134366929, 78.4198840971916, 69.05625297177222, 101.72297554631388, 104.74889586048742, 51.274423137787856, 75.55387097020304, 42.77925575933149, 52.11915654520835, 34.74899515028923, 65.67530716619184, 34.33090971362206, 44.0570580574774, 64.20767391881635, 67.1844587018413, 84.80551842720278, 78.1450749981788, 80.12219275197675, 69.14460828227382, 21.9902604241525, 58.41299564607682, 75.42557024186658, 79.36148828075778, 63.28614050342191, 54.52813902208882, 71.08974302968672, 75.79041342581473, 66.81859570164835, 7.709552424569284, 35.31835855976228, 93.03878522688343, 64.4042395776318, 75.50077776755057, 37.40837389423002, 28.942975344196444, 23.81784958224143, 22.887420231296172, 26.062212144174886, 20.02698079232247, 23.64016229106534, 28.503971907400317, 23.018729417554795, 24.95851209086757, 39.109843161798295, 38.59325916536393, 33.3511330235389, 23.19290618742666, 21.918808567908503, 36.55817662515948, 30.77312973237807, 69.29126570301672, 46.9225848105646, 52.43560160360029, 11.785198526997721, 6.816267428859589, 0.3388368278261154, 1.1297868793049166, 0.27262562585453837, 0.36176513459893966, 0.5491931111581865, 0.19915949463123278, 0.18581205197880346, 0.11348718491893624, 0.21459080369001438, 0.3819546770424612, 0.06273793169267236, 1.7200707403882858, 0.3688549719029858, 2.017925235052263, 0.9022990313749161, 0.8435147147505515, 9.163766753289009, 5.151235509303309, 4.676209515140903, 0.22554425222258415, 0.8641488946253254, 1.0259699533062598, 0.23306794043990875, 0.8740454022922824, 5.446321300921902, 10.999046698693308, 2.6417030730555138, 2.8265231943899587, 0.46078334712693775, 0.5595378721913984, 0.27724017178820026, 11.222215833202487, 14.687788736435676, 31.742406237509947, 41.99974352313627, 52.26357821495303, 19.743026687252907, 20.52033651259638, 18.599804832089333, 22.649387275019002, 17.360018145653513, 17.642167960443807, 21.55939002190867, 27.03375577926636, 35.67521187566942, 27.462468877915416, 32.55406818082256, 31.769515698955907, 35.45815183270362, 31.148247564992598, 31.49278267737358, 24.51996364901143, 18.43882095429205, 11.117516006192854, 23.85103283389922, 27.106896215869536, 60.608028519538145, 64.41076640159854, 6.5099857218803905, 14.363415587332941, 44.48531027763121, 67.20083067494055, 50.73830181552518, 53.78102164114676, 53.15234807229812, 61.89174967427408, 63.91003662540067, 64.04968084827547, 58.008238423255186, 69.28948494695848, 66.588548691042, 63.48972328247563, 68.68786396518831, 63.81519763700424, 58.664905948023645, 54.80055547529652, 48.19557828287925, 56.19984926715974, 26.777234731181977, 51.912800650442804, 62.075889264383626, 78.04667057529574, 43.61801147460938, 57.26807932699881, 76.6621680413523, 57.46038921417729, 0.43006263913646825, 0.2671284547015544, 0.403337539323876, 0.35998456240181004, 0.2233911621113939, 0.3079357520947534, 0.17650976807119387, 0.1210283016365382, 0.2100582904512844, 0.12461927749456898, 0.19332170546535524, 0.10459927796956994, 0.15307120077552336, 0.21619322980123185, 0.32969841012550943], [0.07550700477534726, 0.09154798192602974, 0.09305447850736881, 0.0384887169686056, 0.10793614246311689, 0.026267220551568656, 0.12473553899795779, 0.022048673126846555, 0.03930032583734682, 0.06483936832556803, 0.029031780976501685, 0.10016350631391811, 0.027352259607024254, 0.06762066585642677, 0.12158157033545357, 0.08843747343146995, 0.09334202960974748, 0.06280094242444442, 0.11015389039511643, 0.6223291350949196, 55.99552123777328, 66.64790984122985, 52.23614908033802, 39.82382828189481, 89.72953642568281, 50.883868817360174, 36.51641122756466, 36.01715234018142, 41.303220795046904, 26.66755153286842, 32.294501412299375, 34.46099119801676, 59.23598735563217, 54.84193648061445, 57.02659468497, 61.48556078633955, 71.8965196609497, 66.16972584878245, 71.82639552700904, 29.721204965345322, 57.38014536519205, 59.99585243963427, 40.98783477660149, 52.77027391618299, 46.13720863096176, 45.49676795159617, 76.52764643392256, 22.12499580075664, 7.945938965966625, 60.32311147259128, 42.17841532922561, 52.73392531179613, 30.322115998114313, 16.764431730393444, 25.849201948412006, 22.264359574164114, 24.858158250008863, 18.244083119976906, 15.829200417764726, 23.00428136702507, 19.652539568562663, 18.549370996413693, 25.055445624936013, 30.88026535126471, 36.414284475388065, 32.60480207781638, 17.849973170988022, 29.28696916949365, 23.085215553160637, 28.811734799415838, 53.29454575815509, 36.62140130996704, 30.888296404192527, 5.566299250048976, 4.536157856064459, 0.8616382712798735, 0.17082291354815807, 0.5455711700262562, 0.26467510408932166, 0.6600170450345163, 0.9703898453904737, 0.17299719365133395, 0.06308436431291123, 0.07494162422634902, 0.1951167567242538, 0.02517090468186765, 0.5623537049658838, 0.11707730275849182, 0.5108493993118887, 0.5240464895482987, 0.18875234339746738, 0.9372383404162623, 0.9902567728873223, 0.3409693714591765, 0.12250715776556924, 0.4517326311719033, 0.4545907826433259, 0.07388241574048035, 1.418888114633099, 1.232270444593122, 2.6064446424284293, 0.5422028346407799, 0.7660151152841507, 0.16819756087516585, 0.15760783556728594, 0.3815868322647387, 1.3271199743593893, 8.858593606179761, 19.51037130048198, 29.395242275730258, 45.537509610576016, 15.760717795741176, 9.858226314667734, 7.706626826717009, 10.633661247068837, 13.090035761556319, 12.80239070615461, 14.752817711522503, 20.591609900997533, 22.170860075181533, 29.373190710621497, 29.857956440218036, 30.53839352823073, 30.07229828065442, 29.569526910781864, 21.869245498411118, 25.091272554089947, 21.77687171966799, 18.964655860777825, 6.660600814127154, 18.3335857237539, 14.50784706300305, 66.05432971831291, 39.381027990771884, 3.9345569764414146, 4.232561501764482, 37.61581628553329, 66.28953072332567, 53.932064271742306, 60.737478502335094, 54.051233722317605, 59.47871931137578, 56.84711487062516, 61.94396426600795, 60.51102046043643, 61.42406978914815, 55.90833087121287, 67.01979760200747, 51.77950674487699, 56.12129988208894, 36.929840810837284, 40.56244980904364, 17.795393390040246, 25.7304149289285, 31.42624947332567, 53.91063244112077, 48.31094303438741, 30.60670552715179, 44.79358503895421, 48.76883660593341, 5.930565845581794, 0.5727805906245785, 0.19970091961083875, 0.1449324665290694, 0.08976516509128195, 0.04544863342157295, 0.05848322874836384, 0.030871274911107558, 0.04633105945803466, 0.028851553046655272, 0.07135764275106692, 0.06759877872443007, 0.05492104247452752, 0.019384165700044365, 0.06873756076299375, 0.06270356498838914, 0.010257428925063823, 0.08948773401038301, 0.02188677768102817, 0.0730929774562678, 0.082203793008962, 0.04959098957178574, 0.13271625994914962, 0.056879642013941085, 0.10483475807573527, 0.13023330769952268, 0.020105123384705475, 0.02948630094197729, 0.022500207264637275, 0.07513716050814237, 0.03550183208238694, 0.0312187934609791, 0.13633789464591012, 0.09348737181074197, 0.10657429094276122, 0.9238593809066281, 61.828685806643584, 84.42176157428374, 53.106232766182195, 56.21411492747646, 94.61914739301129, 52.366595345158736, 41.87864034406601, 27.02057661548738, 36.36681202919253, 29.678282468549668, 29.93801397662009, 41.7409102378353, 62.3849484997411, 57.444464391277684, 68.35311320520216, 65.65327913530412, 74.77144441296979, 70.57319041221373, 70.36202569161692, 31.25538710624941, 59.5677649590277, 66.96497071173884, 47.47088509221231, 59.78694700425672, 53.41594703735844, 49.37574886506604, 85.96292357290946, 26.1375294962237, 15.630053839375897, 63.81950439945344, 48.61914719304731, 67.25989372499528, 60.683012470122314, 23.311642216097926, 24.920773006254628, 19.892818081763483, 22.72343574031707, 22.578176644540605, 15.10532602187126, 21.4891815570093, 22.047501533262192, 19.733006992647727, 22.34192640550675, 39.54399854906144, 36.775891703944055, 36.774660079709946, 23.658389545256092, 27.042767424737256, 23.113784136310702, 38.52401364234186, 61.675882031840665, 46.29721779977122, 45.32477594191029, 12.337223099124047, 7.181499417751067, 1.3914201240385733, 0.25170278404989554, 0.367506810373837, 0.24845630260965518, 0.9560252065139433, 0.8115032098947034, 0.22176555417958768, 0.11298635493843787, 0.02562221282372071, 0.29187520905848474, 0.14357002512101205, 1.7235897193031928, 0.05164997727279702, 0.9124639762505409, 0.9428500263921676, 0.07227726235625244, 2.1954373678853436, 4.52962318735738, 0.5076959975544484, 0.13493757785087632, 0.1964284677899653, 0.24555491313578623, 0.27411146870543884, 1.9354638986049162, 1.6177213937044146, 1.520531679834089, 0.7924764050591377, 1.6304709353754598, 0.3912220733059991, 0.16224753982838125, 2.115452395331475, 2.0094917714595795, 10.423236873842056, 28.156534241091823, 30.260834847727132, 48.451540393214074, 17.77275739177581, 14.288871922800618, 13.298008653425402, 16.2576703294631, 16.251176845642828, 13.879949142855983, 14.385156304605546, 14.740169048309328, 16.10574124320861, 25.793949480979677, 27.482351372318885, 31.402948633317028, 26.44502958943767, 30.039585713417303, 21.299311384077996, 22.59656079353825, 18.07657437939798, 20.50069916632868, 12.585483635625533, 38.38664831653718, 22.982002304446315, 56.66388527039559, 24.13332581520081, 12.402171665622342, 5.383124563001818, 26.322849719755112, 73.44314944359564, 56.41804679747551, 66.52932874618038, 57.8434439628355, 60.87587148912492, 55.2427674108936, 66.22990285196613, 62.62741373431299, 64.49020224232828, 57.247855586390344, 68.79889842002623, 58.78052957596318, 63.44724793587962, 41.61992865224039, 39.15421301318754, 21.985871291929676, 21.194156562128377, 34.23166198115195, 62.79496169859364, 52.276263160090295, 39.092910289764404, 52.32770504490022, 49.73239821772422, 4.335762493072018, 0.38519342099466636, 0.13908386020170105, 0.11078158453587564, 0.07789379000783929, 0.04614815596611269, 0.03936357405637542, 0.012318858531333748, 0.0028200393153970404, 0.05931891959100481, 0.12011359265494732, 0.08358612205953368, 0.054653202814440575, 0.04017380779729255, 0.076060664179104, 0.04829758800746453, 0.11896223145266695, 0.2807546767496294, 0.11545740218172151, 0.23271459004571363, 0.1457848772406578, 0.12685014085183222, 0.2594072996608673, 0.16272084426976022, 0.21285993527741204, 0.31571522174823674, 0.10368250821146274, 0.2569795057417885, 0.1326866736335139, 0.2652243584875138, 0.2322688034825748, 0.1600143475638282, 0.19350686891665383, 0.2497488614772597, 0.3848612452706983, 2.6076250307021605, 87.98392480419528, 89.6932545015889, 77.40016983401391, 62.227233917482444, 111.11588324269941, 71.30995273590088, 55.69260443410566, 52.995429731184444, 53.108088047273704, 38.18632110472649, 51.46765478195683, 48.86351869952295, 74.65887238902431, 65.56968558219172, 72.44868739958733, 71.68056180400234, 83.18630126214798, 72.46892682967648, 82.86773420149281, 31.870148028096846, 65.58932881201467, 70.00821221259334, 52.13487348248882, 62.130355296596406, 58.83938474039878, 55.06432310227425, 94.27752464048325, 30.06626371414431, 12.436060943911153, 76.15939863266485, 59.44961924706737, 69.33918137704173, 41.25361065710745, 19.733483560623664, 32.12304480614201, 30.022089981263687, 32.30208531502755, 26.707510678998887, 21.537773839889034, 30.637711863363947, 25.720658033124863, 26.75349066334386, 28.849544486691876, 42.05969695122012, 45.26505001129643, 38.319701302436094, 23.575343162782733, 36.766831028846006, 31.312455631071526, 40.525540305722146, 74.05958129513648, 53.28222951581402, 56.94794331827472, 10.598914930897376, 6.46850714760442, 2.4762800528157145, 0.2269328172288595, 0.478219845362248, 0.21025883694810255, 3.9443790816491653, 1.6555239716845176, 0.5327728438761927, 0.33035136218513217, 0.1821948759137623, 0.6379893818689931, 0.18779232797603454, 3.1438681915883095, 0.4642895783387846, 1.0823122267761538, 1.6231493411525604, 0.24910222198213303, 3.0513191319281057, 6.132279124952132, 0.7781444321716986, 0.32806085122208445, 1.8229883404508715, 0.5970099291974499, 0.3630162174663236, 4.735053893058531, 3.006284929090931, 6.446421261756651, 1.8250669514940632, 0.6059775705779753, 0.9118695533083332, 0.1794918878905235, 1.2698351063074604, 7.483061532820425, 15.480680177288672, 35.62964177900745, 35.65064214891003, 54.5921834822624, 22.402219118610507, 14.87367182008682, 12.605818183191362, 16.842504547488307, 18.407283136921546, 16.627923442471413, 21.54107843675921, 30.800007773983864, 32.7636266908338, 35.9331077144992, 32.80486060727027, 39.9562043528403, 34.401288801623934, 38.34700099883541, 28.61769122462119, 31.332226337925082, 24.26471737123305, 21.68457050477305, 8.336372183215234, 23.450076387774562, 25.219573282426406, 74.55773015176096, 41.07963392811437, 4.934087703304907, 7.175663421230932, 39.48523752150997, 71.15574083020611, 55.221719972548954, 63.66790086992326, 59.250966887320246, 59.7835776882787, 61.033939084699085, 70.74804967449558, 64.04233424894272, 66.14190055478004, 62.98215289269725, 73.85006397001206, 62.27757753864412, 65.01565864009243, 47.370331210474816, 56.53565906709241, 28.879393723703203, 36.685167281858384, 48.621014241249334, 73.78650588373985, 59.84219751050396, 48.03936204602642, 63.559655220277854, 68.63012667625182, 12.735479973977613, 1.404715733182046, 0.40058605793503027, 0.29969209444619, 0.21592267818989294, 0.1582789898759896, 0.28309173521495634, 0.23451615305196857, 0.18741682231906923, 0.14901190004762144, 0.2257540683832861, 0.2602488319239309, 0.1299941350495623, 0.10853260319920317, 0.2850480786254329, 0.1762768926639711], [0.026867159326831182, 0.012267923260468149, 0.0047133990465813595, 0.07105180512993567, 0.022083451603389075, 0.16538321431125366, 0.03111551714790685, 0.1270783661053546, 0.11860248422430408, 0.045372986069489876, 0.042777499334225734, 0.018368250757996595, 0.057632219977676875, 0.21847676936416857, 0.15942415342696253, 0.2065238825255825, 0.1614736224855146, 0.18193075944098736, 0.3113553847276396, 0.9132637720434897, 8.344674860277484, 65.36699710353729, 58.387394335962114, 44.584667836466146, 72.57007691168016, 96.42588523126419, 49.682446833579775, 33.571715354919434, 43.93289542967274, 30.193391653799242, 29.38373992519994, 37.55115209087249, 61.99333906173707, 74.53907535922143, 59.421797875435125, 67.24512207892634, 69.29095191340294, 70.54719294271162, 70.52925202154344, 62.90882810469597, 64.43427316604122, 62.43244448015767, 65.01615678110431, 60.6843460759809, 62.27598897872433, 61.98265452538768, 40.0221590072878, 5.578175696634478, 39.79119416206114, 46.7103845842423, 36.49985098069714, 31.983375087861095, 10.306005074131875, 29.725268540843842, 25.588605557718587, 21.905368566513065, 19.31709062668585, 19.176860009470296, 25.874195291150002, 20.739965708025043, 21.674615529275712, 30.91924978840736, 30.48305476865461, 37.19618151264806, 41.219109489071755, 32.14800676991863, 26.231599700066354, 29.19357361332063, 24.256872630888417, 27.619850058709424, 46.8959205381332, 39.47538060526694, 32.23984906750341, 10.61350908971602, 2.5592646579588614, 0.07520357267029824, 0.1672116057166169, 1.0022774278636903, 0.6764537985286405, 0.4838589572858426, 0.5751178942380414, 0.9161814638683874, 0.18927083170462042, 0.24908230369610174, 0.14160839570385797, 0.45991463406432065, 1.8218192289913855, 2.4033107296113045, 1.0540335312966378, 0.6463777382046946, 0.08344261846955746, 1.2668722459385473, 2.8299616421422655, 0.4300344471008547, 0.11936612066722686, 0.09338567363879374, 0.7560986893311624, 0.3307521793871157, 2.6491891616775147, 1.3852005932600269, 0.35398146678363124, 0.3606122642034485, 0.3222225564381769, 1.35178457344732, 2.233479210445958, 2.50832851375303, 1.0264809033082378, 10.092091752636819, 23.148218624053463, 35.70837159310618, 37.15540062996649, 33.29075597947644, 15.815664318300064, 8.578283383000283, 11.29820881351348, 17.98599704619377, 18.538123599944576, 18.966152244998565, 19.80826354795887, 24.693946261559766, 26.647849467492875, 27.565382065311557, 31.752376902487974, 27.859393127502937, 29.306530029542987, 21.69270746169552, 20.475582268930253, 17.116389928325532, 20.889002046277447, 21.24338426897603, 7.697970155746707, 16.986643806580577, 27.21159996524934, 76.67384101498511, 19.79674158557769, 3.8418380291231222, 3.2561766812878274, 35.6269431883289, 40.88392334599649, 45.54736260444888, 55.833668554982836, 64.3219207948254, 61.70116955234159, 50.61928925975677, 57.10386537736463, 60.0095768128672, 60.9077956599574, 61.74039325406475, 50.14105035412697, 61.205523167887044, 33.32121710623465, 31.528878288884318, 21.001140648318877, 32.41145864609749, 41.06556830867645, 53.647461014409224, 37.824043150871034, 25.820380372385827, 47.41495993829543, 12.073385850075754, 0.37418017163872724, 0.1660073921084404, 0.18865442203898586, 0.06642778268865039, 0.22614601428710648, 0.015411629217616735, 0.04283165792003275, 0.05736547582332165, 0.03879866848189024, 0.14003604620454774, 0.0534570790947445, 0.07776684923878602, 0.03383974304362651, 0.04784689848161033, 0.031335880424106316, 0.0737280413628586, 0.01656280560118537, 0.03408188811473308, 0.019548518372879877, 0.09894380240791267, 0.10695548097212469, 0.12068766064100689, 0.0315941880351954, 0.22931305240959893, 0.1373063829997855, 0.12763857556086394, 0.06590387047899347, 0.035288813674161514, 0.01834174028537687, 0.23408055545822268, 0.11227301982862335, 0.1023215223704615, 0.1039133228421692, 0.1746094103662237, 0.2136066411772082, 0.6894095097818683, 13.036230648717574, 80.72629267169584, 69.4675527080413, 54.93588901335194, 89.85469141314107, 95.3702969704905, 53.99028793458016, 35.23298425059165, 32.90124697069968, 35.60837468793316, 27.368469276735862, 43.053676543697236, 66.22382317819904, 72.68761465626379, 66.34722094382009, 74.18923916355257, 77.52423440256428, 71.30184911912488, 71.59612886367306, 59.71914099108789, 68.39628281131868, 63.453735536144634, 66.55673826894453, 69.4346518670359, 66.89734904996811, 70.02984016172348, 40.27066076955488, 13.805241719368967, 43.62379304824337, 50.31878079137495, 51.725962469654704, 63.72279444048482, 19.153190466665453, 28.228648977894938, 21.872134324043028, 19.38840323878873, 23.306925565965717, 17.585399496939875, 19.40681092200741, 23.036340859628496, 22.41840870149674, 21.768489614609752, 34.801605901410504, 43.12347119854343, 43.52571025971444, 40.34626837699644, 25.37679364604335, 25.474541071922552, 25.747575298432384, 31.930221088470955, 59.477648504318736, 49.34428753391389, 46.301355900303015, 16.112562244938267, 2.1107786461230247, 0.13501961054580827, 0.19077354381161352, 0.6756660149943444, 0.7010323506209158, 1.2634966786830657, 0.47453894610366515, 0.6339634366093144, 0.19672825331649474, 0.41875070742061066, 0.21746626874852568, 1.047752468336013, 4.242171798982929, 2.820605318392477, 1.447113245244949, 1.8294728763641852, 0.40330116546923117, 1.7707602655695331, 4.60599075401983, 0.7675413462904193, 0.14976982147462908, 0.5790857393895427, 0.08020486277077468, 0.9161596456843039, 3.5087635920893763, 2.7879282976350477, 0.30006646629302736, 0.9276643251219104, 2.9564227788679065, 1.2760315931612447, 0.9110565808030867, 2.8891678587082894, 7.962190326183074, 13.913418727536357, 31.790114025915827, 36.48316129561394, 43.938751528340006, 25.072052940245598, 15.478178685711278, 10.73593116575672, 15.00451816666511, 22.39353891341917, 21.90430952656654, 22.15451163630332, 18.40009735476586, 15.74126382027903, 19.053472049774665, 24.076698557023082, 26.984969339063092, 23.455128400556504, 27.362095425205847, 19.150566401020175, 18.754387401765396, 12.80544231014867, 18.93534791085028, 15.908232254366721, 9.410785859630955, 32.88346098315331, 33.81832261239329, 58.842812891929384, 18.080618343045636, 13.780502350099626, 5.08589078341761, 29.402373144703528, 38.28230542521323, 41.22457727309197, 54.886208272749386, 66.12450092069565, 63.76432841823947, 52.57199810397241, 60.01617816186721, 63.035595186295055, 63.71497715673139, 67.34249884082426, 52.52079940611317, 64.72252815000473, 40.47413764461395, 36.15581204814296, 19.506015508405625, 26.035877350837957, 49.89351741729244, 54.51186510824389, 42.83061919673797, 30.437127736306962, 54.86425476689493, 9.168159807882002, 0.23425614281046778, 0.14846639948025828, 0.3072071105482117, 0.04369279437307869, 0.059297312081100485, 0.06057418146801572, 0.02997977264796294, 0.11962117431985757, 0.0617253473178754, 0.09880975234292208, 0.12408054148357724, 0.0220313212353616, 0.1224068002474885, 0.015548933241065713, 0.0667024175486257, 0.030763155007134044, 0.1409848614205276, 0.09187247378811722, 0.11911253790341078, 0.2625209567767959, 0.13850169466628184, 0.2637047158373941, 0.0797832616034054, 0.2899202139627549, 0.31400506835310693, 0.1851127975650372, 0.16436257069149326, 0.18241448267813654, 0.12937156603701655, 0.5033845160036318, 0.3184893486961242, 0.1858230989666716, 0.22804387454544345, 0.48492789508834966, 0.8757282829573079, 1.5160582166525627, 26.99568525437386, 102.686293971154, 81.43110336795931, 68.60582367066415, 97.01901820398147, 123.67517917386948, 73.69572654847177, 52.77701254813902, 59.1155235229, 43.89764116656396, 45.48587552962765, 56.21000820590604, 72.927287163273, 87.12931094631072, 71.27371788024902, 81.64744561718356, 80.01560626491424, 75.41911402056294, 80.66424862031015, 66.93221107605966, 72.5323280211418, 66.60104536241101, 72.72306503788118, 69.68301634634696, 74.53920087506695, 73.16296669744676, 56.5620840749433, 9.783203140381845, 51.39568713403518, 66.22208164584252, 53.39671565640358, 43.84757603368452, 13.18716541413338, 37.88332585365542, 29.573996451593217, 28.466272046489102, 27.149681429709158, 23.20065482970207, 36.69633426973897, 25.093539684049546, 30.745516246364964, 39.49069353841966, 41.27515623646398, 50.87062689565843, 45.34974182805708, 41.584890119491085, 30.435723527785274, 36.55368943368235, 31.280605985272317, 41.29649393020138, 70.16910783706173, 58.055557897014005, 59.272881169472974, 21.381124181132165, 3.800214572298912, 0.31848502796023126, 0.19804670595593993, 0.7584766262481291, 0.678249508623154, 2.123310128527303, 0.850109015741656, 2.974270053448216, 0.3576482087373734, 0.25999642127463896, 0.32060660121421664, 2.9573479679323014, 6.0981873543031755, 4.129347272457616, 1.5507085573288704, 3.7026463497069577, 0.777100591409591, 1.2290096066651808, 6.719276530127372, 0.8104123006905279, 0.16635511941727132, 0.5334673485448284, 0.9082775202489669, 0.553930537594903, 3.8952746843138053, 10.932133024738683, 1.0621894871996296, 0.5476798117160797, 3.502755991874203, 5.28466179486244, 6.232542751296875, 11.027515261403977, 14.542500222882918, 19.64654814812445, 33.52290145812496, 43.65021021135392, 48.214601778214984, 37.41049981886341, 23.167036194955152, 11.669409178918409, 18.838773273652603, 24.76276424623305, 25.23711019946683, 23.726876089649817, 28.370662312353815, 30.52307471152275, 40.16858108582036, 32.59614736803117, 37.55144234626524, 30.892742410782848, 35.06559318111789, 29.615069550852624, 25.989069746386622, 20.796287021329327, 23.991345820888398, 25.206494139086818, 7.207368919926306, 19.527296327775527, 42.14340033069734, 80.47671225763138, 21.89300721691501, 5.309043738149828, 4.947609584177695, 40.09290679808586, 45.088135427044286, 45.8459294995954, 59.93676977772867, 68.97989226925758, 65.00751972198486, 56.57375704857611, 66.03911092204433, 66.49620825244536, 66.78283937515752, 73.52738626541631, 56.17995500564576, 69.896895347103, 43.67656461654171, 43.26290361342892, 27.54422087823191, 47.76466277337844, 66.69872022444203, 69.90086478571739, 54.77233009953653, 41.558771056513635, 72.20083282839867, 29.102386351554628, 0.5184189915176362, 0.33726040273904806, 0.4812373431219209, 0.19509366683421597, 0.4142833116554445, 0.27758889501133277, 0.07749913215276695, 0.18536496306619338, 0.2791763824080267, 0.36375950661397755, 0.38353772112919443, 0.2918154235568739, 0.2800366991469937, 0.1798645437004105, 0.21642872522915566, 0.27439780172801786], [0.06482924830408827, 0.08080904567313772, 0.07873088662182132, 0.18365621927284426, 0.0658434184808885, 0.03315303715005998, 0.1862689774603613, 0.048297637803179604, 0.0510556960568553, 0.07083600582254511, 0.07395076610508465, 0.03703254087257289, 0.040983558902817394, 0.14358793625668173, 0.022193216681179982, 0.11029754720267751, 0.028838361012599165, 0.1722642926559333, 0.09253537732987635, 0.04080961863960951, 0.5598408140001759, 27.638000826681814, 74.26439177605414, 51.57893634611561, 51.7043423652649, 86.69839935918009, 81.34814523881482, 33.815635788825254, 43.792478499873994, 39.29494765497024, 33.34553187893283, 34.23768674173663, 59.07257356951314, 79.05776346883466, 74.86429475968885, 75.35242588289323, 61.41636233175955, 73.75395805604997, 69.4637244747531, 68.92597536886893, 61.621678798429436, 63.583899390312936, 70.53431972380608, 53.33798993018366, 67.87239536162346, 43.77176446299399, 4.047003239393234, 18.45445748298399, 66.86138091548797, 31.5715987836161, 30.61033371956118, 10.302628894006054, 33.16887617111206, 27.998978514825147, 24.839046501344253, 24.966772602450465, 20.30837751203968, 29.142790686699655, 28.925603166703258, 22.538609735427364, 29.333602228472312, 27.805264419124974, 35.10903735314646, 46.91281810883553, 34.584773355914706, 40.630102849775746, 30.9437979421308, 25.954545044129897, 26.16464484122492, 33.85702463888353, 40.54991391397292, 40.64202685509959, 29.540977939482662, 17.10544651554477, 1.787240103848519, 0.6897450562927031, 0.9280403823621812, 0.9105524336618762, 1.2802393157635967, 0.1195023081175262, 0.17313594749617964, 0.27122981365649934, 0.2644845627007946, 0.18209068795606015, 0.2920340037634296, 0.3711817954336444, 3.8981576263904576, 1.0666665050291246, 0.4870940240160112, 1.2909665078886094, 0.4314149681839251, 1.6410500580264678, 3.531123798701071, 0.2960039633176019, 0.42240427266205516, 0.1240284551656054, 0.749893928727796, 0.191138262950605, 3.4625644453110236, 1.045296206589668, 1.0803099793772544, 1.5295793620809433, 3.6511983361936386, 1.5481873313265464, 0.6108661921274278, 1.2451010077230393, 9.152375209716059, 22.511963113661736, 32.39035825575552, 39.46716323975594, 48.717445711935724, 33.12401602345128, 18.910664435355894, 12.752213785725257, 9.62206825133293, 15.434571735320555, 20.359344790058753, 19.609750432352868, 27.19790893216287, 27.950884372957294, 39.075185098955714, 38.56493180797946, 36.68541831354941, 34.502572244213475, 37.90741312888361, 37.05624311201034, 30.93535896270506, 33.097124253549886, 23.486107280177457, 32.6149865119688, 30.798685935235795, 11.282634062151756, 18.097413932123494, 47.2562647634937, 55.32954985095609, 12.452456451231434, 7.0103757227620775, 1.2689893452390548, 10.54989020670614, 5.234953107372408, 11.895748569119363, 23.95564832995015, 62.00148974695514, 66.54062517227666, 56.74551763842183, 57.231413010627996, 57.609121568741344, 49.26378480849728, 47.707517762337964, 43.6878296636766, 30.031109471474927, 28.52863184867367, 27.49034320154498, 37.732620546894694, 62.259464033188365, 49.63385258951495, 36.87179757702735, 33.490949830701275, 25.425438880920414, 1.910931066639962, 0.09626535218088858, 0.30438867307478384, 0.11833012464546389, 0.2157574636681426, 0.15210986768286075, 0.1054569440443189, 0.03672769150486396, 0.014846217067491625, 0.062355726596809206, 0.03475454012532869, 0.05635556126494081, 0.1872683391575852, 0.10028696904379515, 0.061495655005978006, 0.09246862808903379, 0.0169676830691676, 0.01110623327774867, 0.1118744396033787, 0.08812772110104562, 0.4463171249916477, 0.10477525602665641, 0.023578809266309106, 0.22824204616969634, 0.03712357510061514, 0.005515870880410677, 0.06454154398412475, 0.033599903897172025, 0.08591332097327517, 0.08164719948845525, 0.09818730590444419, 0.1288078325770555, 0.21710217780163213, 0.06583329845940875, 0.14732451478560127, 0.12023654976679433, 0.07520540362043728, 0.4048999296801706, 37.60219781629501, 90.65145031098398, 56.43051208988313, 69.5170843985773, 91.43377488659274, 86.44626155976327, 38.49381923675537, 31.491215690489742, 38.30947960576704, 31.10361295361673, 37.40309830634825, 61.656838924654075, 79.68399340106596, 75.0091008217104, 79.13388882913898, 68.223157236653, 73.97406578063965, 69.01089468309956, 64.44500869320285, 65.07058751198554, 65.46093002442392, 73.34290935147193, 58.410497096277055, 80.50435712260585, 38.97328192187894, 11.238206355802475, 30.249181485945183, 55.053795460731756, 42.17603052816084, 55.190768549519206, 21.34247510663925, 27.450917497757946, 30.185980335358654, 22.168943997352354, 24.02329940949717, 22.364572209696618, 18.1530664813134, 25.81085293523727, 20.694148502042218, 24.260742049063406, 23.66507914758498, 39.34749564816875, 46.649878101964156, 42.83607521364766, 43.431188983301965, 33.47821389475177, 26.349392398711174, 26.076383667607463, 38.012630708755985, 50.2314256852673, 51.384873159470104, 42.753148463464555, 24.440441516137895, 2.2252767989712376, 0.26404066071394955, 0.8329403724881911, 1.0859505928331807, 1.1998016771770295, 0.13090933432742474, 0.06335047644472892, 0.4863826654130413, 0.06481789488105044, 0.5685215094877828, 0.4037492656179013, 0.8058365494493516, 6.041378196208708, 1.072309324818273, 1.0517507118563498, 1.6158928337597078, 0.2979077224529559, 3.4907422623326703, 5.30359213390658, 2.612991568542296, 0.6363332223507666, 0.3318938955424294, 0.27652682135662726, 0.47715718948072006, 3.7313759951822223, 0.8727641355606818, 0.7944183460166379, 1.2695868938199937, 1.998707827541136, 2.024944806771894, 0.4387480537256887, 0.8115678677155126, 15.99865367335658, 23.315113513700425, 43.667252909752634, 41.930843168689364, 51.781605212919175, 35.106146566329464, 17.178945849018714, 18.351218738863547, 13.999451014303393, 22.28100807436051, 22.809137567397087, 25.204260349273685, 30.28225098886798, 25.487510388897313, 22.99816639192643, 23.82136206473074, 22.447226355152747, 24.58602616863866, 27.220264480959987, 35.90374877375942, 25.25508838315164, 30.43812401833073, 16.753076468744588, 28.902822040742446, 24.189947189823275, 16.48011480608294, 33.334721826737926, 47.7379043640629, 39.75591244236116, 14.12155733954522, 15.533200713895983, 2.275005343460268, 6.964925748686637, 3.973623538209546, 7.64548295928586, 17.76162962759695, 55.224516622481815, 71.73163106364589, 61.66913163277411, 60.96594087539181, 61.80485348547659, 53.673293744364095, 50.81581177250032, 51.87340044206189, 36.69211379943356, 27.7411768128795, 22.913150979626565, 37.96484447294666, 74.72312081244685, 58.057605374243956, 50.7515045135252, 41.577064990997314, 40.067050533909956, 2.369387866027894, 0.12280554901207648, 0.2075952871312057, 0.15585395387343823, 0.08534451601125541, 0.07395899388939142, 0.13622307338781897, 0.03291351209965444, 0.06743554070952439, 0.07635541650797091, 0.13875972840093798, 0.04921529239283935, 0.048723184323358926, 0.04961744641825076, 0.06617060697246945, 0.021338917562858235, 0.14233328341957063, 0.25956339773631865, 0.28289151047506644, 0.14038121477971155, 0.44708002599016317, 0.32157888936419643, 0.14875838623171853, 0.2847219703178252, 0.1390017355762182, 0.13196465108663807, 0.22520197945977413, 0.1614503334126165, 0.22731340970964203, 0.30505100205059976, 0.3682399565173734, 0.15939807579402002, 0.41825149388563254, 0.21010465409246185, 0.33924928956454803, 0.3194455796432111, 0.20361748283668873, 0.43900257877765164, 63.63920873211276, 100.51862747438493, 75.55833462745913, 77.83381139078449, 110.25831976244527, 108.93719488574614, 52.717043430574485, 59.70310241945329, 53.93941479344522, 51.721628250614295, 51.35342751779864, 67.84074183433287, 92.55663179582166, 86.68796585452172, 87.43517737234794, 66.81120595624371, 82.55301106360652, 75.34673844614338, 71.01649668908888, 65.29801830168694, 70.49580989345428, 79.56489455315375, 64.30854159016764, 77.81237956016295, 58.10984742256903, 9.391912394954312, 25.93154230425435, 78.75238341669883, 47.373363202618016, 41.93782498759609, 16.031312308003827, 39.031097658218876, 34.79039576745803, 33.698270628529215, 33.736552961411014, 24.196421061792684, 35.665535388454316, 36.47382213223365, 26.783849808477587, 42.24007891070458, 34.24239750831358, 49.48766193082256, 54.01872511832945, 44.03844641100976, 49.2759245441806, 37.131117236229684, 31.927773529483428, 34.39225558311709, 53.680083367132376, 60.80300954080398, 60.29391727139873, 56.08567691618397, 33.94450918320687, 6.251924162910831, 0.7302896161713909, 1.2500952881190086, 1.9495018163034994, 1.478628018690694, 0.210533602043025, 0.20709460270741295, 0.9975620034721591, 0.458017953581387, 0.3271215354963657, 1.5389195060537708, 1.493203791399156, 9.53606047937947, 1.9201497397115155, 1.1918265180241678, 5.138686376233255, 0.9698627156115348, 2.9644697664245485, 7.476710234918903, 2.66130413739912, 0.45693960821916985, 0.4195536901393245, 1.047394797205925, 0.3967568134107898, 8.336212346630713, 1.0385412722826004, 3.4208578832687873, 8.454764023903879, 11.267239739817958, 6.506278101475009, 0.7561942358170787, 1.0537508754960954, 24.106324218934585, 37.37027199037614, 40.48401417270784, 40.927830357705396, 59.304789650824766, 42.708202023659986, 22.630171583544826, 17.469307145764752, 15.30790271297578, 24.983601531674786, 26.79165924749067, 26.7630632077494, 34.208908311782345, 39.14824316578527, 46.403745451281154, 55.20963907241822, 42.63254342540618, 42.10237626106509, 40.95497315929782, 48.43487816472208, 34.26829691856138, 41.158171546074655, 25.73783213092435, 37.2145107484633, 35.867992447268584, 9.115727524603567, 23.364639320681174, 58.18410181230115, 56.170407956646336, 12.853870834073714, 7.756448772645767, 0.9224897995591165, 11.246798307664934, 5.402988916443241, 9.964741218474604, 22.40751627952822, 62.456072838075706, 68.35879279721168, 62.722354704333895, 61.40784686611545, 64.53683137893677, 58.36392679522115, 67.33369704215758, 53.70400590281333, 38.82412595133628, 34.67291685842699, 37.77149515767252, 56.56074654671454, 83.8799959613431, 71.51662242028021, 59.334136824454035, 57.814285062974506, 63.01094701213222, 3.8319666491400812, 0.23593067311711852, 0.4695568311839335, 0.22329616720878312, 0.28516115320305674, 0.28478604591181206, 0.4042644750687384, 0.14143058669663247, 0.16222526199154316, 0.16195166135026565, 0.2236538076953542, 0.1231688662101665, 0.29197035717868036, 0.353151303265364, 0.22583856788133422, 0.19068144472135654, 0.34643874894226756], [0.1031834172505525, 0.1380052543695896, 0.09675726489794832, 0.1881794934912074, 0.18201541215662034, 0.08370721757772469, 0.07375814095740357, 0.16128007803232441, 0.10408791428011271, 0.06587537966908948, 0.05293054303394691, 0.030540884172003117, 0.044037974439561374, 0.042149471945219466, 0.07318350606628003, 0.0940684648230672, 0.29129782391171305, 0.21656967008546477, 0.0951055027244072, 0.11383163337145122, 0.2936113787995231, 5.345467848162498, 74.48435829531762, 66.90143615968766, 55.64204116021433, 70.01526463416316, 89.83660928664669, 52.67294030035696, 49.25627739198747, 41.093934889762636, 39.55439283001808, 28.158152218787905, 58.85252075810587, 82.19616167006954, 69.78716311916229, 69.78049508986935, 70.20859041521626, 76.77757986130254, 60.64830733883766, 66.98994836499615, 63.25416141940702, 75.77747744898643, 63.21136051608671, 63.14464492182579, 46.5548586845398, 12.70522673283854, 6.35916127312568, 53.68508831147225, 48.273453020280414, 31.042465163815407, 19.285648907384566, 27.97032952308655, 34.416605657146825, 19.488706088835194, 25.85801159181903, 19.383172758163948, 18.276668210183423, 26.27355729379962, 22.775842528189383, 34.223385780088364, 30.756802866535804, 31.902627214308712, 47.22045744619062, 42.49252657736502, 41.0798418137335, 42.180309834018836, 29.082911783649077, 29.10717752672011, 38.281065956238784, 29.83609118769246, 47.80249403369042, 38.44748035553963, 31.086360408413796, 21.93177200132801, 0.6362755512518268, 0.3359707396837973, 0.5752988748492733, 1.7034588898381882, 0.2656125505605052, 0.7982634332391524, 0.2828318169040065, 0.2619946237292982, 0.29561629218439905, 0.3786770771107366, 0.45891890362385784, 0.2528796329974167, 3.112435787916184, 0.9576106407950002, 1.9252743163416464, 0.6880173135188319, 0.20801099708243725, 3.871647797284588, 4.3225455764801275, 0.06203344106794365, 0.6450476869940758, 0.31399247386763174, 0.36927227531709983, 0.5081988883114631, 1.2412383311217832, 1.251308403668865, 1.4369755118123948, 0.6248897073730346, 0.5191906565620054, 0.3045574575662613, 0.40611929650748935, 0.6410732841299427, 2.4245861557222184, 20.252946576764508, 42.44943541865195, 44.94936981508809, 50.75831374814434, 33.89555015871602, 18.927440412582893, 11.04784196422946, 8.68388927751972, 18.435614416676184, 25.103839828122048, 28.370491689251317, 23.799630172791023, 29.79488276666211, 39.10437537777809, 46.67283181221255, 46.59481586948518, 51.056496251013975, 49.6730645241276, 28.393504235052294, 27.908157994670255, 24.9009415026634, 23.502147812997144, 21.660138060969693, 29.349597654035016, 15.954205374563895, 10.983619036213046, 27.861450410658314, 59.12887527096657, 33.30566883087158, 24.02977328146658, 6.3967924925588795, 0.3059809102166084, 0.8972206651683777, 0.4109642816887748, 0.41751767358472275, 3.1318520105654195, 38.75067172511932, 61.259969588248964, 57.09868784873717, 54.34665095421576, 39.91183450145107, 28.347663494848437, 27.923731765439435, 30.71837148358745, 25.104587039639874, 22.46659698024873, 46.997580528259284, 52.754913914588194, 46.736436966926824, 35.82093184994113, 34.61081789385888, 13.54844218300235, 0.6028106243860337, 0.12782815933948563, 0.10005769424981649, 0.13787822166998542, 0.23740845672305555, 0.6476284839933919, 0.3641089346380003, 0.08673861217234405, 0.028307824057617018, 0.018004209606818134, 0.1507115120729131, 0.23015125985107115, 0.2515230904663763, 0.2751468212133454, 0.24911359072692935, 0.05530766789771377, 0.027133757924480785, 0.09749879204337636, 0.1168299942547756, 0.11571763458872035, 0.1967700204301265, 0.23095266442866097, 0.13035470199200416, 0.1608163037247235, 0.19320754304287896, 0.0703171804367054, 0.04342253387515103, 0.16874266307680838, 0.04983070231373272, 0.06712572709206613, 0.0650776676352947, 0.08829568587844411, 0.08137080262625411, 0.23597129109886386, 0.23886413103149784, 0.2200274079317047, 0.07151714225690212, 0.68272125576773, 6.4974503171059395, 88.74369575131325, 78.11435499498921, 67.25765012925672, 88.01297387769146, 92.33291549067344, 61.80142141157582, 39.92839474831858, 36.631728910630756, 36.10747668050951, 27.793263927582775, 63.98096092285649, 87.34260159154093, 74.0590556975334, 78.71622700845042, 74.37373176697763, 78.52753746894099, 61.48984009219755, 70.94412895940965, 63.79053769573089, 75.90313449982675, 70.64773897970878, 75.4460842378678, 42.06162283497472, 17.912493790349654, 21.57560313901594, 43.75478844488821, 50.768107906464614, 53.6242562724698, 27.88868146557962, 23.91245322842752, 33.02132444996988, 17.603132532488917, 22.65319197408615, 20.623369332282774, 18.69045080677156, 23.789604594630582, 23.378630415085826, 23.980790722754694, 24.885220643012758, 30.099125331447972, 47.943005100373306, 50.78834341418359, 44.28258257527506, 48.952631027467795, 33.776663118793124, 28.251628183549453, 36.05380688944171, 37.63913085383754, 57.74331761944679, 44.26462204225602, 46.007068311014486, 27.60451751370584, 1.93466974121909, 0.4979827994060132, 1.2521330819975947, 2.2251659920138698, 1.0682332467648292, 0.6665970048596782, 0.35838463373722573, 0.14609655245177208, 0.5321000348175726, 1.3596568929572261, 1.1312576455454673, 0.5973023909234232, 3.7186032870123467, 1.9449246554605424, 1.8689576608519403, 1.317704202186677, 0.16300765226685232, 5.824755987813396, 6.355398739537885, 1.3009216059600155, 0.4565536837664343, 0.23910092880889294, 0.24919406060249577, 0.3927341470074269, 3.95231869432234, 0.8968686324454124, 1.991296509100545, 0.9446470235143939, 0.3342948150971244, 0.14756995403478224, 0.4670516317409854, 0.5764307850791562, 7.427532538290947, 21.321664971690026, 49.71954068829937, 49.17866937575802, 55.32962437598936, 40.22377275651501, 16.12724465708579, 16.96884801310878, 13.451800865511741, 21.44061084716551, 28.320554033402477, 32.64431211256212, 30.32272788786119, 35.390286983982215, 33.55542182922363, 32.585709941002634, 32.051843981589045, 41.17044464234383, 37.535901915642526, 22.280439330685525, 20.79397282292766, 17.847388329044467, 17.22459243189904, 18.803979889039073, 30.028567775603268, 10.28934774860259, 16.25444123821874, 40.55831170851185, 45.580028103243926, 26.76699930621732, 24.03673548852244, 15.571344783229215, 0.763204982203822, 0.8388841116139967, 2.4221214363651895, 1.6934023004385734, 1.3140858157027153, 23.605943533682055, 60.14701274133498, 59.37183080180999, 55.725062047281575, 46.1326273026005, 30.4488536619371, 31.23654207875652, 31.6335996889299, 21.463888152953118, 16.35505395550882, 48.434030932764855, 57.76198417909684, 60.11778323881088, 45.0934188596664, 46.42311019282187, 23.529321993550948, 0.35022230398270393, 0.06484614054281866, 0.03888926987025527, 0.08604977655434802, 0.035791505248315876, 0.3400389117098624, 0.3334735075552618, 0.0369926123699594, 0.011576967494141673, 0.05138939246535302, 0.11611397783722609, 0.158414832586723, 0.3218271018516633, 0.3785113569709563, 0.07667463768513934, 0.05307549836053964, 0.08858723595978753, 0.2652428978152814, 0.28966473896176587, 0.19928614428687483, 0.3246532614913679, 0.45813292805706307, 0.11238292280224063, 0.2546399345080699, 0.2584298634000363, 0.2728832152581984, 0.17603916025930838, 0.18915270094669637, 0.10963323405913769, 0.15647826956645136, 0.24529563833869275, 0.24563732887468032, 0.29550383047711465, 0.38712733335071997, 0.5971573245140814, 0.19213112822223097, 0.22787803183159522, 1.007445763436056, 10.906527792253803, 116.18484850852721, 92.69580533427578, 87.65049980532739, 97.32385696903353, 119.68932936268469, 80.36873725152786, 67.09521693568077, 53.133916854858406, 60.018543351081114, 43.36384580981347, 69.38599094267815, 92.96017308388987, 82.30412098669237, 77.60767890561011, 83.21807246054374, 83.55143470148887, 66.72011283136183, 71.09570503234863, 68.81381911616172, 81.94971130740258, 77.65655163795718, 70.36426928735548, 55.913202454966886, 17.644142873825565, 11.055337613628758, 60.84606539818549, 67.5162676841982, 48.84021197595904, 25.38624067460337, 31.362720804829753, 40.176625867043775, 22.217275442615634, 35.0610157751268, 22.996091458105273, 23.33958714239059, 32.05196165269421, 28.60364325584904, 43.14041583768783, 41.218736863905384, 37.50544863362467, 60.00665464708882, 54.697840367594075, 50.88282154452417, 54.37533916965608, 35.63727078899261, 32.79127155580829, 49.81767446764054, 44.37741371893114, 64.32339168364003, 55.85405703513853, 60.350921077113, 34.31866407394409, 2.721713541015502, 0.4167471117069645, 0.9381738869893936, 3.3779464181392425, 0.6838397441371795, 1.0477122640417469, 0.6564297923637975, 0.31256344409719594, 1.0412743062742296, 2.3397786290414873, 1.8822341484408227, 0.6933979473767743, 3.7736387983445203, 3.3704105644456805, 2.297800197716682, 4.2928571566458675, 0.4578951650088834, 4.871512170760862, 9.411782141654722, 0.7930880496578833, 0.7387744995855516, 0.45733319355114815, 0.5598294758988965, 0.45442613502663953, 5.891605923252722, 2.5439681497312363, 1.9974299928834363, 1.9583205301915447, 0.5431761340268197, 0.4196758658414887, 0.5851513784258597, 1.539702999495691, 20.568356129430956, 41.14563172863376, 54.334609277786754, 40.97183935103878, 61.7934040869436, 43.39478154336253, 24.115129939971435, 18.293848191538167, 12.451846522669639, 24.557759607991866, 31.53551493921588, 40.435737640626975, 28.58685551151153, 40.227004789537006, 47.075188544488725, 59.52816470976799, 58.66280747998146, 58.55236922540973, 51.32405680994834, 29.128038652481575, 31.74587949629753, 28.42554999936012, 24.35739121129436, 22.260601943539037, 35.16172262930101, 20.377754434462517, 10.19420869888798, 39.023503949565274, 63.43397855758668, 36.071092774791104, 23.17675582824215, 6.118288030547481, 0.2531394900213326, 1.1840108277336245, 2.1620195094616186, 1.290767815324568, 2.6003323639592817, 41.18536533847932, 71.575026512146, 69.48127315890405, 66.45110884020406, 54.2980057193387, 46.82952265585623, 41.83743584540583, 42.025635088643725, 32.63128788240495, 29.985015738394956, 65.3758655824969, 65.46914738993492, 74.75952040764594, 59.94704638758014, 63.90185848359139, 41.34163256614439, 0.586409539945664, 0.23985995340251157, 0.21839358753735022, 0.2619013448636378, 0.42533140269017994, 0.8752792328596116, 0.5268593192581208, 0.14203139881212867, 0.15549206925976664, 0.13020373670564545, 0.32497232179007224, 0.4337098918134167, 0.5191454267309559, 0.61635346542443, 0.3143964779953803, 0.12341319463185726, 0.23131672473203754], [0.08084112943540658, 0.23235557060087883, 0.06282164212015849, 0.20034875420312728, 0.1720521016226661, 0.044811171659779166, 0.1945982377735838, 0.16444166160879597, 0.3275359890634014, 0.10664493191025912, 0.0516063945307847, 0.13629785889098722, 0.06672704727539132, 0.1205644737027826, 0.09213544878988497, 0.2637233164521956, 0.13660487628752185, 0.07468107006242199, 0.127335871239343, 0.017121207089193406, 0.21826892971031128, 0.32942825687989113, 27.152168212398408, 85.38738635278519, 56.18677992974558, 61.893718704100586, 81.74588926376836, 79.40512072655463, 49.131004733424035, 44.83278128408617, 35.114662031973566, 26.648559416494063, 60.38821889508156, 72.7805434503863, 72.2130000206732, 69.31021075094901, 72.97982338936099, 67.19999128772368, 65.56068766501643, 61.138093702254764, 68.6992702176494, 77.69064487949495, 52.302648944239465, 33.12192540014944, 11.71642957195159, 5.381897841730426, 21.30565974020189, 67.39726297317013, 36.40648288111533, 18.724712710226736, 35.88868687229772, 41.8170944336922, 34.269077470225675, 31.832830598277432, 23.99592322687949, 25.321815744523082, 28.80738489089474, 23.312536516497214, 27.398428340112012, 39.6980143362476, 37.520941995805316, 35.29701694365471, 44.02419251780356, 38.134985123911214, 51.193896878150206, 32.34325647354126, 30.462907514264508, 41.21685412622268, 37.475540561060754, 36.829765458260816, 44.36817653717534, 41.671731395106164, 32.39477876693972, 19.039771210762765, 1.2242336306841144, 0.49597803923872213, 0.4503010886330759, 0.9083068154511914, 0.2942838507794565, 0.37690879296391244, 0.2773638183791792, 0.2724424695536014, 0.15670176805748096, 1.0476431322674598, 0.18190811388194564, 0.5394976862495946, 2.4010622309100245, 0.3591580454620623, 1.1772099281511, 0.8277092177060343, 0.3619400784373284, 4.869072456513682, 2.612745930110255, 1.760328599522191, 1.0045068662974144, 0.37289458417123367, 0.2529652663055928, 1.045657187219589, 1.015317347501555, 0.2315667451870057, 0.21498317860307234, 0.3911164451029993, 0.4440715374244798, 0.7160044665778837, 0.17537152995505642, 1.3899369778171664, 4.086022977867435, 13.731717871081445, 31.880709009785807, 44.165417455857806, 48.83443040232505, 38.21413070924821, 21.29149606150966, 21.291649033946378, 13.271385565880808, 13.7136455505125, 22.62890858034934, 29.968881068691132, 35.43471959329421, 36.9723867600964, 43.819931168710035, 55.74113199787756, 51.098108676172075, 50.929187882331114, 50.785793873571585, 60.35641631772442, 61.83631873899891, 58.29369675728583, 41.07233439722369, 30.707498673469793, 20.745425647304906, 32.89510061663966, 17.007620642262122, 15.332285146559439, 49.963986719808275, 47.239955548317205, 36.04778212885703, 19.56261334880706, 3.2611166613717235, 0.6259918321044214, 0.48539251209266726, 0.7061692459448692, 1.5144110663283257, 0.6185814942563734, 16.91673932536956, 39.82392241877895, 42.228947224155554, 30.408019827258205, 17.05990779784418, 12.371046677712473, 32.51484644028449, 21.53907214441607, 30.413619010679184, 37.34245846348424, 46.0813658468185, 32.732947872531035, 26.38974182067379, 40.39333289669406, 4.299363878465468, 0.03936808631424943, 0.09431429477708955, 0.10650181902512428, 0.19150328852476614, 0.1859453206341113, 0.09543349560830863, 0.1853920979004714, 0.09599972651490281, 0.1298063209340457, 0.17569592222571376, 0.035388186769259554, 0.07311519400607194, 0.2436734778025458, 0.23907379397461492, 0.2600108237276154, 0.0021874271295664292, 0.03667832479902333, 0.08969086988438522, 0.1495054138884429, 0.024015149965341535, 0.18868026984555109, 0.1892649941146374, 0.1572600622931796, 0.2729342367139555, 0.07258366688244766, 0.22996346105731305, 0.26540230539056564, 0.03459358122199774, 0.13978660797640202, 0.01918463043928627, 0.12543965807004323, 0.06417659884919563, 0.6025269879929481, 0.12608360093567642, 0.14275484628254367, 0.12757380282686603, 0.12206988243926918, 0.11472308392366094, 0.338312333389636, 28.4540028725901, 100.41084858679004, 62.59769393551735, 81.41902246782857, 93.09956627507364, 87.13033076255553, 50.13302518475441, 41.79218346072782, 36.63330570344002, 29.039971636187648, 65.08013456098496, 77.40553563640964, 82.2977118338308, 74.00640964508057, 77.1521819022394, 70.20548389803979, 66.20126170496788, 59.05388739801223, 68.45221580997591, 78.13874429272067, 57.958322340442294, 31.68435908132984, 13.76103170456425, 18.681621551513672, 25.12608358936925, 52.681177277718824, 56.65910782352571, 39.63355018246559, 35.53196299460627, 40.15448800979122, 28.848542321112852, 24.1761580974825, 27.83114225633683, 21.200971680302775, 15.300678687710917, 18.56265018063207, 23.285334879352202, 31.722678676728282, 29.73392717299923, 34.329030898309526, 53.09486573742282, 43.93796313193537, 54.60843778425648, 41.551244028152965, 33.67736439551077, 40.244000419493645, 38.01542735868885, 41.04654481334072, 51.1684799194336, 56.88855471149568, 44.844426801127774, 29.30155254179432, 2.2490081191062927, 0.2516390302128369, 0.6618576785249095, 0.7309235079634575, 0.027842969566042867, 0.39864221707947795, 0.15415054205204212, 0.4751501923366901, 0.220072852267373, 0.6512477284958286, 0.31619004304370574, 0.8836992745918613, 3.2696088379429233, 1.2637354529673055, 1.7158890034883254, 0.9750607753953627, 0.5434625283364327, 8.163005382783952, 5.458210495210463, 5.810991410286197, 5.396387567443233, 0.5595883727073669, 0.14630506626300274, 0.31825651925417686, 2.081833270288283, 0.5227214638744632, 0.515353904376107, 0.503296967475645, 1.2967935565017885, 0.4191003805927692, 0.3048273656637438, 0.32793392577478964, 1.7029956824356511, 13.859806791428598, 45.927856045384566, 46.80308588089482, 47.37377505148611, 43.00513721281483, 16.62150252249933, 21.7223645025684, 19.02153415064658, 22.850863741290187, 29.920724168900524, 33.70575451081799, 38.655448344446, 38.12248060780187, 44.121581046812, 51.84701073554255, 48.66923193777762, 46.14874432163854, 37.248815797990375, 32.25012567735488, 34.10060774895453, 34.713619293705115, 23.208964370912124, 16.070607592982633, 10.745741994150224, 18.709599817952803, 13.271824871340106, 26.9646083154986, 50.52750579772457, 34.38286935129474, 29.622898601716567, 12.727389104904669, 7.3252979209346165, 1.1686569548422292, 0.35295861683064894, 1.4099509941954769, 2.0483900390325056, 2.4809079593227756, 11.375013724450143, 35.64034984957787, 41.518872707120835, 29.314949397117864, 21.667333649050807, 22.214176770179503, 26.49025255633939, 15.600307564581595, 23.32292099152842, 42.59158603606686, 52.43795110333351, 42.03992428318147, 39.32523619744086, 53.151214507318315, 4.819498600498323, 0.07223390944061742, 0.03518454527722732, 0.021050837859811804, 0.13608024395521612, 0.23873571937362995, 0.17544453813424035, 0.1024138359653373, 0.02979111966616925, 0.09179244058266764, 0.0874212424781534, 0.1591444700475662, 0.10799892336851168, 0.23964581650591668, 0.37229363415991107, 0.0941294607435984, 0.029685788322240118, 0.054797610388167446, 0.1076973605179979, 0.33465833913895393, 0.12846065685153008, 0.4660594559484913, 0.2971299287051924, 0.24496715515851977, 0.37003554403781896, 0.35012721714954226, 0.3982114918049305, 0.41837474211089076, 0.1197398949654833, 0.21990350087083158, 0.14468259929168611, 0.2388583240850318, 0.13606775672205035, 0.7306432423572387, 0.24564135849716204, 0.3608833061110589, 0.27529486004383336, 0.45190199789020324, 0.2838931551143047, 0.45626967965114507, 48.670126238176906, 114.20114901758011, 79.71243842955559, 89.03236650651502, 111.67368350490447, 100.33811999905495, 71.10254564592915, 59.656665478983236, 49.024014242233775, 46.3414974366465, 72.04126296504852, 85.29589314614573, 82.96817825686547, 82.84179948991346, 81.1791067738687, 78.2043969246649, 71.49461792361352, 57.36488342285157, 76.41584319453086, 92.05550978260656, 61.01696698896347, 36.63654950357253, 19.102295752494566, 8.748465218851644, 29.619040950652096, 78.79848695570423, 55.04275398869669, 23.680935329006566, 41.98936493166032, 46.1272144317627, 41.06324626553444, 37.82549835020496, 29.828013066322576, 29.445468225786765, 35.72146838711154, 28.420064564674135, 35.29749155044556, 52.192398963436005, 44.42100301865609, 40.69377468478295, 58.10336766704437, 49.35785893471011, 60.094398067843535, 39.50761856571321, 32.204159421305505, 52.11870547263853, 45.67236854184059, 51.77549808256088, 63.91837950675719, 64.77508398794359, 59.528321604574884, 39.32839370542957, 3.3597667226868295, 0.5887258833935184, 0.8523515083136097, 1.8070338546268403, 0.7202178275873585, 0.9210961936942993, 0.2625085767959395, 0.47790651540121726, 0.30412207447713424, 1.068569835155241, 0.6268327514971457, 1.2474295472906483, 3.2151307934714906, 4.898151438082419, 2.340782020361193, 2.150189886170049, 1.575293115550472, 11.381269904874987, 8.133712632040824, 4.572332405274914, 5.311596220539463, 0.8392696070574945, 0.6005608999440747, 3.050688610922906, 6.1038272323146945, 1.1764576910964906, 0.5223094924323021, 0.8185047632263553, 1.2086054370287926, 1.7573586298573403, 0.2681526836128004, 2.851485403314714, 9.210794991062535, 43.39005508730489, 59.7392862842929, 40.126101816854174, 54.61148546588037, 47.76386260986329, 27.04159659724082, 30.86405223415744, 16.927731767777477, 20.27532369859757, 29.516341532430342, 40.887594684477776, 46.797284695409964, 44.74762270527501, 50.951525780462454, 68.36364869148501, 60.06893796305503, 59.79704710745043, 55.69671115567608, 63.40703187450286, 73.63047399828511, 70.1898414857926, 48.7965795301622, 37.35294295895485, 23.89664803781817, 45.23296110091671, 21.59451876917193, 17.538195733101137, 58.86768856356221, 51.614394572473344, 37.695875783120435, 18.255634500134377, 3.2590770288821194, 0.40051735516998077, 0.8306090137170208, 3.467179849263161, 4.160963046935297, 4.303898138384666, 26.15017717884433, 47.862745561907374, 54.946879494574766, 42.08502369542276, 34.74980315854473, 26.544981387353715, 43.54201555252076, 27.051890857758064, 47.72474873450495, 57.14477569826188, 65.1527690118359, 53.75396120932795, 54.73537352777297, 78.08922829166536, 8.694503211206007, 0.25069900968622777, 0.2546947864034484, 0.23326531533272038, 0.29930442331298707, 0.5923776713109786, 0.3037087853637434, 0.3153891747276629, 0.1642405328851554, 0.21567012964477464, 0.18411555027048435, 0.2672456967974863, 0.15040518415551032, 0.4823742788885871, 0.668593675138489, 0.3756595180640298, 0.15332522020945627, 0.17826061605686144], [0.059290241089559374, 0.10032705842487274, 0.017131848050461664, 0.16800119721841428, 0.17852459463380999, 0.0050412430221425195, 0.08137265655903086, 0.16739529827910085, 0.3021019312643236, 0.1522222527813527, 0.04957046607629426, 0.0901274863750704, 0.037395126456695224, 0.021993635455146435, 0.08549154360568331, 0.1121246975456034, 0.31601941994121, 0.06588127854610644, 0.05946364509122026, 0.06937488462896117, 0.013903563113642797, 0.029977190931658113, 0.30774092061385033, 50.303259972603094, 83.38097633854036, 47.362682588638805, 63.722868965518096, 90.89542958044237, 57.84968837614983, 44.65277194976807, 29.978910569221746, 18.447073621134606, 40.505963756192116, 69.71942378628638, 56.12871708408479, 69.56154054211032, 67.60547807139736, 67.35277545067572, 63.09643114766767, 66.30310212412189, 80.75552217421993, 33.76490385301652, 7.147868035301086, 1.1056987460582488, 8.537060253081783, 18.816060789169807, 55.99158317812028, 56.29961083012243, 22.85756903309976, 15.862133618324036, 34.45963405793713, 33.54941275811965, 24.220508337020878, 35.63911822534377, 21.493221598286784, 39.97492582567277, 62.4451921832177, 49.417216162527765, 51.6736811976279, 37.179585964449, 38.67617022606635, 48.27820693292926, 43.383567487039876, 48.366032723457586, 44.81586802390314, 29.347938491452126, 28.056035272536743, 40.263875069156775, 35.66401350882746, 36.45510065940119, 48.22751422082224, 44.279040675009455, 28.31621785317698, 14.719649168752856, 6.393224116294615, 0.25072317209935957, 0.2245083328096136, 0.4602223256182286, 0.789332073782721, 0.0371988968653304, 0.5244990330069296, 0.7293842841059931, 0.24346602119265065, 0.18453440118220546, 1.5049397681028613, 0.47607292991972744, 2.6173358386562717, 0.5237738235342888, 0.2744371786473259, 0.9230459793921441, 1.233774796128273, 5.616690429948992, 1.604379941859553, 6.905711197083996, 8.820481896400452, 0.20353152777158445, 0.734601526731445, 0.5087551907185586, 0.36164976175754304, 0.20615753928019157, 0.3927434319930692, 0.31443230026671964, 0.22153906794565342, 0.45780446019864857, 0.19972603197299665, 0.7329148462703152, 1.8171498924493792, 1.9760641071104237, 20.50500592877788, 41.86736745219077, 52.52028949799077, 47.629160573405606, 24.23539177063973, 19.12679291540577, 19.299587049791892, 15.669466795459872, 24.48335420700812, 40.494910517046534, 43.776483074311294, 45.78831380413425, 45.93479079584922, 50.85884801803097, 50.743753910064704, 61.592280633987926, 85.57391858869984, 96.67061759579568, 97.60995464940225, 84.51345089943179, 94.94190354501048, 80.38207331011373, 72.14441345584008, 49.4209659484125, 44.0768228807757, 9.965175620971188, 32.25085523820693, 67.97461232831402, 50.65403361474314, 72.23078404703449, 26.414521394237397, 2.8519617261425143, 1.200339899909112, 0.22287117227190928, 0.48148966184066194, 0.6562179230874585, 0.544039361899899, 5.563303049533598, 13.50714845042075, 11.530236621056835, 7.673883861111057, 13.868584075281698, 48.63964942193801, 31.123921025183897, 36.92210589685748, 41.27567006695656, 32.806115765725416, 22.881950486090876, 30.06978992492922, 14.597737981427102, 0.5031440869694757, 0.06926142700737523, 0.026977759440459555, 0.09044826271072512, 0.08530776677352768, 0.06079418659811059, 0.010289957975938676, 0.061229473926247134, 0.290330040358728, 0.06186390197986077, 0.1712731434212577, 0.10161680574979513, 0.030079300875865647, 0.20708332589316755, 0.07123099309542487, 0.043747424102959134, 0.18149690852770883, 0.06940848524532012, 0.018196997548183127, 0.1353299527639343, 0.07919296787510957, 0.10815276914546568, 0.10733751369820488, 0.049422672393942074, 0.24802519429114558, 0.24526975988861055, 0.3581390259487014, 0.1865861531827719, 0.09209507595627539, 0.1973730848441201, 0.043302985854567065, 0.06794451420465786, 0.06395694994998556, 0.2225777146316344, 0.36175149823388747, 0.08530526932689451, 0.0918426882896212, 0.009739605199185111, 0.08983737653902463, 0.06041850474092269, 1.3060013204813004, 58.6074314578887, 98.02030517208962, 60.09659067276986, 78.50994171634798, 94.54280237997733, 60.26994374490554, 37.57523152136034, 25.70540393552473, 24.54527078136321, 54.30115146021689, 76.07848798075031, 63.41577875998713, 75.99667518369614, 69.70283216045749, 67.81461884898525, 61.426121188748276, 63.027624930104906, 77.95382022857666, 31.352861927401637, 6.443776113371696, 2.5886088898105006, 19.008851166694395, 25.661667546918316, 39.5722553037828, 62.252960743442664, 43.85563650438863, 22.93135077722611, 38.06243304283389, 32.180799745744274, 19.133906133713264, 26.362522532863004, 11.9699215696704, 26.81518562378422, 39.8262954527332, 33.125008383104884, 31.575413288608676, 31.120257531442952, 35.1051502843057, 51.1709314007913, 50.62041105762605, 48.992537221600934, 49.22195273060953, 36.0827539813134, 30.485435647349206, 41.243479174952355, 37.72444632745559, 38.384385108947754, 59.09060862756545, 50.63615152912755, 40.92780290111419, 24.471998945359264, 2.1514447994770545, 0.25266661458919126, 0.04685947626468636, 0.1750705493313651, 0.43268698057340044, 0.10061788838356735, 0.5199126791088812, 0.7080060183521241, 0.27997375736313485, 0.6662940017638669, 0.9030772541319171, 0.8721841763584846, 4.286150393947478, 0.3502855522017325, 0.17773814409250216, 1.8504253198062222, 0.8813400915072811, 12.505676150321962, 4.870855173757, 5.146139369856927, 5.633457091546828, 0.21530844421396333, 0.5632837969929941, 0.534897726630011, 0.6282198609363648, 0.3848151880646906, 0.417974170057043, 1.0921535761125627, 0.43890550011588686, 0.2743544411515036, 0.1136927646134169, 0.5369454490080957, 0.7256493296834731, 9.569967408334056, 42.08737711752615, 45.33751972260014, 49.43570229314989, 46.54476250371626, 17.00183906862813, 19.631543121030255, 19.557174982563144, 20.694809421416252, 32.500176775840025, 43.0486245309153, 46.461396448073856, 47.33002885695427, 54.4457967050614, 55.471869130288404, 53.03027999016547, 56.904408931732185, 78.1515625984438, 83.71287161304106, 83.50427996727728, 71.62455035794166, 73.14237425404211, 61.87585230796569, 53.86579190531085, 33.56382354613274, 23.54055566172446, 9.01706422528913, 48.18781198993806, 62.48433743753741, 45.79345603143015, 49.33724295708441, 14.875430022516559, 5.49339464595241, 0.5525699654413808, 0.1559497148639733, 0.3771555345625647, 0.8365303217884034, 0.9617540732987466, 4.256893925128445, 14.000944456746502, 12.428022046242992, 8.480840921401978, 18.1893091817056, 59.992204635374016, 26.847011735362393, 31.732763090441306, 54.17188190644788, 42.52851824606619, 35.46152507105182, 43.1714064844193, 20.90228711405108, 0.3544341021728131, 0.06418252453928994, 0.021913152173041336, 0.1631878514684016, 0.03591617839711328, 0.055887244055948915, 0.12824518696194695, 0.04489713438576268, 0.22807002878717839, 0.1187152753493959, 0.05318298815719543, 0.055326348951747345, 0.02417989908867786, 0.3086320647308904, 0.032265455341867866, 0.06429046632782107, 0.07109040063956092, 0.03003495587636867, 0.17566471180367857, 0.24551783448025105, 0.2206402323058536, 0.4345551012985168, 0.48109567814296295, 0.1256189686096003, 0.48047854835467957, 0.3483557154334361, 0.45011872906358014, 0.5263434662934273, 0.20490297837363136, 0.26559060980235377, 0.10488916564011767, 0.22936565200648001, 0.3134381939326564, 0.5901606741451448, 0.7415489023250919, 0.2252130570911592, 0.22254510992957702, 0.14148680222851617, 0.45920232551232465, 0.21441173829859306, 2.7932730172911002, 89.2856731722432, 108.57962377609746, 73.04618204793623, 89.9216619614632, 114.94680727681806, 74.52443707373835, 66.84318111788842, 41.04654089097054, 34.663275672543435, 66.14798022854713, 90.59860814002253, 71.19022630876111, 82.05979654865881, 73.03391287403723, 80.90019487565564, 66.04709686771517, 73.75460132475823, 90.63952630566013, 41.24644448680263, 8.620915624403185, 3.85248089028943, 8.771651329532746, 24.51585496625593, 65.50626085650536, 79.85340841354864, 30.392726505956343, 20.99501782847989, 38.487178664053644, 38.233158126954116, 24.535604100073538, 41.1443648030681, 23.304678047856978, 41.94064124937981, 70.95435850081905, 56.79262530419135, 60.59340200116558, 50.446418639152284, 45.10131459082327, 57.649180735311205, 62.152516688069994, 66.10624620991369, 55.96111420662173, 35.744586836907175, 32.08224431160958, 51.24041618839387, 43.85953534033991, 49.6170844570283, 72.75582467356037, 60.61374341287921, 53.74578698988884, 43.996253475066155, 15.197584090694306, 0.15970414324152857, 0.5243791555685382, 0.5273002794673366, 0.9878993671267264, 0.11224707243062797, 2.441086096148337, 2.930380202108814, 0.6660477504614861, 0.29614139949121787, 2.8319345943389402, 2.202691791519042, 5.735941760001644, 2.7987846828276113, 0.4410674615252403, 2.616399863073903, 2.289118276488397, 17.599718109253917, 6.692794157612709, 22.051620021943126, 18.950511793936453, 0.3802164541857858, 1.473751409399894, 1.0025911561904415, 1.2390213339559495, 0.6517323250732114, 0.5954147502779961, 1.509777153691938, 0.38687011166926355, 0.9710952591511511, 0.33192340524927266, 1.6176791056509943, 3.7325522159376456, 35.30331627015145, 62.67105010248, 43.98707512886294, 52.191292855047415, 58.45178004234069, 29.90671934620027, 29.73261514017659, 23.0386354461793, 19.981265567964126, 33.84699121598275, 49.57106721016669, 54.687281347090206, 53.17939281463624, 53.4068432161885, 59.79142242862333, 60.58505127506872, 68.55123996734619, 92.59139968502907, 98.48870677332725, 103.80905674349879, 87.25621531086584, 98.13561501041536, 88.09294316076463, 85.42745728646555, 63.41170733974826, 56.9634327580852, 12.032691259537975, 43.41247143283967, 84.45154020863195, 64.13117985571584, 87.99502511178294, 31.329986664556692, 3.2830115768217274, 0.7683864944884855, 0.4306214543119554, 0.6696761267319803, 1.1899717272289339, 2.7276588736041902, 10.703825585303768, 26.204309809592466, 22.412142715146466, 18.76339512486612, 28.914296934681555, 63.3930564695789, 41.186840149664114, 52.49387625725039, 69.25675669024068, 56.00124005348452, 48.72462364935106, 69.98040260807161, 42.94021414172265, 0.7694837775441908, 0.4286124653393223, 0.114699074728114, 0.382286056034988, 0.13119778175267482, 0.24710375905757953, 0.36626090626082114, 0.2660802319165199, 0.39454416762436595, 0.21873225968691612, 0.21160834679199805, 0.15644342788765508, 0.21597440444654037, 0.3987509709212088, 0.3814693143771541, 0.17675007453128216, 0.2321036962131339, 0.4199961518808719], [0.0527368568544907, 0.013231495245089455, 0.0702213964635326, 0.2065188416670407, 0.07181684351375989, 0.08713102538979824, 0.048772983868876775, 0.1225921092554927, 0.23817558652691304, 0.09720625370861062, 0.038545418966321215, 0.023712782722507274, 0.07745386401732123, 0.07731892529033846, 0.05208216577527985, 0.08102963303005503, 0.11361794846673166, 0.14955628212661515, 0.20618577728108053, 0.13599942167920454, 0.07704072046063601, 0.054868297320940805, 0.6038566714813632, 6.1028402659200855, 77.25264949183311, 64.89182549138224, 64.40904055872272, 86.9796960584579, 68.31512112771311, 58.0499489076676, 29.64387151502794, 18.243198625503048, 19.541569832832582, 48.02194672246134, 47.58643419511857, 63.883752822875984, 58.76218857303743, 58.459718919569454, 63.63406258244669, 58.004084633242705, 15.748059326602569, 0.7327524356303677, 1.206243679888787, 8.561251471119544, 33.09902660308346, 37.75036927192442, 68.976487651948, 40.049031165338334, 22.593009087347216, 42.6911554028911, 33.28528035071589, 42.091923144555864, 56.38838975660263, 68.57266395322739, 89.30716776078748, 90.53122966520249, 87.48152409830402, 66.14698394652336, 71.103134001455, 51.6155908953759, 50.60728680702948, 47.57867574691773, 55.45504608461934, 62.9908017189272, 43.7333958379684, 32.45715229741989, 35.89565692409393, 34.520148384955625, 28.139811215862153, 40.03871140941497, 53.486471253056685, 40.05163561913275, 28.15506139109212, 8.395091045287348, 7.721867196021542, 0.5970546074451939, 0.7506749706883585, 0.38442417678813784, 0.08718182468005727, 0.13435761864867904, 0.211907044473675, 0.47551163261936563, 0.13296824158920398, 0.6745505909765921, 0.49371360590861696, 2.849616639075741, 0.911481054800172, 0.4726133687842277, 1.2050190423765492, 0.9404385041806006, 1.6926422186436194, 6.309140266910677, 1.5273720482664725, 5.196814921594435, 4.4317806440015, 0.23439439103728343, 0.5235652637577827, 1.2441753283623727, 0.9682002435288123, 0.6813384977079208, 0.07025793885752078, 0.20488244721726065, 0.1352192224153588, 0.4762927971539959, 0.5915622473243745, 0.28616203175437066, 0.18164965113805187, 2.7322509884834294, 16.582394530696256, 36.223025783415764, 47.33158603791268, 46.539828162039484, 26.100435641504106, 23.319071185204294, 25.005304005838212, 19.49056725348196, 16.959457858916252, 27.342575750043316, 36.680154492778165, 41.93213755084623, 38.501087388684674, 52.21470548260597, 67.66585119308965, 69.10166617362731, 75.64829810973137, 71.36599556092294, 69.20994712460426, 71.89532726041733, 68.23232773811587, 72.9426000964257, 62.78484982828941, 71.91102458584693, 70.51906170383577, 52.59956059917327, 12.546405061598747, 48.03529062578755, 49.94513188638995, 42.921963353310865, 63.190948501709975, 22.78613482752154, 0.5152831178519034, 1.24863714700745, 0.5528725395279547, 0.1722309678312271, 0.31517727480780694, 0.4384050301967129, 0.890413698169493, 2.187600962577328, 3.6761853050801063, 12.656572672628588, 22.71561649537856, 45.79128303835469, 36.22363767316265, 38.1079678381643, 25.935968698993808, 25.487528039563088, 13.964728232352966, 3.011911078806847, 0.23782559159782626, 0.11851060729954513, 0.1264592215058304, 0.034291037778940894, 0.05986300672614767, 0.05672107713537351, 0.15274334578744828, 0.07556950222821006, 0.23582470783543205, 0.11205444728294689, 0.06434252966315517, 0.1150477136815748, 0.09627451459246297, 0.1375866026407288, 0.14394577592611313, 0.061694991083875786, 0.15548233994312827, 0.04581894117197202, 0.05125488657804747, 0.004720052041398783, 0.06811945804304655, 0.2934227373090483, 0.13374255729779122, 0.0863101621789317, 0.03231336265021274, 0.18981719029045876, 0.13991826784706887, 0.024654297120568734, 0.09735276802412926, 0.04274167706288638, 0.02250862848614493, 0.11462578309639809, 0.04532469954762248, 0.10881074674187169, 0.3173049767651866, 0.41847185141617255, 0.2704726123521405, 0.050431162028783755, 0.04224003119874866, 0.01680100914992152, 0.5722544414381827, 9.63367062230264, 93.11151381461852, 74.1326315172257, 81.32934139620873, 93.69741393673806, 78.2899751970845, 49.95704804697345, 21.34461475956825, 18.524456101079142, 35.192179833689046, 56.739626238423014, 54.06728013869255, 63.196388829138975, 63.785022843268614, 63.613332856086, 64.69203172191497, 54.812726589941214, 11.449255366479198, 0.7197299215101427, 1.6587638494468506, 13.764912889849755, 39.851100521702925, 29.510354034362305, 60.83830302761447, 59.094527075367594, 38.046006156552224, 32.01091601002601, 29.881488700066846, 21.893817186355594, 32.729553061146895, 43.24122075111636, 55.51643117781609, 62.242923398171705, 67.99147852005498, 52.748190972112845, 58.38089889095676, 46.22588557581748, 45.52113763747677, 57.18954955377887, 59.38473147730674, 62.10412248488396, 51.59968960669733, 36.86101498142366, 32.217968125497144, 34.07501036121, 28.009898393384873, 35.709536537047356, 62.06296897703602, 49.427092690621656, 39.59595034199376, 22.35821012527712, 2.8914712705919823, 0.6271229456028631, 0.6702984352746318, 0.37834005971108714, 0.22385623876846608, 0.20483583842794742, 0.35526687039002297, 1.7843938114181643, 1.587427825697007, 0.5347089012784343, 0.25575246271346846, 5.420845506652709, 3.3208166062831883, 0.1765786087320697, 1.9153070834375199, 0.9370196069921217, 2.8901258976228776, 18.60833206484395, 6.19916191024165, 4.367094386008478, 1.9417507225467314, 0.5316458366090252, 0.40286394376908585, 1.9438184244978813, 0.7988196130721801, 2.920736319595768, 0.5268226083247892, 0.42384647914478857, 0.24453704275431173, 0.25121944385670847, 0.47632904843457285, 0.4739100798483818, 0.10241499275810297, 11.018341818163472, 34.560387980553415, 43.81473795060189, 43.193320766572036, 46.56993235311201, 20.08089965389621, 18.023528245187578, 19.71267734804461, 17.105311193773826, 27.94540874419674, 35.75424763464159, 38.73850453284479, 44.21500405957622, 47.77106408149966, 55.75549963981875, 65.02236197071691, 67.40904577316778, 77.23953308597689, 71.69356838349374, 69.85221170609998, 73.69164728349256, 68.14369786170222, 68.87488257500434, 62.78334756051341, 66.05305102563673, 60.232743986191295, 34.172767593014626, 13.045115797750412, 61.46296401177684, 49.196590685075336, 44.41488804355745, 52.866517113101104, 20.954340888607888, 0.9467595262873558, 0.661138536468629, 0.2939163124369037, 0.47306321561336523, 0.5237455089246074, 0.4140650378840585, 1.4955268151337102, 5.684460651489997, 4.619240520461913, 12.791392380191436, 31.705233935386907, 37.89094309653006, 38.38382421001312, 50.75241450340518, 39.283380585332075, 41.86480614446825, 28.061102974799375, 3.6642372752389605, 0.3463876049124426, 0.12918284793774928, 0.05738274727557456, 0.06695961624744438, 0.12508112892147996, 0.043779714708967556, 0.1804945131223048, 0.048758332437324914, 0.11513038989036314, 0.11622239460027027, 0.10594383122459536, 0.13595676590358058, 0.2827356269042338, 0.14672071492720037, 0.21526445544535117, 0.06297599734558214, 0.10385765123271173, 0.09384973139892663, 0.20638995503465976, 0.12791256690698286, 0.21558501727638707, 0.48102403360028423, 0.22216680039080883, 0.22338786793331947, 0.27195318451812195, 0.24745615950274855, 0.3443396067427051, 0.23963147533997414, 0.15280087899056174, 0.133154523528872, 0.16852155478010256, 0.23587710824945282, 0.3235638538195241, 0.284469835460186, 0.5090021774653466, 0.6429714661452078, 0.4024194289119013, 0.19852690518863741, 0.22426684657412194, 0.29488354440658326, 0.8627613561768687, 18.532163558467744, 120.1835793833579, 85.17840247000419, 93.23631578876127, 104.40699069730698, 96.8359298090781, 78.4195310838761, 45.02505194756293, 32.40998971846796, 40.207769486211966, 71.89597837386593, 69.9004960829212, 70.05051889727193, 73.38289399300852, 72.38966357323432, 78.82138575277021, 73.59844392345798, 17.41824180849137, 0.6890438100503338, 3.1998605160943927, 7.4568218569601745, 39.01803224317489, 45.5998949081667, 78.60565539329284, 58.59836686042048, 28.754230891504598, 46.97703907566686, 38.69377774576987, 44.90237589805357, 63.97223757159326, 77.40598278660929, 102.25272301704653, 99.11730581714262, 95.79404630968648, 74.77667685477965, 88.24679420840356, 62.74602620832382, 58.29526178298458, 58.28064310935236, 67.06478718788394, 70.79683611469885, 59.120304892140055, 34.81036847637546, 41.76599379508726, 42.6407725580277, 35.53342603868054, 48.707404444294596, 69.3849789711737, 57.59962158818399, 44.479336507858775, 38.46045947843982, 11.923805282961938, 1.0274311587695153, 1.2611448500425586, 0.4404170222340092, 0.26107605366456893, 0.44057961673505847, 1.2397792094176816, 3.476480524386129, 1.8199936108243082, 1.088715250934324, 0.5951718697624823, 5.87528984392843, 3.8803672261776465, 0.46273215223223935, 2.443064931900271, 2.0140254185084374, 5.559884213632153, 24.567775380226877, 7.718769994474227, 14.32177080262092, 7.6348866762653484, 0.7313772158757333, 0.6259384510978576, 4.235963667592695, 1.728512661591653, 3.4979483917836225, 0.7695641861327234, 0.5941022271590849, 0.18993205751382536, 0.5635998542270353, 0.6558474429672765, 1.35275352145395, 2.5418108461364626, 28.681241466153054, 43.33754239543792, 50.05627224522252, 44.92314877048616, 55.7624069336922, 29.069309003891487, 31.71552819590415, 32.53803549274322, 24.948325695530063, 26.41245822752676, 34.660530013422814, 43.862912501058275, 50.9260303743424, 49.21220564073133, 58.340059172722604, 73.21212184044623, 68.24796230562272, 74.13427106795773, 65.11035642316266, 60.44524623501686, 69.1352024386006, 65.01314440081197, 70.04970304427609, 67.37263048848799, 81.12832776961788, 92.36396497295749, 71.27065843151462, 14.497694988404552, 62.92184252892772, 64.66250804162794, 50.29761568192513, 74.95022604542395, 29.554839595671627, 0.6505614362897412, 2.557579999969852, 1.134970536635768, 0.29963767156004906, 0.44951192614051605, 0.5879718077278907, 2.7629879068943763, 11.608184902898728, 8.186284649756647, 25.93112261064591, 27.494006695285922, 59.06385021824991, 54.44276471291819, 62.523659198514885, 48.355567839837846, 66.76871884253718, 53.07807407071514, 6.648496870071658, 0.5598620806009539, 0.33874786969634796, 0.21852941492632513, 0.2700949310054702, 0.25209456141437253, 0.19870155791361488, 0.3905814399401988, 0.19471590887875329, 0.2809698555258013, 0.2046138721127664, 0.1698682913857122, 0.16757145253640993, 0.483688211609279, 0.20358507731749168, 0.4474798013125697, 0.2030860016783399, 0.3708391396268722, 0.15054493391465756], [0.0802973066005976, 0.04879574817154677, 0.060684892664393114, 0.043086182971995686, 0.0552203530265439, 0.03212356245175245, 0.08500906143097148, 0.08635500130513984, 0.0699661436280416, 0.04307463802697678, 0.14631922356784344, 0.009040822887102203, 0.09679394518776287, 0.017734561979229894, 0.07889818490272568, 0.10594687259365475, 0.05297757700205811, 0.05916919919752306, 0.12138222659667655, 0.02640751423314214, 0.25521226347454135, 0.010634010935562753, 0.08233244981496565, 0.048472554828490944, 39.39089667412543, 90.77060407207858, 50.55251482994326, 72.52225537453928, 75.41894143627536, 59.52253610857072, 40.72495360528269, 56.380301829307314, 20.637252561507687, 23.760688881720267, 23.23536780572707, 39.933058446453465, 47.946307736058394, 47.01309742466096, 22.662109482672907, 0.7150990119384182, 0.10148095537818248, 0.18496282819298007, 1.2468226830805502, 18.946407033551125, 50.16324312456193, 52.02627874189808, 70.45165185005435, 24.27174233621167, 25.92981253900836, 47.85386923820742, 74.49142640636813, 117.20095419114637, 108.863964234629, 100.72399493186705, 97.01599013420844, 97.74942628798946, 81.41761825930688, 85.8459428048903, 75.09433392555484, 66.90731187020579, 64.65289823470577, 50.282294904032064, 46.90115690231324, 44.12913160939371, 32.90699128181704, 26.430965931184833, 29.782193899154667, 28.01325398106729, 26.48058979741989, 42.526819859781575, 51.08881265886369, 42.251751884337395, 29.82728546665561, 5.5886096915891095, 3.4489947605517606, 0.14540793133839486, 0.23392985064175822, 0.3188207889756849, 0.11642811985145654, 0.2739688537774548, 0.3081607061528391, 0.3506723346729433, 0.6082715442584408, 1.2638157389817701, 0.2718826431420542, 1.6169716081311627, 0.9925996536208738, 1.758824983431447, 2.365744474434084, 1.881190185104647, 2.0340177392767322, 10.39674420510569, 2.0352417639186307, 2.759517099588148, 1.2471737352109726, 0.5165250995947469, 0.39021920292608203, 0.2444269865631096, 0.4717166475470989, 0.6708172913039885, 0.4209043337933479, 0.2178187611242456, 0.16736110011416097, 0.3346300551727895, 0.30258940833230175, 0.49734749801216593, 1.282053411968293, 2.4349956358632734, 16.632189020033806, 33.56068957236506, 44.52354946444112, 44.56294182808169, 20.408584264016923, 18.282567454922585, 27.86249964467941, 21.422285533720448, 12.52589302678262, 20.821031293561383, 33.96343854165847, 39.783016020251864, 51.90426165057767, 65.43069247276553, 66.80366716077252, 74.91577979057067, 69.46141812109178, 77.66316475406771, 69.2471625727992, 70.08185863494873, 65.55955017766645, 66.19700201096074, 57.51465912788146, 59.43629887796218, 63.491084344925426, 85.21165632432508, 42.37136456274217, 27.64486889685354, 59.17727731889295, 39.74150557671824, 47.73316221852457, 71.09156300944667, 11.430853566815777, 0.3280025366092882, 0.7641978934407235, 0.07879928295170108, 0.21528694778680804, 0.19522178737867266, 0.014803916565142574, 0.8284601064458971, 1.395568765940205, 9.316592101127872, 20.749189161485244, 29.51537270699778, 45.290412056830625, 32.04343245875451, 25.263992163442797, 18.479140958478375, 2.913566226920774, 0.4243767039189416, 0.15050394821070856, 0.0657178336874612, 0.1021089023279567, 0.03989269949435707, 0.04196983581829456, 0.040897308893862276, 0.023422025542165485, 0.12037973159984236, 0.21218521099898124, 0.1672803544469418, 0.0749839122797693, 0.07907282230594466, 0.08588718971417797, 0.07952888976902732, 0.13345109148611947, 0.04861745652892897, 0.1360757853234968, 0.07928187237872232, 0.01580857576036285, 0.05439457536164311, 0.04459656744955048, 0.09543803850969962, 0.048854886328861605, 0.02298638006792434, 0.11631687622397177, 0.0753739812681752, 0.12432728308222948, 0.12930822588743704, 0.21006487880743321, 0.10032697415520107, 0.06751550496706078, 0.00092671758935584, 0.10746149736787043, 0.14039776227887601, 0.08866028244336767, 0.06112620910449375, 0.11630471840861345, 0.10097060292478531, 0.25469982726199014, 0.04714935244391522, 0.03688365551492861, 0.040464844599726706, 54.3940527977482, 100.8681106567383, 64.95491681560394, 83.91712511739424, 88.76357432334655, 58.800215951858036, 43.35793087559362, 76.28929184329125, 42.58745578027541, 35.6965809483682, 32.1452199259112, 49.17103644340269, 60.58552588185957, 54.45068005592593, 23.770063346432103, 0.8244065820209442, 0.1624782089023821, 0.2332212193117988, 2.3326342769207495, 33.70214985262963, 52.56805612194923, 43.45569987450877, 65.0145996001459, 43.50356455772154, 24.478000171722908, 29.086283060812182, 47.78996990573022, 82.2532949139995, 90.46265878985005, 84.2120873543524, 85.13983772646996, 87.7665941176876, 79.65787826045867, 82.15893837713426, 71.91522936667167, 63.372636610461825, 64.72442265479796, 61.972609335376376, 50.59395859318395, 55.032041995756096, 39.69389584756667, 28.666061893586193, 25.296420358842422, 28.48155752305062, 24.331287837797596, 41.964148013822495, 59.136920052189986, 48.09750333909066, 45.44301579075475, 26.706602650303996, 2.0591806019506147, 0.08842710060097518, 0.2156976628447733, 0.14421651139855385, 0.02531443891536084, 0.421774119379059, 0.5122067538961288, 0.27548086619184864, 0.7193514127885142, 1.349170681449675, 0.20601906122699862, 4.185452365106152, 3.0231896090892056, 3.12592530923505, 2.621290813530645, 2.239556677879826, 5.440159257381193, 22.268907562378917, 11.176629066467287, 7.922908769499871, 1.3997585927286458, 0.7808745243856985, 0.36316569654210923, 0.1893051371218697, 0.6253839260147465, 2.091401647175512, 0.4416209753722914, 0.4913446475421229, 0.16690245859565275, 0.3424954492478602, 0.5070407778745698, 0.5582955840133852, 4.423830980254758, 11.174765940635435, 34.14669559847924, 37.80878513090072, 44.69576112685665, 42.384269160609094, 17.485355523324785, 16.153476488205694, 18.391197496844878, 18.450593948364258, 18.825219523522165, 25.05971904723875, 38.00602935975598, 41.59226025304487, 56.26784747646701, 64.36692607018256, 64.87309225143926, 73.05841199813351, 72.96746007857784, 82.04427965225713, 71.54788371055358, 71.5167793150871, 70.84482239138696, 68.40917956444525, 59.36784175134475, 61.80802668294599, 65.23657045056744, 79.1178463351342, 36.54584861570789, 30.094959774324973, 63.58469563145792, 41.4686938255064, 50.06910624042634, 70.78261360045403, 14.374482554774131, 1.1382267167491298, 1.1364339484322457, 0.9971078052636116, 0.9038668762772315, 0.5690730315062308, 0.058968009186848525, 0.986008845990704, 3.4539886732255263, 11.500791388173258, 24.03065973712552, 25.796906948089603, 52.10781697304019, 43.92433289558657, 40.48365723702216, 36.69046640396118, 7.55266938478716, 0.2150544401017889, 0.5337834057788695, 0.03692592058571116, 0.06283192302010233, 0.056600111852129625, 0.021795343172045487, 0.18335952874152892, 0.01917926782381631, 0.17802654555247677, 0.09129880416777827, 0.16393788218978914, 0.058378860759999485, 0.04292902386476917, 0.14810425439669242, 0.05197796249581922, 0.10375439790227722, 0.10183219903058584, 0.09086355131359831, 0.05448000565651925, 0.23170810373079395, 0.30748458759438607, 0.16759633507219054, 0.19991582259535792, 0.18085773072896466, 0.15329289129905163, 0.23349051453894187, 0.10062396346080689, 0.17547447685032122, 0.16908104411296307, 0.2295632873691859, 0.3635502420365811, 0.22054295446122849, 0.13916114315150246, 0.16806263746994157, 0.24812881534378378, 0.18162170425057414, 0.37199801615168976, 0.2942748722289839, 0.33647562226941513, 0.4817533799477162, 0.15840916353608334, 0.27959368582214084, 0.21739940459449447, 73.07912211264335, 115.05817121075047, 76.07576585585072, 94.37158307721539, 96.04383068699991, 85.42864968699794, 57.545849815491714, 75.67819441518476, 48.87343445131856, 48.85057095558413, 51.86745805125083, 62.332577013200336, 77.8937687412385, 71.04524766245197, 35.27312186456496, 1.7982560804774685, 0.1776541961777595, 0.1598834997463611, 2.1139871449239793, 20.257506332089825, 55.14050729813115, 62.55820351262247, 83.81893250250047, 32.450790213000396, 31.30603078872927, 54.79786865172848, 88.00861220205985, 133.97377783252347, 118.14246423782842, 104.49112553750317, 89.6228087332941, 99.02596950531007, 84.0725294236214, 88.51398606454173, 81.47266480230516, 69.84528480037567, 73.56133830162787, 67.1795714286066, 53.457747736284816, 50.39330190227878, 37.464110774378625, 27.15168379968213, 29.570144684084003, 33.16928801998016, 32.246752439006684, 54.49252782329437, 65.92722139050885, 49.51604420138944, 43.58152950963667, 34.49726135500016, 6.594800603005194, 0.17175234673965364, 0.2624895778154173, 0.3457864403965012, 0.22662002352937577, 0.7161608098014709, 1.095955455976148, 0.29889717097243956, 1.4980083271380396, 2.594343395002427, 0.27494135643205336, 5.06195402914478, 2.596045948805348, 4.365565151937546, 4.19322258041751, 3.6750313928050384, 7.306920145788501, 28.051567692910474, 15.64103549526584, 12.099388222540579, 4.459232822541268, 0.6701088744786479, 0.606365517502831, 0.2243023317667746, 1.426249300279925, 5.49763668929377, 2.160020816710688, 0.8601624795025395, 0.4350281759135185, 0.38409855877680166, 0.7685063719268769, 1.089156272430574, 5.076557013296313, 18.98957860085272, 37.88370632356213, 44.29278466009325, 47.18889021104383, 49.48858761018323, 18.53563681725533, 24.603651339007964, 37.75819832278837, 28.078781097166, 18.97602092835211, 24.91608185152854, 39.10300254821777, 48.7182144964895, 58.854383883937714, 65.86713067946896, 67.1637721215525, 77.87549834097587, 72.93426113743936, 81.54118860921552, 65.57666347872826, 68.60739261873307, 66.33124120773809, 64.25316164570471, 56.74625504401423, 63.04726423755769, 67.79279478134649, 103.12746647865542, 58.58323043392551, 37.064064318133944, 71.0419136478055, 48.10383796691895, 55.71369894089238, 81.85757483205488, 16.668280709174372, 1.5365353178593422, 1.6989085727160977, 0.6368018230122905, 0.42797596884831307, 0.5511829785762296, 0.40205719189778455, 1.9103178285783338, 4.868575296094341, 19.051230415221184, 28.607475411507394, 39.791606010929236, 63.951978529653246, 54.22249617115144, 54.66773225415138, 61.047883110661665, 14.823859680083492, 0.5975338107635898, 0.946446226969842, 0.15087490330540365, 0.24194256342466802, 0.11883226463631277, 0.13467137761894735, 0.2903742589537175, 0.281982746335768, 0.3362922208203424, 0.3430659089597964, 0.29834472964848247, 0.14022621987087114, 0.18742282844839558, 0.2873034108309977, 0.17364338881546454, 0.24833135366920503, 0.24150751741422763, 0.4992863746179689, 0.2820294164121151], [0.08726094624087696, 0.05203359197044084, 0.048542559943011696, 0.013526096271591322, 0.08153911214321852, 0.04092098101072254, 0.024442232491809036, 0.13737543816528014, 0.08662543034241085, 0.033377512403193026, 0.17347163190284084, 0.041097495329356006, 0.003676399689040057, 0.054806431890615535, 0.010638323052966548, 0.12490168814697575, 0.07388109806925058, 0.1051196508530167, 0.08772370931241782, 0.03487930903511663, 0.2786545846010408, 0.05024436681020645, 0.09107698340930286, 0.17251394538869783, 8.790767000567529, 69.99637449941328, 63.39987747130856, 58.487049994930146, 87.81439996534779, 66.77399835278912, 48.91695707075058, 45.34649018318423, 28.14913861213192, 11.450163395174089, 20.938747505987845, 29.87521290779114, 16.724584371812885, 4.519601531567113, 0.09973959156101751, 0.06313303387874077, 0.3964685804901585, 0.9523994655859087, 2.078699786816874, 30.875393767510694, 37.7877769162578, 67.60880424130347, 57.34187087705059, 16.44155300432636, 62.50764023873114, 92.75224039631506, 114.7598514249248, 95.1322953931747, 86.96122953968664, 80.53838760622087, 71.55758765435988, 72.94487507112565, 67.60055941920128, 72.087186075026, 79.05373127229753, 76.50950939424577, 79.78243704765075, 62.60750378331831, 51.633469058621316, 28.57783602130029, 21.03436116249331, 24.79427068464218, 24.534580361458566, 26.84538395174088, 23.00880385983375, 35.81775865247173, 51.30645321261499, 40.81639974348007, 30.414450553155717, 2.027594735545497, 1.9243062263534916, 0.46090233590333696, 0.34519229324594625, 0.26735880201862705, 0.0828352639631879, 0.06254280909835812, 0.1620011046648987, 0.1072647813106737, 0.35014520489400436, 0.35111528671076225, 0.5336407908508854, 0.9888797758087036, 1.3751668026370387, 0.8107213712026997, 1.9068826903258602, 0.08659517753028101, 4.960152833692489, 15.97303863494627, 4.595467034847506, 11.149737296565887, 1.315173170258922, 0.2187141800119031, 1.3791753423790778, 0.175572658678697, 0.06715034149707326, 0.41055828573242314, 0.056840165503202915, 0.6889140653994776, 0.32590394599303124, 1.380890398736923, 0.19325036735784626, 2.838601152743063, 3.6094748589300343, 4.897200263315632, 12.706149470421577, 29.78138589089917, 38.01635696041969, 40.48832093515704, 25.354779343451224, 22.1078432759931, 30.34899796209028, 17.82531911326993, 23.45496169982418, 33.955997805441584, 39.5112467581226, 58.648949746162664, 62.1585649828757, 65.32382357505061, 62.11956877862254, 71.03075058229508, 72.31442466858896, 72.09703906889885, 71.49332354145666, 67.66198373609974, 64.56295828665456, 61.3606176068706, 60.454420658849905, 60.33352536539878, 60.64473013724051, 60.82179769392937, 72.6397538954212, 36.028817469073886, 50.811234366509225, 61.686307691758685, 39.0988762147965, 70.70464472616874, 29.258900688540553, 1.0451442147454908, 0.40487673253782336, 1.7839382036078362, 0.730378850092811, 0.28689713908299325, 0.21632937894713497, 0.033745272911243865, 1.098934373547954, 5.725051299218209, 38.19819804160826, 40.853791698332756, 42.984862481394124, 25.167250825512795, 19.16423389988561, 3.359814036277033, 0.26728639138802407, 0.05271125419606125, 0.13422257266938686, 0.11116766986707527, 0.10700084103812134, 0.06565506044294565, 0.06573556862290829, 0.10642244465528958, 0.1221322573180641, 0.01843626787435384, 0.036828895550101035, 0.030629269651047168, 0.05272361885515913, 0.04052987014273963, 0.08081205639868014, 0.09445451951074986, 0.05916900001466275, 0.07396981105088227, 0.027206591818661943, 0.047473189300827445, 0.07526652211503637, 0.04223922297598855, 0.004889853993400691, 0.0838895388428242, 0.04464121505377754, 0.027174232264740333, 0.03451864633168425, 0.11220644678800337, 0.20598421954820234, 0.06171182969645147, 0.09342632226405606, 0.04846858649304317, 0.11335821401688362, 0.04545766942863984, 0.05996199294684395, 0.1991497499928359, 0.056336807432554425, 0.1349623071690721, 0.07146734654182388, 0.14176480021447907, 0.2669886896206487, 0.045141202337559194, 0.056500420830543005, 0.223899997710701, 12.939895276100406, 81.42523550218152, 72.35790021957891, 72.3212182137274, 99.58398157550444, 69.89989203791465, 52.03284086719636, 66.60720348358154, 42.91712314851823, 21.87652345626585, 27.620344277351137, 36.009797896108324, 19.08330951967547, 3.7294655557601684, 0.20461964841571548, 0.10914491429444283, 0.4183564785747759, 1.2057956716706677, 5.26050832963759, 41.39228605454968, 35.24114670292024, 59.38878328569474, 69.689299983363, 23.048462944646037, 33.72541735249181, 66.67341309209024, 98.68666879592404, 94.52584205135223, 79.69142237017232, 79.2083824834516, 74.25663332785331, 76.95027397524926, 69.34544147983675, 74.96939074608588, 79.0979834525816, 76.07580507955244, 81.11608997468026, 71.72897169666906, 54.71833475174443, 38.81256280406829, 28.570030504657378, 25.483095761268373, 22.456028153819425, 23.87939549261524, 20.124789014939342, 40.46662630573396, 58.039633074114406, 45.43181350154262, 48.366177851153964, 30.28176461496661, 4.57357628691581, 0.6547891997521924, 0.41648492577575874, 0.3033233818507964, 0.05234954578261222, 0.21680875080487422, 0.6145850893470549, 0.4518921000342216, 0.4783132468019763, 0.9606127248656366, 2.436452796382289, 3.2046551233337772, 5.240757724931163, 1.0677900189353575, 5.483269047352576, 1.5714316646898947, 8.627030599501825, 20.834771356275006, 12.152299034980036, 18.633572516902802, 1.029105030240551, 1.3424391587895732, 2.1825217383523143, 0.12813657101604248, 0.06023803740859993, 0.31439102344935943, 0.06357640726491809, 0.1878167661808191, 0.16383197819513662, 1.5289756847966103, 0.22396641753373608, 2.080357723659085, 8.632925921870816, 13.683518805811483, 34.89968868993944, 37.077023829183275, 41.66649110855595, 45.217871742863814, 20.536071100542625, 11.3917455750127, 29.50896747650639, 20.63140822995094, 21.845728928043, 29.54713409946811, 41.308339488121774, 60.71794902124713, 62.448408526758996, 65.2078547785359, 66.95326635914465, 69.37134481245472, 73.03420312942998, 75.2072197391141, 73.72810179187407, 69.14111737282046, 67.86815135709702, 64.66395931859171, 60.837098859971576, 60.598881552296305, 63.14057350158692, 62.10579341457736, 74.4387254407329, 38.240740068497196, 55.36966393070837, 62.77764835665303, 43.562545238002656, 73.86315684164725, 36.19789908009191, 2.481529654995088, 0.6060232294182624, 2.402405397545907, 1.374991889442167, 0.2928889885304436, 0.19754752306447876, 0.03468778322360689, 1.1218117201520552, 7.987634251194616, 35.898673226756436, 39.247173186271425, 53.93808510995681, 36.77607997771233, 40.36018886873799, 11.693141479646007, 0.9053155791855628, 0.11068221527121722, 0.23085583091503192, 0.08105723517796687, 0.10483232191613606, 0.09223187627691416, 0.10118621837107405, 0.17628875170503894, 0.024778874508375605, 0.1029170714619179, 0.049634691057426315, 0.10951465130933832, 0.015796853657511455, 0.03141481237816474, 0.10798026146667619, 0.08224007493305592, 0.09980031168989598, 0.14094421279526528, 0.061701108295951164, 0.03616793021079033, 0.1607192097412002, 0.28170324681747344, 0.16305415380385616, 0.186837338091385, 0.11437132699234832, 0.15225067464334352, 0.28201786380621696, 0.17018707589276377, 0.23807634749720175, 0.11181661528685402, 0.2557766404483588, 0.24761380507580696, 0.15884781015976784, 0.15722306024643684, 0.10355041167067905, 0.2850258314321118, 0.10155027867445063, 0.2949385495195466, 0.2106955377084594, 0.1946560620901085, 0.5342784824390565, 0.18945437104951954, 0.204674469667577, 0.2567028101052969, 20.422616543308383, 100.83116977445542, 83.65869583622103, 85.27119005880049, 111.99913040284189, 90.66965010858353, 66.90946132906022, 57.001577808010964, 48.12380675346621, 31.15044213110401, 41.41310207305416, 52.67628215974378, 33.2008199537954, 7.329730689525605, 0.20921717187569988, 0.1692136692544145, 0.46339239744890126, 2.443642991204416, 2.1554755251253805, 38.71758261034566, 46.30642752493582, 79.13815636788645, 70.86850566248741, 20.28625338308273, 74.50819061648461, 107.14163580248433, 127.13747101445352, 97.53564142411756, 85.12976507986747, 78.17846221308555, 70.82961143985872, 76.73349242056571, 71.21607472819667, 74.73105184493527, 76.7270597334831, 70.42419525884813, 82.28734893183555, 73.96804886479532, 60.246739002966116, 39.11424013876146, 23.31410546456614, 25.23095403948138, 25.424636756220174, 30.835101219915575, 29.210514330094863, 49.604215160492934, 67.0228962744436, 49.09145547497658, 45.56808056369905, 38.856167793273926, 6.469897137534234, 0.4818727670898361, 0.5386614246714501, 0.3535913441690707, 0.17783542193712729, 0.26106799441960554, 0.3463265936701529, 0.32176434392890624, 0.386373472189711, 1.8106642533694546, 3.176735692447232, 2.619395082996738, 5.537303618846401, 1.285131491961018, 6.246665245102299, 1.0089583887207894, 8.015888064138352, 26.724567105693204, 12.477791040174424, 32.84566894654305, 4.162108869321885, 1.8253036420191489, 3.4013320794028625, 0.19818996439778036, 0.23932700135534812, 0.6418647448862753, 0.15158782472773907, 1.104481462990084, 0.3196343437077538, 3.115164286667301, 0.30939885745606116, 5.853596195097893, 6.255833785380087, 18.90171947017793, 40.96441038193242, 44.55253185764436, 42.67658772007112, 50.861350490200905, 27.274493209777344, 26.28709927681954, 42.20513843720959, 26.19382727530695, 27.1931726701798, 39.05030942732288, 47.90396967241841, 59.54860025836576, 61.55721072227725, 68.22571462200534, 67.09065129680019, 70.5415839533652, 74.70983966704338, 77.87101114949873, 75.1677450056999, 66.56976838265696, 65.73995959374213, 64.64322566986084, 61.230798921277454, 61.22732762367495, 63.09962787935811, 65.92373048105549, 82.63556911099343, 49.3018945570915, 62.5911828010313, 75.31333554175593, 51.62003494078114, 76.56149648850965, 42.216203443465695, 2.991094079709822, 1.1267600352725675, 4.056470370100391, 1.987006784446778, 0.3421614655563909, 0.5750303763535716, 0.14318151129109247, 1.7792409201783521, 13.166718098425097, 54.559384622881495, 54.428400993347175, 62.782990624827725, 50.39425896060083, 64.10049515385782, 28.716756566878292, 1.4668694883584978, 0.23360496807482936, 0.486971787026813, 0.25553020528487624, 0.1964222011907447, 0.20048704839521841, 0.21964758153884645, 0.2762557181619829, 0.1523277890538016, 0.18806298683968284, 0.14265931511838592, 0.25366715606181856, 0.15991454162905294, 0.17621680072719054, 0.2408186971179901, 0.2168747875839472, 0.2045558792568984, 0.2342378945961114, 0.27845322605102296, 0.1285961624835768], [0.06546915388636051, 0.08030655328184366, 0.0756858250186328, 0.022112176070109974, 0.06906441983676727, 0.02662035261070536, 0.18284004452007432, 0.054383095534097765, 0.03054045516276552, 0.06145704034415465, 0.026041389322809638, 0.09902315379510965, 0.05191678271418618, 0.028160106984057257, 0.059150686682832826, 0.08351884421802337, 0.04032591838509806, 0.03275868189971774, 0.040274820320548556, 0.11363628861163894, 0.032348028128786434, 0.08925603837856362, 0.11261427369449409, 0.04438842902140272, 0.9002795623194788, 48.1569194024609, 78.58456873124646, 59.39269388875654, 78.99491140919348, 77.32392680260443, 52.24244840683476, 32.001053210227724, 23.287070528153453, 10.059243863628758, 12.757951232694811, 4.477550291245984, 0.2531724011585597, 0.20111249789835947, 0.09897003325844005, 0.3550253688327728, 0.5532177693901524, 0.09188254018344226, 10.47770388664738, 51.80950503195486, 65.324333483173, 78.79488621988605, 29.335331993718302, 51.32040116094774, 105.06103807880034, 91.09936929518177, 84.93510569295576, 78.33751432357296, 87.80734754377796, 82.03910212362968, 76.26822087072557, 72.64610813510033, 69.6523198773784, 71.13704681396484, 76.0083403125886, 74.75730819086876, 76.83679196142381, 77.0097057281002, 65.52430375929802, 51.50245797249579, 33.28035777614963, 22.61633150039181, 26.677165262160766, 27.919046494268603, 28.79964605454476, 28.734701410416637, 46.62601832420596, 40.2546339650308, 31.524047890017112, 6.916481535280905, 4.195070997361214, 0.4096107269006391, 0.45660997590711044, 0.15760254956060843, 0.17778224011342372, 0.3349741818683763, 0.5366053672567491, 1.866389734129752, 0.1059048603318872, 0.04839221518787165, 0.6405135496489464, 0.8047235769129569, 5.0444234859558845, 1.6808282848327392, 3.5339493761139535, 0.9038937812851322, 6.176528363458573, 15.21972587031703, 8.666877958082384, 13.553774645251613, 0.3417624869654256, 0.7433699239646235, 0.34748911677349004, 0.040354979930505644, 0.07542811304090485, 1.357152827324406, 0.9127550896617674, 2.3823924843342077, 0.9948767733670051, 0.12881409917627612, 0.055152132896886724, 0.14991197674985857, 4.681994030552526, 10.388075767024871, 18.859987412729573, 33.87554607083721, 29.733348623398815, 36.51476775446246, 29.441022219196444, 31.963486709902366, 21.551629612522742, 18.190817333036854, 34.97618667541012, 59.31453674070297, 67.4583185872724, 57.229275318884085, 59.09027914847098, 63.891507348706654, 65.14595193247642, 63.429205033086966, 71.74575159626623, 72.27885661586639, 70.00774152817266, 69.15122139838435, 70.13332013160952, 65.96224815614762, 63.389891116849846, 61.443438453059045, 66.0890583838186, 64.1078652874116, 68.7392391697053, 60.3961891512717, 35.60327168433897, 62.05901522790233, 46.446409071645434, 58.47224696989983, 42.409639050883634, 0.8785558215552761, 0.1305420411330077, 2.4845930260996667, 2.8119856647906767, 0.2517024776147258, 0.09705127412152868, 0.09410693009774532, 0.11681065819556676, 6.783760786056519, 40.949779941189675, 46.61831478918753, 37.77473895780502, 23.185255604405558, 16.70317215304221, 2.8610368649805746, 0.1966494228690863, 0.22696061089875239, 0.13424920188563486, 0.04303172944233783, 0.05289652106922962, 0.15413079230535418, 0.05417153269292847, 0.019316370749185165, 0.036242980014292464, 0.14237480538506664, 0.03921178139505848, 0.11298028752207757, 0.04120512685227779, 0.025551725073807666, 0.012576079255180254, 0.04485985271692757, 0.04745713209793453, 0.05578582167565342, 0.15922651806425664, 0.018045315969615214, 0.042343418594569936, 0.02456081715682822, 0.1073002358598094, 0.06466601028918259, 0.08144024849659012, 0.06132493997293134, 0.08553210796127397, 0.026957935000198986, 0.06129741060337233, 0.042488680356332374, 0.07511220136356932, 0.09131043338246884, 0.03716061545175411, 0.05852848922293033, 0.020064691179281762, 0.023290105201604388, 0.030484371781048757, 0.050813175602665836, 0.00792366272259143, 0.06458788464266448, 0.020971926973171292, 0.16035709530115128, 0.09131515248408241, 0.10283890751100357, 0.8697094672149228, 62.01199777664677, 89.72930892821282, 76.52097055988928, 89.86950228291174, 81.47062516981556, 50.631079904494754, 35.39304441021335, 27.222782642610614, 14.77419953192434, 12.461332774931385, 4.51469954944426, 0.2774169848811242, 0.09125433276377379, 0.09218381958142405, 0.5844699278954537, 0.21055356629433172, 1.6693788862997487, 24.135028123855594, 50.55059286855882, 53.2437510644236, 76.34798619054979, 41.91146666003812, 36.79287164442001, 79.92710974908645, 88.05394695651147, 86.4652144524359, 77.91230586267288, 85.96831290952622, 83.12220188879198, 78.97843745446976, 77.22033700635357, 73.31263649848201, 74.11967200617637, 74.91018649070494, 76.9937103025375, 81.86771023658015, 79.51051481308477, 68.71817604187997, 54.69110565800821, 25.757997035980228, 23.27866881124435, 23.016846679872085, 26.960803616431456, 25.62538758400948, 34.633446047382975, 54.46542424540366, 45.819963409054665, 51.036033245825, 33.49115771632041, 11.325644812276288, 0.5846183650916623, 1.3566828783481353, 0.37564848639792014, 0.23986721591603374, 0.934305326832879, 0.687099417611476, 0.8061608191459411, 0.47844700575355564, 0.11055523619776773, 0.9448881267059235, 4.79573590140189, 9.931154943281605, 3.2146059313128075, 4.332426026944192, 2.6353659937458658, 8.769360665352114, 16.001412080180263, 13.945692969906716, 25.477724075317386, 0.11446892659390166, 0.7646677198429263, 0.3531756648613561, 0.025997519297825716, 0.8575537356157458, 0.15256492390988335, 0.726871760862489, 0.7181998907077698, 0.20417449004467458, 0.17977402275127752, 0.17448928777969655, 0.8381154496342906, 5.013186220199832, 20.101372465010613, 35.292859231272054, 49.69317451600106, 33.76750046207059, 44.04842099835796, 21.73900515802445, 30.363210670409668, 31.345917371011552, 20.841090294622607, 25.481664096155477, 45.9751872862539, 70.69831402071061, 55.69175327977827, 59.04120637524513, 66.72582380233273, 67.2844869859757, 63.711800036891816, 72.46636944432413, 74.40604425245716, 72.70565755905645, 70.65035127824353, 71.40055948688139, 65.65212595847346, 65.32475317678144, 63.07601913329094, 67.70587505832796, 66.5939772513605, 70.43436988707512, 64.21504797474032, 42.729935876784786, 64.82377236889255, 51.30565697147001, 62.75897787463281, 50.29061032879738, 2.4530203976938805, 0.5618705792773155, 0.3192982456136135, 3.4135220704540132, 0.8367279111858338, 0.18323163802344955, 0.12723811842020483, 0.13268458987435988, 8.732056963828303, 37.4199095849068, 49.27333185749669, 50.33927909789547, 36.0362111368487, 31.348682641983036, 5.712193769793357, 0.10567288124753584, 0.1266026178434972, 0.036430453220682765, 0.0643778463164645, 0.061824479095277295, 0.2107085918466891, 0.06361301477637983, 0.14231845195735657, 0.030378927439150792, 0.07119599819904374, 0.08402519003157655, 0.04172129774345987, 0.08126245481112311, 0.01075160255911009, 0.05387639732009942, 0.06327441540516673, 0.035552068298021634, 0.06523899043038969, 0.1987767111389868, 0.0288849180909775, 0.29482366697442147, 0.2748535627559308, 0.3039151694505446, 0.2285758460000638, 0.212621467428342, 0.1558396127074957, 0.17888421162722573, 0.21180106387023004, 0.1696206151597923, 0.1160459875339462, 0.24380755851105337, 0.3721475565145093, 0.1624040975565872, 0.17880948741109143, 0.1318532312589307, 0.2698878727612957, 0.18675210314892954, 0.17213756639149883, 0.11884364104198834, 0.20275488315570742, 0.07097551043355657, 0.28421310407500117, 0.21322342867572464, 0.16268260116058011, 0.8991976623092929, 79.95645692271572, 109.21154898981895, 89.27218021885042, 100.92385538162725, 98.23642776858424, 70.88455600123253, 39.583410524552875, 37.33130716508435, 23.57082066997405, 21.24892265565934, 8.630642121837987, 0.35169113968168536, 0.39550643534429614, 0.11822993566672649, 0.6215814945678557, 0.7324128441752926, 2.8027026403334836, 14.417392303866727, 64.0144540417579, 74.95345807844593, 94.85798835754396, 40.55138480278754, 66.05481609221428, 117.48779712184783, 90.73839356822353, 87.06848282967844, 79.16807620756089, 88.89957074196109, 85.30190221724972, 81.61478796312886, 76.78994317208567, 75.1421711521764, 76.206725951164, 74.79264874612132, 75.07244709999331, 81.64162481984785, 78.96487389841388, 64.11226618674495, 61.01976363889633, 40.93090941829067, 26.74480849696744, 29.23051057323333, 31.353915083792906, 32.660272236793276, 41.059119932113155, 62.94477662732525, 51.16345928561304, 52.84772895997571, 40.71545754709552, 10.413049497912008, 0.5724276385961041, 0.7715599983930589, 0.3371814037522962, 0.5514450419333674, 1.8862409721459112, 1.9039247329196625, 4.523068416503168, 0.4917992747599079, 0.175031800604155, 3.134128946450449, 7.374916393910685, 12.680174554547957, 2.9966665419840046, 6.222762321272205, 1.7425017948112183, 10.865456654179482, 20.722771998374693, 13.430419045109904, 43.49756725372807, 0.4396748668964832, 1.6638040951182766, 1.3565376280776917, 0.1172929258656598, 0.6489579223336712, 6.421002341854957, 2.040330671495007, 5.7822781897360285, 2.102089615598802, 0.3137677343141648, 0.8701871996445041, 0.64547338673184, 6.885744371721822, 28.853092270512736, 36.97766234797817, 53.085373601605816, 35.60435425850653, 46.15909937889346, 31.301067029276204, 42.20029038767661, 29.00631573892409, 25.48651802924372, 44.3254070128164, 67.06294367390295, 68.69270416998094, 54.33733140268634, 61.536320178739494, 65.3226782429603, 64.20502239657988, 62.00420402711438, 74.0529054211032, 75.54397090788811, 72.677353735893, 69.54465866088867, 70.12338869033321, 67.13771189412763, 64.75349526251516, 60.63115481407412, 66.94246415169009, 68.27181816101074, 73.45162960790819, 66.92354263797884, 51.48560354786535, 75.88526418132167, 59.03046692571333, 68.53955130423269, 54.841591312039284, 3.658777826255368, 0.9283365825972251, 5.524582882081309, 5.280204511457875, 2.7162489439210584, 0.34318005606051416, 0.3626083522554367, 0.227292143108864, 13.74581486948075, 54.39715147018433, 62.44817318454866, 62.71236442750501, 53.23123478120374, 47.561009391661614, 8.036877157226685, 0.387113482481049, 0.3193819024149449, 0.099010007726329, 0.13715169452611478, 0.17735929829218697, 0.30185721213779143, 0.17397580968756832, 0.2964922064735044, 0.14035633224393093, 0.279464615328658, 0.21442398038362304, 0.21810607473936774, 0.32259907333120225, 0.13357099956802784, 0.14819491324165177, 0.19346235920825314, 0.1829662651664788, 0.1889226600647934, 0.49040073528885847, 0.17004378680740634], [0.12362196125210294, 0.03469621019077397, 0.06435856388341035, 0.07413978297864238, 0.12815550104865145, 0.03200964517741194, 0.20839185003311406, 0.08883563230835623, 0.08625945481922358, 0.042857015430326426, 0.10498608342341839, 0.17312272481860655, 0.05325178285279582, 0.059070247450783375, 0.057578942392982786, 0.099239987321198, 0.09756017866874896, 0.008572826477428599, 0.058151213902859926, 0.039704728330815994, 0.15722690600781672, 0.11998622287665645, 0.059970473540165735, 0.27628679068819173, 0.2980466295153864, 20.627024981283373, 77.48143349924396, 65.02677463716077, 69.84359033646123, 90.72752860284622, 62.25614178565241, 50.50909419213572, 17.938595202661332, 4.477492436285942, 0.8931624829288453, 0.025711456321239955, 0.5376368280380004, 0.043443965184832775, 0.6000397150074283, 0.02959036632561155, 1.0718520009709944, 6.944993734359742, 20.68752754119135, 65.57172521468132, 71.83842151395737, 64.73344802856445, 38.88031782642488, 88.48841221101823, 88.9936056444722, 77.49010193732478, 82.89225685981013, 78.72769601883428, 78.98421902810374, 81.0018862447431, 79.29245456572502, 67.49212941815777, 68.0387979938138, 74.13310220164638, 73.02040423116377, 73.47283394105973, 72.42524731543757, 74.97209718150478, 66.9108106243995, 69.15076640344435, 76.01291379620953, 40.85921633628107, 24.70890618139698, 25.15882753556775, 26.225443540080903, 27.10758263064969, 43.586420705241544, 38.278751757837114, 36.288129283535866, 11.220910664527647, 4.662994069437827, 1.1465080659235678, 1.4575480982180566, 0.6343744887459664, 0.8501053385196194, 0.6585834800235687, 0.11164856623978385, 0.20864545577956786, 0.9778304590332894, 0.34636122084433035, 0.36373318383289927, 1.9142375021211564, 4.892382612151485, 4.137156711470697, 4.804106239349612, 1.4360046026206787, 8.56874123696358, 11.7648983001709, 12.190808865331835, 15.281788552961043, 1.0669454836076306, 0.13442344092313321, 0.13063918108180647, 0.09498829127199228, 1.6961349667079988, 0.4044928612007249, 0.23074968177224361, 0.6737097941579357, 1.3307225487885939, 0.06478286934115234, 0.13849006545159126, 0.3061171819365794, 6.660987167589127, 18.324915324487996, 24.2074135042006, 37.91888213926746, 29.61499502581935, 41.61875194118869, 38.8616120430731, 23.512673493354555, 17.240454496875888, 28.614796515434023, 62.671163851215, 70.35915451665079, 54.67269013004919, 60.3913724807001, 66.13300461922923, 62.0304839072689, 60.59557891661122, 66.07857781071817, 66.36619737071376, 68.26389497326267, 69.34166031499063, 68.8039190538468, 66.78073698474516, 68.78106732522288, 63.97977244469428, 65.35945438569593, 63.53999237860403, 67.88941060343097, 62.363618650744044, 73.98419334042457, 46.003946104357325, 42.2864217142905, 66.8237732302758, 52.850717806047015, 65.75133838961202, 7.3540047676332545, 0.4762645438313485, 2.3912754270338246, 1.1781079057724246, 0.7304112709337666, 0.21639316342771056, 0.08971013699568088, 0.062351838700593486, 11.55401893200413, 38.74760443164457, 39.88891217016405, 36.11689821366341, 29.66555633852559, 11.978627270267857, 0.27112914970324886, 0.03873244401127581, 0.10883434224993953, 0.011164592898210451, 0.08224176032648933, 0.05631487050484266, 0.15682498563922223, 0.06380898006741079, 0.07888463280734517, 0.08798501424251065, 0.07247286758595899, 0.06322991335764527, 0.06780978232141464, 0.00471814208844256, 0.005961057979748735, 0.01750308851290855, 0.08989231270407477, 0.03507406007678759, 0.06382758451265193, 0.054650383610879226, 0.03803148888231766, 0.08948850775918654, 0.03435717797988365, 0.05283352182877641, 0.03266632233956649, 0.13411616305670432, 0.015668197809117698, 0.1297370052986568, 0.12998385414961847, 0.06901037999458852, 0.09803323796199215, 0.11730469297617675, 0.040571537664941246, 0.02506284031926865, 0.08240404073148966, 0.019742007284695585, 0.11845294386148454, 0.10977862222540764, 0.0868069701978276, 0.07402404241504208, 0.09120148035787767, 0.1099752540129327, 0.06218625262619988, 0.027578096581442703, 0.27046780131997605, 0.29756905030339, 30.265924123025712, 98.42212846202236, 74.30499615207796, 76.8191962088308, 98.12932352865897, 62.94018745422364, 38.870696252392186, 22.731698213085053, 6.12675936952714, 0.26130529781503065, 0.0373286530075054, 0.535496010655357, 0.2329482315408607, 0.8829113684834973, 0.029393246157034755, 1.59389789787031, 12.081944461791748, 25.752821468537856, 43.75749880267728, 63.78187710239042, 68.01694254721365, 40.136743207131666, 72.26243757432508, 88.8771269398351, 78.7675629892657, 86.0645051156321, 75.84455782367338, 83.46445222054759, 78.18189036461615, 79.44983574651903, 70.03691611751434, 73.91718356840073, 75.00229158709126, 70.57437496800577, 72.41901074686359, 75.49786736888271, 74.4312572479248, 67.80198881703039, 69.55247202227193, 58.36799821546001, 26.278120971495106, 23.27422868820929, 22.846305947149954, 22.561100605995428, 32.24986876210859, 49.517283670363895, 47.460133875569994, 51.1607999186362, 26.965400634273408, 19.469107966269217, 11.891769324579547, 4.728056874967391, 1.0301979006298128, 0.25282828978473143, 0.181663915695202, 0.14006485111050068, 0.17190272979918989, 0.9637239611437245, 0.36156944509956146, 0.30214339194278567, 2.150317608348785, 6.326670810099571, 4.013936923396203, 5.674558627989985, 2.606004111228451, 9.237687741556476, 13.644323541272072, 15.759169440115652, 19.86234714907985, 0.8520626625226391, 0.06364741595461965, 0.9739522155254119, 0.3876566694628808, 2.315964693984678, 0.6774699375514062, 0.3512542244167097, 0.8139103807268605, 2.107260525226593, 0.39036843685373185, 0.308522789949371, 0.8534075451954719, 8.090020370098854, 20.479596814801617, 38.43975328630017, 51.7451899282394, 28.533095505929765, 46.41135092704527, 35.14500156525643, 28.754525069267522, 17.507057997488207, 18.863672479506462, 44.976351799503455, 67.81493263859903, 55.72110829814788, 59.631260287377145, 66.37296738163118, 64.53987121582031, 62.17268943786622, 64.09214050539079, 66.81228853041127, 68.71268472363873, 69.58025024783227, 70.49056960690406, 65.60604987605926, 69.00110444714947, 67.49836598673176, 68.24802506354548, 67.04252381478587, 70.29974629802089, 64.46980199506207, 74.97590188057193, 53.239483525676114, 48.131129818577925, 73.06608415419056, 57.4397300904797, 74.22395213957756, 11.002252255716632, 0.3467526611301207, 0.5908336670648667, 1.4761606027041714, 2.2919752328626575, 0.8671388438632412, 0.1625054816324865, 0.04068927388758429, 18.07981425716031, 40.93579669152537, 50.41398063782723, 49.69075441360474, 45.375915804216945, 20.578783750534058, 0.31349899067032727, 0.03382801040706616, 0.2184141493372379, 0.03345141690524836, 0.05505490867841629, 0.07028452976937256, 0.09628150897521166, 0.10746563424266155, 0.09656445588916542, 0.08080109368048369, 0.042447652517547535, 0.040100037360623966, 0.0165389898428393, 0.08131348392775944, 0.02260223676961276, 0.023824579848517335, 0.05918016957659876, 0.0682952369172727, 0.04978335041913295, 0.11767188657916362, 0.09503541334021477, 0.2436204491964271, 0.12795016650230656, 0.12605781441614514, 0.2408547645374652, 0.3269545589723895, 0.3212217391738969, 0.2507841680198908, 0.19392826324028356, 0.20177825894807616, 0.2458666802774514, 0.21950842932828013, 0.3848642789788785, 0.11402384483165319, 0.2001945713474866, 0.19239719055833357, 0.26235474634074396, 0.3939405822705838, 0.16970980311593703, 0.1708259625780967, 0.2920994583156801, 0.19744695104177923, 0.21408699362749056, 0.12970792460105113, 0.41775850098459955, 0.5340978695500282, 36.59338774219636, 118.62170727022233, 88.89288702318746, 95.28331448954921, 106.87090596845074, 83.26461530500843, 69.94918838624032, 32.53302662603317, 9.69409179302954, 2.026582396318836, 0.220501417173974, 0.3409966441892809, 0.14392044905933643, 0.8119259678548383, 0.11071232252664144, 2.705993416809267, 16.207773858501067, 26.201419022775468, 78.25165364050096, 85.21662204496323, 76.64283075640279, 53.51220200138708, 105.90495171085482, 94.6267960148473, 75.1217826720207, 86.31803927883026, 75.59240433477586, 79.90461887851839, 79.44446209938296, 83.79937556482132, 71.62475432119062, 72.96101170201456, 75.22899673831078, 69.0279491486088, 70.74673960285803, 77.04926675365817, 72.42844796949818, 65.85956050503638, 69.87382396574944, 88.20564070055562, 50.32993208977484, 31.989831309164728, 31.408234027124223, 30.837384039355864, 36.26546190631005, 53.87382884179392, 51.55405282974244, 60.45828811583981, 36.4391601470209, 26.21051892157524, 10.610164288551578, 4.430420562144249, 1.780278019366726, 1.9960048241961388, 0.6833106531731544, 0.3248664177954197, 0.5801488855673421, 3.828457598724673, 0.4001821457378326, 0.44607629759177087, 3.7522331985735127, 9.998587350691519, 6.041266408658797, 6.948656737804414, 1.8268679322734958, 10.969341608785815, 17.550664947878932, 18.901895976835682, 33.06871844876197, 1.7147858368773616, 0.20435092009363637, 1.326734846638095, 0.3312583183569293, 3.4782308820755254, 1.8228340196994044, 1.2051592671102094, 3.220804011629474, 8.000502567137442, 1.3482555434588464, 0.31549020640311704, 0.6997531063614354, 10.991154889906607, 29.59725610671505, 40.63553533246441, 51.18999019745858, 38.507331801999, 51.740667435430716, 43.40875302591632, 30.30268849865083, 23.248360656922866, 37.89710906244094, 73.71486771491267, 70.89955514477145, 53.48888351071266, 62.684754863862075, 65.24220689650505, 59.88857953779159, 64.29437398910522, 65.83267657987534, 64.83647692588069, 66.52240184045607, 69.55819868272351, 70.39564824873402, 67.31717601899179, 68.55244805735927, 63.207477369616115, 67.3156306051439, 67.47661252175608, 70.53072683272823, 64.76183422150152, 75.20746292606478, 55.599797233458496, 59.23872909238262, 79.39493040884696, 64.32406633130967, 78.99761784461238, 14.197729768291598, 0.7518310892966487, 7.99117369997886, 3.1184313758727047, 2.453516087224407, 1.7521062084744055, 0.187633196192403, 0.1933043918782665, 27.608206502852905, 61.14323985192084, 64.17446713293752, 60.843609994457616, 65.05976961505029, 27.429519007282874, 0.9340379315037882, 0.2433644072903741, 0.4102063449400087, 0.18675613277141126, 0.20741904094334573, 0.1915611434848078, 0.22223829171590267, 0.23168315990797936, 0.41616715250476716, 0.14914432600621255, 0.1344729914900757, 0.1624465694711093, 0.1970121501794746, 0.124884374559887, 0.10196206625550987, 0.10801350202171073, 0.22196925695865388, 0.21529088547873884, 0.24977591970274526, 0.1906204641225838, 0.3317635380212338], [0.04589889010774993, 0.1351210712305, 0.08395926816569221, 0.028435638166903972, 0.05636308041791763, 0.01332093409502939, 0.03830685918670028, 0.03628614523838605, 0.052158169358247713, 0.058980385337265274, 0.13330708227811322, 0.07066016566128501, 0.10061650942530363, 0.09326840856022413, 0.022117596142174258, 0.07638530925877633, 0.09674318420190005, 0.0908779384448163, 0.08635101764793358, 0.13177107598993087, 0.08679067550767815, 0.15854885200819663, 0.06863262203912582, 0.019779827130297502, 0.0997267749100443, 3.1601705426169984, 53.31771519876296, 71.53595970522973, 87.60589461172782, 95.4940712836481, 72.88793794570431, 71.53833666155415, 15.276868920172415, 2.659210572319646, 0.12328861341361078, 0.09118746860974258, 0.19857146086231356, 0.3453744995978571, 3.1873937527979574, 0.5205565606874805, 2.946536199700448, 3.978977573494758, 60.30005970308858, 77.75396762355682, 85.04079003487864, 56.80977390658472, 62.17370533174085, 90.5620438052762, 78.01136924374488, 81.45102900843467, 74.77214259486045, 82.26114749908447, 81.34347761830976, 82.8140369538338, 81.34889048914756, 79.95618235680365, 75.22236008797923, 74.41992944286716, 73.22439885908558, 71.42984390258789, 74.56329991740566, 77.0080191089261, 72.27893506326984, 68.72841342802971, 75.64318333902668, 72.24936823691093, 32.88286086051695, 33.22069068108836, 35.98987617800313, 25.430235939641154, 41.38832838304582, 43.781994004403394, 38.751887659872736, 17.932095835285804, 9.670405580151467, 11.008788885608798, 5.90598778378579, 0.4118547516484415, 0.22526884361380534, 0.13898446795440492, 0.06544106144217715, 0.16156535385356796, 0.6406578806138808, 0.24453966277501277, 0.12366542908092662, 0.16112407188742392, 1.3332043059410588, 2.3172205878842265, 3.6902482278885382, 1.877436231701605, 7.79633290344669, 12.313477070100847, 7.656016974679886, 15.114702447768181, 1.3433758698163496, 0.09041858446453849, 0.3268864077906455, 0.6159388586398095, 1.2603025210480536, 0.3984195612851651, 0.2530912877691369, 0.13747466187323296, 1.1508767282770527, 0.026208296898872625, 0.3393449892680491, 0.43359779782833596, 6.889667232190409, 24.96617836336936, 24.45773328504255, 43.63454818725587, 37.586979020026426, 45.90254499066261, 42.524823373363866, 27.74335372832514, 41.85747131224602, 62.029432712062714, 76.48003670477098, 57.57626779617802, 62.82981195757466, 62.906164815348966, 60.40223352370724, 63.9691428215273, 68.63676332658338, 66.76809910804995, 66.78894258314564, 72.18516688193046, 66.37620725939351, 66.3075500918973, 67.42388017715948, 68.54221067120953, 68.69806212763633, 65.76004212902438, 68.3985185623169, 63.72472816897977, 69.85782854018673, 63.23423185656148, 66.45252089346609, 35.52923694733651, 54.93136652054326, 49.62089700083579, 55.925428482794, 26.457749835906494, 0.23378501405879376, 0.12118259940536753, 3.2029398218277967, 1.179455485074751, 0.2924936258744809, 0.5364081455815224, 0.7258479609604805, 12.449237165912507, 35.60131834399316, 45.9135550837363, 45.60708461269256, 33.76133449615971, 3.881924407136056, 0.05687204242173222, 0.02226152108050883, 0.016990060497435833, 0.06546845674634942, 0.03869661407905721, 0.08053483216152077, 0.010781922403933301, 0.0409179128285858, 0.05956857232376934, 0.0356627028856066, 0.03460705670858583, 0.15194515877914044, 0.05869726605352856, 0.026567402528598908, 0.06097984417612034, 0.026976202366753455, 0.029603989284125068, 0.12279431050222729, 0.03409214986247882, 0.05047146974491978, 0.037052095266840154, 0.048614637325367624, 0.035497254707039363, 0.07305825835153942, 0.04070275703505163, 0.027693392814046917, 0.05020481369067585, 0.046463738225640795, 0.05609612558938323, 0.027109250771783056, 0.04770367451372647, 0.12475505891826846, 0.09274222106943208, 0.0853969011035177, 0.073917395315103, 0.023524158469010747, 0.1053979552741493, 0.08887352301709114, 0.08473464873649421, 0.06881126608218878, 0.07482472686998307, 0.06803476702301733, 0.17362731629081313, 0.016685318382036303, 0.01743515758144279, 0.07618886899323234, 5.370888729249278, 71.06921334420481, 83.2075918874433, 94.9141880773729, 97.96652163228681, 77.1175709078389, 57.21354269212293, 20.56962109381153, 4.037675597975332, 0.03222854522567603, 0.1297306314471268, 0.3666631024210684, 1.1970958546284707, 1.0945508797322552, 0.07512098839206081, 5.492479753109717, 10.339697253319526, 25.464309569328066, 50.127259300601104, 85.73250001476657, 64.2167777399863, 59.553456152639086, 88.71531348074637, 78.57650433817219, 82.61197997677712, 77.58568225368377, 79.3908432991274, 80.8582333595522, 83.0394006544544, 79.8090228726787, 77.23160205348846, 75.08119398547758, 75.3530377726401, 72.83809246555452, 68.91318059736683, 76.74976241204047, 77.7686922011837, 74.22643892226681, 70.24804161440942, 72.28739169336134, 52.67021817545737, 21.937892859981908, 28.90727196970294, 28.494964184299594, 31.29905877574798, 44.60962195550242, 50.979284394171934, 50.088141502872595, 22.557370431961555, 22.03148453466354, 20.464140715137606, 11.47056168125522, 0.7457884328980601, 0.1967041215468799, 0.21268010379806643, 0.11032756252755081, 0.05345682628572949, 0.38323480996393394, 0.09570926427841188, 0.12902406855456292, 0.7878951379849065, 1.0174188186084072, 1.1083008709453768, 5.456497400037704, 2.9835121381667356, 8.991941444335446, 13.682313657576039, 9.750448407665376, 21.836072052678755, 1.5075340482496447, 0.1154910104589597, 0.46271180493697045, 3.6452010322001676, 1.3949272132688955, 0.23066381863769025, 0.38932735400815166, 1.4022002681609125, 0.4138716772919701, 0.15292532231298187, 0.3952434220381322, 2.4713969470993167, 15.227132285794905, 24.657081865495254, 34.19581936251733, 57.751762482427786, 42.853286573963786, 50.21364165890602, 43.60258479272166, 28.02446411501977, 17.68331950710666, 35.57249676796698, 68.95485970281786, 61.20022796815442, 62.16881413613597, 64.54789638519287, 62.47788906097413, 68.34850049787953, 69.19794467187697, 65.30981286879509, 67.56146123332363, 73.38866772190218, 66.62886281167307, 67.58148101068312, 67.38517422829905, 71.13617604778659, 72.0699982489309, 70.79166643081173, 70.50916948626119, 68.2862917069466, 70.4880436005131, 66.10634819153817, 70.92465831387427, 45.617169026405584, 58.741031308327955, 59.52139862122075, 62.19762394505163, 38.65293802753572, 0.18557156165761335, 0.5113234851629503, 0.9702170159547561, 1.2849307156378225, 0.19666200203280296, 0.2738340223027814, 1.279117885616518, 24.88428515772666, 43.685452707352184, 59.11751216457736, 62.19099906183059, 47.956003835124356, 8.735676330904807, 0.09107090833206331, 0.1722090270730757, 0.012321734233879516, 0.013687904574908318, 0.021146374769629012, 0.1095674807325967, 0.006619333871640266, 0.02225723098813286, 0.055221984793822614, 0.04520379555141253, 0.02615625271573663, 0.06858029057301822, 0.06783124810505299, 0.06003295567127005, 0.04187521246832706, 0.021942600592850678, 0.06198330827417874, 0.08243820825291258, 0.07773320265715161, 0.0458954120685737, 0.07516313088877548, 0.37349124409018025, 0.1963097394834603, 0.2171517130468161, 0.14468839091639366, 0.23690018802881244, 0.10799005973122774, 0.130877633609118, 0.1570510428639189, 0.106794640812422, 0.1560494748334731, 0.19651062305896513, 0.23176263386924423, 0.1871708008430658, 0.17828868551840707, 0.13283069816327867, 0.30671911254044504, 0.17038995129687173, 0.18911087254603065, 0.2285456161705717, 0.3246222196086761, 0.2256684503968685, 0.21012022099908323, 0.23071097901030896, 0.10595764378987013, 0.3404601987811827, 5.144349788465808, 90.88861250108289, 96.31453698681247, 106.06030894863991, 113.9922514269429, 93.32445144653322, 84.25786141426333, 30.157894203739783, 5.228425302813131, 0.23433975364652374, 0.32463778651529746, 0.4289762038857706, 1.2887493881487078, 10.184210577318746, 0.4814300908436699, 10.875790138398449, 13.691625364365118, 71.71311747643256, 94.72475328753072, 96.0868198640885, 71.85328729691045, 80.50328239317864, 96.50441108211395, 76.3987808842813, 80.22638659323417, 75.87688599863361, 82.71255739273565, 81.20581811474216, 81.8321264943769, 76.58140643950432, 78.35954235446069, 79.02505090159755, 73.63081132211994, 70.39598557256883, 68.14185434772124, 74.65957057091498, 77.72785248294954, 72.96045472545009, 69.73159097856092, 74.78904801030313, 86.42381775763728, 38.961961961561634, 41.574688034672896, 42.0320991546877, 35.42023428024785, 52.65438748944191, 56.08609268742224, 58.06557170806393, 33.736529427189986, 33.119874000549316, 35.405780346162864, 14.153654094665283, 0.9762771391580183, 0.40030116515774883, 0.3400189014932802, 0.3122505431454028, 0.1549903889216723, 1.9717041475157586, 1.0166242322133434, 0.3640546036824104, 0.44129011731955314, 2.870857499299511, 7.464791132557777, 7.493448949629261, 3.417937923823634, 10.955730984287879, 18.54165569428475, 13.40664359831041, 28.84382959335081, 2.240249711659647, 0.2772813566750096, 0.5037585507717826, 4.338034525994332, 4.113467066518722, 0.5034407162137571, 1.1182928638112162, 2.9361514795211057, 2.787102638713775, 0.3371187071165731, 0.8152551408256254, 2.750764085400489, 23.547668880031956, 35.68071888339135, 38.60754051516133, 56.728839720449145, 47.15551476324759, 51.58452572361116, 47.33852471074751, 33.90449708507907, 55.272495054429584, 74.50379756189163, 83.28467430606966, 56.303258634382686, 62.16864547421856, 64.40538883209229, 61.05199767697243, 65.1304703374063, 69.73885520812004, 65.01762374754875, 67.90877142260152, 74.02596658275974, 68.16038362441525, 68.33090474528652, 67.06613648322322, 66.68067732164937, 68.8112852650304, 70.74284076690674, 72.92971118803948, 68.48683464911677, 76.45555327015539, 67.744094633287, 72.21158012267082, 49.07581698509955, 70.55287253472113, 70.54218799837174, 72.01149217544064, 40.30034526701897, 0.3019314613794127, 0.9913791836269441, 7.866323676801498, 2.4099868487927223, 0.6742975981004777, 0.707867693516516, 3.824280274491157, 38.798187317386756, 57.99614183364376, 71.63627040001654, 74.82504752374466, 59.150989593998084, 10.071288481835397, 0.30665093071518407, 0.3157653545420016, 0.11093063460242365, 0.18290632644728308, 0.11922607979466839, 0.2868099582772101, 0.18403869632992054, 0.15187852445148653, 0.28722686332560354, 0.10161713516760258, 0.1353166534775688, 0.2893232782521556, 0.22452949215808224, 0.12799538101159758, 0.1548750926890681, 0.0855918168540924, 0.22499835328950038, 0.23664387033110668, 0.1928845603740023, 0.17122218325253458, 0.18842111762252547], [0.13602120921977107, 0.11025888274513906, 0.03751647861434087, 0.1284670307030601, 0.09680459380991037, 0.08491550677365835, 0.016464428420388894, 0.10036008447528848, 0.01893404116403432, 0.04113160539418459, 0.0166974704517352, 0.06044968068900128, 0.03376206938898371, 0.046767258430801095, 0.08827661795000877, 0.054291877444953694, 0.054697118804699955, 0.05556163370549198, 0.012262470629667083, 0.039887317726689006, 0.056720322538768096, 0.09876828400358077, 0.07227952231562908, 0.077881570905447, 0.07978330756868086, 0.2973891422152519, 28.64650691709211, 83.38580085385232, 79.46999672920474, 85.27690887451173, 82.29692735979634, 67.11162028774139, 20.38640522187756, 0.8558333472859475, 0.09191270872590043, 0.15687567001629263, 1.0948462832358576, 2.0236750620026744, 2.0896905131878394, 0.21713380191114642, 2.9033582585473217, 21.609827779954482, 81.6394361372917, 75.55179995875206, 81.44825197035267, 44.557536801984234, 76.52881530023392, 80.3277406384868, 79.543549014676, 78.90482241107573, 77.00324950679656, 78.81677304544758, 83.08362145577708, 81.3936996459961, 76.05112552642822, 75.36461660938879, 73.98160457611084, 75.1205353583059, 71.38484647197109, 68.78841000218546, 72.73079995186099, 76.16933007394114, 71.09099034340151, 65.54743789857434, 64.06102826518398, 83.05013225924584, 61.43478178208875, 26.320786553044474, 35.622801165426935, 27.705634255563062, 48.37090822958177, 39.67726499803605, 39.110149106671734, 20.454866270865164, 11.679031733543644, 4.5512187769336085, 7.261712378071201, 0.34196534704777504, 0.3816873736439213, 0.06060136609800881, 0.234271862934674, 0.03342962170380258, 0.36443182537632607, 0.16210562970128753, 0.5354874304706051, 0.8864657713040229, 2.239965094674018, 1.5084496765367448, 4.038738315143894, 1.0399024573064621, 10.40286212198196, 10.689612876984382, 6.021526590470345, 11.97715049789798, 0.17117142226667176, 0.510471043807845, 0.10107791652121853, 0.7985138520598413, 0.8282433954938766, 0.1765419744075306, 0.2909599178500714, 0.5998996128478359, 0.5857385694980621, 0.11516487916871426, 0.05293505529182092, 0.6091109314753164, 9.585140116753118, 23.53099096205927, 23.170311374049035, 43.9280120788082, 35.81758606818415, 51.954785700767275, 34.928984872756466, 35.65645117913523, 108.80869803890106, 65.4572626083128, 64.1474380800801, 55.79225224833335, 56.688941371056345, 60.5439095343313, 61.30627316813315, 68.10217565105808, 65.25275807226858, 63.92156839370728, 63.72138630959296, 65.68888248935824, 65.40099228582075, 66.1645326306743, 65.79303318454375, 64.77174605092695, 66.13211031882994, 65.27091472379624, 68.7097272565288, 65.46409929952314, 69.94252035694738, 66.72414502789898, 72.09782354293331, 51.21603473540276, 38.71009872805688, 54.16874008793985, 53.758134611191295, 48.303027691379675, 2.008084008289922, 0.37421933405341645, 0.5514264719620828, 2.8720057731674564, 0.27566678040931303, 0.960074624707622, 4.015675023678811, 20.89853732816635, 46.110454144016394, 57.869343373083304, 51.21968646203318, 15.797768504388872, 0.4862092231069842, 0.05585657755633997, 0.07513901444091912, 0.007038177601287082, 0.07080589856712088, 0.05343677776475107, 0.06673046402753362, 0.10775172977798408, 0.05457056107960882, 0.027295099871773875, 0.09703433591752283, 0.11333677887676225, 0.03579329406361907, 0.07057627137269705, 0.012486219056881966, 0.045805526972417875, 0.06658716728129695, 0.005329560212445476, 0.06188283201246973, 0.08210353508231141, 0.10327036056907908, 0.05940058073329349, 0.1523764049934764, 0.04987656033688015, 0.032785042985192234, 0.08018332803922315, 0.025020169221886226, 0.08756502185978236, 0.06774347741156816, 0.055248813192930915, 0.029245015804565726, 0.05076444474980236, 0.02856370700042575, 0.09292022159863865, 0.11659121230965662, 0.06309791640829175, 0.10584536594368758, 0.021999541993042635, 0.08003890514373779, 0.06851104388554251, 0.07801172924378226, 0.0868091382266533, 0.10945906396955253, 0.11621338540628073, 0.07984641023100385, 0.0468773988916749, 0.021865457454095447, 0.3654086487668176, 44.24197819925124, 96.74524461069416, 88.42462662727603, 93.75832050077378, 84.17755480735534, 67.11675074792677, 25.630408217830045, 1.3397884945715628, 0.1697045171092595, 0.1477540756065038, 2.302332986747065, 1.2250352650880814, 0.6926498165534389, 0.22637619306483578, 3.5197462285718615, 29.40076497293288, 71.0658871742987, 76.10169272268973, 86.47699725243353, 50.32412305954964, 80.3529614786948, 81.33923361378332, 80.93197391879174, 79.97642963163315, 79.12008993087277, 78.13865015583654, 79.86834479916482, 82.40881689133184, 77.96848989302113, 76.40278954659739, 74.12871699179374, 73.4613492411952, 71.77879364259782, 68.54139481821369, 71.99332375680247, 74.9684807562059, 72.17388614531487, 65.93596043125277, 66.495039386134, 71.92831439356651, 41.319251521941155, 28.19107267164415, 36.467997412527765, 34.89924546210997, 48.93601194504769, 53.64955163771107, 43.06811086593136, 23.638571769960468, 18.65411396949522, 4.7881647463767765, 4.371036368031656, 0.5732574650356846, 0.25027691056170775, 0.14961309520707977, 0.16647807652911834, 0.06514727438409483, 0.15565470972609136, 0.16654846468760123, 0.8669340838828395, 0.6850034010506446, 3.747309643414713, 1.7110283288263506, 4.840924547564599, 1.2913328817775174, 11.163867635111655, 13.615546091910332, 8.05179246010319, 12.856224256177104, 0.7249426288950829, 0.44046338587518663, 1.0303171651978646, 2.796517552868013, 0.5510832032849712, 0.1287395894647606, 0.5191450590087522, 1.4503071577318254, 2.52249292788967, 0.5502544187249676, 0.6226123424787676, 3.763768153805887, 18.431429247702322, 21.77231784789793, 29.96983812701318, 53.43709645732757, 42.61983886841805, 55.93437148678688, 37.62465338553152, 36.148610576506584, 96.67648546157345, 59.38367635973039, 65.65610324182819, 57.56501843852382, 58.29754852479505, 64.26954538591447, 60.100014901930294, 70.25233268737793, 68.52267726775139, 66.5258849051691, 62.44408607482911, 69.78309954366377, 63.516081610033595, 67.53084321175852, 65.9907716320407, 67.69671240160542, 68.00230426173057, 72.23657346540882, 69.41775429633357, 67.63710806446691, 70.92505055089151, 68.22666383558705, 70.86455975809406, 57.67182850068616, 46.79809270366546, 61.16378130451326, 60.36038967870898, 62.63026921979843, 2.9325698652575096, 0.40300370884999154, 0.9298066133933683, 0.9583854314781005, 0.36221108970142185, 0.9829973237168406, 10.09404509298263, 35.28411626815796, 50.90000544824908, 68.89963273079165, 63.07977676391602, 25.554294624636253, 1.2300459704091473, 0.0714571652333102, 0.12074143235241214, 0.03252529704402531, 0.06344424177622122, 0.020431712412485675, 0.10312064400603695, 0.043887721614972244, 0.044668522257838524, 0.09549836027285746, 0.0672579845113139, 0.09166713924177232, 0.042062229852402405, 0.08188913771582228, 0.053517611532081524, 0.1112615462813166, 0.11211073176274378, 0.029193268480500387, 0.07841532734493095, 0.109613208520797, 0.09443564310429559, 0.04500060605125562, 0.2892101423874978, 0.23586512663431708, 0.15456393841774235, 0.20281149705331172, 0.17106200958932602, 0.12915894599451175, 0.18465866064352376, 0.12487398640763377, 0.14399909564564306, 0.1401786458107733, 0.15091094008136183, 0.2205986030880482, 0.159932054399002, 0.13933089291376455, 0.3039762113363512, 0.1376427109203031, 0.33085250626167945, 0.19622697134412107, 0.154603683059254, 0.2715733581252637, 0.25906819850206375, 0.2032652968961385, 0.22589233193186023, 0.2296069543808699, 0.16569231546694235, 0.37837012100123596, 52.264370533727835, 118.26008827455583, 99.14126365415513, 108.11799218577724, 102.85299470347744, 88.73210122508388, 33.644506700577274, 2.1746105628628887, 0.328008113729377, 0.35446496019440316, 4.063587265629923, 5.654872742391402, 3.856698173669077, 0.4065215233112536, 7.812023364728498, 37.44462051699239, 96.93194158615606, 90.7729261152206, 94.53793864096366, 58.15511549672773, 83.59556136592742, 78.96483467471215, 79.6346107605965, 79.53002468232187, 75.28451396572974, 74.87501067499961, 78.61174291180026, 79.67408549401068, 75.14959227654242, 73.28739996879332, 72.37291505259853, 74.20488157579976, 69.19547357866841, 66.69821031631963, 67.35975726958245, 74.7395476987285, 71.70983053022816, 64.02834315453806, 61.757941938215694, 87.58472165753766, 71.84614073845648, 29.64038060557458, 43.97505698665496, 41.311834319945305, 54.778598047071895, 61.85294958852953, 48.3941404281124, 31.27449885491402, 30.148511894287605, 34.15184174814532, 11.678118801886036, 0.9337496985831569, 0.6754429301907939, 0.12407271206499108, 0.4874655766592872, 0.407954138373175, 0.6494561859196233, 2.0649624207327446, 2.139185186355345, 0.9617594665577336, 4.111372030550434, 4.954472261090433, 7.451603633742179, 0.9276175018279784, 13.40042075803203, 19.77020675136197, 10.557143649747296, 19.181213840361565, 0.5450938053188786, 0.7150830160225592, 0.21516737678358633, 10.498465972561991, 3.3497433508596117, 0.5055109922203326, 1.813869687818712, 3.1019625692598285, 2.3940585938192185, 1.8335588829171274, 2.3663705827728396, 2.2897358046424006, 20.054862960692375, 33.08834206673407, 36.31765688619306, 54.47340626870432, 45.08312656033424, 61.828113140598425, 40.464873006266934, 41.18065457190237, 122.7400625905683, 76.91894208231281, 65.45298722482497, 54.81134199327039, 54.09424251125705, 60.27870239750032, 59.44300613095684, 68.40871672476491, 63.87512753086706, 64.47594834912208, 61.1432163176998, 69.35771849847609, 63.71025462304393, 69.27485450621575, 66.90934365795505, 64.67562836985435, 67.9844888564079, 71.21086582060784, 71.44075593640729, 69.4349656566497, 70.65368529289, 68.36610409521288, 70.42051607562651, 63.744787170041, 57.99752250794442, 69.5510599690099, 66.67798657571116, 68.1900445876583, 2.988869360377712, 0.46042981287164075, 1.8685493666318156, 7.545823377947654, 0.5607232247148791, 0.9656934199794647, 21.01867952654439, 55.03235970774005, 71.15499557987337, 79.23633329329952, 74.5403697413783, 30.42067731580427, 1.4867811553901242, 0.09119760395298082, 0.23057918124381574, 0.15363968398061492, 0.15069484199968078, 0.28184785357406067, 0.3213869383738887, 0.17807430347367642, 0.11853126869086297, 0.21557398561027744, 0.33265026947182996, 0.27009851629695586, 0.18248559095926825, 0.19014714435944635, 0.14332503020282716, 0.2395382424395892, 0.16706203471028036, 0.13383793524436413, 0.23769819117601843, 0.17482691804968542, 0.2738160345583193, 0.17833932393020202], [0.028055085905737458, 0.04482930879138651, 0.03504776793922629, 0.06751336758175204, 0.06031255861143432, 0.05324440159564538, 0.04516166837645635, 0.11403808640616556, 0.05412992262732118, 0.013581816719153957, 0.04698910983279348, 0.06677837516631811, 0.054424858817289916, 0.02532156736349627, 0.07881960726433224, 0.08339457709582583, 0.03661518383230414, 0.01933446957639629, 0.02985044743024534, 0.047085242375971816, 0.04458424875572805, 0.058592921047801935, 0.054073645808403535, 0.05173239684213073, 0.11017920194013466, 0.11295900559954106, 4.967668585238918, 60.92543063625213, 74.51248168945312, 67.17993228666245, 86.60952629581575, 68.49866451755648, 33.18079625406573, 0.40544507784708855, 0.046962178011815396, 0.04876830307165942, 0.3837248917308546, 0.802664271285457, 0.5478857974371603, 0.287699110565647, 1.7113978896410236, 54.61705523152506, 69.39734228195684, 73.9448441228559, 63.94316496387605, 56.701081106739665, 91.16040137506302, 79.55397467459403, 85.13019654058641, 76.62774532072007, 80.20808481401014, 77.73585411810106, 83.2506359777143, 81.45961899911204, 82.19814638937675, 77.7905398030435, 81.18703780635711, 75.17729989943966, 73.38032876291584, 71.05162543635215, 75.50782234438005, 74.77012649659189, 74.30684751079929, 72.58957109143658, 68.250927617473, 73.44061559246433, 77.9374796344388, 33.29408214938256, 20.317036144195065, 26.030017329800515, 43.05396679908999, 45.34814934576712, 36.914649471159905, 18.16895600288145, 9.680081086774027, 4.631525874137878, 1.8955998699511252, 0.1423594070177886, 0.1058827740170302, 0.25584169663488865, 0.028125830295105136, 0.09715869497027128, 0.06076944195815633, 0.07136709627605255, 0.7836420016904032, 0.7961644749006918, 2.740769150757021, 2.1442131746199826, 4.743814506838399, 2.7475729921171745, 6.8500385457469575, 8.324738433284145, 7.3225978593672485, 4.97905130347898, 0.6280893195540674, 0.6471559609616957, 2.029339699975906, 1.5891979178113322, 0.13308674006933166, 0.06406812079911751, 0.08382189327911024, 0.530087368622903, 0.20116734979373796, 0.20335685972484852, 1.3568830418009914, 2.6517369862525695, 14.376176038096029, 26.022237308563728, 20.65782931543166, 39.69837127193328, 34.97241727767452, 56.911614325738725, 42.20548752815493, 22.2043590776382, 28.035389877134754, 53.04172938869846, 67.72569087243849, 59.786237055255526, 62.3908281326294, 68.93724041600382, 64.2406649743357, 66.92173834769957, 63.93665382939001, 66.66102624708607, 68.49882141236337, 70.06718112576392, 65.70761965167138, 67.67531979468562, 71.30325332764657, 71.86834135363179, 69.739286668839, 64.86804808339765, 68.628628330846, 68.93331020109116, 68.15107191762617, 67.39681582297048, 70.6705593293713, 68.97323992944533, 36.38312516673919, 51.87116469106367, 59.55685292520831, 52.0872990546688, 12.195436281542625, 0.21110378596330845, 0.11427951135462332, 0.08677780523055023, 1.3328579116252162, 6.902771380639846, 16.12352526956989, 28.272473619830226, 51.68134158657443, 58.7085933070029, 34.14674266692131, 2.4790754770078967, 0.246196664989956, 0.021357495195022034, 0.05375077039183629, 0.11376184276154927, 0.026721526012425462, 0.17006372041519613, 0.09944146844528376, 0.009805842118728305, 0.04626789167823811, 0.035878440905963226, 0.18733501945051456, 0.030867628332587983, 0.05255721689712617, 0.0245351129917488, 0.0431666873215187, 0.062242502632040175, 0.06930981312067279, 0.039976383108765855, 0.04332483085172792, 0.09154153146570729, 0.03595495010696111, 0.0539787313450248, 0.13161180631047295, 0.052391738075041966, 0.021795159310943658, 0.05297123762448469, 0.03762713235412394, 0.05970618852804746, 0.0735309039573035, 0.06410099363194839, 0.07565999253382606, 0.02682176287165813, 0.016311605370813803, 0.02501873663746782, 0.054829966111649434, 0.04262958690824528, 0.019846354205642017, 0.039605056461427486, 0.02558934573654927, 0.07087796445815794, 0.06330017894206029, 0.09965130758862342, 0.17575639720645644, 0.08877153373173169, 0.0714378368349806, 0.07575675709954194, 0.2697190576263013, 0.24757461201760078, 8.121571915764964, 83.681822130757, 82.15541608871953, 81.329529669977, 89.27355304841073, 76.43749467788204, 43.59469298393496, 1.1539805488240336, 0.02324550930831221, 0.22597749026552325, 1.2520976580919758, 0.9836629009054554, 0.6246049678133381, 0.7233705551874253, 3.6540160688661762, 65.79455114180043, 75.62947073290425, 78.27405821892523, 69.65555975514074, 61.610468664476954, 89.837048592106, 82.48243193472587, 83.28303475533762, 77.47921343772643, 82.4123078007852, 80.65846704667615, 84.96682982290946, 80.85532296088435, 79.65015119121921, 78.01668797769855, 80.04266277436288, 73.27425218397572, 72.50896638439548, 70.10812282562256, 75.32271000646776, 72.74306912575999, 72.65016386585852, 71.91534703777683, 70.51233091662007, 73.94984122245543, 63.1601147497854, 29.550399472636563, 22.558062730296967, 30.98719112334713, 46.828145903925744, 57.20000267028809, 40.59205193673411, 23.728570553564257, 18.254618606259747, 5.108428232131466, 3.1377144830842174, 0.9721457189129246, 0.1023629907098028, 0.18384899763811022, 0.13295701074023403, 0.10677030985994686, 0.1404214956827702, 0.1388126191112303, 0.5605955025361431, 1.00917712214493, 2.720993050644475, 2.559817957301294, 5.62990685624461, 3.453036027569925, 6.952726687154462, 11.367218013732664, 7.528356573274059, 13.396613117187256, 2.4758593786147336, 3.0529581923638625, 2.632112877984201, 3.633415290424901, 0.493763616128314, 0.23141536621316788, 0.2860838601425771, 1.0758406837140362, 0.14255858987810152, 0.8080781227157963, 4.96026756302003, 8.359969162171888, 23.85465514275336, 23.761022283184914, 23.681425625278106, 47.666281884716405, 41.071189065133375, 60.11819508767898, 40.91478455451227, 24.135432127983343, 42.52394476244527, 53.3183467003607, 67.43163078061997, 58.41945186738045, 59.30460922179684, 70.85858206595145, 63.45075453481367, 67.97819737465151, 64.31229922079271, 68.71808190499583, 67.8844762617542, 70.30338625754081, 67.5529496900497, 67.88272688465734, 72.05596400845435, 74.42072176164197, 72.74622271137854, 65.94935140302105, 69.59488853331536, 70.05498255452802, 69.32880278556578, 71.32184536226335, 74.2474942053518, 74.03905160965459, 43.382057374523534, 58.61631170395882, 63.6283084654039, 62.64386415481568, 18.12217781620641, 0.6643014377163303, 0.5390284114306974, 0.16140787681985289, 1.5007990935156423, 9.67879258817242, 29.611209938603064, 39.75771281027025, 63.518097708302165, 76.71458659633514, 44.73248627878005, 7.6416865952553295, 0.1491429010826734, 0.04420216240349316, 0.011837620291888956, 0.11319836211060325, 0.037682482206653205, 0.2312292221693262, 0.07223858257695552, 0.03439080923975956, 0.0030171843818313777, 0.09482576571885618, 0.07903217368068234, 0.023896856413733576, 0.023606315653230396, 0.044986912229609106, 0.045203730433938966, 0.04210519589363568, 0.10104395584353518, 0.061664435667015856, 0.013720455650810995, 0.07019835253877026, 0.14088511677278628, 0.06372446524760415, 0.23746427388921862, 0.19396957070116075, 0.21319157473983305, 0.1935284113090846, 0.09853272728862301, 0.09276706530081649, 0.16574672303132473, 0.26953087578858104, 0.16008669690739724, 0.1270526102293403, 0.10949184487183249, 0.13993172035101922, 0.19920561312427446, 0.07803637429230637, 0.3176278675035123, 0.15223211999381744, 0.11527586998718402, 0.15235869304066704, 0.13971117895937737, 0.20993219237894784, 0.24941713008428776, 0.2682040421472442, 0.13950108700702268, 0.16303979731615514, 0.38740165411464633, 0.3625976883115307, 8.621635379329804, 98.0750536149548, 96.86200572598366, 94.73262940683674, 105.77671374044111, 89.50543572825771, 55.28849440236246, 2.4381673624438625, 0.12770059037833445, 0.5192190937457547, 5.061103855409931, 3.988684459078697, 1.4922441590216853, 1.0933050369062731, 6.5912753728128255, 73.04437775765696, 80.95874801758798, 89.3047280465403, 80.4977753854567, 70.11235114066832, 92.97899261597665, 84.72132867382419, 83.55181124902542, 76.88756312093427, 81.66154261558287, 78.54340737865817, 85.50115862200337, 83.2854901590655, 78.80931269737982, 76.09824103693809, 79.08189389013475, 74.27006352332332, 71.58724861760294, 70.15614048127206, 74.20350874623945, 72.15559221083119, 71.65765516219601, 73.11523145244968, 71.82992566016414, 72.58973583098381, 79.86661111154865, 42.480163266581876, 23.804854769860547, 42.31627879604217, 47.863153488405295, 67.67393127564462, 48.439949789354884, 34.036151439912864, 29.567197022899506, 22.69171553273355, 9.315402642373117, 1.6683061180576202, 0.1268254574989119, 0.45776998624205595, 0.4076276929868806, 0.24070522417464565, 0.17349895059822068, 0.32177565138666864, 1.5717377321374033, 1.1209188906415817, 5.723428908855685, 3.1138968708053714, 10.761595233794182, 2.628685216749868, 10.079018492852489, 16.667451127882927, 9.2382368733806, 14.687173904911166, 2.0463403554693347, 0.9998083571272512, 5.596873635245908, 14.840882766631344, 1.252847198517092, 0.9075639553127751, 2.6123936522391538, 2.123793315502905, 0.2567255016296141, 1.1253674712873276, 8.450871071507855, 6.060139383039167, 27.254700929887836, 33.71935729057559, 31.440713213336085, 49.03860938164496, 50.42966227377615, 64.80607071230489, 47.907762604375044, 24.899117600533273, 36.884392307650664, 58.83281084798998, 66.0249040972802, 60.049773262393096, 61.295247385578776, 69.35978166518673, 59.454294712312766, 67.00895617085119, 62.66367212418587, 66.850751292321, 66.88337756741431, 71.20988522806476, 65.93949056440785, 68.32122433570125, 74.92486399988975, 74.19141215662803, 73.22839967666134, 65.2825523960975, 70.0477026354882, 71.04058788668725, 70.58200790036109, 68.94561075395154, 76.23156239909511, 77.82095386135963, 50.46584221624559, 72.21877374956685, 71.23287816201487, 69.19526177067911, 21.3063951846092, 1.1349830391906923, 1.0847015630814338, 0.3495026103431179, 1.2087560805582231, 12.666132469331066, 49.27352405363514, 61.369458629239, 77.824672268283, 85.14199503006475, 51.44195541258782, 9.011263039804275, 0.25017857551574707, 0.22074250504374507, 0.19908401964893266, 0.30186760029004467, 0.12795804188616816, 0.3697214786323809, 0.16227009345687207, 0.11176161783476991, 0.10881289944893892, 0.16174809646702584, 0.3534368395565018, 0.17898887455944093, 0.18856364061995862, 0.1878451880428099, 0.1567955372194129, 0.12241422363947477, 0.1976080746540139, 0.14937167025862202, 0.17083032927926511, 0.25463377516115865, 0.2193301147030246, 0.2140609619598235], [0.15772391320957294, 0.024917440661679835, 0.06494196282038767, 0.07767260510234103, 0.04926179392984317, 0.029022243181844393, 0.03237261955115584, 0.03638791235824747, 0.027955877519543135, 0.05304859335263891, 0.13067518721424765, 0.04445681385996361, 0.07021791076347714, 0.09067770604404712, 0.06588170755534403, 0.02490504727428479, 0.018126218684858853, 0.027908973786379063, 0.03153122326869878, 0.05641908910606177, 0.015003991917887283, 0.07431685654146057, 0.09138659018302157, 0.003732623121205477, 0.06836914908020728, 0.022373785520152702, 0.7284948866694205, 24.749198728992095, 94.41266598240023, 75.71227981198219, 86.28343612917008, 71.14995925657212, 42.6183012993105, 5.980525564762854, 0.13092795026398477, 0.09387967011500752, 1.7906552625279275, 0.8383256641607132, 0.795901369663977, 0.8965365180084783, 21.19261899302083, 90.9564067471412, 69.91913518598004, 80.86879238005608, 48.79889372856387, 73.36491384813863, 88.53373912072952, 84.0577107091104, 82.3194182303644, 80.61168886000111, 80.94789874169135, 77.34904566118794, 79.77522773127403, 81.7948482882592, 79.72566466177665, 78.96648207018453, 74.50694330276983, 74.1883134841919, 73.64105655301002, 78.53499781700873, 76.40116568534606, 72.18043650350263, 71.75852283354729, 72.4625333662956, 72.33978671412315, 68.19365316821684, 75.91269723830685, 59.44259820445892, 29.568762048598263, 35.0381758136134, 42.287598425342196, 43.840880547800374, 38.76755752871114, 19.77965574110708, 7.137125153695384, 3.9952568805986837, 0.6988167017698289, 0.4086819831882754, 0.06882369202832062, 0.16463079339554235, 0.1698621167170425, 0.23445644415915015, 0.108374681834492, 0.3373261637264683, 0.4624402727330885, 0.8277819041282901, 1.3166250600930185, 1.965391950741891, 4.404492224416425, 1.0809544738261931, 3.308220159622931, 5.388524686136554, 6.729852220704479, 1.9339382191819532, 1.2994264474799557, 8.280046947540777, 5.99742558694655, 0.3784237777994525, 0.4002334123417255, 0.0762531514309587, 0.06497529530597311, 0.19985914741071964, 0.2002478144582241, 0.33654224127531057, 1.670857374706576, 4.938821023510349, 18.118985006886145, 28.910333379622433, 23.000119732272243, 31.39425469983009, 49.00607724343577, 45.67315301587505, 36.28450501349665, 25.669759396583807, 33.634414442123905, 71.71881275792276, 57.391618297946074, 62.992060799752515, 65.19131806588942, 64.54199321808355, 66.55374942287322, 69.10513354885963, 66.02640244268602, 70.87090615303286, 63.61581963877525, 69.54905171548167, 66.56809745296356, 68.7995966019169, 66.0363809524044, 71.13421486270043, 67.33627796173096, 69.12385894406226, 67.43541979020642, 70.51325659598075, 66.91612151361281, 68.71475573508971, 67.46196639153266, 69.61471219216624, 46.80137572749969, 41.68842108018937, 53.786238393475934, 55.4930656186996, 31.405486406818515, 1.3508363404581625, 0.2040509660277636, 1.756914911731597, 10.38730502128601, 21.41825333718331, 29.604292838804184, 36.23918987089588, 51.64915069457024, 41.9305254567054, 19.630574295597693, 0.958564757339416, 0.056336723162882754, 0.07849669354336877, 0.016185804157547893, 0.09465782392409541, 0.017954597752841733, 0.045591466684615424, 0.07314868737012148, 0.04022576004987763, 0.027615813005174843, 0.07340519658980832, 0.06952706799511948, 0.022261509589189966, 0.03774262010870922, 0.08718177871478182, 0.019276576311958414, 0.054863436493061246, 0.07598861360982542, 0.09548830153841166, 0.022100845629709865, 0.036114055077515306, 0.06909618184210793, 0.0830799907505993, 0.050091857856680314, 0.07872301889883895, 0.030412472514135223, 0.1417261280960614, 0.0691352982915217, 0.04273441071892458, 0.04975448805658568, 0.018351295317012458, 0.05224903504694662, 0.0670128440364234, 0.054129704292262756, 0.05922140425912315, 0.05338192969981221, 0.0677117690323822, 0.0369268054172637, 0.026430079352951823, 0.07166787771688354, 0.012836202494649878, 0.030698556558138905, 0.0449551425633892, 0.05025270950770186, 0.020171416803233085, 0.16434908754402594, 0.03644068815535115, 0.09700126390183166, 0.024869251816022783, 0.7395935395071584, 39.74849916273548, 107.74972085029849, 82.39313525538292, 97.55237425527265, 72.513029959894, 59.428677712717366, 10.863987726549949, 0.13413413547940795, 0.13492202626601343, 0.26944694319559687, 0.70263561942885, 1.1652844519384447, 1.2135495846309972, 28.27185780771317, 100.21554593117007, 74.78043448540473, 87.73286957894602, 58.24020739524596, 78.90988226859801, 90.83106348591467, 85.29158638369653, 80.42020659292899, 84.1512357034991, 81.19420789903211, 78.12464729432138, 79.72093428334883, 83.19223973058885, 80.210312720268, 78.17796799444383, 75.5024879209457, 76.11157709552397, 71.25626333298223, 77.1446038830665, 75.02848517510199, 72.44183894126647, 71.60171431879844, 71.6510263566048, 71.78044888281053, 68.00480673390051, 70.61763871100642, 47.95856514284688, 25.169259079041023, 38.56140167482438, 42.14997030073597, 61.13821137335993, 40.135440980234456, 26.378898428332423, 16.99602807721784, 6.554710547770224, 2.29883129077573, 0.5466694336745047, 0.2088522841973651, 0.07789777366504555, 0.2615980659761737, 0.11409181215229536, 0.060501939376756075, 0.6045562629738163, 0.28917444269022635, 0.9248725168647306, 2.9285418362386766, 2.546147761806365, 3.897028474077102, 1.8133306070681543, 5.021699724658843, 6.430577828038124, 7.9062185941203955, 4.617903482529425, 2.229398229429799, 12.669836167366276, 10.672310321561753, 1.3005777856995984, 0.7733865971526792, 0.16309230498248534, 0.488811623785765, 0.15504626737486932, 0.4662698543360157, 0.3390908932253238, 7.628986941229913, 12.815714017037424, 24.49733941785751, 25.51562789947756, 23.714234290584443, 34.90116350112423, 55.578620356898156, 47.32389427000477, 38.695715396634995, 22.673458860766505, 36.70101757972471, 73.13336849212646, 56.92519357127529, 63.1480142378038, 64.079216295673, 69.74006329813312, 66.92876723504835, 70.08750684799688, 69.12035234512823, 71.16717846162858, 62.98055648803712, 70.1938658375894, 67.14727463260775, 70.20310694171538, 69.25207338025494, 73.24233978025376, 68.34118919987833, 70.7405657922068, 69.08419593687981, 72.78656821097098, 69.00730179202172, 73.97281062218451, 70.01386042564147, 73.81888897188249, 52.87830775783908, 48.08847796532416, 60.207589826276234, 58.71538685214136, 41.07050657272339, 2.812190853780316, 1.134212538599968, 4.021703461485525, 13.66857163367733, 25.97444126682897, 43.12922923795639, 49.91181919651647, 61.5950890510313, 55.88217650690387, 28.057243362549816, 1.0191556931503358, 0.04091779791539715, 0.06556998637895431, 0.03592088600740798, 0.04383295398926543, 0.055105650512081, 0.02704660776221464, 0.03673114273096285, 0.09495405480265619, 0.056419177206173066, 0.01713498518051159, 0.024383232230320576, 0.011366665825217722, 0.02523659480615489, 0.0571681852001817, 0.014633953255871612, 0.02503574570460666, 0.10096481130007776, 0.04866506506298338, 0.004972908458101654, 0.12770474257488407, 0.057460551165164485, 0.0508397818362761, 0.3884791721019053, 0.10272954845981253, 0.17035183076175953, 0.16076462343335152, 0.35758051720838396, 0.19752627178545923, 0.12370370283362367, 0.14140178179067953, 0.12599052125287633, 0.24636618492584078, 0.2423590854290993, 0.256497789655001, 0.5088434440474356, 0.15036052122952479, 0.16796565073872768, 0.14114845183587846, 0.1477749438415612, 0.05690562771633268, 0.13866179172069798, 0.08455253431513425, 0.2071563953593854, 0.2033001538966933, 0.20999904121122054, 0.1440250200610007, 0.12728483446182745, 0.1348227259492682, 0.8372096272726214, 42.677270212481105, 128.9972000737344, 96.82363710095807, 113.54574449600713, 90.62759445559595, 69.2143637134183, 19.324270525286277, 0.19529729300448972, 0.28663939646174835, 4.3851804348730274, 1.8483594564660903, 2.288200196719939, 1.9555132163147775, 35.200507025564875, 113.03909194084906, 84.64286558089718, 99.38307777527841, 65.63666789762436, 82.85741052319928, 89.01466092755719, 87.46446178805444, 81.61827887258222, 83.45641136169434, 81.9357398248488, 77.91673029622724, 77.33598416851413, 82.52921012140091, 78.94101804302585, 76.23979937645697, 72.21041125635948, 76.73502214493291, 69.46930992987849, 77.70941734313965, 73.71795854260846, 68.3900619322254, 70.22567625968688, 73.56380155009609, 70.63007262445265, 67.74560866817352, 72.97210416486188, 73.33948904468168, 35.68760656541394, 55.43837993375717, 45.54149866104127, 64.3546647410239, 49.20256445484777, 36.10346017345306, 29.21428372783046, 18.34767487741286, 4.505923246183704, 1.1601713972706948, 0.24768983164141256, 0.22008242836642652, 0.43144242477513134, 0.5596101908914505, 0.30476684471772564, 0.7555079436109913, 1.4882909001842624, 0.5522837549928696, 4.551468828032094, 2.047293981717479, 6.602698785643424, 2.197079124950594, 8.550921909270748, 10.35013468034806, 12.560314766822323, 6.39577659868425, 1.3177582573506141, 19.59740084986533, 11.036759307307582, 1.5618599783028326, 1.9540705195357724, 0.6095945474601562, 0.8738090182023664, 0.4933069970819258, 0.5720517652169351, 0.45813960834376277, 11.474005522266513, 16.983188198458766, 32.48847830680109, 36.64792437707224, 30.037589226999593, 37.74015149762554, 56.736076493417066, 53.70656328816568, 48.31995271867322, 30.609866957510675, 46.55481161609773, 75.3209763188516, 53.42077939741073, 62.963839346362704, 65.3648554894232, 66.11036469859462, 67.67972853875929, 69.68649156631963, 69.4287290880757, 69.4285721932688, 61.44080262030325, 68.97098064422607, 66.53714995230398, 67.97752272698187, 71.96126230301397, 74.06504123441636, 68.23041362147178, 72.76244563441124, 71.88044578798356, 73.93099031140729, 71.12002372741699, 77.84399386375182, 72.96593035421064, 77.25739555974161, 61.43217340592415, 59.49609148886896, 67.98626961246615, 67.21553956308674, 43.32305316002139, 3.612835349575166, 1.933568780941348, 5.725199858988486, 16.386002436760936, 35.315228508364775, 59.265228625266786, 67.59704497552687, 75.62637990520847, 69.74085561690792, 35.47606137491042, 1.8764096738830691, 0.47119328692074747, 0.16530997630569244, 0.12800920889863085, 0.27192094753826823, 0.1558727383493416, 0.1845526800400788, 0.21085943455897996, 0.230655039270078, 0.1260424160488671, 0.07876750562460193, 0.18240124467880497, 0.161796375328014, 0.15143528130025635, 0.21702487953007224, 0.1319020004161904, 0.17242776049721628, 0.27956322616627144, 0.23913839050839025, 0.11262371189772122, 0.2592034896294917, 0.13273551939956604, 0.3108618708868181], [0.010442312754270051, 0.04363439932105042, 0.0242892045137142, 0.09549886589088748, 0.022215507924556736, 0.03478897960796472, 0.09105559423445694, 0.014625003433696207, 0.06317925196321261, 0.028883640639363762, 0.04680787258210682, 0.055951128127954664, 0.0377510087714801, 0.08999835459455367, 0.04468293237169424, 0.006614633922224805, 0.028223751653586666, 0.0915907679366008, 0.08329407402103947, 0.1418959391453574, 0.04079386021100706, 0.05167277221898398, 0.04570679739117623, 0.057960316283448096, 0.032792125468052206, 0.04855456071034555, 0.0599371602067784, 5.967686666596321, 75.03877747443416, 86.88715950135263, 77.2462324942312, 84.86643283597886, 53.03432395381313, 19.49681558916646, 1.7966515859288557, 0.2467216344009484, 0.34851493914761855, 0.7082487150065361, 0.6172456207775301, 0.44924017943201533, 48.128333168645064, 80.32188846218972, 76.58933747199275, 67.57389514676987, 52.40996891452421, 90.1177098674159, 83.69805289853005, 83.66297121970885, 78.84954837060745, 84.37878808667584, 77.13591191076463, 83.49110080349831, 77.83767884777438, 84.62710549754482, 78.63119002311461, 80.88434850015949, 74.62566560314548, 79.63832916751986, 73.71252213754963, 76.9275006940288, 75.17648404644382, 70.20779025170111, 71.85822163858722, 75.94044408490582, 71.92278385162354, 70.028577158528, 70.0821175113801, 73.98384817184942, 31.94181561470032, 31.375233165679443, 49.03943307938115, 47.34028585495488, 30.144673855073993, 19.410509717079904, 9.423625738390031, 5.352608032764928, 0.27294995683816176, 0.16294308637659397, 0.07383815884109467, 0.06332249125285495, 0.026359641398753852, 0.0053902568798812655, 0.0780407639761125, 0.11167520311691108, 0.3276914436249964, 0.8212372456346789, 3.0008563687724457, 0.13481595373201755, 2.39468323126916, 0.5785279660936326, 0.5934517878678538, 2.9302980774833314, 5.025996190886344, 1.2923930248906537, 6.153433447883976, 3.3913006176871643, 11.619554873435728, 1.2583604575164857, 0.262022478686225, 0.07544987759883366, 0.04391920016778093, 0.045372721769156, 0.22122209140610313, 0.3419224154804984, 4.3975260949903925, 10.385395807604636, 19.137808892034716, 28.920407987410023, 24.32181335264637, 24.589062083152033, 36.15102283416256, 45.954814495578894, 31.91626725658294, 29.940084988071074, 54.374597841693515, 62.48294499612624, 61.15563061929519, 61.31057993058236, 61.2473552457748, 62.669814555875725, 65.15968022807952, 67.48852083759924, 66.8042790505194, 68.95907232838293, 70.20673905649494, 68.8861083984375, 69.08249362822502, 65.48913971070321, 68.36647279800908, 70.47504486576204, 70.10801299925774, 66.47365462395453, 71.08298870824999, 70.53955216561594, 67.22047390476351, 68.71947826877718, 68.71889775799167, 72.32744693756104, 57.047536219319994, 33.04152857872748, 52.080725162259995, 44.16944573002477, 30.550158677562592, 10.633730869139395, 2.798304437629638, 8.695288665833013, 26.16502138876146, 33.72993984530049, 40.47629102583855, 58.41605509481123, 59.383535154404186, 42.84167635825373, 8.083830869966938, 0.2460598416866795, 0.012998028992555075, 0.05254946025689283, 0.06925401893714744, 0.04045855118742874, 0.048802018601207, 0.04416350943727359, 0.07887154036471922, 0.03889476655111198, 0.03123300056153488, 0.03980411674767252, 0.06830151883825179, 0.04088818861712371, 0.06251804913664538, 0.04941876151508862, 0.050813608442343054, 0.040768180943785176, 0.02539260478149499, 0.05032353050586197, 0.05871989246037218, 0.05939167113073411, 0.07069693788165046, 0.07297711431859963, 0.04001255395011075, 0.06970840866767591, 0.062468310878161466, 0.056978930839367455, 0.05947995893356781, 0.003190873511841581, 0.04163187996093785, 0.045683592587949774, 0.05818415568360399, 0.017366043044134014, 0.07851555462806456, 0.03324620110253173, 0.023927503761144418, 0.0435922836374131, 0.0762268056672427, 0.0529215568225951, 0.05730916453044742, 0.10920359662944272, 0.06617870452182908, 0.02974968197034492, 0.04949201867284794, 0.02517459339522306, 0.06483494033736568, 0.007914546276292494, 0.01900121366845504, 0.04507776259654953, 0.04491920154842158, 11.263784131696148, 90.3907617445915, 93.34851910991054, 95.39181509325581, 86.05895888420844, 61.363316197549146, 31.787260501615464, 2.7013579107099965, 0.1300111728449983, 0.6273390436845442, 0.3527142960698374, 0.5778504379333989, 1.0417500162316908, 56.39703073809224, 88.71860827169111, 86.8185729365195, 75.72283883248606, 59.99924528983332, 91.05954939319243, 87.9774058249689, 86.28880977630617, 80.77394162454914, 84.18957294956331, 80.69469405758767, 82.24281434089907, 77.08236371317219, 85.50486133944604, 78.3186791020055, 79.19867069490495, 78.22308309616582, 79.84601082340365, 72.52514223898612, 75.46131087887672, 75.8717869174096, 71.15043778573313, 71.39644099820045, 75.03976591171758, 73.54303652240385, 70.15619539445447, 71.45556680617794, 63.046401316119784, 26.34958459484962, 35.19764761770926, 53.303088680390395, 58.106646768508426, 32.4052809130761, 23.588553705523093, 23.037452851572347, 13.814524008381753, 1.1081188484545679, 0.4545306294195114, 0.02696993576753284, 0.08887145457969559, 0.044460291899139845, 0.075657655965657, 0.018297119494227153, 0.1902361024892138, 0.8767559439424546, 1.138382998685683, 3.702312948242311, 0.48093363522521915, 1.9707529727489719, 0.5376149485668829, 1.9571584054539282, 2.8477613579842354, 5.0934246759260855, 2.4104925893968154, 20.891806540950654, 19.627456011310702, 23.850285622381396, 1.8707317979105058, 0.2688197929772639, 0.062120633365045634, 0.08029870854149904, 0.05405320275214411, 0.48228047908313815, 0.4553736938584236, 11.201359610403738, 22.284757860245247, 19.520947971651633, 27.879263854795887, 24.55032475533024, 24.615581227887063, 49.993796733117875, 46.897924869291245, 34.67837679770685, 28.06832798065678, 54.06134951499201, 67.31046092125678, 57.9763573984946, 61.43498966770788, 61.6506298126713, 66.87779211228894, 65.68978463449787, 68.85156016195975, 67.07851548348704, 68.9044572461036, 69.88422609144642, 68.587200257086, 69.029478872976, 68.32762564382246, 71.07887806430941, 70.48548621516075, 69.63925053996425, 69.51778258046797, 73.4910886518417, 71.73429043062272, 70.11479869965585, 71.96378830940493, 71.43795536410424, 74.32397257897162, 58.686898677579826, 40.53417736484159, 61.594230051963564, 53.18012629785846, 42.766323704873365, 17.12798837692507, 5.985159354825174, 11.145653128623964, 29.849089922443515, 44.72054266160534, 54.6822528685293, 62.899940013885505, 68.87532188046363, 50.89454158659905, 12.185530335672441, 0.3355133851930019, 0.035960753222987536, 0.012635612905385995, 0.07238515817950811, 0.015151117188525538, 0.0776870611814722, 0.10753823639524561, 0.09129085983600348, 0.04079593630928186, 0.03895755894782563, 0.07589630767582886, 0.05642431382570536, 0.010226198393220623, 0.12269972928709562, 0.010963977453479124, 0.09227981039833638, 0.10174154784650573, 0.02462672753139369, 0.05312675730355325, 0.04483051537986725, 0.038117738891272776, 0.06841501476423395, 0.0766209042781303, 0.20662617058523242, 0.1288029602578571, 0.16402657984966235, 0.15683423998134752, 0.2386921136489799, 0.13753152091897305, 0.21909239762012037, 0.11839551791068047, 0.18866007576786703, 0.10511228108718511, 0.09933502818908423, 0.09791943560084028, 0.13186942635765, 0.30092902000873323, 0.1369427823491635, 0.19515132261139734, 0.17037746406370596, 0.2710343693052569, 0.2182250481940085, 0.32700349666899253, 0.15622584359540095, 0.2684463097924187, 0.21043682981642986, 0.07039944295801463, 0.09865622832289628, 0.16946837816747928, 0.3367005150404669, 10.40548618762724, 101.921172911121, 107.81659726173648, 103.86848065160937, 110.16748551399478, 81.0671466396701, 42.626534354302194, 4.475534683273685, 0.3683359013690103, 1.4281292187590755, 1.6242051941733209, 0.9581393640368217, 1.2635621332353162, 62.675250960934555, 98.92024593968546, 97.4079918092297, 86.87033253331339, 66.45863194619456, 94.57706820580268, 88.80856390922301, 87.14525930343136, 79.38128840538764, 85.41527440471035, 79.57329627006285, 85.52687368085309, 77.02927835526006, 85.20273685455324, 76.48800696096113, 78.48243805669969, 76.85235592626756, 79.07076220358573, 71.50863647460938, 74.48344046069731, 75.87468162659677, 67.86656671954741, 67.42410767462947, 75.52196641122141, 70.40098267216837, 70.0798111577188, 67.18282699584961, 85.82905307892831, 40.5832266038464, 46.13065827277399, 59.62189758977583, 60.971808741169596, 41.70410663850846, 30.727773404890495, 28.339181369350804, 17.79841949862819, 4.383522743178952, 0.6968142705098276, 0.2614748177509154, 0.19438495889546412, 0.19507529604579174, 0.16862108492322508, 0.2319899781216537, 0.44345618496018074, 2.09482612148408, 1.6550945947247169, 7.862104187088629, 0.19475333993473362, 6.92072848158498, 0.8849089580678171, 1.89503921616462, 5.862891231813739, 8.934516964420196, 2.0500446663748835, 31.016483383793986, 26.56474424946693, 29.589882050791097, 7.755163706118061, 1.0151283382888765, 0.2098538675495694, 0.16564958308252598, 0.11166248605736803, 0.7077678569382237, 0.667475677065311, 15.190721904077838, 31.468915054875037, 25.98202124718697, 38.05798899742865, 35.419755751086825, 29.442087142698227, 49.919703160562825, 53.59781949750839, 41.884241488672075, 39.40838652272379, 69.11100925937777, 65.44656238248272, 57.91597643206197, 58.06204941964919, 60.4297411057257, 65.30518054962158, 65.8518648147583, 66.46056175231934, 66.18626256142893, 66.42893960399013, 68.5282156544347, 67.6586026530112, 69.93852738411196, 68.48208073646792, 72.40609830425632, 72.49863486136161, 72.95734036353328, 70.73672186943793, 74.81362558180287, 72.74831725705054, 72.34876894181775, 72.0815613961989, 75.55320416727375, 76.30330254954677, 65.98124027252197, 47.27888507227744, 66.06674009753813, 61.879543258297836, 48.154463998733036, 19.238535358059792, 9.178476622027736, 11.380388352178759, 32.412274499093336, 56.034438994623, 71.0795448672387, 84.67159302003923, 84.9226874689902, 62.23915007806594, 12.396210643552966, 0.692681685811089, 0.12335527072390243, 0.12099602635228827, 0.18424886489106765, 0.26821283683661495, 0.14232985134566986, 0.17764465072222296, 0.3972486725016948, 0.23657455469571778, 0.10713021796677383, 0.12309644025780501, 0.11028957222738575, 0.11729068122804166, 0.28754442209197634, 0.11791769355054825, 0.3555160941135499, 0.28180397205775787, 0.13671537680972007, 0.14114492783142676, 0.20157659396288857, 0.22392782202411085, 0.25336977605137134, 0.2283809225886099], [0.1307147479946575, 0.03547163289641181, 0.004389875328108188, 0.10930965384168011, 0.057336525360663096, 0.08548169171497708, 0.056074621501348676, 0.03036629081883979, 0.07315255611413911, 0.06110122314684334, 0.021431121990204822, 0.06930883252812971, 0.011118777009898858, 0.09097518564592447, 0.05519193499499271, 0.02136412377078687, 0.0641188396501445, 0.060470472315266255, 0.05533291815569805, 0.11754206531951505, 0.04342177544810599, 0.08059093278021583, 0.07040297462334556, 0.029662259846865654, 0.07417646326845692, 0.042027625660862655, 0.050893764221860524, 0.40977200373045863, 46.282367706298835, 89.30883869048088, 78.9249598595404, 94.76846418073102, 76.81454427780645, 41.774956410931004, 7.2038427091413935, 1.1826468235062015, 0.4072452312515628, 0.6620873210410918, 0.1862536710236342, 12.386480223747993, 64.4298565772272, 82.58310348756852, 78.35723600079938, 59.727652534361816, 61.45184409233832, 92.84119190708284, 81.88129732685705, 83.49645091641335, 80.1013178979197, 84.1762996489002, 81.59883176126789, 77.74926862409039, 78.8336000134868, 79.45464457235029, 75.85956481195267, 81.06105127642232, 76.80728789298766, 76.10490906623103, 78.45742117974066, 77.79719998759609, 73.86908746534779, 74.09903249432965, 71.65091653023997, 74.53545893392256, 75.02459418389105, 69.02561141598609, 66.40265972383561, 74.18257113425963, 49.02807389536212, 27.083110963144613, 49.77426559694352, 40.49968404154624, 28.368424600170506, 23.929327264908824, 14.689886223885322, 4.831451043005913, 0.7657654931949032, 0.3723351867689241, 0.07157931029195748, 0.16703370477884047, 0.038481473607281526, 0.03446816113747416, 0.0847685634489021, 0.1046619286400176, 0.14922281937493434, 0.7454432030358623, 2.0919159679643573, 1.9071272255912906, 0.6450438871979713, 0.7661388538056805, 0.40121400488480446, 1.860995984846546, 2.7236389344738376, 5.541771688768941, 11.591114747908808, 14.054515207967452, 12.001278958012982, 0.9028302673851291, 0.24048707297732755, 0.1286109786240324, 0.12363911396072758, 0.18263071865564395, 0.05024717452244894, 1.2521091800543571, 8.29334476301747, 13.062700763825449, 21.485396469793013, 29.015268548842403, 26.15291499322461, 24.250283048998927, 25.56266692376906, 38.65022374737648, 28.295919587535245, 29.60946056150621, 55.363329302880075, 69.15986630224413, 62.407976735022764, 62.795110748660186, 63.21341976042717, 63.105625183351584, 66.39907467749812, 67.77945087802026, 70.90938460442328, 70.6001998532203, 66.72318012483659, 66.88050639244818, 70.98880475567233, 69.47624468034314, 68.69521448689123, 71.39537411351358, 68.2160577466411, 68.64827156066895, 70.83299252294725, 70.9402693471601, 67.62225012625417, 70.65439131952101, 74.4574979043776, 69.52008893412929, 62.455060866571245, 29.533880410655854, 42.31993836741294, 45.78285778722456, 34.96863219045824, 14.358868579710684, 8.144821764961366, 24.95046142608889, 30.789558579844815, 46.46338508975121, 66.4340857536562, 74.91393627658968, 51.26867686548541, 21.044016076672463, 2.2391364939751166, 0.04397514373845151, 0.044811604499456384, 0.048055688084493724, 0.02829589032297654, 0.09273133496002806, 0.0912496979318319, 0.039282115927386674, 0.08983214415850178, 0.06067311023211768, 0.0962429134655864, 0.03084161581711904, 0.06096183344902051, 0.12948171415876958, 0.05764993959136548, 0.04346803949785329, 0.06252218984187612, 0.05123998999835984, 0.15747157916907342, 0.049386723718095216, 0.036514833975102634, 0.029381561400969664, 0.09670642730329307, 0.0372326506992742, 0.01378236130075229, 0.016240839914028204, 0.09650347529039269, 0.10592732202982712, 0.1087498427518914, 0.051538028844421914, 0.06086299278502984, 0.03346632880669448, 0.11129318571258938, 0.16243045098118244, 0.010349118158281332, 0.032187969378766515, 0.018570235584892573, 0.10692382621909342, 0.05552971465212684, 0.03566633031192807, 0.05112523768818186, 0.028452576370909814, 0.011349472896977058, 0.0736297522821734, 0.0069901955993695855, 0.0413413449460941, 0.09056980255991222, 0.02355352644958804, 0.07421298267980737, 0.09318771651915966, 0.06612496345394081, 1.4954287558794024, 63.81593896496681, 104.58883177849555, 84.95644338669317, 101.57860094501127, 71.82882739651588, 61.05037381572109, 15.082558624206053, 1.417872220758469, 0.2826682418104141, 0.5909668437896237, 1.7726488868075034, 16.747108582527407, 77.57828466353878, 89.44008119644658, 87.59258993210332, 70.09640278354769, 67.61431909376576, 93.18945915468278, 84.40400892688383, 85.39879260524627, 80.83974330655991, 85.22564349635955, 83.0404047812185, 78.62695386332851, 78.78592752641248, 80.49652022700157, 79.03039316977225, 79.93045160847326, 76.72171746530842, 76.96641845087852, 75.5244767281317, 77.22274534163937, 74.9216555010888, 73.66196278602847, 71.54649519151258, 75.09328273034866, 75.01895381558326, 70.3384522468813, 67.25397094603508, 70.36886630519744, 37.95212422647784, 30.50643797843687, 53.08801727910196, 54.25235325290311, 27.832130693620254, 25.42469951414293, 25.269940437809115, 13.497450390169698, 2.1109482886329776, 0.840699004550134, 0.1377935076673185, 0.10736228898167612, 0.1054180344386447, 0.053451930983893337, 0.12914638215255353, 0.04294672815669929, 0.09612626125735622, 0.14556641960817, 5.546502067196754, 2.116480056316622, 0.6801618479432598, 1.5476434701873412, 0.7411245509020744, 1.8058386348908948, 4.377824029614849, 2.495838216235561, 31.849686984092962, 15.990799127086518, 16.46163848138625, 3.8569450378417973, 0.12454168810959786, 0.08593104824784302, 0.04282140383316625, 0.0551086918811404, 0.11791960877035895, 1.748112009898309, 21.81805660647731, 19.479508130781113, 17.73758157607048, 26.437751631582938, 27.21638329567448, 21.778689738242857, 33.96234812275056, 43.32057029970231, 30.95813224392553, 26.310888451914636, 53.09854099827429, 71.9746454300419, 61.83514595031739, 62.925039260618156, 65.00203624848398, 66.24403907406715, 70.7350274055235, 68.7458993542579, 69.95169085841026, 72.1810640827302, 68.9481367603425, 66.59552266520839, 71.76297864606305, 71.1740347646898, 69.6094326819143, 72.31968064461985, 69.99522916732296, 71.4646823944584, 73.79519001130136, 73.79350339212726, 69.36529651764901, 72.05162586704378, 76.3827540797572, 71.48536113000685, 64.8260316541118, 38.28148957221739, 56.00457406813099, 55.012469368596236, 48.86944147848314, 20.749032266678352, 12.102736946075195, 31.254588903919345, 36.79623703802786, 61.09631261517925, 71.01848140839608, 77.2151751672068, 66.26254481654014, 32.42182743164801, 2.874559236149634, 0.07994221718681437, 0.017955019101200086, 0.06747828841569924, 0.02062666646745657, 0.03166554337968269, 0.11296503471150515, 0.0452237100070042, 0.05564452824933876, 0.0850904276294093, 0.07784086099315075, 0.02468834589836338, 0.04545061758929684, 0.10924213851291327, 0.12822938256806907, 0.036790514545094584, 0.06021627668111075, 0.11681730783874951, 0.05604592001726551, 0.005008357261577922, 0.0957957479441839, 0.04009330344776954, 0.09071599511850266, 0.05533376468285438, 0.17519476282740795, 0.1739687770004234, 0.14597586296018095, 0.23520822156100507, 0.26241143684714074, 0.19008722096200914, 0.16208995554235675, 0.10650296049613146, 0.14807119004188046, 0.18033443138964717, 0.09045757067900512, 0.15286564406368042, 0.1492763995643585, 0.2447800764874105, 0.14191962658397614, 0.18575404380117694, 0.16482507329313986, 0.1499361085194734, 0.10104166524064156, 0.14447407015869695, 0.1125967379419073, 0.1216335877055122, 0.27156483922754565, 0.16250532841490162, 0.18585337476143915, 0.19798601647057842, 0.2869066079297374, 1.1918583872818178, 67.36821389967396, 119.17999390632876, 95.94319835785898, 119.36601623412102, 101.72838841715168, 82.74319894852178, 25.174750397282263, 2.383683189269035, 0.5169914326360149, 0.9652655751955126, 2.92222436877989, 21.966996846660493, 90.56967673763153, 98.14470706447479, 97.15959595095728, 79.95935947664323, 73.56464093731296, 94.93907159374606, 88.31116030293127, 86.13695129271477, 81.65173669015208, 86.32967302876135, 85.04308854379963, 77.86642197639712, 77.80859839531684, 79.13119023846042, 78.29131664768343, 79.09348057162377, 76.68449417237314, 75.23610407306303, 76.7302054743613, 77.44792861323204, 73.35894400073637, 70.91331481933594, 71.12112983580559, 75.39812149540072, 74.53022649211269, 71.68695526738321, 64.50970426682504, 82.32676875206732, 64.35267609934654, 35.81543268695955, 60.923602811751834, 51.32030702406361, 34.02161905842443, 33.371917663082, 31.395868755156, 19.68188281982176, 3.78435863602546, 1.1541168511875215, 0.17194017617692872, 0.29391533184436064, 0.24785329948269555, 0.12386638926522386, 0.22890192366415457, 0.6585313247576837, 0.2653981072287406, 0.6989811961689304, 6.642977114646666, 3.2830400140054765, 4.131105965183628, 2.141299589026359, 1.1885117475063571, 4.215619804397706, 7.981371696918242, 9.71615610584136, 37.969484636860514, 28.90510682136782, 22.510611857137373, 7.413227654272511, 0.8660467702054209, 0.208137953173249, 0.19906413200641834, 0.18795637804413998, 0.2932134727316518, 1.8917902679212633, 27.873813721441454, 29.011722726206628, 27.843931144283665, 38.01732186348208, 32.03615057852961, 30.554241864911972, 34.73583952073128, 50.15604557529573, 38.538357750062026, 39.014996328661525, 68.32081640920332, 69.99684518383395, 61.82284931982718, 61.07846190852504, 63.01214333503478, 65.09915021158034, 71.15602324085852, 67.74160785059776, 71.86384631741431, 70.803417851848, 67.97784436133601, 64.58835955589049, 73.2387782681373, 72.14488414026076, 70.55603396508002, 73.61434521213656, 73.25476584895965, 73.70936070719074, 75.81088035337388, 76.58569751247283, 71.09247299932665, 74.75053817995133, 79.10868367841168, 73.32539989102271, 70.84217086915048, 44.67053636427849, 61.82180989173151, 65.87779952633765, 59.316486158678615, 25.93310340758293, 13.623520270470651, 29.390480518341068, 41.1197833091982, 75.0734982951995, 89.11561489105226, 96.81946369909473, 74.52438216055594, 31.924559147127216, 3.637346240781969, 0.25938986349971066, 0.18125683189399783, 0.13301192392264644, 0.07311887122810849, 0.21970365917490375, 0.3211327197570955, 0.15347108335023926, 0.2594424784183502, 0.17794704094769495, 0.2653970347056466, 0.0881868324452831, 0.11355671505894392, 0.23682042295413636, 0.20377465343523413, 0.2132290057958134, 0.17399686178372753, 0.27346630009912676, 0.3745529500226821, 0.108120218069563, 0.15520916831108833, 0.1275268876023831, 0.18464831845654597, 0.15839108386107031], [0.0537646250919469, 0.09999479077035382, 0.01934263607366912, 0.07097757121007289, 0.05804722512801809, 0.06396846808192712, 0.045362494495366855, 0.05239998884198647, 0.018977367266592, 0.04639272570549961, 0.020883512765830083, 0.03304087038662645, 0.042819174517306595, 0.016504607816797592, 0.06116052984350151, 0.053145978449573444, 0.035048338674729874, 0.10078171628617472, 0.02455829481233753, 0.10827829265185904, 0.0548998486521023, 0.0406298752603752, 0.1414229871044236, 0.030701308729006883, 0.07295940236579027, 0.031324685964312766, 0.08945085453770815, 0.09708838342058082, 15.649523504318731, 77.20367477786156, 85.00180952010616, 86.17701438165481, 84.61807620140814, 58.181775846788966, 28.726044739446333, 6.606637335592701, 3.320177995389508, 3.0377818067227644, 6.396767487449031, 18.114340920602125, 66.97706730135026, 76.76833875717656, 76.66404293429467, 47.955270351902136, 71.94649065694502, 89.26911292537567, 85.2622627442883, 81.26835638476958, 81.10911600051388, 81.04884486044608, 80.69754169833276, 79.58532225701117, 80.20101670295962, 78.90609325901156, 84.0563771032518, 80.48174073619228, 80.3243830896193, 81.18444904204338, 78.6824946249685, 73.72299486590971, 77.08924355045443, 73.2876588452247, 72.79031015211537, 76.34636232929846, 71.84485420103996, 70.30030327458536, 73.06379349000993, 71.86969064897107, 49.07569146925404, 30.681603185592163, 50.7836091133856, 32.82731029295152, 24.264733060713738, 27.664219910098662, 19.906012935023156, 7.238270332736354, 0.4293956829895897, 0.2858480276359666, 0.14614052589862578, 0.11373931977657542, 0.0706143459425338, 0.03361729026261357, 0.09234497383717569, 0.24241736939837857, 0.17806719417773909, 0.4997319313547304, 3.400084765688066, 1.61210039209935, 0.7047988065788824, 0.18162181150288353, 1.2697417048677322, 2.2922233227760564, 2.74257613766578, 6.187216331881862, 31.077572338042724, 4.089067717713695, 11.035363924118782, 2.1448986088075945, 0.5933124824397026, 0.0367172458960164, 0.1588498632754049, 0.0871455350950841, 0.23607966189663257, 1.6647436253486143, 16.120096137446744, 16.015718925383783, 21.917321989613196, 22.373368124808035, 27.04268309377855, 26.84446219475039, 16.83894499655693, 30.10526384076765, 35.414335035508685, 32.61198785997207, 55.63096830921789, 64.39200962743452, 64.86261167833882, 59.35919684748496, 62.583832279328384, 65.71626455553117, 66.21924969457811, 67.26676571753718, 69.4527026145689, 68.08352085851854, 65.94727254682972, 72.45024065817557, 66.74778123055735, 66.81124517994543, 70.52301545296946, 73.96122394069549, 69.10009722555839, 69.2855861110072, 72.45426500997236, 68.55215780196652, 70.44550157362416, 69.71120249840521, 72.08408740258986, 70.75636509926089, 62.13161437742172, 31.38982830509063, 40.07911574456, 45.50248676730741, 51.21714084379135, 22.42865981594209, 21.09832717526344, 38.86981764147359, 46.11174460380308, 58.0333847384299, 81.23105464443084, 61.148413458178126, 25.14704473557011, 7.5652062604504255, 0.20294044497272662, 0.013909511786374836, 0.13150132111003324, 0.05269476415349111, 0.06861608986171984, 0.06127190753637303, 0.048939301557238066, 0.04978850619086335, 0.10157785783972471, 0.0391818963051323, 0.10247210461285808, 0.06891476456075907, 0.06438499391679803, 0.12218563832462796, 0.15860174271848895, 0.13423758799270277, 0.058278748390054515, 0.027100379473619887, 0.029113775367037426, 0.024428331826422966, 0.043142149525304, 0.08168808560097411, 0.010176888186364405, 0.02695043691464009, 0.020391205513489344, 0.07413792138498637, 0.038972903688948964, 0.04884606099597389, 0.13527304775291873, 0.041340345201352914, 0.050622994275463205, 0.0496187947329975, 0.025055342233709754, 0.06811686866586247, 0.033706374796888525, 0.03270764512220218, 0.04942207484536114, 0.034254353658686724, 0.12057824030278191, 0.020827017611854022, 0.06786356169369913, 0.10486369321663534, 0.05484150722622872, 0.12627525315169366, 0.04983724470460608, 0.09428590355861573, 0.1190916543465949, 0.01469869055830303, 0.06620787714998569, 0.00768856039353376, 0.09045367895234978, 0.11195989671133219, 26.29259647861604, 96.14365500788536, 94.29759933102517, 98.22357023915937, 85.66404681051932, 66.31962314728769, 44.58084352554814, 11.144007694336677, 3.3821053562625765, 7.870740755911797, 10.761628573940648, 27.479013435302246, 78.8404720060287, 88.15075889710458, 87.29036346558603, 62.33257309083016, 78.1621608426494, 91.65827566577543, 83.95390910487022, 84.59342802724531, 84.03938539566533, 82.42849150011617, 80.6098767249815, 82.24406165461387, 81.617204143155, 81.61876524648359, 82.22078631001135, 80.92106972971271, 80.28825806033227, 80.84658392014043, 79.8989785102106, 73.72287719480454, 76.09319686889648, 73.61355289336174, 72.69043091804751, 78.43832708174183, 71.16022017694289, 72.23788353704637, 71.44848300564674, 72.57067311194636, 40.342091052762925, 29.87172199833778, 56.08161726305562, 39.78290619388704, 24.52297995167394, 25.15081217212062, 26.51074301811957, 14.621842907321069, 4.954259962804856, 0.8490061555658618, 0.10772944428026678, 0.09831369509019199, 0.1726848442828463, 0.0074859631751033094, 0.051075644986403566, 0.508155251943296, 0.29812605751137583, 0.0821300953506462, 4.545157244128566, 0.29873865205914746, 1.0801397239969623, 1.4543491601943972, 1.6948782147899752, 4.893348495806418, 6.768245360543651, 10.856426377450267, 42.17883110046387, 7.219184079477865, 9.23011854771645, 2.609401619242084, 0.4865315316184875, 0.09424005319634754, 0.1744985727653388, 0.11521697314756534, 0.23905056618875076, 1.8833629330319746, 24.422216223132228, 10.979853560847621, 17.823104935307658, 25.1655642063387, 28.149430828709757, 24.509353637695316, 21.407192253297378, 37.67939790602654, 34.64787252487675, 29.53209573222745, 58.697351794089045, 65.8225803990518, 66.35229649082308, 61.07894828242641, 64.1307483949969, 64.9384742398416, 68.63786159023162, 67.02329635620117, 68.87514145143571, 67.51414960430515, 68.76230270631852, 69.53667271521785, 70.00190504135625, 70.15699555796962, 70.41055325538882, 72.68475917077834, 70.87215346674766, 71.24216633458292, 75.10068816523399, 70.66550731658936, 69.70741348881876, 70.648131216726, 78.13000525197675, 74.35502206125568, 67.14443483660298, 42.03043606973464, 49.25556352061611, 58.40031070093955, 61.07812066232005, 34.06385514043993, 29.48000861752418, 48.58703867081673, 57.97332148398123, 67.06141394953575, 76.5139102935791, 71.09049612475981, 42.021732330322266, 11.94979000476099, 0.3752709582688347, 0.03545557952395851, 0.12334725744421444, 0.014398384091985083, 0.05658361031824062, 0.04040630399099281, 0.05554422818785233, 0.05517536834363015, 0.05644521653471936, 0.014779850870611207, 0.05449072705701955, 0.05068197155431394, 0.08604008554210586, 0.11401374013193193, 0.07172390938766542, 0.0319332336526244, 0.036526221872097066, 0.07547705073750789, 0.08882734323701552, 0.056144040558607354, 0.04845062556165842, 0.05581405201566316, 0.1524488462675964, 0.10997855585188636, 0.08959800470620395, 0.17929055998402257, 0.13302513127846102, 0.25166196688528986, 0.17747868543430684, 0.15655098663222405, 0.12065717800249978, 0.21831999713134384, 0.22718738824609788, 0.12410407570461113, 0.11692318118988507, 0.14842199702416697, 0.08383294026697836, 0.19609742587612522, 0.16402472591688558, 0.18064416073743375, 0.13190066742320217, 0.17048649369708954, 0.16989674389121995, 0.2548455065416713, 0.16343512932860083, 0.17033554373248933, 0.30628317786801246, 0.10801254441180538, 0.16992901151459064, 0.21110747850710349, 0.19736810527261228, 0.2233636748766707, 21.74973087926065, 101.77311128185642, 107.17871789009341, 110.69360086994787, 105.71011973965554, 80.35643669866747, 61.50202689632293, 14.506815479647729, 5.3138584475363455, 15.119229843539578, 20.43191844417203, 35.47819514428416, 90.68898739353304, 95.95655795066588, 97.96409760752033, 67.15686090530889, 83.55657300641461, 91.30763930659141, 90.02735414812642, 87.82550027293544, 83.68216729933216, 83.46187130097421, 81.50227869710615, 82.59931856586088, 81.76054323873213, 81.82995350130143, 83.06888118866952, 81.64105999854304, 80.03260581724106, 81.91364903603831, 78.15973681788292, 73.4779957802065, 77.2621573171308, 73.66408871066186, 71.73771073741298, 80.18887304490613, 72.71955059420678, 71.61593683304326, 70.14381639419064, 78.90189632292717, 59.707989692687995, 41.45622853309878, 61.9525856356467, 42.91414999192761, 33.66390282107938, 32.955965995788574, 30.90984590591923, 17.27317490885335, 7.305184987283523, 1.215864273328935, 0.27725720958363625, 0.38908956031645503, 0.17529902739390252, 0.10033314116299154, 0.1724252783723416, 0.8082538939291432, 0.5638602628342567, 0.5715380572984295, 13.311379032750285, 3.9161201205945786, 5.0123973334989245, 2.826209895072445, 2.5484249428395302, 7.243708698980271, 7.6790510935168115, 11.687294206311627, 55.436603100069114, 16.246013045310974, 24.9734406317434, 9.137128956856268, 1.159174747524723, 0.14960662942499886, 0.23747640872193923, 0.17808153534368162, 0.3314146002934825, 2.8445364342581843, 35.500682092482045, 23.465250076786166, 28.257635293468354, 32.237978096931215, 35.977101018351895, 32.239688250326346, 27.135621693826494, 40.634970511159594, 44.42078336592644, 44.05288857798423, 67.01490248403242, 66.6490787075412, 67.08883916178058, 59.03915497564501, 63.05245353329567, 66.94199346726941, 68.20093308725666, 65.48440148753505, 69.51456623692667, 65.89866653565439, 66.00886160327543, 71.16961817587577, 69.13302944552514, 70.7432016249626, 70.94774538470854, 75.50086405969436, 75.24450578997212, 72.52285157480549, 76.8340306128225, 72.9691388530116, 74.76072065291866, 69.84670469837805, 79.93053790061705, 75.9870026188512, 70.15916855104508, 49.09155745660105, 58.19836747261786, 71.01196242916969, 72.49783469784644, 40.33216353385679, 29.14700919581998, 50.683588673991544, 66.88448367580291, 80.4426896187567, 95.10814928239392, 81.19326653019075, 42.337965580724905, 11.31712346307693, 0.4071906551478371, 0.07795354486593316, 0.2311693140936475, 0.09733602900298373, 0.08867551227130237, 0.19947205850433922, 0.10774400761170734, 0.09062536691706027, 0.18418642872523877, 0.08968517785110781, 0.166343214410928, 0.1409067051304925, 0.22081459391741987, 0.3398810975974606, 0.201763013798383, 0.29052269614992604, 0.19802274272566844, 0.12816203577864554, 0.11683807648237675, 0.13269577475805439, 0.13494385977185544, 0.157823933648967, 0.38254496310987784, 0.19500323781563392], [0.09700892478107445, 0.08171856823948123, 0.01728729112073779, 0.08429490660707797, 0.0558837162210576, 0.015266276482913285, 0.11935737194313158, 0.034536415741087935, 0.048911672596248894, 0.016421550479266914, 0.057716045318351644, 0.02195967669268289, 0.0039038519119663586, 0.04527162880666795, 0.034936738816360315, 0.015197746087646773, 0.10807634421413946, 0.03487854677763197, 0.05776331294327975, 0.02781607987990062, 0.04789223556496924, 0.031329546792192325, 0.06846854132750342, 0.1430719300744034, 0.07766340438637041, 0.0619376264512539, 0.11532711360843913, 0.06063306681631554, 2.471647733642209, 33.14300421745547, 80.1976199303904, 83.63505178882231, 93.47618441427909, 75.76498862235778, 43.90943573367211, 14.977758776757026, 17.1127676194714, 10.154689838809352, 6.236013068306831, 29.14813295487435, 73.43722666463545, 71.23329393325314, 64.92733470855221, 51.76073428123228, 76.30345159961333, 88.75702396515878, 85.43298782840853, 84.41707041955765, 80.82735646155574, 81.31350286545293, 82.57374471233737, 83.93816471099854, 81.00937012703189, 77.49113744305026, 80.99282556964506, 80.02729492802774, 78.17704231508317, 76.52264933432303, 75.95183464788622, 77.73863900092341, 76.03778946784236, 74.65643267477714, 71.85835499917307, 75.5005894937823, 71.54859758192494, 69.11330776829874, 73.72219470239455, 71.52208235956007, 43.94940076335784, 39.708922447696814, 42.87620106051045, 23.427552177060036, 28.35761062560543, 31.421171965137606, 19.195605016523793, 11.190733909606935, 3.4864693303262038, 0.09070612024515869, 0.15885266715720778, 0.09522185615834691, 0.1659440672806194, 0.05889254569586727, 0.339815734975761, 0.19766101132958167, 0.031436695679721814, 0.18142992179960976, 1.678499867839198, 0.8581588225018594, 2.686708348412668, 0.7194622197458822, 0.7544267790452127, 4.151370400382627, 3.4687939045890688, 11.254213548475697, 25.263599926425567, 4.001571406279841, 1.2278404952056947, 1.0030519121116208, 0.871045463267834, 0.04021814130547066, 0.18251565224941702, 0.041379055624166806, 0.15183528644904015, 0.3296617911227288, 13.043319352211492, 11.431243842647923, 18.8604933984818, 21.60639178368353, 26.21776353928351, 26.432317187709195, 21.05619699724259, 19.733197227601085, 41.72757417924943, 27.77867271054176, 47.03196794755998, 70.39529523541852, 64.08457033095821, 63.875802178536695, 66.07324338728382, 65.42221230845298, 68.4954873977169, 68.92998403118503, 67.1160525660361, 66.9368943860454, 68.46475170504662, 69.87846805203345, 69.12343532808366, 72.29771537165489, 72.94485153690462, 67.2386658576227, 68.89987591774234, 68.9575896724578, 69.97797073856478, 70.1219609475905, 68.63128769782283, 69.93546793537756, 72.71927602829473, 71.63090459762081, 60.288331816273356, 30.648614091257897, 45.37376634536251, 48.44011845127229, 52.13390857942643, 39.44660217531266, 39.03053675928424, 48.78321601498512, 45.50635030192714, 63.750808008255504, 64.75510343428581, 24.915813169171734, 9.104261455997344, 1.3048651814460754, 0.12033057173774128, 0.13679854331477997, 0.07070167230502253, 0.10230087630090215, 0.06499145210029618, 0.06187798267590904, 0.05312971440294097, 0.15867488879349925, 0.08861224873051529, 0.05057380760028478, 0.07886771758597705, 0.0780253732697137, 0.04875786129325148, 0.13366862981309816, 0.06716403914915939, 0.048662736155693574, 0.07232448401590509, 0.07643264583161763, 0.01131170284709022, 0.07649156565387404, 0.038901711138145584, 0.03871675070014693, 0.09229888598765097, 0.05203328170483151, 0.11978779078250933, 0.04005286549668639, 0.05082583903605419, 0.01824614400374553, 0.13225843048384114, 0.09023545114623924, 0.036368430742333015, 0.0674650197728507, 0.03371383266283139, 0.011776687573611498, 0.10719082318246366, 0.019722638666749965, 0.013936530749854303, 0.044537176483220635, 0.11761523437716308, 0.08196539410780515, 0.09786318176456037, 0.02729625666453954, 0.028286318054362655, 0.05395720427435252, 0.03423475712958363, 0.0771958532653028, 0.05493617271103206, 0.12006862329379206, 0.1627625654181165, 0.030852860072627667, 0.039395217318087816, 0.057970888296803164, 5.260225428688911, 56.85123728167627, 98.1634638386388, 91.62392354780629, 93.31159391710835, 74.76323096982895, 62.1731875788781, 23.703081030999464, 23.17720493962688, 14.137885185980029, 8.925728894049122, 42.09681434016074, 88.58771877904093, 87.83238011021768, 78.13055438380088, 65.77477062902143, 82.69343976051577, 91.16096619636782, 88.5453022679975, 84.72604336277132, 84.74789880937146, 84.08485351070281, 84.7024856075164, 82.48425191448581, 80.7453397012526, 79.3214173470774, 79.55369226394161, 80.55922323657622, 80.67825932656565, 79.32191941045946, 78.44162187268658, 79.57939947805097, 78.04436422163441, 76.46003261689218, 73.48074928406747, 75.59984114862259, 73.30445443430256, 72.38044600332938, 76.50511633965277, 73.95224171300089, 43.19359925485427, 36.30780389232021, 49.18180727189588, 29.56644000545625, 27.797137268127937, 28.369189462354107, 24.003564003975164, 18.006867977880663, 10.218219487897812, 0.6150334652873778, 0.22977907901569722, 0.06555360741913319, 0.1172608191207532, 0.10444679582912116, 0.14871813597217684, 0.1778067396052422, 0.02216154852161004, 0.30872243246243847, 2.5337405695069224, 2.7672998174544308, 0.6453657054132032, 0.215742678171204, 1.4514664632658807, 7.246731865790583, 5.137829338350604, 29.784786585838567, 14.596955468577725, 6.363387136690079, 8.229482693056907, 4.953708869795646, 0.6659427044853088, 0.10283703825646832, 0.06777215208257399, 0.04993851003687709, 0.23263197512395922, 0.15676861688975366, 17.84008291459853, 8.488398348131488, 16.430927303529558, 21.67775538659865, 24.610852810644335, 27.832660213593517, 21.88534094441322, 26.904917686216294, 43.82586179241058, 26.995893139992994, 53.894735074812374, 69.98987120966758, 67.10477967416087, 63.04407142823743, 64.98599767684937, 65.93748231087962, 67.48050351296702, 67.67515505513838, 69.34144066226098, 66.36294180347075, 68.86884996967932, 70.16913921602311, 70.61613252086025, 70.87841356954267, 70.96423502891295, 70.96683163796702, 70.01309948582804, 71.09600313248174, 72.7119255065918, 72.15399188380088, 71.03136247204196, 76.22190552373087, 78.45873909611856, 76.20166609364172, 65.49011245850595, 38.54428837376256, 49.19936772315733, 61.22586850197085, 58.98339063890519, 46.6981154103433, 48.78868379900533, 65.27967337639102, 67.81901974831858, 74.35479456378569, 78.18156873026203, 47.23938288227205, 22.558233353399462, 2.6788947418812783, 0.09275480789402801, 0.03813997842371464, 0.04270744442398991, 0.03791217834899022, 0.04968403861106885, 0.0689213912213041, 0.020745095999671087, 0.08572027447723574, 0.02563771652808834, 0.02298228532796906, 0.03133021711912607, 0.11333196018371852, 0.13130478891393832, 0.060746819381752325, 0.1035413105461386, 0.051629947904016704, 0.04235444643023995, 0.06258896589579602, 0.059621524321095604, 0.006767766279799323, 0.0427937787026167, 0.03260927177184532, 0.009521165761285493, 0.043466009364853946, 0.2974089992142493, 0.19017023424948418, 0.13515093333778844, 0.22905993695941665, 0.28365753711231295, 0.14584248705256372, 0.1641157218405316, 0.17720081002241184, 0.09801273744913841, 0.11445170493736384, 0.21141935290107805, 0.14000547929636895, 0.1214279467239976, 0.18154515674518001, 0.181355120974683, 0.17869085103513735, 0.2798857491823935, 0.12267761232872164, 0.16938052320432279, 0.09820730846014716, 0.18871161816341264, 0.1534178095959848, 0.2330481906932208, 0.32051914461678077, 0.23528274659427906, 0.20977388797027452, 0.20981199318362823, 0.13871704198179707, 3.2018079728849473, 58.05807213629446, 103.181791305542, 100.20374744169175, 105.58795359826858, 95.61349176591443, 70.6416279269803, 37.612650932804236, 42.01836693671442, 24.07682799523877, 11.160322793068426, 52.49855564486597, 97.85551855641027, 96.22942939881356, 83.73168330038749, 75.26399212498819, 86.02397134227138, 90.62794746891146, 87.75352478027345, 90.22948957258656, 84.5294306355138, 85.39490945877569, 85.75823076309698, 81.50053716474964, 82.17407088125907, 82.51985134616976, 83.92241247238653, 80.11921959538614, 78.62949555920017, 77.63602979721563, 77.26117672458773, 79.31021505786528, 77.79609387920749, 77.02757604660528, 73.40846000179168, 75.85790957173994, 73.54117731894218, 72.02786414853989, 77.97698574681436, 78.9986925740396, 54.950468463282434, 51.92760367547312, 52.580086031267726, 32.70749365129779, 34.95502548833048, 38.23944568634033, 26.380796855495824, 22.659314793925134, 10.525658784374114, 0.2620017943122695, 0.39427612878141866, 0.23267198023536514, 0.258711262816383, 0.22913680622173896, 0.6070481324868818, 1.0751958215428938, 0.1746852530707275, 0.3206407687356395, 5.885574298520242, 7.631614438949093, 6.9828622571883665, 1.4927288168861022, 1.898303486166462, 8.733693572782702, 4.739922535034919, 42.42379488483552, 47.25308764365412, 7.8965063152774695, 16.429175965247616, 4.648224384553971, 1.0278582068220263, 0.1714357532440655, 0.2663315087556839, 0.13032438023196113, 0.22629681103412183, 0.2627780252406674, 35.16206387550601, 18.315880144796065, 26.87203645706177, 28.49276177344784, 33.621560835069225, 32.58040297415949, 30.143222578110237, 29.519253892283288, 54.46511437816005, 41.24188277029222, 58.91343124451176, 72.38635309280889, 68.4721100714899, 63.66358234036354, 65.27583729836249, 68.20654207660307, 68.66073685307657, 68.74577383841239, 68.1210579410676, 68.27980410668158, 67.95260783164733, 70.020018546812, 72.11000642468854, 74.30119145301082, 73.6517567788401, 73.73975123128584, 74.21025522293584, 75.43110078380954, 78.24745670441659, 76.494627921812, 70.90506215249339, 75.73377440052649, 80.73026995505057, 77.87331750316005, 72.0019059027395, 47.555835785404334, 60.104329509119836, 73.04424439707111, 69.18992734724476, 53.1837623350082, 47.83415932809153, 71.21284269517469, 81.18313112566548, 88.07117400630828, 89.84643090155818, 48.633581515281435, 18.63192512143043, 1.7204061030380189, 0.20108856531160496, 0.1547212162685971, 0.1542246687195955, 0.24042354896664622, 0.18720732791529548, 0.13535223060077237, 0.17917815956377214, 0.20797197256357441, 0.21035963879717937, 0.1439790241420269, 0.2006257869183056, 0.24955300343853815, 0.21142246321805064, 0.14710965776635757, 0.16713531868111703, 0.1525305878491171, 0.10996428363385702, 0.13240104541182518, 0.12402336834178818, 0.20444357076719885, 0.12766658373537565, 0.13181866537178719, 0.2347248966895765, 0.14389380452132997], [0.06459507054739422, 0.06281870034252925, 0.02774731582781721, 0.08292596111254347, 0.14244258884460698, 0.17692164758280401, 0.08880521095688305, 0.03757171355368149, 0.011693992212625041, 0.024453695082376083, 0.04089519832163088, 0.08170488590915358, 0.05325449480404777, 0.07803606019625742, 0.031073625544987382, 0.06933582180570211, 0.030051520612511425, 0.03530909968239646, 0.05060727798169659, 0.0742072063768583, 0.08846856127943724, 0.017600973482213674, 0.029895880274594794, 0.020226833688455726, 0.10882063693697415, 0.09758492330870322, 0.024233410330188852, 0.01275009708479047, 0.1536932641700391, 18.883256873776837, 65.27518618491389, 78.59335484043245, 104.80215380268713, 98.60964913522044, 60.37678910839943, 36.05765865695092, 18.63872847249431, 7.086741328239442, 8.211261812717684, 38.77664173803022, 61.14644050598145, 69.61590459269863, 62.06158045799502, 52.009373326455396, 81.26186093976422, 90.48137634031235, 84.30300789494669, 84.67166362270233, 81.26125689475768, 80.77254526076779, 82.33741406471499, 83.41213564718925, 81.50602063825055, 80.79498121815344, 81.60132638869747, 83.48302072094333, 78.64265903349846, 79.95848871046498, 76.96816782797538, 79.03696706218105, 75.86169073658606, 75.140272725013, 72.83963003466206, 77.64935801106115, 70.43520927429199, 72.8345387981784, 74.3241451632592, 72.01788563882151, 37.23308709359939, 44.28612839791083, 32.3799325958375, 22.92824818241981, 24.46810991533341, 29.77587692199215, 21.578382138283025, 11.9331052226405, 6.423785263492215, 1.6313915891993431, 0.039230447127333576, 0.09602346757967627, 0.20782477642980315, 0.6808222770210236, 0.21738558436834046, 0.1055610170888324, 0.1008729343753188, 0.432824753825703, 0.5268215051581783, 2.1145404442664115, 0.9562951146114258, 0.9121246299436017, 0.3373170932454448, 2.230232713683959, 1.3757886208834187, 26.77567755022357, 3.533670887831719, 6.2707132966287675, 6.511615466686988, 3.8572598080481257, 0.09600592416621025, 0.17812982952642828, 0.07042152927287164, 0.36617029338113727, 0.016913405739732327, 0.5318766435788524, 8.935376944080476, 6.760389343384774, 14.576420880133107, 22.487728749552083, 28.129316914466123, 23.571410986684985, 24.193392992019657, 17.645266632879935, 37.845329853796194, 38.007939554029896, 42.67010011980611, 68.79452889965427, 65.7862239499246, 68.73223381657755, 64.55163048159692, 68.07477397303428, 63.963137672793486, 67.95570650408345, 63.91795981314875, 67.55239271348523, 66.02167206425821, 71.72471984740227, 68.41074851251417, 70.29581608310824, 67.37563502403998, 74.26494875261861, 70.02369773003363, 72.45431207841443, 64.2056421310671, 71.39869243867936, 66.77913665771484, 75.24674154097035, 69.42529309180476, 78.31824764128655, 49.82722151663996, 43.062697995093565, 50.38503746832571, 58.666153261738444, 56.13868382669265, 49.67692413637715, 50.761082941485995, 37.06976744436449, 39.60833326462777, 43.244919546188854, 21.855352463260775, 11.115318498303814, 5.6486008724858685, 0.03913115830190721, 0.07157030109796794, 0.11412828559837035, 0.14630166483261894, 0.3005154857472066, 0.040624336444682656, 0.03261800517418212, 0.029374982620919907, 0.10413090713442334, 0.12968457424111907, 0.09760934619172927, 0.09809994123755925, 0.04435537232747001, 0.06928672323063498, 0.26291628878924156, 0.07291501523145745, 0.04962994897317502, 0.04136376067875855, 0.08171119081277041, 0.03635883932152102, 0.07730666022267073, 0.06425768159510148, 0.027545915142963492, 0.08097570044018569, 0.0797142294205485, 0.10963831322207566, 0.031744850716824015, 0.0880270265042782, 0.049119680789449525, 0.03332541842434195, 0.07311144017524297, 0.07331295960372494, 0.04478083840841728, 0.04075351802091445, 0.037989656651212324, 0.018185004441728516, 0.025837429904288826, 0.03936952272910745, 0.010399755612466364, 0.19146879924641502, 0.014131375637295988, 0.07711071791427751, 0.02392552533907996, 0.04293894853382822, 0.0400898598825499, 0.03851271084239406, 0.12691105250269175, 0.08683458000661866, 0.05776555758089789, 0.07653786800801754, 0.056345134808291356, 0.027349564892750595, 0.04767939718740602, 0.4065568246428044, 26.54113942576993, 90.5721321413594, 94.1796693494243, 98.50454530408307, 87.38680670338293, 57.91739633006435, 53.82131222755679, 27.932337445597497, 9.453115097938046, 10.93514834680865, 47.74943613236951, 81.05541875285488, 83.8622433139432, 74.6277601488175, 63.880520789853996, 86.07811574013003, 94.0059946429345, 86.8199771450412, 84.66066529673915, 82.42740892594861, 83.56398628604028, 83.8612784108808, 84.3091973950786, 81.88215240355461, 82.76527404785156, 82.6414526662519, 84.67932793401903, 79.8840735035558, 83.70466601464057, 78.77834950723957, 81.1798834031628, 78.283385615195, 74.85114697487124, 74.65052558529761, 79.07281752555602, 72.85556270230201, 75.49500403865692, 75.8430673230079, 76.35543084913685, 38.79842658196726, 40.81151639261554, 43.75724384861608, 24.58369039720105, 28.230821970970403, 26.70400800243501, 23.733777499968006, 19.3069532609755, 13.093578642414464, 2.806468115698907, 0.28448953924159853, 0.08225358106316098, 0.4288344469762618, 0.5121526987321916, 0.1992291933105838, 0.11752441465373963, 0.20082941308857935, 0.735289289826347, 1.706015417172063, 6.466397402747986, 2.937273277390388, 1.8387889958197072, 0.732274090330447, 3.424740049146837, 0.7148539863767163, 42.93949634798112, 1.7757815122604372, 6.226148307323457, 5.558515796738287, 1.6772228911999734, 0.1325629657555011, 0.14140293092256592, 0.17399485463336592, 0.06491603074415077, 0.2749935116979384, 0.5759766481576428, 5.512378917586419, 8.990521546333067, 9.882361638930536, 24.62999397708524, 26.119827839636034, 25.276659457914292, 28.156691135898715, 22.14747686539927, 41.61822242121543, 37.270463358971384, 50.243035900977354, 68.28837840787827, 65.96016929995629, 64.9420435966984, 68.68089783576228, 65.72840429121449, 65.50706886476087, 69.40736786011728, 69.00745868682861, 65.58552411294752, 69.12227430651265, 73.85449624830677, 68.55138901741275, 69.80832038387176, 73.18163717946699, 74.38564008282077, 72.05827036211568, 73.1455199949203, 67.43327033135199, 69.58716930881624, 73.45875263214111, 78.82049145237093, 80.3509767593876, 80.50819320063438, 58.351284996155776, 48.04646153603831, 60.68321643337127, 63.45992895864672, 67.19452350370346, 55.47822336996756, 65.91827054177561, 69.05541358455535, 62.10091006371283, 65.58650862786078, 51.60278435676329, 26.502837481037265, 10.639879184384501, 0.3707721835422901, 0.04498176028831832, 0.07424264560423552, 0.09783191005549124, 0.07681704576938383, 0.027404081624662204, 0.14116881445290583, 0.07829834571889333, 0.2702856562550991, 0.0566770117579689, 0.14121405960571382, 0.10178490076214076, 0.0856542606808005, 0.04675543386368983, 0.10690674245838197, 0.09897212467847333, 0.02861158749569328, 0.05702227226368362, 0.06148027196045845, 0.06750913111553078, 0.05244870054265184, 0.06276830707887007, 0.03585439340602006, 0.05658858988974845, 0.033390543558785034, 0.24766412173067373, 0.12030955028509903, 0.24068977984209217, 0.2144539344214624, 0.1731253295175491, 0.2547232082654392, 0.23001411479086648, 0.10465858849666773, 0.14063880418337163, 0.14582975467126216, 0.28283132660773497, 0.2027436982720129, 0.13225179616241686, 0.26444490998983383, 0.36005639080559054, 0.26880330676513337, 0.10485030199971893, 0.08847565525361607, 0.13465308343931554, 0.25919346919944214, 0.1417642333094151, 0.25908290739020995, 0.22658032485313956, 0.22355366468189225, 0.10895940610357832, 0.17731898674561133, 0.1151689853999884, 0.12837113181669868, 0.3026180600206698, 27.63109157162328, 96.47762129383703, 102.31664980611494, 115.70136147160684, 112.54223746638145, 67.16977334791615, 64.89522618632164, 42.06297605268417, 10.672072037573784, 12.946949658855317, 60.01295005121539, 95.54379909269272, 94.93052082677042, 83.23202825361683, 70.22802183704992, 93.3817494300104, 92.68472071616881, 89.79114117160921, 87.50013966714182, 84.64571322164228, 83.44749973666283, 87.32834769833474, 85.58574845713954, 83.51218746554467, 83.54265643704323, 85.7467931316745, 85.35709781031456, 79.03492742969145, 82.17937392573204, 78.14065840936478, 77.22307482073384, 76.4452374366022, 73.66588515620079, 74.62765816719302, 79.2821858006139, 71.70501385965656, 75.18961614178073, 77.06574855312225, 75.61979032331898, 45.11299148682625, 56.01771400820825, 44.28170788672663, 33.11929348976382, 33.228107883084206, 37.00826860243274, 24.929480668037172, 26.84505839501658, 20.203305059863677, 2.681092985214726, 0.2357943094665966, 0.27499415521179477, 0.52605094328042, 1.1589537464803266, 1.2581464431939589, 0.22212593726092772, 0.19965590428440802, 1.3033315347087, 1.9621182425368218, 13.307697888343567, 7.539461783824429, 2.1635568334210307, 2.3435232668153705, 7.5983473466288665, 2.164232706831348, 63.89807731874528, 7.1452165130646, 6.403563974365112, 10.864439779712308, 9.832493605152253, 0.27024655512744383, 0.34205356973313517, 0.23653520841992673, 0.4464746939559137, 0.4721937977498578, 0.8182381646287057, 18.21397304534912, 18.47126680035745, 21.89109702264109, 30.005831756899436, 34.823939877171675, 29.034097886854603, 35.69046597326956, 27.194202292350035, 47.76536095526911, 48.42387199401856, 54.77265173389066, 67.92319005535495, 69.98514083123976, 65.72476825406476, 69.67252008376583, 69.42249251950172, 64.77940251750331, 68.58673741740566, 68.91863269190635, 69.27448580341955, 68.68722854122039, 74.30916170920096, 71.92108154296875, 72.69147426851335, 74.11592222029164, 77.6148803772465, 74.08569643574377, 74.39834856217908, 71.92203860129081, 72.01406525027367, 74.82204298819266, 79.3994568240258, 79.48486251215782, 82.97868236418694, 65.73708057403564, 59.41121532071022, 69.25703910089308, 74.47480340157786, 78.15482601042717, 64.40525547150644, 64.9315159551559, 76.53112165389523, 74.52662575629451, 72.77835476783015, 49.452697923106534, 28.654967469553796, 8.668932299460135, 0.3508670435797784, 0.16666022159399527, 0.13609449319060773, 0.5425601380486642, 0.4044748428127458, 0.15695963325279375, 0.21506265256433718, 0.33197887001499055, 0.4090548535027812, 0.23773805839159798, 0.2206393896091369, 0.24585057710928304, 0.157987340203216, 0.24550928493901608, 0.2236152887945214, 0.2191926632076502, 0.1171249074621066, 0.2105503946903252, 0.2352303002149828, 0.26024748360918415, 0.1658431275357162, 0.1871831501804052, 0.13415817531847185, 0.19248431007708275, 0.12341748472423324], [0.11013957987269087, 0.07963645617447554, 0.02743673995287428, 0.07880790910172848, 0.07529366461019363, 0.1528982487657378, 0.012134493726696218, 0.0633936608210206, 0.1024237874474737, 0.026958467431306362, 0.09140545126771735, 0.10870613743581119, 0.1826833642178005, 0.07750637934453065, 0.13181580020295036, 0.04441592391700514, 0.04128294223318658, 0.06108010976365017, 0.034027507363428036, 0.04419944279136197, 0.08628360957147614, 0.010653892832417643, 0.1198759828243525, 0.034014434073000185, 0.06599495067231118, 0.16355474629709799, 0.045822982285772605, 0.11464858953390392, 0.07185763003484857, 5.485762203893354, 50.410548563926454, 69.35663592430853, 103.55424388762444, 108.49984276679255, 80.8786218397079, 49.654331284184615, 35.28120979186028, 25.617905662905788, 17.45744393717858, 44.105836652940326, 72.84291698086646, 69.59866185342112, 59.29497588065363, 53.93740261754682, 77.52480706860943, 89.74304506855627, 85.47596916075676, 82.98634667550364, 80.77558902002151, 82.7103530206988, 83.70330887456095, 81.99832516331827, 83.93410898024037, 84.31515155300018, 78.48506604471515, 79.85313384763657, 78.28986537071967, 77.31001023323306, 77.88066018012263, 79.96540777144894, 78.5083806130194, 76.76325536543324, 73.52828056581559, 68.83194046635782, 73.68809361611643, 76.27392399695613, 75.67658624341412, 70.68104774721208, 36.42502784729004, 46.77888093456146, 21.45129930588507, 25.470663809007217, 25.737216318807295, 31.325889748911706, 24.980861756109423, 11.694176004778955, 6.404808346302279, 3.0888934769938072, 0.34552946386318056, 0.2087786171825663, 0.20533477617127283, 0.27683135662828723, 0.07514203282734079, 0.24163120997048196, 1.738356952705691, 0.9444951542442845, 0.43019615293991187, 2.0861277753306977, 0.7938882744600697, 0.5324911073811593, 1.092801747783538, 3.177822679281235, 1.2221539164743116, 12.852799046424128, 0.917025079890605, 4.71270275692786, 5.721877121156262, 2.5436592630801664, 0.020698270790519255, 0.395543881722035, 0.11929660584897765, 0.5944794488530005, 0.2631618965777659, 0.05787832189291235, 3.4696470201015477, 3.365589236059497, 12.015210236272505, 20.89998664394502, 25.855868016519857, 25.068338455692416, 28.29367206942651, 20.675532933204405, 26.23565543082453, 38.61660119025938, 38.99386652054326, 66.96496286699849, 64.05921613016437, 68.49989614179059, 64.91702671973937, 66.67542134561847, 66.88848449337867, 66.23310350602674, 64.78577636903333, 67.96021722978162, 64.78971050631615, 70.79052109872141, 71.04178028721964, 73.8463455630887, 68.74442454307311, 73.4514727131013, 65.96240505095452, 71.10301633034983, 67.75765034460252, 66.61674268784063, 70.58854256906818, 81.1715679783975, 72.2448653559531, 77.05339308707946, 42.92296748007498, 45.79783339654246, 62.321688513601984, 62.51444947335028, 60.42937632529967, 50.19790903214486, 25.8946406456732, 24.583100080490116, 26.38178921514942, 15.858365201180982, 9.414613112326592, 7.888429174500128, 1.0257849890378214, 0.02328997879709688, 0.15715336156708581, 0.11706082420724055, 0.2355190540754026, 0.08332095604630248, 0.10255820523466795, 0.11974496646754204, 0.02633791514522126, 0.09997625144258623, 0.16339622738380588, 0.16002246809582557, 0.008711955705357176, 0.1596405273002963, 0.1358524094065351, 0.21749254556432848, 0.03399565342753645, 0.05415716088346897, 0.09715991305007089, 0.0339971472989888, 0.07494003842434577, 0.06668779293015119, 0.07929335603670729, 0.11563278269022705, 0.04896843971143808, 0.013687547386413621, 0.0357001262807077, 0.1056052050403049, 0.06620097469778792, 0.09037340059876443, 0.04189393565719647, 0.09933361858730355, 0.03680530770291244, 0.11252534620824362, 0.10070295478667944, 0.061987031461490746, 0.04488665813339814, 0.06143799156791741, 0.02929468894557607, 0.09723255350705116, 0.14065699111069405, 0.05808996134287408, 0.08256976853214926, 0.020776819700615543, 0.059937887990306464, 0.04787491814744088, 0.14196554589415752, 0.019102940568700433, 0.10966881884322052, 0.05852819427907948, 0.0603055029416517, 0.0684932170195445, 0.09093412333318303, 0.04699218950624909, 0.09042603850004174, 10.969544591442233, 74.80597695996686, 94.32409886390933, 113.96155495797436, 104.81997705275013, 72.33024750986408, 56.18094344292918, 56.39449688696093, 35.44976580527521, 24.219151196941255, 49.7817926253042, 83.29506074228595, 90.71304721217003, 68.1509385570403, 67.6475101901639, 83.60477109109202, 91.52260088151502, 88.60818570660007, 85.58674473916331, 83.13297271728516, 87.32629237636444, 85.68941670079386, 84.75579061815816, 82.39449239546254, 81.30035508063533, 79.19388540329473, 80.59134744828748, 79.64762518482824, 81.59717652105516, 79.47433487061532, 83.91327334988503, 78.18272190709268, 78.7410399221605, 76.5870075841104, 72.41004420864967, 73.56078916980375, 76.87717668471798, 77.33931033842026, 74.80898149551885, 37.333715500370154, 47.51181110259026, 29.04258001235224, 29.474140751746397, 30.548850567110126, 27.522826310127016, 23.437418899228497, 20.242216933158137, 10.681976022258883, 3.1832429045631043, 0.4386049485014331, 0.11412054044945587, 0.5858886001571533, 0.5862538095924162, 0.2116954969542642, 0.9158766834485916, 3.8594225049018864, 0.6299379816459072, 0.8526765134546065, 1.7039950288111165, 2.9138854097935463, 1.1944663957242043, 1.1760144632670189, 6.10578106295678, 0.8117055183937474, 27.878138134556433, 0.9361107815657893, 9.173669757381562, 4.031472369547814, 0.5290575013045342, 0.14720572519206232, 0.24501341154738782, 0.19707005110479173, 0.3109868657925437, 0.06883961133538716, 1.6189253161991797, 2.2794028107197057, 5.329527335782205, 13.951969742774965, 23.653549340463456, 24.790815076520367, 26.367523554832708, 31.543495001331454, 23.666332344855032, 32.365360990647346, 40.78618964841289, 44.67465093058925, 71.79977832301971, 60.999355546889774, 69.51425244731288, 66.3319472343691, 67.07832720971876, 68.65903454442179, 67.66418026339623, 65.43344205425632, 68.37131300280171, 70.95093034928846, 70.62317709768973, 70.25945571161085, 76.96481812384822, 73.01350870440083, 73.11888710145028, 69.5278787612915, 74.04178942403486, 68.1276632124378, 72.40558839613392, 75.72538837309807, 83.14648920489897, 79.48304253239786, 78.25941993344215, 45.98263586721113, 54.68492008024647, 69.21157883059594, 70.70260509367913, 65.90643282859557, 60.91534622253911, 57.27269203432145, 48.74676150660361, 49.09930806006155, 42.548659616901034, 23.17110369282384, 14.307764018735579, 3.4200207023851337, 0.1581588672894624, 0.016579506317934683, 0.1810950341243898, 0.11551639861277035, 0.006802895241567204, 0.12915367530959268, 0.06452891119425336, 0.1360689671409707, 0.0902864496193586, 0.1764316730681927, 0.17665619811704084, 0.05731033281453195, 0.087231352264362, 0.13693555047915829, 0.1664764064574434, 0.11841250974084101, 0.026393130932363774, 0.042587287363506136, 0.010582663892437855, 0.056237579894162, 0.06778966485252304, 0.07867289376595328, 0.02234553219750524, 0.23740314007286104, 0.03537635837170867, 0.18598376292615168, 0.28160837448893056, 0.3237791551697639, 0.20838699303567412, 0.21339215188016816, 0.4244782565341842, 0.12565458403720012, 0.1950251938955438, 0.3036835044622421, 0.21551240746292377, 0.13710304794292297, 0.2219209780976657, 0.2455026659393503, 0.12712708929733885, 0.3032998782732795, 0.23813414117020948, 0.22441661676331875, 0.11955087809192559, 0.2207933579601588, 0.14320738974117464, 0.20240775339545744, 0.12971814421396102, 0.23839258859234475, 0.19753203276664982, 0.23161533048316357, 0.20794201852573505, 0.2134308852856198, 0.18204879826836048, 0.19705986213539878, 6.858583919463619, 73.17027015070762, 97.91225171858265, 125.08153715441306, 127.97346930350028, 88.91613883356895, 63.78804699067147, 68.03734671685004, 40.152181656129905, 28.227799784752634, 61.17231245963805, 98.24014617550759, 101.84522013510428, 78.68586001857635, 77.94297095268004, 89.20829265348374, 92.87809356566399, 90.10369131642004, 85.31277502736738, 87.21745444882302, 87.36470022509175, 88.40883516496228, 85.51907600895052, 83.98757088568904, 85.37156351151006, 82.455916712361, 83.69310286737259, 78.55668067932129, 80.73324311164119, 79.98941267690351, 84.20954565848075, 77.15530410889657, 77.52945899963379, 76.16852206568565, 71.74445721410936, 71.20582165256624, 78.70777822309925, 79.32580255693006, 75.71271127270114, 45.702582559277936, 57.571325609760905, 30.708430236385716, 36.70105288105626, 33.39264346707252, 37.749235706944624, 26.179175261528265, 25.82575794189207, 18.312032299657023, 3.8713107185979045, 2.070994535761495, 0.34554288572361397, 0.8105383681193475, 0.22766561097195073, 0.2245998956383236, 0.44334531671577887, 6.764572551173549, 4.975564806692062, 1.7625212044485155, 11.422014505632463, 5.161912200912353, 0.7790679051991433, 2.523116339598933, 9.565154660132624, 7.089713504237514, 70.92832965235557, 0.5504912931111552, 9.611394501501515, 9.135359967908553, 4.934566232465929, 0.5175512284040451, 0.8699650341464628, 0.6490201286731229, 0.8818494480463767, 0.9012783571116386, 3.5178850639250974, 4.718732420475253, 18.030347285732148, 19.89147270879438, 30.331553220748905, 30.244121628422892, 31.376774657157164, 35.07139044423258, 31.606013659508, 39.02144078285464, 52.42304609667871, 50.96910976594495, 70.60625599276635, 62.41553906471499, 71.14664877614668, 68.89855800136444, 66.72164255572905, 68.9459010093443, 70.45518198320943, 71.32042546426096, 68.10281891976634, 72.06158084254112, 72.7509609345467, 75.35079417690154, 78.48614861888271, 75.9520072321738, 75.08493592662197, 70.12047044692501, 76.19181309976886, 70.98721227338238, 71.75755008574455, 78.50775303379183, 82.95343798975792, 83.51840834463798, 85.17208745402675, 55.707729093490116, 61.33062324216289, 83.45507775583576, 81.9093579630698, 82.05774907142886, 60.78776328794418, 54.99634058244767, 64.93610905062768, 54.404584361660866, 43.99367255549277, 27.245659866640647, 12.552677912096824, 2.5263437148063415, 0.15898613499537592, 0.2510858228009555, 0.2505292905674827, 0.29414380990689803, 0.13747912050495226, 0.17359743886176618, 0.280646505134721, 0.23833594405122344, 0.1765731848295658, 0.3402068688263816, 0.14919427493887563, 0.10909802971347686, 0.1905712659560865, 0.1716239810470612, 0.40346578244240056, 0.1878818989761414, 0.1822894111636185, 0.20866761104233805, 0.12422563853643595, 0.1949183093083482, 0.16648323996172798, 0.288248518181424, 0.21484134508477104, 0.2820261375557992, 0.10846706437728099], [0.09193625826869281, 0.03310013877888841, 0.07074148589444738, 0.07903792700099369, 0.05911636594382506, 0.0811557847285463, 0.038866566854619214, 0.08965662575416988, 0.03197863776867669, 0.0044805480584111665, 0.07103558704857865, 0.07550632295709464, 0.09049253493186929, 0.11449878104031087, 0.16932279081834903, 0.12460567943391301, 0.09084121985060555, 0.007800205738373822, 0.14800913692001375, 0.05858906379510319, 0.012553643412707795, 0.08280143352045168, 0.05726170155309862, 0.094899149281123, 0.08257241153548803, 0.11027567539243929, 0.13300705160344803, 0.1845856831078568, 0.16982848545716656, 0.12473111100975545, 22.564542485821633, 52.53616333007813, 68.68389452657392, 79.85543235655754, 91.81344462979226, 61.033033017189275, 30.69762606774607, 32.27534063400761, 29.911000613243353, 34.312129405237016, 79.39416162429318, 62.53757576788626, 65.5878383113492, 57.58198268951909, 75.32729917956938, 91.21958994096326, 88.38483025950771, 85.60986318895894, 77.34269926624914, 81.60974379508727, 80.60522479395713, 82.6811235181747, 77.5081919085595, 84.65807653242543, 81.99538338568904, 81.88156404802876, 77.26626796107139, 82.02920990605509, 81.54628769043954, 78.24616232225972, 74.60324533524053, 80.25737331759545, 75.33901922164425, 77.48603051708591, 72.99258678190171, 79.22872389516523, 76.57226731700283, 65.31126022338867, 34.684115225268954, 39.66233253479004, 19.9410730408084, 32.91324353987171, 24.593829724096484, 30.84337938216425, 29.09060355155699, 11.259693099606423, 5.105701694565435, 2.4374637872942033, 0.27031102908715127, 0.9202325980990165, 0.32979885957414107, 0.6414364710930855, 0.6062895215807423, 1.8876699406293131, 1.5303970536878033, 0.3626670652339536, 0.13777489173075846, 0.2196775508984443, 0.039812329210220807, 0.07381785751110123, 1.1538681484037832, 2.2400021120425198, 0.7187332717641708, 1.1191839772847392, 1.6835334945109584, 6.706040491980891, 0.719313292253402, 0.47143353209380184, 0.06449343366247993, 0.06129167643525909, 0.05858671573561527, 0.08511303488405482, 0.060870216994155804, 0.906867673320155, 0.8074511563585651, 2.4372573725638853, 7.796016172055276, 20.870737529570057, 27.654333576079342, 28.474652190362256, 27.295124876883726, 21.628360979018673, 23.894416209190126, 35.375189781188965, 35.06453806354154, 59.228487783862704, 67.5695413158786, 61.61756815448884, 70.91536229656589, 65.71691959134995, 64.6280578644045, 61.87396172554263, 67.75102938375166, 65.57683998538603, 70.95806121826172, 69.31330157864478, 71.54350634544127, 69.88576366055396, 74.7332013037897, 69.73114382836127, 73.88702838651596, 68.79707844026628, 69.26802173737558, 67.92044439623433, 82.62312735280683, 70.28617489722468, 77.73402629360076, 68.34617845473751, 38.40354980960969, 60.88428889551471, 76.3560192046627, 59.436702882089925, 53.18895163074617, 29.19159281638361, 15.0779115961444, 20.86675436266007, 14.959799224330535, 12.85400321406703, 6.107343637174176, 2.188075569368178, 0.5478943776219123, 0.050939085983460954, 0.15458394863432454, 0.08726181958111064, 0.39951666047976864, 0.09936476772230479, 0.09394687900860464, 0.04723120893862459, 0.09526678721510595, 0.04463055494031118, 0.09471814568725326, 0.2661886486795641, 0.027920482342221567, 0.08812810414500775, 0.1565903482297736, 0.05062130888202979, 0.04882977396670369, 0.024945322431684024, 0.03142901181784128, 0.10363236009593933, 0.022968771536984754, 0.015986482443798695, 0.03632333880710987, 0.16441232044129603, 0.05550506194272349, 0.006899237501314812, 0.12432866204049318, 0.06039541485088487, 0.15257500562696688, 0.149850276028437, 0.06010288417699838, 0.02081960954162623, 0.17365311813210288, 0.004697941786294142, 0.022123159855724345, 0.04022227434982215, 0.09108927145960832, 0.08139123419119466, 0.08051417077020293, 0.06363221677020192, 0.06626609217135176, 0.1455737893740016, 0.08766811431175278, 0.013426009757113794, 0.09373717776109135, 0.0552776602337197, 0.043376009355509476, 0.01811230652815392, 0.04734817141246411, 0.06046472665583415, 0.06636765244747363, 0.03339436250708757, 0.11828750717423617, 0.031974387895916744, 0.08713251926125058, 0.727226245066812, 41.62005809045608, 88.3702390424667, 102.06391580643194, 100.37308400677097, 89.56595790001654, 64.5664256618869, 56.729765399809814, 58.20809887301538, 47.557922486336004, 44.986640176465436, 78.57681028304562, 75.88011018691525, 79.16760552314021, 71.70327232730004, 84.5394640584146, 92.64510477742841, 90.93666153569376, 88.50640020062848, 82.04919830445321, 81.6460100297005, 84.92932411932176, 87.24658196972263, 81.43750467608052, 85.19414686387586, 79.06389021104383, 83.15091363845333, 81.98852708262783, 82.82572561694731, 82.6988918550553, 78.79003032561272, 80.49842649890532, 80.02080732776274, 76.993835818383, 76.77652866609635, 73.75043576763522, 76.98624995446976, 74.03412511271816, 69.63768159189533, 38.154898997276064, 42.74640198676817, 25.412481331056167, 30.861777259457497, 29.03120513885252, 26.81155547018974, 22.73654430143295, 13.932676584489885, 9.108601558593012, 2.0696172935347406, 0.8824914910139576, 0.8447534482805961, 0.5329609337833621, 2.2091220271202827, 2.002439717611959, 7.696340901236381, 2.6718121670907546, 0.5253299626131211, 0.43386727691658084, 0.4027181112718198, 0.3395392385221297, 0.14041823214821278, 1.8123359185072685, 9.550223177479161, 0.5022287038305114, 13.93921321438205, 1.7713623493909838, 14.426987401900755, 4.11994731233966, 0.40276392332969174, 0.1031353299115454, 0.13039006461058894, 0.07304859798281424, 0.06285324324703505, 0.15570487316337325, 2.017780352504023, 0.8474369010617657, 4.232139846970958, 14.5149524365702, 20.26040496364717, 27.90156056804042, 29.200457372973045, 36.051500535780384, 25.438723948694047, 26.587160595001716, 39.001432772605654, 43.659549374734205, 61.11746987988872, 68.63328026187035, 64.09421151684177, 67.76045091690557, 67.17170315404093, 65.02202856925227, 65.89952945709229, 66.36107475526872, 68.60240336387389, 72.45955236496465, 69.51162445929744, 74.90949615355461, 74.82961316262522, 73.93896841233777, 73.6586993740451, 71.89335038585048, 71.99134688223563, 70.97800254821777, 76.30694250906669, 81.10375019811815, 80.72307632815453, 82.08483695983887, 71.49737927221483, 43.26364886376166, 76.08585419193392, 77.8403695937126, 71.50193706635507, 61.51936769485474, 49.22425516190068, 45.20081727735458, 42.81397265772666, 36.76331266280144, 24.689949366354174, 15.846416681043564, 5.280884062090228, 0.7645558097189473, 0.022977286604263132, 0.16889519118253263, 0.14645783951686275, 0.07632055184653691, 0.038536428924529784, 0.09349854903355723, 0.11214542788483443, 0.17108142225732728, 0.1274894795290405, 0.11171152334540121, 0.19854138425040632, 0.04036922916589726, 0.005376815867249764, 0.14664168529693158, 0.043678529815928596, 0.04024568982722779, 0.09994446645460783, 0.03641099075696642, 0.03966606770371718, 0.050184688560905, 0.030902196134951328, 0.00831596677251641, 0.06100065878502304, 0.05406522267167607, 0.03513445461829824, 0.1763947476302424, 0.18918305335025634, 0.24404077099696284, 0.2558565434188612, 0.17433749511837962, 0.16689340343638775, 0.3283218726996453, 0.29764829443827756, 0.12789732175728968, 0.09329781867563726, 0.364415921391018, 0.2708367492643095, 0.1311229656059896, 0.17484959425224414, 0.271282336644588, 0.4225873063889242, 0.16220272368481084, 0.1411247337537427, 0.17019167242030944, 0.2095050677176445, 0.08576035619743409, 0.2912988045042561, 0.16972382252495136, 0.16590275981974217, 0.1863915668500047, 0.13664730223676852, 0.22568757195145855, 0.13255953368160034, 0.2673054822990971, 0.31664987965937585, 30.049572067876017, 83.88951163138114, 104.12589011653778, 109.8268747329712, 104.69234312734297, 68.0601906007336, 57.40032988209879, 65.6307686528852, 55.877846210233635, 58.07530703083162, 93.58589310799876, 89.32787003055697, 87.13308426641649, 82.2111294346471, 89.87906502139184, 96.83324690788024, 93.39198681616014, 90.01887398381388, 84.47445469517862, 85.91186215800624, 86.56703918210923, 89.77715399957474, 82.45904676375851, 85.75808955777077, 80.28854047098469, 84.13488726462089, 81.55026497379427, 80.50818535589403, 82.27167514062698, 79.75052464392878, 76.43590219559209, 78.49969648545789, 76.50990947600334, 77.29306559408866, 77.57413479589647, 79.13970178173435, 78.34513941118794, 71.41289926344349, 46.474826643543864, 50.63133878092612, 31.76505204169981, 42.687005535248794, 34.73073259476693, 36.592191419293805, 27.073981646568548, 24.77782222532457, 17.686849640261745, 2.352882777490924, 0.82981338544238, 2.4947551517717304, 0.36772551315446056, 1.1864316655743508, 3.0985275535814227, 15.589305316248248, 4.164447092240857, 0.9964343833346522, 1.0917235862824226, 0.5552665336478142, 0.40903548680005536, 0.2508485806925643, 3.314394460570428, 15.837111838402288, 5.3336404312041505, 20.822557095558416, 3.4004971048524304, 21.211079628236835, 3.729090479112441, 0.5971143010162538, 0.16311049190980775, 0.2618008341279722, 0.22762958951775106, 0.23060792486273476, 0.7391380542708982, 5.874134705912683, 1.28923662006855, 7.202107060340143, 18.12841634596548, 29.31184680231156, 34.15790181006155, 36.546174172432195, 39.18911818535098, 33.89627971956807, 36.88233698568037, 44.528989791870124, 49.67852838577763, 62.14058483800581, 67.89068929610714, 66.61305565987864, 71.93839488490936, 68.59102849037417, 66.92297781667402, 64.24865876474689, 68.55189892553514, 68.67618314681515, 76.1894126092234, 73.3884088454708, 77.5890084235899, 79.81846794005364, 76.76640895105179, 74.84270603426042, 74.21494637766193, 74.0304067057948, 70.15562272840931, 75.92375047745244, 82.82321530003702, 79.89425597652313, 86.20960927778675, 80.2081475719329, 52.04128180780719, 83.81457082686886, 90.0936657382596, 85.02780698960828, 69.36050338129844, 47.29555122313961, 52.91962208286409, 50.95859389151297, 42.82398646877658, 30.18450160180369, 16.136365148328967, 3.3011817114968456, 0.6495263595734874, 0.13415299656410373, 0.11095960038684069, 0.28552461595785233, 0.4699848904725044, 0.1997306744658178, 0.27839736291958445, 0.1672302522966939, 0.24986250295994744, 0.2145781019522298, 0.23679698066365337, 0.3609078209246359, 0.28668453436224695, 0.1639443173283531, 0.19460415197235925, 0.14624607749283314, 0.13138852232406217, 0.23476750649992498, 0.1881166896031749, 0.15625115514041918, 0.10627812135123438, 0.14630593960323643, 0.08323718433178241, 0.19626979565908834, 0.2017523345327185, 0.1760806515812874], [0.046812469109652505, 0.07964237037325099, 0.06021986197259638, 0.04721094591302737, 0.05558900985746615, 0.011464430135674776, 0.0838747533458856, 0.055863637056562214, 0.16510811213764454, 0.04155864195537664, 0.013728798348306408, 0.03337394243346588, 0.1313137521426524, 0.16305691172038356, 0.33765291554793236, 0.3569530605548813, 0.04886026809652967, 0.03098717826839176, 0.13024479901838687, 0.087794327297278, 0.04500871892237375, 0.0306129711304581, 0.025895394031859698, 0.03863525426676197, 0.03439894892395504, 0.14658036761947218, 0.27573511545215884, 0.12979703594840344, 0.23707703176525333, 0.20624337177122795, 2.7513316033347963, 35.56080810485348, 50.41310594927881, 74.70226949261081, 92.58459045040993, 66.62047678424467, 38.645191346445394, 29.5473478686425, 25.93590201870088, 39.598425357572495, 67.43602383521296, 90.96600086458268, 64.13336461590183, 61.046541660062736, 65.79582591210642, 93.00916348734211, 92.65393011031613, 93.64996110239338, 82.1952046117475, 81.13084593126851, 81.72350037482478, 81.22882673817297, 81.18030701914142, 80.49284104377993, 83.30050499208512, 82.78657251788725, 75.37369297396752, 78.06069697103193, 81.85734733458489, 82.0039027737033, 77.72511466856926, 76.98067234408471, 77.21680687319848, 74.58569665108958, 78.46514040423979, 70.65036696772422, 74.33658692144579, 58.2408663534349, 34.7087477099511, 37.11003841892366, 20.413718646572484, 26.897361240079327, 27.485316684169156, 30.5808178840145, 26.42729655388863, 11.105442950802466, 1.9557322561740877, 2.2242488928379553, 1.851451877624758, 1.906132291882269, 4.235659193608069, 7.96806799788629, 0.9570651861929125, 1.367381265567195, 1.1242304742336273, 0.4623807323796134, 0.40778109443283855, 0.1012128935525975, 0.09727627414488986, 0.13365182184403943, 0.043933928208125216, 0.7419584835729292, 0.35408663533387646, 3.232112204836261, 0.5739222454928583, 6.704765231378618, 4.876343550220613, 0.2699507839016376, 0.07512016101710259, 0.2538330753844592, 0.12055095225091904, 0.40662797888921154, 1.4544604574480366, 3.507593009741076, 0.2747132767352366, 2.979386785338002, 6.550063519708573, 24.08514734237425, 24.223779593744588, 27.194308196344686, 34.43513493384085, 25.093220010880504, 17.809884586641868, 31.3855823393791, 31.671768273076705, 51.47969253601567, 66.52325691715365, 62.11201429367066, 64.81653559592463, 66.15456981043663, 69.74063596417828, 66.57220809690415, 66.47906749479233, 66.93862022892122, 69.98762761392902, 67.96586544282975, 71.17877298785795, 73.24429312059956, 71.87752754457536, 70.35185890813028, 74.16218265410393, 73.03510527456962, 74.00050255560106, 79.6770586506013, 80.56636979503017, 77.4544240582374, 82.10861436782345, 51.79301931012062, 40.965857736526, 78.02992989940029, 58.7083108963505, 43.63812146648284, 33.31694172274682, 18.317870747658517, 16.069178869647367, 16.47383705262215, 7.8605528896854775, 6.299227456892691, 2.612172528620689, 0.17130974710227984, 0.06619805590279641, 0.14204615366555032, 0.14456180254778556, 0.15128336606487153, 0.23481797637237659, 0.12219319961244061, 0.05847149228136386, 0.08158182920587641, 0.06296023125610044, 0.010583314109563587, 0.19443345226107106, 0.07381476251588714, 0.04486069158320466, 0.18620649532925698, 0.12762614961473212, 0.07825708422329157, 0.10110528118187383, 0.01697368728327415, 0.040537772339678584, 0.1021789534077529, 0.1007107842052656, 0.04290154046048561, 0.10379898421947034, 0.025043274433682525, 0.10066752322018148, 0.02762126946641553, 0.07905780698262876, 0.021336081122318586, 0.04352265390597525, 0.00772451768786977, 0.05012217195584409, 0.05516308412376431, 0.18087954891304817, 0.16740767825995723, 0.04786674781972843, 0.09306462917236552, 0.121318128020052, 0.0180660558849453, 0.09086398032283591, 0.056379604934444355, 0.27674166305411246, 0.133191816689026, 0.020992582618829705, 0.06843783652349826, 0.05252555831365528, 0.06058840389032999, 0.05990369748624583, 0.05242879757837904, 0.05752335888363662, 0.03622935897099876, 0.047398507219528964, 0.17797108078675886, 0.09583691750923473, 0.03032993994683268, 0.06856259394196734, 0.17289849088316964, 9.192265714368514, 63.97989403816962, 85.88488409596106, 96.57428418436359, 101.30019895492062, 72.97974494195753, 47.849625233680975, 57.79092342622819, 62.69531780673612, 58.73396319727744, 68.16769492241644, 82.97927071971279, 69.20686414164882, 75.45818082747921, 80.53337481714065, 96.52914554842057, 95.82009084763067, 92.55775359369095, 84.71838689619496, 86.73465774905297, 86.63367240659653, 82.68929773761381, 83.88487538983746, 84.38745652475666, 82.39258612355879, 81.45499060230871, 77.24313382179507, 81.04790349160471, 83.27670404987951, 82.2461405108052, 82.51825101913946, 81.30881955546718, 78.86972504277384, 71.77670694166615, 76.89736904636507, 70.77916191470239, 78.62128996079969, 60.914565670874815, 40.3673432719323, 39.58850568340671, 23.72524634484322, 31.850310640950358, 28.660786305704427, 28.58974433714344, 22.149904812535933, 10.75234236255769, 3.480227858789506, 2.409680658771146, 1.6118123430398203, 1.2106455598146686, 1.5554652891812788, 1.9170525381642005, 0.6632080157437633, 1.0672902844605907, 0.5524049807460077, 0.7272080428177311, 0.17904446189922674, 0.29438099072825524, 0.1316925519776921, 0.2074268703619319, 0.18907069889528139, 0.6091832501753685, 0.7489298836838815, 9.514249159443764, 1.1248630789979812, 9.536063421157099, 11.014141940301466, 0.36114313249145785, 0.14957459162800543, 0.15669920932381384, 0.08858085444737827, 0.19949395329721514, 2.244504257555931, 5.755410444351935, 0.8562316517195395, 4.65259047285203, 11.849926460173823, 19.751732387850364, 25.503021401743737, 28.95043569226419, 37.50513876638105, 29.747312261212258, 24.11463179895955, 35.7756402415614, 40.670640545506636, 57.61169072120421, 69.42554412349578, 64.60093075229277, 67.96479071340254, 69.30988127185454, 75.1565819401895, 68.8028129454582, 67.71446504900533, 72.37999885312973, 72.25814650135656, 70.07001307702834, 77.28887650274461, 73.33229541778564, 76.06111188088694, 71.24815971620622, 76.88372704290575, 72.26055483664237, 79.76941477867865, 80.4456941543087, 85.5202684094829, 81.10589965697258, 83.44518553826117, 55.79953608974334, 50.70094516200405, 85.40279342282204, 66.8624948686169, 56.64843897665701, 47.22494071529758, 42.35476509217293, 39.12481484874603, 36.03772124936504, 28.95342649952058, 17.871718791223344, 7.388424546487871, 1.0811542695568455, 0.03722662158731011, 0.13501089246522996, 0.21903118719497036, 0.30761347422676705, 0.11711476445798913, 0.06560196288891378, 0.027369425722187566, 0.1239114965222055, 0.09806660109109457, 0.08935921510020572, 0.17809298069727036, 0.07378357507648968, 0.018163197748963873, 0.03302053075223681, 0.18100811378850093, 0.04010499394949406, 0.015837725405881724, 0.06272134205867207, 0.02216554558535497, 0.02987297424565881, 0.11447927644175869, 0.08227415818480716, 0.12518890217066775, 0.067561324685812, 0.017678154925365123, 0.016808451694105903, 0.16521596199562474, 0.19075803819202608, 0.13639660762442699, 0.1671915801782762, 0.19510483639615198, 0.24020123025102003, 0.22279050321348254, 0.3546659816657344, 0.3047946690311355, 0.22059356222950646, 0.20137060824180805, 0.11235725119589798, 0.20315494959152516, 0.20151899947274118, 0.3603554102441957, 0.3474744691723778, 0.3462980339123357, 0.19336198636841392, 0.1852059998219052, 0.13340993724282713, 0.15397026624170043, 0.17951375203988246, 0.2522669771626111, 0.185973328808623, 0.15290224774470254, 0.2544675647251068, 0.27210569730208767, 0.15569842270305081, 0.24460050547795914, 0.26201300983948095, 4.210510917248265, 52.16229084999331, 84.05313722548946, 112.80495782052319, 118.05224972386515, 74.86478113359021, 52.73901262590962, 60.14904845145441, 62.90437229218022, 67.31357528317359, 83.09922464432256, 101.96922194573187, 87.87076442472397, 90.80241449417608, 89.71005009066674, 96.88819931399439, 99.22138198729485, 92.76911443279636, 90.7136041887345, 88.42673686242874, 86.43870707481139, 83.8298523810602, 86.75789386995378, 85.95847560513405, 83.97478395892729, 81.75054903953307, 80.22739071999827, 81.43519047767886, 83.33106810046782, 83.73555075737738, 81.85519787573045, 78.82388822494015, 78.31680420906314, 76.44651612927838, 79.23467805308681, 72.57177137559461, 81.8571041476342, 64.02398147890645, 49.359039568131976, 46.807537771040394, 30.971968404708374, 36.59861626163606, 33.97393872660975, 37.36314504377304, 29.68471907800244, 22.91332748628432, 4.368535366750533, 4.0842777682888896, 8.701498758408333, 3.1575746690073325, 16.37788018872661, 18.188169733170543, 4.126209866616034, 4.772933692701401, 1.0066913813352585, 3.268527489516043, 2.012419575645078, 0.6601702626193724, 0.3886702957172548, 0.24313577601025183, 0.3180281024786734, 6.136916837384624, 1.2355417013168335, 19.915232466113185, 3.9591742619391415, 16.19864061955483, 13.75021969118426, 0.48337181729655115, 0.23804015750365876, 0.5454303937092905, 0.19238525490847327, 0.35790962858065484, 4.351552484496947, 11.13324765236147, 0.773819161038245, 4.527952257663974, 12.858478638433642, 31.357692326268843, 27.24744062269888, 33.39734638890913, 42.27248945543843, 38.16351252217447, 31.751849343699796, 44.28482224864345, 48.09551861978347, 57.055165229305146, 68.04283019035094, 68.06490528968074, 69.12643201889531, 68.79164203520745, 75.33045276518791, 72.72726197396555, 67.10266159426781, 71.54414961414953, 75.87035917466687, 70.58970359063917, 77.98435195799797, 77.61682587285196, 75.97088167744299, 73.11452542581867, 75.42088693188083, 72.60982621100642, 79.08188604539441, 82.95325756072998, 83.0535525660361, 84.27636715673631, 89.79417708612259, 67.66221907831007, 56.552623318087676, 99.71575752381356, 75.96799481299617, 69.18100003273257, 50.04429724908645, 48.33151194357103, 51.867069736603774, 46.74714503749725, 29.983907668821274, 16.249267631961455, 4.563845376814566, 0.798905843928937, 0.2873197438255433, 0.1077020489760945, 0.2288625007795711, 0.7402551943256009, 0.3446780643876522, 0.26266017027439614, 0.16981749975633237, 0.2619679025824993, 0.19022808920952583, 0.14492085263613733, 0.19299792606503735, 0.12741122364757523, 0.09883577634970989, 0.275588057214214, 0.2372548714159958, 0.1407861841782447, 0.1766590939293946, 0.20563963319986098, 0.14782437183443578, 0.16920006353287928, 0.23039649991739183, 0.13441787912480294, 0.41294636565350723, 0.07451890457061029, 0.1538760833922894, 0.2599466562030777], [0.06272807980196611, 0.04028154657252374, 0.07885053423383544, 0.055478459539552855, 0.10878836165272421, 0.10939483515798085, 0.05875935364935187, 0.07286698151860507, 0.06675119436676465, 0.0674092868763593, 0.07146248188350471, 0.019878547135440093, 0.12828932128726475, 0.08404596633608304, 0.2766662493588463, 0.36221023168294664, 0.18411322136319455, 0.05734242423768005, 0.15493985776218677, 0.11682409537775863, 0.10192261272740942, 0.10307230385801486, 0.1073246664037147, 0.10578047063562179, 0.20633406125970427, 0.1328942987827524, 0.08768183494647665, 0.2676148286029216, 0.43927098534280257, 0.21229817832429565, 0.5875564042118289, 6.763113429469447, 39.66945555902297, 65.39827408329134, 83.83219795842325, 81.09298721436532, 70.42494835392122, 31.40694356733753, 13.995094241634494, 33.65308100177396, 62.16050263374083, 96.88285704581969, 107.45190312785488, 77.61057361479729, 55.68397521972657, 86.35755323594617, 94.45425879570746, 95.86112668437343, 94.47111714270808, 82.99534459267893, 83.04097744726366, 79.60520082904448, 80.6535719287011, 82.11801236675632, 82.8309109903151, 82.0015807305613, 84.57003501153763, 80.72837937262751, 82.35602963355281, 85.4887011743361, 81.96872695799797, 74.44592691236927, 77.85400375243157, 77.24227090035716, 73.58948522998442, 67.24850316201487, 72.47873275510727, 46.222214237336196, 30.575999252257812, 30.253105817302583, 20.12514006706976, 32.810479402542114, 26.962896200918383, 30.610796559241514, 22.247558101531, 8.820767248830489, 1.5247553370652662, 1.0122565504524017, 0.3718470661870895, 0.8189821892207669, 0.8978097561386325, 0.05205318849954394, 0.6859621141226061, 3.425512756070783, 7.763555617101732, 0.7842334828549816, 0.8049003900058809, 0.6286982062362856, 2.5383537671258374, 0.1469525790983631, 0.15031454063230945, 1.0907015637043984, 1.040808402242199, 1.2379128966600665, 4.302553255711833, 2.6968594424186216, 11.037247642394036, 1.0821973748745457, 0.4165304926854949, 0.5445186265053288, 1.8407848693670767, 1.1071207278197812, 3.0797759275282584, 3.923946719977164, 0.6952596023198098, 4.838780972265429, 8.45697820186615, 16.7032447168904, 30.744623907150764, 27.23166092749565, 29.266359075423214, 32.73287923105302, 15.491616725921633, 23.51544857025147, 25.817607256674, 31.824989780302975, 64.65856998197495, 60.37988778083556, 65.78519236656928, 64.1648926273469, 61.50088940897296, 67.3556544703822, 68.7765016863423, 64.56731996228619, 72.4132997758927, 69.42042935279109, 70.58122342632663, 71.47804198726531, 75.3925831087174, 75.17981021634995, 78.17160591002434, 77.42741461723082, 82.54540951021256, 84.53938561101114, 83.15000364857336, 76.44746534286007, 74.38243158401983, 37.45679163163708, 64.85744199445172, 74.47363453526651, 42.55116601144114, 32.62930512428284, 29.187017371577603, 19.585463116245887, 18.500066803347682, 12.062481660996715, 6.871946944344429, 1.2288199845821628, 0.6945365991803908, 0.6825111638153754, 0.1677194607233809, 0.33847342635835376, 0.21168817315370808, 0.37879661747044135, 0.1755755391692923, 0.11413418447538731, 0.07823387942006511, 0.07526688983724003, 0.12963366003767138, 0.29897163471867966, 0.17888775095343593, 0.13842531570023106, 0.025828993361022685, 0.06258561809156692, 0.033219093081331065, 0.1316546765907157, 0.023979965462199142, 0.07032566869090642, 0.051789217583474614, 0.1173514320004371, 0.10528605281104965, 0.043543215705862934, 0.04388940317796604, 0.10832697753944706, 0.1504815631215611, 0.10517652522051528, 0.10593348903761757, 0.09487147052441874, 0.1369135943992484, 0.06325772617973628, 0.027685745341342785, 0.08271264393002757, 0.04422748543983025, 0.0592170107448774, 0.1569846996496762, 0.06570152367555326, 0.07726621844114796, 0.023118133784361908, 0.08753164340892146, 0.12173913163884033, 0.10953685253738396, 0.1996410268569185, 0.08867907458015027, 0.025396096227209897, 0.1439014194352973, 0.1334651108951338, 0.028589838259522955, 0.0668858802847324, 0.11879220589875214, 0.24134555110527625, 0.25872358151020547, 0.1680245169348294, 0.17209892491659812, 0.3205758657666945, 0.19753330447260412, 0.0350298912775132, 1.3014165600461345, 20.742246566280244, 73.76093203021635, 101.02291876269926, 109.98877448420372, 89.24087970487534, 72.16007155756797, 51.84552807961741, 46.75264812284901, 70.06562786717569, 81.4524567511774, 88.64264765093404, 93.57749923583, 79.56523972172891, 71.64813164741763, 94.21516679948377, 100.7632500125516, 96.88711673982682, 93.73775159159015, 82.17331778618598, 86.30991212783321, 83.94116140181019, 85.35265768727949, 85.06377512408842, 86.84341722919096, 83.63545187057989, 82.45710911289339, 79.27407433909755, 83.52127167486375, 82.51815688225531, 82.31949667776786, 78.22658185035952, 82.44915454618393, 77.48585793279833, 74.00294226984825, 67.11737832715436, 74.37602243115826, 51.94139080662882, 35.96770301941903, 33.79924812624532, 28.9079152384112, 34.86283409980036, 28.58959136470672, 24.369921222809825, 17.37907498113571, 7.961042052315128, 1.8316382698474394, 0.5666460649621102, 0.07555172898836675, 0.4415290754648947, 0.7566266771285766, 0.13592489664593052, 0.3019137494266033, 5.052402567478919, 10.44898723402331, 1.012587316574589, 0.8746328997996546, 0.17253384835297064, 0.3378141923777519, 0.7702645743566175, 0.1473344892503754, 2.498620157280276, 3.4844569092796696, 0.3562688521079479, 2.0484676284174768, 6.652604081938344, 21.629800488871915, 0.8492337143228901, 0.33495380392959045, 0.7284790746146633, 1.2667254022052212, 1.045871201542116, 2.578880431190614, 4.877723734224997, 1.6399239700648094, 8.47503875532458, 21.641622512571274, 19.263046249266594, 30.103704698624153, 33.49641761472149, 39.78978210879911, 34.59045294792422, 23.61425307489211, 31.729450648830785, 36.52225948149158, 41.4585623433513, 70.45248339253088, 60.53480963553152, 71.03911307550246, 65.95992611300561, 66.79293555598106, 66.15173001443186, 70.60788769875803, 68.34054593117007, 74.02196576518398, 72.06056102629631, 74.97434077724334, 75.20615285442722, 78.41668344313099, 73.17117229584726, 80.53243344829929, 76.70647513481879, 87.98681166864212, 81.78014724485337, 89.63093588429113, 78.19559512599822, 79.15914104830834, 42.19543841577346, 82.49759581781204, 78.63563799089002, 54.57951030423565, 46.00833915895032, 38.94797871189733, 41.074970229979485, 34.94070491483135, 30.682842654566613, 15.387720004204782, 6.8815846981540805, 2.0978556621459226, 0.34576076112927934, 0.22843738326862936, 0.3363704537191699, 0.3674784957641556, 0.07860002348259573, 0.15227829977389307, 0.17738195917298719, 0.02198128420258722, 0.16553234098659408, 0.14684312045574188, 0.13764491725352504, 0.20957527201502554, 0.10584547319599699, 0.0707359777222718, 0.04076368017723003, 0.11916579633590677, 0.10405824369480533, 0.11500299712943454, 0.15099776848669977, 0.044696691310814315, 0.05297783364151275, 0.11072634193565577, 0.10426964565751054, 0.020257835351531545, 0.10870517216502659, 0.12098101868985162, 0.016374415004505746, 0.1747134604280995, 0.19711123599160105, 0.1725205643883636, 0.2117485102386244, 0.2319404581982282, 0.2843818885664786, 0.2367177212070073, 0.13673907957009732, 0.18718875794401094, 0.21171573699722368, 0.44559743135206165, 0.09892504091464704, 0.2900428799611907, 0.251373810573451, 0.3946954853111698, 0.3483686776411149, 0.2465557763653417, 0.1692046140951495, 0.20880092566292133, 0.205872799720495, 0.11672736911643898, 0.1390549480434387, 0.1567616761331597, 0.2900528391042064, 0.4140731584160559, 0.27209334796474827, 0.21225969006697978, 0.4292080833786919, 0.25692992453132907, 0.17697216342053107, 0.58308974389107, 10.177223855449308, 60.657320945493645, 105.36741441295993, 122.46848552457749, 100.59046176172073, 85.70496497615692, 50.648106913412775, 44.83988861883841, 68.80965355903872, 88.84458695688556, 105.63139777029716, 118.15778501572149, 105.56754158389185, 85.1804970156762, 98.74965421615109, 101.1950166763798, 100.12623356234644, 94.61444054880451, 86.6268474824967, 91.73144355896981, 86.59240907238376, 86.07901004052933, 86.61526080100768, 84.73078158593948, 82.85010706993842, 86.84505677992298, 84.82657371028778, 85.7785015721475, 84.6157306240451, 81.63455670879733, 76.84096536328717, 79.3471637848885, 76.82271849724555, 76.6689851207118, 68.61367625574913, 77.04852150332543, 57.84595820211596, 42.73950253763507, 45.944545730467766, 34.182699034290934, 40.87310937143142, 36.192356771038426, 37.169074012387185, 25.088675945035874, 20.937282500728486, 0.6710634813193352, 1.262735125999297, 0.760853092276281, 1.0168723834137763, 1.5020677351182508, 0.17199610059540119, 1.7487831029199785, 12.301243197533394, 19.04530175270573, 8.097940616069302, 1.5958383679389956, 1.755022980993794, 9.244565617653633, 1.084958968623992, 0.11792477220296861, 2.932836831577363, 5.690530519331656, 6.343952282782524, 7.059057729859506, 9.96409304680363, 36.45718736033286, 1.329353273876252, 1.3214243251469828, 1.4659700398483586, 5.473066962534382, 5.019750796979474, 6.4874036562058235, 9.331856985245983, 2.527203694466622, 6.063316993175015, 21.64607636390194, 20.15120029449463, 36.06881780009116, 35.740272229717625, 42.97858276674825, 39.26183108360537, 27.628139988068614, 38.01203058611962, 45.64344498418993, 41.82398996045513, 75.3189915995444, 61.43547604160925, 73.18879942740165, 66.60416756906818, 70.59819944443242, 68.05175750486313, 71.28555559342908, 70.15010003120669, 79.1914378443072, 70.86965099457773, 75.58685810335221, 75.14046884352162, 82.15696150256743, 73.65945246911818, 79.83411035230084, 74.58761861247402, 88.7437741987167, 82.35240536351358, 91.62142892037669, 81.71881706483903, 85.94778322404431, 50.32843766673919, 85.07524413447227, 92.49966329143894, 66.76973081404164, 57.95968340289209, 51.96939652965915, 57.69065979988345, 49.049654776050204, 37.50048291298651, 14.337549517231604, 5.21227837570252, 1.088539602295045, 0.6107944862977152, 0.25396675772724614, 0.3050168345291769, 0.337655458959841, 0.48265166400421056, 0.19505853404200849, 0.39470244138952226, 0.24723200217610408, 0.3178637000101228, 0.1873901471375458, 0.35861669709124877, 0.27315149924928145, 0.2899767512515668, 0.17783350671731657, 0.09370120227216713, 0.25805331586349395, 0.2910535337944185, 0.1366591459560779, 0.28756385008173607, 0.14335559711100596, 0.20320209464238537, 0.3793790587975133, 0.2175027498554799, 0.15685500096409552, 0.25094961236801844, 0.31034019565390003, 0.17991032511476548], [0.03209411211672329, 0.059869127768662676, 0.07787842994495746, 0.02731299760090488, 0.059699898946189114, 0.07018060228156467, 0.12575361622317185, 0.009876986789036422, 0.07137605950476662, 0.1076907721618491, 0.1519942037280529, 0.0979396986264375, 0.2944229417029889, 0.20230595563207904, 0.22531693861369165, 0.7506482495415596, 0.3344354381965053, 0.1261148803056248, 0.10324283502995969, 0.13407556039671745, 0.2319777513583822, 0.27642431879235857, 0.10676534561019753, 0.5156990729512707, 0.3280219952425649, 0.2930607147995503, 0.11157080065459014, 0.2622462376471489, 0.3136147005904106, 0.412712371757915, 0.2494049492862917, 0.6813415007725839, 13.539761977811015, 34.409455176322695, 45.603401507100756, 82.72204952855265, 81.35277363561815, 66.75470029154133, 22.53650930620009, 19.916717083223407, 32.98370892001737, 73.87763823232343, 98.86979641452913, 121.70739666108163, 60.28010268365184, 70.63038641406645, 97.34242546942927, 94.52864262365526, 102.11281991774037, 91.09896136868386, 86.93295709548458, 86.30914334327944, 84.68336797529652, 81.68994842037078, 82.49062968838601, 77.10250116163685, 84.9242328828381, 82.09505081176758, 83.07600421290245, 83.29926552311068, 91.9654364739695, 83.03092049014184, 74.60049183137956, 71.96565535760695, 78.36667322343396, 70.24946935715215, 65.94604876733595, 31.970115515493582, 29.23051645678859, 21.79053725734834, 16.293068739675707, 28.328257568420906, 27.247589672765425, 27.581220596067368, 17.860838136365338, 3.480199176457621, 3.493488656897699, 0.7971336680554575, 0.37142504367136187, 0.24275593429563508, 0.16154759593548315, 0.4318374503524073, 1.1402468599619404, 0.35517926057500226, 1.91294961638989, 0.3457711492815326, 0.24666877433417306, 0.08536568302060328, 0.6021322994943589, 0.20637903062085952, 0.3779022251406024, 0.8470879326904974, 2.6988368072817406, 0.6166996758791708, 5.713416078398305, 8.29898807310289, 4.071039523809187, 0.4211133225790916, 1.7315999346394695, 1.7205088201069063, 2.0860522697048802, 1.6349906089805788, 4.504868618903622, 2.8383775776432407, 0.6403896272663148, 10.147541319170307, 7.410524650927513, 10.383226736899346, 29.30881481016836, 33.68653489697364, 30.1579059708503, 29.607152246659805, 14.780841085218615, 15.789827665975018, 28.199719536689024, 20.049536381998372, 42.1230746084644, 68.34002817830732, 59.795580141005985, 65.00727261266401, 68.87053658885341, 70.55240185030046, 70.57628908464986, 73.00908427084647, 73.01664660053869, 70.83316510723483, 73.9273738861084, 69.72633500253, 71.98639685107817, 73.384611991144, 77.3907639903407, 82.54571545508601, 90.62600981804633, 87.90733660421064, 75.43458384852256, 91.50950800987982, 51.054484075115575, 46.465946397473736, 73.70250440412953, 46.46757810346542, 25.919533967971805, 29.37667181414943, 29.380727544907604, 20.22667258016525, 24.426236652558853, 8.248211030037172, 2.134878423906142, 0.5560338473127735, 0.29123301287331893, 0.147542528087093, 0.19692221145716407, 0.5785262500566821, 0.7012009512512916, 0.7844168536605374, 0.19828678258965093, 0.07854145606078448, 0.279792592890801, 0.1293560910609461, 0.2591157572404031, 0.4342187580562407, 0.19101274710509086, 0.21750054352225798, 0.04323516026019089, 0.03998859071983926, 0.019715108022454287, 0.18699732789349172, 0.04139032094709335, 0.09691281139009422, 0.08030944909419745, 0.062103017173226804, 0.03764105600214774, 0.20410947982342015, 0.07606504620203088, 0.052637031767517335, 0.09747531144849717, 0.08388753935334184, 0.031113871974089456, 0.11541203445484562, 0.03367250221931646, 0.05541818757211009, 0.06278179022633741, 0.04705705800123754, 0.09327886566039055, 0.04545857724283011, 0.04608604538765165, 0.12879447200365607, 0.14193527009938994, 0.07245311017839179, 0.17793888977218061, 0.05828860794164001, 0.2676702627251225, 0.2782420615755743, 0.10855711801278015, 0.10368823088825711, 0.2912121752817785, 0.1697583884120949, 0.12155766073133677, 0.1711681740538728, 0.0715744839380345, 0.4400363991097097, 0.27760731176503245, 0.37430672936381837, 0.4133662431230469, 0.27613299087651316, 0.37484749550780944, 0.0784106465477136, 0.29165601598158963, 2.4837166215142896, 35.16994391718219, 77.4386247511833, 91.05345402994465, 103.89501940819525, 101.63334154313611, 67.56729772014003, 42.361307605620354, 59.099657535552986, 78.45274571449526, 89.12185930436658, 88.0451451578448, 108.98435746469806, 71.12815087841403, 80.0381834276261, 108.2313722179782, 96.96554060905211, 100.36592960357667, 87.9535891932826, 87.4796413606213, 85.20722404603036, 86.45486723992133, 84.81423393372567, 87.20785248664119, 83.79821454325031, 79.769650120889, 78.61998773390248, 83.59583593183949, 85.92601406958796, 86.80622531521706, 78.46670935230871, 81.8885850906372, 76.69639464347594, 77.49808003825527, 68.234265388981, 70.84553626275832, 41.57856333640314, 36.45670490880167, 30.786004912468698, 23.390411253898378, 35.63044194252261, 31.642809414094497, 19.63392399972485, 16.795328240240774, 2.4868790324657195, 4.473275398054431, 0.5867484572433657, 0.2594604661628123, 0.6707723066210748, 0.24607977529446928, 0.6018218806674404, 0.6359861538775506, 2.980164395224664, 3.9498738319643087, 0.23883615350050313, 1.1728313372981165, 0.3615484542904362, 0.5500679222806808, 0.1511153936265938, 0.4427703217633309, 2.6287896498557064, 3.37537702052824, 5.7166471308277504, 10.947175314349513, 9.09342492780378, 10.008613909444502, 1.5874058849388555, 5.71468202337142, 3.798648075711343, 3.266999726333926, 4.29916677936431, 3.4275271383024033, 1.9081644473537323, 1.8789826261420406, 13.189154055810745, 27.091214579920617, 16.389884602638983, 26.1754156697181, 32.969188305639456, 33.782672189897106, 39.14661930453393, 24.98770433087503, 29.126650133440574, 37.732102794031945, 33.74579798790717, 51.55189552614766, 70.50196801462482, 63.75040792649793, 67.56723496221727, 75.73804978401431, 70.42359905858194, 73.34419588888846, 75.92730414482855, 72.24580672479445, 75.50065225170505, 75.06855610878237, 75.4123204754245, 72.19423540176885, 76.64681588449787, 77.64976593755907, 87.94514825267177, 85.73370810477965, 91.39104458593553, 79.76630826150218, 93.27197013362762, 51.29832606161795, 60.30577459642964, 86.32505247669836, 51.4099371048712, 49.22431007508309, 32.98015525264125, 38.53321552276611, 41.59307610604071, 32.01991196601622, 19.84882477791079, 7.061733766909569, 1.7845076827272293, 0.3515455829760721, 0.016496607943648295, 0.21940200439383908, 0.5115056302278272, 0.6807969041889714, 0.3700762386283567, 0.1294923321374001, 0.02835255018585632, 0.09795600863834543, 0.0829298528391988, 0.256121410657802, 0.180059926764619, 0.06822560718583484, 0.19213733353441764, 0.05287232418214122, 0.15348740102302644, 0.07221888645642227, 0.09649463463574649, 0.13023074896585557, 0.049634848105450796, 0.09880147093246061, 0.16641043096540437, 0.11164921741451948, 0.08240088444924162, 0.015959262382239103, 0.136669687325916, 0.007660131349468665, 0.07170948395205122, 0.15936450582117806, 0.17972031998778545, 0.16025969488245828, 0.2848587323340678, 0.13049301150585377, 0.18503287927277628, 0.2975628296694448, 0.16537691706851607, 0.16738202963625232, 0.2388215825081833, 0.32931582581612373, 0.186366745601258, 0.5544930299924267, 0.2603796184543641, 0.30871219752777007, 0.7128741700322397, 0.3290812190501921, 0.2200798083457255, 0.42750286358979445, 0.21424109987433881, 0.16560616121897775, 0.35292827974884744, 0.20201828961651172, 0.5678199568102437, 0.3247260398441746, 0.45371572637269575, 0.2834119293237886, 0.4318723839617545, 0.4260969390311549, 0.3881647389742636, 0.37707108102979203, 0.7704053506735833, 23.613219530351703, 62.86171259418611, 85.48262934530936, 118.34881228785362, 118.16779490440123, 85.5121491032262, 40.77528153696368, 58.222925432266734, 69.50406997434555, 92.69803324053365, 106.244825086286, 133.5619289644303, 94.257214607731, 92.45723109091483, 106.82032308270855, 98.41823747081142, 102.6444265919347, 92.2452897410239, 90.1298927491711, 89.5710648259809, 88.09010336475988, 85.64099111864644, 87.6335237872216, 82.18505351774155, 80.04524369393626, 82.7685139256139, 87.19579512073149, 88.4441835649552, 88.77868329325031, 84.29995629095262, 79.32246069754325, 74.57449436187744, 74.45229684152912, 70.80886994638752, 73.16611243832496, 46.73576624162736, 46.12546897703602, 39.096169779377604, 25.098252411811586, 38.45971815047726, 35.085283479382916, 33.32017767813898, 24.361237095248317, 8.597341199075023, 4.416944278824714, 2.0587319808621563, 0.4600020906617565, 0.5556429586102886, 0.16506170253119162, 0.7120995019232074, 3.6790885944520277, 7.663428293120477, 4.229250040746504, 0.8335624358827068, 2.3389480671574994, 0.35430159960542956, 1.160419364610026, 0.5627041442259666, 0.2980313384004178, 2.4696659561126464, 2.973540492596165, 14.959838448032258, 15.343181490898134, 19.467686107081754, 11.908123647013019, 2.5821698288763724, 10.223235218755661, 5.6760358906561335, 3.4786461630175194, 3.4587423407262374, 7.129575571706218, 8.311208217374741, 3.7697041707654155, 11.916714618282935, 21.46921080927695, 16.844163710071197, 40.69635952672651, 38.697068614344445, 37.4571721015438, 42.62754240343648, 25.232162129494455, 31.742074797230384, 42.71406988943777, 36.471296125842684, 58.02211576892484, 72.80939640537386, 69.42334759619929, 67.69781850999402, 80.54114895482218, 73.24532078158471, 76.26984473197692, 80.13464235490369, 77.61331142917757, 76.76116866450157, 79.762707525684, 76.88564900429019, 76.08993345691313, 74.57742829476634, 76.51916626961001, 82.53174397253221, 91.51401089083765, 87.87132140128844, 84.10424570883475, 95.46859941174908, 69.2280763195407, 62.60790386507588, 97.85004292764972, 66.21177365702968, 64.56961062646681, 48.34028236327633, 59.98866665747858, 63.16912835644138, 47.51895373867404, 15.728434728037929, 4.36136870614944, 0.6484516301462728, 0.6466657872642241, 0.31519955264464505, 0.23884514737273418, 0.5138254976801334, 1.0066714017621934, 0.7555911714030851, 0.3271625671655901, 0.17362578411496457, 0.31341401619776604, 0.12975372133716462, 0.3661093127823645, 0.47931277703854347, 0.21182438358664515, 0.3349192380424469, 0.14768164965414232, 0.2005814917145237, 0.20675418387737968, 0.27649063136308427, 0.21845298999499893, 0.18953788995502457, 0.1590987039549697, 0.19853206862124706, 0.11347482025983835, 0.26086256028183047, 0.16602985380638033, 0.4385308831209137, 0.1133192661068132, 0.20978567040254995], [0.033453450868687326, 0.026604460116716164, 0.10205344522311803, 0.025445608489756143, 0.060271714633751305, 0.02676325482166102, 0.07733058514854602, 0.09018455992542929, 0.02351717366236112, 0.08318231711464544, 0.21234282592852272, 0.20447828987192726, 0.07573150684155765, 0.46444782146042396, 0.3076831575843596, 0.3447116190387357, 0.23926799726342005, 0.2797593140313702, 0.11946501495737223, 0.05790515412246028, 0.1340695542673911, 0.12905126467587488, 0.04576359131944276, 0.13753365064340253, 0.30393042992199626, 0.33343121950184146, 0.25225576163539964, 0.2428668791488294, 0.1662861561823276, 0.08583282045419179, 0.11564985112918001, 0.7836253316171709, 2.885171698947107, 9.12587175446172, 29.260655949192664, 56.869197814695305, 66.35629730839884, 69.63459860893988, 58.93187030669182, 25.54237061931241, 24.014150481070242, 32.83645529900828, 77.24402027745401, 99.78791344550349, 100.49146898331182, 49.329237399562714, 94.20106980108446, 99.33422073241204, 101.74318359744166, 97.58035644408196, 93.86832729462655, 89.92142661925286, 86.68562027715868, 84.39042968134727, 85.13686456987935, 88.25259147151824, 84.32540462863061, 89.77415730876308, 89.27769507131269, 87.87220785694738, 81.03951746417631, 93.95424289088096, 81.53175923132127, 82.75637811230075, 70.02781621871456, 77.58449769789173, 47.050269726784, 19.2909009610453, 26.77549712119564, 12.801840593737941, 22.333752186067645, 29.869594112519298, 24.339977848914362, 23.393888435056134, 17.007112695324807, 4.567914345572072, 0.7165626688830314, 0.5340712096902632, 0.29949150198409635, 0.13953300222994822, 0.42698869601853434, 0.6800144526266283, 0.5598509876478104, 0.4376618636231269, 0.1457780590581317, 0.11832248674885881, 0.5596510080560562, 1.0231990439276542, 0.1416358216515472, 1.0360824364808299, 0.5136405640552121, 1.5508338280262486, 2.0457027251681974, 0.42041955335486325, 0.991623167309069, 2.5799122596940687, 1.7224419357315188, 0.8343513838706479, 0.434731669243305, 0.454274449617632, 0.6546197411033415, 1.138998320506465, 1.4828553531439075, 0.4944107459197122, 1.2308818029780542, 9.885619167358646, 10.157574742071091, 8.711404704278516, 21.915190181424542, 26.594132607983006, 32.07153820222424, 33.22756659600043, 24.01984968493062, 6.253869168220028, 16.44897707047001, 24.08597496248061, 22.43532588404994, 37.36680069277364, 68.62721627758395, 63.148696730213786, 64.68035874828216, 65.99710233749883, 75.49803995317029, 72.62851238250732, 67.1859727367278, 60.16502034279608, 63.81740985378143, 59.54267747940556, 68.43011717642507, 69.48525828699913, 80.10167875597554, 81.37781404679822, 94.01198017981746, 82.79908487873693, 93.52191140574794, 58.61502908891248, 44.36367757858769, 65.14736398573845, 51.2448759232798, 26.59295589693131, 16.633771696398338, 26.3584001218119, 22.831251890428607, 16.592324010787472, 9.519734594129748, 2.598482721274899, 0.08452699294373875, 0.38870581155342443, 0.4636564832781592, 0.2865845139228529, 0.45503652324118926, 0.5016352921243638, 0.6891493463227827, 0.4881632988972049, 0.10467579483144707, 0.217387652805736, 0.1957417312528818, 0.028625999524768804, 0.13169010049633442, 0.23090910466928638, 0.1551221100793731, 0.31129918451751437, 0.08831376555345713, 0.04655002653899212, 0.07601020196753164, 0.04878015828228766, 0.10351084322938997, 0.044750256178480004, 0.07076082961453546, 0.033029834890077193, 0.06337913196353663, 0.04126650198633152, 0.051605724203850956, 0.1793277152483502, 0.1072421970386659, 0.04870568687516836, 0.04180474770105174, 0.06653030823555685, 0.07004791585307929, 0.03940621834068049, 0.09135785422498181, 0.03984719770209443, 0.13372887496746358, 0.0897213984881678, 0.05767278433326752, 0.09081158756969437, 0.25003174710417947, 0.13122108614733144, 0.2019653989062194, 0.170950222039415, 0.22611518690903343, 0.20086330481834952, 0.04111621851822542, 0.11993998947042613, 0.14967160900273632, 0.3859818173993019, 0.38395002965004216, 0.16381003743698522, 0.12188356985608417, 0.10127431082148707, 0.2408429361399143, 0.34238743085053663, 0.31319212649137745, 0.3349357548980944, 0.4293340895204775, 0.25157899956309027, 0.10596353500600784, 0.9930660479491757, 7.791478970358449, 36.89925024586339, 58.61806500342585, 87.20215720515098, 99.23904834255096, 97.69256760997158, 73.14134659305697, 54.42929529374646, 54.836147062240116, 81.76433224831858, 85.11179277973791, 85.19596684363582, 100.98112198614307, 61.45837091630506, 101.68000990344633, 107.1336655462942, 106.28748478428011, 98.95113068242227, 90.21751849882065, 88.6194585984753, 87.47349892893146, 85.83352458092475, 88.51686508424821, 93.69867693993353, 89.35964122895273, 83.98644908781975, 84.52974442512759, 86.59903003323464, 84.6689336530624, 84.5980485793083, 81.66376267710041, 88.43105931435862, 76.17108729577835, 77.01517351212041, 50.84001279646351, 32.267154647457986, 34.89490339832921, 19.566014043746456, 29.670637769083825, 38.7901896046054, 26.615056491667225, 16.303319854121057, 12.712726304608008, 1.3228868789249852, 3.7196694362548093, 0.7307457755650244, 0.5052847204910171, 0.28733059163055114, 0.3274473986558376, 1.4377597406987221, 0.29588534226340635, 0.23147956438122258, 0.2668659929786959, 0.08044964318434078, 0.0591246779978035, 1.195825496988912, 0.3264900338986228, 1.1000783573235235, 0.06748512958086307, 1.1962792661882218, 0.7881421247316945, 1.6715550663009768, 4.74544229045991, 3.147103411536063, 0.6961884686062414, 0.215506860986352, 1.2170509128801286, 0.9017193786078884, 0.750464694874902, 1.0673727768082772, 1.3743324409569464, 0.8465675444852921, 3.545879755289324, 19.18568926472818, 20.592894477228967, 20.165411041628932, 23.75431895256043, 30.95600239692196, 35.7251161913718, 28.685173642250803, 28.18038421292459, 23.321146119025446, 33.64507152188209, 42.82737539660546, 39.36682508837792, 46.43750529135428, 72.34226565207206, 70.99854792318037, 68.15977173466837, 69.571958357288, 78.2413770306495, 77.50492849657613, 69.41448303960985, 67.41328977769422, 69.14304717894524, 64.56067938958445, 66.97403923157724, 74.52556671634798, 83.28193649168938, 90.5195802257907, 90.49279828225413, 89.07277476403021, 93.03469027242353, 63.481639277550485, 51.87877408919796, 79.70251483301963, 60.51038503646851, 45.45610474001977, 33.65841542520831, 26.579610032420007, 39.78140392611104, 34.12246711792485, 23.07103422380263, 8.354459212672326, 0.15022818720148456, 0.9273723536922086, 0.02250920496730795, 0.2604610076354396, 0.22398765349099714, 0.6912797449096557, 0.40298210517052685, 0.24178623552283934, 0.1301844006464366, 0.08302514651610006, 0.09409476462150775, 0.03732413308875215, 0.14700478032952355, 0.25758989395633825, 0.04005917040030322, 0.09655401411075747, 0.10975767738155781, 0.0979780872923232, 0.06205658458413617, 0.03430419150860079, 0.14671101625407898, 0.03683506638833112, 0.033200752936423786, 0.043360572683835225, 0.07238897329737103, 0.023854535801576513, 0.10536095322740656, 0.09794389678826255, 0.1995869257277058, 0.06801006834833853, 0.1420637124007748, 0.14412223661859191, 0.15888171721129649, 0.09300445296591328, 0.20899034856307894, 0.19087904944054543, 0.24590477016904663, 0.1711469993836457, 0.12703449224993107, 0.13599399777670063, 0.3589859821142689, 0.3689140219601893, 0.3065668142610981, 0.5707864944011934, 0.4900049129801412, 0.3000953324860142, 0.1609405325425248, 0.41954648891283625, 0.22635556997791415, 0.6165149567588684, 0.3946858019598069, 0.13511979952454567, 0.11393188363722256, 0.3550947457551957, 0.2868570880063119, 0.32525142294264614, 0.2758102533557723, 0.4115051397633168, 0.537689289739055, 0.2942899181958168, 0.18488974340500372, 0.7663989559777322, 3.1851910967980666, 24.798061655413722, 56.85193546356694, 84.17214193651753, 100.1719448643346, 103.68303883460261, 86.61867326305759, 55.022651841563565, 56.219684693121145, 73.90565964483446, 88.54383530155306, 105.3535213778096, 121.13924134162166, 80.44133247867708, 112.31111572634791, 109.2069362824963, 104.80546428311257, 102.02846542481454, 96.20014498310705, 96.87731865913638, 93.2255449602681, 88.6093859518728, 88.70109881124189, 95.61563338002851, 84.99056016245197, 86.05586805651265, 87.83833426813926, 94.80367922013806, 87.01431489759877, 93.27773601778092, 86.42435904472106, 91.74696830011185, 77.02785845725768, 76.09938636902841, 56.913681414819536, 36.056948707949736, 37.23731148627497, 24.8247435785109, 34.36898023851457, 44.56367531130391, 30.94948341769557, 30.240722894668583, 23.09318973172096, 5.667492478124558, 7.3601800491732945, 2.7170123352158457, 0.5915414097328341, 0.21189316296048705, 1.3955766106805494, 3.9085619584206617, 0.6605118765465675, 1.0110393899583048, 0.34347380481420026, 0.21424074747389366, 0.8103614324523557, 2.655916271671172, 0.31208473107507156, 3.578328297984216, 0.4914216547002716, 2.6151728966543755, 4.14894441443105, 2.6603730647794666, 6.0939256991109545, 3.8020544090578636, 3.4503840150371676, 1.4524725512150796, 2.3227562779380433, 2.4993546210950424, 2.044970835408857, 1.4394637653904578, 3.2230223571100547, 1.0576878319824896, 4.427009570983149, 22.000440935934744, 16.48103460188835, 19.581870225168046, 29.44945139269675, 41.37248592991983, 45.791545837156235, 39.85190852995842, 34.4599360804404, 19.000169000317975, 30.1574529370954, 43.53211549020583, 44.533877065104825, 51.49714708328248, 76.75772482349028, 74.22300292599586, 73.803968275747, 71.2988288940922, 80.4860161196801, 81.86549801980296, 72.69566335985738, 71.89556260262766, 72.82096739738219, 68.04088469474547, 70.25986363810878, 74.19505996088829, 82.19293748178791, 90.19563167325913, 92.38578904059626, 88.76962261815225, 100.50190248797017, 77.15798701009443, 60.738619912055235, 80.47201325816494, 75.38737420112857, 60.49873167468656, 57.947214188114295, 53.801457189744525, 59.048690257533906, 44.27174506648895, 24.393131848304506, 4.041291778126071, 0.30707016467086734, 0.6832337992325906, 0.4879216134788529, 0.19838430558241185, 0.4619177394816953, 0.4738352177364211, 0.5873531764072757, 0.5255897583500032, 0.31196675353473236, 0.5040753740937479, 0.2899049228477863, 0.17759111649807424, 0.32805484509275806, 0.5587594042862616, 0.2202078676031482, 0.25321740116323194, 0.24637312568243475, 0.24298894759868425, 0.32353636658480095, 0.12821844283251033, 0.27966952852664456, 0.2116143529213244, 0.17283171865968935, 0.09906001794602602, 0.1407915161501977, 0.12297507660884051, 0.10465494191814816, 0.3590415694540547, 0.15616058822601073, 0.10795275891019453], [0.019127531991069837, 0.11986502010615603, 0.1092021793667828, 0.05742617680000202, 0.029510898110006126, 0.013592484493499563, 0.1028833176279741, 0.08393604037982803, 0.08952502717053698, 0.09441206291798623, 0.1092810174750705, 0.16085972558827172, 0.1013746300351716, 0.1185194785977083, 0.34932941318519656, 0.3636522236610613, 0.21114187585490368, 0.32432531457274194, 0.16413611510107595, 0.20629554235887146, 0.06968670539678105, 0.20654727885079002, 0.2807762804290941, 0.14660779356716142, 0.006961377765682917, 0.21930964483368784, 0.45733061949572257, 0.28304966166615486, 0.19343963704041897, 0.28481846675276756, 0.07140587564677962, 0.20572537376034647, 0.931007961832708, 5.229124955592617, 12.718971698514878, 30.299613360435735, 48.034502229382916, 51.442296658792806, 61.03755943236813, 52.75652600872902, 29.317083166491603, 29.08745388830862, 36.87099349114203, 68.92508106846964, 103.50779518004387, 80.18055762014082, 56.39824275047549, 103.26795793348744, 93.77357852074408, 102.4241227488364, 95.85922041246968, 93.30032886997347, 87.55240917205812, 85.8172232104886, 77.66238812477359, 83.13312961209206, 78.50967499517625, 79.39363602669009, 85.39829838660457, 87.12443936255671, 82.01471282589821, 84.42104770291238, 86.88553564010128, 73.31840238263531, 84.99665552569975, 54.41475506751768, 27.821206892690352, 29.204062031161403, 14.353589069458748, 18.147016225322602, 28.75771983977287, 17.97038601290795, 18.64953067994887, 17.18049518523678, 21.55988031818021, 3.9170808561386603, 0.6041501750869136, 1.6739066497933481, 0.10287593254038405, 0.4085838320034166, 0.5170131282460305, 0.3822323992367714, 0.7025655683490538, 1.2548363304907277, 0.30266715093485774, 0.1751133736463324, 0.09333799232638652, 0.18980592879797184, 0.6357297902145694, 1.4207251321884895, 0.16498982816213564, 1.0863173344442922, 1.627774918752332, 0.8978419318314522, 0.5829372004635873, 0.3330381857531686, 0.40260224813415163, 0.48254934530104365, 0.34661890217854135, 0.7635122753920094, 0.42059051353604565, 0.4105396544741046, 0.6331927521574883, 0.9318729670297716, 1.1652484151624865, 3.757610522931622, 21.147827486838064, 27.629293164899273, 23.611258345265544, 22.558211780363514, 27.883262711186564, 40.138010132697325, 34.74760663124823, 11.973460528158373, 14.18718251489824, 25.648837474084672, 28.338693034264352, 26.08283400535584, 33.61408087515062, 57.767883423836004, 69.37363547663536, 69.82189178466797, 62.21967158779022, 65.36709124042143, 56.814072824293575, 57.78733837989069, 54.24186091269217, 60.41447916338521, 56.69522108570222, 65.06990894194573, 71.67161095526912, 88.64625623149257, 87.1368105180802, 92.72578008713262, 62.137199832547104, 40.63918705909483, 57.98492777732111, 50.049262969724595, 29.26798293667455, 12.644348605986565, 21.15991230933897, 19.526194141757106, 8.420512906966671, 11.609338079729389, 3.246913268681496, 0.08443780498759401, 0.5471336829566187, 0.5036933107241508, 0.3012675082971973, 0.1511438154885846, 0.6464386575164334, 0.8920876309275628, 0.6457905471324921, 0.5953154652830094, 0.3311300445948878, 0.30793480214572727, 0.12292574820739609, 0.10193297023614568, 0.20413702834517727, 0.10702028434963957, 0.0745783606544137, 0.12415959409648374, 0.1625633519142866, 0.17166311281823343, 0.029563915224805958, 0.07458389947010625, 0.011548582978937174, 0.15710232478957023, 0.19245907514085694, 0.19652965268300426, 0.2322396461761767, 0.06624083425248824, 0.10383619310995264, 0.09854472422551724, 0.08829581611339124, 0.06326573945942425, 0.06079923128709198, 0.11768120986920212, 0.12826119053868518, 0.031617050014075734, 0.0698521037796332, 0.19939603193873362, 0.0943130307320145, 0.03208746055832073, 0.11157990177913059, 0.14610087318766504, 0.13322655111551285, 0.10252460461830902, 0.06211285374217457, 0.16998372551414276, 0.2602586378493617, 0.45152339723802387, 0.20014747226190185, 0.08527700068248857, 0.05904095607899851, 0.15513542468749708, 0.3528551643173541, 0.25503906631662004, 0.35031175240874296, 0.19662346781021167, 0.16446366365398132, 0.19668234932807185, 0.3557739899523797, 0.4512072174299148, 0.5469145818102745, 0.2504966245783914, 0.23910049979965534, 0.2129199046401247, 1.5038971530814327, 11.58827102953388, 39.70745155888219, 51.24868846708729, 64.65509868437245, 90.24826203623127, 93.69544490691155, 67.78996283008208, 60.53919876775434, 63.31053764589372, 83.89540303137996, 73.89622242219987, 93.02849292755128, 84.5244021569529, 66.26827147699171, 109.54555449947235, 99.50457711373606, 108.51546164481871, 95.35613721416843, 88.82020550389444, 85.78906843739172, 88.04880080684539, 81.92401978277391, 81.16035784444502, 85.73439844192998, 84.84679745089623, 84.46015373353036, 84.62867444561374, 81.97928597850185, 84.09716975304389, 80.79486354704827, 76.94103287112328, 89.49905795435753, 61.375098997546786, 37.76696874249367, 40.51787991677561, 33.15910162464265, 21.24286847729837, 26.61693334579468, 23.940535437676218, 21.48112108630519, 19.771342277526855, 26.607498084345174, 3.1502601840803703, 2.0862729030270732, 0.5420825894801848, 0.19448458096913754, 0.4452833046595897, 1.1749321342475954, 0.3493792089002748, 0.38600271627787625, 2.8081145305787367, 0.491047497358053, 0.23236235813988795, 0.054817957683436336, 0.2895498870601577, 0.965013808060077, 0.5559680863253532, 0.32803112701062237, 1.2545712027818927, 0.5899608784144925, 0.2679673209786415, 1.0861277123612743, 0.09261340338496432, 0.5769206523414582, 0.40655572147619345, 0.39301517870157, 0.44302276305613986, 0.5559865337225699, 0.10145482411908527, 0.4304389721683918, 0.9823131152699072, 1.367379304382109, 18.177189057873143, 37.242100700255364, 44.28468104331724, 33.75481159456315, 26.387841432325303, 30.660183122081143, 41.62196043998965, 34.946149164630526, 20.15386946739689, 26.514916419982914, 39.78730709322038, 43.43878661432574, 39.577727010173184, 41.08392500108288, 71.14591921529463, 75.89001024923017, 76.37599191358014, 70.4243835326164, 69.13383745378064, 64.22354775090372, 66.6299924542827, 61.63224566367365, 65.95572133218089, 65.05476859308058, 71.69181116165655, 79.50004992946502, 92.48311088931177, 90.46277646095523, 97.5300951926939, 64.15137221736293, 51.384104374916326, 69.94349310475012, 62.639047484244074, 44.687465313942205, 34.893306993669086, 22.08397957586473, 23.872025359061457, 22.417165310152118, 16.904862388487786, 8.31537377449774, 0.9231970519308121, 0.8272396364519674, 0.3075752924046209, 0.11615238948574952, 0.12971812889220255, 0.5954430036006436, 0.7659936035352369, 0.7716827563220455, 0.4283967962668788, 0.34850482678701805, 0.1342568474431192, 0.12130067653713689, 0.12562239302262185, 0.11735484109170015, 0.12378087087023644, 0.07283150398683164, 0.015588039156770515, 0.08770157703228536, 0.12314645813838129, 0.06526593374268663, 0.10121268670885794, 0.10092749515728605, 0.03218612693730862, 0.19426385571639385, 0.062139180353692466, 0.08061829744087112, 0.06475588772445917, 0.05202442189798721, 0.05769890410104587, 0.2699693232294052, 0.12060563560695418, 0.1338927105309502, 0.14324630700772809, 0.20827270803912995, 0.15657095088353082, 0.15312540915704545, 0.3322632112089665, 0.13194134669198146, 0.18339525908231738, 0.1943963582837774, 0.34052007621334446, 0.21156604341681928, 0.22207149905302834, 0.23072023335243427, 0.46814842450041927, 0.5468526819059926, 0.5705067190912463, 0.4349960921512496, 0.45902309158155996, 0.22967623937274181, 0.27261244914224075, 0.37354793459657704, 0.2411420475090704, 0.572033746828956, 0.30909061431884766, 0.31343825521969026, 0.3052144239266073, 0.4832472207565462, 0.34464003578309094, 0.42277702040249304, 0.20498265151775655, 0.3756690175542909, 0.2676319276853915, 0.7897083148840935, 5.797480315931383, 35.35271067773142, 54.176365175554835, 66.82499700976958, 92.68936480245283, 97.5819253921509, 85.308805588753, 72.11067322761782, 69.56873416900635, 82.70979604413434, 79.63283784927862, 107.32038605597712, 108.92812636590774, 88.19607011733517, 116.45948502325244, 104.00603032881214, 109.6867912046371, 93.25939501485517, 92.66834089832922, 91.06173807574858, 96.754164080466, 86.24152168150871, 84.88891586180657, 82.41289615631104, 81.00899357949534, 84.30324323715703, 91.65600069107549, 87.95406772244363, 89.41161263373591, 89.45080495649769, 83.99797301138602, 90.76592860683319, 63.926196790510616, 37.794982310264345, 43.129766602669996, 28.349948275473814, 29.590480212242376, 40.74228655907416, 21.744039520140618, 26.342379200843077, 20.998483242527133, 30.62132420078401, 6.495702410897901, 4.176338738010776, 3.2628035256939554, 0.2178147315017639, 1.1423195874498737, 1.4972649154163178, 0.4885564858634626, 1.1370976870098422, 4.84070489483495, 0.6737301414532046, 0.27101950719952583, 0.3356213116597745, 0.3345768273838105, 2.9590941581033894, 5.009066260630085, 0.3466128041186641, 2.4501158825812803, 2.3145712719809626, 1.2857995206309905, 2.9885815564663183, 0.4133168764172062, 0.548340669803081, 0.7318844886556749, 0.6389162869703385, 1.4391640717944791, 0.8867598264928788, 0.5297357036221413, 0.580267230829885, 1.283915434633532, 7.58360315715113, 20.72761808672259, 51.094704058862504, 40.685490638979026, 38.9962120979063, 35.787552479774725, 42.72194208637361, 65.66212015767252, 45.008511312546275, 16.761340902697658, 21.369739501707016, 37.86893467749319, 41.586972898052586, 48.65002409104378, 51.043677945290845, 75.92173437918387, 83.5035425616849, 80.72677120085686, 74.0500577803581, 76.4808133340651, 69.73057900705646, 73.95404600328015, 69.2322418766637, 70.6688021075341, 64.50880604405558, 71.14915124831661, 76.33654855912732, 95.59391913875457, 90.36485841197353, 103.97099571843302, 78.38567318454866, 60.26169107806299, 74.04527248874788, 79.1745481183452, 61.84589716695971, 56.36941725207914, 52.11737578915012, 44.401163670324514, 33.81871484941052, 24.883124136155654, 5.409595658702235, 0.28034172471492524, 0.55826923058879, 0.8221761017076431, 0.3120319629388471, 0.18578896208876566, 0.5306390132154188, 0.639000985651247, 0.8510239085843487, 0.4955482639132008, 0.41066581383347517, 0.5414434270031991, 0.141460893134917, 0.10331246476139753, 0.265476462701636, 0.2896061485573169, 0.19508338593427213, 0.15051755393224378, 0.23258328257549196, 0.19030624549956093, 0.16526516016212203, 0.20545082317004282, 0.27964014139386917, 0.26687736172349225, 0.18746940659419184, 0.1807128941460002, 0.34232871787201974, 0.1722623621143641, 0.1433063529792332, 0.22861145376678438, 0.32241303653966996, 0.22896272040182547], [0.036272206268603766, 0.054120515067611015, 0.06952104654403464, 0.08199336397792063, 0.08641467955444129, 0.06995316609860429, 0.05320561456403906, 0.06146019279596306, 0.07712836858005294, 0.0526461175702993, 0.17336718347524444, 0.1733066472074678, 0.03243933048760218, 0.06898497651901937, 0.27943915056605495, 0.2704271680164722, 0.6379269303814058, 0.21354268815728927, 0.12655636911550838, 0.11300349232530403, 0.4270129963274925, 0.1483602350157115, 0.028242687431855068, 0.21861284190127928, 0.05185371452581979, 0.2124586890661909, 0.14118355398456897, 0.18596079561018175, 0.37363468639312253, 0.14970033729989685, 0.16848124323352692, 0.33690686848375107, 0.4018673246666309, 0.7382919867673229, 5.611672247609785, 14.62244499114252, 22.8780085040677, 38.39774077938449, 49.69293525142055, 52.95961849151119, 51.49002013667938, 37.74924747405514, 27.70071952573715, 32.81622959721473, 67.53638944318219, 98.98079949040567, 73.92472236387192, 63.63841249096779, 99.38678049272107, 102.35701883992841, 93.83737979396697, 92.23897472504648, 88.37676586643343, 82.95173568110313, 83.5011185369184, 77.76914719612368, 82.00882927063974, 76.88180508152132, 75.55904849883049, 73.92008612232824, 86.61590406971594, 78.21941175768453, 82.77413075970065, 86.65810092802971, 57.14864315525178, 35.234702248727125, 35.19296038535334, 29.29704769965141, 11.90630857021578, 18.37438229591616, 35.808905862992816, 27.959756774287072, 29.903389253923972, 18.24000777736787, 15.101748820274109, 7.2372465941213795, 6.517612770680459, 4.960046929697837, 1.9674857609695005, 0.2734209476940094, 0.26345662592399505, 0.04106714292579601, 0.45308091527512, 0.4575956246304897, 1.1670583438488746, 0.46878770955147286, 0.20252723246812823, 0.40433694698637535, 0.19008578071671148, 0.7454709660622382, 0.3566368501032553, 1.1256170320895411, 0.7279515158264869, 0.45015556257097955, 0.8387906488872344, 1.0870631976473717, 0.41913595771597284, 0.2903442589506027, 0.16358500677010707, 0.3601570241153241, 0.10343772779789664, 0.3222175309013936, 0.306325220773297, 0.4138107886237483, 2.1263813443722266, 8.070873320102692, 26.646123624617054, 40.010195778262236, 16.232017047943607, 38.30439621402372, 39.19737085219353, 13.432286093311927, 10.106022050303798, 12.995982227786897, 15.45811282050225, 24.969353522023848, 32.541553858787786, 42.826543854128936, 38.054611836710286, 29.472695358337898, 45.33369148931196, 63.413550853729255, 67.78075310491747, 65.92713509836506, 61.2431465425799, 60.31367424995669, 61.53996798299975, 67.35001410207441, 70.97416647018926, 87.4416728173533, 96.21334768110707, 102.71939877540835, 86.83328182466569, 61.01478615114766, 45.72188454289591, 60.05156578556184, 47.797638139417096, 30.501468335428548, 16.047150838759638, 14.042762806338649, 17.726781329801007, 13.449420967409688, 9.503491078653644, 5.719069684705427, 0.3402761538182536, 0.5936093568321198, 0.5771863929206326, 0.6265753459545874, 0.6532118553596159, 0.7341592794945164, 1.1060783579464883, 0.750964061627465, 0.6689275668994074, 0.5469192396248541, 0.2904990087113073, 0.26678120236723657, 0.1639118505221221, 0.12500116466394356, 0.2356713370329911, 0.2144098843658163, 0.5588448996986113, 0.3830784360968298, 0.22804727597582727, 0.2106459105327245, 0.17353186173544777, 0.010413639998484043, 0.1472372726927842, 0.19103839572879577, 0.07086926169933812, 0.05089267254656842, 0.07334766338669485, 0.047699024360026085, 0.04760060504439378, 0.12022475967363966, 0.08085422187803254, 0.08154973012184905, 0.18356082600451287, 0.04392806380506485, 0.08042728873871027, 0.038017848686825846, 0.10392947963649228, 0.02555477218852649, 0.08592226121935152, 0.10403077944271988, 0.09885575592277512, 0.20671292238177794, 0.17492618772291368, 0.04274317093433873, 0.1549801693087624, 0.15785719718663924, 0.4548685048376361, 0.39043787506318867, 0.27370820002209756, 0.14312422323611476, 0.08043033776864891, 0.06593275199373884, 0.2589709359791971, 0.4901370784688381, 0.0942312431852183, 0.08005633364401518, 0.09872548267125122, 0.10848948777082468, 0.15846098172328166, 0.07585057222674932, 0.3796726236900976, 0.10722355811946815, 0.21628807148625775, 0.24396238488055047, 0.29674283979881194, 1.38495875462409, 14.680337213700819, 33.51489982297344, 37.21493828681208, 53.36734887092344, 84.40913154232888, 85.40138136956, 66.28585154010405, 54.59034781302176, 65.03440364714592, 78.53136570222917, 66.34421640826811, 94.5279287522839, 76.94468067538354, 77.03606405565816, 106.71070068113266, 104.69981132015106, 102.1530399014873, 96.87980544182562, 89.27811868729131, 83.73921425111833, 83.86768756374236, 83.30641208156463, 83.37260600059264, 86.33512512330087, 81.42119546090403, 75.333755400873, 87.18324353618007, 88.18076502892279, 82.05799225837954, 83.52684144050845, 62.939340222266416, 43.623761669282, 46.63927985775856, 35.69235263332244, 20.931779415376727, 24.63387908474092, 32.326694265488655, 28.28914369306257, 29.997265300443097, 24.212336078766857, 25.457523868929957, 13.538150864262736, 8.952872676234092, 2.181580614659094, 0.6298534055390667, 0.06089685387128304, 0.6488484024040161, 0.24409087314721079, 0.26923982366438837, 0.5472564408856054, 0.7453159711533978, 0.5508585863055722, 0.21884335775769528, 0.09753651421276793, 0.13722634213345666, 0.6244806164214689, 0.4816260867782178, 0.9670557694569711, 0.9577778318235952, 2.1717295819713227, 1.7889994094448707, 1.5821465994081192, 0.590401041892267, 0.3493946532328283, 0.1743786953269474, 0.4968201230850912, 0.009494687847402549, 0.6746789260256676, 0.29397174655910463, 1.1030267539524263, 0.7349440599641492, 11.277916431427004, 34.73166611886794, 48.95288598152899, 24.801746722190614, 33.13742268470026, 34.92831022508683, 27.341067598712062, 19.78385856074672, 18.633443078687115, 17.46316275288982, 30.797921073052194, 45.865976733546105, 64.22551678073022, 55.120993506523874, 40.62914971382388, 50.253963624277425, 70.62500492219003, 78.18977432866251, 72.68008370553294, 68.94746995741322, 63.731247148206165, 68.4775778555101, 69.62334925128569, 79.12134508932792, 91.08073803686327, 101.47064947312879, 100.65073290178853, 96.18245509362991, 61.99842245348039, 57.76434544594058, 71.45544913507277, 59.76353829906833, 43.987777233123786, 36.94818965850338, 23.711131695778143, 17.17778286626262, 21.59390295705488, 18.5964374772964, 7.0560242668274915, 0.9459874935207829, 0.9255573381820034, 0.7652425922213063, 0.2295401821573896, 0.42868999343725944, 0.8007724631217219, 0.9697728688197752, 0.6635374335512039, 0.4528139795987837, 0.27159287804557436, 0.16419547159344922, 0.16003121681992086, 0.16302191682400244, 0.08105442363528476, 0.26582135548514707, 0.26412018064048987, 0.336548155474086, 0.2901210515729843, 0.1763165913402073, 0.07563253594261986, 0.2851102849648845, 0.07736121334375874, 0.03040008870283923, 0.08940833665791059, 0.13695959031822222, 0.05962401793728914, 0.017129685767295382, 0.07472367221189123, 0.021549323611261866, 0.08229652795219615, 0.021457795256508455, 0.13748278240523032, 0.17879840977970632, 0.10532500072112007, 0.2495986316353083, 0.07590441288606775, 0.21722734124670107, 0.1894020166007742, 0.16867616664498084, 0.10170715815958478, 0.14348950928017018, 0.47279477840469736, 0.30091982695364183, 0.25939157953666103, 0.2119364316064504, 0.16369487910020739, 0.3926583043029232, 0.4639664424523231, 0.6746025623813753, 0.1982586058757959, 0.30075766146183014, 0.36261310200056723, 0.615738143603648, 0.45721993511242254, 0.22937934965856616, 0.22261713751621787, 0.3710265553766682, 0.37700057029724127, 0.29708592461482175, 0.28690820139261985, 0.5488608128601505, 0.46630610561659264, 0.46662458368847454, 0.34713187465263956, 0.6346839269803417, 0.5233624649624671, 7.492164863694099, 33.26003205391669, 35.68859108032719, 55.48012571950113, 84.53963664270218, 97.23259910460442, 94.90529998656243, 78.7809931847357, 81.27951160553964, 79.7892855059716, 75.16814508745748, 109.09797283910937, 98.50579261779787, 99.71140369292229, 112.94056200212049, 109.84247792151668, 101.57076404940699, 95.99302030378773, 94.66933804173624, 94.73037012161748, 90.50797001008065, 86.69449267848846, 83.40979791456654, 82.23860171533401, 77.31018281752064, 76.10653292748236, 88.90563472624748, 92.09657699831071, 83.92598967398368, 96.42916433272823, 79.06505123261483, 52.65930221926782, 43.29216841728457, 34.16632313882151, 20.61695037349578, 26.90365076065064, 48.15450714480493, 42.22318526237242, 33.31223487854004, 21.94375680338952, 19.700200288526474, 10.493948382716026, 22.562932352865896, 15.11330020043158, 5.1673839073027334, 0.396573411961717, 0.740984448742482, 0.19860757424706416, 0.5709569949296214, 0.7841748311634987, 2.8674989698394655, 1.4215697900902842, 0.7888626763897558, 0.8293963884634357, 0.38345375789269326, 1.1402146229820869, 0.7312103312823081, 4.766339207849195, 2.5385368927832577, 2.3061742128864413, 2.220925174413189, 1.915116480761959, 0.49800863189081995, 0.3463517519975862, 0.3203267033302015, 0.5437893720884477, 0.13287713841324852, 0.6291086455025982, 1.3936124838167623, 1.0166402894162363, 6.143813344740099, 19.64851325558078, 46.31056954783779, 65.2541309018289, 20.08450431208457, 52.871365162634085, 53.75306298655849, 24.168521242757, 21.396223345110496, 25.369862817948867, 30.288075708573867, 41.7741915487474, 53.538281840662805, 69.02409738109958, 60.59605744577224, 56.866883616293634, 63.45451608780892, 81.65305460652998, 81.8286826533656, 79.86480682126938, 76.61888860887098, 71.98689106971987, 74.3435844298332, 72.87275837313744, 73.18991338053058, 88.8339259547572, 102.95242678734564, 103.361843785932, 100.62056203042307, 75.22024985282653, 65.6685567671253, 77.33742760073754, 70.37049801118913, 58.47733036164315, 58.00027601180538, 58.65161303550967, 41.31528208332677, 33.15878391265869, 26.53253766798204, 6.401301747368229, 0.2388580023281036, 0.7871644739662448, 0.8910464867949487, 0.8138058863339886, 0.8041955278285089, 0.6353961436017868, 1.1027776834464844, 0.8707875674290042, 0.5797873533541157, 0.5732036550198832, 0.5681339302851308, 0.2331318628163107, 0.1736117953494672, 0.13625694979583064, 0.29879935686626746, 0.36161225409277026, 0.537392354059604, 0.2763476487128966, 0.31592856191339036, 0.17892418609511468, 0.35037521513239034, 0.23978273173974407, 0.39577095018279174, 0.14819825338500162, 0.3171681534619101, 0.19537436144967235, 0.15259918336185718, 0.15827828507509925, 0.12875682644305692, 0.32044759200465295, 0.1904601219200319, 0.25749299915567525], [0.07099600328553109, 0.026511910949803652, 0.07193061523139477, 0.04790555017309324, 0.2535373501239285, 0.03550891839568654, 0.1032917344221665, 0.09484470341234438, 0.05342284262540841, 0.049839018198150786, 0.06209701870477969, 0.11764697339986602, 0.17529804680135944, 0.030681591541055712, 0.20365077701787795, 0.25569378037846857, 0.7392733760418431, 0.20989931188523772, 0.16281629882512555, 0.27394482926014935, 0.23342790983376965, 0.3013779475323616, 0.06616929696211893, 0.09909543419076551, 0.2628675962407743, 0.08295697235171834, 0.20010423425945545, 0.02976140311558641, 0.2697359115606354, 0.17326822023718588, 0.38407704702788786, 0.12817658378832764, 0.09196268830208049, 0.3413967259468571, 1.0967850372675927, 3.117125226605323, 14.612036981890279, 15.456716456720907, 23.424698652759677, 36.19949940712222, 49.48507316650883, 48.47919702529908, 42.41742103330551, 19.915862006525842, 31.05146896454596, 58.83329722189135, 82.37686526390814, 69.06118731344901, 60.70020814095775, 92.46691934524044, 99.85339349316013, 97.77338412500198, 90.39008709692186, 82.82958522919687, 79.56897381813296, 81.05307317549183, 75.87450904230919, 76.3087389546056, 67.70472188149729, 77.76790772714924, 79.16735449144917, 96.02631338181035, 69.22238888279085, 52.21179900630828, 40.429320643025065, 63.06324005126954, 52.06106624295635, 33.43393033550632, 28.201237493945708, 17.903978324705555, 36.4513587182568, 44.903634978878884, 24.71503096242105, 21.876164559395086, 10.665894304552387, 1.9943433327059594, 9.848871461806759, 13.61816035163018, 4.969130158424377, 0.15573439819197502, 0.7524257573869921, 0.3722158915573551, 0.41966949198995873, 0.15417274328008776, 1.1877376922676641, 0.38683002994906523, 0.28829426895226207, 0.7516349707880329, 0.2041716861628717, 1.8662405614891362, 0.6174591448037856, 0.895747876455707, 1.8616008878715578, 1.3029214018775572, 0.477367036284939, 0.5645276786338899, 0.7232124959268879, 0.43565630672439454, 0.21584651372846098, 0.36625774997857313, 0.11428490461361025, 0.5894330131911463, 0.038110936030505166, 1.142208412770302, 5.82643231076579, 15.69204003580155, 24.115288795963412, 28.724042369473366, 22.613170070032922, 44.35420897699172, 52.37758974875174, 9.99123094543334, 16.506020099886005, 22.75363995182899, 36.817555119914395, 34.081917655083444, 31.252255093666818, 28.049061298370365, 34.69801610515964, 39.89769435697987, 38.52786933222125, 40.333599121339866, 51.02648619682559, 60.228005763023134, 68.35847116285755, 80.0530884342809, 81.9798037313646, 92.73903769831504, 92.5101673987604, 90.59484266465711, 88.26754354661512, 77.50317127473893, 63.54493064265098, 56.11523982017271, 59.34307590607674, 49.70784025807535, 30.393671797167872, 15.121881365776064, 13.180102206045582, 15.131339180854061, 13.694311207340611, 6.538439085406642, 1.9157438148413937, 0.267702744853112, 0.6531248277714176, 1.3963386536605897, 0.7957893369659301, 0.4994034328527989, 0.4914822369333237, 0.4337035486054036, 0.5508724984622771, 0.9972445366363373, 0.6250507084112014, 0.46683930281189184, 0.14161355913646761, 0.14130079608050086, 0.21203807615224393, 0.37856697495425906, 0.26383323474757137, 0.3336696873509115, 0.1684546293390374, 0.09290252496758777, 0.1883707550023833, 0.17188532428155023, 0.22882061109187143, 0.16120270315197208, 0.08130890272197225, 0.2304432772460484, 0.2806746971703345, 0.10032778620840081, 0.028663604865751924, 0.04048551748236341, 0.05773889772113293, 0.031001358555870193, 0.06291299427468931, 0.06967339078865706, 0.14216065316671325, 0.19753868240983258, 0.03872970141650688, 0.04885766339758712, 0.06113553239453224, 0.05661895378462731, 0.06342818457332831, 0.15564502637472846, 0.09497286992207651, 0.14812178248839994, 0.2841650243968733, 0.05793917608717757, 0.05534699885174633, 0.19514805907683988, 0.1618208441763155, 0.3485598012564644, 0.56560933349594, 0.08669264689688722, 0.0906302392362587, 0.08416186011726819, 0.18248551435047583, 0.4148451911826288, 0.21549169244545124, 0.08096441596506104, 0.14211736919899143, 0.19782274781215578, 0.23024804739942475, 0.052031029406334126, 0.29276874336984854, 0.45857542044212746, 0.11912261962049431, 0.17712911951445764, 0.05959163923116942, 0.5462733968611687, 2.9814452942340606, 14.51425523527207, 20.8435711937566, 25.009238143121046, 45.12174621705086, 79.48342692467475, 72.13390934851863, 58.42435483009585, 42.915526743858095, 64.27828050428822, 73.26622701460316, 62.41853575552664, 92.54986178490424, 76.36573099320935, 76.09118077062791, 93.50414306886735, 107.92607845798616, 106.50869861725839, 94.09250643945511, 83.15876622353831, 84.09254135624056, 84.65020825785976, 79.02749846058508, 76.61896705627441, 80.35022366431453, 83.38901719739361, 79.77345481995614, 88.8564403595463, 80.97970916378884, 50.09584111552085, 46.310914716412945, 77.61617475940336, 69.93079247013216, 36.49206115353492, 25.92298565372344, 34.2722192887337, 46.06073810208229, 41.659626960754395, 23.22964506764566, 20.16672307445157, 10.192465205346386, 16.710248108833067, 24.63326523380895, 13.31522491670424, 5.5831933886774125, 0.23021861430137391, 0.22523657599043465, 0.736577727140919, 0.03595450194552541, 0.19167248670372272, 1.6384014775676112, 0.19693333505382463, 0.20651444432235536, 1.0181544468768182, 1.2882567629698785, 0.7942854757270505, 1.0255402086242553, 1.9588469858131103, 0.9140926791775612, 1.4029060496437935, 0.8088642515001759, 1.357856525048133, 0.5376856738040524, 0.3934610725170182, 0.09870934119868664, 0.05935346249551062, 0.0073035346576944, 0.14516423876968124, 0.04994498347983726, 1.055962479402942, 10.755681280166874, 26.609647543199603, 28.42760532133041, 38.23339739153462, 31.659326514890118, 59.71788191026258, 66.4023224000008, 16.38096317168205, 25.016878920216715, 28.16390241346052, 42.99979494464013, 41.81733762064288, 52.729524412462794, 47.28405475616456, 55.23349492780624, 61.01424878643405, 57.71921465473791, 51.61462206994334, 60.02325411765807, 70.34370822291221, 79.52237606048584, 85.24827557225382, 85.71901490611415, 94.03456518726965, 99.12557417346586, 95.79493276534542, 87.0083450501965, 78.91802510907574, 66.19343265410393, 66.84377731815462, 69.77431343447778, 56.62663844323928, 45.216746022624356, 34.007212192781516, 27.95171787661891, 17.020452676280854, 21.34913136882167, 26.030866522942823, 3.0874282265863116, 1.2075147729727531, 1.2520139400036105, 1.5904052723799984, 1.0113248649624087, 0.48992759938682284, 0.5969026768880507, 0.374067526070341, 0.47322694392454245, 0.7925562620643647, 0.34474633814346406, 0.5726360757985424, 0.18975299212240404, 0.114976697330994, 0.14278614863512978, 0.4528000367985618, 0.3537598528688954, 0.3532021408600192, 0.22332149407555982, 0.41064047164493994, 0.047181639219484026, 0.07821430587359975, 0.5355868993266937, 0.18838816052002294, 0.16118912807395383, 0.04577910843034906, 0.24756069986089585, 0.0690363810187386, 0.042382427791674296, 0.04844453516266039, 0.037531440311502066, 0.030957681968087153, 0.028940712274502844, 0.024255431527572296, 0.1541984685125851, 0.20280329991252194, 0.16429642666011088, 0.4002029220423391, 0.27410665767327436, 0.25687927079777567, 0.20723779986221946, 0.21345426628906883, 0.20179776354662834, 0.3588781475780472, 0.5357182987274662, 0.11313082379919868, 0.22238594750242852, 0.18060326696403567, 0.2107879279121276, 0.44143478536317426, 0.7459255319929893, 0.39099947879872016, 0.31427460872838575, 0.5875397954256304, 0.4697184450924397, 0.6025748531664572, 0.17908691849199035, 0.2456608784174727, 0.3593514060541507, 0.29171209361764694, 0.31551870487390027, 0.10743255456609112, 0.24604626660866125, 0.4271720974676071, 0.41820718336009216, 0.23933450901700606, 0.49434627196000475, 0.6713183128064679, 1.3703909492300403, 9.963458603428258, 27.063430470805017, 21.929738252393662, 38.71223249743062, 84.50134646508002, 84.55134099529636, 90.80752926488077, 78.74177732775289, 92.36838940651187, 75.37615622243574, 69.18199631475633, 106.3467517975838, 97.61685017616519, 98.22946948389854, 106.2482532378166, 111.3751676005702, 101.45520317939021, 92.89896841972106, 86.11502524345153, 91.85398624789332, 88.85268272892122, 83.8373205738683, 80.12970016848656, 78.67012346944502, 79.85714250995268, 81.46895424012216, 99.38224623280188, 86.21237062638806, 59.72682099188528, 59.31518000941123, 81.45345303320116, 64.10040886171403, 37.01737634597286, 31.275879529214677, 28.248527549928237, 48.13493844001524, 48.25248402933921, 27.062090981391172, 24.16687188609954, 13.276407180293916, 13.05108956752285, 36.955614705239576, 43.135524642082956, 11.581332356699052, 0.24357419280755907, 0.3695216522582116, 1.235047237526986, 0.8349664605432942, 0.39375669052523954, 2.9777158556445955, 0.6959540457014115, 0.47271161189963745, 1.8039264794318908, 5.6921803662853865, 3.0556102048966194, 0.7702382209320223, 2.0397594763386637, 2.8070238665226968, 3.021062949011403, 0.8387781463323102, 1.2363495869982628, 0.6256855807958112, 0.5902300510675677, 0.287951459927905, 0.42652904326396607, 0.19112890135617028, 0.6543666256531593, 0.12207627161255769, 2.0625403571513394, 22.03694055157323, 32.84214665812831, 46.48966496990573, 45.12706102863435, 42.620595885861306, 78.50153215469854, 76.83467388153076, 20.6966588189525, 26.570041410384643, 36.34567829870409, 56.397842668717914, 49.271343215819336, 51.12414536937591, 45.73596192944435, 58.29405369297151, 63.64959909069923, 60.95329515395626, 57.7566772122537, 73.07166960931593, 78.33050112570487, 87.96458751924577, 89.67412902462868, 92.75300133612849, 95.09972403126379, 100.27872746990573, 95.27723481578212, 95.41341950816494, 87.59561800187635, 78.54995773684594, 71.90800436081426, 75.39035520245953, 68.81582736968994, 59.902817741517104, 57.55662064398489, 67.5667642777966, 41.05761374196699, 33.11810501160161, 28.283738666965117, 5.16523297755949, 0.492671205391807, 0.6457398627554217, 1.5033581949049428, 0.8750343298719776, 0.47756894641826236, 0.459943009961036, 0.36227007847159143, 0.26914819954864444, 0.971982388967468, 0.5734993036716216, 0.7258045697404493, 0.21969776029788682, 0.2227999107731927, 0.1601176468595382, 0.2835452592661304, 0.25938655399987776, 0.5084969271575251, 0.2993292139182168, 0.33109174019867377, 0.255388310479541, 0.18377749099125787, 0.5177315348579038, 0.4513288109052566, 0.22248884843241787, 0.23230894648980713, 0.34701775819543873, 0.184131377647, 0.19435466777893806, 0.20633320324122909, 0.1327263110227162, 0.212724766724052, 0.12941702569444336, 0.09210262192232956], [0.11227238397564619, 0.14175277263406785, 0.0492456907616748, 0.21547134515018235, 0.17258479319993528, 0.22271656040703097, 0.09540169529857175, 0.2271745026472115, 0.08999617890484872, 0.08084246242839484, 0.09139376842687208, 0.057317951558938915, 0.07903450258797215, 0.13248520783118664, 0.1688401707478108, 0.37786689316553457, 0.33911562254351957, 0.9386760729455179, 0.19072711888340213, 0.21155269816517833, 0.120710444095875, 0.16943273975724177, 0.11027355332888904, 0.15473122137688822, 0.18472849721870116, 0.15740237078599392, 0.01327794124071877, 0.12016012483546812, 0.17489632561562524, 0.27012640189739967, 0.0903289904817939, 0.24615819205439862, 0.14471374842668736, 0.09712688699965516, 0.6651196809064958, 1.275347629862447, 2.0744396025134675, 8.183330614720623, 11.606702246973592, 21.893632834957494, 26.323436114095873, 46.77033801232615, 39.39324225148847, 32.298874855041504, 16.880443672980032, 17.2796703538587, 47.843831892936464, 70.1741127814016, 70.76630438527754, 65.29377821953067, 90.49517523857855, 90.69719299193352, 95.05704864378899, 91.76989063139885, 95.0062539500575, 89.46960879910378, 100.13470588191863, 98.49627694775982, 110.62331199645998, 86.86732015302105, 80.07452026490243, 61.165675809306485, 57.495231628417976, 47.88111402142433, 64.06258544614239, 46.36160350614979, 42.71044169702838, 37.855190692409394, 25.863557823242683, 20.90121630699404, 14.271326180427307, 39.31572444977299, 54.26047255915981, 49.40767303589852, 39.41884748397335, 10.178548635975009, 18.433200197835124, 27.369773464818156, 14.524187657140917, 1.3954987761474427, 1.2515653189151519, 0.1926930383929322, 0.4462719258041151, 0.059615556496165456, 1.04050294766503, 0.33605841078585197, 0.6033329124892912, 0.6027370186582689, 0.9108091650470611, 0.7537806911333915, 0.9648610194844585, 1.3926559157909886, 1.9082741511444894, 3.2553005218505864, 0.21812298996073587, 0.403200225724328, 0.3043191122912592, 0.3344807293145888, 0.0729123722281187, 0.2598125908163286, 0.40205305502299343, 0.41473937911852715, 1.4187063372904256, 2.3832414323283784, 10.405436177407543, 13.92684696182128, 32.3246056033719, 38.80331777757214, 19.262265697602306, 13.94011830129931, 4.18470319240324, 8.533727219027858, 10.047005088098588, 13.683337396191014, 10.995198853554266, 13.81710590854768, 18.039658992521225, 27.05168297213893, 34.08474176160751, 26.13601153896701, 29.49295243909282, 43.27386663806054, 47.3443062843815, 49.736214683901885, 56.894049952107096, 60.36829325460619, 62.651685360939275, 66.28559266367267, 70.72032636211765, 77.57645683903849, 75.63096123356974, 65.77126795245756, 64.7769235795544, 65.52170322787377, 46.59920107933783, 34.32302182720554, 23.74004348631828, 14.596036653364859, 11.042264353844429, 4.831196088944712, 1.3081678171311657, 2.099424610214849, 1.1293763787515703, 0.8489281984586871, 0.8608964530210342, 0.9315304337970672, 0.9536225709222979, 0.6861110416150863, 1.0898138823047763, 1.052781192045058, 1.0621617854602876, 0.7083962328972355, 0.8112675612491946, 0.5458891271583496, 0.1782406364837962, 0.4779219903772878, 0.33738349774672144, 0.4481250312059157, 0.4911175177943322, 0.3070447305517812, 0.1097236171124443, 0.2019848728612546, 0.16561541556110307, 0.11470861252277129, 0.39745539366718263, 0.38436423806894215, 0.08513880608182761, 0.1930261947094433, 0.2494950259044286, 0.06487622481560515, 0.12640470668913859, 0.1564165841667883, 0.048798191992025224, 0.09750883545606367, 0.07700962495178947, 0.13521191393656118, 0.23185758280657956, 0.307192983886888, 0.17471133070366998, 0.1283989331474708, 0.05705534044893519, 0.10085667798956556, 0.2779713261031336, 0.15694504693871544, 0.3381117715710594, 0.08156578732474197, 0.013968369363987399, 0.05580478235177937, 0.05446867138567952, 0.04913840780875856, 0.36825659594708876, 0.40909640611179415, 0.6911978654323087, 0.2715283427988329, 0.1954629058919607, 0.02785474625265887, 0.04656765805256944, 0.06821435335422717, 0.3666725712678125, 0.17717470174595235, 0.1877398815967383, 0.13585792523958992, 0.10813363226911715, 0.07711699217437737, 0.04331427416013133, 0.29800210448522724, 0.16619911327237086, 0.062377625220124765, 0.1348463674226115, 0.048257349239241694, 0.2721423163048683, 2.2975967247639937, 9.044566904344867, 5.71701975599412, 13.574233728070414, 37.90804070811118, 72.95449272278817, 62.873628754769605, 33.2691829435287, 30.501925291553622, 55.27671160236482, 64.69035294748122, 59.0678471134555, 85.74422005684146, 86.11132252600886, 83.5093790485013, 87.56364284023162, 102.92081248375678, 104.91591038242464, 95.99074532908779, 94.20379192598405, 99.18109140088482, 109.08882587186753, 109.56878277563281, 107.96996193547403, 100.62275855771958, 88.61324556412237, 65.67591121119838, 62.06996648542343, 70.97827711412984, 67.46282146823022, 68.98579151399674, 49.51451055465206, 49.16358001770512, 30.691467946575536, 29.920075016637004, 23.97665458340799, 50.045109179712114, 50.93261603386172, 46.81013438009447, 49.24876997547765, 14.334355727318796, 33.83358455473377, 29.377291548636656, 14.357078017727023, 2.091743628824911, 1.885126528720702, 0.948319097440089, 0.2576330093847167, 0.47425273565515397, 1.7359195673658003, 0.17133472156861138, 0.5550236531323003, 1.6645832984678208, 3.0058600873716417, 4.487775910285212, 0.6253629045621042, 2.483435191454426, 1.297606590294069, 2.243290529135735, 0.39689084815402187, 0.9344966649528473, 0.6620167183779901, 0.15026525053526127, 0.08880890350067809, 0.30262167595567246, 0.5608131327936726, 0.19052073479660098, 0.07830586104143052, 3.500971558593935, 16.222842624110562, 20.56517508722121, 47.13836616085422, 38.0017618210085, 24.088734349896832, 30.763729772260113, 30.115418857143773, 26.742908108618956, 23.354341137793757, 22.249276099666474, 20.704572200775146, 17.336228970558412, 21.774179012544696, 42.846959790875836, 50.894082669288885, 36.21580077755836, 55.017282116797666, 77.23049594509986, 73.97105340034732, 67.44440201790103, 66.77492403214978, 72.57077509357084, 69.6904060917516, 75.56304147166591, 80.89796696939777, 87.65241392197149, 84.66642333615212, 78.6727043890184, 76.76490276090561, 73.7692003865396, 57.74448256338797, 48.98822261441139, 42.05740236466931, 31.88360764134315, 19.35118582940871, 17.473715889838434, 12.000834749590966, 2.414177901321842, 1.302792944254414, 1.3404853281474884, 0.901095905611592, 1.2522367796590252, 0.9192133334375198, 0.6593921011494053, 0.6448683611327602, 0.74382939285809, 0.8870293055811237, 0.6476764717409689, 0.7099610747348878, 0.34785745184748407, 0.1474433043791402, 0.5898721960763778, 0.34815071030489864, 0.9893945868938201, 0.8005049452185632, 0.3629630203208616, 0.4124853339406752, 0.3404800251366631, 0.21765337806315194, 0.1623172231859738, 0.3504265736668341, 0.3664177397806799, 0.2341106780354054, 0.22522467098409132, 0.2812221742445423, 0.04962715658269102, 0.22768795009582277, 0.07270228793664325, 0.027108898371337887, 0.0532322897455625, 0.08884700105315255, 0.06372629236730357, 0.30131359614672204, 0.40314791724085813, 0.2651188528585819, 0.31755340375727226, 0.22692909404154749, 0.3907793970598329, 0.3156455996776781, 0.21180748368703553, 0.3489798319435889, 0.1862492890007073, 0.42638428328979405, 0.08838938609246286, 0.15075035273067414, 0.198570464948012, 0.3600213346221755, 0.46528993595031004, 0.7641179138614286, 0.7986667632095276, 0.16066376029724078, 0.169324935864537, 0.18718944742314278, 0.2167474637709318, 0.3913769149972547, 0.2174022544415728, 0.24231148072548453, 0.21680351076347215, 0.21172479215648868, 0.20053212500868306, 0.22917956924967228, 0.36831123333784843, 0.2094046642342883, 0.2992187746830525, 0.2759800797268268, 0.43938421313801124, 0.9852679470373739, 1.2459881988263901, 7.519597920679278, 12.69323310544414, 14.33381247904993, 31.730794060614805, 75.42659790285173, 81.24800712831559, 66.73781841031968, 72.3349465093305, 89.55819945181571, 69.58534932905629, 66.18934554438438, 99.88092068702944, 98.9988894616404, 95.72617361622473, 101.80686719955938, 109.70495177853493, 105.26613881511074, 98.0528373102988, 101.26178326145296, 106.58451018794891, 108.69726350230556, 106.10057600082891, 109.56509574767082, 94.8324929514239, 86.06306952814903, 72.30119059162756, 71.31542836466144, 70.8182522558397, 70.92141843611195, 65.20628583046698, 43.685523310015284, 44.16449962123748, 24.008345373215217, 21.36722134005639, 13.060899415323812, 47.03200324889153, 60.908717416947894, 47.54922659166398, 55.46060800552369, 11.280048239615656, 44.8424538489311, 53.47586516411074, 25.52954446884894, 5.2609966647240425, 1.8947689403449337, 2.133495543272265, 0.23802362532625276, 0.1557278098358262, 1.706646551047602, 0.2357914136542428, 0.6423780850825772, 1.5894483366320211, 2.0399630718654205, 4.6460028521476255, 2.985012935053918, 7.182659458729529, 2.702877093707362, 3.99291007749496, 0.617182924141807, 1.5068579296911917, 0.8818540445739224, 0.3325564696663811, 0.2573376058811142, 0.2936141060725335, 0.30305442370234, 0.29897065412613655, 1.284786323385854, 9.804794807587902, 30.096838589637514, 34.80127642231603, 60.93316947260211, 59.963755684514204, 37.192890644073486, 25.526598768849528, 25.060936943177257, 29.229261298333448, 28.28432506130588, 27.3289200182884, 25.192742309262677, 29.1118686814462, 30.757416717467773, 44.653948660819765, 48.53775801197175, 46.3637411978937, 54.06273803403301, 72.31245563876244, 71.35069047251056, 72.32994156499063, 74.74653736237558, 81.82269711648264, 79.05784191623812, 84.28473749468404, 89.51745387046569, 97.68194583154495, 92.67413031670355, 83.7040933485954, 79.7019657011955, 82.63625160340341, 66.52287252487676, 61.84252785098169, 64.4240906930739, 68.97468336166875, 42.53859481503887, 32.91995079286637, 20.26189350312756, 6.286156648589719, 0.9738063523846289, 0.9757176498251577, 0.8488738368595801, 1.5319471253502754, 0.8571366160627335, 0.5572638167969642, 0.7165516372169218, 0.7387479622998546, 0.6863383552239788, 0.7157439353965944, 0.7660937465486989, 0.6036058849384708, 0.19446568924092478, 0.5742972608535521, 0.30753220761975936, 0.7029206654237163, 0.7449626514027197, 0.5229840788149065, 0.6170537310742563, 0.33669362024914834, 0.27508354235079985, 0.25902024139800384, 0.5599168712092985, 0.5075050271566838, 0.2984156693902708, 0.28140867068882913, 0.299587722627386, 0.13243407912312016, 0.2591590871734004, 0.17586027872898888, 0.18958911059364197, 0.18900588785688724, 0.08667412289087811, 0.2326023888083235], [0.09712471897082944, 0.1577947610208104, 0.10369926255436675, 0.05207886776676582, 0.05624842769916981, 0.09415350824354157, 0.1978483811141022, 0.22731196946434437, 0.11595899058926491, 0.13117604017738374, 0.059388468883210616, 0.07610502066991984, 0.10633323371650712, 0.09452515281736852, 0.2047705064497648, 0.2705708554675502, 0.2726193132900423, 0.3149446292269615, 0.28540740450543745, 0.26660595209367816, 0.048968466524515426, 0.25666971510696795, 0.12543261006113984, 0.05573488065912839, 0.19915043947196778, 0.14114256828061997, 0.3982025745414919, 0.14145378383897966, 0.2560903228098347, 0.1598519982109147, 0.41821996170666914, 0.06380480105778383, 0.1482304290778214, 0.13290652554602395, 0.08347507761490923, 0.3495080036021048, 1.0733132064342499, 1.0463771872943448, 5.702362348956447, 7.860754891749352, 21.35246930583831, 15.676135805345352, 32.067860980187696, 25.057716677265784, 22.131685403085527, 9.283114671707153, 7.47184943768286, 33.02894561521469, 53.701981959804414, 60.39338857896867, 54.784807159054665, 72.94558894249701, 74.35721858855217, 76.60002985308248, 88.56485920567667, 95.84272292352493, 93.29955224067935, 83.80884416641729, 72.46673814712032, 67.01995449681436, 55.45286916917371, 49.28397717014436, 50.96451274810299, 48.46685724873697, 37.010971115481475, 36.67440037573538, 31.455051437500988, 25.293249122558105, 27.80460349975094, 23.567057155793716, 20.02880861682277, 21.631269416501446, 32.787115804610714, 51.40317101632395, 52.92430539284983, 29.40408329809866, 30.118148826783706, 49.89475296389673, 13.110177132391161, 4.496630660949215, 2.312131557733782, 0.7170608098949156, 0.45359382646218427, 0.5603146853466188, 0.1414896520755945, 0.4633012023423949, 0.49334891741314246, 0.002830862461949789, 0.11803701940563419, 0.8758012758147332, 1.1258037123949298, 0.8356137741957942, 0.3192520658335378, 1.3436878208191165, 0.17447563609288586, 1.0085429239176935, 0.2451386362794907, 0.06609050481910668, 0.11034957989449463, 0.38755465719488363, 0.22515469651308753, 2.0596674661482535, 3.486679667426694, 7.355515370445867, 7.926992447145524, 1.5638306015922179, 2.8719258548751956, 34.41670763877131, 39.944825556970414, 16.427691348137394, 15.12978494167328, 13.530775827746238, 10.709445361168155, 13.47189614849706, 16.055378010196073, 22.623974238672567, 20.318638432410456, 25.695960829334876, 26.094097091305642, 30.612424342863022, 24.375030109959265, 27.593832977356453, 38.58617536483273, 46.7434815437563, 47.61968804943947, 50.62115238558862, 56.68201054296186, 63.86106975616948, 65.99930670953566, 62.5781056188768, 63.541043573810214, 65.03471351438954, 59.92655592579996, 48.738340177843654, 40.44656730467274, 27.06824714137662, 10.948162771040394, 4.438118213607419, 3.747688642432613, 1.4883119829239384, 2.0289557979952906, 1.270738354613704, 2.116754622228684, 1.2090155698599354, 0.7086240980894335, 0.4191811262599884, 0.8390831719002417, 0.5479109864081106, 0.6641810086946334, 0.8805386409644158, 0.9704445134247504, 0.8142473981265099, 0.9611541345234841, 0.38281505506846214, 0.475188619306972, 0.17154340391918538, 0.39847015373168454, 0.4060882239812805, 0.4381505357882669, 0.012603605751909558, 0.14811312569485557, 0.07281800551760582, 0.08425025900285091, 0.1530767778956121, 0.0704570834134375, 0.29437688449698113, 0.6405038662975835, 0.16248986876058966, 0.2070697508151493, 0.23011626495469004, 0.22191250516522318, 0.02247292878887346, 0.13600685273207005, 0.04618349177162013, 0.08552954156672762, 0.027900031625082897, 0.059211644298967823, 0.08066956404476397, 0.3106571109064164, 0.05211122732068743, 0.07056409057470099, 0.12290735443633412, 0.15781685499654663, 0.14122363570476734, 0.14208816592731785, 0.13726515214770071, 0.011448301112038956, 0.06469244032257027, 0.10693530221619915, 0.12734166286405058, 0.3833387221299833, 0.3207402682352451, 0.6778570877448206, 0.4137318815675474, 0.06267340793724983, 0.5886256178059887, 0.053627108479098934, 0.2653687200959652, 0.03830170724540949, 0.09888867472088146, 0.16238073187489666, 0.21894446604194182, 0.11474458035081626, 0.05238508077097997, 0.11598947322777203, 0.006460600453729351, 0.2460085291175112, 0.16921818917316778, 0.14336659813359862, 0.0797497375958389, 0.17126456323650577, 0.7141880414658978, 3.7553956095249426, 3.7666474186605026, 4.364150647194156, 11.202768721888143, 36.67363551355178, 57.54557524957965, 40.44639079801498, 20.98528446689729, 23.66032131256596, 47.74555690826909, 58.49836603287728, 50.40358635687059, 69.05873190972113, 85.34129850326046, 78.4397783587056, 80.28241372877552, 88.33915818122126, 98.1919010223881, 98.88758828563076, 99.51635206899336, 99.44189763838246, 98.76939942759853, 87.16219609783542, 86.49857813312163, 80.51619483578591, 80.21362320069345, 72.2550792078818, 72.91780287219633, 54.94819348858249, 45.1991855713629, 36.848734040414136, 30.2142115946739, 28.15153714149229, 23.235042249002767, 30.45656700288096, 28.29727476642978, 47.07205457072104, 78.63423378236833, 88.78448055636498, 34.841680757461056, 30.144087460733232, 43.809058358592374, 21.275571238610056, 6.275565758828194, 1.6379543273679673, 1.5992914020053803, 0.32904987073233055, 0.5341184007063989, 1.211698103335596, 0.5201296964960714, 0.36875893512079794, 0.4198587769942899, 0.7633889658797173, 1.678102727859251, 1.065934737843852, 2.228471814624725, 1.0199261324540263, 1.9046614030676505, 0.05592809952495079, 0.30288263614619937, 0.140848666309349, 0.042779268997330824, 0.16817738211924033, 0.12586679039222579, 0.1766092982143164, 0.5277714541842861, 2.432425747955999, 10.939165834457645, 20.281564189541726, 28.182286562458163, 23.508329468388713, 60.121815435348026, 31.49670896991607, 16.484574540968865, 14.957862554057954, 15.84117639449335, 20.094190605225105, 22.035334340987667, 22.545307182496597, 25.18360907031644, 23.817218080643688, 27.367686763886486, 41.48810955785936, 46.38045833956811, 28.402945380057062, 33.76249551773071, 50.386547580842056, 64.31755519682362, 68.22644418285739, 69.02328152810374, 74.10485329166536, 85.57140827178956, 86.6185163682507, 80.7183224155057, 78.52278355629214, 72.24270020761799, 67.13816688906762, 59.088714122772224, 54.59601956029093, 40.674547226198264, 19.235889719378566, 8.203619074436928, 7.990522586530256, 5.986175738996075, 3.869463282246744, 0.7085686946107496, 2.3012965004290304, 1.6977568667742515, 1.2767746371607627, 0.7670799162118667, 0.7511086377405352, 0.8217543856270852, 0.7884609398822632, 0.7748950549191045, 0.7618415908467385, 0.8017708901916781, 0.7274785024985191, 0.35810384719121846, 0.3834947282748838, 0.26874634046708384, 0.6837429106235505, 0.7718750750345569, 0.7230446920279534, 0.4076769371186534, 0.2311435122523577, 0.10259123128508368, 0.24983716077141224, 0.20444111928584116, 0.19722167522676531, 0.14514709372193585, 0.5666610802854262, 0.4943609808481509, 0.2851964238910906, 0.1998986009388201, 0.19707564354663898, 0.1498161085070141, 0.13840558127530161, 0.027898817375722914, 0.053014303257148114, 0.09559219072182333, 0.23227416609804477, 0.2532350977942828, 0.36854492079827095, 0.14108980014439554, 0.23048262352183943, 0.20543482725418385, 0.42791020786089284, 0.5350724559637808, 0.45054681899566806, 0.2522202611209885, 0.11015729182550024, 0.18613819092992814, 0.24821611872363478, 0.3027310426677427, 0.7914250872788892, 0.49484239049976875, 0.6758211324772527, 0.45257278447670324, 0.2516241527853474, 0.48989361572650175, 0.08836058118650991, 0.6016424322320569, 0.35155885161892064, 0.1627608953464416, 0.3957746580483452, 0.28456001933063235, 0.5315670827704092, 0.19880698693375434, 0.3519231417486745, 0.21524369446260316, 0.435754856274974, 0.43213591820770697, 0.3105901854653513, 0.15833908181277015, 0.18461563714569618, 0.689543912247304, 2.805901333209007, 5.334944128990174, 6.024309021811332, 9.4452723187785, 31.438646124255275, 56.929920027332926, 54.51633661024032, 47.4383137303014, 64.96274586646788, 102.07319613425963, 76.51103911861297, 65.68265768789476, 93.95499598595404, 102.34467906336631, 89.52495344223516, 93.50806543903967, 96.73510136142855, 94.89485079242338, 100.21612644195558, 107.45363681547104, 109.78307754762712, 104.55535042670466, 96.09185618738975, 91.65560845405825, 79.62862522371354, 74.04373491964033, 74.42033736936509, 75.77287258640413, 47.32887568012361, 44.653662327797186, 43.73319971945978, 31.86975382989453, 30.72674378272026, 23.545168369047104, 25.559170130760442, 16.728804842118297, 39.88521337509155, 78.36137802370133, 93.35533618927003, 58.58889825882451, 48.70274466852988, 69.36295094028597, 36.3842861883102, 14.284175865111814, 2.569655506841598, 3.2205716111967644, 1.1831324619631614, 0.42672084103668895, 1.2306978193021592, 1.023744498529742, 0.6150444969534874, 0.8058736281048867, 0.6081953031882164, 2.1838879489129592, 3.1149826318986955, 3.1812184712579175, 2.136863633509605, 2.9461172415364176, 0.47422711767496606, 0.41945330197772673, 0.36051304049549565, 0.2968254853640833, 0.19768140459012604, 0.395624780606839, 0.34011604144207896, 3.085431249872331, 4.838497090724207, 19.85926220493932, 26.68883627460849, 20.15945492252227, 14.938008496838233, 62.30331220934468, 58.545026548447154, 27.484704794422274, 22.059221575337073, 21.572480932358776, 24.473038373454926, 31.40254266800419, 32.463532032505164, 38.4107748154671, 40.175982598335516, 46.506684134083415, 47.807334238483065, 48.02187219742806, 41.93531074831563, 47.79570048855197, 58.7034079336351, 74.21080435475996, 73.26319110008978, 72.86991073239234, 75.43961232708347, 88.41758205044655, 92.76687868179815, 86.67138207343318, 86.0825558631651, 83.99308573815131, 80.14928064038678, 71.62345993903376, 66.83960391629127, 62.38610167657176, 52.92010061202511, 35.39862202059838, 26.306791536269653, 10.556509206371924, 5.629198378132236, 0.8676009480991672, 1.6585807237894306, 1.4403990055284193, 1.7444872495628174, 1.100102259266761, 0.990727702456136, 0.8022141793081838, 0.646073877090408, 0.7087501655182531, 0.6984901644529835, 0.8523507115821686, 0.6863659343892529, 0.3795349423683459, 0.4067532495865899, 0.32501126970014266, 0.7644123367724881, 0.6982083666709162, 1.290215251426543, 0.832610403097445, 0.4310141203384246, 0.36614666722955247, 0.33879346724960113, 0.22284976777530488, 0.3036546689127722, 0.3078993169530746, 0.8469999245097561, 0.46394241793501767, 0.3211287667434062, 0.3651220705961028, 0.36508306139899843, 0.21699959862857096, 0.45316371405797623, 0.1738427248933623, 0.27970489114522934, 0.21728473655398817], [0.07751319752705675, 0.12043024743756942, 0.24341265550784527, 0.23816768049953446, 0.16599222356753965, 0.009073072315884695, 0.036700135322227594, 0.02211656766913591, 0.07382303626546938, 0.04465333456473966, 0.03754936293849061, 0.09941362881011541, 0.1151036764044435, 0.04800323021387862, 0.2822347586193393, 0.554593785876228, 0.2745906107368008, 0.047185071293384805, 0.061625169830456863, 0.2101001341737086, 0.2768565455992376, 0.10286743662530377, 0.24836463252863578, 0.1324320106857246, 0.14287886059572621, 0.1777240327529369, 0.03007016144692898, 0.09890411139255571, 0.16735377631360487, 0.14412528564853055, 0.28063703628797687, 0.311167509325089, 0.19430545429068227, 0.10186037574444087, 0.11062403855424736, 0.09846734168428568, 0.16590865869675914, 0.8918505726802735, 1.106277663380869, 4.337136303224872, 5.696160101121472, 12.579482409261889, 7.449241876602174, 20.990540442928193, 14.890668430636007, 11.195127944792471, 7.113970912271931, 6.8121999309908965, 26.649316433937322, 46.91397128566619, 60.719384608730195, 49.32915110741892, 67.26094492020147, 74.54870870036464, 70.72907324760192, 59.600740325066354, 68.51576605150777, 70.91655469709828, 71.4258195507911, 62.83840587062221, 56.61023116880848, 40.1849256023284, 36.31960238179853, 34.421026168331025, 19.14110956653472, 17.135189848561442, 27.318125655574185, 26.710913335123372, 29.69954759843888, 26.27046254373366, 31.527517226434526, 31.532886951200425, 39.54274731297647, 58.41823985499721, 77.78894732075354, 59.92707760103288, 43.69256004210442, 55.013775517863614, 37.418062148555634, 7.426955459579346, 1.7846236377954485, 1.8934062844322574, 7.181112573992822, 1.997505866231457, 0.8004063956679837, 1.5872592863536652, 0.9964892965170645, 0.6081209620160442, 0.27782377756891713, 0.9269611789814888, 2.3466040434375888, 1.0974231578650013, 0.4960120841860772, 0.6609721421714753, 0.2188544200673219, 0.449953836298758, 0.17771900721615363, 0.37244412447175673, 0.10944113751212436, 2.2334914678527467, 2.804671670159986, 3.324393317584069, 5.721742779977861, 7.854318282296581, 8.061172808370284, 12.461789731056461, 25.494431411066365, 54.432609696542066, 65.98204043603712, 62.18382896915559, 52.65217527266472, 33.266566722623764, 25.271274043667702, 22.113493450226326, 17.948677655189268, 11.991355361477023, 11.485532387610405, 14.055091796382783, 18.66179789266279, 21.706645604102842, 37.00179669164842, 38.296080789258404, 36.19001119367538, 38.92556236636254, 40.851257847201445, 38.02183258918024, 41.07080859522666, 44.62224022034676, 46.08184829834969, 50.481735660183816, 51.57355485423919, 45.06531115501158, 41.93990776615758, 45.180162076027166, 33.70396983238959, 13.288986221436533, 5.748156020718237, 3.1246912335195853, 1.5258746834531909, 1.7239448163778552, 0.5354080637616496, 1.5404275348109584, 1.4195471953961158, 2.123349352229026, 2.366778018974489, 1.1494535207748413, 0.2654035617747615, 1.0540042360944133, 1.1381064715885347, 0.6984152716975058, 0.4684201405654031, 0.28345323678466583, 0.1696426784920116, 0.34009259915159595, 0.35836358164106646, 0.3505899955428416, 0.3793867503202731, 0.1605408491506692, 0.1964160418438335, 0.1007451662313073, 0.3017257208064679, 0.4655527347518552, 0.42674881856768365, 0.4137824433705499, 0.17735336877165303, 0.2781268419517625, 0.46149148816062563, 0.47178531966863146, 0.12026384547953645, 0.08972443219634796, 0.1932393356917366, 0.24475917760883611, 0.07187231594035703, 0.03445097778533255, 0.04762236194144334, 0.1586491788827604, 0.035990412316976056, 0.06691017293281133, 0.14220148565307741, 0.2599781577385241, 0.16446277499198914, 0.08020889239325639, 0.020918339122867873, 0.03887207119635517, 0.03239235014564568, 0.06566900324316756, 0.14418277288636855, 0.024365623699380987, 0.06397182737747509, 0.026572855159399972, 0.187583691590736, 0.7261684921479995, 0.569305983522246, 0.42061628473381846, 0.3860911228243382, 0.4145597468220419, 0.467601499009517, 0.03533386730498845, 0.10833232483315854, 0.059876374960426366, 0.23589163327649718, 0.21157673800424223, 0.14566343698290088, 0.07142159577098585, 0.1540142703320711, 0.091757461008045, 0.10281797032803298, 0.18792124525193246, 0.054056523743295865, 0.0835031547373341, 0.05590008368955986, 0.08165223268611778, 0.5880413072243814, 1.4895738829528133, 1.3233415061427702, 3.561448132799518, 8.375602749086196, 29.30194477881155, 34.733909714606504, 22.268260371300485, 12.58317434018658, 16.91195207257425, 28.496709639026275, 41.531742003656205, 43.656980222271336, 56.84399658633817, 80.78909766289496, 82.28311277204945, 82.54595079729634, 87.55598637365526, 88.70188328527635, 77.14928719305223, 85.13522501914733, 85.43152086196407, 86.18351767140051, 76.62710205201181, 78.03091833668371, 55.00472268750591, 45.88799691969349, 48.88152630098405, 50.62331361155356, 32.7880395227863, 30.216714066843835, 28.951608480945712, 35.514316251201016, 30.609027570293797, 34.27938938140869, 29.85257298715653, 56.540628710100734, 83.17670714470648, 79.22881803204938, 64.47347333354335, 34.36949406900714, 45.924467117555686, 30.853102937821422, 11.76637605313332, 0.539398217393506, 2.7478752597685787, 4.179765418652566, 0.31963091163385304, 0.1804044365041679, 0.5919297856669272, 0.26796232608537524, 0.25020883598875615, 0.03880866975974172, 1.1163667349084732, 1.8605629306647087, 0.25218451545844156, 0.7318305560658056, 0.6456261140204246, 0.1917256225621508, 0.18385423767951228, 0.03748359429019113, 0.21591297951677155, 0.06384451888621816, 0.7743472714097269, 1.3754819405655707, 2.6870113515084793, 6.035329901402997, 9.950879562285639, 17.59986912050555, 26.895007817975937, 20.41763121081937, 59.8705287902586, 68.59789263817572, 51.7813894825597, 33.498241516851614, 15.92229591261956, 15.932882389714642, 16.97047971910046, 18.352142457039125, 19.79580217792142, 17.74662656168784, 20.41549155789037, 20.955170469899333, 31.968383789062504, 48.77293548276348, 45.83892022409747, 39.66517625316497, 48.24804390630415, 53.07397519388507, 52.00170117039835, 61.091829346072295, 59.73878814328102, 57.89863563353016, 58.52019010051605, 62.045561498211285, 58.88883013879099, 57.55862497514295, 57.527414675681825, 39.67252285249772, 17.633324976890318, 7.92490819769521, 3.378943680755554, 3.720265636521001, 1.3830240455365952, 0.4227812185643181, 2.109698768584959, 1.270903707031281, 1.3159549476638919, 0.8768549225022717, 0.6550508341000927, 0.36625045682153395, 0.5864410414811104, 0.7682895384007885, 0.9497709872741854, 0.6010907263525072, 0.5682837157960862, 0.29612430040874793, 0.5673265348999732, 0.4474094437976038, 0.7417415887598069, 0.3527193522501377, 0.0855144113302231, 0.11761807656336216, 0.15731948007258678, 0.16667293865353833, 0.2284740635584439, 0.3416674614192978, 0.3248319744823441, 0.3485922527409369, 0.15876144140718446, 0.22072612608392395, 0.48363875297288744, 0.20296531218674876, 0.09856419051967322, 0.1753493900140447, 0.12168515308369553, 0.04349206018471911, 0.061681320244867, 0.07736400956468237, 0.08385999849246395, 0.2576898837522153, 0.2569323913344453, 0.300643912726833, 0.36331226448378257, 0.22029088089062324, 0.09983155275544814, 0.18730446786409427, 0.22317279640945697, 0.16410236126713215, 0.16139670725791685, 0.24001454994563134, 0.1672356608774393, 0.20030522508726967, 0.24681022480851222, 0.3825578640305227, 0.7747392632788228, 0.5244508001112169, 0.3705722958810868, 0.3992758943669258, 0.31718853140069597, 0.3803556370398691, 0.12014403698905823, 0.25350476074362954, 0.21468619695834576, 0.34638058754705614, 0.17469023264223532, 0.16508252480097357, 0.2897315724722801, 0.2734472091880537, 0.11838512975842723, 0.2818752795217499, 0.41719331195758236, 0.3698034500402789, 0.23767292559627565, 0.23919236906353505, 0.28062312413127194, 0.5621368714397954, 1.90517719474531, 3.130652745885234, 5.641032168942114, 7.4656795494018064, 21.36360883712769, 33.17311625326834, 38.251059824420565, 26.73636167280136, 41.38502182499055, 91.10210710956206, 77.93591068636987, 62.54000371502292, 75.69792393715151, 101.38958977114771, 92.89538337338357, 93.83495576920049, 94.44248384045017, 90.69533378847184, 84.48876350156723, 95.24280425040953, 94.50546141593688, 95.78646044577323, 87.4344321220152, 85.96304124401462, 57.548450346915956, 51.49452694000737, 45.88882061742967, 49.11862573316021, 36.77507977331839, 37.0401966956354, 32.676026436590384, 40.96991346728417, 39.265416129942864, 38.351790212815814, 39.30422013805759, 64.94311440375544, 92.696425068763, 98.16049852678853, 88.01268362229871, 64.36273697883853, 60.15828171084004, 64.8249843812758, 39.933772317824825, 12.553921303441449, 12.028657101815748, 11.721690450945209, 2.202982537208065, 1.190458101130301, 2.2713161091650687, 1.694424935886937, 0.5846679463021217, 0.5078207166685212, 3.5868565113313737, 3.773486561352207, 1.7488236749364485, 1.4674946161047107, 1.4545786188494776, 0.2937285289649041, 0.22782970700533162, 0.19195767059441537, 0.7418552762077701, 0.22877985521429972, 2.9147833874148708, 4.6208942897858165, 4.312356729661265, 10.91811643492791, 21.80378310142025, 29.136399184503865, 54.631003179857814, 42.311599408426595, 73.39710081777265, 74.99295634608116, 86.86502164410007, 79.50824768312516, 51.21086505151565, 42.312274056096236, 33.23351683155183, 28.187324846944502, 24.809136467595255, 26.3519105603618, 28.326061041124408, 30.880661510652114, 40.92670463746594, 52.44840421984273, 54.0472956626646, 48.02834410821238, 56.937909895373934, 65.21135353272962, 63.52251037474602, 80.29319240200905, 82.23897041813021, 84.95447435686665, 84.97065805619764, 86.33216765619095, 71.96106618450534, 67.80442068653723, 75.82012145749985, 69.50137138366699, 51.1988429869375, 28.9208649435351, 14.41439659364762, 6.332241556336803, 1.9280927844585913, 0.34464264048203347, 1.1980435973213566, 1.0766880382453243, 2.0849564575379897, 2.2387763713636706, 1.4453411919455377, 0.5804718682362188, 0.7790700502453313, 0.9532268405441315, 0.713593679810724, 0.3151670092296216, 0.6003449857234955, 0.4393704235553742, 0.5352292894836396, 0.4911128599797526, 1.0867366603305264, 1.1377727024016844, 0.5831634721929028, 0.4663276480090234, 0.6771819497789107, 0.5023843728967252, 0.7244861630662796, 0.516537786010773, 0.5217142727586531, 0.49670661949822986, 0.20780329532440633, 0.6290956526514023, 0.7936381007875166, 0.5493083920690321, 0.23353059625914022, 0.30878687577862896, 0.3224904114200223, 0.22012681550075933, 0.28621964156627655, 0.2755769029740365, 0.21038254482611535], [0.09916490304373926, 0.3526267168983337, 0.24617878449780328, 0.1541004092582772, 0.21489754529489627, 0.12591946659789932, 0.11839239993282866, 0.13419218962230992, 0.16106068577256896, 0.0495242977875375, 0.1192385363843172, 0.10679083335543833, 0.11233419194937715, 0.1039369643155125, 0.28824082665866424, 0.5302340897821611, 0.7219092271501019, 0.22767371618218962, 0.17144480840333048, 0.05995195336459626, 0.29238055129685714, 0.0957541723525332, 0.16476257584027706, 0.06562309159386544, 0.11329688867854495, 0.0467504887661386, 0.1702796499575338, 0.17894085616834704, 0.016271922016336073, 0.1804753609241978, 0.22118948670404576, 0.3815229711753707, 0.3647781890486518, 0.12342272476563532, 0.05441742393398478, 0.22708267934860724, 0.2502734325225315, 0.11697449375905337, 0.9279320881732049, 0.8577151656631501, 1.910343078836318, 3.23434746553821, 6.686139856615375, 5.206301173856182, 12.379938690893113, 10.740995926241721, 9.842480940203513, 11.149978522331486, 3.6159161261973845, 12.911726774707919, 37.965307312627, 59.00444592199018, 55.84427464392878, 51.06324272771036, 58.25062521042363, 58.58479153725409, 63.92775397146902, 60.55235047494212, 47.90827251249745, 47.995655075196304, 53.763696532095636, 46.5047307937376, 29.418280316937356, 21.894923294744185, 24.153223999084968, 26.955184821159612, 21.06244533292709, 16.017152551681765, 18.513112606540805, 31.198550001267467, 46.08600208836217, 63.74362614846999, 53.088562488555915, 44.10468739847983, 48.73784595920194, 30.178465074108495, 37.95725076429306, 35.8598849081224, 39.09514604076263, 31.525220678698634, 13.06924229668033, 24.032966090786843, 11.042905661367602, 4.303206820641795, 1.9615485182692929, 1.7655663120169796, 0.6141146500745128, 0.5059504815407339, 1.3349937647581103, 0.6046377747289596, 0.5432963791874148, 0.9198290842675394, 0.8812755562605397, 0.5075598790520622, 1.2263919148714313, 1.9018072658969511, 0.7861320938794845, 1.423412078330594, 4.141909643527001, 4.781906604766846, 4.506331172681624, 3.842559990382964, 8.570577886796768, 19.48269505654612, 21.623554114372503, 54.87739862934236, 49.253017902374275, 70.41693887402936, 83.42424792628135, 68.19666554850917, 59.93368679477323, 49.83709804473385, 49.298533085853826, 39.76047415887156, 17.33116126829578, 3.766951647496993, 2.456072982280485, 2.1771988368803457, 14.949521633886523, 24.292946669363207, 24.9087764370826, 22.787464511009958, 19.46479924263493, 23.16698520414291, 31.72545767599537, 45.82876128535117, 51.58428645903065, 53.74916022823703, 45.99562675722184, 50.273826506830034, 49.049117411336596, 55.34939312165784, 43.862449661377944, 23.951121914771296, 6.158483499480832, 2.0557341868838956, 3.8611878166275644, 1.0957213395064878, 0.7849407965137113, 1.073378170690229, 1.8704696119793, 1.5808465788441322, 1.3064092469792212, 0.22822565188811672, 0.7757807751336406, 1.765437118949429, 1.1128519235118743, 0.2849105198777491, 0.21209127329770597, 0.5465453887178052, 0.7357361948778554, 0.9081850994017817, 0.5821676191783721, 0.20440661468573157, 0.256828831568841, 0.36597598284002275, 0.40953316815918495, 0.06775987935402701, 0.1536143571138382, 0.35300461274962275, 0.44109914692178853, 0.380990356206894, 0.5015442502354422, 0.6783494064884802, 0.3686655336810697, 0.20647485289842854, 0.18498444719420326, 0.4420417721473402, 1.0060874589027897, 0.7261480835656966, 0.2560455679532982, 0.040926255526081215, 0.03786781036685552, 0.03545052334365826, 0.06510525446144805, 0.03410722264238904, 0.1514056336975867, 0.06841750454998786, 0.0970838328583106, 0.04601284185604704, 0.12407809766309878, 0.1789876181752451, 0.3049854555677983, 0.11366653376288953, 0.032620161711688966, 0.19820490311230385, 0.09453807672065112, 0.16386671262162347, 0.09526368455901262, 0.17338769930985667, 0.12124816120992746, 0.2397319094668473, 0.7652127454357763, 0.5210187874974743, 0.48135121443098594, 0.23054988604159127, 0.20414387717122034, 0.17131535486588556, 0.28430010101968245, 0.13903809410910453, 0.10419335862201068, 0.09655333229250486, 0.027853985910394022, 0.018965044742329948, 0.02354703385442976, 0.06001864131840487, 0.032247842980488654, 0.07607587102440096, 0.20931497066011354, 0.22914105034883947, 0.24050533651344239, 0.11310624769858776, 0.22199918035297628, 0.6003915638692918, 0.32607686735929986, 0.27439473737632075, 2.1945815557433717, 3.3879523844488206, 15.930556424202459, 20.824373152948198, 10.667614263872947, 11.135461830323743, 14.630891815308603, 14.155391704651619, 24.25539585851854, 44.14882975239908, 55.72980811519008, 65.46069860458374, 72.61116766160535, 76.17696300629648, 82.18273931933989, 79.12591072820848, 78.21552076647359, 76.25602229948967, 67.85320712674049, 61.43888065891882, 49.91236048360025, 50.92787388832339, 57.62447764796596, 44.95953267620456, 24.018268969751176, 22.00766790297724, 16.931726701797977, 23.869677820513328, 34.711234492640344, 35.61919650723858, 33.07012265728366, 57.03929924195813, 58.22286267434397, 60.34794399815222, 63.40944020978866, 58.4370005515314, 46.17296103508242, 43.046224040369836, 44.285492973942915, 32.82828892430952, 10.759180034360579, 14.334058607778243, 12.34342730814411, 4.449514169846812, 1.095025854245309, 1.1888897659317141, 0.23921599521511988, 0.9197962344173463, 0.5266297380289724, 0.512033005154902, 2.3702858436492185, 1.5673867204496938, 1.730131129584005, 1.5096330065881054, 1.7197358680348245, 1.0567279544568833, 0.8257688702114168, 1.1091988485667015, 2.6541892030546745, 6.28892437104256, 8.912198678139719, 8.482096079857119, 5.551337369026677, 22.35272272940605, 31.024992965882827, 70.09892094519832, 65.4910106812754, 60.3601033456864, 68.2734106433007, 71.00547482890468, 67.35042987331268, 43.40803915454496, 31.48152155260886, 26.823267667524277, 23.633168705048103, 21.518275737762455, 18.066066349706343, 17.266004816178356, 17.812041890236642, 18.213286630568966, 18.74215352919794, 24.25883185478949, 27.13363305214913, 29.973633020154892, 34.52232922277143, 37.59237227901336, 45.18609269972771, 53.838986427553245, 53.964553263879594, 63.527491784864864, 61.01593148323798, 64.55154418945312, 50.16340001936882, 29.136762003744806, 12.904162483830607, 4.979470016494875, 1.964261327539721, 2.32385405129002, 0.45634199835119715, 1.6437639704635068, 2.5709231678516637, 2.3688257413525737, 2.642278926026437, 1.2586195790959944, 0.6864610518659315, 0.39104783426850076, 0.6163736288585971, 0.5047390513843106, 0.4453480544109499, 0.9358637948190013, 0.8055418813901564, 1.051201089735954, 1.084176455774615, 0.5787560151469323, 0.42774209752678877, 0.3046287037432194, 0.1546697045165685, 0.16605472102040247, 0.03525702868618312, 0.22366160647042338, 0.3213594204956486, 0.5367185644084408, 0.20782543526541805, 0.3158133729330955, 0.3308450598870555, 0.31469105412402465, 0.05216007691717917, 0.13931437605811706, 0.47118844524506603, 0.23469129607321756, 0.19380532145019502, 0.128441313131442, 0.045188094579404404, 0.061927261281638384, 0.05486400722856483, 0.1111113700655199, 0.18361062171959108, 0.53417049468525, 0.3689463508705939, 0.33692157737189726, 0.32930635696937965, 0.3207216982639605, 0.4541620185538646, 0.36956930292710183, 0.35835040492876885, 0.40021723256476466, 0.2387150349996744, 0.1997385651714379, 0.17887458956289679, 0.39308112355009206, 0.3288057644761378, 0.6265371028454073, 0.8117349361700397, 0.6251793498954465, 0.572956852134197, 0.23718287447287192, 0.26778523720079855, 0.15295375949673115, 0.2849849529804722, 0.16193195756885315, 0.26184851544037946, 0.20704114509205665, 0.26883483894409677, 0.2461818641712589, 0.130291530381768, 0.17720834832758675, 0.26212795367164, 0.36192435831312214, 0.42173265870059695, 0.45116128279797496, 0.39510874378104366, 0.5921691115344725, 0.46587041609229585, 0.4379988503792594, 1.2659913061126586, 1.8700708785364706, 3.5632117284882456, 3.777342006083458, 12.215239347950106, 16.75618886947632, 18.75532484823658, 22.10557810721859, 23.18345719768155, 59.209982041389715, 77.26032164789017, 74.04251898488691, 75.76090935737857, 90.76920770829724, 90.35626057655581, 95.3841115582374, 104.87433325859809, 96.30863774207332, 99.54873515713601, 96.69666213373985, 89.54541252505395, 84.9276767238494, 77.86387243578511, 65.56480615369736, 56.501867848057906, 49.64330157926006, 36.209101369304044, 29.742062168736613, 30.653281711762954, 44.424521384700654, 61.33806790074995, 72.13719629472303, 80.70442938035535, 106.25728253395327, 83.47161446848224, 78.37032102769422, 79.67021019228044, 63.46558893880537, 57.16826285085371, 46.12280568768902, 49.01801301587013, 54.04087866506269, 44.202734885677216, 42.24453472322033, 20.284860941671557, 11.879686463263727, 5.15632527489816, 1.7862025143638736, 0.6564379435393118, 1.2032585110395186, 1.6948119022192496, 2.6408482415060845, 3.591112037820201, 2.3348543384382805, 1.7741608379348632, 1.6638532473194985, 1.0986640977282678, 1.090230511561517, 1.0443939388759675, 1.8070124041649605, 7.74948803647872, 10.104961049172188, 15.101506613915967, 23.03228512887032, 16.479538217667614, 46.48493459147792, 77.42140554612683, 99.20287624482187, 85.66739651464647, 76.97889943276682, 92.60595167836836, 93.83432034523257, 86.79092807154503, 70.73360750752111, 80.7075829659739, 86.65373140765776, 80.26914827285275, 67.34204384588426, 56.625936338978434, 58.23364526994767, 56.75615510632915, 53.029766159672896, 40.55951195378458, 40.52533634247319, 40.693178484516764, 45.96958221927766, 57.29603013684673, 71.078140658717, 80.68852024693643, 87.43928017154818, 79.09480633274202, 82.61482761752221, 79.40996877608761, 84.22779252452236, 73.84768701368763, 50.55740602554814, 32.70103939117924, 21.332441683738463, 8.035421467596485, 2.5639322784639176, 0.8445770029098758, 0.6776834615776617, 1.7681727269964835, 1.628101946365449, 2.6093753883915567, 1.6593086911785988, 1.4413027441309345, 1.9983548142256278, 1.3389396691514601, 0.6941227891272115, 0.3913113991579702, 0.6351864806586697, 1.0983363346707438, 1.2952127187482774, 0.9916172224667765, 0.43951579639988564, 0.5217718825705591, 0.5351956429020052, 0.7924243723673206, 0.7738072100666262, 0.768286841771295, 0.6694210500967118, 0.5603600377517363, 0.6635250535703475, 0.5846722976815316, 1.2471759415441945, 0.849137983975872, 0.5284648556863109, 0.5975920947328691, 0.9215707391981156, 1.0412663389598171, 0.8020892763330091, 0.6338770831784895, 0.3230440171976244, 0.31106313750628506, 0.11690309436451043, 0.1861125882714987, 0.16442627856327643], [0.08480570339147123, 0.05127509597748999, 0.02503141347739485, 0.023236839108229167, 0.1030707563604078, 0.33060824678790185, 0.18797925342955898, 0.017276675057327075, 0.1931284980908517, 0.13070742419410136, 0.2249554370439822, 0.3197662640483149, 0.3789315715191826, 0.4354519451097135, 0.011498187800058195, 0.05463725669429668, 0.31459060467539296, 0.7227112292762726, 0.6407905670423663, 0.4415079007946676, 0.2821288852682037, 0.1352918322288221, 0.0693053238454365, 0.4075870596833768, 0.3455330491546662, 0.20308503640755532, 0.19861094503393098, 0.14734536769890016, 0.2477369766922728, 0.2965142085186897, 0.06553159771306862, 0.1682292615934726, 0.19829959157974492, 0.2768935936112558, 0.25061377474377233, 0.3956967928717214, 0.3096190617690164, 0.0685596521643381, 0.381700427782151, 1.0074251709926514, 1.1328112718559082, 2.213758513812096, 2.5627612058193456, 5.216013452699108, 4.554937674153236, 5.769666298743218, 11.883032245020713, 0.8514294448879458, 10.921091552703611, 10.561392557236458, 13.126287287281407, 21.938188998929917, 40.52368110226047, 53.06437323170324, 50.69299451766476, 43.94874572753907, 36.079188546826764, 37.265023031542384, 41.55811994306503, 34.284390403378396, 22.826250868458903, 22.15940675427837, 36.0303315039604, 30.64291684858261, 21.348452798781857, 12.21864200407459, 7.744749813310563, 22.72204722127607, 1.0317135289792092, 33.61129599232828, 37.704540298831084, 49.35061431700184, 34.56228640771682, 35.8431952230392, 33.17779171851374, 21.817935013001968, 39.08599122878044, 40.39326621640114, 34.37143956461261, 38.58478292342156, 39.96127205510294, 30.649318156703828, 5.296188169910062, 5.14441107549975, 7.993824241622803, 1.7437194456015865, 0.5035830247065713, 1.059605012978277, 1.9847926064845056, 1.8870964165656798, 4.666926245535574, 2.578561003169706, 1.53902271341893, 2.662462217192496, 0.9830976505914043, 1.2840237901095422, 1.5191066337208596, 4.7083984459600146, 6.045319197639343, 2.5826042313729567, 2.3756212476761114, 3.6195264227928656, 12.826116142734406, 22.02067252128355, 29.894583532887122, 82.23736224635955, 70.28688876859604, 59.803393502389234, 69.9970099233812, 63.70213139441706, 51.73590175567135, 39.955008029937744, 32.29160866429729, 27.64108184845217, 18.627255539740286, 9.183135417199905, 13.877010307004376, 14.965014015474628, 7.7875193376694964, 7.052335277680428, 8.642345493839635, 10.20696032431818, 20.49928515188156, 28.315082327012096, 34.35185517034223, 35.87746497123472, 36.324430819480654, 41.6060983750128, 50.78414255572904, 53.22855972474622, 44.9450042170863, 27.83063234821443, 16.476102221396662, 10.667356368034117, 4.668971761580437, 2.847230367122158, 3.005117043372124, 1.7521368519913767, 1.901237786777558, 2.1181823649714073, 1.9077480632451274, 1.569262471410536, 1.2139961219603017, 1.019312036373923, 0.5498312317555951, 0.6826581914098032, 0.15041495943742414, 0.20097602699552813, 0.7320759493497111, 0.6296876241122523, 0.36731485938352926, 0.3794016430695211, 0.8672002534712515, 1.160628108247634, 0.4816828998586824, 0.1884066232389981, 0.41314370990280186, 0.45640061939916304, 0.25411806009229154, 0.26499992536921657, 0.2472705210769369, 0.39958186988388344, 0.21082117612804138, 0.17912041185603989, 0.0474506126896989, 0.1491376763630298, 0.14581499981784052, 0.12116041349908038, 0.2584837347028717, 0.32166245423497697, 0.2490400462861984, 0.31187479234030174, 0.4089925245892617, 0.24690656802586972, 0.34427170070909685, 0.20077201778129225, 0.050365607885103074, 0.3053852921772388, 0.1637457320166211, 0.12442651445106154, 0.17121901164852804, 0.15738180898610624, 0.08557394402281893, 0.08291618583062965, 0.2009432843976444, 0.2637840825463495, 0.08495918144622157, 0.08363934984851269, 0.2766156875558438, 0.20637633399136607, 0.007542355386014547, 0.11776266033731161, 0.2795658615087309, 0.314754547491189, 0.3667239910892902, 0.30731895938515663, 0.3416910569273657, 0.13316748573655082, 0.21712411855978353, 0.6295456220546077, 0.3110155174809118, 0.19125101577130058, 0.2937713379581129, 0.0531976395887473, 0.19994839665389832, 0.14957581736868428, 0.07917557001834916, 0.06567467229380723, 0.25159991376342317, 0.23425808867379544, 0.02719050397225205, 0.39371216549508037, 0.4232798498724738, 0.10057110339403154, 0.09741028590548424, 0.18258011088736598, 0.3927906842962388, 0.7819144427776338, 1.914520157921699, 5.3618334474102145, 14.17573998051305, 19.72983967873358, 4.342089276159964, 5.4393046709799, 15.089298236754635, 4.102160589348886, 27.453608243696152, 50.62704378558744, 65.27928898411413, 70.63480300288047, 65.97529395934075, 64.61931097892024, 61.53122501988565, 55.850554358574655, 51.25527412660661, 51.18353397615495, 49.14434079200991, 50.45326709747315, 32.18716575253394, 16.906282286490164, 21.733902154430268, 21.07721697899603, 32.81946947497706, 47.16657976950369, 49.61078120816139, 46.64617930689166, 54.591638272808446, 77.18560834084788, 72.31973555780226, 58.90737118259553, 52.489075276159475, 40.23028389100106, 59.898805156830825, 46.7315379265816, 45.54919435131935, 56.94085559537334, 51.05189923317202, 45.88303512142551, 14.452404360617361, 11.000724492534514, 7.799905692377399, 2.072560296904656, 0.33857549991338487, 1.519559544901694, 2.3234189133490286, 1.3421524580447906, 3.261741298821665, 4.571971547219062, 4.7043981186805235, 3.4538477130474585, 0.8328636411216952, 0.5523597509149583, 1.4034519945421529, 3.3085349298292592, 4.777835184527982, 4.47620835035078, 7.785912146491389, 6.443663345229242, 10.923136088155932, 22.8874869115891, 48.300960602298865, 85.87050468690934, 79.86339476800735, 72.62107556866061, 70.56705582526423, 69.92241428744408, 69.34803808889082, 58.790057013111735, 53.09903913928617, 48.66288554283881, 40.59539379612092, 37.168858282027706, 34.52741653688493, 30.101772931314287, 27.149402941426924, 34.45298564049506, 41.469756787823094, 35.994308456297844, 40.25543805091612, 43.58080779352496, 51.997519923794655, 58.82068287941718, 65.67229086352934, 61.79854239186933, 66.62536405747937, 57.72709469641409, 48.41988294355331, 36.10082041832709, 24.023856386061638, 11.43110263732172, 4.5259861696151, 1.269220397357018, 1.7301216913807778, 1.262839436531067, 2.0168196169599413, 1.980814465111302, 2.17105517944982, 1.9331629382025812, 1.385817998839963, 0.79001885628508, 0.6336160617009287, 1.1881803072267965, 0.5204303093975591, 0.17532317448527585, 0.5254592169677058, 0.6600870348272786, 0.5809983851448183, 0.49692817212593177, 0.7510260228187807, 0.41731695854856127, 0.2172742717929425, 0.24035994834717245, 0.3274204630044199, 0.47510582052411576, 0.6468042346739, 0.37720646408777087, 0.3243954269395721, 0.5157395223936727, 0.3558798326599983, 0.30573943930287517, 0.09742125628455993, 0.049778953074447574, 0.18968441193142246, 0.16799922071156964, 0.2680616417238789, 0.351318882237519, 0.3597277697295912, 0.21606719301592922, 0.06713547939134222, 0.3020692346317153, 0.10210333286874718, 0.17972062642295517, 0.16129771337634133, 0.19516033180538686, 0.1496330901019035, 0.14157180734459432, 0.45356189591750024, 0.8019395521090877, 0.47285916043385384, 0.3409968893374166, 0.28000737330125225, 0.49433720147898125, 0.6520931831290645, 0.5412555822441655, 0.620899860176348, 0.45533732000377874, 0.27948974301257445, 0.27839062134585074, 0.29572256390125523, 0.6870102449770897, 0.6553876063516063, 0.384203604752979, 0.6412441523805742, 0.30094081776276715, 0.4157975916900943, 0.6199165710037755, 0.3502059403446413, 0.33305975878911637, 0.46987230619115217, 0.36244085479167204, 0.4356629563675773, 0.37719304222733746, 0.18966271632140685, 0.15439647159749462, 0.430225785220823, 0.44448436688511606, 0.6020328919253042, 0.8924449343354472, 0.9054932502969619, 0.4528046639696245, 0.6637000893392871, 1.2449868912658384, 2.4270334695616076, 3.6964276769468865, 2.8655144956804093, 5.178664643918315, 10.16198838910749, 19.986849061904415, 12.534975274916619, 5.652960586932398, 31.67236839571307, 75.00565698069911, 89.51441011121197, 85.60770588536417, 90.23590657018846, 92.97962019520422, 84.00438216424759, 82.35104037869363, 76.05100785532306, 74.11571825704267, 75.71178559334048, 77.47405159857966, 73.66808168349728, 82.9192663008167, 85.98340618994929, 70.13523424825361, 65.47750596077212, 66.37703880187004, 87.41147056702646, 113.10851789289906, 119.13181935587238, 106.78423727712324, 96.51588009249781, 105.05373462553948, 83.1943734999626, 63.70491235486923, 63.30137498917119, 50.69133535508187, 64.27879041241061, 50.26799786475397, 56.61262773698377, 72.1546116182881, 65.60134695422265, 52.598666298773985, 26.43779085528466, 17.057422976340018, 15.118236503293438, 5.4378798700148065, 1.2543959218648173, 3.679084181785584, 4.120137547293018, 5.653552864828418, 9.296911608788276, 6.53517714431209, 5.93025892011581, 3.623230365976211, 1.247005931312038, 0.8898463640962878, 2.2632860368297947, 8.879151728845413, 11.07192139471731, 15.073074333129393, 23.276572304387248, 26.083559643837717, 36.49685036751532, 58.14642352442588, 84.07506327475272, 120.59835433959962, 105.61348038335001, 85.3240636087233, 77.59569214236352, 74.17797411641767, 73.2321180835847, 64.5356232889237, 67.81560728626867, 69.29921242498583, 82.61376073283535, 110.32399592861053, 109.02984126921623, 97.73809848293182, 94.11251837207426, 87.37361185012325, 82.02760957902478, 74.63045089475571, 78.70287526038386, 78.75445442814981, 79.124192730073, 76.73864641497212, 80.80936847194549, 82.94218863210371, 95.94829743908298, 90.95623416285362, 79.1402744477795, 64.68413206838792, 50.367347578848566, 35.989291744847456, 13.037698595754563, 3.5306134002823986, 1.8409330614151496, 0.8219175929984739, 0.9286140289998824, 1.2306398417680495, 2.022941946502655, 2.746392848991579, 1.0553107530839982, 0.36356580894320245, 0.20746672225575294, 0.5662940935261789, 0.4162659165599654, 0.15845359663569158, 0.4859926653725486, 0.6059712580134792, 0.6491574116291539, 0.6581302624075644, 1.037334408010206, 0.8909496532813196, 0.3269834558088934, 0.2668603545715732, 0.6047808186661813, 0.9826601837431231, 0.7483851645262011, 0.38598577041299115, 0.43502835977462034, 0.35661218207209344, 0.31135535408412257, 0.5742009789232285, 0.3430224564527312, 0.4805034308904602, 0.2548136832492967, 0.4112612173682259, 0.48706641420722013, 0.9192943548963917, 1.0825182737842685, 0.9463179532078005, 0.9100411772247284, 1.1627867601571547, 0.37076544196855643, 0.21177633455203426], [0.13685966180937906, 0.19745194593504553, 0.11596073726973227, 0.202702620637513, 0.2207350127038456, 0.1671863861021496, 0.038708633998589176, 0.06035091663380304, 0.18803398275086958, 0.2923074358653638, 0.2354972358913191, 0.33714548955040596, 0.27280173414657194, 0.0680333650821159, 0.3212288484698342, 0.3523461142134282, 0.19319044396040902, 0.10238448713695812, 0.11106615555622887, 0.22997965615603233, 0.3406443050311458, 0.18563972816111582, 0.3473367572071091, 0.4759596714810018, 0.3613982091267263, 0.31415997133139645, 0.24879607792583205, 0.2864325527221926, 0.15686005714439577, 0.10425585607487349, 0.045127286350414644, 0.1493836212302408, 0.21114147748918305, 0.10215285279217268, 0.22847389501910056, 0.3170248337330357, 0.1628067686913475, 0.11604405699237702, 0.16623954739301436, 0.40702236095263117, 0.16420521623184606, 0.702924281358719, 0.4347800553566025, 1.2369034992110346, 3.2528755164915517, 8.605027083427675, 2.842548282877092, 9.310959577560425, 2.005023946685176, 4.745475630606375, 9.649266946700312, 14.830767954549483, 17.98862503420922, 16.89553891458819, 30.592447711575417, 37.15735004794213, 38.63532266309185, 33.27291703993274, 22.303092979615737, 23.827173056141024, 21.432083614410896, 13.375360735001104, 18.11395064476998, 13.600752872805442, 10.450845456892445, 15.941058570338836, 18.0451032423204, 2.7330840018487748, 12.132011555856275, 12.777325780160966, 18.04719190443716, 22.003198362165882, 18.750639577065748, 20.528338147747903, 25.262242786345947, 25.739642304758874, 40.924013891527736, 50.3986833941552, 77.140563841789, 52.91593897727228, 14.126829985649357, 1.747568761629443, 4.170627767039884, 7.016346550756886, 1.6212892796724074, 3.58633287491337, 1.2177247025312916, 2.191373792386824, 1.098322116078869, 0.6911780084333112, 0.6783017864631069, 3.1200883321223722, 1.5406311303377154, 0.6993839745560001, 1.2572509170539918, 0.8066631276761332, 2.5403691299500006, 7.590385425475336, 3.7873563074296523, 3.7111684343507214, 2.7409968933751507, 4.482688596171718, 3.3622554665611637, 7.543736186719711, 12.65356029233625, 61.728594764586425, 93.23206393949448, 54.72740327158282, 44.0514765247222, 35.823528458995206, 30.43085586640143, 37.86962109227335, 28.189956757330126, 14.20161291476219, 15.443397068208265, 13.117384487582793, 2.2669507563114166, 6.411276334716428, 1.1733179563476195, 3.9102576480757807, 4.652219808870747, 3.3307607952625524, 2.9672784286160625, 8.527974082577614, 11.981390580054253, 13.734071293184835, 20.73295251015694, 23.063181638717655, 22.785989699825166, 14.642990366105112, 9.607662366282556, 11.758014540518484, 8.190149164968922, 5.7063940551973165, 2.7943859898274948, 0.16454560441836236, 0.3863867101890426, 1.6182832732315988, 1.775285455007707, 2.335499568331626, 3.8418760270841665, 2.5957091152668, 3.1469411234701834, 1.9245649802107967, 0.7507531729436691, 1.045648852182973, 1.2611464435054411, 0.4974370690122728, 0.8425960833987883, 0.6161791650998978, 1.2229720983774433, 1.4646160866945022, 1.25732115199489, 0.5129757835980385, 0.4892686411978737, 0.15445794249253889, 0.09398188156586501, 0.04781888647665901, 0.30354395388595523, 0.055821257072591016, 0.07683634352419647, 0.2043070232555751, 0.4571258288718039, 0.48376546391556347, 0.45696663580113844, 0.4187522395964592, 0.03662806560075091, 0.06364522877359582, 0.20280648683828695, 0.21074879614095535, 0.11019612482238202, 0.27691041690207296, 0.4547675038056989, 0.5302275933565632, 0.27538844534466345, 0.09842260981038695, 0.3321120467397475, 0.44461257936012366, 0.21715307668332132, 0.1759033941573674, 0.19303564823442892, 0.36051996593033114, 0.17049018624088458, 0.08178312646886034, 0.13698755252745845, 0.08378331309124347, 0.37004810787977716, 0.5522747457988801, 0.5743844110158183, 0.4041326160152113, 0.1386995445336065, 0.23103221499871826, 0.29943625172299726, 0.2694014375728946, 0.4854973435642258, 0.41283666186275025, 0.06085842307056151, 0.24106609755225722, 0.17315264821292894, 0.10991621161660842, 0.33540312981893944, 0.3197748748765838, 0.13963348232209682, 0.19526746154071825, 0.293051460457425, 0.14636620007936033, 0.05952504703835134, 0.09947591941923865, 0.2229660292786937, 0.18947982049036413, 0.13120260810659778, 0.46261399083079835, 0.3045941684995928, 0.3154899612549813, 0.19333552569150927, 0.46748741319583315, 1.149369802686476, 1.314350330541211, 0.6728835836533578, 1.5865445569638283, 3.2761515965384826, 12.662451324924348, 15.784741332454068, 9.623442061485784, 1.5593507645591613, 6.0688171367491455, 4.208343807728061, 7.540212917712427, 21.100710015143118, 35.04794251534247, 47.07583573556716, 54.921407622675744, 47.24592539571947, 45.74565018376997, 43.22513511103969, 39.848962829959014, 31.91498071916642, 20.641900570161884, 20.38012158486151, 31.335691751972323, 27.498552722315637, 29.062085959219164, 24.29361935584776, 29.283270374421154, 46.03141054030388, 50.16096422749181, 47.83572435379029, 46.25367556848834, 42.34830102612896, 31.680073891916585, 33.05229156248031, 37.03706664423789, 54.87077766849149, 57.1383979243617, 74.43315567508822, 65.13871123713832, 47.24830627441407, 30.065234091974077, 19.127708788841, 11.499428364538378, 10.693202826284594, 6.082702817455416, 0.9776694579951226, 2.697441424092939, 1.2168063776146982, 0.4567442251549613, 2.7949451727251855, 3.7079263502551667, 1.8295888314324043, 1.0114808404637923, 0.9107440782170143, 1.2924169268338912, 1.9691602453108759, 9.824722409248352, 16.789366237578854, 12.03889644915058, 8.176902340304467, 8.650405964543744, 17.51188055161507, 30.763978842766058, 62.12864906557145, 96.20492242997693, 102.34874263886483, 74.78468633467152, 65.48071445957308, 53.369145316462365, 44.72315103776994, 45.10046343649588, 45.88265072914862, 43.22966937095889, 36.58593916123913, 36.6648337148851, 25.459806688370247, 18.950170547731464, 13.322131229985146, 8.127388300434236, 7.626446716247067, 10.603704144877772, 11.838951668431683, 14.862157702445986, 18.094425086052187, 20.520154122383367, 23.589136177493682, 24.682589038725823, 25.543413969778246, 21.081921862017726, 13.350478199220474, 8.08245558892527, 6.133102332392047, 3.887164938834406, 2.812546318577182, 0.2097727235166296, 1.3147076339490953, 2.6110904447494017, 3.2605511046225026, 3.259897294544405, 2.930247331819227, 2.1470549318098255, 1.7224144791403126, 1.4133413929131724, 1.1311210980338435, 1.2208146722086015, 1.3570518262924687, 0.9506320088140426, 1.1111830775776217, 0.9753686201668555, 0.8681555957563463, 1.1382464511740593, 1.147543816797195, 0.8238504634749505, 0.39376456590910114, 0.06498802002639541, 0.141538099475926, 0.13814426868432952, 0.37229173426185885, 0.09400400618511824, 0.10298247238801372, 0.03237251229884644, 0.162503857526087, 0.4096601242499967, 0.35378684980734704, 0.17282448678968415, 0.04266385785153797, 0.03290928329431242, 0.21794916461071662, 0.2679069838937252, 0.15967017490296595, 0.6679277915147044, 0.7288493095867096, 0.809148378189533, 0.23949923324248484, 0.11458436838321148, 0.20278109868447627, 0.4129953646371442, 0.22448636140794526, 0.26134139587802274, 0.23972881447163322, 0.23254091791327924, 0.15111105756894236, 0.21588115622439694, 0.7034664877480077, 0.8264087068457758, 0.6792609285443061, 0.7090862636123935, 0.8077293994926638, 0.8092954670709949, 0.7162630365740869, 0.779553666230171, 0.282939865944847, 0.2822634409512243, 0.5078823101376334, 0.5179093285433708, 0.7436764817084036, 1.3236943968842108, 0.8923175185918809, 0.49124435131107613, 0.4044491941890409, 0.29568588361144066, 0.3765205702474041, 0.2137321876662393, 0.2809843499093287, 0.40244786609565064, 0.10731237069253, 0.13057222499722435, 0.36849521701374366, 0.31927707094338637, 0.4206279905573015, 0.6809490186072166, 0.695010164091664, 0.6138162435062471, 0.5898210214030358, 0.804426457372404, 2.3649205315497617, 2.093771003907727, 1.8112989418929624, 1.6959439963102343, 3.609174797611852, 11.219593728742293, 14.35973052055605, 14.319494847328434, 2.932173215573834, 8.657660388177442, 30.791284422720636, 58.99569119176557, 76.17206788832142, 83.94456601911976, 83.24840022671609, 84.64096715373378, 85.62435242437547, 80.49273121741511, 70.3826024455409, 72.83918288446242, 85.04396715471822, 97.6031611042638, 83.15870346561556, 88.090879994054, 87.68191799040764, 107.63703115524785, 112.20873402011011, 118.4709313607985, 102.95007336524226, 72.02700907184233, 43.169684563913655, 30.77171571793095, 37.76674516739384, 35.35069850183303, 51.99089111820344, 48.055647726981874, 59.466050055719194, 65.1833438873291, 91.82390166867165, 68.8206361955212, 43.25327027228571, 35.43590807145642, 30.0225273255379, 19.25317756591305, 13.17016193943639, 10.342621380282987, 1.849340539305441, 3.3533484993442415, 2.1205200975941074, 2.5987506681872956, 4.403145380558507, 5.397174002662783, 3.58193148528376, 1.2521942464574691, 1.2955127800664594, 0.7928437595405887, 5.285404103417551, 19.700623904505086, 42.64491850329984, 41.43981341392764, 32.99707243519445, 30.61893351616398, 39.65824934744066, 56.07585530127249, 77.81946336069416, 103.61784904233872, 119.30003412308233, 99.95417487236762, 81.47544184038716, 57.7205051145246, 47.01352888537992, 55.14330002569384, 54.08356581964801, 50.28116526142244, 48.29730103092809, 58.33450117418843, 54.96193355129611, 58.7418040152519, 49.59823746835032, 40.02390446201448, 32.083007212608095, 32.87214102283601, 35.62229517967471, 38.105226101413855, 42.84878761537614, 42.32250359750564, 46.31959099923411, 46.8599171023215, 47.25978705190843, 43.81278853262625, 44.23323131376698, 35.85924948415449, 29.07375304929672, 14.247048670245757, 3.339658937146587, 0.2572335711409969, 0.7469832849118018, 2.7048068998321413, 4.008727525511096, 6.20951843838538, 7.716132690829616, 5.406261153759496, 4.749386723964445, 4.167149605289582, 3.12117678984519, 3.4429685290782683, 2.1660590604428323, 0.9757525834345049, 0.9835564453274974, 0.9973335866966556, 1.384241206030692, 1.3231209953946452, 1.3696203260652482, 0.93372083239017, 0.6620111412579014, 0.38166626026072814, 0.2837066586700178, 0.424013179877112, 0.8424985757277859, 0.2621463397818227, 0.32286824598427744, 0.37151853704164106, 0.4713047373919718, 0.5160466317207583, 0.3472922628204669, 0.2785569849994875, 0.15892933723666977, 0.142214156747345, 0.2124888116433736, 0.296059244222218, 0.5355603007539627, 0.9826350560592068, 0.9590554826201932, 1.3260924359483104, 0.43719396776249336, 0.2635384747578252], [0.4977218392154863, 0.3033605830803994, 0.04855635718652799, 0.060205704667755676, 0.038679396252959006, 0.14788411137077118, 0.026499239855536053, 0.21688782640041845, 0.035960136522208495, 0.10326446169206213, 0.06309302493689523, 0.130035994093745, 0.09616390681795536, 0.3634741848274585, 0.31620974682511827, 0.33971053578199883, 0.09079033629067483, 0.18680363022271665, 0.22475450750320192, 0.3036703583934615, 0.5660962589806127, 0.367545145413568, 0.24623334527977053, 0.10077887409997564, 0.2707707737722705, 0.21128519558377806, 0.37501051901809634, 0.29854657849477184, 0.1744540630569381, 0.22022976239602413, 0.43210720523230495, 0.21292529789911163, 0.36401492032793265, 0.22592639220097374, 0.15570220717739675, 0.03794263800485961, 0.06479848221304917, 0.39273733393319193, 0.16934203494700695, 0.17033016579526086, 0.33661204720697097, 0.3160224230058732, 0.646475245875697, 0.26099389839556913, 1.6506810702623862, 1.3370646536350252, 5.759001374244691, 5.4737710279803125, 2.2163325692376783, 2.469698070518432, 1.226867011958553, 4.508613501825641, 7.49937859273726, 14.216213937728638, 11.54728618360335, 15.16416451623363, 14.042851059667527, 12.2095940766796, 8.75838097064726, 5.836125958350397, 9.260773831798184, 5.454423446809092, 3.2355962501418207, 3.6167037871576126, 9.945260767013798, 2.7527711131880364, 10.164165304553125, 1.2956227290053524, 3.306315358608, 5.136226559838941, 4.195267606166102, 9.27261644794095, 17.326009235074444, 23.2478880113171, 34.96994226209579, 37.477642951473115, 24.492232491893155, 43.82759940239691, 76.46183690717145, 45.421007371717884, 19.51945354861598, 12.138753129589944, 1.618027461151923, 4.156593036267066, 4.664188921451569, 2.7953540798156493, 0.23335638786515883, 0.4529316813474702, 0.2161901654495347, 0.5795161582289204, 2.2519825014375874, 2.1893581844145253, 0.274711744559388, 1.9334551547804188, 0.562446064526035, 1.0730056680979267, 4.74562075830275, 8.853983840634747, 5.7107395510519705, 3.6674634247056903, 1.6473384754311655, 3.3514767933276395, 12.755676257994867, 13.687875578480384, 30.502193973910426, 51.42345751485517, 59.368437951610936, 37.94773509425502, 24.444763968067786, 20.37625805024178, 12.825466990470888, 10.516904054149505, 8.75784948948891, 9.485421699862327, 5.280288842416579, 2.109764958581617, 3.468165344768955, 1.0609967189450418, 0.5414688611222852, 0.7149449363350869, 2.0119577165572875, 3.203994449107878, 2.805646379147807, 2.04920748549123, 3.2849342736505696, 8.29310942080713, 10.402004103506766, 9.36376448600523, 8.856498079915202, 3.312852723944572, 1.7609614494346806, 1.1163175827072513, 0.8492762475244461, 0.09812186667395216, 0.20959787160879184, 0.14058075004046963, 0.16184889831610266, 0.3046357211086058, 0.9060028519841933, 0.5232045282759975, 0.5442655723421805, 1.0382649903335879, 0.4089820445064576, 1.1398350110938473, 1.155834849322996, 0.8729050957387494, 0.5968708076304006, 0.2566490000894954, 0.0438674547589354, 0.2558425086880884, 0.40775014448069763, 0.5215144157409668, 0.4886543306131517, 0.33019655113739355, 0.21658280083248693, 0.12888474780465328, 0.13696878337331359, 0.40814314758585346, 0.21298663089832953, 0.48680664911385507, 0.2580925702087341, 0.20065361123171546, 0.2978230544155644, 0.1565735249389564, 0.36761921079408744, 0.16303425083958334, 0.5778997739957226, 0.39729209436524304, 0.179136790815861, 0.23526429919706238, 0.12331194845178436, 0.0540843787002227, 0.06578625299997869, 0.12498568202699385, 0.12001412379885874, 0.05216346302580449, 0.19052254276410227, 0.15917649252280114, 0.11611782359860598, 0.041697127669448816, 0.04826482242694305, 0.11739434058507604, 0.08209163773684733, 0.133608645128627, 0.08293207449417922, 0.07852448721326168, 0.02711863917929511, 0.17010426178814905, 0.31995499746934064, 0.5768724194457454, 0.5816831451750571, 0.526386305930153, 0.0970074309096221, 0.09824731357155309, 0.4189417697489262, 0.5046803077622768, 0.704885405157843, 0.388477364134404, 0.3748349929528852, 0.08213194928342298, 0.23151892597877213, 0.1522646327653239, 0.3555830195546151, 0.15135447434600324, 0.08485487091445154, 0.09364242800661633, 0.3065557519514715, 0.5101358343756969, 0.533901138171073, 0.4025658436359898, 0.24552046982271059, 0.11982563552596878, 0.22554322566476562, 0.30702619122401364, 0.10215012551916224, 0.2625049608609369, 0.39398801843485526, 0.22916833840070233, 0.5936838205783599, 2.2237218243460504, 3.316621876532032, 4.675334826592477, 5.8827634299955065, 7.809323303161129, 10.272564907227794, 3.814097801523824, 1.316018563605124, 6.558437780026467, 8.356615535674557, 3.3348378539085393, 4.167238839211003, 9.810365553825132, 12.233795100642789, 12.507469654083254, 4.6235046271354925, 5.994624034050973, 4.88795425622694, 1.348213377979494, 5.474833500000739, 7.253148373096221, 6.534644192264927, 11.893784442255575, 17.04244540583703, 12.592284044911786, 9.543074657840114, 13.886717192588316, 23.134274598090883, 21.21237793276387, 22.381108922343103, 28.37080744005019, 39.96456292367751, 49.696692882045625, 46.91463024385514, 57.56461443439607, 83.13280013299759, 55.1404288507277, 24.61307287216187, 14.02940615530937, 12.600905414550537, 10.600552520444317, 6.323725110100162, 10.57689376415745, 1.1657442272670808, 0.8606608043755255, 0.3010937595559705, 0.18484952378897898, 1.2029955896639055, 2.913502243257338, 1.4300444385697766, 2.018939658038078, 0.4266754886315715, 0.9920046790953606, 1.6629650756236047, 4.990497760234341, 12.312294475493893, 6.846450557631831, 8.714018963998365, 9.047683227446772, 16.804028057282974, 31.13821218090673, 45.33867682180097, 69.78156197455623, 83.68070033288772, 68.26631115328881, 49.44737134441253, 36.307007651175226, 29.3218586521764, 24.588234463045676, 24.223077489483742, 19.739906441780832, 15.601561742444193, 21.422042346769764, 12.046911812597706, 4.233377354760324, 3.630177373847654, 2.6482409286883573, 3.4492438310577027, 4.016681601924281, 4.323723758420637, 5.468234602482089, 5.326475731788143, 4.200640272709632, 5.7727840927339376, 2.5361160549425312, 0.547024775897303, 4.100799281750956, 1.0234583493682647, 1.2756778444013288, 1.1021873667355508, 0.1821229862229478, 0.1462905412359584, 0.31922611077466323, 0.43444904408627943, 0.25219209972889195, 0.4288857748671886, 0.749682059451457, 0.7511869625699136, 1.648747832063706, 1.4664361890285247, 0.6405652759055938, 1.1729008367946072, 0.45553515454934496, 0.7665545024698781, 0.15665877520317034, 0.19605406529961095, 0.27636266403621246, 0.4828711328727584, 0.5426487590997451, 0.3794079556340172, 0.20661464862285123, 0.1499758225174681, 0.17869178566240496, 0.17641483445561704, 0.2072286068071281, 0.3068834843654787, 0.22331942563816426, 0.0447684392753628, 0.2980041576008643, 0.4049563443949146, 0.5686123981591195, 0.5909046374501721, 0.44771682891634207, 0.1351963317081813, 0.30192919375915683, 0.8383075844857001, 0.5845883957320644, 0.18071154583125346, 0.08727337218700879, 0.3091711148379311, 0.018777581112038706, 0.16102065001764607, 0.24655585297413413, 0.6635119994321178, 0.36498261195036674, 0.24855194102612235, 0.25698036376026373, 0.23758032088798864, 0.4454628143820071, 0.260192294635119, 0.28298889557200096, 0.18627147490699447, 0.21200856644540064, 0.2619105072752122, 0.4856464855613247, 0.6719339410624197, 0.8286003311795573, 0.6823097746218405, 0.7350708015503422, 0.5219450184414464, 0.7863773033022882, 0.7208589512494303, 0.7152351304408043, 0.6250758360951179, 0.678823339121957, 0.7667234708224574, 0.4048908591991471, 0.5385441212884842, 0.5849756072125127, 0.6076362428645934, 0.6620023159250137, 0.4034059050102388, 0.33417751171415855, 0.6447923652106716, 0.7408329471945764, 0.5231402381773919, 0.4117292664464443, 0.4213142827633889, 0.13113556009146476, 0.23473738392274227, 0.5644080463436343, 0.4404609956808629, 0.6103700123006298, 0.5972320334084573, 0.6305992687421461, 1.5456211206413086, 3.5182417544626423, 3.925812787586643, 3.182958777873747, 6.403602707770563, 9.941488427500571, 9.897144071517452, 5.245057623232565, 1.2389772072915108, 9.613941100335891, 22.588941589478527, 45.67143894010975, 60.880366525342396, 67.58369322746032, 54.11732565972113, 47.40986085707142, 52.11733264307822, 48.1942250651698, 29.433748183711884, 15.12803654516897, 18.040323834265433, 18.949378228956654, 29.06483554070996, 31.508374098808538, 33.224307106387236, 20.55463960093837, 10.619622103629574, 13.257873981229721, 21.07153150343126, 19.058818240319532, 18.70204729418601, 31.243922018235732, 59.88812062048144, 73.0161210029356, 59.2283465785365, 80.2735334827054, 98.3057438942694, 65.09702428694695, 38.978467295246745, 24.989190909170336, 24.638958554114065, 36.49570895779517, 32.09906931846373, 17.96895434779506, 1.9924819229110597, 0.7423631005710172, 0.3417103929865745, 1.0833732279077655, 5.395913450948654, 7.572486179490244, 3.011508055271641, 2.745025657838391, 0.8574132657339497, 1.7729082535351477, 13.78923942965846, 30.51824235147046, 30.603842196925996, 23.109932368801488, 27.596945378088183, 35.72446900029337, 49.956855850835005, 59.800004574560354, 63.88922060689619, 78.08365852602067, 80.9014186551494, 69.71186930133452, 52.899406186995975, 35.79074921146516, 26.459589427517308, 17.85988696159855, 19.64260812728636, 19.240388677966212, 12.051145030606179, 14.784387888446933, 11.081488055567588, 5.926098265955526, 5.615914781247416, 6.202571430513936, 7.497554200310861, 6.744955307052982, 10.697030078980232, 19.21575423209898, 23.721269061488492, 34.94195222854614, 36.03233583511845, 40.754936202879875, 36.42681252571845, 23.06992027067369, 10.650572546066778, 4.065130718292729, 1.5963066008783158, 0.25009908623272376, 0.33083396693391187, 0.22598185696669165, 0.31808608001278293, 0.7959266812089951, 0.5378381559445012, 0.46937073310536725, 0.8690915713387152, 1.5150147436126586, 2.48602248487934, 3.441488814930762, 4.446229184827497, 4.054291738617805, 2.9672678872462246, 2.66602078753133, 1.2334743670878874, 0.8954356803048042, 0.9338041827563317, 0.7424574826032885, 0.5986459865685433, 0.4389753979780982, 0.25468445953822905, 0.2205012945999061, 0.20732818291552607, 0.7494407723988257, 0.7142256717047384, 0.8923335757947738, 0.47044184659757926, 0.7235230373278742, 0.5899899284685812, 0.9086826888303604, 0.9802422263929922, 0.7220381137824828, 0.661057637583825, 1.2128077663721577, 1.1823831666861813, 0.7511585253861643, 0.20336237555790335, 0.19811755376717738, 0.3111583775570316, 0.3012812059492834, 0.33029791989153434, 0.3830321950297202], [0.02825500995611712, 0.12159699934624857, 0.0292540671333911, 0.05347336995445433, 0.17751348114782767, 0.09377741269887456, 0.10991378311788845, 0.04921604315900514, 0.028970181761730104, 0.11117340020474889, 0.1816773069121184, 0.190907716450672, 0.22566060565652388, 0.028402319087857203, 0.07075232603857595, 0.09457599807290301, 0.15627985279406273, 0.2190164629850657, 0.2294655345500477, 0.07892427785742669, 0.0787619361653924, 0.2195451862268871, 0.19806241075838768, 0.27329800590392084, 0.1439301630542163, 0.05692402148739465, 0.05976651412164492, 0.3587566766767733, 0.23030950297271055, 0.21646218794968822, 0.15018496452079666, 0.05789911351917733, 0.0518473981308841, 0.03389671700255525, 0.15551330521702766, 0.05601975045377209, 0.2011329064806623, 0.21174667162760613, 0.13892575497588805, 0.16953784702045305, 0.1944344941406481, 0.061414503312158975, 0.11026509571820499, 0.06964860018342733, 0.07850892796751954, 0.21994281650310565, 0.38719848759712716, 0.11793379671871664, 2.040533163855153, 0.4148004516478508, 0.23107951326716333, 0.8845319202350033, 0.19410296193053647, 1.1453426316861184, 2.1811670497540505, 3.2394259543188157, 2.6197368194980006, 4.42492090886639, 1.9845318914421144, 1.6228800459254173, 1.6253412106344778, 1.4841971714650433, 2.0177901584294538, 0.5606262073401482, 1.0414087700266992, 0.18341966664358494, 0.6559521825082841, 0.8325872365986148, 1.1537594252055692, 3.0971373185034725, 3.3465824107969966, 6.1561820487822265, 9.53372961090457, 3.867074803959939, 15.431395596073521, 40.700666289175714, 27.828122031304147, 50.5474235934596, 54.44578101558071, 45.57390528340494, 17.058915438190585, 4.117337955582527, 4.931845578455157, 2.4937198911943748, 4.348310645549528, 4.553770769026972, 0.6792134923800346, 0.27320512540398106, 0.09869636366924933, 0.2906885082202573, 0.5463662467175915, 0.3594650935021139, 0.6913714915994675, 0.34610635871368073, 0.1434676604525697, 7.952873226135009, 8.989857685181404, 3.261724383600297, 4.275884080317713, 5.952624765134627, 7.7253306488836975, 10.715621133004467, 7.877720613633433, 18.90270986864644, 38.75472745587749, 53.59766652507167, 33.59421407022784, 24.275329343734253, 9.172537172994307, 8.385644997319869, 4.192559209562117, 6.312500267259537, 4.656927633670069, 2.2342070552610584, 0.29942552649205734, 0.7175999519325073, 0.4957398778248218, 0.3455036620218908, 0.239944115821873, 0.11948553079198446, 0.4993943317282585, 0.8016996133712031, 0.1711405948885987, 0.4588716819642052, 0.28377275673612473, 0.8201236602279448, 0.41667439464119177, 0.7605315804962189, 0.6954060170438983, 0.37077025300072086, 0.15971892873846716, 0.3003569668339145, 0.16361670748841378, 0.44066918773516534, 0.17306508436318369, 0.07599072035161719, 0.0945819199325577, 0.46374565591254546, 0.7847465779031477, 0.3869215008472243, 0.19933987769388384, 0.12694545751137118, 0.14973949971458606, 0.12256225480908349, 0.06757126850706917, 0.21563944016252795, 0.29507157302671866, 0.28141400266078215, 0.3043396128041129, 0.2949895403317867, 0.16714074258362094, 0.23420982513456579, 0.16802401131679937, 0.2076878152307003, 0.08984126060480073, 0.08966121462083633, 0.15051948447381297, 0.061683404004021045, 0.13584776691371395, 0.05578971723274839, 0.05616799995843923, 0.04763175417939502, 0.09797449433995832, 0.06552286431073182, 0.11443825243341346, 0.12952118300862853, 0.07054040313608224, 0.2540358128927408, 0.3205832814978015, 0.16706025738629604, 0.2114761659815427, 0.17480367494206275, 0.08442518751948111, 0.0675993379686148, 0.1368397128798308, 0.02121678782596944, 0.08672123729822137, 0.041638537264999845, 0.019287879939281175, 0.11502404156471453, 0.016100396845309485, 0.06535875295559246, 0.07061107474709712, 0.24681149651446652, 0.10435494954787916, 0.13586532564893847, 0.12630520718953303, 0.14341788005924996, 0.14125460097866674, 0.13109204629736562, 0.1312504886018653, 0.09102009372004578, 0.23979209333417878, 0.38551386025163437, 0.1713672649836348, 0.09376574517978777, 0.2528424930548476, 0.1749148036563589, 0.27073629981567787, 0.16270014457404613, 0.2189478981158426, 0.11308031562235087, 0.2781504374598303, 0.2539902613047631, 0.16570831138280132, 0.16340932748731107, 0.15872874477457616, 0.01979064237656853, 0.05049791893050556, 0.07764359335264853, 0.14939180304927213, 0.25753939344036963, 0.2029762519223075, 0.16674095193945593, 0.29231344199469017, 0.49638973488923044, 0.4372455408015559, 0.1181724867332847, 0.11546515499151523, 0.04440165552941542, 0.2207554672514239, 0.5408617517640514, 0.9387591168765099, 2.199297470431174, 3.6445352098634167, 3.208686829574647, 3.35182563912484, 1.998433261629074, 0.379293165019443, 2.9655140974829277, 3.5032217733321653, 3.3728578782850698, 2.9779181028566057, 5.221537130494272, 1.432863519557061, 0.7178933329639897, 0.7938733204237877, 2.029228035000063, 3.441468712783629, 1.1817674771431954, 2.553356097590539, 2.0236096074504237, 1.7921532402115485, 2.1861555691688292, 4.604574778387624, 9.617422203863821, 8.905538493587125, 8.95384640462937, 11.412079141985986, 20.052468353702178, 41.9194604504493, 52.26523345516574, 41.81291318708851, 62.273035433984575, 76.89374477632585, 50.68170985867901, 28.26673519226813, 18.15567485747799, 12.18052637192511, 16.13507272735719, 15.449671879891428, 11.408384269283665, 7.370045790749212, 0.4555049400416113, 0.34409933092613376, 0.2747901306758004, 1.5820332183953256, 1.434087789347095, 0.2432363020676759, 0.24711436171445156, 0.15596143600921478, 9.381346510302636, 11.663027482648051, 12.667433715635731, 17.83190869515942, 11.578110129602495, 15.010841027382883, 19.17995672072134, 23.917226752927228, 31.840083060726045, 43.18573882502895, 59.74176914461198, 57.6175860435732, 41.98318327626875, 24.00308547481414, 14.847401745857733, 9.02545907805043, 10.58186536835086, 8.695978022390797, 4.9095248406933205, 2.9228110082687873, 1.9553924808579108, 1.371869192488732, 1.3468471674188491, 0.8489601902904049, 0.433071801859525, 0.8995482854304776, 1.2137009636048348, 1.940681999248843, 1.4508603345001898, 0.6196122195932173, 0.6947669158539465, 0.915488736523736, 1.5751145251335636, 0.916330881657139, 0.29565027584472015, 0.06808561993943107, 0.1575826312745771, 0.17270877686960084, 0.20639007760872766, 0.06739181241080647, 0.07545575349321289, 0.34242411114035115, 0.33387493762758474, 0.7614648594490944, 0.594095730733487, 0.29022300255394756, 0.3880698053586868, 0.08688200084913163, 0.11693269600190463, 0.2295526387470384, 0.05742213185576182, 0.033030191120961984, 0.3225657944717715, 0.26288690165646617, 0.10504003899592547, 0.24774794707134848, 0.3002931057445465, 0.14140653153581006, 0.13370831316757587, 0.0068815542768026075, 0.09496789035056868, 0.0664361407079043, 0.09491359769937494, 0.13523043794257028, 0.04912974718477457, 0.10931845619193009, 0.10306848107927269, 0.04915858273424449, 0.09460808949605112, 0.24172608229902484, 0.13932897769395383, 0.31004837744178315, 0.43653553051333277, 0.8224595542396269, 0.30815065507927253, 0.10200437729156787, 0.20170820786827998, 0.05802479024315554, 0.047090057238575914, 0.12529579441874258, 0.04294002105692222, 0.3432594534129866, 0.2842974656772229, 0.25867311163775386, 0.2957385598171142, 0.26009037429767273, 0.19440447881577477, 0.2333126748881994, 0.4848464752637571, 0.35379064960345147, 0.3544175240301317, 0.36146066061431364, 0.648929423862888, 0.5608533370879389, 0.4517241735612193, 0.5133618612683589, 0.6661206820318777, 0.5861254745433407, 0.7318934365626305, 0.32877346620925013, 0.12062762999126028, 0.20812289188465766, 0.31470518078534837, 0.7237710046672052, 0.8275327723353141, 0.39876935703139155, 0.2724924184862645, 0.4494184327702369, 0.9922732388780964, 0.538760525805335, 0.8160926281444488, 0.3764236754467411, 0.11847313793916857, 0.1133967252568372, 0.1917877063275345, 0.2735328271744713, 0.5003093165015021, 0.5507965025401885, 0.5681064124068906, 0.3096345673886038, 0.3816031346157674, 0.3372714037616407, 0.19186538764305655, 0.18908790523006072, 0.22120102398818542, 0.20843297363288943, 0.6705287519481875, 0.7647746657171558, 1.5148757446196772, 3.9635381439039787, 3.714070252833828, 4.670724080454919, 1.3511205897215874, 0.23617327784097966, 4.77873880055643, 6.8072297976863005, 14.248197924706245, 17.134377917935772, 15.66785175954142, 9.579164385795593, 5.539687929614898, 2.3838317490393117, 3.26072221802127, 2.5426095387628003, 1.1395636321075502, 3.259982360947517, 0.9664945640871603, 1.298625671094464, 2.6200528154450082, 3.9833963686420075, 6.417116253606736, 5.872509373772529, 8.929166851505157, 10.532232676782916, 20.851245310998735, 48.321270635051114, 75.39744684773108, 76.82663302267753, 87.57799871506231, 85.93611809515184, 68.00671300580426, 42.57493557468538, 38.60110782807873, 24.310312963301136, 20.373004444183845, 21.487912670258556, 14.282786365478271, 10.463424498035062, 0.4328378998944837, 0.2929649538090152, 1.6949778675071656, 4.474892395157968, 4.950157653900885, 0.9020188270557312, 0.31512064558844416, 0.30700541491950717, 17.329164781878074, 17.29936653567899, 19.391239112423314, 28.09041484709709, 31.33487197660631, 47.07866768683157, 46.417760079906834, 55.18979972408664, 60.1178656085845, 65.65134932917934, 76.5520514211347, 55.40155672257947, 44.35337351214501, 21.124699231117003, 11.880552326479267, 5.836708920617258, 8.732462929141137, 6.752602948296455, 2.4353278115872414, 1.870868100273994, 1.3503239808544036, 1.1946657011585853, 1.11768820593434, 0.6123665600053726, 0.5803426751686681, 1.634550813225008, 2.3603776914458123, 3.935686864199177, 1.4850155985163105, 0.8849741674719319, 2.6142369210720062, 3.4773956623769577, 3.750712544687333, 2.7202536838669933, 0.9885119310309811, 0.40427924524391856, 0.5519656752867084, 0.878791347626717, 0.8255766127859393, 0.2868969858654084, 0.16347465946549372, 0.571211887703788, 0.6583533472111148, 1.1785926862109093, 1.3138887166015565, 0.671472694844969, 0.6757074450292896, 0.46126181500092633, 0.5203698190950579, 0.6013310940996294, 1.1177941099289925, 1.2158875624018333, 1.2376372275813934, 0.6680350438241036, 0.47234631053382353, 0.7015384589472126, 0.5276827718461714, 0.20335122131772582, 0.44101285477799756, 0.20807571619028048, 0.27752757733387334, 0.24975148149796073, 0.4148796651392214, 0.4820715822279454, 0.3267073270774657, 0.2622233469399714, 0.15583199779352835, 0.19522868216999117, 0.1568075341563071, 0.26410706521522614, 0.3789252895982035, 0.7016203384245596, 1.0178783487889076, 0.8660779040186637, 0.5772165461413322, 0.33259995281696325, 0.44289856488185547, 0.16657573741770562, 0.16609679456920395, 0.2616049914110092, 0.253792871090193], [0.059759596347688675, 0.021599628774809743, 0.02817969968272073, 0.04090423815913739, 0.03427112715378885, 0.03102789967200689, 0.07389485700837067, 0.06578040008823718, 0.04759213977283047, 0.01428448022418325, 0.1626996542777746, 0.09901533969828198, 0.021161629495421247, 0.030888088625825705, 0.00536749066199146, 0.1563133921233877, 0.2025948627100837, 0.11931261708659512, 0.046216330130494414, 0.1039598397009315, 0.08895757052326396, 0.045687453671088146, 0.08811111997572646, 0.13515462588158347, 0.07536654255443043, 0.05591366259801773, 0.13207136713449033, 0.020505607338441957, 0.031445132222987955, 0.06563164113510041, 0.08199513364102572, 0.047343222484473264, 0.05337258342713599, 0.05317180327350094, 0.07027117685685236, 0.021064060537384886, 0.03441609397170044, 0.062147228107337034, 0.021595840470024177, 0.10699967658447643, 0.13397970747563148, 0.05180481896405259, 0.09074700635767753, 0.06759566074657826, 0.039196716276027506, 0.16360610483154175, 0.03117534478435353, 0.0306356645699951, 0.18074519241288786, 0.5542310892093567, 0.0704171012846693, 0.3678680974389277, 0.07292829919606447, 0.7728122763576046, 0.6431003527775888, 0.117001521341022, 0.1719137001782656, 0.08970546385934276, 0.1506451841804289, 0.12152335531408749, 0.05915416472200906, 0.03813070109895161, 0.674194023013115, 0.11673617912756822, 0.10424035811616529, 0.6380378599128416, 0.36265125317919644, 0.28139163289339314, 0.10503944910822377, 0.14595877919946948, 0.8894421148204035, 2.0963225057048183, 0.38288191922249337, 1.8335744498237487, 4.394087647238086, 17.303416382881906, 38.64128858812394, 54.056383794353856, 67.17069902727681, 38.58447305617794, 17.798139049160866, 7.847484532863864, 4.419779171866756, 6.037806387870543, 5.861947901787297, 3.5646706050442116, 2.907880996504138, 1.2498833575556356, 0.07400327377141484, 0.24447051567896722, 0.7674091501582054, 0.3132311050449649, 0.057187846846758365, 0.2630132448769385, 8.331639843602336, 8.740826402941059, 2.790970340851815, 3.570918450432439, 12.852100864533456, 7.737020782886013, 12.687738845425269, 16.60510309280888, 6.724772261035058, 23.871537023975005, 49.722451086967226, 46.19906833094936, 35.328368448442035, 17.12972794809649, 6.961497597156033, 3.318058199459507, 0.8780429716552458, 1.3491453086176228, 1.6536408662796023, 0.742633682825873, 0.21514543602543496, 0.04847334389905295, 0.053023369907731974, 0.22044173892467256, 0.07182455035827814, 0.15702611436286282, 0.03895406558689091, 0.16710967005741212, 0.11089387004293742, 0.07186086292588903, 0.03824634590156136, 0.07660587363305592, 0.1136315924926631, 0.14539666984590793, 0.04506131085837561, 0.03881701628767675, 0.08812384469614876, 0.08106999820278538, 0.09002456246244331, 0.06252356113926058, 0.06143709907548563, 0.04995944721984768, 0.04025719646785048, 0.0315210611123832, 0.07517182598671607, 0.02831280554434465, 0.1541899649366256, 0.029875096309209065, 0.0770469487554604, 0.03998191809401878, 0.02339199489553369, 0.06633937614218843, 0.027592296021119244, 0.055596483045167504, 0.03190227603960422, 0.08006680606594009, 0.06381988532901292, 0.05905446986998281, 0.04864834902447559, 0.019961119922358665, 0.07698292678762829, 0.0821099778817546, 0.007488444821173026, 0.061201377651624145, 0.07553393276588571, 0.07769581756644672, 0.0913395447235915, 0.055870413104252475, 0.08518993478989409, 0.09108973111236289, 0.05352151858049536, 0.05403849769443755, 0.13461482500837696, 0.05550950525268432, 0.1709700330731369, 0.1124491204597777, 0.07765659386472357, 0.11683964696262153, 0.06238539718211659, 0.08427319567530386, 0.10872198013408531, 0.05001099344583289, 0.036128177908399416, 0.05017140459629798, 0.03232685728899894, 0.031757496913234075, 0.06702013719346255, 0.1354708056896925, 0.12539215295785858, 0.01843332226628498, 0.05357813247809968, 0.11118044055277303, 0.18297922737415762, 0.22577009494266204, 0.053586180231744246, 0.07341218331167776, 0.09665375875849878, 0.04506981826477474, 0.14524522958503616, 0.1846675625852039, 0.15714403061616808, 0.12047424386706083, 0.10677672201587309, 0.09823605973994541, 0.12839039126711507, 0.15918810641573322, 0.12412734179487153, 0.04218442470676476, 0.06677112797455442, 0.08736202388160652, 0.046426908548681006, 0.00375548557889077, 0.030794516731534275, 0.04239851563808419, 0.04158786054880869, 0.0870681831973695, 0.02864163729452318, 0.05345248639763844, 0.08561652318965043, 0.06058857626011295, 0.13985635262102852, 0.3520974114296898, 0.10173690535368458, 0.059673376982250524, 0.26182357161756487, 0.0908198766410351, 0.31842190231527057, 0.19436750741254902, 0.017147049150099198, 0.059370262803690094, 0.06106041747355654, 0.5487039180532579, 0.9882414713501931, 0.1773561573316974, 1.1228775016723143, 1.8693225638520334, 0.5346318021897347, 0.2588724783591686, 0.3049989080717487, 0.10492872642052752, 0.202303335611378, 0.1769654218467974, 0.09050183523927005, 0.09972779380698359, 0.5827904793043291, 0.16283676869446234, 0.4825549224211324, 1.5267680032599358, 1.2212456426312848, 0.9783840648108914, 1.134066675459185, 0.674120539859418, 1.7818253943997047, 2.971241003082645, 6.293948436937025, 12.850481906244832, 23.528088408131755, 43.781723360861506, 39.8618438936049, 56.55478062168245, 64.46093351610246, 49.98914087972334, 25.75454535022859, 17.652291597858554, 6.117691339985018, 6.401971492075152, 6.335600085796849, 4.4917188729009325, 3.8526882856122913, 1.814878840119608, 0.10323133605021624, 0.34125837046773205, 0.3141688273078011, 0.8129528321085439, 0.07689593750382624, 0.5027186323798473, 10.014013051986694, 14.189313342494351, 7.896458266242859, 6.508781063941218, 16.610464972834436, 21.326260028346894, 21.931509202526463, 18.420936907491377, 23.986768414897305, 37.02212633625154, 49.665349221998646, 57.904993795579486, 41.49452655546127, 23.261029912579446, 11.695238967095653, 6.523130564920365, 2.1989172456725954, 2.1076064292461645, 2.7230417536151026, 1.3580423473350465, 0.25470226342158936, 0.07387568948850518, 0.10166308512130093, 0.5513470439660935, 0.4083823815228478, 0.08220285072081512, 0.1527573805182211, 0.13173050397346098, 0.18721544844729288, 0.20037009741269773, 0.0631487348507489, 0.007310478765923049, 0.19411642975624532, 0.13868917170311176, 0.029816528887397824, 0.02980731476488854, 0.12165156012821583, 0.06344186690365596, 0.05405884115926681, 0.0820889640899916, 0.08174243953920181, 0.10883153836813667, 0.0318960439143402, 0.04458405340330736, 0.017028560246070547, 0.09815306177422886, 0.011581754586058519, 0.07120075560505353, 0.06240598579508163, 0.05354941567225803, 0.05468096967125612, 0.09571768358469972, 0.06948821967647922, 0.1293576845238286, 0.020242203327436602, 0.013034702579100287, 0.04502695947585087, 0.07581404515451963, 0.10557693639589895, 0.11293657454511813, 0.06690662594572191, 0.045800263948378064, 0.03221958965784119, 0.07352246166837793, 0.09974536020308734, 0.04517552307656696, 0.03995795103330766, 0.13918863038622564, 0.031000816548663764, 0.021470142678628047, 0.031355907877666817, 0.12165735941380264, 0.019928589913873904, 0.13426027951701996, 0.16203404644564276, 0.08748244524242417, 0.12158988238943201, 0.1274591807516352, 0.09889447400646825, 0.09143868416187265, 0.17045578889308438, 0.04592622412488826, 0.14828498985978866, 0.0967664426312812, 0.17830828204751017, 0.15385611914098263, 0.169585267862966, 0.16542982310056686, 0.350544826998826, 0.1504404548435442, 0.1461932021042993, 0.24620956591060086, 0.6141310749996094, 0.5287629558194069, 0.5186781130971447, 0.3255562952929928, 0.16591759128195627, 0.28509790498402815, 0.35132755435282187, 0.26496860769487196, 0.2011808176194468, 0.31320775468503276, 0.16332963902142741, 0.1607014211795984, 0.27014166236885134, 0.4594752366744703, 0.37032301087052594, 0.2206783681627243, 0.17975943643719922, 0.13267032531720976, 0.25856852531433105, 0.3137466515744886, 0.25451498556761976, 0.14735592439049675, 0.15296597093824418, 0.1826517554300447, 0.13681804791333216, 0.27388869033705804, 0.24540604693034004, 0.21991906777745296, 0.2292551514842818, 0.3559893525896534, 0.2275520460980554, 0.16370831628239926, 0.3935231256388849, 0.1159882321653347, 0.4290723938855433, 0.3488569514405343, 0.176796039806739, 0.20649710009174965, 0.19326279330397808, 1.1950401649359734, 1.1112281848346035, 0.9167250798594568, 1.0689305706370262, 1.356474502432731, 1.950899283251455, 2.657448937816005, 0.34349565364180074, 0.24212547457746922, 0.2818902948450658, 0.29492644533034296, 0.13012847622796414, 0.323271208232449, 1.5050343952832685, 0.4443714148815601, 0.39177567908360117, 1.514204038727668, 1.0884580905399015, 0.5450608941816515, 0.4170110136751206, 0.24801802370817433, 1.0560046448822946, 1.270715188114874, 3.6949906185750043, 10.506122439138352, 19.661919916829756, 44.93446873080346, 64.8347903067066, 72.96352986366519, 79.90783522205969, 63.95224132845479, 48.012466353754846, 41.79960458509384, 37.463593021515884, 38.92895129419143, 21.014717932670347, 9.366030635372285, 8.30748490748867, 11.937039359923332, 0.24780381020278702, 0.4488651027842876, 1.8277103838420685, 1.564904840723161, 0.23387361978811605, 0.42788894126011484, 14.47985310708323, 24.999045864228282, 19.859264166124408, 22.674943477876727, 29.746176735047374, 47.493007259984175, 43.88203013327814, 45.96065490476547, 50.08970260620118, 63.12775519586379, 75.87614074830087, 64.64476716133856, 46.20771715717931, 26.34289303133565, 12.74016034218573, 6.08605154099003, 1.3662752797526698, 1.6797077127041358, 1.4154874196937008, 0.8594133067996272, 0.18497566782659103, 0.12656001569402794, 0.11374234582387632, 0.46246687130581954, 0.4906895504363122, 0.33999190455482853, 0.24022174608563227, 0.4942745661302921, 0.49240515837746285, 0.25575785597245543, 0.18448362487458414, 0.3355620164544352, 0.37047451241843166, 0.2598770341325191, 0.1681600378886346, 0.2137832704090303, 0.3024958536749886, 0.10860997041867626, 0.20837400018447833, 0.27799820046751733, 0.2816625215834187, 0.14278236416078385, 0.13184039162531977, 0.13325511087333003, 0.13879780297077474, 0.15481775866881495, 0.1973756588995457, 0.13616658206428253, 0.18631527981450483, 0.20368120603023038, 0.1505543874396432, 0.2587452464767041, 0.29276662896717753, 0.40191503662255507, 0.21221608434232975, 0.14387733363095792, 0.13911099503597907, 0.12690444116390523, 0.21751500726226838, 0.2011109963660279, 0.1451152857513197, 0.19262061244057072, 0.10997497822127997, 0.18354783315331707, 0.25608437796754224, 0.16976643233529984, 0.17329296487714016, 0.3246855904017726, 0.07509393016657523, 0.17723894587928252, 0.11761676655301165, 0.19461051050213077, 0.16319437853751645, 0.28589460578176284, 0.3784900597266613, 0.28605995819933955, 0.2736585575246042, 0.3859560155580121, 0.2211309729083892, 0.22057217305466054, 0.2842215923292022, 0.21255336221187346], [0.09401479270309211, 0.05507117272504876, 0.10214965820552842, 0.062387898459189364, 0.06392652859851237, 0.04611805254112809, 0.0311549362020507, 0.054120262258596, 0.04648011718546191, 0.08927355114851268, 0.04332845827804939, 0.21832390417975767, 0.13575928375845955, 0.16836246896174648, 0.046869952517050895, 0.02182692514672395, 0.11116367854898977, 0.09234949375592894, 0.12136472148760674, 0.007470218631844487, 0.017940241265140714, 0.11065251404239286, 0.04096457907449334, 0.02682402091581495, 0.0697335516733508, 0.04555075294187954, 0.12067544919949387, 0.0199575288852136, 0.0759912949175604, 0.06860023184168725, 0.049288829172691034, 0.07612168308227293, 0.04354821059912924, 0.021860161871318857, 0.04250363439261433, 0.05589884645756214, 0.006170478647559762, 0.0526161750237788, 0.0369856333089692, 0.04707549390713534, 0.039817385390521064, 0.029364983258288235, 0.07315052598113976, 0.02129987580701709, 0.060625314006521824, 0.06112266211740433, 0.05711832819806953, 0.08373228397460715, 0.027399356777389205, 0.054624535804314, 0.03934557482059445, 0.026596429600049893, 0.09274739216292098, 0.13484434495049138, 0.040139969693677086, 0.15128977055991852, 0.04933585164948337, 0.05971338592409607, 0.1815447583794594, 0.012722063054811331, 0.06407621451803754, 0.14701757399785906, 0.10918736322632722, 0.10582697217262561, 0.018364380098759167, 0.0956565421074629, 0.07202818418943113, 0.03864073945629982, 0.06256747329908033, 0.1083213467932036, 0.16964724437604028, 0.08481160226848819, 0.9854830032394779, 1.133735725475896, 3.406443172885526, 3.342972359349651, 20.26198175645644, 50.726977932837706, 51.13717940545852, 36.66031906681676, 10.62519088868172, 5.030930532563118, 2.86724720270403, 1.7509005699426898, 9.143084095370385, 7.378327385071786, 5.805761910253956, 6.631169799835452, 1.9938864991549525, 1.3093507794603225, 0.10246289623600822, 0.38434312468574894, 0.062375679356797095, 4.8252507563560245, 11.831419737108293, 13.196621268026291, 20.252728885219945, 26.448908813538093, 15.60959573714964, 9.988984407917147, 11.478569199962001, 9.975589513778687, 2.7249553799629216, 34.01149149863951, 43.21489380251977, 50.567984657902876, 25.361839609761393, 12.381641980140442, 3.696268575806772, 1.92053658346976, 1.5832083359841378, 0.9442905781249847, 0.19137294632532906, 0.3312572458338353, 0.07399611084932282, 0.06376270069590499, 0.18380315493672125, 0.038731532366645914, 0.05975653199599155, 0.053923109531282425, 0.04786221257921669, 0.10182837625184368, 0.013498684688050662, 0.027889587931455146, 0.06838794887786911, 0.050698158992153984, 0.04941044946111018, 0.11671907238421902, 0.012545356256586891, 0.03026296279483265, 0.06406384219806041, 0.09142773676543467, 0.015347326670082347, 0.008038710934230158, 0.02307096766608377, 0.05989966020288487, 0.08628272857036322, 0.02014897808793091, 0.08218483999371529, 0.08049134135005936, 0.020532058439247554, 0.03449150766696661, 0.07768681603333644, 0.06383471296078737, 0.06201133560088854, 0.02383521889456578, 0.0006822697058293758, 0.08317694683829624, 0.028123014921983405, 0.029356843574092756, 0.05358649049735358, 0.01520340268935768, 0.010971713026294546, 0.15445680868241096, 0.048678176657807444, 0.042635083589101994, 0.03244187006907117, 0.038014543017432574, 0.02215646935867206, 0.01893202826801327, 0.1239195864106859, 0.036391581919404774, 0.0508744319930913, 0.07779208417501181, 0.04290152896916674, 0.06836695040786459, 0.11847136827606349, 0.17155100351139424, 0.03478359017941741, 0.125919267415039, 0.05340171009001713, 0.046092683539515546, 0.09380357460148873, 0.14690387122813733, 0.03930858426517056, 0.023524533852093646, 0.08470349960149297, 0.07072345984558906, 0.17176795961155047, 0.10352338408871044, 0.04953093976984101, 0.1337852743604491, 0.1082632543459054, 0.06225898501373107, 0.1304121432645667, 0.27032350099855856, 0.06696451921015978, 0.06985928202348371, 0.07358013276731776, 0.04570376368299608, 0.06714285681805304, 0.05228432871761823, 0.22968002384708774, 0.12738348360383703, 0.12241188707130572, 0.08927228710343761, 0.05926329011638319, 0.020906112359596357, 0.04150324613757191, 0.06299817559099005, 0.05807689188288585, 0.05023525036390751, 0.07974312625705235, 0.012567773904471148, 0.04160871729254723, 0.03522905881606764, 0.014030940552812912, 0.04113618276953217, 0.03942364301051825, 0.0473338149247631, 0.006751409823810983, 0.04041409893562237, 0.019935835190417788, 0.0464319187637058, 0.04326984872140231, 0.06627800483857432, 0.023320342691975738, 0.02610804854832109, 0.11441993527114393, 0.04115045115712189, 0.02996300681374006, 0.03627093073220984, 0.04649526274372493, 0.07436526563739584, 0.04896927091683592, 0.06754200394836164, 0.11020937048259283, 0.03956102172753984, 0.09899112365899548, 0.09645285220035622, 0.09905039588169706, 0.09227234104107465, 0.1303310451969024, 0.06664421018813887, 0.0982039146906426, 0.05571996875768227, 0.09951366457126795, 0.31113352566476793, 0.0725468410359275, 0.08624020302968641, 0.04867787022263773, 0.26313443998655967, 0.2563532441854477, 0.16077790739795855, 0.2740056872848542, 0.3363236304252379, 0.1256266984367563, 0.8700852180200239, 3.597007605337328, 6.067780160134839, 10.673905745629343, 21.327503419691517, 36.16312726851433, 57.54634011176325, 67.10459924513295, 52.262711371144945, 28.377032241513653, 9.65493869396948, 4.342722248646521, 7.974319765644689, 11.469275143838699, 4.381004091232054, 4.889786983689954, 5.354440760227942, 6.192347282363523, 0.6860387842020681, 0.01322992093440506, 0.3632761357772735, 0.6216654578043569, 11.287451713315903, 22.558129410589896, 17.168624131910263, 24.61418486410572, 19.889209501204952, 19.057484634460945, 21.143579559941447, 19.83840500154803, 14.472969347430816, 18.822524855213782, 45.09356790973295, 52.8024334292258, 50.51371474419871, 35.16273460080547, 21.689189095650953, 8.476043862681236, 3.4708097577095036, 1.7882932602397859, 1.3785031461907973, 0.7042306757742359, 0.3759536038964026, 0.22828991134320537, 0.20503617042014677, 0.16324909253706857, 0.14009734856024866, 0.0499625843498976, 0.05626886692498961, 0.09118873265481765, 0.0378484245119316, 0.038361757047354214, 0.05468648167387132, 0.049892889500986186, 0.021704881594726638, 0.16225904646900394, 0.08650926076957295, 0.02256391322120063, 0.05766559076765853, 0.026236906452404878, 0.053732706038581754, 0.048743703988410776, 0.05115958524026698, 0.03807990563913219, 0.03556284715511626, 0.15204085848264157, 0.04239210731259758, 0.06304345521775466, 0.03423835774282775, 0.0873158977276856, 0.03529022327594219, 0.08083336130385438, 0.044696174201465426, 0.035494508281830824, 0.1152738092106677, 0.1026191551899237, 0.08831353572707984, 0.018694247982855287, 0.035994223604399356, 0.007127543194069257, 0.034376468073817036, 0.08392421964315638, 0.11261792027301366, 0.050934535421190724, 0.055529523130145766, 0.03996966068723029, 0.04869024637305448, 0.0632195711706675, 0.008991370953979992, 0.08460409969331757, 0.03876901704878096, 0.06101799152430989, 0.04609137735960465, 0.0797598346346809, 0.048836105683397864, 0.13958053032477058, 0.037444665532318816, 0.09191493038088085, 0.08935553021728994, 0.1750784400369852, 0.24308559725121145, 0.03637194325546584, 0.04885207478617949, 0.026352758098754193, 0.0039717316113021825, 0.402354801734609, 0.1653537965349613, 0.3224748751569179, 0.17734281208005645, 0.16370745826392405, 0.21074761636555198, 0.21079109951613412, 0.353298177642207, 0.31826476236024215, 0.6223534660473947, 0.3450974822044373, 0.43262584675704285, 0.40284218687203627, 0.3940002145546098, 0.18752390608912517, 0.1679253851574275, 0.46292986420373766, 0.21833683574391952, 0.34698426483138917, 0.15469959726737392, 0.14352036730176018, 0.3117938934554977, 0.2792589360427472, 0.1027063666392238, 0.24359077095024048, 0.15693050658991262, 0.1843886146502149, 0.10720186250945253, 0.1985799337947561, 0.1657764625645453, 0.10041163453171331, 0.16453457275225272, 0.10043355230722698, 0.1463057710638931, 0.19834935665130618, 0.16329507313428387, 0.20750810632542258, 0.18756605624671907, 0.16383409259780762, 0.21541850040516547, 0.11670870721460351, 0.1088789362280119, 0.2367550909759537, 0.1111060917197216, 0.20910258044398602, 0.11450307113268685, 0.13304547857372992, 0.17155970627021405, 0.11852125592169263, 0.18613400808986158, 0.21156222829895638, 0.12309510726481677, 0.14744757914975767, 0.17042388899191735, 0.2569541022662194, 0.3215675512629171, 0.308640951350812, 0.23416894668292618, 0.2621452059716948, 0.14176207294146861, 0.24264118964633635, 0.510427407439678, 0.2161202522655649, 0.24277312530865594, 0.08660142880774314, 0.21850408805954843, 0.21756552309999544, 0.2555550112118644, 0.20710327482271582, 0.1753886903245603, 0.107851650625948, 0.34931072063984414, 2.1444480265340498, 5.596474043784603, 8.706143825284897, 19.24641736092106, 38.3211878807314, 66.65146350860596, 68.8872851094892, 63.19582400783416, 43.69715705994637, 26.173252482568067, 26.261913737943097, 39.820670773906095, 39.79374370267315, 28.359999349040372, 16.20888388925983, 26.2009895232416, 22.342148019421487, 2.338651437913218, 0.1882707498847477, 0.6442761445237745, 0.49258957106259565, 16.70157967075225, 39.42156568650277, 39.54749730325515, 57.43728253149218, 52.07026420101043, 36.51788603874945, 41.971635818481445, 44.1883280200343, 39.30538900436894, 43.903152096656065, 67.81476005431145, 63.20790883033507, 61.65991798523934, 37.99361113579043, 19.248866881093672, 6.630394151133876, 2.4807486130345255, 1.9055447943748969, 1.2903779072146262, 0.6027703588047336, 0.40498695726836886, 0.16918690214234014, 0.2170104311118203, 0.32362195392770154, 0.12333028859669164, 0.08130780721624052, 0.150780827708302, 0.19832373867111824, 0.1732897166643412, 0.14164372767892577, 0.1272510729670044, 0.12382756392922133, 0.2818770262022173, 0.19449818669067276, 0.2153902624042765, 0.08718016993014083, 0.13403757775743164, 0.11687667965288125, 0.22647553934685646, 0.12644547788846877, 0.21925531387809785, 0.18268661243059944, 0.19127189932811647, 0.23208097404529973, 0.11236244527202462, 0.1515964202342495, 0.1413395907729864, 0.14736798261442494, 0.10012859568720865, 0.2678333168789264, 0.12387198170707112, 0.11438040513425105, 0.14178097999143985, 0.1883989317162383, 0.15458967897199816, 0.17554388441626104, 0.10527028672156796, 0.17519249520715208, 0.15778561393099447, 0.13550684246565067, 0.22826034034932816, 0.24665552101308302, 0.18282884431462135, 0.16759213691036548, 0.17414079438294136, 0.11873555369675161, 0.1167233088504403, 0.1742275155359699, 0.12284291112014364, 0.24492117456130444, 0.17812855782047396, 0.12067029342776346, 0.16807870999459298, 0.3022063337266445, 0.4345222514483237, 0.45538858660767156, 0.28604267525576776, 0.4058654762564167, 0.3703897524504893, 0.2548400826391674, 0.27707610639833635, 0.12411811809626319, 0.2546990611740659], [0.08441004962209733, 0.15077773271308792, 0.11912264260313205, 0.13957927394057476, 0.10612847373610544, 0.1617977236427607, 0.22556078439999014, 0.18061221487099127, 0.28766825254405703, 0.01617279598459361, 0.09085926122122234, 0.13338753683192114, 0.045906401599847504, 0.1610449809701212, 0.18501935016003349, 0.18688135750351414, 0.1759029345046128, 0.18338441127730956, 0.07105847775575615, 0.14078858969432695, 0.06750823479265937, 0.08463958488597025, 0.04371257476328362, 0.02697693398072114, 0.022218194977951147, 0.060367801211654186, 0.025375798727656086, 0.01721780503078574, 0.03277876106421313, 0.07009543628702242, 0.011428429748893026, 0.03485999978898514, 0.05742758640178269, 0.03847405404573487, 0.020316743682469093, 0.022339621829169414, 0.031089728713155757, 0.022381666649673736, 0.01632064520832031, 0.08147968670293208, 0.043464496341203494, 0.03570211427887121, 0.038930374317832535, 0.029232095731722734, 0.009049806225624298, 0.0457445195605678, 0.025380513998830033, 0.051514961937021826, 0.043801904445694345, 0.054495128232144543, 0.07069034952550166, 0.10497932652792624, 0.04848029231652618, 0.12914754660619845, 0.05900393871049728, 0.08210175009744783, 0.028725744172510122, 0.10449749552795004, 0.05510729760111821, 0.015328361205906879, 0.037188424443405484, 0.08052310335540003, 0.061588953023836504, 0.10885070588800216, 0.05092552239676157, 0.03935647625175696, 0.13769025433688395, 0.07878519459477357, 0.045898009106637015, 0.21694482334198492, 0.026992158062996405, 0.20739972020589537, 0.6164339352999965, 1.8358338576170707, 2.3381400589020025, 6.411217989460115, 19.245736829696163, 40.26522044212588, 48.23479806223224, 37.80012453756025, 14.600463048104318, 1.9567344217531144, 1.1103683277483911, 2.2158692392610737, 2.519029720175651, 1.3694770369798908, 5.094583736312005, 5.5182541378082774, 7.4943648230644975, 13.153566391237321, 10.833209868400328, 9.478700718572064, 16.633032329620853, 23.17200387677839, 27.215769444742513, 28.97493873873065, 27.300143549519202, 23.46932149702503, 18.001723789399673, 13.909372802703613, 10.083883212458703, 2.8845576028670035, 12.98004367659169, 31.12610774655496, 55.135933814510224, 33.26277771303731, 18.928799513847597, 6.8636280875052185, 2.332990477162023, 1.5840132798879378, 0.2675580768094909, 0.13464510080314454, 0.05743090739293445, 0.03373506862009245, 0.014356604529424541, 0.08695942935563865, 0.05798193911511091, 0.05896613610187366, 0.06121173899080004, 0.02448985443240212, 0.06271293041326347, 0.09429943267135851, 0.03453886722244563, 0.11089074440420636, 0.030143621617988236, 0.11135678633206314, 0.1323578074093788, 0.04236263974059013, 0.0457008333966857, 0.0501686888146064, 0.01793680727602013, 0.06445525950121303, 0.05757356828619396, 0.03146474981950897, 0.057857897988851034, 0.010737552506578787, 0.02099164033068284, 0.04702098675132279, 0.010186375227696713, 0.09543218559795812, 0.05741234508252913, 0.05169837487741344, 0.04094405174856225, 0.023293667510452292, 0.019401864246315053, 0.04517439692731827, 0.002895995975479544, 0.05735863848859745, 0.07515032955956075, 0.02897391260992135, 0.025240676139571497, 0.00941739532150208, 0.013469177854037093, 0.0103962718276307, 0.1079056828072475, 0.07102634036733259, 0.02059419008512651, 0.04779053739302101, 0.07166678221115182, 0.05960419541224838, 0.0651757805157573, 0.11162197532793207, 0.031088353585331675, 0.09096924080363206, 0.07002061247945794, 0.05782196080432304, 0.017510544463631608, 0.061362478281221086, 0.15156084311104592, 0.18801023402521688, 0.1943939987329706, 0.1457909753005351, 0.09670455038787858, 0.12470733164058578, 0.16240130899654281, 0.042320784526847066, 0.08786105355548282, 0.09897397861125008, 0.03169448043580257, 0.15582150238896572, 0.23334075967150353, 0.3736112441026396, 0.39055094964081244, 0.17740910932902368, 0.24286896290798343, 0.05930418388978128, 0.12735496215041608, 0.1809528635274018, 0.0901285972025606, 0.14585224701271904, 0.12395153993800764, 0.14087385528029936, 0.27822683174763957, 0.13002965088573196, 0.1152249864272533, 0.12355878198098753, 0.06981962165164371, 0.02546712598432937, 0.07504401953830835, 0.05833767587319017, 0.04918322012188935, 0.03756033331756631, 0.08801191158953213, 0.025196101313697237, 0.10047179541640705, 0.07045777289256935, 0.02083958719947165, 0.04918621552567329, 0.06949811753246092, 0.011120750643913786, 0.02286105957483092, 0.07799620830243634, 0.03534478022746983, 0.04155655053534335, 0.06778182777305765, 0.057214223253991336, 0.03005496609295088, 0.09370836519425915, 0.0494346501786382, 0.026646399600130898, 0.08776451881614425, 0.009031305202252923, 0.015407523943952497, 0.060808458816139936, 0.03078344484580861, 0.03848675961395906, 0.1489597601034949, 0.01933346025555605, 0.0930474994463786, 0.0718003649625086, 0.03784736731059609, 0.06542388575091478, 0.07052557933474742, 0.013556109681244821, 0.17059632006191439, 0.03210031551369016, 0.010620914662497179, 0.05927359399896476, 0.08923789741651666, 0.053006450855924245, 0.035554121413658706, 0.05261414489077945, 0.062773052993561, 0.015336241377818008, 0.061162196084736824, 0.017357221541685924, 0.1926976195987194, 0.4106232499884021, 2.056332470909242, 2.6338666677474976, 3.2463428089695596, 9.82122169386956, 30.09696410548303, 52.434864198007894, 65.55799299670805, 55.7850193977356, 26.590359287877238, 8.146535840726669, 3.4979743774860137, 6.004817783832551, 9.72709265447432, 9.369103812402296, 11.249798920846755, 8.816892927692784, 20.00373878786641, 26.2127919350901, 20.235964675103467, 20.31460427468823, 32.01153574451324, 36.127676886896936, 37.31612759251749, 43.44189313150222, 44.54893112182618, 36.535603384817804, 21.933462542872277, 18.15630635907573, 11.627423148001395, 9.1635412170041, 24.616406886808335, 44.19761227023217, 54.42621623316119, 48.18803164266771, 27.347031562559067, 11.452164784554514, 4.972053304795296, 2.116980648809864, 1.1409691889439861, 0.2163298692434065, 0.04806104686952407, 0.08421629832516755, 0.0505776227181477, 0.08056713042840843, 0.026486769859348575, 0.024630372194693457, 0.11175562702720204, 0.0901552647232048, 0.09652088080803234, 0.015435846214513145, 0.018476305544496547, 0.039877155570373427, 0.014624780310588259, 0.06910106948306484, 0.07194828887980792, 0.0581223055750372, 0.057687592812843864, 0.07414641730006664, 0.03998658739991727, 0.07654113154257498, 0.04766681036281009, 0.05027810149195214, 0.06386989171827032, 0.03966108813220936, 0.03060204863187767, 0.024157544643047358, 0.01671939780334792, 0.04185540909548441, 0.050210026919000575, 0.06830768584604226, 0.026377226947055712, 0.04193233964484065, 0.01702647074125707, 0.028953980917351383, 0.006876141865617566, 0.05046999119522591, 0.05888453624661892, 0.05811071466474284, 0.05267034893134429, 0.06087715008987054, 0.0430781313879115, 0.1083969290278131, 0.019290476977344484, 0.04465736035678176, 0.017969004036257827, 0.06466068597810884, 0.09361188408107528, 0.06718375059145112, 0.0302912314392386, 0.021270145849895575, 0.1478782124937542, 0.08242757495252356, 0.1257255850660224, 0.07259714236903576, 0.03842731885191414, 0.13520095887924397, 0.2041395411135689, 0.10923771818559017, 0.11058077756916324, 0.11789376862467298, 0.07262577107476612, 0.09754903208945068, 0.09943304147811667, 0.028513187332259073, 0.28499016237835734, 0.25479626240989856, 0.1616345315931305, 0.3151600837947861, 0.20467551154715402, 0.5866428596838829, 0.4871543304574105, 0.2663416211162844, 0.47410926270869475, 0.39560716058458056, 0.7542511304059337, 0.6236400647509484, 0.2091471207959037, 0.39703465817916783, 0.29437385078880096, 0.21647536466198586, 0.4129887762809954, 0.39787986766426797, 0.33930548977467323, 0.24853706359863284, 0.17737599900893627, 0.20999790740109261, 0.23421770051842739, 0.14842359048704948, 0.12584417547670104, 0.14159947844041934, 0.14727982121609873, 0.13472809876886108, 0.15515923470018372, 0.21747861808586508, 0.07559459926860948, 0.29069794642348445, 0.1489723392672116, 0.13399953383111185, 0.11896338058455337, 0.171260594901058, 0.07857853471631966, 0.22349979337905684, 0.08567262380834549, 0.16714561490281937, 0.18631907961060926, 0.1950212408818545, 0.14325911599782207, 0.09488830913699443, 0.15275604752523286, 0.22489310813046273, 0.13494980461414785, 0.22887989097545225, 0.15458799357856476, 0.39881780443172304, 0.24418675671181372, 0.11734703465575173, 0.1295048040488074, 0.1641613960025772, 0.15557096099420903, 0.1721341802828735, 0.17732978858534368, 0.23332324690155445, 0.29137587294943873, 0.07183632512967433, 0.10886131620575344, 0.2177870297624219, 0.17119273483272524, 0.25781555281531426, 0.12783178293536748, 0.1373948508332814, 0.34256997428113417, 0.1745946401910436, 0.1921646215862805, 0.18257615787367668, 0.22076456837596434, 0.29638829430745495, 1.4868553127011945, 5.248430371284485, 5.753043784249214, 11.5882396505725, 34.13797616958618, 54.169128402586914, 68.34863385846539, 67.71797949267973, 48.36618961826448, 32.85976790612744, 23.542326611857263, 27.707960221075243, 34.205178137748476, 38.20729009566769, 43.0313661021571, 37.42597749156337, 47.61246304358206, 47.786600589752204, 30.8804653921435, 26.592414609847534, 40.22479257275982, 53.449208736419685, 56.38725619162283, 62.82090425491334, 58.908649875271706, 51.977041229125, 39.24299586203791, 40.61489189824751, 37.788847723314845, 35.89969696537141, 50.338255359280495, 59.80599795618365, 73.45545784119638, 49.75512835287279, 25.94937732142787, 9.919898721479601, 3.8529807473382647, 1.6988789097916697, 0.8764340644401889, 0.37392555465621335, 0.09734091664394064, 0.1711441188930504, 0.2703907635183104, 0.18095753666373993, 0.12998855792947356, 0.1895069859681591, 0.17724447703409582, 0.11797187128855337, 0.19191224158050554, 0.14731411131158953, 0.06881466751257259, 0.1961395147466852, 0.16880246390017772, 0.09102923314898245, 0.19897597060809213, 0.1861827466036043, 0.1380179254638572, 0.16076895949100295, 0.09522370243024442, 0.17035020665536005, 0.10362378757206664, 0.16076384202366875, 0.11575505798382145, 0.11058920453633032, 0.07270457087865762, 0.13315749595001822, 0.0966895580472004, 0.1274646736020523, 0.21204126307800894, 0.11300651837260493, 0.19725987237066994, 0.13391544802054284, 0.10134852175871212, 0.10693466636322199, 0.1136622130269966, 0.15782960269960666, 0.19193534679230184, 0.1685975353804327, 0.25111741626695283, 0.1165683905503923, 0.13749805819844046, 0.13142337932461692, 0.1744577096354577, 0.1311554170904621, 0.12224858776936609, 0.2717026124798483, 0.18501291502146952, 0.16973873059595787, 0.2191449665734845, 0.26132187595771206, 0.20287921922581814, 0.20827794808053202, 0.1683714934774945, 0.16460926632487005, 0.10060908603331736, 0.47584549373676704, 0.5349368890447002, 0.6212514026030418, 0.5426496784052541, 0.48129513679492864, 0.35093908648817773, 0.2144031581138411, 0.28812781336807436, 0.2030435604073348], [0.05491899701976969, 0.22243436425924304, 0.1274839483742272, 0.15051525566847096, 0.0791164433523532, 0.20423357074539508, 0.2867971186435992, 0.266930834660607, 0.09598789811735192, 0.12307274515830702, 0.16467781587233468, 0.14274075026473693, 0.18843763447817297, 0.06847413376935067, 0.24916689512470078, 0.13326339994467076, 0.15138979099931257, 0.06137752807849358, 0.08355625229136598, 0.053970641456544406, 0.045210594581740524, 0.09060694250248133, 0.10246931605281369, 0.03604049531502589, 0.1264135320220263, 0.026070776455585035, 0.03710854828598038, 0.08732098455150282, 0.037182146352866007, 0.07634040884553425, 0.03596760204903061, 0.06647419995598255, 0.05071464903472413, 0.05507319136672924, 0.06884526506426834, 0.06712198858299563, 0.08723845389942009, 0.04937122575938702, 0.01414923027398125, 0.0401744244980716, 0.06197039969265462, 0.036064481527935115, 0.017309777716535236, 0.0791046839027155, 0.02840264276000521, 0.08829569353932336, 0.04127428160920259, 0.05774122279798312, 0.043097107385795926, 0.04194663484550772, 0.02819210264621483, 0.020263548452226866, 0.05237362392607236, 0.02995421403958913, 0.05764479914139356, 0.03390677190656143, 0.01993630633449122, 0.06523889083895953, 0.06025848046485936, 0.05716378019461709, 0.08974320135049282, 0.099712724857513, 0.10469728359772314, 0.0076737725025703835, 0.018321542377253214, 0.017412875914165092, 0.05944717803128785, 0.01204425048443579, 0.020552051418851462, 0.011504861383488583, 0.1530296175229934, 0.1128500372531914, 0.03400493458273911, 0.3586319882062174, 1.1712811430615764, 3.361621758630199, 18.464184961011334, 27.56952016584335, 43.24676306016984, 34.623765637797696, 22.90176630020142, 9.262548704301159, 1.7941364886299258, 6.887470214597641, 2.2126283809061977, 2.3542678644580226, 2.130778321335393, 6.588346342886648, 13.453562990311655, 17.5774194348243, 17.387678700108683, 16.131889723962356, 25.85560521771831, 34.67353659291422, 40.45238025726811, 37.08076184795749, 32.733042009415165, 19.253975768243116, 8.477546130457233, 9.016014991268035, 3.5145799767586494, 4.85142179073826, 23.72395588505653, 49.73008009695238, 38.12734826918572, 35.111116209337794, 15.312922366203802, 4.74607575324274, 0.6771701213813598, 0.2057975239210552, 0.06831777522400503, 0.08371942135835848, 0.09630423114304582, 0.08596032812830903, 0.09451861042649516, 0.10192831242156607, 0.019225007103335474, 0.02888413476607492, 0.018432981357158675, 0.06721489972645237, 0.034847769195274, 0.03358663525432348, 0.03179727411348253, 0.0653162733801911, 0.06017474322429588, 0.028550241089936708, 0.04969359938836387, 0.08472336426136956, 0.010651239295369916, 0.05903426813141954, 0.03364472387118205, 0.12525604977723093, 0.09933584024228397, 0.011755761881959776, 0.10371624672364804, 0.05096766872391586, 0.030794951486431306, 0.018622597694517146, 0.030355444929051786, 0.09603232355608095, 0.04937241319566966, 0.026609437773004178, 0.0454139219777238, 0.044947217383812514, 0.0636386365870074, 0.06261934894287298, 0.017228610700957717, 0.026742187403743307, 0.009808835607292432, 0.05702458584921495, 0.028061496146443873, 0.04015759354637515, 0.06524183261658877, 0.010376945344520914, 0.07077038273095124, 0.048797487191134886, 0.06685401102708233, 0.06353757809847593, 0.03563416227998753, 0.03260688157752156, 0.013106445755599248, 0.03693637002499835, 0.09329994840006675, 0.04534172202129999, 0.06459644950565792, 0.06035812552117052, 0.03402318662753509, 0.07437698678263734, 0.06436298421073346, 0.16712765780187425, 0.042708719960383834, 0.06893825281651751, 0.0519415388454593, 0.10671398707575376, 0.093595152720809, 0.09643864893024007, 0.07396437948749912, 0.12014654209657062, 0.11332060676068069, 0.18845188371356458, 0.40394829526062936, 0.38730301263351596, 0.3713382305877824, 0.3437000152564818, 0.21044770826495465, 0.11468918453301154, 0.21263294342544772, 0.06815912607576578, 0.07516745162466842, 0.07464818190783262, 0.24253121006392667, 0.3603002519136475, 0.30408095087735887, 0.11435935303809182, 0.12385868242070561, 0.06292102670657539, 0.058556780849974004, 0.11213065770965432, 0.11211781807604337, 0.048383240467838706, 0.056645238261309364, 0.010584512079555181, 0.027141466684218858, 0.07160606208227335, 0.08608413559775199, 0.03474435115593576, 0.12809626713034608, 0.03722154242437213, 0.05082438729943768, 0.059610527128942555, 0.014219489155126917, 0.0664468812606027, 0.0821074191480875, 0.04286412089582413, 0.049445639709912004, 0.032383317969018416, 0.08418242957803511, 0.06945805113402105, 0.05324399173860589, 0.058448375578248696, 0.019117071060463786, 0.013161596425268198, 0.009936168038796996, 0.12787325127470878, 0.07594108551500306, 0.04007561830803752, 0.022875910189243096, 0.10934349960617482, 0.04075804943098657, 0.032409717358889124, 0.10535382860971075, 0.07290398356534782, 0.05860574535965439, 0.022070248078014103, 0.09742933085128185, 0.02530394734123782, 0.0823033920999977, 0.04242843520196696, 0.07267494625862568, 0.031286601818376975, 0.07454833766866116, 0.030802983918317386, 0.175326177549939, 0.06843055102733836, 0.09932260990383164, 0.05672468157905725, 0.09887167522984167, 0.3230431898226661, 0.7303319042248111, 1.780631645552574, 2.2909963563565285, 5.8952708878824795, 21.771678501559844, 40.43365878443564, 58.68194080168202, 52.525427802916504, 39.64796489284885, 19.305980513172766, 6.165365788244433, 6.371219129331651, 9.207034418659827, 6.6143536183141896, 12.99534680381898, 16.979093243998868, 30.02742244351295, 37.59816954212804, 31.166427750741285, 32.678215119146536, 41.32214623112833, 51.335972970531834, 56.99731811400383, 53.815934658050544, 47.53949911363664, 35.21421963168729, 17.30834876337359, 12.4168844761387, 12.14880028078633, 18.14029916640251, 30.24854410079218, 50.644808200097856, 52.360496059540786, 36.30532887674148, 20.36735426995062, 7.560699947418706, 1.3669197742016086, 0.7356379517624456, 0.2308983181513125, 0.033600731272130244, 0.027862901258612835, 0.06546969780878675, 0.055913792832964854, 0.050270969213377086, 0.023220226491591143, 0.03675838098711064, 0.030822869645611897, 0.08788486356816946, 0.04397890906059935, 0.03420684471606247, 0.03437569049457389, 0.098318207348066, 0.020820174531470385, 0.020368073488615697, 0.04780217426859083, 0.020193213919898676, 0.04279775086850409, 0.048233937592275684, 0.06815476703547663, 0.07030781884227069, 0.04449638613169232, 0.06291161914686523, 0.09041572695658093, 0.04769804759792263, 0.03753472682869723, 0.02493668670555757, 0.06660985880561414, 0.05309368911830168, 0.07331452242309049, 0.13250699537175317, 0.03915615192043685, 0.06272569343808197, 0.01871225679473531, 0.05069662681630543, 0.016853195059323506, 0.034050344444450834, 0.037589444658688964, 0.04295125573633179, 0.03230456029996276, 0.032910336665208303, 0.03132665672549798, 0.0271969199586179, 0.06499216456206576, 0.05811420802567756, 0.08095992668982475, 0.1428895245396322, 0.0471723465729625, 0.04833063704051799, 0.02382721136053724, 0.040083363456952, 0.14871858030317292, 0.11077699566920919, 0.08356078753187772, 0.0905352596554064, 0.18755913081188358, 0.06510017529851006, 0.2057561092078686, 0.1561155882213385, 0.08733593858778478, 0.2361727262576742, 0.1052351615902397, 0.10175782721489669, 0.010784165126331633, 0.054008348304177486, 0.38590965191683463, 0.30177986790095607, 0.2155821214640333, 0.23724586222200628, 0.43743056635702815, 0.46229906740688514, 0.3454373188076481, 0.4807443502208879, 0.6392029877151213, 0.6830518993158495, 0.4387696880486704, 0.33337302746311315, 0.2849483339776916, 0.17130386354702135, 0.2930680692436234, 0.2494168696143935, 0.3324146208263213, 0.21218010885340555, 0.3283505856750473, 0.21043885228854997, 0.22403251559984302, 0.29357056163491746, 0.1545907055298167, 0.13173597384124033, 0.1275395586966507, 0.10138874903561608, 0.10082383580025166, 0.19984105241394814, 0.14300151127240351, 0.2345976801288705, 0.21924147833018534, 0.18057711272230073, 0.1525250566943038, 0.17375467074734552, 0.15403253386818594, 0.2662423974083316, 0.15430437250723764, 0.1610151648281082, 0.15277149185778635, 0.10724346874462021, 0.15628949018015018, 0.13465446239757922, 0.0738591036849445, 0.2366642789134095, 0.11233797642372309, 0.20856733013304973, 0.1729115143778824, 0.1971727988171962, 0.12114642473358302, 0.14878519930906836, 0.13216685233337264, 0.2607766358602432, 0.14532321733572792, 0.1032035883455988, 0.2417859750529451, 0.12380015330329058, 0.2055754197100478, 0.10538881584521263, 0.23471000394032848, 0.10805752143383988, 0.1886168990524546, 0.18802338009399755, 0.18077577464282515, 0.09734603411127483, 0.22858110136322438, 0.10429488825461558, 0.24412989766607363, 0.08623606615489529, 0.11627733842619967, 0.09136079600261104, 0.24555120527023272, 0.28495311436633913, 0.2877262607216835, 1.096615517331708, 3.109242243151511, 8.965634107589722, 27.75044733478177, 41.75037099469093, 67.51141963466522, 63.134309476421734, 60.25218325276529, 43.82799556178432, 31.786458376915228, 28.37111926847889, 39.847715516244214, 39.40706468397571, 46.25356574212351, 49.49285122656053, 53.72014253370224, 55.909068276805264, 46.76177940061016, 44.40336019762101, 51.33940504443262, 64.84065817248437, 71.57800751347696, 68.12927138420844, 65.05956565180134, 54.670101365735455, 39.781733405205514, 32.107749523655066, 38.57578108387609, 46.91901153133762, 54.133368153725904, 77.27590914695494, 54.64818316121256, 42.00709796720936, 20.56336687457177, 6.4642028366365745, 0.8130103806334158, 0.39129816115863864, 0.2911074663842878, 0.1814255091331659, 0.17677690293039047, 0.20476042473268127, 0.1831682365868361, 0.2481867009473424, 0.10269704334918531, 0.1518801638796445, 0.1593729634318621, 0.20057724758742318, 0.17378453285463397, 0.1354547638085581, 0.14297494334318947, 0.13189599428686405, 0.16013713613633188, 0.09744449939218261, 0.16181646215338863, 0.21429334707077474, 0.19239041834108292, 0.14678236968334646, 0.11604927405114136, 0.24165685859418687, 0.33563093372410346, 0.17915272544468605, 0.31013466958557406, 0.1444851937553575, 0.2580970441622119, 0.19784876415806432, 0.2478797601596002, 0.1595010686545603, 0.22790688270282364, 0.16850154456352034, 0.1881533086059555, 0.2916416441721301, 0.1321183589677657, 0.09640708610775972, 0.10947305273504988, 0.1261607536505307, 0.06676696045624633, 0.15628218170135252, 0.1509508685839753, 0.10997119374693402, 0.1835690997540951, 0.1255720227416004, 0.16827965485713176, 0.14458414167165756, 0.14890391229381486, 0.3045736066997051, 0.13020189809462718, 0.178121080802333, 0.10817688559332203, 0.19680021961610164, 0.21458996099329766, 0.14277303320986612, 0.17484426228029115, 0.23681317576237265, 0.35843648256794103, 0.3075150166067385, 0.3633497108615214, 0.402171706720706, 0.39316940752248614, 0.5198691040277481, 0.20259906087190876, 0.1584942605827124, 0.22222332235786224, 0.27332203042122627], [0.11060885469158811, 0.1488515884885865, 0.29472854949774285, 0.19044984102008805, 0.1433937482896351, 0.18185378292635565, 0.22031168783864669, 0.2587674936700252, 0.054803723769803206, 0.1657807373351628, 0.13323814968668646, 0.18685848211809514, 0.13406791483923314, 0.1828604224588602, 0.187281837626811, 0.10819384677996559, 0.06554953949225527, 0.08330670681091086, 0.061813470411805384, 0.02836994038173749, 0.05273822432143554, 0.16588536962386102, 0.04275745464368694, 0.0879516970786837, 0.025977445878989758, 0.047043027100904335, 0.03842997334657177, 0.04246727202928836, 0.09447690459989733, 0.05859376374451865, 0.09752742840998596, 0.023162015300664692, 0.047190682887430155, 0.058949963985792095, 0.021323906069981958, 0.0300799367288428, 0.029017541317209124, 0.08433460528331418, 0.007987905898311687, 0.04590697233535109, 0.020658070326692635, 0.035998299192156524, 0.09753122820609039, 0.0398976445919083, 0.07736577922778745, 0.05528482698625135, 0.08581606611128777, 0.046622345239044204, 0.080386578826414, 0.0272613862574461, 0.06863252244769566, 0.08003725805470059, 0.0862468756555069, 0.02154395716535228, 0.057611949291200414, 0.023344418920216062, 0.048614058928984794, 0.02479418286032254, 0.041128016272259336, 0.08566125506354917, 0.1120556117365918, 0.049755690814626795, 0.052726897711475054, 0.025429532134665117, 0.031910775785124114, 0.0051334019630186025, 0.01256630684609615, 0.0667048690299834, 0.041401582439580274, 0.08635821887442181, 0.04272932006466774, 0.08624865297949122, 0.1225034652217742, 0.29135405476535525, 1.120332986597092, 2.486703016104237, 9.983643120334996, 25.830453018988333, 29.075206287445564, 47.07640447924214, 32.94182977368755, 14.735007209162559, 4.631276313335666, 6.185322317384905, 8.533546789999932, 8.233067739394404, 7.395009715710917, 7.751302132683416, 15.786128870902525, 21.696202293519054, 34.56286299613215, 34.4310046780494, 45.375919726587114, 40.098143162265906, 31.315213057302664, 30.275349578549786, 23.04161252514009, 17.250456540815293, 6.533257634409013, 7.342214122895272, 3.019739149078246, 18.386824054102746, 41.20836611716978, 39.50618297823014, 29.570721272499334, 13.179440306079004, 9.340893145530455, 2.402410545656758, 1.1310677783143137, 0.16011585421379537, 0.21687039023926183, 0.10647807029947158, 0.053552855407038046, 0.012712790518097821, 0.0486579979018819, 0.03898621829707296, 0.009063804567220711, 0.06448231772669862, 0.04275119187490594, 0.01744466856302273, 0.06116405767839282, 0.09955609818139385, 0.08551395933834777, 0.05671079623542967, 0.030484314324454437, 0.009598380720783627, 0.05116065776336098, 0.08555732757574128, 0.03424214604761332, 0.05574426906664045, 0.06947149597709218, 0.03236827200218555, 0.08369329776014052, 0.0878006475226533, 0.060249754723401806, 0.061461150405868414, 0.02843826010282482, 0.033726499926659374, 0.014771082994317817, 0.045584292271204536, 0.045062950286533565, 0.04945289073211532, 0.032503689534120986, 0.04106554180203427, 0.09017499914813427, 0.035483461293962695, 0.037237925214632865, 0.038396284630101536, 0.01660456696915771, 0.03545773606146536, 0.06004335148440254, 0.04668373569485642, 0.04849056555559078, 0.09796661129521747, 0.022252362499374057, 0.05200093364222877, 0.021451419489758632, 0.04642141569826392, 0.09551913657736394, 0.05847446853294969, 0.07517612373997128, 0.10842011084840183, 0.06172418669467011, 0.0238309632761464, 0.1058801080310537, 0.048139793047260855, 0.07481842196636623, 0.03842925705436257, 0.057008513324563546, 0.10802112459655731, 0.11711707038264121, 0.038550907986298684, 0.06496902104587325, 0.1425530893668052, 0.13299905364551853, 0.12414515333911105, 0.09358232840895654, 0.16648012964475542, 0.11731204742024984, 0.21214473091306227, 0.45249868845266683, 0.5567546441189705, 0.3456946017761385, 0.4814282215891346, 0.24301896292355754, 0.09101759627341263, 0.12086771428585054, 0.06529041791274663, 0.07784630021741314, 0.1500847448985423, 0.4036775291446717, 0.16562862291691766, 0.10585501865153352, 0.0510115425793394, 0.1243810854371517, 0.07749019956756985, 0.08192744977291554, 0.08341275636226901, 0.0910139726775308, 0.0766220840535337, 0.006769287443133973, 0.020998175060676954, 0.0548690480871066, 0.03312674884293829, 0.023811364831823497, 0.07042604919162489, 0.03477187669505516, 0.02714499260389036, 0.021785575551010912, 0.030530147449744326, 0.03694415730874866, 0.0842716251950591, 0.02636925197176395, 0.07938837392195579, 0.04414121627867703, 0.040853381412284034, 0.055117084374350894, 0.0034108685870324414, 0.07646662183105946, 0.039268498714532585, 0.024538874483457016, 0.051024692478559674, 0.023307388145176154, 0.0274585064260229, 0.011641346650468487, 0.02696485660459486, 0.042847489126988, 0.03525509048373469, 0.043140985071659095, 0.056393777561043544, 0.02252341398308354, 0.013735972761717296, 0.030483688047576337, 0.059252844507535624, 0.017571751058341998, 0.06603742258683329, 0.09619492571800949, 0.0510532790494542, 0.05790099043459181, 0.010811738545946296, 0.020955398626204942, 0.04341230660136189, 0.04986306569809395, 0.03156770246043321, 0.07387751277776496, 0.022561659007483435, 0.008015591358285277, 0.0443990929653087, 0.20129395348410453, 1.0301726503718285, 1.2127646203002622, 4.269014048960901, 18.198091368521414, 31.18533749734202, 43.73034031160417, 54.23476926742062, 45.44409836492231, 30.34691518352878, 14.883389492188732, 2.791924947692502, 11.041572055509015, 11.785662347270597, 21.45341934696321, 23.74581133165667, 31.42943051553542, 36.838465275303015, 47.54217024772398, 46.13688699660763, 58.907422173407774, 55.330808931781405, 53.13931011384534, 53.823618581218106, 33.54932646597586, 25.842345645350797, 7.73607058871177, 12.759606472907528, 21.5107879331035, 26.55812328861606, 47.698512000422326, 55.262367494644664, 36.02358894963419, 25.185887967386556, 13.450349588547985, 4.3500977754592896, 1.2278651325933396, 0.3329405861516153, 0.3260570103603025, 0.07744821794931928, 0.05010455576402526, 0.05494219033167728, 0.04036977691876312, 0.07429424928681505, 0.05204741985747411, 0.06371804543079869, 0.017323578790491147, 0.023229431038001375, 0.08568668918263528, 0.09847975996953827, 0.07782536303444255, 0.06059883800785869, 0.05051047511158451, 0.012120807565928949, 0.029937559288115274, 0.04059239440867978, 0.022404710574436094, 0.05367771241693728, 0.01555957803277359, 0.01246604796183566, 0.009925798081131953, 0.016992364506868106, 0.03511215379882244, 0.030596592170636983, 0.0801976002572525, 0.056105805110306516, 0.032515108074632385, 0.07931450772429667, 0.04699322372494687, 0.037915055009145895, 0.05762964209181167, 0.024690104070149606, 0.09605211160716512, 0.03270678327328736, 0.08171672196758371, 0.03267833459821921, 0.02679597443690704, 0.025428834994654023, 0.07484905016157897, 0.026174045107778043, 0.03146275416046622, 0.03388649355920573, 0.03321436248839863, 0.08057759518945411, 0.07031603896569821, 0.06371998746368675, 0.06741474142238017, 0.05199361750255189, 0.03660841927593274, 0.16796195819493265, 0.23348829288396145, 0.09454090358509172, 0.12103298243375556, 0.015577652919737082, 0.14291937132516216, 0.08505868094582712, 0.12270792642788542, 0.17083360813558104, 0.19103265006936368, 0.13298753168313734, 0.12400034739966355, 0.08069590214760074, 0.13656666382185875, 0.08287156120904031, 0.569548802750726, 0.44621207901547033, 0.5084277034526872, 0.4200835778347908, 0.42385095309826637, 0.48606967253069727, 0.24953310047426533, 0.4778422559461286, 0.5200255698254032, 0.3877507757034994, 0.41585520150200017, 0.3429737332607469, 0.20400127756499475, 0.23101381356677703, 0.46935991594387644, 0.32417997237174745, 0.2548725800889154, 0.2343845238248187, 0.3139667946004099, 0.1988607050190049, 0.26843343951529075, 0.352305909919162, 0.27798836389856957, 0.15258430593436764, 0.14428743581858375, 0.17290742346836677, 0.2306242578572804, 0.16782888872248514, 0.18155076450878577, 0.1984889072275931, 0.3251364791104871, 0.13618369646851095, 0.17710920122842636, 0.18307852769090285, 0.16537356160340771, 0.13050036594992684, 0.09115263459182556, 0.19924938738826783, 0.0687289959000003, 0.11739362812330646, 0.1471068538845547, 0.09252080633755654, 0.1578235965702803, 0.20100789625317822, 0.17835901238985602, 0.271674175296099, 0.18335102516556942, 0.1351118934971671, 0.17486578935096342, 0.13544409986465208, 0.13990996345396967, 0.1788854220461461, 0.18764868649023195, 0.07987402003979491, 0.1856412450152059, 0.10541655588895084, 0.13987123004851804, 0.21475261678138088, 0.22876290934941462, 0.1970353626435803, 0.2035344848709722, 0.09688461169360146, 0.20024698708326588, 0.09942908080354815, 0.08210089207897264, 0.16626136557709786, 0.1830189413721523, 0.19836542917595756, 0.21774621259781624, 0.1328628891778569, 0.23082851221965206, 0.09962378971038327, 0.21508696819505385, 0.8423309556899533, 1.9826853131094289, 7.266309395913155, 18.73513640895967, 33.74639811054353, 45.3894950497535, 74.68814895999047, 64.47535214885589, 53.38979659541961, 42.29883601588588, 32.102413139035626, 32.18169992969882, 40.44553179894724, 52.18391487675329, 51.14874647509668, 61.06379224408058, 67.1180372853433, 81.78071206615817, 75.12843501183295, 85.00507293208953, 74.85898387047553, 69.4469367304156, 74.59633411899691, 50.77241074654364, 43.45774735173872, 31.182615372442434, 34.547016620635986, 45.935685096248505, 51.09903827790291, 70.68853162950086, 61.078583502000384, 41.17881105792138, 18.211301911261774, 12.23735857394434, 3.3305806113827616, 1.228244744481579, 0.22860966112104156, 0.4431022216956462, 0.3148130153215701, 0.26448836249689905, 0.14939934135444705, 0.11949974172297986, 0.20602690596734324, 0.11963260435168782, 0.2772747683188608, 0.18748581619752994, 0.19941729853951162, 0.2270189561550656, 0.19231791577992902, 0.14791662414227763, 0.19826986736828284, 0.26635534941188754, 0.12207094730148393, 0.12487331991113963, 0.18669291519589964, 0.11734495089659769, 0.13545290987578132, 0.2274747478264955, 0.11245440646645524, 0.23374859423887348, 0.2763547273653169, 0.1423022108933618, 0.15024845788796104, 0.18766092857526195, 0.1546028556842958, 0.12896065179619098, 0.2622860129321775, 0.12529673670688946, 0.12940752620418228, 0.161038285361663, 0.09135015504134279, 0.22576411945685265, 0.11758249944015858, 0.14798678247438324, 0.10265644835007769, 0.15947833116496765, 0.112889054111175, 0.14950325352049645, 0.13464546852534817, 0.11489028261313516, 0.14091715456977968, 0.1049242141626535, 0.2832040437046559, 0.17359106501023616, 0.19557752796719152, 0.15976293282883783, 0.10306643562451487, 0.14109024447539162, 0.2872156477983921, 0.3358163882888133, 0.17570968116483382, 0.34459921861848525, 0.12540493896531482, 0.16918854157049812, 0.179916714288054, 0.12029734650446523, 0.2582067479529689, 0.35431759552128855, 0.3084979687006243, 0.1288666068426063, 0.24263251753103351, 0.2937409702327944, 0.44352488772523024], [0.1597005885935599, 0.2970444332928427, 0.07210575059176454, 0.11985675401745305, 0.22055499736339818, 0.16850413394070443, 0.3413107402382359, 0.48666455512565954, 0.21605476706979737, 0.27683656602617235, 0.07325566388786801, 0.060576269057609385, 0.12006706047442653, 0.1518962364042959, 0.17905972237067838, 0.07767098099594155, 0.029307082332971118, 0.12224992076235434, 0.0531922348384415, 0.12514298286048636, 0.08930692193849434, 0.023127981844628533, 0.05513080500907475, 0.018187953880236998, 0.05324383469058141, 0.05649985392547904, 0.01108017479700427, 0.06927541577287259, 0.04250483715065545, 0.036023553280580434, 0.1264386443841842, 0.08356736056626805, 0.012996965087950231, 0.015135286939180186, 0.08613865807532303, 0.0711051095277071, 0.025328104008710193, 0.04120228849651833, 0.018389722287294366, 0.0717079594370819, 0.038164351511025624, 0.09508406758428582, 0.035067762834050005, 0.06415028755943622, 0.03295853125652479, 0.044929846340129455, 0.10493061099682124, 0.02487563907409147, 0.03544028074811063, 0.08510487604766123, 0.006288606053849142, 0.04412949513343554, 0.05029059255555753, 0.03687634703613097, 0.05465255163970494, 0.053023710816858284, 0.06529292302025903, 0.003511497348118874, 0.035936652096889676, 0.05967104041408147, 0.06393575229712072, 0.03510732361445985, 0.07242835787755829, 0.04664976735629382, 0.061759480365341714, 0.04491710629794867, 0.03370829001669923, 0.028981897161312165, 0.015163748063177112, 0.0505108313424693, 0.048189684523329626, 0.0989089071029617, 0.0710104133993868, 0.0319283843160637, 0.327287255636146, 2.3967481140167486, 5.781979109010389, 16.89649401172515, 26.505061464924967, 31.598971043863607, 46.50281667709351, 32.37607494477303, 14.844706096956807, 3.97812960609313, 7.108466846327628, 7.047980956492886, 11.937712046407885, 15.713192397548308, 15.641333595398935, 19.262275503527736, 22.47652057678469, 28.287631619361143, 31.64432933253627, 32.933051509241906, 34.96581200630435, 19.298441717701575, 14.568566333863044, 8.730943991291909, 2.829376473542183, 5.824752065443224, 13.664410979517045, 36.698534719405636, 40.63132270689934, 38.343427719608435, 20.82664812764814, 7.235988984184881, 3.375590054258224, 0.8393300973599958, 0.32496622373019496, 0.1371640285416957, 0.0590184752288605, 0.0668518046938604, 0.011744147989027684, 0.12785276608361354, 0.04430133631573089, 0.04708315095593853, 0.032025120153482405, 0.05201280800505512, 0.037362023797487064, 0.018988333815228076, 0.009019606082039255, 0.06039830683279903, 0.07415703527869717, 0.02275987085135233, 0.0487559499038804, 0.005203547367390486, 0.010814526148380773, 0.0371567850121327, 0.05531064414929959, 0.03794534612567194, 0.022081965392815973, 0.023004499962553385, 0.056905501311825174, 0.0418653950515774, 0.042995976118911663, 0.04379012967429815, 0.08077752881593282, 0.04537290946069745, 0.03772437572479248, 0.08536569834236177, 0.013584882028460985, 0.028300498341841084, 0.04156983833039, 0.09734955045484728, 0.05633566979198687, 0.06233815253982621, 0.05993291224923827, 0.06171798904336268, 0.06330774406031256, 0.02562917656295242, 0.05465250567442948, 0.04885652192657994, 0.06793159796225448, 0.11001931172945809, 0.01820197520447114, 0.02208015359487505, 0.0731032660170909, 0.034922654289872415, 0.033282705192123695, 0.07454150416437658, 0.09240256066644385, 0.04047149424290946, 0.07908060575925535, 0.06891543871813244, 0.0646564724945253, 0.08065436486034624, 0.012665227949318868, 0.04003905676185124, 0.10729399990410575, 0.05599304462873167, 0.08000400983878682, 0.059763128013019605, 0.08136979905107329, 0.06526152873712202, 0.09610863357421853, 0.08481168653815986, 0.07692213004995739, 0.11288015983037411, 0.06464694236074725, 0.3033349344566945, 0.5303632828497118, 0.4221630775399747, 0.5883542388196915, 0.7505090054004424, 0.23371258810643228, 0.027190643783298232, 0.04325309820893792, 0.0170700553984892, 0.1876872053910648, 0.208698530350962, 0.07727011016780332, 0.1804425417175216, 0.10269495959003126, 0.10072432097888763, 0.1797544568656914, 0.12673312858227762, 0.05423084322002627, 0.07642593490140093, 0.17624480890170222, 0.04262831137185136, 0.13021459983241174, 0.02224153193134454, 0.04140119173473889, 0.057926405401479815, 0.026873776411277153, 0.06702854117799191, 0.06461674317477212, 0.04276405832159423, 0.02684712995805087, 0.040610056565774065, 0.06193142879994647, 0.03331300013908937, 0.05065992737429277, 0.02112692188201172, 0.047080469648203546, 0.09535558446640931, 0.05539545008251744, 0.03798021078710595, 0.030244402399647142, 0.09881694590853107, 0.035849521086821635, 0.03120563015522015, 0.05972285477084018, 0.054835328727119395, 0.017114829407223774, 0.02593552937821275, 0.032004081463861855, 0.06330294834990656, 0.0803435706503449, 0.05279181217173896, 0.02943369368421695, 0.022488957263469216, 0.017048633664906505, 0.004339499780232268, 0.06823833956713639, 0.03763747454110173, 0.08614078779975254, 0.09092524437414062, 0.011700496299102182, 0.05022025419278972, 0.06526871464185177, 0.04152045630279087, 0.01308685209932587, 0.029740031177718795, 0.08023862426559772, 0.007400530965007361, 0.011200846094007214, 0.09823647342742452, 0.032278570767131545, 0.11197929405757498, 0.8218680730750485, 3.4131670959534186, 10.749658480767282, 22.735863770208052, 30.141769339961392, 51.62078411348405, 57.89691371302451, 39.970587684262185, 28.624051347855602, 10.88160897454908, 6.9614632764170254, 9.134510774766246, 20.766537804757398, 25.447033489904097, 32.228152559649565, 36.930515458506925, 41.5836977189587, 46.475893528230735, 47.69842963064871, 53.20985394139444, 60.0469530782392, 33.0574651687376, 24.178560549213042, 25.143769556476226, 13.351098914300243, 18.748446972139423, 28.092399566404282, 45.19412571384061, 54.308741246500325, 42.784649018318426, 27.004902824278805, 11.059062884699914, 6.640974744673699, 2.0145099537987865, 0.468958976167825, 0.20937351509928706, 0.12857399189904814, 0.09710897586398548, 0.023502104712890524, 0.05657239096058954, 0.04562743068222077, 0.06504547662071644, 0.02180707006294641, 0.05252414488143498, 0.012109222401294016, 0.01998268338220735, 0.02277199227753426, 0.07125509422152274, 0.03538935505334408, 0.03793952002700779, 0.018945607176471143, 0.04767896817816843, 0.023087321728047346, 0.0794566017124922, 0.0253103326840867, 0.05324053285162776, 0.018610830584000197, 0.01918961958689315, 0.0677371112209174, 0.05017903100158419, 0.04335819398083034, 0.04993149267149068, 0.04524560096944052, 0.019090562503063874, 0.037141133835839654, 0.03757852790576797, 0.047843232750892646, 0.022491791788789055, 0.07177804116039507, 0.04333623024004121, 0.008236627834248207, 0.028886879276063655, 0.14760727783845318, 0.049940632100427346, 0.007430547247490576, 0.013557107510766195, 0.039243991561834855, 0.06207450721112471, 0.08986689390674715, 0.008097612561898367, 0.02621189559689693, 0.06309491717406819, 0.017493973981829423, 0.015225202678852986, 0.11996717793085884, 0.030566963720165437, 0.03669659599601742, 0.04264212393712613, 0.11370297656544756, 0.18988460602779544, 0.0984058861109999, 0.08283517969351623, 0.1375943860940395, 0.23250209257727672, 0.1644120446496433, 0.08643184758482442, 0.15843056803268774, 0.10571642568515194, 0.12773154033047537, 0.0670243506770461, 0.08765548918276064, 0.07697342729736721, 0.29164863089399956, 0.33628091336258, 0.3665403751355987, 0.3623537659164398, 0.4969049136965506, 0.41043516008123276, 0.529909513650402, 0.7444774419549973, 0.5387829568597579, 0.540507635281932, 0.30484575177392653, 0.2561086935982589, 0.20120162456747026, 0.18731332384049895, 0.2836699477366863, 0.33616566309525125, 0.47355314416270106, 0.26119816807969926, 0.3879298564166792, 0.24500550552000924, 0.4595385155370159, 0.27054676966321084, 0.25826340781584867, 0.12480355228387541, 0.26052137536387293, 0.15923920448028273, 0.13861109202186908, 0.16881210128626517, 0.11067461567900835, 0.14894940259475864, 0.19646666493386994, 0.17259387900271725, 0.10164009482269326, 0.16186670219946295, 0.18298052972362888, 0.28469828287920645, 0.17482777606816063, 0.10288069760727306, 0.14335817116643154, 0.46672065111417926, 0.12515962229020175, 0.2397829002790874, 0.162492687964151, 0.27465312351142207, 0.16837592146569685, 0.14330661344912746, 0.19212654701644377, 0.2094365947789723, 0.18328029992839984, 0.21157515986311823, 0.21662726457561218, 0.17398448180287115, 0.14592467296508052, 0.1221769815310836, 0.20730117065531595, 0.07767729356043762, 0.2622854307053551, 0.12666788087376665, 0.16469007327912316, 0.18290255729469562, 0.11185530272703018, 0.19336364111833035, 0.2276227253699495, 0.16899410845531573, 0.18995648039685142, 0.11562789504927014, 0.1243550614303639, 0.11779910313986963, 0.13969245577050796, 0.11941179482927246, 0.10250173689376924, 0.2126833213673484, 0.09778849585282226, 0.2630996902383143, 0.9661138490323098, 4.107479813598817, 11.808502308783993, 25.239761721703317, 36.86881265332622, 51.05089118403774, 72.9334060607418, 61.472766014837454, 58.06519123815722, 32.35928720043552, 31.323791280869518, 34.90061044692993, 47.409766720187285, 51.34860692485687, 61.623443865006976, 68.4385581170359, 76.81561900723365, 83.65449890013664, 77.28297725800546, 69.08669056430941, 79.41373425145304, 50.42437491878387, 36.288039069021906, 41.643258910025324, 37.71444820588635, 40.52919987709292, 51.29388986095306, 75.1581822672198, 69.26132232912126, 47.669737492838216, 25.34934489957748, 10.353796212903916, 4.5115724398243815, 1.4793144334708492, 0.41000835717685763, 0.2968892238793835, 0.22487800087659593, 0.14590150646625027, 0.07075452471091863, 0.21634963431185295, 0.07879113943706598, 0.13670017762530234, 0.1822642681579436, 0.1892596774644429, 0.11381229731224238, 0.10835885445797637, 0.12760315931612445, 0.266154665019243, 0.13418724069431906, 0.12828960473979675, 0.13206228133170836, 0.13006905844855693, 0.19362339088993688, 0.1605857878683075, 0.14983106254329606, 0.16758397041309267, 0.14849882032121384, 0.10150002330661782, 0.10726977620394, 0.13172917098047274, 0.0983097420765027, 0.13716120933813436, 0.2897219197644342, 0.10667712292483739, 0.16692962407344775, 0.19048262958324727, 0.11463768044186216, 0.10842804751929738, 0.12888816455679555, 0.16599937882875243, 0.14803035755551633, 0.12863561601167725, 0.1661560438092678, 0.11301174309224853, 0.1449236411961817, 0.11382257821218622, 0.12335682588238871, 0.2516518392029309, 0.19068771132057716, 0.16282527737559813, 0.12085969334528332, 0.19903534242222387, 0.19772706343041313, 0.18114225578404244, 0.18454906410507618, 0.09855046988494935, 0.2002018185392503, 0.16997516065114932, 0.17484266881740865, 0.26567199898342936, 0.13792748112351666, 0.21090418941551642, 0.2193952781418639, 0.2210178983307654, 0.25127038870367313, 0.1267007843501145, 0.30860834664875464, 0.18063631599708913, 0.20936118108370613, 0.3183641392857798, 0.3997624521293948, 0.24461812550021758], [0.15319463286188342, 0.1936841723058493, 0.22889732713660887, 0.06375447674203785, 0.08950518549329813, 0.5180122907603941, 0.3950769051669106, 0.26730869986837913, 0.19969100643309856, 0.2842226342087792, 0.11230435282472642, 0.06473940151232867, 0.07782611380060835, 0.24759571007903547, 0.05885036106431677, 0.05886479033037059, 0.04656123823576397, 0.08841259855656855, 0.036533898073098356, 0.05969043392988463, 0.08399687542189514, 0.03976051102302248, 0.08822624766898733, 0.07544614675064241, 0.07958196434042147, 0.0364369036810052, 0.053476315562523184, 0.0885703896863326, 0.06211707871707697, 0.06759862550684521, 0.05902120633231056, 0.03197922382593876, 0.06047726751515462, 0.0434094988891194, 0.024238769115219196, 0.04350081273925401, 0.027555000945745457, 0.05862277166377153, 0.06413502325754493, 0.04483870485977781, 0.01643415837128076, 0.019441061134960864, 0.018570647357151877, 0.02921176375821233, 0.05161102170184736, 0.06502025700624912, 0.04873080689820552, 0.017082789695010554, 0.041660960658543536, 0.023262820980181138, 0.07659898650261664, 0.0885362221649097, 0.031068829834581386, 0.02557484560736245, 0.06178459655793925, 0.02518316400387595, 0.018743630010454405, 0.014373943971980725, 0.04968557844779665, 0.01758218900631032, 0.013791024797565997, 0.03422322367588359, 0.08882346683211866, 0.08263048866102773, 0.05033451237625653, 0.07572094248908182, 0.028162543143656467, 0.06132760978934746, 0.01634964546669395, 0.04315111275401808, 0.004331163307201237, 0.0452406941762855, 0.152479597036877, 0.029214588707433115, 0.07198535221358461, 0.08336803214924951, 1.8533787419719083, 7.354134205848941, 13.092478417581129, 22.474961434641195, 29.915430930352983, 51.60025835037232, 32.13330768769787, 14.873856171484917, 3.824512184627595, 2.5649616554860146, 5.164128830355983, 7.63798927107165, 11.764823775137625, 20.92368168215598, 23.361999565555205, 22.30612693294402, 20.292801780085412, 23.02683891788606, 52.76830880872665, 10.063317245052708, 11.031122861369964, 8.049684676431841, 12.694163687767523, 16.13379305408847, 29.914940634081443, 32.02700949484302, 33.06368212546072, 12.4839932880094, 8.170804525575331, 2.3563754029812354, 1.1379978709643888, 0.2900375479892377, 0.09158653147037953, 0.08384398725484649, 0.06517181218030953, 0.05408833171391199, 0.08804099228713783, 0.015781848867904517, 0.06269595773530103, 0.03027094543100365, 0.010233985676970935, 0.0392882599525394, 0.04850659594540635, 0.023912281594088963, 0.051439923624838554, 0.05095309773159604, 0.03713122448853908, 0.022954382490546956, 0.009177517870651379, 0.13985779286632616, 0.028315477275980577, 0.03988424188367302, 0.04174748262871177, 0.01711823849848682, 0.03173009394818256, 0.10184698452752444, 0.05816758903224142, 0.04596237964447468, 0.09603253806069975, 0.060012347906106905, 0.023347368358724543, 0.00979732034818059, 0.04709810499222048, 0.05044243501258954, 0.00453374999192273, 0.030939577395216595, 0.0872950294926282, 0.058536077323820324, 0.027980616413837964, 0.017653471572444807, 0.04949531668136197, 0.033946688917856065, 0.04824984540802337, 0.013913844971196547, 0.012656419853409453, 0.01833406025393596, 0.05688798854187612, 0.0170561489874437, 0.0030593105991776554, 0.08272967406458433, 0.02584312768322566, 0.0842498453153718, 0.01985750653059973, 0.04917360188800001, 0.06477133971789191, 0.04617612200578855, 0.04577943018727726, 0.11285163837695315, 0.13691624506346642, 0.1477258682491318, 0.18691546373790313, 0.04244857182305667, 0.05608891287157613, 0.022297645956578276, 0.016860796566752177, 0.023802911051579063, 0.01809826030606224, 0.023905614713927912, 0.04021210453262733, 0.07176705545956089, 0.22420122348252805, 0.11183647994673061, 0.16360923047027282, 0.4392483091402439, 0.38642476943712084, 0.747974234963617, 0.3877353620144629, 0.2830191713667685, 0.13529298136070853, 0.24196608232394343, 0.18649434520592614, 0.15051481133747488, 0.1401383189424392, 0.45607901568855014, 0.1710846091830923, 0.15158745700553541, 0.07382843718533555, 0.1021949340018534, 0.076632410918753, 0.023477515205740932, 0.034912649181581316, 0.06496988672522769, 0.010170281635627392, 0.0385535586505167, 0.08673626794329575, 0.05745617680311684, 0.06555429689826504, 0.049410357530559265, 0.030396309974152717, 0.05108251296464474, 0.0175330578725064, 0.048020796609982375, 0.017196415855939833, 0.08260667098746186, 0.05487962010046167, 0.02426579286674819, 0.051410582457338615, 0.05043581601292376, 0.08934216198301123, 0.011744559761286985, 0.08089447979845348, 0.020729774241185477, 0.029074612952348207, 0.009185398042562508, 0.06492081879367752, 0.030411673867474162, 0.005556307873883916, 0.044895142557159554, 0.01608199349814846, 0.054323444097873666, 0.08284222004154036, 0.08205883385192964, 0.025211834844442147, 0.04157697060896505, 0.015211323080884834, 0.03526531392708421, 0.014120874487073913, 0.01327530494064934, 0.044854091735736984, 0.026213107931037104, 0.08881811187752793, 0.05667712284071792, 0.09939754862458476, 0.06444834172725677, 0.03958450615285866, 0.0440379974221991, 0.13466751653580897, 0.03392034315414006, 0.1288998244150031, 0.0949668178274747, 0.03734883942431019, 0.03499951589131548, 0.044204675171884804, 0.038276062452144204, 0.43696343658431885, 1.834385522430943, 5.017461113391384, 14.837621315833061, 22.684684684199674, 26.97321399565666, 48.09150603509719, 59.63448055328862, 45.78495625526675, 24.891961236153882, 17.35692927914281, 10.506547035709506, 5.063556807656442, 11.174756134710005, 24.638234876817275, 33.548498845869496, 40.61655498320057, 33.99826134404829, 28.945630788803104, 43.95704938519386, 69.8262534602996, 23.22689940852504, 18.74681526614774, 24.693473615954, 30.35548163998512, 28.18145698116672, 42.17021365319529, 48.37092391906246, 44.19201112562611, 23.32334068513686, 12.580946433928705, 5.4565841824777666, 1.9753368751656626, 0.3216733633270187, 0.14835462725210577, 0.13910544855940726, 0.0626558989977404, 0.03706300818932153, 0.07531901445960806, 0.058348979500512925, 0.017587314134523753, 0.07129640168239994, 0.021628747776811643, 0.007467526790400547, 0.028690142151448998, 0.024030770498117613, 0.07337493611679924, 0.031483637717282104, 0.0434073155385352, 0.0382915067846977, 0.04769766838440011, 0.022064925682160164, 0.012005894377286877, 0.0036139987153752198, 0.06742630168915757, 0.061425561791345965, 0.02240653194847607, 0.10838723801557096, 0.022836498795978488, 0.06675919232469413, 0.02319077041090256, 0.015083309788737568, 0.055530063222132386, 0.0390667456292337, 0.08273224045913066, 0.031294385271687666, 0.0060098874664324675, 0.007094645942185796, 0.03687749233757777, 0.05174376941736668, 0.059075759453398574, 0.025958416254950628, 0.019885160389446446, 0.010187941877501867, 0.08894941934774961, 0.08328774613478492, 0.04423208962825518, 0.027954149991273883, 0.05889334625774815, 0.029230324153397835, 0.045604693192628123, 0.08367540194622933, 0.024784742741875594, 0.07447701488291064, 0.08608029749725135, 0.015880670379697075, 0.07141679239970061, 0.09604091140171213, 0.08099322853189322, 0.08972689133858489, 0.17384514573120302, 0.10770227114159255, 0.15430564421319193, 0.2052022582821308, 0.10018907832883059, 0.053465586501143636, 0.07501087857470398, 0.09483902670082547, 0.1179482144934516, 0.046211959598886396, 0.10992767229195564, 0.07102409572971445, 0.4389651630434298, 0.36896050817543463, 0.4202077147220412, 0.5644558502301094, 0.4026992655088825, 0.8418246022155209, 0.4850194272735427, 0.452985062354034, 0.42456733723801954, 0.6049442098986718, 0.4819569141874391, 0.3280951106740583, 0.14842670080402207, 0.45271218183540535, 0.18984453962935557, 0.2631846953543925, 0.1857637731178153, 0.24361640425218692, 0.23971292580808365, 0.1331219647920901, 0.24601920838317565, 0.25028847848936436, 0.306726589558586, 0.09400509402997072, 0.19307637346848366, 0.24547462712132165, 0.16068786142333863, 0.1975756231695414, 0.1531236318330611, 0.2749298344696722, 0.19336134285455753, 0.17060413415874207, 0.13218551423520813, 0.20394786591491393, 0.1741851661955157, 0.048864508393190564, 0.12013740266763395, 0.13431949811356683, 0.10411260529391228, 0.24189837547319554, 0.2455097139482537, 0.141040847126034, 0.08371887743593225, 0.16314544084091342, 0.17558393549294243, 0.1499891064820751, 0.1597234639789789, 0.16030529243571146, 0.27615591222720764, 0.11994631735668068, 0.14499816622945572, 0.18864783368283705, 0.1134672589720257, 0.14526568413261445, 0.09387577838835218, 0.1408391974626049, 0.1138794142752886, 0.12067368719726802, 0.23637773138621163, 0.185462792494124, 0.13793313485239783, 0.16042849469569423, 0.2709048085155026, 0.1850240079746131, 0.10797813940312594, 0.16914315852186373, 0.2745979958243909, 0.13350252662935566, 0.2683911514618705, 0.19311214977454758, 0.13040328728816203, 0.16167838246591631, 0.19626210413632855, 0.13741450864941845, 0.27837336904579596, 1.1441722944859536, 3.5419845965600785, 13.385096057768791, 21.850647580239084, 28.32565703699666, 52.30009548125729, 81.33175757623489, 70.0878990850141, 59.45519293508222, 40.559680615701986, 31.692915731860747, 31.02189821581687, 29.36642069970408, 43.658568782191125, 52.86161807275588, 65.18204558280208, 60.031855875445956, 53.866709739931174, 62.52213339651785, 97.20854713070779, 34.62866075577275, 33.99723368306314, 41.043359848760794, 54.92729510030439, 57.03354904728552, 72.63508627491613, 67.92239773658015, 44.660616690112704, 18.032031943721158, 9.307111732421383, 4.556342863267468, 1.275953513480002, 0.24194299243390563, 0.20957577763305557, 0.19918315142633455, 0.20983825467767256, 0.08312487584208289, 0.14985594507907668, 0.10585200026511185, 0.11073836185518773, 0.2241729701598806, 0.09000243784319009, 0.07901394078808446, 0.0942070424676903, 0.1045770231153696, 0.15564079756938642, 0.11108394411783065, 0.12939497768398256, 0.20634133909498492, 0.1553467730240476, 0.14984426989911065, 0.12481957884325136, 0.12295191777088951, 0.12565180313803498, 0.17293966044822048, 0.1060678838421741, 0.22110814348824565, 0.14996414733750207, 0.17869864981020653, 0.15988058861224883, 0.15224203317155763, 0.1375167660655514, 0.14451646546442665, 0.15792478146331926, 0.155523065177183, 0.1505427582249526, 0.09588946347996112, 0.1661447516732639, 0.14146101570898487, 0.18495378835547358, 0.09861758684799557, 0.11714059694279587, 0.08494904610298334, 0.2036792908104197, 0.21058581859594394, 0.20725416350028208, 0.10396914766921152, 0.16699095707266562, 0.17139767867422875, 0.11278295093366217, 0.19230116909790426, 0.27767693383559106, 0.19673263533942162, 0.20798004713029633, 0.16699167719531446, 0.1581088417480069, 0.1942154849248548, 0.14957928008610202, 0.23427535629560872, 0.38034950833647485, 0.3211637003527534, 0.37860739375314406, 0.3713673725724221, 0.2500502557884301, 0.165688960001834, 0.19338486175383293, 0.1755941704276108, 0.13950131683339997, 0.09178110248138828, 0.248651884856724, 0.2963586313830268], [0.073223197081637, 0.14460494861968104, 0.10898133920085047, 0.11366353069822635, 0.1136734362150873, 0.27448452288104647, 0.23519835434854033, 0.08048036331010443, 0.047025679039859006, 0.12926423711882484, 0.0943413453416959, 0.1154211049358691, 0.12895930348144424, 0.16672380689171054, 0.13134444162489908, 0.10933583106605277, 0.12178803869192639, 0.04427810852986671, 0.10667243446674078, 0.09026247872820786, 0.07848082020157769, 0.04172395606855712, 0.028717853466890035, 0.023585851529553056, 0.039644498498209065, 0.0504900167335666, 0.07645589660011953, 0.09225964696416933, 0.03861739675724699, 0.031117390232881716, 0.0581282657390881, 0.027830173982487574, 0.04870835669158448, 0.021779772434984485, 0.13454713347938754, 0.02214508720733706, 0.051107184826246196, 0.03148647224260194, 0.051055152134429065, 0.07071377649422615, 0.028207960666247436, 0.012288134575130479, 0.04641787254161412, 0.06963805881358924, 0.03747448933521106, 0.015910881056991077, 0.06403041012104481, 0.03983538079586241, 0.014489640485525373, 0.04605196213590042, 0.05207341705118457, 0.03776448042762857, 0.08761033596050355, 0.005760160040095328, 0.060988320939002506, 0.024981677134130752, 0.010446078076417889, 0.016686421548647266, 0.0716607990644632, 0.009430526068524249, 0.013224674189733642, 0.03224102096752294, 0.08711729709419512, 0.025176192603764996, 0.04604854155331851, 0.09563814067552168, 0.04820257395265564, 0.03849630123905597, 0.0484415129457991, 0.0320846643373971, 0.12104728529530188, 0.01499607344157994, 0.0858000012475156, 0.07324704539871986, 0.04140042564681461, 0.14940966821966634, 0.5329353158031741, 2.329684164254896, 4.14161644635662, 14.360059019057983, 17.650391209510065, 26.098507796564412, 40.05791533377863, 18.71722686675287, 11.936747143345496, 12.337491781480852, 13.513724304014637, 6.38091326721253, 4.920729091090541, 8.370190858840942, 14.60218987157268, 12.371160426447469, 8.685689645428813, 9.975645407553642, 18.973998946528283, 7.823048166690334, 16.608123317841564, 23.16145270101486, 22.504394900414255, 27.458338622123968, 30.74565549050608, 16.935547090345814, 8.138530283204972, 4.805147628630362, 1.1007723716958877, 0.8475738162955931, 0.15990516471285976, 0.14710778851182232, 0.10199651722946476, 0.03172491327859461, 0.0484456651423487, 0.03442354417676407, 0.03864248613676718, 0.07234350597906498, 0.04500650109783296, 0.022056785997964685, 0.056407590126318324, 0.019093272539096016, 0.036431280595640984, 0.024397607870219697, 0.10599630058652933, 0.116960788446088, 0.028059843311747237, 0.08588067030594235, 0.023631364813134558, 0.01463227935375706, 0.01739733007496163, 0.06451408739291853, 0.04582205531938423, 0.14381701186780008, 0.0317374924423113, 0.0880359054633206, 0.010750118263756797, 0.05255777997175052, 0.041261357705919974, 0.07037718810381428, 0.10017734952270986, 0.06989829888146731, 0.020081060563003825, 0.025023172286549406, 0.04583289163307317, 0.041404535708528374, 0.03464578245315821, 0.07177957333624363, 0.008670021009991967, 0.06588817333742496, 0.017323739668955247, 0.08865245302478153, 0.07344352396866007, 0.07846375176262471, 0.033475621453216, 0.07784260001273886, 0.0674364370323958, 0.01460837932573932, 0.021782388625245903, 0.03739616833627224, 0.0385136837740579, 0.0864784870176546, 0.10145898397651412, 0.05464734990269907, 0.08148510294455676, 0.009670423629182962, 0.023636704445966793, 0.046250727478294604, 0.05355758216953086, 0.04508111423121826, 0.06739004274770137, 0.09732996924750267, 0.09744403207854879, 0.07392143259846395, 0.038604281331983306, 0.09062748131973129, 0.08996203436606354, 0.046312171560261524, 0.04998306954099287, 0.08044077954705685, 0.2455882839257679, 0.10142809531140713, 0.19390172595458646, 0.43938102621224623, 0.5011064463084745, 0.5933550156412587, 0.3703799158815415, 0.17251006898380097, 0.08205087419839636, 0.05694970458505615, 0.11186272611901646, 0.22457317449152472, 0.15420084338515036, 0.2461291573220684, 0.17335546233000296, 0.1005638485413886, 0.04287068626933521, 0.06024061146402552, 0.11208374248517138, 0.04200086620966754, 0.012155838851486484, 0.051606157043528174, 0.036995017886041634, 0.03727552097951693, 0.06835663886440378, 0.012689944818585873, 0.10223790387352628, 0.13159386453128633, 0.012840398741255124, 0.02280029156545718, 0.024653883433089625, 0.037079624636399175, 0.04295480655386083, 0.020480722887441516, 0.043960994094490044, 0.02290921969219081, 0.058945624097701044, 0.1061521458529657, 0.08659229703968571, 0.024850164735389334, 0.059340676488054384, 0.009561279082610723, 0.005256750737316907, 0.018515420078690496, 0.01661009046309177, 0.0042028378342248264, 0.079872602777135, 0.053609936618276184, 0.020271540664496924, 0.04484130189784112, 0.06720691709028137, 0.02329052080430331, 0.05366103851326531, 0.045082585120032874, 0.02691422010801973, 0.031395091359773954, 0.021429430851111972, 0.03639665725190313, 0.04360720319973846, 0.051243318650390834, 0.009485512029289479, 0.02020963692977544, 0.016886837810518283, 0.02743591066269625, 0.024171577458600366, 0.030130540666681145, 0.06889136057467231, 0.08236314695809158, 0.05787447613153247, 0.10734867559926164, 0.08951361246046521, 0.06979133002460003, 0.0710998465036673, 0.13837263949455755, 0.16572372507183783, 0.6565725911528834, 1.5556209582474925, 5.462507942030507, 10.168760361209994, 19.191674801611132, 23.58307807676254, 49.55916673906388, 50.36596690454791, 38.63292609491656, 27.739721613545573, 22.00576751462875, 20.274490194935954, 15.663117458743436, 8.659433299495328, 17.12222445395685, 28.538229888485326, 20.642767413969963, 14.818688035011293, 17.870289087295532, 27.5341913777013, 19.850566310267297, 31.79059255507685, 37.678636966213105, 34.68282084311209, 42.915954282206876, 50.26856660842896, 29.64454027914232, 17.30433617868731, 5.682378363224768, 3.7410561596193626, 1.7923983883473182, 0.5661647778845603, 0.2843993860146692, 0.06279562577424992, 0.0863337500261203, 0.0038926270480583156, 0.01782359288735015, 0.03559203127459173, 0.015496105733027142, 0.11888776004554764, 0.030014775205223315, 0.08302929871264966, 0.026475621364830483, 0.04548039542691362, 0.07390893770441895, 0.06856465471848365, 0.05334463270921862, 0.053506564544213396, 0.02705892454081726, 0.05055274784324631, 0.06003957467093583, 0.02431151682450887, 0.03608641845564689, 0.06448149801261964, 0.04655967541639844, 0.018470904624630368, 0.07661018670806963, 0.01890785053312298, 0.03633785234283536, 0.0445522032978554, 0.007959828775886807, 0.009283147031261076, 0.017549578558593508, 0.04749030370505587, 0.0703017897303066, 0.041244909798185674, 0.05838536101603701, 0.028941671799628005, 0.009870953846632714, 0.05965086931903517, 0.009825591865416256, 0.04159282479855803, 0.04172958681480058, 0.08735100753725537, 0.06050042635310562, 0.029347935886753183, 0.03835416894646422, 0.023532451370791085, 0.01451856892315611, 0.03470893874163589, 0.048046916377760714, 0.041454932802627166, 0.06567371468390189, 0.021902809986063553, 0.07987503127585496, 0.0788454627317767, 0.05735928200245385, 0.11572030057469684, 0.07982467631659201, 0.02973621222941626, 0.11785876606741261, 0.07948228097971409, 0.1303625620541073, 0.13623107134574844, 0.13131962037615239, 0.02211080860316513, 0.028177058594601772, 0.06274750396128624, 0.07546755124724681, 0.159634996145483, 0.06443969259459166, 0.37464196943948347, 0.40052038887816094, 0.42657136196090334, 0.6501688315503059, 0.4660388635050866, 0.5503788926909047, 0.5545670647294291, 0.4658447981121079, 0.40845770328756303, 0.46664336816437785, 0.3489472885285655, 0.34980153785117213, 0.22915229651956792, 0.2180633423549514, 0.21402195276271915, 0.2789627051641864, 0.2974203066720117, 0.2984415631621115, 0.18792659254564395, 0.20810734029979477, 0.1431201476483576, 0.2027692702869254, 0.16826922073960307, 0.19128712915605117, 0.08065940571888801, 0.15462709470622002, 0.19517144008028894, 0.2001203527493823, 0.18216922729005738, 0.13734730741670056, 0.19962139968429843, 0.18169696472825544, 0.17327552871598353, 0.1072974089953688, 0.20771861196525637, 0.1024691015481949, 0.2144250988719925, 0.18162847646782476, 0.1891349736721285, 0.12545143284143942, 0.19646769149168847, 0.14564379448852233, 0.13855574983021907, 0.3001114203324241, 0.1281178708098108, 0.07198748193801412, 0.1505229931565062, 0.16628601828650122, 0.18635871699981152, 0.20961124750394977, 0.12948035052226436, 0.10955115539893027, 0.20291999042514833, 0.1296552483953776, 0.0797546252367958, 0.10017414727518636, 0.19544056676808866, 0.09119355900874061, 0.2703716419637203, 0.1305556774980599, 0.2636583828397336, 0.11707720316706166, 0.13247552447982375, 0.1583471257359751, 0.12249487737614302, 0.1794422607147886, 0.248227073780952, 0.2840800192807951, 0.15040576638233277, 0.210516533604072, 0.2840403665698344, 0.17318572788949937, 0.24664933102265482, 0.19379750735336737, 0.31006890859815384, 0.47802378814066615, 1.497259277009195, 3.7591181839666064, 8.043859956725951, 18.750196349236276, 24.252912998199466, 51.17232776457264, 67.3779413777013, 72.33511124887775, 54.14078535572175, 45.497395530823745, 46.57497652115361, 43.066067311071585, 28.27587039239945, 36.666069261489376, 42.880280325489665, 38.36813472932385, 27.95749748906782, 40.33833342213785, 54.813954291805146, 34.906847015503914, 56.566175107033025, 78.11239380990305, 61.750575727032086, 71.65316012597853, 69.29794157705, 34.22702966197845, 11.997387966802044, 5.017179683331521, 2.3814599408257395, 1.051230017215975, 0.4185347319129975, 0.41516400633319733, 0.17600821030716743, 0.3291134560300458, 0.15083977051319616, 0.12341170842128417, 0.16829456292813824, 0.16255561442625138, 0.20603839728620746, 0.1592195313423872, 0.17850565694032178, 0.1940955921647049, 0.1491448163024841, 0.17739735754026523, 0.20969252943271594, 0.1822642681579436, 0.13223458982763753, 0.32492044231584, 0.11835644742654217, 0.1672885669094901, 0.09587588074106364, 0.13331555521055577, 0.18875937608461227, 0.19874254361756388, 0.15390616000419663, 0.20803676828021006, 0.10946894650377574, 0.18980559171928515, 0.11202745034449524, 0.0855193525973347, 0.21012475623959498, 0.1554375697648333, 0.11777614348477895, 0.23193304246712118, 0.13475121930241585, 0.11859273958590724, 0.12431350882135092, 0.12280238506894921, 0.16716090601778802, 0.16605760151099774, 0.1740960242046464, 0.11966270394623281, 0.1626804101491167, 0.1707500432648005, 0.10851823138974367, 0.13428709259436977, 0.13069964074079068, 0.1699169226471455, 0.12570094767837756, 0.09066826017994074, 0.16938507376659304, 0.2213738534239031, 0.17363931322770734, 0.1232015475210163, 0.2989548420713794, 0.22257806703207955, 0.2537213491215821, 0.12082497424055492, 0.23055724048566437, 0.3788454632364935, 0.22409602428876588, 0.2270386446147196, 0.3768731851971919, 0.1850376443396653, 0.12169125880445204, 0.12073609271957991, 0.2879609287746491, 0.14544952991268328, 0.33039331315986575, 0.34579437706739674], [0.05876987203655224, 0.15997860190128127, 0.1014291448518634, 0.18435803242027762, 0.08230174501096049, 0.29290716013600754, 0.1831791916441533, 0.06924817368628518, 0.028472031173746915, 0.06797080634221916, 0.10115527607981237, 0.2509339994961216, 0.1902499533588848, 0.06737992272622163, 0.106143037067546, 0.07831626451544224, 0.05851948002894079, 0.12743375429342832, 0.08078820042071805, 0.07593194608606639, 0.047649692128142046, 0.01726165590357156, 0.04695521427258369, 0.050719180444796244, 0.06376035263641708, 0.07024905989847838, 0.07363951990320798, 0.058041092594184225, 0.04509683052498487, 0.04002316043742242, 0.08351377271596463, 0.09156099009898402, 0.0502763050157697, 0.048862976217342, 0.12188938446342946, 0.013758725573068425, 0.007644881411725956, 0.031103405297823974, 0.03814256780089871, 0.03108224786457516, 0.029884086351000497, 0.007053308795401527, 0.06121074307649847, 0.023785488296961112, 0.024674807209521536, 0.046023241499619144, 0.0601224155886279, 0.053203906187967914, 0.02398411191308931, 0.05739778175108856, 0.02004725501812514, 0.045336240662201766, 0.08560822645743048, 0.05010158334287906, 0.017552020463852153, 0.005910455957130199, 0.01754316065700785, 0.07890138715024918, 0.044151225217407754, 0.034360035487841216, 0.02818181025495212, 0.07147723673692635, 0.04094380660042648, 0.03504097656977754, 0.0129449860222878, 0.030016228857059634, 0.08682526437745941, 0.026235148280618653, 0.055164386473235585, 0.023100203496494123, 0.048765169772049116, 0.02796332580938695, 0.05999693804751, 0.04740198142826558, 0.05809370751282381, 0.06049879841626652, 0.21167606896450444, 0.20970444976081773, 0.8969768040603208, 2.070097783880849, 5.496478119204122, 9.299685705092646, 29.283709679880452, 18.799865322728312, 22.56539167896394, 16.277608717641524, 13.068852020848183, 18.94165704327245, 12.595522942081576, 9.870791627514748, 4.85009063636103, 5.611311879850203, 7.795731800217783, 2.6979736406956953, 4.679436154903905, 14.090118562021564, 14.53505458370332, 16.986684991467385, 24.944093458114136, 23.148754027581987, 8.882573016228216, 2.257308589835321, 2.00834607164706, 0.23774855379616064, 0.11722691206922455, 0.08750508314058666, 0.22407451253985206, 0.03358405353801866, 0.024032961509581056, 0.05708894872617337, 0.032398792945088885, 0.06423532331903135, 0.07804549073860531, 0.0686563324603823, 0.028562592342495922, 0.027754871369970423, 0.08939225647237994, 0.04729623448163752, 0.02006058303278781, 0.05294503358703467, 0.030979210953979246, 0.035581486074314, 0.07108224180316733, 0.036654874847661105, 0.0899071365054096, 0.0278276554684365, 0.02350717238450964, 0.041596881234117096, 0.01948745541965529, 0.047988655391119184, 0.05923555390308461, 0.06309196773555971, 0.04781980578216815, 0.06039079151026184, 0.030735213865315726, 0.0998916293704702, 0.056558520938720436, 0.03634544044372536, 0.0355997572713081, 0.059183992355340914, 0.02577532890192684, 0.02794215305437965, 0.05107886255568555, 0.033731950642240625, 0.017514853708205685, 0.06418997474435358, 0.017056524370526596, 0.02820195453692108, 0.00796895144665013, 0.031689837942981434, 0.06716398552300469, 0.0417356389094024, 0.06623174078882703, 0.03811750140401625, 0.0879516817569252, 0.07077795934052238, 0.020386970962487885, 0.036573240518449776, 0.09820320222887302, 0.017177008933597998, 0.019237417727708817, 0.07484824576925847, 0.06693969030053386, 0.07912071812297068, 0.029102383639603376, 0.08631599210803548, 0.0427594886071259, 0.09632422603786954, 0.024505982498428034, 0.07722265102089414, 0.018409853162724647, 0.010046196459311872, 0.0189365079671505, 0.032330151467073354, 0.058427944013308135, 0.05875361182035939, 0.22614987537024483, 0.2212764223616931, 0.15762012361759142, 0.49832018452786636, 0.6323819246984298, 0.5898512971978034, 0.41517923616113206, 0.0830832849286737, 0.06020630987721586, 0.0813086805564742, 0.12346962466835977, 0.3464809450651369, 0.3046711756577415, 0.11031745016695031, 0.176113011135209, 0.06245346026374929, 0.05561809055507184, 0.013900529405462646, 0.07843755921649356, 0.008294441617063938, 0.02714734257859809, 0.025375934708262646, 0.04045137294357823, 0.05388923312327074, 0.0687107936509194, 0.014388359831495872, 0.036624955283778335, 0.04142304056233937, 0.04121944503558259, 0.05423932764378767, 0.023568735210104816, 0.06833819912806635, 0.05284819241252638, 0.032173463503920266, 0.050647217975628954, 0.020556211276280306, 0.01351342805015344, 0.033573776468514435, 0.02096527541476873, 0.025755519783424757, 0.04154348873623437, 0.03078668539772832, 0.04042678918208807, 0.027160921487055963, 0.05571159924710951, 0.02031872401975336, 0.055445107901769305, 0.031866449937825246, 0.04070257700438942, 0.051934559784469106, 0.04153608066600658, 0.009481175971638051, 0.07778585588018741, 0.08831787944561051, 0.033489116092002204, 0.06736172047714073, 0.006480366958590646, 0.04915569075233033, 0.11710911838998718, 0.07326905510478443, 0.05602798206851848, 0.06749666686500273, 0.07386800562662464, 0.031276031720241716, 0.03151412227100903, 0.04237850159106236, 0.028129543906318086, 0.023999745852404067, 0.012992392500652181, 0.0794827636151064, 0.008471398351473675, 0.04252862418070436, 0.09813920324367863, 0.044368384330863916, 0.08901898013127428, 0.09286352343136266, 0.3720996606974833, 0.5985937087285904, 2.263714800919256, 5.573237922883803, 10.951070227930623, 12.371366350881516, 39.10437930014826, 19.766351061482585, 53.72856778483237, 43.258165390260764, 29.195558332627822, 25.026786827271987, 25.881977273571877, 26.66433911169729, 15.209093305372424, 16.909655524838357, 21.034622000109767, 19.058979057496597, 23.336590451578942, 32.783279726582194, 28.473326429244015, 36.40450992891866, 45.4132410787767, 43.12054118802471, 18.16357647219012, 6.282658874988557, 3.450065322460667, 1.4049885830571576, 0.3272067857605796, 0.23112601480416714, 0.25115878501486394, 0.02533339576104716, 0.04767334509280421, 0.02380028528521859, 0.09837721143999408, 0.07628338892133006, 0.04714898472171157, 0.0443643547083822, 0.07476638927454911, 0.02552202384498331, 0.011786211961730114, 0.01463331931811427, 0.07238983131584621, 0.010823362014977442, 0.006706625281367452, 0.02829964606902532, 0.06623616111615012, 0.04033483947897631, 0.031690083091117205, 0.11729232831707886, 0.05030296870597428, 0.04675850587626619, 0.026110950106334303, 0.02130446275846372, 0.03618964497300406, 0.027375408868876197, 0.027249667027424422, 0.06397262793935596, 0.06760821692765721, 0.040115960498130133, 0.035350981709216876, 0.0642842073894797, 0.06438752200694815, 0.09655474189428553, 0.05571168351678118, 0.06382560417536767, 0.061633068196956194, 0.05205279396426293, 0.07760436199004613, 0.07455539333844378, 0.021070543556444107, 0.03739942420995043, 0.009406502508828718, 0.04381760924814209, 0.035250356060362635, 0.0299274699101525, 0.058010977677880764, 0.010719426866290311, 0.10519881837911184, 0.030073432642365658, 0.015520729714133328, 0.05873858117528501, 0.08900231005804193, 0.08548709263484325, 0.0410207869454978, 0.03480091908826463, 0.06965643726289272, 0.11175251671022947, 0.020701264279083382, 0.09351934832070144, 0.13939882959088973, 0.12624801106510625, 0.13982521880778576, 0.027172424297239033, 0.0530902570444009, 0.034238591399644656, 0.05505893064001876, 0.06813029818717511, 0.09867293670052484, 0.11314575485284291, 0.37535859872737243, 0.5089518914539968, 0.5497469007968903, 0.8948700622685495, 1.0259410871132728, 0.614895937183211, 0.6371968179460495, 0.4229593493284718, 0.5506999754617291, 0.4095576829727619, 0.274734114326777, 0.37735192886283325, 0.3672631944139158, 0.1899472413764846, 0.2824243194153232, 0.20219545510988082, 0.27100164202913163, 0.30499115526195497, 0.2480638357660463, 0.18475011621992435, 0.15383682904704926, 0.09796618228597988, 0.1050630599380501, 0.2060463492788615, 0.1238370634194824, 0.1529565787002925, 0.1779591298151401, 0.26625704500944386, 0.13258509037475433, 0.18897188887480768, 0.24208762983400978, 0.13827202150658255, 0.1752156923494993, 0.08225443908163617, 0.22256058490564748, 0.12025990012672641, 0.14720451477314198, 0.20425492927672403, 0.18287482491183668, 0.13216167357900452, 0.06509659766790367, 0.2116292609923309, 0.1552352919093063, 0.0849200803185663, 0.17098682572043714, 0.1443927882299308, 0.20173379520495094, 0.12276981101040879, 0.09746534464460227, 0.1421756072029952, 0.17340636121169214, 0.15411502621587247, 0.19101976447047728, 0.14871854965965595, 0.13032444151899508, 0.13404096386605693, 0.25589182942865357, 0.13997892668891337, 0.21240270336068448, 0.23059673997904026, 0.16772460883423207, 0.18853154153593127, 0.14718525532272556, 0.1251376738711711, 0.08359170684050168, 0.16250442443115098, 0.1118753512480086, 0.09752930532540045, 0.21422225411140153, 0.158675700846699, 0.21755777029020174, 0.09785144529756039, 0.23483152080687786, 0.13315231719565007, 0.24594724208356875, 0.11422433770231663, 0.29924126702450937, 0.3325187474969895, 1.5520177709479488, 3.4124635208037595, 9.291494815580307, 13.003357264303393, 38.323804101636334, 36.682186280527425, 83.76587852354973, 64.16747746929046, 53.92256036881478, 63.14064802662019, 71.68577071159118, 53.75778944261613, 33.48232846106253, 28.737217610882176, 39.41144597145819, 30.633918931407315, 36.97865470763176, 67.09025121504261, 74.4628401725523, 76.26294136047363, 75.12341437801238, 64.6502467124693, 20.81421813657207, 4.488638341426849, 2.0144186361182124, 0.7389833657972275, 0.1761751868311436, 0.22605912459473457, 0.46678157042591806, 0.11300396729981708, 0.1434426246992042, 0.19455516831048075, 0.14237247647777682, 0.11740462914589914, 0.12889496741756318, 0.12115970869819004, 0.12869380805040562, 0.11962480557661866, 0.15826136985373113, 0.1475695709908201, 0.09861351892111764, 0.2353620213726836, 0.23462369647477907, 0.13563704676926136, 0.16360518552603262, 0.06365700737543165, 0.23132588714361194, 0.3095455786153194, 0.11629511932692221, 0.13899018297032004, 0.1920309085999766, 0.09124775972938345, 0.3368849277255997, 0.08345532786822127, 0.20580812657792724, 0.1416214651638462, 0.14415021414958662, 0.18760695002011715, 0.16049468469235206, 0.09909403224986407, 0.14953772747708907, 0.2506088258157815, 0.1417733650774725, 0.17735709195896504, 0.2483982484667532, 0.12049085265325925, 0.11735978235881175, 0.15375026111160556, 0.10938644649520998, 0.09265128643281999, 0.08200991913796433, 0.13954340570395993, 0.15298645612933945, 0.09748248203146843, 0.13619986092371328, 0.2159242103657415, 0.13690165874938812, 0.2256403502918059, 0.11881999956864504, 0.23154566244732952, 0.21420423572342243, 0.18856797667761005, 0.08229671181329797, 0.15822301949224166, 0.24081809956940914, 0.26184318346842644, 0.1786662136474925, 0.31043231006591554, 0.23995569907128814, 0.1893650758410654, 0.244515469718364, 0.3017572223419144, 0.17445092209644858, 0.1743468720345728, 0.14486970860631238, 0.13855430958492143, 0.271760406152856, 0.20949310142426722], [0.07365011489920079, 0.07540615696099497, 0.19528609279903675, 0.23296096392216223, 0.28177728155447596, 0.35118585873034697, 0.13932001446523976, 0.061353327360965555, 0.08594070095568897, 0.06419211212966232, 0.1231713023697657, 0.22042342942328225, 0.07939041937671362, 0.04425082430844346, 0.022657590452581648, 0.07868972471764973, 0.011909114489812526, 0.017859011047309446, 0.053788741539803245, 0.04465352225628111, 0.02295502408918354, 0.033786741250585166, 0.03125718021164498, 0.05805944039997074, 0.01608286683838214, 0.02898387941381624, 0.047028260756163835, 0.02954149566170189, 0.037932847401187304, 0.017160289064650575, 0.058587765276071534, 0.028901145748433568, 0.0522567801958611, 0.03158497391268611, 0.030016552529207645, 0.012974425823607994, 0.07834487023853487, 0.004889559049549843, 0.03361567764753296, 0.039181080421492945, 0.013993164757266642, 0.07245432059731215, 0.06018477514566434, 0.0535025195999732, 0.0390362476689681, 0.06155856614631992, 0.05882452857951003, 0.02893117064940593, 0.04767963850510217, 0.018258797861034834, 0.004133706538742709, 0.07608635876808437, 0.0006659047510531251, 0.03568379711660166, 0.04396533015214148, 0.05994457210744581, 0.0397194410494018, 0.03755782054917466, 0.09488147563270985, 0.02480087846878075, 0.022349014067121094, 0.06427270840973624, 0.013147877705764147, 0.05041446131203444, 0.063979760217931, 0.05069026445609428, 0.07151577095951765, 0.048386576780748945, 0.09491877645374307, 0.045518921988625685, 0.04656866928862949, 0.07092170041775511, 0.03950464148675242, 0.01218605048639039, 0.10721866281763201, 0.07980961502800066, 0.025188551517203454, 0.016438436972337867, 0.11899488211999978, 0.21682275489213007, 0.692191941122855, 0.8958749244770697, 1.8053641506741125, 7.03666982150847, 4.466505387137014, 14.498870718863703, 7.821560117506213, 1.3296886365259848, 6.266699241053674, 13.895245405935473, 13.350384062336339, 11.85198276273666, 12.734411128105657, 20.1164637842486, 12.245381782131812, 16.674544734339563, 12.178196484042752, 7.3098565301587515, 17.240142668447188, 4.503393317422559, 0.04234758994331764, 0.1937428393190907, 0.15991860189505164, 0.13263120886779603, 0.03788279504665444, 0.06544403386332336, 0.013633960493720107, 0.059488159904797236, 0.08342513634312539, 0.0834977844609849, 0.07128815091545544, 0.04544961784455565, 0.046978292671302636, 0.016490565425145532, 0.015963022916337416, 0.01614755147226876, 0.029174773202788447, 0.05309185816816265, 0.04826983647240747, 0.08946416914583215, 0.10057180819492187, 0.05744233742476471, 0.018924719789215637, 0.07904661443805502, 0.01957067746608969, 0.03802161783941331, 0.06189874748909666, 0.06233304656381088, 0.03181829556612478, 0.06393609703668664, 0.03160479835294668, 0.012303599017491985, 0.03759558102296245, 0.07188183841325584, 0.007053027736894306, 0.013063579305796134, 0.039248630224216374, 0.028381969877368504, 0.0811836320245939, 0.03731619258741698, 0.05079195113672365, 0.01872539520263672, 0.045934854105355284, 0.02115494729350171, 0.057182166304799824, 0.03112885665388838, 0.037225399677070885, 0.05403840576388663, 0.03225685600491782, 0.01767514228460289, 0.06923050003787203, 0.02342162526122505, 0.09252865107790118, 0.03863693582975576, 0.014038233709852061, 0.031039088386141007, 0.010566096283465384, 0.01996088818076157, 0.03129214446450914, 0.039077846243256525, 0.02315709127053138, 0.11073800945474256, 0.016358807878268343, 0.058296004520548936, 0.10113869793713094, 0.024899360986666817, 0.061802335323825966, 0.10468403793751233, 0.12385201745576437, 0.04441408530598687, 0.03844600373638734, 0.07584488019347191, 0.08057968660948739, 0.03212301278366678, 0.0668959926453329, 0.1301004986969694, 0.13176554483511757, 0.20314630811973927, 0.27266451247757484, 0.4044007774322264, 0.5097476423027054, 0.7339156022475612, 0.5832120728108191, 0.017218333631453496, 0.10662161219384401, 0.06283966433857718, 0.17874793990725474, 0.21009127819730392, 0.1883932933091156, 0.14740313072839092, 0.05993144519086327, 0.06905844435095787, 0.07183156772366456, 0.10514015902674968, 0.014698573729894577, 0.09600565603543675, 0.023200612725509752, 0.045002904315028465, 0.029279055006261316, 0.12877325136815349, 0.029082022937795812, 0.005988479139388449, 0.07801726039859556, 0.03199816151942698, 0.049889200787630775, 0.04135049586634963, 0.029738257684174086, 0.03162326298714165, 0.015453063083001444, 0.06353184009992308, 0.015663843556878068, 0.055323173517301205, 0.12370777842138084, 0.08554670959711076, 0.023779976294345917, 0.055697598990293286, 0.02591531806355042, 0.057583630851079384, 0.05949028579878712, 0.058919910356522574, 0.05103513425696762, 0.03489890556421972, 0.05254940280029851, 0.016098916380395813, 0.06516129379310916, 0.018653810031772144, 0.00634171940844446, 0.04121317460592236, 0.025908884840206276, 0.053962700955209233, 0.03401649101907688, 0.11121385730803014, 0.050667132431220625, 0.04493406748459224, 0.0697677881426869, 0.027238756020162857, 0.011286721677489338, 0.07165290069796386, 0.025456124961736704, 0.01813022149426322, 0.048143577521606806, 0.05833193787463731, 0.04552833720921509, 0.06720510912278006, 0.027025942540457173, 0.02085649475996052, 0.10035482911212791, 0.020629161998869914, 0.062432549893856056, 0.12644155551829647, 0.06533394702860425, 0.03532204273787718, 0.09035899814578796, 0.10013212735253958, 0.0471860901903241, 0.3974329013257258, 1.5669056172332458, 3.165330665726816, 5.9736702422941885, 11.602839692946404, 13.026765969491775, 30.897992503258493, 28.41743265428851, 23.126004280582553, 25.53706757483944, 25.247963397733628, 28.11916974283034, 24.778090907681374, 32.287415650583085, 29.929063127886867, 30.026128061356086, 36.944510475281746, 34.87750376424482, 29.57032511311193, 30.169578944483114, 5.930980145931245, 0.10985284082351193, 0.4372201373259868, 0.42523012586659004, 0.2420375583272788, 0.07428111087891363, 0.21769581933415708, 0.06937273192189394, 0.0864848915127016, 0.051872521984360875, 0.011181116457127277, 0.09187792067325885, 0.013621330576678439, 0.052744280246476975, 0.006798120598579127, 0.013641869393928398, 0.023904764356331962, 0.04440640910498558, 0.02338311785171109, 0.05898261848356455, 0.012988453851111475, 0.02704330209282137, 0.014607831572873459, 0.02778572747634063, 0.028618629758937225, 0.02312305781449522, 0.03091467379201805, 0.05658107839765088, 0.028939093913762804, 0.04398627882643093, 0.013248560811212708, 0.08871996835354837, 0.024397674902913072, 0.05725060476951542, 0.043474030305421164, 0.045325894644784356, 0.02334474067714426, 0.06237421995930134, 0.021798351982368097, 0.022222820233793992, 0.021316712504372965, 0.02181127588565071, 0.05491266147263589, 0.05515969035425975, 0.04668170173141745, 0.02200171768274759, 0.07187164178298366, 0.11505434800299907, 0.03675240933174088, 0.07346092182542048, 0.05592363706279186, 0.047130636915925055, 0.03606728157929836, 0.016310791402394255, 0.0172001332975924, 0.00224390744058896, 0.01857440118798085, 0.024247132880132527, 0.049241469617212014, 0.03080987487919629, 0.07908144845597206, 0.05046259844675661, 0.04523779070305248, 0.10234246721431133, 0.05413602451763807, 0.1603610329930821, 0.018445292390101863, 0.04526225572091438, 0.12080410600549753, 0.17735831769964389, 0.05214600771244976, 0.06110393126765567, 0.04963851383616848, 0.11469672283818645, 0.040213399221219366, 0.039009312017550396, 0.05276583413022661, 0.21755329633672393, 0.3756575875224606, 0.6934890199092127, 0.9382059401081455, 0.9363362565636636, 0.8314543457761888, 0.8316262559063974, 0.3695763509360052, 0.2883543608890426, 0.2070159867646233, 0.3132287148506411, 0.25352510803889844, 0.2745735422978478, 0.2409578186850394, 0.1954561796399855, 0.14185850808937706, 0.16712082429758965, 0.13029703089306433, 0.1995899134706105, 0.1726920761528515, 0.13965571419365946, 0.23287525400519374, 0.07640510497073974, 0.15629319804570369, 0.09909721151474984, 0.15047013308973084, 0.16906340876894613, 0.16165739165679102, 0.1156617331528856, 0.1592193168377684, 0.16056153352462477, 0.21581629922072734, 0.16004039455325375, 0.1060243240827995, 0.11006088732110877, 0.11113824442990365, 0.30391452593668816, 0.16900785207267732, 0.16425303544007963, 0.2208907583788518, 0.061580303891171376, 0.14988453548041084, 0.16734565578160748, 0.17641264344415358, 0.23135556538979854, 0.10502873153816308, 0.16952551300487212, 0.16430350531253124, 0.23076508013952166, 0.07585269429029957, 0.08839910008734272, 0.16860036990575253, 0.14757965270790363, 0.13395301697234954, 0.09357360266749898, 0.1832341048265657, 0.17474715297500934, 0.13370900264670774, 0.23929661830827115, 0.24410930522266897, 0.20491128276673057, 0.1472061695230584, 0.10562583578810578, 0.12858615737528573, 0.212760420456048, 0.2592753486767892, 0.14743593461330862, 0.20579979154131106, 0.18382126525525125, 0.08663018774842063, 0.4682726839617376, 0.20422241650521758, 0.20763109408078656, 0.184984217367826, 0.17531422657832024, 0.1943636616511691, 0.21473415406240573, 0.12132413414937836, 0.18506491706976969, 0.36581556402867843, 0.9661740328996413, 1.8770373756847076, 4.128159284591675, 10.559616704140941, 25.406760554159842, 60.41982927630025, 56.81402967822168, 58.51405551356655, 59.79441127469463, 74.48092229904668, 93.08249612008372, 70.3979310681743, 71.06329056524461, 66.68607450300648, 53.821500501325055, 92.30580406804239, 76.12945525876938, 63.684594477376635, 53.36977681806011, 10.869712425816445, 0.11530984598662584, 0.30082225799560547, 0.2677175456718091, 0.18338419677269074, 0.17604611633766085, 0.31764156515559844, 0.1700064783254939, 0.1499378245564238, 0.18837130658568876, 0.14622193040145984, 0.1846223021106374, 0.16624458825155614, 0.15283109349829538, 0.08003085355965361, 0.08298723282472742, 0.12841767931897796, 0.08133737821011774, 0.1255425283565156, 0.1589560277399517, 0.1837961988583688, 0.1785040328339223, 0.08529174021415173, 0.1355029660607538, 0.24966797791421416, 0.1579545363182983, 0.17578419087634933, 0.0997950716484939, 0.11180435021918629, 0.13602385988398907, 0.15654225322988727, 0.21410340323082863, 0.1475052502486975, 0.11762675633954427, 0.12211041615134287, 0.1433074255023272, 0.11146692679293695, 0.19716639432214922, 0.1686987815605056, 0.08344163787701438, 0.07621519177431062, 0.16052027202902303, 0.18567555043245518, 0.10227357292728079, 0.1712604876487486, 0.13766756281256676, 0.14976992872693848, 0.23857300229851278, 0.13041303192655887, 0.18374880865937282, 0.22296650425320674, 0.19256291069811393, 0.0878196158596585, 0.19837960180255676, 0.21410456768447356, 0.10460089441509017, 0.15859239644581274, 0.14496225202756544, 0.1480032227212383, 0.12374553123428939, 0.1689568612604372, 0.20119921905138802, 0.15358895363826908, 0.2482374925767222, 0.17674294991358636, 0.27001197900502916, 0.16001549669571463, 0.23797277240983902, 0.33064462064254674, 0.3169505232043805, 0.09294628390982267, 0.18193469713291816, 0.17078347534181612, 0.14591699676407924, 0.08688070616053958, 0.1924754234571611, 0.23073639780763658], [0.19534163417354708, 0.11642743803320393, 0.23100232224791284, 0.17536507949473398, 0.29857872354407466, 0.37217967092029514, 0.22531687732665773, 0.14622707851231098, 0.04028518932060369, 0.04034882824447367, 0.10351371605910602, 0.10818193411274303, 0.09314321447163822, 0.1658703849440621, 0.018311253816430128, 0.09075259879952477, 0.02342536568551535, 0.059441696672189626, 0.04934554649216514, 0.11060515448691384, 0.05999105449225153, 0.022011669164883996, 0.05171565399054558, 0.09998376676512342, 0.0381009194308952, 0.05339843889458045, 0.022950820181699052, 0.05531310712197616, 0.07651776586088442, 0.05233920742607406, 0.009142685767954156, 0.011036777831313592, 0.019316703997432225, 0.03730105085959358, 0.07423630239622248, 0.06477961346747414, 0.05837619094358337, 0.03404187151200829, 0.025542991671470866, 0.018818633848681085, 0.01000439678694332, 0.003454987590591754, 0.0254172153560625, 0.09660223168471167, 0.03208675958787001, 0.016148085818595944, 0.02740679932157359, 0.012528398900382943, 0.008450374983611607, 0.04310033261595715, 0.09906150415659913, 0.04518386577406237, 0.057774490166095004, 0.08140927556181148, 0.04125690673507991, 0.04429827196403377, 0.11641227715318242, 0.021911122040041996, 0.04537433438423661, 0.050685204445354404, 0.047966645685054606, 0.10384353989314649, 0.09623807178990496, 0.016920382885502714, 0.048129236355664275, 0.062138245726424846, 0.050227532028070385, 0.04323504917744187, 0.005679750493952945, 0.008052953466352436, 0.03586786889260815, 0.10054347060260274, 0.010660798157445125, 0.03778700341260241, 0.08526480456273403, 0.018265991426643827, 0.0275732453296622, 0.024829099232691432, 0.020671618591633537, 0.036899938713759184, 0.028083837185535702, 0.07912626459954247, 0.05672405338695934, 0.023152795432495977, 1.109702015115369, 2.712781813836867, 7.54155142653373, 3.3253143391301556, 5.663537258102048, 2.405677634862162, 15.194842353943857, 18.133760575325258, 19.45347732113254, 25.961491561705067, 23.067978697438395, 14.647990407482272, 7.308138532023277, 10.54846638633359, 4.801148281943414, 0.044308648624968146, 0.11120076486540419, 0.022871897803739678, 0.03556026543881144, 0.05653409805569438, 0.004673287161670986, 0.01449192917319916, 0.10268531454306457, 0.07169934860881298, 0.05981122301290593, 0.018078929992512833, 0.08897539738926197, 0.06619691443178924, 0.10480700271023859, 0.014158931819932356, 0.026373191578914563, 0.058470469553984945, 0.0447620309498762, 0.023490283976218874, 0.03932782456338887, 0.026363383738263965, 0.010755460769418749, 0.022248723581733725, 0.028655030426659414, 0.054266650169607134, 0.06834893968076476, 0.07563049048786202, 0.0429677764224189, 0.041839420840504675, 0.040793549945397724, 0.03009110820599862, 0.040869672271993854, 0.048763043878059235, 0.03863416642190949, 0.03992797018239095, 0.01019991200131875, 0.03748862365741403, 0.01582700592060123, 0.051650762512919404, 0.026293847852596836, 0.06093582476399118, 0.026551121244988134, 0.05977643112982473, 0.09535173870502942, 0.027158468090478453, 0.04307429328741085, 0.061527087593511234, 0.045852396231625354, 0.014738983910290465, 0.02410379782949965, 0.022872200408469767, 0.03313602233726171, 0.04267460989555524, 0.03226320304337048, 0.02281910860009732, 0.026678452718882795, 0.0687905970299917, 0.05487847479901487, 0.048154318074305216, 0.052775402568400874, 0.0610776812649302, 0.058404409792274244, 0.032391338909585635, 0.05817608111688207, 0.06525652618297646, 0.019260254808731617, 0.025828775025964267, 0.08544967690062139, 0.09473277030572777, 0.05331461738434531, 0.05601215086156323, 0.010746692893125359, 0.04515743957111432, 0.0418277035257028, 0.12465041130781175, 0.020639333731284546, 0.04958241321747342, 0.06560813755758348, 0.18047081036192758, 0.14309066858503128, 0.5256194825614653, 0.44468391746763264, 0.5995073145435703, 0.475727362978843, 0.20487714588882464, 0.15955751401282128, 0.15694092538568283, 0.15517519997252574, 0.21696674877837782, 0.07048447105673052, 0.1283535577597157, 0.05836759926751257, 0.036262745082738905, 0.09583938431235091, 0.06514584179967642, 0.07419729319911811, 0.009869244512951663, 0.022115949053137053, 0.03875417409524803, 0.017016172604334932, 0.08709757033014491, 0.044209754334822784, 0.027628171918613297, 0.02274836229550983, 0.015389996809854865, 0.01517971908117855, 0.04454841882350945, 0.06171780901270048, 0.052723737598787394, 0.031827122814232306, 0.07554212990667551, 0.08468497559548387, 0.036132705488031915, 0.08479693168473822, 0.036148306868609884, 0.08452144646716696, 0.026793183961642847, 0.08098530718275616, 0.033351166639477015, 0.01901622899177094, 0.02428365803714241, 0.023969527514230822, 0.018869841080759803, 0.003936938531208603, 0.0394187668608802, 0.02628342905682662, 0.04911217312779158, 0.01567624843559198, 0.037039267124548074, 0.028027104544303114, 0.024370417494567174, 0.051920314379517114, 0.03852260103749652, 0.031213149308196964, 0.036388801020239635, 0.02859979357209898, 0.03932854851647731, 0.06005902947377294, 0.04890036130804689, 0.06699566834516103, 0.062384696211665876, 0.051401466011039676, 0.03127514305824955, 0.023538409619622176, 0.011798947215861371, 0.03422833348233854, 0.05173361109149072, 0.04937959526995978, 0.04206529803453915, 0.03789756522183457, 0.10307516902685167, 0.06913546683086504, 0.02535469109012235, 0.04633712687439496, 0.04279340714997342, 0.018543958769089753, 0.020175726047807166, 0.042208594780775814, 0.08191479400040642, 0.07953249038227143, 0.1836662856681693, 0.7685802228027775, 3.6459783969386934, 11.05757728699715, 9.461545252030897, 17.604960356989217, 23.042559777536702, 46.18475560219058, 44.1573844417449, 44.917500557438025, 54.14602956464214, 56.14915263268256, 41.01111796594436, 23.246934875365227, 19.428023099899292, 5.129854669494014, 0.34270811525564043, 0.1299714741687621, 0.13222052445334773, 0.06375993511849834, 0.014602780180622735, 0.046179067613857414, 0.02890855381866136, 0.16922388886732442, 0.035455142853841666, 0.06898346732580854, 0.05139793051526912, 0.027201305811984405, 0.015726066175698033, 0.03348795546879692, 0.01505361334796274, 0.030130284027226513, 0.023965660685433016, 0.037607524333701986, 0.025371679089843266, 0.04651772444166484, 0.04365322210134999, 0.06085344349905368, 0.020415900357728525, 0.043984229541233474, 0.0403278948919427, 0.04202620839820274, 0.04938136876350449, 0.01949941788259293, 0.041164761679547454, 0.025385955138312235, 0.019799174680825204, 0.01371737310452567, 0.04550891304989496, 0.05424390884957487, 0.0415391450177037, 0.03407461410989204, 0.052059914751519124, 0.011088603679391166, 0.03993563106163375, 0.06413495430963174, 0.030218027907633976, 0.06990572993433283, 0.02482807650531252, 0.031060006416913484, 0.04777238493965519, 0.016145678387293895, 0.01974472689682678, 0.0366956077425951, 0.04304506320265993, 0.003993953906765749, 0.019962703809142113, 0.010119559911770687, 0.06212896840166181, 0.058024043307429364, 0.0342886054497813, 0.06183934503144795, 0.04892860313937549, 0.03223494205984377, 0.10857152046575662, 0.045418441896477056, 0.07001887345986982, 0.02288556672752865, 0.02203747292139357, 0.04321442226008062, 0.03807290742594389, 0.02147512225013587, 0.02332166227842531, 0.06930870995406183, 0.03760982259747483, 0.05590551908338263, 0.07897616499253819, 0.04084681603877295, 0.020000590687437404, 0.11676877616874634, 0.12724116745014347, 0.05835548358699007, 0.051418431028122866, 0.295222369773734, 0.34206650129729704, 0.5324855915481045, 0.7598551555025963, 0.7958758742578569, 0.9206570108090678, 0.9436431418984168, 0.4211900845891045, 0.2576984026499333, 0.24540961690006718, 0.23193437546010942, 0.3729306515907088, 0.32357362910143794, 0.2413174969654891, 0.13730756277518888, 0.19302933566993286, 0.2328762652412538, 0.19233634785538722, 0.19961015351357, 0.20504399983873292, 0.20667691624933676, 0.1413899687148871, 0.14721467309901792, 0.21553733596397986, 0.16236081358886537, 0.19121062761593252, 0.20204660422619314, 0.19551331447737832, 0.15948740164599112, 0.19501200186148768, 0.1642408393203251, 0.13324285346654155, 0.22219284738023437, 0.12427496693788037, 0.18851753744867542, 0.12248776041932645, 0.193974090619914, 0.09721385330081948, 0.13245690854326372, 0.12250266849033295, 0.17709231665057523, 0.25557877525927564, 0.09350897549020667, 0.12172409333288671, 0.10206767913675117, 0.06963560733223154, 0.1867420367536045, 0.10708887986237965, 0.14337608230210122, 0.12930893068832736, 0.18024939563005202, 0.13706134211632515, 0.08997025448949107, 0.155582697461209, 0.12513385109242894, 0.09737866945684918, 0.18976906464705545, 0.09051398539374914, 0.10200610865027675, 0.14242265523681719, 0.16987406768866126, 0.24364910088479522, 0.20211452558155985, 0.14676778336926816, 0.10789500354158302, 0.128921213589849, 0.11292990958017689, 0.1941748975866264, 0.07316722669788907, 0.15513830517809238, 0.10110875156017081, 0.27056359295402804, 0.11983995370927358, 0.19749561294672952, 0.2677650431231145, 0.1270401536396915, 0.0983808120532382, 0.1291461829696932, 0.08416719208922117, 0.1412681913784435, 0.1242100563080561, 0.16553823986361105, 0.08452276413839671, 0.18567686810368494, 1.2753088964569954, 5.434863077056024, 16.028323461932523, 33.87228658122401, 59.933980972536155, 55.80490973687942, 68.62281537825062, 59.89664393086588, 65.48669607408586, 79.00538413755356, 84.00587266491306, 73.66587731146043, 59.113499579891084, 37.15530649308236, 8.198573925802785, 0.6715697735067337, 0.31648808188976785, 0.15033957638567494, 0.176440958053835, 0.11852291833248832, 0.1448416851100422, 0.14730396830747206, 0.34445200716295554, 0.14926769680553867, 0.179891693856447, 0.1309347378029939, 0.1517691270958993, 0.2044929068295225, 0.20867914832647771, 0.06678985882430308, 0.11617063770010588, 0.222545140573094, 0.13331069821311584, 0.10846349440755383, 0.13622077512404612, 0.12670482163347546, 0.1267486418627443, 0.2050192092335032, 0.14415717022793909, 0.13432916614317125, 0.1719878881328529, 0.16784471609900076, 0.09825692797500281, 0.17867010537414782, 0.11634443240660815, 0.13468381888683767, 0.15257166548361703, 0.13515323160156129, 0.10556350687458631, 0.12443066664761114, 0.12624968113678117, 0.15049126179468247, 0.15287974008148716, 0.11030074945020099, 0.13177095341586298, 0.17800506444707995, 0.13474464626802554, 0.21166990961759322, 0.11986185616302876, 0.13762201122458906, 0.13007163250398251, 0.1918107196087799, 0.13399939593528548, 0.09503270904984205, 0.20234055216273955, 0.11315274157471235, 0.06802237172040247, 0.11703568120156566, 0.15717565472568237, 0.08838704186341456, 0.1254663026080497, 0.17744208175328471, 0.11144431953829144, 0.18826364058881037, 0.1671127956961432, 0.12055056154607766, 0.16854550268861557, 0.12450692303959401, 0.14086745078525237, 0.11406657721606955, 0.16780753019115618, 0.15272365732779428, 0.28636403381824493, 0.21042405146985285, 0.26750969069619335, 0.1546755727500685, 0.12439432343648327, 0.09354285189821836, 0.19301312524945508, 0.26578452197774766, 0.2417411589093747, 0.20707701332867148], [0.03733024263994829, 0.1665969427314497, 0.06739003508682213, 0.13767280285396885, 0.12644087370004387, 0.16714106434054915, 0.06993449653588957, 0.05218377967755641, 0.12065432815542146, 0.03728568696627214, 0.024908919848742026, 0.021041742480930783, 0.0964199334022499, 0.04299548582264012, 0.08957779530676142, 0.007537018626012029, 0.03670755488377425, 0.06391293819873564, 0.022140293412150878, 0.015693450939931696, 0.1031573242958515, 0.024093028548504078, 0.07109709624801913, 0.02796602052366061, 0.05867170552993494, 0.027046421985893, 0.028317028604027246, 0.039420559506623015, 0.08476880093615863, 0.020626955665647984, 0.05021446256808216, 0.10590070047445836, 0.013147406561690713, 0.011342503412085916, 0.06408518540763086, 0.02727186825547007, 0.012185273864757151, 0.034556272740085284, 0.008038312568509532, 0.031711636974866834, 0.02750001881541985, 0.049109078132577484, 0.014661146504353854, 0.061057165430317965, 0.00943707324744713, 0.027980331046086167, 0.04148691314302626, 0.042228436458014676, 0.0238412901413657, 0.028956828849209897, 0.004483314114622772, 0.024938061833381656, 0.016917301296827295, 0.017288905651038213, 0.04887775022296175, 0.07454895819987982, 0.02245569755623658, 0.022185643902048472, 0.08979641381771335, 0.01177083753469971, 0.016988271682132638, 0.016044804717474166, 0.014903965732833792, 0.052988562702892296, 0.03456340118822071, 0.0555671840125034, 0.05559420776403239, 0.02593186747793469, 0.049229250514819745, 0.054258908851132284, 0.0033577506837900732, 0.056833512029580535, 0.06957214460858414, 0.03113693696626973, 0.060207585413609786, 0.07245283438673905, 0.02046892704862741, 0.042862967933498086, 0.024330632633439476, 0.06469398782017731, 0.04045226543601002, 0.09780610821420148, 0.02732084234124951, 0.0855927668031185, 0.09353090092659959, 0.06156896578989202, 0.05255903252550671, 0.618469093836123, 1.7285292090908175, 1.1395028353698793, 28.678050618017878, 34.293129444122314, 32.90438682802262, 36.99775665037094, 24.671537760765325, 13.189857140664133, 3.382282843512874, 0.8819022774696351, 0.09510446084483017, 0.09903419312209853, 0.02990349327334233, 0.04284146001502391, 0.028824400975398963, 0.06266421871259809, 0.04338589572017232, 0.08743457240803588, 0.031122172536749034, 0.05251307108048951, 0.055138381618645885, 0.0157725389844047, 0.08355206179042017, 0.1012151841554911, 0.006273391068867979, 0.0432165136801139, 0.02752692382332058, 0.021976151413494543, 0.045540563972486604, 0.05722961779082975, 0.04316596719886988, 0.1088733514470439, 0.04155956126088577, 0.12264346778993646, 0.047794398476159385, 0.019707190503756848, 0.03740285245341159, 0.004230242235691197, 0.06181668415064774, 0.05530533132954471, 0.010091955848639051, 0.0694264500071445, 0.035423181665640686, 0.04017966453947368, 0.04376545015181746, 0.04448436238172074, 0.07912182128958165, 0.022236180807193442, 0.02530845959911183, 0.03908786284286649, 0.016677948616204724, 0.04506421433160863, 0.08478495006960246, 0.034609738016320814, 0.05254436960263599, 0.03190141802112902, 0.034036957057974035, 0.018012356951892856, 0.07893370073889533, 0.020258287343406872, 0.0454764730567413, 0.03303104530899756, 0.020120439397531654, 0.0850962805411508, 0.00831643600137003, 0.02604612183096188, 0.023548280662526528, 0.03421940089714143, 0.10519599151467124, 0.12342331465333702, 0.036556754306319265, 0.0419594093616451, 0.06305598841619588, 0.05688908404760784, 0.07685071533365596, 0.05543077439670602, 0.027990893483342185, 0.003838726298718323, 0.014332475632639423, 0.12546707635685322, 0.07822327676319307, 0.030776312567233562, 0.01994611225992201, 0.05100051091322976, 0.05856509673439207, 0.04489913387524505, 0.022537613422760082, 0.07710111883258627, 0.0718875610900502, 0.23175089740224425, 0.009809094161966877, 0.19792348837419865, 0.086216684130411, 0.12222461687821536, 0.14761861593973252, 0.04118394835161106, 0.08818499383426483, 0.07648766626633945, 0.039229734665563995, 0.05341316310448512, 0.0796022656704149, 0.03011815302494553, 0.043731600556883125, 0.019900955207225297, 0.05252011142851365, 0.029493471524948557, 0.009430775047099639, 0.02733592278203897, 0.03311936758578785, 0.04455739737398202, 0.06336521597639208, 0.018943151864673824, 0.02436005807061109, 0.04228866246018199, 0.017345364415837873, 0.12128191504387126, 0.04511475698241303, 0.04337601701638872, 0.029281460522343556, 0.07398806692611787, 0.0228798306441956, 0.011049648108441504, 0.0448506405096381, 0.018088038777932525, 0.025396205394739108, 0.074888143628355, 0.017154664064066547, 0.012636180768059868, 0.024388746148155584, 0.042278553930021105, 0.03256957309560911, 0.03684021066874266, 0.01813846268510867, 0.08300490647314057, 0.09195106674826915, 0.05541525728579971, 0.06165126661559748, 0.03997631799129229, 0.013776105235240633, 0.028820693109845443, 0.005212298485510533, 0.04871760720327016, 0.04077174325263308, 0.055885914893400286, 0.03614548000416929, 0.019647079414778182, 0.04570996516474313, 0.06659845175642161, 0.022806881836825804, 0.02134835385086556, 0.01693299077751656, 0.08803500147956995, 0.015012416012224652, 0.028482112890830445, 0.05770886324406151, 0.03396827344512267, 0.030836067425327438, 0.05517223121358022, 0.004243665053734496, 0.034385967564078114, 0.04163029032849497, 0.04561983492045153, 0.020446766040197784, 0.05679976585651598, 0.12777089426714566, 0.07498898378182804, 0.02086397560854112, 0.03490618722994001, 0.043521489452330336, 0.1139007498239798, 0.061165172336322654, 0.031887756758219296, 0.10026875147295576, 0.1040812876195677, 0.1573560837536089, 0.7661560754622183, 3.746849745512009, 10.068002516223538, 27.916493031286425, 36.33858665343254, 38.919259117495635, 38.77204864255844, 24.232402924568426, 14.616088790278281, 3.6712590532918132, 0.5111050581739796, 0.07819033498244901, 0.049908448746728326, 0.05086585563877898, 0.0540720293628833, 0.04775879453987845, 0.026976164062357238, 0.0420642867984791, 0.02498524135819847, 0.009780594733573738, 0.03064979123131883, 0.02346732049068857, 0.01910314549722018, 0.05483577305811548, 0.020859660618307612, 0.043834738974129005, 0.015057089471919163, 0.018655403494654645, 0.08316002395604888, 0.035124009009450674, 0.0480948428383037, 0.05537061734245189, 0.01447732466453266, 0.05255404529311965, 0.048136234568852576, 0.048810993321239955, 0.027729358726872072, 0.052907755748639186, 0.025640880471215616, 0.05949095612572086, 0.04394556125325542, 0.06341038068996803, 0.0842245031268366, 0.041368058432013764, 0.06006425419341653, 0.04750726872213906, 0.03554555272022563, 0.08513936532601234, 0.009347825919488266, 0.08708280781584402, 0.0536103694579534, 0.04458101203424796, 0.022125753063348033, 0.0229359561607482, 0.023860689402828296, 0.0227083571841039, 0.02473748086260692, 0.01297823519581148, 0.05978131877078165, 0.05638100304490617, 0.033549135250429955, 0.02365983647084044, 0.03402674127550375, 0.05260706240791948, 0.061660953797400005, 0.009725264990852486, 0.010249640683703607, 0.02815891188689538, 0.005918696190365741, 0.040008493684112065, 0.039112806665681066, 0.03090861786697661, 0.08557207476828368, 0.05283980758019513, 0.07219576592286749, 0.05773546181679253, 0.025629216782568444, 0.029642383695670196, 0.08486549655396132, 0.02856264405343081, 0.05213527865107021, 0.06124577627727582, 0.03410824920020757, 0.018312358898260904, 0.06888124055319256, 0.035024681879628095, 0.03811347561197416, 0.014329227419840473, 0.00934269025756587, 0.26315913866123847, 0.3670150432134829, 0.23177214868126378, 0.43433817584187756, 0.6508500369325761, 0.33238486597134226, 0.5592503747151745, 0.17092227515193725, 0.2945797445793306, 0.21076070114729867, 0.1454656943678856, 0.10364343006644519, 0.19303809971578662, 0.12274533450122803, 0.1330729658084531, 0.09888226256495523, 0.09131843134039834, 0.0908345012595096, 0.08256052185090319, 0.12334709656575035, 0.18485819590428185, 0.17175648361444476, 0.21551778540015223, 0.11444435049329074, 0.15198236000874352, 0.18145866541852876, 0.12677174707454059, 0.30549055265803493, 0.13388869623022695, 0.14663203258908566, 0.13272032021514832, 0.25732773866864944, 0.15863324425393538, 0.1202636386357969, 0.2581392402850813, 0.16600141662263102, 0.13330959504650486, 0.09132013971646948, 0.06933626613669819, 0.09092981791904858, 0.14522023979694615, 0.1252484195415051, 0.08036649200103937, 0.10624200030560456, 0.10890771815132712, 0.0957163735743492, 0.21815858240569794, 0.14698483139997529, 0.21178296887345854, 0.320335743167708, 0.12747352191757771, 0.14748975995086855, 0.08805696522035907, 0.16860717276652015, 0.14368712932111757, 0.18441231741059214, 0.16652880687146418, 0.2045631724139375, 0.2450807353541736, 0.17449068205971874, 0.10924554760417632, 0.0999777682966763, 0.13825768034064, 0.16993498700040002, 0.14367075036129645, 0.1450093817566672, 0.14958934648142708, 0.17963724541327647, 0.1646845880895853, 0.25828127298624287, 0.0669546060324196, 0.10828165577784662, 0.19238954500084926, 0.17565832263039005, 0.14424899352654336, 0.22321289345141382, 0.13284707712309976, 0.22728961501871386, 0.12680158619919132, 0.11814899847752626, 0.1486213024585478, 0.24466421334974228, 0.20434946452658023, 0.11346806336434619, 0.25390744720014835, 0.18332885458104073, 0.6201740378333677, 1.6281759811024514, 7.197436498057458, 31.78539541459853, 66.57597357226958, 75.52923064078055, 70.48137557122016, 75.83513629051947, 63.040639354336655, 36.855370690745694, 7.805969676663799, 2.302337399413509, 0.23745881934319776, 0.2625744910009446, 0.20706840250040257, 0.12860155574256374, 0.11620344158502356, 0.13092710756726805, 0.12912198991304444, 0.19277220591902736, 0.07266793655411852, 0.08910765480850974, 0.09280331658139344, 0.10694986554763972, 0.2430219966317377, 0.17597015105908917, 0.1080295515637244, 0.21480397531582465, 0.14207857450650585, 0.10016136126773012, 0.15317135911074378, 0.24069512713580365, 0.15027407586814898, 0.20617925021196568, 0.10603891805775705, 0.2445194074102948, 0.1967946424960129, 0.09146745842430862, 0.19516734917077327, 0.12855234225430798, 0.21492883232572388, 0.06883437895486433, 0.21410265246466284, 0.2213054877375403, 0.17135273995659045, 0.22942992678332716, 0.19658772214766473, 0.16783101844691461, 0.20052683900200552, 0.10856242700209541, 0.16558942985871147, 0.12214677468422921, 0.14832473450130032, 0.1313394007663573, 0.11852807410421873, 0.18360512120829475, 0.09460329378564512, 0.1127838166130166, 0.08501305274905697, 0.14985165498670072, 0.224855033560626, 0.14016985112140257, 0.16486576788367766, 0.08270859898578736, 0.19739474981061875, 0.26619624827177296, 0.0626419025713638, 0.12423886887488828, 0.12093613359836802, 0.09540047721877214, 0.1873285843119506, 0.2255905392549692, 0.1424556583045952, 0.19341377391209527, 0.17563158616183266, 0.1376580480005472, 0.1170297823245487, 0.12395736986711142, 0.1201903853084772, 0.14380126110007688, 0.2128988219004485, 0.29819883586418244, 0.1466736158416156, 0.19470803349489169, 0.17786465585231784, 0.16731481308177595, 0.13133901772239517, 0.13840967218481726, 0.14426099046343757, 0.21147559907647873], [0.07779678795486689, 0.07736649935043628, 0.030063042574892604, 0.02785488797892486, 0.05821021033390876, 0.04070952159142302, 0.08788068838898214, 0.02137001881736421, 0.021291720801063126, 0.017551669978626797, 0.06137570478923379, 0.03429988609446633, 0.055206004199722124, 0.038915539025178844, 0.06090919171730357, 0.03298719060577212, 0.03585094217992118, 0.026554254544598442, 0.06495681726523946, 0.10903635963557229, 0.046496706819462205, 0.07879400460590279, 0.051628385084651174, 0.05604994197886798, 0.025951027336920944, 0.037879466394623446, 0.09643023728483147, 0.0478403982255728, 0.008702366199764994, 0.07949752612940728, 0.04531784689113979, 0.02643149853083155, 0.02714876175647782, 0.030561804117995407, 0.04500618317134438, 0.03163552997002919, 0.04711452991731706, 0.06293921746433744, 0.040615013154644164, 0.0172120344734961, 0.027705820675398556, 0.07145525001349949, 0.021371593128048608, 0.008943302767171014, 0.04510639130227989, 0.03246437007140729, 0.016683768969209447, 0.04801052337091777, 0.00316697420203127, 0.02256410091274208, 0.027013434239873485, 0.030315049112804478, 0.034431557456452044, 0.004867534979336685, 0.009331978433164618, 0.02027396341755746, 0.06546235868647214, 0.07535862886617262, 0.021303886277300697, 0.018410420067788615, 0.04640374588029039, 0.10506405585235166, 0.07361830692858466, 0.047486500078511816, 0.03084511109327357, 0.04272461628481265, 0.0557576296400399, 0.010589803831892149, 0.06748711374858696, 0.02200067197273095, 0.05309608697350468, 0.04892173899157394, 0.06167076355327041, 0.07067301295577519, 0.038866624311213537, 0.05529134256404735, 0.04282303177000534, 0.027975246137488755, 0.12022021677224867, 0.039593063354972875, 0.013990865535883894, 0.037548688781117244, 0.0378862769162703, 0.008647901178788274, 0.05022213876908345, 0.014131938711920334, 0.022533154791040767, 0.04466460754854545, 0.14902892252129896, 0.5440307204281131, 0.6552427238033665, 1.0773395194161324, 4.71193838504053, 1.4018543641413412, 0.3283085427697628, 0.08206395898014307, 0.09963289849580297, 0.07836118791132204, 0.037807419655784484, 0.04377444785448813, 0.07890157867223024, 0.04857997184679393, 0.04107121085267394, 0.05499984227841901, 0.05184983429048331, 0.06364924690475868, 0.005869398911243245, 0.017629741998990218, 0.03089261237501858, 0.05262028508549256, 0.01704246857233586, 0.05142395452205693, 0.033532714155773004, 0.032939942133042126, 0.03151773054513239, 0.04941422627457688, 0.0704160440833338, 0.031499003525823355, 0.03890671369229113, 0.028206568301445054, 0.0010590417420439002, 0.07588460185234586, 0.052611999844591466, 0.03588070086533985, 0.041142349777322625, 0.044575473218555414, 0.04836713346923071, 0.045000644355651834, 0.01452840357688406, 0.06396131282071434, 0.04977787672091396, 0.02750476856055039, 0.0685516695281671, 0.03129070230399168, 0.03174245669206064, 0.03715855084479817, 0.07367010213314526, 0.024087692746111465, 0.08212307798525981, 0.0461356649025073, 0.017260548906520973, 0.04436825409591679, 0.02472126469646971, 0.08558400275726473, 0.04020557363307284, 0.027620059047495166, 0.0043505290523171425, 0.05801601853642253, 0.047919604056064165, 0.06205892115230523, 0.03837208391257352, 0.03395707707010931, 0.08519361967280989, 0.025807360953260815, 0.027436686326719584, 0.02206808387962801, 0.048936486184116335, 0.04135636793028924, 0.016690648438769485, 0.013889306217371939, 0.014319392766112523, 0.026187022637215354, 0.030358913392128966, 0.038830928444381685, 0.05049205835788481, 0.06518377081280755, 0.03309404454945076, 0.048798643983900554, 0.024135490886927135, 0.03157545910066655, 0.0539849941138058, 0.04919915858115401, 0.04193291038034424, 0.051175473903816555, 0.03988004372184796, 0.03416926427293689, 0.045025687769896565, 0.07798977316387239, 0.054962353765844345, 0.08736479711989242, 0.009300345705161172, 0.05817097897130636, 0.058321679957331195, 0.05977185758491678, 0.053240257059975024, 0.012776534779057389, 0.08386493209869632, 0.01265743587751903, 0.04810122818115258, 0.05818971748193426, 0.02599217774977367, 0.02928991238736818, 0.03380091004674474, 0.030869239032448783, 0.045452000378000165, 0.03628456326682241, 0.02528607834040398, 0.0765847525889835, 0.019025094544274673, 0.012359628773054049, 0.011807810853145296, 0.026823542110862273, 0.0916427776457802, 0.05395285289494261, 0.0633968630685441, 0.07739137422533766, 0.04465377889573575, 0.02430480014863274, 0.020606903314229943, 0.0330072314658713, 0.06354061946753534, 0.036297766792197386, 0.019036338799783302, 0.02648445627381725, 0.004107798402753449, 0.08611596655100585, 0.01836815116656644, 0.09388212925724446, 0.053534611023121306, 0.04455932791555121, 0.03274809456460419, 0.03411939960994548, 0.024995098994564147, 0.05763590486059266, 0.022012804890231743, 0.04330990745896294, 0.09558735670702112, 0.03794692426679596, 0.05854431276900634, 0.027633486653587995, 0.03987168570259406, 0.05152099487942554, 0.05352136919335012, 0.0582177869434799, 0.009342190385195277, 0.027700609362293637, 0.022778954101546157, 0.052717402051653595, 0.05319677007895324, 0.022999233108073957, 0.010624577520385144, 0.038838876606596094, 0.00025585568085173896, 0.06315594373811638, 0.03890816159846802, 0.0492345939780916, 0.12105655495918567, 0.041021572185620185, 0.04881145297399452, 0.06993039796549468, 0.029071404959165284, 0.0535822157267361, 0.044970782248363386, 0.04600276779984275, 0.048779365381286036, 0.05260458794392405, 0.03537109534766886, 0.022867487052515633, 0.033970797704833175, 0.041132754526071014, 0.038260032062328635, 0.05380554567842234, 0.021590343789167462, 0.08388898725951872, 0.2980467827329713, 0.3430348977206215, 1.0472358186398785, 1.5097094928064656, 2.339010089635849, 0.8562410286357327, 0.8128192876615833, 0.12538051608228876, 0.0350754045610947, 0.06332495805597113, 0.039079370758225845, 0.028806192980658625, 0.04853380355803717, 0.07655175718208475, 0.0353561413113869, 0.03703375512193288, 0.0653377161811917, 0.076209461436637, 0.027583939917085153, 0.011034638530785039, 0.0922969401243233, 0.026278641007299867, 0.01751977965355881, 0.07392121809384516, 0.018964948981339415, 0.009549055192168922, 0.02280225658098296, 0.05004437955757303, 0.05847215111697874, 0.028387412932070515, 0.05065808110239525, 0.005552158550164032, 0.019056293474990996, 0.041871355215628306, 0.024113770379053972, 0.046823171357954704, 0.02448553944216861, 0.011090328334830703, 0.07090811001797838, 0.010443854506217666, 0.03456310624436986, 0.02499486150730762, 0.056694528358357574, 0.02842866868201283, 0.014300348777924816, 0.029070175388046814, 0.04858553747556383, 0.06109754592480679, 0.014497242950563951, 0.04086146363988519, 0.10937415078402528, 0.03342535076362472, 0.07994490615542858, 0.17505113666336383, 0.04030295106912813, 0.06217808229848743, 0.03525625110693997, 0.03540393753698276, 0.02133535525401033, 0.042656744725161025, 0.042748602497721874, 0.016116957751012618, 0.012680640680745486, 0.03832705709482393, 0.028260544941370046, 0.023619936696524103, 0.033494233559336395, 0.058296954469575044, 0.013049627887085082, 0.06257685787615276, 0.052249261042884285, 0.02071669712031801, 0.061001524464377475, 0.033541914871743614, 0.018091635560737025, 0.023132900129102414, 0.020218477584421635, 0.053741427949599685, 0.02304224319936287, 0.0332890062653009, 0.03316072484238013, 0.024703234817171772, 0.008371997485688377, 0.012826904102468924, 0.032238270711874774, 0.021301396491546786, 0.01809755742039171, 0.025602712055608153, 0.14697419809958628, 0.11399435044656839, 0.22042194321270914, 0.16850943526914045, 0.09564644506862087, 0.13163042224703297, 0.17286965533369975, 0.13801945763970577, 0.10666272813274015, 0.18263818035202642, 0.1620502109008451, 0.1548316555037614, 0.11947374069882978, 0.11241403363284566, 0.16947312791260982, 0.1400610053491208, 0.17685793971102085, 0.14805301843631655, 0.22121271448990992, 0.2672244914837422, 0.15913143123109497, 0.15971807071999197, 0.18389199049242083, 0.09224465462349116, 0.13878801236710242, 0.12862116759342532, 0.22843295528042704, 0.13270646934547733, 0.12435075601622944, 0.14587844721972942, 0.17771065685777895, 0.16839603893458846, 0.13242153060292045, 0.19538530118523106, 0.23800683267895253, 0.08969322177431277, 0.0998887642016334, 0.19002597989334216, 0.12767177015062303, 0.19463510192450018, 0.1472676250963442, 0.16514771888332982, 0.16702520120288097, 0.07310443813161505, 0.10873020025751284, 0.1455945350349911, 0.09564829900139764, 0.18930463150383967, 0.06737881955961067, 0.30759226891302294, 0.1976824924349785, 0.19514160861651744, 0.139278247351608, 0.17477151457100146, 0.12353838872044318, 0.1307900237940973, 0.16729785189513238, 0.11950547206065348, 0.08807949586621217, 0.1552528659662893, 0.08532593837909161, 0.2173762534174227, 0.15439953594919176, 0.09327889630390752, 0.1453134267320556, 0.13936558137497596, 0.1296801615746752, 0.22793348127555466, 0.19021272148576476, 0.09234793859744266, 0.1628773407109322, 0.33229183225381764, 0.16695081406543333, 0.1032021557611804, 0.13416010586004104, 0.09645471379401223, 0.12238846776346046, 0.1010972755630651, 0.17318945107681138, 0.18065119342457864, 0.15735750867714807, 0.11887172582529246, 0.12105119234371571, 0.11792694023179433, 0.14853724729149573, 0.12785611388784263, 0.21472767295856632, 0.19120331913713487, 0.44861829989860136, 0.8724407851696016, 2.8016548772012038, 6.116744577884675, 10.209740304177808, 4.13986804985231, 1.6200006584967337, 0.2245546658072741, 0.24618051585651216, 0.2907332783985523, 0.10664539922389293, 0.13454670447014994, 0.13623047379716752, 0.132753660361613, 0.12085305902385905, 0.18510231748223308, 0.2494846990392093, 0.17396056453787512, 0.09800606482331792, 0.10217240335600031, 0.18172111181962877, 0.14565835015908365, 0.08135224797672803, 0.16503056871794886, 0.09546447620396653, 0.11758580127911222, 0.1478604392539109, 0.12628608563494298, 0.14029817084871954, 0.14790951484634032, 0.10916595106884357, 0.08376622933053202, 0.15527025616217047, 0.1990946376275632, 0.1343628740118396, 0.11498938374702009, 0.12135695335605454, 0.12785533247815986, 0.19365591898320184, 0.16124373482119653, 0.11702387578665249, 0.13814370177926558, 0.14606449933302018, 0.13150643857736743, 0.14890156806476657, 0.12618782719777477, 0.15648006221219418, 0.15621309589234092, 0.12970449252715036, 0.13925102058677905, 0.21593269861994252, 0.147807625152411, 0.175633363485817, 0.24855535777826465, 0.15881327491614128, 0.283100652478395, 0.12512129491135, 0.1796246509278013, 0.18299813442412885, 0.0808849803081924, 0.15407578719239082, 0.14250597495946193, 0.09887777328971895, 0.13543170456203724, 0.10134251562938576, 0.10854158941055499, 0.11441124017320334, 0.20369893330479824, 0.18854410537788946, 0.14058009120485476, 0.18854317075062185, 0.10747057550977315, 0.09462706549393554, 0.15713321345467723, 0.09193957542940494, 0.10536951809040002, 0.24302147569194918, 0.13293612718341813, 0.1385881859929331, 0.1376033033574781, 0.18604342585369466, 0.10963629074995557, 0.20615531762521114, 0.21670131463437312, 0.17283865941628335, 0.14474725711249536, 0.14086193495219754, 0.16103053255186928], [0.05865167999159425, 0.05507424473762513, 0.031476959345802184, 0.03385691490444926, 0.021723648833651698, 0.060801732564164754, 0.04552779711722847, 0.06719393956084406, 0.030651463218213573, 0.019522760581645756, 0.09026570395836908, 0.022796018710059505, 0.03403305383999983, 0.034087024734265385, 0.01782479756061108, 0.02448698543312569, 0.0573841147425194, 0.05905983248545278, 0.0635319856566287, 0.048751046941165006, 0.008555802088531276, 0.02715151967300523, 0.03151924548400266, 0.04671586925284036, 0.008574969608396774, 0.05111105357026381, 0.04397760671112807, 0.032541089946584355, 0.024555812687462857, 0.02266456951357184, 0.026556340218972296, 0.017595507444873933, 0.11939898583917849, 0.060573806084932826, 0.021076626294562896, 0.02429497507100384, 0.03410531125301796, 0.026000824967218984, 0.04375351833239679, 0.08905600516065475, 0.013224026845437626, 0.04859199176632589, 0.020328051140231472, 0.09125364328464193, 0.0958107632674998, 0.05403482430284062, 0.03280923604184101, 0.06253703279540905, 0.05622142693027855, 0.07382190245534144, 0.057770368613062374, 0.0803269618641465, 0.027447149172545444, 0.034793989822989514, 0.015064189191757432, 0.05597884518905513, 0.07500887142434236, 0.041151121484055635, 0.0346669532929457, 0.034345644526183605, 0.03517911371384417, 0.0469088084965704, 0.026473106681219032, 0.06120700456742799, 0.02904000876080846, 0.005389954275151174, 0.07034307420854607, 0.019686622958209728, 0.051484061780595974, 0.03963324849704101, 0.00614734614388116, 0.029048537234625513, 0.06368886897220247, 0.01765907933605054, 0.054568297289792574, 0.04265045131286306, 0.033533920744253744, 0.01659593315825107, 0.11192574451166777, 0.07179684095805691, 0.021041631398181763, 0.030077990865515127, 0.07342434878791533, 0.05039069343418364, 0.04556987066602996, 0.05649230795942488, 0.06586932757448766, 0.06730497634458928, 0.026982210411299622, 0.07312483905303864, 0.04141331124570101, 0.08412058329990796, 0.12641432875346753, 0.04362744707313757, 0.0429287250904787, 0.06530959309349138, 0.1138459285721183, 0.02708140156051565, 0.036869858271412315, 0.03586639034291429, 0.039766233699816855, 0.047512838181348584, 0.03718522985676124, 0.016324646102504867, 0.02973799338384021, 0.03322221488962251, 0.059404905299626054, 0.027311561186046853, 0.025873202379913102, 0.034278489258741184, 0.024205206803256468, 0.12947901752927612, 0.04387275991781105, 0.03341024734019753, 0.04856795575770159, 0.05451972348495357, 0.08103540933300411, 0.07015846234055297, 0.058303473877810666, 0.028462502955188675, 0.03702242851197239, 0.015668694808658575, 0.015961632466754846, 0.07536266614953357, 0.034904283501448176, 0.07206123322248459, 0.03065648492455723, 0.0484483847544799, 0.08785152342170478, 0.030186114599928263, 0.05911415578016351, 0.02043664410349823, 0.04254925875894485, 0.025741640185456605, 0.03986091450637868, 0.045153513370502385, 0.049878950531203906, 0.05937744870841984, 0.08742740182506462, 0.05655362946732391, 0.05726395385159601, 0.07833630537554141, 0.05228221048450759, 0.024217295670701612, 0.016812119340043397, 0.023007704125296687, 0.07108692260038468, 0.03526969978045072, 0.02586999630194999, 0.032656650479522445, 0.04195637948390457, 0.10005279894798033, 0.02800527486890074, 0.053130059142506895, 0.06543587502692977, 0.06744624295782659, 0.06642293335208971, 0.010091248174918997, 0.0285223018633382, 0.02903152242182724, 0.026685205783935326, 0.070469057367694, 0.07827787584955655, 0.03335499707909842, 0.04415356561601643, 0.04399680487451054, 0.03638259187761334, 0.0489082558441066, 0.05599929973663342, 0.009584261720339137, 0.028565246837153554, 0.025974601777570865, 0.07191543136873553, 0.05156840806105926, 0.04846040850445148, 0.007641520679763128, 0.03911293690062819, 0.04458867674393039, 0.015386101252759899, 0.044135279097263856, 0.053153666141893596, 0.03125966808217908, 0.01608988611898836, 0.030955276452004913, 0.016742257867008448, 0.024933926873810353, 0.02590105159118051, 0.06545639852242124, 0.04780985046959212, 0.022584622493013743, 0.06377316162651105, 0.037120851658044324, 0.02460153473000373, 0.03691185521142137, 0.04268823093884895, 0.03871372848328564, 0.051990963007894256, 0.02354256947705102, 0.017531843623146415, 0.03381205279560339, 0.016220136387874524, 0.04819824172544384, 0.05517959714897218, 0.03755408970098342, 0.05091987249832, 0.015142524554844827, 0.007718704516939338, 0.10897663542099538, 0.06536092864529741, 0.06603330103380066, 0.020212113308990677, 0.043906789543407584, 0.02330439848705165, 0.0423070102659685, 0.043564275462901404, 0.060313677099803766, 0.0369596284543795, 0.09254178182492334, 0.012171088789229192, 0.0171176447803455, 0.06879935341496622, 0.05298346821819583, 0.09518456299819293, 0.009914310592707368, 0.029467436026841886, 0.07895218644050822, 0.03779099856112753, 0.002906170101918941, 0.04411663634762649, 0.03324885942762898, 0.017873733341994307, 0.027549697702089627, 0.09217536963161924, 0.014182643198798743, 0.059205714778433886, 0.06258377565010902, 0.0184105426418565, 0.0214336060302993, 0.03222404062868126, 0.00944481552353189, 0.03289609509069593, 0.02014170791352949, 0.025923065127684705, 0.03678626658755445, 0.04184116369053241, 0.06537359973956501, 0.0790003427274285, 0.06363796626007365, 0.05296529278219227, 0.009967831410317412, 0.0027888083047488887, 0.05052149528637529, 0.05174606768113952, 0.04541307162012785, 0.030851184255293304, 0.03127534798676929, 0.011919963252430242, 0.039115587564846205, 0.01355266420080537, 0.019576277568816178, 0.08913088259437392, 0.017972328857849204, 0.021292791408937306, 0.04398703725347596, 0.03218365630375282, 0.07222128431162528, 0.0822935478701707, 0.06660415145057826, 0.03992192957910799, 0.08472268244311695, 0.015571963759289395, 0.06070615543473152, 0.0320223986261314, 0.03813894037457724, 0.06758545645542684, 0.06858837280061937, 0.05516740485965725, 0.10279195398212441, 0.028562676612167593, 0.010614234375797454, 0.04704008915371472, 0.06706296150842983, 0.011011101436921427, 0.04013808511738335, 0.053501397281164126, 0.0252874247399309, 0.04968461700745168, 0.03207506334048606, 0.022735815690529924, 0.04645895783699328, 0.027974991413253932, 0.03667943562651354, 0.034062532903326136, 0.017145285232653542, 0.04193272268880279, 0.06336693201334247, 0.03806937193017333, 0.028765931229798064, 0.03709283582265339, 0.033684146755765525, 0.06403720149049355, 0.053275278769433505, 0.019084698100003506, 0.051807998228938355, 0.027107971404949506, 0.04929352146122725, 0.02177472966122291, 0.01224866955571117, 0.02053917539606412, 0.023004808312942906, 0.06490369672856985, 0.07037603897192786, 0.07598140472245794, 0.014104246548677405, 0.04349227851977752, 0.020752492578580015, 0.03692486721481528, 0.019608359415865233, 0.027036374742766062, 0.019925219127007072, 0.01320442840111472, 0.02364986583650593, 0.030347627001784505, 0.02176681214252547, 0.012803022269039385, 0.0666965646368842, 0.0028228266784290396, 0.03087540604023924, 0.07886270737095226, 0.07425627430840846, 0.011028562495935588, 0.04176577297790397, 0.013451434300100852, 0.05312238677194523, 0.02563651568526703, 0.07067663655165704, 0.024347534448268916, 0.07905801382636832, 0.031300699751403545, 0.08766872718209222, 0.019593933980251034, 0.011562289249512457, 0.05937897322338916, 0.06377636387403454, 0.046451806406220125, 0.05877073771590668, 0.030969843613885106, 0.07183122298409862, 0.0484327603912642, 0.044581142269195094, 0.06810167714232399, 0.04864914958635646, 0.15762199287212666, 0.11947416204718814, 0.18714637796003974, 0.10568610392510892, 0.21322823970788912, 0.14527570456266403, 0.10750644374638797, 0.24734083262662737, 0.1001026559500925, 0.08131165297762041, 0.11959194040466702, 0.1937776656761285, 0.12830685703985154, 0.14784945355307672, 0.1321448809317043, 0.16563148808575448, 0.21391485367090474, 0.18745881925907829, 0.15154618018817517, 0.12410156293621949, 0.18403504975140098, 0.10826106333444196, 0.13006918102262482, 0.1493237897633545, 0.11319277732963524, 0.08339853777039437, 0.09555626119817458, 0.10058735211890552, 0.1714767389480145, 0.11512207017550546, 0.14530228781363658, 0.1881668530404568, 0.23880483582615855, 0.15535916832666244, 0.17063488492802267, 0.14161328334481488, 0.13878076517533872, 0.11128045333128785, 0.20722342805275995, 0.2475451023107575, 0.08947722328406188, 0.14719812559985346, 0.09773051831871273, 0.1411569094465625, 0.21204990454979483, 0.1616173865453851, 0.18546113774420755, 0.11984784441489367, 0.13165037117658124, 0.15412778924069098, 0.10896465380585964, 0.15252905567326855, 0.15420727852371433, 0.11923803076628717, 0.08234515921362946, 0.1373361684982815, 0.15238095555574666, 0.10609828221100955, 0.1936340241903259, 0.12280658323077426, 0.12108703759769279, 0.1223206613212824, 0.15765251381502998, 0.14173426394981725, 0.1791457234010581, 0.0669747771274659, 0.16104496564836274, 0.1857135483934995, 0.17144450196816077, 0.14128547432201524, 0.21658738203827413, 0.1679638274494679, 0.20484328480257144, 0.15568647173143205, 0.1524679678221864, 0.09087293589067075, 0.13037909423151325, 0.10466722230757437, 0.15601084868033088, 0.12827295764920213, 0.10925317783990215, 0.10149822299999577, 0.19372141950072783, 0.08373824413865806, 0.2161407834219356, 0.17312116199924102, 0.0975464044078704, 0.16561308665381325, 0.17187360313630876, 0.17947756204633944, 0.3047848018186708, 0.16200977678020156, 0.25490691614968164, 0.1245480313176109, 0.09175951412368206, 0.14924871314677501, 0.18111505966273048, 0.21002370924238237, 0.159652033940919, 0.13270052450318492, 0.20176091471747046, 0.18071474807877697, 0.15090373885487357, 0.06058982881386915, 0.2013670382720809, 0.11252084161124884, 0.15185901985293435, 0.11984065084928468, 0.14979190012860685, 0.13727990700112236, 0.1023366449460868, 0.1982977836122436, 0.10909259048921448, 0.1295810451190318, 0.07921739841901487, 0.10298955870131332, 0.1378159540434999, 0.17511128988717833, 0.22279675449094466, 0.18155686256866302, 0.12798762054092463, 0.08282473791510829, 0.12756965063031644, 0.11090543030971482, 0.13656674043065117, 0.15783373957439778, 0.17154386357193993, 0.13217941617533085, 0.20881154364155186, 0.119305009833507, 0.1549763541908995, 0.0694432043500485, 0.14241903930181457, 0.08754671235839206, 0.20319081782813997, 0.16043093085529345, 0.16386006297844072, 0.14663917252853995, 0.1863892072991979, 0.10112773521893448, 0.21090425070255034, 0.17380103438852296, 0.11328185037259134, 0.1782617192234724, 0.12310163433393165, 0.1041208407390983, 0.1587036936994522, 0.15612196207286852, 0.08460783054150882, 0.1606732904310188, 0.19761342194772538, 0.1281501384331815, 0.17189477780653586, 0.17398835820776803, 0.18527706213776143, 0.15014834551801606, 0.13238797595183696, 0.18655330333257877, 0.11004315238566169, 0.3588925193875067, 0.16323196281108165, 0.15249976047104405, 0.12899472738706297, 0.2284672606976763, 0.12477496188254127, 0.13934186329284023, 0.19230064815811573, 0.1160269808925448, 0.18373884951635716, 0.18150593304345686, 0.09395398830454196, 0.16691479261123365, 0.10225205351748776, 0.18375948792503727, 0.15811627280087243, 0.15062574086891067], [0.014637721450849166, 0.06823358982200585, 0.036330428950849085, 0.12106816119123852, 0.03248496251481195, 0.04376433166344801, 0.035487261090067126, 0.03600525527050899, 0.054183414716634064, 0.07193243852065456, 0.038770671798697406, 0.0334065739486006, 0.051342186127458854, 0.04106402494794419, 0.008856014709078498, 0.08207583334296942, 0.040248976344422954, 0.03372556146895213, 0.02854578628865702, 0.017687160288915038, 0.031277006567125364, 0.06888810470099412, 0.04483917600385124, 0.11698177159433404, 0.042391498272697774, 0.02973330109530399, 0.05307098993310525, 0.040084661975983656, 0.06041837833641518, 0.011129839319525468, 0.07868765628025418, 0.06604788734787895, 0.15728342797487013, 0.03999884097626613, 0.04860503441323677, 0.015435941975503681, 0.09733720877838713, 0.029705530408048825, 0.023156422858817444, 0.021967601872259573, 0.03701368361831673, 0.05621972238464702, 0.03228592904164426, 0.035451055774765636, 0.017335206089961915, 0.036542340362023924, 0.04086509489664628, 0.006942259562727545, 0.021421994052587018, 0.10713995494429143, 0.012824444960231983, 0.029788516882446506, 0.08114905847657113, 0.04389426017540597, 0.018229609911119746, 0.014818957743925915, 0.028236528084943854, 0.060771445278078325, 0.04082371465741627, 0.04079711225424563, 0.007390416210382096, 0.07141017340003483, 0.02199886592044946, 0.021756981319237142, 0.0032937959880538045, 0.05137482913391245, 0.020501344059143337, 0.03793314617547778, 0.010293303864947971, 0.10002031681999084, 0.04690834118293659, 0.057015837125119664, 0.05734997020373422, 0.054075810006789626, 0.027829436622860453, 0.04841982499666272, 0.015858654927973066, 0.05438104624890032, 0.02290814908431663, 0.0257935234901285, 0.035345879563641165, 0.02699905285431493, 0.06825629666808151, 0.007856568263377994, 0.028405676468185363, 0.014549935435605867, 0.10750628286792387, 0.07685337365875322, 0.06695823728918068, 0.07719985990514679, 0.03490252149922233, 0.06744454990351392, 0.04881853162641487, 0.09712703255636078, 0.04547340870504418, 0.01509722003022269, 0.10144855751986466, 0.06338547134111006, 0.04289093397317394, 0.05267917043379238, 0.10163247990872591, 0.007226557185452793, 0.04509060606060009, 0.06902030083320795, 0.06760032622203713, 0.0664064318182007, 0.025617273471828912, 0.06697319132546264, 0.11487273919966914, 0.06042540336268083, 0.032067352665528175, 0.0029365304057606526, 0.11007329028460289, 0.018981276230225642, 0.02867484912126055, 0.05022993754415263, 0.011436545492840872, 0.10886917626785655, 0.021341543329218705, 0.005542266918646713, 0.061008645251633666, 0.08981690666968785, 0.02619976459461595, 0.042696654075576414, 0.09188147532122751, 0.0841003662395862, 0.026725680124194875, 0.038106998338574366, 0.04526783667144276, 0.004340761431282567, 0.04941390834808831, 0.013355996981713802, 0.10485566461518889, 0.00938326514686548, 0.037745439312270576, 0.025671441633734974, 0.025448965870084304, 0.028099112978745854, 0.028341499367548574, 0.050212351995850765, 0.06950080650107515, 0.0639155428976782, 0.06689148804833812, 0.008343052768689251, 0.013237544466861555, 0.012160135647131792, 0.02883291795789715, 0.11043692923962109, 0.06132973951377696, 0.03389082961685715, 0.04100608571823086, 0.01891945293473621, 0.030055586624169545, 0.010804497099842035, 0.04400371115714793, 0.0541540697186945, 0.0541159836575389, 0.036320515773108894, 0.01547947875224054, 0.01680505792460134, 0.01273970605970751, 0.04021437981376245, 0.059336589408978346, 0.08835295861166331, 0.05287292173072215, 0.0305478249285971, 0.03828848456783641, 0.03348509413039973, 0.043026914579733726, 0.06362232274465984, 0.07991334333294824, 0.0014328527885804614, 0.09548933575710944, 0.05849052573584261, 0.042649880577359474, 0.06050336046985561, 0.02017325349903155, 0.045057905597552184, 0.041752841413742116, 0.052231595055350376, 0.08647291755844509, 0.07744694624336497, 0.06173218848303922, 0.06297017124691798, 0.06694721328395029, 0.08670054526338655, 0.021599488963763562, 0.0742648161887642, 0.045992663100121484, 0.062048345308510534, 0.003254136095018757, 0.06065372054675414, 0.03543330168712043, 0.03529120769892489, 0.02560100750997663, 0.10585886441291341, 0.0375796961898525, 0.04811998201353897, 0.047455745478791576, 0.04118455356107124, 0.038703604631366274, 0.0027399424288887535, 0.08607892619986689, 0.06680740989864835, 0.09272535181333942, 0.07332797492704085, 0.019327953998600284, 0.05921896809952394, 0.10513830509397293, 0.04862311791868941, 0.021205034121991168, 0.02979568171975834, 0.039261868223547935, 0.03146490686753344, 0.0741551966676789, 0.05766315843849894, 0.020033237524330616, 0.016371791153365088, 0.02695726275804543, 0.042643334356046496, 0.07915640249848366, 0.02380967752317027, 0.04736612468296963, 0.057581455161374424, 0.07642303908904714, 0.0960174767721084, 0.03190309000802377, 0.01467368832128423, 0.02648467843931529, 0.0505709654140857, 0.05886705795062646, 0.01630216908280648, 0.04827681553339766, 0.007196045339843559, 0.03360554230429473, 0.015138907662232318, 0.044118218319190126, 0.009617226483720926, 0.05862148846649836, 0.017993310090875434, 0.018507257411857287, 0.02030916515767815, 0.008647357256362035, 0.021837081557380098, 0.07214064589671551, 0.03676056050725522, 0.04338821696658288, 0.030653956834407105, 0.04819025908927283, 0.021681824263425607, 0.03434472522067447, 0.047313073094213204, 0.02746814189689054, 0.06618956764859539, 0.03530847532073817, 0.030514569051804084, 0.014869853752785394, 0.04860329922408827, 0.061135773712228385, 0.03361549378643113, 0.047889205687228716, 0.06742597993222937, 0.016278401204955675, 0.05051191152644254, 0.06978852614279717, 0.09995746696668287, 0.10080826123275104, 0.04899008552573862, 0.02025401640322901, 0.05558224530109475, 0.04705103655015269, 0.061930360107292096, 0.07641180824007719, 0.07327141465559121, 0.07683533994901566, 0.0603895849217811, 0.1134653820566112, 0.03366443531347379, 0.0052015014338277045, 0.04679047472534641, 0.03986973600882677, 0.030547679371891484, 0.048380375299001896, 0.07650012285598824, 0.061594920848766645, 0.04206016141500685, 0.061947558781192194, 0.01317683965974157, 0.03790559765372065, 0.01707180399417637, 0.14386155221971775, 0.07011501749436702, 0.05076480098068715, 0.0035067054681525, 0.07456336065285629, 0.03708505619978232, 0.03528895156998788, 0.014156104955491761, 0.04129893048816631, 0.009252823355998243, 0.1232183171856788, 0.08590495529314203, 0.027858153428702105, 0.017343751800757264, 0.016845706549863664, 0.03234194156022803, 0.010866729294761054, 0.036370805614898284, 0.09255256068201796, 0.019363812659116044, 0.05107215928634809, 0.12098158559491559, 0.016074148757803827, 0.04248783765961567, 0.0459386347492616, 0.040347970225998474, 0.01894768327474594, 0.03457612207820339, 0.05228700619491358, 0.019542694189435533, 0.0496323429979384, 0.042682370366228205, 0.02946769075107671, 0.033512045103575916, 0.022193053887496074, 0.05099026831768213, 0.032643017944909876, 0.06320264828842014, 0.0042802079265276275, 0.03996663463992938, 0.004410908750874261, 0.012592328937664148, 0.044368683105154384, 0.030508041982689214, 0.041885466555193554, 0.025537470092756615, 0.01830271385129421, 0.07193361829605795, 0.012285676390503444, 0.02936498900394767, 0.11311894177549309, 0.08927897505101659, 0.023547824840211583, 0.06112671472252377, 0.06754073224240734, 0.044597996203529264, 0.05704477609645936, 0.041927245160144185, 0.04219863563776017, 0.05135112254309559, 0.03715689609488172, 0.01434438925747189, 0.2014181669801474, 0.12830707154447032, 0.10853552965507393, 0.19699201738882452, 0.13502327244608633, 0.1436630281950197, 0.11412191174684033, 0.27866978378545854, 0.1762196199307519, 0.25923707492409215, 0.0959089297741171, 0.20643153828718971, 0.12693904535544495, 0.19121061229417402, 0.1259453986741362, 0.1675671164787585, 0.09637769897498431, 0.10944979430566873, 0.08781491974068266, 0.11521740981768216, 0.17634720421366154, 0.12652588647700128, 0.14242383501222058, 0.2532734787992893, 0.1261733711186436, 0.09948754097304999, 0.20118431098038153, 0.09087071423569033, 0.1796985477689774, 0.17452328676177611, 0.29266878421748843, 0.18572252694397204, 0.3284335683190054, 0.23044456427376117, 0.12940711251670314, 0.06846304847708634, 0.2699401812447656, 0.2177987355859049, 0.1277273574904088, 0.12294965015063364, 0.07678955853466066, 0.13559273624372098, 0.11505129897306043, 0.15193601168932455, 0.15413964828175886, 0.1344531804563538, 0.21375002219311653, 0.10934385200661999, 0.15609370875022105, 0.22251800573881597, 0.10875901282434502, 0.08534578771720971, 0.16748846989245186, 0.16855613598900457, 0.0930654871908407, 0.08547400019221729, 0.10998541233880867, 0.14106743037700653, 0.15055549060625417, 0.09869045713135312, 0.11002953900324722, 0.17752126460113835, 0.08935538466058432, 0.2669215190314478, 0.11179114286337169, 0.16861602874292483, 0.07549255635709533, 0.1622593069388982, 0.1743529394509331, 0.22495908362250175, 0.11948309463238525, 0.16143951625112565, 0.10087624387515169, 0.11404535658056698, 0.11671161834871578, 0.17231318438726087, 0.07846815676818933, 0.22408042673862752, 0.15589212037382588, 0.17481106002965283, 0.2009946888973636, 0.15769532280823878, 0.21809887351287952, 0.140512231136522, 0.1695598184221214, 0.20985412801946365, 0.1466621245227514, 0.1719250842448204, 0.3202773059808439, 0.20087055201011322, 0.14687656785451597, 0.16305907208833004, 0.21028940385628134, 0.19388494862904473, 0.14717511231860808, 0.16175908216786, 0.3166835568845272, 0.24854985726696832, 0.16699434318129094, 0.1520150872848688, 0.22801418097749834, 0.17031430777522827, 0.14119974908328828, 0.12930670903334696, 0.13987740471718774, 0.11722326549070498, 0.11251343354102104, 0.18361144909454932, 0.2227584041294552, 0.1025011393451883, 0.15678148716688156, 0.08742767761671737, 0.1282512620391865, 0.13490742463017666, 0.16427695270507567, 0.16873258135972485, 0.16634485383908595, 0.21184664610172474, 0.23463052997906364, 0.13938528515638846, 0.2067946179980232, 0.27594928299227073, 0.1446208372832306, 0.1022105238911125, 0.22979227104975333, 0.11002917894192281, 0.08146072602680615, 0.09461147560467643, 0.16982349056390025, 0.11360237389923104, 0.08874128091960184, 0.09852859807471115, 0.1857686607587722, 0.0670745907231204, 0.15807301947666755, 0.1457763583429398, 0.13977700123383155, 0.11010623206534695, 0.08498977899791733, 0.15405597615866892, 0.10845027939086, 0.2272801155284528, 0.17581693347423308, 0.12558325359057035, 0.1085211731673729, 0.1564510887668979, 0.11661244826691768, 0.1542659915022312, 0.16137288192347174, 0.14256781357670986, 0.12058931793416701, 0.12256891977402473, 0.15600252896547318, 0.12396257926499653, 0.11574327555154601, 0.1843965666428689, 0.12780893819346545, 0.09973943834343266, 0.11652585734883625, 0.1522294846513579, 0.06556659260944975, 0.20189358582419736, 0.15733400509963114, 0.23671266502670704, 0.2132396697397194, 0.2506623906834472, 0.23566157707283575, 0.16811848527962164, 0.12014028315822925, 0.1644995625341131, 0.17027945077467352, 0.0950210108872383, 0.1615721107490601, 0.26082021094137625, 0.11641739462051662, 0.16407288220380584], [0.03169045655898029, 0.030993653626571742, 0.04552732597315504, 0.016635266027503436, 0.027029817030134223, 0.007861097758230304, 0.05197325488552452, 0.032439809292554855, 0.056538847800824917, 0.013838197619113472, 0.064701771273488, 0.054326542923527385, 0.028277027323060942, 0.0369703843288364, 0.03185881587165979, 0.025632769515317295, 0.08694534865959037, 0.022879981946560646, 0.03817825600685131, 0.011247438603952047, 0.017247335805046945, 0.018981689917704752, 0.0480934830322381, 0.03567108771793785, 0.01452890823730418, 0.0328448323172427, 0.06774345442893044, 0.07241992324951195, 0.05304077159493201, 0.0351633514548021, 0.05339686458389606, 0.03491342293038484, 0.0074630207569909195, 0.03736094744395345, 0.017093426825839187, 0.01804147786911457, 0.09333772419561302, 0.0534697501890121, 0.038320150812186544, 0.043179346924467434, 0.0407224225120679, 0.01417396629544636, 0.0384558403053351, 0.03831503334485235, 0.04852754845013542, 0.019270334610595338, 0.07002052820978627, 0.049911991903378125, 0.0468162267709211, 0.05066012655715308, 0.057567182943345084, 0.03267613592587652, 0.006287299395133291, 0.061257348035372076, 0.027178870927121852, 0.033915283143400185, 0.056961659387114554, 0.04317168221478501, 0.022920132614672187, 0.07433933356115896, 0.08202400749489185, 0.05070948177167485, 0.02502832614306, 0.02712231640133166, 0.02129463576561501, 0.06645664888163728, 0.03063766405947747, 0.07175056924743038, 0.012660371909488835, 0.014556744999642816, 0.035032174219527555, 0.054412103453350645, 0.014564590697597354, 0.1056610451891057, 0.04325175755507043, 0.06241544698094649, 0.07588501553982496, 0.11604408763589398, 0.06264615435934355, 0.020591495370852853, 0.028230581327431628, 0.04026597200502311, 0.055462306575669404, 0.07555537556688632, 0.04602045677001438, 0.017028058458480145, 0.09920659354857861, 0.060481913838415384, 0.055739749147887194, 0.037141578166835734, 0.048814758643387794, 0.05720623295694109, 0.09154180725736004, 0.04396007095854129, 0.07139259934305184, 0.03932963253089017, 0.05845933063556591, 0.030147522920742634, 0.03512232744645688, 0.024589673773716056, 0.027465721059049812, 0.03459443541003331, 0.06120490931695508, 0.0010087198203226793, 0.05077688218725305, 0.03322748940498118, 0.06072778592727358, 0.045146342787531116, 0.016880573126517476, 0.02488672436635581, 0.02317897457208845, 0.0132510649611152, 0.05661773187438807, 0.037047334030390754, 0.03372578746488979, 0.04542655476759519, 0.06024222790954575, 0.01923856877481505, 0.020966033841813767, 0.03262827841324672, 0.018747125286608934, 0.030667616182097027, 0.05375214551966037, 0.03236913002066074, 0.0651945190263852, 0.019748317933971846, 0.08635052735166204, 0.02353339748937757, 0.06624394456946081, 0.030196602343611663, 0.014877327898096655, 0.06017228408205894, 0.0631432764742884, 0.043699926651653745, 0.014367413072426234, 0.022117839375090216, 0.02447796857825691, 0.03726631260266708, 0.030672965391028314, 0.02428401618324701, 0.006566393365632864, 0.046526296965537534, 0.051046977976277, 0.022309629486933834, 0.027057325332275322, 0.07155887106613767, 0.05153098466595815, 0.050324909464125676, 0.05602943380513499, 0.054802298846264044, 0.06609196804704205, 0.0038461118651133396, 0.038142809118594856, 0.026265255536042878, 0.06474698578277904, 0.06898764250499588, 0.007091508333330915, 0.03128849788598957, 0.03874093992635608, 0.018185414298768007, 0.06144317032228555, 0.01590351895203874, 0.021570980916881276, 0.04133224382155365, 0.04630489755542048, 0.03452756359512287, 0.0180851525416778, 0.013286048366177469, 0.036542719575546445, 0.020930701866745952, 0.03438399105723347, 0.022236464259725426, 0.10689704378526058, 0.05361920628215998, 0.05686456540359124, 0.012888220822318427, 0.004137564270246414, 0.03542673631360935, 0.02856904088759855, 0.03873696393002907, 0.015061327853360245, 0.04465046173502361, 0.05160533349900957, 0.07184338079945696, 0.03255554602571553, 0.005275349915703578, 0.07373721143531223, 0.029309539559988246, 0.047925977907594175, 0.033696312232003096, 0.048417511411131396, 0.0357703190867699, 0.09586185367117006, 0.03109967636485254, 0.03545552972824343, 0.06320645957584343, 0.049436795224826184, 0.020119186843775456, 0.05637925253399918, 0.010521932272240521, 0.02711491790720292, 0.10167780167032635, 0.06982329121280102, 0.10564927041770951, 0.0759952326094912, 0.015735375101587946, 0.08066383370709035, 0.014986636195962709, 0.029833338771676345, 0.02455176965844247, 0.060162106603984876, 0.02971425806472619, 0.051222821967976714, 0.060038019512449546, 0.10152091452431294, 0.05237606774655081, 0.06108153851762895, 0.00879509827016943, 0.05325892279225011, 0.011396948323254625, 0.02405922108840558, 0.03197587985214928, 0.005412843545913817, 0.1385831910996668, 0.036172009628987124, 0.0836622252339317, 0.04985192677967491, 0.09105722600173566, 0.031483488330136866, 0.04518062139170305, 0.01943925125223975, 0.01749777186271404, 0.04438208198295005, 0.030948699587174965, 0.009089755795655713, 0.049069490539090294, 0.04729038923077526, 0.027220756784381888, 0.017650905177898465, 0.046367218808060696, 0.0596174602246573, 0.016302607668143128, 0.05858858115971089, 0.02819103012312084, 0.025961511250164722, 0.01616835842029222, 0.0173449928631946, 0.02731693337761587, 0.051573724711253766, 0.00804780152506165, 0.03139754284113165, 0.04367437761937899, 0.04577369601916402, 0.04755605703159686, 0.11085697524850407, 0.05592397031103892, 0.05682604650275842, 0.030881540489292918, 0.032245257433744214, 0.07956433665728377, 0.06369351146502361, 0.01666954654689518, 0.042540628778477835, 0.08021807012658927, 0.015777674646327094, 0.016892866922482368, 0.04617735157690702, 0.04418491010343836, 0.031562427945074537, 0.05033473071131495, 0.03897139066529851, 0.05129971421293674, 0.048019115046988574, 0.04150297800679842, 0.03050588161474274, 0.10447280451415047, 0.01740995328873396, 0.10013520702599518, 0.02070675329906085, 0.017971208454259945, 0.022174794181820848, 0.04247966733190321, 0.020891252169085127, 0.017755947323636185, 0.060224083117059166, 0.012540138240212636, 0.07147147575573576, 0.03251800771742579, 0.043083229703047586, 0.01098940008124637, 0.011243899277741871, 0.05704774085672633, 0.027628664130104647, 0.040568473313244126, 0.009254101765221887, 0.06358523642824543, 0.03929151965665721, 0.022918184836124702, 0.050863503748851444, 0.040395613234009475, 0.05665078856832078, 0.07568951756242784, 0.041374271405079675, 0.0033812880170561617, 0.03681348186106451, 0.020472654066379034, 0.04314208823827006, 0.06725856673813636, 0.03741149009475785, 0.08431466401464517, 0.033926525483689005, 0.03786591812968254, 0.03190074769419528, 0.030504759295933673, 0.11761528034243854, 0.003364133872016664, 0.06707556365478425, 0.018839448457583785, 0.03617388654440161, 0.03623412403788778, 0.053438731288957986, 0.07462526055713815, 0.03999877585879257, 0.011428371334688799, 0.014632917121954024, 0.023505366332228148, 0.026750645014427366, 0.02375014100013481, 0.03308008642747037, 0.0438195972463056, 0.06888406741763316, 0.05218762160849668, 0.04233748141315676, 0.034461228041759426, 0.03208198302966212, 0.030903306962441535, 0.02202427322645822, 0.06575831377338018, 0.038004576213537686, 0.03997536804226618, 0.01760369500956468, 0.009154997758507248, 0.0430557424683244, 0.03980693595123388, 0.041334427172137846, 0.009232175371219075, 0.04211801637504851, 0.03376815595754212, 0.02667153494492654, 0.03458923367302745, 0.058401134766397945, 0.030902427876548424, 0.13829068340841802, 0.15540654320389996, 0.09531790060141394, 0.09850783709196315, 0.11345196785705705, 0.14062126076990558, 0.20949310142426722, 0.18854539240560225, 0.19524072507216086, 0.10877802712662567, 0.18507452381234016, 0.10428030194053728, 0.14314444795731576, 0.14170283902316325, 0.1868923738478653, 0.08308205918799486, 0.1715308094337102, 0.08141376483704775, 0.099340858118188, 0.20608603263333922, 0.12240128441443368, 0.11374931722398728, 0.18020396661614219, 0.07874520480512612, 0.09492845214422672, 0.19795774782617248, 0.17104624349984432, 0.1806472863761648, 0.240207129128037, 0.09461674628959549, 0.21225733051617302, 0.20834145676945487, 0.08602542261923514, 0.1444038658613159, 0.13177412501986951, 0.11299653624695156, 0.15084193088114262, 0.1220723185988684, 0.1749457842520168, 0.15642216128687705, 0.12270994890000551, 0.11166338238023943, 0.20352311612617588, 0.05790794651294428, 0.09913186167156506, 0.0834079223474668, 0.15064538336328923, 0.23035353770659817, 0.18076996769635909, 0.26834708608446584, 0.1613838829460644, 0.2793119493271074, 0.12334557971166027, 0.1297931442217481, 0.1467675228993739, 0.09437380448704767, 0.13034458963140366, 0.15832043523269315, 0.13818153120096655, 0.179706423152839, 0.2018090097173568, 0.12354562825132763, 0.16008574695837113, 0.10601572857628908, 0.1383770521610014, 0.1883312248654904, 0.13758715422403428, 0.18770715432061305, 0.1292727100512674, 0.06261551850325157, 0.09975911148132817, 0.08073044505210654, 0.09215168985387973, 0.20578978643301996, 0.12368946125911129, 0.15389754917592774, 0.19219716500130393, 0.212052401996428, 0.19393017846009425, 0.20632643102397843, 0.1474251940606102, 0.12685235484593338, 0.1322858411097719, 0.20515546563171572, 0.22758457419132033, 0.13955328823818317, 0.13242784316741651, 0.3089921260553022, 0.10861616040910445, 0.12350611343619325, 0.14764011236688784, 0.23976246105326762, 0.1697821524595061, 0.09775516336723682, 0.1222187026794399, 0.11767599281043777, 0.15864260584837006, 0.14443717536426362, 0.08592296602024187, 0.28755097980460814, 0.08148001612073953, 0.14373275751788772, 0.15542027149950305, 0.13624506011124582, 0.1647186943239743, 0.16258559910760773, 0.10143171890728897, 0.22115548772196617, 0.10465783006962269, 0.1863892839079903, 0.20818569577269017, 0.17403018660843375, 0.10450737806217325, 0.1215008782943891, 0.11947604662348187, 0.1481501583851153, 0.15835077231449468, 0.12824583047580335, 0.1492061339799435, 0.12498825608241944, 0.13668382930899822, 0.10547834088004406, 0.1672653544453844, 0.13186288396677665, 0.2369146977340983, 0.14197824763194208, 0.17195398108132426, 0.11055833885386107, 0.13645332877434072, 0.21417543081746948, 0.07442357258931284, 0.21173559399622105, 0.17759485500714473, 0.11815869715064765, 0.1253714839056615, 0.16899090620779222, 0.08192896662700562, 0.25466202848380615, 0.25762737097759403, 0.07428583764140645, 0.23303792511503543, 0.10377985500400105, 0.14910012273298157, 0.12804498520469473, 0.19679340143357554, 0.25989716692316917, 0.1609388318273329, 0.1194471651087365, 0.13581618876947513, 0.13810228706607897, 0.11749118175958434, 0.10078621322229024, 0.11717067355470312, 0.12206181553342652, 0.21648981308023776, 0.1137280965884847, 0.09157494056008517, 0.12671947689546695, 0.13527442671118245, 0.1643943633403509, 0.10980392610954662, 0.11285605104339701, 0.1416926653755288, 0.1434510210228543, 0.3282218829037682, 0.1045634403764721, 0.13512464120022713, 0.1511762669730571, 0.12608024547056806, 0.07734631293363149, 0.16608547178968308, 0.11923689695615923, 0.18932539248658767, 0.19572346771676696, 0.17327379735727466, 0.17029714740572438], [0.06095294682909885, 0.029428809873699665, 0.06419922908647888, 0.030985739938313925, 0.046896363398240465, 0.03075773301984995, 0.017283150415507056, 0.00498140006393735, 0.03227011698688711, 0.03545275265951792, 0.03854745676019981, 0.03958395456955318, 0.025673630729978605, 0.024374874211066676, 0.030561899878985943, 0.040549225354146574, 0.07278338600430759, 0.02426926132982537, 0.06743596971876199, 0.029373201466495955, 0.022855719941998684, 0.03844532191813473, 0.05379093638170631, 0.03863807730076294, 0.025030662711229057, 0.03403370118429584, 0.020904164581048875, 0.047208027118035865, 0.01756250437709593, 0.05772017070182389, 0.08063890520603427, 0.025616865530009233, 0.052555339981711684, 0.002562727618609525, 0.03850442177105335, 0.08688172505747888, 0.02374352200046903, 0.0402550514216625, 0.019232279192956708, 0.031456807402953986, 0.009933980857773174, 0.057354501613806334, 0.03401495884322832, 0.03769109686536174, 0.02356265247198603, 0.01995037936966025, 0.028169849707234292, 0.14346268088106187, 0.04234973498950562, 0.025674111450151093, 0.06052779101376092, 0.06337588375073767, 0.023384935395311446, 0.040160416580376126, 0.0328248221006605, 0.03966434783632717, 0.0571306890267278, 0.03719187949994399, 0.05468640889551851, 0.03031009443915419, 0.061743522753878954, 0.0034706466671665234, 0.029125272431561065, 0.04202239328033982, 0.0233260806905286, 0.07555682347306321, 0.044916753897503506, 0.012983530778588067, 0.016706257480226697, 0.06371868894465509, 0.022290622845532435, 0.023559586205069098, 0.018307775777253895, 0.03645121420343076, 0.040168169390169844, 0.006449540059322552, 0.02957638139055381, 0.02406951347966829, 0.04483570945599387, 0.015301915850760716, 0.05876861948279604, 0.01680931162780091, 0.053916862084259914, 0.05991637241095305, 0.039840291419457045, 0.03631533318830114, 0.05868348030133113, 0.025871321634058992, 0.01180555089376867, 0.03730646327077862, 0.017569481522866318, 0.06428652097501102, 0.08374408172864108, 0.06675858711523396, 0.07168087822895858, 0.04681217033536204, 0.09523287250269806, 0.034014395768603975, 0.06224623348023142, 0.04027984968777146, 0.048250565530672196, 0.03338057292445052, 0.03831412553066208, 0.023060698257458788, 0.03429303343798365, 0.09521687658683908, 0.048426669992266164, 0.025185418217593146, 0.012993937125429513, 0.10571539146645416, 0.02799057555685361, 0.018174204517215974, 0.02420041300807028, 0.03191764759380491, 0.059060211698975296, 0.03370804103812383, 0.05124277855840422, 0.03559409588154766, 0.059813440837446726, 0.017870529179251003, 0.015945257337373352, 0.03047836756694221, 0.06393492109172287, 0.03205213815935197, 0.014268121374170146, 0.0712767438662629, 0.048719545405718594, 0.010914112790487708, 0.07698200748211916, 0.06313573050823423, 0.024029021902430444, 0.04768844851623139, 0.049071493859012286, 0.016183649535260854, 0.009137708111666143, 0.02465584461817578, 0.0671045141174428, 0.04517270770344523, 0.009684449741466632, 0.020865940624066902, 0.028468315647314155, 0.012189223048006816, 0.034291145031250296, 0.08270037120148059, 0.06841211895188017, 0.023911174597038377, 0.04284218396811236, 0.06558998127377803, 0.040755314497096885, 0.03688063712850694, 0.050136164551781076, 0.04086547027972918, 0.02888241872912453, 0.015438408778619864, 0.07238007135569088, 0.01844379468820989, 0.04686693796106885, 0.02985648228786886, 0.03663884062740592, 0.05429131820076897, 0.05868266441769177, 0.0731269611165889, 0.020073916793109912, 0.009590494803213065, 0.05799417736970129, 0.07084864627329573, 0.042219630277325074, 0.02403550875192929, 0.040256602749709165, 0.011986330406920565, 0.051709218851981625, 0.023674415124039498, 0.032962074413174586, 0.06103732758351873, 0.0657703260320329, 0.04467829370931272, 0.018674844890953075, 0.03336206040976029, 0.04169295249026149, 0.016473897267132998, 0.023992180734151797, 0.09066692718695249, 0.04204374798122914, 0.04961108788847924, 0.01728195723356499, 0.02168691683290226, 0.08547209263328584, 0.01121056008888709, 0.020437036723559423, 0.07356420579937197, 0.03453572243151646, 0.0481154429425876, 0.040341473800400575, 0.012773926249675214, 0.04086673815524386, 0.07225276286443395, 0.009695372240047061, 0.01655485935419077, 0.024771550707819483, 0.02321756625127408, 0.03333022562606681, 0.04349810078800206, 0.011012521572411062, 0.013239092922078506, 0.05255274677408799, 0.04307530069303128, 0.043719044375804164, 0.054575701529580745, 0.03314402412563082, 0.13700972311198711, 0.03906743127792593, 0.11516330868846948, 0.05213552762964561, 0.08376147192452224, 0.034143182809554765, 0.048135188858835935, 0.018079441356202288, 0.06767652132698605, 0.029153587041242473, 0.06746043090618427, 0.057103841475421385, 0.064065202004126, 0.008339231905166902, 0.056980294475872675, 0.04158930845498558, 0.025982302876429695, 0.035096992918800925, 0.07383867212000393, 0.006017510520084011, 0.01978965986880564, 0.002515455923839322, 0.026433658898778023, 0.014052771185825189, 0.03455080287230592, 0.05042425574614637, 0.020615577344752608, 0.044323200465089856, 0.022626992900885885, 0.061112940461645206, 0.017235693183817694, 0.029012056127671274, 0.08437010579772534, 0.061328418012107574, 0.006339287079284869, 0.009992347181504293, 0.02578822407691229, 0.02823921513833827, 0.02017508636439039, 0.026566054213852174, 0.03885955715011205, 0.032757325924091765, 0.0057143527702728835, 0.024451308718491948, 0.017879546034119783, 0.02635032385437479, 0.04080959182653216, 0.02921657095993719, 0.05482945666317979, 0.06045743732923462, 0.044153389415793845, 0.06850126860362869, 0.040231176291502295, 0.050740289997549794, 0.03820131908381178, 0.060736879390934785, 0.03183799168665803, 0.025574112078174952, 0.12277327372782654, 0.09651013259445468, 0.0581541097152137, 0.03659218970325686, 0.0392498521344556, 0.09090170249222748, 0.06909936876787294, 0.048529655191927194, 0.019999692449346185, 0.012635040254662595, 0.014266127630347207, 0.050634041263331334, 0.02953377349542514, 0.02365218899813631, 0.030760399005826444, 0.050116250096189405, 0.0368754583741388, 0.026253195396894892, 0.009391559963865627, 0.020514204760172197, 0.007492253714571557, 0.019436313305050135, 0.04543931013153446, 0.07213252536471813, 0.019767253712240248, 0.039572053393649484, 0.0894665210357597, 0.03275321969281762, 0.015179607998429528, 0.05426424082308527, 0.009024998383416284, 0.032421626195672064, 0.07033321465696059, 0.027292280668212522, 0.036671950947493315, 0.019174406995936748, 0.06918044385289954, 0.026367677661079555, 0.08063568763675229, 0.035780791508694815, 0.008274640159441099, 0.026100144436162327, 0.020875126018279025, 0.02835746272467077, 0.021690797068238742, 0.0378657840642958, 0.01881211444044546, 0.031050932105450384, 0.024723595518979336, 0.012320631067268552, 0.06342097951640045, 0.02731438996570726, 0.11724400349081525, 0.006236497710849489, 0.04990573296503675, 0.055239007267500126, 0.03709001278865241, 0.016102796615732294, 0.05285142147312722, 0.04380800250557162, 0.053171676868993434, 0.043161286401652524, 0.015487525548275202, 0.029042684322884007, 0.004640799288022062, 0.01111913898644308, 0.0454441135028197, 0.04852742204562791, 0.039284824048199, 0.04149847340980365, 0.05276235992149, 0.08708309892925524, 0.03869243123899064, 0.012193612731812943, 0.07210388899810853, 0.04002431723018808, 0.006887229551906668, 0.07470507925796895, 0.034650072545534184, 0.05889558706492667, 0.01781922427096194, 0.01613488229322097, 0.06738287216473011, 0.10309805207314993, 0.04868093840477448, 0.30197675249749617, 0.13474067793257777, 0.13517518768147116, 0.16139509847327588, 0.11146875008219674, 0.2134915747709813, 0.10097895328315998, 0.19074522920193213, 0.10572397931208534, 0.10606363205419433, 0.11926419266890134, 0.21488784662177488, 0.2553659866774275, 0.13202504945858834, 0.09518957321321773, 0.09430779069061242, 0.16605265258300692, 0.0646721160099391, 0.18897006558554788, 0.17177166747710398, 0.11148798654997542, 0.16277054805428753, 0.16121139058903342, 0.17610444627221555, 0.1342691967804586, 0.1191105001095322, 0.11564931486763301, 0.12175300549114905, 0.1902695192444709, 0.12797953065244422, 0.19078394728562525, 0.12969819528441276, 0.11624379143599542, 0.25652153838065367, 0.13421806807239212, 0.22752054456260898, 0.18244472782938712, 0.17819684689804433, 0.10272275325992417, 0.12355898116384784, 0.12903468653319344, 0.13085437517973686, 0.2286925671562072, 0.129368961338074, 0.14831546483741653, 0.0918926755266805, 0.08280707958845362, 0.19783969367704085, 0.1755534145500391, 0.10180981394143836, 0.1360356423162645, 0.15746322881069877, 0.09944396589191691, 0.1493967366555045, 0.1692714782491807, 0.14620636349483845, 0.12211979306753605, 0.0876703895928879, 0.13670463625702167, 0.1011917035606119, 0.1404615467594516, 0.0960232760576952, 0.11229096160781, 0.12440586072062293, 0.14125866124466543, 0.14567567906793089, 0.14339400875952937, 0.11399059661573942, 0.08812778238807956, 0.12095801306948548, 0.12624736755124985, 0.19160822724863408, 0.15886841792493098, 0.13916826776919827, 0.08610908708144581, 0.09038180458329378, 0.0892526675916968, 0.14413717533311537, 0.052723266454713966, 0.08807897492642365, 0.13307982995625467, 0.08946544085178645, 0.20965702891830476, 0.15801904092152275, 0.17824907877272178, 0.13011663250865477, 0.20739582847924004, 0.09255087528858455, 0.07442810782982458, 0.16210334675927318, 0.11852442752569915, 0.15315821304196311, 0.2559620950130686, 0.24133042852965095, 0.10391123908301515, 0.1712418410686716, 0.17572622866399829, 0.18683841061447898, 0.11946368962526323, 0.11176611477088545, 0.1866495239758684, 0.13207974813638196, 0.15795343315168736, 0.17159177471072445, 0.11050843588647344, 0.21513861784290886, 0.1564825903023443, 0.12607559531686768, 0.12329924671399979, 0.28409172510427816, 0.2108053793950427, 0.1529653274243878, 0.12438916766475286, 0.12738846317534486, 0.1679854158071741, 0.12574039354559877, 0.13037406869472998, 0.12811262310752947, 0.08801224100733958, 0.12415482136871546, 0.06721857694848891, 0.1664654514001262, 0.24428041862143626, 0.18838417686281667, 0.09822611591868824, 0.16051291758494993, 0.15797189587066252, 0.1366857445288089, 0.14692256377348978, 0.27375490074196174, 0.07672364432965556, 0.1125961097498094, 0.14635699170251049, 0.09278083190081582, 0.12711549838704447, 0.09643359274993982, 0.2015803018284421, 0.11209485076007344, 0.053756757368964535, 0.13621424805493126, 0.09285097491116294, 0.15897407677144776, 0.20076755914957295, 0.2524656390831355, 0.11839052301741416, 0.15190811076712224, 0.15412622642132545, 0.09072534139117888, 0.05680530850264815, 0.10292452549742115, 0.14415436634613624, 0.11117123217592317, 0.06735055091520471, 0.11337984067898606, 0.17650573844871215, 0.1328631190042342, 0.14114495847494374, 0.22261235712757035, 0.10977193427782868, 0.24763888679444793, 0.08421050670046, 0.22642981921953542, 0.11466569627725309, 0.08869952912772856, 0.11750858727722399, 0.20825240670913653, 0.21856578878096997, 0.10704964083889801, 0.23354535111256186, 0.13118699523470095, 0.13180786353205481, 0.12537128472280118, 0.06076903210111684, 0.20026393294815095, 0.16448566569916664, 0.1326798860945048], [0.03681565372032985, 0.04382574510189795, 0.03832333773795155, 0.05924198904164857, 0.03486996276244041, 0.07403468337631033, 0.04171476301346575, 0.04343831911683083, 0.06592247875467425, 0.07166608507114072, 0.06194526434785897, 0.05354736255662096, 0.04728752406193845, 0.04611216898586962, 0.06741860250551855, 0.0398315312040429, 0.05967774751385855, 0.03769999497660226, 0.004446672129204437, 0.014850023566865394, 0.063656356200696, 0.039227654736849575, 0.04766237854416813, 0.06324627699570791, 0.0461818216999452, 0.023783444757423094, 0.017547540764714924, 0.04408963940917485, 0.025201144087458813, 0.04380577702015158, 0.03298702206642878, 0.09053419479319165, 0.06798908520009249, 0.06534994294446322, 0.033262829040928234, 0.010685817631442222, 0.042725842025491505, 0.08509229688394455, 0.015564265533260282, 0.06270878204715348, 0.031509209732194586, 0.006782997544148878, 0.07585669326926432, 0.04098651983264474, 0.036303880173833146, 0.04883213351751047, 0.0179585296991131, 0.05416482176271178, 0.16170637531866952, 0.03131787735788572, 0.07386350102962987, 0.06951038260012865, 0.026459857190568602, 0.03627844222430741, 0.03363477621948527, 0.05238318470336738, 0.028224732246129747, 0.022480451772289894, 0.03348227109639876, 0.029612525418821364, 0.03254497018192084, 0.03832142634858047, 0.027775846857337222, 0.016140084030226837, 0.029938949737697843, 0.04654929492502444, 0.04861558344395411, 0.07271002542467848, 0.015098518549254345, 0.06116302729013467, 0.030819916376663797, 0.02172821471768041, 0.06541160536148856, 0.028571756669290127, 0.025154629143916314, 0.0651693377163141, 0.03126714318510025, 0.024213798479327274, 0.027437383466730678, 0.015021933697073933, 0.041896291377563635, 0.005394065773279797, 0.0923581658712318, 0.0334574919824879, 0.04925204929144633, 0.027701986405337532, 0.028621276592715617, 0.014943561944810134, 0.029799581107292927, 0.04467635167642467, 0.0819902996262235, 0.06360734189530054, 0.06099723820244113, 0.06992671308257888, 0.08636077760808891, 0.08416798882066243, 0.034769383078861626, 0.08423532794920668, 0.051009006828310034, 0.06727099268426819, 0.029310954907428355, 0.017622471824588797, 0.05709446072878857, 0.033947945302051884, 0.038816878391850385, 0.06304920470762639, 0.013216794975432418, 0.01726546144533542, 0.14414020904129551, 0.02648330905715064, 0.051706522222488165, 0.07776828182320442, 0.03363452724090988, 0.02438379913538454, 0.06379224870714449, 0.04569211148566777, 0.0451172199550896, 0.03493251767189753, 0.038476333157309604, 0.027701097743345365, 0.022381961593524586, 0.027043723441179723, 0.04724551563061053, 0.06780715463983436, 0.06191710295576242, 0.024809458653532693, 0.004843826473300015, 0.008898017394746984, 0.10551148184364843, 0.03535334126002366, 0.019935184015682148, 0.05957650516422526, 0.07376453013069208, 0.05745144621018441, 0.05525436733038195, 0.0650107651768673, 0.07037166460988022, 0.026619592268440514, 0.011726373791574471, 0.010376546978800288, 0.0948489475394449, 0.025466972766744516, 0.05942149876406597, 0.021902528448751377, 0.0023433717480304864, 0.0854202361416913, 0.019222814176652222, 0.04443412233564643, 0.015482465537535328, 0.04377937379984125, 0.021526136045013706, 0.02050192628596579, 0.026620461778234572, 0.035846483548201864, 0.06827219299251033, 0.026389116631640543, 0.07593254363464733, 0.03277535580338971, 0.04950206208553526, 0.10490178310823058, 0.07107911616443627, 0.03652638658100078, 0.03660360824376826, 0.04214841857432358, 0.018286175928228808, 0.051332502776095947, 0.03191781804836806, 0.04152284649711463, 0.0587927014566958, 0.04121151985600591, 0.07077675658248125, 0.014613944954509217, 0.004997568349579289, 0.07340584776454395, 0.06094661128196505, 0.03362643735242948, 0.05884547342335986, 0.057807719229810664, 0.034826418324824304, 0.04233769591777556, 0.048499674341010476, 0.03776222429869156, 0.005995857044904223, 0.055484082624917073, 0.02567437958092459, 0.019662280514415716, 0.050970418979564024, 0.032532992397224715, 0.02872967228834187, 0.00719584328415353, 0.043066674543003884, 0.042345280188225934, 0.03395392461830089, 0.021301499913416563, 0.03909276580558189, 0.04805986326368106, 0.12203243606153036, 0.029165926802482818, 0.058797003040390636, 0.02627135359592015, 0.04434552809764301, 0.024833508068695668, 0.02002079051078087, 0.05902994356508698, 0.02097934078905852, 0.028916337271972053, 0.025081437103630557, 0.029466677599796848, 0.06497293575516631, 0.023849525586551717, 0.009889303567639042, 0.014731145873215171, 0.012086618019478216, 0.07835131303797807, 0.04089033749375132, 0.03405306788702165, 0.026149003608753125, 0.02483187630141695, 0.05265550597781136, 0.03374501244134961, 0.048561673836722496, 0.037266611376957554, 0.01515192828411537, 0.07387192799679695, 0.07736367248599568, 0.013646792466451806, 0.06229487623298361, 0.06242909100687793, 0.02802882441169312, 0.031774680265375686, 0.06509297407202183, 0.00834118064132429, 0.0170488290173272, 0.03791947533646899, 0.056259482347917174, 0.032275529398072156, 0.006897767091305146, 0.08178968418149218, 0.006341923858159252, 0.09181369186168717, 0.026630746508618037, 0.041630244363219514, 0.02881185628563887, 0.03252498677841598, 0.021022810533102003, 0.009132899952331379, 0.027207059132295753, 0.08124243693366166, 0.09152499928830132, 0.06951406748304445, 0.03394301552625914, 0.025221198354096665, 0.019343204893952897, 0.06682807895084543, 0.0908208265900612, 0.007759168323489928, 0.03986746072769165, 0.058389291047088565, 0.12729738298202717, 0.05029346155483396, 0.04376630050941341, 0.04742930395408504, 0.01894786905106758, 0.12430473711461791, 0.03460034577836914, 0.022267590412088943, 0.018473359936427687, 0.026230678157580477, 0.031215192847734982, 0.04319567608857348, 0.0044596606711556595, 0.01602597331868545, 0.03406436002302555, 0.07694083791706832, 0.03848872462948484, 0.054137970380965746, 0.02918939016038372, 0.01747602454176353, 0.029154657649116653, 0.06080688833589516, 0.09803919812604305, 0.055784166925736976, 0.03129332040947291, 0.0261916478930582, 0.09934757670928394, 0.03132189165860896, 0.060355402078599706, 0.04217695151906341, 0.033996733611509684, 0.09589538533961582, 0.054281914471498424, 0.026677035456222874, 0.05132442820937403, 0.07550351907529178, 0.09947221155368513, 0.05326530813509899, 0.05235719900097578, 0.04436137845679637, 0.01985253270475134, 0.04955170841346826, 0.03136580381842871, 0.037807082577097806, 0.022440364306432106, 0.026951032548001217, 0.07692150951873872, 0.02997352711616024, 0.012266178495220601, 0.04529030219982228, 0.11658994060370231, 0.07965807517569873, 0.08253052950866761, 0.05580908776591382, 0.07865194126122421, 0.044742955360561616, 0.023806088401245016, 0.06458080599024411, 0.04294249169047802, 0.07277400908811439, 0.03641700454717202, 0.05455827302930336, 0.009216152642282748, 0.05220920230532366, 0.060848184305453495, 0.017636179052773985, 0.0453027626199107, 0.07936248781099435, 0.10554740370641794, 0.07870038866155571, 0.034455091677485936, 0.025495126497961824, 0.021428957791818727, 0.024570868230394782, 0.012401359497509416, 0.06966111806011008, 0.027772204109257268, 0.023210759560066848, 0.06761236146332757, 0.04919700204364715, 0.05194847960205329, 0.03407043893070471, 0.05303996720261151, 0.0038546400995279153, 0.02630596353311933, 0.029358211041037596, 0.057638187802607016, 0.044981967132057876, 0.0458307657390833, 0.027101951869084474, 0.07412998471409082, 0.07873912206700734, 0.05057365438269992, 0.07297571237769819, 0.1691512943756196, 0.12897592758940113, 0.09421258894426209, 0.2047781673290076, 0.09331803573595901, 0.14876269164585298, 0.1439053724489866, 0.1272255315956089, 0.16493079342669056, 0.14295845713105895, 0.17497347066960028, 0.10435081267308804, 0.11459294856796343, 0.20520602743471825, 0.21310440925580842, 0.2078285455823906, 0.12921718399851553, 0.0736907252200669, 0.11251072925064834, 0.13513856867869056, 0.16624104892534597, 0.08146228884617168, 0.11856860015541316, 0.14699339626296876, 0.1361768169989509, 0.14240005564305092, 0.11226145190096672, 0.11763546675924333, 0.11822558428731658, 0.1116292838067297, 0.1359129916395872, 0.1715227348669883, 0.18479208251641643, 0.13948820140813628, 0.09165958561483892, 0.10782127523975027, 0.10793744481258816, 0.20046023531786858, 0.12820224773379105, 0.16192043560647196, 0.09482016561612969, 0.13750783348035428, 0.17924805742598351, 0.12356633560792094, 0.11791426913752673, 0.20420090475630379, 0.08408781005850724, 0.15781719207523331, 0.18571932469644856, 0.13123870616958988, 0.19123370218421185, 0.18371192918669793, 0.1118700882239688, 0.11605915658536459, 0.1797965150927344, 0.13696671493591803, 0.1310388338301451, 0.11019248590474168, 0.136800090812387, 0.11425592350743471, 0.24313280358910563, 0.1266435499212915, 0.16969985929467987, 0.0821280882002846, 0.10074350382051162, 0.16378103334817196, 0.13172774605693358, 0.12622809277907496, 0.16450671779532589, 0.19523954529675747, 0.13313546326131592, 0.14021132712162312, 0.12529273006704547, 0.12806179317375346, 0.09252749428513551, 0.1342302029051127, 0.18917496346177595, 0.09209762702906325, 0.18973338027154246, 0.07481953279385645, 0.10682539158170262, 0.1993675334679504, 0.3353728540241719, 0.15213009240406175, 0.14451073512675303, 0.11122242983190284, 0.08340815217384408, 0.20462255954982775, 0.1810471076638468, 0.12510843995598056, 0.14399975448125793, 0.22290685664742227, 0.17280406288562283, 0.14468436129391193, 0.24741460689373557, 0.16761482843468267, 0.18170695451478805, 0.16028391858262403, 0.13938766002895372, 0.1371308109692989, 0.23914275720955866, 0.13775526455813839, 0.16844471616129722, 0.1382733698213293, 0.250240475420029, 0.176613419767349, 0.13410418144156858, 0.09500325296915348, 0.1789513362511512, 0.12126957336741111, 0.13982054567144764, 0.13471365035060914, 0.17482085063332514, 0.15175294731893849, 0.13746675584585438, 0.12720157602621665, 0.08668679398514571, 0.1515210371825003, 0.25282433677104216, 0.09240080632509724, 0.14852155781080648, 0.13664269038746435, 0.12545856512001446, 0.15262541421238454, 0.13991773158552187, 0.1322650648052654, 0.18344831833195302, 0.11388473858636235, 0.202254903532805, 0.16449735620089118, 0.12598686701347753, 0.20838345370946393, 0.17541156570997932, 0.3236764993879103, 0.17239800564223723, 0.17361942558519303, 0.28541129623209277, 0.09098626327730956, 0.10891203122634081, 0.1734161977806399, 0.12928574886773864, 0.13963008089171303, 0.1264832613448943, 0.13257007505143845, 0.08329131610451207, 0.1700757786391243, 0.08222316737256705, 0.1813589667360629, 0.10448264874397747, 0.20356272287186117, 0.19605694579020624, 0.1812575060513712, 0.10190588136714313, 0.06850972621431274, 0.09776832475777596, 0.196574668009435, 0.20785273863903939, 0.17382911917182708, 0.13487927855983858, 0.22129269406920482, 0.192632011828884, 0.17403032450426012, 0.1275083099702193, 0.2136793735647394, 0.16510736137147874, 0.11261510873033155, 0.11907272431398593, 0.11078158453587564, 0.19876272237348944, 0.06065416870818985, 0.14855218600601922, 0.13536836441245773, 0.16701556381679353, 0.30378940845689467, 0.11587157229622526, 0.17797949243216746], [0.056442834001274846, 0.03612656146287918, 0.07334952498035086, 0.08528490670986714, 0.0271694652826315, 0.050971403402546724, 0.032565669877634894, 0.008429207016653832, 0.0730460852144226, 0.044944547567396395, 0.03677953267470002, 0.0340380065984303, 0.05713324009951565, 0.06520761146901116, 0.05416157354991283, 0.029434471263460098, 0.05517739464618987, 0.055624134988794406, 0.039831703573825865, 0.0520217712337692, 0.030759724848453077, 0.044698376704247735, 0.006534247837525102, 0.022611295759317376, 0.05618006584324664, 0.05116414729385607, 0.016370956117527622, 0.05818271160786671, 0.021181291141997904, 0.06674498139369874, 0.07131398340026218, 0.06423607408519715, 0.10348609858943571, 0.023615891752283902, 0.02265987530981581, 0.03486499085181183, 0.043304747856792905, 0.08037403030621429, 0.08305258012466854, 0.04883452371183423, 0.06232888670638204, 0.03154273757020072, 0.08064250581927838, 0.02446886745371646, 0.018882378109640652, 0.002213108551410598, 0.06070794041959509, 0.039578806458702015, 0.04431690322235227, 0.018012236293044784, 0.03928382813389744, 0.019466458864870573, 0.014122331011739951, 0.02793319940176462, 0.055064124716145385, 0.05803312527977171, 0.040086550382717, 0.04403409420422489, 0.06332698435853086, 0.05954254065610229, 0.026296747495390238, 0.026828906641552047, 0.029552159605607874, 0.057589016449187076, 0.03257508509822431, 0.025233358084674806, 0.031681485669386965, 0.023196879962098696, 0.05064156041630814, 0.049383847057939544, 0.020925929138977683, 0.022307361866677963, 0.06447032845068364, 0.01058681704659736, 0.04478073115610788, 0.019872971930571144, 0.024982673048432318, 0.00877741217282751, 0.07132005847750172, 0.026169931215624657, 0.06448401078101128, 0.015806704590607797, 0.039849469152789925, 0.024167557412217704, 0.02211637614715484, 0.0284038225354086, 0.04177452170199925, 0.019346112197625543, 0.06302893402114992, 0.06351941798423087, 0.05812665312400749, 0.059135893525014964, 0.012131032924498282, 0.050212022578043324, 0.06478952664521433, 0.05455189917777335, 0.014333624764525843, 0.02022520958205625, 0.029451968711650664, 0.052675083354716344, 0.04255138465293473, 0.055336913304223176, 0.10178594264171778, 0.03795697534036252, 0.037368321040224646, 0.04926873085599753, 0.08826593102346506, 0.018714828934941082, 0.035784016738856034, 0.06513520849928742, 0.04718362721764753, 0.007108106585820356, 0.049260054910255056, 0.017187385594532374, 0.047098484205743, 0.09285652904861397, 0.002361761688652839, 0.05271732927330079, 0.021651828090750405, 0.026471721977295897, 0.033030719721629735, 0.04282708054468517, 0.11382064767061703, 0.036548097512774894, 0.04566259794838486, 0.044879935711862586, 0.056228130199616, 0.05683887081461088, 0.06980423094524492, 0.05905635827671617, 0.035071823100048694, 0.041435236682093916, 0.012355876857444886, 0.0693741185410369, 0.03107766857400777, 0.022798474021856825, 0.04192258734556456, 0.015540394233539702, 0.021150452272605993, 0.017216154111308918, 0.009627211482204016, 0.016109566917763125, 0.026319260904265028, 0.027448920750870343, 0.03771867986107546, 0.014561523473070515, 0.04041619035565565, 0.04612158803689865, 0.05962720103261452, 0.03379160590890435, 0.09949260481422949, 0.003583236215373261, 0.05095846417750563, 0.08468990154083698, 0.04294915665541926, 0.12405304658797481, 0.09011448586299535, 0.04890793791761802, 0.04176899054718595, 0.11433679174872176, 0.06350126553086505, 0.06549988933388265, 0.05957300031197168, 0.04237583177464624, 0.08894139840718239, 0.03411544659625619, 0.08695392884434232, 0.03960036417289127, 0.06094600990294449, 0.04020036806562736, 0.05984880345603151, 0.07079514269266399, 0.048145956224611694, 0.027309983044922836, 0.02478595507601577, 0.00494048139268172, 0.011596227902167989, 0.03357220215783004, 0.01940868051362134, 0.0464790599841264, 0.05926148214888188, 0.016975150511209524, 0.11112735832049964, 0.020670381359635823, 0.012555752069719378, 0.04447172576140973, 0.05193855110255461, 0.012509379810052774, 0.03145453978269812, 0.11380593112159161, 0.03915479594481088, 0.046932986231460694, 0.035992526719647075, 0.02443459842564358, 0.018725019819553823, 0.03944613918241474, 0.015230673504242254, 0.031950311667676416, 0.014974357721756303, 0.033608131681478796, 0.005905843150216125, 0.050850327036553816, 0.13833598984825995, 0.05134427371705252, 0.025757373716201515, 0.08683847939415325, 0.03370467408169662, 0.07256991560420684, 0.059760557788033644, 0.019364155483462157, 0.00720999627974966, 0.04530265153716168, 0.005630720387994042, 0.02623448178412453, 0.04628058958558306, 0.0613590079029241, 0.02120629816706623, 0.012306361722068922, 0.033336461581770456, 0.029823371967781457, 0.01672661243637483, 0.07427698166500177, 0.06155960419545732, 0.06621062740563385, 0.032957451072551554, 0.007894998585294572, 0.05161353063979938, 0.02803573452477013, 0.05522071691830793, 0.043778887334009337, 0.03883498487994075, 0.035999034636563836, 0.0942537738310714, 0.035570753182494835, 0.06412666523829103, 0.03478025003606754, 0.053860301812810284, 0.07490024781755864, 0.06692115097276627, 0.01751765759000855, 0.02877913667039285, 0.028924838932711753, 0.012966539906037432, 0.025123550872048064, 0.08024774071189665, 0.06065216155782823, 0.09692706828636509, 0.05406630668608893, 0.03164040611966724, 0.02452320798540548, 0.05737518598776191, 0.02607475053669224, 0.05116341184944876, 0.025748316641716708, 0.11840446581763607, 0.034470627940590345, 0.02761528248928728, 0.02035634659771477, 0.036598000480162526, 0.034171600841105945, 0.02094587998374576, 0.02325657353315863, 0.008406983763580362, 0.015306368736820597, 0.04348076804871521, 0.04446926278873317, 0.025069059037993995, 0.04618881225225426, 0.021374929440958847, 0.07363811796230656, 0.04298931115397042, 0.026327798954181136, 0.03771224089207188, 0.02895501705126897, 0.08482405119725774, 0.07214659839988717, 0.03080321757513429, 0.03542125495451112, 0.0723927654325962, 0.052062557754857894, 0.046024758353709214, 0.02314789055456077, 0.0398779025060996, 0.03383171061174043, 0.0409980571167844, 0.05495509125232216, 0.02907532349889798, 0.026731525375057134, 0.016296678147609198, 0.004117106849838409, 0.026908303994024475, 0.0287653643247341, 0.020991443063042337, 0.013138249895775752, 0.06688925107159922, 0.04112461867231516, 0.02907352127705611, 0.03566254583758212, 0.03989138565356693, 0.03947663331224073, 0.04726077993250182, 0.01412571328992565, 0.06720799727425461, 0.05728029450702091, 0.04550640028150332, 0.059826713310734886, 0.01139627799632088, 0.06531200627045286, 0.028284797369832956, 0.029392717556367, 0.04219034273597983, 0.05747927052359428, 0.04822279867385665, 0.005400777182301446, 0.04297419623922437, 0.03331167480698036, 0.026985224967281667, 0.015193772006539569, 0.07874371093367377, 0.04069399681963748, 0.119536598213017, 0.0689243636424503, 0.0131372204651275, 0.03203652720267494, 0.1288425516817839, 0.03243438539005095, 0.017372508826214942, 0.008639455059423082, 0.08380342289925584, 0.03130585743835376, 0.04015899548727659, 0.04994154374505724, 0.033543623247814756, 0.046384405990641926, 0.033193861975544886, 0.0780416219945877, 0.03520964231762675, 0.04562006091638919, 0.032467499540577975, 0.13520871168903767, 0.022052063065911495, 0.04362435973880272, 0.05147951504876537, 0.05402585724368692, 0.03138587149160524, 0.0691539142280817, 0.02914456252549445, 0.07966516148899833, 0.018240804370913296, 0.020278734230105917, 0.016702377244890217, 0.05902992824332849, 0.12692053667119435, 0.12476454308677105, 0.1757039661489187, 0.17768352202350096, 0.1977399796728165, 0.0855947356490839, 0.1618195724703612, 0.07443373091518879, 0.1039873805618094, 0.15058657845422146, 0.1658909314221913, 0.1288921635357603, 0.24017907498824984, 0.14308185857390204, 0.07344863377511501, 0.17432626426940964, 0.16695378648657955, 0.11428860481828453, 0.14984210953116417, 0.17304436934571113, 0.10693419138870894, 0.1712322649696181, 0.10275728084267148, 0.08195220973462829, 0.15189979105226456, 0.12503514832426466, 0.2380181707802319, 0.18119194424681126, 0.10613100182625557, 0.24020567356098085, 0.129450932745972, 0.16730679980208799, 0.17249839380383494, 0.09064877856402628, 0.09888489790741475, 0.08986104099500565, 0.11847617164734872, 0.09736080428645497, 0.1660645729111087, 0.2080209562254529, 0.10837386978129226, 0.11477447310162169, 0.21624178445387274, 0.17020377660951308, 0.15239319764077663, 0.1942930896315844, 0.13014081024354504, 0.16741756079418046, 0.15296485244987473, 0.0908629231215004, 0.15473693639280336, 0.09260575016660076, 0.13823937083924973, 0.08407300923981013, 0.28129722021760484, 0.09609055389920551, 0.1655523512031763, 0.12444767379953016, 0.16884044653946356, 0.1537944184195611, 0.10131800847668802, 0.17706801634161703, 0.1554540866204808, 0.1335050393977473, 0.09066003239563397, 0.14266558171760652, 0.20159288099215877, 0.12015074025839569, 0.16451396498708956, 0.12464473459629283, 0.21966791351235684, 0.12082452224867961, 0.10179427767833395, 0.07014988215580102, 0.21471556876936268, 0.23317727650846207, 0.2056128967313036, 0.09777565621921132, 0.1624975602833494, 0.10912364769366481, 0.12122071227960049, 0.18197494739245984, 0.15036019947259657, 0.13232547849897416, 0.0952418816966876, 0.11699032113556901, 0.14408126623640138, 0.10379388207389463, 0.14747826863200436, 0.1385354944655011, 0.09897989281002553, 0.23834337510408896, 0.14920686942435082, 0.1258821274724699, 0.11914566354525667, 0.14869663954502152, 0.12782462001327546, 0.11813580644347015, 0.2619028463959694, 0.13897827796397672, 0.23999049478480894, 0.17827293475068387, 0.2107304406742896, 0.10236541920852277, 0.13603786397124493, 0.13534325205029982, 0.11854308942753462, 0.0978493691992856, 0.15839561910158204, 0.14745568435999656, 0.11317702656191204, 0.11378732284591084, 0.12430924171161269, 0.10972947768506505, 0.18639801731032712, 0.1435527421774403, 0.15198271240918867, 0.259544919695585, 0.14612308973746915, 0.11863827585212647, 0.11884389385100334, 0.14405298227023694, 0.15823251898250273, 0.10931919929721665, 0.13527981997016938, 0.17545719390674946, 0.1610346694266604, 0.13880494291022902, 0.14900187961757183, 0.14269620991281926, 0.08367788407110399, 0.24635043415811755, 0.10220022000853093, 0.10425642297993745, 0.13184926292348292, 0.09899432590651898, 0.14985128726449706, 0.12707812861809809, 0.1452552040498103, 0.150047252555528, 0.083324127650309, 0.12181146566065089, 0.1779154781252146, 0.11994333727465523, 0.18166120374395003, 0.133708190593508, 0.11119526435410786, 0.09692831700968166, 0.22731049857552976, 0.12688738804671074, 0.24815401963649258, 0.10275002599002854, 0.1496542800938891, 0.15882799912604595, 0.1544203582189737, 0.288161276088607, 0.15501278933257828, 0.20901611976085172, 0.1032936649637357, 0.1467208987883022, 0.18945990220433284, 0.35348007755894817, 0.18341804253718547, 0.20548853001767592, 0.17649101423880748, 0.15255144076241603, 0.2807665664342142, 0.09174906468439488, 0.11426331625590402, 0.11773919506419091, 0.22718691327158483, 0.18427742464888483, 0.1313971331523311, 0.07278239775088526, 0.22788068249581322, 0.15894159464345825], [0.025065563761839466, 0.021879708604706873, 0.08641413563201505, 0.059680398178076556, 0.02140776779983313, 0.014364227104271132, 0.00878222320499199, 0.040117833583105, 0.022444349878858176, 0.07508068450636442, 0.06549145470583631, 0.033089976622572834, 0.019686234168588154, 0.034178438175830154, 0.03409724434717529, 0.02749188870732342, 0.007184149430794342, 0.02613636507322231, 0.004105025164467553, 0.061359578638427684, 0.03018881314464154, 0.04124789371065075, 0.03141108536041312, 0.028872421281712673, 0.021988313059292493, 0.025926280781746875, 0.009984885485121801, 0.0961630181559632, 0.033020618852348096, 0.11128749367931198, 0.04553904328795691, 0.03409226094522784, 0.023318720500796072, 0.023903981031429385, 0.05553661710432461, 0.004892094800579212, 0.06597513963858928, 0.06063318172950418, 0.03352305378704783, 0.058885689208944964, 0.02705176927960448, 0.06007986323487374, 0.08359870888412961, 0.056000701677534855, 0.06035752797258958, 0.1019139482729858, 0.09200586501749293, 0.04225657869791312, 0.02681375533762959, 0.02589431193266665, 0.06724840075138115, 0.05485214818749697, 0.007850260008126497, 0.058484220832225785, 0.024241910075708747, 0.020795150269423763, 0.026358053681530783, 0.01634475591051723, 0.008802760107022141, 0.04112386790614936, 0.015984708950253987, 0.03237751102255237, 0.013660117608284759, 0.07250531140955226, 0.053412887312832384, 0.03837904382136561, 0.04339934439368306, 0.029492573286857338, 0.0927869835868478, 0.06319211457946128, 0.021724650493612694, 0.031281212389829664, 0.032353953818880746, 0.05743736934457576, 0.035958634989876906, 0.02984760715926607, 0.021827459493051135, 0.11464409259778839, 0.06378677117848588, 0.03569859793529876, 0.037135732915973475, 0.05340799201099623, 0.039939001848500584, 0.014906156744297235, 0.03683975101598809, 0.011081234871169493, 0.011344594832119203, 0.0542200567020524, 0.033988429218410485, 0.02580890270520843, 0.01690505538135767, 0.045018340986702716, 0.04343818505144408, 0.04129510387898453, 0.04920311159484329, 0.08550216924519309, 0.019912994278955366, 0.021135735723580566, 0.07964088416267788, 0.02242658621511392, 0.0350335072125158, 0.05349598103953947, 0.009571894188411534, 0.012917706588914078, 0.009353053511961574, 0.04533904071356501, 0.021572811867020304, 0.03651340905156347, 0.016915489498886372, 0.04302582673488125, 0.03095731807632312, 0.0666757500279815, 0.026619946584105495, 0.055742231272761865, 0.028338333509201487, 0.04827146440924657, 0.05551328972703027, 0.09860963485534154, 0.0689937482257524, 0.01700627666357304, 0.012877637317644493, 0.0379885419932825, 0.05033602923034661, 0.026621423218579545, 0.0013533195752027116, 0.038445379374729055, 0.051099251985790274, 0.08681213363043724, 0.007838035160074792, 0.06485258334226186, 0.007335349331579863, 0.048258735858384645, 0.05800404841260565, 0.048157248360615586, 0.034827437221763596, 0.10037435669331782, 0.0437991580204858, 0.02074753024405049, 0.03976520714199832, 0.02685871703790561, 0.043053313969604434, 0.05912923622095297, 0.04958267368736768, 0.04904836183413864, 0.030010548315101096, 0.024937544724032767, 0.05146247725332937, 0.055389677610007994, 0.023119796195157596, 0.06892496119103125, 0.012516612637667887, 0.009936942745210424, 0.04065367378174298, 0.03015625632307943, 0.055529396725638266, 0.08521010588494041, 0.020935330953028415, 0.03364354409577866, 0.08873071656712601, 0.059888172714460286, 0.013143192120497266, 0.07539044449766798, 0.028342244388054938, 0.019590934746027477, 0.018930938507940982, 0.062380762350174694, 0.024057501221015572, 0.020770413290348747, 0.03135398116653725, 0.01809677026504951, 0.07448614665096806, 0.03076557776019458, 0.049177807710704305, 0.011874570627696814, 0.034363666744602304, 0.018961139609135928, 0.004428677202668041, 0.028826266399494586, 0.025565143103801438, 0.013187656821232411, 0.08429756493217523, 0.007247112282071143, 0.036886980336519985, 0.021755991150595008, 0.056551335033990686, 0.060841147787868984, 0.004233468423462323, 0.052833663555042404, 0.026745426040443204, 0.058649213188478065, 0.04433815450137181, 0.027852197095090826, 0.024148387977132396, 0.016818121638930133, 0.06514387295371102, 0.026149436448430343, 0.022740055987190817, 0.013357810694874536, 0.01804644786452334, 0.048672748924863916, 0.02643408790801562, 0.03620480585302557, 0.07888677019265392, 0.06134289707387648, 0.07550478312036685, 0.04652834242029537, 0.05081181579660024, 0.019439722396313183, 0.01418793686635552, 0.01813382976838658, 0.05897065219018729, 0.036687927711154186, 0.03327605937938056, 0.026876068929390564, 0.024658432080140038, 0.03246814688487399, 0.05179938740066944, 0.09686510709504928, 0.03408559214984698, 0.07288351369601104, 0.009952751927137857, 0.07681194362380812, 0.049414770197003126, 0.015686195129678858, 0.011675000892982129, 0.048956450435423085, 0.00768752234439636, 0.0631698175904251, 0.05959681798553756, 0.09241223635692751, 0.03875043558617754, 0.04400006457862835, 0.01752425935269604, 0.019766970259708264, 0.06523150575136946, 0.037376993155527505, 0.07738621845360726, 0.03049781853933969, 0.05838199022917017, 0.020149140881614822, 0.06506940920747097, 0.014653110242028151, 0.02188063365587544, 0.04837882397095523, 0.11302103573877005, 0.01582566526673374, 0.043495434802025564, 0.05394046142276737, 0.055866257077263254, 0.04937253960017716, 0.04025963262744969, 0.019216306259735458, 0.030366687269340602, 0.02788312023415441, 0.043357186575209906, 0.05186535140138961, 0.03666222546129458, 0.10898457975277018, 0.02578467325938325, 0.06884290551346156, 0.03299541455963927, 0.008596752360913782, 0.016608056499652805, 0.05415185955503295, 0.09098722088721492, 0.05414475408953525, 0.07629504111865837, 0.050433314735850984, 0.025212068501259052, 0.08616822906920026, 0.05967606212042513, 0.046028814789268284, 0.03655568178322527, 0.015951555537720843, 0.02568243308022859, 0.0659555814138824, 0.05454768952462943, 0.06580191949803023, 0.022007566764049476, 0.03756894797627484, 0.06869762459950102, 0.029853990586895137, 0.036843470372860475, 0.04609500478592612, 0.061378359283891425, 0.01509861239502507, 0.03794192554309003, 0.03776159993703327, 0.02263367893324504, 0.039666209429983175, 0.06255268014126247, 0.04843644144374037, 0.016572456393811493, 0.07710914743403274, 0.02611243823212722, 0.0054329734637341915, 0.023594481510020072, 0.0534581516178385, 0.13737340037140156, 0.03064400343705089, 0.02017423983723406, 0.040425973298448714, 0.06811968020854459, 0.07919413232875448, 0.04319834590498959, 0.019546354174493782, 0.09816191775063354, 0.07763177261597688, 0.012527778369164275, 0.024336418512487606, 0.056598464763092424, 0.10802384420868852, 0.038359516240175695, 0.023903247502241886, 0.032281573831794724, 0.10029400173094004, 0.042120624904430685, 0.037389775332544124, 0.06595578825762195, 0.10149361881157083, 0.04377663503551195, 0.032849539927537405, 0.037541663754851594, 0.025923766098135424, 0.05157523773490422, 0.0956444455791385, 0.013944585206768206, 0.05281439644374675, 0.01664523857705776, 0.05113256148873799, 0.02966107624102264, 0.0208069690908756, 0.020838169936811732, 0.013964251641394391, 0.06370255896340936, 0.029696739549117706, 0.08514324939178844, 0.06038632521766329, 0.034338259438593546, 0.021322718633699323, 0.024326991800579335, 0.047807322379442, 0.03565319573446628, 0.028093158560354384, 0.037579588937543096, 0.03095480722315129, 0.021379347853062135, 0.04034805066523053, 0.02319527692311714, 0.016522097604108915, 0.012312776750824865, 0.039644264841392156, 0.08528767994815305, 0.057895099218454094, 0.2079192657143839, 0.12445420852952427, 0.1842018424142753, 0.11795555361576619, 0.13193390031735744, 0.1643153643535991, 0.21089165621707517, 0.16069964385561405, 0.21078182985225033, 0.10195444368066327, 0.1015951790876927, 0.12746788351045502, 0.17336752055393112, 0.13207551933103992, 0.1337018014202195, 0.05009308359735916, 0.09576164170979493, 0.14826678761070775, 0.09171050747916584, 0.12597558253835286, 0.13615622455554624, 0.16317721816801256, 0.2483018133188448, 0.14774836059058868, 0.19328283416407724, 0.2838292940249366, 0.19879613912874655, 0.19784258948939462, 0.14473225711093796, 0.046286741271615035, 0.13513173517440596, 0.2571424373215245, 0.10516110387059951, 0.08973509614025393, 0.16831201441105337, 0.12065291089276153, 0.10381662722436652, 0.13565550948823654, 0.15251402502819417, 0.16076894416924448, 0.2731467188606339, 0.11574883734987629, 0.1498873240404552, 0.1526804040035894, 0.1702711310598158, 0.20326990874544268, 0.1229607737472942, 0.1192893663180932, 0.187880780487772, 0.14089334455709304, 0.15890457727495702, 0.1442352192656648, 0.1711348339074081, 0.10035787814206655, 0.06414446146077206, 0.13413638777790532, 0.11738219809147621, 0.18934685827022602, 0.1326951925312319, 0.10513499559414004, 0.08802891874145116, 0.1925597544158659, 0.16636172309517863, 0.07053016820141385, 0.15392021005672796, 0.08266143861316866, 0.2102330044632958, 0.12414375905908885, 0.11122036139450728, 0.1169047337926684, 0.15659345854674617, 0.18096738855444616, 0.16320988415710388, 0.15080819236895732, 0.1251055671262645, 0.2642468609396489, 0.1807457899614688, 0.2551651337454396, 0.09491610280688732, 0.24201465229834282, 0.1047881416255428, 0.11462394448537981, 0.12022836794776302, 0.08714509842496726, 0.15104184918586286, 0.1480938356009222, 0.1954225177365926, 0.15808464869135813, 0.18207720480859282, 0.1764785270056417, 0.22642277121063203, 0.13058075921670084, 0.15994639556494453, 0.21503795388965838, 0.16228106383594776, 0.0846249909110127, 0.1701601095978291, 0.19156897290339395, 0.1102163265609453, 0.15817342296002374, 0.2068996026871666, 0.1458185697875677, 0.13788326252852717, 0.20703403579611934, 0.15944872952757344, 0.13693113781271443, 0.11677422305388797, 0.08974998122862271, 0.0944505358535436, 0.12117257897531795, 0.1331402589717219, 0.19784692554704605, 0.17963779699658194, 0.13667224605958309, 0.0832775035392373, 0.16276667164939065, 0.14389686887302708, 0.13096360399598075, 0.11785968537292174, 0.1645173510957149, 0.17302676464521116, 0.10986833878222013, 0.1017904012734371, 0.11610290020584099, 0.16048259582490693, 0.2873976090021672, 0.1710687358413012, 0.15117312601256758, 0.11457570392878787, 0.21872211668279865, 0.1352146258878131, 0.07409260728426519, 0.1585227743752541, 0.25122396377546174, 0.10393497248690936, 0.1556821663172976, 0.1266565044680911, 0.16609570672435148, 0.20637792745424857, 0.20808163038905592, 0.09586818921830385, 0.18307753177660127, 0.11980070702491269, 0.11341436826173337, 0.12619885120300517, 0.1548194134187314, 0.16995927198759972, 0.14190386049449444, 0.08543855330396084, 0.12503624382999637, 0.10653241657682004, 0.13563591295913344, 0.16661168226311285, 0.11635991504355786, 0.15333502613488706, 0.13885513699102786, 0.16804351591535155, 0.15649657906784167, 0.26005424559116364, 0.15126545492920185, 0.12578759222261368, 0.08175328734420961, 0.11826379675297968, 0.17867782754042458, 0.1380495495733715, 0.10580039658253232, 0.13905566816608753, 0.1350216023744114, 0.14060606158548786, 0.06695151103720551, 0.14152990233513618, 0.10267351678903065, 0.11868348270053826, 0.11069787410838951], [0.048287548425216834, 0.03281448374412233, 0.09757605967141929, 0.07398763791688028, 0.049149067922224926, 0.010417280831344185, 0.053937565610413594, 0.03424164809046253, 0.028459515212283983, 0.12240526807163993, 0.03711614021731, 0.03205211517671424, 0.0032509295382506906, 0.026870497554961233, 0.03460238740268735, 0.037979823912704186, 0.022595012560486797, 0.03537030244666723, 0.07646095278041978, 0.0779999238288691, 0.006856288218254885, 0.04317974145974844, 0.00894409471056274, 0.057084819512261506, 0.02651008191488443, 0.0275480103934364, 0.09106291037413383, 0.07320026807006329, 0.05649956664250744, 0.04004993521037602, 0.06458806084288705, 0.02956093705800032, 0.037966222021608584, 0.03769872327064795, 0.042613675262057976, 0.06926237695640133, 0.07800277367594742, 0.053973755603956605, 0.040497985563331076, 0.05027712472984868, 0.01311131232913824, 0.044128208105722745, 0.03734595127283566, 0.025399133765829668, 0.01768761994166961, 0.029261050024820916, 0.06443977686426332, 0.058824463462036465, 0.07885736773812002, 0.015995048264402057, 0.042240812608431426, 0.014946019171827264, 0.044744679058391246, 0.032039426845468344, 0.03144579297382265, 0.0292180763227084, 0.06895031104044569, 0.021676442495757536, 0.033443265729734016, 0.02498789202241648, 0.05289989568653607, 0.035572990159233736, 0.03104830633908991, 0.028739985747022495, 0.055215338981079484, 0.06756082672866122, 0.0424504027731957, 0.03329728767576237, 0.025853316652618592, 0.02113017201003048, 0.06711658766312946, 0.023183437034247384, 0.046321310989198186, 0.08844658221688964, 0.012775601109399671, 0.023268382778511416, 0.0015768791138637633, 0.02871302711296707, 0.05869278826961114, 0.03513252407672905, 0.021670488077366067, 0.030275386825744665, 0.041225569908537214, 0.04085152747950727, 0.022718463799044974, 0.01302911205247285, 0.03491544540250494, 0.05825116156390118, 0.030232642950009436, 0.030103447967238968, 0.02050299497862016, 0.021613069787441243, 0.03430509932279106, 0.02261251000867736, 0.035753740944088466, 0.04954508941380247, 0.08348363481702344, 0.04827657804614113, 0.03497076078107761, 0.03159590981780522, 0.01999909490076525, 0.016772384274630778, 0.04142454592511058, 0.0948196140328242, 0.0684791133408585, 0.028461426601655064, 0.06284091306189377, 0.06660815809042224, 0.019092742023208452, 0.005813948988478872, 0.03764715406202501, 0.07961340458883394, 0.06229797505863732, 0.0394489583859761, 0.019298597509341858, 0.04273817604107242, 0.030108107697038405, 0.012828157613835028, 0.05371359597531058, 0.06855529312404894, 0.013017549870475646, 0.032409682884932525, 0.0611465678910815, 0.11966333213833072, 0.07150388127493282, 0.06667512949676284, 0.05488868292060591, 0.06507805067925684, 0.030571713465295976, 0.03499973805681352, 0.021642612053021308, 0.01370794830783721, 0.0378300077582319, 0.03375239752893967, 0.03646873463425906, 0.04304631575641613, 0.026725379434684594, 0.04497763107440645, 0.04805905887136056, 0.03861923536826526, 0.02160726092575539, 0.030482690218054963, 0.046422124329593875, 0.06752161834869655, 0.026524926783637177, 0.042308055975985144, 0.0022488221340256956, 0.004611913942837067, 0.11012713094392132, 0.02960382074478173, 0.030739191776862552, 0.039251690745473876, 0.029338943929741942, 0.0967704339493667, 0.01794170449307609, 0.04951523496739326, 0.031657643097963546, 0.058522394993492675, 0.014286224031820895, 0.04813262246428959, 0.0564992027507434, 0.05509238186923247, 0.03046473503232964, 0.03218590094137096, 0.05233250798717622, 0.018640926348105557, 0.1389867202529023, 0.04488932794981426, 0.03986821915473669, 0.06383516112222307, 0.026522414015245535, 0.03410088709525524, 0.059602873910578995, 0.013936305711526546, 0.028979470577812003, 0.01513619283815065, 0.037697585630080396, 0.06867293358570145, 0.0629929738539842, 0.011341865643888954, 0.042412508234021165, 0.01849317097014958, 0.00935822843589009, 0.03060655131365263, 0.06041397716129019, 0.08636086187776058, 0.033280579298133814, 0.058178590054834084, 0.030208193253906026, 0.03167055359470748, 0.06875691980484032, 0.048804140664757266, 0.03438928472479025, 0.023438119134234808, 0.05174401073506282, 0.10321468895962162, 0.018809540385019877, 0.03537208360109118, 0.03421020018117082, 0.06332573563521428, 0.07065483368933201, 0.03291636960761201, 0.009247365937147652, 0.02399230139299987, 0.040212774859561075, 0.05262826772166356, 0.0742064019845378, 0.033640192461109934, 0.08427369363245465, 0.04376611664831158, 0.035245794006773544, 0.004598884223659914, 0.013363649242467458, 0.03550387753714477, 0.04895312944427133, 0.10228142532850466, 0.011314135176249811, 0.012629157657014027, 0.021569230405974294, 0.025972217328906543, 0.05176806206544561, 0.018022888745631904, 0.06182878067897213, 0.042242180075376265, 0.04305051774868081, 0.00451157174651481, 0.015927351947363107, 0.05258350137380823, 0.06504852565065508, 0.11398847455218916, 0.05264242885694389, 0.06667352071212185, 0.1071739922307672, 0.01653235169097541, 0.07889420124551944, 0.0445855281225616, 0.034283162395079295, 0.05509853738570406, 0.06472839282885676, 0.013392050037040346, 0.05399304952832961, 0.024004987809025956, 0.01330204715486616, 0.0764796759692892, 0.008974953689762663, 0.0057360024150130496, 0.03915442056172798, 0.04378671675259548, 0.027736768712319677, 0.04098196927037451, 0.028506005257968942, 0.038096885977973866, 0.06732253507981378, 0.03737844872258363, 0.031313788363589876, 0.03431654084594019, 0.05628902269827743, 0.030425825426655433, 0.04829873330891133, 0.04091542304283188, 0.020345621366774844, 0.07600405028149967, 0.00936178116863894, 0.029909372998161182, 0.013884438686223041, 0.03278218547723467, 0.07167413665522492, 0.02542421165403099, 0.039479927490315134, 0.004650485512214683, 0.0802664868834038, 0.03327357342406627, 0.05664458708657373, 0.027179200344929294, 0.041434868959890264, 0.09817307965169031, 0.0918579027957974, 0.02937834957734712, 0.02975798636344412, 0.028956122133099747, 0.10475037349087578, 0.011696285688348356, 0.016487137181684375, 0.04045811068687228, 0.027170664210233, 0.015092786296360917, 0.029819482156345924, 0.028232892997743144, 0.0619355695051772, 0.006408791842630074, 0.059925979153523525, 0.007695640003564017, 0.015347320924422916, 0.005957479870337392, 0.04288202820105418, 0.026699861045926813, 0.049132930280099955, 0.04235887824888191, 0.0755502887430691, 0.09720790079764782, 0.0242778759885339, 0.05682857076246893, 0.05364040393502482, 0.029567944847287673, 0.042342192853891084, 0.060976661080794956, 0.05144055947781571, 0.059062598062859434, 0.04393553316232659, 0.12011163913074041, 0.030572502535857984, 0.03809872458899214, 0.026615007232213696, 0.024641325336790854, 0.03541744366708783, 0.015121716649211464, 0.007662510531278508, 0.09344651634174009, 0.09099593130691398, 0.013537759960238493, 0.025553753291587197, 0.037485226057469845, 0.017766745332928918, 0.03414541212541442, 0.05789622919814241, 0.06253204556302198, 0.06536554049460158, 0.015609543244805069, 0.025237753514140367, 0.07087371267017818, 0.02377515760130219, 0.01818113186727128, 0.04475476077547477, 0.09540780868020751, 0.04060792301090495, 0.04852346520149901, 0.03511728658791512, 0.011994651079388156, 0.016724180107215242, 0.06090351117534503, 0.02230082905190366, 0.06824052291772059, 0.02213292939197873, 0.02526575785821244, 0.048208105107468945, 0.08804999382024811, 0.004923069650577682, 0.09379203731734907, 0.01462430246324549, 0.05901407405373551, 0.02645744592882693, 0.013934311967703604, 0.09831311286336954, 0.19188317620465833, 0.20325994960242705, 0.11233487376762975, 0.14171011685844392, 0.1004352223789019, 0.13543476891373435, 0.1387342483165764, 0.12489861613439938, 0.17353146336972716, 0.10024144043845516, 0.11600733073728701, 0.13298051431775093, 0.1489182534597574, 0.136252322624768, 0.21612803571887557, 0.11339084170157872, 0.14189236917563025, 0.37301875170200105, 0.2355398150581506, 0.13667826751066794, 0.13666944217778024, 0.06916328348339566, 0.16659105917619121, 0.1642656452473133, 0.1084775367992059, 0.11626980778190399, 0.1781052074605419, 0.21991431803232242, 0.17659926246250832, 0.14524959628620457, 0.1313105652168874, 0.15437353492504166, 0.13982587764340063, 0.12581691806835513, 0.10975690363275428, 0.14359492297855117, 0.14220620475469098, 0.09452745108114136, 0.2725539200248257, 0.14350319161049782, 0.1353381652264826, 0.12220824557927348, 0.08749968222072048, 0.12170357749827447, 0.14888209410973136, 0.1281553861354628, 0.18639810924087802, 0.2202467389044262, 0.08426244746172622, 0.14523021426172028, 0.19814242098119952, 0.11255120167568808, 0.17004312797179147, 0.14868128714301895, 0.1367313114385451, 0.23800111766303741, 0.07840861641471425, 0.1933775226315183, 0.14719285491493442, 0.08849549693085494, 0.09706435124239615, 0.14708794683458346, 0.11635120462385878, 0.13938559159155817, 0.16564906214273747, 0.25224567991831615, 0.15543199264474455, 0.09441116659511482, 0.12421459154856783, 0.15438666567206383, 0.11108603553786395, 0.15220215063421957, 0.2055262521870675, 0.1844025574504368, 0.1457712561973641, 0.09978682854242864, 0.23030844577137502, 0.09162903402841861, 0.13216672975930477, 0.10324140244554128, 0.10827552707445239, 0.18743726154488904, 0.08121682661435298, 0.17550053916150526, 0.11703412604307938, 0.13762178139821177, 0.09953745160131686, 0.10824461542670766, 0.1554139436132485, 0.12808493668994597, 0.09717419292897948, 0.1649898741274111, 0.1813033793962771, 0.14351040815874455, 0.16332499652860627, 0.20535624195491115, 0.11499483063216172, 0.1019019743187293, 0.2458531818082256, 0.19675307456524144, 0.14279742544937518, 0.11804415168420923, 0.15993648238720434, 0.22693275594182555, 0.1219081306349366, 0.16780578351068884, 0.14484700176023668, 0.16605804584199385, 0.15429266668375463, 0.12072165196220722, 0.1301139052356443, 0.1842684920636877, 0.1286256875121786, 0.18523316529970016, 0.14473706814310244, 0.1265948343901865, 0.1259624671130892, 0.14482806406674847, 0.09135112797300662, 0.12172779353756098, 0.21929751000096723, 0.20779192657961001, 0.23025293504038166, 0.12845456645253206, 0.12563301100125238, 0.18546250138071277, 0.16349188112203153, 0.11936776009538483, 0.15515184961259365, 0.2130232958663856, 0.1511175233510233, 0.0937147620284269, 0.17652225530435964, 0.1546699343429458, 0.12573809528182592, 0.12813018950363322, 0.05883999206426163, 0.12621267909003844, 0.17885756708921927, 0.1504139482013641, 0.12786327680993465, 0.18293076465206762, 0.14679330941890517, 0.08506272589006732, 0.12632772251362764, 0.154800659586345, 0.06636389861664464, 0.167048045944783, 0.11664438647248092, 0.14506097011748822, 0.15944883677988284, 0.11851120484812606, 0.14047967239974007, 0.18513594874210898, 0.09015535665375572, 0.10408275084750307, 0.16354671769565152, 0.1102201570005667, 0.14008008093843538, 0.0803725287738827, 0.13440457983843743, 0.18132653057334885, 0.18866217484877956, 0.14914123101099847, 0.10378280444250954, 0.1913047338565511, 0.13361218445483716, 0.12417311554834728, 0.32611989085712745, 0.07102193536176797, 0.13674632676186102, 0.13301203117495583, 0.11871209608451014, 0.17082528842072334, 0.1658990213106717], [0.025282414524906108, 0.03710306692688215, 0.04843194067718522, 0.054761677034079075, 0.034351803873094826, 0.06008090894489039, 0.05586810717960039, 0.09294012456291145, 0.029558200208890825, 0.01313297154997746, 0.018924943869933486, 0.036952622580311956, 0.011565988496576828, 0.0021441963091943296, 0.04358952955132531, 0.020186246350227345, 0.059784792979518254, 0.04509015789916439, 0.030372565078939644, 0.07689348602246854, 0.0313858465937477, 0.10484438780094348, 0.07801513833504531, 0.02919453061035564, 0.09503979536314165, 0.04557410330181161, 0.04113921647771232, 0.008951083347651987, 0.048752364612394766, 0.05997774754500678, 0.04369894605911067, 0.07268263012050621, 0.03137204168935216, 0.08348451581813636, 0.03724225744184467, 0.0313355375997602, 0.020516196588775324, 0.03587993860785519, 0.042117759735593875, 0.024194715229133447, 0.045023316727770914, 0.030135367020604112, 0.014451590813546172, 0.023589930947749846, 0.04828927595348609, 0.06267304021504617, 0.05892194431996154, 0.040642174801999525, 0.0441558332362723, 0.06041123456652127, 0.10859475591250005, 0.04335554331661232, 0.056572149642893386, 0.05374759878782977, 0.009762633802188982, 0.05057995162543751, 0.05194102556655004, 0.022409776330835397, 0.060107473043664816, 0.06334949202174622, 0.0422185615846707, 0.02677444928145457, 0.03972053655513352, 0.045611519036033464, 0.07424713487947181, 0.02434117974893701, 0.0395918874100091, 0.034514114921612125, 0.09599085521673965, 0.052959459022648876, 0.09650853913157217, 0.03452827605689245, 0.016912030611908244, 0.002572550302213659, 0.018171592157394178, 0.021608705001492656, 0.013773331996954739, 0.004100171518662284, 0.033849035690148035, 0.04122359723213219, 0.0400328208061476, 0.05125800838633891, 0.05467020613591998, 0.038621269331704226, 0.028494090675526572, 0.018202051813263568, 0.035914094637959235, 0.024664599087930495, 0.06910738204756091, 0.03775455958900913, 0.04241869822444935, 0.04817368860747065, 0.05987450953633074, 0.00977807526191276, 0.036440699646670016, 0.01066139474841616, 0.03906933883685739, 0.022707324880625934, 0.01637752915191795, 0.027265745297735258, 0.0362120951796251, 0.03973781183782605, 0.03209806129997296, 0.013725645896497995, 0.026739373945841388, 0.050583958265281496, 0.0896279740658018, 0.06435925336254221, 0.013930666346793935, 0.031220126453967347, 0.007090744639431397, 0.035061488573950146, 0.04865720500088027, 0.019451162004242503, 0.025853757153175054, 0.01209784408039864, 0.05358673181504973, 0.047941441392345775, 0.10283348360849966, 0.04760684100009742, 0.04230891016402072, 0.03008357181604351, 0.019826466563127695, 0.017949667977048986, 0.06722761678599543, 0.02665198055065928, 0.059989897699485865, 0.0766068005994443, 0.018489907435592146, 0.01689049396513691, 0.08488661759803373, 0.0267640381465636, 0.02421527319858151, 0.031988976125214855, 0.08842489426775325, 0.08655649009010485, 0.06289356245448993, 0.06733758104664665, 0.1138826012010536, 0.07696144568223147, 0.0077807380078029975, 0.056584292136493235, 0.029178720470818303, 0.019196165808206125, 0.042331302914047436, 0.07584922391200259, 0.06633138584513819, 0.02008978438924157, 0.014614682314136337, 0.06079486458592358, 0.037913469207142635, 0.034422395044877645, 0.022823818125611833, 0.06533543323917736, 0.02218485866192608, 0.026563497395404888, 0.04434530593214497, 0.048079685788721814, 0.05233378735400977, 0.022207787673499797, 0.04981607003437896, 0.0675556326525346, 0.08154769998884971, 0.04253793980986361, 0.01931201170889601, 0.018998926896001064, 0.01865227785592358, 0.10096949209729511, 0.06436274672347693, 0.05355457144398844, 0.02543950659943925, 0.03629235055057272, 0.04710236061063986, 0.020900188584721858, 0.10743066998979739, 0.042810958224318685, 0.02483250640873467, 0.06323221545185774, 0.01646568097414509, 0.025284620858128035, 0.030688978543865587, 0.044951495984869624, 0.05359350403230037, 0.0500426558597434, 0.15949760593714254, 0.054377005135099736, 0.06836479003991812, 0.03508549393905747, 0.049729165020248586, 0.0306753613310115, 0.031052581109707395, 0.023057683701476744, 0.06540354611652513, 0.07100164935353302, 0.06715820155917637, 0.03738151690472038, 0.023416348830646565, 0.09414513490252918, 0.02018417791283179, 0.05499295897841935, 0.014114921026292348, 0.044212301577171015, 0.04163659906255142, 0.025247038499782645, 0.02585513611143876, 0.043583450643646146, 0.05797538523291869, 0.05570334848016501, 0.031552671815358826, 0.04785743985144843, 0.044279196374719186, 0.05943694309661946, 0.039879066959744504, 0.03974626178763086, 0.07440455062615295, 0.05547707675084953, 0.04713757767251903, 0.04180234984584874, 0.02503187121492961, 0.04213189788823647, 0.004884077690451617, 0.04130280689306317, 0.03955011646593771, 0.03928004365955149, 0.07482880245774023, 0.018136951576678023, 0.13204718939960003, 0.008194411601570827, 0.044149156780012196, 0.06831655714420543, 0.029879980119726354, 0.04545397305440518, 0.04115806224064962, 0.023047295549223502, 0.03154506647749053, 0.03321794394944464, 0.018517770053398226, 0.10989361968372138, 0.06762389108658799, 0.051668106743525115, 0.09795690496121684, 0.026252827674691236, 0.004605687563232477, 0.04316516280654938, 0.05410017926366099, 0.05921006232740418, 0.07521999759539481, 0.029127926926218697, 0.03479164942438084, 0.034573475244425, 0.029322595613437797, 0.02659849995266526, 0.017913070041686296, 0.025783397722989324, 0.019123623027436195, 0.060516334168853304, 0.06250796741956184, 0.05298047664485151, 0.0174126633247661, 0.030908230992574847, 0.05096684517939726, 0.004984941305367337, 0.05986486065892443, 0.023662504372036746, 0.03125131772380443, 0.03959212489726563, 0.05990893369720829, 0.044865540919765357, 0.06199789075781742, 0.02044708205146655, 0.03312143985362303, 0.016803851336120598, 0.033480378859225786, 0.014345207056331058, 0.03851360333482585, 0.044547694870421005, 0.04139762942589099, 0.020040745185988567, 0.07146815859502362, 0.006002154287641809, 0.09501484387944784, 0.03149023947996959, 0.015155299070982203, 0.05662579111935151, 0.02210274744298189, 0.08648509069556191, 0.05713515531932635, 0.039643353196762265, 0.04345010920998551, 0.03130064421002904, 0.0523090771880121, 0.011241936177435902, 0.036878518895396305, 0.03355796058331767, 0.01874421032205705, 0.07184169540602355, 0.04483438029344525, 0.02246597079530118, 0.03457822881999516, 0.029744830718564413, 0.04111158751672314, 0.03898577396607688, 0.06535967226110159, 0.004831456547347649, 0.03536011730771392, 0.030152920010169188, 0.040264083598289764, 0.054570710466754054, 0.0621271949081171, 0.057863911779056636, 0.033000788666428096, 0.03545968958567228, 0.03609129077484531, 0.039745212247174595, 0.00423651936862077, 0.012909999744395816, 0.016038875196940236, 0.06283635100830468, 0.038870389633361375, 0.04692169026501718, 0.0360614363284361, 0.06473474369774904, 0.0834969417642682, 0.0068561929360693025, 0.02961546528123079, 0.05802076062067382, 0.04992162928946557, 0.028819712517302365, 0.04382896267117993, 0.09137185065135842, 0.01072442367477643, 0.06894413637177599, 0.04671607992701954, 0.046664958879832304, 0.05797595596842228, 0.03436848543764603, 0.04733160476110155, 0.03872677496063613, 0.07744713776534604, 0.05647109881524117, 0.05153543946723785, 0.014976059394558112, 0.0460070004356244, 0.07775335076956019, 0.05880136591111941, 0.05329010257076833, 0.06542917941847155, 0.005648772292319806, 0.026244875682037205, 0.05383671396562169, 0.02556788378335055, 0.009252954548555277, 0.08740736862584468, 0.1573885352380814, 0.22047858775383045, 0.12861186728602456, 0.11166784101195874, 0.22939546814849301, 0.139262251435749, 0.14277690961476297, 0.2786436755089991, 0.09558387866784489, 0.2057030806017499, 0.1619295673745294, 0.21149311184642777, 0.15530453093590277, 0.2473134373224551, 0.08019227594617875, 0.16674168738386325, 0.11810666445883052, 0.12733092231135215, 0.1732107176775894, 0.10179370311239075, 0.21494082926261812, 0.1213386744981812, 0.15428276882777292, 0.19191015782135148, 0.11427990972034394, 0.1220140805948646, 0.14328603632748127, 0.10344336620501934, 0.18696525945298134, 0.18638070372323837, 0.2313775674349839, 0.08845336209501951, 0.14866458642626965, 0.22566532475813744, 0.2548420744677705, 0.09239086250384008, 0.1467255566028818, 0.1728217748384322, 0.13768089274244924, 0.12676931857582063, 0.1436298106226229, 0.12351901435683812, 0.11816811237123706, 0.15725784063819917, 0.13186859898269176, 0.17115968579967178, 0.10622349928223318, 0.14951333523757998, 0.13739552499065477, 0.2497928196023549, 0.05884836540527402, 0.15507527146368258, 0.1308220769128492, 0.20110848359763625, 0.1617778513220049, 0.19551489261850236, 0.07138668514427639, 0.13950094911119632, 0.14063751715565884, 0.14445766055535886, 0.15179666029589792, 0.09021138066365834, 0.14155461633157346, 0.20110155816280073, 0.11107622195155391, 0.13207558061807387, 0.16630996619501423, 0.13548595890883477, 0.1443123030326059, 0.28702320651181285, 0.12663266381188748, 0.12761955359770408, 0.11867419005401673, 0.06731197072733795, 0.11540107173664917, 0.12097483636030268, 0.0870684130237468, 0.11497149559398813, 0.15594239106341717, 0.13030976327436586, 0.17192172877971204, 0.15275592495116497, 0.11678346973513404, 0.14220137840076802, 0.21867912382848803, 0.16186690138232324, 0.15910254971634957, 0.17497985984288877, 0.1333332978068821, 0.07968265127630965, 0.09656051053635537, 0.2222667901866859, 0.09809947392392544, 0.2125527186980171, 0.12259410874497507, 0.18845407472502804, 0.06365307734438008, 0.14952425965138022, 0.16384270342607654, 0.13057256207591103, 0.20478687008782742, 0.17502355749808973, 0.11652141403887542, 0.18507018775468875, 0.11642988185368239, 0.1480034525476156, 0.15726350968883884, 0.1710031433932243, 0.1660322286789456, 0.15285263589072615, 0.11581964685671753, 0.21023916381020702, 0.09405345716063054, 0.16021884707433565, 0.12985467640382628, 0.1363571847398435, 0.21225325492841585, 0.16399296391154491, 0.1520583865743491, 0.11068636746776682, 0.09718616688323599, 0.16151961840448842, 0.13852907464869563, 0.12542359320627106, 0.13433826726771173, 0.14393937143106617, 0.1172131914345007, 0.11182607647271887, 0.10545604006056825, 0.3014508791027531, 0.12350811292567562, 0.10203015615021992, 0.19130942231464773, 0.21049548150791278, 0.20322991895579523, 0.1036496430395111, 0.15924749355162346, 0.20383051656667264, 0.26677504302032534, 0.2036458434116456, 0.12076963970978415, 0.16517738180775798, 0.10147290379409829, 0.1273430111787973, 0.1744401202567162, 0.17567548299989394, 0.12792256435439472, 0.09434028047948115, 0.09820894022742588, 0.16991076330023427, 0.21824842919745754, 0.06575612276191674, 0.15357180859052366, 0.07009667734945975, 0.1592182596364329, 0.0823947404240889, 0.18097889519506888, 0.22451118265669193, 0.09720974706954534, 0.1331746409977636, 0.1991480952429195, 0.10775201323051607, 0.1077327614409789, 0.10121301612666539, 0.21323082908507318, 0.16519111010336107, 0.26410731036336194, 0.2514294898437877, 0.11984941489513844, 0.16858659564487397, 0.14494890677592448, 0.12491455842410365, 0.19668167517069848, 0.16230602298052083, 0.08643050693095693], [0.0217243651258609, 0.05214102814094194, 0.00759423821188149, 0.0734573288730556, 0.08817190139163887, 0.04185170889081013, 0.024896675848492214, 0.02720352172130539, 0.04433028294794983, 0.06163676457119085, 0.02509124494428116, 0.02386728925029597, 0.0242263316777685, 0.017635340186496897, 0.01990972882917812, 0.07726450240419758, 0.02036685923925571, 0.038727406983173666, 0.05702227226368362, 0.03592847027785836, 0.008362899233977641, 0.04582681655583363, 0.05412346067567987, 0.052285179075214176, 0.033007246787629785, 0.06418725896266199, 0.025662233256885124, 0.038893506336476535, 0.047436175762765834, 0.022309972311279947, 0.02879625873550052, 0.014025745519076385, 0.040957320391410784, 0.019508769900928584, 0.048782808946505676, 0.009385374761486967, 0.030424379435698354, 0.02946282992319715, 0.050142760568809126, 0.027843726077868093, 0.037137100382918314, 0.04792720364827303, 0.027725045651858373, 0.04295099526643754, 0.009366134463268663, 0.0075840152473369195, 0.015668161419941293, 0.009970638164949995, 0.04278784918208276, 0.04974448677873419, 0.02125428974508278, 0.032547142041186174, 0.042390847097962134, 0.08571140317907257, 0.04348095190981704, 0.014988288073049439, 0.01901539204071366, 0.07260972919363169, 0.015535386891344623, 0.030292955137068228, 0.05296095289410122, 0.035189647422803026, 0.046019073981311054, 0.05151693078298723, 0.026526991390593113, 0.025979772871059757, 0.0330328073112234, 0.01601647191320456, 0.018107495495989438, 0.01902431888025134, 0.04235116757392403, 0.054443827154295105, 0.09041374278885704, 0.036665933326848095, 0.05318953054806879, 0.014392241024442259, 0.06143534856457865, 0.05365243151543602, 0.04787362728928847, 0.011564810636393245, 0.043719339319655014, 0.03634759698123221, 0.051377119736806046, 0.012544379494483433, 0.05881715881367845, 0.013636043295264246, 0.047981408199355494, 0.07253394777616186, 0.08606804009046286, 0.032346449987662416, 0.03088630172574232, 0.09806909087684848, 0.0922363042651165, 0.05049457878715569, 0.03592845495609987, 0.09522135054031688, 0.016078810402823072, 0.045689717460904396, 0.059662230402952245, 0.025222272792410468, 0.014604041352868082, 0.061582383819885796, 0.07500430554031365, 0.06766938904841101, 0.018444654621904897, 0.034156604669988155, 0.029469002676647038, 0.015624698379167147, 0.026600530085664605, 0.042943211813126846, 0.044376983667813966, 0.048868442254681746, 0.04694610548716399, 0.041609012236398076, 0.030620555400908477, 0.03328503792985313, 0.013094044707324958, 0.008990034130552124, 0.04783320465996381, 0.029757626302119707, 0.04280628891842019, 0.09614283173915841, 0.04539864618451365, 0.03924127194970366, 0.036548932548612356, 0.04579139648065452, 0.04885426962808256, 0.019772466940564976, 0.018161565981685154, 0.01033508821555804, 0.029872696538786256, 0.027372093623383876, 0.03835121950795574, 0.011836900169240131, 0.025335607839928522, 0.10064072546459014, 0.02943920377161234, 0.06036365284554421, 0.026219546900040684, 0.01812240356699594, 0.015304092498075579, 0.01412268532740493, 0.05953537007313102, 0.011071224017218958, 0.026206780044782548, 0.04080875679069469, 0.03841151828847585, 0.07270479304415566, 0.05633015778937167, 0.05103006275490888, 0.029016890142473484, 0.03698313586233604, 0.03656316646224549, 0.037853239374535705, 0.03763603429580408, 0.0405810333247627, 0.0355492529248999, 0.02861713588748488, 0.044281621042999535, 0.08713020567571925, 0.05343798052279219, 0.06298730480334451, 0.02667051987842687, 0.025230674861720013, 0.04535750726297979, 0.03039874613375193, 0.009198670515850669, 0.017511548038812417, 0.043895129685200034, 0.13480360439467814, 0.03403450557661634, 0.04377737431035888, 0.04811060509734577, 0.04185033759342567, 0.013831583407497215, 0.035376117054012515, 0.01719942083582282, 0.04471814177269417, 0.038099927347033255, 0.02219429686515322, 0.07797098868796903, 0.002174119703516725, 0.03529826336870751, 0.04142541160446502, 0.018697517263072155, 0.03378952598018992, 0.04027798809411545, 0.021224063746030294, 0.022792584720938917, 0.046955175968187476, 0.06555309414022392, 0.04504384022326239, 0.04964543544056435, 0.04871386486376005, 0.03751207743921588, 0.020347482960430846, 0.0921385667677368, 0.05114738145963319, 0.04898001529997395, 0.038590009113953966, 0.044697430585661245, 0.053911844208355875, 0.03197045786486518, 0.05533604762486874, 0.04976171226571164, 0.050519821384260734, 0.03311209741138643, 0.052838781022376595, 0.016611528793169607, 0.027343148906384746, 0.1045110552842098, 0.019408364502352574, 0.06593783115667683, 0.08371055006019532, 0.04069658236638193, 0.018631310029436025, 0.053570272415996566, 0.027351315403657577, 0.02497961827283425, 0.08572490930917763, 0.007010670256755886, 0.025780703008715666, 0.013034890270641735, 0.029189489751813874, 0.016282009479079037, 0.020366727089088772, 0.0421517319045961, 0.04930846400619034, 0.05877099052492169, 0.06291471797251894, 0.04347667713919955, 0.0195483977140318, 0.037255748250191255, 0.005749691448610036, 0.011208381526352418, 0.06415944997101061, 0.036168378372226036, 0.03872892000682412, 0.026224384745282513, 0.05076084030611862, 0.04276177154914026, 0.08976546386557241, 0.045800018800242294, 0.01057811524538744, 0.030851760736456325, 0.03983523906959642, 0.010653660133210643, 0.04759376770966957, 0.019949260881290804, 0.05819324148638595, 0.1626174530434993, 0.08454894136276939, 0.046023842878639705, 0.05302647256382531, 0.05262911807925952, 0.03201614351822965, 0.02332660546075673, 0.02310383666847502, 0.04252452944074908, 0.03654594863614729, 0.061117870237437956, 0.027878064053854155, 0.06981048222270704, 0.032529859097614404, 0.02486015260670214, 0.02595650678079936, 0.01887048650983601, 0.033981293109395815, 0.07400226253535479, 0.03243142829066323, 0.07892709706098804, 0.04820359668003456, 0.02186219391953801, 0.08288027162873939, 0.012182300486001036, 0.06314027724006484, 0.026237410155215093, 0.04346301013063039, 0.014179490746990328, 0.06143714504076108, 0.04355550758660801, 0.04240322707881851, 0.06566340314044107, 0.03301190460220941, 0.02516870983996459, 0.026111633839806723, 0.030234215345474023, 0.02194479160431412, 0.03748003964222247, 0.05159276582661176, 0.07379216292212087, 0.022680260909480915, 0.042236005406706564, 0.03076164006826378, 0.041327965220496546, 0.021439167828629577, 0.024799470782219887, 0.1498659348656093, 0.021447322834583542, 0.021229095028473005, 0.03857360717149512, 0.06796057906843002, 0.02500819526762972, 0.09050450888612578, 0.06188194718091719, 0.06777236658719278, 0.01369275869951854, 0.09332584217190744, 0.05497182261258845, 0.04072504253276894, 0.009524007947484573, 0.11736901371829933, 0.06526921259900255, 0.0889976522434623, 0.03961746325536121, 0.02842782407007631, 0.014684502609945355, 0.03231693261993989, 0.028380228942560575, 0.04160863302287556, 0.04975237365391466, 0.051215122784337694, 0.0843698836322273, 0.05364581634620986, 0.03196007737349118, 0.05686718542429228, 0.020045019956606052, 0.032443459701514056, 0.06293029637045919, 0.05583599660425417, 0.031924850735512954, 0.01664371789252806, 0.007106493970739746, 0.052187755673883424, 0.036346091618460995, 0.08168710500843103, 0.00807389926781217, 0.03821164211859146, 0.03096204675403574, 0.058580234631775856, 0.037633199770484245, 0.00897192860007166, 0.0197558983739826, 0.052184530443722205, 0.06881240755319595, 0.08256979917566623, 0.031222526224390156, 0.012288338546040318, 0.0320731021553999, 0.065266071638513, 0.03125728171829495, 0.029389837065771706, 0.09914025033433592, 0.1300816835775491, 0.12671900958183313, 0.2027780190110207, 0.19303145007260386, 0.13108642321200142, 0.11994991030904556, 0.16791862826193535, 0.15493909167426248, 0.231462097576549, 0.10135441297484983, 0.12547644561216717, 0.1025018901113541, 0.07510745161843878, 0.11262122977284655, 0.12550922651444713, 0.1536370639599139, 0.138680913275288, 0.1756771224280519, 0.16325008845137012, 0.18441663814648507, 0.19933494408765148, 0.13067414533467064, 0.1871408927705019, 0.20143047035221132, 0.1511177072121251, 0.10833106078808347, 0.12475502061387225, 0.16504676381666816, 0.11828235140250576, 0.09335581919238453, 0.12285362869020432, 0.16693644225597384, 0.12700102952939848, 0.26391566580822395, 0.19602705303940082, 0.1970643054453596, 0.14913409107154416, 0.09834489019046869, 0.12754549587806388, 0.2114653947853273, 0.14367712421282647, 0.09380315325313038, 0.15480723262073534, 0.09644464739868719, 0.14651696618285873, 0.10316493920981885, 0.10591268208959412, 0.1563598323733576, 0.13765708272976263, 0.169731131003749, 0.11575848239684298, 0.14875504608836868, 0.1382694321293985, 0.10405477331650835, 0.11431220032635236, 0.15538239611252663, 0.14729437688666006, 0.12947365491380616, 0.19064007597344537, 0.1523367063172402, 0.15661363730267172, 0.14040019843847523, 0.12008887099763078, 0.12558068719602403, 0.12911273557091915, 0.10625346864183104, 0.10898975084625906, 0.09298864857203538, 0.17837258746787427, 0.1352183797186421, 0.222999200885815, 0.13700504997564902, 0.1344883898573537, 0.19212709859974925, 0.11226558111487858, 0.10000906298838316, 0.18428742975717594, 0.08530448791721175, 0.1817142476718272, 0.1317912700676149, 0.10667675520263373, 0.15555148703917382, 0.08378332075212272, 0.21861458858174665, 0.12357335297330735, 0.23276438576079186, 0.17833629022202185, 0.19003292064993613, 0.09088989707731432, 0.16293406186084594, 0.17242279624746693, 0.3628674431914284, 0.2651204156779474, 0.0783724570646882, 0.221345707353565, 0.10071564886358478, 0.22145292901944733, 0.1871873023769548, 0.12699502340007213, 0.2011428196584025, 0.10937121666727528, 0.13505102015070378, 0.11223627059089561, 0.08310391567647459, 0.08656382155154022, 0.19658983655033574, 0.1260763537439127, 0.13973751706221413, 0.08279571850453654, 0.08753085433835946, 0.1084135914401662, 0.1363648609408448, 0.1203909241444161, 0.14196931504674498, 0.08480628561829368, 0.1798143802631286, 0.07893475794023083, 0.08240013368307583, 0.1326643345096419, 0.12244055408143228, 0.31214221831290956, 0.08874331871348043, 0.11836704242253497, 0.21965862852671456, 0.09915622326755717, 0.20288355528346955, 0.14921269169257534, 0.07671285781168169, 0.08383193669179756, 0.057879991964587284, 0.21045443451692983, 0.14330799240739117, 0.06406985215782639, 0.09294615367487555, 0.24789128212198136, 0.16752947091815934, 0.15009907074272633, 0.12458347820586736, 0.09676659584886606, 0.05792601469663843, 0.11951599044785385, 0.15153102696903292, 0.10171674191951753, 0.07821469657844113, 0.20075159387723093, 0.1836543959835845, 0.2197830412056177, 0.14308280852292815, 0.11578135012138276, 0.17097986964208467, 0.14290015784002122, 0.13524396705531305, 0.09316039016290058, 0.11356187083067433, 0.11257419963517498, 0.11822202197846868, 0.19161412612565104, 0.20757055781300993, 0.17500461980460152, 0.10355721453144666, 0.11205820111377586, 0.12684565157659594, 0.10336114198810632, 0.11491045370818147, 0.08061553952434371, 0.10628667089246935, 0.13630637778870522, 0.14327452968685858, 0.2393103925691497, 0.15802189076860107, 0.11499738170494957, 0.16713596219497343, 0.1541854756613893, 0.09058772901734037, 0.14260086260976332], [0.05889362971028013, 0.03446749464098004, 0.1598522127155335, 0.04607307934953321, 0.07515750014253202, 0.05044565641231114, 0.04011458920074567, 0.10013190518704154, 0.052173245968597556, 0.04163576402671395, 0.040804386259086674, 0.026934963853789434, 0.01799035490670752, 0.04138552523668736, 0.026834206054768255, 0.009006596951475068, 0.027013123974264152, 0.05889256101762576, 0.025790290599088037, 0.00782186112877342, 0.02749988091959348, 0.015242761414077495, 0.021689069539969488, 0.027403748376415144, 0.0325394696706245, 0.058990543663141236, 0.0666556861852446, 0.06095527573638867, 0.05088552877667451, 0.039471879736670566, 0.004972116514709929, 0.019815894549772627, 0.020181251456961036, 0.06589745832306725, 0.034363551831413666, 0.058211148791616006, 0.05987337189576319, 0.019268484508258202, 0.026874619107993863, 0.038571534903659936, 0.020207549340181777, 0.05205199340238206, 0.04036418447691587, 0.04110363935450873, 0.03911772495015495, 0.023989039773662246, 0.0147572455311855, 0.045348409968878955, 0.03525215636698469, 0.02661630575124535, 0.06531763701669632, 0.0613700510603526, 0.04797881882217142, 0.024707726007627866, 0.05896879825741053, 0.07475557211305826, 0.0685422926119739, 0.05429682637294454, 0.041760988758816835, 0.04360736407820256, 0.09327117413763078, 0.07151356462629573, 0.027272733934824506, 0.053831205793446114, 0.14106700136776895, 0.07930782743759694, 0.017794077434847434, 0.0459184636542153, 0.04072943221657507, 0.02753976537215133, 0.05067919448558843, 0.010026691860759692, 0.024064976323936737, 0.036680473675650936, 0.038653219028586344, 0.03309493704188255, 0.011930285329600016, 0.04855631505169215, 0.051780541637732144, 0.01968594880083636, 0.03633137123899595, 0.09170515252457512, 0.03787907952022168, 0.05577572080637178, 0.00443012127840531, 0.06165056947558638, 0.025141276231396104, 0.030734401812115987, 0.050790579839339184, 0.09121677913372556, 0.016368981525902788, 0.061433165213994445, 0.05814487069484688, 0.061818944110024365, 0.0649141231852193, 0.0960463276433368, 0.03336447741716139, 0.029182926293522603, 0.026638192883242044, 0.05518434306366309, 0.07067786229233589, 0.04658394125140002, 0.04090620700510279, 0.053735092402465885, 0.042320144843430295, 0.08115758503516836, 0.03600108009132166, 0.044698376704247735, 0.024432453379455595, 0.03612099966454891, 0.06681845688651647, 0.05422607432269762, 0.044752320785435944, 0.06346658090009324, 0.058435654688266024, 0.021763175140104948, 0.07105516825592326, 0.022542324863494407, 0.038002546080538345, 0.054303242359310396, 0.016926367947411154, 0.06586681480609602, 0.03146164907863544, 0.043547088280320174, 0.02307567336115866, 0.03651695220821327, 0.055330443691702626, 0.025112695406161012, 0.04084945138123247, 0.043757743307299195, 0.029637222178280357, 0.05067747078775879, 0.10143173422904746, 0.004594780865215487, 0.06691870715228782, 0.0421783994252403, 0.020955871685498187, 0.037489899193807956, 0.043633028023665955, 0.00039540395288983546, 0.04356860769011321, 0.039732173430703344, 0.017220076481481234, 0.02862532728261525, 0.05080510486638354, 0.026709303079593568, 0.04081863549447829, 0.017851258237515728, 0.017830706013727094, 0.04324773176302833, 0.048127279001017736, 0.05933688052238957, 0.05883386719130701, 0.015413782882293867, 0.017640074609868953, 0.05160638686990546, 0.0043015042132127194, 0.028247624868527058, 0.01199699818126617, 0.09046338528635041, 0.03436942772579289, 0.14078986140028124, 0.0625934896449889, 0.06805194271427971, 0.019941483173639547, 0.023724224245656404, 0.07689524036381515, 0.06680483584322276, 0.017155158190777706, 0.18419575967615653, 0.03966182740705629, 0.030492796832996032, 0.01637426178692089, 0.01470485277804396, 0.06269720645861761, 0.03195092453801584, 0.027358382564759063, 0.031272072960892995, 0.0682013681639106, 0.02976519908125122, 0.11910884535961574, 0.05291218373684153, 0.06406605619216157, 0.0499051698904124, 0.038238562448250676, 0.06810922310837815, 0.03171795336980253, 0.013833693022118702, 0.031362343016230775, 0.020790540335339405, 0.0318394529993736, 0.042665539414531765, 0.013592740175344292, 0.02082582059947233, 0.004761276669019173, 0.03483803604819602, 0.020978224215908878, 0.05185617749849635, 0.06212110450911907, 0.05604022032310886, 0.04047430961603119, 0.046946630257392125, 0.03482990019444016, 0.05190211596087583, 0.07157829139501819, 0.028746453444323236, 0.004811117870567908, 0.029312707333555146, 0.01830931944442132, 0.06411276457290496, 0.055262020548745516, 0.048647039014125065, 0.015300963986514798, 0.05417569255035731, 0.03986753350604446, 0.06976775749916993, 0.048554223631658865, 0.033989141680180066, 0.018756576896374746, 0.03593310894023988, 0.007431421545334161, 0.017979196836090377, 0.03776262266441219, 0.061837383846361796, 0.04330133110465061, 0.04293062498853092, 0.12370056187313412, 0.03412435236837595, 0.03826964646577835, 0.009648704078919705, 0.03405717411829579, 0.08215147686461288, 0.01367436205562685, 0.044785929062674125, 0.05834547847869897, 0.021780942634288824, 0.06600938376880462, 0.041657111066724026, 0.03268162877629361, 0.019389045680122032, 0.10609382357929023, 0.04424178830137657, 0.03589551317535582, 0.02648582374076209, 0.03412535211311714, 0.053601927169027834, 0.028822803682076837, 0.032833130324199315, 0.030027181999157035, 0.07427802354457878, 0.019132004029327826, 0.05815116410714485, 0.018479394794051206, 0.05865618841902864, 0.03387847261863851, 0.031036079575818394, 0.006828121080498903, 0.06424800207417819, 0.03585492966756706, 0.03309941482579997, 0.07743210712027165, 0.04036505781714955, 0.02809120503614747, 0.02221424770992129, 0.04384127753456274, 0.04919483401482144, 0.052326084339931134, 0.01885385282578007, 0.05737021790757295, 0.05836813552905956, 0.02479778921922609, 0.05546708313387729, 0.021097818201768304, 0.027671319905728586, 0.023962320542083155, 0.05015967962061686, 0.04864454539793153, 0.015608983043010439, 0.05917502912662684, 0.05403739069738696, 0.0368563789543846, 0.020045060176222075, 0.03924818972365991, 0.03477277301792656, 0.03821763675659895, 0.07637294459967844, 0.08377123188467757, 0.02556896779776341, 0.09152606415051608, 0.05406391266132555, 0.09658758408359944, 0.04622929616861286, 0.027783934830597816, 0.010613250910424659, 0.02319666737269971, 0.0386136046220218, 0.015159560435061014, 0.007823223328863782, 0.06384845657814896, 0.07117012740984079, 0.03915443971392609, 0.05320485996743364, 0.009304836895617266, 0.01924694786148687, 0.026829159450567058, 0.04706294921737525, 0.07874916547969465, 0.019357256861704013, 0.039850388458299066, 0.016826408795051036, 0.06091671470072001, 0.09609105185635629, 0.026247769579171177, 0.01556990298277308, 0.013372082912903881, 0.04382144734864274, 0.0690416440427784, 0.05331280558640438, 0.014385005323997429, 0.053509617404591654, 0.03689390577135548, 0.021430369308819214, 0.013462259122470935, 0.025850369129329923, 0.0637550589688603, 0.009883634516999367, 0.013290239824733187, 0.12674095800086377, 0.058852069440387914, 0.049622560055145336, 0.015402541499614958, 0.0700290547683835, 0.04608355943233736, 0.043624394212759314, 0.041446570952933644, 0.05570223382223518, 0.02190347073689824, 0.05341348486141332, 0.07765896873728884, 0.059107893011382515, 0.03527633027143536, 0.044115008410787394, 0.0583902448265543, 0.03604758545876511, 0.04323717890187137, 0.03542189463792789, 0.03590212834458198, 0.012754598808955523, 0.02508759262010215, 0.05139022750119048, 0.013234927318990232, 0.03779988901148881, 0.1997917776386584, 0.17077910864064771, 0.23237908950015423, 0.11791446832038703, 0.30812574189997494, 0.09280914651049722, 0.21412588025052703, 0.30332099165647264, 0.0987783810424228, 0.17298623859401674, 0.21148632430741865, 0.08757226905154605, 0.09513995369836208, 0.12200759949102519, 0.08852746577993517, 0.11029166364741903, 0.1395128847610566, 0.134827199902746, 0.09057094403091939, 0.08878198317101887, 0.12782676505946344, 0.06375989298366251, 0.21117103316130179, 0.14960171114052498, 0.08935488670343354, 0.11185015461617902, 0.10501550119971076, 0.118600178299652, 0.12000372032484702, 0.13999196550538465, 0.11812351839316469, 0.13451166360849334, 0.1543629629116866, 0.24315678214113562, 0.13760094380667134, 0.11273650302281303, 0.12019824537058031, 0.15217988811914, 0.15026034757254586, 0.15389272282200475, 0.12767453572802967, 0.09542008140875448, 0.17308517118855832, 0.20826058852816784, 0.15384130300052706, 0.07236212957650423, 0.14595006111889117, 0.10861163282947195, 0.13240317513625469, 0.14203798716827748, 0.28485986614419573, 0.10438948479150573, 0.2393166898118873, 0.08056080254215388, 0.11131122708320619, 0.2060919008668392, 0.1505095406525558, 0.18748390097771922, 0.1468815474260238, 0.1665707578461978, 0.170693643871815, 0.17884029946740598, 0.15652824914263141, 0.12374548526901392, 0.24522523485845138, 0.18643192436185577, 0.09101676123757517, 0.13048176533512532, 0.1371643502986239, 0.09915855217484698, 0.1484739377854332, 0.1312189870664189, 0.24689333002653815, 0.18236261852566274, 0.124690868411093, 0.12748865981496152, 0.10726336404801377, 0.15369042964471927, 0.1882927978952085, 0.12877725034711823, 0.09684128176060416, 0.18928135775270002, 0.13166229150468303, 0.10979595879513411, 0.23676057616549157, 0.19940076636210566, 0.15338636934757233, 0.13367679631037097, 0.1304371636961737, 0.1357219752765471, 0.2359303666819488, 0.14582783945145147, 0.12770039119547413, 0.11925551289271925, 0.14896025039976643, 0.12357583509818201, 0.11485088271118941, 0.09024600783783583, 0.16685873029693482, 0.11561684040052277, 0.18029491657451277, 0.1359706014514931, 0.237719411811521, 0.12388537292398753, 0.1024863538482497, 0.11059259830583489, 0.14316019872503896, 0.12312293923910587, 0.10615574646620982, 0.15649158417457537, 0.17379254613432193, 0.14291083710568567, 0.14990393282665362, 0.15519229905499568, 0.23529969245916416, 0.11320167927131539, 0.19316862577632551, 0.13850566300172962, 0.15802305522224597, 0.13344548372251372, 0.08696565765046305, 0.15445530715007938, 0.20308287603960884, 0.19413950432452465, 0.11901064054860223, 0.15221396371001197, 0.08695864028507665, 0.1991461647013503, 0.14684707346943118, 0.14567770154005097, 0.16632815312233665, 0.12080717801807389, 0.19285194035018646, 0.0892970547260296, 0.2617715389257477, 0.2500041219736299, 0.07190574801737262, 0.1308628481121794, 0.12438827134188145, 0.11065855847611544, 0.1429403927778044, 0.17764659658555063, 0.12266762254218902, 0.15677948001651995, 0.11723544628870104, 0.22895104522185944, 0.14424833469092846, 0.08182556773986548, 0.18413582095696082, 0.11035490420556839, 0.09553196855009564, 0.22920413002852472, 0.13930028004031028, 0.1116442991300456, 0.13687158213748088, 0.09773757398849535, 0.16604269343999126, 0.07915438002636356, 0.18672997852967632, 0.21261530808143078, 0.09460498683995779, 0.22592093765495286, 0.16093837217457835, 0.27085372577271155, 0.12963528414407086, 0.11273561436082087, 0.12246329923190417, 0.20269514361937202, 0.12297782686448867, 0.24214727743979425, 0.15207114959916762, 0.20125601681009417, 0.11900003023085096, 0.19272899856009792, 0.12855808791374007, 0.09482096234757094], [0.057851991450954834, 0.01846834780618308, 0.047777433459076195, 0.01748580365411697, 0.028859068369192463, 0.03580743987714091, 0.011985056785746448, 0.0680389651848424, 0.06361226784065366, 0.021620602346956733, 0.08793834416616349, 0.04900054645634467, 0.02190774167707611, 0.04130383728132133, 0.015448031800558731, 0.004681578148231512, 0.11596888844524661, 0.024294599687920946, 0.011427043129750078, 0.03249584479377635, 0.015392782497069529, 0.05525891789265218, 0.08555871419488423, 0.03363212938570688, 0.038202077510856816, 0.041102884757903316, 0.007574760905211612, 0.03054720439737843, 0.02921741174143409, 0.01968209537857723, 0.052926072910908735, 0.04420428829748304, 0.04376454233762719, 0.051947054678514126, 0.038938701693569465, 0.04886064347961257, 0.07586384086959785, 0.07042074786318887, 0.05146315524114236, 0.030602469980236024, 0.07155687923753454, 0.034491270179710085, 0.025136942088964487, 0.10080646092612898, 0.04404853496159758, 0.1462772113060759, 0.017576554429627234, 0.025137641144195394, 0.03596988882148459, 0.07522574325482692, 0.014545629063861506, 0.021602729515683268, 0.09616910855496123, 0.043876617170509793, 0.038693369696697885, 0.056734633061193654, 0.056666110326806386, 0.147318416725724, 0.054997758519264965, 0.02638971034978186, 0.05162995173445633, 0.03327686760214067, 0.039150180265067086, 0.02818910341199127, 0.04693580926546166, 0.10382815684762695, 0.010667895004453679, 0.04436546553587241, 0.03205503971736518, 0.02588205069543854, 0.022492054173903122, 0.02094212040725735, 0.04403824640077449, 0.030477925151165937, 0.06358807478400488, 0.028424457113649097, 0.04411233093349203, 0.0036018002015959115, 0.024506499607776924, 0.028721733702226516, 0.061591055935188654, 0.05742459099799876, 0.01506116218684662, 0.09329772674508634, 0.015834746281466177, 0.017931228240711555, 0.01161402699747874, 0.029875592351140037, 0.03909758449862561, 0.037571238579168435, 0.021209513821128397, 0.022848043740997394, 0.040890149802209876, 0.010940766904593236, 0.0135381908846959, 0.030050833048599384, 0.04635264398530126, 0.059760569279352506, 0.03488098293723118, 0.0428113719117978, 0.012113074865943242, 0.04130891644425931, 0.024420630727564136, 0.06701478223887182, 0.05958944438926636, 0.033158311665418654, 0.061406398101920084, 0.06187835422855231, 0.10011557985337512, 0.07018424119920501, 0.019258877765687726, 0.04065347076844304, 0.03892543305072092, 0.10072979084666699, 0.05331618020371084, 0.04169973236839137, 0.029492887382906292, 0.06217545461690715, 0.024588026684678854, 0.07791762300316366, 0.017201797623607903, 0.09982193835199842, 0.10032390980350395, 0.09872410371298752, 0.07635266625232275, 0.018727559401022813, 0.03399614755424761, 0.03668454160252887, 0.05242405166368812, 0.020571670930592284, 0.009889846532455376, 0.024776355994324532, 0.008568374548978623, 0.023442051080506177, 0.07935296533809555, 0.0073886925125524645, 0.027584485754731203, 0.03616389292742937, 0.060156878053901665, 0.09241103359888639, 0.04123760898026728, 0.03485787389499526, 0.01756416870311143, 0.01745240413583815, 0.03895297008115919, 0.050874301758144176, 0.09416530599757549, 0.03198941088011188, 0.029735490191547625, 0.05553552925947213, 0.033232342571981495, 0.02397738757633394, 0.04560930887237192, 0.0184917422161708, 0.030096616378174196, 0.04065268935876028, 0.016690793995475097, 0.030222919379030506, 0.07169177199924184, 0.0383777721154113, 0.08738437066635779, 0.05540281984834902, 0.08121374694089736, 0.1072690943856874, 0.07146281130131214, 0.018388688068596587, 0.0464484547715514, 0.035643811157393845, 0.02534664333647778, 0.028367015841086547, 0.005095776512227472, 0.06308397743850946, 0.015937460477523986, 0.07544599353305756, 0.026467477850195383, 0.051467430011759845, 0.061447985184889656, 0.019604647719872095, 0.019732174546187444, 0.021862592285258636, 0.04019335453068057, 0.03733886112909644, 0.036431598522129564, 0.025243918606711012, 0.0639527709403586, 0.015713903572290175, 0.04971232257723328, 0.07086307170890993, 0.013357878685177816, 0.04739857616744215, 0.007330952465699445, 0.02652228378029841, 0.011942627006060174, 0.03439574284599193, 0.04273918727713247, 0.011845190198190752, 0.05515543473584037, 0.04079736506326064, 0.027111596916051164, 0.09602630976587535, 0.03957912055475097, 0.080014995539621, 0.07230026797661859, 0.013958094209702987, 0.011720045905319915, 0.040045139499970024, 0.04253772147480519, 0.028851447709565683, 0.0306707073468715, 0.0686300786272172, 0.06259103050275196, 0.026590869716939428, 0.02236913728167213, 0.09627640682963595, 0.05496806878175947, 0.0046252898379950036, 0.04326827824115754, 0.03168050890728351, 0.03528932312263116, 0.0927852139237427, 0.01991377377341832, 0.10399632846876498, 0.035655624233186245, 0.023512845265588934, 0.0256036696655135, 0.06669571427928825, 0.06299858927846917, 0.020543919395535223, 0.05312222972392075, 0.015434937442712968, 0.004802296368119818, 0.008494800422340631, 0.018908065037741777, 0.010256316182353805, 0.0243392990030829, 0.010644945883071952, 0.07248451212240804, 0.0756775742516883, 0.03278840611117982, 0.02380151485633706, 0.016732005695361766, 0.061034316857976306, 0.03327553843959205, 0.08025001599303178, 0.003513934225925515, 0.01481736045060379, 0.0790697502933683, 0.005022652941049948, 0.024145587925769152, 0.08614800434799925, 0.017100959385354674, 0.014508532213738129, 0.06301106885075569, 0.05169159499928356, 0.06887042339170171, 0.0038233817969974613, 0.08625691140731497, 0.019584445981308818, 0.038661002481897036, 0.05989088849615186, 0.039077738990947124, 0.06350250659330238, 0.03652140317905334, 0.01128344473639323, 0.03041650979749618, 0.08768930430373839, 0.03699712845827303, 0.02179813364730968, 0.049044665459903984, 0.017372466691379106, 0.035938942699783274, 0.03284960887545059, 0.05356428926930793, 0.03316246386196825, 0.03518676310176811, 0.02684219060615907, 0.16954786745050263, 0.09739519397337591, 0.041572217033394886, 0.005645569565991361, 0.04725176307763304, 0.06580123767977761, 0.025254595957155672, 0.10242230889777984, 0.021802278182980035, 0.024408063055166317, 0.048915334496526956, 0.0236812160695873, 0.012737281391427163, 0.024749784234670863, 0.12084110805224027, 0.024008982957551078, 0.016384274556091236, 0.020672221885873907, 0.028486579183429003, 0.022950914027469776, 0.04907504467654133, 0.04891811156525247, 0.011298558693529378, 0.03291965229436755, 0.056278703493937376, 0.033262875006203695, 0.005254815886503146, 0.02499702570569371, 0.05314042048168279, 0.025996615314075065, 0.027470233316923824, 0.03707318566739559, 0.021250635505683964, 0.009265573931887988, 0.055667043573433356, 0.0060277737042446055, 0.02833804622622988, 0.03922726403200819, 0.03828674554824829, 0.056170033921878186, 0.03232168236507043, 0.018765419466240753, 0.06558449608424018, 0.03733503835035428, 0.03122944974400584, 0.056311492057096575, 0.12764540906514854, 0.03394827088941971, 0.012070257254245301, 0.02274853275007298, 0.022906168747032364, 0.04605766949093631, 0.006334733165379975, 0.055978990745760744, 0.05111628978122627, 0.021390467619283066, 0.040791370425253146, 0.026209438369879802, 0.06569188628946582, 0.040749135997987566, 0.036210474903665246, 0.03707849082627124, 0.03667285876168359, 0.02434749805909251, 0.04388647289165566, 0.035377557299310164, 0.025999451754614714, 0.025972330326875372, 0.05909553601316387, 0.044202962965374036, 0.05778224297588872, 0.029524335292198008, 0.027603555598386356, 0.06588913094733032, 0.08077642564932186, 0.02765192064426599, 0.22400083020329478, 0.08375639276158425, 0.08421652815154484, 0.10615948497528031, 0.10923607875743221, 0.07809722465613196, 0.08529357882517, 0.16542519592950422, 0.1334337166119968, 0.11530723362680405, 0.1215418639983381, 0.1824728738997252, 0.15181141514931956, 0.16226635494780156, 0.08915816298535756, 0.09180352587493197, 0.1854794778891148, 0.16226102297584857, 0.14343372275752408, 0.16875182548838277, 0.1809769646534997, 0.09982212221310025, 0.11453805070730949, 0.12172088342448398, 0.21066009848108216, 0.11702107956572888, 0.11752714958762932, 0.10967294805713239, 0.11990228262279304, 0.12233058215990184, 0.11567121732138819, 0.1539073857448755, 0.12196299785207357, 0.1727965552239649, 0.07895270738029674, 0.13911965182952343, 0.15678137991457217, 0.22225159100226818, 0.1292700287435324, 0.07807598103799167, 0.21535865361652068, 0.08483672229152533, 0.14198088297440162, 0.27897909944576604, 0.179425330171662, 0.20881632403019937, 0.16357141637033032, 0.10691457953784736, 0.1904675529728974, 0.3033378455908068, 0.13073101970216922, 0.10481872385548008, 0.24609195609246534, 0.07376348059023581, 0.08816070884706513, 0.172406769688091, 0.215136855840683, 0.2674462586160629, 0.12671995186998, 0.06997660838908727, 0.15700107860949733, 0.19496121023210788, 0.11355725132049092, 0.16787854654173698, 0.11465090311943524, 0.2170269479674678, 0.09501537248011559, 0.12508563351847474, 0.10629551154711556, 0.14670975986988316, 0.08714018780137263, 0.10650987060920847, 0.19420128165473863, 0.18770025952929453, 0.16167217715372964, 0.19237380955488453, 0.13631425317256682, 0.1525602967388207, 0.17751011036096082, 0.1686161513169927, 0.14385684843986266, 0.18108115261120183, 0.13616290484224597, 0.17132611074034246, 0.10144776844930264, 0.12968959977790234, 0.15696115010688383, 0.08757285893924775, 0.1440985032146977, 0.1874598917821723, 0.18173825686737416, 0.11959916461379298, 0.09585395530467072, 0.08241891049809995, 0.17209900152539054, 0.14119714438434572, 0.15394929075433364, 0.12849028147156202, 0.17086886350185643, 0.17980354777987928, 0.22778709719498313, 0.16741965987509297, 0.16812487445291013, 0.1258775309449242, 0.20177350920294562, 0.1333587319259682, 0.14291394742265826, 0.1798078991592892, 0.24988499530140432, 0.28765859983621106, 0.2337451468432142, 0.13110926795390346, 0.12975369069364764, 0.2562189030070459, 0.24278622541216113, 0.10903238363924528, 0.0890670751311606, 0.13901670493425863, 0.12506402983901002, 0.1558155422249148, 0.08685834405402984, 0.1894935794294842, 0.1148294016057926, 0.19047784919459976, 0.27928191868047564, 0.15536010295393007, 0.14431424889593356, 0.12392641991497048, 0.22000686145357548, 0.06037287654415254, 0.1436848463791032, 0.125934979878366, 0.13247564705389162, 0.08261011072224186, 0.22766377236093246, 0.0976574565133741, 0.0966563021704074, 0.157995859100934, 0.2458484014195781, 0.21986256113215802, 0.16849008388817313, 0.09142330877723233, 0.19682478039495407, 0.15500788636986287, 0.1595819828611228, 0.11829443260907166, 0.2933832378156724, 0.1312667756311355, 0.09773689983112198, 0.1689007529808629, 0.12239108012328226, 0.10409065687488164, 0.14237829874600136, 0.08966301492745839, 0.13982564781702336, 0.1277972783352579, 0.13961845167702244, 0.14726330436045124, 0.14047757331882754, 0.19367199150785325, 0.169662979822005, 0.07495192044805135, 0.1453526351120203, 0.14317513743956245, 0.1064328634510598, 0.12214240798306082, 0.24971044982873628, 0.13068061111675155, 0.14715599076401803, 0.13390925803011464, 0.1241543463942024, 0.1215688149715143, 0.08482631115663437, 0.17438771984269544, 0.15322729885097475, 0.16755479778493607], [0.015291543977875865, 0.016913285080884254, 0.12651081752753066, 0.014874766291599843, 0.08187024598760952, 0.08061227598978628, 0.04091605506536942, 0.07847388710586295, 0.07263564594811009, 0.06181319078971302, 0.06201927610222371, 0.00886782203921147, 0.06853283142610904, 0.05265357160580255, 0.04019178021999617, 0.027984829897421504, 0.0632761620856341, 0.02368991308274769, 0.08374362973676575, 0.03912808245889122, 0.07664510499565833, 0.029330562927850315, 0.014307887083099735, 0.09698113111118156, 0.04474095587107924, 0.024602245276553497, 0.05750602231391015, 0.037791546313993396, 0.03686848314358823, 0.041930849603827924, 0.040724004483631546, 0.030990798033833988, 0.016998866678125436, 0.06520039492076443, 0.0391642494697965, 0.05219976793253615, 0.02634583649435832, 0.034133158549065554, 0.09264259899575865, 0.06595315291516243, 0.062125490362485575, 0.06078955559660831, 0.030520695839978518, 0.12049070709655363, 0.03162542910074755, 0.0440657566181354, 0.026010278492204608, 0.04635010057339265, 0.05934503552834353, 0.011442435751368683, 0.03665990804532363, 0.0222173810095316, 0.04119115723897854, 0.023650731515860366, 0.025394585118779255, 0.03916266366779324, 0.04150801120446094, 0.06983633002927227, 0.03558079659518215, 0.007372612327021817, 0.021087506658307487, 0.022751380681931492, 0.023796933650549863, 0.057466124454813625, 0.04679428218233009, 0.018670964655616594, 0.04263236014653118, 0.06531411301224463, 0.013710169962817624, 0.016047667971091167, 0.06078266080528979, 0.01824090204712364, 0.09579532659582554, 0.038102397980589064, 0.00890895713030571, 0.028520968870349953, 0.05349344145807047, 0.014359670796341473, 0.027750841747488708, 0.06042027440402777, 0.03098893069451855, 0.02812725904908392, 0.048501865352473916, 0.030236896653209003, 0.01878005366081432, 0.05376338019906994, 0.03563803868488439, 0.04934074695131952, 0.025798365165809953, 0.028596780931336746, 0.034174734140716256, 0.020941882920000824, 0.05245053149279087, 0.0654324812574252, 0.038866049745270324, 0.03549292247982756, 0.05453638589730667, 0.10566004927480414, 0.06123213608178401, 0.029748465805765123, 0.08564184239554791, 0.01728600026258538, 0.013320118211390031, 0.03844197794434525, 0.009632456311655622, 0.0852727105901126, 0.06690626588439749, 0.03163010606752529, 0.03515819568307169, 0.06590514218494778, 0.03977206745936025, 0.09161106926659424, 0.010393411446843418, 0.04249003250151873, 0.020110260004237778, 0.029792979344605442, 0.045140018731716185, 0.031278209325166485, 0.07757736505159447, 0.030578794032936136, 0.08409007001788386, 0.013929177263391115, 0.06003265306653996, 0.06540856399242917, 0.026855976358356497, 0.0564945487666034, 0.0727154493271824, 0.04225860883091246, 0.04865903978145892, 0.05836512097307752, 0.03998470665406316, 0.034865278134783434, 0.06709401105200091, 0.035519639796186844, 0.09106749924080026, 0.0315869044542553, 0.037020245161388195, 0.04173883732648627, 0.06602586232005589, 0.022103689731128758, 0.05054659615721434, 0.050480356364841425, 0.017790930728698452, 0.034355596008320013, 0.014954037239564764, 0.040038731174483415, 0.03392641057050036, 0.04156606151692329, 0.10601223521535436, 0.03460215374587044, 0.07160109017164477, 0.026548449513352206, 0.07734953050291346, 0.028402541253355243, 0.030813925569095922, 0.028240754975066073, 0.0328271854819069, 0.09641405750787067, 0.016334825495798743, 0.012980165737380665, 0.03549286885367286, 0.09760045957180763, 0.030936972696274042, 0.0383734054142429, 0.06141156919540898, 0.016337014592042374, 0.05544572843298797, 0.021300145853010398, 0.017517274546046412, 0.033449283350379236, 0.02683470592713885, 0.01245226699768776, 0.07279020418683368, 0.041633910093937194, 0.026568088177291137, 0.04663957455646127, 0.020054291535709656, 0.016857153818672223, 0.07527129484280463, 0.06698212391065975, 0.08946842093381191, 0.061911299839736, 0.04001462238750631, 0.034927423187201066, 0.06054692405966982, 0.013783090041890262, 0.06604987151560283, 0.049760658894815755, 0.04800883414704473, 0.017628499021333073, 0.03940073315114264, 0.03513302969475908, 0.02244269704416154, 0.02002103374369683, 0.03754137264144036, 0.02288214806016655, 0.010370126204384912, 0.01768041488474175, 0.12498616466238616, 0.03291346996481861, 0.031973131511720924, 0.060589679426723914, 0.042205396363691944, 0.09627400131355371, 0.037528686225414276, 0.08314280229951106, 0.022246647483458924, 0.01764406018229502, 0.019582216665449164, 0.05764588698624604, 0.028018495631254012, 0.07336781915998267, 0.0364520262566305, 0.043265983807824315, 0.014822077636997548, 0.04994618240743876, 0.016782896916171717, 0.06364415242006222, 0.005007869359331145, 0.03405420935802883, 0.04216440299886369, 0.05833088450374142, 0.02044270385897929, 0.07500795211883322, 0.02044035771471118, 0.030257954495027665, 0.01692458104732777, 0.02390399252274825, 0.023298752419049704, 0.023456087726498806, 0.035630676579932054, 0.06324122464584728, 0.057545395402778546, 0.0072353116552075075, 0.03943557482993892, 0.06007442401061135, 0.02356672039886396, 0.03550373581087878, 0.011866171431216982, 0.013018328407328698, 0.0633025614755048, 0.03740766731601569, 0.0495445033565404, 0.030627113113540317, 0.047685464603766325, 0.027292993129982103, 0.04498574011508496, 0.017915494709966645, 0.017985225948054465, 0.05296086096355031, 0.021069664470550996, 0.013222334748734871, 0.04097421646058079, 0.035189547831372875, 0.029426406272837234, 0.013536433670519581, 0.026360683278330875, 0.04339863193191348, 0.08350205923160238, 0.027116727789924033, 0.07392371554047832, 0.027451967865589167, 0.05773204506465024, 0.03548716532907659, 0.0031176745288840108, 0.03866055432046133, 0.03869731121906831, 0.020593740008470994, 0.03447299515227637, 0.044206812557193546, 0.020214248779079607, 0.04410302296521203, 0.03809868628459592, 0.05474064409011795, 0.015192621917043243, 0.02180923043089288, 0.08294782526190243, 0.027668370467220104, 0.011041355206661168, 0.028410077643310352, 0.023203181035275904, 0.010085707444006638, 0.01253598508605313, 0.03406823642792241, 0.08774182729182706, 0.07090880715798947, 0.1300539818382071, 0.09832606741016912, 0.03531334380949697, 0.05386960595065067, 0.03234009528833051, 0.04558106704104332, 0.011902664029490084, 0.01611988803732299, 0.009566860033139106, 0.029534516600711696, 0.028609691428080685, 0.12428955325195867, 0.043203589776831294, 0.05217551741929305, 0.04001707003842439, 0.061495792901804375, 0.060585983052489266, 0.011042010211836427, 0.04454005697381593, 0.09128113818024436, 0.0402657728221628, 0.015708760249488536, 0.048204029519711776, 0.05151671627836843, 0.0172998568779158, 0.0060838858142585285, 0.03353739495299036, 0.011211235203870363, 0.06795081144739544, 0.02691708336163673, 0.083971471946326, 0.036483041326245, 0.04959962338269238, 0.05729468546867852, 0.07270215770169612, 0.018892980766512694, 0.025369212286727085, 0.07026243579363631, 0.04502233613522784, 0.0694493253925635, 0.053300548179615895, 0.03814816407318558, 0.08536710794414244, 0.06301515209939211, 0.021109368892446644, 0.03590163804831044, 0.013672726457908511, 0.02743353579013098, 0.06485424575305755, 0.024075896907297355, 0.017985277658989354, 0.05536223634056026, 0.01730088726617396, 0.01190852651733064, 0.019888190267186974, 0.029328136344350157, 0.03126810845588485, 0.02629463500793903, 0.06739848503662695, 0.03728776306454693, 0.07065480304581505, 0.01412992102784976, 0.034603842969743476, 0.038723990231031374, 0.0764810013013982, 0.01960362499249318, 0.09114934041375115, 0.12140399115460536, 0.258674000299746, 0.18721036162347565, 0.20123102702200416, 0.18938917696716326, 0.11024051961759407, 0.20082354485507936, 0.09400297196642046, 0.15001524540205158, 0.1588688162906516, 0.14764129214229124, 0.231534508207152, 0.11810887845293169, 0.16079088492739588, 0.13866612777834939, 0.1439178137168769, 0.13498473822349502, 0.23534928899138208, 0.2073104556409582, 0.11853170536097982, 0.09411538770842938, 0.1997780799865723, 0.16893588577307042, 0.10021094247818955, 0.1561284738202249, 0.1963406434703258, 0.1800239359539363, 0.0961374614628092, 0.17289804655217356, 0.09325632735365823, 0.08720119904366233, 0.12056252783945492, 0.16980223928488072, 0.17283610068261626, 0.21798449658578445, 0.08808400812408618, 0.13132331291994742, 0.12604665251508837, 0.19977788080371198, 0.23361986082407737, 0.2979174977348697, 0.09416196585422563, 0.19591414700112036, 0.11886765023753529, 0.1393278285620674, 0.1374657599315528, 0.2117043529306689, 0.08327417105676667, 0.18584487118547965, 0.22001758668451543, 0.07759637935387512, 0.1301043444583493, 0.183685269326933, 0.13191269500361336, 0.09281027265974591, 0.2559725904176312, 0.15846303483891874, 0.06908678194327701, 0.20034155297663905, 0.08928137290621958, 0.12227386867086734, 0.06916071708884931, 0.1610061556341187, 0.13537801712030365, 0.1343013571515199, 0.17021891450689686, 0.16481244816414772, 0.1256849517625186, 0.09699618473889367, 0.1303269849309037, 0.10764873691744382, 0.16925646292586483, 0.13825921251648857, 0.10110294461370477, 0.11410826006002965, 0.16698767821634972, 0.08691248348763875, 0.1640312836295174, 0.11108179907164267, 0.12913204098661102, 0.1294224036316718, 0.12493126680173221, 0.12861031978841753, 0.128103016364959, 0.11174328535074189, 0.16257430697160383, 0.16100626288642808, 0.1653975248336792, 0.12390503074012457, 0.16750455773886175, 0.15469408143431912, 0.15165666538861491, 0.13731366083506616, 0.11843882486104004, 0.12906309307342576, 0.19526289565668953, 0.19664186924215288, 0.16877658545009552, 0.15227993920205102, 0.24682421357400958, 0.08539499354458625, 0.09710782673209907, 0.20804741690235756, 0.1403263475625746, 0.12321868490788246, 0.19933351916411232, 0.15373477081377662, 0.19622375377483908, 0.15212187994151347, 0.2791360555396926, 0.26716939444022797, 0.12859463030772825, 0.11070054775524525, 0.12222518378327932, 0.17473739301485403, 0.17942228114172337, 0.13292331819332417, 0.13664920213482074, 0.17077365409462683, 0.16873207574169483, 0.26407063007354736, 0.19102322718789502, 0.23152186775640135, 0.10407037852752594, 0.13381745005326887, 0.2715703550606005, 0.11866976972669364, 0.23189985553824136, 0.17436173414030384, 0.16853375089985712, 0.16948045171316595, 0.12121606212590011, 0.14338784941261815, 0.2215222752983532, 0.10960400780482639, 0.18613157193026236, 0.14755883043812168, 0.15004751302542227, 0.14593190483508572, 0.2488614099040147, 0.15121392785541474, 0.12586646097441836, 0.1898026652634144, 0.2078650573328618, 0.09620151407415829, 0.1725353652070607, 0.11833003271491298, 0.14877519420077726, 0.13032767441003554, 0.24168477483814765, 0.12503069735342456, 0.3072008592707496, 0.19373606710184008, 0.13221413528005924, 0.18452441139567285, 0.13744061692587792, 0.2244856719288134, 0.3036404503208976, 0.10116026331219943, 0.20386918868509032, 0.1500415068960959, 0.14125607186748138, 0.14548129191802395, 0.20584077724526006, 0.13307305773900402, 0.16193223336050588, 0.2265980521277074, 0.16439108448403497, 0.22246871564176776, 0.10916588978180963, 0.15326790151096162, 0.14369097508249745, 0.12081231846804581, 0.21485966990791985, 0.12306126150032207], [0.057563233760095416, 0.032774130062710856, 0.024977116995761474, 0.04425565832324567, 0.02833650830472189, 0.03176044252130293, 0.051952160654529456, 0.07012363598351518, 0.009292279756928404, 0.07051652417548242, 0.06371214655378173, 0.042658870619150906, 0.08114181894568667, 0.0550919222164779, 0.06620038481008622, 0.0874332700585646, 0.07998232955052968, 0.04206869180404371, 0.045509376533089146, 0.04990884711244895, 0.020071681731590824, 0.02017514382098471, 0.02359474772557376, 0.012442030147799562, 0.06381339656429426, 0.02227954521414734, 0.029882492888117992, 0.056822181589180426, 0.020820030889984582, 0.03907285901086946, 0.07644904011319723, 0.025803241315448, 0.07578182349642439, 0.05380256942683651, 0.05434201789959785, 0.08620522345506376, 0.025116196427974972, 0.02655943521418639, 0.03305284817132258, 0.03620457602664828, 0.025585919408307924, 0.03424997929663908, 0.06953518086623761, 0.023163880724760316, 0.014858541506973487, 0.05869831559398483, 0.0640085536325651, 0.030339494978468266, 0.017620995190114747, 0.024828122470587976, 0.0245682941749692, 0.05778444547867102, 0.07103957836666415, 0.05795776521066024, 0.014837148501687955, 0.07778803156989236, 0.05806838447648672, 0.03986969004355131, 0.029368183590591918, 0.06680210090933308, 0.029252793512216983, 0.08095127755715963, 0.04606902291397414, 0.03435610545678966, 0.07704880268823716, 0.09790665725426329, 0.023261369243564627, 0.03803200599166655, 0.05010609943119269, 0.054763462018942645, 0.07332284213794817, 0.004297158579462238, 0.07919292190983411, 0.04382811231358398, 0.04783307059457706, 0.025229096720595996, 0.028998994328562292, 0.03097415094323937, 0.0546644106807728, 0.05787334998228377, 0.06629685826239086, 0.024034788629280466, 0.061930605255427866, 0.1053715022581239, 0.01638960269760461, 0.025548955665961392, 0.06585301756257973, 0.032294133843313304, 0.059398948966014775, 0.04555033542396081, 0.03931135367301684, 0.04684317391365767, 0.00929663688199775, 0.05573473127198316, 0.012326385345189803, 0.0313226520008738, 0.03516966018885855, 0.05360317589234441, 0.02700208464727527, 0.02164430702255378, 0.017234831334902875, 0.017217534984792435, 0.04156184037246051, 0.02767712685219463, 0.04780621155195179, 0.04641164807722934, 0.051325550528183106, 0.043877153432056795, 0.09813495911657812, 0.04875136486765358, 0.04625052063455505, 0.09207491252210834, 0.06594968253686544, 0.03806069981487047, 0.01224729825832671, 0.027217606247793284, 0.058112181723117835, 0.0433539460232902, 0.03782327767581709, 0.05093013424606574, 0.021908362208294774, 0.018417270809051492, 0.11140985324257806, 0.04270407363712307, 0.04323275474410865, 0.02127917419608322, 0.061880725270677964, 0.05711869208983356, 0.06408225895176012, 0.042866645155534636, 0.027574164635171334, 0.02440100163972426, 0.02155597900010405, 0.04772460020537819, 0.03636270806553864, 0.08632445737959878, 0.05051194216995951, 0.06926803834616177, 0.08904632947017109, 0.030849661655543797, 0.007694524388024284, 0.03846089648563535, 0.0260635752290968, 0.013013947342011719, 0.045959629388826514, 0.027740589575842026, 0.015783884746563292, 0.03179803637096719, 0.0681810515121587, 0.014266355541504681, 0.041090002989456545, 0.015433109365403654, 0.028412816407639655, 0.02113432420658008, 0.04356139114186649, 0.02459364785482326, 0.06990069673667032, 0.025350772550389655, 0.048322608439071525, 0.008005975518420699, 0.030268777402177937, 0.0432067230764416, 0.051557648356162736, 0.028521327016454552, 0.09819645299426011, 0.09331493307986567, 0.044773736773359205, 0.08027073101050432, 0.05446259247800035, 0.06915289533114241, 0.023207578379961274, 0.03458635701287178, 0.017289922632757696, 0.061688904515317375, 0.09204020873913843, 0.030775328144250862, 0.02201457455333683, 0.12202960919708976, 0.028100758152563247, 0.0031757538090460007, 0.031239259499876253, 0.023399841551098133, 0.03798011119567579, 0.016489556104305293, 0.06700768826469299, 0.06149671220731351, 0.06750920006344396, 0.047215075126939246, 0.029707962737208413, 0.037077288068230116, 0.06575891132196111, 0.07383404494894129, 0.03543862599819418, 0.0049851519795465135, 0.10105599874570485, 0.05202694232725809, 0.05717529449611903, 0.029560305035462784, 0.025779417896222685, 0.049744605522362456, 0.027527781841795773, 0.017206746551598755, 0.11208492226057476, 0.00763351362453954, 0.02909712444600319, 0.054875502377868667, 0.013387465958423434, 0.021310681477189067, 0.02577885290637853, 0.10216527107742526, 0.06955400364653719, 0.06671906463922032, 0.005382257485536919, 0.00426786816528728, 0.03736378579971291, 0.008974539044673645, 0.04934436671676175, 0.04723303222788438, 0.008112045658391812, 0.03555028714359768, 0.034980091731995344, 0.05953975975693715, 0.009764592114445424, 0.024664915099199262, 0.051263060736199545, 0.008494960343194826, 0.0366487882791027, 0.031198576400657336, 0.06660073469843596, 0.027627763976793618, 0.006314421301677583, 0.036367668484848355, 0.01696267668458243, 0.059053676968981186, 0.07996607316477645, 0.07848630539111554, 0.019347916334687222, 0.04189623392096931, 0.024336615780128107, 0.050818465439782995, 0.0809409813354573, 0.005970138515676222, 0.040309489629561865, 0.06573304819363741, 0.014635548633973927, 0.026703371643839825, 0.08595385468534886, 0.027629169748134674, 0.02996093646112469, 0.03182920082772692, 0.10263748767395174, 0.06550069372620314, 0.016229842721875158, 0.017277207488434452, 0.030945696522511786, 0.046291751486639825, 0.01613253231851324, 0.018030721994657672, 0.04736172733828426, 0.05405747369232197, 0.06088537404373769, 0.02547989858524694, 0.055147911752423937, 0.0074813010512791095, 0.04858559493215815, 0.06061140568025651, 0.01947601581172597, 0.06610650839584489, 0.016359656320644483, 0.0487248084297584, 0.01756471262553767, 0.03770585937966262, 0.04662734396275013, 0.0896645011380315, 0.04090879255184724, 0.06589627088678461, 0.0443048641506222, 0.0050282903905627474, 0.03591823151275035, 0.0629868183375126, 0.04582804995739172, 0.012766497112029504, 0.034745779909914544, 0.01868347295620028, 0.040240733238357695, 0.055523065008944085, 0.017639408113374826, 0.06398534116845939, 0.03267456544563174, 0.03408963709408718, 0.045597580066251184, 0.08232455910934557, 0.07682577917172063, 0.05290893169360296, 0.03686480592155168, 0.02197840754243155, 0.028255946498604554, 0.024215746257874756, 0.06607754261142786, 0.040763201372277354, 0.025379167599303108, 0.02489262515859258, 0.039695638697594404, 0.025740247820654226, 0.041953656041333755, 0.041569880465225834, 0.04077059412074666, 0.005071864514085915, 0.07754451520140133, 0.12292142747150314, 0.024602025026275266, 0.01442626394676946, 0.05241051489006608, 0.01998910511423263, 0.03901799562417212, 0.02118990963114606, 0.04061166151997544, 0.0379466982708583, 0.01654243723849856, 0.00454998291623328, 0.018877168711755547, 0.015143804879288281, 0.013726682030415584, 0.02712855044181549, 0.08424042243390314, 0.03468265043451421, 0.0243424131504951, 0.03674580182339396, 0.00904147023139822, 0.03994022375873981, 0.0472120950449138, 0.11486150068981994, 0.014902856820563396, 0.008317643547460677, 0.0668924686408812, 0.037822128543930675, 0.02445423900480232, 0.04782246793770502, 0.036179475155809236, 0.06736642425699581, 0.06997749705107943, 0.03786550061176381, 0.040574958247523156, 0.03391488477767956, 0.027279259088719567, 0.012073502594214535, 0.08876375793930023, 0.02933527436858464, 0.06355402217577062, 0.028795462004059268, 0.048851542355072115, 0.03785295592200372, 0.21567936866514145, 0.17022001767350783, 0.18980715453865069, 0.10889855573975271, 0.1484460215414724, 0.16070062444815714, 0.15957790727336563, 0.19030973886049565, 0.08364249080900224, 0.27206711711422094, 0.2119430199625992, 0.1856578691231628, 0.11219467967748643, 0.16569397021685878, 0.20153427526595133, 0.16007050180867796, 0.29798132818072076, 0.10931133923511352, 0.14305873804034727, 0.09290497644894546, 0.2508997860094232, 0.11933017582181962, 0.1041457002922412, 0.14411356450328905, 0.1462529416406347, 0.17941802169286436, 0.1678492513395125, 0.13711254743318405, 0.13421937042186338, 0.1835382110889881, 0.22599327167676342, 0.11482069118609352, 0.17691924206672177, 0.27764776120743445, 0.19760113389741993, 0.27601243928074837, 0.10799654083506716, 0.11712421032209551, 0.09791032681542058, 0.07325604693183015, 0.17427055435555597, 0.20012635887870867, 0.08400442138794931, 0.08871089787252488, 0.1642918148108067, 0.2746622246359625, 0.09855242340915626, 0.17042770410978025, 0.12407515588546954, 0.0912978082534767, 0.18624464650788616, 0.09988873355811644, 0.22527422155103377, 0.09339750969722387, 0.07847699742283552, 0.16856837807403457, 0.13983652626554813, 0.14032297677570774, 0.18719315528869632, 0.19417583221389403, 0.0948575736894723, 0.10480930863489067, 0.10766796572434326, 0.1280225694720303, 0.2651478722691536, 0.10615684963282078, 0.1747322908692783, 0.1129581169375489, 0.16781552814908568, 0.1567323962526937, 0.245293753762399, 0.1428863222921087, 0.13423484539793384, 0.20625909189543418, 0.18048807798374086, 0.2839599579813019, 0.13254629568226878, 0.09515837045206178, 0.23618210317386737, 0.15309255930685228, 0.10281937226893441, 0.1079772200976168, 0.2022904653342501, 0.16806714206693635, 0.15059204832200082, 0.12543318462708306, 0.09173444006592037, 0.1555458792755681, 0.219403674465514, 0.1474953523927158, 0.16313519058448656, 0.14904134846743078, 0.1535736778450589, 0.11248315008537424, 0.09002935051197007, 0.11015979693301263, 0.1415655560671322, 0.27372680063689914, 0.14968743637925194, 0.14698507654811108, 0.2226405338414254, 0.11641469033014391, 0.17412122849735523, 0.1169633854841513, 0.10844258020722097, 0.09572432556700322, 0.07446075083627816, 0.06566596187410817, 0.1378991205485598, 0.1168187021187717, 0.11138751411870604, 0.1437250813168864, 0.12718332015098105, 0.14817998984888678, 0.10314245452924121, 0.16849975191777752, 0.1731021323752019, 0.15425918864146357, 0.15452468407250222, 0.09896490046934736, 0.17009585014274045, 0.08812791262302669, 0.2747637159641712, 0.0749693795918457, 0.1321245336364354, 0.13841097453428855, 0.17575658106755826, 0.1937001528999498, 0.1671688120451666, 0.06632265244280139, 0.11747029820276846, 0.12376122837585789, 0.19045102079549145, 0.19723517369599114, 0.21734055372015124, 0.10550818000469478, 0.13519912026822567, 0.18112170930591323, 0.09322017566451142, 0.061595978050102154, 0.07769731143789907, 0.09301012201655297, 0.11744304079442255, 0.09727587577916923, 0.11520888325908493, 0.12685151214921667, 0.1556547863348838, 0.15265939787270563, 0.1552236626946157, 0.07537680813261578, 0.0954197443300678, 0.08761029765610734, 0.1018327659356498, 0.1189343918174986, 0.15807714102970016, 0.24524666999857275, 0.12381978813678989, 0.1318966990877544, 0.13224180637588426, 0.13581168417248035, 0.11958602620589158, 0.14384331932711986, 0.1613656040881911, 0.23593960570231562, 0.1215609932138074, 0.1656627597948236, 0.16815242297466726, 0.24184560733697108, 0.09270458316971218, 0.15496420403642042, 0.17217596271826377, 0.10397731416648436, 0.12040916469789321, 0.1341043653026704, 0.23010279712898118, 0.13722562201080785], [0.00634794770326886, 0.0350093103254274, 0.07350461948062144, 0.05453822450832494, 0.0029551657339212515, 0.0677368967162986, 0.029441312428623922, 0.044002975712740616, 0.045142071847353256, 0.012291787856919392, 0.0286499627550403, 0.04897548388990183, 0.05271451390017906, 0.04454991652540142, 0.01902211446224922, 0.05717706415922411, 0.03866010998946525, 0.06226532056086487, 0.054800157630515677, 0.035543530248105526, 0.04319970188061557, 0.020904687436057195, 0.03900031814531934, 0.015911440301175802, 0.04332212656135521, 0.01592614823171208, 0.024052104131589015, 0.011754029565640997, 0.06295082369639028, 0.016050135731817256, 0.022842393842555826, 0.006801124620852211, 0.058789277043674266, 0.02977596261658736, 0.013661941855154453, 0.03471825437079515, 0.020996319212680383, 0.06945084224665357, 0.03342007241782642, 0.06377006663129696, 0.009244841677437146, 0.004661017784758682, 0.03554500879779939, 0.02973897397638329, 0.04663580923431343, 0.028178916357818152, 0.024682807082670833, 0.013631409420932253, 0.04915399386757805, 0.0029111329152534207, 0.025969334923091437, 0.014029150779899812, 0.020964718085803816, 0.02595716944685386, 0.017829646897171775, 0.054082061284251755, 0.031827480960336905, 0.020447143338500492, 0.01508064380276107, 0.07365352399046383, 0.017611572308646097, 0.04325975551299992, 0.03907461718265568, 0.008147397743267639, 0.04060126953728257, 0.03637672364411335, 0.02418598948767589, 0.018110956298187375, 0.003733316191374475, 0.015424232321581053, 0.06374827142985118, 0.11182038443944148, 0.020114454335623214, 0.05783707571906909, 0.06289494524319326, 0.026793329518348463, 0.016019022985992414, 0.029261375612188733, 0.02291233575482282, 0.01066008473806564, 0.06541890617940696, 0.005058927204264629, 0.008108186490473249, 0.031582851849135854, 0.031577079376626405, 0.004996916217233745, 0.07519144549845688, 0.026655353252745928, 0.025003592994424607, 0.04811655760051743, 0.10966257522663764, 0.05364769326162435, 0.021688286215066913, 0.028012340114782416, 0.03140456595217749, 0.026346284655794024, 0.031056070640202493, 0.022314522873550173, 0.03780116071744311, 0.028351567678093433, 0.05963932820445588, 0.054599109346107136, 0.02812802130656858, 0.05921779981543941, 0.03798597942917578, 0.05770911605307653, 0.04842446365904424, 0.029567324316069007, 0.05705358227714897, 0.027317011901628108, 0.014273534742965093, 0.021297889724073392, 0.02744569743592893, 0.09330754033139638, 0.04319479125702093, 0.0900873280460796, 0.1288861114411585, 0.05875330538518968, 0.08950553023286405, 0.07820885132757888, 0.04587432166801826, 0.1042627125617958, 0.014678593199219436, 0.021082684134824142, 0.07473468089536314, 0.03314256089769545, 0.03795019546223264, 0.02905842551450816, 0.07019991535813579, 0.012661525829424782, 0.10622203605429781, 0.030124164899931322, 0.0267272601805387, 0.02843745762572414, 0.10724919142141458, 0.012094855379884042, 0.05467197962946469, 0.03688087844620309, 0.07361813838924132, 0.12735225019916413, 0.026084703934048454, 0.07222192016460242, 0.0482563303423024, 0.05913111313636746, 0.07699528378584693, 0.03177279568908196, 0.009951652590966514, 0.06744874040445975, 0.02356623201781223, 0.018624244783554348, 0.05517520363472643, 0.020359652267108043, 0.04313534666453639, 0.037680969183002753, 0.04759064207093851, 0.04468157256562864, 0.035482304501197034, 0.00729856466228563, 0.0368459984630106, 0.03210081538606075, 0.10949038930477635, 0.041455499707691135, 0.0089728306686025, 0.025513342153581402, 0.07151854419780355, 0.09136255800483689, 0.016297932616585208, 0.0559126551923973, 0.05114484953904345, 0.024962775829818942, 0.05346294732824449, 0.06285963242032355, 0.03908515089161454, 0.04608004691920454, 0.04292094163716801, 0.035546433721338554, 0.04159066060017194, 0.02241237911455814, 0.04537137345440927, 0.04614928211536139, 0.007848111610303844, 0.04741030114312326, 0.022093286257117026, 0.022422215683505903, 0.026451533645271297, 0.034989426513352705, 0.06015782417248815, 0.00521255225213545, 0.03751773116809707, 0.04309918731451035, 0.06029377030509134, 0.016584089438941692, 0.036855884827673435, 0.06701767039034637, 0.06773337271184691, 0.04552506601377841, 0.031109963010455814, 0.03734329677817803, 0.03593377926717362, 0.05745648706872618, 0.026893855575772545, 0.035093867280069864, 0.07348486973393349, 0.061777288079141617, 0.06223681442920239, 0.03160940637181123, 0.036198152379403194, 0.023905176128591263, 0.03603342815392441, 0.04224763079095752, 0.013641433681421464, 0.03288698247483662, 0.029713689244442412, 0.014244666634758395, 0.041009000682782744, 0.07695062085986137, 0.01012280716695973, 0.027056371552809596, 0.004783551633027533, 0.10488535818313399, 0.0680007373974208, 0.04965900285770336, 0.0673137863557185, 0.04500963056700365, 0.06948304092211109, 0.024812446396437385, 0.024747704305956443, 0.013408397395734586, 0.03324902030609308, 0.03400426425580536, 0.019855382551829663, 0.026267931098118428, 0.05185881284095588, 0.03856953541417757, 0.09216018576895998, 0.11460267022372254, 0.006688797457759539, 0.05236379501800384, 0.04787498326491445, 0.07533864929310738, 0.013285053409485808, 0.026229737784653425, 0.06123433092368707, 0.08024394857667147, 0.0126076937885955, 0.0594091379354077, 0.037282002083356344, 0.06043623584593016, 0.03473127786550791, 0.0808358510896083, 0.013557933928114514, 0.00729577610224125, 0.02463674604622347, 0.06976722123762293, 0.048251147757494645, 0.040034709212880944, 0.05910678601433193, 0.030554229423644084, 0.04705496658120425, 0.028818756822616826, 0.07172641449517782, 0.0600552641516251, 0.04673293003091409, 0.03837462732448213, 0.04109070779034688, 0.09094629647029985, 0.02085692185397831, 0.016619856168906537, 0.060112889285289475, 0.02422780448180293, 0.0295447189766433, 0.06953122019166909, 0.048283288976357835, 0.02539012648705994, 0.023716314387838208, 0.023239374859258536, 0.020629602499426376, 0.025704209129476262, 0.06718414129629251, 0.027621780830104987, 0.05110953288573412, 0.027735636817411553, 0.024713396973487352, 0.02297253494391278, 0.026144523909615896, 0.05916889276235335, 0.036919837847592375, 0.09059529030515302, 0.03288501362887121, 0.03475596887930747, 0.01667755216570391, 0.0228571008154822, 0.06428800718558413, 0.03552479173747763, 0.03330419778883938, 0.058909920569989956, 0.02642100887192834, 0.07689903249904033, 0.03779159227926885, 0.04185183912575726, 0.07952106035044117, 0.051741275801173145, 0.04825525781920841, 0.01785363694052062, 0.0037653647614793195, 0.011639112546559305, 0.0248113930255415, 0.014129238251987246, 0.029901972588812633, 0.03792666507163837, 0.05811575169284498, 0.011655335415965848, 0.029069376741385752, 0.022801174481789914, 0.07296594475666363, 0.03530995387043204, 0.025696255221602418, 0.010260737467286809, 0.007806996629017616, 0.03033994313990397, 0.02090584231360305, 0.039014850833242944, 0.03526064845162534, 0.027603653274596702, 0.04043548811046828, 0.033350879356505415, 0.15050286036585608, 0.04370159289288906, 0.07563824329765574, 0.03569523097887155, 0.020448351842201045, 0.03159012393875709, 0.027349099494336594, 0.07392635088293784, 0.0497942595111747, 0.03753015328378927, 0.040111762336305076, 0.04043805833545424, 0.02358474644772228, 0.07561979590043907, 0.0722714017836317, 0.1425698973358639, 0.04726549520367577, 0.006937264190656284, 0.026948998584562255, 0.016946368587894306, 0.0799373372067367, 0.06087728032481767, 0.019643542003787814, 0.10019748997423919, 0.07366966546302842, 0.03245156108131332, 0.1250531820340022, 0.09670651923384398, 0.12811662974737345, 0.13252734266702207, 0.12060038790467287, 0.16087242732605628, 0.11389265227462016, 0.1362548660366766, 0.1647137607177419, 0.16086639055321295, 0.1296296917022236, 0.15640492430858075, 0.20483784557830906, 0.32409248513079464, 0.07938458178673061, 0.10345197703328826, 0.24573984676070754, 0.18975044871049543, 0.15406854000062714, 0.16625915924387594, 0.1005334425116739, 0.1269816628266727, 0.09679044416594891, 0.11011850479389391, 0.19097104127849304, 0.10021666515498392, 0.1362429610303333, 0.1657381428465728, 0.19603036253923373, 0.1614437297347092, 0.11249864038320319, 0.11606405954807998, 0.2708466164767742, 0.09839201991957042, 0.06183333124124235, 0.09649252023307547, 0.19720696633861912, 0.18756254756402588, 0.22317933880033033, 0.13434038167038273, 0.15171335589501167, 0.11064395684027865, 0.12145485939277757, 0.1634375042011661, 0.13687608673447563, 0.18053226593521335, 0.11825916192103779, 0.09826787537144077, 0.13366530499150678, 0.13789211850493185, 0.09789731098158706, 0.1060653787346617, 0.1431795501060063, 0.10004691539272186, 0.12172753306766673, 0.13274961541737282, 0.1771168314641522, 0.12205252288690499, 0.2821581804704282, 0.21568488449819628, 0.06894324770978383, 0.07612091699434866, 0.1196078826943713, 0.09870138154515336, 0.11386004757256278, 0.18812186835754305, 0.09789659851981748, 0.18007337926856934, 0.11730723638808536, 0.2300542271545818, 0.19033492783144598, 0.21173513434346647, 0.07750808005972255, 0.245743615913295, 0.155048213238197, 0.08149968925863504, 0.08332605053099894, 0.19288544903599447, 0.10262644068608362, 0.1636387401771161, 0.15468853495774731, 0.09441546434837003, 0.19729885092425734, 0.12045124590757395, 0.2644275044721942, 0.1464376607609372, 0.20039833541358673, 0.10141750797629358, 0.2349015565649156, 0.17685453828063705, 0.11378104858581098, 0.11202252439914212, 0.15516678832711714, 0.10430438774487666, 0.13911036684388114, 0.19149945808514474, 0.17970829240737424, 0.2259068263153876, 0.15946478673046635, 0.11975255073799242, 0.17588522255180344, 0.15649394372538214, 0.2023103836202814, 0.16309612010034824, 0.10559283272032777, 0.1577691890058979, 0.20779923505840764, 0.1075323988052626, 0.14971193587107046, 0.1274881925013277, 0.12125075058711153, 0.18309916609958296, 0.11783955258227165, 0.23035199020899114, 0.12373842193835205, 0.25383367293304016, 0.22080290341569533, 0.21998626901017082, 0.18253457462114675, 0.25037919862135766, 0.1002784424851979, 0.2931587740538582, 0.16305585451904805, 0.12857751590349983, 0.1904847133424013, 0.20454213563953677, 0.11387064256855559, 0.1626187400712121, 0.20448916832045202, 0.19696419307541466, 0.20904412793536342, 0.12636664744106033, 0.13450504460882756, 0.1236636900613385, 0.2980762617962976, 0.13208316488852426, 0.07317841924246281, 0.1265387261106122, 0.1744921069832579, 0.16135638038958275, 0.14635415717719064, 0.12869990611028287, 0.15625141561031342, 0.14837548016540467, 0.09313585236668588, 0.11168636501796785, 0.11318800460186698, 0.12347196889740807, 0.13475057578855945, 0.08234420926460335, 0.19646464246174983, 0.15760241166478203, 0.13557637260565836, 0.20135050609467492, 0.1565148426039565, 0.20779509818361652, 0.11181099986236905, 0.14209093916560375, 0.1220130080717706, 0.13536174541279195, 0.15263108326302421, 0.1353818015946496, 0.08084207172355345, 0.196075837518419, 0.2657631634464187, 0.23045441616446743, 0.15634228895989158, 0.11456421260992367, 0.1774930878872833, 0.16199548157953447, 0.1754713358898317, 0.19639445348612725, 0.1228011133629949, 0.1771603605800098, 0.16886134541803793, 0.15886654867039574], [0.061555084276704065, 0.034352987478937835, 0.005603846023610283, 0.04170436720033327, 0.052165929828920675, 0.051694379728888316, 0.04395759266410624, 0.014803845702009577, 0.0487337218627574, 0.037529793222464865, 0.032857955403385625, 0.08972843883619194, 0.055957655197069536, 0.05326401727694658, 0.05122469505295158, 0.012215063193692796, 0.05759369724640443, 0.05370298948799891, 0.04129834060046462, 0.03423692898884897, 0.04163551887857818, 0.04204406590771772, 0.08585193434790259, 0.01703285416888614, 0.04432118948428862, 0.11245036152221503, 0.0140810149323736, 0.03949842468324689, 0.05196966193315964, 0.0074218473615004655, 0.02993948791446465, 0.040522159467781746, 0.029959833294513728, 0.09047923564550378, 0.027425844267371203, 0.03396499841924637, 0.038704956776552626, 0.06111570986949148, 0.04131987533201614, 0.04519562139326046, 0.005051450664928604, 0.0314365673599945, 0.04707645534748032, 0.019354422336384174, 0.0583669787362939, 0.04470265530530484, 0.0692211537651958, 0.04172445785614752, 0.006434221173666659, 0.05872699026499064, 0.12600991859911911, 0.014120391851681617, 0.059130921614386385, 0.04750043138741486, 0.028869688263042804, 0.010810440026914642, 0.05958656772911068, 0.01795712967343148, 0.011286706355730853, 0.052191555469987855, 0.10229578947708493, 0.03266079884563242, 0.04518855040171935, 0.05541595825625043, 0.00858819324357976, 0.019109414011660605, 0.013147166201604471, 0.0493416202915532, 0.028815261546462297, 0.022944145640658758, 0.0720275866408502, 0.02065272494820097, 0.06447386011601457, 0.023284078004860112, 0.01742104049621811, 0.04549299757326803, 0.031285628886713136, 0.027418748377972556, 0.08687991708997758, 0.024011137579838117, 0.05247870820664591, 0.023780640875620228, 0.05255732797987519, 0.07952230907375775, 0.002130224541272788, 0.02831501762322601, 0.044304542393694, 0.03807357775287763, 0.004060677292140862, 0.034894174971287294, 0.03114839955683678, 0.036166030312738115, 0.0329275889652631, 0.004335404561472036, 0.020905223697604194, 0.048020884710093664, 0.12555411926680995, 0.06252943320320019, 0.03811823684842356, 0.07102833985681496, 0.08324220986856569, 0.09923792654468168, 0.0448705243217128, 0.029225107094633485, 0.04875918279492086, 0.09417873551888813, 0.03017543341904398, 0.025593137871774457, 0.032161849610988176, 0.03932460316366727, 0.02972135969978427, 0.05390949997930758, 0.10560100687847984, 0.037423410422859654, 0.043463305074481234, 0.015612509920291845, 0.03560105579033975, 0.036553165184394006, 0.012143591978406955, 0.02287040776272695, 0.04580906246818843, 0.028653178409102465, 0.020233395231527188, 0.06376355871438019, 0.04854781913661188, 0.027527812485312744, 0.07433865174290634, 0.024540615418264945, 0.049757621356195984, 0.06645553805414708, 0.0263318190005638, 0.029216207068173156, 0.05852340622955273, 0.018367404230840264, 0.060975481305391564, 0.02889830356223449, 0.03269005191302107, 0.049046496410043015, 0.04765111705168121, 0.033317596666635044, 0.02957610368368126, 0.07353589118969056, 0.02772874777175246, 0.03378283420217133, 0.03832824836154619, 0.0549988923293929, 0.043277647496471484, 0.015736036810032543, 0.06306775169627321, 0.004484625561388149, 0.031197283627285115, 0.036167152631547184, 0.03609175042759988, 0.03049951542409197, 0.012534952782575163, 0.05064063728035939, 0.013214867306692947, 0.08029173714138808, 0.011468602442032388, 0.06971600825988478, 0.015756597652310328, 0.028120728149529428, 0.06691473881684004, 0.004465812357187632, 0.05993487726476404, 0.035482277688119686, 0.06954179986590339, 0.03285474932542251, 0.03524565228050755, 0.026469444780940973, 0.02333430655961556, 0.017138520676282146, 0.011371645396725546, 0.03438383017876937, 0.028720339422204325, 0.06286010356439699, 0.019676953013385498, 0.04626397696894504, 0.08177420920542172, 0.03615977137439674, 0.01436118765043155, 0.05507424856806475, 0.027536214554622292, 0.06965185605710553, 0.022755128767101035, 0.042330762822060816, 0.07465756648490507, 0.03777168548455642, 0.03309052054499907, 0.07416608277708292, 0.022837015905327374, 0.010127275374778097, 0.06703076283297232, 0.08141616269225076, 0.04430171935969303, 0.03848283724378675, 0.0464963659103359, 0.03334157521866503, 0.05920774108099361, 0.10882981467030703, 0.044618883590784766, 0.032858116281849724, 0.06814845447098056, 0.04210080237938993, 0.08527429639211587, 0.028999164783125444, 0.03887055817270472, 0.02728473087171874, 0.04402842132314559, 0.03467452224163759, 0.03541057185840703, 0.05630552806260605, 0.044298635855797804, 0.027352476026862863, 0.02876582589270848, 0.045804565532072905, 0.02851249785312722, 0.0320890118863674, 0.019634559622875625, 0.040584404111629536, 0.049324390974136136, 0.055957632214431806, 0.03886768917342828, 0.03437585520347761, 0.025807360953260815, 0.022429267522848906, 0.03832425704346069, 0.0320540054986674, 0.030113261553549, 0.03680653344359129, 0.0213767105953828, 0.016918747287784374, 0.0022646325129655103, 0.03653748336458399, 0.019868877190615863, 0.04687261467258777, 0.04914790729901964, 0.08415673498905475, 0.1286267293917556, 0.05209605877978667, 0.06787305352308097, 0.03325590360609274, 0.03974830724238869, 0.03406956176003141, 0.011277291135141447, 0.025628174902991425, 0.023920266145479777, 0.04103766769290932, 0.04625496394451588, 0.04524977997906747, 0.004347874078854558, 0.036693466526846734, 0.02324326467069407, 0.040451510839404604, 0.02624996825151386, 0.03636693687088067, 0.020998718983103192, 0.04024347583312662, 0.05508203202137544, 0.006368072833039708, 0.016611360253826264, 0.011614317153280061, 0.06527216969839027, 0.011837088818391486, 0.046382019626757795, 0.01990931897213863, 0.013530341356301741, 0.04522637982342032, 0.015205999727420991, 0.04203329088106271, 0.023460119264200333, 0.057622207208506526, 0.026215898406301296, 0.01970369522760232, 0.05397557889321639, 0.03890521215995954, 0.0816023373796094, 0.03735899008930691, 0.022483376312940832, 0.05678726713203135, 0.016238574208992145, 0.07336998718880838, 0.003669525725736974, 0.04966711189838187, 0.06448430955530175, 0.033564269317374114, 0.06609156968132143, 0.028778542952251532, 0.1360874911469798, 0.051211813284504804, 0.05193313869136957, 0.07196590890206638, 0.02433877806329439, 0.02235336927697063, 0.04610109518492415, 0.038234716686870784, 0.015309670575774245, 0.034636995424666715, 0.0326679885808018, 0.020770244751005404, 0.047364431628656965, 0.08773228183629052, 0.0660123868334678, 0.02613208072650577, 0.0453700557831795, 0.1132379765171678, 0.031141123636775923, 0.024280938425011212, 0.07616682864365078, 0.03585474580646523, 0.10919794290056152, 0.04043123632248852, 0.040926293830477425, 0.11754486920131792, 0.02785898846453957, 0.0019740338170630557, 0.015818138452877682, 0.027964212556159305, 0.027032189987479683, 0.027787485648126855, 0.027129734047658505, 0.017040633791757208, 0.027890116532122897, 0.01289503996245443, 0.028475800326334375, 0.02146731198374783, 0.02205656000202702, 0.03307270900075955, 0.05894235673270399, 0.005455901996502954, 0.005100349578330474, 0.08170778172150736, 0.015712342668144454, 0.017868983596863768, 0.020824246288787936, 0.03833516230506282, 0.02861478591277715, 0.061960509497552156, 0.05112729463425856, 0.04548299629541655, 0.04161417949944735, 0.03739075209464758, 0.020276033770172827, 0.059818186752137646, 0.0410289840862876, 0.0486067581110664, 0.015542404256731033, 0.012983300952210784, 0.017420914091710604, 0.013625274014268673, 0.02977057701847967, 0.07678251818663652, 0.22809966106808957, 0.10246805966861787, 0.1470056843132742, 0.0946791747945451, 0.17068943038823145, 0.10140826895592675, 0.17266229065435548, 0.15566793240366444, 0.06001874857071427, 0.27920748557775255, 0.10640996508300306, 0.17725517162151877, 0.19282842145091106, 0.19541802846135634, 0.15048511776952975, 0.11041612229159764, 0.16007817800967925, 0.18548107135199732, 0.13881931471968853, 0.19504770155875914, 0.184227736186116, 0.12408288571262553, 0.18945283887367095, 0.19672972420530935, 0.171617285438603, 0.1583697100079829, 0.11717508622114697, 0.14439782908847257, 0.1749255595308158, 0.09991675705438662, 0.19440385062367688, 0.1423187277490093, 0.15031432612769066, 0.18034420667156098, 0.19903630769300848, 0.1101049910029096, 0.08844808374922122, 0.08833759088790225, 0.11471586737541423, 0.096463477839866, 0.0863528102936764, 0.11198294063609456, 0.11881863593213982, 0.16179645193680642, 0.1595880349557246, 0.10964268758412331, 0.10454673199884354, 0.17081280118755757, 0.11810633504102308, 0.15700768228740464, 0.1299239920392152, 0.13736330333255953, 0.09345174872226293, 0.05901926812986213, 0.13883007059414543, 0.11054895427678862, 0.16165854078867745, 0.08225351977612703, 0.1520359248764092, 0.11787981816357183, 0.22794354767087968, 0.12645864693988718, 0.16271333660810225, 0.16004600231685948, 0.10050873617611586, 0.11620027764189629, 0.16581231547940165, 0.11677459077609163, 0.16354749910533428, 0.14860326874881022, 0.11668198606780461, 0.16221576250128208, 0.17180395042223318, 0.1453510110056208, 0.1579725393845189, 0.16142183494183326, 0.12820303680435305, 0.09128172806794606, 0.16732780593297175, 0.10230825372761297, 0.08346884165920558, 0.14889582240533444, 0.10826742952509273, 0.1049062800443461, 0.07519993375265792, 0.12177455554445907, 0.16735354648722758, 0.0724881357182899, 0.09199975163585718, 0.13290234270595735, 0.083888428015334, 0.17467026839092856, 0.08856498876646643, 0.15365489848679112, 0.22190325082309786, 0.2365726088323901, 0.3761055038100289, 0.11725187887467685, 0.1735639914629921, 0.12949763346583615, 0.18686009090273611, 0.12963059568597426, 0.13617358410791044, 0.09807796983589089, 0.06667035676899456, 0.1856729610552711, 0.24689418804501337, 0.15024113408740492, 0.17867836380197158, 0.21252771358816855, 0.13043265909917895, 0.1697702014878873, 0.18542787420653528, 0.1900888757119256, 0.1435382631156714, 0.20733469466288246, 0.14425095471162952, 0.17825876212408467, 0.08303276909094665, 0.14012547930882824, 0.1117137220177439, 0.11117889305516598, 0.08522988627514533, 0.10891430650747592, 0.14330449904645645, 0.24259913141929337, 0.150562584580433, 0.18363441641051925, 0.16882103387146227, 0.30626672229939894, 0.15367256447432504, 0.11989717281633809, 0.21791237706859268, 0.1727944254995354, 0.19024763977335346, 0.06818626857092304, 0.1326186450258378, 0.22148789327231147, 0.09632228783542111, 0.16358791790421934, 0.22980878790540082, 0.11468954459433595, 0.11036945987612971, 0.15746564964853949, 0.10492023050544724, 0.13583247579874533, 0.12684178283257833, 0.07745055451748833, 0.19610680279231843, 0.09767548256223241, 0.11099487873575381, 0.13508334906110842, 0.15602070057103712, 0.15517273316940955, 0.0723990626753338, 0.3188506970482488, 0.16920492053031924, 0.1631504510559382, 0.08256824401717994, 0.18961167954389127, 0.19362910590585203, 0.10198861886296542, 0.17076530373625218, 0.10043657069364864, 0.2362545904132628, 0.1641742816014636, 0.13292714863294555, 0.12033683067608265, 0.15332643062837664, 0.0975035954146616, 0.11564407482623093, 0.08261050142708325, 0.06775188905697677, 0.13862338007217453, 0.15109958157183664, 0.18092154585305723], [0.031031760755145264, 0.0288588423732548, 0.055599532075106144, 0.07537998739750155, 0.03876456990838051, 0.0970299079293205, 0.05855107732537774, 0.07218524753566712, 0.020781171080025456, 0.010803249334135364, 0.04728860807635131, 0.04138875812772782, 0.04081037323621493, 0.01846785559469173, 0.05733771662738535, 0.008418226103869178, 0.050901750688471144, 0.040701604072725585, 0.02337497816751561, 0.010620313283476618, 0.01919467193675378, 0.040931913085402026, 0.04724902048286411, 0.00952531221217566, 0.04404801785224869, 0.06762567607145156, 0.04675996910420157, 0.02612408468379609, 0.028136948146106257, 0.013185597959935907, 0.03023704795557405, 0.10113829957141031, 0.07927700772040314, 0.014983629300859908, 0.06482848987704323, 0.039744449989689935, 0.03164533206502036, 0.07150329138723112, 0.0458896855613397, 0.10507432143053702, 0.06960920794236083, 0.03598275143773325, 0.029704572798143473, 0.013019064809345912, 0.05122546114087586, 0.02205571155965088, 0.019346012606195385, 0.036848553366238074, 0.0742757865678399, 0.0737395326817228, 0.03752259199597663, 0.08256083594695215, 0.03841731757406266, 0.06231465662318853, 0.04273406980979828, 0.029621546104129766, 0.050110515928076166, 0.011917534753710273, 0.02103637795024101, 0.04385677549327093, 0.09862422116941984, 0.06179733660012003, 0.06702695537598864, 0.03298389259725809, 0.01811788173302287, 0.022799923843253526, 0.042339005928126075, 0.025764511740435998, 0.02599288829632344, 0.008558063963127714, 0.02065605360023197, 0.07004548735435932, 0.020371787099828644, 0.032584017683421417, 0.009226351187774732, 0.022797127622329903, 0.05194499390199781, 0.009635213270573127, 0.020378842769611268, 0.017972363331805796, 0.037753655605258486, 0.059034720123294866, 0.010265911433605418, 0.002387270980116521, 0.07686360093254237, 0.021172438996032845, 0.030144500703881347, 0.022325726909442775, 0.12418605477338839, 0.026065865831990397, 0.023752558007535916, 0.055395840787358826, 0.021063332753856818, 0.03657097672863353, 0.07721971690414414, 0.03082241190807714, 0.050553598200842265, 0.04257909405315596, 0.04892004210682166, 0.07205849828859491, 0.029772829316977053, 0.02970052402346365, 0.08571503443583366, 0.030883340795914975, 0.05474858842189274, 0.03915255896807198, 0.029340209890036818, 0.0025582558197540144, 0.013519554838327872, 0.02216560112672948, 0.02088323314373772, 0.07150360548328008, 0.03365614241169345, 0.008850977680976353, 0.07204815610161713, 0.04251971074770536, 0.06570196034567011, 0.01526678593138293, 0.05641726964724161, 0.06409115706300063, 0.018422169941327265, 0.041195087270030094, 0.09540790827163766, 0.04442252759491244, 0.03566485559267383, 0.06824820677960111, 0.03329204380392067, 0.03374047720083787, 0.04515979146104186, 0.022302020318625916, 0.0382859411559278, 0.05633408015954399, 0.045619624246272354, 0.05315773789921115, 0.02458567479475131, 0.017245648496393717, 0.011691098315491071, 0.021776518476526105, 0.048051049422112205, 0.060208190623069965, 0.037080942307628935, 0.007070049731766866, 0.030690753952630108, 0.10364617266121412, 0.043520359472642024, 0.03419950559374786, 0.028061729803260778, 0.07042262477860337, 0.012198338536695849, 0.08197025110524508, 0.03442370505522817, 0.04574136327831976, 0.021116156431455767, 0.011568690871729726, 0.05595570550330224, 0.032026594872736645, 0.0796584812022986, 0.07284707855433226, 0.01521909504287666, 0.05724868954970472, 0.06494283616062134, 0.0730341648863208, 0.0502921438836042, 0.05662279954600719, 0.039662371329482526, 0.07367606995807541, 0.023750194626289512, 0.041146789256843834, 0.015198240214357934, 0.00428216097192959, 0.06287358671186433, 0.04193091472130149, 0.06831156225093911, 0.04289851058274508, 0.034960112158930114, 0.004385120794928123, 0.02301867258915257, 0.06558209822903718, 0.030772275283872604, 0.034263726744440295, 0.09275622515668792, 0.021285205223267118, 0.05525575777996452, 0.047947639043653206, 0.06570350018239791, 0.030717455947230903, 0.009257803885115972, 0.12589200234581388, 0.028151477003590237, 0.013470504143756005, 0.04734101232081171, 0.02239664175337361, 0.047682147443054185, 0.032019163819871126, 0.07575462737511243, 0.04048349117980369, 0.027045933604841272, 0.0723466239569168, 0.04465447603574684, 0.035712762901018706, 0.0505524950342313, 0.0354417784500026, 0.03892179030264097, 0.03208261122176003, 0.03833484054813462, 0.05387405692149074, 0.009765007717144347, 0.05069745802170327, 0.03633263528407101, 0.02305884432468203, 0.03209478435887685, 0.0023391395910537893, 0.04717363743111492, 0.11950986174445961, 0.03536431163909935, 0.11776640650726135, 0.04105532218912437, 0.0687301756754037, 0.026123812722582972, 0.03668392490174982, 0.07773304943956676, 0.04222786572251109, 0.013239303596257685, 0.1377277773234152, 0.027216439878928567, 0.06740946307658188, 0.043557173827843326, 0.03042016978255443, 0.07604048542317844, 0.043696578847424644, 0.053261416408443646, 0.11413236118612752, 0.035236076181454044, 0.03683810009651127, 0.06904143719903885, 0.10695988597768931, 0.023648733941597805, 0.01270179428355468, 0.007739659415693173, 0.028289466675731446, 0.013197074914651533, 0.029103088440493714, 0.06936018340169423, 0.07286420061943993, 0.09920627179165041, 0.05151078292739488, 0.015425506900365074, 0.033915332939115264, 0.03477100335482148, 0.028806905442428206, 0.01961274718445155, 0.05960416093829179, 0.056234385307517745, 0.014282445303134382, 0.03129988195254438, 0.041353257613316666, 0.0506407292109103, 0.037343434674004396, 0.02666191862625701, 0.03100391728953729, 0.05033339005744746, 0.02155927317817846, 0.028619231137957786, 0.012032825240655052, 0.021005847431238622, 0.028791832662517988, 0.03499643621785987, 0.01910863834763727, 0.05369321037564547, 0.04602531376745432, 0.04632882248129576, 0.019372645652882995, 0.03591948789694617, 0.09117680466583661, 0.03620042383009869, 0.05869216390795285, 0.01676427331873246, 0.07193365660045417, 0.1045939000323415, 0.03710212080829567, 0.042348379013879646, 0.00539424340991724, 0.0714554645181183, 0.008863994472419784, 0.06686407742240737, 0.042372587392286915, 0.03677432710725454, 0.021974308972036647, 0.03652183984917018, 0.03028129144842106, 0.0359223913701792, 0.05899632379652993, 0.04127630408132269, 0.0025830799413304175, 0.06758247637340138, 0.08109862690851574, 0.02403707157129482, 0.0266592143358843, 0.014479555895612126, 0.024035175503682227, 0.04975436165207817, 0.061708133322216814, 0.015330136614671398, 0.02896263771089575, 0.02808500738484004, 0.030230101453320637, 0.02224496592046513, 0.05546075141718311, 0.055693393167588985, 0.040579658196938616, 0.00231532646613496, 0.017982515912022323, 0.02309550163185885, 0.09869205825511487, 0.058642437140787804, 0.008005491446613545, 0.006786549319287823, 0.030691384059947827, 0.04757402945430048, 0.055477042276892936, 0.0356026569141015, 0.06490602563585966, 0.022558527623092937, 0.02554376350505458, 0.054306394811118805, 0.028976524969743147, 0.04205579088339883, 0.060626164364117774, 0.005534387704345488, 0.00833843325850584, 0.04728080547084251, 0.022882492799732475, 0.0399465937798302, 0.10392084582558564, 0.09333855157057125, 0.030602841532879302, 0.06939463437564912, 0.04341352468116149, 0.05493037725588488, 0.034292152436870726, 0.042826111443460955, 0.035720094362454075, 0.03771394160726378, 0.05435889481656975, 0.07697080727666616, 0.03157891607242486, 0.033953629674450043, 0.03539936399207481, 0.04861913043104353, 0.05241439129496294, 0.02899054054831786, 0.04746308077066656, 0.16831317886469827, 0.1175129539783924, 0.1488323290381701, 0.21043077772182806, 0.14020412589513487, 0.16945918511238792, 0.08932520079636767, 0.12241656786852306, 0.13648757290455604, 0.11067134448357167, 0.14812919821950699, 0.15473803955941431, 0.1131978718143317, 0.13527238891730387, 0.20295829482136235, 0.11779154951293623, 0.16355512934106012, 0.10789997545221161, 0.2497104191852193, 0.16792046687295362, 0.1505286315636289, 0.17628778643425436, 0.09334744585137214, 0.11175464643465896, 0.09490668758629792, 0.1953170121076607, 0.10333010010541448, 0.11490715953010706, 0.13448603030654693, 0.08044837913926571, 0.1323212803371491, 0.21582825019234614, 0.17412585566841787, 0.11513183013566079, 0.13672806322574615, 0.11080544817471698, 0.1901037531394151, 0.21784391945167897, 0.13315882894300646, 0.2362235791740879, 0.21002780015189804, 0.17495139201562251, 0.1625399402673206, 0.09055336231305715, 0.1615806449685366, 0.15606648198539214, 0.13791678653609368, 0.2986638818777377, 0.3012648729547378, 0.1758972041669392, 0.17788222990930083, 0.13598645947152568, 0.16707947087143699, 0.11848423089231215, 0.16927494096659845, 0.24338192006032316, 0.14499847266462543, 0.12019306661621218, 0.28363412546534694, 0.2794035427993344, 0.1379825628452724, 0.16485482814811891, 0.2553065535762618, 0.1322225775689848, 0.07877034014992176, 0.14486842157859958, 0.10096079699935452, 0.24960186452634875, 0.16018887771473778, 0.11282132427778938, 0.1718838840362526, 0.12102162134983849, 0.09890611088203807, 0.07030101598150308, 0.08676688081674999, 0.22160570227330734, 0.2310893345143526, 0.13897780298946366, 0.18177852244867435, 0.18280305779509007, 0.1404657142777597, 0.12082764022653142, 0.06594510899195749, 0.11555619688043672, 0.16820298477766976, 0.10403429578629234, 0.0685251092598323, 0.15072988286133737, 0.18139639779204325, 0.15079141504341556, 0.09404747401394191, 0.1531827278555401, 0.1054218648782661, 0.11954791333165862, 0.12026322494831779, 0.23248064211539685, 0.24853275818449838, 0.15667173741084917, 0.14436427443738908, 0.2508359095982967, 0.1608878563368513, 0.13753476913177198, 0.1696972545957373, 0.18172146422007393, 0.09663442269928994, 0.1304110094544388, 0.18981856924872245, 0.14512642466973874, 0.1322688952448868, 0.16539643698882672, 0.10043227294039342, 0.14601815101360122, 0.13093348141879807, 0.07766801623567458, 0.2393062710161171, 0.08554087966800698, 0.15581296816948922, 0.10805189068759642, 0.15052686956140304, 0.17532919593636068, 0.11230180175193857, 0.12221327111605676, 0.11941528819020718, 0.12578562337664828, 0.12393899141780793, 0.24482879967939472, 0.1284995128310496, 0.0836472635367705, 0.11137059123645868, 0.13481210797063767, 0.08899186827963398, 0.14407259412109852, 0.18983186853508796, 0.09289356173887368, 0.04516757108391293, 0.08295733241304275, 0.11199346668417416, 0.15011279903832944, 0.21219124777182458, 0.1408900810225356, 0.1278433125586279, 0.10245257703166816, 0.17514305189251902, 0.19227371250669803, 0.10512824635952712, 0.1331267451807376, 0.1293015456007373, 0.16332193217690916, 0.08420593315555204, 0.14251959600275563, 0.16701447597194105, 0.16703062510538488, 0.12847473754757835, 0.08442804502743868, 0.18823419216900103, 0.1311894007507832, 0.13771599489113978, 0.18237168900668624, 0.17550349626089298, 0.10158449216114898, 0.12234470882122556, 0.2389812199098449, 0.1476715832588173, 0.24209826313439878, 0.18669905922105237, 0.2645609876321208, 0.1471806128299044, 0.14221371241634892, 0.17171390444761322, 0.13841840558715407, 0.1665635259761926, 0.09154216731868445, 0.10594796043850722, 0.10283419607026924, 0.10817471756449631, 0.1105782111746169], [0.020040628357580113, 0.021612232836383968, 0.01830831203880089, 0.05203481388068007, 0.02224718182978611, 0.033967254548183376, 0.08211186245804833, 0.037260402234331254, 0.013000529312017946, 0.010084926991933777, 0.047121302134567694, 0.027571973623707894, 0.04625744989983017, 0.09885956337975879, 0.07457023246153709, 0.029826013055900415, 0.04522471358218501, 0.015784191181733003, 0.06420525053756372, 0.0437594095485345, 0.06012233131895623, 0.024247805122286085, 0.018568450600029002, 0.02992755609504398, 0.03064219929998921, 0.026272270986209476, 0.011652468331909228, 0.022047646569028016, 0.06613386539562095, 0.047752225335927746, 0.01931532503916852, 0.07971185454798323, 0.02729205084183524, 0.01618584820760354, 0.052568524354888554, 0.017421959801727248, 0.021642761440166546, 0.03950137795219499, 0.05547172562669843, 0.039430510988759424, 0.03582278844870387, 0.060736461873016054, 0.006150002553758602, 0.03194654634552858, 0.017770428300624894, 0.03322821335806962, 0.037950593827953266, 0.09135088282487086, 0.05332086483136781, 0.06671189405624905, 0.01739902121405448, 0.024848345276569168, 0.07960696178939074, 0.0787264816162567, 0.0503657725940068, 0.043308287183003086, 0.04512349421518945, 0.037076598589098266, 0.03060264618045861, 0.00654885713424113, 0.05646416188908681, 0.016983498954364372, 0.01793984098420028, 0.07326992078413887, 0.031232002732013504, 0.012794849068497219, 0.04483753657569328, 0.043311317060743613, 0.054926309329006946, 0.04757282669625936, 0.054384631540385954, 0.023541962352371024, 0.011992417933088879, 0.02062917923584821, 0.049375186433955554, 0.07668067445798267, 0.014341183179508776, 0.006880066151009693, 0.07132929749786854, 0.03253404959856022, 0.03682802604030698, 0.03605063831914337, 0.08333060109326917, 0.06183949441859319, 0.03361647054853459, 0.06056269397959114, 0.01976541127078235, 0.025376855928991592, 0.023449397863700025, 0.030538641449604786, 0.0057934867800213405, 0.018295949294922814, 0.04986320742435994, 0.06632871219828244, 0.04875780000621754, 0.034022527791920214, 0.03610133035709301, 0.03499942013032494, 0.03857780533332018, 0.05421530695692186, 0.06973092399177051, 0.06869436872582282, 0.019774420464771892, 0.011479290326186007, 0.05909357865851733, 0.028670513063609123, 0.07597423413948667, 0.027239378466601336, 0.028061088204624194, 0.0813491989467894, 0.040036957680938706, 0.00958682332683595, 0.07269160867097878, 0.019406809343866283, 0.015041429677136965, 0.04913586056641033, 0.05888420682881148, 0.061728760239578066, 0.11060654110605679, 0.060017093820797826, 0.03478710269255023, 0.01792404999686105, 0.038732083949951396, 0.06915032127571684, 0.05810671185533847, 0.009774520613944099, 0.1252436774572538, 0.055688199091462366, 0.0581228954627389, 0.02538474471939187, 0.05791885560498603, 0.00807613624455107, 0.07871757201369732, 0.03444633529251141, 0.038437680191090035, 0.010690197739149294, 0.004125177107315752, 0.05331391258345497, 0.049436331741632, 0.03348607472294281, 0.059668022027659806, 0.027103055035695437, 0.04529474550978311, 0.015886221644318393, 0.0415722553377911, 0.051236810733474074, 0.0807852050169341, 0.053399204982504736, 0.03258741911380522, 0.029632817172715743, 0.011411995247697398, 0.031060326258621873, 0.03087876916622683, 0.03929950229282822, 0.03348029075911449, 0.03223668874031113, 0.04221437491416451, 0.020408634013766726, 0.05215795485362892, 0.035953348983199365, 0.021834476858437545, 0.05202497348129269, 0.03320793884115354, 0.07305858010846762, 0.03645468075128813, 0.028712998384669907, 0.10057319481406482, 0.0513253168713662, 0.029160816996027867, 0.02757846813408598, 0.046963595274475314, 0.02759114497401301, 0.03714563843283442, 0.02852022193462378, 0.05549457036860048, 0.03148178186928553, 0.016566894595481215, 0.04731156007056275, 0.060357692681493304, 0.021522987423644915, 0.0410608418526188, 0.035863483039241646, 0.05640680871663555, 0.051460722911982774, 0.028169007010517583, 0.025912215407457084, 0.04728455930167148, 0.05454276740971593, 0.04796622433669625, 0.06382313354181186, 0.021469280829713232, 0.06523580350462468, 0.04604037122560605, 0.050693976152087414, 0.02681766047082361, 0.03562956192200223, 0.05791502133492501, 0.03701774388431542, 0.021204076512085817, 0.018155655613349333, 0.04267665535031308, 0.031081694366049864, 0.07020867940398955, 0.07155586034059525, 0.05016432977431724, 0.026826171707662366, 0.01981172703146454, 0.010770893610653379, 0.04295418985308178, 0.02453429136245001, 0.031138720035913493, 0.043646966993448236, 0.04900348823397391, 0.035608226373311014, 0.04588954000463409, 0.06287808747841947, 0.040072695682606393, 0.0983567032662611, 0.013346396942412662, 0.02982225922507144, 0.029613073171687224, 0.007737235226217778, 0.05681377377421145, 0.034868855765389825, 0.05194193338074031, 0.06537191434613158, 0.015939975161135437, 0.010214594076387584, 0.0666327418519124, 0.05502331521241896, 0.04548748174021321, 0.06515993781748318, 0.014998179225761805, 0.05385274052499764, 0.021924566883113117, 0.08107938277985781, 0.07169118211154016, 0.028981862687355572, 0.03655551707432155, 0.10621178579787094, 0.031199901732766343, 0.03216024848722643, 0.03959288715475029, 0.06685713666581339, 0.03986215173837639, 0.03435673364888757, 0.03289863467216492, 0.04915982762712145, 0.025928743754423438, 0.04512278175341987, 0.06462022121394835, 0.06352620552324, 0.045167368070612994, 0.025551564195343567, 0.08009269217690153, 0.07355333501172644, 0.0432584991288041, 0.06171228551876642, 0.08516483774949467, 0.031106465819081476, 0.01856284666686289, 0.03807227923384598, 0.029391474578709855, 0.03713032433522805, 0.019994031059585755, 0.03135695741812308, 0.008980605503424041, 0.0037443837678555643, 0.08407041220174682, 0.05370744045883898, 0.027056227911323793, 0.07191635067424468, 0.041950725755023385, 0.01197092533637319, 0.04875408447978478, 0.02729145137803449, 0.1280001077740904, 0.04372808038287106, 0.05360475020302881, 0.07906037337717511, 0.023176990404364564, 0.057363123933394114, 0.08194083332895272, 0.08163762338940175, 0.039334815115697926, 0.0614053983571789, 0.045227693664210464, 0.02851244614219233, 0.014191282755364815, 0.04321050755078754, 0.04440656232257043, 0.03639746547466324, 0.03339790566373737, 0.04228638334860725, 0.06772377363015568, 0.031108137805976217, 0.014109440624804027, 0.010670460441390113, 0.03974885499525455, 0.057034878240477656, 0.04355220191721474, 0.01891396582997855, 0.01625604292888555, 0.03671886234153663, 0.028739566313883955, 0.005694915204414077, 0.027648046154588945, 0.032075927104620684, 0.08484091279247115, 0.09274094170259853, 0.01998191729428307, 0.053301704972381556, 0.034110348281120105, 0.07402962719601008, 0.056950612399246425, 0.030832759840714357, 0.03559308847592723, 0.026480371109961022, 0.03467848674664575, 0.0210454139573079, 0.026646148706335696, 0.01640605635099834, 0.057036540651273344, 0.03074652898395735, 0.05196986877689919, 0.02287949931116835, 0.022820759519574144, 0.024478368859197346, 0.04334285307014662, 0.04491611038364711, 0.05647259651713314, 0.04372138860485247, 0.0201529138646419, 0.015944962393522503, 0.04425064044734163, 0.019196734628489903, 0.030904860205708012, 0.03417190727627566, 0.045906619934905926, 0.06282176086378675, 0.08293021290052323, 0.023642769947107282, 0.041791444584246606, 0.01712167631804703, 0.03340088574576282, 0.05649810341457206, 0.01351181735029264, 0.06223578021050461, 0.022035507905867793, 0.03237883252422175, 0.028772709192708138, 0.01459929831100688, 0.12991879796308856, 0.146999524966363, 0.12368953786790372, 0.06506195517196771, 0.10521233983097539, 0.11069791241278572, 0.12344270433870055, 0.13008323107515612, 0.11859096226192291, 0.1362635075084625, 0.17953227604589156, 0.10966347154950905, 0.15045873370141755, 0.1989939123872788, 0.21954025262065474, 0.15091867756939706, 0.18383647976142747, 0.14683516846308786, 0.20424982713114834, 0.11380803020250414, 0.18879015749740988, 0.09481545417539536, 0.1131864341216222, 0.1310421586517365, 0.10036848845981783, 0.11238249379300302, 0.1898785692549521, 0.07758926239705856, 0.15823621152629777, 0.0723337383580304, 0.12003705281043246, 0.2402476551792314, 0.16764703477101942, 0.10750216131489124, 0.1757415351007254, 0.1255606233532871, 0.13235679617331875, 0.11667692988750436, 0.0997817034142152, 0.15100950495369975, 0.10161793955992307, 0.24579552603104424, 0.115147044641837, 0.13516915090862783, 0.09096845173307004, 0.11121877559250402, 0.132784012765173, 0.2197679339517509, 0.10022637148898456, 0.198033330060782, 0.1023332971418577, 0.14597235427748773, 0.1724378268925413, 0.10473680607373677, 0.1650754614703117, 0.19436966778049547, 0.14295640401542187, 0.12292793921885953, 0.0917728363926853, 0.1569388416265288, 0.3632037557901875, 0.11248895703184028, 0.12548442058745893, 0.23156925795539735, 0.24633822271660452, 0.1187137355126681, 0.10975059106825821, 0.07242330169725804, 0.1690005282721212, 0.23565672007539581, 0.21833996138265058, 0.14634502540913322, 0.09480883517572958, 0.11738625069659565, 0.24191562777325032, 0.2174999919389525, 0.10091462488015814, 0.1530613488848171, 0.2654363196944037, 0.11897216761304487, 0.14488204262189328, 0.19482124596834186, 0.15939367844933466, 0.1963966291758322, 0.11669020619123213, 0.122391355914935, 0.11821659041508553, 0.10634607335011806, 0.15229239579169981, 0.086719237808739, 0.1755920560249398, 0.1340528229071248, 0.14766398366660843, 0.1997731463803399, 0.19624005612586776, 0.1326850954923899, 0.144895663665187, 0.11452567838733235, 0.22954439564097315, 0.20013504631577, 0.20793467940342045, 0.11630839563064999, 0.1031508278702536, 0.10221343502522477, 0.09993475245972795, 0.12473904001977175, 0.25860207996541457, 0.14668611839653986, 0.13975728213066055, 0.11989550274466315, 0.16634952697542407, 0.11376498372203882, 0.10679894622655646, 0.08915401078880796, 0.12330741321127262, 0.11832781872081181, 0.11899242297776284, 0.2204669278956229, 0.20375758499628116, 0.10139596558386281, 0.12432576622813941, 0.08966216456986244, 0.15134246208735053, 0.17503644309697614, 0.17640502853018625, 0.06656269843299543, 0.19976416782986736, 0.1893010921776295, 0.0884178309370914, 0.06538334437796185, 0.18584142378982038, 0.19294396283165102, 0.1299090992899672, 0.13756987128046252, 0.2650142665351591, 0.16169675325434055, 0.11343464660908907, 0.1377613472962572, 0.18744323703069843, 0.13225141311845473, 0.28605983562527165, 0.101965919677769, 0.10909808333963157, 0.15314541937362763, 0.15426401499538653, 0.15862644139316776, 0.18021070818987586, 0.12579832511443284, 0.19679775281298548, 0.1432105153799057, 0.08871644434909667, 0.06703862289507544, 0.10160581238808171, 0.1364142429684439, 0.12721976295353907, 0.21099665622797706, 0.13967869683138787, 0.11042964374346119, 0.08355292746977461, 0.17701731664278816, 0.16209902602338022, 0.14173832421581592, 0.09508713959686219, 0.18606312963510716, 0.1499020176068429, 0.09779209646606639, 0.31172859212083204, 0.17542173935761377, 0.10309001581082422, 0.15186171648242783, 0.1552748833332331, 0.13685034618021982, 0.11091862234377092, 0.15941814729763618, 0.12455774531249078, 0.10035328161452087], [0.08991986888671115, 0.03511664307405872, 0.06285232777196555, 0.03052223376148651, 0.011272508831274126, 0.08034785308184163, 0.0744980363355529, 0.05058498482310003, 0.04288914515787075, 0.0581357465876687, 0.051551201726279916, 0.032652590213523756, 0.04788818679028942, 0.06731757849094368, 0.04437398060315079, 0.022226436168796593, 0.010274254131100832, 0.029181183443494865, 0.054843165806584784, 0.024930824217717015, 0.08296334620324836, 0.01856724401154826, 0.01015106336243691, 0.02027672133408487, 0.02702595211655623, 0.04299588035792113, 0.03672358527358982, 0.08805468227834472, 0.024465621156137318, 0.03255839204235423, 0.09455573504730579, 0.04893814859491202, 0.07136115909463937, 0.03002722030355325, 0.024236823251891523, 0.0020278672943071976, 0.03140718405765872, 0.040041347364744836, 0.01435031686278601, 0.057445581807124044, 0.048786244850846074, 0.04466603247208461, 0.08658419182944684, 0.031211820145648335, 0.016491697320053657, 0.08725795083709302, 0.04968309249248236, 0.04906694712718168, 0.034744251564505606, 0.04096338014689185, 0.059667420648639245, 0.09956366713008574, 0.021465032872173096, 0.06454104602697396, 0.04244620844181027, 0.09374187388006719, 0.09896079423807322, 0.04071839288958619, 0.03691550178994094, 0.053604742542149565, 0.05429817468769128, 0.019022677536873568, 0.020572458085934484, 0.043956022183861465, 0.1049530114077272, 0.03913628343012064, 0.049713038869442484, 0.012820024632908886, 0.06893760164178188, 0.021726594441720558, 0.05141390727892999, 0.04789181038617127, 0.016463940039337162, 0.04194321426292581, 0.07382233912545828, 0.020585688424386808, 0.03306041328957485, 0.021733975698871, 0.05156912818370808, 0.04107738935178326, 0.017009513385053125, 0.025951967709848, 0.006386001684492635, 0.06303600501269102, 0.04746623322247498, 0.07440787544774433, 0.025240204995498065, 0.033895943253751726, 0.012697801050249369, 0.052553704383993344, 0.020305777133833018, 0.04450562515205914, 0.028398754863789486, 0.021225277995390278, 0.005642857135934455, 0.03172699895296847, 0.0057962585818923775, 0.10681561629978881, 0.019486285220350952, 0.02646914026099107, 0.04522528814812822, 0.02166834494639789, 0.027952186890967914, 0.04296030706515716, 0.009650331058148897, 0.00741065338051187, 0.020847962455703847, 0.00988572210659303, 0.031021631157566464, 0.0403934873400196, 0.00876114525336532, 0.04255541044497683, 0.022694266911956574, 0.01454674850984086, 0.042821426815803976, 0.012644467924180771, 0.03860451881923983, 0.06198616578213631, 0.080757373042645, 0.03543383411822781, 0.05274000164541987, 0.03767985452507292, 0.06014513392602244, 0.06599795373697435, 0.04448170022618386, 0.064888367309205, 0.08100175509049047, 0.011586276420031585, 0.07985617019115918, 0.05959994362426862, 0.07700928021222353, 0.03573689084019392, 0.020808189085895018, 0.01899449316213929, 0.031101779276204687, 0.03925734830479469, 0.018020349164162914, 0.06482667424866269, 0.04936415859828553, 0.08336591008569925, 0.04436718923370204, 0.079358879536871, 0.006399412053607164, 0.04513328864930138, 0.03657398362373633, 0.04694557688649624, 0.008634666052286424, 0.027903729914537365, 0.028373648247291005, 0.03281337674707174, 0.02708990322125535, 0.015739159575933893, 0.004551945058929344, 0.06382681459428803, 0.041839681310398925, 0.03763339129246531, 0.09188522149117724, 0.05845093048147618, 0.027678057649022633, 0.025333614096105583, 0.05830982857714257, 0.029835196534892725, 0.03753383433626544, 0.029362928227431355, 0.05442287464956603, 0.04598410589800728, 0.06000408947828317, 0.05242797020342081, 0.003027028132853429, 0.038826331916836, 0.0604492363580052, 0.055446414081680204, 0.05588149456607719, 0.029229485287120747, 0.08197464844993047, 0.023796121597350128, 0.015675578108658234, 0.010392070792975926, 0.03766688848695448, 0.019927708912760984, 0.003369451719223552, 0.027969050401401137, 0.06711180727448195, 0.07636126941971241, 0.025291345194883408, 0.03692394024842689, 0.028671526214888984, 0.013871061833455198, 0.02734055569876106, 0.05279185813701442, 0.04949861852031562, 0.036669403705145084, 0.010396089881748683, 0.029176818657546278, 0.002603221589872133, 0.04844787530601025, 0.024981916536607092, 0.04075575882809297, 0.06135247317292999, 0.04694432433274004, 0.05460133100108755, 0.03672063200464172, 0.04885241186486618, 0.03200816279727846, 0.04416301148012281, 0.058142691174702305, 0.02935111706685876, 0.03742268263933159, 0.0672498409966788, 0.03641777829597554, 0.03936275817273606, 0.07876782738153013, 0.015118943410925569, 0.059776105542456916, 0.04643975584317119, 0.03979713002580308, 0.019256663771586555, 0.08276584107548961, 0.10022361357245715, 0.0153430049765795, 0.03268528684613205, 0.08838932480542891, 0.050505499370516314, 0.0497629763107867, 0.038195489154708, 0.021499476185248747, 0.03987122604983949, 0.10448466355521834, 0.009865736787868364, 0.10065262281005422, 0.02154996329467864, 0.02747372476263873, 0.0475311323609804, 0.02031045218539094, 0.01391450572203124, 0.035386685236927964, 0.03495352763322092, 0.02744009541798263, 0.03091738765848981, 0.04078015489804168, 0.0033645683875112168, 0.06925212669997446, 0.02360046082626908, 0.015899107243204792, 0.15491411720793094, 0.015385239403845083, 0.03684372701231511, 0.08994413855215234, 0.03666793281633047, 0.019601133291519458, 0.026999259698054483, 0.05394692337440868, 0.06005169035145833, 0.04922268897174828, 0.03617716157027791, 0.02344812424252591, 0.04052595926388618, 0.012102354423052842, 0.049388309520098476, 0.04122598359601633, 0.009264214125822389, 0.01578431088297117, 0.03243767190724611, 0.037864179110094424, 0.03467611953495972, 0.10729321083354373, 0.016576005296120723, 0.04223677149463085, 0.02236977121942947, 0.04595829639583827, 0.024773121188064257, 0.07442699700233436, 0.04144316952254984, 0.023709888825373306, 0.027617965712242072, 0.028397931319270885, 0.04229248906936377, 0.07511863650213327, 0.049118412913934845, 0.020041810048203317, 0.05332888960237465, 0.045842050214207945, 0.029863013187423352, 0.03740959019670564, 0.052716379324274684, 0.05818122922773323, 0.03797754097068983, 0.055918109738418174, 0.06186681694441265, 0.06848499689611696, 0.04448618184054091, 0.023644901586756594, 0.06212253326309785, 0.06546536941201457, 0.047828596641099265, 0.024364771426565224, 0.05224208279903378, 0.021010736987415343, 0.01651199865004709, 0.031088139080712875, 0.0035693338741698576, 0.04540410456097415, 0.0356994099884985, 0.04920230337208317, 0.039680332260867285, 0.07750873123445819, 0.07343993101629519, 0.02146283803027003, 0.027909002514676224, 0.062339171436765504, 0.028984988326086637, 0.037610738072544336, 0.05757253023705656, 0.025227936097390713, 0.019220255442985126, 0.09227040283862623, 0.04568319422222915, 0.040653014946128094, 0.006448923358543506, 0.015692141887191084, 0.03938789734797132, 0.0702816033135018, 0.048619138091922774, 0.03837858799905066, 0.04856844605397313, 0.04973682589949139, 0.049690527375787504, 0.03273567244891198, 0.056187833974798845, 0.04850083496421576, 0.021024200982684572, 0.07346558730087935, 0.05033090027169355, 0.04698337183424062, 0.032117429917918584, 0.03252213693133766, 0.020455399851104426, 0.017260863002569928, 0.023006690974016825, 0.054469540895473574, 0.020702777302733833, 0.045535492470427874, 0.04420262588668735, 0.06943131466546366, 0.0034379138847843056, 0.01912903543862124, 0.0758841268778328, 0.07470897098462428, 0.039854636415839195, 0.012857312047403428, 0.017382757167422005, 0.027629368930994987, 0.16933818918562707, 0.12134085018788615, 0.1673102931630227, 0.07770516383912295, 0.11824855160328651, 0.1794404680690458, 0.2262686189985083, 0.1831582161567865, 0.14669243096103593, 0.11115547374732072, 0.12267764297223861, 0.061964424206845226, 0.13902713905178732, 0.17614777620521285, 0.16757307664280938, 0.13677202135084138, 0.22302422131742203, 0.15136670110927475, 0.1287625108154551, 0.1131850551633585, 0.18974150080353985, 0.08713593601339287, 0.11671646002439723, 0.13398370645459623, 0.07843732172923704, 0.08411124468811097, 0.12562171120436924, 0.16077096664136456, 0.1033967191113099, 0.16223059396349615, 0.22212405268463398, 0.1484269765956748, 0.16009172244418055, 0.13086404320934128, 0.12097808457310162, 0.23794582143666285, 0.11038009317651873, 0.11313668437181942, 0.10727608876843607, 0.12169475982626601, 0.13694311942785017, 0.22362618256480465, 0.21689994591138057, 0.07802161177800548, 0.12568511264098267, 0.24301713963429777, 0.12991721982196455, 0.20386902014574698, 0.10970690873481574, 0.11146318062298721, 0.09872336826858022, 0.18764392142334294, 0.1671274892625309, 0.19481956057490843, 0.17113003819700212, 0.1798745488087016, 0.13076224544596288, 0.18798708284814514, 0.11516933780043356, 0.1255261877010907, 0.13893876314884232, 0.1851088751948649, 0.13423210280316492, 0.17067605449307352, 0.25543982223156964, 0.15046700745099975, 0.16726821961422123, 0.08309472262138322, 0.3071215232053111, 0.07524393018214934, 0.08146325411695628, 0.17375047258552045, 0.1787304118155472, 0.21519255043277818, 0.13614926847719377, 0.1250721886754036, 0.11472244040980456, 0.184431086564737, 0.08217344826628124, 0.16850398072311956, 0.1334128330551809, 0.1103434894954966, 0.13519752680534317, 0.12160518882615913, 0.12917155580174539, 0.15730590499456854, 0.10851103782413468, 0.1181538018488115, 0.11668216226802719, 0.14895159360622207, 0.0751819460081958, 0.14703554642056266, 0.08385897959552466, 0.17857659668211015, 0.08136408403515816, 0.13836418188387348, 0.16351314772280956, 0.3382107807743934, 0.080064500141288, 0.12248527829445179, 0.1825889208984952, 0.168927259623043, 0.14550896301384897, 0.16644700400290952, 0.13118570820698816, 0.1680167488032772, 0.07471320745084556, 0.09040712378919126, 0.20246383103151477, 0.1562096025314062, 0.0846145031673293, 0.14266008120631019, 0.2436663685066085, 0.19825198687613013, 0.1240774924536386, 0.14587332975239525, 0.19115729257464412, 0.15550170664585408, 0.17246267878480498, 0.19811061301058341, 0.10680639260118047, 0.10615897935725029, 0.22235386374015964, 0.16745226457715037, 0.14622660353779793, 0.1337964592441436, 0.19787087345555907, 0.27327946657615326, 0.19182962665875114, 0.17240945099582597, 0.23528449327474643, 0.1382127569447602, 0.1655958803190339, 0.07633281691420464, 0.16072426592150044, 0.0950966467480025, 0.12000853135701149, 0.1357046157241829, 0.1508694487593828, 0.30292777404669796, 0.13045034040847134, 0.17367531936014854, 0.14638153715960442, 0.13320952864183536, 0.07004947867244482, 0.13982650583549855, 0.14524955032092912, 0.08408328247887474, 0.16551804578592702, 0.20004291658199605, 0.1273442828847516, 0.19686743617057803, 0.19416670044583662, 0.14921045471583644, 0.10243691819449587, 0.14743896832148876, 0.27355614689088636, 0.18089977363424917, 0.10186766890148002, 0.0987224872674673, 0.13721455970118124, 0.17868645369045197, 0.11766134520932553, 0.14985205335242135, 0.23212716914713385, 0.1062583639436672, 0.12834726817785733, 0.12092079651812393, 0.03673866571437928, 0.11501901602793126, 0.18376950835508687, 0.15658189061908953, 0.15608427054699392, 0.09629253298044206, 0.16411720805110472, 0.13123066224638494], [0.015518866205257515, 0.018091279329852234, 0.009916252625595418, 0.05541494702019038, 0.03940536032220529, 0.03852950348969429, 0.043240419453791076, 0.030944985975962014, 0.10243951523255918, 0.06592201144104043, 0.020340343020976554, 0.004226117809828852, 0.009106389479711652, 0.053389559935538046, 0.05547445289970887, 0.041815335036165295, 0.06086438706505203, 0.04231895740714766, 0.04202192596670601, 0.049971903809496475, 0.028924354382099646, 0.03573506372049451, 0.0605673939290066, 0.033320327770085104, 0.0677465264415068, 0.06465117116608927, 0.09400175388662085, 0.04788495772968858, 0.071550015089733, 0.03631425683476752, 0.01791009379010047, 0.020819463984920614, 0.02956272587330351, 0.027421450753125454, 0.014128592822911039, 0.03327975958405483, 0.02649266107548629, 0.03594278846116316, 0.06158645174676373, 0.002806135777181255, 0.05950848038698878, 0.02908081634931507, 0.039458385097884366, 0.0530653247129052, 0.05145620682366914, 0.02874947374596471, 0.027847041323360418, 0.0763203909680728, 0.03197670531188769, 0.058256616109922055, 0.029041418362589135, 0.03594597921736779, 0.06409181972905513, 0.062437288147667726, 0.031801794032235785, 0.02356538740587571, 0.022505412832082763, 0.026067112640087164, 0.044177770163984074, 0.004767159745472694, 0.06368306585617604, 0.114651684529118, 0.04465073369623673, 0.03297775240254498, 0.06542459055180512, 0.009938396397046745, 0.02920061526369424, 0.03389909187512052, 0.025586296706610633, 0.03869736484522301, 0.05523578586777853, 0.034744439256047054, 0.03139856556851057, 0.025828572012664332, 0.06807707805907534, 0.02769449215021826, 0.02275789051406807, 0.0346646971640087, 0.08708798657021216, 0.04110035283731357, 0.02941284460135766, 0.057293777654488245, 0.026480212146716735, 0.01609052963284475, 0.02901346189901233, 0.1465142235880898, 0.04443015016975903, 0.11348805825916991, 0.0531917330508511, 0.05120657707354234, 0.047865659974875956, 0.025641778709306836, 0.023046810998611396, 0.01838882596442296, 0.031498672192796104, 0.017447280922844526, 0.04211768312680145, 0.021555283775312767, 0.029818536037759438, 0.019638809495635574, 0.06838290801932735, 0.010393376972886824, 0.044360746434258844, 0.05160596169110748, 0.05162266623829642, 0.019858533088418267, 0.052394725817946665, 0.05239192959702304, 0.01374577581431837, 0.04396737177645968, 0.0724637434787808, 0.040097750588169986, 0.07380068181983887, 0.026845613103960792, 0.0046473866865609685, 0.048091495034074595, 0.02612394104231029, 0.045172202085415204, 0.009964068003389384, 0.053571417717443365, 0.046079322966116096, 0.032586541943131916, 0.007052111783019838, 0.030716588352656657, 0.0792164714526265, 0.05940408175510745, 0.024966276851632906, 0.00693246704383543, 0.017093794548042843, 0.03416344583515198, 0.027045475867306514, 0.020802357241571433, 0.008673816975656777, 0.015256886160181416, 0.04963016347779382, 0.05251630780196959, 0.028167453767251105, 0.034289559229247035, 0.024463399501156904, 0.008589976313223523, 0.044351603174882556, 0.029952067078181335, 0.037279431858370383, 0.011346353961515331, 0.026421928177437475, 0.059158428001307675, 0.0616009078258949, 0.05896210647939194, 0.010090325996580144, 0.06659174848708414, 0.07611907072245114, 0.0416298306757404, 0.03455650256646257, 0.07118549513360185, 0.006494645879889328, 0.061100123810671994, 0.030952959036033963, 0.008334586539516046, 0.014407614493862757, 0.02717331870489063, 0.012561797461051856, 0.08263093299202381, 0.004992525097012761, 0.03533124728428741, 0.03359031630679965, 0.01855795519546636, 0.0412942573518282, 0.012999293995240043, 0.048125340798569304, 0.017543446024759643, 0.042149337879832716, 0.019667221781527324, 0.06245132670888017, 0.04672913023480966, 0.01609271298342895, 0.07335473437823596, 0.04351631452840182, 0.03796520695510892, 0.02165648973576965, 0.055505586712951624, 0.03526010069875948, 0.00693275528441694, 0.03068025088718822, 0.04605735922532697, 0.0108032914689712, 0.036222272657699166, 0.05152890473724373, 0.030381344446551897, 0.02430724013867157, 0.028268709523423065, 0.10663735530068798, 0.09411388617609778, 0.03772048782857676, 0.046885255123338396, 0.09288882731550163, 0.04624795807044833, 0.013584896392609565, 0.01671199356355975, 0.03756420972246317, 0.05776764134005193, 0.04494496891575475, 0.046512633787408, 0.07772587885659549, 0.04017630907436533, 0.03603262759204354, 0.01684712381252358, 0.008954750035979576, 0.05854458089977984, 0.028648511018423785, 0.059272046501357714, 0.0033639643750634166, 0.019765056955117374, 0.060840347225988106, 0.039016103386999144, 0.06382985979378705, 0.014159470954309068, 0.11481915901024496, 0.021758059587990566, 0.025964171490481785, 0.07746779915666388, 0.05517877360445358, 0.05501234100290364, 0.025518045933436484, 0.049547839669450644, 0.03013908254703687, 0.041752795448466655, 0.04872320347555703, 0.0070252297577568365, 0.07033552058161267, 0.004040676172852757, 0.02907224574066218, 0.010119238154842489, 0.06657954470645036, 0.02268575950555744, 0.07529318197480134, 0.04098693735056347, 0.007779661654269384, 0.032499261545918645, 0.029291092162771575, 0.018648935797353907, 0.008442482362771708, 0.056896323578492294, 0.038534433265487035, 0.03847971160505568, 0.007096621970225487, 0.06818277520998832, 0.02864171773375523, 0.0292135123538995, 0.03753652713531929, 0.015437917524738418, 0.0724687383720471, 0.059408153512425003, 0.04282683156610977, 0.0069915056097201046, 0.04307154686220231, 0.050624246829219406, 0.05359288733152132, 0.05798192379335242, 0.032959527170826355, 0.01926520182150266, 0.013321109337642068, 0.025849792648166902, 0.05442947449703371, 0.04709280366378446, 0.07818644325579367, 0.02036142193021313, 0.05460751716107611, 0.05112773513481502, 0.02520644158545521, 0.027631816581913063, 0.06433823190989994, 0.024057520373213678, 0.0032816894048254097, 0.07542099608408828, 0.04277527767924532, 0.0649042253292376, 0.037686025363303004, 0.09003903386333297, 0.021483003379656904, 0.0573219926727395, 0.03266950160445225, 0.018224570967797792, 0.10495931631134403, 0.004980587053127708, 0.042689540949199474, 0.028301423393009652, 0.05045483414564402, 0.015381294051035038, 0.0705793587070319, 0.011582999478935475, 0.04281340204479714, 0.011802054660004235, 0.06037813190731311, 0.03378544656199313, 0.0276142482705895, 0.022052179894319946, 0.026211585331287597, 0.04731621788514238, 0.05988230065052068, 0.020481939052021312, 0.0665821494053929, 0.04575160204342777, 0.0217804370162588, 0.029347604553725933, 0.01870709527734547, 0.0313070276376581, 0.021256183897475564, 0.028686955225683992, 0.04627015546805436, 0.030347851082502358, 0.006668778622688185, 0.04707634809517092, 0.0639149530099765, 0.0415510117196508, 0.030026423572111997, 0.006801453081049747, 0.02481291945573063, 0.0106425920779246, 0.05225839281094171, 0.03851329689965614, 0.010388479755830862, 0.016083753585154494, 0.01607424834923398, 0.04220954472980192, 0.04197363561439899, 0.06612887050235464, 0.07046467534476711, 0.022225606878618562, 0.005985261570106471, 0.0046758559502420895, 0.05353158880626002, 0.017737109221578125, 0.04332374300687544, 0.03128541629731415, 0.017459902221397046, 0.0351801747456193, 0.04824757012688825, 0.14329711395886638, 0.030387540182639516, 0.0411210831765446, 0.007387257055304344, 0.04008609456040206, 0.056230853642186815, 0.018936538610667474, 0.01558026719477869, 0.029288964353561885, 0.08159364994254806, 0.022259165360141667, 0.04519698502976568, 0.10208379762667803, 0.0707798439168161, 0.02920734151566942, 0.16607247893848728, 0.12411745159976906, 0.13495334394035802, 0.1563827077587766, 0.08905406695820632, 0.12186608006877285, 0.1944957198875566, 0.09794822518503475, 0.1527350260725906, 0.14561255342297016, 0.13884635762341563, 0.11404573962452913, 0.19490052074674638, 0.15128512806709737, 0.18687933503139406, 0.191305392692166, 0.08571403086065285, 0.10668692885026818, 0.2651064728777255, 0.1517089585503263, 0.15395563396234668, 0.07252988751016318, 0.11916306906289632, 0.1259587439257772, 0.28134389029395196, 0.08084953341993593, 0.21166362769661412, 0.11141344619494294, 0.0620884117069504, 0.09934121051863318, 0.09375901892781259, 0.12525284752970742, 0.12607695129249366, 0.15991728422382187, 0.07261301571082684, 0.10747689573514847, 0.13026433426045603, 0.14333325798713392, 0.20171856537701624, 0.12237936663892, 0.1727674592046007, 0.11514335975892122, 0.11981537760866266, 0.11981933062235195, 0.18591259335798604, 0.11456256552088646, 0.18217351738243334, 0.14950634851571054, 0.10461253895153923, 0.1202275941989595, 0.16810012981295588, 0.09740730582345879, 0.229529625465793, 0.11992276015300905, 0.14354618446480844, 0.08967819879011762, 0.1537175338354803, 0.11339876305071578, 0.1849529916240323, 0.13540147473254513, 0.13474547364298375, 0.23134045813593174, 0.12904118295879136, 0.16000659475403448, 0.1701239042825276, 0.10410190304561008, 0.06209976896042786, 0.16513204472439905, 0.07414330698309407, 0.21676080902257275, 0.12308493361718233, 0.14823476513547285, 0.160040655023148, 0.09509939700365068, 0.1540023346822108, 0.09491385816926919, 0.09123097474296248, 0.10622772042669597, 0.17998455903462826, 0.14746691520896651, 0.13262601479166938, 0.13910204712902347, 0.12749759240015862, 0.1053974879605155, 0.10288221446136314, 0.26287574741628866, 0.1712584651766285, 0.18987530572039468, 0.22075465519822415, 0.15423309568676258, 0.17715440041595892, 0.2098363088143449, 0.10614619334979404, 0.15496708452701569, 0.13925177135294484, 0.07923851180220805, 0.19173093921234532, 0.0829320515115415, 0.09013680966510888, 0.11836397807083784, 0.1340183489505322, 0.1848919957035011, 0.12176195339810465, 0.1291933893075874, 0.1418971189207608, 0.10223564391414966, 0.20424929086960134, 0.1548919159798853, 0.10786464347714379, 0.29555803885863674, 0.14176470828392815, 0.07357732122463566, 0.16081775929177963, 0.1008375870784925, 0.13781831359430669, 0.10602238588035108, 0.12434132547388155, 0.2822980681254018, 0.08652089764514277, 0.1542140047756895, 0.1156840339723614, 0.1323540995438253, 0.1666238783828674, 0.0701158908346007, 0.20831511866661812, 0.14699584774432645, 0.10799248822994771, 0.12391945617573878, 0.15354415281645714, 0.10979616563887366, 0.13845012162721929, 0.1211289196245132, 0.128837664040827, 0.10279727829319817, 0.10981075195295197, 0.21859511462671144, 0.1526510015490555, 0.14027371732217653, 0.09865298011009732, 0.13442244500883166, 0.16335557875854356, 0.17247781668218876, 0.22394147371092152, 0.07327162149933077, 0.06287526061397887, 0.13896750676776135, 0.16092879607552485, 0.18096084616357283, 0.08986189901348084, 0.10876259045495142, 0.22270588114136652, 0.07870736772254591, 0.11729884006443525, 0.17945128523053663, 0.1364085126307703, 0.16909745371630117, 0.14867966303661947, 0.11005841285711336, 0.15656492943244596, 0.12267892233907216, 0.11818511952315608, 0.16774794387240566, 0.21621255053868219, 0.083172932537573, 0.1100490972279541, 0.1438989679539396, 0.14264661338060133, 0.12277628445336897, 0.10274959698079095, 0.05527734230723112, 0.14351384023264532, 0.06615789757380564, 0.12271760977924832, 0.19794265589406415, 0.2516499852701541, 0.17854074376725382], [0.029765681716643518, 0.01104944509514157, 0.013071687388864738, 0.029542843976448623, 0.051615058985208316, 0.0015859768867695465, 0.03914953675121069, 0.02481303436891927, 0.029408251904251597, 0.053175315786633766, 0.016968663661710678, 0.029338382770337408, 0.01664343443999608, 0.04970972553916997, 0.050472189867568594, 0.03165421485450239, 0.07998132597534888, 0.04778829275540287, 0.0422614433562323, 0.0500235419660326, 0.0972020785294233, 0.036470561753958464, 0.015452708767336464, 0.04450455645940477, 0.037216310043849295, 0.029577386880954428, 0.03826462475943469, 0.04377395372777697, 0.051876582250359564, 0.04049493270295282, 0.00895995177298544, 0.026846438563699206, 0.04156761284496996, 0.013612081022602657, 0.022035151674983003, 0.0311808874304857, 0.01907214000370474, 0.05262198197024484, 0.009425086844261856, 0.032097795084419276, 0.0417664586265962, 0.04584293121532087, 0.026070485342173808, 0.017145490161173286, 0.029000237306219437, 0.025922140076516137, 0.013517955629785937, 0.017103098685883226, 0.025665833870129242, 0.09220217504808981, 0.030692452752602198, 0.048723628654355006, 0.09237865106232705, 0.02771110093641666, 0.03747218724099859, 0.0213403252494191, 0.028824544616884766, 0.05858827472454118, 0.018627546622508, 0.056872877457569686, 0.05489754655788984, 0.020546843936186165, 0.04311306499725869, 0.05841655994675333, 0.0641034642655042, 0.03642985567210182, 0.00933215750621692, 0.04594952085866563, 0.09371516805502678, 0.01429432732683997, 0.025116477965287147, 0.03519639282697632, 0.07665119539465635, 0.035352521545944676, 0.06614092872628281, 0.04696494358922205, 0.04612395141814505, 0.02074849359961527, 0.019444556411115393, 0.033303607901137684, 0.08714139055941375, 0.048334069114418766, 0.052902232254705125, 0.027616749547662276, 0.04197826661590127, 0.05393049844931211, 0.03650852524104618, 0.02803717285484797, 0.015205570718183395, 0.06745345184519407, 0.03295553202230123, 0.06503144188994361, 0.03828719754012362, 0.013962522197905329, 0.045528984553511107, 0.06739503764096769, 0.025801893000701265, 0.05787429227043064, 0.03639340903910418, 0.06516852566311437, 0.02271943673070881, 0.019247815456061114, 0.023119049259431423, 0.02640833586244093, 0.07545448944813783, 0.04018869288566132, 0.02614822219907036, 0.010014612569413599, 0.03557582468455357, 0.06914592393103146, 0.030499678217775883, 0.018529950851394285, 0.03558128689145369, 0.04379871368948971, 0.0334829950494872, 0.025255798715196794, 0.0392123214870451, 0.04497818265771193, 0.027296183886186733, 0.04768449167210249, 0.02284330931762534, 0.04180761670032817, 0.006793467093244076, 0.059786585625261075, 0.017205605080591577, 0.016152870037683075, 0.013668715030014997, 0.03607765440979312, 0.034969485244683685, 0.03553406523180104, 0.030469728010376135, 0.024049893967927467, 0.04718263896422521, 0.03570429762945541, 0.03940220020951764, 0.029969441952304016, 0.02666473016893912, 0.017976212923625307, 0.07706345795022865, 0.006289315642789007, 0.04512236423550114, 0.033029202867539666, 0.016695323490327405, 0.05424091727623055, 0.07276057190592251, 0.10045332503655266, 0.05481239971554568, 0.038548851040221994, 0.025346687386533426, 0.015319998398603452, 0.007144621687926233, 0.04625880970589576, 0.046211090089092334, 0.031744295303078915, 0.026857895408606818, 0.08198747276178292, 0.11717275731385716, 0.032812683437500274, 0.07555559773238436, 0.05097588501690377, 0.04035959177980981, 0.00571295082937145, 0.03969743517377684, 0.08180408663446866, 0.09250425117751283, 0.0349906254409542, 0.058507804848974755, 0.036872600866181236, 0.05148000917547653, 0.03266744848881518, 0.017889715851314606, 0.03201608223119571, 0.08736734053180104, 0.04621058447106231, 0.031666453109092774, 0.03041199179396274, 0.06710827560915102, 0.013135256407211625, 0.050789580094598, 0.025582870378369288, 0.03492586036783553, 0.059056400411552, 0.04652216392118604, 0.03872610846414201, 0.011169921997333727, 0.08858297651092853, 0.026038742489031246, 0.04515290433060258, 0.011924671820334852, 0.06472202663820598, 0.0402345240957314, 0.0604692465745874, 0.011867493890496272, 0.03694665092494219, 0.032121539979632345, 0.02946398097030338, 0.030609035353747108, 0.05624955001797888, 0.03493229550639949, 0.0909562556133155, 0.07871058529182788, 0.03877938987927572, 0.046129662603620565, 0.06532820903005139, 0.05785587551673094, 0.03386389013499983, 0.030998148647467458, 0.06036029354999624, 0.02888929245302514, 0.0733680413254807, 0.039997281987340226, 0.03679748594520554, 0.028136582339122414, 0.07876228856583757, 0.03616935896476911, 0.011509586230761582, 0.01954582557382603, 0.0351982505901927, 0.041048523158796375, 0.014565920817755885, 0.021546312885719444, 0.040178205141977924, 0.05345337889007023, 0.06304113397134409, 0.07745139721420503, 0.05093984441050599, 0.08482191381194899, 0.07028904968812581, 0.04064431218730827, 0.012619422594716233, 0.02772367052403429, 0.036961110834512985, 0.06825634263335698, 0.05416748008780903, 0.058271600789720976, 0.040786609188803745, 0.028150362345660408, 0.03956699338290961, 0.00997595098470488, 0.035883792030114325, 0.12567020456997618, 0.08678243240161289, 0.027721990876260306, 0.06584049968589699, 0.05345315289413256, 0.013379034203206821, 0.024714028996024883, 0.05014871307198079, 0.10353868286455832, 0.07371665729630379, 0.03886354846819755, 0.013297714927654355, 0.041982932091360135, 0.0686756072325572, 0.03391349049765737, 0.06884653677022265, 0.06547265490817447, 0.049554948965387965, 0.04721663411586516, 0.021940572375071146, 0.025773067027330402, 0.03297177308629597, 0.012100481338077977, 0.024111167595331228, 0.02172756354294477, 0.09684847532621316, 0.06151356231120806, 0.056761695117118864, 0.016422705356812766, 0.02042964780552974, 0.053177533611174554, 0.029352427077209278, 0.030749777196756298, 0.13071960499209742, 0.009217690563790742, 0.061870314135786995, 0.05315525577433648, 0.026931604558241465, 0.07045214214632589, 0.042436620851437894, 0.07945232694187472, 0.026259435183038155, 0.11170013161796717, 0.0036615708602532266, 0.03465385701988013, 0.04631147825069005, 0.033898724152916865, 0.04356873409462072, 0.03574757393629801, 0.05192874517712382, 0.038810381966252486, 0.017948922956542625, 0.027370038592526992, 0.015623303141535051, 0.010436049027879153, 0.03323749451327228, 0.04916099208076635, 0.05486819389907103, 0.04438501226926043, 0.04137628238588091, 0.013258540064036367, 0.04614302700745963, 0.05674205645317993, 0.007393190406277897, 0.03259735910462276, 0.03415892591639873, 0.08086181380936215, 0.04664586030787999, 0.026505671163660385, 0.011589091793153317, 0.07868918845610273, 0.02795853584464039, 0.06394349361559556, 0.04843410487557131, 0.0334728826888867, 0.10784949791888077, 0.0470315664255571, 0.027050765704423673, 0.006539724408573802, 0.08019041435252275, 0.05112482400070276, 0.020897637511934006, 0.05460703835612344, 0.029101326438267867, 0.0015446476402669967, 0.018215127018911224, 0.05213427890632903, 0.050337779741253585, 0.019259350824980967, 0.03971547654439365, 0.08904884989944198, 0.0606993870479205, 0.10767249330397576, 0.08688391606894233, 0.02278663413298707, 0.06185519539060132, 0.02680342655719048, 0.07190648346177994, 0.039674341453299414, 0.006664767194794672, 0.05996157925936484, 0.06303191410317537, 0.0482629148680116, 0.06773750192575878, 0.05519881063411313, 0.042672786606295456, 0.03963613664851554, 0.030428589088842276, 0.05568896900982626, 0.05517261808798198, 0.09408220077954954, 0.016962808834749366, 0.13347015175367558, 0.1294849164062931, 0.09886294948838412, 0.15789392344172926, 0.09435271408649222, 0.2023379627855555, 0.08796914090071956, 0.17118545699744456, 0.11387103327339697, 0.14563735934995836, 0.1473174361331809, 0.15459482708284933, 0.10194315920553862, 0.17667363427819746, 0.1606916152541676, 0.11845842139014315, 0.18089438037526223, 0.11417925342797272, 0.15975049156094753, 0.11082348954533378, 0.15057102686935855, 0.1443113224400628, 0.09133853348753146, 0.23094625993361398, 0.10395391784127682, 0.1354608925119523, 0.13880014719982303, 0.2186148337298824, 0.16157673792012278, 0.10919815740518032, 0.07012211146854586, 0.1462461541016256, 0.12615249522270697, 0.17905514116489119, 0.16712082429758965, 0.1408857143213672, 0.10961454151378525, 0.14234984624049357, 0.13027351199378892, 0.15524428578153734, 0.09585539554996837, 0.12416795977661688, 0.20485681391531424, 0.09782860821653759, 0.09730068170615742, 0.0997382662289085, 0.17449999768887797, 0.10816027680712362, 0.28004239884115034, 0.19266824778770247, 0.19886571523402968, 0.08955272890987898, 0.1689687049797466, 0.13928334949718368, 0.12652953305552084, 0.11955440975725652, 0.17354218860066709, 0.1719704366499378, 0.09446665434347046, 0.1194325787946582, 0.1188226578937423, 0.09860733659156869, 0.11652482313013847, 0.1765802021949522, 0.2127800169851511, 0.15935555791422246, 0.09950643270126275, 0.2669428162757428, 0.18058409944417017, 0.1485102503530441, 0.13692243505389462, 0.08258675270143055, 0.1309443139020474, 0.25879010858554996, 0.1564356444343444, 0.09917973450595334, 0.16451932760255952, 0.17389103439786743, 0.10528800633525658, 0.12708001319439183, 0.10007161406740066, 0.15568881596048034, 0.14224047952842328, 0.09136412848508166, 0.3153805026123601, 0.16530174852138566, 0.2371677978625221, 0.12817074619834462, 0.109832271362745, 0.2924021243328049, 0.1426087686371419, 0.10464584845448695, 0.10714829764178685, 0.08769418428381605, 0.15249033758957542, 0.16808146791112039, 0.16340408744590898, 0.2529505420956881, 0.11086570098996164, 0.1652043940679681, 0.14680610308724065, 0.09563539041987351, 0.15459393842085717, 0.09226566841525417, 0.19007571432138645, 0.12801026609996635, 0.20530793245040602, 0.15839105321755334, 0.0760409067715368, 0.1834039618411372, 0.09452630961013418, 0.14508053600307436, 0.1674539346488253, 0.16123224350233234, 0.1264583711482344, 0.174000094674768, 0.1332239617383288, 0.09175481034382697, 0.09103860240429641, 0.13875355373226828, 0.1050230778092819, 0.13539123979787673, 0.11326896477370493, 0.1296875006969898, 0.09187196050920794, 0.13675109182875003, 0.1705985723604118, 0.07396143004899064, 0.16017700335191143, 0.11839215478469288, 0.16769618697224126, 0.18776392143580223, 0.169223781615015, 0.14087238439148472, 0.2686439911204, 0.12406356497517518, 0.17203510979250555, 0.1300842116676992, 0.24138676663560255, 0.17309480857464576, 0.18497890071763148, 0.1416611638400824, 0.09984128973296574, 0.2179723004660299, 0.2026306236943891, 0.22652626968920234, 0.1544538975482987, 0.1273330980010571, 0.11663317094526945, 0.1345367300053758, 0.1555019977592653, 0.08086011309417025, 0.15118457136615632, 0.22156621810168992, 0.17740140248450542, 0.2103336377730293, 0.2447848415542995, 0.22378031945516988, 0.15994916880323043, 0.1197030078319292, 0.1102418143061861, 0.12446585306597334, 0.11650145744844792, 0.11391256289977221, 0.21507599781597816, 0.22132280132462903, 0.09392728247950155, 0.13154792989934647, 0.11778964961488401, 0.13239569811811372, 0.09732569447688519, 0.1269069615931761, 0.1765600847260606, 0.12088152685112531, 0.190467476364105, 0.09656506875950484], [0.0347625419136978, 0.032578965333560785, 0.015926044809842305, 0.027845809837022138, 0.009317338492931619, 0.020285992913188475, 0.06915441984611173, 0.04178407481841503, 0.06824633752506587, 0.015861920377750312, 0.058570999441848653, 0.022943800901092833, 0.059630851441573714, 0.06437438359904675, 0.010428323031162784, 0.05912681538311224, 0.06835224918059765, 0.03955216575113516, 0.037554901754183155, 0.01888695165454861, 0.07185438948292887, 0.031160164752133915, 0.06102854821590647, 0.014988711336627604, 0.027722697592370456, 0.033668549205627174, 0.056037473897900314, 0.015959762254609697, 0.024585607762057936, 0.09504619985818864, 0.04584333341148111, 0.0431399125485651, 0.0643077262887551, 0.022889726584957495, 0.023099109905982212, 0.015501484627865497, 0.02293160861177791, 0.02737268351108557, 0.038682383995863705, 0.031555527408096584, 0.025557298363456805, 0.05475104373369006, 0.10872807053308334, 0.015573266108760671, 0.0393754905540376, 0.07266516331583261, 0.05221934913988075, 0.056138528555992155, 0.023699213390148455, 0.052555374455668276, 0.03123468787018811, 0.050368802471747326, 0.05708096225956275, 0.025615815989552967, 0.06251376670514865, 0.01361648602816727, 0.006848636436306181, 0.022929605291855913, 0.017572097713127732, 0.02948304889873872, 0.02871186265932216, 0.08145671938696215, 0.08007804457578929, 0.008098557722874948, 0.05967491681897833, 0.09890260986022412, 0.008409271493644245, 0.03761508179107501, 0.011420719073935142, 0.03461710778215239, 0.013872585390814611, 0.04157027883094646, 0.0665700835205855, 0.030225070170877926, 0.02963659973184188, 0.01723853345479696, 0.010575432980042553, 0.033102571108048005, 0.03429276913764977, 0.011971420420694255, 0.01509256317325297, 0.03864831989631057, 0.038058187046478835, 0.04024478967391676, 0.02193539936636244, 0.05551430096309032, 0.030929005381861524, 0.015507287743891922, 0.056419893498382265, 0.039671093240500464, 0.019992510375056057, 0.061309066631140254, 0.0551005675187034, 0.06166556181626455, 0.11001181938955862, 0.013399781779416147, 0.025857750386480364, 0.03703600742043026, 0.055585876557855844, 0.04919998978655185, 0.03708779879455124, 0.03554722279190056, 0.04983395435697129, 0.01833258361946191, 0.03447798238466344, 0.03848098714144961, 0.04241023678332568, 0.019865581097321647, 0.023593089145217693, 0.029954478339923006, 0.05021056318054757, 0.10619848651150543, 0.05943097910212894, 0.022019944829686035, 0.03593131246405744, 0.03152959916229931, 0.06225606238829994, 0.017157477521968466, 0.059537246988545504, 0.025619113998066996, 0.014636873966082932, 0.010047701822083083, 0.06849434316879319, 0.019454312540831107, 0.048485440427377346, 0.04123110872422976, 0.025238418095414678, 0.014512154852010071, 0.0039895388462971295, 0.01637046582125608, 0.008534048064311427, 0.03487206184335294, 0.0504017289307329, 0.018642071649552356, 0.07020613599208093, 0.07260066637348744, 0.05574338423508791, 0.05112398513442567, 0.02675866403977477, 0.03713479062782661, 0.05482581008466021, 0.04119965698449843, 0.023427483918625983, 0.06483306342195119, 0.03239255315894562, 0.03291322864712246, 0.026325755414643118, 0.04168601173366751, 0.017767902125694582, 0.021836340367313356, 0.05499510019416771, 0.012189988178321192, 0.050133571344157385, 0.04923323034158638, 0.046464967796759266, 0.030885166000394575, 0.04526033284022443, 0.02941369112851399, 0.03182742733418221, 0.017431526324681697, 0.014291136570635342, 0.03129117153284531, 0.058837613361256744, 0.011628920704336658, 0.01300121400310027, 0.05131491722779409, 0.07162585779423676, 0.014896212923040074, 0.07439918801068299, 0.03704312820768645, 0.005679908020782375, 0.014129760149385662, 0.0718127296216065, 0.043416152362741774, 0.03609947259387663, 0.054294953287969676, 0.0805331544289666, 0.06528579840256322, 0.026712842405803745, 0.06348309392530112, 0.039560431839838144, 0.0033488417994381203, 0.019377449024168235, 0.02347778333651443, 0.02537810656752798, 0.009311150417723244, 0.006867558808035909, 0.04579272564320315, 0.06598466977236733, 0.08443166862332052, 0.06395479724291833, 0.04998518394366388, 0.06060948663000619, 0.048284924574076175, 0.015029879944068531, 0.017141175170939778, 0.018093916587531567, 0.03704312437724683, 0.00593512398829203, 0.013355374535275324, 0.007213892315649578, 0.0450093547753509, 0.01076010900789932, 0.08396884426474573, 0.07373637639947477, 0.06335678517878537, 0.027158471920918074, 0.030859329685148214, 0.05171053652321139, 0.018618937709458896, 0.009746171530306099, 0.030692763018211534, 0.05325933264928961, 0.02775764843869594, 0.09365926661919202, 0.04754945335368957, 0.08445140304825, 0.03427867695028263, 0.06238800188105914, 0.046181105407736, 0.025872966807876385, 0.009137942726092954, 0.08753052492055201, 0.03392498181652158, 0.055839796400358604, 0.019581052211804256, 0.05295755146371742, 0.0747242237951967, 0.05102515596175387, 0.0043245385618760224, 0.04835790594018275, 0.02522536970284437, 0.06308069475175393, 0.059351294466684905, 0.029504058860062115, 0.0045806570767214705, 0.05369124152968007, 0.024586155514923796, 0.05952819949015976, 0.04396194787395578, 0.00888050941284746, 0.026368438003344402, 0.04285132339704902, 0.04747118215046583, 0.04272966097379404, 0.016093729965148434, 0.02144743583255237, 0.02618152021069921, 0.06496329070819963, 0.0341473235147855, 0.0233277277795658, 0.009405135999493783, 0.019647824435284542, 0.04521566991423888, 0.024902275951218703, 0.046880041895013665, 0.02829906192698306, 0.08682657438780993, 0.030735045325972384, 0.024894630393734383, 0.05428383735218837, 0.05243735861093287, 0.006100740227397652, 0.03144555931700574, 0.015657193913695314, 0.0677442511603717, 0.020945468211486455, 0.07673649162414574, 0.02357813319371593, 0.04652823516798597, 0.09417989997253304, 0.0248197510447954, 0.05603435208960887, 0.06515536427257523, 0.026382200772904103, 0.06470014716708852, 0.0379517276380812, 0.018805815282488064, 0.012743418713310554, 0.0026274196739729137, 0.0353461362030958, 0.10755720473225079, 0.014657741243530427, 0.007884375339809565, 0.07250224705785513, 0.03330771796285145, 0.016899416974234967, 0.010353713728217109, 0.06845873540207263, 0.008291405993663977, 0.04108310819813802, 0.05342867255451218, 0.04679481844387708, 0.03374594323817761, 0.021203714535541592, 0.08889245304970012, 0.01538860348744258, 0.04778717809747304, 0.031144071160064592, 0.002743477206451879, 0.030129221080231573, 0.04905446755489515, 0.03712496555019771, 0.035374592539043195, 0.05784197102090525, 0.023370096272218133, 0.03758135477020856, 0.023943459457387368, 0.017151053874723373, 0.014101389998329744, 0.057834842572769815, 0.032321395082098824, 0.034551247203302, 0.05671620864661471, 0.07514504355288322, 0.09083165907331052, 0.031211779926032312, 0.006833809762141638, 0.027704951165604497, 0.06836767053051342, 0.024166052049446492, 0.018167953239753842, 0.007112244897026329, 0.08732358925044538, 0.03517104297756188, 0.06493365842728846, 0.07184347273000787, 0.06776190948702636, 0.019764650928517504, 0.04536539413816026, 0.023531060921208515, 0.04473752379717846, 0.06382084293891827, 0.028416746438691215, 0.055803801759236285, 0.027300563993893807, 0.05635133245959879, 0.018421622188461405, 0.06646548953628348, 0.014561197885702697, 0.029594344237158378, 0.04290585736593893, 0.03866133189970448, 0.015134718118896408, 0.06948746891031343, 0.010719153947467286, 0.05142844762773283, 0.042605041451151335, 0.06352916645306735, 0.013784658606915225, 0.018609076242653594, 0.015560663962406258, 0.16200020068114804, 0.13649639823744375, 0.13606489155321352, 0.22174220381965562, 0.2121189290717725, 0.14971683883378584, 0.10554132096829916, 0.18793840562143635, 0.2595288624926921, 0.21235053277304097, 0.1696190370186683, 0.20505069544719112, 0.1588900982131881, 0.1752095176808296, 0.17143218327433835, 0.13969417180745833, 0.2191462382794388, 0.1691491799729486, 0.09204521129328398, 0.06721695284208945, 0.23252427848356388, 0.11525468765607766, 0.1292925976937817, 0.2547981316644338, 0.18937065296115416, 0.14968648643022583, 0.16653032372555426, 0.17395190774433075, 0.10992902060670239, 0.335937001171612, 0.1212482224969614, 0.10545931891688418, 0.20232812621660773, 0.1549901744170535, 0.178818971579594, 0.15499990373369188, 0.165487724025884, 0.10965315234516898, 0.24899032717991262, 0.11635760145802652, 0.15214043459103954, 0.1266752276569605, 0.2380177417709943, 0.17532435426067922, 0.10914158181197221, 0.13218572873982692, 0.17849523814455157, 0.1874576394836749, 0.15392070035299948, 0.12598028631820796, 0.11912436630096167, 0.1402594527650264, 0.11647048451366926, 0.1883436967768977, 0.08810935797350061, 0.11424177386347326, 0.17836619829458578, 0.09888140454648003, 0.11217687579412615, 0.10486866512726392, 0.19859726270360334, 0.19197438663292318, 0.23678541273599674, 0.11942248941669542, 0.18566268015532725, 0.20313080250015184, 0.07000178203827913, 0.1512777429795073, 0.07828967360359046, 0.1629104969962951, 0.11477869424608447, 0.15950831584632397, 0.19796121054359023, 0.06403176226623117, 0.12228466284972046, 0.17184101375600985, 0.099985551749987, 0.08880232280540852, 0.10085125408706166, 0.10395774828089822, 0.0975410188097627, 0.18332959002544805, 0.16281493518862034, 0.18040106571730108, 0.12299983657055324, 0.1131213243089376, 0.1077025852376415, 0.0958546677664403, 0.14733695605349156, 0.22862597879382873, 0.16178387277308973, 0.1299204680347635, 0.17036018112013418, 0.08995579074948065, 0.19536015817955618, 0.11368250669611078, 0.18614991207516965, 0.17880063143468675, 0.15729980693469126, 0.19637945348456984, 0.13099918111918435, 0.15410214061698607, 0.20308581781723808, 0.0885857650709729, 0.12182635074901967, 0.14311077073216438, 0.19423511209747485, 0.10189362396035465, 0.1375239826137981, 0.12984160694383806, 0.13351095359652274, 0.15188564906918234, 0.1872933595891922, 0.08417128299873683, 0.11712328335570714, 0.11805214198125948, 0.16001546605219766, 0.11125580062188449, 0.14280715476601355, 0.2060098068848733, 0.10481393580595333, 0.08973079838699873, 0.20580250349256302, 0.13091337927166494, 0.15580296306119812, 0.20444614482262444, 0.11892190458433283, 0.11492568353611617, 0.16400004256396525, 0.08151889508289677, 0.08900100004769142, 0.09210102079856781, 0.11491750171708484, 0.108831170645933, 0.21984389923032255, 0.18698405925064318, 0.1739014991589131, 0.13038646399734483, 0.15897102774150912, 0.13336820077271233, 0.21181770329994543, 0.14129537217799695, 0.1178655153020255, 0.18003004933557204, 0.1266904421631367, 0.1699928266386832, 0.10882969209623915, 0.16876132497864385, 0.18134318532482271, 0.16112370416522026, 0.16306662571526345, 0.14328913132269538, 0.12571950998878287, 0.1265022526645372, 0.09944306190816626, 0.0875537527064162, 0.22525971184574792, 0.1953103164992025, 0.12160975471018784, 0.11477045880089845, 0.12763898924834308, 0.13185315465013828, 0.13601192423412878, 0.14735540345070824, 0.11110599212829145, 0.1475477528067366, 0.15344931113143123, 0.1370354177009675, 0.2119441997380026, 0.07217031648202289, 0.15884489902565557, 0.10342434424185946, 0.14505692517324803, 0.13001573872902703, 0.07847391774937992, 0.141354943174989], [0.07331931813349647, 0.10303713276141113, 0.08396384937147941, 0.0645944576770548, 0.025277519223069953, 0.061860535023433555, 0.011810382993351068, 0.05735653174680568, 0.05569327825440034, 0.014185789904947725, 0.05565030838272745, 0.000983068323788053, 0.027961008393416004, 0.0398131336025413, 0.044843550365898883, 0.031565614870839545, 0.03866186050037223, 0.006862757830775433, 0.05194136647567634, 0.07865220173111848, 0.07189058713735112, 0.03956348086977678, 0.03706562437958295, 0.03337855428277004, 0.03332783543174306, 0.034477603171140916, 0.014560005661370534, 0.05518857952988437, 0.029955566184775486, 0.02577254225710227, 0.03997529143347375, 0.027761233730181575, 0.07519503845082176, 0.017548509865939137, 0.009676660542496511, 0.03361732856700978, 0.057590138767996145, 0.04101363168428502, 0.02440848440352467, 0.06889257865447192, 0.06695483585879689, 0.05278257698181176, 0.025120088154630318, 0.05686716244165456, 0.02748070956928836, 0.021469656212796128, 0.10082046501338483, 0.018335347281648748, 0.05351674585272709, 0.017283837979419098, 0.029818145332918055, 0.017277075338267514, 0.027311266242196004, 0.008085923017783752, 0.033097147205544096, 0.05034608796479241, 0.05811372922072488, 0.043784709602233865, 0.04464453221448968, 0.019560643629501426, 0.03653311666341559, 0.02721892966468248, 0.05235858178967911, 0.04509235274106745, 0.019134961128715548, 0.046665870524462194, 0.04578187400775571, 0.030604159204109065, 0.02052282133410054, 0.014557158687121928, 0.016175655407770988, 0.02540994518166108, 0.09695578126176711, 0.020199511162636262, 0.037636781231530254, 0.06695691195707168, 0.022593961104810722, 0.06202869515325274, 0.020689014533174135, 0.027135519926706632, 0.022563206505090482, 0.018563515078576825, 0.05899540832146041, 0.013562149326917867, 0.033590113293499715, 0.028240680281493454, 0.06517378868715418, 0.07581556966948895, 0.04780287140860193, 0.05115934775301045, 0.05429760395218769, 0.01935785057984533, 0.02846641574926194, 0.04275400341758805, 0.0987683759341317, 0.020676889276552587, 0.047986230722838835, 0.07939912213553345, 0.03385618712092119, 0.05049442556957084, 0.008980481014136345, 0.023383809246062752, 0.013187582127659792, 0.034712738537740324, 0.09057581635011781, 0.030907639189653342, 0.07497383056268578, 0.028550340681366866, 0.028223360948745283, 0.07126994100549529, 0.01459419041977174, 0.059436368530676256, 0.046358673097265345, 0.09186554069240248, 0.043389469520339084, 0.18512021329614425, 0.027063396579075246, 0.021474156979351275, 0.06428999135330801, 0.08445062929944647, 0.049401045731839635, 0.027636139233025814, 0.06952687647313842, 0.03188851710048414, 0.05375211104570378, 0.017897598896055453, 0.016796715227105928, 0.03253300388854358, 0.05796464084978065, 0.033514236115039356, 0.1083717630395005, 0.048037133434967655, 0.13943566309828914, 0.05192108046744139, 0.055641084684119116, 0.0762440962716937, 0.07387325332890596, 0.01610013637541523, 0.030028359859340617, 0.049832648177060394, 0.04951155391491709, 0.03745562825051527, 0.028246117590536034, 0.09111289761119312, 0.018545787804008975, 0.02645719886547135, 0.0854578740414112, 0.022455268546998985, 0.033700950894384615, 0.02315605130617417, 0.020188973623237783, 0.00946769378178062, 0.05119820373252996, 0.05395250815537669, 0.07017851852241062, 0.08504859156786435, 0.02598119970981873, 0.09153321941172884, 0.07595138173670539, 0.01046306799135862, 0.039403617472177556, 0.024990215184046857, 0.013019482327264645, 0.026088614812901905, 0.0301954991770007, 0.08053523818812064, 0.06743105143428811, 0.02328192146735326, 0.0073313666319835095, 0.04513855933422043, 0.020467944540864518, 0.06408470277223857, 0.07518206858226369, 0.01457603892401582, 0.021604443637413845, 0.03047252040086014, 0.007249376071887392, 0.00421787757659331, 0.0377686019806612, 0.10597699517083746, 0.03035127549552389, 0.015708629056931506, 0.01617481271105428, 0.04398782249359835, 0.06434442956120738, 0.047105053409693703, 0.054943297328727866, 0.03877643661032762, 0.09005891384496804, 0.0260585286248956, 0.0238059964706941, 0.03113570739515126, 0.04075122358758123, 0.062316771025859544, 0.03143404118506418, 0.05528345185842726, 0.025679328508915442, 0.04741312800756386, 0.005699288608851813, 0.10391979628512937, 0.07314197643990479, 0.018161813045040737, 0.033028888771490704, 0.06628965703590263, 0.0414466705443638, 0.03786976772150205, 0.03048639616838867, 0.10368708175637069, 0.021244441684816154, 0.01895781287232474, 0.008402157409657395, 0.06578085974099175, 0.035280076441385096, 0.005695843128412361, 0.015322971777359565, 0.060642144958218264, 0.10601877760622772, 0.07785298050411286, 0.058062225129575505, 0.03800381395605303, 0.02861855698058442, 0.013925593887125293, 0.036966255114924525, 0.061545121303248795, 0.046927018406530546, 0.02546436423736234, 0.05704397553457849, 0.03751398116770772, 0.06783721592998312, 0.03289140663259933, 0.03609435129610281, 0.012103688373650995, 0.05412995327083815, 0.05315536302664588, 0.01377168011986801, 0.08554502420367734, 0.01297741739695231, 0.010815904149034572, 0.03347401266857501, 0.08945889080003386, 0.018067557417276888, 0.009612486314689441, 0.05626586002988681, 0.07578443585624618, 0.04956362874157006, 0.07762711480139725, 0.030191276117318103, 0.05267365077029794, 0.04976044439019696, 0.06342040878089686, 0.04219344539207317, 0.056809721169092005, 0.03511133025430384, 0.030439775887756582, 0.027745749178012053, 0.014857147226951297, 0.0416157461492525, 0.05594860769868378, 0.00695929496413878, 0.04073543068502219, 0.021718889512422106, 0.01985512782759484, 0.03369617050573711, 0.04018814896323508, 0.0793725005801647, 0.008060437187762752, 0.03462175027497354, 0.09043687864417031, 0.031221061081234968, 0.01687713722217708, 0.07146895532646487, 0.06072590135097985, 0.02913561078809923, 0.0729678752982328, 0.035727720767740286, 0.056071855923942024, 0.050263932695792574, 0.07973190306896165, 0.034158952729476076, 0.06963546177552593, 0.0791690429492343, 0.0474604913934825, 0.050158679875875675, 0.02705591764571446, 0.033408404898739634, 0.03292806777021578, 0.014992721806911212, 0.05479764486212404, 0.03978565019825774, 0.06670715197199775, 0.016618082675361828, 0.037189726792876764, 0.029671305430031596, 0.0526719615464249, 0.033903646267830365, 0.03741306823588187, 0.034664057480591925, 0.022534474377490343, 0.09267021646542896, 0.009585546832832118, 0.016534542702438853, 0.05738131086071653, 0.05735931264597082, 0.04838026038581326, 0.07080860285749359, 0.05097367485324222, 0.011779781611215685, 0.005189905735483814, 0.012979939741443002, 0.10600547065898296, 0.013562385856564487, 0.0761779445794321, 0.07034433825362114, 0.03260503913606367, 0.03548055399029005, 0.04843538041196523, 0.06496810940124335, 0.042937075448853355, 0.029374429122394616, 0.059907390030040863, 0.05687435983770317, 0.057180921411922866, 0.0655194092541933, 0.017315921741687966, 0.06595532860486739, 0.05668613586514708, 0.02553641863708054, 0.046335594698546395, 0.06019417504449526, 0.05621351324202073, 0.05688194793859317, 0.02170422850477119, 0.0846907978637084, 0.043885706803731384, 0.007947831360187622, 0.03005156274734726, 0.004658848798323062, 0.02239702288211594, 0.013261925215051781, 0.04055882443583781, 0.06301854969933629, 0.020033093882844816, 0.007261373008781624, 0.014305598395425948, 0.02707100574738316, 0.015792619106509996, 0.03350953999606352, 0.05850230816811804, 0.07530947666495078, 0.011238796174556259, 0.019874862252524304, 0.03393658421813481, 0.15042782971455207, 0.211890006678239, 0.15778976612754408, 0.1789961523947216, 0.14440248690305219, 0.2013675438901109, 0.19863800325941658, 0.17777692346322924, 0.14996806970767437, 0.0962254083565166, 0.20310622639954093, 0.10960128053181595, 0.18649321139579822, 0.12585665504898758, 0.1042719669039211, 0.10002508954775911, 0.21394250944497126, 0.17846833313665084, 0.15100765102092298, 0.18336257777146756, 0.200096711276039, 0.10957182445112737, 0.10854288409914702, 0.17566261272276604, 0.20418247268084558, 0.11608858968341544, 0.18886452931309902, 0.19945315145436796, 0.1884351370315398, 0.10632747273531654, 0.16308888823034304, 0.18717285395870287, 0.1676973207823692, 0.13074036597484542, 0.11299709549113629, 0.09089521372750883, 0.10092815399290093, 0.17754692854660173, 0.11024568305020371, 0.11841872271390692, 0.19541053612145687, 0.22027163676196532, 0.16550923577479779, 0.23084954899405283, 0.06851864347775137, 0.09457022943083318, 0.18025445181035227, 0.07263556933931767, 0.2074047150991617, 0.12180670059376186, 0.12061367186927989, 0.12349181823552617, 0.21461347989257307, 0.10318966852801462, 0.06605499664381628, 0.13485664832255534, 0.09273989982302151, 0.11314977681444538, 0.12789061848795222, 0.1372921950514278, 0.07812029156353205, 0.09524712939896891, 0.0846593193108997, 0.17535084558110084, 0.11006074176440317, 0.20635911233482823, 0.3009606441182475, 0.1134604944156543, 0.11419745567705362, 0.08610121169758421, 0.14529851866104912, 0.19512559737889998, 0.14088366120573015, 0.15018307994450295, 0.1344918219312545, 0.11977496647065687, 0.18588394166961794, 0.14412265030607102, 0.2173835006091864, 0.09523248179785668, 0.25144373907917933, 0.15518880569406096, 0.14866071002137277, 0.09885082231654276, 0.09448075036127722, 0.11767959342368188, 0.17645301627776316, 0.2443995146501449, 0.16828656497020877, 0.11112827762600877, 0.11856409555841839, 0.21376119175505257, 0.11079172753999311, 0.22248685660381473, 0.3042215433332228, 0.13828421762633708, 0.1442797289740655, 0.21358447059267954, 0.10546756968382867, 0.13178515668597915, 0.1566937088125175, 0.18388419171735165, 0.10771859647525896, 0.17385012530271085, 0.2551898477418769, 0.09424663389161711, 0.14554507639859954, 0.11984925401667434, 0.14120177155540836, 0.10342944638743516, 0.07561434901529744, 0.18857641896653562, 0.21741720847785476, 0.21832647823518325, 0.07779367763789431, 0.40266154333949095, 0.07193802330162256, 0.12473177750624957, 0.11803072982377584, 0.17074609025111123, 0.19941372856978448, 0.11738500963415831, 0.16230965423728191, 0.08611401302679893, 0.17262841424634381, 0.1509394845174205, 0.24984204841236918, 0.14599270157275662, 0.1385107804690638, 0.12936686225716146, 0.20540323378818653, 0.09922058997495521, 0.2833837372881751, 0.2243060702758451, 0.15523705391153214, 0.27747263350794393, 0.16494481283570492, 0.13739235338664826, 0.14205649585252808, 0.2194075355486524, 0.12092041347416178, 0.21455960858973766, 0.16929913402324723, 0.2420137023493167, 0.13862849753950873, 0.23901013206810723, 0.16979372038716273, 0.06610861513763666, 0.14399987705532583, 0.09379190708240194, 0.0973800330933544, 0.09829776046136696, 0.12954673970178252, 0.10543046038477652, 0.15517077198432339, 0.18537967195433958, 0.29703239039067303, 0.14888140463059948, 0.15495488840726115, 0.16272027736469624, 0.20286078715035993, 0.10370675489426621, 0.08320906890496131, 0.17576726033322274, 0.17766319004999054, 0.21222233561979187, 0.10829880848647126, 0.1055550569247815, 0.17230178499894758, 0.09250666435447433, 0.12999428826714718, 0.16362387807138506, 0.23365027451467132, 0.11063110954578846, 0.19928242109956282, 0.16487600281834602]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.02069837038194941, 0.04109103720815432, 0.049088263523674784, 0.008520625246268128, 0.044606940280045235, 0.056651769160863855, 0.04648417745146059, 0.04259290661843073, 0.035524401032636245, 0.042502492921607155, 0.02209758209515243, 0.021115078162702344, 0.033002657920963345, 0.027209095010954528, 0.058436099019262104, 0.043013469736662605, 0.016615832292084253, 0.03563115921532435, 0.037217489819252686, 0.034819144319983265, 0.05440231668011797, 0.05025624883391204, 0.060939302803167415, 0.08344408169749283, 0.06218707617071848, 0.03331704508332956, 0.02340677273159306, 0.04445983224638528, 0.008044530329624973, 0.008466424525625283, 0.11153477153951123, 0.040920586475441535, 0.025833697140877767, 0.022424879754262588, 0.05463891527465275, 0.024306611946573662, 0.06837772160407997, 0.02820903318934143, 0.05180617493967857, 0.03536453763503702, 0.019257684583745657, 0.0855594419784123, 0.05136705717192062, 0.032543778915198586, 0.09068139092696291, 0.02868604741149372, 0.003988355958661546, 0.053159017266044696, 0.005927511468349446, 0.04642776273671658, 0.00921771546164828, 0.028743364194768573, 0.014537721121263121, 0.05755239361596685, 0.04205494818668212, 0.040357588459887815, 0.12224785998583802, 0.08794621188914584, 0.020113307118956602, 0.038677454220070955, 0.07004624578140436, 0.015805709633916136, 0.04662317644444205, 0.04468974672378071, 0.062064436985360044, 0.029593407694670944, 0.058811447628202944, 0.0546020204802194, 0.03309457315011852, 0.009017408367306476, 0.02680061118406875, 0.014222935593176275, 0.08165102226719742, 0.08224002130690121, 0.06511390359411318, 0.06784202696214761, 0.08588914323838488, 0.08121343284484842, 0.06931340607303767, 0.02059351209731352, 0.04716774238453758, 0.027173605987862236, 0.021939534325933745, 0.052294471721735694, 0.02299039053820795, 0.03762664971873164, 0.05923863740697984, 0.04139072697369322, 0.02872098676650034, 0.04927307840496783, 0.03406699536548507, 0.0455753558555678, 0.05044412423646258, 0.024930761015463262, 0.029715198437653245, 0.04466538895822821, 0.04301342760182677, 0.08042796289608364, 0.065801881193634, 0.01387121792386977, 0.023855947318577, 0.08169434453931548, 0.021234011397727078, 0.07590587611400312, 0.043449021365133025, 0.009570569813912435, 0.012072350589498397, 0.049415398389101035, 0.049174827628678856, 0.034277761475213116, 0.058868969339997544, 0.04695907152528244, 0.03828914340345129, 0.03158079873349878, 0.008591497955363124, 0.0816744645576804, 0.04681079903797758, 0.03493894898002187, 0.04266847736172138, 0.043112348705049486, 0.011867569541678795, 0.04435547574933979, 0.041858071251021284, 0.06574568098350879, 0.049224060269132744, 0.03631082859130637, 0.03577983389878946, 0.03953539225603304, 0.023274197385856704, 0.018217672346039646, 0.01612177069839691, 0.05347457271249545, 0.04419180872519651, 0.04978273754879352, 0.007959786162246019, 0.04688153576646601, 0.05202718747539386, 0.041058524436647856, 0.025342349413662188, 0.06182056438598422, 0.06058556936501015, 0.018031543623956463, 0.02860448969107482, 0.07833212253547485, 0.06575630662301857, 0.05095174558640969, 0.024282577853169174, 0.031582012982858766, 0.03086578589113009, 0.021879942261523778, 0.012772349066161101, 0.05627902142042595, 0.037769605555842, 0.10569823109695028, 0.03817535253361829, 0.04894656407076025, 0.0320930204414312, 0.037469754911839, 0.03098403347746259, 0.046858216050050916, 0.045319930650293834, 0.027574528526935368, 0.047060221944364815, 0.028042740398837675, 0.05187797269994213, 0.006151459557229594, 0.0807070257442613, 0.03527825315212531, 0.056771757682004285, 0.04895532045573477, 0.08241280477734343, 0.05244777740670308, 0.029468091032017144, 0.0770631974803344, 0.027576286698721593, 0.08407857869901965, 0.012922835547567136, 0.06707973883397157, 0.09078063761755344, 0.0594746231311752, 0.042047367746671366, 0.056266492052424344, 0.07953600672584388, 0.02372681170762066, 0.03225174619846287, 0.05875109139108851, 0.07326076603344372, 0.032604196439346964, 0.06506962371208976, 0.0832975137558195, 0.05199372092442167, 0.03475868083055943, 0.03995641119657986, 0.02127914355256625, 0.07820996981594833, 0.020963461701607993, 0.0940171522538989, 0.031690979413988615, 0.05846121904229926, 0.061084350060311064, 0.03373444425843416, 0.02668046561490384, 0.03695295965899864, 0.02397309173829854, 0.02552740561265138, 0.03019479629133017, 0.027674688777375608, 0.026527634904449506, 0.050701070126266255, 0.026012084544486096, 0.06143868487748889, 0.016136673023743976, 0.02715313037286603, 0.030604557569829688, 0.028248812304809693, 0.02209206243165799, 0.06631339043979684, 0.05939838972183005, 0.06473155677198403, 0.036913073291220976, 0.028755050866053473, 0.011043649639994388, 0.06647349515509221, 0.04651695452330094, 0.06176184757702774, 0.014372854211908436, 0.029521673136661132, 0.01387319538832432, 0.03296393983727021, 0.08477866814862337, 0.03905771728304606, 0.05662422829998597, 0.013629734561207795, 0.07932976053486909, 0.044773951277978, 0.0006711729820967923, 0.03516802459114021, 0.011923659626664895, 0.042178307494689385, 0.022312320370767868, 0.01941152844547985, 0.045642174044323545, 0.03493768110450718, 0.06996613596716235, 0.0843514668785276, 0.024262977493626457, 0.05276111119817342, 0.030860879097975073, 0.0654978055747286, 0.041088110752283566, 0.09352699387818576, 0.01725967173584767, 0.035839408726221135, 0.03637815239809213, 0.07874238560156477, 0.049599619552252755, 0.04925366190652694, 0.03631779233053808, 0.03895413070436447, 0.01365371407084768, 0.051841372849359635, 0.06357480997159597, 0.03940770455125359, 0.025208464057575312, 0.015106493524546105, 0.043419029022897446, 0.02445567925009997, 0.03130119962377414, 0.03478938563456459, 0.012950375450835114, 0.0326582171293276, 0.05594902904704214, 0.04372719555131851, 0.054041217306568745, 0.03138882093011372, 0.06369935671588586, 0.0920261203822109, 0.05227381799129709, 0.01296210808739547, 0.015583663837112969, 0.02235693350103834, 0.00964396390988822, 0.025695885584178953, 0.0833951440008898, 0.03143656352955488, 0.016283177763163563, 0.04239007334915861, 0.036914291371020584, 0.0039488363554776315, 0.009143386738404874, 0.04147983832104553, 0.016798350824824265, 0.057202034795116034, 0.06938131210664589, 0.029727327524714416, 0.05004126924060045, 0.022605161310263702, 0.03250052559099371, 0.030127968526475375, 0.040767763425866445, 0.01812648490041254, 0.047023759989608685, 0.08242203613683101, 0.06418539353856637, 0.017226703142026262, 0.10322840193346625, 0.019332521797848806, 0.05940836035616456, 0.07632290373646444, 0.06528964416394312, 0.014827104131390732, 0.030977021857735612, 0.12351027329362209, 0.07263976750114272, 0.012913541943435709, 0.03976244922547091, 0.06015998837087424, 0.029850631291347168, 0.04695114251526614, 0.017420862380775715, 0.07636626431297872, 0.048726298470771125, 0.013357386473686466, 0.06005475853359508, 0.007526728149969132, 0.02208461222659436, 0.03371258393951482, 0.06402361875159607, 0.04474383636167453, 0.04529153560138038, 0.0519262362391718, 0.044877269725886085, 0.04227174723881387, 0.0924645831447936, 0.027925963701319792, 0.05433881182163473, 0.014166787093985948, 0.012292291559729607, 0.06688010398178332, 0.024630014048588854, 0.05192005774006248, 0.017621244168690136, 0.004334674383919206, 0.06979198119933568, 0.039870797040601896, 0.03107503706198787, 0.03625480841184336, 0.10235988039283023, 0.04545157519920219, 0.06851409291548115, 0.028842465328653494, 0.054660568749832536, 0.16951841903069328, 0.1953713124197337, 0.1732349107342382, 0.11232473076351228, 0.14295528552705242, 0.168011095074396, 0.16765797450657816, 0.15772408174891628, 0.16286327533664244, 0.21538214187227914, 0.24350381997083467, 0.12778099896686693, 0.12086222143543345, 0.1333885633897397, 0.17142236202714906, 0.14193618940489908, 0.10405688005830012, 0.09520324788266614, 0.20245077689328503, 0.15039016883219444, 0.15303168596038896, 0.13173205147106803, 0.23777213398247, 0.1315045693228322, 0.17586705094623953, 0.1339190026685115, 0.14467021931082974, 0.1434016236734967, 0.11795382225705732, 0.23764047411180314, 0.24585137384072428, 0.12693493146329157, 0.152688815648998, 0.13799121963881678, 0.20730755982860444, 0.14635389670729637, 0.12745445398914237, 0.11109887517147488, 0.11307277731717595, 0.09416295410764795, 0.15836833104971917, 0.12345648626045835, 0.1786155292704221, 0.13367052971115037, 0.25282827446297296, 0.1330835225000497, 0.1528232947232262, 0.0972766035626973, 0.15046245688872953, 0.09002843120646092, 0.0853189210137052, 0.11738910820455321, 0.12342110065923584, 0.17970562642139776, 0.09950977284461261, 0.0817988159495496, 0.18531968726986842, 0.19089737426369421, 0.12453405787387203, 0.22309384338798063, 0.23963988698538274, 0.16511408762345392, 0.11611728733705899, 0.2469761288093944, 0.14752582737034367, 0.1868763013232139, 0.12603291655860602, 0.18989982053397164, 0.12484685923423498, 0.1535810476108905, 0.18532051464482663, 0.0913704716930947, 0.25144796788452134, 0.14589386090876597, 0.15818005728144802, 0.17882736790324413, 0.23102798619337622, 0.10086266879713345, 0.17220694331392167, 0.19669232379284599, 0.16678373028914775, 0.1629916103857179, 0.1013057434090203, 0.11218888039189963, 0.09713876902336076, 0.2420625940806443, 0.2489704395373983, 0.1291744056488237, 0.10552980666679722, 0.13205132627439115, 0.1366341102027124, 0.13159895135510352, 0.11254187072477034, 0.11696772920268199, 0.10038593994273294, 0.15009566931234253, 0.13682993759791698, 0.19934433632560317, 0.17737788358523002, 0.17926846600828633, 0.1893516386588735, 0.2493560728767226, 0.0943327881395817, 0.15547323881858782, 0.19463769130168423, 0.1528128606056975, 0.1912642078053567, 0.21769784180627716, 0.2543830192617832, 0.09616640426458851, 0.13191326190867733, 0.11658273937721407, 0.1880267355591059, 0.11048610442348065, 0.08756436302416748, 0.15848514413641346, 0.17329331727758532, 0.18325984538082155, 0.10506345830377072, 0.15221315165681226, 0.05084222182631493, 0.1369175320911792, 0.08349399232575971, 0.23118362461607303, 0.14216259903004094, 0.14484468817470536, 0.15750899490329529, 0.12298043922431047, 0.0911191565495345, 0.2042273654332084, 0.12077703245825346, 0.10639406875857424, 0.1148598995660582, 0.17200723951382024, 0.09259845700956161, 0.13399850727329332, 0.28661246081033065, 0.18579519804446928, 0.1538800210842202, 0.23359415091333852, 0.19162403930339122, 0.07552611100817881, 0.15925107884310907, 0.24342137358842358, 0.15563597121546346, 0.17870857830970518, 0.12373122837274306, 0.11434704200514864, 0.1355912347113894, 0.14726923388098517, 0.08453169672359383, 0.2014426205066904, 0.18122212811102792, 0.17458403753417154, 0.1706751964745983, 0.16698560977895416, 0.1130746465717112, 0.21026141100352813, 0.1743598648857686, 0.18052138748668856, 0.23020980429024468, 0.10469696950167419, 0.18321679123947698, 0.08743165361304438, 0.12299044433260158, 0.08688291249376151, 0.33746448856207634, 0.21676742802223853, 0.14607896307303062, 0.11692220825822124, 0.14638757393244775, 0.19180054596114546, 0.15388679330147084, 0.19473743594942555, 0.15239810060349204, 0.2220333019091237], [0.04547423991044203, 0.026031874510790073, 0.058777996398989237, 0.042762966646302136, 0.03965059272764672, 0.06673515248563021, 0.06332712608479685, 0.043352712621732105, 0.04567345724471154, 0.10679973529711848, 0.09174203965812923, 0.028747851554785046, 0.01562145591202763, 0.05852178212315325, 0.056788255385453665, 0.027748204489809372, 0.08058963809162378, 0.036580571979885144, 0.05461051639529967, 0.03818287168659511, 0.0436892512164289, 0.021903482228217107, 0.030395348533807747, 0.09062674587532397, 0.06918644232134666, 0.01915348321950484, 0.09431542092633825, 0.0646875603424926, 0.0360024475582665, 0.06467190916619955, 0.050867280562318144, 0.15516006207514196, 0.06207400159309469, 0.03710342698820657, 0.0732932481614332, 0.09556379950334949, 0.029646993629754554, 0.0956726529365105, 0.04879037023431832, 0.013668186429347242, 0.03837083901969656, 0.01963082685946457, 0.05148987255750164, 0.06141905770486882, 0.04437332559797553, 0.03109951357116863, 0.047670901272325754, 0.033133881121513345, 0.024662624496305664, 0.018366331707746274, 0.017681795758225264, 0.0455756239863413, 0.015694672850170927, 0.03425261846953823, 0.02188920043408871, 0.052630083350044106, 0.06200390454802302, 0.0804966809828916, 0.012440662680854721, 0.014142584461238117, 0.04749355191785482, 0.02819049960723327, 0.03166575788430149, 0.02914525008940649, 0.056488979307393876, 0.0528321773444693, 0.06645759883066339, 0.04005330216680323, 0.017188879465984724, 0.02492094934437304, 0.008130092774668049, 0.09915045462548734, 0.06990392962771078, 0.017599002721028465, 0.037357201274003715, 0.019749061039258397, 0.0032242294588697056, 0.060966904951079245, 0.04736670307935246, 0.029495206714097052, 0.039644138436884656, 0.03799770057441727, 0.1355684512565213, 0.05263439642505781, 0.031590882365802125, 0.044538789098301244, 0.061422508930967706, 0.03462736952989813, 0.03418054874806154, 0.024287199278572397, 0.06804491768801404, 0.05503903533662519, 0.08718999883820934, 0.024906027866827867, 0.041056199359797665, 0.017055001770777088, 0.07126984907494438, 0.04614986051174422, 0.013456542191335992, 0.016466372368496754, 0.018335525397091143, 0.06533586224841495, 0.04925634321426192, 0.0559184544779841, 0.03745005113042651, 0.07198935119254936, 0.04772300674249569, 0.008339229032337185, 0.0438115609839799, 0.046442410337828824, 0.059068784222847996, 0.02885878300144067, 0.050588573945025285, 0.012073103270884003, 0.007898478539690616, 0.061561975237582965, 0.047393474021866444, 0.04660333476720318, 0.10894367831849283, 0.04172353855063839, 0.02181769378723637, 0.05468167447214646, 0.03665553368327599, 0.012414571641373539, 0.022605174716802377, 0.06853337534853528, 0.027696727211737347, 0.030155335102350484, 0.012678251444031636, 0.06994668499476488, 0.026985456708878763, 0.054240710432491, 0.029410864264073393, 0.06307289214624513, 0.04958286903978837, 0.043512790523950136, 0.024063823361610694, 0.15644238600807805, 0.05171514837251556, 0.07011469573743882, 0.025565056918909954, 0.046681540852953354, 0.042893416098048615, 0.0407840236420593, 0.006056057670409041, 0.04850692536321379, 0.019519567910221317, 0.04913992466284864, 0.036688299263797464, 0.04677664683831315, 0.03595226879922613, 0.03413025124539291, 0.04082259999948644, 0.06102502421145478, 0.07156135319101234, 0.06152689990196979, 0.03700303116572961, 0.05699470842016801, 0.05110095270098217, 0.07788122616588108, 0.07421788564252277, 0.003391614642872986, 0.05871530359370574, 0.019936229725698792, 0.0255272658016052, 0.019031347736956614, 0.017505806209819934, 0.050280625751662644, 0.08589877296359309, 0.044773062615985834, 0.05133988020280677, 0.012664721373678937, 0.05180015348859372, 0.02990250885035963, 0.07714321536402549, 0.025110609731787158, 0.0448502115004005, 0.03588915464558429, 0.051311075296853824, 0.030538120509816274, 0.032368065158445994, 0.11520083167500074, 0.13466088221438471, 0.026193907852434826, 0.07830553162362307, 0.03248801154475058, 0.09902061804408029, 0.046245449132496314, 0.0472580028637763, 0.03551064975439541, 0.052413326432748195, 0.018742777737638643, 0.05293338138970637, 0.046172559696940646, 0.030165265517068968, 0.0155119551345706, 0.016906216004562956, 0.01646717867603706, 0.055398016477063786, 0.12084192010544001, 0.03195554787863887, 0.006782550819128031, 0.038759555862916094, 0.06466476922674526, 0.023234207596209262, 0.06550067840444465, 0.011348828425510757, 0.06776998405374828, 0.014270096923404885, 0.03560037780252676, 0.052801380609913226, 0.08589006254389402, 0.02397219350020732, 0.04845036509176416, 0.02273321099158737, 0.05442567470092928, 0.02370653910592439, 0.034588980864012436, 0.011357625987711213, 0.0684061281443123, 0.02512828912585974, 0.06924065836374799, 0.06042160739701602, 0.04743971508897601, 0.015627339467286103, 0.023052137224904956, 0.04233051767392505, 0.08953596690609571, 0.0452442564851334, 0.07228671588123807, 0.06975156240045063, 0.08896675591747608, 0.10263925733705682, 0.07615666265689558, 0.0325214819261624, 0.023567042155792157, 0.055030187021099755, 0.015492009077852052, 0.013754521665583937, 0.02859302135484834, 0.05422493668213006, 0.021403454724819432, 0.09664614384453143, 0.01595871175654353, 0.022866569662226305, 0.07660634860756897, 0.05180759986321773, 0.056793878470817884, 0.03589156016166653, 0.033173246549502496, 0.02267227444287029, 0.023782860615380833, 0.05197012924679345, 0.05480324113441091, 0.00717456327683683, 0.02918158180921549, 0.06586073206797724, 0.027000075581693844, 0.09177685835428777, 0.026675725445872354, 0.042699408161664204, 0.06347583524221856, 0.07214605447746093, 0.03013377355772161, 0.04996292525902391, 0.03185435149428104, 0.009864274517542893, 0.012802042634106212, 0.04598230942182484, 0.05154764324787164, 0.05080879357973895, 0.03290618063821908, 0.04518947353766811, 0.04381279821597761, 0.03435448135039018, 0.0008499830507770963, 0.03450472651410007, 0.08669683739783303, 0.06833696572650826, 0.06553256298385321, 0.01835966482758522, 0.10959691383064755, 0.0406506898692779, 0.015738489249000148, 0.027173391483243436, 0.039708907340442946, 0.03146756902307032, 0.030164957166679447, 0.02693282646848069, 0.027883403686686393, 0.05684157510498359, 0.037889659194456, 0.04443902912880144, 0.025338160827936187, 0.06866430743567406, 0.012146428418946604, 0.03220119971721884, 0.034452260982605724, 0.057795860188742804, 0.028186849198274078, 0.028949577827006582, 0.01147051574662328, 0.03333665310375152, 0.017911811742270668, 0.009164981799380434, 0.09075755538839488, 0.03887783600798538, 0.0325401131844809, 0.01671191120910789, 0.03586994499088295, 0.033256688846215125, 0.0021531818023387103, 0.05271680833351228, 0.09567786233439561, 0.02923390944488347, 0.06730961117653117, 0.08658213105293051, 0.007515229170225682, 0.030187108599010016, 0.030816972683814746, 0.06483422021471685, 0.026473922564858393, 0.01809818369726981, 0.016856177056568767, 0.05174350894747242, 0.04596879180040091, 0.005916969619706394, 0.02948747497172125, 0.05648615244295328, 0.026901700316117178, 0.07550069987173043, 0.01616339991620231, 0.058966718328696106, 0.034361475733138865, 0.018242968569299387, 0.03295260556643048, 0.06871722112860411, 0.014510396680223846, 0.04922475740914384, 0.09040245065285314, 0.025524025249685493, 0.05068921108519839, 0.02303931099783269, 0.04133449612005104, 0.10544238071287833, 0.04567834105522883, 0.03934028881391691, 0.008472526415942178, 0.07777295495954253, 0.048991410857847625, 0.06364076631143689, 0.05535539517539644, 0.1335103407261833, 0.09605551303754892, 0.171853638885002, 0.17784397147836226, 0.14784294180572033, 0.15837392349156643, 0.23028990644360744, 0.09166601309252363, 0.20029031701626318, 0.22812264370581797, 0.23292655125260356, 0.2134009618912974, 0.09522758649602052, 0.19192148060087236, 0.17561487012332486, 0.1692961769238595, 0.19473605699116187, 0.18124924762354744, 0.12928573354598016, 0.0928579309895154, 0.16227274412109008, 0.1267789253183911, 0.14211212915758933, 0.1983760624763466, 0.14535842673672786, 0.15322034277262228, 0.21382424079122084, 0.13154544777447177, 0.14756900408575613, 0.23783014216009649, 0.11312492492218172, 0.26996564600736866, 0.21092544069453595, 0.20284509766967068, 0.2276578734839155, 0.197948141083602, 0.14677011227655798, 0.22643965578848319, 0.15921606862496945, 0.11125389306295304, 0.1526527022642474, 0.10652866274599107, 0.14997642006604903, 0.1611230453296054, 0.1272183380299999, 0.18695111746989912, 0.12228778848845152, 0.09381337286604029, 0.22727740357720086, 0.136516347166992, 0.09391067369330315, 0.16041145690025824, 0.12057725971023883, 0.14988429033227507, 0.15066612902427876, 0.1794727050488995, 0.20207369309519568, 0.13381499857191118, 0.11906691736751988, 0.1110807112267902, 0.16899885820044627, 0.05126785261616592, 0.03722495151563518, 0.0833381240766856, 0.10864105060576432, 0.2023690353117643, 0.22222851643398886, 0.1607136479428699, 0.1500561851407251, 0.14419844704529933, 0.2004296377661728, 0.15591363212273968, 0.16476672803682668, 0.10098130517308751, 0.14142265002573692, 0.08769364036138981, 0.12235804641198729, 0.23472570874277623, 0.13909236377766057, 0.08496493476653293, 0.24846983172239798, 0.1980496170900522, 0.29116400367309975, 0.2015688105095779, 0.11307221807299123, 0.12233473435645142, 0.19147793101447244, 0.10548443127904208, 0.1266854472698704, 0.12907991636424296, 0.19359427954881422, 0.12625955601012515, 0.2365321593899881, 0.12913102975055096, 0.10349205109260737, 0.11390517781218214, 0.21582111025289183, 0.17701121858291088, 0.11356939381409077, 0.06738396000958259, 0.10503833061985432, 0.13517325713990197, 0.18282691377305216, 0.16068029247464674, 0.09178235120470486, 0.20831044553028, 0.19654733399229665, 0.08514695725734196, 0.152976282481705, 0.1080399856812531, 0.13436644398156675, 0.08437556034374623, 0.17022012492581723, 0.16898615646266169, 0.1318206572003903, 0.1119056883298101, 0.12254400659472713, 0.18191143870353702, 0.2006745407538068, 0.07848750814915666, 0.08782814241825573, 0.11919095466334013, 0.08416825695143593, 0.11312560674043433, 0.11221388550174814, 0.20255517935560596, 0.1426087533153834, 0.19629469351662746, 0.16887069169071414, 0.1929938045120047, 0.18840061710967174, 0.09240092889916512, 0.14112704733927406, 0.14179400348615262, 0.19224870739684952, 0.17838078460866408, 0.09997518658037148, 0.2760194566461348, 0.08768824710240287, 0.1716954264068796, 0.1696399052537257, 0.0763329701317895, 0.11057359932531273, 0.15078438235627067, 0.17706225536042647, 0.24192129682389, 0.1110866713908411, 0.08575627294879767, 0.18472756259143355, 0.15665807040228, 0.09718969854856692, 0.09728933594399884, 0.19871447415601826, 0.14861422380612743, 0.18461533071052644, 0.2588649094104767, 0.10970769014449851, 0.09625831183286444, 0.15410848382499912, 0.11932268348192016, 0.16969947625071774, 0.16766183558971653, 0.23109760826393483, 0.13182814954028976, 0.19258578608353294, 0.2201348287804473, 0.1010781080431996, 0.22257189236340985, 0.18409619888951703, 0.10780108116206624, 0.14282589327664147, 0.0840542094421483, 0.14588350340002967, 0.10795098158621019, 0.10739189827994955, 0.12425820493409712], [0.018466635599672314, 0.01456923989368783, 0.034399416237588853, 0.015806050543042443, 0.04818046848560053, 0.08733396974181937, 0.01769442280243722, 0.01467038265189096, 0.034007301794425134, 0.00975096628310219, 0.07699980370460019, 0.04146255537747376, 0.031225554186910875, 0.043063966422191555, 0.012622964793756124, 0.07429142242237445, 0.03215266804721567, 0.08716297125624073, 0.06070092305420868, 0.07140174643286774, 0.035847467971184564, 0.019762756776124723, 0.033646677395388964, 0.03675788686039948, 0.06353272876191525, 0.021443609223370592, 0.020788797485311667, 0.029187572616783362, 0.04171549079699382, 0.011259512149638707, 0.006405617365793836, 0.02638576691219163, 0.032979472269934994, 0.03402156252113562, 0.04944691907674555, 0.12337020943842589, 0.03770966300620668, 0.0696053545201017, 0.024619781029140277, 0.03390417486849812, 0.05641404441708038, 0.01984349478246464, 0.0287962912942373, 0.01328564425479741, 0.08379111186631265, 0.030445502394990578, 0.0377172740897344, 0.19038648554875007, 0.05632971728881521, 0.061476230846657876, 0.024000077185431318, 0.05081703668580421, 0.012664890870632184, 0.01836960290318295, 0.07461794441746128, 0.048431994303339915, 0.06307930813261098, 0.03105994129943992, 0.013766850893115325, 0.07504723710759033, 0.041928876927422906, 0.028273486081630956, 0.06104187048490971, 0.027713765007173343, 0.027280233935603214, 0.01128341983853569, 0.037010822279919545, 0.07336594990544743, 0.04011900569762915, 0.008795222759457126, 0.012648600968532266, 0.025290847237732623, 0.0984618871382648, 0.04739753045742551, 0.05594629794359208, 0.07462395054678764, 0.05617920782477145, 0.048970940988510854, 0.03694576609338965, 0.03711192290328684, 0.04761687292146587, 0.0035172329526469716, 0.02337516394383725, 0.05353554565038893, 0.028431842201239163, 0.01354494873779796, 0.05467803555450613, 0.040346223545531114, 0.05697768977693012, 0.06802520624572231, 0.00669855502389011, 0.03387151654028604, 0.08055476576931055, 0.0667252010034938, 0.027373156570378813, 0.02571709281314285, 0.037836496522950555, 0.04777637242730107, 0.02531640584610643, 0.035017461500941746, 0.028471755382094174, 0.0676873384884769, 0.10045825864278501, 0.056287073004510135, 0.058757687408116564, 0.05195497219721156, 0.06056262886211757, 0.06078342306277445, 0.018053208590455113, 0.0576540956183547, 0.04885801962847191, 0.02518365430014749, 0.03922428778042236, 0.006765285591339513, 0.10426128763825664, 0.0463980385252545, 0.05355664754226323, 0.12634194876638152, 0.03018848755727372, 0.0318820474879636, 0.125157990522923, 0.039716989568044106, 0.04838193428792781, 0.08958081369318309, 0.00900870752370646, 0.03449645276451784, 0.050497639308413195, 0.06129579415785209, 0.05830003797347027, 0.030044003374754425, 0.10358779676138394, 0.020025490460196332, 0.03216525104137198, 0.020948107384385604, 0.03365688168654039, 0.09485434079843183, 0.03626441515441384, 0.03344012476924447, 0.04957391347195353, 0.058259347213372115, 0.01736499541889756, 0.0379550026639575, 0.04262817347602498, 0.020684042622545556, 0.038256511888316566, 0.0302136650369052, 0.03222654956663328, 0.06854629159093865, 0.0169478528832476, 0.008516738307662308, 0.01803774127526389, 0.04209081259285731, 0.07036686889947423, 0.05630740880846016, 0.07368514043909889, 0.04851643634479373, 0.042063298545056776, 0.0539666309862608, 0.04250871355555231, 0.01583625930511663, 0.058174537449714646, 0.05051434385560213, 0.08963918193213402, 0.01920406992036489, 0.034680432609973416, 0.04906887000787163, 0.02196814004902638, 0.04067128997356181, 0.07202328122671574, 0.0678449227745014, 0.018106060996351224, 0.041000386024074215, 0.044809965071298426, 0.040782376553022096, 0.07907179574812613, 0.018821908874557387, 0.033470465681485595, 0.013949558075006693, 0.025272260029469768, 0.03007713093182012, 0.059909604024142034, 0.08185646406585172, 0.050469531542471344, 0.020340017433608734, 0.024564871677167477, 0.035517736067695004, 0.06732757593835555, 0.05357652752389831, 0.03765903225529098, 0.031123741101774, 0.004492146150779821, 0.007978297240521398, 0.027891853636491205, 0.02053480869489572, 0.07089568407184656, 0.04662736694538786, 0.06626540269221991, 0.04167349002654514, 0.024480935253743685, 0.025006096186717192, 0.07723148401466108, 0.0038900649627565498, 0.024293592282300516, 0.03686109422555855, 0.01918462660884665, 0.07588202779692027, 0.028763098619698037, 0.019438004444142985, 0.045594098196635326, 0.02605671682695468, 0.047589577208723755, 0.05958278325476474, 0.01366865661581077, 0.07797484211022816, 0.02885496022269851, 0.02934669099387623, 0.029406003436193835, 0.021598313018799793, 0.051728497454596144, 0.02897498321779553, 0.04090672028401206, 0.04409572214729363, 0.005235937086024112, 0.045682068072980454, 0.015241364261225588, 0.01846047242232148, 0.029925958801721855, 0.03692745276155972, 0.019025408640323628, 0.03209916829702354, 0.03656307453169458, 0.014705205178489129, 0.03406672340427195, 0.03179645439940355, 0.03762104961600515, 0.06416609578375375, 0.020815451599417195, 0.0664108521455238, 0.033934975433493816, 0.028004298106797283, 0.10666349422066443, 0.02316827232378625, 0.01399131561253941, 0.012988740176473175, 0.02988155634563056, 0.024412749598043102, 0.02730241218101113, 0.021873733118897485, 0.023312407936300003, 0.017754005290748134, 0.06621341596567823, 0.01845768577749691, 0.01231575204480079, 0.018814391636800383, 0.04497710630417832, 0.0322509111626254, 0.035715459530512174, 0.027516296268591, 0.07595839910209179, 0.05917193796185236, 0.03020014358504165, 0.03396320194306393, 0.016888929230551568, 0.06971862061970657, 0.08652180928977267, 0.05267934663401497, 0.023282398357086127, 0.08881212106996006, 0.015589806904655792, 0.008423356977742045, 0.03953053908903272, 0.0781662415172304, 0.04690566753608085, 0.10093609832467572, 0.04252439920580195, 0.027089637005701665, 0.06928173599824791, 0.029250093052283894, 0.021256902104904576, 0.022640880159733277, 0.04169346959961038, 0.024559103035097642, 0.03226472372790018, 0.01858448482028419, 0.025206313265727896, 0.07917613692341313, 0.02145715557309168, 0.05456714049702691, 0.031453844557906833, 0.03457811773724614, 0.06319139828725208, 0.04383854643111268, 0.02953751200449563, 0.046052322197224826, 0.01094065486423431, 0.06838714448554863, 0.0600789784033212, 0.10078732404978046, 0.04481095332472075, 0.018796151083323265, 0.03492849954073468, 0.027713787989811074, 0.028710809288426276, 0.04850197260478332, 0.17208738763245846, 0.03792779505132668, 0.09329542082043425, 0.05236368776569444, 0.026898438696779554, 0.04457971351521631, 0.028343581211482807, 0.0027865832981338067, 0.01736873009752843, 0.018004041067474795, 0.059801041704392245, 0.026296546397310112, 0.05994688186253752, 0.08936421765435128, 0.022404139838932503, 0.020316827952140765, 0.037804466386836384, 0.05916511211844702, 0.022457381034450188, 0.05585390007904461, 0.0441906442715516, 0.0641123432245466, 0.013904276533022284, 0.008320531698935216, 0.01744924976880993, 0.028646862014166774, 0.03952369026298966, 0.04272269723456233, 0.058607744849136764, 0.013591400479086706, 0.042733433956821124, 0.016181006531922087, 0.03872276832079215, 0.01384920438736557, 0.05437581003793786, 0.09939669060610956, 0.03462585650624768, 0.047437290420695666, 0.03578485943557274, 0.03398963580689123, 0.07975989592171485, 0.026635875467271097, 0.01967218028561723, 0.02899701590649784, 0.054058320219478304, 0.07388420072534392, 0.04277404427768723, 0.02623133316275574, 0.10155011013510729, 0.14919566921889782, 0.0874621898777062, 0.14067775209344205, 0.1830356727324186, 0.168127142073166, 0.10998354308427342, 0.14963463759951054, 0.12190135075680672, 0.087770095936233, 0.09535453492595304, 0.13723741976484177, 0.13447225604566837, 0.11690557648938511, 0.09755335282534362, 0.18792752717291156, 0.13953923818565186, 0.21602749433969298, 0.1845505656374078, 0.16027847935836162, 0.16819690203955098, 0.14026918208166478, 0.06504349245299255, 0.10945612219192329, 0.15787720740322145, 0.22767089697862827, 0.08379888765874409, 0.12284353931224155, 0.3198046603750798, 0.2727070150356139, 0.08348731969993922, 0.1267326765904023, 0.21050167149834095, 0.17152553874879115, 0.1311000595770536, 0.215846483084944, 0.14302732843545177, 0.2073345414452976, 0.16145407192168698, 0.09385867164500299, 0.15215154286594162, 0.15018191549085802, 0.16829480807627403, 0.13923652620325166, 0.11348379114943166, 0.14341115380727476, 0.09586983630734106, 0.24201621511770835, 0.10525239856853601, 0.16531740735855796, 0.08785839523038558, 0.15561308050828596, 0.08642313716512534, 0.08433062928698717, 0.18066771028022613, 0.1122149503639629, 0.18025328735670737, 0.14759716547785268, 0.19936423928987598, 0.12678641765829057, 0.12103392472190243, 0.13895822178211906, 0.18109224556434542, 0.1354545186604223, 0.22718070795939815, 0.1499250308880883, 0.15031138435006142, 0.1562920335920588, 0.08294127521014984, 0.1389530583495094, 0.1408885948119625, 0.09931943829982512, 0.18028146407056242, 0.17238081462921637, 0.19752549037577646, 0.15682359135920004, 0.11202921234672109, 0.1700286182665056, 0.11418204198801711, 0.18849096951946137, 0.10224859080007, 0.11075714633109109, 0.2573993219242942, 0.1841056064492272, 0.17174920577916408, 0.20753139539832072, 0.21097586460171208, 0.17373600884551005, 0.2054241173450024, 0.24386009682090054, 0.14482789552740513, 0.18787068344892996, 0.19487853402331953, 0.18948417186977404, 0.16707185595746965, 0.18890045883674778, 0.1003851278895332, 0.20700161495516378, 0.14425264010506292, 0.2398267971171487, 0.13161978894664397, 0.17699411950044094, 0.23795142920026857, 0.16605777005034109, 0.16136381144244827, 0.27288563609603916, 0.11767030077716036, 0.09025346953421833, 0.13020510034215066, 0.16584446052870444, 0.10662938032539622, 0.09258730276938408, 0.17818138724373234, 0.0637667992662999, 0.1783668111649252, 0.1310672710138944, 0.22739695925866404, 0.3000488462707689, 0.11252623487023578, 0.12553185675173037, 0.17895904309566946, 0.10759347899546547, 0.19069813011634737, 0.2055197251179526, 0.1366716178674852, 0.14649954534346057, 0.10109317699267019, 0.13605445743568484, 0.27114876155411044, 0.1560013338683113, 0.22310959415570383, 0.1723322140113, 0.1307276335935439, 0.11872136574839393, 0.10445431115165835, 0.22193297503455994, 0.10447956907052187, 0.16566806112325963, 0.15850114005227245, 0.1360241356756418, 0.12083547730599681, 0.18742606133943607, 0.10910665586350426, 0.11586886800585255, 0.11055833119298182, 0.29485835543563294, 0.15510796809629088, 0.18143484008408364, 0.10995528210074672, 0.23408289968727097, 0.09222619956539524, 0.13456493736274783, 0.2408526501347942, 0.20718031262438144, 0.20531778434111228, 0.20022927513045652, 0.22037010970375231, 0.2035929373795948, 0.14275671553707894, 0.17197452755945344, 0.17285364409608228, 0.10355211238587096, 0.20280268704218252, 0.1753751612118175, 0.12774234217020775, 0.12909952821510454, 0.1098543040514473, 0.15696738606258748, 0.1608148175141504, 0.2816661681619383, 0.19622548513354796, 0.0792194055693765, 0.07445299802648445, 0.1896056887363234, 0.16054403607643422, 0.10380831517038808], [0.08833857148044533, 0.022293455455632463, 0.03262264000612401, 0.020344447337030884, 0.0023967101409535616, 0.027357842472772446, 0.01197046376839881, 0.022657444895876032, 0.011714482191769827, 0.027426719522824692, 0.13263361438387825, 0.08336665319098581, 0.026572977733467857, 0.05096506019453368, 0.01603591043667327, 0.09737879203091707, 0.0822150161970527, 0.032380885639858824, 0.03914560672015913, 0.01776282487797641, 0.04336703463547653, 0.023346360953104113, 0.03308868959486004, 0.035146160441781246, 0.02689905731277841, 0.057248789141134876, 0.025822359039598418, 0.017709876711089766, 0.06399152349800834, 0.030500047855199348, 0.019706280774346763, 0.023767577161291437, 0.013237661295270008, 0.02794671319274893, 0.11287792285363521, 0.018486241704874465, 0.046275119717803695, 0.014146256895225136, 0.0397209617339315, 0.004223050106497061, 0.034309278332418015, 0.03397592666348623, 0.04029635505210008, 0.06551417687367048, 0.04805171591860633, 0.06022532034905688, 0.03654716288550727, 0.06355362764048962, 0.049331737757329984, 0.05846938553957209, 0.011305434332649794, 0.06937190454693572, 0.07773920878647797, 0.033483186571468274, 0.06921997398979242, 0.07466888926442593, 0.039682684150794824, 0.04855049661390724, 0.09677470871998418, 0.013623320490061758, 0.06557112018908225, 0.0358595913125863, 0.06762993552031056, 0.025870607257069602, 0.06171085293434801, 0.05099741974845529, 0.015146108888720554, 0.04367708574019132, 0.018958860497561195, 0.03739257921434699, 0.1010441933307917, 0.059521802655992016, 0.02802982798687393, 0.019790355093596924, 0.08584228930093589, 0.056666026057134715, 0.015405184502953724, 0.03937167543617468, 0.010789735543151057, 0.04657150764438895, 0.03398812278324077, 0.10909115024391683, 0.023613329188177185, 0.055127208226270256, 0.009499066997499717, 0.07058898843224011, 0.10506604002007555, 0.047531990379455595, 0.03207593668071974, 0.023195248194819978, 0.02140096493906552, 0.034519603941589594, 0.019730106108791886, 0.033695978983756036, 0.054581052653731844, 0.0635409373940239, 0.08476727642118932, 0.04717457588882216, 0.09368512208663649, 0.1178982119346338, 0.045825602306473645, 0.030346458717699976, 0.052144326149455966, 0.0393865337114661, 0.018155197875814575, 0.012946253897802485, 0.0889990465234845, 0.03515682055524761, 0.008994043643225827, 0.014660728028825214, 0.023183165073034265, 0.07181973932611366, 0.028357418674615123, 0.03017214881706863, 0.03752705445813556, 0.0333902869193304, 0.03714542392821562, 0.03865188220515847, 0.043953130201947306, 0.02463870914652944, 0.04547108362819399, 0.05650490627533967, 0.04999183741728625, 0.04328840720136801, 0.04845371672643289, 0.01093867548455995, 0.055396587723085, 0.03491435372721284, 0.014953071011170266, 0.054972604022271214, 0.03931157200807526, 0.013328981848673956, 0.05925856718433, 0.05453671914555373, 0.04573328871159785, 0.030999133070450158, 0.013756651390013436, 0.02023985526794868, 0.024256544270282312, 0.019561959385511377, 0.03072427604497681, 0.040850160012562434, 0.03692178754135966, 0.019569903717286164, 0.05836780611125212, 0.04963304779882874, 0.03649135338022344, 0.016435257707452102, 0.07553440007951952, 0.05471473116607917, 0.05966535987212293, 0.049529327154760404, 0.012355515838510567, 0.04621421955826302, 0.02202523275158338, 0.026523934699775233, 0.03894495680147121, 0.03335368323830828, 0.007082611179700302, 0.027683083185805913, 0.016590633745034857, 0.06780425116660134, 0.060273239148720625, 0.03401837559537061, 0.04348364087843126, 0.020331967764744358, 0.00791077808131494, 0.04134087763246029, 0.06540944499354209, 0.08207845336367046, 0.02782726859403474, 0.04181709703839114, 0.051760834025880026, 0.07163676688627851, 0.056243130201173414, 0.03604340261869854, 0.029517480720495506, 0.0372797919196948, 0.028637002462581284, 0.04418337026671056, 0.057196622383930994, 0.004181228409100685, 0.10232180582299348, 0.06829929718327138, 0.044207885080287536, 0.031059165635416587, 0.03516368470304916, 0.041091516013106996, 0.024420211294425592, 0.029170555888765284, 0.04059317198792293, 0.049331990566345, 0.07688571789091633, 0.07899394589326075, 0.027365794465426477, 0.015771583289719157, 0.02322747942901427, 0.027910919649706736, 0.04685977503897683, 0.046898642509815194, 0.004020503641391594, 0.025607111315513333, 0.041805644023923144, 0.019090656348834598, 0.08742748609473629, 0.017057468573893272, 0.06201743749120544, 0.0067839474931749855, 0.0298943959792415, 0.056372997426097436, 0.11384887034974753, 0.03441348161187864, 0.06007970618684927, 0.05198265095391581, 0.06091268890867792, 0.007825721733106842, 0.018915817847535498, 0.03424665830548733, 0.04384403545109015, 0.03754819082396646, 0.029129972380976525, 0.05830980176406522, 0.062109643833771835, 0.05571524965606871, 0.07616702016563186, 0.018771594134910453, 0.054062721394603296, 0.04429770122853018, 0.020859480587645404, 0.050166628038090084, 0.013719341950491072, 0.018571737117224166, 0.02660614551014958, 0.0544956223588557, 0.021965317015025406, 0.04021072557436363, 0.026734423102630724, 0.03877118507760667, 0.04826670317279716, 0.02291457656200134, 0.0413992611931697, 0.03666039068071592, 0.020374659929544698, 0.06318502060528244, 0.053870988739353996, 0.0329579068948665, 0.027887354785155867, 0.031074529528738033, 0.031216454977590232, 0.04011803276596531, 0.0559058370098712, 0.057158988314650716, 0.04084283621200631, 0.01698598682489847, 0.05807699147431601, 0.02439917260480504, 0.07403116703273789, 0.038795611791072354, 0.021998741431161765, 0.03387813937039145, 0.006905482075507603, 0.06874295402198069, 0.001064345823608399, 0.06930983610331051, 0.03410810364350196, 0.0026632488879840825, 0.010754454321408225, 0.07854945401871398, 0.02039297326137462, 0.0035481304756455846, 0.0816451310510597, 0.02415481162437749, 0.017461859576043584, 0.019828529254863822, 0.03266102484157009, 0.0385428755544126, 0.017169118227977908, 0.060052498574218446, 0.047566816736493385, 0.07642450997786177, 0.019333849045177622, 0.026083658224031813, 0.028100853913553783, 0.02756852239760901, 0.030567678097154827, 0.03279780601001075, 0.06533495060378505, 0.041047270605040174, 0.023175375874064142, 0.029025665679646116, 0.04798320084509831, 0.021144698952294646, 0.04701421070363253, 0.045831731009867885, 0.0482174207366282, 0.0453465560361022, 0.031163688756585605, 0.025142863948619174, 0.02847234910023549, 0.04245562749283929, 0.08161384402023208, 0.04781965256458329, 0.05186524031864059, 0.02939839426788592, 0.018223787642895214, 0.027645939412797173, 0.04299036835530593, 0.05631112433489292, 0.027415067325496388, 0.017695322955748247, 0.04709943415476911, 0.04644225712024397, 0.053638423597740556, 0.03919254109684018, 0.08687410248263229, 0.039815918332146066, 0.034031356955247546, 0.03675856867865209, 0.02054615445705431, 0.027295858298818913, 0.12224846519529821, 0.01397775681388955, 0.02638154193728922, 0.029868132569977356, 0.05581048970681526, 0.08021731936042348, 0.04704467418994154, 0.02936406778321872, 0.026520613708623478, 0.0048084049617060495, 0.028679273279023268, 0.05846597261786942, 0.04954032817735307, 0.04186357942319686, 0.021950701972649946, 0.043909850064665086, 0.012705218696576214, 0.04804372179111646, 0.0662860027965038, 0.046592349066369, 0.035110154309340065, 0.009862179267069986, 0.0273356412447268, 0.06058066257185513, 0.008183127126446175, 0.0721086080997221, 0.06401336083428995, 0.04132775071587774, 0.06499552002717411, 0.06724747378499278, 0.04074147511874476, 0.08342957199220696, 0.19074245596364622, 0.19693673648420842, 0.1600716202970474, 0.14665218070149422, 0.1211553726405386, 0.1483913381854373, 0.20783988368366996, 0.17943004927327558, 0.10884691375277697, 0.10716030223956031, 0.24710486222419048, 0.23322339500150374, 0.14418686379588422, 0.12422006141634719, 0.16179323436752444, 0.1306466887434644, 0.18073106575156414, 0.16811707567784095, 0.09164623270231871, 0.12302202247684041, 0.19225619973674898, 0.093855201266706, 0.17693303164935884, 0.10266752598146278, 0.08901461343010587, 0.19186434576347952, 0.1138648662656065, 0.08593100994344681, 0.1488238101404521, 0.1188369760770471, 0.0900793607316671, 0.13332243468011581, 0.09158210348217719, 0.15045262031978177, 0.41388071712947666, 0.1283055623512595, 0.22188347043289294, 0.1075252588658083, 0.07983209970857828, 0.16091868371492432, 0.10540544761404877, 0.08871113535978141, 0.16684369965186044, 0.11679107698822215, 0.1379268835749357, 0.0961668485955846, 0.12238925683402246, 0.20881280002574767, 0.17893013093740712, 0.11729950656092937, 0.10109414992433402, 0.157139296192796, 0.13592829807631432, 0.14663826854478929, 0.12159774245153512, 0.13778003984160964, 0.11221913320402946, 0.21815075298711178, 0.13925583161894353, 0.13100154066999115, 0.1424022006892389, 0.07755917046339282, 0.16695338812085891, 0.10795498056517494, 0.07872584576327955, 0.13787106640877264, 0.0779873753086694, 0.19184140909102657, 0.13875749142419908, 0.15312039894202065, 0.216917060315609, 0.21210728453532343, 0.09842765832980795, 0.12316931054116258, 0.23089231202198615, 0.11176193959169811, 0.16997350590123286, 0.15067820256996542, 0.09274873281678847, 0.0914093429943727, 0.2216851455910552, 0.16091352028231468, 0.09003398534391197, 0.14485268613263486, 0.13177194933016456, 0.15095476031063065, 0.18901907989094335, 0.17535210196529666, 0.22554328695179957, 0.20406402016599334, 0.16190828545199287, 0.19036756317702033, 0.0785387747530495, 0.11118257793808177, 0.12964171928263482, 0.13225003416019102, 0.1342399168999926, 0.15647839214051926, 0.12436521209536061, 0.14462875863236768, 0.12567758965756626, 0.18637137277232063, 0.11982424124594658, 0.10831083606688247, 0.1381327007566729, 0.10019509977991543, 0.16181718227603745, 0.1428962354698489, 0.15580791198918897, 0.12734122619393373, 0.15401825398927735, 0.118702405072268, 0.09051103595524065, 0.16632773943485754, 0.19019897786840317, 0.07884131819610635, 0.10074691291177466, 0.1385586916078483, 0.13797212872774373, 0.1236808887352386, 0.13101140788245585, 0.14077305343122254, 0.15764457714413443, 0.13792530543381168, 0.15865573659539223, 0.1631760383926092, 0.1528776716440916, 0.15785857614490295, 0.09039115085597, 0.12122278071699605, 0.167594802896342, 0.15187800351169803, 0.1294468724799733, 0.12712698204502945, 0.2167245577419958, 0.12305672625981032, 0.18803772125994006, 0.15697569045568668, 0.14875405017406712, 0.08035483214283183, 0.16734864352451218, 0.15866656907864157, 0.1287373678097802, 0.11542436847042654, 0.29209749713059396, 0.057812909475497665, 0.11821679725882508, 0.21860030870283806, 0.1556789487480156, 0.2067778100289645, 0.1381583647021363, 0.21390365346545176, 0.1507576612094718, 0.11860247656342485, 0.09433541582116196, 0.22918931388806915, 0.22084589627000595, 0.12468694604092068, 0.09617902173270142, 0.12069869230711654, 0.15131151213520957, 0.18188283298044436, 0.131872077021868, 0.10878575695378166, 0.12266900916133197, 0.10133959683439425, 0.10191649168489442, 0.1583359408522806, 0.11660396001271664, 0.1811065101214955, 0.14213013222380994, 0.16534864842411012, 0.14937654257782046, 0.09745589111961665, 0.17481122856899617, 0.13280976864118732], [0.009148706261429095, 0.10114010753891162, 0.017049380600632682, 0.06304474224546744, 0.014430264840954015, 0.036438290300148155, 0.04839160614797185, 0.028918288880959157, 0.00805489071119096, 0.014839554017770195, 0.01937579427425179, 0.04039820261119355, 0.0630707739131345, 0.04015018547614736, 0.0779501510964286, 0.021327477954928915, 0.015533486993292408, 0.026994013910992976, 0.020681397703986977, 0.05046562449405751, 0.015619790628402224, 0.06834070423557874, 0.07550855993383354, 0.01664791796957293, 0.03752161140343355, 0.006172396740200179, 0.09261567866609943, 0.038052885718042814, 0.015616926417175322, 0.04537904965541056, 0.046551991554517905, 0.0737584856969695, 0.053960398860996774, 0.04484400618821383, 0.011365383585554459, 0.042945073406782844, 0.009981493630837049, 0.012866925493243241, 0.00889723598506422, 0.03201000906917597, 0.027919036351264487, 0.06269523378221259, 0.03326303205422817, 0.02019089841914754, 0.04311028026765393, 0.030809501411333203, 0.043330718237426014, 0.023932582924082398, 0.011957925781908055, 0.04454785957932473, 0.030019450256781235, 0.01417264000572745, 0.04407430615937037, 0.08190868061877067, 0.03509282540049284, 0.05222551997811083, 0.06509541023162103, 0.016860691229662588, 0.035966916400338375, 0.12560275818912253, 0.0487367632318168, 0.019504355319264918, 0.07080828110056539, 0.06671666678401732, 0.028992802422914295, 0.007288914827269412, 0.025144095434957457, 0.06875723390088928, 0.0472030935118035, 0.07614306459623961, 0.046342052819748084, 0.03662005232106294, 0.049026616428407936, 0.022486272125294613, 0.07410878706122599, 0.05920128295979193, 0.056326940220089695, 0.07631063866879671, 0.03246707819221962, 0.061668178006525964, 0.038518035153467814, 0.023112003165747852, 0.051735614411412716, 0.02968716919572363, 0.04732603913233165, 0.06440505775953494, 0.10743456937733198, 0.03130747196865419, 0.048608746109229904, 0.066439917521371, 0.030757932202710263, 0.012686453372870964, 0.03378328619404666, 0.022784000705747355, 0.019997752331677946, 0.04876815368451419, 0.004151906872603802, 0.005282089574217436, 0.060743398799170414, 0.02794971625741211, 0.04086707906437017, 0.05076407319715908, 0.031810808971884756, 0.02738118134138565, 0.03716212847540456, 0.0480918359432009, 0.05165088891742691, 0.017743002352935654, 0.016638468275026932, 0.052756445722714554, 0.04345462912873876, 0.04591005966968594, 0.026140174445425792, 0.028246799408788645, 0.09616192265023148, 0.039156638386268774, 0.04566418758082775, 0.03867335181923644, 0.018244897195648764, 0.02200812983867382, 0.03443814581260085, 0.02900387813907958, 0.03756362749564071, 0.016217786413166794, 0.012185713407703707, 0.034424632021616546, 0.023932987035462455, 0.05145023899873899, 0.05591990621460061, 0.05507610633128113, 0.02536534354270947, 0.08624799414387635, 0.027072099337895072, 0.038125844101511666, 0.018426245529084437, 0.041535226477971005, 0.02802865587234978, 0.04068494166037248, 0.14941234952740132, 0.010176452473857471, 0.10877249597181236, 0.02362419039972367, 0.03192187639914694, 0.010748601409666722, 0.011156047187415103, 0.05983047097200348, 0.01860050754922052, 0.05754976976482619, 0.06764637576716562, 0.04199540400276742, 0.03606466155859732, 0.03911443460252016, 0.0207297244454704, 0.0743827401029487, 0.08726997075662499, 0.017403598589402054, 0.021509822202666153, 0.037690219694688436, 0.025510614880570964, 0.020736780115253022, 0.07450601131084465, 0.03998355369173712, 0.025463912245487014, 0.05708899852188845, 0.08824152346219748, 0.031226538609893575, 0.010708746643015936, 0.01770494502007721, 0.0438987034853668, 0.07573739805769536, 0.028719259238231088, 0.019988951896647775, 0.0358993397845376, 0.0136796509351341, 0.10873105061510879, 0.03907602678443636, 0.047066174447536475, 0.05777844701022391, 0.032448948721491525, 0.027868332821995984, 0.03907960824548237, 0.009431806392967701, 0.02462208312335274, 0.027650673836169225, 0.016823177819230387, 0.013962807565657123, 0.05424817595931311, 0.03385374713088236, 0.015243292887574963, 0.04804114007481164, 0.063197327807786, 0.06790505301567816, 0.015450886435686581, 0.04944524900507062, 0.03893156558455479, 0.06014773479452538, 0.016175255126830552, 0.024964074348850597, 0.06246322788478387, 0.017205407812951073, 0.033843021899942434, 0.024010978616593827, 0.033206150025850346, 0.018409311155518217, 0.030134966739663677, 0.03256548601653307, 0.05378995195872361, 0.059430772258389386, 0.022035804764938452, 0.015520454880090491, 0.04272780321057766, 0.08189110656178768, 0.04890734802991633, 0.012974931441638018, 0.015069569044205693, 0.0146061385185608, 0.01832199053868892, 0.048283982285929304, 0.019973904014595097, 0.14018102068333857, 0.03422982735379088, 0.08736397740581343, 0.027972549507995288, 0.023794564523644025, 0.02347472856091636, 0.01603474885585808, 0.007027916811151251, 0.014833542142784404, 0.00971988418079432, 0.0654913091491307, 0.030774332229949297, 0.01960373032958277, 0.048972722142934806, 0.026911439208854592, 0.05600854258743986, 0.08133769996704594, 0.05582454358978618, 0.032938827475112294, 0.02706881282069991, 0.04760125238868979, 0.05223698831433731, 0.038335859445073915, 0.020746183844523567, 0.047018075617210525, 0.027169551467522982, 0.0666996596320983, 0.07594193587259901, 0.06572119681344879, 0.052101310312507615, 0.1325031496103733, 0.06561307116381584, 0.06504321666133982, 0.025224572971403122, 0.058750034189753, 0.06732962139311337, 0.07760402491135944, 0.022291297002905802, 0.01575476382934158, 0.027168714516465704, 0.07001753280600233, 0.06704624546992202, 0.03258436242298734, 0.01806581839768877, 0.01405499954407494, 0.015316681237891318, 0.03391250607467467, 0.08999755020223318, 0.07214648348669853, 0.05895432302608125, 0.031704071856614564, 0.012562285842103584, 0.03255278810918812, 0.0063787204975773015, 0.036345007604048137, 0.0892638371536328, 0.026425996104315407, 0.08704998860916785, 0.04413958451139831, 0.014867810213247375, 0.04883749996342006, 0.032410418329339837, 0.057596692650188366, 0.045636761633138505, 0.05805950934788393, 0.037427332793031974, 0.048313587753763126, 0.06953999955928133, 0.05897473160838408, 0.019515247174328374, 0.024315305129294435, 0.038752147792688305, 0.07442208637873973, 0.07830735491288286, 0.010311083808060615, 0.0342598963048189, 0.08383968950159128, 0.037978510071914044, 0.0241512167567928, 0.06431334937411932, 0.022274724605883804, 0.02516022158576356, 0.08861205720853421, 0.01270778604873246, 0.0737517900885113, 0.04186977324406466, 0.07121335775140794, 0.11652537471344394, 0.00673328657754727, 0.06040156653691685, 0.053476154684059085, 0.0366269356210626, 0.04398103878502885, 0.018936553932425958, 0.061464839119223826, 0.08962002973402701, 0.03915239808960788, 0.1158073281628951, 0.09189704222784889, 0.047000658608252005, 0.08102324385676654, 0.027418800088907444, 0.0660130839734789, 0.017818190052264163, 0.06698950899824982, 0.12123652433435764, 0.02970655122020793, 0.025204078204208807, 0.04194987539742743, 0.06057286379678596, 0.03996696788817644, 0.054102259192375414, 0.023967376722383405, 0.042968186279458385, 0.024385741168272593, 0.07773533238158112, 0.024691019545219118, 0.04457476075678583, 0.027200545469719558, 0.024468719981791034, 0.03201219241976017, 0.08842543819017949, 0.03224651381794003, 0.02485064354034201, 0.05855814831691885, 0.03444586414843798, 0.04932217314959534, 0.0207909329554006, 0.010868495127426521, 0.05972041095036173, 0.0390357650335758, 0.02572818193584681, 0.021751427181786107, 0.11056257532008233, 0.22706340457643234, 0.14483387101321452, 0.131123609119846, 0.15090010759811248, 0.10767635438711413, 0.16674594683272226, 0.1049876232601462, 0.10209269956835818, 0.0913529129578702, 0.09793826604201909, 0.12882116250693798, 0.17366968095302585, 0.11403060938802459, 0.1792565763237015, 0.11277928137250486, 0.06632119687574525, 0.08881967469689347, 0.18016799112721799, 0.19413553598907687, 0.11182950088574041, 0.1492539225446601, 0.1471348467373079, 0.14381448377764997, 0.15880326980785017, 0.14173679203996736, 0.16840040563575684, 0.09074130666352088, 0.10920748835609806, 0.20972573168335423, 0.1192551834749118, 0.169497964483115, 0.13915391128149726, 0.19517369237878632, 0.10183780679419156, 0.20701368850085045, 0.13510729696962143, 0.0920833548110339, 0.13425583620705914, 0.1641038321559468, 0.11270871701379938, 0.1249348444323386, 0.0900315032190373, 0.16112002694318373, 0.12648824091640212, 0.15735361695049271, 0.15006113406871596, 0.15406512324848484, 0.14245700661934194, 0.15536940326133084, 0.09931427486721547, 0.09242231807401104, 0.11303116342112904, 0.29012194023497645, 0.1566648732630476, 0.12911356294587736, 0.15353545005763733, 0.1867556577968982, 0.204434362390349, 0.18817593884323874, 0.12863656596070336, 0.09646400644053375, 0.1097756804477784, 0.13921712885700888, 0.2238853654313472, 0.07516081730324416, 0.08343635187033685, 0.17247919564045247, 0.14113692987349727, 0.1636368249573054, 0.17970222499101393, 0.1785957029149417, 0.23656487134435486, 0.1553576055072969, 0.15875961811792466, 0.17863590720920794, 0.19187232839965052, 0.19079068885935893, 0.16475885265296505, 0.16964347522345283, 0.14856988263707008, 0.12701036048031625, 0.11214132931443954, 0.1635861559019935, 0.1761982154341475, 0.11939045928058126, 0.21255633463301968, 0.0926802292345993, 0.16003929138664277, 0.18334031525638797, 0.09902072529638968, 0.11667064796652525, 0.13392753688798797, 0.19833691538341586, 0.10224476802132784, 0.11969744603359893, 0.10638092268979359, 0.12076695840204917, 0.20201453578568276, 0.07226674396905207, 0.15037762031199473, 0.13827982028165173, 0.14404533671275263, 0.11895890663107557, 0.22051073280313324, 0.19722884580973657, 0.15252658887015236, 0.24215291584691695, 0.11483425860323253, 0.16711356178406747, 0.18303050929980894, 0.15015505644823277, 0.1251638051302683, 0.1404944425749202, 0.2532236524406941, 0.2331172765022324, 0.1888415466753706, 0.09716572765741618, 0.14176144474937072, 0.19646548515846654, 0.13054951815114868, 0.1221051071620276, 0.19358573000757925, 0.10840728653654938, 0.13180357343967886, 0.24075442234114294, 0.14947815648009702, 0.25485229408068044, 0.18660732785299902, 0.22595461488010424, 0.15890146695798443, 0.1274087491835798, 0.13847762418370094, 0.13549271580432692, 0.16802422582141815, 0.12901224015701201, 0.1158017433819271, 0.151911037222993, 0.26898710657992675, 0.11460429433012202, 0.2710644918824396, 0.12229988501677591, 0.19367605177385194, 0.1343468168089467, 0.1744432458954473, 0.13904904916642175, 0.12275161642220714, 0.11550020351405106, 0.2696369942878523, 0.15682919912280577, 0.09176483843475582, 0.17671155563044935, 0.12665794471338873, 0.1603852873367648, 0.152654234440096, 0.10498204614005743, 0.11609982819326463, 0.08393104548656172, 0.16066507796847052, 0.08139802939108304, 0.14823291120269608, 0.13173157649655498, 0.23363650025379276, 0.15514060344186523, 0.14017792568812448, 0.10598792724551694, 0.12601754883484495, 0.09984551853830777, 0.13026854774403956, 0.15282226816540764, 0.1360658721457566, 0.06133618231322016, 0.17548647378721546, 0.10871416603725766, 0.1632371262436913, 0.09253401369337114], [0.03032901681088392, 0.03968979727717177, 0.0536104575580647, 0.09096299718704917, 0.024387742572974776, 0.0414794935814796, 0.01940624818446175, 0.01835094866222672, 0.034817792174796906, 0.03101172947114514, 0.044399077643550215, 0.03758474853971312, 0.03179598517054993, 0.06890662870700322, 0.031123191433688326, 0.03458292110853138, 0.035782714389384754, 0.026679025369606195, 0.021052450474892414, 0.018624150937783624, 0.028130327231220664, 0.0495118411978887, 0.05955868978954612, 0.003985130728500325, 0.019927764454135494, 0.005766568844386887, 0.07002391431841158, 0.046574257900037115, 0.07864773543851991, 0.015051380201663463, 0.05323082651762713, 0.05735491913172507, 0.034438670582828984, 0.02855978271503362, 0.07616822292367298, 0.050484071891274185, 0.07977316456456339, 0.0661725681575556, 0.03570119114292245, 0.016935350328323343, 0.06664442469275768, 0.03809407443529175, 0.13162760304347162, 0.05502469034024304, 0.006016186624389863, 0.047171932885483395, 0.01113872402422731, 0.03037654299048647, 0.07367181050921641, 0.09930452256793938, 0.040384738615924315, 0.028892389363459045, 0.02801265421083137, 0.035623444709926844, 0.05031617606178888, 0.03190214005899766, 0.0312314473182684, 0.038174915863501455, 0.0694307477603997, 0.02337511223290236, 0.022416244028136138, 0.05675133377794297, 0.027841153937662323, 0.008743192940469711, 0.022378759346001094, 0.05779410201695658, 0.05581307142312008, 0.021133355105355866, 0.08418732487987127, 0.04333600424410355, 0.07615615703886555, 0.01945391034467086, 0.05416517799359657, 0.04062242505531158, 0.06662275972625901, 0.05103023512469185, 0.11855208329976567, 0.04497598781580887, 0.012024312088596485, 0.052159299337936026, 0.05724394746545342, 0.02590777784315569, 0.014288634335952661, 0.023907439918407512, 0.05202648650494315, 0.04924177988282135, 0.04391885925865462, 0.004366076327935463, 0.008053211063416976, 0.002739838767616499, 0.07496122075545211, 0.018330858006412466, 0.042245796010378873, 0.036679416474315434, 0.01179856034145961, 0.024942150827677503, 0.067827494274224, 0.01781794298890858, 0.0349625789620463, 0.04578440592834546, 0.02194656509785883, 0.03977916909441833, 0.00796587129438957, 0.04687330798215924, 0.09096715704447801, 0.011460605441712806, 0.03154370858664474, 0.036198531592925715, 0.04846291361196388, 0.04814636991209081, 0.03230759783858254, 0.07437098831419023, 0.038570535158918756, 0.038842722367975986, 0.01308420718076729, 0.011033454924942026, 0.022554867638034687, 0.04176253242598426, 0.05845325555832637, 0.05971526283951056, 0.051137632990796725, 0.05989820846626836, 0.04824314213868591, 0.07576341440360393, 0.03646986461394737, 0.049881264116735234, 0.00532709293052434, 0.016416218507313923, 0.03929976276272247, 0.035302036351734595, 0.005787248909097886, 0.08686196764991169, 0.08369849949714639, 0.11537509369513682, 0.021687506720603957, 0.04302373148440834, 0.045693593865801255, 0.07592180308194892, 0.05901588968211605, 0.03210738650523126, 0.013769351212578195, 0.07382665220047198, 0.12740116491312944, 0.026296398925384688, 0.010853141767814035, 0.0375772447084948, 0.024540699687936617, 0.02559604709066691, 0.028509636514730034, 0.042575677301013665, 0.05037371692578158, 0.02019696200506822, 0.010997170128018386, 0.012491278110011932, 0.020952445357256842, 0.024798903877155918, 0.03826643655737562, 0.05082774276454603, 0.025053685568573496, 0.030507170557675344, 0.05314277237161033, 0.023376713356664105, 0.046223512204784545, 0.025984216181020585, 0.06463137545412587, 0.01477256728967111, 0.06580326781277696, 0.06872945555275486, 0.010104989877060778, 0.02260455993124314, 0.09112998903278383, 0.035174417594868335, 0.02814217861140928, 0.09338292338314558, 0.01907438464132288, 0.10572767951675963, 0.027579462133167733, 0.034813241612526684, 0.04002538592284245, 0.061899988551533995, 0.031123432751384475, 0.03723697909604638, 0.016152971544333043, 0.037889111441590136, 0.013871389336042829, 0.03678981357464387, 0.04118547286658038, 0.023003934972709226, 0.03705540859711267, 0.03620670958151741, 0.047420769734608556, 0.032825660966937585, 0.023043696851199193, 0.05715994209411645, 0.031244507202157573, 0.045649949836754994, 0.08840168180364756, 0.03851807728830365, 0.06076254333639818, 0.0053838289233915995, 0.060499970530790675, 0.020335204486224442, 0.015562041963060057, 0.03140389371002394, 0.03273041708575141, 0.039725948966318564, 0.05268578943345816, 0.07040198636992324, 0.03473468695677096, 0.049217356999795285, 0.1089618192805398, 0.08155925259474786, 0.0937673079991533, 0.03695523877057337, 0.0857991049246442, 0.039061436639918436, 0.030305109121986938, 0.02131544654407809, 0.0409009822854592, 0.05296187986048961, 0.04801676698750065, 0.05473958688878244, 0.10762797593469582, 0.03350550271270256, 0.04379410184018555, 0.08906222579459991, 0.07960070285104937, 0.027232690519022367, 0.04860649764117214, 0.05153062843507336, 0.0181841425928137, 0.012142669800068102, 0.054465760251567255, 0.12400363391685872, 0.07018975703225983, 0.03471988613807386, 0.016361439390288248, 0.07475646843592967, 0.03867070881589767, 0.047523023320301894, 0.047736566498755455, 0.10624978375891525, 0.0263776368040952, 0.05999391583064872, 0.042605976078418956, 0.01986105160246934, 0.023802208165908535, 0.03461843694470102, 0.012478471035137774, 0.02816691367526449, 0.03137873346737075, 0.07775901982019987, 0.080041624755869, 0.07366628701528234, 0.047646949533373124, 0.037185222195881995, 0.017627010895540158, 0.06344824075518597, 0.06687629652479965, 0.05499042322738998, 0.055150248320592996, 0.08006457675008044, 0.0351760761752244, 0.04890370528183637, 0.028466754743168433, 0.04853547746015172, 0.03354673356478734, 0.00707135686928767, 0.02138700873230494, 0.056011664395731305, 0.09854695354137691, 0.035594904104307774, 0.07168575820903625, 0.022705352204220913, 0.025341058555509777, 0.05055452899767026, 0.004051502431637698, 0.06343679540159722, 0.019681744893351873, 0.040447500369120995, 0.028376846664374875, 0.02271490915107631, 0.032996421965259704, 0.01503811443164464, 0.010281940865811082, 0.00797287285921254, 0.03843308749398397, 0.026744776780927376, 0.03472945074580851, 0.02133251881347068, 0.05207236368028868, 0.03960354343777703, 0.020994294825340473, 0.030405533672761054, 0.03590154994819914, 0.023198758792732994, 0.11872482080493243, 0.07701807490159428, 0.046872216306867144, 0.03400162508290622, 0.039159664433569684, 0.09620258659725228, 0.031871594218236786, 0.044781363178645416, 0.010489737427222633, 0.02733425654080366, 0.06176759323645985, 0.03382371265381094, 0.0548078759663528, 0.044259933093863155, 0.03453165833507815, 0.02299014539007218, 0.03625894911707409, 0.06165218975154623, 0.0818222965444288, 0.05126908218728439, 0.03636912405190449, 0.07997695161330123, 0.02467968144393977, 0.013217963259516945, 0.03643806813465011, 0.02842271426362136, 0.04686352503936618, 0.05078549301552196, 0.021683699263620283, 0.018317453382957368, 0.060851972610239065, 0.00870949369029052, 0.08406776919840805, 0.036912889430119146, 0.0035507586360308194, 0.028470451117403088, 0.04932546732766975, 0.02837597906980063, 0.021319719399475766, 0.027605606798803615, 0.028712714932137923, 0.0628263344086947, 0.03912150559406127, 0.014878317109128882, 0.07008675651084031, 0.01482686377130449, 0.019609726882810076, 0.07276790336735788, 0.048979525003702416, 0.017058791990782467, 0.04310454226910107, 0.03526206188384564, 0.061086292093199115, 0.16843497152290038, 0.01250967762673334, 0.005680616173307382, 0.0963436387058708, 0.1311980269008106, 0.12822696173022832, 0.18060703611662313, 0.13782513177683278, 0.12337603170665042, 0.0920150044464296, 0.11265529004196007, 0.13552391090460364, 0.138262506694563, 0.19605775784340598, 0.15287837644498195, 0.09746211941444105, 0.16224594636549874, 0.08671624240495505, 0.11414949091211443, 0.08905101026738844, 0.11529106151072249, 0.12011562278794667, 0.15636108875755342, 0.16666722363762318, 0.21750048223522403, 0.15395089953897462, 0.08027109873270796, 0.10988937555662087, 0.09397256593670576, 0.1327077716949486, 0.15714881100481556, 0.1464366188813602, 0.12362008433668845, 0.19415747674722827, 0.1680825557559729, 0.10262782730522657, 0.15271112412935303, 0.17726223495218063, 0.14705469861866968, 0.1669306199877493, 0.15441200786059903, 0.10172281699675707, 0.144000735073801, 0.15249775332068244, 0.077992316575781, 0.3470784630025587, 0.11038435262537773, 0.16514353604326326, 0.15696196216008357, 0.18235558583851785, 0.12697270725883786, 0.12189531398396339, 0.14954236996991022, 0.15587612445796692, 0.18448151047191313, 0.15738470479846, 0.23359646449886987, 0.1540778249862694, 0.16753858736445829, 0.11170940894273021, 0.2119329076019987, 0.15362603229380425, 0.1962672675689382, 0.20204957664733936, 0.16215076760178612, 0.17089435890797647, 0.13033767951832664, 0.07593302627003963, 0.33729496862619157, 0.11493873001346666, 0.1586292759184876, 0.25535311640029956, 0.10187673172162426, 0.21904221886108, 0.10279538605602519, 0.12131771433257288, 0.1138511915961581, 0.09161896763309356, 0.17272291885268304, 0.18284683205908348, 0.3034491122009293, 0.0939271292619167, 0.15592506215456994, 0.20802187553096205, 0.20930899517430415, 0.12435203538306298, 0.08416054244603842, 0.12616670615370237, 0.15664463322008812, 0.1186055638977597, 0.13276456945365475, 0.15339666556927467, 0.18818022893561473, 0.32872082064709357, 0.13480800173936353, 0.10864154090203586, 0.08237299118791858, 0.15624372408755366, 0.18885939652400632, 0.23160068288205132, 0.13394883413228298, 0.1546383102334315, 0.11489741489171021, 0.13590752177180784, 0.1813566378287731, 0.13474107629829837, 0.15872629329321847, 0.12713840441598048, 0.12488563094408282, 0.1292839868655128, 0.13904261402785778, 0.1576333156516475, 0.19083453973214473, 0.1002712642413474, 0.20238481672300448, 0.08217042221898034, 0.10887575696312612, 0.22946046304798898, 0.10214901469167202, 0.07739669853641142, 0.11316807865495644, 0.13477505995861946, 0.15393853487987674, 0.18317879327843267, 0.11250820116049821, 0.1752224952102669, 0.1210034037789991, 0.2003997450153674, 0.17826380298262645, 0.14121013723554152, 0.19708532689800187, 0.1598798838113585, 0.1846904532923814, 0.1261190171804159, 0.2006587133772912, 0.21863777040233537, 0.1899849329023592, 0.09993574071315028, 0.14711114397693068, 0.16628637068694638, 0.2047696637530481, 0.21972248961608257, 0.13940207780368868, 0.08327019506043966, 0.14911277850549068, 0.19128518329272348, 0.13434974326481744, 0.169996764330614, 0.13980412074635107, 0.26300236642841374, 0.1628961098650771, 0.11933137857986074, 0.15646913779839394, 0.17606848610504983, 0.09430289538877626, 0.27493406327501424, 0.18147450811680288, 0.10150960706655057, 0.08873455466762667, 0.1655304104450249, 0.1935842131534892, 0.09610108760816437, 0.1544894287062268, 0.20299394855335837, 0.10586788892866143, 0.12669681601466673, 0.08470068039793162, 0.14592900902273195, 0.10973147717454743, 0.11953419269693476, 0.1509030646975002, 0.10907862470635485, 0.07988917325893719, 0.1837447790368911, 0.12132255600825434, 0.15612254429969097, 0.2244792980772834, 0.11123137773885844, 0.21185372475414507], [0.03041467693213734, 0.03152908396817023, 0.06953448372622652, 0.08502924784777627, 0.0631696030858063, 0.02304042948620214, 0.05524513214045475, 0.016896482857484973, 0.03419988480727038, 0.044803901485377745, 0.03973132690354701, 0.04404449767823662, 0.03702400665309641, 0.03123273243076138, 0.03968388307839632, 0.03240607461080917, 0.03062588545764166, 0.0059516087640076884, 0.027173558107366966, 0.06976273962326589, 0.02310806930425667, 0.008968061771273853, 0.041334093923890786, 0.004451914564631279, 0.0358965665462517, 0.016369881679213816, 0.033335297128125545, 0.034204642213280165, 0.10961196745835966, 0.0830852537746391, 0.01770363117928707, 0.06549400577862417, 0.01647625490271997, 0.031655390799466165, 0.033778881188482046, 0.08147744972619318, 0.04205575257900261, 0.04304291432603233, 0.02265694693872525, 0.05083442688168538, 0.01225036644046345, 0.0015121762853889398, 0.02509184823852153, 0.06721387316863384, 0.01683793650309165, 0.03827188727295688, 0.04629912891335065, 0.02559789910822386, 0.05224389842741432, 0.04325067354065757, 0.01948412293718467, 0.04183537972670409, 0.037166977811965256, 0.016810146663638375, 0.010218130529768044, 0.04464194283730561, 0.08172768468578016, 0.03172039719028098, 0.08416991936223162, 0.05619005179933964, 0.0807564230936189, 0.0671940544740327, 0.11215945495472801, 0.05561355148412048, 0.07893383097384246, 0.04858177215341599, 0.006444845376761571, 0.03397248692870621, 0.0348863723657785, 0.023483042530114615, 0.03842744142598203, 0.004130564620643254, 0.048026975109091694, 0.06264914593268787, 0.03513721253482565, 0.008627249363569484, 0.022258416509195682, 0.027409541916342515, 0.0459912879722974, 0.059641036580527024, 0.07977839694508622, 0.016513061597042026, 0.03038053239335216, 0.023220320337361867, 0.004053197401170169, 0.039371192800782384, 0.0029168915024192464, 0.035733895436409986, 0.03776528481994906, 0.06581296648589835, 0.029543826484211513, 0.05830698639094349, 0.061573010734132225, 0.036161529546182965, 0.04438209347426892, 0.01880484809648366, 0.0487901518992599, 0.08807733549826569, 0.046510335523635156, 0.08622726380464532, 0.056374253810293255, 0.038560426628757874, 0.06637152885237048, 0.03330626622623494, 0.01925353430241587, 0.0317869242656255, 0.04893073286380499, 0.05117317947048334, 0.0910929716642826, 0.079385225300587, 0.02092720084493199, 0.05039153613090035, 0.048792036475553635, 0.12610058510495772, 0.023628691166278817, 0.01880297118106917, 0.02685106956520148, 0.05807699530475563, 0.03886556327943841, 0.0451730601038904, 0.011862878210752482, 0.05153625152043758, 0.05206132052286018, 0.017893343277636076, 0.08010432905247135, 0.01767858393460272, 0.047737700308883385, 0.051331529844432115, 0.003995042469825656, 0.0632802798082271, 0.02124000029007514, 0.061505955058119954, 0.03500361829215, 0.02005875208264878, 0.04534538775201767, 0.02722300142200003, 0.017434910518087206, 0.05601687379361642, 0.017592284129932523, 0.04669431153865111, 0.015207793330773713, 0.013975492066463396, 0.037511303690412355, 0.05744386193973403, 0.0899827340617776, 0.04824805276228055, 0.03878281429229725, 0.04602604155098239, 0.03432852629151556, 0.05552124555012392, 0.06211413693944774, 0.01832627871584508, 0.06967734380234634, 0.03993638565823917, 0.044147708873835304, 0.04939372193128352, 0.020706956312360785, 0.007224832051208304, 0.04462403553207556, 0.03192785380017613, 0.03988040378317237, 0.08160534044427258, 0.035986773399335724, 0.04327027390020029, 0.025298333831972657, 0.030228385416370247, 0.009875288946674237, 0.03625639804428624, 0.01751863626733182, 0.041641819951755386, 0.011421566558701378, 0.08551183727479751, 0.06400782584903703, 0.030688289064733736, 0.01741790336616818, 0.06522435815103593, 0.06828689421977728, 0.004545497950241571, 0.07126050280226816, 0.045416683724690834, 0.021570785564460584, 0.02198797023494638, 0.01000207745575256, 0.03204760866449966, 0.06397962232210463, 0.037818991413880745, 0.02429737484142665, 0.014930776894963799, 0.019956236111841375, 0.019481439714229876, 0.016673564678058028, 0.031079723604864655, 0.02414386614315933, 0.030614233260313352, 0.0519437758221982, 0.04927404750619204, 0.00994183708943667, 0.014673698854993188, 0.07089516313205804, 0.13054582560735364, 0.026257332271686005, 0.09431495361270444, 0.015296339688281861, 0.04379564933779259, 0.03377133522242789, 0.06435216704924261, 0.03625777317211032, 0.05121775812679722, 0.049323578920936396, 0.12318917520103917, 0.025073816444003777, 0.08431370640473981, 0.04793448148355369, 0.048226889583372304, 0.019575771950786153, 0.03413788531155836, 0.021100639320549466, 0.016901567766082384, 0.0566819874990371, 0.02909472276036057, 0.0376692020724858, 0.066152450688664, 0.03847621441368134, 0.036321699378951904, 0.06310627825798527, 0.03645248973982469, 0.03306412498556799, 0.029040707816039363, 0.0391291358297871, 0.051676384323546966, 0.0234033080989555, 0.09024397770483648, 0.03091668285759947, 0.017646477189696124, 0.03036629464927941, 0.012763169417608411, 0.03899893535661601, 0.010090148838747655, 0.03506876257879119, 0.06384641112339112, 0.0550125133726866, 0.05150481893290436, 0.038468262421027306, 0.09507328872719119, 0.05227861370170309, 0.026172742758306767, 0.017347011504875078, 0.02029575478856362, 0.03786289208238164, 0.06009205552418867, 0.03427639017782865, 0.019158196575458974, 0.026074310036135778, 0.01975396017153417, 0.08709903355808028, 0.0731763584659465, 0.057574296069722024, 0.037170942316973404, 0.05029403995121679, 0.0300369477049718, 0.05377328954637051, 0.03317387091116079, 0.08762049428637951, 0.039067032912205306, 0.06325683751774412, 0.03922140345938745, 0.021865476606293552, 0.0623779891118888, 0.06857102090913443, 0.03289604529498085, 0.09112650333272834, 0.033947428192702994, 0.01453963059541439, 0.055841470302473155, 0.04134854617258234, 0.011987710322794175, 0.055758368914886836, 0.02292167245139999, 0.07121020913003914, 0.008306148398156849, 0.02634004870009038, 0.004877090968582179, 0.024843628090175412, 0.03635859034294563, 0.024421199547847914, 0.04963497067951868, 0.04406823108213083, 0.0612134856712674, 0.022699233076925722, 0.02346331576606439, 0.021168351916956808, 0.013687107843467066, 0.012152112791344765, 0.02316561016824938, 0.05618568892861086, 0.01828788430429995, 0.05972614128803534, 0.010693177821174746, 0.029744484063778675, 0.044017554365939675, 0.05823161100007354, 0.047054035784376246, 0.06452404653593417, 0.046407040058364796, 0.02602525551112429, 0.08795303773255118, 0.06015275267042941, 0.05885509931812844, 0.013057293554377413, 0.004645061130905825, 0.011702590591965184, 0.0188440679677672, 0.04033615715020607, 0.11621920767450526, 0.031732980184437286, 0.02766702023725356, 0.01858073673511465, 0.01970457048305581, 0.06981174626778211, 0.09475890922570422, 0.042727293762108015, 0.02392103606384368, 0.02886648984595893, 0.07635543949060863, 0.04927404367575242, 0.01208100259499324, 0.03745696890438276, 0.02695658093979282, 0.007996073353194423, 0.04569970341699739, 0.01819648426927386, 0.013342274431770128, 0.06887439172714949, 0.021589066337553725, 0.035733700083989295, 0.08450758793661672, 0.03724106617512242, 0.03686376021153504, 0.048267591834789327, 0.04021095157030129, 0.021740895388047063, 0.044999433936731476, 0.10635017192051296, 0.08176775874509927, 0.040834462870993925, 0.027162840537306283, 0.05015929657665472, 0.026598023062932397, 0.046525519386294394, 0.044612191812766176, 0.011441378550033176, 0.10491308290511371, 0.11352717470858367, 0.14073508611369517, 0.23111279212659408, 0.2364826547883211, 0.16095473581264097, 0.12078236443020644, 0.11315012921489055, 0.10859837184750265, 0.18038556009771364, 0.11212633697376137, 0.16365004763487848, 0.1121535637385903, 0.13113997275790862, 0.18145022312960318, 0.11202083134482946, 0.1831154224853362, 0.1296389613661074, 0.09907985962326489, 0.1165155381444962, 0.128077965289835, 0.10162792934645569, 0.1592361707721026, 0.08813452396181323, 0.17032271942063687, 0.13792426355423468, 0.11929037755415325, 0.10027694861374556, 0.10024079692459877, 0.1971534474362289, 0.19168289017773446, 0.09995074071470769, 0.142109279310511, 0.120812387415959, 0.2213871373885101, 0.12840466348514443, 0.1465199845692804, 0.12330217316987054, 0.11436332903441884, 0.2216513917571114, 0.12952079996466637, 0.12093038793893592, 0.06581815290114572, 0.19868167027110056, 0.17639989574109355, 0.1296561983444037, 0.14541412132882303, 0.12481144298949551, 0.08729360456908904, 0.07830257452423535, 0.10462095059694783, 0.14574078121973624, 0.08900150566572144, 0.1593919317688673, 0.15238691571979754, 0.13324493722569558, 0.14185043352265514, 0.1621788064198148, 0.06561594399353189, 0.15947181941761127, 0.10557420146200927, 0.18290424268812905, 0.1296149215270435, 0.2140807423500284, 0.22957818011843392, 0.1948596269733483, 0.13696476907259034, 0.15730449539278785, 0.2216663304716349, 0.08494311658244941, 0.1031359734254018, 0.21680988461500217, 0.09773866949422706, 0.24649749239606245, 0.12561182100926677, 0.14686987224605777, 0.08402872169690748, 0.11955300015547585, 0.16159186049574809, 0.29447016336264153, 0.14227492284149895, 0.14881086325453174, 0.10493008239615349, 0.16864507879701354, 0.08410243467698175, 0.08734735329785655, 0.1419580995195335, 0.27254812840011816, 0.10080263048650757, 0.1477053217710026, 0.2598148277930675, 0.19961436699715354, 0.12744138452915416, 0.21223797913520567, 0.08644739150880806, 0.29439922362085313, 0.14781001534673477, 0.12823053169995546, 0.1644282244266041, 0.14624328893278876, 0.21029343347876303, 0.16709931254867585, 0.10188562600242515, 0.14806308483164157, 0.1390953974858407, 0.1366502899796732, 0.12699396619873662, 0.10883452611104136, 0.1525017216561302, 0.1736890782992686, 0.28375060147335457, 0.1589790103776801, 0.21277974119349835, 0.11340906693329735, 0.21841934341336453, 0.13844494287285114, 0.170039895080751, 0.12765483960749643, 0.1634154561907053, 0.12455613652784979, 0.14470797212373826, 0.18032847122559625, 0.13546113766008808, 0.18181629058334137, 0.11594745330512525, 0.24257038780037435, 0.09694136348703215, 0.15880326980785017, 0.14416031118842865, 0.10880504704771504, 0.17712962513248767, 0.2591283823693952, 0.1530116297785313, 0.10120553144764516, 0.10315660417320267, 0.09145998906704689, 0.11684478741259345, 0.14543957076966763, 0.16700805615513556, 0.08181324138516381, 0.18785500928999918, 0.10623378784305627, 0.07854046780736217, 0.23286636738527208, 0.26180803535446046, 0.2359177109094397, 0.1516692445523316, 0.17074232109852377, 0.15307011293067088, 0.12854776104852078, 0.1610376418478066, 0.2400229156257645, 0.19557089364576727, 0.1585735660046339, 0.16905901142426077, 0.135071030367286, 0.1586301186152043, 0.1238531512658923, 0.2765285986806116, 0.14606572507369905, 0.18550341047586935, 0.15268012821193666, 0.17379197922925796, 0.1450848567389673, 0.14313542344156774, 0.07996772025381366, 0.1349495594660121, 0.16963952220976355, 0.1929252549645401, 0.11149909482487749, 0.15407134388243, 0.15642933186984834, 0.13919943222595801, 0.23506925321154057, 0.12731866490456367, 0.1026807716416736, 0.19003569388822203], [0.004102750840942346, 0.029562157053019733, 0.03610358265559039, 0.05115039601561524, 0.026491818378769585, 0.08931837495296233, 0.01656343570850309, 0.05039650038064969, 0.07673027099020059, 0.05126456992941038, 0.04271630423083421, 0.01572295490111555, 0.0319593993856782, 0.04374676526734426, 0.02628100438854627, 0.0917347694837278, 0.022638876839811285, 0.008197186755076533, 0.08565959265275348, 0.03862086713554398, 0.012902080310478568, 0.026593619972587596, 0.05980271177606718, 0.017939099794133537, 0.056917521231357134, 0.060221317539652514, 0.07225007389581974, 0.07262400141166103, 0.022631689019861723, 0.001217737334363553, 0.0957891442662766, 0.02277300734403393, 0.02770736434256598, 0.006339606920993257, 0.020884388021283576, 0.0291438558093843, 0.047769324418397686, 0.03175813851187066, 0.06248016608878971, 0.07757299068954683, 0.021897602503398256, 0.019157677550890276, 0.07097003290489798, 0.015467253904188833, 0.0599903688435593, 0.03525175417082445, 0.03023507910960865, 0.0038217979102140114, 0.020217629142045494, 0.036306071185296586, 0.03048841481006915, 0.026120108687469078, 0.10355327683951586, 0.028486475761559223, 0.17117430275726706, 0.010568734498754626, 0.05905421323052818, 0.07409074569060918, 0.017029941119554064, 0.020330743939285318, 0.0156413703676193, 0.017549863926345305, 0.07367134319558259, 0.0803158306066067, 0.04474623421687753, 0.03124370089461727, 0.02730735153290293, 0.04034484075682779, 0.039822430079502445, 0.041321794382266464, 0.06529829329660823, 0.05691624952540283, 0.022546819884390123, 0.021039798532822923, 0.0489545198938539, 0.027635149064383684, 0.09010654153122057, 0.05845085387268375, 0.09374562005001692, 0.04433651890365347, 0.01568994896050783, 0.0439603237675563, 0.03495495255676008, 0.04132470168593911, 0.023367344101350156, 0.031340632084456664, 0.0037475448381531266, 0.035854155918763536, 0.06253595261143581, 0.010389573346342771, 0.005339383374854562, 0.04000712238672761, 0.058483991005848494, 0.03410824153932833, 0.041434106702405604, 0.02651318840141739, 0.0016157564002036628, 0.07426411138787385, 0.07759932113150436, 0.10169511525741509, 0.03363553464653031, 0.017278008050315322, 0.016539625695816452, 0.07045962682534611, 0.011853217842027306, 0.05098276065602418, 0.04995244900665937, 0.01942804530112734, 0.06264634205088501, 0.033977198369440534, 0.08438430140696226, 0.024015506196226326, 0.021283611760384614, 0.043154039209888834, 0.04190379137834234, 0.03159065253942484, 0.025105036442138018, 0.03726116832225554, 0.10811045810940767, 0.08177433944036884, 0.025719377670377016, 0.025279465086397626, 0.010685086017474534, 0.023808786945958293, 0.0466279836461669, 0.04950634451703199, 0.005236766376202145, 0.05159638176161436, 0.025866763410909523, 0.04326657752596563, 0.07503210687108579, 0.018216844971081423, 0.05590221724442898, 0.03678327501421014, 0.05613533779978753, 0.025286229642769022, 0.02293169479666939, 0.04585021288104115, 0.044019362333440976, 0.02502586508560325, 0.1068434789175949, 0.02174454579700626, 0.052399464071758335, 0.03840473841034597, 0.08661911777791478, 0.1096799654225188, 0.029285528449221488, 0.05066655786527742, 0.037027243374576496, 0.017705525331679853, 0.024796680306955695, 0.04769189208145103, 0.01712954212580958, 0.02991716794279074, 0.0175172898678049, 0.013339004193943356, 0.05859659060895924, 0.06834691720864466, 0.02430412024559994, 0.014422668121574868, 0.08981905171587583, 0.043682984617208286, 0.009778741758406885, 0.08219345848286345, 0.021460867269084822, 0.04438807662095755, 0.06927835755050182, 0.010362723879816552, 0.050533856115033554, 0.021689420025194847, 0.04289333565881656, 0.056663969111058025, 0.07584642769107897, 0.04344160563402599, 0.020142929823768717, 0.037192251052587263, 0.04472097246757439, 0.04117961612439925, 0.062155961509673834, 0.11257293559009991, 0.04209850411561709, 0.07506524017381092, 0.01359339135007993, 0.05746588313711747, 0.037683060603036035, 0.06393513559634167, 0.026534793996101907, 0.021605728749906825, 0.015158427582542985, 0.008020971210733538, 0.025964062322952577, 0.11893027792534522, 0.03432368078539449, 0.047060777358109915, 0.05331775068395561, 0.021722664410668998, 0.030796860960582574, 0.03460685752572552, 0.048155601271578384, 0.11942290310417453, 0.126630250634926, 0.04517706291329476, 0.040236588702687336, 0.04284340204791196, 0.042375107821557796, 0.0366501672373664, 0.08618253959162582, 0.0655264419413382, 0.009103135521253271, 0.034201420813558564, 0.029228431916224863, 0.12390082491742027, 0.06413062974329918, 0.07839432887492642, 0.025663328762616844, 0.03843073560405643, 0.06856358219538966, 0.054357948697983265, 0.023697922531996044, 0.0648136124495537, 0.036391348262587865, 0.023336759956193068, 0.03001613118084929, 0.045689989422117515, 0.03454781895984085, 0.03194698493086523, 0.028014766698282574, 0.03195521654561162, 0.025264639369842988, 0.03903833525856176, 0.08041826422296225, 0.013821960385558347, 0.05072419065982104, 0.05375220680669431, 0.05427849771935613, 0.03151026118787066, 0.027165324577400764, 0.007003199941884246, 0.03879907067805048, 0.013602670590062777, 0.048288728200620225, 0.0709748515979417, 0.039022565338640444, 0.025442668627346718, 0.015182434862870124, 0.02852826011216929, 0.04454070048767232, 0.030148817609334667, 0.03608896569799512, 0.03140975045220506, 0.011979676933298189, 0.05165415245198435, 0.12644438238273706, 0.02079741022880039, 0.060936866643568205, 0.02272599635856046, 0.03546576466291182, 0.030978891112270857, 0.035420967671539516, 0.0708118434094133, 0.04454112183603068, 0.01286007762481008, 0.005632893683674235, 0.017683188123027646, 0.040696341048685775, 0.02439263979003074, 0.04400540421146058, 0.05826299762233131, 0.04061726928358117, 0.06657133224390208, 0.010273586676996804, 0.03679183604676397, 0.03510562289926795, 0.002303123643111077, 0.07841718893858694, 0.010329635584756974, 0.01169816739181237, 0.04919953013379728, 0.035807252185599464, 0.013736753213790157, 0.0493827477217682, 0.06180443440473849, 0.03910015089317195, 0.03661823286224277, 0.03874725249085215, 0.03188760162541463, 0.022773225679092353, 0.03408134802274647, 0.04187260010850526, 0.03687400663752229, 0.020289570543794863, 0.021887637614723177, 0.0883931705668088, 0.027613445793488817, 0.046156839572734414, 0.031117426622058117, 0.04350971851137377, 0.04340171543580871, 0.022755555861118822, 0.06085189217100702, 0.04347810972361796, 0.022031334641900276, 0.03158777396404936, 0.0594231152095862, 0.0296317178365444, 0.06498081113902793, 0.030186422950317784, 0.013790048993072443, 0.03914779773162257, 0.02542907248191055, 0.060781017546692205, 0.015603805246252208, 0.028618539743606123, 0.024670821637095466, 0.014927344821063022, 0.0468435378054217, 0.026159947174751473, 0.04336667457415212, 0.0700488658021054, 0.029023616394448667, 0.010675867106915723, 0.0838253943009242, 0.009709814912639558, 0.04354826039484432, 0.030450661997160608, 0.04271099907195857, 0.053988678996721585, 0.030805138540604425, 0.04352718148560774, 0.09177678174549535, 0.012799151609801959, 0.05267001951353685, 0.04288315435030288, 0.030226493179197275, 0.010694589338175232, 0.02101162756462732, 0.05617262712950188, 0.05621693382460264, 0.023771273535526088, 0.08227265665247556, 0.05222362774093786, 0.017499501306203105, 0.1168212608524388, 0.0797787876499276, 0.04550176928000105, 0.011436215117423525, 0.04087329203743608, 0.021036751418104096, 0.019367524355109182, 0.06727133742383412, 0.04133589423051284, 0.01206946243802386, 0.07990680094207488, 0.11151360453016336, 0.2570165690755652, 0.22069877674502714, 0.07345477780026775, 0.1717034090430506, 0.14887634845029923, 0.1734743438540928, 0.14696642996803408, 0.16859011964932566, 0.10136957385487134, 0.1505354037808795, 0.0721692975850836, 0.08188564435488756, 0.07929054449402517, 0.15136435688022645, 0.09592628932648128, 0.10845692137316351, 0.15932566516341704, 0.17906005944936507, 0.2083017121279432, 0.08227051926716682, 0.13365692398961515, 0.15717122673748002, 0.20622892335297602, 0.17002471121809176, 0.16172348972289793, 0.1741632254373643, 0.15089928022315427, 0.10205739057592808, 0.1444906483013784, 0.19547188444243324, 0.16340914362620923, 0.15666734006616378, 0.14593028072868625, 0.17887891029878972, 0.12525417286181642, 0.163274189577468, 0.09488546695079535, 0.18158033550266298, 0.10112251049929089, 0.14343052051000058, 0.09463878663917703, 0.14551833993004215, 0.09443165944708933, 0.14009924845830088, 0.09006872743127808, 0.19339705787358746, 0.14619989771275752, 0.21580771903597543, 0.1373488702360661, 0.27522067208924605, 0.21139592593235357, 0.07559821520361208, 0.3811277310934759, 0.14363056138878869, 0.1526910526257369, 0.19634917768980228, 0.10003465798593338, 0.0918499737857811, 0.08804545091885714, 0.18827211352125292, 0.20852449049632396, 0.15809943418829672, 0.11575877351025421, 0.15940144658088684, 0.07475369519764379, 0.2694138788407849, 0.09290735132151073, 0.11445728205745259, 0.11370583407340512, 0.22896794512146906, 0.16343460838881232, 0.11865221099146914, 0.13186703616332623, 0.1405528031529919, 0.18015046303551044, 0.14421047462571052, 0.18257675542225762, 0.10480462017679408, 0.08052956913748095, 0.16526247885438705, 0.12426426468957817, 0.1639511201891207, 0.1972336108766256, 0.11397827026103774, 0.11205415616953567, 0.12209573024583441, 0.14270564811604639, 0.13788200614433135, 0.10767866031176622, 0.12969914523343887, 0.1342369291570879, 0.15917990927494344, 0.19884247212640702, 0.12034554875666097, 0.12579051867848443, 0.1745638434564875, 0.1963494688032135, 0.2733174032501636, 0.11438651085500756, 0.10203908107453778, 0.12925495213318255, 0.18886184800536404, 0.2535130651367288, 0.1661477547379271, 0.09823469610344018, 0.11430284639279689, 0.1703253547630964, 0.09897441528136693, 0.1477610163630978, 0.16265148266909585, 0.2652740929155581, 0.0659205405522258, 0.12995823616943053, 0.10179765612608004, 0.13931849761114967, 0.11618364587306015, 0.16971456818282607, 0.22079130484452172, 0.08847935545829036, 0.17959201558222695, 0.10683331293083968, 0.16793787239059327, 0.09697291098775403, 0.16623501215250264, 0.13220360923197963, 0.1650222336813327, 0.10695161988898631, 0.10172014334990133, 0.1730781538231719, 0.09530451704537678, 0.1932942641959075, 0.11298067822691896, 0.14457844197750092, 0.12305735445190823, 0.12221124098305741, 0.09712956830739014, 0.1044444592609521, 0.12602630521981947, 0.1305132055835378, 0.07842423694749033, 0.1796276233489475, 0.08596208246965563, 0.11824577836500061, 0.24201091378927234, 0.05909106972056532, 0.1767847476707351, 0.18038896152809744, 0.15718553725990558, 0.13310083608713844, 0.14190421289493962, 0.11268229464129095, 0.08617949056168718, 0.09925576873243817, 0.23080408933662602, 0.12601302125521247, 0.08785710054179353, 0.12364805420680393, 0.08437142346895511, 0.24129892699420455, 0.1555115891800773, 0.09893346788181413, 0.18320450318917153, 0.07968901746696042, 0.14162095954581616, 0.15303168596038896, 0.1824200291547083, 0.10090040628828349, 0.08669987876689242, 0.14780292137255593, 0.2456003268279376, 0.13054507484118785, 0.11848338819559544, 0.16793756595542356, 0.08877983812483088], [0.0355543359182775, 0.027335926612478592, 0.04800392352345009, 0.011122445613446255, 0.04161110748687098, 0.02873502341249297, 0.026435694777436798, 0.009445197609884125, 0.09100471833540548, 0.022301020573884733, 0.1110777234838855, 0.019985240200654637, 0.06261543806401954, 0.05291443986577853, 0.03288930755168681, 0.08869555313140155, 0.05719063157636312, 0.02830619803599773, 0.042326139481437784, 0.0324668062310065, 0.03670641341276708, 0.1447115727369824, 0.017865718147086523, 0.12328434630387253, 0.08737309385211238, 0.04301095313783135, 0.018881183012478778, 0.014905355224806457, 0.11075590526865375, 0.05624007351035553, 0.019233828605783564, 0.029993862920110265, 0.015678263246832837, 0.023342859931290153, 0.02277600657825749, 0.019353384287246776, 0.043803283403958046, 0.08183434710747774, 0.0715402091643022, 0.04524861552542256, 0.05711242549061295, 0.04981383305764006, 0.03174622967508772, 0.019287018090366356, 0.018964948981339415, 0.06193983661491544, 0.05153975637269117, 0.06276563343201434, 0.02558776759542525, 0.006548283047102873, 0.04524774984606812, 0.04003602688411071, 0.1111560942785394, 0.03096150474682931, 0.038654827813227335, 0.026521655588200497, 0.04530554351907584, 0.04125700249607044, 0.01054950281902547, 0.03500381364457069, 0.01762870969551225, 0.060612148785543066, 0.1281127150380804, 0.043090377303381125, 0.08737878588538978, 0.1138388958849734, 0.031801094977004875, 0.05702879167191925, 0.021971734916611065, 0.029550843849597924, 0.02076449717635349, 0.04106317842078786, 0.022686770741617488, 0.055593085445223324, 0.057004184927791364, 0.055216101238564144, 0.08812180690227017, 0.05600854258743986, 0.030677592562090968, 0.04629517589966136, 0.02475136237579488, 0.03998997350854259, 0.09356074005125031, 0.040325849437184876, 0.025297018075962702, 0.018785052384520252, 0.055883712390617984, 0.057781327500819206, 0.03542498580270237, 0.018646043815439748, 0.03290090229242079, 0.042468922948765184, 0.028544386262975396, 0.06941161854493041, 0.04470897170024053, 0.02105661990842031, 0.01511805762176312, 0.029226689066197124, 0.07508466816357068, 0.0079772682886781, 0.04011789870057856, 0.04817928487975751, 0.06169090017436012, 0.00979841010825288, 0.0094761552229043, 0.027181473710844596, 0.05183813229743993, 0.08849987129290258, 0.06473225391199512, 0.05003874498088995, 0.05905022957332193, 0.07763194881619946, 0.03281147684901953, 0.03583964621347766, 0.038453967220360236, 0.012475092587391696, 0.04165036183211111, 0.023837473108282974, 0.02202647764446034, 0.014510906128693494, 0.09418225952333982, 0.061260734143997395, 0.04389691850050323, 0.10694372918336623, 0.024467413801880136, 0.03223158659473543, 0.03656713096725364, 0.01858092825709572, 0.038803828084060264, 0.04064293322904457, 0.02971152696127613, 0.06380005514309292, 0.08802467461435065, 0.02792412700552133, 0.035230499061365286, 0.03295494979547878, 0.029270721884864955, 0.05268635633852213, 0.0555821648618627, 0.037513345314730565, 0.04359255942906584, 0.03914514323696494, 0.044073578375842304, 0.04115880534593617, 0.05591970320130068, 0.00908319616780406, 0.04818970367552773, 0.08168270766374566, 0.09255616129526208, 0.02606696325294193, 0.04857381633032234, 0.04437894868333975, 0.009232854316641968, 0.03355576191097498, 0.03125154946540152, 0.026581033147991668, 0.04706081566250613, 0.0077236496144905695, 0.029579725364343296, 0.0324139729773085, 0.05112021981227783, 0.05932839609862817, 0.09333365626873509, 0.06240197915523764, 0.060278540477156646, 0.04349665671226479, 0.04637631610216153, 0.04467632486334732, 0.005868666339665652, 0.02324381625399955, 0.03863261509386282, 0.05029520057442208, 0.04268274574931111, 0.01995552939573123, 0.05380643817085413, 0.038629600537880775, 0.039280403720875906, 0.024897907334830494, 0.012738827931424303, 0.027890459356469013, 0.041849893262429584, 0.013780692186687264, 0.05407158886232684, 0.034708777863171794, 0.03596218580740594, 0.1267140453320838, 0.09857860063352893, 0.06933800515628631, 0.04031353074336245, 0.057010348105142196, 0.004159118153996045, 0.03414695196214222, 0.02598461454674121, 0.045258003932934616, 0.01802902319468558, 0.030892713881668546, 0.019736353555814396, 0.050089237835979274, 0.05856701578464239, 0.0345641864283431, 0.05162008835243122, 0.028296233147322655, 0.028600088515949827, 0.019910027603468588, 0.13099651513320784, 0.08566946752609746, 0.08690011116766161, 0.041185932519334945, 0.04216638716658758, 0.03750513285218227, 0.05520080629315588, 0.050759752461266135, 0.03785518906830299, 0.02223243655246352, 0.014804422183172598, 0.04236370077236526, 0.01809471331897282, 0.017499999263353886, 0.0026400100896059866, 0.034388438197633917, 0.04811003053140256, 0.055242822385363044, 0.05425942213004155, 0.04372572083206427, 0.0580347876905674, 0.03760174036987367, 0.06509177897485995, 0.013526246616346462, 0.05981609533210436, 0.05382146881592851, 0.05063286148792794, 0.022256736861421697, 0.03963734323699628, 0.06275452132667265, 0.031151860359034715, 0.05749811245609195, 0.0030104492719645703, 0.021912903194465948, 0.005827699787914754, 0.014774445162695504, 0.04702891193089947, 0.03350574403039871, 0.01266433545688708, 0.06986508130907051, 0.01940343472655983, 0.019781313340870604, 0.06803420011795337, 0.035136320042393865, 0.014703390507718489, 0.019177434958457466, 0.04833742074908749, 0.01714855642809022, 0.043784315066952864, 0.03535390816508763, 0.04416035698546518, 0.05886893869648057, 0.04283507084173541, 0.012516920030447505, 0.02672861424094487, 0.0033470041460297523, 0.034283074294968, 0.0332703213808277, 0.06739260148136847, 0.0623747677121672, 0.04112603210453545, 0.09176424088617487, 0.09440627895415792, 0.035838167663783796, 0.043554557637581905, 0.08659403605927384, 0.060504229979649674, 0.014602095489540409, 0.05188528500917939, 0.05526241891446614, 0.013612828915938737, 0.03359921058760055, 0.06237457619018613, 0.06006358769692241, 0.10079497726814401, 0.030196818763450272, 0.030696739014538548, 0.019505475722854177, 0.023176772069306146, 0.04281100035915452, 0.010538122582910283, 0.01675761218423084, 0.06700109990854418, 0.0765891346119104, 0.028669781449641434, 0.02017953925045027, 0.027120537162127516, 0.004370444465518719, 0.057967283853119424, 0.07055947872539682, 0.06540887042759888, 0.04199008735257291, 0.019208869461210507, 0.0413418275814864, 0.02282798947435954, 0.09195272915906484, 0.06479483563452959, 0.07010254558295974, 0.04164016520183894, 0.030796805419208064, 0.05841305126406013, 0.06989559459109461, 0.060008843053853324, 0.013093894362569818, 0.00870404393231917, 0.045863320645425594, 0.06726674855716767, 0.049683785802053834, 0.034230313819622805, 0.018085305759262656, 0.06239159483342402, 0.040028680100916855, 0.06371616468494458, 0.055658015227245713, 0.05701469565411249, 0.04480565582672435, 0.05733331162182074, 0.022954217781643235, 0.03131872771548168, 0.019066198991851944, 0.07830650455528691, 0.03950848341769269, 0.006912478373476094, 0.03786007287882028, 0.04788892606513635, 0.044344482387626366, 0.02531011626424809, 0.038398399032772555, 0.04956060652470878, 0.010363696811480388, 0.039940254402256785, 0.023475010098228534, 0.1002249465654454, 0.042553889760447126, 0.01829847163941351, 0.020846374738480777, 0.03316434460782236, 0.035610735311263034, 0.07297637121331307, 0.032477929827667056, 0.020087039879252835, 0.03631052215613666, 0.03810874118860211, 0.04734076717267594, 0.05820952851565615, 0.03195610137716417, 0.06563531835713694, 0.07122235162363899, 0.10493745982286432, 0.11729282627422964, 0.21953320461175135, 0.1546900518118374, 0.12692866486407098, 0.09625077352768953, 0.1689996549318875, 0.12022629951036747, 0.3248892165720463, 0.1659899406255253, 0.34434028090007845, 0.09700293397350658, 0.0955872800982287, 0.18830338523032206, 0.0775944794558229, 0.13612279247853065, 0.1294162442847606, 0.11696979764007753, 0.19014449369522834, 0.09260375833799762, 0.10238171389867222, 0.2581753077045564, 0.13649783848274138, 0.14740279364970424, 0.1461911949539377, 0.1529844643007363, 0.07919855265607757, 0.15686583344734487, 0.2475958020095864, 0.21751001236900208, 0.17835758746631686, 0.14723840650291214, 0.08125940578118448, 0.19155205768202582, 0.18115586150557766, 0.203104525684349, 0.15413753387908782, 0.15179653772183005, 0.1415264549394769, 0.12580471428772136, 0.11980531887421686, 0.14704645551260442, 0.1039124801454525, 0.19383498437462315, 0.09697386093678013, 0.23892607690105516, 0.14568773729185905, 0.23965959076679524, 0.1507362567128674, 0.12823744947391172, 0.12412461452186109, 0.19944083276054553, 0.12203077365073467, 0.18549276185372185, 0.23014156117794976, 0.14057123522845008, 0.09525148077837883, 0.13944117893134395, 0.06585635004505035, 0.18137923742253936, 0.07580425455084733, 0.20200410166815405, 0.16324346945170434, 0.18280394645708223, 0.1643762683435794, 0.1696427397790455, 0.1194437483565942, 0.15787305520667186, 0.08885570381197239, 0.166663148049866, 0.14196191463739644, 0.08598832864194147, 0.14367137855339435, 0.14742353931069374, 0.18492812441001016, 0.16158790748205878, 0.15766193669649864, 0.11450015999857457, 0.11963380710972894, 0.11070987104528374, 0.16234042032832102, 0.050534863520653985, 0.14988611362153484, 0.04822728794909293, 0.1559440611350921, 0.10265486254807442, 0.2766730522196139, 0.26148146739409817, 0.14096491249097934, 0.16717170785752036, 0.22040386353769612, 0.1608451545959519, 0.16875539545810994, 0.17328708132188167, 0.13044839454514365, 0.12812496478398963, 0.15181806479250232, 0.16331361246205148, 0.1653617791711323, 0.12203254331383975, 0.15309649699878308, 0.21836128927046256, 0.1865947946545578, 0.10667676286351298, 0.1699218102881024, 0.10492200016855233, 0.13261965626189787, 0.2028023806070128, 0.16649805610218357, 0.21681425131617055, 0.18089491663680923, 0.16872580914247423, 0.15329233971574616, 0.13240361946725077, 0.17388429282413376, 0.0523626420556778, 0.19674473952862526, 0.17410641235689964, 0.14512889147285493, 0.11780415165929065, 0.15454262585168885, 0.19222025489134176, 0.1284466987295497, 0.23876948852933225, 0.08043236790164825, 0.16843130962262232, 0.1254850947448323, 0.13029816470319225, 0.12960016667362184, 0.1522940352198578, 0.12596321021837573, 0.12050350842576836, 0.1633079280896533, 0.11726066590316835, 0.15730353012200327, 0.10026938732593291, 0.22333379744762377, 0.21840264269661522, 0.11861801282652926, 0.16876178463139843, 0.13662661786281294, 0.13902468757042963, 0.12919980912439286, 0.16174723844855063, 0.2183459981554939, 0.13579009581477414, 0.1255444588980848, 0.22400187208287178, 0.261955430671092, 0.07913201791985382, 0.13493135721693117, 0.10209902745461273, 0.10024779130734744, 0.1359577311743652, 0.21982424141418552, 0.1307982209348871, 0.13185096363867485, 0.1420525275170803, 0.12370751795148659, 0.12253672875944646, 0.2940420734305536, 0.1113399553803667, 0.11728504282091895, 0.17522718366836348, 0.1632919628173113, 0.08729293807259492, 0.17363424172564862, 0.12138222659667655, 0.16326446026082964, 0.14479015803625508, 0.24240391689442822, 0.151388289466981, 0.1603790054157857, 0.10389949495513594, 0.16976801047642387, 0.16735751482267536], [0.006121415025254171, 0.034469854191786824, 0.0029793458628363067, 0.021430830876793594, 0.008185501041401538, 0.039926583563248, 0.07086841134174217, 0.017209370402739416, 0.034309439210882114, 0.033266268775708256, 0.060437162812318534, 0.027145791250551422, 0.04306827949720525, 0.009410647044499076, 0.086019171341773, 0.04352154690892466, 0.029694460437542973, 0.08737308619123313, 0.018728436571696115, 0.0365617185560686, 0.044969200276799744, 0.03435106459824789, 0.012108604742905066, 0.019440568923469514, 0.05765999066493204, 0.029525530389359886, 0.06578108956736904, 0.024796867998497143, 0.03423771422897135, 0.006938757104498725, 0.03934695377885815, 0.01623429560793504, 0.06352820884316199, 0.08493134947193247, 0.020435339838807142, 0.041990363144225655, 0.032580122126326445, 0.023954927793613846, 0.030707899000375505, 0.015791121404618025, 0.04409657633532921, 0.04656790320070521, 0.021375180334754048, 0.019294991150438305, 0.023603912052367965, 0.012592197745107116, 0.009669563695487958, 0.02226410854247309, 0.05254002971454494, 0.059862118064155506, 0.037913591781210516, 0.04937495660757826, 0.033550525700012525, 0.06838528289189262, 0.018482964763778354, 0.04097610869775376, 0.045986124539687756, 0.043070363256359295, 0.05886397827717085, 0.02310181228113511, 0.024112096476939418, 0.013288533363881852, 0.006360252511747663, 0.032364299836298155, 0.07032815847666034, 0.022490227054203712, 0.033862790798828486, 0.07970611654943036, 0.036320282116291985, 0.032684612688758684, 0.02555556891996774, 0.04568926546902907, 0.06323858547294814, 0.00998675378204714, 0.035680901304247885, 0.037257900957258484, 0.07392710930998288, 0.009908218278489526, 0.06592551246285439, 0.067932118902043, 0.02383280954804392, 0.012942014558751498, 0.04947001662766261, 0.06901309194584047, 0.04321879279168864, 0.023255052848628933, 0.04874604821745907, 0.03780725111644115, 0.0346146754529928, 0.03230811494793142, 0.02242125232794112, 0.07575063605702693, 0.0495581588737907, 0.037864558323616945, 0.10383490608223986, 0.023814582401105476, 0.010544055933883835, 0.021293275959549413, 0.0204243617988522, 0.025051276222051635, 0.11790863839128327, 0.021124012663119265, 0.0621881525242521, 0.05063602926149484, 0.024099867798448093, 0.05961986957117916, 0.0683463886079769, 0.02808905041386043, 0.03149720513442111, 0.07568049304667981, 0.09346838049109905, 0.04125851935016052, 0.039294170320875225, 0.05022897610380765, 0.023714673044460437, 0.0063869382269800675, 0.03782932977041891, 0.01686500813511591, 0.04097814266119273, 0.026316480005099892, 0.057191512577476046, 0.047314279682693944, 0.039094405233739846, 0.08981369676128512, 0.04355694017102642, 0.01692286692559719, 0.08275800399602422, 0.07042707574944343, 0.039754991359528036, 0.09466053587534735, 0.010579433874227108, 0.05991394008179346, 0.014422586724732914, 0.03377211280167103, 0.016619444396647236, 0.009859435714691157, 0.014772572077720638, 0.008073402268271293, 0.05119079566230217, 0.04004166529123341, 0.0516346172099152, 0.009715690807018791, 0.027764562382212574, 0.02469386939229744, 0.005410687008406968, 0.045924925605856606, 0.05441175871378472, 0.027339368262478424, 0.033762655446245786, 0.029916838524983298, 0.04320392685551797, 0.07321486970590008, 0.07265777056736332, 0.044045394001108025, 0.01966452706725367, 0.0319145679203493, 0.11188439108551511, 0.02660889959623737, 0.1067802153768078, 0.03359425016829083, 0.09414614613858924, 0.10091010496140489, 0.023262518375451048, 0.018644044325957378, 0.05997496664584164, 0.033314850241426504, 0.03678777195032566, 0.02201873249554586, 0.03875305560687858, 0.032695586898274, 0.014320268021566013, 0.0600728037346515, 0.023472418805824655, 0.05468684173519573, 0.04398640523093843, 0.02186795298550879, 0.03583923252599855, 0.05499145744608776, 0.020538778945563302, 0.02065364808414973, 0.03267871381174172, 0.09786706583033647, 0.050111278185560826, 0.009919709597353735, 0.021068051855470386, 0.028941664138748765, 0.03154297314223743, 0.10624954627165872, 0.003360715922861991, 0.02242785983628804, 0.030341557670204394, 0.05132698694304113, 0.028959835744312698, 0.012633911232584187, 0.04752027306465372, 0.023685475518446297, 0.02874037836708369, 0.02282954080240621, 0.016526464305277315, 0.019692598444019115, 0.08827078036002575, 0.02500844041576549, 0.022371565780392098, 0.02589557597774171, 0.04415952961050695, 0.03116427481384768, 0.08377830287621868, 0.026594811239309853, 0.04029320643073128, 0.04973789459214576, 0.06437257563154544, 0.012062251635436571, 0.015088829452232009, 0.04473482333724538, 0.019646953010270675, 0.04273105525381623, 0.09318174869422952, 0.03654216033136172, 0.016845691228105177, 0.05305708926771918, 0.06731034662093847, 0.033003102251959425, 0.05785236683403773, 0.019073359998724154, 0.021802123050175367, 0.01720708554550525, 0.01471234799077314, 0.011568183338479891, 0.060626788725776065, 0.09346065832482231, 0.07523374887363565, 0.04809995264475865, 0.10716472256688342, 0.010958719217488843, 0.008238802566343259, 0.048075893653496626, 0.044129081445956425, 0.0568913133634675, 0.017427992744130955, 0.061069281110840465, 0.024250653054144596, 0.014308561240473102, 0.027956965364395615, 0.0006494390078343362, 0.02084973786446837, 0.04010806979251005, 0.02610531936009084, 0.017449018027212833, 0.09939259203571467, 0.033258569592069236, 0.029969989705169876, 0.0458956265731925, 0.04208548828178356, 0.04010757183535926, 0.11620274444501247, 0.017214805796562184, 0.07044557677281481, 0.01681638836500145, 0.01811875507325655, 0.057742728160754334, 0.042028433883622776, 0.03352326063078738, 0.041832273240171136, 0.05964312800056031, 0.02581747522908113, 0.06889600306749344, 0.015905443747948497, 0.030985194100667874, 0.03155609622838036, 0.03565062550948032, 0.04444982713809417, 0.03528303737121244, 0.05293736121647301, 0.05022066404982921, 0.012584488985369043, 0.06440202405135478, 0.07247675165173507, 0.0560972287559942, 0.004434369714750398, 0.040537067538788246, 0.05141712867865159, 0.03657998975306269, 0.08648502940852797, 0.006280068961542941, 0.044413889953566175, 0.012679709883917485, 0.1053139613941312, 0.08491500115562832, 0.06472255523887373, 0.031174517409395308, 0.04415011055947792, 0.041344390145593116, 0.02844483888287458, 0.06135318563469957, 0.07462099344739992, 0.056610676204605456, 0.03919872725682874, 0.026015359570362398, 0.053419150081613374, 0.037330189013793584, 0.0534287644850631, 0.0064947981398642786, 0.053502726443712754, 0.017578484971196424, 0.010598883889014683, 0.06990158539866248, 0.015484159549457893, 0.021861119481224208, 0.029951036689923178, 0.035387064450450485, 0.048281090304015145, 0.06800225425151087, 0.0409964100277472, 0.04613107986628048, 0.04886024511389194, 0.03175964578986168, 0.02058468676442581, 0.012338181184003911, 0.06637788738214201, 0.03051830564565476, 0.05446393696230747, 0.029503170198069948, 0.050463774391720374, 0.02696256025604183, 0.02477195098875992, 0.04760257389035918, 0.03580426061225515, 0.046257292851805694, 0.027796998544926607, 0.02454161707822594, 0.016246740706264973, 0.11603661061775301, 0.05679279062596541, 0.05025768524877006, 0.009693476172434467, 0.05860220986388384, 0.008204150494308242, 0.07439050057362165, 0.01701441060210909, 0.10051423668741219, 0.06933307155005394, 0.032616840720537214, 0.014277122907280443, 0.007430348543435216, 0.03527386346831918, 0.022801310462396474, 0.08971498633224158, 0.07485964515757176, 0.01458755609834747, 0.04250044746684932, 0.016603159282596845, 0.04109469527799276, 0.19043416686115727, 0.090808262748103, 0.08033443122140824, 0.10489737810266596, 0.13487275149072372, 0.20662017977766453, 0.20663101226091388, 0.10630495741122192, 0.1775443238476592, 0.11260042282482309, 0.09197489974359352, 0.2025963489206568, 0.13862037700751137, 0.08020471721406906, 0.15566987826699213, 0.1287967702674289, 0.09261761686854786, 0.18570230222277104, 0.1449396217902822, 0.156557452414305, 0.15632750346295296, 0.1159340927317258, 0.12664674450793575, 0.10130547527824679, 0.22339770450226723, 0.18138159697334613, 0.11804252757780975, 0.13191994219537706, 0.15010929035563625, 0.11240093352934045, 0.21655773443560447, 0.08288531248728115, 0.1575451695750798, 0.16433024178108863, 0.10820609652587485, 0.08808421496782573, 0.11089287412863587, 0.0874682036679118, 0.12697715822967792, 0.13969234851819856, 0.17020392982709795, 0.15110754888624917, 0.13165024860251334, 0.171578414137325, 0.12492663963066956, 0.14931338628934276, 0.08673970767807576, 0.11204038956953634, 0.16040258560209505, 0.10627684964528007, 0.12465386636435025, 0.14989579697289776, 0.13145445185082574, 0.09132258353694793, 0.28810525973958356, 0.12716036049589036, 0.20982923016192453, 0.08059741388405524, 0.1485505772213782, 0.17373403233866538, 0.08381094588267227, 0.152604699194912, 0.09159580879514256, 0.2897589677764524, 0.18098978896535214, 0.13779479469503128, 0.1452361437822542, 0.12535673671311912, 0.11838812516221117, 0.12936252619951003, 0.16335769316121457, 0.14119113825501936, 0.1534066247122903, 0.09909813082025898, 0.12273123848342127, 0.09546581685783402, 0.09525159569156748, 0.11054482506287676, 0.17842224528712614, 0.16779819924023845, 0.17661219402667017, 0.08667922503645382, 0.1496087131841529, 0.13302761340333571, 0.0965407224852712, 0.16568177409710425, 0.1043533254414797, 0.12077763000683439, 0.18843236379325393, 0.11798140142233142, 0.1328966430118007, 0.157678576126214, 0.16651532372399686, 0.10970193682418716, 0.22600165267865505, 0.22461069747805598, 0.14913148637260162, 0.1223931255780401, 0.09991409872928936, 0.14422803336093504, 0.24910753863232754, 0.13435259311189576, 0.15675438297612054, 0.14154554585055, 0.09098763457469403, 0.190954034126574, 0.13313550922659137, 0.12999614219992392, 0.12142627665232267, 0.21268227948777138, 0.2447772572838491, 0.26408601311906693, 0.13785997345562906, 0.13518249616026878, 0.20955782053211044, 0.14320156747295013, 0.1927575429961566, 0.09460975956772605, 0.11095231489068079, 0.16707430743882734, 0.12758782989675962, 0.14240106687911097, 0.11536899563525954, 0.18875877853603135, 0.10977047871077254, 0.0985664428181706, 0.11771604388711915, 0.11513012175958966, 0.10405264359207884, 0.24969309027637207, 0.08576491442058357, 0.13744263939799803, 0.12212318683704063, 0.13687702136174326, 0.10768334876986281, 0.12332188461216227, 0.11484039496750602, 0.08745975371810698, 0.2762019694332154, 0.10531062125078133, 0.1283269668478639, 0.1915562405220924, 0.17200150917614662, 0.15153672666318957, 0.1403854129415366, 0.09613526279046651, 0.1543693520849751, 0.11824372524936354, 0.1037550031117374, 0.17039535987761714, 0.19471923370034466, 0.1668815290735614, 0.12673026341344082, 0.10004608801776364, 0.19030480525426327, 0.30662810129504053, 0.15834291225239155, 0.08000256959348917, 0.17858238830681772, 0.12035816622477387, 0.1710857889584957, 0.20477946967847888, 0.08929108690109946, 0.2388037020160306, 0.26163728967789684, 0.11565698340775506, 0.12759692336042083, 0.08552405637718978, 0.10118178272199246, 0.08883532587318652, 0.15171501064492812, 0.2268974699320332, 0.12971520243633178, 0.1983144996507514, 0.14916819730593314, 0.1221869866393747], [0.027964756478585547, 0.02006539023451267, 0.02436392872984852, 0.07683350899887663, 0.024178071968978452, 0.04287815562659695, 0.038535379384073525, 0.048988166475488294, 0.017565689387641126, 0.017751094156635866, 0.04571826572740271, 0.019959865453382655, 0.004618867148359817, 0.055426361730262164, 0.040994544603651574, 0.04244293341593396, 0.01580572974372415, 0.053608814299467115, 0.10951823660082395, 0.021622714834407936, 0.03012077687608619, 0.016364827414133375, 0.01990523189306259, 0.05211903758707547, 0.08983694752978702, 0.03906217974520499, 0.025592456053521846, 0.020057915131591504, 0.08443476361853462, 0.025842302223487247, 0.08142864226453728, 0.025523829897264802, 0.014896986671843597, 0.027988547339074077, 0.03706219613612179, 0.050377355843421914, 0.057323168617703264, 0.06478565024031747, 0.030918827903787457, 0.08083912994592421, 0.019291631854890336, 0.09903606237663377, 0.007892676381274097, 0.02253741807033939, 0.03807176212449709, 0.04481491399928928, 0.05439765503509872, 0.047009369027951074, 0.04164878752142672, 0.042734491158156626, 0.053064049176511266, 0.023250023481406035, 0.02933680462921339, 0.030127978102574428, 0.03661058347431883, 0.03399130970900578, 0.018051243574929335, 0.0315079054675035, 0.010680972125321146, 0.06805799480888151, 0.012013763057879143, 0.09460807417429264, 0.060843262190539996, 0.01304313624953671, 0.017860395751232584, 0.08980440411476359, 0.06017050675807461, 0.07523658339895549, 0.02837701328849841, 0.06791812247566639, 0.022047119883580074, 0.044097319440615755, 0.10108480365165781, 0.036046804049082344, 0.017635968378594807, 0.028373506521025015, 0.030309000848642284, 0.02938684932286701, 0.004823189501034757, 0.07441837851318621, 0.03109918798380081, 0.061857623889321284, 0.03393326322698305, 0.037888670941033674, 0.03629314728201397, 0.06813078848344666, 0.02019079308205795, 0.028180134437617757, 0.015424510028453605, 0.016338675087618253, 0.031787856977673314, 0.06121208373036596, 0.03601897207479324, 0.08462584892948789, 0.01856355721341266, 0.02645408854849877, 0.12100204780337312, 0.04479352482444337, 0.08345564196427023, 0.03788665612979281, 0.026562365500496763, 0.025018495319771673, 0.036536165693354224, 0.03164022417378522, 0.015477309765804921, 0.05921968056129352, 0.02668027217770296, 0.0423032334525018, 0.05962479551653228, 0.04286746486961361, 0.06507370696072617, 0.01472538106158496, 0.057923770059020295, 0.03854112121306601, 0.016690140905519648, 0.058644019112351446, 0.023920197197566592, 0.01849027707301561, 0.018413026681950977, 0.026846934605630177, 0.03382201959949828, 0.026816367697451386, 0.0521098790059407, 0.034489929525842594, 0.026347554446528518, 0.027829616653522658, 0.0035717144923945593, 0.045891026215207194, 0.04004247734443315, 0.03381044018052278, 0.01268875450947352, 0.07958487547453373, 0.013392239643801606, 0.04350572719328827, 0.08485673250810755, 0.08270578744310526, 0.054971707699399804, 0.09146319131457037, 0.02461325779046503, 0.06361098081294088, 0.05228981390715607, 0.04282620337401186, 0.024749495036479448, 0.009755345433199359, 0.013524925114677079, 0.03611928745803814, 0.013773564696161738, 0.030714611845812013, 0.06222399777822918, 0.03048617783333025, 0.03537402180353961, 0.03229161341404242, 0.046321004554028475, 0.05475964690107973, 0.029084528045308207, 0.006878397036944667, 0.03474535473111657, 0.05677926534366223, 0.031246839939887007, 0.07004996130783712, 0.12142766327146562, 0.012599736050282036, 0.14835154757865016, 0.03826794192014683, 0.05846375862376825, 0.04336015899635611, 0.03645252038334166, 0.03110521901098471, 0.02919979554961526, 0.04356443251092588, 0.05452503630470845, 0.027458062095026818, 0.04471146148599444, 0.08856912564125755, 0.029260479289317326, 0.052588120883991646, 0.02512651180187541, 0.07616449207548173, 0.055440407952353846, 0.023103047597913012, 0.027546769330999064, 0.06119492719130171, 0.045076222759821725, 0.03760020053314586, 0.007522823016775111, 0.08108903548770374, 0.026341730263084177, 0.15089705856817384, 0.056142282386821125, 0.07139708861828813, 0.07600324588917917, 0.03634513783899527, 0.03896662176796987, 0.0550216221581063, 0.06076802469549641, 0.043141624755075866, 0.023387499874637976, 0.1400234210755556, 0.047329923198107755, 0.06640997880529012, 0.07184033943039757, 0.08444741173016448, 0.07907071556415289, 0.028775252604616747, 0.01357624247189491, 0.05123313351143753, 0.08450830805926554, 0.029171013626300042, 0.011136780076119448, 0.03815207878247865, 0.053630908275203365, 0.06561209057127276, 0.05225757309686273, 0.07328181812960295, 0.04677884168021622, 0.029180555251396956, 0.10014099865070275, 0.03046293089526796, 0.05090603311996787, 0.0477937396405445, 0.03318661095334157, 0.04956564355281092, 0.05273423683378966, 0.10395209455201704, 0.050144151018391696, 0.057347043747863466, 0.08049402265779435, 0.07151118209285122, 0.03967848981940939, 0.04203379649909274, 0.09462220849649561, 0.05014222430726213, 0.0386872869585791, 0.045807361752996524, 0.049181779876591704, 0.06475488414927837, 0.04078067200739057, 0.12661829200242797, 0.027249864295064926, 0.03656897723915116, 0.03249294515098295, 0.06683976179169071, 0.048293094901788625, 0.03223583072183594, 0.07745738036089367, 0.07803434415930703, 0.014071199430843756, 0.05120970271227341, 0.034905961234002345, 0.022367861745278203, 0.04171439146082248, 0.03844876548335437, 0.04483148831153109, 0.00329585867978993, 0.014695708561057766, 0.0750986492681888, 0.014225908971932388, 0.05211821787299649, 0.01955729965571194, 0.023122724566248157, 0.05671416319185688, 0.03552508668132848, 0.06347764704015947, 0.040715887782073794, 0.014511987270276635, 0.021817902546195735, 0.059752670912853176, 0.10040860082353316, 0.0742030541803087, 0.10740937274550239, 0.04691109526902438, 0.04428797191189182, 0.06894539275597181, 0.02147965749064761, 0.11241967970084761, 0.03085208057816471, 0.03516048628596529, 0.0351395299507966, 0.023032278310687795, 0.03616438322370091, 0.03532488875451588, 0.10781673233835928, 0.06519006805554514, 0.061535771200132955, 0.015483510289942066, 0.08507269269396221, 0.0450523246470238, 0.01799580562228878, 0.06338246444600724, 0.0429531364821859, 0.10298188250031202, 0.18320894649913236, 0.016616791817209414, 0.0042203774172512275, 0.04112481402473585, 0.03507796712520142, 0.011904259407592398, 0.009890736152057447, 0.029555741066653884, 0.05453312236274924, 0.039249070724772836, 0.025002116359950557, 0.022882105925330715, 0.018262689587690176, 0.01698467106888852, 0.020127713402372696, 0.033923093409788226, 0.032146585309096885, 0.010667603891042453, 0.08375853780777225, 0.12751987023699668, 0.06217802101145349, 0.028565735218205282, 0.05108967971717639, 0.0061861398787568175, 0.04030791914931709, 0.07748660661520497, 0.058343478989216595, 0.031520578476990906, 0.01670896368581922, 0.03983071532040354, 0.04621768610612039, 0.01953280016389345, 0.03237410959216856, 0.016157995165896513, 0.06519161555315219, 0.07897878501323924, 0.046584492834705504, 0.040108322601525054, 0.016384500552028898, 0.04110003491082499, 0.011324725384193083, 0.062447438812664444, 0.031058223347269723, 0.07357266341005603, 0.013417927529512635, 0.044509781179048365, 0.04500016555069916, 0.03921324845343348, 0.02543682912214389, 0.028744329465553168, 0.0434316924562858, 0.04050878357262381, 0.008767192559917609, 0.04044350522059587, 0.10161686703682908, 0.026766250225444956, 0.04986243367555642, 0.03564223301626983, 0.018732565785607985, 0.019276695055586678, 0.019313206806057887, 0.1147384669691805, 0.15341512828824982, 0.17704800612503485, 0.22830823616635418, 0.10488933417946102, 0.09940908590872442, 0.10038258447762459, 0.10490693121908173, 0.09320548975900297, 0.1830995491435451, 0.18855915134472234, 0.1932512866633554, 0.1360616280186561, 0.13686002953158272, 0.128952102254956, 0.1947352602597206, 0.10952775141284352, 0.17012352123856547, 0.10606278935747762, 0.11999989754610485, 0.07294153719539605, 0.18970828323114305, 0.12712313628364957, 0.12115158816619266, 0.16895244859399336, 0.16269323446096914, 0.1086876517341983, 0.07951348374087004, 0.13264611693880252, 0.15862072637725264, 0.20327891793943223, 0.12478310539717637, 0.10576550127758134, 0.15488856051477695, 0.18275151539954448, 0.16381215183965622, 0.1740248086712053, 0.14355523962407343, 0.10100633326557376, 0.1493650052936808, 0.14579301309441367, 0.2530659762241187, 0.0960685212105032, 0.0768258634413923, 0.2563319316193942, 0.2045091938587927, 0.12596079704141425, 0.2038471713181465, 0.128335899433061, 0.1630213958842139, 0.16184068585355438, 0.19164055615903872, 0.1166412684946291, 0.2701408962809271, 0.2639526218896912, 0.11873991273704076, 0.10311593256530263, 0.10192085838606281, 0.12354971149996405, 0.137105667963624, 0.19626444836537685, 0.28089652558968914, 0.17174563580943694, 0.10704807035865323, 0.12438508441611645, 0.18747130649224406, 0.13677448815395757, 0.13067429855225549, 0.17294411907993978, 0.16906166208847878, 0.12127263771910822, 0.19317637858611925, 0.27186563599013513, 0.09890807972800347, 0.1369105300475513, 0.09708993857906711, 0.15270183914371077, 0.08757059897987113, 0.1116893450999933, 0.1763210652936851, 0.11440285151043247, 0.13785932994177266, 0.1295287826008374, 0.08885529012449327, 0.1294387672697344, 0.11716086762927233, 0.1684900992099316, 0.09740835536391505, 0.05427352580872755, 0.11384503991012612, 0.16715563533286895, 0.1865146158924026, 0.19805128716172712, 0.26032746318847905, 0.16739652401977972, 0.16522929192550723, 0.16162860207259655, 0.10353924210874305, 0.21341982297599318, 0.12559993898556118, 0.10818893615637096, 0.05983464998163043, 0.14977126171992672, 0.20093035283348254, 0.16884898075894003, 0.25298627243647653, 0.11997142971883859, 0.10960639033827091, 0.2660597314036662, 0.1483309551352455, 0.18449903856362068, 0.08599795836714968, 0.15464120604578527, 0.13403961555131022, 0.21582023691265814, 0.17595580989314666, 0.2210509167203019, 0.10404613950560171, 0.1100990844650134, 0.15678999074284108, 0.19579088345410364, 0.10484981936432662, 0.13291469204329676, 0.14462866670181676, 0.21032398506518335, 0.1345979404305258, 0.17346597817395965, 0.12026373056634782, 0.17805999295125086, 0.16543248908654337, 0.0908782065755898, 0.14379048990386148, 0.15251701277109886, 0.16018581336304066, 0.1793264128988789, 0.1898456734394835, 0.1288192319653688, 0.1840608822362077, 0.11944161097128546, 0.13881058131735172, 0.20919455696017514, 0.1888849991824358, 0.09120069128731567, 0.10445752872094032, 0.09762771698015352, 0.17348318450873898, 0.09058706252084625, 0.09734212706286101, 0.11094542776024151, 0.13787943208890577, 0.15227459190833956, 0.12713347847062734, 0.11654461118122263, 0.11906616660135409, 0.08621232509012185, 0.07435423397128621, 0.14882572536026278, 0.14751445862554735, 0.19918701250947293, 0.10574149974291364, 0.2721087922973018, 0.09443038774113502, 0.3341953155975188, 0.0704456840251242, 0.09416174368872758, 0.1551055166149332, 0.1479690398780569, 0.0810824241489172, 0.15750136466756945, 0.1618622742112606, 0.14954382553696632, 0.13027679085010482, 0.09878020433168258, 0.13490272085032157, 0.11622881441707573, 0.1095367529459538], [0.04366182909917928, 0.027537650969480316, 0.07595343485234246, 0.03792054785956298, 0.04352177673530194, 0.020523051160477826, 0.11050514936927827, 0.0965206050163796, 0.05841140417502292, 0.020833203771842584, 0.027016739909266754, 0.039192403201013803, 0.010759393673300022, 0.04979149010332842, 0.02113145712252346, 0.01592671705199586, 0.023585255896191926, 0.07110721626949888, 0.09249903411874849, 0.05384794098415202, 0.030648793401797454, 0.034497824061902306, 0.03717225232732393, 0.07386834270531133, 0.04379270756016335, 0.031939781789157184, 0.05411190806978172, 0.02861331502396253, 0.05083830711702186, 0.12558057228283537, 0.03633663426303575, 0.03733939356020382, 0.0037626738776452844, 0.04528802308824755, 0.037563029947059776, 0.02621344884016341, 0.07858329212232944, 0.05604847875093261, 0.04264078328325864, 0.07037789290470463, 0.029244167362189585, 0.07774495444591008, 0.06646964939371233, 0.031762872935242714, 0.03571283184893189, 0.022355903112780184, 0.05664189428751988, 0.05784844446386542, 0.06958131468103779, 0.032757486802555864, 0.02213172854915742, 0.04029909381642938, 0.0873311275556203, 0.03127238514172214, 0.02643535386831049, 0.07345526043566004, 0.044174744116683165, 0.036069376829771266, 0.021734981189271616, 0.013575146008553285, 0.026153887419270414, 0.054832352475533565, 0.042070373367037506, 0.062274685985739195, 0.03965955212592118, 0.11651989718478535, 0.014706114907899212, 0.02048416836788097, 0.02369930340547956, 0.026317780439351356, 0.036282391407557076, 0.02251108954360168, 0.02153220729181363, 0.10526343023464566, 0.014660999990038335, 0.022401351278888124, 0.014853668230165158, 0.022836113836796536, 0.03643452114756069, 0.030997531946688413, 0.07015163649714763, 0.07531689239605781, 0.061583912165294734, 0.056926043959514755, 0.08111348135336753, 0.0467111156772702, 0.059706678824319, 0.010141093685712305, 0.049657892030213154, 0.028987223387605725, 0.030240826684260563, 0.05639824002320248, 0.035072462783465465, 0.04726160730746004, 0.03360329000579734, 0.045286215120746244, 0.06946696839745968, 0.026172104990109805, 0.019053100803566557, 0.03666968715767707, 0.045288478910562494, 0.02087544011432798, 0.039105597778313586, 0.05319822947644899, 0.04713733252438326, 0.07861149947970145, 0.013060106054669427, 0.012391225111881092, 0.031107611120528275, 0.08666335935554198, 0.06039419677108527, 0.029920301242401044, 0.05500304069550288, 0.03741162032970498, 0.05776431268802094, 0.018305429632985787, 0.040750626039000294, 0.03543887497676957, 0.01286653670362167, 0.07490494393653448, 0.003039443066471347, 0.03189775612085097, 0.04097818479602856, 0.05169105490729694, 0.031169388450742252, 0.023256119626063495, 0.05318277748301626, 0.0354505846306922, 0.035069597614628654, 0.03722541882926899, 0.05841450300067664, 0.05408167057941037, 0.060275001150946465, 0.059595703327607726, 0.05579892560959824, 0.029158250601481528, 0.040925960582230365, 0.03096669116207669, 0.07567051092102643, 0.03416034700949827, 0.03374582066410973, 0.019646131380971883, 0.06430676867884975, 0.08282314445222579, 0.018873095039218184, 0.04208368414472188, 0.06538781067056042, 0.025556064961898713, 0.045077057795659195, 0.03455377912389175, 0.032496262311695084, 0.030142662092863075, 0.06541796389126009, 0.060108756240937984, 0.055974735127341364, 0.056612066654188026, 0.0256564129038804, 0.017070752538500295, 0.095204190170813, 0.016127349733705484, 0.04277485633088697, 0.028665386020175876, 0.05212932614789856, 0.05238618010715131, 0.020922081462377985, 0.07152913153291711, 0.07600816417365305, 0.03932527349060101, 0.05118111231093926, 0.010764816618194024, 0.046325700673004316, 0.015648728642132015, 0.0347309714303382, 0.01746233838099626, 0.03985728708005721, 0.019953225386298953, 0.037387641777675, 0.07644995941870636, 0.0494752949734609, 0.019418358119324814, 0.03439309984265316, 0.04845763143572596, 0.05402695274941864, 0.029443811790476886, 0.09669436907936489, 0.027097916500943325, 0.037780882370087414, 0.04770855066336451, 0.06703555088249907, 0.012864271956195515, 0.08064186230542199, 0.04557898328188927, 0.037841345859511245, 0.02389958943240345, 0.05367768943429955, 0.08972532851921936, 0.024610561160971562, 0.055763808139149225, 0.06677585473704724, 0.027623814793543953, 0.015720753355943147, 0.061061934327646616, 0.110537639158147, 0.06609612024359166, 0.025476479917884837, 0.034665536030285785, 0.06709704476018107, 0.04824847028019929, 0.024514675681148807, 0.010894509558115276, 0.023353165729091536, 0.026980607372318065, 0.033810386554368084, 0.05329060052791911, 0.02354298507974994, 0.06410695379599929, 0.054672515891011686, 0.013437936788484936, 0.057934288446220665, 0.023498429406073787, 0.03544809867537791, 0.006602715509342811, 0.03711819333294707, 0.022062604435749596, 0.017121854433489424, 0.04725753171970287, 0.06186361852732878, 0.015807828824636678, 0.13134949780519933, 0.02777334941070407, 0.05636930488230241, 0.0452610606237525, 0.07163687413858791, 0.08807840802135967, 0.06334357399253115, 0.03678052858900159, 0.014713672365272238, 0.04725546711274693, 0.06559802519698298, 0.04591105941442713, 0.01156733298088394, 0.02784829387711662, 0.04183679315892439, 0.01080349735510085, 0.005583235864422375, 0.028385961195454005, 0.033222280007096074, 0.06860183296544899, 0.03370879180428963, 0.042243099380885406, 0.01813729631624395, 0.0033877662480658586, 0.00888823732478364, 0.06642118667162235, 0.018713440400578322, 0.07894355262960158, 0.07178444565544206, 0.06557412325374543, 0.027415222458301053, 0.009549105945493906, 0.04353854639996444, 0.05399504518737236, 0.039321297494273995, 0.023776703183689428, 0.08648777966417613, 0.07663481643483525, 0.0938950225170101, 0.08452781265781772, 0.07480712983036235, 0.050451371428226276, 0.0852925599282307, 0.04057971565353294, 0.01815614399440106, 0.03206891931533333, 0.049866474789357, 0.06802475425384699, 0.0029818181722094457, 0.00137929450448287, 0.023349559370187983, 0.023971170772828405, 0.054274322540168805, 0.049554546769227714, 0.011377363285470394, 0.028511199334095565, 0.0662335793998453, 0.04214727327287678, 0.06235660376748251, 0.042714978898725206, 0.029119423350259185, 0.03675367337681594, 0.02153736306354404, 0.018262429117795922, 0.045753463637083776, 0.03183461898457139, 0.014053824556721075, 0.050251862980545535, 0.01982172256365659, 0.027443190413196723, 0.06341767384700718, 0.008863536734885026, 0.045370971258249015, 0.01448948247989099, 0.03232986035366212, 0.05500409789683838, 0.011045058284165158, 0.04437301533236619, 0.04824452492738924, 0.017652785923752575, 0.013700811241212632, 0.010354248074544294, 0.05975478531552419, 0.06281899911681972, 0.02249868849532739, 0.03096332037520986, 0.013989255793633, 0.012290043091671842, 0.015640619601453506, 0.015900134758633232, 0.03199915360328892, 0.021007659229179545, 0.014444294783677307, 0.07194726998286863, 0.02874078822412318, 0.030888333773961475, 0.03565529864581843, 0.03834723585074948, 0.09838987487338244, 0.007330796375284873, 0.05027281931571422, 0.10043108550411078, 0.048153850760671406, 0.027311285394394112, 0.020554573763342156, 0.03253909811798123, 0.07175250744987881, 0.032626979894215064, 0.0393395533695096, 0.10808925279566359, 0.005775844732735066, 0.03592188575214917, 0.029926751702723485, 0.08642925054676111, 0.060608904403183735, 0.07269698660820723, 0.04234852840102488, 0.03345841894887629, 0.04833861967668899, 0.047177789627664515, 0.03727316525914977, 0.05517034280684687, 0.005129438894425309, 0.03576315616467788, 0.15931117077988965, 0.17377489546854652, 0.15678956173360348, 0.17263261240816888, 0.1253374083147895, 0.07813369810220697, 0.1594606038903998, 0.15746517467402643, 0.22813540673063648, 0.19868326373398307, 0.11187897484389045, 0.18433371678956095, 0.19304465742841845, 0.18121880328943654, 0.16063746815967947, 0.0807902841798721, 0.17378194347744988, 0.18180331305390407, 0.14603665969785184, 0.2692662996630515, 0.17138287785553163, 0.09275426397160177, 0.12182032929793482, 0.2601522742019546, 0.1342967606239742, 0.12968811356732923, 0.17631069246319034, 0.13242298616997658, 0.2021175439679815, 0.25489269755780697, 0.1562305933405315, 0.09773545192494508, 0.09968006652930092, 0.09653866170875489, 0.177802158399455, 0.07676441552898577, 0.14089362034874578, 0.09560028061030373, 0.21570336253892994, 0.12270371294430188, 0.15247903013181302, 0.161982151649652, 0.15901002161685499, 0.0824960019259203, 0.08091689553111792, 0.07095656507918913, 0.17523246967504102, 0.12482364677012929, 0.17314158590330234, 0.13542006002558818, 0.16099685532671792, 0.15018203806492592, 0.22427626945559057, 0.11469753489138619, 0.1464086107068485, 0.1697371830983508, 0.15135082776748365, 0.1905738400115121, 0.18242830290429055, 0.09375501994884784, 0.18620097949620218, 0.16883022692655364, 0.26013247848999116, 0.1883296467243664, 0.07097799255843125, 0.18454370148960622, 0.3025142091416544, 0.12028199410246265, 0.1836982621781288, 0.09146841603421396, 0.09852941012791089, 0.1751985319799954, 0.14141388597988314, 0.15509384143496716, 0.14426741028024306, 0.09416850824509898, 0.07000066354990968, 0.13643563214328983, 0.09885619259289197, 0.19409646550493856, 0.20265788110273503, 0.16481410291406418, 0.1398684874537491, 0.10386529679019606, 0.24079309445956062, 0.14490206816023396, 0.1896330687187372, 0.11139351258715315, 0.1376095239914233, 0.1887057958951881, 0.1303011064808215, 0.30876708006666553, 0.11642968267082207, 0.16274934274054345, 0.165222090699019, 0.14587332975239525, 0.11152520310133697, 0.19898272750358428, 0.20208279421973616, 0.17730179573259047, 0.10973163805301152, 0.13428719984667917, 0.1628169883042574, 0.16047691145250875, 0.19114944783429946, 0.16645697846768365, 0.11839278297679079, 0.1282764050448614, 0.13037089709072344, 0.12825357562471784, 0.17303379733235608, 0.12846750567757315, 0.1270525566031856, 0.1405804742488169, 0.25965658467142816, 0.05407789376594367, 0.13737779771608694, 0.16739424107776535, 0.16094549679227416, 0.1521705112029468, 0.10705716382231444, 0.0993785496440626, 0.14618526543340377, 0.12632946153321575, 0.14338260937121608, 0.13385209254920483, 0.1550284328479921, 0.19403623567233164, 0.11587960089767173, 0.11235810921437318, 0.09882200974971057, 0.17002149364880978, 0.11030907682593792, 0.12181697383282647, 0.1785135170024249, 0.19332671568038004, 0.20149776351548013, 0.04666937154627616, 0.2042882847449472, 0.19000958561176257, 0.18713024414835439, 0.12089258149987268, 0.14971354465571143, 0.1701414783395106, 0.13922751700926211, 0.11636490993682416, 0.09241451929894187, 0.13538941650861694, 0.10600599159877147, 0.11661727462084064, 0.19017409533262256, 0.1528194642836048, 0.19612551065942935, 0.19083794116252856, 0.12530439758613227, 0.1798166172398675, 0.11584708812616526, 0.16186532324119923, 0.17654716848365723, 0.0788597809150815, 0.16171530790386662, 0.15553397426922477, 0.14712848820753638, 0.11943158288035663, 0.0949505691026007, 0.22011103408951915, 0.22652551892303655, 0.17548636653490607, 0.12690221184804557, 0.15153473483458643, 0.1315651209123673, 0.19417813047766688, 0.11797680489478574, 0.10257909645236309, 0.1539732846281221, 0.11630330114595352], [0.02973066958328409, 0.03336454253463495, 0.09271796672574936, 0.0427015378860937, 0.02596827963697574, 0.029504122062315865, 0.06362630257142649, 0.056865496200419245, 0.031525056260908325, 0.018176504696208625, 0.07712635376881208, 0.05197388307762243, 0.07044931528188529, 0.05242001438032716, 0.061887145087483435, 0.023193137622588587, 0.03819197664157518, 0.016490565425145532, 0.03876823180865857, 0.017982265018227122, 0.06242252180292722, 0.037289467610178456, 0.022230670719798055, 0.04639414296815953, 0.029633527719265515, 0.016960788277849075, 0.04413814043566104, 0.009933037612016403, 0.0496287998412886, 0.005861190757939533, 0.07306902188687556, 0.021034504865266142, 0.03847274786582397, 0.005001746880401287, 0.0017566748025391492, 0.10634408918239417, 0.0680270295349821, 0.06186627685242604, 0.009122572129502172, 0.023252224068968527, 0.026238134108303536, 0.026516375327182394, 0.04927636492216299, 0.049112785998131, 0.013899559346628527, 0.020497427434630452, 0.04926969229634251, 0.05506487165187156, 0.06596880409145547, 0.010447586312018817, 0.0698700915240953, 0.017050269262624845, 0.09959233414021232, 0.03636893252992342, 0.044837161192610386, 0.05471819388349691, 0.04539632110766346, 0.04656083987004334, 0.018407137381033074, 0.02379864585706063, 0.014331449074820887, 0.03490388513572755, 0.017653224509089224, 0.024707249117895, 0.004411544603851414, 0.07402023495805841, 0.02980220878887321, 0.03507586421384927, 0.025240411839237618, 0.03980666399002075, 0.04338286967287141, 0.025551730819467097, 0.04354650605349772, 0.01752516142122688, 0.031259955365150686, 0.018332420825777997, 0.12863949241657413, 0.029766225639069756, 0.006613661469365921, 0.023600882174627438, 0.017694897776950273, 0.06288977414970437, 0.10099016114949219, 0.024424972530874996, 0.04303964696103527, 0.036373720579450174, 0.012556113088653694, 0.04167440550161466, 0.020919442289478837, 0.01557308512048856, 0.00659056487605877, 0.09951294444861913, 0.05338544604338465, 0.021019052871833407, 0.04045148402632725, 0.04927569842566887, 0.023383897346174045, 0.05463235373158128, 0.04495832565871458, 0.06683074493682192, 0.039022913908646, 0.03994426870298001, 0.0686741746481388, 0.03688492339044329, 0.017231439480618123, 0.013935265747169334, 0.06895354393148614, 0.01621578692368442, 0.011476123510229011, 0.053995332470343965, 0.018816697561452468, 0.06060479434146997, 0.017459643666722605, 0.060438771596959526, 0.05317432753321144, 0.09752020420086, 0.031191696931097298, 0.03477414048487141, 0.07140712437009619, 0.029029122651404435, 0.13526204673032607, 0.011167520311691109, 0.023033454255651564, 0.02173444301250481, 0.05397967746361129, 0.03815193322577304, 0.0991551737271009, 0.020754530372458602, 0.0629581474969464, 0.029579989664677172, 0.03013394209706495, 0.05965042115759946, 0.036778245646987236, 0.01774960411562314, 0.0618981461100761, 0.05430082535190929, 0.07673721174679457, 0.04681729163313585, 0.024137865759492404, 0.031417292587819605, 0.03827919958219413, 0.02449476697121657, 0.017915981175798564, 0.020345516029685255, 0.02781432553855402, 0.010117398586214311, 0.030161295266401385, 0.013655716433159769, 0.023600060545328646, 0.04144662457908835, 0.03199243692741279, 0.057229253899065725, 0.05792198507415672, 0.020246719415750236, 0.06639596705715503, 0.07285693810591776, 0.01117153844285396, 0.08268095087260008, 0.01773812811851742, 0.018544031547442563, 0.02456062563484715, 0.014755669305281294, 0.09035263961601643, 0.08494336939146442, 0.017370499760633516, 0.013351742320904329, 0.08416145409066832, 0.01290749655210323, 0.04218398037576868, 0.01755160103071361, 0.03590777824302355, 0.03374418506639139, 0.01719534333284584, 0.01427554572376633, 0.021472653531799876, 0.02785053276907533, 0.10190045746463923, 0.002555878792566458, 0.05596342383913937, 0.01570772603079076, 0.028034897573712855, 0.06999565333488487, 0.03132381070885928, 0.021768125983315612, 0.034280959892296986, 0.041840110319636525, 0.07482640460253724, 0.04287708310350295, 0.0880805071022722, 0.0014613677781345625, 0.04884965777877839, 0.03798971793824627, 0.033135784850005186, 0.03442941624070368, 0.02524002879527548, 0.024629144538794796, 0.039375092188316974, 0.07468657823459757, 0.01738673124852921, 0.02328784141178814, 0.06783661838140219, 0.06323005508391127, 0.05495403022054703, 0.02358882203547945, 0.0564064409944319, 0.00993964990841285, 0.04370496367975589, 0.02813152424360235, 0.02395130036729238, 0.08990542812933845, 0.03113858022486731, 0.03986821915473669, 0.09415519363697498, 0.015495602987826833, 0.005245724338061747, 0.033046033819236105, 0.025575682558419726, 0.012411330131843928, 0.05010346025829354, 0.05088422259676361, 0.02388711369055654, 0.05181074848458652, 0.009594230439453837, 0.03173772226868859, 0.06270354583619103, 0.0055475696834975914, 0.02422973502337212, 0.006319846640596347, 0.02569204748367831, 0.059199329435585014, 0.01896759389989799, 0.04206712132379894, 0.023274205046735948, 0.06323238399120108, 0.030969433756845615, 0.02289307247396679, 0.029593817551710436, 0.06640647012259691, 0.05071084540818007, 0.09997513295421678, 0.027783555617075295, 0.020496910325281566, 0.026651800519997076, 0.02535141414902624, 0.04469198370051961, 0.016398669348188465, 0.12576165248549756, 0.03694804520496438, 0.05559089443375988, 0.06042802338338187, 0.023065465239567623, 0.023657538207067598, 0.05378880282683719, 0.04978941400505362, 0.03862487760582759, 0.031729138253497026, 0.047961455439367605, 0.04139521241848988, 0.057496189575402014, 0.016132986225608378, 0.014186067611820275, 0.0330000187480642, 0.04131703697625668, 0.03678533962116607, 0.04023919340162989, 0.06794005557293854, 0.034847144833615715, 0.005557036615021888, 0.07323700964691178, 0.04214368415095153, 0.042300169100804676, 0.025533141695984432, 0.01653350656852126, 0.06709758102172805, 0.024237891944545894, 0.07564139957990378, 0.06576970550081422, 0.022682823473587636, 0.019172702450305223, 0.039126351100182345, 0.03212748673714457, 0.04789218959969379, 0.03734161521518423, 0.02628231439889679, 0.034237250745777166, 0.03406910976815609, 0.05628088684452157, 0.04851973435330776, 0.05542979763460256, 0.09450947865843774, 0.033776383741848895, 0.03732453145447277, 0.024785895704201637, 0.037939500874809684, 0.08210335122120958, 0.04355307525744842, 0.05993172481295563, 0.024471678996398568, 0.010366179893964962, 0.03792124499957408, 0.07777372104746681, 0.05861178213249772, 0.007004606192030254, 0.032376097590332074, 0.06679137567839315, 0.04551107341784143, 0.010306921077802057, 0.03360266564413905, 0.02428709968714224, 0.01856801009947254, 0.023917251589497732, 0.01822669111612824, 0.01691944825823509, 0.01591153510455643, 0.10616304728412822, 0.022961867169567177, 0.02537488516780638, 0.022442042038986282, 0.02042345781510155, 0.03803356498059246, 0.05811927186685705, 0.03834805556482846, 0.05154250279789971, 0.026153942960644924, 0.03249240505899633, 0.05351645090887624, 0.07857539375583011, 0.04415739222519821, 0.05714400363485179, 0.06295150168420327, 0.023207662649632945, 0.04570810357108713, 0.08559068304396446, 0.0469408271413657, 0.09292697083325156, 0.03331403435778714, 0.018255231721747308, 0.046723036005372004, 0.0646071670757186, 0.014099876017069385, 0.041413659815706556, 0.006922374314237987, 0.037572613706992525, 0.0551047733414077, 0.04594998817229944, 0.03878456480320423, 0.055243006246464874, 0.07938649700654131, 0.03749795460833177, 0.01890086381125354, 0.02120955212552461, 0.033754266783474915, 0.15648554740173204, 0.07930730649780843, 0.2595105376695433, 0.16592949628829956, 0.12506765343489187, 0.1868533186854855, 0.26338541039055396, 0.11075629597349514, 0.1459434574409839, 0.10382592753176728, 0.21630098772866113, 0.09701171334111884, 0.18512044312252154, 0.11416696537766727, 0.22321788834468012, 0.259420384442614, 0.062414749840935396, 0.09246915668970154, 0.12770750049141147, 0.12258719863189806, 0.13758790499020007, 0.17242140196744474, 0.12906355272618034, 0.1579395363167409, 0.08548323155170487, 0.09113367391569961, 0.1505944385163246, 0.12309780389431024, 0.06893746374595551, 0.07692782208323479, 0.12171065615069483, 0.16695709598641242, 0.19288292094584436, 0.17405603441499895, 0.09506168249513834, 0.22270246438922423, 0.23178167881504183, 0.08568302728235723, 0.15636447486617874, 0.07629081997419558, 0.10268462506393272, 0.1608423660359075, 0.1034032155369078, 0.19909223211148094, 0.12110851104221038, 0.21543440439047354, 0.09570482096845105, 0.15444329489142666, 0.19078895750065006, 0.11254992996973377, 0.18066746513209037, 0.12374055166278156, 0.2547688364622093, 0.10906327230435227, 0.10925048121040869, 0.1305166070139216, 0.20752450060700217, 0.1567718804243111, 0.12652711221768012, 0.15624033797892833, 0.16295162059607046, 0.2033636779073746, 0.14573811523375974, 0.1520386061841442, 0.10390005419932066, 0.13975057120044387, 0.08067992155350025, 0.22264663190130266, 0.1022132971293984, 0.0896188652803821, 0.16977924132539382, 0.1440375839029589, 0.09400853376475074, 0.14549855953983723, 0.13460748588606236, 0.10900213848799468, 0.2531689231193835, 0.14852529631987696, 0.15755074669516858, 0.13263525381203622, 0.20829881631558944, 0.14605679248850192, 0.23710128610893605, 0.1036042906343937, 0.2544745208034592, 0.14349461142574588, 0.12165724450061399, 0.16428418457508087, 0.1037792727771786, 0.13087778682670287, 0.09507041589747514, 0.15179097592349977, 0.37594156099423287, 0.1444119710715548, 0.2136447770340789, 0.11891444288795033, 0.10625140786531473, 0.23246912015301568, 0.13707914599968543, 0.22928639254983396, 0.1545749241185765, 0.0755806947727838, 0.187771612958562, 0.1309831545598084, 0.2414572007593609, 0.05566171926235961, 0.1387173330952083, 0.10799877781180606, 0.1174639703165139, 0.107019035626323, 0.15585767706075024, 0.19089150603019422, 0.13872373759025527, 0.21652191216426514, 0.1491512054757726, 0.15707139015918778, 0.10060652729965026, 0.13266030488716019, 0.23793295115953494, 0.15053761011410147, 0.17747067215461887, 0.17667674459517005, 0.11551393947053341, 0.13714902854013827, 0.2070920899390213, 0.14186187887624388, 0.16195558372043795, 0.1656806556087348, 0.17102917506089135, 0.16589068627405554, 0.13586915608855987, 0.14845392756885098, 0.1872570316998228, 0.15005210955296794, 0.13344724572473957, 0.12159056420768462, 0.10457872383056149, 0.20572676804036866, 0.19587297743606955, 0.13872942196265345, 0.20669439837576883, 0.1479162410983155, 0.09424506341137233, 0.09064435057582394, 0.23004826699053088, 0.11900245106869167, 0.1100213725059744, 0.07396456334860095, 0.1132796057349732, 0.15541043493055529, 0.12742649177990614, 0.09061097978584229, 0.11068776940866826, 0.13968393687278996, 0.10997844093869771, 0.21564785180793655, 0.13333113743893563, 0.18380879334384398, 0.1785556671600188, 0.11803896526896185, 0.11638567091957217, 0.08999426368503802, 0.328926928942242, 0.17949075408039555, 0.1468004187148425, 0.08322753928481572, 0.2299486908821329, 0.18751710322835755, 0.11792806638104301, 0.12192316894089023, 0.25714899503415634, 0.10497513602698043, 0.11289270835057383, 0.1379401062525088, 0.0883201853702626, 0.11076974081656626], [0.011321003154490986, 0.05093300324534217, 0.03926301735543436, 0.03270552688909154, 0.01643830482217093, 0.020213992139624975, 0.11458799197909333, 0.02572687767115572, 0.08362429622080057, 0.034914778906010815, 0.04656833604038243, 0.0387576061691488, 0.0488878166182868, 0.0573733052419078, 0.040740774148294044, 0.07214753302715479, 0.052765140820655136, 0.02614325794932102, 0.03331810228466507, 0.044270723442276644, 0.03375131734496644, 0.040910769058691884, 0.038757131194635745, 0.029398595365966042, 0.020279190052420865, 0.02353121413879337, 0.008877690209286108, 0.03458415834052909, 0.0888749096362341, 0.011555892415344717, 0.01063386346363733, 0.022230337471550992, 0.03484366296399986, 0.04792562550714901, 0.04631459239810225, 0.047975808096629, 0.02916418203723527, 0.08472446742798052, 0.06677093645257336, 0.0378513050025269, 0.04548058694889469, 0.024943581496876095, 0.05807422589690936, 0.054661331007317196, 0.1047421074021728, 0.02459481230846817, 0.037879244229125406, 0.055116211034117214, 0.00872814984646656, 0.08099798593790301, 0.03536097915662873, 0.0017738623442240962, 0.01967565257913403, 0.007731697368135135, 0.017693181739999883, 0.0475527513622036, 0.111883977398036, 0.023021646925518592, 0.010603504356808, 0.00962848989142766, 0.03992654142841216, 0.07508063088020972, 0.008571004145778716, 0.09957069981723063, 0.03609285359421084, 0.04726225465175606, 0.0728182889701378, 0.026765147058833993, 0.016547987545509974, 0.03354244730285099, 0.017871435078221466, 0.07230723937672955, 0.0006715493826402141, 0.06705704730965438, 0.013476047747498079, 0.01319240656636295, 0.029774805823821696, 0.02338335725418743, 0.04478224801019796, 0.07973767171103148, 0.017047202995707913, 0.0606491316800877, 0.033041360682897994, 0.09900434633656856, 0.03732908584718262, 0.02867236891160569, 0.06940725184376202, 0.013242951132387165, 0.006946217364466359, 0.02827319879865935, 0.07412102148537675, 0.04372171802265991, 0.027583807766918215, 0.04023625162400065, 0.044551743645100825, 0.04943715911659022, 0.04368246367741977, 0.030847865179361358, 0.044394779890295, 0.026654818906418742, 0.04409516673354853, 0.02441848376615634, 0.046153074250586575, 0.013357779093747659, 0.025700859410027345, 0.07846844788160055, 0.06002249091022438, 0.03354080021381378, 0.026881806927943425, 0.005521579193056471, 0.03953344639270537, 0.06844284673852306, 0.07506558491337685, 0.051225254297136306, 0.021209481262391614, 0.017867386303541642, 0.014171464060763679, 0.008716437319714216, 0.06097072006894216, 0.06121263914411107, 0.01600585010413441, 0.019359773460535273, 0.08405821608199228, 0.05998051312241343, 0.019413853522330042, 0.01593503772446345, 0.013401694126397133, 0.009988714009523392, 0.04729688948681278, 0.031070904017636375, 0.07087646292582636, 0.06917242291233233, 0.03796317682210957, 0.04689634424604235, 0.031683096369247765, 0.062619601751888, 0.03940256410128167, 0.03250560092349206, 0.02155302764637576, 0.02166244415416112, 0.06665632203822175, 0.004330858308446384, 0.04945159604352328, 0.01114120806432179, 0.014330389000655664, 0.01714934549865223, 0.11608706516844612, 0.08982479737530794, 0.03061849653961197, 0.051684822782032916, 0.03492893621085152, 0.060597045362115874, 0.06838269351470856, 0.05852796062226257, 0.04967182333911619, 0.02694865384499633, 0.09596571221106476, 0.02538255945358786, 0.024902423423144127, 0.009919067041107245, 0.015742363738677195, 0.03773757541972784, 0.028037672727218563, 0.06329608037166538, 0.0354016354427703, 0.010374941066989015, 0.04212133353576065, 0.029515831716238495, 0.025218333185259855, 0.008446548374429827, 0.027472838015866377, 0.04905721781054332, 0.07184708866501047, 0.011818622268976705, 0.03306388749831146, 0.04755481979959915, 0.03021481225357181, 0.03541253687393281, 0.02564375521615148, 0.03442972267587339, 0.013351234787654494, 0.01729886479405386, 0.03328448251610802, 0.04946507153011138, 0.095927132023198, 0.023502075984593362, 0.08495505989318894, 0.028183673763827934, 0.07724895081933468, 0.0026683163202007214, 0.005983497652660815, 0.014171571313073079, 0.02428117782748755, 0.04980942805207545, 0.036811348306195396, 0.04082782471913003, 0.11582870967686178, 0.06791518069803715, 0.03266555242120259, 0.06592886792796274, 0.01755695407008452, 0.0450163338363411, 0.05505805729978508, 0.029176625220345396, 0.06563432244283539, 0.05028983029807287, 0.028557691295000336, 0.01803606928836915, 0.03483938819338237, 0.039864400206434156, 0.0077136531246886145, 0.0042131637418342215, 0.023161254958399845, 0.05716155470919706, 0.07868515883362101, 0.05185934910250287, 0.056778154516172026, 0.053764640413705385, 0.02878206121104379, 0.07545227545403665, 0.06825002240798167, 0.02775350198780577, 0.03821176852309897, 0.05163404647441161, 0.011623154935096542, 0.03684669943346131, 0.05509822328965511, 0.027553351941488446, 0.018747060169135372, 0.021594940316713145, 0.01862660241914132, 0.028322835550493294, 0.032885396672833356, 0.01997986800908562, 0.04092824735468434, 0.011406061896723847, 0.07793839930767014, 0.029978815038057587, 0.03241748549044132, 0.04184832278218481, 0.01513783226630861, 0.04290994444501497, 0.017908398820567998, 0.007614219221361583, 0.06810530839908509, 0.010013087096834376, 0.037975629581318754, 0.008524231605171677, 0.024465014031457327, 0.028467266106857892, 0.03100790477718317, 0.02176910083019926, 0.06119752039892539, 0.004384056890323278, 0.03252527406138759, 0.05256363671393164, 0.06201059249560199, 0.02688597827669113, 0.08233801927417517, 0.020654190091356155, 0.028833693621920484, 0.025503003797043237, 0.012912530707375658, 0.013036426276929918, 0.038240251672123714, 0.021014301211483056, 0.012111234339705158, 0.01244445481607991, 0.0071469156424544995, 0.07687152994255866, 0.008262360727624788, 0.013184577147776802, 0.042551074387325395, 0.011873758574497077, 0.07877617007902554, 0.09083221831749524, 0.030508076456645807, 0.06214083510360891, 0.042914525650802164, 0.05508179070367929, 0.04733881747890865, 0.041056988430359674, 0.023387808225027496, 0.04605947745843761, 0.019134486154202494, 0.018635408599830924, 0.06339299049408686, 0.027938018094808347, 0.01882842062191377, 0.005576817484031762, 0.03947178014524041, 0.06987824269960966, 0.043585335219939875, 0.03516746151651587, 0.030350337037816647, 0.05850850198898585, 0.009925672634234353, 0.009395184517357378, 0.08514328769618466, 0.03741335168841385, 0.06286934258476382, 0.057797212333929156, 0.03923103701503527, 0.008107029697707584, 0.0383645647595967, 0.03553908310770508, 0.041186215971866925, 0.09937596792775778, 0.04121498640386328, 0.06895518335964411, 0.04644908679408893, 0.1288596967295293, 0.02060424498913269, 0.03609518250150066, 0.013532697076668904, 0.06401584295916461, 0.0346700482881598, 0.04045844776555896, 0.02358054254023779, 0.008517968836390685, 0.025302727346218405, 0.042811425537952495, 0.024904329066855774, 0.039735777874387083, 0.07280438447431212, 0.06257934000102744, 0.0954085594463733, 0.018332062679673397, 0.05382648669183255, 0.021330900452730638, 0.04779199296007714, 0.06810597489557921, 0.01780701665988853, 0.018613201626125845, 0.027226270702216896, 0.020809878309768055, 0.031227953957333684, 0.041630822759602344, 0.00842492745798682, 0.05882066749637166, 0.01899419438784882, 0.047577764132931355, 0.027093172501472217, 0.027159580833188472, 0.014799518262847297, 0.035736848705358086, 0.02333218066562568, 0.015393887578900305, 0.02855057242296396, 0.051397137614267493, 0.09292785183436449, 0.010456076481439655, 0.10586114735492777, 0.09746019653375111, 0.14276742544626037, 0.14421209873211, 0.1529439995365758, 0.1199606738443817, 0.35931144690802025, 0.1487925997184169, 0.17112680530596167, 0.1037474877892002, 0.1262721121912041, 0.14727117974431286, 0.1479537181195713, 0.16192895450418995, 0.13116143854154697, 0.11649613313737417, 0.24214704761341696, 0.14629829404575212, 0.10558534038042831, 0.18731488665986448, 0.2248347935176665, 0.13695680175817784, 0.09812526810433596, 0.13019382352790526, 0.08209765918793217, 0.10554596346112029, 0.06901683811579021, 0.15041721173592154, 0.2710314888146616, 0.22088210158530744, 0.14654469856571767, 0.13053663255226228, 0.11231249633936152, 0.15611912754754867, 0.12513300839571223, 0.10024895576099235, 0.14790897858479332, 0.18436495785511312, 0.09859353168717316, 0.14060886546729073, 0.13022963047748612, 0.12293544688051748, 0.21084598205502958, 0.16342532340317004, 0.26108114048838615, 0.09259661073766409, 0.16010039455948338, 0.16076499115555518, 0.136616459536937, 0.18125393608164403, 0.14028087258338928, 0.1176974585940761, 0.13736745552910914, 0.0858382826610919, 0.100899065634416, 0.1166193430582362, 0.21563095190832693, 0.1287439408441705, 0.15566568010516707, 0.10411781469179739, 0.14136965206313518, 0.1646870548927015, 0.18042348144996553, 0.1893022413095159, 0.17805694392131222, 0.17828240359742797, 0.2107736633549775, 0.14571211420960967, 0.2656662992892727, 0.08911982794562656, 0.07691645333843847, 0.09624484400715559, 0.10221492889667712, 0.1726543999487354, 0.10527944913314236, 0.12479491081208953, 0.1990728960522721, 0.10894527178137534, 0.08672122963734212, 0.21386937869171943, 0.15081009226700953, 0.114257225856906, 0.25390234505457265, 0.20102721699062856, 0.1304520564454217, 0.2106152363722363, 0.11008937813101277, 0.0976829442586149, 0.10040861614529165, 0.0975167491443215, 0.21572536458411526, 0.13722073436985094, 0.0585656559785768, 0.13797453424382594, 0.09641152941772053, 0.22115594737472075, 0.2504752966905794, 0.1467523083931977, 0.21707983867776012, 0.1414517154015841, 0.15637097129177663, 0.1395358827205435, 0.20581780992929014, 0.09595229035063137, 0.21423040528691586, 0.20893761107037145, 0.11425662830832506, 0.1401309644983661, 0.09121654164646903, 0.13743877831485965, 0.1613562118502394, 0.1614531985814533, 0.10809537383817858, 0.08405422476390678, 0.16471906204617795, 0.13175555504858494, 0.14524783428397872, 0.165521263355209, 0.17838743425184683, 0.2288174548096234, 0.13203320063410268, 0.12593311062383075, 0.19348145011932621, 0.11524439909525457, 0.08280082065011225, 0.12376646075638072, 0.10443851441865969, 0.06659426125547578, 0.1983857151841925, 0.09547857222177329, 0.1536770690713198, 0.2683830309298731, 0.16519956771404515, 0.17296241325957162, 0.17684817975086553, 0.18478572398664492, 0.13599068827686772, 0.12335738512657343, 0.15091942833556285, 0.14693057705317775, 0.13993414118885994, 0.13039129035126779, 0.10561405335583034, 0.049821482445564, 0.09853447396909037, 0.1291966834856618, 0.15716074665467586, 0.09710301569993458, 0.1634539138045042, 0.14349790560382028, 0.15357311093999496, 0.13669294575529714, 0.19347706809639934, 0.12260676451748419, 0.12613438490417697, 0.16411261152355902, 0.18120685231781777, 0.13132617808878422, 0.13846597964725188, 0.07270592685428358, 0.13598961575377372, 0.11588253501442172, 0.09495406246353542, 0.20825164062121224, 0.12546860087182254, 0.10987501906891985, 0.13438840006147662, 0.09745624352006182, 0.11649106163531543, 0.09669505855849675, 0.19016994313607294, 0.1518876102542685, 0.1592027233733285, 0.1460581101597317, 0.18881648027848816, 0.12407963749982658], [0.006668604816490364, 0.04958397220639933, 0.056869223218170874, 0.0658236610733213, 0.032715217901333686, 0.1322077920720462, 0.04032566940652267, 0.025266433930805614, 0.02543006265055268, 0.030847775164030256, 0.03996753096280079, 0.010976841027337697, 0.03877583140086743, 0.03958106641807864, 0.03685094739100145, 0.02529897543060924, 0.012402464579340192, 0.035310168375050834, 0.009790266593617779, 0.05937112082216529, 0.06224120794344814, 0.018043544391290318, 0.03572103665060094, 0.09211073479344768, 0.08312831557686291, 0.0631848520659391, 0.02205693730032973, 0.056699484947227666, 0.008505656845837591, 0.01396680175657234, 0.056484195088306745, 0.03937741343472754, 0.0798085118613897, 0.03618556938524689, 0.017107980581180706, 0.04155750048436946, 0.08249104533705019, 0.04997481111316912, 0.0684125709437555, 0.031802927842363715, 0.045267748571331465, 0.06574293838873987, 0.057787640065315275, 0.12256438453351298, 0.005835576608191215, 0.04054518040990637, 0.06924227480926821, 0.07075712174898194, 0.013052016166189026, 0.06798310205340385, 0.089056801892096, 0.02621465542864415, 0.029920925604059335, 0.05066435919293473, 0.008008145941271177, 0.02407965265334614, 0.015975547496289495, 0.04357772796685177, 0.03288217910355137, 0.032331959434574654, 0.015889075321836338, 0.0472183424919363, 0.09557994863679332, 0.0644162196605917, 0.07672860091852565, 0.03535966148539897, 0.04225094412123004, 0.023541855100061626, 0.005428558882070525, 0.021799686890576157, 0.03735051332642475, 0.041923751799209465, 0.11613477712437031, 0.036057295623205365, 0.05577148817059013, 0.05451180979669575, 0.029402843323506178, 0.03736169437967962, 0.03929982021931679, 0.05009216812228964, 0.02861942840559829, 0.03276990125736883, 0.012426830005771931, 0.04402059573499907, 0.04315911071194757, 0.028484039601960012, 0.04914368998499648, 0.011074920391453611, 0.08119205133088174, 0.032148600120337746, 0.03542466787621379, 0.0487248620559131, 0.06920243823720564, 0.08276981707181662, 0.1358729405629058, 0.05904773978756801, 0.045295082588469794, 0.01864083633277445, 0.07858278650429942, 0.06521446795593347, 0.027747905715518904, 0.04294496998491307, 0.05987686142625828, 0.0356436962442052, 0.06292219499065992, 0.013380574039934624, 0.04184080745964762, 0.01637084694999841, 0.033474771095620054, 0.03213829623775617, 0.07914824366209008, 0.03386716133043651, 0.0717156203163247, 0.034348731860518456, 0.04444847499290782, 0.022561132322035493, 0.03897253596674531, 0.07577492870510587, 0.014826658842784744, 0.0655333673761737, 0.026899513135093357, 0.017969021273236123, 0.03170730283243522, 0.048767839588465235, 0.04656470478362134, 0.05040825599984777, 0.04242349776529497, 0.048248244284261624, 0.0286039668360665, 0.057878731749951846, 0.02713896157670646, 0.07624068718043066, 0.022459351795635397, 0.0056641012328797055, 0.03642946113682082, 0.0435432808233365, 0.042794326455482555, 0.05269736502199404, 0.05015417527888091, 0.04871444326014288, 0.060477780794063886, 0.033549698325054306, 0.007149656322003613, 0.07072822491247809, 0.02420657810064093, 0.015558664472923886, 0.10544851707715182, 0.008240625855603046, 0.10313321550887439, 0.008135260995327225, 0.003897577173061549, 0.02616588818660427, 0.028567489559551882, 0.01924479706963945, 0.06393607788448853, 0.06327992740778193, 0.08437998067106932, 0.037049904255376714, 0.021750301032537417, 0.04409225559943626, 0.025791033704374588, 0.05009784100336894, 0.019936210573500684, 0.03977431975785763, 0.09520004563514264, 0.03849881017700799, 0.05358151475628538, 0.030214230026749354, 0.07962272021799319, 0.024084925253485, 0.11094650794421473, 0.02954671080524643, 0.03542573273842854, 0.07935358586931422, 0.025183232951789133, 0.06022419803024781, 0.040770050198320425, 0.02493324122511812, 0.06986813799988839, 0.018317009051961285, 0.020936482000134645, 0.02501300438457439, 0.04173157481296409, 0.1334011425534564, 0.027635532108345823, 0.030991864811268546, 0.025863432843658715, 0.06693337773603779, 0.028007917872239507, 0.056056610774248845, 0.04750386729175526, 0.04189750562692362, 0.04701031131609794, 0.06324535002931952, 0.028379993370523857, 0.016713646398256385, 0.008244965743694094, 0.02790505333142656, 0.049651173439117215, 0.029884927132497394, 0.04493769108047409, 0.04784165844020825, 0.010654535388664134, 0.055757499405092774, 0.02923066123208452, 0.017880007602094163, 0.04346728490124788, 0.05377688632917501, 0.0737974489287984, 0.047011854983265364, 0.046634265567146005, 0.021972412904424053, 0.03708321375832443, 0.053714300776200916, 0.041537283424047694, 0.06155117722829023, 0.031674866669721184, 0.03704890451063553, 0.03540984024443934, 0.13065447219677512, 0.016924538912491936, 0.08665646456422345, 0.03973691168451502, 0.07705333792874891, 0.06675359988284689, 0.026904237982366356, 0.05671355032151746, 0.018588692558208303, 0.07763863676377843, 0.032231663203527855, 0.0698825098093479, 0.059783808556535555, 0.00855279615103838, 0.027017883295493744, 0.0156557239824906, 0.0452083882485186, 0.03775936296029437, 0.01703613110998225, 0.02580795084096251, 0.04118088399991393, 0.035016749039172165, 0.03680297879562263, 0.03298236425184915, 0.02628970523214629, 0.03910192821715628, 0.010516231620473968, 0.02914328890432033, 0.015792365339885078, 0.05147959548799742, 0.03815147740345809, 0.07390554393491439, 0.06580101551427957, 0.019660497444771954, 0.049885646139662114, 0.05301543323683643, 0.03242212415282284, 0.0264700576512804, 0.08718080578311797, 0.055540075991302736, 0.02937278203335741, 0.01941687573919133, 0.0404482358135283, 0.08269185996464185, 0.04364096086412188, 0.025372659682386348, 0.0060011215053588874, 0.046251780849190495, 0.021003533845707294, 0.023864297676951658, 0.04472166194670624, 0.1666268508040136, 0.07537181323934948, 0.06261743372306228, 0.06809237683492322, 0.08876907458949475, 0.030683993226698333, 0.0259610956474658, 0.012608423487343376, 0.048336003486427574, 0.002648655152429016, 0.06833310464336988, 0.010818218692175804, 0.058383679453043215, 0.04383794122165249, 0.021254500419261958, 0.04425841623977308, 0.05289686580879554, 0.05539204865213364, 0.011285260364773774, 0.033278143138534604, 0.023370230337604884, 0.05695613972362011, 0.009054571292513322, 0.0754377504269923, 0.014792047947975657, 0.032519696941298824, 0.04688394511298788, 0.01389150967776415, 0.0422039216444377, 0.053711991021109205, 0.06339245806297948, 0.08804666899865674, 0.04809978793585493, 0.02983151931285618, 0.048698470326921636, 0.051281856703421766, 0.028213152827154246, 0.05161900050757874, 0.09709337065296789, 0.03326082955144587, 0.036714346253223, 0.016778622145554232, 0.040680199576121186, 0.018594323304451762, 0.03500610424746429, 0.0624367633774396, 0.05977122556237925, 0.035887840804794145, 0.010517298397908529, 0.015319787724424275, 0.023379162922801993, 0.03826282062237302, 0.03670973057347921, 0.003459507748747485, 0.05655728370672273, 0.013992008922110884, 0.04910389937820935, 0.03503834122731801, 0.0723100585802909, 0.01851865296973096, 0.06809826805106095, 0.06354631533125235, 0.005671979010766072, 0.04688649618577573, 0.031095378611597325, 0.004383296069253477, 0.10297637432813646, 0.01875989405708688, 0.008682460362662472, 0.05488804706762876, 0.06770632980811982, 0.03817784998025145, 0.07167320968883653, 0.07392441268048941, 0.03439743590030459, 0.016088290740886045, 0.03499086292821073, 0.05114708651578234, 0.07966502359317196, 0.030763204802849123, 0.02965687616397777, 0.027558821809267806, 0.11220502952534346, 0.1873465873781712, 0.13837720537858625, 0.10941504455742337, 0.1422829514429454, 0.13984971829960424, 0.18522144415445868, 0.21536913369932484, 0.1185608933108949, 0.14565592932124294, 0.09952874884249703, 0.12584000795839295, 0.11991883012195749, 0.18971730774689108, 0.2040387239427336, 0.10327887180591784, 0.1293050542834305, 0.33031900263121056, 0.1317971383011149, 0.11852133253048505, 0.13770879366465155, 0.09668684609594846, 0.10939933209409637, 0.16297944490948033, 0.1389891564125015, 0.142050183288032, 0.22800213807532865, 0.135531495175054, 0.13723435541314466, 0.10120984452265887, 0.21017026186229723, 0.10893427841966191, 0.1680145884353307, 0.10778575174270139, 0.07255403460153649, 0.12450977288667234, 0.19440841650770557, 0.13366135197781748, 0.12635982925853423, 0.13318712823092937, 0.15045776843063294, 0.12723172158603707, 0.19313330912301618, 0.22453024292424803, 0.1742867188107583, 0.20977702893076405, 0.10621488845396428, 0.2762170154000482, 0.10632397171350257, 0.24187196076156633, 0.11802956537013093, 0.10067661668384269, 0.16379768809964582, 0.15376581269646847, 0.16296622223190724, 0.13906810943397785, 0.1844130988202749, 0.14374051032768143, 0.1483888560605626, 0.13898541790343102, 0.13039162742995447, 0.13971574484340607, 0.20167629264535444, 0.12744546777779056, 0.16291492498449742, 0.24306077600246478, 0.12828159146010876, 0.19831872845609344, 0.15665695191391055, 0.07482252819764038, 0.1052245819160054, 0.14223243560521834, 0.1520167420347852, 0.12342573549117773, 0.19036120464724882, 0.17675071804513856, 0.08059904565133395, 0.2626535819182473, 0.10628594310894128, 0.11323324209379573, 0.20096868787321354, 0.19648719609024065, 0.07657909119922308, 0.1359921898091993, 0.1698698848485947, 0.09891665225187618, 0.1971329775668921, 0.07803352444522804, 0.1047059403912675, 0.1729757278676956, 0.20179885139148082, 0.14173616384786947, 0.2130348025070083, 0.1686160440646833, 0.32636445676607473, 0.19786174168750165, 0.17235303628108195, 0.21279975141008056, 0.15510478117052587, 0.1609736428626122, 0.08808992998374086, 0.0904947565868497, 0.21559338295652022, 0.08371299388067377, 0.14362029581060334, 0.05501005423044967, 0.1360539364958963, 0.06450307104856738, 0.1259124262498752, 0.1872993197532431, 0.16651736151787544, 0.12189650142024602, 0.11576859475744349, 0.0895416742611316, 0.13131186756635868, 0.11708233595615435, 0.2083028919033466, 0.16486261160142962, 0.08108670658041393, 0.13631039208942844, 0.15031380518790216, 0.18906858449261035, 0.10578595582515964, 0.1127243605292132, 0.12263504848364862, 0.12386294953044384, 0.10654917091972406, 0.19055219036677193, 0.1245672524636311, 0.18822427899126085, 0.14343580651667812, 0.20937487873579227, 0.16393598229173692, 0.1851973583501193, 0.09554643229010606, 0.15506594051276484, 0.11096641856936679, 0.1287055445174056, 0.09937950725396795, 0.1578099602052281, 0.20649198262441545, 0.07850266136829892, 0.12331189482562965, 0.1960045147326685, 0.10378289637306046, 0.16419968507703275, 0.1466815831560281, 0.0786259172544364, 0.15566549624406523, 0.04624449535303059, 0.10029676730834669, 0.2651194657289213, 0.1805493650176833, 0.11622089306793867, 0.20909692671510482, 0.1203076657088053, 0.13715992231042157, 0.14089740482309174, 0.1061638133720525, 0.19567745647603468, 0.14526729291725546, 0.15858136477970308, 0.09527616413129915, 0.12001714984615965, 0.23276415593441457, 0.11689115871465015, 0.16806190202553428, 0.19460383021543104, 0.3131945473292182, 0.09534901909289822, 0.2030910118933647, 0.14397291076039115, 0.12566819741961457, 0.20794016459295828, 0.08938841837187929, 0.09529072746273973], [0.03996439766319048, 0.06931221097587578, 0.010565975624617311, 0.016248516115029494, 0.03634073666387028, 0.03388183191418648, 0.03302711144750638, 0.03449720353068363, 0.02213722139957451, 0.009849663305607055, 0.03455041216746454, 0.05024494137614966, 0.02978137119733278, 0.03300780986225413, 0.009133427595389227, 0.04578702977948612, 0.020973189103026545, 0.03251164535721464, 0.094993899035598, 0.004752200921141213, 0.023741876826651638, 0.01416232750465673, 0.013992322060549933, 0.03042074243327783, 0.05030903229189496, 0.10286642538924372, 0.07023696337015399, 0.010827322689545973, 0.07417192036706595, 0.04255205114942886, 0.034725873115202116, 0.03727405009070232, 0.06564904665274006, 0.1214271040272809, 0.07602972954872154, 0.02683211463473497, 0.034112734645004236, 0.02824320645642377, 0.03838230735592304, 0.033370686559787685, 0.01418542409796388, 0.005126931871693101, 0.054646361649276755, 0.04185218386532318, 0.011550473300890337, 0.03152663440203234, 0.02473043668414316, 0.012510941671808402, 0.04467022680347005, 0.051551680531232595, 0.026085450869774627, 0.04258148807791933, 0.023051970600781423, 0.03859567816459364, 0.034458573547101794, 0.10191887421833892, 0.02757352112131494, 0.060299113768363194, 0.04700543899689952, 0.06236541377861173, 0.047782577739487735, 0.053655771658785885, 0.08254410458668586, 0.05649971602965267, 0.04826181936227987, 0.03833564877089474, 0.04659613354071494, 0.050118770525460286, 0.03889064882851897, 0.019147410057485104, 0.05132034496073762, 0.038600236387743105, 0.059415063625502015, 0.017291064103764874, 0.08637542520920116, 0.046580731342997284, 0.06257757416836197, 0.02944262435419425, 0.04366568252143841, 0.0903699225595882, 0.03166982964161904, 0.12267765063311785, 0.04896990293937345, 0.06720654170719847, 0.027039785749248924, 0.04567482088121676, 0.0354657263585156, 0.07476425188924037, 0.056719227033036376, 0.03432070453380866, 0.04635803724428819, 0.07955026362211474, 0.03352987580001354, 0.000608758302640185, 0.02111479854060998, 0.037948824164848176, 0.026652949651883497, 0.03584637629589246, 0.051126842642383236, 0.06728363313501881, 0.057676741177396434, 0.09163060450866338, 0.06484697557865612, 0.06501487140814144, 0.06421536672860384, 0.11922771922282635, 0.0323038516686328, 0.06071475477168157, 0.03499211931240655, 0.024636588998198993, 0.0767962234996019, 0.08249133645046143, 0.05217200490616022, 0.042431894088945085, 0.06601183525016231, 0.03963336724066927, 0.02770515226368462, 0.0063220237667161614, 0.07989825906171914, 0.023804609851551153, 0.019005842754737507, 0.052255703842327486, 0.0028456462830710677, 0.01748096963931476, 0.029753091061607968, 0.07149204521650268, 0.06788241511751568, 0.020597449789244323, 0.03860929537744772, 0.04708114380557691, 0.028139642860379913, 0.05364816057525816, 0.01395257167337883, 0.025146974010332942, 0.015123994803176293, 0.06368181330241984, 0.02281422287436022, 0.01964344624279728, 0.02473204929922377, 0.02981848432682455, 0.03889419964604801, 0.020773667248807127, 0.0816906443346412, 0.04890630615033931, 0.00996989793249316, 0.051371672851664406, 0.03163662930620054, 0.031527850566612135, 0.05286170620351069, 0.02937919227406383, 0.03892717973118828, 0.01460892516338537, 0.026657333590030193, 0.030444839728936076, 0.09434275494347658, 0.07449946125909206, 0.046646469347779794, 0.04592327085594016, 0.03685924412322141, 0.04715389917574583, 0.030351585761133223, 0.047508394871387756, 0.04544599041823418, 0.01704681420608634, 0.0053434886485188, 0.024001879407273188, 0.052750255732286366, 0.04697607484676185, 0.06993910838519374, 0.02166634928735514, 0.04433525102813879, 0.02614405085032265, 0.04871772977733805, 0.040479105326437184, 0.042677386964280764, 0.02482259323099448, 0.032276000542145585, 0.038972926671586694, 0.08139331028946946, 0.006028832341994971, 0.04172597087979798, 0.038896126357177575, 0.013590643967261479, 0.09220818117741617, 0.057037463787222104, 0.04652477628100784, 0.0696348106007903, 0.026892735172183286, 0.03798561170697212, 0.038552294605441635, 0.01665005152444205, 0.025980586839479305, 0.022472944110631946, 0.03488967420473214, 0.07646740324074223, 0.029190552698808814, 0.0190362315474739, 0.07106529593828224, 0.033621013449925574, 0.04228194003864642, 0.033440182225838784, 0.042144442577996565, 0.04860524508741595, 0.06617678164113915, 0.05025305807770741, 0.04904960289657597, 0.02083952782765752, 0.041155449880827824, 0.0437725096520397, 0.09418491018755783, 0.057394269237955736, 0.03639866057182512, 0.05203144309381324, 0.056659295974719914, 0.028673805326463717, 0.02663355996651996, 0.02770365073135303, 0.07269009947776794, 0.04248194261303833, 0.03382557424746695, 0.010917345681528171, 0.031033049698077866, 0.016816790561161695, 0.05661380184333652, 0.07975395107942243, 0.034706809017206394, 0.041203648302583926, 0.014240362178233844, 0.023034628285395525, 0.016227209294635444, 0.02442501083527121, 0.09157785169419744, 0.050460955188159025, 0.10017680560028362, 0.003338183601191568, 0.04880101885646582, 0.04654632633431785, 0.02297253302869297, 0.0275867399684484, 0.053181567064095894, 0.03558996666763579, 0.06078376397190075, 0.02620511571876705, 0.033455664862788496, 0.06422067954835874, 0.031435058166783665, 0.07892878245442145, 0.051640156025607745, 0.021084608930733897, 0.019852034747600555, 0.0392645648530414, 0.03685995658499099, 0.017242197270294832, 0.08480996284033022, 0.00672498218444807, 0.021937230316501473, 0.005676635867735792, 0.05166832507858354, 0.044225156532540444, 0.07340266083877894, 0.0732635545934881, 0.047218262052704255, 0.07755572306773356, 0.07856371857586407, 0.05881632760828061, 0.005523780738228873, 0.0289386457523271, 0.008865834041047961, 0.009705632072572988, 0.01829869572013136, 0.07623124131632429, 0.01800796535286692, 0.011828306577949515, 0.033387195754555926, 0.04194453193415557, 0.038444923552414106, 0.06348964780749333, 0.06713365610208243, 0.061627211454775066, 0.02779544530166013, 0.02887035858997655, 0.10116253859333454, 0.05456684938361568, 0.06359155282318112, 0.040096436747379845, 0.028303256258368496, 0.047670728902542786, 0.0429251091554761, 0.07325717308107885, 0.04287462396126601, 0.07451725748157309, 0.12691636915288626, 0.02968771694858949, 0.10702167862966176, 0.034220534707269365, 0.00581630758167575, 0.04609512352955438, 0.025012971825837612, 0.03279306775619907, 0.023596373747193047, 0.04920499617113702, 0.03545614642902248, 0.006248693351799082, 0.039517764572895346, 0.021858438173489227, 0.02760635181930998, 0.037944729424892895, 0.010902235554831644, 0.032663821062493714, 0.04121558395244422, 0.0035207361290832202, 0.04023099626084009, 0.058608813541791135, 0.05506963671876058, 0.058215553797180616, 0.044668384362012155, 0.03814049170262391, 0.04782455169685906, 0.0848180833723276, 0.02629563475268022, 0.055766416668531396, 0.07875668080223185, 0.0685963784194281, 0.024508941513035568, 0.020771696487621918, 0.07591523770843783, 0.03589344473796026, 0.03723453910600755, 0.020468869592033086, 0.06211979449876855, 0.052382931894352364, 0.08305517716273185, 0.0571904132413047, 0.014497114630836635, 0.020994053507644325, 0.019963408610032454, 0.028188839111657395, 0.03279312138235377, 0.05844731071603395, 0.010807327794722252, 0.017995547067614335, 0.04808895162216598, 0.03421432939508269, 0.004140742577522272, 0.027006141082834334, 0.0017420227724810943, 0.0309164377094637, 0.006815797119821993, 0.030856962473462188, 0.022716885657920953, 0.011165358986134731, 0.03790953534565145, 0.1538536216943495, 0.16003961314357099, 0.21379079339244675, 0.08499930913169539, 0.13755980488513747, 0.14496948389757067, 0.0682109595847226, 0.22081802599132064, 0.11540933782535216, 0.16023079804595441, 0.21303186072937905, 0.10679823376478688, 0.044731605767963395, 0.0835554862034417, 0.17791362419243784, 0.16501961366063164, 0.10848658429759164, 0.13687551982941168, 0.18332192914620524, 0.1401536253791663, 0.11859463948395946, 0.1092489260519224, 0.10827003422403529, 0.1551495819923378, 0.1927504183784608, 0.19440970353541837, 0.19500023475097072, 0.23314919172515794, 0.14948748743101475, 0.1486017212512032, 0.21235460836079814, 0.07959548579228502, 0.14749414197379543, 0.23135875231556355, 0.19268396791190873, 0.12399074831797231, 0.10538483218800639, 0.11494324227134067, 0.12649977053966255, 0.10589812641903278, 0.12022729542466903, 0.08532410742895258, 0.2698878727612957, 0.11512033115591734, 0.13016655079780087, 0.06155736721871842, 0.07981708438526239, 0.12438468605039582, 0.14274143974386877, 0.2012041373358619, 0.07301547234096835, 0.13843665380151043, 0.15937898488294694, 0.10757554487715806, 0.13268662766823847, 0.22436012543978232, 0.2912780894867836, 0.17143284210995322, 0.1825078075090724, 0.14644403461246722, 0.23279214878716778, 0.15039399927181585, 0.1390161993162286, 0.17448236234486106, 0.10749299890331684, 0.2450039427006437, 0.11914913392355365, 0.16972114121721638, 0.17121040082025915, 0.13656280273872037, 0.14147567863185562, 0.16562545131291115, 0.17376769424205826, 0.08218510046360955, 0.1657218711390611, 0.16123215157178142, 0.19563827873958697, 0.07403286774792979, 0.09102985368020113, 0.20347105279084177, 0.17641861892996297, 0.23031175527120792, 0.12816927530953, 0.09443569673045028, 0.15130507699664564, 0.10425555730058302, 0.2166996598844567, 0.16302349496512644, 0.12853554960700775, 0.08018273049064222, 0.09063378622334811, 0.13721357910863816, 0.1168938170397474, 0.20150344788787827, 0.11865025746726221, 0.12536283477299637, 0.06451738923187218, 0.10390940047199689, 0.17430285262244363, 0.19865418303637736, 0.12890400725506967, 0.13938995829272655, 0.16342932238213478, 0.147079351328073, 0.14930043940342244, 0.2274863463976691, 0.09876905009150506, 0.1487559807156363, 0.2656305076614503, 0.20789418399574297, 0.12386667271775585, 0.19888164986285473, 0.15725583348783756, 0.14634098046489302, 0.23006642327433635, 0.20790195212729518, 0.1317531648542612, 0.1878018581098126, 0.17685919609521666, 0.07209883281780828, 0.20670918387270745, 0.10064192056175202, 0.10423851950514702, 0.07806407603164835, 0.08237554226070642, 0.10964523099603192, 0.13015230156240926, 0.07273886863502764, 0.07644540885643614, 0.07365783706547753, 0.18668235850430306, 0.1066655473363015, 0.13800721555467577, 0.14532713970590025, 0.08104060340913073, 0.18036838440645128, 0.15910578260739006, 0.1540466605295097, 0.12507521472270453, 0.16393694756252153, 0.12066630210967795, 0.08865346426084157, 0.22818678058683875, 0.09776621035510495, 0.15524831540401907, 0.17688498261474794, 0.21152931716172926, 0.12195591919965322, 0.12395215280834707, 0.23340089757355953, 0.14686959645440503, 0.1851921183087172, 0.1112325881577788, 0.10826978907589951, 0.23338602014607002, 0.19901465804826832, 0.1822129862322923, 0.2152180918041737, 0.06588250428678528, 0.12244711945494338, 0.11448663088583177, 0.1644689036953834, 0.1440373693983401, 0.22778591741957974, 0.12534237256453884, 0.16536046149990252, 0.1065925621397553, 0.10067634089218994, 0.15333672685007896, 0.16074435274687507, 0.14297552557001192, 0.11783602091694072, 0.0924990724231447, 0.10330992901036817, 0.12699152237825817, 0.1153976779671446], [0.03746828019258477, 0.043796151125382994, 0.04135971190407872, 0.02721350193173895, 0.028603794466283534, 0.015759734782360254, 0.020045265104741822, 0.06806842892641021, 0.04311743935930633, 0.033617776728445486, 0.05215633840810868, 0.06304920470762639, 0.05033921232567199, 0.013991879644773662, 0.025288202319174044, 0.03188239222752952, 0.039778437480450644, 0.021522832290840246, 0.033049822124021674, 0.053501753512048916, 0.040681613008341486, 0.02082057481241082, 0.022228998732903314, 0.04708027812622247, 0.022144409219524073, 0.021517416049215584, 0.03157117666916982, 0.01481648711037011, 0.031926409724438866, 0.04017673042272368, 0.06489441174292757, 0.06065255609310924, 0.01701266392164173, 0.01870914647776273, 0.03265470078575515, 0.05530970186115273, 0.03262714460311878, 0.05757693141218155, 0.05579708699857997, 0.0416681312415148, 0.039134889150098454, 0.06271940002578401, 0.03434595862223256, 0.018306546206135425, 0.03745871941528974, 0.04292744572364515, 0.05178202401786562, 0.017545499140396714, 0.04613864115409313, 0.052631607865013426, 0.07897384374612763, 0.021721182030535514, 0.052391814683834394, 0.041815729571446296, 0.05919495507353737, 0.0523842993612972, 0.06989708846254696, 0.007235826849336586, 0.08101339962693953, 0.040686113774896636, 0.05831424124358643, 0.03861018020900027, 0.07233612855235416, 0.05595136178477157, 0.05600478109573165, 0.05404766010601194, 0.0394651917890916, 0.01403930719055596, 0.05589893838811306, 0.10124513819333046, 0.07899867265575355, 0.006637513616888394, 0.014569119234839755, 0.0506317813039547, 0.05338371468467578, 0.01619455479686299, 0.06584770857326447, 0.04354133879044845, 0.0222608354318166, 0.08776815773378457, 0.06529105376572379, 0.027682497128543836, 0.022373145836735928, 0.07543393530912938, 0.04443040297877404, 0.046479596245673396, 0.06794151113999468, 0.046819566914270964, 0.013407952107128598, 0.015233686145004487, 0.036411266548619155, 0.03530997302263014, 0.0034436214792226715, 0.02012592267184969, 0.03808659741715078, 0.10351597601848264, 0.06758438393233285, 0.007964023586077196, 0.04227678809735564, 0.013420291868368945, 0.04657877015791113, 0.09314637075388625, 0.009007577544018146, 0.05606996368676905, 0.07551645830033288, 0.03323009027348411, 0.09302369709457121, 0.053108804033047734, 0.044810926511643395, 0.02649920538157946, 0.026579464582966703, 0.01921879987592899, 0.017708564785519437, 0.05057929278982263, 0.009202248146457058, 0.057475635436393564, 0.032151262275874615, 0.02849909322967212, 0.03889533728661557, 0.06123061539725431, 0.021947637620952823, 0.08664984556455767, 0.06698640634215648, 0.05196203935831305, 0.033475238409253864, 0.05080564878880978, 0.03540583360459536, 0.037569725555517984, 0.021698942498093652, 0.046814717577710274, 0.04344276625723128, 0.009700269457103025, 0.08812617360343857, 0.10028672389565937, 0.04069597332648212, 0.07546554409688519, 0.022670374544818076, 0.054495986250619737, 0.04811295698727331, 0.020604863605131547, 0.004746843572525729, 0.08543570345688252, 0.024465259179593097, 0.030087141785770658, 0.05124788836485917, 0.007598235754431376, 0.10751378286870257, 0.03989468366208096, 0.009891765582705698, 0.04416156740438554, 0.03139338681414243, 0.03538286245818581, 0.03581907292227111, 0.0322617934415898, 0.040754820370385726, 0.04577984004431675, 0.04792141968444471, 0.044128993345845136, 0.03784848579896554, 0.021675843031956785, 0.055268421213352875, 0.11072644918796518, 0.011698000767688838, 0.014398205018932781, 0.009924994646421364, 0.08221291711614018, 0.02405675620050921, 0.03968597066798999, 0.040246612963176547, 0.06860242285315069, 0.07395160114092213, 0.029590048399122975, 0.05593246622611919, 0.04550104149647298, 0.03202605861118965, 0.07302366948175816, 0.0051944246966271635, 0.010295064909563912, 0.03033928813472871, 0.05754601976443684, 0.05926254318065702, 0.002630531187957874, 0.06431538716799791, 0.015003494918346407, 0.029190225196221185, 0.08841506535968474, 0.032241775564128355, 0.04647638250683104, 0.02556652014684533, 0.048234650054045265, 0.01608858185429727, 0.024815704185335387, 0.055070720733173435, 0.02781372032909384, 0.034601433623221614, 0.002719817299117905, 0.03890674816624772, 0.0129803687506806, 0.022799536968851765, 0.03180183808229143, 0.04475297962105082, 0.024430438568214738, 0.05837509926829127, 0.03606550042487441, 0.0643997181267027, 0.058224141642811804, 0.03498934224368103, 0.04316191459375043, 0.06773304329403947, 0.007295486904049834, 0.023505253334259315, 0.07466010989681368, 0.045420766973327246, 0.014648726303881456, 0.05223749393236734, 0.03796716047931583, 0.0627570187733058, 0.019228362568443822, 0.03009048192912052, 0.05711163258961132, 0.047513144616518295, 0.03008247247987217, 0.02969824874232854, 0.032971830542890296, 0.08871756283746612, 0.02958588471125451, 0.017777064537268975, 0.02522979003016747, 0.057737105075390115, 0.01845989785637827, 0.02163174509581539, 0.029041259399344845, 0.09403616655617954, 0.016960648466802893, 0.060450481250882156, 0.015766621912799535, 0.03396425914439944, 0.030790603937461015, 0.062084918346015684, 0.08060852215895731, 0.10028513043277687, 0.08292051422740183, 0.024423932566517786, 0.05339084696325083, 0.09457681012610275, 0.11488527239811037, 0.04145793969772997, 0.021515638725231254, 0.03776617731238085, 0.038943156494849154, 0.05053252312204531, 0.026861549648005637, 0.013973022390517497, 0.0390613217267298, 0.027572858455260436, 0.021218967346114018, 0.027489103977718664, 0.025994426217831434, 0.010714991217208727, 0.04224926255823624, 0.06451518289865026, 0.04853935003460896, 0.016180887788293824, 0.059308542930070436, 0.049137898360288916, 0.01731811466837122, 0.0025297755435589823, 0.061946229618643565, 0.04395543229615977, 0.011145987495359395, 0.03331639390859393, 0.01505981291448998, 0.005999545758259633, 0.05524971717668157, 0.07045497667164573, 0.044187744628758206, 0.039012916461234136, 0.03340855811632449, 0.06445438616097936, 0.07331550301563355, 0.0388516741053712, 0.07315673129332644, 0.08963064005177829, 0.041535755078638756, 0.03382105432871369, 0.049706875692091645, 0.03763444083292158, 0.014846165356556735, 0.034377234161741314, 0.03791323938076535, 0.06195770561574929, 0.04011823960970487, 0.03714678373428122, 0.034501382540310585, 0.05490508486306476, 0.054406602942054315, 0.034879029413024266, 0.01542211791891004, 0.06268427489445576, 0.04041111502315729, 0.03303577973236961, 0.03661920962434623, 0.04138081762639265, 0.015729820964136915, 0.0361744036537505, 0.025144484224579027, 0.027012482375627565, 0.032879283291197596, 0.03419749844338625, 0.020621430256494114, 0.023400820228421403, 0.06234849089636438, 0.01606296387410933, 0.05667090220677276, 0.006770093750674278, 0.058524030591211015, 0.05541672051373509, 0.06911567111890163, 0.029205713578830325, 0.01857284219905494, 0.024343543130183415, 0.0483640537957751, 0.09527492306886182, 0.009221763278718197, 0.03741781798101241, 0.032248716320722334, 0.04439132100331687, 0.0237996245343839, 0.06313276191752765, 0.08340688046788977, 0.020731737341491446, 0.026923246538987564, 0.03080573417396555, 0.0436149598399718, 0.02405697645078744, 0.03812513930062133, 0.052917967700669845, 0.016939441237839, 0.03495174264835735, 0.019033902640184088, 0.032236290374590505, 0.06439881414295205, 0.04695239123858271, 0.01487863886605708, 0.024014102340105082, 0.06865627117334835, 0.03981046761656481, 0.046054723882867445, 0.048590329355530204, 0.014522269127830384, 0.01042172892935454, 0.03106430800060832, 0.1627486226178946, 0.1594793270792692, 0.11047175559665888, 0.2079193729666933, 0.17474217340350154, 0.12981433421373367, 0.1670390980378274, 0.20838228925581903, 0.11454657726590672, 0.13493786896428756, 0.0641643874076826, 0.0955875329072437, 0.13536787411618617, 0.13671105607382714, 0.11535393434666819, 0.10580724540857539, 0.19862101142925603, 0.11995452215834973, 0.13219228645245876, 0.18918941188002789, 0.09924776311362944, 0.08421863489333661, 0.12895245465540117, 0.14513229290323873, 0.08591662281222882, 0.11876190712134685, 0.189409677480017, 0.0841179249748107, 0.14479838582056184, 0.13259101989528826, 0.13495593331754208, 0.1497753219859254, 0.1520132486738505, 0.11811042595053874, 0.13263225074737303, 0.1665592512055751, 0.10581320557262629, 0.1400489471251926, 0.20211581260927264, 0.08212539923167037, 0.13778575485752476, 0.2805991915445174, 0.11923979276851301, 0.12790607048138497, 0.15341040918663626, 0.11095774645406394, 0.1320218778545818, 0.173232443931122, 0.1939534522112339, 0.19053360507372888, 0.17366405786766162, 0.13225703620381896, 0.20292414262169794, 0.09451725445086918, 0.12649159638151047, 0.13696115313758775, 0.2757647170895531, 0.0908036815423158, 0.22355518153598233, 0.11571491497658914, 0.09518612581755846, 0.14816595511811395, 0.1575832135013996, 0.14138980017554376, 0.21010132927087047, 0.14937439753163248, 0.16598151365835823, 0.2489236928522587, 0.1977368999993609, 0.15967106356495814, 0.1726698596030474, 0.0873385739302443, 0.14919127187421247, 0.08595984549291673, 0.14539811009120557, 0.07298825323701867, 0.22111888404094407, 0.1195597953553642, 0.19098038755116925, 0.11642965968818435, 0.21033037423847184, 0.10963233007538704, 0.07083700939772591, 0.1778763003887669, 0.1275120331575313, 0.09880899391587704, 0.1965362410391531, 0.2850049325535374, 0.12705776600107072, 0.13709477419334073, 0.12664252336347295, 0.11329822933241246, 0.09753514291538347, 0.1331888136243628, 0.10889596636256865, 0.25382163003087044, 0.19374227241402675, 0.26565140654002467, 0.21615379159488987, 0.11943332956082399, 0.17493403246325834, 0.1400386509034903, 0.12455864929624143, 0.13579251665261485, 0.16320450621987545, 0.13449507014405343, 0.17228234168742934, 0.17627871595323089, 0.20485155855215367, 0.09359511441641277, 0.19225754805149572, 0.14847801337319036, 0.15466031227861682, 0.19840028617651234, 0.21068982269254424, 0.09227049476917713, 0.12422796744372576, 0.14203331403193936, 0.1261108583440223, 0.16301987903012385, 0.19254011192148734, 0.1479958682771652, 0.1351220211795261, 0.2317851108889426, 0.1919316542485068, 0.11443606908282927, 0.18442973824999026, 0.06808607959218564, 0.13850054553439542, 0.11327074975856852, 0.18961144971751398, 0.16588083438334927, 0.14314458585314213, 0.1407860616041768, 0.08744941919200844, 0.1972172012732875, 0.15191826909299821, 0.17239158582543174, 0.135500637153464, 0.12568048546992003, 0.10515686740437824, 0.33776111780635776, 0.12338466551755706, 0.21815855176218096, 0.2653911817939051, 0.12861119312865119, 0.2397632118194334, 0.07743442836668223, 0.15627427567397395, 0.177218200218293, 0.17307607006401787, 0.13845782847173754, 0.14017521373687253, 0.19903086846874607, 0.09808153980561803, 0.09576205539727405, 0.1302029246524457, 0.19818552108781956, 0.1562073808764258, 0.1101255528027973, 0.14033451405984743, 0.1754032613168801, 0.06061266206445233, 0.14844692552522307, 0.1006567520239661, 0.2410955306503081, 0.11609670255453357, 0.13071096352031156, 0.13574224596302356, 0.09006546389672065, 0.17704946169209096, 0.15016466319080324, 0.10736383647928316, 0.12841328197429258, 0.10847641831083644, 0.1441353214003386], [0.0777773523042279, 0.04543825676063857, 0.0765215733178681, 0.07832417054282081, 0.07231126133833202, 0.020052736377223365, 0.03100859425631502, 0.002976086637523446, 0.01342171008863877, 0.029887985738535083, 0.02427780895584053, 0.02843979227867338, 0.018719425462486766, 0.059150847561296925, 0.056524839883129445, 0.023647278374541673, 0.021705712800124483, 0.051772137653202786, 0.02748292739382915, 0.07269698660820723, 0.08656759836500691, 0.01915903352651625, 0.034912369559488954, 0.0657042509485637, 0.02861492380860352, 0.0314089345685657, 0.046293027023033756, 0.06617171013908041, 0.06224552101846184, 0.00901263755475802, 0.023333664960978974, 0.03546293013759198, 0.043362292551225236, 0.0272054388563359, 0.053901973165451526, 0.01895346532335445, 0.05335218633615202, 0.04823042890958248, 0.01902959339561001, 0.05294655044112475, 0.010306139668119291, 0.06965688159388882, 0.017136555660756368, 0.03301034944372312, 0.0588655066225798, 0.12143019136161574, 0.03161321574401471, 0.007379520524879017, 0.005319743753305727, 0.07553800835364288, 0.013200965683696973, 0.048028262136804487, 0.05033631651331821, 0.05741337164034767, 0.06620603087808817, 0.02045694351827185, 0.024245047205758673, 0.02504208125174046, 0.04311668093226129, 0.035584956452611, 0.023914156594283642, 0.016939835773120006, 0.05426612539937901, 0.047653928594363314, 0.0532096480169604, 0.06968974676584044, 0.013651622650814394, 0.004356182781198333, 0.018752143162512974, 0.03611792382153292, 0.05156858809172146, 0.014796745982171308, 0.04602213833300818, 0.04749121534968576, 0.05810221108878332, 0.043600553556555705, 0.03497422349849536, 0.028565141500063965, 0.08457978406260092, 0.04523715868051495, 0.032154460692958485, 0.04447883888778668, 0.0771036469227364, 0.06538352057818445, 0.05276972585688195, 0.03979762415251425, 0.08083165292778323, 0.05941926178732707, 0.0898857856349599, 0.05186090043054954, 0.04115974763408303, 0.01824035046381816, 0.022511731142238266, 0.04033402742577657, 0.04494239102988955, 0.09263027264105697, 0.07658524288525505, 0.07146761467259738, 0.00994094938505441, 0.09747263780164142, 0.022053193045599807, 0.04223979754193176, 0.018048839974066904, 0.06340605995407508, 0.06630124794619699, 0.036525547714723695, 0.008610446182560296, 0.09572615651714225, 0.062578868856954, 0.03317317377114969, 0.03485282154513463, 0.017557649294875802, 0.04892167770453999, 0.024927129758702173, 0.03797578279890361, 0.02265282730091243, 0.02524353173230925, 0.04238852585155157, 0.0257382923812275, 0.05503314412048748, 0.020089826524077405, 0.044559687976875616, 0.0022952990125744577, 0.03779959789807758, 0.027273335313845067, 0.029574694081900582, 0.021933250489734837, 0.060486406944091284, 0.0036769771278129834, 0.028040897957379782, 0.005055069951565876, 0.10532834852534918, 0.03335237322795776, 0.008461195975542068, 0.08103209217229197, 0.030998334423789096, 0.01586654276076344, 0.05856341517139828, 0.026314641394081618, 0.05971291478002264, 0.05703979269451192, 0.009511160652994389, 0.03153585235498125, 0.021878343052981843, 0.05379575507475003, 0.014481562088363835, 0.02421323923514255, 0.013324528005004171, 0.030160617278588396, 0.017911145245776545, 0.04692217673084909, 0.03252417855565587, 0.026348069640657595, 0.03384104539309779, 0.055943045900353504, 0.021967536754786007, 0.034391736206147945, 0.012731504130868182, 0.012714203950318118, 0.03378123307840959, 0.015777825948692138, 0.0545124801236295, 0.10007041897023879, 0.05387880283618166, 0.024907052509426594, 0.017559834560679815, 0.06943319924175739, 0.03990879117120658, 0.010955329278423902, 0.09162289000326589, 0.01777088029250022, 0.030680609033292824, 0.038291855354703246, 0.03761046611133122, 0.06454379628262212, 0.06224600365385414, 0.02275951270524773, 0.05255749651921853, 0.036197769335441055, 0.02921747877412746, 0.038935147045600804, 0.04336968913013416, 0.09052877089068775, 0.024056809826663906, 0.035531043014939756, 0.04986716426848885, 0.061938603213357354, 0.06052847283201353, 0.0376311696374849, 0.06611994557803677, 0.052302944654178236, 0.018529650161884004, 0.04755203890043402, 0.023815047799519474, 0.08633127556212487, 0.06341573181411912, 0.10697023582554634, 0.051069972105324275, 0.0325774293272726, 0.059699944911464575, 0.0420739509976439, 0.08877227683701823, 0.001247893547594187, 0.04155945400857637, 0.04825508927986507, 0.03215912999885698, 0.03470927582032258, 0.058801285471887364, 0.01713230961843604, 0.04496927305515255, 0.03764383690131288, 0.03750406032908828, 0.041489736177027225, 0.057435212807068904, 0.02538911142056027, 0.028716713911102667, 0.012916902196593584, 0.05157875024803704, 0.03183284357580687, 0.034053332187355526, 0.05241724497248089, 0.04849063067306434, 0.01907927994315903, 0.016750832306100957, 0.015351454926384313, 0.09796873335876773, 0.05986956443877951, 0.048703465220187946, 0.0391824517188774, 0.04618758268113579, 0.04735277177044942, 0.01986681641409955, 0.04629832835146978, 0.043564738946095596, 0.031226795249348207, 0.013650799106295793, 0.02545600621810844, 0.05557510536164046, 0.054679414512769836, 0.004378176207894519, 0.026866726487153963, 0.05794536224716614, 0.004994361792811223, 0.01464406465886221, 0.004616323736451206, 0.061301754321903, 0.019102712657542962, 0.04270242654808587, 0.06071117331063556, 0.10127421889093616, 0.024856611365272153, 0.04205622372307605, 0.020884692541233475, 0.011425116418620512, 0.05191477173338494, 0.031724503421555125, 0.023542104078637018, 0.02471746298514547, 0.02306146817582269, 0.042809123443740035, 0.05046173276740217, 0.03417181534572475, 0.03776342322629306, 0.04004288337103302, 0.07062847260385752, 0.016786687136177095, 0.005690230576757101, 0.019786593601888707, 0.016489881691673113, 0.06349000786881774, 0.010273647964030746, 0.06253709025200337, 0.03252261573629033, 0.07934028658294871, 0.01741869626716981, 0.03819520570217602, 0.027283798159670927, 0.04598532014736726, 0.06607829337759365, 0.05283467862154207, 0.023570610210299495, 0.022875605669293194, 0.01344970868705141, 0.018424108143775694, 0.01929142501115078, 0.055288079029489914, 0.04958878706900343, 0.02605526509033817, 0.059419380530955336, 0.03248172962377149, 0.026764492053658735, 0.01927470514220336, 0.017588103205085765, 0.019775835812212, 0.04662438303292279, 0.019338315337776177, 0.040610363000943776, 0.010782346625121371, 0.06667557382775892, 0.018590642251975594, 0.0699853647740618, 0.047643222515621496, 0.04554758133787302, 0.032538159660273985, 0.01610240782611072, 0.03672437434415183, 0.0363539670023226, 0.0692286154615783, 0.015881644268970818, 0.07234656266988286, 0.052220942602763255, 0.07388777069507108, 0.048378912071066524, 0.022191144413344806, 0.046199648565943205, 0.05069914724557631, 0.016665668226778507, 0.03963454701607266, 0.03886753212540381, 0.06528970545097705, 0.03189984562566444, 0.03600326344190586, 0.02645845524966717, 0.0364605987805032, 0.02622492292204932, 0.027651759765801892, 0.0708709394318923, 0.047255708430443084, 0.005313991869409239, 0.0982798186821803, 0.03153998731455255, 0.006421166556631967, 0.027985896674856067, 0.045810200108755986, 0.05005263032451753, 0.08163386189769353, 0.019228123165967486, 0.05012970260013977, 0.02952040334592664, 0.07033529075523538, 0.0034088173866151806, 0.017744124671744726, 0.06354342717977782, 0.05133756661727544, 0.050815910536555514, 0.10906468956701218, 0.04701414941659859, 0.060364112498298775, 0.07651451764808548, 0.06832630178260227, 0.05981931290138633, 0.10274437992202659, 0.2510084325988447, 0.1470920377440991, 0.1438558525255611, 0.21339035923442534, 0.13567027966341666, 0.14784710932402842, 0.21215009352853223, 0.13466710284832986, 0.20402069023299604, 0.1513171505423323, 0.11374188617112176, 0.13388314975365517, 0.08131263357016348, 0.16028044054344778, 0.10917601746416862, 0.12047361567496293, 0.14634467300868806, 0.1401457806388217, 0.16841244853792653, 0.12951381324279693, 0.24551584265164791, 0.10595812642526244, 0.09845187436909446, 0.10834059092186152, 0.13564196505373524, 0.12507623361964382, 0.134794196834968, 0.20101767153509204, 0.18818192965080663, 0.12225211177381778, 0.1547114563084418, 0.18939112283049092, 0.11624494056788184, 0.10857550412296288, 0.18066458464149507, 0.10695160456722784, 0.09597771680883824, 0.13957705228559433, 0.10167371076081069, 0.11824039276689292, 0.169782780651604, 0.13827785909656556, 0.09222184052510608, 0.08256701061562186, 0.10259507704646358, 0.1595484282100393, 0.1234280184331921, 0.11208946516196575, 0.11890557158978717, 0.14088297172659828, 0.08820782325440839, 0.0913083496233148, 0.15877233517746772, 0.12062921579326354, 0.12014294914420574, 0.08621008811338295, 0.11666775981505072, 0.10206138955489283, 0.13370045310547277, 0.10794409445577091, 0.13306697500088524, 0.2061446383595467, 0.1730371681192229, 0.16374153385479606, 0.16014113511529662, 0.11118404116601714, 0.08170588182345515, 0.12013302064470707, 0.08341031254179056, 0.16642313270318895, 0.15658919909788718, 0.1631194857820388, 0.12537948952447023, 0.12845455113077356, 0.1307258103042841, 0.22461310299413823, 0.10135855751052018, 0.16289059403202227, 0.13982554056471394, 0.11895650111499334, 0.08774617101035773, 0.1934035236556684, 0.10982707728661838, 0.1387155404494655, 0.2657790367882098, 0.12369425696951729, 0.315488183930997, 0.23738642403435326, 0.1630587809749188, 0.12087172092569452, 0.09096130413273651, 0.16009584399721316, 0.10160627204083628, 0.14370750725990342, 0.21597630434459258, 0.19194325281968042, 0.2230933377699506, 0.18774921254765606, 0.1054698296432053, 0.21496240229856586, 0.15145575116959312, 0.11850481567483757, 0.16744875589445715, 0.18218552964108606, 0.16818283666526118, 0.1417039575115327, 0.10548907377186323, 0.13420846132982162, 0.259994245584934, 0.1537915379289658, 0.20822046084269402, 0.09520601346007279, 0.1546722785719941, 0.1388536201369378, 0.10229534514608885, 0.09339836005481983, 0.12436728053275617, 0.11183597432870059, 0.12087203502174347, 0.1432249944416746, 0.0925476807019403, 0.11593657485660046, 0.20137751835488504, 0.13941032090975394, 0.15965397980424667, 0.1298873577146761, 0.07395848061048216, 0.11940607981335734, 0.08455033564279157, 0.17269057462051993, 0.10899359660763895, 0.1790219235924944, 0.2142894706658779, 0.27615876207428597, 0.21074285129866294, 0.15999897984006714, 0.1332604888105585, 0.19209372780976758, 0.12036908297769486, 0.150188886890969, 0.13285582584719505, 0.13865667425336378, 0.08933285401473123, 0.1322901158803894, 0.1266679804651968, 0.13282210265676822, 0.11428208541004889, 0.10992492969718673, 0.12100073013214335, 0.04962430290517308, 0.1836615052795218, 0.14233953469703275, 0.13656379865302196, 0.17475996196510332, 0.18641543814972525, 0.11013249355939128, 0.09074241749101108, 0.11178617095274311, 0.11612399826727568, 0.10703423481074073, 0.1400762351770555, 0.1499131105599865, 0.13495630103974574, 0.20279974526455327, 0.09503742049057638, 0.08169632870703936, 0.1936835441137514, 0.20601809595621404, 0.13026399718176934, 0.24675906545692877, 0.09092309932795264, 0.16764030851904424, 0.20899044049362983, 0.1504648317612948, 0.14720768637714848, 0.17014766832993877], [0.06643047931814386, 0.03744985960844544, 0.024616461953208334, 0.02404310642891834, 0.04957767879410137, 0.04221941194226665, 0.0406591551408412, 0.043580941705694126, 0.04635892590628036, 0.03726732000828751, 0.021425211621868997, 0.040244831808752594, 0.013032736605964603, 0.026753544657220765, 0.04770629070398789, 0.02958341790813833, 0.03404654847878603, 0.09655428224153097, 0.03087175180084042, 0.0810909966727899, 0.025477899095764565, 0.08989806602438612, 0.046171402904174985, 0.039637201510730295, 0.023978799093334426, 0.06613273924637227, 0.0498145914846851, 0.02203719712974083, 0.019735009071507284, 0.07537667023678941, 0.051415749720387885, 0.009236996937092514, 0.07407900156272997, 0.02183342731798128, 0.04122329845784172, 0.08791484058864656, 0.03871917153798765, 0.015379840399198716, 0.04410001607010922, 0.11044746294857995, 0.02490625769320515, 0.03566027438688663, 0.01908874878990314, 0.059349505651381716, 0.01241053244279277, 0.032080550445243716, 0.04510887725759418, 0.07133872804021643, 0.08194470207297033, 0.09398963437565873, 0.040201766176089164, 0.01291887008494908, 0.045012526379357425, 0.01776274252352455, 0.030871397485175443, 0.037169513562994624, 0.04875152574611768, 0.005865441588309384, 0.05930294282734395, 0.01859117085264335, 0.04213816065701746, 0.05626640778275267, 0.003672200809007571, 0.06471880140804476, 0.03159342194727111, 0.11826160574151624, 0.044172503309504646, 0.055888274444207076, 0.04831127799867142, 0.03835712221541232, 0.0388736340157207, 0.056411244365717136, 0.06345331608768433, 0.008656703529038258, 0.03349768095499566, 0.017883761432923136, 0.04364121750357651, 0.029915430838422432, 0.06635587767607744, 0.0484186222386216, 0.04854172490717423, 0.02167674701570744, 0.05719936497869992, 0.06210175312815174, 0.03131771647942162, 0.0380986288280016, 0.012198080939631309, 0.07685985476259263, 0.040656565763657136, 0.053892194053098086, 0.06451046379703669, 0.03565329149545681, 0.04651510825140342, 0.013253322047662112, 0.04548408414026903, 0.034922382328659296, 0.09275087020209721, 0.04415739222519821, 0.04472218671693437, 0.06310183877846406, 0.06974431520868694, 0.033623955227554805, 0.019081446056764935, 0.015245707979756258, 0.037834481711709694, 0.09487452721523662, 0.02399606671514771, 0.021607877626534433, 0.019870261894539, 0.06031865667131159, 0.06835960362467074, 0.04632251757767893, 0.03684509830969957, 0.022932943519985965, 0.012720822949983902, 0.01798698795028031, 0.08024611660549719, 0.008394171900656677, 0.01664616745866595, 0.04496661856049492, 0.03176237689331174, 0.11810739224235858, 0.08921165890511006, 0.0557208689109933, 0.046152101318922736, 0.010254886470765117, 0.03361797208086618, 0.026245641769961487, 0.04417729518947102, 0.010674032326337072, 0.03439830924053827, 0.025905228685587648, 0.05800938804543788, 0.06889335240327543, 0.04112395983670027, 0.027194456985941338, 0.03369669527596524, 0.051688415734397794, 0.004482863559162304, 0.03836939111351967, 0.019855955202553063, 0.02711730235586724, 0.04212199620181515, 0.05275320517079485, 0.06737654427847556, 0.05117378467994352, 0.014623620644992879, 0.03337827083023806, 0.020615588836071473, 0.06156622702556272, 0.04914753957681599, 0.039420398628158916, 0.017001923368943316, 0.026420742656374653, 0.03755230854655947, 0.04342415415111088, 0.019901583399323207, 0.03073512384998462, 0.020208644845913497, 0.03240651894180525, 0.0339682964277604, 0.02023473780061449, 0.02034568648424841, 0.016470388584439794, 0.06634475407941688, 0.03893069607476073, 0.01917940380442287, 0.08227945951324317, 0.038153327505795226, 0.06586984085339694, 0.02907975531753994, 0.006265009588171398, 0.06277021080736192, 0.030184703082927776, 0.004553734353037491, 0.02912496408117154, 0.020369521394792586, 0.020301090590956233, 0.03604144143361238, 0.07774900705102952, 0.04903005233274833, 0.05261244034514793, 0.019865904769469655, 0.015668198766727603, 0.02458580119925882, 0.09112503244391373, 0.0467807185956307, 0.007091240681362369, 0.03715998342921657, 0.0351269124826837, 0.032450668588881536, 0.007901055467945915, 0.03496908304852343, 0.07366079416486525, 0.03397974561178877, 0.05420627094985497, 0.040276693405523416, 0.05492605651999193, 0.02866829140862871, 0.061158683571604, 0.05285480375131292, 0.06459346176275323, 0.013464150402034003, 0.034625959928117456, 0.05253752843747216, 0.05396901351970531, 0.06355273514805783, 0.06689435321717493, 0.05270932748493168, 0.02595871885968072, 0.004690033843695757, 0.06485710326101511, 0.03768808613981932, 0.028974395245313648, 0.05917798239557494, 0.09888312824430967, 0.03134171992930914, 0.04728583100762579, 0.1399353516077803, 0.02956250562302528, 0.01984774848566421, 0.07016825294422527, 0.023285966411593462, 0.039818982683843186, 0.06564154665196134, 0.04292779046321108, 0.04211197194132594, 0.01738555721878525, 0.038307835948803735, 0.05858687661407937, 0.07058725707353124, 0.013920022512695963, 0.10142911420834642, 0.049242733662287076, 0.04380791823589995, 0.0793332692175623, 0.036634600330745025, 0.04473129167191444, 0.011230898765666832, 0.05664432661667947, 0.09807786258358149, 0.0358634562261643, 0.026984022209240545, 0.029534761748847463, 0.019758612240454363, 0.013116318713723412, 0.03350698509283605, 0.031216629262593006, 0.054906800900015144, 0.11354361495543873, 0.05120090419246305, 0.007633514103344492, 0.02534221534827544, 0.015116857736551715, 0.0852179429644058, 0.04011175850586545, 0.041170258360404166, 0.03681514810229983, 0.04339348765150194, 0.0834948503442349, 0.05455070791105109, 0.04662029595384675, 0.05844332322838807, 0.017803230270322774, 0.05911591778238935, 0.004552849042679994, 0.023387392622328574, 0.02480303309106779, 0.06209188974612664, 0.055499603566262996, 0.0038913352322959976, 0.07728781445973343, 0.05435066320182336, 0.07648515349794781, 0.09335104646461626, 0.0870220800260863, 0.048164039730064334, 0.027722155585164027, 0.05380318995805518, 0.028738172033861763, 0.06044467813485573, 0.10420407619207137, 0.0361343487466295, 0.07408857000090423, 0.06989193269081655, 0.035564823661960905, 0.03253570817891629, 0.04518915561117953, 0.022710982950464375, 0.03756651947755487, 0.01705485046841204, 0.05980104936527149, 0.019091087273292003, 0.02874217867370575, 0.07388495149150973, 0.002796309981344929, 0.06309398637724019, 0.01938701937756231, 0.02628949455796711, 0.015574581864770624, 0.023978666943167488, 0.023615263560185992, 0.06231736091356124, 0.05647263482152935, 0.05608725046078044, 0.021113586206469807, 0.017688075763984554, 0.029212372798112132, 0.05399422547329338, 0.0780633865525165, 0.042818251381357836, 0.05785708976609092, 0.027037924155592922, 0.032225442569582693, 0.03948122600934679, 0.02852011276709457, 0.05285162831686678, 0.02421791237148066, 0.05240353199863627, 0.03975276970454762, 0.046904372847488815, 0.02717880580964829, 0.041767469862656253, 0.01898681504591819, 0.026025569607173244, 0.05559058033771092, 0.032691499819197965, 0.024679011117006024, 0.036783501010147795, 0.04785115410002971, 0.0518131961355046, 0.039597590934605374, 0.0372647229702242, 0.04510581290589706, 0.11404436066626542, 0.020330554332524058, 0.03614540339537686, 0.01208093077425034, 0.02203574347790451, 0.02554144225864401, 0.026785251121186925, 0.026761278314816377, 0.013855909571922837, 0.07044927697748908, 0.054904720971300724, 0.021929444947970972, 0.035880865574243574, 0.026466070163634517, 0.023591943843770894, 0.033383445754166574, 0.040243219193671985, 0.027427161938600966, 0.17849939034110118, 0.09970716305918272, 0.09277631198206256, 0.20036350905654893, 0.2140938577752921, 0.11159082619293083, 0.1504068082619098, 0.1395469756736871, 0.24001848763756214, 0.24612037795445613, 0.1488088867476871, 0.1533900312478504, 0.09553874076734628, 0.12247965520908757, 0.07579095526448182, 0.18463186288793243, 0.17213424156990745, 0.17248700973728012, 0.242975878138696, 0.20847363757991022, 0.12386422123639815, 0.14085738438992731, 0.3743629602174605, 0.18351496798136543, 0.11561109474109066, 0.17171732119975552, 0.1682063708862951, 0.0910335002587207, 0.11686102081570895, 0.23875433531018997, 0.14401132240891457, 0.23384496809974795, 0.15986492977507655, 0.07495876927409442, 0.14731434113796682, 0.2338313930217297, 0.062099791943065585, 0.12326510217521461, 0.3074096029083575, 0.3103936685910148, 0.1289489000074325, 0.11952887604674024, 0.19961640479103213, 0.20307944396570807, 0.25303672698716967, 0.1545063592493534, 0.08179864741020626, 0.13796523393642518, 0.28497839526784036, 0.18159772569854415, 0.13560364533576275, 0.10969731731400376, 0.23517003973885892, 0.15341229376293, 0.15426913246272073, 0.07311206070646163, 0.16793604910133347, 0.10198761528778462, 0.1827805807753917, 0.17532421636485285, 0.19636650659864952, 0.1714817491630393, 0.17001112081831501, 0.1459452347649682, 0.28219899763503387, 0.29490995911821244, 0.19803835559756527, 0.15977348952043444, 0.1480545352904066, 0.13860088773071766, 0.10022634850634683, 0.18451085163941308, 0.1804487317079498, 0.21928747424915915, 0.11402173808986142, 0.2599508543649028, 0.1346549220503338, 0.2329595236768646, 0.22246719878767768, 0.13060893593055586, 0.07733647636468373, 0.1583160225662493, 0.12550344255061882, 0.22238300572479927, 0.1371717813514894, 0.14303394743511755, 0.14544576076009583, 0.10652238848589121, 0.16995648342755534, 0.08904559402576379, 0.15950934240414252, 0.11175830067405779, 0.20225626716931022, 0.20681334118689262, 0.08321813172510556, 0.1948302398405729, 0.22451470666114362, 0.1900453006307925, 0.1730875307393651, 0.16917070704362086, 0.2369429357349873, 0.12589515862806192, 0.14983143026549972, 0.08305753671353863, 0.15299184938832638, 0.18095312399729607, 0.12504268662943957, 0.1586146742826508, 0.21407222345231042, 0.12121695844877152, 0.24685091939905, 0.21561225936297448, 0.09668297735193083, 0.0882047129374358, 0.11401855882497565, 0.14875878459743916, 0.177482761022064, 0.12448338881856012, 0.10834472013577338, 0.13282064708971208, 0.2111478053754376, 0.34810523532571336, 0.13949839037752923, 0.10510100427293971, 0.17550988543418147, 0.18748066808667876, 0.1763191653956329, 0.16053442933386372, 0.11885776004243283, 0.20306853487366633, 0.1272605035093523, 0.17386966054478, 0.15770943414780403, 0.26711736174841083, 0.2847292941183813, 0.16055856110347858, 0.08126286849860223, 0.18762956493564192, 0.2666956150243359, 0.13315461545942292, 0.14462707323893426, 0.0855518347253242, 0.13337547860799298, 0.15407670649789995, 0.1913207144506516, 0.1420886409018309, 0.10849426815947218, 0.1596477898138185, 0.06773536454045004, 0.1655935667335026, 0.1396191411561543, 0.09235775218375268, 0.07402521452956623, 0.19662950458305498, 0.14791100105691343, 0.15628702337703398, 0.11676578842584165, 0.10692574143890413, 0.29103376872597203, 0.11598529038770546, 0.1749123368532427, 0.12432720647343706, 0.09792229310879785, 0.1122838369901142, 0.11651855653091786, 0.13308882382848572, 0.1291082003304074, 0.21851683576260844, 0.19688090399628688, 0.16312743777469282, 0.07765922154630385, 0.08333954900022476, 0.09425152153257402, 0.09072104363792366, 0.12498116976911984, 0.1452807454212058], [0.07660881541068516, 0.026986831836702845, 0.028256637892956217, 0.026351338920874462, 0.01840961950590774, 0.0684222006689637, 0.04055839159616059, 0.0739813253523842, 0.04042026977385244, 0.06715486141582651, 0.03280625595981556, 0.03464349951114386, 0.07116823517266782, 0.045143416331660365, 0.053181356389916716, 0.02356467685932594, 0.016843657264666214, 0.04337206400269943, 0.07337664449287039, 0.07738303152784225, 0.0332531227069276, 0.03367976090239902, 0.1119143144798375, 0.01710302590753042, 0.05727077969500134, 0.00833220879412106, 0.029673877570237366, 0.019947690401046027, 0.06984158539243283, 0.015973046219216722, 0.035519528713437824, 0.0563378952774069, 0.08126158147088944, 0.05129725124026018, 0.027886100316179857, 0.02642791706978554, 0.02101540820853364, 0.08728556830676333, 0.05931947500474992, 0.03185937128540489, 0.03079521195632556, 0.02759098026510929, 0.04092026854895296, 0.0904842535214078, 0.0767009757879761, 0.03717576484045675, 0.04119117639117664, 0.028233270296045852, 0.04131872620012972, 0.01735933594435694, 0.012223832985205997, 0.03692540730680189, 0.09988858800141082, 0.06689144974394191, 0.03346633646757372, 0.03241296940212769, 0.03241187006595635, 0.04019349242650694, 0.020924954292094036, 0.04735218188274772, 0.1078901848485393, 0.0552990111041694, 0.046505934348510164, 0.037866994483216156, 0.07227755346966368, 0.0457736577147678, 0.0865407316615024, 0.05003420207949896, 0.06810950656091014, 0.11770282887042531, 0.02624477609060705, 0.026808201200178555, 0.006043246286290308, 0.04287750445186131, 0.03220655467180956, 0.023720805578294302, 0.0149406565563573, 0.04004378352434405, 0.022107430155419057, 0.03999871840219825, 0.024192763620146343, 0.07387519153135438, 0.0834886220494105, 0.02596884654203971, 0.061261569179834864, 0.03916985723340223, 0.029692361356630444, 0.0781760321209027, 0.06824873538026888, 0.11635329604389207, 0.033758855650141355, 0.03804324833195537, 0.02319677845544873, 0.06971862061970657, 0.06038888012089076, 0.012458938665898337, 0.08321299893601287, 0.04871899382241311, 0.025025211995647802, 0.027204035000214656, 0.04840310129727568, 0.013255096498816727, 0.09018239955748282, 0.04162812229966925, 0.03730231490466864, 0.06125891851561685, 0.07645638689639107, 0.05591607194453959, 0.04014001565895254, 0.09960136631683958, 0.05562963550009074, 0.038961757109650684, 0.04513033538035328, 0.09195495847492449, 0.05617841492376982, 0.016045960552629926, 0.06690255035796473, 0.0490010520743747, 0.058570788767669475, 0.027696729126957156, 0.045593768778827884, 0.035027834331436504, 0.017770920512116244, 0.08483892862474726, 0.09248792584384642, 0.03620532296237446, 0.02899234660059935, 0.03940084806433128, 0.04574048993808608, 0.026665565204776587, 0.06120534598707192, 0.07271908824482272, 0.03641327369898077, 0.07620694866824536, 0.00909562019871608, 0.029712637788766337, 0.014617340639233591, 0.04353783010775524, 0.014725380103975056, 0.03993800593419902, 0.01043336772014417, 0.03260325798163972, 0.06651219025614762, 0.08495149758434103, 0.019372634161564133, 0.014836907183991806, 0.059139026824625275, 0.011404530678485191, 0.10376920638185355, 0.025139606159721172, 0.05545633492029964, 0.00407586642165458, 0.09951817682914196, 0.03257344950050597, 0.060679097209245934, 0.02405542703796058, 0.03664981100648161, 0.06418927760434247, 0.04715657665304119, 0.035532544547271346, 0.037472428558694745, 0.027161453918163336, 0.04394839960901488, 0.012711456567499668, 0.039603198698211106, 0.02743984260896762, 0.08305695448671618, 0.023556550581669135, 0.018391518763476805, 0.027777271780876384, 0.014428691487879524, 0.04589384541876855, 0.03920227424391816, 0.07184505087113188, 0.012502688032034184, 0.04141385133768763, 0.049137863886332324, 0.0535614202700315, 0.017071346256641612, 0.04216310831027166, 0.05969076334769207, 0.07516647869300458, 0.01891880750566, 0.02066474486773293, 0.05751589335681451, 0.050792805324759216, 0.047573757493087364, 0.050740795615579815, 0.05886254569275245, 0.04872923258752112, 0.06075982372426699, 0.011745961702188418, 0.023902715071134513, 0.010975484094101816, 0.11208283084054148, 0.038962998172088016, 0.05275297917485718, 0.09265533903793943, 0.043944381477852026, 0.027432013190381473, 0.03841736736977774, 0.051277352106427, 0.005237607636503996, 0.026347175233006, 0.00655146997286788, 0.0427007679677298, 0.03497098294657565, 0.0234534198253025, 0.014018462895746193, 0.07773897129922144, 0.011314196463283754, 0.016131452134540005, 0.025031547542781602, 0.0266835721014368, 0.029451692919997923, 0.02319178739262204, 0.03330523583797678, 0.05278209051597984, 0.07346952499281015, 0.02831069880255288, 0.01380967999613213, 0.03849679919620676, 0.020641268103293354, 0.045842984841475566, 0.04205901611356005, 0.030766462591747125, 0.01996711456036616, 0.043064460548902714, 0.047668120373160615, 0.1025918594771816, 0.029987793588530154, 0.0558159212701984, 0.045630586964468804, 0.085762309721641, 0.05449536188896145, 0.04106959057671409, 0.06282236224280731, 0.044721022263289466, 0.014847518459352997, 0.01324669442950718, 0.008281883520765171, 0.04308742786487264, 0.024525400912088734, 0.07400243107469813, 0.024474542250015566, 0.0071700572434272025, 0.014406171375735393, 0.05443788231200269, 0.04546251493476091, 0.018635814626430793, 0.018810425216572422, 0.005935086162700769, 0.05349044605428654, 0.017463284499582746, 0.008723732391973178, 0.01252785785078642, 0.04355077699367558, 0.08518860179690585, 0.008237092275052302, 0.00678771042129806, 0.06150364530302825, 0.03714989022081418, 0.06124237484689202, 0.03775542143792395, 0.027435993017148108, 0.029808262798694835, 0.09005006552944261, 0.051047472102988156, 0.0297700101134157, 0.03641651042046086, 0.07606916009418427, 0.055461689874890356, 0.07640155032277107, 0.028345067422055913, 0.031013437847216285, 0.03749777457766956, 0.029127534306157502, 0.008076790292116423, 0.005850655612565818, 0.04226133993436252, 0.041354062005637154, 0.015519716562853466, 0.04604292995927315, 0.028739346063605724, 0.020502726847846663, 0.030962000788760283, 0.03588648099872855, 0.04562746132573774, 0.0735253191763355, 0.03353717278749232, 0.032200858808092536, 0.06152637130130203, 0.04507693905203093, 0.038137779751371954, 0.046563394773270816, 0.033138136739932725, 0.05529060711964004, 0.01348406390001577, 0.06017119240676684, 0.08373002401523053, 0.038945186627848495, 0.017199355718349258, 0.05129711717487343, 0.03685573161008858, 0.019997501437882745, 0.047002516371468385, 0.05614686359260833, 0.022015166356258338, 0.05270440537001818, 0.05896531255735506, 0.0261557815716632, 0.04512742807668063, 0.046947120553663665, 0.016155304282062476, 0.045502650281113964, 0.019419815601600755, 0.0350644686559756, 0.023960141021938577, 0.05866733499832692, 0.012892764681319316, 0.04722054882515823, 0.08199972250769216, 0.020152628496890108, 0.04142536180874994, 0.07004408541345788, 0.012828622054639123, 0.03566050038282429, 0.06262531293736351, 0.05328890747360645, 0.006515772669621173, 0.009661241107800556, 0.02930076976847505, 0.0632080645300448, 0.026384861013221166, 0.007827949133746686, 0.0037377544738832983, 0.023840445529429183, 0.06347541006342058, 0.04770160224589129, 0.01971025677067378, 0.01124288229602239, 0.051513019904133775, 0.06015460660320617, 0.05890713200994557, 0.03550698785411735, 0.060215361206041235, 0.073542088840998, 0.034206032662862734, 0.04333997257955132, 0.08197752894052575, 0.014202151627790545, 0.029876465691373717, 0.22496230119178373, 0.10487127748708572, 0.13573501409301836, 0.08144797832374612, 0.11681513214904456, 0.14500011209278338, 0.11396078047372642, 0.14358620489797286, 0.1936840497317814, 0.13268488098777112, 0.09301958320241782, 0.14307490249554958, 0.17191855717570553, 0.14431074021324036, 0.12578232919857388, 0.11560288227854237, 0.14454317128946706, 0.1163518711203529, 0.15549917855570394, 0.11880252510309221, 0.12282043410044526, 0.2077959715238502, 0.16666733088993257, 0.1022933150130895, 0.1706790422359782, 0.06555452672464233, 0.10681696461453553, 0.11052929646065159, 0.15090516377841273, 0.09124092622509888, 0.1535729424006516, 0.11387698577656863, 0.22635737794541547, 0.2820134817832901, 0.0751997345697976, 0.12699640235833584, 0.10010657065938558, 0.15607592018861927, 0.15302805470362787, 0.14851935147758455, 0.13638959025904057, 0.1261535600849217, 0.08070092768438401, 0.2041920487798991, 0.16350312729275998, 0.1988488919432125, 0.22002356217032482, 0.09707154480800514, 0.2442931510027378, 0.19480207844847636, 0.1712438635407917, 0.1469568232254636, 0.19388822748536066, 0.11864678708896523, 0.12623604477172898, 0.1840350037861255, 0.12670094522857858, 0.21416415400322408, 0.12258925940841438, 0.2733183225556728, 0.18371628056610786, 0.11032480461102341, 0.07406855212344278, 0.10803774104363496, 0.144265862782636, 0.11115024136679788, 0.15887079279749625, 0.20883351504322023, 0.1746836136425695, 0.2893010004153175, 0.10139385118119179, 0.10940641840739597, 0.14680991820510358, 0.1380804075949615, 0.14653129202704276, 0.14340756851578915, 0.15296751843585124, 0.12534637920438282, 0.17751804703185636, 0.19315466765434514, 0.16047712595712754, 0.18196166342785283, 0.2014876817983966, 0.07494805936491297, 0.16366809666637452, 0.10632725823069773, 0.2051268752303816, 0.1687076068933933, 0.20685409706446434, 0.16317743267263138, 0.3174119532829331, 0.14039342622122458, 0.21779217787327307, 0.17354938982715531, 0.14119536706036137, 0.1610715029340598, 0.25796233526160645, 0.11611004014529529, 0.13336190352997473, 0.1118723635051039, 0.15819438312563205, 0.12651460966275585, 0.14739366188164682, 0.1786882463361948, 0.12791484984899723, 0.09421216759590373, 0.11245161024553162, 0.09464111554646686, 0.13929597462617582, 0.13784380900042673, 0.1314529349967357, 0.10003998995788636, 0.21894183069948228, 0.13080957435792492, 0.1706323874813895, 0.26962473688106386, 0.1267577736308017, 0.15734866802250186, 0.1497350717263837, 0.16676254029716217, 0.16858578359167423, 0.08159607844126802, 0.123218638942607, 0.1258705672056925, 0.15238863175674794, 0.12221474200487138, 0.09505348535434854, 0.08728310150364715, 0.11285066544528931, 0.08431434991859621, 0.14768097549676895, 0.0869579354841863, 0.1445914807939722, 0.19755051080738345, 0.06816999686341133, 0.17332055936417273, 0.17289256136263573, 0.08824238148067268, 0.10221859845783442, 0.11968967790204672, 0.08046909415673825, 0.06546385255792449, 0.20042951519210495, 0.1507239686625619, 0.22143509449257007, 0.1492860982374799, 0.13819354345961926, 0.10443021768643972, 0.12403120542125357, 0.0774773216295627, 0.12965711764991283, 0.11908703483641149, 0.10808618844396646, 0.09420076820759044, 0.12333019666614072, 0.08130641293621833, 0.10119935677897546, 0.1288575823268583, 0.13319026919141894, 0.09933435403171087, 0.13067708711229986, 0.14084000951580464, 0.12376667526099952, 0.1489928551018238, 0.10253451013516995, 0.157762156318753, 0.16389792304365866, 0.13679011634761287, 0.11043490676750099, 0.12755060568451881, 0.1673612686535043, 0.1356898455490028, 0.16065153353396924, 0.20479056263162246, 0.10641626998661988, 0.16925027293543662], [0.04396271013144044, 0.02514842383172964, 0.043359132438537576, 0.0254841158992701, 0.016817217655179482, 0.06556853847277742, 0.03475439456862307, 0.025209473378415552, 0.03469372806589931, 0.010180312599385939, 0.03493334504685575, 0.028520273645558668, 0.018970503118790446, 0.009184156980125174, 0.05166964658025292, 0.04196794741156121, 0.0403477250778627, 0.043570427148933374, 0.008748973073858407, 0.05129237126018252, 0.00998541887383908, 0.009134241563808775, 0.0064451910739374025, 0.018680092593234394, 0.03826321898809364, 0.04827200450123318, 0.08181524087464617, 0.06813308674721949, 0.05255104222845647, 0.036463153683730674, 0.03385049891808341, 0.03760565890960636, 0.06201921864562939, 0.06168020175649755, 0.04161234854930832, 0.07078241797224169, 0.10129145586923247, 0.05262142655649974, 0.07133577094082871, 0.09829724718245769, 0.045562922248556736, 0.06821967000442167, 0.009476168629442974, 0.016678128646866932, 0.01801241249326737, 0.013824301741776929, 0.04861984289281311, 0.06137364018227785, 0.05446476050682607, 0.02534341236065713, 0.02547353622503579, 0.054119825588479165, 0.03212456219649363, 0.02963401226987762, 0.040050379541372104, 0.015834507836599745, 0.03425210902106858, 0.05915424133080149, 0.019708119385365038, 0.00811075671545921, 0.03279683307834691, 0.006075850988347685, 0.038569221318128614, 0.032854753155862136, 0.005987348680895183, 0.0012945122721101788, 0.056456156270278085, 0.06979017323183437, 0.033678841596889886, 0.0018942471961641025, 0.030506753039756612, 0.03732818952431122, 0.024678495922876943, 0.0719345376015671, 0.027210066027398554, 0.021439732818473733, 0.022915727609107574, 0.03546552334521567, 0.0377726469249014, 0.043746857197895166, 0.037361207913847706, 0.04768586296948695, 0.08572716926855427, 0.01805863057773921, 0.015357580756948841, 0.12860109608980919, 0.008722173403047265, 0.08021454612213759, 0.02414091095899142, 0.11066078013109584, 0.041584248444245714, 0.047147084823659355, 0.09105047676712276, 0.021189597450316917, 0.006790062790030554, 0.030704894020492514, 0.037643411722514904, 0.028805319640424945, 0.04440679214894772, 0.026419087906458208, 0.02372421466955735, 0.009419322990241551, 0.01964530592123347, 0.029185804868898088, 0.024679043675742807, 0.03226215733335384, 0.02226064965549496, 0.08731473327404068, 0.06497709561259517, 0.037919333610203, 0.03025924726839989, 0.017489044206036676, 0.056453635841007196, 0.030800756517677542, 0.03798080450524727, 0.026233596952571988, 0.03461392851726663, 0.042751122926992756, 0.017244658327751586, 0.022879110521546776, 0.014816780139001147, 0.0776972271682274, 0.01834376084227716, 0.05304151470021856, 0.018913171013757106, 0.061714246703852574, 0.09171701156564298, 0.03773956724833097, 0.09782046470190249, 0.034393865930577444, 0.02154733752831817, 0.040263761841361566, 0.002693142835801888, 0.04237340710636589, 0.02863032792154099, 0.05049582751047227, 0.0068416760487091405, 0.01720766202666827, 0.012791199617147928, 0.05880603138657828, 0.014158673265257911, 0.05163400050913615, 0.019870020576842853, 0.02401767614027185, 0.027617159404701767, 0.05655172190839245, 0.01350810182385988, 0.013588817805171976, 0.05737622020645969, 0.06659633735375059, 0.11365501946138759, 0.017766172682205518, 0.04593656631186605, 0.02313360684521256, 0.021465549981521986, 0.0018765367994708342, 0.08326898464151929, 0.045790051996347406, 0.019627404361662847, 0.04467537108388159, 0.04538523581539912, 0.01506848407218293, 0.03772701106725201, 0.047163398666006905, 0.03372682168358757, 0.1292905752216616, 0.042523552678645625, 0.02701063993416967, 0.07270155249223595, 0.052988650803003585, 0.05652333452035824, 0.05905481460954874, 0.0341539808188475, 0.030786398114756714, 0.07569792154695719, 0.05033718985355189, 0.08774939624051895, 0.04095265491595192, 0.04896447520642992, 0.04529305628591007, 0.01456775081028501, 0.021185617623550278, 0.04113535156413432, 0.03504392983872564, 0.06901096988229022, 0.027181801213432225, 0.011448789493090684, 0.03873536280626732, 0.026016006914658413, 0.03541155245095011, 0.08204733487218618, 0.05602752241576391, 0.022074679896656065, 0.08708260863298371, 0.018561789465527383, 0.022612052271142605, 0.0319024522398268, 0.04375319657546859, 0.037094463759492484, 0.042394681368023164, 0.05263981649712209, 0.051721372836900335, 0.04873882400833311, 0.052718543522660775, 0.04414886566660097, 0.06760532877618267, 0.020732689205737367, 0.0326086052753512, 0.06549449607489571, 0.07305623587941931, 0.038617492518237526, 0.07160402428839477, 0.026103386903301846, 0.05755885173716853, 0.047537406621080254, 0.036327157755412405, 0.062379322104877045, 0.03807857647658356, 0.04468792726496055, 0.060411403105864604, 0.022498895339066946, 0.05179580593962343, 0.05471332922517773, 0.015125937793674249, 0.06469106136430657, 0.04179920122447995, 0.06508730502138216, 0.05118067947126204, 0.05583888092528909, 0.017938433297639413, 0.028209739905451576, 0.030127229251628442, 0.09000510382916659, 0.02608460817305792, 0.05364987661220855, 0.003707254598397882, 0.047979538944820245, 0.05212612773081468, 0.06577464676792584, 0.09786200965003622, 0.019790596411293073, 0.052010977054916085, 0.03604930915659474, 0.048307819111693295, 0.02664572544275753, 0.03185965665315669, 0.054620713025571845, 0.039559543177845984, 0.042505936486826795, 0.03220106565183209, 0.03886762405595472, 0.0573821995227087, 0.04066906448814177, 0.046911692817605315, 0.055803886028907956, 0.003393893275642768, 0.051525997433571086, 0.05299697051786127, 0.018399376910360112, 0.021374948593156955, 0.005527034217882301, 0.03487405750239569, 0.06790000449625716, 0.009821319010018582, 0.027855772810477405, 0.08405389534609933, 0.027116907820586237, 0.06118236717978313, 0.09713886861479092, 0.09346705515899005, 0.09498787758451316, 0.05706472502600762, 0.04236186599178661, 0.03395587814250781, 0.018403557835206873, 0.03324231703675563, 0.1126048431521462, 0.06798492534266365, 0.0277085843375854, 0.010565912422363558, 0.048556077564435626, 0.06373285774081465, 0.02496637069740363, 0.060509925843366695, 0.02649442690815176, 0.02547949638908669, 0.03272441478686468, 0.07071909314442067, 0.013359378302289594, 0.02598278359660218, 0.02021037620462237, 0.034920635648191936, 0.029711191797809258, 0.038268508825210795, 0.030001232685941844, 0.018532737496218855, 0.15764474568347778, 0.030308997018202662, 0.041855780648127686, 0.039091903956667076, 0.05480912085922976, 0.03593742967613282, 0.05288421769716567, 0.04283779428430623, 0.029363841787281058, 0.012124700250194199, 0.055925747635023254, 0.0472945490882041, 0.050429216165456085, 0.05745659432103557, 0.05490308154314276, 0.05492877996256275, 0.018046710249637405, 0.04087448330415834, 0.014018934997429532, 0.048225744281925505, 0.012988266159570026, 0.08468624730143817, 0.028529549055101893, 0.017557545873006026, 0.070408636013106, 0.03199140653915463, 0.10436703075444508, 0.05509768319766849, 0.01279004378199217, 0.040284760311366095, 0.03570993220613849, 0.023583564757099076, 0.06904797958991221, 0.06870786719504865, 0.029042904573162238, 0.06866049231781114, 0.08169519489691143, 0.020859043917528564, 0.05564459719725194, 0.03246280725204176, 0.03638041618790838, 0.016559769977785407, 0.04029652742188304, 0.08252445443142807, 0.0572276757579417, 0.029235652294911207, 0.0018430993358995167, 0.012324513217824842, 0.03902964016062118, 0.04507213568074569, 0.0539260589697909, 0.024454466915959795, 0.06973702971252703, 0.006994232882730544, 0.0674520805478096, 0.09908517627345939, 0.142801363141306, 0.11643326796230771, 0.14590152178800878, 0.14639388649694382, 0.06173869639995599, 0.25875955699912967, 0.14162748661493102, 0.09644891450842542, 0.2409584775206543, 0.11865781109419563, 0.11060823416036945, 0.12590566169350378, 0.06500763953813622, 0.17693534523489016, 0.13949932500479684, 0.13066856821458186, 0.12611345538208563, 0.18909881432210246, 0.058400732570237694, 0.09743395036146527, 0.08798609442648389, 0.07197816630885487, 0.1056763286431951, 0.1407679972509223, 0.0925646648712216, 0.18432544303997872, 0.2955621450899109, 0.18454367084608925, 0.17137406784440243, 0.26630668750693726, 0.11210821899435214, 0.1292103045289555, 0.16116355605904134, 0.1720715602559428, 0.1042556798746509, 0.12532844508607544, 0.12811963281203664, 0.1993441831080183, 0.15862146182165993, 0.1802188593653902, 0.33933457047227894, 0.15282260524409433, 0.13862754759048262, 0.2843283543423299, 0.16488260649625333, 0.1184052931925943, 0.12213794169046226, 0.1053578275886755, 0.23043475834833038, 0.11237132423106702, 0.24926021995563663, 0.14123541813704277, 0.10760691617765736, 0.22832389500352646, 0.13722701629083003, 0.12445008697649165, 0.2033062826000875, 0.18221315477163563, 0.15219576146093108, 0.07650684910796343, 0.1711990473972213, 0.11208827006480387, 0.13993720554055708, 0.17701751582564848, 0.10285321803342912, 0.08618458504638365, 0.22974765408904324, 0.18745350260888377, 0.2231771324671084, 0.09251963422303239, 0.12555696911388828, 0.14942192562645482, 0.11463535153457236, 0.20915314224698853, 0.13699288449941144, 0.18964874287766798, 0.11564307125105013, 0.17480699976365413, 0.07064968557848085, 0.17945862435285123, 0.17364269933633267, 0.1799458562726936, 0.20671145149296333, 0.12550397115128656, 0.11496934288692091, 0.19372546444496802, 0.10356341984363333, 0.12161448147268066, 0.09978068451727591, 0.2463969356951214, 0.23642774160590865, 0.12957842509833076, 0.1651233726090962, 0.14163617405199236, 0.11943948124685597, 0.1411708369250259, 0.1405616131641211, 0.14271528550213383, 0.07462420335580265, 0.0889150373217079, 0.16622709080336556, 0.27149285760618025, 0.17689203062365133, 0.10133292420857376, 0.1160398664914312, 0.1973890654382206, 0.1502173087529598, 0.17333470134725495, 0.16496349005929886, 0.20463539918343868, 0.22340130511551137, 0.15828234534109795, 0.11954985919498629, 0.13852165891758858, 0.060504563227896734, 0.13809913078383093, 0.18867303797554588, 0.14421706298185935, 0.14558282921150809, 0.1921486256704215, 0.18977600540364944, 0.18641888554538452, 0.1602092096882482, 0.14590169032735212, 0.12786593513503192, 0.09515679997181702, 0.21945120256033637, 0.0955204159441975, 0.21806318913736653, 0.09952539337738868, 0.09864029369407123, 0.14906790107488632, 0.2063691480866363, 0.1137281119102432, 0.09689561271619412, 0.15102154785586944, 0.04379067359672439, 0.11444126315895589, 0.1217211745378952, 0.1580924321446688, 0.16066509329022902, 0.18676872725688642, 0.0794529474730934, 0.1736016829888667, 0.11787015013396741, 0.11318467211939635, 0.28226141847910424, 0.1302929093400317, 0.151573529527072, 0.1791744823417356, 0.11297226658151036, 0.10689788648197729, 0.1578353023937633, 0.14002360493665741, 0.09643313309718525, 0.21173491983884768, 0.15897277442197646, 0.1239903499522517, 0.13861175085748398, 0.32517027890970635, 0.11126388284948566, 0.052316695932419076, 0.16584200904734675, 0.13949816055115194, 0.18666054032021956, 0.24873313614197318, 0.13112154068245044, 0.09429845973969468, 0.14492267592539712, 0.19578734412789348, 0.12330018900214665, 0.14511432048053513, 0.15556153811274037, 0.07500357009590634, 0.1772286343358217, 0.2669721727650012], [0.04191922805001659, 0.05596700146974576, 0.10365269973032898, 0.03406549383315348, 0.016686235772325628, 0.05695107588244062, 0.03529902562619217, 0.029651563344222885, 0.013594504092789948, 0.03914972827319176, 0.0437870423399633, 0.00656517049778373, 0.08005630300049821, 0.03153333001049056, 0.02673609508952547, 0.07765172920640438, 0.05152697802611417, 0.035539148225178646, 0.03717163562654488, 0.03995971303553351, 0.04094587503782204, 0.00970898466485162, 0.046663717817394965, 0.015132376762677827, 0.07731784510636523, 0.05026809255322141, 0.043085451358028, 0.03790562063635838, 0.04405375202036193, 0.02273788604314529, 0.047587026135935906, 0.08924495308629929, 0.007634843744698071, 0.0311810483089498, 0.07755952286383799, 0.021764038904239575, 0.03570704788510357, 0.07373736465289708, 0.04245871865761377, 0.04072406960110511, 0.012931788242572259, 0.019798793552082875, 0.06965253787535815, 0.03336056653830794, 0.06136363890442637, 0.03315525497460077, 0.03593060383272748, 0.04325523559424666, 0.01875172372937443, 0.04769915459497322, 0.027245595270106872, 0.03237709733507326, 0.023023156118729425, 0.050118107859405785, 0.027185984053498796, 0.04967777584228785, 0.03331381985316834, 0.018811612652855057, 0.048224733045865456, 0.06068798765960721, 0.10011944859739273, 0.025585208861758153, 0.006803978777175109, 0.04262204477263074, 0.023441137520656474, 0.007826004706833872, 0.0519942993208045, 0.05416377605269513, 0.04099439521650634, 0.016985801048576832, 0.04606480559995098, 0.05554339315201487, 0.030248100689101606, 0.008198225761823838, 0.06359811053581296, 0.038953073503028963, 0.05180615961792008, 0.05134939118438671, 0.071688431855892, 0.015137946221887346, 0.04251702943997037, 0.0349606101160809, 0.04385293739277028, 0.035534337193014166, 0.05952079141993196, 0.022348801477722103, 0.04681190220458854, 0.06135467184527267, 0.04526080398429786, 0.05222607922229556, 0.018626550708206433, 0.044939119834452874, 0.05182571018174772, 0.024318222009066134, 0.02293428417385346, 0.027368736243055716, 0.09273595447021146, 0.04830549786528272, 0.029848896102198673, 0.01643375234468089, 0.011967112133730085, 0.055531675837212996, 0.031662749073978876, 0.06024240410976833, 0.01048322951030587, 0.00344293846395768, 0.019807798915632793, 0.04335620981310645, 0.0337662369072918, 0.03585443937129552, 0.02143106836405012, 0.03909407581593241, 0.05858984137434633, 0.046416240774335406, 0.03655920578767696, 0.048809752258802616, 0.03384689064396005, 0.025012159772637873, 0.02073015920036743, 0.015969150662121755, 0.04005122989896805, 0.04206571555245788, 0.022161994767825932, 0.019169800892292012, 0.04916944969145041, 0.07563240570767273, 0.02568487115504761, 0.017478654138563622, 0.019350517203190157, 0.014740127296517453, 0.08543748844174609, 0.002325301170311568, 0.024999982805081436, 0.03181821129645311, 0.08933603327961699, 0.04844489905442442, 0.05791086913837541, 0.046026539508133166, 0.08913570128741766, 0.00827647302479994, 0.07836465828961904, 0.03178093920371706, 0.036695703503585635, 0.03568595365410851, 0.047343099910405376, 0.028594746967897784, 0.018341156143334605, 0.055578751940160036, 0.036521560227077816, 0.01387681611137645, 0.05135497213491509, 0.034669718870352355, 0.023515359949200385, 0.028935003004247145, 0.08151616780988633, 0.04852475605965142, 0.025539320195093754, 0.08939753481817823, 0.026212443349762794, 0.03178980858666042, 0.0605096040864385, 0.06746984612677367, 0.07668955341702507, 0.025612500744060646, 0.027108974980130315, 0.07303332985048333, 0.035278352743555466, 0.005879300118859617, 0.06606217488766679, 0.018123899353668094, 0.06579461101923259, 0.01768669489050104, 0.061360827361744266, 0.06318384082987905, 0.04858731862998778, 0.013290630529574571, 0.04512599932270185, 0.027958779077556346, 0.052857944711802475, 0.08426132897335677, 0.06094715137395167, 0.03291319417316587, 0.03485055009443914, 0.051983754120526776, 0.009981931258563795, 0.021823669273045757, 0.02808569111831246, 0.034898334828716134, 0.021318985870288267, 0.05042666126222861, 0.05449743415679663, 0.03516975211940947, 0.025094814914008303, 0.019798569471365022, 0.028907787730737083, 0.02503733725226935, 0.026645162368133187, 0.016276325106680874, 0.10694251876444587, 0.05599514754008382, 0.06450225899536764, 0.009591273340066115, 0.03014587391648562, 0.0402962516302303, 0.052448865251555565, 0.037200256671395995, 0.021429459579409133, 0.06945193009150606, 0.026479878898469672, 0.07453996432764877, 0.04478963309778802, 0.025067289374888908, 0.029698819477832126, 0.053287298688965465, 0.02072757365362298, 0.016021533839164243, 0.03611149634384821, 0.021292278130028038, 0.07391649133135235, 0.029007112945339857, 0.045022883888093695, 0.03877144554750093, 0.02723900882917787, 0.0008738663804721118, 0.02661723463285354, 0.07403724977085668, 0.04391283397713015, 0.016036762709489033, 0.0454425583443334, 0.05341640365640483, 0.036330233598428394, 0.0903470701568069, 0.05213626690449254, 0.033911996626205025, 0.04137544351960382, 0.004888498496579668, 0.06246711195055997, 0.01710684677105277, 0.03225433174520731, 0.07555388169543398, 0.044417816154178114, 0.1582074219421033, 0.007655670802529542, 0.0230624181248488, 0.08026058034550759, 0.03502377789587744, 0.007213174587025518, 0.0485608158182473, 0.04352919246640898, 0.040066394609429186, 0.030230335110137542, 0.057856135986625194, 0.009497998304845346, 0.016899196723956737, 0.013604827127569627, 0.023454126541412646, 0.039668254884741, 0.08510407165534074, 0.03621517868352033, 0.06020347535189602, 0.0502047332514438, 0.04523436629003094, 0.03119369642057967, 0.04694713204498253, 0.06580293839496952, 0.055637334683729764, 0.012085926625126553, 0.009540327535491557, 0.10913161500807732, 0.04645672469069401, 0.04741426947857103, 0.05248659125138676, 0.0613386414554571, 0.003482894258453481, 0.0519067814363347, 0.033498883713036776, 0.046645029102482145, 0.048478419231551315, 0.073208304332389, 0.05184418056160212, 0.0501829533717565, 0.03021561090023287, 0.04303132341573796, 0.009934627244459286, 0.09819103675263544, 0.059017758936651295, 0.05639775738781018, 0.016726922701984163, 0.036293783134991126, 0.058130414615715706, 0.01913207297724101, 0.0075775145124944475, 0.03812127438704333, 0.022540208545603582, 0.04676700945222571, 0.030448756353448958, 0.028403834026727467, 0.026808639785515207, 0.029427718198407563, 0.008865714339809793, 0.01544144535962973, 0.06984941481101899, 0.09767101626963386, 0.020601393226834557, 0.05193156438068517, 0.023763551369249344, 0.037145328167225086, 0.04211894717187651, 0.02128351599939408, 0.03070042198223453, 0.0865537781388529, 0.03255839204235423, 0.008065459851716316, 0.024219341125459443, 0.010336152120162884, 0.008907820447348058, 0.09046633472485889, 0.026734804231373054, 0.015034336660568033, 0.050385955180371964, 0.07777729101719395, 0.024009691588881037, 0.037544383366982785, 0.08475479684890279, 0.05295540258708981, 0.03690956077808815, 0.020974355471891262, 0.05656879034734542, 0.05009272353603475, 0.05357082016886242, 0.06622459318849348, 0.03474317521097199, 0.02920599894658212, 0.03942171246894906, 0.03345378794737401, 0.0418201498987694, 0.04661115269447046, 0.03319067121934026, 0.06633178421085881, 0.002985668482236384, 0.07654283225776688, 0.053904574033954454, 0.04614142205325827, 0.02215988419559454, 0.04622210260300387, 0.07274636097492711, 0.016526142548349117, 0.049491892268340436, 0.09802522468230418, 0.0009241049302809482, 0.06196493365531487, 0.019409272316542846, 0.13969988682337348, 0.19517502537177456, 0.18851197565034514, 0.09556699408999375, 0.11320756282657386, 0.13560865555078755, 0.18899716977630893, 0.14847464258632354, 0.12269274256522618, 0.14457854922981034, 0.13503519277418816, 0.08548354564775383, 0.21335047669708732, 0.09823309497967844, 0.1322787931008685, 0.21436971071506702, 0.2051423961717275, 0.17352072281702874, 0.14484553087142207, 0.10326305209028144, 0.126260528941789, 0.14100811984990874, 0.2135966360689171, 0.14390831422661582, 0.14269913636869, 0.09837666751756784, 0.17390531427677602, 0.10176390229213624, 0.10273929309820938, 0.11003525401916235, 0.21147302502105314, 0.2126175144146527, 0.1297659787439531, 0.12118665201048698, 0.16479401608868954, 0.08665093340941014, 0.1435549638324207, 0.11337506795121778, 0.12880576413965997, 0.16376338268239654, 0.15131603205396285, 0.1762364278998106, 0.20369714065905542, 0.1708169074188317, 0.08234509026571628, 0.14448419784105596, 0.11670595695895535, 0.19475122553206262, 0.17085591661593608, 0.1454961387019965, 0.12917460483168403, 0.06970067884051992, 0.07190390174547512, 0.14147290539356971, 0.13565206209257727, 0.16450780564017836, 0.14583782923798408, 0.09549216262155003, 0.20089586355513145, 0.15830545055289424, 0.22523976291619965, 0.05863660721168403, 0.12724081504969828, 0.18191180642574065, 0.16408831121460085, 0.24156253784894946, 0.08989555325599448, 0.14863461706667178, 0.22322695882570362, 0.16653004793390153, 0.14320450925057934, 0.18701266497373584, 0.08037412989764445, 0.12001695066329934, 0.11649100034828148, 0.12401668039420921, 0.19492285987061841, 0.18443457992567172, 0.17266794438323668, 0.178316417901266, 0.11784129926273901, 0.1565708742747384, 0.11910137600235401, 0.18426305283942532, 0.10689001875899493, 0.10335570276384393, 0.1247341064135394, 0.19608716029793988, 0.15188833037691732, 0.1650098843439933, 0.19863170601667898, 0.1729990475841107, 0.2145205993926333, 0.20300694140455416, 0.21915610549190354, 0.16398665134704885, 0.1461340294730279, 0.10412336116836918, 0.1553884788506454, 0.05544938267238679, 0.21277632444135605, 0.21047423022889325, 0.12880786322057247, 0.12151528840824483, 0.1111319548480453, 0.0829387624417582, 0.18755600517315252, 0.10435663494131259, 0.1516653068604008, 0.14035340578806016, 0.12375307720034354, 0.1665380612135895, 0.15029719640170375, 0.17065417502195607, 0.12982531991456786, 0.14196943762081285, 0.11501436587423088, 0.11362437594441638, 0.13621234815687905, 0.0943023284837123, 0.1430021394645014, 0.09206512957931527, 0.10645243699752516, 0.13384928866740198, 0.11204686301249651, 0.18992885526630188, 0.15693927063576638, 0.07695082004272169, 0.20784693169257334, 0.13029249565255258, 0.1625783978811195, 0.1395713372696792, 0.10009674175131707, 0.14113887573682493, 0.14878017377228508, 0.16234962870517086, 0.16170793813803505, 0.1362297383527602, 0.21514289261352634, 0.14516439198726608, 0.2613343172256024, 0.10099219894337078, 0.13707090289362017, 0.1650505636127726, 0.11544241750192259, 0.16246592085207665, 0.12363240303051089, 0.24188619467519948, 0.12767959956920918, 0.14268395250603078, 0.10012159364358073, 0.18917041289950573, 0.160027876676571, 0.24144521914422515, 0.292877926220817, 0.13163244471915309, 0.13890396743532152, 0.22883571834573824, 0.1606404252590672, 0.1272334069794705, 0.11520095424906862, 0.18962323214978943, 0.2384883649046383, 0.12534195887705973, 0.15529610396873567, 0.22705710733369475, 0.18332534589834754, 0.12523343486170616, 0.11484411815481801, 0.1267086444122176, 0.18123959491570152, 0.12498864678726082, 0.21346255536040953, 0.16416626832177564, 0.1221817082935764, 0.13229152548217005], [0.07033861557682676, 0.05689032511004517, 0.043660928945868246, 0.0044723025583211454, 0.021998611196214636, 0.052141154545449445, 0.04603341897769321, 0.020334934440231132, 0.048425237407847765, 0.04264227332427137, 0.02568772866300518, 0.05648124564979827, 0.03378519375297812, 0.09422080140681037, 0.16304232540630526, 0.059824809582243045, 0.041641264538010286, 0.06336347695680396, 0.07171192777252967, 0.09678699677028964, 0.06044707982049835, 0.071701463011484, 0.032702079493432276, 0.044442786790070035, 0.014533669473753582, 0.08268044525457006, 0.03531278839575187, 0.02659836205683889, 0.07164121019623934, 0.04946062055927131, 0.05435007331412166, 0.03370175145626549, 0.06973262470696243, 0.07064741029734574, 0.08032575144522613, 0.012431587411781714, 0.06739470822316024, 0.03248626869472285, 0.02409560260392966, 0.023380921094588215, 0.028520296628196395, 0.0634915055707097, 0.05471258611989118, 0.046570247429753506, 0.06084859799293261, 0.04908210417676357, 0.030759142621630625, 0.07960999549757089, 0.02194145720662369, 0.06280975626601328, 0.0372556678109592, 0.05793077976352746, 0.020379495859566717, 0.022220694339804115, 0.025466482470472975, 0.025066749282902288, 0.016559331392448758, 0.045578083128578244, 0.06327010233015304, 0.038531506809616284, 0.07930929832641156, 0.05928296325427871, 0.05215504371951665, 0.018163220731601603, 0.03409102754366975, 0.03407241543754935, 0.0668553670027083, 0.053628265271864595, 0.025148464051345666, 0.02036014064815977, 0.035435113485061356, 0.03937359831686463, 0.042783279467614434, 0.031809876259836944, 0.05210734708535095, 0.03176565958006728, 0.062214567235881285, 0.06175026815805224, 0.053180536675837733, 0.004716368594897851, 0.042244405560796304, 0.024049939933202924, 0.01146967304990657, 0.12977249049130948, 0.03606527825937637, 0.028028309217564044, 0.02941483642996079, 0.04865501781985645, 0.009031070587826113, 0.027105366706006953, 0.023310318431486527, 0.07412780902438587, 0.11399343880193849, 0.06445016501651657, 0.04346694016168195, 0.021876243972069314, 0.03455765935922823, 0.024703681063387665, 0.0633625882948118, 0.016992762872588732, 0.08102694406144081, 0.029380230323201226, 0.05154317695527308, 0.03598728284780537, 0.02805064451099644, 0.03927124513974113, 0.08163133380754341, 0.07918811087766964, 0.02940766010133009, 0.00933859168717097, 0.03573450830674941, 0.028410100625948082, 0.06996016048135296, 0.026358967241380486, 0.04515945055191556, 0.012859162149740564, 0.021673519870326407, 0.016972720097269745, 0.025618857358612364, 0.062029476562935504, 0.047763053988737446, 0.07105722903243958, 0.043723989473355394, 0.010511630304878759, 0.06259451620280743, 0.009960123608189245, 0.06488966199779703, 0.03984321404488818, 0.026822620890133327, 0.05197709298602516, 0.027924695825805108, 0.0369133107784775, 0.0536366232911185, 0.03342261582973503, 0.008534828516384287, 0.08145391550515929, 0.052439557283275554, 0.04617822108670108, 0.02427148106958597, 0.09149378886626613, 0.017573080220890623, 0.017051247939948114, 0.12259138147196463, 0.06148589121538305, 0.07019677439764624, 0.06025647714493736, 0.021199229090744932, 0.029095663133287625, 0.03919863149583821, 0.01779319068807508, 0.016274982537593574, 0.030790747578946814, 0.01874031284974227, 0.02482447780728821, 0.03746192932369248, 0.008669148627368194, 0.03722677097445534, 0.054985914799955585, 0.03667253317431577, 0.009533714281485207, 0.02873411942874232, 0.04324042711467032, 0.019950666652631857, 0.00962854351758236, 0.06510695517663995, 0.07775161941085132, 0.03384607859076031, 0.013003609943083458, 0.053453639359964486, 0.01900117919449845, 0.03234195688198651, 0.06107609546292694, 0.05869047468407981, 0.010529011882270777, 0.04643820451512452, 0.162282933090483, 0.02999466922765057, 0.047746372424186244, 0.03909643536673919, 0.006269906326422409, 0.03181517567305315, 0.03592588473111391, 0.026995356480080276, 0.08490499604733721, 0.03581096005115298, 0.00911080980703475, 0.04254116120958521, 0.031064428659456394, 0.06117869761862582, 0.016864898967586698, 0.07276003564437551, 0.0526228514800389, 0.07582428008918801, 0.1120660994802752, 0.03807194598559891, 0.03739023881573831, 0.03362032397079372, 0.03632538043142807, 0.022875657380228082, 0.02502668288446242, 0.046273959094598416, 0.06886225689442889, 0.046430551296760963, 0.03583534462978283, 0.0340744455705487, 0.07596316416898082, 0.06659029292002802, 0.04011843879256518, 0.0721514170929309, 0.03260560604112764, 0.04382110260907681, 0.05687686494521557, 0.040454881626271436, 0.079851558341855, 0.06637155183500822, 0.011048169558747642, 0.03927318717262918, 0.045020815450698144, 0.0339304976495764, 0.025982484822311712, 0.046559361320349484, 0.041268218023281907, 0.03922318844425102, 0.011248245869102258, 0.027383048680701086, 0.06454993264689561, 0.03968481387522432, 0.0701751477355438, 0.033010644387573965, 0.04752319185964523, 0.06684431235396093, 0.0823069007826909, 0.012348445804579364, 0.041904438722638354, 0.06319264701056866, 0.07411730595894399, 0.019737447146326303, 0.06738273426890373, 0.03707956334936523, 0.03782923400942837, 0.043590552278704224, 0.04637831942208352, 0.06618532352149487, 0.008823325737349449, 0.059364237522165623, 0.013516555604104315, 0.05409277885431244, 0.030239248543136546, 0.0075020582035874896, 0.0012263806016680095, 0.05773655349208463, 0.05663339454199999, 0.051346503032912175, 0.011623086944793262, 0.028011823005433527, 0.017522257947993856, 9.310045096489992e-05, 0.00615354762562821, 0.036895483912479494, 0.03692194841982376, 0.04993895436787317, 0.04689240655411155, 0.032196541902639216, 0.039358628958824186, 0.022671546659342224, 0.04146592616434059, 0.07842600661059541, 0.04174819892092098, 0.01741572001558398, 0.03724420713561197, 0.035296045544166724, 0.025913908461769743, 0.020600154079617034, 0.037523568758080085, 0.14951391746440243, 0.014200063080586975, 0.025004295880095135, 0.01839356038779501, 0.023518470266172965, 0.04710277046767935, 0.05937511980113003, 0.018901147263785525, 0.11162330832092032, 0.045130818015745575, 0.021510132468275486, 0.08945173553882108, 0.03557445338716911, 0.032036201615307125, 0.018071403178656777, 0.052689585399122975, 0.03252550388776487, 0.03276238593483164, 0.06427284630556261, 0.052571565723947944, 0.04078341843259912, 0.02690474360039638, 0.05223696150125996, 0.04399992668280198, 0.026272577421379187, 0.02842683390143418, 0.025745279103096937, 0.03417334369113369, 0.08192489103924844, 0.0639356948405264, 0.04010235477659491, 0.01691430972348298, 0.025510067127705104, 0.03592839366906593, 0.09144630673671923, 0.03537407159925469, 0.025309103112968228, 0.09370686366192757, 0.024825684395768953, 0.03924755770112238, 0.04071067838418869, 0.027188787935301665, 0.06079621673110993, 0.04101818224655525, 0.04109964420598361, 0.06807376855924245, 0.013216408101030657, 0.013476528467670565, 0.06874661592225875, 0.03654299919763881, 0.028488806584068847, 0.012971812506176293, 0.02602388421373983, 0.02007752123679365, 0.019528504325858047, 0.027043533834418463, 0.03168328789122884, 0.1071427588260943, 0.03140389562524375, 0.06426697807206262, 0.008789328670489692, 0.032335824348152645, 0.048723816345896453, 0.014927779575960051, 0.04242209582439354, 0.05682671299925255, 0.04932089378276179, 0.04859971010216302, 0.08553193176105138, 0.037490661451292616, 0.0692740214928504, 0.018686056587724917, 0.049494106262441606, 0.0058167049897864705, 0.06738039003985544, 0.10970805786670217, 0.04377708702738728, 0.09584125356688615, 0.102266417666068, 0.10847895406186582, 0.23594544329229863, 0.03318613597882852, 0.08928235349876266, 0.10596892826499478, 0.16927558448045485, 0.13920782854960811, 0.09750097539396056, 0.19640180793020034, 0.0904530201167349, 0.2271869439151018, 0.20201482689909397, 0.27696606552889275, 0.14932519936513516, 0.1806664692177888, 0.20059402491296494, 0.1269593466854384, 0.14691917766486445, 0.2256252430379391, 0.13231921189975354, 0.26091014966368675, 0.190859820633646, 0.10307269456285624, 0.13967460592187222, 0.20373734495332166, 0.09954181064160601, 0.1897114395133911, 0.14545906004646134, 0.23963846206184358, 0.1180923079711295, 0.11883407260381407, 0.13818516245772763, 0.2605540413529642, 0.1576950010513106, 0.07887544741313304, 0.16380236123598393, 0.19804030146089294, 0.1314709074194393, 0.1338304122609477, 0.0840120822671921, 0.1606942965619026, 0.30887059386699434, 0.13633775675008375, 0.19322692506736328, 0.1655671520218734, 0.22192531415531713, 0.20853588988463725, 0.14556202226348464, 0.19804863649750912, 0.23084660721642358, 0.18882578058588892, 0.13924334438577776, 0.11024317028181208, 0.1566053635530895, 0.11957778309982632, 0.187327649684683, 0.19169068895280364, 0.1468822981921896, 0.10638927304816824, 0.151195541745232, 0.16475588023181886, 0.16311312725226726, 0.09661667244208437, 0.1628017737980812, 0.1685266109604028, 0.1994043516535913, 0.1772940122792798, 0.11946064825620382, 0.12057802579816311, 0.17193792387843135, 0.0810704655164192, 0.11754276245952615, 0.12935324121386776, 0.10391415787800666, 0.10208123123213168, 0.1761399467866267, 0.1719186950715319, 0.09889661905265625, 0.1504693210365311, 0.09379964457043717, 0.07368206076564328, 0.08755224351320537, 0.307413341417428, 0.1684678520166105, 0.2247557792091562, 0.1898776039841675, 0.11287551733755297, 0.10567657379133087, 0.12970855279314902, 0.15355890766987879, 0.14380884537052724, 0.24134498420021228, 0.17083785226268156, 0.11566882712706444, 0.09857591932579395, 0.11489720804797066, 0.1997172832489014, 0.2796165458858013, 0.13206004435496946, 0.13379648988766055, 0.15907552213438098, 0.12466256912317007, 0.13527847165542264, 0.13552251662458145, 0.16953404722434862, 0.2226690476339671, 0.16882725450540745, 0.03896614296301719, 0.12992535567572042, 0.14295258889755896, 0.1328282007166455, 0.2226560701045298, 0.10456347868086831, 0.14257955004370984, 0.1835311630800847, 0.1739876534068777, 0.0950653060910202, 0.10079951250865575, 0.14473915190225647, 0.2728752173002689, 0.18401462584733966, 0.09133507843099295, 0.08363803217728293, 0.14062121480463013, 0.10792750865221025, 0.15818600212374043, 0.15306545511609124, 0.09409995869763436, 0.12493888937657881, 0.1437378749852219, 0.21214925083181552, 0.2236587106580696, 0.11954400628324478, 0.1144009592732595, 0.1948372725277178, 0.100834384830969, 0.09316407504581636, 0.13244760823586296, 0.15785727379543169, 0.1512513435896366, 0.19144961640479105, 0.2381531554724901, 0.17600151469870923, 0.13137491660252695, 0.13414901290689746, 0.19156276759120727, 0.08922424572970598, 0.14607989770029822, 0.08588591800822366, 0.10651576182534618, 0.13320237338062257, 0.1189375787432636, 0.1618755734976261, 0.08787431453745212, 0.16671191720712572, 0.08839383706330292, 0.16330518549488438, 0.09053778008467729, 0.11067709014300378, 0.11875524981728486, 0.18837182752547726, 0.08955272124899973, 0.11721582677696021, 0.364887586404239, 0.3470116907790784, 0.197640955147724, 0.07130109014049654, 0.1424363835324203, 0.1335061119208413, 0.19025427409477774, 0.1438255001220011, 0.15591194672930628, 0.19462224696913075, 0.11285543051217833, 0.22961809329928892], [0.0884153641339752, 0.026036721932130958, 0.07243404991083569, 0.09408669005478583, 0.04520430499988218, 0.06449102048551844, 0.03234351587091242, 0.07216430269181728, 0.01487673801039496, 0.026574883377179507, 0.054887303962342204, 0.04406601708802966, 0.1050197836312075, 0.04878858524945475, 0.05419537334913208, 0.049303748735016396, 0.07284429765516713, 0.002188786217424598, 0.05018070107325912, 0.028888486145484834, 0.04969276052208678, 0.01857126597315073, 0.014019702042963718, 0.03461509680135116, 0.04339767815244775, 0.013580354448828488, 0.037865925790561784, 0.016833826441377882, 0.05719651896206122, 0.024125660063638806, 0.006688666744007459, 0.04149623643306475, 0.06846314806851649, 0.04189259117288936, 0.005039485329161248, 0.028481925199288997, 0.0274722691955826, 0.046184073998442585, 0.06281153742043723, 0.03054091290030028, 0.0449081622214327, 0.024728010100643003, 0.033294181189229416, 0.07753210457702799, 0.0473705756538097, 0.03218002887743135, 0.10590108351842051, 0.06626771627775123, 0.05225719005290059, 0.01585228586449258, 0.026604463947155786, 0.029606869774720365, 0.031527429218253786, 0.057051804953164635, 0.025447111937307546, 0.034068562015290224, 0.01632140555058516, 0.06133398364087748, 0.028135191889539845, 0.17100496668248408, 0.023197067653640144, 0.03133670971428435, 0.06595443228199598, 0.03987274673436919, 0.028651546641823747, 0.047636814190134893, 0.013284601417610483, 0.08666203402343296, 0.07372114657154007, 0.07261657035879551, 0.10240907089844828, 0.02103006538574494, 0.02751454384246421, 0.03414242821294935, 0.019271089207200755, 0.05587717766062387, 0.08330984011052117, 0.08980532342027273, 0.03678598313502247, 0.07952250059573882, 0.04011451642239287, 0.09058940674989455, 0.03259878785860154, 0.01748352837298186, 0.01229716579414784, 0.04992688082218651, 0.03975546633404109, 0.11056675816014891, 0.06018959383870806, 0.020416913509008386, 0.07558480100405794, 0.02804157594519277, 0.10575302170529481, 0.011595932000707234, 0.050445886238688425, 0.05502431112672052, 0.07077550019828543, 0.08348381101724603, 0.06834897798516097, 0.038620407482789415, 0.08328372417318244, 0.0344174652690849, 0.03736297757695279, 0.028024840754486864, 0.030098887828869686, 0.044855003380366874, 0.03376272056371935, 0.035551329023174705, 0.009128556233800707, 0.04906084906730441, 0.06225661780204504, 0.04140651987625226, 0.03814153358220093, 0.013283333542095798, 0.030891346414723707, 0.06041138012322688, 0.0424669579332394, 0.005131767801715122, 0.028325116577287836, 0.043955110539231575, 0.019663720759713364, 0.031402690951982816, 0.013990527499587306, 0.10089335827938012, 0.05320996594344897, 0.04861777062497793, 0.07911075131907579, 0.09363579368519206, 0.03731564866499074, 0.03853446773944363, 0.06852581406072264, 0.010732184145449391, 0.009502157204664283, 0.0377428844090431, 0.022066208879433332, 0.04603162633195039, 0.03658195476858847, 0.051635961694222306, 0.05362916542517562, 0.012373033396509147, 0.04445279572880076, 0.019829764571641723, 0.05286375931914776, 0.05942783814163939, 0.06766539006944626, 0.03481656643411806, 0.025450369726205548, 0.05542730401840903, 0.06899577835875173, 0.012794446872336971, 0.012222093008007976, 0.04754700187233187, 0.03285253533132134, 0.044267421603323, 0.04386170143862406, 0.04275213799349243, 0.06851364858448505, 0.043573376587441856, 0.06275731754759628, 0.05852234136733798, 0.07556253848897834, 0.0174343895782987, 0.029673408341383743, 0.04618235413105257, 0.08752120163051352, 0.008736018527058825, 0.03208006780985142, 0.00869757623501843, 0.06324447668908585, 0.06952484634013907, 0.09362466242765227, 0.05911830797671311, 0.08880541780062261, 0.03978583022891995, 0.008923591324879278, 0.04183894586599162, 0.06476308895094741, 0.05125074204237712, 0.02538968407128367, 0.058965940749452966, 0.037604046294525746, 0.05550118936826626, 0.018121108878403902, 0.033078669164810455, 0.052678392854549234, 0.012376510478075475, 0.0509775550885787, 0.07941334072740809, 0.09083624027909772, 0.05433675104511842, 0.01619958990974532, 0.07447062570962214, 0.058516465472958745, 0.025276203467060002, 0.019452115783708233, 0.042164000802703445, 0.05749304861491246, 0.03560342300202578, 0.05572377621466595, 0.031129797026815436, 0.03783880627804226, 0.023970138469350435, 0.01424825767190346, 0.03748072912135432, 0.0029410215962167472, 0.05881699793521435, 0.011208450474265602, 0.04857677342971006, 0.06516032086144533, 0.021323459823766065, 0.03721459017645928, 0.027542580745273063, 0.04853249354768665, 0.04070273022197428, 0.07226720362180664, 0.042922803230824015, 0.06523860738642755, 0.0151945294759747, 0.01063596829020929, 0.05810168248811557, 0.03166419314971614, 0.03250473524413763, 0.045501244509772915, 0.01221121072904357, 0.05842462302215638, 0.031891805532899116, 0.028446346160865603, 0.033770982821982716, 0.029007082301822883, 0.04886993612613409, 0.09766062045650137, 0.02534254093564326, 0.026194449859641256, 0.050507529503515655, 0.07138642467438214, 0.05557266920204124, 0.03097097359357342, 0.025338017186450384, 0.012820305212611153, 0.01688300545567707, 0.06585094912518417, 0.1381896670547224, 0.020926398367831306, 0.07332912405892726, 0.05687423726363529, 0.07719766889368335, 0.0386295507421657, 0.038426265481018254, 0.037457949496925845, 0.03858986738768797, 0.057531165319585034, 0.04125290009523592, 0.09424370743574635, 0.09037995831139627, 0.027234864293507514, 0.07076058446639968, 0.022904672960360205, 0.06879424360851127, 0.007438309633383348, 0.02372579664112099, 0.0029965955294638633, 0.02274887940485872, 0.10154587366888601, 0.08008125448419202, 0.06529766510451032, 0.03603674914507616, 0.1061305957996557, 0.03482240402410108, 0.06347880000248551, 0.04021729094787471, 0.08160859631795077, 0.06316520191068131, 0.013600561933051194, 0.02824397254434805, 0.042249634110879515, 0.01912109876772569, 0.013936501063947237, 0.07117633272202746, 0.047731054496140256, 0.07185022196462078, 0.04934572652282734, 0.07727338136323998, 0.05914929240281063, 0.02927135965306192, 0.024087177551982385, 0.016190946522739627, 0.035069015387806206, 0.03102628705692628, 0.07670600898563862, 0.059205324073592504, 0.06718427919211888, 0.045098473783582456, 0.003723041755297492, 0.025161987418429028, 0.014492849436318202, 0.025724014417538722, 0.02747628924196526, 0.0335213300892182, 0.02486290860800974, 0.03352400756651356, 0.026196539364454728, 0.05597039523925032, 0.022971228764001882, 0.034945399440344305, 0.016936447749274875, 0.0454308525208504, 0.03016188132366346, 0.03794033208020753, 0.027051070224373575, 0.07322187941040724, 0.02725320826885441, 0.03901642131348772, 0.017705645990527926, 0.02860501063086333, 0.02512746749656095, 0.03366589854140917, 0.009473671182809819, 0.03609727392153394, 0.0605534166548281, 0.08119716879821594, 0.028279229825843247, 0.06459680956698234, 0.060828177919310916, 0.055583256537154804, 0.059983083347399394, 0.08317689321214154, 0.020814764035505154, 0.03220707561159807, 0.01992035829912751, 0.04605511075726921, 0.03644785873832242, 0.029577294950403517, 0.03162921740553312, 0.10219753870079595, 0.027597162594658234, 0.06193271582765926, 0.019625653850755865, 0.052028041663429433, 0.04629173616488134, 0.0647726803717594, 0.07922636164772896, 0.11506344912753952, 0.05669774209719993, 0.04931807840964006, 0.01168765475027143, 0.040666976898548104, 0.04787406778984493, 0.036861703265458345, 0.036221832157142704, 0.042904846129878875, 0.023723525190425497, 0.035900841316869186, 0.21885795939353206, 0.18797228202944805, 0.11553879902367631, 0.1623486174691108, 0.16940680002012562, 0.24195053073908054, 0.11542470554911322, 0.1743387668243339, 0.1355081907803974, 0.1281331006377455, 0.19504224701273828, 0.13885312984066625, 0.23612354341293537, 0.15766343822883022, 0.2380894782442239, 0.1696618306901186, 0.1977625486230658, 0.14137905962284536, 0.29185167483745084, 0.1894898409204137, 0.2132520803640927, 0.1680012891489652, 0.14239107709257834, 0.24396397834343297, 0.1385447488076264, 0.07957894595399981, 0.09676355447980667, 0.12054335265871018, 0.15157185945539706, 0.1356082725068254, 0.13321561137995414, 0.1986427683263056, 0.16012728424562564, 0.12699827161287108, 0.10736253412981188, 0.08788490187256567, 0.09175265763675974, 0.17121470623439358, 0.1639711304057029, 0.159120736643672, 0.20900842823809196, 0.09725201980120714, 0.15927389294149416, 0.16681590598196755, 0.21099382170265724, 0.12762434930811006, 0.19621944836070462, 0.09984904254275946, 0.15565247274935246, 0.15436497006204822, 0.14901646593165013, 0.11005140315260618, 0.09598681027249945, 0.1753542163679677, 0.2280386038605244, 0.1279583406604586, 0.15615802949234364, 0.16914755586654912, 0.16623648304131725, 0.27560990604181446, 0.121105186220619, 0.13706912556963582, 0.16845970084109615, 0.07306207346940234, 0.16785741783678534, 0.3016917984331808, 0.1350770824618878, 0.17757024826301684, 0.11878013235306549, 0.11919001237519326, 0.19442413663191183, 0.13938632703596546, 0.12833445918776337, 0.11424051747927744, 0.1405142382868836, 0.13913857420125317, 0.12707293454197147, 0.2732121121258505, 0.16652462403139762, 0.19791749756663077, 0.10777526399901799, 0.20896810136975782, 0.09979165489635161, 0.09157615097900552, 0.10645023066430323, 0.22041316384509688, 0.1324649218229517, 0.16123032828252162, 0.19485032666594754, 0.08351350458519113, 0.38594050993842466, 0.1400446110675412, 0.25163631826158495, 0.2508768033716948, 0.11352126817068747, 0.16861399094904625, 0.17920636692114417, 0.30882272869348526, 0.13452572898278314, 0.11003088731799396, 0.22060186662260564, 0.22532757191408068, 0.19651537280409567, 0.16539826027808652, 0.17009775004079267, 0.2276657641895356, 0.17622637682624404, 0.21703004296268188, 0.18428962076863936, 0.17702369049431818, 0.1825333335587094, 0.15732806025733873, 0.2115440873369094, 0.13307523342870897, 0.1984205721847473, 0.11131934761520355, 0.09935974984640077, 0.11418602564522337, 0.14752103165993768, 0.17808046282058765, 0.10395542703448765, 0.16115549681407793, 0.11329612259062068, 0.15324520998664443, 0.11170130373249132, 0.3586509565432226, 0.15422131325448715, 0.22813715341110385, 0.09172090329229833, 0.09958083516046887, 0.128035937706309, 0.07211540329961047, 0.07966047303090174, 0.32164115699068196, 0.06140963482340017, 0.1687863147667339, 0.12068858760739527, 0.16217905156795057, 0.13458261867204022, 0.06066002161993135, 0.14225364091896242, 0.12575592980870318, 0.17592014083939214, 0.12277256126605696, 0.1505796070541105, 0.17281523244755884, 0.1754859068821515, 0.20698736571977217, 0.2119678565331044, 0.20592305508832778, 0.08069327446602045, 0.14865392248236364, 0.11131120410056845, 0.16255037438484932, 0.20529166074289432, 0.23615550460113635, 0.08429840762889193, 0.23764563754441279, 0.15682656378034623, 0.16194931712121735, 0.18832497358802827, 0.10413708180309304, 0.14987198696021112, 0.1562434789394179, 0.11826353628308543, 0.18446533069495233, 0.11057962843727683, 0.17081047228026777, 0.09924620795514315, 0.20919187565244016, 0.19145663377017746, 0.09413598781271328, 0.17270885347839326, 0.12354974980436026, 0.15346241123493642, 0.11502011919454222], [0.03354168504536633, 0.04756611193560305, 0.07805625427394144, 0.05318635894406227, 0.03962260753577275, 0.05938383788170834, 0.08322629056149915, 0.06699570664955724, 0.009304133052336834, 0.019367989753523183, 0.038656467241385294, 0.04777334254956053, 0.013798978705439838, 0.0706673056007393, 0.0559157693398095, 0.035647702884049184, 0.017218168922549775, 0.010926775266266158, 0.028224368354365714, 0.06153490552077852, 0.04491687264113177, 0.041298873031571995, 0.014447900184970951, 0.00866850032546227, 0.013176764966168953, 0.05099646596898956, 0.11194678894694775, 0.10853404344450082, 0.05009620157521098, 0.035009084329489744, 0.024608404623464714, 0.04313714697115845, 0.08324497544597234, 0.10459797562009866, 0.03607771952726668, 0.014699154999107124, 0.0463808206991563, 0.14968426477524543, 0.05925522321054052, 0.039657855241168896, 0.031116336861985828, 0.011674624552289325, 0.014520981142507687, 0.04043488290100809, 0.036294660305664424, 0.03159458448569621, 0.0733359652240911, 0.03489668773967893, 0.05792023456324974, 0.025031894197567336, 0.03962163843454854, 0.04570512348906167, 0.04465337286913588, 0.05947620510273884, 0.08266909949241147, 0.010483888345920752, 0.07277587834264963, 0.04332519474349195, 0.039903152764083884, 0.05550871235168269, 0.022277365694002762, 0.030693971521912083, 0.033157648999364145, 0.03590566384035253, 0.055530469248732256, 0.0783134299901224, 0.13018159676463376, 0.02989939661816724, 0.06305165618898408, 0.052505199527067524, 0.05991552588379672, 0.03420298746336372, 0.05333930456770524, 0.06770924860311132, 0.06182187822677436, 0.025633522196702903, 0.06208904372948793, 0.11619803300427815, 0.09115181487774657, 0.013345026602638106, 0.052369927551837704, 0.030296578732950073, 0.09450605424541621, 0.04229118671989249, 0.010553854198435382, 0.024410085527286417, 0.0284705966741087, 0.06482519569896883, 0.05499387828392848, 0.08002174477423392, 0.08885257051236208, 0.04832614393484208, 0.07728864183469165, 0.006052131948602056, 0.01067809833799519, 0.007846280660164814, 0.0911451805563223, 0.07633958147057603, 0.032297650186885754, 0.018318594853964545, 0.04915156536885808, 0.0774049646251144, 0.03930058630724107, 0.06910503781851261, 0.021739918625943606, 0.024538374611086423, 0.010459485572702702, 0.033542581368237734, 0.012509474613433404, 0.012154847725234445, 0.04658538532713729, 0.019231733355310657, 0.03999244031165877, 0.03106782817462039, 0.03381968303132923, 0.03213260420447877, 0.01487817155242327, 0.05421119306476847, 0.0461890152655542, 0.032649158139622984, 0.029615233539633697, 0.0479096947087636, 0.013893207520126336, 0.06498156190519372, 0.04697969078176445, 0.0557156250391516, 0.024538232884820432, 0.06348575225039836, 0.024085105284147208, 0.050915907993311846, 0.04551038010826996, 0.08006777899760394, 0.03574402694920859, 0.021365366748444015, 0.03359981579706073, 0.05849911358147379, 0.02003633634998433, 0.018087661479629816, 0.08541685003306597, 0.08977696284531586, 0.02430091799807645, 0.02895706442124661, 0.02003471798924429, 0.0917248026798329, 0.05701909682923748, 0.06398678524419665, 0.01779117970727384, 0.02437529364420522, 0.01324767885248988, 0.032089640078465306, 0.047249951279692115, 0.01374411148830287, 0.08993765744831293, 0.01531341004245464, 0.0388209807926849, 0.006080247854228102, 0.04168193231547072, 0.05625244199989304, 0.08366379571417648, 0.03858755380215664, 0.0465968957981996, 0.04155779542822031, 0.0412927902934532, 0.04672338074493793, 0.01579018965018012, 0.037071362378135804, 0.03836625015303012, 0.07689558510338107, 0.08022429076053443, 0.07631620046712699, 0.0248567262784608, 0.06689410040815992, 0.01361583293821182, 0.012434570366636881, 0.03765568445106188, 0.015493470390567617, 0.05938697118131865, 0.06774664135469545, 0.045343365279897574, 0.0814551872111136, 0.04649293766687474, 0.0067504799845928875, 0.0033890425026672144, 0.0734717006825151, 0.055562124001763524, 0.03420957581951253, 0.05938251638003896, 0.046200790036950386, 0.06523603333100196, 0.051348383778766285, 0.06656998392915534, 0.04806804508271237, 0.04988418291172674, 0.03714342826917287, 0.07413523241637215, 0.03897622851054034, 0.00890246932319696, 0.06324895064256365, 0.03180628139225226, 0.056694455580004764, 0.013962160221361106, 0.05623596344864177, 0.06663440426270809, 0.01768563385872591, 0.12133450697987311, 0.022552693863549543, 0.061049427942282734, 0.017725956896620414, 0.03932251174363398, 0.028309097678791133, 0.0336002218236606, 0.030724130488271197, 0.03011325772310938, 0.04114856275038854, 0.048731155468211065, 0.03067394023791196, 0.046382414162038796, 0.04900012510798631, 0.08038726830554586, 0.03109446313652781, 0.047661382629866564, 0.0490392453878397, 0.035267972252181465, 0.04087024300749745, 0.043203628081227505, 0.06714305600091335, 0.010973453003492568, 0.05919533811749951, 0.040282366286602714, 0.03075180732975564, 0.08678751922543011, 0.09368968030978596, 0.016882649224792278, 0.029764011644968585, 0.027407147891579137, 0.04942914583690224, 0.03911249256963211, 0.018589822537896615, 0.00641193567594934, 0.007985581779071401, 0.10168068216092165, 0.1049798015024393, 0.07439692805130636, 0.021067915874863827, 0.04670922344009723, 0.019570279100369063, 0.030967936054953647, 0.042094780928305084, 0.04193507074829071, 0.07574056966170188, 0.02838559538847016, 0.0022589771082669858, 0.054503846312722856, 0.15668902035442092, 0.06633540014586141, 0.06505230246412178, 0.012556789161246872, 0.015393992915989892, 0.0408051791600883, 0.03230966627597809, 0.10069246704299605, 0.015229037906523916, 0.02269428606415468, 0.04897624614738649, 0.023369356997371204, 0.07741718372750668, 0.05558994065429415, 0.06251527589835948, 0.15331961244585054, 0.02958014096704222, 0.013950727316701125, 0.05635416698491862, 0.037335057502552386, 0.11740063016693439, 0.04307251979386614, 0.041855956848350265, 0.019848401575619658, 0.03416604287321529, 0.04869306940705546, 0.05560406731561788, 0.04306233848535246, 0.06090666362715345, 0.07941831263803667, 0.052830798386205594, 0.07523954815922246, 0.06369076503981506, 0.05446004906609174, 0.020825006631052783, 0.07841613939813069, 0.018622628338034117, 0.05530411708018473, 0.05580414266836259, 0.027669128894265142, 0.021631191597290097, 0.07884294230250583, 0.027773550508784193, 0.05818574148560724, 0.07681801870104767, 0.04246964307141401, 0.03210290680609403, 0.025614841142669324, 0.06487044085177683, 0.029676055175162135, 0.03613791488591702, 0.04058697050617587, 0.035327324914115096, 0.029230981073792905, 0.03534878686731381, 0.028242377166245735, 0.0671880943099818, 0.026199360483235894, 0.0348168422257708, 0.030198268584846973, 0.05405173952420873, 0.06407744791959563, 0.014029133542921516, 0.03716571376689019, 0.05391909140011957, 0.02760384096613815, 0.02813143805871087, 0.06606405180308127, 0.05514840204869548, 0.07294228796156184, 0.06690851818289488, 0.03424467796820306, 0.014842603047708831, 0.08883249134786668, 0.018236294028259093, 0.043519593384717746, 0.024336521934357383, 0.03082274324110439, 0.03455139276000761, 0.028532860470154596, 0.052181872118624954, 0.014114274639606237, 0.03867113782513527, 0.06756770619822126, 0.019417410085518515, 0.04442480287604755, 0.018837207650405266, 0.058940502799927234, 0.012399944150069309, 0.016167780023909385, 0.0061803410719749674, 0.059109061295467044, 0.05713410960930971, 0.014819635731738903, 0.04506577332053454, 0.03212830262078393, 0.03919377449839827, 0.029351791224232125, 0.08558842308458783, 0.18838440668919396, 0.21345310183542393, 0.08122332303995088, 0.1576725240316122, 0.1724543437481888, 0.1741408556699753, 0.2918912969048946, 0.11767693509858464, 0.15204953059794443, 0.10664231955043732, 0.15479402526492073, 0.1975886773077711, 0.15811555267822358, 0.15627159436623897, 0.19288826823955585, 0.10494961763822264, 0.11598602583211277, 0.1314897531823766, 0.14405779330240143, 0.15273334067915717, 0.12068905492102909, 0.27886047839157047, 0.158307810103701, 0.11413098222786382, 0.13016526377008808, 0.1665127343468128, 0.18875704717732247, 0.17536412954570788, 0.2713714786354573, 0.12621631800767877, 0.08956729224131954, 0.08965540001349104, 0.30652850986488406, 0.19482765046338882, 0.12385695872287597, 0.2154759876430035, 0.16338674321530328, 0.2736820304586042, 0.19098814036096298, 0.11298407965730276, 0.19125325274803948, 0.10931633412837984, 0.10934484792092156, 0.12196281399097174, 0.11587197066194589, 0.22914805239246738, 0.2316771691004115, 0.08622983019919166, 0.1691106151068403, 0.2449761643525093, 0.053789794910699136, 0.26901422609244624, 0.11088481488367243, 0.24908624138803254, 0.19043134765759592, 0.14146443246112717, 0.20417108861429079, 0.08960421001839061, 0.11630901616186866, 0.16414195269105897, 0.1397884465874203, 0.11655729759724871, 0.11255556071597723, 0.1064876847029213, 0.1505897347364695, 0.1880231043023448, 0.15534557792688572, 0.10675729402611334, 0.11214959540314252, 0.13114395641511487, 0.09006452926945302, 0.1638196441795557, 0.23149560626235702, 0.20795410739318018, 0.1245068311090431, 0.10463388982198893, 0.13004094302173586, 0.2695626531156802, 0.15927487353403724, 0.1955609498245101, 0.13054456922315782, 0.12582436444297915, 0.1627177645963046, 0.15780150259454406, 0.18121013117413368, 0.13124691863213817, 0.16965530362100373, 0.11111913053619285, 0.23829431483341804, 0.21076594118870076, 0.1882771543797947, 0.18432187307025158, 0.2208090167973311, 0.21095976143354372, 0.2298624906688929, 0.10437751083724922, 0.23693544339508782, 0.2948208784143771, 0.17525865456029294, 0.18781220029679038, 0.22044428233658114, 0.20101788603971082, 0.1944593766764287, 0.1230450357580858, 0.17340063087401852, 0.13530145429315107, 0.1290781543620171, 0.1503375998788303, 0.1040998116255768, 0.19772628202073037, 0.15150341716024185, 0.1792331646767355, 0.09556525507040563, 0.17106433849661581, 0.2155572082847357, 0.12872232184294732, 0.11471157728303825, 0.13984323719576483, 0.18765394185339251, 0.0954747954083066, 0.151245582608446, 0.1505117010205023, 0.1195656635888642, 0.1377507752829021, 0.09528087557203348, 0.1126656245680586, 0.13299133147924178, 0.16634828591298673, 0.11225042023485708, 0.10295158372290673, 0.09327273695699631, 0.22400246963145273, 0.13072908916060003, 0.12142696613145453, 0.15627642072016196, 0.15640054228565387, 0.09108294357335375, 0.11982300018350925, 0.11435326263909379, 0.1371792583696304, 0.10645918623213807, 0.1266883813866204, 0.1174828160794512, 0.20004556724621406, 0.17283694337933295, 0.13413494753260768, 0.1265878706509548, 0.1366461531048821, 0.07861857047124256, 0.19551571999346057, 0.16011750896371182, 0.06955614869272517, 0.24573459139754697, 0.14578601105078576, 0.18103603003246171, 0.1186934418435539, 0.10666269748922318, 0.15162214546674682, 0.18713819614100843, 0.10016028874463613, 0.17858606552885425, 0.08170117038272082, 0.1714253038047783, 0.20211956644010162, 0.1509351331380106, 0.08695030524846047, 0.15610432672885158, 0.13394799143556627, 0.19651745656324973, 0.18140989626126905, 0.0672833266998491, 0.16264112516035958, 0.09373681003888769, 0.1611594498277672, 0.11512529540566668, 0.2008664151353221], [0.029759112512692813, 0.06360372979073756, 0.0634082279829008, 0.04714729549783853, 0.06703059429362898, 0.012055832776241006, 0.010897410158518582, 0.025864061035756624, 0.058438918222823454, 0.033528420232957414, 0.01122436786611234, 0.09567066110790738, 0.06590646751705678, 0.02474662603720302, 0.016635386686351512, 0.058943099837990544, 0.03509758663694224, 0.03655745527676998, 0.035210917854020675, 0.06884498161173637, 0.05585724405283409, 0.03676042644186847, 0.07441304654123322, 0.07232127410750236, 0.05636198108174628, 0.03972668058028625, 0.013050316408607028, 0.03632185259653676, 0.05571967381383142, 0.026102299058449366, 0.04403093409153723, 0.04889469225740722, 0.11785262204225987, 0.013938692075410678, 0.03813470007791635, 0.03362336533985311, 0.02295980830827067, 0.0414645318843184, 0.01995966244008272, 0.05700926792116896, 0.05300067838341479, 0.05028028867297596, 0.04007867116841578, 0.04323309182279533, 0.0237768238425375, 0.07974858846395247, 0.024541479182399573, 0.053902467292162685, 0.028515581357022448, 0.024811111488229325, 0.13536241957016532, 0.0151817147402213, 0.022039857370057897, 0.024681449191825047, 0.01877205187244521, 0.037063632550979816, 0.03599681681202304, 0.05267849244597939, 0.06638428421630975, 0.08024233979203048, 0.006586194823255703, 0.005175430025349582, 0.03943873494262657, 0.029474717692562172, 0.07351217310755484, 0.02200092478174596, 0.047258056489931005, 0.004467714170459658, 0.004032519730483933, 0.02972640630398547, 0.13924023406880517, 0.029275031129439032, 0.061431430024845954, 0.044597452281103026, 0.16739070175155518, 0.05196132306610385, 0.0363801863615311, 0.08362676302391676, 0.03501187288953412, 0.052724794800122904, 0.023203366811597542, 0.04158269328575942, 0.004933794881517609, 0.052329677292296005, 0.051028867657747, 0.040484923764222094, 0.05362553799885416, 0.03893626170353063, 0.024094080004180153, 0.03362366028370396, 0.02517567166397649, 0.06863434573695545, 0.031646927443122676, 0.03215492034571306, 0.04978724980666753, 0.03144122708979393, 0.08332776656794934, 0.05506164642171033, 0.06561294092886871, 0.03892965419518371, 0.04851840519075913, 0.04951351510000326, 0.06583200377081672, 0.03312505578862564, 0.049575901470117034, 0.03231837286523754, 0.03519847275569074, 0.03456837309884929, 0.046135814289652535, 0.025860119513386202, 0.050318439851605126, 0.02335628753738298, 0.051395513507868015, 0.06597071165038694, 0.056248109772681236, 0.02992728413383086, 0.03329417352835017, 0.02513444081189171, 0.06434717981685555, 0.07840470170542117, 0.03768092321772729, 0.03802784230379808, 0.01932294186835568, 0.05123743126469274, 0.0520562949860769, 0.05714754296106197, 0.020696311520652908, 0.06821625325227938, 0.024067324383424658, 0.008623141217075529, 0.014628446041305941, 0.057830215401707165, 0.06749020874380104, 0.03806631523935545, 0.043636191966793234, 0.026792469584653457, 0.03801838111793322, 0.019126342639567393, 0.06159311671170497, 0.056394846253697915, 0.028305115936804685, 0.023071917615109877, 0.02597150678235677, 0.0771879778814412, 0.06712497632590032, 0.018575826111520012, 0.05072365439827404, 0.0796785450450355, 0.035599136740089424, 0.0484788827147455, 0.049241971404802416, 0.010236413218080997, 0.022067511228904612, 0.021057200220022953, 0.11356098216868217, 0.03552889796875177, 0.04410261310817253, 0.028044230439850402, 0.0015092817897487793, 0.11432279532234516, 0.022408096683061412, 0.0036030099023088456, 0.005900561931588117, 0.013527741445408714, 0.05631669762454206, 0.009109037271099947, 0.08357446220132612, 0.0646856451226819, 0.06489505525678396, 0.05638071959237418, 0.08235704123733506, 0.03514033817355672, 0.010459505682510715, 0.03398924510204985, 0.1018790836115518, 0.02249084758542238, 0.015104650125478306, 0.07394885088527396, 0.05577297821160286, 0.07109204006771888, 0.028573533993274457, 0.03697787283829624, 0.03516840763510235, 0.0696826144872654, 0.03402426681150833, 0.031314759380033905, 0.013466868098945388, 0.04644402678334906, 0.03249936496778842, 0.012144066952920009, 0.01258217061178819, 0.05755045541351842, 0.06621787459739754, 0.07446133306310063, 0.029306793134779702, 0.0383165272163047, 0.03357069679505883, 0.02117093171804182, 0.026941902695163607, 0.044647067965519045, 0.05281259996756431, 0.06377327270926007, 0.06252840281494203, 0.07877643820979903, 0.043868714973570845, 0.036936507920824715, 0.09934350878240601, 0.01268979064339111, 0.032965272830258456, 0.03195520122385314, 0.04762707721261729, 0.013409232431572052, 0.07102992565881822, 0.02637832245278743, 0.01115329597415703, 0.01600562985385618, 0.0382147103007282, 0.0511140221609704, 0.034512636371918266, 0.039430078149082205, 0.041305518844315124, 0.059222312073313424, 0.008822268536013943, 0.09206588800636031, 0.04535900496487175, 0.08236060354618296, 0.051830758701168725, 0.06340911281445334, 0.04835232498965437, 0.016857351086312727, 0.03645636997516117, 0.034860723742073586, 0.055785136026961196, 0.028855816325953895, 0.03953931079576573, 0.02958017544099881, 0.043513395733410315, 0.04083536302430495, 0.04473837415477441, 0.08813050200021075, 0.027996380588099844, 0.09066987662546097, 0.009978402466062578, 0.040475497052313826, 0.024048957425440033, 0.03031683218244824, 0.0013118645226988463, 0.022983468933812073, 0.06723759125076956, 0.08317683958598683, 0.05874811513950268, 0.02847551112814296, 0.08804355102080492, 0.03670948542534344, 0.03987823575434666, 0.0658638040805536, 0.014702263400859892, 0.02336872305961386, 0.04448630058416917, 0.02830936580956463, 0.050531592325217305, 0.05474484608238263, 0.04860092818196263, 0.0698024382995021, 0.14849390203673996, 0.05256265995182818, 0.09652956824509368, 0.050367017486883756, 0.03385945831635787, 0.06927086521060237, 0.11025240164129965, 0.03988831747143019, 0.09370062770622392, 0.0639244371784791, 0.06401192824987155, 0.054053976500947634, 0.059153287551335754, 0.010226917558259541, 0.09298932272940875, 0.10290016390142903, 0.07828265623820406, 0.022077411000106125, 0.007387042550685546, 0.041718348304951386, 0.0291064151773049, 0.05622576298792997, 0.056713412425691084, 0.07580466057744718, 0.006260441310117923, 0.03417364629586378, 0.015706803852451906, 0.05582516412100485, 0.011935380771906387, 0.01780570090387858, 0.023489462346920086, 0.0071023259736267075, 0.024002538242888068, 0.002227947913906387, 0.05127565522167472, 0.04949270049110056, 0.006269103849321725, 0.04286204479754933, 0.0806966835572835, 0.033138776423349496, 0.04366816081587346, 0.0786983815111941, 0.021872884676521345, 0.09594466777578478, 0.06619856152082644, 0.013160346744341717, 0.04919776813157144, 0.050288596896514784, 0.01660036306167322, 0.0504976048344566, 0.03275483230789823, 0.027248245934324882, 0.0840025597942933, 0.04564836403475173, 0.0495795825225932, 0.030041479115043918, 0.04803540973713802, 0.02484086442798857, 0.023925483204244126, 0.06056594985326933, 0.02838269766089657, 0.01655745639225408, 0.05121620296831093, 0.05534381192598132, 0.05948062926050156, 0.012606598282863778, 0.07379711951099097, 0.037869304238307866, 0.05991487087862146, 0.0592371626877256, 0.02969636991169424, 0.09999358035143345, 0.03513765303538211, 0.03085350358648406, 0.0199096177464291, 0.009486348022736851, 0.06600086487108661, 0.022092682962876656, 0.028054298750395258, 0.005298152043964835, 0.041017596189293175, 0.016274653119786132, 0.05823757499456406, 0.04181507073583142, 0.04335489214187668, 0.06642773672337494, 0.009073702423202415, 0.019684320863997264, 0.10724418120638979, 0.22470480371867457, 0.27569445150513805, 0.14799789074928532, 0.1472087282567255, 0.13224404335262316, 0.14667291104072525, 0.16261071146976563, 0.09660102126579131, 0.2686400381067107, 0.1125449580591052, 0.15403362171303842, 0.17228277069666695, 0.12573804931655047, 0.0904030865058303, 0.11375186829677514, 0.16806610018735932, 0.18678472317274541, 0.20796670187865535, 0.20942844360345797, 0.08647421990791637, 0.1432292845340506, 0.18935513201980822, 0.1717892262123285, 0.12069867698535805, 0.13518655642626748, 0.12422363138607434, 0.1844978281447003, 0.12469875911671309, 0.10417993676157729, 0.2014512773002348, 0.12195208109915258, 0.2386623128287254, 0.11652961884054447, 0.14897304406810194, 0.11969166973064985, 0.15671477623043523, 0.19052703203933855, 0.24226761453094023, 0.16535672299083204, 0.13295423750194812, 0.20420999055908573, 0.1394001472621195, 0.16945723924906025, 0.09400998933180686, 0.1584066354459332, 0.15151392788656298, 0.22002656523498798, 0.1340444265834747, 0.25855556310665223, 0.2824400088960125, 0.2841833798635391, 0.1272065939021207, 0.07166648343686136, 0.13526515704729866, 0.0889501164877607, 0.11963818913265584, 0.25261075145775275, 0.15539993952599265, 0.13081680622793015, 0.21633141674101355, 0.17761135654103372, 0.12527832761406898, 0.2611864928997332, 0.14041738945149607, 0.26765172339735493, 0.20803125244715523, 0.09458117682727114, 0.07662184656627717, 0.11158288952203528, 0.30872534359655074, 0.1326189821045245, 0.17434169328020466, 0.1700146448227667, 0.3274744568813232, 0.1356388087714872, 0.1105053332303801, 0.1816459126289814, 0.21446079856926398, 0.18256748575837384, 0.14039013204315018, 0.1623541639456826, 0.17562692834725305, 0.14479742054977726, 0.21380939400724827, 0.2197785825738984, 0.20515537370116482, 0.16936458857549777, 0.2668848387416332, 0.14967485721553528, 0.14932449456424485, 0.1520937491929339, 0.22208029374239907, 0.1810150698668534, 0.18599989673783704, 0.10903327996211667, 0.32563161705770804, 0.1339138085923849, 0.16285017523313725, 0.14058211367697487, 0.2198834753324909, 0.2721918362282938, 0.18363590262109236, 0.21428023164551105, 0.1697749052677424, 0.21752591635431015, 0.1369743145281269, 0.16554260656477945, 0.2055721255319734, 0.22698029935840638, 0.13475239907781925, 0.11356731005493673, 0.18746228197649603, 0.25464189569315604, 0.12748486767973632, 0.14464814065685197, 0.2257194565308671, 0.12111323014382394, 0.10936788418480467, 0.08635657178538461, 0.17617196926186163, 0.18499019285363538, 0.12746763836231925, 0.1678640674799681, 0.17322911910953062, 0.14273305874197714, 0.1019960958811064, 0.14477515803469768, 0.15436968916366178, 0.18341986582644526, 0.10540465854348675, 0.13458127035729348, 0.14949591439818183, 0.17494037567127138, 0.1344268576752755, 0.14432183316638394, 0.1688163300916072, 0.1363963777980497, 0.12879983461912603, 0.1492270022150009, 0.08338937535881998, 0.12743688759303864, 0.15576566990104415, 0.1953182072048226, 0.22298498229394037, 0.1897318634174524, 0.12034289809244296, 0.09945524270616232, 0.12072145277934691, 0.18440646449885062, 0.1477928243337139, 0.10664641812083223, 0.1732642519017381, 0.12933214315243308, 0.3024451692979182, 0.1190081660846068, 0.1753563307706387, 0.25690544036126906, 0.1043252483190548, 0.1922453366099827, 0.06704528019913743, 0.08599399003170191, 0.07390915220903774, 0.07530737758403824, 0.17968569281360797, 0.10198801365350524, 0.16630599785956646, 0.1534878759975395, 0.11581304317881023, 0.1638385971948024, 0.14965146089032774, 0.10326700510397073, 0.16721465474655553, 0.16758622271159004, 0.19719195101530324, 0.09096101301932528], [0.03706213867952747, 0.028385997584630406, 0.020206055468729427, 0.043235363273490826, 0.02948700765808744, 0.062174045015126474, 0.024766645829884276, 0.03960075104729303, 0.03007291553301677, 0.05587409415672864, 0.024956742887415236, 0.00598124343894362, 0.04346082678004619, 0.03598661635131125, 0.01340203216269372, 0.019073007598278985, 0.10748005967827574, 0.035543089747549064, 0.031027918824204997, 0.05218416272151855, 0.08505825959746877, 0.06988878406944775, 0.04465146914064404, 0.031330852972103224, 0.010613976778732914, 0.018442863891381892, 0.025905749625376156, 0.027370394823411782, 0.07070137353073205, 0.06028764926257634, 0.07017129431328467, 0.035747911014984694, 0.0648037682197267, 0.039614479342896136, 0.02449622062305289, 0.005611884201155795, 0.08234560354462556, 0.030679117077060288, 0.04325315949597186, 0.01038391195658234, 0.042560213816262064, 0.03964546376899366, 0.05621494199599951, 0.05488942219545284, 0.03965495942881511, 0.011585434680924782, 0.008356116483018042, 0.05075957243060393, 0.04710151025304391, 0.0392843950389614, 0.03835125398191233, 0.005984777498299317, 0.034213237719790596, 0.0041314336516323595, 0.03591620521019063, 0.05733849803706812, 0.022143589505445094, 0.018737788590031768, 0.027643183411489573, 0.015234331574080693, 0.0388522639930729, 0.04741600466771953, 0.028273131765965975, 0.04491774598136545, 0.043175566280561115, 0.09011700629226624, 0.003447259199850622, 0.06678533890554983, 0.09561266059116011, 0.0397324339005976, 0.057104917828955, 0.03298693013587787, 0.02504036904522969, 0.03673403854331663, 0.03626274125229928, 0.031948321754293095, 0.03328711402812793, 0.06966092653812901, 0.02241668644391241, 0.06688548957989102, 0.04874246675641306, 0.21056239162721943, 0.07878553933433949, 0.08983664875549656, 0.012137167373551958, 0.08131704623660735, 0.02588571068049679, 0.036518484384061835, 0.09203197329395241, 0.03234500208148553, 0.1319952486383338, 0.07967855270591476, 0.11161059126137726, 0.14094222096666215, 0.05474697963725175, 0.038411035653083556, 0.12032985161509245, 0.10461995468264627, 0.051019226441219936, 0.049303086068961895, 0.045027185471788536, 0.03600374224685854, 0.02740855174770038, 0.012435053959639083, 0.08081176528526891, 0.023598612639151757, 0.07030267839229877, 0.07657046504919568, 0.06159585547603427, 0.0516060727738565, 0.01202742719361859, 0.022472082261717128, 0.04456669385094316, 0.05796210126831167, 0.019983897631567334, 0.05361704208377389, 0.005577540958315255, 0.12350674162829116, 0.0730510801076889, 0.007113860384936655, 0.07725553151460425, 0.03523646688629543, 0.08357250101623998, 0.025646394389050624, 0.04776005475451389, 0.07058970855488893, 0.06613718255633308, 0.007768578277224856, 0.04435408529975722, 0.04595208342277235, 0.05981725978574926, 0.035820674046032855, 0.025138633228057337, 0.03226573879439985, 0.012240472414921369, 0.05459830878422626, 0.08703293549197336, 0.02301172417167935, 0.025777996803123145, 0.10214744421142725, 0.026638472505334406, 0.04817285357163318, 0.09783008676623145, 0.0416557819041754, 0.015367562882602217, 0.034156271421741095, 0.11498550734212322, 0.06418041013661893, 0.014164336570238155, 0.03327523583486196, 0.038668176895307924, 0.05120014576541801, 0.028200583239536614, 0.0551223665505888, 0.03278178711151404, 0.018274556289637284, 0.04488214587552413, 0.012362819529258677, 0.017057179375701857, 0.055024429870348786, 0.005228470601592093, 0.024869562081632116, 0.06592990980753977, 0.06214201870945193, 0.012983383306662643, 0.10731268478857894, 0.013162616279817397, 0.0013664316488317244, 0.06267690129818455, 0.033695810444412694, 0.11595489967974926, 0.07076325811325543, 0.05951554754809026, 0.00597144469558712, 0.07668517905497745, 0.03236500080674887, 0.1157373307092536, 0.03610853541402086, 0.05270543958871596, 0.09265543096849034, 0.05143688991665841, 0.03590421976461526, 0.09413018852712647, 0.02746513883222736, 0.0426662442154221, 0.06348678263865652, 0.03151803889552192, 0.024327951325704495, 0.06952414153924874, 0.040562386744685715, 0.08802442946621487, 0.03217408786557856, 0.03191096539188537, 0.04487200670184628, 0.051379222648158196, 0.08512123202484462, 0.017476106896215392, 0.047069437982093905, 0.0633068056026053, 0.01950750777107333, 0.06408787820668471, 0.08998989698386962, 0.05835898460880403, 0.04615872797946777, 0.08270629306113528, 0.037099738274851156, 0.044753278395341295, 0.006554833577660423, 0.06901081666470536, 0.03590413549494359, 0.05179142008625692, 0.032030383177522215, 0.035221930367932204, 0.017088458745650226, 0.03098583186886484, 0.0504955287361818, 0.00945686034092139, 0.04876907682046295, 0.047572045286576596, 0.06584946291461106, 0.014494936068301961, 0.026548064554170258, 0.020198444385201703, 0.036967040355046915, 0.04616689447674059, 0.03326281371916975, 0.053199428404050494, 0.035745559125057155, 0.02981465963286258, 0.024584067925330133, 0.03701423520162221, 0.015508720328310325, 0.028796406207425945, 0.04061980503461054, 0.0662107959449772, 0.02955875753785574, 0.07945526105862472, 0.04681266063163358, 0.042490070805914944, 0.046849593730463136, 0.013987146179011513, 0.14075716476767294, 0.11356629115799743, 0.019909204058949987, 0.07358675176698355, 0.0390324363815448, 0.035506233257511934, 0.011121566527553145, 0.043428957522396124, 0.013841032144433309, 0.06412044077390625, 0.04690344588110044, 0.16245970021813147, 0.15318127228848397, 0.018783238671359517, 0.0384847256505201, 0.06604423310848014, 0.03602055404635687, 0.04246274828009548, 0.03486725081118845, 0.07669590428591737, 0.07592510492090257, 0.0064252799699804, 0.06587613043525527, 0.09597805388752492, 0.13939970293112341, 0.0567084749890191, 0.026420863315222726, 0.12017690216100986, 0.17851841996514028, 0.05946333865605055, 0.03381070448085666, 0.10591099669616069, 0.1496645150285575, 0.11274313734423731, 0.028156309103172635, 0.051820156044296684, 0.1057253506094698, 0.10076712997209641, 0.07275747691070841, 0.06329953542820389, 0.02945415206223486, 0.01895092382666565, 0.03661948924643859, 0.01725740986125123, 0.048742474417292306, 0.017040520793788375, 0.07007935610149177, 0.020396809446655458, 0.027415933004850825, 0.04346589062122568, 0.043890713188316555, 0.04947933608726148, 0.07803365468017517, 0.03137231365056529, 0.06680482818234353, 0.08196151004202905, 0.03690249744742628, 0.06174815758582085, 0.04757340892308182, 0.028569027481059876, 0.025808747572403763, 0.003386020285805928, 0.05184547525019415, 0.05225468111494857, 0.060810316579356316, 0.0649981477087544, 0.028298431819665338, 0.04388309444390959, 0.0342044162173425, 0.024211212932582826, 0.01447784751954098, 0.06964781877374457, 0.10377724264417926, 0.020092345038128477, 0.008725992351349805, 0.09211223632577928, 0.029789579829441446, 0.02505287543059357, 0.025133305086543965, 0.023981466994530732, 0.05726262085860776, 0.039185952740691365, 0.05808009413040935, 0.03578787399155479, 0.03299611169965037, 0.022655426254195553, 0.04733685629382249, 0.04522203610488965, 0.019940320635214448, 0.029398338726511406, 0.027481977444803043, 0.05463135015640048, 0.015695889972360627, 0.04306004788245886, 0.012427977222438543, 0.03388857731835977, 0.02531921164312911, 0.06356476655890865, 0.02344479176005529, 0.0504301316405256, 0.06656287463321801, 0.07384932840303068, 0.01847211312833092, 0.06926862057298422, 0.07964685964848726, 0.061937274050808726, 0.03006431428084691, 0.07657323828748158, 0.1086493320162258, 0.04436009908996282, 0.011800535890694347, 0.18970523420120441, 0.13899059665779914, 0.16711965984394475, 0.14238667974789299, 0.10655882362756999, 0.13406863496188196, 0.20307273303549137, 0.17521494158333348, 0.05141940779022632, 0.1338930169661199, 0.1017047296608648, 0.0914494706798465, 0.13452883929975573, 0.14302273190790607, 0.17413612124660324, 0.13224399738734768, 0.19892422902968623, 0.1383718580848748, 0.18375194961986235, 0.2310490842548109, 0.15158284515623124, 0.13357034073241297, 0.17441408858904917, 0.0797971660992311, 0.17069123835573274, 0.1354704686110058, 0.1558480396746628, 0.08161111674722164, 0.2005065529937706, 0.24348413151118065, 0.1741409629222847, 0.10626113718195308, 0.16851030860937413, 0.1144330506964076, 0.14178481043106125, 0.11175175828318443, 0.123000901432768, 0.08010071311746875, 0.09280828849202202, 0.23861729750229468, 0.1601416866986021, 0.14315243059348676, 0.14093524956655118, 0.14489377908889325, 0.13726922773545788, 0.080506632465028, 0.13542864021034012, 0.15594007747788585, 0.34611080202364153, 0.21235633971950701, 0.15750606844742454, 0.23656640352020342, 0.14061808916589907, 0.2100648941291917, 0.16512761673619672, 0.13317638767823098, 0.16161688092735507, 0.15976676326845923, 0.19919548544191545, 0.12795089428583462, 0.18917654160289996, 0.12779435954026638, 0.1956848722071417, 0.18090884411527267, 0.10950767224834812, 0.24119386569626872, 0.1896706376705439, 0.3185537307252807, 0.21444601307232536, 0.10403730651183475, 0.133774166085547, 0.12427747970627201, 0.1849518271703874, 0.1098652361261268, 0.17911504924056992, 0.14504820709266972, 0.15121127719119673, 0.22987159179343333, 0.10251853720194871, 0.23586224614372178, 0.3897058627297802, 0.3618376371600936, 0.1621128922148097, 0.19698608786829058, 0.1938709138982719, 0.23057447746396068, 0.12233089625595078, 0.13210645396142237, 0.17343571770095056, 0.2198163660303239, 0.17937700534539838, 0.18240305264630627, 0.2437479109052689, 0.29529934628836574, 0.18495806312609106, 0.1736923111903091, 0.20148697699750626, 0.3081622689722046, 0.18514952382012723, 0.1100525139800964, 0.2500222322921599, 0.31382414902890887, 0.19568001520970177, 0.126320161225815, 0.1891583087103021, 0.13125068778472562, 0.11639774446525883, 0.14990716571769408, 0.13718694989239016, 0.12792358325133402, 0.09258517304495459, 0.13111794006920632, 0.1435676196049298, 0.145187895564783, 0.15295932129506143, 0.14810057717465586, 0.1297806723103408, 0.23125700051746062, 0.2204878880612312, 0.2757746762325687, 0.25880864791331754, 0.1492557611556784, 0.15861741687741973, 0.10693599935621025, 0.15936321879346527, 0.14662277824696035, 0.19933076124758492, 0.09601872549542496, 0.20788526673230434, 0.22340910389058052, 0.1574541430079168, 0.16274220280108914, 0.14605009688004372, 0.1311513568244634, 0.1085810199560177, 0.1571550776040362, 0.19603871289760838, 0.17176785235924108, 0.17381327647355296, 0.24510796211900251, 0.1683866007313613, 0.14977175201619827, 0.1866191868940669, 0.14032319128032655, 0.11416282850287615, 0.08752908467525437, 0.20257045514881614, 0.21935967037514334, 0.16244853065619547, 0.09587993334618308, 0.14439614369503914, 0.1486300205391261, 0.13945515237508282, 0.17471071783333056, 0.1623312579167466, 0.18568675063790815, 0.09701646308624938, 0.0769689150394932, 0.164366033408911, 0.1507065325014053, 0.10354651228314447, 0.08092822597151803, 0.16449963914290552, 0.12975712276754842, 0.10957272077399878, 0.191723829916408, 0.09013294092109127, 0.10585095072465558, 0.10868149238728708, 0.2098536530449506, 0.2530579629444307, 0.13299431922214647, 0.241731230409876, 0.16984278065783365, 0.19694024516690165, 0.08753716690285553], [0.025658151923468518, 0.05977024496983617, 0.030330368956070275, 0.030385400882110964, 0.04469142062589527, 0.052291001343438705, 0.019890218484966506, 0.026639171560565313, 0.02813420172089771, 0.025714978410471833, 0.026743884288495588, 0.006727006092983028, 0.056746304410720066, 0.049579099887200904, 0.05772665563610293, 0.010622916067199362, 0.024153695051227848, 0.019519757516982577, 0.01762502289737665, 0.017223272983345295, 0.022845506074748213, 0.05887355437622436, 0.024271649608929313, 0.01925943892509226, 0.0224757096880386, 0.036940089381870725, 0.07111463966148515, 0.007642395456411666, 0.01588745983392601, 0.043251420476383744, 0.03155057464966611, 0.07884848877907762, 0.06909804343576394, 0.04158675355175811, 0.07214697378297007, 0.038641900079505104, 0.03315043245111743, 0.01907509901831227, 0.05057948048136408, 0.008684605408850457, 0.030165229127892566, 0.04239792575038249, 0.08029403540516093, 0.05203271863020716, 0.039826413736708706, 0.06016438571555961, 0.04543018219391665, 0.045949689398008975, 0.019745073551612518, 0.05837963450880301, 0.11610145996054334, 0.030697213989051602, 0.03711700972710406, 0.043981425659430605, 0.10645792984794225, 0.04534215869141683, 0.0055050695194832746, 0.04336566716853169, 0.01355565673175959, 0.03442151404376473, 0.06540890107111585, 0.07388213994882761, 0.0805000824132754, 0.06287940898008886, 0.047758894131308606, 0.14888845263950287, 0.06678418211278415, 0.06567556861667864, 0.0324730881519856, 0.04988256263576689, 0.029362378559345682, 0.03267963694769048, 0.04210523802847151, 0.0967523925787499, 0.04319366510777224, 0.04095710588679199, 0.0985989785723148, 0.28718503492493785, 0.06615006049434025, 0.09739032931505673, 0.042275183143154274, 0.5137655896044547, 0.12470743889289519, 0.04130638069322994, 0.04345558673864411, 0.11614619949532133, 0.06289270060557513, 0.0355148364249016, 0.08611303243425586, 0.06012380220777085, 0.09109798187930739, 0.0496590641447373, 0.03468775641052954, 0.05687839329062451, 0.1633081425942721, 0.11689130427135576, 0.12741734469009022, 0.2708655541702625, 0.20386295272938668, 0.01323754542447146, 0.13614366071358805, 0.054171210936000275, 0.028399346666710994, 0.08395334630603753, 0.04477777022628054, 0.098992433669346, 0.052499587933022174, 0.01345774782220683, 0.024613451227665912, 0.03442464734337503, 0.03560204021332245, 0.03614307831852667, 0.015133091139667218, 0.028156004583222732, 0.11051443435492055, 0.05607532630223901, 0.04046470287346071, 0.014862648695857536, 0.011082942289630733, 0.05774539797717045, 0.12637164233432663, 0.02770880650308344, 0.05195118772286562, 0.06715525978154714, 0.1063895718224587, 0.0477419444359839, 0.06257572789646446, 0.08382259041912134, 0.0044990251415349064, 0.009179698348405861, 0.04962924417228468, 0.04490282641904009, 0.04380697594775308, 0.007808711229553147, 0.031258936468211394, 0.05881106075380118, 0.025569751122665983, 0.023729203817164226, 0.054953237319545406, 0.047036086344310356, 0.04254384251732019, 0.02968470813826688, 0.013424105071012053, 0.024948898147070603, 0.024313887866634517, 0.015464381074472783, 0.10314765626624708, 0.03922435289789592, 0.0026748862423588552, 0.09584861567183849, 0.01764214879292394, 0.04498811881808985, 0.03350467533774434, 0.038890553067528436, 0.058748302831044125, 0.04705391704074798, 0.04960132026744466, 0.06113359419208381, 0.042857371661211216, 0.10057016110588467, 0.016961832072645906, 0.0018281353644147937, 0.016690809317233584, 0.012710563117457975, 0.024289464983608455, 0.10683463826294869, 0.05356345423347047, 0.028203400527878154, 0.025374925387422406, 0.03458875103763515, 0.02761039676355018, 0.018590611608458624, 0.04200328704750827, 0.013509905003311654, 0.039179042627614354, 0.08216185735598688, 0.03640484673181369, 0.010589336518258339, 0.04569177823742071, 0.0895095292118288, 0.048554702436611544, 0.042263285797690196, 0.04638938173171013, 0.04543019368523552, 0.06252305935167017, 0.0333263224080926, 0.0688000658767358, 0.021127134471410708, 0.028774814019280098, 0.06618366877157843, 0.03162754541863838, 0.04445464200069828, 0.015246453000262622, 0.08846462358750644, 0.0338615037711157, 0.004978439134110006, 0.038591349767821456, 0.06369258066819561, 0.026798171194029913, 0.04300956268824878, 0.08173509275600796, 0.02299411181030014, 0.08144692112241061, 0.008065351641797011, 0.046139445546413624, 0.01092033055160315, 0.058896475726918834, 0.03973116985552254, 0.029559261240665952, 0.025195289260497498, 0.061882199989932204, 0.056372484147188165, 0.029024821067709598, 0.06222449190494034, 0.0812700927077282, 0.018509452253760352, 0.02804728904588809, 0.07027540566219438, 0.0914638578110645, 0.07497871820364269, 0.0422500248157209, 0.09124524696099182, 0.028885121104277434, 0.061059586268158696, 0.031140995317048607, 0.05232405037649217, 0.022972171052148747, 0.02085962614435102, 0.07636336850062495, 0.026792979033123103, 0.033346217711486166, 0.026720327084823966, 0.03267577969499173, 0.022743629787357587, 0.006258128203391548, 0.12449658085261622, 0.06082546596805896, 0.04284861527623669, 0.04415440831273314, 0.04341611405834556, 0.03985202022557778, 0.2020317421204621, 0.030912228056319782, 0.01843117338965737, 0.01359752918248095, 0.014629522394839556, 0.0508526329612059, 0.041354529319270965, 0.06799026497549589, 0.02067766302535611, 0.03373142970245212, 0.017020598677317464, 0.2498929932593338, 0.37035996695199325, 0.11145604068353293, 0.07123504570054431, 0.051128589322850596, 0.14998438738046155, 0.0696302830211578, 0.07028581679708536, 0.17099456320847237, 0.08465217937144541, 0.02225977440004147, 0.03104411775336391, 0.13612293037435702, 0.08647857128732628, 0.11782279057848839, 0.050613912303120866, 0.11767697340298085, 0.720638869510543, 0.5970520946768023, 0.04694423623262875, 0.16054369899774754, 0.057330178322210434, 0.1966972267555614, 0.12285025790333749, 0.06280276954414384, 0.07257802847532496, 0.13923038217809894, 0.144574626859638, 0.04997538184867271, 0.08468089234684745, 0.029102253404656248, 0.03888712482406728, 0.020102005406853654, 0.04759189079425508, 0.044681178030347636, 0.044204330432318875, 0.11196298404566704, 0.10739804996598153, 0.07622126685155016, 0.015679384608032004, 0.10219489569745718, 0.07126917491757101, 0.05340047668845904, 0.09599938943621614, 0.15118294725975684, 0.02144843940773318, 0.019714973957067537, 0.05520801518052336, 0.1180399382006257, 0.007030233269512293, 0.05747606827607078, 0.1101860814096947, 0.02101168502122164, 0.0071651743905198195, 0.028056332713834224, 0.05278021743100497, 0.013450103222332416, 0.05757053840845343, 0.03670266341237772, 0.058600647044518304, 0.04624323896883477, 0.03860242739920655, 0.073374392194373, 0.026502905586253733, 0.08943585453615074, 0.038325720271396066, 0.02663200289281386, 0.015220855129882695, 0.0552481658486349, 0.053437616631028154, 0.07504986478917061, 0.046724326863524415, 0.014589559418269464, 0.03991680062045494, 0.07169525769929733, 0.022266251673441262, 0.0384694766703873, 0.06432275693382948, 0.03013824751119941, 0.047717402809329575, 0.03931912180456904, 0.01913007540297845, 0.07733906574186779, 0.07230880985697431, 0.04803878052400486, 0.0056469427785956336, 0.016625157497342558, 0.042496931123276876, 0.06235316020226287, 0.02016787173136348, 0.0205202549395542, 0.047627651778560494, 0.03836367609760454, 0.07452684890238509, 0.027600223115915735, 0.034426922624510144, 0.005259042776625363, 0.021586519095205495, 0.0676447976260416, 0.01987516868769402, 0.1604054201274149, 0.10816778446878157, 0.1153383291356506, 0.1871991154527472, 0.11445218757275613, 0.20773267733954615, 0.18978247118573036, 0.14134358975195116, 0.14898740055580295, 0.10018871060662693, 0.13076363972598506, 0.08351122930405602, 0.21649594178363202, 0.13383321614275057, 0.1724098340397881, 0.1328597022520919, 0.08233739108207726, 0.17017088079404447, 0.1569661756436671, 0.10958251903855032, 0.11897064309807555, 0.1702389094017206, 0.08832153368500933, 0.12984107068229106, 0.09116476942454615, 0.08423234020630199, 0.19845031171796784, 0.08685296611680139, 0.09902479322326761, 0.14896631781612674, 0.08011648686782968, 0.21185888818675475, 0.13401772075843427, 0.13797488664427113, 0.19171685851629705, 0.104399306038695, 0.1342848402958724, 0.16784076308531148, 0.15553909173655897, 0.1434070935412761, 0.11999718559485291, 0.18275998833198703, 0.17021140684523892, 0.11851258380638978, 0.0990116011892115, 0.20407391802197505, 0.12220760206541709, 0.14910905531817867, 0.07838425481872213, 0.13449005992902865, 0.15436915290211478, 0.14839827894203125, 0.1562117169340772, 0.12400932595013611, 0.2546570795558153, 0.15449926527517457, 0.1418176909247714, 0.14849463748114725, 0.1034516629372393, 0.22245199960325995, 0.1983163229400112, 0.08757737119712176, 0.2594465540061074, 0.16762584477903383, 0.1072752690543571, 0.15172595038048683, 0.3327613215773337, 0.1525446379016484, 0.2351408824324608, 0.08541408445565932, 0.07772814647685136, 0.09185395744298736, 0.27632114207071645, 0.2205492210604491, 0.17272791374594937, 0.19245440200451883, 0.21029769292762204, 0.5877705411084237, 0.2225964378205038, 0.3047998171419867, 0.20381968408342332, 0.5949088870998352, 0.2824623173763675, 0.14258241521254664, 0.1075471306760465, 0.31620591638549683, 0.17968722498945652, 0.1406796213479773, 0.18197913023252643, 0.11193764185713184, 0.14119927410877522, 0.14057194002934043, 0.10551333577642519, 0.4892773439566936, 0.41483933827088726, 0.2501554856257093, 0.16675371496427446, 0.5456256541994311, 0.3104703386704768, 0.18558132161776866, 0.2633519476700214, 0.21197922527790072, 0.25397006722707904, 0.2566232288917226, 0.16074577767041423, 0.1914770270307218, 0.2151362429703436, 0.13262811387258192, 0.08648917394419832, 0.1085823606098852, 0.2083598582013961, 0.11791976964882306, 0.26010992486150036, 0.1827197687159623, 0.2085355374841921, 0.19342446849951822, 0.17042940482497218, 0.21035041509857103, 0.1539296329381966, 0.2528342652705408, 0.31121856142436305, 0.17874576421754976, 0.15631104789433942, 0.17026014535898165, 0.2372143147212844, 0.1293570256882137, 0.23894349774045331, 0.2725641243159771, 0.12303767365313346, 0.10362077684652421, 0.2186247469076226, 0.18131761330991022, 0.0739534780563366, 0.2812374960030279, 0.13423953385603044, 0.13197320062787304, 0.16225060418007836, 0.15594314182958297, 0.12100722655774125, 0.12099081695440317, 0.2514330291699979, 0.13841243010134469, 0.103689678794434, 0.16313718241308967, 0.14627929506522996, 0.10151509991696767, 0.1530136675724099, 0.2046383716045849, 0.10036251297400844, 0.13933345164743163, 0.14296408021642318, 0.2497882537183262, 0.12231575069768776, 0.1317331393159205, 0.1722548238091892, 0.19296455527505568, 0.16624576802695953, 0.10298956636219256, 0.1759609733257563, 0.16747025232161247, 0.1406408572990087, 0.0710789246424552, 0.1507906489554913, 0.1458967873646367, 0.179758072800694, 0.21270636529211076, 0.12611713260412216, 0.07766495954485671, 0.08475193934094521, 0.1363758006764035, 0.08404199033975603, 0.07635332508793763, 0.15760357611842696, 0.08484609920771853, 0.13648178127984847, 0.13329565224628295], [0.07604462995884881, 0.03436690346608239, 0.05050024783779537, 0.010442307966220523, 0.009473618514265024, 0.094986988922521, 0.0888552441592178, 0.07811669861116717, 0.03948971426354782, 0.06856403418726499, 0.007545604556423402, 0.03626712327522617, 0.01759314406362753, 0.04498143470095051, 0.01122480262100937, 0.018412093969903166, 0.03682585801148126, 0.020655628421433994, 0.02285746470724623, 0.06382569227547896, 0.0014968006613461542, 0.02106404904606602, 0.034868920882863384, 0.03498811267256256, 0.05306726674579325, 0.07411572015694073, 0.06844051783123324, 0.02336071552558532, 0.02613584796387342, 0.024884451000440507, 0.0457210925918433, 0.02896263771089575, 0.03565052208761054, 0.012333426650823846, 0.059340492626952554, 0.010592983096777912, 0.023127012743404316, 0.030710662662562345, 0.01518840651823989, 0.024382655749157555, 0.04994463874027134, 0.039955051390514265, 0.0817652766202246, 0.02306690356964546, 0.040920536679726456, 0.0335245514889398, 0.020989836193621162, 0.042713799123321815, 0.055396737110230236, 0.04997361601600724, 0.033012931160027945, 0.07743668832605885, 0.029426710792787136, 0.03922723721893084, 0.02866247871650323, 0.02274844273474188, 0.024085790932839437, 0.10838375231551547, 0.018533032440069704, 0.05521328586544241, 0.045739566802137324, 0.027057252553922516, 0.03618609415547502, 0.10303484215851753, 0.01678016772794147, 0.13729973335660275, 0.10665790943969643, 0.16387530812813392, 0.09898670333167238, 0.037000575853932294, 0.05210085832063229, 0.037528341485848354, 0.08343686514924611, 0.18608634209921285, 0.05861536742398336, 0.18174677576509216, 1.583744965253338, 4.3980840521474045, 3.861772249783239, 7.402786795170077, 8.420070659729744, 18.597461215911373, 22.930346650462, 37.99924365935787, 42.32125236142067, 34.24377033787389, 27.126102101418283, 36.84975777902911, 31.93271375471546, 33.377899277594786, 26.297120932609808, 39.758481594824026, 35.56944908634309, 47.712632533042665, 52.15475597689229, 43.679639754756806, 42.93235371189733, 15.912698853400448, 9.966024814113494, 0.889003912527715, 0.1989667622312423, 0.391956812912418, 0.25015217612587637, 0.3642141951187965, 0.03288198758157031, 0.006466285783737417, 0.05683188409274144, 0.04028953303913436, 0.05296836096432902, 0.09420931008794615, 0.10647527407854797, 0.14485003546841685, 0.07038470342635147, 0.06566030048434773, 0.020163648671680884, 0.07517855223869124, 0.052903572908572616, 0.022952149344247677, 0.10595662489293084, 0.05605417461464963, 0.009831031089678649, 0.03346349428137464, 0.061116395518183715, 0.05923510957208853, 0.021985570464523572, 0.08822133704539269, 0.04188616369520465, 0.0223681835022064, 0.0607072969057387, 0.08936640866581472, 0.024762386381025278, 0.022441149546554493, 0.057050353216548125, 0.0628907662335663, 0.019748735451890577, 0.04404455896527056, 0.012958060270325552, 0.10565903037786485, 0.03508905241746576, 0.03603347411919986, 0.04989011243226067, 0.03812102540846794, 0.04802944957308712, 0.07298518122444231, 0.07772870572103609, 0.02490892750962127, 0.05605340469628573, 0.0119542648392399, 0.04882839117800036, 0.01704090766819014, 0.017816893448452317, 0.05499633742616542, 0.019516591658635486, 0.04773832084010205, 0.0038601892095269457, 0.04551823633993345, 0.06213541503154463, 0.07447429527077945, 0.09252745598073929, 0.03857459159447782, 0.0405078336235977, 0.014090364077879537, 0.029813859070981705, 0.02103823954389701, 0.02828235163413469, 0.12208437682279658, 0.05148795350725132, 0.02447228995151818, 0.009461876301605616, 0.04737318035275225, 0.026003335820390813, 0.013034630758357386, 0.06793745853487523, 0.0501608862090976, 0.047535954884463744, 0.06228686678373526, 0.05891837818067401, 0.0044182880928048925, 0.026149704579203844, 0.058881874091082045, 0.03446616547843141, 0.032344936964011965, 0.07119276530800328, 0.07347918536153532, 0.089425451062139, 0.05062480224296451, 0.03194927553375883, 0.07280530377982125, 0.026845203246921304, 0.032222880005475976, 0.07053248178694518, 0.0935693662012777, 0.04842939343483699, 0.02763191425812341, 0.04118537327515022, 0.015378448034396336, 0.058222578823446273, 0.06536124274134636, 0.03392884289965995, 0.06234742220371001, 0.06756802029427021, 0.02352389225345706, 0.08068169887748458, 0.02044992040722601, 0.06469817832112312, 0.06946873039968553, 0.03677147726017622, 0.053397140375548796, 0.042839916347856485, 0.02817325688327753, 0.05902512104160363, 0.012402538315302903, 0.06478976413247085, 0.03651276170726746, 0.07416890198064428, 0.036348596725973396, 0.016444931482715953, 0.07277924146863722, 0.022015271693347924, 0.050765398529268084, 0.052015910661148454, 0.030736792006439743, 0.06791823738885504, 0.014868121436466614, 0.030604980833407854, 0.0204803973000737, 0.0646389137593008, 0.06262478050625613, 0.03418873056709286, 0.03133640327911464, 0.06184464635988397, 0.058288910546370094, 0.020887745401611733, 0.09251080122926543, 0.02661887023057188, 0.02440870082336328, 0.03211085305308863, 0.023961531471521146, 0.050252686525064136, 0.0648121951868938, 0.054018188703564875, 0.3598769423702071, 0.12599329449116223, 0.15867648225638176, 0.0662515135181527, 0.0714457122188422, 0.02605798278724955, 0.0947519991126272, 0.05369871854782105, 0.06941192498010013, 0.021463085093625614, 0.5801966894538172, 5.769696697112053, 12.038060984303876, 11.728858582435116, 18.533867828307613, 22.480070321790635, 37.0693555954964, 44.787944670646425, 63.26828587439753, 69.49305595890169, 59.3995580365581, 47.66803126181326, 61.15085317242531, 54.69201564788819, 57.801164734748106, 50.43651465446719, 64.11471766810264, 61.01555101333126, 78.62010540500765, 85.08656409478958, 75.54709311454528, 72.30804689468877, 38.05371361394083, 24.682008527940322, 4.545470053149808, 0.2037037596587212, 0.19595674148971037, 0.2374344883907226, 0.36492705525409797, 0.13981274689637846, 0.04947263281792403, 0.03924131408453949, 0.08719094112635621, 0.0062589785609875, 0.03433772700748617, 0.04211521632368526, 0.12116268111933624, 0.11280059393855835, 0.05939144896523607, 0.02264255214662802, 0.0866220748773025, 0.02307965701836492, 0.05667489735529788, 0.05425497882008072, 0.0541093263534769, 0.09161430981851394, 0.03710448035910245, 0.07050240517503793, 0.031186489448432, 0.01845242466867691, 0.030239825024299567, 0.06105987738156992, 0.03415558577304886, 0.03218852479251162, 0.0614808350350828, 0.01946472942138151, 0.056532121548849734, 0.0460805410459157, 0.03335677440308275, 0.052755683465229894, 0.04203438255635481, 0.039169397580647664, 0.06240207108578855, 0.05959137493083554, 0.013863109840801167, 0.03884625786374654, 0.06675268057733774, 0.01622220099483046, 0.0797506339187103, 0.0889331859446341, 0.03652759316948153, 0.058419834972629626, 0.036928157562450055, 0.032582677029553926, 0.0173093601986165, 0.05537696438090456, 0.09550670297035287, 0.052599144889222044, 0.06784939672797918, 0.05611395628582086, 0.04149935058047695, 0.06474790508828818, 0.03383510438124499, 0.06254557850620439, 0.040659656928431605, 0.05033224858644028, 0.041736010462045676, 0.03597782166194051, 0.04719877277591056, 0.021594088043897383, 0.06307573050200459, 0.022695358587248672, 0.06524080605877024, 0.039333589375019073, 0.025816102016476855, 0.043369811704202045, 0.03536747558222663, 0.027418541534233, 0.050561940898337675, 0.03957222193299283, 0.01592451359160365, 0.1309430268743346, 0.05252732031588113, 0.11490354359510446, 0.15078249777997696, 0.09693580934958113, 0.15107808514468132, 0.17258678502853841, 0.21704383254531892, 0.16616185075573384, 0.2527932029577994, 0.14994608298424753, 0.2041388209909201, 0.1418405663101904, 0.18242022833756863, 0.15021871835474046, 0.21737171817691098, 0.13071232715681677, 0.11756321700710444, 0.13448334899881195, 0.15098785530895958, 0.1937769149099627, 0.19524421843309558, 0.11564641905527924, 0.1469219968684258, 0.24899329960105882, 0.20875260083665773, 0.228604405757881, 0.14802245152813776, 0.10420262062501523, 0.2198477909569779, 0.09862769154771682, 0.10893702867531008, 0.13398366048932076, 0.06685275464288651, 0.17630623383147104, 0.09920432592832273, 0.10016267127808064, 0.137852021462975, 0.22847378776679117, 0.09960538827844205, 0.15557828479476515, 0.2043566657530685, 0.14940183880108018, 0.1640383163166623, 0.11608379397300944, 0.10035885107373038, 0.16387547666747726, 0.12829504396405914, 0.15619641049735009, 0.21219376054021621, 0.09501669015134535, 0.1867708876248329, 0.2072896027276593, 0.10629577967788904, 0.23053882373196466, 0.16592810200827737, 0.1770290990750636, 0.1603226979533511, 0.1596300931827676, 0.13113931392229375, 0.13101088694266735, 0.11407060683855128, 0.08258442379414074, 0.22355145834867032, 0.13303970227078085, 0.3603031936912768, 0.25833165092814353, 0.41446092147980973, 0.21498425112616634, 0.11426427386580937, 0.1468422624372667, 0.1923659494927814, 0.4374231506259211, 0.2255751868529666, 0.10392695154634216, 0.3376350810210551, 3.236104442227272, 9.176135947627406, 8.092069318217616, 14.032037085102452, 17.60263635266212, 30.512037161857855, 40.47150965659849, 60.304876373660186, 69.01735874914354, 58.00924647238947, 46.53448589386479, 63.496399156508915, 59.3072646664035, 59.68415344915083, 52.78981124201129, 66.74962474453834, 63.053532185093054, 82.14490413665771, 89.45803780709544, 76.36461704008042, 69.43273775039181, 34.960293231471894, 21.22330761724903, 2.5120204446777223, 0.1893463066869205, 0.5274405654880309, 0.39958416814765624, 0.4587124582500227, 0.20639639017322373, 0.12859911958296455, 0.15319748270896175, 0.2197653752180838, 0.1118553946575811, 0.2116031680376299, 0.1783542320012085, 0.3468490349909952, 0.16074254477937377, 0.22118150406787473, 0.17999457946467787, 0.2264832768348917, 0.1394627519672917, 0.14049831897981707, 0.20664700817677284, 0.13630562702253943, 0.1623068043902036, 0.13267706689094344, 0.24047856940136803, 0.12088380979313967, 0.14375687396574405, 0.1368718885726506, 0.12029147061008601, 0.15625959742934475, 0.13747456994268203, 0.23050199022456525, 0.10556730667069074, 0.08973197816240211, 0.12373473705543626, 0.10676933692828303, 0.13434310894339316, 0.14104941198902746, 0.14667189980466522, 0.1694637969616921, 0.16850846999835584, 0.15877769779293768, 0.18134421188264124, 0.27237851653368245, 0.16128127312948629, 0.13700684262139184, 0.21716230038192966, 0.1212235774484373, 0.1857754942630568, 0.12436319728411975, 0.13516127552476623, 0.09581525254273608, 0.10639852739029354, 0.26756684085534466, 0.07782309541418668, 0.1683242105308079, 0.14711788555066432, 0.14353383512746903, 0.15681888757934495, 0.17335635099199512, 0.24406528581053982, 0.14409773712677343, 0.1917830178694379, 0.12049639146895179, 0.16396382192690528, 0.07621120811710436, 0.13501536641870776, 0.2928807760678953, 0.278771520261803, 0.16006518515848345, 0.18030875212242528, 0.08531424787736709, 0.08840428650259011, 0.1300793240267423, 0.17384514573120302, 0.13895383975919218, 0.1172051934765712, 0.145659054959974], [0.0877740336281638, 0.11093399772841124, 0.0321476080364758, 0.06446095919536968, 0.03279523195458516, 0.03751052611116921, 0.03218359501671887, 0.03722932970812244, 0.06624202168877087, 0.04152676886728695, 0.040892179935209216, 0.021025168168688976, 0.04057390104618765, 0.044639981652219454, 0.05717154066529005, 0.09355226711880776, 0.029161282394441868, 0.036674678220503756, 0.10625019744639436, 0.03189946449692211, 0.027794719433351874, 0.02979748394160021, 0.025060871473303246, 0.05229435297810743, 0.029820805573235118, 0.046375933058199384, 0.05105191158250936, 0.04143898668248327, 0.027999986947003393, 0.022376775178277207, 0.02676645323874489, 0.0006960932836180643, 0.030305210628636906, 0.04120931352278398, 0.03189140716717849, 0.02159792422917822, 0.026169191940777728, 0.06207791247194814, 0.025878480725711393, 0.06887043105258096, 0.022274517762144248, 0.03913079441014317, 0.0476885212945842, 0.02376223369801958, 0.0058187662451077374, 0.025199878127163938, 0.00963900444818841, 0.0376591969641947, 0.021273413214892633, 0.025267807143409888, 0.023053811127019506, 0.018201940730514548, 0.11905105168660803, 0.11186196003109218, 0.06357903494649837, 0.06305423024440966, 0.0614779890184441, 0.04816794677847817, 0.07444514562526057, 0.05027168550558629, 0.08847243002345485, 0.05504268191514477, 0.10232424964347195, 0.04453206667676569, 0.04627855945258372, 0.346569229037531, 0.2322167554689992, 0.25233304458520106, 0.0664779844303285, 0.07053674123580418, 0.7568275147388059, 2.3761277237246117, 6.512984864173397, 13.679236558175857, 29.315567170420003, 45.62767705609722, 69.44125713840609, 77.51630337007585, 99.07712505709742, 104.1734370877666, 113.48655593010687, 119.68668568518855, 119.25328731536867, 122.87159535192676, 125.19523882096814, 129.0753415323073, 121.49090536179082, 123.11709650101201, 118.87197802143713, 114.04572902187225, 115.73448196534189, 109.91526926717451, 116.84731329641035, 124.40808973004742, 127.4799959121212, 131.95501235223585, 119.28234423360517, 102.58678343988235, 97.05158956589239, 79.07391578920426, 44.041784348026404, 20.72473514464594, 9.888274611965302, 6.0978367924690255, 1.504591902898204, 0.05650685596910696, 0.3197069381994586, 0.08289950809651807, 0.022569653134973302, 0.06279322791904693, 0.039046957578149535, 0.09682152435303697, 0.07714622608956791, 0.06740966992032144, 0.13433927850377175, 0.12273162918826266, 0.03172707173132128, 0.03708086186839688, 0.05274821793840778, 0.036577323767086195, 0.11088449312674423, 0.07995237551269033, 0.01715074169389423, 0.05752222507350868, 0.022230243625780268, 0.061587945618216074, 0.04469366143307379, 0.10720981450210657, 0.03746249622875645, 0.05209559146615286, 0.14691527061645063, 0.044942042459884, 0.04563046822084054, 0.06705618163029994, 0.03526381622519224, 0.015991854635367713, 0.03411622417549934, 0.03381302189682761, 0.12158250496272119, 0.038246315258044394, 0.021926039687147545, 0.02416246292752124, 0.05023665230480894, 0.09391538513403747, 0.0355445989407599, 0.04066988037178113, 0.00757745418307041, 0.03346807548716184, 0.031177980126813058, 0.06631821679371981, 0.046923747211093866, 0.02041880766140117, 0.08597863762969933, 0.011357239113309452, 0.01472764485140121, 0.017878611406852162, 0.013284823583108524, 0.020812664954592625, 0.03584125882855827, 0.006816215595350631, 0.012012931852481298, 0.06783446567433496, 0.05299221694229111, 0.058030440141597105, 0.01915654374076234, 0.03276573373906074, 0.047431939296544566, 0.054144256132384466, 0.11781155972951844, 0.03796146844603843, 0.03748461701757005, 0.059308619538862864, 0.0452663044955942, 0.04429650996180792, 0.03345729279962759, 0.07097745629688425, 0.020664369484650034, 0.02387121928134753, 0.031018890478017352, 0.1505468184909513, 0.05219674954611448, 0.07534178259271769, 0.015249179315663155, 0.035305284564533544, 0.06103581455986827, 0.030798153733954798, 0.07562906556432286, 0.010883995958964431, 0.030598819571276827, 0.0013395475886476738, 0.024519729946229248, 0.009372165490452562, 0.023496466305767818, 0.037504895364925746, 0.0551642447469696, 0.04537855552869939, 0.023386207101265752, 0.024427425927452506, 0.02353645992585488, 0.04802854941977609, 0.08113526123305483, 0.029524549796816804, 0.01600902075053103, 0.030506406384970874, 0.04701678475905811, 0.03252773703406415, 0.015043771033355547, 0.06335798410638686, 0.055074298363779826, 0.04674363227921628, 0.08136539404550869, 0.024073140905989755, 0.026479357958681164, 0.07509534742923514, 0.010849517214322283, 0.037618081025298566, 0.056896055447718794, 0.017239232510027867, 0.06687873268439885, 0.036087054308624036, 0.02646695116474744, 0.020524993193365877, 0.018848183775140394, 0.024209048734196735, 0.026448409921760042, 0.023046619476630323, 0.021923433072985183, 0.04516084100149813, 0.06306721926516583, 0.060433002954889695, 0.07454819211195554, 0.0432184097477265, 0.02053724485449493, 0.01579005175435375, 0.03911187586885306, 0.046122292837788986, 0.010929919099585425, 0.07026892455835497, 0.11472761916417269, 0.11847958073861177, 0.04301733848068022, 0.4589079026012652, 0.2662488019033786, 0.06475088517031362, 0.1330636195357769, 1.3428396082693532, 3.691357768351032, 6.104015996379237, 17.977269772560366, 28.476111312066358, 50.445438046609205, 72.73346716357817, 95.08120259931012, 104.51811928902904, 128.1396209039996, 129.05390970168577, 135.89818677594585, 140.3868216852988, 137.50860214233398, 138.24065762181436, 136.8537232183641, 142.50447796237086, 139.513513811173, 137.01789794429658, 135.46289782370292, 127.64503355949157, 134.0116051704653, 124.69268906501033, 130.4152310279108, 136.18977577455584, 143.8630614742156, 145.63170525335497, 131.91977377860778, 127.8500166246968, 123.13954814787834, 112.54237867170765, 76.37607036098358, 43.84264953674809, 26.21973256911001, 15.116132151695991, 3.349588662385941, 0.5775836554746474, 0.18779321663802673, 0.089392984255908, 0.12842600669471488, 0.05638536591563494, 0.028818919616300735, 0.04068967991418416, 0.04855969349943823, 0.04951633047312499, 0.038562161817906365, 0.019296845083215067, 0.06428862771680278, 0.04989085553754723, 0.025706756371824492, 0.01769660615302142, 0.05342287326892538, 0.18392755229386593, 0.028615866096750386, 0.049156265318273544, 0.06352542411355723, 0.03057610123388229, 0.03789881777559077, 0.010020854270776675, 0.023127072115218448, 0.04996599344116065, 0.054200847047351064, 0.04728052967918977, 0.03320935993425308, 0.05951833227769502, 0.010296965765226032, 0.018496321506738182, 0.06512842096027828, 0.03983199085679747, 0.02840864505889195, 0.017653031071888346, 0.11130953402889353, 0.026572338050051082, 0.017265310142970374, 0.09947755884739662, 0.04561128920965618, 0.03422811514728012, 0.008351427067311542, 0.011371903951399991, 0.10157113158774954, 0.06735510913835419, 0.04866951986426308, 0.04817994754581202, 0.042946743478457776, 0.023575641492742206, 0.030649747181263183, 0.025683317911781134, 0.04363372516367705, 0.04264453328364799, 0.035051108082576145, 0.07988770237012256, 0.055571753726971734, 0.017805063135681615, 0.08380412003926693, 0.018419030896057526, 0.00469894727669476, 0.022008503306536906, 0.03920462996428532, 0.08035873919124566, 0.115808239807525, 0.06712189665244472, 0.05618069403534455, 0.09497400373220445, 0.06633193742844366, 0.0359732557779118, 0.07678157589848965, 0.04399115880650859, 0.08774722821169323, 0.14141129660269908, 0.13157710252750304, 0.159917131006237, 0.2296670922829259, 0.13511750126077285, 0.15839433207386927, 0.10704149732426291, 0.170059047278858, 0.13665598967382986, 0.1306923016184761, 0.07032719320587574, 0.11839253016777578, 0.14270707303958555, 0.13754422265675761, 0.1760210039755029, 0.19590841666344674, 0.1429959035087978, 0.1918559647615879, 0.1119515233703198, 0.1185537533714406, 0.17118577875437277, 0.10084537053180319, 0.14976643536600376, 0.15656177315019792, 0.21141040499412247, 0.13157059078014668, 0.11874378148105838, 0.1290880828615158, 0.1837047432819682, 0.1279247247223412, 0.18008358355972076, 0.0853689618769192, 0.10742384414639204, 0.22779026879898964, 0.11307198824661394, 0.09069126580030688, 0.22215080447494986, 0.1119034666748297, 0.13944834951431523, 0.14071110756166522, 0.1030741194863954, 0.0869461760345486, 0.06593184800998819, 0.06414478321770026, 0.12986134136876754, 0.12376300569984222, 0.13263860927714458, 0.13973878876816842, 0.15460457172124617, 0.09397537747938788, 0.1360873992164289, 0.17136967049971705, 0.29550254344940186, 0.13588772605984442, 0.19619710923683262, 0.12542069739391729, 0.1661200529985851, 0.152358218066154, 0.20409115500027136, 0.18817506550300508, 0.12269883296422421, 0.27293065142246986, 0.1321558359890215, 0.18713258837740268, 0.5372747442414684, 0.4156109726717396, 0.4577711813392178, 0.18532578532974567, 0.6215949164282891, 2.527429966195937, 4.864952006647664, 14.71896569575033, 23.641442944926602, 46.203159363039084, 73.72564638814619, 100.42446705602832, 114.60065810911118, 139.7505504854264, 142.4712633317517, 152.16389502248458, 157.5706155838505, 160.04880043768114, 155.63492590381256, 156.88611492033928, 163.63052060527187, 159.10324250498127, 157.60897636413574, 156.62444576140373, 147.94891603531377, 155.3814152748354, 148.8211727142334, 155.19411425436698, 158.2405407198014, 161.90596426686935, 166.28329800021265, 153.35466384887695, 144.64340917525755, 141.53469547148674, 120.68126540030204, 75.1843209420481, 41.155496489617136, 24.12739715268535, 13.464922174330681, 2.9682247004201336, 0.4470797195549934, 0.3820975064750641, 0.34524987241433513, 0.21671876611728824, 0.15569701310127013, 0.13231974816130054, 0.17718703576153327, 0.20411234499225694, 0.11472757319889723, 0.34476444846199406, 0.2040785451930377, 0.2137453950220539, 0.12371759966857011, 0.13641459536888909, 0.11197665105423621, 0.21068351012804817, 0.3003099290353637, 0.13316489635936676, 0.21758167223343927, 0.14146293092879558, 0.20710790199377846, 0.11288647239487018, 0.16375455734950883, 0.18881314013513828, 0.15149491358428233, 0.26248574737579594, 0.11731819144540256, 0.11939011454101532, 0.18239048880434808, 0.17575481906533244, 0.08281254179535374, 0.1281504831727474, 0.0982651787419473, 0.14216869708991822, 0.24595842696726325, 0.18064203101300425, 0.09652657284130974, 0.19227501485616932, 0.12650003867043605, 0.10827264658385709, 0.20677664557531958, 0.09851666242485085, 0.11275164092019682, 0.14251752756536007, 0.22672517675786252, 0.14086899828285943, 0.11789540039195169, 0.17104121796306104, 0.12962762326482805, 0.08354283809181183, 0.14404222639578004, 0.11778355155500675, 0.13818219003658141, 0.1687705639990107, 0.19478816629177143, 0.20902748850564803, 0.14010753752964158, 0.16188827523541066, 0.08924573449598205, 0.1535097095033815, 0.09776921341976813, 0.08669280011447207, 0.17839989084149563, 0.2534773654394573, 0.23880433020812852, 0.2326982110858925, 0.2081026211981812, 0.17656748513540915, 0.12569181591032014, 0.1274130622585935, 0.24307645016139556], [0.07669693850461515, 0.0233812581732749, 0.02661124574050548, 0.093783863159197, 0.04196068872847865, 0.053662264253944165, 0.00932413081999027, 0.02917535159917128, 0.0468526121168848, 0.0711453597872488, 0.0016754091531413818, 0.006453626180788683, 0.048335348481252316, 0.027289304416626695, 0.05184161033661616, 0.022946752254821123, 0.008540645996559291, 0.017701874922720656, 0.041088773418338075, 0.09158216476921113, 0.07128213712524983, 0.03722572909487832, 0.03743013667483484, 0.09845160623832096, 0.034878895347637516, 0.04657986183320323, 0.05708336777564499, 0.03050302985244461, 0.03225975564771122, 0.0913914088760653, 0.019180518462352695, 0.019089999428439527, 0.07833162457832406, 0.04917685393123858, 0.0519771006469044, 0.009687028584941741, 0.00614912155264568, 0.03943253346087952, 0.04666744866558621, 0.02289552778576411, 0.031025815912852847, 0.044300439992859486, 0.0035341098696188705, 0.008216153176861906, 0.01851297242777242, 0.07504514568755705, 0.06767045391062576, 0.05468254398194052, 0.05520927156471918, 0.009250392942058464, 0.006642736421312176, 0.06872777015932145, 0.0346677576852662, 0.15810662009302648, 0.062207162996093114, 0.023110721883694493, 0.1100936069363548, 0.07826721190565056, 0.024572331458330158, 0.037332537073281505, 0.0495841101022257, 0.06864843409388297, 0.11924904711063831, 0.11555955234554507, 0.1547286779649796, 2.984528767485773, 7.214111474252517, 14.817013182947713, 28.90012541124898, 49.18185434033794, 61.20471515963155, 63.766336671767704, 92.00820599832844, 103.7220742625575, 105.74525633165914, 103.72195659145233, 107.82234745640909, 117.57022180864888, 98.34501466443463, 96.92939989028439, 94.02688518647226, 102.65816273227816, 95.98579529793032, 86.83799651361282, 92.37095463660457, 100.29022785925098, 87.99896317143595, 97.80117804004301, 103.13125548824188, 99.60764915712419, 97.11014270782472, 94.72979745557232, 98.76872477992889, 89.01399412462789, 91.45661092573597, 97.18919415627757, 110.88276893861833, 103.03802859398627, 107.51263710760303, 109.20922694667694, 122.72741686913275, 118.45198631286623, 112.03004652454008, 85.38254614799254, 58.72320413589478, 38.24350533946868, 24.520408838025986, 5.45228575506518, 0.5267285327276876, 0.14509648595365787, 0.13862541786605312, 0.3345147436184268, 0.037601571830530325, 0.06615240472338854, 0.05623269225320509, 0.06395061823329137, 0.07955414768789085, 0.07674458917350539, 0.10347270737251929, 0.06400463892327202, 0.007310345658146206, 0.09365608735430626, 0.05053783211136057, 0.16365522638924662, 0.05117938478267001, 0.010928791035116922, 0.03254213182616138, 0.031067326387029984, 0.03279776004473529, 0.08271147947638266, 0.025864739023569613, 0.033253183993961544, 0.01715611963112268, 0.02161658421579388, 0.03508634429665343, 0.049411966315200256, 0.029917949352473504, 0.03546553100609491, 0.0668789012237422, 0.10953023353771818, 0.02586901187896729, 0.016615673328839963, 0.06972153175381884, 0.040215555758726214, 0.047505690581015045, 0.04332422947270736, 0.03397542104545621, 0.04651021678000689, 0.055282555535555854, 0.0314251124303067, 0.10661063415388908, 0.054252856756530465, 0.1034123243223275, 0.05078797514039663, 0.059812517701497966, 0.058952350349676226, 0.031127529406559565, 0.06271200727731471, 0.03941862130417459, 0.042194805198138764, 0.025621956184266076, 0.0809164435392426, 0.07739541150869862, 0.10070250279480412, 0.020225274699529814, 0.04847630099844068, 0.07449163950138515, 0.03417479925818982, 0.056980271493234945, 0.02714583721582688, 0.04328101828333832, 0.013242386142543007, 0.0912730559526432, 0.047735191370931365, 0.008567725289462796, 0.11689253767291385, 0.035572660741426294, 0.016390878233998533, 0.018723317189142108, 0.05972583102242601, 0.0417058763935441, 0.08050265646870099, 0.024192744467948234, 0.07023251239931391, 0.039510249250358155, 0.02146668379164992, 0.020322230787226753, 0.021562971467632922, 0.04411023185257951, 0.0788300337209817, 0.015093696025771, 0.04975487876142706, 0.06192968211947911, 0.02407474011453169, 0.07342473183187746, 0.03898909878766826, 0.03126003580438274, 0.01602595225126753, 0.04748283051735452, 0.040852374006663604, 0.03554287141249065, 0.020462489994843642, 0.04514139002910064, 0.04377975684380339, 0.03413749460671698, 0.0363282839046611, 0.019474991169127247, 0.03439695709535191, 0.06136000381722566, 0.04154638071814853, 0.022786900348540758, 0.010981692279118204, 0.08184630573997576, 0.06630785162410428, 0.04555488981667065, 0.09522896545428423, 0.09993593223513135, 0.07921056491473029, 0.06153195608227004, 0.0249712870666577, 0.05652403166036933, 0.043025914834992546, 0.07466606239998534, 0.04251824368933036, 0.039298797491937876, 0.025018508726310347, 0.10444819777002258, 0.06644363304780376, 0.02615562835407834, 0.054583082786731185, 0.055121443414640044, 0.047132850910026225, 0.01926913185255422, 0.02510697847502607, 0.04569817124114883, 0.03316279711021531, 0.05347305968884499, 0.01567624843559198, 0.16404306606179284, 0.05893154340165277, 0.4856169452109645, 7.527542681463304, 15.767388766811742, 30.12158090068448, 52.021458148956306, 77.57149111840033, 88.59604204854658, 95.06542682647706, 118.50975498076409, 127.8891226553148, 126.29737777094688, 124.5227719891456, 128.04633909656155, 133.86875244878954, 107.86503068862423, 107.45272682559107, 101.83397077745008, 117.45005607604982, 111.78861679569368, 102.85919989309004, 105.3944944566296, 114.39373739304082, 102.45652937120008, 111.12754837159189, 119.92297710910921, 116.2103674488683, 112.78593432518744, 112.80167871905913, 114.75701947366039, 101.72648998998828, 109.97948631163567, 109.93052728714483, 127.62081684604769, 122.65952848619031, 120.49727486025904, 123.15887758808752, 132.69806615767942, 135.04618521659606, 135.01537107652234, 111.11813468317833, 85.81216335296632, 62.46468636297411, 45.7148713450278, 16.56852306858186, 2.5240111302944923, 0.39684990841534834, 0.08724566278678757, 0.21696870996346398, 0.046369616663263696, 0.026720886329008688, 0.09990501292650739, 0.033544274422550396, 0.03751277074878735, 0.11552289503836825, 0.0440046725974929, 0.060840347225988106, 0.07926429066086009, 0.025959362373537114, 0.07465009712764333, 0.07824504132112188, 0.03222646912740123, 0.041296141928121935, 0.05325750936002982, 0.020658671705713196, 0.010337410419578514, 0.007486835078922131, 0.05401667951035404, 0.031643901395821766, 0.06444568340215953, 0.015209879005147565, 0.05607287865132094, 0.12503172391124312, 0.021147803523607796, 0.02915617833364635, 0.005204356068955554, 0.025111666933122664, 0.0798011574173166, 0.015618958465394475, 0.07103480563889589, 0.039857229623462886, 0.07643341958042114, 0.0404735780020635, 0.011693482764155395, 0.036851184878257975, 0.030388323507542093, 0.0231458910650784, 0.1435430435043189, 0.04207393567588541, 0.08142863460365804, 0.09723975473353941, 0.08319912508370415, 0.08565381634980442, 0.027594100158180923, 0.03299464464127537, 0.06205442804662932, 0.0935551705920408, 0.06163169689957173, 0.06582875555801777, 0.071585416012714, 0.0033834747192750298, 0.00839220209708137, 0.08299994988427048, 0.061315758409158844, 0.034720387925664266, 0.028585329832088564, 0.02009057154458377, 0.07168095483775101, 0.01396000272624435, 0.05768227233220974, 0.019646928112413135, 0.05761820439910216, 0.03395813810188444, 0.1750091244015963, 0.08272497028472924, 0.10724644116576641, 0.17061928737788432, 0.1875271696236826, 0.21516590589477172, 0.12008318662523262, 0.15748792748537757, 0.12634153507890242, 0.18383422746293007, 0.12393491583005076, 0.16188700352945637, 0.2116176624211573, 0.19317795672724325, 0.11684992786256537, 0.15659794782198247, 0.14927698179118096, 0.15619023582868038, 0.24619295712440248, 0.2286676539769096, 0.07912293211707185, 0.10048152473304542, 0.18828706755753488, 0.24647452508009252, 0.10967042762786151, 0.12749373897789948, 0.19610631249604688, 0.24782014319733267, 0.08097904058353556, 0.17111922103551128, 0.11019196496495318, 0.13166310355788277, 0.18448538687681, 0.1254200385583024, 0.16231247344084326, 0.047361244702891964, 0.15438271265837455, 0.12862581008624646, 0.13858127587985608, 0.11996517844137647, 0.12831272527335152, 0.1787626487954009, 0.15487480157565686, 0.100566353648901, 0.17806295005063857, 0.09769639676256527, 0.20659215628139435, 0.317068163666033, 0.13042793999756538, 0.1154298919643606, 0.12680213012161756, 0.20334789649613444, 0.15363363188601312, 0.3171603087215655, 0.2225918719364751, 0.1943480181357553, 0.19136401374013196, 0.15267133352256593, 0.14714365674843713, 0.17725103474672765, 0.16893678975682105, 0.15517285574347744, 0.1953267261025406, 0.2080210481560038, 0.30783248344256037, 5.086671825378172, 12.295145873100529, 27.19952298748878, 48.01946778451243, 78.0301260179089, 93.50578261959939, 99.13261875029534, 130.69886545981132, 139.74557692004788, 139.6697025914346, 134.68636266646848, 137.30692955755418, 141.62076796254806, 118.95444977668025, 118.32883957893618, 115.95699802521737, 126.07049219069944, 120.0806014768539, 108.82230081865865, 117.47807748856084, 125.81459676065754, 113.15030682471492, 123.21834071989983, 126.20757118348153, 124.23271271490283, 122.97072149092152, 121.7489424059468, 124.33289789384412, 117.6165371556436, 119.30225418459986, 118.82911436019407, 132.27117107760523, 127.02857032898935, 132.1265140656502, 136.24862701662127, 153.9904800538094, 156.22682725229572, 153.08547942869126, 123.18306292257002, 90.3335657427388, 63.238981846840154, 42.963893490452925, 14.267499908324211, 2.005464477885154, 0.26758911869218277, 0.17971659680047344, 0.408150073020689, 0.3267601258572071, 0.14010119432162854, 0.18392888528685417, 0.19454963715566745, 0.19218584222178306, 0.31687345475919787, 0.23585400303765652, 0.2069583769527174, 0.14053902889211334, 0.12627437981145997, 0.18905887049773049, 0.45316659454857156, 0.16594518576898884, 0.17356284233110567, 0.18286952358340064, 0.09793498718570318, 0.07986259000796465, 0.17509166271455828, 0.14108112802909267, 0.15454420399281288, 0.1498592239353926, 0.057922000395915205, 0.17469102937367656, 0.17770674980936513, 0.09284690698428501, 0.14405279840913512, 0.14794086316420188, 0.1963351889243049, 0.13392769010557284, 0.16592263214049802, 0.11479121978364645, 0.13707473333324158, 0.15361991891216847, 0.1535519669132848, 0.1761099314617534, 0.15680782526971834, 0.1626247155570215, 0.12665678025974383, 0.2757485066690753, 0.174346121268407, 0.2515332334704938, 0.1740844409552313, 0.14400712424708953, 0.16179441414292783, 0.12192832471262063, 0.17667858320618832, 0.11742626346888081, 0.1495375895812627, 0.16144665619057996, 0.18818542301174135, 0.24070012202906996, 0.211784623623375, 0.15488045530453806, 0.2208277399862005, 0.18370213858302564, 0.18154244479392806, 0.14102826796231732, 0.17962149464555327, 0.14320624060928822, 0.13287139275381643, 0.17191541621521597, 0.1266783073304161, 0.13674618886603465, 0.20647099181529016], [0.0032093173180211096, 0.021441443109764688, 0.03084445608809831, 0.037534332293416225, 0.032923976860700116, 0.09737994882368273, 0.05068913447640596, 0.012288863316268451, 0.05329931094761818, 0.025929776057901404, 0.03614863245597771, 0.059538327172518744, 0.06029873455484068, 0.0228745331461992, 0.013413227580097175, 0.02116322678874337, 0.05495801770819291, 0.03913841698498976, 0.025541095603858272, 0.07025856704961869, 0.05040949323184548, 0.06911408531689836, 0.035772548402629556, 0.029036890782956636, 0.019552115155684373, 0.06816092638238784, 0.06182331464163238, 0.03820328792977718, 0.045053060091431105, 0.06988562012632048, 0.027895098018850532, 0.024623563588266412, 0.059931291973278414, 0.0660352239144906, 0.040276498053102724, 0.02408827880337354, 0.044627865971696955, 0.035537010839869904, 0.06633014478270086, 0.039479065641400315, 0.06779534156404196, 0.07976260021208756, 0.010187553087880295, 0.04019857925032416, 0.057818233786571416, 0.08290500094693515, 0.03222883250864764, 0.02646077458085793, 0.04926603039606445, 0.0498474145218009, 0.04056539363978852, 0.024461838597011183, 0.047069261781871326, 0.056160170539853074, 0.03651544684544206, 0.06965269875382224, 0.08264784055251269, 0.07446868750717371, 0.14834823807881725, 0.058759667745400826, 0.060083881366036596, 0.2751741552304837, 2.996434876995702, 10.109336453099406, 30.534839860854614, 60.42909783701743, 85.75710112048735, 89.16996325215986, 108.94604375285488, 109.34465854398667, 104.85720034568541, 99.35687634252734, 85.96861100965931, 82.0497239020563, 95.25344171831685, 86.15930880269697, 68.2233690446423, 67.77937243061682, 95.65893634673088, 97.44158298738542, 102.09022706554782, 91.2778606722432, 100.84318007192304, 95.85896938077866, 97.81525150422128, 98.46698468731296, 91.05707829998386, 99.58731559015091, 95.09521330556562, 98.72146021935248, 104.446575257086, 87.12961689118417, 96.20616974369173, 103.36679381708946, 75.86898634510656, 102.39366946681854, 88.29415290586411, 82.40216455151959, 91.01587772369386, 75.90969270275485, 97.97171485039496, 96.69514025411299, 107.57591278322282, 104.22889940200314, 108.30585018281015, 110.44898617652156, 113.09919834136964, 95.00899176443778, 61.70134998136952, 45.27765650903025, 25.927231619434973, 11.600124432194619, 0.27490770985041896, 0.17904030970267712, 0.2827712346709544, 0.04026866480407696, 0.012407708451181892, 0.02779539359072524, 0.10305601682874466, 0.026835272832202817, 0.0486942759955362, 0.0635893120160026, 0.009048855318988283, 0.02045027280767118, 0.018308082212423606, 0.031083663212015267, 0.05708458202500498, 0.03828738523166507, 0.05168132176021895, 0.0519557842504113, 0.08672892882098114, 0.04255659788125946, 0.022897031233315508, 0.04701671964158455, 0.08317828749216373, 0.032070644928382776, 0.07030407267232096, 0.04276508870985239, 0.02514334083835204, 0.056870046762689475, 0.02865206566639245, 0.07807441821862614, 0.008784549239452088, 0.05946052328292882, 0.07047156247520639, 0.051760094751033096, 0.05450012695585048, 0.06832740494921323, 0.01791069708434084, 0.05118548284254728, 0.03090847997115024, 0.03441680643347002, 0.024658091171013734, 0.04540695057761285, 0.07775269193394531, 0.05280899552388057, 0.024056752370069587, 0.01830044048537891, 0.0625914671728688, 0.08926279527405578, 0.07570463247717389, 0.08994383977786188, 0.012211426191272275, 0.058156335200633735, 0.05576985640331142, 0.03953410905875987, 0.050453121939133254, 0.043359094134141365, 0.05784999196147246, 0.04010247352022318, 0.015945540789905337, 0.016387712375651446, 0.026435876723318815, 0.039373157816308166, 0.002773758507476399, 0.011477561840306849, 0.039433831979911176, 0.04007000671399217, 0.042390686219498035, 0.04290634766221047, 0.0057871205893705695, 0.04407141417745621, 0.043649035430843794, 0.03637782298028469, 0.013273249909792458, 0.04067372613316102, 0.0444149509853413, 0.06767135789437641, 0.04514296817022466, 0.06517913598086565, 0.049375037046810316, 0.04052430451396973, 0.046820229580325466, 0.011813234755649202, 0.039736501827475526, 0.07484112881244191, 0.013321795943944205, 0.0373730554635967, 0.06814528286697404, 0.03481552455454104, 0.02581228881383375, 0.0691481838904081, 0.08716719240070352, 0.07278695597403473, 0.014654558148205042, 0.05481783893980807, 0.020403907251273914, 0.04843260717367934, 0.06767340334913424, 0.048423222596606905, 0.06329995677656224, 0.015181894770883506, 0.031065351795405153, 0.013036112180880964, 0.058653886324816176, 0.043459451652222106, 0.017432572034698342, 0.029005069405801838, 0.034896940548693946, 0.08311642589227808, 0.0158527014671915, 0.06157107636212342, 0.05090938858507622, 0.027905242938187816, 0.05019591174899571, 0.04209152505462689, 0.050095213321788665, 0.05460276741594557, 0.023659972451447, 0.039757412197368766, 0.005638028866791677, 0.03642446624355451, 0.22871369586115886, 0.07605884088984421, 0.1575976619196515, 0.05421856666103967, 0.05263972073613156, 1.0300532632297086, 8.352653941800519, 21.623683552588187, 50.65788930462253, 84.4047227982552, 107.40015137580134, 104.62324665438746, 120.96589611422633, 120.69594290948685, 120.12828965340893, 117.66730831515406, 99.36178714998307, 96.78939480935374, 114.5504988393476, 105.56310146085679, 79.8792411435035, 76.33425005020635, 120.48486448103382, 131.30287124264626, 128.92686413180445, 125.87600538807531, 131.3121045020319, 119.74796879676082, 126.08640132411834, 119.68827816747852, 120.42528367811634, 125.16267530379758, 121.3178974582303, 131.75206891952024, 125.21373671870079, 110.98602141103437, 126.8547857961347, 128.3478516917075, 97.84594797318982, 127.91601442521619, 124.76310345434375, 112.13276555461269, 114.97972380730414, 102.97378801530408, 113.71675199077977, 111.32718132388209, 115.96968297035464, 118.30365011768957, 118.95311617082166, 123.04789020169167, 129.7041210051506, 121.58841548427459, 91.56393481839089, 71.06637354820006, 46.83771256477603, 24.161515889629243, 2.7112513540252565, 0.10173133589447507, 0.3706611927238203, 0.1387921032766181, 0.015390058096888808, 0.028631976925798004, 0.030038870585661744, 0.03775711449223661, 0.01406037556608358, 0.0842857671781413, 0.04575869218716699, 0.03339283416167863, 0.018112643606840603, 0.06370044839117797, 0.026777977116345882, 0.06619162076423246, 0.042376368036193234, 0.06012899628389747, 0.07451593214946409, 0.05520334587462487, 0.04816583237580715, 0.03451706436012061, 0.0186239498397035, 0.04881052217716652, 0.03449163407147412, 0.009354876801221362, 0.0337048847558758, 0.04471289023997323, 0.02614306642733995, 0.06171962464108102, 0.016132997716927243, 0.0460814718427437, 0.12766769456286586, 0.06405862130885644, 0.008316300978373376, 0.0057933239863374305, 0.007157631297295373, 0.04155706381425262, 0.02791098285196049, 0.03923756791458976, 0.03552922738655921, 0.055980442482377255, 0.02872161112815863, 0.09209564286133937, 0.04362445933023288, 0.059922642840613285, 0.06920014763431204, 0.02831932495258028, 0.07419421352566251, 0.0405400131468571, 0.02119070253214769, 0.05170331997496467, 0.029068482333734155, 0.08719329301628374, 0.02424088543311002, 0.05257370693969631, 0.02747297782691256, 0.009328927488006171, 0.039576986999881845, 0.02474474720656872, 0.01872338039139586, 0.040522404615917516, 0.01598599118991725, 0.007293774697539067, 0.09873872833146204, 0.15029431591110845, 0.13361797607954473, 0.18702605619065224, 0.16051780522590683, 0.24217378408197435, 0.16927737712619767, 0.19101254792223055, 0.10071877450231584, 0.10623840735323968, 0.18627941157789002, 0.19591002544808775, 0.15514895380023988, 0.10005217841676167, 0.09944024270460491, 0.0927103671335405, 0.15347089948913745, 0.19012600033273622, 0.14000891137026972, 0.17582609588580747, 0.09449462421358594, 0.19034643447206867, 0.13031042210998076, 0.1529317880950628, 0.1471121552129907, 0.15435139498402997, 0.23952578584994041, 0.13774967211629116, 0.20008967858889412, 0.09219727974625365, 0.13743770579176565, 0.19736602151345825, 0.11010281531320465, 0.20781604302746637, 0.14307407512059137, 0.1370594575400314, 0.27625553430088107, 0.19719446378369487, 0.1750299926366537, 0.12362513285610946, 0.19495180267239773, 0.1767041398993423, 0.22575026858718167, 0.21847810235715684, 0.1069839564602702, 0.1622011608654453, 0.13349894133787002, 0.18248067267479437, 0.13281779724263376, 0.18480464635837465, 0.10297164756564364, 0.16761507358281844, 0.2176082708061703, 0.17109614646723195, 0.1118243987401647, 0.16455602321413257, 0.3064908183390095, 0.12289053114551692, 0.32543390508620973, 0.175670626002454, 0.2534881059921557, 0.5593890672729862, 5.5602102606527275, 19.355084665359993, 50.00387722446073, 89.45455474238243, 116.24377035325574, 118.16827343356226, 136.33628414523218, 133.8639985361407, 131.64064222766507, 122.93206261050318, 107.49510411293276, 103.79661498531219, 115.9524872995192, 106.46066527212821, 88.72102445171726, 91.0323202994562, 123.79055961485832, 124.09862256819203, 127.70328860129081, 117.39339351654054, 128.4140769896969, 120.41597197132727, 121.4963339221093, 121.83765072976391, 114.00295165277298, 125.28213500976564, 117.68695938971736, 126.47269987290906, 126.88596079426428, 111.38349087007585, 120.80886794674782, 130.39709398823402, 100.81800630015712, 130.36101602738904, 117.58224779559721, 110.08246421813966, 120.41133572978359, 102.0048527563772, 124.17352414900257, 121.11041192085513, 129.02755921886813, 132.60799284904235, 136.81336987403134, 141.2278876766082, 148.90062424444383, 132.4122351984824, 98.18377387139105, 72.69784419767319, 44.2793740764741, 21.243931439615068, 1.931863285360798, 0.3378120779750809, 0.5439930289022384, 0.23454377818251812, 0.1597754353837621, 0.0708178571996189, 0.230680059701685, 0.1368650703901245, 0.22760403282459707, 0.22250942555406403, 0.2488021913074678, 0.16720935341811952, 0.09434054094937541, 0.14957952523423781, 0.14068815556745376, 0.11950925653499943, 0.15273894844276292, 0.16434331124107684, 0.165576636190376, 0.1814940586806305, 0.14389645518554797, 0.1148997208163623, 0.17061885836864674, 0.13438213346225603, 0.1670103697406669, 0.1716408043378784, 0.23816175097900055, 0.2031723857526818, 0.1400232985014877, 0.14122596461205714, 0.09974163701577533, 0.15575915815368777, 0.24973896362127798, 0.18298727129736256, 0.15007469382497574, 0.13898563240804981, 0.1007740860504489, 0.19238243570491192, 0.08428841018148008, 0.134691970062352, 0.10520966618411964, 0.1469234064702065, 0.11092781539886229, 0.19769586833013644, 0.11307843870693639, 0.15226667055920248, 0.18934215449037092, 0.1271045433297273, 0.2511853989093535, 0.143421036341498, 0.06901677682875626, 0.18629874763709886, 0.16570844927862768, 0.1600367326529757, 0.07698402995423925, 0.22817423206663903, 0.17463652987874326, 0.11984791336280685, 0.07533218351102645, 0.09295055868044015, 0.26446930222934295, 0.17415888937971286, 0.17048790329887023, 0.07993453332493383], [0.05563549607271149, 0.07666574340433845, 0.01733895992079089, 0.09172479501895367, 0.03545968575523265, 0.05483328327236157, 0.04791989133903577, 0.016722529187738415, 0.046905736483994036, 0.05599520882711776, 0.04219671275707022, 0.08674382923110839, 0.054792086894233386, 0.012430958262073898, 0.029886566560655355, 0.015901747373713842, 0.030768979190578385, 0.013247889526669058, 0.041245557142481695, 0.03304722891639798, 0.030729062179283752, 0.01339273089768305, 0.04073490208435444, 0.03762828148601036, 0.07063933573062382, 0.06706531339835736, 0.059713328467501756, 0.039869310830028794, 0.10208849374565387, 0.031302088285766305, 0.04820476113367946, 0.026432320160130342, 0.061890676752814365, 0.026717657268407847, 0.05000535886914981, 0.014896896656512495, 0.0557466937349208, 0.08986705478521125, 0.01600732290816884, 0.025411569288060553, 0.005132169519070416, 0.06734642170129285, 0.01810733078708572, 0.07082602369689173, 0.027898074270436363, 0.021841718304541805, 0.026343346708604408, 0.03769060273865058, 0.08929210579803876, 0.07369617210520853, 0.02991075578686451, 0.03960955339754301, 0.047938537919112754, 0.025234779177774346, 0.04846349583878633, 0.24001517813772927, 0.08019691843899988, 0.018283969595006878, 0.1757647628865896, 0.3626643686044601, 12.047820821885141, 44.038132621395974, 68.8680576509045, 82.28172425300845, 94.3496334937311, 104.66780477954497, 92.02204412029636, 84.83925865542504, 77.56864347765523, 77.85632579557358, 82.6929533866144, 66.97834599402644, 90.6679948683708, 93.943864299405, 84.1213393980457, 78.3290655382218, 104.24598524647375, 109.61962453780636, 51.288614273071296, 40.76220043243901, 36.1480849789035, 32.273465741065245, 33.9120594147713, 42.27413685091081, 44.049770293697236, 43.429066981038744, 36.96245924119027, 39.274790594654704, 40.068372372658025, 33.59257451949581, 47.312036944973855, 39.31979194764168, 38.36413783411826, 40.41680043743503, 35.65926744091895, 35.7649007920296, 36.43027205621043, 35.6543174097615, 59.0883061962743, 45.99893331527711, 79.36996844507034, 101.74994576361873, 97.515119583376, 81.87029900089388, 88.39518531676262, 92.2032105538153, 78.33877732676845, 94.00961106823337, 101.93344208502002, 99.80761158850886, 101.29678649287071, 94.46440988971342, 67.32987665360974, 24.759459649362874, 3.6377286718737696, 0.17940170402007719, 0.35136763607302024, 0.04002540507504056, 0.07941539384304516, 0.05371285670046365, 0.03374454129727618, 0.05168188866528292, 0.08044063399035124, 0.057280122137237946, 0.016625416052017002, 0.06542986889760341, 0.04449800257721255, 0.06022961044143285, 0.07031036991505854, 0.03644585924884004, 0.005142418339082431, 0.034090878156524514, 0.0874543144938446, 0.014145521450817827, 0.022886177682648265, 0.02436302857653749, 0.04329427160442837, 0.062217309830650214, 0.07178123574703932, 0.04118095294782712, 0.05653631204979555, 0.015679891183671933, 0.05751382491941895, 0.050734889077683615, 0.025858003195495378, 0.04611318405236929, 0.036181850028374506, 0.06020763137888524, 0.03257119720200858, 0.0597134625328885, 0.05646178701652154, 0.048477679956704385, 0.06608932504370328, 0.03946927886816763, 0.13500445732666602, 0.03134353555768969, 0.022129271322140293, 0.010432142937075227, 0.02738421313434599, 0.007880419932095515, 0.04694854164676321, 0.04627955536688528, 0.05735191223662227, 0.003798930425076716, 0.03852412938290546, 0.05836904717368945, 0.0453456443914723, 0.02924494494143273, 0.011734049992575761, 0.11376844643945656, 0.07219644774112009, 0.043777056383870305, 0.04407260161373885, 0.030656737733572244, 0.028282941521836386, 0.0798304372977826, 0.08327754950451274, 0.04247863311320544, 0.012392964131469208, 0.03135411906236362, 0.05414214556015307, 0.021668660957666657, 0.08365389785819477, 0.04504826055058549, 0.1300434557901275, 0.019017832030752496, 0.10775510822573017, 0.06586336741043676, 0.04429401251517477, 0.04221814789719159, 0.03657650788344684, 0.03758000262502221, 0.14633350344675203, 0.026996231735533765, 0.06445739688652177, 0.09399107462095638, 0.04451775615434012, 0.04719846634074085, 0.04485904066372783, 0.06091800938931204, 0.04540777029169183, 0.017557049831075054, 0.037084006659326055, 0.05521779046243718, 0.02673307861832361, 0.05216072043103557, 0.1036101588678937, 0.05521753382298255, 0.0673901729826485, 0.027950917100233418, 0.0565909800840722, 0.021699486420519894, 0.040186754683212894, 0.11900943012968188, 0.023459663441885385, 0.029323183585919683, 0.07393021196607621, 0.05432317213666055, 0.037795399736252525, 0.13253881866412778, 0.0027790538508505112, 0.0851685302932897, 0.04534685481039267, 0.03116873344556699, 0.041434796181537455, 0.043612106162453854, 0.09284132986419624, 0.10323908886000996, 0.020710733125827486, 0.03488798115041948, 0.064179276326491, 0.16079802486685016, 0.09383724416576086, 0.023443470258385907, 0.05809945700269553, 2.7020992386725644, 24.949841691601662, 67.48680283946376, 91.62427656112179, 102.36027440717145, 108.03631274930893, 115.50073223729288, 101.68454416336553, 94.96834031997189, 91.6453318442068, 94.65073816237911, 100.44408675163024, 94.51088213151502, 120.05273695914977, 128.42247870660597, 111.86436560846145, 100.7378879670174, 113.87967940299743, 116.98224283033802, 67.806350492662, 71.45151892016011, 61.08606346191899, 47.41555613856162, 54.83654714399769, 57.69088729735344, 74.4858644854638, 61.25154433711883, 58.8192629814148, 59.36307999395556, 55.07698059082032, 52.747512402073035, 63.742104268843136, 54.00694231833182, 59.1751866955911, 68.68018396439092, 54.15777706330823, 59.08712164048226, 64.42093710745534, 58.506948178814305, 93.4329128265381, 77.0425045874811, 107.00043047628095, 129.07128580154912, 124.35381981634326, 104.65579448207733, 107.86502284388389, 108.34671343526533, 94.54710914242654, 103.92744956477996, 111.69351500849571, 109.3147308595719, 113.41659653571345, 114.02385004105108, 92.81303713398596, 46.2862116290677, 13.102817785355354, 1.520359340694643, 0.059619616762164145, 0.07190733381937589, 0.013013497265356203, 0.15636363216946203, 0.017986670023791732, 0.06112469608084329, 0.03413364501489747, 0.06330808496943886, 0.13390636221776087, 0.04189665526932767, 0.09502821977460578, 0.055187292502171574, 0.09978807726574522, 0.03430440984365921, 0.03823424171235773, 0.042711512350867835, 0.1033817574141487, 0.03509969337873402, 0.01879727914779177, 0.05621229516222112, 0.019863275172669562, 0.04685459245416907, 0.019417195580899715, 0.03376422592649057, 0.017725110369464083, 0.030656410230984612, 0.049328757675304535, 0.006293512847004158, 0.055208536120311874, 0.06785547180521874, 0.05564142942368504, 0.054185862367552136, 0.03712021580506717, 0.027009529106679465, 0.04733683331118477, 0.0587807466546374, 0.0710236207552014, 0.05711976844336718, 0.03028343074894961, 0.03324601341099028, 0.07575068202230238, 0.0796851487229428, 0.08102441597129069, 0.054406445894029834, 0.07136008657154537, 0.036249978227480766, 0.01866986531944525, 0.03836045852832256, 0.021810879435149894, 0.01910905011989657, 0.017445135876656543, 0.062260229906608025, 0.010919037778230925, 0.054668356033582846, 0.0334357465767572, 0.052667885958667726, 0.08767942176951517, 0.06954150109161293, 0.0025451935418400796, 0.0469946984442011, 0.20789366305595447, 0.16792438924312594, 0.13006053955083893, 0.21988395030700394, 0.15054501052345, 0.16278649800487105, 0.1802075825511448, 0.1284169898398461, 0.23846432506557436, 0.13279706690340273, 0.2070255628636768, 0.19483820715498543, 0.14038008096958363, 0.07870107814068757, 0.17401463502357084, 0.08363694433243045, 0.29248896805990127, 0.13225329769474845, 0.15395918861031532, 0.13198694424523463, 0.15100834050005482, 0.07690161421534515, 0.0747041599524598, 0.14644417250829359, 0.22757734232131513, 0.18719404395068848, 0.21539945545936787, 0.11015439601314646, 0.19576128181670943, 0.1007632612280788, 0.1685391901241195, 0.15763561391542036, 0.1556664921583668, 0.12728173946661334, 0.11222137784164761, 0.1523341475835731, 0.2129071569370647, 0.21540593656320728, 0.1734970200566515, 0.10257682117122797, 0.12977786842853795, 0.12283292133361103, 0.21522307137568153, 0.2642615085407611, 0.15995338228681397, 0.13301417622114384, 0.12341316398834029, 0.08907997605180548, 0.1831500190159967, 0.21230853583303191, 0.1258355569875529, 0.29116375852496396, 0.11802027272360942, 0.1793798551924767, 0.19141405460334596, 0.39309944837324085, 0.252652533893143, 0.14693454538862552, 0.3075161810603834, 1.640642989547022, 22.372826837724258, 66.4429424655053, 98.64331091603925, 113.32061613759687, 123.56883587375765, 128.4680252690469, 112.99517708439981, 104.61176979926326, 98.76013478925152, 100.1946004744499, 104.04069623639508, 90.88021078417378, 115.59417878427814, 118.59211690964239, 107.10602852606006, 98.3100506567186, 123.13528060913087, 123.90330422309138, 68.48631689625402, 57.25221333965179, 54.77356172377064, 44.91501377474877, 49.10072795806393, 60.59200563738423, 66.83054324119323, 63.8562491632277, 52.98113661427652, 54.7497647039352, 57.65297366726784, 50.572001164959325, 65.76353303847775, 57.337775922590694, 55.419701606996604, 60.68357336905695, 53.194462560838275, 53.623875802563084, 52.65676052339616, 51.29270530516102, 81.89541785947739, 65.20125735190608, 103.41609801015547, 127.92411019725185, 124.98088129105108, 106.88059422277637, 110.28707073580836, 112.90195803488456, 98.327677788273, 114.6900724595593, 125.2736548454531, 130.0880818213186, 131.00166459237377, 130.55641281989315, 97.808575630188, 44.481674240481475, 12.151291966438295, 0.8898568441790919, 0.47141615721967917, 0.1718455489965216, 0.140706556999395, 0.23646213895370885, 0.1920249177924087, 0.1812530167761349, 0.1568559968783971, 0.15645729407908457, 0.19148888607178965, 0.17640777112495515, 0.16560378634641248, 0.13182696976488636, 0.2039533051391763, 0.1394196212171547, 0.1374187987417944, 0.13084141297205804, 0.1864112093443832, 0.1194262815519206, 0.1297222351234767, 0.19063521897600544, 0.12264069455165057, 0.18437067287102823, 0.1644993633512528, 0.09163848755340423, 0.18140255713895445, 0.0820106469214924, 0.21945518621754265, 0.1214853420312847, 0.12531103190755652, 0.1758066985395647, 0.14569772707839168, 0.23935546918261438, 0.10485407881318562, 0.12085815350855551, 0.17215448161286695, 0.20178870838736335, 0.14206608727334008, 0.10522910183475864, 0.2286125875769123, 0.19211370738283282, 0.14121726185323732, 0.19757661908384294, 0.16821983871200394, 0.17385251549703462, 0.14324468290132863, 0.11020244504775732, 0.0837682671244106, 0.10647175773497551, 0.1194985313040595, 0.21996481854829097, 0.07433980853567201, 0.19864240060410193, 0.09060927907065039, 0.23511143401265147, 0.15266704343018994, 0.1402699175260721, 0.22342598846843167, 0.1833923479482051, 0.12937482957157398, 0.1631308698485936], [0.018714924695931615, 0.030339730550504984, 0.017983996376935995, 0.13119709227354298, 0.07729699985394556, 0.023889831387467926, 0.054163584530714064, 0.016645125579088926, 0.03417381483520712, 0.03595912528614845, 0.01810540024551653, 0.05049299681559206, 0.02241710779227076, 0.047750727634035775, 0.04530399219102917, 0.03165426273499766, 0.03729119130800809, 0.09925063594334549, 0.024003369448285912, 0.0875437475981251, 0.0339463365174109, 0.011279511832511954, 0.00746918106151204, 0.07702136907966868, 0.010445969866498584, 0.011932119152568763, 0.028507640855687282, 0.05211568212196712, 0.08866680951248254, 0.07321115417946732, 0.05182585190801371, 0.03984763054177165, 0.029842811448860074, 0.04491512979110403, 0.024924220539809718, 0.10583261057974831, 0.04247514741314996, 0.029261463712300026, 0.055979749172805786, 0.12367404757007477, 0.03417004185218004, 0.043637704990443685, 0.018116979664492033, 0.022106549154306133, 0.018309363494476965, 0.07718980883158023, 0.06628503752571922, 0.026124532845231797, 0.033425293307030396, 0.061707060799122825, 0.024486119753771254, 0.07704117245251134, 0.06055486456100499, 0.06405816165610187, 0.03459636212116288, 0.17863566206107218, 0.29014921296508084, 4.105091580460149, 23.548727919978482, 59.71903900946341, 86.11018503865888, 87.50999266101469, 86.34013791238108, 83.76108538719916, 81.08391084978658, 59.1611602998549, 75.57199232039913, 85.97443180699503, 93.59744841052641, 67.51119998193556, 59.40738316505187, 50.79448192350326, 45.84605109307074, 42.97009083532518, 38.278210470753336, 39.63712346169257, 24.855161559197214, 94.43846733339372, 133.51449966430664, 38.0012519128861, 35.38842778052054, 63.88907155682964, 52.06865995160995, 42.86289245851579, 32.79981055567342, 40.027991571734034, 45.81294236644622, 36.37713178511589, 48.82123554906538, 41.88091139639578, 30.174780007331606, 47.22981622142177, 46.813040856392156, 35.64682568273237, 41.99400509557417, 41.8392675922763, 40.73159025561425, 39.75879930680798, 25.764264983515588, 26.40721597979146, 28.816578926578647, 40.32918645489601, 43.706186356083045, 47.4576117915492, 75.76023470970893, 71.28058202805059, 90.28110011931389, 85.16785129424065, 85.32753882869598, 86.41041894112864, 84.33878775565856, 81.69982494846468, 83.68382253954488, 100.53173603550081, 71.62361683384066, 47.648184068741344, 14.410829197975898, 0.6431368185627846, 0.34913620581069305, 0.10723301164445379, 0.10243999020707223, 0.051287452975708636, 0.02739248688392822, 0.07142675920359551, 0.0792332257955305, 0.09870096785767425, 0.04225772782979954, 0.005212015511783501, 0.10037449458914419, 0.020706128937402563, 0.03485012874608079, 0.040310841774748224, 0.06046026802411484, 0.008964326135033082, 0.03458175665488647, 0.042210847079273195, 0.01872170648928131, 0.02565577513568344, 0.10161973220566589, 0.020779686784672163, 0.017160235438495874, 0.037269825115799904, 0.060190647209603945, 0.02956028396804487, 0.07702598092897285, 0.052957896203283346, 0.03634262890104325, 0.07935727841310924, 0.04306081397038314, 0.04736162391641448, 0.03425147699853105, 0.023855037589166916, 0.05472336497698581, 0.046438851859420545, 0.11582131692839247, 0.01865027453600159, 0.010106122729578807, 0.05143752576963556, 0.02333692274987698, 0.07934253122056685, 0.01534315340611483, 0.06976295412788469, 0.0038847272451441256, 0.10804539426199852, 0.010640718035339829, 0.07271426189089976, 0.0019690949439762104, 0.0178102859401054, 0.015603674053695175, 0.030422762990178123, 0.04336034668789756, 0.012481096801498245, 0.05149524666429047, 0.04284349014802326, 0.03687704800658169, 0.016902144247245406, 0.02260972144863298, 0.03682779238349007, 0.03293059969080552, 0.03272847505286336, 0.049408561054376826, 0.054251565898378054, 0.05870238735130238, 0.045483789196418184, 0.031289196941220475, 0.01646712888032198, 0.027574003756707235, 0.04140997876323039, 0.022887388101568627, 0.019437763126446836, 0.031208619813344655, 0.022617794100135084, 0.022467734712746837, 0.010345117264096777, 0.02467742339978295, 0.02214109397403175, 0.08769750144452819, 0.11027225097941776, 0.028151306549027085, 0.02146944362339714, 0.04882064985952551, 0.04842886100372961, 0.03276780983733554, 0.020546196591890147, 0.048028461319664796, 0.04925515194753966, 0.033583467480756586, 0.07461495667455659, 0.02972089430137027, 0.022386828167063576, 0.02653715163168888, 0.018981722476441535, 0.03381871776054463, 0.03149140776405412, 0.05420716727272638, 0.027074640834583875, 0.05038322790736153, 0.06586014218027554, 0.04470420280291189, 0.02451837014016365, 0.05463926001421867, 0.08230201314173399, 0.04838341283762167, 0.0168796997862838, 0.10663770770113315, 0.07455051335836611, 0.04997954553654117, 0.09657613873001068, 0.08415118085160371, 0.053870287768903284, 0.021425945151056495, 0.06903310982330192, 0.8963275905097685, 10.111481989583663, 40.42485306339879, 87.56114821280204, 101.81438246080953, 99.56382843755908, 99.54135325647171, 104.45498481873544, 92.21755858390563, 80.51334719504081, 99.7333925001083, 122.46710485027684, 127.53941982023179, 90.11386594464703, 88.88587382531936, 75.70295241571243, 66.77202147822227, 60.586988925933845, 56.11469068834859, 51.88996461129958, 42.80031104241648, 112.93614541330646, 140.15367600225633, 45.02591879137101, 41.89000737282538, 63.81386010877548, 57.92251110076905, 56.32304306953185, 47.5522272048458, 54.04999817571333, 55.084476240219615, 47.44873546784925, 55.177950243796076, 50.181776323626124, 43.29479248292985, 51.55494713014173, 43.45458199900966, 43.235305816896506, 45.91595949665193, 43.64021601215486, 38.02122462180353, 41.75523081133443, 26.509187798346243, 36.856810200598936, 50.81889083308559, 62.96017193025159, 69.15723046948834, 76.35555636498236, 105.93380466584237, 104.60471737769343, 123.88388849073841, 116.67916128712316, 111.27571198248096, 104.54949825040757, 99.53767407325007, 92.01481126969861, 93.17623292246174, 111.88207903215962, 95.91871492324337, 71.1095666885376, 31.240980240606497, 4.236623116077916, 0.14166192992800666, 0.16996081948520678, 0.04897039323564499, 0.08817810670382555, 0.03511213081618471, 0.1549256544920706, 0.017339107392716314, 0.04874731226253414, 0.00987992665144585, 0.053527233596410484, 0.049658309548131885, 0.02536745411494086, 0.06318961713282813, 0.008423446035463243, 0.0805221687281324, 0.014795689738445706, 0.0933838580104132, 0.05774067121467764, 0.0068603733821111105, 0.02645605739446417, 0.04907586822105993, 0.058997974716006756, 0.014284524274238897, 0.059887655605111396, 0.052772449299452774, 0.04404573107979471, 0.01630280493578363, 0.016583066711562778, 0.028711630917725064, 0.03837370418853337, 0.1033359759997937, 0.035011742654586994, 0.030555292370639024, 0.07046600833775536, 0.08066506710864844, 0.056477330940505194, 0.1355531141762772, 0.026764172211950345, 0.016647042714119438, 0.10255434415152959, 0.031814721765958016, 0.08018854509798751, 0.07178934095727821, 0.07753072561876428, 0.09035736637850923, 0.08048580253436681, 0.011248458458501245, 0.03861197668518271, 0.024415383025282816, 0.03343717150029636, 0.030324571585703283, 0.03253980674931119, 0.09135618415330687, 0.05572042841043684, 0.09407340609017881, 0.016754122653735742, 0.04425740500371303, 0.01807851055937429, 0.12313589378590546, 0.1766472961753607, 0.11532391136091565, 0.17699704595631172, 0.13682017763776166, 0.09188593395294682, 0.11653835224288127, 0.19624305919053095, 0.19335107727637216, 0.21283529788976718, 0.13916777747292675, 0.11412918192124176, 0.12626585325286274, 0.08354413278040387, 0.07552781172337071, 0.13547354828446143, 0.1396703771165302, 0.15354038366386968, 0.12665301110715638, 0.1333265868766654, 0.1431506685912609, 0.2226309270988549, 0.0938869709329259, 0.15638895903623876, 0.11534990472418648, 0.1558135197527947, 0.09503981834577938, 0.17889102980975183, 0.3581090565891035, 0.2822628587244019, 0.07622853702595157, 0.22477459432857655, 0.10909702613829605, 0.11278523387567652, 0.0639785421381314, 0.13580580061722186, 0.17243470125381025, 0.19692982637113143, 0.21942153963590824, 0.1915476296938235, 0.21836361817775235, 0.1420824509114027, 0.10691759026338978, 0.12547205592836105, 0.10521492920815946, 0.18402334392791797, 0.32101538573061267, 0.12069325308285414, 0.13760319610516872, 0.1625128054330426, 0.14776976508719308, 0.3073033005479844, 0.17408434902468037, 0.14123310455151145, 0.09017902877061598, 0.3483274008237547, 0.6472924471862855, 7.899112730256974, 38.53656914926345, 89.61539545366841, 114.97399714685257, 111.99241530510687, 109.36438022121307, 106.20863729907622, 99.96865626304381, 81.66118960226737, 96.7315241598314, 106.05420574065178, 116.44538802485313, 86.57923775334513, 79.19650554656982, 68.97475396433185, 62.09585020619055, 54.25633053625784, 51.882061035402366, 50.966893626797585, 32.87775197336751, 103.12137111540764, 146.1114111254292, 55.41985065706315, 50.22004296702724, 83.87382999543222, 72.1792362582299, 58.790053090741566, 47.23103607854536, 56.47120275805074, 62.99670096366637, 51.05016162318569, 68.31579577538275, 61.473864278485706, 47.49957330765263, 71.15506618253647, 63.46482407662177, 53.70703005021619, 57.97398436454035, 60.40486151172269, 54.786713430958415, 58.97538508138349, 38.71966538890716, 37.898258316901426, 47.424365781968646, 60.04204227078346, 60.919962852231926, 68.516158288525, 97.87476170447566, 95.03179642461961, 114.30368761862479, 108.28841916976437, 109.9984392043083, 109.73859002513271, 106.51601775999993, 104.50572459928452, 107.87010623562722, 130.90782580837129, 106.21121037390925, 75.58259840934508, 26.231062335352746, 2.364866108663621, 0.48797790561952903, 0.19041844673695105, 0.22258352157810044, 0.1637275144457817, 0.23274481987520573, 0.3156110031470176, 0.22510658619144272, 0.1705388328240764, 0.12769525074550223, 0.1650923766916798, 0.21743715740740302, 0.10778710005744811, 0.12009283933307856, 0.11948651138452754, 0.15692195704867765, 0.21679254038439644, 0.1215497547039582, 0.12789771246213105, 0.17111425678576195, 0.11294317822302542, 0.18269165328914122, 0.216842535282335, 0.13808201637960252, 0.22092348565497708, 0.17161532425351683, 0.10136599622426495, 0.11342614303312956, 0.1886723638181725, 0.15433555228575585, 0.12463140466641034, 0.18462078525654732, 0.13992326274033517, 0.15897626778291118, 0.17532444619123014, 0.15440460745125048, 0.13343822120899154, 0.1771386649699942, 0.13404801187496032, 0.1647825554133423, 0.20970664077228118, 0.11799445556056117, 0.14795281413582065, 0.07712078430960256, 0.17051364385312603, 0.12287700203277412, 0.30280519997881306, 0.06416405415943553, 0.16011724849381756, 0.08010350933839237, 0.08044894604432969, 0.12714984210869, 0.15638002645104163, 0.13390011094029874, 0.17805668345141798, 0.22741392044530762, 0.09454281880490242, 0.1249754164488085, 0.10784764398610401], [0.043924332956873605, 0.07372232634694346, 0.05222709811923485, 0.08178236038093606, 0.06000207849748193, 0.025420898323758476, 0.032292888950436346, 0.012437126227474261, 0.09854741319413148, 0.07774916792949361, 0.05824759159417403, 0.039684361883349, 0.07518534743857962, 0.04959762772364963, 0.06387401327130295, 0.02803960326878775, 0.06031995519034325, 0.04879564858011661, 0.05933978782606222, 0.06690975158445298, 0.032155307220114816, 0.061259799516729774, 0.02729240898793984, 0.012308628384714887, 0.02314212574293056, 0.039994677288397666, 0.08875173035888903, 0.06885456537166912, 0.03781703405923421, 0.01366267346912214, 0.033921457812069886, 0.041485181784317385, 0.0360605591577628, 0.021926390172372905, 0.013312861443527285, 0.025014050094591036, 0.04615577088008004, 0.039179322249706716, 0.04314909794277722, 0.04824496159750608, 0.04514913517801512, 0.11392448322787402, 0.025539904337136016, 0.03131057270952771, 0.03312601722897061, 0.005796374931495878, 0.039232331703627304, 0.0442125314035483, 0.02329529544729139, 0.05432329088028881, 0.025256618429275773, 0.16837552309997622, 0.06968927179132739, 0.07823058524199071, 0.8610418258655457, 10.005460323825961, 43.621984835593935, 62.83685261203397, 83.3748495963312, 84.87190061999907, 88.43451884485061, 85.73341000464656, 77.45618912481493, 74.06642975345736, 83.37182937129852, 81.08629565085135, 54.30898051108084, 37.042385378191554, 34.969063651177194, 38.37097844769878, 18.762441988914244, 35.36941997466549, 38.80176059661373, 43.64456199830578, 35.53395948102398, 55.14015036244547, 27.94378684413049, 20.578460154994843, 66.26984826980099, 74.17664051055908, 64.34891454635128, 48.273523622943515, 46.1392011950093, 39.35283399397327, 50.76357364654542, 45.13979696458386, 52.04042280873945, 46.87416707315753, 47.366906981314386, 53.71668300321026, 39.626325176608184, 46.28872586834816, 61.22457019744381, 58.450364066708474, 47.82910731530959, 62.60816274150726, 74.9570039010817, 76.99540476645194, 97.93106340592908, 71.31953116386168, 31.660248271880615, 28.294068228813913, 30.08334759742983, 22.488356328779652, 9.292376368276535, 21.680267664694018, 29.727229725930002, 34.06982106547202, 56.86546371829126, 67.42951270072692, 70.1496450362667, 79.65646620719664, 86.77719977594192, 79.92408167931342, 86.9487093340966, 90.21811469908684, 84.22731399536133, 57.93023817000851, 13.042857493123702, 1.1641794467164626, 0.3367289215806992, 0.26588895508358557, 0.026593100948018894, 0.05402294610957465, 0.03318637729652467, 0.03547407671689026, 0.026620406236860062, 0.036021178408015164, 0.07707117245562616, 0.06170556692767048, 0.08291181146858201, 0.0742994127194247, 0.02892466464770898, 0.05543767301846416, 0.06574594145340305, 0.06037918144776937, 0.021866664042576187, 0.03517282796242545, 0.05476488311204219, 0.03844534873121208, 0.07804637173971823, 0.04934704802449673, 0.024462650650210922, 0.07993443373350367, 0.01654331057873224, 0.08101118563283836, 0.029642481371880542, 0.01172407361258182, 0.014862503139151922, 0.10034559009176108, 0.03502552074590518, 0.06007496793303759, 0.07454047760655803, 0.007894722314836879, 0.03520244875201776, 0.05993472021673957, 0.050107700554954435, 0.02622700093554393, 0.01215273140734362, 0.05791333211105197, 0.021508565818470333, 0.053071503212014516, 0.06769747383171512, 0.044986410442018704, 0.08317363733846335, 0.019984876308890603, 0.06870032888987372, 0.014316731568185553, 0.11462914622238568, 0.059667202313580824, 0.05869159317244926, 0.08649419182010236, 0.01882195483983284, 0.09714859793142927, 0.04762066888713068, 0.015834664884624223, 0.011959924313780523, 0.026129403249210408, 0.059092812570593053, 0.045816918699851925, 0.02224847077271871, 0.0575312304370586, 0.04718216782015178, 0.026520121497132128, 0.08567479949805044, 0.028344259199295795, 0.03807914338164753, 0.029212531761356422, 0.0627691153016302, 0.08714855348150577, 0.005381708296256201, 0.024135592393577102, 0.07718830729924864, 0.020962174673895204, 0.02014299111080266, 0.02067443204953546, 0.02352769204956149, 0.02251034452309532, 0.04738939843410927, 0.040897251437267954, 0.0030037603667756965, 0.06261731880987365, 0.02117775947666697, 0.037298817713294304, 0.026577484245682438, 0.026783502525499752, 0.06471194492112245, 0.03903738913997527, 0.07114999461919069, 0.0449817909318353, 0.004824754714425053, 0.08759322155627512, 0.04700284578927583, 0.06011529480137172, 0.07758861122232291, 0.01903240493829212, 0.038163757792884306, 0.050705475131830866, 0.03049563518875549, 0.09608708352090851, 0.14989328420450612, 0.03459764914887567, 0.01631298815951713, 0.0683161051523301, 0.04635817130967494, 0.038244323429441264, 0.07373267619480049, 0.15069496457374867, 0.1440950864625554, 0.17680989067640998, 2.932062408616466, 21.434034993571622, 68.08615669127434, 86.8109086252028, 98.29168611957182, 90.81256558818203, 97.22360903216948, 108.06951169044741, 104.74535003785165, 102.4679042446998, 124.98044198559178, 103.10191615935295, 75.0640453830842, 62.63199114030408, 59.19239021116688, 47.87931757588541, 24.42947849150627, 27.526562367716146, 28.584982579754247, 21.289403477022727, 28.48155752305062, 32.83730449215059, 16.211098067222103, 16.352632872519955, 57.91499191714872, 33.62027822002288, 40.15490378102949, 32.17344726285627, 23.789128026654645, 25.908604283486646, 30.89791797822522, 32.38477280063014, 35.29984497254895, 36.07876885321833, 37.2703613773469, 36.95660706489317, 20.538730467519454, 31.0361756432441, 39.54846220631754, 35.154940851273075, 28.79552560467874, 38.10545752125402, 29.524062718114546, 40.98747391854563, 66.33950956406133, 29.3274127283404, 28.53793767190749, 25.552547208724487, 27.836761051608672, 21.329329283006732, 19.367149876010036, 33.22232238708004, 40.89438822961623, 50.81546268155498, 76.20118756448069, 93.28304690699424, 94.01507100751324, 110.82722817697834, 114.16554174115582, 98.65589387955205, 96.32414679373466, 101.96826488740983, 100.94793088974492, 85.2364064801124, 30.78389075494582, 6.129799696706957, 0.39753025577914336, 0.2965386620452327, 0.023426269669266, 0.049616446673509576, 0.02869625936352438, 0.04953949697195523, 0.07213327613088392, 0.011612611650038632, 0.07244248453888201, 0.02632144617006904, 0.05347187225256236, 0.12779662716052226, 0.10074371066425117, 0.03690820863290179, 0.03184969367970142, 0.0346991864423598, 0.03867381530243062, 0.02812089094321334, 0.03542541864237959, 0.05385796524464123, 0.09700451977550985, 0.006649673347466536, 0.0487163623103932, 0.05095912301312051, 0.025386855291623264, 0.04650513378662929, 0.019992749777532393, 0.08080919122984333, 0.04738009812670851, 0.059133346282666734, 0.012314568438957776, 0.0491863610823789, 0.06643519075887819, 0.019185164785613457, 0.027071065119197293, 0.12296776813004287, 0.0383832304918718, 0.04963017113867307, 0.013342037902123505, 0.06341058753370758, 0.022914070943971316, 0.04226450004705018, 0.04402739859576668, 0.03019738949895386, 0.05717529449611903, 0.09735728028200327, 0.058995580691243374, 0.09567450686928727, 0.03176252245001736, 0.05091435283482556, 0.04358708573084685, 0.0767540580202495, 0.006783268068947139, 0.03731839509019929, 0.0318983345172338, 0.021970210401641748, 0.1358210917321905, 0.14125951926314062, 0.09833314606258947, 0.18041949779275926, 0.23616288968872642, 0.11194883440170558, 0.18858982550521053, 0.10164688236170238, 0.25686725853912296, 0.1529011139345746, 0.11331107662690264, 0.1078599396972887, 0.1221400254496163, 0.20439564430665588, 0.18340515693829906, 0.1552357055967854, 0.13340256747699555, 0.09587907532770788, 0.25778861716389656, 0.1285340021094007, 0.13944024430407634, 0.26127777993679047, 0.09111976175899468, 0.17636672413397222, 0.1031749902833854, 0.19303272177855815, 0.13374104044370114, 0.21034436300396922, 0.14467996394922658, 0.08146915299397323, 0.1784527049429955, 0.17459925204034776, 0.16070653864693257, 0.07743417555766721, 0.12310461441595709, 0.2009056848023207, 0.1717535724803325, 0.10550012075973135, 0.18789728202166098, 0.12836273549304855, 0.12150280883595829, 0.222350278448674, 0.06177497449361029, 0.1335264438943517, 0.2656084136857141, 0.2037610477136989, 0.10511791949430782, 0.20554066996180242, 0.1981490553026238, 0.2230466983371204, 0.13730930945565625, 0.2627761559861322, 0.214407003875221, 0.1562541122398069, 1.7212223237560642, 17.0619454691487, 66.20901230842837, 93.84309860967821, 111.74005000822007, 105.85146627118512, 106.43170249077582, 105.50056319082938, 99.51165306952693, 92.41447725603658, 105.47968833677231, 100.40541218173121, 71.24951685628584, 48.972580202164195, 46.85539460951283, 53.52429074625815, 28.349312851505896, 49.49342781497587, 53.943635263750636, 59.206287168687396, 51.37076047159011, 70.1318923888668, 38.294115681802076, 26.440305094565115, 76.16933791868149, 91.15232129250803, 86.27748981598886, 62.90624326275241, 65.86741309012136, 53.7595937328954, 67.86017325616652, 62.6430247675988, 69.48619965584048, 66.0496150293658, 65.20382258199876, 72.12405635464576, 54.86356050737443, 66.0234292860954, 81.29437738849272, 76.870006592043, 67.45964434839064, 80.17997710935532, 94.53734244069746, 93.22768657438218, 122.58885522042553, 90.48441225482573, 47.16148853302003, 43.087730561533284, 43.4108240373673, 36.006444269610995, 20.51484911672531, 35.87571559413787, 42.76342115094585, 52.027023992230816, 74.66524231818416, 91.02689958387806, 93.11323965749433, 104.40671613139492, 108.60970051057878, 100.39177017827188, 103.98891310538016, 113.12821603590443, 116.59530101283904, 90.13603518086096, 29.422991083514308, 3.1294716221670953, 0.529828614765598, 0.42679564186161567, 0.18927830872276138, 0.1586761298559366, 0.11776415420876396, 0.10917150520629461, 0.19465972399038656, 0.09984204816001077, 0.10502474022007759, 0.19375915699187787, 0.23134974312157403, 0.22907178067872602, 0.193044075201596, 0.14706934621978193, 0.1327772865131978, 0.10679216634842659, 0.07114126121685391, 0.17200347036123279, 0.14560668518947018, 0.11941777797596109, 0.16977223928176588, 0.12472956351214841, 0.18364262887306754, 0.23040670420854326, 0.14506283937202347, 0.14903710434033027, 0.13599297121888207, 0.12270582734697288, 0.1256416601339175, 0.18066651518306426, 0.12604774035994085, 0.13416785866983477, 0.21445359734277572, 0.074746003674884, 0.07753161428075644, 0.2508577431041387, 0.09078272903758673, 0.1865751981254547, 0.08311556787380288, 0.2678871575382448, 0.08318496777886346, 0.15256780440047865, 0.14414028565008796, 0.17444520708053343, 0.18719703169359317, 0.18415622953926364, 0.17233728551335875, 0.26278700379114, 0.22711575902517767, 0.1302032770528909, 0.22186485449633292, 0.1800406519924441, 0.09846413177588294, 0.19251372785337512, 0.08185985783535628, 0.17468773519560216], [0.02985153910553744, 0.013849886205618181, 0.02845126444533948, 0.025064625304132223, 0.16704643716014203, 0.08246438547728524, 0.03589101240880067, 0.053986510967895876, 0.03600827748737028, 0.024289899738505486, 0.15096594519432516, 0.05002708129224278, 0.027389140994918924, 0.013988983832419881, 0.10037187456844315, 0.06808237172663212, 0.03025802727338047, 0.04528789285330042, 0.020818198024625742, 0.049603453822313785, 0.07750012806706852, 0.04299871105280134, 0.08645761878259721, 0.019998807617793643, 0.05301780044852246, 0.03800479454859611, 0.022015796463576057, 0.05488439665866956, 0.0186993692806291, 0.039757684158581885, 0.04215225667482422, 0.03625820218134792, 0.016741777146835963, 0.02320581829295524, 0.025175445668038823, 0.04367988579155457, 0.051288870238368554, 0.008469181484542787, 0.03917598210635685, 0.06026146054688481, 0.037777611174650734, 0.024229706295074958, 0.020146750687291066, 0.05539825013388069, 0.01680284010006055, 0.0675732986400685, 0.08337372418252692, 0.0033969473330334073, 0.1003988025589816, 0.04626915572331317, 0.09302090087364759, 0.12246686920163133, 0.822445642082922, 23.110514840772076, 54.009382032579, 72.32983173862581, 82.55873772405809, 81.14515473765712, 81.71398470478674, 85.86207159103887, 84.86980607432704, 73.89514769277265, 49.565724941991995, 48.25824991349251, 23.065032997438987, 26.786277755614254, 36.75078461247106, 27.605454960177024, 40.17051873668548, 44.518583743802964, 74.3917432908089, 70.60242775947818, 59.983720548691295, 75.52435121228619, 108.81917076726114, 103.15770795268398, 94.04357879392563, 63.09955727669501, 45.68809724623158, 75.41739602242747, 53.58988846501997, 69.37300005266744, 79.83709135363179, 83.54992066660236, 91.21036452631797, 71.61548183810326, 70.82724232827464, 72.42343518041795, 69.35192908010175, 74.88814277033653, 77.4432139242849, 71.46956966769311, 58.70853447145032, 61.690335965925655, 80.77878182934177, 78.32791236139114, 109.50206325900172, 110.82004239482265, 106.79951098657425, 100.76517981867637, 73.1206129443261, 71.14170658972957, 67.18970683313185, 80.38185365738408, 56.262399304297666, 67.29979207438808, 49.80475418029293, 38.001361739250925, 24.775035381317142, 25.58805642589446, 27.596719841803274, 36.85393118089245, 37.84311371464884, 58.181728778346894, 64.68740332511165, 73.64487694155785, 82.65053687557098, 78.89745619989212, 79.09286083713656, 59.75092787896434, 23.75176941194842, 1.60466002360467, 0.04847190365375531, 0.2924255053362539, 0.06188493492382188, 0.06691162083898822, 0.03882391873987452, 0.005798299727405632, 0.04100616232702329, 0.08885155927630202, 0.06888605924623628, 0.060122005731588414, 0.06261716559228879, 0.008705353942669688, 0.035016193625427065, 0.05479870206345955, 0.04177608835180441, 0.03336791715194141, 0.10570370862560888, 0.04583654204203237, 0.07308791361508832, 0.019818621822783065, 0.019524769647227182, 0.055737347462244576, 0.03956135880622653, 0.03725497067094811, 0.04127155433619215, 0.02906164308379014, 0.12523665243098814, 0.05800000729880506, 0.07813090188128334, 0.07380989785756796, 0.047706700561027375, 0.06143105464176305, 0.09285433037627129, 0.016435004898437088, 0.03616657806560397, 0.03985342599691884, 0.08270921185612679, 0.021053921363707033, 0.03459231334648306, 0.04933700844224903, 0.019128070167836644, 0.04961716296571878, 0.05090345140366305, 0.012918392237606309, 0.020307881960404978, 0.040774049177285165, 0.017404747721288475, 0.028249279618443503, 0.09351550255932155, 0.020780814849140666, 0.038327382682191755, 0.06822070422311945, 0.039909250823961157, 0.032150101652669336, 0.05532129660188671, 0.026633533153442607, 0.04271663747908127, 0.03311070313136424, 0.04884020808423239, 0.05177445889961335, 0.06696143953670418, 0.10363607562237209, 0.06599652115255594, 0.08671664077067569, 0.02279698972650353, 0.0629139940194305, 0.10970125500593456, 0.03104128705848369, 0.07938318750670842, 0.03049805985703584, 0.04311636683621234, 0.04515061372770898, 0.0187342684160197, 0.044721455102966684, 0.05730984251826041, 0.018607844756315314, 0.050903742517074274, 0.022361288710887876, 0.06383631791498873, 0.04509164027929787, 0.021103065904049624, 0.14721237483524507, 0.0372936083154092, 0.1386007498348913, 0.030498925536390276, 0.042344908635582656, 0.008706528930023553, 0.036951822018431085, 0.05851474943600836, 0.022504928281470653, 0.034902406586033684, 0.013420921018076761, 0.007411309822101988, 0.14276790042077342, 0.04434239862847232, 0.07024526010237395, 0.043184755505212856, 0.06530336479866697, 0.02280288477308087, 0.1341381344583727, 0.04807006372439285, 0.02898671968479551, 0.18082273583258354, 0.09890756644909421, 0.20395592515987737, 0.1683316722271904, 4.826117109867835, 41.32665303445632, 77.82417020490094, 88.26202869415285, 93.95198360566171, 94.31546180478989, 104.79850599842688, 115.24414647010066, 112.29271981023975, 105.56176001025786, 77.45867590750419, 63.387827950139204, 32.42665586933013, 25.135862058208836, 33.13475939535326, 14.849597292561686, 24.324219726747085, 28.033679723739628, 36.69839743644961, 33.96200687654557, 34.32779927407542, 49.996110931519546, 70.96598440600981, 73.30086154322471, 60.8959932481089, 38.21899444826188, 23.78682951773367, 42.756859025647564, 26.281047059643655, 27.98044335457587, 40.19432360126127, 38.948767108301965, 25.207770870577907, 31.61199527402078, 22.038880163623443, 24.290787404583348, 24.33860698053914, 24.985415627879483, 29.964468402247277, 40.89609053827102, 33.296306133270264, 35.46469826852122, 52.03031878317557, 54.93353951361872, 79.22990060621693, 79.92774517305436, 93.42698220283755, 72.42643971596995, 37.26058683087749, 44.81282034227925, 38.00631961514873, 49.2291973483178, 22.596856932486258, 34.914934942799235, 28.8310230547382, 21.82145534023162, 25.461599211538992, 34.14791153323266, 48.75048775826731, 54.91611634531329, 59.39560036505423, 86.41820092355051, 91.57321514621859, 93.24859280740061, 97.37466735224571, 89.36921965691351, 95.13301710928641, 83.54733974702897, 44.888741739334606, 6.345402088857467, 0.02659960694971585, 0.2708208759225184, 0.05861942385954242, 0.01989842137141574, 0.049754511039223404, 0.14853425954859104, 0.10005207116445226, 0.06605754005572488, 0.046613562040992325, 0.009402184645765492, 0.02907885899466853, 0.030619377540724895, 0.009893873282107375, 0.018696810546962005, 0.05747855423138507, 0.04999321637554996, 0.0952762254183331, 0.027337179166234793, 0.07389456589495944, 0.05920125614671458, 0.081089832219145, 0.018603583392236504, 0.04799579533057348, 0.03909393025922679, 0.03736184376682486, 0.0447969837114215, 0.008872841830335317, 0.037889712820610696, 0.0318332955676822, 0.009835808605496443, 0.058348879909082774, 0.04632650123488519, 0.11703198865777063, 0.03373170932454448, 0.034594887401908636, 0.08718326492535491, 0.058584176154146274, 0.03842455710494711, 0.001558915788454244, 0.037689089715000124, 0.029884193603309895, 0.013162066611731726, 0.0508125780540849, 0.025139175235263767, 0.02981515567479355, 0.10806515933044496, 0.026083849746012883, 0.07611817439957973, 0.06360894301906228, 0.024119052555291884, 0.072831641882658, 0.04356911713858286, 0.055356475359369675, 0.037028882802734454, 0.16235542032987843, 0.11658614846847712, 0.11271790240801151, 0.16389093632178922, 0.26176225394010544, 0.19177869713354498, 0.1399584568195766, 0.1471063329447662, 0.2543259457114243, 0.2653301705516154, 0.22340389449269543, 0.13460416106447098, 0.28215355329936553, 0.2096731933735071, 0.18684689886868003, 0.24403877916835973, 0.11548897266508111, 0.16882884796828995, 0.1870818886785738, 0.11355645458904967, 0.17080419035928865, 0.1802199165667257, 0.24876407077235563, 0.08709985327215926, 0.16989905747675127, 0.11857192497700454, 0.2129401446830842, 0.20175326915998615, 0.04419415295424481, 0.26368035424140196, 0.10992696749106531, 0.12066868464312247, 0.08714158208139482, 0.1917993048987081, 0.18809946794663707, 0.15318710987846698, 0.14417169525498344, 0.1506517112495438, 0.11547024181533246, 0.30285778425393567, 0.09330269099483568, 0.18041949779275926, 0.17241550309042777, 0.1629871364322401, 0.25265613450638713, 0.2795309891864177, 0.22274524273891605, 0.09962204302991591, 0.18631089779157795, 0.3287409840812606, 0.25401518980581916, 0.3541313748686545, 2.6093062566172693, 37.008441186720326, 79.57675580055484, 102.92991238255655, 107.18714314122354, 102.97985984433083, 100.28116718415292, 108.11894924409928, 109.29397367662, 94.03670680138373, 61.276886770802165, 60.08872632057437, 32.359351919543364, 40.42518254249327, 51.73190486046576, 38.43081028230729, 54.406827957399436, 62.46164652609057, 96.79914582160212, 93.62663084460844, 78.6503625685169, 102.43751372060468, 137.49085733967445, 127.46539685033984, 121.74789121074062, 83.74542728547128, 63.97867418104603, 106.52865563669513, 77.31254408436438, 94.84797062412386, 109.79939460754396, 116.96230934512232, 122.94446514498804, 100.57172852177774, 99.18069131912725, 102.20501130627048, 97.14163149556806, 103.11633479210639, 109.72150418066211, 102.23530769348146, 84.99250565805744, 91.99096325905093, 116.08603615914623, 108.45328423284717, 142.62475352133475, 141.89977399764524, 139.11605219687186, 132.1696287585843, 95.26621295559792, 94.42309948705858, 87.85002293125277, 106.31169365298365, 75.07730299426665, 87.74291084658715, 70.63316345214844, 54.91448856169178, 40.07783312951365, 39.60098274292485, 44.345273817739184, 52.336930459545506, 55.14896000585249, 80.18174217593285, 87.73124571769469, 94.75634405689856, 100.43071146934264, 97.99276228873961, 110.04852787140878, 89.79147065070369, 38.91999652308803, 3.4077061760810117, 0.11253751934536042, 0.41371971609130986, 0.1906016183596465, 0.1252850921704404, 0.14623231855371308, 0.20668663024421663, 0.16235833146399067, 0.1904507450038387, 0.10666583078883349, 0.15434031735264486, 0.12950440568308677, 0.13015349665957113, 0.07880495200234075, 0.1793185375150173, 0.14520723162399185, 0.2156576270898504, 0.1979463484378592, 0.20105392281566897, 0.19525764029352896, 0.1396828183844205, 0.1925459954767458, 0.13055858863217215, 0.16658801014625257, 0.14692581198628873, 0.11847077838836179, 0.16622244831054442, 0.19584907549283198, 0.11667263213424914, 0.17544988542795184, 0.1375452032493007, 0.14571229807071148, 0.18012873678197786, 0.1729839403302439, 0.18879552011287984, 0.11952055633188256, 0.20166515372693541, 0.1176706301949678, 0.08970510379801835, 0.07894015886009702, 0.11325856896057246, 0.10559295529439565, 0.10970128564945153, 0.1107958950583012, 0.15773941882916037, 0.1618014774735897, 0.19102040798433367, 0.148830275922533, 0.1411528645023223, 0.1819380525980265, 0.1269979881603391, 0.16094329045905223, 0.1256320304087093, 0.13591936549111722, 0.1582356446212338], [0.056356955544963006, 0.05762169009915764, 0.020751940995274533, 0.027120763158065178, 0.07276732114053543, 0.07150951202117628, 0.03484203119672114, 0.04086274300671874, 0.03484537900095025, 0.03364930124652963, 0.06637918207073404, 0.10512447720693965, 0.06213205190555704, 0.013387477449742297, 0.02761649290820764, 0.05239589027159157, 0.10337145353156714, 0.13437376778212287, 0.07260681039864018, 0.05444655059686592, 0.03063460545343978, 0.015592139642385226, 0.020841257271146583, 0.039679949216905146, 0.07195340634714212, 0.05802732982462453, 0.05687350948010722, 0.09055152370203888, 0.038570956507277106, 0.0311136287411735, 0.04492692754513795, 0.07711761270559604, 0.02072720593141933, 0.02358101176909141, 0.039740979611392946, 0.08449687802743527, 0.0361766406304894, 0.003040073413191544, 0.03990618647226403, 0.08176683943959014, 0.08712419954639289, 0.023998215591775316, 0.04846539956727817, 0.05597370856952283, 0.11605330367362308, 0.04898866443263908, 0.029459236970832272, 0.022876488585625927, 0.10035152727317426, 0.04558679354827731, 0.4625393738669734, 18.928266071504165, 66.63237725534748, 86.17157797659598, 83.83167236082016, 80.52103504057854, 78.14044660137546, 72.96475364315894, 62.5182306381964, 56.78181525199645, 44.19697292389409, 42.4537500258415, 27.91995648414858, 35.99402996801561, 61.90836875669418, 59.823829050987, 51.855353616899066, 85.84040441820699, 84.76033272281771, 61.338550352281146, 69.3641511855587, 61.856781744187884, 53.62746869364093, 42.263566063296416, 69.93163185734903, 57.573251493515514, 56.67968065507951, 53.335934608213364, 86.82466829976728, 67.91732218957716, 60.6406077261894, 64.72358718995126, 58.5659327814656, 66.84238095437327, 81.53193966034921, 67.49984864265689, 84.37210436790221, 83.49438774970271, 82.11999708606352, 77.02196705725886, 63.28794871607135, 59.29678409330307, 61.583443533989694, 67.62610189376339, 59.099963480426425, 57.553055209498254, 36.637934100243356, 57.72648672903738, 55.75969657590313, 48.885656556775494, 77.26269860421458, 57.214354622748594, 58.29000188458351, 51.82003659586753, 79.46336792361352, 71.43113828474476, 60.312564219197924, 68.70060382350799, 62.833267565696474, 46.17391809340447, 26.744016178192634, 30.224707857255016, 31.69278825483015, 28.059080992975545, 33.027455114549205, 53.82119063408145, 63.519525451044885, 65.45580740897887, 70.06608286211568, 77.51658578072825, 85.64925947496968, 55.65516148844073, 20.67778829605349, 1.5352145822778827, 0.2521374163728568, 0.1059903021180822, 0.023937905319936337, 0.053661835244706566, 0.035131424740557714, 0.0137655399251549, 0.03494081823455711, 0.01106386670031615, 0.03631726372987032, 0.021304832395887183, 0.10673583590335424, 0.035147784548180724, 0.078759967319427, 0.03525390304745205, 0.023205900647407098, 0.029973207274451855, 0.06461992243965788, 0.07688200236448357, 0.03692044688749217, 0.030851812447391214, 0.04838784082582401, 0.042588505443305745, 0.054126693566720334, 0.01601044567407019, 0.10710041714651931, 0.07091037763823425, 0.03693345123000684, 0.06392613406323137, 0.06154291880046649, 0.008723499692766177, 0.042958529741172834, 0.037058331222543796, 0.05584550758583411, 0.024739329049724246, 0.04340915031911385, 0.0736125689300318, 0.020908370403753176, 0.048580561734495625, 0.031556686116082054, 0.062425279719454635, 0.08960677641293696, 0.06844210363323651, 0.05258283487731411, 0.04214577940142444, 0.06290162936033261, 0.08916793826727137, 0.05277894189461105, 0.08841719508411423, 0.05720097376334091, 0.011220139060770313, 0.034057499705663616, 0.0213315554579059, 0.02938244048686278, 0.04393475941352306, 0.03997150695912781, 0.0437059672549367, 0.011708183991422337, 0.019937627836160605, 0.04032069749589409, 0.01585849787994859, 0.030648636353772976, 0.07759063369444302, 0.043939512989093224, 0.04871305664099994, 0.07913430086186818, 0.03278138108491417, 0.004322411710276239, 0.09067577550247793, 0.04321554457888969, 0.11406049447795076, 0.041452324273244995, 0.015220265242181, 0.028165837321730874, 0.04310858721334127, 0.03860470651078128, 0.03939161287440408, 0.056215156500618306, 0.08203985785404522, 0.035969402355652665, 0.011687562819720517, 0.04338189291076795, 0.03781746306847181, 0.0011642058633433115, 0.026947548763165553, 0.02065575865638112, 0.06292222946461651, 0.06476973093325092, 0.06413972703740001, 0.05615526757713768, 0.007424772859761312, 0.0850607723658604, 0.019152245987507126, 0.016814750852063298, 0.05498746995844188, 0.030450725199414358, 0.005528632947619284, 0.12046347267084545, 0.03559343321549316, 0.024700925062080065, 0.04379168100234482, 0.07315884569599744, 0.08285749583475052, 2.1017226288395543, 37.77929675194525, 89.43233059298608, 100.7295411632907, 93.2899816574589, 94.82972375808224, 100.89726171185895, 102.4338423821234, 90.91744976658975, 81.66154261558287, 59.622109397765136, 50.64715769983108, 27.86443925672962, 19.94271847509569, 33.583317725889145, 49.081653471915956, 43.61352820550242, 52.84657578314505, 60.041932444418634, 64.63533778344431, 72.41312719160511, 63.04291825140677, 59.75911386551396, 46.71600141832906, 64.00421273323798, 60.994970337037124, 55.30231291247953, 54.343399309342914, 86.00481448634979, 74.05044217263499, 60.96774908804125, 66.53422386415544, 63.22181363259593, 65.06837921757852, 72.9829377512778, 62.22951281455256, 71.03428071545017, 70.17936875743251, 75.798705316359, 77.95504400807043, 68.54527796468427, 70.3312821542063, 64.75064762177007, 66.6097608689339, 63.18650053393457, 60.99657850880777, 45.46649509860624, 65.91147699663716, 64.90518116181897, 52.42157520786409, 68.50822725603658, 55.14410803394934, 55.86584375750635, 54.080486759062744, 72.54513063738423, 63.64697110268378, 58.60275991501347, 60.03907303656302, 47.05075610068537, 31.732547360081828, 17.971445052854477, 24.98379961136849, 25.690979419216035, 31.092214545895978, 55.84228600225141, 77.01385559574251, 94.1801243443643, 92.68804688607493, 83.95412875759988, 86.64717320472964, 98.18833951027163, 77.43781674292781, 40.25659907248713, 5.086185451476805, 0.03818107521041267, 0.15873594600106442, 0.0671668506918415, 0.016475871858757832, 0.04336906476847587, 0.07299685640440834, 0.03870925836024746, 0.03309153178105912, 0.019406977883209626, 0.031019882561879295, 0.03906743127792593, 0.03814027719800511, 0.013160237576812507, 0.01688517348450278, 0.028243631635221745, 0.045443734289297176, 0.030014125945707484, 0.10601012081268335, 0.06321176090427945, 0.07357288557555407, 0.07500368500909499, 0.08550717179933864, 0.022394174950257428, 0.0407806413638736, 0.07800665774172352, 0.034335026547553084, 0.05923906641621744, 0.036332370983737136, 0.026570731180629907, 0.02816156255111339, 0.026669734638304483, 0.06381661796401586, 0.08398252659507337, 0.009406865442982845, 0.03148840661461075, 0.04273514616333189, 0.0347404211248842, 0.046637847028192014, 0.030935434774766048, 0.052761206959163955, 0.05872872545413914, 0.04665640550815771, 0.014256678893411113, 0.026150671765208248, 0.04810110943752432, 0.011036116122868995, 0.05278826135420992, 0.08240381856599162, 0.07982305221019254, 0.031704317004750335, 0.07934122887109557, 0.05578256580197523, 0.17596815923048606, 0.17584440538719778, 0.13008776631566787, 0.10162373884550988, 0.16178707502061324, 0.17668546267574833, 0.10374248523505465, 0.14747005616945608, 0.11320035393920638, 0.10614646914144678, 0.14526804368342125, 0.21970557439471447, 0.17306854708060143, 0.1129796669908589, 0.1622599351309961, 0.12221401422134331, 0.24275429486747713, 0.30989663074574164, 0.1696124180190025, 0.13788574465340184, 0.08314651016506457, 0.21791599300359527, 0.09167991758834931, 0.19441529597726562, 0.18440693947336367, 0.16509021632373333, 0.19280166966059517, 0.20594062914531078, 0.21445537466676007, 0.07105154466004142, 0.13919226164298673, 0.1694395885832848, 0.12224560768734063, 0.16141389827093772, 0.21772451698780063, 0.13810669973252282, 0.10646691605929406, 0.17460876685236731, 0.12998511053381429, 0.18593056578068964, 0.16692974664751561, 0.19910592976356709, 0.1763856771492189, 0.14154769089673797, 0.24029476958657467, 0.07748997740207181, 0.1387845190061677, 0.16911182552576068, 0.21331399559013306, 0.14295713945982919, 1.0525536945750638, 33.00088497900194, 96.50020630128923, 115.6557599959835, 103.29001734333654, 99.48540456833379, 99.30687396757065, 94.43597270596413, 81.08815485431303, 73.54553899457379, 55.92976662420458, 55.01655647831579, 36.31042795796549, 50.58635311741983, 83.56573566313713, 75.85022172620221, 70.63473240021737, 112.82463242930751, 116.4091217902399, 90.09385401202788, 99.62553516510995, 90.54018051393571, 80.93373114062895, 64.52214602501162, 96.30488795618858, 82.27787248549923, 77.59074211120605, 79.33189792017784, 121.80583246292608, 88.89844894409181, 89.49801460389169, 100.67192939019974, 95.31240278674711, 103.7799527568202, 129.85861532149778, 100.65241167622229, 127.94386325343963, 119.3582420964395, 122.52384585718956, 115.54539234407487, 96.68785249033283, 93.83553627998599, 95.97822512349775, 99.73458490064068, 87.83947175548923, 86.99733103475263, 60.24514652067616, 81.69163503954488, 81.64078543263098, 73.52144779697542, 109.58211098947834, 85.42399775597357, 87.38184098274478, 76.0330355551935, 117.08165922472554, 102.78366288831158, 88.69665868820684, 95.39437247860818, 86.38654739625993, 64.67449872724472, 37.0606832350454, 42.30186800802908, 44.96189786541847, 40.229738681547104, 46.745933025114, 69.89167075003348, 84.81788173798593, 88.87034123943698, 87.27136350447132, 97.21051616053428, 112.75937987912087, 84.51767921447754, 36.946648167025664, 3.4022761448737118, 0.3814179864862273, 0.3011885399539625, 0.178089655875679, 0.18846446287728127, 0.21540947588941745, 0.19624489780154922, 0.14095550493126915, 0.10685615767274173, 0.0983192645494015, 0.16898201958787057, 0.1636589648983171, 0.23580285900783157, 0.12442625398116729, 0.12544691292268614, 0.1052339971365948, 0.1143315363855612, 0.09316160824270019, 0.22905515657076914, 0.1973600000623734, 0.1503060830216254, 0.14329403428541077, 0.1865742481764286, 0.17628892024438228, 0.12968457424111907, 0.20510455142826806, 0.13077059580433753, 0.14399374835193157, 0.17431538582088488, 0.09173769593959855, 0.18515064230849668, 0.11418578815796684, 0.16589506829698242, 0.1516426306578421, 0.14397790565365745, 0.12415429276804771, 0.2419655920276719, 0.06924471862974667, 0.12653669597761286, 0.13844639843990728, 0.12566817443697684, 0.15533551153156067, 0.13673937068350855, 0.1060929578999358, 0.10147042166922363, 0.17238346529343437, 0.17530124904888292, 0.1511641321403365, 0.18530015202779926, 0.16526543595377477, 0.0962903036645824, 0.11913889898888527, 0.18740750668991], [0.009519372157932771, 0.03055382914270365, 0.02979020993675917, 0.06876764503578026, 0.024540868227279956, 0.025831850868980252, 0.03787835939757286, 0.014463156825982997, 0.03042311156018367, 0.02919403648364448, 0.04378366772265684, 0.03253954244897731, 0.05056952516878805, 0.02994484286905537, 0.007337581520269235, 0.004325669499174242, 0.04289445797762564, 0.02587647932100921, 0.029941686586807334, 0.027836513360060995, 0.04580628156902329, 0.02591559002476354, 0.011861462863312374, 0.052445126742485075, 0.018361629843111002, 0.04344250578733702, 0.07318506122476633, 0.02000003335847249, 0.03145677484421721, 0.03236650616952008, 0.1045056160599474, 0.08967121972912744, 0.08546122950651953, 0.016228831485815106, 0.05931998062277994, 0.0613361363479447, 0.08006845315497729, 0.017244748343082688, 0.08816345144183406, 0.06385413328966787, 0.030547761726343346, 0.04784600981961816, 0.07913390249614755, 0.05954061394497272, 0.055746977187452786, 0.00748895043920305, 0.09270698102491517, 0.05242675978450045, 0.13428880863132017, 4.833993229173846, 42.60139588386782, 80.3234338760376, 80.2712663527458, 76.78156498939761, 67.97896615920529, 70.69803945479855, 63.496163814298576, 53.1770315477925, 46.948213577270515, 33.08638480401809, 37.79703763223464, 42.58250574911795, 59.4482111161755, 65.75841434540288, 109.69550671116, 80.1211807804723, 47.55922471323321, 45.940250735129084, 51.658678131718794, 39.275202443522794, 36.53176338441911, 38.28010105317639, 32.03019642060803, 49.222905866561405, 55.76279524833926, 28.34549834651332, 19.08101885549484, 14.395736898145369, 18.01944309665311, 20.11151179190605, 17.764663580925234, 14.379358060898321, 18.587506240414037, 20.169137293292632, 18.913425783957205, 25.788799408943426, 29.983234982336725, 32.366637722138435, 30.936431730947188, 29.113190520194273, 22.579927982822543, 19.148515001420055, 22.196224081900812, 18.371775880936656, 14.182384475584954, 15.332935279415501, 20.472920940768336, 22.090092589778287, 30.742647032583918, 24.648174162833925, 22.789053070929743, 28.679968657032138, 27.97454018746653, 31.9664284875316, 32.82961860779793, 40.790410118718306, 48.74756559248894, 45.49149236371441, 54.89759883572979, 60.599881756690245, 82.25200053184264, 90.69032099939163, 185.23215847630655, 43.865713073361306, 26.57137501624323, 28.005617126341793, 23.793526964802897, 31.241852967969834, 52.26439406794887, 60.6328296661377, 65.00070656499555, 76.34385201238817, 74.33544943409582, 44.08953920487435, 8.351003604550517, 1.2295486874157384, 0.13392916099438745, 0.2204736235040811, 0.046928592717214945, 0.1797124905691993, 0.09871184630619903, 0.02790418765207212, 0.024459243474167683, 0.03367280099360693, 0.05037027336056194, 0.051891957634999875, 0.06386510366874357, 0.054368087871661114, 0.05289083669683146, 0.03082222230131588, 0.043200870164700096, 0.017783645232538545, 0.05014530398071774, 0.06664028781796656, 0.04945291371475305, 0.04887616442095849, 0.08088782249439148, 0.09293470066040756, 0.0558795103983533, 0.031677276016243046, 0.01740943617938507, 0.031442833959215113, 0.04873081072864514, 0.06480592858767317, 0.021926901536062363, 0.03793296997525519, 0.02688302500774303, 0.06890865884000255, 0.015483765971786795, 0.078302405984892, 0.046210289527211464, 0.06940916706357272, 0.06079889420840529, 0.03758399777354733, 0.020520952079565297, 0.03033634061144004, 0.005424797390362309, 0.05288281192582461, 0.023509830709606893, 0.03921645453139659, 0.062007700513687834, 0.06801287989102064, 0.015246600472188045, 0.06779632981746428, 0.02948596386329061, 0.036605485159182743, 0.035917955721097614, 0.007435797822601613, 0.1035466808224878, 0.011942255453416898, 0.03396481072770492, 0.04442020251806225, 0.011902841187322573, 0.003547473555250514, 0.02988720241363251, 0.025304937509879954, 0.1445840190975897, 0.018335201724943136, 0.037429596582848224, 0.02538072850344883, 0.01928120731346069, 0.0045188040953249705, 0.04646461922675372, 0.03346788013474115, 0.11923985405554695, 0.07086024484446934, 0.03580674273712981, 0.09771269145271472, 0.02111982982305269, 0.060218019531138485, 0.0046399695190390755, 0.08910314255063573, 0.06079265825270165, 0.059165636888675155, 0.010399580369853686, 0.025097712641581896, 0.07127927961729227, 0.09843285240593458, 0.09656951206946567, 0.042774691621983246, 0.05425939914740382, 0.029728089782199072, 0.013290442838033122, 0.05396705999549839, 0.012217414126010432, 0.08321646165343062, 0.013136233169315083, 0.08565964627890818, 0.09956239542413144, 0.06783746873899814, 0.07281504841821809, 0.06263190129351232, 0.06482586219546295, 0.07096017335331248, 0.14635712959833685, 12.145678074129167, 65.07590232356903, 93.85375961180657, 89.24308407691218, 92.12475530562863, 93.72775739239108, 99.21931097584387, 86.89785188244235, 71.57459505142705, 66.90467603745, 34.45774347551408, 40.67419813525292, 19.664563594325898, 19.106151442373953, 48.20791021470101, 108.55976089354485, 86.60870259807956, 43.84714849533574, 47.88844100890621, 49.55022765744118, 39.17495842902891, 33.10344711426766, 37.57288594399729, 29.56755788095536, 47.71629994915378, 56.19609555890484, 23.091259925596177, 12.276210631093672, 10.550426590827204, 14.173358121225911, 14.955989622300672, 17.223329428703554, 13.642818331718447, 15.26352599743874, 16.29973873015373, 14.432090405494938, 22.648216447522564, 27.43186458464592, 32.12053448923173, 28.30538622794613, 26.609782864970548, 19.787943709281183, 13.071234860727865, 15.55519050167453, 11.84001463074838, 7.859138875238358, 7.7596994369260734, 16.31335327702184, 15.113194296436927, 22.393619322007705, 21.645833176951257, 18.110732340043594, 22.464633833977487, 22.602601243603615, 25.758942327191754, 30.90450756011471, 39.862851942739184, 48.206913932677246, 47.848181801457564, 52.9527739555605, 54.25949196661673, 56.84262375677786, 65.89778007999544, 142.6068518238683, 31.384897885784028, 18.879516893817534, 31.96688544365668, 34.60371840384699, 48.88473087741483, 78.18651091667914, 88.1981489735265, 86.60574513096964, 89.41715102041923, 89.98558090579125, 66.75305289606895, 21.441210969801872, 4.67969601192782, 0.21896136594155144, 0.2943682736687122, 0.021991151415051955, 0.06564834185184971, 0.12146720106923774, 0.016591673709392067, 0.007270421943582235, 0.046299856696878715, 0.04264663619500014, 0.08737510100247399, 0.02400276040838611, 0.03885786409579939, 0.020066744294918833, 0.054212545209954825, 0.017863000450175137, 0.046293459862710974, 0.036401782380116564, 0.06351705843342409, 0.13790285905763028, 0.06236857006085977, 0.04024089028638217, 0.06294625398192195, 0.08134357586142518, 0.03155544505364472, 0.04152412203350856, 0.03136107897115571, 0.07120512996710117, 0.03389600071034605, 0.0556205726799465, 0.016499746988918033, 0.06470805319446711, 0.02208239823249319, 0.04965468595225004, 0.007898603028978312, 0.02521835042223815, 0.023895946684323495, 0.04031900827202105, 0.11433991738745283, 0.02666139194080907, 0.03491919157245467, 0.03452771681270773, 0.02788293445783277, 0.033784465969450055, 0.06233714896464541, 0.009177731417660272, 0.04458739737709684, 0.059500547546532855, 0.059848784303833405, 0.03810186554948169, 0.06640800229844547, 0.078992881031046, 0.16148414853359425, 0.15191816184068882, 0.18801271615009155, 0.11171310914740448, 0.12204977263125683, 0.10166647889080549, 0.13502685773757198, 0.11502176628357942, 0.13394747049577777, 0.17080386860236046, 0.1210667975547333, 0.11019882145187548, 0.13107136192341007, 0.09713958873743973, 0.06267470262584186, 0.172109711434572, 0.1014894972585382, 0.17980602990475394, 0.10069533987271209, 0.18530965151806034, 0.17963920659836263, 0.11898311500948285, 0.16863423099200572, 0.1006047806191829, 0.11301330591161406, 0.1687025966783685, 0.11682168220079715, 0.09146797936409713, 0.13234984009496628, 0.12656923173175705, 0.2559018345369447, 0.2516077278602508, 0.11156475622086756, 0.2559364004240882, 0.10537716364788433, 0.12847829219554702, 0.18504316017272013, 0.14941297771949924, 0.11659838289262787, 0.12996110133826733, 0.20063661940155492, 0.25585789173360796, 0.11605187108920467, 0.16321624268687543, 0.11481854613990554, 0.17194134063057362, 0.19984275312914004, 0.19541611324154562, 8.727619782570871, 67.45551801496937, 108.24226071757656, 100.02289479778659, 95.6915626218242, 89.3941737759498, 91.73710746149864, 80.22207198604461, 63.03659931305916, 57.834238160041075, 47.065009993891564, 51.25792172647292, 58.31217896553778, 77.61073835434453, 87.97582903215962, 131.57237729718608, 96.00350087688815, 65.93556819423553, 68.97632291240078, 74.69399329154723, 57.55531841708768, 54.13303475226126, 59.666385112270234, 50.47764070572392, 76.5889766139369, 79.96064601405975, 44.37482103224724, 31.540325726232222, 25.57872706843961, 32.49961979927556, 35.62301297341624, 34.246810174757435, 29.198241233825687, 36.581703001453036, 39.02350787193545, 34.47467242517779, 44.90480384519024, 50.19820713227796, 53.90330545363888, 50.055691734437026, 47.82998984859836, 38.95283852854083, 32.84996786425191, 36.45184901452834, 32.70729753278917, 26.788876325853412, 26.384815323737364, 36.110026221121515, 33.90382243740943, 43.14792325419765, 38.579385742064446, 34.94701208606843, 44.23857750431184, 42.56294881143878, 47.61673842706988, 51.22037679918351, 61.59067246221728, 68.54713716814595, 66.11263967329457, 79.84086467373757, 83.09725561449605, 110.96615852848177, 115.24751186370851, 192.41896044823432, 57.36014519968341, 39.90515078267744, 41.2448480821425, 34.763539298888176, 44.73249020115022, 72.90979339230445, 82.94860562970563, 83.75503709239345, 98.99553191277289, 103.16771784136373, 73.62605740947109, 18.78791189962818, 2.819064317211028, 0.20132920885037994, 0.4039142196697574, 0.15636465872728056, 0.3034748833987021, 0.18292074422201804, 0.21014242222712887, 0.10066602168784988, 0.2672807836244183, 0.10410784022702325, 0.16144719245212694, 0.12108837825156028, 0.1381292073957382, 0.14062398804291604, 0.21449668212763726, 0.19295701696988077, 0.15033137924488515, 0.25011453056527727, 0.13323199033977526, 0.21732913901007947, 0.19735787033794389, 0.1374978130503047, 0.14646507138686796, 0.22071958369305059, 0.1089936578946729, 0.1271303221883793, 0.1505073036758169, 0.1445127575988731, 0.11569381691515447, 0.12305686415563669, 0.19410881484227796, 0.2948608682040246, 0.1399810410915844, 0.18218033556495944, 0.22511882827647273, 0.1647341080130108, 0.1335584816913451, 0.15218001069320788, 0.16449908755960005, 0.1484169868091422, 0.1520611751343935, 0.13101963566676264, 0.10809054748425562, 0.12270545196388999, 0.1994986723988287, 0.06126704670849347, 0.097018723045626, 0.09468314312999287, 0.26911397074018756, 0.2337413164035928, 0.24164598014566208], [0.07658985473455922, 0.05713420920073987, 0.04230650081749886, 0.010948210406387526, 0.006607285702616097, 0.04753389027750781, 0.03321629686040744, 0.0242692670754848, 0.02937455361168231, 0.08406800668566458, 0.009021866041415883, 0.02833094267595199, 0.055257412529880964, 0.12112986191266006, 0.011897253533524853, 0.04124060821449084, 0.10325625689039308, 0.022736664132906065, 0.044166244371163274, 0.0472908259008921, 0.05218831491806815, 0.030134145110364885, 0.041517939703959617, 0.09371183557255615, 0.031249456130148425, 0.07957412726095608, 0.009324500457413737, 0.029963943356227492, 0.02514473320315442, 0.032343079200795585, 0.017594228078040387, 0.030638717430373354, 0.024437892603717988, 0.07238790077427704, 0.018305667120242314, 0.020615071726722584, 0.053250101289802024, 0.011903249129142252, 0.0350860531832422, 0.06997624066688361, 0.037645219690016204, 0.04202689787733459, 0.0358167440149813, 0.03483046709950413, 0.10137447681758674, 0.03718003961107424, 0.12035356969722819, 1.9838725655309617, 20.704919330535397, 70.13221402322093, 90.01616754839498, 83.5155136354508, 84.83004108552011, 72.81212637501379, 44.61118698120118, 39.70265057779128, 39.95219961289437, 36.776691867459206, 37.58957170671032, 47.09683610546974, 39.90510371423537, 62.802900575822406, 58.09686829966884, 41.55031050405195, 44.232415460771136, 36.3425168683452, 51.742754136362386, 49.33085341607371, 34.94128150324668, 18.20951919401846, 10.93425012403919, 5.131208377499735, 5.1983171893704325, 3.0167983520415524, 1.369297956266711, 0.25825066011278863, 0.5752664540083178, 0.5124033320574991, 0.23289803746006182, 0.4727740021001908, 0.8005678257153881, 0.6584902011579084, 0.7842347698826945, 0.31254272907972336, 0.6843989883219043, 1.0201802284967516, 2.5376830418263716, 2.5287182196494076, 1.7136618326748572, 2.2846399103441546, 3.2011553885475283, 1.5499723774771539, 0.9947582442433605, 0.5920071911907966, 0.9844369561441484, 0.4366677266455466, 0.3031594083914834, 0.03446061517142, 0.17876545267720378, 0.7399199542499358, 1.2084538129068192, 1.2930615438568978, 1.8171930385212747, 5.155366255391029, 11.157586939873235, 15.44039841621153, 28.793635022255685, 34.13475198130454, 30.83870391691885, 40.89754965997512, 42.717152872393214, 50.38032670174876, 32.10213465075339, 43.14040014820714, 76.1411125429215, 50.1465573618489, 42.094558977311664, 29.011167710827245, 25.447096247826856, 29.544466887750936, 38.53636126364432, 51.39436921765728, 58.097523335487615, 77.06511312915434, 70.74098156344506, 54.894056935464185, 22.664023599316998, 1.6815473043149518, 0.21844463963662425, 0.029281449031024694, 0.02007039087343841, 0.03523959635546611, 0.12211123586542184, 0.06081370651842125, 0.03975374263621146, 0.01562317577941764, 0.06320775426443546, 0.039033980048712225, 0.05671003014750539, 0.06764067607300897, 0.040904716964090065, 0.09373787490110244, 0.06348070756141698, 0.07450858536627024, 0.07591264067037452, 0.11409505270421506, 0.01746859731933763, 0.03345413651737956, 0.11495952930061087, 0.033944176149464426, 0.0487726659423882, 0.02545854771479724, 0.01014126988593489, 0.04200993669069102, 0.059077161394300005, 0.020553175652880343, 0.08394531770459107, 0.06618037459350402, 0.05083252315319354, 0.0357261311352974, 0.026564746118721463, 0.013893049514491954, 0.12632924702859696, 0.00960049129301502, 0.051492339360617825, 0.02375128055592218, 0.03376206938898371, 0.042429990360453244, 0.0351676109036611, 0.03597863371514025, 0.038494684793535745, 0.05342008087844138, 0.03257489740668285, 0.012769895669583593, 0.07688297529614742, 0.032447041162560065, 0.00163985142153838, 0.027871416325891213, 0.058494555358324325, 0.05549267047054826, 0.07725091966530008, 0.0662551294531553, 0.05336904793136543, 0.030787083763448946, 0.017946107583420894, 0.04950180161564101, 0.04723775132949795, 0.04456637209401496, 0.008134294766932726, 0.1577801440632151, 0.03654456584744396, 0.11862436369542154, 0.027526287970343427, 0.034410681560515397, 0.10559779697007711, 0.05842889779277387, 0.08635668669857326, 0.05230390992496283, 0.01420186626003875, 0.025338884781024633, 0.019184505949998577, 0.04384937125348276, 0.02201829391020921, 0.09246433799665782, 0.036443974672546314, 0.026892917118065303, 0.09046333166019571, 0.0265358665191959, 0.037915683201243805, 0.054466805961583896, 0.02772363413485789, 0.025586413535019083, 0.06280715539751035, 0.01889619067491543, 0.09720335789625684, 0.0952154823068169, 0.03443968181888904, 0.047865230965638356, 0.02174432554672803, 0.08707713876520434, 0.137987251303369, 0.06342831097783581, 0.13389473300307028, 8.122620659489787, 38.59887992182086, 94.97513386511034, 103.7724296508297, 99.82615655468356, 104.38296225763138, 95.80655867053618, 68.06582312430105, 63.42423931244881, 58.074079328967684, 30.587740867368638, 15.068250798409986, 28.152286314195205, 32.09257387345837, 59.881013285729196, 54.597965055896395, 48.17667638101886, 40.35001424051101, 30.246567226225334, 39.380047398228804, 35.231368234080655, 21.453731175391905, 6.925740290072657, 2.966762636938403, 1.7193495145728512, 0.7614874130775853, 0.4534308642389313, 0.3104990822893958, 0.606842453200971, 0.8993034437298776, 1.0709040131299727, 0.8902745153154097, 1.052626871293591, 0.9157173371603413, 0.8119128524295746, 0.8335435594762526, 0.14288561749121836, 0.5506709254076404, 0.2625891692455738, 1.8068689925055352, 1.5754926661329887, 0.6036644140558859, 0.4845539828942668, 1.0678975163928925, 1.1790623900390442, 0.43083206720409856, 0.4714844003319741, 0.45048991398465255, 0.5736712138018301, 0.6923163538017582, 1.0916300622686264, 1.5103481037001458, 0.7443380139527783, 0.6391375944499047, 0.8035816156095075, 0.3720561162598672, 1.564855933670075, 3.3316474960696314, 7.861399631346426, 18.02743688706429, 22.50735236752418, 23.917571921502393, 33.64442040843348, 40.3834955923019, 48.30494180802376, 41.06502309922249, 37.049586849827925, 42.45038070986348, 29.996941704903882, 26.02412396861661, 26.51821513329783, 36.76885497185492, 53.53803473134195, 63.21962887240995, 77.8611816898469, 77.16204274085261, 89.54210204462852, 89.48809885209607, 77.46837200657015, 42.21756450591549, 6.309205966611063, 0.050112178338871854, 0.07855207403941501, 0.045547868620844624, 0.07725556215812122, 0.06894756844567676, 0.09723777056581552, 0.046135431245690396, 0.020700569054292097, 0.026765229413285855, 0.012974087787311406, 0.04484941093851963, 0.08366565730783247, 0.06560185563660438, 0.016859597639150677, 0.011905572290772633, 0.030026279930626194, 0.03274536729159375, 0.05884330539453415, 0.02719555440689287, 0.005658522197571133, 0.10246673433650887, 0.09084135774643191, 0.07087768100562596, 0.027552476686034954, 0.017482854215608492, 0.043559280569635095, 0.12486453288264814, 0.04787540844371242, 0.015052031376399102, 0.016031399136409163, 0.028774448212296255, 0.028300316395959067, 0.01815649831006604, 0.03677019789334267, 0.010983860307943918, 0.013777530158779795, 0.02431290727409144, 0.09449457058743124, 0.03879853058606386, 0.053690176667465325, 0.029213002905429854, 0.00966528126399123, 0.05899697114082594, 0.016884198637619134, 0.030380068910157973, 0.08334779976716927, 0.010593464774560305, 0.06726068880168662, 0.1218863124508531, 0.18994037722868307, 0.19376905484785958, 0.1266988001823906, 0.15841777436435223, 0.2024049341918961, 0.10690761579861564, 0.10996393889429108, 0.19428899872206873, 0.16181496062105702, 0.11175077769064135, 0.10589503908469793, 0.1018213665473365, 0.36409195812959827, 0.12490230101731517, 0.20577916845438943, 0.2849429407187047, 0.1650455533977478, 0.23468268524494865, 0.1725751864573648, 0.19052355400016233, 0.1370506322071437, 0.118668329481396, 0.1611118298023939, 0.0718249717066365, 0.1261567623324452, 0.11108505494532087, 0.15128207903715873, 0.11892671561649731, 0.17080609025734086, 0.22457089154951035, 0.17852750576792226, 0.12149943804909145, 0.19661367720653936, 0.11570118668098604, 0.11772409547120334, 0.12378448680523904, 0.11115512134687555, 0.171839788015331, 0.28376138799132844, 0.0970302143644902, 0.19891158857893562, 0.15667368327417683, 0.1381584719544457, 0.40039548590298624, 0.30745057329054803, 0.35160411209348713, 4.575199167574606, 33.20930404047812, 100.8940924367597, 115.17622670819684, 103.74029759437808, 107.25094441444644, 95.3357958024548, 58.361416478310865, 48.023931441768525, 52.15554045092676, 49.230056347385535, 48.00763007133238, 64.74494841790968, 56.67025127718526, 89.98006605332898, 80.39265586483864, 57.463821288078066, 61.0861889777645, 55.18312385005336, 74.50069104471515, 69.351411327239, 48.57851536043229, 25.288663871826667, 16.895703654135428, 8.74754052008352, 9.51840098827116, 5.7569411493116815, 2.366730705384285, 1.0261253159373038, 1.3684922769185037, 1.7796740969342573, 2.077451247361399, 3.7173101305961613, 2.8507989885345584, 3.352959449252775, 2.7316361569589187, 1.8731691832503967, 2.7758591646148316, 2.8921187068185503, 6.943340945628382, 5.552508686819385, 4.256682607435411, 5.3975647687912, 7.512845070131364, 5.924937734680792, 3.174382515491978, 2.458194984543708, 2.575833975307403, 1.6414536944320126, 1.6249883198930373, 2.677527060431819, 2.6472054229628657, 2.1464288234710693, 3.817018251265249, 3.7237310505682424, 3.969597225227664, 9.557862973982289, 17.167235612869263, 22.631467926886774, 39.10659151692545, 43.11523029881139, 44.69885195455244, 59.96533639969365, 64.06586454760644, 71.7739377483245, 49.88249947947841, 62.280487937311975, 99.07213580223822, 71.88496435842207, 62.88816898099838, 44.52307878002044, 36.49244946818198, 43.06588295967349, 54.50830359612742, 72.30232807897752, 75.48082074811383, 100.7443206541, 102.37379089478524, 85.36027493015413, 40.86199729673324, 3.935619203313705, 0.3081338011449383, 0.17476259730756286, 0.14527587310200737, 0.21068116589899988, 0.18652054541293653, 0.21711904705772478, 0.1455077679166871, 0.16550483843011243, 0.15668597132448228, 0.1355353409364339, 0.11279887024072871, 0.1727931537935811, 0.1557350570275899, 0.23758896235977453, 0.18366622438113536, 0.26690739237012406, 0.18313987601187923, 0.2676806508773758, 0.10160718368546617, 0.11694846975226557, 0.18702406436204913, 0.15224960212024952, 0.14263075536056874, 0.14154933032489594, 0.0911873996618294, 0.24957874399279398, 0.20124092487798584, 0.2598099861173861, 0.20560154330826577, 0.11915224424052624, 0.11217889826624625, 0.255533637358777, 0.06523756550685053, 0.10814237333233319, 0.12725468124112777, 0.16396956758633738, 0.24530011229217055, 0.21498740740841438, 0.14470735925339884, 0.1604011760003144, 0.09347795659015257, 0.13708807858488253, 0.17153738246810052, 0.10296022519469263, 0.2382731554849494, 0.165164036556117, 0.12905742402278608, 0.13487386997909317], [0.08555530510362118, 0.05890744993643415, 0.06455892651912666, 0.026650645642451225, 0.044120003304053704, 0.06063418147424537, 0.014836362303955661, 0.10290147391177955, 0.04576514264748943, 0.08031964572446962, 0.023167866297186385, 0.019495258025164088, 0.03944185675091801, 0.040680027206338225, 0.04548224935969038, 0.03712538306811645, 0.011792227667155526, 0.0918534288423196, 0.00481009274916423, 0.03483797476116208, 0.021198127839353778, 0.07041188422590494, 0.008003342091180986, 0.050477652074468714, 0.0422245562226782, 0.04069734079342696, 0.002805050086951064, 0.037330112405001156, 0.04244608586774238, 0.06869357199438157, 0.10134998498664749, 0.046702983653953964, 0.052619331306026834, 0.11120902329322793, 0.05892497419770207, 0.06994941992865455, 0.07378757405545443, 0.00889852301277701, 0.057572422984747164, 0.046980050843088865, 0.05138460824626589, 0.03840944602064068, 0.13476179131577093, 0.038660378120238745, 0.10407129017215583, 1.2434822945825517, 25.197127519115327, 67.2083459361907, 88.31706739241078, 83.93391286173176, 66.1089369558519, 56.541836800113806, 50.35523922212663, 51.60379240589758, 40.151538387421645, 41.1604033747027, 30.09701313511018, 40.82307169514318, 84.69354260352351, 51.470659317508826, 58.63273466787031, 37.223092894400324, 31.600416437272106, 28.9840837447874, 26.49846011592496, 21.645542921558505, 6.167449547398475, 1.2666865462257018, 0.031069615074703773, 0.3928175586606226, 0.47678591262909675, 0.19021272148576476, 0.14851401950563156, 0.27110043672784684, 0.33148789958607766, 0.07512530912795375, 0.2329924961011256, 0.37910933456113266, 0.09722467812318956, 0.13562822143637365, 0.10042877957945871, 0.08030541947171574, 0.043578808150825, 0.025415729145489396, 0.061879380786370855, 0.02219700498596555, 0.02900535668877344, 0.046005625307800314, 0.02491655199968767, 0.09480829891418258, 0.027695903667218746, 0.05320448841479036, 0.11723598255024803, 0.10218305197814781, 0.021103012277894927, 0.04513643344023055, 0.0863555682102038, 0.02044498105533421, 0.30601480194637853, 0.0484064337797463, 0.07293160103501813, 0.05205668186047866, 0.08223340230723543, 0.28210501396848314, 0.6684236649063326, 0.8066200428912718, 0.7003695926358623, 0.433458277895566, 0.26832560497906904, 1.7122798100594552, 6.832882588909519, 16.08396718578954, 34.39754293810937, 49.76209055992865, 57.778524814113496, 63.82257953766854, 52.12021950752505, 50.19259422056137, 30.233119380089548, 20.22068508209721, 27.196277226171187, 33.064627416672245, 38.71917117026545, 53.94450602992889, 57.79024485618838, 71.17374450929704, 70.56880520236108, 56.934167954229544, 13.943628822603534, 0.09849811543620403, 0.3862522157930559, 0.025146054704823805, 0.01364197377340808, 0.09599723672914891, 0.017190616570353028, 0.007404744927395857, 0.05138675712289349, 0.020809989392517075, 0.018889309290135582, 0.05946281388582242, 0.038344029772786364, 0.016769386955627033, 0.055526535387241074, 0.03906773771309564, 0.05546627108067755, 0.09128577301218625, 0.06180700846016408, 0.05268009740018076, 0.008927486881974244, 0.032307172659784555, 0.03130813846514831, 0.02649623104521344, 0.019839206605308482, 0.0561914230967241, 0.07842779159545898, 0.021664269358640718, 0.0672623129080861, 0.00872345564271053, 0.037459439537938566, 0.04406412485085669, 0.06213443826944117, 0.03556609536791521, 0.07911446684550855, 0.047719038407047915, 0.079099620061536, 0.05436854369397606, 0.06413018924274272, 0.04709533941481383, 0.022224308359586907, 0.08418634428732819, 0.04540084102641671, 0.03885568840609443, 0.03287191352536602, 0.04317328333854676, 0.030947226783140536, 0.028963373155303063, 0.0712295834936442, 0.06577836995523784, 0.06698559428895674, 0.036908151176307476, 0.050173036363576694, 0.027495878110189113, 0.04337997386051763, 0.07274207854343039, 0.025304707683502667, 0.068924417268605, 0.047014103451323126, 0.047592492173275644, 0.01628797730400918, 0.04069708032353271, 0.01703502028249204, 0.018177941111066652, 0.013332215697324325, 0.027475645728108865, 0.03306320568005885, 0.046607176698143446, 0.04528700802174788, 0.007793759108491003, 0.02680539731837569, 0.050324089750046694, 0.042330050360291235, 0.03603444322042408, 0.016700946575691624, 0.027704910945988474, 0.046180653415860674, 0.1088058437791563, 0.06737226184697882, 0.03804800956840477, 0.04518020004334469, 0.10791073898754774, 0.058581556133445234, 0.08344964349582311, 0.04308766152168955, 0.029816875542183558, 0.01825007403479709, 0.024626219998143857, 0.018775095156724417, 0.040428849958604386, 0.21318584440215943, 0.1158146289808135, 0.08125813407523018, 5.979448383854282, 46.230027598719445, 91.28428551458543, 103.90142071631648, 103.52199416006766, 87.70279284446471, 83.40771121363487, 79.4573353182885, 82.48605620476508, 46.74544665121263, 32.97385592614451, 16.3886922021066, 24.384612460290235, 64.05783545586371, 47.60346120403659, 52.004148729385875, 40.67490808425411, 28.52963597543778, 18.040655274544996, 15.485371332014761, 11.732487755437052, 2.0171743463124, 0.4992740252806295, 0.4676186900225378, 0.57890972302806, 0.34091758391549515, 0.18817953945648289, 0.23150395662073167, 0.14558747170432923, 0.16631595700258212, 0.1548727331382613, 0.20178276354507094, 0.22349573311305818, 0.15263140501995243, 0.25005371850584784, 0.14823877943619607, 0.09990381782934551, 0.0012560102491519386, 0.1951656178120644, 0.00850791872043403, 0.045270701840279565, 0.16359780043844255, 0.22646384884513196, 0.0721765294550888, 0.1503567827204543, 0.052896402325601354, 0.23963478483980705, 0.03361762351086063, 0.13080943646209856, 0.012633606712634285, 0.05858707196650006, 0.09243339570539613, 0.14587107745389785, 0.5959882130545955, 0.047064270719044635, 0.08013004662408944, 0.06531274937573942, 0.030882622588485963, 0.23168752660914776, 0.3437646730772911, 0.6887281205384963, 0.8557553288917389, 0.6980642195670836, 0.1165541106714837, 0.3209386237205998, 3.1118878818327382, 10.92143770187132, 30.556665889678467, 44.43499411306074, 54.898493136129076, 57.90098905563355, 36.848451629761726, 35.04918982905727, 18.564087729300223, 16.319536893598496, 37.299288857367735, 51.43165919088548, 63.45223326836864, 80.94236035500803, 73.03377951345136, 82.10001653240573, 83.30016766825031, 80.3893453844132, 29.907452829422493, 1.3064789916238477, 0.1463308987478095, 0.016793788771235177, 0.021378658373930284, 0.022261616841499365, 0.023248368731489586, 0.035812507548760024, 0.009126317341842, 0.019556384180642424, 0.01953023376934711, 0.009659569120905813, 0.044845710733845356, 0.05439178297115911, 0.05336468506063666, 0.06703293086179803, 0.09386899084934304, 0.02379301894125679, 0.04117835207932419, 0.0354851620091546, 0.058306254776975805, 0.021986778968224124, 0.08542606607079507, 0.043736695041579586, 0.012136236576723957, 0.04458409170770357, 0.03543343192206756, 0.07060224941420941, 0.0418879448496286, 0.030522273981102535, 0.04155231406912208, 0.027591855520562782, 0.03323827592295504, 0.07371934626491801, 0.0356858080974029, 0.0026534381745037653, 0.05460680852974615, 0.050044950293076616, 0.017523763310765068, 0.0034903018498763203, 0.058898888903880314, 0.011170007224615303, 0.0437965992868187, 0.007102449026499545, 0.03948702146449397, 0.03117788436582252, 0.05096297260494002, 0.074174256935235, 0.21848605434981086, 0.10618923983025937, 0.12136449166122945, 0.11525651860621669, 0.14736550048955027, 0.17208559498671563, 0.1364868834254242, 0.1884756017957003, 0.12994418611689923, 0.2486172576825465, 0.12008838070135926, 0.13733370169516534, 0.10524105280637742, 0.12635584560132798, 0.24486834513804606, 0.12337821505723462, 0.08115123416627608, 0.13780153626876493, 0.08671428888074814, 0.1332516175123953, 0.08505517226313392, 0.11160218727684791, 0.14129957033982202, 0.25199716099567954, 0.13957345167235022, 0.13017278675350452, 0.1296802688269846, 0.09621449926447484, 0.11961068657617416, 0.16869816869016618, 0.27070118234522883, 0.18478437567189818, 0.13032074897520005, 0.31104726416449396, 0.21008729454009764, 0.23014137731684794, 0.11094680671850521, 0.11851268339781992, 0.12331193313002588, 0.2708035623354297, 0.12495323820340058, 0.17734553935306688, 0.45426752418279653, 0.3132653338534217, 0.1566179120732892, 3.457810287514041, 40.51749160212856, 99.6908583179597, 116.94835355204921, 104.145949117599, 84.75264487727996, 74.56530032619354, 68.26387928378198, 65.63080787658691, 54.608061236719934, 52.45073410772508, 41.729653035440755, 58.74880936837966, 116.71134041201685, 70.42587403328189, 80.7245825183007, 56.8160104751587, 46.5772593405939, 42.53076576417492, 36.408008683112364, 28.31372322574739, 8.161252573613199, 2.475042299878213, 0.7407767469844511, 1.0760721035542027, 0.7796389777814189, 0.6000275188876737, 0.49275314615618804, 0.4175860699146025, 0.4008060170998497, 0.2523026768598826, 0.5406998927074095, 0.6684172910548026, 0.3408168586752107, 0.3564618756213496, 0.2526521048839054, 0.29512234933433995, 0.15730002143931004, 0.28523819100472236, 0.14289468797224184, 0.10557878266779647, 0.24625951484326394, 0.5550364008353603, 0.14689424916380836, 0.3082404405839982, 0.20855245270556022, 0.20517055756382405, 0.1648444093523487, 0.30232737561868084, 0.07377735444254453, 0.14311263998669965, 0.22438376691312562, 0.21633771398375112, 0.5720494363096453, 0.20561784565929445, 0.2774446253334322, 0.23738126060174358, 0.29401878435765544, 0.7847358526722078, 1.3588548908310554, 1.4868469776645785, 1.4347250519260284, 1.241847646813239, 0.8886539022768698, 3.1323332363559357, 10.606565513918477, 25.044408075271118, 53.159306356983805, 69.38491621325093, 82.63297250193935, 88.99640621677523, 76.34744490346601, 69.31734946466261, 46.59713399025702, 31.069394196233443, 36.65992290742936, 43.74830476699337, 55.18400246097196, 76.48438269092192, 76.81510125437092, 93.93999684241511, 98.03954047541465, 87.55797109296246, 26.64098139732115, 0.6273821897564397, 0.6223890125270813, 0.15614587933786456, 0.10644135936614006, 0.1668018865729532, 0.13314837950371927, 0.20189154803031878, 0.15713295298478297, 0.11169132926771719, 0.054753276879989335, 0.2483545967768277, 0.17125129459365723, 0.18041628022347728, 0.14538753807785051, 0.15977192670106888, 0.2988712772005989, 0.1557596637717178, 0.15746656895404862, 0.26415496103225217, 0.15126885635958565, 0.10714705657934952, 0.17568496716839654, 0.06586352062802162, 0.12856610119342804, 0.13118530984126753, 0.167168888653959, 0.15986453140935591, 0.20496546050473569, 0.1346537575966889, 0.17590016126632693, 0.06834880178493839, 0.13187892584791108, 0.19038351312760385, 0.09385166960137506, 0.20390332556299626, 0.1780345128668893, 0.19337845725878594, 0.11939932291786517, 0.14185879920278827, 0.10145856262815577, 0.15366936222680155, 0.19294894240315885, 0.0750541931859428, 0.13709947797319583, 0.13174844575264763, 0.15008151200750183, 0.11885818905167042], [0.04991778352808568, 0.06342592461395168, 0.007291858998923413, 0.009435313160441095, 0.04129390878182265, 0.028657566177688783, 0.007078361785745309, 0.015709132759741718, 0.04903593971844643, 0.011662099972337244, 0.030918201626909357, 0.021718586907692013, 0.05395161949338452, 0.03099066971410667, 0.06578311970036838, 0.059522691317984176, 0.08656245025415575, 0.03622764293404837, 0.00923401110940763, 0.06849023693751904, 0.03831435918747898, 0.02093471042180975, 0.022757748787802075, 0.06980091378453278, 0.03363843428932371, 0.04491830522555017, 0.054500992635204915, 0.016027050629828968, 0.05012930040397952, 0.02462639619836644, 0.03467788153718557, 0.03261651513316939, 0.04071021107055488, 0.039194169033679276, 0.06340480740031888, 0.02280058459408822, 0.0501222102602403, 0.0054165600299564826, 0.05863074280862367, 0.012076052709392483, 0.02671154005633247, 0.025619734529285662, 0.1306795079501406, 0.837781803021508, 16.29351588987535, 61.66375406326787, 85.31935676451653, 86.40386858294087, 75.8357560250067, 47.47821600206437, 59.40372359368109, 51.36765395441363, 28.02038681122565, 23.922627856654508, 45.51621506291051, 69.91863312259798, 91.78149300236856, 62.171767680875725, 34.56432996257659, 36.689285770539314, 30.365617044510383, 20.66432476043701, 9.599184163155096, 1.455623807926332, 0.07525943580173677, 1.072243012247547, 0.48431955998943704, 0.027467507959133195, 0.13185808825637066, 0.08966983310998448, 0.10150740073332865, 0.1504677275736486, 0.2783427255288247, 0.1330604172882534, 0.20260525086233694, 0.08324853009394101, 0.11704772410373535, 0.07974990613518224, 0.308702698037509, 0.08231662243845002, 0.7433910679913337, 0.55349288688552, 0.33494834938356954, 0.4131366312503815, 0.04138711869956986, 0.1633213499500867, 0.43906254814036433, 0.40269601729608356, 0.23205805269460525, 0.368672704264041, 0.7420895152514981, 0.8464449704174073, 0.31473668232079477, 0.2803332364607242, 0.3560756447334444, 0.5448150106014744, 0.1047508944306643, 0.048924171320733525, 0.13387337447174136, 0.1693827448593032, 0.1405513935512112, 0.1503346274576841, 0.10588262079944534, 0.38902971352781024, 0.3101185817391642, 0.22567957399352906, 0.24256649607371902, 0.23105107608341405, 0.03547690741177048, 0.07898111392052905, 0.07053585257381201, 0.5148349870597163, 2.652138293750825, 18.165053244559996, 25.895462382224302, 33.120732999617054, 47.018902532515995, 52.42630166392173, 72.26601477592223, 67.42094624427058, 36.14304865560224, 29.908160817238596, 37.0359879924405, 41.59889690337643, 58.19440587874382, 57.37229670247724, 60.83356872681649, 72.38105789307626, 82.00482845306396, 46.85912870591687, 7.915719064974017, 0.07080074279539048, 0.14956924433429397, 0.017323048274603584, 0.041629210144521735, 0.09386920535396184, 0.06065046850351557, 0.0764854369504798, 0.09368512208663649, 0.12697888192750756, 0.041171553048996196, 0.04704281642672516, 0.025153596840438344, 0.02464874681355732, 0.0429726985373324, 0.04527062523148714, 0.04884418025011978, 0.004671056409396472, 0.03897408729479198, 0.03559347918076861, 0.046575269136097164, 0.05826694680558098, 0.04744375620277659, 0.012576672973321571, 0.07125810494706517, 0.05063751547206795, 0.018524312444271582, 0.007916716220338018, 0.05391269456595183, 0.08529848944876464, 0.08494867071990045, 0.020312020750415903, 0.03532980320855014, 0.06142975995317102, 0.015019463063518127, 0.009838446820785683, 0.023258214876536402, 0.025886022861325936, 0.06478692960715102, 0.07627372855260488, 0.021408307891819748, 0.05259169468415841, 0.06022573020609637, 0.04425766164316766, 0.1129592813911938, 0.053955832976968064, 0.004684857962157337, 0.0787667855019531, 0.09349408274095866, 0.055930888084995176, 0.053995060509130846, 0.04076384488613375, 0.030183446698731957, 0.06117008679035691, 0.02298881622752355, 0.018678148645126534, 0.03493820970517493, 0.02199294023035515, 0.11953728003126961, 0.008863298290018595, 0.006305995292120403, 0.06336712736576315, 0.0410814764308593, 0.05720117677664084, 0.039735816178783294, 0.05113734953826474, 0.04991157055501977, 0.04805128307892911, 0.03784323809668422, 0.05429501840544324, 0.050135206941875725, 0.056811712997695135, 0.022002077744072004, 0.009818531407584107, 0.06095490801418501, 0.0438439013857034, 0.03752224342597108, 0.0770286928802248, 0.1012619155188722, 0.031157129128733953, 0.046944795476813475, 0.048580205503610835, 0.02837183070369065, 0.0424449980228899, 0.0653964521423463, 0.04078386659403482, 0.07608035263875801, 0.05199276714495594, 0.09127787464568693, 3.5765313621490233, 36.80238731445805, 85.70294103314801, 103.21427637530913, 101.06987737840223, 95.84244835761287, 75.38815083042269, 93.48409975728681, 77.32071045906314, 43.41700569275887, 21.947110429886852, 24.253993611181937, 41.59983827221779, 68.67238629248835, 68.84059321495795, 40.00368856614636, 35.22814404579901, 22.51799964135693, 11.628432177728223, 2.9033820379164914, 0.25620774876686836, 0.2876259951341537, 1.1925360993031533, 0.4079238012913735, 0.11026550174480486, 0.1405918736371302, 0.19439288024460116, 0.26650409304326583, 0.18352754714508213, 0.05738122659104486, 0.13054387974402598, 0.2561470133162314, 0.04822228539494738, 0.10634966630248294, 0.32202214783718514, 0.349653713525303, 0.23947264999151233, 0.7286366435789293, 0.6173374287543759, 0.8060927905382649, 0.3756849215395989, 0.4666207532488531, 0.5925209603963361, 0.5424689429421579, 0.5316410562203777, 0.4476311189993736, 0.4261489104359381, 1.1323577478047342, 1.1652656981060583, 0.24173651641655355, 0.4171323926458436, 0.39456025547077583, 0.2568583259539258, 0.10533695169273885, 0.19735751793749873, 0.08108676020656863, 0.061480229825622616, 0.09009880404318533, 0.09303306634988516, 0.07193992319967478, 0.3058199091784416, 0.24130156233666405, 0.3291776235545835, 0.1778771430854836, 0.06764054583806185, 0.00491454309198044, 0.11210386761494222, 0.21157756537920047, 0.4016938823605738, 0.5540447153391377, 12.079245871113194, 26.258687588476366, 33.85679714141354, 47.18405785099153, 43.004952861416726, 46.83837152296498, 29.68727646335479, 18.250315766180716, 23.339483199581025, 45.450778161325765, 69.84605358492944, 89.94638858302947, 84.07532215118408, 78.10001480963923, 83.38494577715474, 97.50359565980973, 71.03655569015011, 19.3285459087741, 0.4562088216264402, 0.2553027997454328, 0.05030079684670895, 0.04199456513649033, 0.09888753324987427, 0.05713055879178067, 0.037279416536611897, 0.020042725523272832, 0.08715466686314152, 0.0956650610051809, 0.056283725200281035, 0.04259486014263765, 0.04434825537065345, 0.07974774576723576, 0.11692131959622908, 0.07566722440383128, 0.04403571831062437, 0.024541297236517556, 0.02225994293938481, 0.11546421270336836, 0.014229839002983946, 0.04097850655295676, 0.06604057886908132, 0.055497967968544656, 0.04358424354464777, 0.03915939247235656, 0.04995382796492308, 0.04962607256827816, 0.061060287238609415, 0.06603936078928171, 0.02807500610698856, 0.024429367960340554, 0.03366539292337914, 0.05807314571293612, 0.06619948082633557, 0.03480867189805835, 0.03999340558244337, 0.009985056897294859, 0.03148402459168386, 0.04061818092821106, 0.06677630672892255, 0.08803881659743287, 0.04634740011345956, 0.03280662751245884, 0.06535892915581504, 0.08564476885141865, 0.1843549374250635, 0.14626858515604851, 0.15419658393629138, 0.16672221342882804, 0.11371619924302064, 0.08973948582406006, 0.12178167250127563, 0.2164649765097326, 0.0791836292633126, 0.10359837643561826, 0.08012128257823568, 0.2883824916376222, 0.14193142433801006, 0.14144356422606977, 0.19067189926581998, 0.24211522432104235, 0.16266308124026946, 0.0742062564278322, 0.21282661045270584, 0.15016008198501604, 0.15220017412737494, 0.14171583187435904, 0.15211742130979417, 0.2378486814878641, 0.11987907781956658, 0.13037693386356677, 0.10079228063865055, 0.17669442590446244, 0.15130984206353465, 0.11649728226926058, 0.12174791100645259, 0.23169817523129527, 0.10296973234583294, 0.1753401509936779, 0.21001997073331188, 0.1338248964278929, 0.1782840736691029, 0.21574624814093116, 0.2827044624474741, 0.1163459262780605, 0.12552489301249867, 0.31627884795588834, 1.8099660714787824, 32.64729311389308, 90.52449103324645, 116.62056107674877, 103.21571196279218, 93.86758988903415, 65.89605423711961, 76.73060555611887, 64.11729858767602, 37.1563773001394, 35.131261502542806, 61.03997953476445, 89.62007876365416, 118.84205818176271, 86.44437882208055, 48.31980759097684, 54.62122471101823, 47.034305680182676, 29.94348764419556, 14.365447375082201, 2.1029054685946433, 0.6215086242844982, 1.5146829356108944, 0.6874190907805198, 0.18919321167613232, 0.28076932435074164, 0.4558977286421484, 0.9405846124695194, 0.48868834491698976, 0.3664326018864109, 0.5510424474073995, 0.7022482240872999, 0.31601182034900116, 0.24821106254333453, 0.4422632328444912, 0.9602262488295956, 0.673413532635858, 1.7675841263225003, 1.9643532580906347, 1.3369972378976884, 1.4466304259915508, 0.9558314169126173, 0.9755539521574975, 0.9971838011857003, 1.3237816696205449, 1.396614077591127, 1.259007648594918, 1.8632220524934031, 2.7984024968839463, 0.5950953835441221, 0.936390066579465, 0.9176463465536795, 1.3873305628376624, 0.4617781276183744, 0.3933552604529166, 0.6508237447950148, 0.640435163532534, 0.6086202061945393, 0.7163416678386351, 0.5566140516631065, 1.3625049014245312, 0.6425061749835169, 0.876491490390993, 0.5149297981012253, 0.5239622198766278, 0.11357230494820303, 0.18589498865748608, 0.5730084558167766, 1.8224323444789456, 5.302971418826811, 28.640368407772435, 43.340405725663715, 49.44783810646304, 68.7908967848747, 72.77091010924309, 96.66427904559721, 87.74834725164598, 50.46080589294434, 43.97688481115526, 48.02374709037043, 55.11019914380966, 78.68175721937611, 77.65575147444203, 77.91946026586717, 90.35276182236211, 108.70135845676546, 73.6101718102732, 15.592932528065099, 0.2579256856153088, 0.4169902986576481, 0.11777576810169606, 0.16159477162986033, 0.23746186837313638, 0.17490076892558606, 0.14673732371339876, 0.18648663836140789, 0.24807333525630737, 0.249442410985789, 0.1569575801371567, 0.10373374417183862, 0.09357074515954142, 0.1917945245100606, 0.2252453400362884, 0.10272821546682429, 0.14931747719885843, 0.1231851532394367, 0.11586447066116719, 0.2929969456407332, 0.09872424926969314, 0.17651234212661945, 0.16342460328052122, 0.18430252168928424, 0.11825849542454367, 0.1477715270894189, 0.12386539335092231, 0.1468625944107771, 0.2520382845954549, 0.20070302390283157, 0.08549173512766439, 0.19295856446748783, 0.1449295247514402, 0.13898025447082135, 0.1631529331808129, 0.12281461183222071, 0.08612170454955871, 0.19607416744674408, 0.13756118384340119, 0.1570209049649777, 0.16773902660896703, 0.17710869561039633, 0.17280705062852753, 0.2164871164507443, 0.10960270545535511], [0.014192243238099882, 0.0025144296054232626, 0.025645063311282187, 0.07211007132765747, 0.03654682963726021, 0.05940055392021614, 0.026984319068311204, 0.02103394562108142, 0.019276725699103648, 0.04139104873062142, 0.03550310378834125, 0.015400151305291203, 0.029298410217668262, 0.09122860753127644, 0.04132089805939505, 0.025402110017415498, 0.05006232133675968, 0.06563875809191697, 0.045564845129246676, 0.011693571821876593, 0.004958657307490226, 0.044521218871757876, 0.05184950104223625, 0.02767862646930641, 0.09868696377041841, 0.04046042427240361, 0.021804350450815215, 0.04565958722284244, 0.010133791910184008, 0.06799531349491689, 0.06902037744200037, 0.08366788662369214, 0.03298545541662363, 0.018930155183038404, 0.030522417622588338, 0.01900792651389155, 0.0524943670438182, 0.039928981418451, 0.11408492502185608, 0.0829519544758143, 0.07977338673006143, 0.37979725087361954, 11.853515428881492, 53.997050100757235, 80.61346961605935, 89.92669828476446, 73.38563965212914, 70.79114083320864, 61.314129675588305, 46.21279662655246, 28.51442110153937, 23.85551610300618, 39.525237852527255, 78.63344930833387, 80.8665801632789, 69.20878610303326, 39.66299149297899, 25.242442661716094, 31.503284823509958, 14.063426832998953, 4.804418558074582, 0.3961324211089842, 0.2626380150116259, 0.031898116182175376, 0.10504339446103382, 0.6305289725142141, 0.20721052713211507, 0.031418165928053285, 0.1663289498537779, 0.014623821743073003, 0.1372625168052412, 0.10973192916642274, 0.10296224766681272, 0.03134906096684356, 0.06464357157388041, 0.07550447668519712, 0.23137981973348126, 0.26323203958811303, 0.06028733516652739, 0.14070203708064172, 0.2952387946988306, 0.07987712269588824, 0.17603618783816216, 0.08593562945363023, 0.260900343738256, 0.2505581414387111, 0.21647545659253675, 0.05991075315602845, 0.1263788818652111, 0.29960981660312225, 0.07001197100767205, 0.02926010965189386, 0.3018439434949429, 0.09001426624074098, 0.08946079835896531, 0.06109372697650425, 0.0784968774044706, 0.04518584994178626, 0.09515280099285227, 0.08634284348978151, 0.05483868036178812, 0.06952690711665539, 0.050386828520605643, 0.15596008769446806, 0.09063147263781679, 0.08461181419871508, 0.08075070041682451, 0.09445108743684907, 0.07958410172573022, 0.07786136916688374, 0.049513813874293724, 0.04530435608279321, 0.02140323638976101, 0.522603486334124, 6.558319128328755, 17.47098788138359, 29.238757356520626, 42.88909781363703, 45.565378050650324, 62.124789453321895, 73.510512228935, 97.84595581793018, 40.931823330540816, 22.997444675814723, 23.397353849103375, 24.007347130006362, 44.29587941015921, 49.47377674041256, 60.73935731764763, 72.35084779800908, 68.09454271870275, 34.295196533203125, 4.16335863451804, 0.10634709224705735, 0.06258769802028133, 0.06749197840690613, 0.057425529455706004, 0.07486120031605806, 0.04329358212529652, 0.050162491163298975, 0.022708587010481188, 0.03984066297210032, 0.057584293517133886, 0.03633405637717055, 0.04711861316595347, 0.07714525315790408, 0.023124794918863524, 0.06140314222824189, 0.06942176154904789, 0.03985597323926707, 0.03773847174259924, 0.06330085692987328, 0.023550630637234258, 0.03515371023827503, 0.042853732743570884, 0.07211572505653867, 0.0459512866913311, 0.021725173348621018, 0.08829812969892256, 0.014735802730184891, 0.02645279960556617, 0.048218937590718276, 0.012573017776312848, 0.05173795097958177, 0.014059014802408076, 0.024811643919336702, 0.051569718071409774, 0.014304445433099906, 0.0200368496288936, 0.09820248976710344, 0.03253219183534384, 0.02295649880843778, 0.03313070951750682, 0.09228380171642189, 0.03310358617454767, 0.053511287476266586, 0.011687157750730554, 0.030797412543888056, 0.011596184809722248, 0.07635373111453748, 0.0008210811269706146, 0.11016784851709682, 0.03645075838111582, 0.050082025118172176, 0.05509830755932678, 0.02662042730427798, 0.03147878071984216, 0.047066090177864804, 0.022708198220859614, 0.08426844593017332, 0.06815095957849296, 0.05995381112781264, 0.0405528451195888, 0.03817277464775309, 0.010857873318356373, 0.044749762051768845, 0.022852387459528063, 0.045735445249104695, 0.04518013875631075, 0.009702459510956562, 0.0457518586828824, 0.04921389811281716, 0.020539581422663985, 0.01869739468900427, 0.05246371586596774, 0.012848151551048844, 0.02548778929086703, 0.009800490994577207, 0.03585191128114539, 0.019140440572593963, 0.019257073628626043, 0.03020632016893116, 0.0535595050502208, 0.014985994597326123, 0.06462697044856126, 0.05011389437582224, 0.027578780314915126, 0.6776626239861212, 25.859702133363296, 80.29745209601619, 96.39966810903242, 104.54180256012948, 98.91368773675735, 102.76029340682491, 87.47859801015547, 49.607211851304584, 23.87824231578458, 17.915698366780436, 16.893628720314272, 46.00485217186713, 63.87245639677971, 66.7337626795615, 43.97846160396453, 22.75098450722233, 18.285956382751465, 6.31469238188959, 0.749560649837217, 0.12732320780595466, 0.21293870443778656, 0.038030458494059505, 0.02779782975032445, 0.5939194079368346, 0.11713955506321885, 0.20650111439247287, 0.13560526944216222, 0.08621047881822433, 0.17073927206858514, 0.07856105258988758, 0.17561572814180007, 0.030412591257763487, 0.07395717826101088, 0.10921881879649817, 0.25577198263377915, 0.3261446508188402, 0.10097857023919783, 0.2506528145843937, 0.20587220217191404, 0.06488612267158686, 0.1173790647918659, 0.22297827136372367, 0.17233671860829478, 0.15145426495902, 0.09959089389491467, 0.04505907771207633, 0.13018850687771075, 0.16370217225724654, 0.15029635370498703, 0.083411178221145, 0.243328309227382, 0.08632261876858051, 0.10138144055681844, 0.05217791910493567, 0.052399326175931966, 0.114176832590132, 0.12712584823490153, 0.07123293895875255, 0.1593888367736532, 0.036661761978100386, 0.04373139754358319, 0.00666983534521874, 0.018385801832341862, 0.14176138346233677, 0.10845533557116024, 0.12977765392391913, 0.03952743260249977, 0.03257119720200858, 0.08315586409862004, 0.0065576211800948995, 0.010097207381359993, 0.14291290554308123, 2.885039564101927, 15.01596168164284, 30.766840211806763, 46.84085438328405, 48.64925530649001, 56.84786796569825, 42.86384951683783, 65.43921578314998, 24.62910556024121, 22.587631517840972, 30.961358393392256, 40.019562398233724, 78.46188483699676, 77.02140223595404, 77.34599405719389, 80.58298495508011, 86.02037845119354, 55.45828988475185, 12.015633852251115, 0.22206673398613933, 0.0535184657201171, 0.07268389416558128, 0.05415552911619025, 0.06701001717198281, 0.0626243093621827, 0.0315019989296073, 0.02800398975640776, 0.06691925107471405, 0.024998781962260127, 0.06379737000491831, 0.040821347445730245, 0.04667608630693248, 0.014704491759109643, 0.028326129728567698, 0.030293878273016987, 0.04881348310699386, 0.03087441587159711, 0.026113307741921277, 0.03418331815590782, 0.012289098888305167, 0.035966920230778, 0.02735490069514321, 0.06857714195164942, 0.04336809566725166, 0.0693067028037002, 0.03615000758380179, 0.03147745921817278, 0.08025853489074977, 0.07807750555296099, 0.04240966221738247, 0.02614585307216452, 0.06970542858565046, 0.02034129488522247, 0.04346857575940029, 0.07524645061142023, 0.04381170271024589, 0.012843806874908268, 0.0333752715960145, 0.03140649840896649, 0.012581001370093756, 0.05386456126166929, 0.07494059000765124, 0.10622028937383045, 0.17727113689386076, 0.16033915352196465, 0.15561225313332774, 0.20175167569710364, 0.19269734380706666, 0.15227908118357583, 0.20054234462159298, 0.13765843104450934, 0.09779535233974458, 0.13928852825155183, 0.10929908182832504, 0.2017330904040606, 0.13101657131506553, 0.11524022391606724, 0.09976357011304748, 0.16575182517690046, 0.0853701799567188, 0.18828198073371766, 0.10758904334638389, 0.06532200371786472, 0.1793261064637092, 0.13362508537548204, 0.20831084389600063, 0.22617437486206332, 0.22518523277774935, 0.32504301638372485, 0.16513547679829985, 0.11051973568335657, 0.11895663901081971, 0.16162873996842295, 0.20425989352647336, 0.08991388574002251, 0.14499750739384085, 0.10849990656659489, 0.09806444072314809, 0.22639413484402243, 0.09933041633978006, 0.23168843059289843, 0.1732384960257238, 0.2219363304996683, 0.5866931763387496, 21.40315809557515, 86.54270479756018, 113.15476263723066, 111.62475585937501, 92.458509783591, 94.67024018687587, 83.63163932677239, 56.863529989796305, 35.13308932704311, 35.67174842280727, 56.45258718921293, 94.60351282550444, 99.73770710729785, 90.72609301536315, 54.61018323898316, 36.26733679925242, 44.12071420300392, 21.261217324964463, 6.645540383554275, 0.7563401602448956, 0.46449982350872415, 0.24063624561794345, 0.31814123834333113, 1.0574854621964118, 0.700326262702865, 0.48771905983167313, 0.432194447325122, 0.18348092303401042, 0.3764563414358324, 0.27370409379082344, 0.3010940966346572, 0.13739563224296417, 0.17337731115760344, 0.380505851560062, 0.591448866311581, 0.7524101904803707, 0.2946686107785471, 0.5387010160953768, 0.5329057754528138, 0.34770457134131466, 0.7844055155592581, 0.5087066207441592, 0.5007867118523968, 0.6563879333196149, 0.5478945001959801, 0.27635904810120987, 1.0894433408975601, 0.800833014711257, 0.40011494450511476, 0.3739760551721819, 1.1344717827535447, 0.5381933755932317, 0.2816778739854213, 0.23715288979151558, 0.24271456554772394, 0.32740688792640166, 0.2480899133989888, 0.1860003563905916, 0.2897017256867501, 0.12543542160382196, 0.19181418232619765, 0.3646515393930097, 0.44844225289360173, 0.3054112472361134, 0.29842866224146664, 0.3592892610017331, 0.22323258191106782, 0.24422530625616354, 0.25263672183838587, 0.22888361416276426, 0.14109404427149605, 1.000220573717548, 11.650808318968743, 29.670147472812285, 49.38946539355863, 65.84478101422711, 67.4042683262979, 86.18032486208024, 101.03805126682406, 115.7938588050104, 55.183280744860255, 33.72289134610084, 31.662795851307532, 35.6895246044282, 61.50345856143583, 70.86192392533826, 77.12121871209915, 91.27284003842263, 95.08865510263752, 55.236872088524606, 8.624766411319856, 0.21847765802616076, 0.2761839816887533, 0.1281472962469824, 0.20758074678240285, 0.13967413094735917, 0.14526378423456224, 0.25494129817572336, 0.09051606915290318, 0.1330217604915942, 0.14355661858233715, 0.16711008374489125, 0.13942095421014294, 0.22937970205901131, 0.19334415184153667, 0.20305393323782953, 0.1556871458888054, 0.09255894219442722, 0.15691801935674685, 0.2774122044924767, 0.10882671201421369, 0.1350819701028447, 0.12753945910522055, 0.143306031222305, 0.22676348115407655, 0.12435195111339131, 0.1728524183554034, 0.16079889820708385, 0.05778565589759139, 0.0951381304091023, 0.11483481018653802, 0.11543580616313605, 0.09908183613010954, 0.1624494652834631, 0.13100601462346892, 0.14576263004733672, 0.14934680304459988, 0.16094241711881854, 0.09815933603432872, 0.1119512705613048, 0.19610631249604688, 0.16095081344246864, 0.21341796904321642, 0.18677133195582898], [0.06043796337419941, 0.026228784005187696, 0.09732815361912213, 0.08261393350098403, 0.015010485470655465, 0.023149012873369842, 0.06290392762410545, 0.029346528200192318, 0.03936740832643644, 0.012041937856514369, 0.02786337431790608, 0.05118144555918632, 0.07254332469235505, 0.036121447825984615, 0.03643807196508973, 0.006430161865277877, 0.009495095789222228, 0.05194042035708985, 0.007505038764417893, 0.08860171502155643, 0.025672297736990358, 0.03776438849707765, 0.025821774897556153, 0.015576396535541263, 0.08091817489795147, 0.028236321241204298, 0.08621085420130722, 0.030164576037937117, 0.029109234380866253, 0.05166147625254047, 0.031593992682774706, 0.09249531093143648, 0.06782894984128014, 0.015746519765666416, 0.05213422144973471, 0.018390373462030006, 0.05527078076415966, 0.048783084738158414, 0.09196952946724431, 0.12907836886663593, 3.6321733699690912, 33.837098998408166, 75.01132088322794, 85.28576558636081, 74.9494807950912, 66.35777211958363, 52.74364102271296, 37.993838633260424, 32.78452115674173, 44.36328534157046, 87.7163956242223, 145.14479790964435, 117.50205101505404, 70.32545351213025, 37.46831947757352, 22.208699180233864, 22.25229436351407, 27.809255430775305, 6.128092485089456, 0.012165172675233937, 0.19926480107730438, 0.06166953781259157, 0.22965681138298205, 0.10237327160974664, 0.0654155660360571, 0.20151749794040957, 0.07738422662500413, 0.03749038182920025, 0.036412224158524506, 0.03677472164253554, 0.20907892364888422, 0.08580333372998623, 0.043013320349517374, 0.04090158749491938, 0.16317426106862484, 0.07566536281017527, 0.1413729462412096, 0.5482741120842196, 0.1526919259659706, 0.2442186106477053, 0.3215452121390451, 0.27217461457175596, 0.35012283512661535, 0.31341355654501146, 0.2856502850209513, 0.27093474723158345, 0.4545698224777176, 0.15751297856050153, 0.19689106232216283, 0.18458491701993252, 0.3053926466213119, 0.18010725567658104, 0.1688736334683434, 0.07409548011398123, 0.2383841003381437, 0.130341571244982, 0.11021389806222533, 0.07378657048027362, 0.0732707864634933, 0.10957264416520635, 0.08596647215346176, 0.2464937079217165, 0.07430390965554022, 0.16101553255031187, 0.23550049942587656, 0.12346851384086956, 0.03448977630825774, 0.05671282253798939, 0.04494337928331187, 0.0281630679138846, 0.07017697102480358, 0.03441034065138909, 0.11558045888499868, 0.0835210505512453, 0.27447493146023444, 0.30316740634941286, 3.908678648933288, 10.57059149588308, 27.728964513347997, 37.41926631619854, 55.27881007040701, 53.149253322232155, 60.50929853993078, 58.775599156656575, 31.730823478391095, 26.44762423730666, 22.11398570768295, 27.918383613709484, 48.885456515896706, 56.70832964681811, 60.88544599471554, 73.63114864595475, 61.7334859601913, 25.265480702923192, 0.5574767279528803, 0.21293090566271738, 0.07005047458674639, 0.05124496956986766, 0.007969172175733313, 0.14424307932776792, 0.03198071961261092, 0.061188396291747216, 0.03060431242169392, 0.03279944160772908, 0.08654394923078437, 0.005328773057103278, 0.041484396544194994, 0.021192973982843182, 0.04383496880050629, 0.057549516955811175, 0.019412279211645646, 0.03328303077949151, 0.018827493655525388, 0.022402833659021605, 0.03680069202316865, 0.04230231414699266, 0.016863303589484385, 0.06979193523406022, 0.13388103535098414, 0.07632052886389917, 0.04610217153845776, 0.0264825506301056, 0.04131070142912288, 0.0626685509398099, 0.03740356874562079, 0.003815214820919679, 0.11234304026490259, 0.015200402497524216, 0.04703515937792198, 0.13212085641439886, 0.08084812381815526, 0.04300095185997986, 0.03962967086643462, 0.011140980153164316, 0.01606719842511079, 0.0329773616977036, 0.04660117056881709, 0.08303492179801387, 0.052389462793906855, 0.0700383244322673, 0.0962842898743768, 0.09730648865262348, 0.03423422086803663, 0.027427322817065065, 0.0334958270222189, 0.03399089602152667, 0.008415895281359553, 0.01961850433520252, 0.026610853120444283, 0.05119296369112788, 0.10829389020199738, 0.018722399798852783, 0.04804858261899603, 0.07844711999378859, 0.04387677804897389, 0.04095867636703676, 0.024553215649399548, 0.01939639437853569, 0.032759834862043785, 0.02780981519589982, 0.06929144999312778, 0.06953563285811294, 0.04207285549191218, 0.03173736795302361, 0.04060766254101069, 0.04417356817171939, 0.004468057473610726, 0.018747945000687917, 0.03670914068577751, 0.032905747798541864, 0.09281501474399721, 0.018573451238954743, 0.03299475572402439, 0.062023623651194, 0.11513805076960595, 0.22168977276211788, 11.858054591763405, 57.33970965108564, 93.71760629838514, 98.14894322426089, 93.21245993337324, 88.51214255056074, 83.26222265920332, 56.010492924721014, 55.36399610580937, 51.206754407575055, 57.498283232412035, 102.93756884913292, 88.54358426986202, 67.7604587616459, 41.06048099456295, 20.63083556390578, 11.235019430037468, 10.940456294244337, 1.938194971411459, 0.18793794596868177, 0.10044194096999784, 0.10673112446261991, 0.08312160464664621, 0.06087392485970932, 0.06659968515797969, 0.170877811408812, 0.056669971409944765, 0.02496123407787133, 0.028515182991301822, 0.08023709208974916, 0.11759285694889485, 0.16440056865253758, 0.15840597661031833, 0.060780745585479086, 0.1596635405815417, 0.16614654431900672, 0.180096622376192, 0.38682019338011747, 0.48714207305062207, 0.46429012992209007, 0.2083927540168647, 0.3539989948753388, 0.5149176019814707, 0.549292518727241, 1.1664567503236956, 1.6309527740363152, 1.3297890246875825, 0.8522140414964768, 1.0421991276164209, 0.7341127013487201, 0.23114228651167887, 1.3528461874492708, 1.0700505298952903, 0.2760902738138553, 0.7947755881374883, 0.33794317094068377, 1.4552847680545624, 0.7415344385850815, 0.1891784261791937, 0.18639640852568612, 0.1271614253581051, 0.23371902324499624, 0.07436916502493043, 0.3855801421788431, 0.3686476378671585, 0.17906009009288204, 0.13142653560686496, 0.07919594795713503, 0.09746193555333922, 0.06776055351140038, 0.17828848633554675, 0.19013180727920226, 0.1426982783502148, 0.061923607042239565, 0.3144370806553672, 0.35661794305328404, 1.526611353601179, 8.730439966724767, 27.168820634964977, 42.82170364933629, 56.18015504652455, 53.74707744967554, 40.97330631748323, 26.976804925549416, 20.327612815364716, 23.68183159059094, 27.872988062520182, 44.26978388140279, 73.76362277615455, 84.99800482103902, 79.44725482694565, 84.0570439061811, 80.30495166778564, 44.12562501045966, 3.026250283564291, 0.24196663390724893, 0.03932832635097927, 0.0816414078637477, 0.0587861858788998, 0.012996718982204556, 0.0073476967536994535, 0.041405826566680785, 0.06289197665248668, 0.048634306632823525, 0.026827043132676233, 0.06044364774659757, 0.05569101446458409, 0.025460436121530594, 0.08468175802620188, 0.1024921531338365, 0.02193891954037451, 0.03937637538559014, 0.008247192186724034, 0.07218609023238383, 0.05031351007581238, 0.06901963433671383, 0.008946524166892613, 0.04275302282504497, 0.10849439073354007, 0.031651409057479714, 0.0345450189084776, 0.03257102866266524, 0.07924467114911926, 0.057833413818791035, 0.016485055337750142, 0.012710445331439618, 0.05225538974627853, 0.05260149677914958, 0.0439059698293286, 0.03051966162128074, 0.05876705283299089, 0.02852877913673799, 0.07448377943928204, 0.02651562264579679, 0.031268298062646104, 0.1343982213086659, 0.1680754004947601, 0.1745043337465294, 0.17207054901988278, 0.1643536074627792, 0.1525959811143337, 0.12458005379284583, 0.12599909377674903, 0.2000142189283525, 0.12801353729540302, 0.11412767272803093, 0.1220472445411067, 0.08172654321477299, 0.1338460557763615, 0.17580901212509603, 0.24260691487260405, 0.04796894777926707, 0.12310770941117119, 0.23521215925293587, 0.21023216176657908, 0.1694596447651425, 0.15664458725481265, 0.13467681684320973, 0.11624569899492687, 0.1332390689921956, 0.1551966351126471, 0.09890739024887163, 0.1384995802636108, 0.12901101441633317, 0.11879909302919142, 0.1382659081249468, 0.09084338021855201, 0.2530843623343014, 0.3383908420801163, 0.11978114880020581, 0.19991482668105634, 0.11232481503318395, 0.16464591597116765, 0.13122065713809383, 0.24228577081474567, 0.19901023006006596, 8.847501143332451, 58.380008512927645, 105.94175138781148, 107.79884461433657, 94.20645913770123, 89.55479483450614, 72.83302476329189, 49.54650140577748, 43.94667471608808, 63.69323153649608, 107.77320800289031, 156.39208455239574, 138.87545401050198, 97.28936364573818, 56.6937227402964, 34.03175446294969, 32.67514978685687, 37.84145455206595, 9.610961079597473, 0.7566969733565085, 0.4190668872287197, 0.2092305630926163, 0.7686825721494613, 0.3413855717066796, 0.23234345108991672, 0.3091295622289181, 0.16079496051515305, 0.16291800465795303, 0.27960002903015385, 0.33868744068088075, 0.5378045706499008, 0.4306792479849631, 0.42198935944226484, 0.25777133422032483, 0.4387572161372631, 0.3475644385382053, 0.5158441393606125, 1.1969059873973171, 0.9865368337881182, 0.8362799029677146, 1.1114914739324202, 0.9654768316015121, 1.1819259654129706, 0.9390140096506766, 1.5863582443806434, 2.1064618326002553, 1.9950682357434306, 0.9916030651619359, 1.5714259037087042, 0.5720176283390291, 1.5021498597437337, 1.2723743506977636, 0.928140709236745, 0.4471865734986721, 0.8105964069404911, 0.5233960502570676, 0.9482494753695304, 0.5418607917043471, 0.3137418405423242, 0.28717936587429815, 0.813695753533994, 0.4034923503716146, 0.25782355077324376, 0.7214637929874083, 0.8098278062478189, 0.47336726058875367, 0.28488971292972565, 0.19627806940867057, 0.29360705806363013, 0.15057516374414967, 0.5870015726935479, 0.478607363277866, 0.33712336493115275, 0.1658607935232501, 0.7106905742999047, 1.166862102766191, 6.577038149679861, 19.19351439322195, 45.3210340007659, 58.057158224044315, 77.53691150296119, 73.28938468810051, 83.61117239921325, 77.55598206673899, 50.16340786410917, 41.21464190944549, 27.259331287876254, 37.70179071734029, 64.74472876518004, 78.48947478878883, 79.75389788227697, 95.6757946937315, 90.69765583161386, 40.917255647720836, 1.6656417255440068, 0.3820187219929311, 0.18477320610996217, 0.19037490229933493, 0.09992709924136439, 0.2292790074622439, 0.14813111343931767, 0.12286758681218471, 0.15242451531512125, 0.17214075331726383, 0.2152422542173055, 0.13851720028586928, 0.1771126792676026, 0.1761498446426084, 0.16400016513803314, 0.2048140508873809, 0.09131544359749363, 0.1572355474796026, 0.06352979464516526, 0.13838008586918155, 0.11697195800802401, 0.12922810841231577, 0.26244060947529735, 0.17475648392592708, 0.24962945901338132, 0.12824586878019956, 0.25987635997514574, 0.16289355113141, 0.23026606578740383, 0.1357798762018642, 0.13102125977316212, 0.07580069990287866, 0.18699000409293562, 0.125944571299178, 0.09697307186621813, 0.20960263667568085, 0.1927903622028328, 0.15226300865892442, 0.10844320839931888, 0.15271771248550187, 0.12498065649021058, 0.14445568404851422], [0.05946032793050813, 0.029851004759210254, 0.008380333479914454, 0.07518304917480677, 0.04308165922280281, 0.023539888169316035, 0.04686031513096345, 0.0388093822215113, 0.05567763090854692, 0.03830451112721236, 0.026703578487579382, 0.04177563635992908, 0.039516339649356184, 0.08827503214800551, 0.009057142475109187, 0.033702942722987746, 0.045403851751959136, 0.032338517147206494, 0.019428876506525184, 0.01681502472849623, 0.020940295202777754, 0.09185354375550825, 0.08605556051817634, 0.027035593333083297, 0.02259087377047587, 0.031867658441525795, 0.0791765965761677, 0.02965272013698855, 0.0083499523480573, 0.049317136121493195, 0.08376818285473893, 0.028070317648891962, 0.055767033369310444, 0.0594344609717448, 0.044499101913383896, 0.03129891859697959, 0.012152551376681415, 0.1482301226426517, 3.098848942787417, 30.384981786051107, 74.7652078443958, 97.78475899850169, 81.63334077404392, 63.08488761225055, 72.42173287176317, 49.83088108801073, 29.161459207534794, 38.82510654387936, 29.749375427922896, 20.198492311662246, 56.8118723746269, 123.60904801276423, 50.02773700221893, 20.259810724566062, 22.792718525855776, 22.454906355950143, 6.8065659365346365, 0.05054947281737001, 0.4390104541615133, 0.11033509317184649, 0.09473463956026301, 0.08675902841552612, 0.10164649931774025, 0.05806259668221878, 0.04917623340001991, 0.24938798809964813, 0.20178124669098085, 0.0839798835917346, 0.13454926320381705, 0.024482800677839308, 0.11331636263358016, 0.07562235463410616, 0.07115325049286889, 0.14018520352340516, 0.2410384417781907, 0.13247549383630677, 0.11425433770543146, 0.12196580939475568, 0.07505824579106224, 0.1357435942777703, 0.2196458195366206, 0.014394646540524499, 0.09200243294359216, 0.15548617038274967, 0.06663834195463889, 0.14662535230238594, 0.48412705741582385, 0.49020924395130533, 1.3310922321773346, 0.11243837990707929, 0.18546950342434068, 0.06892924362252797, 0.1292921686845441, 0.6029947306359968, 0.5068718095219905, 0.23628379368493635, 0.2017625694673869, 0.026408000698974057, 0.011597384694933651, 0.04570529585884464, 0.04593833214453152, 1.0342345098333976, 0.8057367741580933, 0.0572030307094176, 0.023435223321881027, 0.04785734792089751, 0.01652925861098113, 0.010991127609515624, 0.13312150513933552, 0.04094496339319214, 0.06720760656941323, 0.04742646176788596, 0.1023001331956156, 0.16576233590322156, 0.18015472248436945, 0.051085385794360796, 0.114745392404016, 0.2685634293142827, 1.1794568333894977, 7.9886290623295695, 23.97834316376717, 37.091254188168435, 48.35005298737557, 64.41683038588494, 55.3301578183328, 61.0630234595268, 54.37974399135959, 29.71100876408239, 36.30085345237486, 31.303755814029326, 47.97527443978095, 57.20794154751686, 70.3999314769622, 75.63467964049309, 51.10123088282924, 7.209419829230155, 0.2177455231186844, 0.02056545795752637, 0.042294289375985825, 0.06796489980432295, 0.02976195086845227, 0.08448001643222186, 0.03949052631674756, 0.03834998610639765, 0.09847527835518123, 0.04635037253460577, 0.025467277286694418, 0.04654880079831328, 0.012180299081298853, 0.013326997680950069, 0.13271184728270577, 0.026258182629281958, 0.02250160920553871, 0.030429688425013618, 0.048839189187293096, 0.02824801557336844, 0.01570674352302787, 0.049567191050417965, 0.027638127231189323, 0.07008166202614385, 0.01956453918659639, 0.072590239916838, 0.03974402481089196, 0.03781108921694179, 0.015323129782993949, 0.09591271424846304, 0.014684857883220239, 0.05776842658017432, 0.05632789782999505, 0.014127260787532696, 0.02561734433496191, 0.07182908559878988, 0.04120152623903367, 0.09612400895885884, 0.04848997949832871, 0.045108662752975384, 0.03934950102120638, 0.019685088867141355, 0.04729620000768093, 0.05367998003719315, 0.06584089039073837, 0.044892783006352764, 0.016023993939011088, 0.040802168434545885, 0.05534381192598132, 0.020595132373273373, 0.027187518144567168, 0.02548063977531368, 0.018705273903305494, 0.07308049022310203, 0.06232730090437878, 0.026343994052900423, 0.03426448134104571, 0.015628649477636623, 0.03983523906959642, 0.028652033107655666, 0.022043375628850153, 0.04696486698042962, 0.08956268805289462, 0.09245246363383147, 0.08043265135418023, 0.03302840996653803, 0.013102773321612228, 0.07234825572419552, 0.036290944779231664, 0.09516152673430982, 0.011939483172740909, 0.05041336963674234, 0.007588540911749607, 0.040681651312737696, 0.03137848640401517, 0.09236943502459796, 0.007181718059244656, 0.14352297200070274, 9.45177855030183, 54.51173959239837, 97.54098369229226, 115.10048574016942, 97.08154862926853, 87.48669378219113, 101.73959855110415, 79.18982182779621, 44.79606397690312, 41.157422373371745, 21.27915628494755, 12.86329628959779, 50.727048535500806, 107.13430881500246, 52.38810170081354, 21.00347249738632, 18.593034821171916, 9.353093677951444, 1.7742248215982992, 0.32769512084703295, 0.20246813644564923, 0.038251382929663506, 0.09777242332817086, 0.046001775715980804, 0.19162022418552832, 0.1776110654276225, 0.06822156990247388, 0.30844032824520146, 0.18238402302226714, 0.23204934993578544, 0.10621137211039182, 0.08991695009171964, 0.2092857214231645, 0.33104197512711253, 0.6429962873939545, 0.47343979379342455, 0.5338271647211045, 0.6212693597039869, 0.8055893788414618, 0.20110344273909447, 0.18567924297625021, 0.15242655310899983, 0.43490547927156575, 0.2097725243337693, 0.3780635632574559, 0.6274776749553219, 0.8267610460039109, 0.8240411887245794, 3.496480444746633, 3.8996299860938906, 5.644956500299516, 1.2496798846029467, 0.44141587831320306, 0.6255239668873049, 1.0156300339487292, 2.0025104428491285, 0.6547592303925945, 0.6531546132699136, 0.4260586039914239, 0.149747543637791, 0.11945677951218621, 0.09930699703193481, 0.03448586159896466, 1.3728057809414402, 1.5103427104411589, 0.05230624649313189, 0.06359469378367066, 0.061253169025745124, 0.022413556974741723, 0.08523265951343122, 0.09481730044729288, 0.10305525840169961, 0.08491904609986851, 0.11749318124906671, 0.18591812451279935, 0.2070054300730267, 0.27448556476062347, 0.08620084909301612, 0.178357970510279, 0.6578002317297844, 0.15016208913537765, 5.49686300177728, 23.92456746870472, 43.523894202324655, 53.50198814945837, 50.71619925960418, 38.54559452302995, 40.21539457382695, 28.77395452991609, 26.112722466068885, 45.170250246601725, 53.92469021581835, 75.42957105944234, 79.77572979465609, 85.60663115593695, 89.08274542900824, 73.66010358256679, 17.001335044060987, 0.13004400737343297, 0.08844001684337856, 0.05632370349860961, 0.13801564252184284, 0.12013632248366073, 0.032494871862112515, 0.04348066462684543, 0.06232108027043362, 0.055082886209411014, 0.03706144153951638, 0.02307900201318966, 0.06662305083967025, 0.04092228719063344, 0.04209776484077016, 0.07848478853702545, 0.03728980851930477, 0.05373704209623318, 0.0615688355549449, 0.0311121616827985, 0.026737265288829807, 0.06638740219416157, 0.01968829686032428, 0.0228739604954758, 0.04316438139686662, 0.008497911696923117, 0.002243448745444297, 0.11228576753168337, 0.03492054371764103, 0.018366586431981097, 0.07321732118725777, 0.026670471997931603, 0.06164583888265395, 0.023245882776175297, 0.013841601922326993, 0.056514344478566805, 0.04386739730234108, 0.051810277340513085, 0.05817960512133376, 0.0976368410873317, 0.06225799676030875, 0.15271561340458933, 0.08730580068884358, 0.12417862372052287, 0.19800118501147917, 0.15396897921398764, 0.1374871797499157, 0.12362006901492997, 0.11242435283718571, 0.14218100046198215, 0.07508975498738789, 0.09274727724973234, 0.14662689979999297, 0.13532226124117452, 0.1876484260203377, 0.18646984571410766, 0.2006369564802416, 0.21244555831916873, 0.1342107289500775, 0.12294998722932032, 0.13505984548359148, 0.14233167463492963, 0.2161957119261065, 0.177922495490601, 0.14150929456997302, 0.13239951323597662, 0.126176412487703, 0.19472513257736163, 0.16822324014238774, 0.1448644532431518, 0.2014408278609476, 0.12393054912888235, 0.12615876948280683, 0.09200962650920115, 0.2013802456278955, 0.2068321869498299, 0.21576455764232144, 0.07510473200630757, 0.37220213261823504, 8.556529918024617, 51.22045524658696, 110.73582126248269, 129.16897635306083, 101.43872922466647, 86.19337066527336, 96.06696482627623, 66.97512965048513, 39.533710172099454, 55.05002606299616, 46.0525050470906, 25.74088961847367, 66.57412221354824, 141.19304133999734, 66.77103304093885, 33.06905185022662, 34.18355803335867, 32.74689582086379, 11.174817912040218, 0.8878324721609393, 0.6204627610502705, 0.19203293107209668, 0.5899974667737561, 0.4867943304200327, 0.27571957918905443, 0.3126289905799974, 0.19618151168669426, 0.6361294429629081, 0.4911262205531521, 0.2957519203905137, 0.2643236229496618, 0.09844421348985165, 0.32771767447552375, 0.20099018430036886, 0.36122957785283366, 0.46452648336848906, 0.5830154640059317, 0.6430049901527743, 0.5933805110473788, 0.38422048933083014, 0.19797032698988917, 0.3106858238818184, 0.2952878549695015, 0.12540298544110792, 0.23131801175975034, 0.32061907312562393, 0.20880411258868634, 0.30414242177240314, 1.6599870160702737, 1.823231772549691, 2.575280921113107, 0.4374194427603676, 0.3414231713020033, 0.2853922053210197, 0.2323098045082823, 1.2815845661586331, 0.5722090890330653, 0.4652160850744094, 0.3350849888257442, 0.2361982523073112, 0.2159624381531631, 0.28568000923241343, 0.15152586353642328, 1.1988207169117466, 1.580678407222994, 0.13510032556951046, 0.20403769738491506, 0.13767246577528217, 0.14770720634729634, 0.16671760157952387, 0.39591644560137107, 0.3402447135698411, 0.22740359358008833, 0.26007842332605396, 0.4900450253438565, 0.36238131443819693, 0.48562475930779214, 0.20336255941900516, 0.44766188509041266, 1.2347110168587778, 2.7096539687725807, 14.282300972169446, 39.17496627376926, 60.02389346399615, 70.09805017902006, 92.26212455380349, 77.94981156626056, 82.70870562522643, 75.71115016937256, 46.29473886182232, 45.12065972051313, 41.688487760482296, 64.14549258447462, 74.07101108181861, 87.75748637414749, 101.27233443721649, 78.26165568444037, 13.000754771694062, 0.3109614010299406, 0.171549670518406, 0.09330821448876973, 0.24993567967847471, 0.21479505805238602, 0.23794721571668503, 0.2363532778596686, 0.18280295054278067, 0.1641318096869415, 0.20495370871597723, 0.149393534407981, 0.14066806874207913, 0.1011172321534926, 0.192936010838997, 0.24626414201432661, 0.0872865105949102, 0.1751342418813898, 0.12644249014556408, 0.1275434963885815, 0.08759833902360932, 0.12654211988011677, 0.12746328698290935, 0.15443309060027524, 0.20787501647587747, 0.17397308241455786, 0.16842787754872154, 0.26269387814306444, 0.1999698317940197, 0.07389582227915525, 0.29723206354725745, 0.09831402450799943, 0.18109713320530232, 0.09766316386840998, 0.05692912746340998, 0.13095606569080584, 0.14137100037788192, 0.08734087219401714, 0.1598742300824773, 0.1401146774690959, 0.178224349454526], [0.058123466198242484, 0.01981793234365121, 0.010498214190104797, 0.018245171072081696, 0.029922517151722026, 0.03289593038179221, 0.0366799489054228, 0.0637786468160489, 0.039684246970160354, 0.10336556231542941, 0.022311466182732297, 0.015142336863303378, 0.042661494470291564, 0.05275038979767312, 0.044812964305521986, 0.031027579830298503, 0.027446821669957815, 0.06050165592422409, 0.022052587836139628, 0.06612399818315622, 0.028984488453716043, 0.02364801190372917, 0.06396976660095877, 0.07348384317611495, 0.05312345163415998, 0.01215309817193737, 0.0395745087054468, 0.06635571679761333, 0.0685067461322873, 0.02785280230455101, 0.062049096074676326, 0.08826306585462824, 0.08696946510744673, 0.1374727772969392, 0.03674887383597032, 0.02425880231443913, 0.9645418366116862, 15.933947313216427, 64.97967481613159, 88.32633203075778, 76.18950674610754, 61.92403470316241, 53.58893532906809, 55.1080261507342, 40.52223374766689, 25.460424461672385, 38.33765006834461, 36.81952807211107, 69.17005661995181, 80.37324013248568, 40.63586873392905, 20.546890958662956, 18.273787229291855, 20.606630617572417, 5.566016349100298, 0.04191470430082372, 0.693840072039635, 0.1432509801440662, 0.28988157248785423, 0.13149030476568208, 0.017094411248821887, 0.020049017020350984, 0.08483948020805275, 0.1742301662001879, 0.05144348210324684, 0.08785350758942866, 0.02449444329906856, 0.08969749654493026, 0.08999371976261178, 0.14268001481409998, 0.1873713933051594, 0.09370807408084793, 0.10709323890266881, 0.09220842632555193, 0.21778923609564382, 0.09068876069279448, 0.06850996370156927, 0.5463039178040721, 0.4227199315303757, 0.6384182072454884, 0.5467317625880241, 7.392357212881889, 6.514932320963952, 7.508900636626829, 6.6883912970942845, 10.967561833320126, 24.946741057980446, 13.91513672567183, 15.757582841380952, 1.5860950778568945, 0.46506498189222434, 0.9154185628698719, 0.8871405415477291, 0.8822028903711228, 1.0479180659017255, 0.861089384603885, 2.7365182820827734, 1.5530918875048239, 0.11293193971317624, 0.2408341108070266, 0.29416688447517736, 2.287669696154133, 0.4566499350532409, 0.4463909452240314, 0.20160072573250343, 0.12989184698991238, 0.044835280446756276, 0.10332216343451893, 0.11583119946261568, 0.04977168673048577, 0.13667892634628281, 0.12868499803927638, 0.06651543846894657, 0.05197986239387144, 0.07782285792693015, 0.09660312800758308, 0.07701044466586844, 0.08409835908922457, 0.19669462205661883, 0.285369559761978, 0.345717461839799, 6.755873224427623, 25.808550503946122, 44.26573599538496, 50.381397508805804, 54.336107623192575, 69.73206950772193, 52.48564712462887, 30.825791474311586, 30.03626934943661, 36.51915296431511, 37.02629581574471, 49.546450414965236, 57.38089061552479, 75.36587961258428, 73.32991846146123, 21.375532842451527, 0.3744844311187345, 0.08440670947874747, 0.047950442925456076, 0.032764818263991226, 0.014867682851129964, 0.038852421041097374, 0.03375206428069261, 0.04352812760419423, 0.08252046311334257, 0.05178342595876706, 0.032168384340982285, 0.03134746558874125, 0.039054729540141365, 0.049406262790603984, 0.05370782733324075, 0.03857351141050458, 0.05349465570743046, 0.055211255732443065, 0.019714073803756508, 0.07397672116395927, 0.06178768006183448, 0.018904092871854385, 0.018452677477691925, 0.040041496751890074, 0.02518444911636893, 0.011592105391525455, 0.13202196978513273, 0.0898082881805397, 0.09760616692684351, 0.04565156628227523, 0.02936439911624597, 0.03980359197744439, 0.09339544125982831, 0.019184191853949623, 0.011321597830242208, 0.030320503658825354, 0.015742765934837442, 0.10283036563064783, 0.05033969113062467, 0.044079687927038445, 0.032641125707736904, 0.031509565963079376, 0.06584324994154515, 0.032566095056432875, 0.039498830709846756, 0.05026362626062286, 0.024967282342033523, 0.03657155895545598, 0.06068649761859448, 0.02588955835709649, 0.030956105742182945, 0.06488809151755226, 0.035159130310339314, 0.073625669033537, 0.039651680572499196, 0.0623501762897978, 0.02391256887706057, 0.04817109156940733, 0.05761735404150621, 0.015326761039755037, 0.029871329071841417, 0.059095700722067594, 0.06455022376030684, 0.09354954750667657, 0.06890053830800519, 0.07167694819790703, 0.024056363580448013, 0.06709480012256293, 0.08931717985580045, 0.04443973009925216, 0.05196193593644327, 0.04926259449172405, 0.09256562248112694, 0.0884240056057611, 0.01870357127289378, 2.03969475723082, 34.41620557538925, 89.71236428906842, 104.8187062048143, 92.45036694311327, 82.63522394241826, 84.26090517351705, 81.82596052846601, 65.92082792712797, 32.47965297391338, 28.027354901836766, 20.883475426704656, 33.59877970910842, 53.08905278482745, 42.52711011517433, 26.824728750413467, 14.793281862812659, 11.742090698211424, 1.0609886290565615, 0.5035534843562112, 0.49720439278791034, 0.2928539629905455, 0.3370132014876412, 0.22320851142848694, 0.06799943504794952, 0.046881171874701984, 0.09128197321608182, 0.33558941175860746, 0.15193282476355954, 0.16903111050205846, 0.07462630243671518, 0.03376817127930061, 0.11557047675934531, 0.8872754343094365, 0.4269194110266624, 0.528395478763888, 0.8543202929919766, 1.3608386295457042, 0.8040321978830522, 0.45687559391221694, 0.3067160481887479, 3.717366759815524, 1.404565457374819, 2.120656890253867, 1.9634017156016443, 17.525028336432673, 15.04494603603117, 15.290813926727543, 13.208478593057203, 21.026834134132635, 38.25330342015913, 25.512354681568763, 20.694609380537464, 4.653175396303977, 3.4076245417518005, 7.158751141640448, 3.810336493676709, 0.47667053978770013, 1.7987594921742718, 1.2945478770040697, 0.401598856814446, 0.34654434650175037, 0.13363472276156949, 0.23050600452528847, 0.14512034193161996, 1.9332699453638447, 0.3977824212802995, 0.1051839026472261, 0.015143402683128034, 0.14921393275501268, 0.1381235383450985, 0.09992894551326191, 0.14360793115150544, 0.10083281435072423, 0.31120210585574953, 0.25369525616688116, 0.055089237078303294, 0.09476991790917613, 0.09256461890594614, 0.038672198856910395, 0.024630174927052953, 0.03209323111561037, 0.0869722000413364, 0.4355281861799379, 0.4338536099080117, 3.8724555603919493, 22.18778314128999, 49.73609701279671, 52.32311194942844, 50.16520823201826, 51.8765579500506, 35.89601385977961, 22.470789993962935, 35.69139165263022, 51.11264498003068, 60.40007622011247, 76.85527416967577, 76.46344507894209, 84.41374424965151, 90.05459108660298, 38.91314022002682, 2.031707463245238, 0.07233295694834764, 0.02959986581587263, 0.03852504485797498, 0.061914850657265035, 0.0097798363065287, 0.03053378445216485, 0.0389794422493827, 0.037495506957413695, 0.07369814095117393, 0.04293546666421237, 0.07610582506224033, 0.08534885972978608, 0.028684771875099793, 0.006869105826838003, 0.03419258015891237, 0.04013420105160725, 0.025306846984031222, 0.036063025960878986, 0.05606677676100404, 0.010741389649469527, 0.0562496955746845, 0.05168652349722482, 0.03267949139098487, 0.0635119792704861, 0.029995218895736243, 0.029914590056925535, 0.031100197304641048, 0.10490055736755172, 0.06196890582120227, 0.04335930097788092, 0.024619424798255487, 0.031014835957678098, 0.03713315886054789, 0.05275002207546946, 0.016765372654903802, 0.027687470954392227, 0.09430186883095773, 0.01729542505927384, 0.15348537855090635, 0.08656136240930327, 0.26080829061327443, 0.14884973455580974, 0.10286242641027897, 0.19074351316498173, 0.2099370340546293, 0.11688288496506792, 0.15360118040154058, 0.14691185386430833, 0.14178537733612523, 0.13612631648298235, 0.19157739987056102, 0.16213092592454728, 0.1659328517534079, 0.13060971734023866, 0.12284472674852419, 0.1639146084386495, 0.09837128191946015, 0.18762944236157403, 0.06348112124889609, 0.1936947443192044, 0.1453856228580398, 0.1463547240822546, 0.18259774623138292, 0.14901701751495564, 0.13553644410304486, 0.2013465990462611, 0.21813218301582724, 0.23717928918138628, 0.320249542954468, 0.21060573688197523, 0.21446977711973653, 0.2821342172401567, 0.14124019852569028, 0.11098632153363959, 2.5358015298843384, 35.18219347923033, 99.64543727136429, 121.38075736261185, 99.26725802883026, 81.27038817251884, 76.56377930794993, 72.14875159725067, 54.24617159751154, 33.66492655969436, 56.381368713994185, 53.669532191368845, 90.96300417377104, 113.23531243108935, 62.40613714341195, 39.58056680617794, 29.716374566478116, 28.101279812474406, 9.47862325176116, 0.963455033638785, 1.3677461685672885, 0.48535111270123915, 0.6970168241570074, 0.6066264776933579, 0.1771785781508492, 0.18668376810608373, 0.29191780354707475, 0.5473352560112553, 0.22105738250238283, 0.19742542397110693, 0.1365008109038876, 0.17656779157057886, 0.26018166133473, 0.6889963125990284, 0.6932362108942002, 0.4406864706787371, 0.2627690160466779, 0.6339994120982386, 0.4243349368053098, 0.18799071410490623, 0.15359993933910324, 1.8788801542212887, 0.9309652447700502, 1.397620288114394, 2.5253405686347716, 15.636717946298662, 12.62364927799471, 17.48111936353868, 14.930232397971617, 21.68678076036515, 45.62426851641747, 29.211661623370265, 28.99564885324048, 3.165318653468163, 2.4015937120683732, 5.609800786741319, 3.894542426832261, 1.33042432608143, 2.291138542275275, 3.9909954705545982, 6.504076180919525, 4.065882342476999, 0.803743964962421, 0.8397698931155667, 0.676774820012431, 3.118903531182197, 1.3764880285147698, 0.8889662822888744, 0.5856195500781459, 0.48776061244068614, 0.4640883730063516, 0.2509706184989022, 0.22704475799635535, 0.2833802132837234, 0.40891306594975535, 0.4183836287308124, 0.17082587064754579, 0.21249717732350673, 0.24237780861796873, 0.25606383148941303, 0.217656503701883, 0.1189927906999665, 0.33409416134799685, 1.0489252570175356, 1.059923337832574, 11.117414024568374, 41.582089547188055, 63.268591819270966, 70.1276562290807, 75.72338011956985, 95.21071141765964, 73.01765072730281, 45.408310659470104, 41.536197816171956, 46.57254465164677, 49.65965394050845, 66.81746605903872, 73.33326032084804, 93.67643710105651, 104.49409084935343, 36.80863172777238, 1.149379486037839, 0.21884452221134018, 0.24554544428904213, 0.11747109493420971, 0.15095771741001837, 0.20029905041859997, 0.1662744197153276, 0.20422325920193427, 0.22433004882787505, 0.19516452996721192, 0.2080359715487688, 0.1630746543167099, 0.15967028215527534, 0.15141396873420285, 0.1433565930253075, 0.1537540762294685, 0.15065295231198111, 0.11978619731962682, 0.12242429769567906, 0.15657856579749815, 0.1197652371540185, 0.17093880732934322, 0.1859362654748463, 0.11691758874803783, 0.17290500263052602, 0.08103607582949823, 0.14712479566374134, 0.1552736269490373, 0.18483596403271924, 0.20465481185143997, 0.1652443072488231, 0.16098574705181584, 0.1892147234250461, 0.07370494381194154, 0.0763631463351269, 0.09152355138212444, 0.15088671638119608, 0.11134984557546916, 0.16111967454273857], [0.019956743645091212, 0.0730427374101935, 0.018467078015448588, 0.0744861160074511, 0.06452501180671877, 0.04690526150948098, 0.050581828540852, 0.08258774861573212, 0.04038763825871772, 0.07015123047054776, 0.09065149817615749, 0.03521498578089861, 0.01891691718370684, 0.014836468598655155, 0.13147637728721867, 0.04110435947715756, 0.04818567405304602, 0.027436439263364, 0.069140829446335, 0.0367438061643512, 0.012675890935614947, 0.045153674248966484, 0.03558868347036262, 0.030603232237720684, 0.0245452962154823, 0.018782604733602177, 0.044913486532506444, 0.035427847141099554, 0.03626642996565469, 0.048857054357687314, 0.02379755801220815, 0.013167558504538912, 0.024873189507953586, 0.09113147524335692, 0.2162366976300555, 5.006968282884167, 42.63659523379418, 87.65420252277006, 86.52538361087923, 72.57943568691131, 74.49192846975019, 72.60875932631954, 48.21386045025241, 28.993073817222353, 30.94186225245076, 51.49718238461403, 60.86281391882128, 64.8480361507785, 64.54882206455355, 37.73386001586914, 28.406357842106974, 19.81166228171318, 8.244092541356242, 0.43513643945897784, 0.19051387064879943, 0.29283177708425834, 0.672854656173337, 0.06294663702588409, 0.06776816842536773, 0.049179087077537854, 0.22925913514148807, 0.03442781128650231, 0.04256822709595004, 0.12920757725594506, 0.030774462464896422, 0.022995739747139237, 0.23916629143059256, 0.23926500952051533, 0.28261866059995466, 0.9783062915648184, 0.2500634631442447, 0.7554918251210644, 1.8101445393216227, 0.6795893657592036, 0.42185731652763586, 0.5216994412964391, 2.6941402592966637, 3.491986143973566, 2.576080104035716, 2.889105591081804, 3.37995050414916, 6.68056175593407, 18.232869063654256, 18.405667120410552, 13.90391384401629, 20.90512102650058, 15.118521855723474, 14.031190833737774, 8.048104451548669, 7.928817820164466, 2.8612310223041044, 7.473826312249707, 7.118433098639212, 0.9107333529860744, 0.3997817269015697, 0.6741935940038774, 0.8025548739298698, 0.33129646953555847, 0.3061432902130389, 0.34338855454998635, 0.30659718198641656, 0.2668508550813121, 0.1789575109198209, 0.14459612328679333, 0.16441877090161847, 0.040209327463901816, 0.016151607907827825, 0.03371890416489013, 0.15594255960276052, 0.1959322113543749, 1.3403008541753216, 0.9882546480624907, 0.3218239149258983, 0.9011214010177121, 0.0927373564111129, 0.05667760547611022, 0.09618550283654083, 0.05232304297087174, 0.17676432376667378, 0.15913844859648138, 0.10251459951001791, 0.3039099906961764, 0.31615958338783634, 11.551284059401482, 46.46460886924498, 53.82528166617117, 60.14425531510384, 56.826291007380334, 56.32696543970416, 48.73728113789713, 34.86650936065182, 23.53128513982219, 31.463884615129043, 45.90865212102091, 52.03537471832768, 65.43969038994082, 75.06654785525414, 45.38834971766318, 3.946210828519637, 0.15680131352236196, 0.033769201667558764, 0.06269499246451644, 0.05937030493852593, 0.054804217896514365, 0.04134657349617731, 0.08433116554853418, 0.03235030724036117, 0.10402166299642095, 0.0870273047457299, 0.04539540563259394, 0.030799980853654207, 0.01082215351127689, 0.019624200198919545, 0.021247182364365267, 0.12293071245714543, 0.11254352547468678, 0.046086535683923194, 0.011780970005108225, 0.09198600801849559, 0.024509797616290952, 0.026271935822742603, 0.04775745005557134, 0.011271927562061579, 0.025290856813831676, 0.07388377171610633, 0.039021826063793515, 0.05510128764135223, 0.03364831682354693, 0.06216098704645711, 0.026076204188528563, 0.0675394528755738, 0.01838975867647077, 0.0018758816745943362, 0.02213973225274634, 0.04608737455020028, 0.05786738598779325, 0.020516449397790338, 0.02012804665061976, 0.05102596035407436, 0.01657559543908123, 0.04090790772029469, 0.025308438531693914, 0.03247135679327673, 0.0687151603520878, 0.079193044483902, 0.03278435350606038, 0.04243341477347478, 0.06032007010353189, 0.06084387889131904, 0.010754283866845073, 0.06516201391575799, 0.05350541158188736, 0.03197978307012349, 0.01653658432675706, 0.021323616871790543, 0.0441558332362723, 0.04701028450302059, 0.05476428173302163, 0.039742385382734, 0.027087045713297786, 0.023534157831642418, 0.04793572254599102, 0.07192017345298683, 0.06813359236524952, 0.05644000713683425, 0.09727597537059939, 0.030401555761214227, 0.041219613574925935, 0.06511512167391277, 0.00846303937460987, 0.08294220983741746, 11.215395812065372, 67.98375929555586, 106.68678991256222, 99.28739547729494, 102.91241861158802, 110.2957783975909, 103.79111582233061, 74.27776705834174, 37.179268252465036, 23.89594593355733, 22.542100644880726, 32.487272177973104, 42.660458933922556, 55.63250195595526, 40.832983524568625, 26.379265169943533, 11.051770217957037, 2.729390109738996, 0.548589924170125, 0.07665799825542396, 0.10176495949347174, 0.4719696404232133, 0.215086278715922, 0.010981794743378077, 0.016257804931111394, 0.08123071578842017, 0.4940362514988069, 0.2054147557505677, 0.34853795242886393, 0.17752679575595165, 0.17321663187636485, 0.6008248019122309, 0.8789093251670561, 2.405114284446163, 3.466629001402086, 2.0052970417084235, 3.1286859223919534, 5.059378012534111, 5.543473997423726, 3.4455207663197673, 4.4407035458472475, 7.783866140150256, 7.839116646397499, 12.000558222493819, 8.894756878575972, 7.389159010302636, 13.69069968500445, 26.001735079673033, 19.84578101865707, 17.205727792555287, 28.312450416626472, 15.514944041928938, 16.225004830668052, 9.332717945498805, 12.560929598346835, 4.36145794007086, 6.524146458794994, 1.4490659727204231, 1.3311480033782221, 0.805679532068391, 0.3977775183175841, 0.8419567983477347, 1.6124384513785763, 2.345307209799367, 2.7627322173887685, 2.500160913313589, 1.8850002774307806, 0.9375203220594315, 0.5356534570455551, 0.287185954230447, 0.029902181347772002, 0.02395288999973526, 0.043194400552179546, 0.27209294959902763, 0.18533764437081354, 2.1541884974125893, 1.2610239920116242, 0.2214360137980792, 0.9283020779971154, 0.025812758042687373, 0.052229097608717225, 0.09039066055969847, 0.1606875856316859, 0.08583867336593329, 0.1895260615574737, 0.041003312479944966, 0.34118608241119697, 0.6047300730020769, 8.169968570432356, 48.66527034390358, 53.860057400118926, 57.86403248386999, 45.537509610576016, 33.9093529793524, 23.596472970900997, 21.248167599401167, 26.186735630035404, 47.76285848309917, 69.69740360013901, 80.98094863276329, 86.90752444728729, 91.2085759255194, 68.69410837850263, 12.40540271805179, 0.06228225876487071, 0.04501121253856728, 0.029707912941493338, 0.013512627488272566, 0.0602638928760444, 0.13724656685465766, 0.03662284471154694, 0.022314248997117245, 0.10929305271636094, 0.06532387297239996, 0.009287415098609223, 0.08711188851344971, 0.04565642327971516, 0.0469057479753129, 0.03401782018162551, 0.033171277703537096, 0.0811967704324953, 0.12491858804658537, 0.03165459406802491, 0.013822570383068056, 0.0459123426117003, 0.10232903003211945, 0.04907519406368656, 0.02620605226125448, 0.03657535109068117, 0.06249882799062518, 0.10058236488651845, 0.008074160695316331, 0.04104319118684338, 0.025961020953893185, 0.04714880086060974, 0.01909459212554559, 0.059943151014346274, 0.041749102904671626, 0.04665206178962704, 0.017012715632576617, 0.08692414334584629, 0.09905123857841377, 0.11743972363371043, 0.22190680547106653, 0.13816840045394438, 0.10860607103114167, 0.08096390268615178, 0.16458712638385836, 0.1909808778474408, 0.24456566379916286, 0.16020320355892181, 0.19658094993041408, 0.2062452257040047, 0.1565738620176431, 0.08239971233471748, 0.19242703734386354, 0.07832522774415632, 0.17156013527945166, 0.1235631793256729, 0.2271365046861672, 0.15739968947825894, 0.13716415111576358, 0.17476181589788006, 0.12070028576999904, 0.13469776168705958, 0.13654038700605595, 0.14056369692327517, 0.114906968008126, 0.15715959752278943, 0.1439388964565531, 0.24069757861716135, 0.15918380100159876, 0.09928861858263131, 0.15724112459969136, 0.15665221749053848, 0.18234125999433382, 11.063591261063854, 74.7173313940725, 121.50333143049671, 113.59390335698282, 98.61478744014617, 102.12861922479446, 97.51751222918111, 63.168594914097945, 41.4114115315099, 46.53988699759207, 70.38934892223728, 82.53594875335693, 92.10599068672427, 93.84705235881191, 58.905084440785075, 42.24511915637601, 26.69242132094599, 12.311271717471461, 1.3320784631275362, 0.3249332513059339, 0.45997319382525265, 1.4191742025075422, 0.4948290299263693, 0.17387390467188052, 0.18779787445260634, 0.5115824535248742, 0.3462362565821217, 0.17643642281332325, 0.20624010823667052, 0.13270847649583895, 0.19698280901197465, 0.5003034329462437, 0.585691868778198, 1.5512174848587283, 1.7056257542102569, 0.9289679616209, 1.4420727544253873, 4.162478062414354, 2.3339320911515147, 1.1858425746040961, 1.8460404776757764, 8.488066907851927, 7.819232681105214, 10.882778821452971, 7.164329732618025, 12.286276413548379, 21.03714800650074, 32.056782245635986, 36.25297700205157, 27.54538974454326, 43.946172652706025, 27.787433324321626, 25.85662111159294, 18.703345598713046, 17.356187951180246, 6.4286230168034955, 14.111226797103884, 17.036848183601133, 3.377329870577782, 2.527076952880429, 3.68491895256504, 3.7510143220424657, 1.605630932796386, 1.3490200379202444, 1.651829957000671, 1.4936804819491603, 1.2263248668562983, 0.6329891566307314, 0.5787177720377522, 0.22080138656160525, 0.2797345234261405, 0.08214826695621014, 0.1441358729836441, 1.1918116865619537, 0.6788336966306933, 3.8558654054518673, 1.8214572677689216, 0.4985742499270747, 1.3034733529052427, 0.27419258209486164, 0.1334365971025921, 0.2394960003514444, 0.38088527958719964, 0.4409488098275277, 0.5791190795360074, 0.21824749457018994, 0.7033979075570261, 1.0960342711017979, 18.43207447759567, 67.93594560315533, 72.94710297738352, 78.36182517390098, 79.34199410100138, 77.46773658260223, 64.37067977843746, 48.959750129330544, 33.77634540680916, 38.25049892548592, 62.16375820098385, 70.06165058382096, 83.60852087697675, 100.81351126393965, 74.36353360452961, 10.524911572856288, 0.2634314369530447, 0.14119124550732876, 0.12397777844941425, 0.12618662443973366, 0.10836169664417544, 0.2138798740962821, 0.2093516356281696, 0.1777309581877724, 0.23844307378655483, 0.2030803632712172, 0.1373568681939956, 0.19383224177985423, 0.12810691575249358, 0.13789132177349062, 0.13066296045097614, 0.20768084383058935, 0.19719627175119617, 0.20953086955893427, 0.09578043384657753, 0.12997300634461065, 0.15192006173874104, 0.1990111493655751, 0.24701054147895307, 0.1873974709381019, 0.17839275090204132, 0.30210009265330534, 0.271486820833337, 0.10368053936549734, 0.20279851952387443, 0.18717231769715587, 0.23640750156294918, 0.09262671033220907, 0.1664555229006275, 0.07245864899408433, 0.20965218724262333, 0.18507967192319133, 0.2075560021424486], [0.026634257106531053, 0.08391181667966228, 0.0823926643258141, 0.061179494350067073, 0.034228605443551656, 0.0689212839689947, 0.045044238588983015, 0.031148834311733806, 0.047125446670238054, 0.0257967448898501, 0.07067167996278695, 0.06608885006919023, 0.014732275852903485, 0.11361522119372122, 0.0827663237108819, 0.03474334758075495, 0.003070077725550941, 0.04265939538937904, 0.006145657398813074, 0.013424685382614694, 0.047490671427259525, 0.016054423908973416, 0.12537885367149307, 0.048812310992469715, 0.03614833751212686, 0.017874081911999854, 0.05079655532514857, 0.03616249864740718, 0.05843803722171053, 0.06843700914854003, 0.04436166573976798, 0.10189131803570256, 0.017117095112259832, 0.06555487146420826, 15.724636893118582, 76.61076145787393, 91.87965423830094, 80.15667038579141, 64.75982989034345, 60.159132865167436, 38.475713576039965, 24.57833440073075, 29.862396563253096, 35.72661061440745, 68.7020472557314, 64.02726058037051, 57.1558093255566, 52.161627969434186, 35.74302181120842, 13.743854664987134, 2.7345931337725733, 0.6107087457372297, 0.16057250390370048, 0.12221890952317946, 0.19190594433776795, 0.07860298824286269, 0.07851440549617814, 0.05641379543850499, 0.1882332881852504, 0.052731704913199916, 0.1457478445503981, 0.04523699014117161, 0.18007819030073383, 0.23155689329629947, 0.30634847920267816, 0.20173161951524599, 0.29651990821284635, 0.21503996104002002, 1.4080454577361385, 1.3130371945519603, 1.0655915304537744, 0.6301231297754473, 5.23124989963347, 3.96114353691378, 3.585227256821048, 7.297725619808321, 5.859242937257213, 11.312248937545284, 10.357349880280035, 7.193916170827805, 4.483627513531716, 10.237226313160313, 8.294724456725582, 15.086304487720614, 13.903760871579571, 13.348667044793407, 15.115296686849288, 13.038556614229757, 5.84322544836229, 10.427039611724116, 4.345901819967455, 5.4911314383629835, 2.4281241336176476, 1.3220688195959216, 1.8554600496445934, 9.437404044212835, 20.37906450610007, 36.104283871189246, 42.016080194903964, 45.38232887944868, 42.3532392901759, 40.131824554935584, 36.410185598558, 27.070380910750362, 19.304997959444602, 12.715258194554238, 6.236771556638903, 1.590744312251768, 0.17356193834735503, 0.024035141029725635, 0.14103968267238912, 0.15971204926890714, 0.2389274252158019, 0.15105432109727016, 0.012994759712338209, 0.15491807022162024, 0.03695541880123558, 0.027668021897214557, 0.06711492525233377, 0.1018065810503979, 0.20285056753745004, 0.269475533596931, 0.07371832736797872, 0.5028801543578025, 2.5662548119022004, 13.523088962801042, 47.505629447198686, 50.21417117887928, 40.34962200349377, 68.53437377560523, 62.41357395725866, 47.6592412302571, 33.14998995873236, 27.604040945729903, 25.708671269878266, 36.984318610160585, 56.391119726242565, 75.06570846803727, 57.8966469918528, 9.944597886454675, 0.1879055557712432, 0.017447934012799975, 0.03606201472481893, 0.059948402547067216, 0.03907298158493735, 0.12361436165989408, 0.03988384351795239, 0.04309544114456062, 0.06838955000163087, 0.036409994842664856, 0.06967165176906893, 0.027279230360422405, 0.016740225818789294, 0.033746012186090794, 0.12534479340237956, 0.02685057926892994, 0.059733679593210263, 0.028262013914964856, 0.06923201689196211, 0.020081732805157383, 0.022561737531495672, 0.012026271358462832, 0.05477994057019392, 0.0228033195279779, 0.06454954960293348, 0.043506148541646625, 0.046088906726048845, 0.019995745181316332, 0.0461950482079579, 0.05140149665455665, 0.0223754134569918, 0.059582576411025184, 0.029593049548566345, 0.08345325176994647, 0.03670229569017407, 0.0774943441032402, 0.06033518501827794, 0.044566268672145186, 0.07662163206165837, 0.06679047935552175, 0.016829861936369733, 0.050111722516556906, 0.038023877798789935, 0.07303239522321571, 0.023995513216622417, 0.0112509022789797, 0.028084197246860114, 0.07097745629688425, 0.016068188593752922, 0.06899580134138947, 0.055526937583401326, 0.003239981423605294, 0.0694692283568363, 0.023658455597356926, 0.04397946064390483, 0.05908295301900757, 0.07226182568457819, 0.06534914621302197, 0.05673972754589012, 0.022580590955312216, 0.03411294914962303, 0.03788676721254184, 0.023028729408378565, 0.06772290028992199, 0.04169038609571515, 0.024433621663540125, 0.0842918499162601, 0.07930418085907737, 0.027483341081308264, 0.5603020602176266, 28.718341204427905, 101.28670600152786, 105.85232919262302, 96.35685151623142, 91.04264397774973, 85.13322461035945, 63.23344738252702, 36.44859736965549, 21.058366067947883, 14.779401575365375, 45.1760200531252, 46.554140890798266, 47.690243644099084, 55.53871808513519, 42.33956590775521, 11.47475959793214, 0.5198027914570225, 0.47178210209934945, 0.14601330933791978, 0.11372579066383262, 0.377784492748399, 0.16823995618089554, 0.08646972297180085, 0.04256307132421963, 0.12994915036664856, 0.1056683460070241, 0.20850351500895717, 0.019160383756482796, 0.9958778357794209, 0.6798147181830099, 1.3494625303053087, 1.520518074112554, 2.2667043824349684, 2.922513153283827, 3.9470068245164813, 3.4830806476454583, 4.645708674384702, 4.02300764956782, 6.497564065840937, 6.361487728934135, 6.018156293899783, 10.853673854181844, 10.57704673659417, 10.906699395948841, 15.866660033502887, 13.706767674415344, 10.262752117649203, 10.038108171955233, 15.113059955258525, 18.687485494921287, 14.503125509908124, 16.124465657818703, 19.38978587427447, 17.85166371253229, 11.73284371053019, 10.679708892299283, 3.602036083898237, 2.194613179852886, 1.4503963916532456, 0.23317761358714875, 3.930731930078999, 15.804684623595207, 28.76657262925179, 46.5151446865451, 53.02430622039303, 58.20398038433444, 55.87927003060618, 56.814500362642356, 51.3646258846406, 42.1316175306997, 35.73607137126308, 25.04787741168853, 15.496362793830135, 6.7211072964053, 2.243882561883619, 0.9185126387784559, 0.16493604878985113, 0.24179227229568268, 0.20312740106976804, 0.1575212369883253, 0.12258555154286085, 0.0677418533051687, 0.07293009184180729, 0.1565596740692854, 0.14165439162283175, 0.06838975684537042, 0.230363818606542, 0.29011568895751433, 0.0225922393222009, 0.9608140527721375, 1.4251157353001258, 10.782196502531729, 48.31004088924777, 52.08673815573416, 33.683440146907685, 60.25097908512239, 51.2856097375193, 24.01912404644874, 17.62455063481485, 25.820896164063488, 47.02553133810721, 68.22707176208496, 78.90933313677388, 88.94725107377576, 78.56116787079843, 22.11489373637784, 0.08032390517332862, 0.07833991364966478, 0.04727288029126583, 0.08712172508239747, 0.032859296057253115, 0.08756374249294882, 0.029151872919511893, 0.043803528552093816, 0.07687352177116179, 0.06811430227131614, 0.04577604407865194, 0.03158710938277504, 0.054328427499821114, 0.04106800477471083, 0.08127783019576343, 0.036512014771541285, 0.07360730590599199, 0.04896910237749258, 0.07341147851078741, 0.07521045980073753, 0.05042530911704225, 0.04516303201296157, 0.0408046237463432, 0.026852176562252066, 0.052047906323306026, 0.06110675430165664, 0.046905935666854345, 0.030743242466762185, 0.01724154034989976, 0.035324792993525346, 0.036056460587367896, 0.03993752712924634, 0.08260476342853039, 0.04878623718996683, 0.03671525023697365, 0.04110592612696271, 0.08459009560606173, 0.18342178104625595, 0.1344517708545731, 0.18574724094040934, 0.11464940924798289, 0.12071141702753883, 0.19433701711316265, 0.21221416912251906, 0.1339247483279436, 0.12008287252918368, 0.12432444089603041, 0.228624124861052, 0.13189361941429878, 0.18180492183854505, 0.2050058026948283, 0.091050484428002, 0.15653091512860792, 0.17012968058547667, 0.11778144481321497, 0.16982925154509085, 0.16890421569828065, 0.14179450910418265, 0.2446982889406143, 0.18339433977680822, 0.11738841106454212, 0.08662184505092521, 0.12597674699199776, 0.16575959330845266, 0.15513887208315635, 0.23229115792820532, 0.08615751149913958, 0.2488499951939429, 0.09676773731987323, 0.5273632825382295, 30.76268053823902, 113.6396852616341, 119.1669402583953, 101.00933167242236, 90.48942504390594, 81.54302427845617, 54.98083545315651, 36.00233754804058, 45.203821812906575, 55.09722002090947, 98.44045377546742, 92.55208184642177, 85.60771373010452, 76.8183489768736, 55.624743507754424, 23.990161265096358, 4.35907559048745, 0.9929833104533534, 0.2517812161315834, 0.35025009765259685, 0.6868295095139935, 0.49325505632065964, 0.21760353638279825, 0.28937635282354973, 0.461214256262587, 0.27934565719577575, 0.41993278108777543, 0.22361245426920154, 0.5125234852875433, 0.3604950221075166, 0.8046591642402834, 0.5057407573105828, 0.9833145454045266, 1.566298385300944, 2.8436676292650165, 2.8452787428132953, 5.000680723497945, 4.01657913000353, 11.707464014330219, 11.110814636753453, 10.4413023302632, 13.924648473339698, 16.923776057458696, 24.293735065767844, 20.811990230314194, 16.732754668881817, 16.751899757692893, 23.51716656838694, 19.93338323408558, 26.080451165476155, 22.38644922933271, 21.217894746411233, 27.502157380503995, 24.223701146341142, 13.988049664805013, 17.971227361309914, 16.144582513839968, 15.662966447491801, 8.377559031209639, 2.6331643183385176, 2.172720470736104, 10.186028595893614, 19.695413035731164, 38.101825406474454, 42.51785724393783, 49.309911881723714, 46.59228594072404, 47.186152396663545, 41.442425712462395, 31.70351201488126, 25.040648483460952, 16.943937040144398, 10.304567525463721, 3.5130669224646787, 1.2126311371403358, 0.5469043468756061, 0.26141316299476935, 0.35429770787877424, 0.5181908811773024, 0.33589946286332223, 0.22372347573118828, 0.3092021567206229, 0.1977440399388152, 0.23004616790961838, 0.26323381691209735, 0.31270281081238105, 0.45300522578820107, 0.7594496804860331, 0.13386560634018915, 1.557798976859739, 6.894664822086212, 25.541084081895892, 67.33790966772264, 67.96210781220468, 59.11145210266114, 97.81606735721712, 85.28816607690628, 65.11948377855363, 46.57984026016728, 35.64497432401104, 35.212399651927335, 53.427961257196245, 74.2719776399674, 95.03403217561784, 89.55881134156259, 20.178390164529127, 0.2575991176549466, 0.2103505529943974, 0.086216684130411, 0.1520580801391794, 0.13815393671393394, 0.15738890296028507, 0.11170491200661468, 0.09136588282642827, 0.15935163554405013, 0.13839563745404446, 0.2605480045801209, 0.12991400225268257, 0.14458418763693304, 0.12455643530214026, 0.3146041797534112, 0.24746202773624854, 0.1839350293120069, 0.11724835487022517, 0.17274407820115167, 0.20041047024630732, 0.22306080967668565, 0.09802464245548172, 0.10503915799481255, 0.19041607186438578, 0.10911240152293637, 0.1563711245093615, 0.11179111221985472, 0.12037056152738872, 0.10708938548040968, 0.14128335991934424, 0.07880867518965276, 0.1532838821050621, 0.1741812897906188, 0.21344718763664847, 0.15173805456969047, 0.08322323387068126], [0.0719008756981742, 0.024918794722086, 0.1205815498026148, 0.05678990630493049, 0.06163545839127995, 0.04039443728904571, 0.03809163827569254, 0.05594644733073731, 0.09017668454156769, 0.036425669001595634, 0.07567211970566742, 0.10261173179793744, 0.17787093777329693, 0.09140903655920299, 0.055504747846674536, 0.01566490363104329, 0.013805254880759506, 0.01743977134596677, 0.08361688048969354, 0.015681810233922257, 0.07577092972614112, 0.08230185992414914, 0.04698560498053989, 0.05909136466441616, 0.1394965977317864, 0.033415943203914555, 0.02919319570214758, 0.05062681705420537, 0.05752983232659679, 0.030702766211282824, 0.07804283241350805, 0.0970539094639882, 0.892865669823462, 37.23219671557027, 85.89931057345483, 89.2269003775812, 75.9136386071482, 76.90378604396697, 33.54467453495149, 43.40124168703633, 35.00513768965198, 45.09472500893378, 58.928096986586056, 65.69006704515027, 42.56278014952137, 36.61238378094089, 48.68732583138251, 45.05136320667882, 17.65253870717941, 1.490503729831788, 0.16736839327120012, 0.25961374503470236, 0.22546074863883758, 0.2822582928403732, 0.022857472368125475, 0.06467151080047892, 0.2563617784049242, 0.07058145778794443, 0.17760502865477917, 0.10219095800552638, 0.13712874253190335, 0.7673604269662212, 1.115037051420058, 0.3560870134782407, 1.0405393521631918, 1.1253716388056356, 1.3564444717860993, 3.7624759779822443, 4.6635471236321235, 7.83866802530904, 8.377948326449241, 9.203898483707059, 10.295432325332396, 21.32778386915884, 14.448003461284024, 16.82759169609316, 12.468501887013836, 14.988614916801454, 14.549276117355594, 14.116100342042985, 5.474305450916291, 12.443659555527473, 17.446590738911784, 12.429761617414414, 21.1018886873799, 23.122332942101266, 17.67412547142275, 9.518369609309781, 8.275577406729422, 3.663816110741708, 2.326242284428689, 1.0715463012456894, 0.16076503712083065, 14.616169198866814, 54.4979210822813, 70.40354790226107, 77.85839680702456, 82.29469945353847, 80.35061590133175, 81.38616869526525, 77.2951130713186, 83.85620286387783, 85.4798601519677, 84.08524574772005, 81.1753648327243, 77.08124976004325, 67.78087077602264, 57.91126958785519, 40.23876797768378, 23.752432292507542, 11.747497685493963, 3.0999587283980463, 0.3993910527037036, 0.09404272426881137, 0.1042590430006385, 0.13648768015686544, 0.10235271747073821, 0.04752815993983419, 0.12436237757004077, 0.1353442326428429, 0.03464359527213439, 0.01751325066922413, 0.07260037526007622, 0.3392058983445168, 0.23112265933905882, 0.4222040172786482, 5.027389612890059, 27.868259645277455, 33.17737986964564, 19.53712578742735, 33.1838047119879, 59.42186063335788, 62.33093354009814, 53.96951506214758, 33.439174544426706, 36.08858262338946, 50.5717069871964, 50.8877048953887, 73.37769293016004, 68.77846287142846, 17.171803212934925, 0.08088078980724658, 0.04123338400536487, 0.07669210448981294, 0.1284403631824159, 0.08033768709508643, 0.08487540207082227, 0.01073477543785327, 0.01310138478724947, 0.015696536359046737, 0.029107209993526343, 0.014569984914194194, 0.039794287839604, 0.05416584832053031, 0.07580105230332383, 0.006184360160747724, 0.038352686566330736, 0.035829089521881075, 0.013045252567427534, 0.05395618537741323, 0.0628087411995136, 0.02148230049398638, 0.08694408461451532, 0.002136311588636149, 0.03141488707173736, 0.020822114649138624, 0.04044055578208739, 0.07521365438738177, 0.023141238996158206, 0.02032487379056552, 0.08387165068979226, 0.062495032024960366, 0.02916054695003456, 0.061460265574315866, 0.022872983733372345, 0.05619205511926163, 0.025941230987589207, 0.03689056945844524, 0.11451214161371032, 0.09747478284782941, 0.027945776650261496, 0.033391907195290255, 0.04745509047361632, 0.043800173086985465, 0.014212283140589154, 0.08640649773540997, 0.03462528194030447, 0.07158026024098359, 0.09981765592050168, 0.06687179958868412, 0.022147012003246817, 0.0761676023924543, 0.09096263712572475, 0.013652028677414262, 0.04467089329996417, 0.042148920361913984, 0.0487795569032671, 0.05913481334104173, 0.042573930620546305, 0.01674353914906181, 0.08188577458983468, 0.08208460504970244, 0.047747012107603015, 0.030448978518947, 0.0462468778864751, 0.10387405317517058, 0.06971442245788152, 0.12389006904296337, 2.1493495183606304, 56.44051805619271, 108.09407357246646, 99.30187686797112, 95.74664054378387, 106.11209992439517, 65.12412394246748, 55.21760932860836, 22.18246244615124, 22.038397712092248, 36.709889981054495, 52.05131523070797, 37.408271912605535, 42.85081548075522, 51.034464297756074, 47.29125230543075, 14.149905289373091, 0.5419012411467491, 0.12504794199260014, 0.3091059360773333, 0.2824772714126495, 0.2907802242665522, 0.06292921618648595, 0.11863332692413561, 0.11988159824883747, 0.4766137267072355, 0.41320576302466855, 0.7304644067921947, 0.6286732011264371, 1.5806705624826494, 3.3673967132645273, 1.5145911276340487, 1.2867895513772964, 1.8420927346714082, 1.6390612937750357, 1.5182894324102711, 1.3097046507943062, 2.5472622052315743, 0.7108245477561028, 2.3325509265545876, 2.0720119005249393, 2.8986261640825584, 4.623435495361205, 8.757815168749902, 8.093172975124853, 11.358651557276326, 15.4744847936015, 16.259765855727657, 12.688130101849957, 21.339188160434848, 24.821639022519513, 21.266351707520027, 29.640143302179155, 32.135782703276604, 25.737190823401175, 18.887830357397757, 13.298888244936544, 5.392597577264232, 3.584814427360412, 0.7366315371567204, 0.2726503858162511, 19.48295589416258, 57.0980877261008, 71.65620388523226, 75.20664707306894, 78.51139299331173, 78.26823742158952, 79.04059917696061, 76.58726646054176, 83.00497008908181, 86.05404807675271, 82.85586510935138, 83.66848607217112, 81.00743247616677, 76.58987091433617, 70.18533860483478, 56.16807022402364, 37.42018415081886, 22.038674239189397, 8.624433990447752, 2.248214084294535, 0.6248837625307422, 0.2838227363123048, 0.1655629845035653, 0.06437402353772233, 0.09590436389008838, 0.08466272074128352, 0.08292061381883199, 0.06714727714537613, 0.06971773961859365, 0.13484278213112585, 0.13635862498514115, 0.1587079531483112, 0.4460253987100817, 1.947685881487785, 24.372392316018384, 31.66678490177278, 20.345341928543586, 31.18214076565158, 44.864195546796246, 35.041337243972286, 30.38631146953952, 17.158149442365094, 45.046719120394805, 76.89495286633893, 72.65533354974562, 88.00694127236643, 83.90823702658378, 32.13726928157191, 0.563312785760049, 0.06362193970069771, 0.17788857311731388, 0.12444443324761045, 0.010841057688418415, 0.05489349395277039, 0.029154688292633624, 0.04242015379150549, 0.03529824038606978, 0.024529013016651717, 0.038687329093414935, 0.1189551528002466, 0.08327518995370596, 0.067792093351243, 0.04781620133848441, 0.016540807386439656, 0.05892491291066813, 0.037870376761401855, 0.05849722900518006, 0.03602363371981248, 0.08403484273942248, 0.07678896864695896, 0.0299934932826868, 0.07742968628243094, 0.014472622799897387, 0.04945515452193157, 0.050727998116804715, 0.016671511562420957, 0.03349612196606975, 0.06119382019425112, 0.05983238236137456, 0.07434744643227709, 0.02901258472833903, 0.045759320379264896, 0.04594322744636767, 0.11341149543201733, 0.09023925860322292, 0.2825520415940593, 0.16444691697195654, 0.1392410920872804, 0.10040766619626554, 0.12617095794168212, 0.1322629504025944, 0.22041440490753422, 0.18146061128185642, 0.13174617813239176, 0.22435692319225883, 0.22368560034421184, 0.2360146057101027, 0.12923803691181446, 0.12428779891061208, 0.13210170421629183, 0.10834461288346399, 0.16119144165948515, 0.08939201898512342, 0.17541888951053544, 0.24982709437608722, 0.1851841816378217, 0.1558655064793364, 0.2708899770532885, 0.14892629738296234, 0.07337697391067782, 0.16016952633377046, 0.1277602686276359, 0.21113634470009038, 0.34978238565306513, 0.25169827945290074, 2.3254531525796462, 61.77305090811945, 121.36236929124402, 110.94961397109493, 99.39562151508947, 103.69433526069888, 50.30501327207012, 61.761829007056456, 51.22449136549427, 66.18074770896666, 81.45759505610313, 86.37843593474358, 64.62249986587032, 57.13902158121909, 66.60757218637775, 67.67669262424593, 28.707664512818862, 2.6901923937182275, 0.19439108759885837, 0.36680602378422217, 0.7714118063449861, 0.46550925160127304, 0.26813543131274564, 0.2720283530652523, 0.5003849447013871, 0.2935957199623508, 0.2618759413880687, 0.40256642586281227, 0.6236426388063739, 2.117754581474489, 3.293938074381121, 1.8588331654187173, 2.9607253737988013, 2.6385656672139324, 4.930613954221049, 10.426389478868055, 11.234667397314503, 17.204380458401097, 17.639018297195435, 18.08741973292443, 20.54041708669355, 33.204295173768074, 32.66274529118692, 31.011282320945497, 24.677952797182147, 29.327246027608073, 27.752483044901204, 25.816389360735496, 15.215364194685414, 28.09427445934665, 37.46845283815938, 28.993058127741662, 37.71425993211808, 38.507680892944336, 33.50175988289618, 18.91714026851039, 20.609142895667784, 18.014310675282633, 11.59152561618436, 2.693402853704268, 0.1754918670462024, 12.87009277651387, 51.41361236572266, 70.29438049562516, 76.83255580163772, 82.53456807905629, 84.36160026058074, 86.66040728169104, 82.4850206990396, 87.23119843390681, 90.64864189394059, 87.6713981936055, 87.11484524511522, 83.57577693077826, 73.93261417265862, 64.41769722969302, 48.43132449734596, 28.80755747518232, 16.305763490738407, 5.193091121412093, 1.1729324609041214, 0.3711625819485034, 0.30210573106042804, 0.301508488914659, 0.30432012352731924, 0.5303442838691896, 0.3430374717760471, 0.33219346656434, 0.17882747515555353, 0.2609051241269035, 0.2794324089923213, 0.3101227492574723, 0.6380601683931967, 1.536992151410349, 8.932831325838643, 42.22699388380974, 49.620543987520286, 29.9093218388096, 46.408020834768976, 81.62463311226138, 84.83087262799664, 83.55575715341877, 45.11320721718573, 42.877271867567494, 63.29382834895965, 67.29380653750512, 87.98098302656605, 97.02653346523162, 30.229710840409805, 0.32590820544189025, 0.14909495930037192, 0.18328390054164395, 0.20882510339781163, 0.31607166713764595, 0.1358081142027532, 0.09314287739295153, 0.08337077474401844, 0.09861508940136242, 0.1563040458507115, 0.13072790938519663, 0.24848881538116166, 0.1417253773298956, 0.23851893181281708, 0.12195436404116693, 0.10514727598356624, 0.12402303892398074, 0.19880041389936404, 0.25399260553381137, 0.22465180575607285, 0.136452486077624, 0.15992915858664822, 0.08570225608925666, 0.13059139251708984, 0.17605506424461642, 0.15285237542083188, 0.18623376805936137, 0.1468650458921348, 0.21608000200602318, 0.16401145727403704, 0.0963051044832795, 0.20709729933690643, 0.16241822421791094, 0.0962725840508938, 0.16722600816959338], [0.017909157247613036, 0.17144194323449366, 0.11011858906356559, 0.054172819720641266, 0.0602616367471074, 0.09711910354634447, 0.06448455470343752, 0.05290950625954617, 0.0230993224953812, 0.13479496292289228, 0.013100789153888343, 0.08298229155761581, 0.11294226657839553, 0.12174907546009749, 0.1743781590654004, 0.1818556675026494, 0.10589068004440878, 0.04281305347479159, 0.033358555557506706, 0.07084850837746937, 0.05076829434162186, 0.05613879668676565, 0.049418328675411405, 0.07144820200459612, 0.027772682914209944, 0.044784634374082095, 0.05291598353294596, 0.07140513254149307, 0.04990710043198159, 0.009970114352331768, 0.11756926144082701, 1.9226761138246906, 45.621695441584436, 96.25053959508097, 93.55695386086741, 85.14988683885144, 71.02776958096412, 46.03089670981131, 25.13637000514615, 34.932656211237756, 71.84374024791103, 69.87266294417843, 68.28553076713317, 55.08666884514594, 61.01688461918985, 50.01153369103709, 16.529873994088945, 3.1242416318385833, 0.16730045659407494, 0.13275166853300988, 0.12293798263154684, 0.23098229670957213, 0.055477563216681444, 0.12962982959804997, 0.5200520458240663, 0.0643795470316564, 0.11508453952809496, 0.027951539546671896, 0.2176387151402812, 0.1994559706579293, 0.13379386986695951, 1.3028580310844606, 1.1623416937166646, 1.6454883424505111, 1.2485547772338315, 4.814656434520598, 4.701517137788958, 3.7157321120462115, 4.046973086172535, 5.793126485040111, 4.397889404527603, 4.899837076663971, 4.182092855053564, 5.715457672072995, 3.9917618036270146, 10.675122660975303, 8.954302380161902, 8.346918456016049, 12.2421742639234, 18.69306898886158, 12.377860815294328, 9.586754172079026, 17.334336426950273, 21.37673112653917, 18.01817617108745, 24.13518894103266, 18.01997850018163, 11.874178474949254, 11.77057691158787, 8.807835194372363, 0.3353250807812137, 3.479556888341904, 29.93488588640767, 64.24222215529412, 59.647408685376575, 63.238036555628625, 55.22481864498508, 56.430539546474336, 52.96305056541197, 56.9024791256074, 58.00668124229678, 60.961912601224846, 57.60253198685185, 61.129590003721184, 63.46478877529022, 60.78307605558827, 64.49117891250118, 68.11473508034983, 66.79284926383727, 69.39453386491346, 60.75105382550148, 46.84155648754489, 27.965650135470977, 12.786038344906224, 4.380815817463783, 0.6039079074417392, 0.045152444677848014, 0.11612166935998587, 0.14087907999994295, 0.036878346525613344, 0.06624853343612726, 0.08284315466880798, 0.3153740981173131, 0.1682967539396017, 0.10446640001910348, 0.03216156998889581, 0.16868785714670537, 0.5821575681048056, 9.540760459438447, 26.623373877617624, 42.29072455436953, 88.02492141723634, 94.40791991449173, 75.11792305977114, 85.76302389944755, 41.76713912717758, 29.544849318842736, 43.43302073017244, 47.47968689087899, 62.54934287840321, 79.05337041424167, 30.52263736724854, 1.5529322960684377, 0.04727225592960754, 0.12184895800366519, 0.04053355885609504, 0.13840611753684862, 0.04740332591257269, 0.08411963335088185, 0.08198346612193892, 0.09199897788705365, 0.1325187931257871, 0.10131835321625395, 0.03800663315961438, 0.0902646161135166, 0.04835271569449575, 0.1629370036384752, 0.05856059596783692, 0.02516819081539589, 0.022993069930723118, 0.03982970791478311, 0.04174862409971895, 0.11888510938132964, 0.06261244649067521, 0.1436929669111006, 0.13663813982519413, 0.3544426517140481, 0.16620694269095698, 0.11302369406386731, 0.11359047655376697, 0.020193570150783467, 0.032463021756660555, 0.06398310036128087, 0.06203917140561727, 0.09208108719077804, 0.06619937357402618, 0.0569779004511093, 0.09938514566109066, 0.1196689858672119, 0.09046036689992874, 0.06606946038382669, 0.04699820329645469, 0.08050395881817227, 0.07975689285705168, 0.05038785507842418, 0.023939713287437638, 0.04064878997122569, 0.06120207096119562, 0.01413396405687015, 0.20951786138597997, 0.11766627881555788, 0.05613104387697193, 0.05124641364560493, 0.010908673566225316, 0.02405867908119915, 0.05887059727683664, 0.004290943691176513, 0.06213623474562361, 0.053466816072262106, 0.11162672507306261, 0.02871098931908848, 0.07791211483098807, 0.10078812844210094, 0.038187196252927665, 0.04832888652961101, 0.11324788203402875, 0.0728321934659635, 4.53284933682411, 68.9683291219896, 111.35166475849768, 108.21769883555751, 114.4806335818383, 104.06376761774864, 79.95288756585892, 34.110711774518414, 20.43862961953686, 54.609516436053866, 69.00799212917205, 72.21808341241652, 59.17700667535106, 62.022956878908225, 46.95957668365971, 13.374062430474067, 0.7328203416639759, 0.05262074473824713, 0.09984158084637697, 0.09273842127332765, 0.16726529315835045, 0.03857518531261914, 0.11455505019834927, 0.10644493699674645, 0.4048953637961419, 0.42381840968324297, 0.8536794144780406, 0.3336524656943737, 0.6616521218130667, 0.20001795743742298, 0.9931103584747162, 0.25847837208740176, 0.619820166499384, 0.8888717163955012, 2.3022312502707205, 1.6240170429791174, 0.57426116279056, 0.6234213926138417, 0.12830288870440376, 1.109770166297113, 1.6417897925261529, 0.620149216584621, 0.8216892375100044, 1.5285389533927365, 1.1089272244322685, 0.3580655734385214, 5.203953145011779, 8.366622482576679, 21.961452576421923, 23.0323302361273, 16.05098593619562, 21.717879272276356, 25.76156835402212, 27.924573113841397, 31.11291289329529, 23.656045929078136, 15.8154466267555, 12.711856519022296, 7.09215517966978, 0.16394341334460244, 4.798720334806751, 35.34798814404395, 65.06910877843058, 63.03255927178168, 63.76424212609569, 58.42245640293245, 58.09188688955, 57.91863187666863, 63.67775778616629, 66.23176205542781, 67.50597538486605, 68.95740139868953, 70.12483212255663, 71.51243332893618, 69.21612877999583, 70.00873781019642, 68.30772353756812, 68.59336622299688, 72.83917503972208, 67.72751085219845, 59.84272703047722, 40.19250362150131, 23.931712065973592, 10.153252290141198, 2.7667045977807816, 0.4430675945214687, 0.06046024504147711, 0.04590218045538472, 0.13861453941752835, 0.020120768815339096, 0.02637743379079527, 0.18788890101976935, 0.19507866683265856, 0.07489948172963436, 0.09579184855664931, 0.2222470251182395, 0.5597472286993458, 6.047682915964435, 10.396580446150995, 28.75704126973306, 91.61395288282826, 93.36431841696464, 72.91944242292836, 59.80320915099114, 15.305014867936412, 32.87092312689751, 66.72155626358526, 76.28175304782006, 83.42638954039543, 91.2929617974066, 50.40030333303636, 2.7866831902534734, 0.1414971750590109, 0.13730043815749307, 0.08840272368322458, 0.12352768647214099, 0.07531687707429932, 0.07340978545647475, 0.05358207783090973, 0.02787069620324239, 0.1783642371094996, 0.09275809441122318, 0.05709679729695763, 0.07629044459111269, 0.03268407642721169, 0.05222011139736541, 0.0713352500010402, 0.0367012461497178, 0.02503386878919217, 0.08679423015564681, 0.028554379879947633, 0.07524032956890522, 0.06450757564556214, 0.13593775160129995, 0.06950629935149225, 0.29327221635368567, 0.12256239270490986, 0.08868508837035588, 0.09838400663988245, 0.0504853091232719, 0.049524087113358324, 0.025811762128385807, 0.12615750543773174, 0.04646794021790547, 0.0913124481937097, 0.1480198315074367, 0.23268345623247086, 0.2461575791840592, 0.2546896536143557, 0.1269232333006878, 0.1887831094885065, 0.21408058913244357, 0.15307086369683667, 0.1146102851376899, 0.2898866899551884, 0.15278355008171451, 0.10615701817216412, 0.14653783441791612, 0.26923571743311425, 0.2405722925980245, 0.3348842125025488, 0.22639974260762816, 0.12533716316665375, 0.15925216668796155, 0.17969269485723588, 0.11875474419925483, 0.15362742657382644, 0.306928867414113, 0.2781974446148642, 0.11982735156291917, 0.24106179213812276, 0.15042047527047897, 0.11883597250186628, 0.19305000472212994, 0.15000769177511816, 0.2371085945877337, 5.320745639262661, 81.06192204260057, 127.4118878764491, 116.17349716924853, 113.99939798539685, 97.31150934773108, 63.21525935203799, 34.77852275294643, 53.11250463608773, 100.64892076676892, 97.00627834566178, 101.13821291154431, 81.73231786297214, 81.33386781138759, 66.97478448190998, 26.324879546319288, 5.991245892740065, 0.5326065721531068, 0.19448879445272108, 0.35066568502976053, 0.37830279719445015, 0.161183612240899, 0.21340070142140313, 0.6498879530737478, 0.23875862540256595, 0.3111804408892509, 0.25915651311797483, 0.2891894580135423, 0.6794354740169741, 0.4433800358205073, 5.400854656773229, 4.033782400431172, 5.221995557508161, 7.902392322017302, 18.819255559675156, 17.321806415434807, 16.191800986566854, 12.226949584099556, 15.17496378191056, 14.721376972813761, 15.946116466676036, 13.677220459907288, 16.281969412680596, 15.243606240518632, 25.701003036191388, 20.7347862182125, 16.92558034773796, 27.276330840203073, 34.68478595056842, 28.013946279402706, 20.319079699054843, 29.110554687438476, 35.08080021027596, 31.747874021530155, 40.698720793570246, 33.834690663122366, 24.59987017416185, 25.399231564614084, 17.700279835731752, 0.6668124287839859, 4.81713439187696, 28.283448411572365, 66.82007835757348, 66.96348021107336, 72.6348352432251, 67.01742064568305, 72.48323563606509, 67.4046213396134, 74.12988585810508, 72.28910184675648, 77.63929320919898, 73.70201018548781, 77.8004006416567, 78.9771116933515, 77.03050213475382, 78.95247136392902, 79.29657305440595, 76.41523914952433, 83.80826365563178, 73.28921994855328, 58.55615431262601, 36.05821171114522, 19.11717330255816, 6.45686996559943, 1.3609531137251085, 0.3213202580809593, 0.20338431631605472, 0.43660092377854937, 0.23443176080622982, 0.12924010534921002, 0.18223541728671522, 0.3506062672503533, 0.44935693123167564, 0.22982096870339688, 0.3136209518678727, 0.4425617926303418, 1.8883401756325078, 16.654466121427475, 35.847686336886504, 52.6879394438959, 97.25538807530558, 110.10317433264949, 88.64834293242424, 114.60046199060257, 58.99651488950176, 34.24863799925774, 55.4149123930162, 67.64951844369212, 80.33042353968467, 104.75304572812973, 55.07416825140677, 2.5251280252010595, 0.2064968396218554, 0.19313418246324987, 0.14647426444195932, 0.27031724972109644, 0.21970428736700168, 0.19145741517986023, 0.13621155142543778, 0.13065301662971898, 0.21659861288724408, 0.13778068335546603, 0.13967958549338003, 0.20390101197746494, 0.1384618121289438, 0.353997707847626, 0.23762827799204858, 0.22682607053749024, 0.1213743971780904, 0.18538193957459542, 0.10917967170356743, 0.2565306088616771, 0.14329676155842122, 0.4127312175208523, 0.2565314362366354, 0.5564466154863758, 0.35295064951623645, 0.379966066008614, 0.27983052956481136, 0.143800571620945, 0.16561472608197123, 0.1154193122901263, 0.1798362137689706, 0.13788992749346843, 0.19494184352938207], [0.048928315856403885, 0.09370718541885577, 0.048161626553102854, 0.07322741056522054, 0.03495770281240825, 0.06660890885658803, 0.04809954661815878, 0.04032208411503704, 0.06001345107271787, 0.0717200406436478, 0.07076837558058963, 0.15230321295319066, 0.15666914803366508, 0.056341997678241426, 0.058166727183326605, 0.045952236640357205, 0.025476150500077396, 0.012731194822868754, 0.01560460580813308, 0.05731612826967913, 0.041572155746360945, 0.013915831054140244, 0.0701838121899674, 0.033955567876898476, 0.11047161770083251, 0.10928549142854829, 0.04896104313252915, 0.03318300650965783, 0.10323382583597016, 0.07711247991650336, 6.710956692695619, 60.4751072391387, 102.86245546033307, 88.06918144226076, 82.8554101144114, 56.94604489111132, 39.82940981465001, 36.570100630483324, 72.51154730396887, 79.42851374226233, 46.800775604863325, 31.460328986567838, 43.63090038299561, 65.85065672474524, 24.36307276448896, 2.7161214668904585, 0.3394917717143413, 0.037777105556620706, 0.09848339122629936, 0.3051397150322315, 0.14077812493328126, 0.15822677332307064, 0.10841816498507416, 0.13013912485011164, 0.04175233579571209, 0.21562554332758152, 0.26723438933972393, 0.7119416265237717, 0.4831949122730763, 1.6763827685386905, 0.32723111671305477, 0.45836949600808086, 2.4680423400094433, 1.3245258167866738, 2.607245541387989, 1.7064832823891796, 1.953120202787461, 1.1801718079274701, 1.072948180860089, 0.46291567625538, 0.23647968236717487, 0.55461076238463, 0.3308814337417003, 0.7417816704800053, 2.2216937138188273, 2.5918014539826304, 1.6041273167056422, 1.4324367166526857, 4.185605337542873, 11.2849090368517, 10.222049682371079, 12.449255797170824, 8.909025480670314, 6.320398449897767, 9.560185017124299, 7.554512898768149, 10.66623947312755, 19.240977033492058, 3.0486396628041423, 0.07801565161395459, 0.2680138991244378, 18.28012381830523, 52.983521415341286, 42.99711988818261, 49.19774386190599, 45.006412844504084, 40.264604630008826, 40.67976397852744, 43.09490849894863, 46.90720911948912, 49.16288575818462, 54.207544096054576, 60.08991872110675, 59.619100939842966, 61.07248029401226, 61.82796409053188, 59.70577355354064, 57.43899660725748, 56.37104111333048, 57.56774448579358, 58.142199131750296, 60.75107343735234, 54.933315938518895, 46.28724713479319, 34.40712528844034, 19.7432541847229, 6.698997386040227, 1.670542359352112, 0.03636857629903863, 0.04848237607568022, 0.030082686984490965, 0.13920994295227912, 0.09441300520613309, 0.16930463453454359, 0.042181950242769335, 0.1453316596246535, 0.09298427420998774, 0.11755777778284204, 0.17199861336379282, 5.035884976387024, 19.809034293697728, 49.26525961968207, 90.40249747614708, 91.7653799057007, 101.13023481061383, 96.73499937980407, 61.4773355760882, 30.03245092207386, 30.19638049987055, 37.16714028389224, 59.069141495612364, 63.9527786931684, 45.89830883087651, 7.094500757032826, 0.2571348683728326, 0.0792221098597492, 0.10702876494296136, 0.04640307555335664, 0.02689097700039706, 0.05279358183484405, 0.04828945981458791, 0.04253629655126603, 0.06678154677032463, 0.026753402930954774, 0.04189513841523759, 0.12400430041335284, 0.024258074530911063, 0.0869999937112293, 0.05756819417940513, 0.018861733955301104, 0.1132488243221756, 0.06538413344852387, 0.12140531648671436, 0.17546578941325988, 0.30357076696330504, 0.26950473686860454, 0.07459063338296068, 0.0623504099466147, 0.04000842473619888, 0.0793967166194512, 0.07012323761779456, 0.053732127642198924, 0.027046148109460072, 0.10878528197926861, 0.05911890935573367, 0.07319467562821604, 0.05274472457747306, 0.08137433429158504, 0.10268608063098886, 0.11212131909785733, 0.06610459317603419, 0.03913817566729361, 0.05364928289406723, 0.022298651446978894, 0.028617266122432008, 0.06882824259059084, 0.05280894572816549, 0.24715332494628048, 0.2081604608364644, 0.10879171711783256, 0.052068054435714606, 0.039824038864143436, 0.053739286733851324, 0.017848984871600426, 0.07474784994678152, 0.06600704720063556, 0.08100471985075744, 0.026731525375057134, 0.023502853563836506, 0.08462786374072875, 0.053880089863894455, 0.022628230132883596, 0.043625413109698606, 0.02390355010697198, 0.12245884060018486, 0.03818218220746325, 14.450584380857407, 86.10362683573078, 116.60096491536787, 110.51803558103501, 116.01845372107722, 87.32007149727114, 69.73662730186217, 34.3783547032264, 39.96486886855095, 73.15731063965829, 57.29758339543497, 33.886481638877626, 46.24334404545446, 71.01008753622733, 21.174562361932573, 1.1922807775197493, 0.3661859522183096, 0.09891879729806416, 0.09272591105752415, 0.1143256145259065, 0.0340809956223013, 0.2563295720685875, 0.4086913601044686, 1.6467866469775478, 0.3837528692618493, 0.4888617259360129, 0.6724750442850975, 0.5167872855259527, 1.2397007620142353, 0.28752937612514345, 1.0740921646356583, 0.7232190536395197, 0.7110693894567028, 1.6768865479576973, 0.8731767198731823, 1.6215030488467987, 1.5827526055997418, 1.2889469775461382, 0.6550378412488969, 0.9728822664868448, 0.5706289254369274, 1.2734276296630984, 0.683018375308283, 0.7550050222104596, 1.5631389161271434, 1.8812080809185583, 0.4287723632108781, 2.3270304356851885, 1.9038276542578976, 6.344732344150544, 12.983971930319264, 7.741321661779958, 9.468478041310465, 11.650442557950175, 10.060494119121183, 7.492892463361064, 14.498061730015664, 22.291531793532833, 5.950037471709713, 0.3072231064640707, 0.17392170855835562, 23.47895287698315, 55.77418188894949, 49.69841480255128, 53.68106003730528, 48.10297112311087, 46.7644505346975, 48.68681200088994, 53.4062901619942, 59.499935411637836, 60.446999534483886, 63.984338083574855, 67.48868557714647, 69.33220740287535, 69.74894354420324, 71.67445859601422, 70.00018704322078, 69.13703810784125, 66.79444174612722, 67.19941862167852, 70.19906690043788, 69.07413897975799, 66.33357894036078, 55.873908150580625, 45.55422282988026, 31.847678730564734, 14.917563142315036, 4.026211980850467, 0.35161400994946884, 0.07736917299729201, 0.13679713371299929, 0.11568382712862185, 0.0996887999316377, 0.129399819359664, 0.07297971135666294, 0.07870706894825544, 0.08402592547598385, 0.06466221815395741, 0.39738240080975723, 1.148788433882498, 10.232828355604603, 45.13083827111029, 88.08662030004686, 94.55399682444911, 101.74276782620339, 91.76769410410236, 26.18894196325733, 30.118743065864813, 47.9997500296562, 64.37432758269772, 80.00439613096177, 76.4402638712237, 66.81019398473924, 14.459608774031363, 0.08156140530181509, 0.010857655940907858, 0.05872362713900305, 0.0816568368745427, 0.0232174264402279, 0.030866486861580805, 0.02476261237696294, 0.038363882941344095, 0.08784697285943455, 0.007989804838753996, 0.02379815364556928, 0.06507688622561193, 0.06941744081315494, 0.14701483140309013, 0.09575030360851558, 0.01610502210115233, 0.05527942223594554, 0.16408682500402774, 0.025004858954719482, 0.056021282629620646, 0.31441976706827846, 0.15157489316357722, 0.11197461326035762, 0.03473271428036594, 0.07295918020029223, 0.019786691278099053, 0.0488784741760502, 0.05428946043755259, 0.020099959952095826, 0.04782077488339236, 0.01513265829999, 0.0190959902360074, 0.11276440394501533, 0.22982014132843864, 0.1531529117135271, 0.19370081173556467, 0.08929616606403744, 0.26473954740551214, 0.15319737545665235, 0.08207517450735455, 0.18177555002752813, 0.15292596582683826, 0.1923377421354094, 0.361666860840013, 0.3121081733655545, 0.3697697115280936, 0.1561036678932367, 0.29438279869575656, 0.14955412175866867, 0.1276126511455063, 0.14190991258909627, 0.18210512105255358, 0.15241925995196068, 0.1402585028160003, 0.15657194679783237, 0.27615802662987865, 0.21057325475398572, 0.15786691118151913, 0.24623120023358255, 0.1350367096282782, 0.1823061272021263, 0.2973755671372337, 18.38919512687191, 101.09326254936957, 131.53513831477014, 113.05271041008734, 117.54132178521927, 74.04175804507348, 57.47426263747677, 50.20449469166417, 105.04556825084072, 111.1620024711855, 66.56454378558745, 53.39536243869413, 61.378687966254454, 91.81804949237456, 38.02453510222897, 5.12397111423554, 0.5572839189440973, 0.11753902395045566, 0.37368742388583004, 0.5433745814427253, 0.3017401845464784, 0.1710065295018496, 0.2831169241859067, 0.7151745175642352, 0.14658539315625546, 0.47871253182811124, 0.48719563791828774, 1.8277520590251493, 2.7948836405431075, 3.5091582805879655, 3.4586732089519505, 2.2811909212220103, 10.180091108045271, 7.519766092300416, 5.290684103965759, 6.373339660706059, 6.130947480278631, 4.057904241546508, 2.6265409060062903, 2.1594447185916286, 1.4290660523599195, 1.7106655095854115, 1.4851092451041745, 4.056738807309059, 6.290485474371142, 9.505176717235196, 7.276042267199486, 9.412895114191118, 12.243184274242772, 21.650812625885013, 15.403834081465199, 21.6722934861337, 19.46588573917266, 15.036895371252491, 19.81177995281835, 15.100373048936168, 24.8621198438829, 33.03121666754446, 12.064664459997609, 1.3806614303781142, 0.5699128477323441, 22.144044791498494, 60.71073970487041, 55.740575021313084, 62.90845155715943, 60.95084759496874, 60.521167632072206, 60.60694986774076, 64.08011059607229, 69.45380872295749, 69.34060127504411, 71.93457449636152, 75.98331559088923, 78.54239540715372, 80.14697428672545, 78.74255395704701, 77.81794932580765, 75.24077169356808, 74.50426824631231, 72.81162431163173, 75.780882066296, 78.06799257955244, 75.12621495031541, 62.03441412218156, 49.016259716403106, 29.76161322286052, 12.073465278071742, 2.560845127990169, 0.1702734140018302, 0.18514174036681655, 0.20323416308289577, 0.5543535407031737, 0.3098136787453006, 0.3177032505552615, 0.19538127156274934, 0.26059660519803723, 0.2434838710412864, 0.15134008721478526, 0.6524851749981604, 7.2391773808387025, 29.857144509592366, 63.65762818244196, 100.96836643834268, 105.80372318144768, 104.90314698988392, 119.40720896567069, 80.2356747658022, 38.67241651781144, 37.35697515549199, 54.11120283988215, 74.00023583442935, 86.18586324876355, 73.60221724356376, 11.424190440485555, 0.29827369797614317, 0.2104602261416374, 0.281754850500053, 0.1359440794875545, 0.13374908436690608, 0.12380984431553273, 0.1434591415548517, 0.16984697881965868, 0.129853404697872, 0.1179001807805992, 0.09601180772146872, 0.28742059163989564, 0.1612788216481286, 0.22253718858043994, 0.1649927546180064, 0.08820809138518187, 0.12670372612774372, 0.33840463166275336, 0.30638457726567025, 0.2613119168146964, 0.4181082048002751, 0.5537735202139424, 0.31908135080049116, 0.31053983816696756, 0.18576129099294064, 0.14560414177756156, 0.16444828060846176, 0.2764096711912463, 0.1318984764117387, 0.17552491607925585, 0.09872697654270357, 0.15204611384580213], [0.11722841360155614, 0.17648983446340408, 0.05481195155410998, 0.13289232227590778, 0.06407514582538316, 0.06692033125868728, 0.06058553489105356, 0.07103845221741546, 0.1219563635306493, 0.14152948864765708, 0.05128440777620962, 0.09555865139249833, 0.0970889503256448, 0.05082457882141875, 0.03342427057965148, 0.02082278880651199, 0.0035704858788859943, 0.02441597482820432, 0.06141433477281563, 0.027971471239241864, 0.0839242962519488, 0.03383613476950315, 0.02547424485636575, 0.06321403235497494, 0.028759476939036, 0.21175537438642597, 0.05638565319860655, 0.1637550016805049, 0.26349345943139446, 18.170954450484246, 88.84670503677862, 96.87573402158677, 81.67953060519311, 71.95837543856713, 41.913992666429095, 42.10071317611202, 40.42893625074818, 78.1889820098877, 94.38797858453567, 34.76299408943423, 24.444571771929343, 44.14982995679302, 45.24532048932968, 6.283846862854497, 0.5194893695654408, 0.08044133113036234, 0.043231402598922296, 0.2826251570255526, 0.051929564891202804, 0.22217997710310647, 0.3655045016879036, 0.48694482073187834, 0.1220837562915779, 0.1411179615364921, 0.6858989271906115, 0.5646177092867514, 1.4642797434522261, 6.268927637607821, 0.9977880300533388, 1.6288340812729252, 0.5767630833771922, 0.8771052187488926, 1.0611042164025768, 2.158874749175964, 6.871770927982946, 12.484578701757616, 19.19333396419402, 24.497990531306115, 40.05547169716128, 55.40977408809047, 61.42144964587305, 65.86850350902927, 51.50004963720999, 37.58256635358257, 24.99199148147337, 7.785332126002158, 0.642515674473778, 2.366055077122104, 3.7712076642820915, 4.604537025574715, 5.634770595258282, 5.036154149040099, 4.280235459727626, 10.67467845255329, 14.357621265995888, 2.568144658880849, 9.18527997309162, 8.941765504498637, 4.216008609341038, 0.32650887966156006, 4.523576853736754, 23.732273271006925, 36.90010532256096, 48.55567539891889, 40.716653869998076, 43.84021374487108, 49.08747426925167, 58.6684831496208, 61.90778432353851, 65.21924141914614, 68.6974580826298, 64.27204001334407, 65.89437546268587, 64.65111747864755, 64.65235302525183, 64.02927667863908, 62.26656744557043, 61.11909766351024, 59.03438537351547, 60.8204052525182, 58.51544011023737, 56.20107696902368, 57.174758295859064, 50.79220694880332, 47.9458958871903, 43.49040500579342, 33.741808937441924, 20.343647464629143, 8.72918971123234, 0.7792452698753727, 0.17314869519923964, 0.006879594049326355, 0.014041767290402806, 0.06522209053078006, 0.05124619914098613, 0.05889187153849391, 0.09754747693096438, 0.05868472902464771, 0.1596998225056356, 0.3752100389570959, 0.30935565009713173, 1.381341961603011, 15.555568029803617, 48.38692326699534, 65.72833761092156, 62.76881125665481, 75.02515116045552, 65.26998512206539, 31.316656489526075, 34.685593958823915, 39.68132857353457, 56.51027348733718, 61.18717039785078, 68.69114306665236, 17.87717676931812, 0.40522597670074434, 0.009089453190925622, 0.04202206003209276, 0.031781237978007526, 0.01874421032205705, 0.0318260119867421, 0.08073232196752103, 0.10466506193962791, 0.0644331502037183, 0.027286770580817136, 0.03683106357892675, 0.09477954763438433, 0.0496782316646028, 0.03684635469389539, 0.12566973725634237, 0.10195546257760256, 0.044313915479447574, 0.07197522453122562, 0.03451971885477824, 0.04888008679113081, 0.03480520151976136, 0.033103877287958904, 0.03706581973200364, 0.005280329966016355, 0.23546680687896668, 0.2295534967655136, 0.05772081421568029, 0.13978366619877278, 0.023197621152165438, 0.127991450980546, 0.0440555906313802, 0.07479775291416915, 0.12077462694217121, 0.12542488789486309, 0.030971885238203312, 0.1165504028059302, 0.033767772913579984, 0.02710953996997447, 0.027054793411685575, 0.06325267766031527, 0.09399303580604254, 0.06134107761505631, 0.0549742472808688, 0.14774246171357172, 0.04358922694659522, 0.015690139524878997, 0.016638778540636265, 0.061091819417572794, 0.05990365535140999, 0.04850840391290765, 0.03588939596328043, 0.006586707623360018, 0.05750071332459489, 0.053926484148588874, 0.09036069120010061, 0.10626641552775137, 0.09703165460978785, 0.03920045095465837, 0.07879248775181272, 0.6123636182277434, 30.379412020406416, 112.1757782659223, 112.21527653355753, 99.4086673182826, 97.80450420994913, 72.7977705001831, 61.963462368134536, 39.0280342871143, 41.218321092667125, 81.68804999320739, 48.948955766616336, 24.09930709869631, 43.13099430453393, 44.8325224076548, 4.865559483728101, 0.7531139494911318, 0.03664503827871334, 0.1811740024676246, 0.13527435010239003, 0.386759978869269, 0.5280329659581184, 0.9864457612556796, 2.7839537109098127, 0.6106215955749635, 0.386203155522385, 0.623422066771215, 0.7511921719677987, 0.19749781927995144, 1.221514692710292, 2.076628039921484, 0.6945100618946938, 0.27505498259298267, 1.2459785154750271, 2.146528353614192, 3.8850806893840915, 11.214948661865728, 18.47476555455116, 26.756189254022416, 34.67763546974429, 53.508773849856475, 68.6124054078133, 75.79801497920867, 78.84841088325747, 61.96605897718861, 48.7182144964895, 30.98697735417274, 10.962392149433013, 0.911279910754773, 0.5755426746702964, 2.957369540968249, 4.600556310146086, 2.2135734269695897, 2.0540818884488075, 4.369033998058689, 13.434217860621791, 16.562361025041152, 5.857228800173729, 11.619816691644731, 9.226007903775862, 3.367848030982479, 0.2358327364368785, 6.4334038957472774, 26.154556505141723, 44.31058437593522, 56.46536627123433, 49.95110565616239, 55.69370662012408, 60.440445253925944, 67.84522118106966, 72.60212267598799, 77.06165359866235, 80.7756753121653, 76.04091951923986, 78.35756547989385, 77.33479176798176, 75.40340100565265, 73.07776497256371, 75.43567426743047, 72.79665654705417, 72.65137980061193, 72.30274385021579, 69.35380397304412, 67.61274230095648, 64.47071198494204, 58.41911454354563, 55.840030639402336, 52.56045064618511, 45.76789786738735, 29.344447581998764, 15.559112871846846, 3.999679598116106, 0.6141856204598182, 0.046025428680642966, 0.09887845510797155, 0.1528395817524964, 0.07208907285765295, 0.11596441449176882, 0.06590538733308354, 0.04456333455539519, 0.06668545636198213, 0.28479658728165014, 0.47985430927045886, 0.556822305004443, 11.136148245103898, 49.92556710397044, 63.250231204494355, 60.3255315749876, 93.56996828509916, 26.260629161711663, 19.090556098568825, 46.13528274720716, 59.61149154170867, 78.40485357469129, 68.42701065924861, 85.24749109821936, 30.130400350016934, 0.22681958943365083, 0.04398621370895736, 0.09388017573303754, 0.026793118844169284, 0.020039921641469966, 0.04276596588052569, 0.04504969696544352, 0.11048476376961316, 0.04842891846032393, 0.06618372239773312, 0.05633936999666114, 0.02716258581307146, 0.0737680771177815, 0.07455556187778711, 0.027913217913479577, 0.035669348698349736, 0.04639160721713016, 0.0824002715789022, 0.03440844075333688, 0.021265210328443397, 0.0056492951473281275, 0.055989727468019536, 0.04702186775243571, 0.015019469766787466, 0.06997190460923218, 0.03774019544042888, 0.07021152925106787, 0.19107444782651242, 0.021277498378748858, 0.12308051328985922, 0.05960592677095725, 0.2274042524157032, 0.21729923093751555, 0.27508415522113927, 0.24544577625009323, 0.2344413675488003, 0.18724584681612833, 0.13644185277723497, 0.14338385043365343, 0.2260559989560035, 0.17412639192996487, 0.11982873818206212, 0.20781690104594155, 0.2660719581669377, 0.15660677315487018, 0.12845576154969393, 0.12228555917259186, 0.2012214815664676, 0.1755036801219948, 0.20236275339078522, 0.13568166372997148, 0.13108084609191265, 0.19724045970266868, 0.1816800801504043, 0.2159722287568354, 0.21377331126601468, 0.441330750623057, 0.1713954876627653, 0.2292322607771043, 1.0681810302119101, 41.162560678297474, 132.029176527454, 122.78249479109242, 108.07210045476114, 98.25319982344105, 61.016417857139345, 61.29219185921454, 61.42091620352961, 114.93978623420962, 136.035971795359, 55.736119208797334, 43.5588268310793, 59.35306226053546, 63.462705996728715, 13.321660545564468, 1.1906647610087548, 0.3318773480432649, 0.3829964646889318, 0.38362477936090966, 0.37538403284645855, 0.3583493017621579, 0.5294895748938284, 1.0073442721078474, 0.6195118927186536, 0.46834736221259643, 1.8233538563213043, 5.037258786539878, 4.966413426783777, 13.324130658180485, 6.3774017653157635, 4.152982494523449, 2.5352553398378435, 2.2992490231990814, 1.5657200808486633, 2.8578359657718293, 7.962081970707064, 15.600804725000936, 23.824472504277384, 36.03941571327948, 55.15233716657085, 73.53565462173955, 74.09556511909732, 79.55540241733675, 63.71285515446817, 45.875731668164654, 27.930231132814964, 8.314766787713575, 0.7339586870324227, 6.040978604747403, 11.885409201345137, 16.653440421627415, 16.94966370059598, 17.379841804504395, 18.592487650532878, 19.539573346414876, 26.179987192153934, 8.694264927218038, 17.842234334638043, 15.992216083311266, 8.166124647663485, 1.0664527358547335, 6.412759480937836, 29.5905194359441, 49.48360227769422, 64.7561114834201, 59.64306662159582, 67.12268921636766, 69.26277360608502, 80.05376308195054, 80.75359236809516, 84.87969829190163, 89.48238003638484, 84.50162103099208, 87.32055787117251, 85.23824214935304, 83.66650135286393, 83.02879456550845, 83.35839133108817, 81.33719398129372, 80.58709559902069, 81.14962623965356, 76.75279832655384, 75.71429591025077, 70.19805492893343, 64.62307645428565, 63.015273386432284, 56.802615581020234, 45.85520590505293, 28.751316570466567, 14.241373000606416, 2.5909740790244076, 0.430462169310739, 0.08979346437920487, 0.14292173087596893, 0.39261178744416086, 0.23688143419642604, 0.29401529099672075, 0.3478899646189905, 0.29539026560321935, 0.3199469382243772, 0.8532236840936446, 1.103809757098075, 2.753620061182207, 26.448885279317057, 65.34057601805657, 84.82245522160684, 72.66323320327267, 105.73334801581599, 87.71191627748551, 44.206712169031945, 43.69842006314186, 57.73847349228398, 75.47985584505143, 81.73955855831024, 97.26441737144225, 29.724019265943962, 0.39455958131340246, 0.12553368004099016, 0.18869657219657976, 0.18572903869132842, 0.14239199639808747, 0.30681888783170336, 0.14522457585459755, 0.30420380073689646, 0.2206139401682923, 0.24680691530867932, 0.13252383398432888, 0.21444440428768435, 0.32604340463876724, 0.26680985405560464, 0.20643173747005003, 0.16274759606007608, 0.14865767631319263, 0.18432168920914974, 0.17078431803853283, 0.16159589011822978, 0.12345968084710261, 0.19976292676743002, 0.26347911826545195, 0.12502649919159953, 0.3332950090689044, 0.27012134571709945, 0.17715288356186884, 0.3171251606075995, 0.07602805181616738, 0.26015975122009555, 0.1740642009122718], [0.02987828323497407, 0.13778169459152606, 0.11785148057125269, 0.07444417269359674, 0.015196528007847168, 0.01619291919914465, 0.06653062233160581, 0.04586547718293244, 0.06694054831900904, 0.027182122970360423, 0.049067215257955175, 0.059267273773589445, 0.037023861096390796, 0.07014201443281866, 0.052850935007295305, 0.060674186585651296, 0.016150623484845125, 0.05552869192474792, 0.023708383462602095, 0.05827812785883585, 0.042981225095929644, 0.047917524127349745, 0.035137798592087724, 0.17366799555959242, 0.12382504349995045, 0.04939481360657562, 0.07277864392005629, 0.36700771941292676, 31.044198851431574, 93.33941921111077, 90.28816038562407, 95.83498016480478, 74.208050850899, 58.341306486437404, 44.54844474792481, 31.838816135160386, 67.30293781526628, 73.66061349068919, 22.99124340857229, 24.600676221232263, 40.471521423709014, 39.035839803757206, 2.827738638847105, 0.5027893882605338, 0.07400802351654538, 0.19274451950144386, 0.18683859447558082, 0.077052709736651, 0.14304853374919585, 1.5606408566236498, 1.9914058451690984, 6.729591873384292, 3.789020863271529, 5.344072955269968, 5.41245702774294, 0.5449780953987953, 2.546575055007012, 0.693204464210618, 0.886414657917715, 0.6638110188707229, 9.939558621375792, 29.536977121906897, 52.42253618855631, 74.88421255542387, 88.52550214336765, 88.03523725078952, 88.49275819716915, 87.26886887704173, 93.130827565347, 86.67007200179562, 93.9774319433397, 86.82103618498772, 89.62029841638382, 103.52937606073196, 89.78255902567219, 78.66727582869991, 55.3088201245954, 24.231610605793616, 7.381730531492542, 0.3374833956120476, 3.42211524805715, 5.813465445272385, 11.336437213805414, 15.083459788753142, 7.374541317262958, 3.3960959603709564, 2.728075380286863, 5.116766210525267, 1.1226394628324816, 0.14054505034319817, 6.227666264580143, 20.878262596745646, 35.975602672946074, 49.638037758488814, 61.82861520398048, 68.65131531992267, 70.52294485030636, 72.35925735965853, 71.22713581208261, 72.7790843286822, 73.61312143264279, 72.34353650000789, 78.52067332113944, 75.87298716268232, 76.97179994275494, 74.60011528384301, 76.000519106465, 74.5321092297954, 74.35619877230737, 65.73385638575401, 60.871686320151056, 55.43243362057594, 55.503761922159505, 54.82222264812839, 55.89502619158838, 51.52875746450117, 49.968462144174886, 39.93480782355032, 30.011972227404197, 18.36379974119125, 6.91711695924882, 1.052883418817674, 0.08248474809431261, 0.02317166992373044, 0.07097510440695672, 0.20814314724937563, 0.09403256594293541, 0.022920722502373883, 0.05891707200076311, 0.5671651048525688, 0.2787621739891268, 0.06598035669735362, 0.13631649014930572, 9.31132043561628, 66.77137036477366, 59.749923752200225, 17.548170320449337, 67.77832123541063, 72.78623088713616, 29.827344302208196, 35.438316406742224, 43.98259970449632, 50.982473281122026, 64.24952560855498, 71.97538283563429, 29.51913622117812, 0.44378508182783283, 0.06728496612800706, 0.05093633189737316, 0.01786000121595158, 0.027728318762514862, 0.10227265362177165, 0.039507468351193016, 0.02549771587514589, 0.027517788224823536, 0.061404490542988625, 0.0606269036389647, 0.1931759802203986, 0.13954176627580198, 0.16907986433755967, 0.09741077620175578, 0.11165577512715133, 0.034856812863220135, 0.01935522481348486, 0.015508984628644203, 0.03132684441703943, 0.052662473547482685, 0.019132967384892608, 0.018659927243847522, 0.1273776230312163, 0.10382568238363152, 0.017117028079566457, 0.06262486094548818, 0.14236221089959145, 0.05587965595505892, 0.09481093425664211, 0.04113781836725051, 0.11843510167372805, 0.05831408036512233, 0.0647379765887895, 0.042037098338046384, 0.04689527172294836, 0.05967942524641272, 0.02660803200166312, 0.00768466052719422, 0.04169006050834733, 0.06894500971200966, 0.12544098340215223, 0.09242545903450058, 0.010619257039751017, 0.05163514198014333, 0.0346229070677392, 0.023569064627912258, 0.04206517163003164, 0.0075623871488196244, 0.05865030103333055, 0.03281325800344348, 0.039913816707989866, 0.027973304104600704, 0.056040668484544566, 0.0652284337387931, 0.19065902898869208, 0.04212737030860397, 0.7245094521391777, 46.915555923215805, 116.58955866290678, 103.04570075004332, 117.81562097610967, 102.25859088282432, 77.26669157705, 64.55244633459276, 30.332447521148193, 40.85621964546942, 82.07805910418111, 30.699063616414225, 25.72273688931619, 38.524688290011504, 36.30130844731485, 1.1751852496977777, 0.4345321186607884, 0.012149805909082776, 0.04439558811305512, 0.26581017060145257, 0.19024460606517332, 0.09585240014618444, 2.2539983545580218, 4.054881810180603, 5.388100089565401, 4.2578014635270645, 0.4271480116632677, 4.116698609244439, 1.3027113099252026, 1.4819079781732252, 0.14339330395863903, 0.963112316544979, 1.7940342618573097, 14.756317446308753, 41.802048221711196, 67.02120181052916, 88.22118113117834, 101.72026126615464, 103.64339936164119, 105.6989174504434, 102.05653390576764, 105.2531949935421, 95.00782289812642, 100.62976391084733, 92.00871590645083, 95.18577298810406, 108.87995181545135, 97.5517858997468, 91.3865730839391, 72.09539167342648, 38.70203041261242, 15.940741838947421, 2.5689516865438033, 4.1450828409964044, 2.876994537730371, 8.841548946595962, 15.701083060233826, 9.095432200739461, 6.6477016095192205, 2.5710692761405824, 5.90059599568767, 0.2562449806399884, 0.26276129388040115, 8.3936172146951, 25.20875930786133, 42.75613338716569, 60.841185969691125, 71.0982467282203, 77.99376564641153, 75.80047822767689, 76.57458151540449, 78.35210554061398, 77.94588919608825, 77.21785806840467, 77.82520571062642, 82.88201162892004, 81.36184215545654, 83.15028605922576, 82.03761946770453, 82.68171971844089, 85.36181249926167, 84.46131475510137, 77.85053637719925, 72.43034639666158, 68.68264721285912, 67.23746561234998, 63.30601907545521, 63.730945125702895, 60.69589745613837, 58.8342817368046, 52.671794968266646, 40.762282802212624, 27.911413561913278, 13.696628347519907, 3.2698949258173666, 0.21858613607623886, 0.0872487118167262, 0.1800063618969533, 0.07774590439493619, 0.06164668157937066, 0.07333348309921642, 0.10072045223487001, 0.2820286196806739, 0.33849631706553124, 0.09315770119428636, 0.2735708251355156, 5.943264519014667, 70.16621312787457, 54.5571174929219, 13.85212286826103, 68.94010374622961, 42.20419314599807, 24.028018020814468, 58.70193312245031, 66.0865794458697, 78.43035682555168, 74.46919441223145, 82.70774072216403, 51.39241979968164, 1.8636835438589898, 0.12267150660796512, 0.09163062749130112, 0.03297755321968467, 0.04780710021394396, 0.03966835447617116, 0.04241035169651432, 0.051231298730858875, 0.026214255147703716, 0.10593397933388911, 0.037226395591372446, 0.0540297374790234, 0.22910115248974294, 0.09341489989310504, 0.12704087376234033, 0.0854717095893237, 0.05164051991737178, 0.14621730323039717, 0.048270066298784754, 0.024754043683529865, 0.016814032644634287, 0.04307417454378259, 0.11410541787383058, 0.06593667436391115, 0.059791741396991484, 0.044382089643829295, 0.015976476377897685, 0.07346971651479121, 0.06592424841777933, 0.04517787879693412, 0.12662177770248345, 0.2056775239085959, 0.2958041369434326, 0.25414030728561265, 0.13375309866762933, 0.20638414808819372, 0.17131720879866233, 0.10500517433449146, 0.1536348116614165, 0.11413518805056812, 0.18628869656353228, 0.22389025307230412, 0.3333218221462542, 0.16517307639362352, 0.16006478679276284, 0.15691952088907843, 0.15195082782978012, 0.1248031385963963, 0.1123845469086401, 0.18154301169899204, 0.2612476267160908, 0.18489384963627786, 0.11673087013825295, 0.23706613799497006, 0.2404720270104947, 0.3213750486893039, 0.1706955437698672, 1.313076785975887, 61.43344033148981, 133.7893166080598, 115.1113271713257, 124.55590032762098, 97.60735804034819, 77.80457404352005, 62.01400210780483, 50.70645609209615, 98.73346267207977, 104.34336985311201, 38.51775746191702, 40.36580962519492, 52.125989314048525, 57.70792999575215, 5.368495102851622, 1.22789234403641, 0.2292867755937961, 0.376189497690047, 0.31363946055212333, 0.3401910874151415, 0.31402624302333404, 2.5947819650173187, 2.6894844059021246, 10.352887203616481, 7.249215216405931, 13.117631596903648, 21.906576656526138, 7.308224333870796, 7.858844697475434, 2.7434942174342374, 3.411942090718977, 0.9123436698029119, 12.172442366999965, 40.92923456622709, 68.8573182013727, 96.02771759033205, 111.18130837717365, 117.60843353886759, 121.61932376123245, 113.55349509946763, 113.37585095436343, 99.79269873711371, 106.07220157500237, 102.12802302452826, 99.15535280781408, 111.23751594174294, 105.63306869999056, 92.29642960333055, 76.453654842992, 40.075464017929576, 14.45745147043659, 1.242147953279557, 11.77628101841096, 17.22785584388241, 23.642182311704083, 29.28433922029311, 14.360450275482672, 9.500117840305451, 6.1682256863963225, 12.51396902145878, 4.0785089423579555, 0.3924879876355971, 9.580285203072334, 28.743585578856933, 52.08852283416256, 68.3592007237096, 79.66343233662268, 87.96385011365338, 87.054974186805, 88.66837839926444, 89.38986701350059, 88.5312758722613, 87.74512306336435, 86.39917742821478, 91.54744517418646, 90.53548151446928, 93.49036770482218, 89.82767412739416, 89.44325047154581, 92.9198040500764, 91.14979528611707, 83.6998022756269, 80.98946017603721, 77.11883391103437, 77.70742477909212, 70.68027111791795, 73.126096417827, 67.11558188161543, 66.08231190712222, 54.85826138527163, 41.785468362992816, 27.232768997069332, 10.560579646018244, 2.0455292828621405, 0.16610489977944284, 0.17852059565484527, 0.4101435563737347, 0.4262071024746664, 0.20121858575411383, 0.11707073738498074, 0.45319959761634954, 1.282249040180637, 0.8907767012715341, 0.1289363821307498, 0.6640132660827329, 15.247808079565726, 82.54345616986676, 78.87990751574117, 24.3156454255504, 100.61460002776116, 98.03278615397792, 46.54360148214525, 49.22757740943663, 58.63806516893449, 72.40253679213986, 78.03251081897368, 100.03907849711757, 53.07889384608115, 1.2807834220509375, 0.20552263625206488, 0.12230486458828374, 0.08351891316593656, 0.1436038402419898, 0.11799287741943715, 0.11995495116758732, 0.20078239061178701, 0.19648453010426414, 0.29558050055657664, 0.23299692408932796, 0.4142985721268962, 0.34082173099440916, 0.29658986736209164, 0.35576994500813947, 0.21776944038368043, 0.1898335386067629, 0.23095681662521056, 0.13990742004206105, 0.13291355823316883, 0.19135633753913064, 0.13042469178476643, 0.13666118374995648, 0.19580428999277855, 0.24204918754196939, 0.1890537223868793, 0.21113557861216609, 0.1448874358808802, 0.23920090328301155, 0.14527178219249173], [0.07955400979206448, 0.10025337608831544, 0.16057170717225921, 0.06691702175885439, 0.04419784932847946, 0.07550076115876436, 0.0448109801377981, 0.030677613629508885, 0.037361924206056905, 0.10989936534315349, 0.06316802494468228, 0.05558261302329841, 0.04696172601994007, 0.06469962622730002, 0.06891954494940658, 0.014458459749397252, 0.05146677883702421, 0.06362628341922838, 0.05149595529562043, 0.01856654112587773, 0.06906720839681164, 0.02207106396165346, 0.22867899207818895, 0.08648725106350838, 0.1429906634673957, 0.027999414296279994, 0.16086979198359674, 38.95836514811362, 93.2796815133864, 92.40045086030038, 83.06950876789709, 66.58634431900518, 62.2599543294599, 47.460577103399466, 42.21727425052274, 60.3233075910999, 86.62956176265594, 34.351725732126546, 29.8008486916942, 63.57795307713171, 29.944770259241906, 2.1203891884896064, 0.08158935218929284, 0.07156148342595947, 0.14053450897336006, 0.10603002377695615, 0.06695701920938107, 0.6425067265668224, 0.25349253398035804, 3.1035182793294234, 7.601456315286699, 5.564776389829574, 1.5871752005430961, 0.8309417410242943, 0.5324431809206163, 0.5593822031251846, 0.40616792776892263, 4.917626496284239, 28.843382443151167, 58.08762327317269, 85.74236085337978, 82.5778632010183, 80.93111884209418, 74.19295757047593, 72.88914603571739, 67.59266761041457, 71.24887358757758, 71.1840368086292, 79.56199199922624, 81.77325956283077, 80.93034221280007, 79.64058845273911, 76.5975195361722, 75.9368041253859, 71.89717861913866, 79.94078313150715, 87.84137802739298, 74.94868063157605, 67.94104468437934, 69.50466617461174, 24.870666688488377, 1.9121609748371187, 2.6363117752536653, 9.025003102517898, 11.78685082543281, 10.823138202390364, 6.247190842705389, 4.616134983877982, 2.8233759826229465, 3.932275627889941, 25.37692700662921, 43.036206306949744, 57.915925441249726, 59.81208155232092, 58.07425191325527, 54.47964283727831, 54.58928877307523, 63.699519095882295, 64.96742917645362, 68.83099909751647, 68.70926441684847, 73.66977614741172, 71.28680290714388, 70.52569050942698, 71.75020740878198, 70.55980728518578, 71.16014172953945, 76.77044114758893, 74.12919552095475, 73.66014280626851, 76.72404735319077, 73.45406147741502, 68.23904283585088, 55.38795786519205, 52.03489618916666, 53.53322198314052, 54.97378695395685, 57.6093255319903, 50.61213877893264, 43.08443969295871, 30.08052545209085, 15.446433963314181, 4.378027012271266, 0.4701963920266398, 0.0549543634687941, 0.027112253836446235, 0.1332056215934215, 0.10253748255631617, 0.056708919320015184, 0.07772501317724105, 0.11929720339755859, 0.038652564023411086, 0.0032664282151663136, 0.5587272898804757, 14.404764233096955, 89.8474193388416, 101.3829452760758, 29.90178304333841, 26.79526390567903, 53.06400452890704, 19.584625690214096, 31.7093583076231, 33.12378852598129, 56.30131313877722, 62.970452462473226, 73.03867463142642, 40.12858467717325, 0.6311162861604845, 0.09759364138928153, 0.058478080637512676, 0.19711325846372113, 0.07475022481934679, 0.04828085664719824, 0.03144371112988841, 0.11660147022696273, 0.031315914257579756, 0.0042405585672015385, 0.052782672742802295, 0.06739030321759563, 0.09118453449299259, 0.08112787614546477, 0.07341827371067579, 0.024812798796882553, 0.06076801703461717, 0.08049179334193468, 0.04373387583801824, 0.037991621666738105, 0.04350760410870275, 0.03136544567232411, 0.03732682205736637, 0.030236138226163965, 0.02659833332854173, 0.05201720918018011, 0.017792752102738427, 0.03323868194955491, 0.05610163376155881, 0.07299526294152583, 0.046146455250920794, 0.03914630002973061, 0.01730094663798809, 0.019942032841725216, 0.06692981542718988, 0.04761211934589571, 0.05793939825267561, 0.03202052362593672, 0.050130457196745186, 0.018192764912401477, 0.03710109042003751, 0.028721578569421848, 0.05748631853249766, 0.08832208526831481, 0.010846528513807683, 0.0271326509274302, 0.0443632094069354, 0.01362872236753784, 0.02705567632801831, 0.041631397325545556, 0.022180457486801093, 0.034709206872409394, 0.0890223126137449, 0.17527642780013625, 0.08822976401255977, 0.951600527811435, 58.08540713402533, 115.03214236228698, 107.29262351989748, 112.88236971824401, 91.42584385410433, 88.61820344002017, 69.10583173075031, 32.875220083421276, 28.123296076251616, 78.3883325515255, 38.11735406998665, 32.21602459107676, 63.535442429204146, 23.87449056871476, 0.8048760590534058, 0.18478812950272716, 0.11092158710403789, 0.16355407213972462, 0.07930328453620596, 0.13887169981195083, 0.2975125130145781, 0.40290402548928417, 1.7484194256605643, 5.556306031442458, 0.9695997329488878, 0.3006137901496503, 0.621399104354843, 0.4207891754565701, 0.6611662994950049, 0.9585065346571707, 8.862296323622427, 40.070227653749534, 75.92571950727894, 101.37982306941863, 97.5408503317064, 92.19536581347066, 84.74503547914567, 80.72299003601074, 76.95910715287732, 81.29062760260798, 81.26258265587592, 87.13121721821447, 88.9556763249059, 88.73298768074282, 88.46817278092908, 84.44776688852619, 82.84795761108398, 80.285747743422, 86.02726613321613, 95.54386185061549, 86.46088415576567, 82.77329921722412, 85.79312416814989, 40.537327028089955, 6.778098844712781, 0.8455322226209026, 5.306421143393363, 11.551478216725013, 10.557357418921686, 5.763100741371032, 0.8673280982240554, 1.7771662315053327, 6.226638603594996, 31.961813819023874, 54.25225127127863, 67.94126433710899, 67.04039789015248, 64.4480328406057, 62.96727142026348, 61.05580629840974, 72.77076890391689, 75.83018625936201, 77.70771503448486, 77.68175678868448, 83.91626219595634, 76.98523798296529, 79.05983448028564, 77.60783580041702, 73.70958035992038, 72.52483629411267, 77.24391829582953, 74.10649284239739, 76.93609068470617, 85.9152824647965, 85.11967674378427, 80.68535881657755, 69.24629180662095, 63.139840018364694, 65.87834081342145, 62.14844134546096, 65.4551798297513, 60.5026501224887, 52.99540619696341, 42.03946144350114, 24.172306329973285, 8.883700697652756, 1.5414124174464134, 0.15174370829857167, 0.07227633538986407, 0.08072512074103279, 0.1028230571518502, 0.08058704105356047, 0.14058808916278426, 0.10491400987150208, 0.10695454634485707, 0.04223361904282243, 0.5811856170335125, 7.75790544286851, 86.98683477217152, 96.1698172169347, 32.99938271122594, 29.878333153263217, 27.682437358363984, 17.225341604601955, 50.38200547618251, 53.49669294972574, 79.99529623216199, 72.00381217464324, 81.80117114897698, 58.81170849646292, 3.1565725034283054, 0.23412350234725784, 0.03185453727060268, 0.16791608485002674, 0.06523737398486945, 0.04362625963685494, 0.021687322859502128, 0.04458598011443692, 0.1216080999602714, 0.09412471865934711, 0.06501677130619365, 0.030440829258652467, 0.07810407348217503, 0.004042168129085293, 0.0498882201950877, 0.06349373488656937, 0.03834557343995379, 0.02955876328351517, 0.04720590505448561, 0.02262309542857111, 0.06701944005345145, 0.07596699460860222, 0.03826745545431491, 0.04582546058020765, 0.0943573106140379, 0.00838446173621642, 0.07683104985663969, 0.006620495452455456, 0.04320988318912926, 0.2153255279746748, 0.18494888539275817, 0.42531326172813294, 0.1251675972654935, 0.16509306617081165, 0.15251252349586258, 0.1449193970690812, 0.24423966274386455, 0.19491162902164846, 0.24555223182805125, 0.11900612829072822, 0.13713828798743988, 0.22050697897230426, 0.17997746506044943, 0.22935745486569023, 0.13148010047453065, 0.12930163753128823, 0.15698401017054436, 0.1605508695807188, 0.19585177212232546, 0.14586957592156627, 0.13795613281188474, 0.28355383945088236, 0.22276909871687814, 0.21110164091712047, 0.21490738186384403, 1.6278212517499926, 73.02533857284054, 131.45705961412, 113.79862754575669, 110.20109238163118, 88.23981238949685, 77.61280152105516, 62.51422197588029, 61.82895645018547, 85.44601794212096, 114.04877278112598, 49.571377077410304, 46.01641924150529, 87.07749643633443, 45.07147712092246, 3.5903319764521817, 0.3881961792226761, 0.29102705779575533, 0.3611264011311916, 0.17908446701063266, 0.15793490914567826, 0.5490631213591946, 0.7649013460163148, 4.878853867130895, 13.33388755398412, 16.624491368570638, 4.393981252947162, 5.075125348183417, 3.7013345620324536, 2.4009119551027975, 0.6340924458157632, 6.076079405123188, 39.52033881218203, 77.76807246669647, 112.32717390983336, 107.82236314588978, 102.11916631267917, 94.33992170518445, 87.66560877523115, 80.4103143753544, 81.88031673431396, 80.7817549859324, 86.21169597871842, 88.0419445037842, 85.38909650618031, 85.96908169407999, 82.55403087985131, 82.00542465333017, 78.46641909691596, 88.97893598002773, 97.15200224230367, 95.16678871647005, 94.90915175407164, 95.49093338751024, 44.41540187405002, 4.717904310072623, 5.807573064681023, 19.17574997871153, 21.767365855555383, 25.86933155213633, 19.902624007194273, 14.81648366297445, 5.239597683952701, 4.863660075972158, 33.85175689574211, 61.693458172582815, 79.44694103733187, 75.23755535002678, 74.0169608208441, 68.76378536224365, 67.85836112114691, 74.77347620071905, 80.21517645928168, 81.00427104580788, 81.523467340777, 85.40933593626946, 83.09622010877057, 79.05806156896776, 84.6942094064528, 80.26209585128292, 81.18215837786275, 86.19512788711056, 84.95118741066226, 81.5767409724574, 89.69009307123001, 88.61174721871653, 88.46283051275438, 77.51902549497544, 73.13031688813241, 73.32774546838576, 72.52404397533786, 72.76596007808563, 68.2566935016263, 57.42382487943096, 44.158608221238666, 23.727127121340846, 7.64567074275786, 0.8610995582515194, 0.12610093750540288, 0.4648642055690289, 0.2636945728332766, 0.24197567374475543, 0.1655958803190339, 0.3960899491944621, 0.3640202522998856, 0.1476106639470785, 0.15845359663569158, 1.0868756593235078, 17.897649580432525, 102.18836476725917, 128.26210867974066, 42.73315222032609, 46.22133170404742, 77.02196705725886, 29.794874921921764, 41.80555874301542, 45.429099221383375, 76.1371744832685, 76.69641817769697, 95.72545974485337, 66.51162316722255, 3.2251495074841285, 0.3552304352483442, 0.16558680983801044, 0.2752819897667054, 0.17588140743394054, 0.17209550816445582, 0.10199778127453982, 0.25071618537749013, 0.14929630252863133, 0.1456385850906372, 0.16385603335595902, 0.16504740733052456, 0.16326110479572128, 0.21329412326937724, 0.14463905485407, 0.2703750433941042, 0.14988505642019934, 0.31655417995587476, 0.16763911342188237, 0.09339385545782505, 0.16703704492219035, 0.1654314012416909, 0.12816199747424933, 0.182997444944997, 0.17044766836108702, 0.17050851106403336, 0.22011664185312488, 0.16364655427394376, 0.16993785216923685], [0.04796725472495441, 0.0550909914196499, 0.0517702262638317, 0.07580269173148178, 0.07315699942409992, 0.12597342217040639, 0.03377155738792593, 0.0375427401083852, 0.08292200043797493, 0.04321973891027513, 0.031219086489610137, 0.03556665078166031, 0.11334101534298352, 0.03700146834636408, 0.00574707190671395, 0.005529331524045237, 0.02137985538631197, 0.019910998619912613, 0.035449067776602124, 0.06590245321633355, 0.013243350455717695, 0.04160980513739971, 0.10849516448234359, 0.11918796692043544, 0.08661639816578358, 2.1829887455509556, 50.20527916569864, 94.42610402261057, 86.56460731260239, 77.46941535703598, 61.26199353125788, 48.67275814856253, 39.83344201118716, 32.4118253877086, 65.45727829779348, 79.65438735100531, 42.839542588879986, 52.686574459075935, 66.71389195226854, 21.18545086153092, 0.3100368861229189, 0.16743438408499764, 0.03015862928042489, 0.08058369324933137, 0.03102866192949155, 0.09143911317111024, 0.08467677079381482, 0.19929156818937874, 1.2468684032078714, 1.488772493696982, 0.7653955646580266, 0.4701405901822352, 0.47696925279113556, 0.1214089400825962, 1.4477071166038515, 13.57741378968762, 48.03737732671922, 81.45828539325346, 83.42153364612211, 86.13295047513901, 73.4877154134935, 75.13525209119244, 77.09788060957386, 83.06596294526132, 89.80981165362944, 92.85772077498898, 95.17169167918544, 96.32886932742213, 91.80677660049932, 90.20973651639878, 92.10377846994709, 97.77505505469539, 95.07546024937784, 88.56382369995119, 93.67100069599768, 92.37003680198424, 92.9357994756391, 91.27962573882073, 79.37523226584159, 67.98089596533006, 84.2438663974885, 64.75957101391208, 29.888823532289077, 2.024707135654265, 4.779301660676157, 7.67712373887339, 1.8419039706068656, 2.603761986378701, 0.381656822057501, 18.341397123952067, 65.20432072301065, 47.54771255677747, 63.600781271534586, 66.35941167031565, 73.1306306777462, 78.70684469899824, 80.5601724501579, 89.57017837032195, 92.06051472694644, 86.96059411571872, 87.05797087761664, 86.03111790072533, 80.38904728428011, 80.27816972424908, 70.82648138846122, 62.654015248821636, 65.95122629596342, 61.30163692658948, 57.82149830172139, 68.81665891216647, 76.3373879463442, 79.86897237839239, 80.82836058831985, 71.46157587728193, 66.26670252892279, 63.30935701247185, 58.96770900295627, 56.758434003399266, 53.03354340214884, 52.318601223730276, 49.19910884672596, 38.326796870077814, 22.304544256579494, 10.004595441202964, 2.6452944932445406, 0.08283987581249207, 0.035036161707173434, 0.033999916706835075, 0.12664085329179803, 0.008101003458573213, 0.052991335941178185, 0.03460696477803492, 0.09604075818412727, 0.22717402767269845, 1.1197519855153177, 7.565471510733328, 78.1144569766137, 85.46763804651077, 48.70658466892858, 41.39824413484143, 66.95878905634727, 22.992110252380375, 30.85210861698274, 32.17847966378735, 55.54427216129919, 63.26137858052408, 76.17408398658999, 48.667062867072325, 2.7943663779766332, 0.1121409998966321, 0.010642888936995259, 0.07425784478865324, 0.03309870236403039, 0.06144833758533482, 0.06813160819752563, 0.027794217645761468, 0.03893019428717033, 0.03204198366391563, 0.02016025490217632, 0.050918934040612755, 0.1266266193781649, 0.09055978212986263, 0.12743199229120247, 0.16065453659863244, 0.07530040618392729, 0.03249908534569606, 0.016784593800923998, 0.02678739808259472, 0.03292183181451213, 0.04251024190096125, 0.06328925835869967, 0.08209568268108754, 0.013428012119425882, 0.0561813298883217, 0.02240306157017908, 0.008072215789598564, 0.018743823447655288, 0.037675468671706416, 0.04525840229865524, 0.10058144558100932, 0.03263063413361388, 0.11778606432339839, 0.048948134551005024, 0.09198358718065486, 0.1691578980535269, 0.03974551868234431, 0.047653507246004964, 0.01834789197140884, 0.061880920623098655, 0.032173536282273076, 0.01526637224390382, 0.015461981304049974, 0.05078503719320701, 0.015117126824935118, 0.00512765295195183, 0.04769321741356004, 0.059854874702831434, 0.0627397473210529, 0.032244077658340815, 0.03503131620105236, 0.06558713908757895, 5.969475757691169, 70.38605413129254, 109.83566868689753, 98.52373353896603, 104.29619942941974, 79.4305298405309, 76.31493629947786, 56.215566204440215, 28.302836687334125, 31.372826791578728, 68.05813527876332, 51.186303169496604, 54.985048078721576, 62.876335190188506, 16.69323482821065, 0.2336977872877352, 0.09552618458626733, 0.07431759198586788, 0.06806865109190827, 0.14475222136224472, 0.4355314650362538, 0.06315001038714282, 0.13334675031083246, 1.4015398390831486, 0.2570700266909215, 0.5171206257035655, 0.18186826198812456, 0.5275294929742813, 0.8567221318521808, 3.531875913181613, 21.724627710157826, 63.16187981636294, 99.78439115708875, 98.30426123834427, 95.69208037468695, 85.53930759429933, 86.553922776253, 89.2445981117987, 93.54985437085553, 99.29695821577504, 102.89436786405503, 104.20497294395201, 103.50144878510507, 99.86231296293198, 96.26213412131034, 95.30618975239416, 101.74475254551058, 101.21239277624316, 94.40501736056422, 98.18221276806247, 100.50993550208308, 99.32805476650115, 100.11257586940643, 86.07148693453881, 78.01930812097366, 101.19321238610053, 86.58225797837781, 45.901062334737475, 5.658823549747468, 3.260869061754596, 2.8963377062351476, 4.02616074489009, 2.1115520884913783, 1.7054384610345288, 26.03546157959969, 76.60889440967192, 58.99768767818328, 73.5433267777966, 76.18324664331253, 83.9039537983556, 88.65971780592396, 91.10338580223822, 95.40476675956481, 94.43173654617803, 88.83124305355935, 88.81754613691761, 88.15651693651753, 85.232664538968, 83.84760502846011, 81.62653938416513, 73.93189245654692, 77.13376245191021, 74.05428609540387, 70.52037962021367, 76.63024779289, 79.91523281220468, 80.7926199513097, 83.06616690851028, 81.04407525831654, 76.83705083785519, 76.30982937351351, 71.99219411419284, 69.52820824038598, 66.89093989710655, 64.22118648405998, 59.42672829474173, 51.267974761224565, 33.354490572406405, 16.8366680606719, 5.030586344580497, 0.6410301380580472, 0.17485734706203784, 0.03060851632917841, 0.1611118298023939, 0.07069130713540701, 0.12091579396397838, 0.009069714935556536, 0.040623918926763924, 0.06910110778746105, 1.060342786292876, 3.01448856630633, 77.48748179404967, 92.74590969085695, 50.24601690230831, 33.99668847360919, 26.27430646650253, 20.265917854924357, 48.433281760061945, 50.4012760808391, 79.23063801180932, 83.4815380650182, 81.96324348449707, 69.07515095126244, 6.915717163393575, 0.17235951738492136, 0.12106187160938017, 0.09674198910473816, 0.035007483205727996, 0.05387904798431743, 0.035711832104190704, 0.04678224311060002, 0.07657984962626811, 0.021328795626158678, 0.013047018400093001, 0.08583118868691307, 0.08509392099034402, 0.07668512542882273, 0.08323116288069757, 0.040539358141681844, 0.10107754879901487, 0.009468699272181238, 0.028107800415807196, 0.04433298723832254, 0.07404483404130706, 0.032643067740624955, 0.16203536411687253, 0.049260621815319025, 0.02923995004816642, 0.05528728612848828, 0.11604234095542662, 0.10083384090854276, 0.15827905116302354, 0.14353031112301734, 0.22917835883075194, 0.25485640031195456, 0.18273245513198838, 0.39705430067354636, 0.18349981476222316, 0.20232124674704768, 0.26139961856026805, 0.15398345827575655, 0.1327014897739695, 0.1953842133403786, 0.3137621571940761, 0.2567436885569365, 0.13112010043715278, 0.17224535496244509, 0.14297025488509288, 0.15625533798048574, 0.11657609739491057, 0.1970189683620007, 0.1900221034884453, 0.14935044962311947, 0.140033119748677, 0.21900279597649652, 0.222672893395347, 8.713428647287431, 87.33998144826582, 125.50418038522045, 106.94877286111156, 102.93932607097011, 76.6580887763731, 63.94883671114522, 54.836523609776656, 49.813053915577555, 90.57173990434217, 112.93539231823338, 62.18109507714549, 73.43213542815178, 88.23803163343861, 36.14649641898371, 1.0328213534047528, 0.27111303121332203, 0.18105600960552695, 0.21784316868551318, 0.25422728890853546, 0.3405949383253052, 0.157391109293507, 1.7566503968931015, 6.085670090490773, 3.15094169589781, 2.081475599158195, 0.9274221800508039, 1.0520369223048611, 1.024470382159756, 2.0136793919147986, 18.780671204290083, 65.16721902355071, 110.73032994424145, 108.21460016312139, 105.66920941875827, 91.68791309479745, 92.85897593344413, 92.06999117328276, 96.18562436872914, 100.72095901735368, 103.93848711444487, 104.36128724005916, 107.39534254997008, 101.7045953196864, 99.09312048266011, 97.56192130427208, 102.23289935819565, 101.32680046942927, 93.43275593173121, 97.73683547973634, 99.62887702449676, 99.8335070763865, 99.06192979504986, 84.7426663675616, 76.80384405197637, 114.32753562927248, 97.89562871379238, 44.87900641656692, 3.3703772242992156, 9.098309259260855, 16.114282204258828, 12.449098902363932, 7.3883230551596615, 0.892045955744482, 25.389451134589414, 83.60982310387396, 66.37091990440123, 76.90664152945243, 78.20860955022997, 84.39788218467467, 89.37064739965624, 90.09463848606234, 96.2323005737797, 97.31131322922246, 90.03808575291788, 89.51934445288875, 91.05644287601595, 84.85239075076196, 88.600035021382, 90.3757155326105, 80.1993771522276, 80.0044039757021, 80.34715637083977, 73.09427815098917, 79.39673469912621, 84.84815459097587, 84.8663700780561, 85.68076395219373, 81.09972584632136, 81.32681538981777, 81.11650574591853, 79.55611628870811, 80.28568498549923, 77.9284268040811, 75.56804641600579, 69.81287033327165, 57.5001581253544, 36.91206855158652, 17.293253521765433, 4.302165431361045, 0.38984985661602795, 0.26678846488075875, 0.3244174596282744, 0.33626773665028237, 0.242643702414728, 0.16252187591406608, 0.10729714852547455, 0.2720487003605212, 0.27968892587288735, 1.474158232731204, 10.650078327425065, 89.48224667579898, 105.20144324148856, 65.55076799085064, 65.62913302452334, 92.64082154920025, 37.326725836723085, 43.76780679149013, 43.6246677367918, 75.3751991641137, 81.98058820539906, 94.55919004255726, 79.80996424152006, 7.67199965253953, 0.3617704972144096, 0.20989554273265026, 0.23338503955352694, 0.20022870822539254, 0.15303349392789026, 0.11825138612860635, 0.14017159780186994, 0.18457599975649389, 0.103474339139798, 0.15255341726926067, 0.19640127166865334, 0.33105588728381746, 0.20489255957786115, 0.28215959007220887, 0.27071840400176667, 0.24722829431055054, 0.08370734781267182, 0.08612808606196797, 0.1071543190928717, 0.1666537864554313, 0.13205842024856998, 0.2653698845496101, 0.2995116960617804, 0.19746447913348678, 0.10852541729447343, 0.26335072192934256, 0.1970227988016221], [0.029615997712338166, 0.028620642654958273, 0.05406291674702399, 0.06457782590821867, 0.08166938539474242, 0.053869782150873256, 0.04641952346109095, 0.07489132289324077, 0.08663365046583837, 0.12693206629445478, 0.016268365453147603, 0.059054661391963886, 0.046928347569079175, 0.05516280067123233, 0.03722132025887409, 0.03127383304789903, 0.050794552005226576, 0.05323651089002529, 0.03316686503709324, 0.025040629515123945, 0.02452598888457062, 0.043860843420148864, 0.1092206497466372, 0.028069829267840234, 5.1152065780855, 70.19454832999938, 99.86152848889752, 88.49074209890058, 79.81951913525982, 59.46668547968711, 75.36615417849633, 37.49565839767456, 44.85577814040646, 65.39851334787184, 61.732658340084946, 63.256538375731445, 64.73953162470173, 50.003908603422104, 23.082477738780362, 0.5984975493723347, 0.02932446295275323, 0.2538116862096133, 0.04014041019423355, 0.06982859254123704, 0.10181573580109304, 0.38035514674359755, 0.9294828952800844, 0.9320834267043299, 0.8927511243570236, 0.5275237319930908, 2.2542170266951285, 7.22035784875193, 14.597178063085003, 34.06340406787011, 62.97675571134014, 78.9327653761833, 80.85193403305547, 77.14146598692864, 80.83889607460269, 82.86734196447557, 89.5129039210658, 90.51436347346153, 91.58848101092924, 93.35475567848452, 94.31616783142091, 89.2611740481469, 94.2624548942812, 95.05723691755726, 94.8303670267905, 97.29178767050468, 91.93718756398847, 92.57880887677594, 96.81507848924207, 92.04020469419419, 90.97303759667182, 97.74029501022832, 94.08388506981635, 93.76951494524556, 99.79942167958906, 91.67634994752946, 84.8496921600834, 78.01031020379837, 72.58569578970634, 72.41867342302876, 15.327131152153017, 1.2606894873803662, 0.2926688455045223, 10.026815668229135, 43.04596516393846, 55.500678939204064, 51.32722608504757, 73.33553529554798, 93.37525398500505, 93.30473761404716, 95.51678180694581, 94.63123613788237, 91.20128031699889, 90.54605622445384, 87.56837321865945, 86.8726545764554, 95.64661225964947, 96.27864729973578, 94.01115648208126, 94.00361768661007, 96.0833054204141, 80.68224445466073, 92.18234354449858, 84.65107902403801, 92.18865071573566, 89.10396545164048, 87.47490313745315, 76.77169630604406, 69.28510758184618, 82.70996078368157, 86.38757505724507, 83.0216323175738, 73.29922983723303, 64.41857976298179, 56.63695427679247, 57.443248456524266, 51.17610892941875, 47.996314033385254, 37.98589975603166, 27.018637003437167, 14.178831788801379, 4.87555907618615, 0.6290035382393868, 0.19497550543277495, 0.05934287516039707, 0.3220217494714645, 0.17945448747806012, 0.010914405819118745, 0.0850303816579042, 0.036010916660269426, 0.4533617937516782, 0.42687169907073824, 9.999534603088133, 72.89384503518382, 96.36386471409952, 49.01204709083804, 51.623839639848285, 67.61336988018405, 29.82360039987872, 32.44772488071073, 33.45776265667331, 41.8955026134368, 52.6188547380509, 74.135847860767, 61.010836324384144, 7.538361558991094, 0.39939745719875064, 0.05122422773931777, 0.0769900514053241, 0.05038138163546401, 0.1280358994019128, 0.11064384958796925, 0.0649484669068648, 0.06074645165954867, 0.07786262555107956, 0.0389302249306873, 0.130884038104165, 0.03246155469828556, 0.017942321193855137, 0.06975856444407856, 0.05898012869781064, 0.05894914810215274, 0.06947729526267898, 0.05559352594577978, 0.0770812388509512, 0.0234615269507612, 0.06522127081670108, 0.04993107132313233, 0.04831349199277259, 0.07049770905606209, 0.08795282322793238, 0.0417530176139647, 0.03807805170635543, 0.06581391643492446, 0.11550818615022207, 0.06548016256983243, 0.03754155267210257, 0.025835338484255538, 0.03072673901765337, 0.03466922091320157, 0.03997572810359059, 0.11523691441623435, 0.08325617565142532, 0.024529124099400737, 0.06064062427368857, 0.02630948945279083, 0.03790778866518409, 0.033070008540826465, 0.09644780368093522, 0.02817014273586533, 0.04072280555603005, 0.05093257806654419, 0.024402114382434278, 0.015796599890886536, 0.10313312357832348, 0.08079228366935447, 11.528631391063815, 93.42377370403659, 107.68962229451826, 100.88270187377931, 101.3384420641007, 80.97865012384231, 98.5842086422828, 45.80217938269339, 22.36218740863185, 35.07407334543044, 58.52950965204547, 67.76809953874158, 63.36739632391161, 49.49094495465679, 17.8848018569331, 0.15917085411567844, 0.039754524045894225, 0.16890436891586552, 0.12994168867026606, 0.01104083330926275, 0.18272962060666856, 0.13620438084246653, 0.35593082347223837, 0.7092875915188944, 1.545578097143481, 2.4030535692168824, 6.571971918306043, 14.728184246247816, 26.92448050745072, 50.093868163324174, 81.31962960766208, 94.43546279784172, 90.33979446657243, 87.0815678565733, 90.29258481917843, 93.78209790875836, 98.70901061642556, 99.16374667998284, 99.27156479127946, 101.34281942921301, 100.00502447928153, 95.34739032868417, 99.87357801006686, 97.54642009735109, 101.15387885801255, 101.23256160366921, 97.2145248228504, 95.5124907339773, 97.1062909403155, 93.57061155380742, 91.51186927672356, 100.06371098179972, 99.55767816112888, 100.25545997004356, 103.82158479382916, 100.3649882347353, 98.71278393653132, 84.8213569579586, 81.28244553842853, 91.23452632657944, 25.60782713274802, 1.903542914698201, 1.846395574750439, 18.172543010404034, 57.43709033535373, 64.17060752068797, 62.14278528767248, 81.09226549825361, 101.11733805748725, 97.83693436653384, 100.72696024371733, 99.82595259143461, 94.04766590364518, 95.29275955692415, 92.37149592368834, 92.45220261235391, 97.07313122287874, 96.66528317236133, 98.18163225727697, 102.61217686437793, 109.22261791844522, 87.01180458068849, 98.0789916746078, 94.00211149646391, 102.09788353212419, 96.21085305367747, 93.85859197185886, 87.6708725960024, 78.67643848542245, 82.15118777367377, 86.02640321177822, 86.78968860257058, 82.08351904346098, 80.33897430666032, 71.0175714185161, 73.89585371940368, 75.8448794580275, 69.36701451578449, 54.39519812983852, 40.111965594753144, 24.719429900569303, 9.601706247175894, 1.0816975178257113, 0.19537750241016189, 0.08942097710866122, 0.38547120447601047, 0.4521662369370461, 0.158482983768467, 0.22266236734726738, 0.06216237749603968, 0.2021814357008665, 0.4384144071129061, 4.921108090108441, 68.33503892344814, 103.03751868586387, 55.285113319273925, 43.965729590385195, 26.85871216558641, 15.79165647106786, 42.330442474734404, 58.85870633586761, 63.76040997043733, 73.68304160333449, 85.40377401536512, 77.4872229176183, 14.631698842971558, 0.34167325304400537, 0.07972575138292967, 0.06673438639770593, 0.07114540575252426, 0.07401673393624444, 0.03272759022131082, 0.04124579846017784, 0.10289965062251977, 0.027241783982683575, 0.018509251155680227, 0.12352291374437271, 0.03117676396223326, 0.042766548107348146, 0.02717878091179075, 0.08308337685922462, 0.0797529781477586, 0.027174195875563932, 0.054482663981616504, 0.05432267800994939, 0.07204473934947483, 0.053578220578210975, 0.012395847494894219, 0.09592720097111118, 0.09968991842000716, 0.04638532529615107, 0.05169537181275026, 0.11076111466653886, 0.11145574190924246, 0.16188534877953992, 0.260750190505097, 0.18971140886987412, 0.15057720153802825, 0.17381202008935714, 0.15825202358105492, 0.2181557478803781, 0.36126886284159077, 0.18392684749297558, 0.1716174692997048, 0.23320531532649072, 0.13881248121540393, 0.11190277719569784, 0.12863717883104278, 0.30759134960751383, 0.12780648671210776, 0.1255350819818916, 0.09641770408639024, 0.08440248833428468, 0.15050002584053626, 0.3124495727881309, 0.13513741954680414, 15.797005603390357, 115.41394587486022, 122.55091805611889, 109.95708173321141, 103.42915950282928, 78.25776469322943, 92.36756570877569, 51.5867732417199, 63.82068895524549, 92.60781088183003, 82.6852184726346, 88.67389325172671, 86.27572474941131, 70.73422724200834, 37.74608604369625, 1.2362916094641532, 0.11407666659403233, 0.6576593941257847, 0.26817683070417375, 0.15391786582767963, 0.34559877949856943, 0.42143275059999963, 3.76884566199395, 1.2411356140528957, 1.9632130741111695, 0.8555993533903553, 3.5745559584709907, 10.259863292017291, 23.041057509760705, 47.2808462573636, 85.01815795898439, 102.945037041941, 99.25931915160149, 92.56687702671175, 93.6051990139869, 95.19111525627875, 100.0211924891318, 102.25319370146721, 102.31294708867227, 103.72321174990748, 103.70042277920632, 93.87537187145603, 101.09401564444266, 99.19029328130908, 99.79015704124205, 102.51527863164102, 96.75603112866803, 94.59866477597146, 98.66829641403692, 91.25697797344577, 93.26585908089915, 102.60960378954488, 100.12252300016343, 102.44516234244071, 107.56013701038977, 98.8599120416949, 97.68245573966735, 87.3898426178963, 85.91381549835206, 97.62745626511114, 19.406267673738544, 3.326233889787428, 2.3717697253150325, 16.25636516078826, 55.151744888674834, 72.01304543402888, 68.6609878847676, 78.50944749770626, 99.01405334472658, 99.84185388011318, 106.05286429005285, 102.48007143697431, 94.64851025612124, 95.83314449556413, 93.621931845142, 91.44841317207583, 99.25995457556941, 101.41377510563021, 101.31496275624922, 104.65410786290323, 106.15412419842136, 82.20610880082654, 98.7692346880513, 95.8695048670615, 109.17301562524612, 100.74302627194314, 99.9091382180491, 94.29919181331512, 84.25134243503695, 84.0537569599767, 88.15088441295009, 90.00431414573424, 83.93659576292961, 83.59935037551388, 78.3209462319651, 83.45987089218633, 82.63732633283063, 77.84006364883916, 59.56687458099858, 45.97413216867755, 27.3604303790677, 9.862514445858618, 0.8058351398475709, 0.2810509689152241, 0.2900696317515066, 0.7191072452452876, 0.39780261535798356, 0.26867576844749913, 0.33303092323964645, 0.2586918654701402, 0.6698912442211182, 0.717183874259072, 14.609548238015945, 84.21313854955858, 115.32911285277336, 62.83320088540355, 79.18114554497504, 94.02879930311634, 41.52590159446963, 46.606645737924886, 46.07865156665925, 58.87996950457173, 71.40165775052964, 94.06548130896785, 92.03013204759168, 16.391991896014062, 0.46416357219699894, 0.1529431874833761, 0.369140079184886, 0.15910884695908717, 0.24492491307037495, 0.1746563868777406, 0.132806382532562, 0.16764381720173746, 0.15715061897231689, 0.16248637539965494, 0.17036721380727907, 0.15487090984900154, 0.09040667179731593, 0.2173157018278876, 0.12172158822537431, 0.11717476446421878, 0.17054646305980223, 0.09055500174121511, 0.2842082011122858, 0.13301584629281876, 0.16314888823657267, 0.1608405887119232, 0.12172556422170132, 0.34280007645007105, 0.10864484274098951, 0.1590256651322688], [0.04791428357543004, 0.06661512949053319, 0.09968602669335182, 0.06507290256840569, 0.05392877475148248, 0.057691243221803065, 0.040798629108335704, 0.007355110569586678, 0.04434820174449875, 0.06979467782882914, 0.08000285304602116, 0.08077145373869328, 0.0432690060246856, 0.019610358905347607, 0.05721387468398579, 0.04949444717156792, 0.055462996054801254, 0.0878366536550945, 0.09932732134456597, 0.041036775200477535, 0.0400027901595158, 0.06251586195562156, 0.10591052938252689, 9.872009523453253, 79.22844148451283, 86.95860939641153, 83.57540038324173, 84.33438685632522, 53.47734782003588, 44.48738913382254, 39.54309640392181, 58.35050052212131, 75.18736470130183, 53.16651959573069, 35.75887210907475, 48.67382895561957, 58.988501487239716, 19.6994883783402, 0.3653825098468412, 0.027303055694867528, 0.20735792244874662, 0.11887784686780746, 0.13457960028561855, 0.21398985367869178, 0.30358320823119533, 0.6000216353324153, 1.0566392108317346, 1.508685631617423, 23.972194848522065, 55.702920267658854, 67.17388399185674, 74.31033842025265, 90.96290219214656, 90.32579160505726, 76.53586772180374, 76.8360859347928, 81.78912947254797, 90.73345922654676, 89.00497267323156, 87.27689404641428, 89.7718744893228, 94.39424653207102, 96.73957286342498, 98.95106792449953, 100.13777317539339, 100.94727977629631, 96.29860431917253, 93.66042598601311, 94.99737370398738, 93.65749205312422, 93.84540496333953, 92.9340422538019, 89.59550119215443, 89.7950949207429, 87.05129500358336, 86.02772897289645, 88.9361664556688, 88.14876633305704, 88.61170799501481, 95.60425066178846, 96.79561568844704, 94.15788450548726, 87.74245585164716, 76.81732916062879, 79.43057690897297, 39.517216605524865, 18.004281174752023, 41.708884085378344, 75.77731270943919, 62.607629299163825, 83.92925308596703, 92.51816118917158, 90.15914578591624, 86.12316808392926, 91.9600236031317, 93.11872313099524, 93.30280780792238, 92.61377288449196, 90.83408371094735, 93.19964162765011, 94.26119189108573, 93.44554285849296, 95.05663287255072, 105.16260393204229, 100.80867105914702, 94.70382352029124, 96.27012006698116, 95.06843136202906, 95.68228229399651, 94.15857484263759, 94.17058514010523, 89.22311921273509, 87.86088005188974, 74.37569295206379, 74.86869565902218, 72.45972494925223, 76.0852893706291, 79.62059220960064, 68.77086916277486, 64.7620185728996, 82.67553806304932, 73.83310364138696, 58.36607625407558, 43.456809905267534, 33.41206704416583, 16.6546328221598, 7.303431687816498, 1.254201396819084, 0.3860450962618474, 0.4140997876323039, 0.1167879896538873, 0.3586308237525725, 0.14946096546707616, 0.029110268599564032, 0.1368797486347537, 0.11743115110983772, 0.5382612816268398, 8.346202623459602, 61.91349137213923, 88.06563561962497, 59.30075745428763, 56.826271395529474, 77.62638861133208, 33.858887764715384, 26.79724274143096, 34.04840492433117, 47.73384078856438, 55.4485349501333, 71.63040253423875, 67.54451659417921, 15.161080552685647, 0.21635813788781244, 0.07281602134988194, 0.014157094166523988, 0.01695657287904572, 0.059009676709050135, 0.04874116440694179, 0.05806019499657616, 0.07119243589019583, 0.13174306781541917, 0.0684500862694075, 0.013511978228756738, 0.1387353208396704, 0.031022261264884186, 0.07486264822223494, 0.03716264175431382, 0.1076072302737063, 0.05316978463182046, 0.005811915025039907, 0.05570654306680926, 0.012291879787470305, 0.04490630445821632, 0.03664790344755015, 0.07354812561384133, 0.07547626932782513, 0.07030275500109119, 0.003424147524187462, 0.04772145924488864, 0.03712043414012559, 0.018908907734458486, 0.05762200802564622, 0.028380826491141514, 0.10564515652555613, 0.015997188522540513, 0.09193468778844803, 0.025210848506239635, 0.14422283928480842, 0.14690577112618955, 0.028928793861620852, 0.014401881283359423, 0.03643865419191219, 0.030827473834036823, 0.0988590807443665, 0.08021574888017871, 0.005518362581384399, 0.06677721837355245, 0.08864616344292318, 0.036553375858573184, 0.12721587888776295, 19.917795735020793, 99.5246204253166, 101.89773282697125, 100.80263845382198, 108.78232402186241, 68.71838784986927, 59.314136658945394, 45.48009395599366, 18.15307628723883, 31.353793490317564, 46.371370207878854, 36.83256603056385, 48.698798764136534, 59.28427957719373, 16.295125042238546, 0.3268511677461286, 0.02997777890414, 0.039076773720162536, 0.10581480669638804, 0.06951196840213192, 0.4238167549333265, 0.23804176628829973, 0.45685631914004204, 0.39112640424601497, 6.2091664056624145, 44.24189582947762, 76.24199590375348, 91.48321244024461, 91.84415678824149, 101.58632801425074, 97.22479358796151, 84.32253345366448, 84.41204978573708, 91.90118805054696, 101.36925620417442, 96.62930719314083, 96.00214373680853, 94.48483759357084, 99.04773081502607, 101.59190562463577, 102.22049682371079, 103.60241059334048, 103.19415461632514, 101.5575299724456, 99.62897900612124, 97.58157237883538, 97.08484342021328, 96.4698471561555, 96.22021967364897, 97.09675173605643, 94.74353359591578, 89.2345803783786, 87.68386348601311, 93.222469822053, 95.04182200278007, 92.41441449811383, 96.69958822188839, 102.273174255125, 99.5400510295745, 93.8219335002284, 82.44407899918096, 88.75559622241606, 53.00603189776021, 25.62720952495452, 54.00688348277923, 74.98367601825346, 65.83084091063469, 92.45335578918458, 98.36039820025044, 94.75355917407622, 89.26690855333882, 94.7042549810102, 95.50865465594877, 96.60039148023053, 94.70151716662993, 94.89726697244953, 97.33663605105494, 96.13700266807311, 97.17150426680043, 95.63903424047655, 103.06825437853414, 100.08027122866724, 96.44804662273776, 94.8478215740573, 94.68630621510168, 97.5522408946868, 96.3026757394114, 96.79374079550468, 92.98954379174018, 94.64049293148904, 86.60334464042418, 80.44348978227185, 76.87046158698298, 77.35320337357061, 83.21640153085032, 81.25184320634412, 75.91632935308641, 88.80100157953079, 90.51656784549837, 85.5847207961544, 67.02935249574723, 48.85100241630308, 27.911731273897235, 12.520462505279049, 2.30229155671212, 0.4397531917258617, 0.13303884425230567, 0.17383616718073047, 0.41248006325575615, 0.1598033056624474, 0.026375043596471512, 0.12824924722794565, 0.046479385571494225, 0.6596797211996971, 5.32522302481436, 63.380446049474905, 97.6857505306121, 67.50431229991298, 47.75951662371236, 31.037979933523367, 13.821901006083335, 40.87779268141716, 56.02365639901931, 65.68634471585675, 73.69778971518241, 82.17714601947416, 86.19984257605769, 28.410482214343165, 0.0804100057951385, 0.08238738598001581, 0.05432262438379469, 0.07036149862312502, 0.07354506892302344, 0.048829655223075426, 0.0999746886232207, 0.0447349535721925, 0.03443496271727547, 0.05200353834117132, 0.02784505332519691, 0.0483158209000624, 0.0076743034972629005, 0.0710943536532502, 0.10430008999162144, 0.07085809979828135, 0.02236211417062629, 0.03105089380105417, 0.05317024045413541, 0.03202083197632625, 0.07971317221921298, 0.021394050995548888, 0.033693190423711654, 0.0535435589300769, 0.010685531306080522, 0.17030497682431053, 0.22702828710598333, 0.1923788197699093, 0.09373676407361224, 0.16614167199980828, 0.11926999195448815, 0.16642245854581558, 0.11053523364206476, 0.3201808401894185, 0.216719547526971, 0.329193129174171, 0.2151813502273252, 0.17283297504388517, 0.19965184401840935, 0.1442946217233135, 0.12950368556043795, 0.17090523735650126, 0.20525531753176646, 0.19226189943090563, 0.1660538170366518, 0.12185085024083815, 0.1360471642786457, 0.20706308585020805, 24.837242211064986, 117.81471883097004, 112.31896831143288, 106.43983748651321, 108.12284808005057, 71.9098949432373, 61.52719674571868, 53.633375783120435, 88.73292492282006, 105.13033067026447, 76.66088150393578, 54.71687563004033, 64.21812311295541, 77.6864008749685, 32.72537965928355, 1.2266392693404229, 0.12309937437455501, 0.3094308799312961, 0.16650187122004648, 0.26020354080584746, 0.38296373741280654, 0.8976543322205545, 4.362263987141271, 2.383258592697882, 2.77984919567262, 37.52721386571085, 76.05959784600043, 93.01868700212049, 99.7898667858493, 111.52064046552105, 105.95300074546569, 89.77305904511483, 85.88954387172576, 93.95370944853752, 102.58112738209387, 98.89038101319345, 97.98466651670395, 98.75442381828063, 100.62924615798458, 104.61716698062037, 102.02687294252458, 105.73280672873221, 108.12032991839995, 104.36364066216254, 104.36223645364086, 104.35374059984761, 101.87575186452558, 101.01648607561665, 101.99301504319715, 97.89484423975792, 97.93209891165458, 90.63562746970885, 88.27359184142082, 92.26354445180586, 95.30929626957064, 95.81696079623316, 97.12356505855438, 105.46480686433854, 104.17866168483611, 93.3896412387971, 81.07566602768438, 98.28155071504655, 51.383339512732725, 21.784771373195035, 55.13028560146209, 89.75815403846003, 68.65042886426373, 87.43404772973831, 103.24768712443691, 96.92243376085835, 92.32857734926286, 94.30920170199488, 96.271390914917, 96.57654346958284, 96.56668263096964, 96.00830185797908, 101.05553719305225, 101.72645076628655, 100.64351574067148, 98.53117819755309, 103.28451818035495, 101.68487364246, 99.68856765377907, 97.36821897568242, 97.86094711672877, 100.2426887327625, 100.02525606463033, 99.07638765150502, 97.43420108672112, 97.68156143926807, 91.34421933081843, 85.92828119954756, 82.24523836566557, 80.59119055348059, 84.18508575808617, 84.73123658087947, 83.96117333442935, 92.30510588615172, 90.17464699283724, 84.49342327733194, 71.60923742478894, 56.66071991766653, 33.01922598192769, 14.74411593329522, 2.1630417771877783, 0.7662780979467977, 0.4836879051741093, 0.18725146990149252, 0.36342653415856824, 0.3268792678511912, 0.09515064828578504, 0.39052707834109185, 0.21611188658543173, 0.766933746635914, 13.357273705544012, 75.53633013079244, 105.82548449116369, 75.30825999475296, 82.829679366081, 112.02676742307602, 48.649231772268976, 40.02841518771264, 45.81034183502198, 65.57499647140503, 75.04670850692257, 91.15893440861856, 101.68434020011657, 36.3349937623547, 0.7999702158474153, 0.16756031361799087, 0.08086684700702468, 0.1753351561004116, 0.12386617476060507, 0.23599407455373198, 0.24602872319519523, 0.13604494262366526, 0.17507529907649563, 0.2023609607450424, 0.1166726244733699, 0.3108861711957763, 0.08848719253775575, 0.22217539589731927, 0.18596412043177313, 0.15851807059539905, 0.16468029799720935, 0.19996483690075337, 0.21281490462922284, 0.0955518791752477, 0.26484162096054326, 0.18749741476870355, 0.15058288591042643, 0.1315498910844326, 0.18575373736600723], [0.03918441290396356, 0.0990687283657251, 0.06264235839367875, 0.05100181326270104, 0.08669691400662546, 0.07687722963671531, 0.09299027267843486, 0.054842510801409526, 0.06339517001423144, 0.035797794830174215, 0.048414439398555026, 0.05127121957259313, 0.10703005197067415, 0.04410542082041503, 0.08852392645372499, 0.04400500201530034, 0.014613189400293896, 0.061744384602793766, 0.029573334275834987, 0.05234399164516119, 0.012649800853743669, 0.47846192914632063, 21.27142333215283, 81.38343872562533, 88.02383884306877, 77.51441278765279, 65.97538025148454, 70.70058899541056, 57.322619884244865, 35.0663854998927, 44.602781341921904, 71.51819921308949, 103.95252135492142, 125.47943022943313, 105.05753147986628, 76.52770919184532, 23.99018087694722, 0.9531374227616095, 0.07131533937588816, 0.2954708580528536, 0.2804097839661183, 0.27632408384834567, 0.1967781256403654, 0.18901108193301386, 0.4446947039856065, 0.21993235174205997, 8.540477618094414, 56.64556780169087, 87.13525725949196, 83.83572809157833, 88.3859363678963, 72.7633713137719, 75.97745556985178, 76.40655502196282, 86.2195485638034, 90.75474985184209, 85.37634880312028, 86.43369428573116, 90.21107012225737, 93.96781429167717, 98.3546950740199, 97.74730036335608, 97.5528214054723, 95.78384030249812, 90.85069887099728, 85.64744733995008, 87.30579406984391, 87.64078801678073, 91.62655153582173, 87.91671106892248, 91.03864316017398, 93.81589305016303, 95.81468582153322, 96.43593434364566, 88.13797197034283, 90.26762285540181, 92.56209957984187, 95.00710118201472, 90.14537826661142, 89.39826088566934, 88.7737254173525, 84.11194139911284, 88.74289558779809, 95.56812563250142, 61.09825811078472, 57.30269816613967, 75.29247637717955, 76.20774576740881, 65.20224971155967, 82.76360311815816, 92.89440278084048, 92.93016695207166, 90.13372882719963, 90.37213833101335, 90.03094703920426, 89.24385286146595, 87.56002641493275, 80.1058364683582, 84.9671200783022, 82.29533487750639, 89.98580840326126, 86.12839268099877, 87.07129909146218, 87.74524857920986, 86.92469658390169, 91.18617134709513, 89.4976302116148, 87.23605432818013, 90.32881183008995, 92.77984603758782, 92.94881389987086, 88.43866871249291, 88.54010904988935, 86.91365118949645, 82.18551635742188, 80.51074274124639, 77.45371018686603, 72.82042611029841, 72.1983225114884, 72.85635502107682, 80.56913114363148, 83.94382076878702, 78.33204653955276, 68.75346952869047, 49.594856385261785, 31.114803475718347, 16.430770408722662, 7.971911430358888, 1.910708472132683, 0.3933434320553657, 0.626181821909643, 0.24514589879301288, 0.1157228363257262, 0.1822613110585559, 0.07773820521129716, 0.17362978309392932, 0.0807363439291235, 0.23113623441707706, 12.438331015648382, 62.10283594746744, 86.31832168948266, 68.16464331842238, 51.46575243242326, 61.566522429066325, 36.76101023151029, 26.466594780645064, 36.149124406999164, 39.965880840055405, 51.3043547445728, 68.94599514622843, 73.38950710911905, 29.484338914194417, 1.427467563940633, 0.0535097323177803, 0.059932965875392964, 0.08938769824923047, 0.05670206283309287, 0.005975912903405486, 0.050928468004830425, 0.026661786476090073, 0.08140204369180626, 0.10448584333062173, 0.08235939312726259, 0.07168208864787895, 0.08349623696337785, 0.032166438477654616, 0.008566748527359338, 0.0502773966910618, 0.0841872942363543, 0.020783436785061515, 0.01622547793592657, 0.035281283029865836, 0.0339678137923681, 0.055877867139755726, 0.046562214997867425, 0.04804561402828944, 0.01588892880752082, 0.0021166923162978025, 0.11740428440633321, 0.08292297336963877, 0.0029195680221047013, 0.0576878494522985, 0.03288409049292246, 0.04529048606092411, 0.02452686797046373, 0.02895632131596006, 0.01767183469998981, 0.0609886963220854, 0.052054758979788715, 0.0334311462187719, 0.05387635518526358, 0.030698497186324773, 0.01791933089524748, 0.003805770632630635, 0.07338464245079987, 0.003379763980891796, 0.14812434122206705, 1.6747448112695449, 34.9620073072372, 101.5180395495507, 100.29658209893012, 96.17736385714625, 90.96367097670033, 95.83195993977209, 84.1269640768728, 48.0938280782392, 20.490308807742213, 45.691776429453206, 111.73793192832701, 122.11602134089317, 96.50196352312642, 79.82777964684271, 20.314576818097024, 0.29070615888603274, 0.058285957277421994, 0.23476948300676964, 0.26284593127427563, 0.2415025378427198, 0.3590130096962375, 0.448908340786734, 0.046128065310298436, 0.635104172172085, 15.836451899620796, 83.11845210290726, 99.77694649850169, 90.64288385452764, 91.7812890391196, 77.79608603446715, 81.91859906719577, 88.72617844612368, 93.00801031051144, 99.1449506821171, 92.33351169093963, 94.01088191616921, 99.51782688017815, 102.24509792943155, 103.3529870740829, 103.12978067705708, 101.5127286603374, 98.33521658374418, 93.76771849970665, 89.99453959926483, 89.37706439725815, 91.35389189566337, 94.56664254588466, 94.84338929576259, 94.46044829583938, 97.50614520042174, 98.99564173913772, 99.37517812175136, 89.63812951118716, 92.88396143144178, 93.43265395010673, 96.39960535110967, 98.32272775711553, 94.73389241003221, 91.2855249835599, 87.55930469882104, 91.87960716985887, 100.71645613639586, 64.97381087272399, 63.318849148288855, 86.22118026979508, 80.86949056194675, 69.6150573607414, 88.27403899162047, 95.00041746324109, 97.26442521618259, 95.94515954294513, 93.98529237316501, 96.46245741075086, 93.54124084595712, 88.94045752863731, 82.35821831610896, 88.51181307146626, 86.19988964449975, 92.0351605261526, 89.5207800403718, 91.87062494216427, 91.05001018893336, 90.73807977860974, 92.22603874821817, 92.27497423848799, 88.01074597143358, 92.46235370635988, 92.79948926741078, 96.3006910201042, 93.40390297674364, 90.69334906916465, 87.7302808146323, 90.29507944660803, 91.09612941741945, 87.27341882644161, 79.59950554755427, 79.5811959235899, 81.32533273389264, 81.68137411917411, 81.91866182511853, 86.37704741570258, 86.31456405885758, 85.52830926833614, 57.96212311713927, 31.810020054540328, 13.266715984190665, 3.1676017180565865, 0.6036489697233324, 0.3359243453991029, 0.3613682704106454, 0.09111050741686937, 0.12310960164834416, 0.04556952209602441, 0.17864997258349774, 0.2863709592530804, 0.49245657819894056, 7.66960749703069, 62.5652833907835, 96.68376538061328, 78.78930860950102, 56.39950967604115, 42.367097023994695, 15.039448834234669, 34.117450406474454, 55.04246765567411, 63.7940639065158, 76.11097305051743, 79.45783738167056, 87.9583352611911, 45.156329754860174, 3.111369883821857, 0.05819486559278542, 0.04827402314291366, 0.10290622365691009, 0.05373645220853148, 0.03713266473383673, 0.027576742521036538, 0.05835487837752989, 0.027281444354523576, 0.13682808366514024, 0.04489961268019773, 0.04543502003915849, 0.10011551090546193, 0.016828797074154984, 0.029909685178990328, 0.12080186902875863, 0.12513873873338585, 0.0341723439463925, 0.05653632354111441, 0.03717468848692314, 0.06902685088496055, 0.03142460681227667, 0.018860196033793113, 0.055342708759370356, 0.0740319714250584, 0.16063248858817164, 0.2138353490661229, 0.12947970700840797, 0.1512482792379395, 0.20704592548070416, 0.14829217576451842, 0.1405779001933913, 0.1319177511839136, 0.2076528816213531, 0.13163057546461784, 0.24276517331600192, 0.1733588177951113, 0.18254234275269896, 0.162984577698573, 0.12685050091315664, 0.12518291136309986, 0.14747243104202135, 0.23986035176823217, 0.15484702322752247, 0.3064937601166387, 1.6383057472205933, 39.78920944275395, 115.58566724100422, 111.74340755708756, 101.94383636597665, 90.58103592165055, 93.04226829159646, 77.7769370232859, 57.6980063992162, 67.4092968048588, 101.02508391103437, 131.2453536064394, 151.43201212729178, 127.89612800844255, 97.86217089622252, 39.08734052411972, 1.4878454660215688, 0.1102934103278864, 0.49242844745036096, 0.4015973859256314, 0.4973115225232417, 0.280555984185588, 0.5899866802557823, 2.9762868871611934, 1.7942801454374868, 10.847401003683768, 90.9229253953503, 107.8130671285814, 98.97626523048648, 99.41296623599146, 86.26554227644398, 84.36918612449401, 88.68566036224367, 94.47968359916442, 104.07649178658764, 96.01005123507593, 97.4442501991026, 98.81300833917435, 100.74114353426042, 103.76213735149753, 104.26362022276848, 103.52037814355667, 103.14661548983668, 96.86561430654218, 90.12591546581638, 90.86963607418923, 91.77525643379458, 95.9094738191174, 95.53296550627678, 95.99109834240329, 99.35831977475075, 99.53791726020076, 99.88251316931941, 88.46600763259396, 93.81840336707332, 92.88891930733958, 97.07689669824417, 101.18304560261389, 99.00558886989471, 92.71346384479155, 88.01555479726484, 96.76071443865376, 98.91548418229627, 65.97436827998008, 77.52712911175144, 87.76250700796805, 88.94499178855651, 70.79936996583017, 85.94588479688092, 99.02200791143603, 98.19093611932571, 97.6580507524552, 96.37183497028967, 99.13858075295725, 96.98152034513413, 91.91976439568305, 83.21017280701669, 89.63969061451574, 85.87751788477745, 94.6322794883482, 91.50314592546033, 95.17280563231438, 96.84742235368299, 95.96645801298081, 97.15136681833576, 95.51568354329756, 91.31319338275541, 95.74679743859076, 96.17397492931735, 100.52282441046931, 98.34358692169191, 94.17303269909274, 90.89337425847208, 93.1701454039543, 92.29566866351713, 87.93346743429862, 82.16008370922458, 81.29083941059729, 86.54139472592263, 95.18104260967624, 94.64899663002261, 89.7948125100905, 84.8201096442438, 80.23293695142193, 60.78292700552172, 38.742226862138324, 16.761146745374127, 3.5557217174960725, 0.5971601437176428, 1.4392252362543538, 0.44362046485466344, 0.25818088482464513, 0.42338134120068244, 0.15317275339076597, 0.41691108516627745, 0.3077778154082837, 0.6483516097068787, 16.740044393847068, 74.55643576960411, 106.07286053319132, 83.67016484660488, 74.65607181672128, 93.69145193407613, 56.24552919018654, 38.66621917293918, 50.53897088573825, 57.74344705766248, 71.8944251152777, 87.45260054065336, 100.64319410631734, 57.358917497819476, 3.9326754644993818, 0.21219988924361047, 0.14032800231249104, 0.15630853512594778, 0.2595754712820053, 0.1323519391758788, 0.11727093914223295, 0.12120498449451501, 0.1439044837869944, 0.25562444942132123, 0.1862277772517935, 0.14810367216986997, 0.22712213287670768, 0.09240131960400651, 0.10369828962270292, 0.15638469958737974, 0.283225218374883, 0.0406205328181386, 0.14019629647654874, 0.1944765523676911, 0.18676003981982509, 0.19254432540507088, 0.15150084310481626, 0.16978817391059092], [0.03261436625654179, 0.03932797778097372, 0.011341115835333064, 0.03449204009807399, 0.09558349562388274, 0.04925638151865813, 0.00754366587517002, 0.046464883527087594, 0.03411518995680156, 0.0731430719456365, 0.050703395203116446, 0.05270673044686837, 0.08309375735059862, 0.06359797647042621, 0.0307798633847626, 0.04708458737079655, 0.060726472086483435, 0.04168072189655035, 0.0555015915644265, 0.14642477516205082, 1.8969717189188928, 50.258384135461625, 93.47238755995228, 84.18782357246646, 78.41855049133301, 74.53603944470807, 59.353799666127856, 52.382888870854536, 36.467656166322776, 44.51436719586773, 51.68230648963682, 41.518492237214126, 69.06483511770926, 90.85707664489748, 74.4068757949337, 25.830911936298495, 0.6191385933949102, 0.06002048375986277, 0.22055142739367103, 0.11958983366287525, 0.10140937212253771, 0.08000089186093501, 0.07063975707898218, 0.8223997380944991, 0.9697372610530547, 5.703361572757845, 60.65292396853047, 84.47041465390114, 90.21926787591751, 87.47411866341868, 95.27994125120102, 76.86217754117905, 83.86271399836387, 98.32552048467822, 91.24579921845468, 88.75740835743566, 90.21944830494543, 98.46807510622087, 95.5031241140058, 99.3833915648922, 99.33094947568833, 100.11526661534464, 92.98872793874433, 92.45516007946384, 90.09706251082882, 96.73812158646123, 93.50955593970515, 92.39369653886365, 91.24799574575117, 91.58979892730714, 95.27636404960387, 90.58691947690903, 93.24678851712136, 96.7404200953822, 89.11550506468743, 83.72152436164119, 89.39592315304665, 90.07834496036654, 94.35901580318328, 87.68056869506837, 85.19340161354312, 89.11461860902848, 85.78627570982903, 87.35190545358967, 84.14091202520555, 52.53014249186362, 71.47732811589395, 64.47384203633955, 68.80216967674994, 87.1631217771961, 88.20147514343263, 93.20676465188303, 85.53720520388696, 86.58312089981573, 86.69520654985982, 85.4678733887211, 81.99128843122914, 86.0462268706291, 92.54028335694345, 94.16336013424782, 87.50592124077582, 88.53029527971822, 87.25621531086584, 86.64292135546285, 85.69602197216403, 86.51925686867007, 85.16934963964647, 84.91445049162834, 83.8135745448451, 87.96112798875379, 86.44389244817918, 87.87507118717318, 86.85235238844349, 83.90172589209773, 87.8870814846408, 88.6214590072632, 84.26774578709757, 83.73727660025321, 79.83293364124914, 75.53942095848822, 59.32389943830429, 60.70726056252757, 68.32533497964182, 73.9286918024863, 81.51610897433373, 71.4704796575731, 24.747678810550322, 15.510009700252166, 7.975945097784843, 2.6739966821285988, 0.18501435526676718, 0.19215712924638104, 0.17893252113173086, 0.2041539282447869, 0.06788015515813905, 0.08949478968016564, 0.058915938190635175, 0.07394834526724393, 0.3088719421817411, 15.191473037965837, 64.11804383800876, 81.11700780930059, 65.59447888405093, 50.67766981740152, 71.34274375054144, 48.75879926066245, 25.234056634287683, 29.63095122768033, 37.06778664742747, 70.05546892842939, 67.81017088120984, 73.0465978191745, 51.04821612758022, 1.7534517040175779, 0.05654001225446982, 0.03474256617107219, 0.03795968346117485, 0.0424993519611176, 0.07821623641516894, 0.017114235689082456, 0.015240442082886736, 0.04294672815669929, 0.022242433999875383, 0.0724238149761673, 0.0724499998614192, 0.1472869764773115, 0.016017461124236788, 0.09572738225782111, 0.03098097870186452, 0.03470605442060098, 0.015927473563821088, 0.0193598136801513, 0.02439269724662506, 0.11070144407811666, 0.042682837679862015, 0.00732424009906789, 0.03546238238472612, 0.014879980477534476, 0.023281174531627088, 0.07738630272327893, 0.1613470647604235, 0.05475223883085194, 0.06192466424357507, 0.00966726064366559, 0.02568888545577084, 0.027510058397667545, 0.025876766603980816, 0.04877119122313396, 0.06536636020868056, 0.03588581450223442, 0.012270574882296065, 0.025084327170324903, 0.02382465071165033, 0.035135362432488514, 0.07573424943632658, 0.04147510389767347, 4.621553247974766, 72.23402392479682, 111.74131301141556, 94.47353332273423, 105.57105602756624, 104.56776865067022, 79.7628330415295, 70.11264924080142, 39.58909403893256, 34.92923982681767, 39.28542021782168, 49.12575660213348, 77.03982953102359, 97.02580390437957, 77.3564197171119, 24.346520362361787, 0.24290729794771443, 0.040356837693722024, 0.10853798879731087, 0.12453764316535766, 0.011087905581770165, 0.35508962828786145, 0.579321817044289, 0.8352151633270326, 0.40010421927417483, 11.7284712483806, 85.16739629930066, 86.62630619541292, 94.876768665929, 97.13908195495607, 106.46457195281984, 85.13001611155849, 93.62491284647297, 103.32823691829559, 97.68385994818904, 95.94559100366409, 98.60604055466192, 105.62907572715514, 101.31327613707512, 104.62817315132388, 101.00942580930649, 100.06934350536716, 94.81728199989566, 95.8500499110068, 96.6751753899359, 101.73842184005245, 97.99126394333379, 96.70437351349862, 94.03211762828212, 93.56102528110628, 97.2142267227173, 95.19125646160495, 94.74394152241369, 97.43674278259279, 92.95601537150722, 87.02923559373426, 92.44599742274131, 93.10543414085143, 94.22628279655211, 91.48691515768729, 91.54450339655723, 94.95424332157259, 90.89410381932413, 90.86097548084875, 89.39694296929144, 58.71087220407302, 71.64514280134632, 69.34599845640122, 72.27280047632033, 89.43637847900392, 92.3974306352677, 97.28805357410063, 88.2858923942812, 92.13603604224421, 92.07129340017997, 89.68101670665126, 84.92324444555467, 89.4185552289409, 92.55751040674026, 98.20995961466144, 91.69502827429002, 90.76743479697936, 89.935178449077, 89.93364087996945, 89.18863373418009, 89.46861251708, 87.58813411958756, 89.48692214104437, 87.60645158829229, 89.09885852567612, 86.34009084393902, 89.06421615231423, 89.34643853095271, 89.20355443031558, 88.9713893398162, 92.86453000960812, 90.44826369131766, 93.44987315516319, 85.23901093390681, 81.78895688826039, 68.31754515247961, 69.14250589186146, 74.74553323561146, 81.08738606975925, 85.42019305690643, 105.90892899420955, 63.312463529648326, 28.905855994070734, 15.011114612702402, 4.772447809096306, 0.46898968097183014, 0.14520573009166027, 0.1436184112343096, 0.09250467252587119, 0.07400343464987894, 0.049379491848090006, 0.18099029458338217, 0.06692348754093533, 0.32970487590759034, 10.775933457959084, 66.23664932866251, 88.59685005680208, 75.4380355342742, 56.15414580991192, 37.51719613229075, 15.81075841380704, 36.19543975399387, 45.126119659793, 53.31345158238565, 92.7059328940607, 79.90042978717436, 84.49384689331055, 69.55037747659992, 2.8653936376494746, 0.1526251384207318, 0.047405287097658844, 0.07864881562249315, 0.10264645090266582, 0.08355137231128831, 0.01053523538904565, 0.023117042109069806, 0.07567948181061976, 0.025572781000406514, 0.0029905003424163068, 0.06852346983167433, 0.01347835846019969, 0.037449537851517244, 0.02127063040050768, 0.038496136530152256, 0.05747530601858612, 0.031584646410098484, 0.037142880516307014, 0.03006229755438624, 0.02614311622305503, 0.03396098028808352, 0.028017861693496668, 0.0962958884455504, 0.26540242796463354, 0.09411433816797311, 0.08290376754537707, 0.291386199814658, 0.18456429393301088, 0.15469774333459718, 0.24594247701667973, 0.1503098215306959, 0.163043137459505, 0.12049208605481733, 0.15222625176031745, 0.21348625812078678, 0.1742515706967923, 0.11829368950378512, 0.14354498936764656, 0.15520595074180635, 0.2503950106761148, 0.19289474934339526, 0.2704032967167516, 4.958148012238165, 81.41331934159803, 126.68213875063005, 104.6529939097743, 101.71413452394548, 99.26226092923073, 80.44261117135325, 70.42030426763719, 54.047472169322354, 66.94620609283447, 78.5741352265881, 63.484255498455425, 88.90438741253269, 108.94605944233557, 95.84873983936926, 43.528138206851104, 1.285275148768579, 0.16004710548347043, 0.29554069462803106, 0.24899006671001836, 0.1622359719007246, 0.21307315286849776, 0.39134743593392834, 4.62863753880224, 1.7523279449632092, 8.121674877981986, 93.32155673734604, 97.88157878383514, 101.87102933083813, 106.20516992384388, 109.73927251754269, 95.9164870169855, 99.77639736667757, 107.74224481275006, 101.88910361259215, 99.54297711772304, 98.21727091266264, 107.14722125760971, 102.28261147775959, 107.59203372463104, 103.59977476058468, 101.29806518554689, 97.0730370859946, 97.97233458488219, 99.05405367574384, 104.7788078554215, 101.59490231544741, 100.28379517216837, 97.80773624297112, 99.10675464137908, 101.37575949392011, 98.42510946335332, 99.698012721154, 103.4341879813902, 95.81475642419632, 90.73037624359132, 94.4507678862541, 93.82640500222483, 96.95953153794812, 92.20610526300247, 96.45741324270926, 98.47909696640508, 90.5309315650694, 94.3299275059854, 88.8907846327751, 59.678269893892356, 84.29358636179279, 76.62907892657866, 73.8318798618932, 88.49895554204141, 93.81608916867165, 99.9552966702369, 91.9723790691745, 95.81764328864314, 91.33901826796993, 89.54781301559942, 85.00974839733493, 88.78157800243747, 95.167675172129, 100.32932604512861, 92.86685205275013, 92.20004127871607, 93.52382552239203, 92.0706658209524, 91.85233100768059, 92.94978664767359, 92.32427058681365, 91.92528709288567, 89.72533948959844, 91.59758875446936, 89.09543821888586, 92.71669587781354, 95.03601689492503, 94.74176852933823, 96.86126832039126, 95.20119574762161, 90.5606552862352, 93.8342732767905, 88.63181406451811, 85.44891265130813, 71.51153118379655, 75.7203128260951, 86.3819189994566, 87.22824096679689, 86.44227643166819, 91.81654330222838, 61.142729943798436, 33.0556373442373, 18.1833726744498, 5.5273305023870165, 0.5914447600803068, 0.7084445270799822, 0.4034022277882023, 0.17785422173478913, 0.3652540828672148, 0.23210651541669525, 0.22168536009567402, 0.26174855628801935, 0.4678297625674356, 20.66745677301961, 77.19671649317588, 99.290219583819, 81.2837948337678, 71.65057920640515, 105.32092648167765, 72.22212345369401, 37.8257768384872, 39.50923065985403, 50.11311523375973, 91.82590992219987, 85.20055601673742, 95.55984158669749, 85.29861527104532, 5.2885993642191735, 0.23053128542678974, 0.13629284867596242, 0.17178567156435984, 0.21871696857194747, 0.13854759865470473, 0.09179058664989087, 0.0803330829066615, 0.22050924659256013, 0.09791480842977764, 0.15430899967830028, 0.25970993503447504, 0.15796671711629437, 0.19345574020858736, 0.19726793161563336, 0.1472554749418651, 0.22267837858488485, 0.1272945637784658, 0.15225007709476257, 0.06664741243566237, 0.19528883539380568, 0.18578280274185444, 0.12919565692784327], [0.0684960975101398, 0.012362341681915906, 0.025789784981058012, 0.06352856507404678, 0.014766085228221792, 0.028298131130155058, 0.02515975427212975, 0.044219154233653704, 0.020243771892461567, 0.02259313564507231, 0.07710821280676512, 0.09508042100576625, 0.061439818687616825, 0.09686955806588936, 0.08547236842493858, 0.034615529641028375, 0.05056374120495973, 0.02279772134047122, 0.062350563164199554, 1.4344886065490785, 52.951911034122595, 95.03504414712229, 77.50215930323448, 78.85855413252308, 61.302896007414795, 53.26042113765594, 51.092472230234456, 46.46955890040244, 63.8008927529858, 70.40241041491109, 33.757996559143066, 44.91593945410944, 61.046208258598085, 48.39430124528947, 22.79651930255275, 0.9091151914288922, 0.036973870028891874, 0.17534971177097292, 0.05810340235550558, 0.1070829120374495, 0.08597678369692258, 0.15138691050871728, 1.4737897750831421, 0.289127987118498, 0.3957615732665985, 49.58286962201519, 93.15062768997686, 82.61718888436594, 93.03227409239739, 91.05514064911874, 88.67171241391091, 70.50919302048223, 86.01477730658748, 89.01052674939557, 97.61921144300892, 99.40498813506096, 96.3623663686937, 97.15310835069226, 101.17779747132333, 98.61647405932027, 97.77295266428303, 89.12929611821329, 85.43175620417442, 92.12779906488235, 89.37736249739125, 85.01990733608123, 89.17627042339694, 87.24649567757884, 89.60835872157928, 90.71335315704347, 94.08924302747174, 89.21925175574519, 91.89715585400982, 86.81107336475004, 88.81602425729075, 84.08944268380442, 83.99526657596712, 88.72278167355446, 87.64404358402376, 93.07381199252222, 90.4138723496468, 77.97045107810729, 86.515271740575, 82.3641489398095, 90.12078500563099, 70.92890231840073, 62.07253171551613, 66.26780863731139, 71.65126954355549, 91.32289732656172, 90.82390123798002, 87.23218687119024, 82.32531747510357, 90.24932892091813, 87.03994366430467, 86.86484121507215, 81.99046473349296, 84.92267177950951, 81.92858542165449, 86.5380685560165, 85.05516944393035, 88.68112610232446, 86.84226405236029, 88.61806223469397, 84.36270636896934, 81.15709443246165, 80.83167891348563, 84.48760247999623, 80.72247228314801, 83.75085584578976, 81.68193109573858, 84.15532281321865, 84.68862395132743, 86.50748191341278, 83.14237856095838, 86.97727987843176, 84.53652228078535, 87.86959555841263, 82.97758410053869, 78.81170534318494, 76.35823926618023, 74.98085191172939, 69.27402296373921, 69.5840157231977, 64.94832723371445, 94.39156363087316, 60.541387450310495, 20.955148896863385, 19.275384064643614, 8.353311919396925, 4.48995674810102, 0.5938196939326102, 0.11747230535313008, 0.3193277859639737, 0.1552541223504851, 0.10205978843113107, 0.21993374602208215, 0.12383262777040083, 0.09381814559380855, 0.24793196139076065, 22.982421998054754, 70.7350117160428, 80.73239587968396, 64.8636785630257, 57.2503698256708, 63.92704402246783, 40.981492304032855, 38.90062393680696, 48.79557148102791, 42.38739528963643, 55.2596139907837, 68.38531586431688, 70.6973648071289, 50.25083749525009, 7.186888264071557, 0.12592405546456575, 0.06404227682299192, 0.012171603983358271, 0.009911862941789291, 0.06139459268700692, 0.03980473344845157, 0.0303508656384844, 0.010393440175140578, 0.03672677219935483, 0.01965390525818352, 0.10229507701531534, 0.05459090071399847, 0.021305889597222693, 0.045012392313970674, 0.046169322975460565, 0.02419838479029075, 0.014056087388927418, 0.0740815143311216, 0.016063420654034183, 0.02472685522309715, 0.0916763706012599, 0.029432902698435133, 0.03386113604891204, 0.05380732300240667, 0.02941517159342766, 0.008092437637969851, 0.03762275033119706, 0.033153979438206846, 0.05668487565051164, 0.04589016053585276, 0.02500791947597698, 0.040856618133764115, 0.057703017993199254, 0.06659341855875908, 0.016768523191492406, 0.061382296975822224, 0.1516888257596762, 0.019666597419869036, 0.046068624548253514, 0.11791121244670884, 2.961483616982737, 75.89466218025454, 107.76815599010838, 88.44794119558027, 102.38175330623504, 81.63675323609384, 69.2340147879816, 68.54991420622795, 36.68738342100574, 24.29420771137361, 44.268948416556086, 34.745814108079486, 53.417833697411325, 71.25192519157164, 58.57555435549829, 22.25794649893238, 0.18547892630580934, 0.03933267773038918, 0.13658964645958718, 0.14712859545984577, 0.0831975392817009, 0.5394661234271142, 0.997711053538707, 1.246735532918284, 0.7122555387116248, 1.4889589288542349, 71.76395923860612, 95.63301732463222, 93.50571201693629, 100.70947431748914, 97.01170690598028, 90.55765859542355, 78.32330749880883, 93.97651410871937, 95.46473979949953, 103.9490932033908, 100.9987569624378, 99.52442430680799, 102.56355516372189, 104.4795859244562, 102.16639164955386, 101.87921139501758, 92.6875134437315, 89.74849716309579, 93.80887985229494, 92.32598858494913, 87.44812903865692, 93.8328847577495, 91.33564502962174, 95.66084261863463, 94.42280923166584, 95.67486116963049, 94.0838929145567, 96.59428042750206, 90.72337873520391, 92.21515024861982, 88.57686165840396, 86.82718646141791, 92.99473700984832, 91.09090482034992, 93.19291084043442, 94.84673899988975, 84.0928316116333, 90.572783254808, 88.09553192507836, 92.13336883052703, 75.34359270526518, 63.82057520651049, 66.51616527188209, 75.10576371223696, 95.82130678238408, 95.25408498702511, 87.53995956913118, 86.24185116060319, 92.48075746720838, 88.04239165398383, 88.82488096913984, 86.23470460214924, 86.64411375599524, 85.92452356892248, 87.93286338929208, 86.74353015038275, 92.00914736716979, 89.59237114075692, 88.83617739523612, 90.54562476373489, 85.37579967129616, 84.39228888480895, 87.05519383953464, 85.19257791580694, 86.66683996877363, 85.61941023795836, 85.57502469708844, 87.12061112926853, 88.57400617291852, 87.13604173352643, 89.23909110407676, 89.63430912263932, 89.8567702693324, 91.09241885523643, 84.51640836654171, 87.66405551664292, 80.72901479659542, 76.95360798989573, 74.66703876372307, 73.0162778977425, 84.36651891277683, 105.9084818440099, 50.78132629394532, 30.200997129563365, 14.81502159949272, 5.9002684777782815, 1.2435359820242853, 0.17020319438269063, 0.07820299841583737, 0.04308652005068237, 0.1353796718702201, 0.5804320316641562, 0.43694027008548864, 0.09786978544246766, 0.2803361475948365, 18.610140277493386, 74.81736752294725, 90.70990147129183, 75.32861709594727, 60.859762314827215, 42.8232333737035, 29.53521009414427, 53.7892193948069, 61.114131942872085, 62.61905516347578, 81.99240238435807, 79.01524497616676, 80.19643537459835, 67.92864214989447, 10.763989840784381, 0.09564407785693485, 0.055637185296584526, 0.12156565102838701, 0.07149114123275203, 0.023397843976835572, 0.04037728841086069, 0.03611449174763214, 0.05300886786332535, 0.030325234251757784, 0.03878087992028844, 0.05685698113314087, 0.024640180035344055, 0.024915667168135126, 0.017906671292298747, 0.059122372073151415, 0.044378017886511745, 0.08172492676925275, 0.08284021289117875, 0.0755014659596547, 0.034220618976941036, 0.024299807170586243, 0.11485596953500664, 0.08499527950921366, 0.1367541255369302, 0.12406819214623784, 0.17580306728280362, 0.10952062679514771, 0.12087198139558877, 0.1433892743361573, 0.1333756777908533, 0.15378628256580523, 0.15879439850968702, 0.18977628119530218, 0.1590102207997153, 0.1513972220521781, 0.23240971769536697, 0.18635209800014574, 0.1324365918915118, 0.32594675498624004, 0.2515556032378828, 3.262304649237664, 88.06541596689533, 126.23036015418269, 96.0083410816808, 106.1173794346471, 81.32895700393185, 67.7549909776257, 68.60583936014484, 68.48392425044891, 91.84811838211553, 103.39197543359573, 54.575893878936775, 70.77455705212009, 81.41728093547206, 70.936033187374, 39.681983609353345, 1.4575773934202811, 0.08413837952238899, 0.3307919853156613, 0.26208676878483067, 0.25620162006347413, 0.314901483155066, 0.9711218577238822, 5.204282133809982, 2.8559556795704752, 0.929115908520837, 77.81320325789913, 104.45604385868197, 102.51640827425065, 108.97163329585906, 103.35925502161827, 97.98496461683705, 85.68896955059421, 98.96703197110085, 100.97210053474673, 107.13798015348374, 108.41813195136287, 102.58356709634106, 105.85774206346082, 106.14074891613376, 105.05031431874922, 103.49003468790363, 97.5037290203956, 92.11812650003742, 99.15113233750867, 96.71803905117898, 88.99770844367244, 95.45849538618519, 92.57417263523226, 99.4036388397217, 95.03869195138255, 99.31749574599728, 94.75442994025447, 100.38657696016374, 91.65761670758648, 92.02238144413118, 89.57695622597971, 87.311873743611, 95.961500137083, 94.52457904815675, 96.70293792601555, 96.18574203983431, 86.3610363006592, 93.87288508876678, 90.35665281357305, 94.29158241518083, 74.94865709735502, 74.49218734618157, 77.29834510434058, 75.08153915405273, 101.855433987033, 98.73865589018791, 90.7910474654167, 88.8136786799277, 95.08153992314493, 91.66779918055381, 90.33513469080772, 87.38815599872221, 89.48811454157676, 88.43838630184051, 89.1300884369881, 87.81289377520162, 94.47543174989762, 92.08626116475752, 93.01988724739321, 94.805020670737, 89.23211712991038, 86.3545173214328, 89.95293894121724, 89.23948334109399, 91.8594697213942, 86.73640712614983, 88.88257118963426, 89.82485002087009, 92.7185707707559, 91.5307201877717, 94.97193321104973, 92.26652545313682, 94.03718533054476, 95.32524462669127, 88.5515074576101, 91.02121214712821, 84.30635759907385, 84.90206364662417, 86.19710476167741, 85.1496514966411, 94.9890818134431, 86.76731540310769, 53.08127080240558, 36.58944968254336, 19.016246795654297, 7.369192184940462, 1.660344442052226, 0.7487041022508376, 0.3380563374488585, 0.14116976440193194, 0.34871997491967294, 1.2666029507114043, 0.3624091693951238, 0.4110403695414144, 0.37602763863340505, 29.64402056509449, 83.75541363993, 99.95495934640208, 83.21770375774753, 78.58944031500047, 99.48416509935933, 61.917680463483265, 57.67943005408011, 61.75021094660606, 56.12290805385959, 76.51518898625528, 86.03841350924584, 92.9266760426183, 84.12496366808492, 13.850859865065544, 0.18613964649698428, 0.16702193766832354, 0.2598365846901171, 0.11673286962773531, 0.11557798442100325, 0.24083996371876812, 0.10499951294473103, 0.12917166305405478, 0.13791680185785218, 0.1214630948379636, 0.19472304881820757, 0.1698342924036326, 0.190735790998705, 0.16372766766336658, 0.2170402472538333, 0.0790181695934265, 0.18265230701335017, 0.14898753845162932, 0.2286866069921563, 0.14379687907715, 0.19415545427510816], [0.03294496000894616, 0.05707703222851119, 0.05190788460294566, 0.011651395808815235, 0.07628290628593776, 0.026298863813281063, 0.10942556294462374, 0.0541469106270421, 0.05932791346323587, 0.07530609055632546, 0.014254082812957708, 0.03314971615890822, 0.07830740853903756, 0.043080058099041064, 0.04202520865346155, 0.03471825820123477, 0.08289221493947892, 0.11782295145695248, 0.10481470189387761, 31.889846171102217, 91.02351065604918, 73.19307481088947, 80.5647930022209, 52.088813089555316, 58.31767812851937, 73.90569102379584, 49.76788390067316, 57.044645432502996, 124.10562007657944, 132.06011618337325, 96.76234614464545, 105.25769002975957, 80.61923550021264, 30.742152813942205, 1.9394104158686054, 0.14598873323730885, 0.18950249669292282, 0.08790479717595924, 0.0802414128256421, 0.2600949095381845, 0.13635600496444011, 0.8160984504126734, 5.42363235066014, 0.1488792595844115, 11.917773658229459, 88.75614535424018, 83.21396966134348, 92.78991868419033, 88.9433914615262, 87.53575478830646, 79.02253273994693, 84.75869317208567, 91.01173570079189, 91.6964638617731, 96.36998361156833, 94.10176323306177, 100.61319581923946, 102.27423329507153, 95.85912627558555, 95.68892678906842, 91.3552882594447, 90.2986252692438, 87.34619448261877, 87.9718360593242, 87.33099137583088, 89.36347730698125, 90.04999406876104, 87.08226603846397, 87.145706453631, 88.36632451703473, 89.29893078342562, 92.90638954408708, 86.09204015424176, 88.54315280914308, 86.33555658401983, 91.9242908108619, 80.72732033268099, 84.96640620693084, 89.90951830340971, 81.5189330808578, 90.19950697498938, 83.60237844528692, 82.58253866626372, 86.16136412466727, 85.04687755338608, 76.1557351389239, 34.6043263712237, 36.4971367005379, 67.24192926960608, 92.85673233770555, 86.41276451849168, 83.66079822663339, 82.8857143463627, 85.89038325894265, 85.42533136183216, 87.31876927037393, 78.25010822665307, 74.84476920097106, 81.90479232418923, 84.30289806858187, 86.48549310622677, 86.6387479535995, 85.32666806251773, 86.88016983770555, 89.49721444037654, 85.31030393415882, 81.85366030662291, 79.9279099126016, 81.04469499280377, 78.64345919701361, 77.0650895949333, 84.71835551723358, 88.0922842025757, 84.80246682320872, 85.92789680727067, 86.21978390601375, 83.23722147172498, 79.04329776763916, 85.75069981236612, 83.33066017396989, 78.33493340399959, 78.39483584127119, 81.14115392008136, 71.99441417571038, 60.69828225720314, 61.51115817408408, 96.3554943761518, 44.638616115816184, 19.575700336886992, 20.05997184784182, 6.820271188212979, 3.737541225648696, 0.3903961692365908, 0.09916669568948208, 0.2590057163709595, 0.1639723101811063, 0.4553644395162983, 0.21283070136222149, 0.07143069689552631, 0.08427593827007279, 0.2027595562920455, 31.768527261672485, 70.47317781756001, 78.6122057514806, 65.27793576640468, 48.6072624114252, 53.76039781878072, 37.066594246895086, 31.418032107814668, 40.25370828567013, 40.69953664656609, 49.117417643147135, 68.33228541958717, 72.86903212147375, 69.77538031916465, 15.873709513295083, 0.19971850898958024, 0.11039758296383005, 0.010922447827103879, 0.03998014077003445, 0.05459095050971355, 0.07097255333416885, 0.01167073091041417, 0.05577433035678922, 0.07655440784630275, 0.04539772304856489, 0.08810811691106328, 0.0543736879743876, 0.03447804367169738, 0.12165702233511595, 0.09078970809857692, 0.06883928957845896, 0.026367384632448518, 0.062221688023137475, 0.011272659176029267, 0.04074378487383647, 0.019774671358567093, 0.05278200624630817, 0.0958563684816322, 0.0273319008204365, 0.03216173469779953, 0.015397330186510039, 0.087465338499075, 0.05579255175806823, 0.06054441129127818, 0.008467672291331956, 0.04703175411709855, 0.016608251852073496, 0.07395560011988686, 0.037615633374380494, 0.03571833236022823, 0.027915788138465538, 0.09719909844739784, 0.02338158567586253, 0.05262660531086787, 50.80545279287523, 105.98092017635223, 86.23959972012429, 104.45183123311689, 77.04896865352508, 71.16139688799458, 89.09365746282762, 57.434403511785696, 40.981190281529585, 109.14593558157645, 117.12786474535542, 92.84397678990518, 114.59471964067029, 85.21518645748016, 29.48473703476691, 0.654043152688011, 0.1529123141400276, 0.04037865970824515, 0.13592420716679868, 0.05100357909536651, 0.703359664447846, 2.477321442096464, 1.8972662644040201, 2.165367742699962, 0.6619855232777134, 23.219582226968583, 99.4558063630135, 86.16318410442722, 102.48960279649305, 94.39167345723799, 98.18888079735541, 83.89994513603949, 96.42634022620418, 95.9270695717104, 99.4927707795174, 99.84504668943345, 96.09038922094531, 103.64077137362574, 106.13285710734706, 98.25053261172388, 99.52503619655486, 94.55274951073432, 94.57980602018296, 92.61625182244086, 91.43459073958859, 91.84283887186359, 95.30986109087544, 92.39353964405676, 91.69455758986935, 91.61633768389302, 94.2994350002658, 91.545272181111, 92.05456056902486, 91.61096403675695, 93.93515663762247, 89.12855086788055, 93.98952853295111, 85.41183056369906, 86.19444539470058, 93.8845423729189, 88.501905164411, 94.4811034971668, 87.2491236655943, 88.72214624958654, 89.3960565136325, 89.83916667199905, 76.00191547024635, 36.60822606855823, 37.222877164040845, 61.81707166856336, 94.1926916183964, 90.61822783562445, 85.6713737980012, 83.64044112543907, 89.65127729600476, 86.5567155038157, 88.12418091681697, 79.77332145937028, 78.94978061799081, 85.56926665767547, 88.46461911355296, 86.63262121139034, 87.72658594192998, 87.3422093545237, 89.34108841803767, 86.94520273516255, 88.8773387478244, 85.04205303807413, 83.74116759146415, 82.58904980074975, 83.7566452641641, 82.33096568815171, 84.75731249778502, 88.20084756420505, 90.25066252677672, 88.7615974487797, 88.88745061812863, 86.83747091600972, 84.4125989175612, 88.49373878971224, 90.06391848287275, 85.02956421144548, 85.47779698525706, 82.89868954689273, 77.04713298428443, 73.7091802781628, 71.77674616536787, 85.67535108135593, 99.58264796964585, 41.581093265164284, 32.410625142435876, 13.826930465236789, 5.493481918688744, 0.3143764677787981, 0.06841707554075026, 0.12257348565805344, 0.21115512917599372, 1.2049056613637557, 0.38781338040867164, 0.5142429543118323, 0.18334460534876396, 0.2746958712175969, 26.407892588646185, 75.79697162874284, 86.52903925987982, 79.6304452034735, 52.029769651351444, 23.865757411526097, 22.26443017682722, 36.582938548057314, 54.57988292940202, 54.19922474891909, 71.01270767950243, 85.55228279482934, 81.51523036341514, 89.01528850678476, 20.57751094141314, 0.10825497293544394, 0.05152149283657632, 0.023391104318321716, 0.035465734019394846, 0.04205821555167918, 0.08382887234010043, 0.05369329847575677, 0.0565500135323213, 0.012724007002919192, 0.011135981429458387, 0.031162106785021966, 0.07053697872306071, 0.08693806316343047, 0.08644223573707766, 0.037427221710282954, 0.11263876552543334, 0.09800510721341257, 0.04066555580544857, 0.06650714939760585, 0.04498402024769495, 0.12847764868169062, 0.1677148795175937, 0.2054486321585794, 0.08729944981995129, 0.25803217183678384, 0.14694795192730042, 0.18980805852240135, 0.12287023747640273, 0.14495891188421559, 0.24768218608392825, 0.144386705491812, 0.14961091951737482, 0.15222121090177568, 0.12093279345501816, 0.2477342034539869, 0.245442834472464, 0.20474904066612645, 0.21302986890077594, 0.19703948419661294, 56.572556803303385, 121.41814539509436, 94.1951705563453, 107.05681846987818, 73.22552065695487, 78.37316082369897, 94.66629428248253, 66.93408596900203, 71.67004985194053, 138.94928870662568, 156.57784800375663, 119.58136220132153, 132.20798953886955, 104.13657465288716, 49.112071452602265, 3.4920665525620986, 0.32861120878688754, 0.28948311483667744, 0.34140242564101375, 0.3742197017756201, 0.4531274627773993, 1.1075546400200937, 3.0276162489768, 16.234018437324032, 1.8551961476764374, 23.02125934631594, 112.34106694498371, 98.08408291109147, 108.1029381290559, 96.74005923732635, 103.23406081045829, 92.79409208605367, 101.92050610819172, 101.5765299335603, 101.45971390508838, 104.09816680415985, 99.0035649268858, 105.8533097851661, 108.72567715183382, 100.65449053241362, 103.12569356733754, 97.84135095534786, 96.70602875371134, 94.20196410148375, 93.54229988590365, 94.36665658027896, 97.97635109193864, 96.80510782426404, 95.44260978698732, 95.04757219745268, 98.42770607240739, 94.16480356647124, 98.61044145399525, 92.8051531699396, 99.69221545803933, 92.93217520559989, 97.15015088358234, 85.56248095727737, 89.23221126679452, 93.35586963161346, 89.30841507450228, 97.98450177715671, 90.50712277812343, 91.7956998271327, 92.41381829784763, 90.701460530681, 76.10657215118408, 47.32064262513192, 50.86888144093176, 69.45462457595333, 97.96051256118282, 94.74695390270603, 89.87582514362951, 86.80904157700078, 91.48168271587741, 88.78339013745709, 89.2974167485391, 83.14714816308792, 78.91579720281786, 85.74348265124907, 91.61052473129766, 90.60719028595956, 90.64092266944148, 90.36549383594145, 91.77987698585757, 92.1096698699459, 94.4188476377918, 87.68024706071424, 87.33641209140902, 84.64889034148186, 85.16672165163102, 84.68175195878553, 88.1215529288015, 93.06797550570582, 93.369197845459, 91.14438241527927, 93.16389314589962, 91.01565807096421, 86.09403271828928, 92.59219200380387, 93.90927683922553, 86.9526081700479, 89.64234213675223, 87.47209472040977, 80.68629234067856, 78.80407241082962, 81.52737402146863, 93.48131487446447, 82.5168546553581, 46.50032989440426, 37.607551851580226, 17.40684340077062, 6.653226267906928, 1.0718093451953705, 0.2944815321074378, 0.6038407368525383, 0.3499363693258455, 1.7949066214984464, 1.0982021160664097, 0.5635204262310459, 0.2528978505682561, 0.4879382222650513, 40.183333120038434, 81.63494110107422, 95.27030791005781, 86.05198491004207, 66.07307864773658, 78.3233702567316, 56.416811250871234, 45.5449934928648, 52.83032932589131, 56.229486696181766, 70.89008654317549, 89.50305877193328, 92.68096308554374, 105.49047485474618, 26.83643702537783, 0.28115880345144584, 0.24510168019802342, 0.08768073944074493, 0.13945556606256193, 0.12171801825564717, 0.22258698429551818, 0.1552830957957814, 0.1419452292424056, 0.11596541806694963, 0.16635640644498412, 0.23478839005674088, 0.1822811987010702, 0.17665412967964528, 0.21609385287569416, 0.13930881425978678, 0.2159349815619569, 0.1791917499635489, 0.14830020436596486, 0.1481766650272954, 0.16236775434545933], [0.036999384587210034, 0.03222727735016135, 0.05657375459709475, 0.03871380892251769, 0.08535273613468294, 0.12890305730604357, 0.08220915562443196, 0.030996800332720724, 0.0468928623764265, 0.024988378488248395, 0.06702251206602781, 0.030850552232755773, 0.06455987646815277, 0.08987115335560615, 0.06832476960675371, 0.09676002281447572, 0.22278350116985463, 0.13487091287970543, 2.831034165236258, 69.35046211365731, 78.91516962359029, 77.65250375193935, 51.69525423357564, 59.168350004380756, 65.27582553125197, 51.72170669801774, 43.534676797928356, 50.8483596001902, 109.74154749224263, 128.44363597131544, 92.94202035473239, 57.4819230264233, 26.246090896667976, 1.0877678759636418, 0.07646047780590673, 0.024868188869027842, 0.09566425661286039, 0.038499989952411384, 0.09066923311160457, 0.11199712858445222, 1.3935873561328458, 1.9047996666162246, 0.3454308530255672, 0.7991340155563047, 47.55621233294087, 71.11046883367723, 68.12104225158691, 90.42823606921782, 96.06127738952638, 87.47272229963734, 78.51958290223153, 92.07491767021918, 91.44467123093145, 95.55726851186445, 93.20175970754316, 103.60768225885208, 96.2761369828255, 95.35219130977508, 94.19530391693117, 91.37071886370259, 90.22843837738039, 89.68404477642429, 88.16450288218837, 84.48690429810556, 82.18874054570352, 84.56154700248473, 82.2630145472865, 83.88599718770674, 87.95404418822258, 89.11501869078606, 85.99571458755001, 86.02270833907589, 91.73876270171135, 89.13692120582827, 88.80737935343097, 85.9238410765125, 92.96476225699149, 81.68979937030424, 85.38567619939005, 87.72201245830905, 87.6113937747094, 77.40861861936509, 83.49961234677224, 79.78206834485455, 90.5872489560035, 57.66222653850433, 37.37232338997626, 32.62475713606804, 35.46820878982544, 97.0156292761526, 81.93887772098665, 85.2691190473495, 81.08107105378183, 89.62630748748781, 81.3766844041886, 82.00914306025352, 72.47247265231225, 87.4316393944525, 84.33811310798892, 86.12214042294411, 80.32304948376071, 83.56420593876993, 80.62919832045033, 79.18814305336245, 76.17654723505821, 85.49722056235038, 81.79546017800608, 85.42907330297655, 80.46815364591538, 84.54431995268791, 80.7333686274867, 78.68248678022816, 78.90931744729319, 87.49077304717034, 82.62640645427089, 88.63215923309328, 80.81058440669891, 81.92139963949882, 79.21556042086694, 82.7596023005824, 79.69192443355438, 80.99601053422498, 77.33043793709048, 79.54910309084, 76.99043120107343, 70.01130304028912, 67.6580378317064, 88.22024760707733, 30.549407543674594, 18.009907814764208, 17.791543583716116, 8.57806961382589, 1.5613546054209433, 0.0737650357487221, 0.1119879968163948, 0.3478179523541082, 0.3993601027515627, 0.029915294857815872, 0.17348257163839956, 0.13688451370164273, 0.051898844765439156, 0.5479582999983142, 38.18840780565816, 75.84370274697581, 77.76149072954732, 71.70459024367794, 66.16068870790544, 72.66339794281991, 44.40433294542375, 37.09498436220231, 46.8257297238996, 43.430792823914565, 53.889388884267504, 59.96520303910779, 59.52333627208587, 67.41561182083623, 20.474203555814682, 0.14509561261342419, 0.0364349348350398, 0.08653245025104092, 0.016129485203794414, 0.0268531494939159, 0.02747041526280584, 0.04351120089150725, 0.061152256093919284, 0.02631112122006955, 0.03798242478120712, 0.04698132637948279, 0.06456217473192562, 0.04714719207596876, 0.06270802745054807, 0.03761612367065203, 0.010168206494962497, 0.027572362413329464, 0.032596171668340126, 0.04611676168297568, 0.06193677226321832, 0.009054994556091486, 0.03884009851683532, 0.03183756459264025, 0.09036621469403468, 0.06100085413744373, 0.023329597034101045, 0.026958540209659168, 0.04445712029513332, 0.03387469963561143, 0.05643394355091357, 0.09180181749886082, 0.07917183917015791, 0.02607259208396558, 0.15297899443295696, 0.06588561460375786, 0.06453199852858821, 0.26586860778831667, 5.654954621868749, 91.54972014888641, 92.0940980603618, 96.37029740118213, 73.21193356667796, 74.90515016740369, 81.41437838154455, 60.83927185304704, 48.07016441898961, 55.75997506418536, 127.32700778592019, 132.80789252250426, 97.68727241023895, 67.3139439859698, 27.288237194861136, 1.0860571096981726, 0.02875917050386629, 0.06334008446203605, 0.08033390262074049, 0.21248570132640102, 0.2955365883967569, 1.4887972536586946, 3.2536060579361457, 1.7360619984326826, 0.5411790347387714, 2.058459866431452, 66.81803872508388, 79.28693971326275, 79.16276531834757, 94.83320682279526, 101.37652043373355, 90.15745916674214, 85.3840680276194, 95.59606075286867, 99.84916517811438, 99.32923147755285, 97.57925818043371, 103.15630374416229, 98.03968952548121, 97.2112221871653, 98.99942290398383, 94.1673295728622, 96.87712254062777, 94.97987993301885, 92.17093729203748, 90.53920776613298, 86.18620841733872, 84.52247235082811, 88.61241402164583, 87.99243634746921, 93.97502360805389, 92.910735530238, 92.00174193228446, 90.77906854691045, 95.03152185870756, 92.25993587124734, 93.22483893363707, 89.86999650155344, 93.91832182484289, 85.61803740839805, 86.0834893872661, 91.60716718243015, 92.76298769058721, 81.78219472208332, 87.19074310794954, 84.82065093132758, 97.89891565999677, 55.64074677805747, 45.67358055422383, 44.492425457123794, 33.789289228377804, 94.60425023109683, 86.71617554080102, 89.22843794668876, 82.72864695518248, 90.58976711765413, 84.78531037607502, 81.31501690033944, 73.07833763860887, 92.51991841100877, 90.26984291691934, 89.88452496067171, 84.0860459112352, 85.8366781665433, 84.53722046267602, 84.64327350739511, 80.40639200518208, 85.3191057328255, 85.13305202607187, 90.73833081030077, 84.42804521129978, 86.27540311505719, 84.90891994968538, 85.2309779197939, 81.85466443338703, 88.45979459824102, 86.76978649631624, 90.64087560099941, 84.74859699126213, 85.42733177062004, 82.30957308123189, 85.31473621245354, 85.58254780307894, 86.47436926441809, 80.3786059348814, 85.29107647557413, 78.89240418711017, 79.11099003207299, 69.82118575803696, 88.47616657134026, 83.19119638012302, 41.13824982796946, 29.12069989788917, 15.585916388419369, 3.4294042375779923, 0.1527579167797681, 0.16196790241426037, 0.6386199028741929, 1.6537957999014086, 0.6185767751547598, 0.2775540226890195, 0.4325296567572702, 0.059740911463215474, 0.24433124089433303, 32.70360069890177, 82.73977864173152, 85.28721686332457, 85.37052800578456, 57.74537294141708, 27.489978421118956, 22.3704969498419, 34.363904691511586, 59.44825818461757, 58.755206754130704, 70.7991660025812, 75.12766622727918, 68.75790965172553, 81.20400597972255, 27.391018982856508, 0.19795155783574428, 0.0569130587691982, 0.041946362884294604, 0.0034718750412726118, 0.03850562069865485, 0.07124389401606976, 0.04390667463021894, 0.08943811449552737, 0.07257550804605407, 0.008040755431378081, 0.039515255634943326, 0.029574558101294023, 0.008924425403106838, 0.03839645316944488, 0.048945353651839885, 0.03476600846155517, 0.03024797619981391, 0.039854850920458, 0.04245619439790326, 0.26815075307123126, 0.1758289457328858, 0.11649571944989505, 0.13457385462618646, 0.27694924223807554, 0.2299879145838561, 0.19331977492378605, 0.13300836927467777, 0.10858127276503271, 0.1050999470716042, 0.23655650566422173, 0.15818321356369605, 0.11201615820849135, 0.11837334732615179, 0.31899490543911535, 0.1671649662837867, 0.3381723844476285, 0.5777712550855453, 8.021401936008084, 111.83627359328732, 104.23042128163, 104.6860908692883, 71.73466697815927, 79.60517729482343, 87.0321616818828, 73.93128056680003, 63.674768940094985, 60.08980105000158, 123.45854666925247, 145.2432494009695, 117.22891284573464, 83.82913066494851, 46.79413503216159, 3.8582024026301602, 0.22895125972647823, 0.2715249720119661, 0.23526425323178693, 0.2549983564043238, 0.2292323527076552, 0.5157628727536048, 2.5355078424176862, 10.079936327472812, 2.235677944075677, 1.2167601671911057, 74.90649946274297, 92.63469480699109, 87.75646655790268, 101.59517688135948, 110.78015973491054, 96.91559314727785, 92.19964904169883, 102.48202477732013, 104.25631676950763, 102.12320635395666, 101.30055196823614, 108.70181345170545, 101.9880336330783, 100.81800630015712, 100.53034751645981, 97.92374426318754, 98.4624033589517, 96.92050395473358, 94.93034824248284, 95.01264741343837, 88.58280012684484, 86.55057307212584, 90.43008742793914, 87.36024441257601, 95.58809834141886, 95.27379881951117, 93.37281427075787, 94.24108582158243, 97.10502793712001, 97.03262098373906, 98.14000806500836, 94.4545098273985, 96.19408884356099, 86.88908146273705, 88.31304304061398, 93.41248512268068, 93.19664493683847, 84.61097671139626, 90.60722950966128, 88.10813057807185, 96.46812915802003, 63.51926657461352, 44.140231916981364, 43.492997692477324, 43.24481756456437, 96.97966898641279, 91.05333635883947, 93.30189781804239, 87.65482225725728, 94.17228744876002, 87.37576915371804, 81.55780376926546, 74.732252090208, 93.37142575171687, 91.51703111587032, 91.91740312883931, 86.10812187194826, 87.02681156896776, 85.32767218928184, 85.02591640718522, 83.56174269030171, 91.84655727878695, 90.65367821724185, 92.05919681056854, 88.91559754648517, 89.62657420865952, 89.10010583939092, 87.4439242578322, 84.67437005812123, 88.88597580694383, 88.74608055237802, 94.8129124795237, 89.92155997983872, 87.69578749133696, 84.46549600170505, 87.8058256641511, 90.76376345849808, 91.66361793395012, 85.92743396759035, 86.97702100200038, 86.47161576055711, 83.73276587455504, 77.46766597993913, 91.3011517063264, 69.66229838709678, 43.44105374428534, 34.980328698312086, 18.64875993421001, 3.942424760710809, 0.28938928438771155, 0.2438714042786629, 0.7807265161987275, 1.615462598781432, 2.1226644083376853, 0.9965342199129443, 0.2015815888561549, 0.09812984164924392, 0.9391009146648069, 48.87774905850811, 88.81698916035315, 93.18906691766556, 93.05532193952992, 91.22723856279927, 99.1599968940981, 66.59560895735218, 55.319932199293575, 63.961749153752486, 58.10238707450129, 72.54111413032778, 79.16552666694888, 75.57502039017217, 93.83581084589805, 35.976351845648985, 0.47210726045793105, 0.11720998152609795, 0.2086470032771749, 0.06004545439575469, 0.1048439817743436, 0.1653326831517681, 0.21734203993072435, 0.18262592294523794, 0.1257713434977397, 0.2032521048620824, 0.1828735991711578, 0.1162038399507442, 0.10202875420931848, 0.13413313956510636, 0.18496572400533384, 0.09863627939334801, 0.12268806176800882, 0.12401697916849969, 0.11080188586586907], [0.056096025997953075, 0.03207996247276183, 0.06272925191649026, 0.21375420503318313, 0.05821427826078669, 0.022318213502125397, 0.04943820099616724, 0.05842764140857805, 0.06177322781314293, 0.05331935563815698, 0.044703762302355426, 0.1066402051477663, 0.02463267428890592, 0.16272403119552523, 0.02867826395818303, 0.07076033931826392, 0.06481376566713856, 0.16322480754986887, 10.783215338183988, 74.0063076634561, 62.75556149021272, 63.83782186815816, 45.37266415934409, 60.3846848395563, 41.50688594387424, 58.21138189684961, 48.73961887051983, 36.48282004940894, 51.74557824288645, 63.89522183325983, 50.226934571419996, 31.424374580383304, 2.9029419970127845, 0.10313003624398863, 0.1284686394877011, 0.013515726313926281, 0.1490601789086096, 0.14597906520770443, 0.054560977319676074, 0.5584684134491029, 9.436796076836126, 2.797407440600857, 0.2072745874043434, 19.140887952619984, 75.6925267557944, 72.74495186344271, 74.31670050467216, 78.47289885244062, 95.0945935710784, 91.07110469572007, 100.50331454123221, 97.26914774987006, 98.47376254297073, 92.97481136937296, 95.26972739927231, 94.56593651925364, 99.08693882726855, 94.48835988198557, 96.84629271107336, 89.35656609073763, 93.04737521756081, 89.62334217563753, 87.11687703286448, 84.14664653039749, 84.78463572840538, 82.59388216080205, 91.52998278217932, 87.54610200082102, 85.71864620331796, 84.06636345771052, 88.02179136583882, 83.29613547171317, 87.1615763633482, 84.88560538138114, 84.4414597172891, 81.17461173765122, 84.37568156949936, 84.48344476761358, 78.20938617952409, 75.87358336294852, 88.78244092387538, 81.24052324602681, 78.67617960899108, 84.97163080400037, 94.61861395066785, 36.74607776826428, 57.90000846309047, 78.96551716712214, 23.495077740761545, 66.83660722547963, 91.89114678290584, 80.78701880670364, 79.3013269670548, 82.28304216938635, 79.88756441300916, 70.8619317700786, 81.35706470858666, 85.26213722844278, 83.29347610473633, 86.97173364700811, 84.41249693593672, 80.86996909110778, 80.42573713487195, 80.51532406960764, 81.09582701037007, 77.01605996777936, 79.12296110583891, 79.16147093619071, 80.80514015689974, 78.22160044024068, 80.9280829275808, 80.07011152082875, 79.08480428880262, 82.64840310619724, 86.32807270173105, 83.48460535849296, 83.04992829599689, 79.68171058162567, 79.42336759259625, 82.01657202935989, 79.69004954061201, 76.73705393268217, 76.83452483146422, 76.45677704964915, 79.8504509464387, 82.21334949616464, 71.69364683089718, 71.1091979857414, 75.56228053185248, 21.691924948846143, 13.050996411231257, 15.84611269735521, 7.31355385434243, 0.9632955647764668, 0.05272666788509777, 1.8457828269850824, 1.7018279192909118, 0.21551872002741984, 0.7484128049785091, 0.27827187771758727, 0.09306540292116905, 0.1956192950808233, 1.1173800547276775, 47.53361163600799, 77.21362975335892, 74.19185930682768, 64.76109289353894, 52.31175276540941, 49.76148651492212, 44.340672877527055, 27.648434331340177, 41.210123339006984, 52.728277098747995, 59.387571273311494, 73.62215857351981, 64.17793058579969, 77.44744223933067, 21.819339221523656, 0.21341562481416812, 0.03080618616584088, 0.03147292589288085, 0.01417691573395484, 0.05266723861437171, 0.05154091316545683, 0.046077530320373275, 0.04021653252082967, 0.06910497653147868, 0.02156437723897398, 0.008008534730892749, 0.049798622381903475, 0.006831314230728294, 0.007330043215094315, 0.08810280792174802, 0.05915948137220356, 0.09260254025819803, 0.058712296698602943, 0.013327555009914983, 0.034320264033252196, 0.13506623465688, 0.07857218384742737, 0.05150564630786258, 0.024571402576721968, 0.08025572334806766, 0.05027817043986532, 0.04020007312177651, 0.04293541303805767, 0.07083248947897265, 0.0503215310163796, 0.036035496591319965, 0.09359634015709163, 0.00021215590095380324, 0.06492931470875779, 0.07012266305185134, 0.3351308315271332, 21.13609371646758, 92.12251170989006, 76.45497275936988, 82.62988167424356, 55.775872430493756, 81.01793658348822, 58.26263943026143, 53.23562783579673, 29.870737483424527, 36.25824474519299, 57.035839711466146, 71.13407365737423, 60.43426359853437, 36.82106956358879, 1.9097335179967267, 0.1379914188216771, 0.13729771088448264, 0.10840911748668841, 0.15468119583543272, 0.2543075136359661, 0.39809011283420753, 1.6481144918549446, 7.574147303258219, 1.0101535471697007, 0.9781131148338319, 34.93364464852118, 90.75645216049688, 83.12137034631546, 91.34319166983329, 91.72858022874402, 93.73989320570423, 95.71768560717183, 106.2966239067816, 103.05234524511523, 100.62949718967562, 98.477888876392, 99.49685788923695, 98.06256478832614, 100.986628993865, 96.16038783904045, 98.79882504863124, 94.1706871217297, 96.14201545715333, 91.01269275911393, 91.4001444847353, 89.54759336286976, 92.17387906966671, 89.69830651437083, 96.23448925633585, 90.13036343359178, 88.61881532976705, 91.54639397898029, 90.86639619642689, 89.30382590140067, 89.108029027139, 88.66583670339277, 89.68974005791449, 87.55972831479966, 85.63887303875339, 87.719894378416, 81.83091055962348, 80.67049303362447, 92.67019225705056, 87.0073409234324, 81.5664408283849, 90.89611207285236, 94.42328776082685, 40.18283497902655, 61.12731895139141, 81.72768162142846, 30.36378137526974, 58.74427903083063, 95.39634150843467, 84.05144276157503, 84.62918435373615, 81.73256104992282, 79.21061823444983, 72.84283853346302, 85.6882635239632, 87.028364827556, 88.50897327546151, 89.28651255946006, 85.39287767102643, 82.43074294059508, 81.3307063810287, 82.4882213531002, 86.08942001096665, 78.36400601171678, 79.97107951871811, 82.59646308037543, 85.75208833140712, 80.86573293132167, 83.07479612288937, 83.98665305106871, 83.71906111317297, 82.34491363648446, 87.07130693620252, 84.73404499792284, 83.12083690397202, 82.01620332656368, 84.41033963234194, 82.02580528874552, 82.36002260638823, 80.63414835160779, 80.90004582558909, 81.33012587024321, 85.42464102468183, 81.48574982920002, 80.38164184939477, 73.54644113971342, 87.74838647534771, 75.79659508120629, 38.489606611190304, 28.483418687697384, 13.439722907158638, 2.7879177562652098, 0.06902885803532216, 1.1771985287627866, 2.0113741414200876, 0.3594920597970486, 0.1735431385496932, 0.18438723569195117, 0.38338459547488923, 0.22543301625597864, 0.31578223911985276, 42.96576838339529, 87.34044428794616, 82.74809406649682, 75.4664727180235, 50.22585591962261, 28.739847560082715, 25.854087260461625, 37.191643330358694, 61.04047767577633, 70.92632139882734, 77.90418655641618, 92.65405562616165, 75.76936598747008, 92.490445721534, 30.868072663584066, 0.1885150093585253, 0.01100266872409491, 0.06623536438470887, 0.0266036250808787, 0.04698894512388976, 0.029207435361440146, 0.07319564855987988, 0.03809498991036127, 0.07390889173914349, 0.027114780011376547, 0.014835784865182736, 0.027693153411570578, 0.05769072228201455, 0.017819118933872353, 0.0922748921138625, 0.011863956479505907, 0.014274143782864897, 0.054793538630849896, 0.14498492823012415, 0.1618016613346915, 0.18558840027018902, 0.3119105839681241, 0.20325559822301711, 0.09620429497332343, 0.2013590556359099, 0.1860101623160224, 0.1354466585983192, 0.14214373794534516, 0.14648091408514208, 0.14865007672098376, 0.18568966177202043, 0.23277367074643415, 0.14555387108797027, 0.19440784960264162, 0.2046092909069792, 0.3724104778901223, 29.889800202461984, 112.9176082918721, 84.46720615510019, 92.14552033332087, 64.30344250894362, 81.99677974947038, 57.76809130945514, 83.95169688809304, 71.41544095931515, 53.72652815234277, 67.40866138089088, 88.66668393535, 71.97393940341088, 53.1181763833569, 5.779156473375136, 0.40068295273569327, 0.4662287307362403, 0.24583907046866035, 0.3561699348351648, 0.3286818114499892, 0.3148451297273559, 2.36744555734819, 17.100863225998417, 8.451531010289347, 1.1574216932058334, 37.31849670410156, 102.26704751291584, 85.83714885096397, 96.77247370443037, 93.48642964516917, 104.19535529228949, 99.76302208438997, 112.081829655555, 108.80241440188502, 107.43943783544727, 101.18524212991038, 101.58919918921687, 100.13372528937556, 104.74207878112794, 98.111296315347, 103.01367067521619, 94.43949499437886, 100.09712957566785, 95.3113280573199, 95.68863653367566, 89.62168693542482, 94.31335941437753, 91.9293192894228, 98.4477258497669, 96.71078266636019, 92.7531425414547, 92.13298443825015, 96.69195528953307, 93.63140044673797, 95.9107760460146, 92.3812626254174, 93.8426043910365, 89.78340625762941, 89.50941301161244, 90.961364623039, 81.04191010998142, 82.14848918299522, 97.12838957386633, 88.2253231540803, 83.4848956138857, 92.5653394576042, 96.26559365180232, 44.07655615960398, 62.85119279738396, 75.64749010147588, 30.84415012790311, 67.85346600317186, 95.44027989910495, 88.98512548015964, 85.50814828565045, 85.18175217413133, 81.83330320542859, 72.44627906430152, 87.73609376722767, 90.75456157807382, 90.30242996831095, 92.70672521283551, 90.11196751748362, 86.08641547541465, 83.21915503471129, 85.85796094709828, 87.68534614193825, 80.43399764645486, 84.47487046641689, 87.07612360677412, 91.33541753215175, 82.847502616144, 87.21159442778557, 84.95621588922317, 86.00118237157022, 86.47198446335332, 90.40365849771808, 87.94529730273833, 87.56394878510507, 84.58338675960418, 87.53716684156849, 86.60368980899935, 84.27937953702866, 85.04303363061722, 83.71444840585032, 87.63305310280093, 88.04283095944314, 85.57612296073668, 85.00938753927909, 77.16391763379498, 82.70078243747835, 63.546444677537494, 41.13728884727725, 33.93031804792343, 15.46926215771706, 3.242900929143352, 0.276457904086959, 6.069196626063317, 3.4806789313593223, 0.3432820989720283, 1.769993809923049, 1.5173125170892285, 0.3862653312183196, 0.3693022140331807, 2.3615134627588334, 56.108720840946326, 91.92661285400392, 90.45863443805327, 84.06096627635341, 74.79832833813083, 69.22026295815745, 69.65178643503498, 42.27534494092388, 53.154222965240486, 71.60031011027675, 77.93068608930035, 95.89278805640437, 81.22773631926506, 104.91719691984116, 35.31176113313244, 0.3156448642332708, 0.12621464027512458, 0.17092837321181453, 0.18121123434074465, 0.17112703513233893, 0.19959706873182329, 0.12119194567804376, 0.11286849997216657, 0.13387467682121262, 0.08895793058458837, 0.0824064998737266, 0.0782192548015906, 0.18037212291552177, 0.16486973621912543, 0.14768485190166583, 0.15911997055574773, 0.1633532651730122, 0.30871679405531577], [0.02875180073803471, 0.059188002825624524, 0.062318759024023056, 0.050994382209835515, 0.04601068914897981, 0.04077067072953909, 0.022472335070732142, 0.037110490318868435, 0.047452351709287015, 0.056375533177126805, 0.030414841641041062, 0.04586152033880354, 0.08563054259866477, 0.0444490265762133, 0.08285771033936933, 0.09568182300896415, 0.07007445313877637, 0.49501414741239247, 24.10287645555312, 75.25341741500363, 66.9446449895059, 59.89670668878863, 55.548971160765625, 40.702035196365856, 43.67558010162846, 48.18175192802183, 63.4117308739693, 41.85789492822463, 35.98719719917544, 54.85924590018488, 45.78465423276348, 5.739973956538785, 0.13495322136629012, 0.08932521611812616, 0.24163386063469997, 0.24169307923124683, 0.023817719531155402, 0.1317116428887652, 0.45269171196606856, 5.343679247363921, 7.552939538032779, 0.11628660042920422, 5.271414970197986, 65.81042105151762, 77.93306304562476, 88.38495577535322, 85.0448065419351, 91.2348871846353, 83.7114203360773, 96.42906235110377, 96.08958905743015, 94.3670331278155, 90.07211623653289, 102.00755919179609, 98.92931445952385, 95.4749301172072, 96.73996510044222, 95.56323835926672, 93.93279537077873, 94.43919689424577, 88.70881803574102, 86.37245039786063, 89.33125895838585, 87.72900996669647, 83.33154662962883, 86.54672914935698, 83.04540972555839, 80.16416995756089, 83.82177229850524, 85.71473952262633, 80.51337857400218, 83.57965223250851, 81.2649674569407, 85.02320997176632, 86.96256314554523, 87.09753974791496, 83.47210868712395, 84.22258361693352, 80.43689235564202, 80.28188028643208, 83.21163977346113, 85.29794062337568, 74.0293712000693, 87.6132215992097, 80.771297947053, 55.42026642830142, 58.15748068594164, 73.81314662195021, 43.87884124632805, 27.980723804043187, 91.18507308344688, 81.44549062175136, 84.47086180410078, 78.73670178074991, 75.62877255101358, 72.18693194850799, 81.06771146097492, 81.46902484278526, 85.55629145714545, 83.65284365992393, 83.25046339342671, 75.56531644636586, 73.93168849329795, 75.16236351382348, 76.7607528932633, 73.01309293316257, 79.10116841716152, 73.43019777728666, 74.66031582124772, 74.5746983251264, 74.68590536425191, 75.87235173871441, 76.3149598336989, 77.62914995993339, 82.00722894360943, 82.42831107108825, 81.81500142620456, 84.89481510654574, 79.99768103322675, 76.95585943037464, 81.54323608644548, 83.84673426228186, 78.86010739111131, 75.19553892074093, 74.22979647113432, 75.5064416700794, 79.21649394496795, 74.8073027210851, 74.76832220631262, 65.50830833373531, 20.7224170238741, 8.989457603423826, 12.409500614289316, 5.645871393142208, 0.4127668559310898, 0.1962725076103403, 1.0196533438659485, 0.30560393367082844, 0.18356022845593192, 3.791006563171264, 0.5453710065734002, 0.06656024695163773, 0.2047710273895533, 3.1806011882520493, 52.90394436928534, 79.67129276644799, 72.17980107953473, 56.80827556117889, 41.17641841211627, 48.77302569727744, 38.310428819348736, 31.243602345066687, 34.42310110215218, 52.06844422125047, 40.06162589596164, 63.270749122865745, 60.88535970257175, 76.6527621976791, 10.765777460990414, 0.26438475676601936, 0.05057450474029587, 0.07183095485332512, 0.015333697008299492, 0.05654052936381871, 0.03843504484863051, 0.019250165430768844, 0.06845177166284093, 0.06440858176398663, 0.058490939423321724, 0.028379213876060905, 0.12686173942300583, 0.01331200150983228, 0.021305765107934995, 0.04000564766747337, 0.05361577037781958, 0.08833807352329455, 0.026100228705834, 0.04265910810640743, 0.04297896513655301, 0.011530252410128955, 0.07442152713455501, 0.019130088809517123, 0.026384485630138267, 0.024112933427996697, 0.07439538821457856, 0.001871573507331402, 0.023451818701540752, 0.021241047915311593, 0.01882478936515268, 0.05378235619695437, 0.03184774590115393, 0.06357412432290374, 0.05202393543215529, 0.29057341117051344, 37.953100896650746, 93.5713646488805, 76.96519467138475, 77.09719027242353, 66.0006481601346, 54.47433587043516, 30.948224336870258, 28.221320029227968, 31.859047720509192, 33.73225796607233, 38.52101302916004, 59.920519398104766, 51.493358073696015, 3.234137128437719, 0.10706839467128439, 0.1319457593584253, 0.16506864328778562, 0.17466047778725627, 0.034498846789281216, 0.2601402006562679, 0.1671910439167292, 2.145796831577055, 1.5804434327348587, 0.4440019153539212, 11.12657570069836, 88.92609380906629, 82.08944966716152, 97.26832405213388, 92.75442123413087, 96.52305018517279, 90.91808519055768, 99.35332267515122, 98.6262172268283, 98.05334721842121, 93.68377977801909, 104.79804315874654, 102.93057918548585, 98.8935895119944, 98.04761271322928, 98.27332158242503, 95.3214163934031, 97.92981609221428, 91.05261464272776, 90.09493658619543, 93.58590095273911, 93.35068425824566, 89.03894824366417, 89.42108123533188, 87.54139515661424, 84.47596873006513, 87.02689001637121, 88.8949345004174, 85.52018996207946, 90.64289169926798, 89.04580454672538, 88.34836006164552, 91.21751108477193, 93.33263351071267, 89.12828414670884, 87.57069526180145, 78.64202360953055, 84.45430155723326, 85.69881469972673, 88.395216695724, 77.0957782191615, 92.64238265252884, 80.94584341972106, 61.95067151900261, 61.87702901901738, 71.19738071195542, 51.09583370147213, 29.688612030398463, 88.63180621977776, 83.01599979400635, 86.33622338694911, 80.36791355379167, 72.73931933987525, 72.78532089725618, 82.90043892398958, 83.87341422419395, 87.20998625601493, 89.24251925560736, 86.34540173315233, 80.81739364131805, 80.96324305380546, 80.25106614635837, 78.6857972606536, 77.00819953795403, 81.15755727214199, 76.69721834121212, 78.47019241702172, 78.45894305936753, 76.9479440873669, 79.0854710917319, 78.194975391511, 83.39340240724626, 83.29550789248559, 82.8460434944399, 82.3070078511392, 86.90906201639484, 83.94705280180901, 82.25437748816707, 83.82442382074173, 87.25142217451527, 82.6927415786251, 80.93729265274541, 76.80184364318848, 78.45711523486723, 78.87330224437099, 79.95350730034613, 77.97409103762719, 81.24788161247008, 70.20338935236778, 36.19767942736226, 25.25004617629513, 9.904575982401449, 1.314041321316073, 0.8122555082363467, 1.023125928496161, 1.588456222126561, 0.8207939565181733, 2.0034952029105155, 0.5075000016199005, 0.19779032697120022, 0.05475097095533725, 1.4701678339512119, 50.084258356402, 87.7584748114309, 80.94140329668599, 62.222436858761704, 38.39916459975704, 32.35596103052939, 19.038176767287716, 31.526970055795488, 44.96546722227528, 70.38375562237155, 55.09719648668843, 80.78970955264184, 67.81032777601673, 93.78200377187422, 17.30304571890062, 0.14449991796526218, 0.04583411737375202, 0.08757340286167399, 0.017880480661387407, 0.09903490558386811, 0.0401920368594508, 0.03918383833802035, 0.08452446485358862, 0.08228594827796183, 0.05648824386298657, 0.10644296815078105, 0.04070157342920861, 0.013370743216646296, 0.023579872213304046, 0.03627063961879861, 0.04609022822771822, 0.027182486862124457, 0.1195838658379451, 0.09396544131900995, 0.18801666916378085, 0.09349369203611728, 0.13203686253438074, 0.1806575213108332, 0.0716463046809358, 0.16243941420989652, 0.15129858057104772, 0.15861513393540538, 0.14776227274729362, 0.18407592820304056, 0.1913461945350132, 0.22158881769545619, 0.20782221769613607, 0.18464078015137106, 0.2653381378660279, 0.505190062667093, 53.520917507909964, 110.8860323506017, 95.42673203252977, 85.45973054824337, 75.90577817732289, 65.41393610738939, 66.2023364343951, 74.77204061323597, 92.25539376658779, 65.15806421156853, 54.770831754130704, 72.59789436094223, 68.26308696500718, 9.107001231562707, 0.38750670009082366, 0.31589313800777163, 0.5022683565414722, 0.43490995322504356, 0.09068559674966721, 0.4811664340236495, 1.6108038036092636, 15.185337470423791, 15.689350270455884, 1.5944214117142463, 9.63701738465217, 98.28318242103823, 87.33470978275423, 106.01993207008609, 97.47776292985486, 104.04531678845807, 95.069317817688, 104.70142733666205, 104.24438491944345, 102.31339423887192, 96.69265347142374, 108.3884709881198, 104.7441811715403, 104.23777180333292, 101.06438606016098, 102.27290753395327, 97.5171043026832, 100.95648165672057, 97.70893173833048, 93.90591929035803, 96.61158592470231, 96.87469067112093, 90.99042938601588, 93.46434670109903, 90.61222660926082, 85.48513966221964, 92.18900372905117, 90.83125960442328, 88.53917552578835, 90.12260498539095, 91.94740141591718, 90.47770500183107, 94.45726333125945, 95.32230284906204, 90.25236483543151, 91.92076852244716, 84.43504271968719, 85.08154346096902, 87.25754891672443, 93.38573455810548, 80.5099896461733, 93.65696645552113, 85.13977496854721, 58.54332031742219, 58.68425107771351, 74.10195858247819, 47.28474901568505, 37.189078100265995, 91.68050765991212, 85.73997605231501, 88.35272173727714, 85.46673590137114, 75.45858090923679, 74.50002424178585, 85.40649614026471, 86.11383284291914, 90.89149936552971, 91.29214594441076, 88.9976143067883, 83.94189096266224, 81.05887828334686, 82.24506578137799, 82.32759244980352, 79.27409002857824, 84.70705909113731, 80.22684158817415, 82.32141079441195, 84.78983679125386, 82.10089514332434, 83.84319628438642, 81.62823384807956, 84.99751844713765, 86.91117225154754, 86.73617962867984, 86.13684146634995, 90.49699521833851, 87.22477359156456, 85.40103620098483, 86.22588711400186, 90.1024361579649, 84.70829071537142, 84.57380833164339, 81.06465985698085, 80.11998053519957, 83.79780661675238, 84.76952675850161, 80.7270771457303, 74.22854131267917, 58.65153066573605, 38.616785541657485, 28.33102283939239, 11.625228581889985, 1.184402206732381, 1.782786375091922, 3.7742631906463258, 0.9888774469014138, 0.5491120896993146, 10.523135719760772, 2.603603865831129, 0.23241595365107062, 0.33225962591748087, 5.781403010891331, 64.37180157630675, 96.38870116203063, 91.24747014814808, 73.58713965262137, 59.0450071519421, 65.36947211911603, 60.25817663438859, 44.175160623365834, 46.508715921832675, 67.0473091063961, 57.77532023768271, 87.31258761498236, 76.09656226250434, 106.5815919445407, 20.729702826469175, 0.424354947021892, 0.1518950872724095, 0.21126526197598827, 0.11529312228723881, 0.23529563219316546, 0.2062042400000557, 0.1679454873045606, 0.13775140347500003, 0.24558439219911254, 0.16853031882595632, 0.19040761425370173, 0.25374401000238234, 0.1740585471833906, 0.08363891317839585, 0.12961645370289204, 0.17966920660147745, 0.1998097040960866], [0.03795203024281129, 0.035340907653012586, 0.022125345121528354, 0.1699476887381846, 0.009204474589486998, 0.06847722876456476, 0.07999500830567653, 0.013800453424694078, 0.024757602161938147, 0.05007385479045972, 0.047509540172834555, 0.09199439668126645, 0.015120972586315007, 0.024542046087463538, 0.043768372777248585, 0.05684024594243496, 0.022346430435596455, 0.29713210439489735, 36.305266118818714, 65.74143048255675, 58.40643744314871, 50.83855759712958, 58.272092342376716, 48.04573197518626, 56.13278065958331, 58.317109384844386, 44.697145723527484, 45.98464804310953, 53.46649462176908, 51.57393532414591, 9.326527464774347, 0.10336758478754952, 0.12236566898683388, 0.05268776977074243, 0.1949652245328311, 0.12701677263624248, 0.016755656744804115, 0.954224041873409, 0.4785577514238896, 3.9933800264712307, 1.0172630269681255, 0.8582057683698593, 46.51468576923494, 88.44780783499442, 76.60327757558515, 84.16505029124599, 81.08758218826787, 85.22264680554791, 93.79488483552011, 96.97576230572116, 99.3392413662326, 102.8735871468821, 99.1568511532199, 98.52239993310745, 94.73021322681059, 93.53549849602484, 95.97770737063502, 92.97536834593743, 93.33467314320227, 90.43759484444895, 90.03447717235935, 91.79277373898415, 91.06039662514964, 83.68919618668096, 84.46225612394272, 82.03212030472295, 75.05446695512342, 76.77437136250158, 77.95287101499497, 76.0229472191103, 79.7930980497791, 82.96988056552026, 83.33114654787126, 81.25917803856635, 85.63058114820912, 84.50898724217569, 84.31022505606376, 80.38435612955402, 76.49625178306334, 79.37120791404479, 82.31827289827409, 81.38546266863423, 71.35760168875419, 87.44768188845727, 77.85656898252427, 73.62131918630293, 72.75727595052412, 63.54851568898847, 63.703880771513916, 30.637970739795318, 67.12212439506285, 82.03567397209906, 81.25818960128292, 74.10556716303672, 70.42727824180358, 73.28764315574401, 78.42788573234313, 81.5038319556944, 83.27539397824196, 82.62788126545568, 82.7046577392086, 81.07620731476815, 77.93998210660874, 77.60716115274738, 78.46113958666402, 75.7527586721605, 76.19611986221807, 74.94991225581016, 73.51588587607108, 68.54151248931885, 72.8948413172076, 72.22443765209567, 73.1575224476476, 73.66048797484368, 78.65379856478783, 78.81972266781715, 78.81274869365078, 80.79802497740715, 85.192624984249, 79.7215618625764, 81.6448490081295, 80.6566470669162, 82.55663533364573, 75.56967027725713, 74.22450911614203, 72.9556929680609, 73.70699159560665, 75.99757732883577, 75.94934786519697, 73.89790904137396, 59.70033322611163, 14.364096118557839, 5.9976128801222774, 11.137711309617567, 4.750488909982867, 0.10013555942644035, 1.7306713135011735, 2.1005290025664918, 0.21663319409614612, 0.7704336652832647, 0.7183338641639679, 0.2874660666190809, 0.05109092844049296, 0.15955296345055103, 4.94723892019641, 50.17932091989825, 75.62689765807121, 74.70240285319667, 55.64534379589943, 45.44184300207323, 62.14710773960237, 53.039466181109034, 38.23454664599511, 39.528642469836825, 45.84211303341774, 44.98672646860923, 64.90606369510775, 58.60053200875559, 54.59893780369913, 2.4840458554606286, 0.053732077846483844, 0.10594353245030488, 0.0671388961434845, 0.023097265549304507, 0.02650778173589178, 0.04149204210167931, 0.020462202711872036, 0.0523689967550097, 0.0009201899217347795, 0.027397822686320832, 0.08325187789817011, 0.01172456390885336, 0.03544522201522224, 0.06068116564664149, 0.11940417225442587, 0.026796865014119015, 0.01207377934347718, 0.03700209653846199, 0.04388954873467165, 0.06725446816774146, 0.13967105127390356, 0.08638159221699161, 0.03470893874163589, 0.011626997823646713, 0.013392639924742043, 0.057933882419620795, 0.006885911880676905, 0.051247390407708385, 0.060667743786208095, 0.017014751511235392, 0.02282544797767074, 0.028350127432795785, 0.034855594783420527, 0.5503307823692599, 51.577936141721665, 76.36205965472807, 69.4619829423966, 66.9324307287893, 72.22279810136365, 56.176295434274984, 32.10951459023261, 41.252575151381954, 40.529392073231364, 52.11569701471637, 62.64300515574794, 58.95511427233296, 8.177436272944174, 0.13216098409987267, 0.0671278338338579, 0.2077429735612485, 0.02554682594153189, 0.1228057481949368, 0.04389062891864488, 0.23356078012335688, 0.9290982578550616, 2.3341443894370912, 1.0086843131049987, 2.0557529407162822, 68.41966798228603, 92.05304653413835, 88.37937032022785, 90.3108944431428, 88.56092899076401, 88.79305485756167, 102.0532940280053, 98.52807952511696, 104.32483273167765, 106.52046572777533, 103.16110472525321, 99.31720549060454, 98.15435609509869, 97.77717313458844, 99.82841583990283, 95.52144158271052, 96.39847570850004, 93.34724041723436, 95.75462648945471, 95.39827131455945, 93.06846187960718, 86.29991792863416, 87.88456332299018, 85.00488465832126, 83.28891046585576, 78.91095699802523, 83.74508996163645, 79.43912767594861, 84.5815432456232, 86.99895489600398, 85.77540289971137, 86.5441874534853, 87.05052621902959, 87.14136831222042, 90.54415779729044, 86.00230416943951, 79.55635163091844, 79.69357182902675, 87.52746289776218, 85.56648961959347, 75.87500326095089, 87.7903401467108, 76.99701293822258, 73.53317568379065, 74.75850843614148, 64.07165396598079, 67.77242199067148, 36.49460284940658, 70.0297538695797, 84.0378870502595, 82.52426009024344, 74.12521823760002, 72.83144012574228, 74.35157822024438, 77.02407729241156, 81.87433119743102, 83.54223282106462, 84.24423510028471, 85.74195292688186, 82.89466519509593, 82.66918382337018, 80.49630057427191, 79.59248450494583, 78.31649041944935, 77.37661992349933, 75.17613887786865, 76.84432291215467, 74.3417566053329, 77.90270390049105, 76.97569877870622, 76.84232250336679, 79.5077456197431, 81.9833730882214, 79.85693854670372, 79.91448756187194, 82.04582506610502, 86.97737401531589, 83.76529801276423, 85.61924549841112, 80.55659524856075, 84.13073739697857, 80.09571675331362, 80.77849157394903, 78.87082330642208, 76.34939824381183, 77.44362185078283, 82.31344838296214, 80.85507977393367, 84.48950090715962, 59.198732683735514, 36.002204187454716, 19.486380123323013, 7.777908550154779, 0.6345397185894751, 0.5026288162316046, 0.3560949195056193, 0.9000659770061894, 1.9031515356994446, 0.6961636473574947, 0.2665196599498872, 0.012055445901839244, 0.12309198928696495, 2.732040406234803, 47.08212721732355, 85.16129309131254, 83.58025627751505, 64.69560107877179, 46.3156686290618, 32.22805450039525, 28.18980770726358, 47.513293758515395, 57.41354826957949, 60.218266517885276, 61.04868327417682, 85.11769202447708, 66.25677893238684, 73.19269041861259, 5.646536234886416, 0.0652644245494758, 0.031196052140946832, 0.016101929021158045, 0.02072385812719022, 0.08684820104991237, 0.051635383297839475, 0.019156449894991615, 0.060075098167984724, 0.043936080915192445, 0.021118690267265327, 0.029283101865721327, 0.057327558301509395, 0.027769342770860083, 0.03675882914854634, 0.03365937913317354, 0.04290627871429728, 0.14632198148437087, 0.12707654281609482, 0.14537980058981528, 0.2773931135814036, 0.2373701676486, 0.2009957614204576, 0.17216477783456927, 0.2430159138936189, 0.1354563419496821, 0.11617585475887023, 0.20758819315702687, 0.1516365479197233, 0.15172107806128843, 0.11168985837890257, 0.09856239021305116, 0.24912733434429093, 0.13116462546731197, 1.016132771488159, 69.53129906808176, 96.15157819563343, 90.14265614171183, 77.48861928139964, 82.83338992826401, 73.86872660729193, 87.08623547707835, 85.62113608083418, 64.98612711506506, 69.76729239186933, 72.67010519581457, 75.61899015980383, 15.518541835969495, 0.20354986791649174, 0.27877415560426255, 0.31540995103216946, 0.3038402766950669, 0.2397357552282272, 0.5477071457332181, 5.240781749448469, 5.321334975381052, 13.078755024940738, 5.9933345548568235, 1.2027611054720417, 74.57148198158511, 101.14477895921277, 94.07104322987219, 98.22596288496449, 96.6013014701105, 95.92524174721011, 100.73070218486171, 105.16478476985809, 107.29425522588916, 107.64192627322291, 105.69752108666205, 103.82456579516011, 101.56604151571952, 101.76919675642445, 104.35410145790347, 99.55058651585733, 98.46649831341159, 98.44403882180491, 99.29720140272572, 99.41058143492668, 96.50062991726784, 90.56926881113361, 91.35331922961821, 89.01741443141815, 87.05084000864338, 80.99528881811327, 86.64463150885798, 82.48620525483163, 86.82149902466806, 91.26267325493598, 90.9258593282392, 91.26136318329843, 91.15342740089663, 92.47834128718223, 93.00412716404085, 87.1118720885246, 79.86861936507687, 81.14013410383656, 89.45470379244897, 88.44234789571455, 78.80662195144161, 91.02461676443778, 79.2402478187315, 76.49723237560642, 73.22806235282653, 65.38079600180349, 64.4935284122344, 36.68286877293741, 72.20498269604099, 85.42401344545426, 85.30596579274824, 74.9223066145374, 74.58093489370039, 76.63505661872126, 82.34205815099901, 85.66449396071896, 88.14033323718657, 87.03360511410622, 89.82787024590277, 85.5831910717872, 85.57489133650257, 82.63008563749253, 82.4445261493806, 80.43922224352437, 83.21394612712245, 79.26777501260081, 80.53596358145438, 77.51062377806633, 78.92774474236273, 80.39628797961821, 80.68581381151753, 82.54684509769564, 85.80957458865258, 84.47761612553751, 86.38623360664614, 87.27315995001024, 92.84323153957244, 85.55145125235282, 88.60592642138081, 87.14990338971539, 87.64114103009625, 82.95117870453866, 82.65156453655612, 81.39995974879112, 77.04277130865282, 82.29110656246063, 86.7199488609068, 80.72838721736785, 72.30358323743268, 51.396102905273445, 37.599055997786984, 24.910929818307203, 8.533829200652338, 0.7854641877835797, 4.469333416031254, 2.6576580491758164, 0.3508428658448881, 1.113133353571738, 3.4484316552838976, 0.9676719492962285, 0.36626951708909006, 0.22613827679907123, 7.834075910429801, 60.965603551556995, 93.51351753357919, 97.92230867570447, 76.66444301605225, 64.03357167397776, 86.69965451763522, 77.4606998505131, 53.618078539448405, 54.56733526722078, 67.94082503164968, 63.17784386296427, 87.88843077998008, 78.4320826684275, 85.8975298173966, 6.368539660207688, 0.3130846903208764, 0.23620019817063886, 0.14843342705599724, 0.13776765986075326, 0.18962078066843172, 0.14684603158985415, 0.10523475556363983, 0.24446300801730927, 0.11601139866416493, 0.10072737000882627, 0.10087448187292584, 0.13802351790570444, 0.10203931856179431, 0.17275697912179655, 0.19015053046807168, 0.1337054326769806], [0.03229659681598986, 0.07361257659091104, 0.042527379287827405, 0.03178926657945399, 0.04590124199767748, 0.027175314363933382, 0.06657995073305023, 0.06022812806129937, 0.04572860791438049, 0.06706322197832408, 0.0943533192959524, 0.04329313779430043, 0.04473539790318859, 0.15263649184376965, 0.06401992237736141, 0.026831053602959842, 0.023267722027676723, 0.5813129714900448, 31.882595669838693, 59.1572222402019, 54.83587641869822, 59.85580029026155, 59.15990906376993, 48.477588853528424, 37.34279578731906, 45.60229147634199, 56.11780505026541, 56.63676992539437, 78.85300790109943, 27.259529367569957, 0.5205913104357258, 0.05848350454001658, 0.20024170107658834, 0.1384060102845392, 0.210215215901694, 0.18015548857229371, 0.71274405765918, 0.2375234005552146, 0.6745415204955686, 0.7318645703696436, 0.36185991499693165, 21.587338870571507, 75.85084146068942, 72.58320900701708, 83.37475545944707, 81.02149025086435, 87.12214085363573, 92.74489771935248, 99.21627506133049, 93.26909895866149, 101.06073825590073, 97.80548480249222, 97.03397812381868, 92.57876180833387, 95.53433049109675, 95.0087485774871, 94.04677944798624, 94.76944477327409, 95.23625389222177, 88.40520305018272, 88.12618917034519, 86.31865901331749, 83.60534375713718, 80.26062104009813, 77.85057560090097, 74.91294783930626, 77.70463989626977, 75.98970905427011, 76.7435650671682, 77.64065819401895, 79.6655974849578, 74.82968376528832, 76.01922096744661, 76.69049539873677, 78.15084872707244, 81.08474239226311, 84.93650205673711, 84.1876745223999, 80.00860091178649, 81.92722043683453, 82.60880285693754, 80.08460860098563, 75.64015526925364, 76.28467129122826, 73.41774817435973, 65.18166119052519, 67.24910720702141, 61.75172498149257, 67.98242568969727, 61.58667556701168, 74.02788069940382, 82.2598138932259, 80.31973115859493, 74.12002501949188, 68.15410783213954, 73.36847536025509, 73.33788871765137, 78.5038463531002, 83.43435979658558, 83.8517862750638, 80.39997500758018, 74.9210749903033, 74.45571714831938, 70.94689815275132, 70.55214297386908, 69.46155148167765, 72.23026629417174, 68.95051371666693, 72.97717971186485, 73.01245750919466, 72.55700757426601, 75.27003257505356, 73.02056897071101, 73.9137161931684, 73.70936070719074, 77.23307686467325, 76.72354528980871, 80.66770030606179, 79.36305722882672, 82.16103292280629, 77.34562535439768, 78.52315225908833, 79.21206951141357, 79.68160075526085, 75.07725592582457, 71.11250846616684, 72.36752571598177, 72.81411109432098, 74.63980182524651, 80.12039630643784, 69.71833336737849, 46.97958861627887, 11.455957716511143, 0.9507335614292853, 8.650297118771462, 2.727219568144891, 0.41446398583150684, 3.1971109346035993, 2.1428261264677975, 0.7206009941235666, 0.8839560059770462, 0.45680189625390116, 0.07397644537230653, 0.0394969959292681, 0.15403293223390657, 3.9772362862863853, 45.47754441538165, 72.47726578866282, 72.90893047086655, 49.931540873742875, 43.765461214127086, 36.64280568399737, 32.743271550824566, 32.8684030040618, 33.219804225429414, 45.0559288455594, 46.64685787693147, 72.48312580970027, 59.44359448648269, 61.75136020106655, 2.156749805135112, 0.04404998669821409, 0.05140720400959254, 0.038474670746513916, 0.06321877826966586, 0.05551093017622348, 0.013526349080606334, 0.01606758146907293, 0.0560834851386326, 0.025491698254500667, 0.029647709921963757, 0.01969746884799773, 0.009684097341021464, 0.029191872285258387, 0.052200399955073674, 0.026399146637789188, 0.01594726353012506, 0.06489297915850917, 0.03848236226927369, 0.0238628919056106, 0.05875924639704247, 0.022611763072951187, 0.008320651400173384, 0.03380341515425713, 0.07506905529167383, 0.07606525304577044, 0.1387336507679955, 0.055774104360851555, 0.04689644000703289, 0.042656277411527214, 0.10472850934151681, 0.08854855618049061, 0.07922079218851943, 1.0713897741610006, 43.10693840826712, 74.85779146994315, 62.84625061096684, 65.72200690546345, 64.77142441657283, 47.86429097575527, 31.33823540902907, 47.2288630854699, 67.54137869804137, 65.32286651672857, 87.64413772090789, 26.763106353821296, 0.46457024231072397, 0.04078912961807463, 0.18200146935639844, 0.17234418030467727, 0.6202530368201195, 0.13992461105508192, 0.4516213952052978, 0.570878670100243, 0.8818200302700844, 0.6321364701274903, 0.7786599787012224, 35.35788428398871, 86.20327072758829, 81.61369754422097, 91.16783818890973, 88.8176481185421, 93.20213625507971, 101.38867978126773, 103.73567704231509, 100.06418166622039, 101.50544874129757, 98.95702992716144, 98.79477716261341, 94.63114984573858, 96.78870447220342, 97.41885677460702, 98.28515929560508, 98.63128492909094, 96.6819767798147, 91.59240338110155, 89.65752170931908, 90.37376219226469, 89.01496687243062, 82.55974969556256, 79.59512033770162, 78.87829149923017, 82.57852215920725, 79.0909702547135, 81.2442808766519, 84.77645366422593, 83.05407031889885, 78.56698082339379, 81.77589539558657, 83.51327788445258, 83.94014158556539, 87.28047909275179, 88.77076795024257, 87.99609984121015, 83.66402241491502, 83.5952397315733, 85.96826584108415, 83.71849629186815, 81.94396895747032, 79.76982270517658, 72.68954446238857, 67.86782187800254, 64.85499443546419, 62.445003909449426, 66.16392858566778, 69.16383574085852, 78.13519062534456, 82.6964521408081, 82.66216278076172, 73.09555684366535, 71.65798464129048, 74.92416581799908, 74.32098373290032, 81.44044645370977, 84.46007528612691, 84.29931302224436, 82.05713718168198, 80.40323841956355, 77.88959533937516, 75.98493160740023, 73.0172820245066, 75.29525341526156, 75.32441231512254, 73.05405816724225, 72.39721021344586, 75.8622084894488, 75.74364308388003, 80.87752357605966, 76.77914096463111, 76.5308706222042, 77.67068001531786, 80.37405598548152, 78.01122019367834, 82.72894505531558, 78.72582897063225, 83.3367084687756, 80.51677534657141, 82.18437102533157, 81.32385792270784, 82.07833367009317, 79.73419189453125, 78.50712545456426, 74.70836485585859, 74.46446403380364, 77.01794270546206, 83.77675133366739, 78.98318352237825, 79.50903215715962, 55.32923213897213, 26.98790523313707, 14.26751167543473, 4.677097931984933, 0.539444060094895, 1.132676072659031, 1.810216490299471, 1.6949397469720535, 0.1336131190821048, 0.31811059482635995, 0.05614532375588052, 0.0737805183856718, 0.2073146231592663, 2.0570867917230053, 46.49514059866629, 80.78832103360085, 79.63421852357926, 56.34983678017893, 44.30127659151631, 19.417360136585852, 21.35079053140456, 39.75474749841998, 45.36410946999827, 57.075381125173266, 59.02659162398308, 89.16189101434524, 67.73366112862864, 81.70595169067383, 3.88663272223165, 0.19856317179097285, 0.06938849035049639, 0.010937663290889995, 0.05922698137921192, 0.05315811711273367, 0.06519507827056993, 0.02919796842991585, 0.049636705868667176, 0.061336201465418266, 0.014642049847621352, 0.03696433989511382, 0.03878062711127343, 0.05734855677151392, 0.0872475856674775, 0.07321661638636744, 0.08596359166286646, 0.2408222977312342, 0.09184282618544756, 0.1313155601101537, 0.2644822644370218, 0.19884555179986263, 0.1826648095682744, 0.07828058013992925, 0.21344798436808973, 0.13591175057714985, 0.2947267721737585, 0.21217627841378414, 0.19758260989141083, 0.22856893588698682, 0.28774066317466, 0.1790434200196497, 0.35535270288105936, 2.04296380762131, 65.2139775983749, 91.98989637436406, 83.00893168295585, 82.70755244839577, 84.79743049990746, 70.79628698287472, 53.70456680174797, 65.26541163844448, 85.38992804865684, 77.59085978231123, 101.69110236629363, 40.24978199312764, 1.068670958761246, 0.29851752844068313, 0.38946904963062656, 0.3059385302326372, 0.7502924783095237, 0.35578244756306376, 1.8307157774125378, 2.536691417617183, 1.9515003864803624, 2.3429437366224106, 0.97913084731948, 37.080357843829745, 101.54409193223523, 88.57794423257151, 98.52112124043127, 94.76385147340837, 98.11534420136483, 103.78739741540726, 111.15923327784385, 100.86252520161291, 105.27542698767878, 100.9676839459327, 101.8695858986147, 98.34920375577866, 100.65037988847303, 102.80116450402045, 102.63404015571841, 100.70542643147131, 101.61328254207488, 95.8862376982166, 95.69419060983967, 94.01236457209434, 92.83640661547261, 86.52042573498142, 85.17987728118898, 80.56527937612226, 83.06106782728627, 83.505001683389, 85.79236322833647, 86.88385686566754, 88.52831840515138, 81.68346866484612, 84.21147546460553, 85.31089228968467, 88.36824647841915, 90.0466835883356, 94.00393932096421, 94.29361420293009, 87.84651633231871, 88.91036510467531, 88.77390584638043, 85.30277298342797, 85.69962270798223, 82.06362478194698, 74.2828739843061, 68.28848038950275, 66.42084383195447, 61.9938019014174, 70.13441839525777, 72.30533261452952, 84.4491397180865, 85.2634943685224, 86.17515517819314, 75.14504232714253, 73.16616735150738, 77.3084883536062, 76.72450234813076, 84.28985226538875, 89.6388041588568, 88.63460679208079, 86.16143472733037, 83.93439139089277, 81.13536450170702, 78.47385591076267, 77.87854994496992, 77.6148646877658, 78.59296260341522, 74.9815736278411, 79.83520861594909, 79.94869062977453, 81.47204506781794, 84.54508089250135, 79.40730940911078, 76.98438290626773, 80.76224511669528, 81.33995532989502, 80.96673396325882, 86.65641430885562, 83.8081459845266, 88.91232628976145, 86.6376575346916, 83.49787865915607, 84.49530601501465, 85.10492863193636, 83.78174058852657, 78.49768038718932, 77.63276638523226, 77.1068157688264, 81.9790506362915, 84.67807277556389, 76.97571446818691, 64.52051431901994, 48.18138322522564, 28.79591980288106, 17.939360064844934, 5.09363305184149, 1.9955794921805783, 7.811853722218545, 3.942967763831539, 2.25287189887416, 3.18887077031597, 1.1713105608378689, 0.3086170187640575, 0.21577368941037886, 0.30936131914777143, 5.863464388155169, 62.09221809141098, 91.71667191290086, 91.81569607027116, 68.84379386901855, 64.15777352548415, 50.056601724317, 52.42816871212375, 46.931366997380415, 44.5705904499177, 60.50638421889275, 64.81263283760318, 92.24689791279455, 78.9982375790996, 88.51324865894934, 4.282990924773678, 0.4988835655873822, 0.14595330933169012, 0.13963024943105637, 0.17969500844276723, 0.14715862610647756, 0.13438548892736435, 0.2221158402220857, 0.23880452939098884, 0.1343430629781177, 0.20233128249885576, 0.11371841323712181, 0.08523853540781044, 0.09180093649774791, 0.1641535206187156, 0.13903043322986172], [0.024759697412411054, 0.0570295347772058, 0.08284622668138436, 0.04578956553051549, 0.033683790524880734, 0.09421301029262044, 0.03171582747581265, 0.09595091139236767, 0.03206388994811043, 0.09076784394921796, 0.011168929913471784, 0.08816751170783274, 0.07021705274500194, 0.07280872819284279, 0.06910273955473978, 0.05895271424144026, 0.0872937424649154, 0.4619515699244315, 27.560135895206084, 52.87401668487057, 59.49971183653801, 50.13441370379541, 56.74113635093936, 55.155537820631466, 29.44761572345611, 41.336827662683305, 52.186546787138916, 85.97702841604911, 53.38050450048139, 2.2127565933812052, 0.20145205870991756, 0.0520113371162405, 0.048564113826761325, 0.2405761536811629, 0.21042126290980848, 0.12888605015412455, 0.27360603453651555, 0.047466302170388164, 0.15030977556542044, 0.3948783045334201, 8.495944988343025, 63.71800130413425, 70.97860659322431, 74.21722135236188, 78.93194167844712, 86.3684888039866, 89.18129890195786, 99.54730741439327, 91.17092117186516, 101.1318116034231, 96.89776989721484, 96.4999003564158, 99.23886791352304, 96.91768769294985, 89.01476290918167, 92.41242193406629, 94.08133552920435, 94.72563974318966, 89.180938043902, 89.42837684385239, 87.36856768208166, 84.5255474890432, 81.63996957963514, 75.91665883218089, 73.23944507106658, 78.11747720164638, 77.21504180662095, 74.43132785058792, 73.6717765561996, 77.315289743485, 76.68909119021508, 79.15332809571298, 78.3354825358237, 79.73776125138806, 81.79834704245292, 84.38615429785945, 84.46413886162543, 81.8449055763983, 80.49232329091718, 72.06496977037, 79.96549406359273, 78.78806914052656, 78.47733113073534, 76.81002570736793, 67.24266667519846, 70.18499343625962, 67.3163366317749, 68.54630562566942, 63.656584831976126, 57.162010592799035, 66.37153179414811, 74.93510138603949, 74.37273548495385, 71.68543338775635, 71.45730833853446, 69.24154573871245, 77.6018581082744, 80.45814375723563, 77.24784066600185, 81.08771554885372, 75.91092432698896, 77.65768912530716, 74.61791499968498, 73.70917243342247, 71.3204646879627, 71.09637968001827, 71.93950099329795, 70.30736354089552, 68.90695187353319, 66.23759854224421, 65.32814602698049, 64.40405130386353, 71.08876243714364, 76.46519445603894, 76.2112602110832, 74.52211503059634, 77.68774232556744, 76.74891518008324, 77.83503517027825, 78.48272046735211, 79.83577343725389, 76.75508899073448, 78.6287816878288, 76.61572717851209, 77.15520212727209, 72.40015983581543, 69.52398777008057, 69.47672320950416, 73.2460895661385, 73.41583405771564, 71.93252701913157, 66.12089234013712, 39.70765159976098, 4.223190959422819, 7.467072971405522, 8.598055070446385, 2.1540235127172163, 0.337308359843108, 5.566813570837821, 4.977284275716351, 0.5950809810911456, 0.24077110773613378, 0.16725050766141186, 0.20928490936996477, 0.2958615322507197, 0.07450379731674349, 2.3909814944190364, 45.48328676531392, 73.05350903541812, 65.8012976184968, 42.44289290520453, 51.26206767174506, 56.84408680085213, 50.83902435918009, 37.81655142384191, 39.27238618173907, 38.11702066852201, 37.61272153546734, 56.724811446282175, 62.759613298600726, 37.5427072278915, 0.21995827615741761, 0.03274612954907841, 0.13888731268384766, 0.006373408635432322, 0.04336143453275004, 0.08892412312448987, 0.0615175957641294, 0.02527105918664846, 0.06469771100748932, 0.06402325485983203, 0.020874254593265154, 0.04444333837337552, 0.042791733247858864, 0.1328115612869301, 0.15213128750122365, 0.08608624233954376, 0.04380298079922796, 0.012815595687096639, 0.0349785442343883, 0.021734127001236045, 0.03255210246049589, 0.013987263007419965, 0.10589700026978409, 0.015184757066890599, 0.0694441696208331, 0.026936270033700332, 0.15085259482504862, 0.05499075264519742, 0.08552204922682817, 0.05849313809566441, 0.1664682093166536, 0.18880947823486022, 0.9794345858596987, 43.47262490180231, 67.8596398138231, 76.11659772934453, 58.862864048250266, 61.300668101156916, 46.27485244504867, 32.419701507014615, 50.87086616023895, 61.665628956210234, 98.89373856206095, 56.801948778090946, 1.6722113278604325, 0.2431056993983446, 0.06558692458296014, 0.11454109973724812, 0.046288281108342835, 0.2638640927691614, 0.5452201178958339, 0.2654766772062548, 0.09994482651593224, 0.28330449315328754, 0.5328569296867617, 17.134405374526978, 79.64769578749134, 79.84164914777203, 87.51548397925593, 85.88728458650651, 93.44820222546979, 94.7219919389294, 101.82718507705196, 94.36456203460695, 105.55761798735588, 100.52952381872363, 99.76270045003584, 99.42038736035748, 99.93240571791127, 93.41029644012453, 98.38546214565154, 98.50085043138074, 97.81006613085347, 92.3037644355528, 93.33072723880892, 89.68344073141776, 86.77082200204173, 83.29255827011602, 82.40793828041323, 77.23517925508561, 82.31289925113802, 82.16133886767973, 81.84546255296277, 77.91070553564256, 80.30994092264484, 81.20899523458174, 83.85483003431752, 81.15387808892035, 82.12293101895241, 84.61732310633506, 85.85519959849697, 86.67812855012956, 83.92424029688682, 84.33390048242386, 76.13935532108431, 81.144150610893, 81.07128081783172, 82.0649113193635, 79.37924092815769, 69.164643749114, 70.84810149285101, 69.56579239137712, 70.87433430456346, 70.12525573853524, 69.60591823823991, 70.52136805749709, 78.3138781209146, 78.50480341142224, 70.95557443557247, 72.33134577351233, 72.2560441109442, 79.54338427512877, 81.994198829897, 79.74050691050869, 81.40316824759208, 77.7285663543209, 78.6116252406951, 77.60254060068439, 77.4156867304156, 75.73883425804877, 73.31436234135782, 75.51845196754702, 72.11928675251623, 73.47315557541387, 67.60368947059878, 70.1604001752792, 70.53264094937232, 75.37232798914756, 77.36843785931988, 78.4928794060984, 78.798549713627, 80.96990323835804, 78.62074867371591, 80.22188371227634, 81.48974280203544, 81.26029983643564, 78.45047073979532, 80.37873145072692, 79.7472926109068, 81.86794557879048, 77.12164232807775, 76.02592822044127, 73.99097119608234, 75.00477052504017, 78.02094767170568, 78.49023572860226, 79.88583857013334, 75.90431905561879, 42.493573850201024, 18.005255883739842, 12.356821221690025, 3.7928236011535894, 0.25229869320267634, 2.3456759125955644, 3.396338166729097, 0.7345915369449124, 0.24535957603685318, 0.05981187418764157, 0.17103746413223206, 0.14745156280696392, 0.0641898215267687, 1.2485219273836383, 52.95276611082016, 83.21170253138389, 74.08164854972594, 49.51516166810067, 45.135968731295684, 24.434897245899325, 33.727492286312966, 46.46058843981835, 53.61010436088809, 48.55430649172876, 58.92999933611963, 71.01548471758443, 72.55659180302774, 50.087231512992616, 0.33078502923730885, 0.05094896468724455, 0.1516013078752064, 0.02538096790592517, 0.10898182183624276, 0.010572072726884678, 0.09603671323988708, 0.011804533912049187, 0.04614254437206734, 0.029173488090295466, 0.030220948617845297, 0.031428056123155745, 0.03901279388716625, 0.06417334680595706, 0.07396042647380983, 0.2207855898286066, 0.2203460545429299, 0.25591003167773446, 0.131773573436564, 0.18200105566891933, 0.17294896075562124, 0.13652117352091497, 0.2604119780082857, 0.1220133145069403, 0.15832619621388375, 0.07638311058643364, 0.20371119071158672, 0.17114013523584412, 0.11762225940342873, 0.10562010545043216, 0.35464615531025395, 0.4812959028828529, 1.2951836686941887, 63.556411420145345, 84.97104244847452, 89.77269034231864, 87.20156884962513, 81.01129208841633, 80.98117613023328, 43.91216962568222, 68.70365542750206, 77.22562436134585, 110.6362165943269, 72.51147670130577, 4.464516745459649, 0.357548556020183, 0.27664596335061137, 0.21356265240859604, 0.3019262213380106, 0.4531940204962608, 0.7457023859024049, 0.4555875549633657, 0.2971604190045788, 0.80637703980169, 1.3334640403909068, 16.408598230731105, 95.66822451929893, 81.5250127546249, 93.91125371379238, 92.89083342398368, 95.69831694326093, 97.27268572776549, 106.56665555892452, 96.18796210135184, 107.85984531525644, 103.2688836128481, 101.23559751818257, 102.48692774003553, 105.08383489424183, 97.97500179659937, 101.5543842315674, 103.55354570573377, 102.98577477855068, 94.97313345632246, 96.53882595800586, 94.80190630882018, 92.77963422959851, 88.18336948271721, 86.29011200320336, 79.68048680213191, 87.26078879448676, 85.19185619969522, 82.93764652744417, 81.13618819944321, 84.31792859108218, 85.4871008473058, 86.79412872560563, 85.76766014099123, 85.93706730873355, 88.46029666162308, 90.75555001535724, 90.0623966032459, 87.12860491967972, 88.32066028348862, 79.11270018546813, 85.35188890272572, 85.1409673690796, 84.34821713355281, 81.13672164178665, 71.38254011830976, 74.26660399283134, 73.79190306509696, 67.09379703767839, 68.13408805478004, 68.75155541204637, 77.23806611953243, 78.64189024894469, 79.4880945451798, 72.52442836761475, 74.57489444363502, 72.2057044121527, 82.34900859094436, 85.0381463573825, 84.97689462477162, 88.00727075146091, 80.45347613673057, 84.66308932150565, 80.8982023116081, 79.20547208478375, 78.80116201216175, 75.40022388581308, 79.37842507516184, 74.97626273862778, 77.55464846088041, 72.66781453163394, 72.26595201799947, 74.29678270893713, 78.88369652532762, 81.18516291341474, 82.06264418940391, 82.02220455292733, 84.7046507558515, 82.5468921661377, 85.41226986915835, 86.04239079260057, 86.15168371508199, 83.97421129288213, 84.48479406295284, 82.55792187106225, 84.79995650629844, 78.86447691148328, 76.8616597883163, 74.14930943519839, 78.48619568732478, 80.77793459738456, 80.29873078869235, 75.85403427000969, 63.452170510445875, 37.62963871802054, 23.875161294014227, 13.455069180457825, 4.883178280245874, 1.3191346415588934, 11.743656704502722, 15.2158054613298, 0.800393218955686, 0.7637289863440299, 0.28446217458094325, 0.3739000592500933, 0.5960102150997808, 0.24028245089275224, 4.508941019735029, 65.91166527040544, 92.17230227685745, 84.38325958867227, 59.403186228967485, 69.78848888028052, 80.37339702729257, 77.86194262966033, 53.39675095773513, 56.576267365486395, 56.61307096481324, 58.4205932771006, 77.35590196424916, 84.67070656438028, 56.25373086621685, 0.36546365387978097, 0.11466996338699134, 0.22316153491697005, 0.21037145187297177, 0.22620235239305805, 0.14618787013234633, 0.18638241976018877, 0.17054762751344713, 0.09645913412133533, 0.18040334865931543, 0.17481593234885126, 0.17139190237127966, 0.07685513566097907, 0.1871850654002159, 0.3121820242414552], [0.035899071653764096, 0.06760213418953842, 0.029206314957850886, 0.03901635619601415, 0.02075208655198015, 0.021488714565132416, 0.05593623537870665, 0.11172793294873931, 0.021208339791384437, 0.05748849039176299, 0.026771764143279968, 0.10212281448466164, 0.04923575077085726, 0.06449390863699299, 0.12258004337068527, 0.029766083912803765, 0.09121434297412635, 0.8362970020501845, 33.74990863184775, 58.17847321110388, 58.78689950512302, 54.37716307178621, 49.88407627228768, 43.013080012413766, 37.38952298318186, 53.37151050567628, 65.39682280632758, 56.56531610796529, 9.363004526784344, 0.17562366481269562, 0.06529273149827797, 0.1853698660289088, 0.05870285466493619, 0.1411680023997061, 0.44549744155618454, 0.20301126214044712, 0.08272807294082257, 0.47166755663291104, 0.016907719452114358, 2.1714346687639914, 34.99189576795025, 71.9350294913015, 72.9025762311874, 82.74954534346058, 85.6174490528722, 95.13070291088474, 98.48404699756254, 97.7220481441867, 97.1375051621468, 94.75348857141311, 93.71900266216647, 93.09401219890964, 93.88737432418331, 96.0275528507848, 92.19785259615992, 92.75705706688666, 87.78066758186587, 91.18391206187587, 89.2296068130001, 86.56474851792859, 80.55438303178357, 74.26090086660078, 79.77221535098168, 81.70927001583962, 79.04889891224524, 77.02312023408952, 79.3011308485462, 80.65046541152462, 75.39319499846428, 76.87298759337395, 76.50561055829449, 76.37996919693487, 76.53548332952684, 76.89238763624623, 77.96575207864085, 79.1469346323321, 79.2960709910239, 82.72131212296026, 83.37084877875544, 80.03404924946447, 75.66729022610572, 77.35041849074825, 75.64840009135585, 72.26593632851878, 72.40026181743991, 71.5238944945797, 69.57774777566233, 79.78984248253607, 81.37648044093963, 79.49676298326062, 66.338591729441, 76.19253481588056, 77.77565048586938, 69.12951500185075, 70.59524197732249, 72.16598649178782, 79.13492433486446, 78.99937506644957, 76.77634039232808, 74.87595204384097, 75.97586308756183, 74.44731543141027, 71.88491728998, 69.15561445297735, 68.31963185341128, 66.45310924899194, 65.73405250426262, 67.04359069947274, 67.94093485801451, 71.78284152861565, 73.0127634540681, 66.54353557094451, 65.13268647655364, 67.94870899569604, 67.35104960779991, 73.74393247788953, 72.54611122992732, 76.73388465758293, 79.1489899543024, 76.52381820063438, 77.53400894903368, 79.76528844525738, 78.19790932439989, 77.74042760172199, 78.21768591480871, 74.74911043720861, 69.63533601453229, 71.83158874511719, 69.59872461134388, 77.7601335894677, 74.34835403196274, 70.35569498615881, 57.06856012344361, 23.833497878043886, 5.577900150129873, 7.467595136934712, 7.379762482258582, 0.07545173153161042, 1.0363848267063018, 1.6332534892905144, 0.12485363911236487, 0.17345390462827298, 0.07371160111600354, 0.06720495590519521, 0.132051510135493, 0.015368429519566558, 0.034570675193061756, 2.578271238073226, 41.606427854107274, 73.48060807874127, 72.48893876229563, 49.52623844146729, 45.051484800154164, 39.596389647453066, 26.851477353803574, 31.757517168598792, 45.62785748512515, 47.189376584945194, 48.3203528004308, 55.43550091405069, 64.49654471489691, 13.242424745713512, 0.4604428976533875, 0.02950620199103029, 0.07162216525044172, 0.06181977148498259, 0.031171502853413264, 0.028612259737846833, 0.03405404081868549, 0.04322404049396996, 0.028256632147296786, 0.0676896673957667, 0.033678711361942754, 0.06554541027834339, 0.013455573090111778, 0.05333260512880741, 0.08931871203164901, 0.03193382354032609, 0.0864245620886645, 0.0008183649263247067, 0.049313987500124404, 0.02661770194648735, 0.0719766341330063, 0.04948326611831304, 0.06831615111760556, 0.04485313412583163, 0.09332831663590285, 0.05006233665851816, 0.026542234625066483, 0.023367861210699045, 0.08729925829797022, 0.08216957952226363, 0.10877946737192332, 1.1535052065887759, 49.105242606132265, 70.7662965405372, 79.47232661708709, 75.54761086740803, 55.16688915991015, 33.587989268764375, 38.82950352084252, 64.72487764973795, 77.13337805963333, 64.23504029550861, 7.401809144404627, 0.06200097043127303, 0.10247802647251276, 0.21168072677908406, 0.04136594019890313, 0.25150769209909823, 0.8593811923938414, 1.7500559120408952, 0.23863163866823722, 0.726802506514134, 0.04481842268198248, 5.798774207791975, 55.60667707074074, 85.64058319214853, 84.34802101504418, 89.0519077547135, 91.28841184800672, 103.27129194813391, 102.64317143347957, 99.2961423627792, 98.89581741825228, 97.38666196023264, 96.18960949682422, 94.53666779302782, 95.18527876946234, 96.44301814417686, 95.38832418380245, 95.84603340395036, 92.61791490739392, 96.87993880241149, 94.4431035749374, 88.47364840968963, 82.77827278260263, 81.18969717333394, 84.39162992662, 85.87525075481784, 82.02325574813351, 80.39934742835261, 83.45411285277336, 86.17517086767381, 79.54798913771107, 81.33095741271973, 78.97926115220594, 79.04204260918402, 80.81112569378269, 82.14257424877536, 82.97490904408117, 84.38626412422427, 84.40537391170379, 85.50096250349476, 85.70174863261562, 84.468704500506, 78.91891940947502, 80.64584485946163, 77.44066438367291, 75.96269961326354, 73.730604264044, 77.55240486514184, 76.17773179085025, 81.57471702944848, 84.53534556973366, 83.53308585382278, 68.50068846056539, 76.41961651463663, 78.88075474769839, 71.80923907987534, 72.34068885926278, 75.02720648242583, 80.951828956604, 79.85269454217728, 79.1231886033089, 76.39995759533298, 77.1642549576298, 76.7865385547761, 74.84968785316714, 74.0515169020622, 72.24048014610045, 69.93317727119693, 70.464140676683, 69.95108681340372, 70.0494755468061, 75.98499436532298, 75.43685097848216, 73.47008043719877, 69.18179235150738, 71.67468609348421, 71.56449102586316, 76.35663109440958, 76.47522003419938, 78.89704042865385, 79.35494576731037, 79.61972928816273, 78.67817217303862, 78.7944547591671, 80.29324731519146, 79.21850219849618, 80.646558730833, 79.16292221315446, 74.5623585485643, 77.20876601434524, 72.90620834596696, 80.59959227038969, 77.88033070102816, 77.41167806809949, 78.35868727776312, 67.41330546717491, 32.3007320973181, 16.132556526891648, 9.420226024043176, 0.7915994488904554, 0.6320756733898194, 0.7192376027664831, 0.3286427716093679, 0.06438088002464463, 0.12589751817886868, 0.015282631502486767, 0.20253293216228488, 0.05707451946011955, 0.08835400815211958, 1.9892790625172279, 47.627681839850645, 83.70912182715632, 76.50326498093145, 61.63272811520485, 39.98885023978449, 24.941237972628688, 23.665498841193415, 24.566714379095263, 43.542576451455396, 57.361168938298384, 74.34399235633113, 67.86493501355572, 77.88398635002875, 17.646474722893007, 0.5120971113924058, 0.21228612010036746, 0.04875710669664606, 0.014405602555451615, 0.046481197369435144, 0.06750998913400597, 0.0564173041211982, 0.04519822609220301, 0.041399073501628254, 0.01049420946548062, 0.06146507660648035, 0.037723015918726885, 0.16062495028299673, 0.020628288658636234, 0.17140610564139583, 0.145571215318576, 0.1618954917836574, 0.10512166566425755, 0.146363350232282, 0.08094138736205717, 0.2736217240172048, 0.2363462604942822, 0.13191569806827655, 0.17830144854322558, 0.13141864490124489, 0.18167554490989257, 0.20331746748378202, 0.13125957440464728, 0.23773577544958363, 0.15444665035653501, 0.19602763526622327, 1.9652404491939854, 68.75946291031377, 93.19363255654612, 80.86330890655518, 86.36504496297529, 79.77570626043504, 67.23519063765004, 55.0802557699142, 80.42848279399257, 92.55086591166835, 79.91396196426885, 14.03820207042079, 0.4957640862032291, 0.2581738061722248, 0.46184238707346303, 0.12679516638238586, 0.3428094227227473, 1.493656457431855, 2.1986468472788414, 0.3093186020851135, 1.2917789288105503, 0.1992453577657861, 4.347926743568913, 69.20450287480509, 86.25230035474225, 92.10368433306294, 97.40492451575496, 96.42633238146382, 106.20975909694549, 107.7261003371208, 104.67864621070125, 102.82960168776974, 98.86006109176144, 100.8448588463568, 96.50520340088876, 98.64717052828883, 101.10459819916757, 98.73336069045529, 99.55592878403203, 93.35992536237164, 101.98074586929815, 98.46072458451795, 96.44750533565399, 88.2271666680613, 83.78210144658243, 87.34699464613392, 87.61213902504214, 86.8091514033656, 82.14559447380805, 86.50514418079008, 89.20961841460198, 81.77585617188485, 85.00126823302239, 83.4960037662137, 84.01712202256726, 85.10914910224177, 84.71797112495669, 86.22336895235124, 89.82341443338703, 86.90346087178877, 89.52629489283409, 90.66153080232682, 88.68694689966019, 81.3115652145878, 83.2579315862348, 80.1255581455846, 78.91287111466931, 72.13564303613478, 77.78868059958182, 78.92783103450653, 84.78207834305303, 88.24266787498229, 82.72419898740708, 66.69777101086032, 78.882566882718, 84.33117835752427, 73.68355935619724, 77.81090474897816, 77.01712685246622, 86.07931598540276, 86.71168050458355, 81.42964424625521, 80.75968773134294, 81.55201435089111, 79.15616004697739, 78.15779916701779, 77.83393690663, 75.80212562314927, 73.0458055003997, 73.08841812995173, 74.31107582584505, 75.1068776653659, 81.2623316241849, 80.86431303331929, 73.88925629277384, 72.52439698865338, 74.87933312692951, 77.07266761410621, 80.0142099011329, 80.65249719927388, 80.83476189644107, 85.36182818874236, 84.16465805422875, 84.30939351358722, 85.79497552687123, 85.62412492690548, 83.27103230261034, 84.633483271445, 83.04442128827496, 77.27747809502387, 79.98149733389579, 75.04114658601823, 83.22514841633459, 81.40912240551364, 77.5026221429148, 70.24480173664709, 56.4389608752343, 31.3669510810606, 21.68812809451934, 11.528921646456565, 0.7787512350947626, 2.446973083480712, 3.5214338283385005, 0.35048185457145015, 0.44905650219128984, 0.3606250731935424, 0.1840407647673161, 0.39162289050798266, 0.19139917717585642, 0.17629275068400369, 3.441069611618596, 60.2040518483808, 93.56535557777651, 89.54683242305633, 67.3938818900816, 66.32213346419796, 60.23898055476528, 47.07319990281136, 47.27979113978725, 60.93992771640901, 64.67704042311638, 69.49101632641208, 74.51234048412692, 91.69522439279865, 19.289602656518262, 0.780111623387183, 0.3849706119827686, 0.21776590105747023, 0.14459247670827374, 0.1737012437755062, 0.13115630575245427, 0.1523791016229699, 0.12790393309607623, 0.12709834567841985, 0.1871322666204745, 0.18509177611239497, 0.19086628641572692, 0.15081019951931893, 0.12103913411978753], [0.06432114048830925, 0.0896665619145478, 0.04949288052176276, 0.05521395236193653, 0.04210029293092028, 0.11873039026414195, 0.0667358496256413, 0.02833746399940743, 0.07954358333541502, 0.04401251733783753, 0.03887731506819687, 0.031158008214627064, 0.09096949361264707, 0.06731310453746589, 0.02731630710073777, 0.029294091396995132, 0.2160092920906121, 2.56706036867634, 39.94078551569293, 51.101583896144746, 53.55967052521245, 65.92244394363897, 53.796452245404645, 33.854553545674975, 40.47202740946124, 44.645123327932055, 49.64494112999209, 18.218556334895474, 0.4547188112572317, 0.03237915045071033, 0.18718238409248092, 0.02645485272120324, 0.13207273077099554, 0.16997053348008664, 0.5021338927890024, 0.16777981313005572, 0.33571443730785006, 0.023908596711173177, 0.4446077070409252, 22.471152813203876, 74.07778893747638, 79.72745326257522, 73.31541353656401, 83.09500417401715, 91.577435616524, 95.19451202884798, 94.46536694803547, 98.17686265514743, 92.28755720200078, 94.04841899871828, 94.734433697116, 92.27983797750166, 91.61085421039213, 93.2066862044796, 90.61829059354721, 87.74963378906251, 89.3541342212308, 88.70267560405117, 79.35086650233116, 76.78627967834473, 79.03566483528384, 86.34457803541615, 85.7049806656376, 76.96863851239605, 78.2790788527458, 77.74111009413197, 80.28300992904171, 79.26607270394602, 74.41467346683626, 73.91152751061225, 71.57506573584773, 76.09527572508782, 77.01250630040323, 78.70918243162095, 77.3787772270941, 75.77894441543087, 76.41920074339836, 76.92841068390878, 79.0707072904033, 77.72034506643973, 77.24666395495015, 76.16563520123883, 76.5377426147461, 71.60232620854532, 69.09278592755719, 83.29868501232517, 78.03761774493803, 78.79982840630316, 75.95586684442337, 76.47984058626237, 68.49576196362896, 64.23442056102138, 72.31297339162519, 68.796890166498, 64.37585730706492, 69.91387920994913, 73.27524062125914, 72.37502528775123, 74.4734384167579, 72.1652255519744, 71.20679440036898, 71.985596687563, 71.77018011769941, 69.4117138462682, 68.94958803730627, 67.89647086974114, 68.24549121241417, 69.49118891069966, 67.93034445854926, 67.26481237719136, 71.90441146973642, 74.2905382956228, 71.92758483271446, 69.35444724175238, 66.16675269219184, 65.26083815482356, 69.26174594509986, 71.61905119496008, 75.90960641061106, 75.500377685793, 75.32649901605423, 72.26533228351225, 76.39613720678514, 74.17471854917466, 72.78036302135837, 75.09686777668615, 73.80800831702449, 69.2841975919662, 75.41714499073645, 74.38643240159558, 78.75796102708387, 74.65549915067612, 63.47029186064198, 48.226596386201926, 19.195646201410604, 3.3319965870149675, 9.656420369302074, 3.91973213322701, 0.5548831832505042, 1.2579392930192332, 0.5932635140995826, 0.14471287508645367, 0.13613409993629302, 0.05766040052197153, 0.035165933171106924, 0.16393167687760246, 0.03825131398175032, 0.02508609491821018, 2.9146078613496598, 56.8671581822057, 55.7860117573892, 54.488358343801195, 34.04399225788732, 34.62429123540079, 90.61185790646462, 75.06087610798498, 34.50099937377438, 40.076574048688336, 43.98136808026222, 52.90421109045706, 66.72356451711347, 40.311139629733184, 0.5893806127771255, 0.07597264067660417, 0.11494373256761221, 0.04586540823501926, 0.0684607885177097, 0.007228637114167214, 0.08706577768128726, 0.026220391511977203, 0.05670577835952563, 0.022083127931241068, 0.0668676780356515, 0.019871608294065923, 0.06289036786784569, 0.06821322720497847, 0.06379906305923097, 0.039846672931866306, 0.038269431961159554, 0.05079608801151476, 0.06307509081858782, 0.03917967465015189, 0.04164275840946263, 0.057139993164568186, 0.01974966624871858, 0.012781525841884077, 0.04764915969703467, 0.04990716937989478, 0.04376386051937457, 0.041278564040699316, 0.0314026698845649, 0.0031139491869497204, 0.22283315898910647, 3.966799349554124, 57.97929525375367, 65.98914777078937, 73.94219260061942, 60.77256802589663, 56.980055762875466, 29.471781446087746, 42.17493618688276, 59.38714765733289, 57.435690049202215, 19.62706377429347, 0.2543012163932285, 0.08843451633208221, 0.2593624988390554, 0.03421547469652949, 0.22539872616048784, 0.16878729535927697, 0.42935682701007016, 0.21237034380676287, 0.5464376461121344, 0.2806944622387809, 1.1491237965322312, 38.92521719778738, 93.46440161428144, 91.3327189414732, 84.12271222760602, 89.99487692309965, 99.24068004854264, 96.60735760965656, 100.23582458496095, 102.36482435657133, 93.98015406823929, 97.10082315629529, 100.30630173221712, 95.57630769668087, 93.07523189052459, 95.2478954868932, 94.60716847450503, 90.61933394401305, 92.57438444322156, 92.46157707706575, 82.16625751987581, 83.18783098651518, 85.25124088410409, 91.41343347487911, 86.22067820641303, 80.74018570684618, 84.70638444346767, 84.57965266320014, 84.3436985631143, 81.95661467890586, 81.42761245850595, 78.30885748709403, 75.83981175576487, 79.50883603865101, 83.92637406626056, 82.64819129820793, 82.16391194251277, 80.76591645517658, 79.70704124819848, 79.85810741301506, 79.57677933477586, 81.25995466786047, 81.40861249739125, 78.30065188869354, 79.21673713191863, 72.73920951351043, 71.8394805539039, 87.15213129597326, 81.28304958343506, 81.0773761810795, 80.54131369436942, 81.55792928511097, 72.15815744092389, 64.052014658528, 72.5093037082303, 68.96534812065863, 67.16636873060658, 72.00518500420355, 75.26239179795789, 76.84160078725508, 77.84882622380411, 75.26645537345641, 74.90424802226406, 73.83542568452897, 73.35408810646304, 71.83669567108154, 71.18784150769635, 71.4127423686366, 72.42180347442627, 72.96570285674065, 73.1426880436559, 73.00923332091301, 72.53644650982272, 77.15309189211938, 76.83730186954622, 75.02942654394334, 71.00007764754757, 68.50076690796884, 71.17642741049491, 75.3015370522776, 75.79949763513382, 78.42144520052018, 77.69138228508734, 74.9857234954834, 79.97977933576031, 76.67015398702314, 76.34733507710119, 78.28409164182602, 77.7808907724196, 74.8922691037578, 77.18382758478965, 75.4964239366593, 79.29716925467216, 80.38896883687666, 74.8404545937815, 75.6890436910814, 63.38969107597106, 30.371930099302727, 15.627915167039442, 6.3471220481780275, 0.36505563545130915, 0.2838875779942159, 0.28466442179295326, 0.10945576979147811, 0.08506703130420178, 0.08449556035620552, 0.022756457929649664, 0.07273825576468822, 0.03493291603761815, 0.032774264128097606, 3.555889398820939, 65.50857897727721, 61.99099740674419, 59.31034764935894, 42.183341826162035, 23.337247448582804, 51.36908169715635, 59.298192224194935, 50.40663403849448, 48.70385469928865, 50.15552782243299, 70.23974187912481, 76.09167498926963, 53.40623132644161, 0.9094739657255911, 0.08661259070879991, 0.03288877895101905, 0.11790235647030416, 0.05020700470213929, 0.009262750897887013, 0.13103555497382918, 0.024799708269476414, 0.06388374258794131, 0.07050143990425334, 0.07758599886250112, 0.06882304085358497, 0.0300351397374705, 0.012342860066001455, 0.15511322345945144, 0.19435540322334538, 0.08700144927828543, 0.2390493404480719, 0.21388402629283168, 0.18629744528762757, 0.16427846955916575, 0.13331002405574247, 0.20190228858301718, 0.14073340072026178, 0.13010803700214432, 0.16256447040265606, 0.22838769480586055, 0.1221376429161718, 0.1850180784540792, 0.142483007643492, 0.37446062110604783, 5.361521128685244, 79.14439293646043, 79.68817464766964, 81.1243740204842, 88.32727339959915, 89.17732161860313, 55.14330394806401, 64.59664360169442, 76.20991091574393, 72.47639502248457, 29.695380080130796, 1.4144482367461728, 0.15892990414173375, 0.4707037567371323, 0.15205929055809975, 0.5650276582567924, 0.3221422704237123, 1.6226448262891464, 1.2635691199571857, 0.7732244929479015, 0.4484112722979438, 0.565054501977659, 49.60377585503363, 92.11603979910575, 89.6272567010695, 89.22752795680877, 92.15242370482414, 104.30478157535677, 100.4791292067497, 105.4995825982863, 104.70538108579575, 96.20897031599476, 98.51191936000701, 103.11377740675404, 101.40440848565872, 95.85559614243047, 100.03652895650556, 97.97571566797073, 93.91701175320534, 97.95020457236998, 98.41947693978587, 87.80697884098177, 84.18365017060312, 86.89015619216427, 95.52200640401533, 90.90767522012034, 82.78632148619621, 87.12521599185082, 85.61492304648124, 88.11435145716514, 86.58068903030889, 85.16222661541354, 81.33756268408992, 79.41413433321061, 81.59700393676758, 85.14248140396612, 87.12152111914851, 86.72404381536668, 83.70925518774217, 84.2507383900304, 84.22075579243322, 84.09426719911637, 85.82026696974232, 86.48308477094098, 81.92522002804665, 81.06573458640807, 75.11694246722807, 72.66280174255371, 88.32229983422064, 84.26102284462222, 84.4901990890503, 83.87116278371504, 84.44028300623741, 72.19680847660189, 66.04271165786251, 77.24362804043677, 71.41477415638586, 69.07315054247456, 75.15097295084308, 78.67765442017587, 78.2545405049478, 83.09863628879671, 78.99154601558563, 78.46941578772761, 77.41967970325102, 79.43125155664261, 75.8133279123614, 74.49599204524871, 76.0805433027206, 75.55703240056192, 75.9604952412267, 75.82829567693895, 75.1218532746838, 78.94195941186722, 81.47799922573952, 80.75821292015814, 77.33447797836797, 72.13998902228572, 71.37511899394374, 76.69144461231848, 78.42665410810902, 80.61592501978721, 82.87530437592538, 82.02998653534921, 78.78806129578622, 85.15451523565477, 80.48751446508592, 80.1698495495704, 81.76260640544277, 79.64269084315147, 78.0655607100456, 79.64629157896965, 79.9889341477425, 79.64975110946163, 80.38808238121771, 73.49441482174781, 65.51149329831524, 54.49746216497114, 31.37915945822193, 20.20919449867741, 7.530475143463382, 2.033269669740431, 2.89295147503576, 1.672575740564254, 0.4912297037099639, 0.3875476704730142, 0.18053344571061675, 0.126308141306283, 0.5068929229051836, 0.07443871048669662, 0.09327904952149238, 6.428870616420624, 80.61431684801656, 73.89572035881781, 69.9015002096853, 49.54924314252792, 43.623090943982525, 111.92415821936824, 93.46884958205685, 52.32728142892161, 58.45150939879879, 65.14856030864101, 73.80625109518729, 87.69851746097689, 60.5508795861275, 0.8604014376478811, 0.20948208507991609, 0.13185557548797902, 0.23087984011057885, 0.15871037398615193, 0.034104234899484345, 0.28976365623454897, 0.09679290330818585, 0.16166931198489282, 0.20163573595064305, 0.15688094070121167, 0.08584787408190389, 0.194824815938069, 0.1684747621296875], [0.03617861713733404, 0.07294973433618585, 0.009037018302948245, 0.14734697648354117, 0.025088347216707566, 0.02841011786292638, 0.016468791291117668, 0.04457114865222285, 0.05952736062388267, 0.06867201428019232, 0.032887219962093144, 0.0535259465686977, 0.02862243530070109, 0.02700535967315157, 0.07400590145299513, 0.07131870250187575, 0.0471151810920527, 21.671612954908802, 53.23453349451865, 58.01826400141562, 42.99859077699723, 91.35270733987132, 96.08151681961553, 28.34481389291825, 39.02684973132226, 42.47408751518496, 22.49582059921757, 4.533128805698888, 0.049683598110512386, 0.17241326611368887, 0.04610804743283699, 0.09823838864723522, 0.06986852104385054, 0.20663168641828722, 0.6001151593462114, 2.6406268727394844, 0.5782361172379986, 0.1858948507616597, 10.729349428607572, 70.95251498683807, 95.98967844440092, 88.25463110400786, 88.76269571242794, 89.0839848979827, 97.28239751631214, 96.0678199029738, 94.89723559348815, 93.64024931384672, 90.13951824557397, 91.38669859978461, 90.62432319887223, 91.05570547042355, 90.8868552792457, 91.45235123172884, 93.8325866576164, 90.73102735703992, 80.3671290797572, 76.74574590498402, 81.28304173869472, 84.93922418163669, 86.71943110804405, 83.56539833930232, 80.60064346559587, 83.22899233910346, 85.19484504576653, 81.16796724257931, 78.46805080290764, 76.5714906877087, 74.00240882750481, 76.37598406883978, 75.0028250294347, 77.60854182704803, 71.68133843329646, 73.73709970904936, 74.26302679123418, 73.24538353950747, 74.41242202635735, 73.32845149501678, 75.79422596962222, 77.8947336443009, 79.19623098065777, 75.95597667078819, 75.05557306351201, 70.45693136030629, 77.57255015834686, 75.56450843811035, 72.91654771374118, 75.75584949985628, 75.50150732840262, 77.74943336363762, 75.89119480502221, 63.898371496508204, 66.37091205966088, 68.8323405481154, 68.98816062558082, 69.094511770433, 70.9161546153407, 74.18697203359297, 73.74522686004639, 70.98591004648517, 70.0130916410877, 69.23945903778076, 65.29271525721397, 65.9820169018161, 67.77858795658236, 70.42593679120465, 68.65215470713954, 70.00929478676089, 71.95774001459922, 72.6536233963505, 71.58342038431476, 72.05367334427373, 73.48751145024454, 72.63729849169331, 72.25571463184973, 68.95900957046017, 64.68369276292863, 64.49809405111498, 71.14016902062201, 73.86988762886294, 78.70344008168867, 74.59885228064753, 74.76421156237203, 76.3404473950786, 74.03541165013468, 71.52234123599145, 75.37200635479343, 74.87653255462646, 71.73233709027691, 69.99238152657786, 75.23440960914859, 76.73016625065958, 71.14380113540157, 57.254735423672585, 40.84339349500595, 18.92345332330273, 2.848725280454082, 9.72964709804904, 0.45409417380729034, 0.5395017924808687, 0.7312137020691749, 0.20349536842155844, 0.14836452510808745, 0.02453885724647872, 0.11929291330518262, 0.15169978081699342, 0.04606142332176528, 0.21607022672410936, 0.7044145368760633, 1.654758986926848, 60.181580589663604, 54.91231949098649, 43.64099656381915, 58.83887875464655, 78.2065071598176, 25.392898897970877, 31.339855347910238, 41.338412300232925, 55.8651416532455, 48.43548613209879, 55.202516048185295, 61.0255922809724, 4.331656261797875, 0.18253645919744046, 0.11591287209622322, 0.05600208063579856, 0.03237403681381576, 0.01298246974681294, 0.11648735376976191, 0.03813197280490591, 0.047744307817230304, 0.04637592156688052, 0.014435117050344426, 0.033648140623324344, 0.01647652111827366, 0.014136308285918449, 0.07320530892860505, 0.03970741729943022, 0.053315494555018605, 0.06198374494429558, 0.071652211218832, 0.031699952218801744, 0.11617546405402884, 0.04171044610801243, 0.053641487949437676, 0.1704511770437802, 0.04668302706352646, 0.10036232911290661, 0.025792799537040056, 0.043753131457995025, 0.05272898913150834, 0.06559786431851887, 0.0438930650782441, 32.43947025268309, 66.4779378521827, 74.21336958485266, 57.064418100541644, 118.20899548069124, 100.77032596834245, 24.222673485355994, 48.32447128911173, 54.40336842690745, 26.050968670075942, 3.719937383167206, 0.07226106725753316, 0.2123669117328621, 0.215672412586789, 0.16642906222372286, 0.0920712199783133, 0.3650491083821943, 0.6071889700908816, 2.5067149487233933, 0.3955249746720637, 0.3500707411477643, 20.559954412521858, 97.00609791663386, 96.75133997394194, 93.98058552895823, 93.79303347679877, 96.05318161749072, 99.59058684687461, 99.26757181844404, 97.25761598156345, 96.20320443184146, 94.7499898172194, 96.36509633833363, 92.57173292098507, 92.55811445174679, 93.58470855220672, 94.51038791287331, 94.86854737804782, 91.57224239841585, 81.9791369284353, 82.43508108200567, 87.43257291855352, 90.7091248419977, 92.11544359883955, 85.93767135374009, 84.29746166352304, 88.41095324485534, 90.35601738960513, 85.10988650783416, 80.54393383764452, 81.19157991101666, 79.84864665615945, 81.88529029969247, 81.0614513581799, 79.25571764669111, 75.20459175109863, 77.11215019226074, 78.03498191218223, 77.20957402260073, 79.45331881123205, 80.31140788908928, 80.74646934386223, 80.47508839638003, 83.73227165591332, 79.74178560318487, 78.12365885703795, 72.95209223224272, 80.45244063100508, 80.36189663794734, 77.40352738288142, 80.0741986305483, 80.1378979221467, 78.30175015234178, 77.69917211224957, 64.94596204450055, 69.63342189788818, 72.6289124642649, 74.14398285650438, 72.43556314899077, 75.78536141303279, 75.2696874064784, 76.68142687889838, 75.2143741423084, 74.24681955768217, 71.89787680102934, 68.04402259088332, 70.75897739779565, 71.09104525658393, 72.65139549009263, 73.38651826304775, 73.24863910675049, 74.17160418725784, 75.63938648469987, 75.6519223797706, 74.788498878479, 76.69518655346286, 77.24214538451164, 77.28373035307854, 73.20238651767855, 70.45091444446196, 67.86036937467514, 73.68788180812713, 75.92162455281904, 78.16791888206237, 76.45055617055586, 76.82656242001441, 79.32679099421348, 76.49620471462127, 72.57912974203788, 78.0486317603819, 77.91611840648036, 75.37298694733651, 74.22490135315927, 76.47257635670324, 80.21900469256987, 77.13790447481217, 75.39466980964907, 69.459715812437, 61.35229041499477, 28.83335098143547, 13.2821544331889, 1.7359503334568394, 0.42982594861138257, 0.479646546225394, 0.12155500240623952, 0.124681813251828, 0.02930362344599299, 0.1853139416104363, 0.07723784254443261, 0.29550030647266295, 0.21045402082945072, 1.106798358021244, 2.1821736279995214, 71.7082223584575, 60.4830421939973, 49.95361989544284, 57.626395686980224, 65.71304821198987, 24.125120216800322, 31.902470319501816, 41.14167013475972, 59.34471937917895, 60.912953576734, 62.78035479207193, 74.32299198642855, 5.6730627340655175, 0.27527344022547046, 0.0942500506437594, 0.0891718989418399, 0.01046890079329211, 0.014514318092786258, 0.04333178309964077, 0.057554044535443674, 0.027060301583861152, 0.02642253147167785, 0.03786357773107387, 0.038479665639780225, 0.00844312874945782, 0.05187937847128318, 0.27207324581761516, 0.32177329183586184, 0.11644822199858966, 0.20779436273920923, 0.14365971869518682, 0.22324416516048295, 0.3918281101411389, 0.0857887780594249, 0.16020075207756412, 0.2754413054114388, 0.18376491182754118, 0.18375207219393025, 0.19026918216578423, 0.1684962738786013, 0.09055966721667398, 0.19214050513842415, 0.1711543538277188, 36.943620097252634, 82.82246220496394, 82.96049825606808, 69.04712169401108, 119.94036105371292, 106.65202986809516, 38.10432395627422, 62.358272460199174, 70.71660795519429, 38.28064626263034, 7.062301529992012, 0.19397378418474429, 0.4260626795791811, 0.5884446984817905, 0.32049996177515677, 0.5295459589650554, 0.7408031616960803, 5.343577265739442, 10.405653868952106, 1.8570444420460734, 0.33037287393404596, 25.690530307831306, 102.35020176056894, 96.90886236006214, 104.3203769191619, 99.92897756638067, 102.10295123438682, 105.36561796742102, 104.69242941948676, 98.1267818327873, 100.56983009461435, 97.69008867202267, 100.63827545412126, 96.09628846568447, 96.25468161798294, 95.81513297173285, 96.67989792362337, 100.66399051297097, 98.7161022616971, 88.06014430138373, 85.84453859636861, 90.526962126455, 93.84871544376497, 94.57207110620315, 91.06324426589474, 89.5416078259868, 91.69772686496859, 91.58941453503024, 87.1741436373803, 82.2731028833697, 83.48792368365874, 83.08335473460536, 83.74116759146415, 81.95086448423325, 83.59044659522273, 77.90210770022485, 81.18087968518658, 81.80341474471554, 81.56137312612226, 82.41738334778817, 81.55465018364691, 85.11262432221444, 82.61950308276762, 86.03186315105808, 79.83494973951771, 83.11840503446518, 77.2326454039543, 81.38034005318919, 82.39356671610187, 78.7604791887345, 83.17953125123056, 79.91343636666575, 80.78723061469294, 77.8464884911814, 64.71465987543907, 72.37548028269123, 76.77229250631025, 76.38729618441674, 75.58919583597492, 79.47695501389043, 80.24497078311059, 81.65120324780865, 78.13749697900589, 77.55700972772415, 76.07011764280259, 70.72979496371362, 73.21916641727572, 76.52461836414953, 79.815471249242, 77.39930691257601, 75.59886840081985, 77.54532890935099, 79.44601535797119, 78.44293978906448, 78.40020164366692, 80.3930010334138, 79.53294292573007, 80.29716184062343, 74.55948737359817, 74.01580764401344, 70.53573962180846, 77.33063405559909, 79.62720532571116, 84.0776441943261, 80.79265917501142, 83.2694947335028, 83.87272388704362, 79.64502073103382, 76.92979920294978, 82.46342412887081, 79.45120857607934, 78.00531310419883, 76.51263160090294, 79.87833115362352, 84.2861887716478, 77.06017878747757, 71.03750490373181, 57.87812555989912, 52.07811286372524, 29.2115576805607, 15.965713608649471, 1.4398199656317312, 1.8661806227699405, 4.268699769050845, 0.4697936136395701, 0.2553742451052512, 0.17807126976549628, 0.5470500874423212, 0.3489472578850485, 0.3925029110283621, 0.5180894511361276, 1.619154161983921, 7.240509025512203, 85.87032425788142, 72.43705364965624, 61.77504347216699, 82.67711485585859, 99.66822624206544, 36.90322360684795, 39.99394539863833, 55.45616003774828, 75.33866620832875, 69.72922186697684, 75.37316737636444, 85.95717337823685, 6.3987281822389175, 0.5595813246984636, 0.2577527029620063, 0.1984523954771219, 0.11314111236002176, 0.13022953854693523, 0.2336129047457249, 0.11452506551699293, 0.15589889259107653, 0.18004661215649498, 0.10332832278143014, 0.14104133742230554, 0.1296893239862496, 0.1359215105373052], [0.01466898837186877, 0.06225836831295203, 0.0047019919973888226, 0.047231978856988495, 0.038180378070401574, 0.01566303629172786, 0.051395092159509666, 0.17977599925812215, 0.04353223000502875, 0.09713475472263752, 0.04747166095541851, 0.10756723282317962, 0.03719158072565352, 0.047152991361555555, 0.08766079051119667, 0.018055809458958048, 0.9016177647056118, 42.55471575644709, 58.111628178627264, 54.67752249010148, 57.67267965501355, 37.99479569158247, 36.96124330643685, 33.11023673703594, 45.05068071426884, 26.840431959398334, 9.291827236452411, 0.059308975769747654, 0.0643888703216949, 0.0910300298804237, 0.14845910632321913, 0.14632869241458757, 0.06851788505070633, 0.3427111183203036, 0.32381917560292833, 0.2414708064808961, 0.07164009170786989, 2.8998514144651355, 62.187798407769975, 100.93145693502119, 77.94969389515539, 81.17036773312478, 93.6451130528604, 95.13179332979264, 94.22580426739108, 95.16072473218365, 91.63241155685918, 90.93423751092728, 94.42552351182508, 90.34497983994024, 90.6351960089899, 85.70732624300065, 89.10652283699282, 87.54863585195234, 88.29169750213624, 78.3336704008041, 79.97555102071455, 87.99181661298199, 90.58112221379434, 86.44430821941745, 83.5722860213249, 87.57378608949723, 85.89840058357485, 86.0204412091163, 86.82622940309587, 81.50562840123331, 79.0870871082429, 75.60730934143066, 77.13515881569155, 80.2629509279805, 74.64619528862738, 72.28478723956694, 73.6345140395626, 72.42720065578338, 74.05516470632246, 72.86820057899722, 72.42971881743401, 72.81802561975294, 77.62797324888169, 76.22876182679208, 79.29975017424553, 78.21566197179979, 69.93657404376616, 71.12444031623103, 74.94609971200266, 75.02506486831173, 77.3363842502717, 79.30566510846539, 72.72487717290079, 75.6715734543339, 75.32624013962285, 68.51466778785952, 67.45368234572872, 68.51718594951015, 72.14166779671946, 71.55262193372174, 71.18564498039984, 70.68829628729051, 69.06942429081087, 70.17085721415859, 70.84182570057531, 72.15822019884664, 69.98791786932176, 67.92616321194556, 64.64925043044552, 66.78207059060374, 68.04261838236164, 72.49606178652856, 69.44344582096224, 74.30338013556697, 71.96548277331938, 73.73813521477484, 72.0771526521252, 73.99421107384467, 71.58973540029218, 71.44849085038709, 73.82801240490329, 64.45337903115058, 66.09240024320542, 68.16426677088585, 72.55223797213647, 71.90894572965561, 76.200010853429, 73.24772127213018, 73.37553562656527, 73.30778060420867, 72.16824577700707, 75.86490708012735, 71.81971180823543, 70.70299733069636, 66.82572657062163, 75.27883437372024, 70.57361402819234, 69.7104964717742, 46.45850566125686, 39.67731991121846, 17.038883893720566, 6.093677118901284, 6.544418738734338, 0.13858378864824772, 0.13847820641052339, 0.11590808404669647, 0.08100288123973916, 0.07319533446383092, 0.10144472708024325, 0.15979316265832993, 0.06878089069599105, 1.431905235494337, 0.13179022818803787, 0.312925344032626, 4.433252513408661, 70.1479741065733, 47.54122495651246, 21.485861270658432, 20.383345773143155, 63.67398838843069, 55.368695105275805, 40.49303562410417, 31.673886352969756, 53.93417842926518, 52.48561182329732, 62.95650451414047, 4.920353033850271, 0.1279223804932929, 0.04638238734896145, 0.08329346115070005, 0.05964003683578584, 0.06686193237621939, 0.04838849200055965, 0.044275951992359855, 0.014566021366795946, 0.048872663399144534, 0.04151257708848965, 0.042611760042247274, 0.04341630558032663, 0.037097551093827334, 0.04176613303922838, 0.01512382051817352, 0.07032232088667732, 0.02446824500727798, 0.0542729972080598, 0.02696917925570761, 0.07558963501886015, 0.05299418961869613, 0.11100587209746723, 0.06447530036131222, 0.010950358325405227, 0.15027635881016332, 0.1303642627692992, 0.06092924406872161, 0.03030530255918782, 0.060591985351376, 1.2472516923181474, 56.12410045439198, 68.61981868743896, 74.52773186468309, 74.21758221041772, 68.28092590455087, 40.77801542897379, 29.327718673213838, 56.0357294544097, 32.74976503464484, 8.419468575908292, 0.08547577751620163, 0.0367092632598454, 0.059065585805764126, 0.12204098560276533, 0.0599637741012679, 0.12423918297093724, 0.3469200360198175, 0.2052754043571411, 0.596939571682484, 0.05768559332336149, 7.705855590681876, 93.59904089281636, 104.05003932214554, 85.01007003168907, 87.92011568623205, 100.3310126643027, 96.93838996271934, 96.96832549187445, 97.39622469871276, 93.66274802915513, 94.24179184821345, 96.72487966475948, 94.3871235078381, 94.63391903908023, 90.87708857751663, 93.98157396624165, 90.90999726326235, 89.59678772957095, 79.95039293842932, 83.46219293532833, 90.17019902506183, 94.27556345539709, 89.35524032961938, 87.34682206184634, 91.00903711011334, 89.54388280068675, 88.84770131880238, 89.43095776342577, 85.143093293713, 84.28738117218018, 80.66001246052404, 82.69413794240644, 85.2969051176502, 77.21528499357163, 77.04853719280612, 78.86997607446487, 77.89256065122544, 76.4899524565666, 76.70513368421986, 77.64211731572306, 76.7431414511896, 79.39677392282795, 78.36584952569778, 80.12001191416095, 77.31020635174167, 70.55404140103248, 76.06111188088694, 75.08322577322684, 79.52255648951378, 82.36757709134011, 81.4251256758167, 77.3572826385498, 78.72826084013909, 77.05699382289764, 69.98590961579355, 71.26976413111534, 72.87054615636026, 74.47822370836812, 74.96832386139901, 74.77353111390146, 72.61965567065825, 73.74130448987408, 73.33086767504292, 73.86073281688076, 75.16938455643194, 72.35897494900611, 71.08294163980793, 69.59863831920009, 71.85532692940005, 70.85650320976012, 75.15518557640814, 74.37180196085285, 76.3535402667138, 72.19299593279439, 77.46575970803538, 75.187254874937, 76.87374068844703, 74.51175212860107, 74.98525281106272, 76.2471342086792, 69.48640361908944, 68.76624861071187, 72.6352039460213, 73.04802556191721, 74.11367077981272, 76.89903213131812, 75.95934990913638, 74.6415590470837, 75.10413200624528, 75.08797968587568, 77.43940922521776, 78.38375122316423, 74.49238346469018, 70.53491592407227, 75.62862350094703, 75.47226998113817, 79.38043332869007, 69.4772409623669, 65.30521192858296, 51.53754749605733, 22.787897932913996, 8.828929701159078, 0.23417383432388308, 0.04530121512230366, 0.17488351662553128, 0.009248116703313446, 0.06345724611873589, 0.02771055892921023, 0.022880502886349158, 0.060133531524409214, 2.185582903123671, 0.39405797758410055, 0.39626942827336253, 5.555043518543244, 75.08998009466356, 52.03347629116428, 26.5182053273724, 26.24904248022264, 62.98702447645126, 53.608664851034845, 49.36917497265724, 40.579006133540986, 60.57780665736045, 60.17356326503139, 71.95930111792781, 5.8815195483546105, 0.12006279336468828, 0.03955527223766812, 0.05667201686470259, 0.048528927408399126, 0.0443900186538456, 0.07915655571606853, 0.05553997639987258, 0.045801627584883285, 0.02787061576401034, 0.021283655810440262, 0.0325135720683442, 0.024763667663078637, 0.03317407392446072, 0.09369955518312993, 0.12396120030673281, 0.16355103843154448, 0.11842511188719543, 0.16796686115764803, 0.15070763566801626, 0.14541366167606848, 0.2729481182271435, 0.18467113255493103, 0.13864254759204003, 0.08645729702566901, 0.3129318711017409, 0.29150328869300507, 0.23552260872337127, 0.1464105259266592, 0.20638270784289608, 2.1001732926214896, 69.39686375279581, 80.80135899205362, 84.19842181667205, 82.10910858646517, 50.85199563733993, 49.31781937999111, 50.061398783037745, 71.13091222701534, 49.628267134389574, 13.32474450911245, 0.6819806632495696, 0.3094734744198861, 0.3296593089978541, 0.39667327918352624, 0.7193819337314176, 0.28912250192896016, 2.1630895810742534, 1.319177542482653, 1.6596963929553188, 0.19628522466988335, 9.015557054550417, 98.11310060562627, 103.13427571327456, 95.66633393687587, 92.20124936872914, 103.66250130438037, 102.47144222259523, 103.8369526401643, 100.18681064728769, 96.0797909767397, 95.94412403721964, 100.46907224962789, 98.30656759200558, 101.2286941466793, 93.81870931194675, 94.86704118790166, 93.10523017760246, 94.96084859294277, 85.04165295631655, 86.73531670724192, 94.13091428818242, 98.09261014384609, 94.05962913267075, 91.5663117747153, 93.51208979083647, 91.10924582327567, 92.2764882733745, 93.58568130000945, 87.73364620824015, 86.46246879331528, 82.53247353338426, 83.85372392592892, 87.67569711131435, 81.06953144073486, 79.32453170899423, 80.9421250127977, 80.27194884515579, 79.1130296645626, 79.2086805835847, 80.43775527707993, 80.93190331612864, 84.44426813433248, 83.94181251525879, 85.56108459349602, 83.98219723855296, 75.7765047011837, 76.5381819202054, 76.78810750284504, 80.60494238330473, 83.22712529090144, 84.48848893565517, 78.39125863967404, 82.86703601960214, 81.413068309907, 70.44341487269249, 73.36288990512972, 76.13144782281692, 77.91469850847798, 77.2497469379056, 79.76476284765428, 77.08045744126844, 75.95823595600744, 78.46453635923325, 78.38387673900974, 79.28047564721878, 74.85534391095563, 72.7854464131017, 72.79611525997039, 75.84451075523131, 73.76996132635301, 80.24584154928885, 75.54260592306815, 80.60998655134632, 75.17649189118417, 79.04475688934326, 78.1527393094955, 80.43086759505734, 78.27786291799238, 78.69572085718956, 80.334824439018, 71.11391267468854, 73.50622115596649, 76.01706366385184, 76.0274814790295, 78.15964268099877, 82.5636955999559, 80.23065413198164, 80.87277750815116, 76.85431711135372, 77.64139559961136, 81.47110369897659, 79.1861661787956, 75.51267039391303, 71.8611006582937, 78.61268428064163, 78.25596824769052, 77.11188347108903, 62.714192252005304, 55.11369005326302, 45.52842540125693, 27.976652383804325, 10.397637524912435, 0.5042459359092097, 1.012729073484098, 0.40514912276018056, 0.15993850485932443, 0.19253274215565575, 0.23462518268535215, 0.47647852751035846, 0.22935796048372026, 3.9780867051693702, 1.431234510194871, 0.9343881869027693, 8.529439087836973, 89.3196330531951, 61.85186701436197, 33.79098761466242, 33.5947161336099, 87.98140664254466, 79.29309783443328, 57.38520522271433, 46.812024962517526, 78.27153221253427, 71.94743202578637, 84.38409897588915, 7.759169426656539, 0.41084648800953744, 0.0901822003746225, 0.15799455675146273, 0.13155306268843914, 0.13033337410419218, 0.1553035196998427, 0.09730825065484933, 0.2032305011826177, 0.11431466712946854, 0.08504244754271162, 0.1444163224509647, 0.14331133255074102, 0.11631742014639801], [0.038329056584306305, 0.05202190912959557, 0.028747001197189096, 0.020706134683061993, 0.00903380839454551, 0.09812611846193191, 0.0288076198194176, 0.027727539268051906, 0.019714533456511075, 0.004434390303363363, 0.03397763120911775, 0.11764031609580403, 0.03178899844868049, 0.028472467843863754, 0.03987607538640019, 0.0710995247467391, 0.40424477128732594, 32.8933375112472, 60.773042632687485, 53.621396864614184, 50.780353546142585, 41.643702137854795, 29.825781237694528, 51.48507795026226, 30.53443977909704, 9.51943943577428, 0.48937619994244275, 0.015973188903092617, 0.18335883926239707, 0.09634982103541975, 0.11105419692373085, 0.14332601079537025, 0.42537770504432343, 0.07005640410728033, 0.08803417410461173, 0.05641947598046353, 1.062441376909133, 46.74694499661846, 102.06782248712356, 81.79721739984329, 77.80892787441131, 92.22341076020273, 94.03401605544552, 90.17028531720563, 90.32847450625512, 91.61142687643729, 89.20297391953008, 94.39050459092664, 90.17350950548726, 90.00038393082158, 85.19154241008144, 88.5688207995507, 85.60230870400706, 88.16187489417293, 77.61655915168025, 79.74198172169348, 88.08998569365471, 92.33144852422899, 87.73096330704229, 82.21784453238212, 87.82858325589089, 86.90359423237463, 84.4668217628233, 87.09655131063154, 81.75733473993118, 80.66140097956504, 83.99722776105328, 84.79062126528832, 83.05792208640807, 77.08009658321258, 76.95647916486188, 76.51733844510971, 80.02869129180908, 77.2737047749181, 75.23371142725792, 74.28413698750158, 75.00626102570565, 74.33365298855689, 73.49110434132238, 74.35757160186768, 75.71052259014499, 69.33394109049152, 68.8861083984375, 77.17589655230123, 68.92481434729793, 77.52738798818281, 76.14417199165591, 77.79337959904825, 78.23651329163583, 79.28788108210411, 68.67393170633625, 69.764280011577, 70.0585989798269, 68.19352765237132, 72.71744820379442, 71.71451384021391, 74.57735769210323, 71.08560100678476, 70.68661751285677, 67.78607968361148, 66.37609743302869, 65.40924887503347, 71.40465444134128, 70.82502226675712, 70.50285447028376, 67.77472834433279, 68.5819129020937, 68.94659134649461, 70.16189067594468, 73.39730478102162, 72.98039605540615, 73.12095026816093, 72.63804374202606, 71.62269899922033, 73.85932860835906, 70.21914943572014, 71.03187238016437, 72.73574213827811, 66.01123071485951, 65.6296625444966, 70.94131269762593, 72.21667920389484, 74.10370795957505, 74.00012600806453, 72.07469724839734, 70.25206596620622, 75.9281199978244, 70.95176189176499, 75.1217120693576, 72.66904615586805, 70.14188658806586, 68.35568628003521, 72.04425965586017, 73.98150259448637, 64.1962323650237, 40.49846418442265, 30.89023405505765, 11.910049530767626, 10.33972078754056, 2.0322779229571744, 0.09288380943959759, 0.17610988549647794, 0.1192772314853726, 0.14992380514740944, 0.0937479796008237, 0.1352567147583731, 0.3041320336201499, 1.0924426057646353, 0.09392991782196107, 0.3062477233188768, 0.2790711525707476, 13.009288868596478, 75.5902313417004, 45.82128917017291, 21.07922915489443, 14.655231102820366, 17.605746792208766, 34.95921850204468, 56.76799674187937, 55.35234274402742, 53.947416428596746, 49.231429176945845, 2.967446109940929, 0.1423459851573552, 0.07833294224955382, 0.05147726658070761, 0.03714449696182724, 0.08576766467623173, 0.05295121974702324, 0.023831578061705636, 0.01729283376686996, 0.05876599563165538, 0.051843295730049574, 0.026688321846567338, 0.039926978098529006, 0.031026139585000855, 0.028680221312829567, 0.03280870744117326, 0.09451851849594424, 0.06213552228385403, 0.048342151342019926, 0.04766333232363386, 0.05270525955805375, 0.06056629459283525, 0.027879157644366066, 0.035418719203481754, 0.008000717761235373, 0.03495182691802902, 0.03150570871038062, 0.006879551435685567, 0.04800392735388972, 0.030458089219586506, 0.5541393425195449, 40.87968326384022, 72.805097487665, 69.20518536721507, 71.96482381513043, 32.11891062798039, 22.337319581739365, 63.03066084461828, 37.14049170094152, 8.038440221740354, 0.4004184072536807, 0.02440570350435953, 0.16225733043205354, 0.02082944419535418, 0.14687328899820007, 0.0927676398667597, 0.8949422583945337, 0.16892071723216967, 0.34131714473328284, 0.12512822034618548, 3.2729396656636274, 73.33678260926278, 107.67053604125978, 85.56970596313478, 86.39359981782975, 97.94115958675262, 98.87978276898785, 93.47775336234801, 92.9353601701798, 94.11651134490968, 93.25150320606848, 98.54012904628631, 92.61019568289481, 91.07005350051388, 87.84618685322424, 91.92435356878465, 92.7620384770055, 89.32899182842624, 80.85601329803467, 84.04715168860652, 90.32853726417788, 93.20008877784976, 90.44738508039906, 89.00076789240684, 93.01480385564989, 87.38565352655228, 89.16768043271958, 88.05331153254356, 85.80259276974587, 84.3034315109253, 88.44351676202591, 87.03566828081685, 85.5007585402458, 80.53248836148171, 84.09901326702487, 82.1512976000386, 82.94414981718987, 80.35021581957417, 76.84272258512436, 77.55639783797726, 78.43227094219577, 77.98077475640082, 80.11546196476107, 79.56589867991786, 80.0413134790236, 71.58734275448707, 73.28924348277431, 78.06188937156432, 71.25700858331496, 78.50503875363258, 80.70018537582891, 79.52253295529275, 82.58830455041702, 77.43200379033243, 70.38359872756466, 70.6924775338942, 72.70848951032086, 71.61041413584064, 73.43235508088144, 75.52081323439076, 77.77209681849327, 72.5785021628103, 74.95174008031046, 71.25746357825496, 71.15436015590545, 69.48671740870323, 72.85292686954622, 72.589171009679, 74.13183919845089, 71.36917268076252, 72.5201137604252, 71.29265508344098, 73.63063873783236, 75.01740840173538, 76.46824606003301, 76.1905736307944, 73.9815261287074, 74.76279166436966, 77.3774750001969, 74.66354785426971, 74.2632229097428, 77.77909432688068, 71.63761969535582, 67.9988290417579, 72.68748914041828, 73.74366575671782, 74.69849617250505, 76.01089769794096, 74.61527132218885, 72.26468901480399, 77.5306749343872, 72.29956673037621, 77.68548304034819, 73.93270830954276, 73.30523890833702, 70.30817154915103, 78.03646456810736, 76.87630591853973, 81.0484447786885, 65.34979358796151, 61.29306262539279, 39.702646655421105, 17.219609060595115, 3.344609948896593, 0.09485188165619489, 0.09930390203672071, 0.2968985088650258, 0.49533323835461374, 0.07375568947604588, 0.34056910584049843, 0.6899511645878516, 0.9564392617152584, 0.21400321425209123, 0.0701749868570797, 0.4502101693182223, 14.477768367336644, 85.53317300734982, 49.591220348112046, 26.380141819677046, 18.06398553232993, 24.511201074046475, 39.11727213090466, 52.98553751360986, 59.16463551982757, 62.648547464801425, 54.19760481003792, 3.057999663775967, 0.1365538395100063, 0.03872433880103692, 0.1293068775726903, 0.007431371749619083, 0.04880412534299878, 0.07558553644846525, 0.04901668792890926, 0.06277452771281523, 0.0435344401686903, 0.004210271759920063, 0.05969404603444761, 0.05028521078788946, 0.02245149364875209, 0.07935262059852963, 0.1142093683442762, 0.1415286919162158, 0.1681557631180171, 0.17363344499420735, 0.19557881499490432, 0.15088141505276004, 0.18384941132558932, 0.14713668534832616, 0.1303162137346883, 0.13194240389331696, 0.2002852914794799, 0.07693223474967865, 0.12149985173657057, 0.0951776835286329, 0.19482146047296064, 0.9488146643965476, 56.269730214149725, 86.98048837723272, 78.9165424531506, 73.69623645659416, 59.04425405686902, 49.3079585413779, 78.78628838446834, 50.40117802158479, 15.367482535300718, 1.3463248793155917, 0.1553653736388491, 0.44415568452208276, 0.280751857546068, 0.520793373786634, 0.4485166553528078, 1.6256601483591142, 0.266440048092796, 0.7474262063061038, 0.272363010914095, 2.687837745874159, 76.75810137102681, 110.06881436994, 95.95775819593861, 93.48224055382514, 102.64248109632923, 103.86512310274186, 98.76429250163417, 96.00306941616921, 96.8200912783223, 96.72174961336198, 103.18856131645941, 97.6933442392657, 97.81678122858848, 90.64626493761617, 94.41514492034914, 91.87783425854099, 92.54826930261429, 85.25056623643445, 83.39245319366455, 96.05840621456024, 98.3237946418024, 93.9215224789035, 91.01820761157622, 94.9738787066552, 92.37508097002583, 92.0990167125579, 92.47905515855359, 89.92530976572345, 85.87205010075724, 89.43684131868424, 88.77025019737982, 89.16921015708678, 81.92503175427838, 85.89070489329677, 83.57602011772894, 87.87418473151423, 84.14193968619071, 81.76822323952952, 81.01052330386254, 79.84613633924916, 80.20948902253183, 81.71671467442667, 81.53636409390359, 83.60918767990606, 75.09966050424885, 73.54059680815666, 82.23442831347066, 72.86514113026281, 81.51210031201764, 83.38678929113573, 82.8602973876461, 84.52779108478178, 80.64746087597263, 74.73536645212482, 74.34259599254978, 77.00477923116377, 76.27229229096444, 79.10359244192801, 78.76204029206308, 82.77374636742377, 76.26485547711773, 79.20512691620858, 75.17126729411464, 74.91122199643043, 71.39530351085048, 76.99095679867652, 77.25856442605296, 77.90776375801333, 76.00682627770209, 77.00391630972587, 74.96655879482147, 75.86303218718498, 78.27051239628946, 77.74445979825913, 80.18548411707725, 76.92451184795749, 77.7253657002603, 80.26747734315934, 76.64949094095539, 78.27923574755269, 80.23187006673506, 71.11170830265169, 71.38545836171797, 76.91469807778635, 76.99427512384231, 80.15426205050561, 80.08652271762972, 78.52832194297545, 76.27085670348137, 81.13885541116038, 75.87204579384097, 82.17149780642602, 77.1912016407136, 75.96600224894863, 73.77696667948078, 78.92953334316131, 79.82497122979935, 75.86729972593247, 57.623010681521514, 54.13751017662787, 37.77819064355666, 21.671256019223122, 2.999652936573952, 0.3716323164201552, 0.46909169323982736, 0.343426215432344, 0.6564829282222256, 0.39409763029506134, 0.4781109995899662, 1.6854598685618372, 6.239831495669581, 0.3783506010809253, 0.36589698385327096, 0.5191677352113109, 21.88394654181696, 96.12669467926027, 63.45743040884695, 36.138459482500636, 25.052560721674276, 28.662976949445664, 52.780405398338075, 79.28399009089317, 76.49366301874961, 74.0381573092553, 70.89398537912678, 4.865223630782097, 0.3644339091354801, 0.1978958479218906, 0.20419902018001004, 0.1276000489991519, 0.2730524287589135, 0.1987931973511173, 0.24160853376792324, 0.13331724060398917, 0.11554896501043152, 0.1983167366274903, 0.20418201302809103, 0.16857426162929307, 0.09091901607931623], [0.01331441755962348, 0.02068077334232869, 0.03925138431030416, 0.08452254197289867, 0.10343873903395669, 0.028832090582938927, 0.05117488401611486, 0.03140327700924489, 0.027491293073962295, 0.05067351011319026, 0.044545258710821795, 0.021383915652310657, 0.01768475860327242, 0.043585235628509716, 0.026956895035841776, 0.0651318070689036, 0.23402780264375672, 41.111730683234434, 58.683054754810954, 37.050728259548066, 50.26204762920257, 57.43546647410239, 48.64389734883463, 45.099828012527965, 17.538009420517955, 1.818218860895403, 0.03966687209603768, 0.08056208956986666, 0.08621998596936466, 0.09301464959618547, 0.11058645428068216, 0.17872553949634876, 0.14375603126902736, 0.20489269747368752, 0.1972932125171346, 0.1838527208254222, 28.152380451079342, 89.50330980362432, 81.79034540730139, 74.21223994224303, 88.68038085199173, 87.73330888440533, 90.37657060930806, 89.70746917109336, 89.29416902603643, 86.5390177695982, 92.20699171866141, 89.46633754238006, 90.55509336533086, 89.45409190270209, 87.9266974233812, 88.00227365186139, 86.85948325741677, 80.92295246739542, 77.10549000770816, 87.58469027857628, 88.924038487096, 90.41113453526651, 82.48428329344719, 90.3699496484572, 85.31373993042978, 83.93578775467412, 83.113643277076, 81.01588910625827, 83.20540320488715, 83.00167529813706, 85.31239847983085, 81.69128202622937, 79.71577244420206, 78.88745415595271, 80.75851886503159, 81.99321823735391, 77.37585113894555, 76.29275137378325, 71.98965241832119, 75.1794493582941, 72.37119705446305, 73.23576588784495, 74.8682955772646, 78.44923911556121, 76.62480354309082, 72.52000393406038, 71.13870989891791, 71.61232040774438, 70.13450468740156, 76.52819556574669, 76.00015040366881, 72.29690736339938, 72.27108247818487, 70.62984512698266, 66.41241073608398, 65.28406250861384, 68.20657345556444, 66.35048435580346, 65.77084041410878, 68.69209228023406, 68.65315883390366, 70.08249405891665, 70.38134728708576, 69.1571206431235, 70.92971032665622, 68.73811737183603, 69.88233550902336, 71.92163067479288, 76.07706023800758, 73.38742825292772, 68.8858259877851, 66.47439202954693, 67.13281677615258, 71.54682467060705, 70.43946896829914, 73.11735737708308, 74.31188383410054, 74.45657222501694, 72.92703613158196, 72.27296521586757, 75.11751513327323, 69.47442470058319, 75.42423663600799, 66.56285716641334, 65.83907004325621, 68.63053460274973, 72.46795408187374, 74.12368066849248, 74.14728549218948, 70.02967542217624, 71.27064274203393, 72.91789700908046, 70.36335145273517, 70.6290449634675, 69.6384503764491, 68.1390380859375, 72.40765156284456, 77.99953153056484, 71.68759069135113, 55.26219883272725, 39.47995016651769, 19.3374575338056, 13.376902226478824, 8.589239543484105, 0.28234752676179337, 0.12328397858166888, 0.4243414332309077, 0.25860817802529185, 0.34812414237568456, 0.24465125114206346, 0.6974892859016696, 0.20922494000725209, 0.17326455833690782, 0.04355037862795495, 0.06836561741487635, 0.1645814573332187, 43.15853326551376, 66.00900280860164, 30.401655781653623, 35.63407405730217, 36.99272424943986, 47.66408143504974, 55.07947521824991, 54.77046305133451, 53.53382995051723, 15.26538618149296, 0.10466814927396276, 0.05900275127421464, 0.07264251009591165, 0.1164407296586902, 0.0209993107860247, 0.08751951623708011, 0.05236874777643431, 0.017641731275005207, 0.010242358060373415, 0.017952975561662067, 0.07139225460348592, 0.08993359718231425, 0.041279682529068766, 0.02120258647107309, 0.06755551773934595, 0.020788736198277726, 0.06506731778743767, 0.08829976146620128, 0.09896399648559671, 0.039213106727167484, 0.02955441764976469, 0.06562935819308605, 0.028635772891462814, 0.023250216918606913, 0.006335120997391642, 0.01370465508737271, 0.025796053495498437, 0.02204257698218909, 0.10088699974960859, 0.09886106491209039, 0.6227713210448143, 50.44095477750225, 76.02265696371757, 59.96528933125158, 57.81864673860612, 33.96607437441426, 44.72366094589234, 54.51286531263783, 20.368221113758704, 2.482650717419963, 0.1327845643484785, 0.08853920224693515, 0.1425989627117111, 0.11740067613220985, 0.03279972506026107, 0.405824720378845, 0.36614847519705374, 0.246439392287885, 0.34452996427013033, 0.7069569681921314, 42.13157830699798, 103.86771971179594, 85.97385129620953, 82.73587196103989, 95.12732967253655, 91.82363494749993, 94.83371673091766, 94.37472881809359, 93.23261307131861, 89.83428724350469, 96.78363676994078, 91.32940061630742, 92.82517294729911, 94.12266946608021, 93.10151961541946, 91.86911875201811, 91.50423634436824, 83.70027296004757, 83.39598332681965, 92.35974450265208, 91.50889612013295, 91.6442806490006, 87.17810523125434, 92.09420004198628, 88.58542027011995, 87.03895522702126, 84.00592757809548, 82.8117698238742, 86.15510402187225, 88.19249291573801, 87.80824184417726, 85.50224904091128, 84.53314904243716, 82.10772006742417, 83.13506726295718, 84.74920103626867, 81.39133053441202, 79.71918490625198, 77.65062885899698, 76.8286334314654, 75.74914224686162, 77.6606152134557, 77.34644120739353, 78.97149485926475, 79.40351255478399, 75.65668413715979, 72.59219123471168, 75.63395007964104, 73.40280394400321, 77.49125511415544, 78.50501521941155, 77.60539608616983, 74.34999358269476, 73.57574124490061, 68.08217940791961, 68.91094484636861, 70.76133081989904, 70.4623285416634, 70.75219954213789, 71.71065422796434, 72.35704514288133, 72.88003829217726, 72.46604780997001, 72.93725782825102, 73.53091639857139, 73.74193991384199, 72.34177143343034, 74.54937550329393, 77.79191263260381, 78.30226006046419, 72.30063361506309, 71.2216680280624, 71.40041828155518, 74.4174583496586, 74.92628389789213, 75.82762887400966, 75.03948350106516, 76.16713354664465, 75.35970580193305, 75.20904756361439, 77.58041843291252, 73.67788760892807, 77.18623592007545, 71.25332155535298, 69.90443414257419, 71.1647387473814, 74.06219359367125, 75.500377685793, 76.5382525228685, 72.94914260987314, 72.86862419497582, 73.80553722381592, 73.15840890330654, 75.07781290238904, 74.14356708526611, 71.64811595793694, 74.32030124049034, 78.63684608090308, 77.02744268601941, 72.91109561920166, 65.80662419719081, 52.909584737593136, 30.90012235026206, 14.00464423241154, 0.4748522760646959, 0.020089064266592748, 0.14496404467330826, 0.15258752350364962, 0.5266372150471134, 0.6405869102285755, 1.5377722127783684, 0.3117933725157092, 0.08013553947450654, 0.06331982526687846, 0.03535625622457555, 0.06594248131037721, 50.06456805813698, 76.7954501798076, 30.876817587883245, 29.540275835221816, 22.159096887034757, 44.6662413689398, 71.56951950442406, 60.43524419107745, 59.63693987938666, 18.188689447218373, 0.17814305220400134, 0.17153811791250784, 0.037357362152467814, 0.051290701188507586, 0.03969148267060518, 0.047861898483167735, 0.014006022585465783, 0.04001224751494104, 0.06984841889671742, 0.01575821601305037, 0.04686595736852577, 0.027684728359623302, 0.05195167801913716, 0.028360444721916032, 0.1539330190468219, 0.14831823807570244, 0.12340084529451786, 0.28564329829908186, 0.1978655261618476, 0.15815089997504989, 0.16698625329281055, 0.18671038200057324, 0.11721239470305944, 0.10988594348272009, 0.13422304764389992, 0.12850159659020363, 0.10502683164011087, 0.13866929938235592, 0.17369450220177252, 0.21961969593840264, 0.8224750598592143, 61.29447075628466, 82.65550259620913, 57.54525361522552, 75.88548383405133, 81.88699260834726, 65.191718147647, 66.92209920575543, 35.11652908017559, 3.2979075129955047, 0.25255173204406617, 0.43423365080548876, 0.4357596366636215, 0.36350660566841403, 0.25458226340913004, 0.9035486739970023, 0.8548061765970723, 0.47220639223533295, 0.5517173402251736, 0.5799713983170448, 48.26769890323762, 113.09359719676357, 93.75487665976249, 89.26974050460323, 97.66620143767327, 100.61250548208915, 99.19155628450456, 97.04594919758459, 96.51660965334986, 93.50421367153045, 98.91534297697007, 96.46739959716798, 98.00565119712584, 97.74217774791103, 95.63777123728107, 96.43994300596177, 94.47783224044308, 89.40752552401635, 84.08632047714727, 93.89725869701755, 95.1620348038212, 98.65921220471783, 91.27712326665079, 95.05818613113897, 92.85078602452433, 90.57075146705874, 90.14281303651872, 87.81668278478807, 89.3466111152403, 91.34078333454748, 90.77892734158425, 89.5335748118739, 85.589309969256, 84.14434017673616, 85.23743414109754, 87.76249131848736, 85.18634919197329, 82.78249325290804, 79.05542573621197, 81.52162382679602, 79.0032111444781, 81.75462045977193, 81.3771786228303, 85.46002864837648, 81.72971340917772, 78.6463225272394, 73.77447989679152, 77.63709668190249, 77.19904638105824, 82.53225388065462, 83.00093004780432, 79.21178710076117, 76.18769461108793, 76.04711686411213, 71.06968402862549, 70.1926891265377, 73.01855287244244, 73.33541762444281, 72.32475619162284, 75.63016107005458, 73.49326164491715, 75.94226406466576, 74.79182504838514, 74.72523104759955, 76.56143373058688, 76.5308000195411, 76.7546183063138, 77.72191401450866, 81.86103436254686, 80.41686473354217, 73.3929587948707, 74.09753414892381, 74.54677104949951, 76.70166630898753, 76.22640840468868, 77.3889361658404, 80.43588038413756, 81.39136975811374, 78.38742256164551, 79.06847938414543, 81.02341221224877, 78.57758691233974, 80.81160422294371, 72.1884459833945, 72.75118058727634, 76.7775563270815, 78.27772171266618, 79.54873438804381, 81.56406387206047, 75.50173482587262, 75.59421646979548, 77.09358953660535, 75.14417156096428, 79.57762656673309, 77.49750737221011, 73.5694105394425, 76.35481895938997, 82.65682051258703, 76.69539836145218, 68.5047677255446, 58.75376332190729, 49.30079237107308, 35.71841286074731, 15.053346772347728, 0.5821034516538344, 0.2931593256371637, 0.8768820113712742, 1.82678887199971, 1.1495309875857447, 1.8256334888358272, 4.852012107449194, 0.8013400423430628, 0.33094799146056175, 0.194358482896801, 0.15172745191281842, 0.48825639390176345, 61.603659429857814, 84.65746464267855, 44.89235816463348, 53.502301939072154, 53.33553060408562, 70.08623600006104, 79.24028704243322, 71.67125009721326, 75.85551692593482, 29.851098175971742, 0.19968837109063903, 0.3002186726418234, 0.18365467177523723, 0.24787658855559366, 0.04497907515014372, 0.12420987244695426, 0.21929931796846852, 0.1465177475925415, 0.16258785140610513, 0.1230877221772267, 0.18612720522909396, 0.2437316391977572, 0.1313957388723089, 0.18799639847730437], [0.02174047978534814, 0.07740212243891532, 0.05767664924684552, 0.0021269085775730352, 0.030268767826078884, 0.017125627416516506, 0.06198809632370549, 0.026434773556707848, 0.05891930514706239, 0.05347548052668572, 0.05581818889045427, 0.07933461753230903, 0.13054211774180013, 0.013556949505131814, 0.09085914630803371, 0.09180382464922245, 5.560602497669959, 64.03463463629446, 52.95106772453555, 33.20372250772292, 37.29897899012412, 31.641473847050822, 44.58815874591951, 29.851535520245953, 3.0362496308742033, 1.063672143124765, 0.027656599526263537, 0.29557676204750616, 0.03418218434577988, 0.2197926173046712, 0.06536127338486333, 0.7605271678297751, 0.41170579351244435, 0.7540674531652082, 0.5046442403428016, 12.168459200089979, 63.813954245659616, 71.6783574319655, 89.41387191895517, 88.14472629177956, 94.89274840201102, 84.13665233119842, 94.11586807620142, 83.44429123786189, 87.4520435640889, 85.10570526123048, 92.31452741930562, 88.30596708482312, 88.76445293426515, 87.85684001061225, 86.38661799892303, 83.71315402369346, 79.95661381752261, 76.71886197982296, 90.76617963852422, 86.75546200044694, 84.82664431295088, 83.07517267042591, 88.8581112892397, 85.86643326667048, 86.17995615928405, 83.43950594625166, 77.00618343968546, 79.91443264868953, 84.94150700107699, 81.73806805764475, 81.41249564386185, 81.3072427626579, 81.33876292936264, 80.35172200972035, 82.46563634564801, 80.61359513190486, 79.16585614604335, 76.9134036956295, 74.99782008509483, 73.19450255363219, 75.63650746499339, 74.669996230833, 74.61985265055011, 72.80171640457647, 75.18741176974389, 74.3146530274422, 71.82283401489258, 72.33686847071495, 70.60570686094223, 73.26673692272556, 71.15774123899399, 73.30767862258419, 72.32120252424671, 74.57980525109076, 70.01677082430932, 69.42684635039299, 68.82243264106013, 62.329117482708355, 66.76641248887586, 67.55008635982391, 68.14015203906645, 70.9488828720585, 68.54748233672112, 70.2092807523666, 70.25558040988061, 71.78157852542016, 74.38126271770847, 73.32452128010412, 71.59583860828032, 74.52693954590829, 71.91842217599192, 70.41871963008758, 70.00355243682861, 69.67257499694824, 67.87260716961276, 70.4883103216848, 72.00021143882506, 71.65485458989298, 74.79436674425679, 71.85004741914811, 71.17889850370346, 69.72506415459418, 71.18812391834875, 73.52378552959811, 68.54448564590948, 66.05876199660763, 70.39762512330087, 72.30754483130671, 72.62943021712765, 71.57941172199865, 71.43939095158731, 72.4217877849456, 69.99088318117204, 71.26081328238212, 71.07737187416323, 70.16742906262799, 70.01773572737171, 74.68501890859297, 76.31314769867929, 64.64346493444135, 50.20312578447404, 30.36673688119458, 17.06799376395441, 18.388855841852006, 4.227766404228826, 0.15621582316535135, 0.03404748693649327, 0.09658003045666604, 0.17412291389078866, 0.195988534138568, 0.7185106772568919, 0.140854534542849, 0.18809136273639818, 0.02807965434546913, 0.18432498338722414, 0.3230768670478175, 8.382703219690631, 83.27294641925444, 53.870722324617454, 25.993117632404452, 36.73811927918465, 36.39687699656333, 32.51825694114932, 38.0841080604061, 50.74744093802668, 6.0621677387145265, 0.13112592270537732, 0.0778532026696109, 0.03067229697931438, 0.007267032004517293, 0.03115108086457176, 0.016395997616552537, 0.03269405472242544, 0.038735221080001325, 0.0769346938919156, 0.03371484389889144, 0.045499064989628336, 0.03601443300384187, 0.07355414706492618, 0.03671370656980622, 0.027692657369639606, 0.013910329585234004, 0.03174562255040773, 0.0238841182867726, 0.08626501661755386, 0.025117879906188578, 0.09101274693685193, 0.033041939079280824, 0.02994156784317907, 0.01393772584701618, 0.14505220607163447, 0.037892286876036275, 0.05213918952992366, 0.010751943468236396, 0.13569952890036568, 0.1553863644479744, 8.465998672669935, 76.52584998838364, 62.720644550938765, 48.75884632910452, 38.20161834839852, 30.424334925989953, 54.30322247166788, 40.27693263946041, 2.37892510910188, 1.3199731707572937, 0.08588002679208595, 0.18844641384578523, 0.24144350310727475, 0.3129353644626756, 0.08527405890485934, 1.012363741474767, 0.29900843758256207, 0.7491193831928316, 0.3661374128874271, 16.128310561180115, 82.95379100307342, 84.50836750768846, 95.96244150592436, 91.9050084390948, 98.26289592250701, 90.69544361483668, 97.66567584007018, 86.57825716080205, 90.84662745075842, 90.15974198618244, 93.3224275035243, 92.04964191682878, 93.54047206140335, 92.72166159845169, 89.47581398871638, 86.95240420679893, 82.96423235247212, 83.78960886309224, 93.09462408865653, 90.85173437672277, 88.18962958551224, 86.72514992375528, 91.6477244900119, 87.8343334505635, 90.36834147668655, 85.51879359829812, 83.45933744984289, 84.17448751388058, 87.530122264739, 84.83204149430799, 86.27532466765373, 86.92177834049349, 88.14658549524124, 85.91587082032235, 84.35135502969065, 82.43529288999497, 81.52815849550309, 80.91098139362951, 79.17716041687997, 79.61364961439564, 80.62257735959946, 80.18744530216341, 80.50586331275203, 78.6583955826298, 79.11886615137901, 75.98740270060878, 75.85852930622717, 75.50967370310138, 74.03484682882987, 78.61673216665946, 76.4151999258226, 78.37171739147556, 77.00113927164386, 77.37544321244764, 72.36221482676845, 71.49230372521185, 73.36340765799247, 67.74174905592396, 69.32868511446061, 70.64885293283771, 71.57189646074849, 72.29296145900604, 73.19109793632262, 73.41978780684933, 74.28306225807437, 74.56317440156015, 76.14151262467908, 76.65415856146043, 76.06186497596003, 73.52628800176805, 76.05486746757262, 74.07684756863502, 74.45810979412448, 74.6678703061996, 71.35336552896808, 71.98939354188981, 72.80260286023541, 74.86831911148565, 76.65886540566721, 74.69136530353178, 71.23153671141594, 74.09948748926963, 72.6422877465525, 74.58843446546986, 70.90036315302696, 70.1931127425163, 70.10326693134924, 74.81141336502569, 74.89500691813808, 75.00448026964742, 74.20477174943494, 76.44953635431106, 72.54641717480075, 75.47381539498606, 74.118024610704, 72.91377852039953, 71.9964224292386, 76.69540620619252, 80.22081682758947, 75.97489818449944, 68.75684276703866, 58.08411667423864, 40.967305091119584, 28.950361167230916, 7.328233324712323, 0.08170025107721168, 0.08314112456695688, 0.07030967277504745, 0.2596976469841696, 0.16322004248297986, 0.6063945675569197, 0.2261456618866613, 0.25020791668324704, 0.09772013016645947, 0.14057698088788217, 0.2963253218800791, 9.339975310910134, 92.24187727897399, 57.29643021860431, 30.791462890563476, 22.31849024372716, 38.71276593977405, 45.63222308312693, 44.18863004253757, 59.89674983486053, 7.797068347853999, 0.19769530142507247, 0.1774656312960771, 0.0579688007072095, 0.07615779646702352, 0.025355478245464545, 0.06835935081565572, 0.12996142309519554, 0.1052008331903527, 0.07373877425467776, 0.05123168943570026, 0.05792213063086233, 0.03920593997463584, 0.04314040284483664, 0.05079382039125889, 0.09660938694592446, 0.25855482766224497, 0.19340088831320887, 0.08197808818471047, 0.1858031806806403, 0.1338789669135886, 0.14555889662475358, 0.11578457535154398, 0.09576501249666176, 0.11927319420201164, 0.164484761715416, 0.23574167922619851, 0.22881782253182706, 0.18093230172751412, 0.22077294937785596, 0.5115330868190335, 9.847833014303639, 91.50442461813651, 72.40619244114046, 52.131480632289765, 51.879746837000695, 48.65195781953874, 66.27694775981288, 52.195572160905414, 5.692552010859213, 3.9276864547883314, 0.47070268421403827, 0.522303302441874, 0.41370801026782683, 0.5971771815130787, 0.30737592568320615, 1.7214896577981211, 0.6837326756888821, 1.3871960990851926, 0.7433883100748063, 15.309862917469395, 93.6331968922769, 86.89911488563784, 102.15561297632034, 94.92437055034023, 106.6105390364124, 95.68579673767091, 102.56766580766248, 90.16180515289308, 91.89779912271808, 91.27162410366921, 96.82217013451361, 98.68557053227579, 98.69364277009042, 96.64328652043497, 94.38650377335088, 88.69381889220207, 88.79274891268823, 85.55019609389767, 96.46390084297427, 92.26594494235133, 90.58840997757451, 92.11988372187461, 92.93816858722319, 91.72004515124907, 89.93854384268485, 92.09303902041529, 85.37229307236211, 85.52958011627199, 91.29351877397107, 86.69380234133813, 86.3005925763038, 88.8163302021642, 88.6712025057885, 87.69174745005947, 88.10700878020256, 86.21555559096798, 86.15515109031432, 83.59540447112053, 83.21454232738864, 81.31812341751592, 82.30161851452243, 82.51418744364094, 83.88735432778635, 81.75881739585631, 84.41569758999734, 82.09767879978304, 76.37441512077086, 77.35224631524856, 74.70230087157219, 82.76992597887593, 78.64570279275218, 81.24695593310942, 77.31041031499063, 79.48501156222436, 76.87217958511846, 73.65417295886625, 76.69414320299703, 70.39971182423254, 72.00969572990172, 73.84626711568525, 72.88316834357478, 75.82150997654085, 74.9966355293028, 76.50961922061059, 76.73288837555917, 78.37157618614935, 77.8964908661381, 81.88734562166276, 81.2575855562764, 80.97652419920891, 79.57806587219238, 76.49825219185122, 76.84265198246126, 78.26802561360022, 72.06930791178058, 75.87985131048387, 77.04194761091664, 79.36188051777502, 81.35830417756112, 79.44370900430988, 74.57695761034566, 76.3679353652462, 75.58044110575031, 78.37137222290039, 71.4008968107162, 72.82175187141665, 76.95041518057548, 79.3428413329586, 78.99666863103067, 77.4782956031061, 79.03148358868015, 76.6453646075341, 76.24307847792103, 76.81777631082844, 79.42507774599137, 75.69423690918954, 75.92297384815832, 81.39587263907157, 82.45491258559689, 71.62452682372063, 64.11886361337477, 51.53421348141086, 40.627965158031834, 34.5609135781565, 6.116006681996008, 0.25118886162677123, 0.24079107198744054, 0.15507616012567474, 0.5425920685933483, 0.7352220579501122, 1.7725727683113468, 0.34071049502780365, 0.274177260336376, 0.17270961956631753, 0.28683995828032494, 0.462868822317931, 13.569685739855613, 103.4566866966986, 67.91496876747378, 40.643540889986106, 52.69002614482757, 52.7078180159292, 46.282085295646425, 53.93175440449869, 72.08080830112581, 10.733718948979533, 0.7445042243888302, 0.3099225858046163, 0.34537636885239237, 0.16455127346900203, 0.20365975556835053, 0.14132791559302038, 0.33821948353321324, 0.23599078037565757, 0.32537902254731427, 0.10205952030035759, 0.17178171855067054, 0.11492913859265466, 0.12939974275087157, 0.13859422276577643], [0.036331968787576885, 0.05599936868454661, 0.04938921350384912, 0.07291104689600968, 0.02811923236285727, 0.09979186174009116, 0.08405679881933235, 0.049092607242205454, 0.05967664051680796, 0.048358020853371396, 0.023509122078276934, 0.05222845409486083, 0.03642663810281985, 0.06504153892878564, 0.015910031657005032, 0.10108353960658274, 33.80113086392803, 68.08918476104736, 53.49974063134963, 59.82525287135955, 40.774120515392674, 35.49597917064544, 43.91082425271311, 6.903057223366154, 0.6335034161325425, 0.3073142096400261, 0.44374098580691124, 0.2729118975900835, 0.2916595093425243, 0.028296899643816778, 0.5080026472287794, 0.5069609208693427, 0.06639916930467853, 0.1269284733420899, 0.3056571614598074, 34.21038312296714, 84.39163777136034, 81.46615366781913, 91.7863488966419, 90.70499850857644, 91.34460372309532, 88.75027748846239, 85.65884574767082, 87.31645507197227, 86.84330740282613, 88.41756636096586, 86.66647126597744, 83.79663775044104, 87.6616628708378, 87.50978869776573, 86.76220847714333, 83.56901476460119, 79.41421278061406, 87.4779704309279, 84.82818188205843, 87.97593885852446, 81.77041192208567, 88.1550499700731, 83.02895146031534, 83.58667327511696, 83.36220387489566, 78.51334633365755, 82.61768310300766, 85.47112895596413, 81.96242763150124, 79.20912773378434, 80.35599739320817, 82.51039843405448, 82.06330314759286, 82.15505523066368, 81.68003266857517, 82.7314789064469, 76.58817645042174, 77.14728678426435, 75.23994015109155, 78.81911862281062, 78.76548413307437, 79.19830199210875, 79.24060083204701, 76.8278254232099, 74.22990629749914, 71.16131844059115, 73.25329888251521, 72.20718706807783, 68.91260793132167, 75.11444783979847, 75.9651550169914, 74.85352393119567, 72.67189379661315, 72.62034600780856, 68.82234634891634, 65.53386257540795, 66.22657668206, 65.05999319015011, 63.37521360766504, 65.9490611476283, 65.4560309840787, 67.18342319611581, 69.59815979003906, 70.02879681125765, 71.05406515059933, 73.11392138081213, 72.13596467048892, 73.92918602112802, 71.62433070521202, 72.54198489650604, 74.00651162670505, 71.00970314395043, 70.56364336321431, 70.14953520990187, 66.08705013029038, 66.2527467358497, 69.61475141586797, 74.82810697247906, 69.87771495696038, 75.79284529532157, 69.706417206795, 69.80963045550932, 67.85015552274643, 67.73937994433989, 71.44667087062713, 68.21481827766665, 68.5891692869125, 68.23228851441415, 73.55418389843356, 72.80937287115282, 74.06064817982336, 74.37901127722957, 69.8209661053073, 70.74560211550805, 67.386515678898, 68.5587630733367, 68.84876743439706, 70.55424536428144, 76.63566066372779, 73.60265654902305, 55.78798863195605, 44.829486493141424, 19.388695455366566, 22.2406723806935, 16.626717313643425, 0.5742522148836045, 0.23875706258320042, 0.199772012570212, 0.13626841047117788, 0.06892784168162654, 0.028139585403785593, 0.20684856590965103, 0.2953242288241464, 0.297409336292936, 0.01648059670603083, 0.13180092277546085, 0.6313944067205153, 48.13132593708654, 72.62419777531778, 34.84206907210812, 29.496782633566088, 25.305177050252116, 54.71922120740337, 47.68472094689646, 53.7249513595335, 8.69189581563396, 0.362679383927776, 0.10398080752741906, 0.0953202907957377, 0.02143390863502939, 0.09969901954454762, 0.0840752921818245, 0.07810715315563065, 0.018880058778449893, 0.0738327042950738, 0.06559392662658807, 0.014401578678629331, 0.10855368593887937, 0.022204480088886716, 0.038908341629130226, 0.056824602427021156, 0.03377778185231071, 0.023619124643324364, 0.06264138163157529, 0.037637677554401665, 0.09293894478750807, 0.020438130314071334, 0.03283106188680376, 0.050096860410825866, 0.02497898625029672, 0.01151849487571106, 0.0637322755139922, 0.08557566005976931, 0.02255377979318221, 0.017978639507125464, 0.061085774983850226, 43.00515682466569, 78.91396937831756, 71.13741551676105, 70.92227351280951, 26.503686674179573, 41.10888304248933, 53.57438725809897, 7.385001788216253, 0.7782157702792076, 0.2998048319451271, 1.0374681363182685, 0.5545244702408391, 0.4609674227333838, 0.07128556919915062, 1.1785062714930505, 0.35892567567286954, 0.2398888655607739, 0.2449758425955811, 0.6464240712023551, 49.51243562083091, 99.54097670893516, 88.39196112848099, 94.64541942842546, 94.166960870066, 96.91062742663969, 92.45268898625528, 90.24497509002687, 92.20857635621103, 90.63547057490196, 91.19941326879686, 91.380720907642, 87.95797440313524, 92.11435317993165, 92.71615459072976, 90.72809342415103, 85.45940891388925, 82.99396391837828, 91.1447903417772, 88.66252622296734, 92.09889119671237, 82.82194445210119, 91.58826920293993, 86.16370185728996, 88.2194866672639, 84.52605739716562, 84.87622307192895, 86.39318404659149, 89.33983325958253, 84.31894056258663, 85.25142915787237, 83.27964582750874, 86.80708823665496, 86.04420292762019, 84.6567193923458, 84.03612198368197, 85.40002422948038, 79.37949980458906, 83.2656821896953, 81.24519086653187, 83.67652693102437, 83.41596388047742, 82.35176993954568, 82.19475746154785, 80.6549604477421, 75.94379378903297, 74.48842971555649, 74.19913138112715, 74.30404693849626, 72.27075299909039, 76.66367423149848, 79.64429901492211, 76.98834450014176, 73.39843442363124, 76.01773046678113, 71.79626387934532, 67.23445323205763, 67.85826698426278, 67.74093320292812, 68.14288200870638, 69.01961018962245, 71.4522014125701, 71.22788890715569, 72.60881423950195, 72.27014895408385, 75.84640133765437, 76.17108729577835, 72.01684228835568, 74.68384219754127, 73.18902692487164, 74.49115184045608, 74.63516558370283, 74.7088041613179, 72.8862827054916, 73.29162043909874, 71.42869072575724, 69.12091716643303, 70.3915846732355, 75.85737612939651, 70.90971408351776, 78.59179373710387, 71.00036005819999, 71.86237150622954, 72.3606772576609, 70.04081495346563, 74.59751083004859, 70.75849102389428, 69.98623125014767, 69.80815564432453, 73.22097070755498, 76.19806535782354, 75.4370863206925, 73.75840602382537, 72.6395970006143, 76.04263751737534, 71.20334271461734, 73.82912635803223, 71.0967876065162, 73.76360708667387, 77.20842084577008, 79.4967237595589, 67.99271014428908, 67.12268137162732, 49.15010667616322, 38.090411309273016, 23.694871510228804, 1.0773040955105135, 0.17464923161652782, 0.2017185194117408, 0.08447244748352997, 0.12426215028690717, 0.05268538723729792, 0.02387288552258284, 0.06912902403142183, 0.11380921763878678, 0.10252379256510928, 0.2381089828427761, 0.7628300894171961, 56.64305748478059, 77.05694675445557, 37.61786768513341, 26.280007631547992, 24.485056515662905, 61.64589551187331, 53.78337898562032, 63.48269831749701, 10.19177879056623, 0.4205696453009883, 0.15355242656603937, 0.09875487746490587, 0.0676027930251533, 0.07282011225939759, 0.0532476804519613, 0.032692311872397704, 0.052882202885924816, 0.04428162870387878, 0.03684464631782424, 0.06239981495685155, 0.030737402961559357, 0.027878855039635976, 0.04211175360626752, 0.12795246476607938, 0.2133388781259137, 0.13253805257620352, 0.11509724126587953, 0.1562989130616188, 0.2748220918640014, 0.22053759184575852, 0.12671628230882268, 0.16358025702497653, 0.07683841962247126, 0.19720695101686064, 0.17979020252823832, 0.19748733919714728, 0.2027221099143067, 0.09032035667088725, 0.2092759308194922, 51.91844494112077, 89.15692529370709, 76.69179762563398, 85.58825092930948, 57.96786938944171, 57.997259709142874, 67.455259138538, 12.240684743850464, 1.5433597516629005, 0.8528155737346219, 2.128034623399858, 1.0329780030635096, 0.8044960794429626, 0.2120728412222478, 1.2344316705580682, 0.8595075662578306, 0.5570581987980874, 2.0158811898962146, 0.4957284171494746, 57.56233553732596, 100.97636807349421, 91.40233316729146, 101.24230477117725, 98.02935800244732, 99.01659504059823, 96.1904331945604, 94.67543340498402, 93.40084352800923, 95.34366407702046, 92.78638070629489, 97.206389827113, 93.85425383044829, 94.02704208127915, 96.2197332997476, 94.39130475444179, 91.82406640821888, 87.39929553001159, 95.38378992388326, 92.18978035834529, 94.77049596848028, 88.7029266357422, 94.40011439784881, 89.82113945868709, 93.01052062742173, 89.36132784812682, 87.57226420987038, 87.724059935539, 93.69040858361029, 86.7829970390566, 87.58037567138673, 84.41845893859863, 90.63470179034819, 87.94560324761176, 89.17318744044151, 88.52627092792143, 88.43040820091002, 82.30421512357651, 83.72740791689965, 81.54588760868197, 85.76427121316233, 85.34459329420521, 85.01789908255301, 84.95658459201937, 82.15636530230123, 79.72758662316107, 75.85937653818439, 79.81864052434122, 79.0085220336914, 75.84167095922655, 81.97139416971515, 81.29631503935784, 80.92515683943226, 77.48516759564801, 79.07343726004325, 75.78921318054199, 72.42544343394619, 70.28868521413496, 70.15992164611816, 70.30705759602209, 72.00916228755828, 72.85644915796095, 72.89236237925869, 78.34258987057594, 75.66651359681161, 79.05842242702361, 80.44287004778462, 75.47504701922017, 78.29478402291575, 77.33784337197581, 79.6697473526001, 79.86399881301388, 79.02411737749654, 78.16745604238203, 74.99461158629387, 72.74397911563997, 71.08506756444132, 76.76767195424726, 80.74002096729895, 75.36163560805782, 84.2092397136073, 74.23504460242488, 74.1212252647646, 73.4300644167008, 72.97906244954756, 79.64778992437547, 71.92552166600382, 74.84547522760208, 73.3108086739817, 79.32342560060563, 79.19362652686335, 78.64766397783833, 78.03660577343356, 76.1935075636833, 78.97029461399202, 74.1889645976405, 76.98154311026298, 73.42785219992362, 76.36198120732462, 82.27270280161213, 77.16200351715088, 63.20063283366542, 59.97548357132943, 44.688798919800796, 44.54501267402403, 24.529551882897657, 0.8578990267649774, 0.6102674178058102, 1.0441636222024118, 0.4267432414475949, 0.23985875830534967, 0.08793854334902379, 0.8004032700292526, 0.5098825963514467, 0.613331892077, 0.2995412057686237, 0.3387732118848832, 1.3059394205770185, 66.97848719935264, 84.24186598870062, 50.616978983725275, 43.987428142178445, 38.10713629568777, 75.39510127036803, 63.88260749078567, 74.80345095357588, 12.68464703713694, 0.7488565231042524, 0.23167729167447937, 0.15019371324489195, 0.13234266951199503, 0.25948473582825354, 0.14210989218085043, 0.17503982920560146, 0.19738600108652346, 0.22602431355945526, 0.2038021406699573, 0.1919262303460029, 0.26803418513267274, 0.14975069992003903, 0.08725568321683715], [0.019923460955220847, 0.04088395981178169, 0.018872185309808102, 0.07911432128880294, 0.029863080220116727, 0.06368997979969268, 0.13768185801323385, 0.10311752602818514, 0.039584552118134116, 0.042332988307480855, 0.02581799616886964, 0.06442254754684626, 0.03660535875467524, 0.016871090873234698, 0.0982788687331542, 1.2082075616044383, 54.362101170324514, 53.868902344857496, 39.035800580055486, 37.57154057102819, 38.98179738752304, 47.6143418588946, 18.70823287194775, 2.027276533265268, 0.061083246893700094, 0.09385120228774126, 0.10122746454491731, 0.6247583079722621, 0.25601006743888705, 0.3079124630218552, 0.803728030333596, 0.026209124273830847, 0.30631740667646934, 0.41501219835012193, 4.878598913069695, 71.08797011836883, 86.61495485613423, 82.563993700089, 90.60047518822455, 94.75691672294371, 89.53013881560295, 89.01419808787685, 87.76194218666323, 89.2982953594577, 88.0285692214966, 89.61508166405463, 85.52055082013531, 86.54544261194046, 82.29486419308571, 85.19515883538031, 83.23188704829063, 76.3168425713816, 84.75860687994188, 84.25039322145524, 90.11100261442124, 81.0220629169095, 81.67038363795128, 84.22348576207315, 81.88398807279526, 87.94087286918395, 78.7102650057885, 84.96270348948818, 82.0020906386837, 83.06127963527557, 81.11627824844854, 83.34660853109052, 81.9504330235143, 79.13854860490369, 77.4796841221471, 78.96924341878584, 79.88139844709828, 81.38169719326882, 79.92132817545246, 79.52706721521194, 79.08566721024053, 76.14435242068383, 76.24019945821455, 77.71592063288536, 74.70262250592633, 73.69097263582292, 71.8677451533656, 69.33415289848082, 66.83480293520036, 70.39714659413984, 66.29222146926388, 65.61701682306105, 72.60899466852989, 71.8977669746645, 68.06118688275738, 70.67244991179436, 66.98429230720767, 65.85867404937744, 66.09400057023572, 64.51719991622433, 67.49458482188564, 66.29968181733163, 68.32633910640594, 67.3632638685165, 68.30998282278738, 69.23403832220262, 68.16845586222988, 70.38703472383561, 68.45337683154692, 69.32814382737683, 69.68509520253828, 71.79732291929184, 71.29591849542433, 71.36037872683617, 68.88857164690572, 70.06916584507113, 69.00991409055649, 67.67091105061193, 69.36153888702393, 70.76371562096381, 69.12729494033321, 69.3387185373614, 74.04342113002654, 67.40821423069124, 65.77668082329535, 69.94839606746551, 68.01735831845191, 70.44936903061406, 70.12457324612525, 69.1240393730902, 68.52678791169198, 76.03109790432838, 74.2903107981528, 73.63898554155904, 71.5398899201424, 72.39796330851894, 70.56027012486612, 69.43363989553144, 70.93943780468356, 71.26182525388657, 71.07535577589466, 77.88615149836387, 61.36570884335426, 56.091215302867276, 29.326438019352576, 16.387350751507668, 29.2853041233555, 6.005784648080026, 0.327492751060955, 0.1621963804767978, 0.15818992449391275, 0.17488039098680022, 0.053996807189598206, 0.10561126479578596, 0.07076873564191404, 0.06968760171965246, 0.08021790158724593, 0.05563046287504896, 0.11355026459862148, 37.694718683919604, 68.55875522859635, 59.82365646669942, 31.200036579562774, 28.605967260176136, 49.21851281196841, 39.19340925831949, 57.73963451385499, 13.409513792684002, 0.41446416969260863, 0.20517523070016216, 0.07717202793085769, 0.13603836958927495, 0.03221990758432977, 0.042027269429977865, 0.03396979796009199, 0.022113254338863398, 0.01602878198853784, 0.023639856897775206, 0.06089325325803892, 0.04226147016930965, 0.036920504344086495, 0.02597169255867841, 0.02448182391573585, 0.04411166060655829, 0.028642962626632185, 0.050702732537061944, 0.0465317668333169, 0.032321636399794976, 0.04846472924034442, 0.08104994202092772, 0.02745132052129315, 0.091846625981552, 0.04138741747386033, 0.045567932463581526, 0.03155519224462971, 0.0790506900258122, 0.05564349403064098, 1.5963204517479868, 66.03808326105919, 62.44794960944884, 67.57959042826008, 41.8461395848182, 28.27384056583528, 59.77277155845397, 25.507485058999833, 1.5590527870001332, 0.056425022457035325, 0.08479189082619645, 0.353341844653891, 2.156852277055864, 0.8405454192430744, 0.7525080045865429, 0.8289143046544445, 0.08402238614977368, 0.4207898189704265, 0.2959449132603984, 6.705408009790606, 89.74987783739644, 89.63647427097445, 87.41296891243228, 90.15111277180334, 97.05056190490724, 91.63565927936186, 91.2921537891511, 91.2668780357607, 94.30189040399368, 92.0996521365258, 96.8673558388987, 90.36419945378458, 88.27389778629427, 87.66539696724185, 88.22378558497276, 84.00555103055893, 81.37056550671979, 90.23881696885633, 89.08644030171057, 95.44077411774667, 85.51738154503607, 85.47003853705623, 87.18391818384971, 86.92755206938713, 88.46363067626955, 84.10160987607895, 86.15589634064706, 86.21237062638806, 87.25456791539347, 84.80078804877498, 85.4579419474448, 85.04964674672773, 85.1584925190095, 82.74689382122409, 83.35485335319274, 83.78170920956521, 85.17672369557043, 83.39614806636688, 81.38123435358848, 82.31435837284212, 82.18240984024541, 79.98591392270981, 80.64837871059295, 76.76545973747008, 78.85311772746425, 74.81451988220215, 72.97639523783039, 71.79835842501733, 72.62338976706229, 69.97345216812627, 73.13562777734572, 76.97269424315422, 75.53901303199031, 72.45854039346018, 72.50351428985596, 71.11366948773785, 68.99444426259687, 67.93550629769602, 67.43832234413394, 70.01181294841152, 71.01357060094034, 71.92446262605729, 71.08345154793032, 71.4830155526438, 71.22434308451992, 70.92537218524565, 73.55718843398556, 71.66625299761373, 72.79082006023776, 71.76258640904581, 73.48374597487911, 72.48680499292189, 73.76178710691391, 71.42825142029794, 73.59119538337954, 69.96119083896761, 70.10683628820604, 71.60708796593451, 72.20783818152644, 72.41568457695746, 70.68771577650502, 75.11443215031778, 70.35944477204355, 69.15129984578779, 72.54527184271043, 70.54571813152683, 72.40471762995567, 73.4881547189528, 71.07955271197905, 69.91139242725988, 77.20020740262925, 77.64158387337962, 74.0353645816926, 72.87448421601327, 73.45166883160992, 74.78614545637562, 72.97605791399556, 72.78978455451228, 73.31404855174404, 73.21214537466727, 79.36856423654865, 68.62845574655842, 70.23841611800655, 58.09669179301108, 37.08081676113991, 37.85513970159715, 10.43434992913277, 0.3481165734269927, 0.06776518834334228, 0.10790172213267897, 0.10778177574637438, 0.12933223508298397, 0.09296698360553673, 0.040637562952695355, 0.06968082184152258, 0.03084011620000726, 0.019812920213406606, 0.1746244410112981, 43.565718435472064, 75.58288081999748, 68.2584507234635, 33.94482689519083, 24.303843013701904, 56.11054082070628, 46.17621660232545, 65.58713228471818, 16.390381763058326, 0.46348717784689325, 0.2106122639510901, 0.009234585675350841, 0.11337802505060551, 0.06967591121792793, 0.07848221448159988, 0.08484219982018394, 0.07026062016525576, 0.010561283336081093, 0.01399548025801778, 0.022494574603174004, 0.07266085790169817, 0.036910663944699114, 0.04094101420994248, 0.11770027013675821, 0.11442897510865044, 0.12176814338853284, 0.1279771481189997, 0.12037123568476209, 0.13720145959767605, 0.2835662194317387, 0.17230978295687707, 0.1473004136595034, 0.21253696793029386, 0.20202081770666186, 0.22308901703405767, 0.14971264067196077, 0.15098149677918804, 0.3906351273819324, 2.0204497705544195, 77.29799209102508, 73.3235877560031, 55.87420625071372, 54.00754244096818, 56.63038430675384, 69.75899265658471, 38.08650462858139, 3.8164387210722897, 0.10579475817540962, 0.16515799978327367, 1.3221606275727673, 4.370274937921955, 2.306415193503903, 1.810482843748985, 2.355027823678909, 0.18749248116247116, 0.8527465032473688, 0.571801652831416, 6.861953235441639, 95.59762970093759, 94.48337062712639, 92.20821549815517, 93.5348238483552, 105.10076384390555, 97.35221570537936, 97.923367715651, 96.11117778285858, 101.05254050224059, 97.02319945058515, 100.0474488350653, 95.85585501886185, 93.14202200981879, 88.64191024534165, 91.87684582125758, 89.76803841129427, 85.7185128427321, 92.9389295270366, 93.7680793577625, 97.9296435079267, 88.76501775556996, 86.23318272252237, 92.19986084968814, 90.02712665065643, 94.3219337155742, 86.30070240266862, 88.70451127329181, 86.68082714080812, 90.3380137105142, 85.2108169371082, 90.27402416352304, 87.09619829731604, 86.7681469455842, 84.54906602059641, 88.0779440172257, 86.9209389532766, 86.0074189401442, 85.98444954041513, 82.01417938355478, 87.16531045975225, 84.86001583837694, 81.95506142031762, 85.13310693925428, 81.18553161621094, 82.20762283571305, 78.53016545695644, 74.31291149508569, 74.14583421522572, 75.68061059521091, 72.74550099526682, 75.1157186877343, 80.07205701643421, 77.98754476731824, 74.67142397357573, 75.59334570361723, 74.529983305162, 71.77920941383609, 69.91172190635436, 73.58467640415316, 73.69732687550207, 73.8366965324648, 74.57669873391428, 74.5867713805168, 74.53374878052743, 74.48322080796765, 73.83388811542143, 77.37308979034424, 74.60595961539977, 77.1621996356595, 74.75594320604878, 79.63765451985022, 74.6843050372216, 77.71166093887823, 75.94280535174956, 76.60588202937957, 71.74775984979445, 72.92295686660275, 71.99002896585773, 76.13276573919481, 75.47553339312154, 77.13637475044497, 79.32046028875536, 71.50499651508947, 71.31331812950873, 75.03948350106516, 73.1520938873291, 74.5005419946486, 75.36681313668528, 73.86409036574825, 75.06185670052805, 82.3130169222432, 82.1325800495763, 78.93512664302703, 75.18843943072905, 77.38721816770493, 76.05544013361778, 78.19401833318895, 73.76868263367685, 75.63357353210449, 76.67580220007127, 84.54438271061068, 66.15845295690721, 63.18146028826314, 50.635857351364635, 41.48974518622122, 44.48302353582075, 9.482026888478188, 0.492484831521588, 0.4907053012040354, 0.2738236341505282, 0.20720067524140884, 0.3191530259866869, 0.3815465973269555, 0.19086455505701805, 0.20189157867383575, 0.15701260057187852, 0.20497414794179702, 0.29917798816196384, 50.34976359336607, 86.568968988234, 76.61159300035047, 44.05965466653147, 40.0430848521571, 69.45443630218506, 53.69799683170935, 79.48040669964206, 18.838955663865615, 0.6875783144947022, 0.38581808908812465, 0.1336637881374167, 0.36405582942308923, 0.20618344837379074, 0.16200184010930602, 0.17709515117589505, 0.23768502978547928, 0.1974400562504607, 0.0984684908161721, 0.09909644542682557, 0.19675505107208607, 0.11100567291460692, 0.25524073130180763], [0.027255705715487563, 0.008667209467309858, 0.056801366980277726, 0.051015376849400426, 0.018140672848770217, 0.040421395923101136, 0.06244044059947614, 0.026646901387721304, 0.07577197926659739, 0.06042965898110021, 0.019999774803798047, 0.059415335586715134, 0.05674550001839957, 0.1148100042595498, 0.17639660156301915, 7.743005829472696, 63.53490114212037, 51.38707753150694, 38.679061012883345, 42.82294311831075, 34.89139287702499, 41.3556432723999, 4.702729150172203, 0.0922347644283887, 0.1962084933033874, 0.058184232292396415, 0.07169931796529601, 0.04950166371981463, 0.32111467072559946, 0.027458594526134195, 0.04514877894713033, 0.15512820813925038, 0.16000982764507496, 0.3248312083944198, 15.824818149689706, 95.25908208662464, 81.14415845563336, 84.54438271061068, 85.22296843990203, 84.78815801682012, 82.70923906756987, 88.1372110305294, 87.40725009672104, 89.16549175016343, 86.3618835326164, 86.38383311610069, 83.87587747266217, 85.19983430062571, 82.3322286913472, 83.39131570631459, 79.26732786240117, 85.22378429289788, 85.53059208777644, 83.37578312043222, 82.97301061691778, 85.72366683713852, 81.8345348296627, 81.71849543048491, 83.44917066635625, 81.13535665696668, 87.55619818164458, 84.58068032418528, 84.5217820136778, 77.41234487102878, 82.118938046117, 77.72953910212364, 79.02291713222381, 79.10038394312706, 77.88109164084159, 80.44211695271154, 79.3769737981981, 79.55806178431358, 78.94254776739305, 76.35449732503584, 78.97169882251372, 76.37768637749457, 75.90628024070494, 75.98703399781259, 74.1016447928644, 72.64981869728335, 68.18303923453054, 66.01257216545844, 67.61786491640153, 71.39051821924025, 69.8377695391255, 73.19382790596255, 71.79510285777431, 73.37531597383561, 73.08022822103193, 71.07109608188753, 66.78146654559721, 66.91920449656826, 65.22723128718715, 62.191399143588164, 62.77150200259302, 63.70474369295182, 63.44702043840962, 65.47807470444711, 67.82721750197872, 67.93415700235676, 66.7162218401509, 65.52655127740675, 70.23678441201487, 70.22906518751576, 69.27036731473862, 69.19398307800293, 70.97295838017618, 69.71106129307901, 68.83933021176246, 66.29553979442966, 69.26154982659125, 68.7416475049911, 72.24374355808382, 71.62874729402604, 72.1762631016393, 68.38285261584868, 69.47394617142217, 72.02298472004553, 68.26950396260908, 65.85809353859194, 66.54665777760168, 68.32902985234415, 69.32699849528652, 69.41035670618858, 67.30210627278974, 69.3802329032652, 72.81554668180405, 72.62400165680917, 71.03315107284054, 71.76360622529062, 72.04509904307704, 69.25529756853658, 69.09079336350965, 70.45669601809594, 67.94573583910542, 74.65155324628277, 64.31521746420091, 53.769317288552564, 36.81038110486923, 17.21044836505767, 26.155280182438513, 23.191849108665224, 2.20767050500839, 0.029954819249049313, 0.09296332936613791, 0.15245237027204808, 0.057849087977721814, 0.09454918499555319, 0.014905559195716296, 0.08366290705218431, 0.04711426178654356, 0.10474735510445411, 0.22069169809260678, 23.170611435367217, 52.07613206678822, 65.1011113966665, 55.139032486946356, 37.8975248336792, 40.53585613927534, 35.865066359120036, 57.26076802899761, 20.35143336942119, 0.1532443826116862, 0.010026750274963919, 0.054017660102897117, 0.04139174204019289, 0.03295919392257929, 0.06556805583738512, 0.05665285317527671, 0.06309787044301629, 0.03592662400596085, 0.0525681030065302, 0.043647418985323566, 0.011102463167551304, 0.15348874933777318, 0.02243403067451812, 0.04210059170521075, 0.013865637930951292, 0.05254133206401622, 0.007854818710080919, 0.024617540221961758, 0.024616684118706374, 0.11367849239538755, 0.003258429060224444, 0.06411223214179759, 0.02608952454231199, 0.02010813602546771, 0.009837474846731751, 0.051288130963521625, 0.11841568134484753, 0.18273363490739178, 11.336054782713614, 74.9969885426183, 62.81833902482064, 53.755926316784276, 30.60101612921684, 41.85107392649497, 53.92248584378151, 6.538683252949869, 0.2903596419961222, 0.17173889423570327, 0.1173143303622642, 0.17085027820881338, 0.10565202067335767, 1.122753211567479, 0.29333944822992053, 0.13135961016579983, 0.11335603066629941, 0.0822997225388404, 0.5412464504761081, 24.953142366101666, 101.52880253330355, 82.76633308779809, 89.57853301878899, 89.00079142662787, 90.13683534437611, 86.3939057627032, 92.76722385037331, 92.47413650635751, 94.19960283464002, 90.86180702332528, 89.63095941851216, 89.72693197188839, 87.94150044841152, 85.2996821557322, 87.41343175211261, 84.1843326630131, 91.2825204480079, 90.06819386636057, 89.70336637189313, 87.65448493342247, 88.93125564821305, 83.36779717476138, 87.56099916273548, 84.53614573324882, 86.5055364178073, 87.13055041528519, 85.43017941136515, 87.29578418116417, 79.49393887673655, 83.15950362913071, 81.8769121170044, 82.88351781906621, 81.47929360789638, 82.6857989834201, 85.2515782079389, 82.05289317715554, 83.45197123865928, 82.36821251530802, 80.76077815025084, 80.76584585251348, 79.41928048287669, 78.42098236083984, 79.9359429267145, 74.57343532193092, 76.35448163555515, 71.38004549088018, 66.86860592134538, 70.32821486073156, 73.67669520839569, 73.73251053594774, 76.24345502545758, 74.81239395756876, 74.39441050252607, 78.48362261249174, 73.82117963606312, 69.63051934396067, 69.25273233844389, 68.24993918018957, 66.31881513903218, 66.6496592183267, 66.22473316807901, 67.49614592521422, 66.81697968513735, 68.9444968008226, 70.87116502946424, 69.33408229581772, 69.70444817696848, 72.46999371436335, 72.31883341266264, 72.8935940034928, 71.47542968873056, 73.82189350743448, 72.72637551830661, 71.14037298387098, 70.47090284286007, 72.00116065240675, 71.11925494286322, 73.95833707624867, 73.6495053383612, 72.01723452537291, 71.52070168525943, 71.4484594714257, 74.41210039200323, 72.31081608803042, 68.63772822964576, 69.13143696323519, 73.19012518851989, 71.8667096476401, 72.85105197660386, 68.54819620809248, 71.81050992781117, 74.55605922206756, 75.24809868104997, 74.12613607222035, 73.35689652350642, 74.06701026424285, 73.86455320542859, 71.87473481701267, 73.41981918581071, 70.99530020067769, 76.02991334853634, 72.16663760523643, 62.624460189573234, 56.697064599683216, 46.839481553723736, 37.283367956838305, 31.21496315925352, 6.107619183678781, 0.1235466777917839, 0.09619562285802058, 0.42203342481966943, 0.09365508377912546, 0.09700961426020631, 0.15820063440309418, 0.058913352643890735, 0.04797888010920537, 0.04350709849067273, 0.21333471060760562, 22.437063494036277, 53.329458775058875, 69.38588896105367, 63.01006055647328, 31.727148217539636, 39.493827512187345, 46.66508120875205, 63.629771509478175, 25.90867880851992, 0.32256288333765926, 0.07385234678945235, 0.04747182949476185, 0.045449330561584046, 0.07433358024084762, 0.03866237760972112, 0.06359431457014815, 0.025401451181800618, 0.018013653555704702, 0.03321827719769171, 0.05900398467577273, 0.030754833377056548, 0.03704798137468677, 0.007453744868642741, 0.11441369931544028, 0.05903665832574329, 0.09883976766779538, 0.16115139058280378, 0.13180122921063056, 0.19295015282207922, 0.20287630809170587, 0.15510597626768774, 0.20105951525751622, 0.15594568524149158, 0.09922253583828289, 0.16737090603959176, 0.1391269296648041, 0.391755576936468, 0.5763250036585716, 14.073794637956928, 83.90301242951425, 70.72994401378017, 54.092736321110884, 58.007524551883826, 57.05887971385833, 68.25686608591388, 12.498771798226143, 0.6855123898675365, 0.29051813026589735, 0.23387277709139934, 0.4770182517747726, 0.3354202901884433, 2.9057254089463145, 1.557000406807469, 0.29445649635407234, 0.3429851632925772, 0.6094276628667309, 0.7374500867820556, 27.914043511113814, 105.23086886252128, 86.04416370391847, 92.52598239529519, 92.007672555985, 94.12344609537433, 87.72711153953307, 96.09682975276824, 96.3712073910621, 98.5219527829078, 94.64363082762688, 94.14916899896438, 93.57450254501836, 91.77803347187658, 86.45494568732478, 91.33011448767878, 88.86113151427239, 93.0254727025186, 94.40697070091002, 89.50042293917748, 90.09914136702015, 90.70037795651345, 85.72405907415575, 89.93502939901045, 85.62638421212473, 88.65834497636365, 91.79056936694731, 87.89785231313398, 90.67895397063225, 81.16025586282053, 88.39900570531046, 84.9056722271827, 85.3387724968695, 84.87361861813454, 83.93431294348933, 87.17198633378553, 84.83128839923491, 86.6921078774237, 84.28847943582844, 81.6003457961544, 83.90516973310902, 83.7214929826798, 80.585691390499, 85.21714764256632, 77.15659849105343, 80.98043087990054, 76.17872807287401, 71.0701233340848, 74.92651139536213, 77.23186092991983, 76.46713210690406, 79.41712317928192, 78.87654212213333, 78.09570020244968, 78.57638666706701, 79.18222811914261, 71.93721817385766, 71.18360534791024, 70.81488686223184, 68.59580593724405, 68.48743084938296, 68.80366802215576, 69.52387794371575, 73.01303017523982, 75.11195321236887, 75.49933433532715, 73.24054333471483, 71.91506462712442, 76.76118435398226, 76.97214511133011, 75.96025989901635, 75.99782051578646, 77.20975445162865, 74.98210707018453, 74.52983425509545, 73.79146375963765, 75.36724459740424, 73.94417731992661, 77.67963870879143, 76.20595716661023, 74.82852274371733, 76.16999687687044, 73.65931910853233, 77.77834907654794, 75.19820613245811, 72.31312244169175, 70.1090092812815, 74.66638765027447, 74.25702556487053, 76.1784456622216, 73.26659571739935, 76.86815523332166, 79.4279489209575, 78.13164480270879, 75.03989142756309, 76.48530052554223, 76.67118164800829, 77.67959948508971, 75.64756854887932, 76.55961375082694, 72.86975383758545, 78.0752254301502, 72.07355191630703, 61.63773698191489, 49.81867467203448, 47.34073300515452, 47.15445964567123, 34.72844585295647, 5.225758091095956, 0.40296932682394987, 0.49641305460564555, 0.40068178828204837, 0.18013774597596738, 0.3664810186432254, 0.3225370508528525, 0.20811567533641093, 0.2741615402121698, 0.209362376180868, 0.3096768247985071, 27.621793593129805, 68.30749604009813, 78.12099164532077, 70.42517585139122, 51.475668184218875, 58.76146685692572, 51.54515297182145, 77.82580191089262, 31.72246098518372, 0.4862964345562843, 0.17232928755542926, 0.1622454560692272, 0.12074297218913994, 0.16072677868989207, 0.13529267492553881, 0.17213316904681344, 0.21931054881743847, 0.1622012681177547, 0.13068434962582204, 0.08888617112872102, 0.09040065800711032, 0.28448770063058026, 0.08058021521015514], [0.08668759071658697, 0.06977375596761703, 0.027075113893877116, 0.08328732478642657, 0.05339033368434157, 0.015194859851392047, 0.027148033972949754, 0.03717276560623319, 0.0798786012455821, 0.005463356989616108, 0.033733950131723, 0.07477228815156607, 0.053750739748319315, 0.06779701929659614, 0.074091213004243, 29.34347091182586, 65.85938007600846, 42.19289279753163, 49.56697617807696, 34.410129823992335, 45.501211997001406, 32.580008775957175, 0.5652345019963481, 0.2977119410230268, 0.30377776392044564, 0.059914032012344375, 0.05600129156523655, 0.11190754226258687, 0.06163452759445195, 0.11907923606134231, 0.2442495912433632, 0.09588479800450225, 0.07537048790724048, 0.40882064510257016, 35.090527688303304, 95.15558642725792, 84.25863804355745, 85.55294175301829, 83.95970636798491, 83.48939065010318, 85.96336287836876, 88.45773927627071, 89.62204779348066, 86.92142532717797, 85.90890469089632, 87.96184186012515, 84.27158970986643, 88.36615977748748, 79.29713787571077, 77.5554721586166, 86.09713139072542, 85.12357557973554, 85.05639322342412, 85.65972435858943, 82.57080293470814, 85.98270016331827, 82.62788911019602, 84.10988607714253, 80.29973491545647, 85.62919262916812, 81.29510694934477, 83.42773099099436, 79.04310164913055, 81.64320161265712, 79.33153706212198, 77.65870894155195, 78.41716197229202, 80.09973326037007, 81.4069180334768, 78.20834282905825, 77.5467017389113, 77.04266932702835, 78.50365023459159, 78.06941247755482, 79.75888713713616, 73.38115246065202, 73.79473501636137, 71.88575667719688, 66.9020558941749, 62.58702901101882, 60.296407976458156, 58.991980629582564, 62.98199599789035, 65.75199734780097, 71.58343607379545, 69.23850982419907, 71.50986809884348, 73.16686553339805, 72.68720672976586, 67.30660130900722, 70.77218009579566, 68.04031202870031, 64.6829749691871, 62.91513919830323, 64.12326451270812, 62.299362382581165, 60.86637935330791, 63.68949351772186, 63.527009333333666, 63.53382641269315, 65.23436215616042, 66.61634260608305, 67.59269898937595, 68.08566247263263, 69.92512072286299, 68.79750990098523, 67.51709138193439, 68.50332429332119, 70.22880631108438, 67.52892909511444, 66.6608222838371, 68.2515630414409, 65.76701610319077, 71.38472095612558, 67.44024430551838, 69.89363977985998, 69.19268869584607, 67.60623901121079, 69.22300861727807, 66.60668573071881, 66.04781858382687, 66.11421646610384, 67.3979611550608, 72.23021922572967, 69.65544992877592, 67.56839598378828, 69.74253439134168, 71.54578132014122, 72.1527994832685, 70.10881316277289, 72.60148725202008, 69.32471567584624, 69.85946809091877, 68.53220862727012, 71.61298721067368, 69.39713831870787, 74.8160025381273, 44.85339726171186, 45.05325771147206, 32.92055876024308, 23.169473948017245, 34.45790429269114, 19.02693525437386, 0.33384423282357956, 0.11962420036715847, 0.08490054507649715, 0.39428238005888083, 0.16533772401030988, 0.12953317994552274, 0.12305116446148004, 0.08002679329365492, 0.09361411339693493, 0.045261979929261634, 3.3370826753877827, 6.240183038096275, 28.273001178618404, 66.5109798985143, 29.294953153979396, 34.38753697179979, 21.384052230465798, 53.19435273447345, 19.64343378620763, 0.11819756845192564, 0.026224357932205164, 0.06110570093076076, 0.007607165945603723, 0.04489334225053749, 0.019679544305789377, 0.09901202253756985, 0.09553546191103036, 0.011209348712356822, 0.019511127536515557, 0.030052344157030026, 0.05758500980934309, 0.09113917442699594, 0.051562310001181985, 0.03635898870866626, 0.09988393018683119, 0.009175682132462821, 0.02396717370908347, 0.02782436703602153, 0.07257796718829101, 0.03123794182864649, 0.02584131971572436, 0.022197441656082388, 0.05071350373327733, 0.012031028764472615, 0.05427632969053042, 0.06304626676043676, 0.0466334956487821, 0.05758705526410092, 39.6855608109505, 74.94868847631639, 59.26795859490672, 51.46637608928066, 23.61628486264137, 60.31273680348551, 37.09847919402584, 0.4010648322441886, 0.41090100282622927, 0.34786575624058325, 0.030058097477341374, 0.14420813039666222, 0.06862199639961605, 0.053805702726446816, 0.0431272414542975, 0.22400967085794096, 0.16464677398964284, 0.2575562780182208, 0.6308409848040151, 46.51838456430743, 100.9555716668406, 85.44470002574306, 89.52583205315375, 85.72363545817714, 85.70846373035063, 88.92421107138358, 93.53603978310862, 92.62397104693999, 89.04543584392917, 90.78867835383262, 91.62069935952464, 86.31956115845712, 90.92879326112809, 82.5135127959713, 82.43072725111439, 88.97790831904258, 88.87910381440194, 89.4961161767283, 86.20300400641658, 86.57274230833977, 88.10412976049608, 85.08610125510924, 86.46202948785599, 82.30033197710591, 86.04684660511633, 82.67247861431491, 85.73863460171609, 79.65273995553294, 86.08491713000883, 81.0155596271638, 81.03464588042229, 79.77839700637325, 84.79601844664543, 83.67145922876175, 82.11643557394706, 81.5010392281317, 80.13832938286566, 81.46536134904431, 81.10180470251268, 81.3264702212426, 77.32805313602572, 77.68830714687225, 74.78369005264776, 69.12273714619299, 65.26319549929711, 64.55559599784114, 64.13978553587391, 66.83042557008805, 69.27783550754671, 74.60317473257743, 73.47423030484107, 74.59338449662732, 76.96386891026651, 76.20569044543852, 70.93401708910542, 73.2106391845211, 71.39000046637751, 67.60910234143658, 65.17632676709083, 67.47500434998544, 66.61725259596302, 64.7254071697112, 66.9288613719325, 64.98186349868774, 65.88108647254207, 66.86094945476901, 69.75355625152588, 71.20721801634758, 70.67756468249907, 72.16405668566304, 71.57805458191903, 72.66744582883774, 71.60491497285905, 71.0471539343557, 72.08672323534566, 70.40907059946369, 71.81713088866204, 68.71281808422458, 72.46168613433838, 69.82183687148556, 71.71139947829708, 69.87170588585639, 70.02542357290946, 73.44096860577984, 72.36911035353138, 66.78305902788716, 69.5121814358619, 70.82025266462757, 72.89263694517075, 72.31000807977492, 69.33232507398053, 70.76719868567683, 75.49672203679239, 73.94197294788977, 71.32412033696329, 74.91443049523139, 73.0255582255702, 72.79390304319321, 71.2230408576227, 73.5322892281317, 68.41522785925096, 76.79633663546655, 56.17688378980083, 57.56695216701877, 60.03168721352855, 41.53333448594616, 40.13395047956898, 27.293340198455322, 1.9261780549441616, 0.2210149259096192, 0.2746622552794795, 0.35477203887797176, 0.33143792000989764, 0.3195479902769289, 0.04135018943117992, 0.06412243260250938, 0.056778277090239915, 0.06793383493899338, 3.0653313090724335, 4.439261094216378, 24.460220067731797, 80.17882393252465, 20.67614874532146, 27.53823926371913, 34.20865335772115, 59.224616404502626, 25.954037097192582, 0.13748835952531907, 0.12367253071598469, 0.03074815117513701, 0.018292488492724877, 0.01024924231798298, 0.050766566813352614, 0.07694397887755787, 0.0442897224227988, 0.006646993476146412, 0.07491355476480338, 0.0338686628627681, 0.03191519611244721, 0.09254316078318704, 0.08972024935628138, 0.11000780508883538, 0.20232161446925134, 0.03975461597644514, 0.1055056059492692, 0.11949281628814437, 0.11547627858817579, 0.18425876274704936, 0.1348645849934509, 0.23010814442269265, 0.14308431005525973, 0.14649481092008854, 0.20883647214260795, 0.18902242003429323, 0.11660215204521535, 0.22320232143805874, 46.73291075614191, 89.25184665187713, 62.674329203944055, 66.25488050522344, 54.143009339609456, 68.91784037313154, 48.56787789252497, 0.7173867956284554, 1.1588407331897368, 0.5400804033683193, 0.14730170068721618, 0.4892004593726128, 0.2083075650396847, 0.2094520391115258, 0.20536633899375317, 1.1412819979652282, 0.45655331604423066, 0.8114884397195232, 0.9127463869029476, 49.23486125084662, 107.26340186211371, 90.2409585829704, 91.63065433502199, 89.65687059587049, 90.86997339802404, 93.8394037369759, 99.21665160886704, 97.97603730232485, 95.39241913826235, 93.76481594577913, 96.32370748827535, 88.94106941838419, 98.03520233400407, 86.72637370324905, 84.69741790525376, 94.32969216377505, 92.4060598496468, 92.80161519204417, 91.02445202489054, 89.06399649958458, 90.95709708429153, 89.15155949131136, 88.51530398091963, 87.1996468882407, 93.00309165831536, 88.19328523451283, 91.12627675456386, 83.77038140450755, 88.8459127180038, 87.86266080794796, 82.258495976848, 82.58980289582284, 88.10875815729942, 88.40951765737226, 83.45051996169552, 85.65239737110754, 82.4433651278096, 85.09036094911637, 83.41684249139603, 86.6619291613179, 79.24239727758592, 82.29891992384388, 78.32821046152424, 73.69735825446345, 69.98714124002765, 67.35256364268642, 66.05505927916496, 70.18577791029408, 73.80352112554735, 77.87094839157598, 76.76590688766973, 78.76269140551167, 81.05806243035101, 78.2568625480898, 72.51309271781676, 76.00094272244361, 74.87013909124559, 70.35724824474704, 68.93249434809532, 71.16351496788764, 69.82670061049923, 68.073424677695, 69.44535993760633, 69.31761618583434, 68.81522332468342, 71.1966746853244, 74.0934705734253, 76.33671329867455, 75.30214109728414, 77.00357898589104, 75.1750406142204, 73.29606056213379, 75.5797037001579, 76.80934321495795, 77.46540669471987, 72.95600675767469, 76.06943515039261, 70.49169924951369, 76.66540791911464, 71.22249172579858, 77.01375361411803, 74.29165224875175, 73.97833331938713, 76.7844989222865, 72.98325154089159, 70.31433751506191, 71.21820849757042, 74.09959731563445, 79.32472782750284, 75.88422083085584, 73.75496218281408, 75.78134490597633, 79.38775247143161, 76.23502192958709, 74.23312264104044, 76.55311046108123, 76.61011034442534, 74.17517354411464, 74.8615255663472, 75.16940024591263, 71.32757986745527, 81.69121142356627, 54.66317446001115, 53.711427027179354, 56.089289419112674, 48.27950131508612, 51.673971453020656, 28.704973766880652, 1.291784567217673, 0.5433498214810126, 0.630147951024194, 0.6648174745421256, 0.2764994873394889, 0.35708256005760164, 0.3316372254442784, 0.15774047603049587, 0.21362340318099146, 0.06734581649183266, 4.951489788870658, 10.817603738077226, 41.211978620098485, 86.13189143519249, 47.53311741736628, 49.693358867399155, 33.945423095457016, 72.68705767969932, 29.745074549028953, 0.22696663234983722, 0.28831035679867195, 0.17242146325447869, 0.11545347215066995, 0.10458785559861891, 0.15625313164726382, 0.26372371481791623, 0.16734110521933726, 0.1896632985482293, 0.21723483358660053, 0.30492692645038333, 0.20604498564235627, 0.17304891990798135, 0.21754122279103727], [0.05587850299273288, 0.03689634576139431, 0.048162622467404416, 0.04486072605716125, 0.046243602860598795, 0.0031569516173593944, 0.04478784428248483, 0.06059429893690733, 0.063569052820845, 0.058165317581545924, 0.11350924059027627, 0.03398294785931226, 0.0758739608910776, 0.17538476795438798, 1.582685312436473, 49.356603776254964, 57.219418402641054, 34.59950970065209, 39.79605790107481, 39.87499952316284, 50.70917821699574, 13.822324622061945, 0.12408985711273648, 0.04948316269644326, 0.32882065722538584, 0.07429855470094951, 0.07096495374195999, 0.07298297489122038, 0.14609762497486609, 0.09147898038668979, 0.18935864070250144, 0.18799566303289708, 0.3376987276058043, 3.1725475816957416, 69.16778164525186, 86.97450284034976, 76.55455389330464, 86.72708757462041, 80.49466102353989, 79.40416366823258, 86.96082161318871, 85.17484095788772, 87.10324287414552, 83.23169877452236, 89.81786820196336, 84.18467783158826, 78.94917657298427, 79.98254852910196, 76.53073726161834, 79.03486467176869, 87.44211212281259, 82.3581555581862, 85.6948217268913, 76.8915560937697, 82.22797209216704, 82.02956291937059, 82.51157514510616, 79.07132702489054, 80.31358088216474, 79.73183847242787, 80.77228638433641, 78.50353256348642, 84.1681646531628, 79.71794543727752, 77.50101397114416, 79.38622274706441, 75.5281323771323, 78.82610044171734, 77.33387393336143, 79.62256123942714, 77.47164326329386, 78.2205649345152, 78.2328890215966, 74.41890962662237, 71.59136710628387, 68.55110660676034, 63.627720109878055, 60.25933373358942, 57.39791762444281, 57.1955664696232, 56.87093934705181, 59.353674150282345, 63.28363018651163, 68.09522521111273, 73.70112372982886, 75.1477958310035, 71.75005051397508, 72.24898384463403, 71.55262977846208, 69.98236379315777, 70.53644564843947, 66.03729094228437, 64.35759082917245, 61.4765001112415, 61.30151533311414, 61.225719451904304, 57.06952894887617, 59.89436111142559, 59.82268764126686, 61.72373494794292, 62.595685681989124, 64.15624772348713, 66.97650248004545, 68.6592149734497, 69.06503123621788, 70.30515132411834, 71.5954149923017, 69.89267487679759, 68.69879953322872, 66.97077581959387, 66.1805437457177, 69.02566632916852, 65.51285436076503, 69.07305640559044, 68.3416755737797, 69.90246511274769, 70.55591629397485, 71.38383450046663, 68.09073017489526, 66.76711851550688, 65.21003561635172, 63.803006910508685, 67.8713990795997, 66.08133915931948, 72.81651942960679, 70.62045497279014, 66.00544129648517, 73.78873378999772, 71.94034038051483, 68.24954694317233, 69.46545031762892, 70.6748660918205, 66.84089045370779, 65.47736867781609, 66.88327558578985, 68.40212714287543, 68.27726241080993, 55.659330967933904, 50.25879206195955, 46.79451157969814, 25.495074679774625, 25.671595065824448, 34.29535735038019, 12.187300305212698, 0.14539259425815076, 0.17857777645751355, 1.2913229532780186, 0.13861423298235864, 0.14076038233695493, 0.12878085096036235, 0.06636020607284962, 0.07035491792785545, 0.07284609796178919, 0.19816537297541098, 0.15233757965747388, 0.22547438500388978, 53.44503141218617, 44.089315629774525, 29.733266253625196, 35.82663889854185, 48.373073377916896, 30.834508942019557, 0.1171111791665035, 0.06355365062312734, 0.020633861948285374, 0.02962443042516468, 0.03677855974303619, 0.03666720886324202, 0.03104537796799935, 0.03892918305111028, 0.046118853103008964, 0.0817157720185576, 0.01843310967688599, 0.09848788050153563, 0.07649203296750784, 0.12077220610433048, 0.022930426921154705, 0.01764717432970722, 0.07468848579352902, 0.03135421673857397, 0.030433587812548204, 0.022824051782428738, 0.08699414079948779, 0.021450090327210004, 0.0331851477254062, 0.06099323922347638, 0.02739891244639312, 0.0958683960620434, 0.04487564944992623, 0.09785525275454407, 2.5608961188024093, 61.56806392054404, 70.29686727831441, 56.65699366600283, 23.90754242097178, 35.03912110482493, 64.93752110388972, 15.655068755149843, 0.16288350005784344, 0.16426293329606134, 0.353013928378782, 0.08451439845826357, 0.04283543090305982, 0.07780048049866192, 0.014871568832125877, 0.5651100893174449, 0.2845381092159979, 0.5624851656536902, 0.4542867989549714, 5.693396791335076, 79.25485472525321, 86.33118706364786, 81.33563287796514, 90.06825662428334, 85.3616242254934, 85.12243024764523, 89.13193195096909, 91.20703835641184, 91.73121606149982, 87.82848127426641, 92.19949999163228, 88.77456480456938, 84.44737465150895, 83.38848375505017, 81.43430402201992, 82.96302426245906, 88.7536350373299, 88.20430709469704, 88.62885659740817, 81.29354584601619, 83.86437708331694, 86.69137831657164, 86.9514314589962, 82.47956860450007, 83.9263819110009, 79.60550677391791, 82.62520620899816, 80.59378716253465, 86.56772951925956, 82.28811771638932, 78.78405263347011, 82.17544371081938, 79.91611926786362, 81.2016760918402, 79.6558778516708, 81.9815609532018, 79.13509691915205, 82.53398756827079, 79.38146098967522, 79.63156700134277, 73.78242661876064, 70.43881785485053, 66.48168763806744, 61.86266922181653, 61.81347093274517, 60.12277249367007, 60.1275852418715, 61.93227168052428, 67.64549409189533, 70.09808940272178, 78.35168192463537, 74.98088329069077, 75.2651531465592, 74.02136172017744, 73.10810058347641, 73.95042957798128, 73.97029246053388, 69.96919247411913, 67.65271909775274, 64.17320020737188, 64.11585907782278, 61.846975818757095, 62.05646568729032, 61.38354386052778, 62.39269125846125, 62.54559309251847, 63.8715660187506, 68.56907890688989, 68.07936314613589, 71.67056760480328, 70.27081489562988, 70.47808862501576, 73.82853015776604, 74.65244754668205, 71.95528461087135, 69.75010456577425, 71.38378743202456, 71.05421420066588, 68.71146878888531, 70.09255886077881, 70.14860953054121, 70.69954564494472, 70.90474051813926, 73.40288239140665, 70.06029344374134, 70.21896900669222, 71.50271369564918, 65.87696798386114, 70.82810524971255, 70.00269736013105, 73.2354913219329, 74.25058503304759, 67.42595118861045, 74.2674433800482, 73.11687884792205, 71.73891098268571, 70.35813470040598, 74.27470760960733, 69.06941644607052, 70.97852030108052, 70.01135010873118, 71.37036508129489, 69.86098212580528, 65.29706908810523, 58.52275533060874, 65.12618710917812, 54.92405522254206, 40.77534037251627, 39.8347952288966, 21.501358555209254, 0.6206937518811996, 0.2735944512871004, 0.47750952863885515, 0.5456433048652065, 0.052906526177520716, 0.16584744827160913, 0.032255787312263445, 0.06405892774402615, 0.06782849018852558, 0.08072797058811111, 0.034851254895329475, 0.38964086783028423, 56.27563338125906, 52.64913151341101, 23.392758792446507, 36.69638918292138, 56.098416774503654, 39.216970935944595, 0.27588480903256324, 0.06227326106220003, 0.06853234879071675, 0.06669731540305, 0.02130124327396193, 0.03195119266878934, 0.09738406271583612, 0.0029636750555401973, 0.05884513634467318, 0.053332176119569814, 0.025470186505586873, 0.10684301160396108, 0.10637952840977138, 0.02416730268798288, 0.09773456326295292, 0.11234804281904814, 0.1244770149670301, 0.10291166288117248, 0.11808434065671698, 0.14488571984392984, 0.15452404055864583, 0.18855000425490642, 0.227797883712957, 0.11563342620408344, 0.13002191339769673, 0.22130815372351678, 0.2261126588188833, 0.39452945873621975, 3.494383202445123, 72.13006542574975, 76.1398103160243, 51.15986639453519, 56.17863316689768, 59.89884830290272, 76.1604106041693, 23.677852346051125, 0.3343401062152078, 0.5324431809206163, 0.9657019388771827, 0.253965869065254, 0.20803583365294243, 0.38867608734196235, 0.3689147574045966, 0.5674787106052522, 0.3225229241915288, 0.5956427993312959, 1.0167007184317036, 5.7692578819490254, 86.91824820733841, 89.39430713653566, 84.53032493591309, 95.7099977616341, 91.2016176408337, 88.0450745551817, 94.39798847321542, 93.38705247448337, 94.6595948742282, 91.23964894202449, 97.88200239981376, 93.18264992006364, 88.29369791092412, 86.55411889476161, 83.1644222813268, 85.5532947663338, 93.40205946276265, 91.1436136307255, 93.83201399157124, 84.43888664245605, 87.60691442797261, 88.70717848500898, 90.54573459009971, 85.69160538335001, 85.62874547896847, 82.66323751018894, 86.75543846622591, 82.5743095336422, 89.14964537466727, 88.22788053943266, 81.21080736960135, 85.01807951158094, 81.72036247868692, 88.61416339874269, 83.44348322960639, 87.11373913672664, 81.28320647824196, 84.0666223341419, 83.80702418665733, 82.91653633117676, 77.15841062607305, 75.67904164714199, 69.86131944964009, 64.38524746125745, 64.62770877345916, 61.7257785028027, 63.27942148331673, 65.20316362380981, 70.06774594706874, 72.96658146765925, 79.91335007452196, 76.79979616595854, 78.72658206570533, 76.83286959125151, 76.4657828115648, 75.45354458593553, 76.14970253359887, 72.63892235294466, 70.21172046661377, 66.68128921139625, 66.91055174796813, 68.12986758447462, 65.83765014525383, 66.7648200065859, 65.30300363417595, 68.06069266411566, 67.47245480937343, 70.95078914396225, 71.55242581521311, 75.83343398186469, 73.79420941875827, 76.0652695932696, 77.03225935659101, 77.00635602397304, 76.11711548220727, 72.55800385628977, 73.2229789610832, 75.69535086231848, 71.2850849090084, 74.33478263116653, 74.86059204224618, 73.23484020848429, 74.0320070328251, 79.06707517562374, 75.23032249942904, 74.59763634589412, 73.05954164074313, 66.64064561167072, 75.33914473748978, 71.63229311666181, 77.44817964492306, 76.76949193400722, 73.00498147164622, 78.32115019521406, 74.88316920495804, 75.67781002290788, 74.70238716371598, 75.6660742913523, 72.33344031918433, 71.20103636095601, 72.91526902106501, 73.45802307128906, 75.382353567308, 64.94791538484635, 60.473404930483916, 58.28140404916579, 57.007300546092374, 50.22045481589533, 51.392914018323346, 20.627907514572144, 0.43048107636071026, 4.611421765819673, 2.82486280606639, 0.4979426870422979, 0.2543090304900562, 0.7356912101949415, 0.14880524016916752, 0.2011180137314143, 0.19916007685805523, 0.4014669671174019, 0.3572203945969382, 0.4990368751027892, 70.3284502029419, 59.973663591569476, 44.5660287334073, 52.10249431671635, 65.07774975992018, 43.73785557285432, 0.40845525180620534, 0.14173700654458615, 0.21342176883932085, 0.14546500488875375, 0.09325195299161058, 0.14655166996582863, 0.16309395973240176, 0.0995098954186805, 0.1353816177335478, 0.18529011627599118, 0.14221161333543642, 0.2093265079442532, 0.3025786831013618, 0.1574740766157066], [0.0346616902689059, 0.05661883121055942, 0.08419029730101747, 0.1083878738685481, 0.06830145755121786, 0.020790320085061174, 0.04065742378213233, 0.008567813389574089, 0.07727183386563294, 0.08818637279252853, 0.03047730270472746, 0.006376145005736861, 0.15568869338641245, 0.23925647530103886, 7.63264504171187, 59.5923464528976, 43.000351921204604, 35.375935031521706, 44.294655630665446, 41.46289264002154, 30.228420380623113, 0.7945681315275931, 0.0811972683896461, 0.06467572428406247, 0.38838289017158173, 0.010706190782178555, 0.048396011153536464, 0.11057526939698767, 0.24809857019253317, 0.20349170652128037, 1.10277792859462, 3.5862002497719185, 0.43264083143684173, 19.67118259399168, 82.68306116903983, 83.28476059821345, 78.29637650520571, 76.80741340883317, 81.42870287741385, 85.12314411901659, 91.11177967440699, 88.6209334096601, 86.96792894794096, 85.11416189132198, 86.30055335260208, 82.76557999272501, 82.23843697578677, 82.89985056846373, 77.68088602250623, 82.82549027473696, 82.45002531236219, 84.3834400177002, 82.10332701283117, 82.58335451925956, 80.76154693480461, 77.01136881305327, 74.66601110273793, 76.6495458541378, 76.41817308241322, 77.13226410650438, 81.94234509621897, 80.28078202278384, 81.33781371578094, 78.48494052886963, 83.22338334975704, 79.02533331224996, 78.02672924533968, 72.79243607674876, 76.47759699052381, 77.91130173590876, 77.23251204336844, 73.76016324566257, 72.80887865251111, 68.34045179428594, 64.30517227418962, 59.68903287764519, 57.40948861645114, 56.14904280631773, 56.9309869120198, 55.58444899897422, 56.46415818122126, 56.25623726075696, 61.97267209329913, 66.34422425300845, 74.25214613637617, 71.22285258385443, 74.58120161487211, 70.66045530380742, 70.47835534618747, 69.61158998550908, 68.14257606383293, 65.28381932166316, 63.70229221159413, 62.476739806513635, 59.494840252783995, 55.65916622838667, 55.6464106805863, 54.56669199851252, 55.01141425101988, 56.638825247364665, 58.003100118329456, 63.20779508160007, 61.691889224513886, 66.02823811192667, 67.91810666361164, 66.4854766476539, 69.3638530854256, 71.77514583833756, 68.43407092555877, 68.13233083294284, 66.58300245961836, 66.52022884738061, 65.40739359394198, 66.38038066125685, 68.24003911787464, 70.17679568259948, 70.57632046361124, 73.03009248548939, 67.08787425871819, 65.93328537479525, 63.90092888186055, 67.79114738587411, 63.48836614239601, 66.47847913926648, 64.50675072208529, 71.93866945082142, 66.33634028896209, 66.48298986496465, 74.4252638663015, 68.62710645121913, 69.96841584482502, 72.79803722135483, 61.568448312820934, 64.77577432509392, 61.24710029171359, 71.1568469385947, 67.72143117843136, 64.39016611345353, 51.280467510223396, 51.07186801971928, 34.71184638238723, 25.891428224502075, 34.046384903692434, 32.55905155212649, 8.704330709672744, 1.2761805206537247, 0.19084892686336272, 2.0916632202363785, 1.2904599092660414, 0.22985414031051823, 0.06677559426715297, 0.05751241148719865, 0.12654100905262655, 0.007368401716267991, 0.5923255160450935, 0.2203190116392028, 11.59827405406583, 49.22799318067489, 41.536417468901604, 41.7287548126713, 37.969967088391705, 43.10608333156955, 0.066819483444335, 0.11690137066668081, 0.05776566483320729, 0.10380362671229149, 0.004397069851327087, 0.02992455494560061, 0.09782734417146254, 0.03873398767844324, 0.035335116028305025, 0.03453422856006411, 0.038062396699622754, 0.10263783241351766, 0.03849065517105403, 0.08018618554718072, 0.06139327501577716, 0.02148509288447038, 0.022136026302412636, 0.030575352382936308, 0.021263697304792946, 0.09597922600204907, 0.06735689412321776, 0.12074193797044216, 0.05238369798227664, 0.0442556468319268, 0.01635322692773996, 0.0497149923936494, 0.09276006325718858, 0.37464868036970017, 10.79692598312132, 70.10760507275982, 61.44994958754509, 49.14548612410023, 32.19651864420983, 50.984736488711455, 37.600993648652114, 0.5722145435790862, 0.25797100737690926, 0.07127102885034776, 0.24038222618401053, 0.09420727995494682, 0.02093572357308961, 0.06264218985433541, 0.4003342295125608, 0.19854985718284884, 4.872139259692162, 6.751625297531006, 0.383939610854272, 27.259945138808224, 87.14063875136837, 82.31003592091223, 80.48505906135806, 78.933942087235, 85.00850892836048, 86.30996704101564, 94.13188703598516, 90.64847715439336, 90.35458964686241, 89.00048548175444, 86.23489287591751, 88.09233127101776, 86.9643674358245, 85.45080323373118, 81.10151444711994, 86.42178596988802, 86.37410563807335, 87.43765631029683, 82.19958982160016, 87.15337860968806, 85.85258729996221, 81.71108215085923, 79.82592044338104, 81.68799508002498, 78.76110676796206, 78.81463927607383, 83.90807228703653, 83.23137714016823, 82.71475392003214, 80.04527507289764, 84.9117362114691, 82.08376223041166, 79.86212392007151, 80.94370180560698, 80.17048497353831, 81.17367036880987, 80.47187205283873, 77.45967218952795, 75.02190343795284, 69.73360707682949, 65.12867781423753, 62.72034645080567, 61.802813852986986, 59.37652587890626, 60.11663790672057, 58.2374813479762, 59.69061359282463, 60.21300269711403, 66.63754693923458, 70.4780807802754, 74.75209143853958, 73.73762530665245, 76.86641370096515, 75.17802161555137, 74.05871837369858, 71.93408027771981, 71.52179210416733, 70.79288236556515, 67.70276854115149, 66.00120513669907, 61.6538030101407, 58.965594845433394, 56.18241825411397, 55.75098891412058, 57.611227881523874, 59.53373447541268, 60.073201579432336, 63.97892913510723, 64.2483018290612, 67.93287830968058, 67.98722667078819, 67.50384946023264, 72.8044306847357, 71.72742628282117, 70.60201983298026, 70.20826878086214, 69.29776114802208, 71.8152089272776, 70.14241218566895, 68.1744021754111, 70.62561681193691, 72.3275802981469, 68.72154928022816, 72.89191522905904, 70.25605893904164, 69.84043675084268, 68.79365813347601, 72.569504245635, 65.8984939513668, 70.05884216677758, 68.16700458526611, 72.13017525211458, 69.61949748377647, 68.15092286755963, 74.44016102821597, 71.29017614549207, 72.33520538576188, 74.45287735231462, 64.30434465408325, 68.31128504968459, 64.39120161917903, 73.66824642304452, 70.56864046281385, 67.44148377449282, 61.932444264811856, 61.25812999663815, 60.45602098588021, 50.67510458730882, 44.680405047632036, 41.46676794175179, 15.912484103633513, 1.4596330831127784, 0.3134661408201341, 1.4945913298476128, 0.6504283208520182, 0.17323940000947446, 0.044212795703882174, 0.04442425512318169, 0.10691694674953338, 0.03323009410392373, 0.39066987713017776, 0.17272861854683969, 11.025233422556232, 55.86485924259309, 34.88602707462926, 51.047776822120916, 46.99886314330563, 50.77466218702255, 0.1433412712668219, 0.07421649136250058, 0.03386919529387548, 0.11584668976044464, 0.058480455510077946, 0.043879183565056136, 0.09662567397519466, 0.030077353097318165, 0.03879480356831224, 0.027073710037755872, 0.027140256265298496, 0.06674149569364325, 0.014495396678666434, 0.04804356474309199, 0.12814066192555812, 0.27417906830387734, 0.13421017736677202, 0.24186790049556764, 0.14537958608519647, 0.18944681742258612, 0.11650749422129124, 0.14339050007683618, 0.17597240335758657, 0.15475933680370932, 0.18501469234545387, 0.18041205141813527, 0.26870166221933983, 0.6731078941975871, 13.61111479420816, 83.52907719150667, 60.59435905948762, 50.71508138410507, 65.14421432249009, 62.247449813350556, 54.11777280992078, 1.6686732273909355, 0.25158874420148714, 0.23953712395121976, 0.6605106508058887, 0.23082181661119386, 0.14233098515579778, 0.24880173165471325, 0.5557198125508525, 0.7641337872032197, 4.874935909625023, 9.965691412648848, 0.518509635040837, 31.89042864307281, 96.44878402833017, 88.78129559178507, 83.77635125190982, 84.72791825571369, 92.21751151546356, 95.0092427961288, 100.37802619318809, 98.39807648812571, 96.98280688255065, 95.80756279730028, 92.46758614816974, 93.84589918198125, 90.45890900396532, 90.20321753717239, 86.3411263496645, 90.25805227218136, 91.26108861738636, 92.58256650740101, 84.6164837191182, 88.5879776554723, 90.06974712494882, 85.9723529508037, 82.487397655364, 84.92629604954874, 81.92779310287969, 81.60218931013539, 87.83952666867165, 86.92901119109123, 88.79554948499127, 83.78746724897816, 89.049256232477, 85.35610937303113, 84.8342223321238, 81.84197164350941, 82.81999111175537, 84.14594050376647, 83.7655725786763, 82.49354793179421, 79.111217529543, 74.80733410004648, 71.13981600730651, 67.6316559699274, 64.77090666371008, 62.76021342123709, 63.3438503357672, 61.80714022728705, 64.1941927325341, 62.84364615717242, 71.17827876921623, 73.70398706005466, 78.59461784362793, 77.00414380719586, 79.11353172794466, 75.35383793615526, 77.41421976397115, 75.56294733478178, 74.3278871044036, 71.09684251969861, 69.14674205164756, 66.87029254051947, 64.73450314614081, 62.863022665823664, 60.74973983149375, 60.23318721402077, 61.41602108555456, 64.89536346927767, 64.4674015045166, 69.51586846382388, 68.60725141340687, 71.54494193292433, 73.19685597573557, 73.51117118712395, 78.00995719048285, 76.83308139924081, 74.33676735047372, 74.10243711163922, 72.33366781665434, 75.36330653775123, 73.09916542422387, 70.86065307740243, 73.61583571280204, 74.23219696167978, 72.80356776329779, 77.4023271376087, 73.0079310940158, 72.60133820195352, 71.77668340744512, 74.25507222452472, 67.53766813585835, 73.30589786652597, 70.44397969399729, 75.88543676560926, 72.28047263237738, 72.241790217738, 80.56875459609493, 73.55135194716915, 75.13849981369512, 77.73082563954016, 67.22074062593522, 71.60939431959584, 65.71663718069753, 76.35135158415764, 73.77997905977311, 67.86353864977437, 63.85897521049746, 60.997468886836884, 60.08435287783223, 55.31847307758947, 55.238386123411125, 52.9014850431873, 15.725387046414038, 3.088954273731478, 2.8633733718625964, 5.57575265246053, 1.8092670315696349, 1.0457221514755681, 0.14986398900228162, 0.25612715631723404, 0.25096321808955363, 0.1587968346692862, 0.6699518570976873, 0.37337743406814916, 18.71761125902976, 66.08588126397902, 59.57118134344778, 60.957405797896854, 52.653469654821585, 61.25396836188532, 0.152812875927456, 0.165295543209199, 0.11316824719429978, 0.2693747470696127, 0.17886948741732106, 0.1290660501728135, 0.15621023072350412, 0.17781306749149678, 0.127789962195581, 0.19954123624390174, 0.1684006507838926, 0.24523562301070462, 0.10327921654548376, 0.1473138355199368], [0.02892086485160455, 0.02256656771585826, 0.0728664146135411, 0.04671163278661909, 0.09343165423600905, 0.035902863788989284, 0.03145078786708896, 0.06197637134802438, 0.06468498628706702, 0.08847444483469571, 0.014521457074630647, 0.04157820018008352, 0.10860218696536557, 0.20139895349500642, 22.378567226471443, 63.602224703758, 31.888702800196988, 55.82188183261503, 19.894304660058793, 48.68523128571049, 10.6276237387811, 0.5910182023240674, 0.3744097528678756, 0.07008012218941605, 0.1820419494423174, 0.3050575597632316, 0.07506148634298195, 0.09802384572404046, 0.1524246378891891, 0.217698561928926, 2.78318198457841, 2.9042743771306934, 0.27950472769237333, 48.067485440161924, 84.65387959634104, 74.84786787340718, 79.54989540961482, 82.54395038850846, 74.1726867614254, 82.99412081318518, 86.00082935825472, 80.18923390296199, 79.51166798991542, 78.58930695441462, 81.692639166309, 79.72688059653007, 80.91808088364141, 78.41330236004245, 76.24814618018367, 85.43166206729028, 81.14403293978783, 84.41393252341979, 81.69023867576354, 85.70855002249442, 78.14110555956441, 74.47884344285535, 71.53249232999741, 78.97787263316494, 74.31328804262223, 79.09820310531124, 78.41656577202582, 78.03964953268729, 78.91075303477626, 80.47894016388925, 79.72770429426625, 76.7248082930042, 76.99319254967475, 76.43503142941383, 74.91701141480478, 76.18836925875756, 73.77588410531321, 68.57692364723452, 63.24098225562804, 61.27465101980395, 57.42384449128182, 58.8748743457179, 56.70020249582107, 56.439380568842736, 54.69341201166953, 56.444122714381066, 57.29319426321215, 58.495608606646144, 62.09467349513885, 65.92090637453141, 66.0007344522784, 71.68722983329528, 71.52016824291599, 72.6810250743743, 71.83432655949747, 71.44528235158613, 69.05464480000158, 68.31858850294545, 64.27905321121216, 64.74124177809685, 60.908074148239635, 54.56831193739369, 52.50316442981843, 54.60799063405683, 52.17611328248055, 50.222867073551306, 52.78039363122756, 56.771840664648245, 59.49016086516842, 62.389376855665645, 65.22029261435232, 65.73152257550147, 68.06336772057318, 70.48419967774423, 73.14482965776998, 71.69574922130954, 64.73575830459595, 65.0817152761644, 65.27315047479445, 67.04191976977934, 67.1709265247468, 69.74336593381821, 69.28469181060791, 70.04083848768666, 69.97761772524926, 67.03038015673238, 64.26668990042903, 65.58788145742109, 65.75321328255438, 59.049192320915964, 68.65930911033385, 66.0603387894169, 70.9576532917638, 65.79864217389014, 68.0254384010069, 68.47822112421836, 69.48958858366936, 72.79036506529778, 65.0648686962743, 64.75306772416639, 64.3848434571297, 66.3936225829586, 69.76304838734289, 67.25867779024186, 57.32243161047659, 51.80400586897328, 46.692526032847745, 28.709827699968894, 35.09963150947325, 35.09759579935382, 25.67190101069789, 1.8556888954293345, 0.9511931528968196, 1.427370485278868, 0.2946246679752104, 0.02064352423223036, 0.08045516667827483, 0.04357364088777573, 0.06008359408306499, 0.0410526791857856, 0.07800226039703816, 0.013443596263025558, 0.4760725315540068, 44.24490428739979, 34.71388209250666, 19.24540342823152, 26.220201292345603, 49.54678381642988, 1.3090840582886052, 0.20088604230794216, 0.09858576355562096, 0.07445468341991787, 0.10282778391434301, 0.008364664109033203, 0.00656081241510448, 0.005010793899982087, 0.06864129415442867, 0.03192492925952519, 0.15166023535834205, 0.10804630590662842, 0.06487438620458688, 0.04421363457015926, 0.028139570082027106, 0.06390411286584793, 0.0457765382053631, 0.042492568252548095, 0.0268998789420772, 0.04068336734968809, 0.08883971555699265, 0.027709434695181348, 0.05896067389497354, 0.021824236178109725, 0.01722517288139751, 0.025524486817659873, 0.07330831711090381, 0.17403737251316348, 29.023077987855483, 74.31490405913323, 44.16861810991841, 44.38613707019437, 19.8111778689969, 62.61170071940269, 12.050367420719517, 0.29816901972216947, 0.08755176087781306, 0.04383127625671126, 0.18375432449242762, 0.3350960204918539, 0.05464450771649999, 0.10833885190227341, 0.30631587450062076, 0.5393095350553913, 4.926459183616023, 2.6443651366618375, 0.5670813867642034, 57.312511936310806, 89.06875041223343, 78.45935098586544, 83.45145348579653, 86.84478221401092, 82.92514201133483, 88.89990022105556, 91.47761129563855, 87.04935735271823, 86.21175873664119, 84.36264361104658, 85.90203269835442, 85.31475190193423, 87.85750681354155, 82.38544740984517, 83.03709430079307, 87.73547403274044, 85.54858007738667, 86.48746998079362, 86.09902197314848, 90.08626030337426, 81.47934852107879, 79.82850920769476, 78.29228939548616, 83.35487688741377, 77.84908510023548, 82.13102679098807, 82.3004339587304, 81.92261557425223, 78.73673315971129, 81.93103298064202, 83.56613574489471, 80.5760580493558, 78.90115891733478, 79.18939821181759, 76.58565044403076, 76.79482260058003, 76.38033789973106, 71.05719520199683, 65.64906650973906, 63.74938026551278, 61.32238626480103, 62.22481381508612, 58.697955839095584, 61.718933966852006, 58.649663617534024, 59.76815100639098, 60.176269700450284, 61.63420292638964, 64.39739504168111, 69.91914303072038, 70.96973419189453, 75.77804227029124, 72.99599139921128, 74.01995751165575, 74.90109443664551, 74.25855528923773, 73.99882378116732, 71.37306367197345, 69.26888465881348, 67.2384697391141, 61.27254078465124, 57.88388359931208, 57.648149151955884, 55.47697213388259, 55.252294848042155, 53.6137717769992, 55.60231931747929, 57.44053417636503, 59.50253594306208, 61.433989463313935, 64.46242401676794, 65.65116105541107, 70.27257211746709, 73.35915580872567, 73.75194980252174, 73.99698811192667, 67.6491105171942, 67.8099198495188, 69.17626965430476, 68.87479628286054, 69.83655360437209, 71.54315333212577, 70.64970016479492, 71.3533498394874, 72.06070223162251, 68.04665057889878, 68.51741344698014, 69.52365044624575, 70.90305389896517, 61.38315162351055, 71.46031287408644, 68.87423930629608, 72.17687499138617, 67.61616260774674, 68.42188019906321, 71.53164509804019, 71.19716890396612, 74.12042510124945, 68.46481446296939, 67.46808528900146, 67.11558188161543, 68.32251087311776, 71.75064671424128, 68.2368855322561, 61.85325945577314, 64.31832005900722, 64.42853081610896, 55.23754673619425, 49.36427593231202, 45.496112915777395, 33.35550254391086, 5.3413493594815655, 0.7029149044425257, 0.9877711546517188, 1.1794976505541033, 0.0980512333673335, 0.20788857623213725, 0.09995598075610977, 0.07110796703566467, 0.006185766410893731, 0.2326809894293547, 0.2432063786733535, 0.27312624899129717, 48.92610403799242, 35.67509812693442, 22.510239231971003, 37.99267368931925, 56.794927735482496, 2.336804001562057, 0.2783191300207569, 0.11502261664117537, 0.12051106205270176, 0.13760912562570266, 0.05021096920714744, 0.043479599764630686, 0.02043416197862356, 0.05299412450122257, 0.022745598633322987, 0.08729128332267846, 0.1051525466684853, 0.04265052409121587, 0.007517076399733103, 0.21370114578354746, 0.1637440313014292, 0.2298388032302741, 0.1917348002954837, 0.24973718629729366, 0.14514030618292673, 0.27449530939902034, 0.21113856635507078, 0.1441846421409038, 0.1292402126015194, 0.10680488340796963, 0.10791087688337411, 0.20262869315281992, 0.35150357071430455, 34.934601706843225, 87.01742925951558, 44.64652361408357, 77.81229326801916, 32.31763555157569, 72.05117871684413, 19.02558203666441, 1.055885870610514, 0.32504362925406427, 0.19955058251657795, 0.3172202167972442, 0.6133428624560756, 0.26252494043400215, 0.3090207471001533, 0.46702114144159906, 0.7297813015118723, 7.354852489886746, 6.110105476071758, 0.5154907583229004, 67.90434698904714, 95.55620947191792, 81.30863912643926, 85.17812005935177, 95.71683053047427, 92.1299171447754, 96.8199500729961, 98.279079621838, 92.28834167603524, 94.0871641712804, 89.84649365948093, 92.79220150363062, 90.42727116615542, 92.12867767580094, 86.81814147580056, 85.60891397537725, 91.84759278451243, 89.97846572629868, 92.39473204458915, 87.36074647595807, 92.63595781018658, 83.4065580368042, 80.70162880805232, 82.57164232192501, 87.61637518482824, 80.39001218734249, 85.32306732669954, 84.39179466616723, 85.4350745293402, 82.48465984098374, 86.8892462022843, 86.8266922427762, 84.51700456680791, 83.12763044911047, 84.37060602249639, 80.89122049270138, 81.4262866973877, 81.41072273254395, 75.32245897477674, 69.40745415226107, 66.97286252052554, 64.72734089820617, 66.9243271120133, 62.03370417318037, 64.70856451219129, 62.999081842360965, 62.25712237819549, 64.37533170946183, 64.588485071736, 67.44892058833953, 73.21212968518658, 72.18796745423349, 78.58678094802364, 79.07193106989708, 78.674971518978, 78.70358913175522, 77.70005856790851, 76.54092757932602, 76.47873447787377, 72.36416816711426, 70.00358381579, 69.22462463378906, 61.17739192901119, 60.41847213622063, 59.12417234912996, 58.03201975360994, 55.146465378422896, 60.827598879414225, 62.09241028754943, 64.24725847859537, 67.77280638294836, 69.98431713350358, 69.50570952507758, 75.4969887579641, 78.12316463839623, 79.45928081389397, 79.60855053317162, 70.08753822695824, 71.66106762424593, 70.64316549608785, 72.79060040750812, 71.11147296044135, 74.4335400673651, 73.16943076349074, 76.54490486268075, 76.72938177662512, 71.56118839017807, 71.8871138172765, 72.62289554842057, 71.7518626489947, 64.75850805159538, 75.70780046524541, 70.59160986254292, 77.57093414183586, 70.35028211532101, 74.48313451582386, 76.09271833973547, 75.01376844221546, 76.85658424131333, 70.3412998876264, 68.78217343361148, 68.3180707500827, 71.61272048950195, 73.47132775091356, 72.15430567341467, 65.37241781911543, 64.903816176999, 64.03288525919761, 57.048810989626, 59.655861393097915, 56.19840583493633, 42.300687374607215, 4.627969264984131, 2.7905084817640247, 5.856741935976091, 1.1509415699589638, 0.22499329710920013, 0.3947317978787807, 0.20005123629685373, 0.24158593417415697, 0.19580081195360233, 0.2755769336175534, 0.5317130071982261, 0.9164710451037654, 59.511094554778076, 54.36718848443801, 30.789472287701024, 41.45649525427049, 70.90125745342624, 2.451561030841643, 0.4675996297549817, 0.30196146138252755, 0.26821378678564106, 0.31241044101695864, 0.1670929693406628, 0.10871269514844303, 0.07563655024334308, 0.30053555725082276, 0.1748271478760627, 0.2454891368266075, 0.2663858703547909, 0.10770402548293914, 0.13956493277463222], [0.020266425112382542, 0.0616220978178805, 0.04980100108490837, 0.06289198431336591, 0.056896990074986414, 0.07393417264064474, 0.07580287559258361, 0.12581910141893934, 0.024578575074913043, 0.11598383482064932, 0.0475625955920306, 0.06646521374463074, 0.13994508092441868, 0.1706761923888999, 48.19616271603493, 47.92517008319978, 39.21193461264334, 34.714011530722345, 42.205201195132354, 39.87461905325613, 2.8408555349996014, 4.719159468527764, 0.4392001681750821, 0.10774115010374978, 0.14978379491836796, 0.02256109593285909, 0.43448544858444127, 0.11034116824908603, 0.6743395797187283, 0.43703413117797146, 2.984030381325753, 0.5152338430766137, 8.548541030576153, 71.87775504204535, 75.81231594085693, 78.49462878319525, 82.6733886041949, 66.1709810072376, 62.08116092989522, 78.75709810564595, 80.24967762731737, 80.69861642775997, 79.26752398090979, 79.36727769913213, 80.66171476917883, 78.54777689903014, 80.26599468723421, 75.46007925464262, 79.41378916463545, 80.87668418884277, 78.25968665461387, 80.35414603448685, 84.85966282506143, 82.00526775852327, 79.14276123046875, 78.76326407155683, 74.67012959141886, 72.36041838122954, 73.74976896470594, 77.28627989369055, 77.41322348194738, 74.73976735145816, 76.6674397068639, 79.67280680133452, 79.54937765675207, 80.46264663819345, 77.11971252195298, 71.95006001380183, 72.37279738149336, 70.11501835238549, 69.1721668551045, 61.80303742808681, 59.5689965832618, 58.651405149890536, 58.34369128750217, 55.92026664364723, 59.26231822659893, 57.30698531673801, 53.044961421720444, 54.577709936326556, 58.55247120703421, 57.71131500121086, 57.69597461146694, 67.23007586694533, 69.02465435766405, 66.98015028430571, 68.70283172976586, 68.47598537322014, 69.0562294375512, 68.04230459274785, 65.99017543177452, 64.57086578492196, 63.24735218478788, 59.760102302797385, 52.559458286531516, 53.883450415826616, 57.78977809413787, 56.88610715250815, 53.18616282555365, 55.15123105818226, 51.75195993915681, 51.86355137055921, 53.50609094865861, 53.94271350676014, 55.341881782777854, 57.244533338854396, 64.61661238824168, 67.59665273850965, 70.11996053880262, 70.97262105634137, 70.65852549768263, 64.55046161528557, 65.27542152712422, 65.40620903814992, 66.01510601658975, 65.81171543367448, 70.60157268278061, 68.58034395402478, 69.99297772684406, 69.26551926520564, 66.8302059173584, 62.02411790047923, 65.81391196097097, 62.623585501024806, 60.84876006649387, 67.49456913240495, 67.27561458464592, 67.82524062741187, 66.10857609779605, 69.4696472537133, 69.20439304844027, 71.8406415754749, 71.76501827855265, 64.83080125624134, 64.20665018020138, 61.928502282788685, 65.5493559375886, 68.6938730362923, 55.273346208756976, 55.242206511958955, 47.74784757244972, 36.50336542437154, 28.523193482429754, 30.441679646891934, 30.810696232703428, 17.203264544087073, 0.28084115275452215, 0.35583261100034563, 0.046250945813353025, 0.13892201646681757, 0.04325714315317812, 0.13983851809415127, 0.40608954165251027, 0.10424659407186894, 0.023457702256799228, 0.21279657980607403, 0.044238344736156926, 27.939644821228523, 39.49062685812674, 29.032980011355495, 22.737207181992073, 46.989202345571215, 3.335022205306638, 0.27233708649873734, 0.25056635390125936, 0.03775342960932082, 0.11484182755192442, 0.040990311967869925, 0.03181817682249652, 0.10527571828495111, 0.05573682269201644, 0.10341182636517672, 0.06894405210210432, 0.07086197620317822, 0.09690132007123002, 0.0798278785641155, 0.023620271859990976, 0.06245302359363245, 0.03898094378171429, 0.09406550772367947, 0.06689648294160444, 0.025604135063927502, 0.10047741084089203, 0.047396044246852405, 0.04207248010882928, 0.07259154226630926, 0.03843441282609298, 0.05122540368428154, 0.10162688746687867, 0.22782823611651698, 57.918455370010875, 55.72183785899993, 50.835859006451024, 30.33754268000203, 46.53236781397174, 46.07954586705854, 5.083953132552486, 8.145933756905219, 0.717759849804063, 0.15970700841036536, 0.17083878688994916, 0.06051668273885885, 0.37148651456640613, 0.027388208282871113, 0.36377620733072685, 0.29814039867731834, 5.451926858194414, 0.2990544641450528, 11.340472352120186, 81.75613449465844, 78.97591929281913, 80.52802470422561, 81.25938984655565, 75.73100520718482, 71.989762244686, 86.89975030960576, 86.4225390649611, 87.62534172304215, 83.5965576479512, 85.910763894358, 85.2004618798533, 87.9056578297769, 86.4698899176813, 80.60856665334394, 84.74073656143682, 86.00301804081087, 82.44861325910016, 82.5887046321746, 88.06410589525777, 83.011826392143, 84.51687120622205, 82.27816274089199, 83.2637837625319, 77.13871248306768, 79.70755900106123, 80.08529893813595, 79.78517486203103, 79.40829000165387, 80.56021951859998, 84.58997634149368, 82.03668594360352, 83.5749924567438, 81.05901164393272, 76.86111850123253, 76.18861244570824, 73.69733472024241, 70.9903109458185, 64.14501797768378, 63.17681620197912, 62.206033506701075, 61.43713128182196, 59.22724439251808, 59.968729249892704, 62.284873147164625, 56.52004018906624, 57.19827682741227, 61.17620737321916, 59.08922010852445, 62.10705249540268, 69.07522155392554, 72.80570153267153, 69.73024168322164, 72.92698906313989, 70.62641697545206, 72.40091293088852, 70.49030288573235, 69.24222038638207, 68.2968742616715, 67.50307283093854, 63.219319005166334, 56.68434827558456, 55.67570294103315, 59.63380198324881, 57.24153664804275, 57.13391857762491, 56.19963353680026, 55.64768152852213, 54.08817460460048, 55.48220457569246, 53.21353312461607, 56.009673149355, 57.46079321830504, 66.21976744744086, 69.31571775867094, 70.8243711533085, 71.18298561342301, 71.07156676630821, 67.17680223526494, 69.27170092059721, 66.56818374510735, 69.35356078609344, 69.70503653249433, 71.0789643564532, 69.07557456724106, 71.59467758670931, 71.98484359248992, 69.27017904097035, 68.37938524061634, 66.49984036722492, 66.55828368279242, 62.88654119737687, 69.7680062632407, 69.5182454201483, 70.12258852681806, 67.2369243252662, 71.18456240623229, 69.90692877000379, 71.86883557227351, 73.57505875249063, 68.07158116371401, 66.30525158297631, 66.48345270464498, 68.38202107337214, 71.36430894174885, 59.641046600957075, 62.82944717714864, 63.33771574881769, 55.65741685128982, 44.096250380239184, 43.386242543497396, 36.08702152006088, 23.94336738894063, 1.3465808139693354, 0.18030227101858587, 0.13057855288347892, 0.296283953132168, 0.10984273612379067, 0.0984314964303086, 0.297596721399215, 0.12435273252307408, 0.04634955282052679, 0.22882411977456463, 0.18935116368436045, 32.139475614793845, 40.344138529992875, 29.365041986588512, 32.5175783711095, 53.82778806071128, 4.505571213460738, 0.47930395170565576, 0.16462428164818596, 0.10781045041738019, 0.05826876626440114, 0.03413669787527573, 0.02327358643073709, 0.05105515596486869, 0.02521604449758607, 0.09933581725964624, 0.02687477807123815, 0.05454510397788498, 0.03587464877073804, 0.03513153199286711, 0.1662796597567297, 0.19518282414684374, 0.22231427231623282, 0.2375924863642262, 0.10035522747784854, 0.11940936633055249, 0.21464536447198163, 0.27187706602196543, 0.21296410791335568, 0.1458618537552895, 0.1165377317116626, 0.17676755665771424, 0.15220454082854334, 0.5232244465620287, 67.95410617705315, 64.81100113161149, 57.04203705633841, 53.58451481788389, 63.57638412906278, 53.816346506918634, 8.276340307727937, 12.005633769496797, 0.9156504117192761, 0.3546761246698518, 0.3587755837267445, 0.2221829342024942, 0.9255123534990896, 0.34007038260179184, 2.25904080656267, 1.8400301808311095, 9.868049890764299, 0.6974619518845313, 11.45162251687819, 92.24066134422057, 87.3555846368113, 89.3628889514554, 86.72830350937383, 82.19205102612896, 78.01621729327788, 91.05896103766658, 88.93947693609422, 92.23613492904171, 87.1989800853114, 91.0480490038472, 90.0358735361407, 90.4449139871905, 89.82801929596933, 86.63550023109683, 89.70901458494126, 88.98281128175798, 84.39267327708583, 85.1671060439079, 89.72875195164835, 86.39708288254278, 89.32539893734841, 85.38213037675428, 83.38238054706206, 80.31973115859493, 80.03350011764034, 84.05107405877884, 82.93633645580661, 83.49153226421726, 84.5105169665429, 86.93815815833308, 87.47185153345909, 88.50308972020304, 87.10379985070999, 79.66933158136185, 80.71630631723713, 76.05813087955599, 74.76449397302444, 67.17194634099161, 67.19731623126616, 65.6014960042892, 66.35354380453786, 64.32988712864538, 63.82485451236848, 66.8654994041689, 59.555111392851806, 61.9380493317881, 65.31696334961923, 63.11678040412165, 67.40073034840246, 72.05852139380671, 74.09095241177467, 71.23490210502379, 75.1463523987801, 72.86739257074171, 77.76418932022588, 74.59000341353878, 72.95025656300207, 70.78968955624488, 70.49984208999142, 67.91147785802042, 58.545524689459036, 60.293772143702355, 64.03470523895757, 60.959990639840406, 58.780945347201445, 60.120093514842374, 57.40946115985994, 57.761462503863925, 59.696297107204316, 58.68165839102961, 60.4579782485962, 62.358966719719675, 71.10735447176042, 72.85331910656345, 76.48790497933665, 78.88135094796458, 75.78163516136908, 69.43040786250945, 71.24619853112006, 69.55271520922261, 69.76790428161621, 72.14413104518768, 74.3860480093187, 73.16288825004332, 74.66412052031487, 77.37709845266035, 75.28088969569053, 70.80170769845286, 71.23596114497032, 67.07781730159637, 65.08816365272769, 73.55020661507884, 72.39808882436445, 73.74737631890082, 71.9446942114061, 75.1364052680231, 73.9381290251209, 77.89017585016067, 75.92313074296521, 70.35927218775596, 68.52676437747094, 67.076169906124, 70.43304412595688, 73.89175876494377, 62.22749671628399, 66.36306731931626, 65.53683573199858, 56.84339254133163, 51.07464113543111, 54.0023962913021, 47.23667252448298, 31.144805685166393, 1.1448835918018896, 0.4988650262596146, 0.15460034291590416, 0.29282803857518785, 0.21043663063356954, 0.3880996827877337, 1.765746863618974, 0.1650407576873418, 0.22091476757439876, 0.3935537997993731, 0.16713816852819535, 38.76388619022985, 55.97105741500855, 48.1455288394805, 33.67447360869377, 67.75106860745338, 5.480932295322419, 0.5699455750084693, 0.30166026625421744, 0.37209279654968175, 0.14526836544034943, 0.11936328614190703, 0.5343388501674898, 0.23872231283495504, 0.19299735915997338, 0.18984178171282817, 0.1971068846121911, 0.40410696739150637, 0.14022490219964137, 0.2039350109595445], [0.005548904591705651, 0.010497290096546133, 0.028347128198572227, 0.0914584339085606, 0.001138355064247134, 0.06043536250569648, 0.04770406904900747, 0.04951191780668113, 0.059624477590043704, 0.05528982187951765, 0.028924101573084633, 0.05036445875321666, 0.084363027145305, 2.6032947340319237, 62.261888057954856, 34.884269852792066, 51.29092454910279, 17.970338944465883, 53.17919277375745, 20.41508755376262, 0.6908883046238654, 4.925175097680861, 0.06106573412375105, 0.10613184452297227, 0.25410371892634903, 0.0917167817392657, 0.054389883073106896, 0.1417143916290614, 0.22709467628550148, 1.404590952780939, 3.0130272382690064, 0.17081824041181998, 45.90349420424431, 77.43954258580362, 66.85625045530259, 65.9208671508297, 71.00495707604193, 62.13508175265405, 74.02152645972468, 80.67889475053357, 85.31770936904415, 79.54989540961482, 82.11770642188289, 82.68790137383246, 82.31972417523785, 86.77144173652896, 78.09419401230352, 75.67438971611762, 81.40734164945542, 78.96528966965215, 75.75722232941659, 79.84100587906377, 81.7570915529805, 74.97249726326235, 80.16941808885144, 78.32853994061871, 76.9281518074774, 73.90029384243873, 73.08252672995292, 77.61457443237305, 74.89502260761877, 76.85474072733234, 79.75920092674994, 81.81533875003939, 74.1049474285495, 74.32790279388428, 72.50965672154581, 72.56682918917748, 69.71338333622103, 67.74655788175522, 62.39726866445234, 62.129821854252974, 57.698508462598255, 56.79247233175463, 57.093604456993845, 55.073654420914195, 53.48153691137991, 56.23634692161315, 56.23422491934992, 53.86497212994484, 57.99438461180657, 55.28530943778254, 54.32245385262274, 64.02290282710906, 70.8353381003103, 69.29953405933996, 69.92245351114582, 68.72063144560784, 69.52645101854878, 66.9068725647465, 66.42070262662827, 63.837574758837306, 64.16600658047584, 61.835444050450484, 53.5908337562315, 50.7520850243107, 54.600781317680116, 52.217659027345725, 50.62390196707941, 54.17576505291847, 52.934032870877175, 52.699855604479396, 54.70161368769985, 53.56114533639724, 54.8307930269549, 53.77232182410456, 56.84002714772379, 61.2501322838568, 64.81005191802979, 68.4973701353996, 69.59256649017334, 69.18257682554184, 68.10576069739558, 64.99624290773946, 66.59883314563383, 68.42857960731753, 66.97701238816785, 66.55911522526895, 69.46738012375371, 70.19228120003977, 64.8235252595717, 65.05411355726181, 61.754894256591804, 63.80328147642074, 56.23504077234576, 61.70922610067553, 68.7389567590529, 65.79484139719318, 65.08258604234265, 66.91913389390515, 68.49107865364321, 68.26431074450093, 71.46727900351249, 68.80029478380757, 68.33539193676364, 63.25981355482533, 63.6737608909607, 71.50651054997599, 55.20956846975512, 54.38150121319679, 45.919317045519435, 49.178104554453206, 37.01562304650584, 24.781817159345074, 25.39165158425608, 20.6409062493232, 8.809169780823494, 0.21441897016859826, 1.2482264013059678, 0.44157387628670663, 0.1019501535882873, 0.13007852729530106, 0.2839220825943255, 0.14481914680330985, 0.17215791368676772, 0.21991077870611223, 0.3533347966449876, 20.206256643418346, 41.914969336602, 23.445444068601056, 30.625154395257276, 46.76900048409739, 7.532704520610071, 0.658995206317594, 0.16943572750014646, 0.07611757685099879, 0.16280673804783052, 0.04781290716041, 0.1424073947653655, 0.1557435759253079, 0.042982136740559534, 0.09927292144106281, 0.03214001227470656, 0.05735675774274334, 0.06496809407948487, 0.018141281888670018, 0.022114227270527233, 0.03313236426742327, 0.032953057558305805, 0.11238720523373735, 0.03313670798595394, 0.09719135329848337, 0.12450016614410186, 0.020096079716759346, 0.06528975141625251, 0.03082713867056995, 0.061080217015959566, 0.06645169229276719, 0.17020635066493867, 4.411112204674752, 70.49375457148399, 50.60623168945313, 58.60700391953992, 14.857454780609379, 62.451597413709095, 21.19025380380692, 0.4348607090932708, 6.00972859128829, 0.05364305459924283, 0.3414231406584863, 0.06474342347393114, 0.027107400669445916, 0.3524226617188223, 0.2877663117983649, 0.13325115785964076, 1.6283185347434015, 1.900712924618875, 0.6895537181727348, 52.88507384638633, 83.11841287920552, 74.8234550414547, 71.34531682537448, 77.65356279188588, 70.9396182337115, 78.88233154050766, 86.20723232146233, 86.4262810061055, 83.43718390310966, 85.63633134288173, 83.84037217786236, 83.43479910204488, 88.45646058359455, 80.75934256276777, 79.76330372595018, 87.61553579761137, 83.9070838497531, 79.93359734935146, 82.7571076731528, 83.92881378050774, 77.50875672986432, 82.78274428459906, 82.48839393738778, 81.87539808211788, 78.82144851069297, 78.52771005322857, 79.95153827051963, 78.76584499113022, 80.17594491281818, 81.27882911312966, 81.52278484836702, 76.71944249060847, 78.15071536648658, 77.20849144843318, 76.71000526797387, 72.98056079495338, 69.76543318840766, 65.75153058575046, 65.62905457711989, 62.00952276106804, 60.604317957355136, 59.09756298988097, 59.28736256014917, 57.119452876429406, 59.322048079582956, 58.82987299273091, 57.35794867238691, 61.41773908369003, 57.93922039770312, 58.42722208269181, 66.7542060728996, 73.78507029625678, 72.30086111253308, 73.80024986882364, 69.79722792102446, 72.01037037757136, 69.56828701880671, 71.37012189434421, 67.3520694240447, 68.07893168541693, 65.61188636287567, 58.605336912216686, 56.060691418186316, 58.13510748647875, 54.563377595716915, 53.70711634235998, 55.58377827367475, 55.65140385781565, 53.97734019064135, 57.9732548036883, 55.4555481480014, 57.1418966785554, 56.02349558184224, 56.73795530872961, 61.116308858317716, 65.16354768506943, 70.19453264051869, 70.83979391282605, 72.47990162141862, 68.81834553134057, 70.86599534557712, 69.5565434425108, 71.73097210545694, 69.15539480024769, 69.98624693962836, 69.86422984830796, 71.94065417012861, 70.27499614223358, 67.63160105674498, 65.27254250741774, 67.73172347776352, 61.97429595455047, 63.77205156510877, 70.86299865476548, 67.76084315392279, 66.17860609485258, 67.54819577740085, 68.54698027333906, 71.44432529326409, 71.63530549695416, 73.81416643819502, 70.2696381845782, 68.38435880599484, 66.26218395848429, 75.61895093610211, 57.09345148455713, 60.779875401527654, 60.08234070193384, 50.138634174100815, 36.422395936904415, 37.06739441041024, 38.530230599064986, 26.977760022686375, 14.723330313159575, 0.45842744289867343, 0.050535579812863184, 0.5801173227448618, 0.41915115690039056, 0.15064760501826965, 0.19886154771572162, 0.11672365359000622, 0.17476909373316074, 0.16406604869952127, 0.2622281579721359, 20.940520417305734, 52.0805408108619, 22.044183208096413, 37.161990211855986, 58.81053178541122, 9.639096240843497, 0.7725954428315164, 0.12461775297959968, 0.15591881087710782, 0.0249165041191924, 0.07259144267487912, 0.029343373833164096, 0.2127273101359606, 0.0693621292650219, 0.022798414650042693, 0.027847631211062113, 0.05336166667421499, 0.02582723327401665, 0.009031143366178919, 0.08108816214747007, 0.13269156127447082, 0.09584209626360286, 0.23706074473598313, 0.1987376100113315, 0.1423297134498435, 0.2571345925811799, 0.1570010939312558, 0.23798757322853614, 0.30390367813168034, 0.15599768728979174, 0.3591805990905531, 0.4050726978288543, 4.847611208115855, 85.22844406866258, 50.186628295529275, 69.32271526705834, 28.3770538145496, 73.6471519162578, 24.71106544617684, 0.7587584853172303, 11.895891735630652, 0.1564305116452517, 0.7638484960602177, 0.27040590141569415, 0.39062305383624574, 0.5612632860579799, 0.8038618199286923, 0.9674155856332473, 6.658862713844546, 7.03359027062693, 0.8409697093790578, 59.59116189710556, 94.77472428352603, 82.07733738806941, 78.61604182950913, 83.98563323482391, 78.38990149959442, 85.29716399408157, 93.18911398610761, 92.94677426738124, 87.80508825855871, 87.98906310912102, 88.31341174341019, 89.62861384114912, 95.5552210346345, 86.57013000980501, 84.73664945171726, 88.10465535809918, 89.49063270322739, 83.20545811806956, 85.32265155546128, 86.69172348514681, 80.01487670406219, 88.45107124697778, 87.00033557030463, 84.80987225809406, 79.19726648638326, 80.37476985685288, 81.98909974867298, 81.09946696988999, 82.88605167019753, 85.30358883642381, 87.08751416975453, 83.6124667813701, 81.8697577138101, 82.37105231131278, 80.52697350901943, 75.18323052314021, 73.98667227837348, 70.01763374574723, 67.54006862640381, 64.7602338944712, 63.040768792552335, 63.2413980268663, 62.36427368656282, 59.734430390019575, 63.33389143789969, 64.5217655551049, 60.794490152789706, 65.9705400466919, 59.45776600991527, 61.804669134078495, 70.85851930802869, 78.45093357947566, 73.62673205714073, 77.98068846425703, 74.54825370542466, 76.09591114905574, 74.70940036158409, 73.20665405642602, 69.46496394372755, 69.59669282359462, 66.3924458719069, 61.90018277014456, 59.106455003061605, 59.23985481262208, 59.096307831425825, 57.80225515365601, 60.0032578745196, 60.64642852352512, 57.62024148817986, 63.33114577877907, 58.402381712390536, 59.695065482970215, 60.48355994686004, 61.07039359308059, 66.93541173012026, 69.86717947067754, 74.29550401626095, 76.71142516597625, 75.68308168841948, 74.46456601542812, 72.98806036672285, 72.58263634097192, 74.23153015875047, 71.73047788681524, 74.06541778195289, 72.6224091745192, 76.62492905893635, 72.37941834234422, 70.5753477158085, 68.39314491518083, 70.66476206625663, 61.667676433440185, 66.29019752625497, 72.6545020072691, 71.79177668786818, 70.81404747501497, 74.04167175292969, 74.55264676001765, 74.53512945482808, 76.29283766592704, 77.04196330039733, 74.52557456108832, 70.103102191802, 69.2946546308456, 76.8808009547572, 61.336004734039314, 64.73009440206712, 61.121243199994495, 57.97210554922781, 51.09722222051313, 46.90346325597456, 49.12746283315843, 39.13980614754462, 17.039513434133223, 1.2079686647461307, 2.8868448349737355, 0.4179678574925469, 0.259969761414874, 0.21492247379595236, 1.0099789404099988, 0.2388199890453008, 0.28896052029825026, 0.2683101606465155, 0.42085901203174747, 29.20581533062843, 61.99381366852791, 35.50838562750047, 45.64917948938186, 65.3809646637209, 11.887782235299388, 1.0192788188015263, 0.36344283650959697, 0.4690049720867988, 0.32005164712186784, 0.3241018314034708, 0.24754462733624444, 0.38518894704118856, 0.1446217106234643, 0.16231769816048686, 0.10363012311920043, 0.12973057016009285, 0.20347617025817596, 0.12410332493844534], [0.04010828046668922, 0.08568626017339769, 0.07533837350145464, 0.06008445593197981, 0.08873292290034795, 0.019852603567884337, 0.05781844829119021, 0.009047435183498648, 0.08987152873868905, 0.05369871088694181, 0.019717503962437474, 0.020327340593681704, 0.3416454287305955, 9.470442168174252, 65.62192370814662, 30.880610519839873, 47.112984503469164, 26.79534431426756, 64.48376171050533, 6.5770616839008955, 0.4476081976486791, 0.9835872114185364, 0.09765309747308494, 0.09756477519629464, 0.04108289752395884, 0.07494949194933138, 0.22879695429676966, 0.1612868962148505, 0.10134510500656982, 1.0476830914135904, 0.15799749852909198, 28.934028417833392, 70.57975645988219, 65.11935826270812, 68.81194422321936, 64.42628329800021, 70.52664756774902, 63.008891690161924, 72.53929415056783, 76.95897379229146, 79.3148591441493, 77.22138820155975, 80.3691687122468, 78.73881201590262, 84.57570675880679, 79.36360636065083, 77.88962671833654, 79.94364646173294, 81.5513083242601, 75.51602009804019, 74.12126448846634, 79.98443126678467, 76.49429059797718, 76.55217693698022, 76.53513031621134, 77.53322447499922, 75.92003991526943, 73.74459928081882, 73.52794324198078, 75.43187741310366, 75.66947890866187, 74.72153617489722, 76.7771170216222, 74.7775633104386, 75.23127171301073, 74.58886592618882, 72.43396282196045, 69.51560174265217, 65.76901651197865, 60.91698185090096, 63.52440880190942, 60.39099201079338, 56.010614518196356, 57.35559525028352, 55.87295501462875, 55.4705237573193, 52.56711475310787, 56.885495262761275, 54.83318175038984, 54.591422542448974, 55.43924285519508, 56.79706150485624, 56.2300201385252, 60.183345656241144, 67.66661213290307, 66.48397045750772, 65.97254830022013, 68.8741216351909, 68.46381818094562, 67.92086801221295, 66.52906202500867, 66.4764944199593, 62.90357212866507, 58.8993146342616, 52.202859924685576, 53.78910956844207, 54.48398097868889, 54.488695667636016, 52.50669848534369, 51.93853532114337, 50.17050735412106, 50.138238014713416, 50.45169030466388, 51.568408704573116, 54.15828697143063, 51.192206336605935, 50.87829512934531, 53.00582793451125, 59.12543142995527, 64.53646659851074, 65.98913208130868, 67.23246851275044, 67.27978014176892, 67.20905980756207, 65.68687423583, 68.3847902667138, 64.28791384543142, 68.79794920644453, 67.67725744555074, 67.48693620004963, 65.56792836035451, 63.27502450635357, 64.85633196369295, 60.26135767659834, 64.31062436872914, 58.06900770433488, 64.00877837211856, 67.59908460801648, 65.86823678785755, 65.35216662191576, 66.78143516663583, 68.97558550680839, 69.20693474431192, 66.48015791370024, 67.51625983945786, 63.622715165538175, 63.259876312748084, 70.0277691502725, 58.772649534287, 52.725013686764626, 53.0896842864252, 45.1094848878922, 35.96179200756934, 28.971702783338486, 31.669554095114435, 23.398293256759647, 24.182945759065692, 4.9687869510343, 2.3116807303121014, 1.0529476476292456, 0.3645464014862815, 0.2111902926117182, 0.08138818516125602, 0.12502115955876728, 0.10633162493186613, 0.2749129192483041, 0.23451382414467875, 8.091733955567884, 42.68333811913767, 35.65083826741865, 30.464639240695586, 43.38069238970357, 12.79706608864569, 0.6619643179639694, 0.1776416170140428, 0.10828534832164165, 0.05423726686727136, 0.028431581731344906, 0.06882523952592766, 0.05225452023648447, 0.03978908993303776, 0.16334523657156577, 0.013309499275149598, 0.050864744811288776, 0.008561939410414667, 0.021342606276213642, 0.034457305671587106, 0.03985575873464827, 0.03007881632525354, 0.029301420943210685, 0.032807933692369735, 0.09978588625428178, 0.04040919597290697, 0.06015236579602765, 0.07543159874096032, 0.03768775289157226, 0.010520189422212783, 0.09219545645699387, 0.3872421546088111, 12.75006530746337, 73.7762684975901, 43.21463884845857, 47.42254187983852, 27.413900129256714, 74.9286530094762, 6.835933212311038, 0.5182814021264354, 1.0433134484675624, 0.07674072042948778, 0.1056395334401919, 0.0739808427169919, 0.05577209338005032, 0.2537906341134541, 0.3927365984887846, 0.3021777739688274, 1.2602228479039286, 0.06630350024469438, 35.64648443652738, 81.58493088137719, 69.11559843247937, 73.76326976283904, 71.57058638911094, 76.61930438010924, 70.22663331800892, 81.13130877094885, 81.46323542441093, 83.21714678118306, 80.71068163841002, 82.98746062863259, 83.56609652119299, 86.03562078168316, 83.03401916257798, 82.08671185278124, 83.78681613552956, 85.01080743728146, 79.08980923314249, 79.1188112381966, 83.97494869847452, 78.52863573258924, 78.47566804578229, 80.13684672694053, 81.7765857327369, 81.29970396718672, 78.32651599760979, 77.95997050500686, 79.79211745723602, 77.25183363883727, 79.40639157449046, 81.12946525696786, 77.00879573822021, 75.27899126852714, 77.44648518100863, 72.89826946873819, 73.08441731237596, 70.00357597104966, 65.52555891775316, 67.75131179440406, 63.522165206170854, 60.33321549815517, 60.64697373297907, 59.833858551517615, 59.61283691467778, 56.61020763458745, 60.9237910855201, 59.03158480121244, 58.60415235642464, 58.87898106728831, 59.66913469376103, 56.88892733666205, 64.67272581592684, 69.42587360259026, 69.66113736552578, 69.99572338596468, 70.92288540255639, 75.50003251721783, 69.2816480513542, 68.34550380706787, 69.48879626489455, 67.6743313574022, 62.06942127596948, 57.424475992879565, 57.41266573629072, 57.67147156500048, 55.5428248067056, 53.768348463120006, 55.13888343687981, 53.7812138372852, 54.013594658144065, 54.23769927793934, 54.40303894781298, 56.00493492618684, 54.47068414380474, 54.417081033029866, 55.313483822730284, 59.73645433302849, 64.01943152950656, 69.45959814133184, 69.13829326629639, 68.33261489868164, 70.50984413393083, 68.8782322791315, 70.56401991075086, 66.80434180844215, 68.19713623292985, 67.00437484248992, 70.13425365571054, 68.87977769297939, 65.5997113258608, 66.62842350621378, 66.23596683625253, 68.69702662191084, 63.77414218841061, 66.44733552009829, 69.16712268706291, 68.21208046328637, 65.66792134315737, 66.6830542779738, 70.80703427714687, 69.00546612278109, 69.52258356155889, 71.0737632936047, 67.78954705884381, 67.87095192940005, 73.39266853947794, 61.693473862063506, 56.60675987120598, 61.287512471598966, 49.84163230465305, 33.51029888276131, 29.472154071254117, 42.24289517248831, 30.77548315448146, 32.26282042841758, 8.405695173048205, 0.9417640814377416, 0.2104157011114782, 0.19581521440657879, 0.11173718729086461, 0.08034146390855312, 0.11468582140702395, 0.025411500340147365, 0.29800048037882776, 0.42371746993833975, 7.258175380768315, 47.79884622943017, 32.41974857545669, 37.13585153702767, 54.086974359327755, 15.641204157183248, 0.5289783797437145, 0.08000791688720066, 0.11090935267988714, 0.01141322864925549, 0.020385741391369415, 0.04328875960181317, 0.0947973668395031, 0.048832612322463144, 0.039797026603933305, 0.08129122141267985, 0.018452836440936215, 0.02987486839805159, 0.0411553924242335, 0.15552516425809554, 0.11428141891355477, 0.18705375792999424, 0.1783120665218561, 0.2218705388687311, 0.28412037679264623, 0.17021486956265666, 0.12718925733239422, 0.2199782097652074, 0.10478722998091292, 0.17270292395785933, 0.24715769164744886, 0.6052604509938149, 15.633936005253947, 89.1919049909038, 43.89424047162456, 65.67161229348952, 44.28512819351689, 85.27257857784149, 9.392954764827605, 1.0538653596754999, 3.4312791305203594, 0.2828680068975495, 0.3835406016197897, 0.1668871674806841, 0.22027094728283345, 0.7303067152538608, 0.6631478931634658, 0.32519369055667235, 2.95438731389661, 0.42450608084759406, 38.24566656543363, 93.27125626225626, 77.30890412484446, 83.10226055883592, 75.47527451669016, 82.08059295531243, 77.92255893830331, 88.7691911574333, 88.52598851726901, 88.87737012678578, 86.95416927337648, 87.38938762295632, 86.33299135392713, 92.01183026836765, 86.70877010591569, 86.02623847223099, 86.1010302266767, 87.51182048551499, 80.87276181867047, 78.49671548412692, 85.22982474296325, 80.42980071037047, 82.15972285116874, 81.78145731649091, 83.84815416028424, 83.61503985620315, 77.39861657542568, 81.50199628645375, 83.26579201606013, 82.19921327406361, 81.99508528555594, 85.12135551821801, 81.41896755464616, 80.58460881633144, 80.24835186619913, 77.94868192365094, 75.2728331473566, 73.53262655196652, 67.40101275905486, 72.85496650203582, 68.30072602918072, 64.5437269056997, 62.90588632706673, 63.33811583057527, 61.29533367772257, 60.81671037981587, 63.71831117137786, 61.84453218213974, 60.49611545378163, 62.32932929069766, 61.74231521544918, 62.848776617357814, 66.605893411944, 74.25404456353958, 73.41530846011254, 75.15315378865888, 76.1431678648918, 77.64933447684012, 73.00720153316375, 72.77910786290323, 73.99605458782565, 71.39869243867936, 66.95227792186122, 60.46597988374772, 59.3725799745129, 58.24159983665713, 61.08140760852445, 57.23479017134636, 58.31921961999709, 56.267353257825306, 57.238634094115234, 58.078605744146536, 57.414128780365, 60.55139341662007, 56.75548438102969, 57.214280097715324, 58.74763265732796, 65.68036310134396, 70.21404250975579, 73.47794871176444, 72.63748676546159, 71.51155471801758, 72.0099546063331, 72.1451900851342, 73.9871664970152, 69.55361735436225, 73.34241513283023, 71.19264248878726, 74.42764866736628, 72.62210322964576, 70.00088522511145, 70.38447733848326, 67.15802977162024, 72.51633259557909, 64.48480506097117, 69.18249053339805, 72.62903798011043, 71.20663750556209, 70.47416625484344, 72.49731694498371, 73.25945700368574, 71.4342212677002, 72.26133931067683, 74.40491460984754, 68.7861507169662, 69.18964493659236, 75.84451075523131, 66.16172421363093, 62.099654905257694, 62.066173553466804, 57.6080507616843, 53.97897974137337, 45.90680860703992, 51.21856074179373, 43.082376526248076, 41.35972645974929, 8.934063930665294, 5.644335785219747, 2.0271088519404015, 0.5023150266178193, 0.40684416890144354, 0.28888240997349063, 0.19106580635472653, 0.18096498303836395, 0.451384857897797, 0.9003583161580948, 12.56237106938516, 57.662626620261904, 52.988746012410815, 45.29424813485915, 60.026705803409705, 20.906054550601592, 0.9048704514580389, 0.3452715986678678, 0.3324253460572612, 0.2354378334336704, 0.16546988949900673, 0.15219608321785927, 0.16924012993131915, 0.18375266974251117, 0.34270020922826183, 0.14729950967575275, 0.3916546984785988, 0.08912391885514222, 0.24694899397511638], [0.034581982650824135, 0.03930874514363466, 0.028714884876183448, 0.03511768495363574, 0.07724678279050896, 0.03993012288945817, 0.019761391224399693, 0.11110318058560933, 0.23352693435886215, 0.059021696628582095, 0.11557806102979569, 0.19977651716720676, 0.32469610112809366, 26.621702947924216, 54.85717881110407, 51.2872532106215, 34.594226268029985, 31.572102808183242, 60.89373788525982, 0.3184146091582314, 0.16540805088175883, 0.07942553684716264, 0.1058510962813612, 0.08677334659883092, 0.05292986504613392, 0.07537470139082401, 0.09272659287577675, 0.15178861637269297, 1.249203684349214, 0.35502965892514876, 8.894118512830428, 66.44976738960513, 61.994864863734094, 67.54821146688154, 68.08203820259341, 73.8844866906443, 61.45720597236388, 61.230034059093846, 68.86834006155692, 74.23881792253064, 75.45949874385711, 75.68602346604871, 78.36956793262114, 79.66239683089718, 83.17444785948723, 76.9476616767145, 79.31693015560028, 82.38633386550411, 78.56432145641696, 78.23536795954551, 84.81599900030321, 78.68051775040166, 72.84114406954858, 72.46550652288622, 79.62159633636475, 76.43447445284936, 79.46762761762066, 74.94522110108407, 74.17100798699164, 72.26718364223358, 71.87080460210001, 74.71122034134405, 73.80224243287118, 73.2415396167386, 68.79600371083906, 70.27355271001016, 67.75549304100775, 66.29510048897036, 64.35860672304707, 64.77773551018008, 54.793538355058246, 55.32957338517713, 55.62417868644961, 53.56713479565036, 56.440949516911665, 56.2590652896512, 53.675345143964215, 51.96335607959379, 54.98600905941379, 53.413444565188506, 56.261348109091486, 54.07042195720058, 53.72142514874859, 58.335599437836684, 65.12802277841877, 63.08541320985364, 67.23406883978075, 65.6602099633986, 67.049560546875, 65.10960725045973, 64.14853634372835, 64.54911624231647, 61.49008327914823, 57.0332823261138, 52.96494114783503, 50.95345950895741, 54.19600448300762, 50.674900624059866, 51.12990340878887, 51.12343149800455, 50.46334366644583, 48.664725134449625, 51.2866295537641, 50.46469688415528, 51.29782399823589, 52.37304372172202, 54.14000088168729, 52.698537688101496, 53.45257020765736, 55.87023288972917, 62.999105376581994, 68.31023385447841, 68.75216730179326, 66.54687743033132, 66.1747621720837, 67.10965125791489, 66.97964822092365, 67.13910041316863, 60.65621875947522, 65.854657542321, 67.24337270182949, 64.97417565315001, 65.18806642101657, 60.35142314049506, 63.00818566353091, 61.095328100266, 62.60906096427672, 67.40025181924143, 67.62685498883648, 64.55752188159575, 61.91239703086115, 70.04603955053514, 70.2244681696738, 66.33084897072085, 66.8599453280049, 69.47804112588206, 63.32847464469172, 68.52022186402353, 61.53585341668899, 50.75750573988884, 54.44934252769717, 49.56964338979414, 33.96092430237801, 30.783204340165664, 35.38352481780514, 25.74030322413291, 24.733215070539906, 27.591397185479444, 0.7995389389895624, 2.7867680115084497, 1.3286070429509687, 0.13954282347713748, 0.35926284629010385, 0.0327229515589293, 0.09590979545347153, 0.11287744021824292, 0.21668427683893712, 1.63138423475527, 39.4722976223115, 29.70510755815814, 26.539535176369455, 46.515811489474395, 18.476261938771895, 0.4615996291320171, 0.16033550694344506, 0.05418654418580475, 0.07022366408378848, 0.04685648852178166, 0.03084372830457024, 0.08595041495056883, 0.12420656294712137, 0.038730080630029404, 0.027707165159705668, 0.05828914803362662, 0.13709816030196606, 0.036136581892928774, 0.03256479653740122, 0.06730342118610298, 0.02189319366739402, 0.04582787375716914, 0.016689740624579213, 0.0778391143126834, 0.018523774267504775, 0.16114451111324374, 0.11412489182886579, 0.08228839209844029, 0.04672688942763113, 0.17007861316444414, 0.2833776698718148, 33.34353539251512, 65.92945714150706, 61.84779951649328, 38.8791528824837, 39.88333063740885, 67.99548718237108, 0.1909801424030335, 0.10929341277768535, 0.06753980527601897, 0.18344680147786296, 0.13538152580299687, 0.22816517690737403, 0.10390285042024429, 0.2417851170344699, 0.30922544579352107, 3.058821645475203, 0.5621888428445786, 12.172159956347558, 78.47985713712632, 64.50582504272461, 73.68670509707543, 76.32083554421702, 78.53458204577046, 68.96693275820824, 70.8501568148213, 73.13522769558814, 77.92459857079291, 80.11856063719719, 80.29832286219444, 80.42309345737581, 82.55069686520486, 85.48116237886491, 80.08820149206346, 84.17012583824896, 88.54152894789173, 81.42511783107635, 81.48828368033134, 87.46344981654998, 82.58104032085788, 74.6946208707748, 74.71777854427215, 81.13784343965592, 80.05348067129813, 79.52552180136405, 77.56352086221018, 78.87385137619512, 78.43255335284819, 76.08392438580914, 77.14544327028337, 77.49060400070684, 74.56840684337001, 70.5261141254056, 72.54358522353634, 70.27552173983666, 70.08029753162016, 66.37208092597224, 67.8685514388546, 56.95343071414579, 60.20155722095121, 57.270064046306, 58.133307118569654, 57.26581611940938, 57.41964755519744, 58.7098406207177, 55.67268663837064, 58.00064863697175, 56.393759481368534, 60.565415889986106, 58.932862666345414, 54.80396009260609, 61.810156529949566, 66.34579320107737, 66.21968115529707, 65.33008367784562, 67.99876628383514, 70.2421502144106, 66.68394857837309, 65.72907109414378, 67.04042926911386, 65.92675855082851, 61.2814445649424, 54.43770093302573, 55.18649708840155, 57.36864889821699, 52.17123385398619, 52.381857287499216, 54.55160656282979, 52.789838698602495, 51.56851068619759, 55.68825452558456, 53.57903526675317, 55.63335703265283, 54.635886530722345, 55.256946779066524, 56.17513833507415, 55.93941957719865, 56.40329084088726, 64.03031218436458, 68.26732312479328, 69.49000435490763, 71.1814872680172, 69.45197305371686, 72.07960805585309, 69.98346990154636, 69.11413146603492, 62.853965913095784, 63.44813046916839, 71.97783039462182, 68.235881405492, 69.17681094138854, 64.33552749695318, 67.18465482034992, 65.9784318554786, 66.23201308711883, 67.48783050044891, 68.13008723720428, 66.65108696106942, 64.34496864195793, 70.61382616719892, 68.48341434232651, 67.9463477288523, 70.86062169844105, 72.89168773158904, 66.85314393812611, 72.45621050557783, 62.76397105186217, 56.106049706858975, 61.032283844486365, 56.44429137629848, 35.4192772219258, 33.362284321938795, 39.86258914393764, 35.60011417635026, 31.878481103527932, 35.94544356869113, 3.1173720907780433, 1.0640113055706024, 0.34680291649795353, 0.1916384417563677, 0.26324521630041064, 0.05936560881955009, 0.033497738411589977, 0.08714047125390462, 0.14000388583348644, 1.6085955092022497, 42.78149151032971, 34.259914813503144, 27.90178414314024, 55.306027397032715, 25.14462071080362, 0.6219601258635521, 0.13612596408253716, 0.08137670150327106, 0.02267123639373289, 0.007285744180872797, 0.018684493768359386, 0.06516077285332066, 0.01473713955361276, 0.09648064587024913, 0.07994919624780455, 0.09910963746088167, 0.01194026554003358, 0.0240784996910201, 0.1569041378435589, 0.2223030108237459, 0.1474476557585501, 0.15722514400559087, 0.24635063334097787, 0.15346346843627193, 0.11806791573162041, 0.32536912469133256, 0.30233378011372786, 0.295243667018029, 0.291111572615562, 0.45094279452197017, 0.5387544583889746, 38.20254402775919, 74.17763679258286, 65.89846257240542, 47.21957491290185, 47.702705014136534, 78.41745222768476, 0.7906259656433137, 0.21613667719066146, 0.3097114213291676, 0.6035594906537765, 0.17343067684240882, 0.3863161688129748, 0.25206318245299403, 0.31740049260758585, 0.4256648654418607, 3.5559251904487614, 0.9180737010413601, 14.82953436913029, 89.9367081734442, 75.61254178324054, 81.99353987170805, 81.80287345763176, 79.77617694485573, 75.09652260811099, 78.96233220254221, 79.54864025115967, 85.66190519640523, 87.99989669553696, 85.82406382406913, 87.7803224132907, 88.53242120435162, 92.32179164886476, 82.50009828998198, 89.85935903364613, 92.83013866793726, 85.63411912610455, 83.82923264657298, 90.40293678160637, 87.15994465735652, 74.46537402368362, 79.1700295479067, 86.10257564052459, 82.25390680374639, 84.52895995109313, 79.31062298436319, 80.09835258606942, 79.12418488533267, 78.22024330016106, 79.13494786908551, 79.94890243776383, 79.6678489254367, 74.91463445848035, 77.67915233489006, 72.51936066535212, 71.80370853793237, 70.18264785889657, 72.87437438964844, 61.0898446267651, 62.8000960811492, 60.33604744941958, 61.44801585905014, 62.382304822244954, 63.43106423654864, 63.27029412792575, 60.63731685761483, 60.60688318744783, 60.47327549226823, 62.94890296074652, 60.12549854093983, 56.77564928608557, 66.02175051166166, 72.13866326116747, 69.25998087852233, 71.83788807161393, 73.15651047614314, 73.90880538571265, 69.8427587939847, 68.82651190603934, 70.56727547799387, 66.43692554966097, 62.447624052724535, 57.544335780605195, 56.91179867713683, 60.293450509348226, 56.02630399888562, 57.47905185145717, 58.18690238460418, 57.040781897883264, 53.994041642835064, 58.41805942596928, 56.065060938558275, 59.523183299649155, 59.2943286895752, 61.668872756342736, 59.63329599749658, 60.433114344073886, 60.26197348871539, 67.29485773271131, 73.56049106967065, 74.72701964839813, 75.06344918281802, 72.16935188539567, 74.85872499404415, 74.57021113364928, 72.26940370375111, 64.74952974627095, 68.60677288424584, 76.15001632321265, 72.27755438896918, 71.42627454573109, 64.73038857983005, 70.05004821285125, 68.9775937603366, 67.23504943232383, 71.40671760805192, 73.05751769773423, 71.66921046472365, 69.68307910426971, 76.6642939659857, 72.73883296597388, 69.97394638676798, 74.74111664679744, 76.26571839855563, 69.32712401113203, 75.27036989888838, 65.38900160020398, 60.434969625165394, 62.70215842031664, 62.91391541880947, 52.944674261154674, 50.44529291891283, 52.76596323136361, 47.86694642036192, 44.47519448495681, 44.516971649662146, 3.2576252616220907, 7.533799842480691, 3.9898398422425796, 0.3416577780679349, 0.7391357866506423, 0.14559818161351068, 0.2874293556857494, 0.17111454789917316, 0.25803462331814153, 3.197523028619828, 57.36513053217242, 43.04234481626942, 40.595142764429895, 64.24980801920738, 28.341191584064116, 0.7538816921653286, 0.3569402209212703, 0.2559851695813479, 0.22706882847893625, 0.16430123769227536, 0.15451598131368238, 0.19579201726423157, 0.2721537156931816, 0.2441047086951233, 0.18512332361311684, 0.2095517837592671, 0.3625500376426405, 0.1290771124824401], [0.1320815101386078, 0.10604483991741173, 0.06393399795577412, 0.05492533256690349, 0.005439771057647323, 0.04621419274518567, 0.021534275729209188, 0.037831861691008654, 0.075475066569784, 0.023540596800645994, 0.04279377487217707, 0.07540681579660985, 0.10505612684233535, 44.827078157855624, 49.18736134805987, 42.84763051617531, 24.383775034258445, 43.32132731714557, 40.58028090384699, 0.11681978230274494, 0.24394641960820845, 0.214067887394659, 0.17713645863677227, 0.13000250072969546, 0.08692507031223468, 0.2672298540992122, 0.1254932229377089, 1.4887200319959273, 3.005925296775757, 0.4479813743983546, 38.64289675989459, 70.03810851804673, 61.07568094807287, 73.42391414027061, 74.14067237607895, 68.23116671654486, 59.177159647787775, 61.670531918925626, 69.29663150541245, 73.00241624155353, 72.18737909870764, 73.63877373356974, 75.73590816990023, 78.95758613463371, 81.04074124367007, 76.57462073910621, 81.6575574874878, 82.5034793730705, 76.06046076743834, 79.40729371963009, 77.95232188317084, 78.23358720348728, 74.73367983295073, 73.11635325031897, 78.16619303918655, 75.45870642508231, 74.6942521679786, 74.68930998156148, 75.45560775264617, 76.53121579077937, 72.01983897916733, 73.36252120233351, 71.82718000104352, 71.97147615494268, 71.56342414117628, 69.55875565928798, 70.53932466814595, 61.63515606234151, 63.00096458004367, 58.13886119473366, 54.49292398268177, 54.957917044239665, 55.09728277883222, 54.52639748973232, 54.59035173539193, 54.88668287954023, 54.14932827795706, 55.45736028302101, 52.42085349175238, 51.89093735910232, 57.97136029889507, 56.27176984663933, 53.369463028446326, 50.28109073638917, 54.304297201095096, 59.60216806780908, 60.64726006600165, 61.74870083408972, 64.21160413372901, 61.43443269114341, 64.67966448876166, 63.697785408266135, 62.24936392999465, 55.05050066978701, 47.9824641443068, 52.1080836942119, 53.41800235932874, 51.381962760802246, 47.95872596002395, 52.23896141975157, 48.84337340631793, 46.63567912194037, 50.94889387007683, 48.45131681811426, 51.46690560925392, 50.58083434258738, 50.140932683021795, 53.19705524752217, 57.22832218293221, 55.069590845415675, 56.44177713701802, 61.594649745572006, 64.72789787477063, 66.66676859701833, 66.22348585436421, 67.61700199496362, 68.59028324004143, 68.37182291092412, 62.593995140444854, 58.57218896189044, 69.10437260904621, 64.3864594736407, 64.61689872126426, 64.65400434309437, 60.780910907253144, 62.285708612011334, 60.08426266331827, 67.49522024585356, 63.475112453583755, 68.8084376242853, 62.07256701684768, 65.89366159131451, 68.36311524914157, 70.92159102039953, 65.60526147965463, 68.75460701604044, 66.43690986018028, 67.52575982001521, 60.833945274353034, 50.98280668258668, 56.27201695596018, 54.54440509119342, 37.01091620229906, 30.51234506791638, 42.49917891717727, 29.80304914136087, 25.474111572388683, 33.32156227480981, 15.757507335755134, 0.3401161027291129, 0.25137397911279435, 0.19249834480785555, 0.07138526022073723, 0.06094589115931623, 0.059167184386282205, 0.03644066900315304, 0.03593434234179797, 0.03200670914544213, 23.94654254759512, 33.33744787400769, 33.572138970898045, 52.56632243433307, 21.300040944930046, 0.115991365464945, 0.05102769937366248, 0.12293923901574266, 0.04908177858939575, 0.10292957401684216, 0.036795233646708156, 0.04584734388176472, 0.04604513629249508, 0.0993699234940352, 0.07014458082736501, 0.07865074616406234, 0.06894665680104686, 0.13070370100678938, 0.01809758231824925, 0.087884028532332, 0.032189244915160446, 0.08504131373258368, 0.023036108750309196, 0.047785887239320625, 0.06227364410616218, 0.02077541967493392, 0.022626508350273775, 0.021131342209334818, 0.06940439433580445, 0.02150161740099711, 0.022192433356277408, 51.20868421369984, 59.60354481973956, 58.04786220673592, 26.05903502433531, 48.087575820184526, 46.5111634808202, 0.12239862608933642, 0.15134200243459595, 0.2030804705235266, 0.07772272257434745, 0.14642376392599077, 0.16894293378197378, 0.4582717125454257, 0.41410410836819683, 2.3486775063699294, 4.968078963218197, 0.4957271301217618, 41.74568768470518, 76.00290390752977, 67.56476386900871, 75.51602794278052, 76.52694825203189, 70.86870962573637, 64.38148983063238, 70.17463053426435, 74.30747509002686, 76.99162360160582, 75.57877802079724, 75.15797830397084, 77.6253217266452, 81.87414292366275, 84.51618871381207, 80.77241190018194, 84.54612424296718, 86.03328304906046, 77.23361815175703, 82.35177778428601, 81.2503448609383, 78.88785423771029, 76.23110740415513, 76.60762356173608, 80.38171245205788, 79.22669210741597, 76.2478873037523, 78.933714589765, 78.33972654035016, 81.4479774044406, 76.05408299353816, 77.48047644092192, 74.42396948414465, 72.27465183504167, 73.90729135082614, 73.63678901426255, 70.64209076666063, 66.36127871851768, 65.58935626860588, 60.29412515701787, 61.31042695814564, 59.82795538440828, 60.33341946140413, 59.63470412838844, 58.22334512587517, 59.753599013051684, 59.67628517458516, 57.603736154494754, 57.36499324921639, 55.04170671586068, 62.01138196452972, 58.57212228159751, 55.09161495393323, 50.853658722293, 55.80291325046171, 61.001473626782825, 61.22966535629765, 66.73248398688533, 67.5261285228114, 63.275828592238895, 66.36248680853075, 66.22454489431074, 63.00841708337108, 57.312566849493216, 52.51470404286539, 54.74071187357749, 56.563464749243956, 52.89970036475889, 50.23595210044615, 55.22919993246756, 53.799354799332164, 51.995719555885564, 53.736581187094416, 51.57307632507817, 53.728057876709975, 54.28866263358824, 54.471652969237304, 53.4939355234946, 59.36153065773749, 59.32684906067387, 57.51084266170379, 62.67285047038909, 65.77326443887526, 67.30909593643682, 69.45435785478162, 67.90320950169718, 69.8619156499063, 72.58752361420663, 66.90739031760924, 60.733305100471746, 68.81717666502922, 68.11356621403849, 66.83722695996686, 66.95015199722783, 66.59829185855004, 66.49454516749229, 64.79772783094838, 69.98055165813815, 69.28444862365723, 68.7863782144362, 62.96796567978398, 64.61161136627197, 68.23935662546467, 71.44631001257127, 71.15621935936713, 72.05055113761657, 70.72537053015925, 71.01138191838419, 64.65016826506584, 55.84662022129182, 60.410745066981164, 61.147256358977295, 41.5188923189717, 31.379830183521396, 43.47594714933827, 39.55546363707512, 36.852323009121804, 41.88157035458473, 24.75075787113559, 1.074546056409036, 0.2712798851632303, 0.3281908716645933, 0.2662470858664282, 0.12965337914084235, 0.0914859977520762, 0.05601538758304331, 0.015349488953248629, 0.12883610122146147, 24.888129080495528, 36.0407728533591, 31.52877630725984, 59.57366420376686, 26.441950528852402, 0.03896143152228287, 0.05813056783330056, 0.08003886683934158, 0.07990140768308794, 0.06196450464607728, 0.06956488209506197, 0.036914908071799625, 0.057325283020374276, 0.07669382818764256, 0.06561178413610305, 0.08726244777320855, 0.06130752679441245, 0.08287696212890648, 0.18043311883605298, 0.20340814165049986, 0.1490808173172897, 0.2752437160140084, 0.13445432958824022, 0.15230859089041912, 0.2082116661533233, 0.1676063861457571, 0.16980536492361178, 0.18543829300230552, 0.13190365516610686, 0.15031935166447394, 0.2640197924788921, 61.66582899708902, 67.72596543835056, 56.072066291686035, 37.622135223880896, 63.71630291784964, 54.317546967537176, 0.207474107343343, 0.28614064257952476, 0.37735885429766874, 0.5245382567086528, 0.37811574916685786, 0.3250114535612445, 0.46915239804694736, 1.196171523582551, 3.422231693421641, 8.058701224865453, 1.124595132085585, 52.98784778964136, 91.2298979297761, 78.5798305080783, 81.96791894974248, 82.34361925432759, 76.10432855544552, 72.98626392118393, 75.1782726472424, 83.87743857599075, 87.99822576584356, 85.69977175804877, 83.7006808865455, 81.99364185333252, 86.78874723372921, 90.3448857030561, 84.0586442332114, 88.33382375778692, 90.6297831381521, 82.1287831952495, 85.78575795696628, 84.04574748008483, 82.85777138125512, 76.83494844744283, 76.49203915749827, 82.60356257038733, 81.91240956706386, 78.07309166077646, 80.21308975835001, 78.92116300521359, 84.32605574207922, 78.51303254404377, 81.38344657036566, 79.61383004342356, 79.34167246664725, 79.46181466502529, 76.1857020470404, 77.6546218318324, 70.11431232575448, 70.30332349961805, 64.36747912437686, 64.87811680763, 62.380555445148104, 62.15692935451385, 64.14620253347582, 59.46170406956827, 62.84889428846298, 63.966350093964614, 61.77783619972968, 59.95661304843042, 59.9112626044981, 66.42742556910362, 61.77211346164827, 57.78516146444506, 55.422533558261016, 59.516087732007435, 64.5717247839897, 66.86614267287716, 71.07699532662669, 70.837903330403, 66.1549855816749, 71.05443385339552, 71.41561354360273, 69.68788793010097, 60.42499896018737, 55.03938467271867, 57.205882303176395, 59.18401202847881, 55.1597543685667, 53.06434577511203, 58.56670156601937, 57.339701806345296, 54.31361675262452, 57.29497894164055, 56.121719575697384, 57.30651463231733, 58.10965130406042, 56.39528528336556, 56.99400371120822, 66.4128500415433, 62.65166182671825, 62.64056936387093, 68.77829028714088, 70.4243835326164, 72.76178667622229, 73.59208183903849, 72.40657683341735, 72.96332590041622, 77.31378355333882, 68.75243402296498, 65.88624831168883, 74.59404345481627, 71.52192546475318, 72.39506075459143, 69.542799457427, 69.71461496045514, 70.77793813520863, 66.05359231272053, 75.34389080539827, 69.67161009388586, 72.36363472477083, 69.34498648489676, 70.26454694809453, 73.59576886700046, 78.40094689399966, 73.09100689426546, 75.94878304389216, 72.88326248045891, 73.75615458334647, 64.85223700923305, 60.29292883411531, 61.5341942541061, 67.65161298936414, 57.366319010334635, 51.09729282317623, 58.350806466994754, 49.51986458993728, 46.30074008818596, 53.97582615575483, 28.64959970597298, 1.6619377823606616, 1.6322834381172735, 0.47440304210589784, 0.39904490353599675, 0.30379596616952653, 0.14614650138443516, 0.1972231920808554, 0.13719831863718648, 0.1445940088841223, 34.845175589284594, 47.54129163680538, 46.964279605496316, 71.1382862829393, 32.73345974183852, 0.12305222932369479, 0.2305845591810442, 0.2010032231168401, 0.24857113918950483, 0.16785655981831013, 0.1802907337344462, 0.19282088314573612, 0.10595424235948633, 0.139513528274913, 0.14585077612390443, 0.3841758417266031, 0.15089865203105635, 0.29887011274695396], [0.12328726509886405, 0.03354167355404746, 0.020416947982964978, 0.13434804254962554, 0.07958292195032682, 0.1257542673979075, 0.04024649421954828, 0.03778113517910242, 0.09227943501525349, 0.014172256004155405, 0.03276329757946153, 0.016370096183832616, 0.9523020804889741, 56.84639315451346, 41.21276309413295, 46.80950287849673, 20.528269506269886, 56.60597147480134, 26.81286358064221, 0.2604198533921473, 0.230264809403208, 0.024498940235184088, 0.2841650550403903, 0.04661049385885558, 0.06114929899453156, 3.633568753157893, 0.0879413012655512, 0.8397616806530184, 1.6863954764220024, 0.9080494099086331, 52.66700967665642, 70.43616633261405, 70.18686832920199, 68.76571516836844, 70.41562095765146, 56.278767355026744, 56.38943310706847, 63.06375780413228, 64.15002684439382, 68.34009093623008, 70.49845357095042, 71.69743584048364, 74.55821652566233, 76.49920925017327, 77.23228454589844, 77.30669190806728, 83.10147608480146, 78.04914951324463, 74.23028284503569, 78.88507719962828, 78.8805115607477, 69.34130730167513, 73.69463612956386, 74.27437813051286, 78.43373006389987, 76.67637486611643, 77.28018453044277, 75.71047552170293, 75.60092372279014, 74.51651388599028, 72.7087797657136, 72.09227731150966, 69.30608441752773, 68.35641584088727, 68.11072641803374, 66.65577027105516, 62.32654048550514, 58.65925773497551, 56.948092368341264, 57.25311548479142, 57.942848590112504, 53.505510437873106, 56.50258956416961, 55.04794328443466, 54.98389490189091, 52.490432416239095, 56.538738127677675, 56.79792834866432, 54.135003782087765, 52.187193978217344, 56.96027525009648, 55.44973127303585, 55.540149750248084, 50.262985075673754, 51.34068765947896, 54.01028417771863, 60.90607373945175, 63.135717607313595, 63.87198178998886, 59.90504172540481, 59.86204862594605, 59.09250705472885, 51.973071790510616, 48.3732851859062, 48.43323861399005, 50.85603567861742, 51.96449356694376, 50.82968911816997, 50.431223377104736, 50.430160414788034, 49.39299944908389, 50.22668353972897, 50.38759093130789, 47.41839593456638, 51.147259896801366, 54.35664907578499, 51.17816032901887, 50.95097664863833, 53.497579405384684, 54.17796158021497, 55.489445271030554, 57.47805949180358, 63.94673039836269, 63.42932662656231, 64.78925943374634, 64.98942582837998, 67.75989394034109, 66.96113463371032, 67.8404829579015, 63.50731511269847, 64.25817443478492, 65.536321901506, 64.27490726594003, 64.88946030216833, 61.55444152893559, 60.47387953727477, 58.502704174287864, 62.368772645150464, 63.97398302631994, 67.0336514134561, 67.90935977812737, 63.23303161128875, 70.06405891910677, 69.1776660180861, 69.30595890168222, 69.04425051904494, 69.08469800026187, 70.92235196021296, 64.236824973937, 48.57154530863608, 60.52401527281731, 53.88748261236376, 49.91904812474405, 34.4462783875004, 45.27897834777833, 38.379956753023215, 34.23080690445439, 20.3761560686173, 29.616850306910855, 6.912003169136663, 0.15454189040728156, 0.03238910959372598, 0.10443904301932744, 0.1428936614144233, 0.23922558663593185, 0.09986440260564128, 0.0765756591253223, 0.22875304213694989, 7.302955119840561, 48.91270914385396, 20.584826161784513, 39.78434570374028, 29.773221477385494, 0.16336769826950567, 0.032335674961007414, 0.027169065001691063, 0.017212409856578997, 0.07648119282337927, 0.04748301054801672, 0.02508038756317429, 0.03798474985805731, 0.08210190331503268, 0.11731086764484645, 0.10646513873530973, 0.16711350049703352, 0.1211079441371464, 0.017664526221192172, 0.0987801353837694, 0.07653837362604757, 0.03236994207386048, 0.022571351934945392, 0.1429910924766333, 0.07680166272386428, 0.11029404618086354, 0.03325581167554183, 0.01594070773271303, 0.006111595693284707, 0.02803408552051312, 2.051825422433115, 64.01803516572522, 50.650550550030125, 53.36313232298821, 22.111726422463697, 65.4860528053776, 30.314794894187685, 0.2589344701940014, 0.17165942027443842, 0.017012794156588854, 0.3121696749041158, 0.14740130743913113, 0.1738117289759459, 1.5551918264358275, 1.417511362702616, 2.0487404782925887, 1.969285638582322, 0.8055744248051798, 66.20053214411583, 73.62433941133561, 72.33511124887775, 74.57362359569919, 73.61505123876756, 59.79838463567919, 59.62252909137357, 67.12722347628686, 68.73041383681759, 72.79405209325975, 77.06250867535992, 74.47412875390823, 79.61135110547467, 81.22358645162275, 80.78649320910054, 79.81882095336914, 87.4144672578381, 77.78780198866322, 79.18385198039394, 83.59830702504804, 80.82869791215467, 71.49383344957906, 77.00808971158921, 75.62840384821739, 79.77662409505537, 79.9239561634679, 80.79771118779337, 79.05659460252332, 77.84018916468467, 78.9152951394358, 75.75431977548908, 73.94514222298899, 71.82590915310767, 72.52870375110258, 72.48955065204252, 69.46752917382025, 63.41573169154506, 61.095857620239265, 59.20891907907302, 60.48442286829795, 62.53641082394508, 57.37667406758955, 59.14445100292083, 59.19737162128572, 57.91424274444581, 56.593078644044944, 58.99127460295155, 59.94047641754151, 57.254233360290534, 54.706132258138354, 59.65878355887629, 56.27247979564052, 56.76643171618062, 54.10007899807346, 53.994429957482126, 57.734433451006495, 63.075211125035445, 66.42733927695983, 68.41454536684098, 65.97461146693077, 62.60133389503726, 61.04567873862482, 51.89540101635841, 53.04416125820529, 54.60477036814536, 53.596854594446, 53.755942006264966, 53.92707109451295, 52.123671193276685, 53.95433156721054, 49.97246688412082, 54.8053329221664, 53.01233906899729, 49.97178831408101, 52.96135610149753, 54.63092081008419, 55.08428796645134, 54.73662868622811, 56.57010532194569, 55.01291259642571, 57.08645005379954, 59.09154215166646, 66.76635757569345, 65.16919589811756, 67.88992051155337, 67.04303372290828, 67.71213516112297, 69.43727985505136, 69.46744288167646, 65.9103395092872, 62.89118136129072, 68.5149266642909, 68.74021191750803, 67.0223157636581, 65.02086754768126, 66.54550460077101, 63.521125778075195, 66.46465670677924, 67.863279773343, 68.6125466131395, 68.3292495050738, 63.563040225736565, 68.51265953433129, 69.86470053272863, 70.36764252570369, 71.667829790423, 71.22247603631789, 72.11790607821557, 67.45302338753977, 53.356276019927, 65.69957487044796, 59.47884090485112, 54.94209028059437, 41.210531265504905, 45.963741810091086, 45.14828105126658, 46.27040447727327, 32.28645859226104, 37.532752252394154, 10.899242970251269, 0.10511719171077975, 0.6479359610426811, 0.29261243078977833, 0.14325905471078812, 0.2838224605206521, 0.062224150995814034, 0.03653073412997108, 0.0490648748593465, 8.374795721423242, 50.23892525703677, 22.18886963782772, 46.40069776965726, 35.1120928795107, 0.10677001874653563, 0.02559416059915337, 0.013108471100549064, 0.04164885263890029, 0.03084748979627846, 0.11274461589393117, 0.07299905507675103, 0.02340242518262277, 0.012600713769995399, 0.012422216241247954, 0.11180277207806227, 0.18908997366745628, 0.04855779360138601, 0.17039180522964847, 0.2015061904826472, 0.08744272358355024, 0.21506688136967922, 0.1287551410496235, 0.21886915959898504, 0.11725746365564486, 0.21075435793928562, 0.15052216578154795, 0.09896951997953077, 0.10212410917325367, 0.13703385488160197, 2.561552380361865, 74.61246290514546, 54.18339406290362, 60.86577923067155, 31.834615276705836, 76.3366662302325, 35.14842579441686, 0.6366892387309383, 0.41129952176443996, 0.139513528274913, 0.45819755523435535, 0.3125587862826163, 1.2904673862841822, 10.249299368550702, 1.713866408794157, 1.9355767893214382, 2.550469233143714, 2.160516506241214, 85.04539489746095, 89.50758518711214, 80.72188392762216, 80.87207148152014, 80.23957360175349, 67.71790889001662, 69.20910773738738, 78.41727964339718, 77.36163646944108, 81.96478105360463, 84.5002717356528, 81.35397388089089, 86.08294025544198, 87.19059405788299, 87.09560994179019, 84.88679778191351, 90.57031216159945, 78.5632545717301, 82.4944265427128, 86.46844648545789, 85.07930770997079, 75.28052883763468, 80.80322604025565, 77.42724987768358, 83.05054018574377, 80.98711459867417, 83.94076916479295, 84.16864318232383, 82.31065565539946, 81.74755234872141, 77.71443797696021, 77.8324071822628, 74.23518580775108, 77.26953137305476, 77.81570573006907, 73.03385796085482, 69.77947527362456, 65.3040312951611, 61.752862468842544, 61.29984048105056, 65.7917505694974, 61.126699216904186, 60.93577000402636, 61.5266280020437, 62.63739224403136, 60.059261475839925, 62.84719590217837, 62.757852154393355, 61.73668661425191, 57.4204045726407, 63.87488826628655, 60.95773527699133, 62.092096497935636, 55.822815356716035, 59.57960267220775, 61.239965500370154, 68.0363190558649, 70.36134319920694, 70.5890917008923, 69.55896746727728, 66.14691334386026, 67.19727700756442, 57.586583629731216, 54.57422687161354, 54.75441663495956, 57.19485652062201, 57.112929974832845, 57.36599345361033, 56.49287385325278, 56.730494960661865, 53.68833211160476, 57.827107291067804, 56.23918279524773, 50.86144462708504, 56.909653140652566, 60.63235505934685, 57.64797264529813, 57.242823185459265, 62.0397916916878, 60.73017504907424, 61.737067084158625, 64.51756469665035, 71.50564762853807, 69.97353061552971, 72.97638739309004, 72.53648573352446, 72.61352108370873, 73.97634075533959, 75.69373484580748, 69.40578322256766, 68.74717020219373, 72.9214899001583, 70.76250753095074, 71.34973341418852, 68.34808472664126, 68.87301552680232, 63.98819377345424, 69.09871655125772, 67.81872949292584, 70.84572453652659, 72.94423180241739, 69.26911215628348, 75.99470615386963, 75.02287618575558, 74.88968818418442, 75.81125690091041, 74.97830237111738, 76.66689841978013, 71.46256431456536, 59.00578737258912, 67.47481607621717, 64.95436768377981, 66.27450020082536, 57.94854387160271, 60.00107703670379, 54.91966609031924, 56.08054645599858, 39.09446354835264, 56.18495210524529, 10.974018054623759, 0.16837048224143444, 0.5357706378544531, 0.34113043378437724, 0.37306805712080776, 0.6717985580044409, 0.3532893523093193, 0.16145080838712955, 0.3566492607276286, 12.258679597608506, 65.78995412395847, 30.25760477589023, 54.1500029256267, 41.2195566392714, 0.3039050264464271, 0.31363278026542357, 0.15192833548832327, 0.06043345494676502, 0.14578466273603902, 0.30881347435136, 0.19442197626396535, 0.11153343088564374, 0.15951675813524954, 0.19318198634972497, 0.18457532559912052, 0.3269900135215252, 0.13609240943145368], [0.08987558900468773, 0.07640333530763466, 0.05237306085144801, 0.06011902181912334, 0.12681311582245175, 0.09692215766277044, 0.033503740710476716, 0.10142190532097894, 0.06945066604643099, 0.04313427414144239, 0.043230065775494424, 0.042009515342332666, 3.920948313128564, 65.11102714846211, 38.2184100151062, 46.78390549075219, 28.89011356138414, 59.74103566138976, 16.015362970290646, 0.44660964800465497, 0.1713118002179169, 0.011230246633321289, 0.14560716016398323, 0.11307915116870597, 0.5027134229819621, 1.1300061643123627, 0.4490823959631305, 0.08696270055107533, 0.7139511670797103, 3.2035392090197536, 34.4953433159859, 61.158505716631495, 79.9631171072683, 65.00993590201101, 67.7769797848117, 59.121626730888124, 43.28293515789894, 50.661654779987956, 63.59092827766173, 68.0899300113801, 68.77964742722051, 69.18338483379733, 74.60061734722507, 73.10765343327677, 71.1122731239565, 78.20533829350626, 84.49256820063438, 76.82247531029486, 74.70266957436839, 76.78032552042316, 71.63156355580976, 67.4434998727614, 75.79355132195258, 75.78973093340474, 80.62438949461907, 75.22835346960252, 73.87825012207031, 73.68581864141649, 75.6712753542008, 77.5914167588757, 72.56347948505034, 70.38929400905486, 69.2732463344451, 66.33586960454141, 66.95340756447085, 63.29369891074396, 61.128750616504306, 57.98015033045123, 56.542036840992594, 60.33238787804881, 57.63535045808362, 55.68011168510684, 56.28883215688891, 54.66104461300758, 52.090260444148896, 53.60199289937174, 55.03470920747327, 56.47720398441438, 54.64334295641992, 54.34105765435004, 57.551411736396055, 57.608246880192915, 59.90301778239589, 53.946259329395915, 51.816847708917436, 56.207509656106275, 57.160884872559585, 62.772027600196104, 64.19896233466365, 56.91341861601799, 54.11142641498197, 52.16142008381506, 48.92264842987061, 49.641618882456136, 53.72555540454004, 52.56394155563847, 49.9685170573573, 53.94725168904951, 49.51085490565146, 53.203393797720636, 52.395958208268695, 52.749618714855565, 49.38743752817954, 48.45583146618259, 47.91383443340179, 51.64581667992377, 48.89432891722649, 51.65467731414303, 51.869956601050596, 49.91311750104351, 49.984383044704316, 55.92716609278033, 60.59297838518697, 63.95334743684339, 65.65394986060359, 64.89013494983797, 67.16463504299041, 69.73660376764113, 66.85370091469058, 66.84895484678208, 64.52760596429148, 64.9884726924281, 64.12033842455956, 64.4386544535237, 60.50159500491235, 58.99107848444293, 59.419369928298465, 58.702556779307706, 63.55322253319525, 64.9787256025499, 69.10823222129576, 64.4172461571232, 66.65090653204149, 70.39316931078511, 70.50214844365274, 71.11164554472893, 70.01404869940974, 70.85188265769713, 66.99343142970916, 47.47970650272985, 61.51294677488266, 59.64743614196778, 56.2943587764617, 51.49534279300321, 56.50204435471566, 51.52304649353028, 37.58349987768358, 24.327461565694502, 31.742390548029256, 19.95162029420176, 0.669326116481135, 0.1931006278121664, 0.020004202792000388, 0.18362643377434823, 0.16462889349749013, 0.16559203455765403, 0.0880871797280927, 0.07029186123080793, 0.7343538045402497, 36.95705813746299, 30.479112786631433, 33.59861104719101, 41.399762092098115, 0.3937383350585738, 0.04928300307402688, 0.03788686680397199, 0.01788871419135361, 0.055226642608402245, 0.048018276180711486, 0.09483154202180524, 0.11897340101460296, 0.03338586276156768, 0.030829628456323862, 0.16800280600305528, 0.05613911461325423, 0.034468597807591005, 0.01763939087639653, 0.020822920956678932, 0.10530853749162729, 0.02561808360980884, 0.10219714799595457, 0.19953017393427513, 0.07059833470491633, 0.08359161490995078, 0.07147174388650926, 0.023704702410125927, 0.03451974183741597, 0.15447070551735742, 6.880069192378753, 73.13817731795773, 45.76037083902667, 41.688275952492994, 22.02418500377286, 70.81645581030077, 18.032096662829, 0.3814777107008042, 0.07316663681018738, 0.0337332338395138, 0.15038652225367485, 0.13431897717377833, 0.9619845738334041, 0.767854645607933, 0.9847941369779649, 0.9443535811958775, 0.069470354506085, 4.145466742977019, 51.12294904647335, 73.75193411304106, 80.43784941396406, 67.32800176066738, 71.34101790766563, 63.79388739985805, 53.24438648839151, 54.85150314146473, 71.70113855792631, 71.25078770422166, 75.92910843510782, 75.8110450929211, 81.57746268856911, 76.40993610505136, 75.69311511132025, 81.92569071246733, 84.58561466586205, 75.80215700211065, 80.69747894041001, 80.1503396803333, 75.96138169688564, 70.91788830295687, 77.56067322146508, 77.25395171873032, 81.87145217772454, 77.51766835489582, 78.459500035932, 78.30502925380584, 79.34851308022776, 79.42761944186303, 75.0016640078637, 75.69695903408912, 72.5687119268602, 69.36739890806138, 69.4469367304156, 65.6058459128103, 62.590425783588046, 62.1835583256137, 63.6745257531443, 62.27250983638149, 60.983842572858265, 60.69245753749725, 59.01639738390523, 58.22213311349192, 54.63274078984415, 54.793436373433764, 58.77997652176888, 61.45273054799726, 56.37390444355627, 57.03915019189158, 56.005621340967, 60.031804884633715, 59.96747409143756, 53.171842252054525, 53.61377569936938, 58.58802357027608, 61.25054413272489, 67.8376353171564, 67.39832201311665, 61.58063119457614, 56.80276855345696, 54.90053276861868, 53.00945220455047, 52.15454024653281, 58.583124529930856, 55.51138700977449, 53.95851281381423, 54.47615192782495, 50.8665515530494, 55.15680082382695, 53.33462453657582, 53.673109392966, 51.45002372803227, 52.79208621671123, 51.374926028713105, 53.93641025789323, 51.15539489253875, 53.50705192935083, 56.22461903479792, 54.69991530141523, 54.16505305997787, 56.4226673495385, 61.39950398475894, 65.9887476890318, 66.10122557609313, 66.5417391254056, 66.17233030257687, 68.88715959364369, 68.07689989766767, 68.55133410423034, 67.74167060852051, 65.22278724178192, 68.07102418714955, 66.93634525422128, 64.93828988844349, 66.58836826201409, 64.35178572131743, 63.54104749618038, 66.35610118989023, 67.20571010343491, 69.88222568265854, 62.583173321139434, 66.05589866638184, 71.18676677826913, 70.56991131074967, 71.61076714915615, 70.68510347797026, 70.17228495690131, 68.557813859755, 52.789497452397505, 63.94700104190458, 66.15888441762617, 62.50243525351248, 56.33587706473566, 55.701316018258375, 56.39597954288606, 49.78369889720794, 38.70170093351795, 42.81455709088234, 24.824853404875725, 0.8987232393795445, 0.25753930150981874, 0.034697493388047146, 0.0792877023078261, 0.11195183746636876, 0.185428180641705, 0.14259356945272417, 0.03760186294394155, 0.9720214288080893, 38.73440957838489, 29.42777441393945, 36.57908285817793, 48.47811837350169, 0.41919626415737216, 0.04753500876587726, 0.06497131164876685, 0.0794598039600157, 0.028003014909524112, 0.04612230432910785, 0.06228824574199896, 0.06671296657934304, 0.011097087145542667, 0.05848180382482468, 0.17138168275836976, 0.14381768602517345, 0.06675183021974179, 0.1667393891200904, 0.21450561471283439, 0.26372935322503893, 0.06889431767406003, 0.2384658725631814, 0.1847453817965523, 0.12215418275445701, 0.25482705914445464, 0.1532324622835844, 0.14197734364819142, 0.16052932718828802, 0.24112441216505345, 8.259064228303972, 90.16049508125552, 52.327697200159875, 60.61766186068135, 43.98625535349692, 80.20098532399824, 23.889536780695764, 0.7243179914451415, 0.4335738652415814, 0.15563727356493473, 0.6005245567329469, 0.26242225400863156, 1.6956943129339528, 2.0513926133994134, 1.0178627205952522, 0.5627896396383163, 1.103394476156081, 5.648696480258819, 68.52998856575259, 87.37855403654038, 86.07045142881333, 75.71190326444565, 76.53203948851555, 72.43716347602107, 61.75705548255675, 64.83913629285752, 79.82287668412732, 79.49204044957315, 83.40178058993432, 81.84134406428184, 86.23086852412071, 83.93148883696526, 78.93194952318746, 86.71371229233281, 87.84526117386358, 78.91996275994086, 87.41918979152557, 83.35692436464372, 75.97221528330158, 71.95783415148335, 80.14728807633924, 78.46158673686367, 84.99960514806932, 82.14053461628576, 82.19420832972374, 80.55707377772178, 81.837523675734, 82.65516527237432, 76.82460123492827, 75.47936162640973, 76.5043632445797, 73.68781120546403, 73.62549258816627, 70.5267652388542, 67.01102718230217, 66.72356451711347, 63.34131648463588, 66.54901904444542, 61.705974455802675, 64.32399965101673, 63.492461096855905, 62.02254110766996, 58.79327335665303, 58.505912673088815, 61.99713199369369, 63.68553192384782, 59.88438652407739, 60.602160653760365, 63.18241734658519, 63.510645204974765, 62.93815566647438, 56.87972937860797, 57.15798624100224, 62.17725507674679, 63.559384576735965, 69.70193786005821, 72.30487761958953, 62.50538095351189, 58.3043695265247, 58.84398960298108, 56.32982092518961, 54.90706743732576, 59.805546883613836, 57.915035063220614, 55.180895943795484, 59.07964560293383, 54.816213577024406, 57.75493175752702, 57.538471837197584, 56.730479271181174, 56.30339983970889, 55.11434901145197, 54.93368071894492, 58.468226540473204, 54.70478688516925, 56.3642083444903, 59.44810128981068, 57.66030065474972, 58.15890450631419, 63.01372405021422, 66.31187254382719, 71.9605484316426, 70.83351812055035, 71.52149400403424, 71.34020205466979, 74.71951223188832, 73.14948158879434, 74.17276520882884, 70.5368378854567, 68.67845027677475, 72.51692095110494, 70.87121994264665, 66.68677268489715, 67.6765827978811, 67.40509202403408, 64.22223375689599, 69.3391578428207, 70.44553295258554, 73.74109268188477, 68.72802119101249, 73.92887223151423, 77.24489888837262, 74.67448342231013, 76.98774045513522, 75.58004886873307, 75.36243577157298, 75.16762733459473, 55.69848406699396, 67.07868022303428, 69.88977232287007, 70.34941134914276, 66.92563718365085, 67.962570651885, 64.4793176651001, 54.07574853589458, 46.2550836993802, 53.68511969043363, 32.93347512522052, 1.5431382603222326, 0.6088929334955832, 0.09140822450600325, 0.5439994640408025, 0.1857680632101913, 0.22208343470288863, 0.24194746638738343, 0.2967859552271905, 1.6431774535486776, 52.97404889137515, 42.6990903577497, 46.83198982669462, 58.09886478608655, 0.6669992929504764, 0.1691188275693886, 0.23581723081729106, 0.08929392908729854, 0.09385558431066814, 0.13627524397546245, 0.21708294899473268, 0.18034883384262362, 0.1256425181523927, 0.16637915925633523, 0.32888194425932826, 0.2857685996399772, 0.28416082623504824], [0.1321549779705463, 0.029980439144457062, 0.05154101275688699, 0.06226183103036977, 0.04486725695671574, 0.16319897506506215, 0.07960399702912377, 0.08493136479369096, 0.1511114406129045, 0.03665799665595255, 0.11243929155170919, 0.0890769729871423, 28.40547334763312, 64.77509575505411, 31.44296269262991, 42.84901119047596, 31.900058061845844, 54.83391523361207, 5.8232581327038435, 0.24857858556412885, 0.18628043813570855, 0.03560230451365633, 0.0332224102420432, 0.25852881131633637, 0.1696862995384201, 0.701094005377062, 3.105039913808146, 1.2954476932364127, 3.374460166500461, 11.701551041295453, 22.923570755989324, 50.82639432722523, 72.54742130156487, 70.47821414086127, 56.89655242427703, 51.833251060978064, 42.22719392468853, 49.017008889106016, 66.38073367457237, 66.58580303192139, 72.78364212282243, 68.57079690502536, 72.05739175119709, 71.78179817814981, 73.16282549212056, 79.93278149635562, 74.03060282430341, 71.70666909986927, 72.72608526291387, 75.64990628150203, 76.4558905939902, 72.1330778060421, 77.21654799676712, 75.624206912133, 76.3010746432889, 77.29421092617896, 77.1531468053018, 75.27708499662339, 72.86912625835788, 74.0995345577117, 76.59674290687808, 72.86156392866566, 69.75581553674513, 65.81828932608327, 64.46590708148095, 61.50398808140909, 54.41406473036736, 54.54134956482918, 58.8122772401379, 58.989336952086425, 59.24872329158168, 58.01804827105615, 54.373013204143895, 55.77086748615388, 52.632237865078835, 55.86061523806665, 53.60030628019764, 57.88892384498351, 57.36706426066738, 56.646222837509654, 54.75019616465415, 55.84736547162456, 63.100345673099646, 55.35497073204287, 54.018642748555834, 58.76780148475402, 62.52383570517264, 64.73988463801723, 67.31110418996504, 62.192517019087276, 54.24182561136062, 49.70225480294997, 48.57782110091179, 52.119105554396114, 55.9344107104886, 52.26437837846818, 49.65697496168075, 49.06235148829799, 53.0050277709961, 54.75578161977953, 52.377738798818285, 54.031174721256384, 49.317164344172326, 49.507246325092936, 48.99840900974889, 48.7643611815668, 48.12830178968368, 49.71420626486502, 49.34158894323534, 51.57678296489101, 52.052574311533284, 49.848261110244266, 53.670010720529866, 60.81336459805889, 61.54171343772643, 64.60362934297132, 65.86837014844342, 67.84124389771493, 64.65716185108309, 64.12519824120307, 63.46833459792599, 61.31254896040886, 60.71695273922336, 61.81841311916229, 60.758337666911466, 59.656881209342714, 57.54384548433366, 58.772014110319084, 59.235030297310125, 61.54451008765929, 61.82735220078499, 64.02495030433901, 61.5957833105518, 66.35647773742676, 69.9708398695915, 70.88661132320281, 70.56342371048467, 73.01455989960702, 71.316283441359, 47.089058045418035, 59.95402428411669, 67.29575987785094, 53.658690760212565, 58.277516980325025, 48.647043089712824, 48.27353539005403, 35.315534453238214, 25.15424228483631, 25.83078838163807, 29.77020125235281, 1.5489268206780957, 0.9422078608505188, 0.3057657927274704, 0.0979084499000061, 0.6300183289474057, 0.1308680575100645, 0.20416949515140828, 0.053703023961955504, 0.19630247696993813, 19.873119938758112, 36.771110334704005, 18.486073747757946, 47.97851039517311, 1.6974344969757142, 0.08542573665298762, 0.10609229906432091, 0.014330413898513203, 0.07236139413209693, 0.06377658603953258, 0.010488112363213254, 0.14653348303850622, 0.039861201789350285, 0.013467440749668788, 0.02517904245084332, 0.03915194609773256, 0.022143599081544146, 0.020077961737350113, 0.027021039577741778, 0.03234102225471889, 0.02780708217722995, 0.06304502186755981, 0.1391933648095977, 0.1523767573939216, 0.05124215419674593, 0.169173740751801, 0.23608196016040542, 0.03519213720855694, 0.08705391097934016, 35.841963598805094, 74.34880118216239, 45.66519060442525, 42.550867911308046, 33.2273861669725, 64.6752518223178, 7.465750152064909, 0.18027665303839793, 0.05785973276942969, 0.08012504406994389, 0.1783360450738861, 0.1566467782662761, 0.08474548888062278, 0.7595096192052289, 2.0963254474824478, 1.3305666345742442, 3.0954080435537525, 15.871560054440653, 28.5961397617094, 64.44576178827595, 77.56108114796301, 70.56478869530463, 66.40987688495268, 58.042935709799494, 50.21965857475035, 56.857740571421964, 69.78232291436964, 70.55031514936879, 77.52811754903486, 75.58372805195471, 78.49168700556602, 77.05364411877048, 77.86825764563777, 85.45457655383696, 75.80968795284149, 74.71874344733455, 76.42828495271745, 75.52977192786433, 74.4000038023918, 75.89797266067998, 78.88312385928246, 78.51264815176688, 80.05512022203015, 79.26500581925916, 79.27046575853902, 78.89551854902699, 77.10911427774738, 75.11067451969271, 76.94531609935146, 72.59232459529754, 69.8625510738742, 66.52567309717979, 66.5025468026438, 66.49325863007577, 59.97005108864077, 59.282734163345836, 61.163534195192405, 61.56909942626954, 61.31264701966317, 58.314402949425485, 58.30107473557996, 59.02757221652616, 54.394511715058364, 57.04936796619047, 55.266984124337476, 61.47408000884518, 57.406185980766054, 56.74561177530597, 54.75778595093758, 56.693538388898304, 61.59703454663677, 55.806211963776626, 55.72353232291437, 58.84911221842612, 64.93944698764433, 68.68556545626733, 70.1509786421253, 67.88529995949038, 60.11882658927672, 52.918731704834975, 51.34529644443143, 54.7144986737159, 57.14823522875386, 53.43996370992353, 50.314152394571614, 50.89132524305775, 53.64340920602122, 56.015215458408484, 52.19123401949483, 55.62165660242881, 50.60003826695104, 52.60055688119704, 51.61906611534857, 50.67275508757561, 52.033335085838075, 54.42548274993897, 51.517229618564734, 56.40015686711958, 55.01809796979351, 52.193575674487704, 55.40953090113979, 62.68918714215679, 62.376491869649584, 65.29186410288658, 67.08388128588277, 68.83155607408094, 66.7955086308141, 65.5747022936421, 67.614028838373, 66.02268403576267, 62.85626834438693, 66.53308637680547, 65.79188393008324, 64.57272498838364, 62.18092249285791, 63.455198580218905, 63.37751211658601, 65.32594557731383, 64.6129959629428, 65.78531788241479, 62.83393829099594, 67.48436312521657, 70.22715891561201, 68.84215431828653, 67.82137317042198, 70.3264811731154, 71.19286998625725, 51.00029653118503, 62.76037423841415, 76.66484309780982, 60.14335316996421, 65.51478024451964, 58.138668998595215, 58.50581461383451, 45.595470474612334, 37.364219773200254, 38.29049533413303, 40.07806454935382, 2.9449397950403156, 0.770507822594335, 0.42884321102211553, 0.6840597645890328, 0.6894702452325052, 0.12496101399583202, 0.1910582986930686, 0.018534947659880407, 0.04832178872499255, 22.976709065898774, 37.72612117951916, 22.269852853590443, 59.523720664362756, 2.581465518282306, 0.06313135614618659, 0.09719873072519418, 0.021593237686301434, 0.06617559420485651, 0.08634975360285851, 0.047352327439453334, 0.17152362352898046, 0.04027875418203973, 0.024686275545748013, 0.03269869338480696, 0.019471047731537013, 0.013482258805344182, 0.2290231340955342, 0.21845620756428089, 0.11018809622093556, 0.13770752195869723, 0.170394440572108, 0.25553463327307857, 0.19359676167368892, 0.15467941851144837, 0.38505999912177363, 0.27197196899402526, 0.20711433713234242, 0.2077588162595226, 40.10025731978878, 89.43471539405085, 43.888800144195564, 62.79404778634349, 50.48288883701448, 71.9957007131269, 11.820051727756379, 0.5695398548437703, 0.31217537459827244, 0.314967458647105, 0.546916236560191, 0.5379477371611904, 0.5259002997509895, 2.877607898366067, 11.909351348876955, 3.950645313147576, 4.491826738080671, 25.269063788075602, 43.17660362489762, 78.87743642253261, 85.11284397494408, 77.89278814869543, 74.08582979632963, 66.40167913129254, 59.141199358047984, 65.201324032199, 76.5835480536184, 76.96005636645903, 84.62543456785141, 81.15944000982469, 85.27431226545765, 82.0685120551817, 85.75891325550695, 89.17914944310343, 77.07731170039024, 80.0664480270878, 81.30292815546836, 78.11065227754655, 79.99568062443888, 79.174406913019, 82.51687818957915, 81.70535549040764, 82.17515345542662, 83.89326926200621, 84.33729725499308, 83.42795064372402, 79.98108156265752, 78.0481061627788, 80.08779356556555, 75.34655801711544, 74.45526215337938, 70.62615809902069, 70.82671673067155, 69.54911447340443, 62.04938580912929, 61.0181672342362, 65.34724796971967, 65.65149053450554, 65.3159906018165, 62.60068670395882, 60.28347592200003, 64.73114951964348, 55.884141614360196, 61.504584281675285, 59.90496720037153, 63.47730113613991, 61.744468596673784, 61.335843916862245, 59.760886776831846, 60.84761081203338, 67.4952124011132, 61.369658670117786, 59.07662145553097, 64.20981553293043, 69.13002490997314, 70.61414780155306, 73.62346864515736, 68.42069564327117, 62.79052549792875, 55.06453883263373, 52.89117705437445, 57.38256938995854, 60.73148119834162, 58.07205930832894, 52.73590218636298, 55.31883393564532, 56.389233066189675, 60.837706827348285, 56.668454831646336, 60.01403262538295, 53.891522653641246, 54.06968847397835, 55.30262670209331, 54.14032251604142, 54.8593714160304, 56.000024118731105, 53.67155221200759, 60.059991036691976, 59.904331776403616, 55.29223634350685, 60.1990076803392, 67.6718367299726, 66.54672838026478, 68.49451464991417, 71.89921040688792, 76.26396117671844, 72.39091873168945, 73.13606708280503, 71.46248586716192, 69.41195703321888, 66.96082868883687, 68.84886157128119, 70.0185594251079, 65.56274298698672, 63.3174684739882, 65.77593165059244, 67.10900014446628, 68.46053907948156, 67.54198274304791, 71.1442796645626, 70.32670082584505, 73.37901084653794, 76.46655159611856, 76.27594793996504, 75.23192282645934, 78.0240620336225, 77.46599505024572, 58.93497290149812, 67.57170646421372, 76.20113265129828, 67.68918145087459, 71.84820390516713, 63.2122116704141, 62.79726020751461, 47.89371659678798, 45.69264719563146, 46.969217869543264, 58.320478700822406, 4.54434972616934, 3.1639002263545994, 0.6573278312721561, 0.5135373260465361, 1.2492063809787075, 0.4292405348631644, 0.3070181319790502, 0.11479209312388014, 0.18533931444248847, 29.61433802881549, 53.42894969447967, 29.597805238539177, 65.48573117102346, 3.440805587076372, 0.20374788632315977, 0.11915294138053734, 0.07643489046923577, 0.18457235317797432, 0.20850331582609685, 0.22694576411477982, 0.34306073020542827, 0.16288990455289043, 0.09924230856760856, 0.10248734976255125, 0.2341942429061859, 0.16896881223205598], [0.0283640721482375, 0.1266371990523992, 0.12436726521099768, 0.01304642947000121, 0.02958148545134933, 0.292229509401706, 0.153161553185313, 0.22461868011422698, 0.4682652682306305, 0.29398847791937094, 0.5114648743502556, 7.272861224989738, 74.4933875914543, 46.579867716758486, 25.02847540763117, 27.776519329317157, 38.077593003549886, 41.117222001475675, 0.7775458417111828, 0.18275284839253272, 0.029716504617564143, 0.10509751857288423, 0.029432998459425666, 0.0701742897170686, 0.4496032744646073, 0.7046398280128356, 1.3072004625874183, 0.75938698385031, 7.242898239243416, 17.95674793181881, 24.411661124998524, 48.75063288596369, 68.82255815690564, 66.15762925917103, 47.96644518452306, 45.02112565502044, 45.20843059785905, 54.45688524553853, 75.8237692617601, 65.68679971079673, 72.17656904651274, 67.56650540136522, 71.91484497439477, 67.3720342882218, 73.18415534111762, 78.9773391908215, 67.05169431624874, 72.6317757944907, 74.74639615704938, 67.48409640404486, 65.48804536942514, 73.25280466387349, 77.03632293208953, 76.49980545043945, 73.15734986336001, 76.41548233647501, 72.8208105025753, 72.63206604988345, 76.20065412213727, 73.67229430906235, 70.5685620154104, 68.97191416832709, 66.90233046008696, 63.93838751700617, 63.48362399685768, 60.697289897549545, 57.40200081179219, 62.16000841509912, 56.12745408088931, 59.82064408640708, 58.1994382796749, 54.54534646003477, 55.59048552666941, 55.546335328009825, 53.8622147037137, 55.42061944161692, 51.75821611958166, 56.06793995826475, 53.90111677108273, 52.10453394920596, 52.56110960437406, 50.813587788612615, 57.2236624071675, 56.20392068739861, 54.10205195027014, 55.258378444179414, 57.47515693787606, 64.39866196724677, 63.27875075801727, 56.75453908981816, 54.80661945958292, 52.85056875598047, 46.890770466096946, 54.310290582718395, 54.81094975625315, 49.778662573906686, 46.00379705429078, 53.34445791859781, 53.87884555324432, 53.76584991332024, 50.57137750810193, 50.95483626088789, 46.70077085494996, 50.85410587249264, 48.146305468774614, 50.263412614022535, 47.671392733050936, 50.08024184934555, 50.209232914832334, 50.98403830682078, 51.95997499650525, 53.20344871090305, 47.16770156737297, 54.90675757008215, 58.99927623810307, 58.82957881496799, 63.44456503468176, 65.43131612962293, 64.38906000506493, 64.16254704998386, 67.27260220435359, 58.00641452112506, 58.38622154728059, 63.08988471185008, 60.63075473231655, 61.842249362699455, 60.01189885600921, 62.1151678792892, 56.76068936624835, 61.346591211134395, 63.2668306750636, 65.70425425806354, 60.87513408353252, 65.75042447736188, 68.84514316435784, 64.35654355633643, 68.05086320446384, 65.22232047973141, 73.64150370320966, 48.742227246684415, 55.53707461203299, 80.87372672173285, 50.231178575946444, 51.262554045646425, 34.692438494774606, 29.17876078236488, 25.777226455750007, 27.47190021699475, 21.288275795598185, 27.315831069023382, 5.8802364430119916, 0.1854417097544478, 0.05840919018092175, 0.15659612453272267, 0.012863228161398683, 0.3657544914993548, 0.10942235303622101, 0.11799843921776741, 0.18183686770498755, 4.86924062813482, 54.56773927134853, 16.433222870672903, 42.59482983619937, 19.336176879944343, 0.4949099594546903, 0.18243787900334407, 0.16623890387915796, 0.06035255223152138, 0.1465727986707803, 0.02279523346993712, 0.14720377932873466, 0.0867860866410117, 0.17749829728516842, 0.3181618001432188, 0.19273068395353135, 0.1126629202776859, 0.037826077727180336, 0.03454775001192766, 0.11100063971694439, 0.04046985098431188, 0.051075928438935554, 0.27370666784624903, 0.22005431293960542, 0.1799471433004064, 0.4216176842249209, 0.5878111131248936, 0.48463953959365047, 13.315722077123581, 83.08940302941107, 60.26526827966014, 39.26866385244554, 24.756915992306126, 43.71423113730646, 46.72239488170993, 2.2362533067503283, 0.15047934146658068, 0.22640501329254722, 0.10123176229817253, 0.1763768671380897, 0.10331925230040666, 0.14878797254735424, 0.6673217240360476, 1.8564462805947952, 0.2168168713368716, 8.900486480805183, 24.06187984251207, 26.03206676821555, 59.156814313703975, 77.98184948582804, 67.93734981167701, 59.975895420197524, 56.69381295481036, 52.78721071058705, 62.17728645570817, 73.61457270960655, 72.09583882362612, 74.97436431146438, 75.17833540516516, 78.30709242051648, 72.86067747300672, 77.70791115299349, 83.09330186536236, 70.98317223210489, 78.1232117068383, 77.0723302902714, 69.99190299741684, 69.3190517733174, 74.75827309393114, 77.56368560175743, 78.47147895443824, 76.8278254232099, 77.96045687890823, 78.36060139440721, 78.28194218297159, 77.36885363055815, 74.09643588527557, 72.71800518035889, 70.48967530650478, 67.4658573827436, 66.46711995524745, 67.20465890822872, 59.892117515687026, 63.11811400998024, 66.25340569403865, 60.60610655815371, 62.85550740457351, 59.281753570802756, 57.279391442575765, 57.5695409313325, 58.51858585111557, 54.80809819313788, 55.13396478468373, 56.440808311585464, 58.59547607360348, 56.294366621202045, 56.17972358580559, 54.87702600417599, 55.05524673769551, 58.46400607016779, 57.726180784163944, 56.230847758631555, 58.49032125165386, 59.59317407300396, 66.5640260327247, 66.20438391162504, 59.7835345422068, 56.231898953837735, 56.49490956337222, 51.93673887560445, 56.11982507090415, 56.364200499749955, 51.227574348449714, 46.97985141508041, 52.83778182921871, 55.71804884941348, 54.54338135257844, 53.04452603863132, 53.05097049282443, 49.78016876405286, 52.35491844915575, 50.99577011600618, 50.77545450579736, 51.75009289095479, 52.56381996216313, 54.588229733128706, 55.20373590530888, 55.44477731950822, 55.701849460601814, 52.194360148522165, 56.412214233029275, 63.067064362187544, 63.44941700658491, 65.37628135373517, 66.36673865779754, 68.38553551704653, 68.80275018753545, 67.7663266274237, 63.03225724927841, 62.38832173808929, 66.59907633258452, 64.10634733015492, 64.44943312675723, 61.07133103955177, 63.002435468858295, 62.03333939275434, 63.93131156121532, 66.63643298610565, 67.89474502686532, 64.64542219715734, 66.28611826127576, 68.44575958867227, 66.88045932400611, 66.66527809635286, 67.3809459132533, 72.76283787142846, 51.06374871346259, 56.515313733008604, 83.27771602138397, 64.13231734306582, 64.58201708332186, 48.69677482112762, 41.95616599052183, 34.64372265723444, 34.01865374657416, 32.65267068339933, 42.901586640265684, 13.631244397932484, 0.3727440019288371, 0.19204341115490084, 0.43658740998756507, 0.5212177864966855, 0.1578249908503025, 0.01044302138560001, 0.05472432258689115, 0.21625168230985442, 5.149698920788304, 58.97904073038409, 20.236604021441554, 56.93069273425687, 30.109235240567116, 0.32764290429411397, 0.1584431625181629, 0.11489191438041388, 0.0128959832082112, 0.1586094648847657, 0.09908078658965327, 0.08982454456629292, 0.07154341907270494, 0.06129850227866442, 0.16427889856840336, 0.09473458593410831, 0.033976543364265276, 0.2234702530286966, 0.30510190093228895, 0.2385319859510468, 0.1367890285027604, 0.27644521767093294, 0.4940048112503944, 0.3475581872607431, 0.29934159389907317, 0.7555588118491635, 0.7626489249448624, 0.5208574187371039, 17.033388653109153, 98.56407903855848, 64.20872511402254, 38.28846746875394, 41.85500021903746, 55.467585902060236, 58.23284510643252, 4.114653093199577, 0.3999690507208148, 0.29667324837177034, 0.20881197265078946, 0.28650116355669114, 0.2744224084721458, 0.425450575327681, 1.200061656775013, 7.570924095569119, 2.7265069225142082, 11.354772333175907, 30.11984132951306, 46.117549711658114, 74.96224418763192, 83.71089473847421, 73.13225453899753, 68.97845668177452, 62.72803821871358, 60.737176479831824, 66.9989933506135, 82.09209334465766, 81.33020431764665, 80.5134334871846, 82.0086488416118, 83.8982428273847, 80.03855213042229, 83.00896306191721, 87.54441538164693, 71.59923538084954, 81.96365925573534, 77.98311248902353, 72.43329601903116, 73.14744980104508, 79.93611551100209, 81.98332601977934, 83.53893803011987, 81.2485876391011, 82.37585329240369, 82.55192064469861, 81.41031480604603, 80.95482564741566, 75.78635769505655, 75.00016566245787, 73.72857247629474, 69.61170765661424, 72.32607410800073, 70.44309323833835, 65.55670253692135, 64.17987608140515, 69.66721703929286, 63.86937733619445, 67.37591743469238, 63.55264202240975, 60.17955664665469, 62.84603488060736, 60.79214849779683, 60.110001256389005, 60.90898021574944, 60.68216131579492, 61.491161930945616, 60.08643957876391, 58.93846381095148, 60.90298683412614, 61.05395493968841, 64.29635478604224, 62.501105570024066, 60.053876061593336, 61.83226300824074, 65.5176749537068, 70.31753816912251, 70.78493564359604, 63.61432521573959, 61.06893054900631, 59.25835271035472, 51.25972601675218, 59.94846236321234, 62.06871524933846, 55.60412753012873, 51.45098863109466, 55.36843622884443, 61.19169289065946, 60.58418835363081, 57.87643109598468, 56.731248055734945, 51.42436750473515, 58.50529686097176, 57.11414590958626, 56.931810609755985, 55.15833447056433, 55.421733394745864, 57.77898373142366, 57.81341037442608, 60.319138111606726, 59.79037907815749, 55.16684601383825, 60.24209883905227, 66.91277180948566, 67.1661255436559, 70.9174725317186, 73.27850403324251, 71.5444084905809, 71.88592141674411, 75.21890055748725, 64.89227264158188, 64.42105870093069, 68.91226276274651, 65.92574657932406, 66.42275794859856, 64.33440177671372, 66.71490392377301, 63.260013595704116, 67.85712165217247, 70.98891458203717, 72.76571689113494, 69.56924407712876, 72.226516508287, 75.05698511677404, 70.70139700366606, 76.09926869792324, 75.9249036542831, 79.74970879093294, 59.25821542739869, 64.78638041403987, 81.74883888613793, 66.87250475729665, 70.80794426702684, 52.333667047562145, 45.295742557894805, 36.834115366781916, 43.50714175931869, 40.04468517918741, 60.400899917848655, 19.13750490834636, 0.5556090055934845, 0.5962016145067831, 0.5421594434207486, 0.5332585436201865, 1.0290135899859092, 0.3933378549352769, 0.29260731332244416, 0.424743598747638, 8.873455466762666, 77.33993007290748, 28.154898612729966, 61.692422666857325, 31.474433829707486, 0.6079282142942952, 0.33132395677028165, 0.24803283984862992, 0.1626413090214614, 0.3861375477525496, 0.2152559059041162, 0.2130647259013307, 0.26068188610576815, 0.18539507032161762, 0.36060417431496805, 0.48112647487751903, 0.1805354068957029], [0.7239883284895652, 0.1370902542745875, 0.08719949832847042, 0.10905614002577721, 0.3723471990275768, 0.36349018074331746, 1.454625074421206, 6.606341196644691, 10.964567103693563, 13.299891391108114, 4.306355993593893, 43.524160923496375, 65.68373241732198, 41.11233472824097, 33.48584290473692, 32.80398003516659, 48.3047103881836, 30.591520071029667, 0.1197388377641478, 0.13004895630142382, 0.15873632904502655, 0.11075435777104671, 0.019720612364190242, 0.2035836830374695, 0.09875201229606906, 0.31355083950104257, 2.1848405945685605, 3.302840383783464, 4.454667673956964, 25.821504131440197, 29.059646244971987, 54.74616396811701, 60.10294883481918, 54.43650853249335, 51.71122612491731, 54.365235144092196, 59.61926960176038, 60.71074362724059, 61.35686782098586, 59.731347407064135, 74.43254378534134, 70.8164244313394, 68.05140449154761, 65.4705672879373, 73.55942418498378, 71.7846771978563, 66.20677655743015, 75.35245726185461, 68.64151723923223, 73.39309215545654, 64.90878974237751, 68.41174479453795, 73.75498571703511, 73.81884190344041, 72.69718523948424, 73.02615442583638, 75.36957448528659, 75.86342442420222, 72.43459824592837, 69.35460413655927, 68.74745261284613, 67.93387459170434, 66.91945552825928, 67.05016459188154, 58.271774630392756, 55.57535302254462, 63.10727650119413, 57.58976074957079, 55.922667134192686, 58.34559755940592, 58.268405314414736, 53.419065321645434, 55.41149208622595, 54.079364961193455, 53.25764409957394, 52.81919371697211, 53.948687276532574, 53.3552130576103, 51.45002372803227, 50.047086054278964, 49.39519205401021, 47.352700156550256, 54.1490105659731, 55.743050036891816, 56.717645275977354, 58.17437041190363, 56.78024238155734, 59.015773727047836, 62.72495523575814, 57.18343065631006, 54.58094589171871, 52.619380335653986, 51.473389287148755, 53.15483877735754, 53.27385917786629, 45.822567862849084, 46.974548370607444, 47.58473973120413, 50.23501857634514, 50.0416261149991, 50.12635715546147, 49.68937766167426, 49.6738568429024, 48.62807842992967, 47.987845636183216, 49.39994988902923, 48.38087104981946, 48.76724804601362, 50.950576566880756, 51.822911693203835, 53.0554812185226, 53.51159795638054, 51.66397725382159, 46.187258074360514, 56.226760648912006, 59.42223718089443, 62.22710447926676, 62.29363179975941, 62.86485049032397, 63.07981990998792, 63.861289408899125, 61.730595173374304, 53.7280108082679, 55.994889736175544, 59.736552392282796, 60.31584724303215, 57.96615531367641, 60.841378165829575, 61.41791951271796, 56.03927527704547, 58.61462508478473, 62.45423324646489, 60.60292159357379, 61.69041833569927, 67.13793154685729, 64.52086733233544, 65.38056458196333, 64.41232750492712, 64.48143966736333, 50.169903309114524, 44.834550273033884, 89.25260759169056, 66.925503823065, 45.09186560107816, 29.832967019850212, 20.900657369244485, 21.39638416228756, 22.50075690207943, 21.054847701903313, 22.03352612833823, 8.055600591244238, 2.8666451188825794, 0.5854844734553368, 0.9055732911632908, 0.2933180590550746, 0.12594857027814274, 0.1692768255428922, 0.06339776705229475, 0.07149325563542305, 0.6850392539655009, 34.237522002189394, 36.95741507314867, 19.31975587721794, 50.573636793321185, 3.8445211754691218, 0.24343453497896272, 0.021268914363557295, 0.06114843714561674, 0.06604247876713354, 0.05700295152623327, 0.07697879757371641, 0.06847197340140421, 1.5227961131641943, 4.732228315645649, 5.037817724289433, 3.733367088340944, 0.8254764084854435, 0.18208912513669462, 0.06312608163082792, 0.03342925015115931, 0.14158090846913476, 0.4275359279446064, 1.317835969309653, 3.992296716859264, 13.30565139170616, 18.955346115173835, 8.811632048699165, 58.14024186903431, 73.48183970297538, 56.07358817131289, 35.008087312021566, 32.598579237538004, 54.18404517635223, 34.760275886904815, 0.4234152635739696, 0.04533896410477258, 0.07519145315933613, 0.11148149778525676, 0.03493745510856952, 0.1583047304302454, 0.07824238299602464, 0.9427433256660739, 3.052155822515488, 4.1599329344687925, 12.880866546784679, 27.802652120590214, 34.65891791928199, 65.45193995198896, 73.17958970223704, 63.9514607767905, 59.71775247204689, 60.536288369086485, 62.06588329807405, 67.51181187168245, 63.43843437010243, 65.84747960490566, 76.67201319048482, 76.27343762305476, 72.21740876474689, 74.317061362728, 79.16152584937312, 74.19604839817171, 72.54223592819707, 77.68598510373023, 70.09626157822149, 76.6441878964824, 69.76655498627694, 71.58184359150549, 78.14585947221326, 77.49078442973476, 76.2737435679282, 77.00807402210852, 77.4296974366711, 76.78031767568281, 73.80967924671789, 71.51545355396887, 71.04012504700692, 68.16893439139089, 69.4922322611655, 70.86415967633648, 60.78471168395012, 59.07171064807523, 64.66025660114904, 61.562227433727635, 60.67794084548951, 61.10554979693506, 62.203966417620265, 55.48547583241617, 58.188071250915534, 56.80007388514858, 54.81711964453421, 57.01671815687611, 58.07770752137708, 55.11347824527372, 55.923220188386985, 55.14512392782397, 53.64146371041575, 51.26006726295718, 56.61085874803605, 59.43717356651061, 56.25306798565773, 61.02668662225047, 60.486207546726355, 62.72152316185736, 69.69210055566603, 61.92797668518559, 60.11113874373898, 57.40240873829011, 56.426350455130304, 57.73965412570585, 52.72426843643189, 48.96182114078153, 49.99527938904301, 50.352717138105824, 55.17498100957563, 51.684616765668316, 53.11477961078767, 51.5773791651572, 50.07066734375493, 52.54290980677451, 49.8088256005318, 48.94333108778923, 50.918507268351895, 52.642683136847715, 52.50976185644827, 53.969220884384654, 55.888691563760084, 56.69461704069569, 54.758060516849646, 50.46960376924085, 58.8632131391956, 63.79405998414563, 64.99320307085591, 64.20116670670049, 66.25936769670056, 66.07061539926838, 66.36640133396273, 66.05867570446384, 57.2545353827938, 58.58637617480371, 61.52746738926057, 64.77609203707787, 62.98599289309595, 63.122561977755645, 64.3984462368873, 61.73328199694234, 61.00199922438591, 65.98641780114943, 65.21578188865416, 65.92541710022958, 68.42002099560153, 67.19128362594113, 67.20312918386152, 67.8143991962556, 67.11196545631655, 51.56815375051191, 49.8612912239567, 87.94975311525407, 76.93871867272162, 64.61312932352867, 48.45693365220101, 36.03904308811311, 28.446817090434415, 25.973994116629324, 28.18576962717118, 31.643837075079645, 19.434820567407918, 7.572517558451622, 0.6307549990953938, 0.5854405306520001, 0.33633098486931096, 0.16684016032565027, 0.1424226399150587, 0.12426716816281119, 0.18408604056364108, 0.593695403827775, 39.63790009098668, 40.48748939268051, 20.74524914064715, 64.9764584725903, 8.775761973473335, 0.1304355855550497, 0.04778979811817408, 0.03325238343208067, 0.04031596690296166, 0.03032664193831865, 0.01069088434545143, 0.06005362472346714, 1.9091479816744406, 4.985329547236043, 5.99027902849259, 4.130134197973436, 0.8506498738161979, 0.19908896857692351, 0.2098508798066647, 0.25026800862002757, 0.34664911668627496, 0.5851353212229667, 1.9961551000033657, 8.607096133693572, 22.702172571612945, 30.535447828231323, 16.259847244908734, 72.816433137463, 83.10126427681216, 60.02193227890999, 45.877402597858065, 50.78493879687402, 65.6860387709833, 45.628649803899954, 1.1899831266172471, 0.2901689473900103, 0.33262229194083526, 0.3190397675479612, 0.2016968697670006, 0.38858541317524453, 0.2258246404028708, 1.7443920095120709, 5.660776890093281, 4.902946045321803, 19.178038681707076, 44.114932629369925, 55.06437409308649, 79.12445160650438, 75.16233997960245, 71.48906384744953, 68.86116996888192, 68.94791710761287, 68.35771806778448, 72.50501263526179, 72.99600708869197, 72.45484552075787, 80.56645608717396, 81.38961253627654, 77.80902985603579, 80.86103393185525, 85.35384224307153, 80.05418669792914, 76.05193353468373, 83.2046736440351, 72.44871093380836, 79.8186013006395, 71.71534538269043, 76.62501535108014, 81.7616964155628, 81.4779443125571, 79.44242246689336, 79.97781815067415, 85.22575332272439, 82.306411650873, 79.3974171915362, 75.39772925838348, 72.79060040750812, 72.10781774213238, 73.7531735820155, 73.81778286349389, 65.89409305203345, 62.54887219398253, 68.97632291240078, 66.31797575181531, 62.353577383102916, 66.34281219974642, 67.35251657424435, 59.24292995083717, 62.8381234599698, 61.23759638878607, 59.042892994419226, 60.11836767196656, 61.97175033630864, 58.44764194180889, 57.510850506444136, 58.698708934168664, 56.5907330666819, 54.690634973587535, 62.89104800070486, 64.90167848525509, 63.16429207401892, 65.03984789694509, 64.15469838726905, 66.62909030914307, 71.73338044074275, 63.21602421422159, 61.33084681726272, 60.070385317648615, 56.97377604822959, 58.25164502666843, 58.116437004458525, 54.22975255597023, 52.44590567004297, 54.78824707769579, 59.448132668772054, 55.03435227178759, 53.7010209791122, 55.3644589454897, 54.13798086104855, 55.55995771961828, 53.38679990460796, 54.953920149034076, 54.27295354104812, 55.419164242282996, 54.40800074608096, 55.879948600645996, 60.698360704606586, 60.77875752602855, 57.35187292099, 51.7377648815032, 63.2767621163399, 66.11209054147044, 71.17211280330535, 69.18896244418237, 68.94185312332647, 70.47087146389869, 71.67071665486982, 67.06145317323747, 58.054573382100756, 62.21360760350382, 67.1026929732292, 68.66010142910865, 64.55343869424635, 66.77850123374694, 69.33236429768225, 62.82668190617716, 64.4494801951993, 68.85026577980288, 67.83187727774343, 71.54996256674491, 74.33835198802333, 73.3085415440221, 72.40167387070196, 74.34339615606493, 72.69883263495662, 57.85306161449802, 60.537712189459036, 85.29044105160622, 76.7745674810102, 70.69119884121802, 52.65376383258451, 41.39849908890263, 32.801659953209665, 36.9676406921879, 37.77527240014846, 47.552709656377, 41.15830882903069, 9.408941365057423, 0.8295786561023805, 1.4515929597039379, 0.7706241453847578, 0.5231494312324833, 0.33269926845546693, 0.3005622171105877, 0.21976506878291407, 1.859506464773609, 53.115595463783514, 59.127906445534, 28.844445405467866, 73.93706214043402, 7.800268511618338, 0.31143364826998404, 0.12756331508318264, 0.16793851590444966, 0.19294532646815624, 0.20472026640369048, 0.17506100387582857, 0.16220485340924035, 1.8639245244764515, 5.93272069769521, 6.654964368189535, 4.743806171801783], [28.77789455075418, 14.966467253623472, 10.897089589026667, 2.8683082038356416, 3.3646875812161356, 19.822317400286277, 23.499780662598152, 26.935927944798625, 14.896854988990293, 13.117209942110124, 23.089745890709665, 63.154901919826386, 52.8298351072496, 40.40846540081886, 43.45540177437567, 25.25142881178087, 50.30369143332205, 17.497055953548802, 0.10110582510430006, 0.08475373964756729, 0.1661128211285799, 0.10445722994664985, 0.0619786121552029, 0.03079553945891319, 0.0563276220383423, 0.05877837561251176, 2.82803159086935, 5.550751464982187, 5.673650108998822, 47.74892230187693, 44.32037461188532, 62.109955049330196, 58.083685213519686, 55.79099708987821, 50.101426570646225, 54.849416440533055, 49.92138977973692, 59.51180450377926, 60.742542282227554, 61.11952520185902, 71.31348286905597, 71.1653192581669, 66.27960712678971, 66.11231019420009, 70.86277900203582, 61.86612875230851, 71.05291981850901, 73.73714677749142, 67.95628701486896, 69.2245932548277, 72.09703122415851, 71.32879580220869, 72.57760786241101, 70.93706869309949, 73.04115356937533, 74.44690750491235, 74.829220925608, 69.74105958015689, 72.38297985446069, 67.3467585348314, 67.86531940583261, 68.72758973029353, 70.187119360893, 63.46513786623555, 59.19555948626611, 64.90419272453555, 58.68707518423758, 60.32303302518783, 60.11708897929038, 59.348680973052986, 57.009312721990774, 55.95478742353378, 53.08734263143232, 54.807376477026175, 55.31921048318186, 53.51204510658018, 54.622621074799575, 53.3455365703952, 51.51458201869842, 49.47240391085225, 50.63030327520063, 46.895230200982866, 46.12986203162901, 53.228606793188284, 58.17270732695057, 59.4940322445285, 60.32115028750513, 63.37176976665374, 63.888796990917584, 62.659490877582186, 59.76068281358289, 53.94716539690572, 52.57466139331941, 52.560835038461995, 47.32776957173502, 44.92090125237742, 48.21183258487333, 47.251204905971406, 49.22881295604091, 50.36736326832926, 50.930697994847456, 47.75497844142299, 49.26503996695242, 47.44424435400194, 48.09025479901222, 49.90886957414689, 49.07316546286307, 50.049772877847, 50.276799663420654, 47.26857708346459, 51.38746976852418, 51.3865166325723, 53.399484849745235, 48.365142345428474, 50.548608149251635, 60.23893740869338, 59.23466159451393, 58.966983364474395, 59.68327091586206, 60.556629780800115, 62.83387945544336, 62.61415220076039, 54.78764695505942, 52.40488552278089, 56.31564155701668, 56.56440219571514, 58.98317883091589, 62.69770260780089, 60.39178040719802, 58.31481872066375, 57.16753329000166, 59.99987286906089, 62.17705895823818, 61.56662048832063, 64.9645148554156, 66.43077527323078, 68.15926182654597, 64.87444154677853, 67.89877722340246, 44.41637462185275, 42.97901030509703, 89.02973067375922, 81.55781945874615, 53.70917558670045, 31.811773354007354, 20.580313474901264, 16.597499578229844, 18.24897039321161, 21.925356964911185, 26.728991539247577, 5.285783592731723, 1.0600810906579419, 6.6284143347894, 1.1930004098723013, 0.04125400326184688, 0.10719197997522932, 0.08699417144300477, 0.16722041572774612, 0.10135877201513899, 0.101678705654077, 14.103248696173392, 42.84072714467203, 19.96666846736785, 30.343849851239113, 47.01907903917375, 1.9445373214060262, 0.07981811094308093, 0.07697194874767335, 0.03474813179984208, 0.16272772373932023, 0.9416398526199403, 14.202465049682127, 25.17620755780128, 22.9297229936046, 28.95557007481975, 30.369023623005038, 38.057212368134536, 20.87163967470969, 13.460636984917427, 5.080923101594371, 2.2840831789278218, 21.164075905276885, 37.438650669590125, 50.75646238942301, 40.26145496676045, 28.957907807442453, 33.68612304810555, 75.59765246606644, 65.2693340086168, 52.40440699361986, 37.66170409417922, 30.396423339843754, 55.728345071115804, 21.68783195557133, 0.07834849383441672, 0.13895929430521306, 0.12104391450843505, 0.28504930436611176, 0.1934989322457583, 0.020486344057585926, 0.20111476551861535, 0.34691709424218825, 3.995166420936585, 7.981888469188445, 8.376941257907498, 52.82421827316285, 47.21372273660476, 70.66802547823998, 65.88411454231509, 65.00917888456776, 61.84757986376363, 62.563114320078206, 55.57754170510077, 62.20073830696845, 68.03965307051136, 67.30922929702267, 73.36726727024202, 73.31963400686942, 72.74606581657164, 73.94621695241621, 75.83859582101145, 66.24859686820739, 72.59826306373843, 78.66052150726318, 69.41024687982375, 72.96893488976264, 74.00454259687855, 72.60380929516208, 79.07260571756672, 76.21553559457102, 77.24115694722822, 73.52702540736045, 77.36187181165143, 72.4203835764239, 74.32269388629545, 69.23512874111053, 69.58647897166591, 68.38634352530202, 71.26504159742787, 64.61394909889468, 61.632167216270204, 66.5555380236718, 61.749881467511585, 63.26694050142842, 61.89089459757652, 62.2401189034985, 60.14638123973724, 59.04259489428613, 56.485272299858835, 56.836912785806966, 57.987720504883804, 55.4012547000762, 55.765042766448, 56.02144025987195, 55.11643571238364, 53.471938871568256, 52.646142667339696, 50.1544060245637, 49.9292423648219, 55.549434000445956, 60.30709251280754, 63.657545812668346, 65.09835004806519, 66.38391863915228, 67.31003730527817, 65.69373446126139, 65.05400373089698, 56.18370479153049, 57.91936535989085, 53.97873263205252, 51.35838931606662, 46.27360513133388, 48.94428030137093, 48.99530249257242, 50.44258648349393, 52.6079583937122, 53.889812500246116, 48.96103666674707, 51.01705289656117, 49.71040156579787, 49.338651087976274, 50.07826105240853, 52.21249326582878, 53.25253325123941, 52.412216432632945, 50.49525607016779, 54.37014987391811, 56.079306987024125, 56.35711277684858, 54.14555103548112, 54.823670002721975, 62.1178311686362, 62.22157393732379, 62.94774193917552, 63.4416546360139, 64.36982077936973, 68.53868838279479, 66.26777725835001, 58.72642047943608, 59.330179152950166, 59.925598867477916, 60.8208014119056, 62.212042577805065, 63.346894095020915, 64.00314977092128, 62.300805814804576, 60.424022290014456, 62.922336747569425, 66.88690770056941, 64.97031211853027, 65.46560156729915, 67.13564872741699, 68.27199859003868, 66.37681914914039, 72.00643231791835, 46.98098105769004, 48.52414346510365, 88.87326732758554, 84.12690916369039, 72.61039887705158, 51.78286037137432, 39.027979373931885, 26.45200748597422, 23.620840695596513, 27.479252699882757, 34.36030003332323, 15.681373150117937, 7.027209064652843, 13.594498653565685, 1.2490127139514493, 0.36111221318283393, 0.31783186139598973, 0.054495369549840696, 0.20379964322332414, 0.20228766145244723, 0.15910270293393444, 17.453139135914466, 54.85223662468695, 23.112011224992816, 38.682398949899984, 65.1097837571175, 4.4250616238963225, 0.0920633982206064, 0.03448030746151363, 0.08175645894821613, 0.14308866143466967, 1.426336695590327, 19.24438165080163, 35.950126878676876, 39.27199786709201, 44.809890331760535, 43.64324800429806, 47.17517760492141, 26.818756941826116, 18.544993631301388, 6.737863171485163, 5.410666465759278, 35.780476523983864, 54.10743736451673, 62.128837339339725, 51.935013032728634, 42.25422689991613, 55.97228903924265, 89.61617992770287, 73.834060699709, 56.77135429074688, 61.47216196983092, 42.840754601263235, 65.26330924803212, 29.792223399685277, 0.3367628745975033, 0.21587305101415805, 0.33262226129731826, 0.388944739055249, 0.2783344517792425, 0.20573265159562712, 0.19536162906837082, 0.34721920867600753, 5.547511587219854, 9.073414956369708, 9.817371887545432, 69.31006170088246, 63.3470235332366, 80.0361437951365, 71.79702481915875, 71.29052915880757, 70.45391898001395, 72.39956363554924, 66.3296957938902, 67.01418076792072, 76.04604997942525, 74.3524254522016, 79.35571455186414, 78.2643150514172, 80.41589983047979, 81.72550078361266, 81.42879701429798, 70.1307156778151, 76.33193585180467, 83.43055509751844, 74.61782086280085, 75.66175183942242, 75.7143037549911, 76.84776675316596, 82.77726081109817, 80.14760971069336, 79.69223037842782, 78.2581804644677, 82.94905277990526, 75.59542455980855, 79.05188775831654, 72.98933121465868, 72.86797308152723, 72.14536266942179, 74.78878913387176, 69.62651068164458, 63.12345235578476, 69.68289867524179, 66.43932604020642, 67.63768857525241, 67.39359947942918, 67.20788309651037, 65.80191343061387, 65.04193852024694, 59.627424209348625, 61.87905296202629, 62.622714734846554, 62.076422706727065, 62.23137594038441, 59.362268063329886, 58.71445332804034, 55.694432258605964, 59.133746854720584, 55.238903876273866, 54.74821144534696, 59.97108659436626, 66.40920223728304, 66.42771582449636, 67.9739925938268, 69.97407190261349, 70.08481610205867, 69.12205465378301, 67.61918283277943, 57.76002691638086, 60.571534787454915, 57.55582440283991, 53.72366482211698, 52.27821257806594, 53.48756167196459, 53.06536559135684, 55.92344376348681, 54.98101195981426, 56.89607781748618, 52.158776406318914, 54.83467225105532, 54.34171269016882, 52.81323563668036, 55.02556224023142, 57.27455123778313, 56.991626754883804, 54.02421251420052, 51.78037358868507, 58.18656113839919, 57.999342487704375, 59.525575945454264, 53.42792987823487, 57.61012961787563, 67.92442952432941, 69.03311098775556, 65.86221987201323, 67.12936509040095, 67.36913957903462, 71.44199540538173, 69.432400426557, 59.66921706353465, 59.58944782134026, 63.05923138895343, 62.52682455124394, 65.12140573993807, 69.35082297171317, 67.70195268815564, 62.90518422280589, 62.96937381067584, 63.91930518611785, 70.33739320693478, 69.30031068863408, 70.98488238550001, 74.35899934461041, 76.89434882133239, 69.85030543419623, 76.5780959590789, 52.98090911680653, 58.89041085397044, 87.18227863311769, 81.6641470693773, 74.5063078788019, 57.09240028935095, 47.11467112264326, 32.70644833964686, 35.895288221297726, 39.65234225796115, 55.565409814157796, 37.571293461707334, 28.46087290394691, 15.137873849561139, 3.0112972278748793, 1.8113255404656934, 0.28124252153981116, 0.5068153028766955, 0.21704963949178496, 0.2369356578997066, 0.2714152375776922, 22.63672390291768, 69.62052514476161, 39.279975968022505, 44.68593951194517, 76.51190988479122, 4.2084987413498665, 0.1899981402581738, 0.17248941525336237, 0.21160561951898763, 0.3255887467774653, 1.5615287831714078, 22.193747105136996, 44.098337081170854, 47.53225841829854, 50.70819762445266, 50.732022100879306], [15.290438359783543, 24.753797708019135, 20.812321670593757, 17.317540837872414, 25.70633745962574, 17.06901358019921, 15.94824827486469, 6.215668224519299, 3.8271092839779395, 10.26579293512529, 30.70414504697246, 47.01029685235793, 55.70441076832434, 45.93036636229485, 33.69773326381561, 46.793201508060584, 44.92924021136376, 2.8326697935981136, 0.11839871249732473, 0.1177156072170023, 0.07108671575664513, 0.16280341322623915, 0.4526591685510451, 0.056154482337015296, 0.33422114808232556, 0.5868497647104726, 1.0056746907291874, 1.2782897752138878, 0.057488574661434665, 36.60756711036929, 70.85364772427467, 59.70493416632376, 50.777431380364206, 52.23719635317403, 50.9107566648914, 53.04713441479591, 51.49989666477327, 51.47693118741436, 57.70518041426136, 63.02651489934614, 70.26947344503095, 70.08497299686556, 64.76251279154133, 66.21924184983777, 63.950625311943796, 59.132554454188195, 70.57016234244071, 71.77716193660613, 66.2173669568954, 70.59569697226249, 70.96265039136334, 73.64330799348893, 73.99450917397776, 71.98010536932176, 68.60702391593688, 70.97804177191951, 73.78912602701496, 68.11283665318643, 68.39553756098594, 66.00769273696407, 68.95871147032707, 68.85540408472862, 65.7924448290179, 59.02164551519579, 64.79639030271962, 60.1070830129808, 59.98357149862475, 62.29463592652352, 55.22510497800766, 56.56459439185358, 53.14132621211391, 51.96637630462647, 53.418139642284764, 51.650943217738984, 52.33562431027813, 50.308159012948316, 52.373761515463556, 54.00974681300502, 51.518367105914706, 52.480520586813654, 46.9849544186746, 46.50503281624087, 46.07721597917619, 52.71654136719243, 55.19361619026431, 63.15113644446097, 65.00123216259864, 63.46849149273288, 64.85133094172325, 63.79192621477189, 56.77188381072014, 53.67265439802601, 55.33158163870535, 48.520515272694254, 46.16481427223452, 44.28998016542004, 44.33576207007132, 45.42497681033227, 45.02693468524564, 51.77389383316041, 52.87215355903872, 48.813343740278675, 47.45729015719506, 46.796676728033255, 48.69842613897016, 49.302706487717174, 48.934697951039965, 50.47853500612321, 51.451067078498106, 49.51209829699609, 49.72464761426372, 51.78859487656624, 52.27137980922576, 51.50857686996461, 51.70367948470577, 57.90375040423486, 59.86510415231029, 57.92603731155396, 59.86656327401439, 61.06867559494511, 64.08462916651081, 61.925540893308586, 56.96904959217195, 57.30254519370295, 58.52673261396347, 58.94102904104418, 57.74379222623764, 61.265280477462284, 60.726766509394494, 60.71212037917107, 54.885160999913374, 57.19637840024887, 56.97638050202401, 60.684012674516254, 63.94424361567344, 65.20263018146639, 65.74630991105111, 65.74451346551218, 65.15145501782818, 42.77129334788169, 65.30953830288303, 81.45130357434674, 60.460284602257516, 61.70411132997083, 37.91900765511298, 27.27134550771406, 20.22454273316168, 15.855735251980445, 22.202482223510746, 31.323044069351692, 11.444573037085995, 2.3609719305269183, 9.815527392971902, 1.4322588616801848, 0.27618919108663836, 0.2531572785829344, 0.062211284549125744, 0.4397689424935849, 0.026751298104382815, 0.4417866648685548, 8.179202810410532, 42.37739324569702, 34.81054106066304, 20.29661040152273, 43.59776027740971, 32.31394067887337, 0.5893339733442953, 0.04138706507341516, 0.024897903504390872, 0.5837732168935961, 18.885069008796446, 27.64926587381671, 8.782829103931304, 14.24091604448134, 15.41090121192317, 8.222364571786697, 34.631433871484575, 40.407037658076135, 34.86437166890791, 33.736482358747914, 44.20713186264039, 43.99258998132522, 38.02445665482552, 25.095961747630952, 18.445655684317313, 17.75076073984946, 45.384725447623964, 58.71055449208906, 65.7173785086601, 56.23576248845747, 32.88107225971837, 45.35830828451341, 54.136109890476355, 3.5041582392108057, 0.07620871067047119, 0.12488684902388243, 0.1647010130146819, 0.506701952507419, 0.5868797953571043, 0.7336203826050605, 0.36163790271647517, 0.42533820555094753, 1.667068119971983, 3.0741203600360505, 0.14171551011743086, 47.010167414142245, 69.55381347287086, 68.03084342710434, 67.18769073486328, 64.1425076607735, 62.562902512088904, 62.862967752641254, 58.51883296043643, 58.23300984597976, 60.44538351797289, 66.46483713580717, 73.79299348400485, 72.07896478714483, 67.89203859144642, 74.17920574065178, 68.11970080098799, 61.37451456439111, 74.7436583426691, 73.75155756550451, 70.36254344447967, 73.1590521720148, 72.53148078918457, 74.64898801619007, 77.73311630372079, 75.00068341532062, 73.27759404336253, 71.80770151076779, 75.93496845614526, 73.37690845612558, 71.32099813030612, 67.9515487917008, 70.29639659389373, 70.87071003452425, 66.76897771896856, 61.71327006432318, 67.11171442462553, 64.06158131937828, 62.4336878715023, 63.18368427215084, 57.558491614557084, 59.64428255634924, 58.31372830175585, 56.447656769906324, 55.29376999024422, 57.435384104328776, 52.890369046118956, 54.027487693294404, 54.70992126772481, 57.501421128549886, 54.64660636840328, 54.450672211185584, 51.16099995951499, 48.70087369795769, 48.52792070757959, 54.91402964438162, 59.60003822080551, 62.53561850517028, 68.83583145756876, 67.72503191424956, 70.53262525989165, 69.49888460097775, 61.780797589209776, 58.47120754180416, 58.00773635987313, 51.11752833089521, 48.52203322995094, 48.298269856360655, 47.38211008810228, 47.632392606427594, 48.38893152052357, 53.37590748263944, 55.480992563309215, 51.35096034696026, 53.51599885571388, 49.07766442145071, 50.88714007408389, 49.977197262548636, 54.16790854546332, 52.07961120913106, 53.26406109717585, 51.036190140631895, 53.07511268123504, 55.7943703282264, 57.35968628237325, 56.163504585143066, 55.3529546337743, 59.287817555089156, 64.34585117524671, 61.94011642086891, 63.79440515272079, 65.77238582795667, 66.09630692389705, 64.8844475130881, 63.69061531559114, 61.4902009502534, 62.127413518967174, 61.46720801630328, 60.76850445039811, 62.304771331048784, 62.94065029390397, 63.55085342161117, 61.07637912996354, 56.74528621858167, 63.515191232004476, 66.49617687348398, 66.95152482678814, 66.2490047947053, 67.6523974633986, 66.80505567981352, 68.65508864002844, 46.86824429419733, 68.35803185739826, 83.20792921127813, 67.69235072597381, 74.11840115824054, 60.012620572120916, 46.78709830007246, 36.84796525586036, 26.087042708550733, 26.915668902858613, 36.74568160887688, 19.816229881778842, 11.182641079348903, 14.26355302333832, 1.1950752211193885, 0.7253980528443091, 0.35248609379895274, 0.11507344657495139, 0.3081079686601316, 0.03474322500668707, 0.3356160409748555, 8.076425925377878, 51.03070274476082, 41.07162837059268, 26.97090764199534, 54.7140319116654, 46.64138617054109, 0.4195400844177892, 0.09246734872220025, 0.11931860023328375, 0.8644574135541917, 27.476593332905924, 45.048197853949766, 28.378459984256377, 31.350532039519283, 29.09023680994588, 26.86631960253562, 41.166157491745494, 53.552763231339, 51.586008379536295, 55.462933971035866, 65.69604081492271, 50.18343156383884, 42.8459870430731, 29.732201330123413, 28.172209993485485, 38.67618983791721, 64.5467745873236, 69.88304938039472, 79.92437193470617, 60.783170192472404, 53.82747427109749, 63.95232369822841, 61.52735756289575, 6.168505645567372, 0.2489806438285497, 0.41932671360911866, 0.28315691397555415, 0.7471838160868615, 0.8496755325505811, 0.43158258822175766, 1.0947525140739258, 2.012226644062227, 2.1708818597178308, 3.456946630631724, 0.22510258721247797, 47.047449542630105, 79.74653167109336, 70.11209226423695, 70.28443336486816, 69.14489853766658, 67.43049329326999, 70.45351105351602, 66.94837908590993, 64.67549893163866, 70.81352972215223, 74.48026334085773, 79.96044989555114, 81.66449223795246, 76.08475592828567, 83.04197372928743, 73.29547220660795, 65.9136264554916, 78.22254965382238, 78.27064575687533, 72.40818500518799, 76.75910549779093, 75.71119723781463, 79.49670022533786, 80.14167124225249, 78.9988886925482, 76.7663932615711, 77.55580948245141, 82.21885650388657, 75.38597783734723, 75.35614428981658, 71.81922543433406, 75.42429939393075, 76.17678257726854, 72.17483535889657, 65.89417934417725, 71.48233306023383, 67.91774580555578, 65.32768318730017, 68.00339468063848, 61.14345558228032, 62.229104888054636, 60.642164907147816, 61.24660999544206, 58.318129201089185, 60.35437276286464, 55.82835374339935, 56.969022135580744, 58.368845447417236, 62.0491151655874, 56.04717100820234, 58.53218470850299, 56.89211230124197, 52.12550294014716, 53.01582213371031, 58.37446228150399, 64.45267300451955, 69.00651731798726, 74.5141290849255, 70.64766837704566, 73.4758149423907, 72.0561287480016, 63.73201985513011, 59.53674293333485, 59.3227933299157, 54.44524757323727, 52.485886389209384, 53.17880838148056, 48.69944987758514, 49.923727512359626, 52.051503504476244, 57.11205528628442, 57.680579308540594, 55.86760882408389, 56.357497169125466, 50.099288878902314, 54.03020589582382, 55.84623190664477, 57.402832354268725, 56.12634405013054, 56.96754340202578, 52.55731667241743, 55.97772936667166, 58.78703286570888, 59.76748812583185, 57.40134577597342, 58.44457072596396, 63.94245109250469, 69.30184825774163, 64.49923546083512, 67.85423478772564, 67.78320850864534, 70.39455782982611, 68.20900532507127, 64.69091384641587, 61.66508374675628, 66.51704388280069, 64.05568207463911, 62.97213123690698, 67.29628547545403, 66.9781655649985, 66.08881519686791, 61.45820617675782, 59.48429299939064, 63.94621656787012, 68.39600040066627, 70.57148810355895, 71.95378626546552, 74.70611341537969, 71.8575156119562, 76.00472388728973, 51.574817857434674, 68.34974781159433, 83.96034963669317, 69.63151562598445, 75.46407222747803, 63.66878340321203, 55.70884304661905, 45.06605640534432, 42.72142041114069, 45.899764030210434, 63.669638479909594, 48.51601239173643, 18.59983621105071, 26.127148943562663, 3.027048731042493, 1.8355849096851966, 0.43985768611873355, 0.6066642305062664, 0.6946008892789964, 0.1745193797133623, 0.6519400268312424, 14.084350716683174, 60.10413731298139, 50.53742547189036, 34.10153342831519, 64.3803523432824, 55.692063147021884, 0.6415138766169548, 0.17747232690453532, 0.20715041987357602, 1.3739970783072135, 34.48548639974287, 54.33638218910464, 40.40216607432212, 48.65376603218817, 45.89550825857347, 34.92100677182598], [19.00567404685482, 3.2418063427171404, 7.703840473005849, 16.6123398657768, 7.840044286943252, 13.79534459883167, 26.555726720440774, 32.265293482811224, 21.592998850730158, 15.315413071263222, 32.870015098202614, 44.99550865542504, 57.251562226203184, 43.41642910434354, 21.715720007496497, 49.30594636547951, 24.08478452313331, 0.20359954105750208, 0.04908626020375279, 0.06322661917957087, 0.042880771816858364, 0.05182577146878166, 1.0176683181235868, 0.31056665124431737, 1.8909753955179647, 0.1162525401600907, 0.25519597644527114, 1.7524670665302586, 0.045054802941458846, 11.814819285946509, 65.89283004883798, 68.10280323028564, 51.10285474408058, 45.7577742299726, 50.32967321334347, 56.38915069641606, 56.67272237039382, 53.43643357676845, 54.835417501388065, 59.97831160022367, 65.58156644144367, 64.47168081037461, 66.52837953259869, 65.12344537242767, 61.0541549805672, 58.047105189292665, 67.13182833886916, 66.26908732998756, 70.21146943492275, 67.85051638080229, 74.41114333368118, 71.09185326483943, 72.51202583312988, 71.8619086665492, 71.70469222530242, 68.354384053138, 66.32070572145524, 66.83781531549269, 68.1625017043083, 65.38330631871378, 68.51044731755411, 68.67124096039804, 59.426167395807084, 60.448321373231956, 63.806737084542554, 62.991668562735285, 65.75152274101012, 58.71627723017047, 55.76302666817942, 55.49596425025694, 53.19883992595058, 52.06521611059866, 52.91624099977555, 51.98685499929613, 52.26111496648481, 50.33352498085269, 52.48931454073999, 53.373958064663796, 54.075995645215436, 47.884051876683394, 44.43448812730851, 45.59670602121661, 45.132634716649214, 50.48554820399131, 51.557661410300966, 55.62641051507766, 62.57121793685421, 64.88959758512436, 68.04560722843294, 66.14818419179609, 58.69391972018827, 54.50833105271863, 52.54561624219341, 48.70131300341699, 42.84933282483009, 44.252313644655295, 44.70430797146213, 45.541196638538, 46.80802806731194, 52.931906946243785, 53.35193395614625, 47.13786017510199, 48.37499533930133, 46.9859310888475, 50.586490400375865, 47.90294593380344, 48.367942917731504, 47.510677537610455, 48.819976468240064, 48.670361580387244, 50.87830689645583, 48.903695537197976, 51.94417568945116, 54.918673730665645, 52.21379941509616, 53.96468270209528, 58.385801853672156, 60.8934280180162, 58.42618265459615, 62.15551337888164, 57.767451963117054, 59.493808669428674, 59.837941738866995, 58.43103070412913, 58.25037025636243, 57.72068162118235, 59.75154369108139, 59.858192936066665, 59.85235252688008, 59.62044631281207, 59.13872434246925, 53.82697613008561, 58.89210139551471, 63.51390077221779, 60.23934925756147, 65.36749916691934, 64.29286387658888, 66.39462670972271, 57.52377079379175, 47.71412695607832, 66.04211545759632, 68.41646732822542, 66.47473719812209, 69.09075413980793, 49.79228104314497, 34.87174964720203, 26.45812246107286, 20.363984953972604, 25.507326203007853, 31.771210162870346, 23.51958667078326, 16.034585525912625, 4.831417212563177, 0.5063838421577408, 0.5919548520638097, 0.5508425291026793, 0.14217539269837642, 0.12861958945230131, 0.19676052093986543, 0.3360904026175699, 1.988886090055589, 40.265895089795514, 35.17987143608832, 19.98435051210465, 29.782380211737852, 46.45839191252186, 1.8514000287940426, 0.04694925793897241, 0.12836042190751723, 13.429712037886343, 20.397219196442638, 10.986055808682597, 32.57509404613126, 35.1599967864252, 42.745056613799065, 38.583610134740034, 24.773589987908643, 16.602645727895922, 21.117168280386156, 67.01557713170206, 35.48460037477555, 24.91679964527007, 32.20661482503338, 33.37216869477303, 32.131042518923365, 31.424180423059774, 47.58862287767472, 57.233072173210886, 67.42231907383089, 46.756029205937544, 22.571186980893536, 55.07643145899619, 28.08440773717819, 0.19984318213837765, 0.06734969289672953, 0.11770531099529997, 0.017720109730538343, 0.1892698817555943, 1.310635355691756, 0.8437352254986764, 0.9739965260509522, 0.10151432616816414, 0.7680773014022458, 2.3954297073425788, 0.032328554173751224, 18.057099811492428, 77.43198810085174, 71.4116519497287, 61.30386483284735, 58.31390873078377, 61.115826406786525, 67.07515793461954, 61.17557587162141, 60.494001296258745, 60.79993440258888, 64.51378353180425, 69.11784987295829, 69.02906310173773, 71.79388692302089, 70.47972817574778, 66.42145572170135, 60.32988540587887, 72.1405303093695, 70.79926013946533, 73.60344102305751, 70.18353431455552, 76.49676953592609, 75.19293446694651, 75.15513850796607, 73.9547912536129, 75.88877078025573, 71.81538935630553, 69.07955185059579, 70.48841230330929, 71.82557182927286, 69.9435950863746, 70.2655981433007, 69.23640743378671, 61.35107840261152, 66.24818109696912, 66.46466455151959, 67.13596251703078, 67.63062830894225, 60.702408590624415, 59.3241112462936, 58.49154895351779, 56.72906721791914, 54.88663188872799, 57.42568408289264, 55.25960614604335, 55.41283353682488, 52.616579763350956, 56.236998035061745, 58.70904045720255, 55.73881387710572, 53.55497544811618, 47.804517976699344, 48.81445377103744, 50.79567824640582, 52.40201434781475, 53.20693177561606, 54.161550383413996, 62.559140959093654, 65.40256515625985, 71.17524285470286, 67.1322911785495, 62.5688958937122, 56.206493762231645, 54.18486102934807, 50.14713002789406, 45.73437336952456, 46.16761484453755, 45.238534788931574, 46.894465338799264, 47.81256275792276, 56.73966938449491, 55.02617020760813, 50.04086909755584, 50.36747701706425, 48.651804847102014, 49.44507283549155, 49.28474987706831, 51.338428374259706, 51.61714415396414, 49.86334654592699, 52.131461020438906, 53.86406214006486, 53.632355966875636, 54.19780485091671, 57.37495999182425, 55.31210314842963, 57.37287721326275, 62.47123672116188, 64.04071823243173, 62.66590395281392, 64.02586421658917, 62.67873794801774, 63.54818228752383, 64.60564936361006, 61.86640331822058, 63.05909018362723, 60.16805233493928, 65.15542445644256, 62.69920095320671, 63.14642960025419, 63.726936463386785, 64.39557113955098, 56.97942033890755, 61.91945729717132, 70.80159787208804, 66.11223174679664, 65.69591137670702, 65.1456146086416, 64.2062500984438, 61.16145533900107, 51.394071117524184, 69.21685834084788, 71.62969650760775, 70.29400394808862, 76.11387560444494, 66.03386279075377, 53.08949601265692, 44.2111248354758, 38.05598858864077, 32.55381714913153, 38.96783767207977, 26.81247526599515, 11.908426650108831, 2.54660471793144, 0.6300850705273691, 0.21057331604101967, 0.4870267308527424, 0.24466514797700992, 0.2946413686919597, 0.10743638500571252, 0.3537087394825874, 3.066405057907105, 47.6469289102862, 39.16101440306633, 29.07228804403736, 39.29997221116097, 60.764495788082, 3.3043872685201707, 0.17606799580877827, 0.4299402795732022, 19.116045621133622, 34.746265180649296, 28.29945952661576, 44.254918098449714, 48.01072482139834, 55.3361511999561, 53.016892940767356, 50.60970298705563, 27.2966447953255, 31.528619412452947, 117.47320590480682, 44.727344051484145, 51.366598836837284, 80.16968481002316, 88.82206470735612, 70.57058595841931, 52.782382272904925, 67.78655036803215, 70.42912175578456, 79.12396523260301, 59.93116078838226, 37.921506204912745, 65.20987087680449, 37.235769994797245, 0.7524486787376866, 0.11464634489628578, 0.47000670865658795, 0.28101600466235993, 0.4584209771165925, 1.9865591439508625, 0.8423037442468828, 5.1691700566199525, 0.21258700879350786, 1.1377747861608383, 3.6140934498079362, 0.19123197082550297, 14.444245830658945, 84.20218729203748, 74.7288788518598, 68.75507770046111, 66.80671092002623, 67.84402093579693, 76.61192247944494, 67.73690885113132, 67.66838504422095, 68.19876793892153, 72.08703702495944, 75.02486090506278, 76.03259624973421, 79.00721196205386, 79.31390993056759, 71.36550134228122, 64.40778540026757, 76.68423529594176, 74.44711931290166, 77.23275523031913, 74.00484069701164, 79.65107687057989, 79.4147305334768, 78.22047079763105, 78.65949384627804, 77.62857729388823, 75.80783659412016, 72.22199009310815, 73.65105075220909, 74.98720615140854, 72.67020717743905, 75.00077755220475, 73.62242529469152, 64.36703981891756, 67.37062223495977, 71.7389972748295, 68.12869087342294, 71.81321636323007, 66.01757710979831, 62.856974371017955, 61.77897368707965, 61.85904102940714, 57.395415152272875, 60.73334824654364, 57.152883237408055, 56.98054213677683, 55.28056729224421, 59.02693287018807, 60.336043527049405, 62.66324066346692, 55.39522601712135, 50.82846533867621, 51.76542935832855, 54.08368741312335, 56.25724138752107, 58.691664357339185, 61.702903239957756, 67.38492319660803, 69.14747161249961, 75.82103929212018, 72.3598849388861, 64.25441680415985, 58.178551658507324, 58.24780110389956, 54.48032532968829, 47.499796882752456, 51.29004986055436, 48.81069221804219, 50.89609092281711, 51.039488853946814, 59.057958818251095, 57.774371024101015, 52.35508711107316, 53.56458917740853, 51.915934624210486, 54.06601713549707, 53.94626717413626, 55.52101250617735, 54.93543009604178, 54.460211415444654, 54.350706684973936, 56.432198709057225, 55.29481726308023, 59.25728582566785, 62.28222554729831, 57.89386210903045, 60.860080026811175, 67.2690720711985, 69.83480422727524, 64.57980486654466, 68.85453331855037, 65.82039956123599, 67.25506920968333, 66.1510867457236, 64.01515222364857, 65.60703439097252, 64.27578195448845, 68.91325904477027, 67.1800656472483, 64.17531436489475, 65.5593030683456, 66.3923046665807, 57.203674008769376, 62.219102844115234, 70.83529103186824, 70.75682009420088, 72.1837705181491, 72.61150498544016, 71.33450677317958, 67.44262910658314, 54.87142485956992, 70.02496857796946, 75.49946769591301, 70.11723056916269, 73.32401137198173, 69.28100478264594, 60.0887930008673, 49.68997386194045, 56.43676827030798, 57.01829494968538, 68.44142929200204, 55.023306877382346, 46.03559178690757, 13.99051389386577, 2.5016340084614295, 1.2622977817250838, 1.2901808081134674, 0.46924524790337013, 0.8173825363478353, 0.3655345936215693, 0.6902872626819919, 5.4594627118879755, 59.161274048589895, 45.486381515379875, 37.707784098963586, 46.62114674045194, 76.60588202937957, 3.490443426755167, 0.3748402023507703, 0.38999185867367253, 26.817164459536155, 46.389605306809955, 41.945814855637096, 75.91672943484399, 82.67028208701842, 91.89105264602169, 93.25114234801262], [23.256062230756207, 12.96506904786633, 12.275981172438591, 7.975492554326212, 11.175241528018828, 26.78860175994135, 38.820227115384995, 36.585715586139315, 25.597891769101544, 26.698361750571962, 23.85602601112858, 33.8823200041248, 51.15778361597369, 40.41895774102981, 26.61306784998986, 50.45683645432996, 10.06211111622472, 0.12133565611175953, 0.08394961545784628, 0.023660098855954506, 0.2040797096466826, 0.2607553079724312, 0.3954313893712336, 2.5123185448108183, 0.07964583309066874, 0.13524575970105587, 0.9987890311787206, 0.2530983051345233, 0.12868446177772938, 1.8519997837082034, 38.67365598678589, 47.44023176931566, 43.7736197440855, 42.58442771050238, 52.89529554305538, 56.56126037720711, 61.66310294981926, 56.93878458392236, 52.42681157204413, 49.58245385077692, 66.56610488891602, 63.69034074967908, 64.86017196409165, 62.154548475819254, 61.56626747500513, 56.6636852295168, 67.4023385201731, 65.50470759791713, 70.62457346147107, 68.76835884586458, 73.12149939998504, 71.13183006163567, 71.31310632151943, 70.97891253809776, 71.3046810703893, 65.47946714585828, 68.63398628850138, 66.71939895999047, 69.23123774989959, 67.4835394274804, 66.66501137518114, 62.68045202378304, 63.21424738053353, 67.37093602457355, 62.232509505364206, 64.56262096281975, 58.97449470335438, 54.76661912856564, 55.626755683652824, 53.512888416167236, 52.82097055066017, 52.05100928583453, 51.97837483498358, 51.27829059477776, 51.16150986763739, 49.95672249024915, 50.428944480034616, 54.65323909636467, 50.32655100668631, 51.01160864676199, 45.68563399776336, 44.191324710845954, 47.133365138884514, 50.34751215288716, 50.77997699860604, 50.719796073052194, 58.01036827025875, 63.87655135123961, 55.98712344323435, 58.85691381269886, 58.71405324628277, 47.91266948946061, 45.09144198509955, 45.540420009243874, 42.95604090536795, 41.82492348455614, 42.511310808120236, 42.12241565027545, 45.584079911631925, 53.187402294528106, 52.35755428191155, 49.83292464287051, 48.69410368704027, 48.547324672822036, 48.64334429464033, 49.52749359992243, 49.4288146111273, 48.814732259319676, 48.099593962392504, 51.40108431539228, 49.909536377076186, 48.89465447395079, 49.353587473592455, 48.71620624296127, 50.36438618936847, 53.45478634680472, 54.823956335744555, 58.98213940282022, 61.09569288069203, 56.987669083379934, 59.32594691553424, 58.78739372376473, 59.68919369482226, 57.49146615305255, 56.97944779549876, 57.15699388134865, 59.59887327686433, 56.674103044694476, 59.182184203978515, 57.03264297977571, 57.42356992536976, 57.388350963592536, 53.225574801045084, 63.64685735394878, 60.99839848856772, 64.79188349939162, 60.71950620220554, 65.04277006272348, 52.25525494544737, 46.02506414536507, 61.03211518256896, 59.29783528850925, 60.65568923950196, 73.18301785376765, 61.9992422288464, 44.27452602694112, 34.95642969685216, 23.78221877159611, 24.15186489782026, 41.130789479901715, 26.759840980652843, 4.181854571065595, 1.1691401418178313, 0.31861388394909523, 0.2655463299203304, 0.24560783448959553, 0.061067105421135505, 0.28245450327953986, 0.04410172444618037, 0.4424791470650704, 1.2029859063125428, 33.891619943803356, 39.480793476104736, 29.31986608812886, 31.995928633597593, 40.87471754320207, 3.6086320396392577, 0.2365649326313888, 4.025049488390646, 21.044151398443407, 2.4103030898878655, 26.386947131926014, 18.836453191695675, 10.27850337566868, 3.219679517130698, 16.845616948220037, 44.484792524768466, 22.788674562208115, 32.21572845212875, 47.583272764759684, 20.623145757182954, 48.73444526426254, 52.31071333731375, 60.61038586401171, 43.259879466026064, 39.189663394804924, 39.92433509519024, 43.860508088142645, 66.88183215356642, 43.59717584425404, 27.71856631002119, 59.183325613698656, 11.75344595986028, 0.07871060827446562, 0.09318083704959962, 0.07020517072129635, 0.4754502842983892, 0.8514086072964053, 3.2906217104004276, 6.893878386866662, 1.4650917966519634, 0.16751604905772596, 1.5902883367192362, 0.2653159826032577, 0.24392616424349048, 4.331459162696715, 55.30256002180038, 63.49940761443108, 59.33086556773032, 59.23517150263633, 61.870364912094615, 63.80002590917773, 67.40582942962646, 61.39605622137747, 59.064591546212476, 54.65250561314245, 70.4862863786759, 66.94489602119693, 70.7902543775497, 67.33252817584624, 61.952318914474986, 60.60987595588931, 72.80166149139404, 71.72318227829473, 74.96541346273115, 75.40427961657124, 75.97695350646973, 76.27949376260081, 75.68671380319904, 74.15221983386625, 74.06566096890357, 70.78267635837679, 69.75646665019374, 70.24477820242606, 72.90674963305074, 69.6286444510183, 69.10963642981746, 60.99171869216427, 64.09711799313946, 70.05342145119944, 63.76855673328523, 68.06790198049238, 60.79390571963403, 57.15268711889944, 59.62310175741873, 58.58886295749296, 57.03961695394209, 55.9852328608113, 55.04962990360876, 53.26448079078428, 54.17114057848531, 50.458024932492165, 52.61386156082154, 58.7171793753101, 53.66184042346094, 53.28575572659893, 48.33917625488774, 48.516773331549864, 50.79609401764409, 51.84639100105532, 52.81289831284554, 50.82016952576176, 55.81786924792875, 62.92679648245535, 56.66688196120724, 59.02811350360994, 60.388654278170684, 49.164129149529245, 48.09484397211383, 48.13156912403722, 45.42520823017244, 44.45843811958067, 44.93162501242853, 43.59055880577334, 49.27451249091856, 57.20558812541347, 51.50873768714167, 51.37883663177491, 49.42346057584209, 50.5633758729504, 49.84982221357284, 50.7484293753101, 50.92156279471613, 51.00365015768236, 49.981621696103005, 54.15965195625059, 52.88415208939583, 51.7562274779043, 53.3558367144677, 53.67787115035519, 54.26759166102256, 58.40823388868763, 57.28435716321392, 61.640278677786554, 62.505514314097745, 57.9066490357922, 63.33990835374402, 62.62102419330228, 65.58541820895287, 62.307497378318544, 60.80108365704937, 60.60376098079067, 62.51505351835682, 58.77976471377958, 61.14991180358395, 61.12025868508124, 64.2214963513036, 60.80615920405234, 55.91739939105127, 69.23792931341356, 65.5251862925868, 68.36983819161692, 60.77079119220857, 64.98027493876796, 55.11711820479363, 50.70432624509258, 63.83786893660023, 66.34900169987833, 63.19705563206827, 78.34521001385104, 75.32666375560146, 61.55998383798907, 52.56094486482682, 44.415421485900886, 38.40213383397749, 48.17635082429456, 24.924418849329797, 2.826901948259723, 1.106024302782551, 0.23436305804118035, 0.29371363621565605, 0.7430022017609689, 0.20653465372179786, 0.3017345154958387, 0.21938665199183652, 0.46702135594621785, 2.046433756909063, 43.27796551489061, 46.651505885585664, 32.382438990377615, 37.72977682851976, 54.23172158579673, 4.672198401343438, 0.1305565355165351, 7.703014323788305, 37.0668335114756, 17.269644775698264, 44.13993381684826, 39.96380590623425, 31.962388446254117, 24.55046988302662, 37.023220677529615, 92.95832172516855, 69.40660692030384, 69.97626842991, 105.63661452262633, 68.74599349114203, 105.68376925683792, 93.2315383418914, 94.98932500039378, 73.95865871060279, 61.71157560040874, 54.48212569759738, 55.609948327464444, 74.68545821405228, 59.0126475980205, 44.665021511816214, 66.25773599070888, 18.691921695586174, 0.2746378017529365, 0.31508592648371575, 0.12067213203878173, 0.7252942326088107, 1.0333424157673314, 1.3213376652809883, 7.097944598044119, 1.0276393508238177, 0.2988600616733874, 1.9215223241236903, 0.49293250266102057, 0.414230635449771, 3.767931014299393, 59.401742796744074, 65.74831031983899, 66.66013194668677, 66.14024531456732, 67.77410076510522, 70.15448524105933, 73.53079872746622, 68.75302237849083, 70.67783924841112, 63.298774457746944, 78.18431438938265, 74.2609400903025, 80.96925212490945, 76.62591749621977, 69.04428974274667, 64.75481317889306, 76.81408928286645, 76.40593528747559, 77.2905788113994, 77.72312994926207, 79.31269399581417, 82.43554392168599, 78.06057145518642, 75.93765135734313, 77.31011221485754, 74.21705661281463, 74.0562786594514, 73.68617165473201, 75.51269392813407, 72.24867005502024, 73.7818931764172, 69.62485544143185, 68.31019463077669, 73.53149690935689, 68.04165347929924, 70.4364408985261, 64.37299397683913, 62.07310045919111, 63.68744996286208, 62.541984511959946, 60.756906001798576, 60.486619395594445, 57.85879219731977, 57.27751262726323, 57.234264573743275, 54.845329330813506, 57.03998565673829, 58.51753073353922, 56.080977916717536, 56.721418596083126, 52.54864823433661, 51.934746311556914, 52.327909008149184, 55.19706787601594, 55.295586047634, 54.725226356137185, 60.50127337055822, 69.8319330523091, 60.48773727109356, 65.43928638581308, 64.00020407092187, 51.791477818642896, 49.29335947959654, 51.07122475101102, 48.12285753988451, 47.57606737075314, 46.70552084522863, 46.081040290094194, 51.776792464717744, 60.222318326273275, 56.616808983587454, 55.774715331292924, 54.521965211437596, 54.03812516120173, 51.84049567868633, 55.27287160196612, 54.589194636191095, 56.27913605782294, 54.380716739162324, 56.83290412349086, 53.560584437462595, 55.16990154020248, 55.458101610983576, 55.94706819903467, 56.42198877949869, 61.038022272048465, 60.717615619782485, 65.50875940630513, 64.18200200603854, 60.25937687966132, 66.01574144055768, 64.93227297259916, 68.32153812531503, 64.44942920438706, 63.90499245735907, 64.38950715526458, 65.22398748705464, 62.72489640020556, 64.20359857620733, 62.73120749381281, 66.16309704319124, 61.771187782287605, 55.31024786733813, 70.95072638603949, 71.81971180823543, 71.43772002189391, 65.12703826350551, 70.9463176419658, 60.49186752688501, 55.59969132946384, 66.79524190964239, 69.6139669418335, 65.14157064499395, 73.44255324332946, 76.73015840591924, 66.91399558897942, 54.929876019877774, 56.62240228345318, 64.03278327757313, 76.59093779902305, 62.36892561758719, 16.92363681331758, 1.0850662209333912, 0.5339591769922165, 2.6559334320406762, 2.212616858943816, 0.19499862596632975, 0.7494706804713895, 0.2696082813124503, 0.8186126284060941, 2.6809802170722716, 54.61022638505506, 53.942478164549804, 45.51734078314997, 52.29061119018063, 72.2428257234635, 6.689723432064057, 0.9116430977179159, 10.768918298905897, 49.79524635499524, 29.778344092830537, 78.55166789024108, 74.19236921495008, 59.78661752516224, 46.00816265229256, 66.90922598684988], [7.8709962002692695, 16.06141846026144, 32.25538949812613, 15.281260013580324, 3.5063660433215484, 13.100951717745874, 31.720886153559533, 28.383055040913245, 30.265345573425297, 29.251208920632642, 22.678222579340783, 29.805235862731937, 51.76456643689064, 20.50211710314597, 41.103277975513095, 39.985112221010276, 1.1028084495375234, 0.06646453192637813, 0.07833817463007667, 0.1266644717825036, 0.09917193573088416, 0.1239435496409574, 3.199151057389475, 1.8912845273171703, 0.2512240097407372, 0.34035123043483306, 0.515526366089621, 0.2653239805611872, 0.993472503558282, 4.648330778844895, 20.30014445704799, 45.284850135926284, 46.87598313054731, 44.18826133974137, 52.98628668631277, 58.57229486588509, 58.448344046069735, 57.76006221771241, 52.96143847127115, 47.10983091785062, 59.43157634427471, 59.49069822988203, 63.120173254320704, 60.38097427737329, 55.41826994188371, 63.274957826060636, 67.3119435771819, 62.28553995009392, 68.7358110181747, 66.11343983680972, 70.5566458548269, 71.6322538929601, 70.89975910802042, 70.65550527264996, 72.17073255969633, 65.31466091832807, 69.34490803749331, 65.1291524210284, 67.9687209283152, 65.6361109210599, 63.9290601207364, 56.908441128269324, 67.86910057067871, 67.32887252684563, 70.55103686548048, 58.15646871443718, 56.08350000073833, 54.567197984264745, 54.916892974607414, 53.284190700900176, 51.4331026231089, 51.3952164496145, 53.28479082353654, 50.926583428536695, 49.80600149400773, 48.0960520621269, 49.5790845347989, 51.5358647992534, 52.66490336387388, 47.93343843952302, 47.49134025266094, 46.54832401583272, 46.82490210379324, 46.55333680491294, 49.542728085671705, 48.53077619306503, 50.98345779603528, 50.66214507625949, 49.11694303635628, 51.32130722845755, 52.242460173945275, 45.62047950683102, 45.24023709758636, 43.723127072857274, 43.332439391843735, 41.54271679539835, 42.18292605492377, 41.67327288658389, 51.97964176054924, 53.123114647403845, 48.485535575497536, 46.818551786484264, 47.91448162448022, 48.11272605772942, 48.686780621928555, 49.48923087889149, 47.76864397910334, 47.00568414503529, 47.72124998031124, 49.793014526367195, 53.816024872564505, 51.64464781361242, 50.286001543844904, 51.30432336561142, 48.36266732984974, 52.458959317976436, 56.61773466294812, 57.76012105326499, 60.6991373339007, 55.87293540277789, 60.796882798594815, 59.18439249838553, 59.74779782756683, 58.0872820269677, 58.13086740432247, 56.842278588202696, 59.26827238452051, 54.67180759676042, 56.462597077892674, 59.910717395044145, 58.14570180831417, 55.6416214666059, 54.39281332877375, 59.53102019525344, 62.58713491501347, 62.613477553090746, 57.36136113443683, 58.583646205163774, 53.13505826457855, 45.5202982502599, 58.01465149848693, 60.97803746500323, 64.88149004597818, 70.40323411264728, 68.47233756895989, 47.53832240258494, 37.758363062335604, 26.686745651306648, 33.377330533919796, 43.41176540620866, 7.252440875576389, 0.9486057368978378, 0.129755437374115, 0.10044657580193975, 0.020496552179176963, 0.05860347773939852, 0.048176377576084874, 0.16663987429872637, 0.15705623694004553, 0.2028269873511407, 0.4645621524222436, 26.157776771053193, 41.73666623330886, 31.7129139361843, 27.93976837588895, 29.133124005409982, 2.241232755684084, 0.17024168264000647, 10.502668792201627, 9.296456613848287, 11.493891939040154, 12.957329230923808, 7.768901807646598, 3.2042707310568903, 3.978221536644044, 6.213557989366594, 23.301224400920255, 26.948114748924013, 40.5911890152962, 17.766332549433557, 34.095112508343114, 39.30990757480745, 60.58234483964982, 50.87893055331323, 50.12223866678054, 46.98869635981899, 36.66271171262188, 45.4150414466858, 64.74663895945396, 24.284790100589877, 47.49945171417729, 48.01598864216959, 1.2161892171828979, 0.16410459824387105, 0.06259002309713153, 0.18791910020574448, 0.61334028840065, 0.40361667111996685, 1.7202071653258417, 2.6746723103907803, 1.0990975196323087, 0.7600797724819953, 0.9712088240250465, 0.34156033168396643, 1.0625547579219266, 3.7763974503163373, 29.917802003122148, 57.10543040306338, 57.249385310757546, 51.175034199991536, 61.25149334630659, 67.95763631020823, 64.72722714947116, 62.193470155039144, 60.12269404626662, 56.38228654861451, 61.643557779250614, 67.21167210609683, 69.75500752848964, 67.16965567681098, 58.73166468835647, 68.9016958975023, 71.09938421557027, 72.0712455626457, 73.33861827850342, 72.04857426304972, 73.459364521888, 74.03869075159874, 73.88932689543694, 73.99413262644123, 72.07237520525533, 67.89958523165795, 70.22901027433335, 68.80165976862754, 69.64118034608903, 67.57905698591664, 63.208936491320216, 61.29396084816226, 68.79989470205, 67.77356732276179, 72.16815164012294, 63.11568606284357, 57.356528774384536, 58.38226387577673, 58.109929792342655, 57.7579951286316, 54.97349277619393, 54.185763174487704, 56.0344115380318, 53.45362532523371, 53.33143172725555, 50.57244831515897, 50.62442364231233, 55.59298015409901, 56.17319676183886, 50.73789388902726, 50.824303703923384, 48.449736102934814, 50.01067469196935, 48.214405659706365, 49.08650936618928, 47.45695675573042, 48.321305936382664, 50.400370013329294, 49.61424466102354, 50.83684352136428, 51.58347452840498, 48.44245226152482, 46.72209678157684, 47.86206306949739, 45.97955288425569, 43.32889749157814, 45.06256157352079, 45.16136215579125, 53.299597770937034, 53.47854806530861, 49.60408179990707, 50.348696708679206, 50.23787798420076, 50.14214077303487, 48.9347646313329, 49.559362857572495, 49.01252561999906, 50.91421619538338, 50.815976512047556, 52.243511369151456, 55.16797957881805, 54.23289045210808, 54.825027142801595, 55.246576032330914, 52.09466918822258, 54.922690237722094, 58.26677753079323, 60.31797709003572, 61.57051147953157, 60.44665436590872, 63.71087827990132, 62.51518687894268, 62.96104269642984, 62.64095767851799, 61.014939123584384, 61.90754898132817, 61.2963770281884, 58.98635595075546, 57.42544481831213, 61.09692058255596, 62.43424484806677, 59.88814807707264, 54.73680519288587, 60.51039288120886, 66.67393868969333, 65.74264641731017, 59.071600821710405, 59.437467744273526, 55.875206455107666, 49.20896968533916, 61.431934141343646, 68.15458636130056, 68.15777132588049, 74.40423211743756, 74.53603159996771, 61.550762345713956, 54.13595299566946, 46.279802476206136, 45.60789262094806, 56.231506716820505, 13.286548468374438, 0.8181564077254265, 0.2577014057145965, 0.08827613531461648, 0.020379241135331894, 0.10649826437715562, 0.1860028998025002, 0.17761800618421647, 0.1340800803154707, 0.1805067705290933, 0.6300421696036094, 37.46121998756163, 49.671679927456765, 37.976454688656716, 36.50191414740778, 43.06352561519992, 3.10319566438275, 0.1509711086269348, 18.06537012900076, 22.339651430806807, 26.794365682909568, 33.385014457087365, 22.963116092066613, 12.98283346237675, 9.135681602262682, 17.366994081004975, 45.79891597071002, 93.37018628274241, 127.1374474802325, 95.69725790331441, 68.04293217197542, 50.48545406710718, 76.38921814580118, 78.54254445722027, 81.72044877083071, 69.60849131307295, 53.01000525874477, 62.63425827026368, 77.94379465041622, 39.77483395607241, 62.02196451925463, 58.30224752426148, 2.633536453208616, 0.16845067632534813, 0.21310998637589718, 0.5742193650334113, 0.4391872978979542, 0.5883007352390598, 5.904174668173637, 3.3825500549808627, 1.9191882687230266, 1.581078856702774, 1.0305135288546163, 0.938292661261174, 1.8995468775110862, 4.952008522325947, 31.423254743699108, 72.72691680539039, 63.96239634483092, 60.277992448499134, 68.86483346262287, 73.3594068404167, 71.22169156228343, 69.68122774554838, 72.12509186037126, 65.52581779418453, 72.17518837221208, 72.46992311170025, 79.58591061253702, 74.4674607246153, 62.462705566037094, 70.11483007861723, 76.84254215609643, 71.37276557184035, 76.47412961529147, 74.48146358613046, 75.71664933235415, 76.64330928556382, 77.10664318453881, 76.75411624293174, 77.05803717336347, 71.00076013995756, 76.63614703762916, 72.38706696418025, 73.43175888061523, 71.02421591358801, 69.41277288621473, 64.74919242243614, 73.31135780580583, 73.05166552143713, 77.82123627201204, 65.73373479227867, 62.30624221986341, 61.681177231573294, 61.97243675108879, 62.3671958523412, 58.81054355252174, 57.14382648468018, 58.35672924595495, 54.55173992341565, 56.232448085661865, 51.39777383496685, 54.0808319276379, 58.891379679403, 60.13963868541103, 55.71010997218471, 54.173372407113355, 53.634034741309385, 51.30923417306716, 52.07580651006391, 53.064820381902884, 49.063920436366914, 50.27286944850799, 55.234342159763465, 52.30474348991148, 54.2516040802002, 53.40151663749449, 49.62210116847869, 47.65056494743594, 48.08088425667056, 48.77514769954067, 46.15230975612518, 46.22909407461844, 46.70141412365822, 57.736520151938166, 58.7215998864943, 52.56781293499855, 55.640381997631444, 56.04535495081256, 54.057238871051425, 52.71329756705992, 54.771612305794996, 54.22941130976523, 55.72701538762739, 53.29889958904636, 56.0098575007531, 57.845291399186664, 57.65701370854532, 59.04434034901281, 56.788455824698175, 54.2221627696868, 58.07955888009841, 63.42218006810835, 63.57891405782392, 66.93169332319691, 62.790262699127204, 69.86112333113148, 64.94640527233001, 64.30009280481647, 65.3982348595896, 63.39953622510357, 63.27186699836486, 64.5660844156819, 62.146362489269634, 60.330960135306086, 63.086401647137066, 65.74006157536661, 60.94331664423789, 55.1187381436748, 64.81067165251702, 71.72311952037197, 70.40233981224799, 64.88289425449987, 64.24523453558645, 62.22226427447412, 54.2646106596916, 68.34164419481831, 70.96404675514468, 69.7175096696423, 71.64482901173254, 74.17802902960008, 65.04486068602532, 58.4436881926752, 57.17636646762971, 65.68762340853291, 79.78057784418907, 30.70301736554792, 1.758119201948566, 0.7718184458151941, 0.16682347493065944, 0.12665857290548663, 0.462254511733209, 0.32936574410526986, 0.649958004153544, 0.3194001965945767, 0.5846594274044037, 0.6603500174899256, 50.229962641193026, 55.232686919550744, 53.90713368692706, 51.86873674392701, 65.21921004018476, 4.84902375167416, 0.39160885577720983, 28.860958583893318, 35.97655188652777, 56.801646755587676, 68.42368448934248, 37.93188871875886, 17.60132039746931, 21.753674822468913, 37.56369975305373], [14.021241741795695, 47.514403789274155, 47.81904251344743, 31.226057583285918, 3.1084560530800975, 1.2624516121802793, 0.3504125082925443, 8.127831037967436, 15.561558469649285, 29.656799647115893, 31.54444813728333, 47.37064892245878, 30.00859114431566, 51.543368293393044, 61.507706488332445, 16.953550769436745, 0.09442550776105735, 0.07229868217461533, 0.26189659511850727, 0.0971901965057177, 1.2170368168623218, 0.869147158678501, 12.6194356718371, 12.743379627504657, 4.401037596887158, 1.6350940614938738, 0.11646551260304068, 0.2359660510574618, 0.6973502256216542, 4.8567243449149595, 11.689359334207351, 23.713369407961448, 40.72853472925002, 43.01758289337159, 55.582848671943914, 54.85897133427282, 53.108193951268355, 52.033229181843424, 47.809099305060606, 50.04374419489215, 54.165531589138894, 57.26966396454842, 58.96896808378158, 58.31759575874575, 54.717044291957734, 64.44852705924743, 64.49555235524332, 66.47481564552554, 64.7965040514546, 66.83877237381475, 70.36576763276132, 71.24296649809807, 71.21247399237849, 68.66975045973255, 65.13873477135935, 67.37684311405306, 65.61903292132963, 66.65425623616865, 62.866764606968054, 62.36517190933228, 58.36889643822947, 64.46982945165327, 66.52590059464978, 69.45587188966813, 66.45003411077684, 55.127787051662324, 55.63341586820541, 55.318865314606704, 53.952782230992476, 52.97837918804538, 50.61919120050246, 50.935032213887865, 50.087804179037775, 48.89360720111478, 50.786774466114665, 51.183110360176336, 49.54661515451247, 51.31412536867204, 55.19935461782641, 44.46315673089797, 47.06358617351901, 44.09814096266224, 46.01132016028128, 46.06858676479709, 43.960736413155836, 45.62337813838836, 46.9679234873864, 47.70875330894224, 46.81627681178432, 46.195816686076505, 44.542616105848744, 46.10766533882388, 43.74370382678124, 40.86992048448132, 44.271607783532914, 42.32781448671895, 43.42310497837682, 43.45289537983556, 48.54588908533896, 49.29452050116755, 47.15602859374016, 45.93686965204055, 47.37827793244393, 47.91367361622472, 48.54469668480658, 49.630373447172104, 47.439859144149295, 48.11755841778171, 47.513293758515395, 48.4112419620637, 48.858376472227036, 53.62316977593207, 50.13393125226421, 51.54558443254041, 53.40436820060977, 48.84868429553125, 52.27287815463159, 55.49416388234785, 57.5712981531697, 58.56940800143827, 57.284969052960804, 56.784960992874645, 58.786632783951305, 55.59970701894453, 58.81833337968396, 56.3678639934909, 55.266560508358864, 57.101304069642104, 54.46713832116897, 56.595200646308164, 55.00866466952909, 60.13150368967364, 50.945144084192094, 54.52134939932055, 58.55598565070861, 60.091546504728264, 57.10732883022678, 55.01568178976736, 48.841761312177105, 40.535620797065, 57.46692780525454, 62.17092437128868, 62.48199186017437, 62.727387105264974, 70.1050006189654, 54.6255079392464, 37.48802546531924, 26.956916547590687, 48.70625911220428, 26.6294555125698, 7.178552246862843, 0.12297850102186204, 0.1396939113375641, 0.08341536872209081, 0.043076514942391265, 0.0471330615842054, 0.1299835936797242, 0.07925278402023739, 0.0804398219371515, 0.24850818208388745, 0.20557413268233501, 22.81578794602425, 35.24364525272001, 22.1377533097421, 22.648171340265584, 12.103639091214827, 1.577606823655867, 0.709196518986456, 11.925633107462238, 5.865803591666683, 7.19123621140757, 5.660641078026065, 2.4313659725650667, 0.8326040905329489, 0.40871351536723877, 0.7532920496117684, 28.153382616658366, 22.962447327952233, 53.99367294003887, 28.52852986704919, 17.453072455621538, 6.7709135528533695, 15.5544226977133, 40.795207177439046, 36.30264597554361, 45.32295203978016, 46.371758522525916, 62.43094613475185, 46.000153172400694, 49.851959905316754, 73.49229674185477, 19.537163049943988, 0.2302793037867354, 0.06644368667395846, 0.2388439675973308, 0.0941079106902884, 0.4718502839246104, 0.7466843880472646, 3.139209641564277, 5.505447599195666, 0.6361577575725894, 1.1859220026000854, 0.15559699266187607, 0.2582429992335458, 0.5636228368647638, 5.890797424700953, 16.53453769222383, 33.43158475814327, 56.54682605497299, 55.735115082033225, 63.46064675238825, 61.58356904983521, 60.2933132263922, 60.317718213604344, 53.68536679975448, 58.03798567864203, 59.75651725645989, 64.03075148982387, 64.85222131975236, 63.95810134949223, 59.422154811120805, 69.42771711657124, 68.98124156459686, 74.10452381257089, 70.06761258648288, 69.57074242253458, 72.17163470483595, 75.66698428123229, 70.6760584923529, 71.10860178547522, 67.35979649328416, 70.17392450763334, 71.01610445207166, 68.95483616859683, 66.305494769927, 65.11425525911393, 62.38998090067218, 69.18383982873732, 66.76978572722405, 70.49628842261531, 68.49386353646555, 57.452803350264034, 56.049838219919515, 57.95136013338643, 57.821455155649495, 56.25333862919962, 52.3639085215907, 56.242305001904896, 55.25388340796194, 50.815996123898415, 54.06463253882624, 52.8302038100458, 50.19508100325062, 54.51959609985352, 57.10528135299683, 47.47242266131986, 48.32129416927215, 48.76405523669336, 50.0216337942308, 47.16533245578889, 44.70675945281983, 45.03750155048986, 46.851127070765344, 49.64268576714301, 47.96584113951653, 46.66486547839257, 45.888957900385705, 46.825415934285815, 43.825328350067146, 42.26505264159172, 45.088719860199966, 44.47819117576846, 44.2395894758163, 45.41173096626036, 49.45898156012259, 50.31879648085564, 48.57285930264381, 48.39401491226689, 50.2833382544979, 52.564722107302764, 51.71937681013539, 51.0974536403533, 51.66816634516562, 52.15421468980851, 50.889983792458814, 51.35506706853067, 52.7994445831545, 57.56502236089399, 55.491763391802394, 54.3624855626014, 58.25263738632203, 55.83936775884321, 54.17549833174675, 57.813916360178304, 57.43353666797761, 61.447823662911695, 60.767747432954856, 62.42161873848208, 61.2548783517653, 61.51428822548159, 62.99661859389275, 62.58403232020717, 58.773853701929895, 60.434542086816606, 55.204747876813336, 57.168054965234575, 58.59458569557437, 62.94304686207926, 51.48607030991585, 59.50721925304782, 64.02940219448459, 63.13630596283944, 58.66860474309614, 55.42379263908633, 51.13379439999981, 44.64572345056842, 62.288309143435576, 66.81224930670955, 67.56037865915607, 68.8312344397268, 75.9105791584138, 68.17402562787457, 51.90056677787535, 43.30677924617645, 61.496519888601, 31.07496984543339, 6.255137564674501, 0.18319120390280602, 0.1313628583785988, 0.09713180528412904, 0.042720513883978135, 0.05967882769783178, 0.014055607626364838, 0.21602211640246455, 0.05939616423641002, 0.1464843001937674, 0.16949718307343223, 30.8816695597864, 43.53539851404006, 30.90402314739843, 32.3468219080279, 23.648950361436416, 1.89866986005537, 0.7265674707389648, 22.53096699714661, 20.30628492755275, 30.510683944148404, 13.828107176288484, 5.45167435561457, 1.2380824165959512, 1.7463623876533203, 6.247301649662757, 48.423828847946666, 102.58666576877718, 125.41366777112408, 123.40595552998205, 29.062819442441388, 4.756556816639439, 14.880057438727349, 66.70156002044678, 60.93330675555814, 69.61679104835757, 62.07047639354583, 76.25373163530904, 52.56868762354697, 74.14810134518531, 82.59362328437068, 28.15425926639188, 1.0834373341452692, 0.22214507413727624, 1.3566165657774096, 0.1846930120260485, 3.2772393188168927, 2.52578109983475, 26.82222039468827, 30.073663265474384, 10.519432021725564, 3.6688151715263246, 1.2697833800508131, 0.35015614462956307, 1.5244607915801387, 8.222749454359855, 19.82347449948711, 36.5418517205023, 62.834420742527136, 65.92704096148091, 66.97130141719695, 64.88746773812079, 67.94661445002403, 68.04771746358564, 69.58395296527495, 68.86518647593837, 66.5145335658904, 71.59838814889231, 76.0712080617105, 74.65822127557571, 60.54839672580842, 72.62076177904683, 74.24775308178317, 77.42672428008049, 70.60339266254057, 73.27780585135184, 75.43270111083984, 79.12028604938139, 76.25694013411, 74.4558269746842, 70.2505676208004, 73.55581560442525, 74.22043769590317, 73.60552772398918, 68.21951727713308, 69.5265059317312, 66.1656387390629, 71.25170553884199, 73.66412008962324, 74.78824000204764, 72.33986516152659, 61.82484972861506, 60.3197931474255, 60.72345995133924, 60.24214982986451, 60.413518182693, 56.880823719886045, 59.91885239078153, 57.687400310270256, 52.81377300139397, 56.82758146716703, 55.023236274719245, 52.34636375980993, 58.02587339954992, 60.930517950365626, 50.344229129052934, 51.80969330572313, 51.3413623071486, 51.77567458921864, 50.51085141397292, 45.94232566895024, 46.0035813239313, 49.365193766932336, 53.182071793463926, 50.250311897647, 48.94588455077141, 46.96775090309882, 47.956909902634166, 47.546528000985425, 45.06900210534373, 47.76172491811937, 46.991944082321666, 48.450681394146336, 48.404577855140936, 54.66641433777348, 52.71550193909676, 52.71638055001536, 52.41362064115463, 52.655481830719985, 54.572685380135816, 55.97491702725811, 56.744901826304776, 53.63243441427908, 56.5857595013034, 52.9467099712741, 53.213501745654696, 54.160479576356956, 58.83155568953484, 57.71439013942596, 56.9179371864565, 59.07488384554463, 56.431178892812426, 58.04242580167709, 62.994610340364524, 60.65341034243184, 66.07498491964033, 63.13123041583646, 65.82458865258002, 63.95457121633715, 62.73507887317289, 65.90487172526699, 64.72507769061674, 60.37469064035724, 61.96385460515177, 55.920239187056026, 59.61980304410381, 58.45224288202102, 64.19829160936418, 54.250188104568, 59.33717273896741, 68.69627352683776, 67.15901820890366, 63.686963588960715, 61.71285037071475, 61.4534051956669, 51.00134772639121, 68.62137979076755, 71.11130037615376, 68.83085004744991, 69.02051233476209, 76.5416963638798, 70.52056789398193, 58.65417826560236, 53.65461541760353, 71.65547432438021, 41.993208854429184, 14.44353097869504, 0.326795427188758, 0.3018472836382928, 0.1717314172175623, 0.17413566159384866, 0.08598455182847478, 0.3113789802357074, 0.7581797518557118, 0.19420762486275167, 0.8055537710747411, 0.5307565004594865, 43.57712076556298, 52.3031117839198, 42.652221956560695, 45.709517309742594, 53.985247688908736, 2.3591529313595068, 0.847745358703598, 36.41969342385569, 42.75267777904388, 61.25967541048604, 39.593275285536244, 6.46774914956862, 0.895147386097139, 1.269454513826678, 14.96243799886396], [7.4865823503463504, 46.83206042935772, 59.91379253325924, 39.03078779097527, 1.4148907291312374, 0.2461666343433242, 4.193589322028622, 11.369046818825508, 9.940209734824396, 29.09299815854719, 47.18646226390716, 40.27582653107182, 39.0324547982985, 103.0345533740136, 58.90110323506018, 8.482675610050078, 0.17432318459595406, 0.0431918686315898, 0.038202682720316995, 0.0621011364273727, 0.9063731482432735, 0.5373868382265491, 0.40731512911377415, 1.427233202322837, 1.0638207028950415, 0.24018382473338037, 0.03380575555286581, 0.18299611195200877, 0.2343878180028931, 2.233821192095357, 7.398378541392665, 11.79702643425234, 22.079859125998713, 27.72144532972767, 33.16927233049947, 46.847793056118874, 48.32109805076353, 49.10043770267118, 45.40762032231977, 52.359715507876494, 54.82619600911295, 54.1384554678394, 54.05940009701637, 55.65477709616385, 56.11040746012042, 66.9643117535499, 62.35446776113203, 69.24703705695369, 64.45216309639716, 66.30376892705118, 64.34665526113203, 71.2277869255312, 67.72997410066667, 65.04937925646382, 65.33031117531561, 70.37135308788669, 67.64944784102902, 65.35905822630852, 64.3573005737797, 61.13764262968495, 63.39685724627588, 68.95500090814406, 66.53402774564682, 68.79566638700425, 58.53623259452082, 56.78737717290079, 55.50762545677924, 56.41783891185638, 53.97498676853796, 52.46522334314162, 50.930913725206935, 50.55488001915717, 48.87230873107911, 51.8082812524611, 48.186309722162065, 49.87706307441958, 48.73169568277175, 49.06656019149288, 52.299244326929895, 45.27446369970999, 44.22552385637837, 46.22260647435343, 45.3788693489567, 44.394707449020885, 45.54149473867109, 44.86412886650332, 46.1889603830153, 47.17522467336347, 44.82191239633868, 44.53648936363959, 44.35756260348905, 41.77584286658995, 41.99285584111368, 40.83485449514082, 43.959700907430346, 41.358451689443285, 42.75587058836415, 46.20244549166772, 45.842014974163426, 47.19093768827377, 46.807478935487815, 48.647098002895234, 47.59615775077574, 47.132968979497115, 47.692965768998675, 47.111521459394886, 46.98597031254923, 47.150851065112704, 47.812437242077245, 49.77232402370822, 49.66344687246507, 49.546132702981275, 54.31363636447538, 52.89851973133703, 57.39314802231328, 56.66879215548116, 49.13719423355595, 50.038849076917096, 55.061177361396055, 61.19713321808846, 60.15999970897552, 58.253504230130105, 55.63147821734029, 58.548874393586196, 58.9810097602106, 56.21297744012649, 57.59832720602713, 57.16562309572774, 49.184078324225645, 55.286399856690444, 55.9337164509681, 54.81967310751639, 48.35265744116999, 55.75535451212237, 58.675013895957704, 59.31176754736132, 56.28449401547832, 48.122288796209524, 45.82359160146406, 36.84612566424955, 49.163007351659964, 60.43278878734958, 63.12751200891311, 61.20163609904628, 65.50822988633188, 53.07426937164799, 30.70329977620033, 39.94201321755686, 52.913209007632354, 5.6198106754210695, 1.4875460175737258, 0.07172957077742585, 0.07760740335910551, 0.0638714621985151, 0.049506555191211166, 0.06344173666870882, 0.15897438320661747, 0.07646042417975203, 0.14288138868587633, 0.2239307484799816, 0.1629691333660195, 19.646020589336274, 24.269804685346543, 21.37746068739122, 22.220211336689612, 7.462830437767891, 1.238374510599721, 0.7282331910344862, 18.51259289249297, 9.030922939700465, 10.8726090961887, 1.6732695097884827, 0.1788295435929491, 0.1544650671102347, 0.17379884337705953, 0.05244583537381503, 12.016837039301473, 36.224579042004, 66.89920040868944, 22.566007491080992, 3.400426011893057, 1.522141690215757, 8.969623158054969, 19.170678354078724, 31.853297525836577, 40.76312611179967, 61.27888717959004, 54.58189510530042, 45.99511292672927, 103.2748063918083, 65.87894485842797, 10.802860529192033, 0.25549547085838936, 0.071811925229286, 0.14717831456613156, 0.04102089036736758, 2.435208914741393, 0.5273679403528091, 0.6785449734137905, 1.2968678363869268, 0.6111028826525134, 0.7608651045349337, 0.1892296468178111, 0.059330073831182335, 0.2898362507262538, 6.42645541698702, 9.714602847253124, 16.5340454347672, 26.712713703032463, 33.568091084880216, 41.796509835027884, 59.897306811425, 54.93985452959615, 57.80477331530664, 53.260174028335086, 57.57678554904077, 61.16164753513952, 62.08916648741692, 65.48753153893256, 62.00833428290583, 60.21378324877832, 72.03472045160109, 70.45770014486006, 70.82504580097815, 68.95534607671922, 69.68795068802373, 68.89199979843633, 72.10256961084181, 71.89891230675482, 68.33936137537803, 68.17517095996489, 69.72960625925373, 70.97721807418331, 68.19375514984131, 64.84718891882127, 62.61427379423573, 67.4364552959319, 70.58985264070573, 69.60367464250135, 69.06561174700337, 58.53694254352201, 61.19668214551864, 60.227750808961936, 59.344280073719645, 58.9016523668843, 56.845808721357784, 54.63003435442525, 53.47349997489683, 53.862732456576445, 55.63867576660649, 52.88181827914331, 51.870246856443345, 50.434416186425, 50.50582293541201, 52.950149889915224, 47.02770040881249, 47.51643949939359, 48.901824566625784, 47.77225648203204, 44.88547440498106, 44.28599503732497, 45.02925280601748, 47.84808766457343, 47.228208049651116, 45.97646990130025, 45.00982138418382, 45.00940953531573, 42.20449516850133, 43.39004332019437, 43.72805356979371, 45.23412604485789, 42.13033099328318, 43.07766183730095, 46.788153417648815, 48.29145277700117, 48.05194500953921, 47.81708132836127, 51.41864476665374, 50.849512777020855, 51.689931577251805, 50.55719029518866, 49.520974620696045, 48.80130598621984, 50.35867521839757, 50.15534347103488, 51.8184401912074, 53.91539027613979, 52.94915360789145, 57.73388824155254, 56.60618328279065, 57.01027762505316, 62.43953612542922, 53.62512703864805, 52.8901219367981, 56.01292479422785, 62.71953059780983, 60.74540561245334, 59.91515751807921, 61.41707228076074, 60.68966873230473, 62.41833571464785, 57.66384255501532, 60.29429381893527, 58.85319540577551, 53.99051935442033, 56.715091812995176, 59.053302964856556, 59.721627773777136, 50.51868830957721, 57.42245597224082, 61.50805557927778, 62.42723949493901, 57.367676150414255, 49.62990276275143, 48.95457260070309, 42.09939525973412, 55.95510905788791, 66.65093006626253, 67.772320009047, 67.32906864535424, 69.93492664829378, 62.82295173214328, 46.007087922865345, 50.83206999686457, 61.64327929096838, 4.083359933668568, 1.55533192859542, 0.14523600588642782, 0.0490048480400395, 0.20121121598828226, 0.13351893623269376, 0.05133269812851664, 0.10044812329954679, 0.37478648426551975, 0.15864318807519254, 0.11781694532762613, 0.30439596623182297, 27.760470951757124, 29.726078510284427, 25.88203218675429, 37.82807534740817, 7.955072204912863, 2.3544279461906803, 0.9142055698940832, 30.080849047630068, 20.882286948542443, 34.05542204456945, 6.550900945740362, 0.1303671126163775, 0.2361560868279588, 0.2561514106609168, 0.19071155197678075, 28.012987259895574, 102.53230956292923, 136.2431670773414, 118.10105185354911, 5.156106602761054, 1.510706510274641, 14.635652592105252, 51.21214766656199, 55.324999901556204, 65.93170073724562, 75.0293637860206, 69.96683120727539, 58.872011015492106, 121.07726004815872, 77.57053406007829, 16.964466725626302, 0.577058241732659, 0.22007823020460146, 0.6881879979083616, 0.1876372411366432, 3.2080251747562043, 2.222058003948581, 5.2254447917784415, 8.425714950407706, 2.6962968274470303, 4.362350279285062, 0.8711288749210296, 0.32704287358830053, 0.4184501864496739, 7.924580679785821, 14.720168882800689, 25.834561701743837, 39.6923465113486, 47.43497971565493, 53.47724191604122, 69.4890865202873, 59.521939908304525, 68.03701723775556, 63.01852110893496, 73.93326528610723, 67.64286610387987, 69.94929821260514, 74.99032051332536, 73.76945141823062, 63.27911946081347, 75.88022001328008, 74.81237826808807, 75.8018510572372, 74.24177538964057, 73.67580875273674, 71.17360330397084, 76.65127954175396, 75.58091179017099, 71.89691974270728, 72.55025325282928, 75.03218004780432, 73.8342175945159, 71.57818794250488, 69.19895664338144, 66.69457035679972, 71.15266569199102, 73.87641445282968, 74.97256002118512, 72.75531476543796, 64.63500830434984, 64.87084473333051, 62.236557391382036, 62.03266866745488, 61.06550239747571, 59.60607867087088, 57.50735175225043, 56.54191916988742, 54.409059786027484, 57.84191031609812, 53.37450327411775, 54.780386647870465, 55.43244931005663, 53.016128078583755, 57.55362395317324, 50.16395307356312, 51.66570309669741, 53.93469225975775, 49.16384673887684, 48.3253106763286, 46.191466777555405, 46.23225942734749, 48.717732044958304, 50.552032378412065, 46.496485971635394, 46.154545507123395, 44.28700700882943, 42.625624364422215, 44.69805963577763, 44.188029919901204, 48.27643402161137, 45.48186294494137, 46.656259798234515, 49.016224415071555, 50.8293870956667, 51.38074290367865, 52.526235811172, 57.54615576036515, 52.265711984326764, 54.01865451566635, 53.47169568461757, 52.95815936980709, 52.07992499874484, 54.27714263239215, 52.61516378771875, 55.48424420818206, 55.285897793308386, 55.62431989177581, 59.62563168617987, 59.44676376158192, 60.811572074890144, 61.148358544995716, 54.04973929928195, 56.26504298179381, 58.81682718953779, 66.56862305056664, 66.8972235341226, 64.76408173961025, 63.07252822383758, 65.70406990666544, 64.5041423459207, 60.60065838598437, 62.13438749313355, 62.40050854221467, 52.19143798274379, 59.61545705795289, 58.41427826112317, 61.22760218958701, 50.61691622580252, 60.45730752329673, 65.7326522181111, 67.43162293587962, 64.05073596585181, 55.099632278565444, 52.862771249586544, 49.57584465703657, 66.2287732093565, 67.60759615129041, 70.02100698409542, 68.48046471995693, 70.10753447009672, 70.07661834839853, 54.869985349716686, 66.29573591293828, 67.57814699603666, 9.602756461789532, 5.343324272863327, 0.313455599450296, 0.2414046011624798, 0.39021451446798544, 0.3214983275580791, 0.15631201316512403, 0.4333398407024722, 0.733198237515265, 0.3533796587538335, 0.7769161787244582, 0.5735781800843055, 39.12568169255411, 41.3247428401824, 36.9999296434464, 52.101615705797755, 29.753266419133833, 2.9951012711371146, 1.1513623667340125, 45.86061877589072, 48.749271823513894, 59.92113913259199, 26.07929994983058, 0.8478779225580154, 0.5110479080148282, 0.47113779151151264, 0.6722032362895628], [3.253266037471833, 28.405530222000618, 47.227098018892356, 11.875566993990253, 0.44460032195333515, 0.8220098912715913, 20.25590012150426, 9.530437761737454, 12.012832299355539, 30.079419343702256, 51.349305106747536, 35.33110626282231, 57.72782425726614, 79.26368005814092, 42.71934155494937, 3.6992789949140246, 0.13277791470529574, 0.04350283904181373, 0.13840041784269197, 0.13060844563428434, 0.07809881811901447, 0.18162838453727384, 0.22279381271331544, 0.48662294122961264, 0.19270989232726637, 0.3935758937751094, 0.16386344908706604, 0.008191270641081275, 0.2853128079685473, 1.4873207264369535, 4.730397059071449, 10.399216278906792, 10.99410157049856, 15.321268189337948, 15.671370125585987, 22.63003626177388, 37.8655888957362, 39.971230952970444, 42.0468198099444, 45.650364045173895, 56.984299767401914, 57.69561767578126, 52.50922056936449, 49.418573302607385, 58.44764194180889, 69.41197272269957, 63.041000212392504, 61.58472222666587, 62.90701596967636, 66.8278132715533, 67.24440820755498, 67.27365339955976, 64.75890813335296, 66.53843648972051, 67.88849276881065, 66.13643277075984, 67.44696724799373, 65.14510077814903, 63.46076442349342, 62.17004576037007, 67.40229929647138, 67.13994764512586, 68.4866463753485, 58.503472958841634, 55.190164504512666, 56.77500209500713, 56.6996455192566, 57.755327916914425, 57.00096199589392, 51.497013722696614, 51.20558161889353, 53.364493385438, 50.62502376494869, 52.13772112323392, 51.631629467010505, 50.74023946639031, 47.013003287776826, 45.917657882936545, 48.15227139380671, 45.09939262943883, 41.1128838600651, 42.16235322336997, 47.54931680617794, 45.967099358958585, 46.837324250128965, 44.18949296397548, 45.875959165634654, 44.76520669075751, 43.13041379374843, 44.236769291662405, 42.496586230493364, 41.7153795303837, 43.62974720616495, 40.87870267129714, 44.59851380317442, 40.47746381452007, 38.97417622227823, 43.13523438669021, 44.16801406491188, 44.79556975826141, 46.73016901939146, 45.72728172425301, 49.095185649010446, 48.858160741867565, 47.981589455758375, 46.01870206094558, 47.456729258260424, 44.59472871595814, 45.79637427483836, 47.96997924004832, 50.72789576745803, 52.8799629980518, 54.513943964435214, 54.23826017687398, 54.25053719551333, 59.60735344117688, 60.52046160544119, 50.123568350268954, 52.26712795995897, 55.75052607444025, 56.248392520412324, 57.943935086650235, 56.600531147372344, 55.19846816216746, 55.7706242992032, 55.49851771323912, 58.45319209560272, 55.05858075234198, 53.7028056575406, 54.679546433110396, 48.28245878219605, 53.74606940054125, 47.29227212167556, 50.337180629853286, 61.935044796236106, 55.150391670965384, 57.095510728897594, 43.15571700373004, 41.66036828871697, 30.483152827908917, 41.74261646886026, 59.33135978637203, 66.10938410605154, 60.3040801325152, 63.83915547401675, 42.70576623178298, 31.367468833923343, 44.50427885978453, 37.95059842448081, 1.8277827025421205, 0.2054436219435546, 0.12405723708892062, 0.04522471358218501, 0.05051800192544057, 0.04853057449743633, 0.034539024270470106, 0.03715328015987912, 0.10938144394106443, 0.04395283142765684, 0.2888177215091644, 0.38362796628667467, 24.654296982672907, 18.151879964336274, 19.811460279649307, 14.2217944898913, 3.0057590863397046, 0.2764011829370453, 0.20627416850578403, 14.037006728110777, 12.90430368915681, 19.04112050610204, 4.756053772664839, 0.18885631685055074, 0.1156369272258974, 0.010975117329508068, 0.09069606151071288, 3.072269246462853, 27.514844286826353, 51.294658645506836, 22.962961158444806, 0.46697940497148427, 0.716067101926573, 27.51317531831803, 19.27691182782573, 27.783038308543546, 43.34063322313371, 67.37746284854028, 49.92577498958957, 65.59274911880493, 89.99024068155597, 53.31770343165244, 5.464985899386868, 0.2637247873410102, 0.07092079643400447, 0.47923671982942095, 0.16927198386721073, 0.36540150882736333, 0.21909786748789975, 0.18437344610931414, 0.2631995574601235, 0.2754133278804441, 0.3437878395761213, 0.06833349534821126, 0.057129601181875315, 0.25539108371782687, 3.504324449646858, 9.923059171245946, 16.44822495598947, 13.956703062980408, 20.342984584070024, 17.69647905903478, 27.071610573799383, 53.918124168149895, 51.1532062099826, 49.0364363885695, 52.62861359503962, 62.081455107658144, 63.85570003140358, 63.21329424458166, 57.44822594427294, 62.544075135261785, 71.56245139337355, 67.47964059152912, 67.2500015074207, 66.6790142366963, 70.21187736142066, 70.26078147272911, 69.33336842444636, 68.40369609094435, 68.00152763243645, 69.43502841457244, 70.04762418808477, 69.17194720237487, 68.65164479901715, 65.01823171492546, 67.38698636331867, 72.77217311243858, 68.61490787998324, 69.93955504509711, 59.98369309210009, 57.133628322232155, 59.11211890559043, 60.46523463341498, 60.41134126724736, 57.05516915167532, 54.982694656618186, 53.36439532618369, 56.515470627815496, 52.44423474034956, 53.98032511434248, 53.85974753287531, 54.11970261604556, 49.13703733874906, 46.385631945825395, 49.924731639123735, 48.299536781926314, 44.49151154487364, 46.15573006291544, 50.05650366506269, 47.61001156222436, 47.40667197012132, 45.39230738916705, 46.17997423295052, 44.41559407018846, 44.46300768083142, 44.34347344983009, 42.18090603428502, 41.921696201447524, 42.96245398059968, 41.673135603627856, 46.02185564656412, 42.786645504736136, 40.22542407435756, 45.577317745454856, 46.13845594467656, 46.10063645147508, 49.50093915385585, 48.5058024621779, 49.717567736102694, 53.48503566557362, 50.30635080029888, 49.87444685351465, 49.990180307819, 47.70737655701176, 47.152329798667665, 51.14359640306043, 53.74985056538736, 55.871809682538434, 57.89185385550223, 56.259563430663086, 57.66774923570695, 61.74704951624717, 63.70973687018118, 54.85215033254316, 52.142086721235714, 55.701013995755105, 59.18176843274025, 62.009373711001494, 59.033608744221354, 59.051078980968846, 58.5394371709516, 60.1419097377408, 59.223690725141964, 57.022182018526145, 56.39524605966384, 56.62127656321372, 52.354365394961455, 59.887473429403, 49.36118510461623, 52.00785536919871, 64.32431736300069, 57.151439805184644, 59.030341409867816, 43.40800385321341, 42.1696174529291, 38.2966338434527, 50.96404990842266, 68.0094272859635, 73.05927491957142, 67.88347213499009, 70.5975640204645, 53.50534569832587, 41.76854333569927, 55.80176791837139, 46.70781150940926, 1.6218609651250224, 0.19548856983742408, 0.12213028081121946, 0.08709434509998368, 0.02818120121505232, 0.016070703277364373, 0.023190050288253737, 0.07653130263450646, 0.05272900445326682, 0.07696743648979934, 0.1862578078984253, 0.7899757102131845, 32.49382253616087, 22.80549760787718, 19.908025110921553, 32.60960109772221, 2.321778136876322, 1.1159130882832313, 0.6393028242934136, 24.294443053583947, 29.034696048305882, 39.5937498923271, 31.006514680001047, 2.825407034927799, 0.09721082725351858, 0.10964051189441835, 0.17997084606078365, 8.449638466681204, 63.23870335855792, 91.74426186469294, 35.45534733803042, 0.6231172250643854, 0.9772503159699902, 42.01639790688792, 40.8493790318889, 50.6803370291187, 63.15161497362199, 80.76416707807972, 60.6010074769297, 80.26723415620866, 100.22192370507025, 65.57473367260349, 9.689564397258144, 0.5707225720247915, 0.6867696933688656, 0.6128438021386824, 0.3119048229869335, 0.6892848519548294, 0.5057313803943896, 0.7675687415945915, 1.1724100502267962, 0.671643992104838, 1.1236935998162916, 0.29079119464562786, 0.26730612581295354, 0.394134157367291, 3.6871976044870194, 14.465645301726557, 22.884566706995813, 19.09579050156378, 30.580133430419433, 31.465388844090125, 47.05961673490463, 64.67037631619361, 62.69375670340754, 60.79132480006064, 62.57900776401643, 71.94508644842333, 72.78192412468695, 74.54143662606516, 68.08963975598736, 69.2716303179341, 76.83701161415347, 71.79988814938453, 70.61883895627915, 68.85672984584686, 72.90947175795033, 73.18138614777597, 72.10998289046749, 70.92113602545955, 70.7024246646512, 74.24515647272911, 71.29716580913913, 72.78376763866794, 72.4445532214257, 71.89277771980532, 69.0541898050616, 74.15800925224059, 72.16047948406589, 72.7123648120511, 64.84385882654499, 60.53147954325522, 63.548492154767445, 63.50537746183334, 62.71847940260365, 61.62151798125237, 56.61558912646387, 57.9693873466984, 59.66031328324349, 55.32562748078377, 55.75859831225488, 56.48756688640964, 55.04688816685831, 51.65419486261184, 50.438648423840924, 53.71477280893634, 50.44378280639649, 47.24521936908845, 47.7159430134681, 51.90248481688961, 49.21047587548533, 49.19503350411692, 45.28186913459532, 45.91458274472145, 45.81426028282412, 43.19694895898142, 44.549739130081676, 44.22411964785668, 41.18980153914421, 42.91903334279215, 42.41078438297395, 47.7621603012085, 45.28476776615266, 43.643024429198235, 46.249580614028446, 48.273880558629195, 49.08754487191477, 53.925662963621086, 49.872422910505726, 52.55865027827602, 55.54684523613223, 52.33123910042548, 50.823750649729085, 53.36187716453306, 52.97311536727413, 50.198073771692094, 53.3004803042258, 57.434352520973455, 60.35082694022887, 61.54874232507522, 58.55798213712631, 60.90664640549691, 63.24962715948782, 65.79530031450334, 57.69040484582224, 58.33676830414803, 60.057567011925485, 61.850705992790964, 64.3318679255824, 63.203582456035, 63.83370337947723, 60.84067213919855, 62.75368659727035, 62.39054572197699, 59.1369318193005, 55.84096808587351, 58.56660742913523, 55.898921105169485, 61.67872182784542, 50.535703551384714, 53.98312176427534, 71.53163725329985, 63.059698151003936, 63.10217741997012, 48.94495494904057, 51.02244223317793, 48.13840973761774, 62.837613551847404, 71.38796867862825, 69.67931362890428, 70.43841777309295, 75.36156500539472, 68.08166165505686, 58.01531045667587, 66.30004267538747, 58.66003044189946, 4.121906536240732, 0.3287887266807018, 0.2967324822900757, 0.19430813559841728, 0.0870592506121724, 0.22460593241116694, 0.2774888439284217, 0.17134792892442596, 0.4304459588902612, 0.22817640775634399, 0.6853282223305395, 1.0627327354684954, 43.93359753393358, 36.07558781100858, 34.029569702763716, 52.31279611587525, 19.397391350038593, 3.2621769270589276, 0.8592958808425935, 43.36833692366078, 53.46906377423195, 59.516107343858295, 52.636317130058046, 1.9687779367931428, 0.2458015474821291, 0.24450345745971128, 0.5405526812518797], [3.4936296170757664, 18.95152964899617, 19.89573044161643, 3.52577147945281, 0.4184475511072144, 14.038513898849489, 28.490786860066077, 3.5649699309179863, 16.415649671708387, 34.6222202239498, 48.011752482383486, 35.88172858761203, 45.38117962498819, 33.86995277097149, 39.45694546545706, 1.0170170208138805, 0.11231667151854885, 0.26839121274890443, 0.05235191682473787, 0.18274057566398577, 1.2253926910700337, 0.16136129867405663, 0.10236882063890658, 0.1379817354703142, 0.05443079216826347, 0.11128123474097061, 0.038560782859642664, 0.029661154765034878, 0.18423982505356112, 1.737468903583865, 5.628693863268822, 4.41494288944429, 3.6849321905643713, 7.827379934249386, 14.420433121342814, 18.020235415427916, 16.641771370364776, 28.368079431595344, 42.66139638039374, 42.0972458008797, 54.63103063644902, 55.089900878167924, 48.02769691713395, 46.72863929502426, 55.15428658454649, 63.67067790800526, 64.97562693011376, 61.7756945856156, 60.52237572208528, 64.68162175147765, 64.43093130665441, 65.9149286823888, 61.397115261324, 66.87605842467278, 65.46149484572872, 71.23008543445219, 65.89337133592176, 67.0282385426183, 62.3493294562063, 67.40535090046545, 67.82563286442911, 69.67009605899935, 63.296472026455795, 58.06321436359037, 57.96184070648686, 60.61308053232009, 57.64250093890775, 51.34657121473744, 52.043803891827984, 52.24697089964344, 49.4737571285617, 50.63888542113766, 50.28657420989006, 52.54700476123441, 48.15631927982454, 50.56876913193734, 44.49426897110478, 44.62822967959989, 44.12927673709008, 48.0154198984946, 40.49353376511605, 45.81866510452763, 44.44693380786527, 44.695984701956476, 46.32356043784849, 45.04962951906266, 44.57039433140909, 44.310254896840746, 43.85889599400182, 44.77312203376524, 41.518602063578946, 43.25105021076818, 40.91527485078381, 40.280011700045684, 42.7522776972863, 42.81484734627509, 38.668576517412745, 43.9492085672194, 43.7270768996208, 44.3089722817944, 45.403458687566946, 47.17137290585426, 46.13556515785956, 47.670686706419914, 47.796532031028505, 46.02109078438052, 45.52265559473346, 45.39348802258892, 44.59622313899379, 44.99968205728839, 47.734327162465746, 50.68528706027616, 53.76236292623705, 57.01767913756832, 55.244771742051654, 59.04523857178227, 59.98796847558791, 57.90427207946778, 49.40198559914866, 54.02239253444057, 58.61808069290654, 57.33047246932984, 57.23812418599283, 55.32182278171663, 53.39588019155687, 51.682428083112164, 57.77698724500595, 55.34793399995374, 54.741857205667806, 52.17472476343955, 47.65529924823392, 51.6929361128038, 43.22633535631242, 43.03977566380655, 54.8463216904671, 51.29451351781046, 49.5661642474513, 38.60104899252615, 34.645927029271284, 31.028729023471957, 31.50508519141905, 29.513817487224458, 58.3713714538082, 45.892342905844416, 49.68208205315375, 21.288948482082738, 32.47489513889436, 62.142640159976104, 25.3191916788778, 1.1182336605364278, 0.22306859312999636, 0.12801928295483514, 0.09129682766093362, 0.12933623406194872, 0.048560509383077585, 0.11315117109446757, 0.0971848798555232, 0.07769471439983576, 0.06527059155726625, 0.14243144992618792, 0.9957383464901679, 31.28591883567072, 18.74857641035511, 21.85396198303469, 17.160051791898667, 6.6309045495525485, 0.43469287455081945, 0.15571754425764084, 6.925465724160595, 13.925329985157138, 19.476786005881525, 35.141349838626006, 10.648938878890007, 0.2877561687942474, 0.14366788519245965, 0.2356492890225303, 5.6003581708477395, 26.406804130923366, 31.67862065376774, 6.800757396605707, 0.39083470860796593, 21.38362273093193, 43.40709386333343, 21.73974452480193, 32.078306251956576, 47.36507915681409, 62.38782359707741, 45.999117666675204, 52.63479525043119, 47.5707447144293, 47.96731202833114, 2.1665169971604503, 0.1291403453797102, 0.11405286424222494, 0.5323751523129402, 0.07919845306464741, 0.23915205751695942, 0.11277461589704599, 0.1185600506141782, 0.03883165622790975, 0.10208994165183076, 0.26262413349843794, 0.05022192043402503, 0.1334320158968049, 0.15655428081029849, 1.6448311002985125, 10.422446516252334, 8.92564260190533, 7.978450021436138, 16.31120970172267, 22.668222496586463, 20.056167148774673, 23.150375927648238, 45.39890089342671, 50.775003433227546, 55.133898104390795, 57.72515704554897, 60.84021714425857, 56.13643238621374, 57.37626614109163, 59.90346885496571, 68.97353802957844, 67.91587091261341, 66.04486896145728, 68.29341473117952, 66.33393979841664, 68.45027815911078, 68.79191660111951, 66.45955762555523, 70.29084251772973, 68.38923038974886, 71.21925184803625, 68.015334375443, 66.92910455888318, 66.76922090591924, 71.65996936059767, 69.971647877847, 71.591688740638, 64.71161611618535, 61.12966845112463, 60.9937700917644, 62.9977874602041, 60.28386423664709, 54.72161777557866, 53.93063260662941, 54.94762474490751, 52.617348547904726, 53.510786025754875, 53.989205360412605, 54.761982887021965, 51.372870706742816, 52.5208229403342, 49.28024699611049, 47.10135075353807, 46.557031677615264, 46.52876315578338, 44.32214360083304, 49.51420853214879, 48.011983902223655, 45.635047189651004, 45.17241539493684, 44.84460330778553, 45.77711935966246, 45.980984549368586, 44.62575074165098, 41.03402068538051, 41.134766763256444, 42.99860646647792, 42.7539917730516, 43.23310928960001, 44.83958659633514, 44.48113295339769, 41.01342824197585, 45.40570228330551, 46.77093813496251, 45.126272632229714, 48.55564009758734, 49.90753204591813, 47.658754856355735, 48.1583510675738, 50.58951454777872, 49.92107206775297, 49.87809858014507, 47.13933106391661, 46.89339060937205, 46.7317928806428, 49.207126171358176, 53.781080476699344, 56.62318283511747, 59.02399893729918, 60.09593171458091, 62.31367511133995, 63.99748979076263, 61.12294943101945, 52.16336165705035, 57.606089576598144, 60.37883658562938, 61.078599191481075, 59.68798560480918, 57.19332287388464, 57.259885495708836, 57.889731853239006, 59.76745674687048, 58.89835365356938, 57.99636933111376, 54.27362818871775, 52.4663176844197, 56.530289342326505, 46.67283181221255, 46.44242394355036, 59.360608900746996, 53.910444167352495, 50.522830332479174, 43.739079352348085, 39.65213044997185, 38.24054002761841, 37.97394829411661, 38.226407727887555, 58.13091055039437, 46.4889471761642, 54.73713859435051, 26.051823746773508, 39.5776250285487, 73.44683647155762, 25.25647297982247, 0.7982759357940766, 0.3074051595983967, 0.14913124122446583, 0.046974358809811455, 0.12488877190457237, 0.07623435163329687, 0.019864788196320017, 0.060251934243546384, 0.04048105502020448, 0.14929342203803603, 0.13332863999230246, 1.7071551108552565, 37.50477006358486, 24.262316880687592, 26.02045851369058, 40.5899142449902, 2.8256683628405295, 1.1117105137917305, 0.04069984973137898, 10.967564775097756, 32.092269889770016, 34.35851143252465, 71.0307192033337, 25.31630285324589, 0.2230264736159194, 0.04529863340599884, 0.06451645460460456, 8.61436918858559, 34.91051050924486, 38.421267155678045, 4.138392258074976, 0.49226661903723595, 24.441276980984597, 70.02994214334797, 35.69897359417331, 64.60064834164035, 66.7877737168343, 77.34989289314517, 58.879804765024495, 70.51816740343648, 53.57535608353154, 61.59605395409369, 4.413415126262173, 0.23829183270854337, 1.064119293324409, 0.6697271175442204, 0.654295532693786, 5.306618732790794, 0.4688751355053917, 0.3244028426706791, 0.17723300103699008, 0.43269715422103483, 0.6509447254000172, 0.1612135509569799, 0.1593998990832798, 0.31860579406061484, 2.9454288655711762, 14.232298597212761, 9.710279414730689, 9.242479897314503, 19.704295242986372, 28.62373559705673, 30.08264941553916, 43.35662864869641, 61.68315018376997, 60.94047292586296, 63.334821039630526, 64.4930891067751, 69.67183759135585, 66.37047275420159, 71.82442649718254, 66.02313118596231, 73.62812057618173, 73.33451547930318, 69.08622772462907, 69.96016317798247, 70.79707145690918, 71.32992544481831, 70.20149876994472, 69.7230637458063, 72.31781359641784, 70.92098697539299, 75.53838545276274, 73.38561611790811, 71.93245641646847, 70.11154313241282, 72.91231155395508, 74.34991513529133, 74.61806404975154, 69.50332472401281, 64.87969360043927, 63.290078563074914, 65.14970171836116, 63.72632065126973, 57.36725645680582, 55.76991042783184, 58.15238944945797, 56.10576729620657, 58.38223641918552, 57.67800231133738, 57.343302542163485, 53.14799424140684, 54.481282388010335, 50.5785789797383, 48.296877414949485, 48.60074735456898, 51.804778575897224, 48.6050227380568, 52.88308912707914, 49.36582919090025, 46.68703863697667, 46.28500353905463, 47.222430398387296, 46.02570349170316, 45.716055900819846, 45.14855953954881, 43.05894820920883, 42.0349467954328, 44.69326257705689, 43.8373347251646, 42.979084830130304, 47.92524068586288, 47.32657324883246, 44.637812029930856, 48.77517907850204, 48.29268440123528, 46.84796956277663, 51.79392930000059, 53.637137336115686, 51.42470875094014, 51.802264336616766, 55.15132127269622, 51.59222141388924, 50.876792861569314, 49.79659565033452, 50.283769715216856, 49.91129752128355, 52.708931969058135, 54.40388225740003, 59.04965908296647, 59.74426769441175, 59.99044741353681, 65.40496956917548, 65.75500972809331, 61.03049524368779, 55.40058005240656, 59.53100842814292, 64.52769225643527, 63.32559954735541, 63.96395352578933, 60.201353257702245, 60.418581962585456, 58.094507032825106, 63.25289057147119, 58.56793711262365, 61.20069473020492, 57.753417722640506, 53.598733409758545, 59.296858618336344, 48.26711447008195, 45.71983314329579, 65.39529700433054, 56.622084571469216, 61.46119502282912, 48.1390961523979, 44.57483053207398, 46.57985594964797, 53.5830125501079, 60.09291148954823, 74.95781190933721, 62.07532836544899, 72.89295073478453, 48.838215489541334, 61.501697417228456, 81.11947890250914, 25.098717212677006, 1.1259240801295927, 0.41867204551254555, 0.17980806769863253, 0.24668867729844587, 0.2603696286678314, 0.1740032969222915, 0.2633223153891102, 0.15356673708846494, 0.26415342885640364, 0.16071007797314277, 0.6776505504404345, 1.9286644699112063, 50.58746707054877, 37.77848482131958, 39.98017003459316, 60.94391676687426, 14.155414258280109, 4.065733047262315, 0.43029028982404743, 26.061131531192412, 54.04880185281077, 49.69007584356493, 90.7922947791315, 24.13350428304365, 0.5354400555933676, 0.2547861040840226, 0.25096321808955363], [4.621735147891506, 14.066527466620169, 9.637424330557547, 0.7153542724347884, 2.0030267248230595, 30.30363771223253, 16.485602201954013, 4.066532230184925, 21.22068943515901, 47.621315833060976, 49.78303993901899, 51.66610317845499, 87.08804761209797, 42.31789873492333, 34.680196777466804, 1.754911070869815, 0.1596766406850469, 0.20395862178937083, 0.43606260911591593, 0.9496346236236635, 0.18684859958387193, 0.09916009201157479, 0.007274516204732561, 0.0016802945197747661, 0.047551613721636035, 0.030299016807769096, 0.035699858149934205, 0.06362071396001885, 0.15045372348639274, 3.124535809601507, 3.902531804576997, 0.8779365773643217, 0.5262314948824145, 3.567475344865553, 10.115489671307227, 14.918192682727692, 16.82602470920932, 14.201994365261449, 33.13179016113281, 39.75305695687571, 47.77268009801065, 50.13700639047931, 41.84448826697565, 44.35260864996141, 51.71183409229402, 62.66389962165587, 62.12351468301589, 63.693204079904866, 59.77651742196853, 63.82356797495196, 67.00239012318274, 63.915755441111905, 62.96642811067643, 65.6267717576796, 62.48912272914764, 65.44688401683685, 66.77222544147124, 67.576993819206, 64.04319324801045, 68.47586770211497, 68.70743659234816, 66.07214512363558, 57.51334513387373, 60.17777196822628, 60.91709952200613, 57.11859387736167, 53.487538137743556, 51.45820971458189, 49.20400004233084, 51.545054912567146, 49.9895566509616, 49.25935645257273, 49.022198184843994, 49.57044355330929, 53.27530653245988, 50.29869825609269, 48.61626425097066, 45.41772042551349, 45.34114399263936, 43.48833791671261, 40.6061646246141, 42.065270639234974, 49.02044096300679, 45.77269884847826, 44.62939462354107, 43.312505906628026, 47.89546597388483, 46.757064711663034, 44.885788194594845, 44.081894505408506, 42.425822750214614, 40.83779235039988, 41.38311947545698, 40.621575617021136, 43.006863055690644, 39.660857723605254, 37.049892794701364, 40.82846103175994, 43.18279704739971, 43.799981994013635, 46.29963397979737, 47.679778760479344, 44.36416787485923, 46.42120392091813, 46.92136103107084, 49.48664211457776, 44.914182232272246, 45.196283017435384, 43.39216532245759, 44.212042670096125, 45.719770385373025, 49.601544026405584, 53.09457548203007, 56.95135578032463, 60.50564681330035, 58.90494323545887, 60.12801278022028, 58.457043863111934, 54.50104721130864, 52.934421185524236, 57.06126843729327, 52.31807170375701, 56.74217577903502, 52.07695184215423, 54.445396623303814, 54.87736332801081, 54.75743293762208, 55.68464202265586, 51.55502949991534, 53.763253304266165, 50.682517866934504, 50.25952946755194, 36.73400863524407, 38.9098415067119, 49.298340889715384, 41.809006506396884, 39.111019872849994, 41.25600330291256, 21.89189326378607, 20.64800181696492, 27.082648123464278, 8.94905032650117, 10.581415276373587, 25.693848632997085, 25.184103288958152, 22.514842133368216, 40.96272376275832, 25.52805789055363, 0.5955434530492753, 0.10608548854267406, 0.028148422227992166, 0.05775704251361951, 0.10894625237391842, 0.0979896322373421, 0.022114744379876122, 0.08812514704562004, 0.0433080037304711, 0.052173743925748334, 0.052430264636754036, 0.2623008443943916, 1.9894384088054782, 32.073124800958944, 20.62251817795538, 17.498744533907985, 12.349285367996464, 4.337911461630176, 1.93101360192222, 0.5576224685195954, 4.003172223606418, 20.080381901033466, 23.015809212961507, 53.66593930029101, 37.0450565122789, 0.8271174301062861, 0.10927067528809271, 0.2838055452992839, 6.1474067261142125, 23.005216852311168, 17.586570324436313, 1.4945706148301403, 4.3663922817476335, 45.085032832237985, 27.121334460473832, 15.380325355837423, 28.21084337849771, 58.67669659276163, 64.11682790325534, 63.55046118459394, 91.90229415893556, 50.29902773518717, 47.5438960905998, 2.122398422610375, 0.13521226633700634, 0.08160072093408915, 0.5146398491436436, 0.11708000704886452, 0.09653980317976206, 0.17571432365765496, 0.06295493375810404, 0.031088108437195904, 0.119721585464093, 0.0367110520751486, 0.021666900870660623, 0.06087710029415547, 0.09531473665828667, 3.5300740743837054, 6.65927799478654, 4.901382980808135, 2.0421190271454472, 8.516314837240405, 20.49475677551762, 23.81933419935165, 18.16922272405317, 20.035825737061042, 46.774021117917954, 47.93858066681893, 61.03145622438001, 54.693011929911954, 53.167523722494806, 49.98066856015114, 59.34182859236195, 68.55859048904912, 69.00788230280723, 67.04827400945848, 65.03252090946322, 66.53201164737825, 68.96236711932768, 66.83625421216412, 68.418961955655, 67.08855675112817, 65.96560570501512, 70.27300357818604, 70.21259123279204, 69.61275885182043, 67.24844040409212, 69.72402080412834, 68.42482197669246, 67.60281870442053, 61.14751131303849, 64.82286630138275, 65.2890988319151, 61.11749733647993, 55.14583387682515, 51.87271794965191, 52.51416275578161, 54.38150513556696, 53.11277135725945, 52.525839651784594, 53.54070978779947, 51.32105619676652, 53.64443686700637, 53.4682636107168, 51.36254702844928, 46.81312322616578, 45.95372407667099, 45.88044243474161, 44.422215031039336, 46.23831556689355, 50.76030631219187, 44.501015447801166, 46.90388294958299, 45.53429326703472, 47.105798721313484, 45.3779907380381, 45.863266375757036, 43.97464513778687, 43.58740914252497, 40.82538981591502, 41.31852588345928, 39.95770269824613, 44.32801931135116, 42.24982992295296, 39.71060906687091, 41.57978319352673, 44.37976321866436, 45.612066022811405, 48.364200976587114, 51.65977247299687, 47.51887921364077, 48.17189501177881, 48.18465448194935, 51.939664963752996, 47.412582981971006, 46.545903913436405, 46.856383046796246, 45.8876831300797, 48.37887848577192, 51.694956133442545, 55.53458782934374, 58.693319597551906, 63.006961884037146, 60.80470400471842, 63.24659908971479, 61.76226046777541, 58.43905587350169, 55.06576653449766, 58.0747853555987, 54.186920273688536, 60.07859876078945, 57.164203197725364, 55.3526996797131, 60.322727080314394, 58.22185854757986, 58.73939960233627, 56.67609168637184, 60.005097466130415, 55.163794409844186, 54.731533527374275, 41.02053165435791, 42.18198076371224, 51.44272419714159, 43.98738107373638, 42.05728861593431, 45.92553007987238, 24.605624291204638, 20.92696470599021, 36.733569329784764, 15.023937821388246, 25.95716126503483, 39.543806352923, 40.437290899215206, 34.3107997217486, 43.957547526205744, 22.268521208916944, 0.15567487316025844, 0.09175130932201302, 0.00809524343499253, 0.045071093801168666, 0.22953678072700578, 0.01164199495237441, 0.0366412538043674, 0.03365022438247839, 0.035762708003242175, 0.06873300253984428, 0.14953032706774053, 0.4798576800573257, 3.820887669440239, 41.408406995957904, 27.2140710584579, 23.96816461317001, 31.713947480724705, 3.2471677324464245, 3.614119680658464, 0.4385935491131198, 2.2403090375085033, 40.1293848406884, 37.551379588342485, 70.48463898320352, 57.724627525575706, 2.748348395670614, 0.1298509378947558, 0.19761355984355175, 10.061828705572314, 21.706161191386563, 16.528095199215798, 1.0933614209775002, 4.461979952550704, 67.3775177617227, 46.17764042269799, 38.12160591925345, 55.038192272186286, 76.54608157373245, 75.99931886119228, 74.12397092388522, 107.86881185347035, 61.35725221326275, 60.873278802441014, 4.160556101029919, 0.31926481353659786, 0.7019735968882038, 2.423569771551317, 3.0859247330696356, 0.8594796193703529, 0.25791373464369005, 0.3509086574758253, 0.17895997772293706, 0.16160070115039427, 0.15811823398595856, 0.18877619937542947, 0.32218799055103337, 0.3035146280402138, 4.2680442429357965, 8.5741933315031, 7.17543984613111, 2.396753997572007, 8.423625307698405, 25.458567219395793, 32.94383018247543, 28.01363641215909, 44.04043505268712, 62.8038223328129, 58.68632208916449, 66.50563763033959, 63.949107354687115, 63.713702386425396, 61.638619515203665, 67.50205301469373, 71.38554465386176, 72.72355925652289, 72.25379267046529, 68.43446316257601, 70.05879509833552, 73.46562462468302, 68.71758768635412, 70.17306158619543, 72.6772988227106, 67.9418997610769, 73.32668642843925, 75.11986071063627, 72.05827036211568, 69.02396402051373, 73.01857640666347, 73.16128792301302, 72.39151493195565, 63.965420492233775, 66.57816225482573, 68.69902703069872, 64.08143243482037, 58.592091068144775, 53.837739113838445, 56.28105017446703, 57.400439708463615, 56.75211898742184, 57.0199070438262, 56.592831534724084, 53.78200615606001, 58.146172492734856, 53.799801949531805, 54.20319418753348, 49.219234528080115, 50.374764780844416, 48.88800213413854, 46.86017597875288, 47.76976577697262, 52.44423081797939, 48.84789982149678, 46.26847467114849, 45.50190233415174, 51.08486675447034, 47.237888459236395, 44.603832537128085, 46.24295965317757, 43.02301929843041, 40.44202912238337, 41.71099432053105, 40.84741784680275, 46.83348424973027, 43.46740814947313, 41.47477742164366, 43.891404597989975, 45.64947366714478, 48.17867678980674, 51.37603998184205, 53.275279075868674, 49.00093501613986, 52.746139572512725, 52.55216660038118, 53.27416512273973, 48.914462443320986, 49.21064061503257, 48.711738663335005, 52.51718690318447, 50.66208624070691, 54.644409841106786, 57.71201710547171, 63.28586985988002, 65.14066849985431, 61.89563674311485, 65.56721448898315, 62.28512810122583, 60.19280641309677, 57.50986599153089, 63.041368915188706, 56.8119155206988, 62.21567469258463, 58.4406130544601, 57.8545521151635, 61.43680572509766, 61.524290269420995, 60.85189404026155, 58.491792140468476, 62.13371676783409, 58.46465326124623, 58.70956997717581, 43.1645070352862, 44.2881444961794, 60.36447286605836, 53.04283941945722, 44.01460624510243, 51.938150928866484, 38.464785852739894, 39.32989989557574, 53.544055569556456, 35.27330621596306, 48.51078779466691, 56.505205785074544, 68.90324915609052, 54.768509710988695, 56.10912876744425, 19.966656700257335, 0.4524052870129386, 0.204237952768322, 0.22076274508670454, 0.0929159008627457, 0.45186510309576994, 0.1926322569770198, 0.13228343559368966, 0.1849460968327138, 0.22258828664498947, 0.19791245670808902, 0.3689328370796096, 1.0265963067931514, 5.693325208079431, 50.9327886181493, 38.83590875133392, 32.33938509418119, 51.66544422026604, 15.20099655274422, 8.307766337548534, 0.5393851632552763, 9.06302655896833, 71.39034563495268, 48.50082105205905, 93.04284880238195, 64.39653212024321, 1.868907650632243, 0.23257251137927656, 0.5625023260231942], [8.31050709370644, 7.977401277711315, 1.9707834936918753, 0.6302768989436088, 9.244945106967803, 14.570488295247479, 4.3600664792522315, 15.703733601877767, 13.79308629420496, 42.564968832077525, 42.37639696367326, 53.759119126104544, 112.68815748153196, 42.24657435570994, 24.296831777018888, 2.862509224684008, 0.6378966545866382, 0.12030172086651288, 0.6719064844712135, 0.09943434382758795, 0.15597214591839623, 0.1301244619272409, 0.03955695380066191, 0.07235981599097291, 0.08477784077366514, 0.13400157162499043, 0.029930191437503504, 0.1974357968016017, 1.0635841349440238, 5.8506034266564155, 6.20170017403941, 2.244008322877269, 1.2795115935225643, 3.3868487275415853, 9.551219459502928, 14.79584317053518, 15.05236323802702, 7.041445307193264, 19.59846381218203, 30.118217468261722, 45.677459778324256, 47.31797541341474, 39.60250070018154, 40.38765330468455, 47.56826185411023, 59.846304232074374, 61.97304079609533, 60.25493283425609, 59.66181555101949, 61.61899589723157, 66.25785366181405, 63.72594802610336, 67.0604019780313, 66.44922610252135, 68.56930640435988, 64.11889499233615, 68.16400004971412, 65.05253676445254, 68.08352870325889, 66.94438611307453, 65.94222053404778, 59.31336787439162, 62.046436186759706, 64.53407787507581, 59.50709765957248, 57.64024557605867, 54.0601610368298, 47.36174906453779, 49.91677707241428, 49.89839292341664, 49.01912696899907, 48.427986560329316, 48.30787181854249, 50.580359735796534, 52.5345943820092, 51.14347088721491, 50.27508951002552, 45.8779360402015, 45.63614545329925, 45.7829087780368, 42.8099012374878, 45.936649999310895, 47.496125544271166, 43.00027347380116, 44.784469450673754, 44.75359255267728, 46.25171830577236, 43.2985540359251, 43.82741112862864, 41.39281949689312, 43.041442671129786, 41.1795602306243, 38.93975742401616, 38.89201041190855, 43.51382547809232, 42.285229313758116, 40.30903723932082, 43.771223175910215, 44.209708859843595, 47.27524903512771, 48.421373444218794, 47.86362417282597, 45.06591127764794, 44.584255987598056, 44.83470324547061, 44.60624871715423, 47.27544515363632, 43.563898455712106, 43.92058310970184, 44.348321499363074, 45.82934571850685, 44.0937832094008, 51.165412625958844, 54.56563295856599, 59.27723892273442, 61.1673741955911, 60.366743918388124, 59.446202862647276, 61.04300760453748, 51.58347452840498, 53.32930580262215, 55.2802142789287, 55.52932400857249, 57.99101137345838, 53.98020744323731, 54.09614486079062, 53.21193671995594, 55.73055728789299, 52.27373715369932, 51.23257537041941, 50.89598501882246, 45.19240379333497, 36.938501404177764, 32.91612255957819, 35.60456998886601, 35.978050231933594, 34.04195654776789, 20.879902147477676, 7.578741379322545, 1.735743183282114, 23.435669522131644, 19.67357720098188, 23.01854898852687, 23.67751306103122, 19.26163027363439, 14.968856957650955, 4.686307166853259, 0.11365954704102009, 0.1368899988911806, 0.030202596981619156, 0.026950609284423055, 0.0775828808846493, 0.025228077823656703, 0.04242385399617976, 0.0676106684090149, 0.061583172890447804, 0.029353348297938228, 0.07105270145280708, 0.054675381059848496, 0.21217696789291599, 3.8372709193537315, 39.498283324703095, 19.642272764636626, 23.759117972466257, 14.725767085629126, 7.165629508033876, 3.581836367807081, 0.19900704313430095, 0.7529002416037744, 8.310865009984663, 32.881229154525265, 51.458452901532574, 69.39545169953378, 11.055450381771212, 0.2447367312326547, 0.6121157734624801, 7.317311484967509, 15.237580499341412, 5.500162205388469, 0.19652796728957087, 17.464900362876154, 42.68117297080256, 16.30732753584462, 22.604629108982703, 20.155444299021077, 58.1544683056493, 56.61153731807586, 64.92848004064253, 129.79290777637112, 56.773746936551994, 33.300687420752745, 3.951909051787469, 0.6626928982234771, 0.10408539385084184, 0.5428955619854312, 0.10872391833653373, 0.07172957077742585, 0.07286047743212792, 0.020652677067705703, 0.0851087524525581, 0.07296033699305789, 0.08428575185638282, 0.07414637899567043, 0.09715753051662639, 1.9859907679980802, 5.601588814489303, 6.778216515817951, 4.000402539968491, 1.9053429148850904, 4.709839426702069, 12.211972994189109, 22.070141453896802, 16.445264547101914, 11.876383827578637, 32.27465618041254, 43.69250905129218, 53.12828040892079, 56.907782170080374, 48.41646655913323, 49.49079982696041, 54.57667443060107, 66.37266928149809, 65.09443552263322, 64.33810449415638, 60.76340929154427, 68.27706629230131, 66.73846952376827, 65.99341530953684, 68.59338191247755, 69.35925606758364, 70.26152672306185, 67.56091994623985, 68.75359504453598, 67.65114230494346, 70.77036796077606, 71.07361424353816, 68.55974366587978, 62.25178795476114, 65.28751811673565, 65.88609926162228, 61.902387142181404, 60.33086599842195, 55.15003865764987, 51.0035873997596, 53.00519251054334, 52.65352849037417, 51.40916047557708, 51.24518579052341, 49.29550893845097, 52.94131671228717, 53.89076955856816, 54.3475099532835, 52.545180859104285, 48.085355758667, 48.36316939323179, 47.254464395584606, 45.63420388006395, 48.517130267235544, 47.155699114645685, 44.05865053976736, 44.41290332425026, 46.104123438558275, 45.784438502404, 44.90240335464478, 43.47524504507742, 42.49248735366329, 43.17573285871937, 41.7916617854949, 40.6557826072939, 39.93678862048734, 44.58711539545367, 42.551801435409054, 40.909179487536036, 46.19893889273367, 48.318681870737386, 50.455636209057225, 50.754650254403394, 50.366241470459975, 47.06581800214706, 46.426581490424375, 45.471013669044744, 49.62917320189938, 48.36006287605532, 46.47583861504832, 46.82950696637554, 46.995991968339496, 47.369907594496205, 47.74765929868145, 53.78578339853595, 58.54156701795517, 61.00027338151009, 64.53461523978942, 60.49345216443462, 61.82133136257049, 62.286442095233554, 57.10008029014834, 56.78753014533751, 57.181210594792525, 56.146199087942804, 61.484011450121486, 56.516933671889774, 57.81943121264058, 56.84342784266318, 58.3695161727167, 55.46462451258014, 56.484232871763176, 55.770973390148534, 51.71303433756675, 41.487101508725075, 36.459497636364354, 38.336618484989295, 38.798956101940526, 31.96626178679928, 16.61612887536326, 2.5654901948667344, 1.0163090329977775, 25.969018590065744, 29.638974435867805, 36.64993263060047, 30.171573469715735, 23.67175502161826, 15.447254719272738, 3.5334370165101947, 0.037498866252961664, 0.10035682094073105, 0.10804785340423546, 0.08319358626801161, 0.1101353970326243, 0.04796792888232777, 0.07014137091896228, 0.2206523977820912, 0.009803209649098497, 0.05425494051568451, 0.04550160457109732, 0.21068841309076358, 0.3202213202753375, 8.448812807759932, 49.299109674269154, 26.072647610018333, 28.735762411548247, 30.1965570065283, 7.4306586673182835, 4.363621617517164, 0.41453569166121945, 1.0922540868482282, 28.54224051198652, 51.67198281134329, 71.2028092722739, 85.94249586905204, 18.237191515584147, 0.2544864564533195, 0.5583971979156618, 12.197586720989598, 14.837183971558849, 3.8228802334877754, 0.9918496228994863, 27.67534963546261, 74.99557648935627, 39.04615171494023, 51.01792366273942, 23.758088350296024, 73.99846292311146, 73.48489130696943, 72.06276539833316, 139.21006356516193, 56.416273886157626, 48.55724434698782, 4.659985121219389, 0.8088819634529852, 0.23394314992812373, 1.7180211793991829, 0.18076705656224684, 0.24619235957582153, 0.25987344884103347, 0.1492151891392085, 0.2120423968881369, 0.15850227386240037, 0.20093010768534678, 0.1560669569599052, 0.173980375571597, 3.0915212198611233, 6.35891955706381, 14.99888466250512, 10.803615585450205, 5.499836648664167, 11.70872211456299, 23.262153671633815, 30.579621561111946, 24.81936993137483, 25.71566289471042, 56.48134992968652, 55.90793471182547, 64.85708113639586, 63.69895035220731, 59.340181196889574, 64.14692424958753, 61.513644956773334, 71.548872147837, 70.52718101009246, 67.99067051179948, 64.81545302175707, 71.38003764613983, 73.7392177889424, 68.87696143119567, 71.64278937924293, 71.69525500266784, 74.52780246734619, 69.31481561353131, 71.79849963034354, 70.99033448003954, 73.51429339378112, 75.26116017372378, 73.07562335844963, 67.4220209736978, 67.7372932434082, 69.82786947681059, 65.47102620524745, 61.35906434828236, 58.87699242561095, 54.595219396775775, 56.412802588555124, 56.527006318492276, 55.123750932755016, 53.67213664516326, 52.06660855200983, 56.24381119205106, 57.38065919568462, 58.05882915373772, 54.71075281020134, 49.54902741216844, 50.15865787383049, 50.126117890880955, 47.41394796679097, 50.9625711748677, 49.56674868060697, 45.05065718004781, 44.88188935864357, 46.223641980078916, 46.98411503145772, 44.63048504244897, 45.75956283077117, 43.71850259842412, 42.235685856111594, 42.79200346239152, 38.60582251702586, 40.88904203907136, 47.04070306593373, 45.45086053109939, 45.86705930771367, 50.28953559937016, 48.737359585300574, 55.641484183649865, 53.44938524307744, 52.5411408178268, 48.64050449863557, 51.126185001865515, 46.94802922587241, 51.57174271921958, 52.22662948792981, 47.25232670384069, 48.200642062771706, 50.48112377043694, 50.80099698035948, 51.039967383107836, 56.52329575630927, 61.43041226171679, 63.204927829004106, 66.13623665225121, 63.21041522487518, 65.05601590679538, 64.87890520403462, 59.21668929438437, 59.81027726204165, 60.75201480619369, 60.195234360233435, 64.35127189082485, 57.617966513479914, 58.6355705415049, 58.96045261813749, 60.45189465245893, 58.7804550509299, 58.61369548305389, 58.73323363642539, 55.296292074265025, 43.474170315650206, 40.96300225104056, 42.36771675848192, 39.8293549014676, 46.832170255722545, 36.100275208873136, 10.46324504959968, 8.066650888612195, 37.94233399052774, 34.6485746291376, 46.09002644015897, 42.83079178102555, 33.887572057785526, 16.75688312899682, 3.8759449989564962, 0.2036404348309002, 0.23389480978010163, 0.256835833612469, 0.23538531044558172, 0.23278505481298895, 0.1288852381009248, 0.14076715455420558, 0.3726217955831559, 0.2443451990163134, 0.29519442288625625, 0.21730128405315263, 0.6005564872776309, 0.6165266012953174, 12.057157043487797, 59.11821034646804, 37.2131496860135, 39.2581283661627, 56.04663364348873, 18.776925340775524, 10.081614121314018, 0.9361063688993455, 2.2938513515457033, 58.35248131905833, 60.808347886608495, 83.97270510273596, 103.07426344963812, 17.757885725267474, 0.5368496573740437, 1.258900151137383], [4.427166465790042, 3.05223451506707, 0.44051425411335887, 1.0785152498752841, 4.930520307633185, 5.123870603499874, 3.001987727419023, 10.143620910183078, 12.84188210964203, 29.75160333418077, 39.24046201090659, 37.02716658192296, 44.576097457639634, 24.647679944192213, 28.41978215402173, 4.819307384952422, 0.3215375819033192, 0.12509131022999365, 0.11401245310421913, 0.05108397619258012, 0.11409620949698072, 0.05326025578523836, 0.05350530816001758, 0.08114869075436747, 0.036384656484569275, 0.02547388862548096, 0.09391991271366996, 0.02948785610046358, 1.4480367182723939, 8.503525949293568, 7.926408994582392, 4.871461670244894, 0.8053267026139844, 4.6468353752167, 11.75298115899486, 6.220163260736774, 7.144244745854409, 3.4550305528025476, 4.151076222619703, 19.58694184980085, 36.64427265044182, 41.28531125284011, 38.96191097074939, 33.844531889884706, 41.24431463979906, 53.494708230418546, 57.279689542708866, 60.58638880329748, 60.05153048423029, 65.63292595647997, 62.72553966891382, 64.3318247795105, 66.11866443387925, 66.30289816087293, 66.99140748670025, 63.48121958394205, 65.29690827092817, 68.3949335159794, 67.0457636925482, 65.75468024899884, 60.53597065710253, 60.132782382349816, 65.34215673323601, 61.35266304016114, 61.10081549613707, 54.31487975582, 47.60811705743113, 50.00227297506025, 50.45817398255872, 49.11997110612931, 50.475852104925345, 49.002982493369814, 50.4482307741719, 50.15860688301825, 50.95863311521469, 49.82684104673324, 50.41697732863888, 48.34132963611234, 49.23985835044615, 46.856610544266246, 44.89679044292819, 45.43009158103697, 50.97510706993842, 45.0784001042766, 44.14248727983044, 43.31260788825251, 43.48442731365081, 44.03187644097113, 42.27077537967313, 39.44457430993357, 43.33447902433334, 42.76491949635167, 41.8331330053268, 38.254891980078916, 44.322861394574566, 44.19189345452094, 40.013941641776796, 43.49225244214458, 48.354853968466486, 48.731778052545366, 47.47319144587363, 46.39792073157526, 44.798142833094445, 45.849287048462905, 44.71142315095471, 45.47380247423726, 45.48205906344999, 46.71640934482698, 45.79988087377241, 46.25609567088466, 46.24786653826314, 46.9252480999116, 49.55340085491058, 55.679382124254786, 60.52191680477512, 60.63721879836052, 62.07554801817864, 55.46199652456469, 57.13930006950133, 52.99674764756234, 55.89716780570246, 53.26396696029171, 55.83000506124189, 53.8389785828129, 54.71913099288941, 54.58462507494035, 54.37378983343802, 50.89762456955449, 51.00765097525812, 47.64380670362904, 47.28697299957276, 46.24538760031424, 30.576240478023408, 22.765144263544393, 25.963209559840543, 17.385052673278317, 9.31108509340594, 2.1663907458705287, 0.06312936814802309, 0.27790342006952534, 2.8218116923686, 20.37834671235854, 11.722363137429761, 3.4716253655572094, 0.3947202759163995, 0.1630355838325716, 0.10867500362256843, 0.02605824900280324, 0.043193197794138424, 0.06000263774166665, 0.03044441838057772, 0.01824508105675059, 0.02463141981992991, 0.050318600730069225, 0.08018497512826035, 0.06871288507095269, 0.03466260191353579, 0.15473122137688822, 0.0855444802812511, 0.25573268232326357, 11.429706273540376, 44.45211133649273, 23.988392276148645, 26.244931836282056, 18.226342239687522, 9.25147585330471, 3.8268486915096163, 0.36974369518218503, 0.24252259923565775, 9.886060434003031, 38.41091209842313, 49.695637764469275, 81.5011961229386, 29.992050509299006, 0.00585026586533434, 0.700538131979204, 9.166704608548073, 7.574568467755472, 0.9247658774256707, 1.7396427546778035, 25.16232236739128, 27.97728780777224, 11.023670358042564, 13.208819839262194, 17.46154477519374, 44.622907023276056, 54.7172051091348, 45.80247356045631, 68.99088275048041, 38.072117374789336, 36.05715267119869, 7.246370517438458, 0.4965115122256741, 0.2861094168357311, 0.09168950900916131, 0.18936265500322466, 0.22612686208899946, 0.12760736513882875, 0.049306150420659015, 0.05344315161628108, 0.022945834864531795, 0.021942022196467847, 0.03221289404938298, 0.014439530674398187, 1.3567636546588715, 9.736263155937195, 10.238776629970921, 6.2012167419156725, 0.7834323387472861, 9.928221010392713, 22.221378241815877, 14.159673952287244, 10.528601542595895, 12.430257797241213, 14.029346339164244, 31.146694306404363, 47.62453217660227, 51.509506471695445, 48.634581719675374, 44.26162535144437, 47.636079634389574, 61.22891618359474, 62.23692609417824, 64.3306912145307, 62.58845283139137, 70.36040183036559, 67.7960503485895, 68.07689205292733, 65.96349546986242, 69.98911811459449, 68.27765464782715, 66.4809423877347, 69.16291006149785, 70.01166389834496, 68.01794667397776, 67.86968892620456, 61.39820960260207, 64.20934484850976, 66.73043650965538, 64.64571637492027, 64.50612314285772, 55.45997258155577, 48.88324037674935, 53.88891819984683, 54.67272935375091, 54.42222718269595, 51.149252460848906, 52.973660576728086, 50.81661193601547, 51.36671258557228, 52.83208262535834, 50.6054707496397, 52.968173180857015, 51.33232516627158, 53.482462590740575, 49.862671898257354, 46.505075962312766, 50.503912741138095, 51.74291103116928, 45.083303066991995, 44.898586888467115, 44.874193668365486, 44.219922711772305, 43.294890542184156, 42.35951116008144, 41.08832590041622, 41.522810766773844, 43.55883075344948, 42.0740096799789, 39.18613326164984, 45.87030310784617, 47.5585892892653, 42.06984020048573, 45.59596469325405, 49.678724504286244, 50.87405112481887, 47.803215749802135, 47.22450140983828, 46.10868123269851, 48.699920562005815, 47.55922471323321, 48.47772221411429, 47.37905456173805, 49.39185803936374, 49.27723461581815, 49.85281498201432, 49.73408091452814, 49.61047918565812, 51.23332454312233, 55.6385188717996, 62.913205469808275, 62.93501384796635, 63.50209836036929, 57.26698498572073, 60.608416834185206, 58.050066578772764, 55.96309108118857, 58.99616187618625, 59.30697833338092, 56.39201794901202, 60.03566449688327, 58.80077685079267, 57.228510456700484, 53.8598063684279, 55.68321427991314, 53.67314469429755, 50.3173138249305, 49.54940788207516, 31.482764943953487, 24.053382027533747, 24.842247155404863, 14.323361323725793, 4.943633281415509, 0.8900500209100786, 0.05725685604697755, 0.1750608659800022, 1.574489274813283, 15.223198148512072, 7.829029781203117, 2.7403999576645517, 0.4096145879837775, 0.5797641868552854, 0.05808537630664726, 0.10698731192537855, 0.004310698225913991, 0.015186306479717455, 0.052878897216531544, 0.03420800533926776, 0.024732740693575433, 0.014032676699571313, 0.027040113251836553, 0.03759471534360801, 0.04147364833061734, 0.13542874746264952, 0.0837091864236901, 0.36498500214469054, 18.545148564923196, 55.372295841093994, 30.704021492312034, 30.843957931764667, 28.976527298650435, 9.95561190189854, 4.611636025290336, 0.3677774232722098, 0.4902655360919814, 19.097222166676676, 53.04074487378521, 61.126412883881606, 91.51092006314187, 42.28912422733922, 0.017306337981755217, 0.5273855297315506, 8.297861372270892, 6.831935826809176, 0.6321460309047854, 2.9619888672905588, 49.339969004354174, 58.08444615333312, 32.74166337905392, 25.796646110473144, 22.701688158896662, 63.8910758879877, 77.32396602630615, 54.573269813291496, 74.29132276965727, 36.22528899100519, 53.214733369888805, 7.615398870360467, 0.6173310549028459, 0.4068048226256525, 0.1340839260768506, 0.23653507052410036, 0.32826751110053837, 0.25277642563225766, 0.17528729092690254, 0.18622019298134312, 0.10050978571657213, 0.116901439614594, 0.1443643510461815, 0.14184287989572172, 1.9878207988316015, 11.45155191421509, 11.11623437173905, 7.422933559263907, 0.9934552206147103, 14.292958051927629, 29.1999396201103, 17.02176274791841, 15.764285191412895, 24.22274212683401, 28.95925121922647, 50.09922612097956, 59.95244356893725, 61.137203324225645, 59.06829034128497, 57.21620205909976, 57.7314289154545, 67.49852288153865, 66.18503093719482, 70.03373115293442, 67.82185954432335, 72.67193302031487, 70.8453558337304, 72.32972975700133, 70.88192016847673, 73.26090043590915, 71.95211533577212, 69.75505459693171, 70.32031520720452, 73.37589648462111, 71.78019000637916, 72.2983351061421, 64.77660586757045, 66.84606798233526, 70.88836070029967, 66.28106624849381, 68.7849190927321, 59.2214039833315, 51.88445760357765, 55.99275988917197, 55.49918843853859, 57.201246061632716, 55.86760490171371, 55.15565156936646, 55.31102841900241, 55.62518281321372, 56.40102763329783, 54.398363482567575, 56.30992274130545, 54.767446748672, 54.990484483780406, 51.82853244966077, 48.537542281612275, 50.856608344662575, 53.468177318573005, 47.73470763237246, 45.888208727682795, 44.92719273413382, 43.07709309362596, 44.36345400348787, 42.06372130301691, 41.03470317779049, 43.403536273587136, 44.061180468528505, 44.276224413225734, 39.11498931146438, 47.76104634807956, 49.90402152461391, 44.78629727517405, 48.352720199092744, 54.47143331650765, 53.740166233431914, 49.96046050902336, 51.02150086433657, 48.82202002309984, 51.97724127000379, 51.28252675456386, 51.478504057853456, 49.92482577600787, 52.68733539888936, 52.46816904314103, 53.08732301958146, 52.54125064419162, 54.42224287217664, 55.63436508178712, 58.42877926365022, 66.37252023143154, 66.32913097258538, 66.0791975452054, 58.67744968783472, 62.32135511213734, 59.85670635777136, 58.85181473147485, 59.388975481833185, 62.73374134494413, 60.227503699641076, 61.54647127274544, 61.93824545029671, 60.23937279178251, 57.18578800078362, 57.42728440992294, 58.14338368754233, 52.70007917957922, 54.8709463304089, 36.65354513352917, 32.406677276857444, 40.888755706048784, 34.271105335604766, 15.441935985319077, 3.000598963229887, 0.15764370380390078, 0.6446091169791838, 3.31523752500934, 20.713017063756144, 13.078638334428112, 3.3947765731042434, 0.5407062052719055, 0.9493027543348651, 0.3084883772798123, 0.17124545700367422, 0.20740338210617343, 0.1453865881288244, 0.14674763525685958, 0.1310596254564101, 0.1754259681629558, 0.18139265928297274, 0.1938760313656061, 0.17870859363146369, 0.18461539199756039, 0.37686203095701437, 0.32573381318680705, 0.4935781615636041, 23.990429947453162, 63.98539712352138, 40.699705308483495, 44.914527400847405, 50.800592976231734, 26.506471557001916, 7.972994494822718, 0.6964903072484079, 0.581840775426357, 39.29514377347885, 71.36447368129608, 69.46743503693612, 103.80685237146194, 44.298079859825876, 0.06950599291632253, 1.251160579342996], [3.198711016485768, 1.180543452501297, 0.1425508370683078, 2.2664312874117205, 6.376118169676873, 3.659908694605674, 1.7135263883298444, 2.876806999406507, 12.528409227248162, 27.358114219480946, 32.94174740391393, 26.390300758423347, 30.263713867433612, 33.39926442792339, 34.75365884842412, 8.594586714621514, 0.2525461549239774, 0.020164366879109896, 0.05544598890288223, 0.019863700351467537, 0.05391672035799392, 0.07642714532032129, 0.06832864601165056, 0.07985263852582825, 0.022011142479436054, 0.0569363440116567, 0.04147580486812419, 0.07964695923991742, 1.4238973490653501, 11.63137395535746, 11.438285477699774, 10.169019237641367, 4.962715122007555, 7.318444559651037, 8.810988779990904, 2.6910857135249726, 1.3363860835952144, 1.9003624853587922, 2.628777147300782, 8.566157375612567, 27.26387731490597, 35.59859621909357, 32.44314159116438, 34.39829995555263, 33.165373494548184, 46.84029348434941, 55.304850685981016, 55.592619296043154, 54.97450474769839, 63.717840486957186, 62.609574794769294, 63.37233851032873, 64.61846766933319, 64.2048615794028, 63.74938026551278, 63.98773485614408, 64.58771236481206, 62.92182683944703, 65.39899579940304, 60.49408366603237, 58.55696232088151, 62.60416976867184, 66.06756379527431, 65.65801735847228, 60.97890038644115, 51.65890170681862, 49.310178602895434, 53.63892985928444, 52.97643761481009, 50.096186284096014, 47.43630939914335, 47.66122594956429, 48.456294305862926, 49.33646240542012, 49.11600166751493, 47.63255734597483, 48.08619906825405, 49.342141997429636, 52.266563138654156, 46.47741540785759, 46.13808331951019, 51.58452572361116, 49.69982293344314, 42.1810511619814, 41.86548471450806, 42.48605074421052, 44.27147442294706, 40.00838756561279, 41.22523230891074, 39.656970654764486, 42.0290671625445, 40.43375292131978, 40.96859555090628, 38.89985122988301, 45.705218392033736, 46.3767477773851, 40.77199066838911, 43.267508476011216, 49.580269090590946, 49.399640021785615, 47.277861333662464, 40.72361607705393, 44.01898361021473, 44.74752464602071, 46.68004897332961, 44.08618165600685, 42.41028231959189, 44.248575625881074, 46.4544891542004, 47.515415760778616, 47.608372011492335, 46.41828567750993, 44.99425741934007, 50.43608319374823, 57.13443240811748, 56.66195938664099, 57.42074189647552, 58.101555532024754, 57.44795922310122, 55.07418001851728, 51.44372440153553, 53.41887312550699, 54.84368585771131, 53.407027567586596, 54.407098600941325, 50.98307340375839, 48.36889605368338, 49.557990028012185, 45.43916010087537, 41.20180791424167, 37.335531557759936, 29.528208663386685, 17.46497096553926, 6.590252124494122, 2.078969940062492, 3.664088715468684, 0.6369604338561335, 0.15174231401854946, 0.06037019906685718, 0.01434443234991763, 0.039255739520153696, 0.3199116675363433, 0.47697964094338885, 0.18705991727690544, 0.031912583752625415, 0.10649132362056164, 0.12451141997570954, 0.023450317169209162, 0.04989591171784748, 0.07901087643638735, 0.06390345403023305, 0.1723843845989435, 0.011911353381771234, 0.06274558491103592, 0.03831590668508603, 0.023659851792598927, 0.005349358797238599, 0.02302265433113902, 0.05925532280197067, 0.32561393574841563, 15.650049101921821, 44.667245495703916, 25.941958158246933, 18.248770352332823, 13.353488618327727, 7.855110110775118, 1.2209678897934577, 0.2310389718942104, 0.4198272754588435, 3.478357623661718, 44.206763159844186, 39.063743545163064, 79.56825210202126, 45.066848724119126, 0.261006768672697, 1.0831829929544081, 6.680200897878216, 2.029866891041879, 0.5701893748294923, 5.130590113901324, 33.03847697473342, 27.594911629153838, 5.2944623270342435, 4.629984382660159, 17.565968075106223, 37.65377306169079, 49.99778186121295, 35.25716174033381, 38.241544154382524, 32.021726062220914, 41.46183360007502, 13.171820121426737, 0.44313185397655735, 0.07583345782252089, 0.04756944441807367, 0.027436249656602744, 0.004868878506033892, 0.03681582225967319, 0.08480245517867227, 0.0318419944960624, 0.004158277851304099, 0.0629024337526531, 0.05349637940526009, 0.028437626165067478, 2.2127296270862704, 14.364622696753472, 14.724861998711864, 10.826403575558817, 1.740689904939744, 7.3008414526139545, 13.915685857495955, 6.622889676401693, 5.25738416179534, 4.455880176636481, 5.0618844070742215, 15.486151883679053, 31.73563426540744, 48.59389105150777, 42.164126134687855, 45.93930936628773, 42.90485397461922, 52.852078868496804, 59.29642323524722, 60.82384909352949, 59.99373435974122, 66.79511639379686, 64.23746824264526, 67.76523620851579, 68.0775353216356, 67.0449713737734, 64.6929338670546, 68.64440410367905, 67.48038584186186, 65.63856632478776, 67.90421362846129, 63.20169187361195, 61.69050070547289, 67.70413352597144, 67.33335187358242, 70.31413355181294, 63.753302635685095, 54.40505504608155, 53.64896328218522, 59.244726396376095, 53.795201009319676, 51.57633189232119, 50.06649394189158, 51.31214064936484, 50.39126619215935, 52.17315189300045, 51.171935527555405, 47.21440130664457, 50.011019860544515, 53.52808760058496, 54.85888504212903, 49.81213608095723, 47.29198971102315, 55.505095528018096, 52.72960678223641, 42.663541916877996, 42.64324365123626, 43.59200616036692, 44.07579521979056, 41.18427884194159, 39.67582156581264, 39.5687565495891, 42.64358489744125, 40.58144977015834, 41.34507640715569, 37.73086724742767, 47.11927990759573, 50.9528515415807, 41.67195889257616, 44.67547462832543, 51.650260725329005, 51.39613036186465, 49.278034779333304, 43.719840126652876, 46.24276745703913, 47.46126744054979, 48.62571324071577, 46.30190895449731, 44.94651825197282, 47.021310867801795, 51.12620853608655, 49.08783512730753, 50.02574051580122, 50.90713631722235, 48.98084071374709, 52.62308305309665, 59.27586609317411, 60.00397174589096, 59.75330091291859, 58.05434588463076, 60.560618831265366, 60.937593906156486, 53.700871929045654, 54.91094666142618, 58.20038357088643, 57.121025746868504, 54.70573217638078, 53.827952800258515, 52.93453493425923, 55.00521298377745, 50.5480747069082, 46.671862986779985, 39.64075949884231, 30.084045779320505, 16.76393751175173, 6.862982367315601, 1.15634806694523, 1.2873195616468307, 0.3179077960310444, 0.057855963616842226, 0.06601479234955003, 0.022451263822374806, 0.05152639579929171, 0.2049376515130843, 0.47758500362115525, 0.04073817327979111, 0.021102600505635626, 0.1900708879674635, 0.028068274109353943, 0.029970288479460344, 0.06295520954975678, 0.11190167402908688, 0.07681267906821544, 0.11048123210428223, 0.0856254481139683, 0.08165260806920067, 0.011509451207764929, 0.04772234407644119, 0.04852092562003001, 0.0226399531933449, 0.13555585677104612, 0.24258466767928294, 27.902221487414455, 54.71400053270402, 34.09067238530805, 28.854345467782792, 25.40605256634374, 7.102657816102428, 2.3552018788553055, 0.4906710111085446, 0.6640624795709887, 7.015865570114506, 54.965079292174316, 51.74549587311284, 88.81255688205843, 58.74251396425309, 0.4276463058927367, 0.6060755685452492, 5.879860876067992, 2.7267076988374037, 0.8076209827296196, 11.716226589295173, 66.10553233854233, 50.721184592093195, 33.64415760963194, 8.974994844005955, 22.251107846536947, 56.10625759247811, 68.49157287228492, 45.905165133937714, 54.28493245955437, 49.307252514746885, 57.248349805032056, 15.42177402204083, 0.6068575910983548, 0.17953912487193463, 0.13803959043035585, 0.14668907549592758, 0.0945243637468065, 0.3340706884139969, 0.28995732326180707, 0.15103714540600777, 0.18416366059212916, 0.2344140948186959, 0.1514309758861219, 0.13061808302037178, 2.462134760233664, 14.24675351189029, 16.214276167654223, 17.309943206848637, 11.613170235387742, 13.68960730491146, 14.837074145194023, 6.177210855868555, 6.645673253843862, 7.211355028613922, 10.422930928968615, 27.060478887250348, 46.35593175888062, 62.613316735913685, 53.24715568173317, 61.37445572883853, 55.144449280154326, 60.315415782313195, 66.59738186867007, 66.27701836247599, 61.52412160750359, 72.97777591213104, 66.7331664792953, 70.81543599405597, 71.0442356909475, 70.44214402475666, 68.8756670490388, 69.57289972612935, 69.63108416526549, 68.63389215161725, 70.16078456755608, 65.87901546109107, 64.41978000825452, 71.14364424059468, 70.56437292406636, 74.46424438107398, 67.19289964245212, 57.97389415002639, 53.90388988679456, 60.325076580047615, 57.7962343154415, 56.207188021752145, 51.69023752212525, 53.8730953585717, 54.87500990590742, 54.122648316044966, 55.645030006285644, 51.05928897857667, 52.210586993925034, 55.17671861956197, 58.54785065497122, 52.154512789941606, 51.35346281913019, 58.76524409940166, 51.957562738849276, 44.21500405957622, 42.2023182530557, 44.09720743856123, 46.71023553417575, 41.70681307392736, 42.160917635886904, 39.4712778060667, 42.24272258820073, 41.514126639212336, 41.7725912217171, 39.163916956993845, 47.72384266699515, 52.21649800577472, 44.9966343756645, 47.806710581625666, 54.92833452840006, 54.42596520147016, 52.916845044782086, 46.14623008235809, 49.38408390168221, 50.91284728819325, 51.36996030807496, 48.357387819597804, 47.09760489002351, 50.08708638529624, 52.35566369948849, 53.46123864573818, 53.22622591449369, 52.452208918909875, 52.96153653052546, 56.717088299412886, 61.78234300305767, 61.898857009026315, 62.28075858085387, 63.54274980483517, 63.79071420238864, 62.36127699575117, 56.4992045587109, 57.69834372305102, 60.51201282009002, 57.531799885534475, 58.7047533066042, 56.40901750133884, 53.599396290317664, 58.31291637113018, 55.38815790607084, 53.21057173513597, 49.56160253094089, 39.0710352313134, 30.630108348784912, 24.812654833639822, 14.317274785810902, 3.7163386085341057, 1.0584882406457778, 0.49403919327643614, 0.10427773554599094, 0.24610174669613763, 0.11368476665548741, 0.7799108470639875, 1.3123268778285673, 0.3990837901590332, 0.13980038223728058, 0.43309493771483826, 0.20007656316363043, 0.1992731667574375, 0.19411914170749728, 0.16372431219825823, 0.20998295336481065, 0.39206106215715414, 0.1789870053049057, 0.19293034178835733, 0.14233067872062807, 0.2041845717617581, 0.1623289136876983, 0.1233310163802197, 0.2549098272837939, 0.29682965288239144, 37.25975528840096, 63.38873009527884, 45.25120404458816, 40.95711477341191, 41.48729370486352, 20.599552700596472, 3.5814402084196773, 0.6533484028712396, 0.8057616566938739, 14.639438659914079, 89.04331776403612, 61.89932769344699, 103.88417797703897, 68.98426963436988, 0.4697644410114135, 1.261624482370192], [1.1099080621234834, 0.581494810119752, 0.0968870172096837, 2.093370431853879, 11.289964972003814, 2.057665341323422, 5.949308401153934, 1.2142540177991314, 6.004694719468394, 16.459459604755526, 26.240852571302845, 25.88375214607485, 58.13122434000815, 57.31372394869405, 35.104075554878484, 17.21167410573652, 0.1995884425817959, 0.08482249603877146, 0.05066998993917819, 0.05610384392522036, 0.05911437794566155, 0.03991792676970363, 0.03525248961523175, 0.0418099494380576, 0.03816189619922831, 0.11334048674231577, 0.06160088867369679, 0.05769871640950442, 0.9640989152173843, 10.73482603796067, 13.870745301246645, 13.63331344819838, 14.601817246406311, 18.756868300899384, 9.857639920326973, 4.753546397532187, 2.7084240605754237, 0.05553651368245483, 0.40679780526026604, 1.413417388835261, 3.2299801514994715, 22.281180658648093, 24.96372295964149, 26.85836111345599, 29.375530404429284, 38.909225694594845, 46.11527473695817, 52.60011365336757, 57.53621255197833, 61.648119495761016, 56.32687914756037, 57.52526129445722, 61.215234956433704, 61.42379522323609, 58.39044986232635, 63.287395661877056, 60.42827806165142, 65.0766436515316, 61.24262486734698, 59.74558561078964, 64.64364536346929, 65.40441259261101, 64.21598934358167, 64.45005286124446, 57.41209699261574, 48.33502246487526, 52.289720812151515, 52.42367367590628, 47.934348429403, 47.96796314177975, 47.28551387786866, 46.62896010183519, 47.93959263832339, 46.71618969209733, 48.311727508421875, 46.66582253671462, 51.135551621837, 53.102416300004535, 51.52587844479469, 47.38599323457288, 43.96296039704354, 50.84045994666315, 54.067742978372884, 46.88327481669765, 39.317877830997595, 43.504141146136874, 42.72313840927617, 43.51077779646843, 41.34562553897981, 39.38011015615156, 42.03257768384872, 40.789394224843676, 38.63046676881852, 42.603855209965865, 50.75035525906471, 49.44609657410653, 43.15659561464864, 44.82617601271599, 44.39828857298821, 47.78853431824715, 46.80959701538087, 46.12093079474665, 41.56945559286302, 45.307952896241225, 44.054014298223684, 43.58275328913043, 44.22746542961367, 44.817323223237075, 45.56782953200802, 48.32331026754072, 45.639200979663485, 50.71061772684897, 51.3093989126144, 49.43328611312374, 53.49161348035259, 56.09501607956425, 59.066266398276056, 53.993339538574226, 53.65411727659164, 58.41706314394551, 51.59047203679239, 53.20681018214072, 52.74579048156739, 52.98743594077326, 52.734658795018355, 47.15932730705508, 46.18451633761006, 44.63072430702948, 37.17220014141452, 31.1430190455529, 23.953849923226144, 13.104972147172498, 2.6646062827879384, 0.3189126888830816, 0.09928151694757324, 0.16946364374410722, 0.04760146306286897, 0.00549715631003041, 0.12442702006909157, 0.02721327402058148, 0.046784736726793556, 0.059081478299753326, 0.19011682259940332, 0.10832749847923556, 0.04487520128849053, 0.14441062275680805, 0.037533665796922105, 0.02773112072909792, 0.052909896964387554, 0.023317937175893498, 0.042057422650677544, 0.00996910886193115, 0.013249652486504808, 0.05030779505989725, 0.042151218625686826, 0.04979710169737378, 0.0717666647547195, 0.1081660531100727, 0.10323562614259221, 0.41498035973598885, 24.875885402002645, 42.29085791495539, 30.002513431733657, 21.969997459842315, 12.449868667510248, 9.278077367813358, 0.6034071923744294, 0.05864615649766019, 0.08754014698488098, 0.40083522037152325, 25.521587940954394, 43.001171696570616, 65.16441060650733, 57.114243968840576, 0.6018757519702758, 0.5785929303496116, 2.815736431267954, 0.8969196845446864, 0.36721876131430753, 14.701981832904202, 41.208303359247026, 15.029507587032935, 1.8164367565224249, 0.19745445870343717, 12.575491397611557, 26.89181304747059, 48.320219439844934, 35.18441354074786, 56.32565144569644, 50.40263322091872, 40.992227831194484, 28.451606304414813, 0.17235113638302973, 0.07409466806078151, 0.025493990772614078, 0.02751002009327133, 0.04187055465374743, 0.09520963705595463, 0.02629063219853467, 0.04822734923612687, 0.06445257819347805, 0.12616766376360772, 0.01875882919487213, 0.08079142565087927, 1.9240893928274032, 12.581611275672914, 15.687234151747921, 18.290035647730676, 13.17789096986094, 20.464344678386567, 11.195016157242561, 4.096456972822066, 5.061016092377325, 0.8305875632551409, 2.6079893208319143, 7.316129870953099, 8.91280762610897, 23.325439153179047, 35.41424482099472, 37.818371403601866, 41.09608042624689, 44.32094727793048, 51.493640484348425, 55.991343913539765, 61.21823556961552, 64.97008854343046, 59.37527856519146, 60.0038109287139, 63.72409274501186, 65.02036156192904, 63.82987906855922, 67.18663953965711, 63.066452472440666, 67.83158702235069, 64.22197095809445, 63.508417298716886, 65.8661187079645, 67.44713983228131, 66.09566365518879, 67.107423351657, 58.960205508816635, 51.424241988889634, 56.66098663883825, 54.002435515003825, 50.833125114440925, 51.312685858818796, 49.33896487759006, 49.198595016233384, 50.775634934825284, 49.899695150313846, 50.408885478973396, 51.09549637763731, 54.408169407998365, 55.75857085566367, 53.84125355751284, 51.16972723314839, 47.06346458004367, 54.34816498910227, 57.07510263689103, 48.112643687955796, 39.67999496767598, 44.45157789414929, 41.72236919403076, 41.40596728171072, 41.23468129865585, 40.299176400707616, 41.57479001629738, 41.37128176227693, 39.38036511021276, 43.117038511460834, 52.791807728429, 52.63557580209548, 46.611011335926676, 48.47802031424738, 46.21868018181094, 50.501288675492816, 48.709075373988, 47.56593588859805, 44.39121261719735, 45.776177990821104, 46.404867249150435, 46.389624918660815, 46.90514987514865, 47.34022701940229, 47.90584456536078, 52.058599072117964, 47.93709016615345, 53.041160645023474, 53.45249960499426, 51.50948293747441, 58.37943584688249, 57.894905459496286, 61.763366576164, 55.51643510018626, 55.38960133829425, 61.40711338289323, 55.24124553126674, 54.87707699498823, 55.562864195915964, 57.579794006962935, 55.05446226366105, 49.7437495570029, 49.673998048228604, 48.66628623777821, 39.256406445657056, 29.94201675538094, 22.427310520602813, 12.653682866404134, 3.05655304462679, 0.5070735664377289, 0.17709783248363004, 0.06745588800479328, 0.051936589917468454, 0.06291587093484498, 0.07107340880940038, 0.03071842887889474, 0.021550982191617933, 0.10888666605516788, 0.13324453885997498, 0.07422996684908867, 0.005545766025240864, 0.12045486950345578, 0.010320403267659489, 0.11687893961225787, 0.0503393578823776, 0.05121631788149957, 0.04453313919985968, 0.0700092590564201, 0.048375146748918685, 0.07540816411135659, 0.014997777029601558, 0.057796105336878574, 0.13271550918298383, 0.012688862719392825, 0.15179702801810158, 0.5598386076669539, 36.30002975463867, 50.83145810711769, 39.87273631557342, 32.27635064432698, 33.28227189279372, 3.0894840388528766, 1.4872707162172565, 0.12016822238482776, 0.10353057765431943, 0.48879005074981724, 42.777533838825846, 56.27839472986037, 75.89471709343695, 70.12917810870756, 0.6224434354132222, 0.9218730068495198, 2.4282783317950467, 1.1339807510375977, 0.5383643664179311, 24.84473001572394, 77.87558463311966, 32.91897412269346, 29.45968681766141, 1.833102784810528, 16.597974185020693, 49.131110637418686, 59.492628036006806, 48.23787712281751, 78.80510007181476, 74.61975066892563, 50.27670160416634, 33.90550905658353, 0.28667472843681613, 0.21087777470388722, 0.10834711799097639, 0.1421070576555306, 0.08290172209061923, 0.19275146025803783, 0.3143764064917642, 0.1596567070772571, 0.12438804151550417, 0.23809431991990537, 0.17005570713550816, 0.1275132895417271, 2.7742823718055605, 17.337350768427697, 18.44497319190733, 26.61002605192123, 24.14491249668983, 28.47456393703338, 15.553091053039799, 7.60778505955973, 5.762984541154677, 0.5713729500289887, 4.223346383340897, 13.19159180887284, 18.888020592351115, 41.2989140325977, 50.18629489406463, 54.94363177207209, 50.033695082510675, 53.83246352595668, 59.71520293143488, 64.01837641193022, 67.0283091452814, 72.68734793509208, 63.93300602512976, 63.93613999889743, 66.1035240850141, 71.77046252835181, 65.54241334238361, 70.63056684309437, 65.72929859161377, 69.3971775424096, 65.81997594525738, 66.42428767296576, 67.66476861892208, 69.06682768175679, 70.42468947748985, 67.8841624721404, 61.88157112367692, 53.84061421117475, 58.93476109350882, 57.77731672410042, 52.735800204738496, 55.310114506752264, 52.00708266227476, 52.638529346835234, 54.198083339198945, 52.16029828594577, 53.615019090714, 52.03505308397355, 57.36682891845704, 58.983135684843994, 54.44587123009467, 52.842002299524125, 48.54753648081134, 57.91589798465852, 58.53176109252438, 47.07370588856359, 40.47217645952779, 47.26836527547529, 42.80149167583835, 44.11867064814414, 44.76700313629643, 39.901412763903224, 43.74051886220133, 40.1523385509368, 39.96183687640775, 43.022748654888524, 54.651505408748505, 54.92340803146363, 48.84583273241597, 47.61536951987974, 46.77297776745212, 52.36537156566497, 50.33121470482119, 49.43013644987538, 45.68981916673722, 49.38529591406546, 50.945285289518296, 48.977306658221835, 50.47995882649576, 50.3589262500886, 50.583834955769206, 53.5990079756706, 49.69248025648056, 55.4873977938006, 55.534281884470296, 55.10979906205208, 59.29496411354312, 60.954518933450025, 64.87210381415584, 56.58866989997126, 58.12550160192675, 62.24817937420261, 55.699954955808586, 58.510513613300944, 58.6403872120765, 59.95783682792418, 58.63221299263739, 52.6537795220652, 52.14489121590891, 56.293778265676195, 48.186235197128795, 44.78346140153947, 38.80481220060779, 28.67026471322583, 15.860741176912862, 1.8220329981657768, 0.6997553126946573, 0.5700231031064065, 0.13259540191821514, 0.16314159507953352, 0.1759206158139052, 0.1911939115774247, 0.17795286321591947, 0.18225383404041492, 0.23292714880118448, 0.17807225035803934, 0.1405402239892752, 0.30778624237545077, 0.2126005072627337, 0.22430703554662967, 0.15277210472812577, 0.21909250487242976, 0.19407798746420493, 0.14761176711368948, 0.16497470558651034, 0.183635228463719, 0.11428660532880215, 0.13132979402378683, 0.20617235542064716, 0.2977761085475645, 0.2260423779127098, 0.7511800984221121, 51.058120112265314, 60.520775395054976, 50.6394463200723, 43.33422799264231, 46.835920041607274, 20.087430400233117, 1.9811690718896928, 0.21548870470254652, 0.21096834161829567, 2.8332400081619142, 70.93976728377804, 66.86947668752363, 85.78808784484865, 81.70794425472137, 1.042524929488859, 0.7619884345800646], [0.41216127874870456, 0.21265477693128973, 0.14600736449562735, 5.738067194338768, 13.397165190789009, 1.9278381981195944, 4.348558245166656, 0.5970266605577161, 3.4000948167616323, 3.653517192409885, 20.269526435482888, 33.50970268249512, 72.69089375772785, 61.470871510044226, 33.28886147468321, 28.973128564896125, 0.7953489896270537, 0.0700753341398893, 0.03334770009161965, 0.05426095047545049, 0.10745484772468768, 0.061952182121815226, 0.02984487605581601, 0.04767389667610969, 0.04119703313335776, 0.0664662249806908, 0.011352856132772662, 0.04239281594392754, 1.7257507001200032, 12.60422864267903, 8.183591942633353, 16.129169560247853, 20.24722776105327, 18.80012616034477, 8.858492605147823, 17.508428865863433, 1.1731231861537503, 0.9421080242722266, 0.17549434917107706, 2.2995481039247205, 4.0966116612957375, 5.018721174809241, 11.077142069416663, 16.122483880289142, 24.770281468668294, 27.597512160578084, 38.73273864869149, 40.96444960563414, 45.33777075429117, 51.303574192908506, 52.027808466265284, 56.05798890513759, 63.33576240847188, 59.08451326431767, 62.0701979052636, 61.9819994895689, 60.21542279951034, 64.40377281558129, 61.96853791513751, 62.392495139952636, 61.14976667588758, 65.11580851770216, 63.40412539820518, 63.25173739464053, 51.348253911541356, 53.14005928654825, 57.79015856404459, 50.665361419800796, 49.39804753949566, 48.27172325503442, 46.77460162870346, 45.18911684713056, 48.282011631996404, 49.525438277952134, 48.73257037132017, 48.06668527664677, 50.98745861361104, 50.139610844273726, 54.476202918637185, 51.02116354050175, 50.70764457025836, 48.38882169415874, 52.017841723657426, 51.44364595413209, 46.160911513913064, 44.80661515266665, 44.13453271312099, 42.46565834168465, 40.16811040139968, 40.61454672967234, 40.86429972802439, 40.274822404307706, 40.58681949492424, 45.43058579967868, 50.64822066214777, 48.32039986887286, 45.85387229919434, 48.39885119468936, 46.44573442397579, 44.6761178970337, 46.85880707156274, 44.51539877922305, 43.349250670402284, 43.39276152272379, 42.47498181558425, 45.500788381022794, 42.1091188153913, 43.448478791021536, 44.90630219059606, 47.712542318528705, 49.68573377978418, 52.63648579197546, 53.90073237880584, 48.38850398217478, 52.96347810376076, 52.20130274372717, 55.11657299533967, 56.25520567740164, 49.94783047706851, 52.601768893580285, 53.15929458987329, 50.54497603447207, 54.46793063994377, 52.39623277418075, 46.98768438831453, 41.96638376482072, 39.656558805896395, 36.215875302591634, 23.24423432350159, 13.125471434285565, 7.236954867839814, 0.61421129972704, 0.1534657207347693, 0.07106288276132076, 0.05695637721087664, 0.03355617942889372, 0.029887935942820007, 0.04695360931838232, 0.03998448448856512, 0.015576543049856782, 0.07681968111184335, 0.04470413002455908, 0.17848250576325003, 0.04251403786662606, 0.020786051060103124, 0.1332321435573601, 0.06355189628178073, 0.04611766183628671, 0.010352359667810942, 0.06626550228365007, 0.05297714416238089, 0.04818888396144875, 0.052089853467600006, 0.06247298018405996, 0.07799196417533583, 0.013681173534883607, 0.04163747623322472, 0.027991630842969305, 0.23135982483865755, 0.9427431418049721, 24.788030193698024, 43.713960493764574, 30.261580098059873, 20.045057035261586, 30.2854496817435, 11.42878451654988, 0.26582169256383376, 0.14328508637845516, 0.7674780980713907, 1.6208445809541212, 30.94611017934738, 41.277278238727206, 71.34506579368346, 51.94012780343333, 0.26699380708798287, 0.13445003949586423, 1.1755718483078865, 0.322689839428471, 0.30164546543552034, 21.261962575297204, 39.0105640503668, 13.7056262646952, 2.1503448197918553, 0.443969126790762, 3.9111590577710063, 24.773841019599672, 38.471379356999556, 39.664011309223795, 89.66145192423176, 70.33883663915819, 38.010830340846894, 40.37552533611175, 1.105128899216652, 0.10043234954918585, 0.08414286113674603, 0.04401127244496057, 0.06361984061978518, 0.017459727936394272, 0.07749788342945038, 0.07539458903333834, 0.08653349979149719, 0.02970209833414805, 0.07153503040993406, 0.06839741772461323, 1.8278689946859115, 15.528928272185789, 12.638418962878566, 20.632741835809526, 23.71909018485777, 23.923078929224324, 9.883469708504217, 13.496833597460101, 1.2774000100551115, 1.3777173238415874, 1.665923400752006, 4.496674297317382, 6.234773599332379, 7.082493401342823, 14.311172558415322, 27.824758598881385, 34.72163661833733, 35.52659326984037, 44.15235596318399, 47.500498987013295, 50.75022189847885, 56.4005647936175, 58.45940905232584, 59.745805263519294, 66.34972341599004, 64.57579620422857, 67.15504092554893, 63.22210388798868, 64.12591211257443, 66.26432557259837, 61.82083322155861, 65.4502062643728, 63.82690198959843, 66.59989218558034, 64.95678778617614, 64.75759806171541, 52.83853100192163, 57.06157045979654, 62.16666075491137, 57.500012997658025, 52.03795956027124, 52.688590557344504, 50.746891806202555, 49.96021732207268, 50.52583094566099, 49.862844482544936, 50.18136447475803, 51.58272143333189, 53.16086353794221, 52.8528162740892, 56.635122529922, 53.31995094976118, 51.74418580147528, 52.55715193287019, 52.697612008740826, 53.66495086300758, 49.01161170774891, 46.62657137840025, 45.14226413542225, 42.947886297779704, 40.52358696537633, 40.95056049285397, 41.02701533225275, 42.75292881073491, 42.93334214918075, 46.85876392549085, 55.107531932092485, 52.40657998669533, 47.85722678707492, 50.207769870758064, 48.754708228572724, 48.27025628858998, 49.34961803497807, 47.63372228991601, 46.0673669076735, 45.584115212963475, 45.936308753105905, 45.55483864199731, 45.75683678350141, 46.758704262395064, 46.80221511471657, 49.464551325767275, 52.560368276411495, 54.8630545216222, 56.90484431482131, 51.503517012442316, 55.4068087762402, 57.28506711221511, 55.209968551512695, 59.926920706225985, 52.88705856569352, 55.695287335303526, 55.28395229770292, 55.404600481833185, 56.85740716995732, 56.01842787957961, 53.064157501343765, 45.15489808974728, 42.644910658559496, 38.689008143640336, 23.644673016763505, 15.616368689844686, 6.885039325683349, 1.7238613434376258, 0.18645944224009592, 0.0786228375809808, 0.04461132230297212, 0.02156851028332547, 0.14450025504394887, 0.08490465896865053, 0.025071623517320524, 0.026387251207544923, 0.034496092703193426, 0.07029926930103572, 0.07948686218550129, 0.07307593199995256, 0.04339553693669938, 0.09882814611398405, 0.05902954902980597, 0.05645360902792985, 0.023430550185542916, 0.042583847628726114, 0.06163516727786872, 0.0379867340257812, 0.008216944162643725, 0.0915449328960911, 0.010666406878660764, 0.03562694956218043, 0.13883609204523026, 0.04447095201260621, 0.13957948844519355, 1.6574097737189264, 40.79052778982347, 56.809777828954886, 39.880502608514604, 25.671914738993493, 51.146781367640344, 38.62075105790169, 0.1019867342866717, 0.04010803914899307, 0.7707801821731752, 8.985672516207542, 58.040437159999726, 47.86984897428944, 84.26247412158598, 57.43789049886889, 0.02961865795265523, 0.3064118806392916, 0.6541059106107682, 0.5388172775987656, 0.40693717197545115, 39.864617009316724, 67.06545399081323, 31.046613070272635, 28.598389241003222, 1.2067117902540392, 6.329257613228214, 58.5926401999689, 49.12532514141452, 59.9750481882403, 89.81775837559854, 78.32875959334835, 47.83892108548073, 52.481124631820194, 0.9883919310185217, 0.16999691754819887, 0.2534498628829756, 0.2297704835091868, 0.18384342051802144, 0.186051040767662, 0.17562668319911728, 0.22752495722905283, 0.2832335534114992, 0.1653553746760853, 0.1488917314958188, 0.21814442510085724, 1.8263829066868753, 17.70786177727484, 16.770489831124586, 25.805593036836196, 28.089216563009447, 26.70406291561742, 11.462436491443265, 25.671475433534194, 4.2563070404914125, 3.7893559807731263, 2.179228173148248, 5.737854896053191, 9.334564401257424, 12.753567984027248, 24.811280042894428, 44.7268537552126, 53.26086828785559, 49.04759553170974, 53.72242143077236, 55.91197475310295, 56.33373937299175, 63.56688022613526, 60.96428171280892, 64.04415815107285, 70.49966950570384, 67.43697304879466, 71.16013388479911, 67.52848978965514, 65.27355055655202, 69.06320341171758, 66.85074344758065, 66.44965756324031, 64.53370524990943, 68.65408451326432, 68.16252523852934, 70.399107779226, 57.032650824516054, 58.62713352326424, 66.0725530501335, 58.930458253429784, 55.281802838848485, 54.9737947986972, 53.70938347231958, 52.56865232221542, 54.27416555343136, 54.63871848198676, 54.45237844221054, 55.00951974622665, 55.42104697996571, 54.30134365635534, 58.18416064785373, 53.208426198651715, 54.67340400142055, 52.20909257088938, 57.19755511130057, 54.98429890601866, 47.7791480864248, 48.003997956552816, 44.896912036403535, 43.210991044198316, 39.904582039002456, 40.61351514631703, 39.97211740862939, 42.68297333871165, 42.59280589319045, 48.33113147366432, 57.383914762927645, 53.19379968027915, 49.804197203728464, 53.47315872869184, 48.73606520314371, 49.708224650352236, 54.49487340065741, 50.4736477328885, 47.31820683325491, 49.50528121763661, 46.78980473549136, 51.60302754371397, 49.941597830864694, 49.876753207175966, 48.880894799386304, 54.459889781090524, 56.082409581830426, 58.61401711740802, 59.0664154483426, 55.33251516280636, 58.68940507211993, 59.04908641692131, 61.23256006548482, 61.21897689757809, 53.741284108931026, 58.469011014507664, 57.15542493327972, 56.84707172455327, 59.92705406681184, 58.681089647354625, 55.716342618388516, 47.088038229173236, 46.45473626352126, 47.21726855924053, 40.21111526796895, 32.051094808886134, 19.486429152950166, 7.1805472623917375, 0.6175885217324381, 0.27521864961712594, 0.19143375838475843, 0.09940180807344376, 0.27403774040360607, 0.262608106939062, 0.07563841949787832, 0.1387310767125699, 0.16165483292312394, 0.12415364925419131, 0.25913432721168767, 0.16391888320926698, 0.16870420546300952, 0.4433953269354759, 0.19722368237712692, 0.31258544614238126, 0.18228990145989005, 0.23339510594885196, 0.16789048219159727, 0.14981604721998015, 0.1740091345122745, 0.25914137522059105, 0.11642277255774507, 0.19579351879656318, 0.24011826292882044, 0.11819401380395698, 0.37730718932805524, 2.7663586937612106, 55.40756579368345, 68.38146409680768, 49.93541617547312, 35.81456584315146, 59.44388866424561, 44.58721345470798, 0.38132262386141286, 0.23311479437735774, 1.5127460201901775, 7.58786726382471, 73.91947423258136, 61.52901672547864, 101.60451212236958, 75.80480852434712, 0.5472001181014123, 0.2899707757657574], [0.059457504896507155, 0.02377264291769074, 0.21425369435981398, 6.047138196806754, 11.727861319818805, 2.096791719236682, 10.557063241158763, 0.18860628107382407, 2.5553060058624517, 5.708604801085688, 21.238000815914525, 44.564683360438195, 85.88469582219278, 59.4183305002028, 32.09217771407097, 37.767278609737275, 4.926922513592628, 0.3902018586954763, 0.09441239233579367, 0.04546253408695902, 0.07381155260748441, 0.09425794134937948, 0.018590801215219884, 0.053303179691635796, 0.030669671212953907, 0.07535141231792589, 0.03163992539949475, 0.19544395287671398, 4.1444469267322175, 17.394550692650583, 8.135277657739579, 12.746528310160484, 14.440869650533124, 10.79246428705031, 13.983749766503612, 7.302082392477221, 5.233748939729506, 0.9143009325188975, 0.7835329107699857, 0.8235820875533166, 3.642299458865197, 4.553727132658805, 4.711679018312886, 9.32649314403534, 18.61555510951627, 23.594909906387333, 22.741335476598433, 34.063054976924775, 43.58102352388444, 49.25388474618235, 49.42766927903699, 48.87829819033223, 55.80732199453539, 56.728196451740885, 63.30955313098047, 57.92504495190036, 59.38703390859789, 63.18307630477413, 58.040080224314046, 65.40822513641851, 64.78927120085686, 64.52482892620948, 64.59992270315847, 56.485303678820216, 52.1731165916689, 59.04318717218215, 55.90045867427703, 52.17456394626249, 49.87377612821518, 48.862012509376775, 47.250506724080736, 46.13565537237352, 47.14348093155892, 47.94791590782904, 49.01193726447321, 48.2459532830023, 49.60886316914713, 52.63336358531829, 52.470020401862364, 53.642561974064, 51.44604252230737, 56.59466720396473, 54.70512813137424, 52.06071322964084, 50.35453319549561, 51.4155617836983, 49.30046681434878, 48.13436969634026, 40.87134430485387, 43.50822825585642, 49.97234136827531, 48.15019253761538, 49.074789324114406, 48.07521250940139, 50.254195044117594, 53.787285666311945, 47.4224595100649, 50.77188122657038, 46.83032674174155, 45.70807387751918, 46.036160530582556, 45.33071441035117, 44.74441028410389, 43.275867046848425, 43.284088334729596, 42.53465283301569, 43.59539901056598, 43.59441057328255, 43.52766752243043, 47.03365456673407, 49.04542253863428, 53.069185979904674, 55.88053695617184, 51.61595567580193, 49.722325571121715, 55.324089911676225, 50.20867201589769, 56.31649663371425, 53.363689299552675, 48.54108418187788, 54.51932153394146, 51.00758429496519, 51.89336138386881, 48.97750669910062, 46.233502818692116, 36.40562780441777, 32.35117573891917, 23.19973699508175, 10.824613013575155, 7.5267194740233885, 0.6837204795691275, 0.06163911263067877, 0.04629614500088557, 0.015614022943942298, 0.028257721907369075, 0.05698593288299538, 0.044515461721006906, 0.015567177624982453, 0.11215337221660923, 0.15399632855288445, 0.10750238348038928, 0.19446086288700182, 0.47721115271410636, 0.15572318266476357, 0.08946790765490263, 0.1782538438396108, 0.03238717905215679, 0.08132844562492064, 0.015723357097275795, 0.07366219610576669, 0.07904705110817187, 0.08046442102040015, 0.03995846814265655, 0.051742172124044555, 0.046436748948068395, 0.034771738799228784, 0.03207854904054153, 0.04855425044473621, 0.29085903939220215, 1.1849730341665208, 34.484635245415475, 44.18311519007529, 39.81206509374803, 23.366706409761985, 37.61442776649229, 38.74045002845026, 1.931470312899159, 4.543170073340017, 13.724179075610254, 34.817491500608384, 36.47303373582902, 41.699042858616004, 74.83669696315643, 32.45432819089582, 0.10521426271166533, 0.07480476261867632, 0.3923895300155686, 0.00553285600730188, 0.25101344281386945, 24.428894058350597, 38.85660709873323, 12.577038772644537, 9.87858537704714, 0.5537957061202295, 2.5750183674596974, 21.854883740025183, 42.466062345812404, 50.7907086033975, 97.24174607184626, 65.6643323744497, 38.41643871799592, 51.75885938828992, 6.569572898649401, 0.6204438846438163, 0.016862702210463824, 0.02526016541636519, 0.12010911104059029, 0.02964875754720021, 0.040803865319298166, 0.038988830656894756, 0.04465099416613098, 0.06703050236307806, 0.006960350729059429, 0.14870569470428652, 3.0000535086277993, 16.313179712141714, 12.11138871408278, 16.2699963777296, 18.285701428690267, 13.49923114622793, 15.603921048102842, 13.127363977893708, 5.445501525555888, 1.3442402621430736, 0.9039503492174611, 1.63402913799209, 5.85793286561966, 5.2666169308847, 4.671531108117873, 12.60745773392339, 22.978644755578813, 28.66557748086991, 29.48336224402151, 42.426681749282345, 48.41014762078562, 51.878656418092795, 53.394083746017955, 51.84960342222645, 59.36157772617956, 60.320138316000666, 67.28123926347303, 59.34195410820746, 65.41487747623076, 66.46876735071983, 63.3495456172574, 66.75645751337852, 66.23050689697266, 66.21273071535173, 66.44200894140428, 58.06072365853095, 57.03427860813757, 62.56127080609722, 57.54608515770205, 56.33748523650631, 52.04938934695337, 51.92105723965553, 50.46113537203882, 48.64220680729036, 49.322887082253736, 51.00592121001213, 50.337882734114125, 50.27001788539272, 52.01130705495035, 51.50067721643756, 53.70441382931125, 57.07715795886133, 55.253651988121774, 60.5357902280746, 57.88835510130852, 54.0978628589261, 54.439281648205174, 53.64864949257144, 51.279741871741514, 49.21767734712171, 43.38497561793174, 44.744982950149044, 53.103255687221406, 51.06650613969373, 52.4385473035997, 51.20436960651029, 53.11765078575381, 56.47208529133951, 51.90212788120393, 51.4157735916876, 48.2160020643665, 46.52060070345479, 49.564677669155984, 44.97514370949038, 46.92178464704945, 43.82576765552644, 46.698554715802594, 45.48396533535373, 46.74300693696546, 45.56525253480481, 45.41204083350397, 48.67491152978713, 51.81423541038267, 54.70626169635404, 59.86329986203102, 55.29120476015153, 53.620773207756784, 58.03053709768481, 53.9603445606847, 58.78310657316639, 56.35683821093652, 51.20521683846751, 57.78625580572314, 57.19290710264637, 54.558478555371686, 52.49956369400025, 49.69139375994283, 39.87746277163106, 38.56639485205374, 25.15542095707309, 14.317701343567142, 7.629531170091322, 0.8178979603032913, 0.08681473832937979, 0.04679997421560749, 0.03225351969200758, 0.06810130942012034, 0.07176432818655046, 0.10545111411521513, 0.09867458378956204, 0.015489181255801551, 0.17461958401385816, 0.2983325335287279, 0.2148873869690203, 0.5331595650603694, 0.19985062851300164, 0.20958828018797984, 0.4005393878586831, 0.0394795099723964, 0.04075075627394742, 0.04504380957974542, 0.02861426688820845, 0.030684822516876365, 0.10575690577107091, 0.10538814934871851, 0.052178807766927834, 0.07295801574664731, 0.023369780260949366, 0.08940162572769389, 0.021061540108114, 0.18025428327100892, 2.7805633121921174, 53.803916515842566, 55.3938453428207, 47.00496242892358, 29.50325062198024, 46.84537295372256, 60.126592882217906, 3.615957311084194, 5.980034778195043, 25.325116419023086, 53.11516792543473, 51.945677957227154, 50.63897171328145, 88.0639176214895, 30.28494565717636, 0.28715917179661415, 0.16384644193514702, 0.36319379664717183, 0.22862257736344493, 0.6156481742378205, 46.551787468694876, 73.24321839117235, 31.59759036956295, 34.66688033073179, 0.4058956294771164, 3.673997848264633, 57.61340871933968, 56.431912376034646, 70.22448385915449, 96.84874027006089, 73.43452022921655, 44.35757829296974, 65.8162732278147, 5.401888201313635, 0.8843446270592752, 0.29042696580290794, 0.1852887066742105, 0.18527430422123403, 0.21216484838195387, 0.1520701077195906, 0.1349999986949467, 0.19456944818938934, 0.17351646336816973, 0.09465380196249294, 0.3679508655782669, 4.318576628162015, 22.48029193570537, 16.13496192039982, 23.326604097120224, 24.859807606666322, 23.32152266656199, 21.052431521877168, 11.534051126049413, 9.057134178376968, 2.5427107849428734, 1.25254247938433, 1.7273070230599374, 6.109636752836167, 6.608147448109043, 7.646948454841492, 17.960599699328025, 33.973762219952, 46.01283811753797, 43.14059626671576, 53.91078541355749, 56.69345209675451, 60.935369922268784, 60.929219645838586, 56.53782421542753, 62.383407008263376, 63.89072679704236, 68.72524415293049, 60.87826413493003, 67.01248630400627, 71.60999836460238, 66.0043744117983, 70.09364143494638, 69.41182367263302, 69.06132067403486, 69.888109237917, 61.32636747052593, 59.40594365519863, 66.6630345006143, 62.0197719143283, 59.73588951172368, 54.15608259939379, 52.77633397809921, 54.785379825099824, 50.59175422114711, 54.89533170577019, 53.92864004258187, 55.17775804765763, 54.089794543481645, 55.6247042840527, 54.97026466554212, 54.589480969213675, 59.58165407180787, 55.111666110254106, 62.413499432225386, 59.83757695844097, 57.925821581194484, 59.148777377220895, 55.72727818642893, 52.223703399781265, 50.493734190540934, 44.86991436250749, 45.594242772748395, 53.905913829803474, 50.736497525245916, 55.35435099755564, 56.022416930044855, 55.56758280723326, 57.60315564370925, 52.45128323954921, 56.00618616227181, 49.60891023758919, 50.578449541522616, 51.14451816005092, 50.443045400804095, 49.67923441240865, 47.692451938506096, 48.11379294241629, 47.372382610074936, 49.195292380548295, 51.27969480329945, 47.46885722683322, 52.50933824046966, 54.64897940235754, 55.706415099482385, 64.15661250391315, 57.240438384394494, 54.73427526412472, 60.28388777086812, 56.681469255878085, 61.00463897951188, 59.53964940963253, 53.230262033401004, 60.50379153220885, 58.899055757830226, 57.4745842718309, 55.9267738557631, 52.46348965552546, 44.328729260352354, 45.13186200972527, 40.43860489322294, 25.92048122036842, 14.025451425583134, 3.558666436902939, 0.28074591270377564, 0.11459566818009462, 0.2002033200715819, 0.22607311336023195, 0.23435191912276132, 0.25616403578990893, 0.2864749020626468, 0.30168027647079965, 0.35791345902027627, 0.7054585002122388, 0.6053851088208537, 1.4985809931831977, 0.6509271360212757, 0.3776217450297648, 1.47770564882986, 0.3494465020635436, 0.2098288317962039, 0.11160355857423238, 0.15969766213768916, 0.15353949500187752, 0.17415974739818804, 0.1974396272412231, 0.18122295548598613, 0.28102614766647743, 0.13179666332660184, 0.17952731179614223, 0.23340897214028145, 0.39869363690095566, 4.924728437777489, 69.79281917695077, 65.74377213754963, 57.04231554462064, 39.91343482848137, 56.613722078261844, 82.19310222133514, 5.021262870680902, 7.890865946969679, 25.046916430996312, 59.783193296001805, 68.55881798651912, 67.83164978027344, 106.23364633129489, 47.83493595738565, 0.3750038693749136, 0.24485610305301606], [0.0014958499941126174, 0.10687717912538398, 0.15727587434793674, 6.942274060941513, 13.816787215971178, 3.797595409616348, 14.735942694448656, 4.016336188200982, 0.8165995332021868, 18.418263812218946, 32.778135538101196, 50.801910892609634, 107.28371973960631, 106.16081576193534, 57.667796304149014, 42.2318733123041, 11.9916985688671, 0.6924333507495543, 0.14822485195773263, 0.07045908290291987, 0.034361203771925745, 0.057554354801053004, 0.055536881404658484, 0.0162709778129694, 0.04448508633480919, 0.06632060698804355, 0.052797400783146584, 0.3318412499802728, 4.967391077549228, 12.100461971375251, 6.731482455807348, 3.162068969780399, 18.001966976350356, 24.901182728428996, 15.755420634823462, 13.004232933444362, 10.75729827727041, 2.6216379432908954, 0.9107336594212441, 0.21730802562688628, 1.5619178332628743, 4.274445551057016, 4.7442621473343145, 3.458550880032201, 9.268496978667475, 20.64424026396967, 27.7184231435099, 29.468357216927316, 32.66306692554105, 41.30381307294292, 47.71761786553168, 47.65016094330819, 55.61855400762251, 51.970404578793435, 61.364543899413086, 61.6123749363807, 62.58013348425589, 58.571502547110285, 64.28171257818899, 61.98216815148631, 62.76859552629533, 64.81058143800306, 59.555060402039565, 51.31109729889901, 60.28366811813847, 60.00533673071093, 53.311113849762954, 50.360534421859256, 50.03353426533361, 50.1658122770248, 47.36835825827814, 46.72064942698325, 48.55620099652199, 49.143819116776996, 47.8546223332805, 46.53621173674061, 46.70224566613474, 48.6488316905114, 54.134740983286214, 49.926210372678696, 57.46488425039477, 57.909010302635934, 53.04875043130691, 51.141105698001006, 49.730209535168065, 50.2413296699524, 51.166067661777625, 49.10950622250957, 46.77086753229941, 48.38820588204169, 50.68039978704145, 46.11813806718396, 47.858701598259714, 47.44532300579933, 48.61883340343353, 56.727627708065896, 50.6949164790492, 47.620958897375296, 49.4710506931428, 47.16889789027553, 46.37055435488301, 40.490827329697154, 42.36359826980099, 42.596030081472094, 44.521572589874275, 43.0802192226533, 42.72565264855662, 44.05688939555999, 44.486828234887895, 44.04676183577507, 49.11368746911326, 50.80741005559122, 56.54739872101815, 53.128147048334924, 52.11460659580847, 58.547823198380016, 52.776290832027314, 54.12360537436701, 52.811498026694025, 47.61838190017208, 50.19400235145323, 50.81900065945041, 47.761622936494895, 47.25901042261432, 39.241732858842425, 29.555247522169548, 25.296243852184666, 13.166198384377266, 6.8253320263278106, 0.218324072719101, 0.14796058226737285, 0.05660748544840082, 0.029732594379193844, 0.044764436465958436, 0.07071061255109888, 0.0843818729082423, 0.06602369429123017, 0.030927844758656238, 0.04454191473703231, 0.38119925306208674, 2.9639829022269097, 4.972391609222659, 5.21958428044473, 5.026369796645257, 1.0493459312185165, 0.18846614827071467, 0.14994380004223318, 0.06540803539176142, 0.020923772601470835, 0.07311421341352886, 0.025678349831592173, 0.06501143933424065, 0.05377990088515705, 0.012667511848943129, 0.07095437406772567, 0.011199870289513662, 0.07161225973358078, 0.058025567822398684, 0.03596795444947577, 0.4283372865569207, 43.48545889700613, 55.26910220423053, 42.84620277343258, 27.917671703523208, 22.895382642745975, 42.17068433761597, 24.662635941659254, 14.485675865604033, 36.26328891323459, 27.739900081388413, 35.520258642012074, 60.902814249838556, 59.59379772986136, 3.6998313136639136, 0.2498739483135362, 0.04201422295262737, 0.14219718023894296, 0.10064405794706076, 0.2291464436078264, 19.92978838182265, 40.99898607500138, 11.548532516725603, 17.651913089136926, 7.098425578686499, 0.8231270313262941, 33.547714371835035, 49.15047930132959, 63.53799589218632, 111.61906057788481, 109.57414073328819, 69.08137967509609, 52.76727330300116, 17.012264728546143, 0.8526342254011863, 0.14325392192169545, 0.11893024728182824, 0.03440028191694329, 0.044254647087185614, 0.07684980368902607, 0.0769131131950886, 0.014300589138011058, 0.07973381828877234, 0.05549636301434329, 0.09352986670790181, 7.880981083839171, 20.325692815165368, 8.902545725145648, 12.396475403539597, 24.840334999945856, 21.970879993131085, 15.629794962944525, 13.137458197532162, 9.249047906168046, 2.081645977112555, 0.1406325222623925, 0.17678513071469723, 1.144070558009609, 5.081817892289931, 4.514633849743874, 4.468096398538159, 9.686118595061764, 22.0244203459832, 33.23844332848826, 33.33643590250323, 40.810308302602465, 48.782105984226355, 54.56841391901816, 52.31207047739337, 60.208413524012414, 55.6967935254497, 65.0508423005381, 61.327767756677446, 65.85025664298766, 62.889549655299035, 66.28119176433933, 63.18508063593219, 63.80640760544808, 66.97483155035204, 62.89062046235608, 53.06803672544418, 65.12575564845916, 62.68603355653825, 55.29409162459835, 52.94616476182015, 55.104429337286184, 51.3609427790488, 50.675155578121064, 49.07225155061292, 51.822409629821784, 50.208981883141306, 49.27761508572487, 50.674563300225046, 52.250893269815755, 51.78477448801841, 57.16799220731182, 55.042530413596864, 58.19018148606824, 61.57670882440383, 54.72580686692269, 53.494598404053725, 53.36920415201495, 52.841880706048784, 50.98772925715293, 52.68179308983588, 48.53048593767228, 50.21691291562973, 51.81311753488357, 49.03274936060752, 48.855913223758826, 49.60235203466108, 51.7785418418146, 58.4630411671054, 53.48262733028781, 48.059103335103686, 50.20951140311457, 48.816214915244814, 49.148902508520315, 44.720676022191206, 45.57057126875847, 44.47788915326519, 44.86327378980575, 46.64864647773005, 44.59852949265511, 45.91109183526809, 46.02343636174356, 47.280120618881725, 53.08232199761176, 53.91531967347669, 60.669958822188846, 56.60382986068726, 55.05797278496527, 58.24340020456622, 55.74904734088529, 54.62697882806101, 58.95438863385109, 48.90407992947487, 51.46840003228957, 54.21157237022154, 52.82780724187052, 49.91906381422474, 43.919963375214614, 33.52803584068052, 26.247750059250865, 16.58640907656762, 5.496395749430503, 0.8476375548108932, 0.22376919585850932, 0.025851795968088894, 0.044139216789194656, 0.05965109148453321, 0.021026886120859175, 0.04502134022092627, 0.06985255577150853, 0.06881641419303995, 0.05075513295108273, 0.33875035182122265, 3.754576079307064, 5.045097643329251, 4.522174606400152, 5.957283070010524, 1.6519302225882009, 0.5098440161635799, 0.14384859001203892, 0.09647043391821847, 0.09892700209973321, 0.02488206080611675, 0.02355254011138553, 0.06216376794562225, 0.020823999225432356, 0.019486426946616942, 0.08786168940845998, 0.10653929604638009, 0.0652461150480855, 0.05273000036756839, 0.19770084790164427, 7.011008204952364, 62.50096044232769, 63.608394592039055, 48.652958023932676, 35.353436316213305, 35.68029134504257, 54.22948191242834, 42.15940360100039, 23.870903561192176, 44.96480826408633, 38.3300289030998, 47.61212571974724, 70.29136811533283, 64.58995203818044, 1.8800292861077095, 0.10880251129668568, 0.09790822007362882, 0.3598465746448886, 0.23907901869425852, 0.5083602264283166, 35.042121718006754, 73.10391933687272, 27.8126423974191, 43.27803219518354, 10.479747441507156, 6.721703496671493, 69.82721836336198, 61.166475972821644, 73.09696105218703, 116.97831261542537, 119.07179140275525, 70.10357287622267, 69.55520199191186, 15.480791964838582, 1.3820281312350304, 0.3322216585999535, 0.2150416770769704, 0.23315116823200258, 0.29941473997408347, 0.15314952560490178, 0.17779394593690673, 0.11702382982137705, 0.19287343677734176, 0.12378755115693617, 0.3984907155315722, 7.882420593692411, 26.665837457103116, 16.41323447227478, 15.784864887114495, 32.15557498316611, 33.85646766231906, 19.79553741793479, 19.891392300205847, 15.816662561508918, 6.747822559648945, 4.091705266506442, 0.2974869563214241, 1.2981351296747885, 5.234016151197496, 5.208225096425703, 5.697935954216988, 13.580633075006547, 28.69562871994511, 44.35194576940229, 46.161888184085974, 51.56756147261589, 56.90391471309047, 58.458491217705514, 58.41072459374705, 63.9316253508291, 58.31219857738864, 70.18728410044025, 64.90842888432165, 68.07710386091664, 63.62822217326011, 71.43382903068297, 67.0442496576617, 70.324582745952, 69.24858247080158, 64.85816371056342, 55.75733138668922, 65.1045552376778, 64.77823365119197, 57.697406276579834, 55.457336748799975, 56.6874038019488, 54.80371298328523, 55.95596805695565, 51.43893126518496, 56.184834434140114, 53.597415493380645, 54.37031461346535, 53.50735395185409, 53.366736981176565, 54.63709069836525, 58.88346433639527, 56.498074916101274, 62.72653202856741, 65.77985402076476, 60.26904944450625, 55.11470986950783, 56.47239123621295, 58.61510361394575, 58.089321659457305, 55.95619555442564, 49.94683027267457, 52.635869979858406, 57.935788323802335, 51.8297326949335, 50.39082688670005, 52.26695929804156, 53.108801918645064, 62.26268822147001, 55.109293076299856, 52.63887843778057, 54.097243124438876, 52.532331174419774, 51.74278551532377, 47.62355158405919, 48.167588249329604, 48.02009144136983, 49.58664686449113, 49.60277957300986, 47.72515666100287, 48.31871324969877, 49.24555363193635, 49.34063972965364, 55.76398372650147, 55.570654023078184, 61.06029741225704, 57.931595310088134, 58.956604772998446, 63.49674432508407, 58.640583330585116, 58.123285462779386, 58.83811389246295, 53.33504423018425, 55.03589376326531, 57.63567209243775, 53.14052997096893, 53.58436969018752, 47.19927664726011, 39.03557308258549, 38.28820074758222, 31.876733687616166, 11.927650186323351, 2.39656719469255, 0.32273151461155186, 0.16690589066955352, 0.13907695008862403, 0.19165144992932198, 0.10091299311287942, 0.1890328847953389, 0.2715044408555954, 0.1603847817187348, 0.36769244879964863, 0.7904544845223428, 5.229727039414068, 7.577027793853515, 6.838661711062155, 9.89330210993367, 2.488176601548349, 0.5686030825299602, 0.49812820289404164, 0.25034757451184336, 0.1804828072988218, 0.18006983994235917, 0.19589425935860605, 0.18235633660468364, 0.15108589924150898, 0.09267771646620766, 0.30158368810530634, 0.28282345122387337, 0.211147912627747, 0.1829062038732152, 0.501186732322939, 10.50030948654298, 77.08863166070755, 68.44090369439894, 61.94625100781841, 42.85753057849023, 39.33656792486868, 60.902422012821326, 51.30991666547714, 30.366370139583466, 61.760762122369584, 54.73567947264641, 71.33370660966443, 89.09258273340042, 100.00444396849602, 6.847401732398618, 0.3468381565424704, 0.2087317479233588], [0.45189148716388217, 0.3443611491351359, 0.2642300376488317, 5.5407072555634285, 12.64403481637278, 6.226543976414589, 10.713388323783876, 22.701193940254953, 3.879790637762316, 35.31111001968384, 41.41415326826034, 55.16822668813891, 109.87017769967358, 111.6847602782711, 56.14225318354946, 42.13571640752977, 21.60423448008876, 0.4144728418079115, 0.18893073463151533, 0.05177615578436563, 0.05107045474071657, 0.07638674950407398, 0.014991341891037601, 0.04409248159537393, 0.06127937306319514, 0.06719779298310319, 0.15119154276626726, 0.46611580937620134, 3.4343040133676226, 8.771698397974815, 7.967809611751188, 1.1122399111909251, 9.028937239800731, 31.87894198202318, 35.38633715721869, 20.26313885565727, 28.936168070762392, 10.718410918789527, 3.637052553315317, 0.6201890531566836, 0.8955002155515456, 1.3905336683796299, 2.4043989421859866, 1.8169599026441576, 2.614485256133541, 8.683902025222778, 28.829206997348418, 30.13970421206567, 35.574775665037095, 39.33332804710635, 48.535490882012155, 48.289821071009484, 49.38022036706248, 51.95342463831748, 57.260136527399865, 56.41839981079102, 62.45393122396162, 56.52845367308586, 61.810819410508685, 60.54123447787378, 60.32871653956752, 62.654356495026626, 54.56306380610312, 55.42673441671557, 60.51757081862419, 59.5759823245387, 52.22606074425482, 50.37199558750276, 49.19108759972357, 45.82961636204874, 47.99019513591644, 45.97528926787838, 46.69930388850551, 45.46411421991164, 45.37813978810465, 45.45278641485399, 45.82099107003982, 47.5389225252213, 51.71904733104091, 50.79230500805763, 51.98816899330386, 52.38063350800545, 51.10057192464029, 50.48790947083504, 49.50005269819691, 47.32926399477067, 45.49454789007864, 49.30651510915449, 51.914957954037575, 48.19049489113593, 46.706728935241706, 47.98344865922005, 48.78579301218833, 46.327655392308394, 46.84711840844924, 49.322812557220466, 46.743297192358206, 46.96157317007742, 45.937293268019154, 44.340637576195505, 43.57154315517795, 43.072127372987815, 41.9777351040994, 40.71794825215494, 43.217411964170395, 42.21255171683527, 43.234968493061686, 42.73602339529222, 43.67483485129572, 42.83129384440761, 49.569149171152425, 53.25032887920257, 56.68062202392086, 54.91426498659196, 51.66316140082575, 54.86070502188898, 53.243778521014804, 48.699493023657034, 51.85759329026746, 46.37228804249918, 45.96020383219565, 48.664458413277906, 44.30654041228756, 40.03507929463541, 34.46785142344814, 23.058321822074152, 11.602846557094205, 6.760122131916785, 0.2815178841833146, 0.065593735104607, 0.014593092998820207, 0.03387533165814896, 0.04317836633192436, 0.08056720703720086, 0.007338806303338178, 0.05214244923404148, 0.06036047358065844, 0.06391041776946475, 0.38644689405637406, 1.472470755538633, 3.975456265672561, 12.684546036105003, 14.947239795038778, 9.88947387664549, 4.14281080807409, 0.7205807694023656, 0.8687838491412901, 0.03210002823071855, 0.023382177478784037, 0.06762470313978773, 0.06618481790346485, 0.07168279344876928, 0.10378783764017206, 0.05214918314689591, 0.06195985066193727, 0.060401129866800005, 0.004187491177881678, 0.08960557365489584, 0.07378865423942767, 13.653598966137057, 51.732861918787805, 64.0222595584008, 49.79594845925608, 29.065194437580725, 28.106094521860925, 30.864989680628625, 41.59503729112687, 30.985316230404763, 23.590118731221846, 25.097271819268506, 35.83970823595601, 40.78560913762739, 10.274549626534986, 0.07253967811383548, 0.07161795176685819, 0.10453390768699108, 0.1590206395954855, 0.30692951092796944, 0.2951771092991675, 12.810485497597726, 35.08135718684043, 10.726702809333803, 17.238083424106723, 34.46248562105241, 6.483500407588098, 50.796007725500296, 56.17655038833619, 62.40963981997583, 115.51265624261673, 112.241987874431, 63.31606034309634, 55.40714610007502, 30.539207420041485, 0.5883370171631537, 0.3432544585197203, 0.0922279462458626, 0.06259081982857277, 0.15474131841573024, 0.020587519374525836, 0.08355344074868387, 0.06898892953270866, 0.06493145209406653, 0.04089580736153069, 0.38161235831437573, 4.4146070364982855, 18.84370957651446, 9.479793098665054, 5.752345602358542, 18.492988886371737, 36.16663778981855, 27.31856103866331, 16.750330809623964, 22.053989133527203, 7.808387817875032, 3.339200510132698, 0.3230832715428645, 0.5115522390171405, 1.8370640109623633, 3.8165039304764043, 1.6629660562161477, 2.4270976983731796, 9.460748030293374, 27.996740802641842, 36.557478443268806, 41.38865786214029, 45.862195568699995, 52.11221787237352, 52.233599539726015, 54.13730229100874, 55.45007251924085, 58.115672142274924, 59.95916258904242, 63.64266826260475, 61.725872639686834, 64.52022014125701, 64.50438945524155, 64.8449767020441, 65.29856743351107, 57.13711923168552, 59.331426466664965, 65.94413465069186, 61.91424838958248, 56.57607909171813, 53.32518731394122, 52.396691691490915, 49.66399992665937, 50.5808892557698, 50.22910364212529, 47.30200352207307, 48.57671891489337, 47.06888529562181, 49.88089523007793, 48.34471856394122, 51.27216777493877, 53.154207275759795, 53.549052669155984, 54.64586504044072, 54.782238006591804, 55.383635413262155, 51.86426131956039, 54.26455574650919, 52.239694902973795, 49.26695408359651, 50.74271448196904, 53.077477870448945, 50.54071634046493, 50.58858494604788, 50.877557723752915, 51.06081870294387, 50.56949084804904, 48.59805660863077, 50.69646581526726, 49.68543567965108, 49.612165804832216, 45.799975010656546, 45.914735717158166, 45.52421669806204, 45.006463835316325, 43.64554651321904, 44.515245806786325, 46.48553079174411, 43.733446828780636, 48.23378216835761, 46.34675733504757, 46.65269436374788, 44.595826979606386, 53.32022159330307, 56.91030425410117, 61.08485537190592, 58.73087236958166, 55.38542793643091, 57.14213986550608, 58.65645716267248, 55.0630130306367, 54.39746525979812, 48.21151487288937, 48.08858386931881, 53.81445200212541, 49.15614320385841, 44.58565627374957, 37.563927250523726, 23.039082596378943, 15.052456394318613, 5.446399258029077, 0.5927312362097925, 0.10218440795377379, 0.08699158972669994, 0.04812883798994365, 0.025909846280551246, 0.0388715579174459, 0.09215212652399656, 0.07709921893453406, 0.025973228564966592, 0.0551209339661704, 0.3435719559990591, 1.637759802322234, 3.9522569169921264, 13.468813165541619, 16.22088045843186, 11.137547550662871, 3.1021251024738437, 0.8293740799830807, 0.8981703690463497, 0.16151361227516206, 0.10302592489507892, 0.10116773266946116, 0.015603783221224384, 0.06371620681978042, 0.044040962182466066, 0.011899120872840287, 0.05818266947303088, 0.026816197242888234, 0.07875571553144725, 0.05075971798730954, 0.12824925488882488, 27.52200261239083, 64.35284868363412, 72.3018652392972, 57.814304674825365, 33.418052581048784, 38.35897207260132, 40.691770353624904, 49.764938200673754, 40.01750707626343, 31.062359425329397, 29.71775720196386, 46.50824131504182, 45.88238793034708, 6.972648405259656, 0.2702393539009556, 0.044887661708578955, 0.030641042507223548, 0.700635088066901, 0.4531800164090049, 0.5304858569175966, 22.383833008427775, 66.64765880953881, 34.3248692635567, 40.69611633977583, 44.82369315239691, 15.178992056077528, 72.79955125624134, 68.65560639289119, 69.98037907385057, 119.86472206730997, 117.85853955053516, 69.44887438128072, 70.59767384682932, 33.585294600455995, 0.8379490553371368, 0.4508881571312105, 0.1568037037166857, 0.12367210936762633, 0.2778280983048101, 0.14408250729883873, 0.1817698196898545, 0.15254849898478678, 0.19615514294034053, 0.2717306819413939, 0.6260343653059776, 5.182665951790349, 24.329544344256004, 20.531017126575595, 8.4660388769642, 24.71313253525765, 55.98134579197053, 44.892220881677446, 27.576762822366533, 31.68594175769437, 19.270775279691144, 7.451392316049145, 1.074451551802697, 1.1307287384425442, 1.667621787036619, 3.4998517219097387, 2.775213444425214, 3.020223806942663, 11.658383396364028, 34.44274433197514, 45.996513212880785, 51.24163604551747, 53.66879086340628, 59.787841304656006, 57.4410480068576, 57.17879833713655, 61.118819175228, 63.44032103015531, 62.392267642482636, 68.71186887064289, 64.42509874220818, 67.9182086452361, 63.9753205545487, 67.67065217418056, 67.7437416199715, 59.85716919745169, 60.37953476752005, 67.20158377001363, 63.72353576844739, 57.07284727404195, 56.72176768702846, 56.761873922040394, 50.928921161159394, 53.527405108174975, 52.32296682173207, 49.57340102041922, 51.43015692310949, 49.668624401092536, 53.34374796959662, 52.20929261176817, 54.227430512828214, 58.08754090339907, 55.40054475107501, 58.01409059955228, 59.04780772424514, 56.39126877630911, 55.34051287558771, 57.82600510504938, 55.13944041344428, 51.788390913317286, 56.06093852750717, 58.06691708103303, 54.145884436945764, 53.284884960420676, 52.84708569126745, 53.93636711182133, 53.94972278225807, 51.26110669105284, 53.30823483005647, 52.88447372374996, 51.08840473236577, 50.86284491323656, 50.22322008686681, 47.09593396033011, 48.95211327460505, 46.16997218901112, 45.50057657303349, 48.41225785593833, 46.76508203629525, 50.490007938877234, 47.3936967695913, 50.08359155347271, 47.331695864277506, 54.99027659816127, 58.117527423366425, 63.4978033650306, 60.283570058884166, 57.83705049945463, 60.33098759189729, 59.96340659356887, 55.7131576538086, 58.32288311373804, 51.02988296939481, 51.135618302129934, 56.30924417126564, 50.765558365852606, 49.87519210384738, 44.37931999083489, 34.251803351986794, 29.199608179830737, 12.089546995778239, 1.503532617803543, 0.21887738738329182, 0.14622424398699116, 0.2066843013369268, 0.075274903116928, 0.18662131661849637, 0.16924213708168076, 0.1546999496678191, 0.15478336132101475, 0.20896627808049803, 1.0084169790629418, 3.181042454896435, 7.0681184049575565, 18.528047030971898, 20.076343820941066, 16.761591934388687, 9.387037869422667, 2.0304475244014495, 1.488630798074507, 0.3323098506417967, 0.29418499479370736, 0.2568995721277691, 0.16647366386267448, 0.1793924496779519, 0.20182479112859697, 0.17886214829500646, 0.20980235579754078, 0.18000588692244024, 0.22966367553078362, 0.21427528271752022, 0.2866369756239076, 31.1673887314335, 78.66427129314792, 77.81765122567454, 68.0217513730449, 42.65954894404258, 42.68068267453102, 45.50555406078216, 63.69495345700172, 56.27083632253832, 46.63968778425648, 59.218893666421216, 80.39048287176317, 85.14685092433807, 19.749945748236872, 0.5752994877196128, 0.27148679018981997, 0.29285240017117997], [0.5280248760696381, 1.3836122784883746, 0.21851131992955364, 1.5974578165238904, 10.950548552697706, 5.612125281364688, 3.770868379262186, 20.455786066670573, 21.380416193316062, 46.19104708394697, 53.915825659228915, 53.51074287968298, 91.80555282100555, 98.5085225874378, 47.944687797177224, 50.88181349538988, 33.00438765556582, 0.8947455270155784, 0.21613604899856353, 0.06780915412931673, 0.16252543056203475, 0.0820927792078545, 0.02784110988760668, 0.0264862910543959, 0.23633843107569605, 0.06038280504365122, 0.19151185338775958, 1.1336765222011076, 4.228284647387843, 5.6431840792779004, 2.2993110456774315, 1.3102975415606655, 1.333684305990896, 12.020758428881246, 35.32661514897501, 31.462350968391668, 34.9656198101659, 23.247476162449008, 16.09274741142027, 1.8266832131531932, 0.861551427552777, 1.190509214516609, 0.7669175668589531, 0.951846595252714, 1.6131749989524966, 4.466385754846758, 14.676790410472503, 30.558885951195997, 34.54300011357954, 38.176056261985536, 41.28964547188052, 47.620460756363414, 48.91362305610411, 49.91032869585099, 52.66879043271465, 56.73622946585379, 55.21245925657211, 57.1903810962554, 59.725656047944106, 62.44886352169899, 59.98372839343164, 59.48044907662177, 54.54330682754517, 62.14438953707295, 64.40884051784393, 61.14426751290599, 55.055113377109656, 50.7544933595965, 46.032312685443515, 48.407166619454664, 45.94690307494133, 45.63999329843829, 45.05649758923439, 46.47308511118735, 45.4502486413525, 45.529970815104825, 46.40405139615459, 46.468833261920565, 46.000470884384654, 51.736854891623224, 48.802749418443256, 52.17377947222803, 51.07931267830634, 47.0925764114626, 48.80260429074688, 49.926280975341804, 50.047278250417406, 49.142414908255304, 49.37278355321577, 49.71851302731422, 50.138238014713416, 47.58738340870027, 46.407326575248476, 43.05247629842451, 48.18371311310799, 48.708349735506125, 44.76416726266184, 47.015980366737615, 44.17361520951794, 42.06345850421537, 42.496743125300256, 39.947461389726215, 42.565757228482155, 43.07441411479827, 40.33270874331075, 42.653630087452555, 43.10170204408708, 43.880955403850926, 44.18154624200637, 41.31171664884014, 46.808122204196074, 54.822155967835464, 56.141829567570845, 55.538435674482784, 53.201703256176366, 53.79853894633632, 56.777594781691036, 51.18658165777884, 50.428199229701875, 44.01807754270492, 40.562889114502944, 48.41149299375473, 39.08457133077806, 36.77880994735226, 24.724328940914525, 13.247371835093345, 7.609194171044135, 0.6335167767059419, 0.14824070997776526, 0.11755636818106137, 0.05918057943363825, 0.03599093708720419, 0.028918231424364834, 0.11093670201878394, 0.015148783493186197, 0.024910241350411408, 0.07793771748941752, 0.24294822236462948, 0.27032475738275435, 4.418404381121359, 7.349280763056971, 24.536214028635335, 21.120537596364176, 14.409793692250407, 9.54565263563587, 5.671568801326137, 7.671756465588847, 0.1439028903241119, 0.16539171788721316, 0.15984449054925673, 0.02362473432214991, 0.05639268588575144, 0.023350961311089418, 0.04109314394994609, 0.06367521345495217, 0.1297115865013292, 0.1001574005931616, 0.09536041082033227, 0.32040824572886195, 23.889752511055242, 53.21086199052873, 67.85549779092112, 47.88323602368755, 28.96757644991721, 30.332431831667503, 41.6503740895179, 43.175960356189364, 27.728652684919297, 12.027120513300742, 1.131202732363055, 4.017887975900404, 4.987587361566482, 0.29743716060634584, 0.049289185403575825, 0.08736567812100535, 0.057657351492032896, 0.40385939841789587, 0.39790511792225225, 0.10629095332396608, 2.1586318073734163, 23.421709806688373, 11.8765309164601, 11.847132752018592, 39.18923977882632, 30.41522522126475, 58.8318734015188, 67.26189413378316, 59.71620313582882, 99.227736226974, 98.24715937337568, 50.344280119865175, 64.80732587076002, 47.79098187723468, 1.0345962259077257, 0.19505972913917036, 0.16456742260244586, 0.09779811791715123, 0.015921427214878704, 0.017844767557577263, 0.06871175892170399, 0.11717497130795834, 0.059841414538001826, 0.04957029753695092, 0.8866226048238817, 4.390457003347335, 15.228813021413742, 9.81045969070927, 0.9071428521025566, 4.197782335742827, 30.97355304225799, 48.16490927050191, 32.74531118331417, 37.65949972214238, 22.272516142937448, 11.032783004545397, 1.449126892032162, 0.9270917203637862, 0.8542293430336061, 1.6922254668128107, 1.455841009174624, 1.2200277466927807, 4.428910939924179, 14.091962076002552, 32.89197252642724, 43.15608962889641, 46.21487548274379, 46.18476344693092, 49.88453126722767, 53.776891385355306, 53.766673611056426, 56.841509803648925, 60.46310870878158, 57.86691150357647, 59.74063165726201, 61.232669891849646, 64.63581631260534, 63.28498340422108, 61.124012393336145, 58.44263307509884, 64.12363713787448, 67.93751455122425, 62.569390112353915, 59.69028019135999, 54.725136141623224, 50.101748205000355, 50.976272013879594, 48.211624699254195, 49.39835740673927, 48.24835769591793, 47.31149565789008, 47.434175629769605, 45.936524483465384, 50.103332842549975, 49.52041764413157, 51.79061097483481, 53.208402664430686, 49.526254130947976, 54.527723250850556, 51.6092719570283, 49.25341798413185, 51.109609065517304, 50.55861019319104, 53.765587114518695, 53.13443460772115, 50.47571482196931, 52.00174823884041, 53.739311156734345, 51.1354104165108, 49.82165175099527, 47.95292477453909, 51.864131881344704, 50.78326002244027, 46.58978739092427, 50.18331389273367, 47.596750028671764, 44.968330552501065, 43.985141400367986, 43.00405463864727, 44.79381253642421, 44.197831922961825, 42.43725645926691, 43.13630519374725, 45.93699516788606, 48.73126814442296, 46.55829468081075, 45.37543335268575, 49.324530555355935, 58.23060151069396, 58.85536839885097, 58.49031732928369, 54.27041576754663, 56.164469488205455, 60.07216215133668, 52.98529824902935, 54.78443845625847, 46.961730064884314, 48.224976447320756, 50.926916830001346, 44.288168030400435, 38.207435223364065, 24.730445877198253, 14.302241321532959, 6.019962545364134, 0.601706293321425, 0.11946223405820709, 0.18872399814426902, 0.05942725208437732, 0.034331567660574956, 0.043099934250236525, 0.03088349401349983, 0.04666108630537506, 0.05918529853525181, 0.05974693674473994, 0.049067265053670255, 0.05660077068774451, 4.904673849382709, 8.178871860427241, 25.84839394015651, 23.754344447966545, 17.09912561601208, 7.596034128819743, 5.400506056124165, 7.77397882553839, 0.2617419679318705, 0.10474108850523349, 0.3368830278275475, 0.06394287691481652, 0.05742122787201116, 0.004642569908737055, 0.0526164086805957, 0.09333911081475597, 0.09233306116995313, 0.038618208810446725, 0.025204999424937754, 0.322636611639492, 35.73129000202302, 65.67311848363569, 76.5672545279226, 54.750164785692775, 39.497216440016224, 35.70437862027076, 47.45251271032518, 61.4252818015314, 34.893628628023215, 9.492711424827576, 4.638855313101123, 15.029804706573488, 5.620761850187856, 0.17234653985548407, 0.042525548337688374, 0.032306261015154665, 0.05934063435321855, 1.2167540384877114, 3.0421601524276123, 0.3340501266141092, 4.582680108085755, 46.28505060749669, 30.501897834962417, 34.5672050599129, 56.98726900162236, 50.5616343405939, 78.36885406124976, 82.03779205199211, 69.87137640676191, 102.36978223246913, 104.32779019878757, 60.7611382392145, 77.05189474167364, 57.43797679101267, 0.9004693069765646, 0.30250722241978495, 0.27331216320876156, 0.20872522085424394, 0.13591518265105065, 0.1541903786241047, 0.18468625513055634, 0.4155610850261104, 0.24843059269891632, 0.19673258937414617, 2.1246089233506114, 6.84582886195952, 23.257470361648068, 12.744002303769513, 4.35176331189371, 4.64191819390943, 30.61696448633748, 56.01758064762239, 38.6696590915803, 43.84517946550923, 28.00975718805867, 22.148469225052867, 2.8271135111008925, 1.1696119294051202, 1.7092199936028452, 1.9842166309395146, 1.5702490700829415, 2.0603585387429884, 5.068446042076235, 16.499940426118915, 37.69631508857974, 51.353094116334, 51.81544742276592, 52.42319906911543, 55.81071484473444, 58.03194130620649, 59.23359863219723, 62.07109612803306, 63.800531894929954, 62.06213351218932, 64.22953328778668, 62.3186682885693, 68.66731859022572, 65.99193265361171, 65.53232892867058, 59.8120266391385, 67.32515411992227, 71.96360788037701, 65.30273691300424, 60.95107117006856, 58.28544409044328, 52.43832765087005, 54.31591526154549, 50.63782245882096, 52.23589020390665, 50.35988330841065, 49.35281084429834, 51.90930581861927, 51.385696857206284, 53.773412243012466, 54.474061304523104, 51.73912202158282, 57.510642620825, 54.08757840433429, 56.771111103796194, 56.22657629751391, 53.14251469027612, 53.0421490823069, 55.4790823690353, 56.037980894888605, 56.00768450767764, 52.46068908322243, 52.219122071419996, 54.785752450266195, 53.9051018991778, 52.12825644400812, 48.630243578264796, 53.457626142809474, 53.252760748709406, 49.544100915232015, 54.34027318031558, 50.85158378847184, 48.02110341287429, 48.37217515514743, 45.56071043014527, 49.169510641405665, 48.06929365281136, 44.81776252869637, 47.05788304728847, 49.11486810253513, 50.9689175698065, 49.6799208271888, 47.891339640463556, 51.677627102021255, 60.66280834136471, 62.21729070909562, 61.03650431479178, 59.28820586973622, 60.49555455484698, 62.7083832217801, 57.05740098030337, 60.840813344524754, 47.95102242500552, 49.39127360620807, 56.35338260281471, 47.97640800476075, 43.92174020890267, 36.582562000520774, 27.142440734371064, 12.33721721556879, 1.6576541864102887, 0.3069962218644158, 0.2647185259528699, 0.2416388248844493, 0.12124287520324993, 0.08165600183870524, 0.20035235481637143, 0.1889508061351315, 0.14018178677126286, 0.22398373112082484, 0.47882275655865675, 0.4924203882053976, 6.379517393727457, 11.758762732628854, 32.35994027506921, 31.01559300576487, 23.180782141224032, 18.29137513714452, 9.454234934622242, 11.31351194074077, 1.4064822706484026, 0.15789032282848514, 0.6503393933657677, 0.2593439288677708, 0.09580215243923088, 0.13578658713208092, 0.10085762793859167, 0.24701959663821807, 0.1952244993299246, 0.14060834452750223, 0.1856820162145361, 0.7097124945252173, 49.171205105320105, 73.44991945451306, 84.31082910107028, 65.37461434641193, 45.16126409653695, 44.53564605405254, 56.510677491464925, 68.88110345409763, 54.21340411709201, 51.60708719684232, 42.93771951429306, 42.532220963508856, 15.176917122256372, 0.39092360545069943, 0.17651787328143276, 0.1603796642514006, 0.17164900147866818], [2.5033355816718075, 4.369691485358823, 0.09388619718412239, 0.03247724800941444, 2.038356616131721, 1.0866724315189547, 4.30941250055067, 4.14650813225777, 18.437561873466738, 46.00387157932405, 61.621376775926166, 46.033756117666925, 81.42391758580362, 84.24092461985927, 42.75137947451684, 55.06964968096826, 46.30517628885085, 2.0889229543747443, 0.42221229102823044, 0.18129873690345596, 0.10530605536675262, 0.214854720979929, 0.019240598907814394, 0.1016002429288722, 0.05718347248471072, 0.1328522558774679, 0.08098759778564976, 4.658321545970056, 7.578121154539048, 5.789851305946227, 7.903755835948452, 0.5291893910015784, 3.7913115274521614, 7.825719791073953, 7.187920337723148, 26.21994241591423, 42.52844764340309, 32.217009105990016, 16.92408984707248, 7.723604315711607, 1.8547923886968245, 1.253921437648035, 1.2766887127391755, 1.072943890767713, 1.6764586418867113, 3.874390269479444, 10.439286231994629, 23.351560177341586, 32.9477172513162, 36.89568481137676, 34.727261297164425, 39.97374911462107, 44.1151483597294, 48.39549756819203, 49.70493770414784, 51.093366530633745, 53.715133666992195, 54.63243876734088, 58.03046257265153, 60.59502586241692, 60.42783483382195, 57.23340557467554, 56.3832789082681, 59.90785406481836, 63.22639888332736, 60.57706532939788, 56.20255570257864, 53.20109136642949, 45.25310639412173, 47.9169213387274, 44.612387226473906, 45.871970115169404, 47.019973339573035, 45.24119807827858, 42.43642491679038, 46.620570152036606, 45.54791565864317, 44.735494736702215, 52.428604095212876, 51.19907048440749, 44.776177560129476, 45.77836275100709, 43.223652455114554, 46.40899358257171, 48.79409274747295, 48.71760652911279, 49.28811527067616, 53.19131681996008, 47.99122671927176, 49.55296939419162, 49.53717400950771, 47.73819461945565, 46.33181702706122, 46.338100664077274, 41.75275187338553, 45.54123193986955, 42.99142852906258, 43.63947076182212, 46.59932267281317, 39.495196419377486, 39.12087678909302, 41.9889844617536, 42.95534664584745, 42.124149337891616, 41.31902010210099, 40.61570775124335, 42.25364638913063, 42.502199142209946, 44.07230038796702, 47.68933757658928, 44.404709492960286, 54.50968819279825, 56.220096541989236, 56.88154151362758, 51.67212793903967, 51.32977562565958, 52.5960147765375, 47.065810157406716, 48.676798189840014, 42.557218228617025, 44.57565815218034, 37.71410695968136, 33.14382791519165, 21.91688660652407, 12.485534779487118, 5.0971288642575665, 1.140276155164165, 0.42082122857532195, 0.07069696852516744, 0.05172271732120745, 0.02003264572140911, 0.04941144920585137, 0.02695982532215215, 0.004237998875924537, 0.024047340979919802, 0.05577950911115735, 0.044921457677358584, 0.1412167562352073, 0.31561222888769647, 7.178261010877549, 9.333891714772871, 33.77761625474499, 35.044228030789284, 32.46416157291782, 26.718932620940674, 16.47893221147599, 7.532693243795826, 8.309624560417669, 3.023224420124485, 0.19271448885481204, 0.3849815517183273, 0.06042201342361589, 0.06668629905869884, 0.029298695585420056, 0.030930476270676143, 0.03225604395171808, 0.030971322163578965, 0.07268539569791287, 0.7483665332678826, 20.579964383955925, 56.0242094532136, 66.2022501422513, 48.89472115424372, 17.44417259770055, 30.433527000488777, 59.32074193031558, 50.6323899761323, 13.249005502270116, 4.884020609240379, 2.6924578076408756, 0.6202416374318062, 0.16969379187831957, 0.19072298200861101, 0.03492194948898208, 0.03414641570059523, 0.03673224206713419, 2.030914409026023, 1.9083742941579513, 0.04941768516155501, 0.20818404102277374, 5.724460982507275, 7.01646569275087, 5.9881133898612, 12.405678264556393, 42.88148841550274, 64.30903973117952, 73.55075574690296, 54.211984219089636, 85.52578326194518, 87.10219167893933, 42.9854469145498, 65.37497912683796, 65.72529385166784, 3.453396885625778, 0.4296948250022627, 0.17985360396485175, 0.13631411527674045, 0.2215978422112042, 0.027701013473673698, 0.08553808344708336, 0.11305940142201801, 0.11337673036201347, 0.16036512390259774, 4.003100640350773, 10.634416303327008, 14.088657479132376, 6.5288410455949855, 1.7900258446893387, 3.462165834442262, 17.51648541419737, 23.064558390648138, 35.09379110028667, 44.07422234935146, 34.71689055042882, 20.821560813534646, 6.558945236667511, 1.3445365236651514, 1.6640899378445841, 2.3837670299314686, 2.063485158066596, 1.6312844594640117, 4.430905465156802, 12.24151530573445, 24.606355813241777, 37.273664013032, 42.67681129517094, 38.83947026345038, 44.802775152267955, 48.3211451192056, 51.297372925666075, 52.29696935222995, 54.13722776597547, 53.91196996934953, 56.53455688107399, 62.898712312021566, 64.28390910548549, 62.276475352625695, 59.8838177804024, 61.004274199085856, 63.09647429373957, 64.7085056766387, 61.67628211359824, 56.53215639052853, 53.124522778295706, 49.608015937189904, 50.85771445305117, 48.71415876573133, 49.080068834366344, 48.191589232414, 48.64770989264212, 45.99163378438642, 49.97747967320104, 47.58308841336159, 47.08241355034613, 55.22516773593042, 55.34625914789016, 48.9164863863299, 48.69470380967664, 46.225250151849565, 49.17169147922147, 50.306017398834236, 51.47865310792, 52.92799634318198, 53.986655819800596, 51.405912753074404, 52.59519500117148, 50.77204204374745, 48.82230243375225, 46.88525561363467, 47.396375748419, 43.14696227350543, 45.64448833465577, 45.52641322535854, 45.84035581158054, 45.773200911860314, 42.947050832933, 44.13816875027072, 44.4893071728368, 44.928016431870006, 45.57408571243287, 45.027468127589074, 44.48191742743216, 43.956013879468365, 46.74141445467549, 47.82305509813371, 53.823920603721376, 50.36486079615932, 58.71912487091557, 60.87109011988486, 61.305802483712476, 54.894700204172445, 53.138466804258286, 55.74985927151096, 50.962182860220636, 53.20281328693513, 45.84008124566848, 47.066045499617054, 40.44428448523245, 31.139047645753433, 20.437327392639656, 14.529077872153252, 6.0868580783567126, 1.6288365327542829, 0.2931848823303177, 0.0992154878293795, 0.07047882498872858, 0.16461122750995621, 0.06059113116334043, 0.0800382080037267, 0.020473368443368424, 0.03021767933762843, 0.05451626842841507, 0.10019074840050551, 0.28399268525742716, 0.2641643992354793, 6.313361717808632, 10.076719003338969, 35.5335319426752, 38.86268677250032, 33.70753526687622, 32.03894722846247, 19.435848228393063, 10.549264588663656, 9.728798885499279, 4.180519984614465, 0.2282116324791024, 0.09743494627576682, 0.11762189168122508, 0.023912852329592553, 0.04443514889346496, 0.01955360328147729, 0.04904058604170719, 0.05316652875814227, 0.07351609547772715, 1.3519914784739095, 32.28638210604268, 66.02807337237944, 71.8392687459146, 56.22274021948538, 26.725630068009902, 36.06559361180952, 65.5217699081667, 59.327374658276966, 11.088994491484858, 4.62534470904258, 1.4878289185224043, 1.201765313744545, 0.17901579488910016, 0.042649191098227617, 0.13474300683986756, 0.10629939561289166, 0.05811594321482605, 5.1774928358293355, 8.431694603735401, 0.5086093275777755, 0.35648706459229995, 10.848888562571618, 22.09881397985643, 23.183592519452496, 29.966808096055065, 58.0279444110009, 85.4598560640889, 88.66299690738802, 64.74987491484612, 84.9727447571293, 97.97438990685248, 54.59432509637649, 73.86124272500315, 80.87246371853738, 2.3753613906521953, 0.36020887294603937, 0.21474604374699055, 0.16223505259521548, 0.45807948576346524, 0.17868784797047416, 0.18464255747535538, 0.2068040868447673, 0.21943333738994217, 0.22871934959004003, 5.695801694546977, 11.90957002101406, 17.797183952023907, 19.97559185950987, 2.8943831401486553, 10.30862521740698, 34.211791253859, 20.744737271339666, 42.564847238602184, 52.15115524107411, 40.28057259898032, 25.30202542581866, 10.092782089787146, 4.054854353589397, 2.244215473051994, 2.704661036691358, 3.1500439634246216, 2.398197920091691, 5.721579511319438, 14.302205039608864, 25.694705670879735, 42.925744518156975, 50.102085528835175, 47.836332321167, 51.44366164361277, 52.25478818339687, 57.98956401886479, 58.06284566079417, 59.29300685082713, 61.06434922064505, 62.98659693810248, 65.02725316632178, 67.56586997739731, 66.24166996248307, 62.88425445556641, 62.5844245572244, 66.135161922824, 68.87326655849334, 66.35744264048915, 60.117787161181056, 58.0613826167199, 49.609384844380045, 53.48734201923494, 51.02200292771863, 52.4692084712367, 50.1088555397526, 52.167205579819225, 47.32067008172312, 52.72697879422096, 51.032393286305094, 49.48827382056944, 58.00115462272399, 57.31675201846708, 48.26871479711225, 53.04612244329145, 49.63965377499981, 53.049966366060325, 53.94636915576074, 54.40319584261987, 55.94640531847554, 59.12180715991605, 51.842680438872314, 56.4568272713692, 54.28391264330957, 52.283605837052875, 50.73394406226374, 50.16676933534684, 46.84123093082059, 50.47156887669718, 49.59195383133427, 48.23106004345802, 50.56977325870145, 45.073053913731734, 45.78447772610573, 48.028297039770315, 47.33302947013609, 49.38380149102981, 47.053878307342536, 48.95567478672151, 48.099625341353885, 49.96776003991404, 50.47093345272926, 55.689866619725386, 52.6127044616207, 61.397711461590184, 62.686210063196, 64.43867406537457, 57.60139057713171, 55.839783530081476, 58.60296387826243, 54.97134723970967, 57.534027791792354, 46.38513772718368, 52.18697040311752, 47.873994919561575, 38.70319535655361, 31.69980145269825, 28.110466003417972, 15.927155729263061, 2.9973875226513034, 0.8283447642480174, 0.24774722694869966, 0.13242185235984866, 0.31798428224940456, 0.1256051866878425, 0.1797005702410975, 0.2313644673314787, 0.08954441685590053, 0.16528259632327866, 0.17889835361030795, 0.37568446188684435, 0.662744072896819, 10.376640096787485, 16.82979214575983, 40.61151081515897, 48.81579522163638, 43.523517654788115, 33.59539862601988, 23.852886153805642, 12.599963065116638, 13.021955182475429, 8.230694705440152, 0.5324103923574571, 0.46409572745042466, 0.21488338799005557, 0.13616143395343136, 0.23143733761483626, 0.14087740992826803, 0.19830864673900991, 0.0979501863701209, 0.15986163559700214, 1.9097972565120267, 55.01800775527955, 76.04797978555003, 77.42388448407574, 68.41070928881246, 28.976766563230946, 43.84950191743913, 82.5968082489506, 73.10983427109258, 51.52555681044056, 12.662354246262582, 6.021111309528352, 1.691718255319903, 0.26499621750366303, 0.2857078029023063, 0.18856719526792728, 0.14739838098326039, 0.09015226165854162], [7.380928897088574, 20.414481547571, 6.773969569513875, 0.09905749751675515, 0.16897713194691366, 1.6929159265372062, 1.0286437840231004, 4.577787931888334, 7.22864140425959, 25.631175041198734, 60.75348177263814, 46.966189799770234, 85.80068649784212, 89.11549721994709, 36.92929952375351, 56.488692606649096, 55.074136872445386, 8.245348680403925, 0.8702837880099974, 0.21157984832121482, 0.0825776668986486, 0.09214648811687386, 0.03746316272525057, 0.06653261416020893, 0.08256249069686859, 0.04407977219671012, 0.05691081796201968, 5.025382339954376, 5.438698174492006, 4.469412844027243, 9.176486019165285, 4.739338592175515, 1.9458154012118618, 5.37240864769105, 11.919078826904299, 39.499922875435125, 59.53698219791536, 56.088771666249926, 37.02078880802278, 12.60198896931064, 5.997672696267405, 3.130819691765693, 0.8809852395807544, 1.8140981658812494, 4.303069537685764, 5.910240613645123, 15.426613246240924, 19.21569343536131, 22.79273617652155, 21.339399968424154, 24.09543768052132, 31.698369787585353, 40.45452579375237, 41.82732005273142, 47.465891914982954, 46.57541974898308, 48.520530962174945, 53.18967334685787, 56.60384162779778, 56.43584651331748, 58.08387740965813, 58.35669786699357, 59.692178618523386, 59.36800256852181, 61.26552366441297, 60.29135204130604, 57.84875877441899, 49.3986084384303, 47.97261115043394, 47.4243579372283, 45.85702196244271, 43.97591990809287, 46.531697088672274, 43.46833775120397, 43.884269806646536, 43.12112562118038, 43.22205605045442, 45.90813044578799, 48.94239364131805, 50.148883327361084, 50.88231948114211, 46.71295373670517, 41.42248830487652, 41.88218616670178, 44.972413739850445, 44.002882280657374, 43.456237239222375, 46.92061185836793, 50.06542313483454, 49.57793135796824, 44.36379132732269, 41.62860493506155, 41.53246371976791, 40.412827076450476, 41.70329078551262, 39.440020438163515, 45.17195647762668, 45.958862381596724, 43.54725976144114, 43.521011260248, 40.11815509488506, 40.165356897538715, 42.249853457174, 40.819510183026715, 40.29491278433031, 43.0207404013603, 40.040915781451815, 45.48878200592534, 44.39804930840769, 48.94961080243511, 48.86221255025556, 51.546129641994355, 55.89133524125623, 53.41395055094073, 54.40853418842439, 48.35008828870712, 51.029004358476215, 44.86267366716939, 46.752177438428326, 40.00917203964726, 32.64477691342754, 27.41240962859123, 14.794248727060134, 9.730868916357718, 4.763265050226643, 1.379608519134983, 0.8307498513210205, 0.2076281982684328, 0.07219219595314035, 0.06987405985954308, 0.013286001443292105, 0.049019863363355405, 0.013195308124376161, 0.05647083068446768, 0.03542263774321445, 0.04203240221907054, 0.010622097310730287, 0.07368517108261585, 1.2581492623975201, 13.538730394455696, 20.91753140572579, 35.9221133109062, 45.475438102599114, 43.74008740148237, 40.8152622561301, 18.819579155214374, 15.948786620170841, 12.427303271908915, 9.674356387507531, 0.8533539803278062, 0.1831706727464353, 0.27770328726018634, 0.058965894784177506, 0.03468784068020121, 0.17480654011089958, 0.12747717615697654, 0.06308428387367918, 0.2155140928563572, 2.4445088544199547, 17.366158616158273, 50.90850914678266, 64.79717085438391, 42.51713552782613, 17.26170982083967, 38.364039774863954, 57.086363761655754, 28.349467785127704, 7.079103983217671, 0.3559261963011757, 0.2989387848684865, 0.20748204401423856, 0.13423145928930852, 0.15925884697466128, 0.12195811787199591, 0.08915826257678772, 0.10226361378426514, 3.2035583305743436, 10.208620467493612, 0.3218783684555562, 0.12915949757781722, 0.3000250975451162, 2.319451435919731, 3.8435248934453536, 4.419026076793671, 16.52881887651259, 45.71504785168556, 73.11577273953345, 55.57872233852264, 88.50478418411748, 95.8641076857044, 38.00793563165973, 63.609802722930915, 78.28522128443565, 12.831676102453663, 0.875337332967789, 0.1959928089091855, 0.04374781480780052, 0.13453104563297766, 0.01612897575532477, 0.04929774260569004, 0.03704605083311758, 0.1530788156894907, 0.03818413573167017, 8.17026961234308, 11.701500050483212, 7.883749296588283, 12.856747892595108, 2.2765590923447765, 1.0383273805341413, 10.065102904073655, 14.623535410050424, 38.18139460779006, 62.945655238243845, 51.77160316897977, 33.32032672820553, 11.181921324422284, 5.815880154409717, 2.2566062404263407, 2.211701475804852, 4.034952737631337, 3.592911425136751, 6.577587281503986, 19.123072547297326, 22.584136686017438, 21.641887272557906, 24.53549231252363, 28.202031773905603, 34.81059597384545, 43.662295033854825, 44.0878604304406, 48.35449311041063, 50.012478982248616, 51.530063613768554, 58.77357913601784, 58.792908576227006, 61.720891229568, 61.64633481733261, 62.434695920636585, 61.31028967518961, 61.69767472051806, 61.959951846830315, 60.75132839141354, 60.557182834994414, 53.78536762729768, 50.90883078113679, 50.50158285325574, 49.70163506846274, 47.76219952491022, 49.78874698761971, 46.304780129463445, 48.12327331112277, 46.509555309049546, 45.394672578380955, 47.705093737571474, 51.038225850751324, 53.6649194840462, 55.44326720699188, 50.43294921998055, 45.09079871639129, 45.08112615154636, 46.091018799812566, 44.86580764093707, 46.063224884771536, 50.275964198573945, 52.40386178416591, 52.72763775240991, 46.62851687400572, 45.318049077064764, 40.940899695119555, 42.63807788971932, 45.19831872755482, 42.34449632706181, 48.905621420952585, 49.11524465007167, 47.66739191547517, 47.120115372442434, 43.400951431643584, 41.90175094912129, 45.932864912094615, 43.71644335408365, 42.83566336477957, 45.0891826998803, 41.212276720231586, 47.4899007428077, 48.027441963072754, 53.679228290434814, 53.775824500668435, 55.11768694846861, 60.95468759536744, 55.798747693338704, 54.32960433344687, 51.01523291680121, 52.60615802580311, 48.362643795628706, 50.16575736384238, 40.54976486390637, 35.737365753419944, 26.71613989337798, 15.553099878372686, 13.422557634692039, 6.689697446361666, 1.3278459805634715, 0.8803843814999828, 0.5895506842963157, 0.17418510490848174, 0.016346498760544968, 0.05229452917833002, 0.006908160989217821, 0.02535114218781312, 0.061278369488014336, 0.05243828174688163, 0.018650025557426196, 0.015866840577444002, 0.1307757439151887, 0.9421996483879705, 12.908369225840415, 23.778335625125518, 40.12701180673415, 53.20741422714726, 47.16964706297844, 45.2428807750825, 26.534124266716745, 19.86958392204777, 13.173025269662181, 10.404921366322426, 0.7396967468723175, 0.3004404397741441, 0.3441726302187289, 0.03301876875001096, 0.042627001361500834, 0.08094504160145599, 0.09481089595224589, 0.03212535701271507, 0.2407799024255045, 2.7227429180375995, 37.10833611026887, 63.34170087691277, 70.1066166354764, 50.5470548906634, 21.63888273700591, 43.338519065610825, 69.14085065164875, 35.934009859638834, 4.227352594175647, 0.7088717589935949, 0.37585934443819913, 0.21958234149121472, 0.07923146379330466, 0.21266625292839544, 0.13647825727539678, 0.01865837208536123, 0.07159998700503381, 9.846122860908508, 34.10965273457189, 12.56820853679411, 0.2866591921737117, 0.2351621796767558, 5.017941113441221, 12.210935527278531, 24.36409846428902, 33.18380863435807, 66.09126275585544, 87.62321579840876, 66.29012692359187, 89.1862803120767, 106.88133162836876, 47.79773619867141, 72.2848186185283, 102.04270362854005, 11.122540562383591, 0.8341599231766117, 0.19086719039947758, 0.06429959043499923, 0.17001288282054086, 0.1200021958098777, 0.2570534179047231, 0.16502166677626873, 0.22941140277731806, 0.2813121129668528, 9.035450335471861, 16.139785455119227, 7.858236730098725, 17.78082178485009, 18.280372888811176, 19.841266370588734, 36.46474576765491, 32.03549750389592, 61.891977171744074, 64.99163412278699, 64.34567859095912, 45.68450043278356, 18.935422435883556, 7.9217712821499005, 6.222201912633835, 3.4742222197594184, 5.092156769767885, 5.159376388595951, 7.319332486198795, 21.7336570062945, 25.311427347121704, 32.51421101631657, 40.39860848457583, 42.19919996876871, 50.86017770151938, 48.09750333909066, 51.65376732426306, 54.046813211133404, 57.63631536114601, 54.89305280870008, 63.52329877115066, 60.774454685949514, 64.18524580617105, 61.498865465964045, 63.9889782474887, 64.84396865290981, 65.5133407346664, 63.73471452343849, 62.75454167396792, 61.82371616363526, 54.66367652339321, 52.30949740256033, 53.576360210295654, 53.24406093166721, 50.307409840245406, 52.67651357958394, 51.51802193733954, 49.23288829864995, 49.16479595245854, 48.30540857007427, 52.01009112019693, 54.09359924254879, 58.5725772765375, 57.61511887273481, 53.63805909310618, 48.32047831627631, 48.32112942972491, 48.44729638868763, 48.0373106464263, 48.25371957594349, 52.389580434368504, 55.58263686395461, 58.31397933344687, 49.687934229450846, 48.13099253562189, 43.88335197202621, 45.74969022504745, 45.94774246215821, 44.09038643683157, 50.07231866159747, 53.60567600496354, 52.64400889796596, 51.66956270894697, 45.00095290522422, 44.77314949035645, 48.73111124961607, 47.11240007031349, 45.92920534072384, 49.635307788848884, 44.02815803404778, 52.570244804505386, 49.51735035065682, 56.11924848248882, 55.68449297258931, 58.75845447663338, 61.4447485246966, 58.615036933652824, 60.44585028002339, 57.04868155141031, 55.98511518970613, 52.42159481971495, 55.917164048840924, 46.54422121663248, 43.432895214326926, 37.295511614891794, 27.73638563771402, 25.626693733276863, 15.162603412905048, 3.297991108509802, 1.203480615250526, 0.9692531547719433, 0.2560630041144548, 0.16670460872832807, 0.2009858788862344, 0.12443053641266401, 0.15706794276352853, 0.1173881582555271, 0.1344761784158407, 0.1274060985193618, 0.23769460588453278, 0.4403809548145341, 1.9717962006407401, 17.26552628701733, 28.491339914260376, 43.14476182383876, 58.67118174029935, 50.62217220183342, 50.03176135401572, 31.137280617990804, 27.781804723124353, 17.844336725050404, 15.87117958453394, 2.857064239440426, 0.902292657523386, 0.47356028410215534, 0.14583418265946452, 0.20569655353263502, 0.2552654452982449, 0.20050362653789983, 0.2267343544911954, 0.5648125407676543, 5.132585619726489, 59.18095257974441, 75.69655895233154, 79.9509185360324, 62.88813367966683, 28.246887999196208, 49.7985529130505, 82.68264539780156, 66.77115071204402, 22.51709553503221, 1.393526436821107, 0.6685471582797267, 0.3131491336370668, 0.3948417161741565, 0.37063536023901356, 0.2570547355759529, 0.17480189761807843, 0.2346502797257516], [5.548278900884814, 30.971899763230358, 24.70272844837558, 6.871204635789318, 0.2599881781685737, 0.23821462636753438, 0.5684984655630204, 1.9623587328580119, 8.045651499302156, 7.4703050044275106, 45.25102361556023, 45.03434012013097, 81.01086062769737, 77.11337397175451, 35.50865627104236, 60.36257443889495, 64.13316457502305, 23.515266180038456, 0.6500487089637788, 0.12987416568062, 0.049046316379380804, 0.10560344303807906, 0.03379486561302216, 0.15388564416958442, 0.07464471152953564, 0.03875249636269385, 0.31977591675616085, 1.9428281486034396, 3.9338024104795153, 2.7650557314195945, 7.383571593992173, 21.604936584349602, 18.530157266124604, 27.066505609020112, 26.37080853985202, 53.96503571541079, 65.16758772634691, 58.685761190229854, 47.244356447650546, 20.0696797140183, 10.50579688241405, 10.166251024892254, 4.719907660638133, 8.512364029884338, 11.674100333644498, 16.482021077986687, 18.540249524577973, 15.13740904869572, 8.401698277842614, 7.374980132425986, 13.67420219605969, 15.16514510877671, 37.02006709191107, 41.08727862758022, 36.19078390059933, 41.400989793962054, 51.72010637098744, 52.347289439170595, 50.80719432523174, 55.06032228469849, 62.19495281096428, 59.09031052743236, 55.74123790187221, 56.78817341404577, 55.84188592049384, 60.86779532894012, 55.355790507408884, 56.749522378367764, 49.515789247328236, 48.86653892455563, 43.32745405935472, 46.43321814075593, 44.33606801494476, 44.557258313702, 42.79187402417583, 42.5530840504554, 46.07661193416965, 47.305576801300056, 49.12863954421013, 47.010932276325846, 47.43108480207382, 46.36679280188776, 45.714369281645745, 45.25843297281573, 46.4604825358237, 45.50243185412499, 47.76587870813186, 48.85477181403868, 47.25057340437367, 48.951258197907485, 45.35859069516582, 45.230705738067634, 43.416946857206284, 42.11745777437764, 42.24104381376698, 43.894271850585945, 43.51928541737218, 42.886716934942434, 43.16413048774966, 44.88687076876241, 40.14499587397422, 41.58232881176857, 41.19597142742526, 41.27798818772839, 41.24890773527084, 42.584349263098936, 40.481397951802904, 43.537638187408454, 46.335962972333355, 52.439335700004335, 49.98628147186772, 51.808626421036266, 53.83251059439875, 52.30812849537019, 48.79947423934937, 46.38855803397394, 48.15019253761538, 40.88867333627517, 43.70907714290004, 30.944505929946903, 21.02608496142972, 9.663563985978405, 7.803079380143074, 7.131147951849046, 2.069794535636902, 0.8980984180685013, 0.29536789583583034, 0.6271692173134896, 0.13198257754406623, 0.07124326582397185, 0.07273761225083182, 0.09504184847877872, 0.09006471313055485, 0.09739064341110569, 0.03342572997714723, 0.011805791253854912, 0.04506180881552639, 0.19220933047754152, 1.5760301534206638, 21.5621768659161, 24.857458106933105, 44.416084366460005, 63.10037312969085, 58.79661913841002, 58.1942529063071, 41.48634449128182, 42.68556602539555, 27.482300381506644, 21.15240881519933, 3.7879429469185495, 1.989109665155411, 0.8186050288138852, 0.24085340090096, 0.06856527524970232, 0.16722208579942105, 0.029667095776887673, 0.047657149994084914, 0.1313824242641849, 4.648487673651788, 19.302744557780606, 54.53852153593495, 55.27858257293702, 40.65139739744125, 19.72755293692312, 32.150015023446855, 45.36357210528466, 9.458814301798421, 1.4746308783369682, 0.03692306690819321, 0.13813551996023427, 0.09016126319165192, 0.3543672686622989, 0.713466018919022, 0.07278930786396227, 0.0027669345792908705, 0.02870831375701293, 7.2481360743122725, 29.82942511958461, 16.136653442536634, 0.5080566104621657, 0.07246932059886955, 0.11135860196044368, 0.1992452964787522, 3.1721080310883063, 8.006514089722788, 27.261064975492417, 62.73407474640877, 54.81176953161917, 79.06716931250789, 85.88162852871804, 39.62017097780782, 63.30644269143382, 89.30659509474232, 37.32090503938737, 0.4572356245931118, 0.10897679629945949, 0.05820549889317444, 0.10616290938830185, 0.07552251805581393, 0.13224418124844953, 0.040416044798950036, 0.04974673141635234, 0.5602585464235276, 4.6321681622535955, 6.057465307174191, 5.376388872823408, 11.103376842314198, 18.335927378746774, 12.335853211341366, 22.658436183006536, 32.14522973183663, 57.4640997763603, 69.94802736466931, 61.309061973325676, 54.22052321895477, 24.841021414726015, 11.830293036276295, 6.10616986790011, 5.569310649748772, 8.792602669808174, 10.540977601082096, 17.858384693822554, 23.454418451555316, 19.310577531014722, 9.406876237161699, 8.577499889558363, 18.234287000471546, 26.004949462029245, 41.6997096615453, 42.4871450854886, 40.338003943043375, 47.35649308850689, 54.68957985601118, 53.042121625715694, 51.99218550036031, 56.43213595113447, 63.81636650331559, 60.97987705661405, 58.93001110323014, 58.812037975557395, 58.2033214261455, 61.79998974646292, 57.19234228134156, 59.03687215620472, 52.573402312494096, 49.69295486327141, 47.00642939536802, 48.493042992007354, 47.716947140232215, 47.29979915003623, 45.1284142463438, 44.280739061294064, 49.463245176499896, 50.12974608329035, 52.43939453555692, 49.11522896059098, 49.333497093569854, 48.63022396641393, 50.30260885915449, 48.923876131734545, 48.803251481825306, 48.38447963037799, 50.42182537817186, 51.93291848705661, 50.69866234256376, 51.89025486669233, 48.87038676969467, 46.873712078217544, 44.07459497451783, 44.38482699855682, 45.660558285251746, 46.55822015577748, 44.43691607444517, 45.099898615191066, 45.48174919620637, 47.576942059301565, 42.07602970061764, 44.92207011868877, 43.648817769942745, 43.36050395042666, 45.41637897491456, 45.104377961927845, 44.4487577099954, 45.555980051717455, 49.069870671918316, 54.0205882441613, 56.16674054053522, 54.97725432918918, 56.62990969996299, 54.49253566803471, 53.65921243544548, 53.64065177979008, 52.54365113473708, 47.430967130968654, 46.15572614054526, 31.900475794269195, 21.21798692211028, 12.0595791070692, 14.400999738324074, 8.169913166953672, 2.2143022523772333, 0.9303407298941767, 0.9933238825009716, 0.5566892508537539, 0.24394781388823064, 0.06628993282755537, 0.015518816409542438, 0.057448017966723254, 0.08888833915754672, 0.11267783600957164, 0.04455438281799998, 0.04530329122057846, 0.16413017025878354, 0.321445191699651, 1.993286376518588, 23.88024860812772, 28.71963950895494, 50.4794567631137, 67.38668041844522, 64.76490935971661, 63.91530044617192, 45.912307770021506, 44.544341948724565, 27.411228995169363, 21.99469662481739, 3.9371773648646573, 2.112077686094469, 0.4744248909334983, 0.2215901966537199, 0.016836339209769523, 0.026880435630558964, 0.14728811028743946, 0.1295192677888178, 0.23329867080094355, 3.6493950265069164, 39.961460328871205, 64.32489002904585, 64.76145767396497, 48.449198738221206, 21.681985662829494, 35.84186553955078, 57.33632464562693, 14.866608611999022, 2.023876696344345, 0.05701188028099076, 0.061044011700658075, 0.15572327459531446, 0.6986827283136307, 0.6359639679712634, 0.01717177272263554, 0.05904565985885359, 0.040707376545235034, 8.980485181654654, 51.28507237280569, 57.200802833803245, 9.44393479054974, 0.4071464365528476, 0.24513581707592935, 0.5767353203508162, 8.48830323065481, 26.53540688176309, 46.79968126358525, 72.93369631613456, 66.6825443698514, 86.90134279189571, 96.16548692026447, 50.496977990673436, 75.52006013931768, 108.0120881911247, 43.60398507887318, 1.0749682014988315, 0.20315367788557084, 0.25037207400366185, 0.2762316936446775, 0.21020672764749299, 0.284306995811001, 0.17229167263834708, 0.0943640751704093, 0.7541318658378817, 7.62867070013477, 11.05013753137281, 10.596439915318644, 16.239099867882267, 35.74049580481745, 32.69341822593443, 50.37482753876717, 55.009170655281316, 67.66982063170403, 69.92759181607154, 69.8220173005135, 61.89990428186233, 42.176320783553585, 11.952980852896168, 12.850487789800091, 11.462803233054377, 12.745649699241886, 13.762549661820936, 19.94801171364323, 24.990601001247285, 25.203148357329834, 22.003580793257683, 26.172799448813162, 35.08897835208524, 42.90928625291394, 50.84248388967207, 53.418645628037, 45.0439852283847, 50.60128558066584, 60.51064391289989, 58.77344969780215, 54.29150635196317, 60.695795474513886, 65.82676164565548, 64.69492643110215, 61.855228485599646, 62.18436241149903, 60.67962354229343, 64.98515436726233, 59.91011335003761, 61.363206371184326, 54.588782787323005, 52.49049517416185, 50.062379375580825, 50.60763197560465, 50.488438990808305, 49.83119487762452, 48.75979162031605, 47.74835748057212, 51.98212069849814, 53.008761867400146, 55.27439740396316, 53.00217620788082, 54.159769627355764, 52.1472877840842, 52.45428777510121, 51.073738990291474, 51.81265077283306, 51.346437854151574, 52.56180778626473, 55.42798565280054, 55.16954852688698, 55.119722658588046, 50.05042791366578, 49.43407450952838, 48.71287615068498, 46.69137677838726, 49.01587924649639, 48.926676704037575, 48.60850580276982, 47.75469603077058, 50.965395281391764, 50.78220490486392, 44.22897161975984, 48.636201658556544, 47.75542559162263, 48.186541142002234, 48.638700208356305, 49.49522033814461, 47.49082642216837, 49.064649997218964, 52.93391127740183, 57.159586568032545, 57.68914184262676, 58.75364172843195, 59.89609087667158, 57.99218808451007, 57.37574446585871, 54.35352686912783, 57.32008603311355, 50.819381129357126, 52.3348202243928, 40.2501703077747, 31.173919477770408, 25.230832446006037, 22.229579917846188, 17.82739600827617, 4.118190580798734, 1.7793475596174118, 1.5457289858210472, 1.0228774708605584, 0.40200083847007445, 0.19763655780303865, 0.14593192015684422, 0.267313081891306, 0.1882070726564815, 0.2549222991952012, 0.10028703033082909, 0.12801189786724507, 0.4054434537406891, 0.8982557418846315, 4.399233306607893, 27.031329793314782, 34.9296320638349, 58.11616636091664, 70.670120023912, 69.67208862304688, 67.53007442720475, 55.38853445360738, 50.72431856586088, 34.496367054600874, 24.837601107935754, 11.509848140901136, 3.112430394657197, 0.8259569601185861, 0.36121398030269536, 0.15047289100625824, 0.22552500809392623, 0.23807368151122527, 0.194571930314264, 0.5158667542761373, 9.60434502170932, 63.37691983868999, 73.49472861136161, 75.68082240320022, 57.09008216857911, 35.36761568438622, 42.686483860015876, 77.57127146567069, 47.69239310295352, 3.2558910837096557, 0.6945578657811688, 0.1383613013932782, 0.2760451972003906, 1.0048718305845414, 0.7124017695746114, 0.17507794974071367, 0.1332115817574724, 0.17416248999295697], [4.931017958348797, 27.154231379109046, 16.560472403803182, 17.070180485325476, 1.9165903113542067, 0.12336682332980058, 0.21145174309851664, 0.7336545807700003, 2.6553421347371997, 7.938755144996028, 20.066996812820435, 43.10707569122315, 85.35405405106084, 83.07006574446156, 36.393370397629276, 60.15777572508782, 75.66088891798451, 43.98615337187245, 0.929967737005603, 0.10752548869218558, 0.047086008463896094, 0.026956301317700458, 0.1091273325765806, 0.05327868403025693, 0.16051697785094862, 0.1076110224089315, 0.06572854359664264, 4.301292703997705, 3.082413721469141, 8.112426419411937, 26.66351149159093, 50.45380838455693, 39.37822349609868, 48.88286775158298, 51.355671113537205, 59.215022287061146, 59.923139541379875, 54.48548716883506, 54.46642052742743, 30.92377228121604, 5.08551815825124, 13.77461487247098, 2.0248878098303273, 9.199848636504143, 15.521436545156664, 22.523032042288012, 18.776770407153716, 13.349450538235327, 5.356703967817369, 5.836404936928903, 12.819061759979496, 18.00983132854585, 26.948116710109097, 36.69558117466588, 44.5718809097044, 46.69715442965108, 45.44760104148619, 48.189659426289225, 49.47322760858844, 48.36775072159306, 52.72876739501954, 56.425134520376886, 57.399839585827245, 55.06131856672226, 56.6637989782518, 57.66518400561426, 57.4646096844827, 59.60072855795584, 54.200523053446126, 49.023982863272394, 44.73429841379966, 42.270665553308305, 44.85847673108501, 41.982920477467204, 42.5298204729634, 43.923187563496256, 46.49310488854685, 47.40079233723302, 46.96208307819982, 47.30711829277777, 44.67136006201468, 43.320456550967315, 42.963324746777936, 42.80206434188351, 45.10590376392488, 44.91864588952834, 45.443713972645426, 45.949036844315074, 41.3407382657451, 47.17284771703905, 44.73534568663567, 42.93083575464065, 43.11522245407105, 43.32941524444088, 42.74784149662141, 41.93114126882246, 39.4795383176496, 43.77635363609561, 43.34305332553002, 45.56322466942572, 43.88057493394421, 40.24605181909377, 44.01058973804597, 39.51903266291465, 41.42214705867153, 41.33117160489483, 41.339251687449796, 40.41813796566379, 47.13572248335808, 52.621914186785304, 53.28484181434878, 50.50721537682318, 47.71461725234986, 55.03462291532948, 52.28238597992928, 47.611227496977776, 45.12551169241629, 40.36812382359659, 30.140068992491695, 18.10348576115024, 8.558818621020164, 6.652231947068246, 10.069542046516172, 3.2371296517310606, 1.2146716276484153, 0.22962005448437509, 0.15968542005265915, 0.5737301106414487, 0.20303614467622774, 0.09754677213007405, 0.083111722112423, 0.04527999831724071, 0.0393430620522028, 0.007806643749767495, 0.004142632420670482, 0.07901916550772806, 0.03185808234247229, 0.16037857640654812, 2.550785229090722, 21.22899897636906, 32.75922383031538, 55.15421205951322, 56.55305477880663, 48.742831291690955, 48.222928970090805, 50.128718422305205, 46.41685009002686, 40.246444056111, 32.56315435132673, 20.3000150188323, 7.675160592602146, 4.8297521664250285, 0.8482440512987875, 0.16626124300303, 0.033331704175760674, 0.057481771800667054, 0.07728995184504217, 0.2640910386558502, 6.168451712977502, 24.956988250055623, 58.258901411487216, 50.78810414960308, 38.81483385639806, 23.420682145703225, 28.053797560353434, 35.47467677823959, 5.167021578358066, 0.4722611522001605, 0.08627621682300683, 0.18637325734861437, 0.06239542910348504, 5.919090951642683, 12.150356481152198, 0.6712694670404158, 0.10623825413565482, 0.18094098916457546, 6.148933508703786, 47.03620802971625, 37.97208909065493, 22.582434377362652, 0.6775650550280848, 0.028167019012354078, 0.4203892469165787, 2.3157222424784014, 8.075507110165011, 21.320982479280044, 42.846865653991706, 58.16692183094641, 91.77934354351413, 91.56406817897674, 43.169845381090724, 67.41772990072927, 85.77197474818077, 64.73963752869638, 1.1702906220189988, 0.14269139888065477, 0.025096295378921975, 0.027806624439695192, 0.08244625983699676, 0.005081059484397092, 0.0843878713766894, 0.045551695230026404, 0.3423949078686776, 7.061607270471512, 5.606018151006391, 6.301670603213772, 25.937127759379727, 49.075114880838704, 39.62382270443825, 49.984006497167776, 55.304764393837225, 65.0375807669855, 71.39565652416599, 60.25912192560012, 61.80555166736726, 36.93665789019677, 13.579491665286403, 15.650641379817841, 9.005584428387305, 12.69411171636274, 20.145644257145545, 28.932129990669992, 24.303952840066728, 14.855096455543274, 6.417469266922244, 8.833154093834663, 9.897105828408273, 25.08874458651389, 36.69601263538484, 43.54422384692777, 52.2802443658152, 53.26264904391382, 48.24559634731662, 53.25391000316989, 52.12100790392969, 49.164360569369414, 50.11524900313347, 57.10191203701881, 60.82132700950869, 58.9418331269295, 60.061434468915394, 58.986328494164255, 60.299349754087395, 62.354310866325136, 54.593670060557706, 50.868642176351244, 48.181351846264256, 46.86822860471664, 45.807392212652395, 44.640063470409764, 47.05742805234848, 44.51439857482911, 48.036463414469075, 48.72208587584957, 48.63225575416319, 50.03891183483986, 44.2511369336036, 46.664410483452585, 45.64889707872945, 45.826113685484856, 46.264826866888235, 46.88647939312843, 47.25325238320136, 48.88296581083729, 44.243531457839474, 47.53196816290579, 46.07356033017559, 43.883881491999475, 45.645798406293316, 46.84826766290973, 47.44643303655809, 44.5308489953318, 42.923673506705995, 46.02669977372693, 45.00496156754033, 46.61253321555353, 44.66176594457319, 43.567177557176166, 45.12549992530577, 43.000638254227184, 43.447647248545, 44.37790793757285, 45.1060567363616, 44.64667266415012, 47.62444588445848, 53.87395435763944, 56.05534915001162, 53.335322718466486, 51.18415763301235, 59.67978392877887, 56.11775798182334, 48.649235694639145, 46.79355059900592, 41.211586383081254, 32.44825832305416, 18.684841817425145, 11.738982219849865, 13.316643834114076, 11.38255742288405, 3.9783191056020804, 1.1408643881159446, 0.6944758637297539, 1.1965980813387902, 0.6291086455025982, 0.4067409615362845, 0.08882157459494569, 0.0756367877305996, 0.13558084655913616, 0.030971211080829945, 0.05390424461614701, 0.03794400547180445, 0.0032163600600700107, 0.033225984042209965, 0.03962342341941211, 3.9719239261842545, 29.09639100874624, 41.14324300519882, 62.810051056646536, 65.97643929143106, 60.433404599466634, 57.294618083584695, 56.60207263885006, 51.25133214458343, 43.90079082981233, 35.95708516336257, 21.32028429738937, 7.661465637145504, 4.030175290761456, 0.959148332476616, 0.3382164804685501, 0.14379684843363302, 0.10271706888752599, 0.06150382150325084, 0.36757309230104573, 10.791441529027878, 50.35587464609454, 65.35535550886586, 63.447424442537375, 44.97780307646721, 24.13588712292333, 33.19909803328976, 48.907723811364946, 14.177643310639167, 0.6949664664364631, 0.09340814299761288, 0.19042423836165862, 1.1408855934296886, 17.215780827306933, 23.0930563711351, 1.0918640561642186, 0.05049522613145171, 0.08596515448223199, 7.5784771096321855, 61.9898638417644, 52.50008929160334, 44.12468756398847, 2.4572697954793132, 0.2606884438184, 0.34415736974727723, 2.946413870780699, 15.636839539774003, 49.574569886730565, 50.63936002792851, 63.709874153137214, 95.31533671963601, 100.74058655769595, 53.907196444849816, 77.660827021445, 101.48034557219475, 78.53616668332008, 1.5029204829085259, 0.29162874325148525, 0.15109507697484187, 0.12104622043308713, 0.20311652262124325, 0.19795684384242182, 0.24979275831532097, 0.24575645554690595, 1.6693199281730962, 11.494571489672508, 8.455266087285935, 13.474801644202202, 38.90896681816348, 56.39694444594845, 54.404392165522424, 58.7038903851663, 69.51764921988212, 64.86873449817782, 70.74335851976949, 64.29083208883962, 71.19258757560485, 57.23505689251808, 29.420465077123335, 18.133984150425082, 15.665132576419463, 17.297801509980236, 24.601578366371896, 33.37267468052526, 30.202834759989095, 23.497843011733025, 18.158328340899562, 16.73070719165187, 24.6755934915235, 42.725264333909564, 48.519518990670484, 49.72620479522213, 55.871488048184304, 55.63509072026899, 54.29774684290732, 56.72217953589655, 55.379501235100534, 55.370264053344734, 59.09642158016082, 59.66177240494759, 61.96731413564375, 58.42886947816419, 61.72168747071297, 60.22618578326318, 64.56624523285898, 66.20621173612534, 59.49565218340967, 53.86006524485927, 51.313988085716005, 48.78052526904691, 49.89339974618728, 46.386059484174176, 50.07558207358084, 47.22070847788165, 50.349720447294175, 50.875420032009, 52.512056442999075, 51.66089819323633, 47.95779243592293, 50.95732696594731, 51.15698737482871, 49.60982414983934, 50.70555394695651, 50.79479571311705, 51.84627332995015, 50.52531711516842, 47.81222543408794, 51.566008214027654, 52.086051740954005, 48.122390777834006, 50.34767297006423, 51.29693362020677, 50.73695644255608, 48.201175505115145, 45.178522525295136, 47.7886833683137, 49.14831807536464, 50.256548466220984, 49.74344361212946, 46.57580806363014, 48.35268489776119, 45.11697661492133, 48.82371056464411, 48.51725578308106, 48.45131681811426, 47.113753288022934, 51.87108624366022, 58.028579834968816, 59.694226095753336, 56.931900824269945, 52.367952485238355, 61.54535731961651, 61.60892717299923, 55.49048862149639, 55.22320655084426, 52.093108084894, 44.462097690951445, 29.496013849012314, 22.903105789615264, 20.885803353401926, 19.39574983812148, 6.080539140009112, 1.7736414916092351, 1.5831351592656107, 1.40163422111542, 1.035274305651265, 0.7516722945917038, 0.21086450606103868, 0.17917745476288183, 0.32141228056242394, 0.1928430384085063, 0.07211075314591009, 0.19279212420505865, 0.14115557645357427, 0.18112789929634143, 0.6398639070891565, 8.370628203115157, 31.06336355209351, 49.011752913075114, 66.84786442787417, 65.6031826234633, 67.31068841872677, 65.07000700120004, 64.86663603013562, 61.0186771423586, 51.17871730558334, 40.23845026569982, 29.314019795387026, 13.603376938450722, 8.105453916134374, 1.9651753623639385, 0.45243933196029357, 0.18013370103172718, 0.1737050588933691, 0.2698592517164446, 0.34822894320372616, 20.106240126394457, 68.9868034855012, 71.89791602473106, 75.33298661631923, 54.453825796804125, 35.40402312432566, 39.42330721885928, 69.64406721053585, 28.119346249488096, 0.5007580601640287, 0.1326014233693, 0.2541411040170539, 0.6135609830098768, 10.191684653682094, 18.72362033013375, 1.1266732528325052, 0.24385133277504678, 0.34261483638998], [0.6298424351599909, 11.615017671738903, 4.602816085661612, 8.130208974884402, 3.940770010794363, 1.399583802107842, 1.0682125317473565, 1.9196475537553912, 2.7109895358162546, 9.306341967275067, 25.34545194718146, 43.3720592529543, 72.01393188968783, 65.43493647729197, 32.803742731771166, 57.164077681879846, 77.345382167447, 55.84888342888125, 5.843213190955501, 0.48500009121433385, 0.20687252913992252, 0.26277281584278234, 0.2005325999831961, 0.016706663506826567, 0.07361268384322044, 0.11285493255502756, 1.0885093265002774, 3.0974638558203176, 12.207930991726538, 14.399171913823775, 27.08175970662025, 40.501170619841545, 39.47331351618613, 56.922738167547415, 66.60248879463443, 57.79666185379029, 59.13801439346806, 55.58211911109186, 60.989192685773304, 48.29553596435055, 7.505133200076319, 17.852116746287194, 3.0934640188370985, 7.307836019223736, 16.203269996950706, 20.23502330626211, 17.213860827107585, 10.1488955174723, 4.245829409168613, 8.779841238452542, 5.166277798914141, 12.752338320978227, 31.166010018317934, 47.82583998095605, 53.53078226889334, 50.7907086033975, 45.69424360029159, 46.27950437607304, 46.31302102919548, 40.56146529413039, 36.4539945510126, 51.042556147421564, 55.48322439193726, 55.04098892211915, 58.72739714960898, 58.634970418868534, 56.363827874583585, 61.572888435855994, 53.751450892417665, 50.16228214386971, 42.393894657011955, 44.54181986470377, 43.85991188787645, 44.187637682883974, 42.65150808518933, 45.93441032594251, 47.01267773105253, 48.6946802754556, 49.45457673841908, 47.17653474500103, 44.431044286297215, 44.302802393513346, 42.20991588407948, 42.007756925398304, 42.16067444893622, 44.36013175595192, 46.79827313269339, 45.41368430660617, 42.92587003400249, 42.20738203294816, 41.52590159446963, 44.71663598091372, 42.195234452524495, 40.834736824035645, 40.40155810694541, 44.24636733147406, 41.54430143294796, 43.369074329253166, 42.48054373648859, 41.52077505665441, 43.70676294449837, 43.93138139478622, 42.045192026322894, 40.578578595192205, 40.39290143597511, 41.61670446395874, 40.24787179885372, 41.27643492914016, 45.80510547084194, 50.832517147064216, 54.18635153001355, 50.23414388779671, 48.98988569936445, 57.211389310898326, 42.92790574412192, 35.36544661368094, 31.255991151255948, 23.047990299040272, 18.21110971512333, 6.503933995000779, 5.733649624932197, 6.710922862252882, 4.295850905679888, 2.24417110123942, 1.7964408811061614, 0.7834006533507378, 0.5370008524867796, 0.6875974360492922, 0.6208298703835857, 0.10572740372510687, 0.045749614045264266, 0.08810123744150324, 0.09010689393166574, 0.11794390907931714, 0.09708561784317417, 0.10859043517660712, 0.17552729095182112, 0.8677731033775115, 2.8341826027439487, 29.425642605750795, 55.020651432775686, 61.184303145254816, 50.609918717415106, 53.62216957153813, 59.34049106413319, 60.0682201693135, 55.91224931901502, 63.712686492550766, 34.15565821432298, 36.06212623657719, 27.19651256838153, 19.471171132979855, 8.30051681687755, 2.8221605381658, 0.7283044678549613, 0.9028521468562465, 0.37825756736340066, 1.1622702330350876, 7.151783051029329, 35.64705318020236, 60.09384109127907, 47.63475387327133, 31.021135314818356, 26.916186655721358, 22.224480836622178, 23.551177440151093, 9.164713025093079, 2.394399594876074, 0.048973733378994855, 0.0931525913878314, 28.36850500875904, 82.33099706711309, 69.59874030082457, 17.38317385796578, 0.1590835813793444, 0.13432867584689973, 1.800232832470248, 42.005309366410785, 28.24723905132663, 18.460101773661954, 8.574194312095642, 0.47616418631326773, 1.9041494111860953, 1.2337239278901009, 6.03573831819719, 18.90647142164169, 51.940629866815385, 44.359723829454, 78.47070232514413, 72.79552690444454, 38.263258395656464, 72.50491849837765, 81.79301261901855, 79.39363602669009, 10.919529468782487, 0.35847708522792787, 0.1919850046115537, 0.13930242508649826, 0.17315146843752555, 0.10468832036900906, 0.07608514068828476, 0.14886217582370007, 1.575367640583746, 4.202294532329806, 12.001225025423112, 17.6754218147647, 34.02629844604, 49.9095481441867, 46.41905053969353, 68.99899421199676, 71.05558703022619, 68.84404490070959, 66.56866227426838, 63.604993897099654, 70.50146595124276, 52.29793425529234, 20.28069930691873, 20.83228849595593, 7.5872293883754365, 12.15643713551183, 27.794421026783606, 32.45109419668875, 22.510988404673917, 10.88356819845015, 7.246028290640924, 11.954603733554965, 13.064996330968796, 24.11464160488498, 43.40532879675589, 56.532070098384736, 59.45899763414937, 55.32094417079803, 52.0049802718624, 50.13844982270272, 48.210377385539395, 46.17869161790418, 40.46699500853016, 52.75206627384309, 53.82390883661086, 53.19914587082402, 59.2120961989126, 62.1651820213564, 57.42226769847255, 61.12724442635814, 54.87629252095377, 52.809179905922186, 46.2329379973873, 48.65953583871165, 47.013697547297326, 47.12468885606336, 45.04223192891767, 49.21948163740097, 51.11039353955177, 50.62432166068785, 52.38965495940178, 49.57568776222968, 44.5444792316806, 48.13579743908298, 46.039463166267645, 46.48576221158428, 46.62054661781558, 47.620260715484626, 46.947891942916385, 48.07775812764322, 45.828537710251354, 44.18147171697309, 46.30198740190076, 46.92788001029722, 44.634568229798354, 44.66593934643654, 43.366897413807536, 45.84436055152647, 43.17502683208835, 45.41262134428948, 44.65826719037948, 46.75976722471176, 46.21879000817576, 46.030120080517186, 44.14118897530341, 43.63110826861474, 42.108091154406154, 44.411095111600815, 43.646605553165564, 43.163569588815015, 49.13133421251851, 55.484436404320505, 56.78798121790732, 53.38500345906904, 51.27456434311406, 58.393579913723855, 44.5585762300799, 38.422977309073175, 33.25246972422446, 25.06281183611962, 18.112483678325532, 10.875741108771294, 13.991473893965445, 12.703910777645728, 5.839950269268406, 4.352511504004079, 2.3902715454178476, 0.23224108642147434, 0.7249385226638086, 0.8118561619231779, 0.4883315930924108, 0.06909110267916996, 0.08446141581742034, 0.05925276023786395, 0.12873102460176716, 0.07088140419293797, 0.12191624350605473, 0.07756575115866239, 0.0849690486586863, 1.331076910418849, 6.997330409865226, 39.27361780597318, 63.83070276629541, 67.00849333117085, 58.92651627140661, 63.18318613113896, 65.37036249714514, 69.0640349541941, 62.154544553449085, 71.92815749875962, 39.24700060198384, 43.40311265760853, 30.228885181488533, 24.03986946229012, 13.371551132971241, 3.676647899612304, 0.6197590020395095, 1.279655372904193, 0.352026931340656, 1.0966352517566373, 30.890755730290568, 56.1894275296119, 66.61886861247402, 62.28137047060075, 39.14212426831646, 29.674891579535704, 32.69369475303158, 39.35084535229591, 15.492545347059927, 3.9195722966424884, 0.25101728857524935, 0.20722499087212548, 49.21696347575034, 104.17200934502387, 85.76849168346774, 22.68061914751607, 0.3700298137001453, 0.1746652275323868, 0.8995615847168431, 56.136091140008745, 40.69179388784593, 28.814784442224813, 11.682382418263344, 2.1446338488209635, 3.501305940651125, 2.166571420046591, 10.459495263714945, 36.955669618421986, 67.16682372554656, 57.65614294236707, 84.68551743415095, 80.19470953172254, 51.47296959354032, 79.52613369111093, 94.07811918566304, 96.72500518060501, 16.037538090059837, 0.7950787750944015, 0.6721528583476621, 0.45552406159620135, 0.5133484394079255, 0.2795846766281513, 0.2829450753427321, 0.34025231316204996, 2.978881044733909, 7.375984259190099, 20.030326574079453, 23.923832024297408, 39.039707260747115, 48.316614781656575, 48.66425052765877, 64.68177472391437, 66.50445307454756, 68.63229182458693, 66.91142251414638, 67.13475442701771, 69.72244401131907, 69.75186178761145, 45.70671673743956, 29.928394363772487, 21.66479587554932, 18.68085668933007, 35.676914184324204, 41.52414045026226, 29.611843401385894, 16.505912234706265, 18.37605518679465, 25.418761045702045, 20.564284709192094, 31.581014433214744, 50.00985099423317, 59.25635622393701, 65.92488365788614, 59.2508884399168, 56.570505403703265, 54.295746434119444, 55.38650658822829, 46.43481062304589, 43.43566833003875, 57.32540868943738, 62.261425218274525, 57.16818048108009, 62.808878267965014, 64.45474793834072, 61.84668556336434, 65.48910833174183, 58.25682255529589, 55.13307048428444, 49.01865628457839, 51.72893954861549, 50.14069734081146, 50.3246957255948, 50.00149242339596, 51.846889142067205, 55.062781610796534, 56.00853566200503, 55.40785212670603, 52.97005199616956, 50.161933052924375, 51.57367644771453, 46.188399484080655, 48.14487772603189, 48.475196207723315, 50.05447187731343, 50.936440344779726, 51.31273684963104, 49.87415659812189, 48.34050986074632, 47.97343092579996, 50.868657865831935, 48.192832623758626, 48.99508283984277, 45.14511569853752, 47.664548197100245, 47.737037520254816, 49.5566995682255, 49.236241925147276, 48.159159075829294, 48.89743151203279, 48.35973731933102, 47.74086183117282, 45.102965908665816, 45.97580309837095, 47.916321216091035, 46.885404663701216, 46.58340961702409, 49.949422959358465, 58.852760022686375, 60.37858555393835, 57.484449032814275, 55.80758087096676, 60.97425630015712, 53.18602162022745, 48.008630275726325, 39.505429883157056, 32.452482715729744, 30.233462587479625, 22.431240735515473, 24.87102754654423, 22.05588559950552, 8.210068431592758, 4.7361737297427275, 3.1124698635070556, 1.1723774455247389, 1.5235283706457385, 1.244507381512273, 0.77098592274612, 0.15300124162627807, 0.16906192255837305, 0.2107910382291002, 0.20456084350664772, 0.19722578145803946, 0.18266214358229793, 0.196891414722608, 0.15879640566004863, 2.3150326407724813, 12.235232649310944, 46.140083728298066, 68.9141062767275, 67.8841781616211, 66.56170398958268, 65.37362198675832, 71.62938271799396, 70.08816580618583, 65.93636835775068, 71.53350430150186, 44.61683911661948, 42.62067825563493, 40.27992933027206, 25.64018472548454, 18.28084945678711, 3.9164000797656278, 1.8950822396624474, 1.7320919469479592, 0.7744481498675962, 1.8408840317879955, 42.736800024586344, 71.90689825242566, 76.39569790132585, 71.26192723551105, 48.21934000138314, 38.720602835378344, 35.6841980257342, 51.43811933455929, 27.92736976377426, 4.692957545480421, 0.17800060581536065, 0.22592498259919308, 48.03418843976913, 125.31920140789403, 95.73143743699598, 28.743895446100545, 0.5010475494688558, 0.37042968095310275], [0.11089275155456797, 7.424938380718232, 3.479966530876775, 3.297102691665773, 3.490883222510738, 0.9669924599509087, 2.8298699567394876, 2.2632693667565627, 2.1500246563265404, 6.773277761474733, 18.33789836975836, 59.786597913311375, 68.57837492419829, 51.85818556816348, 36.21870333148588, 51.20014913620488, 79.76553163220807, 67.3398708528088, 33.211763366576164, 0.08386798112863496, 0.05916749848233116, 0.025843924414666913, 0.026915397968203313, 0.04254489205777646, 0.08410491680185642, 0.3783259330497634, 3.0107716302717886, 2.06651518902471, 9.83509707835413, 25.9493733990577, 28.88729729960042, 27.64855592481552, 33.095398410674065, 57.78165486551101, 63.51892532840852, 58.80434228527931, 58.485586950855875, 59.86827734977969, 60.07114233509187, 53.172124662706935, 27.560985088348392, 10.610280979064203, 16.42313551518225, 4.492715645220972, 12.189080080678387, 25.780160388638897, 28.76420351766771, 17.522292483237482, 10.064966601710166, 10.35272736703196, 24.460216145361624, 30.78293565780886, 51.57111513999201, 59.133425220366455, 55.52420531549762, 48.37958843477311, 50.4476345739057, 43.85554628987467, 44.49174296471381, 45.55099471922844, 42.631021545779326, 40.14898100206929, 41.086392171921275, 41.97093371422061, 43.62163966701877, 58.28988421347834, 58.8540897061748, 60.42367319906912, 54.96172566567698, 48.620747520077614, 46.08660613336871, 44.01158994243991, 40.138598488223174, 40.791143601940526, 43.10023115527245, 43.88863148227815, 47.46509567383797, 48.81381050232918, 45.428455952675115, 42.24885325278006, 42.3829080981593, 43.58807202308409, 43.81207858362506, 42.512326701994866, 43.34230807519729, 47.35552426307432, 45.41777141632573, 43.70213062532487, 43.62409114837647, 41.31931427986392, 43.53208411124445, 39.78183146445982, 39.69698275289228, 40.64841247374012, 40.87598054639755, 40.20483555332307, 41.2234672423332, 42.950110281667406, 41.43327090048021, 41.421044872653106, 42.78621012164701, 41.995789774002574, 42.695309192903586, 40.53707207402876, 42.39021547379033, 39.318254378534135, 39.31566169185024, 40.94237058393417, 48.056083110071, 50.874757151449884, 54.1027932782327, 47.71583710947345, 48.326008858219275, 46.98796679896694, 31.485210541755926, 24.11811290248748, 23.781369578453806, 12.736614519549956, 3.3924758578500445, 3.5743625365918685, 9.841334627520654, 8.485552668571472, 7.823246246384037, 5.622883362154807, 5.939627501272387, 3.2578554557215784, 4.517018160512371, 1.4725363326649514, 0.04153550610006337, 0.05098605483409859, 0.15143932624449655, 0.07338235184790627, 0.09524243327999309, 0.04978556058279449, 0.2712943489032407, 0.3590830914195507, 0.6925163946805463, 2.238655758480872, 4.767161434696567, 36.577961060308645, 59.843060431941865, 60.316969040901434, 50.05952781246555, 57.39216350740003, 59.46170799193844, 61.43547996397942, 56.73217765746578, 60.00324218503891, 46.02918655641618, 48.22545105411161, 59.68049780015023, 54.37377414395733, 27.79475050587808, 11.093634655398708, 0.7260931703832842, 0.4153164271866122, 0.3374429461696456, 4.096554786928238, 30.275243674555135, 47.768083080168694, 58.873026909366736, 42.18966860924998, 29.62545990943909, 28.6584524954519, 26.754239836046775, 26.825850548282748, 9.00603844273475, 1.1331577887458186, 0.26202961862567936, 23.05313840989144, 46.46162786791402, 39.62485036542339, 26.483249164396717, 12.127887183620084, 0.47664648462687775, 0.09167052535039764, 0.35590165084408176, 19.66952931496405, 15.75405663059604, 1.0005900732451871, 8.628397545506878, 1.625082456777173, 1.6634824607641467, 2.985563047470585, 5.1572372259632235, 14.260753431627828, 49.928795214622255, 55.43266896278628, 69.62292563530707, 62.37008271678802, 41.75549753250615, 64.47251627522131, 87.74157724072857, 80.98673020639728, 49.4767185180418, 0.06487393421271155, 0.07490526569346267, 0.010262261982256127, 0.059482035031842614, 0.11052359676649494, 0.03864521724021724, 0.2618781783648076, 4.395241314365018, 5.476462754511065, 14.371372115227485, 28.712634155827185, 36.82228942071238, 37.312750431799124, 46.206563980348655, 66.72372925666072, 72.56615454150786, 66.46931648254395, 65.10706555458808, 65.89833705655991, 68.7250009659798, 65.00817868017381, 33.21244978135632, 21.459395077920732, 22.70211765843053, 9.209446676315801, 19.798518419265747, 40.658163485988496, 41.75399526473015, 23.439917449028265, 16.148167560177466, 25.775547681316255, 39.081049042363325, 47.354002383447465, 55.89559885763354, 62.554237996378255, 59.5858431631519, 55.75420525766189, 53.98195682033416, 49.854329016900834, 48.19051450298679, 49.773845903335086, 46.65117248412102, 41.859228534083215, 42.320797366480676, 43.133390872709214, 46.86654198554255, 56.139476145467455, 62.097387775298095, 61.635320801888746, 55.91865062713624, 50.053291243891564, 49.33501897319671, 46.48050623555338, 43.32229614257813, 43.18602515805153, 47.45750588755454, 47.51895766104422, 50.421460597745835, 52.1448088461353, 47.65329491707587, 46.657310993440696, 45.96631096255395, 47.5837238373295, 47.070642517459014, 45.29988850316694, 45.85862228947301, 48.27467679977418, 45.935614493585405, 45.92684799625028, 44.57383425005021, 43.57339451389928, 45.6502502964389, 43.15077481731292, 43.85982559573266, 45.37014992006364, 46.20987838314426, 45.94751104231804, 45.15147386058685, 45.57383860311201, 45.333252183852665, 45.50715831018264, 45.577910023350874, 45.668210829457934, 45.33647637213431, 44.077081757207075, 44.8649957103114, 42.369972121331, 41.928615262431485, 43.15223393901702, 51.45738601684571, 52.46622354753556, 55.42732277224141, 49.47292558608517, 51.74922996951688, 48.38062786286878, 36.10547234935146, 28.972465684337003, 25.315628205576253, 13.731015766820601, 9.672005907181772, 9.257777140986535, 15.691908636400777, 10.252271544548774, 8.971806937648404, 8.247509906368872, 7.892120124832277, 4.744303332221124, 5.163796409483879, 1.576786925715785, 0.10483989852570719, 0.06797470572975374, 0.06592573462835243, 0.0737881409605184, 0.07562665238736138, 0.059549385651705734, 0.2063032798469067, 0.27727694400856573, 0.27310200996937295, 3.2557420336431075, 9.634706128028132, 45.58802581602528, 67.32283207678026, 65.97553714629143, 60.115414127226806, 63.61467430668493, 70.61247687185966, 69.03319727989935, 67.65362124289236, 66.741058288082, 56.02183249688918, 52.2253704071045, 69.6091502712619, 60.54549417188091, 35.49302954827586, 17.708958079738004, 0.7167038742092349, 0.8075432707705806, 0.7680476997648517, 11.896967445650409, 52.10286694188272, 61.44798448008876, 69.56462352506577, 57.100111669109715, 34.64719787720711, 37.68854487326838, 32.04786473704923, 40.79116321379139, 18.838026062134777, 0.5653632660546611, 0.6227138950940102, 40.896984838670306, 64.77904950418781, 52.685738994229226, 35.60760198100921, 21.973749206912135, 0.5174374183820141, 0.07315847031291454, 0.2621167994314625, 30.057911026862364, 54.184229527750325, 18.42066626394949, 19.377124463358236, 3.2689317387919274, 5.406045423400018, 8.245327107367977, 11.965327493606075, 31.108231544494632, 67.89874584444108, 72.47218239691951, 84.44155385417324, 66.97390587099137, 54.045436459202925, 66.261289658085, 95.62506275792276, 89.43490366781913, 60.45819397895568, 0.13568347169747277, 0.19564210917920838, 0.10494751855731012, 0.19446020405138695, 0.371915768952139, 0.13983404414067346, 0.531037072500875, 6.4027951898113376, 6.843782365322114, 16.71950686362482, 40.380577348893695, 45.09905138323384, 40.879910761310214, 51.165746027423495, 66.15571514252694, 67.32262811353131, 65.53265056302472, 61.79753042036488, 68.4079557849515, 66.33872509002686, 66.26706338697865, 58.0971428655809, 36.46241587977256, 36.74772516373665, 23.53594295440182, 21.98384734892076, 51.11178598096294, 50.10384667304255, 27.829628221450317, 23.750241648766306, 30.831412230768514, 46.874425949588904, 49.01061934809531, 63.613936901092536, 66.53551040157195, 65.09791466497606, 62.71681631765058, 59.79252853701192, 52.83366726290796, 53.20556286842593, 54.27913911880986, 48.358917543965006, 43.54736958780597, 44.262158793787805, 44.538901621295565, 48.545991066963445, 62.13508175265405, 63.44285488128663, 64.85621821495795, 61.055688627304576, 51.182933853518584, 52.81592638261857, 50.36719852878202, 45.1429936962743, 46.61671446215722, 49.21231154472598, 50.52366187495571, 51.811678025030325, 55.497697937873106, 52.71253662724649, 49.585976139191665, 47.71604891746275, 52.44240691584926, 50.43979375593124, 48.22962053360478, 49.3866216751837, 53.72300586392803, 52.22081261296427, 48.084457535897535, 49.12603509041571, 46.17462019766531, 50.497515355387044, 46.27100852227981, 46.33055010149556, 47.07849902491416, 48.531733251387074, 47.54783415025281, 46.96802939138105, 48.90978305570541, 47.70774525980796, 46.982110700299664, 49.75727781172722, 49.51516559047084, 48.41212449535247, 46.688674265338534, 50.67123320794875, 45.8638233523215, 44.863250255584724, 47.23509965404388, 53.00057195848035, 57.98262926840014, 59.82439779466199, 55.297594301162235, 57.75460227843254, 53.77371426551573, 41.553954385942035, 34.927266874621, 35.89063629027336, 28.557953526896817, 22.22775601571606, 22.5156521028088, 23.422258938512496, 12.718654967123463, 9.37509915521068, 9.872949911702065, 9.794479954627253, 6.369015247591081, 6.051945551749199, 2.4969183389217626, 0.4111304921248267, 0.14706505612740595, 0.16669509391630852, 0.1835304582791944, 0.1349394011401361, 0.21135464911499333, 0.2104268859951727, 0.40441373963990523, 0.5135626069480373, 3.8581818101867555, 18.669764226482762, 54.212094045454464, 67.78908421916347, 69.91099234550231, 62.92432146687662, 63.35904167544458, 66.71268386225547, 61.79284318800896, 64.2841758266572, 64.77307573441537, 61.002116895491085, 55.11928727549892, 71.28051142538749, 57.62459139670096, 39.26486699811874, 17.485355523324785, 1.4557125515514806, 1.769052563655761, 1.0367781668901443, 13.2981861406757, 68.55532707706575, 73.7247677772276, 77.99059637131231, 63.90109362140779, 43.2726114796054, 44.86132044945994, 35.71355696647398, 49.937926492383404, 29.347765907164547, 1.2343235602301936, 0.3234896965084538, 45.33720593298636, 98.66813951923002, 65.59836987526187, 56.80001112722582, 32.75653896793243, 0.5023838826004536, 0.22212867985569665], [0.04578930889106086, 3.7578657221409584, 15.151590378053728, 4.818976925265405, 3.7174407945525263, 3.1271454115067763, 7.671533380785297, 14.890121259996969, 7.215240136269601, 9.948719316913236, 28.98567426589228, 53.93820670343215, 58.20922067088466, 38.769181389962476, 33.38602250622165, 51.947709744976414, 89.50710665795111, 71.13581518973075, 56.16536771097491, 4.368541740602063, 0.18812770594752606, 0.09707738239798816, 0.029383118474675767, 0.01802583435370076, 0.02682692247382816, 0.117518431507051, 5.082781814759778, 4.36094509017083, 10.613867986586786, 21.399459300502656, 25.605742393001435, 27.992188892056866, 42.54196413101689, 63.13647462475685, 63.8985989939782, 61.700110512395064, 57.00113850255167, 59.85128564219321, 61.517567326945645, 59.6931121426244, 46.823011521370184, 17.32996690657831, 25.145430680244203, 8.713023662567139, 6.035762342714495, 23.28469945538429, 45.96910761248681, 41.68200408258746, 27.492886858601725, 32.50424231252363, 47.05644353743523, 53.503321755316954, 60.04277183163551, 59.296219271998254, 52.41873148948916, 40.48395533715525, 43.664381734786495, 45.63575321628202, 46.04906905081965, 42.55408817721952, 41.568522068762014, 43.172018374166186, 40.3745408211985, 41.07097725714407, 40.45297253516413, 43.3830261999561, 54.23966438539567, 54.71584404668501, 52.23318376848775, 47.18693687069801, 49.68259196127615, 42.43039231146536, 43.360500028056485, 41.54376799060453, 45.37652769396382, 47.47526637969479, 46.35096996061264, 46.27608799165296, 46.260441657035585, 47.527273085809526, 46.860623128952525, 46.389644530511674, 43.14120423409247, 44.77809559914374, 44.47081319747433, 44.11452078050183, 45.6602954864502, 45.713671099755075, 42.1089344639932, 39.94364492354855, 42.03948497772217, 45.81124005779144, 45.21684015950849, 44.88082639632687, 42.5814349420609, 45.060321900152395, 43.83924491943852, 45.44108598462997, 44.52903293794201, 42.88022933467742, 43.05764205994145, 43.95183655523485, 41.007289732656176, 40.86246405878375, 38.84895455452704, 40.740725455745576, 38.347530518808675, 44.119000127238614, 45.04967266513456, 48.80058819247831, 52.19823545025241, 46.721159335105654, 42.157081557858376, 34.52523962143929, 25.558013031559607, 19.58712031764369, 10.229983656637131, 1.8474747168440975, 3.6513807264066513, 9.152845894136737, 14.746849825305326, 15.262708183257812, 14.018441169492661, 17.92360390386274, 14.16994663976854, 13.035164744623247, 9.566348041257552, 4.433071103788191, 1.2854907565539884, 0.03146076041664327, 0.054521424200145475, 0.062253672193976185, 0.1780834812070093, 0.3494810985942041, 2.1707597759462174, 8.773987100970361, 4.680600118252539, 6.768472858013646, 13.350791008241716, 55.16303347003076, 63.81200875005415, 57.30710691021335, 54.87983442121937, 58.34953561905892, 57.26857746801069, 59.09881422596594, 50.46405753781719, 49.054914674451275, 51.5045682076485, 65.77551587935417, 33.93406391143799, 27.47587161679422, 34.4065643895057, 24.419123434251357, 1.8362726727800986, 0.3381360412365006, 0.5372664092048522, 16.202891488229078, 44.70814012712048, 51.51878287715297, 53.031711655278365, 37.69133760083107, 37.91893705244988, 53.63719617166827, 31.342446073409054, 43.50616116677561, 22.70758544245074, 1.9191104341899197, 13.180553278615399, 37.05073610428841, 28.31464498273788, 20.177238948883552, 16.832243627117528, 3.5665489300604793, 0.2957389888263518, 0.16311571662945135, 0.04446648572000765, 8.450142491248346, 18.825811801418183, 8.550416904111064, 2.683998235771733, 6.298491031892839, 6.105164270247183, 9.11137173252721, 3.404309403511786, 9.816474645368515, 48.093580968918346, 54.24726593878962, 66.53188613153273, 48.87027694332985, 40.654029307826875, 63.11698436737061, 93.84505979476437, 75.68657259787284, 75.72507458348429, 11.202816770922754, 0.2845764442557289, 0.09084278266997108, 0.09024089037050163, 0.03774109559373991, 0.02169606392271817, 0.4083192558778871, 5.966259904446141, 4.540969623673347, 12.752446186157966, 31.573448181152347, 35.982839445913996, 36.55875321357481, 53.96464347839356, 69.4197468603811, 67.0130354358304, 68.06768232776274, 64.25169467926025, 66.7873893245574, 68.37532950985816, 70.8129805903281, 53.89703750610352, 29.11089005008821, 35.89085202063284, 17.43434117686364, 11.206406720222967, 29.64282424219193, 55.305478265208585, 49.34862567532448, 33.92884715910881, 47.43426584428357, 54.56207144644953, 59.75173196484966, 61.25510584923529, 61.655395492430664, 56.24523109005344, 46.65647552859399, 49.0550245008161, 52.00744744270079, 51.58537687793855, 47.74559220960064, 45.675431912945164, 45.91370805617302, 42.32918731627926, 41.813638825570386, 41.603391939593905, 45.07805101333126, 52.67038291500461, 55.09754950000394, 53.80707010146111, 46.18155887050014, 51.58691052467593, 46.18677954519949, 47.709223993362926, 43.882794995461744, 48.639394467876805, 48.61413440396709, 51.70029840161724, 50.95884100083382, 51.61248045582926, 49.62066558099563, 51.224189342991004, 49.39168937744633, 49.128827817978404, 50.05105157052317, 48.0678855219195, 47.250475345119355, 47.03958126806444, 48.34252203664472, 44.07796429049584, 45.0441264337109, 46.56880663287255, 49.06641506379651, 48.65545265136227, 46.60062097734021, 45.94220015310472, 47.44768427264306, 46.33084035688832, 47.27403310037429, 48.078091529107866, 46.69646801487092, 45.80797664580807, 48.48971289973105, 43.7037701760569, 43.85542077402915, 43.67763150122858, 44.46733797750166, 42.040595008480935, 46.953061626803496, 46.894641845457016, 52.45442113568706, 52.878480342126664, 49.433764642284764, 44.10898239381852, 37.725203344898844, 25.729850107623687, 27.24698562775889, 16.914111337354107, 8.935897638720851, 9.787270638250536, 12.99863669180101, 15.70310406146511, 16.34154237085773, 18.429966203628048, 24.027749338457664, 19.239106062919863, 16.16898455927449, 11.018233952983733, 5.558546685403393, 2.009872609088498, 0.04531847891367732, 0.14527803346995385, 0.10342838918609966, 0.05787904967644042, 0.16470390882703567, 2.0372604362426268, 7.62795094520815, 6.032539135025394, 6.633710515114569, 24.426646540241858, 61.560125043315274, 68.72914298888176, 65.33998374016055, 60.39399262397521, 65.60957608684417, 62.856688037995376, 65.79461389972319, 60.203063411097375, 60.20117282867432, 61.65505816859584, 77.72488717109927, 45.30261847280687, 33.14377692437942, 44.69673387465939, 32.16982887637231, 2.1322675962601942, 0.33485966704545483, 0.39050431020798226, 25.976786844192016, 59.983453827519575, 62.071790387553555, 65.11796974366712, 45.19909143447877, 46.797747535090295, 49.536024755047215, 24.035854916418753, 52.99529637059858, 49.89845568133939, 6.226370411534464, 25.129782384441747, 61.98828312658495, 51.807869403593, 31.314746295252156, 34.63623485257549, 7.13079591912608, 0.3124807372448906, 0.2588599145172104, 0.5631805896278351, 12.138163793471552, 65.79801851703276, 35.60262449326054, 20.51363318197189, 14.002911525387919, 20.110097777458932, 33.706774327062796, 30.638755213829782, 51.02852582931519, 65.8279069777458, 67.15663340783888, 73.72956091357817, 52.86529333360734, 49.97047039770311, 67.52659136249174, 104.95001146870275, 81.4965206576932, 87.00281450825354, 12.616632157756436, 0.2809639719705428, 0.17357756654101034, 0.13145964592695236, 0.2171089040536073, 0.13654052490188232, 1.255860314253838, 7.710490361336739, 6.901363249747985, 17.432874210419193, 40.875968779287035, 42.20278109273603, 48.48743008029077, 62.81034523440946, 68.24972737220027, 68.0927070494621, 64.73299695599464, 62.29448687645697, 65.5746905265316, 67.55698973132719, 71.52400432094451, 68.36583737404116, 55.50074169712683, 46.70747026320427, 39.88801394739459, 21.631300795462824, 34.80720704601657, 66.59986865135932, 55.2005313288781, 40.562300758977095, 54.598000357227946, 62.039324929637296, 70.33338454461867, 68.57737079743417, 66.1692080959197, 60.602180265611224, 56.04667286719046, 56.72011244681574, 58.4112423466098, 54.30619562825849, 51.065054862729966, 50.97218098178987, 49.529501853450654, 44.73684403204149, 43.80294730586391, 42.142447194745465, 46.933488999643636, 57.986936030849336, 57.62672908844487, 55.30074004204043, 50.04746652418568, 53.69476479868735, 47.45673710300077, 51.1188619367538, 47.72975367884482, 50.44042133515882, 50.71666994402486, 53.32519515868157, 53.94210161701326, 54.14785346677227, 54.41222513875654, 54.94596165995444, 50.69314749010148, 50.056444829510106, 52.9087531951166, 49.70655372065883, 49.745306737961315, 52.940324352633574, 52.54778139052853, 49.012839409612845, 48.3377642016257, 50.989211913078066, 52.487396501725726, 52.171771218699796, 52.00883596174179, 48.190122265969556, 49.225973160036155, 49.06412832198605, 50.2236750818068, 50.172005699526885, 49.961295973870065, 49.225298512366514, 50.775721226969075, 47.08041314155825, 46.326741480058246, 46.98428369337513, 47.97442720782372, 46.8896996590399, 51.000320065406065, 49.970297813415534, 55.76195978349256, 59.51271057128907, 55.78190111344861, 52.99168386766988, 41.659018993377686, 34.366952373135476, 33.6807886246712, 29.272528963704264, 17.722433382464995, 19.554237127304077, 18.934367318307203, 19.543223111860215, 19.2071230565348, 20.604037930888516, 24.012561921150457, 22.045250092783284, 19.825631803081883, 12.794898979125485, 7.76342764977486, 2.8156910788628364, 0.38350784370014745, 0.24372783940165277, 0.14799828911500593, 0.18203295557008636, 0.3334284309417971, 3.2168620296062964, 8.973184670171431, 6.721378920539734, 8.280167560423575, 34.237949540538175, 65.78546693248134, 68.46081364539363, 67.62931823730469, 60.07594331618279, 64.84750270843506, 59.375392313926454, 65.80086615777785, 61.038614549944484, 64.0107121006135, 60.03631953270205, 75.59259260854414, 52.862951678614465, 38.064311858146425, 49.66541590229158, 36.41702228976835, 2.364522901273543, 0.4915974565571355, 0.4620704974137968, 30.20609032723212, 73.29060846759428, 71.27105066853186, 72.35246381452008, 52.97536288538287, 52.28946193572014, 70.0630469476023, 44.01855999423612, 61.77918549506896, 66.46054606283865, 8.206203426084212, 33.87336915539157, 86.53137699250253, 66.68223842497795, 45.38599629555979, 68.9468188439646, 10.231998774313158, 0.5259801567562166, 0.5154651403427124], [0.09555437662188085, 1.1663342988298786, 20.155132470592378, 3.1057996278808964, 4.586735348547659, 2.9998164503805103, 11.47617067060163, 37.99801595749394, 21.942497722564205, 23.09058527792654, 45.29623677653652, 60.095810121105565, 63.350996894221154, 28.2205787012654, 29.872884981093872, 51.6528259554217, 80.27700870267807, 69.67692098309918, 67.8303240191552, 29.15407926805558, 0.09715007648112313, 0.07789208163176814, 0.044990639247360735, 0.04501613465348079, 0.12569642009874507, 0.9492929484094343, 4.543250481928549, 9.52562697472111, 15.754036038152634, 16.362504497651134, 28.752440329520937, 44.945278782998365, 61.56262751548522, 68.52117892234557, 61.086498845008116, 59.24238474138322, 60.09799488129155, 58.02463785294564, 63.79122803288122, 62.88331700909523, 53.71014833450318, 37.431288380776685, 31.325958390389722, 22.608953522097682, 16.846220993226577, 21.802186696760117, 44.464274606397076, 50.36586100055326, 44.850600611779, 46.198134806848344, 49.2516529175543, 48.220485333473455, 55.86118398174163, 55.18801896802841, 43.36184147865542, 34.13178666945427, 34.47225624515165, 38.60763072967529, 44.814008820441465, 46.50591534952964, 40.76951957518055, 41.11899883516374, 40.03056464656707, 39.029367892972886, 40.69478665628741, 41.78876707630773, 42.02308947040189, 44.277401124277425, 47.05321542678341, 46.19934681923159, 48.286432143180605, 45.5609183157644, 45.794754335957194, 43.688931849695024, 45.603723141454886, 46.208380037738436, 48.896188120688166, 45.702508034244666, 44.35964538205055, 45.08388750014767, 45.76240262677593, 49.318964712081424, 44.895288175152196, 47.53854990005494, 44.8525421850143, 44.40140293490502, 44.630002590917776, 45.43170367517779, 43.333074815811656, 43.01355854157479, 45.02749166181011, 44.05601470701156, 43.24759852501654, 41.71020984649658, 42.18479702549596, 45.279982474542436, 45.133368199871434, 47.863620250455796, 47.20932575964159, 44.456429866052446, 43.85739372622582, 44.571135659371656, 41.912745352714296, 41.439534925645404, 41.19024868934385, 38.25781022348712, 39.42460160101614, 40.95602827687418, 40.733986823789536, 44.55497941663189, 48.02027187039776, 35.00937777180826, 31.56239886437693, 25.338072007702245, 17.754377165148338, 17.94207630618926, 5.0135411947004265, 9.978437154523789, 13.397232851674481, 15.471028204887146, 18.492010255013746, 19.097432013480894, 28.5455019627848, 27.891362405592396, 25.59144731490843, 22.390097033592966, 16.850688572852842, 4.088973335681423, 4.403575860684918, 3.9345866393658424, 0.2385806631777556, 0.513324476177654, 2.052083318271945, 3.7144254724825587, 20.754345117076753, 25.035604315419352, 9.814105533784437, 25.26562975298974, 55.677907313069994, 67.70116036938083, 60.27797675901844, 59.9785194858428, 52.54151344299317, 52.07133500806747, 54.30658786527572, 52.026204216864805, 49.97371027546544, 46.57960491795694, 49.775885535824685, 67.390226241081, 44.8103492490707, 43.93383287614392, 43.17583091797368, 25.629451159508, 9.677492322460298, 1.7281030190567819, 0.5776590998134306, 27.22248846484769, 51.75821611958166, 56.24604302067911, 48.11737014401344, 27.87118769461109, 44.13816482790055, 89.44850644757672, 49.71832867591612, 53.43636297410535, 50.32040857499646, 34.29201156862321, 54.28784285822223, 27.075648653891783, 16.739346211956395, 15.141282389240882, 17.242364691149806, 0.9702118678439049, 0.23624035649962966, 0.13771665372675465, 0.1881994270989972, 2.665117661799154, 18.359447871485067, 12.344350045727147, 7.263814768483562, 7.425308064106972, 10.976736257153174, 28.66488322134941, 17.938695223100726, 30.54756795206378, 57.31530466387349, 56.68060633444018, 66.88213025369953, 39.69517061787267, 38.58680686643047, 60.84105260910527, 86.04111994466474, 79.70131458774691, 74.75839076503631, 38.682214598501886, 0.1385618938553718, 0.03413385951951627, 0.02117046057396839, 0.09216109741358988, 0.14125492273559495, 0.9255157855729904, 6.743371650095909, 10.549256743923312, 19.868750418386153, 21.181193128708873, 42.864124082749896, 54.29416179656983, 68.38672007283857, 72.55430113884711, 69.60088191493865, 65.54933240336757, 66.52458267827188, 65.04342902091243, 69.53294646355414, 70.07428846051617, 65.37890149701026, 47.92364428120275, 42.0512128645374, 35.35406389544087, 24.78895587305869, 28.80776732198654, 48.48406860905309, 52.69094005707772, 46.99769819936445, 51.271661789186545, 45.584201505107266, 50.44952907869893, 57.99924442845007, 58.126595943204826, 48.34686017805531, 41.7008706831163, 41.36828114909511, 44.315263763550796, 51.9914363276574, 52.883289167957926, 47.29599837333926, 44.29926049324774, 42.82846973788354, 39.90060475564773, 39.91867511503158, 40.91785184798702, 42.825955498603086, 43.576399049451275, 48.170851661312966, 47.87890572701731, 51.40009195573869, 47.98645711714222, 48.37619950694423, 45.73613059136176, 50.472216067775605, 49.52807018833776, 50.6349983522969, 49.480829161982385, 47.05705150481194, 50.151895707653416, 50.565156629008634, 52.94371720283262, 46.623406025671194, 47.48826119207567, 47.435140532831994, 47.135765629429976, 46.690470710877456, 47.157746591875636, 45.80326195686094, 46.212070988070586, 47.89536399226035, 48.12459907224102, 43.88583090997512, 44.207943793266054, 44.735514348553075, 46.056348969859464, 48.02604559929141, 47.94840228173041, 49.8582160857416, 47.16712105658747, 46.51607036590577, 46.09367032204905, 44.9408818060352, 45.925098619153424, 45.406063141361365, 41.08488205940493, 44.46666725220219, 43.15730556364983, 44.627296155498875, 46.17992324213828, 49.54641119126351, 37.974081654702466, 37.73040048537716, 28.531659918446696, 20.842123839163012, 20.53290770899865, 14.600979820374521, 20.13263963883923, 19.40489092180806, 18.855219771785123, 23.192464920782275, 23.162872599017238, 33.06155227845715, 34.813478915922104, 34.661098757097804, 33.87622464087702, 27.90987599280573, 15.995164725088305, 7.030405796343281, 4.3217591412605785, 0.3025645257965211, 0.25532362201521475, 2.1538543605035354, 4.709508967015052, 23.670435144055276, 33.02855730056763, 16.52613401412964, 35.949628737664995, 62.179078978876916, 68.27484623078378, 64.65696573257446, 67.08417938601586, 58.00313149729083, 57.63483270522087, 59.6802467684592, 59.19950146828929, 56.50177371117377, 56.62313184430523, 58.401546247543834, 75.02464909707346, 54.17085032309256, 52.03960303337344, 51.6896217100082, 36.49629731332102, 20.66707434192781, 2.170842145719836, 0.6492899754835714, 39.245925872556626, 65.44442861310898, 62.93459415435792, 61.86921565763412, 37.342329025268555, 50.56387401396229, 94.31724256084811, 54.901081900442804, 64.79000860644926, 68.74688779154133, 59.71271222637546, 72.70265302350445, 45.4205798333691, 27.7398883142779, 34.98909127327704, 31.90682807276326, 1.975275833279856, 0.281926300977507, 0.11994502266808865, 0.3338057445662637, 1.7412130510614765, 60.46108476577267, 48.17922592163087, 30.718344026996245, 26.206612240883615, 47.84838184233635, 74.65769567797261, 57.02759881173411, 66.0973188954015, 60.60648310569025, 77.59296217272359, 75.9104222636069, 43.68931231960174, 47.56621829925045, 62.822124112036924, 97.78245264484038, 82.91171181586482, 84.10154711815619, 37.825062967115834, 0.20026499014948645, 0.16428286690385113, 0.1439686972768076, 0.10978315746591938, 0.36122890369546035, 1.5471459420457965, 9.9244967199141, 17.33738999212942, 22.1967928255758, 33.09990129163189, 57.386931065590154, 59.02237899841801, 70.1082875651698, 72.92458072785409, 67.23209196521391, 63.43743416570849, 67.64784751399871, 62.23584744238085, 69.2171250620196, 67.15737865817162, 65.28090107825496, 60.3686737245129, 56.18792918420608, 49.27503416615148, 45.106641169517275, 38.887778174492624, 56.29866161654073, 60.64191387545679, 57.3713396441552, 62.325148044093964, 59.632880226258315, 62.81253783933578, 61.99164459782263, 62.66383294136294, 54.97619528924265, 52.249861686460434, 49.17915182728922, 52.58660108812394, 58.023700406474454, 57.76749510918894, 49.10054360666583, 49.46117024267874, 46.96869227194017, 43.49089922443513, 43.95193461448916, 41.95878221142677, 45.56180084905317, 45.87683777655325, 49.50814454786239, 47.994066515276515, 53.40686282803936, 51.69521500987392, 50.9688469671434, 49.5299490036503, 51.90487746269473, 53.107107454730624, 55.268572684257265, 53.240173862826445, 49.580575035464385, 53.04403966472995, 53.30062150955201, 56.523562477480986, 51.415573550808816, 50.701431535905414, 49.75775634088824, 50.689417316067605, 50.772689234825876, 52.09875237557196, 49.331218196499734, 49.66162689270512, 51.117430271640906, 52.371592444758264, 48.29678720043552, 47.16058246551022, 46.371652618531265, 49.33506996400895, 48.62937673445671, 51.27040270836123, 53.31541276747181, 50.50230064699727, 51.19339089239798, 49.7760541977421, 48.24625922787575, 49.30478142153833, 47.74590207684425, 42.87016061044509, 47.73206395487632, 45.5429107143033, 46.74649784641881, 52.49029513328306, 55.18926628174321, 43.15044141584828, 37.865420233818796, 35.57870980231993, 27.466914884505737, 39.25592399412586, 23.16138013716667, 26.225123866911858, 28.180356756333385, 21.199859688358924, 27.355631359161872, 29.438957091300722, 37.55631393001926, 35.891044216771284, 34.5574579700347, 36.887561582749896, 35.587986207777455, 21.294198574558383, 10.042739510536194, 6.079382040808278, 0.5639731535507787, 1.092702707936687, 2.544146127277805, 6.035724099605314, 27.055177803962465, 37.20825456803845, 21.776375539841194, 40.782373182235226, 63.26789755975047, 70.63643470887216, 63.392354365318056, 65.1645988802756, 58.78111400911885, 56.95463488178869, 59.29837657559303, 59.306307608081454, 59.71295541332614, 61.70093813250142, 57.60976875981977, 72.58660577958631, 57.68568623450495, 52.76353528422695, 56.572627405966486, 44.86810614985805, 20.618584040672552, 2.1587445755158705, 0.7892751994152224, 44.82406969993345, 75.2918331084713, 75.73795564713018, 65.24720007373442, 45.754961890559045, 57.82818202049502, 106.56948751018894, 60.012157732440585, 72.21664782493346, 84.51634560861896, 76.2522646688646, 90.25525169987833, 62.934849108419115, 40.01343565602457, 66.0905881081858, 54.1576397803522, 2.206649708171045, 0.5290611785265708, 0.2672408244782879], [0.03999144822779683, 0.1304413005709648, 7.683167621012657, 6.0206523922181905, 2.787562046320208, 7.508048501706893, 9.093484743948906, 43.3505803538907, 41.45553427357828, 44.28322192161314, 53.107821326101984, 71.22515893751576, 70.17898436515563, 30.412001032983106, 31.99077267800608, 44.217443773823405, 73.00303597604075, 74.4205334878737, 67.79511682448849, 47.352966877721975, 1.0647599879772434, 0.08420567268565779, 0.07675961981857977, 0.0822899166134096, 0.20434646146191707, 4.241292697768058, 6.938226174923682, 13.595856774237848, 21.156970531709735, 36.04367932965679, 52.03648867145662, 62.52673433672998, 68.81125388606903, 63.112775664175714, 64.28607817619078, 57.424562285023356, 56.629360568138864, 56.34222345967447, 63.22754421541768, 60.426395323968705, 61.10465549653577, 48.28904444171537, 46.51158317442864, 39.21040096590596, 43.87345583208146, 42.69250862060055, 47.663959841574396, 53.109531479497115, 47.37511257971487, 46.53021051037697, 41.58361142681491, 46.13234881431826, 56.422353559924716, 51.24789614831248, 45.448012890354285, 34.57348477455878, 32.409517072862194, 33.57391188221593, 39.58803499898603, 44.05035080448274, 43.571872634272424, 39.76578504808488, 39.09418506007041, 37.537439484750074, 32.9256852980583, 36.86914605479087, 43.054908167931345, 36.51104150279876, 42.384316229051166, 43.642345859158425, 46.03929058198006, 47.53657694785826, 45.5749447115006, 46.004020629390595, 46.91146096875591, 48.45727097603583, 48.04561822645126, 46.4741559182444, 44.411683467126664, 44.06320833390759, 43.12831532570624, 46.69778985361899, 44.47000518921883, 44.03417887226228, 46.5027186178392, 47.196291723558986, 44.90089716449861, 46.749129756804436, 41.452682710463, 42.35284705315867, 40.794442315255445, 42.038186673195135, 42.94548580723424, 44.349662949962, 44.21967168008128, 44.063996730312226, 42.99663351428124, 45.224061242995724, 43.86131217402797, 43.23843979066418, 43.162035942077644, 43.13949015832717, 42.64210224151612, 42.590040622218964, 41.04466992039835, 41.366010096765336, 39.131431887226725, 42.728347316865005, 37.90083923647481, 36.50191414740778, 32.615149290330955, 32.99302454917662, 30.376942888382946, 20.442298996833063, 15.735797016851365, 7.36646564737443, 15.11177145665692, 23.478184092429377, 16.18101741037061, 20.124200659413493, 16.291716502558803, 28.395777248567153, 43.0515859203954, 48.300333023071296, 37.88278064420147, 26.578856937346924, 24.563921651532574, 22.151889531843125, 21.51377481798972, 21.438802634516072, 9.288179432192157, 9.474141943839289, 10.928252820045719, 26.285944138803792, 35.0802981468939, 43.23984792155605, 56.511709074820246, 62.988907214133974, 61.610201943305235, 62.248932469275694, 61.190939795586374, 59.38608469501619, 50.58292104351906, 50.3591537475586, 51.84058197083012, 52.47050677576373, 48.89868274811776, 49.16288183581445, 51.01022797246134, 63.800994734610285, 62.000960226981874, 60.96117911800262, 47.02534698670911, 33.441939815398186, 27.22584797490028, 1.3676470061463695, 1.1993384697744924, 39.842918457523474, 53.3544050493548, 50.831877800726126, 33.27453305644374, 25.89907096278283, 48.45993034301266, 40.64002644631171, 29.59347886423911, 50.52431298840431, 61.735780546742106, 66.23719061574629, 35.07832519469723, 25.269185381550944, 19.583494086419385, 18.908342392213886, 13.374435055640436, 0.1845347995479261, 0.03480627021241573, 0.022671249800271565, 0.16115638547607009, 0.5005408282722197, 23.955309044930246, 15.250257599738338, 5.319012441942769, 16.302243163508756, 19.192718152076967, 48.894246547452866, 45.88424321143858, 52.22427606582642, 59.41312159261396, 70.12433005917457, 70.22878277686335, 36.05467373324979, 41.19698732129989, 50.233963458768784, 80.60180448716687, 79.78877559784921, 74.23218127219909, 57.37312040021343, 1.6118662756296898, 0.10893624726562731, 0.1605577643720373, 0.020790835279190255, 0.1639077902561234, 3.5709566935416195, 8.654597997665405, 18.919183823370165, 29.4787024682568, 50.437577616783884, 59.78229115086218, 69.87591066668111, 70.61952144868913, 69.88474384430917, 69.55178952986195, 63.19858535643547, 61.53033856422671, 64.44477727336269, 68.95686011160575, 68.71428505066903, 69.67508531385853, 58.616550968539336, 54.051571046152425, 51.8717844255509, 52.30850112053656, 51.6598391532898, 56.65204363484537, 57.583626162621286, 49.386605985703014, 50.51018068867345, 51.78011863462387, 54.67321180528211, 55.92369479517783, 53.92849883725567, 49.77197101039272, 44.25441211269748, 39.12880389921127, 42.2100257104443, 47.74689443649785, 51.5306519692944, 50.70839766533145, 45.17384706004974, 42.561972141265876, 40.55601319959087, 35.03382590509231, 36.564483796396566, 43.56563606569844, 41.219250694397964, 44.77553036905105, 44.1058680319017, 45.94185106215939, 51.3315014685354, 48.481436698667466, 47.79507683169457, 45.98893519370787, 50.2766506133541, 50.80799841111707, 48.11478530206988, 48.65912398984356, 47.60779150070683, 46.89819943520331, 50.365672726784986, 47.059236264997914, 48.37791358270953, 47.4462329956793, 51.71958469575452, 50.13156214068013, 50.8428055240262, 43.785414311193655, 46.20639924080142, 45.2851443136892, 45.96978226015645, 45.61980093679121, 46.87536339606009, 45.83578625032979, 45.97477543738581, 44.82034344826975, 47.49614123375186, 43.836440424765314, 47.472952181293124, 47.253585784666, 46.43614815127465, 45.78130452863632, 46.596043571349114, 41.899181796658425, 44.52342002622543, 43.84345362263341, 45.00194918724799, 37.53510959686772, 40.290708003505586, 35.65913800270327, 38.12450847318096, 34.87319700179562, 25.618699942865682, 15.449364954425445, 13.787336099532343, 24.058779208890854, 28.430256843566898, 20.01728077088633, 24.871168751870435, 21.549270306864095, 35.40308175548431, 45.2671798583, 52.94771409803822, 43.80044875606414, 33.89912736031317, 35.82960421039213, 35.78458716792446, 26.91150922929087, 23.981190804512273, 10.373611046421914, 12.416080390253375, 14.687129778246726, 35.593685411637836, 42.767249384234034, 49.448681416050086, 62.188810379274436, 67.53854674677696, 65.48362485824093, 67.81184181090325, 67.70320000187044, 66.99905610853627, 57.134550079222656, 56.50237383381013, 56.291711176595385, 60.2842447065538, 57.220861834864465, 57.39808236399005, 60.654449770527506, 70.75388616131198, 72.0158067826302, 69.03914359308058, 56.06450396199381, 47.825337917574, 34.10853878144295, 0.8308878697214589, 1.8602511022360095, 49.55514238726709, 61.38272800753194, 60.605353463080625, 44.30090004397977, 30.205309775567827, 54.41447265686528, 53.54025087048931, 42.64138052540441, 72.05779183295466, 77.62030893756499, 70.13685810950496, 53.44346246411724, 44.071613973186864, 34.333384729200795, 43.688700429854855, 19.514376040427916, 0.2166284137074986, 0.1343075318201896, 0.021369306355594628, 0.17326101901069765, 0.46864812833166897, 29.626856273220433, 60.19876057101835, 34.82927037823585, 31.312942004972893, 47.29962264337848, 71.83225554804649, 72.52337717240857, 70.11927804639264, 67.92583373285109, 81.45290390137704, 78.3227740564654, 48.645313324466834, 51.582870483398445, 59.936071595838, 85.18523523884436, 86.88490806087371, 80.18790814184374, 63.95022523018622, 1.879767713046843, 0.1653991182965617, 0.18804136783845965, 0.16120201367284023, 0.46599881242840524, 5.235924384286327, 12.991262635877057, 27.244873431421098, 37.63019177221483, 58.65474700927735, 65.89830567759853, 74.02002026957851, 74.57592994936051, 69.74449557642784, 69.63417499296128, 61.947831722997854, 60.891941439720895, 61.94015172220046, 68.61185627598917, 66.7448002292264, 70.4239599166378, 64.33303679189375, 61.13674440691548, 57.19134599931779, 58.481970525557, 63.4147628661125, 60.81414514972318, 61.357448331771366, 56.61811513285483, 57.65305211467128, 58.291084458751065, 61.079599395875015, 63.13016745351977, 58.82691944799116, 57.05656943782684, 53.23666726389239, 48.345761914407056, 50.930341059161776, 55.03323831865865, 57.367299602877715, 52.775023906461655, 49.52503035145421, 48.18514477822089, 45.33658619849913, 37.26681555471113, 39.774347582171046, 44.474327641148726, 41.38776748411117, 46.51301091717136, 43.555449670360936, 48.098523155335464, 55.190948978547134, 50.85738889632687, 49.46848154067994, 49.73040957604685, 54.78769010113132, 53.85269903367566, 50.21510862535047, 49.71469263876639, 51.025638964868364, 48.99906796793784, 53.683542897624356, 49.95901707679995, 49.387159039897305, 51.58560829777872, 56.799493374363074, 51.997700352822584, 55.50679783667288, 47.441969379301995, 49.63583730882215, 47.31890109277541, 49.418965539624615, 46.71460897691789, 47.81728136924006, 48.65316983192198, 49.11560550812752, 47.96862994470904, 51.75563520000827, 49.99289066560807, 50.829206666638775, 48.66307773897725, 51.704742447022475, 49.736269597084295, 47.853276960311405, 46.45784670306791, 48.79202958076231, 46.920192164759484, 47.60442218472881, 42.16092548062725, 42.96449753545946, 38.751852358541186, 39.731958527718824, 38.26041075491136, 30.06595188571561, 25.98070921436433, 21.55262197217634, 29.47819059894931, 38.34714612653179, 26.149628047020208, 34.85284774534164, 27.68057031016196, 39.06057819243401, 49.67284487139795, 53.37862176279868, 48.594110704237416, 43.27396861968502, 44.415088084436235, 45.61890271402175, 34.19996923015964, 27.87941094367735, 10.032970847622042, 14.11577674650377, 17.152228624589984, 36.703167038579146, 47.59487121335922, 54.2001582730201, 65.24444264750328, 70.00456440833308, 65.72514872397146, 65.79365684140113, 67.56559541148525, 65.55379606062367, 56.88160427155034, 55.88957801941903, 57.449877262115486, 60.83914241483135, 57.7739905541943, 59.60536479949952, 62.64962219422864, 67.43726330418741, 70.1680644865959, 66.62469725455007, 62.199134057567974, 53.53627750950476, 47.42917853017008, 2.7115739689719294, 1.101680400390779, 57.17438567069269, 72.29038053943266, 69.16980558826079, 48.526449818764966, 38.91420710471369, 65.95833363071566, 51.2650800520374, 46.25558576276226, 69.38499466065439, 79.77377645431027, 80.48234478119882, 59.573530843181, 50.076676414858916, 55.026609513067434, 81.1938548857166, 24.568501018708755, 0.3701251456814428, 0.2519454500607906, 0.2303686296387065], [0.10726985281273242, 0.052444008254115625, 0.32902740903439065, 8.931675207230354, 2.1942761011662024, 5.436820830068281, 2.59423773615591, 36.9946736674155, 54.17050515451739, 46.101487605802475, 29.38179442959447, 69.14108599385908, 69.45110228753859, 53.6848412021514, 34.08090960594916, 45.56198520045127, 62.956688865538574, 75.14759971249488, 58.68545132298624, 56.0544587719825, 4.768030239689735, 0.16788668239549284, 0.6297188804995629, 0.21613408781347737, 2.8096454806866187, 9.55720401579334, 22.131006833045713, 40.41055210175053, 55.37353923243862, 63.952300164007376, 66.17088687035346, 72.41512760039299, 71.30040568690147, 67.55301244797246, 59.785225083751065, 56.37951343290268, 53.078705572312884, 55.534764336001494, 60.01453468876501, 60.8971974157518, 57.07209025659869, 53.252705835526996, 51.42096288742558, 48.24085812414847, 51.86989776549801, 55.97234395242507, 58.62170888531593, 58.948407019338305, 56.517345520757864, 57.05552216499083, 53.8246972330155, 53.03429257485175, 51.27875343445809, 50.32130679776592, 44.5563522461922, 37.352166329660726, 33.839134708527595, 32.213608411050615, 37.09918522065686, 40.545760123960434, 43.97769674178093, 43.32859154670469, 36.288042991392075, 33.40337507186398, 36.16872449075022, 30.999634842718805, 38.543299936479144, 39.723666637174546, 41.67369258019232, 40.9263986925925, 44.392679583641794, 48.76296481778545, 45.22657940464635, 45.10438188429802, 45.48836623468707, 47.810742778162805, 47.47465056757773, 48.217790665165076, 47.406503308203916, 43.8019000330279, 44.64023213232718, 43.76222918110509, 42.90947452668221, 43.0608505587424, 42.80513163535826, 43.734945174186464, 44.61204205789874, 45.34375236880395, 42.658780159488806, 46.3567280000256, 45.917693184268096, 42.86103325505411, 43.55994862894858, 41.148224415317664, 40.76970392657865, 43.026521974994296, 42.567345788401944, 44.38091639549502, 41.594339109236195, 41.79478399215206, 43.49155033788374, 41.81242289081697, 40.59728830091415, 40.71279425774851, 38.163775320976015, 42.447627206002515, 39.815838413853804, 42.395530285373816, 32.48200051246151, 33.78238193450436, 34.67870627680133, 33.30506870823522, 26.508544529637984, 19.63471435731457, 8.459214933456915, 15.639814657549705, 18.57568813908485, 16.20451633007296, 10.90651112218057, 8.900258983335188, 8.668145864240586, 28.75789046287537, 53.862983488267474, 56.749553757329146, 50.43751093649095, 41.27079848320254, 39.04776773145122, 33.98112843113561, 26.74889168431682, 29.39388317446555, 21.141749774256063, 25.62580531643283, 37.471131816987075, 52.171112260510846, 50.11108344601047, 47.775551272976784, 62.68501766266362, 60.58913838478827, 64.20037438792568, 63.71729527750323, 61.51370771469609, 54.335719308545514, 49.34855507266138, 47.843831892936464, 50.257940907632154, 47.55987974905199, 48.62497975749355, 47.89066891516409, 52.41050235686764, 57.839992277083866, 63.8156997003863, 56.68066909236293, 46.49681545072987, 45.8894403519169, 14.793015141640941, 0.11547293844482592, 3.3177071473290844, 50.67915639569683, 54.2459794013731, 45.18323721424226, 22.33643900963568, 30.551537390678163, 47.15419292449952, 32.95513053094187, 31.41222699995964, 33.52277986464962, 47.31987384057815, 38.87377923534763, 27.79433277345473, 19.751469589048817, 24.44157115874752, 15.497348289335928, 1.7612135842923196, 0.27799596349077843, 0.052298148943772244, 0.06192010218998598, 0.09856700972323457, 0.13229013120214786, 3.1061435707153815, 24.854732059663345, 11.266245418979276, 4.326102675930146, 30.869957362451864, 61.89948458825389, 58.81172418594361, 51.837400928620376, 45.10011042318037, 76.88847311081426, 77.69938392023887, 53.64304050322502, 40.689487534184615, 51.67934510015672, 74.17056868153234, 79.60058812172183, 65.38581271325388, 66.42987312809115, 8.273441676170595, 0.3167096958045037, 0.36065786175670167, 0.28596330854681234, 2.682634476692446, 11.028382105212058, 25.978918652380667, 48.24174850217758, 62.33351053730134, 66.1540206786125, 69.53499394078409, 73.61763215834095, 73.7269486150434, 72.17106203879081, 65.33974447558003, 61.699184833034394, 60.05363679701283, 60.800585516037486, 65.0845197708376, 67.4091399100519, 64.90475362347019, 60.940539606155895, 60.183479016827, 59.53748818366759, 58.084367705929665, 62.175815566893554, 60.9716243897715, 62.117391863176906, 61.887246793316265, 61.58576949950188, 57.10792503049297, 54.429844425570586, 56.03680026146674, 52.7169845950219, 47.75429987138318, 45.45176659860919, 43.840900159651234, 41.23494801982757, 44.732552959072976, 49.98004098092356, 50.83316826051282, 48.828782189276914, 42.55892053727181, 36.4386776954897, 40.74795046160298, 36.58243256230509, 38.83250021165417, 43.11454780640141, 42.277368883932795, 41.42603020514212, 47.26096376296013, 52.38281042345109, 48.635719207025346, 47.70763151107296, 49.69386877552156, 48.994886721334154, 49.250452672281575, 51.41779361232635, 50.49134154473582, 47.19122009892618, 46.85730480378675, 46.35939913411295, 46.6841164711983, 45.9613452419158, 44.661099141643895, 45.78714886019307, 45.95499884697699, 49.9230646318005, 45.19211746031239, 46.62358645469912, 50.23990192720967, 45.66711256580968, 45.37665320980934, 43.767853859932195, 44.22719086370161, 45.67880907366353, 45.005232211082216, 47.86538139466317, 46.514477883615804, 44.96005042906731, 46.75900236252816, 44.560917885072776, 44.28325722294469, 42.56769487934728, 42.0373551307186, 46.3567280000256, 41.85338420252646, 44.74177837371827, 35.66313882027903, 37.71000023811094, 36.40133280907908, 34.38194759430424, 30.14557403902854, 19.85091736239772, 14.86016219662082, 23.838987235100042, 25.399827764880275, 16.516553624983757, 14.28854734666886, 14.28007894946683, 18.265656155924646, 41.814297783759336, 58.79048062909035, 57.19115380317935, 55.475375729222456, 49.620065458359264, 49.4441589232414, 44.68322130941576, 36.16369601218931, 37.66233559577696, 27.83124423796131, 36.61548245337702, 49.43934617503997, 58.86230314931562, 57.28526323072372, 56.1644773329458, 66.76804419486754, 66.08555178488454, 68.70318474308138, 68.61374685841223, 67.02711674474901, 60.87790719924435, 53.575469832266535, 55.48460114386774, 53.60025921175557, 53.4395008702432, 54.541235816094186, 54.302587047699966, 57.17608405697731, 64.17934263906172, 69.20728775762743, 67.38677455532935, 56.796994824563306, 60.08772611618043, 19.254924981824814, 0.11177930680494155, 4.552151810738349, 62.73621243815269, 59.254234221673784, 56.072156506199995, 26.915821875295332, 33.12013679935087, 55.38284701685752, 33.973719073880105, 36.60129131809358, 53.390392795685806, 68.1721664244129, 51.484885754123816, 48.721936825783025, 37.25098486869566, 40.522473012247396, 32.2673233093754, 5.253969738560339, 0.4772727461832185, 0.0898859082090278, 0.27138704554207865, 0.30334440330343865, 0.28962202189910796, 1.1133989715768446, 54.715773444021906, 38.50224448788551, 36.7396568482922, 39.42113422578381, 63.60400153744606, 79.95498211153092, 61.61582662213234, 44.253996341459214, 77.53118484250962, 78.53963405855241, 65.91283413671678, 51.061269775513686, 62.43429976124918, 78.27938479761924, 90.91391178869432, 73.84709865816178, 76.03971142922678, 7.9641843611194245, 0.5449684120474324, 1.2371838261042873, 0.3618112224484644, 3.738003084736486, 11.302944094904008, 31.621002997121504, 51.77314466045749, 70.13448115318053, 70.80593601349862, 72.14868099458756, 72.8536956541, 71.67092846285912, 71.95175447771626, 63.79465226204165, 61.75768698415449, 59.32232656786519, 61.165636585604766, 61.691104750479425, 65.23249118558823, 62.69817721459174, 62.24284102839809, 61.753952887750444, 61.37247885427168, 58.93298818219093, 62.172854177413456, 62.00281550807338, 62.875821359695934, 64.11407832176455, 66.12299473054948, 63.26464591487762, 60.591036811951675, 59.76779799307547, 55.69549522092266, 53.29216487946049, 52.01407624829201, 51.67376356740152, 47.28419596149076, 51.59391195543351, 57.684709564332046, 57.559578111094815, 51.86628918493948, 44.28676774424892, 41.7977963724444, 44.18065978634743, 38.64206129504789, 41.6296325960467, 42.44009625527167, 45.17259582396477, 42.56337634978756, 48.47939706617787, 53.991295983714444, 51.39664419235722, 50.89139584572085, 53.18096176270516, 54.463737626229566, 51.816812407585886, 55.78871034806775, 55.00538164569486, 50.27542291149017, 49.61623722507108, 49.31488544710221, 49.60568212693738, 50.08685496545608, 47.37255127199235, 49.54535215131698, 48.618460778267156, 53.486879179554606, 48.960817014017415, 52.11326906757971, 53.062200238627774, 49.028277858611084, 47.56131533653506, 46.5801775840021, 44.89044404798939, 49.36643323590679, 46.758829778240575, 53.81073751757222, 48.97680459483978, 48.863973694462935, 51.11042099614298, 47.46508782909763, 46.628536485856586, 45.79028283396075, 42.408050490963845, 49.0178757329141, 45.202429371495406, 46.95865492666922, 38.13751897504253, 38.55880114340013, 37.063746606149984, 39.253982420890566, 36.46818176392586, 33.62001149885116, 20.814796686172485, 29.406477905088856, 34.2876067469197, 23.536546999408355, 25.24872237636197, 24.394653727931363, 29.76413138451115, 52.98443924996161, 65.43393235052785, 64.47208481450235, 57.84318508640413, 52.334769233580566, 54.7841795798271, 52.3166714176055, 39.37730958384853, 40.500119424635365, 29.035180461022165, 37.86860912076889, 50.98598380242625, 59.76394622556625, 59.57134608299502, 56.355335943160526, 66.68209721965175, 64.8571595837993, 71.06645984034385, 68.25015098817887, 64.67398489675215, 61.507973209504165, 53.16588024939261, 55.11145037989463, 54.39666117391279, 55.303336651094504, 57.367103484369096, 56.97500375009353, 59.55540557061473, 63.31240469409574, 66.7674558393417, 68.9696470383675, 62.91204444823727, 66.8258128627654, 26.333873541124408, 0.34779968881799334, 4.808937618809362, 67.99345539462182, 71.85690372220932, 62.20612764358521, 34.96614148539882, 44.45103268469534, 63.840320417957926, 43.03588859496578, 51.69714089362852, 50.79846312922817, 68.99955903330158, 59.44392004320699, 60.3998448002723, 51.51202855571624, 65.43629753974177, 56.19010609965171, 4.1969130404533885, 0.60679875554577, 0.2467873647448517, 0.4007035758226149], [0.013740621000197868, 0.12643656062503017, 0.15235222725858613, 8.540664911270142, 14.548587741390353, 16.106621815312295, 24.34561429485198, 30.423979951489358, 47.77482563449491, 58.07462846079181, 28.61436897708524, 35.260782088002856, 34.22534696517452, 30.74520245675118, 27.707820976934126, 41.819294883358864, 53.148021697998054, 75.03163876072054, 59.470768667036495, 59.39645544175179, 17.665266798388576, 0.1260569640585492, 0.7625660648749721, 0.6430295049663514, 8.316487727626678, 16.64727249453145, 46.2149303959262, 68.13771232481926, 70.05695158435454, 66.53052114671277, 70.4081762990644, 69.70813520493047, 69.24687231740644, 64.18110770563926, 56.537133878277196, 55.82358806363998, 53.10564048828618, 51.90630520543745, 57.493078247193374, 59.56910248725646, 60.1727827133671, 53.60747637287263, 50.85281933507612, 52.910498649843284, 53.40197555480465, 57.39216350740003, 58.660854139635646, 58.94057404610419, 63.5457347285363, 59.55209116781912, 60.26912004716935, 56.51934592954574, 57.65257750788043, 50.16969542349539, 45.12068325473417, 39.973152914354884, 39.40027113883726, 39.31077441861553, 41.29813348093341, 40.71985452405868, 40.49751104847078, 43.28672024511522, 43.799354414786066, 31.44618295854138, 28.689792233128703, 35.251548828617224, 33.35431014337848, 39.419055369592485, 38.22392486756848, 41.78029475673553, 41.5356957527899, 50.11726117903187, 47.10777559588033, 45.36893398531022, 46.07559604029502, 44.458873502669796, 48.392277302280554, 44.577109429144095, 44.36688607738864, 45.6540471507657, 42.784633328837735, 43.583369101247484, 41.57604909712269, 45.04619744516189, 44.9284557373293, 42.944391465956166, 45.03690927259384, 45.76782726472425, 40.24386313653762, 41.47371445932696, 42.17575596224877, 39.858878581754624, 42.70181640501946, 42.138897449739524, 42.96837283718971, 42.00447782393425, 41.77647044581752, 40.94287264731623, 41.0319535962997, 45.36347796840053, 42.09153090753863, 39.53813460565383, 39.198841741008145, 39.903997605846776, 38.447366606804636, 44.22925403041225, 37.1860029620509, 43.99226834697109, 39.0556909191993, 37.487480255865286, 32.71126501021847, 27.386880882324714, 25.276245647861113, 10.260145702669698, 18.965589384878836, 22.939848592204434, 13.110638010886408, 5.408505730090603, 2.918923939428022, 5.834606530204897, 11.168189106449004, 27.573001269371282, 47.72366223796722, 50.40834811425979, 53.53331612002466, 53.07861143542875, 46.23997865184661, 47.610745045446585, 46.97212434584095, 42.0237680404417, 43.53519062842093, 46.562664201182706, 48.64148901354883, 54.84991065917477, 57.66929857192501, 57.66042224822506, 62.97383354556177, 59.08366210999028, 59.08830227390413, 59.74139259707544, 57.42537421564902, 49.07065906832295, 49.04447332505257, 46.364557050889545, 48.62503859304613, 47.242540390260764, 49.86319749586044, 48.38991603543682, 50.047580272920676, 53.75480844128517, 59.2143907854634, 55.76539185739333, 53.21192103047525, 48.422765885629964, 16.013243909805052, 0.09531649099963327, 7.284293463153224, 57.79449670545517, 50.87353337195612, 34.026918180527225, 23.29739812881716, 35.291203991059334, 39.32696204031668, 42.35307847299884, 43.12817019800986, 30.650457605238888, 28.099883448693063, 32.74440119343419, 37.630270219618275, 34.37131012639692, 33.39079603072136, 6.695897242715282, 0.3004988156739743, 0.18055858871629163, 0.048990526026295084, 0.13297794026232537, 0.06938021660091416, 0.06684599008651511, 0.4557861555968562, 14.841428956677838, 20.391129716750115, 14.885535028672988, 12.156109617602441, 46.28528987207721, 59.54916900204074, 57.999754336572465, 23.32806125763924, 47.33800303551459, 53.86787860624252, 34.8698982884807, 33.20032573515369, 47.42229084814749, 62.761252849332756, 80.00031686598255, 64.06919463988274, 66.59795453471523, 23.715418846376483, 0.1342927003579755, 0.37310498255875807, 0.8825089578186313, 9.937932798939368, 19.813545019395892, 50.12110510180074, 71.86881988279282, 73.79260909172797, 71.75222350705054, 70.76544146383964, 71.09469306084418, 71.07382605152746, 69.02520348948818, 61.975233401021654, 61.85534615670482, 58.13137339007471, 56.04030686040079, 61.41224384307862, 65.33019350421044, 66.63653496773013, 61.51843417075373, 57.331001989303104, 60.713893290488954, 59.980300241901034, 61.21723144285141, 62.46781641437162, 61.337499157074966, 65.5310933820663, 61.34016636879214, 64.7684944060541, 62.96285090907928, 60.83929930963824, 53.35037677518783, 47.998914564809496, 46.35486879656392, 43.711054017466886, 47.38757394975232, 47.36688736946353, 50.86592397382183, 48.330468593105195, 48.41737262664303, 47.002765901627086, 38.80918172097976, 28.23576415738752, 35.01317462613506, 36.91367672335717, 40.02207663751418, 41.64925229164862, 44.08127869329145, 44.08171407638058, 52.64515423005628, 49.18353311477169, 47.84692272063225, 48.28158801601779, 46.85407669313493, 50.9168637952497, 47.218613932209635, 47.080911282570135, 48.054722047621205, 46.174828083284446, 46.87855620538035, 44.60576234325286, 47.77773211079259, 47.554227613633685, 45.409899219389885, 46.5603696146319, 49.30217696774391, 43.87884516869822, 45.05734874356178, 46.68354772752332, 43.713674160741995, 44.196051166903594, 46.53599600638113, 45.42321174375473, 44.54338489040252, 41.46608937171198, 45.40702412205358, 46.43041364608273, 47.75704945287397, 45.250941245786606, 44.048240569330034, 42.98185402347196, 42.2685553181556, 42.45081217058244, 44.167649284485854, 40.7091974443005, 42.0982656171245, 42.95654296875001, 39.16861203409011, 35.31081584192092, 31.9034646403405, 25.05411005789234, 15.286709166342213, 26.481525282705984, 29.944581985473636, 14.677913188934328, 10.116738946207109, 9.819576259582274, 14.25051800666317, 20.370762809630364, 38.64890583099858, 54.76887449141472, 54.25212575543312, 55.959054962281265, 54.26583836155554, 51.11578679853871, 52.9970653595463, 56.70740004508727, 51.71436794342534, 52.73741622124949, 53.63896123824581, 55.10016179853871, 57.72750262291201, 64.2681097984314, 62.84905118326988, 66.76785592109927, 65.57809514384117, 64.57217193418934, 64.74526612989365, 60.22680551775041, 53.01927774183212, 53.21913034685197, 50.22088235424411, 53.87226381609517, 53.75558114820912, 58.06157481285834, 55.551108852509536, 56.64060208105273, 59.29237927159956, 64.29198134330012, 64.7526833318895, 62.82284190577846, 59.539802382069254, 22.511255125845633, 0.07761985994875431, 11.44864151554723, 64.74459148222401, 59.764452211318485, 40.1244112753099, 28.40597737220026, 41.11941068403183, 49.514541933613444, 42.17135506291544, 44.16024777197069, 23.733473516279652, 23.97125347968071, 59.75183002410397, 41.132731053137014, 31.048552682322843, 55.91180609118555, 12.112817437418046, 0.5652816317254498, 0.21706911344682017, 0.047623580021242944, 0.03414646166587069, 0.17968328729752572, 0.2155257986798402, 0.7419502711103809, 16.308624859779112, 58.689546277446134, 43.4728955453442, 50.25040995690131, 61.57799536182035, 66.45732187455701, 73.89912497612738, 43.16648390985305, 43.17726650545674, 45.5012982891452, 41.63710078885479, 45.52200448128485, 57.89350517334477, 67.31614835800664, 87.73014745404645, 73.4956072222802, 78.88593227632585, 28.046925567811538, 0.17768605011365107, 1.8081513624037466, 0.9978618809292394, 11.1194222780966, 21.7838554997598, 56.124429933486454, 76.72126247036842, 74.64034311233029, 71.13956497561547, 71.03523777377221, 74.31556301732218, 71.88402298958071, 70.10855428634152, 62.72792839234876, 62.825081579146854, 57.36755455693891, 55.28496426920737, 60.50349343207575, 63.79549164925853, 66.24593750123056, 59.39217221352362, 58.17501760298207, 60.58505127506872, 62.54320436908353, 62.63639988437776, 64.73428741578134, 62.331204183640025, 68.17335098020493, 62.71651429514732, 67.34654672684209, 63.75509123648367, 63.587213793108546, 53.264457256563254, 53.10393817963139, 50.59742596841628, 50.48305749893189, 53.45475889021351, 54.16295459193569, 53.75430637790311, 57.496161230148815, 54.83566068833875, 53.863713049119525, 40.03982536254391, 39.072953270327666, 42.91646419032928, 38.86683664014263, 41.80106370679794, 43.183554064842966, 44.384615190567516, 45.68485344609907, 55.20005279971708, 50.47186697683027, 51.00774903451243, 52.292792027996434, 49.03582449882261, 55.115517877763324, 48.80378100179857, 50.15231932363203, 52.19081432588639, 49.45599663642145, 50.48801537482969, 46.41903092784267, 50.0297531004875, 51.12227047643354, 48.354889269798036, 51.016829321461344, 51.510275256249216, 46.977093988849276, 48.984331623200454, 49.9014013813388, 46.78460367264287, 49.09828824381675, 49.213923638866795, 49.42457060660086, 48.199073114702784, 46.06113426146969, 48.02432760115593, 50.53192630890877, 51.07059324941328, 48.90369945956815, 46.802062142279844, 45.69653426447223, 45.956830593847464, 45.93543798692765, 48.352645674059474, 45.36729835694837, 42.85711480725197, 43.20940248427853, 41.073668003082275, 38.18281058342227, 35.36419537759597, 36.65146235496768, 24.161917932571907, 31.07338324669869, 36.716558010347434, 20.23160299947185, 14.346905350685121, 16.66293255744442, 24.81410218823341, 34.83760541485202, 49.79112002157396, 59.702270876976755, 55.24271642008136, 57.87118296469412, 58.30331048657818, 54.09491715892669, 55.04706075114589, 60.8430451731528, 53.420755863189704, 53.6293004405114, 55.97409332952192, 57.05365511678881, 58.8909403739437, 63.34558402338336, 62.135579893665934, 66.11588739579724, 64.86388252627465, 65.67633874954717, 64.50705274458855, 62.56650717027726, 54.28413621840939, 54.97119034490278, 52.67833748171407, 55.86127811862577, 55.74048872916929, 60.37472594168879, 59.92190791714577, 60.970737934112556, 65.58842274450487, 69.21126504098216, 68.81006148553664, 70.01378197823801, 69.51070662467711, 28.362835222674956, 0.255211083699138, 11.820935241637692, 71.77742081303751, 68.29024545608029, 47.55878933014409, 36.31213026662027, 55.151799801857244, 52.51573954859088, 58.21914426742062, 54.099898569045536, 46.68743479636408, 34.674752527667636, 61.25468223325668, 55.39061723216888, 60.6612237038151, 92.26422694421585, 11.793196239779073, 0.7506731320773402, 0.2835178946054751, 0.23107215882309023, 0.21417002223672407], [0.06697174341928575, 0.033818637321312586, 0.05998528201974208, 0.5039139134028267, 12.26182729967179, 29.078501078390307, 54.30903542426325, 39.604399127344934, 24.925897582884758, 35.348286244177054, 58.62343472819175, 44.32855667606477, 28.237056578359297, 30.869914216379968, 28.729786680590724, 42.33307046274985, 45.916288975746404, 68.54234403179538, 62.21634541788409, 55.489853197528475, 37.7648232060094, 0.1911331301615123, 0.163568566523252, 0.216755231902484, 9.707916186701867, 31.844703612789033, 53.52229818221062, 73.78331307441958, 67.85223437893775, 66.62024928677467, 65.47689014865507, 69.49102417115243, 65.47792173201039, 62.425945112782145, 55.85692821010467, 54.725191054805634, 53.24244883752639, 50.04015914855465, 56.40727596898233, 61.96866343098303, 60.53784162767472, 58.210177729206706, 52.84865856170655, 47.46771973948325, 56.46689599560153, 58.68289786000406, 62.30064107525734, 60.82879520231678, 62.22034231308968, 60.080544256394916, 62.39220096218971, 61.1260167244942, 59.73012362757037, 55.99044961314048, 46.40156461346535, 43.67261478977819, 43.35588339836367, 45.34332483045517, 45.677138143970126, 48.06777961792485, 44.11789009647985, 42.696168191971324, 40.707506902756236, 39.03262346021591, 17.34723121889176, 18.66685578899999, 34.37686028019075, 32.74708017226189, 40.140700878635535, 42.02892203484812, 42.57730076389928, 46.420913665525376, 47.50934785412204, 42.86331215212422, 44.307619064084946, 42.70330690568493, 49.078876433833955, 48.73093474295832, 41.59573939538772, 42.899213606311434, 41.04841970628308, 42.01846107359856, 39.99749906601445, 44.45086402277793, 42.28172271482406, 41.54165383308165, 42.31554531281994, 46.2513574477165, 41.344264476530014, 43.57213935544414, 43.42403458010766, 41.048168674592056, 40.98331620616298, 46.41707366512668, 40.20907955784952, 40.62474881449054, 41.04259890894736, 40.53897442356233, 43.66148702559933, 45.546389856646144, 41.590538332539225, 39.798007319050456, 40.225635882346864, 39.52890919100854, 41.57935565517795, 42.48838455446305, 37.75636265354772, 38.90296951417, 38.54573965072632, 35.949338482272246, 29.466851026781146, 26.61140868740697, 10.853630708109948, 21.782217910212857, 30.551370689945838, 18.177418516528224, 6.706005680945612, 6.97968807912642, 9.0490040856023, 20.135324501222183, 16.414174860523595, 36.07467389875843, 55.71993158709619, 53.44310552843156, 50.52503470451602, 50.70749552019181, 50.154394257453184, 53.20167187721499, 53.10439317457138, 52.06097995081256, 49.14186969880135, 53.17164613354591, 56.01236781766338, 56.86322012255269, 56.084029520711596, 55.73062789055609, 56.75421353309386, 57.2580772830594, 54.713278816592315, 52.080368226574315, 46.767564896614324, 46.24597987821026, 46.83180547529652, 46.93553647687359, 48.532282383211204, 48.386911499884825, 50.33488996567265, 50.175802553853686, 51.281683444976814, 51.86763063553841, 53.72373542478008, 57.55704818233367, 50.77913761138917, 45.95679529251591, 15.549305965823514, 0.3671428879662868, 17.185339312399588, 58.051706129504794, 52.48195617429672, 33.26975168720369, 27.77090641760057, 32.779665262468406, 38.703826858151345, 34.85251042150682, 38.155667781829834, 51.656108979255926, 48.55478894325995, 16.416353737154317, 43.226825652583955, 56.12233931018461, 19.41799948292394, 0.27813162234041, 0.12366067933579608, 0.07779373892492826, 0.03802491967836696, 0.10426822839485062, 0.015488418040706988, 0.05133410773029731, 0.15204703315131127, 2.558982002158319, 23.755954580922282, 29.810582053276804, 46.19160406051144, 37.44151399981591, 36.9053848328129, 55.128446009851274, 54.38564323609876, 36.58056159173289, 23.90594601631165, 19.757045238248764, 34.357393557025546, 49.348523693699995, 53.34729771460257, 76.37467399720224, 67.64890655394524, 60.466933019699596, 46.90211788300545, 1.0033769172526177, 0.06909644231200218, 0.5927086825813017, 14.07890058332874, 35.862144193341656, 66.26961292759066, 78.88836414583268, 74.41967056643578, 70.50666701409125, 69.82095826056697, 72.19557685236778, 68.80478982002505, 67.01699702970444, 61.030252056737105, 59.74411472197502, 57.26296847866428, 54.365913714132006, 61.43702537782731, 65.32364314602268, 66.52653601861769, 63.86729063526277, 57.34001167358891, 53.08640910733131, 61.864932429405954, 62.27020740509034, 63.07940413874965, 63.55860794744184, 65.27556665482061, 60.650954938703975, 62.678710491426536, 61.57526539218042, 62.837723378212225, 60.68328703603437, 51.64868393251973, 47.685960415870916, 49.18851060252036, 50.50380683714344, 52.14373411670808, 53.04983300547446, 51.851646977086226, 48.49493749680058, 48.03935420128607, 44.84017495186099, 24.171468903941495, 19.609099318904263, 36.27976286795832, 36.02018433232462, 43.08973489269134, 44.57828221782562, 45.35235804896201, 48.29757951921033, 51.618207116280836, 47.376018647224676, 48.91291702947309, 45.31820989424183, 52.39231432637861, 50.8914311470524, 44.62093407107938, 44.03644207985171, 43.068742367529104, 44.42430957671135, 43.53013469326881, 45.811851947538315, 42.82621829740463, 43.43912393816056, 46.38367860547958, 48.167658851992705, 45.2148985862732, 47.08220174235683, 46.21611102934807, 43.893008847390455, 44.684041084781775, 48.55935458214053, 43.01560601880474, 42.92477177035424, 43.022583915341286, 43.55014662588797, 47.91561518946002, 48.48357046804121, 46.00426381634128, 43.82519891185146, 44.127625419247536, 41.86997190598519, 45.73138060108308, 46.2185154422637, 40.66141905323152, 36.98871558712375, 37.767313911068825, 38.68428953232304, 34.33525569977299, 27.56107726404744, 16.235290265852406, 29.881514195472967, 35.47362166066324, 18.815652862671886, 9.904209240790337, 12.52552334339388, 17.09639172400198, 32.881521371103105, 26.23419434793534, 46.51591347109887, 61.31135655987648, 56.80849129153837, 53.71663985713836, 54.22453580364105, 54.443019666979396, 56.13262376477642, 57.85639170677432, 58.102281170506636, 54.130583270903564, 57.607211374467425, 61.48751804905554, 60.386316545547984, 61.38709360553373, 60.57261343925231, 61.64135340721377, 61.62244366061304, 59.224102574010054, 55.87074279785157, 51.75727867311048, 51.16838186017929, 52.73214847810807, 51.34494343111592, 53.47272726797289, 54.47729333754509, 55.560200906568966, 57.17772360770934, 58.19977560350972, 64.63354526027557, 62.40916129081481, 65.82480046056932, 59.52561516915599, 59.34746111592939, 17.88596091731902, 0.2678445936931718, 21.064492810157038, 67.56062184610676, 60.50108509678995, 42.41194932691513, 31.51904098449215, 43.775557394950624, 48.39101822145524, 35.81481295247232, 42.999069306158255, 39.76386308670044, 56.738963357863895, 29.50336829308541, 42.37891120295371, 69.83319605550459, 35.61363458633423, 0.5178113305760969, 0.08111773314134729, 0.09200901363886173, 0.04851404232003036, 0.07097019378336207, 0.14363877385133697, 0.12347580699790871, 0.21079640084457016, 0.8453733666289238, 31.21067600865518, 59.633562718668294, 85.90760246399911, 56.64897634137062, 33.83216857910156, 56.61799353937949, 76.69639464347594, 53.09113556338895, 37.20816435352449, 43.657121427597545, 48.47120715725807, 58.62141470755301, 61.86289279691635, 83.91766640447801, 76.14293252268146, 73.3087690414921, 53.55159436502765, 1.0210175319544732, 0.39904784531362597, 1.6992232203483584, 18.929887971570416, 38.34614984450802, 67.9934161709201, 74.00888858302947, 73.75293823980516, 70.33665580134239, 70.70159312217467, 71.15407774525305, 68.02463823749174, 66.85122982148202, 61.34522622631442, 59.46020964653262, 56.95741191987069, 52.74353119634813, 59.529439480074, 65.57668309057912, 65.27444877932149, 63.191074017555486, 56.84293362402148, 50.25707798619425, 61.27574143871185, 59.974718709145826, 65.1304546479256, 64.67605983057331, 66.63902959515973, 62.13313233467841, 65.62308472971763, 66.11880563920545, 63.00215698057606, 66.82730336343089, 54.09572516718219, 53.06212179122433, 53.40625486066265, 57.17995151396721, 57.41642728928597, 60.73545848169635, 54.947416859288374, 57.12432446018342, 52.79446709540583, 49.384805617793916, 26.268509203387847, 30.474278465394054, 44.84215574879801, 35.817005557398645, 46.03943178730626, 46.03740784429735, 43.80410440506474, 50.2741010727421, 53.94696535602693, 50.248437004704634, 50.872815578214585, 46.41932118323542, 55.960859252560525, 54.91629677434122, 46.124449160791215, 47.256072567355254, 45.89753612395256, 47.51629829406739, 47.73065974635463, 51.257596169748616, 47.28822423565773, 48.28736566728162, 50.13230739101287, 53.769956634890654, 49.262592407964895, 49.92973658346361, 48.110094147343794, 46.434300714923495, 45.91050347974224, 50.71315157798029, 45.562040113633685, 44.691101351091945, 45.81813558455437, 46.03753336014287, 50.70370258823518, 50.866324055579405, 49.67852838577763, 45.4198855738486, 46.63364733419111, 45.89475908587056, 50.35518038657404, 50.58712582434378, 42.486956811720326, 42.7025616553522, 41.45938211871732, 43.91415826735958, 38.88858618274812, 38.577832483476215, 26.1156818943639, 31.22546334420481, 43.4667609583947, 27.458222912203883, 17.580724031694476, 19.538127953006377, 25.24547269267421, 44.506832322766705, 38.65857447347334, 55.14326472436228, 60.80946183973744, 57.22713762714017, 54.14519017742526, 56.637628924462106, 55.815449145532426, 60.23663497740223, 58.9543729443704, 58.986112763804776, 56.41808602117724, 60.69463053057271, 62.51977212967412, 61.718043588822894, 60.763185716444454, 60.1690133156315, 63.58496235262964, 63.60457812586139, 60.38523397138042, 60.39012124461513, 51.38161759222708, 53.22292720117877, 53.591320130132864, 52.92590964225031, 55.35840672831382, 56.44434628948089, 59.09341312223866, 59.52037880497595, 61.761491683221635, 62.511488083870184, 64.26843143278553, 72.41396657882198, 65.7728055215651, 67.58716060269263, 24.23516623435482, 0.40544789705064993, 20.987482955378873, 75.85950989877024, 68.6801290512085, 51.95650369890275, 39.44275433017362, 52.932232502968084, 52.05716740700507, 47.99632580049577, 52.10749533868606, 70.55579862286969, 63.53133570763373, 33.25396414726011, 67.93645551127773, 96.8806605185232, 42.989639928264005, 0.5617991798827725, 0.34827702288185397, 0.2486243976220008, 0.12999767437577248, 0.3274953251163806], [0.044833732949149226, 0.13595497325783776, 0.060396897231018355, 0.11931892965109119, 1.1202171541029409, 38.724007452687914, 61.36335934362104, 65.01662354315481, 32.55953008128751, 18.40425310596343, 33.864163352597146, 64.82269371709516, 66.55134893232777, 34.88535242695963, 24.527229839755645, 40.41606303184263, 43.63110434624457, 57.40076918755808, 68.61473529569565, 50.206930483541186, 57.11566386684295, 6.698079061123633, 0.42551226072734405, 2.067583299452259, 10.071650320483792, 54.9812473020246, 65.42475400432464, 69.53370740336757, 64.49294397907873, 65.65994716459706, 65.29370761686756, 64.71831944680983, 56.36080372718073, 56.904695264754764, 54.24759541788409, 53.16646076017811, 51.173178918900035, 47.84605979919434, 53.67591781000937, 60.92459124903525, 61.3910787336288, 60.66542063989947, 55.48608379979288, 56.5948123316611, 56.81361782935358, 58.78723682895784, 59.5318046692879, 59.070922251670595, 62.18292682401596, 58.440212972702525, 57.35160619981828, 59.71440276791973, 60.979476974856475, 55.82116011650332, 52.02754566746374, 43.67966721134801, 46.07651387491534, 51.11002875912575, 51.02541146739837, 48.32736992066907, 49.71992900294643, 48.03213704016901, 42.19766632203133, 42.940629912960915, 37.0122851094892, 13.541586860533684, 17.314677507646625, 31.73672272313026, 36.73658955481745, 38.965221451174834, 39.749711175118726, 44.909997063298384, 46.8716214549157, 43.24332314152872, 42.941198656635905, 44.584365813962876, 45.046079774056714, 48.05920139435799, 44.3780138415675, 43.17829808881206, 42.23079073813654, 39.00553949417607, 40.1452822069968, 40.21838341989825, 40.6625408511008, 39.18001044181086, 42.74213444802069, 42.925564089129054, 43.56273351177093, 44.36655659829417, 42.31181513878607, 41.88151936377249, 45.0756230661946, 42.267633561165106, 41.79345038629348, 42.453279341420824, 42.75261894349129, 41.64289805196947, 43.928145439394065, 43.04281157831992, 41.857620362312566, 41.22736607828448, 39.24563953953405, 37.470221827107096, 42.351109443172334, 40.3645662338503, 38.20385409939674, 30.45971078257407, 33.09187612225933, 33.2695516463249, 28.26736669386587, 9.355076436073551, 19.206685712260587, 35.19197194806991, 23.32962432215291, 9.93902910140253, 9.466041268840913, 9.25864496538716, 14.359551072120668, 30.027453822474328, 36.15788698196411, 49.66669067259758, 56.580350552835775, 49.9046177248801, 48.00653965242448, 47.101268383764456, 50.396855569654896, 53.88172849532097, 55.07099505393736, 55.92424784937213, 53.81727610864947, 57.5758598696801, 56.519059596523164, 53.44499611085462, 53.24649280117404, 52.406195594418435, 53.52047820245066, 50.838906688074914, 46.878222803915705, 46.19293374399985, 44.53063326497232, 46.77857106731784, 47.00260116207985, 47.2550174497789, 47.868217268297755, 51.45314201231926, 52.93131466834776, 53.404372122979936, 53.126448662050315, 56.55907169465096, 56.26377997859832, 57.31437506214265, 52.651504547365256, 50.137614357856016, 12.987113748827289, 0.41274359750170864, 23.172047022850286, 61.14214551064276, 52.255258867817545, 36.69994677266767, 54.86265443986463, 30.837766470447665, 43.292235097577496, 29.56147820718827, 35.227214444068174, 65.14065281037362, 32.32221687993696, 33.62129803626768, 59.371360117389315, 62.224825582196644, 2.362878937875071, 0.19607484160411745, 0.09575568154574403, 0.014879491138872842, 0.011167860263207508, 0.039832481153069005, 0.09520645013018962, 0.06484222583352559, 0.06082821622370713, 0.2622413346844335, 5.155582476046778, 44.70610441700105, 71.29609107971191, 54.94287083225866, 20.791711576523323, 24.321207346454745, 44.64906530995523, 65.47861599153089, 56.49364263780656, 25.208996611256755, 29.523150767049483, 46.300198801102184, 52.2940158074902, 63.71106263129943, 77.36804562230265, 55.97494448384931, 68.03657793229627, 8.582982382466717, 0.31761450693011284, 2.7432576494832195, 15.807146891470879, 66.82386736715993, 75.21277381527808, 76.68418822749969, 68.52357156815069, 71.60817838484242, 67.14496827894642, 67.82715474405597, 60.39601656698412, 61.526176929473884, 58.599614174135276, 56.30678876753777, 54.729662556802076, 52.01344474669426, 58.23858745636479, 65.18011185430711, 65.29071877079626, 65.1449203491211, 61.661651672855506, 59.681572529577444, 62.414927174968106, 62.17747080710627, 61.768548027161636, 61.591570684986735, 62.760884146536554, 62.89947717420517, 59.38543358156758, 64.39841878029608, 62.35672704635128, 59.56277570416851, 54.07093578769315, 45.6214600993741, 49.615570422141786, 56.4740700106467, 57.250632624472345, 54.22626556888704, 54.35928490854079, 53.14931608015492, 49.96466921221826, 46.48629565392771, 46.5204438086479, 20.74315263379005, 20.03156408186882, 33.72555855781802, 40.65422150396532, 42.574708077215384, 41.352497531521706, 47.67823334663145, 48.420267335830204, 46.006891804356734, 44.84047305199408, 47.17140036244547, 48.359243100689305, 50.427269627971036, 47.57741274372224, 43.54427876011018, 44.295016488721295, 42.6962270275239, 41.71687787578952, 43.07611250108288, 43.56849155118389, 43.58439676223263, 44.875625333478375, 47.30213296028876, 47.59089785237467, 47.39507744389196, 44.543039721827355, 44.00189776574412, 46.8304757918081, 43.88340296283845, 43.96016374711068, 44.95564168499362, 44.138643357061575, 45.443713972645426, 47.28773001701602, 45.88668684805594, 45.75782522078484, 43.21108518108245, 42.579038373885616, 40.82899839647355, 45.25664829438733, 44.29688353692332, 39.66461143186016, 35.34125343445809, 37.17074101971042, 36.71318477199924, 30.55867414320669, 17.541066908067275, 26.268558233015, 40.88790455172139, 29.909502267837528, 16.39103287650693, 16.266967327364032, 15.666309287471158, 28.460761116397, 39.672001177264804, 45.56770009379233, 57.56748560936221, 60.787877036679184, 51.66951171813473, 50.87151335131738, 48.4445232729758, 52.86568949299475, 58.29772110908263, 60.43527557003883, 58.25825029803861, 60.362158667656686, 62.073033778898186, 60.5761278829267, 58.5622339863931, 56.768239928830056, 58.41269362357355, 56.40727596898233, 55.32798090288716, 50.9730125242664, 51.71030829029699, 48.214350746523955, 50.69563427279073, 50.908022772881296, 51.6049651945791, 54.82066938954016, 56.81734408101728, 58.71709700553649, 58.72392192963631, 59.52371674199259, 61.210241779204345, 58.396251047811205, 68.51535812500985, 61.46025757635794, 61.97844974456295, 13.672946057012005, 0.4117941387718724, 26.157757159202333, 69.22956682020619, 57.79825825845042, 47.76551392770583, 51.0848157636581, 38.415795449287664, 48.56242187561528, 35.464474693421394, 42.35572607286515, 68.78058095132151, 50.406783088561035, 24.337445958968132, 64.90828375662527, 74.97921236099737, 2.928123123222782, 0.13332362977727769, 0.07760152746472629, 0.05630486156611193, 0.017428699460241105, 0.022527771108152888, 0.1381121389567852, 0.2743963001956863, 0.14320144489888223, 0.41406087036575046, 2.8947915569428475, 70.16105913346814, 93.06962290117818, 80.53303749330583, 48.668129751759196, 31.561773246334447, 48.799937079029704, 82.06972014519476, 84.30783241025864, 49.9103836090334, 41.40824225641067, 55.82029327269524, 59.17342555138373, 73.59559628271288, 83.46722141388925, 67.07865668881324, 76.89516467432823, 9.916065585228706, 0.6740249320864679, 3.849177274011797, 24.002277466558642, 64.84522381136495, 71.71614554620558, 78.05222465145972, 67.35056323389854, 70.84104907128119, 66.6884671488116, 69.78729647974815, 61.82556359998642, 61.99622592618389, 59.33275222778321, 56.76379196105465, 52.80013492030483, 51.12710283648584, 58.99653450135262, 65.75795150572254, 64.49249682887908, 66.36188276352422, 60.37881697377851, 59.098394532357496, 63.83733941662697, 61.26147577839514, 64.52411113246795, 62.34512467538158, 66.7417250910113, 63.971931626719815, 63.293389043500355, 67.07260839400753, 65.36323947291221, 59.09568025219826, 56.93911406301684, 49.15098136471164, 52.39505606312906, 62.0099110757151, 59.94197868531751, 56.682877386769945, 57.51153692122429, 58.010109393827385, 54.95222176274946, 52.4672668980014, 47.218951256044456, 24.378675953034435, 29.04409993079401, 39.068877927718624, 44.17932225811867, 43.35219637040169, 43.583792717226096, 48.14970224134384, 50.11251903349354, 48.38130251053841, 48.84831167036488, 50.65329228678058, 50.49587972702519, 54.0500020980835, 49.25529287707422, 47.20057102941698, 47.25431926788823, 45.574250451980106, 44.51769728814402, 44.9079260518474, 46.18918003574495, 45.4256671474826, 48.53309431383687, 51.528867290865996, 50.59774760277041, 50.77756474095007, 47.40553840514153, 47.40667981486167, 49.72656565327799, 48.63881787946148, 45.608002447312884, 48.581500284133426, 48.34136493744389, 47.89621906895792, 51.957852994242025, 49.240525153375444, 48.17005542016799, 46.86589087209394, 45.98918230302873, 42.93870402920631, 48.83738002469463, 47.41277125573928, 41.435008510466545, 36.801740123379616, 40.4202756574077, 46.4831106893478, 42.08821650474302, 30.483741183434766, 29.345228133663056, 47.83594792889011, 38.34063499204574, 28.85402971698392, 34.85131409860427, 34.41768038657404, 42.55004029120169, 47.60265711815127, 54.22921519125662, 58.285055775796216, 60.23134370003978, 52.952946539848085, 51.569695241989635, 53.728705067788404, 55.822046572162265, 59.82764943953484, 61.2057428206167, 59.37880477597637, 61.3843204898219, 61.60767985928444, 62.37491507684032, 58.8088922346792, 56.46011029520343, 58.83178710937501, 59.07856302876627, 57.935447077597345, 53.08155321305799, 51.52838091696463, 48.98759111281365, 51.21088466336651, 52.83451841723535, 52.8280504288212, 55.36385097811299, 60.22904911348897, 61.43278921804121, 62.433860455789876, 65.7627760210345, 62.931393500297304, 59.65643798151324, 73.40205084893012, 66.24157582559894, 71.6072448607414, 17.128849337177893, 0.31083567067980766, 28.559120432023082, 77.4588014233497, 67.56623083545317, 54.57861208146619, 74.80560825717065, 45.6382635331923, 58.20654561442714, 39.91381137601791, 51.58958165876327, 79.69171262556507, 51.39655397784326, 50.333509291371996, 84.19830414556688, 90.72490845957111, 2.91402024126822, 0.2260437568709735, 0.24395061777003352, 0.11703415668659634, 0.12920794497814872, 0.13874143422130616], [0.07356114910855409, 0.03480723548320032, 0.03434737205445286, 0.1427254285062513, 0.5586952367617238, 14.379174690092764, 63.490429309106645, 62.996728420257575, 61.24820640010219, 44.82630545093168, 26.226141721971576, 31.289515649118734, 64.65983298517042, 28.465220851282922, 18.519300145487634, 40.67960708372055, 38.37538719177246, 50.61843418305921, 61.03641410027782, 52.30624575768748, 52.68412690008841, 13.124379054192575, 0.24371003551829248, 1.0436246640259221, 5.012003625592878, 58.149906589138894, 58.08781939168131, 66.81782691709458, 62.365383717321585, 62.17603129725303, 55.20617561955606, 55.90058811249272, 53.78219442982828, 55.25607993525844, 52.03781835494503, 52.289650209488414, 48.856823213638805, 51.28069893006356, 49.76555009042063, 59.042430154738895, 59.3094886502912, 61.19210866189773, 62.6609343098056, 61.55357468512751, 58.817513604317945, 61.53179768593081, 59.33311308583906, 60.95810397978752, 58.93917768232284, 60.54190520317324, 55.54787289711737, 60.66476952645087, 58.92928938711844, 56.378250429707194, 51.929859038322206, 49.41444304681594, 53.72668112477949, 54.96373784157538, 58.76454199514082, 54.745344192751, 54.469354460316325, 50.008948849093535, 51.42553244867633, 45.913982622085086, 51.21968646203318, 34.086247951753684, 14.770922391645371, 21.793192701954997, 34.51314695419804, 35.03389650775541, 40.200571936945764, 44.496241923301454, 48.09842901845133, 43.549103275422134, 41.57282490884104, 43.027596704421505, 42.17136683002595, 46.91597953919442, 45.84240328881049, 41.37048159876178, 42.19761140884892, 42.65193170116794, 42.541297328087595, 43.58591471948932, 41.43057623217183, 41.074275970458984, 43.89637031862813, 42.790195249742084, 43.02885578524682, 42.63484193432716, 43.07435135687552, 43.91968880930255, 40.11689601405975, 39.989501353233095, 40.97317295689737, 41.06020250628072, 43.303927683061175, 39.15647229840679, 42.4839287419473, 39.89821210984261, 40.41097964009931, 41.24132579372775, 37.7581081082744, 40.81859627077657, 43.02595715368948, 40.05857429196758, 33.78543746086859, 35.00280780176963, 34.87169081164945, 24.73686287480016, 14.258503952334005, 12.3140860180701, 38.753546822455625, 48.84344793135121, 36.648952038057395, 26.591849788542717, 21.66116179958467, 26.58161044120789, 33.3590248323256, 46.333574248898415, 52.472813129425056, 56.78179564014558, 54.88861268566501, 52.17415209739439, 46.363988307214555, 47.39751715813914, 48.47333700426164, 57.094687031161406, 54.505581471227835, 54.41295469960859, 52.44309333062942, 57.35218671060378, 54.29326357380037, 53.643158174330196, 46.46574243422478, 48.96046400070191, 45.22296690171765, 47.28724364311465, 45.95073915296986, 44.490997714381066, 44.19609039060531, 46.125159109792406, 44.31303977966309, 48.85829802482359, 49.35699993564237, 52.98985604316958, 53.267148002501465, 58.098601987285, 52.83122754866078, 58.01065068091116, 56.3963992364945, 62.594901207954656, 54.51749370944116, 54.75136895333567, 6.886490112350834, 0.6144160597074417, 24.46771179476092, 64.64327666067308, 46.61453362434141, 39.07957423117853, 36.3609363186744, 31.27802114332876, 39.3718300327178, 34.31263539098924, 41.75919632757864, 55.770079089749245, 32.74867265455185, 47.69533095821258, 74.28884383170836, 21.191140259465865, 0.7280572359600376, 0.15558064434557192, 0.06337220652870114, 0.11658116123609005, 0.06589120704560511, 0.09151360756086727, 0.02803023975913323, 0.052152347090023185, 0.02452388022755904, 0.15142340693743, 0.6605371880915858, 27.39198192473381, 81.90734970954158, 73.27817455414804, 50.81898104759955, 35.164978196544034, 27.551385087351647, 39.373057734581735, 80.2224563783215, 24.757616135381884, 27.528868721377467, 45.648665658889286, 46.4876018031951, 57.83629348201137, 69.01977492916969, 58.23925033692391, 63.76097479174214, 16.409124808926737, 0.22765545264607479, 1.7432854108272062, 14.195617571953806, 67.48984659871748, 65.95696080115535, 71.47612787062123, 66.40285584234422, 66.57121181488037, 59.754610984556145, 60.16459672681747, 56.81446113894063, 59.94837607106855, 53.346109236440356, 58.596480200367594, 52.372372996422556, 55.71633869601835, 51.92885491155809, 62.358911806537265, 63.699927022380216, 66.09122353215372, 65.9073506632159, 66.92400547765916, 63.56393060376568, 64.98129083264259, 63.311467247624556, 61.96890661793371, 62.28339833597984, 60.1626943772839, 57.06945834621307, 62.04345910779892, 61.520258072883856, 58.53513433087257, 52.636160235251154, 55.11495697882868, 58.15551557848531, 56.68958856213478, 60.48065347056235, 60.478100007580174, 56.47084189999489, 52.75760073815623, 56.28875370948546, 50.44619506405246, 55.353146829912745, 43.708575079517985, 26.281205915635635, 27.660468163028842, 36.65785974071872, 38.38831924623059, 46.81046778155912, 45.63798504491007, 51.448089999537316, 46.578761608369895, 46.40015648257348, 45.517489833216516, 45.96400068652245, 48.67200897585962, 49.07408721985356, 46.87350419259841, 46.806643470641106, 45.734012511468705, 44.19626689726307, 43.66604874210973, 41.26406377361667, 42.995095945173695, 44.80797229274627, 47.66941978085426, 45.43281370593656, 42.020555619270574, 44.83457772962509, 44.74577526892386, 40.84800620232859, 41.015365892840975, 42.43769184235604, 42.1780897725013, 46.763320892087876, 42.649280178931456, 45.296511342448575, 42.27020663599814, 45.462329541483236, 44.1724737997978, 42.60179204325522, 44.029785817669286, 45.71781704502721, 42.94677626702094, 35.710803462613015, 37.314923424874586, 40.18964029127552, 29.770152222725656, 19.500749726449293, 23.47647197784916, 47.22146549532491, 57.78247464087702, 48.34551088271603, 38.22105369260235, 32.31053213919363, 37.20173558881206, 43.13088447816911, 54.82683927782121, 60.211724004437855, 62.124793375692065, 57.2928177156756, 55.64487703384892, 49.147549290810865, 51.61663032347157, 50.76851191059236, 59.33937318863408, 58.998095604681204, 59.60249754690356, 55.874571031139745, 62.24715955795781, 58.29310447938981, 58.998534910140506, 49.54002165025281, 51.616512652366396, 50.89214501842376, 51.338393072928156, 47.98726120302754, 49.865794104914514, 48.905213494454664, 52.06514550793556, 48.762458832033225, 54.580600723143554, 54.7993395405431, 57.52512793387137, 58.11521322496476, 63.21295692074684, 60.90352027646957, 67.881103023406, 64.87103300709879, 72.23034474157518, 63.15552165431362, 66.09163930339199, 5.753542905853641, 0.5024553432820306, 28.273560116367957, 74.07587482083228, 53.75236480466781, 47.05908721493137, 38.287396661696896, 40.461358562592544, 40.1112203444204, 40.104473867724025, 41.19850135618641, 74.28522740640949, 32.55384852809291, 43.297636201304776, 87.72562888360794, 25.095851921266128, 0.8182416579896404, 0.2142979435983204, 0.14509431026395292, 0.20513946971585675, 0.10626240122702815, 0.0155333423941967, 0.17865124428945203, 0.19199736927065159, 0.2103790821086976, 0.3624324891115389, 0.9519638986356798, 22.861312935429236, 93.17226348384735, 80.90444672492244, 76.47122706136396, 67.20400779478013, 41.84349198495188, 45.85049906084615, 82.63461205267137, 39.89053995378556, 34.36771723531908, 56.61683251780849, 49.28034113299463, 67.68275660853233, 74.73877891417473, 66.2512170114825, 70.78997981163764, 18.258727289015248, 0.6047059259107036, 4.20712395060447, 27.800543846622592, 68.9108899331862, 67.57484436035156, 71.53601461841215, 65.28724355082359, 67.90160917466687, 58.37759625527167, 61.30653988930487, 55.305368438843765, 61.031177736097774, 53.81111014273859, 57.82213764805948, 53.9849417440353, 55.88338067454677, 53.38297167131978, 63.94524382006738, 62.31971163903514, 66.38260072277438, 65.73205209547474, 67.70159183009979, 63.870020604902706, 68.28289493437737, 63.198330402374275, 65.35286480380644, 64.86872665343746, 60.215399265289314, 56.22130070963214, 64.20804654398273, 63.91968565602457, 60.92488542679818, 55.622088063147764, 56.467998181619954, 60.55868902514058, 61.147754499989176, 65.57691058804913, 63.8772181541689, 60.08394102896414, 56.93000631947672, 59.87318031249508, 55.81006765365601, 58.55323999158798, 43.43973975027762, 29.965858882473363, 32.58614140172159, 43.760279763129454, 42.963003112423806, 47.40358506479571, 46.440082288557484, 51.84874834552888, 49.874313492928785, 48.94143266062583, 48.894532880475445, 48.56249247827838, 54.033567367061494, 50.37331350388066, 47.69085553384597, 47.86453416270595, 48.372081018263295, 47.097153817453695, 49.959177893977014, 46.11375285733131, 46.16847776597547, 48.61912758119645, 49.06076685074837, 49.20442365830945, 45.69592237472535, 48.389994482840265, 48.85337545025734, 44.50454558095625, 43.53311569459977, 45.673400125195904, 46.541910940600985, 50.538853214633086, 45.7522201538086, 49.34692336666969, 44.60334616322672, 48.06650876998902, 47.29366064071656, 44.25246661709201, 49.39145011286582, 49.02568124955701, 45.919677903575284, 38.57476126763129, 43.49108357583323, 49.79095528202672, 41.31112437094412, 32.33624131448808, 29.30382359412409, 49.86138143847066, 61.648994184309444, 54.07395209035566, 50.233657513895345, 45.17145049187445, 48.12511290273359, 51.120854500801336, 58.39781607350996, 58.8352309503863, 58.501080313036525, 57.78421617323353, 57.00921074036629, 53.26863850316694, 54.056528922050234, 52.77610255825905, 63.08104761185185, 59.94215519197526, 62.094928449200054, 58.71880715893161, 64.4179404166437, 60.978280651953916, 60.28464871068155, 50.71243770660893, 55.13032090279364, 52.86672499872024, 53.21722015257805, 50.53888459359446, 52.746300389689786, 48.65443675748764, 54.5631383311364, 50.316968656355336, 56.98345645781487, 57.37114744801676, 64.70768982364287, 62.167111827481186, 67.5499451544977, 64.24052769137968, 71.79194927215576, 66.20649414677774, 75.23683363391508, 65.05536479334678, 74.08095036783527, 9.122151386353279, 0.5901011031481528, 32.20526945206427, 80.39824916470437, 62.61507788012105, 56.45050048828126, 47.82567131903864, 47.19851178507651, 54.262641629865094, 44.36382270628407, 61.2246996356595, 71.1553015247468, 51.65255923424998, 67.62343468204622, 104.86942245114236, 27.18539853249827, 1.152775768310793, 0.2645163093843768, 0.2647542869371753, 0.33308191405188653, 0.27601207155854474, 0.14566910603354055], [0.03340978002656372, 0.013815291590177485, 0.06622722853095302, 0.06437276715352651, 0.04542749322530243, 0.06783617405040611, 30.878345351065363, 59.08078701265397, 48.08665406319403, 44.84498377769224, 29.658299953706805, 18.39759684378101, 28.798039843959195, 55.17152540145382, 25.401526151164887, 32.686361881994436, 32.14350388896081, 44.25612226609261, 58.65424886826546, 55.00010998018327, 58.528211347518436, 19.71394427361027, 0.10997000631065139, 0.9288767665143937, 3.4454256488430888, 38.89254385425199, 50.80815530592396, 64.63132127638787, 59.090188933957016, 59.5234029523788, 57.57138444531349, 56.94996333891346, 55.08418598482686, 53.7096070474194, 50.07506432071809, 50.14850285745437, 50.905273191390506, 50.03835878064556, 47.31142505522698, 48.271558515487186, 58.66357234216506, 59.60853407459875, 57.81201793301491, 59.79756878268335, 57.74774989774151, 55.82620428454492, 57.21480569531841, 56.920690690317464, 57.915764624072665, 59.71727394288587, 59.14382342369326, 59.57886526661535, 59.66438862585253, 57.954701992773245, 50.83610219340171, 57.17334232022686, 55.88813066482545, 57.386609431236025, 53.5916260750063, 61.35417707504765, 56.49362694832587, 58.56104943060107, 57.00048346673289, 52.83474199233517, 49.66660438045379, 46.58022857481434, 35.37198128238801, 24.42601896101429, 27.143931235036543, 32.18198430153632, 43.10947225939843, 40.949721105637096, 49.978625005291356, 45.043102695095925, 40.64199547613821, 42.40388885621102, 41.25152787854595, 42.87197666783487, 47.48104403095861, 47.492987648133315, 43.940626421282374, 44.21885974945561, 41.20574989626485, 39.39426206773327, 41.04552499709591, 43.88075144060197, 45.34538799716581, 43.58364758952972, 42.19976871244369, 41.60061882388207, 40.93270194145941, 42.01777858118857, 42.189119477425855, 40.296787677272675, 40.263306325481786, 39.43354460500902, 41.06433276207217, 44.82734880139751, 43.58025866170084, 43.56501633121122, 40.9004561362728, 40.831987242544855, 38.975400001771995, 40.91860494306011, 40.772853589827015, 35.68935986488096, 31.512571034892915, 31.78060816180322, 20.568966057992753, 13.721194151909122, 15.746700225337861, 25.538814990751206, 49.93196056735132, 55.98613108358076, 53.61328932546801, 49.11060056378765, 46.08513132218392, 47.274005643783084, 49.77124144954067, 55.12983845126245, 57.860871053511104, 54.19076419645741, 55.016485875652684, 52.97299377379879, 50.12116785972349, 45.356731491704146, 47.38906052804763, 55.0805107239754, 56.9452957184084, 56.04266028250418, 56.33762644183252, 58.38264434568344, 56.58180575216971, 51.82506115205827, 46.57333304805141, 45.25780147121799, 45.97441065695978, 44.9634511240067, 44.489181656991285, 44.35080828205232, 44.40862794076243, 45.38710240394839, 43.89285195258356, 49.97521646561162, 50.493090921832675, 53.38485440900249, 56.15009007915374, 58.169443914967204, 60.57623378692135, 62.537905246980735, 62.720001282230506, 65.80627118387531, 64.54506835629864, 53.93146807147611, 2.543363859576564, 0.6194396353056354, 29.543890299335605, 66.19898673026793, 37.29546454644973, 33.469576835632324, 29.038467407226566, 23.703808630666426, 51.83581236870059, 24.777194646097, 43.98451774351059, 36.59170504539244, 40.994330221606845, 65.79770472741896, 55.91507734790925, 0.07749648148854894, 0.04914779621627062, 0.015891910804766082, 0.09717830682113286, 0.014821368048057683, 0.025592622677645376, 0.030305532385565104, 0.049032155244100484, 0.021269795364670215, 0.050714407717027975, 0.0600690996995376, 0.17658122875277074, 0.9100112078651306, 53.49885809806086, 69.14391010038315, 55.28367773179085, 49.80466788814914, 26.47633598696801, 16.907827700338057, 45.25308678227086, 57.744666914786066, 28.383780679395123, 38.11349053536692, 35.66350752307523, 55.91982341581776, 62.57572866255238, 66.46006753367763, 67.50314343360164, 27.4624002364374, 0.1971465220013934, 0.6590281174548211, 8.325549383317272, 54.31451105302381, 60.44321836963777, 72.16272307980445, 63.36043411685575, 64.11083844400221, 60.70587204348657, 61.54691842294509, 60.965729067402506, 59.90692838545769, 53.4041367807696, 53.83851574313257, 55.70057469029581, 54.51158269759148, 49.64237197752922, 53.28061742167319, 63.02264744235624, 63.09907482516382, 62.100741401795425, 64.30337190628052, 63.51323396928849, 60.784974482751664, 60.37453766792052, 62.58430688611923, 59.882260599443995, 64.41282956830918, 61.56233333772229, 60.69044143922868, 62.41455847217191, 60.86301788207024, 54.87584144838395, 57.43992228661814, 58.45935413914343, 59.34141282112368, 55.6877250056113, 59.04730566086308, 56.72761594095538, 60.19353205157865, 58.3280880989567, 56.80751069899529, 55.34122674695907, 47.92995537481001, 42.55675931130686, 33.17230432264267, 31.157608301408832, 36.889899315372595, 44.948577496313284, 44.58299690677274, 53.854197379081484, 48.2094281719577, 44.29500079924061, 46.476305377098825, 45.4993567159099, 44.66289558718282, 48.419855486962106, 49.53869196676439, 46.72370887571766, 47.96322884098176, 44.9069768382657, 43.250144143258375, 44.002027203959805, 46.85468073814146, 47.43777244321762, 47.4413888685165, 45.124982172443026, 43.50525902163598, 43.12815450852917, 44.01562213897706, 46.42860935580346, 44.100741494086485, 41.66227456062071, 42.16650309101228, 43.177031163246404, 45.805646757925714, 46.034348395562944, 44.918253652511105, 44.11458746079476, 42.894545985806374, 42.56749091609832, 46.28121845183834, 42.687915525128766, 39.64549772201046, 34.443956344358384, 34.911243992467085, 22.37364661309027, 18.66445725963962, 24.775421734779115, 36.76465411340037, 54.996442564072154, 60.38024863889141, 61.59382604783582, 58.73322971405522, 56.428056686155266, 58.88474695144161, 59.47504797289449, 61.79407873461324, 60.76287584920084, 57.99354522458969, 56.16395958008305, 56.02384859515775, 53.95822648079165, 49.56590929339009, 50.63241351035334, 57.673052280179924, 62.04167442937052, 60.20829585290725, 59.17975625684185, 64.01641130447388, 60.332603608408284, 58.69434725853705, 50.24543639152281, 50.72307125214608, 48.7282596865008, 50.243800763160955, 48.75721070074266, 48.74155652138495, 47.615396976470954, 50.99116133105371, 50.475153923034675, 53.1236167107859, 54.58966532061177, 61.12323184167186, 62.17149703733383, 64.92548334983088, 67.0160399713824, 70.3069007012152, 68.6961401662519, 72.53546591727965, 69.54487831361833, 58.9155375572943, 2.1959166324907735, 0.6599465649454825, 35.54424001324561, 75.19485642833095, 43.007196457155295, 38.93103407275292, 31.320280759565293, 31.915692629352694, 55.16799919066891, 35.529684097536155, 44.117074243484005, 51.80972468468451, 32.22626001604142, 71.7075006423458, 58.80717423654372, 0.17096272459433925, 0.005307090374821377, 0.02626640849836892, 0.06519877081436497, 0.05984256366988825, 0.013724903748821349, 0.020542180375947107, 0.12784291419290728, 0.07569263554027966, 0.16071565509323152, 0.26454137578125925, 0.21929050795733931, 0.4059201442906934, 50.83962840418662, 86.13292694091798, 69.01077701199439, 59.53345990950062, 52.076069308865456, 27.43507112226179, 49.35909055894422, 67.92598278291764, 39.26420803992979, 46.21987650471349, 42.892490663836085, 59.734144056996996, 71.11308897695234, 70.91718227632585, 74.31644947298112, 29.592986606782485, 0.23994046924335344, 1.779886150071698, 28.235593534285023, 65.81715183873331, 67.20742810157039, 74.65941367610809, 63.93786584177325, 66.22558824477657, 62.68244851020075, 61.56899352227489, 60.991098957677046, 58.23514361535349, 53.24677913419662, 55.16861108041579, 55.742944132897165, 55.99691760155463, 50.30210679577243, 52.587432630600475, 63.990578574519006, 64.4380739427382, 62.69448626425959, 63.855460766823064, 64.67830342631187, 59.44856020712084, 64.31642947658416, 63.0705984177128, 61.468749507781006, 63.906769291047134, 65.73607252490136, 63.7685763451361, 65.32576907065608, 63.21716562394173, 57.373975476911, 62.07632856984293, 62.34115523676719, 62.43681400052963, 59.54385419045726, 62.34939613649922, 60.33887155594365, 61.855710937130844, 61.29807149210284, 61.8841951893222, 58.6314324409731, 52.23806711935228, 47.89168873140889, 38.602331607572495, 38.94032616769114, 42.52354860305787, 49.78688778415803, 45.355127242303666, 53.32494020462037, 51.93104751648442, 46.04674308530746, 49.840792917436175, 47.73670411879017, 48.04781475374776, 50.69821126999394, 51.8911099433899, 49.86101665804463, 50.86340188980103, 48.0545533857038, 44.67624341287921, 47.41370085747012, 50.308213926130726, 52.061685977443574, 49.11595459907286, 48.153200995537546, 48.176378280885764, 48.85451685997748, 49.21909724512408, 48.64742748198971, 44.81135729820498, 44.24571229565529, 45.639114687519694, 45.609053642519065, 51.2326616625632, 49.99248666148032, 47.085225889759684, 48.05686366173529, 45.037984002021055, 47.82324729427215, 49.55776645291237, 46.43113143982426, 41.14743209654286, 38.66058664937174, 41.40591629089848, 37.62166453946022, 29.507729968717022, 30.294174994191817, 38.70672941207886, 56.24006925090667, 61.33220787971251, 58.48163712409235, 56.45274800638999, 57.90660981209048, 57.166019255115145, 58.26880539617231, 59.55666465144004, 58.30875473637735, 59.79845916071246, 58.44797926564371, 58.9096853809972, 54.67321965002245, 51.32677501247775, 53.87844154911657, 59.37116792125087, 63.981984661471465, 62.461426873360914, 60.18798974252517, 65.07302330386254, 62.01380206692604, 59.83199150331559, 52.95981853238998, 52.279240239051084, 51.21877647215321, 51.69259878896898, 51.13922296031829, 50.84561786343975, 48.32390254543674, 52.38811346792406, 52.01189148810602, 59.14978150398501, 56.10267254614062, 63.88042273059968, 64.51733719918036, 68.2791216142716, 69.3745925349574, 73.3468552558653, 71.02077991731706, 75.10967039292859, 70.40337531797348, 66.71838698848602, 2.9886886862016495, 0.7331227931764819, 37.954403123547955, 83.52468413691368, 50.99511900255757, 49.82842960665303, 38.43064162038988, 39.517926554526056, 70.90145357193487, 36.10844942831224, 66.58363788358628, 53.05803860387495, 56.285984516143806, 83.5852926008163, 71.36110828768823, 0.25544156891203695, 0.1370937629572807, 0.19168917209871356, 0.1548088720488933, 0.18300953381244214, 0.1289778887744873, 0.14036436084537737], [0.030361002896942442, 0.032874989368382006, 0.05415576660344678, 0.07294303872772763, 0.04180840194045056, 0.08404710780709021, 1.7000660396391347, 46.18436336517335, 62.25076813851634, 46.736111410202525, 41.35146594816639, 31.313134201111335, 26.919350047265333, 52.24142074584962, 32.12473730887137, 32.0880219628734, 31.30322237168589, 30.03250583525627, 59.00535591187016, 57.110451036883944, 67.91105424204181, 34.418633522525916, 0.6605498132205779, 0.13817649034242477, 6.327605805089397, 31.2147395841537, 55.62331184264153, 59.78227153901131, 65.32124265547722, 59.26566793072609, 61.45174211071384, 57.36534234016173, 58.49077232422368, 57.2254902316678, 54.136003986481704, 49.0802021949522, 46.70383422605453, 46.68666601181031, 48.7684129899548, 45.30857655309862, 49.8100729142466, 52.61553641288511, 54.46492218202161, 53.43731611005722, 53.53089209525816, 50.87574558873331, 54.57542711688627, 54.84193255824428, 60.35926003609935, 57.47359583454748, 61.09531241078531, 58.70318828090545, 60.18010577847881, 57.94106783405427, 55.97659580169186, 49.62342692959694, 50.2541518980457, 55.223555641789595, 59.342479705810554, 58.22842459524832, 60.02257554761825, 61.666017270857296, 56.22568984185496, 55.24636814671179, 49.76746028469455, 51.110636726502456, 39.39918464229953, 33.50113230366861, 25.737753683520904, 26.1709382841664, 38.644634369880926, 40.70365905761719, 50.816815899264434, 48.1026691006076, 39.496302527766076, 44.72127614482757, 43.50225448608399, 43.342151180390395, 44.82396771830898, 43.12266711265811, 42.00622327866093, 41.86263707376296, 40.48379451997819, 40.50364171305011, 38.88194168767622, 42.607546160298014, 44.553520294927786, 43.5411447863425, 41.05580160694738, 41.67956044597011, 43.55793645305019, 42.907360369159335, 44.7422412133986, 42.94247734931208, 40.81379921205583, 40.33587801840998, 41.7649543669916, 42.99094999990156, 46.3674674495574, 42.45482083289854, 39.36476584403746, 39.1307258605957, 38.73499793391074, 39.48269190326814, 40.56110443607454, 34.15783905213879, 28.93952758081498, 20.65638392202316, 7.729232426612609, 13.45144687160369, 26.67649845923147, 43.49130715093305, 48.89141851855863, 49.33507388637912, 51.158042492405066, 52.24715525104154, 51.91100812727406, 55.905463618616906, 54.55325003593199, 55.40639692737211, 56.13689914826424, 56.05708283762778, 54.405545342353086, 54.66183300941221, 52.373404579777876, 44.73640080421202, 47.41543454508628, 55.880576179873565, 55.178452307178134, 55.82237997362691, 54.703237548951186, 55.23228683779317, 56.303352771266816, 52.377472077646566, 45.73689153117519, 45.65174864184472, 45.329208220205004, 45.38268189276419, 42.49182839547434, 44.980740931726274, 44.47266063382549, 48.9134975402586, 48.01521985761581, 50.52440712528844, 53.43458221804712, 58.123571795801965, 60.22701732573971, 61.563494359293294, 64.0577805426813, 64.50376579838415, 65.84228638679751, 68.72503234494117, 67.75858386870354, 49.12741576471637, 0.2782255447199268, 1.7264228963082837, 43.10885644728138, 64.91844661774175, 38.5509564030555, 33.998461384927076, 17.555328646013816, 31.893344925295924, 45.77331073822514, 23.108041786378433, 54.214678887398016, 38.402761413205056, 50.81501945372551, 75.33745027357533, 9.55924560946803, 0.3057840256200683, 0.1510559605254281, 0.08560587456750293, 0.1531541987412399, 0.11886414155484208, 0.08304203875483045, 0.051657722421711495, 0.03674845631805159, 0.06102967436515516, 0.020311204866776546, 0.08935020590621619, 0.041288442744482914, 0.19890328418583642, 5.679114951241401, 63.746579693209746, 72.91766951161047, 52.57148819585001, 44.724245379048014, 30.63797466216549, 20.798860096162368, 63.29071006467266, 36.99129258432696, 35.78301821985553, 31.47272171512727, 40.63110305416969, 66.10492829353579, 65.06461766458327, 75.70195613368865, 41.480629597940755, 1.0840265476895918, 0.060987784677455505, 15.119776033586072, 47.61877021481914, 62.40956921731273, 66.78749915092223, 69.82362547228414, 64.86079954331922, 65.48325615544474, 62.57217499517626, 62.19164625290902, 63.19146233220255, 60.14286679606284, 54.36088131320093, 51.22350685058102, 49.88484113447128, 53.46751051564371, 49.7543909472804, 52.534147231809555, 55.651643122396166, 58.23136637287756, 57.504413896991366, 56.572807834994414, 54.484902735679384, 57.05010929415303, 58.55600526255947, 63.28845862419375, 60.429317489747085, 60.41652664061516, 61.32136252618606, 60.73758048395957, 59.48099428607572, 56.42728005686114, 51.42266519608037, 51.817706707985174, 60.60033282926006, 62.52724816722255, 60.43616987043812, 65.07744773741692, 62.429867482954464, 60.10128574986612, 56.63343198837773, 52.28928150669221, 54.37726897578086, 46.659240799565474, 38.58414749945364, 33.34541028545749, 29.583141457649972, 44.779746916986284, 42.87677764892579, 54.242649309096805, 52.16380488487982, 44.32283786035354, 46.5666179503164, 46.03114381913216, 47.44698216838222, 47.19740959905809, 45.94931141022713, 45.477591483823716, 44.44230541106194, 42.30939111401958, 42.32806159603981, 41.895506535806966, 44.41427223144039, 46.318418210552586, 46.33563349323888, 44.532770956716234, 43.03004818577921, 45.96920959411129, 44.51241385552191, 46.118989221511356, 44.26163319618472, 44.747136331373646, 42.11197037850657, 43.126240391885084, 44.90107367115636, 48.110470694880334, 45.056309315466116, 43.60088640643705, 41.14467074794155, 43.32308846135294, 43.523148951991914, 42.086498506607555, 35.69105825116558, 33.6930577985702, 24.602378529887048, 12.20690921429665, 21.982658870758552, 36.65487873938776, 52.49766134446668, 51.73837677125008, 51.50269331470613, 52.71745920181275, 55.995780114204656, 58.990780384309836, 61.558732601904104, 59.80077335911413, 62.91337413172569, 59.37985989355273, 60.39611462623843, 57.26659667107367, 59.53349521083217, 55.674286965400945, 51.95021221714636, 50.7972118931432, 59.30351488051876, 58.74338865280152, 58.926084810687655, 58.48479070971089, 59.8438488283465, 61.137415132214954, 57.172098928882235, 48.67224431806996, 49.111106549539876, 49.51077253587785, 48.57189832195159, 47.59167055929861, 50.93530677979993, 51.02434066034133, 53.08205135406987, 55.121934875365234, 58.6069490063575, 57.855948478944846, 64.20004883120137, 65.87258277400848, 67.88602952034243, 67.44397055718207, 72.16335065903203, 72.3249444653911, 72.7760954826109, 70.91839821107926, 49.28473026521745, 0.12210929000209417, 2.9559692548167322, 50.74099256146339, 73.1778952383226, 43.692297243302875, 41.616304382201164, 22.078556899101507, 34.73349786573841, 55.71442850174443, 26.723633581592193, 50.73699174388763, 45.04933926366991, 46.566033517160726, 87.62657334727626, 6.45643703399166, 0.2544194850469789, 0.05723783791425729, 0.03693743871765272, 0.09335940448387016, 0.09156682002808779, 0.03223138741187511, 0.02306922673127584, 0.22833720961165047, 0.15586800392596953, 0.23349178624489617, 0.19171125075269133, 0.20969976130272114, 0.3080753639580742, 3.6073423152969735, 67.45245072149461, 87.44082558539607, 64.21790346022576, 59.17385308973251, 49.28306325789421, 33.932695004247854, 71.99447693363314, 44.0496761568131, 45.97874879837037, 41.86938355045934, 43.05109562412385, 75.54473969244188, 68.65215470713954, 84.88373048843877, 42.584329651248076, 1.1469394040684546, 0.344109719078387, 28.59764006830031, 63.09192042196951, 68.57569986774077, 69.13785396083709, 69.52736100842877, 64.65886808210804, 65.62737972505631, 62.99218631559803, 62.50685576469668, 63.60649224250548, 60.66057651273666, 55.74208513382943, 51.89199639904884, 52.576701025809015, 55.5189807184281, 49.79472075739215, 54.39701810959847, 56.89116701003044, 60.09713195985364, 58.88899095596806, 59.67634008776758, 55.425459646409564, 59.61047564783404, 59.880621048711966, 66.10753274733021, 61.37109817997102, 64.87327268046718, 63.75999812156924, 63.610853918137096, 60.43051381264964, 60.58598479916973, 54.107264780229144, 54.08959842497303, 62.555002858561856, 64.00636611446258, 63.39150713336084, 67.8367567062378, 65.16432823673372, 63.16781436243365, 61.277169181454575, 56.911253467682876, 57.59992361068726, 50.2146928541122, 44.27678923453055, 41.89997019306306, 38.811754795812796, 49.337258646565104, 46.31639818991385, 55.42442806305424, 52.25343888805759, 46.359865896163456, 49.66630235795052, 49.500743035347234, 48.635915325533965, 53.39566053882722, 50.33651382692399, 51.32132684030841, 47.09226654421899, 49.288013289051676, 46.61950718971991, 45.71036454169981, 46.81702598448723, 50.58063822407877, 48.51637717216246, 46.97456406008813, 45.13007733129686, 49.734273110666585, 48.06647739102764, 51.027313816931944, 47.8366853344825, 47.77794784115207, 44.959199274739916, 45.970398072273504, 47.975223448968705, 51.51543709539598, 47.1078932669855, 45.60883006741924, 44.19365852109848, 46.213588945327274, 47.267984805568574, 46.0222831849129, 39.43166186732631, 38.97417622227823, 36.212984515774636, 18.65123494978874, 25.965162900186357, 39.682858297901774, 53.67939302998205, 55.71268696938792, 54.446714539681714, 55.474861898729884, 52.9772573901761, 54.17222315265287, 59.30052603444746, 58.26496931814379, 61.51589247488207, 58.655456958278535, 58.741137212322606, 60.30198558684319, 62.213132996712964, 57.31223344802857, 53.195125441397394, 54.82962023827338, 61.76096608561855, 60.44462650052963, 62.71535327357631, 60.59997589357438, 61.78927775352233, 64.0366703464139, 57.68659230201476, 50.95202784384451, 53.23009337148359, 51.3876501975521, 53.56000392667709, 48.868625625487304, 53.00483557485765, 51.29676888065954, 56.27385262520083, 56.31728503011889, 59.5452505542386, 60.87951144864483, 69.19297110649848, 68.67850518995716, 70.07346476277998, 70.22322870069935, 72.75295349859422, 72.72955263814619, 75.71727691158172, 71.47034629698723, 56.3282637442312, 0.4786847688017353, 2.8064036417391995, 52.2907994639489, 83.62885444395005, 49.90686916535901, 50.17980337142945, 25.195378142018473, 53.078081915455485, 62.46096011131041, 32.59504322082766, 74.31480207750874, 61.69675296352756, 65.83128806083434, 103.59071408548664, 10.391195031904406, 0.4567643273020945, 0.25175429580192416, 0.1880450297387377, 0.16431545628415, 0.12333660882206694, 0.15843246793073995, 0.1458191826579071], [0.033142491949782256, 0.06228654502680706, 0.06394077783390399, 0.02499852532280549, 0.10036509469031327, 0.07027344447710822, 0.254035062126575, 6.06919760665586, 50.568631848981305, 59.18516912767964, 37.9030789098432, 20.707447298111457, 33.94445427002446, 72.75986471483785, 28.18418695080665, 27.866928000603956, 35.523553432956824, 22.051655323274677, 55.169964298125244, 57.897898227937766, 64.9409374883098, 46.506076166706706, 4.002948648506596, 0.14218291568179287, 6.590181031534749, 33.27546265817458, 47.70665091852988, 61.86055506429365, 61.45970452216364, 66.84327525477256, 65.08067192569857, 64.5401575488429, 61.12015670345676, 59.840581493992964, 58.16493318926904, 52.76598676558464, 47.581437095519036, 47.854634100391024, 46.93290456648796, 46.722492940964244, 46.62708520889283, 45.98584436601209, 46.46707996245354, 49.23683812541347, 47.21289903886857, 48.55357300850653, 54.02276908197711, 56.44677031424738, 60.13954062615672, 57.910469424340036, 59.67362580760833, 60.394231888555716, 58.81837260338568, 56.32691052652175, 52.3506469880381, 50.682729674923806, 53.09591301025883, 57.26162310569518, 59.937475804359686, 59.456914855587875, 65.34596143230316, 57.78040755179621, 57.917102152301425, 51.5762887462493, 50.41350210866621, 50.45147065193423, 52.351066681646536, 36.68368070356308, 33.0178923760691, 24.85244139548271, 40.47733829867455, 39.616911488194624, 44.72448464362852, 47.782748822242986, 39.69090307912519, 44.359657149161066, 43.71934198564099, 43.73172490827499, 42.488117833291334, 41.99637028478807, 39.48752034095026, 39.25126421836115, 39.45987155360561, 38.33375907713367, 40.65268393485777, 40.24568311629757, 42.41047843810051, 43.571441173553474, 44.97410035902455, 41.57389571589809, 40.999554818676366, 40.74735033896662, 41.932592545786214, 41.112495545418035, 40.85356812323294, 42.4639089645878, 42.157885643743704, 41.21724636323991, 42.334153036917414, 41.92528517015519, 39.230326606381325, 39.005908196972264, 40.383683866070164, 39.4845118830281, 38.116620586764434, 32.15951696518929, 25.710559891116237, 9.826315872130856, 10.007330313805612, 29.88565229600476, 37.10752417964321, 45.52818221430625, 45.76008058363392, 44.48752641677857, 45.94052922341132, 49.353999322460545, 48.0702938572053, 52.71635309342415, 55.39999954162106, 57.50098182309059, 53.33673084935835, 50.66155672073365, 51.840860459112356, 52.41446395074168, 53.24551613100114, 46.62834821208831, 44.47364514873874, 54.592152103301025, 55.84022283554078, 55.955650344971694, 55.19539694632254, 57.40296571485458, 53.40384260300667, 49.82427973901072, 44.98787964543989, 44.69707904323455, 44.8693456188325, 44.820159096871656, 44.23055233493928, 47.53059925571565, 49.585423084997366, 52.169719819099676, 53.06106667364798, 56.53601600277809, 58.58204587813347, 61.08170963102772, 60.295160662743356, 62.275526139044, 62.707128063324966, 66.70310543429467, 66.34635802238219, 70.86695240389916, 67.78411849852532, 16.77564774790118, 0.7444404858735301, 5.535013444962041, 50.454620315182595, 56.05572569754816, 38.53516101837158, 36.18091913961595, 12.861293919624822, 38.393594834112356, 47.85747389639578, 32.78606264821945, 58.320408098159305, 50.34421736194242, 65.24217551754367, 39.877521607183645, 0.20075167048602335, 0.06998698121958202, 0.024698222686927167, 0.014255483796249234, 0.05001274778717949, 0.009275211317975436, 0.06587215443892826, 0.060908054076736017, 0.01798012763291838, 0.06261455706290661, 0.05220820256058247, 0.1033671327956742, 0.037804278695294936, 0.12788298059134715, 0.3118234950928919, 12.5703707433516, 69.84876002034834, 66.55658921887799, 41.77482697271532, 26.35453070363691, 24.402551420273323, 77.45782867554696, 34.15261053269909, 40.63045586309126, 35.64059303652856, 26.84477794554926, 62.35683687271611, 63.27510295375701, 70.9626268571423, 51.122729393743704, 5.9683318964896666, 0.21205715174155854, 12.544811598716244, 50.37022659855504, 56.50881828800325, 68.56718047972649, 66.92631967606084, 69.80743392821282, 68.28914719243204, 68.01660522337883, 67.55810368445613, 64.37360586658602, 61.637909566202474, 59.99246743417556, 53.10034136618338, 49.160383286014685, 49.93848739131805, 51.04478405367944, 49.93867566508632, 50.19890139179845, 49.94796383765436, 52.153159572232155, 51.52391333733836, 52.424681725040564, 57.35338695587651, 61.3967034124559, 61.43041618408696, 59.77776081331315, 62.16097331816151, 62.710140443617306, 62.53537139584942, 60.38346890480288, 56.258069007627434, 53.22654362647764, 56.76771433122697, 57.859498223950794, 62.48505915364912, 62.95530034649757, 61.582498242778165, 59.371093396217596, 59.09234231518161, 53.60314999857257, 53.21095220504269, 53.022956925053755, 56.21464444744972, 43.78052703795895, 42.30898710989183, 34.29167032241821, 44.93132298992526, 41.16512983076034, 51.39315720527403, 51.606494918946304, 44.00772640782018, 46.72922372817994, 45.425051335365545, 48.83581892136605, 45.69831109816029, 46.41601854755033, 43.871325985077895, 42.30620222706949, 42.038453394366854, 41.08770224355882, 45.49350846198298, 45.13546274554345, 45.39240937079153, 45.98918230302873, 46.89655596210111, 45.480513649602095, 43.439261221116595, 43.850074583484286, 46.35085621187764, 43.264299977210264, 43.57125682215537, 44.04578516560216, 43.21614896097491, 43.47004005985875, 44.39153032918131, 44.07395170580956, 42.16589904600575, 41.982779272141, 42.76595500207717, 43.86160635179089, 38.91989454146355, 34.93841032828055, 30.36211044557633, 17.675227657441173, 19.849934808669552, 38.07501600634667, 47.197080119963616, 48.48822239906558, 51.624714328396706, 48.97847552453318, 48.52442587575605, 52.10153725839431, 52.261052208562056, 54.50505195125457, 57.196754947785415, 60.30117757858769, 57.73870883449432, 53.3857879331035, 54.71891526252993, 56.97831030814879, 56.582558847242794, 49.44632407157652, 47.20698018227854, 57.70423120067966, 57.499640372491655, 58.98254340694797, 59.155535621027795, 59.98282624829201, 58.666208174920854, 54.27568743305822, 47.92014944937922, 50.45988805832402, 50.267813513355875, 49.13131852303782, 49.08915304368543, 53.07573633809244, 54.11940451591246, 58.87148541788901, 59.60664349217569, 63.470354618564734, 63.95562241154333, 68.5490434400497, 66.72169746891146, 67.5521416817942, 67.8957256194084, 72.62466845973846, 70.61506563617338, 76.28362009602209, 67.8287236921249, 17.54033930840031, 0.9608926840366857, 7.039155623605175, 57.223568270283366, 60.95018079203945, 46.68670523551203, 41.1418858651192, 14.721447575476862, 40.24850330045147, 61.31747545734529, 31.22756769580226, 54.31937479203748, 52.2848766849887, 73.333691781567, 38.32738914797383, 0.45129841253642117, 0.11802732073251279, 0.10097429546858035, 0.07658006413088692, 0.053917490276357824, 0.04118916541037541, 0.03746993111206159, 0.03618082730099559, 0.12836098115170194, 0.10201258975411616, 0.18184290447783086, 0.151213115802215, 0.20149120580284827, 0.21195743773733416, 0.3034978047493966, 9.765633863787498, 78.23670941014444, 81.55640740548411, 52.64693890848468, 43.006682626662716, 42.60203523020591, 89.47563355968845, 37.71122009523454, 43.559089629880845, 48.145360177563084, 31.583428652055805, 69.56682005236226, 70.85334177940123, 77.4482031791441, 56.069748170914195, 6.1612301391939965, 0.4240223422886864, 19.64360244812504, 65.36230987118137, 63.13385448148174, 74.84869941588371, 69.82502968080583, 72.9589093116022, 71.65774929908015, 69.38795997250465, 68.87504731455158, 66.32125485327937, 63.490394007775095, 61.82385736896146, 55.26291270409861, 53.10434610612931, 53.83589559985746, 52.7849357358871, 54.193019559306485, 51.462551778362645, 50.80042039194415, 54.816252800726126, 51.459837498203406, 54.509252809709125, 58.813324512973914, 61.59984688605032, 63.47928977781727, 61.20804917427802, 64.67063127025482, 65.07714571491366, 63.40297222137452, 61.654128566865005, 57.218881037927446, 57.43279926238522, 58.74225116545155, 61.187213543922674, 64.36066988975772, 66.48022067162299, 66.82968031975531, 62.97787358683925, 62.852961786331676, 59.50326158154396, 56.82445926050986, 59.08828266205327, 60.55059325310492, 48.377387985106445, 47.54896771523261, 40.83260697703208, 52.570993977208296, 44.41839856486167, 51.3548787947624, 51.343692195030954, 46.862662761442124, 48.65878274363857, 48.09571866066226, 50.850705177553245, 48.123928346941554, 47.52069919340072, 47.18876077282814, 46.89395935304704, 44.206033598992136, 45.043757730914706, 47.77835576764999, 46.95113574304889, 50.47263968375422, 52.11276700419765, 51.158701450594016, 49.421773956668, 47.47959275399485, 47.19603284712761, 48.71039721273607, 45.53623091789984, 46.348016415872884, 47.71546448430708, 47.38637370447959, 44.25210968140633, 48.34942148577783, 48.04273136200444, 46.268804150242964, 45.71272973091372, 47.010865596032914, 48.39729793610112, 41.56889077155821, 38.98952837913267, 41.13298992956839, 25.950222592200003, 23.132976293563846, 41.17014261984056, 49.31995707173502, 52.83351036810106, 54.42568279081776, 54.61147369876985, 49.893227161899695, 57.327687586507494, 52.158776406318914, 57.14652507535873, 60.421829685088134, 59.25026086068923, 58.49753841277092, 53.28548900542721, 54.81946914426742, 59.5963982612856, 57.99110551034251, 52.36064510960733, 48.065198698351466, 61.66513865993869, 60.20458136835406, 61.53023658260223, 61.59446147180373, 62.80977649073448, 59.74613474261377, 55.94394991474768, 52.13286130659042, 53.517924739468484, 51.630315473002774, 53.96628695149576, 50.81847113947715, 56.748196617249526, 55.770483093877, 61.16081207029281, 61.14612671636767, 64.7677295438705, 66.836866101911, 72.97477137657904, 68.58971057399627, 70.91686064197172, 67.79982366869527, 74.44292237681728, 70.5134605592297, 75.41128496969901, 72.30210842624788, 24.153361282040997, 0.7468449600761937, 7.140697452329821, 60.00485035680956, 71.62934349429223, 52.88142996449625, 54.93456717460386, 16.181136062068326, 60.699309918188284, 63.40951081245177, 47.88671124366022, 83.5612641611407, 71.73136434247418, 82.19198042346586, 52.63464620036464, 0.5079771211791424, 0.15824898987287478, 0.32924727626865913, 0.14283784424826024, 0.17155581454355873, 0.15995733530050324, 0.17535101412044418, 0.18023819542459904], [0.027385069237601374, 0.03154159801441335, 0.06706201155940372, 0.041316393462400285, 0.05217339918618241, 0.0883581450269107, 0.05297792940250328, 0.3275018215419785, 13.581699959693418, 53.644107387911895, 60.003316710072184, 29.425719091969153, 43.260373684667776, 61.051001394948656, 34.72400180755123, 11.975495257685262, 48.38728020268102, 22.249933096670336, 37.1635042467425, 60.27521541041713, 59.99079650448215, 47.80954645526025, 9.284688522738795, 0.240201797156084, 1.7049338235970468, 40.010058495306204, 52.87142399818667, 60.03567626399379, 61.91545647959556, 61.61998041214482, 61.28718691487467, 62.86197539298766, 59.99445215348275, 59.65150756220664, 53.84999259825676, 53.619859295506636, 46.98297362173758, 46.268749237060554, 46.04777074629261, 46.802862305794996, 46.150407406591604, 46.799473377966116, 44.984196539848085, 46.4253459438201, 44.27817775357155, 50.83654149886101, 55.167328465369444, 60.541885591322384, 63.44876981550648, 55.58602579178349, 59.07608801318754, 57.7706330053268, 58.722890346281, 57.05880518882506, 55.68014306406821, 51.96115955229729, 54.84420361057405, 59.341212780244895, 58.05851144175376, 61.58428684357674, 59.602536770605276, 59.22256108253234, 55.267521489051084, 48.59108655683456, 48.38340882332095, 47.210447557510875, 51.36557902059248, 44.422928902410696, 36.784356178775916, 30.99946814198648, 32.58603157535676, 34.5717393198321, 39.92062061063705, 47.761426817986276, 39.717767392435384, 41.56341122042748, 43.14848023076212, 45.41316655374343, 45.612156237325365, 44.150139824036636, 40.689915072533395, 38.377336609748106, 41.152852812121, 38.17276539341096, 41.107431765525575, 42.1381914231085, 43.1612632351537, 41.40499845627816, 41.68889176461005, 42.850242814710064, 38.56160171570317, 42.82032689740581, 43.006231554092906, 43.560282030413234, 42.24983776769331, 43.22893981010684, 41.857494846467056, 44.314247869676166, 43.62960207846857, 39.22602768867247, 38.64943927334201, 40.220375983945786, 39.9606248640245, 39.49579261964367, 35.64871626515543, 30.788962379578624, 14.692828982107102, 10.574000035562824, 28.26996526410503, 40.59120470477689, 45.14749265486195, 42.586243767892164, 44.738275697154386, 40.127243226574315, 45.73962542318529, 44.07044902924569, 50.399063864061915, 52.157183924028956, 48.46117373435728, 50.88307257621519, 54.19569853813418, 51.21417945431125, 51.65034309510262, 53.26588892167615, 52.018041764536214, 45.1317011925482, 46.49070832037157, 55.87311583180582, 53.81157298241892, 54.83258947249382, 54.35487616446711, 55.95692903764787, 53.22455498480028, 52.57801501981674, 41.76916699255667, 42.946725276208696, 43.385120745628114, 44.394374047556234, 45.69993103704145, 51.93904522926577, 52.87542089339226, 56.46784128681306, 57.70348595034692, 58.77654837023828, 59.17226060744255, 62.16494275677589, 61.59170404557259, 67.81305774565666, 64.45498328055105, 68.49249070690524, 64.29833950534945, 74.9448916219896, 34.92311308460851, 15.217850977374663, 2.0000677868243186, 9.657752994568119, 53.05667361905498, 48.7772108662513, 41.689805676860196, 27.949566456579394, 16.275342568274468, 52.761432893814586, 47.46372676664784, 34.329634943316066, 62.482388019561775, 42.240804549186464, 77.78700182514807, 4.382538228265701, 0.49625760004405056, 0.11541106918406104, 0.08818318586676352, 0.021709799879200516, 0.05373570144236569, 0.08527240415494289, 0.0672815187323478, 0.09417688158611137, 0.06501710838488033, 0.06824532628900583, 0.04352862173090539, 0.0439153658977199, 0.057506091261823336, 0.07567863145302381, 0.0039056838197152944, 0.13025419125633855, 21.632473584144346, 70.00282287597656, 67.86188340956166, 29.283497871891147, 39.991909688518895, 76.09707217062675, 33.106949790831536, 23.116223850557883, 50.65551234829811, 26.60088496823465, 49.867166934474824, 64.62885410554948, 66.96563751466813, 53.53807395504367, 11.405200285296287, 0.2676373209443785, 2.4358654214489848, 50.66673032699093, 63.24160983485561, 67.14179115910684, 65.37533214015346, 66.1294823308145, 66.89182635276549, 68.23115887180452, 64.2754642425045, 64.1816686045739, 61.247594510355306, 59.05684094275198, 52.7135132974194, 52.01426452206027, 50.902480463827814, 50.79882790965419, 50.270574861957186, 51.8236255645752, 48.488391060982984, 49.077468302942094, 48.38956302212131, 52.82562248168453, 60.54557261928436, 63.26656003152171, 65.30107775042134, 57.88717054551648, 61.152751599588704, 60.509863361235595, 62.36513660800073, 57.46641397476197, 56.435528801333525, 53.90317601542319, 57.19763748107418, 59.584890027200025, 61.68133020401002, 60.54621196562245, 62.43186789174234, 62.04758151885002, 58.47253330292241, 51.21380290677471, 49.9048726789413, 50.40005230134534, 53.7829985157136, 50.805782271969704, 41.68682467552924, 37.60293914425758, 36.05052778797765, 36.05897657332882, 43.65427378685244, 55.85532788307437, 44.355240560347035, 44.6662845150117, 45.84073628148725, 48.29567716967676, 50.76834717104512, 46.83569646650746, 41.4480503912895, 39.65371900989164, 43.513162597533196, 41.711719959012925, 43.39172209462812, 44.59778424232237, 45.35838673191686, 44.499344518107755, 44.28299050177298, 44.584903178676484, 39.834234329961966, 43.20774332169564, 44.62276189557968, 45.615439261159594, 43.8807043721599, 45.676141861946356, 43.350690180255526, 45.54704489246492, 45.00669133278632, 41.87369423527872, 42.41532648763349, 44.4415876173204, 43.593833984867224, 43.48684349367696, 36.55103791144587, 32.922821967832505, 19.456111192703247, 18.684210315827404, 35.15949472304314, 48.02572396493728, 50.444351550071474, 47.139746835154874, 49.65322909816619, 45.45715201285578, 50.648569753093106, 48.871743909774295, 57.080056590418664, 56.52473134379233, 52.96662776700912, 52.83780536343975, 58.92572003026163, 56.6704434733237, 55.614545345306404, 56.99184248524328, 55.496525149191584, 48.23769669378958, 51.84994466843144, 60.13850119806106, 58.029026985168464, 58.49215299852433, 57.70133649149249, 59.92106852992889, 58.71429643323345, 55.121770135818, 47.192977320763376, 47.32946403564946, 47.84307095312303, 48.974168762083984, 50.58467826535625, 56.49935753114762, 57.712503479373076, 63.85195809025919, 63.70997221239152, 65.1498507684277, 65.33195072604765, 68.14672593147525, 66.55766394830519, 71.62812755953881, 66.68989489155432, 72.74479496863582, 69.91683667705905, 77.41811859992244, 38.628234940190474, 18.42612816441444, 3.357448111618719, 11.915880134028773, 58.18256032082343, 55.85924633087651, 49.47662438115766, 35.99834065283499, 13.159401897461185, 53.651222567404474, 59.81174030611592, 33.200545387883345, 62.39297759148383, 48.45988327457059, 79.25017141526746, 2.222399740449844, 0.2334006217819068, 0.05228076640877032, 0.04377541312527272, 0.12210051063448192, 0.022188871047429504, 0.01510545643301861, 0.05341868659841919, 0.033818725421423876, 0.15970864783852332, 0.2000681974834973, 0.13500759828715556, 0.24575760467879235, 0.16144343862129798, 0.16723498672006593, 0.23246270033621022, 0.4897133092726431, 21.18111272012034, 83.39631280591412, 88.59619109861313, 48.475266810386415, 60.617442207951704, 74.02496245599562, 46.392923631975734, 18.625531658049553, 67.45994244852375, 31.976585465092814, 55.41754038103166, 70.3771895747031, 75.56674418910858, 60.591801674135276, 12.315652024361396, 0.7152907790676241, 5.296056280213018, 61.743233050069506, 67.16345048719838, 69.6955051729756, 67.56828615742346, 65.47932986290225, 66.83831737887475, 71.41858670019334, 68.05080044654109, 67.40719441444644, 62.32413999495968, 60.98946725168536, 55.2659603857225, 53.388576738296024, 53.741217428638095, 54.65867942379367, 53.99851706720168, 52.48432136351063, 51.45379312576787, 50.426128218250895, 50.264765831731985, 57.66585473091372, 61.86106497241605, 65.48567233547088, 66.76721265239101, 58.61265605495822, 62.45836742462651, 60.75390931098693, 63.56801379111506, 60.23337548778903, 59.82223656869704, 58.35812168736612, 59.232586660692775, 62.413770075767275, 64.30924369442847, 63.32197527731619, 63.94184704749816, 65.79577492129418, 62.695329573846635, 55.6202406267966, 53.34352831686697, 52.86657987102386, 56.864616486334036, 52.29443550109864, 48.34566385515275, 43.98904023631927, 41.1961793130444, 39.421695124718454, 47.53154454692718, 51.93791166428597, 45.80246179334579, 49.88060889705535, 48.59010204192131, 52.00066174230268, 52.78924249833631, 50.10422714294926, 45.60259349884526, 42.16729933215726, 47.666544683517955, 45.05781158324211, 46.5043620909414, 47.19567591144193, 50.47778975579047, 48.78427113256147, 48.556350046588534, 47.381757074786776, 42.79655341179141, 45.67789516141338, 48.17469950645201, 49.42892051512196, 48.99022302319927, 48.66951434843002, 48.31587345369401, 49.49900934773107, 48.70918520035283, 47.1200212355583, 44.59854910450597, 48.424954568186116, 47.385381344825994, 47.79752046831193, 39.28658516176286, 40.45742834767988, 26.089335333916452, 25.291013371559885, 40.974345745578894, 49.81075932902675, 56.91070041348858, 52.008804582780414, 54.95341024091167, 47.851621720098684, 52.618670386652795, 48.7097696335085, 58.35366587485037, 59.030753258735906, 52.79887976184968, 54.94555373345652, 59.149989389604144, 56.07467074548045, 56.273687885653594, 58.32694668923655, 57.06614002104729, 51.94209291088966, 53.84796473287768, 62.58705254523986, 57.757967672040394, 59.803715136743364, 58.59459746268488, 62.73432185572963, 60.125988837211366, 58.8178038597107, 49.60103411828318, 49.82926899386991, 49.8251897288907, 53.23758509851272, 54.01612850927538, 60.36143302917481, 61.21062617148123, 63.36971444468345, 65.9059464546942, 68.75344599446943, 68.4307369109123, 71.53182552706811, 68.74253396065005, 74.60485350701117, 71.66739832970404, 75.14465793486565, 70.07060927729454, 81.19755760315927, 46.553783955112586, 19.92743495971926, 3.0443510413169865, 12.75139008798907, 64.42193731184929, 62.190434240525775, 57.90523698253017, 42.174304685285016, 25.039805173873905, 75.03616517589938, 67.85123025217365, 48.96026395982312, 86.49938614137712, 58.59242054723925, 98.44286211075323, 6.92374135217359, 0.8338113225275471, 0.2539350263654225, 0.32960868590781767, 0.17159221904172053, 0.11469011149939992, 0.2742942572841721, 0.1520634121111324, 0.13778642901489813], [0.060756904929275476, 0.07509417531471099, 0.1777787620742475, 0.03277949267818082, 0.09330393205727301, 0.03944474873283217, 0.04239795639389946, 0.1372003257875481, 0.08338466391808565, 15.648501726888842, 46.983459995638945, 56.736347136958955, 26.874868408326183, 32.85852843715299, 46.83771256477603, 21.462466293765655, 45.80235588935114, 37.0863708373039, 29.68608798519258, 58.24520841721566, 56.23164399977654, 48.30620088884908, 12.543611353443517, 0.0680224100247987, 0.06768449630227781, 27.162558570984874, 54.795821174498535, 57.48329585598361, 64.51341875137823, 63.193607868686804, 63.04405573875674, 58.46880705125871, 62.712246756399836, 60.34442563210765, 57.517447933073974, 52.02278783244472, 47.696299783645145, 46.60365296948341, 48.49219183767996, 46.01426586028069, 43.720059779382524, 43.05885799469487, 44.57661521050238, 43.96476076495263, 46.43282982610887, 48.922181667820105, 58.03333766998784, 57.12841156990298, 61.188245127277995, 53.53876821456417, 56.6784490308454, 59.35355647917717, 59.10812201038484, 54.81860230045935, 51.41491459261987, 55.98120458664433, 54.32611734636369, 58.401099097344186, 60.455989606918834, 59.816976670295965, 60.40960757963119, 58.942609756223625, 53.68828896553286, 49.896384669888405, 47.55530626543107, 46.29057722706949, 53.67437631853166, 52.27736926847889, 45.41403731992168, 24.943695337541644, 23.665600822817897, 34.501179802802305, 35.67823994544245, 42.70597019503194, 44.26445338033861, 38.904122691000666, 43.397707631511075, 44.40168142318726, 45.95562250383439, 43.248449679343935, 40.05949997132824, 36.22557924639794, 38.90800583747126, 37.48071808968821, 39.18496047296832, 44.02339627665859, 43.055653418264086, 44.37487202305948, 42.24259314998504, 39.8324300396827, 39.30361217068088, 40.80447573815623, 41.54485448714226, 43.619631413490545, 41.051149675923014, 44.02154099556708, 40.88023239566434, 42.803515618847264, 35.68900685156546, 40.18578067902596, 39.27230381196545, 40.629514494249904, 37.875261460581136, 35.03553998085761, 36.16956780033727, 18.551034081366755, 13.958744656655098, 20.629856932547785, 36.11714924535444, 44.47137801877914, 44.571406302913545, 43.98016783498949, 43.090138896819084, 40.9382717071041, 41.90042518800305, 46.15007792749713, 50.793140472904334, 51.98572927905668, 51.04288562651604, 53.46720849314044, 54.06110240567116, 53.25919343579201, 52.59355545043946, 52.28600632759833, 50.98995324104063, 44.48557307643276, 47.71045169522686, 53.13035142037177, 56.20404620324412, 54.6008832993046, 53.187386605047415, 57.211746246584006, 55.28174008092573, 49.55261638087612, 41.58025387794741, 44.808340995542466, 43.357522949095696, 44.74781882378363, 45.681633180187596, 50.89350215850338, 56.62961159982989, 62.808058492599, 59.67623418377292, 62.62477790155719, 62.39618216791461, 64.43095091850527, 61.38116690420336, 61.91748042260448, 61.54194485756659, 64.62045238864037, 64.08726107689643, 56.28063440322877, 28.605269078285467, 17.141665681715935, 6.441969861907344, 13.90788524381576, 45.67868355781802, 51.61661463399088, 29.12976057298722, 34.418884554216945, 44.72272349942116, 54.73171003403203, 45.72574807751564, 44.00205858292119, 51.36643017491987, 67.08072770026423, 32.441033317196755, 0.6381140396960321, 0.20367835618315205, 0.26980320472390423, 0.05620704362950018, 0.07024868451539548, 0.09287000453520207, 0.12333851638099841, 0.04212954216786931, 0.09797556686305231, 0.09395219565879914, 0.2163777957039495, 0.2201205642232972, 0.06174549543028397, 0.12727541924123803, 0.09918311295369941, 0.04770123069324801, 0.0633100614762835, 0.3835817558630821, 24.64486956596375, 58.95798936966927, 67.45762825012207, 25.381253380929273, 46.19320438754174, 48.302584463550204, 17.72253340290439, 57.429253439749445, 36.51325764194612, 35.85989275286275, 63.08201251491424, 63.92896990622244, 54.67488665734568, 14.913404449339836, 0.217931192188013, 0.07690713004839998, 30.040101505094963, 63.5911440080212, 61.26331144763578, 70.12058811803018, 66.51836964391893, 68.8842099712741, 64.47271239372992, 69.10307822688934, 64.05133608848818, 64.50213409239247, 55.36820088663409, 54.0559680231156, 52.34036645581646, 53.682385798423525, 50.87766755011774, 51.22104360211281, 47.579275869554095, 49.10144967417563, 47.06881861532889, 48.86114174319852, 52.59796419451314, 60.620509501426454, 59.74133376152285, 63.68115848110568, 55.966185831254535, 62.214078287924494, 59.84795554991692, 61.55032304025466, 59.13215437243062, 54.712317835900095, 57.69634723663331, 57.67029485394878, 62.35398138723066, 62.03867773855887, 61.065482785624845, 63.09495633648288, 61.306696784111764, 55.52994374305972, 51.63455163278888, 49.97014484097881, 47.19248310212166, 53.783590793609626, 55.04342863636633, 51.61384151827905, 28.23113968295436, 26.42876155914799, 37.72443848271524, 39.47891073842203, 49.27906244031845, 51.35030923351165, 44.399830064465924, 46.087614182502996, 47.89097093766736, 49.0156086029545, 46.385984959140906, 41.72845279016803, 39.308734786125925, 42.111248662394864, 40.454031575110655, 42.929666888329294, 46.93233974518315, 46.44332216631982, 45.08112222917619, 45.94990368812315, 43.719844049023045, 43.974182298106534, 43.48357223695324, 44.63626661608296, 43.7558239506137, 42.12671064561413, 44.843783532419515, 44.132889240018784, 44.3471840120131, 38.01807495855516, 43.60248673346735, 41.382523275190785, 42.17754064067718, 42.99966550642445, 39.099307675515455, 38.89709380365188, 21.97880514206425, 17.879014399743852, 31.925063171694358, 44.43718279561689, 51.25104188919068, 48.91683939964541, 47.15895075951853, 47.3706450000886, 45.19345498854115, 45.95494393379458, 49.908846039925855, 54.70559881579492, 57.34007835388184, 55.17469075418288, 58.415576565650206, 59.1823136421942, 56.17379688447522, 57.25276639384609, 56.25060081481934, 54.6636922128739, 46.41019382784444, 50.96742314677085, 57.57292593679121, 60.34900303809874, 55.89528899038992, 58.192585898983864, 61.46251293920702, 59.52269692574779, 53.42445073589202, 46.27380517221267, 50.8327603340149, 48.292241173405806, 50.917452150775546, 50.85868327848373, 55.39598303456461, 60.54153257800687, 67.98369653763311, 65.13188239066832, 67.52485767487558, 66.1461288698258, 68.41390994287306, 66.75055826863935, 62.99996829801991, 67.2820080480268, 69.6440907447569, 68.30016905261625, 60.14300800138905, 38.02850061847318, 25.783051175455896, 8.909342212061729, 14.656450959943957, 50.127722140281435, 58.4407542597863, 37.94132201902328, 37.89357500691568, 42.915546355708955, 57.751727181096236, 58.34911984782065, 41.341263863348196, 54.56103986309421, 73.54487219164449, 24.76111096720542, 0.7591753597221067, 0.27325060038316634, 0.2378027774994412, 0.016917364499081048, 0.14168515771387086, 0.05151163711543045, 0.08020762068730208, 0.1112425932660699, 0.1246049976156604, 0.21419908761257128, 0.29702301347447985, 0.48531856928621575, 0.1913246674643409, 0.12241729565205113, 0.20802578257937587, 0.2130270037319391, 0.2602116919813618, 0.40418927587809106, 32.073919080918834, 69.67869389441707, 83.61882886578961, 41.633860911092455, 44.07138647571687, 59.05319313849173, 28.99485653446567, 65.91328128691643, 46.66503806268015, 42.775913899944676, 71.31538129621937, 70.52940107161, 59.91418869264665, 15.70734610480647, 0.35983676871945786, 0.19885465292440307, 38.079303156945016, 65.14209624259703, 65.59865228591427, 72.21654584330898, 70.60539307132845, 71.68056180400234, 64.0159288529427, 70.85084715197164, 66.7331115661129, 67.33113181206488, 56.96686875435614, 54.06287531698904, 53.20959898733324, 57.980020892235544, 54.030213740564164, 53.61566628179243, 49.32453447772611, 51.44040999873992, 48.987257711349, 51.603286420145345, 53.60926497367121, 61.8729732882592, 63.92201554390692, 66.75864619593467, 55.83904220211891, 64.91609711800852, 65.5449628829956, 64.7481490719703, 60.02056729409003, 57.22219151835288, 61.746931845142, 59.736120931563846, 66.55951530702653, 65.97366225334906, 62.60709977919056, 64.53530165456957, 62.28393570069344, 56.92171050656227, 55.57391743506155, 52.92068112281061, 49.60000253492787, 59.88448066096152, 56.72802778982348, 54.136470748532204, 33.26945358707059, 35.82934533396075, 40.209126626291585, 43.81106268975043, 50.47300838655042, 50.408285356337025, 46.690470710877456, 51.10806757403959, 52.24148350377237, 50.74913540194112, 48.83258296597389, 45.88674960597869, 41.05520540668119, 46.15641647769559, 44.92994231562461, 46.55767102395335, 50.80417802256923, 49.03156872718565, 47.71606460694344, 49.53409887129261, 47.066614243292044, 47.159696009851274, 46.78705907637074, 49.841902948194935, 49.21339411889353, 46.07726304761825, 50.27941588432559, 45.60275431602232, 49.674959028920824, 41.67630095635691, 47.814539632489605, 45.07327748883156, 47.12060566871397, 46.548006303848766, 42.17563436877343, 44.30933706222042, 29.62282015431312, 24.50618044022591, 36.84663949474212, 44.656011827530406, 53.91923812127883, 52.592104173475704, 53.08048240600094, 50.250790426808024, 47.64090022733135, 50.518158789603945, 53.36208897252237, 59.19559478759766, 58.7912376465336, 53.352600759075536, 60.78306036610758, 60.47789604433122, 59.30840215375347, 58.6677888901003, 57.704180209867424, 57.48116208660988, 48.66014772845853, 52.071256560664025, 59.56395241522021, 61.714368327971435, 57.164415005714666, 57.86310288213915, 64.88252947407385, 62.93506091640842, 57.30300018864294, 48.845860189007176, 52.31469454303865, 51.05896342185236, 55.261885043113466, 53.62836299404022, 59.611577833852465, 64.26577991054904, 71.64238929748535, 68.23512046567856, 70.9226422156057, 71.0502290725708, 72.30916869255805, 69.16945257494527, 69.66484008296844, 69.22367542020737, 73.5400947447746, 72.37264048668646, 66.70433705852878, 42.01835909197408, 27.970433465896118, 8.72367387817752, 17.1946039507466, 56.49297975724744, 69.79499217002623, 42.25958877994169, 48.64339528545257, 59.41645952963061, 79.71851810332268, 62.13692526663504, 66.68923593336537, 75.3663581417453, 87.38961512042631, 44.90668658287295, 0.8444204758251868, 0.4656525100431135, 0.44564204831277177, 0.17490081489086154, 0.27803255185004205, 0.22413647373116788, 0.2410414141993369, 0.16400963398477725, 0.1664958038036862], [0.06118958372802985, 0.07314729309009929, 0.010935525905581252, 0.05856692385409148, 0.0590288557202345, 0.006502706561267617, 0.09071869174799613, 0.026848598931645675, 0.14649833492454023, 0.6634558605090265, 14.099548920508354, 53.55244551935504, 38.43296366353189, 39.033043153824345, 46.26761959445092, 82.00408320273124, 49.792661513051684, 40.951329277407744, 25.973729356642693, 51.84351198134884, 56.82416116037677, 51.436452327236054, 11.36443901446558, 0.4518223553895951, 0.1578424423332176, 28.209127341547322, 63.84616867188485, 55.59194464837351, 63.91036218212497, 62.420544009054865, 64.20811714664583, 59.584125165016424, 59.49067861803117, 60.444293099064986, 58.06882727530695, 49.56108477807815, 48.390669130509906, 46.30468599257931, 46.38643995408089, 46.06516645800683, 47.337850063077866, 45.166276885617165, 45.51101007769185, 44.747920805408114, 44.9980228947055, 49.563426433071015, 56.26516849763932, 55.859320855909786, 56.247462918681485, 59.1465377038525, 58.21248408286803, 56.12992909646804, 55.41637543709048, 55.701280716926824, 56.058965575310495, 56.89388521255986, 57.77719120825491, 59.57917121148879, 57.65782171680082, 59.42966615000079, 58.22596526915028, 59.402146800871826, 53.59292045716317, 48.91119118659727, 46.17300025878414, 46.85195861324188, 49.54756436809417, 53.99215890515236, 58.44141321797525, 35.74762275142055, 17.509791889498313, 22.679203171883863, 32.74409917093093, 32.87987593681582, 43.115132239557084, 37.31807701049313, 40.13997916252383, 42.06338790155227, 43.43221664428712, 43.10372990946616, 42.66745251993979, 41.37099150688418, 36.69593811035156, 38.633243806900516, 37.825133569778934, 40.19594354014243, 40.45543186126217, 42.617206958032426, 41.832505426099225, 41.33196784603981, 42.94417965796686, 41.68955856753934, 40.8234796216411, 42.153924049869666, 37.23241244592975, 40.829190592611994, 43.05947380681192, 47.04834384302939, 45.7368758416945, 39.248922563368275, 37.582311399521366, 36.48597755739766, 35.984851621812396, 31.00917796934805, 21.06163928585668, 16.382320311761674, 15.419990324204969, 33.02696481827767, 44.45026782251174, 47.87152774872319, 46.905271468623994, 42.925458185134396, 42.929255039461204, 42.264444674215014, 42.52515285245834, 47.57311382601338, 53.90762006082843, 50.84493537102976, 51.65433999030821, 51.75506645633329, 53.56731522467829, 54.95010368285641, 48.75034263057094, 47.24559199425482, 46.538133698125044, 44.0154024862474, 50.89927196502686, 52.6786591160682, 55.74705477683775, 55.48146324772989, 54.9040432899229, 54.560416206236816, 54.948177799101806, 50.51535429493074, 42.513201390543294, 45.715918617863814, 43.80061349561138, 46.39884641093593, 44.74901514668619, 53.00623586100917, 58.34502489336076, 62.28646170708441, 59.62526690575385, 62.55533233765633, 60.2854214176055, 60.505301644725186, 54.74360658276466, 55.9584548396449, 64.04891206372169, 66.59935089849657, 60.51158528174124, 51.86208832648493, 35.997748374938965, 32.37414317746317, 9.984568799695662, 9.9669308816233, 44.040552723792295, 49.797242841412945, 28.39646170216222, 26.747389416540823, 41.04867858271445, 59.02141801772579, 48.87780004932035, 45.26210431129702, 55.14359420345676, 48.99347466807212, 1.0019897465263645, 0.31319460861625215, 0.09284858471683918, 0.13764908477183313, 0.0077303964550787165, 0.1773745740853971, 0.17358291383472182, 0.10283958166837694, 0.02542522289009104, 0.01686159521341324, 0.07657219640790455, 0.07070350325516156, 0.046330699396710244, 0.031046680317470626, 0.06443755520928292, 0.028614362649198984, 0.13526776174624122, 0.021616488454803344, 0.1842193092189489, 0.788204514932248, 24.081122990577455, 72.57006122219947, 35.387560936712454, 25.942430803852698, 52.388756736632324, 57.22994212181338, 60.85277657355032, 44.05085679023497, 29.062515458753033, 60.11983463841101, 61.55342171269079, 57.63500136713828, 13.976176650293413, 1.0555969635325095, 0.1794316120926411, 34.361445365413545, 69.44708578048214, 63.09303045272828, 68.35483904807799, 66.04463361924695, 68.75364211297804, 65.18771733007124, 64.28335997366136, 65.11749513687627, 63.33461707638156, 53.60088679098315, 52.55116639598724, 51.226966381073005, 49.21979542701475, 51.876714844857496, 52.988016451558764, 49.865900008909165, 49.09760967377694, 48.54085276203771, 51.65335155302479, 51.78485685779203, 60.00560345188264, 60.066176614453724, 58.86055377221877, 58.75895261764527, 60.2285627395876, 59.89050149917603, 59.074542599339644, 56.404314579502234, 59.212084431802076, 58.64052449503253, 59.87599657427881, 62.35975119375414, 60.40397897843392, 60.566310190385394, 59.36071872711182, 59.72456170666603, 55.16157434832666, 51.774274303067116, 49.6247644578257, 48.14895306864093, 53.03876015447801, 53.88106561476185, 60.99594700721003, 45.91694401156518, 24.58835017296576, 25.970185495192005, 33.624322183670536, 39.29756779824534, 48.001821041107185, 40.10445425587316, 41.909234831410075, 44.95113488166563, 46.93385378006966, 46.32783582133632, 46.91794856902092, 43.87948451503631, 42.5249606563199, 39.71686524729575, 39.26628689612112, 41.58587855677451, 41.1201520119944, 45.76704279068978, 45.19860113820722, 43.767814636230476, 42.71527405708067, 44.88059105411653, 40.55143971596995, 42.61078603806035, 39.43077541166736, 43.948918311826645, 44.96143894810831, 47.35040164762928, 46.58907744192308, 43.23137560198384, 39.704627452358125, 39.549132931617, 39.59816255877095, 33.34845404471121, 23.708907711890436, 17.113589356022498, 26.118766838504424, 41.33832208571896, 53.36929436652891, 50.00315158597885, 50.72146308037543, 46.403796442093395, 46.76557625493696, 45.3565392955657, 48.24097971762381, 50.75077103030298, 56.75954795652821, 54.5677706503099, 56.158032878752685, 54.732800452939934, 57.36517367824432, 56.77429606837612, 52.69053997532014, 49.99163550715293, 49.45402368422478, 48.354477420929946, 55.96234190848566, 58.36387188203874, 60.34895989202685, 57.66730993024765, 56.604347613550004, 56.80312548914264, 60.15887791110624, 53.71715368763093, 46.09880862697479, 50.18443176823278, 47.36630293630785, 52.06678898103776, 49.5498981783467, 58.88338196662165, 64.41019373555338, 65.218213758161, 62.837044808172415, 65.55414122919883, 61.73594920865951, 61.18873150117936, 59.43281973561933, 61.813086540468284, 67.05684831065517, 71.28601843310942, 65.83568111542733, 61.070738761655754, 52.82170795625257, 41.73299489482757, 13.93580565529485, 11.253709523908555, 50.58869085004253, 57.18484270957209, 37.44938227438158, 30.591886812640777, 42.37630282678912, 61.59071953065934, 61.9106476537643, 44.73805996679491, 63.70880334608017, 43.844571498132524, 0.6752741456993165, 0.19861958650571687, 0.03530341914043792, 0.0709966851037837, 0.050413928880927064, 0.22239950725868826, 0.08075357324654057, 0.08638392878516067, 0.010122291015220747, 0.09548443279439404, 0.16798040559214933, 0.13104090226754067, 0.2290439104000407, 0.14259568385539517, 0.22264701494526482, 0.13725716951152972, 0.41709497691162173, 0.09183796152712838, 0.292371082450113, 0.8053710744265588, 38.83349649367794, 86.02912533667781, 56.78339596717589, 54.308776547831876, 58.063296733363984, 97.1393172971664, 68.69301795959473, 56.33568094622705, 36.67417680063556, 65.89175531941076, 69.80338604219499, 62.173854381807395, 13.739219404036, 1.8049241097704058, 0.31012222831768377, 34.3741891461034, 69.97440138170796, 65.80566713886877, 70.56245096268194, 69.90796427572928, 70.72979496371362, 65.4647425682314, 66.71308394401305, 68.35100297004946, 68.0927933416059, 58.417074911056034, 55.76118707656861, 55.37046801659369, 53.015543645428075, 54.36834558363884, 54.95812100748862, 51.56472952135148, 51.0800540062689, 49.74497333649666, 53.273725817280436, 56.303956816273356, 60.83558482508506, 59.65128398710682, 63.76452845911827, 63.658314597222116, 60.225079674874586, 57.86642905204528, 62.6243229066172, 60.918935191246774, 62.18902218726374, 63.13396430784657, 62.694596090624415, 63.5923207190729, 61.84890954725204, 62.25007780136601, 62.25054064104634, 64.76769424253895, 59.70138049894764, 53.355883782909764, 52.44599196218675, 50.70904877878005, 56.529218535269464, 58.923374452898585, 63.96045477159562, 47.26232090303975, 27.6217661365386, 34.86381469234344, 40.869606694867535, 40.343185394041, 50.16614175611927, 43.79601647776943, 47.96556265123429, 49.814622863646484, 52.3403743005568, 51.473067652794626, 50.03812736080539, 45.86681219839281, 44.08572273869669, 44.217765408177534, 43.98773800942206, 46.592901752841094, 45.712604215068204, 50.432152978835575, 48.16137913734683, 47.02500574050411, 46.92509904984505, 47.25796707214848, 47.892979191195586, 45.32403853631789, 42.373517943966775, 46.96564851268646, 51.44366556598295, 51.485438808318115, 51.408654489824855, 44.57293994965092, 40.87889094506541, 41.42903081832394, 43.20955937908542, 35.95582216016708, 32.66686181868277, 21.734296352632587, 33.73709032612462, 39.78350239415323, 55.08213066285657, 57.34209837452058, 56.16353596410444, 48.12548552789996, 51.035778291763805, 48.55124704299435, 49.87168550491334, 53.961752691576564, 59.22737775310394, 55.410676233230106, 58.388476910129675, 55.63173709377166, 58.74952323975102, 61.10389455672234, 54.85732786117062, 53.20209941556377, 53.19004989439442, 49.76516177577358, 56.6021942323254, 59.54164197368007, 62.84864325677196, 60.87418094758065, 58.12745101990239, 59.12441161371047, 62.350925860866425, 57.28171740808795, 50.854451041067804, 53.38110462311776, 51.31955785136069, 54.463827840743534, 54.384117434101725, 60.58259587134085, 67.8238207294095, 69.8088538262152, 65.49793366462954, 69.10051299679664, 64.02026699435326, 64.52561732261412, 62.23927559391145, 61.7165687776381, 71.89673146893902, 75.48410769431823, 72.3244502467494, 65.2377236273981, 55.759198434891246, 42.66216516494752, 13.601577551134172, 12.445303028629674, 54.43875997297226, 65.23853555802377, 42.768324113661244, 37.91501468227756, 54.552971547649754, 82.22704641280636, 64.18100180164461, 63.898351884657345, 71.24356269836426, 67.76736213314918, 2.726033296315901, 0.44442782959630417, 0.1992790349909375, 0.2733533787390878, 0.21743970081931163, 0.4357826499448669, 0.2789628583817713, 0.21674465988912892, 0.09657661370452374, 0.2195015345369616], [0.02100184653705407, 0.015605764516118555, 0.04439666446658873, 0.03662331585562037, 0.054168506645627564, 0.072611000899586, 0.1521769003762353, 0.053518795137924534, 0.09924328916015164, 0.12934913498259362, 0.15287348880402504, 34.38655637925671, 54.48867213341498, 52.30826970069639, 51.10681633795462, 101.61489855858588, 74.26061061120804, 39.2460435436618, 27.183511872445386, 38.804627849209695, 57.709906870319, 48.42434267843924, 11.072661742087334, 0.569905370714203, 3.990730955716103, 52.91276970217305, 63.413947013116655, 60.94674871813867, 61.56298052880072, 62.12241249699747, 62.74255098835115, 61.98538449502761, 59.47889581803353, 58.71529663762739, 56.060636505003906, 48.442354202270515, 44.20590416077645, 46.399305328246086, 46.185081158914876, 46.98811977140365, 48.206721736538796, 43.68276196141397, 43.55295896530152, 42.63381427334201, 45.86846743860553, 42.46155946485458, 53.32147675175821, 57.56372405636696, 55.17966824193155, 54.18957179592502, 58.83461121589907, 54.16502952575684, 54.0307197263164, 53.885376299581225, 56.87814474105836, 56.858058283405924, 57.42367582936441, 58.931521215746486, 56.71975551113006, 55.12046398655061, 59.09993994620539, 55.95741148917906, 55.37191929355745, 49.94049956721645, 46.43265331945112, 43.81700900293166, 47.83422208601429, 47.93846691808393, 56.01807094389393, 50.0125809638731, 36.06287933165027, 18.048366654303766, 14.263825628065295, 29.070342548431892, 31.28031376869448, 41.8943965050482, 36.103860255210634, 38.704536807152536, 39.16882384207941, 39.123143919052616, 38.14067256066107, 40.258528878611905, 39.3857152231278, 36.507217191880756, 37.27510352288523, 37.5697676597103, 34.34847800962387, 37.89445754020445, 38.56379039825932, 40.89617683041481, 38.14597952750422, 41.164929789881555, 41.94841930943151, 45.62618263306157, 41.98251647333945, 45.02435376567226, 45.28240649930893, 36.81395046172604, 37.60668500777214, 40.01543606481245, 37.57079924306562, 40.768072220586966, 31.669501143117106, 24.176762142489036, 21.168447386833932, 10.710158251946973, 26.97170976669558, 40.03480865109352, 47.97188551195207, 48.59926862101401, 43.624463773542836, 43.63681139484529, 43.56989968207575, 46.033061858146425, 44.39944567218904, 49.849265237008375, 52.67490148544312, 52.00061467386062, 52.40737230547013, 52.343174872859834, 51.79818899400773, 49.76384385939568, 47.20040236749957, 45.11447806512156, 44.766626588759884, 50.170024902589866, 55.40507901099421, 53.14539763235277, 53.10015701478528, 50.549376933805405, 50.861209284874704, 54.03450481353268, 56.0630605297704, 45.96801327120873, 41.359436204356534, 41.34884972726145, 45.28846656122516, 47.24944768413421, 46.0332501319147, 53.425356803401826, 58.61732367546328, 61.74608069081461, 60.25187338552168, 64.49592105803951, 56.42895490892472, 58.84290310644335, 58.544755904905266, 61.84243371409755, 60.20947256395894, 61.56544377726894, 60.181329557972575, 58.29808196713848, 54.90542396422356, 47.46328353881837, 17.12415033771146, 11.114192778064359, 49.54861164093018, 43.60010193240258, 24.220653464717252, 32.957299601647165, 19.206762198478945, 54.0939522558643, 52.35226692691926, 37.18948994913409, 62.8491178635628, 16.496274971192886, 0.38706687369173576, 0.05708079372021941, 0.07187107487791969, 0.0959056202742842, 0.026363002609521635, 0.1327463212392984, 0.0585206636347838, 0.07523269167230015, 0.07680044464406467, 0.01488478863686924, 0.017573516891007463, 0.03494821098302642, 0.008963328305511706, 0.06857427678281261, 0.04984891988457211, 0.029279219715165037, 0.06615435824759545, 0.03644688580665858, 0.04191720174745687, 0.24088261949439205, 0.25159635911545447, 38.85122560685681, 73.12188379226193, 33.26468790731123, 48.17266771870275, 92.87996061386602, 74.18527756967853, 49.694782687771706, 29.719249663814423, 48.019169684379335, 65.12835617988341, 56.131611793271965, 12.976538058250183, 0.5892134830355644, 5.99591939680038, 62.01802645960162, 69.88334748052782, 66.3054241672639, 67.63412706313595, 68.07290692483225, 67.43963241577148, 66.72758102416992, 64.07547435452862, 65.67738994475334, 61.75001482809744, 52.06184679462064, 49.60705887886786, 49.94661061994491, 51.385657633504565, 50.75079456452401, 51.61505745303247, 46.53489382036271, 46.05181863231044, 47.3317390103494, 49.68162705821376, 45.817213827563876, 55.5982949656825, 61.27630233764649, 58.99282393916961, 57.68447029975153, 60.57503354164862, 57.44800236917312, 56.989273332780414, 57.05433368682862, 59.320216332712484, 60.068659474772794, 60.87050176435902, 61.85825655537268, 58.64304265668316, 56.584841666683076, 61.75876955832205, 60.099501071437714, 56.14943504333497, 51.388399370255016, 48.947963406962735, 44.40688248603575, 50.6057257037009, 49.357953071594245, 58.14035561776931, 52.49524124207036, 42.99997537366806, 19.681843596120036, 18.313395323291903, 34.724225382651056, 38.400015754084436, 44.18659825478831, 40.71107625961304, 41.572726849586736, 42.68449521833851, 44.05694823111258, 43.189904382151944, 43.97762613911783, 41.87130943421395, 39.56190416889806, 42.77156791379375, 43.71793385474913, 37.811722986159786, 40.33782351401545, 41.05791968684043, 43.75420401173253, 40.959868277272875, 43.33342390675699, 47.00835527912263, 48.28093298019902, 42.65362616508238, 45.43155070274107, 48.11917835666288, 37.31805739864227, 38.57141940824447, 42.74175397811398, 40.440926936364946, 41.385198331648304, 33.37225106454665, 28.069779257620535, 22.01255125384177, 16.978932426821803, 34.49779871971377, 50.93415752533944, 53.43860656984391, 51.92801552434122, 47.92431892887239, 45.82920451318064, 45.142511244743105, 49.925068962958555, 47.920937845783854, 52.69659219249603, 54.96195316314698, 55.84441192688481, 53.731839041556086, 55.85041707561862, 56.01075964589273, 51.69637603144492, 50.350144063272786, 49.59978680456839, 48.81830553854666, 52.89314216183078, 59.321389121394006, 55.94232213112616, 57.270495507024954, 53.030444729712706, 56.88658568166918, 61.110488060982, 60.31303098124843, 48.89992613946238, 46.79628841338619, 46.6175813059653, 49.40582167717719, 50.004367520732266, 51.19359877801711, 57.44147554520638, 61.930377175731046, 64.83147198154082, 64.29360912692162, 68.09882594693092, 62.2034094410558, 63.37491550753194, 63.141871806113954, 64.94824094157066, 66.48838704632175, 67.33687416199716, 66.48566492142217, 64.48224767561882, 65.31004821100544, 55.55247775969967, 19.036345020417247, 13.747978056630782, 56.35136650454614, 49.8204436609822, 29.808513003010905, 34.92252080671249, 24.16812312218451, 61.86659551435902, 65.45208507968535, 39.578668379014545, 67.7826201531195, 13.496344281781106, 0.6091497874548358, 0.3623821418131552, 0.1124671082042398, 0.11546985111049107, 0.03938080720423211, 0.029379487217914675, 0.016032328018017353, 0.06024140819546677, 0.0548743992112577, 0.07031635306174717, 0.1407658368829758, 0.1788019491059165, 0.19654552602479536, 0.2121485307091667, 0.11190707494895305, 0.3397139984994166, 0.16797150365046917, 0.14952174688298858, 0.13293511594735807, 0.24539132272043537, 0.7276849785158712, 59.43745989953319, 82.92748758869787, 69.99374651139783, 67.14358760464576, 115.41496569110502, 87.44394779205324, 52.31160763771304, 36.29402068353469, 53.7999588443387, 71.24136617106777, 61.723589820246545, 15.866091289827901, 0.8241658465516183, 4.988349281972455, 63.394884294079205, 75.25947355454969, 69.33365083509877, 71.79926841489731, 70.54833827480194, 71.91083631207867, 70.3176244612663, 66.7740140422698, 68.72625612443494, 64.68627368250202, 55.289502451496745, 51.197893773355794, 52.81298460498933, 54.25631092440698, 54.051520055340184, 54.80691755971601, 49.61330329218219, 48.531089982678814, 50.32983010815036, 51.63154709723688, 47.921667406635905, 58.09003945319884, 61.78370014313729, 60.6574974521514, 59.65686551986202, 64.70311634002194, 58.50410446043938, 57.611153356490604, 59.98168091620169, 61.87025508572979, 62.358821592023304, 62.96979742665445, 63.72328865912653, 59.53230281029979, 59.60466269523867, 64.17904061655845, 61.46283849593132, 61.52217611189812, 55.325658859745154, 51.741738242487756, 49.513557418700195, 53.15039080958213, 53.52416915278281, 60.42489305619271, 55.78193641478016, 46.47322631651356, 26.38518794890373, 25.761886066006078, 38.650372797443026, 39.005927808823124, 46.506327198397734, 42.62315327121366, 46.212753480480565, 45.61337609444895, 47.05348214795513, 47.843741678422504, 48.9951063740638, 44.62417002647154, 42.815318030695764, 47.90315774179275, 47.233487559903054, 42.96315608486053, 43.925756715959125, 46.611976238989065, 47.45268529461276, 44.330478637449204, 47.029818488705544, 49.68093672106343, 52.78476315159952, 45.9930968284607, 50.00970978890696, 50.12391744121429, 43.63633286568427, 44.55913320664437, 45.760343382435465, 44.94578476875059, 43.61033539618216, 35.66025587820238, 31.521159064385202, 23.884563215317268, 26.135013295758156, 35.4062706424344, 51.50037127156412, 56.258920161954826, 54.97058629989625, 51.88221793020926, 50.25139054944439, 48.286483133992846, 53.28841117120559, 49.98640698771323, 56.30435297566076, 59.94189239317372, 58.12823549393685, 56.387095374445764, 57.25626122566962, 57.79489678721274, 53.78871733142484, 53.47498263082197, 51.009678840637214, 50.56669027574601, 56.693310891428304, 62.324791108408284, 58.169851841465125, 60.26723730948664, 54.66919922059583, 57.764847509322635, 62.6219851739945, 64.75091826531195, 51.49409940165859, 50.0658820521447, 46.15053684480729, 53.31957440222464, 52.78255093482233, 54.78044548342305, 59.618210561813854, 67.07263192822857, 67.5111686029742, 67.41719645838585, 70.6414867216541, 62.65112053963446, 63.56328733505742, 65.81276662888067, 66.84042761402746, 70.17031592707481, 68.8020206266834, 71.47284092441683, 68.93015661547261, 70.87351060682728, 55.77361706764468, 20.471328458478375, 14.256185831562167, 62.590406171737186, 56.76522362616755, 39.093514334770944, 44.28846220816336, 28.483597155540224, 74.35941511584868, 66.16747440830355, 56.85805043866558, 82.02268308208835, 26.20533747057761, 0.8091382658289326, 0.6475257056374705, 0.3201975409061678, 0.3016460170188258, 0.14032262437526258, 0.18227320074314074, 0.19906344252728647, 0.2280367192842307, 0.20064872359075855, 0.18064586145262565], [0.043055773111841375, 0.06506112779700948, 0.04206598368323138, 0.05494759508198308, 0.10200344266430025, 0.05930196606524049, 0.06723510146501564, 0.1436477064365341, 0.07854155565221464, 0.07461458895235293, 0.27700286839277516, 4.448079072660016, 58.31213974183606, 58.8255387736905, 58.628714238443685, 71.60979440135341, 97.94869053748347, 39.225529547660585, 27.390014856092392, 33.8551301340903, 55.98607224802817, 54.83868875811177, 17.981262745395785, 0.11007872950886527, 25.906788226096864, 61.12820148468018, 56.960745934517156, 58.47543585684992, 60.13015047196419, 61.52791453946022, 58.39581958709225, 61.51537864438949, 58.115099476229766, 58.4837552039854, 54.046381750414454, 48.58457542234852, 47.101499803604625, 46.20148843334567, 48.34948032133041, 46.41557531972086, 49.0177619841791, 44.6472139512339, 45.30919628758585, 43.79258832623882, 44.86243440258888, 44.32338699217766, 48.172883449062226, 55.35658282618369, 59.14766342409196, 57.94401745642386, 58.27355146408082, 53.1742976557824, 55.05824342850716, 56.103660983424035, 60.790783512976866, 58.94661841853973, 61.307944097826564, 57.618715686182824, 51.86743059465962, 58.34821378031085, 59.82279746763168, 55.71761738869452, 52.21258740271292, 51.56063064452141, 47.90153780291158, 44.75565571938792, 43.70747681586973, 50.19419846996185, 54.656106348960634, 50.967054443974654, 40.26161970630769, 18.86374504335465, 15.35436220707432, 20.09177246401387, 29.34924856308968, 35.83042398575814, 37.368373563212735, 39.52038195825393, 36.42038768337619, 38.49663942090927, 34.87872362136841, 39.132663511460834, 36.43391593810051, 35.302053266955966, 33.93145161290323, 38.0088181649485, 35.08131796313871, 36.527189900798184, 35.74336697978359, 36.628379206503595, 42.02045363764609, 40.742525823654674, 44.86570173694242, 39.39489356933102, 44.75894266559232, 41.92905064552061, 47.33590848984257, 41.27974540956559, 35.83957095299998, 41.71513634343302, 36.151356235627205, 32.404388573861894, 27.038858782860544, 25.287114535608602, 17.439353965943862, 19.963720806183357, 34.70571179543772, 47.9277745369942, 51.71443854608844, 46.59421182447865, 42.4549267368932, 40.39512149749264, 41.242090655911355, 44.468855934758345, 46.45948233142976, 52.74895975666662, 52.80690100885207, 52.1446676408091, 52.0196028678648, 51.90061776868759, 52.21276783174085, 48.15629966797368, 46.54454677335678, 47.29567673898513, 48.008665577057876, 52.12353783269083, 52.772811689684474, 53.06135300667056, 53.46483938155636, 51.51326410232052, 57.01259966819518, 54.86867527807913, 52.24710033785913, 43.80047621265535, 41.52602711031514, 43.81161182157455, 46.37405703144689, 47.747059176045084, 47.13998217736521, 49.801592749934045, 55.5711482417199, 60.03324047211678, 61.41879027889621, 63.55661538339431, 63.909232539515344, 65.76816535765126, 63.00529879908409, 63.53368912973712, 63.502267022286695, 60.81794592642016, 63.06825284034976, 62.55235525869555, 62.3374132956228, 56.26553720043552, 17.762433713482274, 12.380563328343055, 50.3843588982859, 38.440361253676876, 22.08546027060478, 21.683909585399014, 23.042034179933612, 53.503031499924205, 49.03121571387015, 41.64396101428617, 63.65162695607832, 5.530615487406331, 0.44455527598338745, 0.09430959865811372, 0.05350716592323396, 0.07823399433325376, 0.039688353201434504, 0.04972025541768921, 0.050913238176895734, 0.05138939629579264, 0.10808484779009897, 0.13568348701923125, 0.08021872130132492, 0.07829217871110286, 0.046523550540328994, 0.09151562237210813, 0.07763857547674449, 0.044468680561910716, 0.07755484206662064, 0.07947917832362075, 0.179812909374314, 0.09697481854668549, 0.3262081748295215, 3.7538411251960264, 67.2512331316548, 59.30941412525793, 52.18680566357028, 82.71449504360076, 94.614315032959, 50.12962448981501, 35.14722947151431, 39.620367096316436, 65.25334642779443, 62.04935443016791, 20.909806297671413, 0.021434485116192413, 32.53779818934779, 69.55992452559933, 63.70682254914315, 67.4475948272213, 66.07047419394216, 66.74621228248843, 61.4333579617162, 64.96383628537579, 63.129120180683756, 62.92430577739593, 57.39350495799896, 55.22253190317462, 49.88523729385869, 50.28555047127509, 52.79104678861557, 51.79105812503446, 52.158129215240486, 50.16188990685248, 47.63746030869023, 47.51378405478693, 49.58043383013818, 46.67012537679365, 50.36874786500008, 58.4185104985391, 59.81901630278557, 60.061148135892815, 59.04885891945132, 56.72934962857155, 58.80788026317474, 60.46230854526643, 63.14689243993452, 60.85889939338931, 62.95665748657719, 57.900726256832, 55.177291285607126, 60.59334316561299, 60.87529490070959, 60.605604494771654, 53.18217769745858, 53.7891056460719, 51.060826547684215, 46.995368311482096, 46.05246582338887, 52.871455377148045, 57.13552674939556, 56.935274062618134, 46.5386357615071, 27.271480829485004, 16.379045132667787, 23.693608507033318, 35.26426515271587, 39.74483959136471, 40.48457507164248, 42.95421700323782, 40.56226153527537, 42.66296925083284, 39.46106395413799, 41.193755288277906, 39.77223734701834, 38.43624668736612, 37.50100458821943, 39.07414174848987, 36.641201434596894, 40.9022565041819, 39.12483053822672, 39.70000297792497, 42.22955519153226, 41.274877748181744, 46.593741140057965, 40.39734548138034, 43.410310206874726, 43.9634899170168, 51.482140095003196, 43.40771359782065, 38.97658063519386, 46.29013399924002, 36.108939724583784, 35.19088545153218, 30.04371008565349, 27.21425933222617, 19.430651087914747, 32.28243620164933, 47.439470829502234, 53.44356444574172, 53.56069818619759, 50.66267851860293, 44.454613808662664, 44.169841889412176, 44.588021462963475, 47.67609173251737, 49.94355117121051, 56.00680981912921, 56.73966938449491, 56.873712462763635, 53.55807412055231, 56.21547206755608, 56.70497602032077, 50.858530306047015, 48.88696270604288, 50.705710841763405, 51.8130979230327, 56.5567574962493, 57.37490115627166, 58.011858770924235, 56.433728433424434, 54.61054409703901, 59.21379066282704, 59.24008231009207, 55.8193636709644, 46.34103459696616, 44.56618562821419, 47.68846681041103, 49.88339770224787, 51.68875878857028, 52.139486189811464, 53.61316773199267, 58.884366481534904, 63.07736058388988, 63.90291360116775, 67.60314033877465, 65.19025510357272, 67.92188782845774, 68.20412589657691, 67.19346446375694, 68.54937291914418, 66.07624007809547, 65.11283928348173, 68.22666383558705, 67.06503821957496, 62.66369565840691, 19.159607464267363, 14.569423371745696, 56.649007720331994, 46.159624976496545, 26.68110920536903, 27.97497949292583, 28.66060979904667, 62.02696161885416, 45.42053276492704, 39.40228723710583, 74.17520492307602, 6.618378950703529, 0.38017021311867627, 0.143367808552519, 0.11556436337770955, 0.08247555503922124, 0.07397288306345863, 0.05359526603452621, 0.03899369914565356, 0.06951421303975006, 0.047071096562449975, 0.15939006251433205, 0.1763376740798835, 0.20967985833844832, 0.11947728002503996, 0.2585853179616313, 0.3076263751474119, 0.17357658594846728, 0.200370894144139, 0.25880668672823137, 0.22380347063224162, 0.3123388884048308, 0.3718311622017815, 8.268854464254073, 81.3112122012723, 72.19506694424537, 76.74119595558413, 81.2919141400245, 107.0868952043595, 53.27869153791859, 36.79770792684248, 48.285537842781316, 73.06992807695943, 67.09485607762491, 22.317035044393233, 0.1618215949424813, 33.341319253367764, 75.67938681571715, 69.81567875031503, 71.30739535054853, 70.7397028707689, 68.12257197595412, 61.48366628154632, 70.08420421231177, 65.6409825048139, 66.96703387844947, 62.269038538778986, 58.83221464772379, 52.47040479413925, 52.87602886076897, 55.52792372242097, 55.184779090266076, 57.37490507864184, 52.30010724836781, 51.39967618450042, 47.91957286096389, 52.33932310535062, 48.247157450645204, 54.60494295243294, 60.65994501113892, 62.30365345554968, 61.27951475881762, 63.827757066296, 56.71909263057094, 59.36568444774997, 64.38546319161692, 66.26352540908321, 63.68433952331544, 64.03413649528258, 59.71426940733387, 57.34658948836788, 61.44303837130147, 65.09725178441694, 63.81573107934768, 58.0006133356402, 57.081174465917776, 54.5491393919914, 48.272633244914395, 48.27051908739152, 55.48615048008581, 59.55842579564741, 57.21539405084426, 50.39521601892287, 31.774520643295784, 20.1485409275178, 34.09774441872874, 36.45934466392764, 42.940112160098174, 44.870490950922814, 46.49165753395327, 45.374903832712484, 47.30674958998158, 41.24621698933263, 44.147758945342034, 45.161766159919004, 42.01305996987128, 40.190138432287405, 44.333114470205004, 40.37089301693825, 43.367152367868734, 42.93011403852894, 42.40971357591691, 45.377218031114154, 44.36155557632447, 50.209621229479396, 44.66060884537236, 47.48943005838702, 48.633973752298665, 58.08186523375973, 48.40776674209103, 43.707221861808534, 48.85808621683429, 37.6846303478364, 38.10272755161409, 30.777124666398574, 32.22117074074284, 27.640754330542784, 35.772345450616655, 45.57803946156656, 58.69099755440989, 56.96778266660629, 56.27305246168568, 48.305239908156864, 47.87464211064, 45.36694534363286, 51.95814717200495, 51.46482283069242, 59.147741871495406, 57.97884418118385, 58.323957843165246, 57.64241072439379, 59.42765397410239, 61.86727408439883, 53.14478574260589, 53.2520390325977, 56.03589027158676, 54.4022701632592, 58.95742062599429, 60.08661608542166, 59.64076419030467, 60.96915721893311, 55.58131502520654, 60.75738845332977, 62.24441782120736, 60.95094957659322, 50.879518908839074, 48.427272688957956, 51.09276640799738, 53.73420423076999, 54.51590514952137, 57.05314520866641, 57.847750725284705, 64.479019564967, 66.58767008012342, 66.89716077619984, 70.28831651133876, 68.78935921576716, 73.43828570458197, 70.84668943958899, 69.9089527130127, 71.28005643044749, 70.86386157620338, 73.45537154905259, 73.7989947103685, 74.40111775552073, 66.4699754407329, 23.92779165698636, 15.928423635421263, 61.760189456324426, 52.17231642815375, 33.330552347244755, 30.32111579372037, 36.32550554890787, 67.90075409796931, 64.53610181808472, 59.85922059705181, 84.3651068595148, 10.191425777250721, 0.8390183915053645, 0.24420564844002648, 0.30791702890588396, 0.2641620703281895, 0.19831275297028406, 0.1364880325573106, 0.1465459549499135, 0.15557502126020772, 0.17956337921561735, 0.25932119137817816], [0.13185723023789545, 0.05764137855881165, 0.05317951394845882, 0.02810295490968612, 0.06944851333936376, 0.051477404476533976, 0.026814473545058604, 0.050573072155877474, 0.09503407268634728, 0.09191666940046896, 0.12043420811213794, 0.04458393082923947, 21.42010469590464, 68.91815416274532, 37.463412592487956, 44.94127404305243, 101.58452372397147, 50.77317953109742, 20.788379523061938, 33.94581533247425, 44.23485909738849, 59.90425332900017, 22.927546078158965, 3.2750655902970225, 39.4234170452241, 57.37267717238396, 58.36025937911003, 61.359162407536665, 59.569004428002145, 60.52313666189871, 61.02299567191832, 57.0169181977549, 58.52293968200684, 54.201044728679044, 53.26710093405939, 50.12664741085422, 46.91412033573274, 50.42599878003521, 47.656774059418716, 45.538470591268236, 43.67568992799328, 43.76023661705756, 46.16843854227374, 45.48671099447435, 44.05293172405612, 43.860151152456964, 44.03036632845479, 50.321957911214525, 55.33269559183429, 59.069153262722885, 54.817202014307824, 53.0806589126587, 57.07166271824991, 55.03801184315836, 55.99559968517673, 57.574032045179806, 51.524466391532656, 55.58991678299443, 57.01929907644949, 57.969516784914084, 57.07338856112573, 56.97319945981426, 51.724428822917325, 49.17660228667721, 48.8777647479888, 45.88270956470121, 44.556234575087025, 47.94310708199778, 51.83710675085745, 56.6997161219197, 46.77781797224476, 31.261474624756847, 12.142238155488046, 12.233430320216764, 28.894424246203517, 30.639843671552597, 34.06493771460749, 34.40723903717534, 37.94762134552002, 36.58282479932232, 37.451206176511704, 36.09726675095097, 35.64614711269256, 36.50949216658069, 38.43719590094782, 31.39931651853746, 34.61471672981016, 38.008422005561094, 38.60501058640019, 40.84151860206358, 41.89723237868279, 45.5289823778214, 44.450954237291896, 45.772004588957756, 46.25060827501359, 42.38284926260672, 38.86983725332445, 45.76931776538972, 41.95005101542319, 39.80899387790311, 33.89199256896973, 35.35097306774509, 32.61261151682946, 20.91937295852169, 19.3487363092361, 28.429405689239506, 46.79465278502434, 51.91107480756698, 50.47026272742979, 46.14426105253158, 40.990247034257465, 41.224224259776456, 46.721265239100305, 44.76984293230119, 48.407147007603804, 50.09204426119405, 51.519026064103656, 53.09305360240322, 53.358915775052964, 50.140681651330766, 48.564834133271255, 48.13436577397008, 47.685783909213164, 46.90700907861033, 51.98622742006856, 54.27460485889066, 54.71848772418115, 54.91784611055928, 51.27123032846759, 52.93791993971794, 53.91507256415583, 51.71758820933681, 47.32406685429235, 40.982653325603856, 44.82173588968093, 44.345254205888324, 46.05960061473232, 47.694005197094334, 49.10365012384231, 45.86918915471723, 51.981081270402484, 55.77142446271835, 58.557703648844075, 61.34062920847247, 62.78800341390795, 61.8668112447185, 63.143938895194765, 63.366521635363185, 63.27779369969522, 58.544477416623025, 58.89310552227882, 63.0929990737669, 62.93729666740664, 57.6231832658091, 18.136749421396566, 11.491507137975386, 56.0722545654543, 29.237557111247895, 29.238767162446056, 13.043885154108848, 18.1122757927064, 57.95651412779286, 46.6818493412387, 38.77115041978898, 63.58042809271044, 2.9988037434316452, 0.1400377009544642, 0.08060036332256372, 0.019743422632135695, 0.040418641837013346, 0.09164820920916335, 0.20870997570455077, 0.09537732604170039, 0.11906517834793176, 0.03322478511460847, 0.11799201174008271, 0.07996832546327384, 0.047408669375844543, 0.030824984048282912, 0.02904099509901097, 0.0820651081120295, 0.0721719099449054, 0.033294368880770864, 0.032447129262671355, 0.088300856971933, 0.05678611800014492, 0.20345991387242274, 0.14847640458854938, 22.00827390916886, 76.05766803987565, 37.1259436299724, 55.78202662929412, 100.8507110226539, 55.44836628821589, 29.903069580754927, 41.91097244139641, 49.13880632769678, 67.64999697285315, 26.5264226928834, 6.552792999052233, 51.26473488346223, 65.56027581614833, 66.9864417660621, 66.37071594115227, 63.23211377666843, 62.875323218684045, 62.43051467403289, 60.29851821161086, 64.78802388714206, 60.057264989422215, 57.00724955528014, 53.83757437429121, 51.94509352407148, 53.27083110809327, 52.167597816836455, 48.74487484655073, 45.98626798199069, 47.97681985362884, 49.05383210028372, 47.45648607130974, 47.97027341781124, 49.703251084973736, 47.82479270812004, 51.88297887002268, 58.9518508603496, 60.716101584895966, 59.28072590981761, 57.46456653841081, 58.872960229073804, 58.02688929342455, 58.74694624254781, 58.511866831010394, 53.76365338602374, 59.67168423437304, 57.7493659142525, 59.63349211600519, 59.08879257017567, 59.48933324506206, 54.45488875912082, 51.957707866545654, 52.44295212530321, 48.30310613878312, 47.94611553991995, 49.37119499329598, 52.66986516214187, 57.027834153944454, 54.25572256888113, 41.30055358332973, 15.39134035187383, 16.44218058355393, 32.61298806436601, 32.71815661461123, 38.40120423224665, 38.97843591628536, 43.95484501315702, 40.94217838779573, 43.996218173734604, 39.926123695988814, 40.10017102764499, 40.00110372420281, 39.80224740120673, 32.063209049163326, 39.0686974986907, 39.688027981788885, 41.52744308594735, 42.47712735206851, 45.5155090362795, 47.13121960240026, 47.518345771297334, 46.58269182328255, 47.44224002284389, 44.25221166303081, 39.93918126629245, 46.226693584072976, 43.44807870926396, 41.356451280655406, 35.016096791913434, 39.84014534181164, 35.3867333166061, 23.789749722326956, 29.029596967081872, 39.332771070541874, 51.039916392295595, 56.26879669004872, 51.120446574303415, 49.78039233915268, 43.89735091117121, 43.241707125017726, 49.18957748720723, 47.20310880291847, 50.0200609237917, 54.013347548823205, 54.68668514682401, 56.188470471289854, 55.87332371742495, 53.68897930268319, 54.038717439097745, 51.700376849020685, 50.15955217422978, 51.009718064338934, 56.14258266264393, 58.30065504197152, 58.23670471868208, 57.75152714021745, 54.64191913604737, 56.243787657830026, 57.33956844575944, 56.50085979892362, 49.54568163041146, 45.195349493334376, 48.55860933180779, 47.6860192514235, 49.02918000375071, 50.32619407100063, 51.608224684192294, 51.536272725751324, 55.17529087681925, 59.852595713830766, 62.55899975376745, 64.66994877784484, 66.31560664023122, 65.34764412910708, 66.96733197858258, 65.89158273512318, 66.8071972939276, 63.215910465486594, 66.16073577634751, 67.52448897207937, 67.07144737243652, 63.873448756433305, 20.706702047778716, 15.083060687588109, 62.37022392211422, 34.9683262455848, 30.225398194405344, 19.649858628549886, 27.44976628211237, 65.57533379523986, 47.43493656958304, 38.83699917024182, 69.4337183429349, 2.7128717832026945, 0.10515662225624246, 0.038323015981023355, 0.04550758388734633, 0.0023284924053211488, 0.10852004701812422, 0.23525260869533787, 0.0804056544157286, 0.1335524295967433, 0.17946253140126506, 0.08288693659368061, 0.2652620193698714, 0.14998567440817434, 0.15607915307965972, 0.1259722960211577, 0.12820630033891048, 0.11677225420792257, 0.19743734429920876, 0.13468021827359355, 0.1521595561456296, 0.2040367934011644, 0.29394615922243367, 0.1914168584851488, 39.35630529157577, 87.6543515728366, 48.19300520804621, 56.23698626795123, 105.68394968586584, 68.1291223341419, 26.40833973884583, 47.86758968907018, 55.81214258747717, 73.67831122490668, 24.958294399323005, 6.833755806569131, 56.94260889484037, 70.02693760779597, 71.26981904429775, 70.44029266603532, 67.84708822927168, 69.87347879717427, 68.12333291576755, 63.70697944395004, 67.72198815499583, 64.18196278233683, 60.36953664595082, 58.7159320615953, 55.70474416978898, 56.597514844709835, 55.09076772197601, 50.65742254257203, 49.04208852398781, 49.623842700835205, 50.79839252656507, 50.174504249326645, 49.13333069893622, 50.19499471110683, 50.4058103407583, 56.20100636636057, 61.87759776269237, 64.08031455932125, 61.02676114728374, 59.89356879265078, 63.13492921090896, 62.88309735636558, 62.33103159935244, 62.109174497665904, 56.37807784541961, 61.752913459654785, 60.125157294734834, 61.88871768213088, 60.685440417258974, 61.76265270479264, 54.256934581264375, 55.75891994660901, 56.63839378664571, 52.21174801549604, 49.59263632374425, 52.285421894442656, 56.34665966033936, 62.095069654526256, 53.9437960809277, 42.72598997239144, 21.759217131522394, 21.45637877525822, 38.87363018528108, 37.261190875884026, 40.73650890781034, 41.59287214279175, 45.95881139078448, 44.309184089783706, 48.010061940839215, 44.418547614928215, 42.10330194042575, 43.82554015805645, 45.680581984981416, 42.2114848321484, 46.03264608690816, 41.85342342622819, 44.42428996486049, 44.301041249305975, 48.91509394491873, 51.561226844787605, 51.0687771920235, 49.64720825995169, 51.85471819293115, 47.998310519802956, 47.22075946869389, 50.80646476437969, 44.451240570314475, 42.948737452107096, 35.16264830866168, 41.23035884672596, 37.382847109148585, 31.743380946497766, 32.22711901510916, 38.59615779692127, 57.82178463474397, 60.1121271810224, 56.10470825626005, 52.10139997543828, 47.58616747394685, 46.510677106918834, 53.60244789431172, 51.680074661008774, 53.58773900616554, 56.144916472896455, 57.13899804699806, 58.53022352341683, 59.07986917803365, 56.24755705556562, 55.82078749133695, 54.43740283289264, 53.899320325543805, 53.27503588891799, 60.65008025015555, 60.48564272542154, 60.49375418693789, 60.97015742332705, 56.55899716961769, 58.04284549528553, 60.495640846990774, 58.35632131945703, 52.43544078642323, 46.518270815572436, 50.360165719063055, 50.65466119397072, 53.86504665497811, 53.496273256117306, 55.447923060386415, 53.86035550025202, 59.22269836548836, 63.746599305060606, 65.20800775097263, 68.73557567596436, 69.43961758767405, 67.44577484746134, 72.56949640089466, 69.26842966387349, 72.93761868630686, 66.76744799460134, 71.42901236011137, 72.04441655066707, 74.08213492362731, 68.44760310265326, 24.41824874570293, 15.196452486899593, 69.53634323612337, 42.2075467724954, 39.36870390369047, 17.964998637476278, 34.205825328826904, 74.04966554334088, 61.83598533753426, 56.32578480628229, 85.68124248135476, 6.041496847906421, 0.5448512925255684, 0.2805786297446297, 0.11940309973133188, 0.12571878220525481, 0.22389544714843074, 0.28522231766293127, 0.1828961987649241, 0.13749911539977597, 0.24135000973699555, 0.21316113040572215], [0.02297846446444671, 0.012295292709172975, 0.1578534127122933, 0.05412151864279182, 0.05805146925511861, 0.17899558548965763, 0.05319661686136838, 0.17818543218797256, 0.45462396957220574, 0.08642817802366712, 0.06574429436436584, 0.35492556289799754, 3.2795795029209507, 63.83011833313973, 51.01499757459087, 37.95119070237683, 64.25740957260132, 56.50391140291768, 22.493174960536344, 30.451454193361347, 42.879923389803984, 59.439946682222434, 30.951236717162598, 10.432701553067854, 48.06500650221302, 59.03560915300923, 61.89751163605721, 59.271594632056456, 54.85954792268815, 54.53038654019756, 49.1256820771002, 52.38607383543446, 54.30574847805885, 52.40166917923958, 50.948262368479085, 48.755116155070645, 46.734758192493075, 49.534400893795876, 47.41297129661807, 45.233239589198945, 44.9355120812693, 45.02428708537933, 43.447427595815356, 45.331989180657175, 46.0108926219325, 48.71552375055129, 45.94704820263771, 43.40940021699475, 50.249774532933394, 53.963694264811856, 52.87321652135542, 56.40283584594727, 59.89194100902927, 58.158653474623165, 55.50147518034905, 62.32809374409338, 54.69777368730115, 52.456629430094075, 59.33179124709099, 57.54066836449408, 55.52513099485829, 55.56994407407699, 55.048555174181544, 52.48940867762412, 51.877283588532485, 47.406377792358406, 43.67305409523749, 46.748074639228086, 51.81339994553597, 51.80497077203567, 54.7509257255062, 41.49761346078689, 18.960847239340506, 15.525009824383645, 21.63228923274625, 27.5960648059845, 29.971216840128747, 35.31096096961729, 35.799370581103915, 33.366900951631614, 34.02201129544166, 38.50918708309051, 37.05014774876256, 39.83321059134699, 24.04074218965346, 19.18384967311736, 35.39988502379387, 39.44532348263649, 33.29147769558814, 39.583194794193396, 41.0905263500829, 47.095765298412694, 44.41160501972322, 44.54210619772635, 46.27415818552817, 42.497300101864724, 43.22898295617873, 41.715175567134736, 42.89096878420922, 35.636407867554695, 37.65267087567238, 31.88581789693525, 24.08745369603557, 21.72106815922645, 33.33480419651155, 41.17348840159755, 48.83823902376237, 50.109910657328946, 48.74598095493932, 41.621058294850016, 39.88757071956512, 40.16046177956366, 45.99761147652903, 43.70644131014424, 44.867494260111165, 51.66489508844192, 49.05863308137464, 51.1539710721662, 52.83105104200302, 53.133685435018236, 51.943555954963934, 51.040183113467315, 49.34595061886696, 49.42977559181952, 52.1237261064591, 54.2048768843374, 55.439686083024554, 52.40525814794725, 50.856588732811716, 51.445936618312714, 53.2868226112858, 51.1399015303581, 41.42297075640771, 45.356786404886556, 44.26574776249547, 45.62652780163673, 46.0416518488238, 47.76753394834457, 48.19025954892559, 48.591580775476274, 46.8428587144421, 51.8327921436679, 53.92344290210355, 60.02560361739128, 59.37486671632337, 64.00725649249169, 59.6196775282583, 60.32459020614625, 57.798509290141446, 57.79614802329772, 59.98153971087549, 64.01065326506092, 61.396209193814194, 62.79323193334765, 12.128107816942277, 17.936465355657763, 53.32062167506064, 31.40032456767175, 30.417480584113832, 15.454452268538938, 26.123034377251905, 56.88462841895319, 108.06432631707962, 57.85991399518905, 52.33085863051876, 0.7708521944380576, 0.16786449648920568, 0.05263172277820207, 0.07273412655077635, 0.1362568885087967, 0.07631492876117268, 0.040456111197389906, 0.03402181916059025, 0.13446035103932505, 0.027763849920442993, 0.05498574626061225, 0.021067343224140427, 0.11500548691518846, 0.35762832109485904, 0.11499270090773223, 0.039485918297883005, 0.1414414038581233, 0.08317882375371072, 0.1501839532847366, 0.27413368525524295, 0.1107552847374351, 0.046705059752228766, 0.187069462732442, 3.1182058395877963, 69.78400953354375, 51.69249288497433, 46.00229478651478, 73.19658925456386, 58.95857772519512, 33.42130422592163, 39.355873830856815, 46.536423544729914, 65.93941996174475, 34.31669112174742, 14.424783029863912, 54.75051387663811, 66.12499513933736, 67.81801562155447, 64.2595943327873, 58.8461547513162, 59.72130613942301, 52.77363930979083, 55.88577332035188, 58.079127419379454, 56.55370196988506, 54.83986939153364, 52.62696619956724, 50.12872626704555, 50.54804332794682, 48.75579864748063, 48.97376475795623, 48.826856305522305, 48.021166170797045, 45.49862323268768, 49.032553242098906, 48.978950131324034, 51.00489354902699, 49.99803289290398, 45.957646446843306, 51.32793211167859, 55.691678754745, 53.84550540677963, 61.02196016619283, 62.95464531067879, 59.894137536325765, 60.060006726172666, 63.10237353847873, 56.41674064820813, 57.03986014089277, 63.084946447803134, 60.78720631137971, 57.68357992172242, 59.131036496931515, 57.71742213156916, 54.25113339577952, 55.49975718221357, 51.06644730414114, 45.81271486897623, 50.385657202812936, 53.01709690401631, 56.80513766504104, 57.658947437040275, 48.23216615184661, 31.482121675245224, 18.072850088919363, 27.334976157834454, 34.46203454848259, 31.9436885464576, 40.296626860095614, 37.33605715536302, 37.00741352573518, 36.292122256371286, 42.158811323104366, 40.25087241203555, 42.129840697011645, 22.08751755376016, 25.513825570383382, 45.50683667582851, 44.764375148280976, 34.28756752321797, 41.383550936175936, 40.99116094650761, 44.182699418837025, 44.51552037269839, 45.700797880849535, 46.36668689789311, 39.57329865424864, 41.42669308570124, 41.33536069623886, 43.93473502128355, 37.25362070145146, 37.44151007744574, 31.704151361219346, 27.489521464993878, 33.97169120850102, 43.49999127849456, 45.53033951790103, 52.475900034750666, 52.697647310072384, 49.59902978712513, 43.05261358138054, 41.70034508551321, 43.91981040277789, 47.841247050992905, 47.63091387287263, 48.354406818266845, 54.62553931820778, 54.18309204040035, 52.68327182339084, 55.83654365231914, 54.767564419777166, 56.03172079209359, 55.52617826769429, 53.17110484646213, 53.28665002699822, 55.890044781469534, 58.70123886292981, 58.03395348210489, 55.67083920201948, 53.78272787217171, 53.058258256604596, 53.834922852054724, 51.431388547343595, 44.594811085731756, 49.53588747209119, 47.91087696629186, 49.78696230919131, 49.722706041028424, 52.268202689386186, 50.28952383225965, 51.739545637561434, 50.61047961634975, 53.32094723178495, 56.99469012598838, 60.16767578740274, 61.592174729993275, 63.002082455542784, 61.27419994723413, 63.91837950675719, 59.910591879198634, 61.75369401131908, 64.12536298075031, 66.41555647696218, 65.63034503690659, 68.2998787972235, 12.126919338780066, 21.16594099229382, 60.011428171588534, 37.465087444551536, 35.795683553141934, 19.977537355115338, 33.262393320760424, 61.911314456693596, 103.91584719381025, 69.21091987240699, 62.993731729445926, 1.1774743204155278, 0.10234304944113379, 0.04512714845458827, 0.19923340679416734, 0.134329441934824, 0.10227610867831016, 0.0793785143703703, 0.02277797350900308, 0.12609418827078997, 0.04298695926404288, 0.04783873964521674, 0.1512728553385504, 0.26274376578869363, 0.4409993103434963, 0.19372252266733878, 0.172376386641014, 0.20257627741704065, 0.21692498166474605, 0.4167429748321734, 0.49854841744226797, 0.3246360398348301, 0.16756091116657182, 0.5894256587470732, 6.5315018834606295, 90.42749866362541, 60.582305615948094, 52.94372504757297, 72.88775751667639, 77.38568059859738, 32.63591431802319, 40.71637930408601, 54.28153960935531, 72.88851061174947, 37.24897269279727, 16.54727755054351, 59.070600617316465, 68.97962554808586, 72.20877170562744, 67.65921454275808, 63.78791755245578, 63.58285211747693, 55.4926263132403, 61.51764185197892, 64.35264079801499, 59.42872870352961, 60.56558455190351, 55.339865684509284, 52.644628632453184, 57.06567325899678, 54.010852921393614, 52.62843316601169, 50.59541379251788, 50.167569498861994, 46.53084593434488, 51.953142227665076, 51.53087946676439, 57.02302925048336, 53.22517079691733, 46.21790747488699, 55.36580824082898, 56.913540209493334, 54.33038880748134, 60.694050019787205, 66.17931212148359, 63.095572148599935, 63.46157243174892, 65.85456340543686, 57.821023694930545, 58.207079056770574, 64.91058226554625, 64.6271086508228, 61.03088355833485, 61.72098144408196, 60.301083441703554, 58.62189323671403, 57.7352963724444, 53.93370382247433, 48.00740649623256, 53.02776575088502, 55.02620550893969, 57.75844227883124, 59.270453222336315, 52.10686383708831, 36.25116094466179, 24.62090192302581, 33.419280282912716, 35.943247041394635, 33.599772068762014, 42.715191687307055, 41.22962144113357, 40.802145850273874, 40.70769909889468, 45.67103101361183, 43.99380199370846, 46.065833260936124, 25.516849717786236, 30.084763573062038, 54.72514398636357, 47.140084158989694, 35.151767653803674, 44.03288841247559, 41.23347320864278, 46.35335868404758, 45.00290624557003, 48.62102600835985, 47.687635267934496, 42.86647358248311, 42.72912394615912, 45.20233523461127, 48.17784524733021, 40.0658816675986, 41.414667098752915, 38.32890710523052, 33.962826651911584, 38.44246756645941, 43.03837145528486, 51.56853029804846, 56.317363477522335, 57.598335050767474, 51.99043612326346, 47.796481040216264, 45.737221010269664, 46.55973811303416, 52.87910792135423, 50.11371535639609, 52.4011004355646, 57.78153327203567, 57.300250607152144, 55.44965674800258, 59.1442431173017, 58.19510013826432, 58.787417257985766, 56.127548217773445, 57.733452858463416, 57.5821082053646, 57.88614288453133, 61.61937636713828, 60.69351657744377, 62.88389359751056, 56.84337292948077, 57.03563967058736, 58.24613017420615, 58.36396601892287, 47.80729501478134, 53.751184171245946, 51.58816960550124, 53.042337356075166, 51.97953977892476, 53.892613072549146, 53.6455939662072, 55.23848418266543, 52.797503009919204, 55.40719316851709, 60.5079923906634, 66.56582247826361, 65.90120823152604, 70.9233953106788, 67.40846526238226, 68.69337097291024, 64.84328616049983, 66.20853377926734, 70.19496410123764, 71.24194668185326, 70.59246493924049, 74.1744282937819, 18.06951411308781, 20.80516922858454, 66.52087996082922, 44.587609614095385, 41.16804415179838, 20.64874706729766, 47.117742338488185, 69.304884172255, 117.92330572682043, 79.20597414816581, 70.6571134444206, 1.3081842420562622, 0.2768968724675717, 0.18679253726957307, 0.2950523595415777, 0.1941817157691525, 0.21058663064914368, 0.1362098353884874, 0.0994621298366016, 0.2221797013114537, 0.24730153231611177, 0.14302285448197397], [0.21022791763947857, 0.35466319310568994, 0.5437393005817168, 0.16620882726725072, 0.14264079111237682, 0.12231476244426544, 0.18594035638436196, 0.2724031845648443, 0.3420983399114301, 0.14868343218920693, 0.14307833456945035, 0.30358480169407787, 0.3166817795605429, 36.37863797526206, 54.98956272678991, 36.53814900305964, 15.033042623150735, 45.3387866481658, 33.80729682983891, 19.317298512304983, 35.54516569260628, 43.49318596624559, 30.4624270239184, 9.52409823094645, 48.85108086370653, 57.89145377374465, 62.23022276355375, 61.28733988731139, 56.44714686178393, 53.75990752250918, 45.76172797910629, 43.06352561519992, 54.52262024725638, 49.97867207373343, 46.720676883574455, 47.81443765086513, 44.74982315494169, 48.42313066605599, 44.82934528781522, 45.72849765900643, 45.81448385792394, 41.98632901714694, 42.24673517288701, 45.246038283071215, 51.28238554923765, 48.340003874994096, 48.17868071217691, 42.67987466627552, 44.60860606162779, 47.960141935656154, 54.18364901696482, 59.16063862462198, 60.00667033656951, 54.950570444906916, 58.085901352667044, 56.48146367842152, 54.14653555039437, 50.815548973698775, 59.72242009255194, 56.79251155545635, 54.21670283040693, 56.891861269550944, 55.8576616933269, 50.50924716457244, 50.526682099988385, 49.283078947374904, 46.51801586151124, 43.4043638936935, 49.43054045400312, 55.48900988794143, 57.12452842343239, 50.24778589125603, 35.13792560946557, 16.447436559584833, 21.14435030568031, 33.463403024981105, 29.55736952443277, 33.92626623953543, 32.905081087543124, 31.39482540469016, 30.457288718992668, 36.803952340156805, 36.202500020304036, 32.49219475253936, 21.928155576029134, 64.69862914854481, 89.34348890858313, 60.7256329444147, 32.48072574215551, 46.58362534738357, 49.66371751600697, 44.72168799369566, 47.32095249237553, 41.547929625357355, 38.77485705960182, 38.91710181390086, 38.87212791750508, 38.500742220109515, 40.75759949222688, 34.75560042165941, 15.465008347265183, 21.389794580398068, 27.35390159391588, 43.144655919844105, 37.94637010943505, 47.176381772564305, 47.127563953399665, 43.348913346567464, 43.953872265354285, 39.07299641639956, 37.25440125311575, 44.598800136197, 45.46433779501146, 44.04753454269902, 44.43941070187477, 46.37361772598759, 47.94567623446065, 51.43694654587777, 49.021986376854684, 52.367524946889574, 51.40697179302093, 52.308383449431396, 48.05125075001871, 49.351587064804576, 50.132821221505445, 56.59168620263377, 51.15972518920899, 51.11382169108237, 48.69439786480319, 49.95538103965021, 46.87174304839104, 38.97143056315761, 44.62785313206334, 44.485545619841545, 42.65584230422974, 44.058419119927194, 46.434355628105905, 48.55363576642929, 49.07536983489991, 49.95095268372567, 46.46955497803227, 48.05178811473232, 51.8787544773471, 51.603584520278446, 50.26061596408967, 52.332831582715436, 49.97387893738286, 52.6564428114122, 50.125364795807876, 58.480558472294966, 57.846770132741625, 62.199275262894176, 63.98418118876796, 57.18989079998386, 5.4507883902518985, 29.532062392080988, 51.3244451245954, 37.945236544455256, 25.2003477850268, 18.82952432478628, 27.955044046525035, 56.06815176625406, 80.34456760652604, 45.933990632334066, 65.06222894114833, 1.87972848934512, 0.03865422260376715, 0.03744598320354858, 0.4147841492968221, 0.11456363038310122, 0.5664362181578914, 0.36563197871850384, 0.22987021283516962, 0.005408348525018101, 0.015922267038765696, 0.039535514830100926, 0.47232308274795937, 0.8302887276776376, 0.5994772226099045, 0.43400505016888347, 0.1273578119974944, 0.06378625789957662, 0.354280945874991, 0.4320641204474434, 0.49922049105648075, 0.06938068391454798, 0.6154235572584215, 0.35431784066942434, 0.33470378347462226, 42.2529560519803, 60.4833246046497, 41.07042420294977, 29.400349201694613, 53.89312298067155, 37.81737904394827, 27.89564367263548, 41.34008322992633, 47.80522400333036, 36.8912446883417, 12.72990530537021, 53.628829756090724, 63.489609533740634, 70.33089776192942, 65.97479189595869, 61.590127252763324, 58.374466203874164, 48.9596285358552, 45.518752836412006, 58.124211142140055, 53.577054469816154, 49.63729250815607, 49.6357588614187, 47.853418165637606, 51.728790498548946, 46.01173200914937, 50.484426406122026, 46.97871392773044, 44.90476462148851, 43.83771127270114, 48.49525913115471, 52.53207229798841, 49.50377894986061, 51.8098541229002, 44.39620187205654, 45.983679217676965, 50.37188183876776, 58.72360814002253, 62.330258892428496, 62.92726324450586, 56.279657733055856, 61.2978792959644, 60.232065416151485, 56.26653348245929, 54.130638184085974, 62.57984322886314, 59.50413234772221, 56.36169018283967, 57.28425910395961, 59.752900831161014, 53.82036693634526, 52.79631453175699, 54.84445071989491, 50.81828678807905, 47.00672357313095, 51.447485954530784, 59.14627098268079, 61.071970385889855, 56.69717834841821, 41.8943259023851, 27.107100179118497, 26.03869753499185, 36.52912755166331, 37.45093945533999, 38.01938895256289, 36.677051897971864, 36.232933690471036, 35.51850142017488, 40.19682215106103, 43.10595781572404, 36.00456545429845, 26.88937529440849, 86.66837753788118, 109.90058391324936, 64.99728625820529, 34.46538817497992, 49.35943180514921, 51.181988562307055, 47.21497005031955, 45.8359549122472, 37.15629885273595, 37.7088313717996, 38.31448847247709, 38.11986046452677, 37.56167973241499, 40.3769491564843, 32.142562520119455, 18.3528543672254, 23.881782254865094, 39.07106661027478, 51.58280772547568, 41.336847274534165, 53.92082668119862, 49.86593531024072, 47.12897992903187, 45.22921915977232, 41.58994605464321, 40.474745611990656, 49.08533657750776, 50.34231109003867, 48.03569070754513, 47.57405519485474, 49.8493750633732, 51.09359010573357, 54.17390977182696, 52.60049412327429, 56.482989480418546, 56.83009178407731, 55.00320473024922, 51.855000603583555, 51.0285101398345, 54.98664840575188, 59.36482544868224, 54.89951687474405, 54.79717046983781, 50.57753955164264, 50.512361526489265, 48.08457912937288, 41.362907501959036, 45.97944305789086, 47.46746478542205, 48.21453902029222, 48.94635131282192, 48.979801285651426, 52.6241538601537, 52.549389562299176, 53.47369609340545, 48.41605078789496, 50.988874589243245, 53.79973526923887, 52.71061466586206, 52.13170028501942, 54.929193527467795, 53.00816958950412, 54.281194440780155, 55.240523815155036, 63.43943065212619, 63.74432040799049, 64.74866290246287, 68.87335285063713, 55.96008262326641, 6.625928042396423, 36.51787819400911, 57.007637869927194, 40.583948319958104, 33.802939076577466, 20.04684171368999, 33.39740130209154, 60.722216559994614, 93.17419328997212, 48.86984548261089, 72.1926978326613, 2.916057667424602, 0.3385928135004736, 0.13890660277778102, 0.28947937632760695, 0.19060675114873918, 0.5731266172182176, 0.464546769376724, 0.03524328889926115, 0.005782493897112868, 0.06700659275896127, 0.02998267229075634, 0.8394929982962147, 1.515371066428, 0.8146606565963838, 0.4819946976438646, 0.13606021841687543, 0.2376675323372887, 0.523173088027585, 0.5729045742942441, 0.9026960487807951, 0.255207835486339, 0.9423728455458918, 0.6334233752662136, 0.7931912570230423, 62.319617502151004, 73.06645285698676, 50.9909495230644, 23.91315729387345, 61.334843712468306, 47.83630878694596, 27.365199981197236, 49.353269761608495, 53.70649660787275, 43.170559252462084, 15.951182207753583, 60.74898673642067, 66.13919411936115, 73.84122294764366, 70.17983159711285, 66.9810994978874, 63.343077628843254, 52.62258491208477, 47.27061279358403, 62.52691084338773, 60.085396228298066, 53.07343782917146, 54.22338654918056, 51.50402299819454, 55.195828407041496, 51.52513711683212, 53.60911984597483, 52.06933459927959, 47.231326333938114, 45.82349746457992, 50.03912364282916, 58.521370733937914, 53.4971244104447, 57.68256010547761, 45.55791770258258, 46.88714619605772, 52.20292268260833, 58.11115357183642, 65.55639659204792, 67.29694443364298, 59.606498364479314, 59.13115416803668, 63.48321214798958, 58.252147090050485, 55.18980364645682, 66.06255885093444, 61.37757793549569, 57.24168962047946, 57.62543862865817, 61.681726363397416, 57.80623635938091, 58.84957505810646, 57.20665893247051, 55.5707795389237, 50.5860040264745, 56.27893993931433, 63.45324916224327, 65.87990976149037, 60.93253012626403, 48.668059149096095, 34.13730936665689, 34.11526956865865, 39.47620038063296, 35.887655288942405, 39.35629744683543, 39.20606674686555, 39.04376299150529, 37.999667275336485, 43.70765724489766, 46.8254041671753, 40.786636798612534, 22.29135136450491, 83.9886377703759, 107.6969571267405, 71.30215506399833, 36.84757301884313, 51.181666927952925, 50.48944703994259, 46.21536185664516, 46.27900623506116, 39.36435007279919, 38.016051015546246, 39.017443887649044, 39.46240540473692, 39.48484136212257, 41.3910505079454, 39.3097585247409, 25.894254292211226, 32.753273594763975, 48.71306442445325, 51.473440277961, 51.33358816946707, 60.27590574756746, 54.495795157647905, 50.728621405939904, 48.28157624890728, 45.564738704312234, 41.78442893489715, 53.134309091875636, 52.43870812077677, 51.90455975071077, 49.12696076977638, 49.01138421027891, 54.96878200961698, 58.5534361100966, 56.6106116387152, 59.957299463210575, 58.66396457918229, 60.14229413001769, 54.05265362031999, 54.298739202560924, 57.56983510909542, 62.167492297387895, 59.58162269284649, 59.91684413725331, 54.32789810242192, 52.597238556031265, 50.85695743560792, 43.5176968574524, 49.30662101314914, 48.92009104451826, 49.100143524908255, 48.6741505899737, 53.00028562545777, 54.856139383008404, 55.58841451521843, 59.297945114874075, 51.28982236308437, 49.078072347948634, 56.43131617576846, 57.67999879775509, 54.04622877797773, 57.88274218959194, 53.374385603012584, 55.966935003957445, 54.74992552111226, 64.22389291947889, 65.66530512225243, 68.10767481403967, 70.67789416159354, 63.13362698401175, 9.334896822129528, 35.637831687927246, 63.94440835522067, 46.665732322200654, 35.34223402700117, 28.681582712358047, 44.44132874088903, 66.43462704073998, 99.25952311485045, 61.23578425376647, 88.08303525370937, 3.205044173425244, 0.6418337949341344, 0.15644336660062114, 0.556195093499076, 0.23892347220211263, 0.5507372379783662, 0.5225835067610587, 0.4812492634500227, 0.10573809065165059, 0.28776456511789755, 0.16112972561630512], [0.33484477429620685, 0.5624022442967661, 0.7698575671642058, 0.2141021928119083, 0.22094196369571073, 0.1484155005985691, 0.17499371071255979, 0.49888641543446055, 0.4607637659195931, 0.12485166260552023, 0.47387385921132186, 0.18373615288686368, 0.196569336037482, 23.87072901571951, 62.271603768871685, 41.9391272144933, 22.235612523171213, 32.941433614300145, 33.22681742329752, 18.311785190336167, 38.361827558086766, 49.433929381832, 40.008540538049516, 10.041780491029064, 40.82735884574152, 63.03084519601638, 63.896002384924124, 56.67853924535937, 55.69679744781987, 55.68389284995295, 49.32915110741892, 50.271614290052845, 52.139752910983184, 49.36380917026151, 50.09187952164681, 49.005477120799405, 47.10071925194033, 48.68771414602957, 48.054416102747766, 49.07311054968065, 47.75308001425959, 43.06021513477449, 45.116231364588586, 45.96657768372567, 45.29937859504454, 46.75113408796249, 41.41369435095018, 41.49108271444998, 42.315572769411155, 46.97042203718617, 53.53302978700208, 59.44226872536444, 56.981856130784564, 55.57685921269079, 63.218707115419456, 60.803213504052934, 54.561812570018155, 54.962231651429214, 56.413281117716146, 56.30665932932208, 57.36219267691336, 56.7335073409542, 51.45149853921706, 50.24803692294706, 47.62987836714714, 52.03455102059149, 48.31656771321451, 45.25150606709142, 44.025686940839215, 48.948532150637725, 51.990902885313965, 54.950284111884336, 38.23731976170694, 26.209659922507505, 18.19535355414114, 19.022065631804928, 26.11082011653531, 32.71870770762044, 29.26865758434419, 28.795629547488307, 28.398097330524077, 32.93374576876241, 33.73854160308838, 31.451464429978405, 26.892779911718062, 72.00384355360463, 84.50722217559814, 42.58349810877154, 33.46160265707201, 42.31454903079618, 41.38007179383309, 52.01936752565446, 49.422546663591945, 45.4376107646573, 37.421356939500384, 35.7637240809779, 31.95259624911893, 34.64817846975019, 31.36194221435055, 16.21350738310045, 16.041563422449176, 32.923480926021455, 48.36746438857048, 39.70871848444785, 29.673589352638494, 44.30529309857277, 45.40134845241424, 48.64016717480075, 42.40980771280105, 39.78709528523107, 43.652791130927305, 47.71198141959406, 46.292193243580485, 46.6513882144805, 48.35306144529774, 51.69257525474795, 50.64357657586375, 48.713005588900664, 50.316862752360684, 55.281802838848485, 55.040086776979514, 50.474141951530214, 52.74635922524237, 49.56441487035444, 52.9751314655427, 55.07982823156542, 51.840346628619784, 51.21887060903734, 50.068208017656886, 47.10052705580189, 41.73413238217754, 42.6656521520307, 42.387473737039876, 45.83567642396497, 46.25291462867491, 45.79148307923348, 47.92358544565017, 48.37237519602622, 49.75097848523048, 47.89577191875827, 46.56717884925104, 48.99512598591466, 51.427234757331114, 48.33531664263818, 48.88348356370003, 46.2367073951229, 49.27251208213068, 51.73277562664401, 58.97100771627119, 61.50332912322014, 64.18197454944735, 62.579533361619525, 69.64813863077472, 40.93609086928829, 4.776820761542167, 42.36521820868216, 50.85308997861801, 43.34610100715391, 21.82835086699455, 26.206133711722593, 34.830482390619096, 54.96170605382612, 30.229163669770767, 41.796274492817545, 59.22207470863097, 4.087879239551483, 0.19352625094113812, 0.18435596398288207, 0.4368944886711336, 0.16231918437105997, 0.32749413001921873, 0.20696750872077482, 0.037682704372151245, 0.0502953652833258, 0.029459710030125517, 0.07724464540520022, 0.2702039299953369, 0.3173390523560586, 0.4114490621272595, 0.5043092147717553, 0.04858305918112878, 0.15189787583245387, 0.13782589786475705, 0.3212539455102336, 0.33118155634691643, 0.05062656424519035, 0.2267918264072749, 0.17599293451395728, 0.10944843066916352, 34.74004822392618, 73.45558335704189, 39.05175678191647, 27.959990155312326, 42.753787809802645, 35.53868201471145, 23.61517679306769, 49.44708893376012, 55.356182744426114, 48.291974452234086, 15.316436809878196, 45.82753358348724, 70.9197945748606, 66.71819871471774, 63.91006015962171, 58.99339660521477, 59.488387953850534, 54.71286304535405, 55.11493736697782, 56.88704459897934, 53.645550820135306, 53.72487291213005, 53.75605967737014, 50.908289494053015, 53.27416512273973, 51.70635846353347, 54.41552777444163, 51.95489944950227, 45.690850750092544, 46.94675837793658, 47.88391067135719, 49.17306823115195, 45.42491013003934, 44.72924247864754, 45.54254985624745, 46.07422321073471, 48.07355726918867, 54.96051365329374, 60.08490200965636, 60.50650188999792, 58.84684508846652, 66.13667595771052, 62.94977764929495, 58.992086533577215, 58.281223620137865, 60.71747049208611, 58.23289609724476, 57.100268563916615, 57.7946339884112, 53.86159496922647, 56.12146069926601, 51.341385841369636, 56.28441164570471, 53.50421997808642, 50.619681496774, 48.77671664760959, 53.002560600157715, 55.71487565194407, 59.3255272219258, 42.02545858198597, 36.79478183869393, 34.35942142240463, 23.178942549613215, 26.965541839599613, 39.389331648426676, 36.83970474427746, 34.769101219792525, 32.37451972499971, 37.83134660413189, 38.10233531459686, 35.62122045024749, 29.875897361386208, 66.2767751755253, 76.15517031761908, 42.79216427956858, 35.90561974433161, 44.430350026776715, 44.02219603138585, 49.830955613044004, 48.918223996316236, 42.9137695220209, 36.43588496792701, 35.8908716324837, 34.46172468123898, 33.84823460732737, 30.788864320324315, 20.982123036538404, 26.694733558162568, 47.51426650631813, 53.50626745531636, 38.23251093587568, 37.346333765214496, 47.7772496592614, 48.32737776540941, 49.875702011969786, 43.514021596600934, 42.09316653590049, 46.80430966038858, 49.98563820315946, 49.28492638372606, 47.16927836018224, 49.27856037693639, 57.32679720847838, 53.209061622619636, 50.90058203666441, 53.112528170308764, 59.75787831890968, 56.22803934158818, 55.36618478836552, 54.883843083535474, 52.21214417488345, 54.09511327743531, 57.020526778313425, 55.70957652984127, 54.34627440667922, 51.52361523720526, 47.08965424568423, 43.174693430623705, 43.90393264832036, 44.493908113048924, 49.837694245000044, 50.402488093222345, 50.24041968007242, 50.95297313505604, 49.48233927449873, 53.508522818165446, 51.403323988760675, 47.69264021227437, 51.175249930351015, 55.31288370009392, 51.96719607999248, 53.9363435776003, 49.94244898519209, 53.72899924555133, 55.487515464905776, 64.70363017051451, 64.57990292579898, 67.01491032877277, 62.740844757326194, 73.01304586472051, 38.90686050538094, 6.462185757775461, 49.38508410607615, 53.684064572857274, 51.02135181427003, 32.99505633692588, 25.776204678320116, 41.9159891528468, 62.8974885325278, 48.20612553627261, 54.15045007582634, 65.95516435561642, 5.245531739727144, 0.5639698440509459, 0.31577010428713215, 0.3253776742325675, 0.28664886530849243, 0.2880292944610119, 0.20967408203549925, 0.1798576029438165, 0.05092045089470283, 0.10318136413491542, 0.04374182016979303, 0.34457911647135214, 0.507896590016542, 0.7953711142463069, 0.42628110656815194, 0.21513449628987621, 0.38732734358599114, 0.26301909778868, 0.7327917819061588, 0.3757139409501707, 0.2761673729025549, 0.5644932353208142, 0.3511282489184411, 0.3342958876202184, 42.80853233029766, 82.03774498355004, 56.9959766634049, 30.328697735263457, 43.17324607603012, 47.527932043998476, 24.298416414568504, 51.13744220426006, 59.35256804189375, 52.27316841002434, 16.600300150532878, 49.85957714819139, 73.75740189706126, 70.45249908201157, 66.22157958246046, 63.0768036073254, 65.55001097340738, 57.61819401094991, 52.29864028192336, 60.62159992033436, 57.11691510292792, 54.56560157960462, 55.98968082858671, 53.46005801231631, 57.85947076735958, 54.03050791832709, 55.842729230080884, 55.99269320887905, 47.40938232791039, 47.42730755959788, 48.58217100943289, 50.922123693650775, 51.81076019041, 52.01716707598779, 49.10002585380308, 48.26757730976228, 49.82002004500359, 57.95977753977622, 65.69932383875694, 62.32181795181767, 59.046819286961714, 69.08920088121968, 65.00865720933484, 60.80546886690202, 57.06590860120712, 62.637317718998084, 62.13890606357206, 57.26515323885026, 57.015137441696666, 54.07416389834497, 57.47543542615829, 50.59926163765692, 57.97328618264968, 58.005496686504735, 51.66531478205035, 51.595425990320024, 54.82828271004462, 61.95707282712383, 63.64959124595889, 47.09666744355233, 40.426680887899096, 41.605694370885054, 30.798111308005552, 36.8323032317623, 44.98603220908873, 42.07011084402762, 40.42528452411775, 38.24268948647284, 40.0930715376331, 45.95188056269, 41.58059904652257, 33.39855055655203, 55.1499641326166, 72.59095961047758, 48.74023468263688, 39.51952295918619, 50.027383988903416, 47.832955160448634, 52.376420882440385, 52.33750704796084, 44.75016440114668, 38.373112217072524, 36.42042298470774, 37.52617835998535, 36.487487669914, 35.225708253922, 28.81736340061311, 33.79143084249189, 53.242597887592936, 59.883260803837935, 46.4259264546056, 44.142942274770434, 52.41204777071553, 52.39774680906727, 52.79613802509924, 46.327474963280466, 46.30514490988947, 49.66472164277108, 53.36294797159011, 54.878920508969216, 50.96312422906199, 52.16769587609076, 58.31396756633636, 54.40397247191399, 54.21687541469451, 55.22199846083119, 62.415178206659135, 59.35320738823184, 56.23624101761849, 58.297713264342285, 56.71900241605697, 59.04561511931881, 61.50749075797297, 58.81753321616881, 56.91727038352721, 53.36876092418548, 50.33161478657877, 43.99713600835493, 45.831369661515765, 48.99854629270492, 51.08594148389755, 52.35194921493531, 52.508047780682965, 54.86642775997039, 52.64414225855182, 56.907817471411924, 53.66533525528447, 48.39394823197396, 52.204342580610714, 57.919098638719134, 52.76397851205642, 54.12617452682988, 52.162306539474, 52.16131810219058, 54.385811898016165, 64.05849441405266, 65.983334818194, 68.35632954874347, 63.335303491161724, 74.95816492265271, 47.67369124197191, 7.694344414818672, 49.9206562965147, 61.262750548701135, 52.207656983406316, 31.440887758808753, 40.8801539482609, 56.21528771615798, 65.75846533621511, 43.102023678441206, 60.67232793377292, 81.83529576947613, 6.336110484215522, 0.7504307418580979, 0.43124875774787325, 0.6985121664981688, 0.29578587340731777, 0.5617724587359737, 0.40599341293977154, 0.3925866291167275, 0.1587100828727407, 0.22794676524016166, 0.18421520298767477], [0.32103959410901994, 0.395520408788035, 0.4748260758576855, 0.4031464463520435, 0.004254661288277637, 0.13174342021586435, 0.1502710421599688, 0.18814039236355215, 0.05482337775550062, 0.08768943453868551, 0.1652183521899485, 0.2551249907382073, 0.12994087661706633, 28.234540377893758, 62.789623352789114, 54.53686629572223, 59.317521664404104, 32.292408827812444, 40.59010644112864, 29.52835967463832, 38.92663709578976, 47.83105673328523, 52.89859033400013, 20.47090680368485, 37.193047538880386, 65.29005196786696, 64.77538601044687, 62.31066273104761, 59.22751111368979, 56.07997771232359, 58.85701187195317, 61.167048638866795, 57.34008619862219, 58.602916809820364, 58.52681498373709, 55.76404256205405, 56.32401189496441, 55.16904646350492, 61.0211286237163, 56.2723268232038, 56.51020288467408, 54.30898443345101, 48.633255958557136, 45.149289100400864, 43.546820455981845, 41.653739483125754, 41.88769317442372, 42.909854996588926, 42.58425120384463, 43.56736975331461, 43.684617242505475, 46.76138324122275, 53.932566335124356, 53.96917773831276, 53.19223857695057, 49.945657483993045, 54.15075209832961, 57.86308719265846, 54.460548739279474, 57.684034916662405, 59.26014523352347, 58.74212172723586, 57.01923239615656, 53.47521797303231, 50.76095350327031, 50.84284867009809, 50.56116365617322, 49.24725201822097, 44.384885834109404, 48.963597974469586, 48.94579825862762, 53.456822056924146, 38.77974433283652, 37.10786150347802, 33.92146525844451, 12.45325759533913, 9.703393693893187, 22.249362391810266, 26.94948365611415, 22.35985555956441, 21.934347037346136, 26.95409244106662, 25.414471933918616, 25.45744542152651, 20.868111502739694, 32.52605657423697, 31.59339539466366, 25.01298204545052, 35.70134270575739, 43.94468215204055, 43.31480049317883, 36.254094877550685, 39.06982714130033, 40.31337145836123, 32.34428413452641, 29.40162201081553, 32.85996010226588, 33.78123268004387, 35.00887178605603, 40.496212743943744, 50.26605629151868, 44.57427355550951, 44.03905830075664, 26.47184487312071, 39.08332401706327, 49.16805936444191, 48.30210593438918, 48.32645993078909, 43.33579694071124, 41.021127854624105, 42.75894964894941, 44.51685397855697, 41.07344050561228, 45.394547062535445, 50.19768937941521, 47.846024497862786, 52.007965195563536, 51.87531455870598, 51.103509779899355, 52.21964374665291, 50.99389522306381, 52.157081942404474, 50.63140546121905, 48.40169883543446, 48.98801080642208, 49.93506316215762, 51.02120668657365, 54.32183804050569, 47.918047058966856, 40.81395610686272, 43.52369416144587, 41.4272932083376, 42.53003620332287, 40.39604717685331, 42.4801750336924, 43.91111058573569, 47.04972059495988, 47.19598185631537, 47.595734134797134, 46.629968150969475, 52.77032098462505, 50.4956796861464, 51.912816339923495, 51.62727171374906, 52.387760454608554, 48.89368564851823, 56.21202038180444, 58.19344097568143, 64.91732874224263, 61.886909469481445, 69.97590757185414, 64.0075114465529, 66.54093896189045, 17.774444010949907, 7.543010057941561, 50.48730542582851, 50.50599159732942, 39.84631915246287, 16.910018344079297, 29.70709816102059, 25.741980037381573, 58.297124908816436, 31.013967183328447, 40.47150573422832, 60.37546726965136, 4.894141795173769, 0.2617895266702098, 0.11522069633487733, 0.062137349403553435, 0.09521605687276011, 0.033666580359661774, 0.06467805319135228, 0.032080477666890914, 0.008664775222930457, 0.14344619466893135, 0.025307590089317773, 0.0910941361179275, 0.39083041851559, 0.38757184820790447, 0.22398586084525432, 0.07234702998351666, 0.06094995142531492, 0.11942882496382921, 0.14137161324822134, 0.02258396748783848, 0.13162409436077843, 0.15142486250448614, 0.3180790013603626, 0.2623640926134202, 32.18209020553097, 68.81858871829125, 58.191919096054576, 58.48907393793906, 37.34613764670588, 44.629292641916585, 29.872586880960775, 48.56449288706626, 51.82252730092695, 61.76730855818718, 26.525149883762484, 39.904213336206254, 67.45196434759325, 69.8621980605587, 66.2146605214765, 62.6325402721282, 61.22832390569872, 61.769246209052305, 63.57152039004911, 61.67102613756734, 61.40340282071022, 62.905399953165364, 59.58183450083579, 59.3059036039537, 60.42148451651297, 64.45467341330745, 60.33282718350811, 58.845946865697066, 58.680803314332046, 51.5794187976468, 49.5303883091096, 47.766525899210286, 45.78541517257691, 46.416132296285326, 45.6013265732796, 45.90704787162043, 45.293016510625044, 48.34100800175821, 48.90379359645229, 54.39002060121106, 55.783517129959606, 55.336159044696444, 54.23983304731308, 58.065732525240996, 61.10328266697546, 57.12248879094278, 58.46678703061996, 59.87700070104292, 59.12097169506935, 57.01785956659625, 56.84035662681826, 55.959376596635394, 56.26096763918477, 56.068073318850615, 51.355937834708925, 47.26172078040339, 53.747563823576904, 54.9998785603431, 58.86713158699774, 45.90262343806606, 40.467614743017386, 48.75264506186209, 30.780466525785386, 23.498058742092503, 29.821199909333263, 31.927398943131973, 30.382318496704105, 27.38968929936809, 31.33982396894886, 29.155848257003296, 31.39859284124067, 28.18261015799738, 31.470285923250263, 33.21973362276631, 33.31231724831366, 40.225992818032545, 49.635503907357496, 47.44524063602571, 38.27180131789177, 38.60130786895752, 38.26385067355248, 35.36872179277482, 33.876926745137865, 37.20708962409727, 39.21348787123157, 40.782569300743845, 49.54736824958555, 55.8730334620322, 48.50692033767701, 46.88380433667091, 29.655067920684818, 42.98581953971617, 50.98294004317253, 50.8707171101724, 51.87455361889255, 47.222803023553666, 45.18500620318998, 45.59091660284227, 47.88995504379273, 45.1827351508602, 47.78748312304097, 49.4774833802254, 48.52553982888499, 53.60274991681499, 53.56554623573057, 56.79076610072967, 54.099118017381244, 53.09729368455949, 56.49963209705969, 55.38679292125087, 52.303625614412375, 52.93742179870606, 54.8130678361462, 55.144688544734834, 56.497663067233184, 50.40005622371551, 44.81006683841829, 44.746010611134196, 42.66114927107289, 46.87204899326448, 44.17634910152805, 45.545797578750125, 48.26416877008254, 49.15092252915906, 47.63269855130104, 49.95713433911724, 50.629103029927904, 54.47335527789209, 53.58602885277041, 55.87274712900962, 55.20903502741168, 55.79235422995783, 51.45390687450286, 61.41125148342502, 61.93140091434602, 69.79222297668457, 65.60048403278475, 72.34390520280408, 67.3612242360269, 66.0545572157829, 15.228876759929044, 9.855482616732198, 57.758234393212106, 51.703024448887, 50.73103758596605, 20.77664379150637, 33.60833852521835, 28.78656691120517, 69.25114770089426, 37.326102179865686, 39.94613170623779, 69.58138773518225, 5.969488015097957, 0.18269393623115557, 0.11058943436270761, 0.06432055826148679, 0.18905134751431404, 0.0769808889937497, 0.01889618301403619, 0.13692674046802905, 0.058143020592509746, 0.09526471111683116, 0.023594713251617168, 0.3530845310418837, 0.36731777051764153, 0.6044175091289705, 0.38418619923533937, 0.1375084463506937, 0.20213570025178695, 0.23453588747689802, 0.3200947625502464, 0.10788701324453277, 0.15207003111079817, 0.24437899881553268, 0.34778592987887325, 0.3220841396720179, 43.54686752442391, 81.8940136509557, 68.07941021457796, 79.5311386354508, 46.220829640665364, 57.0977347127853, 34.78804626772481, 52.4559469376841, 61.82061749119913, 67.49385526103359, 31.18785369780756, 45.720907872723, 74.48112626229563, 72.70004856971003, 69.14606740397792, 65.37506149661156, 63.348141408735714, 65.3366614926246, 65.58651647260113, 63.49341031043761, 63.96418102325932, 62.34716823024135, 60.95951995541973, 61.51122485437701, 62.98872286273588, 69.46778805025163, 62.570766864284394, 61.06358043609127, 59.96093942273048, 53.88754144791634, 50.465383298935436, 50.29548975729173, 48.088485810064505, 49.15883787216679, 49.587101859431115, 49.6846394385061, 48.43538807284448, 49.19440984725953, 53.479057973431004, 59.21970559704689, 59.317949202752885, 59.96027654217136, 58.816442797260905, 59.08148911691482, 62.458014411311, 60.22446778512771, 61.53634371296052, 61.64889220268496, 61.99277031806208, 59.794670151126006, 58.56480706122614, 56.98858299563008, 54.54174964658676, 59.9010605196799, 54.37430758630076, 52.38292024981592, 58.269083884454545, 56.797296847066576, 62.07459095985659, 48.55416136403238, 44.80051978941887, 53.49054267329555, 39.103602670854144, 29.627687815696966, 40.85653343508321, 39.810221579767045, 38.828781804730816, 32.16402769088745, 36.42808729602445, 35.7265047104128, 37.424126132842034, 35.332510471343994, 42.4160756603364, 42.21007670125654, 42.256901956373646, 52.8955622642271, 56.42950796311902, 55.58377827367475, 40.656398419410955, 44.071449233639626, 41.55522131150769, 39.18606658135691, 37.450598209134995, 41.092562060202326, 45.37364475188717, 47.80068189867082, 51.35920909143264, 62.67643551672659, 52.61847819051435, 50.075578151210664, 39.03848348125335, 46.53069296190816, 54.81324434280396, 52.81885639313729, 52.029110693162494, 49.9437786686805, 47.94452698000016, 49.225043558305316, 52.27647104570943, 47.42493452564363, 51.09691627563969, 54.6867439823766, 50.891407612831365, 56.19424027781333, 54.73169042218117, 58.49619696217199, 58.35437582385156, 58.07427936984647, 60.170221405644575, 58.60449360262964, 56.11481228182393, 57.43617250073341, 57.72516881265948, 56.802450841473, 60.65183747199274, 55.0559998327686, 47.04928128950058, 48.93294465157294, 44.53486942475842, 48.35125715501847, 45.44722449394965, 50.77111244201661, 49.834481823828916, 51.7561843318324, 50.90396311975295, 51.66334967459402, 51.51798663600799, 54.9597958595522, 55.418473905132664, 57.58444986035747, 55.25826077307425, 59.39047774960918, 52.59956844391362, 60.942536092573604, 64.84142303466797, 72.83377001362463, 67.65768481839088, 75.09344746989589, 68.64778518676758, 72.21467879510695, 20.929969241542203, 9.489090096565986, 59.55202448752619, 61.09048789547336, 48.78323562683598, 21.60703701357688, 43.17841183754706, 39.67234634583996, 74.96394649628671, 41.9913221943763, 54.16875969979071, 79.52890288445258, 8.622889557192403, 0.5579862683530777, 0.3611605992961315, 0.2937601530744184, 0.2605778207221339, 0.20403803446360175, 0.14729505104403343, 0.3482065121493032, 0.15388360637570583, 0.16437511921169298, 0.14868833515192234], [0.06647951660617706, 0.032089739669895465, 0.17428602933162646, 0.03586248329450046, 0.06317130763143783, 0.04440067110643272, 0.032813445694984934, 0.09753971646029143, 0.14134902897621357, 0.1596751238309568, 0.06499277743240518, 0.19586206834402778, 0.42872569313453096, 15.31189274403357, 64.28175964663106, 59.30713522818781, 60.622917836712254, 41.005705095106556, 35.57859997595511, 24.02186970556936, 24.42540511008232, 39.58573649006505, 58.17096579459406, 30.83714281359027, 29.098448291901622, 60.60445524031117, 61.69223439308905, 62.54707967081378, 59.19440630943545, 57.118417370703916, 58.489615225022845, 57.86371084951586, 59.76871975006596, 60.2880847069525, 57.1817518818763, 59.07022014740975, 57.484327439338934, 60.0580180844953, 56.41687793116416, 57.856525067360174, 59.64977779696065, 57.50073079139956, 56.49055965485112, 50.38527281053605, 44.833424552794426, 46.23324394226075, 44.70275863524407, 44.71678503098027, 45.791918462322606, 45.48418106571321, 43.14334192583638, 44.45094639255155, 44.72833248876756, 45.538435289936686, 47.948214007962136, 52.34103325874575, 55.04511917791059, 56.80241946251162, 58.68121908557031, 56.35479857844692, 57.258814688651796, 56.819317033213956, 52.07777946226059, 50.17666155292142, 50.2025923421306, 53.60111036608296, 50.09751596758443, 44.54150999746015, 43.441689168253255, 45.74306141945624, 50.168334361045595, 50.489729450595, 41.21494393194876, 27.055799499634777, 37.00546018538937, 31.12265802198841, 30.251793784479943, 21.767738480721754, 24.89293790632679, 25.763052971132343, 25.317279523418797, 21.91642180565865, 17.913733259324108, 15.706583203807956, 17.451272087712443, 13.601527540914475, 14.392055753738651, 17.87238951652281, 16.99677332755058, 11.928328756363163, 12.556413969685956, 10.975920404157332, 26.098572515672256, 32.738629425725634, 34.086498983444706, 36.27334587035641, 40.57454247628489, 47.69762946713356, 52.911871479403594, 52.55411601835682, 44.23293321363388, 50.65159390049596, 37.990504618613954, 22.442233177923388, 42.74219328357328, 50.7823774891515, 48.852936144798036, 45.863944945796845, 41.702557302290394, 40.91853041802683, 42.69641530129218, 40.97970370323428, 44.306850279531176, 48.427951258997766, 51.006737063007975, 52.22127153027443, 49.51979398727418, 51.04539986579649, 53.543933976081114, 51.258274739788426, 51.22968850597259, 53.03461028683571, 52.63312039836761, 47.55070924758912, 50.6521979455025, 52.836581583945986, 56.316830035178896, 49.714594579512074, 41.56036746117377, 41.85940896311114, 46.238460694589925, 43.358111304621545, 45.29806460103681, 42.278474992321385, 46.21819380790957, 44.69893824669623, 48.17355025199152, 47.454120882095836, 53.26647727720199, 52.385473712798095, 58.44655544527116, 54.37309165154734, 57.41061041432043, 50.68150981780022, 53.88618823020689, 50.868320541997115, 62.56998239024993, 58.17358986023934, 66.1139811238935, 63.48348279153148, 70.73159140925254, 62.18043611895654, 49.8326422322181, 4.633188468794669, 15.348933646755835, 51.19423027961485, 51.49060456983505, 23.99917487175234, 25.533547247609786, 27.79048885068586, 36.04351459010955, 36.27198873027679, 39.80762497071297, 46.8536413100458, 48.37907460428054, 6.355052590370179, 0.6340842946402488, 0.2796704171886367, 0.18540545847387085, 0.1444774103020468, 0.07112865140962024, 0.09385984375952713, 0.2617175756923614, 0.08009393323933886, 0.11646157491110987, 0.15589035837160004, 0.0767922858076711, 0.12191652695858672, 0.11194188598423235, 0.030163934439300533, 0.11275851272887762, 0.046158092126490614, 0.06647753243845317, 0.06812922566408111, 0.05434602070900221, 0.19324229279112434, 0.10035791644646276, 0.40176908155122115, 0.560252724155303, 21.292880658180486, 70.64656226865708, 67.74971931211411, 66.35776427484328, 42.57002476722964, 42.578877556708555, 26.16342498410133, 28.6961543175482, 45.56872383240731, 66.44498994273525, 36.785964350546564, 32.19594401697959, 60.530455804640255, 66.12009217662197, 64.1576676214895, 64.686842426177, 60.47259299985824, 62.766304862114694, 62.03078985214234, 64.35417052238219, 63.50989995464202, 62.111206285415165, 60.51989678413638, 60.37208618656282, 63.051300356465006, 62.48009735538114, 59.05964151505501, 63.096156581755615, 59.99125542179231, 59.918456231394124, 54.658157748560754, 47.886526892262125, 48.036498715800626, 48.17150669713175, 48.01290173684397, 49.19577875444966, 49.32229872672789, 47.77389603276407, 48.17226763694517, 47.787153643946496, 49.45233314268051, 50.63986601368074, 54.8467335393352, 58.58216747160881, 58.8752705051053, 59.516232859703806, 57.68219140268142, 59.70347896698983, 60.129307162377145, 55.370409181041104, 54.80932197263164, 53.637207938778786, 55.453092744273526, 55.219597970285726, 50.175712339339725, 47.849731137675626, 49.76327511572069, 53.39912006931921, 53.45755554014637, 50.64364325615668, 31.321892853706117, 38.606359881739465, 45.846682594668486, 41.33028122686571, 35.21437260412401, 32.30133810350972, 31.85488020220111, 30.296002818692116, 25.649855329144387, 21.589296133287494, 21.117566400958648, 21.957030104052638, 19.919239167244207, 19.698162617221957, 20.8315981588056, 21.8934053374875, 19.090546292643396, 16.96786545938061, 17.38989483925604, 32.531404725966915, 38.01941248678392, 37.77662954022808, 41.49906473775064, 44.33581306088356, 53.63146951121669, 58.0454146477484, 53.81387541371008, 49.21380596776163, 53.806218947133715, 40.54662696776852, 27.163548969453384, 47.37106469369704, 54.93872488698652, 54.61692971567954, 48.49722423861104, 46.54149909173289, 44.752431531106275, 47.487213919239665, 44.67781628331831, 46.553536845791726, 50.00033140182496, 52.22739042774324, 54.59775717027726, 52.07101729608352, 54.93719516261932, 55.94302423538701, 52.69040269236411, 54.41246832570722, 56.38426734555153, 55.10560997070805, 51.40184133283554, 52.29531411201724, 53.321810153222856, 57.244176403168716, 51.160772462044996, 45.97671701062111, 45.4834593496015, 48.70525890781034, 47.6580645192054, 48.77961920153711, 45.910687831140336, 48.30236088845038, 47.87616006789669, 53.476665327625895, 51.15018990732009, 57.72214074288645, 57.369617723649554, 63.11485059799687, 57.618719608553, 60.06395655293619, 53.83098871477189, 56.77440197237077, 56.492061922627116, 66.78215688274753, 63.412464357191524, 71.40003388927829, 68.38431958229312, 77.15891268945511, 63.8139150219579, 44.51899951504123, 4.065727899151464, 18.344154550183205, 56.35550460507793, 55.07863975340321, 33.008109984859345, 27.392064294507428, 32.23717989460115, 39.70051288604736, 48.953705756895005, 44.64172655536283, 50.6735356392399, 60.49119287921537, 9.445852829564004, 0.9334963379848389, 0.1323190433604102, 0.27543318487944146, 0.10466168349188183, 0.0713894430608038, 0.07491866457125834, 0.1594618755963541, 0.057721484542614034, 0.0492023799808756, 0.13215788910465856, 0.17923661207239475, 0.2861311430892637, 0.20479192626812767, 0.27619648424367754, 0.18837300730088066, 0.21973978788141282, 0.2184894251366777, 0.21706767320152254, 0.23857684805989268, 0.26175358182480263, 0.19940588382943986, 0.5430254292103552, 0.6867706739614088, 26.572165373832952, 85.97005444188272, 70.8705609844577, 79.70925346497567, 59.767252783621515, 49.46508084574054, 33.17405762210969, 33.260879285873905, 54.180824910440755, 72.90847547592656, 39.156217344345585, 36.382297546632834, 67.46435119259742, 70.10318063920545, 68.36361731252363, 66.22266215662803, 65.450574967169, 64.56406831741333, 64.93987060362294, 65.58192337712934, 67.46904234732351, 62.62285201780258, 62.94439615741853, 61.48329365637995, 67.04666583768784, 64.1812999017777, 64.94167881627237, 66.94688858524447, 63.33194201992404, 62.44115998668056, 57.491348481947384, 50.566631440193426, 50.59617865470148, 49.13989282423451, 50.536107555512466, 50.29622324051396, 52.99899124330091, 48.77275505373555, 51.26402101209087, 52.09029182311028, 52.34210798817297, 53.28706579823648, 57.54486530057846, 59.97164357093073, 61.61463422159995, 62.482227202384706, 58.454529623831476, 61.473122950523134, 62.82410883134412, 57.582539666083555, 58.761780646539506, 55.784019193341656, 58.255849807493156, 57.45165017343337, 52.73210533203618, 50.317874723865145, 53.45657886997346, 57.55840532241329, 59.12683563847696, 54.26197090456563, 42.24976324266003, 48.47331739241078, 53.076403141021736, 46.12199767943352, 42.48231272543631, 38.869594066373764, 38.794853302740286, 37.943577381872366, 33.04095983505249, 30.8196686544726, 28.799555840030795, 31.226983262646584, 26.941242756382113, 31.290425638998713, 32.84318412503889, 36.447691302145685, 33.130480089495265, 28.755219328788023, 22.395619730795584, 37.31906937014672, 43.49961473095802, 43.37511477931854, 44.72306474562615, 48.81103346424718, 58.26390243345692, 62.79627569260136, 62.938324328391786, 55.030747613599225, 56.46822960146012, 47.77525709521386, 30.283064880678733, 50.09460556891657, 58.648337856415786, 56.80477680698518, 52.28450013745216, 48.6325381648156, 47.34430236201133, 51.97837875735376, 48.0030801219325, 50.979029440110736, 53.938077265216464, 54.08292255093975, 56.388358377641254, 53.27403568452405, 59.48013136463781, 58.27819947273501, 55.59802824451078, 56.127050076761556, 59.37182687943982, 59.213672991721864, 52.503960670963416, 54.14383695971582, 56.85227670977193, 61.99276247332173, 56.9357604365195, 47.519122400591456, 48.118597845877375, 51.95628012380293, 49.878502584272816, 51.616747994576734, 49.159351702659364, 50.17188802842171, 49.95503587107505, 55.495917181814875, 53.13625066511093, 58.023606269590324, 58.33696442265665, 68.42870512316304, 59.51158877341979, 63.62690817925238, 55.753048158461056, 61.526333824280776, 58.728958252937566, 71.76623421330606, 65.95078699050411, 74.68004534321447, 70.80129977195494, 78.27526630893831, 65.57341183385542, 55.00303214596164, 6.762344644915673, 17.45910309976147, 60.127824506452015, 65.92740181953677, 32.74969639316682, 34.92036350311772, 39.57388308740432, 59.110871591875636, 51.965266273867705, 54.54538960610667, 60.110267977560724, 68.26556590295607, 11.324794638541437, 1.1269253876901444, 0.46428620755191774, 0.34603382550900985, 0.22493164235305405, 0.2532682694014042, 0.2142065186654368, 0.5123052728031913, 0.1590691023175755, 0.16871425653657607, 0.23545864038169387], [0.07380006894949945, 0.05942979932672555, 0.1639001446986391, 0.08090389501904288, 0.14299552046483563, 0.032021622962108066, 0.06852735389745043, 0.12163730323194497, 0.09936384075591642, 0.12036290830902516, 0.028351517882378354, 0.04635849306660314, 0.1298988490335403, 14.92366635030316, 71.99712845586961, 32.686728623605546, 33.717611835848906, 38.71429566414126, 29.10272171420436, 20.276331747731856, 21.312402294528102, 37.112289859402566, 64.50639770876977, 42.42677196379631, 23.503053880506947, 51.66297704942765, 61.458857290206424, 60.41531070586174, 62.10643276091545, 53.70132300161547, 58.8784868486466, 59.48244948540965, 60.110032635350386, 60.43804476338049, 60.0068703774483, 61.371588476242565, 59.549412188991425, 59.76692722689722, 56.193585241994555, 57.65483679309968, 57.85785082847842, 58.085685622307565, 59.43039963322302, 58.52932922301754, 52.45164017523489, 44.86919264639578, 47.062762475782826, 44.64441730130104, 44.85773540312245, 45.404996256674494, 43.07720684236096, 44.28284929644677, 46.43821131798529, 48.13669566185244, 49.809221759919204, 54.4841064945344, 60.10394119447278, 58.14060664946034, 55.88385528133762, 57.44656678169005, 55.431292210855794, 54.842622895394605, 53.19591383780203, 47.206168251652876, 52.082651046014604, 51.033785727716264, 54.00718942765267, 50.093581830301595, 44.65055188825054, 44.963192247575336, 47.66124163904498, 46.7367664460213, 46.71713890567903, 23.29494664745946, 29.177644868050855, 34.915009467832505, 32.36508838592037, 37.63072521455827, 30.540797941146362, 21.37514256661938, 17.343404946788667, 16.874934704073016, 14.734062898543574, 14.07418687497416, 12.953350966976537, 13.079008998409396, 11.467816022134597, 7.663949478057123, 4.026066853154091, 0.9723472306805273, 5.4944066174568675, 11.612744658224045, 24.226415426500385, 33.38987819610104, 36.92255304705712, 38.24206190724527, 51.813513694270966, 53.50694602535617, 51.70944536885908, 44.67287017453102, 46.19018416250906, 47.3565480016893, 29.664169780669678, 23.983146106043172, 46.60741844484883, 46.49219489866688, 48.77760310326853, 43.840951150463475, 41.996789978396514, 41.108306454074004, 42.900068683008996, 41.55660983054869, 43.604369471150065, 46.409503490694114, 51.55972849938178, 52.14007454533731, 53.8375900637719, 53.56552662387971, 52.74810860233923, 53.28223736055436, 51.429945115120184, 51.49855129180416, 50.94964696514992, 52.06665169808173, 52.410274859397646, 51.58579264917682, 50.03829210035263, 42.97020458406018, 44.332883050364835, 42.588295167492284, 46.15212540472708, 45.98202789983442, 46.418736750079745, 46.93830959258541, 48.193366066102065, 50.52616434712564, 53.29656185642366, 53.14067117629513, 56.1546008048519, 56.33641442944927, 58.17267594798919, 57.35710928517004, 54.51587377055999, 54.236271535196614, 51.255121154169885, 55.761873491348766, 63.547213462091264, 63.03557165207402, 67.77152769027218, 69.66265924515264, 68.22831123105942, 47.3744143978242, 21.31648155950731, 1.191893320891165, 25.14686626772727, 56.21102409978067, 42.11276661965155, 14.962474280788054, 27.680503629869033, 22.12162648477862, 36.9205447935289, 28.318518323283044, 38.597122699983665, 55.12670055512459, 60.405963697741115, 9.147616394104498, 0.14841124114971008, 0.15242525075952854, 0.17207405770257597, 0.1645450068697814, 0.13139684203891985, 0.11314506537371105, 0.09063742514098845, 0.03876511000036713, 0.06328463501807663, 0.09733927721578269, 0.02900054757182877, 0.10313525330275299, 0.05730176029065925, 0.0204295156553628, 0.06963918496283793, 0.07862376454736918, 0.022964178839878693, 0.060866252489147656, 0.07109587050734029, 0.10149700492019616, 0.06058084260251734, 0.12826160422616428, 0.1510324263043942, 20.493156448487316, 82.89351986300561, 41.3556158158087, 39.70650626767067, 45.208207022759225, 34.173320647208925, 24.97892998879956, 26.628210160040087, 41.417946200216974, 71.17999676735171, 50.13602187556606, 23.505524973715506, 52.232634636663626, 67.9591581898351, 64.31457027312248, 66.23646105489424, 59.14140332129694, 61.54991903612691, 63.785442536877056, 65.49610584012925, 64.02501698463195, 63.55627413718932, 63.7593940765627, 62.96641634356592, 60.60953470968432, 60.08565510472944, 60.16502426516626, 62.22076985143847, 62.17667456596129, 61.49457047062536, 61.831698186935924, 57.46186402536208, 47.78075625819545, 51.63818374756844, 47.24609405763688, 48.59629938679357, 48.53052123900383, 44.599823874811975, 46.43413205300608, 47.56939541909003, 50.145670906189956, 52.174838512174546, 57.30148223138625, 62.12230659300282, 60.66175714615853, 59.08373271265338, 59.481021742666925, 56.69539759235998, 57.614950210817405, 55.71290662211757, 51.2726306146191, 55.1777619700278, 56.28682782573085, 57.39522295613443, 53.74645379281814, 48.72927165800526, 49.54866263174242, 53.12520919307586, 48.879965197655466, 53.872216747653106, 31.02379664298027, 33.11648115035027, 44.55574427881549, 38.40392635714623, 44.4968734248992, 39.9494461090334, 25.43708832033219, 22.051782800305276, 23.040318142983224, 20.83060972152218, 21.038224697113037, 20.360172410165113, 20.101996121868012, 15.098716828130907, 11.131115844172816, 10.929203994812505, 5.790281786072639, 9.659609256252166, 16.348460451249156, 25.969910929279944, 31.91963265019079, 40.009501518741736, 40.82441706811228, 54.99712897885231, 54.11567434187859, 52.90321873080347, 51.460676885420284, 46.81387632123886, 52.555790870420395, 31.653627311029744, 29.360205704166045, 49.78824884660783, 51.2600358839958, 52.97566883025631, 47.07498850360994, 46.62177039730934, 46.22126502375449, 48.89911813120688, 45.73711118390484, 47.679421824793664, 49.447363499672186, 53.08386741145965, 56.64844682139736, 57.94160519876788, 57.04185270494031, 55.0776199371584, 56.72821998596192, 54.42159960346838, 54.55277935151131, 52.70202075281451, 53.859402364300145, 52.25178757021504, 50.59986960503363, 48.570682387198175, 45.518419434947354, 46.33402924383841, 46.735703483704604, 48.9196595837993, 50.847747710443315, 50.16845987689111, 51.0154604142712, 53.6226559454395, 55.56830452334497, 55.80378009426979, 58.56656820543351, 58.74595388289421, 59.78555848521572, 61.43365606184929, 61.78169973434941, 60.506799990131015, 58.14055173627792, 58.397553274708415, 59.32895145108623, 68.76336959100539, 68.45598913008168, 69.50915336608887, 73.91381817479288, 68.15402938473609, 45.89896386669528, 18.556078249408355, 1.5617462295678355, 32.77565463896721, 60.149311250255955, 47.82579683488416, 18.06577217194342, 29.451649881178334, 28.063960421469908, 41.01908429976433, 39.65205592493857, 40.990784398971066, 60.238415733460464, 71.42173244107154, 10.709097250815361, 0.31263082919101565, 0.17095771437931448, 0.052963174549081636, 0.1705414834882944, 0.13406797612626709, 0.06186594360417897, 0.06824548716746992, 0.095044476160359, 0.03385105050138889, 0.04044957263695617, 0.1643527341225455, 0.18831666919492906, 0.19709622066828514, 0.11554244560219588, 0.3595557370253148, 0.18254016706299397, 0.09595856461073123, 0.1932670221093201, 0.17051597276041586, 0.19968743646337142, 0.14312888105069438, 0.3265608204228263, 0.2601853385567665, 25.817662169856412, 97.83664411114108, 45.16610430132958, 46.88118811576597, 60.869834961429724, 39.4460020526763, 27.438167833512832, 29.10546933451007, 49.07320860893496, 76.19346049524124, 52.6245500195411, 28.633686650183897, 57.4222049405498, 74.65420476851925, 71.59313217286142, 69.55065204251197, 61.321868511938284, 64.55269344391363, 66.14328907382104, 69.28025168757286, 67.18656893699401, 63.383136795413115, 67.58556027566233, 67.50264921495992, 64.61361569743003, 63.26337506694179, 62.724904244945904, 65.82879343340474, 64.35648864315402, 64.99773733077511, 63.81794329612487, 59.694441826112815, 49.97609899890039, 54.49929391184161, 51.53832412535145, 50.66529866187803, 53.32536382059897, 48.29910532120736, 49.92415505070841, 50.126972967578524, 52.59086862687142, 53.86944363194128, 60.90999610962407, 66.16225765597436, 64.1260297836796, 60.28870444143973, 63.780990646731475, 57.88483281289378, 60.65450076133975, 58.67974427438552, 54.15650229300223, 58.941272227994865, 59.52911392334969, 59.43961328075778, 57.48493148434547, 52.39974329548498, 52.57351213885892, 56.00206767359088, 58.191797502579234, 58.527842644722234, 38.60440261902348, 41.10054800587316, 49.857564972293, 48.43095187217959, 53.23931486375871, 45.70204127219416, 36.61019117601457, 33.9418694280809, 32.2879804718879, 32.59273490598125, 30.167117657199984, 30.077464042171357, 29.64023351669312, 25.98942275970213, 21.366827141854074, 19.00993766323213, 11.162922343900128, 13.416616224473524, 22.790206247760405, 31.328758962692756, 38.908904060240715, 44.522145255919426, 46.15199988888156, 58.59337368319112, 59.58965570695939, 60.666542437768754, 56.31860686886696, 51.92227317440895, 57.61338910748882, 38.52567672729492, 34.428066822790335, 53.719840511198974, 54.83995176130726, 54.956920762215894, 51.35992688517417, 50.61645338612218, 49.50191582402876, 51.95478962313745, 49.384017221389286, 49.64405075196297, 50.712018013000495, 57.26256447453653, 60.083293837885705, 60.677219129377804, 61.43904147609588, 58.641195220331994, 59.40277045772922, 57.217084592388524, 58.55384403659452, 56.917744990318056, 55.00236534303235, 56.97292097153203, 56.884906907235425, 54.02263964376142, 48.07723253004013, 49.238207032603604, 48.6259211263349, 53.014170815867764, 54.291608333587654, 52.6320731255316, 52.28354700150029, 54.51430482249106, 57.77386896071896, 60.72711167796966, 60.403665188820135, 63.61452133424821, 61.458570957183845, 64.66151568197435, 65.43363425039476, 64.06818266837828, 62.97365703890401, 60.95259304969542, 62.313898686439764, 71.61022586207237, 70.03366055027132, 72.18530808725666, 73.30385038929602, 74.23583692119968, 52.553919899848204, 25.956541530547607, 2.3663019412948243, 29.25735723587775, 68.52696049597957, 56.66124551526962, 18.641995806847852, 37.463789140024495, 31.234859381952596, 56.44451887376847, 45.827823838879986, 51.807932161515765, 67.17389183659708, 76.76615791936075, 15.453610920136976, 0.7062734339025714, 0.3643675352777205, 0.36608409316789725, 0.37379599386645906, 0.2931968945889704, 0.20077204842480922, 0.2855410715264659, 0.21008272865606895, 0.2478390655690624, 0.22993027412843323], [0.05772354914956997, 0.03629305535146306, 0.1361345595890476, 0.09007224377485053, 0.05028676594637575, 0.05744125341035186, 0.07837565165133246, 0.0896004485266824, 0.023608121705511888, 0.06347115061456157, 0.08538459773145377, 0.21288766766027098, 0.19657832990971305, 20.642796831746256, 70.32678711798884, 38.32040340669694, 37.50510738741967, 37.854578802662516, 37.1707017960087, 22.68075054691684, 19.025972312496556, 25.46400558563971, 58.74129018475933, 52.970095142241455, 16.299947596365406, 36.68097426814418, 63.054991306797156, 57.442075667842744, 64.59796151807232, 55.73251847297915, 56.50816717455464, 53.882293316625784, 57.29039761327929, 57.15304797695529, 60.158352313503144, 55.10997556870984, 57.35195921313379, 55.91501066761633, 54.90815001149332, 55.6791114807129, 58.898004562624045, 58.4417466194399, 59.39279979275119, 60.92793310842207, 56.37240609815044, 46.602817504636704, 46.328526158486646, 45.8022342958758, 45.79490730839391, 45.303995224737356, 43.36355555442072, 44.65035184737175, 44.11508560180665, 47.05689068763487, 50.96449313625213, 54.09086535053869, 57.51086619592483, 56.60401421208536, 53.54483219885058, 57.26749097147296, 55.18757574019894, 54.72880355773434, 53.7522824348942, 48.68321126507175, 50.14670248954527, 51.69312830894224, 53.17288168015019, 49.42722212883734, 47.98885368531751, 43.68457017406341, 49.69211547605453, 45.15589044940087, 44.15905144906814, 28.916875893069854, 25.363553685526696, 38.74637672978063, 33.723142377791866, 28.59154666623762, 36.9576935614309, 16.71777709837883, 9.50166815711606, 20.294217755717618, 14.010537593595444, 6.420659624761151, 4.971805705178169, 7.788214087486268, 6.978164728610747, 5.04309380246747, 2.3857456205352663, 2.795315101262062, 5.345145233215825, 8.224865082771547, 13.360981325949393, 16.45301515056241, 23.854506092686808, 20.04229372547519, 38.35980361507785, 45.82915744473858, 46.893076819758264, 43.165213061917214, 38.268675188864435, 43.84190820878552, 22.74611096228323, 27.58358382409619, 45.05117101054038, 44.48154480226579, 47.13028607829925, 42.69284594443537, 40.4628098395563, 41.2154616848115, 45.34538015242546, 42.308245781929266, 43.18106335978354, 48.06219808516964, 52.35456543584024, 52.86238685730965, 52.30687725928522, 52.43446411625032, 51.09940305832894, 52.61896064204555, 52.288689228796194, 47.21655468786917, 51.277443362820534, 48.61329893912039, 45.592614989126886, 43.447427595815356, 43.08549088816489, 42.87936249086934, 43.10655009362006, 44.03683823923911, 45.89693992368637, 49.64146983238959, 50.12133259927073, 50.544917198919485, 52.96098347633116, 55.549077064760276, 54.844976317497995, 56.996102179250414, 58.27533222013905, 57.66488982785133, 56.362431510802246, 58.92980713998118, 54.58088313379596, 51.1821101557824, 53.75508300719723, 59.49256135571388, 62.68991278063867, 68.05342843455654, 68.0341225285684, 76.42244846590104, 52.6245774761323, 30.088827148560558, 8.020185510958395, 2.1574327878413664, 39.631851796180975, 50.54230490038472, 30.445819708608813, 18.555291814188806, 31.77856460694344, 28.467486020057436, 36.95506949578562, 36.13889878795993, 53.29555380728937, 37.50896307729906, 63.52094142667709, 5.140687275317408, 0.16169396469429617, 0.012049833350183984, 0.12214627672707844, 0.06861766800284386, 0.07549041897178659, 0.06222774394817891, 0.05751848273399857, 0.10847202862703031, 0.04815745137391552, 0.026543933425038576, 0.08265309591567324, 0.08921935042786984, 0.0860365845202919, 0.0611387461333746, 0.15706714603208727, 0.05881654594333903, 0.04793433592684808, 0.10404479119085497, 0.07995730911892268, 0.09625968313024891, 0.12221383036024148, 0.34370421341830687, 0.1935038352084737, 27.981623987997732, 79.12555771489298, 43.31718137187343, 35.862002988015455, 37.99677256614932, 40.363016897632235, 25.388066537918586, 22.450258347295946, 30.870973256326494, 63.22786192740164, 60.01968868317143, 18.327874752783007, 34.65821973739132, 70.78208015811059, 64.69526375493696, 66.8055106747535, 61.165691498787176, 58.8221537682318, 58.17054217861545, 60.570715012088904, 58.17710430391374, 62.866015434265144, 56.86929587394961, 59.826794362837276, 58.64501168650966, 59.90248826242263, 60.05100096425703, 63.57037898032897, 62.56786823272706, 63.95314347359442, 64.52247158173593, 59.73502659028577, 50.383488132107644, 49.19994038920249, 49.09416191039547, 48.10541083735805, 48.28936999843967, 46.13752634294572, 45.81892005858883, 46.775299810594134, 50.3798677844386, 53.971327197167184, 59.86189173113916, 61.90905909384451, 57.041240815193426, 57.66851802026072, 60.08449408315844, 58.8264173846091, 55.6850617162643, 56.03296026106804, 51.92368130530081, 55.46657393055578, 55.25423249890728, 56.32167808471188, 52.367007194026826, 50.80866129167619, 47.16241029001052, 52.51620238827121, 50.106113803002145, 48.88040450311477, 37.31867321075932, 28.930421798459946, 45.25036073500111, 46.335249100961995, 36.2239279285554, 41.41634979555684, 25.71486077001018, 15.596830383423837, 26.4530586811804, 20.32090360118497, 18.498229172921953, 19.013952209103493, 19.727984397642075, 15.811160456749702, 13.574528886425881, 10.42746420829527, 16.778144336515858, 21.810406023456206, 19.863614074645504, 20.946203931685417, 18.685151684668757, 27.08167145329137, 21.124785523260794, 42.63121374191777, 48.43918100480111, 49.81125747003863, 43.39583273856871, 41.23142180904266, 48.70256423950196, 27.103932865204353, 32.45064116293384, 50.96217109311012, 49.215582801449685, 50.853419457712484, 45.969150758558705, 44.98021141175301, 47.43659180979575, 50.36861058204405, 46.484754162449995, 48.839423579554406, 51.121513458990286, 54.81974371017949, 55.36361955827283, 57.29234310888476, 56.00981827705137, 52.93493501601681, 55.867134217293035, 53.184370302384906, 51.09071893076743, 50.866928100585945, 49.088074391888036, 48.04010729635916, 45.6786717907075, 47.12302184874012, 46.78012432590608, 47.29426468572309, 47.863584949124245, 49.155390108785326, 51.971259655491004, 54.952143315346014, 56.399890145947865, 56.617554233920195, 57.79912902462868, 55.76805906911051, 59.064520943549375, 60.75766301924183, 62.341939710801654, 59.332477661871145, 61.89221251395441, 56.91105342680409, 55.06878283716018, 58.28455371241416, 63.12625685045796, 64.35080905114451, 72.96675405194684, 69.18253760184012, 77.52308907047396, 51.103560770711596, 29.630919848718953, 6.054749065829862, 3.61847204066092, 44.76787390247468, 53.875574296520604, 34.87117698115688, 20.075129847372732, 36.10347194056357, 30.983264830804643, 42.91798999232631, 44.45424902823664, 58.34316961226925, 41.89781288946829, 71.31181193936256, 6.767595717983862, 0.30251531230826534, 0.02562472367689254, 0.15665175783778393, 0.04734676181068344, 0.12211204791862158, 0.0651520317901046, 0.09459808438776002, 0.048186574206357045, 0.025171098119068532, 0.020885403087783246, 0.11158270566093345, 0.3029399088794186, 0.31271142164064997, 0.24234342659192704, 0.3448376864675553, 0.21851800021625337, 0.18085442122913178, 0.18098159182456233, 0.10201676493330349, 0.16466520606510102, 0.2967910420510077, 0.43964642971273393, 0.350319137496333, 30.48480610693655, 91.06256177348476, 51.14622046870571, 51.008859065271196, 56.33190762612128, 54.44662040279758, 32.309924171816924, 25.423179595701157, 36.60209148160873, 73.82146204671552, 63.30859215028825, 20.76171328944545, 39.590062864365116, 73.93255141473585, 65.90647205229729, 73.43215896237281, 64.63668315641343, 62.20279362893874, 61.53353137354697, 64.83124840644099, 61.614336121466856, 66.02384505733367, 58.61253446148288, 63.636710182313, 62.19725131988526, 63.18812439518591, 62.97525736593432, 67.07274959933373, 63.38995779714277, 65.41972944813391, 69.03134592117803, 63.929907352693625, 53.56896654252083, 52.118501509389574, 51.51230312162831, 51.43697792483915, 50.87256846889373, 47.1716788507277, 48.58425771036456, 49.46268819993543, 52.71388984495594, 56.322799882581165, 60.76342890339514, 64.39652035313269, 61.46348960937993, 59.003904634906405, 61.300542585311405, 62.588288091844134, 58.21355881229524, 60.837742128679835, 54.76319882177538, 57.69631585767193, 57.074937897343794, 59.02928236992129, 56.0462845525434, 56.54313510464084, 50.65408852792556, 56.4762665379432, 54.60721400476272, 53.04571843916371, 45.98486377346901, 38.0563102229949, 54.91001705969534, 51.98326603058846, 42.940590689259196, 50.659317047365256, 33.37093314816875, 27.150383533970004, 34.183267777965916, 27.87965216944295, 26.603612976689494, 24.13746979928786, 25.793037529914614, 22.85953021818592, 25.026449503437167, 22.082626358155284, 27.42302748464769, 33.476115426709576, 25.501150431171542, 28.09702600202253, 22.294844235143355, 31.81857474388615, 26.5617730540614, 48.103339825907064, 50.18774224865822, 53.0515706154608, 49.02286498777328, 44.4609131351594, 57.54931719072404, 32.42828757532182, 38.74555303204445, 52.126377628695586, 53.887137443788596, 55.70626604941584, 51.33949918131675, 49.81158302676294, 52.083753232033025, 53.89508416575771, 49.9771031256645, 51.130640814381266, 52.602066993713386, 57.18440732648296, 59.22223552580803, 59.42498284001505, 60.42606976724441, 57.97483551886774, 59.941060850697184, 57.412991293015025, 53.74884251625308, 56.3216192491593, 54.57865130516791, 52.59985869930637, 48.40456608803042, 49.575173931737105, 49.49843275931574, 49.53474606237104, 51.0652196022772, 51.69465803330945, 56.20932179112589, 57.263541144709436, 58.430465882824315, 59.49434603414228, 60.0200613083378, 60.39710698589202, 62.93487656501032, 65.42373418807983, 64.62014644376694, 63.06809202317269, 67.35535637024911, 61.38931758942143, 58.59615072127312, 62.48127798880301, 67.70966406791442, 67.89545889823668, 75.5647437803207, 74.22932578671363, 79.9635721022083, 59.928936804494555, 37.258696248454434, 10.602635299005817, 3.2060171663761143, 46.85665761270831, 63.768086048864554, 42.74882993390484, 23.791716790968373, 42.66556978225709, 38.47312088935606, 54.50370657828547, 55.261116258559696, 71.7727610372728, 45.8416501937374, 82.14035418725784, 10.315409937212545, 1.185039837033518, 0.17197987485316493, 0.3307968269913428, 0.15772379063550504, 0.36750111067968033, 0.22715646893747393, 0.15824234022969202, 0.21625198874502413, 0.16536669745560617, 0.09878670841815973], [0.01151868831291194, 0.028623944493911924, 0.08395895406964325, 0.03838217329053629, 0.061100418754522844, 0.07399799542561655, 0.0883549427793872, 0.065057925549486, 0.025558803726228017, 0.18011945179633557, 0.04441891932078908, 0.12121451462829307, 0.17830316458017598, 31.412032842636112, 67.95360411367109, 37.03261083172214, 34.7386989285869, 43.93793959771433, 38.1039160297763, 26.256224340008153, 17.27673642096981, 25.44086164043796, 47.627356283126346, 63.46722456716723, 19.009808225016442, 20.520244336897328, 66.70424292164465, 62.84988664811658, 64.81015389965427, 56.11632631671045, 54.13369763282038, 51.67714857286023, 55.51472102442096, 53.30170800608974, 55.827592803585915, 52.833145587675034, 54.74942738010038, 52.07138992124989, 55.50901005345007, 53.75324733795659, 56.7568140645181, 57.364624546420195, 58.18664743054298, 57.87483861369472, 57.14914129626367, 47.68001410268968, 46.954971821077415, 45.681401760347434, 46.0270292528214, 44.027632436444684, 45.06194183903356, 43.09827389255647, 45.64009920243294, 46.964279605496316, 49.77985497443907, 54.85551964852118, 57.799011353523504, 55.01096317845007, 55.18954869239561, 55.04366397857667, 56.646846494367054, 53.23490611968502, 53.64039290335871, 50.33509392892161, 52.016951345628314, 51.29148544803743, 52.45163233049455, 47.998275218471406, 46.24274392281809, 43.58065482108824, 49.577668559166696, 43.69523509856194, 44.76537143030475, 31.995885487525697, 24.768963552290394, 31.431848656746652, 40.392791609610285, 34.678549381994436, 32.9972920879241, 23.750225959285615, 8.689891484475906, 9.049808171487625, 5.8832208764168525, 1.9916495224160535, 1.1148542934848418, 1.5591774448271722, 2.525858076349382, 1.6065686244157054, 1.6978437717883819, 1.4251844993522091, 8.307095612249068, 3.031830100282546, 5.390201009088948, 7.350184379085419, 6.3548309764554425, 10.617026475168045, 29.825859685097974, 39.377497857616795, 36.90442777449085, 33.69728219124579, 35.60369530031758, 25.585877549263742, 18.22281602890261, 34.540776129691835, 46.62256271608415, 44.717557737904215, 48.413352197216405, 42.81161139088292, 39.839635433689246, 40.716618568666526, 45.78390898243074, 42.93343236369472, 42.58004642301991, 48.33427329217234, 52.92070465703165, 50.25884697514196, 52.23628244092388, 52.397974306537265, 52.42087310360324, 48.437576755400634, 44.83807256144863, 42.61215494525048, 44.218977420560776, 43.0286047535558, 42.15990958675262, 43.74157790214785, 46.127516454265965, 44.03300608358076, 46.054756487569506, 42.665507024334325, 47.74563143330236, 47.10443765886369, 49.27057050889539, 49.38294641433224, 56.070054115787634, 52.08832671565395, 55.42085478382727, 55.67746800761069, 56.14831324546568, 55.23594248679377, 52.65395210635278, 52.47173447762766, 52.309065941841375, 50.32404853451637, 55.43146087277321, 59.83444298467329, 62.10812722482989, 66.38620930333292, 67.67515505513838, 71.18537825922813, 36.14819088289815, 16.22379772124752, 2.1587889473284445, 6.762468199576102, 54.132669971835234, 42.62307874618038, 24.246597982222035, 15.96566850139249, 31.87486467822906, 32.51006507104443, 38.31632021934756, 33.37596162672966, 52.44071245193482, 38.24054787235875, 57.63472680122622, 5.626815047956282, 0.21904545175212048, 0.061222571474049366, 0.12049585520740479, 0.036314547948178746, 0.057021590445431015, 0.1252627760292061, 0.038281451880691514, 0.056533079158755085, 0.00783126054879939, 0.04419851582497359, 0.01591587116220786, 0.04341100425189061, 0.06602508857125236, 0.03749490940883275, 0.02400915341211423, 0.03143181953008377, 0.03900766875895281, 0.07057827852305866, 0.16797415431468718, 0.08312214090819321, 0.05809358876919555, 0.08249656883098426, 0.1409683445648801, 40.59363265191355, 74.79666525317778, 38.84713065239691, 38.61392221143169, 43.506867193406634, 39.96827740823069, 29.286341590266076, 24.13419854256415, 31.993498725275842, 53.79379680079799, 68.24269848485147, 23.696283563490837, 18.75193395922261, 66.57709537013885, 67.75754836297804, 69.06419184900099, 60.57907358292611, 57.25889313605524, 53.50725981496996, 55.918085805831424, 55.92346729770784, 59.341106876250244, 56.79637901244625, 55.62444540762133, 53.512892338537405, 58.23343738432854, 55.000898376587905, 59.79245401197865, 58.8745330995129, 59.75348134194652, 58.77400667436662, 60.585635708224395, 51.19028045285133, 48.43734141319029, 48.3348459582175, 48.9684421016324, 46.82248200139692, 49.65350758644843, 47.77393917883597, 49.10508571132537, 48.632906867611794, 52.03270750661051, 56.5904349665488, 60.28432707632742, 58.73190787530715, 56.907244805366766, 58.663297776252996, 58.84156950058476, 57.34513428903396, 55.30033211554251, 50.992887173929525, 55.32727487625615, 55.010739603350245, 56.04930477757608, 52.234897844253055, 51.69923936167071, 48.02796363830567, 54.425086590551565, 50.11639433522379, 49.266177454302394, 39.10231221106745, 29.758238023327245, 40.39225032252651, 45.31560151807724, 43.722550484441946, 42.91349887847901, 35.11822354409003, 21.635905658045125, 13.56115556532337, 12.841982130081425, 5.731532035335418, 4.512299549195075, 5.975480906424984, 3.6310265669899606, 5.653694560450893, 4.118862776987014, 15.155968723758576, 17.933790299200243, 7.963188079095657, 9.315910589310432, 9.639708130590378, 10.257810911824627, 12.850367176917292, 36.06975916893252, 43.31260788825251, 41.99475034590691, 39.672750349967714, 40.10261074189217, 27.67900528446321, 24.808632443028113, 40.94075456742318, 50.87400013400663, 49.775293257928666, 50.43875432783558, 46.21532655531361, 43.622949738656324, 45.922902091856926, 48.51297255485289, 48.32833482373146, 45.99457556201566, 51.464563954261045, 55.43482234401088, 53.58567191708473, 53.68242502212525, 54.09567809874012, 54.46145872915945, 51.00831385581724, 47.800242593211514, 45.029425390305065, 46.646724516345614, 46.01177907759144, 44.4200381155937, 45.07692529309181, 47.00247564623433, 47.391833643759455, 47.95178728718912, 45.94842495456819, 50.710413763600016, 51.52532931297056, 52.344528090569284, 53.516940224555235, 57.345302950951364, 54.07773325520178, 57.009736337969386, 57.49713005558137, 58.01800120261408, 59.3806561346977, 56.30690643864294, 54.55789804458619, 56.185563994992165, 55.11249765273064, 57.73131908908967, 63.53965505476921, 66.47831439971924, 69.73613308322045, 67.80684471130371, 73.2413278087493, 36.39892447379328, 16.39518960829704, 1.5938119734487228, 8.927998965786351, 62.519634846718084, 46.05612147238947, 31.372734615879676, 14.609052058189148, 32.500820044548284, 30.360935695709724, 40.89517662602086, 33.21793325485722, 48.08321022218274, 39.52849341977028, 69.2781336076798, 12.868200232905727, 0.38519991742026427, 0.11410839029497678, 0.1529329525487077, 0.11393546892870819, 0.031191668202800137, 0.055456438342169415, 0.11976136074912165, 0.08899482537902172, 0.03676928624871277, 0.026662318907197446, 0.17578287320511957, 0.07954148425450248, 0.20808123202333528, 0.15293425489817897, 0.2934928496758784, 0.29659529126459555, 0.16261690146019384, 0.1333838749316431, 0.33440807353585, 0.24159270639140762, 0.22337109060777774, 0.22192134581986936, 0.4212818312789164, 48.64075160795643, 87.89918591899257, 49.54121405078519, 49.54213188540552, 63.76244175818659, 53.57628568526238, 34.4168645335782, 23.458609504084436, 35.519391798204, 61.54297644092191, 73.5352231610206, 24.84587338662917, 23.627128254982736, 73.27515432911535, 70.97284855381136, 73.62033859375985, 63.897375214484434, 63.392938798473736, 57.48401364972515, 64.05918867357316, 61.06671833222913, 64.21927628978607, 58.84429554785452, 62.40609007496988, 58.21103672827444, 62.27620470908381, 58.58112804351315, 62.41010265965616, 62.568444821142386, 63.21414147653888, 61.48535682309059, 62.169810418159734, 53.99825034602996, 52.699180956809755, 50.62547483751851, 51.209029382275, 49.363307106879454, 52.55510445564024, 49.957318690515336, 52.59841918945313, 50.405488706404164, 53.38443471539406, 58.72033688329882, 64.48172992275607, 62.056120518715154, 59.118590816374756, 59.13706910225653, 60.91132187074231, 58.93263124650525, 58.267279594175285, 55.240774846846065, 59.402864594613355, 55.85433552342077, 58.6632546301811, 53.17612548028269, 54.168559658911924, 49.90295856229721, 57.34203169422766, 51.791924968842544, 55.121487725165586, 42.92512478366975, 39.863295170568655, 46.300379230130105, 55.39630859128891, 50.53830408280896, 51.44054335932578, 42.36769322426089, 25.409706254159254, 20.78818536573841, 10.944859154762762, 4.283633703185666, 2.614704663715055, 4.398221335103435, 6.647477053826855, 7.925331323377549, 8.660371726559056, 24.53839094408097, 26.876356947806578, 10.847075446959465, 10.261103741584286, 10.383994540860577, 10.214067659070416, 16.230658927271445, 44.853620836811686, 46.63316096028974, 47.877077902517016, 44.01425323178692, 46.276307644382605, 34.115559824051395, 27.737868293639156, 47.144626263649236, 54.32326186087824, 55.315299880120065, 55.36463545214746, 50.618030178931456, 48.329703730921594, 48.80364764121271, 50.44592442051057, 50.09838281139251, 49.37340721007317, 55.96519739397111, 57.630494563810295, 56.01280320075251, 58.943272636782744, 57.78943292556271, 58.53094916189871, 55.300449786647675, 49.73729725806944, 47.64662688778293, 49.63195416235155, 49.51480081004482, 47.71713149163031, 47.66805479603429, 51.12019162024222, 49.27381430902789, 51.879001586667954, 48.803447600333925, 53.92355272846838, 53.5087267814144, 54.834103507380334, 56.83227262189312, 61.68344043916272, 56.48167548641082, 60.92450103452129, 61.696827488560835, 62.37167127670781, 64.37211536592054, 58.90211128419446, 57.199163283071215, 60.016970480642016, 58.10197130326302, 60.571460262421645, 62.8196334069775, 69.43526375678279, 72.12312283054476, 71.42991450525099, 73.09266213447818, 44.28539883705878, 20.94821414639873, 3.4079246030699823, 8.263654381998125, 64.79547639046946, 55.65432602359403, 39.17196566058744, 19.68057078699912, 44.56874301356655, 46.430272440756525, 56.847412970758256, 49.8838605419282, 71.78250420478084, 50.91388671628891, 76.24352562812068, 14.552331643719828, 0.8675928582106868, 0.20263537343951965, 0.42811365017006475, 0.3326838241229135, 0.2839856066050068, 0.14357575545868567, 0.3485120586570232, 0.22460721943887973, 0.1201137152290152, 0.1390844424285235], [0.08727519547626858, 0.06775769600344282, 0.043237090801760074, 0.018586790744936275, 0.03591776802955616, 0.03375499456700298, 0.05128708142306536, 0.06622742005293408, 0.018725274543788646, 0.10431622380330678, 0.03497063820700973, 0.10264927010622718, 0.1443191058933735, 27.95844081909426, 66.20966342187697, 44.158259130293324, 32.31943984185496, 43.01323298485049, 43.725853120127034, 25.41623700049616, 17.823944322524532, 19.099759940178163, 40.83194409647296, 59.49694656556653, 33.02471337779876, 7.457354318711066, 48.84280074027277, 67.30889197318785, 63.96757779582855, 61.0446196986783, 55.698515445955344, 49.32939429436961, 47.822953116509225, 48.64975736987207, 51.00687434596401, 48.70891847918111, 49.741101957136586, 50.54914943633541, 51.5320404883354, 53.04336109469014, 56.988665365403705, 57.097381699469786, 57.91698055882608, 58.87898891202865, 58.8948235204143, 49.02135095288677, 45.41357448024135, 44.78954499767673, 46.54011057269189, 45.09928672544418, 46.48390693049277, 43.95354278625981, 45.919940702376834, 46.61045435936221, 48.32933110575522, 55.744705277104536, 56.97094801933535, 56.251169558494325, 56.91878834078389, 57.264682554429584, 58.149988958912516, 53.22859894844794, 52.66282058531239, 49.237081312364154, 53.13777646710796, 55.74980435832855, 51.90753682967156, 50.38742226939048, 50.87010914279569, 44.24588880231304, 48.050670239233206, 44.58397749931582, 43.7947730864248, 35.02590271734422, 24.57425121338137, 30.858808025237057, 31.98680912294696, 30.73773426394309, 29.13608539489008, 20.28653775492022, 25.383273401568015, 2.6249704870485493, 0.8625025410325298, 1.2566272601965935, 0.739333069612903, 0.1454572980442355, 0.12563249006146385, 0.21429970560054626, 0.2551615944192294, 0.24199600571826582, 0.6379078088268157, 1.4258759396691478, 0.6299230276096253, 0.041339602096066366, 0.37379332788048253, 3.6660991753301317, 16.992137086006903, 29.440843751353604, 28.04031833525627, 23.470472712670606, 27.28778219992115, 21.585795417908702, 18.09884951960656, 40.22637328793926, 43.879370766301314, 44.99149607073876, 44.56851551609655, 45.71690705514724, 39.50462579727173, 41.55886519339777, 44.75504382964104, 45.56897878646851, 43.52909526517315, 46.32353298125729, 48.301745076333326, 52.88644275357647, 50.31944759430424, 50.37005009189729, 48.29651655689363, 46.915093083535474, 42.64908013805267, 43.130052935692575, 41.71361838617633, 41.81936940839214, 43.5460752056491, 42.539265540338334, 44.19199935851559, 45.57736481389692, 43.052193887772106, 46.79650806611585, 44.32663471468034, 48.63579373205862, 47.757237726642245, 49.95434945629489, 51.89934692075176, 53.08015684927664, 53.37964942378383, 53.39901808769473, 55.17429851716565, 52.74813213656026, 53.29444769890078, 50.79838468182472, 50.02589741060811, 50.137794786883944, 53.17518411144134, 62.10831157622799, 62.49043280078519, 68.56745504563855, 66.80248260498047, 72.55133582699683, 27.66347465976592, 10.92495704850843, 0.6714892423441333, 13.32166740971227, 61.048573447812, 34.74222513937181, 21.25831477103695, 23.443902577123335, 39.18472513075798, 38.40265943158058, 42.21505026663504, 34.470016571783255, 55.01395594689154, 42.5297498703003, 68.63022081313595, 13.8185267871426, 0.3885070577023491, 0.09083815549890842, 0.0651015772394115, 0.16158177877866453, 0.06548105123182459, 0.01993622014959974, 0.087485279767744, 0.030559193673393423, 0.0666011177423981, 0.10887746533919727, 0.08170228887109027, 0.032738430365439386, 0.07126929749163889, 0.021491062624620336, 0.033720474645134904, 0.04338801012284333, 0.044408416255347194, 0.06621537715076439, 0.02580898122922067, 0.09787522466673006, 0.0038490352087518984, 0.15090464283862423, 0.1592705221546273, 33.382233496635195, 72.96659715713994, 49.02424566207394, 40.57288723607218, 45.170877825829294, 46.72949044935165, 29.569230771833855, 23.5863709065222, 25.30015837761664, 48.37391668750394, 63.257146343108154, 38.415830750619214, 7.507905335195604, 46.01333233617967, 71.64390333237188, 67.89017154324439, 65.66266536712646, 56.981071656750096, 53.19397226456673, 51.95834329051357, 53.578870527205936, 53.47974438821116, 51.348359815536014, 52.53406878440611, 51.86357882715041, 54.20024848753407, 54.86165031310051, 60.76759446051813, 59.22465955057452, 64.11336052802302, 61.61792509017452, 62.869847589923495, 52.36302206593176, 48.552086430211226, 48.54439073993314, 49.98692474057598, 48.4691910589895, 48.10619138902234, 47.32702039903211, 46.9560504728748, 49.10235574168544, 50.30005147380214, 56.71448384561847, 59.700415595885254, 58.36742947178503, 59.18276471476401, 59.249868623672, 61.12176487522741, 56.52630029186126, 54.255059688322014, 50.873094066496826, 55.5065546497222, 58.08181424294749, 53.891401060165904, 53.1830680754877, 54.39957157258065, 47.414869723781464, 52.45146759094731, 48.9551374220079, 47.88671124366022, 42.44197114821404, 28.64922708080661, 36.46597739188902, 39.210553938342684, 39.0936476953568, 36.34303069883777, 26.468550082175966, 39.97754596894787, 8.027035440168074, 6.270891274175336, 6.153945807487735, 3.6952887187081003, 1.4522642978737432, 0.48082721029077813, 0.6715197632870367, 0.5867974255834857, 0.1320389309717763, 2.4458758004250067, 3.014769751218058, 1.7733620227344575, 0.6296909948991192, 2.0179053780532654, 9.492518248096589, 27.18592413010136, 34.605938465364524, 31.036224672871253, 27.4254632765247, 35.05229242386357, 27.236387383553293, 23.905759703728464, 42.5312089920044, 47.00800226580712, 48.3220668761961, 48.52278632502402, 50.77578398489183, 43.010318663812455, 46.68827026121078, 48.39218316539642, 49.07020015101279, 47.844133915439734, 48.98537497366629, 51.16332592502717, 57.06898766179239, 54.77681336864349, 52.76560629567793, 51.69780769655782, 49.188534136741396, 46.553430941797075, 46.009633541107185, 45.59027333413401, 45.760272779772365, 45.21220784033499, 46.46395775579637, 47.286898474539484, 46.2111335415994, 45.792863753534135, 48.81828984906597, 47.09303925114293, 51.26473096109206, 51.661886630519746, 53.125789703861365, 54.01770137971448, 55.089610622775176, 57.73643778216455, 55.31267189210462, 58.49692260065387, 55.45169638049219, 55.748733551271506, 53.44164248435728, 53.462689922701934, 52.17423838953818, 59.03543656872165, 62.177972870488325, 64.51887084591773, 72.54160050422915, 68.26573848724365, 72.33633502837151, 30.998938622013217, 9.965132474899292, 0.7832197340265398, 17.784642173397927, 67.3739170259045, 39.22109726936587, 26.697071290785267, 24.950163325955792, 31.193476415449577, 30.374748322271532, 48.37600338843561, 27.923278731684533, 53.69490600401356, 52.585773468017585, 73.61226635594522, 18.200078049013694, 0.576096709457136, 0.1494970022430343, 0.13950778261548089, 0.04507167602799112, 0.10274610361985623, 0.03449902681994342, 0.23008539161134153, 0.04690135446106715, 0.09309809955377733, 0.018215012105722583, 0.24347431026399138, 0.13167655606183315, 0.21770764773170795, 0.1616363242388733, 0.12101842676319423, 0.11092753194633032, 0.1881696109569842, 0.25872238641304357, 0.13018550381304758, 0.200613115824038, 0.18120107601486868, 0.16978507891537684, 0.19385893228313616, 44.90492543866558, 81.61544692131781, 55.39999169688071, 41.26711145524056, 59.49682889446136, 60.47305583953858, 35.33675839824062, 22.06213393519002, 27.601885603320216, 53.34361853138093, 71.98989560527187, 40.9154748916626, 9.998526553953848, 57.309177921664336, 74.67180836585261, 73.5779691511585, 66.82858205610707, 61.702636518786036, 54.58460546308949, 54.46857783102221, 54.198083339198945, 56.249067168081964, 53.9213679682824, 54.94323953505486, 56.64027652432842, 57.52382178460398, 58.07611896145729, 63.0409727558013, 62.160251602049804, 67.1427325279482, 63.13341125365227, 65.41170035639118, 54.35542529629123, 52.442775618645456, 49.74018412251627, 53.68347621733143, 49.91551799158896, 52.22339353253765, 48.714609838301136, 50.18964459819179, 51.63645005995228, 53.765857758060584, 59.68922115141346, 63.37791219834359, 60.89861731375418, 62.82608962828114, 61.202381349379024, 63.82942015124906, 58.99329462359029, 58.06483038010136, 53.800170652328006, 59.494589221092966, 58.883511404837336, 56.75835163362565, 54.8400027521195, 57.64002200095885, 50.03127890248453, 56.89532864478327, 52.52102298121299, 57.19635878839801, 48.44589610253611, 40.01167058944702, 48.22742792867845, 47.63875861321726, 47.983762448833836, 50.19838363893571, 35.75138822678597, 49.05094523583689, 6.681318773377327, 3.946813402637359, 4.961123130013866, 2.6117221914952804, 0.6353360823085231, 0.32366338396264666, 0.5100850580680756, 0.5050366305776182, 0.39051322747142087, 1.948124574076745, 3.646217171222933, 1.4418844806571163, 0.45030571580413853, 1.0443582698222131, 9.663477693834613, 35.37819039437079, 39.83062182703326, 37.38938570022583, 32.36520801821063, 41.46571282417544, 30.35042766601809, 26.7250495572244, 49.546364122821444, 51.88075488613498, 53.77039201797978, 53.148182515175115, 55.6017937198762, 44.8735111759555, 49.15214630865282, 50.319337767939416, 52.50926763780656, 50.850458068232385, 52.9703147949711, 51.66944111547163, 58.78040013774749, 56.800917194735625, 55.99468577292658, 55.72046502943962, 53.35707226107198, 47.37261795228528, 48.256637819351695, 47.93100657001619, 49.41955781752064, 46.641354791579715, 49.021715733312796, 51.06436844794981, 49.62577250695998, 48.19524095904443, 53.57158276342577, 50.35086970175467, 56.104268950800744, 53.301076504491995, 56.362168712000695, 56.92188701322002, 58.555848367752574, 58.39799258016772, 59.54075159565095, 61.950934317804155, 60.81734580378379, 60.70669181885258, 58.52232779225996, 57.11551089440623, 58.39544696192588, 63.2509333087552, 67.46003658540788, 67.86720214351531, 74.00755497717088, 70.51326444072109, 76.89998134489983, 36.63163085137644, 14.423015021508741, 1.458488731615005, 17.110461265810077, 76.52959192952802, 48.91325827567808, 32.45738175607497, 29.68689010989282, 54.15924402975268, 51.977460922733435, 65.08832839227492, 49.81585841025076, 69.12731847455426, 58.07280455866168, 85.83157908531928, 25.214764456595145, 0.7409715171783202, 0.2214601915329695, 0.16765553834697894, 0.21559589572491186, 0.25314063915321905, 0.13019299615294705, 0.22913444667093216, 0.1123464799996826, 0.20256659406567776, 0.25373861674339543], [0.03766588108133405, 0.041044807632363615, 0.05451056107337918, 0.04844820089337807, 0.06254535251026673, 0.05275775573306507, 0.09933871307200003, 0.10028551347673902, 0.06505544342461132, 0.015578968675747035, 0.07786956630767354, 0.15856607366473446, 0.23015769498963512, 23.1258846482923, 61.94958894483505, 44.170065464512, 31.72220014756726, 44.507487358585486, 44.08064326932354, 30.220118684153405, 26.366525311623853, 19.128610933980635, 35.03045266674411, 56.82133313148253, 49.348025552688114, 5.309981184621011, 22.618747680417954, 67.25859934283842, 64.44687574140488, 62.14733915944254, 58.56466585589994, 51.24380903859293, 51.57867354731406, 53.44679647876371, 49.48635970392535, 48.71045997065883, 49.3109905335211, 47.02229930508522, 51.23571718892744, 55.617326305758574, 57.77155083994712, 59.1434782551181, 61.71685903303085, 59.54714505903183, 60.69134358436831, 50.541653786936116, 46.311483460087935, 46.69698969010384, 43.22815533607237, 45.121314756331905, 44.50427493741436, 44.587950860300374, 43.65692138671876, 47.057290769392445, 45.600659770350305, 52.32406116301014, 55.500980961707334, 56.72619212058283, 57.41983582896572, 52.56715005443942, 53.85772751223657, 53.35829604056574, 51.096822138755556, 49.72792279335761, 49.389783105542584, 52.443881727034054, 51.40586176226216, 51.09623770559988, 48.209396792996316, 47.331091819270966, 49.32631915615451, 46.66583038145497, 42.3239391849887, 38.530928780955655, 22.645233485006518, 29.08535149789626, 29.431257478652466, 29.17946288662572, 21.208641875174738, 9.334562440072338, 19.685401185866326, 11.797604003260213, 6.309823249616931, 3.381854569719684, 1.9530364846990955, 0.12342984938333112, 0.23222885965820284, 0.0653857881984403, 0.019793172381938468, 0.09093062231136907, 0.09444328866177991, 0.1666446240438569, 0.7046598688729349, 0.5676281283940039, 0.4874568739004674, 5.4331818511409145, 13.873098723350035, 19.555251059993623, 17.90781832510425, 15.440945586850567, 22.883125235957486, 25.057695104229836, 25.811857062001383, 37.545084184215916, 46.03517993803948, 44.42949102770898, 46.02139672925396, 41.52473272815828, 41.6968894773914, 43.411879154943655, 46.64621853059339, 46.40899358257171, 43.50570224946545, 43.784629837159194, 47.09612615646855, 50.402539084034586, 51.00089665382139, 48.816713056256695, 46.185857788209, 43.858868537410615, 43.99424914390811, 42.94422280403876, 44.207673149724165, 42.24277357901297, 43.311007561222205, 43.44050461246122, 44.074124290097146, 47.36424761433756, 44.369431695630475, 44.09266925627186, 43.526816368103034, 44.64391523791898, 46.20347707502304, 50.567576731404955, 49.235884989461596, 50.94806624997047, 55.66157848604264, 52.02933426826231, 52.08586738955591, 52.81651866051459, 49.08273996845369, 47.6640304442375, 49.91594552993775, 50.27249682334162, 53.62036528125886, 59.194971130740264, 64.8840944997726, 68.49158856176561, 69.63700694422569, 72.78085724000009, 26.152850274116766, 7.426986348244452, 0.6046500934227821, 27.327345186664214, 58.88132272228118, 29.54796171957447, 20.666770358239454, 23.831160145421183, 40.851704997401086, 31.447742100684877, 39.78106660227622, 34.74290370941162, 46.078522128443566, 29.941640207844397, 63.88199952340896, 11.701676557140967, 0.479268589087071, 0.12178319701624495, 0.018496488130861716, 0.05574947463408594, 0.10606777658986469, 0.011282131853212994, 0.07472978559352698, 0.0595320375906604, 0.019001985502038753, 0.11711243555069932, 0.04899218843709077, 0.14447025504083405, 0.01627332778767713, 0.05628036207429344, 0.07258454788356059, 0.052651771299180486, 0.05772004812775601, 0.04213310447671721, 0.05000246688723565, 0.0698700378979406, 0.0540512147539806, 0.08296103261771702, 0.17405165239207207, 31.565526954589355, 71.47509236489573, 51.87399664232808, 37.163578771775775, 49.949705370010875, 44.04331015002343, 31.44362557318903, 28.85463180080537, 25.14437948503802, 40.377890525325654, 59.561834335327156, 57.80866822888775, 7.056577321021789, 20.801493967733077, 68.7605219502603, 67.225674967612, 67.01476127870622, 62.15947105038551, 55.19106272728213, 54.38190521732454, 57.35696415747366, 54.23766789897796, 50.23854870950022, 53.24274693765948, 50.56303462674541, 55.83419415258593, 57.270240552963756, 60.552083753770404, 61.366720814858716, 63.35051444268996, 63.39349185266803, 62.25222333785027, 54.33663322079567, 49.34868451087706, 48.04023281220467, 47.63423219803841, 48.115640378767445, 47.32505529157577, 46.14278231897662, 46.316778659820564, 49.040256777117335, 47.295417862553755, 52.38430484648674, 56.89954127034834, 58.33441488204464, 59.624043126260084, 56.71863371326078, 54.72040184082524, 55.97794509703114, 53.201005074285696, 53.10336551358623, 54.41726538442797, 54.88969525983257, 55.291428335251354, 52.387219167524776, 51.875306713965635, 50.28371087966427, 52.78762255945514, 50.974648152628255, 46.91785835450696, 44.531005890138694, 30.638870923749863, 34.25822427195887, 36.43259802172261, 39.031933123065585, 27.229003521703905, 18.42073686661259, 30.67095002820415, 23.933786999794748, 8.181592024141743, 7.978297048999418, 4.40562088643351, 2.655227405409659, 0.3940014096517717, 0.16338859714808004, 0.2126584388315678, 0.2881443302237219, 0.40201180884915017, 0.26539749435840115, 0.4402800457131478, 1.2417982494638813, 2.4858126380751213, 13.18272234932069, 22.657765457707068, 26.976004762034265, 22.64434506816249, 21.79380459170188, 31.288242839997817, 27.20872682909812, 27.514332417518865, 41.7687237647272, 50.67322184962612, 49.82655863608084, 51.6589605423712, 47.167148513178674, 44.483188275367986, 46.3477732289222, 48.8813497943263, 49.029258451154156, 46.28134789005403, 45.93551251196092, 49.93440420396867, 52.077638256934385, 52.9205556069651, 51.84497894779329, 47.26579220064225, 47.256217695051625, 46.63316096028974, 45.29083567280924, 45.16767324939851, 45.22064093620547, 44.66400169557141, 46.58370379478701, 47.530858132147024, 48.48841459520402, 45.9911552552254, 46.48763710452665, 47.44889236265614, 47.09964060014295, 50.19743834772418, 52.28757919803743, 52.10671086465159, 51.90121396895378, 56.8011054685039, 54.36843972052298, 54.03381839875252, 55.58718289098432, 54.471335257253344, 51.73336790454004, 51.616567565548806, 52.602447463620095, 57.78337678601665, 63.76552081877186, 67.65819472651329, 71.19567840330063, 70.02213662670505, 73.08443300185665, 30.906784495999737, 6.983084361399374, 1.1075730261302765, 32.36046979504247, 65.24016726401545, 33.794474601745605, 24.76891452266324, 27.779516020128806, 40.89387439912365, 26.462992083641794, 42.13551244428081, 35.70107598458567, 43.75230166219896, 36.7299372150052, 71.69089332703622, 21.70148180377099, 0.21467810706986537, 0.11938784692075946, 0.06973083972209884, 0.09700777564918804, 0.025676133922271194, 0.04487645001180711, 0.1328390791651703, 0.09066844404104257, 0.07110177704523649, 0.06462526207249011, 0.16566145744535232, 0.2501519156559821, 0.1334559484835594, 0.18392200581729415, 0.20459144105834348, 0.10237718631903972, 0.25714406142792395, 0.18779879375811548, 0.15409898433473804, 0.16011286647089068, 0.11597216730156254, 0.3389144784981205, 0.26175554300988874, 39.98771275243452, 83.31827332896572, 56.74622366505285, 39.38799019782774, 62.79959009539697, 59.09257373502178, 39.63301674012215, 32.759443483045025, 26.139082754811934, 48.6015514404543, 68.1223915469262, 59.1982816111657, 7.30936574359094, 24.983362267094275, 74.11297259792205, 70.3677523520685, 70.98594142544654, 65.80979347229004, 58.608117872668856, 53.74051924674742, 58.942664669406035, 56.366357803344734, 53.56058835983277, 58.23826582201066, 51.60238427500571, 57.686015713599424, 62.08969208502001, 63.20768917760542, 63.42025026198357, 67.29075493351107, 66.92047534450408, 63.33074569702149, 56.57358446428853, 51.948258876800544, 51.66835854130407, 49.43220353895619, 51.74914367737309, 51.096465203069876, 49.26290227520851, 49.82226756311233, 53.126691849001, 50.680768489837654, 56.103319737219046, 60.02565853057369, 61.69904755007837, 64.457372003986, 57.449543860650834, 58.87618049498528, 59.051204496814364, 57.44106369633829, 56.83537521669942, 54.33464850148847, 58.28670709363876, 55.9130024140881, 55.10431951092136, 54.27719754557456, 54.89650057208154, 59.326366609142674, 54.78953361511231, 53.30188843511766, 51.191845478550086, 38.04664158052014, 43.88287344286519, 46.9669742738047, 48.08394370540496, 37.06706100894559, 24.598183554987756, 40.85033609021095, 28.412408098097774, 14.503316725454024, 10.176140300689205, 5.095365268568839, 4.584097554606776, 1.1761279668538802, 0.19952812081863805, 0.2450643257508355, 0.2530919466047518, 0.28171032546989383, 0.4363314140467875, 1.173028804121479, 1.5211304541557067, 2.487680176573415, 15.645824709246236, 27.13454108084402, 32.42140969922466, 25.523164733763664, 24.67451091735594, 35.6195612876646, 36.635831709830995, 34.283837349184104, 46.190446961310606, 53.79091385872134, 53.94220752100791, 54.0620594639932, 49.919381526208696, 48.18265799553164, 49.32885300728583, 50.68696191233974, 51.84706172635479, 49.59866108432893, 48.95685934251355, 55.715613057536466, 56.69905324136057, 58.15944579339797, 53.48517687089982, 50.77177140020555, 50.41615755327287, 48.93549419218495, 49.14641572583107, 50.38078169668875, 50.080030041356245, 47.53043059379824, 49.7004936587426, 50.522308657246256, 50.90896021935248, 48.550391966296786, 49.992459204889116, 51.19995301769626, 50.07341300287555, 53.01130748564198, 58.251845067547215, 55.167026442866174, 56.27446059257754, 61.10549096138247, 58.94415124770134, 59.340593045757664, 62.186817815226895, 58.26393773478847, 55.18626959093156, 55.67616970308366, 56.072207497012236, 61.31968375175231, 65.7154526249055, 73.26201438903809, 74.43703097681846, 75.15873139904392, 79.08544755751088, 38.292401606036776, 8.150051264993607, 1.238097738354437, 31.846806003201394, 73.44841326436689, 41.19266094699983, 28.57139745066243, 31.09573095075546, 56.542056452843454, 42.34892860535653, 57.38322834814749, 45.18721841996716, 59.34885355734057, 40.40866544169765, 79.05020898388278, 27.19378455992668, 0.528596745383355, 0.2109813651130084, 0.14089853863321966, 0.162195629710632, 0.23349583118913636, 0.20561092022445895, 0.19368936638197592, 0.23179529985833555, 0.16967152936323998, 0.23155188308127467], [0.023811221190337694, 0.023767523535136736, 0.06598886027331315, 0.13429403335096377, 0.014219188465616636, 0.09546187150502398, 0.05263756802906433, 0.059586847351203044, 0.018286993727087975, 0.07516267123602091, 0.11380684276622151, 0.09247159284930076, 0.16178684519423595, 30.669661529602546, 59.27600729850031, 37.463043889691754, 26.063786975799072, 43.43612332497874, 46.35474328071841, 32.547155003393854, 30.41289729456748, 27.316737136533185, 29.965790240995346, 49.229044375881074, 66.78449461537024, 16.65302465038915, 10.56180440610455, 56.35613610667568, 64.27966510095905, 64.40633412330382, 58.5032650732225, 53.23484728413244, 54.15020296650549, 57.82054908813969, 54.32272449616463, 51.173645680950536, 48.11755057304136, 46.8448708903405, 48.769625002338046, 53.13660367842644, 55.026997827714496, 59.73702307670348, 56.8863424947185, 58.113675655857215, 58.782176971435554, 53.97998779050766, 45.842266005854455, 45.27314186096192, 42.87422810831378, 47.281516982663064, 43.45636275506789, 45.43341775094309, 44.403854416262725, 44.598827592788204, 45.862144577887754, 45.358696599160474, 50.958742941579516, 54.52049432262298, 53.0963993841602, 53.49603006916662, 49.21485716296781, 49.46856783282373, 50.215418492594075, 48.785330172508, 53.209975534869784, 53.06023905354162, 50.28422863252702, 50.71386152698148, 51.01555062878517, 46.64828169730402, 49.30125521075342, 43.34776801447715, 43.18166740479008, 37.23875099612821, 24.776935769665627, 26.50115086186317, 30.150120066058253, 27.659436579673525, 24.36618124285052, 17.378090466222456, 15.008984765698834, 14.344724512869313, 9.658061881219188, 3.772823190496814, 2.866615701106287, 1.642121968250121, 0.28841206263149943, 0.07706767909469144, 0.2530328659040313, 0.40559106356193947, 0.3003993161743687, 0.9666947888270502, 0.24617573546786464, 0.6601293841677328, 2.772754608623443, 12.14398164902964, 15.239359294214557, 18.36349967987307, 11.972143592373019, 15.231052694782136, 18.914043557259347, 29.677713724874682, 32.931000109641786, 38.66252430023686, 47.6868978623421, 46.04549184922249, 48.21533918380738, 43.47697481032341, 40.045693228321696, 41.69628151001469, 46.548794700253396, 45.95088035829606, 46.34256824370354, 41.02527379989624, 43.70154226979902, 44.899387051982266, 48.244129380872174, 45.172246733019435, 47.07279197631344, 43.13285743036578, 43.070456443294404, 41.01204364530502, 41.752273344224506, 41.952200474277625, 43.01175425129552, 41.63073478206512, 44.459708967516505, 43.8277288406126, 44.865478161842596, 43.311439021941155, 46.80912633096018, 43.187335229689076, 45.85296623168453, 44.64729239863735, 48.316575557954856, 49.19417450504918, 46.26429734691497, 46.66288075908538, 45.835468538345836, 49.56736057035385, 49.04055487725043, 47.84446339453421, 47.810436833289366, 50.52990236589986, 58.46802257722425, 63.8419678134303, 64.31066751480103, 70.35032133902274, 69.02511719734439, 73.1050568242227, 25.042945031196844, 5.470799832574783, 4.323618344722256, 44.023247226592034, 50.518264693598596, 25.084245627926244, 19.054315359361713, 26.280323382346864, 26.355579937658003, 28.724432645305512, 39.371327969335745, 25.50464722418016, 45.97275541674706, 32.47584043010589, 60.900621644912235, 27.54186745612852, 0.18446649514859725, 0.036508961911163026, 0.007687376787690747, 0.05859276783021708, 0.06838451680396834, 0.010419407682943969, 0.08306651526401121, 0.058970935642719276, 0.007673904652737322, 0.044241960671159535, 0.06515049961425605, 0.05006573425846235, 0.03404430384116788, 0.07187118979110833, 0.014632060061088734, 0.009294527267376262, 0.02550981048825047, 0.010047274728065297, 0.09803683857523626, 0.0377608721535052, 0.15232696167884335, 0.019410959625196074, 0.09747639929334964, 41.86253509213848, 68.48334373966341, 38.40941767538748, 29.427607713207124, 51.15891325858332, 45.28585818506057, 34.1888806896825, 32.86358241112002, 27.137392643959295, 35.49566145866148, 54.24106859391736, 72.79923746662756, 22.07416972806377, 10.994679139506433, 57.36440489369055, 68.14077177355367, 67.48721861070203, 60.840075938932365, 56.639570497697406, 57.636378119068766, 59.114119314378314, 58.437561450466035, 54.18646135637837, 50.24014903653053, 51.550048089796505, 52.898660936663234, 56.537753612764426, 58.024355442293235, 60.330975824786776, 61.28822242060016, 60.07830458302652, 62.00013652924569, 56.652694748293975, 49.48489665985108, 49.711911678314216, 44.77166291206114, 49.500437090473795, 45.97602667347078, 48.79879959167973, 47.2264547501841, 46.101593509797134, 48.05083105641027, 49.68134856993153, 52.25555696795064, 55.41283353682488, 55.35602192724905, 54.65169368251678, 53.38734119169174, 51.95226753911665, 52.62613465709072, 53.200667750450876, 55.61902861441336, 53.80876456537555, 52.63840775335989, 55.88968000104351, 52.71097160154774, 52.50232896497173, 52.52090923247799, 49.85151667748728, 48.48626905871976, 45.96514994098295, 30.687871133127523, 34.146526936561834, 38.21866104679723, 38.381741431451616, 35.10918248084284, 32.83775164235023, 28.28917899439412, 20.38577764264999, 17.329582514301425, 6.593547896031411, 1.8305807007897286, 0.26564782124853903, 0.6138114018305656, 0.08598187818161904, 0.12949273050312074, 0.04591529971108802, 0.5770160762533065, 0.2875570472209685, 0.9027816667672127, 0.5853986103207834, 5.28770947648633, 20.98347821543294, 23.689333123545495, 24.714685793845888, 21.005688636533677, 28.00252433746092, 33.52424683109407, 39.06207261546966, 36.858328157855624, 45.02797019097113, 50.60968337520477, 48.25609260989774, 51.00430127113096, 47.86726020997571, 44.087832973849395, 43.94512930224019, 48.320611676862164, 47.701689120261904, 48.82296531431137, 43.9002848440601, 46.16975645865164, 47.9835977092866, 50.82850064000776, 50.05920225574125, 48.877505871557425, 46.92791923399895, 46.395422181775494, 44.535642131682366, 44.771702135762865, 44.04288261167465, 47.50537449313749, 45.79066330386747, 47.90102789478917, 46.32024603505289, 46.57896164924868, 46.61078776082685, 48.451516858993045, 46.249600225879306, 48.448418186556914, 47.784388372975016, 48.53369835884341, 48.97316463531987, 47.39178657531739, 49.73693640001359, 49.1180177657835, 52.56504374165689, 52.75203489488172, 51.533593746923636, 51.750473360861506, 53.13304216630998, 62.08199639474193, 65.24209314777006, 68.65854817052042, 72.24668533571305, 69.43272206091112, 74.41071187296222, 31.70658323072618, 4.385186808724558, 5.737183190161183, 51.65133545475622, 53.54356527328492, 30.315808826877227, 20.5316113656567, 26.485973250481393, 29.604965525288737, 29.116903043562367, 43.48072459620815, 38.13894671778525, 56.321787911076704, 40.31142204038559, 67.43565513241676, 44.067456260804214, 0.1331868984045521, 0.023641745304508556, 0.10514313910877514, 0.08907058381385381, 0.08242251111134406, 0.028526193589993545, 0.07113072750789505, 0.08806940648824939, 0.02460727847421602, 0.09905683102026101, 0.130969732699375, 0.18630650044689256, 0.1625717942032122, 0.3006015940298957, 0.10517202828439975, 0.13759593359164654, 0.24141336520833356, 0.1312966990254579, 0.2150353951559913, 0.14762656793238657, 0.3893968228611254, 0.18267570333855768, 0.2718997115810072, 49.44837154880647, 80.32030382464009, 49.35106146720148, 35.23189383168375, 59.820702921959665, 63.01874076166461, 45.10030261931881, 38.883816580618586, 33.52294068182669, 44.29425554890787, 62.19607460883356, 76.29716011785692, 21.14533874296373, 13.530074704077936, 64.36742813356462, 70.30884619682067, 70.20800990443077, 61.68535455580681, 58.025159528178555, 58.950454496568256, 61.79508286137735, 59.878840292653734, 55.47130823135377, 52.33797381001135, 53.07579125127485, 55.248835317550174, 59.34849269928471, 60.38754032504175, 61.2415736721408, 62.0025017184596, 62.019269850946245, 65.29187586999709, 59.259007746173495, 52.18515434572774, 51.96522312779581, 45.62516673918694, 52.84020977635538, 48.30949567979383, 50.249111652374275, 48.09001161206154, 48.07733451166461, 49.888151614896714, 51.670264813207815, 54.33462496726744, 58.666847521258944, 58.581771312221406, 59.17244495884065, 56.14244930205807, 55.2220808306048, 54.07191638023623, 54.27410671787878, 58.44785767216837, 56.56508076575495, 54.63042659144248, 58.57538177121071, 56.021632456010394, 57.711240476177586, 59.91987220702633, 53.77137653289303, 53.19370554339502, 52.486404142072125, 37.242771425554835, 40.428002726647165, 45.23385147894583, 50.33704726926742, 39.749318938101496, 39.05183522931991, 37.06020470588438, 33.64987642534318, 29.662645939857732, 14.025987809704198, 9.034133399686507, 4.378066726269261, 1.235907462335402, 0.16353197816398837, 0.5390393205227391, 0.654507401970125, 1.0962938829775781, 2.2151509552232684, 1.571344024231357, 1.0842214404575288, 9.595965858428709, 29.213158007591005, 26.263416005719094, 30.159072875976566, 22.108553224994292, 27.9877781867981, 33.023250333724484, 47.609156485526796, 48.25446482627623, 49.9740005308582, 56.06149158170147, 53.119082450866706, 55.541255858636674, 47.780556217316665, 43.94676885297222, 46.33275839590257, 51.00052402865503, 50.67939566027734, 53.362622414865804, 46.98987307087068, 49.806264292809274, 51.756466742484804, 54.970590222266416, 53.25683609131844, 53.0705705765755, 50.84585712802026, 53.11474038708595, 45.944526118616906, 48.3422984615449, 47.2027361777521, 49.33471695069344, 48.330041054756414, 50.75681540273851, 48.539844712903424, 49.53037654199908, 46.83915991936961, 52.83477729366672, 48.297842318011874, 52.17748218967069, 51.1088873494056, 52.92961628206315, 52.674721056415194, 49.16718859826365, 53.364705193427305, 50.54091245897355, 59.762726368442664, 57.57163939937469, 54.08704103962068, 54.49830547455819, 55.8925433312693, 64.39930131358486, 71.307724829643, 70.87883718552129, 77.29947474695022, 72.48295322541269, 79.91032984948929, 39.42321308197514, 5.5475807189941415, 5.3213947915261794, 52.92905930549868, 59.62311744689942, 38.409123497624556, 24.986925740395826, 32.8516270268348, 33.26544884712466, 39.40836298850275, 57.69775144515499, 38.28112479179136, 56.30979330308976, 41.359753916340495, 75.32987225440242, 48.10967445373536, 0.2864576191190751, 0.11113558610480641, 0.2321420312528649, 0.1609422485794752, 0.1484040858884973, 0.11196155146124864, 0.10071618512513177, 0.24846837615534184, 0.08941052000849478, 0.2022972681950177], [0.05974019517100627, 0.03726350105998497, 0.15134692071906983, 0.31703117694104876, 0.08897230239404787, 0.10525611409496878, 0.04339721083881394, 0.11373708279983652, 0.1018193057708202, 0.04616267333227781, 0.12299268130934048, 0.13532125000511447, 0.23982914134619698, 40.41198376686343, 57.41177143589143, 47.656687767274924, 28.091883774726625, 40.88676314200125, 38.691828327794234, 34.430184902683386, 32.36560025522786, 31.57772944819543, 30.478936279973677, 44.15682354281026, 67.92209963644704, 33.267688520493046, 9.636666332521747, 41.132746742617705, 65.88325162087718, 63.4828983583758, 60.757321773036836, 54.813918990473596, 60.275733163279874, 58.246659694179414, 63.02221990400746, 60.2753330815223, 52.76372355799521, 47.215887884939875, 51.68735850241877, 52.83061565891389, 55.369977720322154, 57.86307542554794, 58.864154508036954, 57.368778336432676, 57.8312453915996, 54.65454132326188, 47.85107258827456, 45.93742662860502, 43.22606471277053, 43.770509304538855, 44.67861252446329, 42.01571541447794, 44.74193919089533, 41.21448109226842, 45.541769304583156, 45.78090836924892, 46.322250366210945, 51.607083274472146, 51.118501078697946, 48.38096910907377, 47.32606726308023, 48.127070165449574, 49.42082866545647, 49.80409129973381, 52.93002813093124, 51.558963637198175, 51.57346463972523, 50.47608744713568, 48.877274451717255, 47.9505007497726, 50.27208497447353, 46.36315676473802, 43.07308835368003, 38.775994546951786, 28.45717214768933, 27.439220989904097, 33.14871126605619, 26.399008420205888, 27.99499927028533, 26.399500677662513, 19.236574172973633, 20.14468327645333, 5.911385455439168, 8.026538770045004, 10.670593304018821, 2.581359123991382, 2.8075832945685235, 1.2522874027490616, 1.25926946680392, 0.446291231219807, 0.18486743492464866, 0.09087881944592922, 0.4726987416225095, 0.8098066009340749, 4.032599070379812, 11.40899125606783, 20.83954095840454, 18.040541525809996, 9.642666578292847, 15.03683065214465, 27.955426477616836, 29.03861449610803, 34.69022235562725, 38.32892279471121, 51.496707777823175, 46.848055854920425, 48.40458177751111, 44.51075861530919, 44.09870186159688, 41.51233411604359, 45.199507205717026, 44.65026947759813, 47.087077248481016, 42.87509887449203, 40.77661906519244, 42.73593318077826, 45.39617484615695, 44.92983248925979, 45.98960199663716, 41.531318387677594, 42.80672804001839, 41.171688033688454, 41.79229720946282, 42.224295293131185, 43.63304984185004, 41.42448086892405, 43.52099164839714, 42.92326950257824, 45.663535364212535, 44.22506101669804, 43.95947340996035, 44.064302675185665, 42.834333681291156, 45.49006462097169, 47.421055301543205, 43.51183683641496, 45.434496402740486, 43.47055389035133, 47.965366532725675, 44.84896498341715, 50.74520518702846, 48.35554038324664, 47.298430242846095, 49.53158855438233, 60.442194631022794, 59.929576150832645, 69.06335246178412, 66.54157438585835, 70.44999660984163, 71.7993703965218, 24.407940756890085, 3.1594431880981695, 12.545104795886624, 53.97746178411669, 38.712581588375954, 21.16072423996464, 32.997539197244954, 30.965290569490005, 35.25232545791134, 34.38132785981701, 28.88376520526025, 27.19288241478705, 73.20754051208496, 46.14884630326302, 45.359743871996486, 50.639226667342655, 0.6774501418394427, 0.11487079333634147, 0.1460827015821011, 0.07954858588956057, 0.03888315648861951, 0.20930248342694777, 0.1972622319214767, 0.04700674134637079, 0.07258176698439545, 0.08104102475748909, 0.09093144202544805, 0.05922530747709736, 0.15640213574853637, 0.060596662318153735, 0.03961180569604039, 0.06880973390634022, 0.014728678112489083, 0.08647531541364809, 0.07425068952744046, 0.13661339518523988, 0.027385017526666486, 0.04704448266796047, 0.2114519882466524, 50.176677242402114, 65.66583856459587, 53.99381414536507, 30.522653056729226, 47.870817799722, 39.835450264715384, 32.11873216013755, 26.111304529251594, 33.78570810441048, 37.166449946741906, 47.56671644026234, 71.69170133529171, 39.51295298914756, 11.544944528610477, 39.7605682957557, 69.24594663804578, 66.5659950625512, 61.58554984677223, 59.38675542031566, 63.19209383380029, 60.91718973652009, 65.13269039892381, 62.74011911884431, 55.567014063558275, 50.591267847245746, 55.1756085888032, 55.010563096692486, 58.713002051076586, 58.901997535459465, 63.450185791138686, 62.2562712238681, 60.35061905460974, 58.105921130026545, 49.70293729535995, 48.479687321570616, 45.74732895820372, 45.85758678374752, 46.649274056957616, 46.54273463833717, 47.80809125592632, 45.998172375463675, 48.21949297381986, 47.704379866200114, 49.04108047485352, 54.947864009488015, 51.54167775184878, 52.513393971227835, 52.163251830685525, 50.909430903773156, 52.54180762075609, 53.32215139942785, 55.70326151386384, 53.870475215296594, 54.361744234638834, 54.387239640758885, 50.486689613711455, 51.07423320893319, 53.15243044207173, 50.2783372325282, 48.56811715710548, 45.70931334649363, 31.873274157124182, 36.62822623406687, 42.199615740006976, 33.30093845244377, 37.871433227292954, 34.99779501268941, 35.2385736280872, 27.18961508043351, 12.896257927340846, 8.074775588127876, 5.585493858783476, 2.3105081867787147, 0.5618912330077541, 0.8394019870508103, 0.5127309725409555, 0.08912090046872055, 0.2274547376099133, 0.04162847853055404, 0.15973947521659637, 2.003249074182203, 6.860828986090999, 20.950563646131947, 29.544070728363533, 24.400854995173795, 20.652092849054647, 30.419059338108188, 42.2933643094955, 44.37595851959721, 39.01384707420103, 42.72316978823754, 52.72577070420789, 51.167134546464496, 49.15542148774671, 49.38916337105536, 46.8929866052443, 44.9809919634173, 47.048818449820246, 47.17762516390893, 48.4786831948065, 46.18685014786259, 43.775541705469934, 47.32802060342605, 47.74430567218412, 48.43788270027407, 45.94686777360978, 45.15409400386196, 46.2730206981782, 43.61658765423683, 43.37955882472377, 45.35422901953421, 45.19399235325475, 46.927746649711366, 45.569829940795906, 44.9414348602295, 46.07824364016133, 47.273774223942915, 45.36163445441954, 46.95243012520575, 46.280657552903705, 48.44871236431984, 49.11700579427904, 46.47441871704594, 47.367330597293, 46.03898463710662, 49.474639661850475, 51.42008819887715, 52.40364605380643, 52.518849988137525, 49.61881029990412, 53.58910006861533, 63.1536114600397, 65.73126762144028, 71.95366074962001, 71.25408249516641, 71.78066069079985, 73.58837127685547, 28.81837537211757, 2.6139846636402995, 15.921110376234978, 60.86298650310886, 41.73329691733084, 26.31796048533532, 37.82536891198928, 21.90993420539364, 21.773722056419622, 35.81715852983537, 32.81919098669483, 37.959286474412494, 89.77058795190628, 47.212855892796675, 53.244955232066495, 64.41601845525926, 2.8272289758728397, 0.24581161387745412, 0.10721465617778803, 0.037890861952497114, 0.06954763745588642, 0.1531856083461354, 0.07194311012543979, 0.040771168686689875, 0.19269395769844133, 0.019616209901869297, 0.16207431202694295, 0.12628881290795343, 0.2575900471739231, 0.5627243076601337, 0.16818928712558362, 0.14945033216668716, 0.1717029647120545, 0.3524385657041304, 0.28945881452771927, 0.30237285059786617, 0.14329205777856613, 0.1415755458536648, 0.4791377106260869, 62.28522223810997, 75.28260769382601, 61.116163730621345, 39.83012368602138, 54.91930523226338, 53.04015259588919, 46.80173266318537, 41.93185121782365, 40.23415134799096, 44.20629639779368, 55.87390030584028, 77.13475873393398, 37.36205070249496, 12.587995913720901, 46.34998544569939, 74.05567461444487, 69.35763220633231, 65.36760899328416, 57.89557226242558, 64.1206012233611, 62.25343142786334, 66.47835362342097, 63.79027489692935, 57.45448212469778, 51.59862272201046, 57.37669367944041, 57.42209511418497, 59.61710837579543, 63.356519591423776, 64.79460170192104, 64.58328793125769, 62.51644203739782, 60.06962437783519, 54.222715823881096, 51.01519761546966, 47.61889965303483, 48.153875643207186, 49.615856755164366, 46.87887783973448, 50.944496893113666, 46.822791868640536, 50.144298076629646, 50.178838468367054, 49.81429338455201, 57.28743622379919, 55.0446798724513, 55.37606523882959, 54.990096169133345, 57.15473851849956, 54.98871157246252, 56.711063538828206, 61.339942793692316, 59.52101815131403, 58.30601692199708, 59.1042741652458, 56.57834622167773, 58.947049879258685, 58.43197207297049, 53.01699492239183, 52.68922205894224, 50.266860377404, 38.216193875958844, 41.68909965022918, 47.49920460485643, 41.786503868718306, 47.31780282912716, 49.70706362878123, 48.6947940241906, 43.169186422901774, 25.55198827097493, 26.240530936948716, 19.517608073449907, 8.539341111336986, 6.782537987155299, 3.0894585434467565, 2.0468549214063154, 1.1515676782977198, 0.5020631981953498, 0.21535120724189669, 0.6527062373295908, 3.1197399766214433, 10.96153413095782, 23.788453378985007, 34.58005866696758, 31.73643639010768, 20.988871474419874, 28.582278105520434, 43.24182479612289, 50.61251140409901, 50.267495801371915, 46.60450020144063, 59.33743161539878, 55.48394218567879, 54.152403416172156, 51.04272480933897, 47.93239901142736, 46.40156069109517, 51.48916113761164, 49.81557992196853, 51.23041414445447, 47.82871900066253, 47.698370795096125, 50.29899243385562, 54.66241744256789, 52.76285671418714, 49.72905243596723, 47.309326587184785, 51.218635266827, 45.934276965356645, 46.860929073825965, 47.13975467989522, 48.2879069543654, 49.03445559163248, 49.323189104757006, 46.41901523836198, 48.8601101598432, 47.90898638386881, 46.51574480918146, 50.589491013557684, 49.096025036227324, 52.531809499186856, 52.63634066427908, 48.51400021583804, 51.55303693586781, 49.743969209732555, 55.18312777242353, 54.694698549086056, 57.976808471064416, 56.00622146360336, 52.407584113459436, 53.60459343079598, 65.6152242998923, 68.49747996176443, 75.74980904979091, 76.15487221748599, 75.21128331461261, 78.64130973815918, 36.05703107772335, 2.988770320530861, 15.530843369422422, 63.331334052547334, 49.12434454887144, 33.76645711160476, 39.110698238495864, 42.30872431109029, 44.412409105608546, 44.39341698923419, 45.02895470588438, 36.80005350420552, 81.56982191147344, 59.00206112092542, 55.97381091886952, 72.62366433297434, 2.0901545786088516, 0.36080035411061784, 0.24894143544858505, 0.13513786387780022, 0.17952049361361613, 0.40532244249216975, 0.2999383457485707, 0.1060669185713895, 0.287220029821319, 0.16034500643370614], [0.12928751086996448, 0.03408146293593511, 0.2280514128506184, 0.3578818961977959, 0.127982173655783, 0.07710980626964763, 0.17001098292248865, 0.20417963815552576, 0.15795436777895497, 0.21159101788315082, 0.013312009170711523, 0.2143593225628138, 0.2992749136061438, 41.29739999771118, 62.693297786097375, 42.70933558863979, 29.74353894110649, 35.82246549667851, 50.42043293676069, 39.62014352121661, 49.556950599916526, 36.85923422536543, 36.48232190839706, 33.30639054698329, 65.29134242765366, 47.93649004351708, 13.62489898358622, 24.45290484736043, 61.90387372047671, 64.22095898658999, 61.272485871468824, 58.288123069270966, 63.065154167913626, 60.99975955101752, 67.0087992760443, 62.60132605029691, 58.3131830923019, 49.434011751605624, 50.93646387900076, 53.54426737754576, 54.71719334202429, 57.574945957429954, 56.543139027011016, 56.98774360841321, 58.50206875031995, 54.32670177951936, 48.94910481668288, 43.84561092622819, 46.26483863399875, 44.926965236663825, 45.34170881394417, 44.80918430512951, 43.925238963096376, 43.55144100804483, 46.629340571741906, 49.515557827488074, 50.4476071173145, 48.91960859298707, 52.12849178621846, 47.08232333583217, 47.65677013704854, 43.07100557511853, 46.340242278191354, 49.62350929937055, 50.36530402398879, 46.94747224930794, 45.33115371581047, 48.339595948496175, 46.62132716947987, 46.87326100564773, 51.90243382607737, 47.214817077882834, 45.51605816810362, 40.72480063284598, 28.507882510462117, 21.870581065454793, 18.34712182321856, 22.686863560830396, 27.348877037725142, 29.073437298497847, 29.38302605382858, 24.031583455301103, 15.621628588245763, 24.40174537320291, 13.464324993471946, 9.667528521630073, 6.950788545993067, 6.699052789518911, 4.092364960139798, 1.6779507360150738, 0.7761437782356817, 0.33093447766957745, 1.1262509851686417, 2.451031020572109, 6.77887253222927, 17.148400391301802, 27.236120662381573, 23.752602915610037, 10.759119237622908, 19.43863311121541, 38.05227410408759, 37.077043441034135, 31.801798766659154, 32.11172876819488, 45.17686336271225, 44.352204645833666, 47.40507164309102, 47.104712224775746, 44.64566853738601, 43.04619266140846, 44.79483627503918, 43.12405563169911, 47.71617443330827, 45.05740757911436, 42.09085233749882, 40.63028720117385, 39.964100083997174, 44.01594769570136, 40.288017257567375, 40.197892958118075, 40.74186294309555, 40.962629625874186, 38.644779497577304, 42.34296268032443, 42.97928094863892, 40.44206442371492, 42.88354373747303, 43.56305122375489, 46.1541768043272, 45.010954949163626, 45.759880542755134, 43.99502577320222, 45.04344394130092, 44.2136900655685, 47.66898439776513, 44.30763475356564, 44.18515874493507, 44.03653621673585, 44.87637450618129, 46.94517374038697, 50.48776434313867, 50.435345788155836, 50.93130203985399, 52.51078167269307, 62.780515609248994, 63.425443480091715, 67.89712198318975, 66.07739325492614, 70.13954885544317, 72.47422987414946, 17.018477762899092, 1.9924100945072791, 27.796774448886996, 53.99450056014523, 39.132235973112046, 15.815942806582298, 65.56031896222022, 103.62516818508026, 43.91376995271252, 26.18010094088893, 20.702907154637, 33.08294880774714, 63.55236745649769, 39.63410323665988, 46.08311522391535, 71.38163797317013, 10.263609155531853, 0.1334912191715933, 0.03290846741067306, 0.09284283905740708, 0.019983466707109925, 0.09493864111361966, 0.11464750168905144, 0.09048786945641042, 0.11727640134913307, 0.05085055303249148, 0.06781268579464766, 0.16114851009220849, 0.13974482554101175, 0.0814597684169008, 0.08715407697543984, 0.06141679391505257, 0.06748218014235459, 0.026528201809513475, 0.056174940715033206, 0.04013782847792872, 0.06716187112033367, 0.13903322178990613, 0.45130095594832975, 53.08828792264385, 71.96641629742038, 50.92226097660681, 32.27189090944106, 42.13723436478646, 48.3697001395687, 31.285534443393832, 40.32369513665476, 43.652508720274895, 43.89262837748374, 37.35525323498634, 67.65078929162794, 54.48036847576019, 16.613467547201342, 24.358134500442016, 63.37464094161988, 67.44740655345302, 66.11312604719593, 61.13604230265464, 66.03009731538835, 64.7335421654486, 68.22946440789008, 64.12381364453223, 58.776116909519324, 52.36439881786224, 53.92984813259494, 56.037663182904645, 58.6958848276446, 58.33051212372319, 62.0916768043272, 62.42090878948089, 61.651131876053356, 57.928582929795795, 52.40008454168997, 47.06974429468955, 49.88619827455091, 48.2746022747409, 47.02555879469841, 47.05394106526529, 47.07195258909657, 48.825091238944765, 50.109039891150694, 49.81825105605587, 51.25530942793816, 49.599237672744266, 50.85255653627458, 50.09968896065989, 51.155285066173924, 47.41738396306192, 50.58124619145548, 51.95543289184571, 53.884666350580034, 52.51319393034905, 51.43219263322892, 51.01808840228666, 51.39061943177254, 51.230782847250666, 55.05938091585713, 51.39513015747071, 50.273128324939364, 46.425957833566976, 32.29154198400436, 24.871284461790516, 21.71862844497927, 30.15679201772136, 35.96438861662342, 35.77048232478481, 40.899914849189024, 33.70102413239018, 12.465712101228776, 18.328041453515333, 14.040821233103353, 10.250487846712913, 6.347580475191917, 3.6862444685351465, 1.9645664143946864, 0.9959166917589404, 0.26188927131795114, 0.9301160516277437, 0.5132806253048682, 2.5475691306975583, 6.206123136704968, 17.713105986195227, 32.04800594237543, 27.55615076711101, 22.30676627928211, 34.21027329660232, 48.12894113602177, 51.095665039554724, 42.746001905010594, 37.17840533102713, 49.5401785450597, 48.35559137405888, 46.97101039271201, 51.664189061810895, 45.06737039935204, 46.80891452297088, 48.77703828196372, 46.534176026621175, 49.474404319640136, 46.68352419330228, 44.82809797410042, 46.11950305200393, 45.36675706986458, 46.53067727242747, 43.65881196914181, 44.72523381633144, 43.22865347708426, 43.23950275298088, 44.19803196384061, 45.763724465524, 42.854624102192545, 46.53971833567466, 46.36325090162216, 45.772828286693944, 48.11240442337529, 46.70442258158038, 47.37233554163287, 47.03144627232706, 47.712491327716464, 47.303066484389774, 49.6394851130824, 47.186168086144235, 47.43366964401738, 47.732868040761645, 49.02356316966396, 52.827058069167606, 53.80596399307252, 53.1981417440599, 52.19042208886916, 56.757865259724284, 64.61379220408779, 65.56072296634798, 70.310925053012, 69.438888026822, 69.34588078529605, 72.97069211159983, 18.161781987836285, 1.842859803188232, 35.59641145890759, 58.928049918143984, 42.63777586721605, 20.837891601747085, 71.89458985482493, 85.61960635646697, 29.723307355757687, 24.91332638648249, 26.431428770865164, 36.37253868964411, 83.61717362557688, 44.60132614258797, 51.97041242353378, 82.34175220612558, 24.74442912686256, 0.14130603612190293, 0.011930963317413005, 0.04929030006150565, 0.13037900230096233, 0.029342657540954893, 0.016207846422349254, 0.09313350047675834, 0.16928071726954755, 0.17434829695811196, 0.2874656376098433, 0.29605069468098305, 0.19885295220921118, 0.4852939931856048, 0.29558050055657664, 0.2008887542591941, 0.19410412638418137, 0.3144326986324403, 0.24424954527808776, 0.32378013576230696, 0.1518718441647868, 0.17260227532636735, 0.8560611511911116, 67.24221168025848, 80.90767875794442, 57.552055005104314, 38.82003491924655, 50.15721444160708, 65.4428675097804, 56.20164963506884, 62.012546908470895, 44.64899470729213, 51.26636266708375, 45.974210616080995, 75.5882073986915, 57.90036932114632, 16.99765193846918, 30.232301565908617, 67.49518102215183, 69.85148214524793, 66.74271352829473, 61.672477414531095, 66.32349844901793, 66.23787310815626, 69.95915905121835, 66.73479034054664, 62.12239288514661, 54.110206557858376, 55.16440629959107, 58.055930522180375, 57.017765429712114, 60.451996634083415, 63.12429958774198, 63.12691580864691, 63.21961318292926, 60.83494940111714, 54.47321407256588, 51.05255819136097, 53.11595632183937, 50.907355969952, 48.81085695758943, 48.093278946415076, 48.53835028986777, 50.29123398565477, 51.86397498653781, 54.268360445576334, 53.45626508035968, 53.2085987829393, 56.47875724300262, 51.61948188658684, 53.79842127523115, 50.430336921445786, 52.80571645306003, 55.77006340026856, 59.366668962663226, 56.16642282855127, 54.65894614496539, 56.581986181197635, 56.56072693486368, 58.922342869543264, 63.11090861597369, 55.37610446253131, 52.85204356716525, 50.662925627923784, 39.665313536121005, 33.01303648179577, 29.782174287303803, 34.5433884282266, 41.610899356103715, 47.798136280428984, 51.91743296961631, 45.13659631052325, 37.40428678451046, 36.74617582751859, 27.338765167420913, 16.987373367432628, 14.673056314068457, 12.542235582105576, 7.714780944008981, 4.698483184460671, 3.4814234462476548, 1.8992759888210606, 2.330632152095918, 5.432764609013835, 11.331523464572046, 27.011894449110958, 39.01415301907448, 39.33918022340344, 21.64655685424805, 35.1420872442184, 51.32207209064115, 57.27703017573203, 53.46818516331335, 42.720616325255364, 54.217350021485366, 53.304857669338105, 52.938665190050685, 53.67290542971704, 46.73378936706051, 46.91070002894248, 50.63332350023332, 48.299587772738555, 54.17890687142649, 48.169106206586285, 47.25426435470582, 49.96683436055338, 48.40699011279691, 50.05446403257309, 45.95876824471259, 46.106531773844075, 47.384632172123084, 45.726461948887, 45.30882366241948, 48.470077514648445, 46.46518545766031, 48.747255725245324, 50.29122614091443, 48.91816516076365, 48.91949876662224, 50.115331372907086, 48.38340882332095, 46.8114052280303, 51.199337205579205, 50.426912692285356, 55.19187858027797, 49.107650941418065, 46.500549547133915, 48.011697569201075, 53.32604239063879, 56.75675522896552, 58.668844007676654, 56.46142821158133, 55.84845589053247, 60.6636594956921, 66.967159394295, 70.28696721599948, 76.10607008780204, 75.52437474650722, 73.97485025467412, 78.56908321380615, 26.250766361913374, 1.9654194073330973, 34.01678669837214, 65.32782831499654, 50.51827253833894, 27.08463872632673, 73.01932950173655, 112.16815317830732, 54.02724450634372, 32.25633086696748, 30.60608579266456, 45.8894403519169, 75.12578348959647, 51.81332934287287, 54.829145631482525, 91.19815811034172, 21.934662788145005, 0.4860879360668121, 0.16186225888950212, 0.16148624761450678, 0.3161627396700844, 0.3084004610296219, 0.19763997455518093, 0.09925927741513138, 0.2555604657578853, 0.2673786590176244], [0.0782905392829449, 0.021955698781136065, 0.11554049207798897, 0.35343325426501615, 0.16789183050634401, 0.1411028083173498, 0.05579600681460673, 0.11800635290602524, 0.15558848908591658, 0.17859751088244302, 0.02785026846874145, 0.04019872097659015, 0.420281412380357, 50.729190149614894, 54.44995441744405, 43.15616415392968, 26.766495281650176, 36.98224367633943, 47.24640000251032, 44.543055411308046, 44.91788102734474, 30.44375458071309, 39.93084230730611, 27.17532196352559, 55.41483002324259, 62.596062229525664, 23.46389489789163, 14.61771265152962, 50.84954023361207, 63.09835310905211, 65.11785207256194, 60.70079257411342, 64.60473937373008, 60.6102878047574, 68.21135090243432, 66.48673965084937, 60.68079240860478, 51.69063760388283, 54.16133857542469, 57.79787778854371, 56.17954707914784, 58.173970330146055, 60.42445375073341, 55.5520619884614, 58.32462856846472, 55.2108746190225, 52.66022005388814, 44.397527633174775, 43.052001691633656, 43.17348534061063, 46.5403223806812, 43.72110312984836, 45.60573139498311, 43.014205732653224, 46.986276257422666, 44.58274195271154, 48.6182568150182, 51.790359943143784, 50.72746430673907, 46.44765638536023, 44.466608416649606, 44.69036786786972, 45.382426938702984, 45.18590050358927, 50.710700096622595, 46.436583534363784, 43.45861811791697, 46.287933549573346, 45.26715632407896, 47.88361257122409, 49.48628910126225, 47.095780987893384, 47.50799855878277, 41.9719966765373, 27.548431542611894, 16.33185705830974, 15.899276502670782, 20.540373940621656, 26.595124967636604, 35.184193888018214, 38.01843189424084, 36.11654912271808, 32.87533971571153, 26.293759461372133, 24.39585985675935, 20.71638245736399, 9.874414916961424, 8.385239032007034, 8.859702656345984, 4.5456573463255365, 2.592629074088989, 1.2409827641902433, 1.2164553254842758, 1.82680161970277, 9.191958788902529, 19.039910454903882, 28.230233615444554, 34.70749647386613, 10.596969435291907, 21.00214477508299, 45.188375519168, 49.173150600925574, 35.3691493311236, 33.76044804050077, 45.69474174130348, 47.468621884622884, 46.79634724893878, 48.13894317996118, 44.00686348638227, 44.32420676754367, 44.68250351567423, 47.88733882288779, 46.19686003654234, 45.64647697633313, 41.94795254738101, 41.91283164485809, 41.56103034173289, 42.09654761898903, 41.68887607512936, 41.127792789090066, 41.56990274306267, 40.180654141210745, 39.918137750317975, 42.25135180257982, 43.50401170792119, 42.078124246289654, 42.93231448819561, 44.957489121344786, 46.0940468695856, 48.34440477432744, 45.91914446123185, 46.7160524091413, 45.13355255126954, 45.57053596742692, 47.135855843943936, 48.06759918889692, 49.89427051236553, 47.46379736931094, 47.803945310654186, 46.80012449141472, 47.67236940322384, 50.54661950757427, 50.40182129029305, 55.43692473442324, 62.540847024609974, 64.98356580734253, 67.18179933486446, 66.95739269256592, 68.07887677223452, 66.29319421706661, 10.479230669236953, 2.7928253767951845, 43.920120270021506, 55.00316942891767, 31.086429049891812, 14.382411626077468, 45.83954780332504, 91.21966054362636, 45.44705583203224, 29.49489401232812, 25.00178760097873, 33.01023983186291, 36.893288243201475, 35.73097229003906, 32.11234261912684, 55.34948725854197, 48.305973391379084, 1.456043011238498, 0.011877572734750087, 0.03243403298960578, 0.05408305719855332, 0.09272693761534269, 0.1158607857782514, 0.2518443264547856, 0.1348572458711363, 0.08710733029030024, 0.06127982122463085, 0.02646792984207071, 0.12748508984523435, 0.20401446959905087, 0.06593727957337134, 0.06120125124711664, 0.07764018426138548, 0.09923286270350219, 0.06247004989774958, 0.026366662594579884, 0.04327118554483018, 0.0334011155721401, 1.6134675832525378, 65.5055901312059, 60.51477416869133, 51.423912509795166, 29.461820587035152, 44.00230176987187, 46.45677981838104, 42.80470801937965, 44.418833947950795, 31.567601888410508, 43.27474917134931, 31.28067658793542, 58.404468413322206, 66.41205772276848, 29.646940769687777, 12.386709682403072, 47.074404070454264, 66.16578778912945, 65.12525750744727, 65.98511557425222, 65.06273100453039, 63.815899741265085, 69.13825404259467, 65.82995445497575, 62.135293560643355, 54.17481976170694, 54.54617015777096, 58.132965872364665, 57.12868221344487, 59.52810979658558, 60.19496371669155, 58.56954920676447, 59.95313390608757, 59.352411147086855, 52.32038590215868, 47.627662227999785, 46.861019288339925, 46.5829114760122, 48.228847826680834, 46.40416906725976, 47.26711796176049, 48.17428373521375, 49.38659814096267, 48.560040996920684, 49.97495366681007, 52.4413243416817, 52.49153067988735, 48.77927011059177, 49.86834364552652, 48.99400418804538, 49.495341931619954, 50.43136066006076, 53.304159487447436, 52.160984700725926, 49.81803532569639, 50.259686362358835, 50.289315946640514, 50.99900607139834, 55.91916837999898, 52.027345626584946, 50.832858393269206, 45.42929533989199, 30.84311266099253, 19.60030144260776, 22.065868031594064, 30.94626707415427, 31.880934546070716, 44.0034588690727, 48.02847354642807, 34.711552204624304, 37.23855095524942, 34.14271831512451, 26.14052422585026, 18.278852970369403, 13.109652515380615, 9.840375608013524, 5.665269965125669, 3.0714146600615595, 1.9346171569439674, 0.5700110908477538, 0.9141461827581929, 3.636800050735474, 8.853076792532399, 21.40234616494948, 31.955241887800156, 35.66132276288925, 31.85664526877865, 38.299179461694536, 52.32977213398103, 55.0301984817751, 50.04168887292185, 36.78151246040098, 47.18237907655778, 51.50964375465147, 47.94759819584508, 51.12103885219943, 47.5198676509242, 46.61904435003958, 47.96695901501564, 49.378082675318566, 48.38238508470597, 46.958235233060776, 45.75556201319541, 44.34834895595428, 45.67589083025533, 44.386756804681596, 43.52618878887546, 44.49243330186413, 45.12531557390767, 44.93426868992467, 43.76465712824176, 45.2466070267462, 45.414174602877715, 45.18263316923573, 45.627614298174464, 45.03376745408581, 46.56472344552317, 49.99082749889743, 45.86214850025792, 48.98669681241436, 47.13863288202594, 50.02933732924923, 50.85437651603453, 50.83096781084615, 51.9593591843882, 51.46827843881423, 52.408635308665616, 52.123867311785304, 50.80056159727035, 53.96835404057657, 51.92641519731092, 59.127063135946955, 65.26262675562214, 67.83306183353548, 68.58282289197369, 72.82751775556996, 68.90462198565083, 67.27433589196974, 11.313867895833909, 4.32358451427952, 52.36533626433342, 60.09457457450129, 35.061384477923, 18.299351276889926, 49.848570977487874, 69.05613530066707, 40.772390750146684, 25.611741658179994, 28.888344572436427, 32.83087376625308, 46.41559493157172, 41.935957939394065, 38.09357666200207, 60.64835048490956, 65.63216109429636, 5.72459924605585, 0.17374959924528677, 0.08775026958075263, 0.16014205442080576, 0.059606122123377944, 0.08137263357639313, 0.14998374386660515, 0.1262048496714523, 0.06203467063906212, 0.2185495936822507, 0.17260216807405795, 0.2413397288370517, 0.5894563635510783, 0.4846044221232015, 0.1496762208520405, 0.18044945183059863, 0.21329438373927148, 0.3506929271163479, 0.31515202454982266, 0.2283178888742001, 0.3389099739011257, 2.040626565294881, 77.11284837415143, 70.9445055069462, 56.06290755733367, 36.379234175528254, 52.826116700326246, 61.676894003345126, 59.413972746941354, 52.30917969057637, 37.02973573438583, 52.80577921098279, 42.0158056289919, 64.41137044660508, 73.26505814829181, 28.918656649128085, 17.210648405936457, 55.62467290509132, 68.14299967981154, 70.49224838133782, 65.9607655002225, 66.70975777410692, 63.73095689281341, 72.70279422883065, 68.63103666613179, 64.63321970355126, 56.169945116966005, 55.62630068871283, 62.980933035573656, 58.26823273012715, 62.85782160297517, 62.347466330374445, 60.93017670416064, 63.29891174070297, 60.29765529017295, 55.53162643986364, 51.015899719730506, 48.29754814024895, 47.59411811828614, 50.625396390115064, 47.460847746941354, 50.19344537488876, 50.26621710869574, 52.69389752418765, 49.7532142362287, 53.240103260163345, 56.642316156818026, 56.23904943466187, 50.42773639002154, 52.775165111787864, 50.707385693826986, 52.443332595209924, 55.1131683780301, 61.13296716443954, 55.141013283883375, 50.95490686355099, 57.55562436196112, 55.296598019138465, 60.57069932260821, 61.63483442798738, 56.138511242405066, 55.91071567227764, 51.012463723459554, 36.10768064375847, 25.06449649410863, 29.239094680355443, 33.186424855263006, 36.04484035122779, 53.080953090421616, 56.65888424842589, 50.834164542536584, 50.225526440528135, 44.676145353624904, 35.14856307737289, 28.83230566978455, 17.05781913572742, 16.674997768094464, 17.43588266834136, 11.940918584023754, 6.983702624997785, 3.558634077349017, 3.9098100075798654, 6.481793686266869, 12.66915955851155, 26.70979545962426, 36.059270751091745, 45.62266818938717, 30.341619983796154, 37.223520432749105, 53.99660295055759, 58.6848472779797, 52.13867818155597, 47.120864545145345, 50.95386743545533, 56.434548208790446, 52.091472456532145, 54.777531162385024, 48.44695906485281, 48.1611281056558, 49.8015143025306, 53.24274693765948, 51.888391740860484, 49.08346560693557, 46.83009139953121, 49.16705523767779, 50.119085081162, 48.74366675653766, 46.70242609516267, 48.24126212827621, 47.584712274612926, 46.743885547884055, 44.34565036527572, 46.32454495276175, 49.43085032124674, 47.97508616601267, 49.08041008057133, 48.59005105110907, 50.48838015525572, 56.039283121785815, 48.201053911639804, 52.541399694258175, 48.71193085947345, 53.25734992181101, 53.30998028478315, 51.341797690237726, 52.2910818746013, 52.21968297035464, 55.04097323263846, 56.01602346666398, 54.02428311686362, 59.661729258875695, 54.54931982101933, 60.94945907592774, 67.0803903764294, 71.72610836644327, 75.37174747836205, 78.320648131832, 71.42949873401274, 76.36456212689801, 15.877402424812319, 5.238783301845674, 55.542056022151826, 66.1016962605138, 43.6573959935096, 26.64700419672074, 53.386635165060724, 93.72291718759845, 52.0193479138036, 36.8739588029923, 36.997956691249726, 45.57973784785117, 48.90171866263113, 46.837269336946555, 42.505070317176084, 68.7511553302888, 73.0481981462048, 5.524259286542093, 0.2667596906183228, 0.16408589037676014, 0.18012253146979118, 0.0974537690560664, 0.13868498886304517, 0.28744430972203133, 0.2737686903245988, 0.20268504658053], [0.07393552861627072, 0.10091725256173842, 0.028590188744748314, 0.292860888425381, 0.36876500253715827, 0.05465905189574246, 0.04531921818852425, 0.0903402136698846, 0.14738236974564292, 0.34363575580139316, 0.14042463664325977, 0.14560967293237487, 4.320284330075787, 58.0153496803776, 55.316386376657796, 36.90454936796619, 27.774032546627907, 33.91195351077665, 39.885939013573434, 19.716470280001243, 36.551222262843964, 75.72722404233872, 29.566110526361776, 21.001460321487922, 42.80628088981875, 67.05888009840443, 53.676588535308845, 10.763396582295819, 22.378963385858846, 65.12683430025655, 62.964549295363895, 66.79091161297214, 62.688037887696304, 65.61937416753462, 64.36275659068939, 69.93643283843994, 60.15709323267783, 55.907781739388746, 55.19226689492503, 56.206740871552505, 56.639594031918435, 59.37258389688308, 56.8501272509175, 57.74669085779498, 54.29375779244208, 57.370060951479026, 52.054939500747196, 45.799618074970866, 43.978336088119015, 44.56674260477866, 45.947683626605624, 44.21657300764515, 43.08587135807161, 44.216749514302904, 47.100217188558275, 48.41130864235663, 49.48165285971857, 52.968796837714414, 51.04147749562418, 47.37592451034054, 44.34064542093585, 43.70338578378001, 44.816719178230535, 46.089528299147084, 48.724631494091405, 47.96339750289918, 44.5583644220906, 45.69891514316682, 45.626335605498284, 47.76748295753233, 48.045214222323516, 49.22001507974441, 48.71884207571707, 39.598174325881466, 27.75034143078712, 17.20075422717679, 13.264159579430858, 15.351879346755245, 23.783456279385476, 36.33755114770705, 52.3910120994814, 50.50617202635735, 36.24017046343896, 22.62926551603502, 16.220085197879424, 27.528511785691787, 18.507619327114476, 12.427855345510668, 14.352022082574907, 11.014123309043146, 3.824837986500033, 2.9033874311754784, 1.0552788838263483, 1.3724416133857544, 4.633841053132088, 14.854855229777677, 24.36277662554095, 35.14256969574959, 14.625443643139256, 32.04279507360151, 45.14524905912338, 56.321466276722575, 40.8696969093815, 31.146366788494973, 38.044558801958644, 49.998342760147594, 42.68160835389168, 49.572714605639064, 46.61862465643114, 45.02598154929377, 44.33644064011113, 46.51698427815592, 45.36833778504403, 43.42233619382305, 44.09849005360758, 41.377973325790904, 40.93734602774344, 40.07895884975311, 42.97264429830736, 42.40953314688898, 42.007545117409, 41.04248908258254, 42.614143586927845, 43.97402932566982, 43.910231974817094, 43.00958125822006, 41.8385733327558, 45.71703257099275, 45.76569741772067, 48.08891727078346, 47.75931658283357, 46.13722039807228, 46.4079031636638, 46.02490332818801, 51.37579287252119, 50.384892340629335, 51.64136871214836, 50.14820867969144, 51.514750680615826, 49.6348371044282, 50.0243402296497, 49.69891686593333, 50.3077785430416, 55.029978829045454, 63.13197174379903, 67.2399837740006, 64.03267345120831, 67.38989676198652, 67.60063002186438, 51.3428920315158, 6.5155755896722125, 7.111202699522819, 54.90769109418316, 56.44591915991999, 26.08068258531632, 11.731998439758055, 39.088878093227265, 28.695207065151585, 22.733153412418982, 35.607649049451275, 21.99481429592256, 30.739917062943984, 35.0164419604886, 38.511195336618734, 42.485407475502264, 52.171649625224454, 57.80652661477366, 13.71898683809465, 0.3928129927765939, 0.034467295458119725, 0.080075700346741, 0.1338633080764163, 0.04976018008986308, 0.17105387373557016, 0.09889067421036382, 0.1338883285080233, 0.04867570602425164, 0.019767391608066617, 0.09449194290585096, 0.178896177920603, 0.08109933170940607, 0.025432002768220923, 0.08005438011980827, 0.026084725001466372, 0.174959926235099, 0.1256450615643013, 0.1522465377685524, 0.20298696183148893, 6.671834972596939, 69.45366751763129, 65.11875814007175, 43.51470408901092, 27.193125601737734, 41.23210822382281, 45.73310252158873, 25.69019690636666, 34.943403505509906, 63.50581676729264, 37.26834920144851, 25.264109834547966, 46.3485380911058, 66.85689372401085, 60.83824026969172, 14.355399243293272, 15.230698700874084, 62.66736307451802, 68.293744210274, 69.7998559090399, 65.3338413084707, 68.18132908113542, 65.66057082145446, 69.47191438367291, 57.505347421092374, 56.736598168649984, 57.16617614992204, 59.03480898949408, 57.94643755882018, 61.139788166169204, 58.880765745716715, 59.525340603243926, 59.7642090243678, 61.72480967737014, 54.943066950767275, 49.65482550282633, 47.44234984920871, 48.18096745398737, 47.179343162044404, 47.08591230453984, 47.4748113847548, 48.29259418672132, 50.99435806274415, 49.494969306453584, 50.90318649045883, 52.59883496069139, 52.02241912964852, 48.185274216436575, 47.38309068064536, 46.494218841675796, 47.42922167624197, 49.75301027297974, 50.71256714482462, 49.95691860875776, 48.91978117727464, 50.25339488060244, 51.23692920131069, 51.10141523422734, 55.268502081594164, 52.857817296058904, 53.5378582246842, 40.060221687439956, 34.35514603891681, 25.227427828696467, 25.706749308493833, 28.951465314434422, 31.405855109614713, 44.23585537941226, 50.74510320540398, 46.67709542858986, 47.172259361513206, 34.734427467469246, 20.089834813148748, 31.49679526205986, 17.29371440026068, 15.394151710694837, 16.293007942938036, 12.414656569880824, 4.428470653872337, 0.5083304715733374, 1.8133910360836216, 3.746895588213398, 9.862363434606984, 20.475907825654556, 31.767042644562263, 41.95205534658125, 32.75508965215376, 47.81120169547297, 56.55787929411858, 56.217935316024295, 53.235702360830004, 36.15720448955413, 42.46918847483974, 53.05544591719105, 46.43581474981001, 50.9002447128296, 48.93122665343746, 47.875422662304295, 45.821336238614975, 49.478738538680545, 46.19500083308066, 46.10975203975555, 46.17637349713234, 46.99032806581067, 45.08015340374362, 46.12060523802235, 47.05672202571746, 45.34765512712541, 45.16721040971818, 44.12886096585182, 44.798782179432536, 47.07145444808468, 45.76837639654837, 44.65407025429511, 46.53121071477091, 49.126529309057425, 48.34516179177069, 50.098072944148896, 47.565712313498224, 46.63551830476331, 47.09059561452558, 49.6642941044223, 55.299073034717196, 52.08289031059512, 55.568029957432906, 56.241618587124734, 55.854602244592485, 54.81435045119255, 54.8102201954011, 54.789765034952474, 51.8555615025182, 56.61982920862014, 65.28134430608442, 67.95773829183271, 67.18933813033566, 68.49364388373591, 70.85883309764247, 52.18106331363801, 5.660860240459443, 9.624086310786586, 62.38532112490747, 58.23815991801601, 27.644572757905532, 14.521443959205383, 42.09284097917619, 29.22904556797397, 19.132221475724254, 25.21454872623567, 26.793555713468983, 32.429862406946, 38.34241967047415, 49.81357951318064, 49.294504811686856, 67.5118040269421, 62.99751681666221, 30.779585953681703, 0.3009695613816861, 0.07838612407325737, 0.037310071544901985, 0.0844417043751286, 0.02746322552763647, 0.10026053901040748, 0.0931215035398641, 0.09788255612816542, 0.18570483031292118, 0.13624878329855783, 0.2619243581448832, 0.4499480446740505, 0.6859759037052432, 0.1223835724616243, 0.3072011350624023, 0.13093075414578761, 0.2906904387618265, 0.3943974464651077, 0.16872685102205123, 0.3443116598552273, 7.8474605083465585, 81.87705332233061, 70.40873327562886, 49.6235171441109, 36.827412036157426, 45.546766404182684, 54.23863280204035, 29.995602215490035, 43.0734884354376, 83.59880124368976, 40.73670110394878, 35.13723134994507, 54.68379828237719, 74.64107267318234, 61.495743259306884, 14.19797589701991, 24.30966184985253, 70.6981885048651, 65.93155953191942, 69.78531176044096, 66.37601898562524, 69.3791267948766, 70.44041818188083, 74.97591757005262, 62.89413882840065, 61.866054227275235, 58.82626048980221, 61.186872297717684, 60.229445272876376, 61.06372164141748, 61.53033856422671, 61.01750043130691, 59.89915817014633, 64.31855147884738, 56.91892562373992, 50.46175902889621, 49.60994182094451, 49.96071546308456, 48.47125030332997, 48.28390613678963, 47.728573045422955, 48.61802147280786, 53.295279241377315, 52.37835461093534, 54.09597227650305, 55.85839125417895, 57.01808706406624, 49.04090789056594, 48.523672780682965, 50.44002909814158, 50.41496123037031, 51.74902600626792, 58.96066442612679, 54.115748866911865, 51.69931388670399, 53.50161944666217, 58.98920751387074, 58.37032025860202, 59.77667431677542, 59.621917201626694, 56.43804696298415, 47.7192731057444, 39.99991916841076, 28.710353297571984, 27.763804966403594, 28.56527659200853, 32.63535145790347, 52.19690968913417, 61.711657970182365, 57.64713718045143, 56.78117590565836, 40.98528131361931, 23.196791295082342, 36.91600661123953, 23.905057599467618, 17.927163454794115, 22.70505355250451, 21.705627749043128, 12.796350256089243, 8.809121731788881, 5.90877756957085, 5.118143943048293, 11.14899008504806, 25.753919732186105, 34.48662780946301, 41.37131706360848, 32.37253304450743, 47.43539156452302, 55.968543175728094, 59.21242567800707, 54.61047349437591, 47.205046453783595, 47.508339804987756, 58.934521828928304, 49.57659382973948, 54.11319540392969, 49.931811517284764, 50.3448567082805, 49.235159350979714, 51.66518926620484, 49.41267798023839, 48.42667648869176, 46.72168493270875, 48.386860509072584, 47.272723028736735, 49.970156608089326, 47.34953872619137, 48.45286615433232, 47.87722303021339, 45.3579709606786, 44.55736421769665, 49.61455060589699, 47.72837300454417, 46.8959479947244, 48.83410876797092, 52.09161758422852, 50.534699424620605, 55.119067622769265, 49.48395529100972, 49.77937252290788, 48.510066078555205, 50.57926539451846, 58.27487330282889, 53.78590106964112, 55.92237295642976, 55.54783759578582, 58.41837321558307, 57.12784674859817, 59.909701501169515, 57.39551321152718, 55.09285050053751, 61.8953739443133, 67.87402706761515, 71.56985682825889, 72.46482403047624, 75.51072489830756, 71.48047385677215, 62.56841736455118, 9.858374384141738, 9.34997441307191, 65.21525629105108, 65.20130049797797, 37.992677611689416, 20.10744429403736, 49.269378108363, 34.495759087224165, 29.96678456183403, 46.57257210823798, 30.306448090460997, 42.05208363071565, 45.390197154014345, 50.04203404149702, 54.19410997821439, 64.68468904495239, 77.50885086674845, 32.29156747941048, 0.5140611769691591, 0.2591372689893169, 0.36398059958892487, 0.24935510760593801, 0.09667808205009469, 0.5783124195952569, 0.3309974500969533, 0.2737738997224839], [0.11162570617612332, 0.1364876188698315, 0.09095710597091144, 0.10117491091331167, 0.3834618477811737, 0.2570922738842426, 0.09633387874571547, 0.12345498472812677, 0.12303450971000618, 0.2185749205490274, 0.01404867644586991, 0.5381604644560045, 8.366706813535384, 68.6434627348377, 46.431962982300796, 44.13610950593026, 34.607075952714496, 41.5495809431999, 29.585008505851995, 23.50544652631206, 60.00989844722133, 97.27942435972153, 35.664539106430546, 18.164994409007413, 40.7869113645246, 56.390856927441014, 64.84488256515996, 37.03106934024442, 2.2235266864299774, 23.27682529726336, 62.963607926522535, 62.91684935169836, 60.310603034111764, 64.90776208139235, 62.601765355756214, 66.65221660367905, 57.08935653009723, 58.45225464913153, 59.00819963024509, 57.45015575039772, 59.979374562540364, 60.93231439590455, 61.4960099804786, 57.47604731590518, 54.32961217818722, 56.614541853627856, 53.04993890946912, 45.5970904134935, 44.18950080871583, 42.85564784080752, 43.63537580736222, 44.31948815622638, 44.288721084594734, 43.52164276184575, 44.74145281699396, 47.89910985577492, 52.056280951346125, 51.68131020761306, 49.87914585298108, 49.76355360400293, 45.31976315283006, 44.90856147581532, 46.06954774548931, 46.88359645105178, 47.64543448725055, 46.43789752837151, 47.64143366967478, 43.88546220717892, 47.0063627150751, 47.04928521187075, 46.811671949202015, 49.70593006380143, 52.109997810855994, 34.739597151356364, 28.216977965447214, 16.136246496631255, 18.034691310697987, 14.893646490189338, 23.411656771936727, 38.166148354930264, 60.5357902280746, 45.51801150844943, 34.70501361354705, 14.788424987946788, 6.718322413582956, 20.87665246378991, 26.989297674548244, 14.224935327806781, 16.96270558141893, 16.45051169779993, 12.131667367873654, 1.5090891454489002, 3.4348151472307022, 1.8109556119288168, 2.0225151435982798, 6.843889740205581, 15.545189438327668, 27.846092370248613, 32.52198319281302, 35.88844760771721, 51.77322703023111, 51.147812950995664, 47.160441260184015, 31.2061397875509, 34.81781705733269, 46.233683247720045, 44.523447482816636, 47.715715515998106, 48.66308166134743, 46.01739591167819, 45.64049928419052, 46.74197143123996, 45.982926122603885, 44.245151396720644, 47.32628299343971, 43.89496611010644, 42.88495971310524, 41.12669844781199, 42.65117468372468, 40.953839594318026, 41.318212093845496, 41.33186194204515, 43.0316642022902, 44.85307170498756, 44.244829762366514, 43.68706087912283, 43.37768000941123, 45.22499084472657, 45.714314368463334, 49.538005551984234, 48.846087686477176, 45.124166319447184, 44.85846888634467, 49.44147209967337, 52.45131069614042, 51.32970894536665, 54.879187230140936, 54.88730261402746, 52.970914917607466, 53.00455708657542, 53.19324662608486, 51.645534269271366, 50.18434547608899, 55.86804812954318, 61.216109644982126, 65.45914534599551, 63.762088744871086, 64.1018601386778, 67.00907384195636, 30.3052713794093, 1.140665818125971, 17.92029146225222, 56.63362810688635, 52.72866149102488, 17.569219719979074, 20.637768353185347, 43.02466277153262, 37.11410983916252, 17.46454146600539, 33.791705408403956, 17.12667046054717, 27.573534711714718, 43.98920105349633, 40.024249630589644, 28.838646181168098, 42.062540669595045, 61.162965451517415, 52.536963493593284, 3.0128948582756907, 0.41195088036118016, 0.16026780009269714, 0.07410597551854388, 0.26783264272155305, 0.05465105010737335, 0.04822295572188112, 0.10547189808060085, 0.05506417068142084, 0.09268920012419263, 0.010830570902344922, 0.12432782700465572, 0.04338205761967167, 0.023400178629784815, 0.07461318701145149, 0.03818002950039603, 0.03695793923050646, 0.08304039932667248, 0.0346708909848765, 0.43674730785912086, 15.843286629646057, 78.51162833552208, 52.90182628939229, 52.831800214705936, 36.61268972581433, 44.24484152947703, 37.694181319205995, 27.38366257759833, 43.62285952414236, 84.4224597561744, 44.94745177607383, 30.23367439546893, 42.29791033652521, 62.852640151977546, 66.56265320316439, 44.25487103000764, 2.295626224048676, 15.367964006239369, 53.71378437165291, 63.716110721711196, 63.99798008703417, 67.2478755827873, 66.07251382643177, 65.24504669250982, 56.94766875236266, 58.49255700265208, 59.87263118067096, 61.62959414143717, 62.40379941078925, 63.83647649518905, 62.339550987366714, 58.563410697444795, 56.236139035994015, 60.55142871795162, 52.89925321455925, 48.09676985586844, 46.949198092183764, 49.07339296033306, 47.60275125503541, 47.34676168810937, 46.73158891739384, 47.642265212151315, 48.20330927448888, 49.6996581938959, 51.719329741693315, 51.821770283483694, 50.49768009493428, 51.5701110132279, 47.24499579398863, 50.05800201046852, 51.10545527550482, 52.20881016023698, 50.887238133338194, 52.682510883577415, 50.84069921124367, 48.67461735202421, 52.84579523148076, 53.86752167055684, 52.08581247637349, 53.02436897831579, 52.4582415242349, 38.46464856978386, 34.305229956103915, 33.612711967960486, 32.99800595929546, 29.796312470589918, 35.2422292770878, 44.762625771184126, 54.630787449498335, 50.97322825462588, 42.16923698302239, 19.93842544094209, 10.153554312644467, 25.455205748158118, 24.298286976352816, 15.250667487421344, 22.32654286969093, 17.463160791704734, 8.048687904111802, 1.7849417175016098, 0.5192459987536554, 0.881859744268079, 3.486252129077912, 12.634248502792852, 22.997638833138254, 32.059627925196004, 38.808742415520456, 55.32274061633695, 57.65005150148946, 55.981341869600364, 52.21741976276521, 41.06372871706563, 37.34583170183244, 50.94789758805306, 47.87425771836312, 51.1034470219766, 48.748236317788404, 47.87818793327578, 47.608462226006296, 46.9175837885949, 47.752495581103915, 45.50662094546903, 47.61032142946797, 46.77269143442954, 47.33714403644685, 45.926416535531324, 47.62503816235451, 43.44848663576188, 43.99314303551951, 43.60762503839309, 44.93253892467868, 46.203677115901826, 45.80138706391858, 44.74779921193277, 46.38074467259069, 47.93901997227823, 45.78352066778368, 50.942857342381636, 48.53671466150592, 47.54977964585828, 46.70356358251264, 51.665824690172755, 56.66749385095412, 55.945954245905725, 56.380760746617476, 57.1809164170296, 57.33518323590679, 57.65148708897253, 56.57534168612573, 57.16882767215852, 51.63658342053814, 58.52510875271213, 62.77485562909035, 67.46843830231698, 68.03436571551909, 67.45416087488975, 70.56141545695644, 27.260153024427353, 1.510276397870433, 23.611313258447957, 66.0544160104567, 56.52781824911795, 21.327948608706077, 21.20205621565542, 42.40279059256277, 40.58358353953208, 16.585997227699526, 28.38965246754308, 20.160892471190422, 33.59282162881667, 36.642982190655125, 50.81267387636247, 32.83789480886152, 55.065507658066295, 67.90837134084394, 74.04979105918639, 12.394793687328217, 0.6769385789671253, 0.09924351132564968, 0.0945649893894311, 0.29234114373403214, 0.15947715138956425, 0.13295253678675623, 0.062369811123297106, 0.20705433712611276, 0.2918123592051768, 0.2089866560192839, 0.2609707012532219, 0.8202820872106861, 0.19621379463182342, 0.15501306512423102, 0.17778286830552165, 0.16872919525109953, 0.2954107354725561, 0.2403384978852926, 1.0304333654142197, 20.07969548625331, 96.23835671332576, 58.340023871391054, 54.96161191694198, 47.360650800889545, 54.56907679957729, 40.78375385653588, 32.82286232517612, 70.15839192175096, 98.07195494251867, 43.389184321126635, 32.905881251058275, 53.61594084770449, 67.27202953830843, 74.5772635552191, 40.84728840858706, 3.343943391115435, 25.303180563834406, 66.92519787819155, 65.36822088303106, 65.62936052199333, 69.39124691870906, 69.10461579599689, 70.89991600282731, 62.041552835895175, 64.27551915568691, 62.34483049761865, 64.38356476445352, 64.63480434110089, 65.27928506174396, 63.95963499622961, 61.314094374256754, 58.80110240751698, 61.48680810005435, 54.84148933041481, 49.57245572920769, 49.467885340413744, 49.492953208185014, 48.90096164518788, 48.361129760742195, 48.1991554844764, 48.959659914816584, 50.36351150082004, 52.239694902973795, 58.09467569474251, 56.0663317864941, 56.579868101304584, 56.81593202775525, 48.5345220565796, 51.835765300258515, 54.579392633130475, 54.685520202882834, 55.69524418923163, 56.39057843915878, 55.822458421030355, 52.6361680799915, 57.93700818092593, 58.7834595864819, 58.1859923947242, 59.25626993179322, 55.95449716814103, 43.55788153986777, 40.3192275570285, 31.24013496983436, 34.43967703850039, 26.676633781002415, 36.067060578253965, 52.56581644858084, 61.90458759184807, 61.14305157815257, 53.12189086791008, 26.04987628998295, 19.178640765528527, 25.857046688756636, 39.46706125813146, 18.221113720247825, 27.636531899052283, 27.28602693926904, 21.035898731600856, 14.108125182890124, 7.462388190530962, 3.9275128899082064, 7.727570812548361, 14.737904860127358, 23.836561249148463, 34.51417461518319, 49.94296281568466, 46.89234725890621, 57.1773313706921, 56.56368832434378, 52.466039196137466, 46.55484299505911, 43.13468133249591, 52.76339015653057, 48.615358183460856, 53.88765127428117, 50.51755866696758, 49.79803516018776, 49.938797258561664, 50.9796295627471, 50.10567841991302, 48.323157295104004, 48.82465977822581, 50.15923053987565, 49.96331991687898, 51.3693876420298, 48.52487694832587, 46.64499082872945, 45.297386030997004, 45.51291242722542, 43.521591771033506, 48.591149314757324, 48.539483854847575, 46.0853470525434, 47.48039291751, 53.716259387231645, 49.18773005085607, 57.85642700810587, 51.22015322408369, 50.348292704551454, 47.06685743024273, 53.03517903051069, 59.290865236713046, 55.68454788577173, 59.027152522917724, 58.72557716984903, 56.34915036539878, 62.641291079982636, 59.84470782741424, 62.17995758979552, 53.33615818331319, 61.76162896617767, 64.59742023098853, 71.17637249731249, 71.94933045294978, 73.47265351203181, 72.34200677564068, 45.03910187752017, 1.8883981531666172, 21.681126663761756, 70.43501315578338, 63.6576791732542, 27.509898178039062, 31.874031174567442, 49.550231579811346, 46.763583690889426, 25.951803307379446, 48.30617735462804, 26.577731217107466, 42.252818769024266, 56.76536090912358, 55.62235086194931, 37.98926907200968, 56.84562044758951, 74.60156656080677, 80.69193270898636, 12.686644504147193, 0.6542187400402562, 0.37422451280778457, 0.33738463155684933, 0.5645556255213676, 0.3204960087614675, 0.16202777984642214, 0.15350785557060473], [0.05095300580104513, 0.2308570260121938, 0.13291542748770407, 0.20623030231123973, 0.5621817948356752, 0.2575306293945159, 0.1277565990664786, 0.09533723666062278, 0.21856739756561097, 0.25821189606382006, 0.09999144296612471, 0.15085236499867133, 22.50341626905626, 66.39970225672569, 45.24519497348417, 35.010707455296675, 34.765928022323116, 43.96265837454027, 30.221695476962676, 36.35924577713013, 58.68133283430531, 85.80799779584332, 32.10691405880836, 13.382052298515076, 30.693941000969183, 53.74199013556204, 60.13794029912641, 61.65294793344314, 11.106781459623768, 0.04150814143940807, 7.639993111933432, 43.9369668499116, 66.74630641937256, 59.807723799059474, 65.13271785551503, 57.01660833051128, 65.82782853034236, 62.39436611052483, 67.81180258720153, 60.51991639598724, 65.5745493212054, 62.54744837360998, 65.814162992662, 57.11771918881325, 54.409169612392304, 57.341266832044056, 51.82859128521335, 45.69467506101055, 44.44299182584209, 43.490734484887895, 43.184750387745524, 43.88363830504879, 44.08935877584642, 46.03699599542926, 47.811338978429, 48.33379084064115, 51.617030405229144, 50.253265442386756, 47.67600544037358, 50.43889161079161, 46.70519136613416, 43.5171438032581, 47.69773929349838, 47.561429085270056, 47.13126274847215, 46.82289385026502, 44.035669372927764, 45.92346691316175, 49.142359995072894, 50.96263785516062, 49.04841138470558, 50.486677846600934, 48.07611465454102, 32.298590483204016, 25.555420344875706, 20.52248401026572, 18.555664439355176, 13.90840691904868, 27.093273824261082, 45.056611337969386, 58.02324933390464, 41.54308549819454, 25.58040584287336, 10.633780879359092, 16.60597582017222, 20.668551114297685, 30.571490487744732, 15.61793665732107, 18.576203930762507, 18.37097767860659, 7.247720303074007, 0.6682229498701712, 4.529497671511866, 0.897332207570153, 3.681109105387042, 6.864795973224025, 15.540337466424512, 31.832171640088482, 40.82806095000237, 30.115569868395408, 52.68774724775746, 51.46603092070549, 49.38251887598346, 34.67124985110375, 29.63979421123382, 44.9648827891196, 46.439807722645426, 44.722621517796675, 49.26604801608671, 48.68559214376634, 49.58503869272048, 44.536230487208215, 44.52878190625099, 42.831682159054665, 44.442776095482614, 42.67582285788752, 43.961736617549775, 39.63448762893677, 42.60606742674305, 41.41580458610289, 43.47395458529073, 40.97524004597818, 45.12346421518634, 40.72387495348531, 43.090723329974765, 44.73556926173549, 43.97336252274052, 43.46287781192411, 45.671042780722345, 44.10932364002351, 49.08781943782684, 47.74481558030652, 47.4068170978177, 53.76439863635648, 52.75139162617346, 54.92561632587064, 52.227715984467544, 54.34237164835776, 53.64433096301172, 56.59769919610793, 56.08985424041749, 52.58311410104075, 48.23398613160657, 54.82385435412007, 58.07637391551849, 67.67688874275454, 65.55486686768072, 67.8759882527013, 52.18741363094699, 6.939158228135879, 0.5237121687781426, 32.507699881830526, 49.93638892327586, 53.764237819179414, 11.404015729504248, 20.555320132163263, 44.30875262906475, 28.703965717746367, 7.300975793792356, 25.599615650792277, 21.85019454648418, 19.07897137826489, 35.66936754411267, 34.89116930192517, 37.374825862146196, 28.012747995315063, 59.02579146046793, 63.644229365933334, 35.754871291498986, 0.8495464007700644, 0.12486503083979893, 0.0239630272581933, 0.39226217555903625, 0.1088600368389199, 0.20377517437502263, 0.06505842350663678, 0.023500304406268463, 0.05453376204616601, 0.04963152711429904, 0.04253804323173339, 0.15658149225336893, 0.08332608117451591, 0.021296234974156947, 0.027737394989197774, 0.06559175859776235, 0.20195640503398835, 0.07436518136772417, 0.02847253870699675, 37.23174172063028, 76.69157012816399, 52.21260701456378, 41.55320129086895, 38.07796170634609, 48.50077790598716, 34.35233762187343, 31.952951223619525, 44.070825576782234, 84.2579790853685, 35.33420885762861, 18.3569493216853, 34.14543259528376, 55.56819861935031, 63.457657906316946, 66.87546222440659, 16.958945989608765, 0.08159130571349975, 3.5150518869200065, 42.256439116693315, 72.12185198260893, 62.88530957314276, 65.75865753235357, 57.23632381808374, 62.665213615663596, 60.64695412112821, 65.7436348545936, 61.86003338906073, 67.82690371236494, 64.77331892136606, 61.97026375801333, 58.50928591143701, 59.50133569778935, 60.33534142278857, 53.94755371155278, 47.000487004556966, 47.025519570996686, 47.34167829636605, 47.96834753405663, 46.982424489913456, 47.503476065974084, 48.9792246972361, 50.71038630700881, 51.39858968796269, 53.68502947591967, 50.34244052825436, 49.70431012492026, 51.7401457601978, 47.62273180869318, 48.209110459973736, 50.43827579867456, 51.42344967011483, 52.43131053063178, 50.09123625293855, 48.0027388757275, 50.852128997925796, 52.58749538852323, 55.63867968897666, 51.95063583312496, 55.95518358292119, 47.816175260851466, 34.024564758423836, 34.13186119448754, 37.84178403116042, 35.50121161245531, 32.002602546445786, 46.717091837236964, 49.53025102615357, 53.93793998226043, 50.94712488112911, 38.679900400100216, 23.30535661789679, 18.875351336694536, 21.315744153914913, 33.837385331430745, 17.006461581876202, 22.757311290310277, 27.065528938847205, 15.947519694605182, 2.607232548536793, 2.834784931713535, 0.8165393493348553, 2.644202603447822, 9.247353442253607, 19.347414470488026, 34.669637756962935, 43.21774536563505, 49.45159965945829, 58.92416284930322, 54.45945047563123, 54.17343124266594, 44.96984850975775, 32.44630106033818, 50.39065822478264, 50.84297418594361, 47.824184740743334, 51.73738048922632, 50.39893050347605, 51.90416751369354, 46.546547182144664, 46.77746495892925, 44.455684615719704, 47.01301113251717, 46.39164493929955, 45.4526295200471, 46.52257757802164, 46.164296519371774, 43.67437201161539, 46.46296147377261, 44.32521873904813, 44.83976702536307, 43.4334796474826, 44.83771562576295, 46.77746888129942, 46.60087593140141, 47.4318535866276, 46.66627753165461, 47.17815468388219, 49.4658221737031, 47.074706092957534, 49.526556153451246, 57.13871563634565, 56.05555311326058, 56.30152886913669, 56.14829363361482, 58.31894505408503, 56.41439507084509, 60.757282549335116, 60.73927102550384, 59.56439956541985, 52.81878186810402, 59.00022545168477, 61.70685306672127, 70.8842892800608, 66.43801596856886, 69.95880603790283, 53.09595223396055, 7.692892647558644, 1.0687299168878988, 40.4714233644547, 57.67134604915496, 59.591577668343824, 13.092892227634309, 21.161039990763513, 46.56697096363191, 39.04624192945419, 8.938962971010517, 26.032025583328743, 22.140112615400746, 23.43076067586099, 34.37893129164173, 43.899837693860455, 38.38120406673801, 35.855888012916814, 68.96375563836867, 65.72215987790015, 58.466885089874275, 0.5284992377123525, 0.1178005280634088, 0.044308648624968146, 0.13958633727123662, 0.1688099409183187, 0.08995289493712688, 0.020792909462245244, 0.11289968741156402, 0.28021859906373486, 0.12739746470845517, 0.24201739489311175, 0.895431635360564, 0.37627505438943065, 0.14550197629197953, 0.09661951462828344, 0.3315787882574143, 0.39150672093514477, 0.23611661797809988, 0.17760403274047762, 44.705186582380726, 89.80266509517547, 59.51380099019697, 45.405435562133796, 47.05433330228252, 57.63982588245023, 42.11351579235446, 47.06113469216132, 64.65192156453287, 92.94420903728854, 37.93367339718727, 21.535451796747026, 45.77131032943726, 65.26772191447597, 69.99850042404668, 72.35442499960624, 13.869471511533185, 0.13831132181709813, 10.190950189867328, 48.49226244034306, 71.37125153695384, 66.26391764610045, 69.51531933199975, 65.2146561684147, 70.57955249663323, 67.14258347788166, 70.38737989241078, 63.78026500824959, 72.47091939372402, 65.60113514623335, 66.15677418247347, 58.18772608234037, 61.10184315712222, 63.15930281915973, 55.28173615855556, 49.73679127231721, 50.22871140510806, 46.98320504157774, 49.55778606476323, 46.59569448040378, 47.21437777242353, 51.60010930030577, 53.27537713512298, 56.652730049625525, 57.60781541947396, 55.36623970154793, 53.47009927995744, 56.26287783345869, 46.46389107550345, 46.14526910166587, 54.896837895916356, 54.69366304336056, 56.15387124399985, 54.18502576889531, 51.44562282869893, 54.321896876058275, 57.84173380944037, 63.07591322929629, 57.670769460739635, 62.821829934274, 51.2103472986529, 41.18613804540327, 37.293919132601836, 35.468165643753544, 33.59829333520705, 28.954807173821237, 43.46321513575893, 58.42803009094731, 58.401118709195046, 59.725212820114635, 55.23237312993696, 43.59991758100448, 51.095767021179206, 38.44168701479512, 37.880560582683934, 21.033364880469538, 24.20410498496025, 30.387082215278383, 22.994120467093683, 12.975834973396795, 9.240659917554549, 6.951274429598163, 11.845306888703378, 15.65090810098956, 23.868120639554917, 37.54655115066036, 46.69033342792142, 44.7363890371015, 58.432325086286, 52.91414253173336, 58.41032451198947, 48.09343191885179, 40.89671419512841, 54.78937672030542, 52.14919797835812, 48.873854144927, 55.71606805247646, 51.97574292459796, 54.49785440198837, 48.43778856338994, 49.57324020324215, 46.867130341068396, 47.56111529565627, 45.908836472419004, 50.420319188025694, 50.16102698541457, 48.44165602037984, 46.59454914831346, 48.44202472317604, 44.10285565160936, 46.300610649970274, 43.85693480891567, 46.739539561733125, 47.84054102436189, 47.84029783741121, 53.965584847234915, 52.38386161865727, 51.9889142436366, 54.82952217901907, 51.08829490600094, 51.99719044470018, 59.66489853397493, 59.37656510260798, 60.0987244421436, 57.24431760849492, 59.1482674690985, 55.61450219923451, 65.69358148882466, 64.62994452445739, 61.43184000445951, 54.79057696557815, 61.831125520890765, 64.30410538950275, 74.85064491148918, 71.48131324398902, 74.52184830942463, 65.23468379051455, 15.368445477178021, 1.6359629890611096, 40.46393163742558, 60.82542196396859, 67.07864099933256, 19.66362222548454, 31.101751788969967, 53.70238204156199, 36.05826270195746, 12.294518293872958, 38.204815080088956, 32.24799190798114, 27.971888665230047, 52.80010746371362, 50.690484200754476, 52.03441373763546, 36.55440722742389, 72.3511145191808, 75.84921759943809, 65.1215430228941, 1.2550812334783616, 0.24759019424598067, 0.24234528052470378, 0.5004469365362199, 0.4474798013125697, 0.2499941781523728, 0.22816485515044582], [0.03598585409382659, 0.1890707601823153, 0.0856348786563162, 0.1297693954960954, 0.236812271778622, 0.35246776897580395, 0.1305424854640038, 0.028537424438963496, 0.10851564967343885, 0.07899759247178033, 0.37438054959620204, 0.10652356826129461, 36.70326509783345, 67.11741755085608, 45.08077313823085, 34.76663797132431, 29.07243121054865, 38.75035009076519, 29.51406067417514, 32.186965711655155, 40.05703280048986, 33.40059018904163, 23.56373686944285, 16.99837757695106, 13.633318351161096, 36.83393101538382, 59.465728421365064, 65.57138396847633, 45.69178427419355, 3.3354080684723395, 0.3100859157500729, 28.676403222545503, 68.47234541370024, 61.4367429671749, 62.06442809874012, 62.47621813128072, 72.62264451672955, 65.62598728364514, 64.9675311580781, 63.20223316069573, 65.61775815102362, 63.794828768699404, 65.84538505923364, 61.88710558799006, 55.33033432499055, 58.783851823499134, 51.71909439948298, 46.66489685735395, 46.45248482304235, 44.24195074266003, 44.826172090345814, 44.57991784618747, 46.499623867773245, 47.668560781786525, 47.894975677613296, 48.001468027791674, 49.11659786778112, 51.14186271544426, 47.77438240666544, 47.58709315330752, 47.11086642357611, 46.61430612687142, 49.10896101305562, 48.97618093798238, 44.58342836749169, 46.04512706879647, 47.94262463046659, 52.48635315125989, 52.051680011133996, 51.139913297468624, 50.21149220005159, 53.394530896217596, 41.70659342119771, 29.552803885552194, 22.730348917745776, 13.38570010277533, 23.252816469438617, 14.829348056547104, 23.284797514638594, 54.456481241410785, 43.5240432523912, 37.474826689689394, 21.482795938368767, 25.286167283211988, 33.01523693146245, 28.053497499035252, 29.115461572524044, 19.46779004989132, 16.308253215205287, 21.321737535538215, 7.131934877364867, 1.830150343237385, 3.402093754660699, 3.0535083047805296, 7.478568948084309, 8.728683725480112, 10.374832864730589, 21.396344938585838, 36.82742380326794, 29.58543996657095, 49.40786915440714, 46.21815850657802, 43.23240326296899, 39.31786998625725, 27.8427642391574, 41.96593661462107, 46.04936322858257, 48.23259761256557, 47.813096200266195, 51.171558980018865, 49.3408868389745, 48.643316838049124, 46.53068511716781, 44.93228004824731, 46.6092933377912, 45.118247462857155, 45.01614816727177, 42.75525477624709, 40.73225313617338, 42.276831519219186, 43.690963637444284, 43.97293890676191, 44.14683718835154, 44.13647428635628, 43.48182678222657, 43.73550607312111, 43.12570694954165, 44.190736355320105, 44.712870505548295, 43.626456337590376, 47.57001907594743, 46.79158549154959, 51.43210241871496, 54.67265875108781, 53.76988210985738, 52.91044765903104, 53.509558323890936, 57.13952364460115, 58.04255523989278, 55.20818387308429, 55.30492913338446, 55.98813933710898, 50.58086964391893, 56.99124628497709, 59.84237401716171, 65.22694495416457, 68.49277311755766, 62.80929011683311, 31.723910300962388, 3.7496093780763693, 7.6375313343540325, 49.71206465075093, 39.39852960648076, 39.71746929230229, 12.837107604549779, 12.602922493411649, 55.38745187943982, 59.80594304300124, 14.88272955340724, 11.663974735044665, 21.7831612402393, 20.12969393883982, 42.29697289005403, 29.59856813953769, 44.545020518764375, 32.45217480967122, 39.260132697320756, 51.635394942375925, 66.9320620259931, 6.561417800764884, 0.5345296367041527, 0.07239501007021436, 0.22097277575202529, 0.3190874182168515, 0.059713772798497836, 0.11342108685282931, 0.05335064649942422, 0.1065770258766509, 0.11581070661064118, 0.05368238172283577, 0.13445866564589162, 0.2027592651786343, 0.03745246047694837, 0.04179358963043459, 0.15205351425515068, 0.19224679217703883, 0.17897470193284173, 0.2030082897193009, 52.761150483162176, 74.2987988072057, 51.75850245260423, 34.02489423751831, 30.921777755983417, 46.11815375666465, 32.76609974522745, 28.44279862219288, 36.52787631557834, 40.465316234096406, 29.055684651097945, 16.212174757834404, 17.38058901602222, 38.92055742202267, 61.745551170841345, 68.21798755276588, 52.86844691922588, 6.320119471319261, 0.15598778943381003, 27.510317871647498, 70.88644658365558, 64.7341775894165, 63.95267278917375, 66.61975506813296, 71.55086471188453, 66.23267204530778, 65.61069396234328, 64.35952848003757, 65.87746220250284, 63.76770165658767, 66.55947608332481, 63.07810583422261, 59.036742717989036, 59.82462136976181, 52.8877410581035, 48.359866757546705, 49.14144216045257, 48.9134543941867, 49.201030808110396, 47.846201004520545, 46.67483222100043, 50.616853467879764, 49.5672115202873, 50.53556626842868, 51.173167151789514, 50.55214612714706, 49.2108485006517, 48.605854280533336, 46.88045463254375, 49.35925137612128, 53.33501285122287, 53.7921376382151, 48.15626044427195, 50.40368049375473, 49.940938872675744, 54.09967891631588, 56.155487260510846, 54.952264908821356, 56.632137606220866, 55.71082776592624, 41.526693913244436, 33.55417843787901, 36.804450481168686, 36.31547212600708, 36.06069064909412, 34.57457127109651, 39.18046543675084, 57.2207441637593, 50.147616401795425, 47.91511312607796, 33.831929314521055, 26.40930856427839, 34.68852789171281, 26.154836954609042, 35.8029987735133, 23.11237012186358, 21.9722096766195, 26.730558526131418, 11.045313996653404, 1.1426251646011107, 6.190525341418482, 2.2568854641529823, 8.505000760478358, 8.68962574389673, 15.28365069820035, 27.92878377822138, 40.34402478125788, 44.897857327615064, 55.27752745536066, 50.79356016651277, 50.99938654130506, 46.51339530944825, 33.02652551281837, 46.08630018849527, 52.39454615500666, 47.97229736082016, 50.758356894216234, 51.89600898373512, 51.88655214924967, 49.44320578728953, 50.3444330923019, 47.33607715175998, 48.06190782977689, 45.273047724077784, 48.14673692949357, 45.11528607337706, 46.0057778512278, 44.76263361592447, 45.07279895967053, 46.09752208955827, 45.60262487780663, 44.60045145403954, 44.63683928212812, 44.39807284262873, 46.57454113806448, 47.91070045963411, 47.177432967770486, 47.43257922510947, 47.74574518203736, 46.61039552380962, 51.125243633024155, 56.35314726060437, 58.69461397970877, 56.79541410938386, 56.848005248654275, 58.03718159275671, 57.39977290553432, 58.701948811931, 61.152798668030776, 60.57694765829272, 54.57635279624693, 57.401455602338245, 61.12289451783704, 67.78513831477012, 68.95023130601453, 64.82647095957111, 38.17613863175915, 3.324878465744757, 11.082041109761885, 56.88740153466502, 39.64513686395461, 46.36211341427219, 15.201398595686882, 14.940086372437017, 53.658584856217914, 66.58865067266649, 20.08229405649247, 16.320898936640834, 24.94835903567653, 23.04907875676309, 40.88646504186815, 33.76417429216447, 48.01044633311611, 29.640162914030014, 57.80707966896796, 58.25001724304692, 80.23958929123418, 17.44707711281315, 0.5704670663802855, 0.33878562250925653, 0.2554898630947836, 0.09039644452352678, 0.1247087105988495, 0.1070996433977158, 0.19721350872949248, 0.2953973442556397, 0.19441751763224605, 0.2844615310670868, 0.523054804052076, 0.4931717059544979, 0.12032056662945018, 0.16612593655384358, 0.2719388433521794, 0.26561662614826237, 0.6523669523096854, 0.44153063828426026, 60.33686330241542, 86.6355472995389, 60.36353541958717, 44.37216951001076, 38.80931115919544, 51.76554310706354, 40.86227970738565, 43.676819570602916, 49.251805889991026, 39.00205250709288, 29.8293839346978, 26.222148749136156, 27.779327746360536, 50.00363011513987, 69.10176815525179, 74.97281105287614, 52.60955087600216, 4.0279596419103685, 0.5301641612764328, 32.257605637273485, 70.23744337020382, 67.74396127270114, 65.13065468880438, 72.2500507293209, 79.56412576859998, 73.6008914824455, 70.60693064043599, 67.43301929966097, 71.50946801708591, 67.23345695003387, 68.78654295398344, 65.61817392226189, 58.47147818534606, 64.280324059148, 53.739930891221576, 49.997758326991914, 50.69523419103315, 50.708276071856105, 49.134836889082386, 49.6387908535619, 45.844639039808705, 52.59376333605859, 50.05719400221302, 54.481568721032914, 54.33809626486994, 58.39164618522891, 54.05204957531345, 53.30768569823235, 47.831417591341086, 50.60609048412692, 57.249475525271514, 57.07931134008593, 51.04377600454515, 54.72164130979969, 52.53763814126292, 59.31040256254135, 57.925197924337084, 61.35287484815044, 59.96621893298242, 63.966848234976496, 45.021706165805945, 39.08870158656951, 35.137949143686605, 36.03529722459855, 38.23533896476992, 31.097025332912324, 42.14783653136223, 60.20276531096428, 56.737876861326164, 59.007897607741825, 44.40119112691572, 43.92947904525265, 52.17790188327913, 42.09813225653864, 43.150645379097234, 28.522881654001054, 24.242483415911277, 31.57155171517403, 14.01486789026568, 7.733688729424631, 11.819795793102635, 9.969481402827848, 14.495352352819136, 12.522744344126794, 16.88489556312561, 27.489066470053892, 46.467868358858176, 46.531018518632465, 55.060518403207105, 52.41768029428298, 51.67259470109017, 50.74029830194289, 40.694496400894664, 47.70679996859643, 54.936277327998994, 51.0148799034857, 55.54981839272284, 55.584272492316465, 55.48495807955342, 51.13753241877402, 51.26669999091856, 50.51697815618208, 49.95432592207386, 45.92902098932574, 51.31550996534286, 50.14493742296773, 49.73381419335642, 47.55781265997118, 47.81551238029234, 48.68265036613711, 47.767773212925086, 45.665159225463874, 48.10848205320297, 44.94104654558244, 48.002197588643725, 51.954483678264005, 54.12941048222204, 51.0057839270561, 54.82993402788716, 49.36391899662633, 54.7583076261705, 56.8006936196358, 60.37771478776009, 57.75325298309327, 58.52481457494921, 58.39927519521406, 60.28354260229296, 61.57610870176747, 68.40164861371441, 62.52158426469373, 56.42965701318557, 62.18281307528096, 64.9360502150751, 72.22988190189486, 74.4162816386069, 68.49471076842278, 50.30041233185799, 3.9681153047469357, 10.430627599839243, 60.39534976405483, 47.54367251549998, 52.24756317753946, 21.97879337495373, 21.341072859302646, 63.465275149191584, 69.90321820782077, 21.026991028939527, 18.00157081696295, 32.36845574071331, 30.876205698136364, 61.2523562677445, 43.1134299309023, 61.05370783036756, 38.06966981580181, 58.188145775948804, 63.38353687717069, 92.45966296042167, 18.09044388032729, 0.9532882501521419, 0.6023958337403114, 0.5881721550418485, 0.49703983710177485, 0.48343187858981473, 0.17525266375272505], [0.049500158357043425, 0.2282659327911754, 0.02912435121083212, 0.043434971312601725, 0.33067872687693567, 0.7196246303858296, 0.13763865065430442, 0.1337698147061371, 0.19905428011571208, 0.1811873323975071, 0.5632633884106913, 0.24503225731032513, 53.13829814234088, 62.177851277012984, 39.48153480406731, 30.16393465380515, 41.35627085162748, 34.57784252782022, 25.473032920591294, 20.884901208262292, 15.010966543228397, 8.677740962274614, 19.61131545805162, 19.089187191378688, 11.698361173752817, 28.34493744757868, 55.38913849861392, 54.74604237464167, 59.162168348989184, 33.050451970869496, 0.08299513119122676, 11.653831485779056, 64.27355012586041, 61.49570011323499, 66.25611997419789, 63.23782867000949, 69.95548771273705, 66.02255851991715, 68.65449243976225, 64.27791964623236, 68.06798042789583, 64.88056828898769, 64.9059146450412, 66.43057130998181, 59.0485215956165, 59.689432959402765, 50.43504768802274, 47.812507844740345, 49.98975669184039, 44.6349290878542, 44.89112654039937, 47.64882341507943, 48.58258285830098, 49.694515966599994, 50.22938213040752, 48.336156029855054, 50.30297756195069, 47.56219786982383, 47.06876370214647, 46.912116004574685, 48.02409225894559, 48.22607863333918, 48.800411685820556, 49.58976907114829, 48.47325855685819, 49.42373514175416, 51.42031961871732, 55.93748977107387, 57.6011081664793, 52.68614692072715, 53.12638198175738, 49.65045206008419, 35.122702890826815, 25.26779882369503, 12.571583736327387, 12.29714628188841, 21.610304347930416, 16.796416697963593, 32.52536623708664, 48.2584499543713, 30.523153158926196, 19.39214517993312, 7.32111422284957, 19.490200511870846, 33.300153978409305, 31.637082753642915, 23.18187059894685, 22.445933934180967, 17.672658504978305, 15.847703218460085, 4.525032053070684, 3.3555516456404044, 3.550346599471185, 5.822083382837235, 6.7474509150751185, 9.385961178810367, 5.918273627758027, 10.076618982899575, 26.905325612714215, 32.02863335609436, 43.731681762203095, 41.5785123455909, 33.981100974544404, 31.705983108089818, 26.461701623855102, 37.657848404299834, 45.308333366147934, 45.03953333823912, 46.309808608024355, 50.57547246256183, 51.448662665582475, 48.182971785145426, 47.813810071637555, 46.900952939064275, 48.06861116040138, 47.17895092502717, 45.6169258394549, 42.01342867266747, 40.437024178043494, 43.67935342173423, 45.02180422506025, 45.571453802047245, 45.44118012151411, 46.296904010157434, 45.65177609843593, 46.031402695563536, 42.25750207901001, 45.28093561049431, 45.40128961686165, 44.00809511061638, 45.348584728856245, 47.71084393224409, 54.32090451640468, 58.141363666903594, 57.06558304448282, 55.2064815644295, 57.384240319651944, 57.4545644944714, 56.864898896986446, 58.041256935365745, 56.56941498479536, 54.3290905029543, 51.833317741270996, 52.305014133453376, 61.241001006095644, 69.48599569259152, 66.83188469179215, 65.72070075619605, 20.97415081916317, 1.266983298044051, 28.969647461368194, 54.892001613493896, 45.58328367048695, 53.26293145456622, 12.589635464452929, 11.091392040252687, 49.90662205603815, 66.77978777116346, 43.659545452364036, 13.211858695553197, 18.53737834961184, 12.82679275158913, 35.41123244070238, 25.12444599982231, 40.2429021558454, 31.251770680950536, 35.548621300728094, 54.56647626815304, 61.13373594899332, 36.1044172317751, 0.46303181518470093, 0.11694466995616114, 0.428919390805306, 0.33125130099154293, 0.12331112107682614, 0.039918455370371385, 0.015751452414288877, 0.1523105214319883, 0.06279379865455051, 0.04551116534839234, 0.1485767774283886, 0.11239360972878434, 0.05534379660422283, 0.0653805251744005, 0.12773207659202238, 0.1779616732270487, 0.12386451234980939, 1.2550982712737977, 68.38260158415764, 67.61744914516326, 52.11395155998969, 35.25725195484777, 39.82340074354603, 44.767693473446755, 31.39679051214649, 24.001163513429706, 24.53680826771644, 17.325183576153172, 25.290383831147228, 25.96845376876093, 11.727780911230273, 34.381021914943574, 60.004991562135764, 61.95594710688438, 64.2003273194836, 41.94122176016531, 0.6113553239453224, 8.934480682496103, 65.42695837636148, 64.03157910993023, 66.22201888791977, 64.44098434140606, 69.94766650661346, 67.39530178808397, 68.15674366489534, 66.03055231032833, 67.08831356417748, 65.02165202171572, 64.82299966196861, 65.71169107191025, 57.69543332438315, 58.95398462972334, 53.207014145389685, 49.58119476995161, 50.840255983414195, 49.51707578474476, 50.00451657079881, 50.17464937702302, 49.51292983947262, 51.75691389268445, 50.351461979650686, 52.060987795552904, 50.67187647665701, 50.83418807675762, 49.72457308923045, 50.0223280537513, 50.2584586604949, 48.667917943769886, 51.859903566298954, 53.40524288915819, 54.001223502620576, 54.16384104759463, 56.12876415252686, 56.024166307141705, 59.35326622378442, 58.02555960993613, 55.196153963765795, 52.946780573937204, 34.782311762532885, 32.11143262924687, 30.96763614685305, 29.42828824443202, 32.6952499728049, 42.0862788538779, 49.36235397092758, 51.83858156204224, 38.78967185174265, 36.59931444352673, 23.329836130142215, 33.224275727425855, 47.5425781742219, 36.94627946422946, 35.76908596100346, 28.856208593614642, 23.5565746215082, 24.72076350642789, 9.297988299400577, 5.437367510411048, 5.956007319111978, 4.570007910651546, 8.868401492795638, 11.974677443504335, 5.222955557607836, 16.037391981770917, 36.85632774906774, 43.82254738961497, 46.30496840323172, 44.37091435155561, 45.32240290795603, 46.13030525945848, 33.44195550487888, 38.9985929766009, 53.98923281700381, 47.749451821850194, 50.67022515881447, 48.99822858072097, 51.661353188176314, 50.13486477636522, 51.486066387545684, 49.484531879425056, 49.84631169226862, 45.91279806629304, 49.55176914891889, 44.757565913661836, 45.85238572089903, 44.90995391722649, 45.46757767277379, 47.25811219984486, 46.74683909262381, 45.71134121187272, 47.687529363939845, 48.276288893914995, 46.66707377279959, 47.14303378135928, 48.749946471183534, 46.635922308891054, 50.39804404781711, 46.410966534768384, 55.39065253350043, 59.86206431542674, 59.80810426896619, 58.25442206475043, 59.01460486073648, 60.500473207043065, 57.13698194872949, 59.978425348958666, 62.37630751825149, 58.52492047894386, 56.01051645894205, 55.3612151453572, 64.54243644591301, 68.29626237192463, 67.63793960694345, 68.19444548699164, 19.93392255998427, 1.5750406129706291, 37.3671184047576, 61.65572104915496, 47.6959232361086, 56.075867068383005, 13.440836860287575, 11.029153831543463, 52.05844217731107, 68.57202068451913, 43.733160495758064, 17.87338383736149, 22.457610830183953, 15.055789428372538, 40.15027930659633, 24.808002902615456, 49.23682635830295, 31.179055821511056, 38.480918561258626, 65.60155876221197, 70.60826424629458, 54.41434321864959, 0.293019529912741, 0.2042924369414968, 0.19023495335732737, 0.13883822176965976, 0.13573771072251184, 0.04647015421200664, 0.20388644098514513, 0.3276666223762497, 0.16708775994277772, 0.18379186280071738, 0.5652034294701392, 0.5937531362137487, 0.11870671814728169, 0.21774832700048724, 0.47743368593435137, 0.6041842506777856, 1.0486678514749774, 1.3330820995953776, 76.08357921723398, 81.6677870288972, 54.514426415966405, 42.19965888607887, 56.068555770381806, 46.805556974103375, 37.204179225429414, 29.99911273679426, 25.144618749618534, 13.648163541670769, 27.60594133407839, 26.61481330471654, 23.966807473090388, 40.29123360110868, 68.80711186316707, 68.3447350225141, 69.16436918320196, 38.21715877902123, 0.47023484964043866, 13.069361928970585, 65.8783329686811, 66.94713177219515, 70.93509181853264, 70.14941753879671, 78.03145177902715, 73.5736466992286, 73.90638136094617, 68.071330132023, 73.1405621190225, 68.39102683528778, 69.74451911064887, 68.25872528937556, 59.04613287218156, 62.458371346996685, 56.000290839902824, 52.030236413401944, 52.601768893580285, 51.87854659172797, 50.715406940829375, 51.997178677589666, 51.18932339452928, 54.425847530365, 51.27795327094294, 57.11828401011806, 57.310770403954294, 56.87172382108627, 52.929541757029874, 54.6333997480331, 51.95094570036858, 50.55022024339246, 53.64291498737951, 56.90807242547312, 57.55257275796706, 58.991709986040675, 60.188546719089636, 62.22577871814851, 64.34914596619146, 64.98530733969905, 58.827927497125444, 60.375922264591345, 39.90273460265129, 39.210997166172156, 32.89301391570799, 29.480596973050027, 37.399164169065415, 38.10687349688622, 57.79978013807728, 55.40334532337805, 44.326517043575166, 36.70152356547695, 32.30385234279017, 47.026037323859434, 57.26356467893047, 52.73894202324652, 44.76275128702964, 33.963646427277595, 26.208663640483735, 31.545744480625277, 15.255626343911695, 12.418154343481987, 9.086334263124774, 8.32521107888991, 7.926824275524386, 10.544126283737922, 5.677728393385488, 20.340582132339478, 43.894330686138524, 50.54611352182204, 45.97172383339175, 47.0742707098684, 46.1022210890247, 45.79483278336064, 40.61019682115124, 45.20166058694163, 53.3235752198004, 49.77190040772962, 53.889157464427335, 55.196793310103885, 57.05940138909125, 52.2736979299976, 53.76002127124418, 52.249857764090265, 51.387014773584184, 46.840281717238895, 51.86724232089136, 47.54897555997295, 49.61979481481737, 48.049936756010986, 49.73314346805696, 49.10103390293737, 49.51069801084457, 48.86962975225141, 49.79599945006832, 50.88287645770658, 47.40396553470243, 51.43382041685043, 55.497741083945, 51.199513712236964, 54.61171688572053, 47.713577824254195, 57.487477102587306, 62.91490385609289, 62.22717508192986, 62.17422308460359, 61.65334017046037, 60.17979198886503, 58.20957760657034, 60.49029857881608, 67.79242607855028, 62.23288997527092, 58.609102387582105, 56.6148046524294, 66.56129606308477, 73.51991022786787, 71.90358777200022, 73.67702468749016, 31.350863479798843, 2.24964574940743, 35.58389517568773, 66.32585971586167, 53.63450150335989, 64.96919816540134, 23.316266690531087, 18.939537002194314, 56.32724785035657, 70.73158356451219, 48.009646169600956, 19.59674385286147, 25.989132504309378, 21.815279568395308, 47.25496253659649, 35.16377010653096, 56.531014980808386, 39.07584797951483, 41.58390952694801, 70.52015212274367, 79.39387921364077, 59.94301026867282, 0.5551416919596734, 0.37805093812846374, 0.49875210489957567, 0.5395111693970619, 0.26136658484897307, 0.16641921033301663], [0.061481758171031554, 0.3505124980884214, 0.08719628075918845, 0.2033469618688668, 0.43840530598836563, 0.9095133120013822, 0.16559926642765924, 0.04993299803426189, 0.2023448728986325, 0.23859923314904016, 1.0179250495087717, 2.5298400175186897, 59.53182428113876, 56.870213708569935, 26.976828459770452, 23.46513632805117, 40.06549335295155, 26.511531414524203, 22.198428453937655, 11.870153142559914, 10.547882933770458, 12.112513453729692, 26.49130963510083, 9.54531531180105, 8.26756400446738, 19.12966016800173, 53.75871904434697, 59.93568720356111, 53.7432570611277, 57.49768310977567, 16.966402415306337, 0.8834840345286554, 42.39756991786342, 66.89434451441612, 70.42137115232407, 63.30953744149978, 69.11954433687272, 63.63727108124764, 65.7990461780179, 65.52519021495696, 65.25871223019016, 64.52275007001816, 64.96875885994204, 65.03467429068782, 62.19665904198924, 56.723081681036184, 49.80730372090494, 47.57938961828909, 50.0519968617347, 44.302500371010076, 49.29617574138027, 50.17358249233615, 51.31470587945754, 50.6804782344449, 51.16874664060531, 45.984408778529016, 50.255442357832386, 46.60519053859096, 47.6878470759238, 45.444337629502826, 49.629314407225586, 49.86995573966734, 51.7441975685858, 50.77326974561138, 48.66084983271938, 50.59174245403659, 57.83995305338214, 57.661285169662975, 55.58413520936043, 54.64395876853697, 53.57195146622197, 46.664002556954664, 31.5581528986654, 20.05232518719089, 7.716793610203651, 15.093975663185121, 22.819720122121996, 16.65957304739183, 30.358188075404016, 52.42596041771674, 24.57660267429967, 0.6297671746823096, 2.17611895934228, 1.0847868746326816, 6.072553684634547, 10.426762104034424, 2.183901922356698, 14.477310430619026, 21.916525748468217, 11.741947531700136, 7.237601078325703, 2.122175092658689, 3.471944303281846, 1.6116939364902436, 0.6337996163675863, 1.6230525076389315, 4.903102940128696, 8.1353134493674, 26.632020742662494, 34.47669636818671, 42.77020685134396, 37.63691079232001, 27.25967645645142, 23.350661954572125, 22.418769559552594, 27.785423109608313, 43.451067555335264, 48.28759708712178, 49.6449254405114, 49.99486361780475, 51.26521733499343, 52.28523754304456, 47.77818318336241, 46.98810015955279, 47.7966183231723, 45.47028803056287, 45.559329755844615, 43.0049999298588, 43.271497526476466, 42.97948491188788, 45.07541910294564, 46.00436579796576, 45.82872206164945, 46.835598407253144, 45.032614277255156, 44.38454458790441, 45.67226656021611, 44.57736830557547, 41.54893375212147, 43.170935799998624, 45.86183471064414, 52.105714582627826, 59.777686288279874, 59.219380040322584, 60.5060939635, 57.187878624085464, 57.50994443893433, 60.69765860034574, 60.1110799081864, 57.90281295776368, 58.35743135021579, 55.1341099123801, 55.387338130704826, 57.57174138099917, 63.33158508423836, 65.17674646069928, 68.95396540241858, 55.29514281980453, 6.451778729115763, 3.023440150483962, 54.743018227238814, 44.376135026254964, 58.89662781069356, 45.34308948824483, 2.774201718068892, 9.816432479889164, 41.12890281984883, 67.37155575906077, 64.29855915807909, 27.41286658471631, 21.571141442944928, 13.680585853515135, 28.654314394920107, 34.986122039056596, 38.81818356052522, 68.60339964589765, 39.1215318249118, 45.90906004751883, 58.57202029997303, 60.330873843162294, 2.076694965362549, 0.2203521526028072, 0.5347921290705281, 0.18106089724648386, 0.1882850144418978, 0.11362740199171728, 0.10317787843485994, 0.06921736929084986, 0.0012179226318802384, 0.049609176499108155, 0.20141925482499987, 0.3131650376223749, 0.04044265869343954, 0.05743679094819292, 0.06033180274009224, 0.3392562456429005, 0.3754783842352129, 5.753183518686603, 74.20151618219192, 64.80850650418189, 37.14766571598668, 24.895512942344915, 44.396366611603774, 35.16247180200393, 31.30529142195179, 18.120585333916452, 17.093667637917303, 18.98870195111921, 28.949904211105842, 18.265907187615674, 15.521588537000842, 19.91837428462121, 60.16522430604505, 64.7355111952751, 61.404430481695364, 66.32047822398525, 24.600178080220378, 1.297986815052648, 33.57662616237518, 68.48936065550774, 71.41276590285763, 69.81591409252536, 74.68894912350562, 67.74625193688178, 65.90185934497465, 61.813835713171194, 65.63329073690599, 66.6492042233867, 68.75437951857045, 62.37157713982367, 59.15652405831122, 55.27550351235175, 51.95074565948979, 49.28107461621685, 51.899142957502804, 47.7159430134681, 51.246382113425966, 50.41621246645528, 51.29308577506773, 50.66059574004143, 51.192116122091974, 48.14126914547336, 53.516869621892134, 50.358859569795676, 51.08312522211383, 49.29212001062209, 51.977731566275324, 48.357050495762984, 54.068794173579064, 52.817966015108176, 56.29303693771363, 52.402445808533706, 58.261541166613185, 56.39406934861214, 57.897525602771395, 56.73424866891677, 58.7465226265692, 51.68174166833201, 30.80221018483562, 26.515010556867047, 18.262881079027732, 18.108363228459513, 25.06996427812884, 33.60842089499197, 44.87812780564831, 53.86543889199534, 32.73272429743121, 11.912908938623245, 5.661489780872099, 11.565178075144368, 21.03554571828535, 14.938342878895423, 19.181776700481294, 32.39451596813817, 28.432390612940637, 14.521484163499649, 10.071043333699627, 4.123534810158515, 5.481579486400851, 2.8577665888494064, 1.9184544177785998, 1.5585480269885834, 3.3588187348458076, 12.119215803761637, 35.89605308348133, 42.08593760767291, 44.52993116071148, 38.47653727377615, 32.79359163776521, 36.97161405317245, 31.391106997766805, 30.94559438766972, 50.07427984668363, 50.318306184584095, 52.34919963344451, 52.445113351268155, 50.216650116828184, 51.91400874045588, 54.26920375516338, 51.010820250357355, 50.157869477425855, 45.07686253516905, 45.757366303474676, 46.797461202067716, 46.24397946942238, 46.338959663145005, 45.068311768193404, 45.389965734174176, 47.71695890734273, 45.15995402489939, 46.762626632567375, 45.868577264970355, 48.13098469088155, 45.62320555410078, 47.85754842142905, 46.152121482356904, 48.9488616297322, 51.38380627478323, 63.07076315726004, 60.75746690073321, 62.083145649202415, 58.78693480645457, 60.132288163708104, 61.11172360758628, 62.683758581838305, 60.061469770246944, 62.77639712056806, 59.86790472461332, 60.253477634922156, 58.29453222213253, 63.09474060612341, 66.60927449503254, 70.57914457013531, 53.60582113265992, 5.6077944943981795, 6.525034875639024, 65.5673203929778, 49.83193228321691, 61.99007172738353, 42.83292555039929, 3.4626902063046736, 14.623616799231499, 48.699955863337365, 67.90125616135137, 61.3046375397713, 24.73168730735779, 24.12055261673466, 13.530398299617152, 36.338053211089104, 32.19596362883045, 38.84774254214379, 63.298668553752286, 38.42492672704881, 58.55955108519524, 64.84234871402865, 72.21634188006001, 4.0124101408066295, 0.3030226770187578, 0.23634842086222865, 0.09601242059180815, 0.04108695778995752, 0.074290840195552, 0.25855556310665223, 0.352683836413968, 0.13286561645086736, 0.4889400507653914, 0.9531510897701787, 1.0370698931717104, 0.2493808788037108, 0.24739324836240661, 1.0087045378261998, 1.1839369155706898, 2.580472178036167, 7.447354235956746, 83.73404456723122, 75.63650746499339, 41.841330758986935, 31.287589765364128, 52.956884599501095, 36.799249418320194, 31.069613848963094, 16.354492075981632, 16.052545078339115, 18.84091684895177, 40.551784884545114, 14.04821195910054, 21.858798265457157, 33.2589259455281, 65.5366906043022, 71.87901804524084, 65.61532628151679, 65.64847423184302, 19.88431634441499, 1.3093933126618786, 44.25732251136534, 71.4278591832807, 76.26913086060556, 70.51739861888271, 78.88763458498063, 72.23789138178672, 71.81935095017957, 67.25463774896437, 72.05916466251497, 71.9092438297887, 73.60411567072715, 68.47486357535085, 62.7013425673208, 59.86519044445407, 53.604899375669426, 51.229680661232244, 53.68080116087391, 49.34697043511176, 53.65655699083882, 53.08461658416256, 54.439971985355506, 54.034865671588534, 55.40650283136676, 50.36134243011475, 59.6570812502215, 57.2237761559025, 54.31067497499528, 50.943092684591974, 54.14985779793032, 50.432247115719704, 56.848840713500984, 56.86843687488187, 58.320749344364295, 57.148031265504905, 64.36137591638874, 63.923027515411384, 61.127915151657604, 61.891027958162375, 62.10864890006281, 57.43042622843097, 39.253578416762814, 36.04793510129375, 19.305380390536403, 21.71497279597867, 30.08542645362116, 31.103471748290527, 50.456577577898585, 57.64070449336883, 42.23767449778896, 18.58243461578123, 7.324399207868884, 11.486266851425173, 21.363434291655018, 18.114701778657977, 24.669158843255815, 34.70465667786137, 29.998997026874175, 22.161481688099524, 20.470196854683664, 10.59880510453255, 9.345603912107407, 1.9743880293061657, 1.5537129703067964, 1.3948492561617207, 4.791317841699047, 17.782290712479625, 41.698987945433586, 45.84836921384258, 50.158779467305834, 46.31484885369578, 36.95605401069888, 39.94242506642496, 41.32612743685323, 37.0958786626016, 51.61669700376449, 52.33392984636369, 57.04391979402112, 54.31229099150627, 56.03949100740495, 53.92299967427408, 53.78568926165181, 52.850933536406494, 52.63996101194813, 47.365769493964414, 51.14891121464392, 49.24483976056499, 50.00948229143697, 48.36759774915634, 49.33009247626028, 47.79552398189422, 50.851148405382716, 49.776560183494325, 50.394627663397024, 49.247118657635106, 50.85539240990916, 50.30811586687642, 52.10932708555653, 49.58863942853866, 55.2195312899928, 53.5717200463818, 64.56159722420477, 62.195584312562026, 64.40196068056169, 61.66754307285432, 62.696345467721265, 60.1482992787515, 64.0438678956801, 61.660172939300544, 66.18212053852697, 62.04579684042162, 61.81869160744452, 62.603726540842366, 68.78965731590026, 69.88930948318975, 76.09151809446274, 64.75384827583068, 9.237961326875995, 5.553280413150788, 71.46882441736037, 55.733063682433105, 69.04592144873835, 55.15271763647757, 11.58739241861528, 17.375911589591734, 52.6374859963694, 73.4831262403919, 69.5327974134876, 33.94872573114211, 29.605053778617616, 19.302695528153453, 45.743814514529326, 51.2823502479061, 50.59113448665988, 86.96399088828795, 44.373801216002434, 61.27646707719373, 69.49467197541269, 83.71137326763522, 5.082688168171914, 0.8243142837478269, 0.7349706585368803, 0.3353497794558925, 0.3896880894899369, 0.30721256509423256], [0.11916414158599031, 0.11076977146008324, 0.24465803868107258, 0.04797935891415804, 0.9814688250903161, 0.8555801705487314, 0.2591155427357843, 0.07258891458472899, 0.4500762265055411, 0.8017645163401481, 0.7808540545163617, 7.238105102892845, 66.56685013924876, 53.130888785085375, 34.97315860563709, 39.485017868780325, 36.339484876202, 26.742847311881285, 17.263706307257376, 13.955001734918165, 20.260589315045266, 24.5983894794218, 25.847503562127393, 19.495840880178637, 5.238222402911033, 5.295722878748371, 33.92927469745759, 62.1844369365323, 50.9774055788594, 44.805006980896, 47.178766573629076, 4.107464369266264, 3.886961711029853, 39.85335980692218, 56.09623201431767, 65.94499757212978, 59.14370575258809, 58.889806808963904, 63.675894660334436, 64.42810327776017, 65.37005655227169, 60.40688545473161, 62.1778630441235, 60.98097139789213, 59.67794041479788, 55.65529484902659, 51.635340029193515, 47.30241537094117, 51.09415100466821, 47.44808827677081, 51.04789841559626, 49.929614989988266, 49.04583046513219, 50.89815801189792, 51.00932974969187, 49.65457839350547, 46.11245455280427, 46.22745452388641, 51.455507201533166, 49.96010357333768, 51.04887508576917, 48.080001723381784, 51.30908904537078, 52.0351589879682, 49.66358807779128, 52.92150874291697, 57.02605339788622, 55.16698329679428, 60.12316080831713, 61.05909324461415, 53.898496627807624, 46.51540356297647, 20.627301508380523, 13.004434935508236, 9.34345151147535, 13.86345067331868, 20.7344743897838, 22.838186640893262, 29.021552185858454, 43.15302625779183, 11.056635918155795, 5.664180526810308, 1.8683845045105105, 0.6450533866882324, 0.5776522356656291, 0.2925310109651858, 0.4697999874911001, 3.501985000987207, 6.8045576830064105, 6.128796060239115, 2.541234257721132, 1.9054407289912625, 0.5960793468740679, 0.09705256114924148, 0.18016077457897126, 0.218572131988983, 0.8521552059438922, 10.85173914509435, 37.89841128933815, 37.97998874418197, 38.831703970509196, 36.084585728183875, 21.953166569432906, 17.773616390843546, 15.236356719847649, 15.969623231118726, 34.56390242422781, 44.6635506230016, 49.26668736242479, 48.145411168375325, 50.20799344585788, 46.740214209402765, 47.9393925974446, 50.1651454740955, 47.0962752065351, 45.57111255584225, 43.781354658065304, 44.53132752449282, 42.65085697174073, 43.63226929018575, 45.03492455328665, 42.89630320764358, 45.840018487745716, 45.07612905194683, 44.3712281411694, 45.69654210921257, 45.33728045801963, 45.71518905701176, 43.05201345874418, 43.824386981225786, 46.68991373431298, 52.70539791353288, 63.33482888437087, 60.577453644044944, 59.6476165709957, 56.598197337119814, 62.70792038209977, 60.21700743705996, 62.956473135179095, 59.17191936123756, 62.52806009784822, 58.37967903383317, 57.75724595592868, 52.76486889008553, 63.7220609572626, 64.88872289657593, 71.13867851995653, 29.44518973750453, 1.9427289861825205, 18.952067013709776, 64.51568195896765, 38.63922149904313, 52.45041639574113, 22.095929076594693, 0.5430595048012272, 11.778655032957754, 26.267161869233657, 44.91104041376422, 62.3194331507529, 45.11325820799797, 23.80748079669091, 15.08133484471229, 24.270544052124027, 35.70535921281384, 26.423215327724336, 45.26612474072365, 29.673824694848832, 46.51056728055401, 59.04533663103658, 61.327677542163485, 4.650078685052933, 0.1803965611203063, 0.7712229197063755, 0.7005965385225512, 0.1210645605779944, 0.03859604588679729, 0.17520626946803064, 0.10879171711783256, 0.04421911592925749, 0.10986734286791856, 0.40580860188891815, 0.06971925647268373, 0.06628360494130081, 0.14793761495140292, 0.09402812263297458, 0.4732300389197565, 0.41730611074355345, 11.049464844888258, 77.28847642098704, 65.93891789836269, 40.03492239982852, 38.95856126662224, 45.705434122393214, 33.43007464562693, 26.12351486759801, 19.423061301631314, 21.599586471434563, 26.414150730256114, 31.585062319232573, 18.4082107774673, 10.833541308679889, 8.554039212965197, 35.10060817964616, 66.87914140762823, 55.507327356646144, 47.150137193741344, 55.32003418091805, 6.10540843779041, 1.442346952615246, 26.388474895108132, 48.81671697862687, 66.58428899703488, 60.911302258891446, 59.44128028808102, 64.85521408819383, 67.84644496056342, 68.19682244331607, 64.29134199696203, 63.31386773817001, 59.11607265472413, 56.851586372621604, 55.47993744573286, 53.09641507364089, 50.509745305584325, 51.983309176660356, 50.024179412472634, 51.200690423288655, 51.41267884162165, 49.33409329383604, 50.73897254082465, 52.76351175000591, 52.220012449449115, 53.485118035347234, 53.143401145935066, 56.70410133177235, 52.083270780501834, 49.98378292206795, 48.48305271517847, 52.03244863017913, 54.741484580501435, 55.30897309703212, 56.4907753852106, 56.996670922925404, 57.45777299327236, 62.54580882287795, 62.103875375563106, 57.75727341251989, 46.627755934192294, 25.648335410702614, 23.842380085299094, 11.371929760902159, 17.036051942456155, 22.73373588438957, 29.306520223617557, 35.26560268094463, 53.46590234387306, 27.81817686173224, 2.5250856145735714, 1.081311286937806, 1.2454967993882395, 0.7977326875252109, 1.0238791461433134, 0.8341571652600843, 2.743651847685537, 10.868945602447758, 12.991532298826403, 2.9233378316125567, 1.7789478455820393, 0.7144696553868632, 0.0618682035635556, 0.27151439999861104, 0.525596316062635, 2.1439618977808186, 17.886690478171072, 44.39905735754198, 37.869805443671446, 41.77590954688288, 33.88513626590852, 24.484660356275498, 24.613351360444103, 25.315798828678748, 22.52181218516442, 39.74873842731599, 46.084170341491706, 47.922683300510535, 51.931894748441636, 52.72125997850972, 54.15587863614483, 52.44641950053554, 50.45289447230678, 48.71635137065765, 47.52640624200144, 45.83954780332504, 46.86556923773981, 48.06607338689989, 45.77212226006293, 45.54959051070675, 46.04221274775844, 47.14961159613825, 46.764191658266135, 46.34207402506183, 46.23943344239266, 46.54826910265031, 45.79396593955256, 46.44433413782428, 46.80115999714021, 49.36402882299116, 51.427054328303186, 64.76987508035475, 61.36223362338159, 61.749830476699344, 58.9111876487732, 63.205104335661865, 61.64125142558929, 63.32713319409279, 60.246366377799745, 65.46755883001512, 61.624659799760394, 60.38131944594845, 55.445926573968705, 68.25804279696557, 66.384640355264, 71.97914046625938, 23.27187918847607, 1.2345086470726998, 28.834894434098278, 72.46917001662716, 44.262264697782456, 54.37025577791276, 21.85567213642982, 1.501074272298044, 20.259549886949603, 29.189139373840828, 45.39763789023123, 59.260290361219845, 29.12127256393433, 23.35582575490398, 19.8442748285109, 28.9853310585022, 39.85779208521689, 26.01892878932338, 46.16246869487148, 31.722349197633807, 53.30858784337198, 63.76454807096913, 72.57224206001528, 8.591648859362449, 0.3934469152121775, 0.3408883500003046, 0.02924232875117131, 0.08426383408086915, 0.03816229073450931, 0.47453287868730487, 0.29198157270589187, 0.29772493387422255, 0.2626966054160749, 1.2491436230559505, 0.7532870240749852, 0.3459579521609891, 0.2340819190947279, 1.2316665221606533, 1.5525676382164804, 1.9811819421668209, 13.291768162481247, 92.91454022930515, 71.18096951515444, 47.43112010340537, 50.3342035508925, 45.77570730640043, 35.90987551596857, 22.79967288817129, 17.48234510421753, 26.424478330919822, 35.031817651564076, 42.458609842485004, 25.47389191965903, 14.505379892164662, 17.85897893290366, 49.09009441252678, 72.34407778709166, 57.22814175390429, 52.73305846798805, 54.68035051899572, 4.764508441571267, 4.344356406119562, 41.14326261704968, 60.82124463973507, 72.6935217457433, 67.2505114155431, 65.61189812998619, 70.12372601416804, 73.42300415039062, 73.16679493073495, 68.86265262480705, 66.60061390169206, 63.26969400528939, 63.13178739240093, 62.58688388332244, 58.34795882624965, 50.31467799217471, 54.41914812211068, 50.2937521473054, 55.52682153640255, 54.635066755356334, 52.451138111852835, 54.84543131243799, 57.71426462358045, 55.44880951604536, 55.49877266730032, 57.417843264918176, 60.82605738793651, 53.62649986820837, 52.32492800681822, 49.085846485630164, 56.22343840137605, 56.59476526321904, 59.0538913203824, 59.457311014975275, 64.88531043452602, 60.64744441739975, 71.75194109639814, 65.20988656628516, 63.86137177867275, 51.087180952872004, 35.26797963726905, 35.411593298758234, 13.32127909506521, 22.70811104005383, 33.02871027300435, 33.04782006048387, 44.043604327786355, 59.86506492860856, 43.658957096838186, 13.030882496987621, 4.5548842318596385, 3.3344412042248637, 1.5814095615379273, 0.6591709775309409, 0.4412037332452113, 7.011823077355662, 18.464351661743656, 15.57337853216356, 7.152841110383311, 4.673392272764637, 1.0181380219517215, 0.19649422877738554, 0.2356231960678293, 0.332019871040698, 2.970344006053863, 21.839508048949703, 47.03287401506978, 41.191244971367624, 44.71530629742531, 44.43412334688249, 32.86744790692484, 28.055380236717966, 37.03354827819332, 29.63059429199465, 41.38840683044926, 46.8756301172318, 51.70088675714309, 54.89961101162819, 58.11867275545674, 56.251899119346376, 52.729218467589355, 53.66107163890716, 50.81512928009034, 51.68815866593392, 50.557876709968816, 52.19860415304861, 49.571945821085286, 49.88086777348673, 49.091047548478656, 47.818618897468816, 52.24227582254718, 51.13581834300872, 51.63242963052566, 53.56445581682267, 49.399177182105284, 52.976284642373365, 51.003885499892704, 52.73005393243606, 58.21481789312055, 55.47216330805133, 67.35912184561452, 66.24669844104399, 64.64416311633202, 63.00105479455764, 64.10949699340328, 60.98272469735915, 65.14713648826846, 63.42723600326046, 69.91001175295922, 63.63201510521674, 61.29036011234407, 57.87284212727701, 71.77929570597988, 70.75853024759601, 77.16158774591263, 36.06901391859978, 2.654733431916083, 26.029501538122854, 77.50576003905266, 50.25151214291973, 64.4263852796247, 30.238112557318907, 4.5887004560039895, 19.549508710061353, 36.570210456848145, 50.293434435321444, 69.11391181330528, 53.449193046938994, 36.069716022860625, 21.486524151217555, 43.14447156844601, 54.65622402006581, 36.558368821297925, 60.10000705718995, 37.24933747322329, 61.75320763741771, 68.02675631738478, 83.81170749664307, 12.125559256922815, 0.8182463158042201, 0.9398787084125704, 0.8513338984020296, 0.21672720840621382, 0.224644206163864], [0.0036999942394979903, 0.13255482990174525, 0.04513615764857781, 0.02587298212963487, 0.1951856127068881, 0.2116961404681206, 0.037795729154059966, 0.11348049697135726, 0.5097953542586297, 0.7700177714709313, 0.8315766746959379, 9.460177325433301, 62.54556563592727, 57.86412269838395, 44.87404854066911, 35.05138635635376, 35.01568102067517, 31.145964745552313, 27.669883812627486, 26.80684078124262, 22.749103730724705, 25.425901720600745, 28.268257071894986, 27.06490528198981, 8.938528568513933, 2.1887575714818897, 12.589338344912376, 53.61070840589462, 66.87274794424734, 44.9760615441107, 48.76457691192628, 23.139913005213586, 0.6491399448244803, 0.8258732420302207, 7.588130062626255, 26.191917081033033, 31.32119074944527, 50.539802428214784, 57.9953573596093, 63.40629446891047, 61.23394466215565, 60.068420210192286, 58.25165679377895, 55.90529103432932, 51.545772706308675, 49.89173666123421, 52.46293660133116, 56.558240152174434, 57.07448290240381, 57.187164752714104, 54.027428857741825, 45.957324812489176, 48.86318137568813, 49.352183265070764, 49.74019981199696, 48.67525277599212, 48.05271771646316, 55.22809382407896, 49.951792070942545, 51.3049784014302, 47.687031222927956, 48.50408054167225, 49.21157806150375, 53.42616481165732, 52.20871994572302, 53.82305768228347, 55.662025636242284, 59.384288249477265, 55.08268763942104, 61.25746711607903, 49.10954152384112, 36.503514474438084, 14.451057026463172, 4.97836979166154, 10.297956370538282, 7.0896286829825375, 15.278876193108099, 29.261161934944894, 50.551620529543975, 34.414962184044626, 5.327957407120736, 4.199681743498772, 1.3850827995807895, 0.41341266805125826, 0.474925606000808, 0.030187811484680544, 0.0593503981438135, 0.42440262833429926, 0.6671883634501888, 1.507198440451776, 0.0596015141045134, 0.1604446897944135, 0.0816626897862842, 0.08092191340702196, 0.11492656453722909, 0.4785160149537748, 1.6984034449823442, 20.40202213871864, 59.430976221638346, 54.302249723865145, 55.155506441670084, 28.959698369426114, 13.342089230014434, 16.095006696639523, 5.6283790930624935, 12.388601245418673, 29.3211075182884, 43.26667693353469, 47.446440881298436, 48.91380740750221, 47.486249016177275, 50.375121716530096, 51.62281982360348, 45.26144927547824, 42.534252751258116, 42.6472758477734, 44.127127278235655, 43.48625121578094, 45.67534562080137, 44.915186359036355, 43.947114021547385, 44.53155109959264, 43.15878429720479, 44.448177199209894, 41.701933645433, 45.24267681183354, 42.721577305947584, 44.63994972167477, 40.64925970569734, 42.51101270798714, 43.06190567631876, 52.48225819679999, 59.70069408416749, 57.49517279286539, 64.09399186411213, 59.9984686605392, 56.91584656315466, 62.124487430818625, 63.818896432076734, 60.19737205197735, 62.00023066612982, 64.67308275161251, 58.582591087587424, 61.60694245369204, 64.49712522568242, 65.51820839605024, 59.11169528961182, 5.580232489493586, 1.9094867763980743, 44.14977896598078, 52.66105944110502, 41.14251344434677, 55.18918783433976, 13.349323061204727, 0.4925674770868594, 28.03843559757356, 28.50456418529634, 23.513469734499534, 50.268652900572754, 36.031598429526056, 30.121516181576638, 8.407444550145058, 23.781379384379235, 32.482918347081835, 25.938337810577888, 49.331335867604906, 18.351836512165686, 37.68966667113766, 58.014192581176765, 61.66965330800703, 7.33213363155242, 0.16672561485921183, 0.4984356799433309, 0.7006603383248853, 0.22421423165548235, 0.16280257052952246, 0.03862247208974535, 0.0997560011643556, 0.050608971036009254, 0.05374791671431834, 0.1327732722124746, 0.1081425725151935, 0.23270426318049434, 0.1806543497068267, 0.14240593919830938, 0.29445346264589217, 0.2875308163704411, 14.158180509844135, 77.15149940982943, 66.4246093073199, 46.83108768155498, 34.17150851218931, 40.93230185970184, 36.05746646081248, 32.18713633475765, 25.73088953571935, 20.714309484727924, 26.119465020395097, 33.28304852208784, 18.099310398101807, 7.868826639267707, 5.410820909084813, 16.545645844551824, 56.45255973262172, 69.03791196884649, 54.49971360545005, 55.38421200167749, 28.358961882129794, 0.37193924188613897, 0.39411218596562264, 5.4968718271101675, 26.120684877518688, 34.6090018364691, 54.99118658804125, 68.08629789660054, 68.5282313439154, 66.30495348284322, 62.5489192624246, 58.05232586399202, 56.50202082049463, 51.997143376258116, 53.31437333937615, 57.80808771810224, 59.156873149256555, 61.17648978387157, 63.36601564961096, 61.16551891449959, 50.64283132553101, 50.34644134583012, 51.327535952291186, 54.740001924576305, 56.54467267374839, 55.85848539106308, 60.32124834675943, 53.31738179729831, 53.48298426597349, 49.01194118684339, 52.15896468008719, 52.75068952191261, 56.71628421352756, 54.40465888669414, 54.92740884903939, 52.856840625886, 59.487991794463134, 57.97319596813571, 63.51690923013995, 55.70643863370342, 42.88770144985568, 24.135322301618515, 12.780004758988659, 11.472805276993784, 11.032090706209983, 22.557115477900354, 36.80905926612116, 51.20684854445919, 42.46856874035251, 3.4025455626749226, 4.87773108866907, 1.6092815562602014, 1.093918520116037, 0.38613193998894385, 0.1601890768975981, 0.2494755213058764, 1.7497396709457522, 1.8688602144679718, 0.6784597844366105, 0.0369474399955042, 0.1103333388304999, 0.2610572691886656, 0.16332459816288564, 0.19508433588329824, 0.3038579886478763, 2.4238215386867523, 14.36230359538909, 55.15446309120425, 53.92651411794848, 56.14290429699806, 29.670090598444787, 21.030927127407445, 18.66717153979886, 15.567749930966286, 18.142691812207623, 35.326697518748624, 46.4864250921434, 51.63005659657141, 54.41877941931448, 54.0273896340401, 55.90618141235844, 56.09349027756722, 49.61129896102413, 45.244751745654696, 44.89804952375351, 45.30945908638739, 46.19619323361305, 46.16744618262015, 45.74550505607359, 48.222893668759255, 49.05096877005793, 48.79211979527628, 48.62224978785361, 46.44939399534657, 46.80790255146642, 45.96744060516358, 49.889610736600815, 46.26293628446518, 47.62132760017149, 47.42695846865254, 56.6023079810604, 60.86710106941962, 63.2942323530874, 65.33515530247843, 63.91642616641138, 59.36197388556696, 64.0455113687823, 63.901846716480875, 64.72394020326676, 64.53799632287794, 65.27630798278317, 64.01222613550001, 64.643570838436, 67.87507826282133, 68.97655040987077, 50.23567753453409, 2.286978868707534, 4.720859325701191, 54.025769695158935, 58.557417315821496, 46.37223705168694, 59.76476992330244, 15.319171682480844, 0.9758491105129643, 25.468306464533654, 29.388919415012484, 31.239697625560147, 52.720859896752145, 28.061650145438414, 30.33670525397024, 16.25931674434293, 31.266130478151386, 39.31636771848125, 28.359730666683568, 66.19865725117346, 22.411728905093288, 41.83769864420737, 66.33766605008033, 72.23341987979028, 10.689332427517062, 0.6767508567821595, 0.03931098212037356, 0.4067407163881487, 0.13937367126345634, 0.049185211950492476, 0.16582573733983502, 0.2157695218920708, 0.2525038209052817, 0.259271334376066, 0.3126340774038146, 0.3251729142521659, 0.38825096983102064, 0.4366128134631342, 2.267690123088898, 0.9515657780631896, 1.7416070041156586, 20.327597125884026, 91.87180949795632, 72.69444742510396, 53.52230210458079, 42.872576790471236, 42.45057290600192, 38.506323752864716, 33.860350808789654, 34.275529769159135, 27.146206209736487, 35.118352982305716, 39.07838183064615, 35.198243817975445, 16.544059245817124, 10.15652943042017, 23.746158461416922, 61.268951815943566, 71.43897518034905, 51.6054045000384, 57.58641889018398, 27.014345930468654, 0.8490766356548957, 1.9159145605179573, 12.927878114484972, 33.787394723584576, 41.582944623885616, 60.976374380050174, 70.28439414116644, 70.69410923988589, 70.75964420072495, 63.73218459467735, 61.935621384651434, 62.98735003317557, 59.872846911030436, 61.49113447435441, 60.50391704805436, 62.578533157225586, 62.146523306446696, 60.327626120659616, 61.92393272153793, 52.101956952002745, 53.68196218244491, 55.19764446443128, 61.67768632211993, 59.73502659028577, 59.73414797936717, 65.11858555578416, 55.3696168622663, 54.354593753814704, 48.27272738179853, 51.65916450562016, 58.216296626675515, 59.49103555371685, 58.00328839209772, 59.25238286295245, 62.878512105634144, 70.04243096997662, 66.3296801044095, 71.2764007814469, 64.24098268631967, 45.89884619559012, 31.44634573690353, 27.194139534427276, 14.890599789157992, 17.658381077551073, 34.876499637480705, 46.48489929014637, 56.73788862843668, 58.698046053609545, 36.130975600211855, 5.357886562424322, 4.121807496393881, 1.9258440406091752, 0.9749540746692689, 0.4525358896822699, 0.9509041232447472, 2.143489007026919, 3.7089187099087626, 2.2343154107370684, 0.24755018913457472, 0.24409442779517945, 0.43024735825677074, 0.23444565764117628, 0.1750021223579684, 0.3929333298677399, 4.846439890323147, 29.28889701443334, 57.928602541646654, 49.322047695036865, 57.949673514212336, 40.13514288010136, 30.57076092689268, 25.47558638357347, 28.301769802647254, 27.891893886750747, 37.505578071840354, 44.54857026377032, 51.30989313125611, 55.77398577044087, 52.46869071837395, 56.97587059390161, 55.73494642011581, 52.023599763070386, 45.66010329031175, 48.22254065544375, 54.41557876525387, 51.59284507074664, 50.73248886292981, 51.79494519387522, 50.14663188688217, 49.78793113462387, 49.074742255672334, 52.79690680965301, 49.74369464382049, 55.84280375511416, 54.22006822401478, 57.01425490840789, 50.197359900320734, 52.17116717369326, 52.048079275315814, 58.40761023183023, 62.918841915745894, 65.74402709161082, 67.94666151846609, 66.23677484450802, 62.822461435871745, 65.50853975357549, 69.18889968625962, 69.0264037347609, 69.14793445217994, 69.16530270730296, 64.21416151908137, 65.78342729999174, 71.20407227546939, 74.15474584025722, 67.04905848349294, 9.3957680848337, 4.092890557742888, 55.68695622105753, 66.38067876138996, 56.035290148950395, 64.16401401642831, 22.201756585028864, 1.4244484420745605, 39.039530754089355, 37.50193811232044, 30.707900716412453, 58.52999210357667, 46.784944918847856, 50.2111078077747, 15.219364031668633, 44.27152149138912, 51.30105603125788, 35.52721300432759, 68.68504770340459, 25.12185919669367, 50.21040178114369, 69.68675044275099, 80.27747938709875, 15.23377383908918, 1.065541765382213, 0.8547940417643517, 0.9509299250860369, 0.43883076057799403, 0.3341477262156625], [0.16472090065719622, 0.2669114986013982, 0.05894566240209726, 0.022553825758457668, 0.550746921329729, 0.6264014133522589, 0.015079236116200207, 0.16132417405324598, 0.21998934868362643, 0.4330246414869063, 0.251587319277948, 16.986271181414207, 68.06971411551199, 55.047272559135195, 35.515120337086344, 47.06597881932413, 39.807526911458666, 30.288618956842733, 33.71149293838009, 33.58437676583567, 26.01865226222623, 32.86206445386333, 25.7651279049535, 21.188067082435857, 10.454218695240638, 4.590836676859087, 13.615074426897111, 40.265463629076564, 61.936668657487445, 44.90696899352535, 49.31424610076412, 44.25816974332256, 2.240077617668337, 0.45060335628448, 0.971636301086795, 10.235591665391, 25.126199299289336, 54.71999783669749, 68.04557584947156, 60.85149395850397, 61.67535643423758, 59.23299066482052, 53.511876444662775, 51.302860321537146, 48.39132024395851, 48.214319367562574, 60.26027510243078, 63.909279607957416, 61.18149865058161, 66.27772438910701, 62.129888534545906, 50.21648929965112, 46.94053749884329, 49.151185327960604, 52.56978588719522, 49.82742940225909, 54.51305750877627, 56.397979951673946, 57.483715549592056, 50.79423873655258, 49.107717621711, 48.736233865061116, 49.52646201656711, 54.02841729502524, 54.14680619393626, 51.64245913105627, 51.588808951839326, 55.422533558261016, 64.56231109557613, 57.388927552007864, 52.11307687144126, 19.97356399413078, 8.476461595104587, 2.3864138943533746, 8.21611084284321, 6.404386201212484, 19.115635733450613, 61.05823032317623, 60.15371607195947, 5.448152557496102, 10.660940351024752, 2.9239340318787486, 1.2314590042637241, 1.7955947523155522, 0.5728224496687613, 0.08891944232727252, 0.679668855042227, 0.7412647756357348, 0.8841461796433696, 0.16254683505863915, 0.20841544554118188, 0.17371183111061975, 0.14072915659316126, 0.12607270716539315, 0.06120779363799, 0.12850458433310832, 2.6469107549036703, 13.52529529602297, 43.464262408594934, 67.2596348485639, 72.12802579326015, 27.66548095210906, 21.170779235901374, 7.77981972502124, 5.090727556136347, 5.344784865456243, 22.977883815765384, 49.39982829555389, 52.31659689257222, 51.80471974034464, 54.13360349593624, 47.93258728519563, 50.439609404533144, 47.19184767815375, 39.71384894463324, 42.131896018981934, 41.36578652166551, 43.5267222312189, 43.679588763944565, 43.48230531138759, 47.41639160340833, 47.565461281807195, 48.968877484721524, 46.337049468871086, 42.30608063359415, 40.69563388824463, 41.560159575554636, 41.066729330247455, 43.80546546751454, 44.579160828744214, 43.39211040927518, 49.57730377874067, 57.94783392260152, 56.37947028683078, 60.84199005557645, 58.52134327734671, 54.37770828124016, 56.83471625851047, 58.64972245308661, 68.04747427663496, 62.12861768661007, 63.22974074271418, 63.62522940481863, 58.14948689553046, 62.30928597911712, 65.71834733409267, 14.092525916714823, 0.5428494741359066, 13.956247087447876, 58.39902808589321, 46.20403797395768, 45.538043052919456, 54.068382324710974, 6.1736361057527605, 1.7458117849403814, 20.026565021084203, 34.75276454802483, 12.592663534225958, 46.28724713479319, 20.550817251205444, 27.222874818309663, 18.083091397439283, 21.1488002346408, 40.254837928279755, 32.31670398865977, 36.24665021896362, 33.26401718201176, 49.47946025479225, 64.25042383132443, 61.261389486251346, 6.177014247063668, 0.24005392686493937, 0.34502914716159144, 0.6880544534614009, 0.3511875441237804, 0.0281780123740675, 0.3301213213032292, 0.3043265586658832, 0.0901433980212577, 0.13780294587054562, 0.42347900208926975, 0.4967904601606631, 0.26574713688704277, 0.18572367607585846, 0.3201470710337162, 0.5883439425979892, 0.6044884795142759, 27.83037151059797, 80.55875255215554, 61.72784559188351, 45.11789444954165, 42.3006324614248, 39.55823283041678, 35.1438444660556, 33.619152499783425, 31.899787418303955, 25.674134800511023, 28.064470329592307, 27.726224737782633, 20.26756525039673, 9.239174319851784, 6.566525217025511, 18.856698505340084, 44.18329169673305, 69.01050244608234, 48.69240530075566, 50.445543950603856, 49.89482356655983, 3.194687645281515, 0.6027030043544308, 1.0253290747923236, 12.977281347397836, 33.9823482882592, 61.44522313148745, 70.89844903638287, 62.939559874996064, 64.18543407993933, 59.8546314239502, 56.94252652506675, 52.41207130493657, 54.00913100088797, 53.76215504061792, 62.82248497009278, 66.80608334079866, 67.0931145452684, 67.94542989423199, 64.87519856422179, 52.6608201765245, 49.97827199197585, 55.568300600974794, 58.00200969942155, 58.667561392630304, 60.864590752509336, 59.27402650156329, 58.25279428112892, 54.49311225645004, 55.88451816189674, 52.61586589197959, 51.729418077776515, 53.19934198933264, 53.58936286741688, 54.53563467148812, 56.74419579967376, 58.12212051883821, 66.77686952775525, 59.92907016508041, 58.12969461564095, 28.96057698034471, 18.4395367868485, 1.4594804783982616, 11.237699389457704, 8.45081223595527, 25.41846686793912, 62.683382034301765, 65.95164206720167, 31.533128176966024, 13.343577769494827, 6.23352530502504, 1.239482947895604, 2.5511080891855302, 0.637761577963829, 0.24400764535511696, 0.32170039090898733, 1.0349469103159443, 0.449743039545513, 0.3193239861678693, 0.2824078638467097, 0.060900921798160965, 0.10673533028532421, 0.09749018887598669, 0.2877461790077148, 0.5462874315919415, 2.8445808060707587, 14.794944947765721, 57.240846310892415, 72.00192159222019, 68.30544856286818, 30.235696377292758, 23.512504831437145, 11.713666262165194, 8.647045473898611, 13.744504797843195, 27.294512987136844, 51.99813573591171, 57.72827532983596, 56.023538727914136, 56.92560542014338, 52.62459708798317, 51.99013017839002, 49.839600516903786, 43.71498031000937, 44.30567356847948, 45.75487559841525, 43.34853287666075, 42.6367913523028, 47.68827069190241, 53.49612420605075, 53.03107623131045, 51.79234074008081, 51.023105113737046, 45.903717779344134, 45.204500382946385, 48.624595365216656, 51.693175377384314, 51.16890745778238, 48.52852475258612, 48.77682647397442, 51.44319488156227, 59.25242993139452, 61.90303433325983, 60.414039857925914, 59.73808211665, 58.817529293798636, 60.589079549235684, 61.51736336369669, 70.15544229938139, 69.48362658100744, 66.2958614287838, 68.57680597612935, 63.35351897824196, 70.39382826897406, 57.26083470929054, 6.896984904043137, 0.38053667893813503, 19.972189203385387, 65.69693119295182, 52.266633741317264, 51.39225898250457, 56.54553951755647, 9.580562710762024, 3.1564349753241387, 16.450771554823845, 33.7296417451674, 17.919893341679728, 50.756093686626805, 19.81929325288342, 28.753428766804358, 27.569124006455947, 27.08415823598062, 47.59632641269315, 37.45994521725563, 45.09848263955886, 32.34979310343343, 54.96925661640783, 68.80636661283432, 72.12706089019775, 8.362481440267256, 0.8618671170646145, 0.5583483521496097, 0.9686404070065868, 0.314904639437314, 0.04523630066203975, 0.4148443331641536, 0.2618663499672567, 0.20398943384568538, 0.2950703472860398, 0.42464321058604027, 0.47244865988050744, 0.4075769473227763, 0.5586784441144236, 0.9404737442251175, 0.5630676376242791, 0.914975518901502, 35.60723327821301, 92.32764382516184, 70.69912202896612, 42.10576518889397, 58.71080552378009, 47.67419722772414, 37.309079093317834, 45.096870545418035, 41.66029376368369, 32.829438178770005, 44.296973751437285, 34.94664338327224, 28.108147882646133, 15.603663152264012, 12.62470047320089, 25.89031819374331, 50.754505126707016, 67.80549541596444, 48.05417291579708, 55.34069330461564, 52.51657501343758, 3.525306923735527, 0.924058686341009, 1.7836997970458002, 13.929896604630256, 33.0415246563573, 56.392563158465975, 73.36005010912496, 69.44652095917733, 70.28056590787827, 60.71742734601421, 60.28198542133455, 54.776554492212114, 57.16815694685906, 61.29830683431318, 70.97939106725877, 68.35073624887775, 69.92326151940131, 67.02651269974248, 65.57926401015251, 53.96317258957894, 54.003812266934304, 57.12025303994456, 60.85207054691931, 62.537995461494695, 65.03239539361769, 62.357323246617476, 62.10203970632246, 54.37605304102744, 57.35300648596979, 56.00939466107277, 55.143758943003995, 58.590110271207756, 61.7735686609822, 59.958511475593816, 62.46143471810126, 71.75937791024485, 75.30227445787, 68.1773204188193, 68.1544686901954, 32.306731362496656, 30.033990452366492, 10.732176476909268, 14.433089629296335, 18.351077533537342, 37.60044843919816, 63.753247722502685, 58.08930989234679, 52.18335790018882, 20.638254727086714, 7.903208665309414, 6.780238007345508, 4.96414678712045, 0.6620355947844444, 0.9152114126951465, 0.7989950778503573, 1.6343121615148362, 1.7980573879134272, 0.24716870799180002, 0.21137867363229876, 0.23836798184821684, 0.15817218189758642, 0.16184825480224627, 0.3321824042547134, 0.6079524839597364, 7.4971041083335885, 31.94966231623004, 60.18026659565588, 60.466650609047186, 60.11182908088931, 42.30428026568505, 38.68261860262963, 17.17130703310813, 19.028147266757106, 23.701390489455193, 28.89982731111588, 51.38752468170659, 55.76954564740581, 54.70246484202724, 58.152240399391424, 54.75470689035232, 55.9039770403216, 50.10514497756959, 45.64944621055357, 47.24301107468144, 50.323311128923976, 51.743860244750984, 53.49012297968711, 50.32612346833753, 51.81891872036842, 49.979138835783935, 52.90908659658125, 53.766567707061775, 50.858710735074936, 53.32568937732328, 57.757132207193685, 57.90920642114455, 54.77648781191919, 50.68351807132844, 53.82162993954074, 56.36524777258597, 64.65087821406703, 65.1963504668205, 69.1467498963879, 65.64422630494641, 57.978734354819025, 64.20892907727149, 66.86737429711127, 72.6648727540047, 69.4114157461351, 66.97777332798128, 67.45660843387728, 63.47877202495452, 70.15916070630475, 75.12323394898446, 19.734493570943034, 0.6590036026412441, 19.47936104189965, 72.33008277031684, 57.801325551925174, 56.172949652518, 63.589786867941584, 10.640028234451048, 4.246368244771035, 27.553942472703998, 46.92604041868641, 18.370718802175215, 60.634324089173354, 30.675882408695838, 49.0305842122724, 32.13590625793704, 32.32313667574237, 64.35752022650935, 37.9036751101094, 46.07835346652616, 45.88049342555385, 62.19962435383951, 74.79333908327165, 77.77640358094247, 13.251476595478675, 1.1711202033104435, 0.9399925797216354, 0.905530512813599, 0.7142895327941065, 0.14236634777438256], [0.5868900302917727, 0.2733911315519964, 0.03174783271406928, 0.24046078083976624, 0.2505490862794461, 0.24909302892704166, 0.284888272684428, 0.049634897901165875, 0.06697695281717085, 0.6674443593909664, 0.5166221782565117, 24.616285293332993, 69.01780589934319, 55.31917125948014, 22.870583457331506, 35.596027066630704, 40.292206348911414, 30.138082311999415, 35.061200126524895, 33.12160768816548, 21.946755455386256, 30.351204295312208, 25.90521339447268, 17.73108220869495, 7.66727319648189, 3.134231908667472, 13.691595946588825, 51.17471648800758, 54.20024848753407, 40.49150197736679, 47.108654206798924, 51.31995008837793, 8.957757988283712, 0.13300803219599108, 0.36921846530129837, 7.449215890899782, 33.08915399735974, 65.8711471865254, 66.68383875200826, 59.77540739120976, 60.02834143177156, 56.654193093699796, 50.47389876457953, 49.910932740857525, 56.26296412560248, 53.93402545682846, 61.37639337970365, 66.396909529163, 62.0672365157835, 64.4261734716354, 58.291029545568655, 47.84398094300301, 44.06300437065863, 47.26621189425069, 48.294563216547814, 50.80956735918599, 59.05472286285893, 56.33382958750571, 57.927210100235484, 51.57264486435921, 52.121615871306396, 50.39876968629899, 49.549929557308076, 47.48505269327472, 52.92710596515287, 53.74266478323168, 56.07949918316257, 52.55481027787732, 55.52976331403179, 52.52769885524627, 51.243067710630356, 12.113994148469741, 2.6412664642257075, 3.185689973254358, 9.456784475234247, 15.090315111221807, 30.507655874375377, 75.13400477747764, 22.783467615804366, 7.649364634867638, 7.499157469118796, 3.218386115566377, 2.1571802852615236, 0.16767046173974393, 0.12588497731954823, 0.12112092166658371, 0.2831728179608622, 0.12519185927005547, 0.2916910721650047, 0.062350498046725995, 0.03563990793941963, 0.05112442946542175, 0.23735956499172797, 0.33277793036353204, 0.29371516839150463, 0.11715294628013527, 1.2836217471668798, 9.73645535207564, 13.482532635811838, 31.40814381261026, 58.02424169355824, 58.588494254696755, 17.313379203119588, 1.4753865474654784, 3.5310916842952853, 3.6930850821156658, 12.86873269465662, 48.409355302010816, 57.116495409319484, 49.89010495524253, 51.94930614963655, 46.96409133172805, 46.07512927824452, 46.50047502210064, 41.562709116166644, 41.18458478681503, 44.92474909751646, 39.522868740943174, 42.14568315013763, 47.06241730720767, 52.01724552339124, 52.40060621692289, 50.91861709471672, 48.31097833571896, 43.2757140744117, 40.627678825009255, 41.93735822554558, 42.82235084041473, 47.475999862917014, 45.21165870851086, 43.20465249399985, 46.92715437181535, 56.686572259472264, 56.66843914216565, 54.02796230008526, 51.709041364731334, 56.72262276372602, 58.81873346144154, 61.32422977878202, 59.97460103804066, 64.48592293647029, 67.04882314128261, 68.48016661982383, 71.40616847622779, 59.93334947093841, 11.862369198952953, 0.1383500092572743, 0.3576381576638068, 26.874111390882923, 66.49879701675908, 49.219214916229255, 46.963193108958585, 50.768606047476496, 15.998484030846628, 5.3476864387912135, 5.3243885405602, 29.778512754747947, 7.162705871366686, 21.389053252435502, 18.669460242794408, 23.249111790810865, 31.006138132464503, 18.504799142960582, 48.07076846399615, 17.804061828121064, 47.6997906930985, 35.65167765463553, 44.2776600007088, 57.3337358813132, 62.42420358042564, 5.385432387551954, 0.23916618417828317, 0.8789006836952702, 0.5655437563696216, 0.23930864588868236, 0.11574311467308192, 0.6351908320380796, 0.32128278105970354, 0.04699259553284896, 0.17244207101964182, 0.09398107717354452, 0.2603729381676643, 0.22402126942911457, 0.11225186048015473, 0.07529703539706047, 0.42264381303421916, 0.3059654658840549, 32.86893056284997, 80.83885685090097, 61.609150748099054, 29.979406749048543, 32.570940256118774, 41.706918977922015, 37.900168511175345, 33.656289500574914, 30.384987669606364, 26.642897475150328, 25.930279301058864, 26.824414960799682, 22.470082006146832, 9.4683809626487, 4.3722052343430065, 15.32014541087612, 58.573071495179214, 58.30840956780219, 40.613558292388916, 49.12837282303841, 57.04463366539248, 13.903606918550308, 0.1999786418051489, 0.09918766351596964, 7.373059151634094, 34.923097395127826, 66.02494332098192, 64.54970459784231, 61.014421370721635, 60.93777041281424, 60.37528684062343, 54.66834022152809, 50.66813453551262, 59.26782523432086, 58.65031080861246, 64.32588631106962, 67.95357273470971, 67.50006045064619, 65.82939747841128, 61.267779027262044, 51.76353093116514, 48.71563749928629, 51.57808911415839, 51.816098536214525, 56.20521506955547, 64.09925176251319, 59.967536849360314, 55.906428521679295, 54.92678126981182, 58.98097445887905, 55.505436774223085, 52.891667350645996, 52.599270343780525, 55.132097736481704, 55.632980485116285, 62.85240480976721, 60.05660995360344, 58.853222862366714, 53.34825085055444, 50.60655332380726, 18.233437807329242, 7.217432741195926, 1.3384057365117537, 8.788001729596047, 8.72449855650625, 30.68946949897274, 71.64303256619361, 46.36673788870535, 2.8435374556049227, 7.483812176412152, 3.8248571080546228, 2.7721017791378886, 0.5351269401369557, 0.16604952694427583, 0.1664578671296758, 0.43979431532563706, 0.14398188931086373, 0.623506213868818, 0.013846527867680116, 0.02405638464786593, 0.09312559444937976, 0.16170600759646586, 0.4045064669222601, 0.22471646357688213, 0.09356285445392133, 2.431627300477797, 14.133132253923725, 23.37474922980032, 42.944999433332875, 60.76872018075759, 57.71802225420552, 20.640153154250115, 2.978854568735246, 2.962194056280198, 11.605588293844654, 18.41687725436303, 47.47959667636503, 55.98133402486002, 54.39795947843983, 52.991542662343676, 51.34570829329952, 49.62640400855772, 49.02615977871803, 47.18095525618523, 47.82077227869342, 46.91597561682425, 43.38063355415098, 44.78446160593341, 51.15069197070215, 55.271263430195475, 55.95710554430562, 53.82624656923356, 52.27842830842542, 47.05574143317438, 46.617020407030665, 47.88109833194364, 49.096170163923695, 49.623148441314704, 45.6620527082874, 43.659443470739554, 51.941308436855195, 60.56413719730993, 59.24129040010514, 57.52505340883809, 56.555600397048465, 61.187013503043886, 65.0545685522018, 64.16646157541584, 65.08572786085068, 65.77306439799648, 70.5186616220782, 73.04335009667182, 73.61657311839443, 49.57402467727662, 6.050513396340032, 0.14197936612031153, 1.3265172776675995, 35.03900735608993, 72.3682866557952, 55.706591606140144, 52.25162675303798, 56.225125020550145, 23.11637290062443, 7.269371786425191, 5.538553874338827, 34.05801865362352, 11.332879624059125, 28.511893133963312, 23.278204010378932, 28.32797908013867, 35.61927887701219, 20.973162381879746, 52.05471592564737, 24.04696502993184, 48.16743527689288, 29.727951442041707, 49.7570816932186, 63.17822433287098, 71.65629802211639, 6.564252203510654, 0.572358568108851, 0.3333655810884891, 0.6459579220221889, 0.11627088030499798, 0.04745300671446228, 0.5917752810543584, 0.23684179680722378, 0.19278548988363436, 0.34083561250759714, 0.17936753649865428, 0.5600999968667184, 0.3879201117782824, 0.19687632279049969, 0.30928985846619456, 0.45456614525568106, 0.35421294791083185, 46.85613593747539, 94.33297126523911, 72.56925321394398, 34.53319026577857, 49.852312918632265, 48.28029363386093, 42.371415553554414, 46.342379969935266, 43.2265510866719, 27.98806255863559, 46.9858604861844, 39.073937785240915, 23.480753244892245, 12.724964099545634, 10.254097407863988, 25.467319988435317, 60.88291998832457, 61.096289080958215, 45.77535821545509, 55.54935555304251, 62.52143913699735, 13.904439441619383, 0.3302466226441245, 0.6698348601498912, 9.353429040601178, 37.377038078923384, 62.75355715905467, 69.17471639571652, 69.98667840034732, 66.45503905511671, 60.13796775571762, 59.297160640839614, 57.24336839491322, 60.369575869652536, 64.51372861862183, 74.46274603566816, 69.04352880293324, 71.30184911912488, 68.18600454638081, 63.07921194261121, 56.74849471738262, 51.317392703025575, 54.586700008761504, 56.527469158172615, 57.310213427389826, 65.58757159017748, 63.71927607444025, 63.63606299123457, 58.680505214198945, 64.14270770165228, 56.98469984915949, 57.99831482671923, 57.433313092877796, 63.270396109550234, 56.90343618392945, 62.56870761994393, 61.75819689227689, 69.73915330825314, 59.71282989748063, 59.083258105862534, 21.17239917478254, 18.998270573154574, 4.467399687536301, 12.270434941014937, 27.39465698119133, 47.071175959802446, 63.00729528550179, 48.60870192127843, 27.21381022084144, 15.802040946099067, 11.156859340206271, 7.268343635143773, 0.8308002905499551, 0.31184899049901194, 0.203676303067515, 0.5662005082253487, 0.17994784810129674, 1.156440610366483, 0.1649530252982532, 0.08340539425731668, 0.12075283940160468, 0.2263189050098581, 0.47923469735730084, 0.3316659077761635, 0.3349346823750004, 6.1572974727999785, 25.624118697258737, 35.350514150434925, 47.125638069645056, 53.98049377625989, 60.01215381007041, 28.214246034622196, 9.12288781135313, 11.732771146682001, 18.96221418534556, 28.7550094819838, 51.34993268597511, 56.85990571975709, 56.19325184052991, 57.7205051145246, 55.08026361465455, 50.0343148169979, 52.44128511797998, 47.87255540970833, 49.666545544901204, 51.211402416229255, 51.9891260516259, 53.64004773478354, 56.248102265019575, 59.37372138423305, 56.7063331604004, 53.95633982073877, 53.053265079375244, 49.592236241986676, 51.88219047361805, 54.13679630525651, 51.33218003857521, 53.56584433586367, 50.044163888500584, 51.95334619091403, 52.338495485244266, 60.979708394696644, 65.90007858891641, 65.8235845258159, 62.7052806269738, 63.492053170357984, 65.6444694918971, 66.27477476673742, 68.04981200925766, 72.58752361420663, 68.02701519381615, 68.934353551557, 76.01969949660763, 71.56162769563737, 16.608368465977332, 0.26431271385762, 1.0788055052680354, 38.03985980249221, 74.4324496484572, 59.46211199606619, 61.03940686871929, 60.992365883242705, 21.34659359532018, 7.022150187723099, 8.383414149284363, 42.6778232666754, 12.73379139361843, 38.24276401150612, 31.061425901228386, 43.95236215283794, 50.43705986392114, 28.171082312060943, 68.63296647225657, 25.926770740939727, 56.69164388410507, 44.46127791558543, 57.37706238223661, 68.04479922017744, 79.74082854486282, 9.509915920995898, 0.8870882637077763, 0.9521300477846977, 0.5545592199890845, 0.24301343176874424, 0.24940254377020946], [0.11090330058528532, 0.3807569138946072, 0.03255404066294432, 0.04720891961046765, 0.008193982592333228, 0.09891134326256092, 0.17571731140055966, 0.023074089474375212, 0.06844591109022018, 0.32828402795618583, 0.07845154798199093, 13.380912849980017, 72.58897489117038, 41.91243156310051, 23.26059256830523, 39.803126012125325, 32.649379814824755, 37.01237532400316, 25.451034307479862, 43.01510395542268, 18.590481358189738, 30.04030546834392, 28.632911982074862, 25.062835370340657, 11.444954487585253, 1.1904878866287971, 8.082917938309333, 43.72438223131242, 66.61913533364573, 56.78114060432681, 51.279812474404615, 58.08538752217447, 25.54880918995027, 0.5271913724080209, 0.237001265669542, 3.682677318011561, 30.20282691524875, 66.3478014546056, 62.412059922372144, 60.19411648473432, 58.0993393928774, 57.63156144849716, 51.89148256855627, 49.316093537115286, 54.36681585927164, 59.245122555763494, 60.658889893562566, 64.26133194277364, 62.6186982277901, 63.85686105297458, 56.85219041762814, 49.691397682313, 46.72027287944671, 47.00771201041437, 45.80069672676825, 56.5450256870639, 59.580445981794796, 55.749255226504424, 56.2672120524991, 54.09127719940678, 53.686700405613074, 50.6158414963753, 46.63302367733371, 50.245157903240575, 51.03288358257663, 55.066025410929036, 57.41752947530439, 60.078033939484634, 52.02065014070081, 49.28164335989183, 35.63752574305381, 7.10431746898159, 0.6983574780244982, 1.2307676865208534, 2.7249232655571354, 9.114691038285534, 68.08756874453637, 59.795309497464096, 3.3367058827031046, 4.146281615380318, 2.0149367567031615, 3.460178908801848, 0.3573638981869144, 0.11213532318511318, 0.07060440212127662, 0.4155176325190452, 0.38022794550465, 0.04967766092909921, 0.2671774536851914, 0.11874507616965041, 0.018769048807782032, 0.04606288271926103, 0.13975253238553, 0.06379163583680507, 0.05028414209523509, 0.10925274116978531, 0.7000489388742756, 5.522141696945314, 4.0413481621972975, 9.17368740804734, 23.605882736944384, 31.063808741108065, 5.699809376270541, 2.446047649268181, 2.9367403253432247, 3.3159982196746336, 9.325484114308512, 39.22696905751383, 51.91205932248024, 49.90200542634534, 52.34475166566911, 49.49942904133951, 46.22808210311398, 40.30166710576704, 45.05311258377568, 44.41306021905715, 44.69595724536527, 42.41027447485155, 44.479646375102384, 45.501604234018636, 50.54767462515062, 53.9944338798523, 50.6426626636136, 50.707758318993356, 44.66928905056369, 40.78311058782762, 43.49791242230324, 42.5803876692249, 47.05077179016606, 40.996008996040594, 40.35414449630245, 47.137318888018214, 56.06212308329921, 55.447244490346606, 58.39943209002095, 58.7133119183202, 53.71342743596723, 55.38252146013322, 56.57203905044064, 57.588866449171505, 56.59509866468368, 65.35198619288784, 58.95268240282613, 38.91832559339462, 4.248139685200107, 0.08639008813207188, 0.280689038336277, 3.091856827658992, 49.08033163316789, 49.93991513406077, 31.926224193265362, 55.631588043705115, 55.84068567522111, 47.189164776955884, 8.066002716941219, 5.033716886274276, 26.32497564438851, 11.415376874708361, 18.837443590164185, 4.46583221035619, 20.20274808329921, 29.69731184744066, 26.157572807804232, 33.106290832642586, 26.600106377755445, 47.84984488641062, 38.611478574814335, 50.769857283561464, 59.30923761860017, 62.71653390699818, 2.583614241692328, 0.14272593412428133, 0.1255400921969164, 0.014711805025956806, 0.19937369281486159, 0.10151313107100227, 0.13118239870715526, 0.20458846863719726, 0.09642285219724141, 0.0371910751076235, 0.08199327970824896, 0.05642608731925007, 0.1262663282273758, 0.026006093736918225, 0.05943773216718148, 0.2896757399843585, 0.2342173634397407, 21.88455843156384, 82.0567370999244, 47.655526745703916, 23.17212154788356, 39.000185458890854, 37.621476265691946, 41.85805182303152, 31.541351426032286, 36.615917836466146, 20.086496876132106, 28.83393345340606, 27.109020179317845, 31.411940666937063, 17.253106101866692, 3.9356017977960653, 8.139893797136123, 45.55209298287669, 67.42572369114046, 60.02217938823085, 55.22005296522572, 64.71860577983242, 29.081511497497562, 1.127175806510833, 0.11501819631385227, 4.243927059635039, 29.195919190683675, 65.10008373568135, 66.2921194876394, 64.56870063658684, 60.21133176742062, 59.97605231500442, 55.79147561903923, 52.693764163601784, 55.62200177100397, 63.451103625759, 65.49421918007636, 64.88052514291579, 65.49458396050238, 64.800245992599, 58.67317430434689, 53.05934083077216, 50.359793093896684, 49.28126288998512, 48.86385994572794, 61.540454356901115, 60.622521677324855, 58.59458569557437, 59.25213183126142, 57.0193265330407, 56.751942480764086, 53.58681332680487, 50.48209651823967, 54.66415113018405, 53.151104680953495, 56.408197725972826, 59.54024168752856, 64.4647382151696, 56.09846776531589, 51.34569652618901, 35.70724587286673, 8.536916105977951, 3.193539126265434, 0.5403329059481621, 3.5573100322677247, 11.138571289277847, 66.13323211669922, 75.87825098345357, 17.676159220357096, 7.515069544315339, 1.7070993396543688, 4.22726777292067, 0.2151002521596609, 0.11864655726258794, 0.05183579189883125, 0.08784464395214474, 0.26077825996664267, 0.057588732996655095, 0.7817837175342345, 0.045913721569964004, 0.04142525072600092, 0.05550496618173296, 0.08628753194164845, 0.06486160785800989, 0.15814219721623007, 0.03185302424695223, 0.9414827739519458, 5.967838658440498, 8.189137683760736, 14.105974743443152, 32.92333187595491, 37.33782614431074, 9.191126265833455, 1.6468724488250672, 2.1647006946225322, 8.062072992324829, 17.988434799255863, 42.16098039380966, 52.04704769196049, 51.059132083769775, 54.152670137343875, 51.7705794303648, 47.960479259490974, 45.020725573262865, 48.63355013632005, 48.067183417658654, 45.713243561406294, 48.26766752427625, 49.48679508701448, 49.51942920684815, 53.058383772450114, 58.03600095933484, 53.71061117418351, 53.05801114728374, 48.48421765911964, 46.207544572891734, 47.89901571889078, 46.49235571584394, 48.66953396028089, 45.567194108040106, 44.54067453261345, 48.565261671620036, 55.40262752963651, 58.40587654421407, 63.654443217862045, 61.03204065753568, 56.377681686032204, 59.03217315673829, 59.93987629490515, 60.415753933691214, 59.44136265785464, 65.23259316721271, 50.9366992212111, 27.45547333071309, 1.014286499590643, 0.42191247485818406, 1.0303121396610815, 4.491558546020139, 57.89048887068226, 49.517377807248025, 35.30694838493101, 62.00755765361171, 61.43276568382018, 54.28610132586572, 7.099886171279415, 8.079925660164125, 35.51969382070726, 13.540558218955995, 23.500394513530118, 9.756855599341854, 23.853715735097087, 31.615729370424827, 27.63485508580362, 35.013115790582475, 29.124928212934925, 40.943233505372085, 45.155007916112105, 59.45160004400439, 67.25128020009687, 68.79379149406188, 2.5993618224897697, 0.13941997361759986, 0.15835216659451687, 0.1220609192105551, 0.06402578294998215, 0.06214987877155505, 0.29389461682688806, 0.3215139863952514, 0.19683639428788618, 0.22280254611565223, 0.1177122057866185, 0.211020159805494, 0.32296014589167416, 0.15556313157562288, 0.22426680060884646, 0.3600669321754287, 0.5154129237897935, 35.63386224931286, 93.20428571393414, 60.38655581012849, 33.94101042901316, 53.21971085763747, 40.12162247011739, 47.00648823092061, 36.52666038082492, 57.39202230207382, 23.945003017302483, 42.15486541871102, 37.87883866217829, 30.70181908146028, 18.145821863605132, 6.733232323200473, 17.289793991273452, 53.36309309928648, 74.27451933583906, 67.16592158040693, 64.11484318394815, 68.57977128797963, 30.433536806414207, 1.1434335405788114, 0.6861933501016709, 5.856033457863716, 31.477936506271366, 64.62071126507175, 72.45393553087789, 65.72581552690076, 64.08618242509904, 60.1990076803392, 58.16387022695234, 56.447244921038234, 60.641101944831114, 67.50300222827543, 68.13795551176995, 66.63444826679846, 70.48067738932949, 65.54035017567297, 64.93732890775128, 58.009042509140514, 53.648653414941606, 50.016471955084036, 53.49432383814166, 62.26642231787405, 62.92352130336147, 59.373607635498054, 65.01205398190406, 59.67379054715557, 61.38807419807681, 55.3944689996781, 54.78224192896197, 52.95875164770311, 57.421196891415505, 57.557154086328325, 64.16296282122212, 61.969098814072154, 61.60528329110915, 55.97057888584753, 45.33257361381285, 16.03090242032082, 12.251544806265063, 4.339178387195834, 5.620119071775868, 20.14995101959475, 69.64004285873906, 75.21568421394595, 36.28620339978126, 22.55648789867278, 11.095163399173368, 8.840574237608141, 1.0337882176522286, 0.14664459643104386, 0.2535124675881478, 0.6584898334357047, 0.4929112667037595, 0.17773789894436637, 1.7835425345167037, 0.267633551791791, 0.144527267304159, 0.13964717997418297, 0.20067581245976113, 0.3929982634802019, 0.320148388704946, 0.14210805356983217, 1.8713411136019615, 10.997298302188998, 22.486628524718746, 27.352634668350223, 38.386805211344075, 33.21588969999744, 12.538317134303432, 8.458654034522272, 7.943840988220708, 19.959192429819417, 29.705937139449585, 45.55340305451424, 53.951342721139234, 56.41000201625209, 57.333229895560976, 53.9447452945094, 48.67236983391547, 48.047853977449485, 51.434310713121974, 47.158083915710456, 50.78462108489006, 52.30700277513074, 51.32407249942903, 54.212486282471694, 57.7412897540677, 59.93766800049813, 55.9089506057001, 55.50068286157424, 49.40963814335485, 50.00535203564552, 50.67514773338072, 50.15534739340506, 50.23315937288346, 48.5475835492534, 50.21116664332729, 50.84563747529061, 58.70221553310272, 65.97494094602524, 68.30518968643682, 64.40271377563477, 61.20702543566304, 60.44574437602874, 63.895751353233095, 62.60769205708658, 62.88668632507325, 68.72169048555436, 58.54661510836694, 43.51292725532286, 5.795178374936504, 0.5795094779422206, 0.8844221551572123, 3.705727371477312, 60.41228655845889, 60.13122520139141, 46.36698892039638, 66.41612914300734, 65.81972491356635, 55.597110409890455, 11.639593282053548, 9.282931300901598, 34.74857153431062, 18.08152048818527, 30.783743666064357, 10.78906653388854, 34.40288520628406, 46.24907462827621, 36.85861841324837, 45.92796194937922, 35.94600446762578, 58.49920542009416, 51.59578684837588, 67.94112313178279, 75.83330846601918, 87.51197738032188, 4.449754905316138, 0.36623556407228597, 0.24952297279190636, 0.21967151412560096, 0.22977451313166852, 0.24723822281004923], [0.08244429099103136, 0.07423349085354036, 0.07850171908015206, 0.04293795261952666, 0.0647865312414304, 0.047738401279334104, 0.036444959095529014, 0.08336424767490357, 0.0458762790226648, 0.07879545251207967, 0.0911201601247153, 20.402151576934322, 70.77140346650155, 40.34227148179085, 47.144559583356305, 37.76062626992503, 33.60183523547265, 38.04237796414284, 26.87178150300057, 35.61258339112805, 25.909769227427823, 24.565457259455037, 31.860130294676754, 24.1058966805858, 20.257698528228268, 2.486714538066618, 1.7454239605895936, 24.19436573982239, 64.57610999384235, 56.11055651018697, 54.5721637049029, 55.802136621167584, 35.31256521901777, 1.027177246587892, 0.040296351221660455, 1.7956258861287948, 23.75571531634177, 60.26577034304219, 66.61025508757561, 65.23507602753179, 60.26021234450802, 54.26828199817289, 50.70416542791551, 52.7257118686553, 55.47877250179168, 60.275015369538345, 66.16811767701181, 61.47260519766039, 60.53749645909956, 63.345164329774924, 57.74090143942065, 51.3085203016958, 47.171635704655806, 46.55092454725697, 47.82052124700239, 55.582848671943914, 57.95786734550231, 58.2067064316042, 57.407252865452925, 54.54944925923502, 51.92239869025446, 52.65173596720542, 50.507121239939046, 51.888285836865826, 52.699785001816295, 53.19915763793453, 58.921075943977606, 60.54900469318513, 51.92641519731092, 40.44329212557885, 23.862992140554613, 5.394041009487645, 1.8263838872794182, 1.3041993591093248, 3.473707163526166, 1.125200893129072, 10.589707166917863, 17.375556615091142, 4.678854173229587, 3.7199557692773886, 0.6888046067568564, 0.18332289441698985, 0.07549935921786294, 0.026689735278787634, 0.02870629128489283, 0.06773496617472942, 0.0056781067565504105, 0.050168531766581925, 0.701865854282533, 0.11942939952977243, 0.04139279541108878, 0.0453644173760568, 0.04485384275716159, 0.07211385580200343, 0.028696163602533842, 0.0516890975526504, 0.04526364234005732, 0.24211490256411416, 0.21694980291349275, 0.6123574282373152, 0.10532293994460376, 0.6852156380491873, 0.2896985387609851, 0.8578638480074945, 1.94063235675135, 2.931939099104174, 6.332328338776866, 32.08716884736092, 46.92319670031148, 49.508552474360314, 48.71681421033798, 48.58674057068364, 45.26779174804688, 44.9518056069651, 42.90074333067864, 42.19398321643953, 42.467274358195645, 44.15801986571282, 44.331580823467625, 47.54641032988026, 49.152487554857814, 54.02129427079232, 53.4416542514678, 52.952695508157056, 48.71522957278837, 43.585349898184504, 42.327002556093284, 42.733218900619015, 44.496390973368, 43.878107763105824, 43.680820388178674, 45.078792341293834, 49.23319032115322, 57.59045108672112, 59.34222082937918, 56.35148417565131, 56.437274256060206, 55.28614490262924, 57.270193484521684, 58.99819366393551, 52.44167735499721, 36.50585612943096, 18.427426468941476, 2.1907020864948152, 0.2636384339101853, 0.12138700698532405, 0.25935397994133735, 5.870896789335436, 46.6315802451103, 57.193079686933956, 42.86641474693052, 59.3819465944844, 55.01455999189808, 45.11437216112691, 0.442250638359016, 11.805892952026861, 24.95430534885776, 20.476427539702385, 17.697455729207686, 9.736160193720172, 23.797539549489176, 33.453922656274614, 23.914696824166086, 38.77989338290307, 33.05971268684634, 37.95929824152301, 32.276140797522764, 51.16284739586615, 56.496019594130985, 38.45117915061213, 0.5802673534039529, 0.08919521099737576, 0.06166702887463955, 0.06855015267407702, 0.007305892293281373, 0.028003677575578614, 0.20253238057897938, 0.03536956700225992, 0.05641291060695245, 0.037155406053868995, 0.02942087511802393, 0.03657236334777648, 0.033401341568077766, 0.08982197817174659, 0.11639668726392331, 0.13652440641195546, 0.11774048975278294, 30.961105400516143, 81.53752511547458, 50.61265260942521, 46.872429463171194, 43.97918332007624, 31.655600263226418, 44.28053117567494, 27.908728699530325, 40.21359812828803, 24.92087498787911, 21.640059448057606, 24.095775004356142, 26.857041235893007, 25.471813063467703, 5.000069814343607, 2.605613345100034, 26.251833246600246, 70.92605467765563, 57.20772973952755, 59.96589729862829, 59.97414996547084, 39.324243837787265, 1.6419096699645443, 0.02618744973123314, 2.641153696083254, 22.598467065441994, 62.864646527075, 68.0437558697116, 66.51554553739487, 60.644945867599986, 57.9558708590846, 54.26727787140877, 55.04168710400982, 60.02480345387613, 63.397382843878965, 65.6610454282453, 63.18985023806172, 64.65771882764756, 64.88003484664425, 61.77304698574928, 53.62804920442643, 48.53988393660515, 48.42566059481714, 50.41602419268701, 58.602344143775206, 61.091903871105565, 63.341167434569336, 59.3544311677256, 57.46622177862353, 55.3883187232479, 56.270373482857984, 54.52247511956, 54.38841242944041, 55.50436204479587, 57.25384896801364, 57.87633695910054, 61.54591821855115, 53.98060752499489, 43.52664378381545, 29.94595677621903, 8.216407472087491, 3.2297374548450595, 0.8631657280268208, 4.800975697655832, 1.0702792531059635, 11.614350868809609, 21.672067949848792, 10.207034849351453, 3.345934239126021, 1.0230036608634456, 0.07846097852433882, 0.0848557748982022, 0.051780913190375415, 0.04657675917710989, 0.061695768663118926, 0.03361011584920268, 0.09740162911193986, 0.45477522597197567, 0.4035730653953168, 0.043458271876818715, 0.07728402998538748, 0.047811137497304916, 0.0279135798900238, 0.012756704593137389, 0.03208232776922805, 0.02596687769607431, 0.33410363019474093, 1.1909975496030625, 1.4830757413179645, 0.4628724382529336, 0.8085516263400355, 0.9891532385541547, 1.8914428930128775, 1.987387744649764, 5.221591063084142, 15.28474013651571, 37.695644363280266, 49.89498830610707, 51.369199368261526, 51.075857070184526, 51.03870437991235, 48.109576394481046, 47.91005719092585, 45.251478610500214, 45.737362215595866, 46.78368976039272, 47.04719066619874, 47.80540443235829, 52.54538874472342, 52.81924470778435, 56.265254789783114, 54.95542633918024, 54.304548232786125, 51.91470299997638, 46.4270168735135, 44.102416346150065, 45.664284536915446, 46.24532092002131, 47.6624575737984, 47.07169763503536, 47.07157211918985, 49.72699711399694, 59.51178096955823, 62.650665544694476, 60.231300553967884, 59.2019647167575, 60.67816049821916, 61.73052064834103, 60.03559781659035, 53.90656494325208, 36.6261826792071, 15.533809661865236, 1.1791695197743755, 0.11641698859391675, 0.18955688893554673, 0.5199186852382076, 7.698699716598758, 51.91165924072266, 62.131512395797245, 50.345245022927564, 62.974872973657426, 60.13805012549124, 43.536304581549864, 0.40378763130114925, 21.204290005468554, 34.63317148147091, 19.18598932604636, 21.935637497132827, 13.813967031817283, 27.190891811924597, 44.09180241246378, 25.029230463889338, 39.02782640149517, 32.35534521841234, 44.29559307713663, 36.6358591664222, 52.63810573085662, 65.92429530236029, 46.06022819395989, 0.7617152169827492, 0.05663861926164358, 0.04314835100705105, 0.040714202388640375, 0.07029586787065191, 0.005613361314434799, 0.24754982141237108, 0.1499805109755647, 0.23342600993571744, 0.23753694498971586, 0.2246257740884058, 0.200772293572945, 0.2129316104636077, 0.280926494949287, 0.25959529763748573, 0.2697971679510609, 0.3656726426655247, 41.17018184354229, 96.08926742307602, 60.07270736079062, 61.29816955135715, 51.41723663576188, 43.44194804468463, 51.550459938664595, 35.0299859046936, 48.574067392656886, 35.46827547011837, 30.844434499740604, 45.22159407215734, 30.263825654983524, 30.566703234949422, 6.928994876723136, 7.5136550395719475, 34.861559329494355, 77.38971279513451, 67.87987924391224, 66.92284445608816, 66.21016548525903, 44.49169197390157, 2.064145096848088, 0.21291710075832185, 3.5875230691125317, 27.147253482572495, 66.15188690923875, 71.70146019228044, 69.64920551546159, 65.48541738140968, 60.13437878700995, 57.38819799115581, 57.39279893136794, 62.70253104548301, 67.2050589899863, 68.96805455607753, 66.37815275499898, 67.42100900219333, 69.8844849678778, 65.08784201837355, 58.3236244417006, 52.50969125378517, 51.0173745309153, 52.84918415930964, 61.13027641850134, 64.9460679484952, 65.85191972794073, 63.751612094140825, 61.09430436165103, 58.2249846766072, 60.09183283775084, 58.14099496410739, 59.258082066812825, 57.746326077368956, 57.18954170903852, 60.941751618539136, 60.914114598305, 57.549987916023504, 47.48028701351535, 37.71405204649895, 14.990048543099435, 8.967157948401667, 6.8789915211739086, 9.83391938670989, 2.6509395193669105, 14.850475903480286, 35.48564372524139, 22.370938216486287, 8.442934155464172, 2.5422217144120127, 0.17881975298927677, 0.19465174135421554, 0.22468113160181433, 0.19373001500723824, 0.16697715216827008, 0.15690960771133824, 0.17381018147833888, 2.012222231395783, 0.19799694088437866, 0.11537676376681175, 0.1989933608039733, 0.14455938170994484, 0.14867456089104378, 0.20904464887515192, 0.15054035270887037, 0.08359982737249906, 1.3269358681094263, 2.973071279064302, 5.1794726521738115, 1.6760481413333648, 0.6925513282898934, 0.7522229585916765, 6.842209004586743, 8.968297396936725, 16.858137153810073, 27.455471369528002, 44.693329257349816, 55.2338832424533, 52.585687175873794, 52.22378576955488, 53.29966445122996, 49.70329423104563, 50.59506077920237, 49.14101462210379, 49.724357358870975, 50.44498305166922, 49.78775070559595, 50.046564379046046, 53.67014408111573, 54.80894150272493, 59.747162403598914, 58.19481380524174, 57.850496384405325, 53.965137697035274, 50.80442905426026, 46.75869641765472, 46.88141953560614, 49.03327888058078, 49.89350172781175, 49.88734752901139, 53.74897979920911, 53.04760902158676, 63.38747493682369, 65.9996832570722, 61.701224465524, 60.31740442399056, 60.269131814279866, 62.34564242824432, 61.00157953077748, 54.994375474991344, 42.54683571477091, 22.553255865650794, 3.955649522043044, 0.37267971183023146, 0.6420288102761392, 0.4868471291997741, 7.932219005400135, 55.35302915880757, 65.60381804743122, 55.65119204982635, 67.16286213167253, 64.97880012758317, 53.87641760610766, 3.301827676834599, 17.407778886056718, 32.62077985271331, 29.35646180183657, 27.415267075261763, 12.529668308073475, 38.79239005427207, 48.543190494660415, 33.52142664694017, 52.847419092732096, 43.96547071395382, 53.800833532887125, 42.226076049189416, 67.37696862989857, 75.74511005032447, 60.88464583120039, 1.0252795548688982, 0.14856672635482204, 0.12069747422731693, 0.15080773271620274, 0.27943044780723514, 0.11046070860879076], [0.05652183298802665, 0.04229898166452204, 0.04031187216300638, 0.06971092143606755, 0.024139007230499582, 0.07209255855770842, 0.03361350578826762, 0.2090257265034222, 0.14785153731223077, 0.21347937865122674, 0.18370282806215749, 20.114751669668383, 70.49561377494567, 44.92482754491991, 28.210555084290046, 27.14662786453001, 46.40559288763231, 37.37064853791268, 38.88590720392043, 32.44889178583699, 26.6274433366714, 26.610998799723966, 31.603246427351433, 22.033612420482022, 26.210467930763002, 9.065690828907876, 2.6281623157762715, 19.775527446500718, 56.84511053946711, 55.73233019921088, 47.480192876631214, 54.72265720367432, 43.75267428736533, 4.361507459994286, 0.11783930743413588, 1.033201210441128, 14.646754860877992, 59.994208966532064, 67.19748097081339, 64.05393661991243, 59.464084948262865, 56.59780902247275, 51.93136915083855, 56.475360470433394, 58.388531823312086, 64.0353641971465, 61.8285838250191, 62.895056663020966, 61.140219626888154, 59.963822364807136, 58.778917481822354, 53.15130864420245, 49.54630136489869, 47.477176573968705, 48.55878583846554, 58.18916951456378, 55.536168544523186, 56.395469634763664, 54.2926359945728, 57.70529808536653, 52.93235017407326, 51.14640874247397, 52.185621107778246, 51.68163184196719, 51.195465826219134, 56.78304295386038, 52.45033402596751, 59.358969350014966, 47.98710430822065, 38.04510793378277, 17.7615943262654, 4.578083580540073, 2.0092835181182434, 3.975580800925532, 1.550850498099481, 0.23764911558358903, 0.2837842480549889, 0.16440492003194748, 0.47031939510376225, 0.11286171243315744, 0.01814311092358924, 0.01575448612246903, 0.011036917642359773, 0.013067008506867194, 0.04883116441628626, 0.06384376045917312, 0.02626013423826906, 0.03366430124808704, 0.8018762426030251, 0.23459411015914333, 0.04453444921021019, 0.027678938650135553, 0.03745853555418792, 0.061166846238437204, 0.031663118711402344, 0.013622133053779123, 0.07361894278156181, 0.07580809265134797, 0.14348785453025373, 0.035410843819620154, 0.21049189621642714, 0.07195899112811012, 0.15605646155534253, 0.3259302381305926, 4.269018461627345, 3.2894859390874065, 6.665745002608146, 16.217922010729392, 40.55453446603591, 50.096362790753766, 52.1897788201609, 47.64844294517271, 44.54211796483686, 44.117709667451926, 40.77369297704389, 42.58885214405675, 44.54040388907156, 44.92437647235009, 46.31396632040701, 48.862208627885394, 51.298832047370176, 50.83015980259065, 52.70271108996484, 53.83859026816584, 49.80529154500654, 43.48831830486175, 41.66755407087265, 46.069147663731734, 45.509339147998446, 48.46391154873756, 44.48683607962824, 43.68447603717927, 43.9944766413781, 54.91532010416831, 59.141234659379535, 59.199889782936346, 57.62011204996417, 61.67345016233383, 61.3448614458884, 62.28330812146587, 54.93966625582788, 23.921317785016953, 8.82540447096671, 0.5455578094528568, 0.18952920251796324, 0.7819659238861454, 2.519462161487149, 20.315429933609504, 45.747740807071814, 61.26153853631789, 43.856087576958444, 51.63994489177581, 62.423611302529615, 20.579887897737567, 0.10014389446305652, 25.14886079295989, 23.02236741588962, 26.33853331688912, 10.132457844672665, 12.231847643852236, 28.78432135428152, 24.7223206873863, 25.499775640426147, 36.560380997196326, 35.224555077091345, 30.478234175712835, 24.982432665363437, 42.13077422111265, 56.92662131401801, 30.732948972332863, 0.3120967126902073, 0.15419013347596894, 0.06308283979794191, 0.06398466701108603, 0.0941227651351402, 0.07711210453342046, 0.04718698268275588, 0.011299315205354606, 0.03696407559477995, 0.07508908083001453, 0.08748196260703188, 0.11103578017003114, 0.08111502885097459, 0.06366404772345578, 0.21365066058933738, 0.21025808618193675, 0.38642195023355946, 26.604389605983613, 78.29798467697637, 56.933097147172504, 29.75138956500638, 32.88018580405943, 42.015899765876036, 41.57009493920111, 35.41795538317773, 36.72236311820246, 32.571711001857636, 21.91902037589781, 20.91241663502109, 23.286350773226832, 36.225320369966575, 8.894140085866376, 5.888733277397772, 23.596359222166, 66.53007399651312, 61.57544582120834, 54.25968808512534, 61.09278640439434, 50.22198454026253, 5.752905030404368, 0.03249389510000906, 1.2620287316460765, 14.693316336601013, 62.367395893219985, 69.3336586798391, 65.28732199822703, 63.04347915034141, 59.331410777184274, 54.92197244398056, 59.13221713035338, 59.777078320903165, 66.06636355000158, 65.1435592866713, 65.06200928841868, 61.72810446831488, 62.857315617222945, 61.284394187311975, 53.25918951342183, 51.424253756000155, 47.834022045135505, 50.47382423954625, 60.45815867762412, 57.92304846548266, 60.1902804067058, 57.35673273763349, 60.44617975911787, 54.99398323797411, 53.571280740922504, 54.43211940027053, 53.75939369201661, 52.42701161292292, 61.22095377214494, 55.130152240876235, 62.42453305952011, 46.68397134350192, 41.983752019943736, 22.99651115171371, 8.66379693631203, 2.854685567079052, 3.3017663898006564, 2.0105598818871284, 0.19422788022746965, 0.2580165742866455, 0.16918668763772135, 0.24705583259703653, 0.1348409435201076, 0.06536110484551999, 0.012453650744000991, 0.00830679478484296, 0.04098104613442575, 0.0878406832775762, 0.07783647130934462, 0.028199878438646277, 0.09903567933267164, 0.35942504242543255, 0.49694658887963145, 0.08953962114549453, 0.07143288790698975, 0.09488725959653817, 0.05400027373745557, 0.02381637504684829, 0.052993940640120744, 0.11403568089008333, 0.12689307241910888, 0.08844904902000582, 0.06429724620595094, 0.19628278851028413, 0.0834209151986626, 0.07975413494052426, 0.7675982819449517, 6.661632887778744, 5.734566969256248, 13.08229692520634, 25.624163804515717, 44.66156198132423, 52.092970801937966, 53.382391160534276, 51.4820263462682, 49.434121577970444, 46.87650088341006, 44.726351691830544, 46.11682015080606, 48.50639866244409, 48.7143313500189, 50.669625036178104, 51.68268303717337, 54.244006449176425, 56.77124054201188, 54.66264101766772, 57.19797872727918, 52.114402632559504, 47.087010568188084, 43.990189490779755, 48.304671164481874, 49.4914391732985, 51.72378947657924, 47.65884899323987, 46.95676434424616, 46.488390199599735, 53.69942457445207, 60.22444425090667, 60.71425414854481, 59.0607633129243, 61.687970776711744, 64.11137188634565, 63.436837965442294, 58.302494633582334, 27.735638426196193, 10.588291191285657, 0.660892591601418, 0.10160067959898904, 0.49354877443082873, 3.109538382099521, 24.44625250754818, 47.99464310369184, 64.80304264253186, 49.90683778639763, 58.21229580909976, 73.45310441909298, 21.730768180662587, 0.9358792391515548, 28.123502000685665, 26.823722662464267, 23.788745595562844, 15.509301712436063, 12.788874218540808, 34.99617115143807, 31.44588093603811, 24.627054160641087, 37.61647132135207, 30.896613790142922, 33.98722379438339, 23.767337299162342, 48.5826652280746, 70.13269255238195, 35.26633224179668, 0.17323121819044315, 0.16289571149935647, 0.06499235608404683, 0.04113978721321591, 0.05117740827582536, 0.1368943502705905, 0.2369005404292576, 0.15750059857964516, 0.20314008748579412, 0.12713720165793935, 0.1604592914302503, 0.32240693847979274, 0.22703231672846505, 0.26147107924184493, 0.26897558461754556, 0.3779915816360905, 0.5326201165876081, 36.86551786238147, 92.18726219669466, 69.20438520369991, 40.8719640393411, 36.94489486755864, 57.18521533473846, 50.593570278536895, 50.98006102346605, 44.984573087384625, 36.15120326319049, 34.93576272841423, 45.25816625164401, 29.806947977312152, 34.67195980010494, 15.489520219064529, 8.23762063057192, 27.589057491671657, 70.71006544174688, 66.32508308656755, 61.44450141537575, 65.03592552677279, 53.444219481560495, 5.4434736601768, 0.1545004297288195, 2.2793005839470895, 17.099025595572687, 65.09561223368492, 71.71472564820321, 68.091247927758, 66.20948299284905, 62.762900244805124, 59.098017984820956, 62.550115585327156, 62.40730993209347, 68.17962677248063, 67.99740914375552, 67.04999200759396, 62.85703712894071, 65.06417051438363, 67.10757240172356, 56.31360976926742, 55.81530009546588, 51.64332597486435, 54.58185980396887, 63.931727332453576, 59.49844883334253, 61.72126385473437, 59.06163015673238, 65.44953161670317, 58.25329634451098, 57.29155863485029, 57.510156246923636, 55.805733434615604, 55.11745552862845, 62.71807932084607, 56.97316023611254, 61.30841870461742, 50.70012146426786, 45.87320566177369, 34.45023213663409, 16.096108882657944, 8.070113851178078, 10.974876073098953, 7.508196080884627, 0.3913061284730512, 0.3012576410847326, 0.27371046764235346, 0.7039226471416412, 0.6495046026764378, 0.1610180453187035, 0.1302945947334651, 0.09592426685436119, 0.16066060401499271, 0.21177708531820008, 0.17457859830990916, 0.1569421204828447, 0.3634302726676387, 2.0948910857400587, 1.4565334300841055, 0.39538024534140864, 0.18141289932593224, 0.21540898559314592, 0.14215362047956837, 0.19343588320959001, 0.19041575010745757, 0.15621997536190096, 0.2661492411167391, 0.16014047627968175, 0.18481678119109524, 0.33695681741641414, 0.18148425275519972, 0.17894543737413424, 3.3813934460763013, 14.630327974596332, 17.23463958309543, 23.782956177188506, 35.63002617128434, 51.853678764835486, 56.40925676591935, 54.75700147690312, 52.847368101919855, 50.396981085500414, 51.27448589571061, 47.496070631088756, 48.16678024107411, 51.77325448682232, 52.10593815772764, 51.81038756524363, 55.890719429139175, 57.32862895534885, 57.84367930504584, 57.62966694370393, 59.92584597679877, 55.1859087328757, 50.10390158622496, 48.25745759471771, 51.84775598587529, 51.620811570075254, 54.873731213231245, 51.432690774240804, 48.03558088118031, 49.23567318147229, 58.169510595260135, 64.37843822663831, 64.15008960231658, 62.03922687038299, 64.92696208338585, 67.97170192964616, 65.96186376387074, 60.603729601829286, 29.86488138475726, 12.982048988342287, 1.72468516374788, 0.9846569765960017, 2.216062661140196, 4.604055064339792, 22.855882413925666, 53.86430924938571, 66.85171619538339, 55.1981229935923, 62.81385183334351, 71.12412652661725, 27.95747003247661, 2.4610749848427314, 32.494724681300504, 31.134070158004764, 36.67156842447097, 17.168494693694576, 15.17228284189778, 42.84560657316639, 34.273768624951764, 34.012275972673976, 50.19157832668674, 45.84666298281762, 42.41290638523717, 33.329407015154445, 59.28628783072195, 82.90138813757127, 45.590587123747795, 0.3529603635111163, 0.2971224210435345, 0.12154407033156003, 0.20307231934801226, 0.17378712223181803, 0.2420716492399093], [0.019880814755695964, 0.03589213855804936, 0.06506537958498924, 0.06671510396465179, 0.055767163604257576, 0.10013612633150432, 0.08869848724815155, 0.022913134401483883, 0.09024386279164784, 0.190402512108126, 0.36430300003097904, 14.543697526378018, 65.01513304248934, 44.766246118853175, 41.894012112771314, 37.60578286263251, 37.975976159495694, 39.56989403693907, 34.66988486628379, 40.80915120340163, 24.442263457082934, 17.870912744152932, 30.43893987132657, 23.64636551949286, 12.349556011538352, 6.703366906412187, 3.3027908638600385, 38.831668669177645, 53.14969655006163, 59.564560382596916, 50.2870645061616, 60.58521601461596, 54.47137448095507, 12.848976696691206, 0.06746861272521558, 0.9473507623037986, 11.705692083604875, 60.04388186239428, 67.43593754306917, 65.24987513019194, 60.58793813951554, 59.0415515438203, 53.24693995137369, 58.15646871443718, 60.166726573821045, 64.29473484716108, 63.497364059571304, 63.93747360475602, 61.83010178227579, 62.33473039442494, 56.49074792861939, 50.01017655095747, 46.823525351862756, 48.84727224226921, 48.71617094162972, 57.41046920899422, 56.81363351883427, 60.466866339406664, 58.52380260344475, 54.537454651248076, 52.014990160542155, 52.26291925676408, 49.7050985213249, 52.76565336412, 52.93313857047789, 53.646802056220274, 56.349668118261526, 51.11203701265397, 39.52610469633533, 40.49710704434303, 15.469434742004642, 1.3014275917122442, 4.42458015295767, 3.2000777173426846, 0.19934553142276504, 0.04732318928525333, 0.058876990280564756, 0.009830675816403763, 0.09567669788075071, 0.057752323412005944, 0.0864859487140371, 0.040799387535380746, 0.010340388586384155, 0.024199032134586768, 0.02955861964202937, 0.04840367969365851, 0.0890135792114081, 0.05506731164191039, 0.2364211992150353, 1.1932141790466926, 0.05542837654150302, 0.0678252189930889, 0.13400613750901916, 0.06792501726698491, 0.046291502508064436, 0.04880756890821842, 0.025876835551894, 0.018399005357716835, 0.02163611179698379, 0.01602327094353255, 0.010679075100098648, 0.0663454742020657, 0.03865910258384482, 0.2156430407757721, 3.752215793055873, 5.58615428786124, 6.037441607444517, 10.522267895360148, 31.488599469584805, 45.87112680558236, 46.79067157929944, 49.06078254022906, 46.55778869505852, 43.0675813459581, 42.026917703690074, 42.80999537437193, 43.519736489942, 44.44368608536259, 47.396148250949004, 49.112906917448974, 54.35276985168458, 55.54929671748992, 51.84746573048254, 53.01026805754631, 50.22693849379017, 45.07983569175967, 43.06953468630391, 46.16405725479127, 49.309323526197865, 49.5757701320033, 49.17489213328208, 45.52398527822187, 45.06759789682204, 48.1576568080533, 53.82224967402797, 57.78973102569581, 57.94625712979225, 58.787397646134906, 59.75217127030896, 61.593547559553585, 62.33540896446475, 33.65188075650123, 8.633961427596308, 1.0694725931652131, 0.12168252540211524, 0.2551738977912934, 3.93868453560337, 40.265589144922075, 54.97106482905727, 54.006177456148215, 51.24171449292091, 55.74343835153888, 39.216814041137695, 9.145278661481797, 1.1292643460535234, 34.96183864531979, 27.791457676118423, 32.330344030934, 11.911113473676867, 20.435703531388317, 25.339231068088164, 38.009422209955034, 33.88946656257876, 30.529372076834406, 30.220332453327796, 37.451272856804636, 34.38790959696616, 49.18761630212107, 58.03258849728493, 16.125458998064843, 0.3479104038448103, 0.04785304633720268, 0.05806143222857387, 0.011563695020853512, 0.08062297057720923, 0.09062282350515166, 0.06929372527426289, 0.08165869080731947, 0.038060155892444235, 0.08283500349329365, 0.08326794276194227, 0.15973228931186662, 0.0586021141028933, 0.10117634349773008, 0.1944683399051428, 0.2517453325732101, 0.33548234331031, 21.05980165543095, 79.21302656973563, 55.84052878041422, 48.81698369979859, 42.957853040387555, 41.39482382805117, 44.61547805416969, 34.78144884109497, 38.51669057723015, 31.021835457894113, 20.19323633563134, 21.802871150355188, 15.305105082450376, 22.175763037896928, 11.594052603167873, 3.520382878280455, 41.087855215995546, 60.622470686512614, 63.27241613018898, 56.74561962004631, 64.98278917804842, 59.65810106646631, 15.319475666169199, 0.14895715540455234, 1.437730200348362, 11.893787384033205, 58.666937735772905, 71.25758909410047, 67.98186086839246, 64.13708694519536, 61.69047324888168, 56.528590956041896, 61.2792480376459, 61.729206654333304, 67.50873673346736, 65.24303451661142, 62.90922426408338, 64.52949654671454, 65.43927854107272, 60.98128126513574, 53.813369427957845, 49.99291812219928, 51.09667701105918, 49.184968702254764, 59.03705650760282, 59.6048862703385, 63.43745377755935, 59.01543248084284, 56.035898116327104, 56.29504911361202, 55.928962538319254, 53.73595360786685, 54.72489295467254, 55.36185449169528, 59.18460430637483, 57.3063773493613, 54.631340503692634, 43.95448807747134, 47.55140350710961, 23.40132721008793, 4.156568031157217, 4.266641505302922, 1.3830524827203443, 0.14016721577894303, 0.017432340293101246, 0.12083229804111105, 0.11216177620113858, 0.059723111410294814, 0.03712318822621338, 0.06650102835509085, 0.07355865932280019, 0.07637882049405768, 0.029903177262073564, 0.04588285971793436, 0.060453978442256494, 0.10151150696460279, 0.013518626914329588, 0.09074120707209073, 1.1345145611032363, 0.032430225532622106, 0.050417495020214594, 0.022003115793209405, 0.042578848905020186, 0.003095175723560275, 0.06597289500097114, 0.04896776938450433, 0.06183707358075246, 0.06312167662526331, 0.02786845922650349, 0.011978079639976064, 0.1287714434006522, 0.08973223863229637, 0.17634113679730123, 5.494752766624575, 9.109102641382526, 10.440345271941155, 17.738511177801318, 37.55738081470613, 50.233512386198974, 49.98193156334662, 50.226401129076564, 49.08471292065036, 47.453485458127915, 44.43880273449806, 46.12621814973893, 44.948295085660874, 50.05450325627481, 48.958926431594364, 52.73148951991912, 56.43173979174707, 55.51789029952019, 54.856798341197354, 54.1535722824835, 51.88107259811894, 47.67728413304975, 45.03100218311433, 49.65371939443773, 50.94158649444581, 53.274102364816976, 51.27180299451275, 48.576314910765625, 49.634860638649236, 49.888539929543775, 55.60382158525529, 59.93087445535968, 61.231995244180005, 61.018324129043094, 60.818432300321525, 63.45073100059264, 65.81513574046474, 40.59534280530868, 10.564618706703186, 0.8807622773512718, 0.14500961158304446, 0.28838733331330363, 4.96622613360805, 45.90918556336434, 54.425192494546216, 58.437220204261045, 54.22240987900765, 59.52555241123323, 45.21172146643362, 7.671214197912525, 1.9720311751288755, 38.429025603878884, 30.899273157119755, 29.989910856370006, 13.165670825589089, 17.77594823991099, 36.01954498598653, 36.18695958968132, 29.33476717241349, 37.772946434636275, 27.372832913552564, 40.66022273032896, 35.05904674530029, 55.02515823610368, 70.89117696208339, 21.52286687204915, 0.3385382373967479, 0.045534542521401766, 0.05942901025616354, 0.035069375449130614, 0.13017461004276432, 0.04169464171413453, 0.27679329738020897, 0.17389434389770034, 0.17540482413624564, 0.27205700475362044, 0.17504871582552312, 0.28867617910427434, 0.29037854904609345, 0.23747882955977995, 0.2940956995852532, 0.3430452552293578, 0.6026893373458617, 28.564650973966046, 93.4591377935102, 64.7691886655746, 56.991340421861224, 49.83665089453421, 48.5021468131773, 52.55957988000686, 47.3650634673334, 54.505310827685946, 33.897911425559755, 25.32380242501536, 43.23179137322211, 33.17705823529151, 18.77837073418402, 13.55582800603682, 8.702162619559996, 48.00461376866987, 66.31085272758239, 72.04295742896296, 62.2748318795235, 71.47026784958379, 64.5182942575024, 16.108023082056356, 0.26287277499514244, 3.0580055473312258, 15.137808149860753, 64.47096693900325, 72.2678896688646, 70.08429050445557, 64.90087439936977, 64.62852070408483, 59.27073171061855, 66.31366114462575, 63.94061934563422, 68.87729091029014, 67.7888096532514, 67.96144100927538, 66.98396282811319, 67.87467818106374, 64.29710003637499, 57.16879629319715, 51.443116434158824, 54.92670282240837, 54.20470822241999, 63.5183761965844, 61.75591799520678, 67.80041202422112, 64.10834381657263, 59.80639411557106, 58.13994769127139, 57.76978185099941, 57.96063261647379, 60.97848461520288, 57.07983301531885, 61.725209759127715, 56.53990699398903, 59.86031886070006, 38.55270185778218, 53.57996486848401, 29.04680636621291, 11.551186000147174, 9.385759176746491, 10.06877032018477, 1.8016028428269972, 0.23195818547279606, 0.24125833965597615, 0.18248816501469384, 0.24701853943688257, 0.1267652123445465, 0.17557858819923094, 0.167686365725052, 0.18310246027765736, 0.08657689101152843, 0.07625317441359644, 0.1520865173229287, 0.20721870895114639, 0.11033858653278121, 0.4776049525507035, 2.643359048712638, 0.1448942693851648, 0.20532475574122322, 0.2819139516401676, 0.23862310444876073, 0.11560255286073494, 0.2127441334267778, 0.09724157036191995, 0.1281741093243322, 0.12103823013603689, 0.1607482751170474, 0.09158612544377966, 0.3092980096417089, 0.1851267863305346, 0.8286024762257453, 15.136523573629319, 16.738993198640888, 20.86715836678782, 29.205256392878873, 44.69959720488518, 54.048911679175596, 51.04566266459804, 53.18543718707178, 51.60555747247512, 49.3324694325847, 47.03885955195273, 48.3672212016198, 49.6418934483682, 53.335001084112356, 52.724943084101525, 54.58615872167773, 59.28121620608915, 59.874737493453495, 58.033212154142326, 56.470649703856445, 55.07562737311087, 52.145954178225615, 48.59213382967057, 52.659835661611254, 55.1713449724259, 54.8498635907327, 53.634105343972486, 52.32248437020087, 51.12463958801762, 52.009538066002634, 59.66990740068498, 61.459198536411414, 62.530491967355054, 64.66176279129522, 62.80946270112069, 67.60376007326188, 67.12786674499512, 39.61934335770146, 12.698071349051691, 1.7540280472847725, 0.33509749138066847, 1.3529644714247797, 6.653794030989371, 45.82267768921391, 64.8303266494505, 61.99232316786244, 60.138967960111565, 66.35297113849272, 47.777559526505016, 13.77303219610645, 4.328267824265265, 44.66969305469144, 36.29021206209737, 42.613178683865456, 16.15160159526333, 30.369392325801236, 40.20377259100638, 51.034464297756074, 44.78233175892984, 44.63019870942639, 40.183309585817405, 50.95611495356406, 48.993262860082815, 65.59069771920481, 82.25580523090979, 31.474971194421094, 0.34886118024587637, 0.13004990625044993, 0.14598183844599033, 0.10319965831454724, 0.26842311265007146, 0.16107465921630784], [0.08590883935891813, 0.048601472104388865, 0.06384323568894498, 0.1709941954862687, 0.02250028004299008, 0.0667606019264748, 0.028765910162380146, 0.04890551324933768, 0.09818305411646444, 0.19046450394295877, 0.2079706089270692, 12.398026700942749, 65.34094864322294, 49.8410870951991, 25.821886562531997, 28.67889588879001, 32.78288748956496, 36.87540223521572, 34.57906630731399, 46.21326731097314, 33.563317560380504, 15.268482892744004, 14.529693684270306, 52.3766601470209, 19.443449781787013, 14.057462869151948, 0.8226867452744515, 20.262789764711936, 61.89218897973338, 52.081635152139974, 52.640882768938624, 58.8210908059151, 56.8379992823447, 22.32456011156882, 0.09354097498280388, 0.572691785712396, 6.57527651517622, 51.687131004948775, 73.51512493625765, 64.47564240424865, 62.49345694818805, 60.295019457417155, 56.71744915746874, 60.17657564532373, 60.67351248956496, 62.97732445501513, 60.8259161826103, 61.229269196910245, 63.62903410388578, 62.064177067049094, 59.89113300077377, 56.2873024325217, 48.77963489101779, 49.62527828831827, 49.82976321251162, 57.691558022652906, 56.77054628249138, 58.836160552117136, 53.85641351822884, 56.85224925318072, 54.604597783857784, 49.77504222623764, 48.970191478729255, 50.271202441184755, 54.55233612368184, 56.30036392519551, 50.92424177354383, 57.460769684084006, 60.72115752004809, 30.218249674766298, 10.667526991136613, 3.5771927718193304, 5.457408370510225, 1.1237400553880201, 0.10584250077485077, 0.032979372678504836, 0.15842151287342274, 0.05985109405892511, 0.05706086011242963, 0.02345850090346029, 0.05533587525508577, 0.015645324338918493, 0.10485960230711969, 0.0664817076176405, 0.034694861876027244, 0.07126824029030339, 0.02082793883258297, 0.04459644870592221, 0.1741737668072024, 0.2774650032722181, 0.07469811551873723, 0.12210155251405894, 0.04131776475978475, 0.057807715399371046, 0.06563050732497247, 0.02967858326531226, 0.05864672340272416, 0.03231407894242195, 0.07719709432774013, 0.07316101372482316, 0.017638205355333707, 0.08176848652862734, 0.10315215320236261, 0.06070432831503211, 2.04707776106173, 5.205181337171986, 7.770769346144892, 7.061064022202646, 23.02569162461066, 44.107319308865456, 48.954254888719134, 47.89929028480284, 48.09002337917205, 44.34517968085505, 43.038347921063824, 44.83193405212895, 45.097207869252856, 47.42008255374047, 48.739767920586374, 49.64172086408062, 51.86939962448613, 52.09711282483993, 55.10736327017508, 54.254012415486, 50.21587740990424, 42.862649271565104, 45.132709241682484, 45.6843396156065, 51.443971510856386, 52.26603361868089, 52.255921748376664, 47.39994118290563, 45.557086160106046, 48.910669511364354, 48.29211565756029, 49.889395006241344, 54.81798648834229, 56.31369998378139, 61.367866146949034, 58.64540784589706, 64.89237854557653, 48.5426256733556, 10.577988105435526, 0.3933336261299349, 0.10230465311436884, 0.679628344312791, 14.074505567550661, 47.878540946591286, 55.48993556730209, 58.802220283016084, 48.559503632207075, 29.152539737762947, 42.144620187820934, 3.2394075682086334, 3.4488800312242205, 47.14922328149119, 21.874654446878743, 18.88798725220465, 11.824445762941915, 32.62345490917083, 23.682492509964977, 44.38300309642669, 31.750150957415183, 25.47602765021786, 30.023235313354004, 43.0513152768535, 33.331991857098, 46.67401636800459, 62.99859939082977, 12.349208881778102, 0.4595953592609975, 0.048782023706383286, 0.11528514731194704, 0.057545039171893755, 0.08171414025127888, 0.007181910060030679, 0.06930209095439605, 0.05880040447077444, 0.041919726007167375, 0.05031711834993574, 0.03835547512637512, 0.15145616485707222, 0.08535109670652498, 0.18217362463474276, 0.10113977046022493, 0.13619877307886077, 0.4202157126799707, 16.651108572559973, 75.69327200612715, 59.79269719892933, 26.727481426731234, 31.836370537357947, 37.20970976737238, 40.239168059441354, 34.25307419992263, 42.17230035412697, 37.48535433123189, 20.13430468497738, 11.87896082478185, 22.5653406881517, 16.584914653531968, 21.59716440785316, 1.6291741017372379, 20.02621985250904, 66.48005593207576, 57.837893809041674, 58.01236475667646, 63.70444559281873, 61.89105933712375, 26.505481158533406, 0.06612841084960007, 0.09602538279948697, 7.0952406141065785, 53.165115387209006, 73.75195764726209, 67.4863007760817, 64.90379264277797, 63.09366587669619, 59.0494708091982, 63.14888892635223, 66.24131694916757, 65.28590210022466, 64.21315739231726, 64.00005109848516, 63.59474082146922, 62.84989057048675, 61.04305859534972, 58.50859165191651, 53.20135808760121, 51.678748899890536, 54.10762563828499, 60.220710154502626, 61.05677120147213, 60.874075043586, 56.69329520194762, 58.66367040141937, 54.66919529822565, 53.92862435310118, 50.94903115303286, 55.862662715296594, 56.68166145201653, 57.730942541553134, 52.52309399266397, 60.823837326418975, 57.72597682091498, 36.869306871967936, 15.473327694400666, 4.318895320738516, 6.88935540376171, 0.9057953340872642, 0.1233881282349748, 0.05289651723878999, 0.11519608959074944, 0.12640055449258897, 0.04117632194632485, 0.08387556539908533, 0.02226271809289052, 0.08247579252647777, 0.02978218899619195, 0.08031400731734692, 0.05130677371315899, 0.044554336852724516, 0.02474829419365814, 0.0638671682756995, 0.19584120010897038, 1.509624916699625, 0.19655802857971963, 0.1352401979027256, 0.04148562228487384, 0.07832718126836323, 0.057177182902852376, 0.028127908308599747, 0.057205635408360156, 0.0644924454090576, 0.022895273061529286, 0.07838417054905046, 0.01475441579391519, 0.05177968744969657, 0.038536597463873126, 0.19312727235017285, 2.1880167338155934, 7.316245580873183, 12.151932293368924, 13.353363102482213, 29.6397118414602, 46.18415940192438, 50.71148849302723, 52.80271583987821, 51.011785153419744, 49.60714124864148, 44.86092821244271, 49.03982531639838, 49.08344991745488, 48.92504107567572, 51.65341038857737, 53.94205847094136, 53.815918968569854, 54.07088871925108, 57.155538682014715, 56.11323156664449, 51.9504475593567, 45.63353707713466, 47.87736031316942, 50.39991894075948, 54.17578074239916, 55.11547080932125, 57.205741097850186, 49.98777981727354, 47.975796115013864, 50.51073374286775, 49.82834723687942, 51.58356082054877, 57.710722723314845, 58.39631380573396, 65.04192675313642, 61.96069709716305, 69.00797643969136, 51.547518161035356, 11.476755103757306, 0.8462274627339456, 0.1174914958556333, 1.310584364879516, 20.79911308903848, 53.86503096549742, 60.56633372460643, 64.37570825699838, 50.31431713411885, 33.7120577596849, 39.91963217335363, 1.9076691255454097, 5.326827764511109, 52.35084702891689, 30.20666495446236, 13.212467643522448, 11.949498768775694, 35.50123906904651, 29.554374794806208, 30.742764703689087, 34.429827966997706, 29.257378808913696, 27.316752826013875, 48.298995494842536, 32.69633450815755, 55.905338102771395, 74.34603983356108, 16.665899830479777, 0.758909006272593, 0.15720026146981025, 0.06345704310543596, 0.041312233604971445, 0.06516900829850666, 0.05430422295185347, 0.30261281997926776, 0.27737469682770394, 0.18948021885608474, 0.27734625964395465, 0.17145325069225606, 0.13758002960633847, 0.2903338707983494, 0.3517901488850194, 0.21134856637687455, 0.35629244761601575, 0.783643288718116, 22.761647470535774, 92.4941013705346, 69.1233725701609, 35.90106979493172, 38.54810483994023, 42.996056925865915, 50.12418024001583, 46.78781217144382, 60.47158495072396, 45.084746499215406, 22.842044291957734, 21.18744734794863, 67.1265096049155, 26.200446274972734, 21.171200890694898, 4.840031718054126, 27.925738057782574, 73.49920795809838, 63.509001731872566, 65.97400742192423, 68.37904007204118, 67.56626221441454, 26.887000299269154, 0.29873515869821277, 1.2237912608731178, 10.648062229156496, 57.37923929768225, 78.65452028089955, 70.58272177173247, 65.73158533342423, 65.2204651986399, 62.07100983588927, 64.69430277424475, 68.52473258972168, 68.17963461722097, 67.23064853299049, 65.27171096494122, 66.54006035097184, 67.71358643808674, 67.11104762169623, 62.45713187802223, 56.179766731877486, 55.26769407333867, 56.62118634869976, 63.10755498947636, 63.231815676535334, 65.58300987366708, 59.0737698924157, 62.7143766034034, 59.88710080423663, 59.84950488613498, 54.72395158583119, 59.47360846304125, 58.90771242880053, 63.37414280060799, 57.03016404182681, 57.049250295085294, 66.39539549427649, 49.780608069512155, 24.42773892033485, 8.133175267327218, 10.834412074858143, 5.345353118834957, 0.20494109890874357, 0.0965533399533841, 0.208427059434114, 0.17826910431106247, 0.1120497588248503, 0.13724198564887047, 0.17853414008934654, 0.1010918363388027, 0.14238088812318542, 0.20046758976194168, 0.20736688567746073, 0.27455901727080345, 0.25603061391701626, 0.25566263124346733, 0.3671876581445817, 2.0468345741110463, 0.5036634945821378, 0.27157191787996604, 0.3825242480924053, 0.16861195315516767, 0.20998681444794903, 0.08194824139918051, 0.17897056505805065, 0.14276161849979432, 0.22826948743914405, 0.22835987049245068, 0.1872429816472915, 0.13812462618995097, 0.15035281438500653, 0.3863282423586615, 5.30956345219766, 15.835822359208139, 17.925178735486924, 25.475482440763905, 37.947197729541415, 51.06636493436752, 53.92747117627052, 54.39933230800014, 52.38343800267866, 49.984649765876036, 48.42336208589616, 52.05190358623382, 52.33932702772079, 52.74835963403025, 55.11035211624638, 56.559005014358036, 55.39669690593597, 55.41823071818198, 60.83820104599, 61.074786647673584, 54.60262875403128, 49.693033310674856, 51.25241471875099, 51.9760057233995, 57.27240962366904, 58.130592838410415, 59.593268209888095, 50.89606738859608, 50.86575923427459, 52.05610836705854, 53.65375641853579, 54.992504504419145, 62.60933553018878, 61.34854847385038, 66.5021231866652, 63.716004817716545, 72.1589183807373, 51.49789625598539, 14.78243160632349, 1.2375329170496234, 0.3629630509643786, 1.4067123421738226, 18.218601442152455, 56.24366998672486, 67.32684858383672, 68.00515190247567, 60.59116625016736, 38.25367996769567, 51.73741186818769, 5.705620857977099, 6.728001842575689, 54.82663923694242, 30.55826621670877, 26.699675744579686, 16.197676697084983, 43.07659103024391, 32.248035054053034, 58.43724766085225, 46.359924731716035, 36.139569513259396, 39.77930545806885, 57.816783612774266, 46.405561508670935, 65.99367418596822, 88.95106361758324, 25.09787194190487, 0.8916008280169581, 0.36366000711437196, 0.19836515338430483, 0.1525928861191196, 0.25426510300847793, 0.15844366813619293], [0.032450967363172004, 0.03673772342623242, 0.07513745928243284, 0.08561344351619483, 0.08597777961122413, 0.021701907258360617, 0.08085898694492157, 0.0830141991196621, 0.15750646681314515, 0.22035854177609568, 0.24771643021414358, 8.239614175212, 68.20213333252939, 51.252359805568574, 42.93040429392169, 45.612124858363984, 32.84884214401245, 37.45031579848259, 32.82135613502995, 46.29684517460485, 34.109440926582586, 18.992034004580592, 10.592389087523184, 29.129401676116455, 25.612655570430142, 16.453474067872573, 1.6624442584091619, 9.338787813340465, 64.54737470995995, 58.29782701307728, 52.96832223092356, 59.67612043503792, 59.75877261930897, 23.303171857710808, 0.6573923052318635, 0.10697896922788314, 5.833166039759114, 46.38771080201673, 68.38594344354445, 65.9240678048903, 63.663256783639234, 63.13343086550313, 58.84368758047781, 62.91319370269776, 63.44659682243102, 64.05715296345373, 64.51821973246913, 65.38472621671616, 62.66007138836769, 60.0252898277775, 60.21644261575515, 52.52748312488679, 48.89954959192584, 50.86708499539284, 53.06620497857371, 55.31915556999945, 57.09112944141511, 55.38480820194368, 57.423279669977006, 56.41804679747551, 49.79290077763219, 49.85922805724606, 48.406809683768984, 53.341045456547896, 54.43076226019091, 51.230320007570334, 55.41874847104473, 62.39921416005781, 25.20557434328141, 18.165298392695767, 14.369568805540762, 5.904858141176163, 3.5711447221617547, 0.41020564013911837, 0.09002091588392373, 0.02607712540925751, 0.05311273023365967, 0.03272215482748805, 0.026351947960774266, 0.08828105359909036, 0.07557916259693523, 0.0016170697621888512, 0.026071948570109187, 0.031168501703969897, 0.021062748611814553, 0.0414910730004551, 0.028702039496913075, 0.04471456031164816, 0.0450706341484141, 0.42106242369740243, 0.24917426489053235, 0.04320834335240145, 0.04395129159092904, 0.1715071526386084, 0.07838178801560595, 0.056486677213181416, 0.054691606802084757, 0.04857841285786802, 0.03789066660007642, 0.060864616891429316, 0.05540393833671847, 0.06606890113964196, 0.038292311177018194, 0.033574672791385846, 0.38059055024097044, 4.174580045284764, 10.511044033112066, 9.081649972546487, 17.25603415120033, 40.64873018572408, 44.59665067734257, 50.19049183014901, 47.12974871358564, 45.13449392011089, 43.647033091514345, 44.08736621179889, 43.52761260924801, 46.77925355972783, 48.378764737036924, 51.03191475714407, 48.04058582552018, 53.688108536504934, 53.35136521247126, 53.48756167196459, 51.77472929800711, 40.12682745533605, 45.707305092965406, 48.57200814831642, 54.95072733971381, 56.167521092199514, 50.97883332160212, 48.004978549095895, 47.288589016083755, 45.36776511899887, 48.05121152631698, 49.64835359204201, 50.437326585092855, 53.49906990605017, 60.21310467873851, 58.545971839658684, 64.35045996019917, 52.06960132045131, 7.997134231751966, 0.3934379673052219, 0.18510400287566647, 2.036819537320445, 34.864979636284616, 48.33560689803093, 51.673296805351015, 50.91112929005777, 49.22990337494881, 64.39162523515763, 41.321208784657145, 0.16903756096238093, 11.986206270033314, 32.61004628673677, 11.321632227590008, 27.52237915992737, 12.727268492021869, 18.67010743387284, 38.23497026197372, 48.96303707553495, 25.341757074479137, 29.68861006921338, 28.7312634529606, 35.52949974613805, 31.40146205502172, 48.004460796233154, 62.61594472392913, 6.308542105459399, 0.24852163458783783, 0.07000980297884635, 0.03402249331796362, 0.029290241805175622, 0.09922404503149372, 0.0510326253190156, 0.0908999328291224, 0.037670489100198594, 0.03615299532670648, 0.07022227746464553, 0.059992835646675485, 0.058920105708943266, 0.04900332352507019, 0.05266521997269123, 0.12948831783667689, 0.20441433685200833, 0.334076939691459, 10.76437129128364, 79.41835480351602, 60.049863476907056, 41.53495442482733, 46.63373754870507, 35.56417349846133, 49.00157828484812, 30.152697063261467, 35.40543125521752, 30.833253783564416, 27.903419771502097, 18.992691001584454, 22.906724176099225, 12.891766813493545, 18.49955101167002, 4.273754723610417, 8.555522849482875, 67.8066485927951, 63.93521039716659, 59.5238422578381, 61.58323564837056, 63.17119936789236, 26.45151326733251, 0.953228556581082, 0.27840922196065226, 5.663673070169264, 44.63214812740203, 69.03647638136341, 67.84769227427822, 65.55563172986432, 67.0240023828322, 62.54047832181377, 65.48302473560457, 66.52788531395697, 66.17376589005994, 64.53330124578169, 67.40485668182373, 63.60901824889645, 61.86628956948558, 61.771583941675004, 54.345250668064246, 50.15212320512342, 52.8874861040423, 54.34565467219199, 59.836910155511674, 58.54553645656955, 57.94976765109647, 61.98085415747858, 59.23794461834816, 56.00764920634609, 52.94817693771855, 53.75949959601126, 56.216550719353464, 57.01313703290878, 53.63081447539791, 55.15076821850192, 57.663034546759825, 31.153115226376443, 30.190547935424316, 23.78368966041073, 10.552175967924057, 5.346784783947853, 0.8144818823183737, 0.03866981249302626, 0.03643946624511192, 0.021294850270233808, 0.05408017287751841, 0.06341331863715764, 0.07131595990710682, 0.02566045018724136, 0.03981713641194567, 0.03678731995845034, 0.09309076809234197, 0.036451627890909874, 0.029440282040365764, 0.08330833091731034, 0.01400953509859861, 0.051804887911965775, 0.5275771129996546, 0.6648817033536973, 0.0396038958382222, 0.04745759558112872, 0.035558511097464836, 0.02905009047789199, 0.05817115134108932, 0.03723707868747654, 0.02220394574255953, 0.09442329376695618, 0.09028954461457268, 0.0522932727941342, 0.07109501248886509, 0.021013140588277773, 0.055713085457682616, 0.7042841793548676, 4.900555850998049, 13.304567836946058, 16.16532302671863, 22.86363890094142, 48.96829697393602, 50.660497680787124, 52.38245348776541, 51.09517866565336, 50.09730023722495, 45.71791118191135, 47.259563476808616, 48.80236894853654, 49.76750735313662, 49.694264934908965, 53.1103983233052, 51.720377014529326, 53.78171197829708, 54.58562527933429, 55.416810820179606, 53.98500057958788, 43.80061741798155, 46.401694051681034, 50.943496688719726, 57.74805192024478, 58.09633877969558, 53.92308596641787, 50.99610351747083, 48.65378564403903, 46.481722170306796, 50.83447833215037, 52.00912229476437, 53.17162259932488, 56.86485967328472, 60.5990384471032, 61.81550272049443, 64.68273570460659, 52.83163939752887, 8.241200773946701, 1.009377224310752, 1.164946515233286, 5.94766051538529, 42.60652242168304, 52.91346003932338, 57.23739462514078, 54.39446464661629, 54.39762607697518, 66.91663142173522, 35.30969404405163, 0.1478335189242517, 14.075417518615724, 43.23204240491314, 11.057339983601725, 10.085874795913696, 12.83327054592871, 21.67428997255141, 31.00565568093331, 37.863404135550226, 34.04525918345298, 30.602432104849047, 25.708406509891635, 40.04611684430031, 31.81906504015769, 58.258846498304806, 70.98418420360935, 8.992282690540437, 0.4552132137600453, 0.07461042909492409, 0.052516552950105364, 0.052273396642938744, 0.04744432310784056, 0.03869614293498378, 0.17331836835270928, 0.14567975465568805, 0.12563107279880395, 0.1560664973071506, 0.22236800572324186, 0.2518684888679174, 0.2843768323861784, 0.19622168533744352, 0.2694830719021059, 0.6714912035292195, 0.6367451325058937, 17.088798015348374, 94.81237119243991, 68.25852917086694, 54.44956218042682, 59.27566997466549, 41.91419270730788, 52.982376083250976, 43.62822140416792, 59.58212083385837, 47.58031922001993, 26.740399752893758, 17.561039616984708, 40.363107112146196, 37.25276954712407, 21.74712838665132, 5.915499041157385, 13.724415398413136, 75.17842954204929, 70.29024631746354, 67.16469780091317, 70.245437160615, 69.9717184805101, 30.09261419696193, 1.1926096437438842, 0.371842347085476, 8.319983540042754, 54.40130918256698, 72.38285433861518, 69.30171489715576, 68.97853512917796, 67.87117942687004, 65.2461410337879, 68.4987743439213, 68.61939507146036, 70.29418437711655, 67.53443610283637, 69.61970929176577, 67.1040814922702, 66.05827562270626, 65.76774958641299, 57.816673786409446, 55.269357158291726, 57.238728230999364, 60.25514464224539, 62.52379255910074, 62.85127516715758, 61.08001516711328, 65.34642819435366, 65.04522546645134, 59.30587222499233, 57.27929338332146, 57.240450151505016, 58.49078016896402, 60.50224611836096, 57.01873425514468, 58.35730191200011, 65.99880464615362, 40.50675215259675, 30.68324273632419, 27.227081560319473, 13.341870557877327, 9.138740070404547, 2.970717121516505, 0.1406449941737998, 0.2210466419496844, 0.23813170501061026, 0.14354923349474707, 0.13623042783189204, 0.17056677971155415, 0.19481185373039017, 0.14068777252349163, 0.12122687928739095, 0.2071251083285578, 0.14203047950661954, 0.12272013786939845, 0.15843616047453496, 0.13309749594378856, 0.12147590382805756, 1.1939964467479338, 1.571863860853257, 0.12800363177854207, 0.12599809786244748, 0.2492673752168494, 0.16496076278628843, 0.18963651611439644, 0.12697712758616095, 0.167911549609515, 0.1999424671333644, 0.20370593534842615, 0.1622995418766814, 0.2556584330816423, 0.08447453890356325, 0.19582451471397955, 1.369524718292298, 11.248292730700586, 19.931076880424254, 22.7191525120889, 33.94874926536314, 51.610970343312914, 50.36373115354969, 55.912810217949655, 52.485062691473196, 53.77465955672726, 48.4184395113299, 50.608863599838756, 49.45933457343809, 53.991703910212365, 52.77126627583658, 56.93969849617251, 52.93594306515109, 58.19995211016748, 56.86301223693356, 57.497286950388265, 58.98284542945124, 44.08575411765806, 50.53593497122488, 53.483513785946755, 60.79834192029892, 61.111829511580936, 54.201809590862645, 54.96793477765976, 53.327109275325654, 48.77314336838261, 54.02848789768835, 55.908707418749415, 55.304407458151545, 58.994757667664565, 64.14040134799096, 65.7396811054599, 65.5597855198768, 59.05281659095519, 10.275048748139413, 2.2448987009063845, 1.0453459716612294, 4.547347397573533, 48.12871363855178, 57.99893848357662, 62.621734142303474, 58.421295381361446, 61.20891994045627, 72.09907870138846, 50.90839932041784, 0.8434085043207292, 17.46690273284912, 41.75913356965588, 17.13912594702936, 40.18480400885306, 19.01890027907587, 24.978704452514652, 49.043951649819654, 64.64652438317576, 39.26010916309972, 40.54629748867404, 37.06660209163543, 48.807813198335715, 44.400434109472464, 69.82536700464064, 84.69122840512185, 14.42995761671374, 0.8040320753089844, 0.4138976629943617, 0.3135088885263089, 0.1585609102321248, 0.2892087940727511, 0.17372087094812624], [0.08044356810710124, 0.05512111782727223, 0.11820951176266517, 0.01434685031492864, 0.07069057935187895, 0.035684793030903224, 0.028016026912918015, 0.060102263645779704, 0.014358259279340988, 0.07542324838258567, 0.07134841905245859, 2.45346607700471, 59.71423018363215, 62.31550293584024, 36.90417282042965, 52.99341363291587, 50.508403854985396, 32.59145032974982, 36.483600601073235, 59.289868954689275, 46.96731552000969, 25.258259619435957, 12.904620420548225, 31.27612271616536, 50.77496028715565, 45.74496769135999, 6.655694909634129, 2.6028581252021175, 41.29639587094707, 64.4864446117032, 57.40972395866149, 59.6289147100141, 53.88954185670423, 38.03709060915055, 4.931049337310176, 0.23412325719912208, 0.7568134800080331, 20.629235236875473, 61.61871348657916, 69.71037095592868, 67.5203626386581, 62.96176049017138, 62.66553132764755, 65.93216357692596, 63.56930817327192, 64.95783505901214, 60.730900687556115, 61.74161311118834, 62.86035153173632, 61.208868949644035, 59.2002937870641, 52.54196059319281, 50.8023266638479, 50.118288840017016, 52.07299417065036, 57.226545349244155, 57.86788817374938, 53.767422783759336, 55.48380490272276, 55.59017173705563, 54.18978360391433, 49.83559185458768, 51.31237206920501, 50.23719549179078, 55.019976785106046, 50.84080511523832, 49.77847430013841, 31.109392566065637, 23.49808031512845, 32.64484751609064, 25.500873904074393, 13.214803414960063, 4.786905665551463, 0.128968067527298, 0.015167994105497436, 0.12003254055255845, 0.06335485080677657, 0.05544786964873633, 0.014860246052605011, 0.03195755502900049, 0.09014931988091239, 0.03782415101605077, 0.010183590498091954, 0.011149591939043135, 0.0650565312694638, 0.013304853909498742, 0.0369015513288398, 0.04127414754381584, 0.031585286093515255, 0.19241543877268993, 0.602878469132608, 0.06236273630131638, 0.07742749527096748, 0.07434822784195985, 0.025119044359833486, 0.03266326181830899, 0.0810072556017868, 0.040737686813959194, 0.06661062489353842, 0.05327881809564368, 0.10229121593217697, 0.031994120405626394, 0.09798882018414237, 0.10321354748861444, 0.3484719769368249, 2.3915556313530093, 8.704840617795146, 15.640552063142101, 15.500342038369949, 36.61576094165925, 49.91670254738101, 48.932932884462424, 51.12250189627371, 47.19040424593034, 43.62950009684409, 44.53377900585052, 46.6679366942375, 48.10932536279002, 49.6365943262654, 49.44405694161692, 49.918326408632346, 55.136267215974875, 54.413876456599084, 52.81069786317887, 48.27443753519366, 40.6511777447116, 46.14530048062725, 50.3942197368991, 55.81946565258888, 55.10939505792434, 55.920937368946696, 50.49590326124623, 48.43693348669237, 47.589262224012806, 50.18618899006998, 52.008200537773874, 56.31840682798817, 57.25551205296671, 61.44619587929019, 58.55544436362482, 66.69562939674624, 39.61741747394685, 5.308150908639354, 0.13451465135139806, 10.639526171068992, 26.637888608440278, 41.98011206042382, 53.23135637467908, 51.420331385827836, 54.713580839095584, 53.03268832545127, 59.31103406413909, 13.212259757903315, 0.22990338444229097, 21.9546551089133, 17.337894016696563, 19.76699236900576, 15.16649538470853, 12.424233036656535, 25.78500451580171, 41.485622775170114, 29.955568544326294, 22.352228510764338, 37.11294489522135, 48.488512654458326, 46.255715200977946, 35.42067358570714, 55.08586083689044, 58.18162287435224, 4.7897606607406376, 0.3778975060389888, 0.06529448583962456, 0.0709703240183092, 0.03172400737962416, 0.055807831381718, 0.01203747635196534, 0.05386904287602633, 0.05076442176716463, 0.1178552037585647, 0.04054393551702942, 0.01915715086544233, 0.07143191497532592, 0.051623378700066, 0.06869723389465963, 0.057262655332564354, 0.1649641948601892, 0.1538261191378678, 3.228711755044999, 74.43553263141264, 71.22470394257577, 38.02793971953854, 52.60595014018398, 33.17425766298848, 36.70472814190772, 42.08738103989632, 38.90926491829657, 34.08611459116782, 22.78931586973129, 21.3858231805986, 39.13151033463017, 50.2870213600897, 45.18706152516027, 10.107966565316724, 2.388517265358279, 42.908803801382746, 70.28678678697156, 63.728807433958984, 66.81395161536433, 60.01840214575491, 45.80890624753891, 7.03436739021732, 0.17043942525502176, 0.4115052929809017, 17.947985356853856, 60.74726873828519, 72.17206616555491, 68.15046002787929, 65.23295402526855, 66.7187713807629, 68.79412881789669, 64.86412179085517, 67.21444129943848, 62.637709956015314, 63.940933135248, 66.03715758169851, 61.554057136658706, 62.29178828577842, 55.90371031914988, 52.823406342537176, 53.008036228918264, 55.31371524257045, 60.6233649869119, 60.41837799933649, 57.8742894818706, 56.778865629626864, 59.63206437326247, 57.177523566830544, 53.279699587052875, 55.553077882336034, 53.859594560438595, 57.07380433236399, 50.57436243180306, 50.01042366027833, 36.91211954239876, 32.18523790759425, 37.03461908525036, 31.43874026113941, 20.98327817455415, 5.349851587126333, 0.9394828554603362, 0.16336858693149783, 0.07515704048977745, 0.04994691019096682, 0.05623315573639928, 0.0317536358300957, 0.10399739333097974, 0.023453839258441044, 0.053808311255828994, 0.11724079358241252, 0.08574133423427421, 0.0020359444944563535, 0.08081245476440077, 0.030139134257971763, 0.09281565825785361, 0.08674217448119195, 0.058272880156554525, 0.698654720139119, 0.08560151552721378, 0.05310289366471191, 0.10436348376735564, 0.009380565644542297, 0.03830626929899858, 0.05492077817419364, 0.06444749136966083, 0.028205775400443424, 0.09198826797787221, 0.054236604201216856, 0.038611540015065865, 0.04038698325354246, 0.1928475123619841, 0.8687856264652745, 5.713113565598765, 16.023406770921525, 23.890888037220126, 24.331034844921483, 38.97820841881537, 54.33299718364593, 50.57889669172226, 52.84620708034885, 51.1459380580533, 47.22334823300762, 47.341897949095696, 49.36060459383073, 49.76300054980863, 53.46365874813449, 51.995429300492816, 52.06157222870858, 56.54514728053924, 58.317450631049375, 57.375462055206306, 50.01014909436626, 44.83448751511113, 48.09986460593439, 53.975677105688284, 57.64022988657798, 56.818763979019664, 57.921781539917, 52.61860370635987, 50.887787265162316, 51.101140668315274, 53.24478264777891, 53.927039715551565, 60.48037105990995, 61.41273021697999, 63.57317563026183, 61.72946945313485, 69.91380860728603, 40.01141563538582, 4.810693369757745, 0.14077513719037657, 17.40074411515267, 35.595650519094164, 51.40173542884089, 58.90624546235608, 56.50277391556771, 59.870426808634114, 58.07837824667654, 60.11175063348586, 13.478254310546385, 0.20176969408508272, 30.278744389933927, 22.04185135902897, 6.8297108623289295, 10.17460665395183, 15.946672462647962, 27.540967272173976, 38.678527570539906, 30.37458162153921, 27.555415322703702, 34.869419759319676, 49.07793898736277, 54.233290533865656, 37.9210865113043, 66.28818927272674, 67.90022850036621, 6.579082685132181, 0.5182964787367852, 0.08294538144142398, 0.08097098133857213, 0.027821237566850843, 0.0632493375169654, 0.014130854697507477, 0.25677184994903307, 0.18344418145716193, 0.318462964628012, 0.1490044843165144, 0.17314552359523314, 0.21097312200694315, 0.12995213810955325, 0.2013325489937298, 0.17403830714043111, 0.2165045832554179, 0.3253156823977348, 6.716426928197184, 92.84432195848035, 82.41889738267469, 50.63229583924817, 68.86237805889499, 64.3276160763156, 41.33298373991444, 51.95736269797049, 77.47554994398548, 61.715831372045706, 29.991267996449626, 16.465992312277518, 39.51234109940068, 63.92289415482552, 57.21733562407955, 12.022149889699875, 5.633713026200572, 50.11877129154821, 75.28667126932453, 70.41665646337694, 71.13581518973075, 66.31250012305476, 46.92085896768878, 6.639532293042829, 0.6072017177939415, 1.535511088948096, 24.85077831052965, 65.47965149725637, 73.6839751274355, 71.58242410229099, 68.20196859298214, 66.37748595206969, 72.55522681820777, 71.501889997913, 71.59740755634924, 66.0117406229819, 65.89003732127529, 67.39731788635254, 64.71414604494649, 65.04458219774308, 57.26299201288531, 58.22423550390429, 56.6345694757277, 58.07807622417327, 63.80954157921576, 62.65383874216388, 57.94025198105843, 59.089518208657545, 65.11352177589171, 62.04345910779892, 58.09759786052089, 59.13134636417512, 56.67445605800998, 60.92516783745059, 54.81554677409511, 53.34816455841065, 44.504157266309186, 34.3314863020374, 38.35598714890019, 35.66572366222259, 22.748901728660833, 11.950497992577093, 0.9337119457702484, 0.38745531091286295, 0.20380888224369098, 0.24892346302588142, 0.09928756138129581, 0.2433857198564276, 0.12116641962840674, 0.1591612933383834, 0.2576882902893328, 0.1514357562747694, 0.15881460790912952, 0.08664246813784685, 0.13484020807570027, 0.1245938663581206, 0.16778293876878678, 0.11340971044715374, 0.7583831635213668, 1.2053334448606738, 0.2304526388404831, 0.18903240982082584, 0.1699466162150906, 0.2530017320907885, 0.168313990917898, 0.14695921341978735, 0.22467294978278302, 0.25393421431222274, 0.14859527079088075, 0.17748251587392824, 0.1049955522701625, 0.23289002418037386, 0.495331890039867, 0.8268849683865425, 8.788253741879618, 22.646382739467008, 27.25264168554737, 28.033685607294885, 43.66932392120362, 55.55497630949944, 51.00221457019929, 57.861624148584184, 52.10135290699621, 49.120610452467396, 52.46740418095743, 52.00749451114286, 51.950769193710826, 56.87350065477433, 54.9395211281315, 54.09010833309543, 58.96007607060095, 60.75762771791028, 60.9800967093437, 53.41835929501442, 47.56595550044891, 51.7618364672507, 55.236856399043916, 61.397295690351925, 59.72533441358998, 59.87392164045765, 56.56022487148162, 51.8436453419347, 54.67475721913, 55.39864240154144, 57.23084034458284, 62.8122515063132, 64.86526320057531, 68.05935905825707, 64.42457314460509, 71.19051656415387, 46.84566320911531, 6.610062545345676, 0.43316679676213576, 15.544704045018843, 36.950519546385735, 56.42373423422537, 63.45734803907333, 61.63094735914662, 65.54826944105088, 62.63613316320605, 69.55667680309665, 19.37088005004391, 0.4863459238361928, 28.928595935144735, 22.81244020308218, 30.808782116059337, 26.625342907444125, 17.896612113521947, 34.69787489983344, 56.20047684638731, 40.09382463270619, 32.492014323511434, 46.762269696881695, 61.92382289517311, 60.93242422226937, 50.18326290192143, 74.43586211050712, 79.6116570503481, 10.194883346557617, 0.9071313301401754, 0.24433053609344269, 0.33581887041368796, 0.136581847684518, 0.10106485472210955, 0.24838275816892427], [0.04699556795399516, 0.18805210839115805, 0.06641587768230708, 0.05425284909565122, 0.04002686064209669, 0.03815128588147702, 0.008912482092367306, 0.03312824271439064, 0.012040453561161076, 0.07203013005275881, 0.15774482740990578, 0.3077489798588138, 42.22489541576755, 70.07784997263263, 32.81312308003826, 56.624402692241055, 107.46200715341877, 50.270100255166334, 38.475446854868245, 56.42829987310595, 36.620197142324145, 40.60119498160578, 13.310420993835697, 29.487567024846232, 53.15489369053995, 52.384442129442775, 12.099033248039985, 2.1281424885795963, 40.39162274329893, 63.97745824629261, 54.03102959356001, 54.078243163324174, 63.36476049115581, 56.861749233738074, 18.746307319210423, 0.42386504911607314, 0.23687800212252527, 4.2015816415509875, 37.53025370259439, 67.03129014661236, 68.95365945754513, 64.34495295247724, 64.0703203601222, 63.5199765236147, 64.41504962982671, 60.95524457193191, 61.37653850740003, 59.384464756135024, 64.26838828671363, 60.87931140776604, 58.99382414356355, 53.24230370983001, 50.08392103256718, 50.9663680291945, 54.54731941223145, 59.7328967432822, 60.606279142441295, 55.96841765988258, 57.1003117099885, 49.8590240939971, 52.74258982750678, 51.59003273133309, 49.349488596762384, 52.86956871709516, 52.70072244828748, 49.904511820885446, 42.820876029229936, 30.06911723844467, 26.999817471350394, 33.83927983622397, 35.27717759532314, 23.140662177916496, 5.4314810133749445, 1.0203148148232892, 0.5523959102649842, 1.0045076017418215, 0.42160095286465465, 0.020635148975998163, 0.03625693430583324, 0.02680807479567105, 0.0753513969961674, 0.051236328098081776, 0.033322181702861865, 0.03145457425665471, 0.028499024281758937, 0.0499786913485056, 0.05165124131787208, 0.08825145196169616, 0.03234483354214219, 0.07607544201516336, 0.21787641690142695, 0.2738361367054524, 0.07823150454749984, 0.05492462010513391, 0.04519592016755093, 0.13460362480292398, 0.06728575519856907, 0.0213754044154719, 0.0752548775785873, 0.07557842715252792, 0.11795008374798684, 0.21012562957982864, 0.7411853476397453, 0.9750616334138379, 0.1168979156101423, 3.6507122074404075, 13.230334039657349, 22.914663053327992, 31.500174383963312, 31.478917098814446, 46.402423612533084, 49.31031196348129, 47.162833905989125, 47.77270755460186, 45.27658962434339, 45.218585614235174, 45.1657473656439, 49.659857903757405, 50.31431713411885, 49.56351664758498, 50.25527369591498, 53.791329629959606, 51.63749341041812, 51.466846773701334, 47.11470250160464, 43.19090850891606, 46.98528389776907, 52.25059516968266, 54.7202096446868, 58.48400231330626, 51.8976838357987, 53.17905156843124, 49.508536784879624, 47.64011183092671, 50.657893226992705, 52.89418158992645, 58.23227636275753, 58.90192693279636, 59.839243965764204, 59.61115814024403, 60.88233555516889, 23.35411952387902, 0.9552284137856577, 9.595380444680492, 42.43607974821522, 52.043870572120916, 47.55289793014527, 57.69615111812469, 56.629160527260076, 56.64703476813532, 56.124359330823346, 49.82483279320502, 7.705590340398974, 0.4419432225967608, 26.497573660266017, 15.65337036886523, 17.734745702435895, 10.768269146642378, 15.504486022457002, 25.902901157256096, 25.7641355452999, 27.98279677667926, 33.293058410767586, 38.60484192448278, 35.11173594382502, 24.492771817791848, 27.744553973597867, 60.68351845587454, 38.18959628382037, 1.7550728686394232, 0.08161330775868508, 0.0385488165662654, 0.0483602233561537, 0.11969476472586395, 0.06351288325423676, 0.04510668624613074, 0.024544746547396627, 0.08836473338305952, 0.08739598455928987, 0.04512348655431021, 0.0793164459267451, 0.07158170048628124, 0.007602701089420026, 0.07178128171231478, 0.046282684836055965, 0.05295459819476932, 0.05739202460033759, 0.5903203881555988, 55.21069418999457, 81.94738926426058, 35.73323941999866, 67.33092784881592, 91.1171611662834, 28.63908971509626, 46.819065616976836, 50.94129231668288, 47.11327868123209, 27.352893544781594, 12.75299237620446, 37.07874574968892, 58.793210598730276, 52.60874286774666, 14.186652994924977, 3.632432246400464, 45.05193195035381, 75.29542599954914, 63.1153134376772, 62.258863910552, 68.29379127871606, 61.92437987173758, 26.70941891208772, 2.042588118103243, 0.2611555429475923, 3.4567541893451446, 35.03435542506557, 66.30128998910227, 70.67010433443131, 67.36043976199242, 67.60874148338073, 66.76622421510758, 69.46264974532589, 65.34844429262223, 61.79538880625079, 60.96962398098361, 69.23308910862093, 63.85414285044517, 61.02761622398131, 55.7665018881521, 52.63750560822026, 53.98144691221176, 56.93961220402872, 61.46387400165681, 61.736619933958984, 60.40028802810177, 59.161933006778845, 56.22620759471771, 55.41014671325684, 54.56388750383931, 54.2330434245448, 56.711224356005275, 54.8298438133732, 52.59673257027903, 43.954911693449944, 37.56404492162889, 34.38294387632801, 39.70909110961422, 37.41600290421517, 32.25760171490331, 17.04164720350696, 2.7882621893959665, 1.5563043086759507, 1.5253245710365235, 0.5439894742542698, 0.08872400563690933, 0.03691259065582868, 0.04568338957464984, 0.09597894254951708, 0.037245831242011446, 0.13988662841579608, 0.053982404736621734, 0.00812881532305431, 0.02190100393378206, 0.022175242343256553, 0.04516693140049616, 0.0750409322039735, 0.4067644651138014, 0.5499796076647697, 0.16763689176690194, 0.07027444039140979, 0.026136376564541174, 0.0771887669520032, 0.06042808467041581, 0.026904900648420858, 0.0311527164622901, 0.03547364770765266, 0.02615226905853037, 0.11501400581290645, 0.2566522483022944, 1.3505753802676357, 0.540383161315995, 0.22194895562866043, 13.203641330042194, 25.77906212499065, 24.211418244146532, 36.67548687227311, 40.81385020286807, 48.02281748863959, 51.22399714685256, 50.94702682187481, 51.60849140536401, 49.65020495076334, 47.65784094410558, 48.56092745257963, 52.80825814893169, 52.26317028845511, 53.29651478798159, 52.27466675543016, 56.79261353708083, 52.2813347847231, 53.60859032600157, 48.615216978134654, 45.80047315166843, 49.78637787603563, 54.44957002516716, 56.37617157351587, 60.00178698570498, 55.00668779496224, 54.51720737641858, 51.76009885726437, 51.22746059971472, 55.274279732857984, 58.98018214010424, 59.14620038001769, 63.01851326419462, 62.58380482273718, 63.87919110636558, 60.46714090531873, 20.39343018685618, 1.8096889315112945, 16.866068186298495, 51.0363313459581, 56.95442307379938, 50.9391075564969, 64.03745874281853, 61.8581114276763, 61.36232383789555, 58.18565114851921, 55.641692069269, 7.115844334325484, 1.7021282257572299, 36.879775677957845, 12.584085310659102, 10.9767892091505, 16.191417574882507, 19.596494782355524, 26.74677948797903, 33.38071553937851, 22.418700918074578, 39.316987452968476, 28.278792558177827, 44.15367780193206, 30.24014630625325, 31.457926534837295, 73.44493019965388, 45.970751085589015, 1.7123962554239458, 0.04429403166737288, 0.03459903959845824, 0.03802665486751545, 0.030678787659252846, 0.048183463889384465, 0.07548552366995043, 0.1149341564685587, 0.28131146945299645, 0.16341518039905256, 0.11040769532443055, 0.2582762474494596, 0.17244366448252432, 0.11959145776927473, 0.1166692766691408, 0.2188184292566392, 0.17698132583210546, 0.3353321287901171, 1.387719735503197, 72.31752334102508, 89.49559057912519, 48.601402390387754, 67.4730117859379, 132.41565550527267, 66.54370031049176, 48.6516518746653, 69.81054829012963, 47.562786225349676, 58.49094490851126, 19.988918112170314, 40.09644085361112, 65.01096748536634, 64.02621722990467, 18.4851304177315, 6.459368025102924, 50.27244583252938, 77.48306520523565, 65.19068656429168, 67.62381907432311, 73.84006192607265, 69.09800267988636, 26.364191501371323, 1.7001916780587167, 0.7049298995444853, 5.798819805345228, 43.36770542206303, 71.65887894168978, 72.80762349405597, 72.06972368301885, 71.9536764391007, 71.45530792974657, 68.76577008155085, 68.580736191042, 61.67620758856497, 62.783578980353575, 72.72792877689486, 64.88388661415347, 64.16735195344495, 59.095844991745494, 55.76729028455673, 58.97118814529912, 61.37001560580347, 68.68720500699936, 66.02537478170088, 62.07310045919111, 63.38992249581122, 60.08641996691304, 60.704746323247115, 57.8924382886579, 60.04214817477811, 59.846731770423155, 58.821490887672674, 56.28041867286929, 48.8890847083061, 45.31851583911527, 35.74052718377883, 38.496019686422045, 41.595962970487534, 34.77377668503792, 13.216802843155401, 2.2181947144769856, 3.3965803730872373, 2.441466566055052, 0.830017838987612, 0.15309347861236142, 0.16430102318765658, 0.12279619507852102, 0.24595657303448648, 0.134260248873503, 0.4151822085822783, 0.12533828931590243, 0.11548256817003412, 0.1936430640278324, 0.13007405334182326, 0.11773842897626663, 0.1495743158363527, 0.4638719991330178, 1.0398345512728537, 0.6220833128017764, 0.17806572328892448, 0.12586955596963245, 0.24719239543041877, 0.23178097401415151, 0.22513413471319985, 0.08913715685447378, 0.3064207059721793, 0.22966482466267002, 0.2341179252271691, 0.6122194711239107, 2.002569523549849, 2.860342360311939, 0.7075542716249343, 19.138907155682965, 32.11326241493225, 31.825954683365364, 40.25998800031601, 40.25700307661488, 50.420303498545, 54.15806339633081, 52.91571147980229, 55.315370482783166, 52.98887937299667, 50.514522752454205, 51.8283716324837, 56.56890899904313, 54.63031284270748, 55.83264873873804, 54.95128823864845, 61.805830155649495, 53.39801396093061, 56.56021310437111, 52.31396105981643, 49.14996154846684, 52.25882430230418, 56.15177277595767, 58.54368117547805, 63.25654622047179, 56.03720818796466, 57.90036932114632, 54.74766623589301, 52.76595930899344, 55.85594369519142, 61.01726508909657, 62.23858525676113, 67.46747339925459, 64.91807791494554, 67.39873778435492, 64.38397661332162, 27.471711943226477, 1.994679185651964, 11.570314418885017, 48.20772194093274, 61.64797044569447, 54.56568787174841, 70.03919109221428, 65.20863925257038, 65.58971712666174, 64.82987949925085, 60.166832477815696, 11.868745992260596, 2.804929565998816, 33.39878982113254, 24.59141354407034, 29.038722361287764, 19.489941635439475, 19.087932032923547, 36.946648167025664, 35.28841126349665, 36.88759688408145, 46.42401233796151, 48.87022203014743, 51.08074042104906, 36.27651906782581, 43.41515825640771, 82.49323414218041, 61.2508971460404, 3.2675880818597736, 0.4134415342442451, 0.18553425317570088, 0.20038521998832304, 0.18900921267847862, 0.10382337645897943, 0.23983641918147766], [0.02278515175285359, 0.06561562989748294, 0.07815129514182768, 0.0473874525707816, 0.04580035587892898, 0.04440261696976039, 0.015058000158939152, 0.04807944830146529, 0.06924881720014157, 0.03428026658272551, 0.03536275265017345, 0.08833384471795253, 41.43760119715045, 71.37251454014933, 39.01289786061933, 27.195057369047596, 87.5322638788531, 76.8384079779348, 31.43872457165872, 31.539400046871556, 17.61104199194139, 23.428315078058553, 14.696428737332745, 15.957587438244975, 49.78415389214793, 55.56184045730099, 22.746950349500104, 0.2696440729402727, 16.74992092194096, 45.29908833965179, 33.28035777614963, 39.755771237034956, 53.94220359863774, 61.86860769025741, 51.60083886115782, 17.927940084088235, 1.3935314623578903, 0.13793031564883648, 9.848175241101174, 45.53082981417256, 69.77177173860612, 68.82259738060736, 63.16799086909141, 66.84726822760798, 66.0726236527966, 65.34933074828118, 58.574926776270715, 60.594053114614184, 59.196838178942286, 58.84101252402029, 60.04077926758797, 54.768949016448, 51.92671329744401, 50.77703129860663, 57.68418396672895, 59.62709865262432, 54.418293045413115, 57.30685587852233, 50.96634841734364, 56.726125440289906, 54.16330368288102, 55.13477671530939, 50.920021303238414, 54.09085358342817, 49.85471340917772, 52.1762191864752, 32.865294525700236, 33.06549426048033, 42.4043163945598, 30.330047030602735, 23.154806244757868, 26.664203789926347, 17.844101382840066, 3.3108731527482314, 2.1249810582207096, 1.7854029637190605, 1.044538331127936, 0.1294691196732944, 0.05925428858327289, 0.07423164458164284, 0.08302638757853739, 0.09413171304209579, 0.055306545578904694, 0.016541100415070693, 0.09994110332862025, 0.029011403037715825, 0.036303006833599466, 0.040921459815675215, 0.07131413661784704, 0.11606230520673337, 0.39365777325245643, 0.02169983690574525, 0.0625921643128799, 0.05263675597586459, 0.04412491392764834, 0.11778869200497867, 0.07760264595309574, 0.01626798240918546, 0.07180678477931408, 0.09626650897365424, 0.021777703997588927, 0.32359149427183215, 1.5703699281138759, 0.5703006720831317, 2.674835579049203, 4.4312364151400905, 21.06264537380588, 20.48951845015249, 29.570935041673724, 34.25778496649958, 45.90362364246, 50.470878539546845, 49.696653658343905, 47.968057278663885, 48.10322999954224, 48.3765721321106, 48.41707060413976, 49.90974818506549, 53.846011392531864, 49.28695817147532, 51.38792476346416, 51.81763610532207, 54.29348322653002, 52.389188197351274, 46.441364903603834, 44.77395357624177, 51.14167051930582, 53.33353019529774, 58.78589930072908, 57.29122131101547, 54.50166302342569, 48.890500683938306, 49.853058168965006, 50.61852047520299, 57.709722518920906, 56.685874077581595, 59.93376131980651, 57.98866579609533, 63.85330346322829, 61.871074861095806, 36.49697588336083, 6.960862173188118, 10.318740029488842, 52.39727220227642, 56.63116485841813, 51.19023338440926, 53.42134814108572, 55.28798449424006, 55.072626759929044, 58.43232116391582, 57.21281705364105, 40.185184478759766, 0.5467517421610895, 2.0874787867069244, 33.761793413469874, 14.682094435538016, 20.663083330277477, 8.221238851547241, 19.65618148926766, 23.253224395936538, 37.83719485805881, 33.104521843694876, 33.1686447512719, 42.088730335235596, 27.297131169226866, 25.234499862117154, 38.12582638955886, 60.294109467537176, 26.787919267531368, 0.9130545381096102, 0.11515288989269927, 0.07521651189533934, 0.06870186872660153, 0.005951190767284002, 0.02402545767836273, 0.01578293958558671, 0.06187803247162412, 0.03958198572358778, 0.09740647078762132, 0.05674494843509409, 0.03501607105135918, 0.07204697632621374, 0.06758338801803128, 0.0955112535326231, 0.09167843137777622, 0.03210259079482527, 0.05308678666610391, 0.352618933445023, 52.41871972237864, 79.93334631766044, 44.84646251124721, 30.877521653329175, 98.1089585827243, 77.188000986653, 39.6966964198697, 29.618309428614957, 22.092024357088153, 38.144842040154245, 12.84153497988178, 25.436082232382994, 52.880217952113, 56.45900418681484, 29.286474950851936, 0.025411523322785096, 14.373570603709068, 49.91034830770185, 38.813413958395685, 41.30571150010632, 61.97564917225992, 71.30803861925679, 58.86016153520154, 28.04288748771914, 3.363010277671199, 0.25703423506309914, 7.331438881735648, 42.27388581921978, 68.62065807465585, 69.85336488293063, 67.54031965809484, 68.5576726544288, 69.8954362253989, 64.49863533819875, 61.36717580979871, 61.035335448480424, 63.16232304419241, 61.03067567271572, 63.63300354250016, 58.73025263509443, 55.98772748824089, 52.21985555464222, 59.161615294794885, 60.424077203196866, 58.059566559330115, 58.6138641449713, 55.20625798932968, 58.5589470401887, 56.98783774529734, 57.528736514429895, 55.50518966490223, 56.3869071006775, 52.8309412156382, 49.370488966664965, 38.793817797014796, 39.62197919045725, 49.51642467129616, 29.735941310082715, 24.585653543472294, 27.39354891161765, 19.214293149209794, 3.6113335720954405, 1.8134276857299192, 1.630190976204411, 1.0610318977025248, 0.10323431613224168, 0.03366829256617254, 0.0979179876946634, 0.022964807031976602, 0.07682945639375718, 0.07132393488239858, 0.04468443390402583, 0.018128899992593837, 0.029862444367139574, 0.07418783201325325, 0.040653750390535405, 0.048968665707375736, 0.09730802848935129, 0.26538008884076153, 0.054770732193344066, 0.06708363822150616, 0.03642533192290895, 0.08050322337376495, 0.05026349602567573, 0.02503097680727801, 0.03610555916243503, 0.031138720035913493, 0.15718054236663928, 0.026641429604722128, 0.8012460280329952, 2.408941046845529, 1.2294055209044488, 1.069208568622989, 8.748540724477461, 26.320694377345426, 23.9230397055226, 32.946799416695875, 33.30298592967372, 48.98062890575778, 51.98613328318442, 51.105023814785866, 45.981039462550996, 52.25899296422159, 49.55556992561587, 50.88933267901021, 53.95232723605249, 56.64001372552688, 51.62130578871697, 53.396762724845644, 53.53425748886601, 56.52690825923797, 53.67314469429755, 47.52451565957839, 48.27367659538023, 52.389894223982296, 57.59861353904971, 60.44508934020997, 58.36853558017362, 57.55933884651431, 52.67597621487033, 51.968262964679354, 54.973908547432195, 60.32826154462753, 58.83638804958713, 64.29176561294064, 61.45482509366928, 66.26949525648548, 61.39907252403998, 34.732266241504306, 7.641149720837993, 17.041523648846535, 60.18775440031483, 60.32230346433578, 55.9988630971601, 58.318697944764175, 58.28324364077661, 57.14994538214899, 62.60496600981682, 60.41256504674112, 35.92498056350216, 0.438880832084725, 7.030018462288765, 36.5456485748291, 10.773136808026223, 19.701647643120058, 19.55696709694401, 22.665013997785508, 31.97156483127225, 33.44705066373272, 29.04908722446811, 38.86459304440407, 29.28971482861427, 39.69533927979008, 20.576314618510587, 44.198906652389034, 70.6119748084776, 34.659620023542836, 1.181577364763906, 0.16461004773455282, 0.061045402150240645, 0.022685148550437826, 0.08090911207780724, 0.01420961045134332, 0.019061154302870555, 0.14780191013649588, 0.14314882998024264, 0.2006304906981607, 0.11276670220878818, 0.18703534117629453, 0.1448249690715344, 0.17082168780747922, 0.15453566977333638, 0.10023129743433769, 0.14419951956839333, 0.15042013819179229, 0.6338231505886202, 66.58138644310736, 90.74556366089853, 57.57782497713643, 37.69175337206933, 86.04951381683351, 92.77984603758782, 42.770834430571526, 42.01460538371917, 22.427945944570727, 35.69441187766291, 26.401791341843147, 24.00368755863559, 52.7541333629239, 65.4351600523918, 31.211619338681622, 1.7473936032864357, 24.559938484622588, 60.211014055436664, 47.09897379721365, 49.962582511286584, 63.686661566457445, 70.39265940266272, 61.657133102417, 26.974590747587143, 2.386996856620235, 0.4254464690964069, 11.916784240353493, 51.28767682660011, 72.18632790350145, 74.72261090432444, 68.72393408129292, 70.57489272086852, 73.22727787879207, 64.16440625344553, 61.40488547663535, 61.65199087512109, 63.339884819522986, 63.959211380251, 65.86512242594074, 59.914051409690614, 57.91329745323428, 54.29517769044446, 62.388058939287745, 65.87146882087954, 60.8569303635628, 62.2827942909733, 57.98055041220881, 61.387454463589584, 61.07242145845967, 62.22055412107899, 56.86503617994247, 59.02949810028077, 58.87016357914094, 56.37517136912192, 47.22124192022508, 42.9116435973875, 48.77972510553176, 36.23087836850074, 28.480218033636774, 32.34820062114347, 31.35117138585737, 10.67630917795243, 7.548700436469048, 5.194089854917219, 1.2129068062190087, 0.2680134701152002, 0.1478340551857987, 0.21374700380669487, 0.14895850371929908, 0.28260444200808005, 0.22165707612950958, 0.113792470956762, 0.17866935460798203, 0.11337117622456244, 0.13037416062528087, 0.1339959791831432, 0.2746945535463672, 0.15704215624399726, 1.205300349862345, 0.13051683684029888, 0.18878009110208482, 0.2335666943221323, 0.15901199812369962, 0.18526927868445076, 0.254292207199239, 0.09335460877346416, 0.20710816246367272, 0.19882007171550106, 0.0919356300765949, 0.9691953610989356, 3.211283683776856, 5.760906665555893, 6.894077937449179, 18.809745773192375, 35.34277139171478, 28.657738624080537, 38.538667617305634, 40.04916060355402, 55.881556772416644, 53.32366151194419, 54.542114427012784, 51.06388991878879, 54.13458408847932, 51.2968590951735, 53.723084311331476, 58.31157099816107, 58.165839256778845, 53.77822106884372, 54.12841812256844, 55.93124928012971, 59.10243065126481, 57.4279276786312, 50.647781356688476, 50.31790610282652, 56.60863868651852, 60.21499133879139, 65.2468902064908, 62.88592538525982, 59.985167903284875, 53.11574843622024, 53.81714274806362, 57.31561060874694, 64.24050807952881, 62.53666970037646, 67.1159976528537, 63.68178998270343, 71.74199396564116, 65.350601596217, 43.12273771532121, 10.294698842110174, 12.453969505525405, 62.150924205780036, 65.4520066322819, 61.97803397332469, 64.39043283462524, 64.02120444082445, 63.73695027443671, 66.24586689856746, 65.92030232952487, 51.64427911081622, 1.5644443299501174, 5.366434387622341, 44.968220726136245, 25.39109264650653, 29.25119519233704, 13.498069144064381, 26.79582480461367, 33.84412004101661, 46.63193325842581, 48.77422986492034, 41.233296701985026, 55.137573365242254, 40.994349833457704, 34.76645754229638, 56.05771433922553, 81.55417949922624, 47.40874298157231, 1.516112149242432, 0.24329503036795125, 0.10563181127391516, 0.18601508060049626, 0.15006390730700186, 0.09544713963424006, 0.2166283983857401], [0.016369902746631734, 0.016628399964482073, 0.01626407727599144, 0.037391020225421075, 0.027667363061599677, 0.08750124504008601, 0.019147145757151228, 0.05657268590444038, 0.052110633602546114, 0.0856242147124102, 0.03995409761104853, 0.08819499128167668, 24.07459028305546, 71.81452643486762, 44.55559522874894, 41.91773460757348, 28.437940766734464, 16.413387444711503, 35.56678971936626, 43.36603056999945, 60.85382384638633, 22.72055279824042, 21.85996909295359, 20.455570336311094, 39.26220370877174, 72.8982537792575, 46.39391599162933, 4.310948598769404, 1.1853862313493606, 24.46740584988748, 34.68585675762546, 78.33397634567754, 63.37847309727823, 37.483863830566406, 41.68303566594278, 51.0323069941613, 34.47762596991755, 14.577084741284771, 0.36854930282119786, 10.850048603550082, 47.84227078960788, 65.76724360066076, 65.0763730079897, 65.9565136509557, 58.672354528980875, 58.21851276582288, 57.536577332404356, 66.4644213645689, 65.55996202653455, 63.01956053703063, 61.52309786888861, 56.203406856906035, 52.50620426670198, 54.82573316943262, 56.747592572242986, 57.47686316890102, 54.55570151728969, 56.1190523639802, 53.53550480258081, 53.99116654549876, 54.81294624267086, 53.21327817055487, 54.807286262512214, 50.1719037179024, 49.46273919074766, 41.767201885100334, 33.108946277249245, 48.4309361826989, 34.82505383030061, 19.54242883190032, 25.46899287931381, 19.054664450307047, 8.069787313861232, 3.1737230670067573, 1.0727173738902616, 0.7577403238223446, 0.4030995311275606, 0.08413942140196601, 0.027926367812699852, 0.12668663470615305, 0.010752015288979297, 0.07721846818082756, 0.03125036777477832, 0.030041394845372247, 0.027184350371000268, 0.09931160122035973, 0.023478721794221672, 0.015066388821710023, 0.16503475155801545, 0.17173337840264843, 0.1884970062923047, 0.046127666944577816, 0.010833211032853974, 0.05043786146768159, 0.0899632601067424, 0.016896057678686998, 0.12645454070861303, 0.04202431999146939, 0.08302697746623909, 0.10305843766658537, 0.011226911278020953, 0.053507828589288466, 2.6355557384029513, 0.8532802520259735, 5.450861444396358, 5.860575562523258, 11.221056772816567, 16.18972409156061, 27.952849480413622, 22.795952520062848, 29.630649205177065, 39.74505532172419, 50.59235434378348, 45.19544755258868, 54.736938553471724, 45.83838678175404, 49.389747804211034, 50.31154009603685, 51.0815562740449, 49.53213376383628, 51.76923405739569, 52.26744174957276, 54.18910503387452, 48.28756963053058, 46.73759014375749, 46.208027024422925, 51.13311582996, 52.37697001426451, 56.39765047257947, 57.157876414637414, 54.056560301011615, 50.63586519610498, 52.520132603183875, 53.10798998801939, 56.65530312445856, 52.445089817047126, 57.25515511728103, 60.23594856262208, 58.159830185674856, 47.497463072499926, 16.57347309973932, 9.297089096038572, 50.327429617604906, 53.757193242349935, 54.55800394858084, 41.16083483542166, 42.10201540300923, 60.34218203636908, 55.033685468858295, 56.08787736585064, 50.2592666687504, 2.873769368856184, 0.4332278692914594, 24.44138680734942, 26.961205659374116, 21.689069463360696, 18.045295438458844, 10.489287626358772, 25.00516672288218, 28.989457391923477, 42.65302996481619, 25.448167054883896, 35.1736819359564, 38.6260344905238, 28.29461539945295, 33.632629763695505, 44.7710314104634, 56.96469968365085, 11.623632177229851, 0.2655165750653513, 0.1303288082201635, 0.05237823960581615, 0.049682406843790126, 0.028355131902161147, 0.09859792137097928, 0.13456734287883007, 0.011242491591181005, 0.06835686869078106, 0.01332160537957304, 0.05449185703670787, 0.05872564578068353, 0.07999649451624963, 0.023619252963051684, 0.026565540934942906, 0.09026782602191934, 0.1680208856780683, 0.12294348314284317, 0.12420901442847906, 31.279117445791925, 81.85563718118976, 49.717391229444935, 42.494283799202215, 35.66687683905325, 20.027616216290383, 45.70656376500284, 43.11216692770682, 43.83222779920025, 27.889958197070708, 30.107556466133367, 34.31074873093636, 51.05766511732533, 70.0506365683771, 58.19542177261845, 8.21218406000445, 0.5196032408745058, 23.53546638642588, 36.34192459044918, 75.1084936818769, 66.91821605928483, 41.840079522901966, 45.350279192770685, 58.05588737610848, 45.513030098330596, 22.172946776113204, 1.020900412432609, 7.670757732083721, 42.87929581057641, 67.65377813769926, 66.49638083673292, 64.399054204264, 59.62994237099925, 57.58489701055712, 60.18572261256557, 67.05698951598137, 65.9527717098113, 65.18392832048478, 62.46095618894024, 60.34542975887176, 56.719496634698686, 56.851370642262125, 59.851081678944254, 58.939205138914055, 58.7525591542644, 58.90363316382132, 55.798959501328014, 55.98780593564434, 56.03441938277214, 56.80574171004757, 55.906318695314475, 53.383956186233036, 51.17718758121614, 42.4266033018789, 37.64737567593975, 50.41374137324672, 30.35232020962623, 22.62548435118891, 23.983216708706273, 18.429689676530902, 12.997612953186037, 13.160663920064128, 2.120899586908279, 1.2815876305103302, 1.2887173963169898, 0.1741972857064778, 0.026640596484104474, 0.05595223129456563, 0.07064282143067929, 0.09264969296993748, 0.04218108073297528, 0.0994021374912512, 0.04687266446830285, 0.0694145679834389, 0.08248497025981065, 0.035535681677321275, 0.030499364121726928, 0.16949830156180168, 0.1635697616204139, 0.13189099939359775, 0.08602531536692574, 0.03641767870454538, 0.0876460126751373, 0.04264044237413234, 0.12583150438243343, 0.07774542175954388, 0.08166504167621175, 0.13984830869782355, 0.03871665110871677, 0.0779221046175207, 2.404116286385444, 4.06492258752546, 4.446308122527215, 16.168376591897783, 16.1145342165424, 19.66070398207634, 32.409262118800996, 33.636053992855935, 26.0209939172191, 39.01935408192296, 55.047539280306914, 50.11305247583697, 55.946562213282434, 50.183168765037294, 53.07417131239369, 51.00624284436626, 51.356153565068404, 52.06975037051786, 55.0004316145374, 53.91611983699184, 55.62026808338781, 49.54534430657664, 49.86770037681826, 46.20778383747224, 52.3681015353049, 55.69756231000347, 57.14513655631774, 58.10607802483344, 55.85416293913319, 54.84600397848315, 53.65426240428802, 56.06245256239369, 59.4892430305481, 56.71537030127741, 60.17379468487155, 62.33907245820569, 59.499245074487504, 42.817043873571585, 16.254134312752758, 16.35745248486919, 54.26972150802613, 57.127156411447835, 59.075629095877375, 45.632070110690215, 47.97085785096692, 66.6605555626654, 64.06825327104139, 63.10202836990357, 46.44695428109939, 0.4314071847306144, 2.551423839984402, 33.24338551490538, 28.85927784827448, 23.72126513911832, 26.853820969981534, 19.458166514673543, 22.943304200326246, 34.307320579405754, 25.38842151241918, 33.65685039950956, 31.80486998250408, 36.448048237831365, 36.998478366482644, 26.33787435870017, 53.55485385464084, 64.64061337132608, 14.412777635358996, 0.6141961005426223, 0.08791212097651536, 0.1837203101885896, 0.005053040776176439, 0.048049869646708813, 0.07303721391625943, 0.04982977151690472, 0.10774912507904154, 0.16412586484464908, 0.11655553559502287, 0.2391451474038824, 0.1722719688569346, 0.16349341329788009, 0.13206876243554777, 0.23211051439566, 0.18179654083665342, 0.2619958188264601, 0.35940408225982423, 0.24171253786452357, 41.471200220046505, 95.1256508981028, 60.1204582952684, 55.10666901065458, 34.55295901144705, 16.489336298358058, 47.35067229117117, 57.682858205610714, 77.6659574816304, 28.86670485619576, 30.81124732571264, 30.26313727901828, 46.52434264459918, 78.00485810925885, 59.38894410287181, 7.369002930579647, 3.3134854512829937, 32.199760483157256, 40.302616319348736, 79.95542926173057, 71.36118673509168, 49.4823863429408, 53.526957957975334, 64.43396329879761, 44.79558937011227, 18.06574079298204, 0.8461580858115227, 13.13911932130014, 54.08844524814237, 69.67239456792032, 71.5226314913842, 68.62865970980737, 62.789890073960834, 59.90261770063832, 59.74718201544977, 71.81655037787654, 69.00243020826771, 67.88081276801326, 66.52201744817918, 61.983701798223684, 59.019790234104285, 60.5701345013034, 64.57252102513468, 61.52361562175136, 60.59254300209784, 63.34731378862935, 57.31842687053066, 61.11353182023572, 60.14201171936528, 60.23768225023824, 60.68956282831008, 59.209574114891794, 56.235550680468165, 54.09390126505206, 41.91646768200783, 56.426777993479085, 41.46650122058007, 28.334223493453, 31.754249834245254, 29.334908377739694, 22.404258751100112, 26.036775573607414, 3.8270416230924673, 4.33825368842771, 2.1594292742590753, 0.26898741301509643, 0.11168102538513561, 0.20201467368150913, 0.15337291684362198, 0.29823686446874376, 0.22047465006189965, 0.1983405006749015, 0.14228632222981225, 0.20972053760722761, 0.22936433433525025, 0.20586493965839187, 0.4241159275895165, 0.6645346961675153, 0.5740295590892915, 0.15414582295042856, 0.20403280974395815, 0.1556847097292062, 0.18919296652799655, 0.19500840124824356, 0.30684505739519674, 0.11474739189349836, 0.18790339540329673, 0.5300032828123339, 0.1634357115554233, 0.19227899851337557, 4.7949592721077705, 4.377522497407852, 11.558359034599798, 29.085343653155913, 22.193078341022616, 25.087695352492798, 36.39308798697687, 34.86805085212954, 36.34163041268626, 46.48371081198416, 55.642853090840006, 53.63692552812638, 60.45817436710481, 51.521697198191, 56.36929173623362, 53.76938004647532, 56.40610318030081, 53.0665893708506, 56.20310875677294, 56.54097780104607, 58.84041240138393, 52.80378272456508, 52.901461508966264, 47.88434213207614, 53.97957201926939, 57.05088200107698, 62.538599506501235, 61.84146488866499, 58.33653688430787, 55.6129018722042, 57.29132329263995, 58.401299138222974, 61.839966543259166, 58.99029008803829, 62.567087681062766, 68.03468734987321, 65.64938029935284, 51.826010365639966, 21.71275273446114, 14.003073323157526, 57.525359353711536, 62.72362555226972, 62.293592576057684, 50.02020605148808, 50.447575738353116, 70.96170117778163, 65.70274022317702, 68.23128438765004, 60.03644504854756, 6.219921054378633, 1.119533435952279, 34.42289321653305, 39.99967598146008, 32.80971257917343, 24.01226382101736, 13.80145270978251, 35.46571416239585, 38.79390016678841, 56.972818989907545, 36.145292251340805, 44.24603393000942, 53.96534950502458, 39.98363348745531, 48.11402436225645, 62.58411076761062, 78.23119455768217, 23.475954224986417, 0.6810595191294148, 0.21631663124407494, 0.31352537473843944, 0.12809060574058564, 0.18422577500102982, 0.22123053369502868, 0.20803589493997637], [0.046200361027712786, 0.022078860821502826, 0.11952575040800918, 0.0967544686770247, 0.01251902198418975, 0.10758879819824811, 0.14225178698618568, 0.03264637341001823, 0.04037027870635352, 0.11808032635599376, 0.11863594694483666, 0.32798654069342925, 9.83520886590404, 77.39288991497409, 56.23410332587458, 31.692437202699725, 49.51784456929853, 41.56433689978815, 39.51321186557893, 26.351690907632154, 49.18508637335993, 49.90860285297517, 19.993505324086836, 19.280979325694425, 18.393884320412916, 59.17621043420608, 65.39648940486293, 22.576715561651415, 0.2952302758011126, 18.695265516158074, 58.33705463717061, 61.584812441179835, 69.91685236653974, 53.00961302172754, 25.064065033389678, 52.59923896481914, 62.6309399450979, 59.024477466460205, 24.67744092787466, 1.3842164460689792, 10.128660990345864, 45.974214538451164, 59.88668895536854, 57.322141355083836, 59.4437200023282, 56.538702826346125, 61.74670827004218, 62.82199467382124, 63.36715313696093, 61.00035575128371, 64.0396160464133, 57.34915864083075, 59.926936395706676, 58.84822184039701, 60.81885591630013, 56.34741667778262, 56.40021570267216, 53.98762856760333, 54.546248605174405, 55.952692877861764, 51.65985876514066, 48.91289349525206, 51.9093018962491, 44.833907004325624, 43.51996006504182, 27.791324315532563, 28.597183112175237, 23.286911672161473, 17.8371823218561, 19.29096175778297, 12.625516326196733, 11.060868155571724, 11.40328714924474, 4.728963923069739, 2.943831235170365, 1.2631911015318287, 0.9927328916326646, 0.13609309891058555, 0.021153146986879652, 0.07597785773536853, 0.04051799577991328, 0.042852070332775195, 0.011902641046852356, 0.04327401240927078, 0.05724432284853632, 0.0510047052446152, 0.029324361446103262, 0.028646293193882996, 0.28515759855508804, 0.1512643364408324, 0.1428795960401335, 0.04824958110768949, 0.08686852536254352, 0.04607990902337817, 0.09907012264574729, 0.05961908816149639, 0.07272550040074895, 0.012053522063539395, 0.0873089722928501, 0.029326414561740337, 0.13720230229439276, 0.07542007677857915, 0.2475661850504337, 4.108451335660873, 2.0273705475753356, 10.671900433878745, 18.723004518016694, 15.65542765202061, 11.559246470851283, 25.39774302513369, 17.476938116934992, 17.113767823865338, 45.214839750720614, 51.93201241954681, 47.95425053565733, 51.36188022551998, 49.209322698654674, 50.57651973539784, 51.74926527084843, 52.15575225891606, 52.3769425576733, 52.20930830124886, 50.38067187032392, 50.88873647874402, 43.48328590393067, 45.61091284598074, 52.39439710494011, 58.43632982623193, 56.984209552887954, 55.25410698306177, 55.548312202576675, 51.61057418392551, 50.330481221598966, 52.481999320368615, 55.630929085516165, 58.582108636056226, 58.44732422982493, 58.69971698330295, 48.21359765145087, 29.796747853679044, 11.22890543553137, 40.83415239087997, 52.19557608327558, 48.48864209267401, 54.25397711415445, 39.25629661929223, 44.41636285474224, 47.58348065037882, 53.40988697544221, 58.02296300088206, 7.091077018168665, 1.2709462402328369, 35.54214938994377, 39.72968355301888, 34.60693866975846, 27.716575707158736, 10.191475787470418, 18.168361763800345, 32.684334016615345, 30.958734327746978, 37.62719508140318, 21.859737673113425, 37.55367025252312, 29.549430647204, 23.91244342250209, 25.804118225651404, 51.311258116076075, 44.47719881611486, 1.9365603236421465, 0.1444710670940338, 0.11110062185194224, 0.12995970705824514, 0.13280547854881133, 0.026074403881906502, 0.0744376686071196, 0.03375850324969619, 0.06303776701491687, 0.04893723695028213, 0.03923222828175753, 0.03013877419664735, 0.026368110500756773, 0.07955309048655533, 0.07989720952126288, 0.008461092553672292, 0.09563708347418616, 0.04727473422404259, 0.22481139719245896, 0.4574865030665552, 14.966333893037612, 92.3370575135754, 62.391392953934215, 31.11625083031193, 51.170900021829915, 27.61678276523467, 40.00870919996693, 32.47842331086436, 38.183744107523275, 43.89921403700306, 28.45378910341571, 28.56632778721471, 32.40114673491448, 63.909671844974646, 66.03888342457434, 34.0380734012973, 0.8916534735791145, 12.999497652053835, 61.42342652043989, 65.66727022970876, 65.17715830956736, 54.91912872560563, 29.53374508888491, 60.122748959449034, 67.342083069586, 63.39223669421289, 33.70133399963379, 3.0151100168305063, 8.488437571833211, 43.78128797777238, 59.08698043515606, 57.250934646975615, 60.383680712792184, 58.32933933504167, 64.99087710534373, 62.71040716478902, 65.48598612508466, 63.55308525023922, 64.40436509347731, 59.34728068690146, 62.26091531015212, 61.08113696498256, 63.07818035925589, 60.19212392068679, 58.12312856797249, 56.980145977389434, 53.78847806684433, 59.696618741558446, 55.11443922596594, 53.86732555204823, 51.89858205856816, 49.925068962958555, 44.87442116583548, 27.739084228392574, 28.714662021206273, 28.253081421698298, 25.535530005731893, 22.18838914748161, 16.07892595952557, 20.72963026262099, 19.121964477723647, 6.200530817431789, 1.2355969822214496, 4.6503650180755125, 0.05382000175755351, 0.09034118660154844, 0.06888703217790013, 0.036369710109166564, 0.04098732039452561, 0.06929935602050635, 0.08206271791770574, 0.08118952324073161, 0.08654001153885357, 0.017691494431346655, 0.048029702382102135, 0.05822129179573348, 0.24376698649458348, 0.04775540843125313, 0.12423296999787131, 0.04890965778500803, 0.025011309415041923, 0.06530634488069242, 0.03875235463642786, 0.011099336571210336, 0.062152073613458106, 0.028610792679471836, 0.02751727877635389, 0.030864855094302087, 0.03162551911607866, 0.07145237718378344, 0.3963281106083624, 4.421345178158053, 5.175206094018875, 12.188274033607977, 26.104624732848137, 22.653774446056737, 16.707331826609952, 29.464738830443356, 27.768101922927368, 22.423603880789972, 41.28100056802073, 55.570387301906464, 49.932113539788034, 55.067719874843476, 51.175551952854285, 53.96329418305428, 53.68825366420131, 55.312228664275146, 51.75773759042063, 53.551472771552305, 53.50509074426467, 54.54329113806448, 46.42434573942616, 47.28385863765594, 56.37428099109281, 59.888665829935384, 57.01518058776856, 57.35104922325381, 57.13823318481446, 56.36215302252001, 53.908463370415475, 56.96100088857836, 56.700422148550714, 59.772245960850874, 60.820915160640595, 57.52921112122075, 45.265669745783654, 34.11130797478461, 16.6033007637147, 49.71743437551683, 54.80171649686752, 54.948142497770256, 56.56905804910968, 44.84463468674691, 47.603578875141764, 55.770541929429584, 60.50869057255407, 54.004628119930146, 2.496940157105846, 4.933846477539309, 48.48567285845357, 39.09993525474302, 38.23085177329279, 35.167009984293294, 24.101719356352284, 20.71994200829537, 34.50172501225626, 29.776633939435406, 27.62280164226409, 32.71997071081592, 26.03183730956047, 37.154737749407374, 20.43690181547596, 27.489784263795425, 62.211097286593535, 53.9086869455153, 3.0570707974895357, 0.34515723706253115, 0.03761718853286678, 0.060209948794856194, 0.06363671753675708, 0.06065956962805602, 0.06782710356938262, 0.10946947510444349, 0.1863987987200099, 0.14000655181946295, 0.20177925486237774, 0.13786256283281312, 0.13086344566076033, 0.1780086344168071, 0.35443272321454944, 0.16839179480748792, 0.20536646156782107, 0.3521529068389247, 0.41910620286099376, 0.829715510049174, 22.176927981838105, 104.46988982539024, 72.19710657673498, 45.70744237592144, 63.12152254965998, 55.235091332466375, 50.5776297661566, 36.130312719652736, 62.32299858523954, 68.36702977457355, 26.37674112473765, 26.317325061367406, 24.94245586856719, 67.12876889013475, 73.23880180235832, 32.875125946537146, 1.7145261024275136, 23.741614395572295, 68.89961704131096, 69.83868737374583, 71.82809783566383, 60.77732978328582, 35.19724753595168, 66.06724216092017, 74.54223678958031, 69.87145485416536, 30.105724719262895, 3.0097135709178064, 12.00617015361786, 53.54545585570797, 62.921909209220644, 57.37560718290268, 59.12995392276395, 58.31795269443143, 63.9896725070092, 66.75834809580158, 69.23484633045813, 66.27491597206362, 67.34122799288842, 60.783044676626886, 65.76081483594834, 66.33382997205182, 66.82290246409755, 62.34828610574046, 61.03140131119759, 59.643651054751494, 56.50437816496819, 62.67487049102784, 58.56496787840321, 56.81481415225614, 58.39840442903581, 54.22504178939327, 53.795718762182425, 38.15961760859336, 36.519827611984745, 36.80200292218116, 28.311116810767885, 28.54692186078718, 23.819698979777677, 26.71395709437709, 25.5391562369562, 16.811251101955293, 2.8627798682258976, 6.8438804245764215, 1.5371686580681032, 0.29647593476599265, 0.2244971632476776, 0.16588533898034405, 0.18522447786263882, 0.1563243778242219, 0.13755643409827065, 0.18308264924393547, 0.2072968652411815, 0.17412680561744398, 0.11803262972182806, 0.34005545920902686, 0.5853690699704233, 0.3710591600787255, 0.5420913535260385, 0.21555052799803598, 0.1344841457302532, 0.20055746719721826, 0.16164383190053125, 0.20388994966783833, 0.1746183735949378, 0.09181599012546002, 0.1984088203959888, 0.15641281501420085, 0.35855421496014445, 0.169837080963677, 1.1942344855877662, 10.142104914111476, 5.378201988435561, 27.99561116003221, 36.82178735733032, 27.201533202202093, 19.041573539856945, 31.68350596581736, 30.367276207093273, 26.75699333990774, 52.3662894002853, 57.233303593051055, 55.41546936958067, 58.5601943539035, 54.675663286639804, 56.101111442812034, 55.65927213238132, 54.907836221879535, 54.5188900732225, 56.26408200110159, 56.24380334731072, 58.17112268940095, 48.80258467889602, 50.30415427300238, 58.377851209332874, 63.87260152447609, 60.40814453555692, 60.657128749355195, 60.460037492936664, 58.18143460058398, 56.760626608325595, 59.77483864753478, 60.0184178352356, 62.17849454572124, 63.596615714411584, 61.52409022854221, 52.33122341094479, 38.39651699989073, 17.377647238392985, 49.41412141246181, 63.09782358907885, 60.11259002070273, 62.66310730288106, 50.05018080434492, 51.2065779009173, 60.97423276593609, 59.980402223525516, 70.871227787387, 10.425639325572599, 3.288848799082541, 42.4839012853561, 54.82008887875465, 45.73933124542237, 34.852145641080796, 14.575062759460943, 26.95657922375587, 43.935350833400605, 40.221964543865575, 50.92508900550104, 30.293616056442264, 47.97704342872866, 45.68492404876217, 31.00250013412968, 41.14377252517208, 70.78262144519438, 68.91626358032227, 5.172972794502012, 0.6509412933261164, 0.27848696456320826, 0.32700325152085674, 0.27398046767038686, 0.1506484783585033, 0.2864045751911979, 0.22744914516806605], [0.04360629921598781, 0.0557911153432102, 0.07712413211383166, 0.019579786251509385, 0.03415638633492974, 0.03782192936107036, 0.11132205956645551, 0.035267370873160904, 0.010205017019724174, 0.07694441554767471, 0.12829008737518904, 0.12228276295166825, 1.2343707512463293, 47.55316857368716, 70.29638090441304, 43.58645992894327, 43.66182827180432, 69.16279239039268, 41.78184409295359, 42.42224947098763, 31.43519836087381, 44.80469711365239, 21.056369581530173, 28.88048806498128, 18.288758916239587, 29.34338461968207, 86.57885336106824, 54.281053235453946, 6.391896393991287, 0.5536272280639218, 30.935376613370835, 63.28696027878792, 60.97729221467049, 74.90780168964018, 59.1402619115768, 45.50683275345833, 55.46255350112916, 53.36420313004525, 61.229300575871626, 34.39644467446112, 5.002418333484281, 11.925072208527597, 49.43308999461513, 50.6232939997027, 60.26026333532026, 54.038658603545166, 60.88623046875001, 60.96331288737636, 64.51304220384168, 62.95888539283507, 64.59304678824641, 59.99954731233659, 58.35337169708745, 57.11130219121134, 58.739870286756954, 55.34563549103276, 58.338062686304895, 55.58040895769673, 54.07781954734556, 52.579074059763265, 54.05006877837643, 51.18877034033499, 44.81430299820439, 47.03310543490995, 24.451794816601662, 10.578694132066543, 18.077786391781224, 23.616612380550755, 17.526644352943666, 7.610595928084466, 12.877818865160789, 15.794730628690413, 10.066714998214476, 2.673891268430218, 2.6190933056416053, 2.0786703690405814, 0.02531244134109828, 0.019987998117182045, 0.1586106140166521, 0.0635837272350346, 0.048020919184050256, 0.013370770029723646, 0.030565732233827154, 0.041825765323254376, 0.04429380950187484, 0.026105757945427494, 0.016553729374502456, 0.06080470115487134, 0.253532508448247, 0.00555875696121685, 0.03536017859474786, 0.05075022232748809, 0.007590741499312103, 0.029852649933027647, 0.037246907595545053, 0.03798610200324366, 0.05912291599557765, 0.08494621923854274, 0.03394713707929177, 0.10391221967555823, 0.06611924843802568, 0.010865423114850156, 0.4591869731103221, 0.5648710698850694, 5.72956447639773, 3.069322320722765, 9.535078906243848, 21.35010019425423, 34.2905681363998, 12.682491694727252, 14.526064511268372, 16.997553879214873, 22.24584794813587, 42.51376228947794, 50.2188152651633, 48.05164298703594, 49.259815369882894, 51.71166543037661, 50.610079534592174, 52.95240133039413, 52.88629762588009, 52.00157565455283, 53.47987382642685, 48.05074868663665, 48.285753573140795, 46.8926179024481, 51.74005162331366, 56.782646794472974, 56.06902645480249, 55.07551362437587, 52.872000586602, 51.02825910814347, 54.61402323938186, 54.1931176185608, 57.313853386909734, 55.69434596646217, 57.69757101612707, 39.9885521396514, 18.922868890147058, 32.51289113875359, 31.772479049621094, 45.600997094185125, 54.7129258032768, 55.37538666878977, 52.07976810393795, 51.780832505995235, 64.99020638004427, 36.05235953484812, 28.569773589411092, 6.9525771467916435, 0.3821954737988211, 34.07504174017137, 58.58802357027608, 43.61548939058858, 42.009361174798784, 17.2425353142523, 12.338788124822802, 34.92922413733698, 25.2009851701798, 37.81816351798273, 27.427287178654826, 25.051258494777066, 40.500723469641905, 29.410680724728493, 30.639918196585874, 39.26809510877056, 53.800782542074884, 35.91096985724665, 0.7257013623752903, 0.03038525724062516, 0.03996405675406418, 0.044819709709695274, 0.024044303441300027, 0.02524369069555354, 0.0774949339909419, 0.06806913372730056, 0.03773169569490898, 0.04055368398586589, 0.04957984682292708, 0.012280060008408563, 0.015222621920158066, 0.06745273938342448, 0.06268326748883532, 0.05756485403605527, 0.01635612274009374, 0.023400667010836547, 0.011189667913582058, 0.20739045054201158, 2.104244712860354, 58.87257975916709, 81.42591014985116, 37.43719547025619, 53.26309227174329, 53.77025473502375, 29.689618118347664, 50.547541264564764, 24.534223425772883, 39.85793721291327, 22.43075632279919, 29.09889740328635, 28.433690878652758, 46.03186945761404, 80.73283518514326, 62.27653418817828, 11.853016307277064, 0.3089748737552474, 23.802150295626735, 69.60347067925238, 68.15228000763925, 76.01911114108178, 64.212172877404, 54.993732206283084, 60.18672673932968, 63.18347638653171, 63.871326754170084, 45.0751837607353, 7.912013405753721, 11.93291694887223, 47.94842189358127, 48.488834288812455, 58.886563008831395, 54.36948699335898, 59.04404617124989, 60.83085836902742, 65.07506293635215, 66.17063583866243, 64.75427581417945, 64.0662803188447, 60.62829148384833, 60.511255802646765, 62.85211847674463, 59.280278759617964, 62.157345125752116, 58.66055603950255, 54.68214304216447, 55.070394931300996, 56.025484223519605, 52.32973683264948, 49.95240396068942, 49.289582237120605, 23.311006792130012, 15.660527713837164, 26.72109776927579, 33.54627878435197, 18.137224028187415, 13.078874657230994, 25.82547357005458, 23.323611328678748, 13.849172265298906, 7.790400808857334, 6.326160411680899, 1.4305424570075929, 0.05876255206643574, 0.024988183135827704, 0.06296201241052439, 0.07342061027884483, 0.04169257327673897, 0.04791918270770581, 0.03720985575308723, 0.017895306377942045, 0.019210311621727965, 0.0543216782652082, 0.04416483476938259, 0.01131817437483058, 0.36029418449728723, 0.07138454009808841, 0.06254686936435681, 0.10154747479264775, 0.03393366925358292, 0.0340694889816786, 0.06553119168646875, 0.06191071761291354, 0.02320434740414062, 0.09760945344403868, 0.019633343458295833, 0.058895012498983455, 0.016403993659262216, 0.07615526837687339, 0.18336047869055502, 0.5521959306732301, 9.358039786738734, 10.756063711258674, 9.990520996432151, 19.971112512773086, 34.93003999033282, 15.483583711808729, 17.332904761837376, 30.00524732374376, 27.860511003002046, 41.64287059537826, 54.7496941012721, 51.918664593850416, 50.44360237736856, 53.785806932756984, 52.36164531400127, 53.211113022219756, 54.452594172570016, 54.73111383376583, 56.50344464086718, 48.670808730586884, 49.47955831404656, 49.02709330281904, 53.27493782966368, 56.02658248716786, 58.45587499680058, 59.07276184328141, 55.5537917537074, 53.436390430696555, 57.807173805852095, 57.50167608261109, 61.955586248828524, 58.68578864682106, 55.030155335703206, 34.65133990010908, 16.70859482980544, 35.72699892905451, 40.5047752780299, 49.82700578628048, 59.313026628186634, 61.60021951121669, 59.591181508956424, 53.50109777142925, 62.76037816078433, 40.81484648489183, 22.50357512504824, 2.530135421022292, 1.1496050223227472, 45.27958239278486, 58.8855706491778, 44.32864296820856, 46.027033175191576, 30.582118149726625, 20.6198803840145, 31.254129986609186, 30.81552859275572, 24.900684587417114, 31.398116273264733, 28.975835000315023, 29.47263260041514, 35.70666143971105, 20.154224441897487, 42.594410142590924, 61.15932941436768, 44.03903476653561, 0.6133615550014281, 0.07938342499396495, 0.13203431912247213, 0.023635813868754817, 0.06344821394210862, 0.045356132135155706, 0.07065229793830265, 0.038650058915898684, 0.10450949246484427, 0.1317814947857011, 0.16327739182499149, 0.1803762138250374, 0.054822684445929144, 0.1982512361099643, 0.1476037231904845, 0.2786587827628659, 0.24509654740893075, 0.28976270628552286, 0.26085888305979393, 0.4000136370380079, 3.3617055992926326, 72.79249098993117, 87.96853342363912, 56.01375633670438, 58.36142040068104, 83.74083026762932, 53.01344909975606, 56.06200541219404, 44.41664526539464, 56.556867322614124, 29.23943984893061, 39.17248733582036, 25.78344145128804, 37.942832131539625, 95.72285529105895, 65.97868288716963, 10.491210568335749, 2.2879771119163883, 40.01367099823491, 76.6507225651895, 72.06653871843892, 82.63364714960899, 70.43415807908582, 61.05271939308413, 63.60230707353162, 65.09486698335218, 70.01539015000867, 41.1626705046623, 7.073507741574319, 17.638174987608387, 56.99438418111494, 53.76481832996492, 61.284802113809896, 55.68455965288224, 62.29497325035834, 60.597402818741344, 69.27268151314028, 64.99111636992424, 68.84195035503757, 67.37383073376071, 64.08195411005329, 60.807273157181285, 64.20083722760602, 59.91877002100791, 66.07491431697723, 60.57227219304731, 56.79972871657341, 59.354388021653705, 59.78432293861144, 59.13399788641161, 56.542087831804835, 55.950625788780954, 31.745212693368238, 19.02349533573274, 29.230487039012296, 35.85179698082709, 24.32572787807834, 15.139244717936363, 28.29959288720162, 26.479191472453458, 22.39969115103445, 10.970755623232934, 10.03421914192938, 4.358195018383765, 0.07810897644489043, 0.11567944510569496, 0.2083946539149169, 0.18697109704296436, 0.11028854566956721, 0.11121935015844722, 0.078738417266117, 0.0836563723221902, 0.1618038370243965, 0.09942180296826748, 0.28494772110735217, 0.22843145374809543, 0.5540830810223857, 0.15088064896483577, 0.16376316817777772, 0.18195387997454215, 0.11549647266585981, 0.20751622685741997, 0.1220347726296994, 0.16351281064412287, 0.1375136710703373, 0.27673872127648325, 0.1008703756416517, 0.21821073767158294, 0.12825871607468975, 0.21260524168610576, 0.6453529577101431, 1.688280297863868, 13.870912001978967, 16.703211376743933, 24.421259164810184, 29.887972377961685, 47.22388559772123, 18.405614168413226, 22.795909373990952, 27.38258392580094, 29.22339539374075, 47.96043611341908, 53.61543093958209, 54.107743309390166, 55.23993153725901, 55.92407526508455, 53.778405420241825, 55.00169069536271, 57.12220638029037, 58.599280772670625, 58.75538326078846, 51.2323792519108, 53.386686155872965, 49.74212569575156, 53.960752487182624, 61.2446762669471, 60.00836480048395, 59.72311827444262, 57.544971204573116, 56.54626515603835, 59.03757818283574, 59.592962265014656, 62.608986439243445, 60.64175305827972, 57.44539399300852, 44.15767861950783, 23.659601557639338, 38.25875159232847, 40.75863892032255, 57.52902676982265, 61.81327481423656, 63.517866288461995, 61.02546676512688, 60.86281784119145, 69.44918032615416, 44.06337307345483, 35.36248130183066, 10.365535866829658, 0.955737954185855, 41.58695328620173, 70.50219551209481, 52.956974814015055, 48.86404037475587, 20.80165086253997, 17.12731961281069, 50.596119819148896, 35.288630916226296, 48.888704238399384, 38.247388485939275, 35.468302926709576, 57.02063660467825, 44.30966261894473, 44.24289211150139, 57.921612877999586, 70.70201673815328, 56.45325006977205, 1.1678035941816147, 0.24045961638612134, 0.20463903044019977, 0.17989990631899527, 0.20203483711567619, 0.14272421808733096, 0.15088832516583706, 0.20795691127498306], [0.019677362870424986, 0.04274629274263017, 0.0607183936893219, 0.01500872155320981, 0.007133876347178294, 0.019726442293294018, 0.05129314883942566, 0.03291963697260907, 0.02753400247574093, 0.01663543648206659, 0.03225429727125072, 0.12252313835966973, 0.33559848223963096, 23.015585637861683, 72.68868154095065, 49.65522166221373, 27.370193158426595, 43.45350334721227, 44.41172661319856, 34.185460382892245, 35.77345940374559, 37.108418480042495, 39.035749589243245, 39.25759884618944, 30.910349930486372, 11.853044744460814, 69.25426990755143, 62.06949972337293, 47.266623743118785, 2.3161451230126047, 0.11620142677378272, 25.778440429318337, 65.82589872421758, 54.5163405326105, 60.20549528060421, 60.22542876581992, 53.0483542719195, 57.098362292012865, 56.66162990754651, 54.559494449246316, 30.718738225198564, 6.248921098247652, 24.742901363680442, 39.15704888682212, 50.073597354273645, 55.44452628781719, 55.78568227829472, 62.7661911133797, 60.92193972679877, 60.428317285353145, 62.122475254920225, 62.08584423988097, 61.140823671894694, 61.89420900037212, 61.604122269538145, 60.175979445057536, 53.54317303626768, 49.87554511716289, 47.94592334378151, 51.54145417674896, 47.48099304014637, 45.81353464434224, 47.63844482360348, 22.944020032882694, 8.842805085643645, 26.71351778891779, 29.41700750781644, 17.36681757434722, 9.378845018725242, 21.881726480299427, 25.468371183641498, 15.453190245935994, 8.501932486411064, 4.685864429320059, 3.7105599766777413, 0.3197954979635054, 0.10198725522646021, 0.06216605854851585, 0.030586470233937426, 0.019309864747488213, 0.08936915892146288, 0.03196345965167688, 0.08186611677369765, 0.05247533358933945, 0.011976993710343397, 0.0564681685289308, 0.0541853720712806, 0.03625064855441451, 0.20734799394924797, 0.10611388742202714, 0.04143931993073033, 0.024456826466766578, 0.08987851546055849, 0.07114822495608561, 0.02039510107058431, 0.05377160798337671, 0.04096404281294635, 0.09581450943744953, 0.03415155232012753, 0.023262723303970792, 0.043267401070484234, 0.04071360484005944, 0.07184895025866647, 0.31404410819372824, 2.4555831763052174, 6.905703352343652, 4.465008022323731, 7.693486886639749, 23.02924725317186, 34.06268627412858, 8.216238810170083, 11.649697307617435, 21.258240246003677, 26.397953302629535, 40.457440114790394, 51.716689986567346, 51.94973368798533, 49.91108179092408, 53.10967660719349, 53.54423207621421, 51.8158749611147, 52.15343806051439, 57.13743302129931, 50.02879604216545, 46.19019985198975, 46.565390248452466, 53.73399242278069, 56.263364207360056, 55.052406941690755, 53.10978643355831, 56.188788183273815, 51.49370324227118, 51.9466781616211, 52.24772399471652, 61.48812209406207, 49.67592785435338, 35.27829547082224, 8.453046025768403, 9.03782238883357, 41.74267138204267, 47.48839455266153, 43.815565570708245, 49.385127252148045, 45.748792002277995, 49.333638298896055, 61.7893522785556, 50.57007135883455, 29.87305756538145, 11.279077452998008, 0.16353265232136174, 14.68696798047712, 58.16148542588758, 43.45277378636022, 51.10317637843471, 33.273070012369466, 8.320573856753688, 30.115711073721613, 22.166800422053186, 30.698630194510187, 38.33573202933035, 26.23231945499297, 38.1460815091287, 31.526097328432147, 37.69240448551793, 32.151383930636996, 47.266647277339814, 46.27650376289122, 13.624093917108352, 0.3311951314249347, 0.042507771267405445, 0.022035641971254544, 0.02247940989271287, 0.04289648428018536, 0.034454758429238876, 0.041626406262718865, 0.014442892842775872, 0.09737659335857439, 0.04310522408735368, 0.03686315117163524, 0.0274604216458336, 0.03288542731635032, 0.05751180627773847, 0.010309995005598233, 0.05136627959267748, 0.040083114478376605, 0.039875757459911614, 0.05996632134361614, 0.18664938608004203, 0.1981324618381839, 30.63414250650714, 83.55560025861188, 51.38099001299951, 32.547225606056955, 52.05095437265212, 18.986417170493834, 40.446061318920506, 31.118000207408784, 26.139451457608132, 35.99130392074585, 35.458355795952585, 33.03129903731808, 23.00575225583969, 71.56547946314659, 58.21557098819364, 63.411538677830855, 5.626479195010278, 0.5309085535906977, 19.345516043324626, 67.47451013134372, 61.1917870275436, 64.73906486265122, 66.53182337360998, 56.63725237692557, 64.04918662963375, 63.46882489419753, 58.1107456453385, 41.04159085981308, 8.958904300966571, 26.41675518405053, 43.22505274126607, 50.99938654130506, 56.80584369167205, 58.147600235477576, 63.16393121596306, 62.125436644400324, 62.26592417686217, 64.32081860880699, 62.74291969114735, 63.52748394012452, 64.79102842269405, 62.46173281823436, 62.061180376237445, 55.783466139147365, 49.26962521768386, 48.901126384735115, 54.16297420378655, 47.92356191142913, 53.6908620403659, 47.15448317989227, 20.997630127014656, 15.610235083487728, 39.47860871591876, 42.37696178497807, 16.93924980778848, 15.138155279621003, 31.02181584604325, 31.357329507027906, 18.89913462823437, 13.932239240215672, 15.467248020633576, 3.1675882349091196, 0.06248795720297964, 0.1112165692592821, 0.050557738906073, 0.026484303056232394, 0.042240555968976794, 0.05825401524141912, 0.09504044653787729, 0.011560155694643337, 0.005769290850542847, 0.07801759747728225, 0.006203345255926252, 0.016322307619116, 0.1048536268213103, 0.9739505607754955, 0.04594377902967315, 0.09845035751500437, 0.035722335169632594, 0.05752227486922376, 0.08324724306622822, 0.05772200165196292, 0.03395771292308646, 0.06760293858185892, 0.042115005649506085, 0.10442375190435879, 0.012726062033776075, 0.05480897913296377, 0.022607947955088272, 0.22762801137662705, 0.27886384917843726, 2.5832619638212266, 12.99645487339266, 6.824210228458528, 10.040259591994747, 19.127165540572136, 31.449713091696466, 10.948949206259943, 15.075367939087654, 37.70076697872531, 32.9744246698195, 39.308142508229906, 50.66804824336883, 52.8065989863488, 51.37976623350575, 53.057505161531516, 54.013578968663374, 54.218032513895345, 54.866192417760054, 58.586070229930264, 51.97128318971204, 48.07337291779057, 50.09172262683992, 54.64189167945616, 57.993960995827955, 59.300282847496774, 53.90870655736616, 58.96514377286358, 55.33123254776002, 56.8234629784861, 56.04107564495456, 61.330478114466516, 47.40045109102803, 31.33063581682021, 8.31781643052255, 14.079989041051558, 47.37902710514684, 50.246777842121745, 47.52340170644945, 55.70210833703318, 49.02743454902403, 53.88048510397635, 60.97173029376615, 60.14534181164157, 33.307782988394464, 5.026689960110573, 0.6852662611392237, 23.987309701981086, 65.9574628645374, 54.49297105112384, 59.143639072295166, 44.47812449547553, 18.764787566277292, 27.288170514568208, 24.3868129099569, 29.888211642542196, 23.872690200805668, 34.19768641071935, 29.05505903305546, 32.81915176299311, 41.56130883001512, 29.189651243148315, 51.58437667354461, 57.88402088226811, 16.578344683493338, 0.27587766909310896, 0.04100073842451938, 0.14179622514113305, 0.09839470888818465, 0.030423347132220387, 0.07214070718374944, 0.01843813521366927, 0.11948837297818354, 0.16192195246056204, 0.12109681287960661, 0.16635429204231308, 0.14428264010817776, 0.08601577757226844, 0.1329688544595434, 0.18084099936869838, 0.1657255790046146, 0.1301205395570686, 0.24955013826970132, 0.18232308838876987, 0.35294936248852365, 0.5840287225381021, 42.66852332699684, 93.7226975348688, 64.72104941644977, 39.07415351560039, 56.0344821406949, 56.754566546409364, 45.85797509839458, 53.15550165791666, 50.8805779487856, 53.61896107273718, 52.24061665996429, 41.53622135039299, 14.884400483100647, 74.52345648119527, 75.0824805228941, 60.765986288747484, 4.764052466038735, 1.6946887152810253, 33.54014811977264, 78.55895565402123, 66.32986053343743, 70.40374402076968, 70.61457926227202, 64.54294635403541, 67.9508819887715, 63.66945020614132, 64.20729344890964, 38.155000978900546, 9.351237416267395, 32.124860863531794, 44.46252130693005, 57.33054307199294, 58.10443062936106, 61.6335988813831, 60.16159611363565, 62.34973346033404, 67.60616840854769, 66.45019100558373, 65.5211893973812, 65.17294176163213, 66.40680959147792, 64.56907718412339, 64.9339674365136, 57.31883871939875, 51.4764291240323, 50.485450144737, 58.140257558515, 51.27568221861317, 56.59851897147394, 52.27589837966427, 28.752734507283858, 18.80349547632279, 39.37262235149261, 42.42342225966915, 24.51186787697577, 15.489579054617113, 35.236804639139486, 36.934237787800456, 21.58331451877471, 16.88933764734576, 23.148797173653882, 11.23523025743423, 0.48325482034875505, 0.2165549458755601, 0.23358160239313883, 0.15253578192524372, 0.17075660097743237, 0.1373317251883207, 0.20288678817451003, 0.22337829183426597, 0.19179345198696662, 0.1535026768162366, 0.17806641276805632, 0.13322307307633663, 0.1282422758278347, 1.1723231452126657, 0.25033750811651834, 0.2657515189099697, 0.14745917772093128, 0.22198079424279354, 0.22256829175016574, 0.140964207690089, 0.10521136689931156, 0.14330736421529325, 0.2843051878434997, 0.17428544710480398, 0.16948693281700536, 0.12966424226760864, 0.21236698834165452, 0.5285559895057832, 0.9332041826940353, 6.872667679863592, 21.059077978134155, 13.491855129118889, 12.8707262392967, 36.335425223073656, 51.54008919192899, 15.707036237562857, 19.75686284803575, 32.252998813506096, 33.90598366337438, 45.07839618190643, 55.02111427245602, 52.83686007222822, 54.98706025461997, 54.24040179098807, 55.93466174217963, 55.61015229071341, 56.51090106656475, 61.95336226494082, 55.057486411063906, 50.07060458583217, 52.789054224568034, 56.02670015827302, 61.02648265900151, 60.68282027398387, 58.525042072419204, 61.687700133169855, 58.26923685689127, 59.58458015995642, 57.9872811994245, 66.45390156776675, 52.657552842170965, 40.18710251777403, 13.693252167394085, 12.993953381815265, 47.57303145623977, 55.20614816296486, 52.160788582217315, 60.59506116374847, 56.26105393132856, 58.90904995702929, 68.24429881188178, 59.08121062863258, 38.24717667794997, 14.579683311523931, 0.5397219355067899, 19.60398650938465, 69.33422350114392, 56.29140130935177, 60.75068512270528, 38.08821085960635, 10.475351445136532, 45.50099234427176, 35.134222892022905, 43.64381282560287, 52.72371538223759, 35.108213655410275, 50.71365364136235, 48.15961407076929, 55.01892951227004, 44.88463894013436, 63.06630342237411, 73.86500820036858, 26.86954575200235, 0.5254931699845099, 0.18386749100060235, 0.262906237715675, 0.20952866322571234, 0.1939127882642131, 0.13053123929327534, 0.11824417724123887, 0.15493003651499748], [0.04247630803635524, 0.055094228141129985, 0.049175222163959864, 0.10130075617663323, 0.028252453137669834, 0.04238334709718343, 0.1031017522778242, 0.11134138796478511, 0.07063795677236012, 0.10100071784108879, 0.048863140926245725, 0.1268273727187226, 0.14204267562637407, 5.368724561506703, 69.88333179104713, 55.43328085253316, 45.71590292838312, 34.93347990897394, 47.72676483277352, 40.429728569522986, 37.680970776465635, 32.504224661857855, 26.541980774171893, 29.122678733641102, 47.95369355909286, 11.849102762437637, 27.608212386408162, 39.26229784565587, 34.74309590555007, 39.086222648620605, 0.30869044063072054, 0.4012481417627104, 20.483558408675655, 74.13597337661251, 62.01414331313103, 62.06584015200215, 59.64383540614959, 40.395839291234175, 55.77907700692454, 65.1306115427325, 50.996185887244444, 27.62784581030569, 17.06304373279695, 42.14705990206811, 36.99384996967931, 42.74599013790008, 57.789523140076675, 61.44712155865085, 69.98126552950951, 70.56821684683524, 64.12395877222862, 61.98552962272399, 58.26395734663933, 57.40382471392232, 53.84224199479627, 55.61738906368133, 51.54345850790701, 51.76758273955315, 49.66097577925652, 41.760384805740856, 47.52601008261404, 43.33784834031136, 18.57515077437124, 8.392117888696733, 33.766108020659416, 28.006278045715828, 6.799750818360237, 9.268728398507642, 9.321297964742108, 30.14465032085296, 19.829932681975826, 19.190115659467637, 10.480701558051571, 11.220149724714219, 0.9380567674675296, 0.06005416481545376, 0.09603249975630353, 0.07785556988129694, 0.04799293782261591, 0.023851052016740846, 0.09054819121956827, 0.04429561746937614, 0.013148285647583826, 0.05203069232764745, 0.09378675131067153, 0.07073075300262821, 0.04919686414782078, 0.025241635664696657, 0.07718427767676693, 0.023523773509828795, 0.03546272329385242, 0.018431175304877184, 0.030146345060559052, 0.033025613745614406, 0.035177102733042934, 0.05851829259265816, 0.015314663553820744, 0.0609971615936487, 0.014423616155381165, 0.019250590609566822, 0.01249636589143906, 0.029794375539847442, 0.13053082560579624, 0.4010182540983923, 0.19111085232467423, 8.864678182909566, 2.445878251906364, 7.686797774607136, 7.661053788277411, 19.131668421529955, 10.681702436939364, 5.605028242834154, 11.113079805527965, 25.785649745695054, 25.04138392786826, 30.870645738417107, 46.55309754033243, 50.467826935552786, 44.591316253908225, 46.79686500180153, 55.20269255484305, 54.60237772234025, 50.29545445596018, 47.25891628573018, 51.23260674938079, 51.97808065722066, 53.74564970693281, 53.65776900322207, 57.203156255906634, 53.72013861133207, 53.40455647437803, 55.66790919150076, 51.70606036340037, 49.040260699487504, 49.41833403802688, 27.908491396134902, 7.410320197382282, 4.235620460202617, 31.663756831999752, 51.92056694338399, 55.324352710477775, 48.046159513535045, 41.928972198117165, 44.33196913811469, 44.827093847336315, 53.63412103345318, 51.01546825901155, 20.1295272381075, 0.783682634993907, 3.2389751268971354, 48.91411335237565, 32.89216864493586, 60.233724578734375, 55.477784064508256, 10.042842472753218, 20.640612071560277, 43.709559594431234, 33.21231642077046, 32.36078162347117, 30.29459272661517, 35.89741414593112, 34.295125930540024, 31.99396940969652, 20.527636043487057, 26.409920454025272, 58.480825193466686, 43.77194489202192, 1.852923379309716, 0.3448206486721193, 0.07691504373665779, 0.03668711182751483, 0.04645570196331509, 0.012718050669307911, 0.053530160052281235, 0.07347634317533625, 0.048484735626487, 0.08884815018503897, 0.028845221329961094, 0.04125958804281489, 0.03235866142917545, 0.006136883298055299, 0.06326187837628588, 0.07260043654711017, 0.10936943934329095, 0.05889375994522726, 0.05611340087207575, 0.07136224693949185, 0.2345469957518001, 0.17408370551082397, 7.879717100051142, 79.10232159399217, 63.83264041716053, 33.22170265259282, 49.10225768243113, 34.70050681021906, 30.03983282273816, 46.991594991376324, 20.586238215046546, 26.97290805078322, 28.554831320239654, 42.70803336174258, 21.658778959704986, 40.36189902213312, 41.05231461986419, 45.42006992524671, 50.08223441339309, 2.425281886131533, 0.3592086991956157, 19.154949649687737, 73.49183390217443, 69.79769076070478, 64.98715869842037, 66.23997549856863, 43.82650506111884, 62.42534891251595, 74.25788848630845, 56.90059246555452, 34.404552213607296, 21.540913697211973, 43.05991311227122, 39.69399782919115, 44.309207624004735, 55.809906836478945, 59.94748177066926, 66.83497551948794, 75.14542671941942, 67.55263590043592, 65.58120558338781, 62.67106186959052, 59.42321777343751, 57.62202224423809, 56.451751724366225, 53.84419533514208, 54.52744476256832, 50.235246073815134, 46.10535114042221, 49.15921834207351, 40.618155310230875, 18.501370991429976, 16.083591618845542, 41.79905153089955, 43.56187451270319, 10.894968567355987, 14.284083689412764, 16.611392613380186, 31.70038196348375, 23.811838549952355, 22.02456939604975, 18.683229723284324, 16.85827639795119, 0.7358361540302154, 0.09854948929240627, 0.11224110460569782, 0.18543855347219976, 0.03586193171119498, 0.019558199809022972, 0.14637427464608224, 0.024232535074735363, 0.0384594370881396, 0.048076893398237806, 0.09726102133431742, 0.08042197974939501, 0.12531842465602583, 0.11747566081823842, 1.2487094657075022, 0.08358441368346253, 0.004110881906648677, 0.06790112298462661, 0.039034642714766726, 0.019013769849534, 0.027434037577721383, 0.03888786792935383, 0.04913810137358885, 0.027330573573107683, 0.07737858055700218, 0.04416422955992241, 0.015993123468492302, 0.027461693351787907, 0.1302437264952929, 0.18615116845936547, 0.683505913663295, 10.763974151303692, 8.920872019183252, 10.104309935723583, 11.55352863573259, 17.8844763002088, 16.352282800982078, 11.736416989757169, 17.090818035987116, 44.739417106874534, 33.76607664169804, 32.29568989046159, 43.117254241820305, 52.2201418876648, 47.387750456410075, 48.88541336982481, 55.74657232530656, 55.973371613410215, 52.22052627994169, 48.85508560365247, 53.147519634615996, 53.5287465587739, 55.33866151686638, 56.90848819671139, 57.067893320514315, 55.52093798114408, 53.35202809303038, 59.445167356921786, 53.760774366317264, 51.38701869595436, 46.76103415027742, 26.036657902502245, 7.830051558633005, 7.243082590641515, 38.169180347073464, 55.04638218110608, 56.3683739016133, 52.34196678284676, 48.92176197421167, 49.05226315221479, 48.72262716293336, 59.35842806293119, 52.18082012668733, 14.674775292796475, 0.5091238322277223, 7.4269711490600345, 53.6828564828442, 41.15973657177341, 64.80643549273091, 62.140945696061664, 21.48976795135006, 27.396594632056456, 38.844647792077836, 38.49556469148205, 26.794534344826978, 26.733635625531598, 37.987119613155244, 29.328860082933982, 38.359242716143214, 21.55946062457177, 26.602948134945287, 66.14060617262318, 55.98269116493964, 2.0193658480721135, 0.2865213576343752, 0.1373751623736274, 0.161834174106198, 0.09037253491941, 0.06064119117875254, 0.050068017200476704, 0.09638327609507308, 0.05356370321204586, 0.17909673973917964, 0.14712105715467086, 0.11593995330434655, 0.2253872808068991, 0.12436690514967327, 0.12179782929559871, 0.2501706694883685, 0.20364345321732186, 0.1918670270712145, 0.1776597426543313, 0.2856182319021994, 0.3632878416007565, 0.5342955815215265, 12.173056217931933, 88.59821504162204, 72.56681349969679, 59.87390595097696, 47.59407889458441, 60.05076169967652, 50.97727614064371, 53.12728412689702, 47.67266750335694, 36.510676722372736, 38.357689457554976, 62.39642535486529, 17.018771940662017, 35.00514553439233, 49.72807184342415, 48.978950131324034, 48.00717899876256, 2.0290175753255046, 0.8078880103365068, 28.266240973626417, 82.51875308252151, 71.87567618585402, 70.82797973386704, 69.72031024194533, 50.52885117069368, 65.55308611162248, 72.96699723889752, 60.36716361199657, 35.73584387379308, 22.517781949812367, 51.35492586320447, 46.230968967560806, 51.10346271145729, 59.06900421265633, 63.9987684834388, 66.97265071253624, 73.75517399080339, 67.84335413286763, 65.7095141564646, 63.604974285248794, 61.2077824531063, 59.16605934020012, 58.991121630514826, 56.8315665952621, 57.55959772294568, 55.145771118902395, 48.788613196342226, 53.30769354297269, 48.0998920625256, 23.00097284778472, 18.01613457741276, 43.899621963500984, 41.61001682281494, 12.462118229558392, 13.867093574616218, 15.265894128430276, 40.18256825785483, 29.576273387478246, 23.640370176684474, 23.60985805911403, 24.768334011877737, 3.168370257462225, 0.16707862817472027, 0.2341649783474784, 0.2980969768137701, 0.24731536786402428, 0.1257077735217829, 0.24395418773976066, 0.27077776049413993, 0.13556128067355003, 0.16490572702980813, 0.22852583578036678, 0.20885928624099304, 0.4353716590952489, 0.21104786154483596, 2.346159835015574, 0.10379570536315443, 0.1162156530265366, 0.2052462010854675, 0.1458955309804409, 0.15108318729025705, 0.1602821106151227, 0.13957316055893898, 0.04477688156428837, 0.09243075270205738, 0.1564495872345663, 0.19536702232735773, 0.06831618176112253, 0.15037450999502214, 0.42783022828159795, 0.973909559749788, 1.1433197918438143, 18.273967658319783, 15.193349892093291, 13.749071417316316, 15.098290270374669, 30.772258966199814, 21.433966352093606, 18.12033037985525, 17.52051761073451, 36.378606596300685, 32.22666205898408, 38.01573722593246, 49.60145381189162, 52.71837703643307, 47.69136936433854, 49.82193808401785, 58.626254912345644, 56.71834345786803, 54.218640481272054, 50.40899922770839, 55.93414398931689, 55.00647598697294, 57.106509054860766, 58.58247733885243, 61.2669631742662, 57.905676287989465, 55.30635295375701, 61.735870761256066, 58.7053495068704, 56.97330928617909, 54.768949016448, 33.48330513123543, 12.046834345786804, 6.354787830383548, 36.48655414581299, 60.87784444132159, 60.48667430877686, 58.056177631501235, 56.453822735817205, 52.67168121953165, 53.48357654386952, 61.1353401983938, 59.99676635188442, 24.528732107531642, 2.0582527162567263, 6.813822811649692, 57.01494132318805, 42.49551934580649, 70.15269664026076, 59.314454370929354, 14.343555646557963, 30.286757792195967, 56.32047783943915, 42.490898793743504, 44.143099169577326, 40.31828226581697, 48.07719330633841, 46.516188037010934, 46.634710296507805, 31.549674695537938, 39.65771198272705, 74.06814775159283, 71.17199513220018, 4.602608690338751, 0.6381389835188467, 0.3186587767014581, 0.30608007263752723, 0.23891777250795598, 0.14068455495420965, 0.15210798310656704, 0.13644272611746866, 0.18597095393605773], [0.03887562584432383, 0.053076325735497865, 0.040808274155302394, 0.031469968793493126, 0.022695762698628733, 0.030935693329440492, 0.056696003077611815, 0.036303294116571065, 0.04516738339237148, 0.02421600672776901, 0.057032357811206774, 0.1130072997822877, 0.07586541134984263, 0.21658756589937597, 47.32198799810102, 67.03638922783637, 55.468582184084006, 26.173609418253747, 29.485284205405947, 36.12828877664382, 29.539305048604167, 33.70292255955358, 30.119964884173488, 34.917002031880045, 41.76386002571353, 28.334260755969634, 9.211653990130271, 27.009772446847734, 11.368258422420872, 46.25905706036476, 26.735596810617757, 0.19232801281877104, 1.2553432968354996, 18.020659031406527, 64.13927562775152, 62.18630398473432, 68.014173353872, 60.31059126700125, 45.48942135226342, 42.30362130749611, 52.07424148436516, 47.12412011238837, 25.900810533954253, 13.943475850166815, 15.260076272872189, 19.44721917952261, 42.79503153216454, 61.62072566247756, 59.22938600663216, 62.123475459314164, 63.77004331158054, 65.34959354708272, 63.38600012563891, 58.76009794973559, 53.731450726909024, 50.280400399238836, 47.668741210814446, 47.69616250068911, 44.218102732012355, 49.11439741811445, 31.7476269122093, 8.468296200998369, 15.092353763118869, 38.65353815017208, 30.977267526811172, 3.3658118305667757, 7.969082911168376, 6.397536272002805, 21.84077693570045, 22.53836654847668, 23.24022173881531, 22.776362242237216, 12.730655458665664, 11.099336801036712, 0.6322576345935945, 0.10008302877747244, 0.051299384795129306, 0.18377461050066257, 0.04783142733597948, 0.10186636655200874, 0.06345564882541377, 0.031125639084606405, 0.07149880211199484, 0.059699243941013856, 0.0799706620314429, 0.04973363897372639, 0.031214853853828488, 0.018536644544632688, 0.6454652355563256, 0.05225528249396913, 0.09820857250522222, 0.03465254317908999, 0.03554262626435488, 0.08138376483393293, 0.0563325786272124, 0.044330803887738336, 0.07910005673165284, 0.0507505287626578, 0.0679898206444998, 0.10194667554911106, 0.03506763259910288, 0.10771301935517019, 0.04168823721908754, 0.662173429323781, 0.21551812247883892, 3.6316239929968313, 2.533934481682316, 8.89580415141198, 10.732219622981164, 9.92743653635825, 10.822488069534304, 9.586862037258765, 10.933013596842367, 10.5102526949298, 27.521065165919644, 31.03308285436323, 27.398848033720448, 30.223019276895833, 47.2058819186303, 52.12736998834918, 53.18812793300998, 52.97156995342624, 56.91213992334182, 57.38419325120988, 49.56956886476087, 51.30231118971302, 59.01266720987136, 56.912861639453524, 52.98117583797824, 52.84352810152116, 55.06530761718751, 53.50495346130864, 43.623106633463216, 36.548421690540934, 25.26074051856995, 8.227251845021403, 9.171577172894633, 33.85720506791146, 53.018626628383515, 50.74635444148895, 49.99922529343636, 49.8649037268854, 50.37174455581173, 59.564038707364, 55.288717977462284, 53.608900193245184, 15.39736903482868, 1.451795942360355, 1.2955182958995144, 36.77845693403675, 43.88356378001552, 20.277837937878026, 60.218466558764064, 22.77703492872177, 11.54333733743237, 39.71854009935933, 25.693203403103738, 31.176596495413015, 28.43454203298015, 34.83082755919426, 38.28641606915382, 27.790159371591386, 25.500854292223533, 23.42837195242605, 43.669053277661725, 55.57617279791064, 28.709384472139423, 0.6686710806623583, 0.2920092131581999, 0.030996888432832017, 0.08034715594183053, 0.02509043480630123, 0.05459042190904579, 0.019486097528809504, 0.0560538643490403, 0.09978214774521128, 0.02837770659806988, 0.03630215264556389, 0.027211056196040688, 0.07083735413729184, 0.04358525861114745, 0.0550325389110273, 0.05751389003689251, 0.01825873082834146, 0.021006021716241396, 0.011858168685237968, 0.03465943797040851, 0.061746395583595, 0.05252972966240299, 0.2164095117440147, 54.68119382858277, 79.18988458571896, 50.787774670508604, 33.880119554458126, 33.666915201371715, 17.295193133815644, 43.63426185423329, 32.43304344915575, 28.270341811641572, 32.44148635095166, 37.18612063315607, 30.79448703796633, 20.17596810094772, 34.37014126008557, 13.08616634338133, 50.82751612509451, 39.628125544517275, 2.42597516505949, 0.36505523708558857, 14.453062338213767, 63.639969671926195, 69.40248843162291, 68.92216282506143, 64.96790378324448, 51.306198258553785, 50.25825077487577, 53.10631121358564, 53.592747872875584, 31.459795544224402, 14.119180383220797, 14.818000639638594, 21.29725410092262, 41.240376580146055, 59.69127255101358, 59.88877957867038, 58.63116179743121, 59.760655356991684, 63.688654130504986, 63.27853110528762, 58.98680310095511, 53.76474772730182, 51.970702678926536, 48.68652174549718, 47.1726986669725, 49.51425167822069, 49.47591835452665, 34.0354375685415, 12.625047602961141, 25.260150201859016, 50.226989484602406, 43.91211079012963, 8.545662010869673, 15.753236855230025, 12.769194706793755, 19.980836068430257, 35.35240865522815, 27.691905959959957, 22.093685480856127, 27.43428272585715, 18.92150390532709, 0.297373146299393, 0.047746027684620315, 0.019271123681157347, 0.11990752266419512, 0.021386911056094596, 0.05271689260318395, 0.2673169123309274, 0.22698739333258522, 0.2196285672365658, 0.1798970105066415, 0.32340536554974897, 0.12629476541112508, 0.08824439629191354, 0.010721061506398745, 0.9575532761312301, 0.09460841125297932, 0.09282020882012383, 0.08612826226219054, 0.07097737202721258, 0.04793109537492837, 0.025618941628284035, 0.029551966168406992, 0.042741799636954264, 0.07792064138958532, 0.21656881206698958, 0.20226421916196424, 0.2680984139442444, 0.17636289369435082, 0.12883441582802804, 1.111835539340973, 0.34426171092256425, 6.116715650404654, 12.271211570309056, 9.725687465360089, 12.775726433723205, 17.14347585555046, 10.13281281917326, 14.43874470649227, 19.114792423863566, 17.592963787817187, 45.31151440835769, 43.17359908934563, 31.300751278477332, 28.189686113788238, 48.32245911321333, 53.035061359405525, 56.90109845130675, 52.03202501420052, 59.39875395067277, 60.02484267757785, 53.50956616863128, 52.24555492401124, 62.91069515289799, 57.952454474664506, 57.04171934435445, 53.181503049788944, 56.39086084981119, 54.61292889810378, 47.885977760438, 36.460650813195016, 23.785750865936283, 7.81989360047925, 13.374571358003925, 41.67556747313469, 56.9690142908404, 52.486490434215916, 52.84039805012365, 56.725811650676114, 58.36844928802983, 61.942803244436945, 60.47811961943104, 54.61058332074074, 8.769784281330725, 0.7026369064565628, 3.5422572012870543, 45.99468931075066, 47.605398854901715, 20.61366734966155, 50.523591272292606, 29.97191502201942, 20.75048354364211, 37.356747658021995, 28.440813902885687, 34.67504670543056, 18.833381975850752, 39.20481943315075, 39.13329501305857, 28.665289186662246, 33.90279085405412, 18.412254741114957, 43.42254407944218, 68.44470054872575, 31.474159263795425, 0.797442983715765, 0.2766153811206741, 0.11600756056366429, 0.03252225950540554, 0.03797849475015556, 0.05296577541758457, 0.0636936531912896, 0.06267631524092247, 0.010483859617623591, 0.170845344602581, 0.07732519188955908, 0.09380754293693651, 0.11597037465581972, 0.1104842504907039, 0.11990324023269838, 0.13357351233641948, 0.1942733858501719, 0.07987064159204883, 0.12219851626263512, 0.16731279060965584, 0.21944945587986903, 0.1570857772904058, 0.4419848058492907, 71.3157029305735, 86.07577800750734, 72.33490728562879, 36.50865670173399, 39.52347670831988, 47.93260297467632, 42.374067075790904, 47.62335546555058, 44.535155757781, 47.6688196582179, 53.27054085270051, 38.96841818286527, 12.046700004608402, 36.80076345320671, 18.742902701900853, 59.072879514386585, 32.068976894501716, 1.4126586553550537, 3.5030925802646147, 25.20739040067119, 69.82066016043387, 72.72606957343318, 72.91269594623198, 72.55523466294812, 56.700029911533484, 52.0053921207305, 60.294662521731475, 55.63835413225236, 30.9202499928013, 17.77932736181444, 23.300804707311816, 29.24291506890328, 50.32214226261262, 62.79667577435894, 63.45768536290815, 62.37333828403104, 64.03165755733367, 65.12238241011097, 65.34060739701795, 61.81473001357048, 57.64802363611037, 55.62726166940505, 50.441586279099994, 52.42250088722476, 47.88480497175648, 53.39568799541843, 37.25106723846928, 16.17082120910768, 26.78519125907652, 50.92183343825802, 41.52601534320463, 8.228992396785367, 18.845857074183805, 12.118843178595267, 23.326727651780654, 40.8416009718372, 32.55692170512292, 25.74301750429215, 31.250754787075905, 22.15813002278728, 0.6070901141051324, 0.28073022322308633, 0.2542793369221111, 0.2021268289536238, 0.12867638721100746, 0.17582814900144456, 0.09090094406518245, 0.19760948425579458, 0.20154018946472677, 0.1893685845237586, 0.27721250069237524, 0.20776024118306177, 0.2900432170398774, 0.11665779301115584, 2.3138902504597945, 0.1162811918484588, 0.16861037501404363, 0.2482164251588045, 0.1110304941633536, 0.12499233933105586, 0.1371451981005169, 0.16694342897784326, 0.18635465673381285, 0.14372852871254568, 0.2832983338063763, 0.3577797919992478, 0.29858448452526526, 0.2258480673715953, 0.24512440236585759, 2.2925746200546144, 1.5427905176916432, 12.846051589135202, 18.624764834680867, 14.985959472194796, 15.295365837312515, 22.79110250934478, 19.469394299291796, 14.593557715415956, 25.217851361920758, 16.384253059664083, 40.2034862579838, 40.97065087287657, 34.587875950721006, 34.47815941226098, 51.33214473724366, 54.46822089533652, 57.72139941492389, 57.61618575742168, 61.996802514599224, 63.173211543790764, 54.698769969324914, 56.17539328913535, 66.76711851550688, 62.19095983812886, 58.09548370299801, 57.0204600980205, 60.657379781046224, 56.44207523715112, 52.04132887624925, 44.8027398509364, 31.020082158427087, 10.044975261534415, 11.542081198384686, 38.79589665320612, 60.84642233387117, 57.54217063227008, 58.95807566181306, 59.72123161438973, 60.87019974185575, 66.25098166927215, 63.50513035251249, 62.67509798849783, 19.449904041905558, 2.4538762098358524, 2.312910883657394, 43.378056556947776, 55.27910032579976, 26.91169946424423, 67.35227338729366, 27.783971832644557, 16.80135888438071, 52.339840858213364, 35.12054166486187, 40.1555117484062, 38.570113258977095, 48.07451824988089, 51.90993732021701, 37.12415502917382, 40.135601797411525, 32.8448825113235, 59.304613144167014, 74.73449568594657, 53.31989603657877, 1.1084089812732514, 0.44489924946138937, 0.21745595720506486, 0.24138385550149027, 0.12541711210243164, 0.15503249311399075, 0.21725717271047257, 0.24839576634187854, 0.1000524159040182], [0.15515454624208713, 0.043345572682277816, 0.05722939945577134, 0.01156994246787602, 0.07003910584195007, 0.07452398373354828, 0.046466385059419184, 0.009128841601552503, 0.031446300507072485, 0.020355908012378122, 0.031009772116498604, 0.06774624298897482, 0.1474603115310592, 0.22236152461940245, 10.429771542549133, 70.26314273957284, 47.28923620716218, 38.73684929263207, 31.664388333597493, 40.09020036266696, 23.90237273708467, 31.276797363834998, 23.941802363241873, 33.94548977574995, 38.286004220285726, 40.75910176000288, 11.32975055325416, 8.357214677718378, 19.80598072851858, 31.78953939868558, 58.63060482086674, 11.807939448664266, 2.5922760607734805, 0.7178333329577601, 19.99332097268874, 63.148496689335, 59.948925202892674, 46.56890861449703, 71.18708056788292, 44.639435891182195, 62.583953872803725, 62.12030226184476, 58.934839540912265, 22.18272916732296, 2.2669747808287224, 2.7601588974075937, 9.453594607691612, 35.65456451908235, 61.90184585509762, 57.6213397518281, 55.62539462120303, 52.436307630231305, 50.85336454453007, 55.29280508718183, 51.15874851903608, 56.74874574907365, 59.10930264380671, 53.363351975717855, 44.946561398044715, 16.043902135664418, 8.81532790199403, 28.615647669761415, 47.547563506710915, 22.23103511718012, 4.44412483323005, 15.984596879251542, 8.043404471489692, 16.571088298674553, 36.147629983963505, 23.740465141111805, 27.669328797248106, 21.999434847985547, 17.79525218471404, 15.378031749879161, 0.6993464668912273, 0.04198969281729191, 0.13198852238635864, 0.036720505600134214, 0.13725978953223075, 0.05706428835589079, 0.03901418433674882, 0.13310636724195174, 0.047193119047029365, 0.15024642009408246, 0.06468858690031114, 0.08123820812831964, 0.36634266316410036, 1.8226941626879478, 0.9919171612108908, 0.02052416581840765, 0.013787806270674113, 0.03470896938515287, 0.11087695482156931, 0.021452878887254386, 0.03916882684514408, 0.003944177583288101, 0.12281530897223181, 0.0906847540529505, 0.0060543358877992205, 0.12283208629777356, 0.09997264316846287, 0.09567215497935973, 0.20511362190929153, 0.8425875032140363, 1.3067389712218316, 1.4023874387625725, 5.098229089090902, 3.9438954043772916, 14.399212118118042, 15.419023459957494, 14.669820358676297, 10.034898692561734, 22.694920109164332, 14.637392163276674, 7.500525395716391, 24.34987202767403, 38.07565535268476, 33.7280688747283, 18.8860535237097, 33.79087386592742, 57.0610370174531, 55.44952338741672, 51.13949360386018, 51.53126385904128, 61.872165280003706, 58.53107075537405, 56.04618649328909, 55.2829481709388, 58.10772542030581, 51.91004714658184, 46.44548731465494, 44.08792711073353, 31.216657623167965, 17.401756086657127, 8.150155698099445, 7.5738805820865025, 33.51309945506434, 52.45334640625985, 46.99215981268114, 53.88864363393476, 53.834922852054724, 54.08868059035271, 46.321630631723714, 50.594248848576704, 52.131410029626664, 21.79176692039736, 1.1257809136183032, 2.695724161401872, 22.200601447013117, 64.78559201763522, 24.11695776447173, 23.106155126325547, 24.503140603342366, 13.359940917261186, 27.295454355978197, 38.83935259234521, 27.72250044730402, 30.869890682158935, 35.25953085191789, 34.24383309579665, 25.053023561354607, 34.100639127915905, 26.502964958067864, 40.713539508081254, 43.87324794646233, 62.84939242947487, 3.9712343244783344, 0.5228858969865308, 0.12428730095346129, 0.03564366177024861, 0.015537707180145289, 0.057340401765559955, 0.05430883480115764, 0.06037549273441396, 0.05786506474138268, 0.07264044931939534, 0.0792504244694306, 0.011914271219152839, 0.1580916967002615, 0.03734794310143879, 0.07871600919433179, 0.05856213963500435, 0.015356319584703494, 0.10083797012245464, 0.09534214728421743, 0.0939739678776072, 0.149248743790292, 0.06494134995004823, 0.4894492847304191, 0.4358838961249398, 15.671108307376986, 76.40678251943281, 57.69135798177412, 29.486496217789192, 39.93052067295198, 23.74544066767539, 27.36136978672397, 42.851239096733835, 26.209873691681896, 31.264120263438073, 31.474537772517053, 38.13779354095459, 18.37571394058966, 19.692261411297707, 17.500709641364313, 37.504793597805886, 61.900190614884906, 20.018508472750266, 5.729916018824424, 1.0033822492245705, 15.91870302154172, 65.82118403527045, 64.80421150884321, 55.107512320241625, 69.58436089177286, 50.22438895317816, 66.46036563381072, 66.0869324591852, 60.9369114137465, 28.850648633895386, 2.823227913148942, 2.454729815644603, 7.179332308230862, 32.51868840186827, 57.909614347642474, 61.247500373471176, 58.501150915699625, 58.81185754652947, 51.76444092104512, 56.70729021872244, 51.038578864066835, 61.06932278602355, 58.63112649609966, 58.39443499042142, 40.184301945471, 21.783663303621356, 16.3955710587963, 35.49714803695679, 55.56240135623563, 40.68644769730107, 9.707242519624772, 23.485979803146858, 15.517035645823325, 15.459366017772307, 40.98800736088907, 29.71083814097989, 27.963098633673887, 24.431363190374068, 29.795500539964248, 23.375174806964015, 0.44115065867381714, 0.08425352253740834, 0.10274280944178182, 0.12455129485216834, 0.45684449074249117, 0.45727429671152947, 0.3053172942130797, 0.2528727228843397, 0.09463027540233829, 0.42078188229953095, 0.26487143710255623, 0.3049603585273989, 0.3210539046314455, 0.41951452772463527, 0.4728138693157704, 0.09240512706099019, 0.020536815845257333, 0.07268775524871965, 0.0519328399170791, 0.13238011588973383, 0.07757214799283013, 0.040246888754829284, 0.13075348140010912, 0.09933226261167757, 0.11167101261596526, 0.35999593114660633, 0.08071112431465619, 0.034412259701639414, 0.2568012830470839, 0.6615713455023304, 5.7411531190718375, 6.4027505728506275, 17.176917983639626, 10.693471508641398, 15.46412189160624, 18.169765972322036, 20.78520436440745, 7.662097629039519, 28.07040095329285, 22.578894438282138, 13.85526272558397, 36.302540071548954, 51.27700797973141, 44.1125556730455, 18.52930611179721, 33.83726766032557, 55.48406770152431, 58.63734737519295, 52.38911759468817, 50.8738903076418, 60.634339778654045, 60.27501144716817, 57.536526341592115, 55.43839562323786, 60.386053746746434, 53.69938142838017, 45.72939980414606, 43.509950176362075, 30.44687874855534, 14.689839155443254, 8.805428820271647, 11.312599989675707, 37.325321628201394, 55.241724060427764, 48.87433659645819, 55.62708908511747, 58.351610552880075, 57.989230617400146, 50.84737900764712, 55.91108829744401, 56.73882999727803, 20.97884197388926, 0.4173175407753837, 5.155241720138058, 33.25993399466238, 64.1346158519868, 28.2740072665676, 25.566604983422067, 29.589799681017478, 21.082980901964252, 31.35110078319427, 34.55861506923553, 30.864415053398382, 30.180347811791208, 25.774306251156716, 46.25977093173612, 19.805431596694454, 35.64551953346499, 28.506301795282674, 36.83086372190906, 51.16498900998024, 70.63695246173491, 4.646627489597567, 0.5391592592481644, 0.11274011895781565, 0.07876827937340544, 0.0605388839669045, 0.11762985133475835, 0.08836606637604776, 0.020824742330718907, 0.04731434096972789, 0.04740729807846008, 0.19923023519016084, 0.09244261940400447, 0.19610450452854558, 0.11616182002809741, 0.17817669878563575, 0.2068087753028639, 0.1270438078790903, 0.23311917640028462, 0.14193238960879465, 0.2951484269672825, 0.26932988496076676, 0.28487635235632625, 0.6258342018531216, 0.7336482682055043, 22.99859981383047, 92.40818577428018, 67.45436483813872, 51.28697079996909, 45.448279611526004, 54.650685633382494, 35.26430829878777, 46.95628581508514, 33.92453255191926, 47.69861005967664, 48.520515272694254, 55.50221258594144, 16.06932693912137, 13.513003568495474, 29.016731592916674, 44.226590741065245, 67.24292555162984, 17.648473170495805, 5.124519755763393, 2.192923128604889, 23.891880396873724, 72.25591075035834, 69.02743139574605, 62.10360865439139, 77.20877385908558, 54.79546031644268, 73.68402219587757, 70.65833722391437, 63.42214868914697, 25.386487783924228, 3.125055523649339, 4.703115993930448, 13.978195690339613, 41.85885983128702, 63.08389525259695, 62.84369714798466, 61.63367340641638, 61.970150009278335, 55.14863837149836, 59.68398478723342, 54.45695584820163, 62.59335971647694, 63.091524262582105, 58.53956660916729, 52.01164437878517, 22.112936473661854, 18.151444581247148, 39.53695397223196, 55.36833032484978, 31.675345474673858, 7.486323964211249, 30.618615804180024, 13.6301157359154, 18.81114802052898, 47.43943945054085, 35.925592453249045, 35.62597828526651, 25.831162967989524, 37.46593075413858, 26.404317348234116, 0.6478907312116315, 0.14487274231449251, 0.32519684683892036, 0.1558621969795035, 0.24029925886181094, 0.21374010901537635, 0.1736534245672726, 0.24274487198600847, 0.15518638485622022, 0.2303639565023684, 0.46846095773000873, 0.3259249674456735, 1.4581689358718934, 4.458938154482073, 2.2326332042294164, 0.23308128569154973, 0.1197591697376582, 0.1954867159046473, 0.28532779264834623, 0.13476301705644977, 0.1929562202384395, 0.13794367622223594, 0.177794206406801, 0.22624428804603317, 0.24537192537419258, 0.3829931551890989, 0.2319697534004527, 0.19321701188962306, 1.297013576953642, 3.9868630084299275, 3.9579504824453786, 8.037686146074726, 21.820625758940174, 15.445194494339729, 19.573621480695664, 21.66679040078194, 25.726514131792133, 14.338502653183477, 29.776912427717644, 27.40489632852616, 11.708641705974458, 36.89194679260254, 46.41557139735068, 45.20721466310563, 23.72736834710644, 39.317112968813994, 61.389945168649, 57.02901478736632, 53.585954327737134, 55.10717891877698, 64.6125723469642, 58.761513925367794, 60.116061318305235, 56.58500640623031, 62.12860984186973, 53.13189291184949, 47.733279889629735, 49.16312110039496, 35.22326853967483, 21.437298405554987, 10.48785694183842, 10.253030523177117, 35.05011550841793, 57.91931044670844, 54.693333564266084, 62.069307527234486, 62.655321398089015, 62.564953911689024, 54.95239434703704, 59.14652593674199, 61.7434174014676, 28.444999071859545, 2.0287724271897347, 4.905672582887835, 27.9786390642966, 76.17640602973201, 29.133794730709447, 31.305522841791955, 33.545415862914055, 17.26301989247722, 39.58766629618984, 50.77521916358702, 38.09793049289335, 41.389685523125436, 49.58394042907223, 49.435721905000754, 31.941874450252904, 48.72469425201417, 36.07501122259325, 55.947895819141024, 59.3114302235265, 84.52109167652746, 12.801755282186694, 1.0490789648986634, 0.4437070021465902, 0.2558742400499121, 0.13003570298033376, 0.25536875991571334, 0.20127841722100012, 0.13423296082164013, 0.0793681338789963, 0.12054411108575522], [0.12454220138850713, 0.03828584922537689, 0.011908723784971141, 0.029151271540491335, 0.05596436995772585, 0.019656115421845068, 0.13478485056229178, 0.07663109324752324, 0.022316800069905097, 0.1552098424684617, 0.03785091429768551, 0.04059203817779499, 0.08269957447003934, 0.09290560464104337, 1.6151619245929103, 60.775254849464666, 56.11377285372827, 46.41329250028057, 29.096357668599776, 35.18108344847156, 36.76482669768795, 29.654879646916545, 33.49889655267039, 27.980725765228275, 39.9730509327304, 37.13667523476386, 31.662029027938846, 9.736521051776025, 23.5136442799722, 27.71811523745137, 58.25832482307189, 103.49280388124528, 23.007417301977835, 0.6876204186870206, 2.580542535551133, 33.14312581093081, 59.001264879780436, 52.29031309004753, 63.04018828176684, 68.0616497224377, 47.923722728606194, 55.82722017841955, 54.43002877696868, 58.4949065023853, 23.313362175418487, 1.723870536492717, 0.7986559766915537, 1.306481933401477, 12.219195058268886, 27.376410115149717, 39.72279979336647, 45.955881380265765, 60.35370595993535, 57.0006952747222, 55.47900784400202, 41.3980362492223, 28.638954393325317, 12.236928093817927, 2.241787280767195, 13.902601811193652, 49.85786699479627, 42.05810839130033, 19.813548941766065, 3.7656665809692877, 17.247071535356586, 11.706617762965541, 12.343400832145447, 42.56400392901513, 27.70724242733371, 27.430250529320013, 29.01951255336885, 15.600746870040895, 15.724268190322386, 12.017258694094997, 0.9924616352204354, 0.044173330684462865, 0.11194449068317491, 0.09070461105194785, 0.05284677131942684, 0.6162699311971664, 1.4695380483904195, 1.396601207313999, 0.76606065155037, 0.4832079051242721, 0.03624717051523828, 0.7658104778778169, 0.2348044319378753, 0.09289935336358125, 0.36649781129052567, 0.29378868218871856, 0.09550622033496058, 0.036161062232549154, 0.05833444681258933, 0.08002540667451198, 0.02363058148823198, 0.07192473933701554, 0.03627298001740729, 0.0714665268277449, 0.0794968519720339, 0.32325772508498163, 0.70666671279938, 0.5446433456194016, 0.37555615748128585, 0.10561756203852354, 5.897063901347499, 4.548976652083859, 8.325898474262607, 4.113986290270283, 11.538291208205685, 17.679050007174094, 15.888745919350656, 17.4930747478239, 19.336465174152007, 31.00060759052154, 15.177619226517217, 10.215712112765159, 19.818275397823705, 31.337068503902806, 38.97189732520811, 17.568182253068496, 27.661717437928726, 51.490149574895064, 59.33148922458772, 56.275131317877005, 48.08430848583099, 55.45853307170253, 63.37730030859671, 58.8755686052384, 55.56879089724634, 53.5542223530431, 44.827591988348196, 29.838315171580163, 11.130754986116964, 4.832391921550998, 7.537916369976537, 31.64896361289486, 40.73414371859643, 45.60496261042934, 50.299494497237674, 47.64128854197841, 48.63360504950247, 50.10053227024694, 50.55927699612033, 54.71586758090604, 52.418868772445194, 14.983699206383, 0.21312950629620783, 9.618069394942253, 59.29110450129355, 53.46723987210182, 21.170000645422167, 9.615540446773652, 8.541341520124867, 17.077736931462443, 36.39578265528525, 35.53752491551061, 34.783755194756296, 34.529722890546246, 33.62030175424392, 27.254602870633526, 38.464303401208696, 36.780618160001694, 28.965603497720537, 38.610996123283144, 54.142958348797215, 42.642098319145944, 0.07487656037893987, 0.019390531890695135, 0.010699815973038635, 0.021055353948125438, 0.015801533497118905, 0.06385949207469821, 0.04803412653986485, 0.05627480027596316, 0.03567603281548908, 0.030635191510701855, 0.06821737940152807, 0.0239370224036036, 0.07460859814478506, 0.06605132708265897, 0.034670764580368996, 0.00869692793311251, 0.014071224328701296, 0.011440126953886883, 0.018329220493474317, 0.13769097445953277, 0.14263237946696822, 0.07219576592286749, 0.07623072803741501, 0.09468452974913583, 2.717686737737348, 65.55982866594869, 72.39126390026462, 36.19598496344782, 34.91557036676715, 40.892564327486106, 22.585278095737582, 40.174021413249356, 33.51247972057712, 32.36188773185977, 28.665799094784646, 35.67975790269914, 31.454053194292133, 19.611242894203432, 32.061624411613714, 37.8478362483363, 64.34089329934889, 101.86671472364857, 32.1357121006135, 1.214059615327466, 2.6157129579974763, 33.15363384062244, 62.321366879247854, 58.12081436957083, 68.1874244443832, 68.2239652449085, 56.8778976317375, 60.05142850260581, 57.176805773089015, 60.02601546625937, 28.358114650172574, 2.6348487311793916, 1.5709099894569767, 2.3652978145307113, 10.224089314860683, 25.60733879766157, 39.607886114428126, 43.99397457799604, 58.83935728380757, 55.00309098151423, 54.39276626033168, 41.427912942824825, 32.80317398809618, 11.428586436856179, 3.0635672230874342, 20.51473144562014, 51.00032791014641, 55.18596756842829, 35.083734143164854, 8.285449031860598, 20.512350566925544, 20.625414848327637, 8.621346104529596, 45.21051729879072, 31.43904620601285, 34.00084226362167, 31.511541412722682, 23.93734262835595, 22.61022044766334, 13.757736913619505, 2.223046441232005, 0.9131768670293593, 0.5051364671559103, 0.39269584261121293, 0.05366044096468438, 0.315536018460989, 0.5296855708283763, 0.4311837628483773, 0.24922450493660667, 0.32629406860759186, 0.39229802847389256, 1.0358543261404962, 0.33680454978058416, 0.08334363224886118, 0.3824382317402671, 0.23267672998049568, 0.08874066804926242, 0.08094694149950821, 0.006718671056366856, 0.07083962175754771, 0.1396804894771307, 0.057613841528373386, 0.03933581486043911, 0.024961563495678768, 0.11102557587887972, 0.184294784201249, 0.10316468640080384, 0.4240624852959187, 0.2525541222383899, 0.12334875897654604, 5.354040188174094, 5.592234451924601, 16.529475873516454, 14.89082826722053, 14.90005172068073, 18.59017933568647, 19.52486445826869, 20.832025697154386, 11.383988107404402, 39.41476821899414, 21.793728105483517, 16.351143352447018, 22.5786590960718, 37.115925896552305, 48.4458411893537, 22.60068516577444, 27.992941987129953, 48.29100562680153, 62.87908869404947, 61.033303660731164, 49.246114530871, 55.642464776192945, 62.88876910363475, 61.10052524074432, 56.9229382084262, 51.518284736141084, 45.55058679273052, 26.826517351212043, 8.724627014129393, 4.863420811391646, 11.087377494381322, 35.89259747535952, 44.93059342907321, 48.35896461240707, 55.738857023177616, 52.953982045573575, 54.00786407532231, 55.66133137672178, 55.828624386941236, 58.066987683696134, 57.721615145283366, 18.32597828680469, 0.055834801507092295, 11.623117366144735, 68.50288498786189, 64.43765817149993, 30.603555863903416, 14.416643131163813, 15.812842172961082, 22.788652989172167, 35.09258693264377, 32.15897567810551, 36.82818474308137, 26.84378754708075, 37.48819020486648, 30.157245051476266, 29.98857725051142, 43.91822968759845, 21.195037134232063, 43.69246198285011, 64.15130553707, 48.25110727740873, 0.5696668415780991, 0.08535132653290227, 0.056561769151519385, 0.0484714018661649, 0.04087435306921121, 0.02963834641230924, 0.03431310111116018, 0.05390457786439408, 0.03683483656195383, 0.012790270735539738, 0.20285419879421113, 0.10559477092277621, 0.17264870025457876, 0.10599610140366901, 0.13529115807144873, 0.11239229971843381, 0.24198716506361964, 0.17916637713149672, 0.12577933379478995, 0.16581059944245125, 0.22002998198713028, 0.11169545082074982, 0.2531160324090912, 0.27792600434153314, 4.221555821357235, 88.4792652437764, 73.52546430403187, 64.35901857191517, 40.161740472239835, 54.24759149551392, 52.960826581524266, 41.00215142773044, 46.925914902840894, 40.60752960943407, 53.892487556703635, 51.25525843712592, 43.881045618364894, 13.876484709401286, 35.21631417735931, 37.04993986314343, 71.9926255749118, 115.45800978137602, 31.277456322023948, 2.27380387244686, 5.007347772198339, 40.18574145532424, 70.71658442097326, 62.43716309147497, 75.640869140625, 74.9980946510069, 60.8815275469134, 65.75605307855915, 64.65283547678303, 61.96594915082378, 26.704706184325683, 1.9792806957998585, 1.2854033612435865, 2.244983031865089, 15.601378371638638, 29.933197306048488, 48.30556938725133, 48.97908349190989, 64.8025837252217, 64.15484351496544, 62.16630774159586, 47.24477221888881, 35.05325340455578, 17.7766268099508, 3.9960599858914656, 19.72659391741599, 61.42716453921411, 53.66031069909373, 25.866481950206143, 6.152502865560594, 32.90295516290973, 18.66814232641651, 16.06922789927452, 51.87853090224728, 34.77128990234868, 39.21826924047163, 35.767050250884026, 22.153115272521976, 28.202608362320934, 22.56369329267933, 1.1392831826402297, 0.627743844543734, 0.36396518589988835, 0.18892621471276208, 0.14705408574833026, 0.9196091251027201, 2.384037673473358, 2.1487638594642764, 1.247025175440696, 2.9683409006364885, 2.3348641443637113, 1.3383679836988451, 0.7718657594053977, 0.18770148526997338, 0.8200705243695168, 0.7632791395148923, 0.2865015006353778, 0.19321158798711915, 0.15679693149943508, 0.20848281531324311, 0.13673200091767695, 0.3233369692198692, 0.12537016623443173, 0.3127609415640754, 0.2981114099102636, 1.035851261788799, 2.219273856570644, 2.5142679627864593, 0.9728949529028709, 0.2408875531006244, 10.542261196720986, 7.302224088099695, 19.48523675241778, 19.73168319271457, 17.38519387860452, 23.245675794539913, 21.63933969313099, 25.084326036514778, 23.342399481804144, 39.66727472120716, 30.071513806619954, 15.518764430476775, 29.5042763217803, 37.15308643156482, 48.081119598880896, 22.60263458375008, 31.90976396683724, 56.756080581295876, 63.105589882020034, 60.64529495854532, 51.499971189806544, 60.76841423588415, 68.28999442438926, 64.3778302592616, 56.1751736364057, 56.838164021891934, 50.90686959605063, 31.66302334877753, 14.479527550358927, 6.307275670190012, 10.186617932012005, 33.81899333769275, 49.231460555907226, 52.07488475307342, 61.996896651483354, 56.92399724837273, 58.57060040197065, 59.53334223839545, 59.413596199404815, 62.85529167421403, 62.329745061935924, 19.416236377531483, 0.3714811825944532, 12.603496140049351, 70.07688506957024, 62.67570595587454, 30.622812740264404, 15.950796834884153, 12.993778836342598, 23.407165658089426, 47.31167216454783, 48.14239486571282, 46.12873238901938, 47.232734464829974, 45.26386545550439, 36.92757760324786, 53.62277753891484, 52.83935862202799, 36.86094045639038, 59.831187417430264, 65.75022835885325, 67.37905533083024, 1.593029092877142, 0.15920656913470838, 0.20327900986998312, 0.08433498832727633, 0.15685829514216992, 0.13791664864026731, 0.10464293732037468, 0.19087114341316685, 0.18930529033945453, 0.1311092066668695], [0.01761650208443884, 0.07854524053513043, 0.053506012960907914, 0.02269040199837858, 0.06993863341068068, 0.036293254534323374, 0.04745766069860228, 0.08994434539589191, 0.07847306739178397, 0.018946424975330313, 0.07502633822901596, 0.12742459188185393, 0.07301595497636065, 0.10121989559622542, 0.2226324592747035, 19.898984047674364, 70.38483819653912, 49.80411091158467, 31.650967944052915, 30.101941593231697, 40.8611814437374, 30.06447119097556, 35.465482742555686, 30.198390714583862, 33.645534361562426, 35.834883720644065, 38.36476541334583, 18.44728935149408, 10.07514319112224, 17.23012101265692, 21.636427333278043, 45.512622171832675, 69.50227352880663, 7.762597087890872, 0.40874336215276874, 14.468154638044297, 61.125722546731275, 64.2516476108182, 54.135078307121034, 59.62074833531534, 49.59313446475614, 47.65169066767539, 63.731839426102184, 51.68722906420308, 60.512561951914144, 15.096836051633282, 2.3637751994594454, 0.43292033095513627, 0.35082257983665316, 1.423491874048787, 13.374731194588447, 18.96257504340141, 11.601425678499284, 8.999562609580256, 4.430641195466442, 1.3700499481731847, 0.46637762758520346, 0.26198711606764025, 16.694209537198468, 62.23626321361911, 32.51527201744818, 14.538626882337756, 8.599399462822946, 19.026366510698875, 15.390302884963253, 9.501638739339768, 45.47637162670013, 32.07834351447321, 29.910369111645608, 28.637377600516047, 23.293838577885783, 2.275165670341061, 18.274248107787102, 8.695633834408177, 4.172093262595515, 0.9937734228949394, 2.3393260855828566, 2.8157266253425233, 3.173329604248847, 1.4548138384857487, 0.7641244102870265, 0.9209902284126129, 0.22435090174117397, 0.8121736900460336, 0.48199717976873924, 0.1321638186251925, 0.006418560900079508, 0.12402985710650684, 0.11009857118610414, 0.8455001695021507, 0.07560730100639405, 0.07324466286527534, 0.0326456532873694, 0.028711634748164686, 0.014633297293086447, 0.022278032190496885, 0.12566720916619226, 0.3549452053923761, 0.38067809876895725, 0.1736071068913706, 0.014211636753903042, 0.036898402707471, 0.11088001917326644, 0.08067083575071828, 4.761470565872808, 8.618871088950865, 9.84694459745961, 5.852937236908944, 6.773689610342826, 20.884785498342207, 18.69940753906004, 17.47148798358056, 23.699082174608787, 19.015405447252338, 22.593726881088752, 23.078790710818385, 31.681585965618012, 20.188511840758785, 21.641567599388864, 40.111942060532115, 26.609412200989265, 25.97541597581679, 41.11032255234257, 54.74428907517464, 63.97290437452255, 58.0136356046123, 53.31823687399588, 53.87144796309933, 56.09906396558208, 32.26314010158662, 14.98881103531007, 9.208233683340012, 0.5174876124628129, 3.3397467001791927, 20.116689320533506, 46.32072456421391, 51.01604092505671, 53.657835683514996, 49.907469287995376, 52.989514796964585, 52.21266192774619, 52.516798588537405, 56.30612980934882, 53.600608302700905, 42.764950875313055, 9.717273000747928, 1.1929695212071942, 22.134654637305967, 29.346259717018377, 42.55624548081429, 15.773450789913056, 11.613442840114718, 14.982275386010448, 20.999789391794515, 34.190951701133486, 33.21235564447219, 30.775022275986213, 33.73569003997311, 30.353159596843106, 27.9731418625001, 38.14377907783755, 28.788816390498994, 34.19403076171875, 37.48857459714336, 70.65434425107895, 20.459441715671172, 0.7542668198866229, 0.04866770806632215, 0.07997348889588349, 0.03135099725407218, 0.09764507653251772, 0.06898631717288686, 0.011325520200414524, 0.027688997384581356, 0.06399865194614376, 0.008835416520014405, 0.054223630502219164, 0.08470700062330692, 0.10129170101736823, 0.03423787127699583, 0.02395428236453764, 0.0419260845369389, 0.02237968631238947, 0.12094309733759974, 0.06943604142795648, 0.046026305851316264, 0.03996920486491534, 0.040068034037587144, 0.0218834892486132, 0.18334405376545845, 0.2427151630963049, 24.870751019447084, 80.43296214072936, 55.531555837200536, 26.93385693334764, 45.68233920681862, 26.154729089429303, 32.18436125786074, 33.75224244210028, 33.35593008225964, 31.08331664916008, 33.725621315740774, 37.831479964717744, 26.210385560989383, 21.903662335488107, 23.320632288532874, 32.15446691359244, 50.33981254023891, 72.83577042241251, 11.228707355837669, 0.9712904583542579, 17.18251520587552, 70.46975751076975, 69.85633803952125, 61.98923626253682, 62.84783917088663, 54.66787738184775, 51.35394919303156, 66.98381377804664, 56.51243079093195, 65.02613136845251, 21.95677907236161, 5.15234750124716, 1.0729676701368824, 0.07719834305105672, 3.1001408734629234, 21.114740333249493, 28.228799989146573, 18.29144770099271, 17.963690527023807, 10.767133620477493, 8.47092418901382, 1.499889103635665, 1.2124112392625501, 24.231100697671216, 63.86667874551589, 44.70503360994401, 24.65508145670737, 15.334088456246162, 12.100842441281966, 24.394959672804802, 11.052591954508136, 36.70629316760648, 37.291852043521025, 35.07200625634963, 37.04951232479465, 37.06948895608225, 7.569087445735932, 21.836303472518924, 8.513524070862802, 4.888445533091023, 1.0371887900175587, 0.27246848589950995, 1.1350091474671518, 0.7087391338521435, 0.5639910493646899, 0.2892849125689076, 0.2709643182254607, 0.26785991545165744, 0.3369490033195865, 0.3478446735009071, 0.2108526470199708, 0.1602426417652638, 0.20567174760564683, 0.007473013416353254, 0.13111158153943478, 0.06270076876746551, 0.03502956569014538, 0.038141713612863136, 0.08093770247914138, 0.10899973297191244, 0.06750225164597073, 0.11804943769088677, 0.12013828366874688, 0.21130522112211875, 0.13793267519964328, 0.04528181394562126, 0.048842253538990216, 0.05542687883961105, 0.034767812598616846, 6.480754748467477, 12.249322783562446, 16.978506849658107, 13.099346487752854, 16.246296436555927, 20.8714965081984, 21.332663297653202, 23.14463161653088, 21.011223100846816, 13.000365476454459, 32.75823343184687, 32.75149676107591, 35.25548688827023, 18.967974185943604, 33.67477170882687, 53.697251581376605, 33.47407579421997, 29.60096274652789, 42.63504589757612, 49.665082500826934, 64.63034852858513, 60.87419663706134, 56.39923903249926, 51.397550259867025, 56.129081864510816, 30.433962383577903, 12.809010686412936, 8.347572511242282, 0.4768211220300967, 5.573299700214017, 26.396309829527333, 49.40629628396804, 53.58104744265157, 56.13023504134148, 53.978348239775634, 57.40185960646599, 55.299681002093905, 58.92117008086174, 57.91242276468585, 57.28205473192277, 45.74585414701893, 9.614448066680662, 2.6176447253073416, 30.64845915763609, 31.411570002955777, 52.15990997129872, 24.099569897497854, 14.571755220813138, 22.09619579776641, 25.824353733370383, 34.3065635619625, 28.514021019781794, 29.122194320924823, 27.855041257796753, 40.26314158593455, 22.343716967490412, 37.815237429834184, 33.7665787050801, 29.821684322049542, 44.34972570788476, 75.87966303671561, 21.287683517702167, 0.5065061404339729, 0.02055253979990319, 0.07394489787158466, 0.014006754199433473, 0.0613760648505582, 0.09085320912662054, 0.05501957670334847, 0.09465027795804125, 0.041997656301264806, 0.05727844057424415, 0.15157440286730567, 0.25635321354193075, 0.22777108595736567, 0.11399410529843262, 0.13640671998502749, 0.14061467241375677, 0.12954353745425903, 0.14332305369598253, 0.15726118078154905, 0.19013468776979756, 0.2888757296867909, 0.19709850361029949, 0.25244942866265774, 0.2699236950326351, 0.35974722836286793, 40.14772976598432, 92.18493230881231, 68.45096065152076, 43.71152862425774, 41.41705974455803, 61.0672047061305, 45.17205845925116, 48.324745855023785, 42.474671948340635, 49.24724809585079, 47.83912897109986, 55.362242806342344, 25.867978334426883, 16.246013045310974, 25.733448882256788, 33.009678932928274, 57.63624475848291, 77.89650655561879, 11.671516472293485, 1.9350895574015958, 19.03968687980406, 71.02032492237707, 72.37862602356942, 64.11820465518583, 69.2017101472424, 61.05543367324337, 58.689718861733716, 72.61648639555901, 59.07954754367952, 63.37346030819801, 19.016939093989713, 4.23408632316897, 1.0669969647161424, 0.624849870800972, 4.8549504530045295, 19.49172631386788, 29.34317869524802, 15.204746338628954, 13.19320978656892, 6.9187766121279815, 3.6380939425960666, 2.4174163081953606, 1.8830627491397245, 19.798000666403002, 80.19838087020382, 40.107615686232045, 22.508332960067257, 12.09702499451176, 30.53435740932342, 25.7576754016261, 13.7962330156757, 55.62416299696892, 37.47885104148619, 41.91747573114211, 41.908650398254395, 32.732981212677494, 5.163768952892673, 29.459780954545547, 11.511227834609247, 5.215151511853741, 2.0682084271984715, 5.801180581892691, 6.6723527254596835, 4.183765745932057, 2.4821560084819794, 1.2232360003455993, 1.3104432821273804, 0.737897849852039, 3.695551027213374, 1.4385874833791488, 0.3589359718945719, 0.18003683687458116, 0.49764792705255173, 0.26303107940381576, 1.4134935073314177, 0.189504994139556, 0.1676630153651199, 0.14349556137477198, 0.1429796777665615, 0.15634734514019183, 0.195248585134264, 0.17940118308028868, 0.5090915646043517, 1.9259080242726112, 1.1786976096130188, 0.1220158349362112, 0.2423887177100105, 0.21653177937672985, 0.17189254082979696, 5.913609439326871, 17.299456750192952, 24.88380858975072, 14.439278148835706, 15.375446907935606, 22.727689550768947, 26.862791430565622, 23.24703489580462, 29.8727104356212, 22.917361644006547, 26.06162771101921, 33.80295084368798, 40.14313667051254, 27.771616366601762, 28.221437700333137, 48.89769823320451, 35.07313982132943, 32.165061235427856, 44.4555159538023, 57.22606682008313, 67.20047766162504, 59.023838120122115, 56.34261177432153, 52.78792065958823, 60.48965531010782, 33.856910890148534, 17.8082646477607, 13.358137607574465, 0.9410299240581451, 5.597282052040101, 26.262090244600852, 54.22225298420076, 55.365325789297785, 61.92561149597169, 57.46702194213868, 62.16439362495177, 59.897216596911036, 64.88220783971971, 64.34979707964006, 64.83958344305715, 50.63848926175026, 13.233975960362343, 1.5132956423105732, 27.503353703406553, 37.24502678840391, 56.41450489720991, 19.625949821164532, 17.65301331397026, 19.392447202436387, 30.210102911918398, 44.618753233263575, 43.95434294977496, 43.40206930714269, 45.29021593832201, 43.84177092582949, 38.972548438656716, 56.53544333673293, 42.09533560660578, 50.56341509665213, 51.596171240652765, 87.33947938488376, 36.60050292168894, 0.5837503568299356, 0.11818303576400203, 0.21822779078877744, 0.10220997230780703, 0.1639516717724262, 0.17460380260261799, 0.11911522687202501, 0.19263150621085398, 0.1924853059913843, 0.19521663926782148], [0.028222983650442575, 0.05855991031914469, 0.06948103377174947, 0.14503100075789038, 0.07083205280885582, 0.047150528388878996, 0.06807959848834623, 0.02607925130324739, 0.05003698680910373, 0.023940722608277877, 0.04301748786782546, 0.04994749241778928, 0.0751437871686874, 0.08299894630908966, 0.16846935354894207, 0.6724290177226068, 62.616407563609464, 58.37342285340833, 44.94724389045469, 24.6415610467234, 37.03317957539713, 36.94426336596089, 36.68832871221727, 33.95948479252477, 28.143900286766794, 32.64982108146914, 36.573238526621175, 36.06681739130328, 18.088521918942853, 23.73542489544038, 40.28449104678246, 44.02503582739061, 69.5777242414413, 34.072488277189194, 2.7304268412051664, 5.409093595320179, 39.96246837800549, 64.23281238925073, 60.44180239400556, 66.14137495717695, 54.128731912182225, 57.01498839163012, 61.56507507447274, 56.007492311539195, 53.567032814025886, 38.11078017757785, 32.75173406447134, 9.977473232053942, 4.095087085039386, 2.1450143187276782, 5.2517423225987345, 5.703862165251087, 5.974527770473111, 0.18725474875780845, 0.39759889725715886, 1.5604050241170393, 6.868684022657334, 32.61477470397949, 55.04748044475433, 28.698170415816772, 11.822563025259203, 13.896005365156359, 18.620512985414077, 20.892034038420647, 8.415146123978401, 27.839924443152647, 38.01378388558665, 31.578092267436368, 33.28301322075629, 30.89719233974334, 7.5581768828053635, 10.213344962366167, 22.09898460295893, 12.251031956365033, 4.442373985244382, 0.2367917253004928, 0.2787694977896829, 0.305999388257342, 0.12620896356360567, 0.07051083214220501, 0.16095879607863967, 0.047552115509226445, 0.037061640722376686, 0.07722630526029295, 0.0877410305603858, 0.6970412163965164, 0.04152216850930164, 0.07135381997232476, 0.14078079091925777, 0.6987085914419544, 0.07845474256863517, 0.05220677380660369, 0.05454627992284875, 0.07944104246675007, 0.12599956109038285, 0.1011719614748032, 0.2748260142341737, 0.024644973830530242, 0.12134071995293903, 0.05348154028216678, 0.09872313078132369, 0.027526496729302793, 0.10053280665869675, 0.060839389616082755, 5.867731926902648, 5.6752494554365835, 9.010214786375723, 12.986735240105661, 2.5522183650924317, 19.78031469929603, 19.129722925924487, 20.802602037306755, 19.2065562740449, 30.164564194217807, 14.31323572512596, 14.105854130560353, 16.62675065378989, 10.940156232926155, 7.446143204166044, 11.292066381823632, 27.859422545279227, 31.722908135383364, 31.26888594319744, 31.811700790159165, 32.647399017887736, 42.967549139453524, 52.70970467598208, 41.71174349323396, 21.113412610946163, 6.388577088232964, 3.284692067292429, 3.093460096466926, 0.7239153356321397, 17.554487297611853, 45.22221772901474, 49.72848761466242, 48.072243275180945, 49.958122776400664, 50.9620181206734, 51.654987181386645, 54.29111411494594, 51.90819186549033, 52.0008578608113, 53.51401021403652, 36.89026801816879, 4.4898557470690825, 9.236741469752404, 44.23795776982462, 30.285422225152296, 18.299780776423795, 4.749966744453677, 26.346515340189782, 16.738844148574337, 29.02840848891966, 32.95258099032987, 36.70581463844546, 35.76349658350791, 35.82828629401423, 26.375317304365097, 33.77480391533145, 43.48585113402336, 24.7940549542827, 28.38974072087196, 54.423643158328154, 49.130239871240434, 0.5877406943228938, 0.105227125327914, 0.1792594414925383, 0.00782292790620798, 0.030766046989048203, 0.03325414926474614, 0.050125427829522284, 0.052915776689206405, 0.04863764677617339, 0.06754673837173371, 0.06943662365477893, 0.048098680938804345, 0.1323519544976373, 0.02179985734513931, 0.055958999681376645, 0.17279511497866723, 0.019937443975058776, 0.02970150078556711, 0.06009464107093312, 0.03666225227437193, 0.051494871281207576, 0.03040224332512627, 0.1114153384321159, 0.04260858077736151, 0.14539752786438312, 0.24587005106431825, 2.2919911674914824, 69.68555804221862, 72.32666246352657, 35.97885431781892, 32.25858819100165, 36.05024145495507, 26.771157018599975, 36.37920671893705, 34.41842955927695, 35.802881102408136, 25.43322478571246, 36.643409729003906, 34.41909243983608, 27.967570135670325, 29.03392726375211, 38.044915737644324, 53.58721340856245, 72.60122053084835, 42.24678616369925, 5.517414750591402, 6.016272085328256, 42.33635740895426, 68.4185540291571, 65.26831027000182, 69.94619169542867, 57.964135293037664, 61.20489951102965, 64.99035935248098, 60.73057513083182, 62.12425208860829, 42.85746782056747, 30.42713942066316, 9.811668761314886, 9.485902190208435, 7.104727846960868, 10.660993303022078, 12.31748181004678, 13.931603816247756, 1.7447494354940232, 2.2864290014390023, 3.2224749413228806, 7.513791832231707, 41.04430906234249, 57.105457859654585, 47.221359591330256, 24.58521423801299, 25.905991984951882, 16.47168367139755, 18.581616801600305, 11.732848613492905, 17.941395774964366, 39.59072574492424, 34.639831666023504, 37.74195578790481, 42.184216514710464, 18.276325002793346, 11.675159373591024, 22.628390827486594, 9.161637886877983, 3.107284244991118, 0.5357569708458839, 0.10510331785847103, 0.134498211104543, 0.04353661585839526, 0.0903352034548598, 0.10889867065294136, 0.03866932219675472, 0.08905171506827878, 0.08071091747091663, 0.1290843443524453, 0.5445968287606393, 0.44033278320585534, 0.24136816602080102, 0.07411779625521553, 0.27936462553278096, 0.0955006585366303, 0.0414958878630592, 0.055028551423381415, 0.0778806899043341, 0.2064138876214143, 0.22707872633491794, 0.1408670064542563, 0.11912625853813465, 0.10837600716660101, 0.050021465867757804, 0.02751398268305967, 0.00473053403942275, 0.15284385652311389, 0.030865420084146243, 2.925647862495915, 7.208285773954085, 18.221403975640577, 18.171670283040694, 12.299306527260812, 23.52750985853134, 24.22043577317269, 25.941879710843487, 23.663365071819676, 17.7965759846472, 11.053400943356177, 20.028396767954675, 26.005233833866736, 23.758066777260076, 15.06442746808452, 24.498731859268684, 42.9938486314589, 37.35529245868806, 38.86660914267264, 36.04356165855162, 31.18698097044422, 37.04198921880415, 48.929065427472516, 40.02234728105607, 19.76461345149625, 7.602612433894989, 6.175508056917499, 3.4222289967921475, 1.4853494902772288, 21.19168939128999, 51.33339597332863, 52.3010290053583, 53.64190301587505, 52.527067353648526, 55.78759639493881, 56.903122394315666, 58.81527785331973, 56.16563443214663, 56.8253888622407, 59.64821669363207, 41.82712785659298, 3.1730511159666124, 10.80595527925799, 49.286620847640506, 34.30939551322691, 19.660258793061782, 3.8580254056761345, 23.07592934177768, 22.056840696642478, 31.343587483129195, 30.084755728321692, 41.142301636357466, 29.024240970611576, 36.55068882050053, 37.32142279225011, 23.818167294225386, 50.89330996236494, 25.246547422101422, 29.01014397221227, 60.51002417841266, 53.58109843346381, 1.4147509946938486, 0.058012111488008694, 0.06328898639748655, 0.06029729813998265, 0.03648872186820354, 0.019627697390293884, 0.0896891308647971, 0.06845262968131612, 0.0031860181902189774, 0.04914574310063355, 0.052637882125113285, 0.13969371215470378, 0.2558166455597647, 0.20203391781016705, 0.15263466855450986, 0.28591719005377064, 0.11654559177376571, 0.1768154984400157, 0.1336018269461009, 0.15987890321881543, 0.15836198784170613, 0.2131514776978762, 0.24256327850443704, 0.19430752272807783, 0.31439972620817924, 0.5019325035954676, 5.375526931978041, 87.87024667186122, 74.06172290925058, 65.12871703793927, 33.70904930176274, 54.52370282142393, 55.663500447427076, 50.942700447574744, 47.28779669730894, 42.99982632360151, 45.737009202280355, 51.47896297516362, 49.67745757872059, 23.163060872785508, 34.00400369398056, 48.18483883334745, 55.172866852052756, 77.40012276557185, 41.695316606952304, 4.568625275165805, 8.945723176002502, 47.49378388927829, 74.22557600082891, 70.71296015093404, 77.71606183821156, 65.57487880029987, 68.81531746156755, 69.02878069108533, 65.12697158321258, 62.547389538057395, 42.99708066448089, 36.330310452368956, 15.811896881749554, 9.353097600321616, 4.752361351443875, 8.452654769343715, 10.28890452077312, 11.47234537909108, 0.651508198390084, 1.2560217443012422, 3.586269626694341, 13.22360227184911, 39.4341290381647, 69.93549931433894, 38.50565694993542, 18.275342449065178, 22.361695151175223, 25.840105971982403, 36.7259991553522, 16.184142558805405, 38.535062959117276, 46.30667855662685, 39.13541309295162, 42.71403851047639, 40.73743066480083, 11.50556295148788, 18.293838385612734, 38.00846907400316, 20.313980617830833, 6.917842107434427, 0.839264826668847, 1.1934226775361647, 0.5085597770108331, 0.18326934487108262, 0.24817536284606306, 0.2872002647528725, 0.1019514789203963, 0.18154094326159648, 0.2635112939582717, 0.5304712706035184, 2.8140684433521765, 0.3641673105378305, 0.2529528863247364, 0.2903394479184382, 1.347657627155704, 0.2642326423477742, 0.14954583268732796, 0.20982624241901984, 0.16407904155071706, 0.34181246654160563, 0.5787791203587287, 0.9162260808290974, 0.7699775058896311, 0.2639642357826233, 0.16451601810272665, 0.2022139025070975, 0.12170933847946507, 0.25863532818132834, 0.1750431846707098, 10.312318128924217, 18.028490043455555, 32.39472189257222, 27.29459143454029, 10.65341430325662, 25.469510632176554, 26.336044573014785, 31.18197210373417, 23.314185873154674, 38.84487528954783, 20.140519680515414, 16.66802771629826, 21.048991603236047, 19.355067014694214, 12.765620446974232, 17.306167925557784, 38.05793408424624, 42.07467648290819, 43.03976389669603, 37.04150676727295, 36.99429319750878, 49.06650527831047, 59.18206653287334, 47.09448660573652, 24.580766270237586, 11.149555886945418, 7.541557310088989, 5.870364817880816, 1.9462357076906391, 20.401141566614953, 50.015707092900435, 56.68743518091018, 55.80828689759778, 56.92215373439174, 58.57343627560524, 61.468376882614635, 64.9632675417008, 62.07146090845909, 60.5128522073069, 63.612191446365856, 46.333770367407034, 6.349516655168226, 11.841306071127615, 47.935697724742276, 37.08063633211198, 24.469676902217252, 7.094302187042852, 34.08131753244708, 24.39328678192631, 40.0888628344382, 43.266437668954175, 47.690863378586315, 48.32527145262688, 49.441570158927675, 37.4736068325658, 44.68460198371641, 62.59952568238782, 34.14737024614888, 44.14768834267893, 65.51840451455885, 77.82798274870842, 6.77595183733971, 0.5876632275119905, 0.48058236859017806, 0.20254799345087623, 0.129396096172352, 0.18948121477038632, 0.18112564699784403, 0.19742147095741766, 0.10680874449110801, 0.1881642943067897, 0.1483854699519373], [0.06256391099023242, 0.11218912554003539, 0.01521438264453243, 0.023081095348442757, 0.10267465826003783, 0.06734249933112053, 0.07511570238538327, 0.041214212655059757, 0.02970279164371952, 0.021793703743887526, 0.05305362271986181, 0.02300757197512975, 0.03404023208385033, 0.09709556166443134, 0.11819982075042303, 0.14329100057723063, 40.01005457293603, 68.36972052051176, 52.929196588454715, 34.08154502991707, 30.630131883005944, 32.38882853138831, 33.70452680895406, 36.06248317226287, 34.18528779860466, 34.29434145650556, 33.63011944678522, 43.00829864317372, 27.645418028677664, 15.544235321783251, 34.37484418192218, 50.09317782617385, 52.17641922735399, 67.10258314686438, 18.435792884519024, 2.0222864203876068, 14.029941558837892, 54.10741775266586, 60.66235334642472, 58.84190682441958, 54.867027882606756, 58.82440913108088, 56.70144196479552, 49.554652090995546, 53.49494749499906, 50.00980000342093, 31.295212891794023, 11.718645711098949, 0.19917559779940114, 1.050050241812583, 5.208370224122079, 5.7530354492125975, 7.240543346251211, 16.65116740811256, 15.934536649334817, 27.193827705998576, 42.762009097683816, 41.550910626688314, 28.66523035110966, 9.517915594962336, 14.134927718870102, 10.83704202405868, 22.260715692274033, 7.3388977589145785, 19.58336268701861, 46.76199905333981, 27.62636707675073, 33.64068238965927, 31.494653647945775, 19.2244363984754, 9.278444109424468, 18.192658885832756, 14.952988028526308, 4.322678937065986, 1.2420468296735518, 0.08406174774732321, 0.13468922746758308, 0.03615950707406287, 0.04135912201637703, 0.07089307171202476, 0.15371203332418396, 0.1722345990879882, 0.06049555020346757, 0.08398917623825612, 0.22870274080384165, 0.14213494325597442, 0.9977002670207332, 0.11291624257160772, 0.30570119619369507, 0.17668239832405122, 0.048537197327541734, 0.010716180568711172, 0.11201756781027203, 0.1317831801791345, 0.1989302351590126, 0.30233696703949287, 0.03433679621065817, 0.11077056053064524, 0.11586884502321483, 0.09845192033436992, 0.08821544582925497, 0.040879336471158656, 0.012249332221765673, 0.5900965679076411, 0.12216077111060582, 2.430949956178665, 3.9828756740016327, 17.00305892575172, 9.39689576625824, 7.773801338288092, 20.656583962901948, 29.38522061993999, 27.670185835130756, 25.380011950769735, 31.72462417233375, 19.13733820761404, 4.403241478627728, 3.261810430595952, 15.564405129801845, 14.114249963914196, 6.4173996448516855, 19.657432725352628, 27.988380270619547, 30.778840703348962, 30.057128514012984, 12.079520437025256, 5.682566146696768, 2.407661128428675, 5.053759217262268, 0.17453802629343926, 2.1481983027150555, 1.4994424437322926, 3.3294426337365186, 22.779298136311194, 49.875525505312034, 53.70616320640811, 52.26778299577775, 54.945330158356704, 50.41527894235427, 54.1976793350712, 49.53007844186599, 57.71906952704153, 54.73454590766661, 54.51744271862892, 23.622743045130086, 3.5116445729809427, 12.763589639817516, 52.90394436928534, 51.63847008059102, 61.71896142344322, 38.999648094177246, 24.830911505606867, 22.417973318407615, 31.42995611313851, 35.60135756769488, 28.886907023768273, 34.7737806074081, 34.297138106438425, 21.140788793563843, 53.24960324072069, 57.02604947551605, 22.9878132958566, 31.420920933446578, 58.72980548489479, 19.544358638025102, 0.36709483893167594, 0.0733652834089533, 0.03283258257133346, 0.04783506242318019, 0.03130134135004013, 0.043088243748512, 0.013998183590780585, 0.03720496045125108, 0.017033009301690806, 0.045525567801368814, 0.0482609115480896, 0.01935904567700721, 0.011748889115669075, 0.05303057113422021, 0.024695572022709156, 0.05336715569419246, 0.07322134314886025, 0.14141877362084004, 0.02842749465226887, 0.03736930929364697, 0.022957088696139476, 0.06921914661483419, 0.021193778375163678, 0.07977469674041195, 0.049444666778248166, 0.026295832020320722, 0.03910950865716704, 48.29410822160783, 79.50588641628143, 55.80266221877068, 27.281622117565526, 38.59214521223499, 23.903676925166963, 37.316853230999364, 30.303747538597356, 38.915234765698834, 28.587422294001428, 25.637229219559703, 37.9527674951861, 33.154477150209495, 24.62676194406325, 44.37874732478973, 55.95337929264192, 57.416807759192686, 76.72453372709214, 31.972359111232144, 2.39599232231417, 10.859171055978345, 56.32203502039756, 66.4252604207685, 64.49957278466994, 57.82210234672793, 64.9431771616782, 60.364818034633515, 54.79766861084969, 57.019275542228456, 53.90288968240061, 37.2158561214324, 16.379078472814253, 1.9287918243677387, 4.189527707715189, 10.012455871028285, 9.270633689818844, 8.939855310224718, 15.564413955134732, 2.5862804728169597, 10.275539044410953, 44.19478031896776, 44.17965565958331, 45.3037481154165, 20.50196413070925, 19.3759673641574, 13.507298481079841, 15.743928090218576, 19.711543783064812, 19.60724796018293, 40.41674944662279, 32.310367399646395, 36.806537182100364, 39.71171125288933, 39.117228984832764, 10.82435707892141, 21.50165665534235, 20.937680621300977, 0.5220492063991485, 1.234937533736229, 0.14894724222681216, 0.0344802308527212, 0.031695692769942746, 0.1181092385142561, 0.08629066524125877, 0.10362463792966259, 0.1348627770259496, 0.017241078781925382, 0.08546259314302476, 0.17767906339178163, 0.2070430143465919, 0.9700856778410174, 0.13354522837025504, 0.22682522784077355, 0.14866840154413255, 0.09563818664079714, 0.11539371729257608, 0.2061414207902647, 0.5101988068030727, 0.31947741825734416, 0.21208227942547492, 0.14937373869601758, 0.06480173808672736, 0.058146379888057716, 0.061783232921434034, 0.0651493811258866, 0.1347548045939015, 0.12730724253361264, 0.8415053580557147, 0.7296115977148856, 3.8893568083163235, 9.130153021504803, 25.50884023789437, 15.73152457514117, 20.400853272407286, 23.14857948210932, 35.053692710015085, 30.274694542731012, 27.130148026251025, 18.83511370228183, 22.9912845934591, 6.744346849380001, 9.364352841531078, 21.698947952639674, 16.10962733145683, 16.725404147178896, 34.127303400347316, 32.79220311872421, 36.29352646489298, 40.541531808914684, 18.35315638972867, 4.9782570235190855, 0.9627499876003113, 8.783986203132137, 1.3370067986749834, 7.402842198648761, 5.440146509678134, 7.652968802759725, 28.643200359036847, 50.69795631593274, 56.773888141878196, 55.32627074949203, 57.41389343815466, 53.47613188528246, 60.02297562937583, 56.4353483723056, 65.28812216174218, 57.34514997851465, 58.20863623772898, 27.017526972678404, 4.6073155345455294, 19.045537094916067, 56.74740429847472, 52.5187833078446, 68.3933331889491, 21.50096239582185, 19.06268177493926, 29.266647369630878, 28.708856913351244, 35.66420962733608, 30.688339856363115, 30.453062365131995, 41.19825816923573, 18.068225614486202, 45.96696207600255, 63.69036036152994, 16.917574790216264, 34.91149110178794, 67.35126926052955, 25.175152440224927, 0.3630749304448405, 0.02579925957346155, 0.03158492411697104, 0.05577498153152485, 0.01121379585275727, 0.04661214094789279, 0.011990948001884166, 0.009691467106853043, 0.07878717876249745, 0.07360515319892476, 0.07478708130938393, 0.1494563382960135, 0.14862393780100733, 0.13208987581874096, 0.09739386864126691, 0.17720343004311287, 0.14508715500274014, 0.26377911829660017, 0.19312368705868724, 0.11470903387112964, 0.25519792230859883, 0.19083732829218913, 0.10479754918525297, 0.1678171982207606, 0.32735114736903104, 0.14629109281926386, 0.28149159204575325, 64.70287315307125, 87.3796993686307, 72.82667052361273, 45.30234782926498, 41.46830551085934, 49.07467949774958, 51.24598595403856, 49.16574516604024, 44.17061851870629, 49.21914823593632, 46.98448765662409, 60.021802840694306, 35.94546710291217, 21.9848906993866, 40.404166483110004, 62.065369467581476, 64.24339886634581, 78.1328764269429, 27.40423737033721, 3.565744353878883, 17.270052702196185, 61.05472372424219, 72.18995217354068, 68.40524150479224, 66.1271289087111, 71.59639558484479, 66.4829820202243, 57.304404397164625, 61.88073958120039, 58.44981101251418, 40.81795692443848, 16.90268547304215, 0.660005645646203, 4.032841031589816, 12.152240199427451, 10.927956681097708, 11.26989322323953, 29.545829911385816, 33.467497979441, 42.61869353632773, 48.66254429663382, 51.411827687294256, 38.85797208355319, 13.743701692550415, 20.917358821438206, 13.328928697493769, 35.746457807479366, 15.409196942083298, 26.109761076588786, 57.273252933256096, 34.05083287146784, 40.0403235035558, 37.75894357312111, 30.67692772034676, 11.495750161909289, 39.18784733741514, 34.63776065457252, 14.041766524314882, 2.798930055672123, 0.25006424455392745, 0.2340315564745857, 0.19167492286332194, 0.1951728650038281, 0.2566512983532683, 0.23121521808207038, 0.48343647511736043, 0.2160858395960062, 0.29841052127941964, 0.5852806940674782, 0.4560315795242787, 2.0863447314308536, 0.42296633605034123, 0.6742852181196214, 0.39033871264226977, 0.15039908609563304, 0.2502758686821307, 0.3271796356045431, 0.33734268058211575, 0.7746638189400397, 0.7726102130066964, 0.38765354382414974, 0.18405884444232912, 0.17653057501921732, 0.1391405660298563, 0.3643926936051538, 0.21745669264947215, 0.12983350173359917, 1.6866880607220436, 2.8504467106634572, 8.07874208496463, 16.026184789596066, 40.308503796977384, 18.11489397479642, 16.762066541179536, 27.568221861316314, 38.84191782243791, 32.465110786499515, 31.31947667367997, 39.399125806746945, 28.24473265678652, 6.379900315115529, 4.427686179837873, 23.325211655709055, 21.034480794783562, 10.055106743689507, 25.753307842439224, 36.88196043814383, 40.24168622109198, 39.18630192356725, 18.272377137214907, 7.591371411277403, 5.423267570234114, 10.879705644422963, 0.23126815475763815, 4.50834874183901, 3.474584793852222, 6.3288472352489356, 32.2919479493172, 54.996266057414395, 61.116540278157885, 62.39972014581004, 64.0502142906189, 57.27118192180511, 65.56253902373776, 59.80594696537141, 68.67218232923939, 64.24942754930066, 61.76153482929353, 32.47997853063768, 5.378109812736512, 18.35488223260449, 63.94636169556649, 60.192453399781265, 73.25850779010405, 46.348655762210974, 34.04099556707567, 33.647268049178585, 38.95532138885991, 47.811382124500895, 34.99688502280943, 49.58173997940556, 48.28616934437906, 29.111949090034734, 70.97521766539543, 72.10016127555602, 32.540441866843935, 44.30096280190253, 74.59182339329874, 46.400823285502774, 0.3720016627302093, 0.15180395345293707, 0.09502267329803399, 0.11964154459776417, 0.2313879862307541, 0.12389758436550057, 0.10753339471956415, 0.1780708101127417, 0.22622542696133738, 0.16832277028551026, 0.24818780411395336], [0.019865960310844165, 0.045209560363042745, 0.04024814513902511, 0.03933014580979943, 0.05252788339050547, 0.050623867615696885, 0.05967434225303512, 0.031198302524224408, 0.061540337084161664, 0.13832633714041404, 0.02898210208983191, 0.0217326331297837, 0.04057640232326042, 0.031648072744569475, 0.10295012049497136, 0.2001375131188862, 5.347685458198671, 73.99283039954402, 53.34516002285866, 41.74868045314666, 27.409669853025868, 40.085913212068625, 29.337606968418246, 39.55082739553144, 31.905514078755534, 37.05042231467463, 39.856572228093306, 48.137213414715184, 35.0363479891131, 23.676118658434962, 13.316227082283268, 44.139643561455514, 74.68361470007127, 54.61239545576034, 41.07010649096581, 12.88107051003364, 9.494837349460973, 39.89370138414445, 64.59489422459757, 64.63216850834509, 50.23343001642535, 51.093009594948064, 64.5548625146189, 60.89506756874823, 53.51282958061465, 51.99009095468829, 48.87497986516645, 25.79358077818348, 11.68544480877538, 12.482915616804554, 9.821438404821581, 9.974788369670993, 13.095621216681696, 6.259959628505092, 12.202242574384137, 56.38991163622949, 36.78499160274383, 23.933792883350005, 10.632833626962478, 19.564005790218232, 25.701922831996797, 21.04660680217128, 24.962471723556522, 6.035547102651289, 18.04223010616918, 32.071561736445275, 31.86445470779173, 32.17495149181735, 30.30504192075422, 11.542041974682963, 19.452202550826534, 17.724924087524414, 8.776026733459966, 1.1452073099151736, 0.45825470539350666, 0.07547933367952224, 0.07135259423164592, 0.03726096913939522, 0.017015906388781244, 0.12945336890557121, 0.2069431471247827, 0.3069770696663088, 0.2976942290702174, 0.1238907355394575, 0.12143202997263401, 0.127274377361661, 0.044738297545981985, 0.10562680871976961, 0.09026538220144088, 0.04006476284215047, 0.025193031216340683, 0.4668046756377144, 0.04920783069645686, 1.7692317669430089, 0.563487392519751, 0.05682547193681521, 0.13534314479799042, 0.24986590439033127, 0.1947163991750248, 0.07445130497217178, 0.022197698295537024, 0.1895623741250846, 0.43499235364217914, 0.7336608933344965, 0.07181948651709864, 3.361982861834188, 4.291087677401881, 13.438760945873877, 19.01481120817123, 5.850644121246954, 24.028284741986184, 29.248120054121944, 30.791602134704593, 31.0654757484313, 26.349698343584617, 21.993412048585956, 16.19141463310488, 19.817279115799938, 16.43118029640567, 25.60642880778159, 20.12072543944082, 9.70898699375891, 18.36026372448091, 25.937500384546098, 33.448858876382154, 45.055654279647335, 21.034841652839415, 2.7066776252562, 2.0887935161590576, 2.8153407621768216, 1.8289233768178572, 0.5398197496129621, 7.228730147884739, 33.893898840873476, 51.1737358954645, 48.937961363023334, 48.159849412979625, 48.134212801533366, 51.13291971145138, 49.57329119405439, 52.331796076989946, 52.05671241206508, 53.05273555940198, 46.55326227987967, 22.879675511390936, 6.137371342028342, 30.212187651664983, 70.41863333794379, 53.04217261652793, 48.79304155226677, 62.1484217336101, 29.696356750303703, 20.265458937614195, 36.139373394750784, 31.04614042466687, 34.195944878362845, 37.32683566308791, 34.27258014678955, 44.12913553176388, 76.49932692127844, 37.17728745552802, 39.554420286609286, 47.42424811086347, 56.10242151444959, 4.4638097382360895, 0.33291711321761536, 0.11255472568013977, 0.060338011882718534, 0.033252885219671076, 0.01078925290775876, 0.028561514073742494, 0.08930949599391992, 0.05494459584775952, 0.016769781490908037, 0.04810169166434677, 0.08752711582928897, 0.03642533958378819, 0.046108874807795214, 0.07268542634142984, 0.039468363393098116, 0.05859152293734013, 0.10066714017621933, 0.12770013838645913, 0.03875429666931591, 0.08752445750419172, 0.09431185861749035, 0.08964242248405373, 0.030798586573632016, 0.0218240887061843, 0.14569734403442952, 0.2449967108306385, 0.27704978361725807, 8.132069649234895, 83.82619673205961, 63.955171338973514, 38.19544061537712, 32.497289911393196, 43.582353207372854, 35.53466550765499, 36.863890078759965, 31.821630270250385, 47.3466871630761, 31.29723095124768, 41.34784952286751, 30.67825544265009, 33.89505594007431, 14.274493494341451, 49.88025588373984, 83.90545998850178, 65.6267011550165, 46.30250907713368, 18.000027364300145, 8.688344109442927, 43.20832775485131, 71.62170271719657, 68.79896902268933, 59.68027422505041, 63.63149342998382, 64.9669075012207, 62.83424031349921, 56.492685579484515, 58.32904123490857, 51.74324443263393, 28.824368753740867, 7.785116395642681, 11.756563263554728, 13.045223662930152, 9.982917481853116, 10.080561945515296, 4.1236843505213345, 12.9322241006359, 55.47992175625217, 41.977409547375096, 38.85861927463163, 22.705596800773378, 21.316122662636545, 27.038884278266664, 15.72298655586858, 28.97463671622738, 13.299449143871186, 16.606621050065566, 36.22967812322801, 33.487062761860514, 37.157534399340236, 34.46604713316887, 16.33396827405499, 14.092936784990373, 20.700259554770685, 17.918359694942353, 0.5122666619718075, 0.8065540980427497, 0.12167017606477584, 0.09115723878025048, 0.04024341071565305, 0.04291471334234361, 0.1333518218128912, 0.16120081857567833, 0.21838600326689983, 0.10039746956599337, 0.09809516084891173, 0.11618848754874161, 0.2667205894906675, 0.12461590670770216, 0.0649247718073668, 0.12168114644385154, 0.03309827718523241, 0.11681137831821559, 0.3464921299488314, 0.0551537225293296, 1.823619229178275, 0.5542630810410746, 0.08321078494191171, 0.31815349575011964, 0.07310230840718554, 0.06855762203133876, 0.03618792510561405, 0.04829027186778765, 0.32620293478811946, 0.45975446040111206, 0.4119983471689686, 0.5459817318666367, 7.508962413957042, 7.870161716015109, 24.118099174191876, 24.393788845308368, 17.434160747835715, 31.30128864319094, 33.95484855098109, 33.49278157757175, 34.3632653451735, 21.77745419163858, 20.468331767666726, 18.267770313447524, 19.108247949231057, 18.685041858303933, 24.81668899136205, 20.126485440038866, 20.276657304456158, 36.94266303893059, 37.11345088097357, 37.34066201794533, 51.996096103422104, 31.21964450805418, 5.265905510994696, 2.660956027046327, 4.4813039995008905, 4.184942947280023, 2.560395771457303, 6.837314867204236, 39.80175710493519, 53.09453625832835, 51.456860419242616, 54.397022031968646, 55.52245593840077, 56.892892852906265, 54.58539385949412, 55.66176283744074, 61.134010514905384, 59.495871836139315, 53.18525283567367, 22.828533687899192, 9.461874731125372, 40.24449071576519, 72.6272258450908, 55.89869360769949, 51.16188641517393, 54.573877780668205, 31.173338966984904, 26.196610196944206, 33.191578849669426, 31.86051468695364, 31.678926598641183, 29.483501488162627, 39.450536312595496, 31.15478615606985, 78.65014291578724, 41.05551135155463, 33.2972357350011, 55.25162804511286, 62.21066190350441, 5.694555361424723, 0.3945950052190212, 0.18842468759225262, 0.07293103412995416, 0.016851574783363653, 0.03907485850035183, 0.02260390301084807, 0.02547206150578155, 0.03148403991344235, 0.021041010866963097, 0.11668895746791556, 0.14719481610002058, 0.10110721938432225, 0.3126721672954098, 0.15726082838110386, 0.20187558275797676, 0.13486406405366239, 0.24538796725532702, 0.1428161486382446, 0.17189194328121601, 0.14125624040682472, 0.19811196132533013, 0.3143182144530358, 0.13111524343971284, 0.17447500790078796, 0.3067389388959254, 0.46601330681193265, 0.6149903805025163, 14.882907040657537, 98.22045587724256, 70.88479134344286, 62.41085575472925, 38.306651576872795, 51.91014912820632, 44.93239379698231, 59.160811208909564, 43.01084033904537, 51.72299323543426, 51.15510071477583, 65.27193846241121, 47.45393260832756, 31.39689445495606, 19.519992874514674, 53.71587107258459, 85.18365844603508, 67.58816472945675, 50.062132266259965, 17.871410885164817, 12.109481461586492, 46.706395533777055, 76.44057766083749, 75.35184537210773, 68.24441648298695, 64.20415163040161, 73.4327708521197, 70.3471677534042, 62.66193059182937, 62.32914493929956, 56.97555680428782, 31.440458259274884, 18.684790826612904, 24.515262688359908, 23.271608544934182, 22.159236131175874, 23.34735147414669, 14.567123882232176, 18.402040889186246, 62.98044273930212, 49.83178715552054, 34.26291542668497, 16.680208636868386, 24.992044433470696, 31.842440405199607, 31.671703553968864, 39.713488086577385, 9.88737246682567, 27.46860738723509, 42.23725872655069, 37.35213887306952, 39.53082330765263, 35.29978221462619, 14.183151298953643, 30.81856450726909, 32.656581286461126, 33.31681228453113, 7.338385889607092, 1.7902972236756356, 0.3774976694295484, 0.19343346237174927, 0.294203472834441, 0.09799247442354118, 0.438557175258475, 0.940980036412516, 0.5408347854691168, 0.814929767962425, 0.28437759847410266, 0.5455613028137916, 0.3343767865050224, 0.19232317114308958, 0.16067427102356188, 0.2666995067509913, 0.15503325920191505, 0.2550763441550155, 0.5972113796780186, 0.209073331207037, 3.1849628638836647, 0.7849825329838261, 0.22383210699885125, 0.5993799600870379, 0.3400587993523767, 0.6702297325095823, 0.12521528623877995, 0.13963328313923654, 0.24915137418335487, 1.1654750546140056, 2.740554891286358, 0.9170437111489235, 9.097653242849535, 17.6379043440665, 36.971076688458844, 41.4341652008795, 11.463969157588098, 30.489412930703935, 39.72290569736112, 35.838417776169315, 37.38644784496677, 30.456588575916907, 28.69172400043857, 23.3239015840715, 24.095353349562615, 19.58959141085225, 32.22503623654766, 26.173115199612035, 15.24149404418084, 26.324083305174305, 37.291836354040335, 47.58873270403954, 55.92918611341908, 27.101981486043623, 3.6926190555095677, 3.688912660844865, 6.8025940464388945, 4.781273141984017, 1.324535254989901, 13.0242262348052, 41.106007945153024, 59.388889189689394, 55.9484096496336, 60.28513900695309, 57.324977228718424, 64.29131454037082, 56.2464548695472, 63.73154917070943, 63.826827464565156, 64.21592266328874, 56.40110608070128, 30.39768634303924, 9.853251768696694, 36.79597816159649, 81.59905925873788, 64.55594901115664, 57.76473376058764, 74.01239518196353, 42.45052975993003, 28.837126262726326, 46.34206225795131, 41.62445898978941, 44.40013600933937, 52.915578119216434, 47.55229388513873, 56.73168736119425, 94.24937771212672, 48.14386967689761, 56.3350925907012, 59.456561842272365, 82.65956617170765, 12.227337898746615, 0.880863217096175, 0.24314725200735757, 0.2104619115350708, 0.07624736746713039, 0.20638597137745351, 0.11089570099307645, 0.26927239772292877, 0.15126893296837807, 0.1889343965317934, 0.17292429272445942, 0.2896304488662751], [0.05839962174274749, 0.03743150031134006, 0.027446197308299523, 0.02980076279791613, 0.038805118942212675, 0.0859343730694344, 0.07475318191873451, 0.05241231519668814, 0.04713840887791688, 0.01201584394420347, 0.04849193685297524, 0.08088809062516497, 0.07071792869077576, 0.07681477814912796, 0.1240274515904246, 0.13470684748984155, 0.1465656740530845, 51.51682169206681, 66.34630310919978, 50.23163357088643, 38.3994117090779, 33.84118610812772, 35.00382369564426, 35.81221242104807, 41.67609307073778, 24.339207103175504, 23.828185027645482, 31.119449523187455, 48.40814721199774, 26.06329275715736, 47.296127811554946, 44.970946773406, 52.95342114663894, 62.41415054567399, 76.35186933702039, 36.151670025240996, 3.3615062938582514, 50.779443556262606, 59.41420808915169, 65.89345762806555, 39.73746945781093, 34.261036611372425, 59.932215905958614, 56.48241681437339, 60.56850671768189, 57.013697931843424, 52.132335708987334, 37.70992963544784, 10.566401423946505, 6.989455271151758, 8.191322443946715, 9.855894465600292, 8.480155487214367, 17.835040707742017, 43.89340500677786, 27.63705945784046, 19.888397570579283, 11.910481972079124, 22.108459088110155, 29.05791844091108, 18.596906200531993, 17.612420705056962, 11.602724963618863, 16.87764898423226, 37.32421159744263, 27.53258908948591, 32.278317712968395, 38.80251761405699, 22.276783681684925, 14.860167099583535, 16.569958656064927, 18.819745855946696, 5.272338688373566, 0.6166565910943094, 0.9501590567731089, 0.10413760274288156, 0.16028348957338642, 0.14888059257739975, 0.044332355215785005, 0.07045304613007654, 0.29009276760681985, 0.5133164169326906, 0.9311925583789427, 0.8711401517352751, 0.17658775582188563, 0.2143942102068855, 0.6970776821817122, 0.24773785003250648, 0.1611875652545883, 0.4016704400700908, 0.1361297792004001, 0.48631200146290565, 1.3198454485785578, 1.0862203783565954, 0.49086483135338754, 0.7248541917051039, 0.5199571734955234, 0.47657297082966377, 0.024101624055014505, 0.11333581360597765, 0.07559516617367346, 0.10145106262737706, 0.7550794246696657, 0.2233875308546328, 0.3342828334819886, 4.735659899250154, 4.774200127970788, 13.360941121655127, 23.62562990957691, 8.745944115423388, 18.759278597370272, 37.26081040597732, 31.56446595345774, 32.00342036062671, 33.72798258258451, 24.39883105216488, 15.507997524353767, 25.291560542198923, 18.062028269613943, 15.607276635785258, 23.08984591114906, 22.592505062780074, 10.887015961831617, 16.003228137570044, 25.061433123004054, 31.731556961613318, 47.160672680024184, 40.95654602973692, 14.905183161458663, 11.827639552854723, 12.911668919747877, 8.73756887451295, 6.462670170491742, 37.215393281752064, 47.076577063529726, 49.11493086045789, 52.35793082944809, 54.21820117581276, 51.92355971182547, 54.14197383388397, 53.61556430016795, 54.077509680101954, 55.4242790129877, 50.30360514117826, 29.32095454585168, 25.382763493445616, 49.63410362120598, 50.858985300987, 47.067073160602206, 26.565667967642508, 45.97736027932937, 21.03368063126841, 26.740023205357215, 34.693372018875614, 32.93434981376895, 35.19871450239612, 46.51649790425455, 21.726790897307858, 66.17138108899518, 49.13481727723153, 23.249105907255604, 53.65754542812225, 49.96556351261754, 32.8227936836981, 0.6964853429986585, 0.1251025947051183, 0.13593146968032085, 0.08108346602849423, 0.11882628148962414, 0.052089340188690735, 0.015994597230136635, 0.011563700766512945, 0.06885445045848047, 0.03137370601536767, 0.049588729612409115, 0.09153790786982545, 0.021721994083735253, 0.01431468707103763, 0.06638509626950949, 0.057619085400215084, 0.0295130048517979, 0.023895871990750876, 0.015770027173622962, 0.042606408918096174, 0.05197539610127288, 0.09665879961704055, 0.12085218568362537, 0.05112125403097561, 0.04159833680117323, 0.03412621396203195, 0.11695005555426884, 0.12300869254695794, 0.11552851046285323, 57.30284721620622, 79.11840331169867, 50.87760086982481, 37.89465365871307, 34.03778314590454, 35.085428607079294, 41.289370905968454, 31.81133600973314, 36.09434458517259, 30.197790591947495, 33.08507081001036, 37.39042905069167, 31.583805199592348, 40.89977364386282, 50.528910006246264, 69.41873488887664, 68.61540209862494, 78.0239051388156, 36.191678200998616, 4.527306047178084, 55.39521032764066, 65.07566305898851, 67.78075310491747, 50.601822945379446, 53.48966798474712, 64.92042741467877, 61.786536016771876, 60.766398137615575, 59.60880864051081, 53.94352151501564, 39.27276272927561, 8.498807337976272, 10.165888205651315, 4.52160733361398, 7.024086367699408, 3.074681013822556, 16.720760060894875, 52.43070256325507, 31.844227044813096, 34.692905256825114, 22.37319946289063, 27.38121109624063, 28.284634928549494, 23.419815301895145, 17.51038024502416, 16.807052204685828, 17.843891536035848, 27.74043744610202, 32.040716217410186, 33.64142763999201, 40.98221794251473, 34.616438650315814, 14.7018474917258, 15.617383603126774, 21.051809826204856, 16.372750709133765, 1.6965258554104836, 0.5967818188571161, 0.1484791471833183, 0.052751351238018086, 0.1260123700804768, 0.03551416992840748, 0.0784870331746436, 0.4326860919114082, 0.6834872211179426, 0.7454010375565099, 0.5250382363315552, 0.31726550791532765, 0.5149080412041757, 1.0535641951907067, 0.732068594905638, 0.32279007437248386, 0.5438279829198315, 0.0601325087970303, 0.5927116856459649, 1.7323006905855673, 1.168399304151535, 0.6383423951845015, 0.13992091851128688, 0.3083555682772591, 0.09191994059590564, 0.03603736201541559, 0.39742628232606, 0.29721622084898336, 0.09993067687197078, 0.6742888340546239, 0.0816934711990818, 0.19189923340755125, 6.384869467827582, 10.342899868565222, 25.13937846306832, 23.252618389744914, 18.92211579507397, 33.3599034432442, 40.19399412216679, 35.31010589291973, 35.79207105021323, 29.911196731751968, 14.179903576450965, 17.20976979501786, 19.445954215142038, 20.74050699510882, 18.407618499571278, 22.827837467193607, 24.918043036614698, 18.682227557705296, 34.10696983337402, 45.26052751848775, 34.31680879285259, 50.51082003501154, 50.231374694455056, 18.791589121664725, 7.790912678164821, 2.379621574955602, 5.457115173339845, 4.902203736766692, 45.566766569691325, 52.80297079393941, 58.23040931455551, 56.127995367973085, 59.40597111178983, 56.46171062223373, 61.23616080130301, 56.206509451712336, 62.584722657357496, 60.2779257682062, 58.25456327007663, 31.537838943542976, 31.077872399360906, 53.7211819617979, 58.143415066503714, 48.56464193713281, 28.282605101985318, 50.56032034658617, 27.36909685596343, 30.542694407124674, 32.15314703602945, 33.64225918246854, 27.10319938198213, 44.15614889514062, 24.302295638668923, 51.16837009306877, 59.94469688784692, 22.88197009794174, 53.57022170097598, 60.90207292187599, 38.570576098657426, 0.7982472534621916, 0.18397589244188803, 0.10745518480337436, 0.07090263248931977, 0.1284154116987221, 0.03020072198142448, 0.03455240399606767, 0.04328851828411703, 0.0782329830971937, 0.05228793316130197, 0.033739450643019336, 0.08928632183421044, 0.16208240191542334, 0.10653460758828348, 0.19977500031311668, 0.16834501747883138, 0.1094183080919808, 0.19807457623462524, 0.31166206504548755, 0.15369461248478583, 0.1441369301849796, 0.12373388669784031, 0.21267964414531187, 0.15852170185216014, 0.13298347141713868, 0.13416117838313504, 0.30334544518301565, 0.2273725210538795, 0.7538937657110153, 76.33016294048679, 83.96223237437587, 68.42646937216482, 53.90377613805956, 41.60124248073947, 47.585324164359804, 54.28974128538563, 55.125198287348596, 33.21456786124937, 33.30838311103083, 44.77051365760065, 64.49153977055704, 33.87524404833394, 58.791112130688084, 54.84767883054672, 63.011649116393066, 75.64435220533802, 87.35372543334962, 43.88504643594065, 6.462918750701412, 58.198767554375436, 71.04873072716498, 74.61801698130947, 52.13971760965163, 48.523868899191584, 69.8008051226216, 67.37362677051176, 67.31284572232154, 65.83926616176483, 59.9421355801244, 43.7931296133226, 17.034871309034287, 16.90980261371982, 17.344917020490094, 19.337031956641905, 22.02736016242735, 32.07478200235675, 58.18916559219361, 42.805241461723085, 28.05393876567964, 16.139793299859573, 28.267217643799324, 37.51904356864191, 21.83330874289236, 27.888685387949792, 20.549571898675737, 23.689021295116795, 47.82658523128879, 33.787641832905436, 38.05883622938587, 45.309313958691014, 31.074442286645215, 20.115143906685617, 32.34260339890757, 30.718524456024173, 33.552542809517156, 11.625161901597055, 1.7595878844299626, 0.37180603451786504, 0.253520802624764, 0.24399017855044336, 0.11455230760358034, 0.13057915043205987, 0.516638848329744, 1.1898008589783025, 2.0031082365782034, 1.517534621300236, 0.8606228064144812, 2.4219807213352573, 2.4678408282418407, 1.2924903487005543, 0.6878555770362578, 0.5289705962904039, 0.258260925690974, 0.6787181092846779, 3.1632927492741616, 2.8250336743170217, 1.93389029272141, 3.1308383230240118, 1.7372371160214948, 0.9864553833200086, 0.17399303134410612, 0.46835680041582356, 0.18974330877104115, 0.27256982401013374, 2.61318548071769, 0.25773158957881315, 0.398376016847549, 7.946298353133663, 25.028132200241092, 30.41559784643112, 42.403002400552076, 19.148875859475908, 25.797552177982947, 42.46004935233824, 36.86234466491207, 38.374222247831284, 36.163829372775176, 30.330582434131255, 22.702166688057687, 30.762717800755656, 20.522746809067268, 19.771346199897028, 29.49553139748112, 29.83861327171326, 13.088388366083946, 20.471067620861916, 33.58047008514404, 41.13122094062067, 62.03339822830693, 52.80223338834701, 19.920853222570113, 32.3315344702813, 28.272463813904796, 20.440853603424568, 10.993538710378832, 48.48248004913331, 52.84153553747362, 58.93957776408042, 60.669303786370065, 63.259876312748084, 61.24635504138086, 66.53685185217088, 59.249115528598914, 65.64651304675688, 65.0610718419475, 60.71137512883833, 35.643428910163145, 31.416786755284956, 58.29781132359659, 62.86184595477197, 58.5947229785304, 37.25233808640511, 53.13369720212875, 28.82542387131722, 35.16891233382687, 48.00994426973405, 42.46583877071258, 48.66712170262491, 64.56622169863793, 29.341686233397457, 79.60008605833977, 66.36593849428239, 35.8694633360832, 73.44986454133065, 64.15678116583055, 58.454427642206994, 0.8245533031802025, 0.2620978617379742, 0.19326092404944284, 0.218178209578318, 0.18566943705081942, 0.15005198697890007, 0.22487176492089228, 0.11587884247062669, 0.1538375338479396, 0.11132367601197575, 0.19803411147046476, 0.37699569797804283], [0.02860344398105818, 0.03676479697347649, 0.07862941061537113, 0.08044886177465801, 0.00963745120492193, 0.020744795310160807, 0.04247503249996132, 0.08737762143174488, 0.10817075688992778, 0.05338528516492056, 0.03621078133883496, 0.035004066453585704, 0.018398264167650093, 0.11403445514940447, 0.05134746830369677, 0.08608176838606597, 0.2908193560377244, 14.669506569062511, 83.3793838562504, 56.45760782303349, 44.39133028830252, 32.673190562955796, 47.51993040884695, 31.90839113727693, 51.940578876003144, 35.81975906125961, 26.694204038189305, 20.562798130896784, 39.830476699336884, 35.60856296170142, 20.89884915659505, 60.57699472673478, 34.40887074316702, 40.44548473050518, 68.73042952629828, 21.335993389929495, 8.967134414180633, 49.90083656003399, 63.58399744956725, 72.0768859309535, 49.68987188031597, 29.99240940616977, 63.586021392576164, 56.022754253879675, 59.65844623504147, 39.662728694177446, 48.52580655005671, 44.780186222445586, 6.199770367914631, 8.040437198454335, 8.841334196829028, 7.513767807714402, 16.653936601454213, 42.70252243165047, 30.83347147510898, 25.72785754357615, 13.55646735237491, 13.380517671185157, 28.594286441802982, 19.298308357115715, 25.375324718413818, 21.97575746044036, 19.259847556391072, 29.40795271627365, 29.824471166056973, 24.524182158131755, 29.91759215631793, 32.58061085977862, 5.6876304168855, 14.233258597312437, 14.621563438446293, 17.294722449394968, 1.6895694093358133, 1.8583297537219141, 0.15654962299571884, 0.16632078335650508, 0.09875608788382623, 0.04767996792290961, 0.10005124378949405, 0.19692017366328549, 0.34407533705234533, 0.9247082676137648, 1.801320922470862, 5.45342275211888, 3.985376920430891, 2.3212983819746205, 1.6561589053561612, 1.6668598666306467, 0.5112818712669035, 0.6041970596678796, 0.6154070710462909, 1.2090810244121861, 0.5566266767920987, 0.7980716048229126, 2.6189918143133966, 6.08942723081958, 3.1861841918960696, 0.34860901474472017, 0.0873592812868376, 0.11755162609681008, 0.035892923798171744, 0.9375839992876976, 0.02665323310441548, 0.08510246287069975, 0.1916531200009969, 3.7427042905361425, 6.1117043322132485, 12.314597887377586, 25.03831075083825, 25.55575962989561, 11.526835926117437, 26.28797200418288, 37.08011857924923, 34.3836812819204, 35.127413657403764, 34.93371917355445, 9.912284420382592, 23.596453359050138, 22.99882338893029, 20.15879204196315, 19.05188152866979, 18.995823014167048, 18.970772797061553, 8.217261077896241, 12.45898033342054, 35.37836297865837, 44.213431189137125, 46.485060107323434, 64.13023848687449, 28.40835040615451, 8.971433331889491, 6.444640015402149, 8.686830074556413, 24.249375020304036, 44.40156767445226, 55.06760612610848, 50.55822580091415, 52.133508497668856, 50.44521839387956, 56.32801271254017, 52.10323564467892, 56.81800696157641, 54.143723210980816, 59.71304562784011, 18.417318521007417, 40.6709857140818, 68.9155653984316, 58.978538667002034, 45.85557460784913, 45.70597148710682, 63.223343356963134, 16.468167266538067, 31.444357095226167, 32.78591948170816, 34.37688773678195, 43.93930066016413, 26.163411255805727, 23.144511984240626, 72.30534045926987, 26.29007439459524, 29.961499168026833, 37.60712431323144, 62.250140559288766, 6.779112287106053, 0.40133060346688, 0.12038354671770528, 0.04820069320680154, 0.049644014347464814, 0.04470519871721345, 0.033384426346709656, 0.038613646756857634, 0.008806530217219506, 0.07024774988812786, 0.04075059922592294, 0.12024782658103975, 0.0810437826740165, 0.004380464416763355, 0.05006071255211869, 0.013259785914523228, 0.11284187075591857, 0.10005380252316114, 0.011450765042325423, 0.038986237449271065, 0.045808924572362054, 0.24761428005032002, 0.062607217940592, 0.032506336367899374, 0.05553780837104686, 0.0528434350065166, 0.05849034187474078, 0.09933594749459337, 0.17221662666528456, 0.4761774243125993, 17.46725182379446, 91.8567083727929, 63.58506433425411, 41.77979661572365, 34.54975443501627, 41.44555576385991, 41.57007140498008, 38.57066239080122, 28.6566815453191, 33.55037766118204, 23.019000061096687, 36.14047165839903, 37.50922195373043, 28.958019594992365, 66.3600706285046, 54.635725713545284, 41.15923450839135, 72.4568223953247, 28.125851500418882, 13.62563442799353, 54.42267433289559, 68.86342925410118, 76.97599687883931, 51.09242516179239, 36.402725250490256, 69.8436217154226, 59.78641356191328, 65.03878101225823, 46.38608301839521, 49.69319412785192, 45.91493968040713, 7.594720625108288, 4.222577108490852, 3.9245671899087973, 1.5816124216202767, 21.522337352075887, 50.81145794160905, 33.88599526497626, 44.39658626433342, 26.790533527251217, 18.57255220413208, 28.995639047315045, 22.028005392320697, 28.868189473305982, 23.071189157424435, 18.29478956037952, 17.857976767324633, 34.70753569756785, 29.45279717445374, 29.640149185734412, 38.79926596918414, 13.15040986384115, 15.175247173155508, 17.264612374767182, 22.4220133596851, 16.601757311051895, 2.9820402687595737, 0.33916125074028974, 0.09333789273495637, 0.22456097837177016, 0.09623181285156358, 0.14672194066787922, 0.05883125866192484, 0.09695178228280238, 1.0917067936351224, 2.8837589102406658, 2.483369246605904, 2.8051320583589616, 1.2885310837338049, 1.479006895134526, 1.526875378143403, 0.3244960296057886, 0.8352583093989281, 0.9159127815115837, 2.159477568441822, 0.09982334029289985, 1.9413237970682884, 4.604361499509504, 7.18416270709807, 2.1727187546991535, 0.14256706281054404, 0.04147863173256478, 0.32953143360153325, 0.03781342578511085, 0.14855054657786124, 0.09958095007365751, 0.11951469575926182, 0.12484657578170301, 5.562369525432588, 10.299111508554029, 29.379476308822635, 26.41034995355914, 23.554174130962743, 22.36787876775188, 34.287457696853146, 38.77116610926967, 38.9345798953887, 39.29627733845865, 25.417562761614402, 12.383719855739225, 19.200005915857133, 16.231690510626763, 19.338742110037035, 18.637726306915283, 19.72264212946738, 19.62813065898034, 12.198575158273021, 24.83591841113183, 58.40137758562642, 52.121298159322436, 49.01916619270079, 67.24550647120323, 38.15476955906038, 17.5904966169788, 3.8498742301617903, 4.616304626387935, 28.66624624498429, 53.912828968417266, 56.67968065507951, 57.27113093099287, 56.10910523322321, 56.274170337184785, 62.272231348099254, 58.929795372870664, 59.95538142419631, 60.70255764069096, 64.05006131818219, 20.89685267017734, 46.02834324682913, 67.40611968501922, 66.91127346407983, 49.3892849645307, 51.45290667010892, 67.87965174644225, 23.256564294138265, 31.262215952719416, 33.97702170956519, 32.940256903248454, 33.72791982466175, 36.0135123806615, 20.36425167514432, 71.45203667302286, 35.151461708930235, 27.9803256834707, 47.48246000659081, 68.69180202484131, 6.785225301019608, 0.39152268620748676, 0.18227488613657414, 0.08582075456938437, 0.09191431751054141, 0.07612707634125987, 0.1742371069567819, 0.13783078550571395, 0.04535277283960774, 0.032159896086781256, 0.03698469102082234, 0.23629565272600422, 0.06299949709265944, 0.22177275540607594, 0.26154885248791787, 0.12277972418814899, 0.23529056069110674, 0.1346876033611836, 0.1474403166362355, 0.17510258712835852, 0.21182747858185924, 0.2767470869566164, 0.13688174046335683, 0.12145678993434676, 0.17830363955468903, 0.09146964943577206, 0.12080001509598187, 0.38231072406614985, 0.4129040776000869, 0.7956916454338259, 26.68344105443647, 105.12061103697746, 72.53330861368488, 59.82178549612723, 48.49337247110183, 65.36686374295142, 44.511911792139855, 75.14687799638318, 48.16978869899627, 36.43755589762042, 30.78873095973846, 56.133808320568455, 48.37647407285629, 29.344125947644635, 69.32790848516649, 40.54950990984517, 48.865260231879454, 76.57872353830646, 28.18172174115335, 12.787393523800759, 61.331745040032175, 74.98591961399202, 87.30952032150762, 61.210206477872795, 39.160477038352724, 73.61202316899454, 66.03895402723744, 68.62046980088758, 50.2754895917831, 53.19360356177054, 51.957170501832046, 12.056359821750272, 16.48125033224783, 19.26147730119767, 17.75753075076688, 26.89491564227689, 52.203256084072976, 38.70674117918938, 35.69749878298852, 20.371876762759303, 19.728225623407674, 33.56411380152549, 24.38635007027657, 32.27652126742948, 31.745412734247026, 27.271551432148105, 39.1214180761768, 38.03578445988317, 31.202837151865808, 34.24154243161602, 39.91317595205, 8.365864484540879, 20.438027535715413, 28.315858956306215, 31.28299863107743, 32.16694985666583, 10.644056508618018, 0.43832256849254336, 0.7505419778247034, 0.31280522144609885, 0.40861812209890735, 0.26149216198152114, 0.4426766751754669, 0.7461959916737773, 2.4109076251906734, 5.720298857458177, 7.112627500487912, 8.922060497345464, 4.076390617316769, 2.1473998552368534, 3.5751526490334546, 0.8097863762128739, 2.153871766021175, 1.3708653108727549, 3.917713338328946, 1.448120681508895, 3.7744686247841006, 7.597992862424544, 12.297110980556859, 5.313380898967867, 0.8121447012789789, 0.128684890786967, 0.4209047015155516, 0.2009045356704343, 1.1217602390435435, 0.4743110809114672, 0.3781184764398683, 0.1614503334126165, 6.745493652359133, 27.363113280265566, 34.19958876025292, 38.85323778275521, 40.43165053090742, 16.152934220529374, 33.57164867462651, 43.255953173483576, 42.285319528272076, 40.44448452611124, 40.47359243515999, 18.515966130841164, 33.058190807219475, 27.790567298089307, 21.599360935149654, 22.471186153350338, 22.700217270082046, 25.281940929351318, 10.602080283626433, 15.337055729281518, 43.11501849082209, 52.43383653702275, 52.44824732503584, 74.88014897992535, 37.32179149504631, 21.195270515257313, 16.02435108154051, 10.315132429522853, 29.47269339715281, 51.55979910204488, 62.78319066570651, 58.449716875630045, 61.706256866455085, 60.87474184651529, 65.73378578309091, 65.58346486860707, 63.92005828119094, 64.17668327208489, 71.78747777015933, 22.30642895544729, 49.81358735792099, 76.31229262198173, 71.27440037265902, 57.531089936533284, 52.715317587698664, 77.67716761558287, 24.727264834988503, 40.72119989702779, 46.404459322652514, 42.60378852967293, 64.28823155741539, 38.11368665387554, 32.52713522603435, 89.17404251713907, 39.47269378169891, 45.08792361905498, 50.00741127998599, 86.09629984824889, 14.25149565742862, 0.8052326883039167, 0.5197835473283645, 0.4712383941777291, 0.18296586680075816, 0.26363913871107564, 0.39187364640735817, 0.264171110165696, 0.15980466929895265, 0.24409396814242487, 0.14329827841251128, 0.3936379162534591, 0.1654465238173162], [0.07700119032374314, 0.04588105558087269, 0.030070431492922288, 0.04951870151525063, 0.024237451443989432, 0.05595766285794878, 0.06841195807341607, 0.03604442151563783, 0.08115822854902476, 0.05498334840540925, 0.08725874756853427, 0.08606719739374616, 0.04506106187980022, 0.06845800761854456, 0.04684065731482641, 0.1471553778936786, 0.20816988371793302, 0.6528650320345356, 61.13771323234805, 64.1032604248293, 57.142547792004, 43.64281654357911, 42.15554006638066, 36.837500372240626, 42.21061014359997, 57.212142405971406, 30.534312302066436, 32.518813917713786, 26.376201798838956, 49.52277106623496, 18.59005578102604, 29.160453119585593, 8.534109650119658, 48.22534907248713, 77.47865646116196, 30.493235280436856, 6.973604482989158, 24.151176521855017, 53.23050914272186, 63.34323060127997, 49.60648229045253, 57.556495128139375, 59.437754077296105, 62.29031347459363, 53.972947136048354, 28.59657318361344, 53.065389125577866, 39.083351473654474, 5.326879245619621, 5.929677428737764, 2.8194416001919778, 7.714988339331843, 49.84202061930011, 38.713613171731275, 33.97930845137566, 13.861315923352397, 14.497501811673565, 25.31919364006289, 25.159880691959014, 27.13452539136333, 31.74800738211601, 23.306431347324004, 18.7780902847167, 46.91933708806192, 23.424169132786414, 30.504796466519757, 28.01836875177199, 13.104856437252415, 12.12105735655754, 19.0605225101594, 11.53403445597618, 18.645000342399843, 4.649961994540307, 0.8569824791723682, 0.58172904916348, 0.5046589185874308, 0.05746482593578197, 0.20498355550150718, 0.2722061773942363, 0.17316044698799812, 1.2856097759739047, 2.4679518803473446, 5.88383766912645, 4.391414551965652, 5.783031284809113, 4.248181850679459, 3.3278476999652002, 3.1643385512213555, 0.6443738973429126, 0.8376102606135031, 0.57668236835349, 1.6111651519613883, 2.3381692315301588, 1.738623306155205, 1.1658758718159892, 3.7883881359331073, 1.4435881376266482, 0.1584668959220571, 0.0344575010240078, 0.09007016001569648, 1.054409343388773, 0.11294763685474474, 0.02318069060903884, 0.20970391349927073, 0.42463836891035883, 2.743300795555115, 2.9874771641146753, 14.654565280483617, 24.747023774731545, 35.07903122132824, 15.10334816671187, 23.593599834749778, 34.30242546143071, 33.57528078940607, 34.38765464290496, 42.49609593422183, 19.975048611241004, 10.801338649565174, 27.73814089836613, 20.466923636774865, 20.41936685962062, 22.764848124596384, 23.20115493189904, 24.094937578324352, 8.531461069660804, 3.941263984287939, 33.89504417296379, 54.385223542490316, 52.09389255892847, 64.96300474289926, 31.753324154884588, 2.0643225840983854, 1.8687529621585723, 7.229008636166973, 38.171620061320645, 56.77355866278372, 49.26048609518236, 60.89277298219743, 48.78974676132203, 48.81483031857399, 48.51248225858135, 55.90515767374347, 53.524318202849365, 50.31767468298636, 25.079568201495757, 55.844137360972745, 53.75436129108552, 48.68944391127556, 53.23953843885853, 61.34572828969648, 34.59595995564615, 16.314127945130874, 38.20253226064867, 29.551623252130327, 31.078123431051935, 41.12177979561591, 17.289882244602328, 61.76662214340703, 67.54573252893263, 26.74513209250666, 42.96748245916059, 58.54714070597003, 29.646772107770367, 0.4512201183505597, 0.09794621037379389, 0.02828969458688892, 0.060858603101223714, 0.01526618455236237, 0.01140949875867415, 0.07522100883145487, 0.06366023260559286, 0.028743293331635576, 0.07617694866513053, 0.01266418319691213, 0.0932691746481484, 0.05277730246645309, 0.01598538789567688, 0.11533691953386992, 0.045556973575824694, 0.04323998278367423, 0.13109319542925205, 0.06647973111079586, 0.027863303454773083, 0.0862390538978, 0.092092034587216, 0.03424071729363453, 0.05485756825956126, 0.02404392614299732, 0.10474448227473807, 0.05851434723984811, 0.07332614397690182, 0.07141149873214384, 0.22693726053882032, 0.9031330253328047, 66.85617200789913, 74.02736294654109, 57.65626845821258, 47.855316592801, 47.63658169777163, 32.89435732749201, 58.74924082909861, 36.584362368429865, 35.18353885219943, 28.569308788545673, 22.748358480391964, 42.57760278640255, 28.300710762700728, 37.688639010152514, 11.221033238595533, 44.6720229425738, 81.55566215515137, 41.45136479408511, 12.045230096386327, 24.95520161044213, 62.95331170482021, 68.56741582193683, 62.0073458456224, 65.19739381728634, 66.58497148944487, 65.67349503117224, 62.67690620114727, 29.729840063279678, 59.609208722268384, 42.82976804241058, 5.524856467400828, 1.151331968365177, 2.100947960730522, 14.88268836852043, 56.054686269452496, 42.00177531088553, 53.21723584205874, 23.898218947072184, 18.555574224841212, 25.396130930992868, 25.01864202560917, 27.746030745967744, 29.725792177261848, 32.3139504847988, 24.03457622374258, 31.249556502988263, 30.827684017919726, 31.96183539205982, 33.21255960772115, 24.338997256371286, 13.340275133809737, 20.16206329868686, 14.302242302125501, 22.827786476381366, 20.62265349972633, 3.54793899962979, 0.6172494205736345, 0.3366273689654566, 0.1329617298418476, 0.16267034375379164, 0.2835142480269555, 0.24725285508940298, 1.0796658526505194, 3.239749549858032, 5.02938658960404, 7.965955801548497, 8.017333457546851, 6.409641196650844, 4.265699646165294, 2.7305025919791195, 0.6303705455314729, 2.056430407589482, 1.4721824613309678, 2.056097006124835, 3.416180947134572, 4.369134999090626, 2.7531412868730487, 7.892422147335545, 3.0388359437065744, 0.4524141123458263, 0.027514448081473672, 0.06888974412915207, 0.11496647005720485, 0.4473863998728414, 0.09531744860953863, 0.34926754392443166, 0.7405292086543576, 2.824588485302464, 9.376263118559315, 30.158935593020534, 26.405072404492287, 29.465637053212813, 22.155511840697258, 33.38281008505052, 36.13030487491239, 35.90525888627575, 40.29392042467671, 37.49617615053731, 14.688385917294411, 16.278665796402965, 21.461124843166722, 15.421214103698732, 19.268831745270763, 19.35203306136593, 22.272839738476662, 24.356394929270593, 11.229669317122429, 10.437064209292013, 56.591815640849454, 60.70254979595062, 52.32745401320919, 64.64983094123103, 41.50381865039949, 12.733713926807528, 1.5660743199048506, 3.3220739710715512, 44.401324487501576, 59.64076419030467, 55.46781339953023, 66.54849344684233, 53.72621828509916, 53.223668529141335, 53.680263796160304, 61.46009675918087, 58.45350980758668, 53.99086844536566, 29.537749828830844, 56.95609792586296, 61.60764848032306, 51.42888607517366, 62.63361892392559, 64.89761883212675, 42.23887082069151, 24.380646944046024, 31.87773781438028, 29.553033344207275, 28.868609166914418, 37.66691692413823, 27.25464797789051, 51.32669656507431, 74.25024770921277, 28.615555494062363, 44.80971774747295, 68.52618386668544, 26.699458053035123, 0.5770169955588157, 0.15569678327489286, 0.09790845756088534, 0.040168820564905484, 0.030726350228031798, 0.01058721062426846, 0.04632124587172463, 0.09022010640511591, 0.028173159207067186, 0.0356568691260632, 0.134464641131701, 0.13580295077014354, 0.058067308122953104, 0.24999955608960123, 0.1721026634256686, 0.2462843973790446, 0.1350433439497025, 0.21549760664422668, 0.1799416274673516, 0.1511547858676603, 0.28564173547971633, 0.3059565486206163, 0.1505585243144343, 0.3243914739258828, 0.2397522567621162, 0.2591910483616014, 0.21014018525038997, 0.2981384374922322, 0.2361828232965162, 0.4447812412775332, 2.0630426656815315, 88.13060575915922, 78.72440122788953, 76.84405619098295, 58.93638495476016, 59.97687209037043, 48.79375150126796, 63.78790970771544, 78.52425052273658, 40.72157644456433, 42.94033181282782, 42.09469233789752, 66.2172414410499, 26.3217043876648, 36.32843948179676, 10.960125019473415, 55.717523251810384, 87.5635487033475, 39.96882654005482, 12.068924154004744, 32.530626135487715, 68.11635894160118, 75.33741889461395, 64.9279034522272, 65.15514204579016, 70.4483413696289, 70.73221898848011, 66.03606716279062, 29.79924051992355, 58.91396860922537, 52.49293096603886, 10.208108598186124, 11.957193478461235, 9.060013198083448, 12.559352805537563, 62.10556591710737, 46.26893751082882, 47.47465841231808, 17.85294044402338, 22.33183610823847, 30.692799591249038, 32.03582109943513, 31.83983595140519, 39.65444857074369, 24.810387703680224, 21.70769876049411, 54.47224916950349, 31.710380085052986, 36.05741154763007, 36.57968690318447, 19.359885646450905, 17.367943294586674, 26.27347884639617, 24.72293649950335, 32.29398954299189, 32.8385635729759, 13.899733578005145, 0.9543295781458578, 0.6684340837021029, 0.3713989966819364, 0.631499023687455, 0.4854403159791424, 1.2909150267800977, 2.051434411156562, 5.047157868262261, 9.367486815298758, 7.17132527982035, 9.24401060227425, 10.62126067376906, 8.011669555018026, 3.800771058567109, 1.4829141886964923, 3.824056209095063, 4.52472806938233, 2.7949601267614677, 5.971446748702757, 8.345111223959155, 4.83578133967615, 9.742660541688243, 2.7040435085373544, 0.48103665872927637, 0.10755801678545053, 0.16390720802930095, 1.395744292005416, 1.1321444689266145, 0.18507849214778793, 0.541609576152217, 1.3238932120223201, 6.072642428259696, 24.10707143045241, 38.304223629736136, 35.90153655698223, 52.778997267446215, 21.940405138077278, 27.162603678241855, 40.28135707301479, 40.65586497706752, 43.61644252654045, 48.19229525904502, 27.110363591101866, 15.257488489151003, 35.84764711318478, 26.2640102448002, 26.708701118346184, 26.070294187914943, 29.214724994474842, 32.54592534034483, 13.579999612223718, 4.877789924221655, 44.311914059423636, 62.59826660156251, 58.875380331470126, 71.76290804339995, 39.48112295519921, 6.451664490084495, 5.04488387415486, 9.023694011472887, 47.46782956584808, 65.44223208581248, 57.72329784208729, 69.61840706486856, 60.50499962222192, 59.672747196689734, 54.33850419136786, 65.28714156919911, 62.58057278971519, 58.71162137677593, 31.107362739501465, 62.00512578410488, 66.74916190485801, 59.356455110734515, 69.16983696722215, 69.0089491874941, 46.51709410452074, 24.119666161075717, 48.56377117095455, 41.2767683306048, 45.726544318660615, 62.0736692028661, 29.01001845636676, 76.94572402584937, 82.92684431998961, 39.174472055127545, 60.071969955198234, 73.94136890288323, 48.33439488564768, 0.595006027048634, 0.2269069387787773, 0.23834496856697146, 0.16490860752040343, 0.10446126723001081, 0.10950381116520976, 0.18111764903991454, 0.2413038606004369, 0.07900865478140694, 0.20628265675998506, 0.1543672223605456, 0.20739763644674133, 0.34146640930444966], [0.06720061984754379, 0.03601203131819925, 0.043245330077385714, 0.033406635235634544, 0.1067171433580018, 0.006060028399881577, 0.05225971048217147, 0.024121724286927812, 0.04088420879035708, 0.08485353026058405, 0.03581037016345128, 0.03945103831469052, 0.028089728401673418, 0.12097255341828832, 0.16480176889848325, 0.17112669805365224, 0.17310260734971494, 0.7718582823872567, 15.859242831507038, 88.09487296688943, 49.94454745323428, 48.232287745321955, 40.92525336050218, 47.457188175570586, 17.147808113405784, 44.82441486850862, 36.07724697359147, 34.21678835345853, 25.386148498904323, 46.32579226647654, 22.922645076628655, 29.689525942648615, 64.31993215314805, 73.39357068461757, 78.5265725658786, 54.8630545216222, 36.98388322707146, 12.44407238498811, 36.128602566257605, 61.900833883593165, 35.50956233855217, 34.349572350901944, 53.9440941810608, 61.78258619000835, 47.6964762903029, 26.4121973899103, 49.48181759926581, 30.01361962287657, 3.6929470637152275, 1.0400371662070675, 8.355058354716148, 57.47442345465384, 50.07595469874721, 43.57084497328728, 14.380183719819593, 15.638082931118628, 28.54042445459674, 23.759847533318307, 31.170405034096014, 26.63963406316696, 31.559106034617272, 16.418534574970124, 9.721957291326216, 32.19015655979034, 32.975558234799294, 24.087457618405743, 30.529980044211115, 11.513346895094841, 13.960383226794582, 18.920880248469693, 14.948854830957229, 21.020983919020622, 5.8368187469820825, 1.4443278721263333, 0.14327275236287426, 0.2187724180159069, 0.060241971270091114, 0.2766416732582354, 0.3438248875881395, 0.6749064234956619, 1.7911271726892841, 2.6175013136479164, 5.153825744505852, 3.4443313075650126, 5.685868292085587, 5.817310838930069, 7.117967317181249, 6.432058032481901, 2.3237255936668766, 3.442228672004515, 2.1754501952279, 1.3479445730486226, 3.2387162504657625, 0.9904410017113533, 4.691608740437416, 2.4343388840075466, 0.2034029935396487, 0.1542399904780811, 0.1390982932981945, 0.2621658290586164, 0.14579175671021785, 0.14844464258320872, 0.41017092103438996, 0.08596864018228748, 0.11612854116866667, 1.8400246649980547, 0.3200923723559226, 13.847836698255232, 25.504725671583607, 35.41288375854492, 24.026953097312685, 9.385821934669249, 31.16206999747984, 36.23005467076456, 32.73953157086527, 37.458705748281176, 44.58475020623977, 19.407261994577226, 13.03245242564909, 23.910770531623598, 24.020059531734837, 22.128251367999663, 23.199662470048477, 19.48620753903543, 24.477839354545843, 15.64537069489879, 4.441750328386984, 38.02351920835434, 60.065607870778734, 59.00668167298841, 57.08631669321368, 14.452131755890386, 1.908816296246744, 12.057235490891243, 58.93413351428125, 46.89787780084918, 56.29553548751339, 63.170752217692716, 57.2228269423208, 38.57980543567289, 43.60842520190824, 49.257493326740885, 56.504919452051965, 47.447319492217034, 36.72294755135813, 63.018709382703236, 56.923436349438084, 58.20599256023284, 56.765372676234094, 52.986533795633626, 28.527162921044138, 17.824750369594945, 40.822855964783706, 27.628936229213593, 37.51334828715171, 37.06938697445778, 28.09793991427268, 78.88707760841616, 47.856006929951334, 27.195080903268632, 45.650650378196474, 43.49432345359556, 2.362610745814539, 0.12794338662417667, 0.04181918079754518, 0.0530664891665501, 0.025028695780483466, 0.07602399155016869, 0.10286995705457465, 0.0740118386344083, 0.05003363900487462, 0.040367884681590145, 0.1079934151963361, 0.050762422277682254, 0.08902883968285977, 0.045322883919241934, 0.05686121759936214, 0.0543878261270302, 0.07341467309743166, 0.02372516461858346, 0.04541949526737294, 0.02784612201785128, 0.025870350617614966, 0.06834616644247886, 0.06299965031024429, 0.12397734944017665, 0.06274533976290016, 0.0729999284169847, 0.006845555805240668, 0.10848869870026266, 0.2363369755086399, 0.2421628749899326, 0.4049849654397657, 0.9668456162175826, 18.473169149891024, 95.48688550149241, 60.12056027689288, 44.56625623087729, 43.81009778668804, 29.41099059197211, 18.305170113040557, 25.554371110854614, 23.95971582781884, 35.314855883198405, 21.61784902695687, 38.698923895435954, 30.22030499673659, 32.194328000468595, 43.08114882438414, 74.4950585211477, 78.37570251957064, 53.29427119224302, 40.36896713318364, 15.247155985524579, 37.609211014163115, 70.40254377549695, 39.92958714885097, 35.74589690854473, 60.16674226330173, 66.07997417449951, 55.00405980694679, 29.094975033114036, 50.10617263855473, 34.493695920513524, 2.106275765165206, 1.0858668747448152, 17.836399809006725, 62.756475402462875, 54.089112051071666, 61.85291036482781, 28.460843486170617, 18.58656487157268, 28.84932483396223, 22.95849750118871, 31.150863785897535, 26.20090715346798, 29.45455243510585, 21.262001798998927, 17.160424417065038, 40.6306480592297, 37.165359527834006, 28.40992327659361, 37.850570140346406, 18.793071777589862, 14.349881449053365, 19.931129832421583, 18.9742793959956, 26.20138176025883, 22.418891153027936, 5.945060964553587, 0.6856029721037035, 0.11696757598509712, 0.035799012909973824, 0.5686277199176051, 0.15325962776137939, 0.23596223593959886, 1.033467318742506, 4.122492930581493, 7.8598051878713795, 5.657535051145862, 5.640300156608705, 7.07823419763196, 9.126564052797134, 5.330180900712167, 2.4190134482999004, 4.820522829409569, 3.9894279933744863, 1.3678639622465258, 6.55788129375827, 6.2918391823768625, 5.583636126210613, 2.7257400991455203, 1.1871525236675817, 0.039337389171123505, 0.10707831550990382, 0.3959321044385434, 0.11075818054978886, 0.44622209944551994, 0.3662103138143017, 0.21430865350750186, 0.14348627638912972, 3.435194391396738, 7.504924333864643, 28.54836725419568, 31.09993769276527, 32.826723898610766, 21.193279912394864, 16.07907206781449, 35.7066261383795, 36.199075791143606, 35.921889735806374, 42.35112905502319, 31.529162660721813, 15.288638972466993, 17.601183114513276, 21.619467004652947, 18.793136496697706, 21.072621922339163, 20.162771286502963, 18.52562104502032, 22.564081607326386, 18.499782431510187, 11.471406952027353, 62.65699232778242, 68.71510874840521, 59.947352332453576, 57.687780780176965, 23.552871904065533, 9.555813535567253, 7.773017844846172, 58.64858496573664, 54.52710351636333, 55.16437884299986, 65.46267547915059, 63.652752676317775, 43.65192428711922, 47.367091332712484, 54.66686148797312, 63.57705877673242, 53.026396843694876, 41.75048082105575, 64.6616098188585, 61.25165416348366, 70.08675375292378, 58.87558821708926, 55.632266613744925, 38.0692030537513, 21.800217666933616, 33.27441930770874, 28.81000111179967, 29.07848538890962, 36.28822342042, 32.49587981931625, 72.24097436474216, 57.407221486491544, 27.195426071843794, 52.90492496182842, 46.80822026345038, 2.921295257345323, 0.1969481818377972, 0.03809911529383352, 0.12277877423912288, 0.02597311365177795, 0.05442321938913196, 0.11395627587673166, 0.014120661897674925, 0.026302776607354323, 0.06243729580854697, 0.10261112658847725, 0.20485997019756227, 0.09256181502414328, 0.08883642137891824, 0.17193070733018462, 0.18569157699183111, 0.17851633620598625, 0.18536117859184745, 0.23807280817099158, 0.16373814774617074, 0.22150558990336236, 0.08970920236841326, 0.2077515843895174, 0.46584559484354915, 0.18784543319094568, 0.1642500783406919, 0.19432007124827755, 0.2973768235214295, 0.45076202841535695, 0.3672815192370646, 0.4905836157981427, 1.378359611957304, 30.381663460885328, 115.25246189486597, 67.9268378596152, 68.28784496553483, 60.19537556555964, 62.84491700510826, 27.14774181765895, 66.0001931651946, 49.346295787442116, 43.03123666394142, 41.235822708376, 63.815562417430264, 30.665190027606105, 42.84846205865183, 76.63995958143666, 88.77254086156046, 90.1367098285306, 63.283336008748705, 44.45287619867633, 17.16476059729053, 44.687822249627885, 76.08365766463741, 47.53519235118743, 42.40919582305416, 62.664809611535844, 73.60532376074022, 57.7802820359507, 31.430868064203572, 58.90154646288965, 40.25692070684126, 6.50160312652588, 6.129556019460002, 12.482181152989789, 65.24691374071183, 56.44585640199723, 54.893076342921105, 17.437775211949504, 19.061491335591963, 34.18835901444958, 28.018029466752086, 38.21204400831653, 31.53742317230471, 39.595409054909986, 21.172779644689253, 12.797453422700206, 40.05012942898659, 41.65473576514952, 33.05672384077503, 38.991093404831425, 15.395932466753068, 19.60840309819868, 27.829885136696603, 30.39000438105676, 35.48232540007561, 35.91792421956217, 16.921579530162198, 2.2757336785716396, 0.4530414157817441, 0.14729164961364963, 1.079547078378739, 0.35981418444745006, 1.8103578181997424, 2.169049132254816, 5.37164427580372, 8.76181108336295, 6.775477720845131, 8.933800151271205, 11.498322256149786, 13.195761288366011, 8.574949368353813, 3.3299545030440054, 7.990266651876512, 9.094952690985895, 1.62032425403595, 12.492636230684097, 12.238797103205036, 11.190306371258153, 2.2148707509040833, 1.1757335235034267, 0.27562047805516954, 0.5355177062653727, 1.2464999455598094, 0.3312873377675011, 1.1305100663054375, 0.7671432257179291, 0.4136063657220333, 0.14171252237452617, 6.992737804689716, 24.7026833411186, 33.54354489234186, 38.922663734805205, 49.815101392807506, 33.26775520078598, 13.52180144479198, 35.892585708249, 40.754877367327296, 39.87085750026088, 46.732098825516246, 52.294839505226385, 26.665096129140547, 14.285484956156823, 30.722786111216394, 29.90107309433722, 34.22023219446982, 28.002169362960327, 25.21763170919111, 35.520093902464836, 24.059224397905414, 5.282909475987958, 46.32390560642366, 70.41418537016838, 69.435177464639, 61.77096812955795, 19.80589835874496, 2.940679365588773, 17.464839566138483, 74.18526188019784, 60.45252615405668, 61.712709165388546, 67.60373653904085, 62.988707173255186, 52.58360831968246, 52.291823202563876, 58.12521526890417, 68.41359615325928, 59.62845579270394, 43.709073220529866, 72.56307155855241, 66.02430005227366, 68.55701369623985, 62.19252486382762, 65.12893669066891, 38.58447305617794, 25.630825950253396, 56.80197623468215, 39.26252534312587, 50.91678142547608, 55.149803315439534, 39.931077649516446, 97.82178617292836, 60.277729649697584, 43.23054405950731, 57.21844565483832, 70.1183209880706, 5.807341154544584, 0.6594958600978698, 0.2168303851278559, 0.2156987047243503, 0.07788671135541894, 0.20312426010927848, 0.3943781104058989, 0.1934606125277858, 0.11959318146710435, 0.20331467892373764, 0.16565059431858603, 0.4003278556610308, 0.25216790667224315, 0.20488353506211313], [0.04862237098296324, 0.07073516566907206, 0.021909654981667, 0.08648397220719246, 0.08324434725387443, 0.07297946620852717, 0.06617049972016005, 0.08268904842195973, 0.20369617538827084, 0.09817913174629213, 0.06305865440217238, 0.046446834495591546, 0.030609345619356444, 0.10507842000093191, 0.043616396254829826, 0.36311305097995267, 0.17098083491286925, 0.1736546962732269, 0.5308980122208595, 36.538223528092914, 65.53908717247748, 43.527906787010934, 58.309892223727324, 75.77399438427341, 76.62863177637901, 72.67404325546758, 53.03493584356001, 33.556535782352576, 13.935091783923488, 46.276574365554325, 28.099789311808927, 64.67314943190544, 93.46977526141752, 46.66831716414421, 76.14786686435824, 64.24911768205705, 72.78910990684264, 14.193652464497475, 26.62281886223824, 53.822410491205034, 88.1481622880505, 77.122968089196, 40.38909281453779, 59.508011571822635, 46.29615875982469, 29.52197993955305, 59.83069319878856, 24.28867913061573, 1.2708252596278347, 4.04446350470666, 50.24503630976523, 55.36140734149564, 52.86507368087769, 20.958426037142356, 14.214420433967346, 29.51308008163206, 23.690299987792972, 28.721832113881266, 26.683852903304565, 30.924958798193167, 28.251330083416356, 31.01350042127794, 23.797602307411935, 16.001808239567666, 27.94886435231855, 28.591850649925973, 22.562704855395904, 12.550270557403566, 15.28524612226794, 16.400948628302544, 15.209291385066125, 19.86577530061045, 8.98898397722552, 2.395818267137774, 0.3609860538234634, 0.17827826672263686, 0.016694363965202245, 0.3030749548587107, 0.4035793166727789, 0.7933561804313815, 2.137336033967234, 1.2699085281741236, 10.607420590616043, 10.903619354771031, 10.78398314214522, 8.348627628818635, 7.194663872641902, 10.366739053880016, 10.270011444245617, 7.97887755978492, 1.1587023470670947, 1.5585935019677686, 3.0277755952650502, 6.4918614299066615, 3.75772598770357, 1.3464222031254924, 0.6936191935693065, 0.19955908609253747, 0.2687077296357001, 0.061482949437753814, 0.38175632155710654, 0.009757045190781355, 0.24876981643178772, 0.11621955241407118, 0.30846772354937374, 2.677745242272654, 7.4228090240109355, 15.664045099289188, 26.70252338532479, 32.29833552914281, 38.44833935460737, 17.41156985682826, 17.224739520780503, 39.80146292717227, 35.608590418292636, 37.47479923309819, 46.797712233758745, 40.192491854390795, 18.85435292797704, 14.145832888541685, 16.54981336285991, 22.21936018236222, 23.949513743000647, 24.094390407685314, 17.380873387859715, 21.57593261811041, 17.36082419272392, 6.724519758455216, 36.09372877305554, 44.2827747714135, 56.50238952329082, 45.36405063444569, 8.872211094825499, 3.774816735136894, 29.602890591467585, 52.36655219908684, 43.99404518065914, 59.798682735812285, 60.76317787170411, 60.31008528124902, 39.79867412197975, 53.820782707583525, 55.5495830505125, 57.44468012163716, 60.138720850790705, 65.05070109521189, 60.4089839227738, 65.23596248319073, 53.49042107982021, 66.53258431342341, 15.333548149754925, 27.083391412611935, 32.26247133747224, 26.883264241680024, 42.81776166731312, 32.293344313098544, 48.40893560840238, 69.54600795622795, 27.97514815484324, 37.141990046347345, 54.6592285556178, 15.178443904845947, 0.8654153911817459, 0.1488288050337184, 0.08767871696862482, 0.025072828190581455, 0.13781645966152992, 0.02823397318171638, 0.07997428562732474, 0.05244995692684766, 0.06515592351675996, 0.08760115056629143, 0.07432806440779278, 0.05520353739660594, 0.06422108174451897, 0.05938700565527524, 0.047086743908303405, 0.1682782299335926, 0.05391990728375893, 0.029773214276159005, 0.06576293328356358, 0.04812690744837446, 0.06963644236806901, 0.061510651177095796, 0.1516279370914544, 0.07107835773739123, 0.05344258854165674, 0.04175062358920132, 0.09208968269728846, 0.2311838850859673, 0.05776296054283458, 0.16741130951671832, 0.13830384479895716, 0.2882258419788653, 0.8700271179118465, 40.98220225303404, 78.13429632494527, 44.09185732564619, 56.426636788152884, 60.94270083212084, 48.556918790263516, 54.68062508490778, 25.103841789307136, 31.502321881632653, 20.60257096444407, 36.28549345078007, 34.89762944559897, 64.15233319805515, 75.6929817507344, 58.67580621473251, 83.70523083594539, 61.44617626743933, 73.55689817859282, 18.37577473732733, 27.424461110945675, 57.558456313225534, 76.59304018943541, 54.63649842046923, 50.867543912703, 65.52433906062957, 52.371663047421364, 35.38186565522225, 60.34053464089671, 26.237510711916034, 0.8180753862665546, 10.853153159541469, 58.97225895235616, 56.6259402613486, 64.43248064287248, 37.52104005505962, 17.318801879882812, 28.366310442647627, 23.288608097261, 28.674059606367543, 28.115543511606035, 28.396767647035663, 30.05772471427918, 27.72566580003308, 22.32010429905307, 17.05743670463562, 32.48912157550935, 33.2617304402013, 29.823349368187692, 18.3883890798015, 13.989555854951183, 20.85148653676433, 19.457701713808124, 28.37229794071567, 21.764165201494773, 7.462088619509052, 1.692328429029834, 0.10959295315607902, 0.14790119513148262, 0.2878201218141664, 0.19669074565172198, 0.8459057058057479, 2.169209213987474, 4.654435948018105, 7.222309227912658, 9.510590568665537, 11.501265014371565, 10.092988994813735, 9.150602298398173, 11.125923606657214, 10.608942470242901, 11.604362553165807, 5.492513093256182, 1.0138166731884404, 4.120658241933392, 8.377754169125712, 6.068155236782567, 2.1493203457324737, 0.43437025960414644, 0.13884458029943128, 0.3804202642171614, 0.03301668882129654, 0.39604517901616715, 0.014854990689444446, 0.30083656851803103, 0.5575551753563266, 2.368643351139561, 4.8090783338392935, 13.722607185763698, 27.991869218887825, 35.22866572103193, 33.87471060599051, 24.530308900340913, 14.038527627145092, 27.754136323928837, 39.31428493991975, 35.76975276393276, 37.31518622367613, 43.06341971120527, 21.67469789904933, 19.297778837142452, 18.205690960730276, 21.721040702635243, 19.478925658810525, 22.216385064586518, 22.592259914644305, 17.734612341850035, 18.107463044504968, 19.589285465978808, 15.360795874749462, 62.79355356770178, 53.746026254469356, 60.1530884927319, 42.321715201101, 17.617929673963978, 11.492717189173545, 24.168701671784927, 64.76982408954252, 43.9748098773341, 64.84543169698408, 62.096697438147764, 63.97169628450948, 45.79966906578311, 59.732453515452725, 58.394835072179, 61.75502761717766, 65.05439596791422, 68.4056023628481, 63.79228707282775, 68.38236624194731, 60.354243324648955, 67.93936590994558, 23.88812472743373, 29.653410719287013, 24.564078546339466, 27.243175045136486, 28.601756595796157, 37.04509181361045, 47.31866967293524, 72.45843056709536, 38.65997868199503, 40.028795657619355, 64.1364436764871, 14.915552927601723, 0.8364265628399388, 0.09900598576472652, 0.14131060200593165, 0.02572941725262471, 0.11266018534379621, 0.06083636739922147, 0.0266193566964038, 0.026152383971719012, 0.06640016521898008, 0.004126207016768956, 0.10605152786499071, 0.09900351896161035, 0.07695966069736788, 0.051590210923384276, 0.19141969301046866, 0.20410370352047108, 0.15848727386084296, 0.17958250077020738, 0.18921502986021582, 0.14498276786217767, 0.15340340714300835, 0.24025979001195202, 0.47286096840135516, 0.242010745249929, 0.16969028319562637, 0.2043122326534602, 0.2093052260217167, 0.6123112178137226, 0.1661075964089363, 0.6289391255667133, 0.2757543289372998, 0.5086964164530078, 1.5574663108394993, 67.62308951347106, 84.41254400437879, 66.4532426095778, 78.79761618952598, 95.32388748661165, 89.07253157707953, 98.42590962686847, 73.48638180763491, 41.78180879162204, 21.236853522639123, 67.81108087108981, 36.11077147145426, 82.50302437813052, 103.94277034267303, 62.92225830016598, 89.72454717082363, 73.88385911141673, 83.49377585995583, 18.60695727409855, 32.38649864350596, 66.2688127640755, 98.2135368162586, 85.95754992577338, 53.4957633479949, 70.51797128492787, 52.787018514448604, 37.947660569221746, 70.5092087099629, 30.130282678911765, 3.1471585698666114, 6.718025294042404, 61.1691588740195, 59.645757367534024, 61.03763787977157, 25.21246987004434, 15.461080093537609, 36.009189928731615, 29.001363746581543, 36.46234135473929, 32.675136058561264, 39.77211967591317, 36.01196304444344, 39.447778886364354, 35.81936290187221, 20.50672588809844, 36.214914321899414, 41.01363220522481, 32.39421786800508, 16.722217221413892, 23.71845672207494, 26.597272465305945, 30.17691573789043, 36.25438513294343, 35.10564842531758, 18.282449783817416, 2.823128383005819, 0.8774951268588344, 0.22755059053099927, 0.547034336674598, 0.6301730174210765, 1.486556722271827, 3.455168816351122, 7.011513700408321, 11.92721970619694, 15.311404408947116, 21.14196158224537, 14.677319930445764, 13.214274875579342, 13.531252395722175, 18.26202992470034, 18.88750283948837, 8.590811433330659, 4.906326638114068, 9.496099372063915, 17.071820036057506, 9.352240562438965, 5.277702039287937, 0.6795951267403941, 0.26609870995725354, 1.0109163255941485, 0.21072325476955986, 0.5306038344579359, 0.29298263511830763, 0.5435349696105527, 0.8820740037387418, 2.829316657397055, 6.731091689678931, 29.118854422723096, 35.46613385600429, 43.49441366810953, 49.14224232396772, 49.12530160719349, 23.929854823697, 24.73052236341661, 45.798908125969675, 36.77928847651328, 43.77778922357867, 54.29502079563757, 47.336383096633426, 25.853353777239402, 17.965841947063325, 21.470126682712188, 29.96099710464478, 35.74981535634687, 32.293369808504664, 23.099243910081928, 31.181489652202977, 27.223308240213704, 9.475643231022744, 43.04753411200739, 54.40409014301916, 73.63724400920253, 53.70356267498386, 12.800243208485266, 6.547431609322948, 35.29724836349487, 67.7753794577814, 52.869957031742224, 67.85001431742023, 63.67813041133266, 64.33549219562163, 50.77984756039035, 64.84196432175176, 62.55666594351492, 64.19928789138794, 73.26963163191273, 75.12883509359052, 66.69740230806413, 66.37801939441313, 64.47611701103949, 78.2899751970845, 23.505107241292155, 38.5353571368802, 46.395508473919286, 37.451986728175996, 63.41825377556586, 49.754186984031435, 65.94578204616424, 87.68105506896974, 47.0922940008102, 56.73494685080744, 78.41007817176082, 32.588969430615826, 1.7671634521215194, 0.34334163932550343, 0.6295885842654013, 0.27565246988688746, 0.3239491960454372, 0.19860040366409287, 0.1301174445618545, 0.3065781830058944, 0.23230393627478232, 0.22038697895984496, 0.23920186855379613, 0.3310747636902717, 0.23742290514130748, 0.1527856951279025], [0.08256758518156507, 0.04757598680894702, 0.044734114705915415, 0.012791231218274805, 0.006347150014217703, 0.05574259899496552, 0.051180848010605386, 0.01670407796008212, 0.20921115042461505, 0.15247686976386657, 0.10041590164145155, 0.021549220189392086, 0.04999572531350198, 0.12849000567990926, 0.03921961847452387, 0.02681072162944944, 0.14097736908062813, 0.23633781820535663, 0.6928167624338981, 9.588988942484702, 80.96035618935862, 50.56405444299021, 39.433599518191436, 83.79790075363653, 99.18736719316053, 68.82895162028652, 57.34029408424132, 44.08829189115956, 20.04110916968315, 31.300929746320172, 39.524225881022794, 21.319897943927398, 60.38565366498886, 58.55757421062839, 67.60022209536645, 49.34516614483249, 68.64809897638136, 37.004730624537316, 15.190386541428106, 45.31801377573321, 58.092455633224986, 82.87313138284992, 58.66068940008841, 54.8745588333376, 52.46858089200912, 41.249578460570305, 61.32620665334887, 12.95823137606344, 0.37577476833135853, 33.39261993285149, 56.96833572080059, 47.44003172843687, 33.9713538846662, 13.24835733059914, 28.099010721329723, 27.103593580184448, 27.44125670002353, 29.345565457497877, 29.576840169968147, 33.78391165887156, 24.524586162259503, 25.749703184250865, 21.91310348049287, 16.299838750593125, 16.93553336205021, 27.4273048293206, 19.873747517985684, 13.435014101766772, 19.12021706181188, 12.992168703386861, 16.815997169863795, 23.363982323677313, 10.529733146390608, 4.350380676407968, 2.8562684885917173, 1.136776297803848, 0.3034574165940285, 0.5007038517825065, 0.0490413751122692, 0.08779643403906977, 1.0512094247725703, 2.280625609620925, 10.278540638185317, 12.690737497422004, 11.563392416123422, 7.335348994501176, 6.676658017020072, 17.268211149400283, 19.113370564676103, 16.592879026166855, 5.1992595388043314, 0.2119133417164126, 2.6754082450943613, 2.4289191490219486, 3.160990808279284, 1.3606459431109892, 0.36587274483134674, 0.1313606826888938, 0.28405443194412416, 0.05592072209823997, 0.03622786509954641, 0.46712977270926204, 0.18361694960584565, 0.21091682986626703, 0.4688116114947104, 1.6619186608060714, 10.665113752888097, 13.591119531662235, 23.390081774803903, 36.14082859408471, 36.37412332719372, 30.1788043591284, 15.450901542940448, 34.38140630722046, 36.73621692965108, 37.134557154870805, 37.99839250503048, 47.68821970109017, 29.105767434643163, 23.98749601456427, 17.7201093781379, 16.44080677340108, 21.54108432031447, 23.267921516972205, 26.697630228534823, 22.700195697046098, 23.479976615598126, 23.442984742503015, 9.207469801748953, 32.428934766400246, 38.483271983362016, 63.346282205274036, 36.93049192428589, 2.893452802973409, 6.884080306176217, 41.5423402478618, 41.00572470695742, 31.499070236759803, 52.25781233079972, 48.74974250793458, 59.81365442276002, 57.66391315767842, 54.27158855622815, 59.83764756110407, 60.237435140917384, 58.86915553000666, 54.75554627756919, 39.959122596248505, 60.21297131815265, 52.13899197116975, 24.1569737849697, 23.883804236688924, 32.309345622216505, 23.233806702398486, 54.64000109703311, 34.27815775717459, 74.38571068548387, 43.062093950087025, 15.699844571851916, 36.631128787994385, 23.59318014114134, 0.9320477576505755, 0.13119707695178448, 0.0377548583632996, 0.0674513451034023, 0.1401272259892956, 0.057020199995848446, 0.16173225376875172, 0.23931927918907137, 0.17758523294281575, 0.08174454628099358, 0.10366520994613249, 0.02043461780093851, 0.11366677125014606, 0.07243569699987289, 0.06471628097877388, 0.08613570863681455, 0.039403916246468024, 0.07094868203444828, 0.0143349951043004, 0.1486176558800282, 0.013003743050860302, 0.08300833088616211, 0.12892657620531897, 0.11399129375575051, 0.041927919317517555, 0.0906155992960257, 0.040822492747177044, 0.05016770056118408, 0.2792544620892694, 0.06328696009492682, 0.19202410573920897, 0.151201946240279, 0.35212226332195345, 0.609048479987729, 14.28214309677001, 93.81860733032228, 56.437933214249156, 44.728418780911355, 97.68378934552594, 92.32981681823732, 84.4611970839962, 53.31901742566017, 34.729147957217315, 25.71217786881232, 28.26497797043093, 40.15035775399978, 31.30254968520134, 59.22084700676703, 64.86887178113385, 73.50284007287794, 54.63682397719353, 70.37976264953613, 41.079653539965236, 18.120679470800585, 45.18679088161838, 64.99253626792662, 71.04906020625945, 61.30419038957166, 59.67057420361427, 52.16940995185606, 34.293141211232836, 64.85570438446538, 8.409115479838464, 3.598304193827414, 48.66931038518106, 61.16835478813418, 59.03067088896229, 52.50511384779408, 18.773126525263635, 22.278878227356945, 27.817978782038537, 27.685016316752282, 30.161718514657792, 31.28113550524558, 31.221001648133804, 26.04037238705543, 23.90461633282323, 20.84271807824412, 17.11122416680859, 14.460512880356083, 35.27484770744078, 22.648334118627734, 12.287411939713264, 20.819811436437792, 14.825261927420094, 21.038997404036984, 33.08336065661523, 26.57226931664252, 12.455414898933904, 2.9803171225132483, 0.3047550469636917, 0.3831739519392291, 0.534729432434805, 0.1574245720140396, 0.0955488378061883, 1.924258912763288, 2.9129065332874178, 11.775294542312624, 13.460110406721792, 18.581142194809456, 10.46103479400758, 8.35144781297253, 21.59387746164876, 20.648407782277754, 21.513386503342662, 8.951877374802867, 1.2496219070688372, 1.6108611682730338, 3.860925262974155, 5.016775679203772, 2.4517721033865407, 0.39694995949825934, 0.27812083582243613, 0.14231207810582655, 0.2896255152600427, 0.40124587414245455, 0.40302338198788706, 0.0037986785736716087, 0.20813119627775686, 0.9494100066442644, 4.733050542493021, 17.907173095210908, 24.653324234870173, 36.631728910630756, 36.58344845617972, 28.437383790169996, 35.8182018803012, 26.271250940138295, 39.657362891781716, 36.35557836101901, 35.93401770437918, 42.16675020033314, 32.32349753379822, 18.994748284739835, 23.364376521879628, 17.940309278426632, 20.497539697154878, 19.111134813677882, 19.45972565681704, 24.02416233093508, 21.888347441150298, 20.736313981394616, 25.68998705956244, 17.52052741665994, 58.627290418071134, 49.68473749776041, 57.716751406269694, 32.46656010227819, 12.123452944140281, 11.899245362127981, 31.36902601488175, 53.250246509428955, 37.83761847403742, 60.71376777464344, 47.57278434691891, 64.61033659596598, 62.87307570057531, 60.4373348143793, 61.24246405016992, 66.38681334833946, 65.17029808413598, 59.99575830275013, 44.83163202962568, 67.52354760323801, 52.16131810219058, 36.07649780088855, 16.439336865179, 33.224507147266024, 22.802218506413123, 48.99049366674116, 43.92933391755627, 68.87554153319329, 54.98517359456709, 22.607294359514793, 48.48333512583087, 28.02420327740331, 1.9037342528181693, 0.22721960990419313, 0.11717540797807517, 0.03211887973931528, 0.2384257295559491, 0.0508278270342177, 0.09842296987171135, 0.1556464666200261, 0.06375451121599444, 0.07755734717413303, 0.06976968804073912, 0.10050056967884304, 0.08111783273277745, 0.07215914692008688, 0.06841263223078943, 0.1587446947251597, 0.14900008697182904, 0.23137102504411053, 0.205349485059419, 0.2431220783581657, 0.17982787873235442, 0.212648632906137, 0.2859591410285042, 0.37681422707053924, 0.3065464363223122, 0.22147952759217834, 0.15483790678122353, 0.1851200447568009, 0.38439840559036503, 0.175667439076689, 0.4687729393762927, 0.3204985521733761, 0.521962546533154, 1.0925105117982434, 25.208608296609697, 111.03752997613724, 69.75629406590616, 54.684272889168035, 96.33872232129498, 109.3625759309338, 81.83701376761161, 79.79347459731564, 54.952484561551, 27.82206589175809, 49.628710362219046, 53.35323226067328, 29.655252272082915, 72.3856549109182, 71.73680074753301, 83.35041323015767, 59.682992427579826, 79.65166522610573, 43.06953076393374, 19.57318021405128, 56.01019874695809, 72.91241353557956, 91.59432534248599, 67.39814158408873, 66.94165614343459, 58.9671951724637, 48.92955180137388, 72.11993002122449, 16.232987834561257, 1.4551743288193981, 40.42908137844455, 65.32696539355864, 51.36744214642433, 40.41274862904703, 13.579269070779125, 34.41755487072852, 32.7150010678076, 34.75168981859761, 34.99326859751056, 42.6061027280746, 43.56579688287551, 34.71437631114837, 35.885984359248994, 36.27355375597554, 28.008456922346546, 21.346936802710257, 39.70869495022682, 32.76784519995413, 17.50174710827489, 31.732717983184326, 20.632229966502038, 35.215835648198286, 40.77539136332851, 44.939661948911606, 19.107385027793146, 10.067227848114507, 2.5559267209422205, 0.6764648914817841, 0.5316721287465865, 0.40535112482405483, 0.14687281402368701, 2.091077316191889, 3.841984872856448, 11.775208250168832, 17.705184759632235, 28.933004679218417, 15.760577571007515, 12.230729768353125, 26.668124198913578, 28.764703619864683, 30.18171475779626, 15.94869052210162, 8.385589103544913, 7.621260852582994, 8.943995371941599, 9.574783098313118, 4.239757089845596, 1.047374572484724, 0.39713470926207883, 0.5770530936218078, 0.2887949227325378, 0.577469171295243, 0.4532975036530726, 0.4268533436040725, 0.4242066323997513, 0.7923665786943128, 8.901489626976753, 27.102169759811897, 43.71838884968912, 38.50935182263775, 59.2118687014426, 48.816018796736195, 40.88819480711415, 21.77517725575355, 39.07446338284401, 40.050882524059666, 39.224764685476984, 46.628536485856586, 51.111636930896395, 41.009643154759566, 32.47783103296834, 23.844329503274736, 23.22732694687382, 27.619289159774784, 30.335095121014504, 32.95975500537504, 29.198811938685758, 31.397400440708285, 35.383250251893074, 13.322647021662805, 37.81570811425486, 46.52120082609115, 76.5847953673332, 44.62285995483399, 6.8246843449531065, 9.104945909592415, 49.74047830027919, 55.226226775876945, 41.33163444457516, 58.85494086050219, 54.0558111283087, 69.33648278636318, 68.5960255899737, 65.12892100118822, 69.11187218081567, 70.62003135681152, 73.40033285079464, 62.31150211826448, 51.14964077549597, 67.39638436225154, 61.86773692407916, 34.70774358318698, 35.796840652342766, 51.58014835849885, 34.18296183309248, 81.0145555003997, 50.15534347103488, 95.56363059628396, 59.60595707739554, 32.833707678702574, 61.503195762634284, 54.61960477213706, 3.4187236235987757, 0.40798686564930026, 0.3111471007427862, 0.3009861395243676, 0.2912163734436035, 0.1897109798606365, 0.2483232791024831, 0.3956697040027188, 0.27195845520304096, 0.14710017359785496, 0.296090132887325, 0.12944471211202685, 0.15220677780528225, 0.2270841042721464, 0.2006592343170797], [0.06433094641374004, 0.06488703431621676, 0.05844872797869387, 0.04081938626064409, 0.03518479425580271, 0.03841441410082964, 0.021049809386773456, 0.03549237089652208, 0.05376681227297072, 0.1327149116344029, 0.07956370080430662, 0.05314802390433127, 0.03836277594429351, 0.1359417352585062, 0.1558873093416614, 0.06917484375017305, 0.08530184491387299, 0.2760191195674481, 0.13258956432823213, 1.1235684516929811, 61.870761071482015, 73.04643307962726, 45.055669969128026, 44.282374689655924, 76.80145925091159, 24.32893833806438, 28.959006071090702, 57.191298930875725, 28.151113525513683, 24.59954853980772, 47.181818177623136, 25.12912734862297, 51.52913008966754, 51.57713597820651, 72.75617768687587, 73.6673991910873, 69.88389661235195, 71.0729003721668, 36.38747899763046, 36.693063013015255, 62.44547459387011, 47.39566187704764, 65.13551058307772, 57.76663611012121, 51.48154781710718, 63.278252617005386, 43.56606360404722, 2.5635449444094016, 9.302466665544818, 45.48710323149159, 37.43530881020331, 32.791216642625876, 16.518846250349476, 21.18899864535178, 32.14028558423443, 30.246506429487663, 29.519071502070275, 35.79475787378127, 35.45877548956102, 34.9608737422574, 24.523480053870912, 29.818416987696004, 15.833823911605345, 8.134036717876311, 12.899300706002021, 19.36180172428008, 11.85717401965972, 16.701575748382076, 14.306390208582725, 13.139433110913924, 20.917252917443555, 22.222413747541367, 14.871827325513287, 4.692656993865967, 1.1362710474960267, 0.41426700930441585, 0.6897968438363845, 0.3624982807424761, 0.5890948926248859, 0.4907948109171083, 0.7401780952369014, 1.6660489165975203, 5.58754918075377, 6.27815991640091, 5.924317019601022, 5.210463298905281, 8.138719537565786, 26.76436543464661, 29.18703502224338, 17.98926438054731, 5.956588810490024, 1.8825453639991823, 0.9852806947404339, 2.151204554304, 1.5073302075747521, 1.7837371821365051, 1.5138989518727026, 0.0856423786570949, 0.11560619177837526, 0.19454789047520007, 1.0023336280738155, 0.1847066177475837, 0.2704057788416263, 0.3150499203512746, 0.9224488598204429, 4.259106141905631, 4.6939665752072495, 12.879743768322854, 19.245568167778757, 27.7595393888412, 31.37966936634433, 18.101930541376916, 19.195308877575783, 24.515841237960327, 40.98512834118259, 35.0083658003038, 35.06336527486002, 34.81377309368503, 36.95588927115164, 24.0245565291374, 30.369343296174083, 20.03058741169591, 15.13457807802385, 19.52397800260975, 21.222054419978974, 20.60789950432316, 19.88842502717049, 21.40326007719963, 26.754520285514097, 10.8492454982573, 33.31043451063095, 46.31689633092573, 74.07010893667899, 17.660663896991363, 2.9616054556062146, 3.644380521389746, 43.52502776730446, 54.101938201535134, 42.3553652148093, 46.62216263432657, 55.503369685142275, 63.28170038038685, 59.86031886070006, 57.69684537764519, 58.858800472751746, 59.82294259532806, 44.19091678434803, 59.43176854041315, 56.95347778258785, 38.50116191371795, 13.830374306248082, 33.98273660290626, 16.755157286121, 36.19340012150426, 33.67819201561713, 47.42605240114274, 66.54275109691005, 28.198538903267156, 35.58233799472932, 28.561277735617857, 7.238239444071247, 0.5851746674987578, 0.08801293048647144, 0.14510312027508213, 0.035684210804080775, 0.1665561715321195, 0.13594772606607408, 0.2709457788976931, 0.07369459396408451, 0.03693228677636193, 0.044912279944025704, 0.009135455813168759, 0.12855056493032363, 0.136524329803163, 0.08282659184788504, 0.006215082680536134, 0.1996749951954811, 0.05156252833624041, 0.018721673930544528, 0.05199415759453851, 0.06409781819750225, 0.03958667035124475, 0.05834486560835954, 0.06157349336952452, 0.027957227749509678, 0.15785549647144734, 0.03836114417701479, 0.009951402654781217, 0.03953608556560451, 0.1386332166411223, 0.09518813296792009, 0.19132394734169209, 0.113018951979616, 0.3156716466671036, 0.061793429551706205, 1.637320251714799, 71.45654739872103, 84.55464363098145, 48.135926877298665, 61.19016708866243, 89.0145746354134, 34.345273433193086, 44.06674631180302, 43.78837962304392, 34.55011137070195, 27.156492625513387, 41.49607589167934, 37.83370787097562, 57.68466641826015, 59.45790329287129, 75.85688975549515, 78.53486445642288, 72.62081669222924, 70.51120127401045, 39.76794627404983, 40.098445184769176, 66.79710111310406, 53.61104572972944, 61.90495629464427, 62.75663621963994, 51.935118936723285, 60.04905154628139, 42.19995306384179, 4.11079911935714, 20.278440021699478, 41.84682992196853, 44.95763424904116, 51.307088636582904, 24.150178278646163, 18.07258140656256, 30.44506661353573, 28.873374846673784, 28.719617935918993, 35.82801172810216, 35.15427012597361, 34.74166816280734, 25.41792165848517, 25.685474372679188, 14.800914795167985, 12.550957952776264, 15.357507947952518, 25.05039949570933, 19.695691524013398, 11.636995692406932, 15.410300108694262, 14.792461106854102, 29.42871186041063, 31.133338635967625, 31.613719155711514, 14.367909642957873, 0.8833751887563737, 0.43905638879345316, 0.5582335615350354, 0.4911628089124157, 0.5618885976652945, 0.35633675814155613, 0.34607994400205155, 3.325373910127148, 11.079961272978014, 9.523562827417928, 9.123717392644576, 7.497587050161055, 9.985032619968539, 30.422966018799816, 32.854396220176454, 22.983282958307576, 9.92424568822307, 4.189847871180504, 2.8263890983596927, 1.9310671667898855, 2.3613286210644633, 4.102586656808853, 1.8522731238795866, 0.09085363047497888, 0.4601215390909103, 0.22220459916899282, 0.9853745251893998, 0.2031021967770592, 1.159093848639919, 0.37108401197098917, 1.2445356961219542, 6.721803517110887, 7.362879130148119, 25.015957163226222, 31.741855144500736, 33.680945519478094, 31.634682263097456, 20.504105744823335, 25.641628157707956, 34.6910225191424, 43.622969350507184, 35.581514296993134, 34.4858786367601, 34.93136967382124, 21.474676632112075, 21.626472357780706, 28.952602801784394, 19.717178267817346, 16.97644760531764, 17.01634987708061, 19.621048819634225, 18.55953777990034, 18.293465760446367, 20.358266138261367, 28.547086600334417, 13.18229284978682, 56.613525959753225, 53.34111998158117, 64.43944284992834, 17.054555723744055, 10.166878604119825, 1.4993277144047523, 39.78843281345983, 58.82795495371665, 46.02815105069069, 55.21558538559945, 58.11439737196892, 70.89516209017846, 65.08465313142347, 65.19855483885735, 63.461368468499955, 64.7708752847487, 52.6354306743991, 61.90406983898532, 64.59837728931059, 47.35920736866613, 21.04339438100015, 25.962360366698235, 21.612179240872784, 25.67380532141655, 40.7969997006078, 56.83676373574042, 68.74942948741298, 37.60840692827779, 42.928097940260365, 47.60363771069435, 14.211360004640396, 0.7275890030207173, 0.08598569329948196, 0.3779854835762132, 0.28626845668881173, 0.013637301594679876, 0.19475116424502867, 0.06251531037231607, 0.029239668510854248, 0.025631045817487666, 0.037592727345444506, 0.050632294582863974, 0.06402609704603111, 0.010827085202289446, 0.09579269125336602, 0.06636697062922102, 0.2484736468402609, 0.150193651957858, 0.19891393280798392, 0.24336702731107515, 0.1442939628876986, 0.13615502945838437, 0.2329321436944508, 0.36127159011460125, 0.1625529331185164, 0.3233789201946028, 0.1520101690003949, 0.12854579986343462, 0.28630890613121374, 0.2523574061811932, 0.27019256125054053, 0.2501414662166949, 0.22812322593264042, 0.4639706712576651, 0.275138731324865, 4.406371039728965, 98.82637577672159, 91.32543902243339, 69.74120078548309, 61.85560895550636, 96.07070676742062, 35.51703053136026, 38.956129397115404, 70.92149688351539, 39.04149586154569, 43.15298703409011, 61.25202678865003, 34.54055255459201, 64.26306170801963, 67.34355003603044, 85.56813701506584, 84.42441309652021, 81.10310692940989, 76.10353623667072, 45.51067275385703, 44.79456955386747, 74.88485582413213, 56.27233466794414, 72.6493715470837, 66.9808876898981, 61.06213308149769, 73.6288893607355, 53.293608311683904, 3.3624621264396177, 11.315455475161153, 49.02969383424329, 44.432291600012014, 36.94219627688008, 17.140130073793475, 24.90136904101218, 39.927904452047045, 37.88858575205649, 36.924969227083274, 46.945005078469556, 45.272353464557284, 46.46931179108159, 34.11604619795276, 39.211373713708696, 29.33151944991081, 19.7195081556997, 23.860373958464592, 29.28389991483381, 19.38545165523406, 24.919309962180353, 22.1462825036818, 24.676124972681848, 40.71654404363325, 38.4311201495509, 41.68996257166709, 22.283214407582438, 8.61439174221408, 3.034220539754437, 1.4161762859552138, 1.2227718123505193, 0.7725977104517722, 0.7163528833658465, 0.6995975598692895, 2.6991510871917974, 10.654071300260483, 15.326388843597906, 10.966540055890238, 10.783029025600804, 16.23872528153081, 37.57697305371685, 34.155136539090066, 30.26544559386469, 17.53237689695051, 14.476485752290296, 13.228997492021131, 6.102078345514113, 8.248094339524547, 7.521686582796036, 2.4402695077080883, 0.44067206822576066, 0.5312407906016996, 0.5437029573705889, 1.755771540826367, 0.4206533021023197, 1.9219255928070316, 0.7557137454709699, 1.0461889135260736, 10.616355749868578, 18.675190825616163, 45.14472346152029, 39.94111107241723, 44.46809891731509, 42.54999322275962, 21.145527016732004, 25.93567648241597, 30.57110021191259, 44.869098509511645, 39.381757551623934, 41.11628847737467, 42.42866254621937, 48.605179632863695, 36.40086604702857, 39.78564400826731, 26.80112784908664, 20.771617274130545, 26.209342210523545, 25.178166781702352, 26.00436502887357, 25.64809810730719, 28.696150395178027, 36.744355847758634, 13.031364948518815, 41.789767280701675, 56.0121952333758, 90.35234605112385, 24.226293833025043, 5.643892067094003, 4.988391937748079, 56.501871770428075, 64.55953013512396, 52.06074853097239, 54.691278242295795, 64.37351172970187, 77.37599234427176, 71.76402199652888, 68.98263792837821, 64.83191913174045, 74.72600767689367, 58.20354892361549, 64.34988337178385, 68.45465552422309, 47.718108161803215, 22.777486001291585, 52.60929592194096, 24.071499455359675, 61.14512258960355, 56.6717613897016, 69.64515762944376, 82.88672631786716, 47.233130624217374, 55.79661000159479, 64.03972587277813, 25.106720809013616, 1.4551727353565156, 0.2857189877860008, 0.6027980605440756, 0.3104342406074847, 0.3203878065030421, 0.2188070298683259, 0.5240323935304919, 0.16875524224052507, 0.21835715239567144, 0.08197739870557863, 0.2037451743719078, 0.19993028633536833, 0.22076659084808445, 0.4291154173833709, 0.3286598094048039], [0.12718713526884395, 0.1337447023439792, 0.08075476068282321, 0.02375537912631708, 0.07340200200316406, 0.07495264823157942, 0.03877798410793466, 0.009946317746183805, 0.15460270246671093, 0.06903365374572816, 0.08212831802666187, 0.029551449059058103, 0.13832581620062553, 0.10242354229933794, 0.11278377064774114, 0.18414498336853521, 0.2538136780382164, 0.0784472119243395, 0.16340201900851342, 0.650449832600932, 22.732147324469782, 81.08741744872063, 60.91555803052841, 45.08141640693911, 72.13878877701299, 70.37037249534362, 22.32678017308635, 68.96916850920647, 32.006409206698024, 19.06235621821496, 43.60900179032357, 24.589293502992202, 39.03180760722007, 59.29818830182476, 56.20150450737246, 66.19458583093459, 68.42809323341616, 73.29308740554318, 63.893896072141594, 44.7572874253796, 62.40923581584808, 54.93476721548266, 55.46024714746783, 64.1411348312132, 46.214302816698634, 60.722181258663056, 23.253946112048244, 1.516339033842087, 35.40097936507195, 54.85341333573865, 34.92563124625914, 20.823282734040294, 17.948428584683327, 28.32209748606528, 28.71576028485452, 27.977893813963863, 35.77940179455665, 34.351333495109316, 41.5337267229634, 27.196373324240408, 26.2663479774229, 24.62303569239955, 11.632830135283932, 6.919014405819678, 8.324844337278797, 23.118494902887655, 9.17389529366647, 15.486266613006594, 16.12093944703379, 11.09860037603686, 21.580929717709942, 25.175193625111735, 19.89447920553146, 7.039040403981363, 0.9182458563197045, 0.1284457870849198, 2.092336887313474, 0.06050092814069602, 0.5206526587567022, 0.4318821898871853, 0.3777580473932528, 2.257604483635195, 2.9311592828842903, 2.515117891373173, 4.208152101885888, 5.022417518400378, 10.0418108893979, 30.042094069142497, 41.637626386457875, 15.904100037390187, 3.8148001509328044, 1.7589410610737342, 2.4117247039271943, 2.199103803403916, 3.8708755806569135, 3.7062184031932586, 0.10806095350774066, 0.14037111774086952, 0.0724876377611391, 0.8123529546203152, 0.37500996743479087, 1.1236252034864118, 0.41970755123803694, 0.1576837089153067, 1.8441386184384747, 0.4982916247700492, 2.334886943140338, 2.278246937259551, 18.145741455016598, 26.02491040383616, 28.149958387497936, 37.06512335808047, 28.8927690059908, 20.785167101890814, 31.247989516104425, 31.39191696720739, 35.392691396897845, 33.41860955761325, 30.507063596479355, 32.291077183138945, 20.964491982613843, 27.451019479382424, 19.58193886664606, 16.53125859075977, 23.915361665910293, 22.620495096329723, 25.51104460993121, 20.86815464881159, 28.807004420988022, 41.381985910477184, 17.936184906190444, 35.884466401992306, 65.950943885311, 61.09399057203724, 13.155767821496534, 1.2559836237661302, 6.4552049194612815, 84.2728291788409, 58.735485076904304, 47.73986947151923, 55.707752627711145, 59.38136608369889, 60.5811289048964, 60.1647065531823, 60.5428465720146, 51.70514252878005, 51.922626187724454, 57.41542316252186, 47.16965098534861, 30.960277780409786, 18.810834230915194, 19.697501697847922, 21.717598822809038, 47.68300687113116, 39.31908592101067, 46.981483121072095, 45.64027963146087, 37.818194896944114, 39.315595011557306, 30.398812063278694, 1.1210775014854248, 0.17421881277715007, 0.07870857048058703, 0.04732077610829184, 0.15330775340478267, 0.05773055119319789, 0.1784065098411614, 0.0176578555105915, 0.153603907674551, 0.03354418632243911, 0.05549805989909557, 0.07175272195449761, 0.01402276830988065, 0.056369147834277926, 0.05496354886300622, 0.04691562284865687, 0.029704737507047194, 0.12340710423285924, 0.06187097297140187, 0.03375513629326898, 0.024607923903292226, 0.07870877732432659, 0.020967071890951167, 0.04411229262909582, 0.05144275815015839, 0.11861120996576165, 0.004254961498982964, 0.04077241741000645, 0.0607117363852599, 0.13462015698032995, 0.147313084753771, 0.13949610743551485, 0.2283470615023567, 0.24901018417890997, 0.22890797575875638, 0.6868046882652468, 25.872759703666937, 90.64137766438147, 66.76808341856926, 48.02200163564375, 86.26978628097042, 65.32929920381116, 29.455109411670318, 56.78786354680216, 30.901995282019342, 26.760784310679284, 34.3132786596975, 34.33525177740282, 47.42740561885219, 68.33969869921285, 59.45414566224622, 74.65915479967671, 72.74733666450747, 74.46515437095397, 62.14840996649958, 51.69926289589175, 65.04726509894094, 56.0188397284477, 53.44823991098712, 67.06067654394334, 45.911542907837905, 60.88910164371614, 21.92990887549616, 6.356798045096859, 37.19302792702952, 48.85777634959067, 53.498018710843986, 27.146172869590025, 18.93598725718837, 25.258963684881888, 28.550516713050108, 30.40944757000093, 33.77262307751563, 33.52798877223846, 38.617130710232644, 27.544777854796383, 22.64299185045304, 22.07541508059348, 12.661059864105718, 10.652522944634962, 9.433830764985855, 30.617835252515732, 11.652804805386452, 12.79953424007662, 17.835515314532866, 13.691790103912355, 29.156007112995272, 32.569155577690374, 35.102738026649725, 16.792306054023005, 6.546302457009593, 0.08799976143505304, 2.8039536312703164, 0.1232206997191233, 0.24015402391312585, 0.9869193874539869, 0.3341436199843884, 3.988488585718217, 4.150627601531244, 5.253682915241488, 4.752555508767405, 4.003965768121904, 15.71869352171498, 38.404314671793294, 46.67070588757915, 18.98579743600661, 10.885385236432477, 6.4602314368371045, 3.484366204469435, 1.3974068866622065, 2.1357477191955816, 5.831824589160181, 0.13625423784457869, 0.12314492596253274, 0.14467421828979446, 0.5292255503516043, 0.7794820829745263, 1.0988185410538027, 0.5708335015562274, 0.09324365625939063, 2.7005979514891103, 0.9031525758966323, 1.4453187608911147, 16.78211377513024, 35.22166036790417, 32.93276517621933, 33.61935646303239, 34.822641572644635, 31.946585216829856, 27.807861028179047, 38.24955363427439, 33.808112682834754, 36.513065445807676, 35.2014248601852, 23.159815111467918, 16.042491062994927, 19.35889917035257, 23.580108842542096, 18.440380096435547, 13.539159893989565, 25.7727784879746, 20.818366043029293, 23.09766515608757, 19.221982955932617, 29.105375197625932, 33.43212212285688, 27.916024308050833, 62.00327050301337, 71.34580319927585, 50.65098985548943, 18.614398010315437, 4.241909000181383, 4.107126309987038, 83.05581185125536, 59.51440111283333, 55.830248248192575, 62.16220494239562, 67.58333236940446, 66.27570044609809, 67.99757388330275, 66.42191856138169, 59.48563444998957, 57.16950624219833, 63.50772303919639, 49.682729244232185, 41.66458875902238, 20.1698786212552, 22.80019848577438, 23.362682057965188, 27.1045212207302, 43.19188910145914, 47.0756592289094, 60.41186686485045, 45.10054972863967, 50.92870935317009, 40.37475655155797, 2.368238611567405, 0.36107354106441625, 0.28778806869541446, 0.08460712574061849, 0.15459222238390677, 0.04995949318512313, 0.2078101441504494, 0.0403769858061306, 0.12562815400381244, 0.05452561470109129, 0.07546879997056338, 0.11516185312141335, 0.07416451229683815, 0.050219411496073015, 0.05511703840907543, 0.02161122926120316, 0.2090535201733151, 0.26749053849808635, 0.2145710692650849, 0.11902434586156761, 0.19347499965900378, 0.29418894780739663, 0.1417818839751905, 0.22909499314283172, 0.22466755652379608, 0.21349108447470974, 0.21420867903338325, 0.18710536161257377, 0.2627524991910304, 0.2702266674849295, 0.21269020083690846, 0.34300961681912023, 0.349942252881104, 0.421004292945708, 0.29202775248596746, 0.8201349370421902, 39.92577460504348, 104.7747285904423, 80.45940676043111, 65.65517756246751, 90.81572701854091, 89.31160788382255, 34.14788799901163, 97.20768420926987, 43.437923692887836, 33.780283466462166, 61.58892308512042, 33.089620759410245, 51.25524274764523, 74.9755802462178, 67.98045665987077, 79.79283132860738, 80.3157695647209, 79.23318755242133, 73.79791213620094, 59.83550594698999, 72.05178276185067, 62.13747047608899, 63.09194003382037, 73.16286471582228, 51.61999179470924, 66.66760798423522, 30.718334221070815, 2.270001870009207, 39.13296161159393, 58.5402726357983, 39.4929135999372, 17.780804134184315, 22.375223405899543, 31.53374791145325, 35.63118719285534, 34.87470711431196, 44.37837469962336, 42.81380399580925, 54.253988881264966, 38.59354549838651, 35.45005998303814, 38.491383444878366, 24.075649323001986, 19.357128220219767, 17.019221052046746, 40.10555644189158, 15.710111375777954, 27.749635404156102, 24.59381207343071, 20.941573573697, 38.28509030803558, 39.564245823890936, 46.464844211455315, 23.46544619529478, 7.821154152193378, 0.167209905001425, 4.8027079143831815, 0.09426819160580636, 1.4169445802127163, 1.2215801472625425, 0.7602275968078644, 3.9582618205778064, 4.6811198323003715, 5.148966418158624, 6.960895023038311, 8.663072278422694, 28.270620299923806, 48.606842717816754, 48.17594682016681, 25.169580713395153, 20.787881382050056, 18.716107030068677, 16.256184731760335, 7.107674037256549, 15.776347460285312, 12.257331282861772, 0.17985852224932564, 0.2859537477695173, 0.15913420446938084, 2.404821577572054, 1.88180893899933, 1.4874412167456843, 1.0426481164270833, 0.9873477838212444, 3.6982738875573684, 0.42204249530069293, 11.124157559487129, 27.12642961932767, 44.507134345269975, 41.974326564419655, 46.0896263584014, 48.65844934217392, 39.54756790591825, 23.115947323460734, 38.83098617676766, 31.727873856021514, 38.6595432989059, 45.639859937852435, 43.23845548014487, 44.553041765766764, 35.39969282765543, 33.779177358073575, 26.380490910622385, 21.827378119191817, 30.809815660599742, 24.551436747274092, 30.38512691374748, 24.677372286396643, 38.36813080695368, 50.154821795801965, 24.801858509740523, 44.143758127766276, 83.94649582524454, 73.10823394406226, 21.055392911357266, 1.1626388132572174, 8.096692812058235, 97.90591316838419, 71.24481785681941, 62.95300968231694, 66.51445511848696, 72.171658239057, 76.67335464108375, 77.24791126866495, 72.21186253332323, 61.67604284901773, 67.23266463125906, 69.43138061031219, 52.637580133253536, 40.175249115113296, 30.78641087778153, 35.6151407764804, 33.70202825915429, 75.21438983178909, 62.15846300125123, 60.448643007586085, 66.2748061456988, 54.513386987870746, 65.6577584820409, 58.53088248160578, 4.39700000709103, 0.7199529450266593, 0.5517215077434817, 0.1628756399957403, 0.33204322140063014, 0.24480661377310756, 0.3823727465444996, 0.16756385294420106, 0.20312672691239467, 0.22457204068139677, 0.15918010845780373, 0.19971400439258546, 0.30863987882771804, 0.15611278433953563, 0.18370244501819535, 0.14576503556341897], [0.052182071301485264, 0.12610596304218616, 0.15376492403447628, 0.11283306074478935, 0.03984136777299066, 0.016079436679701173, 0.10864445203614813, 0.03651589500687776, 0.08549308344241112, 0.018955721452291456, 0.05317806604228193, 0.11474160792967004, 0.24721330963075164, 0.11917249960524422, 0.1448549690746492, 0.14565602125179383, 0.09252647538819621, 0.09520240518594943, 0.06172233659233298, 0.10144741604885749, 0.6324002495215786, 67.79741533340948, 71.31867608716412, 50.20465550884124, 45.62502161149056, 92.76913012227705, 54.79733128701487, 48.33801523331673, 59.65943859469507, 21.341086587598248, 44.860806618967366, 33.81216841359293, 41.93165509931503, 68.81745123094129, 52.42956899827527, 70.73010090858706, 69.81166224325858, 67.16332497135286, 72.38032048748386, 68.36538237910118, 56.154220334945194, 56.90393432494133, 66.7330252739691, 58.08550127090947, 46.45153560946065, 44.57697214618806, 1.9505837776007193, 12.602598897872433, 58.834058161704775, 40.24747956183649, 19.353907954308298, 21.13204190807958, 24.936097706517867, 27.785627072857274, 30.289362245990386, 35.78891354222452, 31.972923932536958, 39.34871158292217, 37.251263356977894, 28.88913885239632, 24.609107355917654, 19.343974551846905, 9.139648099099437, 7.323298983035549, 5.854490005200909, 18.109428151961296, 20.953285771031535, 8.474435690910585, 10.71987102108617, 15.300602201492557, 24.51382317850667, 28.10286052765385, 21.48332545834203, 8.210375847355012, 3.810513245482599, 0.8188401258760883, 0.7477669009277899, 0.46137136557409847, 2.3728971615914376, 0.7545123357445963, 0.622099799013907, 2.664908795587478, 2.774358367727649, 2.019382150423142, 3.1605659665599948, 2.0966130062457053, 19.672141613498813, 46.941831881000155, 47.90666826309697, 19.180380336699947, 8.843761163373149, 1.9770402869870587, 1.2820058532299534, 1.433886522727628, 2.1239972787518657, 3.3392912149429326, 0.251448335606725, 0.09926758180823057, 0.057147378252158244, 0.12258661640507561, 0.6706472197847982, 1.4470535516738894, 0.939499157811365, 0.4414388303074145, 0.9530674329688473, 0.2209316521522499, 2.8355745538588497, 1.835702580790366, 12.047242272284723, 27.83088337990546, 27.185418144349132, 31.66615143898995, 32.87028378055942, 25.331700117357318, 28.784227217397383, 28.05783367926075, 26.552098528031383, 28.3965499554911, 26.38365234098127, 34.48176407044934, 31.184217660657822, 22.677981353575184, 22.350628183734035, 16.95957160765125, 14.244599150073144, 18.257340731159335, 19.25923566664419, 28.253912964174827, 20.93855138747923, 41.198426831153135, 40.92384522961032, 11.807670766307462, 56.07991887677101, 63.50904880031463, 40.75736807238671, 9.211783428345958, 2.1229036729181967, 23.400478016945627, 65.24602728505289, 50.99871973837576, 60.13718328168316, 58.033949559734715, 67.39992234014696, 57.6205474330533, 63.81056139546057, 53.377774530841464, 59.49925291922785, 59.38258594082248, 49.795799409189534, 27.38072668352435, 18.341287297587243, 13.202130236933309, 31.57040246071354, 39.48212315959316, 100.13955393145162, 68.03365184414771, 44.88028510924309, 41.53858261723673, 37.20035099214123, 12.196730663699489, 0.29369233897136104, 0.05680162361973236, 0.5305271643784739, 0.15543294259377066, 0.24635382026674288, 0.2093367428789216, 0.3186570300209907, 0.008927515610271405, 0.08634505748388269, 0.11692197843184395, 0.0346021997111459, 0.06271314108744264, 0.1049327866865262, 0.20666043003720624, 0.030820268777108965, 0.024949790639502388, 0.01737280185484598, 0.10914473809422025, 0.1840655860160628, 0.18386972797734125, 0.07420201230073169, 0.039804752600649675, 0.04683034960180522, 0.06541729739476597, 0.0349536846812454, 0.0485913674046676, 0.08245131601729701, 0.05465214178266545, 0.11390197556465866, 0.02413783511597543, 0.03082019791397597, 0.25329641547174225, 0.15148423431861788, 0.0644458749241406, 0.05974565737790639, 0.04820243605682927, 0.7666415913451103, 72.47219024165985, 81.01505756378174, 51.156599060181655, 59.72395766165949, 91.88602416746079, 53.06985278283396, 47.728839766594675, 42.91070615091632, 28.5874262163716, 34.317942357832386, 42.127200941885675, 51.113456910656346, 71.1450719833374, 66.06666949487501, 77.26715441673034, 77.55080453811154, 67.43646314067226, 77.01721314461001, 69.32485688117244, 61.559779874740116, 56.76775355492869, 69.41755817782494, 56.3075497073512, 51.03331896566576, 36.46811116126276, 5.039852453816322, 24.49485263516826, 37.13151339561709, 46.672863191173924, 17.25408669440977, 18.356947360500214, 21.797338647227136, 25.991825211432676, 29.303743185535556, 33.65008823333248, 30.552496410185295, 35.03669315768827, 37.71740959536645, 24.152519933639038, 23.5525934157833, 18.300863350591353, 9.178941422893155, 9.596033519314183, 10.922497722410387, 25.62865491836302, 24.31228199312764, 13.045199148116573, 11.70320333973054, 17.461501629121845, 30.89550768175433, 35.214360837013494, 34.7735531099381, 17.518228907738965, 7.639106165978217, 0.2893123385165968, 0.8111643538840356, 0.6899769051421074, 2.4080435595204754, 0.6469351437784011, 1.31229427312651, 2.6021371445348187, 2.031995022008496, 3.5612880510668603, 2.5272966056100787, 7.077753707285851, 39.004531445041785, 54.274189087652395, 50.57939091036397, 23.36498841162651, 18.47305343997094, 6.045244672606069, 3.3224534603857228, 1.861990305685228, 2.4639164968844387, 4.801144359573241, 0.521662240066836, 0.20653575688840883, 0.10573088942516236, 0.024128373930110567, 0.5446077378526811, 1.4984060799883259, 1.1958885000598047, 0.14963764066417373, 1.2147828023279867, 0.8612212743009291, 1.7896744248367127, 8.94864926415105, 33.46778039009341, 37.710514068603516, 32.27782937788194, 28.068757480190648, 38.43045334662161, 32.91197269193588, 37.04109099603469, 31.683201982129006, 32.78255997165557, 32.533336493276785, 27.168065578706805, 22.640395241398966, 14.724754133532125, 20.786951780319214, 18.211001849943592, 14.527929598285308, 10.858375795425909, 15.842470776650215, 18.351432508037938, 26.275496905849828, 19.034701547315045, 50.538413909173784, 42.83446311950684, 24.988282880475445, 81.7083364917386, 69.13877964019775, 43.33232172073857, 24.54043253775566, 5.275342733629289, 20.274050889476655, 70.180859258098, 53.17285030118881, 65.89643078465616, 64.91599905875422, 77.85014414018201, 66.5865953506962, 72.72220211644327, 61.54425905596826, 60.10670254307409, 64.42452215379285, 54.69723632258754, 34.366952373135476, 17.828176559940463, 16.719196996381207, 25.847038761261974, 32.601026796525524, 101.55481569228634, 65.14722670278242, 59.77845899520382, 50.19304921550136, 52.398029219719675, 21.886949116183867, 0.6090233523038127, 0.1840088342226321, 0.43431044345901865, 0.3546087395760321, 0.1839827259461726, 0.2737334502800819, 0.20660196220682514, 0.07270215004081688, 0.024764786151448087, 0.07455986729192157, 0.0399859668686986, 0.07072592664870524, 0.0348595094927136, 0.10086876685701071, 0.023776201396099022, 0.030416140160072717, 0.2252507792605508, 0.2799103252830044, 0.31910087072080184, 0.5969318495162073, 0.2660712840095643, 0.15095030167891135, 0.15842702870647754, 0.10111592214314208, 0.1922588657227255, 0.1716614427465585, 0.2377776651372833, 0.1693608500664273, 0.38095704670394626, 0.24365054113009285, 0.20265014361469977, 0.44320279371834576, 0.26471356170312055, 0.2161450122272776, 0.21199272374712655, 0.292483942523118, 2.3374788943798315, 94.23239384928058, 86.64400392963041, 72.15115993253647, 63.606327502958244, 110.73675478658369, 72.27029800415039, 69.4511728902017, 81.2564088452247, 33.533484012849875, 61.69410928603142, 44.19340748940745, 58.97260412093132, 79.60328671240038, 72.23337281134822, 85.11917468040221, 80.66737867170765, 74.65914695493638, 88.36130388321416, 80.55244538091844, 67.9444649911696, 66.61554244256789, 75.74125828281527, 61.44523882096814, 52.878456807905636, 55.63647139456965, 3.8835482683873948, 15.970699921731027, 60.347700811201534, 44.26267654665055, 17.199985442623017, 24.364157299841604, 29.554743497602402, 32.83229758662562, 37.98921415882726, 45.49642278302101, 37.04409160921651, 51.209460842993956, 52.14418126690773, 36.32354828619188, 37.439470444956136, 36.854193979694, 22.42939918271957, 19.8212230590082, 18.97389892608889, 32.330999066752774, 28.476332925981094, 18.66617721896018, 16.276955643007835, 27.64084258387166, 39.46404495546895, 36.749290189435406, 44.46012473875477, 22.479050505545832, 8.80360491814152, 1.098323341819548, 0.853986646379194, 1.2295557967116757, 4.172222700811202, 1.03451949454123, 1.660023910864707, 4.390185379212903, 5.0178195199658795, 6.154183601179431, 3.1030814253514816, 22.64608463933391, 54.82508597835418, 59.43380032816241, 52.63146515815489, 30.434064365202385, 28.94212418986905, 18.6162729032578, 17.026114617624593, 9.174663097627702, 12.111344587418342, 11.240059675708896, 0.45140492940141314, 0.254152717909986, 0.27539163227042845, 0.22640142800106158, 1.274213697160444, 2.4856113714556543, 2.459853166534055, 0.9214746411288939, 1.9305267377245812, 0.5082649557340531, 5.768864174042979, 26.555850275101204, 40.42166809881888, 42.35172525528939, 45.054583472590295, 39.264074679343935, 47.53375676370437, 32.61847742142216, 35.22887752902123, 33.27882412941226, 30.554292855724213, 37.01625062573341, 33.45245568983017, 48.718995048153786, 44.280036957033225, 34.42519172545403, 31.517166091549782, 25.159700262931086, 19.3621390481149, 22.269505723830193, 24.073643030658847, 33.637783758101925, 23.647477511436712, 50.4123410870952, 49.030823476852916, 16.090039014816284, 70.07232727543001, 83.49269328578826, 45.99343807466569, 19.207940870715728, 3.301666614509398, 38.72900062991727, 81.95764233989101, 59.99347156093967, 73.35102081298828, 71.09910180491786, 82.90699712691769, 70.87080417140838, 80.96845980613463, 65.58559079324046, 69.33692993656283, 76.75677560990857, 64.05718434241511, 38.81384934148481, 31.529988319643085, 21.065946048305882, 51.39777383496685, 65.38471837197581, 115.87464394107943, 76.60544272392028, 69.75747077695786, 56.52692394871866, 69.6785762233119, 33.78799484622094, 0.7749895595254437, 0.30144729381126745, 0.883441991623371, 0.3187862230885414, 0.37265406320652655, 0.375902092144374, 0.534554764388069, 0.1932285951390382, 0.1488538101435669, 0.22027693809040133, 0.248667313867519, 0.35866722825073427, 0.2013245510358003, 0.38311039728503077, 0.10184984969636125, 0.12395015331886469], [0.035999505780637264, 0.07295531911715385, 0.00866343169623325, 0.06098908319648716, 0.028997414272218466, 0.06645874030167057, 0.08468620899704196, 0.08103266673823518, 0.12444210434032064, 0.0370157367339538, 0.03681468078866601, 0.15805405113966237, 0.1267415708712032, 0.25105222218459655, 0.09852943311054861, 0.2309555142757393, 0.07934484480609817, 0.1947686004061853, 0.1399342790846863, 0.33053746026369835, 0.44574081236797, 9.655655507118473, 87.90529697172104, 65.20415990583359, 47.17667202795706, 80.13373236502372, 87.69002945192399, 39.91550976230253, 60.68027073337186, 22.514700928042014, 46.19120005638369, 35.59620749565863, 39.91048128374162, 76.17057738765594, 53.84414826670001, 67.02163327124812, 64.1463476611722, 69.50837673679476, 64.68206105693694, 56.97313277952133, 60.571746595444225, 57.762568612252515, 61.67203418670162, 50.947458282593765, 45.43891299155451, 6.782103094362444, 4.3050679852885585, 34.77993088383829, 60.064964602070475, 32.609140219226965, 39.80460474568029, 29.26477836024377, 25.910104590077555, 26.50917603123573, 36.8890481610452, 35.23305093088458, 35.18839474647276, 40.022300212614, 33.07417838804184, 23.38559654451186, 19.964838681682465, 14.819516635710194, 12.414405538189797, 9.136695534952226, 10.341922217799771, 19.226982016717237, 9.417094992053125, 7.059746105824748, 17.0298820541751, 14.910928453168562, 24.672681131670554, 29.320195567223337, 19.738653244510775, 8.572398847149266, 8.833244308348625, 0.8927557208845693, 0.8875325947038589, 2.677902137079547, 1.6476488329710501, 0.1353763930139042, 0.4507648782624353, 0.25038243151239814, 0.7313239574432374, 1.7599113573951108, 2.671828837163987, 9.399151129107322, 56.97385841800321, 48.97543961001981, 34.696466768941576, 17.831253659340646, 10.216398527545314, 2.6843247730885786, 1.1333274312557713, 1.3801276203124755, 2.0976360094162727, 5.885696382291856, 0.5672974235588505, 0.0804262545200125, 0.4664189350460807, 0.8707021945907224, 3.0896490235482497, 0.7068121469309253, 0.4351356427275366, 0.43688054587091174, 0.5519300675199879, 0.40173767194632565, 1.9358351754565395, 3.614342275165743, 9.168067632182952, 31.936492958376487, 32.15240178569671, 26.464951307542865, 34.79564389874859, 22.948240503188103, 17.805122829252674, 27.727501469273722, 28.3648552433137, 25.053286360156154, 21.22357826079092, 30.996010572679584, 35.16637456032538, 30.637211761166974, 32.90474768607847, 29.98953627001855, 32.834452929035315, 28.305558812233713, 30.05354346767549, 28.775284213404504, 31.804768000879598, 22.03665421855065, 32.16613596485507, 26.300147041197746, 24.400543166745095, 70.59257476560532, 43.88967875511416, 35.930369900118926, 4.6892415900384234, 2.425363520460744, 21.567917254663286, 30.272068515900646, 32.698776183589814, 34.8435595727736, 47.295362949371345, 60.01769219675372, 61.00834954169489, 57.88631939118909, 54.39768883489794, 50.596763087857155, 49.592487273677705, 20.741950427332235, 11.968348699231303, 19.508021800748764, 28.130656403879968, 45.639200979663485, 46.50451506337812, 59.39590630992767, 45.16275067483225, 26.480658438897905, 36.90480039965722, 6.051733743759894, 0.06398497727669536, 0.06039259564732352, 0.39482872332296065, 0.6048984284843169, 0.31271537465433924, 0.5281698811919459, 0.2271801257325757, 0.5169222395746939, 0.0917731964540097, 0.09271065824695172, 0.12650432110193277, 0.085648913387089, 0.026037692948574984, 0.02358157867415538, 0.04570996516474313, 0.07365796730042466, 0.0742972293688405, 0.11059319585441582, 0.03647162661617322, 0.09010716206243924, 0.060999310470276305, 0.03492961802910413, 0.04414867031418028, 0.11117471787597864, 0.20390822852571167, 0.10469451802031648, 0.036073203438953046, 0.11696985126623224, 0.037634785572487506, 0.14979102678837317, 0.05493786959578434, 0.12503420603611778, 0.23711643932807833, 0.135988803700574, 0.20269091481402998, 0.1877425475827148, 0.7637297217884372, 13.020027337535737, 94.7315860563709, 72.76809384745937, 55.53892204838415, 90.72599103373867, 74.7573709487915, 45.707681640501946, 47.63752698898316, 35.55539131164551, 39.92374281729422, 35.900528507847945, 53.40869457490983, 75.09814646936233, 68.98375188150715, 72.75121196623772, 71.33729950074228, 67.66823599415441, 72.64212300700527, 63.035344154604026, 63.87565312847015, 60.904065485923525, 66.9019696020311, 50.67399847892023, 41.49504430832402, 3.9221990589172613, 16.425878232525243, 26.505549800011423, 50.97019626248268, 40.442641012130245, 30.059256399831465, 30.651928494053504, 20.941351959782263, 25.661300805307206, 33.16007045007522, 35.84871399787165, 34.26957953360773, 39.21816333647698, 33.87635015672253, 25.682720868818222, 18.52011992085365, 11.914524955134238, 12.015444597890301, 10.274225050403226, 16.194165195188216, 25.986088745055664, 15.037266035233776, 9.960439358988117, 15.376175488195113, 18.250837441413633, 32.8888052125131, 34.03250363565261, 35.00412179577735, 14.80862617492676, 9.897025419819741, 0.4517540509902662, 2.511407574338298, 3.3606034132742115, 1.6860854866043216, 0.1341517248581494, 0.48657195041737256, 0.8406155928969384, 0.5947142394800341, 4.864773538804823, 1.8532468522748642, 20.774058949562814, 64.27256168857699, 52.97986184397052, 41.094738975647964, 21.033411948911606, 20.367420950243552, 9.511843765935591, 4.1422097048451825, 0.5802881909954933, 2.7016778290271763, 5.335347642821651, 0.7026999708144896, 0.38259350244076024, 0.06996229786666171, 1.0956104099750519, 5.596989345165992, 1.0924346384502228, 0.6606538173171782, 0.2236729905369782, 0.3612139190156614, 1.2721338603765735, 2.357066965872242, 6.804680747370567, 30.201281501400857, 41.504144207123794, 39.21920668694281, 29.237062892606183, 38.395842352221095, 29.575235920567668, 30.911599205386256, 31.473719958336126, 29.116042083309544, 29.1041043496901, 28.282889473822813, 29.42237134902708, 23.073295470206972, 15.893459627705237, 20.151720008542462, 24.95944561496858, 19.240308269377678, 19.008658970555953, 22.75994516188099, 21.383879646178215, 25.13193576566635, 22.989486186735093, 31.87293879447445, 28.129462042162498, 41.3959534706608, 87.00778022889169, 46.41418287830968, 43.680086904956454, 15.486684345429945, 6.55743561444744, 15.099896480960233, 28.117049701752205, 30.752388238906864, 35.28557538986206, 51.627369773003366, 67.61199705062374, 68.06663897729689, 67.22779304750505, 58.64769458770753, 56.245819445579286, 52.06151339315599, 30.703435097971273, 17.256204774302823, 27.020996309095814, 20.824322162135957, 57.6095098833884, 58.45870694806499, 65.15835446696128, 50.45671093848444, 35.560592374494, 55.07885156139251, 9.861275957476709, 0.07845933143530162, 0.07188487978231523, 0.38963712932121375, 0.5998937292925773, 0.45361227385940095, 0.47257647398979435, 0.07287960664759721, 0.4246947529815859, 0.030237088175190073, 0.14312020893539154, 0.18713690911329564, 0.13256557045444367, 0.03137625900337533, 0.02549921740747748, 0.05244249906090479, 0.06894568386938303, 0.20229022018611434, 0.19173818640410903, 0.17408735208934353, 0.2067370235078758, 0.21309785154317656, 0.18211431410764495, 0.13338326206130366, 0.2767002023756504, 0.42149391505987416, 0.27616789384234336, 0.09648225465489012, 0.2507284581060371, 0.35505163032681714, 0.27690925244842807, 0.19336143478510842, 0.5186048750915836, 0.32946686771127487, 0.36511771921669284, 0.297817109573272, 0.55349288688552, 1.2181261326036146, 21.940605178956066, 115.28045192841562, 83.38155684932586, 70.37729940106793, 97.39252982601043, 104.64640432788481, 62.54181585004253, 86.86401751733597, 28.70868629024875, 65.5677204747354, 49.31319098318777, 53.18500572635282, 85.37014361350768, 70.73917727316581, 80.95430004981257, 77.35457620313092, 75.60307318164458, 81.23084283644154, 73.59013634343302, 72.50115302301222, 71.39213423575126, 73.1976875182121, 55.53592927994267, 55.43124514241373, 7.979576231971865, 7.177023503088183, 41.40016217385569, 66.69966159328338, 35.497006831630586, 37.922969248987016, 34.772117522455034, 27.490313783768688, 34.50507863875359, 42.82042495666012, 43.15132787150722, 42.76857906772245, 51.99073030102638, 44.417390515727384, 34.14394993935862, 33.424877505148615, 26.7249220801938, 29.244081974029545, 19.311244333944014, 25.404687581523774, 33.619458444656864, 16.586514980562274, 11.04482566156695, 26.104577664406072, 27.08276971693962, 40.90928931390086, 38.118750433768, 48.132518337618926, 22.944663301590953, 14.333699710907476, 1.0845865886057577, 2.975083209814564, 4.87187449970553, 1.7370338882169418, 0.2896813783914812, 1.2276981867128804, 0.8390882587240589, 1.2192742838974924, 6.258554929687131, 3.667921361423308, 39.95286249345349, 66.22610599763932, 58.62834945801766, 45.996230802228375, 25.42219900315808, 29.098983695430142, 23.616914403054025, 17.196649466791463, 12.298366139012, 13.914245367050173, 8.14915745489059, 1.392479776855438, 0.906938030835121, 0.3990363233512448, 2.182565619868617, 6.7416938562547015, 0.9040301449356541, 1.3310658787527394, 0.4414982174433047, 1.2918567633436573, 1.0847007050629587, 1.423717532907763, 21.718732387788837, 39.926535544856904, 47.03126584329913, 43.520132649329405, 39.470489409662065, 48.82764862429712, 37.00329503705425, 29.4460585424977, 32.343656555298836, 34.6428636581667, 32.50316758309641, 28.130142573387396, 40.60092826043406, 49.19420980638074, 46.365396438106416, 49.11507206578409, 38.229365194997484, 38.92051819832095, 34.31590272534278, 34.97900293719384, 31.97101373826304, 36.84135998449018, 27.831054003007953, 40.72354939676101, 37.59996598766696, 28.40806603431702, 89.05681071742889, 53.56417340617026, 42.27967523759411, 8.552424177046746, 7.3284211081843225, 36.20614782456429, 42.64167078079716, 44.75337289994763, 47.80463172543434, 67.59737445462135, 81.73356517668694, 77.30468365453905, 76.65102066532259, 68.19293929684547, 66.98157018230808, 64.1999311600962, 40.24902105331421, 25.146515215596846, 34.43306784476004, 43.14818605299919, 73.53120665396415, 62.945047270867136, 75.66030056245866, 61.332811924719046, 46.09530595041091, 78.30844171585576, 16.792772816073512, 0.36496416455315006, 0.2562838672630249, 0.6253689719784645, 0.6997298172885372, 0.38361049948200104, 0.7530436532631998, 0.37377616751097864, 0.5701969744217011, 0.3107534541237739, 0.1880024352501477, 0.38889656744657025, 0.25173010274527535, 0.187183900946571, 0.0822750621685578, 0.20263022532866848, 0.25119489839961456], [0.0549950810419696, 0.05534642045536349, 0.042385603226120436, 0.05595976959974055, 0.05477072836290445, 0.03327716637643115, 0.07593292667860947, 0.04512285453177268, 0.1260961417949969, 0.059675345828215924, 0.09036865851451313, 0.08569699306521686, 0.3459408530785192, 0.04386297697501798, 0.17467923161964263, 0.1929516543544108, 0.18301273605996565, 0.0664985845346124, 0.07723432620086017, 0.09415587545522759, 0.05882669660833575, 0.2168463504001979, 34.74441774429814, 79.56829132572298, 45.51732117129911, 57.02881082411736, 105.53962999774565, 53.981180191040046, 58.98839950561524, 32.28033381123697, 34.98110924997638, 60.404308457528394, 22.409563756758168, 82.88387867712206, 72.99401452464443, 65.38138043495917, 60.02496819342337, 71.3923538884809, 59.796364615040446, 59.4465676430733, 50.91935057793894, 57.80559701304282, 49.88107958147603, 59.250931585988695, 24.056900393578317, 0.5029234842907998, 13.832063867199807, 60.42686208601921, 39.59991978060815, 19.094753034653206, 25.245509955190844, 16.456337398098363, 24.706558642848847, 26.051549180861443, 29.410706220134614, 33.573366672761985, 35.72755198324881, 37.01500723438878, 30.86586044680688, 27.467662096023563, 22.160048061801543, 17.50562241000514, 12.600437671907487, 9.140147220703865, 10.89860656569081, 15.291752353791269, 14.701227757238573, 11.53748712232036, 15.299986389375503, 19.586486854860862, 27.862421197275964, 35.6388162028405, 23.292122540935395, 10.055706866325872, 11.170116951388698, 4.8073152284468375, 1.6047298908233645, 1.1961336481955744, 0.9747978540197496, 0.2146229180958002, 0.2047056494460952, 0.21005491966441756, 0.5056231168489302, 0.7228187880208417, 2.486319359271757, 7.0395959096570175, 45.59305037221601, 43.43106738982662, 24.49043212398406, 16.895119220979755, 10.865063436569708, 6.799797396506033, 3.4563072842936364, 1.4248656842016405, 4.260490248280187, 4.37746758422544, 0.540143467726246, 0.3454334270809928, 0.8903579882556393, 1.1139477356787653, 0.4974067932175052, 0.29528852912687487, 0.2029898882873597, 0.5328707192693988, 1.2475026014351076, 2.5108606488473955, 0.5191893082472586, 4.581982416491355, 12.418115119780264, 33.975354702241965, 41.10965967178345, 17.934908174699355, 30.808036865726596, 30.731854631054787, 19.483867845227643, 22.125156617933705, 28.10839891433716, 27.129793051750433, 21.257787212248772, 23.39794416581431, 26.509964427640362, 30.831804467785744, 25.489318601546753, 25.874261971442934, 32.659560326607, 27.793644397489487, 29.39379688232176, 30.96744787308478, 31.584381788007676, 40.53445977549399, 32.048172643107755, 48.54985852395335, 23.066547032325502, 50.621070015815, 85.4645864425167, 49.131110637418686, 23.32723559871797, 1.7438122341709754, 0.9144447731875605, 4.218878803714629, 5.189961070014585, 6.144864049650008, 12.917576009227385, 18.785279989242554, 54.33523293464415, 62.96504351400561, 56.739998863589385, 48.53890334406207, 46.67185121966947, 15.600667442044905, 19.40495760210099, 30.78862113337363, 29.33612039012294, 54.02818979755525, 44.44945589188607, 43.09932901013283, 41.8962674756204, 37.0563058699331, 25.639463009372836, 1.3624984049989333, 0.12957732193171978, 0.12945451803745764, 0.10434838417436808, 0.42477433419516014, 0.2112105020111607, 0.6444448064411841, 0.1866347231571713, 0.21531900090555992, 0.08350510060066178, 0.06111425430243535, 0.023139959629324656, 0.12907174986697015, 0.018419207096280112, 0.04595471110435263, 0.015412406796859878, 0.11880143725823973, 0.19870618508467752, 0.05081732779921544, 0.08786268532276155, 0.30368954123508546, 0.057283374180476514, 0.04599781121097265, 0.11056104314423378, 0.02644368315926723, 0.15830171204382376, 0.09429740253835918, 0.03986106006308429, 0.048492331388256246, 0.2591237551983326, 0.03132892243053404, 0.06422201254134698, 0.2929193256122451, 0.43875528559569393, 0.08139298853254126, 0.07619636133313179, 0.10769841771933342, 0.09683712190317531, 0.13191572871179352, 43.679514238911295, 91.77915526974587, 48.055290791296194, 74.59672635601413, 98.66777081643382, 57.944947058154696, 49.774744126104544, 33.52313287796513, 45.90567896443029, 50.352395503751694, 33.94443465817359, 82.18844244557043, 76.98735606285834, 70.62054910967427, 64.43665012236565, 77.5274742803266, 62.1315045510569, 63.75882141051754, 56.69589573337186, 63.24187655602733, 54.559812161230276, 63.03262987444478, 15.990646154649797, 5.312835689513914, 21.318542765032863, 37.39733634456512, 52.021101213270626, 25.90678038135652, 33.70685277446624, 16.71170134698191, 23.563668227964833, 21.299317267633256, 29.557079269040017, 28.851397806598296, 33.856695159789055, 36.535713211182625, 33.79155243596723, 26.550039283690918, 17.802953758547385, 12.254866073208472, 14.423399413785628, 12.715751432603406, 19.03751780909877, 19.789559725792177, 15.839974188035535, 13.279277374667506, 18.73718780855979, 20.18707036972046, 33.52436842456941, 39.65993988898493, 38.79156243416571, 14.011693712203735, 15.791390730488686, 6.445589719280121, 1.4396341433448177, 2.325752478453421, 1.5175629359099174, 0.4852246469066989, 0.10703123174607755, 0.46315530855809495, 0.42493132093260366, 2.0274335506462284, 2.3814204719758805, 19.07763973359139, 60.601944923400886, 45.682578471399125, 27.497562323847127, 22.50505581978829, 16.033855965060575, 10.924634433561756, 5.429476682216891, 2.5997815160982074, 3.4320905708497573, 3.105029617586444, 0.2286186549932726, 0.3966625539525863, 0.5722619797433577, 1.1170710455025397, 0.49133088860300284, 0.1463687741347859, 0.3742637058659908, 0.43377323196299616, 1.205765518449968, 3.645443483706444, 0.4753274344388516, 4.287989495262023, 30.256294704252678, 47.99794573937693, 45.710929363004624, 21.61653111057897, 32.998233456765455, 29.931540104650683, 27.728387924932665, 29.503615402406265, 29.826512759731663, 33.141411735165505, 27.13630614742156, 28.407687525595392, 24.648786052580803, 21.333734104710242, 24.48551347178798, 29.086108515339514, 23.83468439502101, 19.113001861879905, 21.188496581969723, 21.73947192007496, 23.847361495417935, 33.41007448011829, 30.14928460121155, 43.383838130581765, 33.07248000175723, 74.893798828125, 82.47419495736399, 46.87364539792461, 25.751407454090735, 7.250231600576832, 2.2041903820730027, 2.648854779620325, 4.30757487012494, 4.665776991075085, 12.596918325270376, 20.813143407144857, 61.58467908059398, 74.1365852663594, 65.75213070838683, 57.486068971695445, 56.82117623667563, 22.364925223012126, 30.075663674262266, 37.208682106387236, 23.917183606855332, 72.91938750974595, 53.040533065795906, 58.84775115597633, 51.11845793262605, 51.87676191329957, 37.43860360114805, 1.565288129833437, 0.11496398793233019, 0.2231831845617102, 0.0651379434331771, 0.2685686080686508, 0.3839461992104208, 0.6944716349244119, 0.16360100268596606, 0.23109789937734607, 0.08667328785504065, 0.10436706905884129, 0.18631952394160534, 0.23635415119990227, 0.05259228840229973, 0.052405811110211, 0.26117441935404656, 0.11772640905673466, 0.31136954203248024, 0.2188393128134551, 0.2039555880811907, 0.5164595837554624, 0.26237595165448807, 0.2717768004344356, 0.38024645418890063, 0.07905992904617902, 0.3905058423838308, 0.19950855493305192, 0.1362478486712902, 0.2781117653414127, 0.37912952863881666, 0.1699557939484235, 0.30329044007005235, 0.5505027537865024, 0.8137680109470122, 0.16355384231334733, 0.25652867832010795, 0.2905416951304482, 0.20660024616987477, 0.26355257077563193, 67.04724634847334, 103.13704490661623, 64.71578167330834, 79.11954864378899, 123.16176445253434, 74.26516056060791, 87.21135124083489, 44.35551120388893, 46.23516590364518, 78.31432527111423, 30.116332769393924, 91.54204799282937, 82.0818167348062, 82.59876943403675, 71.41994384027296, 89.27777351871615, 73.12735157628214, 74.10655560032015, 67.24198418278849, 78.1696133459768, 61.63183381480556, 71.3304510424214, 28.408401396966752, 2.738239957440284, 16.49344498111356, 61.89386775416713, 45.679836734648674, 20.00890454938335, 29.255270534946074, 19.838524633838286, 32.88503973714767, 31.185647364585634, 36.11143042964321, 39.1860822708376, 47.13982136018815, 46.799096830429576, 46.85943857316048, 44.420112640626975, 38.59484772528372, 31.539604010120517, 27.8011518139993, 20.73788489064863, 28.519933992816558, 26.893054477630127, 24.545264897807954, 16.20170791302958, 26.944162960975405, 28.874700607792025, 41.12448230866463, 42.37531831187587, 50.748390151608376, 20.612527901126494, 22.887520251735566, 11.74765948326357, 2.840548609533618, 3.0281411111354832, 2.415084704276054, 0.40649982770123794, 0.25845024133882216, 0.7886478040487536, 0.3855609593372191, 5.173589587211609, 2.142197321499548, 38.51847917802873, 57.3236632347107, 50.050651488765595, 33.680247337587424, 27.39749089364083, 24.490853778777588, 22.42324890628938, 16.159156080215208, 13.262292531228836, 9.120452019476122, 6.332119962861461, 1.29109802986345, 0.6846042998856114, 0.9826089477827473, 2.493262689921164, 0.7443156441853893, 0.5579808138070569, 0.30151185970152583, 0.3921132480665561, 2.6205923864918375, 3.4301475267256465, 0.29497807965643946, 14.922819118345938, 39.989948503432736, 56.69286766359883, 51.37470245361329, 26.232807790079427, 44.04954279622724, 41.26602103633266, 34.86796455998575, 31.400142177458736, 34.696047075333134, 40.6690166842553, 32.319896797980036, 31.50940372097877, 36.721515886245236, 40.618567159098966, 37.69167884703606, 36.32228136062622, 36.25770345810921, 31.05258684004507, 33.81721258163452, 34.21834945678711, 37.66459095862604, 48.47659649387483, 42.08538847584879, 66.7485970835532, 32.961312186333444, 65.6131846674027, 98.53389247771233, 60.01655078703358, 31.319213874878425, 7.109369481763533, 5.313115648684963, 11.354328124753891, 13.399695119550152, 12.462873285816563, 21.05684026595085, 35.007087107627626, 83.92442072591474, 85.36124767795687, 75.04270768934681, 69.28684126946234, 64.46735051370436, 32.930858904315585, 31.777519295292517, 43.59289653839604, 43.65737245928857, 74.43768209026706, 56.298041882053504, 70.05415885679184, 62.72370399967317, 66.23835948205763, 53.80679945791922, 2.2900733736253556, 0.15544316220668056, 0.327936714334834, 0.27697335868593187, 0.6592225812135205, 0.2988852200008208, 0.7390575231082979, 0.23516414086184195, 0.39477898889491636, 0.14384624578299063, 0.22873139249220972, 0.34805887168453586, 0.34811602184368723, 0.17864615746563484, 0.14098236397389444, 0.41031687610572387, 0.24581550560410947], [0.06354364168439662, 0.07448970129893673, 0.026575953985053687, 0.02936469597531663, 0.07385046987403786, 0.005076502697662481, 0.03142389243528728, 0.07381690756207512, 0.004486827106560551, 0.07602267387893892, 0.17118772461770043, 0.1517346224957897, 0.03599803106138303, 0.08647437312550123, 0.08988640616617857, 0.10650247786073916, 0.1717558094570714, 0.1457796984862897, 0.12753573591790854, 0.1230395965338234, 0.054163216808510405, 0.6742963723597989, 1.9558962602769177, 72.0446518928774, 65.3907117535991, 45.54286364586123, 86.13677086368685, 77.11077736270043, 48.077989547483384, 63.41468049633888, 33.95913962394961, 49.14374459174372, 29.285004062037316, 69.7573217268913, 77.9486426999492, 68.63090330554594, 68.01739754215365, 71.06579303741455, 61.5748143196106, 56.47287761011432, 53.47305282469719, 64.18373569365471, 50.83609827103154, 39.71921474702897, 3.448417191543887, 3.2287056263416045, 35.155235029036, 47.18053556257679, 20.099140636382565, 13.677754882843265, 16.856634886034076, 27.608610506980654, 29.25454293527911, 39.937745678809385, 38.051156228588475, 42.091758405008626, 62.537281590123335, 53.14190280052924, 33.634375218422186, 27.966048256043468, 18.077984471474927, 19.871413707733154, 13.7424357475773, 9.085703742119575, 17.564761946278235, 11.240893179370511, 14.171696997457936, 14.702556460134446, 18.85270945487484, 19.40618726515001, 32.774630900352236, 36.751486716731904, 31.899842331486365, 7.425201669816048, 8.161443298862826, 6.718520002980386, 3.7567640264188094, 2.690763834022707, 1.1203239161160685, 0.3482019462652745, 0.21927792879362262, 0.2568377335105212, 0.6718226438087802, 1.707135499004395, 0.20458877507236697, 5.276675849191604, 24.97790821136967, 43.817828778297674, 31.699685742778165, 16.940691278826808, 8.947165627633373, 6.335359840623795, 4.777046297827075, 1.9702064149802732, 1.2665518373250961, 0.3081539952226224, 0.9820560161625186, 0.08557532298108263, 0.40394676308478084, 1.0525305280762336, 0.3661960645789101, 0.04485881083735055, 0.1866133033388084, 0.11022340521336564, 0.7478237752952884, 0.8524648280393693, 3.2989562567203277, 3.6324540645845476, 10.244181656068372, 34.33046256342242, 56.752283726969075, 25.87815296265387, 23.660209525016047, 34.30814819951212, 22.900599395075155, 20.93434464546942, 21.281945090140066, 24.88096683256088, 25.897160768508915, 23.96138087395699, 24.17345558443377, 24.778794973127305, 20.15184944675815, 22.50614231632602, 32.54766098914608, 38.687854966809674, 37.762375647021884, 40.383538738373794, 38.43896096752536, 35.1025575976218, 36.1149448733176, 48.07435351033365, 43.496523903262236, 26.94391389046946, 84.12854086968207, 87.87150967505671, 58.76494992163874, 40.95684412987002, 19.135665316735547, 1.8096124452929345, 2.038138434290886, 1.2921214007562207, 0.6097329948698321, 2.0706035244849423, 9.685993079216251, 51.18906059572774, 53.99174313391409, 49.98287293218797, 29.31950326888792, 12.187060060039645, 27.46503018563794, 32.35650820116843, 30.198904545076434, 34.33888781455256, 48.44264445766326, 40.510902020239065, 30.988558069352184, 41.711770949825166, 12.75822481801433, 0.038093802474078634, 0.07838921906847147, 0.1153247617185116, 0.1793439869558619, 0.24257624071211586, 0.6507074220045921, 0.4262538951250815, 0.3866508573053345, 0.0659354486232323, 0.08254590489330792, 0.07457081468835955, 0.014506029021445543, 0.1130881603626955, 0.09238183798809206, 0.09169790533281143, 0.060449523640976804, 0.04196461109865097, 0.12220308980754307, 0.012644113608515792, 0.14634986708481468, 0.048187830590552864, 0.02855133851088824, 0.040577268002614866, 0.0655289623706091, 0.13341168392329447, 0.029527614148513927, 0.08668737621196816, 0.09501728003904705, 0.20373711512694437, 0.059266028880712494, 0.04767644391845792, 0.09737339877193013, 0.1378972972593, 0.060695162073018095, 0.03743849469408874, 0.11003017485622438, 0.17558175980323748, 0.1638316564382084, 0.6126932811833198, 4.168186091607617, 85.00567697709607, 71.75354142342844, 59.343585814199145, 94.79932538924679, 75.12267697242, 50.54854539132888, 39.38112605002619, 43.26608857800884, 43.894648398122484, 38.65871567879954, 75.90922986307453, 79.4501652256135, 72.99437538270028, 70.38324571424916, 76.4252882619058, 67.00448466885474, 61.30561420994421, 58.81121820019138, 66.23560597819667, 50.922374725341804, 30.907206150793264, 4.721310398271007, 9.122829956393089, 23.591505289077762, 50.810394979292354, 29.09083889376733, 15.077947878068494, 17.098827515878988, 20.487969113934426, 24.86531657557334, 32.56936934686477, 38.490367551003736, 43.447678627506384, 53.73366686605639, 48.41969074741487, 33.32895594258463, 29.72344267752863, 17.65488232335737, 19.21529923715899, 16.331663881578756, 13.942782571238856, 24.136053823655654, 18.054291394449052, 17.024259336533085, 14.675496028315637, 19.494909317262714, 21.613387330885857, 36.711588367339104, 40.78536202830654, 47.063684232773326, 11.618218325799512, 14.257392940982697, 17.641983609045706, 3.263139868936231, 2.5956897485640744, 1.1470552365626059, 0.38448932490521864, 0.2078448785769363, 0.2941412052079555, 0.6962933920083508, 1.062057965224789, 0.4317533338983213, 1.928404858035426, 36.9026077947309, 46.84890700924782, 38.27631988833028, 25.428208074262066, 14.25973459597557, 10.862301107375853, 5.652298686965819, 2.293906509876251, 3.6520568449651045, 1.0164821075816308, 0.8414272783744721, 0.11957769883015465, 0.4302666023854287, 1.0562472189626386, 0.5470675542469948, 0.14652228283305324, 0.0817838159479922, 0.09804844480728912, 0.6965047709884182, 0.01834639043907725, 1.410070136189461, 2.9563139330956245, 30.05390040336117, 44.26735201189595, 58.5225199883984, 25.37259670995897, 30.966806565561605, 35.58091809672695, 27.091928451291977, 30.79741312611488, 31.91196245531882, 27.634321643460183, 26.346423164490734, 24.79480020461544, 27.36347413832142, 26.427953550892493, 19.136022252421228, 17.542035733499837, 22.53576601705244, 24.883475188286077, 22.558572638419367, 23.946452333081155, 23.981179037401755, 25.224136960121896, 28.47835490780492, 41.72048253397788, 38.87993735651816, 39.1370173423521, 89.66688048455023, 74.24175185541954, 49.06558352131998, 41.570212610306285, 25.159007964595673, 2.0442347781312082, 1.419200923654341, 0.6537669320260325, 0.666439742330582, 3.051931021674987, 13.516875928448094, 58.079786377568404, 66.10219047915551, 59.73736040053829, 36.359300690312544, 21.240195382025934, 41.67741883185602, 28.712540018943052, 30.478718588429114, 49.83659205898162, 56.37786603743031, 53.58259285649946, 44.08702888796407, 56.76048932536956, 18.015283423085368, 0.06711975926713598, 0.04636480180065959, 0.12153886859455418, 0.15416606299338803, 0.19276505065781457, 0.760137504867969, 0.4560768399988452, 0.2628159006276439, 0.06024811529524385, 0.06565525196492672, 0.11931096233667866, 0.020151247623406594, 0.06235582235779974, 0.049201556436357, 0.028724141133528565, 0.13138067758371755, 0.05478430727136232, 0.1818142221459458, 0.132604074033518, 0.24456269137801664, 0.16093552232750002, 0.24895562339694272, 0.11352031056078211, 0.1433232835223598, 0.2894281710107481, 0.1849039466751199, 0.29840764078882437, 0.2752946761827315, 0.2919653316418971, 0.18164425787906494, 0.17080454275973384, 0.3180075713223027, 0.4377287277771581, 0.49675598620407047, 0.3422756433006256, 0.35704891347596723, 0.36348797441009556, 0.3939331665394768, 0.880630081219058, 9.69419671643165, 104.82753153770201, 83.81403738452543, 68.31906703210646, 107.5954383419406, 99.49964277205929, 75.27675551752891, 84.20527811973326, 42.26543703386861, 65.78933831184142, 40.768362475979714, 85.30916644680886, 89.99239798515075, 82.8234035738053, 74.45271261276739, 87.29292085093837, 77.65018170879733, 74.01570566238897, 67.02307670347153, 77.35311708142682, 56.90873138366207, 42.97372687247492, 4.685114276024604, 5.121761348939711, 42.27397603373374, 57.059071909996774, 23.770687003289503, 15.467328429222109, 17.54735250626841, 33.39549110781762, 36.530217970571215, 45.484949850266986, 47.38127462325558, 50.24330262214907, 79.62914297657629, 67.36233034441548, 51.54663170537641, 44.532433632881414, 33.59696757408881, 34.58651488827121, 27.651381992524673, 23.59231133614817, 33.7364705916374, 21.816626902549498, 20.822582590964533, 21.78456544876099, 25.138017400618523, 29.37664631874331, 42.75319553190663, 47.193977525157315, 61.28546891673919, 19.113533343038252, 16.557918940821004, 26.506436255670366, 7.836746063924606, 4.445639358412835, 1.7424234699818397, 0.4596705278081279, 0.23864735879244345, 0.8487217837283689, 0.461726401361727, 4.354042699260097, 0.20327376982858106, 24.46860217279004, 45.39134248610466, 49.27111964071951, 39.90837497095908, 34.51634760825865, 22.521090469052716, 22.602238424362678, 15.712120609898722, 13.259779272540925, 5.370638678150793, 2.831082949715276, 0.9355420378908035, 0.2237347219019167, 1.0789664450191683, 3.5659485622759792, 0.615629481692468, 0.1737037871874148, 0.23530888551425552, 0.27398163212403176, 1.1184173990641872, 2.6163927537779657, 1.2457374122834977, 7.973878499000304, 43.01191506847259, 49.78802919387818, 73.35061288649037, 33.3019268897272, 38.50361339507565, 44.28750122747114, 36.599643922621205, 29.862410291548702, 32.85930506644711, 32.312232486663326, 33.055762860082815, 32.1788836679151, 33.960936069488525, 34.5398739845522, 28.526127415318644, 30.031797847440167, 39.40412290634648, 43.433683610731556, 44.6165527835969, 43.660227944774014, 46.065884251748365, 40.14238749780963, 43.17607410492436, 58.48019369186894, 53.759401536756954, 33.828191295746834, 95.56025735793575, 98.56234535094231, 72.09314023294758, 60.42208463914933, 31.700772239315896, 2.8318372705290398, 3.8351543103494956, 1.5774136469248803, 2.645447465681261, 6.963077331742933, 21.81346547219061, 79.76157788307437, 78.10392149033086, 75.2777204205913, 49.62241495809248, 25.28841087895055, 44.11966693016791, 46.85248813321514, 44.92599641123126, 59.39285470593361, 67.44203290631695, 63.230478148306574, 52.513268455382324, 77.46213543799617, 24.53486865566623, 0.14459597006920846, 0.13346960017037007, 0.2374044730658493, 0.25239848381569313, 0.33273833893960525, 0.7769351164179464, 0.5673428985380358, 0.6851567412095686, 0.43844223142631594, 0.2029307769431222, 0.1776768570585597, 0.19460137873407335, 0.24723344242140172, 0.17506858814627896, 0.19280168498235364, 0.24044141413704043, 0.11810441216033314], [0.1223235418118777, 0.06618017541064371, 0.1962092593913117, 0.02447936477349891, 0.09878421097152656, 0.10918678099950475, 0.06816291055011173, 0.045705759342038826, 0.07211709635392313, 0.13253823643730533, 0.2755488028689739, 0.13942487658031527, 0.19778838110787256, 0.14602378942072392, 0.2608917022664701, 0.13452206708250508, 0.3351316282585744, 0.08176032003135451, 0.15550239612498593, 0.1656938476427909, 0.1319049881590951, 0.0591715510874506, 0.3490507716853773, 33.10399232372161, 67.04304941238897, 42.342939146103404, 68.10427804147044, 96.08041071122693, 59.655343640235166, 62.18165205370996, 49.08621518842636, 45.514493142404866, 32.12068550048336, 66.13760948181152, 80.58974712125718, 63.11556446936823, 73.01215156432121, 67.76439682129892, 64.44690712036626, 59.76057690958823, 62.70892058649371, 40.49724432729906, 21.903528974902247, 7.316119084435125, 0.3361018326494002, 23.253495039478427, 44.89271510031916, 30.92717689852561, 16.94764367995724, 25.576187333753033, 29.573578719169866, 30.65469768739516, 31.819047389491914, 32.34585308259533, 37.92692299812071, 37.10836356686008, 54.279523511086744, 48.849107911509854, 39.82584830253355, 22.93653222822374, 18.149075469663067, 13.805690830753697, 13.404866764622351, 13.034679351314423, 13.51931760388036, 10.170235172394785, 11.830118490803628, 14.767996303496824, 19.023509064028342, 20.28215450625266, 34.71257594323928, 40.0215628070216, 36.32035939924179, 9.01230933204774, 10.537793617094717, 4.378333447440978, 5.507650010047421, 1.5843217988168041, 0.8993975806140131, 0.8507037451190333, 0.1984407815841898, 0.94727881132595, 0.8410232742467235, 0.7490695568342364, 0.4095386533487228, 7.909187828340839, 4.667696991274434, 37.49037888742263, 41.34935179064351, 9.409833704271625, 4.377439147041691, 7.986521278658222, 3.606060925991305, 2.1684419003225144, 0.4667708145514612, 0.9380207919786054, 0.5146462229951736, 0.4104958036013188, 0.5293768680384082, 0.15651373943734556, 0.31160712121955814, 0.23892986137540112, 0.630986909231832, 0.5655243283798618, 1.610734181538705, 3.0016834985825325, 4.089421466473611, 3.999219700213402, 15.393145622745639, 34.89089081364293, 62.09489707023867, 44.86760800884616, 24.74886924989762, 30.300566496387606, 32.9558640141641, 19.582405628696566, 12.439628339582875, 21.713723521078787, 31.61739245537789, 26.449540315135835, 22.43101323804548, 20.819309373055738, 31.709568154427316, 45.13754160173478, 58.762588654795, 70.09164887089884, 77.25685427265783, 81.09238316935878, 87.53056941493865, 85.91439600913756, 75.47286618140437, 62.90207378325924, 74.64481461432673, 42.59125655697238, 59.26232999370944, 101.51075963051089, 55.370299354676284, 64.0360741461477, 53.22768895856796, 19.09810862233562, 1.0961100218757507, 3.2468963534601274, 2.096283282003095, 1.7969654981167087, 0.6367652959400608, 6.0580114972206855, 37.42401630647721, 45.44785599554739, 28.251259480753255, 19.257731437683105, 21.20974406119316, 37.93882739159369, 34.9442546598373, 56.68181834682342, 45.95407316761632, 29.858017236955707, 47.50920272642567, 45.097655019452496, 1.1067548442271449, 0.0824645386948701, 0.10949416611824306, 0.040921080602152694, 0.01032351071180235, 0.04368691847869947, 0.4149426682101142, 0.2115339749763089, 0.329929921896227, 0.20820363755187682, 0.1623440515850821, 0.11024566772844523, 0.22610038609033634, 0.045197624713182456, 0.07365740805623994, 0.12267588097001277, 0.14158651623274052, 0.10803074666088629, 0.07164020662105854, 0.03980575234539086, 0.05157241470090324, 0.09762233138204583, 0.2119832855438994, 0.09382276510399196, 0.03634411511161635, 0.03732197272080568, 0.056986718123117765, 0.01895346723857426, 0.27396906828207357, 0.14047766524937846, 0.19857512276259162, 0.10161328174534345, 0.07630287053724451, 0.14273063790413643, 0.15933138017933215, 0.12784309039312985, 0.1324723988410927, 0.08468362728073713, 0.04995602663726576, 0.0473118013882589, 0.21457540532273633, 46.811475830693404, 78.62005833656558, 50.08262665041032, 86.84148742306618, 90.63969104520737, 67.72008188309209, 36.823258246144945, 45.86849489519673, 47.25119313886089, 36.41330780521516, 74.11580454918646, 82.05394437236171, 69.55180521934264, 73.11072857149186, 77.30495822045111, 71.18987329544561, 68.06526614773658, 63.94099197080059, 40.9715530180162, 16.103861447303526, 2.9524521145128437, 6.993005996750248, 18.305797692268126, 35.44030112604941, 42.102846945485766, 19.831607534039406, 20.70024386529, 27.288348982411048, 23.650799758972664, 27.490894294554188, 31.478915137629357, 32.4900354877595, 31.395609878724624, 50.714461649617846, 44.50357283315351, 38.61168646043347, 24.4037163642145, 18.90723628382529, 16.725833646712765, 16.76515148532006, 15.241092981830722, 25.490787529176284, 16.81417326773367, 13.808686540972802, 14.278580604061005, 18.241461015516713, 21.08661105555873, 39.97306662221109, 42.49187154154624, 52.29505915795603, 12.608359879063023, 16.348958592261038, 6.328365274014012, 6.44982538876995, 1.6280829473849268, 0.4502823041571725, 0.550589352365463, 0.16299004756635235, 0.35915289735121114, 0.9312536002647493, 0.7321671444562174, 1.9585070879228654, 2.13951000763524, 18.093462144174886, 47.3950146859692, 47.98937143818025, 19.710374916753462, 10.857965907742901, 11.739044977772622, 4.489672866559798, 1.2072215758023725, 1.1348202608285414, 1.5100937625092845, 0.5857586103581613, 0.39727916280108116, 0.9347147242196145, 0.8272897079586984, 0.30208948999643326, 0.4121990928486471, 0.4474313232687212, 0.7667371991180605, 1.0535896905968267, 4.188307360295327, 2.268477048604719, 3.242521930125452, 33.64580108273414, 43.772925484565, 62.28301002133278, 37.79795154448479, 25.29874828553969, 36.89806176770118, 35.58011793321179, 29.580948852723647, 22.07266942147286, 25.74214477692881, 29.872573152665172, 30.488061674179573, 29.572241190941106, 28.64609899059419, 30.88258739440672, 34.70275825069797, 49.11174589587797, 56.08920312696888, 59.08297961758029, 58.7817729673078, 64.93201017379761, 64.99528584941741, 56.94490740376135, 50.11632373256069, 55.75673518642303, 40.02048023285405, 73.02635838908535, 92.20797231120449, 58.6807248669286, 72.03203755040323, 63.53900001895044, 26.826766421717984, 2.7069931309069357, 3.7390993871996483, 1.2289371653910608, 0.9301836512261822, 1.132540138017747, 5.952789504681864, 42.64229443765456, 56.321125030517585, 36.825631280099195, 34.74108765202184, 27.57142447656201, 28.988665073148667, 40.38326417246173, 60.190798159568544, 55.38697727264897, 44.49913663248862, 59.912337333925315, 50.223761373950595, 2.453958579609471, 0.05007346025517872, 0.18093599427130916, 0.02288534647725042, 0.0919179487673025, 0.06659352581106848, 0.42651077972785123, 0.137524641449413, 0.2850021133499761, 0.1430177216928813, 0.1660836331786648, 0.08153932664783732, 0.1310736601871829, 0.05163986491219652, 0.097234062700262, 0.05330854613754538, 0.17162840903526352, 0.18935427400133303, 0.20344643072495538, 0.13857487138480912, 0.22455665763587723, 0.2736786290282204, 0.4811873941892578, 0.2482772985052678, 0.25103814148854825, 0.15758877529972987, 0.2138923153641724, 0.20801603794097903, 0.451106951842385, 0.2306565408024096, 0.2734082612779833, 0.21792218299402347, 0.3774677000699505, 0.6392206996679306, 0.5068312681490376, 0.19834961712120042, 0.2873640849946007, 0.34903725789439294, 0.26833397065920217, 0.2077250624255788, 0.3857422157401039, 63.06452266631588, 97.61299056391563, 63.56569174797305, 96.30649612795924, 108.11707435115692, 85.19930870302262, 83.38512620618268, 61.27507855815273, 61.45633520618562, 44.11554844148698, 80.22964216047718, 93.95977343282392, 75.14293993673017, 86.00612455798735, 86.17375096967145, 83.87810537892004, 79.04726720625355, 77.99595432896768, 51.516570660375784, 25.003368316158173, 8.504313365105661, 3.50834438877721, 25.56075476831006, 53.52151763054633, 39.651997089385986, 18.062885307496597, 29.67362661515513, 34.765696602482954, 38.58644993074479, 35.674917697906494, 39.74195272691789, 47.37772095587946, 48.48446869081067, 62.08066671125351, 61.4786534924661, 55.7488473000065, 35.714157089110344, 30.95635933260764, 25.799642801284794, 22.90208205100029, 22.883089934625936, 29.010740172478464, 17.285434276826923, 19.982336375021166, 24.562931253064065, 26.440781662541053, 31.93056037349086, 47.51857326876733, 49.10397175819644, 64.91998418684929, 19.524319248814738, 19.879566354136315, 7.9736961087872915, 9.465230318807787, 1.1980656606535758, 0.7514802210273281, 2.4370502223891597, 0.26634407259764215, 0.7374695147718153, 0.8320824765870649, 0.8815732273843981, 1.0283391874644066, 12.126431984286155, 31.374725218742128, 52.678070760542354, 50.142517320571415, 28.259288572495986, 20.054282449906875, 23.7193412165488, 11.530365078679978, 10.378025674050855, 4.809930468759229, 2.169570562339598, 0.3125002265216843, 0.6409260726744129, 1.5646328488665244, 0.8711158207827999, 1.4914378668031385, 0.3299877768562686, 0.7056629537574707, 1.5594954019592655, 2.530536973668683, 11.576985389955583, 3.3915621907480302, 8.722579536899444, 45.34708638345042, 44.949750284994806, 76.7211369545229, 50.542508863633685, 33.73499578045261, 43.79529868402789, 43.21177159586261, 29.47728257025442, 20.498404579777873, 30.326546315223943, 40.19465700272591, 35.69902458498555, 29.944005397058305, 29.24351323035456, 40.96431232267811, 50.920931293118386, 66.26156422399706, 70.0925745502595, 76.68924024028163, 81.682919533022, 90.897947742093, 90.89545311466341, 79.70159699839931, 68.95331428896996, 89.60530711758523, 53.45175043229134, 76.78322022961032, 120.17809590985699, 74.99016361851847, 78.35794202743038, 73.62532784861904, 31.318615713427146, 4.297292867014486, 5.121239673706794, 1.9835867228046542, 1.630126869966907, 2.708009760225973, 12.878298374914355, 60.888411306565814, 75.40522883015295, 49.50872898101807, 33.594386654515425, 33.72875136713828, 54.593062093181, 53.47692028168709, 75.43089682056059, 68.36772795646422, 52.51972859905612, 73.23282411021572, 71.06730707230108, 3.3105471057276574, 0.18266562162147415, 0.2259328273395377, 0.11931413394068519, 0.20706277941503834, 0.21053862757980826, 0.8580551248404288, 0.3222340477570411, 0.4745447683718897, 0.637069647350619, 0.4086331067787063, 0.2663310491029294, 0.41296986923102413, 0.13143868576134407, 0.17133743351986333, 0.21059067559338387, 0.34235853401403277, 0.22585859341967493], [0.018270580293310267, 0.07770330224546694, 0.11725367152041967, 0.056461032419916124, 0.03225322474815673, 0.07975454096712413, 0.06111497059464455, 0.0410704868995855, 0.09017102315180725, 0.11689996872577937, 0.12121456825444776, 0.039015942508535045, 0.07115790830744852, 0.06377167924637757, 0.07848410671877284, 0.09176338286769968, 0.23912052533799605, 0.3809465359776251, 0.10356469921046689, 0.12884178559385961, 0.10724954382185975, 0.12979256199492564, 0.9340216291527595, 3.823084932181143, 56.79252724493704, 56.120895877961196, 45.90506315231324, 93.29812449793663, 69.07809272889169, 50.81564703295308, 53.01719104090045, 41.51884525052963, 37.71062781733852, 51.554860837997936, 85.50555167659637, 64.17589879805043, 77.18736556268509, 71.16437788932555, 73.46208664678758, 47.82521240172848, 21.817262326517415, 5.150357878977253, 1.4905431986816469, 0.8366401481532282, 15.800044459681358, 40.90423337874874, 34.2543960386707, 25.710187265949866, 14.810916839107392, 25.505196356004287, 24.421737693971206, 37.80587865460304, 46.01611329663185, 55.44694639021351, 82.06708431243896, 102.4332775608186, 81.92683604455765, 76.35322647710001, 60.503395372821444, 37.488158825905096, 24.387526781328265, 9.971291576662372, 4.689332294848658, 9.070605558733787, 7.068847965809607, 10.639230032120983, 11.885345462829838, 14.239986442750501, 17.577468464451453, 20.35978409551805, 35.46236053589852, 42.41858205487652, 29.58482219326881, 5.84569065801559, 11.232445374611887, 4.505147597482128, 1.323691087384378, 1.353623061891525, 0.618198572868301, 0.7404950717764517, 1.1848639432461032, 1.896453966056147, 1.208375120355237, 0.7729488851562624, 1.1439754405329305, 9.13225737310225, 5.471672559938123, 17.21312930507045, 23.602519304521625, 5.779800232379667, 4.472000627748428, 5.393752715279979, 3.1213400585036126, 2.2584666696286972, 0.6081533828569997, 0.46887914980611495, 0.3010394286003805, 2.796174590626071, 1.6816170489595783, 0.836495572040158, 0.7385017109974739, 1.8564346360583461, 0.9689249627051816, 0.4231037109369232, 0.42617716375858555, 5.2732138672182645, 5.296858404913257, 0.7485980143950832, 16.04854033839318, 34.640933852041925, 54.92459258725567, 57.67326016579905, 36.339779053964925, 31.263426003917573, 26.91722216144685, 27.782926520993634, 17.46783233457996, 17.185506013131914, 16.033002849548094, 13.344932948389362, 17.53102171805597, 33.53112666837631, 53.843767796793294, 54.47293950665382, 52.44701177843156, 52.23146577035227, 61.60860161627493, 70.75937747955322, 72.09291273547758, 80.16599778206118, 90.04269846024053, 106.32721054938533, 104.17905392185335, 85.62731773622575, 37.62228819631761, 77.57534288590955, 54.38157573823006, 29.919314076823575, 50.123638952932055, 48.37391276513377, 3.468228347839848, 1.633778841745469, 3.8675440174918023, 1.3768428804412967, 1.2278393920390838, 0.235963155245108, 1.8653992130871744, 34.74171130887924, 28.17643830853124, 20.815840036638324, 29.98309377701052, 34.502301600671586, 35.72974066580496, 58.20665544079196, 41.77241079268917, 40.578774713700824, 47.570042610168464, 17.367309831803848, 0.1252366447701089, 0.15597678841121737, 0.1710384906900506, 0.08695713109186581, 0.0491407596986861, 0.10780671956918894, 0.12446392252440415, 0.24391130213775944, 0.12569691805589583, 0.24949401466836854, 0.015266119434888807, 0.2636721111353367, 0.173147254953942, 0.010145867371090479, 0.07401376917597748, 0.033066825445501075, 0.04675882380275477, 0.055765076014663906, 0.05879938557383515, 0.07200101871163615, 0.155042375648214, 0.10060015344812025, 0.0664863424495824, 0.07055813807152933, 0.12565380262751735, 0.058639836272284876, 0.031018612771144802, 0.049048246920949994, 0.05503468012677566, 0.051124322213112354, 0.11024508550162278, 0.1362199324273294, 0.07613263813959015, 0.10798673490963637, 0.08810522875958875, 0.22449271993771677, 0.035568539188393665, 0.04474131210196403, 0.10293391773537283, 0.18764326258772807, 0.6830669759261994, 7.242908045168846, 80.94383516619283, 57.54849741535803, 62.04261579821187, 99.35618600537701, 78.4713299043717, 45.45554384108513, 42.0424699014233, 45.30834121088828, 40.742259102482954, 67.07640524833434, 86.35920063141855, 70.20676259071597, 77.06308918614542, 83.76006557095437, 79.51897928791662, 55.42920943229429, 17.84365619382551, 4.362420881948164, 1.1683842275411853, 1.9119864293644506, 21.143793329115837, 38.44236558483493, 34.84511675373201, 31.876259080825317, 19.016295825281453, 24.869676290019868, 20.940577291673232, 27.395880760685092, 31.713306173201534, 35.75123133197908, 57.621316217607074, 64.59827923005628, 61.503234986336004, 61.520756213895744, 50.34003611533873, 31.432046736440352, 24.87863890586361, 19.71688605123951, 12.200817773419043, 16.82872133870279, 15.808772713907304, 15.940071113647955, 14.43032043595468, 16.35038241263359, 17.77066872965905, 20.921494960784912, 38.84091369567379, 48.93420373239825, 44.88729830711119, 6.966599620157673, 10.052218898650139, 7.213862894042847, 1.4148662143176602, 1.4627187626977123, 0.21431524186365067, 0.45322607361501266, 1.2422696693289665, 2.0612231762178483, 0.7342822212846049, 0.14596680780091595, 1.4956118815368222, 2.022788728917799, 8.74226002923904, 32.86090539347741, 37.390264311144435, 8.73824744455276, 14.16879052116025, 15.790416021500866, 6.056291047603854, 3.0704482861103553, 3.5038476365227855, 2.2690377023912247, 0.3020582948961566, 4.6603396054237125, 0.9897806339206235, 1.3716941567197924, 1.2887762318695746, 1.37813383052426, 1.0749704078320534, 0.22305425196405382, 1.852262092213477, 4.114677117716882, 1.8580192736079617, 2.540559119755222, 32.22255533741367, 47.23719812208607, 59.68248644182759, 53.45720644920103, 31.441295685306674, 32.51325395799453, 29.296965329877793, 25.37043744517911, 19.351574144055768, 24.917305631022302, 27.126113868528797, 24.08567293997734, 27.82969686292833, 37.74161846406999, 49.77237893689064, 50.51560924899194, 50.574331052841686, 52.97581395795269, 57.967261422065, 63.944816281718595, 67.82996316109934, 74.54584537013885, 73.32320336372622, 84.91198724316013, 78.9838424805672, 68.01103545773414, 48.53954661277033, 83.86109798185288, 54.50352222688737, 32.414229800624234, 60.720577009262584, 61.40849797956405, 6.573131468988235, 4.397851161418423, 4.468167001201261, 0.8424608229148773, 0.8410742650589637, 0.23818454975562714, 2.545205657520602, 36.22302970578594, 42.843570863046956, 31.336807666286347, 26.525977503868845, 28.782150322391143, 45.630756116682484, 61.283052736713046, 55.64381014916205, 53.637102034784135, 60.156261690201305, 23.61388437209591, 0.09401871507326443, 0.12204182063860279, 0.09173368163887533, 0.06375721167592753, 0.039233032674078024, 0.14547960652459055, 0.07285889163012467, 0.44756793206737894, 0.09276537224650384, 0.22201090149821776, 0.06489004504175917, 0.035867049178529176, 0.114691881162505, 0.042001398640774915, 0.06801615874733656, 0.020497350825838024, 0.06480490969073388, 0.007587426732624731, 0.23651859963372832, 0.22592545757370613, 0.44103366172602104, 0.29293256361157666, 0.17139498204473527, 0.35180522549536924, 0.23684771100599922, 0.1682758857045443, 0.13635298657801845, 0.14122654683887959, 0.19179916700288174, 0.2135055022494447, 0.21728752511403254, 0.2643918354184397, 0.21856563556338512, 0.3062753637711848, 0.45448745270409896, 0.43479540775860515, 0.149309954215442, 0.20150678803122815, 0.3123591437695488, 0.26643238721355317, 1.1504830203710066, 12.276299865015092, 98.59411654933807, 74.20292823545395, 70.73789858048963, 111.51346252810572, 92.51656086214128, 74.8807373354512, 74.40722096350886, 55.40376893935665, 56.33586921999532, 68.65103290927026, 100.47294755135813, 72.83401320057531, 87.87670289316486, 90.092787127341, 91.19086250182121, 60.897930898974025, 28.83093087903915, 6.090239651741521, 1.4446974329410063, 0.9301240802291901, 20.153234043428977, 50.630562151632006, 41.53080455718502, 31.257446350589877, 21.51596938410113, 30.46448430707378, 28.303411314564368, 45.96448706042382, 49.77534032637074, 60.685864033237586, 92.04215018979966, 115.19916472896453, 94.63358955998575, 92.06659440071353, 79.43669580644178, 51.410686277574115, 39.82986088721983, 25.5890997763603, 13.476216639241866, 21.754502442575273, 17.1201632484313, 18.241898359790927, 19.991924608907393, 22.140369530647032, 24.786833870795466, 30.78190407445354, 51.14675391104914, 54.65192902472712, 51.233226483868016, 12.97891599516715, 19.684489234801262, 9.216109802646022, 4.137605822855427, 1.4987948849316568, 0.4743161677352844, 1.1499045933446577, 1.4884323506586015, 2.695752843733757, 0.6900109194459454, 0.6444915071610482, 0.8951562727170607, 16.800856820998654, 28.47903936139999, 45.45128806944817, 40.287248473013605, 15.714466187261767, 27.66864630483812, 29.206442909855998, 20.126561926257228, 6.4016900620152875, 3.735092195772356, 2.329569434927356, 0.23470056573710135, 6.060215378961256, 1.2754901835033972, 3.961471054823168, 1.0284566134214401, 1.8447669331104526, 2.4064138147138783, 0.3936034116533495, 3.923033298023286, 11.897332226076434, 5.787257638669783, 11.317633371199332, 41.78402100839923, 46.11327825054046, 66.2959869446293, 63.52735450190883, 43.24898312168737, 41.40105647425498, 37.38549078664472, 39.01454917846188, 27.055905403629428, 24.339701321817216, 24.952057830749023, 22.823983738499305, 29.752913405818326, 41.34972049343971, 55.002930164337165, 56.7267059510754, 56.19240460857269, 49.78625236019012, 54.8547234073762, 66.07179211032006, 73.4314686252225, 80.154065931997, 85.32626013601981, 111.28327431217318, 119.21899795532228, 106.80343335674655, 55.86523186775946, 103.97649488141461, 72.52678178971814, 41.74435015647642, 67.75364952702677, 64.62818338025001, 8.276912973773095, 9.096538309128054, 7.806207960651768, 1.931423612179295, 1.5071169286966326, 0.6171614736799271, 5.640383016678595, 50.46055093888314, 53.86001425404703, 36.683974881326, 41.62656530257195, 52.00707481753442, 60.44539528508341, 74.85649708778628, 67.24902091487762, 61.09700687469975, 74.53614142633255, 29.57327473548151, 0.29730425967324164, 0.35855228441857523, 0.22238524270153817, 0.20166539887507118, 0.3001070995965312, 0.47981419690674354, 0.27306483938328685, 0.5997344442913609, 0.2181844761775386, 0.5495914768788123, 0.27488279667112137, 0.35501786117111483, 0.3151785311920028, 0.14371207314393214, 0.12749342488185053, 0.12491793687184974, 0.23977428945081852, 0.115869986494222], [0.022396421503095378, 0.09982837349056237, 0.02423539449791274, 0.09643333228004557, 0.03341400500146612, 0.11287200865485977, 0.09553198387185413, 0.01854883874916742, 0.08389649492117666, 0.07019973149703396, 0.0046421016374933385, 0.1466971500626495, 0.1039732768831234, 0.055814971321172295, 0.048417415650140856, 0.0557141924547332, 0.060963794634106665, 0.0788018110418512, 0.03737720382970668, 0.09869238001204307, 0.02928917502774106, 0.40940746845256903, 0.3185430361378578, 0.9478472485657662, 14.287961932920641, 65.386930588753, 49.67092291001351, 75.07017212529337, 87.7952431094262, 51.931518200905096, 47.57056820777155, 33.268704414367676, 30.33453029970969, 47.454501352002545, 82.85346461880593, 78.09656312388759, 78.20766033664827, 56.08086809035271, 27.224322172903246, 3.2835680630899247, 0.580344942788924, 0.6653325920624118, 0.33865281350670323, 3.610475063323975, 23.890146709257557, 25.046002518746164, 51.55634741629324, 24.261122518970122, 24.473263909739835, 27.23506554480522, 42.01692350449101, 64.60864213205153, 88.84706589483446, 108.35900614338537, 102.11023115342664, 111.75655534190517, 112.09651500948014, 94.96567310825472, 83.86876229316958, 68.64229386852634, 37.91522649026687, 15.646833738973065, 7.029127593963378, 9.948593801067723, 15.429731530527915, 18.78593110269116, 12.772627761287074, 11.43832274021641, 10.918345893582991, 17.07761141561693, 36.134411596482806, 36.12078528250418, 20.82683640141641, 5.058234641628881, 10.283525970674331, 3.7505223097339755, 1.047748300817705, 0.22168744385482805, 0.45560401053197924, 0.062304701310612505, 0.2715933376983289, 2.0228425389336, 1.4862760276563707, 0.7229275725060894, 1.145965062802838, 5.010106179022021, 3.5366178135718074, 15.537802634700654, 21.175121299682125, 5.120872932095682, 5.778772081098249, 7.011471044632697, 2.260789938511387, 1.1346199748016175, 2.4388471582243523, 1.2764203981045754, 0.6216041094833805, 1.606326295483497, 0.6565746136250035, 1.004925518026275, 0.6904989480972291, 0.7465834483023613, 0.15817535350159292, 0.6596105894254101, 1.7525426947301435, 1.010644333737512, 1.7027436701520797, 2.89250407968798, 19.927556553194602, 35.92983645777549, 55.50970823534074, 53.589727647842906, 33.19015895166705, 32.43336704469497, 33.69274008658625, 35.790690375912575, 25.43474666533932, 11.958225061816554, 12.15888665568444, 25.37829787500443, 44.33841751467797, 63.15524708840155, 61.02466267924155, 61.13841925897906, 54.17514531843124, 56.44442081451417, 53.568570383133434, 61.871651449511134, 60.16197658354237, 74.79423338367094, 77.55995935009372, 94.82157307286417, 96.1419762334516, 91.59369776325842, 41.985411182526626, 44.92214072135187, 70.6984709155175, 59.21546159252044, 39.7826983082679, 49.283169161888864, 12.482122317437204, 0.824143844506433, 1.2723326755146827, 0.7738140742144277, 0.26224213141587477, 0.45749278498753426, 0.10983304511154852, 7.4867220847837395, 25.25541001750577, 30.735786807152536, 35.526832534420876, 34.46345444648497, 51.52372506357009, 47.18717221290835, 38.95809450457173, 52.171359369831706, 44.90787113866499, 1.289210144069887, 0.1702777500594816, 0.1218977501435626, 0.1502017571680969, 0.043499322698241284, 0.09293185847420847, 0.11062164069904436, 0.16791746380829042, 0.10240716333951681, 0.11986152674522131, 0.083804311561248, 0.14256657251427252, 0.08898003222120386, 0.1387439623114563, 0.09515217280075436, 0.09500379689157971, 0.1208086106024923, 0.07355240804533805, 0.1194332606129108, 0.07240728279876132, 0.08323562151241688, 0.05101957118078586, 0.10097595787937604, 0.09851832483564654, 0.0653962912638822, 0.04995914078467796, 0.03047003061510623, 0.019547420951928345, 0.14874240563761804, 0.07826849893336335, 0.09884019667703299, 0.04482856951653958, 0.05177317953277981, 0.05701246633825283, 0.04462259528677791, 0.08292732474904868, 0.04730329781229939, 0.018576025294380325, 0.07183377405688648, 0.01608401980070818, 0.23648691423718007, 0.19016792066395286, 0.9004711455875828, 35.54053337343278, 78.29431333849507, 53.30931740422403, 89.88390522618448, 88.60733847464286, 56.46486420785227, 37.24163786057503, 36.705881318738385, 38.07038760954334, 60.28711980389011, 90.02953498594223, 82.34152470865558, 86.79575258685698, 61.96449002911968, 30.742827461611842, 2.8892646922219187, 0.1744299312873233, 0.4977310322705777, 0.7768335025156698, 13.425093447008441, 23.683645686795636, 27.46807590607674, 49.304632371471776, 29.944627092730617, 22.48446337638363, 24.40963718198961, 31.007001053902414, 43.605597173014, 60.29866333930724, 79.34431614414339, 81.11584678772958, 91.71987256696148, 91.1356512192757, 83.64496754061791, 70.71618433921569, 52.70404077345326, 33.467078285832564, 20.51425683882929, 12.743031517151865, 18.93274541824095, 21.950038479220485, 22.831928499283332, 13.651296534845907, 14.173429704481556, 14.249746280331767, 20.557414677835283, 39.838584238483065, 45.53308517702165, 30.99394936715403, 3.902037831083421, 4.911660080955875, 2.549361163570035, 1.548459323183183, 0.20879491953359497, 0.4413955923049681, 0.023441886371602456, 0.3095410740183246, 2.0148785340209163, 1.9908161413285042, 0.41278821446241876, 1.1152944569626162, 4.649302055758815, 15.076610349839735, 28.477076215128747, 29.73059904190802, 6.255819076491941, 15.71440637111664, 20.018651639261556, 11.11859759976787, 6.64333846299879, 3.6145214784529904, 0.8639329191177123, 0.8139301151517899, 2.234201907150207, 1.5731909702862463, 0.9555445323067328, 0.8696034406462024, 0.5863974663999774, 0.06534824222927132, 0.7639213050565412, 0.7284592789026999, 2.0571716129779816, 1.2901528612259896, 3.921394482735665, 29.935701739403513, 45.79904540892571, 58.44641423994496, 53.71869125673848, 29.146387500147668, 30.26342557322595, 29.980532469287997, 29.989989303773452, 26.277132534211685, 18.077092132260724, 17.33853336303465, 30.720160084386027, 48.278336371144945, 62.69535310806767, 65.7815053386073, 63.558780531729425, 57.05796187923801, 60.1306878366778, 56.46440921291229, 65.67728011838852, 62.942285922265825, 72.10055351257324, 69.65222574049427, 82.32539592250701, 86.53153388730942, 82.75949247421758, 46.08157373243763, 54.95265322346842, 72.69463569887223, 64.23971183838384, 47.45600361977854, 54.85464103760258, 22.861350197945875, 0.08682216938224532, 0.8730308567323993, 0.6910452607177919, 0.27958437019298155, 0.4679912539018739, 0.2737613971675596, 7.6988271936293575, 34.440598795490885, 37.07474885448333, 28.28740804426132, 30.458300690497126, 59.387159424443404, 56.05023830167709, 51.090977807198804, 62.45638270531932, 52.592370894647416, 3.634118130130153, 0.0316608012954314, 0.19582685894302784, 0.2244487311691046, 0.054550631302258665, 0.06498561451031316, 0.1865783084424273, 0.06758118168480935, 0.08002973507128416, 0.05269817707519378, 0.15449347365046703, 0.2639207526320412, 0.04192732176893661, 0.08414826971749145, 0.09294177165194865, 0.09034588272052427, 0.12766661437889262, 0.07709685172284804, 0.10656572607976776, 0.11936583721469488, 0.19244055113484784, 0.24658893265070456, 0.22982823121691906, 0.2881298051966775, 0.2941524820222009, 0.18020208203984847, 0.1735347115825261, 0.20325022028578868, 0.2504323191580273, 0.18620732270421522, 0.24189943267453104, 0.1677636333530949, 0.1388173075693269, 0.12837368288948653, 0.20039787576083215, 0.24315543382638888, 0.12851170895080413, 0.1652954512786481, 0.12820944129940004, 0.1835389618551539, 0.5061756194599214, 0.3839654126955617, 0.6287677057327763, 53.47424914759975, 92.09864016502135, 69.09040897123276, 100.4284914078251, 104.55312252044679, 77.0675685328822, 71.1354386421942, 50.68718940980973, 49.62456441694691, 69.69486190426734, 102.16094739975469, 88.61403003815683, 95.91687140926238, 72.04818202603248, 36.254416511904815, 3.8892227122860574, 0.40309594583607494, 0.3963506335933363, 0.8242153664750438, 7.874854341630013, 36.23458108594341, 31.700162310754102, 65.16962343646635, 29.25065782762343, 32.247146637209006, 30.8335675731782, 50.91808757474346, 71.86074764497819, 92.17855453491212, 112.59535420325496, 103.7054983262093, 117.61519570504467, 118.44411803830056, 103.7338335283341, 84.93195995207756, 77.07170271104383, 47.60663832387617, 28.078263344303256, 15.992427891300572, 22.28555606257531, 24.99557652781087, 30.411102810213645, 17.160267522258145, 19.27539190938396, 18.51769393490207, 28.07325447759321, 46.10855963922317, 45.56826099272698, 34.54752652875839, 13.174951153416789, 21.963249021960845, 15.76792024797009, 2.306567675644352, 0.23876070916172, 0.6909619103516302, 0.12744008984056213, 0.5860853315361085, 3.5483486421646613, 2.244384134969404, 0.6541900577083711, 0.48116735332915866, 18.536990034964777, 31.510543169513827, 43.168684359519716, 35.519701665447606, 13.482266895232664, 28.661394273081136, 33.72727655595349, 21.372824445847545, 8.687995999090134, 6.840713600958548, 2.5518736868135394, 3.2104048277101214, 2.6048207811770903, 3.3144079437178955, 1.941735278214178, 1.8041753047896971, 3.1175978722110873, 0.15911448536620987, 1.8384511816886164, 1.6568690995054862, 11.673490405082704, 10.76264544840782, 13.526250393159929, 40.197500721100845, 44.79142773535944, 58.52181003939722, 56.11814237410023, 41.7365603293142, 41.66053695063437, 43.445093785562825, 43.44471331565611, 34.70237778079125, 18.199270040758197, 19.342182028678156, 33.89326733927573, 52.4273254025367, 67.363844379302, 67.49015254359092, 65.15914678573608, 52.83895854027041, 57.837999713036325, 52.78031126145394, 60.17438696276758, 61.96532941633656, 74.44904911902644, 72.96914669775194, 96.43059992021131, 104.90118580479776, 107.17752548956103, 54.72667371073077, 62.99750897192187, 88.280879605201, 75.88550736827236, 55.30532137040169, 61.391898508994814, 24.825155427378995, 0.9371548674760327, 1.966558978442223, 0.9539057783061459, 0.8687588440314417, 1.3731399178504946, 0.6331473997523708, 10.483321701326679, 39.86521713195309, 49.889143974550315, 47.85434384499827, 48.01307824350173, 71.63807469029581, 63.66693596686087, 55.71103957391555, 71.38738816784274, 64.58051481554585, 3.2167267078353516, 0.35908799438226613, 0.2721307024119362, 0.25225301904063074, 0.13720368125265645, 0.19220798216279478, 0.28097310373860024, 0.20099796775367954, 0.3324765820176371, 0.18490983023037835, 0.3037714819994665, 0.3672741035059575, 0.2268409173214628, 0.1875034208980299, 0.12913550370402876, 0.1913353160864884, 0.1759003910927042, 0.21327422030510443, 0.27684775090986685], [0.0667793021327065, 0.031156041283881476, 0.02726762987402899, 0.10201310303302542, 0.09559716263245191, 0.08612529750192359, 0.021310072437289263, 0.06179874620190071, 0.06426994283232959, 0.07216951975058164, 0.1545118904041667, 0.23244989134611624, 0.03853506911846419, 0.027222269808032343, 0.03573772970647101, 0.04990614282207624, 0.07919213283927211, 0.03348386838972088, 0.012265778214280165, 0.016928334878156745, 0.059516723493054036, 0.20885809114383114, 0.09661514792711505, 0.4266141096670782, 7.8086952336372875, 51.99977528664374, 80.76175874279392, 62.09856840871996, 93.22920060926869, 63.292820299825365, 46.73070638410507, 35.78479505354358, 28.233953983552997, 42.14292572390649, 82.9045887916319, 68.95533823197889, 22.195676911261774, 7.723888687549099, 0.6877953318818923, 0.4262207694832356, 0.1612883977471821, 0.8555544912815095, 3.643164586636328, 16.53331587391515, 35.79554234781573, 49.79883924607308, 50.20651471230292, 21.686476776676795, 47.50715524919572, 54.684257199687345, 76.69799497050624, 80.19576072692871, 90.52114132911929, 87.57858707058816, 90.26732475526872, 91.98067880445912, 94.65483311683901, 88.43846474924396, 83.24096341286936, 79.92277160767587, 72.97084116166639, 43.153387115847686, 27.234828241409797, 19.95422867036635, 17.309813768632953, 22.825893932773223, 21.454180286776637, 22.828688621521, 14.30331507036763, 24.33726356875512, 35.073375163539765, 30.182871856997092, 22.574981874035252, 4.901899262782067, 6.475385513997848, 5.692348047610253, 0.694308488840057, 0.19610263527401034, 0.16866890413145866, 0.17243021197857397, 0.20778722279975492, 0.2675203852836163, 0.6294829867059185, 0.14401015795526967, 0.9021767024551669, 7.984626283568721, 12.846876267463932, 15.755067621507953, 23.509194351011708, 6.327550401610713, 10.638768173033192, 8.871293260205178, 4.393473796306118, 3.985347502654599, 1.1931098685149224, 0.07753238802955997, 0.7415110269381154, 0.8746034820233622, 0.5918682534848491, 2.6987772362847484, 0.48855676165511536, 0.3478763895409723, 0.3896913683462528, 0.2601675653169232, 0.464378597755586, 1.972473422365804, 2.9550026357173924, 7.084628151309106, 18.49217107219081, 37.04430733957599, 47.63151007313883, 42.40342209416051, 31.374485954161617, 30.39500540302646, 27.735255995104392, 29.11367101054038, 21.52060954801498, 29.960928463166763, 42.97247171401978, 52.06039159528671, 59.20052520690426, 62.87273837674049, 62.191524659433675, 60.14531435505037, 55.74272055779734, 56.169141031080684, 55.93093549051593, 59.95218861487604, 62.09958038022442, 67.86942220503285, 73.32107743909283, 76.24534560788062, 76.2083968808574, 85.68400382995607, 69.9692238530805, 44.1509242980711, 48.70983631380143, 57.39581915640063, 39.122390823979536, 43.076159569524954, 24.698490327404393, 0.6592505281009983, 0.7006626672321751, 0.2798081291539054, 0.562784552814499, 0.1937928955040632, 0.36633586030333276, 1.9624147492070354, 20.86497360660184, 40.334403207225186, 33.03093425689205, 52.551613546186886, 58.50963108001217, 47.91055533193773, 53.78468905725787, 53.26422975909326, 13.864755841993517, 0.20499631852632572, 0.1804635478484054, 0.05509839565943807, 0.020195757331807288, 0.044475889449278196, 0.08789837735915378, 0.10833171962369835, 0.07187120511286682, 0.03222253909634967, 0.07262233900086534, 0.01606021649129088, 0.033826757853309956, 0.046119515769063466, 0.06100040214556841, 0.07104039808074314, 0.03656066135473309, 0.04529190332358403, 0.09240486659109594, 0.09436912368983032, 0.045785352046931946, 0.05605764882338624, 0.20690795304554127, 0.08362534576125684, 0.10725923483410191, 0.05308256935208075, 0.04431406486659281, 0.06508867631876661, 0.040556395937117844, 0.011676553178638702, 0.12843075643984542, 0.1636657677590847, 0.04094445394472249, 0.02292210529107721, 0.07175181797074695, 0.0835060352279294, 0.03741709402792397, 0.09763397591849489, 0.06379485340608705, 0.009306174676655041, 0.03479878553339551, 0.149560158531512, 0.04882032427215769, 1.0320856638493077, 10.462116387582595, 74.90768401853501, 83.69615447136664, 75.22352110955023, 92.76128538193242, 73.66487318469633, 43.79931519108434, 35.593065677150605, 37.15012504208473, 55.81325261823593, 93.91584288689398, 72.82794137154856, 23.935650125626598, 7.826756277391988, 0.8261000040558077, 0.33873925886807904, 0.133921638010971, 0.9530963604488681, 16.3445645570755, 22.561080994144564, 30.486512337961507, 51.42639929248441, 52.527396832743, 26.110478870330322, 31.994932351573823, 40.61864560650241, 52.76515130073794, 65.52480974505025, 69.15430438133978, 79.6154695941556, 79.86529319517075, 87.67538332170056, 86.40002466017201, 81.67992284221035, 69.95865698783629, 69.46145734479352, 68.66334915161133, 44.36604669017177, 25.60506578414671, 23.86027982158046, 20.68418372061945, 25.59973136071236, 20.034690210896155, 24.833515959401286, 15.850528305576695, 25.605779655518074, 38.79328435467136, 42.93209483546596, 29.992070121149865, 3.5989214768332825, 5.383493265798015, 4.750358000878365, 0.6584345525310886, 0.5402058579267994, 0.09537347261944125, 0.08358557813710744, 0.2409567614837039, 0.4855969656378993, 0.43134494774764587, 0.4563321617822494, 0.5399946628078338, 17.15460754209949, 27.15425099095991, 31.071002368004095, 30.58981187881962, 8.246781326109364, 22.441821329055294, 15.196468176380282, 13.744758771311853, 10.83298139033779, 2.1291336224925135, 0.151565516247384, 0.44808053681927346, 1.8772212367865349, 0.49326660892655777, 2.8592953326240664, 0.26240120191247235, 0.18550359433697117, 0.23848395223819444, 0.15076109328337256, 0.6572656249327045, 3.037892858828268, 2.7321281692674084, 8.924981682531296, 28.042683524470178, 47.680151385645715, 54.53418339452436, 41.7555602904289, 28.189060495745753, 27.012170976208104, 25.505586631836433, 28.85663809314851, 22.826484249484157, 22.793599097959458, 37.61417673480126, 49.60545462946738, 58.85769044199298, 65.48906518566993, 65.15501260757446, 63.65981686499811, 60.30160903930665, 57.47875767369425, 60.97112624875961, 62.38371295313682, 64.29869251866495, 66.6489218127343, 72.6190673151324, 72.7985941979193, 76.53636978518578, 81.29513832830614, 64.20119024092152, 50.33780428671068, 55.76420337923112, 60.62379644763086, 46.62168410516555, 49.32237717413133, 33.23200279666532, 0.9750954025695402, 0.35688573674809554, 0.16294011395544777, 1.0817561082301603, 0.10604925258385559, 0.42042592720639327, 1.6217951428505684, 28.30023615590988, 36.69224716001941, 23.767796216472505, 45.16694761091664, 63.42751841391287, 54.34012413024903, 64.02458552391299, 66.16244592974263, 21.08719352752932, 0.12515302627317368, 0.16233072165519963, 0.22055271442138383, 0.06406430951169421, 0.07510143016735393, 0.13118590738984848, 0.08318882886200182, 0.04292510149459686, 0.08154923216469827, 0.041372291067795414, 0.0402110435008522, 0.12060978014262454, 0.026347002863223036, 0.055492582370436964, 0.07142009423865427, 0.06127833884449736, 0.08051076933981911, 0.051895351404504436, 0.048711068642836426, 0.17522618775406193, 0.1372500448938339, 0.31711241290453945, 0.3189599411862512, 0.21334690672736015, 0.24770478567769452, 0.12512184649465546, 0.22734894086757015, 0.18079249068133293, 0.2625936738425686, 0.3138926372893395, 0.41218429202994994, 0.25367271786014883, 0.11691594931987986, 0.25005610870017164, 0.16255414353743677, 0.15685542997333313, 0.19550061273959377, 0.13885533617388818, 0.1755191091327898, 0.15797034837305546, 0.25338436236544964, 0.212150338676668, 1.3999227194055435, 12.928631209558057, 96.1595170728622, 90.86224632878458, 90.30796835499426, 103.02187627361667, 92.03710602175806, 68.91875820775186, 52.69976538996543, 44.321296368875814, 72.58011817932129, 107.15727821473153, 87.99759034187564, 28.396555839046357, 12.224521636962892, 0.9246354586174412, 0.708400093980374, 0.11783273439974555, 3.761189195417589, 11.210817425481736, 23.492943971387803, 50.96996092027234, 61.23867111821329, 64.4805375222237, 29.86050598083004, 57.8135633468628, 62.90526659257951, 79.65253599228399, 78.52229718239077, 87.33440383788079, 81.7428219702936, 85.31586585506317, 92.97353267669679, 99.95295109287386, 90.55768212964459, 78.71504245265838, 78.18520084504159, 80.22126397778912, 51.01111442812028, 36.90080350445163, 29.40344983531583, 26.051090263551284, 34.55335909320463, 30.30951930630592, 33.50764736052483, 22.034822471680183, 34.10858977225519, 41.67987031321372, 43.629990393115634, 37.69996681521016, 12.083501642750157, 19.375063257832682, 18.788904259281775, 2.5672415331486733, 0.547887145751907, 0.5333992586501184, 0.4035584790812385, 0.48649632221748756, 0.9333018742261395, 0.6275761019318336, 0.6700956977663503, 0.6975533308521394, 26.182001329237416, 38.07029347265921, 44.78575598809027, 36.41518269815753, 13.092242094778246, 36.00149423845353, 28.508202183631163, 25.429010198962306, 16.18698431599525, 2.12046199748593, 0.1556721305654895, 1.6571116735858302, 3.009580945776355, 1.0050297059839772, 5.897940551081012, 0.6471842755713771, 0.6979558640910734, 0.5928544231480168, 1.1830731361143052, 1.5304432641113959, 3.251109959617738, 8.460149438150468, 18.0241342513792, 37.35894810768866, 43.36498721953362, 54.60648444391067, 48.151349636816214, 40.64909104377993, 39.81046084434756, 34.56258843022008, 34.94525094186106, 27.969394037800452, 36.70873288185366, 52.07793635706748, 54.19757343107655, 62.20707685716691, 65.36707555094074, 65.9875709779801, 59.265444355626265, 58.35862767311835, 56.869950909768384, 59.96572863671088, 61.65989445101831, 65.40285148928243, 69.66896641638972, 79.78840689505301, 73.91110389463364, 79.39624832522485, 90.51971358637657, 77.37847128222066, 57.671824578315984, 65.82408658919796, 69.67148457804035, 53.55290835903537, 54.229066141190074, 41.075021220791726, 1.7570101517823435, 0.6290116281278673, 0.526928267171306, 2.2278535510263135, 0.3877609187076169, 1.1766113989776181, 2.355313421257081, 33.592460770760816, 51.20439314073133, 45.34454468757876, 66.87329707607147, 70.52973055070447, 67.26830328664472, 70.71421530938917, 77.58252866806524, 21.679222353043098, 0.24407473933552545, 0.3151675608129271, 0.33060790970921516, 0.17416815904359664, 0.2023712722885032, 0.3623636637724215, 0.18341470239383562, 0.09179430983720288, 0.2454648671611663, 0.1308774191044992, 0.17334177999967532, 0.33801558157128675, 0.16491876584627937, 0.1458313174906277, 0.17160760208724007, 0.16518115096034544, 0.15644822359806107, 0.22141031920909884, 0.16134583901974464], [0.06354737253258787, 0.02907939908665515, 0.09954618500365366, 0.01243628831880708, 0.038578977447844325, 0.07576531430165614, 0.0465606177045453, 0.0532206911743889, 0.09388052813348272, 0.028100099316948367, 0.12380750774736367, 0.07501536784994026, 0.0708261615927181, 0.05155738788626848, 0.05612078595966582, 0.11099944461978252, 0.03192508822276948, 0.0740848621353507, 0.0772984400992432, 0.07091600072359847, 0.09262480277327761, 0.07789496212236344, 0.1130086251143967, 0.015204308588328141, 2.490473394432376, 51.54787901909121, 86.17263701654251, 86.16283893585206, 88.13564208246048, 83.11562799638318, 52.658674640040246, 44.678569378391394, 36.79800994934575, 38.689549430724114, 57.67636276060536, 14.099577357692105, 1.4020197165589179, 0.45537308098808416, 0.10919888518870839, 0.1461364656326271, 0.5945778145424782, 2.0245876259380773, 4.1683508311548545, 36.31933566062681, 42.162270853596354, 64.05155574121784, 31.00880926655185, 46.56222881809358, 78.3173062724452, 90.5781961256458, 92.12772846221925, 70.82132739405479, 79.2540624064784, 78.06375641976634, 80.60248697957685, 77.89797352206323, 87.89204720527896, 84.05051708221436, 81.51137859590592, 75.50455108765634, 67.0359734565981, 64.06349935839253, 50.99271458964194, 41.41755788556991, 31.431638809942434, 22.658024334138442, 26.624597657111387, 24.11803053271386, 26.72837180476035, 29.01359958033408, 37.73098491853283, 33.94773729385869, 14.080597989020811, 2.3861263355901166, 3.8763365005293204, 1.1795181204234402, 0.5206111674347232, 0.4365883292930742, 0.0619078639353956, 0.05542535815508135, 0.11317388560142248, 0.17363102415636664, 0.5734585477940498, 0.10548941851142915, 0.4245684710481475, 3.970532955661897, 30.1878160045993, 16.804063358614524, 21.255484780957623, 6.424870779437404, 13.53881766719203, 9.830114687642745, 6.461717524836141, 12.232916489724191, 0.5958938923093581, 1.0459950013506798, 0.1262403808293804, 1.221967113594855, 0.39930022531940096, 1.9481688233152514, 0.16678354642804594, 0.3210408504932158, 0.12356193826323557, 0.4613470346216233, 0.8631140630572074, 0.9561144404353635, 3.4270331648088272, 6.461149271457426, 18.19159984588623, 32.39243318957667, 51.89850753353488, 40.440640603342366, 32.084431032980646, 29.18809602337499, 29.017043421345374, 26.552127945807676, 31.99074326022979, 54.566535103705625, 59.856749503843254, 62.00643585574243, 66.61815474110266, 63.65875390268142, 65.19318903646162, 57.81716800505116, 64.44118830465501, 58.48581444832587, 63.40125030086887, 64.32237578976539, 66.72123462923112, 67.62326994249898, 72.0122766494751, 73.0381098101216, 72.8503381052325, 76.80042374518611, 80.96896186951669, 57.515541661170225, 53.58550325516732, 48.657202028459125, 51.24110260317403, 40.04693661966632, 38.50392326231926, 2.1108323335647583, 0.28366507541748787, 0.5015057619781264, 0.00818321043850794, 0.3080515539453876, 0.1598598735947763, 0.8779960257872459, 11.992088844699245, 34.91170290977725, 43.77295686352638, 54.181801580613666, 65.33029156346475, 61.969134115403705, 61.40051987863357, 34.91155778208087, 1.8917796039773573, 0.12824617521536927, 0.08889035396878758, 0.013247301554187171, 0.07616629238210379, 0.01745025908965017, 0.15609085890314273, 0.01883623280352162, 0.08847593104526882, 0.06315369910049824, 0.11102647220175113, 0.1965754034538423, 0.08380854802746927, 0.046291491016745574, 0.029100648450454878, 0.1491518336678705, 0.04931132534458753, 0.036911893515817584, 0.057827032306381775, 0.022372383579251268, 0.043788792850870284, 0.012410716303894597, 0.23021193401467419, 0.08430222274675485, 0.029717780153958068, 0.10802567515882755, 0.10920794800885263, 0.10121600386957008, 0.027568826917558912, 0.09157886293025748, 0.025175916812112255, 0.052924904626824205, 0.024831531561851024, 0.0664070217059024, 0.11031355844029497, 0.10789478137608498, 0.013982678928803054, 0.015808268367583235, 0.09041359723215142, 0.0493891024211001, 0.08374860930827357, 0.061720727807691986, 0.13491952881938027, 0.3172467234394243, 3.8469253432366157, 74.33744199814336, 89.6377686531313, 98.03428449938374, 99.58413847031133, 84.97598463489165, 51.93391476908038, 30.45604728883313, 40.71652443178239, 53.340778735376176, 67.46785779153147, 13.498295660941833, 1.2466883419021484, 0.6190198191231298, 0.12701861124726074, 0.10465773813907178, 0.6287705862233717, 5.144909216511635, 8.315130587547056, 16.275662241443513, 43.07641060121598, 57.68782784861904, 42.756800190094985, 40.96693638832339, 56.0210362557442, 72.4409132619058, 78.86749713651596, 64.108830190474, 74.73571946544033, 76.91316050867881, 81.61601958736297, 78.77605884305893, 86.98137483289166, 78.56030494936051, 73.7088978675104, 71.70986190918954, 66.91345430189564, 62.0494407223117, 49.12238336378529, 35.29909972221621, 27.815660661266698, 23.56424285519508, 23.57701409247614, 23.718637151102868, 24.838866072316325, 33.90278300931377, 41.04609766314107, 43.17076713808122, 22.455108358014016, 3.555068642862382, 1.9025120667872892, 2.1069151115032936, 0.5666866982656141, 0.06624493282288313, 0.04549353383481503, 0.07850989323830412, 0.10885109659284355, 0.08656595127596971, 0.482960979664518, 0.2542051183240068, 0.08112039912732379, 5.310641613698775, 38.79878351765294, 26.218744131826586, 25.8199312610011, 8.079615302624243, 25.118505570196337, 19.213298828371112, 16.949610748598655, 14.733407862724798, 2.5591739531486266, 2.2780826880085856, 0.7531661047570167, 1.3558088026700483, 2.3713662114835556, 2.788731893224101, 0.10696449016611423, 0.45387013905471374, 0.045683519809596965, 0.649168933591535, 0.6821677725641959, 1.7010510448486575, 1.4344566147173605, 7.763284973559841, 22.68500239618363, 42.19776830365581, 54.47504974180653, 36.11800824442218, 30.62675472228758, 28.692365307961744, 28.03476425909227, 26.069388120405137, 21.735127895109116, 39.89331306949739, 57.02904224395753, 60.55303688972228, 65.67302434675156, 62.94840481973464, 67.08292422756072, 61.26200922073857, 63.637992797359345, 60.94623488764609, 64.62493958011751, 66.30140766020745, 65.966900087172, 65.78463931237498, 70.8515453338623, 73.33053035120811, 74.43963543061288, 77.27818412165489, 76.18563928911763, 61.76029928268925, 58.24543983705583, 55.36706339928412, 55.971037803157685, 43.64902565556188, 45.93372783353252, 6.3105214315076035, 0.016924807043265433, 0.7334723131310555, 0.11874656238022352, 0.1944341570619614, 0.03268444031897572, 1.4158090540478308, 15.115849741043585, 31.46107227571549, 35.53233954214281, 60.55077760450302, 71.05135087044009, 72.55112401900753, 69.41752679886358, 51.15230798721314, 4.261496336229386, 0.06405084168598538, 0.23221939081145873, 0.02588482584894425, 0.08978636274414678, 0.01907627304805623, 0.05299396745319809, 0.03383230816032137, 0.06887024719147913, 0.023122502400750117, 0.056750448946390426, 0.07541062325359353, 0.09442415944631062, 0.104761834166223, 0.06444446532235992, 0.04758318420499564, 0.037735196716722944, 0.05391726428042016, 0.12410987499019793, 0.10330912461804767, 0.18899264985755568, 0.1737863867874107, 0.4068047000515846, 0.26377871993087953, 0.13937046901593286, 0.174604875125712, 0.20244861652533855, 0.23710839540487338, 0.15341215586710363, 0.2041879731921419, 0.125057908796495, 0.1839925318716034, 0.13954640876862312, 0.23234423249959948, 0.2953692441505771, 0.42770685748227183, 0.155259576896506, 0.09978318196390906, 0.24631214508366203, 0.1925237482834247, 0.2119887094464033, 0.1629770087498811, 0.2479720584327175, 0.2982420738666289, 3.6823748052120213, 96.69110021283551, 94.32228672888972, 104.2603881897465, 107.31520068260932, 103.56470877124418, 71.83590335230674, 61.431239881823146, 53.680016686839444, 62.24294301002257, 85.27490846572384, 18.77985535129424, 1.774042921681558, 1.161649150233115, 0.22258022740002603, 0.5218886343702194, 0.5891407353262748, 10.616943124801884, 7.852264921511374, 47.677778351691465, 56.13132153787921, 76.71573192842546, 45.355986241371404, 58.871301066490915, 89.92884774361887, 92.36302360411614, 89.95457849194928, 66.74057191418063, 78.46311646123087, 77.30375013043805, 84.95990291718515, 80.9472946966848, 90.61815723296135, 79.8093209728118, 77.1211402646957, 71.82048843752953, 65.7618817206352, 63.845686220353656, 58.17542160710981, 53.137737243406235, 44.85776285971365, 31.298235078011793, 36.132242525777514, 33.615814562766786, 37.601817346388295, 38.15861740419942, 40.84394262683007, 45.587696336930804, 30.488918712062222, 8.933612858095477, 8.597676561724755, 2.040898066855246, 0.8078722595687836, 0.5430259807936607, 0.1066086882905614, 0.19244193009311156, 0.345352252404536, 0.48192323696228767, 1.522571802619965, 0.2525770435890844, 0.7238268984421607, 11.32812669200282, 49.143340587615974, 34.883485378757605, 33.612162836136356, 13.504727367431888, 39.16827078788511, 30.91111283148489, 28.93010800884616, 21.655921513034453, 3.1203427958873013, 3.4668405642432556, 1.3313725590705874, 1.8707610931127303, 5.091114399894591, 7.699398388785701, 0.4992943112888644, 0.5113155484920548, 0.28707281836578924, 1.2434876878415386, 2.252232062239801, 1.359651744846375, 9.162030123895216, 14.210854999480711, 34.88320689047537, 44.4325622435539, 59.4908590470591, 44.22499433640511, 38.683607039913056, 36.841497267446215, 34.43489959163051, 33.0116871864565, 38.8961838137719, 63.2831673468313, 65.27504890195786, 59.80054978401431, 64.23099633186095, 62.13521511323991, 64.33468810973629, 57.24905583166308, 65.23273437253891, 59.74767231172132, 67.49543205384286, 66.27237427619197, 68.97662101253387, 68.88907371028778, 70.36854467084332, 75.08869355724704, 74.74958112162929, 82.03235564693328, 86.10680395557036, 68.71985481631371, 65.9563724456295, 60.27356801494476, 63.05277909001997, 52.633536169605875, 51.96339138092534, 9.567744405038896, 0.8076442718025177, 1.3623019187681138, 0.6088405943685963, 0.5172987258242023, 0.6513182085848624, 1.6090670516414027, 19.112739063078358, 43.96052068279636, 55.49840004213395, 71.78872508387413, 78.89691491280833, 78.43453807215538, 74.38414173741495, 58.43089734354327, 3.6638952935895617, 0.15296427022305228, 0.22844862943935781, 0.1921205562088759, 0.3616176167082402, 0.20075136405085364, 0.27808265400029, 0.09366617673226903, 0.22283911915315738, 0.1259839099140898, 0.1958151071542694, 0.17785330242928, 0.21234245820631906, 0.15188275325682857, 0.14313785960116696, 0.2681002525552627, 0.09048743278629358, 0.12299039836732611, 0.24358344714968438, 0.18634685795874367], [0.19241853376790402, 0.05666164786464745, 0.12192252542703383, 0.07121182557555937, 0.0356522687680779, 0.046240672574288426, 0.028077811904011235, 0.013100791069108152, 0.0451154311397864, 0.026546425126012296, 0.030375003153758667, 0.0210720450887757, 0.06048292507447543, 0.07342073285291273, 0.1039334939372155, 0.0686529693343947, 0.03368673230250997, 0.06116762764811997, 0.0794482590149968, 0.022841738837380565, 0.062357032776720105, 0.07189141451230935, 0.05006584917165099, 0.2753534504482823, 0.394813493495026, 38.27975196223105, 92.03606267129221, 71.6760903020059, 70.3306467302384, 91.4661579747354, 65.71688036764822, 59.8483830882657, 40.62712577081496, 37.5436838980644, 17.544481331302276, 1.4647803359454679, 0.21086567051468358, 0.20789910228021685, 0.7527439596672213, 0.7491089643970613, 1.5283194232371546, 2.039749670413233, 48.10661108263078, 48.580221591457246, 46.97951016887542, 78.73904735811296, 40.50181781091998, 69.61543390827795, 97.6347283394106, 82.12128362348004, 71.61181834436232, 69.67448126885199, 66.60565022499331, 79.58813067405455, 81.46234896875198, 77.49985294957315, 71.30304936439761, 78.57066000661543, 75.45676092947684, 70.15309672201835, 71.55934487619709, 71.29128225388067, 64.74436790712419, 64.74859622216994, 52.87870391722649, 31.76458331846422, 32.35512948805286, 40.14419963282924, 29.828679869251868, 24.13522424236421, 41.35223473272016, 39.630282848112046, 18.135692342635124, 3.1347479454932676, 2.9844444365270677, 0.14890196643048717, 0.7661288027321139, 0.43091121940843524, 0.002204915959267847, 0.02379525974843531, 0.648105297117464, 0.262000139562353, 0.14559387619937622, 0.03912092336723882, 0.707476927388099, 0.8704089361333078, 12.59150153206241, 15.916931090816377, 22.629808764303885, 4.8104845035460695, 19.61435333375008, 13.099926998538356, 5.774224583179721, 11.975527617239184, 3.159162248334577, 0.9018712478779978, 0.2619037963449955, 0.34755699216358127, 0.4556026009301986, 0.5043226366321887, 0.010093627835533792, 0.19578657803996918, 0.04643583347299888, 0.12305875639280967, 0.5362074918323948, 2.9960767155693424, 4.548213751085343, 10.066168808167982, 17.245049553532755, 30.194299682494137, 55.35768108983194, 45.37710820474933, 25.23153651145197, 30.04164299657268, 26.822396901346025, 30.96933649432275, 52.60522057933193, 62.04928382750481, 66.76689101803687, 66.83344579512074, 64.1947614762091, 65.58018184477284, 63.83760613779869, 62.20185618246756, 62.219977532663655, 59.828437835939475, 62.25888352240286, 65.98098924083095, 68.71529702217349, 67.18691410556917, 69.73210873142366, 69.16176472940754, 68.48266124725342, 69.43705235758136, 75.0107874408845, 67.29671693617298, 50.776595915517504, 54.917124394447576, 44.73163120208248, 48.326012780589444, 38.47720799907562, 5.504378753323709, 1.1475772795177277, 1.44295577801043, 0.36237405192467476, 0.12265356482877848, 0.06642983580428748, 0.28841767039510513, 6.300882697105409, 29.402936004823257, 36.88176039726504, 59.098037596671816, 58.078586132295676, 51.41259254947786, 54.472762999996064, 12.369546371121562, 0.09462122024307329, 0.02762544273038305, 0.031450793612748384, 0.01895401499144012, 0.045701515214938315, 0.13570516730748838, 0.11773489731093568, 0.08097118818231168, 0.03211253078564281, 0.23123103013682753, 0.06925663129696924, 0.06469740457231961, 0.019069462526409377, 0.040501884950865666, 0.05841315851636952, 0.05896658043286974, 0.04296963418563528, 0.022792816462536013, 0.04243480522305735, 0.061266713460246404, 0.13897973353103285, 0.07576451757021489, 0.06492204453435636, 0.056291746140848246, 0.05282308005036847, 0.025108252096200184, 0.041386095972190944, 0.03680582098182171, 0.049716792700271455, 0.023723303024927457, 0.01257471657628494, 0.03020894593529163, 0.04090858570810768, 0.10731738856843404, 0.15484653293125092, 0.04605827086995687, 0.08491996540537766, 0.10273602956365194, 0.1375462604506362, 0.01877863256771478, 0.026300018690826914, 0.0318559545332626, 0.31119965437439184, 0.28441945751828535, 0.9082750074805752, 51.07228771332772, 102.40800180742818, 75.90113409103887, 84.66837667649793, 88.05739079752277, 64.32840839509042, 40.880393212841405, 35.20311540172946, 51.70157709429341, 20.00754152574847, 1.7010503094042502, 0.017930234241629803, 0.20130199740730947, 0.4436743974445328, 2.082979828119278, 3.911560610417397, 7.149423745370681, 27.109490863738525, 35.025737977796986, 46.56949304765271, 74.64999998769453, 44.18630407702538, 62.55641491182389, 84.37779964939241, 75.62601904715262, 75.74221534113731, 69.73455629041119, 69.2374272500315, 78.66029400979319, 82.6893134270945, 75.74207413581111, 70.67204983003678, 74.51385451901344, 70.9270352701987, 68.69544982910156, 71.64217748949605, 70.9064349820537, 64.368506785362, 56.74432916025962, 38.37130792679326, 28.886718750000004, 18.444945735316125, 33.125153510801255, 27.876933966913533, 29.715564597037535, 44.50696960572274, 51.5171629382718, 25.662781500047256, 4.32512600575724, 0.49290366711155065, 0.3905918280924521, 0.8312775939702989, 0.22316614676627422, 0.04401412995291814, 0.08781292791207952, 0.3616371059850339, 0.3370468787127926, 0.03763003199691734, 0.088806061314479, 0.41992787812506005, 1.0538478315837922, 15.354162166195533, 24.56689088575302, 28.105047249024917, 5.099556811394231, 27.3688889703443, 24.2506694024609, 16.33644328963372, 7.388000440212989, 3.6449647093972857, 2.451599273950823, 0.4278359586192716, 0.2884586714208126, 0.6027693782121905, 0.1309744211574716, 0.1748899824076122, 0.23207277690450992, 0.016730580771822604, 0.35831688092120234, 0.2850499172364512, 4.2627887572011645, 1.9545365461418707, 10.222710601745113, 20.67458175843762, 35.28964288773076, 60.056225561326556, 42.71901207585489, 27.337039324545092, 29.23083612995763, 14.594333364117531, 17.248693435422837, 42.66167879104615, 55.459599956389404, 62.16494275677589, 65.26015958478375, 64.80922429792344, 68.01783684761294, 64.8736806069651, 60.637764007814475, 63.27268677373087, 60.77315638142248, 62.6141639678709, 65.17832325350854, 69.67794079934397, 69.51412693146737, 72.37969290825629, 70.32551627005301, 69.03908867989817, 72.49491645443824, 71.44317996117377, 65.41432834440663, 54.147751485147786, 58.14726683401293, 51.43797420686292, 51.80539438801428, 52.21956529924947, 11.494087076956227, 1.4180140389550118, 3.807375349344746, 0.0228387204509589, 0.22056533955037597, 0.07056656503869642, 0.9540254718834354, 10.29586966960661, 37.0694536547507, 36.908942422559186, 62.18155399445565, 67.52951745064028, 57.91171281568466, 66.14197900218349, 20.489424313268355, 0.07915575898462728, 0.012273708181906373, 0.06571009619942596, 0.010049518408073534, 0.04681091778160584, 0.09265071186687678, 0.013178925334115424, 0.05586391667865458, 0.09562850328943423, 0.20700164559868076, 0.14400643476795766, 0.09245502236749857, 0.040998922796138836, 0.04251566197302553, 0.1698099001641235, 0.03178680552199724, 0.024209025751559005, 0.06027759052813054, 0.09608817136576099, 0.06685082410131732, 0.2747398446644506, 0.3276313210446989, 0.2563453688015861, 0.149075178910167, 0.15097256419399094, 0.27816520763501046, 0.09630469079580038, 0.1849338241041668, 0.14325024469965889, 0.18555536655889404, 0.14335550518045503, 0.06496541277174989, 0.21787771925089822, 0.2462885342538357, 0.2735179037817063, 0.2559791328085046, 0.20474447478209773, 0.3293584509482307, 0.22809325657304258, 0.16401628362796, 0.21528716229142683, 0.14758688457790883, 0.26675282647052123, 0.3500143877200542, 0.9845910317474796, 56.78605533415272, 121.8492687902143, 86.9087403820407, 89.7710664810673, 107.7598640995641, 85.67667684247418, 75.96380572165214, 61.32457102498701, 60.73315212803503, 28.149742657138457, 2.2304675655980266, 0.7716361781762493, 0.5945103375181076, 1.913785326384729, 3.1969305055756725, 9.20838567518419, 9.4943941216315, 56.17301633281093, 65.36711085227229, 59.907646179199226, 96.56231311059769, 54.25476158818891, 81.85205213485226, 103.00508068453883, 82.29467591931744, 73.60285266753166, 69.45060022415655, 65.23602131874331, 78.4820536644228, 83.1038922648276, 77.53063571068549, 70.2227815504997, 74.38733454673522, 72.31911582331504, 65.66911374368976, 69.81417256016886, 71.29045855614447, 67.44055809513216, 69.50337963719522, 63.94443188944171, 47.65888821694159, 40.98746215143512, 53.807929100528845, 36.800029969984486, 37.04232654263897, 45.1606757410111, 54.73032935973137, 33.82641838442895, 9.317634471001165, 2.026911385117039, 0.6494985352600775, 1.8488892215874888, 0.7910747705928741, 0.16545682003901852, 0.1993568388805274, 1.359613134014991, 1.5327787904008743, 0.31574212675613744, 0.16966046705361337, 2.001569932026248, 1.4668881196168162, 31.860704921906997, 33.60600079259565, 34.56663239386774, 7.9862923102994126, 40.97229826834894, 36.024793117277085, 29.397934982853553, 17.8051051785869, 8.075755200078412, 4.6918690877576035, 0.925619483234421, 0.6810533291389865, 0.7211810146127978, 0.880804626691726, 0.15461203341762866, 0.5953883355663669, 0.13272474820335067, 1.0510867281306175, 0.925598277920677, 3.7914179217430855, 5.756068912244612, 18.63927956550352, 34.08786789063485, 40.508874154859974, 65.21715471821447, 50.45594999867101, 33.2937369808074, 38.56561822275962, 35.243221636741396, 39.69762209923037, 62.02887573549825, 66.12899595691313, 62.543949619416274, 64.85142507860738, 62.57875280995523, 67.83890616509223, 63.888922506763095, 62.72554751365416, 64.11817719859462, 62.0930653233682, 62.97628110454929, 66.09216490099507, 69.76424863261562, 67.71210378216159, 71.38549758541969, 69.28070668251284, 70.41278116164669, 75.29209198490267, 74.35219795473161, 71.00490216285952, 62.42423888175719, 67.42354285332465, 56.62235521501111, 61.08199988642047, 53.762880679099794, 12.598981491981014, 4.649847755509039, 6.201382462055453, 0.709921483310961, 0.5819751778917929, 0.16226810162826893, 2.0446582715357504, 12.761489210590241, 44.53059011890043, 46.54016156350413, 74.5431467794603, 77.19986223405408, 68.64747924189415, 77.74922155564832, 20.98976185244899, 0.2750466169128495, 0.108349125141338, 0.35026468396667515, 0.14576108254972966, 0.1321310147402748, 0.18704408990038981, 0.2676148898899555, 0.2069969264970672, 0.14937410641822124, 0.35418398978729404, 0.15295184427692046, 0.28114311397075653, 0.2031756799307562, 0.18748744030392941, 0.258104429249802, 0.12747386665714364, 0.13871230755842504, 0.18102947231982985, 0.2766817856219507, 0.21795448126091113], [0.03173309318240612, 0.020916759066524047, 0.005293338138970637, 0.006756017363870577, 0.04566368196279772, 0.05065852543339134, 0.1920826501783825, 0.04919678370858874, 0.013350518495445291, 0.06046672614531652, 0.04103425477120665, 0.026946219600616928, 0.03430681535974145, 0.07804490851178285, 0.10433266405016185, 0.059882982468773285, 0.014760429584120792, 0.10010194348832292, 0.06971659048670723, 0.06145451225400452, 0.02910706635204054, 0.05366930843240792, 0.08000711249488016, 0.021218272121322733, 0.36971188721156895, 2.9208603645524676, 100.14215838524603, 72.74148448821038, 57.30041142432921, 92.22163784888484, 73.8559945937126, 52.6986357473558, 57.20193639878304, 35.35847656188473, 2.3988585943175904, 0.2545015943507033, 0.10779387227469876, 0.5465372375422909, 0.07716225264894386, 0.29619122584981306, 1.4784409706631017, 11.056719268521956, 81.5148381263979, 45.11464672703897, 67.10001007203134, 66.29903854862337, 53.09617580906038, 83.613078671117, 77.80998691435784, 75.04937571863975, 74.5667516031573, 72.53372438492315, 72.25624022945281, 74.17563638379498, 76.3585844347554, 72.02962921511742, 78.80020495383971, 75.61068257977887, 71.37191049514279, 71.61780388124528, 74.29793588576779, 71.81896655790268, 61.603463311349195, 70.79737740178263, 80.43450755457725, 50.46998423914756, 37.96071029478504, 42.98202660775954, 27.654137457570723, 31.227867757120443, 46.174851617505475, 38.14643844481438, 14.427259026035188, 3.56142655976357, 1.506374252419318, 0.17095527821971526, 0.3534115586550005, 0.22904853757110336, 0.05697896531332405, 0.17194763787331122, 0.5949496429774069, 0.318035977862535, 0.16714080387065489, 0.24909195640394766, 0.08101666316149697, 0.029366203253307653, 7.254744777756353, 9.43182937560543, 20.497306316129624, 4.946422576904297, 18.87567493223375, 17.353956122552198, 5.633387959772541, 4.62703574088312, 0.4258680319593799, 0.04644652039954259, 0.3670157480143732, 0.5545310892405049, 1.3270336822155984, 0.10981880353703616, 0.15791253937828928, 0.23289388526351223, 0.23541593864079446, 0.07042097768956615, 0.589992318662905, 2.8941754996776585, 3.5699986546270313, 8.62442026215215, 18.433929758687174, 28.34856563998807, 45.50819381590813, 33.38029584577007, 27.799928034505538, 35.575807248392415, 97.78489235908755, 69.02019070040795, 46.265756468619074, 66.80693057275587, 62.29336900095787, 65.01387003929385, 60.597261613415135, 62.06491447264149, 69.30472727744811, 68.01747598955708, 61.96833787425872, 64.48779782941266, 68.09236188088694, 69.92214756627237, 65.9953058919599, 64.1682227196232, 64.22631694424537, 67.48894445357784, 71.42949873401274, 70.41234970092773, 73.89137437266689, 75.80342000530612, 57.99018767572219, 46.5444447917323, 53.67512549123457, 55.01642311772993, 51.72724900707122, 7.403173638928322, 0.47170834315399973, 2.268144137436344, 0.9638804269413795, 0.11390668700539297, 0.22062995140590977, 0.18938179187957319, 4.681220343036037, 26.63861228573707, 42.783209508465184, 68.33646666619086, 54.37419775993594, 52.99175054796281, 41.326680491047526, 0.48302888569812624, 0.06414667545487324, 0.11319109193620183, 0.03513171585396894, 0.07207034966878353, 0.06292483033311945, 0.02191651912946855, 0.12101679499591551, 0.036837996674641486, 0.114793035412027, 0.08413255725416445, 0.05370346063207235, 0.04291536451707925, 0.07465036525841683, 0.012092553285671579, 0.033650611256880146, 0.02257498127648667, 0.058736688938112035, 0.09202658769584472, 0.03391470857745698, 0.07686761523326559, 0.05229627202835776, 0.03097141983978931, 0.04739862596315723, 0.020602398717235175, 0.07577374892970247, 0.07247507391918091, 0.09824183604289448, 0.03319423735862778, 0.025576787640250502, 0.01009511979176633, 0.02627651128287037, 0.05491752996139469, 0.05254607797870713, 0.05248410529607246, 0.04295522024133994, 0.01676945973397984, 0.045723475125287814, 0.05988441505319169, 0.06600340828299522, 0.04013896611849627, 0.055699678919007706, 0.11175171997878822, 0.08966878356952822, 0.08376811390682574, 0.48428122494970605, 7.148919720803538, 112.72780479923372, 77.24437329076952, 70.5557123307259, 98.04175269219184, 74.20665448711765, 46.344360766872285, 37.783964372450306, 45.724881233707556, 3.4669018512771976, 0.29542777326799213, 0.03188681830051205, 0.6072291130981138, 0.17387076371139096, 0.8664590480827516, 3.6416503066016785, 16.79135880162639, 83.95198714348578, 53.73766768363215, 72.09714889526367, 69.50375618473177, 54.399732389757716, 73.6378715884301, 75.23337410342309, 75.44458589246197, 78.03649594706874, 74.56417852832426, 75.81601081355926, 77.98101009861116, 77.80702160250756, 71.96094066865983, 78.74545651097452, 75.25760650634766, 69.03348753529211, 69.67054320919898, 75.82013714698054, 73.59112478071644, 63.60865346847042, 69.13684198933264, 65.11833844646331, 38.84734638275639, 33.15034689441804, 47.5976796304026, 26.579655139676987, 33.088294998292, 49.814752301862164, 52.203558106576246, 23.527137233364968, 6.590799785429432, 0.9276396877342655, 0.5893616750836372, 0.5601422849201387, 0.060824516019032854, 0.05799555632796499, 0.7819093559538165, 0.19144845195114615, 1.269525851934187, 0.7629671272250914, 0.23454717961290192, 0.19662029620620514, 0.5891602246030685, 3.8482991533894695, 22.59165390845268, 25.4591045841094, 6.43037925804815, 30.365216962752807, 27.287803772957098, 16.5497584496775, 3.199483233113443, 0.8822727575898172, 0.1620896644289455, 1.1016211971159906, 0.6742835633697049, 1.954743696316596, 0.13620697021965059, 0.0842756165131446, 0.03234846479890328, 0.3284901056078173, 0.11104626791371454, 0.6935954142001368, 4.348064516821216, 0.19857207373265298, 10.05013023653338, 19.503075691961474, 31.866060918377293, 56.79676732709331, 34.57878389666158, 28.340307089590258, 37.42277683750276, 78.57248783111572, 49.57802941722255, 39.020487646902765, 62.85381294065907, 63.903843202898585, 66.93792204703054, 58.033537710866625, 61.863288956303755, 69.73011616737612, 69.60973862678775, 62.12449527555897, 65.79874415551463, 69.90149236494496, 68.12904388673844, 67.24650275322699, 66.33229240294426, 66.79318658767208, 69.27576449609572, 72.88803992732879, 70.81459660683909, 73.09749449453047, 73.33819466252481, 60.73088499807543, 52.0448080185921, 60.142427490603545, 64.56654725536224, 59.90177831342144, 11.949938074234995, 1.1307316802201735, 2.5015070217271007, 1.76361738433761, 0.5201340478754813, 0.32984601994675977, 0.7552343582914722, 14.299980075128618, 34.739416722328436, 40.86422520299112, 75.04381379773541, 65.89654061102098, 60.52431729532058, 58.836835199786776, 2.930710661795832, 0.0336982810779685, 0.11795366903947246, 0.13956422797374188, 0.10488358852002891, 0.028135245515694542, 0.030614922739445206, 0.05321429817066078, 0.08200371382577766, 0.08707863263665669, 0.014180781605142741, 0.08102529697240361, 0.09940589132208018, 0.05860379183544748, 0.03068923709854003, 0.044549885881884445, 0.02208493972918199, 0.02463972421302911, 0.02066960186517287, 0.025115058787407416, 0.03438333988249783, 0.09717588598329215, 0.08618982508778573, 0.21723995105393473, 0.15964726887402997, 0.242069841272408, 0.11552363814365481, 0.525613476432139, 0.20128889730380428, 0.16333457262765977, 0.18317848684326296, 0.22638409909221435, 0.1691172034629891, 0.208108167674753, 0.2050147352800254, 0.24636548012495044, 0.2169319683866155, 0.15364818755657444, 0.22503302642895331, 0.23507194984103405, 0.1827778841458982, 0.24557086308636975, 0.2484259348843367, 0.22370233170447812, 0.11121514433574294, 1.0017130355681143, 5.74790547932348, 126.04811899123655, 93.96844187090474, 82.49419904524281, 114.15371971745645, 91.62917167909684, 71.70477851744621, 80.30316306698708, 48.477992857656176, 5.510923227956218, 0.651172835740351, 0.36770914951639794, 1.3285500460094022, 0.3900924000528551, 1.1493115800042306, 8.683712770861964, 18.76573677985899, 98.71887145503875, 58.289264478991115, 80.61306953430176, 81.77234172821045, 65.16506564232611, 91.68965462715396, 79.5579441132084, 77.64399220866542, 72.87270345995503, 73.50786855143886, 72.40019121477681, 76.79586595104587, 77.18007779890492, 70.71395643295781, 76.95940525301042, 73.50515427127962, 66.22932234118062, 66.89904351388255, 70.89253410216301, 72.01601074587914, 60.7513911493363, 72.84995371295561, 83.7735193006454, 62.01939928916193, 44.658318181191724, 54.80859241177959, 34.96889891162996, 43.93346809571789, 53.74412390493578, 52.85396160617952, 28.941643699522945, 11.742810453138045, 0.5610645934939384, 1.4238912203619558, 1.2710609695603772, 1.0391893213795078, 0.4324199836100302, 1.055836963557428, 2.2629469969580254, 3.9741856628848664, 1.67230767107779, 0.40010118556599467, 0.28569977430085985, 0.41797144278403253, 14.477112350925324, 34.942732780210434, 33.77977748070994, 7.842849271912729, 41.62633388273178, 36.94578132321758, 28.480598503543487, 9.383304753611165, 1.3235314959479918, 0.25152379526726665, 1.0576785163533304, 1.5808889894716203, 3.6285253205607018, 0.14044817086429368, 0.37683086650025466, 0.5074454868032087, 0.4769768830268614, 0.1385499582055115, 0.4870947288169015, 3.5671978371758617, 7.853642163738129, 18.67739715883809, 33.43327922205771, 42.71967887878419, 54.737734794616706, 38.99598067806613, 36.36212479683661, 44.841018261448035, 109.6615860539098, 75.1140477580409, 50.8513209896703, 67.89042257493543, 60.744428942280436, 63.950605700092936, 58.09978262070687, 60.59811276774253, 68.78890422082716, 68.63431576759585, 64.6779308011455, 65.95254421234131, 69.83930710823306, 69.80332328427222, 66.34819369162282, 64.26513664184078, 66.37897645273517, 69.46960803001159, 74.12604978007656, 71.93468432272635, 73.56439775036228, 77.05462471131356, 66.99407469841742, 60.76822988448605, 67.6643136239821, 69.11999148707237, 61.6122611876457, 13.314381607117193, 1.5016964582666275, 6.092968150492638, 3.2314485888327322, 0.6171862949286738, 0.9959274169898803, 1.2692430735595766, 15.922239038252062, 37.21013338335099, 57.20640790077948, 85.57408332824708, 77.40617106037756, 69.92942748531219, 64.26939633584792, 1.9754062520880855, 0.187143957122199, 0.19398395783237873, 0.22492206625400052, 0.19305337550899676, 0.22361960953041432, 0.15768364762827275, 0.23501982521866602, 0.22440769949988013, 0.23061621393407547, 0.13268865014035858, 0.19529107237054458, 0.24326533680000614, 0.18364941641207666, 0.10753355559802825, 0.140997210757867, 0.13961802266778486, 0.1401659900382642, 0.22341943075579984, 0.14716009699529217, 0.16900302571875436], [0.07450461703082246, 0.008545606415869008, 0.06510404404252768, 0.06604385772539724, 0.046984233683155435, 0.0409957665138908, 0.06850835491692828, 0.06254462472673866, 0.11710889622448914, 0.027889063161227013, 0.0363463252752779, 0.11090009833776182, 0.04643769506665488, 0.05853272185871198, 0.09178309430999142, 0.014388591573092968, 0.036838207348820665, 0.004385140904736135, 0.03896608167598325, 0.03595826726767325, 0.06159603550669648, 0.047075930577252185, 0.057188425243141196, 0.049750684430041624, 0.17742040146502758, 0.2531665942120937, 28.81500017258429, 86.90723419189455, 67.05911544061476, 81.69675765498992, 90.64758285399407, 50.06792952937465, 45.17945604939615, 31.598804343131285, 2.138158751110877, 0.5080009618353459, 0.4323810356999598, 0.39138417751077687, 0.1590272739169098, 5.581295942106555, 3.8894960524574405, 22.837849317058442, 53.04507124808527, 45.9020507720209, 62.30904671453661, 62.0390268295042, 67.70338043089836, 90.68777930351996, 83.78653372487715, 80.29396903130316, 79.46384645277455, 78.39718141863423, 73.38422759886711, 75.24536871141004, 80.0778542795489, 79.90868245401691, 77.02538736404912, 74.4849858745452, 68.44289625844648, 70.78415901430192, 75.04036211198377, 73.36407446092176, 69.93193780222248, 70.92891016314107, 75.71835164100894, 66.16571718646635, 25.997983332603212, 19.88586371944797, 27.640048303911765, 29.855838360324984, 46.38522794169765, 38.89176722495787, 15.825290795295471, 2.4984144779943653, 2.6129366553598836, 0.24223010686616747, 0.8495601903527015, 0.1293580828895492, 0.0540828388634949, 0.30484565984337564, 0.022050707090285518, 0.5006856801769426, 1.1619778938831822, 1.0593233377702775, 0.9813094788020658, 0.05041007928910756, 7.866277098655702, 6.0678017331707865, 19.61427684753172, 6.45566923003043, 21.829911970323135, 26.430761967935872, 5.7346772859173445, 5.3132396936416635, 2.0794827899625226, 0.0678986715032689, 0.6050237604687291, 0.6522904660913252, 0.7579713759403076, 1.3345007718570772, 0.5184557637380016, 0.03010029168499093, 0.21674625335201142, 0.1796721330573482, 0.7433557666597829, 3.353937590314496, 2.4565838709954293, 8.29030296494884, 20.189488510931692, 27.311853785668653, 30.269962203118112, 32.97640154438634, 32.72706627845764, 24.34924444844646, 56.11523197543237, 46.00672314243932, 59.091906932092485, 70.89549156927293, 57.01817727858021, 64.929150765942, 64.62565345148887, 63.25847210422639, 62.568868437121, 61.19108100091258, 70.22984181680988, 64.16360608993038, 69.46985121696227, 65.34354917464718, 68.29821571227043, 63.65427455594463, 68.7170228650493, 66.30642829402801, 67.8926504811933, 68.31504268030967, 73.08499782316147, 73.06037318321967, 69.62190581906226, 52.58726789105324, 61.04307820720058, 51.9797751211351, 61.53062097487911, 28.709874768410963, 0.3275020973336312, 0.8968348020026762, 0.14270836006729834, 0.3889534418140689, 0.15674857602965447, 0.6707472402241923, 16.47609829902649, 44.36348146007907, 59.09149116085422, 67.44916377529022, 52.14258093987742, 58.65428024722684, 8.827425472197994, 0.11732115620566953, 0.22178433865549105, 0.060229606610993226, 0.0367309014132667, 0.016267042036258405, 0.020195125309269757, 0.011670330629473733, 0.0718333833520451, 0.03926129365760473, 0.19379626629093002, 0.04967880240010639, 0.04181306741590943, 0.0422068557611877, 0.07814507450788252, 0.02376209963263283, 0.04359846979740166, 0.01537875638478586, 0.08290145395984573, 0.03132486216453535, 0.02394245971264618, 0.03609997821190665, 0.026795225585961056, 0.080173100765434, 0.05277691176161171, 0.08481901033871597, 0.0984750408679247, 0.04085068478279057, 0.0335438990394675, 0.09947530654889923, 0.008885829893481589, 0.07193691247413236, 0.10406624931361406, 0.03805580451303432, 0.04029050214035858, 0.0359156268138078, 0.08717278484255077, 0.039402793927658955, 0.024282744477292704, 0.037409961749348915, 0.1823078279173182, 0.04652332837483095, 0.012060766382473371, 0.11570328576189857, 0.03050051899927278, 0.15887912783411243, 0.10335779418387722, 0.15237508732224667, 50.00066088091943, 97.2532307717108, 72.63904002404982, 89.16640958478375, 90.94283534634499, 52.67788640914425, 38.33268434770646, 35.17764352983044, 4.139569949719214, 0.7429341731532928, 0.0672511127026331, 0.3632371878672031, 0.45398269269254904, 8.3237245005946, 7.103805109377831, 28.695314930331325, 72.68258617770287, 49.47279614786948, 66.12650917422387, 67.25021331541001, 64.3863182683145, 82.47123749025407, 80.38697627282913, 81.3177860936811, 80.85247532013925, 80.16213032507127, 76.94501799921836, 75.45384268606864, 77.60378791439918, 73.53598410083403, 77.35319552883026, 74.35104477790095, 68.67797174761373, 70.78036215997511, 77.44550458846554, 73.76410130531558, 70.26227981813493, 71.31931151113203, 71.04593799960229, 54.321473260079664, 30.080966718735237, 25.16112800567381, 25.125659973390643, 31.150538229173232, 51.323880303290586, 49.3929131569401, 21.0316841448507, 4.27392779819427, 2.05413042777969, 0.9422536422648738, 0.3661417336233201, 0.17421561052962659, 0.05323604357639148, 0.2898971700379926, 0.7703368317696356, 0.9458437141391539, 0.8850026046556811, 1.1863345869125859, 0.3202595327410006, 1.8165433959614847, 3.2997296990886813, 18.471590395896666, 31.557103664644305, 12.020900614799993, 36.30913357580862, 36.12382119701755, 21.849955281903668, 1.1682849425461985, 3.7792046416190366, 0.5142775201989759, 1.121621240050562, 0.5931162413570189, 1.286127896558854, 2.5620465990035766, 0.5471207513924569, 0.02042047390263648, 0.2449945964279675, 0.25029453058396617, 2.18674490528722, 3.6003276465400575, 1.9374385668385414, 6.539360842397136, 24.31853032881214, 31.164748976307532, 37.37553188877721, 33.31892251968384, 34.08858568437638, 25.54173323415941, 66.91366610988494, 51.85586744739164, 49.34732344842727, 67.71151542663574, 54.96653056913807, 64.51270095763668, 63.686681178308305, 64.0132341846343, 65.06445292503604, 63.89912459158129, 70.68063197597381, 64.37254290426931, 69.0759511147776, 67.225674967612, 69.3835198494696, 64.5132932355327, 69.80123658334055, 69.17767386282645, 68.39294095193186, 70.72806127609746, 72.71121947996079, 76.66652971698393, 73.66863866006175, 60.46796460305492, 64.39894437789917, 59.43515354587186, 63.91146044577322, 27.572022638013287, 1.359775054358667, 1.836524439915534, 1.1232834669851488, 0.6515461350640943, 0.2739542368198595, 1.649796453214461, 26.05710521821053, 42.08871464575491, 63.07067686511625, 78.128781472483, 65.49716095770559, 70.33837379947786, 20.170645444623887, 0.0724612383712684, 0.03761403225061875, 0.021911378679496628, 0.03612423255558937, 0.11524869684850979, 0.022516362143740542, 0.02541653736824951, 0.03781894927904491, 0.09129230774218038, 0.1792509379165788, 0.11275935542559433, 0.02320404288419072, 0.015701750544981373, 0.032841446208617384, 0.029166062783089378, 0.037325328185914025, 0.07645890732566196, 0.09757878694442973, 0.04805069702166704, 0.009797546344118254, 0.019311391177677342, 0.17142046212909684, 0.16033069591128057, 0.22944316478265872, 0.2746749416955056, 0.26531659547359715, 0.09247484106209972, 0.18721943210449912, 0.14011982557994707, 0.19153860517807547, 0.23661797655926597, 0.32838162755773914, 0.1462321806578867, 0.1319090331033353, 0.13164853256556297, 0.2077930910332549, 0.09000996082660653, 0.09535548487497915, 0.1413909186639132, 0.27468710717174316, 0.12678912960954253, 0.14647743604596586, 0.30435916336794056, 0.14330172580817055, 0.17240693822743433, 0.2862518785461303, 0.2816502028895963, 55.63380810522265, 116.04332939271005, 85.63273060706355, 104.34242063953032, 109.97379103014546, 69.10025412036528, 59.976927003552845, 45.13657669867239, 5.099194972745834, 1.1812461696324812, 1.005577121771151, 0.7466388517810453, 0.8237864798115146, 14.146787985678642, 11.462681639579035, 31.63753578739782, 70.00264244694864, 59.08285410173478, 78.03155376065162, 77.32190285959553, 78.43586383327361, 95.35589402721774, 84.7183084487915, 84.42315009332474, 83.5833941736529, 83.50367592227074, 76.70943260192871, 74.62256693070935, 79.5222270104193, 78.2460524958949, 76.57022768451323, 73.80536463952834, 66.47378013980004, 71.36513263948503, 78.15487307886924, 75.46260526103359, 70.9959513141263, 73.57131681134625, 77.27361848277431, 72.54111413032778, 32.73073761693893, 25.069854451764016, 34.39983752466018, 42.7296926898341, 54.57068497134794, 54.78367359407487, 29.9276844147713, 9.589094846479355, 2.7268920502355023, 1.174181735804004, 1.9670717057681855, 0.9087149870972481, 0.2552394749176118, 0.6274652336874317, 1.1211494524632732, 1.3863850264779984, 3.3278347071140044, 2.7349485985694395, 1.946551948785782, 2.474506651201556, 11.779791539715184, 29.28510408247671, 40.111341937895745, 12.770399855029199, 37.00981793865081, 46.44363203356343, 36.65591032274308, 11.046084742392264, 4.250791697732864, 0.5842257603522271, 1.7851487451022672, 4.359809564005944, 1.4840807261005526, 2.6251896494819276, 1.0886740660475147, 0.0878917966638842, 0.22870359882231683, 0.37735827207084627, 1.6050033535688155, 4.452842791234294, 9.01305458238048, 18.5407555103302, 37.313766325673754, 41.896436137537805, 44.13936507317328, 45.524228465172556, 43.6394315381204, 32.052538241109545, 61.608703597899414, 52.09163719607938, 59.89282354231804, 70.60918992565524, 53.9189164869247, 64.14219779352989, 62.77299642562867, 63.015308687763834, 65.05933815433134, 62.85478176609163, 69.18395749984249, 63.67005425114786, 66.90037711974114, 65.20819210237073, 71.9023012345837, 65.84738546802153, 70.79238030218309, 66.60935294243598, 68.40754001371323, 70.79513380604406, 74.36049769001623, 73.939815644295, 77.05453841916977, 67.9919413597353, 71.14082797881096, 60.633418021663545, 72.3009160257155, 33.71047312213529, 1.781584413782243, 4.4023849310413485, 3.0282193133907938, 1.3662809181597926, 0.5066542711950118, 3.302531497132394, 37.360238567475356, 57.81172375525198, 79.23707069889193, 88.66677022749379, 76.91819683198007, 82.12460979338616, 21.05748353465911, 0.25854352020448257, 0.4368695448483191, 0.22636672421809167, 0.12220836049246213, 0.25240216103772967, 0.13310242955002094, 0.09485744345452517, 0.1775507896297401, 0.2335571029013203, 0.3961686111025272, 0.3419351631835584, 0.0917311535487252, 0.1102359613944446, 0.09994574582144138, 0.1293245588819827, 0.13005946702774496, 0.17210048773596365, 0.16845214721416274, 0.11644316581828941, 0.1840205247243566, 0.113185323294132], [0.015930249674936697, 0.016297995818838958, 0.03807342070485315, 0.09494940464895579, 0.08774388806834336, 0.11379311447061839, 0.02109922588832917, 0.09170993291322263, 0.09230728997218032, 0.12188368476927282, 0.01599177323852576, 0.08570197263672467, 0.09200236399567897, 0.0661864037054681, 0.04168623389916555, 0.08136606820288204, 0.02709584997876758, 0.13660144421362108, 0.07499362627464919, 0.053355917184343266, 0.07469913441567652, 0.061411634312882546, 0.07349639169631467, 0.06588806608511556, 0.05842204130585155, 0.2621137657232823, 5.526200369481118, 79.25607850474697, 76.66105408822337, 79.19299110289543, 87.95500124654463, 69.72025532876292, 37.99203826535133, 25.00249754997992, 2.9626968551066617, 0.08818589015713624, 0.3895318994839346, 1.7829039236230237, 0.7759397536996873, 1.5564565456682637, 4.625639867398047, 54.16397048581032, 55.71637791972007, 61.362853357868815, 73.45767005797356, 58.876003988327525, 81.96554199341806, 85.41602749978343, 80.63446998596191, 79.17374011008971, 78.01922967357021, 77.78891594179215, 81.4843926891204, 79.35340819820281, 78.36555142556468, 77.57771199749362, 77.72508328960788, 72.85057344744283, 74.62241003590246, 73.55659223371937, 75.82613837334418, 79.33789914654147, 75.68212463009742, 69.05161673022856, 69.95427962272399, 81.04854676031297, 54.487915115971724, 28.13310984642275, 27.193708073708322, 28.915095137011622, 44.923046788861676, 39.83642693488829, 21.068424986254787, 4.425629386978765, 3.0396236046668026, 1.222384600870071, 0.08433983766383703, 0.024753246952088612, 0.07282267099306469, 0.15068541911821212, 0.6043394294477279, 0.3022165686613129, 0.493055567025177, 2.1797530353069305, 0.6159601865276214, 1.7715706027323201, 6.713525354862214, 4.342719306868892, 32.07169901940131, 3.7207015099064, 16.74993465023656, 37.50831196385045, 12.153910148528315, 3.6592200734922966, 1.9295758081059304, 0.6966814002202404, 2.827958046428619, 0.21701378657692866, 3.3310535021366614, 0.8054850070226578, 0.9271662453970603, 0.23225400266387772, 0.22198554398792408, 0.17438369022021372, 1.9757944441610769, 2.0299236428353096, 2.742676893549581, 10.350184690567756, 14.887766857301036, 23.276701742602935, 31.303791115360877, 30.61683308693671, 30.15205183336812, 31.003043382398545, 14.902054090653698, 35.90721222662157, 68.45590283793788, 66.91122639563777, 68.73592084453952, 63.78805875778199, 65.5725646018982, 66.67167155973374, 65.54977563119704, 69.90008031168293, 66.89065748645415, 67.45468647249284, 72.41692404593192, 70.29909518457228, 71.78700708573865, 70.13749353347286, 67.04337889148344, 65.33674778476839, 68.98474816353091, 69.44378314479705, 71.40372876198062, 68.58077541474374, 70.98423911679176, 53.30120986507785, 47.85708558174872, 64.71829983495897, 64.65301198344078, 53.23185843806113, 2.420914081796523, 0.2530899394543902, 2.0503526950074784, 1.3797570789052596, 0.44458806454654665, 0.4662639401372402, 31.744359577855757, 57.69786127151982, 61.151057135674264, 65.80132899745819, 66.94068339563185, 36.75074146639916, 0.45854777998981944, 0.1086851083222897, 0.079095896874224, 0.027852741017517064, 0.01767833687124714, 0.07384412666602481, 0.0015968809513592973, 0.09068091595244986, 0.05713902789378359, 0.049568999017919266, 0.008865759347475344, 0.022740894853467905, 0.06187321377858039, 0.03821820366166292, 0.016564739973194176, 0.0662524251627826, 0.07409106744753738, 0.08435702867685788, 0.017448418563412085, 0.010190951645434385, 0.079168813122857, 0.02026831160389608, 0.034693425461169214, 0.06881612307962871, 0.012238739140992685, 0.040909305830756505, 0.12252300046384336, 0.0646307702446657, 0.04871196496570784, 0.23462334407433388, 0.16125714135987146, 0.09169052024522135, 0.04343602851393723, 0.07329058217545671, 0.05823209363546583, 0.043142793039160396, 0.05587104895722963, 0.04995326105985911, 0.06182123854335758, 0.11160152078035379, 0.11370867625960421, 0.05204193466793626, 0.06038922869089631, 0.05609345194252749, 0.030920107270621007, 0.10055743638546237, 0.1271946965566566, 0.5041919726758234, 11.214845699648704, 100.75568768285937, 80.63757650313839, 87.50064957526423, 90.84424264969365, 66.49933045910251, 38.80531034161968, 31.93387869865664, 4.2183953715908915, 0.2538316964261955, 0.5734842883483057, 3.0292768824485043, 2.26811251332683, 3.1444315420043085, 11.929694721775672, 58.53327120504072, 63.01438693077334, 67.44343711483863, 78.2993261275753, 66.77643022229596, 78.67149629900533, 82.79276201801916, 81.5443657290551, 79.76000109026509, 81.12426419411936, 79.52534137233611, 86.10776885863274, 79.14288674631428, 80.78151964372205, 76.89189341760452, 77.56828261959937, 74.94113399136451, 74.5228995046308, 72.44264694952196, 75.71573934247418, 76.54400271754112, 74.73660592109927, 70.11412405198621, 69.66370259561847, 65.98123242778163, 45.42534551312847, 29.397327015476844, 24.21290090007167, 30.87192443109328, 48.31881915369342, 45.01260626700617, 24.39261801781193, 7.727756634835274, 1.0205280324143748, 1.263809487704308, 0.3634110898260148, 0.10113412439222298, 0.09407152151388508, 0.16111362244813673, 1.1514301501935529, 0.8375361645894667, 2.4301002727400873, 2.552619182294415, 1.0306837842349084, 4.436936599593009, 4.547162065582891, 19.522514958535474, 41.21667761956492, 14.999106276419857, 25.10250229989329, 39.750052421323716, 25.58511660945031, 6.275307862989365, 6.2070855882860005, 1.5827213492124312, 3.9206117247381522, 0.5217428938035042, 4.779136430832648, 2.763490950868976, 1.590695282624614, 0.1625908544707683, 0.21119544072256935, 0.2631622336564526, 0.671043440459236, 3.7327640239269506, 3.847221482184626, 9.306630261482733, 19.321085560706354, 26.09149067632614, 37.26312460437898, 30.91091867416136, 32.46214547464925, 25.644848423619425, 22.321180989665372, 41.361926909415956, 61.74767709547474, 66.32555377098822, 67.70706745886034, 68.15864993679908, 66.7812547376079, 67.46572402215773, 65.89774085629371, 68.44260600305373, 67.38734722137451, 67.03937807390767, 72.00030557570919, 71.18451533779022, 73.26431289795907, 71.27341978011593, 69.59453551999985, 68.57898681394516, 69.48892962548041, 71.89593915016421, 72.08385206037953, 73.40289023614699, 71.7942399363364, 58.54321049105737, 56.75539416651572, 70.18974734890845, 62.96019546447262, 56.47461522010065, 4.11300128506076, 0.06070728158398021, 3.409973551188746, 2.577511524000476, 1.0282828033931795, 1.1144756621891454, 43.74169557325302, 59.93483212686355, 70.08650272123276, 74.33464142584032, 72.83220106555571, 53.811620050860995, 1.0875477329377206, 0.09197923580124494, 0.03293390919063841, 0.0564962494817953, 0.05885851607027073, 0.1015415069677176, 0.018860232422969515, 0.10329066189907252, 0.0593323567731967, 0.08290745242829285, 0.16179839780013408, 0.07817528901561614, 0.03509382514523403, 0.032250731131963195, 0.10504971468640913, 0.07718604733987201, 0.12820697449628385, 0.060698827803735776, 0.02745153311069214, 0.02190873759137767, 0.027243681965515982, 0.06903839582997946, 0.16243276456671377, 0.16924854157672775, 0.07603649410509294, 0.14026406461433058, 0.3172283986162755, 0.35660936286853206, 0.13301872678341406, 0.4129510541116038, 0.36496453227535375, 0.20566074658305417, 0.178612434275208, 0.27834474800094483, 0.17502332767171247, 0.12088991551389619, 0.13757687332409044, 0.13475337967036233, 0.16636135537297497, 0.2503343058689948, 0.310976937293045, 0.22746057519989632, 0.21274937346817988, 0.38883721095419704, 0.26917970108409084, 0.31447063530645064, 0.17888856300663564, 0.9484030606765902, 11.413219571113588, 120.90110640372001, 92.73018098646595, 106.65462647714924, 106.773419380188, 90.04180415984123, 53.540243025748964, 37.95485419611777, 4.351147499776656, 0.4811143706883154, 0.991822227595314, 5.429424220515836, 4.288626390118753, 7.255679282449908, 19.706703578272176, 69.9004803934405, 66.85253989311957, 73.94129830022013, 87.6762148641771, 73.47516382894209, 93.15305171474334, 91.06194988373788, 81.36122242096933, 80.20963022785803, 82.59396845294584, 81.69161935006419, 85.89476062405495, 79.86195133578393, 80.83001582853257, 74.6179542233867, 75.17216159451392, 71.2030210802632, 74.88333394450527, 72.92863645861226, 75.65918660932972, 77.79129289811658, 79.29296447384742, 71.8249285605646, 72.93762653104721, 82.72813704706009, 63.3143658791819, 38.77742228969451, 36.04684076001568, 41.25170830757388, 53.15868662249658, 53.92625916388727, 39.08633247498543, 15.869566509800574, 3.7477178150607697, 2.068239070715443, 0.22785785307566966, 0.41583997167406545, 0.2583518450058276, 0.34124228262132217, 1.4597885070308563, 0.6243649677884194, 7.844165227105541, 4.631140501268448, 1.2962666105839515, 5.27534616570319, 17.598935596404537, 32.291724374217374, 52.630076639113895, 17.75431440722558, 23.043483495712284, 46.63380030662783, 37.002506640649614, 16.979603152121268, 8.369741747456214, 1.0998270804843595, 8.093782413390375, 0.8109546909409185, 7.472073012782682, 7.173998865389056, 2.0730072019561647, 0.2596736837538981, 0.39158090888973207, 0.3035699702318638, 2.767695486545563, 6.051799933756552, 8.927172326272535, 20.57285116564843, 26.99203156655835, 37.58313901962773, 43.534394387275945, 38.29495114664878, 41.94298290437268, 36.56603313261463, 21.270134833551225, 43.66251860895465, 67.94231553231516, 68.76970814120385, 69.89209436601209, 66.28657325621575, 63.39505687836678, 66.4446839978618, 66.91182259590396, 73.75897868987053, 68.0871529732981, 66.76009747289842, 78.15261379364999, 72.37527631944226, 74.51518812487203, 71.70087183675459, 68.97134150228193, 67.8430481879942, 70.62718576000583, 72.95470453077748, 72.75300841177665, 72.58480148930704, 77.58268556287213, 64.9247851679402, 62.27645966314501, 80.23201911680161, 76.6752452235068, 62.30128826633577, 4.891595686635664, 1.1650304784697871, 6.297215280994293, 4.4731479210238305, 1.9776113595693343, 2.1604934623164516, 58.809845370631066, 71.5628828540925, 83.20745852685745, 85.71065241290678, 90.29747993715348, 60.00139867105792, 1.335879730120782, 0.29578783459240393, 0.20757936782413916, 0.16367624784188886, 0.12904934945606417, 0.12557938484655273, 0.13051217902571927, 0.2519190200274029, 0.27995383907710353, 0.16732664147932685, 0.32482158633009084, 0.1685944403852186, 0.15599112957715988, 0.14320532130377908, 0.3044562420297054, 0.20538832571718002, 0.4989143316784213, 0.1714346500774545, 0.1594161707907915, 0.11381982029565882, 0.1436256584260733, 0.12483253339005095], [0.01850753511872984, 0.015822786691358254, 0.04492222759572249, 0.05658168743755068, 0.03285077715953512, 0.09356715986805578, 0.0695407273428094, 0.06474815789730319, 0.053980240538235635, 0.005170354214046271, 0.043565049211704926, 0.04780772840604187, 0.041775808729712045, 0.07764055964446838, 0.05573639368277885, 0.010629275554580795, 0.06235100749519564, 0.055789839806816274, 0.1176173487798341, 0.006810567612128874, 0.09994321773129125, 0.00847832378630917, 0.027691889366495515, 0.03705783326539301, 0.048893868712888616, 0.06967498425153956, 0.08218988085225706, 58.70405120234336, 84.90991623170915, 75.01748684913882, 97.809964149229, 80.77821700803696, 40.80279696372248, 10.484017922032265, 1.6251582075511257, 0.6376226402578816, 0.6491859100999371, 0.21871033425052322, 3.0272433786622943, 2.111487859679807, 4.2037855232915575, 74.03436829966884, 69.07854772383168, 66.10780731324228, 60.722981422178215, 62.0440709975458, 78.06219531643775, 83.45663885916434, 84.01043830379363, 79.77035614752, 78.40260997895273, 79.40410875505017, 81.02735811664213, 78.7677041945919, 77.90562998863959, 79.69999667136901, 75.49123856329149, 75.71473521571006, 76.01325112004434, 70.67395610194053, 72.00532620952976, 74.73448784120622, 76.2140372491652, 73.3633605895504, 67.1489377175608, 75.33801509488013, 74.37577924420758, 37.84044650293166, 29.117385495093565, 29.873561589948594, 33.37467901168331, 32.679742882328654, 21.22047370479953, 4.902643042225992, 1.8311292197435134, 0.8992951699802954, 0.13049454368170232, 0.04091824224639324, 0.29298738486343817, 0.056158358741912155, 0.012840641974171084, 0.40760336203440545, 0.014990095082940835, 1.4788947398624113, 1.7858419014561562, 3.3563986324494888, 4.273464958513937, 13.153900773294511, 40.726000878118704, 9.61720843468943, 5.963388239183734, 29.25904189386676, 28.559332240012388, 8.617402161321333, 6.653954357870164, 3.4531505117493295, 0.22156126917369906, 0.5676215093943381, 0.7534772590283425, 0.6928165172857623, 1.7218148468002197, 0.15853412779829196, 0.03683071883936082, 0.4095830558048141, 4.24403541511105, 3.5895065626790448, 6.271524736958166, 8.707532344325896, 18.208960256268902, 25.76636149037269, 26.447282991101666, 28.05737868432076, 31.6586067599635, 32.10792603031282, 31.908093037143832, 55.67303965168615, 65.77899502169701, 65.84296887920749, 66.63160062605336, 65.88403609491164, 65.26977331407609, 66.6396571743873, 66.61479719223516, 69.39852683774888, 67.66062659602012, 69.20793887107604, 70.91835114263719, 68.94110002825337, 69.63491239855367, 70.32856002930673, 68.21059780736124, 70.50996964977634, 68.68292177877119, 70.51022068146737, 70.39436955605784, 73.0120417379564, 73.1156393789476, 60.985929273789935, 44.263727741856734, 62.39391503795501, 55.23440491768622, 50.299031657557336, 10.595159261457383, 0.28171467684930374, 1.0681349423623856, 1.72340095523865, 2.7115369516034282, 3.491986634269838, 46.85125258661086, 58.30820168218305, 71.8511692170174, 74.74318765824842, 70.32452783276959, 17.901354259060277, 0.059225606251387834, 0.04401363199576736, 0.053716453483268145, 0.009840405133042124, 0.06700572707960684, 0.030235841367093307, 0.030742455311419985, 0.04631240138663881, 0.09393540301149893, 0.05464052405929374, 0.05193633710845344, 0.04298043219492801, 0.0053098559522280295, 0.00413730763079178, 0.01389071869198233, 0.07753164492427342, 0.04487162365788414, 0.036253337523028735, 0.07502878204949441, 0.06585801245584604, 0.053078700608063134, 0.05526788112136626, 0.002862782951729793, 0.04379411333150441, 0.005391976747271275, 0.07096365905336796, 0.018679305437892195, 0.1257379344033618, 0.05227081875707354, 0.08375225588679315, 0.06644778524435337, 0.03464565987909033, 0.05882932812035565, 0.020608598283762415, 0.02936321359518315, 0.05732213056856587, 0.05996832466353813, 0.043290575230193716, 0.07430692804196189, 0.06499001185499853, 0.056072985903630336, 0.022812930100987998, 0.08450705167506972, 0.038422117114908276, 0.017215627425860976, 0.011932592211862006, 0.023302632654386184, 0.05728565329205125, 0.7027963140318472, 81.06549924419772, 97.18786055041899, 81.22194690089073, 103.63916320185508, 81.19770665322581, 45.760935660331484, 20.979489164967692, 2.3737372842527207, 1.0170369390999119, 1.3894312372130733, 1.0071954671894352, 4.225024177182106, 4.875643407144855, 8.949661235655508, 81.47426512933548, 69.7065584121212, 75.50681821761593, 69.97218132019043, 67.65594328603437, 78.56712987346035, 83.31715937583678, 85.22306257678618, 81.07914124765705, 81.87196993058728, 80.05897983427971, 82.14160934571298, 83.203214522331, 78.63343361885318, 79.25227380567982, 75.38505215798655, 74.55390191847279, 75.08051149306759, 71.44998135105257, 72.15447825770225, 75.45654127674719, 76.0443868944722, 77.28023944362518, 70.97211114821896, 73.90398087040072, 61.39178083788965, 35.247038102919056, 27.18085054428347, 31.93746178380905, 40.36196178005588, 38.78646727531187, 24.951159607979562, 3.03432815978604, 1.0491681988200834, 1.0306381866816552, 0.32410492639868493, 0.054558468381724054, 0.3554145414983073, 0.20371787099828645, 0.1691016671998847, 0.4895889885242909, 0.04507866274986056, 2.391921392371578, 2.5899037622636367, 5.76865432723876, 6.640381486185136, 27.42393551334258, 43.72610807418824, 12.793411420237634, 11.922079440086119, 30.463515481641217, 37.52208340552546, 12.495266179884634, 6.963465156093721, 11.461406869273032, 1.2006072339511689, 0.6966044237056087, 1.3937782039565425, 2.901954540321904, 2.172489296044073, 0.0731856664342265, 0.336563078866851, 0.5715508050014896, 11.727223934665805, 4.2708389316835715, 6.167102417638225, 9.474302761016354, 21.528585687760387, 28.19888995539758, 31.96253553513558, 28.87849157856357, 33.011373396842714, 27.180293567719, 35.63283066595755, 52.766229952535326, 65.19157301995062, 65.29849683084797, 67.34773128263413, 65.54186028818931, 67.17260529918056, 66.45446638907156, 67.25455145682058, 68.69250805147233, 69.45230253281133, 68.5432069532333, 71.6144149534164, 70.02113249994093, 71.91032640395626, 71.78503805591215, 70.5104011104953, 71.03353546511742, 69.57679856208064, 70.43800200185468, 72.7005349436114, 75.1247009154289, 74.98187957271453, 64.13036400272001, 50.14539634027789, 67.6441369518157, 61.143651700788936, 60.53723758266818, 11.649464907184726, 0.3583005172831397, 1.0788208270265212, 2.6439665257930756, 3.5056587909498527, 6.479329457206111, 51.86242565031975, 61.591986456225, 77.46817588806152, 78.90271217592301, 84.76469439844932, 27.825586218987745, 0.08062612685945728, 0.10835519255769831, 0.053613897292844714, 0.05297266637846347, 0.0192627216118478, 0.04830038039794853, 0.06377007812261581, 0.05799844830987915, 0.04544672969308111, 0.08243797842653529, 0.10817433452053417, 0.005869610543032327, 0.05787158031917869, 0.02415345181831189, 0.06655620200739754, 0.11645251209096563, 0.009837276621481345, 0.06149903345372408, 0.032189666263518796, 0.03233177174303321, 0.0312097019125377, 0.021441515888117497, 0.1315412802561637, 0.12344882538121556, 0.09652475721292919, 0.1762126944959164, 0.16171644171399457, 0.24241611301418275, 0.13039695940190746, 0.25132989841363124, 0.2080202207810456, 0.19341670036796602, 0.22177254090145712, 0.148054642542716, 0.10144528632442798, 0.15441658906638622, 0.15048865709573994, 0.14101683793048705, 0.17745292955829253, 0.24128377377506227, 0.20458826945433695, 0.1551054706496577, 0.22014736197888854, 0.1594909409722013, 0.11767491262646453, 0.14437126115925852, 0.08783454691330272, 0.22729686221047757, 0.6324341412513488, 92.57686338117047, 115.11415127784976, 99.38957322028376, 122.7462128669985, 104.36274636176326, 61.02911849175731, 23.224281226435018, 2.573103025074928, 1.618034938170064, 2.8733690419504723, 3.1192717436821233, 6.175579149876872, 7.719371097703134, 14.413605255465354, 92.73328750364243, 80.7245825183007, 81.20203694989605, 77.45491043213876, 76.4485086933259, 84.99638095978769, 85.54709742146154, 85.48561819138067, 81.17756920476114, 80.20982634636664, 81.62195021106352, 85.07798194885255, 83.9267349243164, 78.10653378886562, 79.91064363910307, 73.05660770785424, 74.46019649505615, 74.55656128544962, 68.95460867112683, 69.87927606028896, 75.46542152281731, 77.96162574521958, 76.68656518382411, 71.63449748869866, 78.2652799544796, 81.83791591275124, 51.40366915733584, 35.24624186177408, 43.03264479483328, 45.25276514791673, 49.14703153794812, 39.05123510668355, 10.238328499178733, 5.034484690235508, 1.640973204085904, 0.7978542810005527, 0.16294330088121278, 0.5266446307782204, 0.5299220162053262, 0.8662275056685171, 1.9946317494876924, 0.20100002086931662, 5.5097636772740275, 3.015989608341648, 6.990986956704048, 19.865696853207005, 38.82644799447829, 52.30194683997862, 15.283266305923464, 9.669981964172857, 39.86188311730662, 44.75496145986742, 22.96473603094778, 12.513983730346927, 13.991607254551305, 0.785956874249443, 1.5174892688951187, 2.461325526237488, 5.470018790614221, 4.980874225016564, 0.15623128281966334, 0.40224816229554916, 0.680659008362601, 13.706666673383406, 15.014034817295691, 13.240138003903052, 15.06846848995455, 33.11147228364022, 39.6238148596979, 39.19667267030285, 36.88703990751697, 43.11092745873236, 37.3118325971788, 41.67577143638365, 60.82249587582004, 69.53027925183697, 64.54608817254343, 65.94732746001213, 66.35031177151588, 66.69364467743905, 68.52315579691242, 67.40262877556586, 71.50097216329267, 69.08044615099507, 67.30529908211001, 73.35905382710119, 70.05439419900218, 72.17942453199818, 72.1701285146898, 71.89820628012382, 73.78581554658952, 69.80224855484502, 70.49413896376088, 74.9353131940288, 76.3774275010632, 77.30363245933287, 71.71034828309091, 58.33918056180401, 79.2435347649359, 68.17560242068383, 63.58977902320124, 11.973464450528546, 0.577230642159139, 1.478355168815582, 4.764295162693148, 7.771621481064828, 12.906862055101703, 71.40757268474948, 74.32292922850579, 92.02606847209316, 93.68213238254671, 96.39143897641091, 31.309256938196, 0.17167366950983004, 0.22950766938588313, 0.13904934027983298, 0.10391251078896946, 0.28491159240084313, 0.17813562115113582, 0.2043078659522918, 0.13292452861224452, 0.26019762660707196, 0.17356947665252995, 0.15639223789255466, 0.11952889136849873, 0.1927705358473524, 0.13344926819685968, 0.20608946470724, 0.18121284312538563, 0.08419097911927008, 0.14186255303361725, 0.22801065697304665, 0.17588192837372904, 0.19720350362120137, 0.20346049609924519], [0.06193601383617329, 0.05641233604100924, 0.03124471979155656, 0.02171556852127035, 0.05089855610182689, 0.12933048840251662, 0.07679678274378662, 0.03611040083811649, 0.13342274623292108, 0.01731244753295135, 0.011446890552648374, 0.10780349433902772, 0.04932968081125329, 0.06154773366307059, 0.07016583976726379, 0.05009494902145478, 0.03251655598080928, 0.07401489532522618, 0.08683335426593981, 0.11629036958179167, 0.060589874779144605, 0.023962422048733122, 0.11223377314426246, 0.041052840064249696, 0.06785275985396678, 0.2800434407207274, 0.32976754189979646, 30.549301639679943, 89.38073573573944, 82.78661958632931, 88.79964443945116, 93.92477020140618, 58.77036279247653, 31.125946929377896, 1.643909465882086, 0.3517959711532439, 0.15280696172868052, 1.840294818243673, 1.500849716605679, 4.478878013549313, 14.875470226810826, 74.63253759568738, 71.61039844635995, 74.13112532707953, 65.49439568673411, 67.39887898968112, 77.88655942486179, 83.43966284105855, 81.24903478930074, 81.37344452642625, 79.93740989315896, 80.09286911256852, 80.69554913428523, 81.79069057587655, 79.50937732573479, 78.03397778541812, 79.15726615536597, 78.40508107216128, 77.61161696526312, 78.00290476891303, 71.84093183086765, 77.31649783349808, 74.72701964839813, 72.78138283760318, 70.77660452935004, 67.62421131134033, 77.15766537574031, 55.281744003295906, 22.82973981672718, 33.80069155846873, 29.960493080077637, 24.47967110141631, 17.725675221412413, 12.852441130145905, 7.03909972983022, 1.3284317620338932, 0.0029826213675175585, 0.09071742770292106, 0.07739024041520973, 0.10639876487755007, 0.10450098122800551, 0.09621641448428554, 0.7406592597403835, 0.3452897396299147, 2.5717779994010925, 6.173543930053712, 7.261418690604549, 24.89184944860397, 17.85007711379759, 3.8430909812450413, 12.964236524797256, 18.710925579071045, 36.349173130527625, 14.442594512816399, 4.7978990885519215, 9.887389136898904, 2.578146457672119, 0.5588177495425748, 2.020243110675966, 2.551271357843953, 2.771749746414923, 0.171436274183854, 0.07629697166022754, 0.252375700360825, 11.608709519909276, 7.565695576129421, 7.295813954645588, 9.224805697318047, 18.09441920249693, 25.114506713805664, 28.532467926702193, 26.648732000781646, 34.07281775628367, 30.385162215079035, 34.072821678653845, 59.63435111507293, 67.20890291275518, 64.32989497338572, 66.19893181708552, 65.65066683676936, 67.91879700076196, 67.61508787831953, 66.04516706159039, 69.085247132086, 68.21184512107604, 73.1339882266137, 70.93184409602996, 73.28936899861982, 71.10198082462435, 71.40025354200795, 69.01526420347153, 68.40061310798892, 66.93719248617849, 68.2307352558259, 70.70839451205346, 74.85572045849216, 71.68744948602492, 63.762037754058845, 44.29028218792331, 53.106181775369954, 58.685600373052786, 43.723052547824004, 13.510649165799542, 0.019974869285379688, 0.42001591694931834, 0.16547561983668035, 1.7902766312322311, 10.53021167555163, 51.21839600224649, 55.050979198948035, 79.72643344633042, 66.36992362237746, 55.44689539940127, 3.4589230149023, 0.2145999201363133, 0.029555635729564295, 0.018620515850582914, 0.08380433454388574, 0.019371601858086163, 0.015213338849735598, 0.027042112741318923, 0.07540625655242512, 0.022200615175308722, 0.057445911224931485, 0.013241778060253109, 0.1058196866764657, 0.06006421971945994, 0.02721620047645223, 0.09459600062860597, 0.05830566105883449, 0.05142121575772763, 0.0367622037658528, 0.030861455579138095, 0.03922459038515245, 0.1048876334642691, 0.045754486364462686, 0.028537886006937876, 0.07334703519459694, 0.03434268359635626, 0.07436227023361192, 0.07418695101214033, 0.15332522020945627, 0.049559599119088346, 0.05151920989456196, 0.08866118642711833, 0.016360677132803588, 0.03493332589465765, 0.05049615309784009, 0.026585403679599686, 0.061600210685883804, 0.03916698057324656, 0.12495192819305005, 0.061537226767189084, 0.1121046337028665, 0.0542129167625981, 0.13983438121936015, 0.0035667088260168153, 0.00841176032178825, 0.09989306961576785, 0.028763993027349635, 0.05350593252167587, 0.2625372284843076, 0.19676479571048291, 45.761947631835945, 107.68720611449211, 88.53238982539024, 98.7701682121523, 94.88725708376978, 61.06501210120417, 38.60692470304428, 2.1729597353166152, 0.7405312924135117, 0.22277689749194732, 4.25846875675263, 4.035631552819283, 7.430852824641813, 22.172413333769768, 94.32529126444172, 77.60269749549128, 80.89977910441738, 74.06447641311154, 72.59110081580378, 81.83236183658724, 83.70434438028644, 82.17520836860903, 82.2557032492853, 81.46015244145548, 81.36316007183444, 83.47636053639074, 84.0985974957866, 83.25184406772738, 80.65700008023171, 77.98941966026061, 77.52609360602595, 76.10930212082403, 77.4191148819462, 71.37268712443691, 75.12948620703914, 76.12230870031541, 76.92157007032826, 71.53465747833252, 70.31168599282542, 68.46865838573825, 48.63800987120598, 25.54184698289441, 33.05433511734009, 33.6673152831293, 30.255896583680187, 19.547414164389334, 9.569494762728292, 7.084260919401723, 3.4675546807627526, 0.10319465576040168, 0.028285310648742224, 0.17701975280238738, 0.08566722288847932, 0.07843916800113455, 0.15643173738593058, 0.6488529989315618, 1.1609372400468396, 3.6715152330936927, 11.699704585536836, 9.55212748819782, 39.527575585149954, 22.684974939592426, 5.874277872423972, 18.160877881511567, 16.629086425227506, 43.43693917797458, 21.689706848513698, 6.490208641175301, 12.738859095881063, 6.614632596892696, 0.5933899492506058, 3.10102365189983, 6.457516176085319, 3.944795588331838, 0.18097169396858062, 0.022811005305078243, 0.1052359123564055, 15.19513653170678, 9.475787378126576, 6.721318123802063, 8.545231530743262, 20.279359817504883, 28.956138818494736, 33.25516047016267, 27.91093699393734, 32.60201523380895, 28.629942747854418, 30.206274678630216, 55.532053978212424, 67.87639617919922, 64.97566223144531, 67.30595019555861, 68.08285405558925, 69.56212105289583, 67.85191274458363, 66.51935808120236, 69.72228711651218, 68.2244751530309, 73.31628430274226, 72.017532625506, 74.46035338986304, 71.35328708156463, 72.467208831541, 70.23213248099051, 68.77903553747362, 70.2349095190725, 70.93535853970435, 72.95680692118984, 75.93820048916724, 72.76884694253245, 68.00472044175672, 49.74839756565709, 61.815541944196156, 66.46688461303711, 51.71007294808665, 16.209705625810933, 0.05105287685329395, 0.47415795525716203, 0.0874902363566141, 1.8315474424631366, 19.732961885390743, 68.21470845130183, 62.4586380681684, 87.28358560992827, 82.46423213712632, 66.85788216129427, 7.470818344623813, 0.17766213284865504, 0.007272993126178101, 0.044263993359861836, 0.03878805816413895, 0.12338887900114061, 0.10034912175709203, 0.05497391403262174, 0.03493473549643832, 0.021757195823855942, 0.04692538663925183, 0.07743138699762284, 0.030285652403930025, 0.031089395464908694, 0.016451385773478017, 0.062214613201156746, 0.08407983508321547, 0.053575650353225014, 0.07150136850654118, 0.05093965671896454, 0.032298400953051545, 0.04362085871698876, 0.03924709421792819, 0.13099665302903424, 0.14422729791652772, 0.1058232489853136, 0.17791340968781905, 0.2793866275779663, 0.36736088594602, 0.10105474236150903, 0.2465158478627282, 0.15668975579882824, 0.11620547171802291, 0.11967824787021646, 0.21818567127470048, 0.20521413264495714, 0.26676597253930184, 0.15514023571966157, 0.23168745000035534, 0.17545818982105102, 0.1320179554844095, 0.12997564168707018, 0.3634493329351948, 0.13220037634093917, 0.18800695516890098, 0.16526463922233353, 0.1560134993445489, 0.25228289646967766, 0.3260687161837855, 0.8451477690569816, 46.590422814892186, 121.53403574420561, 107.87438946385538, 118.2528240449967, 113.32015329791655, 81.29509125986408, 50.217697389664195, 6.275669211341489, 3.731720183164843, 0.5151720044593657, 7.895437959701785, 8.48297174899809, 13.094037559724624, 28.889570313115275, 96.89187065247567, 82.36632193288496, 87.91069415307815, 84.32559290239888, 82.46438118719286, 83.46376188339727, 86.35599997735794, 82.47766233259632, 79.5341980841852, 80.49379810210198, 83.38821703387846, 82.09053224132907, 84.74258792015814, 81.22785399037024, 78.60639279888522, 74.92676242705315, 77.93222365840789, 75.7221249611147, 78.88033897646012, 69.083631115575, 75.57830733637657, 76.0255830518661, 78.95393048563312, 72.10695482069447, 72.18441378685736, 82.08755123999812, 69.7865669188961, 31.04014115948831, 45.43937190886467, 40.0260264642777, 37.4535870552063, 39.44858297224968, 24.870635309527, 18.83791623576995, 7.999046877507241, 0.15078260503228635, 0.19809385100680013, 0.2536913031531919, 0.2174736998013912, 0.31334463927534323, 0.6057421670806024, 1.9154449792638903, 2.143466453398428, 9.535390734672546, 12.205577569623149, 17.014794657307288, 52.649045221267215, 30.928787031481345, 8.85344941769877, 20.73395859810614, 25.125638400354696, 47.62957634464387, 32.7618988867729, 10.716777251612756, 15.216440885297715, 7.211160871290392, 4.774781129052562, 7.077827251726582, 9.560233066158911, 5.174545664941111, 0.5702439202897011, 0.27853599419036223, 0.24248476981395678, 15.343013809573266, 17.740580228067216, 16.4179285687785, 15.61783173391896, 26.332163387729278, 37.58178972428845, 40.83634891817647, 34.0367554849194, 42.43547178083851, 36.92095272002682, 42.33667512093821, 66.47072853580599, 68.89852662240305, 63.8398850348688, 69.84981121555452, 65.20567001834993, 69.16203145057925, 67.0311567860265, 66.34019990121165, 69.28793168837025, 69.53398196927964, 73.00484811106037, 74.08510808021792, 74.3138450191867, 72.59252071380615, 72.85415064903998, 71.86733722686768, 69.69042962597263, 68.99415400720412, 70.45898668227657, 73.46190621775966, 78.01429533189344, 75.29017002351823, 72.42578860252135, 59.3488339454897, 69.18425559997559, 74.83006815756522, 58.10975720805507, 18.396063197043635, 0.1498951994243168, 0.5668538892942091, 0.2873387428060655, 3.236088262450311, 27.654955271751653, 76.24318830428585, 70.21030841335174, 99.23472589062106, 87.54290919150077, 78.58557285801058, 6.215966814948667, 0.3841650858521462, 0.11449644447214181, 0.1570966097736551, 0.13918679177520737, 0.2515062058885252, 0.0944772033741878, 0.11245249890752378, 0.16490067084950788, 0.09748759183792338, 0.12751039372937334, 0.15381312628667201, 0.25106299338081195, 0.14997248237411823, 0.10879354806797159, 0.2008209401561368, 0.18742917165640863, 0.14138072969452029, 0.19946753858558594, 0.1339779761169226, 0.11985750478361884, 0.2234179751887437, 0.12691317456624202], [0.04960931822537415, 0.006483710453575177, 0.03307525241266816, 0.04173854238263542, 0.05551421669341865, 0.0784566271449289, 0.04091909643442881, 0.05752320183561214, 0.05584589446023588, 0.029535637004300955, 0.04064581371963986, 0.03653596268005429, 0.08555548130384377, 0.06199324826499628, 0.03999748883107978, 0.051397984141423825, 0.05675676917176574, 0.07118426939292301, 0.0912191846498078, 0.04751701336053591, 0.04640427065051852, 0.07535793172616152, 0.09279004793854491, 0.041454848532955495, 0.11931096233667866, 0.0958630794118489, 0.09019261150951348, 3.752451625562484, 79.78584950970065, 87.22274964855563, 84.19839828245102, 103.67487245990385, 58.922107527332926, 56.23260498046876, 11.014545944429214, 1.4872335762746873, 2.0328714265938728, 2.2509067914178296, 1.5329332337264092, 2.139035891140661, 21.714445237190496, 77.66462387577181, 73.08566462609076, 70.57981921780494, 54.93352382413803, 75.69417415126678, 81.4712449043028, 84.7544962360013, 84.17562500123056, 85.04235898294758, 80.38912573168355, 82.75304409765428, 79.71250903221869, 82.57939292538552, 80.88623908258255, 80.1271741620956, 76.8675119646134, 80.1682492225401, 75.70749452037197, 77.43831096156951, 74.51177566282212, 76.01912683056247, 74.09456883707355, 77.52137107233848, 72.74409678674513, 74.54207989477342, 68.22648340655913, 64.5920426614823, 34.49801445007324, 29.6050557398027, 25.973699938866403, 21.45208181873445, 17.669448044992265, 1.2331735703252977, 1.6808757209970107, 2.8880744980227564, 0.3014163132156095, 0.035600362480768276, 0.07718763314187527, 0.06134567031216237, 0.06707167958900814, 0.03481558201113536, 0.14357780857432273, 0.424543435294782, 0.35924850512416134, 5.794817026584379, 6.321107418306413, 30.22726916497754, 12.62831493731468, 8.890139268290612, 13.027707338333132, 11.708205342292787, 38.32742444930538, 16.268375458255893, 7.4920663141435195, 13.649519701157848, 9.692821925686253, 1.2979115545749664, 1.2367591069590662, 2.401278941862045, 3.332979631039404, 0.42180693858573515, 0.07909204345196486, 0.07516893783524152, 13.136066736713534, 5.659437400679435, 9.145166873931885, 9.28775385502846, 21.25912670166262, 27.91422001777157, 32.18250401558415, 27.434980907747825, 31.50046463935606, 28.21052370532867, 46.42500861998528, 61.025560902011016, 65.60537522838962, 64.77654310964769, 65.86654232394311, 68.39789098308933, 66.73740263908141, 65.62434381054294, 71.84373240317069, 68.7603650554534, 70.79269409179688, 70.97830849309122, 70.84574022600728, 72.08202423587923, 72.99013137817383, 71.6899048897528, 67.63138924875568, 71.91026364603351, 69.07816333155479, 71.34205341339111, 68.65980332897556, 76.25731668164654, 70.99214661505916, 65.42290264560332, 46.33737502559539, 45.33831988611529, 49.26045863859115, 52.392377084301366, 10.30147179480522, 0.051799720648916504, 0.4396070834369429, 0.7771657395266718, 4.511948497064652, 19.713065662691672, 44.28188047101421, 71.29471040541127, 59.54046526262837, 59.40345687250937, 30.16650184508293, 0.24166957565372993, 0.03644211307889031, 0.035346086407380725, 0.09790926961408508, 0.08455015944256898, 0.02622852162007363, 0.05248655677743016, 0.05193105876265515, 0.02262559287520426, 0.059012974717564164, 0.04785969981082505, 0.05731694798375811, 0.02972630096689588, 0.0594834293118648, 0.05518265767022968, 0.06137824054026316, 0.06345769811061121, 0.02464236913158769, 0.011280622660002161, 0.044007089604894, 0.06162837590841998, 0.029267657533167835, 0.08956497865578822, 0.019668834396607934, 0.07428370791697696, 0.026046181202776013, 0.042088797781616456, 0.07124034702898034, 0.038841251479161364, 0.03579653078509915, 0.015868559487224106, 0.004081960172287279, 0.04468036980758752, 0.024888354218414715, 0.053370484346223455, 0.05323225144116629, 0.04307414390026562, 0.13181268988597777, 0.022983421053316806, 0.036481214206545584, 0.08015114468552413, 0.046696548515390006, 0.04590168249823394, 0.06717889359401119, 0.07739361120207656, 0.013133623682323002, 0.18468066268870909, 0.1308579604712225, 0.22211927229598646, 0.42814401789538326, 13.146063877690224, 101.71549950876545, 97.46547022173482, 97.12841310808736, 105.21295147557413, 63.02489496046498, 64.41544186684393, 11.25752697067876, 2.896718421289998, 3.958334874722266, 6.046794008824134, 4.519796179186914, 3.9939894647367544, 27.685151638523227, 85.98161758915072, 79.44155954545545, 75.9057467983615, 64.5165527251459, 82.21809556407314, 83.20071989490141, 88.96558423196116, 84.58595983443722, 85.1568921919792, 82.06800999179964, 84.66735686025312, 81.97526162670505, 86.61351142391082, 83.3041763305664, 82.6719843956732, 79.6719438798966, 80.08121967315674, 75.05576918202063, 78.02916895958685, 74.72286978075581, 75.50240947354224, 74.63769943483415, 78.94658780867054, 73.44281211976083, 74.54958731128325, 69.45631119512743, 54.88720455477315, 30.40999670182505, 32.13235062937583, 29.53146423062971, 26.14805909895128, 20.25468222556576, 10.771597277733589, 1.9734643111305854, 3.86471035019044, 0.7321637123823167, 0.526654681851787, 0.05421403908140717, 0.05907914939246351, 0.06300320112777334, 0.024578395044250835, 0.20871084904478443, 0.2807126951313788, 2.032385175266574, 4.913794340625887, 11.007580795595723, 49.92073082154798, 14.385505395550883, 4.1322189377200225, 12.97891011161189, 15.300931680587032, 47.556549656775694, 19.955915289540446, 9.946683606793805, 9.818377975494633, 5.594978640156408, 2.5774521981516196, 3.6420964762087795, 4.589331957601733, 4.794833756262257, 0.27231581989795933, 0.2436864859755001, 0.04133902369968353, 13.352018710105652, 10.272066766215909, 6.991412043571473, 6.699432769129354, 23.72620144198018, 28.06164622306824, 36.31849627340994, 27.270570839605025, 32.44240026320181, 29.480185124181933, 38.42106319242908, 60.7995068642401, 63.94160778291764, 64.23032952893165, 66.53044269930932, 69.63763452345326, 66.10645017316266, 67.87984002021052, 71.07086858441754, 70.38741127137216, 69.62811100867488, 72.15444687874087, 70.70463688142839, 75.42324035398423, 72.87729263305664, 73.77040847655266, 70.50707494058918, 74.4082643139747, 69.26014561806956, 73.82081093326693, 70.47764931955646, 77.96587759448637, 74.10239004319715, 67.74083906604399, 48.24507859445388, 53.4833804253609, 57.63466404330347, 54.30188494343912, 12.66406047728754, 0.07372023492691017, 0.5940399595325994, 0.7160867750644685, 7.161551713943482, 28.150266293556463, 56.26312494277955, 67.85069680983021, 78.65565776824951, 69.95012191034132, 43.34614415322581, 0.47730559603341166, 0.09827431817088397, 0.07267510713708979, 0.09765855967998506, 0.07119233629876567, 0.1004735574186329, 0.03116291309256227, 0.056749724993301984, 0.07374491061895125, 0.046364686887470946, 0.04053787576154836, 0.026649205397153576, 0.11026987610685249, 0.04800552847765146, 0.0051093420141466684, 0.05713866017157993, 0.0664195855478606, 0.019599342560996453, 0.12741008217656805, 0.06790735127945101, 0.11199981755306644, 0.05287087244552471, 0.04121594018332901, 0.17432031942711723, 0.15782983252598395, 0.08959340817865827, 0.2296689155721857, 0.16591397534695365, 0.16601254021929157, 0.09703015307745627, 0.13030220964743247, 0.19733778351256925, 0.21162984321915337, 0.20992610964082906, 0.2328071487887252, 0.2190577704459429, 0.27393097839047836, 0.14557910602419608, 0.13172783798748447, 0.16889837810829764, 0.22664472220405457, 0.1424834213309711, 0.1305530115120834, 0.1425547747602386, 0.2640869324245761, 0.18669961080435785, 0.2726808454721205, 0.22536175475726206, 0.3497018238469478, 0.46938440011393645, 9.285992710821091, 121.71633966507451, 113.73266112419867, 110.1888075182515, 126.30319072354226, 79.75425874033283, 79.31165849008869, 22.58894943421887, 4.085825878766276, 6.150980985933735, 12.705179664396471, 9.546432206707617, 8.452364513950965, 32.4307978922321, 96.57373505253946, 91.3363039878107, 90.60074190939628, 72.06267126144903, 92.3977836485832, 85.22643581513437, 90.01957216570455, 85.58366960094821, 87.79719644977202, 79.76171124366023, 87.14005039584252, 82.51475226494574, 90.79764489204653, 83.03056747682633, 84.34304744966569, 77.97210631832, 80.1888495106851, 73.6112073159987, 77.85872628611904, 71.34304969541489, 76.16224627340995, 72.15887915703559, 81.38799651976555, 71.50946801708591, 76.63878287038496, 71.44336823494204, 78.43036467029204, 41.21341420758156, 41.383550936175936, 35.55009218954271, 38.051544543235536, 35.68177007859753, 13.033266317459846, 4.056026406826512, 6.714398572521826, 1.7120801369028709, 0.7684624904105741, 0.1880662197307233, 0.18029033536872557, 0.185708737361335, 0.3268441197372252, 0.43076658200833107, 0.8119112589666921, 3.93115260427998, 10.134101317774865, 17.12505836640635, 63.43243706610895, 15.930930029961372, 15.81011220332115, 27.138467373386508, 19.57952072543483, 53.02094867152553, 35.031480327729255, 11.110818559123624, 24.304688284474036, 18.24265145486401, 7.442193377402521, 8.099125171861342, 6.570153899731175, 5.826776008452139, 0.6282103001590699, 0.2142563297022735, 0.19394041339476265, 19.717201802038378, 18.56067918962048, 10.826177058681365, 16.418742460589257, 36.5018827684464, 37.755354604413434, 44.1227852144549, 34.73385872379426, 43.20868861290717, 34.24802610951085, 57.35634442298644, 67.62208538670694, 66.71470780526438, 64.26760381267917, 66.88928465689382, 68.04712910805979, 67.97509085747504, 66.83819970776959, 74.78601209578976, 68.39403921558012, 70.31808730094664, 72.49904278785952, 72.87936364450763, 74.9822953439528, 75.45941245171332, 75.63227914994764, 71.25539256680396, 73.17121151954898, 70.92649398311492, 75.01398025020477, 75.48717498779297, 81.1251506497783, 75.21550378491803, 72.16864585876465, 60.97560951786657, 58.77970980059717, 67.04723065899265, 68.56794141953992, 16.412702991116433, 0.10856742189536173, 0.9426540917446538, 0.7062864267537672, 8.61942022077499, 43.535680924692464, 57.457329765442886, 84.59424388024115, 84.45390147547569, 83.09192903580205, 46.30281502200712, 0.38176631134363914, 0.195559463613937, 0.20032541916495372, 0.18379147975675522, 0.177476923432081, 0.18152536103321662, 0.16546861779305244, 0.2373358928748677, 0.16967277042567733, 0.10291427524099428, 0.1295071482778557, 0.317696355763943, 0.24217540818837383, 0.2359127160161734, 0.10713724299303948, 0.14602204274025657, 0.18084902797014485, 0.11642850289541869, 0.24665708383244855, 0.17508073830075804, 0.19707883047240396, 0.17917411461953195, 0.09603426941940862], [0.029862833156761144, 0.03077393577944848, 0.06259357008422095, 0.07189830930362787, 0.011409202857213396, 0.043281117874768474, 0.04926606870046066, 0.01140382875042457, 0.04024470157380547, 0.02300077869046119, 0.15844618090458457, 0.03531348170532334, 0.01281896934679319, 0.08049317996107763, 0.07937185706630831, 0.08016190055998103, 0.07710494161132844, 0.015916238884411512, 0.06609102575889518, 0.09163978224199626, 0.05966252917724271, 0.052721741939744646, 0.11291412050805746, 0.023393946504520795, 0.048980329396022905, 0.12828910678264596, 0.16819864872001833, 0.07534336073384171, 41.75153201626193, 91.60256231984785, 72.90576119576731, 104.64637294892343, 77.76546801290205, 57.14651330824822, 33.00201854398174, 2.9127229173337263, 2.8320858507387103, 1.8732910218738743, 0.8209922200729771, 0.6973657925282756, 29.98960687268165, 80.6221615883612, 79.44494062854399, 71.65483890041229, 57.34756223617062, 76.21171520602319, 82.8832354084138, 86.9113919042772, 81.35955933601626, 84.01776529127552, 84.51810283045616, 82.38324303780833, 81.85064008159023, 86.18011305409094, 81.77887639691754, 79.94022615494268, 79.81490642793717, 83.07712601077172, 78.08334473640689, 78.53324843991187, 78.11726539365708, 76.29639133330315, 75.08471627389231, 78.22851950122465, 76.62011238836473, 78.98186560600035, 64.60023649277227, 66.58272789370629, 35.73934655035696, 30.520758551935998, 22.983677156509895, 21.60738414333713, 17.422940807957804, 5.121263698224099, 2.010430321097374, 2.251523093831155, 1.2773921653147668, 0.6279863573370442, 0.2239536238654006, 0.0808965942011245, 0.036783772971360915, 0.1838413367588674, 0.11088440119619332, 0.12174456320222347, 0.41493779589091584, 0.6819196826507968, 14.500116071393414, 27.038680315017704, 15.09765092403658, 10.556501361631579, 9.36713380198325, 13.985773709512527, 41.22951553713891, 4.325490295886993, 9.513822601687524, 1.2407622534421183, 1.3142303305287517, 0.4069393783086731, 1.1823666191870168, 2.6518987840221775, 2.2050734056580454, 0.4711674850794577, 0.09829992849019267, 0.1977483913182251, 5.755906133882462, 3.6303877109481446, 10.862334447522318, 7.556663338215121, 18.675432051381758, 28.475677890162316, 35.34121421075637, 26.152691418124785, 31.481350929506366, 29.450522199753795, 44.715490648823405, 58.38322877883912, 66.72734568195959, 66.0515134565292, 66.27784206021217, 69.98328162777808, 68.23247678818242, 71.60813131640035, 70.70968104946998, 69.85614976575299, 68.3131677873673, 73.79851618120748, 71.00101901638892, 72.84766304877498, 71.34370080886349, 70.63794874375867, 70.826795178075, 71.38759997583205, 71.57841543997489, 71.0872797812185, 73.43918000498127, 73.73587592955559, 71.4948611105642, 62.308905509210405, 44.24585742335166, 37.88946828534527, 47.8478366328824, 45.863427192934104, 6.386286914348603, 0.38074710796917643, 0.7329850812112132, 4.4643951519843075, 11.174625715901776, 42.19950591364215, 65.58566531827374, 79.42343819525935, 47.89197898680165, 43.656391866745494, 10.371853824584715, 0.3435171041036806, 0.03630456582252537, 0.09375828348340527, 0.07695969900176411, 0.05380698975415961, 0.09527807169023061, 0.025730459132201733, 0.08381515170537657, 0.039984346592738744, 0.1014667674298248, 0.031950461054821654, 0.011903122724634747, 0.022213435656721556, 0.026390579859575918, 0.06639072701575295, 0.05143480232706474, 0.015100984394760623, 0.08000314415943238, 0.017878923587681308, 0.06363266493163763, 0.01837438137661065, 0.01953370223242429, 0.026139580727284475, 0.02752492624905802, 0.028996299614288637, 0.02015528107632793, 0.06565424072886668, 0.012797458555489298, 0.11380949343043952, 0.07603257939579987, 0.026742124201489553, 0.016965601225233367, 0.031446474792075255, 0.16512708047464972, 0.05100293941194973, 0.08028262835596839, 0.06620341085738714, 0.04129766261265163, 0.03716051969076357, 0.026832315732815096, 0.050030655092409546, 0.046754771197635325, 0.07703969390281747, 0.06510220543150941, 0.017429115062940027, 0.023386988510948517, 0.07717570515289422, 0.013189229216696996, 0.1169305432948374, 0.05172828678041697, 0.4137290623639861, 68.40439427283503, 105.8137801385695, 87.21700729862337, 110.73311482706379, 74.39947036004837, 69.29958112778203, 36.48176885420276, 3.093188717480629, 8.496638267270981, 3.199172385277287, 1.1210457548018427, 1.2826472833271951, 36.24392809406404, 89.81329471834245, 86.18656143065422, 83.18284957639634, 66.35803884075534, 83.24279908211001, 86.63589246811406, 90.06962945384365, 84.3042395191808, 85.90822219848634, 85.73280595964002, 84.90084771187075, 81.83433086641374, 87.81152879038166, 85.56610522731658, 81.32340292776786, 79.79769506762105, 83.28131675720215, 78.11143675158101, 78.68752310352941, 76.92075421733242, 77.05540134060767, 76.9389618596723, 75.9015812412385, 77.37791430565619, 77.82066360596689, 66.21098133825487, 58.37749035127702, 35.842748072839555, 30.879292603461977, 26.919153928756717, 28.25087901084654, 23.76318350914986, 6.766306238789713, 2.7466436355344714, 5.453460504931789, 1.219958124622222, 1.0585483019390414, 0.1939555819356634, 0.11519436589291981, 0.06636226684936593, 0.2812484663821036, 0.08912630138858672, 0.19055387576020535, 0.37346326655918555, 3.7711311780637313, 19.353462765293738, 37.214569584015884, 16.310960631216727, 1.3267458783042048, 7.777566323357244, 16.904950641816665, 52.27166614224834, 5.937788399957842, 7.785765057609928, 0.4456410064331947, 4.84839960452049, 4.40122930272933, 1.7466561976940402, 4.570828666610103, 4.896271151881065, 0.5151617082376634, 0.034384577114495544, 0.11332437591326815, 3.187477348312255, 9.218836830508325, 7.762958926539268, 5.946643150621846, 17.32636224838995, 30.300792032672515, 38.13753858689339, 27.088102179188883, 30.75967796387211, 30.63160865537582, 41.27888248812768, 60.557504469348544, 66.70013227770406, 66.4973928082374, 66.3923046665807, 70.96351331280124, 69.92923136680358, 72.24175099403628, 70.00172461232832, 70.42058667828961, 68.49660135084584, 72.3180881623299, 72.04112960446265, 76.3901516699022, 72.14477431389594, 72.98080398190406, 70.48587845217797, 74.16168843546222, 72.4252002469955, 74.866483442245, 73.72170048375284, 76.46406481342932, 74.35314716831331, 68.37452934634301, 49.74324357125067, 45.13185808735509, 55.13998562289823, 57.61061206940682, 7.6897454357916315, 0.08129161977840048, 1.074286321959188, 5.450344672126155, 20.667611706641413, 55.77926920306299, 58.43738886617846, 83.95658416132774, 65.10507691291072, 61.82441826789611, 14.723854930170122, 0.11176409995964459, 0.04602090110101047, 0.07844228597898638, 0.014385671820491554, 0.009573325815220034, 0.07352892745045886, 0.1149471493197545, 0.05217680061656622, 0.07385828397086552, 0.03003396762294635, 0.035385639526911324, 0.022117442924589403, 0.026313076659496275, 0.03869604717399325, 0.04968317676215403, 0.06564214420054229, 0.03969295738985942, 0.09353486160116811, 0.05353917690715002, 0.016360297919281067, 0.11603010653127586, 0.05156247854052533, 0.02564288953679704, 0.08685747071379617, 0.13626173018447815, 0.19628012252430763, 0.21207481772909242, 0.0977057813396377, 0.17769630037007794, 0.20792573149646484, 0.12905819011071037, 0.16434361767624656, 0.16184868381148385, 0.5516070848511112, 0.10649801156814061, 0.19470706822410708, 0.16008858148369098, 0.1935796166259435, 0.13514857378698167, 0.12563566932634962, 0.17046234660571621, 0.16006231998964665, 0.21230911805985436, 0.10760749074360056, 0.1676682400847635, 0.2530232591614608, 0.18423170452156376, 0.13066774083962365, 0.17440982914019018, 0.2893340954136464, 0.18734235857282916, 67.08123760838663, 127.37468027299451, 97.72222857321464, 121.1449444678522, 98.2301833552699, 78.12350196223106, 51.811003377360684, 14.138118567005282, 18.08576253152663, 5.843276439174529, 1.9044321895607057, 1.8082122817154855, 41.91983699798584, 108.0388387556999, 95.81184602552845, 86.83341518525155, 74.37398279866865, 92.1894116555491, 88.24694325847011, 90.85535080202165, 85.45663972054759, 85.80627195296749, 85.67146009014499, 86.79351683585875, 83.85976437599429, 93.69625291516705, 86.00820341417867, 83.84691469130978, 78.38154685112738, 85.38009074426468, 77.28365975041544, 78.67851734161377, 75.16136723179972, 77.24910366919734, 76.82064748579457, 79.92597226173648, 75.32096062937092, 79.37665216384396, 67.81108871583017, 78.8187812989758, 45.45261775293658, 40.48789731917843, 33.0189984844577, 34.33603232906711, 24.24076737896089, 9.02725846536698, 9.369298950318369, 10.803544982787102, 3.5750668471859353, 1.3935553643011278, 0.4912074871601597, 0.3132825861534765, 0.13853935554863947, 0.30097670132114046, 0.24941997993136608, 0.8345210876676344, 0.8178125261779755, 11.092637392782397, 28.051122503895915, 59.55569974837765, 17.82718223910178, 17.3884416011072, 22.97973321330163, 20.049881550573534, 51.53739452362061, 27.59028127116542, 11.457697287682565, 3.1211873312150282, 4.748966049763465, 8.281579613685608, 5.301618691413633, 8.469766109220444, 3.5138398745367607, 0.5815353208491879, 0.2779440227295122, 0.5045154456409716, 8.544082276282772, 21.1070603324521, 11.48487146823637, 11.978382122132087, 31.084081511343683, 38.56777160398422, 49.37072823124547, 33.38698740928404, 41.38504928158176, 36.4295542624689, 59.74256538575696, 67.33406574495378, 67.29588539369645, 68.04247717703542, 66.37164946525328, 74.10188013507475, 68.13934403081095, 73.60844596739739, 71.87391111927649, 73.23650329343735, 68.52652119052026, 75.67169112543907, 72.2722827234576, 78.31575301385696, 72.3884476384809, 74.22663504077543, 72.62928116706111, 75.92098128411078, 72.69307459554365, 76.50656761661654, 74.77280939778974, 76.19182878924956, 76.58856868743896, 72.6324269079393, 57.36309089968282, 54.13641975771997, 63.84815339119204, 68.5303964922505, 9.664907397762422, 0.7630018769733368, 1.0622262594199952, 6.152285664312302, 35.613352175681825, 61.40828224920458, 77.96193953483336, 105.15399825188422, 73.91754442645659, 71.19855742300712, 14.907469903269122, 0.5174119842629279, 0.144198247862439, 0.2266662186312099, 0.23546052495798758, 0.18810320645570758, 0.21955643239761555, 0.16791096738269254, 0.17405214268834363, 0.2455180183413529, 0.17640297541454916, 0.07870758988804395, 0.08995040515137297, 0.17540569747647933, 0.16010097678630583, 0.1530959607372361, 0.19161499946588473, 0.11357608942254899, 0.15293713538877426, 0.12810474772366787, 0.1195580563357761, 0.24635853936835644, 0.10354373904485857, 0.08726830068495005], [0.024068486921849753, 0.016809989615613898, 0.03584746031030532, 0.0988353856448685, 0.04511923476633045, 0.07420687695905086, 0.09104827043390082, 0.005186781533167608, 0.061677968610198274, 0.06560199353243075, 0.017267775030866746, 0.03717461570857033, 0.04464467011031605, 0.1081926133784075, 0.0879370571384507, 0.07590239041394765, 0.0915675018463404, 0.012384369582568687, 0.017688520094980637, 0.04416896781373409, 0.025317870989261616, 0.05117178902090077, 0.03626028977094158, 0.062152690314237154, 0.04635940471123304, 0.037692667345606515, 0.21737965484780652, 0.1886206069180081, 20.359884115957446, 100.08656271042364, 79.98590607796946, 92.5016087870444, 94.93577680280133, 49.88677094059606, 41.91403973487116, 8.812778361382025, 1.2636581087304701, 0.41144017550733786, 0.007526712349405693, 0.4766673528619351, 31.70668325116558, 66.13053352602067, 70.69341105799522, 61.91320111674648, 62.41040468215943, 72.28687394049861, 86.51422839010917, 84.63893536598452, 88.05211128727083, 82.19708734943022, 86.75352434958182, 84.37249660491943, 83.90700540234967, 84.6106158533404, 83.90760160261586, 81.28555990034535, 81.8823799010246, 80.77450644585394, 77.3480886028659, 80.09312014425956, 77.854764692245, 77.64406281132852, 80.56444783364573, 79.26197774948614, 75.02618666618102, 73.40119577223255, 70.8343888867286, 61.70446826565651, 39.083425998687744, 30.414717274327433, 23.90464182822935, 25.78775998084776, 22.68280390770205, 9.391004366259422, 2.5650663337399884, 0.6989229121996511, 1.7157376245144875, 0.8282424761883674, 0.0865288649595553, 0.2108041383326054, 0.09623968823542518, 0.07791750042909577, 0.42650924755200265, 0.7484849398174594, 0.47757103017741637, 1.257217944629731, 11.288386218009457, 16.780725256089244, 15.377775815225418, 6.583096740707275, 9.592555357563882, 7.696062903250418, 25.950097076354492, 3.259889694952196, 2.148288026932747, 0.1199359062217897, 2.837537454981958, 2.0985317807043753, 0.24806498489793272, 0.30203908141101565, 0.27115164204470577, 0.1477543054328811, 0.0934908651716767, 0.24952046002351472, 0.5459958278844433, 2.277802238541265, 9.756310389887902, 7.68142952073005, 26.097990043701667, 28.558710544340073, 34.185852619909475, 25.18674304408412, 31.9170380023218, 33.7117753490325, 41.89441219452889, 59.29957289849559, 63.2879134147398, 67.89101093046128, 65.49106167208764, 71.06656966670867, 67.90473138132404, 69.59453551999985, 70.55130358665221, 71.6706774311681, 71.02878155246859, 72.76723877076181, 70.45628809159803, 75.21428785016461, 70.33176068336734, 73.88622037826046, 71.75510252675703, 73.11761625351446, 68.74496583015689, 74.77980690617716, 73.63982492877592, 74.79257029871788, 67.25418275402438, 60.46639565498599, 41.18253338721491, 39.12969427724039, 48.24077967674502, 38.03299957706083, 2.25434965183658, 1.2649403560546137, 7.821621894836427, 15.459874945302165, 29.05704571354774, 55.52424061682917, 73.15560048626315, 56.101256570508404, 44.66447630236226, 33.86586958362211, 1.6685441568974526, 0.2099962986164516, 0.03451843565750507, 0.11009578262605976, 0.01530271641264159, 0.05919770149874592, 0.030660215772748477, 0.09628424390910134, 0.01851040220278646, 0.03744379985296438, 0.012418368564648254, 0.040353248571796764, 0.022205491324946768, 0.15367219675212138, 0.053896070457994945, 0.03811706090345979, 0.006100756985570995, 0.04175080361986353, 0.02355238497858086, 0.00838727519411834, 0.06338298921623538, 0.13821661802789859, 0.10204497995155473, 0.024286921571699843, 0.030364791201728008, 0.038579383474444194, 0.05364076782678885, 0.061638553386494044, 0.021211547784567363, 0.03712389302710372, 0.08431448015354334, 0.028322414202134938, 0.0748156410672011, 0.06013664567182141, 0.06317071774373613, 0.09491097767867389, 0.022338953417455478, 0.02374158762846022, 0.03254407002860981, 0.035296708210221225, 0.03260187136249677, 0.03421244864922858, 0.05921372039724262, 0.019224059069529176, 0.05712836778031723, 0.03140458893481522, 0.14762966292760066, 0.01826217247834129, 0.02314813570269654, 0.04041679939555545, 0.23444067806966845, 0.12920953844103122, 31.341275245912616, 116.08558116420623, 84.76037979125977, 102.52245656905636, 91.58040877311461, 58.3665547832366, 52.301884082055864, 13.226212609198786, 0.9942170797336487, 0.44367648120368686, 0.1277618620905184, 0.5854325633375876, 38.97914194291638, 81.49357888006395, 84.06357073014783, 75.89140661301153, 74.19529530309862, 83.65702490652762, 90.82398753012382, 90.72119005264776, 87.77402308679397, 86.17550034676829, 88.0672045676939, 83.6621004535306, 84.54547312951858, 84.98564151025589, 84.19877482998757, 81.57346187099334, 84.05184284333261, 83.41203366556476, 78.41917022582024, 78.2260327185354, 78.72469148328229, 79.50023035849296, 79.55021704396894, 78.96062989388743, 76.0836184409357, 75.78396504925144, 72.32173596659015, 61.29239974483367, 35.43653172831382, 30.44029308903602, 27.729531295837898, 29.268755643598496, 27.787184253815685, 14.080033167715996, 2.884873598814011, 6.047999647355849, 1.0908414207158552, 0.850527483609415, 0.0967050560059086, 0.13193644372926605, 0.28591014204486725, 0.31882532421619664, 0.3570464313510926, 0.8687517960225383, 0.760895748051905, 2.0686143925113063, 10.097931181230853, 12.643193467970818, 15.41441369441248, 0.5775607954109869, 3.9564540982246403, 7.03106769630986, 20.33911712708012, 5.041102709308748, 1.9851231887455911, 0.1777763105928898, 8.459504208257123, 5.356568646046424, 0.3733884350907418, 0.719160013381512, 0.8855399080822546, 0.19440480057270298, 0.017746993671021154, 0.10678554734876079, 0.6757285890559996, 6.66705213246807, 8.450198385023302, 7.247667841372952, 24.78125233804026, 31.9281598829454, 33.75767492478894, 25.34053917854063, 31.94507314312843, 36.7691413048775, 45.89056999452653, 64.05490936771517, 66.5727101602862, 67.82058085164716, 66.65516622604864, 68.3472296499437, 68.56115571914181, 69.5017400864632, 71.43177370871268, 69.90635610395863, 69.50664304917859, 72.15637668486565, 73.0047147504745, 75.6451759030742, 73.88001518864786, 74.35162528868645, 73.3417247956799, 73.53914553119291, 71.92316039916008, 75.12549323420372, 75.0671911239624, 78.64819742018177, 72.73574998301845, 65.86346718572801, 49.12140277124221, 45.00233357952487, 58.99944097765031, 45.308494183325, 5.166903907252896, 1.4958461205805502, 10.066058981803156, 23.9176837090523, 45.596827614691954, 60.72936311844857, 73.92178058624268, 77.83975770396572, 57.32305526733399, 48.45272102663594, 3.143698549078357, 0.21961583485526426, 0.10708275115898541, 0.10784873949183572, 0.05452270739741864, 0.05034484307191545, 0.016956705029212663, 0.09462581677061897, 0.056799118512219963, 0.11243240442126991, 0.10716518221963799, 0.043495890624340505, 0.07731999015255321, 0.10520978875818754, 0.077846989696545, 0.019540202488461812, 0.08355713329247891, 0.009922263542971304, 0.04052726161335746, 0.04159452934418956, 0.06925000463642421, 0.1744329956390204, 0.008331558576995328, 0.024681906929359804, 0.09860181309763463, 0.19284435607973607, 0.08847308885906974, 0.20181726814518053, 0.12239690239150679, 0.3136744860920214, 0.2401908420987668, 0.21689024723825917, 0.19462011724470124, 0.14069125056266785, 0.1921771854282387, 0.17327814873668457, 0.20021845796896567, 0.17823505936370743, 0.11735055099932418, 0.12863871100689137, 0.11642114845134559, 0.10366568492064554, 0.18597248611190628, 0.13625031547440639, 0.13489642360758397, 0.11756871751840077, 0.25784212074452834, 0.11399788211189932, 0.21671153424728304, 0.11379749649354529, 0.39882895867190055, 0.4068590922942085, 34.125965872118556, 135.06284744508807, 100.87281750094508, 114.28478963913457, 112.76001530308878, 64.95765462998422, 64.76971034080752, 22.183994131703532, 2.651167261985041, 0.4983167218104486, 0.5918538510318726, 0.7260218935628092, 45.28254378226496, 91.24976081232872, 93.31081728781425, 83.23359720168575, 83.08650832022391, 89.55767385421261, 93.38249468034314, 90.69700471816525, 90.70142915171962, 88.3668108909361, 88.53832829383113, 85.59888055247646, 84.72798101363644, 89.14345587453535, 88.06388624252813, 83.90993933523856, 83.32500411618142, 84.49506282806396, 78.86057807553199, 77.91775795721239, 76.20896170216223, 77.56658815568494, 80.90453301706623, 80.3686744936051, 77.33675295306791, 77.55383260788457, 74.09530624266594, 72.66321751379198, 47.942279461891424, 39.73041311387093, 30.852438096077215, 36.926416581676854, 32.242292704120764, 21.502237166127852, 5.749218983034934, 14.722569373346145, 4.462885529764237, 1.3275453063749498, 0.24907763055976362, 0.6863408679923704, 0.43493391645531504, 0.2529474624222325, 1.110500340019503, 3.1618267634222588, 4.080858687239309, 3.9928612930159417, 22.57865713488671, 42.76226405174502, 25.81044500873935, 16.3843923038052, 24.037947500905684, 17.13470543584516, 49.02587344569545, 14.665240010907574, 4.578817063762296, 0.5001205524369594, 9.471120738214063, 6.171827402807051, 1.0912039948086585, 0.9373079624868209, 1.2191850499760721, 0.28825516782460675, 0.2552643727751509, 0.5214454065407477, 1.8546700597770753, 16.88416600227356, 11.687380498455418, 10.840158347160587, 39.28924060636951, 40.42928141932334, 43.98911083898237, 31.993286917286536, 41.517499877560525, 42.795400234960745, 56.39433214741369, 66.89966324836978, 65.79150346017653, 69.29828674562516, 66.82262789818549, 71.33154146132931, 70.02163456332299, 71.73053279999765, 74.16401832334458, 70.93378959163543, 70.63579928490424, 73.06176954700102, 73.32995768516295, 78.21150425941714, 74.69082401644799, 77.31965926385696, 74.10001308687272, 74.56159760875087, 71.22772416760846, 75.14039824085852, 77.27605035228115, 79.96019101911976, 73.39513178794616, 70.95103233091294, 56.5481988845333, 53.619753391511985, 66.0884778730331, 54.64414704230524, 6.638300178512451, 2.397653446082146, 10.326174882150466, 32.70298292559962, 58.348633473919286, 68.47020379958614, 95.30471494120937, 82.12540211216097, 72.10078101004325, 55.758951325570386, 2.5408079451130283, 0.45020036339279146, 0.21722839844803657, 0.2711285061893925, 0.19373482603940273, 0.16062202382712595, 0.16643675374648265, 0.2921188556619229, 0.17961590220370602, 0.26999512507069495, 0.15425716616934346, 0.24493704790309553, 0.13791620430927123, 0.2954211236248094, 0.17083469598043352, 0.12966795013316218, 0.190744309896423, 0.17758426767203117, 0.15185353466339652, 0.18524376795657221, 0.07737730119016863, 0.2732727250024196, 0.251392487797045, 0.09199534663029256], [0.052886029495106596, 0.03809671743863052, 0.052394162743322314, 0.061064742039889104, 0.026564876353668592, 0.02521659225045193, 0.053389402887513565, 0.03329170289479437, 0.03222077326368421, 0.04584175143991748, 0.05482589052389226, 0.09356153678269157, 0.04303116253727386, 0.0502513382103174, 0.1968877834658469, 0.028583426103596727, 0.046011443745585225, 0.018126783674703013, 0.0761721835982415, 0.053682772427677154, 0.11549815039841399, 0.0756159731216969, 0.08387364251839538, 0.09674717551998555, 0.09548834750368711, 0.0934585286003928, 0.0980396731005561, 0.07506980605783962, 4.576542579358624, 82.43963103140555, 93.84935871247323, 100.14208778258293, 109.70707770316832, 65.21344807840163, 41.23821535418111, 15.80976801533853, 0.9403531926293528, 0.17211980847341402, 0.055085149999227256, 1.1123733943508518, 23.16634193543465, 65.95816104642807, 76.44588070531046, 65.30084633058118, 54.54053371183334, 71.66535869721444, 84.55460440727973, 90.65617284467145, 85.43828302814116, 83.63964096192392, 85.22565918584024, 86.20440037019792, 87.89315331366755, 88.32048769920104, 86.27956082743984, 87.30988117956346, 84.39316749572754, 79.47177748526298, 79.95702958876088, 78.59691635254892, 75.82843688226517, 75.31623809568345, 75.65567216565533, 77.30108291872087, 78.50838845775974, 76.54528925495764, 71.25332940009334, 51.22481692221857, 39.53403572882376, 33.439319672123084, 24.310518887735185, 24.104519928655318, 20.836916892759263, 9.680023231813985, 3.5462374264194123, 3.1994359195232396, 0.9508957882081309, 0.12882965076113903, 0.27962334874656897, 0.021046961454914945, 0.07073312021431423, 0.13339584122502035, 0.059515704596114744, 0.07460295973766236, 0.19755074063376074, 1.6519301000141329, 1.2917056295179552, 1.8634836255542695, 5.546536387935762, 0.477800366258429, 3.61564229572973, 1.1703314391836044, 2.8633890613432857, 2.019634040132646, 0.7208317398063598, 0.1531048013918823, 5.826108715226574, 3.44276677216253, 0.1102327591469211, 0.027797017697124716, 0.2797870464142292, 0.08358864248880456, 0.15182207909322556, 0.07914766143526762, 0.13861700622064455, 1.5572562188871446, 6.819011617091395, 6.555375879810703, 14.926172744843269, 25.192250051806052, 32.546621561050415, 29.586120497795847, 28.34022471981664, 32.48997665220691, 33.780161872986824, 51.13164886351555, 63.40564335546186, 69.95216154283094, 65.57179189497425, 69.78730432448849, 70.78765776849562, 72.72145686611053, 71.60515815980973, 73.12071492595058, 73.55634120202834, 70.98854587924096, 72.11035943800404, 73.52522111708119, 74.14231192681098, 75.93496061140492, 74.46197725111439, 71.97682626785772, 71.0082204880253, 74.72146557223412, 74.73698246863582, 73.98216155267531, 69.77611772475704, 56.67726839742353, 41.378722498493815, 38.6712319620194, 51.82815590212422, 25.03429816615197, 7.94017308181332, 12.819780534313573, 15.950681124964069, 26.436722009412705, 43.03910101613691, 59.031286701079345, 76.41352115138885, 43.10177264675018, 55.341289504881836, 15.750180348273247, 0.30092154299059226, 0.09879020943997369, 0.05948526409244346, 0.058188798176425124, 0.09237989212476438, 0.08693102281540634, 0.014915818070632317, 0.1565400928619408, 0.012679283747509604, 0.024054674356574976, 0.014477275826427487, 0.1306203046753522, 0.05966502662387587, 0.07285154484693082, 0.045135307290981856, 0.07625924182995673, 0.047823073147165204, 0.07286903463424214, 0.015846325700441678, 0.03332445315355736, 0.06845068381798845, 0.029581475875250278, 0.015669354601883363, 0.03520693802725404, 0.04671701455428716, 0.053240180451182596, 0.024378176050020323, 0.04633254183816814, 0.08121025357996264, 0.09594231588585724, 0.04917448288911293, 0.030028572448739604, 0.04259322454491931, 0.021885504059854056, 0.03119653286111932, 0.07409883557908958, 0.07229531904862774, 0.049590598866944356, 0.044296961953683246, 0.02950938508635567, 0.05111830459246713, 0.015197970168364626, 0.011017250250123683, 0.03214270124332078, 0.03625725223232181, 0.020355459850942417, 0.01962389184853002, 0.05296607419187504, 0.1023467573066873, 0.02181914552385288, 0.1293671380488142, 0.12171565870484038, 11.175278790535467, 110.11761649962395, 100.78113602053736, 103.5343574708508, 109.48354182704803, 60.87560084558303, 61.050930792285556, 17.464919974727017, 0.5977326871887331, 0.0296179186778083, 0.2987886929223615, 0.8939188262147288, 33.66397342374248, 83.76029306842436, 92.08927354504986, 74.36751873262467, 72.0681861139113, 82.19960551108085, 93.05904034645327, 91.50059638484832, 88.25509394368818, 86.9767778150497, 86.44120954698133, 84.36704451037993, 86.75692112215104, 85.8585963710662, 87.75681172647785, 87.48991012573244, 83.99651388968192, 80.37694284992834, 80.30589303662701, 79.62575404874741, 77.44558303586899, 75.90828849423316, 77.46948595969909, 77.75384995245165, 77.96186893217026, 76.84505247300672, 73.8098910547072, 55.81649641836844, 37.71606030002717, 33.14426722065095, 25.96002067289045, 29.904603227492306, 28.356645722543043, 12.096304258992596, 3.966516693753581, 7.021020054817201, 0.6866314298202915, 0.7781804076606228, 0.01676911116397429, 0.03227639124698697, 0.35176440833076356, 0.37606303189550677, 0.3930063533686823, 0.14296909043144795, 0.990801124322799, 0.8983656908235244, 1.6775414612024062, 3.6326928388687874, 3.9883174723194497, 1.5087878583900391, 2.537787229784074, 0.6229424957306154, 3.886174540365896, 3.6891521705735117, 1.9495414077274262, 0.40525502675483305, 6.195573922126524, 4.889251089865162, 0.19811672639221917, 0.3493767574189171, 0.21903929240520925, 0.18396072390098728, 0.0940488682939641, 0.12594741348537708, 0.12498240317067794, 8.194602526003315, 6.611302994912671, 8.445597444811176, 10.287368912850658, 22.844509501611036, 33.13679510547269, 27.769015835177516, 29.648419503242742, 34.671010586523245, 40.93758921469412, 59.84952057561567, 65.41126889567222, 67.51336513027069, 67.60471713158393, 70.95982628483927, 69.161160684401, 73.23566390622047, 70.62666016240274, 70.54359220689344, 70.85659734664425, 73.4692959631643, 76.96144488550003, 76.77923510151525, 74.5301401999689, 72.85329557234242, 74.62383777864518, 73.68964687470468, 71.59067676913354, 74.96996341213104, 78.00102987597066, 76.36460919534007, 73.2608376779864, 62.24134268299226, 48.47511776031987, 44.473260756461855, 64.02546805720176, 33.84799142037669, 7.612306081479596, 17.256347940814113, 27.495956113261563, 42.342676347301854, 52.5948106088946, 65.94877089223554, 78.31455276858422, 60.33276442558535, 66.3551127526068, 24.055747216747655, 0.2744512440216157, 0.07201638643539722, 0.08304853518042835, 0.0604318231794863, 0.030702708754688505, 0.052578368584715554, 0.1512488921082789, 0.22271660637230645, 0.05262730628131859, 0.04523508258224015, 0.08336485288436375, 0.018148046445041414, 0.08795008063316347, 0.033721213919981834, 0.011850418748273965, 0.024727720902451587, 0.04985104577856199, 0.05491567219817831, 0.02952513585407888, 0.027312137667209874, 0.008609243424519176, 0.02050058946253792, 0.0377710189880623, 0.03534353533459287, 0.283790591263002, 0.1286249367460128, 0.11227931707136093, 0.2595484437000367, 0.2058205372023006, 0.21934825566507157, 0.18048702078240533, 0.14879903485698087, 0.12196659080443845, 0.20190509246482005, 0.11560072191059591, 0.195623324703305, 0.2163606353344456, 0.14491469328922613, 0.3449037845336622, 0.11345368389400745, 0.10896237086384528, 0.1360304175966209, 0.31099339286165856, 0.12308258172725478, 0.14810407053559058, 0.14097022914117383, 0.20723240660323253, 0.141971398805899, 0.19515129196788036, 0.19218499952506637, 0.24132246121523843, 0.36816576856278604, 7.6122717607405885, 118.2123451848184, 118.51465794347949, 120.29912456389397, 129.1085796971475, 78.5104751586914, 68.0438421618554, 32.08138139017167, 1.715657583648159, 0.2104240208263359, 1.273051082126556, 1.3687587529420855, 39.16275985779301, 98.72899901482367, 101.73597428106494, 84.38940202036213, 80.46683572953748, 89.52840512798679, 96.73696056489023, 96.66074106770178, 89.56669530560895, 86.57283644522391, 88.05876362708308, 87.3158431822254, 89.30708146864369, 93.4144070840651, 90.10554267514138, 90.78310858818793, 86.42417861569314, 82.00886064960112, 80.67728657876292, 78.78235816955566, 74.93086522625339, 76.0515256081858, 75.89547803325038, 78.4195859970585, 79.26199343896683, 81.49309250616258, 76.14820418819305, 64.34840856059905, 51.92084543166622, 42.30488431069159, 30.09883507605522, 35.082125971394206, 32.590863935409054, 20.04691427753818, 9.012619199291352, 16.359518593357457, 2.470856885756216, 1.2048443743298132, 0.34179144508896336, 0.10650799369379398, 0.2854411123741058, 0.20778694700810219, 0.3501126614789809, 0.29897711990821746, 1.3924605327267803, 5.79248272603558, 5.538605845743611, 10.543347693258717, 13.206160472285363, 5.6482552136144335, 15.40284368299669, 2.3150343568094316, 7.643275645471389, 8.784608879396993, 3.1021736418047263, 0.3410012713603435, 13.760597302067666, 11.414833626439496, 0.2567488826330631, 0.31710996142318176, 0.3605791998486365, 0.41095282101342756, 0.15695345858412404, 0.39114240016187396, 0.14065918212215747, 14.571193341285953, 8.893421311532299, 11.939915437852184, 21.857588214258996, 33.60401215091829, 41.45479294561571, 36.79203617957331, 36.30938852986982, 42.380323256215746, 44.43926557417839, 63.76277515965124, 64.10648069074078, 72.05866259913292, 69.03553501252206, 73.26625054882419, 68.85123852760562, 73.49244579192131, 73.35022849421348, 73.31024385267689, 74.04756315292852, 76.08230836929815, 78.47148679917859, 78.69537568861439, 78.83534154584332, 78.86517509337395, 74.69553086065477, 73.93872522538709, 71.22691615935295, 77.38350760552191, 75.92832396107336, 79.14659730849728, 75.68119110599642, 72.42050909226941, 54.570794797712765, 54.649097073462706, 70.60283568597609, 39.38739791993172, 9.946133494377136, 18.565170303467784, 32.21554213954557, 55.13331367123512, 55.76516435992334, 81.5089153474377, 96.4501254789291, 72.00924073496174, 77.549266969004, 24.106992983048965, 0.3121351090169722, 0.20165070530868348, 0.2727678424168018, 0.1890780226958375, 0.1527394847043099, 0.213857059997897, 0.21725150365983287, 0.4320455198326419, 0.17317498733680095, 0.1861890285245834, 0.1619099708454263, 0.20035310558253722, 0.2585617837405974, 0.12767825891534168, 0.1574547865217732, 0.21745566609165362, 0.2370823024501724, 0.21599571701259385, 0.1475851378974415, 0.1532432947668337, 0.17950728625780155, 0.197313038872615, 0.2382678235129964, 0.21363202933101885], [0.030738599973941044, 0.04350848127937606, 0.019539101237070658, 0.04209123011077604, 0.05024088111015097, 0.011946963063711602, 0.0432998065896813, 0.006541247008323309, 0.0667592229682111, 0.061408546978547696, 0.01667692014316638, 0.04186205873866716, 0.06878317363800542, 0.0704412636978011, 0.02093840488082459, 0.08444042500829504, 0.021589738579707283, 0.0409305839228534, 0.030527305263545246, 0.08708077002196543, 0.04569344447865602, 0.07071333982410931, 0.013286773276875817, 0.0330781405641427, 0.0752657407053536, 0.12518432096488055, 0.07065783675399519, 0.015005573889450922, 0.02784644377477948, 29.773817677651685, 102.4550231810539, 73.37882257276966, 104.9239355517972, 93.47338384197604, 39.24408235857564, 35.127841195752545, 7.076906965624902, 0.6896079571977739, 0.13419609667072374, 0.6663184552904099, 8.970550798600721, 54.521235650585545, 58.886437492985884, 64.38057984075239, 58.07542470193679, 72.01191579141926, 85.7609058195545, 87.1449141348562, 87.096402260565, 87.54429771054177, 85.9911960171115, 86.42098580637287, 89.78958006828063, 85.92955989222374, 94.71810094771847, 87.20120014682894, 86.56417585188343, 83.55587482452393, 83.27742576599121, 78.23958058511057, 79.29768700753489, 77.6418976629934, 80.84072389910298, 78.8851870259931, 78.08313292841758, 76.16124214664583, 69.32791632990684, 50.133676298203014, 38.75088353310862, 24.46478766779746, 25.252678086680753, 28.13736365687463, 21.564777397340347, 13.147027800160071, 1.9217700463148857, 2.206413140220027, 0.6101433115620768, 0.11391518292047324, 0.31190911307930946, 0.3966580799991085, 0.3729010499533146, 0.9856053321592271, 0.18530093343748202, 0.16777065071848132, 1.1276892692812028, 0.28221649508322444, 0.6524103435297167, 2.846478988086024, 1.3455598945579221, 0.10457946693584805, 0.19949606769988615, 0.15024505645757721, 1.8481828272342684, 0.7204825262869559, 0.44205641974845244, 0.16533199367263626, 1.1954849862283277, 2.0629958423875996, 0.5460033661896183, 0.10756031504922337, 0.07873189019700212, 0.05113136639157611, 0.055412422760479876, 0.09666363363184276, 0.1370204176994101, 3.582998860266901, 7.375962686154151, 8.52964795404865, 27.799659352148733, 35.48896205040717, 29.543568664981475, 30.43551171979597, 26.46267241047275, 33.11744605341266, 33.56179175838348, 46.40205883210706, 62.176760858105084, 69.90729747279998, 69.24514647453063, 71.0188187322309, 71.90174425801924, 71.26273524376654, 70.02449004880845, 71.97269993443643, 70.8663248246716, 72.46551436762657, 75.68158334301364, 74.69990038102674, 77.62003437165292, 77.86434312020579, 73.86024644297939, 70.38293192463537, 72.22433567047119, 74.51474881941273, 73.11662781623103, 76.36202043102634, 65.5795777997663, 54.395547220783854, 44.08493434229205, 41.595029446386526, 53.739530809464, 22.430381736447735, 20.720985358761205, 24.246827440877116, 16.321567700755214, 36.24540290524883, 40.728836751753285, 72.71854646744268, 49.72826796193277, 46.490492590012096, 38.037584827792266, 1.1734938501350343, 0.25823999616888266, 0.046361438674672, 0.09287645499552451, 0.18878796648594642, 0.05354393814359942, 0.06432228195931643, 0.08762312962883904, 0.10507878006225634, 0.05563697462240535, 0.010849386979375156, 0.0820333231240511, 0.037994057826337316, 0.09260614087144214, 0.08184079756780017, 0.016635913371799455, 0.012921397217489299, 0.02427931048817212, 0.09639769386980804, 0.04980349853154152, 0.042612989613365744, 0.010604370993772342, 0.03691827885866646, 0.07532372590034239, 0.0352691596884641, 0.034420560264298995, 0.06681091858134156, 0.08653299417346717, 0.03756569976347589, 0.05330366998790734, 0.028067810626159755, 0.017433924179884697, 0.017632637811344, 0.0460995668395152, 0.0552662416932083, 0.06498870184464801, 0.020622619607996558, 0.06693294106592095, 0.05640148440556181, 0.07264930529580002, 0.14748478037936075, 0.030299311751619946, 0.03648042130554396, 0.03899587100491889, 0.03971928400137732, 0.0017128667827965994, 0.07726918320141493, 0.07395140195806181, 0.021613062126562003, 0.04087395470349058, 0.03671122061449193, 0.0559432067788176, 0.025341179214357853, 0.4340962452753898, 58.259215201101, 117.81768414282031, 96.7565724157518, 114.62720471043741, 80.00583956318518, 53.37175761499713, 50.72036873909735, 8.282250338985074, 0.7043589495362774, 0.07946594798516843, 1.2208921390195047, 13.758957751335638, 72.5676764211347, 87.39702055531164, 78.9994142901513, 67.90305260689028, 86.9172989937567, 93.4347955642208, 95.04414404592207, 90.26161378429782, 90.54117679595949, 86.2861817882907, 89.4738998720723, 88.21833349043324, 86.25908605514034, 88.31978951731037, 86.19257050175821, 85.62519181159236, 81.42502369419222, 82.27864127005301, 83.27963013802805, 83.17902134310815, 77.65519449787756, 81.81650761635073, 78.00011988609069, 78.67122957783361, 76.47346281236219, 73.90438879689863, 56.32296069975823, 40.62547837534259, 25.619335366833596, 26.65864383020709, 31.9854853230138, 28.91515201137912, 14.217213161530035, 2.363024801015854, 7.278373135674385, 1.8956186237835118, 0.3762503250712349, 0.5924467417982318, 0.8560737763201037, 1.2630008665784713, 1.2645069341505728, 1.293284873808584, 1.2430395570493515, 2.9569454346933677, 0.8415804346722942, 0.3470965733210887, 1.0172665816160942, 0.8081797979051067, 0.8204586551554742, 0.7815817154703603, 0.2610301496761461, 1.8603491614903174, 2.3094940089410354, 0.5040118194395496, 0.6263122407178725, 3.809564767345306, 1.096126937097119, 0.16869107471598735, 0.017815951160305453, 0.2025483458513214, 0.012743645666858122, 0.1294608152801952, 0.09203551262016259, 0.4190709321729599, 9.828221163442059, 7.130600781210008, 10.911779845914534, 22.777384019667103, 34.87115344693584, 27.82481155087871, 30.2665634693638, 27.85529817304304, 34.15214377064859, 42.14174509048462, 55.42768363029727, 69.74237749653479, 69.01396197657432, 68.96501864156416, 71.60391084609493, 71.29580866905951, 72.49124511595696, 72.1560707399922, 69.9509769870389, 72.6012440650694, 74.27436244103217, 77.29512876079929, 78.98069673968901, 78.80644936715403, 76.35924339294434, 73.08867700638311, 70.88210059750465, 73.2419789221979, 78.42442620185115, 79.52478439577165, 81.08285180984005, 70.99714371465868, 60.27516834197506, 44.01065249596873, 47.63846051308417, 59.4598017200347, 26.438610630650675, 29.761458289238718, 36.92524379299533, 34.179419932826875, 49.65309181521016, 60.35884034249091, 71.10618560544907, 77.1830980239376, 55.9081857435165, 52.184785642931544, 3.543444944004859, 0.24387630724137832, 0.036316677672608245, 0.03268018087011672, 0.09382656490009639, 0.008654464637079548, 0.10331178294314493, 0.15543154831374847, 0.13605873220630232, 0.09514866411806115, 0.07698232923904735, 0.10355558276416794, 0.051831593737006194, 0.09840331205557432, 0.02874335653388933, 0.01422209002362985, 0.0740411185148743, 0.009203471014306191, 0.05803298738394534, 0.03339328998399358, 0.09202701670508232, 0.09518904461254997, 0.10815073901246633, 0.055007292483482635, 0.01616768234769904, 0.17325625394380864, 0.13916892660481317, 0.2457963227624855, 0.1911285642774836, 0.13491528469227976, 0.1721017134766425, 0.1096662371269157, 0.14649939212587573, 0.17418026323280028, 0.12497209162721712, 0.15585721740799566, 0.13305376764507065, 0.29489043919790175, 0.10203286044059262, 0.1455393920262014, 0.21678012976002312, 0.12659837371639668, 0.24418407540407874, 0.16077076745850427, 0.17784591734168992, 0.09831243870599617, 0.19039151108553334, 0.1572632492189446, 0.21238799447253828, 0.11004682960769824, 0.19651828393820794, 0.18734235857282916, 0.13674222053058688, 0.21536591613004286, 52.077265631768014, 134.8339379218317, 95.55317355740456, 125.02319582047002, 107.19005353989141, 57.992619545229026, 63.30889025042134, 18.185555473450695, 1.1394974421108923, 0.30884601776638343, 1.413538737162467, 20.256088395272535, 83.8093226955783, 91.38274485065092, 88.60373773882466, 79.02165412902832, 96.82781834756175, 98.25235259148383, 96.46140621554468, 91.07406216282999, 95.71624217494842, 87.41678930098011, 88.72102445171726, 87.9683529946112, 88.46147337267476, 95.83220312672277, 91.1634922027588, 89.71115619905534, 87.00247718441872, 81.17867531314974, 83.52363294170749, 81.5288802116148, 78.59712031579788, 81.37237764173939, 81.20827351847004, 80.66318958036362, 80.60981396705874, 75.65056523969098, 59.66683618484005, 49.18409009133616, 31.66257815976297, 33.05125213438465, 40.41335659642374, 31.65662988539665, 25.73172696175114, 5.931303251174189, 20.769205016474572, 1.7366073304607024, 0.3505109659125728, 1.0537881380127323, 0.9863095201792257, 1.0235436609195125, 1.5098131904678962, 1.5700894786465553, 1.8732809708003078, 3.6832362557611162, 0.972275157128611, 1.5038964176370253, 6.254752682101342, 6.052593233123903, 1.9064981754749053, 2.976883822871793, 0.5584818965965702, 6.3097291127327955, 6.173388506135633, 0.8492899145330153, 1.5806567116129784, 11.465747952461244, 5.447729922110035, 0.7334614040390138, 0.31358984869814693, 0.2413453825659329, 0.14563319183165027, 0.1231048672249721, 0.1816306981228052, 0.31019390350387943, 12.815992505319658, 7.748327995500258, 14.73942772034676, 38.57832670211792, 44.18282493468254, 35.045847969670454, 38.612208135666386, 36.04761346693962, 40.95378075876544, 48.53307470198601, 59.03140829455469, 69.31779661486226, 71.64202059468916, 72.27151393890381, 72.71841310685681, 73.92159231247442, 74.96177350321125, 72.67253706532141, 71.09034707469326, 73.55722765768729, 75.66801194221743, 78.28781789348972, 81.86574120675364, 82.50274981221845, 80.30994092264484, 77.1719192689465, 75.57147456753638, 73.63308629681988, 76.44680638467112, 78.15037804265177, 82.76376001296505, 74.40549512063303, 72.72747378195487, 56.84367887435421, 54.10049476931172, 69.73974950851934, 39.248973554180516, 31.22063490652269, 41.33998517067202, 42.944214959298414, 52.415930917186124, 63.153729131144864, 94.25317456645351, 84.24261908377372, 76.01659297943115, 52.50805170305314, 2.0157729569942724, 0.43205805303108313, 0.11762009903548226, 0.1272187363957205, 0.2817847585726169, 0.10565004416651304, 0.26263203952581654, 0.1542415839409636, 0.2838437271214301, 0.18530640330526138, 0.27068190757305394, 0.21828953747547444, 0.07884022269037463, 0.16549363822465943, 0.17186453265528526, 0.1447119864244615, 0.16450097213589376, 0.10790811130596746, 0.22136155005183913, 0.1596715385394712, 0.18644978953225, 0.17343838368692707, 0.276927454697509, 0.17281233663520507, 0.11285479465920119], [0.05638122904084383, 0.012841418595804323, 0.11771325532707477, 0.07311918532415744, 0.07255836299830869, 0.12426456346386865, 0.08268347896275022, 0.02205708094181553, 0.05873260951991524, 0.08566880869048257, 0.04848471264384928, 0.06151221782690095, 0.08583468204784779, 0.14682781401901476, 0.11500729488268976, 0.04953407689989094, 0.05877243077021934, 0.07254960661333415, 0.13503254210997012, 0.0779696403732223, 0.05705889509690385, 0.027482331760468024, 0.028373286270746784, 0.06424731642548596, 0.10126593748047467, 0.17301755626836132, 0.08241062908763848, 0.07363276300771583, 0.19222334988655584, 2.523506860579214, 84.38791151969664, 92.54032258064517, 88.93107521918513, 113.31050426729264, 63.28142189210462, 32.484899144018854, 27.709992008824504, 7.452407719627504, 1.281868815422058, 1.1212080428677222, 6.602074638489754, 33.27534106469924, 49.97995468877977, 54.49677967256116, 62.45843802728961, 72.24107634636664, 76.04777582230108, 94.21715936353131, 85.85381892419632, 89.10876643273139, 85.77181000863352, 89.69378794393232, 87.44809765969553, 90.79147108139531, 89.60258499268564, 88.9945234790925, 85.51509088085544, 83.40498124399494, 84.59098046825778, 84.14023737753593, 79.1240515247468, 76.67570806318714, 73.89882687599429, 78.7402162244243, 79.08851485098563, 77.63026391306232, 64.23660139883718, 43.21057527296005, 33.70712341800813, 28.291944265365604, 27.397284969206783, 29.394965748633112, 24.41775844943139, 12.170218383112262, 3.8312243405849706, 11.278139025934282, 1.7807385301397693, 3.8088050532725553, 0.7921145051237076, 1.5213358882934818, 1.9079378079022131, 2.9832522811428195, 0.3554202718359809, 0.5620570757216024, 2.489847040945484, 0.1646558444706663, 0.945932090042099, 0.45538460295046534, 0.06251764311004551, 0.24340856459832963, 0.0967892260861493, 1.0733485077658007, 1.1083403397952358, 0.1935818536026824, 0.3689649514853955, 0.11308233809447098, 1.2201036200408013, 0.490222328733052, 0.39636384094915084, 0.5080202978945548, 0.3988452610229293, 0.17782469670618736, 0.2620993939138228, 0.4663592108315038, 0.8598736337115689, 5.304775218809805, 6.057617299018368, 18.47741315441747, 23.68263371529118, 15.745036159792255, 35.28627357175274, 28.50141844441814, 30.665715625209195, 31.0617494967676, 38.82748350020378, 36.419630665932935, 52.3233159126774, 71.40181464533653, 67.00726170693675, 75.03662801557972, 69.0735427794918, 71.22763787546467, 70.57308058584891, 70.47096560078283, 69.33613761778801, 74.87060193092593, 77.6855379535306, 77.10467415471231, 75.1602925023725, 73.78456038813438, 71.94069339383033, 72.48682852714293, 73.60315861240511, 77.69673239800238, 77.75128472235896, 76.81617598379813, 62.68123649781751, 55.09445867230816, 57.806444245000044, 58.02287670873827, 29.810413391359393, 24.13193533497472, 23.13434716193907, 22.00939766822323, 25.92691782982119, 43.09834841758975, 66.82667578420332, 63.932656934184415, 36.77025133563627, 42.40995284049742, 8.615056583958289, 0.42155869545475133, 0.16119346413160526, 0.027416294981395046, 0.17296158588461338, 0.061612755375643896, 0.023719976288116267, 0.02208433835016143, 0.2677583321928978, 0.09049128620855271, 0.08315188810229303, 0.031077572813017235, 0.0734274208004917, 0.018080778179630157, 0.10493445675820114, 0.04173163226955841, 0.0721042413985537, 0.049402531942412745, 0.05323594398496132, 0.004762876356366061, 0.03635165724723089, 0.037564052674438686, 0.057891184509161024, 0.053050860972894784, 0.05424856666415449, 0.043435277747771436, 0.06367476912395609, 0.032241174185107795, 0.022117293537444165, 0.07545317177690807, 0.04242466987981912, 0.0365255132407671, 0.06683510397711108, 0.04772875240192779, 0.037194633586031776, 0.015081709622585726, 0.031146451778289293, 0.015104238353219005, 0.1245805517499966, 0.07116026019737606, 0.020396943512042204, 0.0937258932859667, 0.07580911154828726, 0.033272002943821495, 0.09079386795600576, 0.036605787763912837, 0.05081173152692857, 0.05426335599153273, 0.04656682301673197, 0.11925155221815072, 0.09345780081686475, 0.14153975422584242, 0.048170842590831944, 0.0734917262208558, 0.08702067042430563, 13.297212412280421, 109.79053005095452, 98.08300818166425, 111.15889595400904, 106.98565883021202, 57.03987583037346, 51.95056523046186, 36.44010543823242, 8.807195848034276, 1.9895873362979584, 0.8487501596250843, 8.135086442193678, 43.86884704712899, 65.47155180285054, 75.1778333417831, 74.84360033465971, 82.39196638907157, 86.74435384811895, 97.3527491477228, 88.95398186099145, 93.03705938400762, 88.86452828684162, 90.75152566356044, 88.14632661880987, 90.42440783592963, 89.5431532398347, 88.52457646400698, 84.14777617300712, 83.02670786457678, 85.01276862236762, 85.03505552968672, 80.4296124366022, 77.89835006959977, 77.2852522327054, 79.582200050354, 77.2251066084831, 78.14362372121504, 67.2348690032959, 51.42652480832992, 38.04558646294379, 29.48183644202448, 27.266936763640377, 30.727490994238085, 29.717578734121016, 14.574796038289225, 4.5736718946887605, 14.71972663556376, 9.401818340824498, 4.1381093571262975, 0.4172138737574701, 0.09854429521627965, 0.5774632877399845, 0.908654374220679, 0.4723813667172386, 0.31480357711834295, 3.0014077069297915, 1.5226504951715472, 1.1435622433500907, 3.4775996256259183, 0.08699866071824106, 0.09515785717315252, 0.09116840068130724, 0.6149919126783648, 0.5679255543697266, 0.9241968273155151, 0.8588676683364377, 0.10382520740911846, 1.289773371911818, 0.8388768797439914, 0.33957365119168836, 0.12510022749343228, 0.616438593114576, 0.1606129227025855, 0.35852632935970064, 0.38312483038152423, 2.332221692608249, 9.78995059767077, 8.810330802394498, 34.852035814715975, 30.918671238806944, 27.927477628953998, 34.27591416143602, 31.33222241555491, 30.48980320653608, 34.12436162271808, 42.13803452830161, 44.32910973025907, 60.2884808663399, 73.49446189018988, 68.41378442702755, 74.81234688912669, 68.54261075296711, 71.1356661396642, 71.16178128027147, 69.70054149627686, 72.03264944015011, 76.6176648293772, 78.55084419250488, 78.92660725501277, 73.77746089812248, 73.79631180917063, 69.61262549123457, 73.4408038662326, 77.56203036154471, 83.29765735134002, 81.46440429072227, 81.18405680502616, 66.20034387034755, 57.36171022538216, 54.8876517049728, 59.76770385619133, 39.96238993060204, 35.77567554289295, 40.31745464571061, 42.29209738392984, 38.05046981380832, 63.7409040235704, 62.437390588944965, 78.70432653734761, 52.21579590151387, 53.03487700800742, 17.745500841448386, 0.3363111585138306, 0.055168852765834143, 0.029979328316966855, 0.22329368508390843, 0.06464852050187127, 0.18146782783010315, 0.13502282811509025, 0.10599276126031915, 0.048901633014001196, 0.07093560491358081, 0.0736445147964743, 0.038317714652587334, 0.09022340058319031, 0.08617205184794242, 0.04561927184582718, 0.08771651574680883, 0.04439639250537561, 0.07691921891584512, 0.0179259747927708, 0.048312469265393676, 0.059305076382213065, 0.04353903669623598, 0.018313864261032115, 0.07363754339636334, 0.06293949325599017, 0.20532262601679374, 0.11296488915479953, 0.20270200776717356, 0.1155865646057552, 0.1635979689777859, 0.13928892661727246, 0.2826266279143672, 0.10739935997633204, 0.27330719895901223, 0.10852508021578675, 0.19187409040187636, 0.16259508327611033, 0.26383801513621885, 0.32021794948847065, 0.14280494843279162, 0.1758779447165228, 0.1825076849350045, 0.16781106951736635, 0.19387557171285155, 0.22024644779101496, 0.1627868657270747, 0.2059165433409714, 0.12903056498016083, 0.23031397692618832, 0.30118366763476406, 0.2680788020933828, 0.24301683319912804, 0.18119290951759587, 0.26959047742909004, 8.482707969604, 122.00616359710695, 119.83679479168309, 118.48470672484368, 129.27860659937707, 83.37918773774179, 47.465319248937796, 50.39344702997516, 17.839427878779752, 2.4921982567156515, 1.3012292668704064, 9.211418647919933, 59.767288084953066, 77.13073438213718, 79.68028283888295, 85.72229400757821, 96.16206661347421, 90.30555217496811, 101.91714071458387, 89.2508582145937, 95.20544759688839, 92.51678051487093, 93.75543363632696, 88.96939677576866, 92.0324540907337, 92.16062145848429, 92.50608813378119, 88.35123123661165, 83.89723085588025, 85.34253012749457, 85.7148571937315, 79.69308545512538, 78.96503079322078, 75.84891165456465, 81.8130402411184, 79.46966725011026, 80.43031061849287, 70.03765352310674, 57.30078012712541, 45.96932334284629, 38.37094314636723, 34.98245462294548, 38.50773188375658, 33.52994211258427, 20.3301937349381, 11.30696648551572, 28.966272261834916, 13.728557421315102, 9.616222939183636, 1.0905020131218819, 4.301127474154196, 3.9141721735077524, 3.9699436195435065, 2.0658535342062674, 4.215025075020329, 15.542853666890053, 2.8252731840456686, 1.426377267606797, 6.592112798844615, 0.15229306994907318, 0.6221906263982097, 0.23351150534806714, 1.5519084348793954, 3.7220336448761726, 0.7927446584067037, 0.7744310507851263, 0.3030463644573766, 5.888992644125416, 1.5752955670318298, 0.6824841362334068, 0.5300072664695402, 1.651068772039106, 0.34467205825832586, 0.6916260166514305, 0.5750743191569083, 1.1304724360665968, 16.699255666425152, 7.294200879912223, 34.29654190617223, 28.911412031419818, 20.762435005557155, 41.50247719980056, 34.17092407903364, 39.822953593346384, 38.166611194610596, 51.310171619538345, 48.20813378980083, 59.60181505449357, 75.50976783998551, 70.69283839195006, 76.07746031976517, 69.84628108239943, 72.30524632238573, 73.90870340408819, 70.65169272884246, 76.73209605678436, 77.97696221259334, 81.83863762886294, 83.68977669746646, 78.51267953072825, 76.69517870872252, 73.48777032667591, 74.03297978062784, 75.90168322286299, 80.7816686937886, 82.51843144816738, 81.5730147207937, 75.17615456734934, 68.2271658989691, 66.3434946921564, 70.15916855104508, 58.046732564126295, 43.36460282725673, 45.25800543446695, 45.229619241529896, 37.50224013482371, 69.87318854178153, 86.61562165906354, 89.06044283220845, 68.6292794442946, 62.83862160098169, 13.749921591051164, 0.5324888397609034, 0.19432613866463785, 0.11469582651531506, 0.35785330579646174, 0.15713799384332475, 0.19979422912001613, 0.17314101899823836, 0.41725741819508616, 0.27382746459014956, 0.2709840832939071, 0.2613721926125788, 0.26408144723503824, 0.25897133434491776, 0.17242894027261965, 0.1498325181103522, 0.2200873466509004, 0.10013432602488226, 0.16326090561286097, 0.11671167963574972, 0.1425874713928469, 0.1554907209450199, 0.17729788868417665, 0.1424678850678667, 0.19613255866833273, 0.23449137776849732], [0.11478771110095325, 0.07350963735652548, 0.03416747928807332, 0.05643919891407413, 0.06195723447167586, 0.06052635459890289, 0.09814101121117992, 0.02237176496325241, 0.06976270131886968, 0.09453014771063482, 0.21569525732869105, 0.08218664030033736, 0.11792697853619054, 0.09590115398168565, 0.0822322148709528, 0.24646481108521265, 0.07907394079431411, 0.016790247529805187, 0.059667313396329844, 0.0212499441113323, 0.08099446193345132, 0.09941056445841828, 0.04170725918224743, 0.12739436971324106, 0.17315174422917828, 0.20902906664677207, 0.15505369842773484, 0.04885689730966284, 0.09413611038678116, 0.00434679868293085, 44.126252589687226, 92.523542681048, 76.67760649035054, 98.03243314066242, 98.47428814057382, 41.961065030867054, 36.72026857253044, 20.32580852508545, 5.526673505383154, 6.292295157909394, 5.198963399856321, 26.390698878995835, 69.07117366790771, 57.22950281635408, 62.958493155817834, 70.62933521886026, 78.27054377525084, 87.84116621940368, 91.32150880752071, 89.39658995597594, 86.23628923969885, 87.34778696490874, 85.40023603746968, 87.03229504246866, 90.04761711243661, 90.45842263006395, 87.47859801015547, 84.0542511786184, 85.63160096445392, 82.53605073498142, 81.48887988059752, 73.6481168193202, 78.20124333904636, 84.6540129569269, 75.57225904157086, 71.39782167250111, 52.03754771140314, 34.37657394716817, 41.15825391584828, 25.10976064589716, 31.69313342340531, 28.34685548659294, 25.996675222150742, 9.592089576105918, 6.938947400739116, 11.034462759571692, 6.943126686157719, 1.3553422857676785, 0.04076269192380771, 0.06985582696694521, 0.057490765672898105, 0.09147288232681253, 0.09941234944328185, 0.27980190851996023, 0.33304550955372475, 0.04491224547006911, 0.057215468146868294, 0.1157721417445329, 0.13606924293262346, 0.19565150141716006, 0.21006941404794494, 0.0555462085251366, 0.3577984232575663, 4.531948662573292, 1.9110689624663324, 0.10221609335032203, 0.14895239033766333, 0.4907556791459361, 0.25022994937194937, 0.17088213214470496, 0.28476324713518547, 0.13166215360885666, 0.11379937340895976, 0.09695847023038134, 2.568634464856117, 5.89010855843944, 6.349003805268196, 7.0259450808648145, 11.737469165555893, 15.794820843204377, 30.158502171116492, 25.621800576486898, 31.067515380920906, 33.788355704276796, 44.448443920381614, 24.89125324833778, 44.95014252201204, 62.65416822125835, 65.85675208799302, 69.30249152644988, 71.01505325686547, 71.42544300325456, 75.8808946609497, 65.7403596754997, 77.16139947214435, 74.75173842522406, 79.91028278104721, 74.56997579143894, 75.46997931695755, 70.35995468016594, 73.97335190926829, 73.90463198384931, 77.05459333235218, 81.52282407206874, 74.53798494031354, 68.85320755743211, 62.19875751003143, 61.2154624539037, 72.6412130171253, 44.376899888438565, 31.990111758632047, 17.02761688540059, 17.035240011830485, 22.9930555435919, 43.101921696816724, 68.05137311258625, 68.35838487071376, 38.42341661453247, 42.61338656948459, 20.717690567816458, 0.271663480708676, 0.21033060406484913, 0.11102100999485101, 0.1023980315714594, 0.07963776618482606, 0.05265116992015993, 0.08965739950297341, 0.12742246981830369, 0.19075399324778589, 0.012820504395471466, 0.09413411855817803, 0.06044519524420462, 0.027652315179546996, 0.04284872635898571, 0.007452999848136379, 0.05029775547764955, 0.07890644333054943, 0.10252750043066279, 0.09079022903836544, 0.0855560941741832, 0.022265194472105756, 0.028558610600509474, 0.036935661393668384, 0.06018563316413953, 0.03371943659599751, 0.0489340806680341, 0.024203412242293842, 0.04345116641132101, 0.07132892211478564, 0.07777657089454514, 0.06613556611081285, 0.024997581119438814, 0.05297867250778983, 0.00888837713582982, 0.037855759803806587, 0.05649080642709329, 0.05506739974202168, 0.048277363286263524, 0.022693880037554813, 0.062249267188411575, 0.05538866254350832, 0.06073767612237604, 0.047030650950487585, 0.03491900388091322, 0.01815327499512463, 0.04037448452905782, 0.06064161252711089, 0.025339221859711315, 0.17000152939750304, 0.01502683378695961, 0.1388933341349325, 0.17626342483826224, 0.08233811886560533, 0.027163472559843815, 0.080036039974901, 0.32575967631513075, 74.52457827906456, 109.69936632340955, 99.56043950973019, 121.93424301762735, 86.12393686848303, 52.10461631897957, 53.18632364273072, 29.948696551784394, 9.22302298007473, 6.9051542205195275, 5.595358619766851, 26.93728900724842, 71.49112701416016, 64.72764292070943, 73.66464568722633, 80.49377456788095, 86.48508517972886, 94.79295546008696, 94.82747231760334, 92.60060941019367, 91.38118374732234, 88.6462797657136, 85.9625078016712, 87.89172557092483, 90.2172831566103, 87.1164063484438, 83.76721997414866, 81.7678310025123, 86.0090349566552, 81.58225582491967, 80.50471013592136, 80.52660480622323, 82.09474486689415, 84.13896652960008, 77.67146448935233, 72.63583936998921, 60.062199331098995, 39.43430554482245, 38.724772314871515, 26.257903114441906, 31.907261494667303, 33.88792114873087, 27.87690454913724, 12.380315238429654, 6.918161290307199, 15.851837396621706, 10.868422946622296, 0.8236203919495306, 0.07412252301770834, 0.13830539229656422, 0.19837013295581266, 0.12344084274504455, 0.08338539936249295, 0.24448029096088103, 0.16105710048108332, 0.31813207593175674, 0.1140982626126178, 0.5884855156463962, 0.315299695658107, 0.06406655414931237, 0.2016919821260437, 0.13633639311357854, 0.8880613792327143, 4.9188237997793385, 2.25356615839466, 0.6208445792717319, 0.588920163291116, 1.978338959236299, 0.5885691111606937, 0.7999943016517548, 0.17239970635742913, 0.26528359240581917, 0.08431551437224112, 0.261152693100514, 3.461721626020247, 5.066394642476113, 16.279763079458668, 21.92354875226175, 16.61526595392535, 22.037040572012625, 33.40233956613849, 34.682636491713986, 37.103087978978316, 35.68494719843711, 47.445942740286554, 35.03157446461339, 51.957103821539114, 68.26231033571305, 67.48321779312627, 69.91654642166631, 70.17400295503678, 69.4100978297572, 73.77487213380876, 67.44409607302758, 79.5014855169481, 74.84626754637688, 79.96645112191477, 75.83495586149155, 74.54795560529156, 71.15854924724948, 72.59328949835994, 74.13044283466955, 82.27826472251647, 86.48301416827788, 81.12691571635585, 74.74485074320148, 62.32252005607852, 56.07500022457492, 73.23030594856509, 52.74347628316572, 49.51239639712919, 41.1917862584514, 38.73572357239262, 37.70132003291961, 59.174484591330256, 70.60294551234092, 70.1369365569084, 60.266299863015455, 48.10009602577456, 33.50379559301561, 1.240925399526473, 0.07934666809535797, 0.11860063029152733, 0.14959876936289573, 0.14621019393445986, 0.22903228118535013, 0.2806056879701153, 0.17607400193810466, 0.1873012043295368, 0.030051936215210347, 0.04008550084226074, 0.014514175408910361, 0.05117151705968765, 0.06276335048999998, 0.04073348482169452, 0.10780779209228293, 0.07345092437800861, 0.04594122029600605, 0.06584246087098314, 0.02388452048293285, 0.048230555314089985, 0.044374057211943214, 0.020670946349479982, 0.06070437428030757, 0.022853274206300418, 0.06476117373113671, 0.2211417134610876, 0.22498156064220015, 0.17878167841944004, 0.2209228268193622, 0.17708281716031415, 0.19616885591418515, 0.29661297257388797, 0.12382040100712931, 0.18363490670679078, 0.15121060303382336, 0.30282085881598536, 0.26447536964570323, 0.20366494964447715, 0.10488241640550476, 0.20214325387872037, 0.23363080055963611, 0.21668616141523087, 0.12205579408234167, 0.1348539057277864, 0.10711157904757608, 0.1954228701370378, 0.19070242020872333, 0.1625113192224695, 0.159116477194813, 0.3319523633728105, 0.2982766397537724, 0.1950143307687775, 0.09227726698642777, 0.19797772739923772, 0.18002320050952897, 66.11267889699629, 119.92381649632608, 102.33639501756238, 128.67158059150944, 116.89241270865165, 60.54312898266701, 50.93065877114573, 43.19960832595826, 14.934102796739149, 8.53544423657079, 5.70872982663493, 34.87401677716163, 100.28851770585584, 84.34510277163598, 86.66558481031849, 94.02039758620724, 95.8581143040811, 99.38548611056422, 95.80559376747378, 97.58564379907425, 92.97537619067778, 89.51550837486022, 85.32113752057477, 89.83140037905785, 92.35077011969783, 92.38331010264736, 89.42007710856777, 86.36532737362771, 87.77492523193361, 84.7297147012526, 82.39403740052255, 79.8763229000953, 82.34234840639176, 88.36666184086954, 78.0137462000693, 76.90694747432586, 63.726912929165756, 44.09798799022552, 49.01484766314107, 33.9647093895943, 39.75441017458516, 38.08949739702287, 39.35668968385266, 18.604815659984467, 13.056045482235572, 30.033939461554255, 16.957480984349406, 0.8683497530798759, 0.21881910341401256, 0.1907750606657036, 0.5410583605689387, 0.17027408815920356, 0.4855192230353433, 0.7305754588976984, 1.031758391088055, 0.17797426771252386, 0.18051905857939876, 0.6939000720458647, 0.6995846895921616, 0.7598238378282517, 0.6840183345540878, 0.3613422847082538, 1.3400411197254736, 12.726244753406895, 3.1764645586090707, 1.5417579537437809, 1.0018824329299312, 4.293422958543224, 2.6068368794456607, 0.8039811457837782, 0.5850582221342672, 0.5497559099908799, 0.34904185442193864, 0.2631885870810478, 5.96237087442029, 19.069243900237545, 12.147240158050293, 16.775577145238078, 17.511321613865515, 19.34442170204655, 37.41265320008801, 31.514098798075032, 43.491781757723906, 42.25746677767846, 60.54027741955173, 34.19912199820242, 56.34269414409515, 67.95363549263247, 72.9372735177317, 72.1736978715466, 76.07239261750253, 75.28725962485038, 79.50734553798553, 66.70301914215088, 83.912794820724, 77.23050378984021, 86.05091802535519, 80.7095363063197, 80.71306643947479, 74.2301808634112, 76.88735915768531, 73.32758857357886, 79.24573129223239, 85.80052960303523, 81.46096044971098, 81.2338944404356, 76.50139008798908, 67.89825947053971, 81.83968882406913, 70.0658945883474, 56.21992395770166, 39.25041698640393, 34.37575024943198, 39.69573936154766, 70.50320748359927, 91.18672047891926, 90.40098344126056, 71.04669893941572, 65.37870537850165, 30.600719990268832, 0.40463838726282125, 0.20128924970424947, 0.21103253978635036, 0.4581868300034154, 0.1895723792333757, 0.35604604309605015, 0.4115371315950348, 0.4452671555261459, 0.25687046078664644, 0.14466946854466392, 0.1512505928234708, 0.15308047043940715, 0.2192443894642976, 0.1768729090690613, 0.11462765235093333, 0.15948525659980314, 0.17302449702495531, 0.1811273783565529, 0.15040437210231059, 0.1685282044232853, 0.19122763476785154, 0.22398659628966164, 0.18474533583127684, 0.09543384034787455, 0.14465431532552167, 0.29533863127712284], [0.06585731531583494, 0.06968599293501147, 0.024165044643826062, 0.06198254601669408, 0.06718988695572461, 0.03238223395460556, 0.04372873921848593, 0.022103802729097587, 0.11243057347113088, 0.04705410473228944, 0.08651495280285036, 0.14542562796944572, 0.11213287170375548, 0.042295863686670224, 0.06618319379706537, 0.16889935870084072, 0.06421758455314464, 0.03031440176850846, 0.061507958378041946, 0.05241196662668259, 0.09460838060946235, 0.06563557882703121, 0.03441927706702583, 0.042084408097810326, 0.11284079823282459, 0.06192451485642984, 0.31870734667585743, 0.1321743446732721, 0.07433034734980715, 0.22617546270691583, 4.596212285180246, 73.49578765130812, 87.22538548131143, 84.12320644624772, 97.50612951094105, 91.15541212020382, 46.789420343214466, 35.86263056724302, 20.928125727561213, 8.287116039183832, 13.01762390521265, 14.965640614109656, 62.62262844270276, 83.19753493032148, 76.54900766188099, 71.06454572369977, 68.95826432012743, 86.73640712614983, 89.53271973517634, 94.56588160607123, 85.80089830583142, 90.38987528893256, 88.86678757206087, 88.28272311918198, 84.60953327917284, 89.26581813443093, 89.16962592832505, 88.9260781195856, 85.43068931948754, 87.78928110676428, 80.99234704048403, 77.94438300594207, 70.7232524502662, 85.91030889941801, 69.66991562997141, 76.06796033920781, 32.40634387539279, 24.671012163162235, 41.375070771863385, 30.485435647349206, 31.255285124624933, 22.242986579095167, 22.794305124590476, 10.5109400903025, 11.535327857540501, 5.419351083617057, 2.3285383418683083, 0.41361463947161553, 0.1493740604529458, 0.022865987435403853, 0.2062900418475751, 0.05008501286107687, 0.04404840089621083, 0.11132720001642743, 0.2767690277147678, 0.6653312437476651, 0.26540199895539596, 0.022040447257759593, 0.03674565243624872, 0.11817145251458692, 0.058607790814412225, 0.31346307646843696, 0.6659074644407919, 3.5735035375241315, 2.81492474579042, 0.6636442568513655, 2.787312975814266, 2.5389818366496795, 2.464631348848343, 0.1845949374499821, 0.16179937839267716, 0.07919328963203777, 0.29466432068617116, 0.08228479148519617, 1.0601102632860984, 1.8278052561706113, 3.33522200103729, 0.39580542413938435, 13.630843335582366, 25.636497697522564, 35.796409191623816, 28.735366252160844, 25.874969959259037, 49.54059823866814, 37.02576237340128, 15.21827655453836, 31.861206985289055, 49.156711947533395, 61.481995351852916, 70.45794333181074, 67.0426336411507, 74.17968426981281, 69.44215928354572, 74.9321674531506, 76.1912404337237, 75.52909728019469, 79.14177279318534, 75.2034777979697, 70.4920679523099, 71.9492284713253, 73.84505902567219, 78.80373508699479, 75.79846997414866, 78.6343514534735, 71.74720287322998, 70.88790570535969, 65.56721448898315, 79.11856805124592, 48.921793353173044, 46.13066611751434, 25.365069681598296, 9.07627534481787, 18.045167961428245, 44.78948616212414, 78.53480169850012, 66.82965678553428, 39.65776689590947, 37.370209232453384, 21.946188672896355, 1.8785623196632633, 0.12323366192680214, 0.21708052815689197, 0.10363187746054704, 0.091722312894079, 0.17067654478934505, 0.04489195946183416, 0.2989845969263585, 0.17373291385029593, 0.04784550803202776, 0.07118023210956205, 0.10913798885960733, 0.05277273658242437, 0.09491663906843432, 0.0650066129803177, 0.05655691598451907, 0.07209149369549367, 0.13479179131888575, 0.037451970180676836, 0.06521879635270565, 0.06140099718205391, 0.05066578794691352, 0.09310136308833476, 0.07900814916337691, 0.01630315925144861, 0.040491048637176716, 0.10086449974727246, 0.023584078036008344, 0.05747715229048364, 0.005960650037929055, 0.02531624113720271, 0.07368425177710672, 0.036990291123548825, 0.04917071756696509, 0.08248487832925974, 0.04541131727878125, 0.019259400620696046, 0.12927070290090578, 0.04406676019331621, 0.009473222063764209, 0.033969361289975145, 0.15292926000491266, 0.051293681270533034, 0.05516160557407045, 0.031172696035355333, 0.06779377874467643, 0.07124259932747773, 0.05091272489798646, 0.03763830957693919, 0.08447378813739746, 0.07591439501172112, 0.09145739202898356, 0.11990645014110113, 0.25325414274008046, 0.08912781058179756, 0.09944646333855006, 0.06280936556117189, 15.363817080374687, 96.45421258864864, 98.78499477140366, 115.91178094187092, 106.95807672316029, 74.11105063653763, 60.60693417826007, 46.58301738000686, 31.96424372734562, 22.402005349436116, 18.6172652629114, 16.780948831189065, 57.96741831687189, 78.30806516831922, 78.51453873418993, 81.0196545816237, 79.41018058407691, 93.60223370213663, 94.91154439987676, 96.18075278497513, 89.6330382747035, 93.80556152712916, 89.34997650884813, 91.00782117535992, 88.07445310777234, 89.42986734451787, 87.95090629208474, 88.68987298780873, 84.52459043072116, 85.229660003416, 76.91439997765326, 78.19036268418836, 77.43440428087789, 87.76333070570423, 73.24568163964057, 73.85091120196928, 44.74425338929699, 32.25029630045737, 46.68836439809492, 31.11863955374687, 36.69423187932661, 24.20679376971337, 24.70721563985271, 8.34681353261394, 14.37152018470149, 9.793847472436967, 8.599469084893505, 0.3602565236149296, 0.03760531800048005, 0.014513478268899265, 0.1654279844895486, 0.2149480764543818, 0.018636986740954944, 0.17057915969241053, 0.2625099251106862, 0.8542041540626557, 0.5091793582804742, 0.03366083853066929, 0.07848601427770431, 0.09239532879643864, 0.05376894965827946, 0.2590633568263823, 0.606797713666193, 3.240283237349603, 3.6797509847148775, 1.962274524473375, 3.3859414342911016, 5.400187853843936, 2.4620043414254345, 0.25079648671371324, 0.4353769604236849, 0.08737591305567373, 0.10097401967692761, 0.23836828828338655, 1.011375671913547, 1.7823326058926123, 15.031204992725005, 9.087113834196522, 14.719252028772909, 22.580300607988914, 31.54543657456675, 31.207351799934145, 31.369643788183893, 44.62664504205027, 43.2210950697622, 34.203342468507834, 43.06531029362833, 58.522225810635476, 62.842771468623994, 67.1613794757474, 68.62053255881034, 74.97215209468719, 70.58684810515373, 74.61101162818171, 77.89361969117196, 75.4522737379997, 80.76925831456339, 75.48985788899084, 71.88489375575897, 70.40829397016957, 75.60655624635758, 80.27212142944336, 83.78545899544993, 80.94434507431524, 77.9351262123354, 70.71658442097326, 63.49123339499197, 77.21367682180097, 58.236991051704656, 64.7128124390879, 54.33887681653423, 30.578762562044208, 33.421676851088, 58.03060377797773, 81.46652237061532, 77.84342119770666, 64.74162617037373, 43.68586847859044, 38.58448874565863, 6.916207459665115, 0.13286382380512454, 0.10007283980807952, 0.11201045851433471, 0.3547548478649509, 0.22622150459116508, 0.19445165451015198, 0.22865053957268117, 0.2019830648937533, 0.0828739590642433, 0.109593520061143, 0.05828072872733878, 0.004065053569408314, 0.06232523629742284, 0.012875794876186598, 0.12842909402904973, 0.04749228787277976, 0.032535294491437175, 0.0037727081930385006, 0.0432021954968091, 0.07974822840262806, 0.046533379448397506, 0.057659063698543664, 0.03462545431008743, 0.05096524405563551, 0.07037199402768766, 0.03845670598468954, 0.14095285426705115, 0.11094989405284006, 0.20918827503919604, 0.18209637232845832, 0.11492877087045102, 0.17069657032768573, 0.31833493601410623, 0.21549644219058178, 0.15376899962223348, 0.1772992369989234, 0.2847152593876085, 0.3550289847677754, 0.20621756992993817, 0.14532157790756997, 0.2461523544644156, 0.20198720176854443, 0.11621007590644783, 0.20000219134794128, 0.11230162555171598, 0.20363311103034407, 0.22092841926120946, 0.11474523918643115, 0.1332372610246943, 0.19830187452175926, 0.17605118783971957, 0.15613431141020792, 0.4095430047281327, 0.26891938440742036, 0.14762474464312678, 0.16588322457767304, 7.009301973927406, 102.92490743821668, 112.78318082132648, 118.13930280746953, 119.87226086278116, 110.24749402076968, 67.91238784790039, 52.54471017468361, 44.629951600105535, 32.936620866098714, 22.583587554193315, 21.85687630407272, 71.79995875204764, 112.39736864643713, 100.29992395831694, 88.74441746742495, 87.40335126076975, 98.84642693304248, 97.3689877602362, 99.46700865222563, 91.49243001014956, 98.64247152882238, 88.09755586808728, 92.56331551459529, 92.0663590585032, 91.86683593257781, 88.81632235742386, 88.74700623173868, 90.30260255259853, 88.86722687752017, 79.96635698503064, 79.43820984132829, 78.46474816722255, 89.929624372913, 71.60983362505513, 78.68705241910874, 43.145240352999785, 35.421846374388664, 57.570615660759714, 39.60082584811796, 41.82816336231847, 26.741060672267793, 35.236683045664144, 15.246972614719024, 20.647331091665453, 15.462464690208437, 16.773782660884244, 0.5168033427288455, 0.1849154073504671, 0.1496598265704609, 0.36247542067881555, 0.7019675907588775, 0.16721646271405682, 0.4243850389555578, 0.37370412460257935, 1.0550570247634765, 0.854564828257407, 0.10634496252262786, 0.2336220671572993, 0.3005336267092536, 0.17990474799467673, 0.8502907930843292, 1.327929576077769, 10.110128771874214, 11.350571474721356, 2.57033285114073, 6.318632893023953, 9.929147670345923, 6.947860986955705, 0.4049036069022071, 0.7076701041190856, 0.8083465599244641, 0.7519630402807267, 0.5754557083691321, 6.053330638716298, 2.226042396599247, 10.78305354041438, 6.954457923289269, 22.641183637803604, 30.93621207821754, 39.12108075234198, 30.567005257452692, 33.14796993809362, 60.37824823010353, 50.21668934052991, 26.4630901428961, 47.275519678669596, 60.606012421269575, 69.24416588198754, 73.7312553774926, 70.66967287371236, 79.29222706825503, 73.70031572157338, 81.97413198409542, 83.16373978891681, 77.62441958150556, 87.92803887398013, 83.1899098427065, 74.75926937595491, 73.33613934055452, 74.70605850219727, 74.55074833285424, 80.52704411168253, 83.89674448197889, 82.7320437277517, 80.88063009323614, 78.49753918186312, 83.64533624341412, 67.8957099299277, 72.77061200911, 49.886841543259166, 22.983937994126354, 33.10858149682322, 69.75267764060729, 101.19376151792466, 91.79434268705307, 71.40078698435138, 59.97004324390043, 37.463483195151056, 3.8447315125696124, 0.20186689532091542, 0.28709236892961687, 0.16853171310597853, 0.4620013349959928, 0.3193758349985846, 0.21855438939265667, 0.39870479114113316, 0.2572639388663154, 0.18084210253530936, 0.3161454260829957, 0.24250606705825178, 0.19278244085369572, 0.22717473247358877, 0.19113587275628122, 0.22595928801644236, 0.13396806293918243, 0.22256787806268663, 0.1008987438774878, 0.22391865961253646, 0.17210798007586312, 0.14752927476600294, 0.21424520610561296, 0.17979049364164953, 0.12575854216852497, 0.17745516653503143, 0.18569390589912094], [0.07319636102164946, 0.03488542624719201, 0.0633565400306496, 0.038638245840106285, 0.04108583930158808, 0.1040752048814489, 0.03566742964809941, 0.10094564378021226, 0.10252378490423003, 0.09418790559134177, 0.0331002077268016, 0.1521286828022811, 0.19976919336665064, 0.07107954517367386, 0.048668998924474564, 0.1514238206249091, 0.2016491884545934, 0.06351263810610099, 0.04649650763660189, 0.07581634341829246, 0.05045353562661237, 0.07280796976579774, 0.16445584955715364, 0.10663870361543472, 0.29072371762125726, 0.36151428676901326, 0.19593708367357332, 0.13863571408775546, 0.16429253493345555, 0.03846758826365394, 0.23650631158342286, 22.31187516643155, 92.22795286486226, 74.7643292334772, 84.53505531434091, 110.26355220425515, 75.56364551667245, 38.61838586868779, 26.702748921609697, 23.480666952748454, 13.117129533521592, 20.482367969328358, 29.948926010439475, 83.28945959767988, 71.5901590162708, 81.57823931786322, 72.74237094386932, 79.892773320598, 91.59671014355075, 95.00283364326724, 93.32220785079464, 91.37427253107872, 90.41942642581078, 84.23192670268398, 86.27032756805421, 85.41268564039662, 89.19463496054374, 86.20855023784023, 87.47965705010199, 82.947020992156, 79.72281702103155, 84.80768357553791, 82.8510170598184, 80.72284883068454, 68.47843293220767, 42.78336248090191, 20.59772683728126, 22.877261292549875, 38.40174159696026, 30.195537190283503, 15.353460061934689, 25.395254281259355, 21.738032410221717, 16.195538024748526, 4.880892028731685, 8.654967681054147, 5.471803959338896, 0.2124098126566218, 0.04297703459498383, 0.16422767792978596, 0.10317449232623463, 0.1076367782849458, 0.20067547538107444, 0.389190714565977, 0.522454313693508, 0.34032760428324826, 0.15944220245845858, 0.0814826591240783, 0.0599178854346035, 0.08865673545627825, 0.09373415171379045, 0.45049766679444625, 0.3275828736443674, 0.08473376007450205, 0.17997599417163482, 0.4174923620397045, 0.788876343398325, 2.1152719663035486, 12.179197669029238, 0.9457246334322038, 0.12484637659884269, 0.32933972775936127, 0.10364117010706857, 1.1289554594024536, 1.6836603586712193, 5.26823490858078, 5.2952320921805605, 7.1662825826675665, 46.16835225012995, 39.90408782036074, 31.49240024628178, 33.51356229474468, 29.421482932183054, 47.67920217206402, 14.253564707694517, 12.005215056480901, 25.591092340407837, 33.07790856207571, 48.312123667809274, 59.1573909021193, 64.59582774869858, 68.21098219963812, 69.93742912046372, 78.66858590033748, 74.72578017942368, 76.11556222361904, 76.983182660995, 72.7996140141641, 71.3197272823703, 77.50139051868071, 79.89819403617614, 74.32334499974405, 81.94294914122551, 75.8980275738624, 66.36080018935665, 63.08824516111805, 83.99565881298435, 60.251928298704094, 55.46893127502934, 29.21084380918934, 6.312500757555808, 17.349121801314816, 56.75034999847413, 91.55936917951031, 73.6539533061366, 37.281532287597656, 35.781366902012984, 28.02796090802839, 2.073270736202117, 0.22905667342485922, 0.3103374990244066, 0.08733255247915946, 0.01731686977549426, 0.09288175632396052, 0.0845256599507505, 0.1696150993267375, 0.22439677508607989, 0.1382494985216087, 0.02704025114766292, 0.11143998348064, 0.034735349622825464, 0.07096243331268912, 0.07512987501198247, 0.015847384816996993, 0.025778264933896643, 0.08995163855293105, 0.051851941032275084, 0.017518952278600588, 0.07295821492950763, 0.026713903437578873, 0.054722744445767135, 0.05502613058554069, 0.05141911284637548, 0.06073991309911494, 0.07373021705256355, 0.030970408603729262, 0.07743176238070573, 0.017666968126450817, 0.01938027397338902, 0.036007794851977984, 0.05288547025092187, 0.09528004053619601, 0.02593195366282617, 0.03468181922911637, 0.04624841006232366, 0.06123713480548994, 0.060049821096923084, 0.13025557021460227, 0.142184876866879, 0.04492123934230016, 0.052675684733736905, 0.14207241515959465, 0.11114278733129464, 0.011900235530770114, 0.07709495182479582, 0.06249489029869438, 0.1260224977628358, 0.09474025498474799, 0.010397883485101405, 0.015010084232105123, 0.10998921979579235, 0.005496014360218279, 0.09722327618228813, 0.2267415863612006, 0.0040534751080427206, 0.06989494341635896, 0.4632213453371679, 46.41899170414094, 108.53003717237904, 102.38660920050837, 118.9434749849381, 107.40996514597248, 72.71503202376827, 56.7975204221664, 42.52534897096696, 42.311917120410556, 31.207071350466823, 31.808645263794933, 37.05054783052014, 72.78651329778856, 67.66161503330355, 86.6567280984694, 84.81657166634837, 86.04106503148233, 97.02860447668262, 94.8221222046883, 94.21998347005537, 91.43762665410196, 92.14731677885979, 88.53512763977052, 88.49529989304082, 83.34536121737573, 92.3044704621838, 86.42736358027305, 82.83343699670608, 78.9291803298458, 81.48619697939965, 84.7907232469128, 81.46024657833962, 82.9495862222487, 70.55917186121788, 55.14014251770512, 31.949950610437703, 29.08194688058669, 42.02649801008163, 26.99337301715728, 23.221243350736557, 32.481916181502804, 29.81726381086534, 18.20362191046438, 13.376363881172674, 12.758712172508242, 6.2066555984558605, 0.16975235163925156, 0.10806610927947106, 0.06772395749125751, 0.06948757616262283, 0.05337360998495452, 0.1962157558169096, 1.2870204809211916, 0.2881226959007402, 0.08994294345499047, 0.263473755649982, 0.018171994353554422, 0.08341492439109473, 0.060078124215285626, 0.18908597468849153, 1.289690511841928, 0.12279351377078604, 0.20956172758052427, 0.27933637221013347, 0.13808060677782183, 0.9037882450126833, 4.196769873942099, 7.914138349794573, 0.8233597994812074, 0.025508492817020705, 0.7844677218987096, 0.1798509073353583, 1.7323051032520111, 4.574409300281156, 10.245253443717957, 9.913617045648637, 27.326666616624404, 49.056393408006244, 40.802871488755756, 26.094640339574507, 28.69106111987945, 21.41635294883482, 49.33440708344983, 30.410410511878233, 22.46846598963584, 39.12019821905321, 38.35646567806121, 53.999368221529075, 64.51868257214947, 70.78121723667269, 70.1846404229441, 71.87024762553554, 82.79557043506254, 79.0158333316926, 77.55024756154707, 77.29520720820274, 73.97281062218451, 72.7888039619692, 80.30361806192707, 81.97524593722436, 80.93020885221421, 84.87903148897233, 79.07705368534212, 67.76181590172553, 64.75331091111707, 85.04005262928625, 67.82378935044812, 78.18613436914261, 62.324842099220525, 26.88753962516785, 31.999872576805856, 64.38445122011247, 81.15787106175577, 83.40578140751009, 60.39742862024615, 42.369073898561545, 40.76856643922868, 11.243638838491133, 0.25633704908672844, 0.11658309177765924, 0.12299459652915118, 0.12366359046990834, 0.22234801082841812, 0.28478730229600785, 0.3824088139639747, 0.28068591269754595, 0.28553644435540326, 0.08559177854969617, 0.03917807352639014, 0.08662009070957861, 0.08256323380215515, 0.008169321264440735, 0.06445224877567061, 0.06654608198591778, 0.0392923585229343, 0.03840623994267756, 0.0229505961009812, 0.03528355831100095, 0.035537895671422445, 0.009397392765799118, 0.10046456354640185, 0.027997941492245566, 0.047034477559669365, 0.025690208872660034, 0.037967807823611845, 0.21841684596673136, 0.2061173503076838, 0.12249228033807971, 0.12571045482951787, 0.13184468171769573, 0.24993194116940423, 0.15221837637645586, 0.21844923616416995, 0.26321742263051773, 0.22252401186814233, 0.19023702179472293, 0.2468403627074534, 0.32749955392172264, 0.3168384905063337, 0.23919345690838753, 0.1829348555615833, 0.27253044709082574, 0.1446526912191222, 0.22664443109064336, 0.23455896204517734, 0.15953188071087485, 0.2063839489053334, 0.34326886097269677, 0.22494538597041563, 0.46762368491580414, 0.45514408198575823, 0.2912562406591831, 0.3155059265273233, 0.1273155009614364, 0.21136732020926094, 0.14795017879336111, 30.596179846794378, 123.14208984375001, 103.2355042426817, 122.18302326817667, 132.11565694501323, 96.22940586459254, 56.093192177434126, 43.61940391602055, 50.455832327565844, 43.94003022101618, 38.248282786338564, 52.65251651886971, 97.0368100750831, 89.94860079980667, 105.14939338930192, 98.34094324419576, 96.06330917727564, 102.26144636830976, 102.35402214911677, 101.03218340104627, 93.36067061270438, 94.43397229717624, 87.26920620087655, 91.76915322580646, 88.2060250928325, 93.18206156453779, 87.13657517586985, 91.99454046064808, 86.78688803026753, 85.8430245614821, 85.9822294788976, 88.32268422649753, 85.46799890456661, 74.87413206408101, 51.46123778435492, 33.852608050069506, 33.720667362213135, 50.42881111944876, 40.11693523776147, 22.87111297730477, 40.22976221576814, 36.43157036073747, 24.60996243261522, 13.299180461514382, 15.966349032617385, 19.19584035873413, 0.400807763780317, 0.210826370204168, 0.28749986641830017, 0.19902538327920824, 0.30588012368929, 0.369409435699063, 3.0871450804894973, 1.0139458049689571, 0.6899541063654808, 0.48864440211365306, 0.153963815781378, 0.16568264743733793, 0.16823290817199216, 0.28597354348148074, 2.641259845226042, 0.607001064044814, 0.2868588653302962, 0.5168856512154303, 1.1479479434990114, 2.750079141509149, 6.2486612412237355, 16.784233816208378, 0.8287778184298547, 0.27005126399378626, 0.690844055385359, 2.127917197442824, 2.271831165398321, 8.454987599003701, 17.77651894477106, 7.700080390899413, 24.653379148052586, 50.53558588027955, 47.01477619909471, 38.82653036425191, 41.163482435287975, 37.92995106789374, 62.90248955449751, 29.239777172765425, 19.27574884506964, 41.74571906366656, 46.48055722636562, 67.35392862750639, 71.21045789410992, 79.01116571118756, 75.92681777092719, 73.68897222703504, 88.18229475329, 80.12970016848656, 81.41812816742929, 85.07129038533857, 81.33020431764665, 75.03177212130639, 80.45105995670443, 80.39970828640847, 76.65087161525604, 84.03667111550608, 84.86087091507451, 83.0982126728181, 79.28541783363589, 92.74362687141665, 73.07579594273722, 77.10421915977233, 50.445543950603856, 17.07267903512524, 31.338205991252778, 81.83571938545474, 107.84650141193022, 93.11813477546939, 68.30880611173569, 59.50076303174419, 43.495421717243815, 7.552612510419662, 0.24308495373735506, 0.30141141025289414, 0.278391387433775, 0.2567850113395722, 0.28251940624848493, 0.42623318010760897, 0.5998946485980865, 0.4912041163732929, 0.35367558319722453, 0.14371686885433813, 0.29347195079730404, 0.08384378041110693, 0.19365115391631282, 0.1547153786786141, 0.14695055662624298, 0.1313727255910635, 0.17108028844719933, 0.14125427922173855, 0.11517078570661046, 0.13003296038556483, 0.1161945702868604, 0.1431499637903706, 0.1654474737663423, 0.11186551467906083, 0.20610593559761203, 0.22896998291534765, 0.18799770082677567], [0.14371895261349218, 0.05243951897887934, 0.06093714243522095, 0.04756834508190232, 0.07326697134563039, 0.056516497185634035, 0.023769622616049264, 0.10832953627311415, 0.04741317397283931, 0.07571573309119671, 0.05860053979220891, 0.1027631567370507, 0.2084732698577066, 0.13024374181705137, 0.01193675781495028, 0.06044945469306362, 0.05766638749909978, 0.11218824453892247, 0.1898417510693112, 0.1696082658224529, 0.2768789766536605, 0.05856944045292274, 0.14679560768267802, 0.06065925936244669, 0.028692838780942465, 0.28162167377529607, 0.44930030201231286, 0.5750654325369866, 0.3166133219436292, 0.03906653878549415, 0.05733599292955572, 0.7736842069895037, 32.79493308836414, 106.45058478078535, 87.93771143882506, 83.66908227243732, 103.62694109639814, 79.6311669195852, 41.292132254569765, 28.06474881787454, 15.608162110851659, 20.772237008617772, 29.242187469236313, 41.41975049049624, 72.95723053716844, 74.03758464321014, 85.09888818187099, 74.98169129894626, 83.37766585811492, 95.56460334408669, 98.89535457857194, 98.53934457225185, 95.47298462160173, 88.0712289194907, 86.52231631740447, 85.05045475498324, 84.88089069243401, 88.20328727845224, 88.83089788498418, 87.52208140588577, 92.48318149197488, 87.54840835448235, 78.81488246302452, 70.57921517279841, 56.158409426289225, 29.056665243641024, 24.965829272424024, 14.687841688433002, 26.152681612199355, 38.370476384316724, 30.362875307759932, 26.132251947156846, 16.546496998879217, 10.960860463880724, 2.941461633290014, 10.30020094686939, 1.0972370904299522, 0.3509124879154467, 0.157830843762044, 0.12066701457144753, 0.0684730995506529, 0.06816671034621616, 0.08308460259990347, 0.12716810564480482, 0.66533878205284, 0.584401531565574, 0.23967266022678346, 0.22238033973882276, 0.5110285413121024, 0.14392769625110013, 0.2053310836274778, 0.02531973449813743, 0.042737455918423595, 0.7760030632057499, 0.32885531504308024, 0.3782874754359646, 0.18066859894221832, 3.270750002514932, 10.223232276978033, 7.523892425721692, 1.9927801456182235, 0.6131040881718359, 0.016400023408594634, 1.3384694750270536, 1.7185011794490201, 2.106816071656443, 6.77541055025593, 13.00758557934915, 23.83966188276968, 19.643288658511256, 30.01716152314217, 35.738542464471635, 47.901290693590724, 27.52476199980705, 6.735426889311883, 24.810479879379276, 16.53211170627225, 40.38305236447243, 38.9815620453127, 35.751713783510276, 41.39651829196561, 56.00970845068655, 68.77192820272138, 69.19843889051869, 74.16288868073495, 72.55303029091128, 68.44164109999134, 70.79052894346177, 74.05655322536346, 76.68618079154723, 75.29788924801734, 73.4283071948636, 72.09019061057799, 64.30334444968932, 68.88395109484273, 79.30905403629427, 72.03509699913764, 65.08455899453932, 29.979951958502497, 7.416235131602134, 23.430121329522905, 61.8639910605646, 92.26010061079457, 87.03622525738132, 52.59346915829567, 39.650055516150694, 31.442546921391642, 7.304749604194396, 0.5818602647031508, 0.14556877915897679, 0.15262251840003077, 0.27170583004913024, 0.1353160099637124, 0.4695596503874948, 0.22019089109474616, 0.016737879674521186, 0.1217456587079552, 0.12086710907639035, 0.04263277383401029, 0.12831457154524903, 0.18215369102695297, 0.0516131590871561, 0.126510986066874, 0.10570414529572572, 0.2420258525037958, 0.12028365651325834, 0.12300711440583392, 0.08361382379887566, 0.030113786323777134, 0.027965493838212667, 0.03753094618479091, 0.07742457647597598, 0.1331511220984882, 0.04352815441727158, 0.055541259597145745, 0.03828296873478159, 0.10844057305685936, 0.035917377324714776, 0.06187958763011041, 0.09160005292224307, 0.027993277932006507, 0.060320280777711066, 0.04848973051975331, 0.12741031966382457, 0.06459435808562464, 0.05529497382080844, 0.11778768076891862, 0.17341042147769084, 0.041245055354891286, 0.08059294759145669, 0.17078229556641272, 0.16818913390799878, 0.1325229606440952, 0.08382734782513111, 0.14639088343228066, 0.017948798467254928, 0.19141678187635638, 0.11097849211505345, 0.11675270364409494, 0.1871189520123505, 0.022597308909039826, 0.14912630761823348, 0.19258574011825746, 0.3088249350267072, 0.2667926323990668, 0.16456357684106598, 0.09339519611169254, 2.4183348782600897, 67.58653302346507, 107.54857386312177, 112.24596515778573, 121.86338932283464, 102.03421561948716, 75.62234770867133, 55.486040653720984, 39.287197051509736, 37.64308068060106, 40.955734099111254, 46.547990614368075, 54.251549167017785, 66.2146056082941, 69.41176091471027, 94.86503293437343, 85.635131097609, 92.04916338766776, 97.03289554965113, 99.1110457143476, 96.17320614476358, 97.27914979380947, 91.90891511978643, 93.33729328647738, 88.28739073968704, 88.8402174365136, 88.5693463971538, 85.80538549730855, 80.87440921414284, 81.45903848832654, 79.2214753550868, 79.71963990119197, 74.24896117179625, 63.218601211424804, 33.898872406251975, 28.006007402173935, 25.368189927070375, 37.83313128256029, 33.030216463150516, 25.860365013922415, 25.11560105508374, 22.67618883040644, 19.220284569648005, 8.531479700919121, 13.439090424968352, 2.8736212993821795, 0.367322581549806, 0.04950794947123335, 0.17441008961008442, 0.11405287956398343, 0.036166842365937854, 0.04237047682005552, 0.2563022227296906, 0.5197802378285317, 0.651259066597108, 0.4047194393652101, 0.1506136826449825, 0.2970453832418688, 0.1075862011601848, 0.19109214445756328, 0.09335637077569, 0.33143173001946946, 0.8849571296764959, 0.4301595952241652, 1.4795953732344413, 1.1176080424939434, 4.384095409224111, 16.8186173131389, 8.099039860310095, 0.3786899167443476, 0.8115641904934761, 0.09764110819706995, 0.9876679472865598, 1.8479572909493602, 4.311289844974395, 12.543901608836267, 28.587245787343672, 27.235242051462976, 20.347471775547152, 30.051949024200443, 29.46089098530431, 34.38067282399824, 37.818924457796165, 16.52137617911062, 17.2836947056555, 24.76762406287655, 49.95110957853256, 49.53143558194561, 45.07814122784523, 53.38640766759073, 63.257271858953665, 75.5498230841852, 81.80064555137389, 77.16594942154424, 80.46213673007104, 73.9303627321797, 72.89586113345239, 72.44953463154455, 77.36360549926758, 78.86827376581009, 80.03073876903903, 73.36795760739234, 66.63464438530707, 71.91153449396934, 78.30411926392587, 73.93930573617259, 87.9762291139172, 57.545959641856534, 23.658346399184197, 32.49383822564156, 63.190575876543605, 85.75668534924908, 90.54488735814249, 66.36165526605421, 47.055486479113185, 41.33856527266964, 18.266466125365227, 0.9706441865813349, 0.00959678821551103, 0.19058390640683714, 0.29636062321163, 0.2085131983603201, 0.5730886805442073, 0.5578939700799604, 0.42464921671536665, 0.23462015714856888, 0.18275539180444134, 0.14615560250897563, 0.13853157209532876, 0.051649084780365236, 0.011799075535588689, 0.056907654018892403, 0.16796546687762584, 0.07230189208301806, 0.03844558238802898, 0.06718110758811235, 0.07047807422256278, 0.1379507548746563, 0.02776788337336433, 0.014971302946158236, 0.08040493429307977, 0.05170056205843726, 0.05912699924421407, 0.020480014256111557, 0.04817587578849447, 0.2371434975535639, 0.17798635657996903, 0.18669601019111373, 0.2769970767680676, 0.14090796151468832, 0.17354900678319318, 0.19470205800908227, 0.2837782419256626, 0.2754352379950785, 0.24066102090141467, 0.3409526400989102, 0.2932517771278658, 0.2630014777664216, 0.24582603165218908, 0.36023010890330043, 0.394746384192859, 0.26189564516948116, 0.20320535817694282, 0.387837435569494, 0.2694911617905863, 0.278226402738402, 0.19345658290530407, 0.21924587567487072, 0.26027748361229897, 0.16277656950537236, 0.4671244100937921, 0.45757438867322864, 0.49807488317451176, 0.28161848684953106, 0.3666095681969197, 0.22875337921563657, 0.5604436945530676, 51.621827463949884, 132.57921834145824, 118.75758601773171, 125.45936338363157, 128.82226236404912, 104.7529515912456, 60.65527739063386, 37.35984240808795, 36.32812569218297, 52.188900209242306, 51.753168029169885, 66.79120971310523, 87.6100052556684, 92.21144753117716, 106.98302299745622, 96.24285959428357, 95.34029083867227, 104.84628046712568, 104.00561455757388, 98.34431648254396, 99.7428140332622, 96.69318691376718, 90.75067058686288, 88.44003369731288, 86.93763256073, 91.4608157065607, 90.62533517037669, 88.72023213294246, 92.3988897569718, 87.99642932030463, 84.08588117168796, 79.4295649374685, 71.33275739608273, 38.12479872857371, 34.498190956731, 25.02655148506165, 42.31643961321923, 54.428506897341826, 42.39150985594719, 32.30706672514639, 30.777197230246763, 21.54583234940806, 8.565650409267795, 15.920328843978146, 6.952039291781764, 0.48685334983371925, 0.1349396309665134, 0.2304228533419871, 0.2371383954079882, 0.2133587810901865, 0.1080256674979483, 0.31681664167873325, 1.4433692203414057, 2.124377258362309, 0.8862705721009163, 0.6531196796605665, 1.0221773277847999, 0.259511947271324, 0.4045889286264297, 0.2488293567852628, 0.4743246559894854, 1.6328607619770112, 1.1121226078079594, 4.253725630621757, 2.358804330710442, 8.214872844757574, 24.02566852108125, 24.858248464522827, 5.5657383511143355, 1.34254077269185, 0.21427915912241707, 2.03045156934569, 5.767518310777604, 8.045692684188966, 12.551461977343406, 21.284500514307332, 32.88667340432444, 27.62065806696492, 43.584687017625384, 54.0338223211227, 63.43601034533594, 41.87736557376, 13.050592407103508, 41.133158591485795, 24.907754659652714, 51.04233257232174, 56.89583855290567, 58.31991780188776, 62.60973953431653, 68.06288134667182, 77.79072023207142, 86.94116269388508, 81.26655209449031, 90.20478648524131, 82.10844178353587, 79.0910251678959, 75.23237782139933, 77.76991598067745, 73.77951622009277, 78.86994469550349, 79.76584542182185, 78.72017291284378, 85.77284551435902, 85.66034409307665, 79.07193106989708, 79.52807134197604, 43.12196500839726, 21.3750974593624, 40.10701164122551, 79.25920071140413, 109.82604319049467, 99.54317323623165, 75.91436816800025, 62.274012104157485, 46.24718796822333, 13.615839289080713, 0.8088463556862647, 0.1980883504955038, 0.3331444881135418, 0.3960407663497233, 0.25067241111349675, 0.9745144627747998, 0.796568846750644, 0.5198990121003121, 0.3149575914346403, 0.20597790698370627, 0.18593209795653823, 0.19785340665088547, 0.2099013496791163, 0.16779502763623194, 0.28155260328804294, 0.3162975098577238, 0.2660593943249795, 0.16563914896499726, 0.15702557810131582, 0.1788749879286174, 0.19486437671847884, 0.1122479381099824, 0.33683807378815067, 0.1107983848440551, 0.4113308700823015, 0.09017778770817865, 0.12464613653719427, 0.23157285856864146], [0.2756612032892243, 0.04765440356887637, 0.07196363362093126, 0.08064931634092525, 0.019355299507057475, 0.14728915216701646, 0.09995428004091787, 0.046396525501604044, 0.08431970487318693, 0.058043222318613724, 0.07483862370492951, 0.09020772642425953, 0.07672799570906548, 0.20737486831363172, 0.010417815177671371, 0.16795376105414284, 0.026871889919763612, 0.0212577831060175, 0.14536182816711166, 0.12004849050314197, 0.02993044999217795, 0.028462499124749054, 0.017694554952604157, 0.0489799157085438, 0.03130623856709609, 0.04660656765824364, 0.22324673921590854, 0.5068919116691236, 0.13057556514057422, 0.36020234587692446, 0.12298970888819426, 0.11191985329553006, 2.781191626864095, 49.20587885764338, 97.92725870686193, 83.47028870736399, 85.20726326973208, 101.78298780995031, 89.78179808585875, 49.112393086956395, 25.14491096619637, 15.480565447961132, 25.619609932745657, 31.5450894448065, 59.05493467084823, 85.76125883287, 89.39808045664142, 80.22908518391272, 74.55156418585008, 85.88324454522903, 92.66360267516106, 102.48349174376457, 99.59303440586214, 92.6238141521331, 88.63438713935115, 85.8877238919658, 76.14916909125544, 75.8853583182058, 75.17332261608493, 80.22559427445935, 82.73239674106722, 81.59195192398565, 72.456555674153, 59.07440923875379, 37.91800352834886, 35.520293943343624, 27.015361824343284, 11.466012712447874, 15.609216247835468, 37.82713397856682, 44.64591956907704, 40.433082196020315, 34.03040516761042, 10.235766210863668, 4.6831418141242, 3.7737751007080083, 0.8797315520144279, 0.9731481296400871, 0.15075301871665064, 0.30760621171324487, 0.3666987714748229, 0.1576810429293302, 0.30286578221186516, 0.34448136365221393, 0.04971604193410566, 0.10862383661010575, 0.23257879330025566, 0.12218002290014299, 0.19094258877298526, 0.461257892630754, 0.4761067297189467, 0.045744190142760356, 0.1434151527862395, 0.5027737907103954, 0.4131593993834911, 0.782122818693038, 0.8833581509609377, 2.5054097800485553, 6.313644128461038, 11.645484682052366, 3.7878466037011917, 0.7045469168693789, 0.4341628949248022, 0.4962628094419357, 0.3540180551428949, 1.9561729099481338, 11.87592589086102, 8.016953477936408, 28.53542931618229, 39.054184729053134, 14.809167462010539, 33.89706419360253, 38.707502119002804, 15.594637778497512, 15.937676506657755, 30.337905499242968, 19.53519009774731, 27.96762897122291, 37.168089497473936, 36.574168128352014, 34.45904962478146, 45.4176615899609, 54.473221917306226, 62.66221692485195, 67.01530256579, 66.70623548569219, 64.62975625068911, 68.60285835881388, 72.70324922377064, 71.85046319038638, 67.26514970102619, 71.91943414749639, 69.37420814268052, 71.72329994939989, 78.11604945890366, 74.12339825784007, 60.08101101844542, 30.429928225855676, 20.827475747754498, 46.29861808592274, 71.90234830302578, 99.61113222183721, 80.08124320737778, 54.549868952843454, 39.57965681629796, 18.886900755666918, 8.698557961371638, 0.6387742236256599, 0.4248196866002775, 0.19604776805687338, 0.22236360837855648, 0.1495310931556648, 0.4301180426151522, 0.29133615895144405, 0.28217812939997644, 0.16014259068235276, 0.17216001276768025, 0.23031547845851993, 0.053897472398896376, 0.08170659428522473, 0.02477072907852069, 0.06224588107978625, 0.07796488296721252, 0.15244187486748542, 0.04893459777738299, 0.0866264415784709, 0.05954991042193386, 0.04382120220050697, 0.09225315053857143, 0.10494367279593023, 0.0695372186601162, 0.031769026536494493, 0.024137149467283202, 0.03443846373908943, 0.13432873713393367, 0.12237072516713413, 0.0548292804629572, 0.033622932500175895, 0.032966601992807085, 0.03772127306869915, 0.028670392404761047, 0.05968332080350769, 0.07169132766824576, 0.05420516778324401, 0.06583440928689896, 0.08467931420572343, 0.08828342081077638, 0.1584011042911199, 0.1877252033521091, 0.19566287016195638, 0.35245223271269954, 0.2464133146549425, 0.06494189387247448, 0.03008603287350026, 0.11092311927988646, 0.10312091213681045, 0.1659565085485097, 0.16040355087287966, 0.10532572850464814, 0.0580410351375899, 0.05230096048645435, 0.03995618137020258, 0.0728816980676305, 0.06897920787694954, 0.1127666715652712, 0.2806439310792954, 0.0567645296424387, 0.43051266982670755, 8.786253333091736, 89.52733039855958, 111.70256783885341, 107.0349944022394, 117.80428532631167, 99.9878837216285, 83.74351316882719, 68.09022026677286, 37.93995311183315, 38.62897626815304, 45.50243185412499, 48.07411816812331, 73.1236880825412, 81.41195435677805, 83.28822012870543, 88.00658825905093, 84.78370220430436, 92.53207775854295, 97.8844342693206, 104.1786067716537, 97.78553562779581, 92.49982018624583, 89.42339543373355, 89.52092124569802, 85.1843095594837, 82.12831251082882, 79.86816437013688, 83.86193736906975, 84.16338720629292, 76.47325884911322, 69.42693264253678, 61.61653657113353, 49.15465270319293, 44.088260512198175, 25.12058246520258, 11.555629064959865, 22.08019252746336, 41.05320892026348, 32.42096058783993, 26.258209059315345, 22.73114319770567, 8.943122644578258, 10.942608694876395, 10.728095250744975, 2.5193113953836503, 0.6557824174242636, 0.15041520458555993, 0.3548465945547627, 0.3740402533402366, 0.11277434010539325, 0.22338595271350878, 0.5537304967161149, 0.03690915092104866, 0.18522870666798086, 0.6656333888250013, 0.08326707708258783, 0.24595841164550475, 0.07443345512353605, 0.3072393475280654, 0.32323409893339683, 0.39738160407831596, 0.5605722134632449, 1.4626311222391746, 2.2920634861915343, 1.8392359008712156, 5.1779331218811775, 18.258582161318873, 20.402408492180612, 5.524774587923481, 1.3624182415585364, 1.9513552587839866, 0.9106881231550248, 0.31897799021774725, 2.325586268017369, 20.346320559901578, 16.378168482934278, 41.96495994444817, 38.501460013851045, 19.763746607688166, 24.891649407725183, 39.72219182598976, 26.79596797112496, 13.870560949848546, 32.339820477270315, 20.2691851892779, 45.66249201374669, 57.764243464316095, 59.516181868891564, 51.65623841747161, 58.24538100150324, 68.8099673486525, 74.19770363838443, 74.60650874722388, 75.09113327149423, 70.3424765986781, 72.83271881841844, 78.59527680181688, 78.30913205300608, 78.68023533974925, 77.97346345839962, 76.35750186058783, 76.99349064980784, 78.61423753922986, 81.07147693634033, 84.11183941748835, 52.97282903425155, 29.351568645046605, 49.62150104584233, 71.34987461951472, 90.06751921869095, 95.08373645044144, 71.37593484693959, 46.335209877260276, 32.92806225438272, 17.667380955911455, 2.4907727203061505, 0.015932921406572625, 0.07360231867360492, 0.14893432598440878, 0.36413700409954597, 0.5376086360023868, 0.3483416500591463, 0.5125915751822534, 0.6127119737286723, 0.1631415337924996, 0.20087499532007402, 0.15383143578806233, 0.06405436569043706, 0.04301495977767533, 0.0445242295973003, 0.1115134130081823, 0.05217545230181948, 0.1323950852477743, 0.05795964595651435, 0.08092317745209703, 0.10243245190189731, 0.06989182543850715, 0.12616035528481007, 0.054120426967499725, 0.032065284228132616, 0.038202177102286974, 0.05415922165998528, 0.051802735204898545, 0.12533387664945858, 0.4359277776412426, 0.1498788357862542, 0.23404439610819663, 0.14181335486711996, 0.09467993322159014, 0.23188577484219308, 0.26820033428169066, 0.18159487585146583, 0.15984360188726457, 0.21779464467638926, 0.1451705513341773, 0.3583532854193642, 0.19815224222838881, 0.18484521837484452, 0.4490063693975249, 0.26387380676404126, 0.1109514415504471, 0.11859377380460502, 0.3282051821870189, 0.182861709486573, 0.3147024841558549, 0.14103327817734213, 0.22173671863011776, 0.21323799966804444, 0.176287648538428, 0.19917052629734242, 0.27071215272430454, 0.3330475626693618, 0.2004005877120841, 0.44628056727590104, 0.16732843412506967, 0.365673347466415, 3.2429274051420154, 70.88520711468112, 125.06600456853067, 122.08916879469349, 120.07048960654967, 123.93901348114015, 115.75570983271446, 75.97630239302113, 40.52847031624087, 31.526946521574455, 48.95696916887837, 51.7292494158591, 78.56842425561722, 103.46977956833379, 112.29078215937461, 104.16993833357289, 94.53225904895415, 100.59880856544741, 106.78593958577802, 107.11275931327575, 101.95303040166056, 96.24438931865078, 92.95936507563438, 88.71756492122528, 80.23183084303334, 83.08426472448534, 82.74927077754852, 87.79193262900077, 91.32996543761223, 87.90485766626175, 82.92778568883097, 76.2345669346471, 57.30016431500835, 49.24995845363986, 38.61949197707638, 16.844297070657056, 24.14058416120468, 53.13712143128919, 66.33495961466144, 60.52174814285771, 55.16796388933736, 15.400992324275357, 13.975615751358772, 18.13870276174238, 6.28459652585368, 1.2723570677541918, 0.4818291307216691, 0.82330169937303, 0.5418614658617205, 0.23745158747319253, 0.3389782170134206, 0.9030118608667005, 0.14631972918587346, 0.7065149661033385, 2.2750450574582626, 0.3984644540375279, 0.6575085054482184, 0.5009641071721431, 1.7350739288714625, 0.8557692410484438, 0.7426551945747868, 0.7988365282935481, 1.7632072515064672, 2.1988995950068198, 4.521141552156018, 7.505072403338648, 27.227248261051795, 36.06316958704303, 17.031176436331965, 6.155938371535271, 6.332990238743444, 1.1111877353922015, 0.28984112304545223, 4.116704492799697, 22.072157552165372, 17.946379146268292, 38.04677886347617, 48.03982096333658, 30.30493993912974, 55.64330808577999, 50.495922873097086, 24.79594553670576, 22.244524148202714, 44.02383558211788, 23.852886153805642, 42.825994722304806, 60.14521237342589, 66.11934692628923, 56.98888894050353, 62.00564353696762, 73.85800284724083, 80.24552775967507, 84.92267962424987, 87.18092933777841, 77.92098214549404, 82.6340707655876, 80.05383368461364, 79.96502337917205, 80.86173211374592, 84.23785732638451, 85.37605070298719, 83.17686403951338, 86.75855282814273, 86.16549045808854, 71.13042585311398, 46.73494254389117, 33.69712921880907, 67.2343590951735, 94.51217651367189, 113.41955400282338, 100.80771400082497, 80.56780538251324, 54.47039781078216, 32.77656462884719, 13.271919008224243, 1.9598568735584139, 0.4506685963321117, 0.2034896687274018, 0.296637395456914, 0.40739967457709775, 0.7970257415886849, 0.6658279751577686, 0.7349500660934757, 0.7361900253641991, 0.33010563182253994, 0.341217951668847, 0.18532486602423653, 0.20866068560750256, 0.29210760949119446, 0.19641423387633217, 0.26758292870175454, 0.35042758490289416, 0.174693756646687, 0.21111539985624053, 0.17834559052942262, 0.13776874770560574, 0.12889936476224853, 0.26170302002180007, 0.14421991282893767, 0.13197963576643698, 0.20336767688633936, 0.19916488789021972, 0.3231947833011228, 0.20006315662495552], [0.09221009639722687, 0.09780486715176413, 0.0820015534578312, 0.07119222138557704, 0.06766133746432682, 0.07442517371307458, 0.13243836921549615, 0.033565939389049046, 0.004004837143340058, 0.03359981196662111, 0.03226075156201278, 0.000832198319614925, 0.17493282204433797, 0.12865459967044093, 0.20555482726664315, 0.1617500423303535, 0.15057583790152304, 0.08384546580454035, 0.09149625566938231, 0.0869782827794552, 0.1868913166465298, 0.0708751452545966, 0.12122648858254957, 0.051334544400414156, 0.13221222006024855, 0.08834714400431803, 0.11599067598581315, 0.28839891656271877, 0.45104759535001177, 0.20193743669698316, 0.032679951043739434, 0.23902019846343228, 0.06770911070728494, 8.69641536666501, 51.611695981794796, 90.02474184959166, 81.25064296107139, 80.54203541048112, 83.89494019169962, 84.16634467340286, 56.99450577459028, 30.98090944751617, 16.912087394345193, 24.107512697096794, 40.11423272471274, 58.972780627589074, 91.83279760422246, 92.33488452049994, 85.45958149817683, 75.05498470798616, 83.16927817560013, 86.88927758124568, 95.64163869427097, 91.19856603683965, 89.55047238257625, 80.14436983293103, 81.94376499422135, 70.21814530895603, 71.03872083848523, 72.83185589698054, 71.431530521762, 66.34547156672325, 62.19315244305519, 55.23105521355906, 48.21585693667012, 31.49316118609521, 31.184115679033344, 31.31352447694348, 30.63627039232562, 23.198528905068677, 40.1610658245702, 28.580991568103915, 61.8677879148914, 41.61358225730158, 5.171320005770653, 2.2707775187107826, 0.5554930505252654, 0.32389048306692036, 0.4138510848485655, 0.20555876495857395, 0.08235338699793623, 0.45439641081517745, 0.014254977220609305, 0.29029293105967585, 0.08108901250506602, 0.2835693144269528, 0.1522280137625433, 0.043922471363217606, 0.12900191329179272, 0.19203360522947005, 0.7041521670837557, 0.6823934927102059, 0.355869475151262, 0.0724852552276946, 0.3533112317804368, 0.09394081925312359, 0.5751059432664226, 1.4185473587243789, 10.832960797894387, 9.133434084153945, 4.554472382991545, 2.3445303353571125, 0.7658082102575611, 0.27286538073132116, 0.25330375459405685, 3.710548209567224, 16.290440751660256, 17.278126901195897, 9.417861815421812, 18.58168544307832, 34.908659150523526, 30.700050092512566, 22.302455594462735, 15.515790293293616, 22.984436135138235, 9.56644315873423, 15.914927740250866, 15.658277253950796, 24.937803937542824, 25.320578236733716, 32.54740799626997, 46.23538555637483, 54.970837331587276, 58.52210813953031, 58.94145657939296, 55.46363607529671, 58.965269288709095, 61.11251984873126, 64.10846933241814, 62.876605833730395, 68.32820615460797, 71.90418397226642, 78.70738598608202, 72.89294289004418, 68.54184981315368, 45.85609236071187, 26.48279416945673, 42.43660534581831, 64.98446795248216, 69.96649388344058, 83.10069945550735, 68.65959152098625, 57.45525090925155, 44.07495583257368, 19.845559404742335, 7.341907197429288, 0.12970855279314902, 0.3679832251321885, 0.31702219839057616, 0.3672391086095764, 0.46419072235303543, 0.06548468248858567, 0.13025546296229287, 0.2280467090707633, 0.22410690273729064, 0.13745429925620556, 0.07623446654648551, 0.1324695183504974, 0.12381536780946678, 0.20285141023416675, 0.08809148514222714, 0.08152184452140525, 0.08063197977119878, 0.0745527656568635, 0.0493274629867125, 0.008585358718259922, 0.004682491229276263, 0.07069126883101079, 0.09127190682075678, 0.043500414373533386, 0.0763897066034617, 0.05315544729631755, 0.12478377955454974, 0.1125914749178675, 0.021534624299214735, 0.08044297055852029, 0.0854267708716854, 0.0304122714160551, 0.12383088108993347, 0.08158452583536988, 0.08483594854272182, 0.031007343617778634, 0.14815064868138683, 0.01437939085712236, 0.03894513683213342, 0.06762880171018262, 0.02248866423483818, 0.01336624819575058, 0.24456547993806102, 0.07538285256633837, 0.521920932637107, 0.14666059234690282, 0.12326348572969438, 0.07065465748910943, 0.03957926611145658, 0.05915694179073457, 0.18396404872257865, 0.15918413808028545, 0.13835016247485915, 0.026920810379388354, 0.029204757884144786, 0.06350346803364736, 0.08536036637040877, 0.09581140678135619, 0.19645212458506708, 0.457677289603218, 0.13372502920608367, 0.1780202483097392, 0.8512164724449959, 16.852818419856412, 88.48666283392137, 112.15228326859014, 110.37252349238243, 113.20971504334481, 101.95434047329812, 86.07996709885137, 69.72024748402258, 48.73826173044021, 39.53507515691942, 48.87751763866794, 55.310181187045195, 75.92784543191233, 96.60516108236006, 88.5334723995578, 85.76486741342853, 82.4412941163586, 88.55438647731658, 94.03342769991968, 99.43530021175262, 94.32953526896816, 94.31256709560272, 91.93787005639847, 86.5501965245893, 76.48925427467593, 76.4230211319462, 71.79294555417954, 68.27005309443321, 67.9315133248606, 63.00911918763192, 65.03460368802472, 67.46966992655109, 51.647483687247004, 35.943603977080315, 26.361173237523726, 30.505457385893795, 35.04789152453023, 40.70760496201054, 37.259037494659424, 52.171006356516195, 33.82760294022099, 20.59607159706854, 10.606345861188828, 0.49565263573200474, 0.5942525029663117, 0.18130774609744552, 0.040449235558269486, 0.10371706643772703, 0.14204967767000198, 0.034365681555843165, 0.1745518465195933, 0.0900947897424621, 0.07982240103545689, 0.07749531703490405, 0.0879179279229814, 0.17605717864728745, 0.11798790550880855, 0.7605161361636654, 1.011259532984226, 0.8379812923169906, 0.7983707468355856, 0.36468748423841696, 0.49569535279466265, 1.02443655171702, 2.6744985003625197, 20.74089138738571, 22.54463057364187, 9.430299651238228, 1.9605078644329503, 0.6741931649946398, 0.13937558648326706, 0.3997599700045201, 4.603095064240118, 24.238872874167658, 32.727888015008745, 20.7746982959009, 25.123371270395097, 34.101172570259344, 34.36006076874272, 32.44700512578411, 22.79273029296629, 27.67164887920503, 17.987581683743386, 22.243508254328084, 23.514401297415457, 44.097372178108465, 45.56093008287492, 51.961614547237275, 65.56412366128737, 77.76834703260853, 78.80500593493062, 78.54573726654053, 67.41914979873165, 68.21193925796017, 67.62614111746511, 72.40614537269839, 76.28639713410409, 81.63666694395005, 80.78147257527998, 87.74560159252536, 79.80088003220098, 76.98083708363195, 68.41725964700022, 49.0518513033467, 48.138900033889286, 67.02251972690706, 72.02956645719468, 85.00019350359517, 91.5806519600653, 66.65577811579551, 48.40905720187772, 32.54443287849426, 13.116151882756142, 2.5361106616835443, 0.22619841470112725, 0.028943987300379143, 0.19105558674181664, 0.335941291263988, 0.8281308112125244, 0.38703175622128677, 0.3851727366207108, 0.5581612428349834, 0.35114301909362117, 0.15556719184162157, 0.05610675888977224, 0.08227143857267596, 0.04872331072786643, 0.0672805687833217, 0.09712369241301091, 0.06140466291277159, 0.020852053365219506, 0.07055691999172972, 0.024822160391317263, 0.09086149819796124, 0.10743155099091031, 0.21098711077244053, 0.03466336800146007, 0.031304256314592015, 0.05506914259204942, 0.016408006044765635, 0.0445943343032512, 0.027329052888577985, 0.07904404038262945, 0.17307770949217582, 0.2613446440908217, 0.2390377265551398, 0.27600962007718705, 0.12185098047578528, 0.14412197614869765, 0.3268013413875334, 0.20821301446807003, 0.1690668561646054, 0.15144052134165842, 0.16310402612772681, 0.12093310755106712, 0.43894686886379797, 0.1916238554422894, 0.885917374924306, 0.3703662488729723, 0.18470335421302628, 0.24364701712564116, 0.17792290917808012, 0.2262160500451442, 0.280731663468384, 0.32828666329864536, 0.21133195759067613, 0.1433942079423897, 0.19976755393849266, 0.25825666624211496, 0.34549367223535815, 0.3550138468703916, 0.4754403251553736, 0.4861354335181175, 0.4049608796354263, 0.25945970007488806, 0.2918890599281557, 7.8821362218549185, 75.3868878272272, 122.66689469737392, 131.1816386253603, 124.049773370066, 112.85269306552027, 111.94257766969743, 77.7361600629745, 51.26839053246283, 39.88500548947243, 44.35116129536783, 54.252957297909646, 73.8852240962367, 105.30058506996401, 113.30122393946495, 105.28126347449519, 91.48722110256072, 95.59590385806177, 100.26590916418262, 108.0755913642145, 101.38025453013759, 95.50473228577646, 90.85434667525753, 91.7924128809283, 79.43320489698841, 83.0029853697746, 81.1351840726791, 82.52891986600815, 80.8323064927132, 72.745391168902, 73.02676631558326, 65.25855925775343, 46.34449412745815, 40.18706329407231, 36.23944874732725, 35.957147921285326, 35.60025145930629, 60.08368607490294, 42.09327243989514, 70.11613230551444, 52.15396758048765, 24.1651911504807, 11.905613330102737, 2.870168633037998, 0.863660620825906, 0.6633866674477055, 0.39179951973980476, 0.15273645099612976, 0.9689297430938291, 0.18885109213090714, 0.5881926249111853, 0.1836170108928796, 0.5084922999864625, 0.16566663619972047, 0.387477588749701, 0.5864888453675855, 0.24618074568288945, 1.7475382406865398, 3.2543365993807396, 1.363774278471547, 1.0258106070180093, 0.5106419120584765, 0.9475680248391245, 1.256959068198358, 3.623681683694163, 34.042286026862364, 30.450000955212502, 18.533634447282363, 10.728545342722247, 2.8584299597047993, 0.397829826801054, 0.5791786505329994, 6.96142356241903, 27.47884673456992, 36.53854516244704, 22.191119117121545, 32.517464622374504, 53.306603124064786, 50.12245831951019, 36.6677245017021, 25.158217607005952, 36.26090018979965, 16.923128866380264, 26.433674327788818, 23.21903701751463, 40.65391163672171, 54.65636914776218, 53.118054789881555, 63.337853031773726, 80.37390693541496, 81.27100006226571, 88.11630479751095, 80.63204596119543, 82.05843156383884, 73.48027075490644, 75.31772859634893, 74.4162267254245, 80.51567708292316, 84.8196154256021, 92.33599847362888, 85.31607766305247, 78.85293729843633, 58.9060728780685, 47.495325380756015, 58.13377388062016, 82.6963972276257, 96.67118241710048, 108.57374022083899, 98.93534706484888, 80.66727669008317, 60.63527330275505, 35.20004810825471, 12.43632080093507, 3.0617261605878032, 0.5424200971761058, 0.2549311398498474, 0.2916628494858742, 0.7159642622836175, 0.7744357698867399, 0.6283064595153255, 0.5278231191538996, 0.6840196828688345, 0.4831293657902749, 0.19041613315141973, 0.22679913488607253, 0.21338470550554417, 0.3394641925490672, 0.1973077222224205, 0.24945365715651746, 0.11212589264276529, 0.2106615387263798, 0.17186912918283095, 0.11236613781581964, 0.16711849539029985, 0.19641401937171338, 0.23140197499625145, 0.1157268429655702, 0.15717927066068496, 0.1648773358113343, 0.1765787159843791, 0.19678269152439412, 0.17635278133375032, 0.14273668999873823], [0.050631976656375394, 0.08874213893807704, 0.023425620409750172, 0.0610650101706626, 0.16565546663778444, 0.104574196250929, 0.09643476486446396, 0.10062758705668873, 0.09154851052669749, 0.039065458601520914, 0.13151318015110108, 0.02836245953315689, 0.11500354871274003, 0.1629278259051423, 0.1400324609130621, 0.15244089427494234, 0.4233756415065258, 0.16675221343194285, 0.08402000361632916, 0.2772218776085685, 0.23699662317672085, 0.10881424010280641, 0.02534117346869842, 0.11052087715436375, 0.09057423054811456, 0.0621194804027196, 0.07785942330355607, 0.10022119273461642, 0.11439961095851277, 0.33934235392558965, 0.4610683318347701, 0.14378446845277665, 0.2987110728938734, 0.18786656189589732, 6.998112922714603, 67.75517925139397, 78.56283880049183, 60.92168869510774, 71.35907649993896, 81.49008797061059, 96.63114286238148, 75.72347425645398, 45.36664724349976, 16.43155586334967, 16.971160250325358, 37.76049290933917, 55.405490859862304, 72.03117462896532, 86.32186751211844, 96.7328420762093, 83.73918287215695, 70.50810260157432, 74.55691429876512, 82.50039639011507, 82.0706928929975, 76.88161680775305, 71.41892402402817, 69.97386009462419, 62.41080476391701, 62.07046070406514, 63.160514831542976, 64.78916529686221, 66.0554672056629, 66.95767510321834, 45.10311495873236, 14.749471929765518, 6.19505665956005, 15.151406026655629, 18.803283668333485, 18.70507928632921, 25.204409399340232, 12.666291325323044, 45.119443785759714, 57.81474398028467, 29.626642504046043, 8.120439331377707, 0.9077871626903935, 0.5550549095196109, 0.02874048561939309, 0.19931274285960585, 0.21239954707843645, 0.25615249850576927, 0.2523442907559295, 0.6180281949139411, 0.13758572930049512, 0.2159245168009112, 0.17079787779479258, 0.12263033704291429, 0.0681780101430993, 0.13690927366335548, 0.26261205995275133, 0.29128804862979923, 0.6426049696822321, 0.5019377129933527, 0.30619900012689255, 0.051567676447091565, 0.13457652061216294, 0.8644213154911996, 5.593964707466864, 3.9950975343104336, 1.7338082290464834, 0.7518736837852387, 0.5715920511753328, 0.29070934581179775, 0.8521684439432237, 8.491269523097623, 27.553346272437807, 34.06768729609828, 14.363569540362205, 25.063586504228656, 27.392132935985444, 9.066546886197983, 9.080553670083324, 15.47887980937958, 9.686604968963131, 15.645895311909339, 10.089991323409542, 10.064680268687587, 17.68880298060756, 26.512388452406853, 31.717112833453765, 36.6721724694775, 45.05031985621299, 50.92375932201263, 57.54993692521126, 61.531350535731164, 64.72253991711524, 64.65454170780798, 67.23696354896792, 68.01905278236636, 68.66767160354122, 65.03228948962304, 62.47947369852374, 61.69751782571117, 50.19432006343719, 33.707754919605875, 43.555932121892134, 59.59380165223153, 62.31145504982241, 71.96749887158795, 48.12704270885837, 50.61331156761416, 55.7833759246334, 28.345547376140473, 7.701084027367254, 0.20479632361281305, 0.238832047269229, 0.4230776333039807, 0.24300972390319073, 0.1802548501760729, 0.368317024962556, 0.04792465257548517, 0.13918343631009902, 0.487279478580721, 0.4678374234466784, 0.30144376980681575, 0.10173744927611082, 0.15748523085588412, 0.14099030064478998, 0.16091707493028334, 0.12405011247122481, 0.07983928561330804, 0.16249469511451262, 0.08898726409120906, 0.05913110164504859, 0.002221010748349551, 0.09916880243127385, 0.06627140116066703, 0.19667033706941914, 0.044895843527610266, 0.01338561298325658, 0.04423641802502736, 0.05793642200108978, 0.047352178052308104, 0.08472256752992831, 0.016900993200139176, 0.06479246842284357, 0.053316524943276766, 0.03320766687994042, 0.14071522911469783, 0.04238291808794584, 0.05859188299866454, 0.08806862507856662, 0.1378429050166761, 0.04303375574489755, 0.04367195678153827, 0.044175077364930225, 0.06437976919715444, 0.06995720338196525, 0.2942044227834671, 0.36975540100566806, 0.33452442696978973, 0.4329453054214678, 0.18366689853850873, 0.06354805435084047, 0.06553804051251182, 0.07165601101493643, 0.10628302431394977, 0.05064691154045924, 0.1257705927315739, 0.06507925343729797, 0.05736265278932068, 0.12173008414045458, 0.09268471084895635, 0.12050783682254054, 0.0807520946968467, 0.37350822059858235, 0.2739145534653818, 0.11607330622932605, 1.2553182917256511, 17.453107756953088, 86.40015017601752, 103.66656487987888, 97.35138416290285, 96.93206710200157, 103.14344621473744, 95.75545803193124, 79.03437829786732, 62.771027395802165, 36.29536605650379, 44.13467391844719, 47.29346844457811, 67.6443644492857, 93.44242849657613, 99.17784367838215, 104.7909358239943, 95.13444485202913, 85.08798399279195, 82.89566932186004, 82.23032551427042, 86.05401669779133, 89.4553235269362, 86.58192849928334, 84.04209967582457, 80.51417089277699, 73.57481556553995, 69.51124006702055, 73.56420163185366, 72.03674439461001, 80.73567498114802, 61.687225526379, 28.2777903925988, 22.658567582407308, 28.392147094972675, 28.003944235463297, 25.604346029220093, 37.00990815316477, 22.766124856087472, 65.64650127964636, 72.66387647198093, 48.0179419825154, 16.480287390370524, 1.4414868503808977, 0.6163794511268216, 0.08432491427107204, 0.17526104475461668, 0.23397999875728162, 0.4023727281920372, 0.33741904422640806, 0.37030683109356516, 0.38342216442669597, 0.07208762495147605, 0.08068064167614906, 0.14980424946594625, 0.167764613945638, 0.3552058897912503, 0.1617676163873365, 0.19174063788546672, 0.9842200000439921, 0.7251749067537246, 0.5628960339292404, 0.0014041481922651012, 0.2827385686818631, 2.0113653160872, 20.135661825057, 17.560868993882213, 8.617905205295934, 2.288050901505255, 1.8500504883066302, 1.315039074228656, 0.6747883846682887, 10.79077374550604, 28.08346244596666, 44.75772280846873, 27.87985417150682, 36.83970082190729, 49.16841630012759, 29.8833655541943, 21.791202099092548, 18.489941204747847, 15.981272670530505, 17.113561899431293, 19.041247983132642, 16.537518693554787, 25.764884718002815, 52.61611692367062, 47.05013244382797, 52.885611211099935, 64.74298723282354, 74.87272001081898, 79.49640212520477, 77.47234928992488, 72.43437074845838, 78.11648091962262, 87.07879866323164, 95.72940564924671, 83.82870704896989, 82.66124494614141, 70.15998440404093, 69.23807836348011, 63.83596266469648, 46.32974993798041, 46.628093258027114, 70.86473234238164, 74.30425090174522, 78.0017045236403, 76.60139483790245, 63.028287810664025, 57.909061293448175, 34.967027941057765, 12.904992065122052, 1.5207779311364698, 0.5961012263451854, 0.08475872687995435, 0.05600546674442388, 0.2566726722063557, 0.5591300682675454, 0.553064796953432, 0.39906166553978, 0.37875871143994794, 0.3022306646791197, 0.17175608524872413, 0.03539645668840216, 0.07049053081221159, 0.260231702197944, 0.14040706258627678, 0.04420153421139525, 0.11038745528147106, 0.09032318353532784, 0.056442899118748405, 0.023256069830348416, 0.01860595060392253, 0.09576978522443003, 0.09681805397473997, 0.26107470534982224, 0.019428359397176295, 0.022453000926743114, 0.0667409670929755, 0.05526474016087671, 0.09291881199685798, 0.028269190243595553, 0.060547234325279156, 0.22514263828915937, 0.14496021423368685, 0.17266880240171187, 0.2368004740245881, 0.27092166244983673, 0.14600638390308426, 0.1656289140303289, 0.23954020362467537, 0.15104888187300775, 0.19000960093352104, 0.2756254729484358, 0.29316232870182685, 0.20082225782736657, 0.3366218531324018, 0.6042586531369918, 0.31680110541562884, 0.36331486918272515, 0.3102841793048767, 0.26454125320719135, 0.24557919812298593, 0.27274709675581227, 0.2064368702591427, 0.13178705658403136, 0.3166820553521956, 0.13963133727590885, 0.09003856654969916, 0.1965488968116622, 0.2240076024205454, 0.10350738817285146, 0.3546896384608361, 0.520533639336786, 0.37521114212370693, 0.32959201583458536, 0.3700052375995344, 7.647028863430024, 79.63432834994408, 122.67550037753199, 114.4449870817123, 120.62923123759609, 110.69388328060028, 117.63939672900786, 91.63607505060013, 62.79966462043024, 38.95218349272205, 35.45731244548675, 41.96255160916237, 67.99750328063965, 94.57024328170284, 111.18701934814455, 117.61746283500426, 101.34814600790702, 89.80021753618794, 91.55001040427916, 88.86292795981132, 94.86134590641146, 96.06734137381278, 92.06556673972838, 88.93300502530991, 84.74082285358061, 76.90928520694857, 73.26436781114148, 79.11725013486802, 84.53119570209135, 76.43552564805555, 52.763433302602465, 20.696401903706214, 17.249154313918083, 24.45725279469644, 28.32176212341555, 29.322539183401293, 34.27589847195533, 19.776713963477842, 64.06591553841868, 74.00158512976863, 46.72277535161665, 15.569063924974012, 1.5961383066831099, 0.9156279806648532, 0.11895217271822116, 0.2559517834696078, 0.3026438925054766, 0.6581631735447915, 0.6128226581119722, 2.014038533933701, 1.2457926931881136, 0.402449551489084, 0.39308611844335833, 0.44070026026137415, 0.31580227997995197, 0.6395268284024731, 1.8724114303627324, 1.1934633721267025, 1.5881353232168383, 2.2170535499049775, 1.0476583314518775, 0.18678919712622322, 0.9490834080403852, 2.5874358559808424, 21.460846354884488, 17.094581550167455, 10.46686343608364, 5.070969106689577, 5.443029451754786, 2.1500391200665505, 1.5799180802799042, 15.626940458051621, 37.687019071271344, 54.881897587930005, 29.56490831990396, 44.6050210152903, 54.819280870499156, 20.87613274974208, 16.995777045526815, 18.856498464461296, 12.041623477012882, 23.756760627992694, 22.121051857548377, 25.271083808714344, 35.50152540206909, 50.09710804108651, 55.15622423541162, 61.07055441025765, 65.47789427541917, 72.25080382439398, 80.4979165907829, 87.97203217783283, 76.94642220774006, 74.57187421860235, 80.03877178315194, 92.14311199803507, 86.20261176939934, 83.59789909855013, 75.68268945140224, 70.81960939591931, 60.81193293294599, 52.36678361892701, 59.32317379982241, 91.88975041912448, 100.28323035086356, 97.28068736291702, 83.06438615245204, 79.48931832467356, 73.81539021768879, 37.949017709301366, 10.660860923028762, 2.074693330833989, 0.5965507667391532, 0.3905746677229482, 0.19542811017843986, 0.3192367440750522, 0.6782032369125275, 0.7009462423382268, 0.8831342081389121, 0.6853323285618137, 0.5831418378699211, 0.5811188754535491, 0.2269973371538424, 0.28032336924825946, 0.3822726341745546, 0.2633967484918333, 0.35197223266286237, 0.320763771812762, 0.3183927603306309, 0.13480810899167292, 0.16687455767345044, 0.16754522168588254, 0.2621281681762588, 0.19483454525470736, 0.31462461897923105, 0.10488937248385723, 0.09417625339401346, 0.22871328217367973, 0.18373740927105953, 0.10505641795574658, 0.1784210195464473, 0.14971300839416443], [0.02639366910913058, 0.06924346224555085, 0.06125341800432052, 0.07446583766009539, 0.12396015076627656, 0.02421635721299437, 0.05769255706259321, 0.05663787615635703, 0.018991752482590177, 0.06678923063220517, 0.007069027483192904, 0.06499811706523742, 0.05228761140437377, 0.09254115363282543, 0.27477248001002497, 0.23656628094613555, 0.33825175115658396, 0.266116329979512, 0.07038443529557797, 0.08941347710788251, 0.17397392511127457, 0.04451896657326049, 0.04166852194635619, 0.05052884206956914, 0.09409626615383933, 0.24500818682774422, 0.24197383513373716, 0.0488735175871801, 0.04922536644904364, 0.3145243227481842, 0.2843106117460036, 0.27888655602451295, 0.29367646562956995, 0.14693109799296628, 0.347101568214355, 7.594368102089052, 37.31144428253174, 58.25394745795958, 49.13921033182452, 48.36065515395134, 78.87783650429019, 106.59044081164946, 89.08728753366779, 47.22770206389889, 27.062867610685288, 24.515319562727406, 40.65018930742818, 44.945969120148696, 48.07300421499437, 67.57055328738305, 67.7908649752217, 85.16041448039394, 83.14622248372724, 86.28666816219207, 73.60794390401533, 55.86425127521638, 59.77042990346109, 60.655061660274384, 57.69952043410271, 52.36597561067151, 50.73663873057212, 56.25672363465833, 57.62339115142823, 36.819163291685044, 27.616984767298547, 25.74939331700725, 17.122400960614605, 15.205371956671438, 12.30994301457559, 10.112193899769938, 5.971872816162725, 8.942117537221602, 12.939678565148386, 35.49376695386825, 20.75784191008537, 11.330112391902555, 2.5705838828317584, 1.9316824886106678, 0.272967791365039, 0.3555188213865603, 0.11911800777119015, 0.04653364374873139, 0.10167345029091644, 0.20322133877104331, 0.28526629110978496, 0.2039903837947115, 0.11306907711250168, 0.0882367660561877, 0.227202189064795, 0.33702527503332785, 0.09769771443379503, 0.0819597480398032, 0.12898122891783714, 0.5145820554706358, 0.6271776136371398, 0.294057609693658, 0.19852047005007345, 1.7074833642090521, 2.95962784559496, 0.9758811023446822, 1.5363103944447734, 0.5772243908816769, 0.43914099554381064, 0.740461792917021, 4.477796419974297, 17.99397710830935, 29.520173688088697, 40.08779202738116, 23.41990943877928, 38.593612178679436, 10.745209532399333, 5.333222698780799, 7.933616349774023, 16.350559899883887, 12.34387641952884, 18.333293507176062, 14.603913753263413, 25.10333972592508, 14.206035387131477, 4.798818884357329, 11.582042305700242, 25.377225106762303, 32.29415232135404, 40.04790544509888, 44.55527751676498, 49.157017892406834, 54.15972648128387, 56.00602142272457, 46.65466731594455, 40.913584309239546, 36.156651435359834, 31.57164977442834, 39.6037950823384, 43.33371023977957, 36.75184757478776, 55.38387467784267, 59.82559019519437, 52.95736312866212, 55.07592547324396, 39.925641244457616, 42.9468664815349, 38.49644330240066, 27.83869674128871, 5.051143486653605, 0.2953884269922011, 0.4192842723381135, 0.4914399488799034, 0.16057638030859733, 0.15521566473668622, 0.38210103047951577, 0.07038815848288998, 0.10363448982036884, 0.7694044721222694, 0.385307751956486, 0.3635537353975158, 0.1281640812334034, 0.05275133208581998, 0.14768151175831595, 0.2282871381049195, 0.15772824926722437, 0.09503499965273565, 0.09072263710080616, 0.09850446630509631, 0.05312577671101017, 0.13689718479591031, 0.0368178638839914, 0.05373290905188169, 0.08681868368218984, 0.14351549498256178, 0.0641303309690087, 0.05537615232770482, 0.06149922114526553, 0.023973074501320243, 0.04163792822510005, 0.09276701933554105, 0.04877728545257161, 0.02539646011897393, 0.0359231268145865, 0.14586664946569552, 0.1359717812268965, 0.11423169980726897, 0.06165391344937587, 0.019251965737390905, 0.05841546061058199, 0.06144698544014847, 0.09768936407542038, 0.004516838122189286, 0.06047748201977342, 0.14522374847963934, 0.17135319960934503, 0.23290263398760752, 0.4255483281468192, 0.7340658780547881, 0.5012893881047926, 0.06457749649041122, 0.06249563723442055, 0.0679055433119497, 0.1408776550764038, 0.10990693429184538, 0.049360040875692526, 0.06631915908186667, 0.07757925728876745, 0.07605392260537033, 0.009477820506529703, 0.19901628215466777, 0.22026242838511545, 0.2545704196898207, 0.26017326501107985, 0.49296176721972806, 0.27870012086726004, 0.7141661007077463, 22.908000907590313, 72.98408308336812, 91.77462885456701, 86.22161957525438, 89.80268078465616, 106.5695502681117, 100.30716465365504, 84.51155247226839, 64.03360697530931, 40.987058147307366, 48.4916623177067, 51.541387496456025, 53.62555457699684, 70.17873333346459, 93.68097920571604, 88.81819725036623, 98.35728383833363, 97.06420390836655, 97.22165569182366, 83.60948578003915, 71.13994936789237, 76.27349253623717, 79.30103671166205, 70.129484053581, 76.05704830538842, 67.95354920048868, 63.535320835728804, 70.35302777444163, 55.67751899842293, 35.6993148403783, 32.15965424814532, 28.142837324450095, 23.011088640459125, 17.054294886127597, 19.01031421076867, 24.11820507818653, 26.63647851636333, 35.69765175542524, 45.27596204511581, 36.38691417632565, 20.84465180673907, 3.6197313666343693, 2.0426296707122558, 0.13243365011388256, 0.2390470115407821, 0.5918664761608647, 0.15036372347704827, 0.2753478120411596, 0.7285910460256761, 0.16829347508328577, 0.20231648168015867, 0.13233496266747677, 0.26626023193520887, 0.3679917746734235, 0.41377380189876406, 0.2597517940786577, 0.4369396572151492, 0.12687898406218137, 1.6452548388511905, 0.16114719242097872, 0.25016051116249255, 0.22091731098630737, 0.07620287308048818, 9.835933523793376, 5.800095065947502, 3.1860395544959657, 1.7084836911770607, 1.9719072527462438, 1.6898216667675203, 1.8416795374885684, 19.469776730383597, 35.29202376642535, 51.30558636880691, 38.017212037117254, 49.274857659493726, 28.739219980855143, 12.240646500741283, 11.289370732922709, 15.43272626015448, 15.8380522266511, 22.052224066949663, 22.437465536978937, 29.305655340994562, 23.85577105706738, 18.29397959093894, 30.83995907537399, 44.42602365247665, 50.48456761144823, 56.44151041584631, 66.08393576837355, 76.1175940113683, 77.01919001917686, 75.59802901360297, 64.85293911349389, 57.8700807786757, 51.6192190877853, 43.600305895651545, 49.11724113648938, 55.40623218782487, 46.92025100031207, 55.36547091699416, 67.79134350438272, 67.41882031963718, 68.57399755908598, 68.09271489420246, 62.09543443495228, 47.852261066436775, 34.45806903223838, 10.568441056436109, 1.250958332130986, 0.6275482163313897, 0.34060250727399705, 0.1654012633427497, 0.2299211270386173, 0.30072027637112525, 0.2487707970243308, 0.48940004059864634, 0.6235388798579093, 0.39745812094019306, 0.24797132298831018, 0.14298458072927692, 0.13208797592068874, 0.06526702158753911, 0.26170678917438756, 0.21219552254244206, 0.041476276012197624, 0.022290408340913635, 0.06046349708471568, 0.12535143538468307, 0.08906659249576832, 0.022418402480862798, 0.02920915905926978, 0.10775755204620863, 0.06431004753516567, 0.07362337076976415, 0.02802775188859913, 0.0165124123375262, 0.049859319528144215, 0.029571032181622523, 0.026699464595425996, 0.06413834424869669, 0.12248799790658298, 0.10721535331779912, 0.3246987364705532, 0.20892605846447332, 0.2533921764622773, 0.173797786175724, 0.2765400593559588, 0.13749871703405536, 0.15771476611975702, 0.2499745816232697, 0.14125141405290173, 0.13180147435876632, 0.3054059459076774, 0.23639144436005624, 0.590248866186988, 0.43778581664927546, 0.802349194643959, 0.6355553060289353, 0.26424018065294913, 0.17338210686800942, 0.12609320001736765, 0.28051633147462723, 0.21000064999586154, 0.146150944694396, 0.24901825874563188, 0.3020122989771828, 0.2995029626594436, 0.15356987804895447, 0.3759559328036924, 0.3906804797870498, 0.3581857266685655, 0.4104414420022119, 0.4381756021851494, 0.3253711778069696, 0.2146848946088745, 9.117239598304995, 54.67502786267189, 112.8057893629997, 104.3102179804156, 100.1306736853815, 111.89621525426065, 111.16009619928177, 104.37789455536874, 73.66298260227327, 50.526587963104255, 50.05941014136038, 48.545614519426906, 52.333506230385076, 70.25589419949439, 100.19704803343743, 97.82849342592301, 108.69922468739172, 101.30916549313454, 101.98138129326605, 90.32308516963836, 80.18622936741, 84.66854926078551, 79.4328675731536, 75.15490316575574, 77.59254640148532, 69.6683309924218, 69.58050912426364, 70.40006483754804, 53.11863137829689, 36.113646568790564, 36.28831755730414, 23.232071053597238, 16.801566769999845, 10.739451492986372, 14.372976364627963, 18.08472114224588, 23.240831667377105, 30.175229118716334, 50.92001738086824, 32.48807038030317, 27.789149361272013, 4.258775191922342, 4.305992193760411, 0.26574725946111066, 1.0130764483924837, 1.9617513783516425, 0.2813862702779232, 0.6526544497859094, 1.089292329645926, 0.35576286635571913, 0.28952160309399333, 0.27843333840850865, 0.7262313726448244, 2.029446339414966, 1.3650567709438264, 1.0736472207692362, 0.9472281882359136, 0.7249365001916886, 5.051951494909102, 1.9790106651283081, 0.25815753446471307, 0.3774923068140784, 2.0327644194326093, 9.54601937724698, 4.070653905791621, 2.7164597713178207, 2.385764006645449, 2.802356000869505, 1.3458245319704856, 6.4566723762019995, 27.903990476362168, 46.276648890587595, 56.050834501943285, 41.25099051383234, 58.83539961230371, 22.184482466789987, 14.191732464298127, 8.736187219619751, 18.613782198198383, 16.954174426294145, 33.54379984640306, 39.508301058123195, 47.903161664162916, 32.36443138891651, 23.231971033157844, 29.939894753117716, 44.47628490386471, 46.542232574955115, 57.15634669027021, 65.68747043609619, 68.43083889253678, 66.32180398510349, 69.73457197989188, 65.40584033535373, 60.060932405533336, 53.86709413220806, 48.02800678437757, 55.662041325722974, 64.29108704290083, 55.53563117980958, 75.82005869957709, 94.35638781516784, 89.4666591767342, 80.9086436610068, 72.9871033084008, 78.07734351004325, 58.356101666727376, 37.19256900971936, 8.594492577737379, 1.5323912111982223, 0.836020720101172, 0.5815122156373916, 0.2537324727182427, 0.4970767625397252, 0.5597783012255546, 0.4700788434955382, 0.49807626213277545, 1.0079033937185042, 0.5577042254228746, 0.3183789094609599, 0.29662136889753804, 0.203983458359876, 0.22488523274660113, 0.3781387930916202, 0.29751186950072167, 0.42882467169434796, 0.11216792022629131, 0.19374403441625257, 0.10145922912464989, 0.23341159216098248, 0.1860646618109557, 0.14702610821733553, 0.18635974355763008, 0.20169159908208156, 0.21624379160423435, 0.2035822734356888, 0.16074982261465443, 0.17160784723537584, 0.0883903973285229, 0.19444282917726427, 0.17191118740987393], [0.04805653844208968, 0.048467088791151205, 0.09188540535227907, 0.036162598238837336, 0.03776701234821831, 0.02673763684147308, 0.09863433353002034, 0.0313548123719351, 0.11290054543003922, 0.019031646511247082, 0.150608365994788, 0.008770251165955298, 0.16748266294598582, 0.18332799656256554, 0.38108296091518096, 0.3434116597617826, 0.1988566600747647, 0.3759165558843844, 0.27482763834057317, 0.09148438896743522, 0.1494908428961231, 0.09672544160557371, 0.1758069130441835, 0.06349208779753217, 0.07194828121892868, 0.05342343634354973, 0.11196951111478191, 0.11761209341667353, 0.08901186317445771, 0.28970436102920966, 0.2460915577267447, 0.43341583662456085, 0.3848182217728707, 0.03127391923279051, 0.28249550430524734, 0.13702996315494662, 6.766639640254359, 33.94630562874579, 54.953174898701334, 54.03161010434551, 40.6636469594894, 66.40689588362171, 87.52176761627199, 110.79706515035322, 72.28122572745048, 59.991761407544544, 49.213527479479396, 54.63059525335989, 52.68910438783708, 53.59107694318218, 57.67912018683649, 64.52225585137644, 68.3992402784286, 70.0363120725078, 75.83927831342145, 58.477385274825565, 62.88108518046718, 72.94787960667765, 61.720271495080766, 57.183795436736084, 46.73766466879076, 35.24988574366416, 33.10458067924746, 30.051170433721236, 26.87126571132291, 32.38937374084227, 32.16545543363018, 25.70762399704226, 13.671706588037553, 10.480830996267258, 7.949009691515277, 8.283854588385552, 14.016967338900413, 20.260395157721735, 18.15764388730449, 15.260367508857483, 0.5334631197394863, 1.3384948478591059, 0.762725901459494, 0.5247394007540519, 0.31103969521580205, 0.04958168926438497, 0.45833762675043077, 0.36903521706981046, 0.09489783927077249, 0.06501572176573739, 0.38789706785352, 0.09953228050782796, 0.5638176683456667, 0.8070930562192394, 0.10395535042569523, 0.53127872727571, 0.7065019119651087, 0.30371822356697054, 0.5874249435240223, 0.40611448547532486, 0.28489326757769434, 0.6987166813304347, 0.5226962749035128, 0.21033634972428122, 0.09612657535340517, 0.08160927813620338, 0.11644027766681488, 0.9073656917579713, 5.598234697695702, 21.248475505459695, 39.50040140459615, 62.50594185244653, 31.686226129531864, 36.80106547570998, 38.33177043545631, 31.468936627910985, 28.134419918060306, 15.115579097501694, 12.82953448833958, 9.756685956831902, 19.584284444009107, 21.88012223089895, 14.866042810101664, 20.382814291984808, 14.97266754027336, 14.526665614497277, 14.893212087692755, 20.59637361957181, 24.862229670247725, 24.995097998649847, 25.8786020740386, 30.70216425003544, 31.118904313733502, 30.255967186343288, 38.03703961833831, 41.68640890429097, 45.18655161703787, 47.09802066126178, 49.74733068097023, 44.67230535322621, 41.605819886730565, 37.447476002477835, 44.15389745466171, 40.86278961550805, 29.978951754108554, 14.654235801389142, 2.5898750799317516, 0.38700194007927374, 0.111322074888214, 0.386953799114112, 0.08491430401561723, 0.12689655811916437, 0.07014206039809412, 0.31735464990619694, 0.19537523478990604, 0.19146611793868004, 0.29147996897658995, 0.3785358104974993, 0.03783044059790912, 0.041675734664163286, 0.05327783367266098, 0.21857973158119187, 0.07111145273572014, 0.25812545070244425, 0.09016997361135098, 0.02433927219000555, 0.05408889478853634, 0.10736015159636737, 0.09811805155608924, 0.06163995915783509, 0.04061014849632498, 0.04967361598485901, 0.12268934113484238, 0.18418845119735888, 0.1807931648387063, 0.04924289071031156, 0.07408139941793296, 0.15826855575846088, 0.05646980795708876, 0.033830415923148394, 0.07638271222071302, 0.1402911994486086, 0.06782395494801384, 0.10449355783601923, 0.04403875584924414, 0.0472724091471924, 0.16104176340083923, 0.019300863214377916, 0.05526852846566228, 0.040917154401540756, 0.004644347232721386, 0.06310010741975519, 0.25316143077948405, 0.162835527632025, 0.18446510086857504, 0.32532441580007154, 0.36296004789971537, 0.4347782780326182, 0.13076166321914043, 0.09497214979942768, 0.0639953118027939, 0.09509973408233735, 0.07056006861309852, 0.08567490675035985, 0.04917784601510052, 0.05134272238900585, 0.07951347607999079, 0.0564566963622647, 0.13559531029914657, 0.09955489542335273, 0.1866699785234467, 0.29669454561606534, 0.1915848922104605, 0.017244824951875116, 0.22159168286429298, 0.9829807762176761, 15.406059045945446, 63.40302713455693, 75.44171471749583, 78.19130405302971, 87.64727561704575, 96.48960805708363, 104.4604447580153, 87.993911158654, 69.1818315752091, 63.96522829609533, 55.89635587507679, 47.836681412112334, 47.92460526189497, 67.61043594729516, 80.96793420853155, 79.69861599706834, 84.15577780815863, 91.89816782551428, 89.77387489811068, 64.84970315810173, 78.18618143758466, 91.31437793854745, 76.72542802749142, 72.30532476978918, 62.79826433427873, 53.68813599309614, 46.691780782515, 35.459603109667384, 32.86441983715181, 41.53506425119216, 46.73822164535523, 35.16081263942104, 21.80921950647908, 14.300844957751615, 11.764054009991309, 14.46341053132088, 29.167864438026186, 46.22896463640275, 32.236573888409524, 34.409188455150975, 2.89386072947133, 1.631509015156377, 0.7059758240657469, 1.3409931525107355, 0.93951711491231, 0.3651855946067841, 0.32439236258787496, 0.29327837570059684, 0.17363358289003375, 0.0797010220647339, 0.1705211361930255, 0.28435486098451, 0.3726262388931167, 0.35240963822410953, 0.21210972069492265, 0.5440892495455281, 0.3060727488369711, 0.6418006386487716, 0.5497173604465301, 0.6124047418275188, 0.260605430530925, 0.32614606042062083, 2.636093838560966, 0.9316328444307851, 0.3829429611083, 0.27881353252357055, 0.027404598734011094, 0.21197904141679888, 5.460673743678678, 25.14444616533095, 47.01768659776258, 62.674309592093195, 45.87006384326566, 51.66197292266354, 33.25270114406463, 29.738832096899714, 16.5929574735703, 15.087078175237103, 19.044891865022723, 21.831163206408103, 29.29106608513863, 32.39982881853658, 28.23622895825294, 26.37327963306058, 23.474310751884218, 30.541276470307384, 35.62494670191119, 39.42129504296088, 34.12033334855111, 29.03358601754712, 24.979494810104374, 30.77912311400137, 37.44737794322353, 39.036055534116684, 41.257905652446134, 43.39132985761089, 46.69669158997075, 52.198741436004646, 60.12951112562611, 63.028213285630756, 53.74726964581398, 55.1276497687063, 65.86247874844459, 63.694455315989835, 44.45316253169891, 21.21648073196411, 6.732519432421654, 0.26940713726705123, 0.8450646025519218, 0.3487339790069288, 0.21441130928935545, 0.04701526790496804, 0.23306433982666463, 0.4478230393461643, 0.2816219802104658, 0.2912656788624102, 0.2546797097930985, 0.3019392754762404, 0.02143609581605321, 0.08436154859561114, 0.07206822760523328, 0.1286684965053874, 0.060202628824739694, 0.2233069384049985, 0.0852950267313469, 0.04305846974133484, 0.18340212323011892, 0.046787360577934214, 0.009888592063479367, 0.09058099510448595, 0.04396991901880792, 0.026792006101459268, 0.0678499712939224, 0.03160679018154981, 0.22095376144974466, 0.0618123097886001, 0.024835490321199742, 0.06002110046064181, 0.07330674663065903, 0.10561026888148439, 0.2702821628941644, 0.23146690860871347, 0.17541997735538792, 0.21257527232650789, 0.12096590377510556, 0.10804694942048482, 0.1592366917118911, 0.19827663958553346, 0.3034762930004828, 0.12092250489419508, 0.3206056206216735, 0.1423140392909127, 0.510020676038919, 0.33978205775060966, 0.3740833994121321, 0.4941845048339137, 0.3207206257408665, 0.39763778388019533, 0.5523186886022168, 0.3426417107543638, 0.1357602030639687, 0.2350723175632377, 0.16419754003084477, 0.2085183771146882, 0.23763143427429662, 0.18796992247864125, 0.07557783726482623, 0.1612528206239785, 0.31744143234625943, 0.5931389788466116, 0.27605947707929923, 0.268713184181721, 0.5046971923401279, 0.13722985081614988, 0.36411935343377055, 0.495462891074919, 7.424580464440008, 48.29710491241948, 90.05433221017161, 115.18459704614456, 96.26400116951235, 101.48113004622921, 103.9133761006017, 117.25861303267942, 100.31959072236093, 89.66429956497686, 79.03250340492495, 61.187193932071814, 60.60994263618224, 76.19651994397564, 87.3506816740959, 85.38328355358493, 90.16772793185326, 96.42379068559217, 96.91738174807642, 78.03060454706993, 88.05337429046632, 89.82141402459915, 73.35258191631686, 63.831122459903845, 59.48561091576854, 48.142026162916615, 43.90292852155624, 40.96620682747134, 36.87955210285802, 41.45222379315285, 41.63048767274426, 31.522631914384906, 17.918171421174083, 11.420077835359882, 6.989619030106453, 10.29923310202937, 31.89000894946437, 50.84875183720743, 31.26908402289114, 38.398219308545514, 3.188748931692493, 1.8372612326375901, 6.659613847732545, 4.51580761901794, 1.9427889249017163, 0.7424042241707925, 0.5403651429280159, 0.7553812633118322, 0.39234135840688983, 0.15064501564108557, 0.7718582823872567, 0.4617124279179881, 1.668242502116388, 1.5288496786548247, 0.5362045500547655, 1.3770496628938185, 1.7570003458569128, 1.3395134383632292, 1.2951733724724863, 1.2695553922845473, 0.3804255349020804, 0.8199090330350784, 1.8134485233214594, 0.3710602938888535, 0.8031288270027408, 0.13986350788224128, 0.2174580562859774, 1.0475649300121492, 12.486743850092735, 31.264365411573845, 56.4013296558011, 81.5587059144051, 45.07505432251961, 53.43360162550404, 54.959607585783935, 50.54745889479115, 40.46333935952956, 28.793778188766975, 24.878456515650598, 27.046885913418187, 32.16896987730457, 35.519329040281235, 32.23483039486793, 37.26524268427203, 32.58630221889865, 35.17712185459752, 37.38331779356926, 40.86530385478851, 45.59364657248221, 37.070912776454804, 37.76200302185551, 45.87421371090797, 53.59024147833548, 52.07069566172939, 61.27578458478374, 62.76548900911885, 68.20805611148958, 66.78961723081528, 79.23721974895847, 92.36880517775013, 78.07537448021674, 71.06970756284653, 79.77219181676065, 74.94093002811556, 49.66145038604737, 21.84683111406142, 5.621789020876731, 1.4913314725122144, 0.7306200758584085, 0.567188210064365, 0.22517066178542955, 0.4347095139805348, 0.31534596736873355, 0.6158744459671359, 0.5299633236662035, 0.29941516898332105, 0.3583073507874243, 0.262135400046264, 0.10878987084593504, 0.1885317100752746, 0.16109272356956236, 0.2751301511401131, 0.15012113407494562, 0.30656365797885005, 0.11109058610013417, 0.13334645919742125, 0.22559311331039478, 0.20182849899415048, 0.2082237856642854, 0.22444997223154192, 0.2013215786146541, 0.1929295144133991, 0.1943081968854512, 0.27962730176025824, 0.39408822273535116, 0.17893051398136925, 0.20775601237771973, 0.24489699682641417, 0.22679976307817046, 0.18652661282929683], [0.07846901478666453, 0.020899795964660666, 0.14331047453226584, 0.050515366582981044, 0.15414721723045074, 0.009379992993818897, 0.024137490376409505, 0.10296157350943935, 0.0479976607546691, 0.122204759879218, 0.044068411112793034, 0.15650194168331164, 0.31500125844632426, 0.2580989440602641, 0.2706950536418346, 0.30103991889665205, 0.17581178536338193, 0.4177149259034665, 0.4046006344499127, 0.14750220121875887, 0.11038187050050306, 0.1826037063954338, 0.07779608315397656, 0.16359318858913838, 0.11487401090562345, 0.02014558431842635, 0.2052140713579232, 0.20327168606942703, 0.16910555892654006, 0.1947979568954437, 0.31000238152280934, 0.353227912057792, 0.2794255754880367, 0.17424858295388762, 0.07669378222236711, 0.10291967616086045, 0.3380013016923782, 1.4811536573594617, 25.210238041416293, 49.75624230600173, 46.14820303455476, 42.445877828905665, 52.84825063520863, 91.54677837125718, 108.16938307977493, 99.30576785918205, 75.47316428153746, 65.8862953801309, 67.66045401173254, 63.630756024391424, 49.11919055446502, 49.00050747779108, 57.982174273460146, 54.43627711265318, 52.40081802491219, 55.91561863499304, 60.18946847608013, 47.68734501254174, 37.108402790561804, 33.65882335170623, 33.5148488321612, 30.17546642211176, 28.065727449232533, 21.8163150741208, 16.00470785171755, 13.082141991584534, 23.791226494696833, 24.880264728300034, 25.195050624109086, 22.75281233172263, 12.61050247376965, 16.1756065007179, 28.643998561366914, 27.204575000270722, 35.12666056233068, 17.929467847270352, 3.953022514620135, 0.8301320167318468, 2.140162346824523, 1.824972569461792, 1.3989181023451591, 0.3185506970171006, 0.5275996053411115, 0.06880136822620708, 0.43547783888155417, 0.17509469642273842, 0.7821062711938735, 0.7755421847105027, 0.9674624702142132, 0.7096316569274472, 0.17528621840380854, 0.11525264986219907, 0.3099774070564778, 0.11944003283016144, 0.06548317329537484, 0.396241266881266, 0.5457454090637546, 0.9573487000119303, 1.0011280508291338, 0.3019742703726215, 1.0511824584776357, 0.13187138754273617, 1.3195180532432373, 4.078644999573308, 13.316716397962264, 25.187333360795055, 34.175407348140595, 61.18547201156617, 44.782151329901914, 56.504880228350245, 63.92266665735553, 56.28821242240168, 49.95210586055633, 42.98674914144701, 28.762307051689397, 20.249085003329863, 20.08114480203198, 20.146099252085534, 11.79692445262786, 13.310521994867633, 6.631070759988601, 11.958211333520952, 17.227991165653354, 19.014644507438906, 27.866043506130097, 44.219561853716456, 53.20454305218112, 43.19849045045915, 42.34797154703448, 47.02896733437815, 53.96635363178869, 53.0458047313075, 47.28651800463277, 36.457603131571126, 41.70653458564512, 32.64381789392041, 26.468177457009595, 25.37173967207632, 26.758577977457357, 15.357739367792684, 5.738417756172919, 0.5590856351679372, 0.4984693265249653, 0.386516209691763, 0.2052039436755642, 0.22826760286285033, 0.29526045966532927, 0.17380406809670312, 0.0806250926407595, 0.2202316163288009, 0.13924699096429732, 0.09596055643933435, 0.06710382463831095, 0.09855813076419216, 0.04674557814254396, 0.07593802882418518, 0.07896753118163155, 0.02876036943146779, 0.20116543457392724, 0.07191847273779493, 0.04771652180821665, 0.02590594114735723, 0.061886294729887485, 0.07458807464929358, 0.04195449490761084, 0.02514055419352747, 0.13861184278803487, 0.08295427572222487, 0.1743849772479265, 0.14987476019849702, 0.11081347677616343, 0.09122327555932346, 0.05215128222780843, 0.035584726626233715, 0.1142501931697611, 0.05951424519861898, 0.11707410817184757, 0.22748846080034013, 0.2041525186430062, 0.13230415061116219, 0.30378456678121324, 0.14447880458206902, 0.15091803405554066, 0.030106504658056848, 0.04460602480497572, 0.024266974557371392, 0.05031664720586231, 0.03752862110794072, 0.16198262662416504, 0.07592392514549917, 0.24863775819540027, 0.43196655148940705, 0.477359528623281, 0.5905059652943766, 0.21353098233380627, 0.1963031511273115, 0.1816999065058847, 0.07426110066233144, 0.07548279639693999, 0.09070372238995568, 0.1153227928725462, 0.05911388764939001, 0.03347946338415627, 0.20439011315184258, 0.027572067469478618, 0.05954067906244628, 0.1838348403332695, 0.17654248002556064, 0.43003536640636386, 0.2000625437546161, 0.0024936645528331643, 0.15724446474304124, 0.9320012407918131, 7.1593993133114235, 48.12716822470389, 83.36458867596042, 72.7301331489317, 76.54390858065698, 81.38816910405313, 98.56269836425783, 103.95548666677168, 85.3026710018035, 80.44450959851666, 76.85965153478807, 63.27208272872433, 54.96263565555696, 57.519891569691325, 68.6232860626713, 73.31488793896091, 68.8695324620893, 74.17544026528635, 71.4027246352165, 63.553379428002145, 54.799049285150346, 52.385850260334635, 48.022091850157715, 46.25367164611817, 42.42827815394248, 30.17323067111354, 29.110060468796764, 35.36823149650328, 42.806881012455115, 57.01456085328133, 47.29045998665595, 30.37171436894325, 21.81585615681064, 14.332131743431093, 21.072686641447007, 43.715097981114546, 57.54149206223027, 54.08044361299085, 40.14383093003304, 3.981426358222962, 0.6415212923480619, 2.148267189341207, 1.411122924858524, 0.4590735308104946, 0.3072835354795379, 0.07909537593443548, 0.3438133043387244, 0.4638500583748664, 0.5335195650977473, 0.6241846613345609, 0.41393936882095955, 0.4487011293249746, 0.6334625376809029, 0.21827591643218072, 0.6993358642343552, 0.8159725055579217, 0.1135072794051901, 0.7712534406492788, 0.6406764505851654, 0.9253067967872467, 1.4309785755411273, 2.197754998360911, 2.9211846955360907, 2.404061863499303, 0.35171182405564094, 1.6664530432993367, 1.9348543377653247, 11.192510743294994, 30.845675929900143, 51.508223856649096, 68.68825620220554, 53.490464225892104, 63.76592090052944, 74.34268228469357, 65.52679054198727, 55.03588199615479, 30.308509295986546, 24.88336536192125, 21.56769367956346, 24.139507470592378, 28.23545232895882, 19.065343103101178, 19.56398617836737, 15.884417583865506, 15.448490265877018, 15.495821506746355, 12.498829653186183, 14.436086320107984, 27.100206613540653, 42.12092514960997, 46.05541152338828, 47.6322357116207, 47.77646126285676, 52.4570648131832, 54.0571290446866, 56.721704929105705, 54.53868235311201, 58.36438571253131, 50.396569236632324, 51.173273055784165, 59.384896216853974, 47.578259975679465, 29.735547111880397, 13.720025285597771, 2.204741475082213, 0.5024650879204273, 0.5245775416974099, 0.09432972378788457, 0.15072597581292355, 0.12872941581712616, 0.07579971931033558, 0.04741548372793102, 0.04495528428965519, 0.03445883401699605, 0.11310715168233841, 0.1510569257962127, 0.03879107655056062, 0.052189475541273435, 0.1262254191322192, 0.08247520263877609, 0.09449947355014664, 0.16264176867421598, 0.16493987922947254, 0.042876627281188004, 0.028162813189649777, 0.04128306097681484, 0.026631853505668622, 0.02808957135364894, 0.11615648039526517, 0.05660567748089952, 0.1792003607918178, 0.00869373526168807, 0.06807864853932012, 0.07640345788170254, 0.0939933499020915, 0.023530028617730545, 0.01757295956204255, 0.05226329960409672, 0.10320883604788011, 0.34177465244166316, 0.24422956570502252, 0.3245961113322166, 0.2505714407250766, 0.3688201915112234, 0.19948797781140576, 0.4405528649447426, 0.10406460988545611, 0.1207079926145173, 0.19401504568034605, 0.16823356700760705, 0.3232547833073524, 0.23343685774072526, 0.34928194637740817, 0.5831160973156653, 0.5147113711122544, 0.49426662945939653, 0.6141745887937085, 0.5144906152159937, 0.3849705200522177, 0.3655643178330314, 0.18164445706192525, 0.17828287857194103, 0.18784045361943785, 0.2874686406745065, 0.11233479715883733, 0.2628799149345967, 0.3146285413494033, 0.17672244940073262, 0.26157851541234606, 0.2655674739470405, 0.27253001808158817, 0.3798105195164681, 0.23992265003823468, 0.2008281873479005, 0.29107369722858556, 0.3852402136450814, 1.9122795039607634, 33.628617179009225, 78.80300552614274, 102.20927100027762, 89.97021305945613, 88.66978260778612, 107.66982216988842, 128.41048409861904, 124.30590414231824, 113.27252003454394, 107.43274627193328, 86.9621552190473, 76.54684251354587, 70.877942885122, 83.77966173233526, 91.82997349769839, 81.12281291715561, 84.24588249575707, 83.62219425939745, 78.93348709229501, 65.66044138323876, 56.16879586250552, 48.27866977260959, 42.65656794271162, 36.6018404499177, 27.373129052500573, 27.84133061285942, 32.837504533029374, 34.38363813584851, 42.749688932972575, 39.071937376453036, 30.04454947287037, 20.696778451242757, 12.66273863853947, 23.21676596518486, 48.871496800453436, 55.75913959933866, 66.09260420645437, 36.59786708893315, 3.7097620194958107, 3.4855017306343203, 2.8803883685219676, 4.388376185970922, 1.9669671500882797, 0.3751065558002841, 0.5699488232212683, 0.4519477180175243, 0.6118586130680577, 1.0978106144935855, 2.3668361190826666, 0.9446056547664827, 1.0549772290452835, 1.6091729556360554, 0.3941793259113066, 1.0699989262127108, 0.551225082768548, 0.1936605461542645, 0.9514522744763283, 0.47564882364484573, 0.744209433755567, 0.9430859814728461, 2.3840474793987894, 3.043092205639809, 1.7874981222614166, 0.2121228820854618, 1.3590719695052793, 7.484710399181613, 31.26042735192084, 40.45188996099657, 55.13844805379068, 81.29846449821227, 66.98649667924451, 77.06560734779605, 87.65248452463459, 82.3398930026639, 75.93961254242929, 67.8996793685421, 50.59996374191777, 44.25920524904805, 43.95788877241073, 43.751022969522786, 32.610346348054954, 37.88840924539874, 31.107490216532064, 34.46921248589793, 40.253465098719445, 45.92869151023127, 52.89485231522591, 64.57056768478887, 82.34555690519272, 75.00507646991362, 78.38846591211136, 80.56014891593688, 84.48499802620181, 81.68339021744268, 84.18495239750033, 83.48011032227548, 85.50005251361479, 68.88516702959615, 64.50953560490763, 70.75398814293646, 52.19424639978717, 32.73722913957412, 15.563020533131017, 2.505174682986352, 0.7428141731408335, 0.7638415706253822, 0.3530913339026513, 0.2753408866063241, 0.49386434136859836, 0.35370935235292683, 0.36596449152115856, 0.2647255126747393, 0.15022147627126786, 0.1452917158002815, 0.18573156678147856, 0.08302405867124758, 0.14455651654110802, 0.16885587555025855, 0.20110791669257227, 0.20898638022763116, 0.20753574677773062, 0.22373735724437624, 0.0802049930057218, 0.07123156766136808, 0.08745803002027736, 0.26400042577616634, 0.14760504086171428, 0.2410579157332259, 0.4219526178654163, 0.21877013507389256, 0.2211832354265836, 0.2636023358471932, 0.13358241427809964, 0.22332861869325563, 0.16264051229002016, 0.2077773249437732, 0.23569295603421428, 0.18773065789812998], [0.08107063405576252, 0.09666320462260516, 0.11818599286338977, 0.14975837612104032, 0.09385039023454152, 0.07893517162770995, 0.046465730054243926, 0.08536349200913984, 0.040549275149861654, 0.06661376585402796, 0.0571754323919454, 0.10894748577547651, 0.036105731532218, 0.3724913461314094, 0.522486305525226, 0.36827421596934723, 0.2888675478677596, 0.5019117579344781, 0.289339856394837, 0.3590655326843262, 0.16325915893239362, 0.07346956329720636, 0.04824232242460694, 0.045262225077397404, 0.11218157957398123, 0.06410966574725124, 0.04238419362433976, 0.0820724089299479, 0.12646292171050466, 0.09543844453629949, 0.14695285489001583, 0.027112495154142383, 0.10303783756230148, 0.0976644738787605, 0.22137871042134302, 0.3107972437095258, 0.346283907251012, 0.8702491608358199, 2.5030573385377086, 13.066827097246724, 48.794708559590006, 60.26456225302912, 61.813816101320334, 55.5041737710276, 74.20730560056626, 98.54191764708489, 97.94927104826897, 72.87866546261695, 57.01638083304129, 61.50829092148812, 65.65110614222866, 63.2747930865134, 58.81706253174813, 54.49681889626288, 54.51888615085233, 44.979509307492165, 44.25898951868857, 49.26344356229229, 51.63142942613172, 43.88602702848373, 33.74047533158333, 27.204323968579693, 31.7341810272586, 31.86806917190552, 29.307765576147265, 35.93420205577728, 41.06943576566635, 47.50129915052845, 46.525691939938454, 29.783874634773504, 28.515197730833485, 59.73094732530656, 62.23897357140819, 42.01293053165559, 30.709361799301643, 28.189923417183664, 14.288033516176286, 4.38197095547953, 6.362744358278091, 3.7322242077319854, 5.2431930265119, 3.2359853002332875, 1.534827738519638, 1.3703702342125679, 0.18334065233507466, 0.7173194411781527, 0.616629318364205, 0.9693474755171807, 1.672971899951658, 1.2426997817331746, 0.5367656941375425, 0.4092096339070028, 0.16922258651785313, 0.34301173122179124, 0.4771820720165007, 0.7032557829253135, 0.17129969602871328, 1.3590941554115665, 2.3026698202856126, 1.657951918821181, 0.15047486751310288, 1.2764544736954475, 3.224429262261237, 10.349298234908812, 33.0916956932314, 31.50420854168554, 40.32829215449672, 60.86637150856757, 49.63325638924876, 67.82213411023541, 69.67598745899816, 62.36383045873335, 56.79358628488357, 55.573823298177416, 65.5334036580978, 60.71284994002312, 55.20701892914311, 43.276600530070645, 24.497070735500706, 16.939143903793827, 25.981691768092496, 30.861659588352328, 29.083394235180272, 36.80154008250083, 35.21227021371165, 38.14973323575912, 35.65818878912157, 32.293736550115774, 33.37138422073857, 35.94611821636077, 34.259612790999874, 22.24450061398168, 19.661794400984242, 19.637091313638997, 17.27785429646892, 28.49691164109015, 23.350495253839803, 28.22139455426124, 10.514034840368456, 5.0839913756616655, 1.0777565163950766, 0.09363833709710068, 0.21209271354300363, 0.3062917274092474, 0.3509742039586267, 0.3418515983127779, 0.1675383728598395, 0.3116768965077016, 0.3074653128222112, 0.22169328144481107, 0.11791330386674213, 0.03269200543722799, 0.09546172594831837, 0.16906392970873466, 0.06687914637187797, 0.24356314581969093, 0.1759803553502406, 0.1548619159767705, 0.0879957624560883, 0.06776162603449437, 0.010901084507725412, 0.0698632886633277, 0.0973798722148903, 0.03550201977392839, 0.1760004881408907, 0.14329248678780374, 0.04156117387596638, 0.05872093817038883, 0.04782021563920764, 0.03158576681368774, 0.08071671675650344, 0.11394881418034916, 0.20250189027959303, 0.10136154525342489, 0.021385401862883763, 0.13323952864495017, 0.2831363215321495, 0.06862830896411212, 0.11422306599636232, 0.10232139979639363, 0.15380276877793575, 0.15305744183640327, 0.06554966206632315, 0.034591221671190955, 0.06228384456687397, 0.016349806345158046, 0.1152826345435554, 0.03545654096430348, 0.06995820695714605, 0.1266513716789984, 0.1862908416097203, 0.4659576275415959, 0.29230130716196956, 0.6021593270763275, 0.31195088019294126, 0.397424106636355, 0.32726197473464474, 0.09471811504373628, 0.02501275157555938, 0.03976981899130248, 0.08525414827970729, 0.04986233791456588, 0.11335160267809707, 0.10161257694445311, 0.16732906231716757, 0.051373208857952594, 0.155442166292379, 0.04563795673030038, 0.03231066219027966, 0.11211702134460212, 0.18843521364033225, 0.20770566507933602, 0.1638767024081561, 0.22250642248940086, 5.067733641593687, 27.07507794903171, 73.61890300627678, 71.23709078757994, 75.17415415856146, 78.79358399298884, 89.79758170343216, 106.12014078324842, 90.2397975613994, 77.26137284309634, 64.08252677609845, 62.19909091149608, 56.39543825580228, 62.82076304958713, 70.75065412829, 69.82883437987297, 61.30561813231438, 52.786465460254306, 51.61624200882451, 46.05967121739542, 42.90628956210229, 36.900097477820616, 32.2551090486588, 25.112296458213564, 27.979241148118053, 25.45419966020892, 37.379442491839015, 42.50846316737514, 40.309268659160985, 34.84437934813961, 27.39609060748931, 15.915048353133665, 19.635530210310414, 42.58828732275194, 60.81910694799116, 52.77285875812654, 62.641844134176935, 40.45270189162224, 22.264610605855143, 9.28875994297766, 2.045525605640104, 3.3848041920892658, 1.3516900688409808, 0.5843703977523312, 0.2586157469739837, 0.39499793682367573, 0.28673763957715803, 0.48591571950143386, 0.5797339723475519, 0.600327457631788, 1.3981797161602205, 1.2565084859248132, 0.39418196125376614, 0.3546220388623976, 0.4968844744707308, 0.7737543806433679, 0.1776072349880011, 0.523038930710285, 0.4751060963157685, 2.7067788714362733, 3.0404838294752183, 2.2826353340379657, 0.47789079527701106, 1.2913836274416217, 4.090590332784961, 9.125004910653638, 25.61306938048332, 40.645866855498284, 48.77963096864762, 74.20924325143137, 67.65616293876403, 79.8464579736033, 74.67520513842183, 71.65375632624473, 69.8105247559086, 62.464199989072746, 43.11768962490944, 31.873401634154785, 26.734469129193215, 28.683657646179203, 26.11383249682765, 24.20500320772971, 25.704925406363706, 25.800191933108916, 28.483907022783836, 35.91547666057464, 41.44922317997102, 50.59475875669911, 47.77813611492034, 43.77176838536417, 44.227983182476414, 46.38469449935421, 45.82543119307488, 40.37242274130545, 36.43839920720747, 36.63480797121602, 35.690124727064564, 42.899837263168834, 53.30263760782058, 40.102069454808394, 17.608641501395933, 6.968934411002744, 1.467859273956668, 0.41157902128273444, 0.25115268695498666, 0.11431660533191697, 0.14187361534324386, 0.16236934780834184, 0.31565191224217415, 0.33536902358455045, 0.10300253623075063, 0.06269825216863426, 0.032437223745810415, 0.12666883082279276, 0.0485247177552552, 0.06270390972795506, 0.053475649066029064, 0.13319976868168001, 0.20714773856584104, 0.5106852113479569, 0.23900349774668295, 0.04858864779253641, 0.07965202308109692, 0.04117899176274096, 0.13447277698545687, 0.03194914721403151, 0.029996419738557552, 0.08955426874660677, 0.032437124154380256, 0.046775007410155195, 0.026842359145502412, 0.02802494226113683, 0.06742977206745455, 0.02857802326851074, 0.1670760847628117, 0.14928122591828147, 0.11416714157788985, 0.11552540014588064, 0.33714910548540855, 0.22072108522538217, 0.271805145687634, 0.2830692428734995, 0.25343844817290384, 0.2225313969557324, 0.2496872986516645, 0.18958224644584043, 0.18871849763297266, 0.09396107461784156, 0.1785816528624104, 0.18968520866286373, 0.1887977724113772, 0.3176136182681207, 0.3578133160068143, 0.6139499105272755, 0.35906069100864474, 0.6207098703711265, 0.5728590993150589, 0.5629962995167702, 0.4865861077222132, 0.26872274495901605, 0.14264025485082982, 0.314459664927375, 0.1444252550361618, 0.19891753342122803, 0.20883774384856227, 0.18724318083015182, 0.17481188740461104, 0.24836346807499088, 0.2127345420059658, 0.2728246554972664, 0.1421616797245318, 0.1512204702462881, 0.20552640540465233, 0.3649594148080195, 0.30924481249624686, 0.7670947476740807, 2.359548355302503, 15.573793322809282, 72.54153774630639, 89.32489687396635, 100.00332217062675, 88.8164008048273, 93.39494428327008, 116.19215980652841, 115.36096249857258, 113.3387061088316, 97.77602780249812, 98.49419024682815, 90.97498309227728, 93.14535602446526, 103.96317451230942, 100.36744363846319, 89.38694092535204, 72.04272993149297, 73.04882572543237, 70.8337926864624, 68.05216543136105, 59.178371660171024, 52.382339739030414, 48.172365696199485, 52.76100143309563, 46.33228378911173, 44.56896658866636, 47.87765449093234, 44.2662968943196, 46.526562706116714, 51.34899131713375, 37.70320669297249, 41.210892123560754, 82.19376117952409, 82.76760393573393, 61.45740209087249, 56.73797492058047, 45.370244056947776, 22.000976339463268, 15.101466409621702, 13.555164144885156, 6.132018777631945, 5.611263830815592, 2.1883006153568147, 0.8056431888572632, 0.9260999735805296, 0.7146530261924191, 4.037933248666025, 1.1792726045654667, 1.320830086065877, 2.3934570002940396, 3.88857061824491, 3.6110710184420314, 0.6517501596000888, 0.5053419319372023, 0.8314248054258285, 0.4680106206045997, 0.8725230323691523, 0.3052433514066281, 4.015327158474153, 4.336191012013344, 3.1366699068777026, 0.39920345309280586, 2.571686804294586, 9.467603352762039, 25.45198352106156, 50.63826176428026, 45.75605230946695, 56.3328254607416, 87.13026015989243, 75.54346884450605, 93.49346637725831, 82.1136663806054, 74.38741299413866, 75.10712085231658, 74.15763270470404, 84.22922026726508, 88.23772568856516, 90.11265000989361, 79.93976331526234, 63.462011737208215, 58.94221751920639, 78.25254794090026, 81.39142467129616, 77.1401402258104, 78.30234635260798, 76.87449378352012, 82.93068824275848, 80.05323748434745, 79.47981049937587, 79.1595019063642, 80.29036045074463, 79.87153760848507, 74.43391661490165, 69.10882842156195, 56.3253729574142, 52.09386902470743, 58.78947257995606, 66.20869067407423, 49.57344024412094, 20.947182563043413, 8.113779146825115, 1.4895800116562075, 0.3466116090215022, 0.19985946916764785, 0.2775760553777218, 0.3549884127513055, 0.3249809019748242, 0.5448810780240644, 0.5935988154622817, 0.20173653779971987, 0.3187164784439149, 0.16033734555446333, 0.16857265284465206, 0.22188569208787334, 0.21107075225201347, 0.1667679182343906, 0.22892055492247307, 0.2898380280502381, 0.4909450867243352, 0.3218389302492142, 0.12099217293002915, 0.23541966182810647, 0.20752109917661837, 0.21661641677060436, 0.271986156942383, 0.24731631781305038, 0.2606491588296429, 0.23140683199369141, 0.16368108951757032, 0.09291080637804924, 0.1342726748196348, 0.2387241667677318, 0.14439577597283548, 0.29693656811310404, 0.1847047944583239, 0.2029039638657724, 0.3099089187960471], [0.14443682296381843, 0.07521570750301884, 0.14440201192853913, 0.1952071244558019, 0.15480997521550427, 0.13988215446231828, 0.10255323332403937, 0.1081945439199767, 0.14372790052044776, 0.31878272972760663, 0.17599379253243247, 0.09067561462401383, 0.15648893351035734, 0.2746980469073019, 0.5118354157574716, 0.4395104950714496, 0.3234048139664435, 0.2553390203824928, 0.20529994981423502, 0.27263861870573414, 0.09264516539030498, 0.11069224336214604, 0.03940172140456496, 0.03921371193662767, 0.11448463139634941, 0.16298945001777143, 0.089406835125579, 0.06604867641844096, 0.1390404843034283, 0.10133149162415536, 0.04311180478262325, 0.07708640228356085, 0.09224388853556688, 0.07029663395857619, 0.34346307958326033, 0.5024038315300019, 0.6343485643306087, 0.7692171176595073, 1.433354183550804, 2.4692391532082714, 5.8165636274122425, 17.278909414045273, 48.53326297575428, 52.68180485694639, 60.24814713385798, 73.4006937088505, 85.33841948355399, 76.7859737334713, 63.92871887453141, 57.34189048890145, 69.39276879833591, 52.706190232307684, 57.00035402851721, 49.83911022063225, 42.65711707453574, 32.997660790720296, 33.777498583639826, 34.77920524535641, 37.57631801789807, 46.27012991136121, 53.37407573576897, 65.16872129132672, 82.58150316053822, 77.99898239874071, 64.30977713677191, 60.361283979108265, 71.70357042743315, 84.63707616252285, 75.75951299359723, 71.59232416460591, 70.01222871964978, 61.07104862889936, 53.40978107144756, 41.844017582554976, 47.7251958847046, 35.54162379234068, 28.241071124230665, 28.301559955843036, 24.098773656352876, 12.260131855164806, 10.700357229478898, 8.504517328354622, 2.239442438848557, 1.1304060009218033, 0.24007427416020827, 0.1621007573820891, 1.1593848394770776, 0.8815704081808368, 1.0965414825947055, 1.4786935958170122, 0.9585221628508261, 0.7557558496632885, 0.5533815283448466, 1.3132801363545081, 1.2849036267688199, 2.201929625964934, 0.7304341309974272, 0.7978369980569809, 0.3848923790839411, 1.031252650483962, 0.8749556373203955, 4.148727703479029, 10.255544762457571, 29.74850073937447, 42.115578959065104, 60.03566449688327, 68.22997431601247, 84.05622020844491, 77.47751897381198, 67.29472437212544, 66.27547294862809, 68.05182810752623, 68.64416091672837, 54.811408673563314, 66.38627990599602, 68.24074514450567, 60.890674514155236, 48.105885444148896, 37.5851551178963, 20.428653071003577, 20.056810417482932, 20.26382330925234, 23.85477085267344, 22.9782780139677, 18.06217928086558, 21.406366594376106, 20.724256615484915, 12.465362029690898, 7.230354499432349, 7.546176391263162, 3.9077804261638276, 3.7589764883441315, 5.786978660091277, 7.939105216533908, 16.260249287851398, 20.838591744822843, 10.06940084118997, 2.8003099945283707, 0.1912788707282274, 1.932773642962979, 0.5994452307781866, 0.2381475323871259, 0.34939278397829304, 0.19987246201884365, 0.5757031241251577, 0.8395498113766794, 0.5804658008198584, 0.29476366696819184, 0.4123423512904875, 0.29569357513420047, 0.10025412685448125, 0.18317402821154366, 0.011695247639210956, 0.05740102230300827, 0.02466584015036783, 0.26564631971620745, 0.6082702572307279, 0.2959285189788188, 0.17216701481130817, 0.24282229283163625, 0.15036232919702608, 0.14883772229715703, 0.1279245638438771, 0.08554795832042733, 0.1442715165115172, 0.17182449690036236, 0.032094230860351555, 0.04169844534067858, 0.07289351880430214, 0.07637053142271696, 0.07365769916965116, 0.04149460849622565, 0.03151466236299565, 0.04661932685262254, 0.10170061576871142, 0.09915132030484178, 0.05502787726600805, 0.06012443039986876, 0.06425740197300911, 0.2684785467722724, 0.10681698759717327, 0.14271611287709207, 0.13999581126676452, 0.18464575972287886, 0.19638680792864294, 0.1385629510567073, 0.08051786331399795, 0.018215395149684722, 0.1450657658278942, 0.11877132234193626, 0.23559069861808132, 0.2489581821306098, 0.5163399514652068, 0.5519934996001182, 0.46692433857148696, 0.34623126168885543, 0.17270122324266743, 0.07980085098214688, 0.0336600532905469, 0.018117295675760797, 0.063122408239231, 0.057183074118990096, 0.11416154913604261, 0.08066533523942195, 0.16594805093782564, 0.05740556903483887, 0.10882455164626723, 0.16168182986157556, 0.024479167505858407, 0.19418732353275825, 0.2112572486963003, 0.21784083977822336, 0.11092924032240145, 0.3120056401577688, 0.6609752678102063, 3.3160707835228216, 16.357137714662862, 51.69371274209792, 75.79421028014153, 63.38109324055334, 72.19938155143493, 87.56802020534393, 93.63475015086513, 84.73870477368756, 74.7188768079204, 63.93819532086773, 58.658253608211396, 54.62358205549179, 59.82711207482123, 51.90991378599598, 46.481796695340066, 40.7197525424342, 44.228316583941066, 49.20642406709733, 52.396083724114206, 57.86286361755864, 61.36036657517957, 60.966744961277136, 62.37229493356521, 59.44148817370015, 49.341714459080855, 54.87972851722471, 54.84188548980221, 50.15138972190119, 39.38100053418068, 31.25792880212107, 56.40830362996748, 78.71514443428286, 72.77485601363644, 64.70991772990074, 54.17480799459643, 57.625454318138864, 43.78796777417583, 34.36058636634581, 32.21652273208865, 16.563165110926477, 12.294362379658608, 3.711702366990428, 0.4248271023313846, 0.40990560946445315, 0.23381087718711746, 1.052873980614447, 1.6889143735170367, 0.9300189116789449, 1.135887513237615, 1.8560101620612608, 1.1883544849772607, 1.1419918243923495, 0.998386130217583, 0.6713273832874914, 0.17990313921003573, 0.5732865763768074, 0.27642388978312094, 1.3168072051578954, 2.278411186510517, 1.0937156600336875, 1.1169123120846287, 4.412966505173714, 9.357193535374059, 26.01428274185427, 48.93573737913563, 56.36783261452952, 70.55119376028739, 80.45507646376088, 80.15466213226318, 83.24297951113793, 76.06707388354887, 73.32879666359194, 68.80264036117062, 68.88489246368408, 63.94503201207807, 56.265274401633974, 56.11805215958626, 47.049677448887984, 41.42603412751229, 37.1121015856343, 36.54855505112679, 30.300062471820464, 25.973637180943644, 26.861850061724265, 25.690638173011045, 25.813265192893248, 25.863497026505012, 23.238719471039314, 20.951769774959935, 20.61292798288407, 17.06686608252987, 16.965172752257317, 20.895124866116433, 20.448968987311087, 29.940641964635542, 35.57501492961761, 22.446902759613533, 13.864475392526197, 3.731317649925909, 2.3554553620276915, 0.9932416965884547, 0.27575868031670975, 0.24920302383120985, 0.12408897611162356, 0.10949366050021303, 0.05003736602262624, 0.5620309061581089, 0.8636258097906268, 0.6697607641258548, 0.22617670376935314, 0.12392939999699594, 0.10130418058965476, 0.04334474147687997, 0.05078419066605069, 0.14299591883055626, 0.11523217233198306, 0.3309422304793712, 0.3360009848350479, 0.47027787313826624, 0.2787807746039283, 0.07308326346138794, 0.08099121372065238, 0.03695324694197025, 0.09637645025166774, 0.09500078616603728, 0.07564188221529608, 0.0069829455347761756, 0.09145310959748684, 0.03804822407302357, 0.1587352105566571, 0.027747746752274614, 0.15598628790147845, 0.11164926337979494, 0.059285809270917415, 0.08442573144190735, 0.032403669094726924, 0.18705179674490807, 0.27885986552123104, 0.1631539903821484, 0.37259106013563376, 0.13041624949584085, 0.25468962297083875, 0.30439526143093265, 0.30939484315533794, 0.3760659123861021, 0.27622669875141115, 0.142288176162589, 0.2083648530946624, 0.14217439678407487, 0.26806237716828624, 0.39829095044443685, 0.4466517521969734, 0.6011396334055932, 0.5599496597724577, 0.5806304177930278, 0.45267139531431666, 0.27541669866731094, 0.14674970369425513, 0.10593710497262017, 0.10144838898052132, 0.1456435186968696, 0.2024915940578907, 0.31407812249756634, 0.23747096949767685, 0.22749736274202026, 0.20074681348858342, 0.18057662242602918, 0.3811488751201861, 0.1554589742614377, 0.20311494448011924, 0.18169204644378156, 0.4102334950960452, 0.5007303277811697, 0.8546995984450464, 1.3966425147748764, 2.446107955709581, 7.306316591078236, 37.00647215689383, 74.85919567846483, 74.8683818694084, 82.61321160101122, 89.03047592409196, 105.38708117700394, 105.93730342003607, 112.37043765283401, 107.10008221287882, 106.5171709368306, 99.59727841038858, 104.63594728900541, 90.25951923862581, 85.46454721881499, 77.10119893473964, 74.68806266784668, 74.16044896648776, 76.24857764090262, 90.54327918637185, 93.73280156043269, 98.62302441750803, 103.5762954527332, 109.91962309806578, 114.42543014403313, 116.01315067660425, 116.57178248128584, 120.90473851849957, 108.47347659449424, 92.07705143959292, 90.65916169074275, 87.02870999613117, 71.6856687299667, 68.96417140960693, 59.9299644654797, 53.38459161020095, 53.919567600373306, 58.43261141930857, 49.55130630923856, 28.07309562160123, 19.951122153189875, 10.46377064720277, 1.821251465908943, 1.2933932292845942, 0.8976113087227269, 3.7236606930532767, 5.32082163518475, 2.0027466430779426, 2.3916159377944086, 4.04960033874358, 1.2445523661951865, 1.1730062504929881, 2.686459277906726, 1.9150740701344706, 2.6485632984868945, 3.8085684853215374, 0.5781224910770694, 2.1620641264223286, 2.633877944561743, 1.63177598147623, 2.3690228404537326, 10.13494953032463, 19.97595467875081, 44.31637771667973, 60.99893585328133, 75.37948239234187, 82.7316907144362, 96.28161261158606, 93.75583371808453, 92.81215852306735, 94.92802619934083, 97.41928823532598, 95.02751319639145, 82.62599068303263, 87.87646755095452, 96.51065549542828, 93.68764723500898, 86.98190043049475, 88.64187886638027, 70.02511762803601, 65.021612798014, 60.28446828165362, 56.96891623158609, 60.08043050765992, 57.174366058841834, 62.433452529291955, 58.2442395917831, 51.7930075430101, 51.886038318757095, 50.00128061540666, 41.67580281534503, 38.46272660839943, 36.87648480938327, 41.952396592786236, 46.76887496825188, 48.033772668530865, 26.405794120603993, 14.407667767617012, 4.357036938590388, 2.2206550211675706, 0.8812006022180281, 0.3199181333184242, 0.3827135330967365, 0.5238228531614427, 0.5025106548301636, 1.0409559814199325, 1.189470276717217, 0.8909989280566093, 0.7868898467671487, 0.30784109427082923, 0.24195714973874632, 0.26224746338782773, 0.06131518384321563, 0.10881537391293435, 0.1431009801284921, 0.24473184359169778, 0.4174037716321407, 0.5010858538650698, 0.48422839552644764, 0.4363917817752208, 0.1951642541755592, 0.2504113743141774, 0.36502922073967997, 0.31563597761334916, 0.2655539601560562, 0.378954584800428, 0.15906363244979613, 0.16257300462213256, 0.12008775250926135, 0.30701638529858283, 0.1721470658817599, 0.21539216230232872, 0.11386724879905102, 0.10740278438935358, 0.2133299302189581, 0.27749065189592304], [0.11639455753949382, 0.011603505737448653, 0.1038943698269225, 0.08505056041382975, 0.08473097917533691, 0.15598447993397713, 0.03814033848503905, 0.2465701634965597, 0.3667272086585722, 0.3297136705969611, 0.12996330767148925, 0.10479633876633261, 0.16861805121504492, 0.14936601652974082, 0.2863419398425087, 0.22541617764340294, 0.11126320869211229, 0.06125595758578951, 0.23642388052277027, 0.05746516301446865, 0.11812515782132266, 0.13591643903524647, 0.12083924645858428, 0.013192609579662883, 0.09530260948644531, 0.06917718031834211, 0.006726524415200637, 0.07667146608113282, 0.10514499304155189, 0.16909584493166016, 0.21666138613175964, 0.2943128395465113, 0.2688033680521673, 0.19680674668521653, 0.08848586720564673, 0.45869667683878257, 0.38127828269235553, 0.9639590582059276, 1.9066714952068946, 1.243409730734364, 0.7917006337834943, 1.2245905663697951, 12.799755853991355, 36.45892889268937, 49.22753426336473, 68.8438880059027, 79.1470758376583, 75.89892187426167, 67.5840070170741, 66.76321967955559, 63.039733286826845, 42.89366737488778, 40.05088644642984, 38.3432198339893, 24.52242297510947, 21.87231279188587, 26.428606625526186, 19.30515681543658, 20.522656594553304, 34.26017368993452, 42.927650790060724, 53.033904260204686, 58.152252166501945, 48.083739742156006, 40.45247047178207, 54.06227911672285, 64.3517896436876, 71.34253978729248, 64.03555247091478, 74.79502570244574, 67.69169961252521, 49.644846993107954, 48.215778489266675, 58.61466823085662, 59.825421533276966, 53.3298235554849, 54.14058923721314, 64.81911259312784, 40.91370198034471, 21.339556863231046, 13.201549726147807, 7.133279269741428, 2.444395841129365, 1.0113798394318552, 0.34951863690249385, 0.6051807165626557, 2.6164211909617148, 2.0931497985316865, 0.7802396520010887, 2.409727482065078, 1.1034172749327076, 0.4044391124719574, 0.16725256077704892, 1.1783057403179908, 1.453882765866095, 1.4599558206335193, 2.4689439948528045, 2.843062113369665, 2.7194081679467232, 4.564269973385719, 4.731127600516043, 12.940834683756675, 18.934979208054084, 42.13781487557196, 54.029268449352635, 66.76010531763878, 81.73682074392997, 80.58523639555901, 76.01358844387916, 75.7622351184968, 63.125021303853686, 49.68471788590955, 49.08124946778821, 45.86532169772733, 52.81462807809153, 45.698569974591656, 47.36199225148847, 47.76416855473673, 43.045529780849336, 32.513844274705455, 20.338011018691525, 19.929553039612312, 21.912913245539514, 14.212655367389804, 9.331790304953053, 10.629603555125575, 9.25488341239191, 4.725956936036387, 2.2519709794752063, 2.7202355429049465, 1.1615132155918306, 3.8037751038228316, 5.879888332659199, 4.2006726322635535, 7.1551258910086855, 1.2122328939937776, 1.5327285350330415, 1.2373201284677753, 0.5286147024843001, 1.6978418106032958, 0.6349538963648581, 0.3308746921679666, 0.13298069817885277, 0.3879008370061075, 0.5097995524204547, 0.634599534734603, 0.1973664811662128, 0.6704814996450179, 0.3392421802686107, 0.3674845018934819, 0.10865158431472317, 0.15306704857897374, 0.071827354240081, 0.2195756458827565, 0.0670892306633534, 0.29485991825499847, 0.6361477064990229, 0.15574823373988753, 0.3929109294568339, 0.5623817744274293, 0.4253827305811067, 0.12929998278137178, 0.06013338213726398, 0.0928606506016466, 0.08302999585266076, 0.05607361026528863, 0.07793763321974585, 0.03197268143506541, 0.050302191126731136, 0.05189765732915652, 0.05772719955852917, 0.199123595751101, 0.0663687402923261, 0.056193564312472466, 0.11110379345594876, 0.28808607689795956, 0.055620986367425615, 0.1017136239416657, 0.10569113712277144, 0.1616597818511148, 0.07425213743361735, 0.25678654351542074, 0.33478042291056725, 0.23955414642489728, 0.33159726629814795, 0.04999930677454799, 0.20111263579418584, 0.03288198375113068, 0.15250253370932995, 0.1687241237490408, 0.1698103598168781, 0.30223189041979853, 0.4481889842258346, 0.3648547059105289, 0.3137694809946322, 0.12072994103354794, 0.09083505284281508, 0.041603427455430074, 0.0733441623648809, 0.06060056553612794, 0.13743310926421998, 0.018896717360363375, 0.11293158731273106, 0.04588224301715532, 0.19263219568998585, 0.23659582129649578, 0.2242149211346142, 0.28339026435729, 0.15777671198931434, 0.10830348162280937, 0.052729111705576225, 0.1676776170009567, 0.15782598676460405, 0.21004247839652726, 0.899954557178482, 1.1326536416046082, 2.3422078019188297, 6.641384142060434, 27.313199158637758, 53.044639787366314, 68.00607758183634, 82.92229437058973, 93.00307596883466, 84.74472953427224, 78.59074254189768, 75.87445412912678, 67.71682631584906, 46.7322047295109, 38.39051969589726, 34.426176240367276, 30.606681992930753, 28.060873516144294, 31.067913501493393, 29.39350662692901, 34.179451311788256, 37.96629967228059, 42.234705263568515, 50.34847705594955, 63.659491308273815, 71.24507673325078, 74.27781412678381, 82.2733303808397, 87.82942264310776, 84.49914993778353, 72.4774383729504, 66.55553017893146, 64.32012434928649, 59.09477418468845, 61.52474134199081, 69.96870610021776, 74.30686320027998, 64.86518083080169, 72.99936463755947, 76.01708719807287, 61.76789691371303, 33.41987648317891, 20.466470603019964, 10.462639043408057, 2.465573698282242, 0.8652062798219343, 1.6252183914184573, 3.2368416026715314, 2.7392563416111857, 1.805858737038028, 1.5312357054602717, 2.381131197175672, 0.13434819576721038, 0.3832728385684952, 0.24482780376509314, 1.1095638741408627, 0.6955775594519031, 1.4648301010170293, 2.2368294048693875, 1.7414950939916796, 2.441950978771333, 4.495862856987984, 2.494038828919011, 6.353515511558903, 20.97900082988124, 46.465467868312714, 61.527651740658676, 74.07090125545379, 83.91494427957844, 93.32351007769185, 91.33013017715948, 87.00591318068966, 90.5976353922198, 81.77470299505418, 80.62419337611045, 68.89815791960686, 67.24778929064351, 58.425719814915816, 60.48733326696581, 67.0510196685791, 67.77157475871425, 54.71652653909499, 39.05588703770792, 33.113704112268266, 26.24284709653547, 20.884554078502042, 19.197930982035977, 14.360975873085762, 15.502520915000671, 13.103677765015634, 10.425927619780264, 7.203743178998271, 6.870981060689496, 7.912977818519839, 11.833580963073238, 12.039854488065167, 12.448478187284163, 6.559944950765179, 3.346796915415795, 1.3296924363220892, 1.014152587421479, 1.6483363509178164, 1.0685627258593038, 0.904073903877889, 0.5620040624372421, 0.38759657752610027, 0.4318877363637571, 0.12522285518747184, 0.8834361693551465, 1.174285310891367, 0.9829464554786683, 0.6161784909425244, 0.1657747924928704, 0.20338834593853644, 0.4465624263450023, 0.4452153373389475, 0.5569370343319832, 0.5974231263802898, 0.24662493878314573, 0.2726997831656087, 0.5978301948597354, 0.8002876213962032, 0.35296391815908496, 0.07268492838427906, 0.054607635904704376, 0.0724428216175687, 0.1143561814340853, 0.04405519226565958, 0.08942669212457635, 0.0663234951395181, 0.053153221810897516, 0.04904489528628127, 0.16672774458364134, 0.28716502470835564, 0.13546801712964812, 0.1299820002168417, 0.1858404431972773, 0.16166722822573878, 0.340706879092801, 0.2490720074743994, 0.4416844074524218, 0.17802985505230967, 0.18962681744127505, 0.38064010080791294, 0.5123969582059692, 0.6651546758028769, 0.49931842773672075, 0.33036934992959427, 0.26949578896164894, 0.27670593271332405, 0.2345993808440624, 0.11341897245015829, 0.3871587429556155, 0.34584889188408857, 0.6791357191339616, 0.709027121624639, 0.6511810482028992, 0.3047235760717623, 0.1811971230011794, 0.17942945172469463, 0.22282793426946287, 0.17546284763563066, 0.2435498771768424, 0.1802636755089606, 0.19770372839223957, 0.162535282452741, 0.19006269082667368, 0.29401526035320374, 0.30493480183424493, 0.5275291865391116, 0.3138408191021412, 0.2068924474259538, 0.2967487846411044, 0.43789763484270344, 0.3673064017728452, 0.9078926376758084, 2.4204845822626546, 1.7918617590781183, 1.5283868389744915, 3.51126630940745, 16.870882895685014, 47.58597527780841, 66.57493806654408, 87.79787109744164, 98.52032892165646, 95.54452080880442, 96.48370881234446, 101.98028302961781, 105.25590927370133, 88.4598965798655, 74.43328119093373, 76.20467847393405, 62.4753002966604, 61.040469831035985, 66.78912301217356, 69.13550838347405, 77.69461431810933, 83.84663228065737, 89.55095091173726, 99.72535164125505, 113.43409815142232, 124.25090466776203, 126.74950938070975, 130.3195801088887, 125.04201535255679, 121.12115137038694, 102.84190224063013, 99.71792267214869, 90.42840080876505, 71.9396343538838, 68.24007834157636, 82.1858536812567, 81.77964518147131, 78.85097611335017, 92.65666007995607, 97.30813610938289, 69.33993447211482, 49.57831575024513, 34.88909044573384, 17.77886256094902, 4.2007393125564825, 1.6437758601480916, 1.460091264978532, 9.739522645550391, 3.819473654993119, 2.7363697223124968, 4.132783268728565, 5.170690465357996, 0.8989523303124213, 0.2718342876722736, 0.358034010616041, 3.894271047845964, 3.1179405893048937, 2.7039432429498245, 4.341258714275976, 2.0366338376075994, 3.140888170849893, 8.13050070116597, 15.355857610702516, 29.778049915067612, 38.32145852427329, 71.05765804167717, 82.07690592735045, 87.74141250118133, 95.56814132198211, 92.66776823228406, 95.9442573978055, 99.02178825870638, 110.30784360824093, 97.22796286306074, 99.02410245710804, 89.52753436180853, 85.05837794273131, 72.92825991107573, 80.32310439694314, 89.17351691953598, 91.94726021059098, 76.74120380032447, 61.70496640666839, 58.67534337505218, 52.535355321822635, 40.52094721025036, 31.505571565320416, 24.934126715506277, 25.917188390608757, 22.279676429687008, 17.378008096448838, 18.677987475549024, 19.52257771645823, 21.658445558240338, 26.302584794259843, 21.45348798844122, 18.37537269438467, 10.111671243944476, 4.772604213606927, 2.075130184811931, 1.5585035326019412, 1.823864009591841, 0.6984078559663989, 0.6074871927980454, 0.49641048055021997, 0.614866090397681, 0.7080950071254085, 1.1224459183792914, 2.110765898419965, 1.7824157111106382, 1.3947686024250523, 1.0101867034550638, 0.2808676593967023, 0.26159166148112667, 0.39497164468611445, 0.40166945947754773, 0.3972733405328566, 0.4704491397546184, 0.4804654022858989, 0.5398684115179124, 0.9536324994217966, 0.867950345479673, 0.6828730637508055, 0.293176026353913, 0.2714103959020107, 0.3066272739200823, 0.2483566192489478, 0.1505458532201667, 0.2275888796054548, 0.09791976501864773, 0.14198000963416793, 0.12465709159451148, 0.27550620838038387, 0.4016941887957435, 0.23442190891552359, 0.17870405839095194, 0.24792518917351003, 0.5518235506549959], [0.057130079986827995, 0.037724590229411284, 0.08480523607783741, 0.06629156459483408, 0.13783993259552987, 0.1482523545142143, 0.3588088625861753, 0.13903896744933822, 0.1658147056737254, 0.03489671072231666, 0.025202272151927316, 0.12490225505203971, 0.23178059097018935, 0.10180453559564007, 0.1255598342827251, 0.22130521194588756, 0.24350391190138557, 0.11286049435335783, 0.24880032205293257, 0.165930109158639, 0.1076072302737063, 0.14618498964175103, 0.13478806813157376, 0.12098920816976218, 0.0751689684787585, 0.09562897826394728, 0.09319238965549777, 0.03111278987489641, 0.09886927737463867, 0.21101488912057495, 0.22833203085728232, 0.09759426192050019, 0.3063006140291691, 0.3649430511699569, 0.08260370622719489, 0.15021491855863603, 0.3809621641712804, 0.45073239613444577, 0.49124566898230587, 0.20911290730920531, 0.8077605945929405, 0.45786960831572937, 0.5271294112167051, 3.244424769955297, 11.002070846096164, 36.79065550527265, 43.63941192626954, 44.84966316530782, 68.05500522736581, 58.690397431773526, 50.730351171185895, 47.00618228604717, 31.654631437793856, 19.599087469039425, 12.63792964719957, 13.125103712081911, 8.84722363564276, 4.906090805607458, 10.153497438276968, 22.700946830934097, 29.150515794754032, 30.006977088989753, 31.033755540847782, 18.506905455743116, 36.277111345721835, 43.0629058807127, 46.31921445169757, 59.445865538812455, 56.511583558974735, 45.53946687329201, 35.83919048309326, 35.084765726520175, 41.300632030733176, 52.863022281277566, 61.91560160729193, 70.80185674851941, 80.55039005894815, 75.07703627309492, 46.962549840250325, 23.08191683984572, 7.751783113325796, 3.4670374181962784, 3.9914592908274744, 0.7186647528602231, 0.7534347871138204, 6.30235799858647, 5.740960432637123, 0.7171182358457197, 0.08261306016075035, 0.6299438652011656, 1.5547563207726327, 2.0884382965103274, 0.8190557336614979, 0.33515169976219056, 1.1464596491667534, 0.29756794713677903, 1.4041279905265378, 2.306685837045793, 3.878855887920626, 3.3576368756832617, 4.540951973007572, 6.573509977709863, 16.952448583418324, 40.99063534890452, 65.27539014816284, 75.09326704086797, 69.29184621380222, 65.14257869412823, 54.875708087798095, 41.82477443448959, 42.90687007288779, 36.68265304257793, 36.40697709975704, 28.907252357852077, 28.173320024244248, 24.59330020412322, 28.53569211498384, 35.82434431199105, 29.502226883365264, 30.10496574063455, 21.89618629793967, 14.718783305537317, 7.232070536382738, 4.24496844891579, 4.072467511700046, 4.790046503466945, 5.412060378059264, 4.766923641004871, 2.667466426087964, 2.7741798998848086, 1.433646767850845, 0.6474703634458204, 1.404105559472115, 2.595012649413078, 1.2960045472268136, 0.42279053419347734, 1.1211913727944898, 0.029274897064052285, 0.37688271533096995, 0.7362522929906846, 0.8106817797787729, 0.3119364777399648, 0.3677465958941368, 0.33497602047939457, 0.34431239529963464, 0.15731230948961553, 0.24625076611916868, 0.6615834803350511, 0.22642580491881217, 0.1938866033789612, 0.1365532113179084, 0.16082709024269737, 0.0716586003921205, 0.11339710830079933, 0.5150585621595383, 0.05938273088465776, 0.22014828128439767, 0.09347640909254552, 0.38183666885860507, 0.24580212970895154, 0.445909014632625, 0.16312161550646828, 0.06726907746445748, 0.08650600489589476, 0.06706296150842983, 0.06413868898826261, 0.09354229265403363, 0.04947488128598179, 0.04131780306418096, 0.07621928268382627, 0.13583265965984714, 0.15308278402493847, 0.11032936283417287, 0.062373932676329735, 0.15833885198639286, 0.015993629086522326, 0.05358684289779875, 0.09174201667549149, 0.22355092208712335, 0.23943693497248236, 0.22969606572822218, 0.1857606934443597, 0.5431242851961045, 0.2473629572458806, 0.18299067272774636, 0.09784804386717659, 0.037266289620029355, 0.09976421362690388, 0.23193360937218513, 0.11889575034259789, 0.09862140962673772, 0.37141008963507993, 0.5366058575530206, 0.5363226501691727, 0.35054078205458583, 0.1338591712016252, 0.16783127891680888, 0.11236572412834053, 0.0929258140404859, 0.037735798095743504, 0.10895801948443537, 0.18482890070205737, 0.3254171124389095, 0.5147285927687922, 0.39222368730172036, 0.42170017657260744, 0.14938215034142618, 0.16987279598270694, 0.14268450408933625, 0.06298242482326685, 0.0858381217826278, 0.07362248210777199, 0.42554060598054244, 0.12223794680809784, 0.24430355447674953, 0.5243276744600266, 0.7559484748109695, 1.7294013235838184, 4.65410941070126, 13.289323545271351, 29.946747133808753, 61.58655005116617, 60.96736077339419, 65.91346171594435, 85.42168355757191, 79.60708356672718, 79.71152059493527, 53.423215189287745, 35.47251555227464, 32.06432300229227, 26.960062288468887, 22.439059980453987, 22.937699133350005, 20.406026878664573, 26.338852990058164, 36.40202314622941, 50.02212016813217, 70.42823530012562, 81.45798729312035, 89.5413254153344, 86.18433352439635, 85.36226749420167, 84.48911651488274, 78.9820146560669, 65.2133539415175, 57.64277158244964, 59.63501791800223, 59.12010485126127, 63.41840674800258, 72.71060759021391, 78.50259119464506, 83.65338494700771, 93.66534463820919, 91.57963214382049, 56.0216599126016, 39.990999698638916, 22.870057859728416, 8.247606004438094, 3.634693247656669, 2.4123576764137518, 1.6762219513616257, 3.8927788311435334, 6.659833010165922, 2.6136206186586812, 0.3537022430569895, 0.632446582519239, 2.2067374712036503, 1.889278970418438, 0.10968041741439413, 1.105738950352515, 0.9267751115464395, 1.0267685846455636, 4.347648255286678, 2.9208493328863576, 4.95721644932224, 11.056713384966697, 10.407171826208792, 20.014894008636475, 33.86245712157219, 59.25408909397741, 73.9119589713312, 83.07603559186383, 90.24473974781652, 86.77577987793954, 83.88434194749402, 75.37601501710954, 68.88320584450999, 71.11690936550018, 75.92333470621418, 65.41728973388672, 61.625730606817434, 50.955216730794604, 49.72556544888405, 57.40544073043331, 58.66088159622685, 56.895603210695334, 45.53914523893788, 38.95534884545111, 34.431773462603175, 18.16431191659743, 11.078400169649433, 12.928271332094747, 9.140054064412272, 4.401856881956901, 2.183270665907091, 1.815691261041549, 2.566130276649229, 5.618484914302827, 5.031204117882637, 4.2031049920666606, 1.3637661885830665, 1.292292636729056, 1.1191337219169064, 0.6692710194376208, 0.45754714658664125, 0.743601527665892, 1.0035206966342465, 1.2387972685598558, 0.9969159155603379, 0.5349842026349038, 0.40487942916731684, 0.5547455325722694, 0.7410757664230563, 1.159918036672377, 0.8742366178381829, 0.18321355834843653, 0.19766104197309864, 0.3810758209757267, 0.5042271207897894, 0.5663413458293485, 0.7871807150302396, 0.9464171769157533, 0.47280709709851976, 0.11728681248402405, 0.4635994250495588, 0.574857424343786, 0.28068401279949373, 0.1816605908736106, 0.40219876494619156, 0.2162447875185359, 0.10322542185144079, 0.08130386186343047, 0.06360813479630217, 0.1493843566746481, 0.07153981845946082, 0.21315345420472084, 0.23283808341910764, 0.2674826018271908, 0.20809433212684048, 0.0897875655021879, 0.14863052615715613, 0.10366344794390664, 0.17656828186685042, 0.13000034036174898, 0.24885259989288547, 0.3254763157136979, 0.41699020672709713, 0.26374136548369165, 0.5993669059488081, 0.21247152869980182, 0.2727469435382274, 0.18768349752551128, 0.15837257517681969, 0.2355643145499691, 0.2684673312450609, 0.1964135597189588, 0.2943308272909734, 0.6796034617770104, 0.9442851848659978, 0.9309028545694967, 0.9068658347091368, 0.6528438880078254, 0.2824561886729733, 0.23749056602677993, 0.1481409959735409, 0.1670284647374384, 0.251288085334724, 0.19057178689587503, 0.31360654941489624, 0.45472625763185565, 0.498030940371175, 0.4211186851945616, 0.2912076706847837, 0.25747571621210347, 0.3713231233339156, 0.315268776349483, 0.15097662445998963, 0.2008061393374397, 0.551920322881591, 0.42047998237033046, 0.3946322983791752, 0.6522155120488137, 0.7445861651532112, 1.0426580449265819, 2.211587481921719, 6.372817985473141, 19.787975088242565, 53.980470242038855, 57.49618868674002, 63.77664466058055, 100.42805994710615, 101.13040739490141, 102.50257799702307, 80.80010383359848, 57.192157929943455, 44.76301800820136, 39.31352400010632, 36.009244841914025, 38.01903593924738, 38.78379614122453, 50.66329040834981, 60.0756020699778, 82.6895252350838, 104.28363215538764, 116.6648603254749, 127.60702579252182, 114.42501437279486, 93.75590432074763, 93.29884621404833, 101.95532891058154, 93.74429410503757, 75.75857162475586, 69.03341693262901, 73.57432919163858, 83.6115332572691, 84.30662432024556, 103.48364122452276, 113.66819304804649, 111.46420540348177, 100.22099018096925, 66.67327188676404, 51.716615461534076, 36.72099028864215, 13.57117820170618, 8.798099871604673, 3.80049109939606, 1.9761706239754155, 11.836623741734414, 10.52260619978751, 2.967038428591144, 0.2133353387997035, 1.1347559094429016, 2.478803117429057, 3.1181695576637023, 1.8736887747241606, 1.7015478375457949, 3.4434166598704556, 3.3483420841155516, 14.677660196058213, 1.7446773619421068, 3.340589519469969, 11.812173647265281, 29.355345887522546, 41.18374147722798, 60.50605473979827, 87.73768624951764, 98.58449889767556, 100.63476101044687, 89.2941298023347, 85.14884348838561, 81.44390598420175, 73.2384801680042, 68.17456691495835, 80.38887469999253, 90.99832119480257, 76.5104821420485, 72.86546276461694, 61.5460241225458, 62.78738367942072, 66.53422386415544, 67.81044544712191, 67.3709281798332, 62.49769310797415, 58.461770319169574, 46.80269364387759, 31.803842321518932, 22.111136105752763, 18.89417871352165, 11.000534257581158, 7.454502755595793, 5.285796830731054, 4.100250885371239, 5.283795441350629, 7.660309028240943, 7.827329433733418, 6.83704863632879, 2.241921621945597, 1.512259891436946, 1.4391616203131214, 0.9291243048444872, 0.457315297737237, 0.6578461970052412, 0.83256462168309, 0.9771030432274266, 0.8238873582693839, 0.5446832434784982, 0.9115233428535924, 1.3720110106852748, 1.284184852434743, 1.4690430943043002, 1.3750890906779998, 0.5875123388344242, 0.5825358929653323, 0.4426500459592189, 0.49691465833494747, 0.6550967380885155, 1.167500836233939, 1.0319162664874908, 0.7252042019559491, 0.5296359283308829, 0.7744650650889643, 0.7105759675464323, 0.6805933699492486, 0.49466612899015033, 0.4530544086329399, 0.441978064275557, 0.29597166505071426, 0.31057814256318156, 0.20804482752517348, 0.2554062369369692, 0.16510615095255837, 0.20315088932552647, 0.413459767136843, 0.3264179603467065, 0.3106059975201084, 0.2031043265014887, 0.3494930495658229, 0.3521164716972459], [0.0381748890504241, 0.03959596299776628, 0.14804198677020688, 0.17767353223696833, 0.12777385902741265, 0.1364187169219217, 0.15515633888782995, 0.1470168538752102, 0.03299379811411904, 0.15718259548227634, 0.0688503212445686, 0.08698324702920453, 0.19717364151391292, 0.1344936298987558, 0.06024843322173242, 0.1302907796156022, 0.2364252748027925, 0.17574125930907267, 0.20299108338452157, 0.23788948333071125, 0.17061502792902533, 0.13656333900026738, 0.0910723562382402, 0.13235103519212815, 0.12749992130744842, 0.1923117717547763, 0.22128224462991763, 0.02268939842319777, 0.1878975884568307, 0.3150112175893399, 0.2927104287570523, 0.07065755330146321, 0.08570306048157715, 0.10381310321991483, 0.12851295767412071, 0.14741636872772249, 0.21121519046925732, 0.19628117972564316, 0.15204832017902406, 0.19283724678379877, 0.5576233878251046, 0.3874349023305601, 0.22589697442468137, 0.041297337025283806, 0.1567507976846349, 4.394557841362492, 9.575438134131893, 16.92352894813784, 27.791155653615153, 37.057411978321696, 51.74935548536239, 41.13256631358978, 24.10866979629763, 10.331999601856356, 11.957171905425287, 7.388982503644883, 1.0492264215023288, 2.562472421315409, 11.104242705529737, 19.57780861085461, 21.332741745056648, 13.950895993940293, 10.14179994983058, 17.851952006739957, 28.078820320867724, 24.149946858805997, 22.138596619329146, 27.977152486001295, 24.623543639336866, 19.800097173260106, 12.297757191042747, 16.65515449739272, 29.581103786345455, 48.270138617484804, 47.567030229876124, 64.66821509022867, 53.27196859544324, 49.67993651666949, 50.643329466542895, 40.867727879555, 10.583829495214648, 8.16973420881456, 4.707333522458231, 1.9259653889363813, 2.2901182357342016, 3.2660686537142727, 5.5622631311416635, 0.7985121973099247, 0.30921533343292057, 0.7510150524397051, 1.114119216799736, 1.0294705461109839, 0.9207670823220284, 0.4869731046980428, 0.46672429769269885, 1.9659469661212738, 2.0110286051227204, 1.5275199951664096, 3.544385332253672, 6.685052869781372, 8.823944368670064, 20.117920944767615, 37.287913983868016, 61.673814942759854, 73.61776551892682, 75.83519904844223, 88.7343526655628, 72.12449566010507, 46.66639520275978, 17.74378284331291, 12.57715448256462, 13.647187852090406, 12.642744356586087, 12.182655238336134, 10.583626512558231, 13.530327696954052, 11.996105351755697, 15.606855961584277, 19.46723895688211, 26.247187199131137, 19.298420144665627, 11.19048680028608, 2.94811005073209, 2.267559459132533, 1.7230886365136795, 2.894602547730169, 0.70575108451228, 0.5914729521159203, 0.1890843965473675, 0.974387537327505, 0.5378710670817284, 0.986236711182902, 0.7138330056782692, 0.11453440412878992, 0.10532104004655155, 0.20567704893408284, 0.38856387078281374, 0.1814523528540327, 0.20141052142266305, 0.33245047374117764, 0.3784119800454186, 0.24350875357706703, 0.2990384375856769, 0.10768369350942875, 0.10055500022586315, 0.1998516244273032, 0.15114235992152847, 0.17919358857456716, 0.07478405526208301, 0.07110076580917643, 0.1256812668796028, 0.161603627606265, 0.23384519792612524, 0.3390567563474179, 0.2671909674761757, 0.3077062321526389, 0.26035853571468787, 0.13413280248641968, 0.01525122955847051, 0.06965267577118452, 0.2126385205455365, 0.40201992938114756, 0.1718537614590699, 0.16814326056309287, 0.09686444059855516, 0.1604386376998117, 0.10344335854414011, 0.13367478916000936, 0.018808473607585318, 0.05861283167295399, 0.11411772890677375, 0.07699092474555777, 0.009758269973850299, 0.051903031435945345, 0.04754864513092945, 0.10512666821840311, 0.030999203933583155, 0.05944422476233975, 0.2651172287521824, 0.2845011531345306, 0.25814585928474704, 0.3454426201360841, 0.1673386230944626, 0.11654353865812864, 0.031857494369990406, 0.06541027236850032, 0.008064085681502136, 0.07043954766085071, 0.18086788905484064, 0.17833195416437042, 0.15635797844058083, 0.2663224995616944, 0.3497852661436604, 0.4752130115464811, 0.2965007866582563, 0.2924789169863347, 0.05050538445732767, 0.1616160995176723, 0.07377918539268356, 0.007272082439158113, 0.04695171708120935, 0.36489726975560194, 0.4582236022237809, 0.6957631978777148, 0.7143723928639967, 0.43988983116803637, 0.36715398091943036, 0.21568169757243127, 0.15625553716334606, 0.15137374911817814, 0.026424823989791256, 0.2700140321206662, 0.3087790310382843, 0.0155502375057568, 0.1667379182312758, 0.006714014199397137, 0.40949437346669937, 0.6980814412236215, 1.022472057131029, 0.6807775374862456, 2.223099638377467, 11.53253120760764, 23.109532287043912, 35.99879172540481, 57.28626343511767, 73.83115030104115, 75.24041868025257, 51.21218296789354, 36.75682114016625, 35.10801753690166, 28.24567206444279, 23.341350247783048, 22.69449845437081, 25.17392473836099, 30.907406191672052, 48.91794943040418, 69.88751303765082, 77.29400696293001, 73.81099716309579, 66.29347662771902, 61.74286826964348, 57.87821185204291, 49.44106025080527, 46.83601025612124, 43.81924475392988, 41.890623184942434, 42.65028430569557, 50.95049419710713, 61.263421274000606, 75.2716407468242, 83.10357063047348, 93.81374359130861, 87.56099131799515, 74.08477075638311, 57.20240316083355, 40.46274315926337, 23.9986845754808, 6.607947897526526, 3.035283011774863, 2.1009053049548982, 2.83923240919267, 5.264756256534207, 6.51039953193357, 1.0787020527547406, 1.0296697289712968, 2.7741303799613832, 3.013395941065204, 1.3017242209565256, 0.456842560200922, 1.4860995209986165, 1.0587375562998558, 0.5009630040055322, 3.4262636448106463, 1.5439424687816252, 2.156449253520658, 3.025769057773775, 10.26696180143664, 22.506057985367317, 38.793233363859116, 70.8405391631588, 84.2674712211855, 86.74782122335127, 86.74553055917063, 81.82760792393839, 75.83792901808216, 54.78952577037197, 46.73564464815202, 48.32072542559717, 54.016681563469675, 46.56302898160873, 38.49818091238699, 31.708681698768373, 36.498737027568204, 38.671930143910075, 37.884569245000044, 48.536467552185066, 37.4804788251077, 33.042054176330566, 17.442556581189557, 5.314177630409118, 3.996298269879434, 2.4249840311465727, 0.49580649683071726, 0.5608666976613383, 0.5182911467648322, 0.41897204554369377, 1.291763361903929, 2.5806356918427253, 1.3197582984162917, 0.16133506782352924, 0.102809167977783, 0.3685588329549759, 0.5337059389679663, 0.474632868483182, 0.39437339130428534, 0.3198630975619439, 0.14378711911699465, 0.7290923739633253, 0.6254000445046733, 0.43353274164180605, 0.23897889100255507, 0.352876584135717, 0.27135085554853566, 0.2967976304071565, 0.11219548406980692, 0.08891133711703363, 0.04270225800874253, 0.16039420460020343, 0.1372558978055754, 0.35528697253715613, 0.6480621510455686, 0.581687557841501, 0.22801568250982995, 0.08613344101655869, 0.20268018958309006, 0.37377855770530244, 0.32498935958550823, 0.3796030935500899, 0.37045309260006876, 0.2830290998662672, 0.21674044640554538, 0.09435655218699286, 0.16611128895273133, 0.07682594771106398, 0.050777870440675374, 0.09242296924874668, 0.16325427129143671, 0.10496899966270694, 0.11206364799891749, 0.10862003681400131, 0.006526035853781768, 0.07574569478991532, 0.18981109223058149, 0.13241117309418418, 0.4708512746278317, 0.34715136392943324, 0.2826923276147535, 0.5077424224826598, 0.4026370898129479, 0.30738839759461345, 0.14026162845473136, 0.1386020215408456, 0.176936034714022, 0.22569748512919874, 0.22648099389287735, 0.4926966395108931, 0.19482211930857551, 0.39528644553595976, 0.5488199956955448, 0.8234168577098078, 0.7901984272945313, 0.5234876130857776, 0.39034291080409483, 0.339744427511769, 0.23545301729632964, 0.11972434338062041, 0.16162788194994773, 0.30780937823076404, 0.36163879137846733, 0.6285682777243277, 0.6699664434117656, 0.6836216848704123, 0.420197326569788, 0.3874728083610535, 0.27535256178629014, 0.29069993825208756, 0.14503599565115669, 0.31418761178370447, 0.37254932366551896, 0.2511373192312256, 0.21554470572981144, 0.18876876832256395, 0.28392517758953956, 0.5667173417825853, 0.7119069380625602, 0.35144547060612713, 0.9491864928314764, 7.141048504460243, 15.524722510768523, 34.15988260699857, 50.27133972414079, 69.8991781665433, 87.5469570775186, 65.65865670481037, 54.34143027951641, 51.26460936761672, 36.547441097997854, 28.259937724759503, 38.893281259844386, 40.274998910965465, 49.60123415916197, 72.20477088805168, 97.09874430010396, 109.14670436613022, 106.2197611408849, 85.35188105798538, 72.07250856584119, 61.9966926882344, 57.09319653049592, 56.029834132040705, 56.747200335225756, 57.19150681649485, 57.789880075762355, 69.3038643560102, 80.88128905142509, 99.2117408014113, 93.54000922172301, 99.75373391182193, 75.77406498693651, 63.28970593790855, 64.13185842575567, 64.14566124639204, 44.882077632411836, 19.16132350121775, 9.432677588155194, 5.3445460911720035, 6.602966487407685, 7.26030767925324, 15.700219158203373, 2.5153679424716584, 1.01774376246237, 2.3695999191653345, 3.683077890065409, 3.1565943216123893, 5.057857603796068, 3.156055486009967, 2.6754141286496194, 3.1450851069342707, 11.385428597850185, 2.3436762392520905, 4.315444615579421, 9.387318318889989, 15.37362692817565, 36.176682979829856, 66.22576867380451, 97.23325806279337, 109.93222959579961, 105.78252669303649, 110.40199618185721, 98.18426024529242, 86.5988652936874, 67.25333552206716, 47.655424764079434, 49.62310137287263, 50.35258377751997, 54.880222735866425, 47.27011465257215, 51.14573801717451, 47.91947087933941, 39.92969305284562, 40.2377873851407, 51.441265075437485, 38.64367731155888, 31.64324283599854, 19.348385257105676, 7.802196846854303, 5.312527293159116, 3.2817797074394846, 0.537273089491552, 0.8949917170309252, 0.7590233678779295, 1.8735377634725265, 1.8986627507594325, 3.8545516565922773, 1.3172537424872, 0.2508655418792079, 0.16535076282678113, 0.4640954823022889, 0.5565387298983913, 0.539765571874957, 0.5761545644171777, 0.48183339017052806, 0.5670238382393314, 0.7046833418069348, 0.6232918318240874, 0.42874410988823064, 0.6030938317698817, 0.5643023262100836, 0.3200098800082361, 0.2769052075041879, 0.20028636400257388, 0.14108616888763445, 0.2708333478339257, 0.4476897400473395, 0.5099249150483839, 0.5494605064872773, 0.9935711143958954, 0.7948334430975299, 0.482244472950697, 0.2068434790858338, 0.3904269659711469, 0.3593524172902108, 0.6024647203664626, 0.6107336895600443, 0.48755477993719043, 0.6063139138202513, 0.3903419914985857, 0.25695221768992565, 0.2588186989868841, 0.22404298036088868, 0.1608231219072496, 0.08877845150568793, 0.22930010552367858, 0.46597245900381, 0.2910400812904681, 0.2678279849069734, 0.27672710738355116, 0.33838122001578735], [0.03261335502048174, 0.036853804898959015, 0.1662771163448211, 0.1484883095948927, 0.10785529720446757, 0.09191447838900552, 0.1027842547984854, 0.0485801097426203, 0.059674985766891515, 0.009455162498559202, 0.04003526845706567, 0.06457687595919256, 0.05830646545115498, 0.14886239032831886, 0.11153519288786959, 0.05243839282963065, 0.0967957225117472, 0.19214286468923095, 0.16429304055148558, 0.16392743275050195, 0.23335306304356745, 0.14716182835400105, 0.07323950709354493, 0.05173259602499105, 0.1695121371097142, 0.12306365935552506, 0.10778818024142135, 0.06273528485889397, 0.08959010633970461, 0.026571254035638227, 0.07702045743503878, 0.07132535980593774, 0.054082294941068663, 0.03683839504036211, 0.06640545888653686, 0.08259616026114072, 0.11155203916132451, 0.04321739851166645, 0.03980928784116142, 0.010272836868440913, 0.4466248471890727, 0.05453300361912097, 0.20754883155947734, 0.07960531470035354, 0.21446754014299763, 0.0915728338182934, 0.5299291255012636, 1.9099025476363398, 7.518078002237505, 5.795239171674175, 10.524009427716656, 13.824176961375823, 12.328106530251043, 9.307743234019126, 7.759123338807014, 8.001773905369545, 6.527971750305546, 1.984226804587149, 5.206766465017873, 8.449996382959428, 3.1536763233523217, 6.693305046327653, 10.688290057643767, 11.127109143041796, 14.911560935358848, 13.046501375013783, 17.350745662566155, 21.799282181647516, 9.955138275700232, 7.322594917589619, 3.031840151356113, 12.392513809665559, 18.514355997885428, 21.482988134507213, 30.463513520456132, 31.040564775466922, 41.79400736285795, 50.67297081793509, 58.56059835803125, 56.585481013021166, 26.463654964200913, 8.544713777880515, 2.1435828987629186, 3.467035702159328, 1.273678171057855, 1.9983403504856172, 4.61206748600929, 5.937948236542364, 0.9644955649010598, 1.417461352482919, 0.18504098448301518, 0.6614080155568739, 1.3387115588111262, 3.237754044032866, 6.166176738277559, 7.784851145359778, 3.81678119301796, 4.056071268935358, 9.15681533275112, 13.47500462685862, 19.578597007259248, 33.6809729760693, 51.9772961831862, 62.95926978511196, 74.53288585908952, 69.75636466856926, 62.50028187228788, 59.413937445609804, 39.93463131689256, 24.081940804758382, 13.389593055171352, 10.093371425905536, 6.837109923362733, 1.812656817416991, 4.199589077503451, 12.408089541619825, 6.596588713507499, 4.993410120087286, 9.406470271848864, 8.514063396761495, 3.8698842015958603, 2.5063965012950282, 1.743215421034444, 0.9147635883381291, 0.8438210886332297, 0.5170025255891585, 0.3373308828280818, 0.4890433194175844, 0.21200956235970222, 0.12842792957540483, 0.14216675122659053, 0.12135480830986654, 0.03639337456514759, 0.20382719174508127, 0.10709414288641946, 0.12482346290902746, 0.0774538410346835, 0.08193142576924256, 0.08124844306298802, 0.03048874997353602, 0.020388989604168364, 0.1416489983638448, 0.06675629651234036, 0.08453597149421131, 0.07116435110689172, 0.0561887379585495, 0.04995741325640871, 0.07180385832344333, 0.018850183264622768, 0.12703836865482793, 0.19464012746128345, 0.12183826341624222, 0.10016514574207606, 0.07200460400312178, 0.11927217530507235, 0.08270296057866466, 0.26131142651842487, 0.03835366715887382, 0.10808900764752781, 0.06529401086511151, 0.12287907047016967, 0.06110313836665404, 0.1276655724993156, 0.12100791603687311, 0.04242000440436025, 0.16336143167028505, 0.09935731368680155, 0.02945040589228513, 0.12556705083097183, 0.08766737120646624, 0.10728055506103462, 0.018934640627835068, 0.04815820597052094, 0.034596879230511766, 0.03087947588233698, 0.14653018886043181, 0.11292955717973172, 0.1341062652007226, 0.3418398312022609, 0.2665485261428741, 0.27130648373596133, 0.16753209093886037, 0.08154155596369698, 0.017193089119128643, 0.03759443572151565, 0.09402035450142238, 0.034849665262886596, 0.035352839472433256, 0.13383888519339024, 0.10056908858279068, 0.09215385022182619, 0.026918431676383463, 0.18704850256683367, 0.22914521786714756, 0.19584270164130196, 0.3984370893768726, 0.33022042243711414, 0.20269489847123626, 0.11863312008039606, 0.1801827613023981, 0.1761174850886868, 0.20224491374627238, 0.20968344362993396, 0.17417614167976767, 0.1932661794126034, 0.10307558271433077, 0.17287952254616445, 0.15807709506442472, 0.0981461440002726, 0.12048556664658171, 0.02132377583503483, 0.1018041295690402, 0.0540988922359482, 0.06693828835963242, 0.15669271289821596, 0.06654722345692497, 0.3935351991845716, 0.2246626382393222, 0.33877149584793276, 0.2037945870430239, 0.320938378572464, 0.8893301434093906, 2.3824108704443905, 8.364544606977894, 16.97018358015245, 17.511096077580607, 22.2987626829455, 23.4889490373673, 28.44502848963584, 19.566602399272305, 20.57495355606079, 15.679015805644376, 10.251016386093633, 18.184055166859782, 21.839768886566166, 27.366774812821422, 39.94983834605063, 43.81705214900356, 38.49974201571557, 33.7686889402328, 31.22284712329988, 29.20091432909812, 26.161461837830085, 27.249803850727698, 27.760869072329616, 27.722253337983165, 32.35045794517764, 42.6447263071614, 52.231834473148474, 63.20868153725902, 66.88825699590868, 70.18153390576764, 65.15798576416509, 54.08400904747748, 55.67078428883707, 52.474134968173125, 24.762230803889615, 7.249681978456437, 3.006591119112507, 2.318794438915868, 3.7209272913394438, 4.762642864258059, 8.302106357389881, 1.4749773952268785, 3.6214996201376763, 0.8107751812185011, 0.5936117470264435, 1.0218383492000642, 1.4159620264845512, 2.563482676782916, 6.527849176237661, 8.286945416081338, 2.0925501661915935, 4.824610429425394, 8.894027317723921, 10.984966370367236, 15.009918289799845, 31.229017011580932, 52.656482035113925, 73.79341709998347, 90.8408929455665, 83.69427173368393, 87.21324966799828, 82.71122378687706, 68.4882467023788, 47.5490814639676, 31.61109901243641, 33.76775933850196, 28.857277439486598, 21.198273089624223, 22.589967289278587, 22.44193703897538, 20.389878480665146, 19.305309787873302, 23.602672276958344, 22.512539702077067, 16.38541800360526, 11.574278954536686, 7.685079776471661, 3.541549948915359, 2.6510949432849884, 0.7579900071986261, 0.20249783001359434, 0.26198855631293794, 0.1557607209730533, 0.3172930564370848, 0.2866515312944689, 0.4367680228765934, 0.062070389488531705, 0.06957654961414876, 0.16157318327215411, 0.20383477601553165, 0.12529128216086857, 0.051406510700021064, 0.10657037623346814, 0.11973095471940695, 0.16853038011299026, 0.34036039284640746, 0.25090760010625085, 0.18541564744326378, 0.11081868617404854, 0.11636271892536072, 0.08207909687752686, 0.08570298387278473, 0.0342204159636411, 0.02110810293215177, 0.0820410912556033, 0.19521127665235152, 0.11366867880907752, 0.4235903912734601, 0.21408264224808063, 0.3522883818274544, 0.20437800896263894, 0.0982076378779546, 0.11644660555306943, 0.26116645203963407, 0.2509761496537155, 0.44374555169094, 0.13521067287412383, 0.1964846680000905, 0.0439896381219789, 0.11790399589846212, 0.04689599950647643, 0.03180956599422761, 0.008718038443475962, 0.10197851416324416, 0.08631242213830834, 0.027567233454676408, 0.09236993298174874, 0.20925259578131863, 0.04815970367241291, 0.0967424410966135, 0.22530203054268516, 0.27146114156611506, 0.4424276046695248, 0.2965028091303764, 0.3813493143646948, 0.26543972112478753, 0.27331939507876674, 0.12463543428889207, 0.12739081506527242, 0.18881853339412522, 0.189791894067199, 0.132203210866259, 0.2719571068882942, 0.42075077912980513, 0.3540569417659314, 0.34703059782904966, 0.5855476603873315, 0.3671854518113598, 0.43378889080016847, 0.5206704932835795, 0.38658433022999, 0.43458850273201544, 0.3063047509039602, 0.23105574921975214, 0.2323717810213566, 0.22847564169956794, 0.23731189900107924, 0.21413715706477243, 0.18902461104575666, 0.2255131184093414, 0.2456168130400681, 0.22404970661286386, 0.23299465646907208, 0.22559081504662193, 0.33551565281325774, 0.15067451002617038, 0.1851707291338713, 0.2279669593178457, 0.20778711554744553, 0.14018086746575373, 0.5775465155320784, 0.17627779664772172, 0.4618447772677868, 0.27789284805617026, 0.3444982482300651, 0.5155030770167228, 1.2156453560436926, 3.883923099886987, 11.120995148535698, 10.349106038770369, 16.58533630832549, 19.598981565044774, 28.643027774749267, 23.641588072622977, 25.017237817087484, 21.357866487195416, 14.584971647108755, 26.511066613658784, 25.903342423900483, 31.31892950304093, 39.72815775102185, 46.46733883888491, 39.82213774035054, 31.5563819485326, 30.142524396219564, 30.770344849555727, 37.4189603713251, 43.451455869982325, 41.41776969355922, 46.42846030573691, 66.1918087928526, 66.61720552752095, 76.90016177392776, 74.30480787830969, 71.81964120557232, 67.26948784243676, 67.36513091671851, 65.56165649044898, 69.77214044140231, 67.45681239712623, 52.210065318692116, 26.258766035879813, 14.546470642089846, 4.1228915414502545, 6.250182630554323, 12.687584892396005, 14.81895769796064, 19.64480857695303, 9.351624750321912, 1.7162737634874161, 0.8116016981582489, 3.6630125151526545, 5.919257162078734, 7.713438512817507, 10.643011196967095, 13.471758865541029, 7.584993147080945, 6.443792293148657, 11.713013187531503, 22.42153875289425, 41.26383235377651, 61.12649133128505, 84.72601982855028, 89.35374982895391, 102.46544884097193, 95.46905440668907, 92.83095452093309, 97.67794501396918, 77.438412943194, 62.7830376932698, 58.2702527507659, 46.508770835015085, 32.26768416743125, 23.698568344116214, 22.91191739420737, 28.944469767232096, 22.210103388755552, 20.560884014252697, 18.272747801196193, 15.02135592122232, 10.440481574304643, 8.711945991362295, 7.393805057771745, 3.6885422420117164, 3.4523157823470334, 1.526665653913252, 0.4553626928358309, 0.5287711682819551, 0.19402642974690085, 0.36716881238164445, 0.39378160370453713, 0.37510707674007265, 0.13949961611820808, 0.3242099110878283, 0.3753183331460722, 0.22056590645543991, 0.16768631975977652, 0.28724960081519624, 0.15685136970733443, 0.30454921446019606, 0.2886575784894728, 0.3469140911775251, 0.22557290391095225, 0.22806861918539773, 0.23149814967426563, 0.31269162592868655, 0.16624518580013709, 0.1734160139195381, 0.19054449884401214, 0.18898229234881941, 0.25646800415650495, 0.4015710018575192, 0.2450775484284086, 0.464976943067966, 0.3305260302318681, 0.470171693351961, 0.5609851042109152, 0.3368402494778556, 0.5012208998443619, 0.4411908629680834, 0.3663614476400037, 0.6630609268623014, 0.21776547204823266, 0.3280489308939826, 0.158364791723509, 0.1290391145213958, 0.15583437266609362, 0.11080683479385992, 0.3591781476091954, 0.23020628028579299, 0.18918245580167542, 0.17586433899498757, 0.21145587997330775, 0.2919742795488527, 0.17330794955693907, 0.2684904364568572], [0.13149200548087397, 0.08337113480534285, 0.05337706121105341, 0.03285386832430959, 0.030515356207146283, 0.05414731665364197, 0.01266497609791376, 0.0998831794206654, 0.050252981468914985, 0.009068427907843745, 0.09425980294303549, 0.04953223445843305, 0.03408458474422655, 0.06015167248645618, 0.03857110589442234, 0.12037150381553559, 0.054252952517521, 0.1499501585720047, 0.018875759109974872, 0.08409607614721022, 0.05249261653291122, 0.015493734690901494, 0.03231332051537691, 0.12061002529076031, 0.035140479899822705, 0.0340083513348814, 0.023743144702166322, 0.05660907125040408, 0.030015349771166523, 0.01927842641429555, 0.026136692575809937, 0.10325194381537939, 0.130757327161489, 0.04451030211883687, 0.020067592737294977, 0.03414816621150221, 0.04681768616841686, 0.15879442915320396, 0.02309891263834171, 0.023912348626782338, 0.05825882244314398, 0.05076153361569009, 0.09028779027322609, 0.157142513762078, 0.1672108549504511, 0.16051150798316927, 0.15065497478410123, 0.0051561365797815305, 0.1791447887737905, 0.07596578418968186, 0.47104098864140054, 0.6555331630572196, 0.8770988448973626, 2.0745611959888093, 2.8158977387412905, 2.045182643398162, 3.2244814788141563, 3.1001163586493465, 3.329921162897541, 3.134951663594092, 1.6476408656566375, 2.708033294447007, 3.283430534985758, 3.2648610539974707, 8.79238203648598, 7.241926472033224, 6.002931123779667, 5.39246617786346, 3.3609409822571665, 5.989913267474021, 10.012618649390436, 7.132517839631728, 9.510907300056951, 16.575987339019775, 19.89637959387995, 25.954764696859545, 42.6850208159416, 51.547447558372255, 59.391987862125525, 68.13448813653761, 47.70445831360356, 27.617508403716553, 12.038394385768521, 6.188250366718539, 3.0731152526793943, 2.407586113099129, 3.9899908534942137, 7.2901588774496515, 5.123457283742967, 5.8736483320113155, 2.4251161659917524, 3.4016417014983396, 4.9962489354995, 5.35750707311015, 10.0500851292764, 9.916500968317832, 11.058916776410996, 15.387294427041086, 17.225018009062737, 20.493760493493852, 26.36554275789569, 47.50240918128721, 59.77227341744208, 70.08117614253875, 66.34423994248914, 72.29080415541127, 63.45835608820762, 46.356555415738015, 33.50470558289559, 26.833783541956258, 19.186232512997044, 2.0949263870716095, 3.5653273568999384, 3.0484094687046546, 9.324306422664273, 6.5391333449271425, 5.627847121607873, 4.875647329515027, 1.8297574933498137, 2.718198116748564, 1.9803787142999711, 1.4634040743112566, 0.6498185761513249, 0.43967891184072344, 0.24899815659849878, 0.054653336879827326, 0.10149723474657345, 0.05011790484610585, 0.05524869827974228, 0.044935281733952226, 0.05786039926592381, 0.05897799514294152, 0.060906406987698815, 0.06689446813036358, 0.09775629717736475, 0.05100677368201075, 0.04977048014200503, 0.07903107051407138, 0.06942035194726721, 0.03431547215328582, 0.09373399849620559, 0.02053585248969255, 0.07708893803459022, 0.07822546011377728, 0.03802940895360324, 0.09776021954753707, 0.10202651723257958, 0.039121233632848154, 0.06970059457084826, 0.0855837652700082, 0.05436055339692582, 0.04289754531196049, 0.056303555386201035, 0.08761097947435995, 0.10278222466548605, 0.08474585660282644, 0.02542857452475977, 0.06876025994819018, 0.08845377578249863, 0.17034513515330132, 0.02956234474456118, 0.045174439062154105, 0.058394986910805594, 0.07221288798797516, 0.03345447742650586, 0.019784015716023503, 0.12337816143107992, 0.14099426898023776, 0.08585883680010035, 0.0777169309496399, 0.08382973035857563, 0.12002935362679344, 0.0752033505048002, 0.052446394617999756, 0.06972924625921635, 0.10567037614002343, 0.09393911853793169, 0.159357090090071, 0.1717879391846157, 0.1211947265772089, 0.033366296875981555, 0.06722746356841057, 0.08417205674754036, 0.036757101620277094, 0.05706372911170606, 0.065837282116615, 0.055603542545389746, 0.07722250546418852, 0.04669142721761619, 0.08566864015113923, 0.056647007924414454, 0.14167112298309803, 0.07604178011177049, 0.011207018847457104, 0.017444729850056673, 0.10899782541298098, 0.1116649681822427, 0.13095641809125103, 0.11656566327738187, 0.06719364078655359, 0.04872256379214026, 0.07363863124121582, 0.15994697779176698, 0.09425631724298002, 0.04733160093066193, 0.05490236908137318, 0.03115204613535635, 0.043168173532091805, 0.041738029103726156, 0.05705765786490614, 0.04878751655680038, 0.08386125487665977, 0.04271129784624904, 0.07326956072281446, 0.04484702074419587, 0.07562181071167992, 0.05704746889551321, 0.05005330065145128, 0.021979598809153806, 0.05665130950810929, 0.02231387935969378, 0.16380410791645128, 0.2638920703001561, 0.3690586593602935, 0.6477460938115275, 0.300825965861159, 0.667233961003442, 1.4733525533829968, 2.6844623011927453, 7.366954963053427, 6.450142610457636, 8.71589974049599, 9.688232752584643, 10.17461253750709, 14.114715745372159, 13.359911499484895, 14.6347886900748, 13.17994531123869, 13.904322751106756, 11.340201708578295, 18.77155561600962, 17.089521692645167, 15.527983961566804, 16.89643321498748, 18.063742345379247, 19.693085109033895, 25.502854701011415, 25.834877452542706, 33.76828885847522, 47.30231338931669, 47.27590014857631, 46.98869243744881, 56.73724143735824, 58.961848981918834, 64.5655745075595, 69.23131619730304, 41.07495846286897, 9.52329904802384, 0.9860689072839677, 9.447170745941902, 0.854375328748457, 6.428241076007967, 9.884418922085917, 10.989060344234591, 6.0430388296804125, 6.887973748868512, 5.257536643935788, 5.683374154952265, 5.052717827981518, 6.18140337928649, 11.067708769152242, 10.489775961445226, 12.184058466265279, 17.339831667561686, 20.265455015244026, 30.36327538951751, 34.444450563000096, 53.678745838903616, 67.46632022242393, 77.20128213205646, 80.43013018946495, 79.55031118085309, 75.00206408962127, 69.40335135306083, 55.30675303551459, 40.86664922775761, 32.07650392286239, 23.693059375209195, 19.5922056705721, 17.061957236259214, 12.360483734838425, 15.28880959556949, 13.364183941195089, 10.828150991470585, 9.759769920379886, 7.925278861676493, 4.292850292498066, 2.8202243581894906, 1.406360554598993, 1.1654412241712695, 0.5961582232867518, 0.03686478676935358, 0.04011911294993855, 0.05052253716595231, 0.035873499638851614, 0.12225545191716765, 0.09691386093055049, 0.08176880828555554, 0.008946877524947688, 0.07665591449626992, 0.022970167732226755, 0.08034949250999959, 0.12368666503818766, 0.06039253436028958, 0.02932360684949785, 0.04653065217538707, 0.08395218951327187, 0.02638763042106744, 0.08068253391332204, 0.055398020307503404, 0.029214312915780374, 0.033544278252990015, 0.06480578303096757, 0.05292535661869953, 0.07047953745049816, 0.07110472648374497, 0.056132035960833875, 0.03591555403545499, 0.1058559456179219, 0.07712060810937997, 0.09300727983035388, 0.06511273914046826, 0.11543227449780512, 0.12367569465911198, 0.13322262874534055, 0.11428930195829562, 0.06780916179019598, 0.15497757993157835, 0.07873700000345707, 0.009327666315760826, 0.01187907139425196, 0.06498081113902793, 0.059963720475113204, 0.10979070343197354, 0.16899354155025176, 0.02362897653403061, 0.0752599950459215, 0.04100097591177591, 0.08001343272025548, 0.04975015582937387, 0.023547183241574995, 0.08542759824664363, 0.18452635725900052, 0.24994865720791204, 0.22192850108108214, 0.24306442258098435, 0.13429092303399118, 0.18412437560337205, 0.12074720865536122, 0.1516047246273487, 0.11674672815828555, 0.1468059345478973, 0.20355241132840035, 0.19428012742390557, 0.18897702166390037, 0.365974665168793, 0.22699663235295206, 0.3208443336188793, 0.29074063284262536, 0.2877061585745504, 0.2753202635194025, 0.14743794176367023, 0.21442866884171966, 0.19668705310792695, 0.1809203047906199, 0.2057971868423685, 0.1375974810892536, 0.21539268324211722, 0.19432039300520576, 0.23084023336489357, 0.27752650481077934, 0.23129328244155456, 0.19536659331812015, 0.22049752544731865, 0.32561562114184905, 0.2879655865892288, 0.3882760362279031, 0.1686020093339105, 0.22043409336718822, 0.17769335859244872, 0.13116070309713965, 0.17890324125126486, 0.12084813307850592, 0.24121010676026347, 0.2794909381097363, 0.2706847267766153, 0.29215544402118654, 0.35705902583656773, 0.19432644509980757, 0.225318715937676, 0.247088345368543, 0.14776187438157298, 0.37665580008779803, 0.873527342994367, 1.1558418360448655, 5.267558790022328, 4.653734334053532, 5.068681384286573, 8.16482977521035, 9.665038797163195, 14.645340846430871, 13.331315459743625, 12.381983226345433, 9.127756453329518, 8.952627528098322, 7.6349033463385805, 16.962582026758504, 18.955983500326834, 16.547301084764545, 21.589519708387314, 28.570387440343058, 34.00567854604414, 47.387142489033366, 43.84542657483009, 46.135875025103175, 68.9594724101405, 57.33460664749146, 58.11089861777521, 72.63193268929759, 71.74047993075463, 75.33643830207087, 83.96978685932775, 76.7114487001973, 66.31305709961923, 43.33325524483958, 25.652828485735004, 15.058322298911312, 14.175348724088362, 16.543953341822473, 17.59243230665884, 12.952252703328288, 12.740628084828778, 8.28491460892462, 10.01394441050868, 12.26551236644868, 12.394847619918085, 19.275723349663522, 16.121484656487745, 14.640185871431905, 21.940585567105202, 28.565557041475852, 42.8299210148473, 57.02094647192187, 75.95927930647328, 86.0957036479827, 95.72380450464065, 94.13598199044505, 96.14933459989487, 88.3019741119877, 76.45549051223263, 71.16106740890011, 66.06194696118756, 52.1819576140373, 32.48045313742853, 24.881294350470267, 21.074434057358776, 21.873871934029367, 17.78633075375711, 14.519049352215184, 15.333126494961402, 7.937254348108846, 5.146006009271068, 2.97390184094829, 1.911951986051375, 0.7850495809989592, 0.6739304887671625, 0.3326785227944774, 0.10288350148907593, 0.16018247321969079, 0.14477623055779165, 0.14444823767389023, 0.25996663577614293, 0.1513336673979798, 0.3298175521194935, 0.1226622139614436, 0.11736878389192205, 0.11968422335602584, 0.15496256460826244, 0.19108005559011815, 0.16581364847238989, 0.15811392857182413, 0.12632970668135152, 0.258430169835206, 0.11626962392080216, 0.17459945122320808, 0.22404261263868502, 0.10610353757417011, 0.21087238144490028, 0.22941584608727889, 0.15834473554165135, 0.2720717442852836, 0.2566931420756925, 0.16294556850146863, 0.10001854715688575, 0.16919914422737015, 0.18759106135656758, 0.18061639771105784, 0.17806449754824563, 0.2513705317171351, 0.1749345687248053, 0.23972400343946873, 0.2279854986456133, 0.07443364664551712, 0.2539817730505621, 0.24958361631199238, 0.13717361996250768, 0.14923345267532334, 0.33029782796098345, 0.3589149810854466, 0.3889877931965936, 0.32827642836397697, 0.29439487224144323, 0.3078279175585316, 0.28802221580859155, 0.2086265640513551, 0.11133491452182494, 0.18274028455057453, 0.20570292738416504], [0.08712637523609786, 0.04015525314776648, 0.13133402282912887, 0.09899317677463255, 0.048485283379352866, 0.09727443553387158, 0.030584848042757764, 0.03386390545675832, 0.024749320751476674, 0.057977491974710464, 0.05892794661884827, 0.08587402832363883, 0.0862820084477144, 0.08261984003888023, 0.02881947694526565, 0.16727949642846662, 0.12455811303469444, 0.10626769489458493, 0.1438765981865506, 0.06473515738522814, 0.043018165855638446, 0.023744073583774512, 0.113094549535984, 0.07642256411453409, 0.047063374396173224, 0.11769094684671973, 0.05380879006078167, 0.03266509276844802, 0.010505981364047096, 0.01667042371756848, 0.023415176716122418, 0.05659125204528532, 0.08299058828983577, 0.03400487329570517, 0.03789693702973666, 0.13299107100934754, 0.008987870889775937, 0.0646019576778335, 0.013970031774783087, 0.04708067266150348, 0.027601504397969094, 0.046404630711842934, 0.06259205323013087, 0.02284633344970644, 0.031684278059870966, 0.09403105674972458, 0.03617305150856415, 0.03994232667009196, 0.0324945462747447, 0.10383588667478293, 0.05826927188243117, 0.06149507277915555, 0.06427591831813897, 0.03691200842900622, 0.08742667404153655, 0.05563604765601697, 0.3376346213683006, 0.3086532394011175, 0.26722899608073697, 1.472421725911479, 1.6358929992683473, 1.2568937362201753, 2.0028865000893994, 1.9297817325399769, 1.7291401182451558, 0.566023449984289, 2.131407126303642, 1.9647860671243362, 3.6424529215981885, 7.0481976674449065, 1.8107168376445772, 4.299446738535359, 8.288396693045094, 7.966824606541665, 14.891275417420173, 19.490002432177146, 38.36592251254667, 53.35470707185807, 64.64646946999335, 65.61894270681566, 64.24859208445396, 50.37693385154971, 36.57308947655463, 16.94196016557755, 9.491983825160611, 5.5236542609430135, 6.94886266223846, 9.347574903118996, 11.386938710366527, 7.580257375394145, 6.3400652139417595, 12.238234243085309, 11.93968794038219, 15.556473116720877, 21.464021513538977, 21.182516928642027, 22.817162736769646, 28.14862870400952, 29.203995350868475, 30.79366137904506, 39.99401600130143, 54.57555263273178, 65.42433038834604, 65.1951619886583, 69.29052829742432, 64.437932737412, 54.61233269783759, 46.55705128946612, 32.25178483993777, 25.36613460510008, 9.276253465683231, 6.873923328615005, 5.484164818640679, 5.201981173407647, 5.222878581093204, 4.422170346783054, 5.165289851926989, 4.107540365188353, 1.8681152092833675, 2.0350033573565947, 2.755970786656103, 0.9065581125117118, 0.24629676203814246, 0.13475535617720696, 0.17486520712414097, 0.057437622153590766, 0.015022027542844657, 0.04078957011863109, 0.05525403791257451, 0.04596691488498642, 0.05841524993640281, 0.08483634690844244, 0.10703318527028446, 0.019969592854801207, 0.040106081794346535, 0.046873645060845924, 0.052998740180966356, 0.019949178526838942, 0.08108728114635715, 0.02951738304428516, 0.02777312916042584, 0.017626489955751647, 0.11201857904633207, 0.09116777248920933, 0.025653471126251166, 0.09279094426141632, 0.04131884494375798, 0.07124410852068855, 0.05483935834960111, 0.009477527477898666, 0.04945551075281636, 0.09006324224174024, 0.09969507419173756, 0.04780653330887999, 0.01743058020609521, 0.06992878151997443, 0.18159164296042535, 0.03014093456459382, 0.12836570791419477, 0.1107232699230794, 0.04734716783728331, 0.03860035513137137, 0.033558385762115645, 0.0620237309035034, 0.010098780734434484, 0.08264501368807209, 0.046480174642056234, 0.10091377452256219, 0.08137939047188529, 0.06713156468204914, 0.09360941727795909, 0.0664643480652763, 0.0625372741131052, 0.0625021413208977, 0.02683271601375553, 0.03664403853397216, 0.06967122275983134, 0.03292613722864659, 0.12575226024754588, 0.03361762351086063, 0.04972831466265264, 0.01843567607143233, 0.0042846541093181706, 0.08297186510096635, 0.044523658861796704, 0.08314718432243794, 0.05173996579082263, 0.03884511256229974, 0.04145046267958899, 0.04531755960816818, 0.1009873879112063, 0.18757121967932872, 0.18470516218052757, 0.15624098149278473, 0.14861005628781934, 0.08123534295948283, 0.039929575136592316, 0.04310977081918428, 0.12422311044628583, 0.009614534642276986, 0.0417721851338302, 0.056867660398805336, 0.06132268001355472, 0.0046890034554376, 0.0335268612440315, 0.04784057442579539, 0.07414586571676117, 0.06359131150548497, 0.0716828853793202, 0.05616886946823328, 0.08880333404146856, 0.03511347530049182, 0.0551244962750183, 0.041948427491250544, 0.06283596796434253, 0.036770240028178504, 0.04844702111797468, 0.03283430626916309, 0.13995534650260402, 0.04973452380527893, 0.015827157222966275, 0.15777084375581435, 0.12126842423552468, 0.015306863821141664, 0.12540778881239315, 0.08136943132886965, 0.08501936531355304, 0.03482320075554233, 0.1108627055861777, 0.10988724583219137, 0.2530575339351931, 0.07068766821776667, 0.914207837514339, 0.7850882531173768, 1.2779469355460138, 2.4901694107440213, 2.6834098802458857, 2.7631688262185743, 3.027313000732853, 3.270427142420123, 6.520387357281101, 8.160346996399666, 8.079635404771375, 9.868554895923985, 12.051399004074836, 15.727128578770547, 21.9992289235515, 22.068082209556334, 26.452133001819735, 34.335467507762296, 32.063520877592026, 37.47800380952897, 60.15544975957563, 63.848898641524784, 66.17166349964758, 76.09350281376993, 66.52976805163969, 46.903341662499216, 29.36572251781341, 11.924021993913959, 2.490906326040145, 4.089665143720565, 11.817617897064457, 17.08632496095473, 13.996888725988327, 9.551346936533529, 10.722708855905841, 15.413769445111676, 15.631836556619215, 19.553131018915487, 27.12505678976736, 28.257378378222068, 29.97091873999565, 33.822570539289906, 38.7634547295109, 46.15626350525887, 54.69420040807417, 66.59154538185366, 75.41665861683508, 78.34950108681956, 79.85582459357478, 76.22242327659362, 69.86808946055751, 60.108287180623705, 50.671798029253566, 39.347350520472375, 31.84304641139123, 17.322251604449367, 10.733034495384464, 6.8644311927979995, 9.479806826960656, 9.182258767466392, 7.2054606868374735, 6.937229402603642, 4.207521580880688, 2.354938589757489, 2.1377515600573633, 1.292911145475603, 0.9173096355891998, 0.37330217359046786, 0.16512917955556225, 0.20061038855102756, 0.053673399341923576, 0.014989857595684308, 0.013935207332965108, 0.04266148680941232, 0.022174372833462495, 0.030920700988762324, 0.0675780943504745, 0.13723084673045144, 0.06408771349778099, 0.03981246710604718, 0.02665167220026976, 0.04179285418602728, 0.03878579820476232, 0.017144183981262388, 0.04955663052838176, 0.0269340445482803, 0.08182350696334917, 0.030323445436454592, 0.04498273321998216, 0.030787066526470647, 0.048153632425612984, 0.03315246641455639, 0.09584903702019684, 0.04276298196806062, 0.059831574138614445, 0.03383220090801197, 0.06493363544465074, 0.02455199565438013, 0.08378352759586227, 0.02308561718241582, 0.04170571934551962, 0.020205532613721107, 0.03948970277222895, 0.06253430169195899, 0.025215734231976733, 0.013376146051732284, 0.06301371185409446, 0.07482525547065082, 0.08051460744031975, 0.023069887482110533, 0.1499378245564238, 0.18896551502327766, 0.11020781532410653, 0.07870626455593495, 0.12771326147260206, 0.1333363928020962, 0.13404980452070314, 0.13064705646566807, 0.02683415817427299, 0.03984901333047498, 0.1783379296501798, 0.12598612390819097, 0.310495680859012, 0.2705789759995476, 0.21277473097847355, 0.16314338772527634, 0.179753813351835, 0.1602493526954805, 0.061668495933014544, 0.18565308873451528, 0.17946113712124287, 0.2278964792288119, 0.15420593020896758, 0.2770333586921615, 0.21424508353154506, 0.3478317419367452, 0.3023299803176234, 0.2453583043308989, 0.23158182179735554, 0.2512854806357815, 0.12558981896408145, 0.16645668735427244, 0.211015869713118, 0.16458536438163252, 0.17650497236078785, 0.2522539536678984, 0.21074032320851283, 0.20761980194478266, 0.16759910831047645, 0.3051509305594429, 0.15185284518426465, 0.23378628576474808, 0.22402039608888089, 0.1367719907073244, 0.13861605627161844, 0.2743548701607412, 0.12196028590082161, 0.1198608449269687, 0.11170862753304744, 0.20864484290922844, 0.16977066114064188, 0.12415038571963388, 0.25385208968673983, 0.09729606219597402, 0.1232323672382101, 0.2286714690947725, 0.11968352621601475, 0.17555899167012784, 0.23813702166080478, 0.26055725892224624, 0.14365360531355106, 0.1360902797070242, 0.13268848160101523, 0.13055622908136538, 0.16468281076560098, 0.10166594262925849, 0.30888505760700474, 0.1911312149417016, 0.3472234987683835, 1.037341639880211, 1.4515028677640425, 1.6823306751828042, 2.3188581774311685, 4.080582405290296, 7.6639058416889565, 8.593719870813432, 8.28885757154034, 8.176485588473659, 17.216341726241573, 24.69074756868424, 22.13285819176705, 27.12589421579915, 36.456834347017356, 46.61645558572585, 54.85757497049148, 57.78568313967798, 78.617108714196, 75.9722545070033, 80.5698371702625, 78.94705064835088, 84.32592238149336, 76.38430733834544, 69.59752436607116, 53.262798093980365, 40.08607010687552, 26.812718452945834, 31.107464721125943, 30.928630136674453, 23.963189086606427, 14.860371062832495, 16.165880983875645, 19.538716308532223, 19.350872039794922, 24.55209178309287, 31.21936013621669, 29.82589302524444, 32.72435592066857, 41.027992002425655, 53.79864877270114, 67.41888307755994, 81.61721198789536, 82.2038181366459, 93.07405517947291, 89.93452733562839, 91.92754637810492, 87.39107424213041, 83.77153458133822, 76.76121573294364, 69.70382844248127, 53.85682536709694, 40.308805819480654, 24.965470375553256, 20.786541892636208, 16.333168110539837, 14.538295442058196, 9.991628085413288, 9.416175196247718, 7.33950327480993, 4.538256814402919, 3.645351798303666, 4.12266061190636, 1.7557488646238082, 0.950310129311777, 0.41737726498996064, 0.23513804790714096, 0.21312576778713735, 0.1592309307307005, 0.1298047274711632, 0.11961836277717545, 0.21379940422071567, 0.15028751305034085, 0.23308554514040872, 0.22899849670788935, 0.29559346276425547, 0.18652983039857882, 0.11526039501111354, 0.09902324572566057, 0.10778877012912305, 0.17859878258839731, 0.14763926967017113, 0.0778197705925953, 0.12205973177427247, 0.2741887822987572, 0.18047614233388057, 0.12238975479117326, 0.22513094778743484, 0.1485296323775284, 0.23350415090399407, 0.2398138961965038, 0.10483665797378748, 0.2310343753666647, 0.2645149610696301, 0.2786183946074978, 0.10018562327229208, 0.2077138928636428, 0.12008627395956747, 0.14017686848678898, 0.12265372570724258, 0.26218317328922214, 0.2774254118482913, 0.17153961944483942, 0.16225371449705095, 0.10020895831046567, 0.1618324733910061, 0.2343759896053422, 0.1548183408956374, 0.2923915523194498, 0.3650933269771838, 0.24734454049218088, 0.19684453014164202, 0.3043450673501338, 0.25460782010228405, 0.2519534173752031, 0.21651595200021423, 0.08320552957875114, 0.12164139414146063], [0.0605263201249463, 0.09859643516040618, 0.13639077003444397, 0.0316305733811591, 0.012759059355894645, 0.04199536569837121, 0.06397020327107561, 0.08282372667904823, 0.006547225845767366, 0.07139691241806553, 0.11199181959513696, 0.05614826553350976, 0.09042240724328066, 0.045043169896328644, 0.1497373087031226, 0.12260901681598156, 0.16803947097111135, 0.06428774671568986, 0.05672885675824458, 0.10001612631904502, 0.039317984164001486, 0.032552638722042886, 0.05079762018736332, 0.04754567270978324, 0.053442151871539896, 0.05035764440113018, 0.026268603340271982, 0.0242797548191682, 0.013610229962655615, 0.034019796688470154, 0.019036327308464437, 0.04941885344563954, 0.04731306160289434, 0.030805831850175897, 0.03276655728357934, 0.02728642201081159, 0.0629440629704585, 0.06752518831842369, 0.025241727595247572, 0.03774007286636099, 0.07514944089756859, 0.043031882659922686, 0.05568371747710532, 0.15164863678716844, 0.026176352947649938, 0.04391007989104237, 0.026102649543674725, 0.022736530067519318, 0.07307210156033117, 0.10136486241413702, 0.08189191095410817, 0.13994512688969413, 0.04698554369350595, 0.006050569129236524, 0.10666838952250059, 0.2107000729489711, 0.22840119327508637, 0.29719725251197815, 0.26274434801551605, 0.2594513956817889, 0.20376437253529028, 0.3947485905260809, 0.5604463298955272, 1.0216695034215528, 3.0413781298745066, 2.771124863816846, 3.093169595926039, 4.039159969937417, 4.181405949977137, 7.259821305351873, 11.321512595299753, 11.036444537101254, 2.436189997580744, 10.143754270768936, 10.494658331717215, 23.64473577468626, 41.95349093406431, 54.615243096505445, 58.1579396032518, 67.31260253537086, 66.80030176716467, 70.57612434510263, 53.43882230020339, 44.76633241099697, 33.103682456478, 20.08396890855605, 18.27407160112935, 18.56314439927378, 16.01651418593622, 18.848365429909, 22.028695729471025, 21.065463596774688, 27.008250567220873, 33.34635165429885, 37.278931756173414, 44.075320612999704, 44.98664802120578, 48.544276991198146, 43.88925121676537, 44.66433901940623, 56.21828440696963, 56.004605447092366, 56.38473018523186, 59.24810355709445, 66.19646072387695, 55.388965914326334, 57.9800130474952, 42.17457925119708, 36.146916112592145, 21.604275664975567, 20.949539907516975, 11.732659359132091, 5.392662786668347, 2.798665785981763, 5.496040284633637, 3.6101529386735733, 1.7273493111133578, 1.1673586503151925, 0.4349205558819156, 0.17077938443230045, 0.2157540622377588, 0.025410081162267638, 0.08497398226491867, 0.009583609587993593, 0.10227398661475989, 0.03333846107125282, 0.05217159504912073, 0.038172173268732526, 0.06930881720637122, 0.030405809464413795, 0.03325570059279281, 0.05254567195210726, 0.1532844030448506, 0.0406281745451833, 0.047021362134405685, 0.04384250710568121, 0.08049377750965857, 0.07053773715010575, 0.008064718661649574, 0.12831199748982347, 0.07661208660612184, 0.02463781282365803, 0.012494478442315615, 0.015787985232178003, 0.04183921782720474, 0.03576127541882377, 0.04043196027557697, 0.026466912860351226, 0.011974308572168793, 0.032928588710004286, 0.014110928750596942, 0.02522115621926083, 0.05383340063534918, 0.10640403556246912, 0.04632495756771776, 0.05024853815895416, 0.04941374363918458, 0.07660419590050176, 0.09322094941331495, 0.03398723795168823, 0.11348061954542515, 0.028197959388395952, 0.07587996702040396, 0.09264828336815681, 0.053508763216556086, 0.1026282639753434, 0.18602994270622733, 0.13294538152554344, 0.03015343903473789, 0.12269039067529863, 0.1376356935549167, 0.06037763778060194, 0.1771456823353806, 0.029020385418628013, 0.0837626823434426, 0.041348216754774895, 0.05557874810972041, 0.17464523263756307, 0.09746827110047303, 0.08393008787665637, 0.07263353154543908, 0.0752774618505951, 0.0428480981668878, 0.07725977564170476, 0.02934685187234033, 0.07764353972649382, 0.13278981971163906, 0.039733977567765026, 0.04347606426886013, 0.06427073190289159, 0.08008867787617831, 0.16041462850426474, 0.2812156778189444, 0.1785681237496676, 0.1442312662519755, 0.1125620341589374, 0.14080930471179948, 0.028489702906940254, 0.04142648029711939, 0.08054646903709059, 0.038317553774123235, 0.06839948616200878, 0.029325227125457702, 0.03259139511013224, 0.06792944525518725, 0.040815456229592526, 0.04818399632049184, 0.058326353093669306, 0.0582753814336273, 0.015493814172523638, 0.024173268597693216, 0.04416367414617731, 0.07090653187685436, 0.07064780100218712, 0.009875684439565146, 0.06349736614333046, 0.08309496776951898, 0.0805296840506696, 0.07829462253158131, 0.05206163844934875, 0.0478126735035931, 0.03210430108611623, 0.020804584642211278, 0.019323962680514783, 0.037430887441000635, 0.02236026215306934, 0.029095105804322712, 0.07430945613211201, 0.07077944555109547, 0.06847411844759219, 0.13986873260188487, 0.16678437380300415, 0.21897731589213495, 0.34592577646816935, 0.612901718385758, 0.5881994890589869, 1.2371518342725694, 0.8348139171158114, 1.3094175823273198, 1.6339057059057298, 4.553012770991172, 4.511696484781081, 4.056099951267242, 4.222014738667396, 8.73771204102424, 11.475892182319395, 13.8551450544788, 12.63452502989, 17.323120409442534, 25.759160018736317, 27.650991716692527, 36.55143799320344, 61.56548300097066, 68.72603647170529, 71.63133605833977, 73.87260190902218, 77.25724650967506, 78.34327236298593, 60.40898784514397, 40.542406497463105, 25.997949992456746, 19.59047394414102, 22.976412926950765, 26.74205303192139, 24.849136798612534, 24.420123638645297, 28.5368021457426, 26.8151601283781, 32.90783459140409, 40.48122928988549, 45.40267029116231, 52.06076814282326, 53.3442461106085, 58.62424273644724, 56.69429932871173, 59.214508456568566, 69.70609557244086, 73.34955384654384, 74.05744752576275, 75.61595424529045, 77.1156567911948, 68.58515277985605, 65.57123491840979, 58.02320226546257, 46.218546821225075, 34.472440596549745, 19.976952921959665, 9.157304648430117, 7.128893569592507, 6.904599205140145, 8.713349219291441, 5.89257376809274, 3.8978754608861865, 3.6179560038351246, 2.004890831247453, 1.044462457779915, 0.9154767855521172, 0.17606376700343626, 0.12766278393927122, 0.06697843136686472, 0.05119379872696535, 0.033676309676300135, 0.020870542897272016, 0.06839105153396245, 0.02521373091205474, 0.026284620323548877, 0.07219100085597846, 0.048347073456933426, 0.042966857116909764, 0.05253414615928646, 0.028169510713327798, 0.012793949872796095, 0.01997837030719365, 0.07197916222315642, 0.03872376423509371, 0.03784702640146979, 0.015693437533393022, 0.04001699342963196, 0.07405390452233053, 0.05863438555670362, 0.04252925620324189, 0.06705054322317724, 0.08209554478526115, 0.018538245668394432, 0.022183519923278404, 0.07628820761437378, 0.07761507956010681, 0.06986288263672782, 0.05890639656553826, 0.060965625584245696, 0.07399689991988483, 0.06438565275241291, 0.01250636333885092, 0.1366309385987059, 0.11031632401770163, 0.1896573383841784, 0.059367102691002434, 0.07899462005063411, 0.06114820731923946, 0.04452673470481269, 0.08697629095085206, 0.035693894155443676, 0.07015982597705818, 0.08888136775743577, 0.03320536095528834, 0.17326615179979032, 0.07514159615722395, 0.09628895534983567, 0.1413454743282449, 0.071334928244112, 0.03175167081456992, 0.0037663333838985815, 0.18225092290630265, 0.25878158968783194, 0.25088654801009164, 0.16767908788977132, 0.1479413687822319, 0.1845331907632851, 0.1899623792738684, 0.2689794763442009, 0.17804480908859163, 0.11887665177064559, 0.1893874149649374, 0.16254727938963523, 0.15721558322829587, 0.19481297221875962, 0.2547793778320474, 0.20718000618921173, 0.26164139590917096, 0.19627954029748518, 0.20902453140626032, 0.24452757390756763, 0.1647345217004899, 0.1485294025511511, 0.14879013291530072, 0.13485862482939998, 0.14287794129021708, 0.1312001566252401, 0.15671316744579425, 0.20140178802032627, 0.17777618801882192, 0.18733607665185006, 0.1530834122170364, 0.20435721733637396, 0.2059320183170419, 0.11309780540966219, 0.16771725439015897, 0.11511974892909489, 0.1771538947979289, 0.18488951357862643, 0.1511565631916446, 0.1138567763771261, 0.20623972519270836, 0.15565858613098824, 0.154896481863914, 0.19743797249130665, 0.1762928426145546, 0.13628509586616872, 0.1539480650136548, 0.15903795318257424, 0.13818324723791692, 0.11824794639382633, 0.27924992684875766, 0.22927395128194364, 0.37786039673993665, 0.12269228291247161, 0.28411133695513974, 0.4178610035488683, 0.31122576265085133, 0.49006929500929775, 0.6439361853464958, 0.3776022557529711, 0.8515211302907237, 1.122183364725882, 1.0383825388646897, 1.7562108462856663, 3.9851479520720825, 4.766650055685352, 5.6011897133242705, 7.415799748513007, 12.301577579590584, 19.92682306997238, 24.655110874483665, 31.99778783705927, 34.333718130665446, 50.12815360100039, 56.29730055409094, 66.75303720658826, 84.22403489389728, 81.74160603554019, 80.08226302362259, 82.64623011312177, 85.44166411122968, 88.37202764326527, 78.57036190648233, 80.29157638549805, 68.83449000696983, 60.236493772076024, 53.68132283610683, 50.64119569716915, 44.55779567841561, 42.59815600610549, 40.09059652205437, 38.19059648821431, 42.293305473942915, 48.35297907552412, 48.657613877327215, 55.63098792106875, 54.14009501857143, 70.96802403849941, 76.73480249220326, 79.1291976744129, 85.74145870824015, 81.43217809738653, 82.15205853985202, 85.5519062472928, 92.9460996197116, 78.6044002348377, 84.39421084619339, 74.7336249197683, 66.88719011122181, 46.9776431206734, 39.46990497650639, 23.980551458174183, 16.869074683035574, 10.082934979469547, 11.010240162572554, 5.884069579262888, 2.980909400409268, 2.239045789164882, 1.8795275904478568, 0.6933946378769413, 0.6910162719507372, 0.09486325806187046, 0.1408568481283803, 0.16235263176983403, 0.1555298986814676, 0.14812254857632423, 0.16473073722614398, 0.14668081706810385, 0.2020733713382675, 0.16004712080522893, 0.19756797761205705, 0.3374266438186169, 0.2313580781581902, 0.19744854450466173, 0.14362654708806546, 0.12768624921239194, 0.1592029378779473, 0.27258909878230864, 0.2020165122925274, 0.15703659444566698, 0.15583783538351137, 0.11926187142249077, 0.17055769390877218, 0.18597041767451072, 0.18275217423515935, 0.22324771980845162, 0.15024366217755503, 0.1089055501225014, 0.09329316086105763, 0.12379163440557257, 0.1316633793495355, 0.28249657682834134, 0.2340298404376353, 0.25055657861934555, 0.1750740886575753, 0.14587179757654667, 0.18118354792316116, 0.2547324626075645, 0.13692687836385545, 0.2515594949645381, 0.1896473332758873, 0.11782033909713069, 0.16274929677526798, 0.15779065478953624, 0.27653175496285964, 0.19548308464788622, 0.41204642684709647, 0.33118927851319313, 0.2379387121407255, 0.3989906338674407, 0.2391564395398863, 0.28946292075899344, 0.22551460461991452, 0.1416867205332364, 0.10145342217818384, 0.14549131234807355], [0.04027955091348098, 0.10295930588918348, 0.17967577963586778, 0.10967289443097769, 0.03151764436024091, 0.04360275222889839, 0.06256533591377159, 0.0944904643561571, 0.1051330037655369, 0.03855584542297068, 0.06427630136210112, 0.03609824685319778, 0.03571556295238195, 0.12090731337065659, 0.24769432091664886, 0.13734753724307786, 0.052284956909716136, 0.05276204965588066, 0.04191733581284362, 0.08690877562208522, 0.0364820760554604, 0.052526366536415396, 0.07127354161873942, 0.020333457805757082, 0.02760463386713978, 0.028714597593211842, 0.0634575525539056, 0.008847639452846301, 0.0967931101519254, 0.07798226550221443, 0.0868196412920952, 0.04988825466904429, 0.04065251315853769, 0.03561940359612627, 0.030310996507685033, 0.05704741909979813, 0.04900208246263285, 0.013494533449110967, 0.01905985386861909, 0.03622293149331405, 0.02974490541213703, 0.06913473904733697, 0.01612985292599807, 0.04952020687802185, 0.036592676169088775, 0.02534860069112432, 0.07058965492873423, 0.05431688255480221, 0.01032182627597884, 0.01985029381279263, 0.12309494638635267, 0.05396947317245988, 0.06459108689018796, 0.01701884050553124, 0.051347238477319486, 0.0743637181397888, 0.049827086378730116, 0.03488623446995213, 0.1798790227621794, 0.09476386581457431, 0.010875613041852993, 0.0391179317938945, 0.2958318693262916, 0.19125066337085542, 0.17177870016424887, 0.18825643936232214, 0.33708245583599616, 2.6408857491708573, 7.066234196386031, 7.124670157509466, 7.175840418184958, 17.303583083614228, 16.00663765784233, 12.761391151335932, 15.318161672161473, 23.87295299960721, 36.359069270472375, 47.06121706193494, 45.31046713552168, 58.041704085565385, 68.01283190327307, 69.11616325378418, 69.21532077174034, 71.29454566586402, 60.75428193615329, 50.816972794071326, 44.510895898265225, 40.09224783989691, 38.224764254785356, 41.67154704370807, 41.96627001608572, 39.754720041828776, 49.72833856459587, 52.038732267195186, 51.931451520612164, 60.61502602792556, 62.117693885680175, 52.450475231293716, 50.68826413923695, 55.86364330783967, 62.217208339322006, 49.08043753716254, 67.02623813383042, 62.71572982111285, 72.1317598896642, 53.85173805298344, 46.40713437911003, 35.543683036681145, 38.39292803118306, 24.586004595602713, 12.850898658075641, 6.227939849899662, 5.699901061673319, 5.005215964009685, 3.080858256547682, 1.237093611590324, 0.49776048069038703, 0.43297889071606827, 0.38794517817516483, 0.10076174437398873, 0.25964690132006524, 0.09085583680820081, 0.029438389803192792, 0.08602530004516726, 0.01706101939142231, 0.11412545873392975, 0.046906563858952255, 0.018490369003566525, 0.017857448227943915, 0.021953546074068835, 0.07116595989153271, 0.10811802705809956, 0.05414460853282964, 0.030883254611023495, 0.024451490664373965, 0.07014360789570116, 0.05669057151422866, 0.02157378671390395, 0.037936229679373004, 0.09729721132786044, 0.07159309987459453, 0.01266478266071288, 0.06718234098967045, 0.04098113040409742, 0.03922972700468475, 0.03607831707584762, 0.023998380300679037, 0.041992282194475976, 0.02856379510053704, 0.1055431365966797, 0.047721681410386685, 0.11660600546747447, 0.06089729820227912, 0.010969684808515014, 0.01010536430253377, 0.045309339484740654, 0.11983640672218417, 0.06944219311398846, 0.014035038165597907, 0.06145306434782763, 0.03990582641093962, 0.08379160982346343, 0.024205890536728888, 0.06116817923142545, 0.03599521951870092, 0.03529893752608088, 0.123958335137896, 0.06350572416258436, 0.04850640442342528, 0.08898714151714118, 0.12893504913776152, 0.05464366501978329, 0.07391528857331123, 0.028070710268953157, 0.05653105285619536, 0.03112220892592544, 0.04488786855231851, 0.21774216765357604, 0.21221174828467831, 0.13378722022377676, 0.1112082495444244, 0.031994231488375414, 0.04540483234450222, 0.11990569937493532, 0.07680169336738125, 0.05695372654665863, 0.10201034511649802, 0.06779854381156546, 0.03637007017049097, 0.11797935596757358, 0.22268352669573602, 0.12741918330110852, 0.19544153203887327, 0.20372874944681124, 0.019868565009786718, 0.052869719483198664, 0.03171048401254079, 0.06156835674999222, 0.05517282876216116, 0.03570077362500372, 0.04997102663882318, 0.054405974749956405, 0.014012769904858885, 0.031099827667217583, 0.1347089159272371, 0.09183374804354484, 0.04282994571352198, 0.0647477825142203, 0.013140340358199132, 0.0306043085912543, 0.03079367403481757, 0.04609352623623225, 0.03965925718207033, 0.0680033880616388, 0.10604943644495742, 0.05886720350733208, 0.08149467138273102, 0.04233993289451446, 0.032147374379658894, 0.05729892576533941, 0.0674594886180374, 0.013866321664423713, 0.022130916495957685, 0.048700075281123, 0.05527116763856142, 0.05290864441063135, 0.07661688997740708, 0.05908793259051539, 0.07546030405548311, 0.06354509342101312, 0.010100723724932441, 0.09223776749305188, 0.17754427788238372, 0.09330333450869208, 0.1232422267897956, 0.06373732786385283, 0.08415936267063504, 0.0726492669914038, 0.32725578474421657, 0.6615247673565342, 1.7329513137379002, 1.3992838633637275, 1.6700713072092304, 2.1766470084267278, 6.421722096781577, 9.777460790449574, 10.400200793820044, 13.890602300243994, 12.76564202001018, 19.589440399600615, 24.635149932676747, 35.39154214243735, 55.86841290996921, 67.11438948108305, 61.77200363528345, 74.21612308871362, 77.36647667423372, 82.02011000725531, 78.52422698851555, 78.01097700672766, 67.51658147381198, 56.56780681302471, 54.125699920039025, 51.90566193672919, 46.46212600892591, 51.04509392092305, 55.40843655986171, 51.31558841274631, 64.17793058579969, 62.59089254563855, 64.96289099416425, 79.9593359424222, 80.98886397577103, 71.61691742558634, 70.98870277404785, 73.38869125612321, 81.6632370794973, 69.63042520707654, 73.43699916716545, 71.23964032819195, 80.08534600657802, 61.51790857315064, 59.779965185349994, 45.396272905411266, 41.73090427152572, 30.136072097286103, 19.654779241931056, 11.169962998359434, 8.80943650199521, 7.70150960453095, 6.065571865727825, 2.9750905642586374, 1.4907600322077352, 0.8512497513044266, 0.8126959168622572, 0.36186864839926847, 0.2939505718888775, 0.0703247340636388, 0.16025836188947, 0.03375852623233392, 0.07206286498976332, 0.04418172317767336, 0.04060447944568531, 0.05407428932225993, 0.0502850384181065, 0.07878448979388322, 0.08164642573965174, 0.17113556935181543, 0.07358417005067872, 0.08241272050767176, 0.025484883902414192, 0.10308685186769694, 0.09207231548404501, 0.11224162554548633, 0.06275694982539262, 0.05229313489830783, 0.05416270736004076, 0.02217747548955583, 0.021486494825371814, 0.007004660296989906, 0.04108074864733123, 0.033867234108789314, 0.027772801657838207, 0.10789569302071488, 0.03264383765898886, 0.0012831948791450312, 0.04373412864703325, 0.05738054477279225, 0.08484904098534778, 0.03464964736673621, 0.05504025724686443, 0.028392792784518776, 0.058443863320374684, 0.056401403966329755, 0.015591927052986239, 0.05720176666434254, 0.037623393845053456, 0.0888926292499227, 0.03240370739912314, 0.04559506729785954, 0.07506668041910856, 0.11016221010997412, 0.04191624413755152, 0.13210176550332578, 0.0732766930013895, 0.1006477504908558, 0.07132755081740118, 0.17338739287468696, 0.05226245307694039, 0.05561898687794324, 0.0011885653047131435, 0.05652772420416436, 0.16993642724569769, 0.21634218793722892, 0.233652220377999, 0.25343590476099526, 0.15623943399517767, 0.15526619589617177, 0.16979143744514835, 0.24526199175705835, 0.12115044669518549, 0.12169597024518637, 0.22761131065987775, 0.15055291655082859, 0.18439799156640807, 0.13481796088237918, 0.38218851772046863, 0.15796596635012858, 0.20938606361948678, 0.18267562672976526, 0.20618545552415235, 0.2623069424542689, 0.2020883866615834, 0.12440603692084552, 0.12153920567324086, 0.1168445269426992, 0.19164075534189903, 0.14455466260833127, 0.22827854259840905, 0.15409968913562838, 0.23441119900634214, 0.15976547624074644, 0.1593236733348139, 0.11246987378164647, 0.15192790647908566, 0.12204016588868634, 0.22314043685553536, 0.13836923806417373, 0.12443220648433893, 0.1831995236176637, 0.18564720517925679, 0.1909426500600192, 0.1219299641407786, 0.1598832852417423, 0.14824679271588403, 0.256744776401789, 0.13193653565981697, 0.1421614805416715, 0.15314718137585348, 0.1662417230827193, 0.08830192949502699, 0.10017568711191417, 0.24662481620907786, 0.19283286476087189, 0.20934618108214872, 0.13017591239223558, 0.21803199403708984, 0.19370055126567043, 0.20473865251387321, 0.1291912442613994, 0.28786038739546654, 0.07253408567198823, 0.1256873342959631, 0.13293900767401343, 0.2966296120036033, 0.7532688218259043, 1.1842737491092374, 1.0202005145049866, 1.624032609885739, 3.992189587123933, 9.754249184362351, 13.823919065536993, 15.97393979949336, 30.91737489546499, 39.90873190664476, 43.340766583719564, 56.61997041394634, 63.89975609317903, 77.15003244338497, 80.9910055898851, 70.30803034382483, 79.54128972945675, 83.98742968036284, 87.98934551977342, 86.94553221425703, 89.78004086402156, 89.33671105292537, 84.77459446076425, 81.63851830267137, 77.54584666221373, 70.55248814244425, 67.90080901115172, 69.23479141727572, 63.60821024064095, 71.75208230172434, 72.52791927706811, 72.10889247155959, 79.96712576958441, 86.40035413926648, 84.62455595693281, 87.44816826235864, 86.83719635009767, 90.44189376215782, 78.26941413264122, 88.87951174089986, 87.91514212085356, 96.81927542532645, 78.53357007426601, 77.04786254513648, 60.60793438265401, 59.0980689756332, 43.47693166425152, 27.63812045897207, 13.524089167194983, 12.622399022502284, 10.631747130424747, 5.017265975475311, 1.9372053083873566, 0.8592526121966301, 0.4722524187978237, 0.5600810591732303, 0.2832120110190684, 0.4821493861175353, 0.2511615735749083, 0.3168835058327644, 0.09808870272771006, 0.14788997960427117, 0.19188020378351214, 0.1472924310233324, 0.1644214215658365, 0.09157549214339064, 0.11555085724760449, 0.1733442161592745, 0.49386069479007877, 0.14996849871691198, 0.2280260553403247, 0.10629027916659271, 0.19964928528474224, 0.16011568567445203, 0.17356362374078843, 0.17633365977916027, 0.21501938391837383, 0.17002068159561004, 0.06205886752615052, 0.13450493735651817, 0.14574839613370358, 0.1224935673657925, 0.14537336545125132, 0.08342705922381533, 0.21856226477651827, 0.17215549284892698, 0.1644431324976106, 0.12177218833277303, 0.1892816795096282, 0.18847739444144312, 0.10653265406407657, 0.12949818504914162, 0.14714544939417995, 0.2020049137213538, 0.1254448981114453, 0.14838903992166444, 0.11551329595667702, 0.0981504034491316, 0.1919405102249115, 0.13864806342509486, 0.26401966990482423, 0.1377194882520745, 0.1946999129628943, 0.2087386733581943, 0.3454414250389222, 0.2545155831162007, 0.21907983377816218, 0.25992091564882186, 0.37201833280344165, 0.11993571469980864, 0.054506822564308686, 0.11985938935991257, 0.13774150561901832], [0.08801325990427887, 0.02635971800754628, 0.07470632798128551, 0.09787312558581752, 0.038101968971351464, 0.08645929651515138, 0.039133854931400675, 0.0819640611148169, 0.014761663943288789, 0.0035043751244478293, 0.08112696450083487, 0.1341066176011678, 0.09546516568309839, 0.06892623289698555, 0.15660842790478663, 0.13552460038373548, 0.024752816027631203, 0.06140304646725136, 0.042953400782519774, 0.05420968770199726, 0.044184672616181836, 0.014616330360783445, 0.038436328045903675, 0.029661985970432722, 0.03174805679478713, 0.021965284456288623, 0.05028947789762771, 0.029481003443980892, 0.03963664609698519, 0.07363891469374781, 0.05748616148447318, 0.03880258319118331, 0.09674374344608477, 0.023829634113597776, 0.08097149461748139, 0.0519207050843585, 0.048218807355771144, 0.0650730864295075, 0.015036629178681442, 0.03500058458396985, 0.09015473612253705, 0.02063704695883057, 0.010541629350383677, 0.03767972045968618, 0.0228479020147314, 0.06925419513737002, 0.05188145839999761, 0.0508601674359412, 0.03834654637161763, 0.10701484512537719, 0.0462062867178071, 0.08013977594072781, 0.028482413580340725, 0.07835970936162819, 0.09648878938488423, 0.10166948195546867, 0.07793996212703568, 0.06037500626858204, 0.15040994922239936, 0.08746704687514613, 0.061870057496332356, 0.10042175455319305, 0.04800246412595434, 0.0058167308452539155, 0.14568312544255488, 0.3182742005634693, 0.4420141623385491, 0.9041009927468916, 2.121928228485969, 6.179643705967934, 7.837611436843873, 11.89461696532465, 17.654847022025816, 20.217843324907367, 25.325208594722135, 31.456149701149236, 29.669288473744547, 38.56149581170852, 45.00771507140129, 57.45327403468471, 66.36801735047372, 70.00074401978524, 73.26645451207315, 70.75848317915394, 73.74161043474751, 73.89523398491644, 71.51428468765752, 64.48061204725697, 58.30041185502083, 69.46732521057129, 64.92537352346605, 48.497514494003795, 45.02260046620523, 72.90683592519453, 64.40876599281066, 54.19081910963982, 59.25083744910456, 56.03839666612687, 57.99191351859801, 55.659472173260106, 57.78242365006478, 57.438431785952666, 73.12459807242118, 62.09204942949357, 57.2006106376648, 43.522839084748306, 44.050880324456, 40.404327300287065, 28.172929748412106, 19.717933324075517, 11.21165975447624, 4.702993419862563, 2.7244334595818676, 1.4347061755195742, 0.7394473086441717, 0.551237830471608, 0.36849987482832325, 0.15589544519541726, 0.06871313787996769, 0.08809216696047976, 0.03281863211023231, 0.02848908620616121, 0.09186341096797297, 0.08849653114955272, 0.10001388934230614, 0.07209373067223257, 0.05511849397613157, 0.014148203716162714, 0.03151898692932821, 0.017629736253330787, 0.06666668720783726, 0.0020666883210651577, 0.02251797092838153, 0.01404147809221139, 0.04908227654654653, 0.025259221212998516, 0.005294434602312263, 0.043441747360291987, 0.09700632774301114, 0.0630281985767426, 0.03011992268805062, 0.05983108767278253, 0.0272758289300386, 0.09480040820856249, 0.014290854075713264, 0.031164994936496503, 0.017937056254595518, 0.028472722568098578, 0.09496624326153148, 0.12298092185970276, 0.03513088847901072, 0.1020537439974085, 0.04548142198473216, 0.06432362261318392, 0.016982968438476805, 0.022559140493432363, 0.025498922463626634, 0.029311912517333706, 0.050724531568947344, 0.06087334646332649, 0.023256284334967216, 0.06283148251954587, 0.060554355112535346, 0.04746485426421127, 0.047773239127690756, 0.07118524232458684, 0.1992755109864858, 0.07699847837249119, 0.02933666481816721, 0.08863637283925088, 0.12932613702310672, 0.0575004298720629, 0.10793227371909928, 0.011818287105509832, 0.03621601754979741, 0.053850246908804106, 0.06461164869007564, 0.08071918355961961, 0.02642286663514472, 0.10554736540202173, 0.08089441085054029, 0.08896906184212816, 0.060338820105478655, 0.04499415559093318, 0.10209382571760686, 0.005497460351175359, 0.026240966718403563, 0.14598234406402036, 0.029969853724563317, 0.07114692260661433, 0.12587219131209199, 0.13906106142507446, 0.081242605473005, 0.07396984935527848, 0.07123840116565267, 0.05939598803618743, 0.017044835784021887, 0.10473724274385361, 0.10256762045525736, 0.0365609677899028, 0.05144124129606832, 0.04602045677001438, 0.04514977869187151, 0.06710574751900089, 0.08146466371873695, 0.022710845054638003, 0.00924543635318837, 0.03870822414154968, 0.094078523557513, 0.032324256420496016, 0.06116850481879327, 0.0168207818792472, 0.045872647765903704, 0.09231488956438919, 0.07847784778043147, 0.042609224291217905, 0.056549664962315754, 0.03196989095980122, 0.06768370723171581, 0.06953995359400589, 0.039582744150632815, 0.046442134546176086, 0.031145264342006658, 0.03135113706511836, 0.08737143144131669, 0.03920531178253793, 0.02082346487910517, 0.0983696271695437, 0.04704639022689193, 0.0397872168480629, 0.08253423737422114, 0.054395927506829464, 0.040069309573981075, 0.06457293060638251, 0.0784473728028036, 0.0442139448357686, 0.06820226448678202, 0.10449196437313672, 0.03779547634504495, 0.012284966801563579, 0.40240714086159585, 0.6218613924518709, 1.0463357572593996, 2.449176229776875, 4.8134135334722465, 8.815183754890196, 11.406964371281287, 16.506545697489095, 19.326955387669226, 27.455910674987305, 29.612939703849058, 38.37074702785861, 46.027445024059666, 62.695023628973196, 54.5316848447246, 70.91960630109234, 76.72521621950212, 73.08950070411929, 80.23422348883845, 86.39014028733777, 92.5030835982292, 92.16469287872316, 87.63363361358644, 80.56149821127616, 76.11916295943722, 86.82182065902218, 77.62730644595239, 63.7132199348942, 59.93421631474649, 81.67214085978847, 75.14198287840813, 68.5768138208697, 71.94566695920884, 70.69610180393343, 74.165234258098, 73.3507776260376, 81.1286101802703, 69.89555389650407, 82.30959661545293, 75.61400874968498, 74.33879913822298, 55.07957719987439, 54.07887074255175, 42.528443721032914, 37.77258165421025, 25.385595444710027, 19.11074649903082, 10.430316752003087, 6.92727001443986, 4.790224481013514, 2.394268685771573, 1.4146786759937964, 0.6078023307265774, 0.3855786100029946, 0.16486726941600924, 0.15734056281226297, 0.07033067124505198, 0.10098692825845174, 0.0571516836662927, 0.059414546516153126, 0.020838097158458926, 0.060202690111773635, 0.03813162423490036, 0.013991831764278394, 0.04712472654758923, 0.05839910080295898, 0.034542345261621865, 0.11091989404972523, 0.0398163550022629, 0.049223704038247953, 0.029076081925943017, 0.008204567054617069, 0.021554374045902686, 0.04204548317037764, 0.04474934070341049, 0.07441486983049302, 0.03334588063279948, 0.08512928360892881, 0.03523119620137638, 0.028498683372632633, 0.04206403015902446, 0.03956836468029407, 0.015277519780812005, 0.018448712972683773, 0.0058547426916418545, 0.10641181135490056, 0.022963181010357315, 0.02495493491991393, 0.02784513184920915, 0.04207423445017588, 0.020316398942903168, 0.02246060817983122, 0.053112469763765414, 0.13737116339466265, 0.07507118501610334, 0.035623896701802174, 0.03707688587206987, 0.11220793299857648, 0.08304654335182521, 0.05242703557615319, 0.051343994094960155, 0.04605681913334035, 0.08842968997815925, 0.03364881861113733, 0.08291946468694557, 0.07352748720516121, 0.09725419549091209, 0.0548770115710795, 0.07709981648311501, 0.021760294649509654, 0.04720286751586584, 0.12691262298293654, 0.10414305728890243, 0.1917587635257552, 0.11159137011535707, 0.19254627126839854, 0.08641866321164755, 0.2241373164278846, 0.13449208240114874, 0.22598282223747623, 0.21678167725763015, 0.0970011643104015, 0.2331529761995039, 0.2483022270063239, 0.16679687635792842, 0.14135636809852817, 0.3279473169917061, 0.20297724783660906, 0.19052896258090773, 0.14119584203487442, 0.10166616479475653, 0.26118379627023974, 0.15672272822308927, 0.24469543909353597, 0.14810883560247962, 0.12173561529526788, 0.1259855723248855, 0.10362775590751441, 0.2776528480312517, 0.29175766052738317, 0.2508783815128188, 0.2402685234142888, 0.10615341755892001, 0.13155569803089867, 0.18246185755537403, 0.21448266271862293, 0.17736311341004987, 0.13918270086569173, 0.1285604168210299, 0.22096503826399005, 0.1818011526859576, 0.11625362800494318, 0.16484850026186437, 0.2395848971941779, 0.18985422298071847, 0.11295931203471077, 0.16030132410026368, 0.19520324805090505, 0.15206843764791567, 0.08827569864449963, 0.18729319104984885, 0.20707851486100307, 0.16811077843510336, 0.27213637146257585, 0.24002245597300992, 0.1733332764237158, 0.1679879898625997, 0.19100116385567575, 0.15766022065954824, 0.20249055217831366, 0.24326542873055707, 0.2609717737763159, 0.18408907427182122, 0.1416645652704662, 0.07349195604723308, 0.15023066932635923, 0.20789450575267115, 0.3811518475413323, 1.1257537021752329, 2.347157587928157, 3.6975798731850045, 8.018799443398754, 13.489522299458905, 20.72326425583132, 31.762406403018584, 44.24812063094109, 52.48700034233832, 67.79735257548671, 63.71612641119189, 76.42117761796521, 71.54847206607943, 84.13695827607187, 86.79880419085103, 83.17227486641177, 91.04113778760357, 92.10874419058524, 94.53639322711577, 102.47628242738786, 102.05094060590191, 94.58792532643965, 87.27004558809342, 93.83373198970672, 90.84734132212978, 72.12315420950614, 70.24874764104044, 91.34731800325456, 84.03206625292378, 74.30659647910826, 79.96214435946557, 82.51032783139138, 86.21806590787827, 85.18665513684674, 84.7900878229449, 83.20757619796261, 93.64647019294001, 91.19448677186044, 82.85931679510301, 71.67896932171237, 69.11886968920308, 63.12787286696896, 43.52035230205905, 32.91694625731438, 20.96074611909928, 11.265898289219027, 6.222586304910722, 3.942552728037681, 1.6222409447354655, 1.0132659479014337, 0.6105262942371831, 0.38413713896466845, 0.27565341983591357, 0.17252768900605941, 0.09932431827990279, 0.25541441875600046, 0.1261129497640556, 0.22115839885607844, 0.14568505598412407, 0.12398649652999257, 0.1324860964931788, 0.09258615363749767, 0.15258835087860786, 0.1358981754991316, 0.18567205707152046, 0.20083230890093312, 0.11561957533441244, 0.19114701167470027, 0.1754257383365785, 0.16212266749672352, 0.20411078217289141, 0.24390350336269026, 0.14485864629668577, 0.14415640414001482, 0.12931049350769291, 0.12188052082614553, 0.12942373662466003, 0.1589885864767336, 0.17209759192360988, 0.12037240779928624, 0.13077891551919524, 0.158547917380929, 0.18344352262154703, 0.33296822660392333, 0.08910513437923887, 0.18429741954370854, 0.09947388162536007, 0.18329571361743635, 0.19287228764545536, 0.0729249743744731, 0.13895917173114516, 0.23620989684376026, 0.12232736459061985, 0.14540656770188964, 0.22853548848821273, 0.2626278413639915, 0.1361518272108609, 0.1470211439675862, 0.1320003814274265, 0.2141331274422907, 0.27413923173181476, 0.13293226610027975, 0.40474067532247116, 0.16900909313511464, 0.21669469563470733, 0.18733325744828871, 0.3055998887265882, 0.14872139950673427, 0.12105715250776661, 0.20268965842983416], [0.0929925709422077, 0.058314091856441194, 0.10258326397067118, 0.1012846453475856, 0.027999667105295008, 0.002907258186173896, 0.06486616608115935, 0.05642369712492632, 0.04903659855406131, 0.0695572441984569, 0.12927064161387183, 0.09595461159704194, 0.061531542394790924, 0.06077439088614718, 0.025397754807565964, 0.08872119409422721, 0.04232294489479354, 0.09303108218216127, 0.08977949859634524, 0.046343470082408, 0.048933249462636254, 0.058653740768110564, 0.047790116044662656, 0.029528954802381418, 0.053253027745672775, 0.08182644108009916, 0.051442945841699846, 0.020699151791632175, 0.057036479364239404, 0.02093971680639492, 0.04493791324597213, 0.008989293898095288, 0.09133345432459347, 0.10743392586347558, 0.03747185782319115, 0.019515090126303897, 0.09493599811028089, 0.07302680278136846, 0.01659665711133951, 0.0719316034848171, 0.01841272790766051, 0.023712953177070426, 0.016276644948389263, 0.061971472215748606, 0.07195956569405333, 0.034990031722812884, 0.0367227042724769, 0.05170466062883216, 0.04437172064377416, 0.022638608709037788, 0.03059557327369769, 0.16652410309160912, 0.023383150410447872, 0.0076095135262866905, 0.05090833521418033, 0.07299622821231043, 0.09231513471252496, 0.05574208571605625, 0.03209424426689023, 0.23607567823942632, 0.014230919186957182, 0.059675169627993345, 0.049888189551570726, 0.02427418535995868, 0.04603862071469907, 0.03252391425532199, 0.02513058355919296, 0.23352023875040395, 0.27836347118981425, 1.388886395481325, 4.105496810328576, 8.191546019046537, 8.361630285939864, 19.90451066724716, 22.39790843379113, 40.083630392628336, 37.67303582160704, 46.83652800898398, 48.775473256264966, 54.21663222774383, 63.925879078526656, 69.21130426468389, 68.64957378756615, 70.15574039951449, 60.734109186357074, 65.1084776078501, 71.7393659776257, 64.96481687791886, 64.91421438032582, 69.54378004997008, 81.4809488481091, 70.59312389742944, 67.80472663141066, 82.82608647500315, 103.70047769238873, 40.926390847852154, 37.91911355910763, 41.010980682988325, 46.68482642019949, 46.828393013246604, 56.989379236775065, 67.1088275601787, 68.3536623370263, 59.089498596806685, 57.76814622263755, 55.09955775353217, 39.828440989217455, 31.00118810130704, 16.881214418718894, 13.823414060377306, 8.539260702748454, 2.7557592238149335, 0.9791921956404563, 0.875203236937523, 0.4897845248060842, 0.2251125616772521, 0.11990881735278715, 0.05082935154918702, 0.04338320292111847, 0.028965895499793753, 0.052340134392462434, 0.03488305520506636, 0.06716734864899228, 0.13555625513676675, 0.058686192252583085, 0.044532365451056155, 0.07653112643428388, 0.03722031285325366, 0.024771294068364848, 0.06468508587849718, 0.0627108964498245, 0.059504929569459734, 0.03737665990728044, 0.04452187004649351, 0.04901781790859757, 0.02756377456769828, 0.03170785633096051, 0.04532184587010453, 0.05678785318929342, 0.03573789824581435, 0.023986134385209412, 0.05455250821767315, 0.03844666640244184, 0.025099511032984145, 0.06749436860122988, 0.03366309082916668, 0.021136555437659545, 0.06884025484924355, 0.013834935999775847, 0.030269786723018176, 0.0870292735916953, 0.033789188901503245, 0.05208806465229681, 0.0357764937554396, 0.057315308555600145, 0.041843764559035344, 0.04579635689996424, 0.018826491995564392, 0.08847819866552468, 0.053593661080324845, 0.029406442021530484, 0.056679187447673855, 0.06461203939491703, 0.051973764333994164, 0.05634431509421237, 0.04240713029679272, 0.05199537184389849, 0.04667152042290376, 0.08777506784686158, 0.03057730016148379, 0.05786586147282393, 0.012625327217392625, 0.04489012851169513, 0.12435572026597878, 0.09361753014907723, 0.060261039198526455, 0.04379329361742543, 0.03885129106140906, 0.05578225936680552, 0.10699099680829434, 0.04578557804286961, 0.007368282493834775, 0.036849487993505695, 0.05444019206709439, 0.053490017045048945, 0.047330367529103835, 0.05401744942871794, 0.06588012941422002, 0.06125787280560021, 0.06364804031627794, 0.045991540781312415, 0.012434596222104325, 0.14377714465222052, 0.05238133460103024, 0.07068143226206303, 0.03691433350585642, 0.06644959321185466, 0.03324076570870896, 0.002412741488379036, 0.03247446711024931, 0.00987688432477655, 0.10318674973302311, 0.02538853302417744, 0.022310730738324985, 0.052164796018792745, 0.04154138965532184, 0.042338182383607474, 0.026508538247717005, 0.09256730787456037, 0.012342547885172311, 0.02637129934174159, 0.04635887228012566, 0.014378772241123503, 0.004953163978268183, 0.030017996604944912, 0.01606270436182498, 0.07274315106652438, 0.07736513571393105, 0.026088176227565256, 0.015339486717787242, 0.02014334351124783, 0.052918369896830096, 0.0328198655117904, 0.04033812599617147, 0.10200687473820103, 0.08407414304993807, 0.034801026340574026, 0.01298235004557477, 0.027750376349074707, 0.03268059072715621, 0.10828062155914885, 0.07975216609455886, 0.04378521138982427, 0.0700340803051668, 0.16122041510478144, 0.008893399799783385, 0.012276733271597375, 0.13857300213027385, 0.03257078734496909, 0.03298568524300091, 0.05719952968760364, 0.08833602040765748, 0.09620952735384626, 0.5004614615632642, 1.8734815019753672, 3.8627089608100156, 7.554389834403993, 13.932746206560443, 19.044915399243756, 26.22852260066617, 31.835238933563236, 42.88259060152116, 40.86473511111352, 58.10621530778947, 58.04178645533901, 73.36743985452961, 81.32907467503702, 76.82342452387657, 77.91865225761168, 79.85212972087245, 78.83838530509703, 88.49111864643713, 87.1163514352614, 79.23464667412543, 73.42417301670199, 82.82744361508279, 98.5535200180546, 75.89225384496874, 75.24855367598995, 92.8541043496901, 111.71897119091405, 53.032758928114376, 60.35502387631325, 58.563053761759114, 67.2006110222109, 73.07089298002182, 77.07076918694281, 80.96220754807996, 85.57972369655486, 65.43321063441616, 64.32714539189493, 52.87809987221995, 48.482629099199855, 41.08510171213458, 27.53442671991164, 19.48488570028736, 12.234687439856991, 5.8848442473719205, 3.9505940771872, 2.040617004517586, 0.6880730847197195, 0.28113747556363383, 0.20986754987989703, 0.10809552705576343, 0.12368370793879994, 0.10864620637749473, 0.0935785975607653, 0.039477640717861154, 0.134984768867012, 0.05164895837585773, 0.051159566088068875, 0.032063301975628546, 0.07178842165176907, 0.030573711039558537, 0.04377493432032005, 0.11780225176123843, 0.04329966103297569, 0.06320342586766328, 0.035891016239240285, 0.06306550705865507, 0.0640522627790849, 0.07507969625294209, 0.04680775000803894, 0.008513653846157175, 0.06939916195528162, 0.057997984826684966, 0.03773854069051243, 0.04331315567176189, 0.03729362363716768, 0.028717232935671366, 0.03828115693684067, 0.012006563746610717, 0.06031091918327636, 0.006199806408521029, 0.14065015760640945, 0.040885491987630244, 0.0513059348468819, 0.04112665263575412, 0.0796625797726935, 0.021299586608825673, 0.05382917183000715, 0.030738337588826978, 0.04643675660894764, 0.017243264047729395, 0.07593150175507031, 0.07495132289947042, 0.03990196532780125, 0.05245637674365313, 0.07693791912207681, 0.1338455501583315, 0.010145122350584115, 0.08289832066023543, 0.03537368472485292, 0.026059555182714137, 0.056049662356775616, 0.05607013605655201, 0.08366559602079854, 0.045459998335929654, 0.07613910392167107, 0.0351104301009928, 0.07345142999603864, 0.038789031095802784, 0.25779790214953885, 0.14339442244700848, 0.20989617092474816, 0.22341204566820977, 0.2732325819951873, 0.1441545042419626, 0.212961656431998, 0.17205181050925486, 0.1671534749649225, 0.11411218243020196, 0.3238774595722076, 0.19915984703167794, 0.14675201727978646, 0.21204434275146455, 0.08099080769405251, 0.26187790257315485, 0.15028041907616202, 0.2979201943643632, 0.13558227148267532, 0.21088036408107128, 0.09484353895869949, 0.12677966842367766, 0.1620571056921636, 0.11513470296537685, 0.14258953983024245, 0.2107407522177504, 0.13280437538220038, 0.1486458785591587, 0.1528058279185526, 0.1813917399774636, 0.21622511438064038, 0.14351880448239465, 0.15837239131571787, 0.28958721086382866, 0.17482271988786038, 0.08897400310923977, 0.19824686940879593, 0.08826066799942525, 0.09000749402349034, 0.12158198402293267, 0.1756969487835323, 0.13469734799958047, 0.10696572356767232, 0.22050072769484214, 0.15993147217217954, 0.09485558952174841, 0.1146775629792002, 0.13488837968437903, 0.12871443113732722, 0.19723236981418826, 0.05055940897774793, 0.3077713189826858, 0.17771733714447868, 0.09917752817273141, 0.19156106687601537, 0.1621527441086308, 0.16762317879305733, 0.16545473627986448, 0.25142455623755533, 0.2627725400511296, 0.08045485258222589, 0.24489477517143374, 0.14408207828960112, 0.15013273264611923, 0.21837086536951605, 0.11534898541867734, 0.14317781874729743, 0.2491098215743419, 0.9205717605448539, 2.375964209918053, 5.160630566458549, 10.75709725579908, 16.28745778914421, 31.734004520600845, 41.61115823253509, 64.51638798559866, 63.88674951368763, 81.4830041700794, 76.72477691404282, 88.32375111118441, 92.59436499687934, 88.36545375085647, 87.64445935526203, 90.02813077742054, 87.62936607483896, 92.96894350359517, 97.90114356625466, 87.31356820752545, 89.03555147109493, 93.92498200939548, 114.6948185274678, 91.72945883966263, 91.15657314177483, 99.42359585915843, 120.02102067393642, 61.4282431910115, 66.24060307779621, 68.7340537963375, 82.17418070762389, 84.0671322422643, 82.81355842467278, 91.71147085005238, 98.16898653584143, 86.56300698557209, 85.80017658971971, 76.59449146639916, 61.4513224171054, 47.0590401464893, 28.082762302890902, 20.65413836509951, 12.239982639589618, 4.972631854395713, 2.4396424187767893, 1.451184910631949, 0.6209558152383374, 0.3618731529962632, 0.28730696547896634, 0.14574393750198428, 0.10560050126044981, 0.13802604599585458, 0.19592499480612818, 0.1770863871300413, 0.2164074892718946, 0.3019975900890366, 0.13954953440735418, 0.0901119347902075, 0.1432695194718338, 0.15658933699371355, 0.1959660571188696, 0.23708650061199743, 0.2611199964679057, 0.1923237993351875, 0.07867936720891346, 0.25885804526267514, 0.17615444117015408, 0.12557013816530668, 0.12174006626610795, 0.14935021979674218, 0.20107610872195614, 0.20284310584106754, 0.10064844763086689, 0.17659238299294827, 0.1828924755776121, 0.09464024986711242, 0.28668226674199104, 0.10526123156230296, 0.15971385723640844, 0.13448986074616834, 0.15975865805822034, 0.11796914401554293, 0.20710128299411268, 0.15012634347283071, 0.17452474232883225, 0.06536193222047822, 0.12013899613051646, 0.1967035086765405, 0.21896731078384385, 0.16686487432208755, 0.1662429181798812, 0.18403480460326518, 0.1526861496630215, 0.21590412354036687, 0.21031868373674734, 0.20986497582447147, 0.12520461463399474, 0.22787469168824537, 0.1684221778545649, 0.12761255155407614, 0.17334965538353692, 0.13951547413824067, 0.17867441078828228, 0.19173417210338578, 0.14034326278394268, 0.23680445768179434, 0.18579746566472516, 0.17616907344950786], [0.06546618146521431, 0.12382966301013386, 0.06529341331653057, 0.06605812228254734, 0.09093967747063407, 0.05312152492303041, 0.08423390302566752, 0.025164718521879088, 0.08021148177044046, 0.04538663392586093, 0.10468516408676103, 0.027159423785163995, 0.09954382545284687, 0.14132178688962616, 0.10163230370850333, 0.10282956123832734, 0.014477332325411901, 0.06573670243303623, 0.029967362023589593, 0.07498626416969685, 0.04251832795900203, 0.00229003407331484, 0.04124504769401204, 0.07064581683446323, 0.01170677247442185, 0.08542037403751766, 0.07482032186441845, 0.10865533048467291, 0.049048886604366765, 0.005070650743530883, 0.061757289353878274, 0.06488592348872654, 0.021275146488821315, 0.038117922752374606, 0.0554411165836838, 0.04331132089118323, 0.03529707593242488, 0.04221871097181593, 0.05160258324336141, 0.020573965363925504, 0.03466753168932853, 0.07874286057607782, 0.022173306056027933, 0.01662317332961867, 0.05657164019442374, 0.05277853203757156, 0.02431665344404117, 0.029050931259388887, 0.04577958723530174, 0.06834052803535616, 0.05755562267656769, 0.03301093167054557, 0.027204080965490113, 0.05306025704128608, 0.03668599333914538, 0.07206610554168302, 0.029885302515580293, 0.07770821286906159, 0.030616454915293766, 0.07070047720786064, 0.004790737537757284, 0.022769565694034103, 0.0847866201412774, 0.11316777221978673, 0.03995970920509389, 0.1278973600616859, 0.045958767539911696, 0.03307807161622951, 0.23177360424831991, 0.09163912340638139, 0.9431549906730653, 3.2719117595303446, 4.84252046192846, 12.154426920798517, 13.29632301484385, 15.941927375332003, 32.558690694070634, 47.911614371884255, 52.708912357207275, 50.3288338261266, 55.89942316855154, 61.87935890689973, 74.676711328568, 79.11918778573313, 59.484159638804776, 55.92629532660208, 52.46922808308756, 45.92299622874106, 43.71225426273961, 42.5373867250258, 38.095812413000296, 49.399479204608554, 42.19055506490892, 59.20027025284306, 80.74434341922884, 20.849411602943174, 14.869419970820028, 25.8348362676559, 49.654170467007546, 60.37538097750757, 62.97251170681369, 69.49988872774186, 64.48100036190402, 53.355205212869954, 48.384699283107636, 36.621636652177386, 30.850931905931045, 15.941284106623744, 6.397749060584653, 3.870735355923253, 2.1559729306928577, 0.42834592802870664, 0.052111445655745846, 0.13273838456840287, 0.0646773943557374, 0.16876871006623392, 0.10617646914456161, 0.04535428586325819, 0.05456412977148449, 0.09956662422947346, 0.06652483836777749, 0.006762493200855511, 0.004954432811392772, 0.044617799576371915, 0.04699740273457381, 0.03864622464583766, 0.04125453569295426, 0.18064972253576403, 0.07658638435626224, 0.03372191872087217, 0.029350630601026842, 0.0960571371439484, 0.03875096035640567, 0.029120687395334247, 0.019184672574122107, 0.03595836302866379, 0.06990612063917422, 0.04858760591295939, 0.02399042256236557, 0.0789429857245376, 0.013401545696861803, 0.024174063413914655, 0.10146693596916814, 0.04922365807297249, 0.03746157309280769, 0.030976696270367796, 0.07191284965243071, 0.04966120919092529, 0.02407276552290686, 0.02225764276039216, 0.03394887226844027, 0.03969050207806211, 0.05612873795231985, 0.0407057945736714, 0.010178725839772773, 0.01815447775316575, 0.01371156711566953, 0.05439521504505988, 0.02211331562589734, 0.027443104228305242, 0.029016700535712224, 0.011955117112055663, 0.13541958505107513, 0.12258644020485303, 0.017307395183090723, 0.03970200105780556, 0.08844674309535373, 0.049504046253259146, 0.06474643419947355, 0.09164401870821753, 0.022434450107656663, 0.06917547960315021, 0.03813846923050381, 0.055945083694232095, 0.10344601686923735, 0.03532570080771562, 0.13337265940443163, 0.15478409676542207, 0.07028916460131446, 0.02276325121431822, 0.04428986031862517, 0.01064921586563991, 0.008062264307462161, 0.04729027814802624, 0.07840416544387419, 0.018374988501290643, 0.05906587691917535, 0.04234887697103043, 0.028937132728676644, 0.1319211526142974, 0.14190543863561847, 0.07216809482704248, 0.04092655046993206, 0.05193477811952753, 0.02216996399745826, 0.028812739201971603, 0.03338935995294202, 0.028715175989594673, 0.06761370977807431, 0.065921398570701, 0.04040938749488804, 0.07265808466341227, 0.05437387183548943, 0.09328079620195974, 0.09655713974948853, 0.006979262567080197, 0.026977485564026623, 0.09596187411056412, 0.026657473401076374, 0.02739594960134597, 0.06959007106601231, 0.024695849729581706, 0.03064083374826418, 0.04425682660733019, 0.04075395086059167, 0.02079702910005806, 0.03382297720940363, 0.060799185321816517, 0.04575211915277666, 0.027902237958304828, 0.07583880511623237, 0.06123091417154478, 0.07917158636114291, 0.023620294842628703, 0.019300719572892113, 0.029308829013438478, 0.018606444730633692, 0.040128972501524036, 0.031459122903705124, 0.03658373592301242, 0.017277908458885168, 0.11542328062557405, 0.08062559825878951, 0.042936114008508386, 0.03231790938204335, 0.03288359636621129, 0.08526059107915049, 0.0347218971188751, 0.06197503452459651, 0.019962981516014666, 0.021972194569365635, 0.10243861890968778, 0.0965082556790402, 0.06639032098915308, 0.5045930043824258, 1.222540024788149, 2.718848494752761, 6.346779331084221, 10.070805049711659, 22.01809552408034, 24.50677271812193, 34.555771350860596, 42.98864364624024, 59.66081534662555, 63.829373082806995, 66.32046253450456, 74.29534712145406, 73.56163640176096, 79.09825017375331, 81.57532891919537, 66.15773124079551, 71.78031552222468, 65.65419304755427, 66.93753765475365, 62.03230780939903, 58.22002680070939, 54.84760430551345, 59.055283761793575, 54.374346810002486, 68.62490992392264, 87.06543122568439, 30.450810924653087, 34.96352918686406, 55.04839827937465, 74.07086203175207, 76.4277671998547, 79.84998026201802, 77.1895856242026, 71.07639128162016, 62.74835609620618, 60.262106849301254, 51.14053303195585, 42.00359529064548, 28.160927295684818, 14.59028155572953, 10.553094783136922, 6.923750177506478, 2.41969961793192, 0.8170078887093453, 0.3992460475813958, 0.2151636842397913, 0.13961865085988276, 0.07389818182996205, 0.1300053505767738, 0.06781516791952234, 0.03971739176420435, 0.09794104694118423, 0.059745117285919774, 0.0479102501225087, 0.0736650076484488, 0.01578827826080904, 0.028671173814443812, 0.04106797796163348, 0.0227870152617294, 0.08420559607686535, 0.032448182633567246, 0.009445915817313138, 0.06065035742076655, 0.020449824646235477, 0.03514163669258837, 0.10175146102424591, 0.06175049032355028, 0.004450497780776313, 0.018936841215397564, 0.03484126893923648, 0.06745287727925085, 0.00802223334058879, 0.0524780991667461, 0.031187749663067442, 0.02939918716888755, 0.029805311444966547, 0.03908678648933288, 0.05184059527011649, 0.029369428483468872, 0.07551068965826305, 0.05759948887111199, 0.07272607496669216, 0.04436531231828755, 0.010815847650050156, 0.030652097155970913, 0.021252753738794598, 0.03406543637655916, 0.04464861163268647, 0.004013862377295512, 0.01169245812155667, 0.11025493739232903, 0.06364340165389643, 0.013781381665819116, 0.05969605318480923, 0.18348303743668143, 0.08430901028576397, 0.04848070217356567, 0.08150841500009261, 0.041054219022513404, 0.03220380824660102, 0.058078895202807845, 0.024456918397317493, 0.06988198120868014, 0.02433763850750702, 0.04726604678698125, 0.0623555274139489, 0.06094507910611649, 0.2856873636764865, 0.1285592370456265, 0.129787904180346, 0.13552826228401355, 0.14058280315610672, 0.1257977965137651, 0.17087987984620756, 0.15738419918043, 0.15555027662025345, 0.0752942851414123, 0.17731008480393118, 0.17266115684422756, 0.25774979182789404, 0.2518163948890663, 0.1783545537581367, 0.20032845287313386, 0.20783185508222352, 0.15802207462970289, 0.2367251675816313, 0.19344982600981192, 0.09733792890103594, 0.18740811956024941, 0.1610690667744606, 0.10614125974356167, 0.19130698615504851, 0.1984987131530239, 0.15646123177101537, 0.2787690381369283, 0.16023531796470766, 0.12298490551690902, 0.19704691524947845, 0.13402352770490034, 0.17045719849486507, 0.19255255318937764, 0.1743501662126472, 0.173160569562066, 0.16094206471837338, 0.11781503776869467, 0.17585421131262857, 0.06716786192790156, 0.1555169977608227, 0.29980774307923935, 0.1450888710396905, 0.17871089189523653, 0.14601042884732449, 0.1702591341229216, 0.08430480446305968, 0.0845232620955475, 0.10003118760763638, 0.15900922488541375, 0.14368893728861887, 0.18647888555161415, 0.13466267486012753, 0.1583362626092088, 0.1236161006794822, 0.26134608433611933, 0.17640778644671365, 0.20198632842831074, 0.12338067419947156, 0.11707590847846963, 0.14309483610333937, 0.09460559971029721, 0.2565769571810961, 0.1805713057758347, 0.26960779101617877, 0.143210745206283, 0.17002907791926017, 0.12147460913946553, 0.2772452586120175, 0.8235170620103037, 1.8237346939502226, 4.297067821025848, 7.581555679921181, 18.691841286997644, 22.839071135367117, 30.61484640644443, 51.89562459145823, 66.79017420737975, 82.20148824876355, 82.17780497766311, 87.6657029121153, 88.04576489233202, 94.42863787374189, 99.06531872287874, 81.47335513945549, 83.95841983056839, 81.4527234723491, 76.2293815612793, 73.29433471925798, 68.72315745199882, 57.96414313777801, 76.1323421232162, 65.07912258948049, 79.90011599756058, 104.9451163507277, 37.52996344720164, 36.3305732511705, 61.25427430675876, 82.41788541117023, 89.45075004331528, 93.30148204680413, 94.10099444850799, 87.40655191483037, 79.18081606588056, 70.54876973552089, 53.37231066919143, 43.700949991903, 25.084382910882276, 11.069872936894818, 6.458335461155062, 4.086996951410848, 1.1843046377743445, 0.4672890883539954, 0.3329133134215109, 0.2470619153351553, 0.23263407420487175, 0.2811734510525581, 0.17410173922056155, 0.1648284287582482, 0.11896962420113626, 0.23492386504527063, 0.2091923506269532, 0.17085867453246348, 0.10913796587696961, 0.18840761915329965, 0.21259025700630682, 0.15916921468752046, 0.18987274698672757, 0.1239509960155814, 0.08439917883445179, 0.13625279759928105, 0.13154645901053183, 0.125916616750821, 0.10564265141804373, 0.1339017503684567, 0.10543942361349061, 0.23546026448809335, 0.1433509392964263, 0.07606195120681679, 0.3532297200252933, 0.07778026343834016, 0.08155003655701876, 0.20096632832240677, 0.21943145281364843, 0.1437951783619581, 0.17810719928914504, 0.20124844786140228, 0.31574721357995467, 0.2216717390523803, 0.2982347807095897, 0.13558305289235809, 0.1284021353949943, 0.2664759010076523, 0.13989911564896185, 0.10818698263216404, 0.12020489501376307, 0.1053298730403185, 0.24951155808183456, 0.10720714851613007, 0.2882330125618366, 0.2277336855449023, 0.11368856645159184, 0.21063615057256915, 0.3588099351092693, 0.15281480646902515, 0.09807773234863436, 0.15357395363671167, 0.18956664889570207, 0.2463237896201111, 0.2371533034789947, 0.22178030903300933, 0.161545067845333, 0.14476965752340135, 0.10947290717834428, 0.3703104163850508, 0.1289637314696466], [0.07476757671083174, 0.09331048976990486, 0.02943043972575857, 0.009179413938263973, 0.03621905508841719, 0.03447302196535372, 0.06703500696007283, 0.09871500258844706, 0.035223389765427965, 0.12802076150452898, 0.08234905094028482, 0.07681392779153201, 0.03654028724638685, 0.07725604479351351, 0.055678063748224135, 0.026540156611571872, 0.12619354221368992, 0.03013456262828362, 0.05242711984582486, 0.1096938699183445, 0.10115128476172687, 0.024614037284927986, 0.03873319860788123, 0.03827534999037462, 0.01582844329306916, 0.05814483622089029, 0.023530720012082208, 0.0438516503650575, 0.049557139976851405, 0.01083079785589249, 0.08887351535621191, 0.07260546974477268, 0.04945794691241557, 0.016078950213869254, 0.04632917871218055, 0.04759607363432165, 0.06155155644181275, 0.04261244186049989, 0.043855120743354487, 0.04207276356136126, 0.08598986847866928, 0.0566967883177342, 0.07151743337031334, 0.043298312718228954, 0.06368758577492929, 0.042460055481041634, 0.012980582297689492, 0.039861006436929594, 0.01221546826268276, 0.06746570925198256, 0.04009079450981752, 0.043031465142003955, 0.01661781645980814, 0.037699937520007935, 0.033545703176529176, 0.052889683734505415, 0.09410322223219181, 0.026385929705875538, 0.08816851528301355, 0.06811580380364772, 0.07695866478306633, 0.051203642956792354, 0.13531755746131943, 0.04015263312706544, 0.06883080132425794, 0.06814860768856541, 0.06674278272135604, 0.08812742232675515, 0.03541495771177354, 0.15566684455881197, 0.16870990515716616, 0.23845364579990988, 1.4889429942254098, 4.116497097476836, 7.004011186861224, 8.058446270804252, 16.957728093670262, 23.633676651985418, 36.64197414152084, 48.4812484248992, 57.06570463795816, 59.75007280226677, 60.08709069221251, 72.0204665583949, 84.55691076094105, 82.86408639723255, 65.18554433699578, 50.08661962324574, 49.76115311345747, 27.2585173960655, 17.121387027925064, 21.006726103444255, 39.82566787350563, 27.79590564389383, 17.352628400248868, 33.04145797606438, 44.46243109241609, 45.57051635557606, 56.82971915891094, 53.07964301878407, 50.99170261813749, 54.073053867586204, 41.767131282437234, 32.778437560604466, 23.233267376499793, 15.867065998815722, 8.913104745649523, 1.8187732634044464, 2.070867794175302, 0.5623670042522493, 0.2724113663838756, 0.054149139942901756, 0.039502906297603925, 0.05970640686310588, 0.157518892759277, 0.03625277827884402, 0.011914054799314228, 0.127510508642562, 0.13041209729929126, 0.08737639569106602, 0.033420126043981126, 0.024444475214207367, 0.09584850841952909, 0.044987774078523925, 0.03114810269776612, 0.07181612339111106, 0.03790507671393214, 0.0460849077470841, 0.025045427140749754, 0.1041992115337522, 0.024257787247939457, 0.043218379104209524, 0.025340309704563795, 0.008607490998392385, 0.022800982959808844, 0.0776053425825892, 0.017386865313915957, 0.03295610658824444, 0.099184614486031, 0.08243410202163844, 0.060172674786900325, 0.11399763696376355, 0.038120604060109586, 0.02271411241963506, 0.03127506453423731, 0.0663500554078529, 0.01943297124648046, 0.01595692198363043, 0.018504683356431705, 0.05395319763450854, 0.06443184019336778, 0.04104353209596969, 0.09937270439320034, 0.07647560038153203, 0.043687745853657686, 0.03766824446258046, 0.07318019656644714, 0.06981987446065872, 0.004917089376718768, 0.061441519402808724, 0.0202470526639973, 0.053597966494459304, 0.10684446717101721, 0.06561281069392158, 0.06521908746611688, 0.04544048990693785, 0.03186462473334565, 0.05992212190082478, 0.028573576128110293, 0.037624221220011675, 0.07470694851250419, 0.14250893205884965, 0.05597244069400815, 0.01671360617864036, 0.07992941585759963, 0.10263440033961689, 0.1830169495435492, 0.15817460273542713, 0.018980301383341995, 0.0372945927383919, 0.03096491192287255, 0.011150046803748176, 0.04464401127470117, 0.003489547971478333, 0.09393049238790428, 0.04998865049152125, 0.06495653381270748, 0.021653634143031893, 0.07501255630725816, 0.14404499963406595, 0.15128119037516657, 0.06334139447238657, 0.06109161257383324, 0.06747880935548775, 0.07963451797202711, 0.039329134573739384, 0.0698362457596006, 0.053612372777875394, 0.12091472910176362, 0.05790961658461921, 0.017131007268964764, 0.10845557305841677, 0.03858779128941317, 0.10653101463591862, 0.057861314740993326, 0.031492713943965016, 0.04668277425451144, 0.04031048937430305, 0.07057156759284197, 0.02617905723802265, 0.050795724119750724, 0.02690269431519893, 0.03387917358908923, 0.030808061166035555, 0.03556036503024159, 0.06258907314810543, 0.0572813670301149, 0.03647115547209978, 0.007811295818687687, 0.06742591098431619, 0.056416066889200485, 0.046882527850327954, 0.025900693445075906, 0.031947988506046035, 0.019767167527348768, 0.046425617690528595, 0.08450342041830863, 0.03302091762663857, 0.05910437666781007, 0.10968855326814998, 0.043906605682305755, 0.046891517892119386, 0.11516942207010523, 0.019813186428960294, 0.03562419164565302, 0.12333699186602909, 0.05492178174937445, 0.0646548254054881, 0.07701370053954663, 0.07335377676833062, 0.027259654898737228, 0.0966912204579961, 0.059502255922604, 0.08271574658612091, 0.045938987149706775, 0.11083350997538337, 0.5158309626483149, 2.0697511444168706, 3.667188123349221, 8.791961362284999, 11.611472829695671, 14.60323126085343, 29.71976741667717, 41.480986533626435, 56.44890408362112, 64.97435608217793, 68.95832707805019, 73.8483851955783, 75.10175504992085, 87.3030327212426, 93.5035547133415, 85.9435627537389, 75.95305842737999, 59.79174014060729, 65.06932843116023, 48.34974312013196, 33.00066532627229, 39.84911188002556, 51.96538786734305, 45.23228645324708, 42.58507097921064, 49.700842749687936, 54.97228076381069, 58.67756343656971, 71.55937625515845, 80.87331095049458, 66.12921560964277, 63.40013242536976, 57.88746864564958, 44.569723606109626, 35.837735283759336, 27.40862258018986, 19.833717769192113, 9.206590210237811, 5.651146981023974, 2.9437334210641923, 1.1578070660752635, 0.46111742274895795, 0.12243157553095972, 0.08037879537310332, 0.18992122503057604, 0.04075696541657371, 0.12533922394317004, 0.06688280827215602, 0.08721242223175303, 0.03452051558621949, 0.038769982319565556, 0.007024781596321132, 0.03605469475470243, 0.021631676147902207, 0.08295335641671574, 0.037555464828807505, 0.032936563685296044, 0.06875205514652115, 0.04837434618703781, 0.06651643438324814, 0.10061881534995572, 0.08267123687772021, 0.052285991128413915, 0.04237032743291028, 0.0440147313319387, 0.042594461776917024, 0.023502470519874367, 0.012434059002947424, 0.014834818636788236, 0.04174450637712594, 0.12059827350200185, 0.038854929979049393, 0.020859679770505717, 0.04063934793755893, 0.04026568472205151, 0.0827952818344197, 0.05645403420672782, 0.02819403893344345, 0.03317956294443819, 0.06890518080082632, 0.04972620792086086, 0.035357393865143104, 0.013181815400809772, 0.07178597783129062, 0.03442232609696446, 0.018985719540186467, 0.04307636172480641, 0.10486606808920061, 0.02640429857907997, 0.02279007195254728, 0.040405725594609976, 0.04722642088909784, 0.0279386003216308, 0.0714996371478323, 0.070330640601535, 0.06259009587548434, 0.08165655342201072, 0.043269113276995, 0.0631438663619901, 0.05194150437150271, 0.06845005562589054, 0.039332896065447605, 0.07325249994474073, 0.011470952416740118, 0.023617782074237065, 0.0704048055734846, 0.2781364640160915, 0.19822788575003225, 0.1183025454801898, 0.16053373985473188, 0.17252808737178005, 0.15105824346744245, 0.13814583150369508, 0.2155744605847905, 0.14392403435082207, 0.1906849993693252, 0.49729080750576915, 0.21813107984921626, 0.1339889464959983, 0.30209491389893717, 0.15634193655944642, 0.17256030902987526, 0.14474878928834392, 0.15366700267599476, 0.11919940461314495, 0.1329837625305499, 0.2256208763367707, 0.20297534793855684, 0.3759068112459875, 0.23882113817718723, 0.2442498210697405, 0.16785375593650728, 0.16685856175759148, 0.21663849542458213, 0.18853550987137904, 0.13203513117567187, 0.19595833495259288, 0.08975977183229501, 0.16873311762127186, 0.05433018184116772, 0.13757558629637764, 0.13912257828539418, 0.13818589790213492, 0.0897188397545007, 0.19740786523588244, 0.1305863516585481, 0.24621036264204213, 0.20596469962789168, 0.1409612199471843, 0.1498830952351132, 0.10744775375050884, 0.17190302091260112, 0.13246173489718668, 0.09946912421935028, 0.10750404589118497, 0.11680593143307394, 0.14613430526468063, 0.14303704243033163, 0.21017556319073324, 0.20805952109156117, 0.1434372007967003, 0.20578359644259178, 0.16333878611124333, 0.2069317324147109, 0.17877167331114893, 0.23390073930063557, 0.1467311950100045, 0.1493430645355294, 0.33197687818638744, 0.1968039887686891, 0.19339587809818407, 0.21817690722884672, 0.21731691224680794, 0.18042898196126186, 0.14765557202119983, 0.2002996632889394, 0.20882403087471763, 1.2589191501179051, 2.777517591753314, 5.293449865233514, 9.479873507253586, 12.943815685087635, 25.457463072192287, 35.55879200658491, 55.17731481982816, 68.88350394464308, 79.83829159890452, 87.11787331488826, 89.79185504298057, 101.67163172075826, 116.10392216713198, 108.07188864677184, 91.87287638264318, 81.30442650087419, 81.83371897666686, 62.38140267710533, 40.94237450630435, 46.54862996070616, 69.2936897277832, 55.445836359454745, 47.49492137662826, 61.49972446503178, 82.43442996855705, 82.47013138186547, 91.38665937608289, 106.52436456372662, 82.00663274334323, 75.3274796085973, 63.98914298703594, 47.67917863784298, 32.49137889954352, 23.584707821569136, 15.72914565763166, 5.947182476520539, 3.88163268085449, 2.179909439817552, 0.6609817029487702, 0.4113281121657741, 0.33537659253324237, 0.19339854408416057, 0.39098737460951655, 0.28654740462380074, 0.4657647572457791, 0.2577135099038001, 0.24824757429380573, 0.16234302502726355, 0.12139049268537953, 0.07405854701515167, 0.1616582649970247, 0.17646879768900334, 0.24537834519099808, 0.1501136877003216, 0.086247572795518, 0.1598469726741314, 0.16078182976813088, 0.15824263134310323, 0.17926602984868711, 0.132031285414292, 0.14902846286854438, 0.10746299890020203, 0.13044585113323506, 0.19351174123585227, 0.22215259712069269, 0.10034395832448237, 0.1407170677257161, 0.21398663610940982, 0.3239673063639672, 0.22209521713516406, 0.15087821280523656, 0.12754733448908215, 0.11951048227567827, 0.13276832328448374, 0.2068190102375323, 0.12317059756887537, 0.11288268792052424, 0.22879251098680883, 0.21065006272927408, 0.14091209838947943, 0.18080716892596216, 0.30045652762055397, 0.1556340100303773, 0.08091010033122956, 0.15021715553537493, 0.19798442300769592, 0.12211672105495969, 0.09583970606927911, 0.12167689465587178, 0.21575505815206036, 0.19093744066213408, 0.18054973273988695, 0.17978274083185583, 0.16883598790774423, 0.275024798728766, 0.15412792713651735, 0.22655167316477146, 0.34979427533764995, 0.1566151541567618, 0.24719133822908326, 0.18762297657949312, 0.1017369972842355, 0.10062994660749551, 0.2568665690599911], [0.17507604984266145, 0.08815093356515132, 0.06577384237560534, 0.07489500777615656, 0.10021632807629724, 0.024605319204349673, 0.06975360785520847, 0.18830272639470716, 0.15274100155839998, 0.11343927378015173, 0.020733480191519185, 0.06705517039423989, 0.22966562139411129, 0.18890116363763812, 0.06047632139656813, 0.09371526764645692, 0.07395243617675959, 0.01014091173983029, 0.03701384449678083, 0.009254449377617529, 0.10477656603700693, 0.006259604837865599, 0.060849046154368314, 0.10315948466379797, 0.05924988357770828, 0.033240987874207, 0.054273770956863324, 0.05281608949805941, 0.034652324844031565, 0.07822290904098943, 0.0029491303974927795, 0.04064481397489867, 0.025312868435116067, 0.061606898633462776, 0.08363212563938673, 0.02357092047590883, 0.045071044005453594, 0.0787364867245478, 0.07407867214492253, 0.06071167892866558, 0.1019906183524478, 0.08640278220897721, 0.06908777019669933, 0.12298728805035354, 0.016081474473579757, 0.019363471749989737, 0.04892002678506317, 0.030801394285874504, 0.008013825525619812, 0.06555860997327874, 0.0734042619625407, 0.045635466944546475, 0.013796724491722643, 0.01805792194640925, 0.044092496917132414, 0.04418715857149613, 0.05091676218134742, 0.029534865170717243, 0.021944035092488896, 0.05403225407785466, 0.10249861125503817, 0.03158942296830637, 0.03899932223101778, 0.025585488483850515, 0.05762227615641971, 0.05737957950200766, 0.026662309331098394, 0.0837290893879629, 0.07801624150165627, 0.033326203664464336, 0.1482860317393657, 0.030537739381073948, 0.09423707311432208, 0.2510897911364033, 0.23685460579731774, 1.1065288176459651, 2.3336043280939904, 3.7787817610848338, 10.325238416271826, 17.121824372199274, 30.083329946764056, 38.05970699556413, 34.11088828117617, 35.200224614912464, 54.3127969772585, 82.40181938294442, 78.8998959141393, 81.63028917004986, 56.66169266546927, 57.27706547706359, 56.873018203243134, 43.64742925090175, 53.771972733159224, 36.8731233381456, 39.551482431350216, 42.67373223458567, 65.17387136336296, 56.166736618165054, 33.15006056139546, 36.179648291680124, 25.64151833134313, 18.20381999015808, 11.055206214227985, 8.132263806558425, 4.3128264334894, 1.857461193876882, 1.2621211524932616, 0.6337405969538997, 0.1766639202833176, 0.2956060266062137, 0.12099729039736333, 0.06322558113043347, 0.0539452264896564, 0.09205730016072912, 0.038654693747840585, 0.16103719751681053, 0.09110490731414288, 0.022251019930286754, 0.00812906047119008, 0.044719424969967336, 0.09856655007048, 0.01076435409260974, 0.10026787047184284, 0.06039845238950464, 0.03154751795884823, 0.05798204636742031, 0.047983265962571874, 0.06517345160846749, 0.010164503417458507, 0.11446038471354593, 0.12808271503496554, 0.09418592908449712, 0.0971228497162942, 0.06560675093844053, 0.10100261007826175, 0.02245563818442245, 0.05636722112314836, 0.04551789926124677, 0.06060408954057963, 0.02610091052408661, 0.023430050313172322, 0.07547858291335645, 0.07736149679629073, 0.04616088068653499, 0.06383663967191693, 0.028406477030066234, 0.06044956960625226, 0.06761253766355015, 0.034217102633368586, 0.021299981144106677, 0.05091737888212647, 0.04194173188279233, 0.058801113102104396, 0.05174681461686569, 0.03752707361033367, 0.08249117557199732, 0.0855570441232093, 0.05331107039725589, 0.05031388545889528, 0.04558574783826067, 0.05364799203591482, 0.053173975132766275, 0.11609737671190694, 0.09907001539343789, 0.07253346514076957, 0.027734315315742167, 0.04925051711559777, 0.04112658751828056, 0.017053827741033128, 0.09147309683143132, 0.1099095160081502, 0.121171981426737, 0.027538413226964976, 0.06157768004003072, 0.09131327556866793, 0.1665299560033506, 0.1172854641692773, 0.025101322830925067, 0.0940367870873982, 0.022272974094976822, 0.13488674025622108, 0.06563596187099334, 0.1018478348851204, 0.15116652233466027, 0.12282511489766261, 0.09617824032301865, 0.046995709680261157, 0.053283510384179895, 0.0804314639178976, 0.23687173552330465, 0.10617250080911383, 0.05481149573179503, 0.12572062847715232, 0.006344143597919855, 0.11085960293008436, 0.1406614037771379, 0.08029957422085347, 0.0070773716171031766, 0.04424500587065855, 0.0784195791329107, 0.03214245609518501, 0.11078739914322093, 0.02089770262940757, 0.1006396452806169, 0.023058091643296426, 0.06025425165951733, 0.016085898631342476, 0.04038506420329213, 0.04433213688072659, 0.020878247826570467, 0.03608197514568606, 0.05303323712019671, 0.03520885707750436, 0.10744311891856695, 0.05788243578506574, 0.01904808292766252, 0.08973043832567432, 0.026042061564963193, 0.038366564249079076, 0.03919028496790317, 0.024601935010944164, 0.05739659814524555, 0.031816828507749785, 0.02267388322751128, 0.006552560690550074, 0.07384069459212404, 0.048795185096922426, 0.03909100380335604, 0.06710321176797152, 0.027098414458094106, 0.05136423413791964, 0.10182141251261197, 0.0346619239257228, 0.0886233646662966, 0.07842383092089046, 0.03133258624603191, 0.035161773313678084, 0.06074132270089561, 0.0487947867312018, 0.021796672334594112, 0.056393689460932254, 0.037400305211063356, 0.08559950071597293, 0.04843801575442476, 0.05273004250240423, 0.014130977271575362, 0.08481730196264484, 0.12068104164134111, 0.7071237302114888, 1.1789649436550758, 2.1281542556901134, 3.4596533111987577, 8.514770403985056, 12.984032727056935, 25.71831637813199, 35.498148241350734, 46.90108629965013, 56.57220771235805, 53.050021279242735, 51.01377379509711, 73.49486197194746, 98.85016887418686, 95.32641349300262, 89.93132668156778, 68.55857479956843, 68.64375299023044, 59.31239512658889, 56.944291591644294, 64.4215254629812, 52.06310195307578, 55.37436685254497, 60.699094187828806, 81.9605213595975, 74.26501935528171, 56.21512297661074, 50.29925523265716, 33.593421751453036, 30.679606699174453, 19.34381569585493, 13.978668335945377, 9.261541635759416, 5.33248088052196, 3.9208490281335773, 1.6123000652559343, 0.6623292209640627, 0.3518115074163483, 0.0808065712091423, 0.03178343090469078, 0.09310746114821204, 0.08319049127279751, 0.05656636567906507, 0.04292379148424633, 0.04309615743676982, 0.044335454041438724, 0.015475278675195672, 0.03698157687341014, 0.06607595680942459, 0.09232844165976971, 0.05484475543902767, 0.037111597315919016, 0.05321952672074399, 0.009786929323097632, 0.07452527076126107, 0.02208509869242628, 0.035899906689601566, 0.14525544919794606, 0.04106947949396507, 0.0280372322266621, 0.024831860979658463, 0.03900797902456215, 0.022177598063623714, 0.12383987496216452, 0.037069021979527134, 0.055128648471567905, 0.03680052731426493, 0.048866389139044675, 0.04398674230962511, 0.08073737814782128, 0.04465536086729938, 0.06433758839604355, 0.07345792642163654, 0.05875695196370925, 0.038819808678160754, 0.059141623862688585, 0.050306090514265725, 0.03721423394557449, 0.05647100305425064, 0.14944832501632555, 0.04467640530257937, 0.0755574286825234, 0.02992755609504398, 0.004489229749813075, 0.12075356718513275, 0.03239523829712022, 0.06769575779476474, 0.045052098651086135, 0.031338033131173545, 0.07214926438586367, 0.07533983672939001, 0.08922945512759109, 0.10894582336468082, 0.04115330483463984, 0.04153480896005227, 0.04790981345239186, 0.010347358071275297, 0.05245901208611266, 0.07846742898466126, 0.13048139761292166, 0.04093303157377147, 0.014619360238523975, 0.041480788270071636, 0.06787139111228528, 0.2389204078504155, 0.1828329505458955, 0.13769250663538135, 0.14860726772777497, 0.15351923963715955, 0.20770681421122245, 0.15118881549325683, 0.3210334347621087, 0.1396302187875394, 0.27826007996355334, 0.20310896899430983, 0.26137819874190515, 0.265815042920651, 0.20920436288560593, 0.18075107596814635, 0.19412556152430274, 0.2032543571605798, 0.09624538792958183, 0.24300532655850535, 0.36470485911253964, 0.31967323033079026, 0.16866927185366232, 0.26697615642220746, 0.33594172027322555, 0.18166829771812887, 0.11006399763808136, 0.18520226131283468, 0.1981782279307804, 0.1262218721451298, 0.13386232748387322, 0.1129477364461749, 0.14205168482036362, 0.138478635419761, 0.16457827040745368, 0.2565920644349629, 0.14510926430023488, 0.12272429006594805, 0.22615782736289888, 0.1390412350695941, 0.10726829765424614, 0.21858679491185376, 0.14993370300339115, 0.1722139147140326, 0.24946838136642213, 0.1249900563890415, 0.1913058370231621, 0.21367728980558537, 0.0517059744696223, 0.10330684933691256, 0.28587579066234253, 0.18810484588386553, 0.173799394960365, 0.15914658445023722, 0.10621125719720319, 0.19985882565379146, 0.13531979443805833, 0.21062873484146213, 0.21515807647618557, 0.1549839997483838, 0.12210990287243359, 0.12968543225959425, 0.1410487225098956, 0.10266086867740078, 0.09337391418915603, 0.2948640551297896, 0.18855149046547953, 0.27069189735958654, 0.08652820612394041, 0.16801515534039468, 0.2422677677485251, 0.2699114376258466, 0.17882411969044518, 0.3416312101387209, 0.5826747693842458, 0.8827208270949702, 1.7990890938428141, 5.126861410756265, 7.700092158009929, 17.267005020572295, 26.543659548605643, 40.76806437584662, 55.606292678463845, 60.76971646278136, 60.739153354398674, 84.32291784594136, 114.32266404551845, 116.63194379498883, 115.54695344740345, 95.22550659794962, 102.62101004200598, 102.67577417435186, 84.58779550367787, 91.36841251004128, 70.36653641731509, 65.92812353564848, 85.3087506755706, 114.7318692361155, 96.23736827604233, 82.10912427594586, 63.23784828186036, 34.062768643902196, 29.71132843725143, 16.373990178108215, 10.892458250445705, 6.707356447173703, 2.6104839482615074, 2.7111905572875856, 0.9355782585278635, 0.35722615557812876, 0.3853861687164153, 0.38101707735369283, 0.24824840166876394, 0.19270048476755622, 0.24639952507230545, 0.2609037451686398, 0.25040754387455605, 0.1829393295150611, 0.19743435655630406, 0.1250865068587084, 0.08891480749533062, 0.23272119372362093, 0.18190308834516233, 0.26893341913819313, 0.1468365167778346, 0.17807946690628607, 0.14754312563567393, 0.20553068017526982, 0.09636231592946476, 0.1831365971555633, 0.35838968991752596, 0.31963759192055274, 0.1510389380517506, 0.14958370807430438, 0.14073697068998892, 0.13952025452688818, 0.24623542903892456, 0.23473145440220836, 0.12443635868088854, 0.16036929142090584, 0.10030673411224159, 0.19819733416361196, 0.19432379443558956, 0.273101918038822, 0.20334523051015793, 0.17937623925747412, 0.26891392986139945, 0.11785086004003403, 0.215170931431555, 0.19625337073399177, 0.09125949619638343, 0.17039169797733908, 0.21115208014605508, 0.19028015254485994, 0.28739390113661367, 0.22289974735148493, 0.14260334473463798, 0.20782433209880707, 0.11313630898873653, 0.17383140211384143, 0.12302517875908844, 0.18997776231938795, 0.36272593143005527, 0.2343754533437952, 0.34862335591066274, 0.17112193298676323, 0.08092127755404481, 0.13334955419263533, 0.1584840409698025, 0.1421463579660462, 0.21699302559418066, 0.10520531480470974, 0.2901125020317493, 0.2277640073049453, 0.19276252256766443, 0.24055142436296711, 0.20548952593197747], [0.13168749579739186, 0.0833795541116307, 0.09126653654440757, 0.017142318557166768, 0.02732157778565682, 0.011203316727563018, 0.07225548247656516, 0.15066496457063383, 0.01246577217018292, 0.05098526576353658, 0.1060473373640449, 0.10195075113686825, 0.09460647305053088, 0.06332222695252107, 0.21680968543214185, 0.0896802519057547, 0.03414167744678355, 0.0009013558895188204, 0.02959596259789842, 0.04758757388880176, 0.047680718689075405, 0.05143236233702591, 0.029725711079194184, 0.08261212553348272, 0.023017747537984003, 0.05087993633482726, 0.05828317254781724, 0.09638293901638639, 0.037790902800137, 0.01918533524017661, 0.027879916071411104, 0.02619550706097676, 0.07898942597450749, 0.06880967261930628, 0.0441443074434515, 0.03958663587728816, 0.003639065830465106, 0.06333600504383927, 0.03358137223028368, 0.06816330125495311, 0.009672639538503943, 0.011837770636644096, 0.017070988110537012, 0.028377624243618022, 0.05211399289809408, 0.056726757677332054, 0.06204248856632941, 0.021008034612262444, 0.05378754261220175, 0.04793808975767705, 0.04802258542528556, 0.02336811976537349, 0.04482849673818677, 0.01744398865998993, 0.043379418446772525, 0.015006273902291733, 0.027041379212131424, 0.07176548497931612, 0.04666602374204705, 0.06264802744431842, 0.09305794122478656, 0.0806285860016942, 0.04204270993209174, 0.027080225615551876, 0.06904146784255583, 0.0772966321317419, 0.07748656831080876, 0.052030673175449335, 0.04861913426148315, 0.12919695927731453, 0.015531898318459431, 0.03299417349720194, 0.09166728479847794, 0.044081105189698364, 0.03199823621299959, 0.02602894997013913, 0.11251649789271817, 0.10137168059666311, 0.2548306137924233, 1.082886118561991, 4.319918569057219, 7.20334162635188, 7.732991528126502, 8.157710183051325, 10.751974640354033, 7.692794588304336, 31.17044229661265, 53.414872307931226, 66.29357076460316, 46.36954630574873, 55.17764429892264, 56.79014244387227, 57.71681416419245, 63.964283004883804, 57.354712716994754, 59.47198067941974, 51.68738595900997, 35.18299364274548, 12.519318153781276, 4.220892450501842, 2.145844880611666, 0.7100902065154046, 0.23375705184955753, 0.23284919169400972, 0.1367871132829497, 0.11088957995056145, 0.10157794977027564, 0.1377960510792271, 0.10678573120986262, 0.04133233192166494, 0.039691210709392064, 0.14050239456757424, 0.034820772256822355, 0.031862602261225545, 0.049573683645576246, 0.043166660508441354, 0.007233494590412105, 0.036764505860065265, 0.03480299901697905, 0.047135386661055594, 0.033570784895170125, 0.04743334889832524, 0.029401991050690416, 0.05782984001862426, 0.0511859501561811, 0.03001965518530098, 0.11363936828509455, 0.03656773617671382, 0.019438898851794582, 0.021511113060818567, 0.03297771409814877, 0.04436185726174905, 0.025907622710351023, 0.04908818308444274, 0.038590319379563295, 0.02417437176430418, 0.10560958706323179, 0.024270646033748507, 0.1255695559384842, 0.062420667870150465, 0.06075586688013808, 0.053849806408247644, 0.031718165959201516, 0.01975404061076622, 0.03848836839860005, 0.06638452170356628, 0.024915224752358855, 0.08144468414567171, 0.029965195909983693, 0.04016732286301352, 0.008333660530737572, 0.05681426407048299, 0.07179331695360523, 0.08062618814649121, 0.04050185430734869, 0.01939751095168533, 0.05340315799619402, 0.12639166021178808, 0.04067490590856441, 0.004598064030775981, 0.03566591279400933, 0.02918993599802977, 0.07822998003253052, 0.10124630264697537, 0.08928521866759948, 0.024238384156037244, 0.06495929939011413, 0.03572100217664435, 0.007305874098693171, 0.05220826384761641, 0.09014267023772964, 0.13980816569059126, 0.08475034587806271, 0.027319848342167757, 0.05794290693536882, 0.08041120855317963, 0.1415319094854978, 0.04177326148736381, 0.0957195068739595, 0.03402505588207034, 0.05491957541615252, 0.07839150967136507, 0.10375593007812578, 0.0984142977564085, 0.062122563906614824, 0.04881472799987082, 0.06423210574974937, 0.02315129773060401, 0.07166356464186985, 0.06624849513173103, 0.15110996972408988, 0.0854289542222696, 0.09904112621781327, 0.07270656270726074, 0.04588151906406687, 0.06502214158254285, 0.07655536545620811, 0.03670794941905526, 0.1024633022626081, 0.06648240475765159, 0.03925619917290826, 0.07374782175306352, 0.10309518690431312, 0.032308145591448394, 0.06194077507262269, 0.043908191484309016, 0.032726092519418847, 0.04405926402297713, 0.07156586544888635, 0.038231962600782994, 0.03159023885194573, 0.034846627724266825, 0.03801380757302527, 0.0270789232660806, 0.013971640559424077, 0.02081087422406962, 0.023698424319586447, 0.03786515204175826, 0.05410116368664369, 0.05396560442844226, 0.020163543334591295, 0.046872327389616164, 0.020312114596186627, 0.03261896278408747, 0.02604879930825724, 0.055930677410816, 0.028435211072886185, 0.07165552837954414, 0.02783664167978831, 0.09027891897506292, 0.0842791788219925, 0.051904176737392144, 0.009077675546699715, 0.048013760092397856, 0.04568099554988646, 0.08154065964082557, 0.06981012216138263, 0.03411252397082506, 0.024067812764476386, 0.02946687103699773, 0.04034380653813001, 0.08220816737100964, 0.10283262559002447, 0.04115423563146784, 0.02025661727173194, 0.038094733270906636, 0.04137415649189104, 0.04924126277347246, 0.050551322919707146, 0.09726914952719405, 0.16520730520208038, 0.16616966485256152, 0.38473640358255756, 0.4171743436205772, 1.963933564482197, 4.35381422119756, 8.686019124523286, 13.776446619341451, 13.371998283170885, 16.042992145784442, 16.487180955948368, 16.24694755000453, 40.523029988811864, 66.12494807089529, 80.45648067228257, 66.06896015905565, 73.82536872740715, 73.87679884510656, 81.03137462369858, 79.60047829535701, 73.78367393247544, 78.19699933451992, 70.35275320852958, 51.99320531660511, 23.948907736809026, 10.15956828671117, 4.582811507486529, 2.4162950006223496, 1.0664998042968012, 0.9136232817845961, 0.38185992728798623, 0.27909916074525926, 0.15742598161582025, 0.16320029273629189, 0.0268932925011482, 0.14832217576763324, 0.02995323536226586, 0.04174117389465532, 0.043790600818371585, 0.07249374348189562, 0.053932287264615304, 0.009637725081354862, 0.028197465261684793, 0.037144282457208445, 0.03438705923937021, 0.07142832968384027, 0.04093362529191279, 0.024688529759465207, 0.05745559074585477, 0.038280563218699354, 0.02921129835979833, 0.014520777171597847, 0.07501532188466481, 0.08664085169232662, 0.031049378862183903, 0.060685382960664655, 0.01526320638555673, 0.04640270783115299, 0.08300550402172151, 0.07400234680502646, 0.02560560595274212, 0.039356556690989, 0.028677158876352256, 0.04857067536983279, 0.05320899684222476, 0.06148217568895029, 0.03327853001293636, 0.029375492069389553, 0.021075222438441652, 0.038774019602926514, 0.036522376110717174, 0.046596708106658155, 0.08986598226211726, 0.05288709435732134, 0.016077728303630027, 0.023926954093058745, 0.018838157599431374, 0.04508108741814091, 0.025120074748091643, 0.05176682866388752, 0.04034602819311042, 0.018582067812883088, 0.055900784660010576, 0.055558875788964575, 0.07329673386148869, 0.012026475329372672, 0.047467619841617924, 0.044038345992204644, 0.08202953098882591, 0.11133183484836934, 0.03670102398421976, 0.1157569119165982, 0.05258178150641823, 0.034582695112593716, 0.040134990122169256, 0.07184973932922849, 0.044798868287715225, 0.0361644521716141, 0.009278684569102143, 0.009123941511666823, 0.025626891705718254, 0.08374693923659864, 0.17180566645918355, 0.12687909897537003, 0.2229701661534848, 0.14119657747928174, 0.12801801890976008, 0.24017608724534514, 0.18249113743584003, 0.10761114498299938, 0.11873137085668503, 0.14450716515702589, 0.1969284627346262, 0.10805998057607683, 0.14135763980448246, 0.1174913349771692, 0.2788230013703146, 0.20627645144779838, 0.1736894153779553, 0.13452536126057948, 0.21845283677741406, 0.1770807334011601, 0.16536963923323542, 0.11013267742049311, 0.1811772200369066, 0.2749077711374529, 0.0908146519213915, 0.2627792203378293, 0.24709148632903255, 0.10227653768754776, 0.18814541790033543, 0.15231419865402485, 0.15542143595314797, 0.1201795221817109, 0.15645436762321382, 0.13594095384882343, 0.09064428162791076, 0.10208711478739016, 0.1362372153709012, 0.12763576401818183, 0.2065671971368213, 0.2805724091106846, 0.09035597209848704, 0.10608364227077655, 0.15122825369959877, 0.11500637557718063, 0.12101437415807478, 0.13817140351860754, 0.14731873848265217, 0.18906624026356206, 0.18710473342047584, 0.19400651146086956, 0.17375198943961054, 0.09948548019653368, 0.12531103190755652, 0.16798550773772503, 0.1463141673875432, 0.18948050996949597, 0.168029174749409, 0.19741485195775188, 0.07089464985314878, 0.1846702285711804, 0.17364089136883137, 0.10234389979872974, 0.1382551369287314, 0.14718167003123991, 0.16816936883955233, 0.11408016761584629, 0.1434544684185136, 0.14284763485193253, 0.10070872342874927, 0.22315195881791655, 0.07399349848950103, 0.17177180537293035, 0.32964257763758786, 0.1283948728814721, 0.27931391051219356, 0.12123212698967227, 0.25598161493337923, 0.2667661870439207, 0.6753498351862354, 1.6781558024306453, 4.625330980746977, 9.103476981962881, 11.37338888260626, 14.974028602723154, 15.877159237861635, 20.299763987141272, 46.11669855733072, 86.11875149511522, 106.12221963943975, 99.21113675640476, 109.35706892321187, 106.67967473306965, 99.63552936430901, 108.8493416386266, 101.22233206225981, 103.37074756622316, 92.67731528128348, 77.02894103142523, 30.58706818088409, 7.1312386566592805, 4.144046844974641, 1.542987616792802, 0.9746024709555411, 0.7575723973493423, 0.6569784338916502, 0.2722135624818264, 0.17611665771372859, 0.18095966638816943, 0.286623768268093, 0.2679547264931664, 0.20171078192370556, 0.318456529489448, 0.18406803749742048, 0.13245932938110444, 0.27536858834566613, 0.1397633035817454, 0.11849928452002427, 0.1198617565715986, 0.18745098984049213, 0.135796622883889, 0.0979798416336698, 0.14020139862212444, 0.18487776178986798, 0.17231520685938098, 0.0936092027733403, 0.12860121866387705, 0.21395275970139813, 0.12153084765398696, 0.15563074649581987, 0.13463785361138084, 0.09781156276022235, 0.11064280770839223, 0.1538463745025858, 0.18752456492474004, 0.20703443416183998, 0.12573525309562683, 0.17889014114775967, 0.2397326755547716, 0.22567510004005126, 0.16369428155162644, 0.16218282072053802, 0.2120481272258105, 0.10796290957519125, 0.1434736052948621, 0.11561992007397837, 0.23470565256091858, 0.14739859548787917, 0.17294511499424137, 0.09681466020523541, 0.1565198681407398, 0.06126809241851011, 0.2493963231362643, 0.08494284845167592, 0.1942038710319227, 0.1019419564474975, 0.09124651866694612, 0.20774622177404745, 0.21197631414378845, 0.12016827601098246, 0.10195674960531535, 0.11705551521792529, 0.10465478103968406, 0.2349734002904546, 0.24000773176310525, 0.12829564151264009, 0.2492537694953142, 0.11640814793927055, 0.1995490503407294, 0.132606219079706, 0.16205143664152394, 0.22791259771873876, 0.1722036184923303, 0.24026024966470658, 0.18733546378151064, 0.16705556892819945, 0.20348884135244355], [0.10356106029282655, 0.07697622351829084, 0.08270473024176975, 0.01291745282228916, 0.01972289913664422, 0.07527159361709511, 0.03134166630315444, 0.06288004866350563, 0.04888812305345651, 0.04207370967994775, 0.04859249738435592, 0.028646565155096115, 0.02959346898170489, 0.018322168654131315, 0.07219057184674087, 0.039752470930257154, 0.09789243100150939, 0.026275436844556566, 0.03326628409746674, 0.0675213425570438, 0.05829353771743275, 0.019120235003591068, 0.06864387587073349, 0.031281237287687204, 0.05421898800939803, 0.04400406738803272, 0.08275389010387083, 0.000658740631948721, 0.02564129990435416, 0.06689899570999608, 0.03798300317758995, 0.009989689814016945, 0.010060802883198185, 0.04266566581903927, 0.05375378877825795, 0.015779201076516224, 0.05135268919290074, 0.07477846282023577, 0.01900206211083118, 0.06253015715628862, 0.049777757977285696, 0.06294798917107045, 0.09222188649038154, 0.09302388095567304, 0.041503881990549066, 0.03977136265846991, 0.05640757097412021, 0.027117398116857778, 0.07189478529917617, 0.0421831606616897, 0.062083428305002956, 0.025707991688602397, 0.029333621533888004, 0.05049501545727254, 0.015028096874424768, 0.0662454614235509, 0.006437326223784757, 0.021224362520320762, 0.026481254026293758, 0.05145301606746451, 0.03901110083285359, 0.048142868890276844, 0.14087053045870798, 0.040198491150212866, 0.023415293544530872, 0.09902411906589424, 0.0646740848559045, 0.05255248247375412, 0.041186805859568625, 0.04164767286349689, 0.05987187802431084, 0.03805869649494848, 0.04158170886277672, 0.064798666074151, 0.026036792795263955, 0.09483052312486595, 0.06465054297399137, 0.04962242982019821, 0.03358044909433492, 0.0700212866368313, 0.13172880325826908, 0.1424113324572963, 0.08479660992781002, 0.057127188004913836, 0.1294657488864276, 0.11079561160576921, 0.5164179698594156, 2.4770010334830133, 6.35452110921183, 7.924066358996977, 23.30146758787094, 33.49958296745054, 56.886883781802275, 64.72854898821923, 35.518454351732814, 30.20207774254584, 18.128802699427453, 4.907318017175121, 0.5715615915194635, 0.1255630058867316, 0.07757259998470545, 0.13578883943057832, 0.051683570228276715, 0.05434208301707141, 0.03647726885373554, 0.09282937889257747, 0.023949760530564575, 0.04622774101012657, 0.08036636942697149, 0.029658008058885896, 0.0654540466324937, 0.09490733876103356, 0.04160549206238601, 0.014081449687270629, 0.01837290665735641, 0.031093061195626378, 0.046237941470838366, 0.049227408073361845, 0.030466167616748044, 0.05024372712678967, 0.019041293473433585, 0.023467063851233934, 0.01686563441199401, 0.0614883695098181, 0.03311222764633356, 0.020905068564799525, 0.015915324366951904, 0.03967646351684967, 0.018620389446075407, 0.044114736449574275, 0.04580365005700339, 0.06205146328636235, 0.021570513603247462, 0.04579543376401548, 0.07577524280115482, 0.02248118147103777, 0.01128751649371078, 0.04045984204558115, 0.015652835831016062, 0.01231284378351824, 0.06673227199503491, 0.030312097759076187, 0.0937259469121214, 0.024002076674913688, 0.006355250436407064, 0.02871625617356791, 0.0587269826041114, 0.03023773551948609, 0.02630959287466061, 0.03642923514088316, 0.0513932918528876, 0.06317039981724755, 0.047497654318689346, 0.05986144390678214, 0.02747317700977287, 0.0521625513811746, 0.03011500823401636, 0.04716923625598993, 0.05190028118029718, 0.05785774477126618, 0.04576867048238074, 0.07759931347062511, 0.01760554894234144, 0.09282595447955594, 0.024238638880272067, 0.039168769388549754, 0.06926302813113698, 0.06355102677198668, 0.08938000672647069, 0.018604763167639895, 0.07116185366025857, 0.047203932378080585, 0.07324729054685562, 0.0028273746072720258, 0.0231649877218109, 0.14756048518803813, 0.11428099756519641, 0.05019740945088768, 0.044848372889382225, 0.05419798570895388, 0.004569499006104326, 0.12083157025758298, 0.04593923995872179, 0.04878662406436859, 0.0651145164644526, 0.0459030537956184, 0.06573861765284693, 0.033335477158787756, 0.02540317871006987, 0.09930350367100009, 0.16701116647210815, 0.07260308721132817, 0.03310871513320073, 0.01014001350173907, 0.05113566797527094, 0.0867158210565967, 0.07253321999263379, 0.023767263065242482, 0.07502834537937757, 0.025346269868614695, 0.048953987462746526, 0.05080524659264953, 0.08104688533010983, 0.03004876652642364, 0.04916709780152287, 0.024952127207671444, 0.039924040151339386, 0.045509472294079686, 0.009917368241135153, 0.0626077886760956, 0.030007131562958804, 0.021614084853940917, 0.09516307423191686, 0.04328764111344372, 0.028496344889243765, 0.03337607215789538, 0.03663870656201917, 0.041949967327978344, 0.020222262058767582, 0.05267833539795491, 0.056699779891078515, 0.04133471062466983, 0.040440563442966634, 0.020146942209272135, 0.08681874496922379, 0.049663610876567905, 0.061819055192773385, 0.019429922216541825, 0.026539944022172884, 0.04900387893881529, 0.021408034015386816, 0.02166768994122263, 0.04482002763618385, 0.041150075774038994, 0.01937760032653328, 0.029238111437148148, 0.06181758430395877, 0.051600066644530145, 0.0636674338320811, 0.031728511976618926, 0.03983730750699197, 0.06688915148016907, 0.06985438672164757, 0.01719403906815475, 0.07624300842684123, 0.018055445567194014, 0.02185951644224265, 0.03740341552803594, 0.0024266191711273767, 0.09398133764343877, 0.03732728554056056, 0.05471622886797113, 0.04218312618773311, 0.10903388517157686, 0.1984738919042772, 0.07429510730529025, 0.25548941876378756, 0.20364313146039364, 0.3771899165886064, 0.3348345087180215, 0.5878185901430346, 0.13771124514600924, 0.6554546543667394, 2.7681495008930086, 8.782745753565143, 16.487684980515514, 35.76351619535877, 46.65107050249654, 72.71235696731075, 75.12419885204685, 46.54451147202523, 40.112691233235026, 23.10864387019988, 7.805620585718463, 0.965659037953423, 0.1331349423215274, 0.06783834207923183, 0.08583055283393591, 0.027155489923672813, 0.04632830537194687, 0.06161283964531557, 0.0462557376933194, 0.015379884449254363, 0.09597494357055235, 0.09567118970857513, 0.023083091007485505, 0.0398206144511219, 0.059157845774485227, 0.06152784602055627, 0.03091695290359278, 0.028780699489758383, 0.02356092494371678, 0.032561793472738035, 0.049372604717650724, 0.0742387768602179, 0.1336957340038592, 0.04538261579469808, 0.057202030964676416, 0.08382138000020097, 0.012641231202700687, 0.009814220247790217, 0.06477019824688474, 0.0829169825620709, 0.08062862430609043, 0.043803490247697606, 0.12023503291270426, 0.03012088795883521, 0.029225744862830447, 0.03305979275835618, 0.03418273975952499, 0.04883327115807803, 0.02779427127191617, 0.028408631652353272, 0.044956230408241676, 0.026447063522233118, 0.05187266371062687, 0.045199141567272526, 0.0894491997877917, 0.0528282051785819, 0.018567182724514318, 0.13794626559942, 0.011597669105075542, 0.08418721762756187, 0.00603729234670379, 0.03862446008790885, 0.019142934188787496, 0.030806339383425734, 0.023084943025042454, 0.017894298972321615, 0.02687635621236217, 0.029911263320114345, 0.04136252727720045, 0.035540408439814083, 0.0034202895532812806, 0.04263958052521752, 0.07506151698649892, 0.02953799463988793, 0.06961604144664542, 0.04487641170741089, 0.1433655715757801, 0.10707207189332094, 0.05874128163521809, 0.09800285491491519, 0.02108270137180244, 0.08861460828132207, 0.03348269627519673, 0.053221721562647054, 0.021663681386158835, 0.04462249186490813, 0.008590706969581304, 0.017060559738667744, 0.07518223712160703, 0.24181562265561474, 0.1894627214078942, 0.22448852177589174, 0.19033377869955956, 0.0777076612857561, 0.18519487622524464, 0.09319414399684438, 0.11756875582279698, 0.31490951175651244, 0.1341893244534731, 0.09837023237900389, 0.17498822552302193, 0.17139629971596504, 0.11958751241646468, 0.31883948152103736, 0.16014962336949765, 0.214280829194092, 0.14225646012252377, 0.17357062578441637, 0.25133751332759857, 0.1594070543444926, 0.08867283096356739, 0.1655738629520901, 0.08508112732200854, 0.29351975468377917, 0.20097613424783756, 0.2777692933957423, 0.13856961602164855, 0.08291767204120275, 0.1395622974321727, 0.10532172186480415, 0.12764422928974514, 0.12363561293891362, 0.1917478850772304, 0.17245244385013658, 0.134624922047219, 0.17503656567104403, 0.1407497796800829, 0.14932394298093934, 0.140646924715369, 0.10264445141318346, 0.17423479337125056, 0.13924219525389134, 0.2059042093253905, 0.157500782440747, 0.1416670320735824, 0.18894294607302836, 0.1176534851472224, 0.15565922964484463, 0.11592203450779762, 0.15173701269011344, 0.06663137821540718, 0.10725382625335649, 0.13630328279349113, 0.06262482264109197, 0.14767663943911755, 0.13288319050785036, 0.11270727676850174, 0.1672921062357003, 0.13195818530455714, 0.13155827208632423, 0.14626395798498584, 0.1564130601623366, 0.13117346612195815, 0.22828845577614926, 0.14327295154573458, 0.1712761311641624, 0.14755101634129403, 0.13045490629250003, 0.13122742935534448, 0.15778599697495663, 0.09384861291055718, 0.1697377500034148, 0.22983000854090338, 0.16496978730203646, 0.25235732957240076, 0.10607595840889601, 0.1579094290613167, 0.4098172029179912, 0.12807038868026388, 0.3014502049453797, 0.1940801325103929, 0.5395997291611088, 0.30502673238515854, 0.6144981843329246, 0.14518818667819425, 0.7218472659587861, 3.5968980241206387, 13.566360550542033, 32.73421479809669, 65.98399377638295, 76.59108684908959, 108.9403876950664, 99.10762540755734, 68.2805101333126, 57.23682195909562, 29.153596816524384, 8.957285342677947, 0.8386097908500703, 0.3590968810021878, 0.22029343962429032, 0.2297759993422416, 0.099880927122168, 0.15884149759527177, 0.1665214371056326, 0.18466152581236056, 0.2621298229261752, 0.19303494343353858, 0.16530914893073423, 0.1195392105728388, 0.1265606132426089, 0.19181798212230208, 0.245846348303941, 0.08644578272416707, 0.15787984274568098, 0.10536248540325512, 0.07704255141077504, 0.1580939489987589, 0.15620177311282005, 0.20189050615074175, 0.1837967504416743, 0.21920177965394913, 0.10818000357117384, 0.08195391811069944, 0.07664126689515768, 0.11966726216938227, 0.12111593443419665, 0.13522308349849718, 0.10901048884636934, 0.23520351778114998, 0.1544746738528052, 0.2079326722530588, 0.17293509456419176, 0.1365740642312073, 0.228337163646375, 0.16311196279862236, 0.2566626670980646, 0.10012796749511074, 0.10636242932730144, 0.12179040590361243, 0.13564254728055772, 0.12591179805777727, 0.19576011736306453, 0.11868012723542991, 0.29474227779334594, 0.18429711310853883, 0.2880205304151581, 0.13073961520867963, 0.11804508631147685, 0.10927001645247783, 0.1822356471130925, 0.14076666425793402, 0.20673333096408075, 0.15173350400742025, 0.12578431336629775, 0.17462488534229417, 0.1657404564321041, 0.16785842907284537, 0.15504039914136933, 0.16556773424869584, 0.11036373719933534, 0.3579153589183285, 0.13082625975291576, 0.2236143082019783, 0.22078296980790554, 0.14048036187887192, 0.24849286032540185, 0.19488188948842788, 0.2026390659833147, 0.1053908306564535, 0.3120170395460821, 0.14852889693312107, 0.18255456951597046, 0.08064481174393047, 0.15935646189797312, 0.2749429498949359], [0.030112146895619172, 0.03472512234903632, 0.08699176592692252, 0.050507701873298616, 0.036324476447677424, 0.06966779068593057, 0.019400280359531605, 0.08826438352585801, 0.0517787796355063, 0.08194512342132869, 0.02064333271024929, 0.02430237356513258, 0.016236507686816396, 0.07688407080187913, 0.0731871143404034, 0.08906021098335905, 0.0595737204346205, 0.049651127473841754, 0.06203924035353046, 0.041593786238903, 0.034785635634175235, 0.040305172724108544, 0.045772753731017156, 0.0335777792779188, 0.1634833162590381, 0.0394080454603799, 0.022873504673160856, 0.03037561027843866, 0.1349438750936139, 0.03932687461436276, 0.03891603698232963, 0.05947911623685111, 0.017208577501737786, 0.10784932171865817, 0.03009990672580898, 0.05316800730783613, 0.02287223871286598, 0.05382067208448726, 0.07650077403072389, 0.026440773940374775, 0.007794503171387459, 0.03543871409830547, 0.04284817477568023, 0.06415873750924103, 0.07812367767215737, 0.01925733601374011, 0.06736624039589398, 0.021273861376328335, 0.014344334673707285, 0.013546869703268093, 0.017476646988202008, 0.04165437613283435, 0.05091082499993425, 0.016162882806853424, 0.057459838703394904, 0.02695797138937539, 0.041339088817157095, 0.04484682539177518, 0.015774942585267127, 0.06474630396452642, 0.04213987286352823, 0.055471668170104106, 0.08431177586317064, 0.034112539292583545, 0.1338594776367949, 0.03870121060660289, 0.018663931968471697, 0.0029937918870634734, 0.0840480347734786, 0.036794904228900714, 0.032881757755193024, 0.04945936800551511, 0.00919226027514425, 0.039981634641486796, 0.003502309081077035, 0.03601417636438724, 0.045771106641979954, 0.04100481018183693, 0.025952446514800675, 0.04258446432950516, 0.04679636977192375, 0.030907807728996685, 0.03655437177287475, 0.02020870804816725, 0.04250016401431734, 0.03108375705778599, 0.07976531216333951, 0.04093380149213537, 0.13686997335283987, 0.647275960974155, 1.2914955375656005, 2.483623710370833, 4.385241231610698, 5.4631894538479475, 1.2686619499037344, 0.6779536761103139, 0.1307949267568127, 0.17230419051502982, 0.02745039163968496, 0.07725537063614016, 0.0345220209489907, 0.08567998591329783, 0.021816582959746162, 0.06330110973888828, 0.02130061508186402, 0.0635684437809452, 0.05349703824087497, 0.026998899636730075, 0.0721838838991619, 0.005577613257863109, 0.04946770304213128, 0.0205773112529348, 0.035587151294514056, 0.043893440461326996, 0.024443368217156782, 0.061044295153190056, 0.08200460248776982, 0.09585347266927843, 0.03535069825668489, 0.06522980503617756, 0.04903506637821275, 0.035599872184496735, 0.006879098007395383, 0.02141888565083425, 0.05253648655789514, 0.02236370763350879, 0.05940205545254773, 0.034217324798866626, 0.031937935517259666, 0.07565227036754932, 0.04380529438475928, 0.03339415183290839, 0.07052429996791386, 0.050856405944232984, 0.007306823568914327, 0.058870149115400935, 0.04154751069783684, 0.02875892727095033, 0.013558203974107822, 0.058236762941364324, 0.04794282418104911, 0.046775685397968184, 0.06460800977243532, 0.03062906472252742, 0.025417251745238904, 0.051627668792441975, 0.07239748453420979, 0.08335736054446428, 0.10330200766123111, 0.08847123492629298, 0.030828657439879836, 0.04575397308555342, 0.03556319189468219, 0.016854974298527645, 0.0033770240195501117, 0.04358337020441409, 0.01929196893357702, 0.03276171560789789, 0.06835623283780391, 0.016666892052237547, 0.02683088314839669, 0.029983696933355064, 0.05453602966642188, 0.001987436884402057, 0.024215229148525867, 0.017953251353314808, 0.030399969959210967, 0.023227418141980326, 0.02323490665144017, 0.04597217024814698, 0.011596404102390573, 0.023041538398472533, 0.03901159495956475, 0.03377699661218832, 0.0351925240829587, 0.07848786054960183, 0.027661462269362905, 0.025440937268637845, 0.014538145342451191, 0.044876668346865524, 0.0454995054901848, 0.07601770962918959, 0.04472512466412398, 0.05659175383287573, 0.0233916386646489, 0.11114353809746043, 0.02063062522680529, 0.03449922600280374, 0.17205064605560996, 0.04912663303736237, 0.0829821843053064, 0.05051476903440011, 0.04579098279317541, 0.04413334089481542, 0.05296705861485774, 0.07524655786372962, 0.02257838462209029, 0.11844038768040559, 0.04675127400626098, 0.046458118970716195, 0.07049766309078663, 0.022756509640584552, 0.037622447726466966, 0.03414204899942683, 0.036145188890758066, 0.051039945289132096, 0.04781790971455555, 0.056256172848084283, 0.03519504068178996, 0.03740657564072359, 0.03922010494035579, 0.033879472363379695, 0.03568956958911112, 0.12238179513763998, 0.048835117429975546, 0.06773701929036649, 0.038439514971668684, 0.018870170498567245, 0.05705726332962514, 0.08209981955587864, 0.03936006920412183, 0.013383463149019068, 0.022216218471106504, 0.015429055802674304, 0.06193318697173269, 0.03770417781666883, 0.039548791133828705, 0.01086178515481973, 0.07087633269087923, 0.024287768098856174, 0.0538803311815906, 0.02867211610259068, 0.009894474661127936, 0.034060797714177644, 0.01930658206073267, 0.06259235200442134, 0.036089452163827036, 0.018839561455552618, 0.013764074781999714, 0.04598150119906472, 0.07365304135507153, 0.04636770527389261, 0.008991832521954372, 0.026204301750347502, 0.0716258118289613, 0.04152438250340281, 0.0307595314112522, 0.0467915625701989, 0.05513322201647586, 0.04942944078075309, 0.08529862734459101, 0.029361181546963995, 0.04006663209668571, 0.02798639846244647, 0.0302481179260799, 0.06780377619208829, 0.045391429636266925, 0.024267263755562807, 0.01548218495783306, 0.08039677545668618, 0.02620656362494394, 0.07284749224181138, 0.055083774871403174, 0.01244308926435488, 0.058110006033412875, 0.7819637788399574, 1.9871841491230073, 2.873148898924551, 4.8575441202809735, 5.218375700135385, 1.6911165392206562, 1.0154510758096174, 0.11400327537088625, 0.04737436012815564, 0.11408517783087109, 0.029834233179327943, 0.07610774028205103, 0.04329537860147896, 0.09638359785200128, 0.013788390412716376, 0.033099977900424314, 0.023649145713857105, 0.01976704303806107, 0.026346288486233643, 0.06748750445342834, 0.07045548228967576, 0.010544769353263322, 0.026377814919537595, 0.04652914298217624, 0.0018117365341881412, 0.07207892219265623, 0.02355497052532531, 0.010656863338344041, 0.006945698339897659, 0.01920649841908486, 0.06799045649747695, 0.07895572576671839, 0.05392838021620147, 0.08765760358543166, 0.002141857825805463, 0.021185753604156837, 0.01229361306139899, 0.0525803450915602, 0.021803641819485256, 0.036778716791060664, 0.054479856269374016, 0.09818707607806691, 0.04430384142324329, 0.04619147440779113, 0.0753945813724591, 0.0195913867379028, 0.054558625429748535, 0.03550049142851945, 0.06629735621954165, 0.03402951451378965, 0.03818696642655038, 0.055678546383616426, 0.0745125690234765, 0.036056667431107456, 0.016657277648787827, 0.013564292457886042, 0.02502461061662724, 0.06879552297534482, 0.03934228447295966, 0.10180681087677518, 0.06784234105819656, 0.014902350244923465, 0.020925364149133527, 0.04872029234144477, 0.045615257545103954, 0.022005553868028428, 0.07788668071190197, 0.05005182210175742, 0.020174548187623584, 0.05150580335588706, 0.05489586882533566, 0.02017044961722868, 0.03939085827779867, 0.03340927440853369, 0.03982863922212874, 0.016267936443910003, 0.013445362095691025, 0.02031515596524602, 0.049520589921983986, 0.05313734846910643, 0.051314285205256556, 0.08547817537140462, 0.009856002683180475, 0.019787999373229764, 0.0398174811515116, 0.07559783215964995, 0.07632387666812829, 0.19813413190985882, 0.21625773440445625, 0.14408580147691313, 0.1618674836091457, 0.13141141303123968, 0.20211889228272825, 0.16082995541153416, 0.23603414095217184, 0.12971621367239183, 0.23260321618328172, 0.14241212918873758, 0.18866407474683178, 0.2817157800159147, 0.22091541108825516, 0.19140648565465407, 0.16296193213953128, 0.14714649127375695, 0.18557419700007285, 0.17729531462875106, 0.13075559580278012, 0.10692973275698962, 0.20721999597885918, 0.13536969740544597, 0.173610937330992, 0.3893727064132691, 0.10288370833281549, 0.14981506662743707, 0.1238757202161416, 0.23091255206494565, 0.21302740209765975, 0.14895228308535394, 0.14944947414821194, 0.14532890170812607, 0.23961457544036452, 0.20383572596455776, 0.08679566274006521, 0.14394303333134423, 0.22212746943677628, 0.12813705365143477, 0.0907277622290196, 0.19311835508673422, 0.19949874900762113, 0.12795473238633526, 0.19696377938793552, 0.12847539638319325, 0.20282337141613807, 0.1776554678837138, 0.07859953318632419, 0.15741951583373934, 0.10552309573658052, 0.13072967138742247, 0.10276389218145802, 0.18373086688018617, 0.08999668452287875, 0.12408379735725543, 0.15076193598008927, 0.11806880439361257, 0.19177583196470815, 0.06282613905627402, 0.1215493256947206, 0.10367034273522516, 0.27549079469134735, 0.13572396710515022, 0.16187522109718094, 0.27933272563161393, 0.16008620661112571, 0.16843734639546565, 0.08407482486819068, 0.2252339253262166, 0.15568213567378061, 0.168617989928011, 0.11779555615278021, 0.19433727758305688, 0.2162486179581573, 0.14436641948357706, 0.05477750824103433, 0.1258993797725247, 0.10271061842720355, 0.1391438448861722, 0.15527004165755165, 0.13598972300608314, 0.17681205104435646, 0.10553976580981286, 0.11509727957027574, 0.13106304220855236, 0.1666395065765227, 0.1549486524515575, 0.16780138616600346, 0.24265792100660263, 0.8228615971822894, 2.1968506468880564, 4.506944043021049, 9.371834762634771, 10.54663562005566, 2.210504662606024, 1.6609229916526427, 0.3291567859630431, 0.30217621114946186, 0.16457586489137144, 0.08704117093715938, 0.17909352216989766, 0.19500637877612345, 0.18299844085929856, 0.18228299134681303, 0.23335957479092384, 0.2293458716162751, 0.10379477839676604, 0.1798832668892799, 0.16232972574089805, 0.11827204751992419, 0.13372495259729125, 0.13200522310310794, 0.1350269343463644, 0.1626871823663673, 0.19219658277448148, 0.10806935749227002, 0.25317623159818115, 0.1581570899654781, 0.15837790714877267, 0.16101971539037843, 0.1276457231611975, 0.14905086327945033, 0.21416608454479327, 0.06612644200363467, 0.12241003313852895, 0.09416744338288423, 0.13785249643748806, 0.06437283610143969, 0.1410111382363304, 0.20592472516000274, 0.1703573772383313, 0.16724542083759464, 0.19946565400929223, 0.26213150831960863, 0.1169217562663459, 0.11981790569881279, 0.19388736946688545, 0.11033063454012718, 0.13688531043308397, 0.19380219581146396, 0.11125892626061556, 0.2035443520834369, 0.09847309500459703, 0.11564197574531841, 0.10364727582782508, 0.2073853177529189, 0.15871535355765976, 0.13610189359995628, 0.20574264138215975, 0.15503748800725708, 0.10433708437748494, 0.1546338209581952, 0.12384797251152417, 0.09691348554746759, 0.23038479409390883, 0.16796293878747573, 0.15927531786503332, 0.08265007752925158, 0.15600756982401495, 0.147946578180117, 0.12492653237836016, 0.1262920457989939, 0.13737799689894722, 0.09166038234628017, 0.13238812916942183, 0.10056548796954656, 0.13842309404525066, 0.12377178506745447, 0.22339848591195, 0.1704286234152894, 0.09240606934913705, 0.10210658108154613, 0.09178126335985239, 0.09177631443186153, 0.14201382475514568, 0.16960651914198555], [0.04298081523889015, 0.04174701914551758, 0.04622772951880771, 0.04051976927345799, 0.06492429683285375, 0.009316690191025696, 0.016112434001819744, 0.06961502254970613, 0.027223832627397873, 0.020780159843965404, 0.05290669471686406, 0.018020483229549664, 0.055644152866255854, 0.00776851459616615, 0.04987620410599536, 0.028854295641424197, 0.04039314260045367, 0.09937324065474734, 0.05260779019144755, 0.07591713760649005, 0.04692643617970809, 0.046773187951335025, 0.022802871366542195, 0.01077317942549745, 0.031655501882215185, 0.038099149767790115, 0.024403144770692435, 0.0579970961646928, 0.04862569963499423, 0.043343090557403145, 0.018941585214868672, 0.02999016080021618, 0.031965089503735784, 0.04139967871108844, 0.008074455639167179, 0.0460525137192059, 0.03584556807313235, 0.06853505308108945, 0.033727633736787305, 0.028199447514188868, 0.03196519292560557, 0.016881710767085036, 0.04160167311408347, 0.0192187654019724, 0.018006417855259874, 0.06037697511454744, 0.06342366082413543, 0.012290096717826542, 0.03815440002888922, 0.007919118863590544, 0.141146797085962, 0.0559412915590069, 0.0422597426410404, 0.04810301699645577, 0.02919228788795731, 0.04843176064652301, 0.06473993011299642, 0.016613733211171725, 0.01584763092274267, 0.027130423526790355, 0.011356663589756335, 0.047576768218629786, 0.017204896449261618, 0.04679055133413884, 0.06826514498360696, 0.07921050362769635, 0.00751667324596295, 0.07151922601605616, 0.0720917311827502, 0.03768063593475569, 0.02688340996692498, 0.036525559206042564, 0.10341500563006248, 0.04567594320002583, 0.05499420770173592, 0.03406982606036529, 0.004386321158944479, 0.028081607869676048, 0.06149079417809845, 0.039356491573515444, 0.04966927226632834, 0.09247069652642935, 0.0325307707422443, 0.01731060509149346, 0.08774319092833227, 0.07350918536465015, 0.08365797344595195, 0.05993717935897651, 0.11724035691229567, 0.17779020742783624, 0.16737830644894033, 0.06453546124600595, 0.12277260723133242, 0.08092392055738358, 0.10887136727932001, 0.07079338069043814, 0.14809296226068852, 0.10880966655789845, 0.07057616412038765, 0.07724823069668586, 0.01163652221176533, 0.0033332782444514095, 0.021300312477133928, 0.022839559317235986, 0.09657814588037231, 0.051932885882354556, 0.02358513332212404, 0.022672917956726688, 0.03824444983394877, 0.026642929221833908, 0.07243824807266075, 0.011727616769231617, 0.01563402741486507, 0.10447124169478494, 0.022542650450862223, 0.06449757819815029, 0.020944047118386915, 0.034220400641882615, 0.08299516949562297, 0.011230259082250057, 0.03310544776820368, 0.006847153098562793, 0.03906366978621772, 0.032762343799995805, 0.03408710517349743, 0.05948224570602179, 0.06968905728670859, 0.024103401378998836, 0.053246753485572916, 0.11965144245374588, 0.0025202619285518003, 0.019985349368183844, 0.03404936768234738, 0.048848336277109, 0.027952728898174344, 0.018568594241514802, 0.05707124443424325, 0.039467907570783174, 0.04953387005615139, 0.0329353379446172, 0.08426637749277777, 0.038976347254168604, 0.0593361527388615, 0.0158123248031423, 0.09418651131131957, 0.0240875740024832, 0.059817834351692474, 0.015855746666690516, 0.058746628928929574, 0.06544696798007335, 0.03638012124405753, 0.015397899964403723, 0.02456974782680552, 0.044380856242271206, 0.0866698787637776, 0.056218427696054986, 0.07491001543859321, 0.024742950730386282, 0.0237349437309369, 0.02249088205937897, 0.029970171651051893, 0.012241636868566276, 0.01593620792376779, 0.016065769671132008, 0.05420445915191405, 0.02621628145026344, 0.04907216801638565, 0.012256412789405835, 0.0433844784575124, 0.08542724584619846, 0.05546121106993768, 0.07149534705545633, 0.034898725533557516, 0.06286203027552655, 0.08154455902836016, 0.10583261057974831, 0.028889439924950563, 0.010425012573719987, 0.056978831247937296, 0.010866074289585794, 0.011585445214633741, 0.056064421040636886, 0.017078394265544992, 0.04611624074318717, 0.0697198616821439, 0.011041017170364579, 0.08829881917805442, 0.010901595871414869, 0.08194400493295924, 0.008269215299327287, 0.04286430092648633, 0.05818327085205144, 0.05099299942113219, 0.03712588485570685, 0.025284787482251565, 0.04782203126758818, 0.011901005449134016, 0.1443018382715602, 0.052203242141272754, 0.035191493694700544, 0.027516539501506957, 0.06132044303681582, 0.004672464095957337, 0.05446646505245759, 0.05071949837128482, 0.018253552073973323, 0.03246918876445101, 0.04375562507418856, 0.07845717106735514, 0.02358207663130616, 0.049408978572295564, 0.02185279402070709, 0.007015860502442886, 0.05792709105017205, 0.022516513446105585, 0.037094164985202016, 0.0261082649681597, 0.02312433909654858, 0.015182460718337568, 0.09391220586915171, 0.06274104967052418, 0.05137282581399045, 0.10233717354675455, 0.05141281560363789, 0.053185688617128524, 0.03012956965023712, 0.04313426648056315, 0.08470787396354061, 0.03247274341241967, 0.020429303065963814, 0.03899411283313267, 0.018549668039345456, 0.01461569738063601, 0.02674434777168978, 0.006987323727263439, 0.07858619559556246, 0.018004123421926654, 0.06641223876466675, 0.01586088232861291, 0.0149530949514179, 0.04613157782343127, 0.09132286698947992, 0.026792597904380773, 0.10689998556288982, 0.06853161334630943, 0.07112357224668227, 0.03788731879584732, 0.04096064904344179, 0.011899441672158579, 0.04854098180188768, 0.029406438191090862, 0.06683564789953732, 0.031831518243697864, 0.040019663246048075, 0.027532780565501704, 0.04675284448650576, 0.020750789948168303, 0.026322394203875336, 0.06724445539857112, 0.05238779655267155, 0.07533176982354733, 0.07759602695342994, 0.15715723797198267, 0.034993475288032524, 0.041573412130556764, 0.08259415311077911, 0.1111302158284572, 0.07065833471114598, 0.053727994597847425, 0.10741380839458398, 0.033980576817186615, 0.06491691174526369, 0.04448552683536564, 0.041966951497259646, 0.032891820320078445, 0.023775630660595435, 0.048506281849357395, 0.05449786699647385, 0.05765201568964028, 0.04735689715392167, 0.04308145620950288, 0.06753747636872916, 0.022470433257460114, 0.034441447651554505, 0.05382569762127054, 0.019729177227183696, 0.06373449716897261, 0.03764255370403971, 0.04954768645186579, 0.021260150317703525, 0.00770311271246042, 0.050316965132350885, 0.012719338654630609, 0.07385198672812793, 0.1492591472643037, 0.02450735762625212, 0.04935686544124638, 0.060244974334754293, 0.033182558348222126, 0.034887165266780124, 0.01760156720035499, 0.05840175912805623, 0.04842581197379097, 0.042244551117501916, 0.03170286909857344, 0.029926776600581025, 0.017762891910669786, 0.07109341136510335, 0.07879375179688777, 0.10406963542223939, 0.0313211657903007, 0.056001529052493074, 0.031564718547968135, 0.04266345565537772, 0.046959818461008614, 0.00962107128749091, 0.05879581943454762, 0.013008358730604092, 0.055648726411163814, 0.05117622083954273, 0.09486423865441354, 0.025918853559320974, 0.07377076608639571, 0.06323108930260905, 0.05252615586223622, 0.027165272866465875, 0.022722227205973, 0.024974228844286937, 0.009819836629885099, 0.058929383033706303, 0.048971848802701126, 0.01574007026295388, 0.06442473089743046, 0.048671753010562355, 0.013689187772181487, 0.021532714825063463, 0.04883866824750458, 0.030844496307714336, 0.06965995360646518, 0.0447800186943383, 0.04333090592896746, 0.04685828116752448, 0.04657339988156192, 0.13006315957154, 0.021397506052087394, 0.0552926755570356, 0.03621696749882352, 0.01124550614716305, 0.06503766252388878, 0.07793698970588946, 0.04698302709467469, 0.10167393292630873, 0.1842951366016942, 0.08555397977151218, 0.11444113292400876, 0.11763627881244307, 0.1330116634527522, 0.090591850570373, 0.10582111926088411, 0.12278614400495445, 0.17084413418366065, 0.09251231042247626, 0.19144642947902604, 0.11147408971502898, 0.17889216361987978, 0.16390088014304638, 0.15247317722007153, 0.16511557383402703, 0.1440463173052957, 0.15418135410835668, 0.15481115499090764, 0.12158638136761805, 0.08954673810231109, 0.2129491998423492, 0.17138019654779665, 0.11747234365752629, 0.09507454511138702, 0.12396740561891949, 0.06846475685315748, 0.13455240416430658, 0.19279858998713956, 0.1039295562452847, 0.1302786601046401, 0.15370408133152993, 0.12028399359194503, 0.14228000966531618, 0.10177839667566362, 0.12484273768120235, 0.08367626762558376, 0.1831435379121573, 0.1383347794293396, 0.10108376943296003, 0.13698971289540493, 0.17446511004480625, 0.14178173075760567, 0.1758398395031691, 0.12088204013003458, 0.2763700797673195, 0.1970343820510372, 0.15566656876715923, 0.11164402333839286, 0.1290968009420941, 0.17785756187813898, 0.17352642251118539, 0.10767170423341375, 0.1325552129457074, 0.1372479151694044, 0.18029358358152453, 0.09635004320091779, 0.182940463325189, 0.12294129979225898, 0.1349785941983423, 0.0647269679053176, 0.11216056578221822, 0.0789378835789619, 0.14932693072384404, 0.11766044122557487, 0.2135955941893401, 0.07911559299475725, 0.34819459182120144, 0.2672057682948728, 0.12069938944712763, 0.09182283129062384, 0.163843285652899, 0.21044349478137112, 0.18280661244305874, 0.14946479590669756, 0.10306280436775378, 0.14931464267353858, 0.13165582572260212, 0.19088309438478565, 0.14192238450050354, 0.09011845419844312, 0.1732590578256115, 0.15475631841728765, 0.14555638385636194, 0.11511847722314059, 0.16327932236656068, 0.27021915982327155, 0.1405570319583339, 0.13981354362781973, 0.21128491979212533, 0.2539132388248559, 0.22702886933280578, 0.2653119683025345, 0.17480335318513457, 0.14878389695959707, 0.10529637967626895, 0.1765706567394157, 0.2744795586312971, 0.20456358610141664, 0.09632067905078012, 0.09854231870943501, 0.11209628334449184, 0.12140434355505052, 0.08076058295104774, 0.24545639422872376, 0.17974972244231932, 0.11029235312655089, 0.10411409916536463, 0.1525354908118325, 0.09235929202048049, 0.16073874498326934, 0.12494668049076874, 0.10481042712326012, 0.16193822416807377, 0.09602425665023828, 0.22819217384582569, 0.07895612413243902, 0.15287442343129268, 0.3216323623013112, 0.10009278873762778, 0.1596968654062479, 0.10852956183014378, 0.14791716040382463, 0.08477071615596933, 0.11211465413291609, 0.19200826304093485, 0.12947039137924873, 0.15063471941938325, 0.1535401691592509, 0.15977580310596576, 0.13582648499117744, 0.2225356717263499, 0.20394452577156408, 0.18334106602255376, 0.08185970461777142, 0.1899815161502169, 0.16145781043075746, 0.09336520376945696, 0.18625316540560416, 0.10552916315294082, 0.17127642227757364, 0.14372828356440992, 0.2195863098266625, 0.15283708430586324, 0.22878898698235714, 0.15284125182417133, 0.12938175500640947, 0.17552854733601694, 0.2146371979747088, 0.11449928665834089, 0.1440457963655072, 0.16663733088681776, 0.06460011140593598, 0.15423959211236046, 0.2080295823754803, 0.16279009861811516, 0.16992971631548098, 0.10917646945604395, 0.09272753516392362, 0.06237204810003601, 0.1638450782986418, 0.12292624616454687, 0.20313938268490378, 0.13810573446173824, 0.152858626698294, 0.10703590488241566, 0.109128765160999, 0.18884087251799722, 0.16448255538219408, 0.20218679831633646, 0.1327997482111377, 0.14789161903242912, 0.12400831471407607, 0.1688727601281097, 0.15305132845476752, 0.18317148479963505], [0.013669770316130692, 0.06544849249504267, 0.11000405891888565, 0.09176959584076559, 0.12333038052724254, 0.016656666693668214, 0.024736214902312047, 0.013908789748506201, 0.03525458103526504, 0.01468719732421901, 0.044364806700257525, 0.036226367397654446, 0.01638210461204571, 0.03445119228995135, 0.010297153456767481, 0.0726096066195638, 0.041805728293594815, 0.03463546324881815, 0.06759043602693467, 0.018786454325421684, 0.031975628958354076, 0.020839127546717084, 0.03980556848428903, 0.029548811801378767, 0.03245189432956038, 0.03339895137375401, 0.046351559970888405, 0.01466965965641242, 0.043256066799644506, 0.033553884995560494, 0.07049635308043611, 0.018868695779313004, 0.0515240477398038, 0.013001143139967275, 0.04794279736797175, 0.019504345743165865, 0.0261592366282017, 0.0342377410420487, 0.10180002333776605, 0.014904317175669056, 0.03098113191944938, 0.03190779570309866, 0.06300254612259808, 0.01636913091304802, 0.013560350935515619, 0.036231316325645295, 0.05212640735290704, 0.05985279860455663, 0.0523273675372043, 0.027488833931725354, 0.01784563706737132, 0.029312801179325873, 0.03193614287151685, 0.025334192492488413, 0.02406913618136558, 0.026508802548050884, 0.04506984507785209, 0.10914721255821568, 0.026846022961000283, 0.018359076855103337, 0.08756813217675494, 0.03676134191693799, 0.01721476557694616, 0.01860171605292107, 0.11435556090286664, 0.09557912892271435, 0.0234377954620868, 0.05305966332314476, 0.04035380398554187, 0.054959660966790495, 0.018818944114290418, 0.012426912360223792, 0.047804093318841154, 0.041824229316966194, 0.049332021209861965, 0.06240895055534859, 0.05163464019255293, 0.031671802318024064, 0.06170401943006343, 0.03543750750982473, 0.03164978878151986, 0.024054017436179905, 0.05686291448411442, 0.026908755985899802, 0.015508009781760555, 0.023375750001099323, 0.06799856170771584, 0.10015596034786395, 0.05292071029543877, 0.065086669168405, 0.12281624359949944, 0.0515329075466481, 0.03419023209942445, 0.04055818858286066, 0.08505287399936108, 0.05155954825421495, 0.06518520339722596, 0.09931560019932448, 0.03126499430847264, 0.00814422996970074, 0.03601133417818816, 0.036257076032099225, 0.05060487629605397, 0.03146779310378817, 0.02377466538981084, 0.03202502822293149, 0.03948286543750475, 0.03137659225162239, 0.047926602269252466, 0.022820129412256425, 0.05239372224276585, 0.051433955799908414, 0.05562994576570007, 0.014178144347463405, 0.02730975130332574, 0.03897764194276064, 0.07167769130319357, 0.09505679485418143, 0.050383036385380456, 0.03395585515987008, 0.05139072162790164, 0.03771505243475399, 0.03091028219299211, 0.015165138512759682, 0.04273764744040467, 0.07207529093589514, 0.045170428591870496, 0.07002299501290245, 0.024105098263751117, 0.037309753618413405, 0.008160081286464007, 0.049416654773296854, 0.03078838036726079, 0.04146484598036736, 0.054683486270087386, 0.05176214403623054, 0.03570076596412448, 0.04815346771670927, 0.050909783120357224, 0.029992328829041896, 0.07241426952063076, 0.06687107180515606, 0.032812633641785195, 0.015708074600796307, 0.054148871812128255, 0.13434289443877437, 0.024278887224593954, 0.030964082632694515, 0.046270197602890195, 0.09451408284686266, 0.09641968825411412, 0.023032450680470756, 0.035090668862985994, 0.027432187475384246, 0.02708247599882945, 0.05376420757402817, 0.03236551791609776, 0.043772762461054715, 0.09046538477583278, 0.01239608593976065, 0.02195020018505954, 0.033309671487058365, 0.01666176883924392, 0.06851099792026705, 0.027227149788110007, 0.029860841328158017, 0.030647646185130845, 0.05405036439638465, 0.05554927670727334, 0.10075050586413953, 0.049562207648470524, 0.061250545174604466, 0.10593126738263715, 0.037360962765711936, 0.0276013799086814, 0.03795249372600548, 0.026507990494851145, 0.05870806789326091, 0.07619808503096143, 0.03266985783533704, 0.07054882244237008, 0.021101240699570027, 0.05029435787770537, 0.008549345882549401, 0.015903657805475018, 0.019865607910398996, 0.03386250351585689, 0.06485705729573965, 0.013662726137666933, 0.018488988130083008, 0.022486827539039717, 0.028561657715228297, 0.04395449383845253, 0.015918854117063026, 0.03717666499376778, 0.01844263406500461, 0.05374987406896488, 0.04502831162103722, 0.06130179645673883, 0.043472996086723385, 0.03624263910516616, 0.03730517624306583, 0.014547107613555368, 0.050173281511712464, 0.02511872643334491, 0.03902643408265807, 0.014620153139525605, 0.039591787818578944, 0.05951560117424496, 0.027830367419688452, 0.0042466312504163195, 0.011262824522301314, 0.055458162039999044, 0.017773894848482266, 0.05978903710661877, 0.03520322250082128, 0.05328866998634992, 0.017192480079228842, 0.04030616097753087, 0.03392012098864202, 0.05071650296750088, 0.03503599699826972, 0.009471920671902839, 0.059400967607695254, 0.009381093287600145, 0.03260937136327548, 0.0188636300229137, 0.024229405605564677, 0.03148066912657552, 0.05521540792899267, 0.016563016275364547, 0.03514324164678974, 0.0058322560958444115, 0.03972541270477157, 0.05980553864050777, 0.00749646001608081, 0.015147047346427798, 0.0546309249776025, 0.05244345284037052, 0.02314759369549011, 0.012638486692711953, 0.0656824327644802, 0.04170284651580357, 0.06187059375787936, 0.023096961029354605, 0.045983186592498136, 0.0808790737702962, 0.04473486164164159, 0.029792987005484682, 0.08222888238848218, 0.02650611549465647, 0.02078165180019794, 0.09957384843859943, 0.034090652160586855, 0.07649775564430222, 0.04945759068153078, 0.03391190086521449, 0.021111795475946802, 0.044765926506971164, 0.020629299894696283, 0.04295992402119502, 0.06386173671231636, 0.048624945038388816, 0.07611586847492764, 0.05443134375156895, 0.08655747068264792, 0.16921947620088057, 0.03867650044060523, 0.02770812660005064, 0.06605796906496249, 0.11398035402019178, 0.07294178234353181, 0.08617252682245548, 0.025734404485011776, 0.052745103790995576, 0.02109119728688271, 0.04072878487227906, 0.0708330180796404, 0.023693550085168213, 0.02558836131356657, 0.05798077083102638, 0.04117962761571811, 0.003941563308246494, 0.02947433464860003, 0.04383005817691165, 0.04362640136312093, 0.07794029920572236, 0.05276470798097792, 0.07330630996054219, 0.05243375799768875, 0.0467798950511121, 0.04347682652634479, 0.05260805832222105, 0.11613152891157136, 0.04789728025395063, 0.08110047318041325, 0.04455755825244612, 0.023814505792313048, 0.009400041514797317, 0.026696501750378843, 0.0310962691888093, 0.04846635717718352, 0.043665567608249765, 0.04484590608626605, 0.024933206751161528, 0.024005610255464434, 0.030065727713067206, 0.05520758234084614, 0.08444787138291905, 0.02040586652114026, 0.0036775672549171556, 0.06739354376951534, 0.008257364876748574, 0.02754170548981957, 0.03356069551720735, 0.03660355844805318, 0.047124167303404504, 0.03725174544078689, 0.028628621460689653, 0.021211618647700357, 0.07733573325939717, 0.019253252765103694, 0.0377774081613508, 0.05418375562576037, 0.0357700509559964, 0.01033209759982363, 0.0653047284351722, 0.02928064846914382, 0.09515625604939076, 0.06639058145904733, 0.07121141188808026, 0.07003725957005255, 0.05860437023183031, 0.026121162058364962, 0.08349263635013374, 0.04527726721379065, 0.07222715254512525, 0.020148323082755652, 0.030435313425597646, 0.07640001814692252, 0.04958403349343327, 0.05528052157211689, 0.03027589627421431, 0.020545242812424418, 0.04848758930400495, 0.04731992575069589, 0.00990926590372598, 0.031554583204729904, 0.11053259829960524, 0.018727760499102936, 0.03689820352461069, 0.02168530613304146, 0.11114551460430508, 0.15506364224899202, 0.230477245584611, 0.17756192854815916, 0.20642818282208136, 0.10171360095902797, 0.11439620186724972, 0.10371998523271854, 0.07339354439248001, 0.12817703578020298, 0.08791215162003234, 0.10669832823858147, 0.21770200932458525, 0.1556953583513537, 0.17162189728790717, 0.10130782716817434, 0.18374208240739762, 0.18401801195596496, 0.1397128490310523, 0.08475831319247523, 0.09380194283421002, 0.20370457171192094, 0.13223783804043648, 0.16286048677659806, 0.19353142969550627, 0.12090726740538113, 0.13548575972597446, 0.14174875833334463, 0.10130356771931534, 0.15876082853684503, 0.12696139214019622, 0.14540325820205674, 0.15970267235271393, 0.16633184566613168, 0.17190680538694705, 0.0811235324269341, 0.11479488168392452, 0.15504668106234845, 0.1878649071459809, 0.09879646071743581, 0.1430775378380091, 0.0842337038428072, 0.14290236417324315, 0.10952460279147472, 0.08645522092739422, 0.12782356281193996, 0.05630231049332408, 0.11213826496274241, 0.13582274648210696, 0.09763841922845572, 0.08137459476147929, 0.2577303331946173, 0.14586962188684172, 0.12696574351960613, 0.1425294478934619, 0.08445180907484987, 0.0801839792139588, 0.15308650721225048, 0.17937630054450807, 0.08579594098151692, 0.25073579722835176, 0.15294750821926903, 0.1896015365397738, 0.20356486791804915, 0.13881972840716764, 0.1221640423060425, 0.17024873064890986, 0.30959442438137147, 0.12830921659065833, 0.11353508073596225, 0.2373534669318507, 0.10471759258859581, 0.1190912253373573, 0.20760002155457774, 0.15620080784203547, 0.14093155702275617, 0.12399757416137766, 0.12045022701063465, 0.13879322176498754, 0.1470724565367545, 0.0828840177986891, 0.14109448860249213, 0.14491372801844152, 0.07014379941768224, 0.1389796875657574, 0.17027057947651034, 0.18366080047863145, 0.15477675764310747, 0.11680517300602891, 0.21391013456929117, 0.30041960218260366, 0.12400581726744292, 0.09002028003094659, 0.14623571998409687, 0.19810696643206382, 0.20076763575836537, 0.24422040329344813, 0.1749685523851264, 0.12937386430078937, 0.16410490467904076, 0.11806994586461976, 0.2063918396109535, 0.2286626284401263, 0.16845234639702306, 0.17785843521837266, 0.08404740658138068, 0.11606129397067333, 0.07401277326167592, 0.11552069636602556, 0.15658330022087022, 0.22744176008047598, 0.2942101837646577, 0.10582301149805708, 0.09232695544919661, 0.11709185076817391, 0.19917452527630716, 0.17701874156632733, 0.28035735290858055, 0.20355446444403744, 0.21533547179593196, 0.1799389614813751, 0.1379355250467216, 0.15962609420380286, 0.11048231994913471, 0.10197636911705618, 0.34405259956275264, 0.1213014656076989, 0.1488609654047797, 0.08187466631493262, 0.12989229132090846, 0.08199279707285666, 0.11063948288680085, 0.1772456568094992, 0.15293247757419465, 0.1976882380944106, 0.21816769885199688, 0.1047295818646108, 0.18968842623214568, 0.10468884130879756, 0.09535520908332641, 0.15465525609831657, 0.25079133860286207, 0.08519899761003834, 0.19122279309217008, 0.14554792624567786, 0.22425894054674336, 0.16330958283956976, 0.1560580090529496, 0.15479252373258914, 0.16892382754914223, 0.20920422498977956, 0.08520849710029942, 0.21624103368770695, 0.08804975633299159, 0.16945166212897148, 0.20923595635160325, 0.13896736887193498, 0.15423649711714638, 0.1595697407760928, 0.1569537343757768, 0.19092553565579076, 0.14169959081036432, 0.11450065795572535, 0.1934665573700782, 0.18198023339913738, 0.18734203681590098, 0.13869594392036239, 0.11541495324983714, 0.18140870116410718, 0.21609351579700747, 0.15033326382117887, 0.1943037229319734, 0.2640450427368764, 0.14127453458645653, 0.12511320502286957, 0.11955189698886488], [0.08052184697120421, 0.04262408639694895, 0.04590479281520651, 0.037040075347308195, 0.06874027271424571, 0.07708771229391137, 0.01355588943096659, 0.05985625366109514, 0.05156221807063107, 0.031750289941086404, 0.023261118349769426, 0.023598742874098882, 0.05916069945200317, 0.019360660207307628, 0.010380862926643704, 0.03509607744373141, 0.05949547604447412, 0.012514634215603433, 0.08105120606600277, 0.057886032567870234, 0.017921531482809977, 0.015193147644881281, 0.013574058163700806, 0.069144299824632, 0.043493025455503695, 0.018918736642527006, 0.028228009187225855, 0.04266212266238947, 0.025717211556771112, 0.04499412494741621, 0.0542107678859705, 0.08609373467944323, 0.04857629845519701, 0.051213805113107934, 0.014147788113463792, 0.01581306599320904, 0.03159716620200104, 0.04463674876117899, 0.033146437302592306, 0.03757560144989722, 0.044397714007044994, 0.02330391010599992, 0.030334513491740635, 0.027134700212627653, 0.07023588318618075, 0.04442178448962589, 0.03336266178878085, 0.01660544413983101, 0.05193401586204287, 0.021508378126928886, 0.040970114059746265, 0.04235286445867631, 0.04707010830902765, 0.04618228518313939, 0.027152065510651278, 0.04886706712685766, 0.034928346323149825, 0.0527115146659555, 0.01151913551673774, 0.023118767722119248, 0.01981924235400173, 0.03522817015407547, 0.08290601984387444, 0.005686981406348247, 0.006413616760138182, 0.2130432141524169, 0.07870977323862814, 0.0393597053123578, 0.12991531992391234, 0.051169433300533605, 0.026223817840218547, 0.025555388889305537, 0.027880544263509013, 0.018364454792331786, 0.037647383888402296, 0.021428840963410276, 0.04387035057128918, 0.05387201912761216, 0.03438984013853535, 0.02556878202144177, 0.008643319973001077, 0.05724320052972725, 0.061393416742043155, 0.05396463149677842, 0.06778341357506092, 0.032859725066490715, 0.10452495211915624, 0.06461017014038178, 0.024957079966101917, 0.06457059403821346, 0.06849792079939958, 0.05089458010549988, 0.09725628691094537, 0.02870011470100332, 0.048960265553286, 0.01248675148798934, 0.1255749568583504, 0.056856896863469196, 0.02444355782391804, 0.029787932740404244, 0.05445193236453399, 0.022064954410457326, 0.021782223916342183, 0.038632289506495, 0.04529219443699525, 0.03718988767134086, 0.027774672827593265, 0.00649747944759926, 0.06699111012201156, 0.07810963528050531, 0.043130236858081435, 0.10088042671521825, 0.06592526731471862, 0.04640009547133119, 0.0064775132810727006, 0.02248374211992468, 0.013063983417176192, 0.011394417360274783, 0.015481570172273825, 0.04082422410588592, 0.09662460911297992, 0.0167198057451676, 0.06658503755686745, 0.05245092602807188, 0.040399167881978136, 0.05437363051779328, 0.033558680705966494, 0.07118527296810381, 0.0533562274499526, 0.037797659695629156, 0.011729631580472475, 0.05821972131548871, 0.0874660739434823, 0.13247774613480415, 0.07149140936352553, 0.07326271189677139, 0.05279337882154411, 0.027387411551429864, 0.030802865174689123, 0.02378861968135161, 0.019128776883946794, 0.1015161647791824, 0.022562543839035977, 0.04641437535023978, 0.04230247119501714, 0.024802688351501862, 0.12783215065757114, 0.008748501929784975, 0.041509711919652845, 0.07399806437352974, 0.027945916461307677, 0.09527686893218949, 0.03692175306740307, 0.030328423092742602, 0.050716537441457474, 0.027719322975064, 0.007867235558918648, 0.025702918271323847, 0.01756460154278865, 0.022886394102486874, 0.02637856377048358, 0.042429952056057034, 0.029268101864163915, 0.03936820122743807, 0.03929091827763666, 0.05488543470780696, 0.06277991714136255, 0.07850403266568338, 0.03438180387620965, 0.02396438323381928, 0.05015219111115702, 0.04311093910326881, 0.026896849064336672, 0.019488683075553948, 0.03037713479340798, 0.029358808589618535, 0.04796193041388066, 0.050255095871586, 0.04362896009678802, 0.047672452600372416, 0.1103223684514242, 0.03453176558738755, 0.03251502763540034, 0.054271208392756606, 0.029599409993557684, 0.028784696553503315, 0.042149659636760914, 0.0766815401373371, 0.07129436388852135, 0.015492997331274374, 0.04681204393085453, 0.03455045047186075, 0.04788593066135242, 0.021110067947677547, 0.0421890671995859, 0.040277777419936274, 0.051358067130129186, 0.007352020362422111, 0.0023771502404293468, 0.05393197316856635, 0.016682650480839997, 0.07449714767356073, 0.02943912141716048, 0.002832209819086617, 0.004547584103420377, 0.06123483271127748, 0.031025398394934116, 0.05863331303360963, 0.020955708891814275, 0.017935819022597808, 0.03893037048739292, 0.013072056068678298, 0.03629456454467389, 0.04430163509002136, 0.02632327903542788, 0.02032192626727685, 0.02311089999913689, 0.03311711911773009, 0.07295211686963037, 0.02463442288459309, 0.08847501940063893, 0.12919807776568398, 0.04550306013815346, 0.06272123097592304, 0.13379725597558484, 0.05211925975257351, 0.05167732661169383, 0.11903946843719292, 0.042867372939062696, 0.008138340668782832, 0.035274169903488896, 0.026524836768306075, 0.017670568739694935, 0.0166006637511835, 0.032964537385851145, 0.09555308193328882, 0.013766272496732493, 0.014014268564360758, 0.04741471764000674, 0.1036162645886502, 0.036164367901942426, 0.03810406039138475, 0.0346679913420831, 0.028358383945399718, 0.10163274803949941, 0.05290759103973547, 0.00484947206249701, 0.022313383317762808, 0.0986680107551717, 0.08149535320098363, 0.04384619581903662, 0.019496926181619207, 0.020369636307981227, 0.027831851715041746, 0.055848886033580195, 0.02391661382130077, 0.0945981533356732, 0.02657708204952219, 0.07161336290019174, 0.019488683075553948, 0.013529566649888313, 0.020568884285767714, 0.08761072666534493, 0.0846396844774004, 0.034526797507198594, 0.02109718426401096, 0.010495458188797198, 0.03219371886863824, 0.017571364183940234, 0.019360840237969835, 0.04177661695247216, 0.02153764460085621, 0.059031104188292265, 0.020033769955437992, 0.03515030114701198, 0.0309266745593519, 0.015131953499099661, 0.02970365923829377, 0.02895637302689495, 0.01829041814010951, 0.022186090148264365, 0.05493075646940739, 0.04451470712440149, 0.0451809163355539, 0.03292840101846284, 0.05791607470582089, 0.0394790618109607, 0.0669548741631931, 0.06369441927921388, 0.05726484251358817, 0.06068856222555042, 0.019788225369167425, 0.05074526190817837, 0.07820168074460761, 0.017165785745507287, 0.03343973023396346, 0.08458402052882218, 0.01477596776244501, 0.027922169650874795, 0.040467552720539035, 0.023988382853267175, 0.03014245524912352, 0.006539439519626961, 0.03946270200333769, 0.0358063635236073, 0.04384836001742271, 0.009227318373779136, 0.01768931682642189, 0.026185599628896005, 0.0955553342317862, 0.04733049393361134, 0.017863101956825105, 0.05400832532153976, 0.05118032324037725, 0.0011901889323076655, 0.029490378444954276, 0.039271586048867435, 0.07598947162830061, 0.040517402061771964, 0.06119933985774556, 0.02681965612986636, 0.011466697755930646, 0.040740122973558404, 0.05851330919071071, 0.027640994315245943, 0.052132455617069244, 0.01892942739951034, 0.025645331442055684, 0.08314716133980021, 0.06226373475886161, 0.05259203559328472, 0.029161209616089062, 0.025177828201483336, 0.04108457142607339, 0.02950251519289469, 0.008454185313424997, 0.03487325694051481, 0.05762327973160052, 0.0422760832964653, 0.06727732823140199, 0.01714861579990435, 0.01791636038932108, 0.11003357628660818, 0.05613045781970986, 0.03811594624552996, 0.013969292499936156, 0.012760531202319169, 0.06602932503747364, 0.06427142904290269, 0.036214401104277184, 0.04401486922776507, 0.007924923416031826, 0.16779539535843557, 0.0921434161042975, 0.12819612669127603, 0.12948376727440666, 0.24822276836681753, 0.16844419522150872, 0.10172703814121986, 0.094226784553499, 0.08031393836943373, 0.16983210139216917, 0.10335469152778388, 0.10619291705229592, 0.16490422549747652, 0.11875646789708447, 0.12979509008507575, 0.12554094255451234, 0.10287662968039514, 0.18072329762001194, 0.19512173629576163, 0.08784318072420937, 0.1941768281281956, 0.07152572244165406, 0.07840043459568294, 0.17938606050466338, 0.09837105209308286, 0.17248497194340154, 0.14114123528763173, 0.1496293669145915, 0.10075810545634839, 0.13742181712821608, 0.1314742169192722, 0.27370654527218113, 0.12909612678472074, 0.14904850372864356, 0.08351098415592025, 0.12771152245301393, 0.14506368206874018, 0.16804316351490636, 0.18068601978161644, 0.16648745344531152, 0.14642344216906256, 0.1703451504750598, 0.17229481359883664, 0.10783768484308835, 0.14094113312180967, 0.18716264966755145, 0.17490654522853513, 0.1265881234599698, 0.16527171787475387, 0.09761128439417771, 0.09716409589013747, 0.18062640281934894, 0.1990003934911182, 0.15047915760547886, 0.14204247644351375, 0.10234762298604173, 0.13913570903241634, 0.10516917843732143, 0.11979241795357197, 0.27094335805985237, 0.11901452461437834, 0.12713353209678205, 0.15822343317972076, 0.15261825895117176, 0.10540825915673088, 0.22680434428395765, 0.26367045638542025, 0.18777749651382047, 0.19004021380697528, 0.12224587581811414, 0.11681305605076975, 0.06618571422633625, 0.13041238841270247, 0.12250867461965931, 0.21533888854807426, 0.0949343356994852, 0.2637396800902582, 0.16100162039360694, 0.20267936220813185, 0.08590112485352062, 0.16520220305650465, 0.1451007147589999, 0.24982309539712247, 0.14590400391288344, 0.11368507309065712, 0.14537148087495758, 0.15421382091458768, 0.1480675434633609, 0.1364722817895874, 0.24092499947836324, 0.14346301795974856, 0.11819347754240998, 0.18764390610158446, 0.2587186172604561, 0.08540281530229316, 0.11086541753742965, 0.22445964026114634, 0.09561322749622407, 0.08346018486566122, 0.12107923116174438, 0.112404610751377, 0.12196033952697632, 0.09360960879994017, 0.12773635136263986, 0.13723145960079086, 0.14927695114766398, 0.1815788186485729, 0.15019798801550943, 0.16914226985987157, 0.11013898998498918, 0.12654270976781845, 0.2211361976280328, 0.17549166786334208, 0.08376120379374874, 0.15513416830330126, 0.11090638025874093, 0.12699022768966614, 0.09382304089564471, 0.07448364920433491, 0.10411975289424581, 0.16884852110618548, 0.10974269270175889, 0.16581317349787683, 0.20544187526308721, 0.11092763153776047, 0.2036868291155946, 0.12313483658456996, 0.1568604555101164, 0.11742503006732273, 0.15521693644264054, 0.12865950263315631, 0.11974507371985144, 0.1765667037257264, 0.2010143926787761, 0.156495705727608, 0.16978386849645646, 0.11281590037528547, 0.16202967974447435, 0.077118715872207, 0.23422836446233336, 0.12642397380043424, 0.24982375423273734, 0.1130827900863463, 0.20532225829459008, 0.08087237816183798, 0.11801798978159506, 0.21196034887144644, 0.17288773500871274, 0.12104350082095593, 0.17791434431508665, 0.11004303747247304, 0.2371277621075992, 0.20333510282779896, 0.12889838416970548, 0.08917744541841169, 0.13996663863860792, 0.22685043213348235, 0.11196557342285111, 0.12209113371828872, 0.09151702431300957, 0.10762626755862467, 0.2017878350471297, 0.12543735214539115, 0.16140249888262442, 0.1314860453168231, 0.07855952041403902, 0.1736655593999932, 0.1645306657038389, 0.1933298413191111, 0.1330588085036124, 0.11205306832468319, 0.13355811396914144, 0.12522552117344835, 0.13293145404708, 0.23217347150127735, 0.135892414517941], [0.027304281435546376, 0.04885665216152707, 0.015145213523459052, 0.04317407240910877, 0.055529117103545904, 0.0371248199934921, 0.03574417633635383, 0.019028540024714127, 0.0016982311518081736, 0.04861596648791625, 0.07892515885853961, 0.02454158834992878, 0.01132579886489698, 0.04630088325469725, 0.04188345557439231, 0.03615234415197084, 0.01780111586765176, 0.0228292343672365, 0.030284449645888903, 0.06033325830714838, 0.024910279654807625, 0.05928476356090077, 0.025375745101501385, 0.08669763412927428, 0.04806291229361969, 0.06236628711884541, 0.02687679862813844, 0.05100815264027446, 0.045850733820829666, 0.022245124883709416, 0.02093144305681269, 0.025770316771682233, 0.019213450666997704, 0.03650984291227595, 0.05866249332264547, 0.04923762768627175, 0.027841023702715195, 0.07815463528517755, 0.03661587714187561, 0.05196793057445077, 0.025499717279848073, 0.02236840566770444, 0.05781589721840236, 0.005733907164540143, 0.08724023888428366, 0.061581966301967064, 0.040452200318536455, 0.05551124810271206, 0.019954269181095788, 0.03324412883469655, 0.020774456319369135, 0.028737543841763854, 0.03231188027007926, 0.08211828993573304, 0.047851797613886096, 0.05453403017693951, 0.03749575210554946, 0.02744681209385876, 0.05363560056373958, 0.03269483996254783, 0.028359747581904935, 0.04425168232691865, 0.05232018163247455, 0.07023081934500126, 0.06231471791022247, 0.09904276564597123, 0.0886514111452045, 0.055098571859660654, 0.03290597762491915, 0.011332046311919489, 0.023001004686398853, 0.07817377982240531, 0.04243407360908966, 0.033667380921542645, 0.02944996730694848, 0.052386214581107905, 0.0636978590139939, 0.039900754908880884, 0.13117219441600386, 0.034729515863282066, 0.0361995849638216, 0.041167171026069316, 0.05621944276255466, 0.0697613989693984, 0.04912148492651121, 0.06938257615172094, 0.08858669969824054, 0.02450550177825555, 0.12110684097053544, 0.06172600232305066, 0.07797141769720663, 0.038674033637489044, 0.02821581306747131, 0.04935384705482472, 0.034617521469631506, 0.03770583256658527, 0.053470125572095, 0.03441422088672558, 0.03617131248897603, 0.011084009067065293, 0.017628437734299132, 0.05708435985950693, 0.0033063344533495126, 0.011504378748096285, 0.08835829824449555, 0.03847539086916274, 0.04283042068803503, 0.02681852806539786, 0.06468668700225892, 0.020102179691856428, 0.0783701817835531, 0.07256053102713439, 0.15146943349992076, 0.0032109500429097324, 0.05270642018125904, 0.017138549404579307, 0.03530754069347055, 0.049192876660174904, 0.06674649058690955, 0.028380018268381397, 0.05223810680270676, 0.012249887635510777, 0.009524623690653712, 0.05076570113399818, 0.04370978237279961, 0.028150053995270884, 0.10603506463549792, 0.07943302152618285, 0.02037049432645642, 0.05535603485881321, 0.016862809462773225, 0.03883832502329061, 0.03799923275026583, 0.09878867726412513, 0.05008382925523385, 0.021466180088839704, 0.02574151761138872, 0.0278248630779525, 0.03646360184516638, 0.0370378038966127, 0.02019521340938105, 0.04422045275268536, 0.09129698853939773, 0.025259542969926715, 0.08382711799875384, 0.03614935640906615, 0.033763662851866216, 0.018600312196799827, 0.08666160501419537, 0.011594118287546501, 0.06622088532293997, 0.03798330961275966, 0.05541936351707386, 0.0437547019382398, 0.10280538350343706, 0.04560229916786475, 0.024304438172088518, 0.05036376161320556, 0.035984961601394805, 0.07742211733373904, 0.11865920537421781, 0.04982820103665994, 0.033988318135661465, 0.07846529159935252, 0.05085550962136157, 0.09965991075601309, 0.051880075611294284, 0.04816628436768248, 0.04054094777412472, 0.04621002522687759, 0.010274378620388528, 0.041735769144349524, 0.0760054522224011, 0.014655254330606231, 0.053514114340707186, 0.053748648328286026, 0.010420466799499288, 0.06911082944322018, 0.04971306951295945, 0.06859533653985109, 0.02657150492943343, 0.018166133780933676, 0.06874725943611515, 0.12818773802850517, 0.010718062272175186, 0.014510220480001262, 0.03292603380677681, 0.034319689467308984, 0.08255967149330724, 0.028869016020889246, 0.03404060363649361, 0.01578325846968519, 0.05048822408782379, 0.08955102053380783, 0.013380658309606296, 0.01602964287984275, 0.07633201252188414, 0.02067875470064821, 0.043963353645296833, 0.07296953004814925, 0.046900573051384384, 0.058628965484639334, 0.011768782503842827, 0.03484884937924724, 0.05716631594564646, 0.0970380514439556, 0.016433601042315844, 0.04837929894546828, 0.03800497840969794, 0.025338704750362425, 0.029244933450113864, 0.03303590613687712, 0.005245114340552039, 0.03516441631701685, 0.06165163816824075, 0.050915352579566746, 0.02969942468729231, 0.06355826247243151, 0.03558038290770304, 0.06813805099696883, 0.04156637944341187, 0.03511024623989098, 0.009768235820135283, 0.1091017758834266, 0.023226807186860713, 0.024625884834676984, 0.08551621929772439, 0.05664008248957896, 0.020674834245695703, 0.036978887904795914, 0.05654938917066302, 0.04735730318052154, 0.09441816863874275, 0.05465683790164129, 0.03987211088139204, 0.054366398647788076, 0.05481477075767133, 0.06651752988897985, 0.08419444949756708, 0.030082215840417533, 0.01834233783395781, 0.0439999305132416, 0.0430714013054967, 0.026562070556645914, 0.02545174102359001, 0.017213001659500505, 0.057832689865702586, 0.044134681548682914, 0.04573068784309491, 0.028538303524856607, 0.007112027519577815, 0.051176125078552195, 0.017570588519916903, 0.05867500353844897, 0.06355028749713976, 0.02826083413956146, 0.024293448640814713, 0.02982124607379158, 0.06186895432972139, 0.03333290310336217, 0.045166356834552945, 0.06013103407777606, 0.07188700184586548, 0.07416176970206922, 0.07733016380018766, 0.04032592987641692, 0.1261597500753499, 0.0796770052083077, 0.02270349252578472, 0.07216121535748243, 0.02136341513945691, 0.007964772915828132, 0.03765068572735594, 0.007875748710977215, 0.03698571757864087, 0.027630834074150172, 0.050804158747797055, 0.11168384458869697, 0.06660135522965463, 0.043958864370060545, 0.023432266222493305, 0.03769634839808268, 0.017847441204433, 0.053734441227730245, 0.03896194863163176, 0.02881533049437548, 0.03743505878974834, 0.04019712751370765, 0.05505281342794338, 0.07831052651688938, 0.06678857179659028, 0.09135836750389108, 0.041466236429949926, 0.051495131751101826, 0.032983000104826306, 0.05223130777237877, 0.024963384869718747, 0.014197043736555405, 0.027742366899826357, 0.01828252551926961, 0.026700717149182197, 0.045520557586344025, 0.07618121577486878, 0.0316924981832985, 0.05532285942125225, 0.04005678403641909, 0.03633451986036474, 0.06018602003854129, 0.009442600571820814, 0.019821105862877542, 0.07890777632353768, 0.0044388738329402145, 0.004985833318994171, 0.08776372974558223, 0.012857925875352757, 0.07666130009437762, 0.041516307936680895, 0.0007629416969364449, 0.05832035462522219, 0.05759074780789595, 0.012211486520696313, 0.02348551699411004, 0.07492553637993914, 0.03423499844727978, 0.03652108525256476, 0.05390019584146719, 0.02573824258551242, 0.06743029300724307, 0.03863829180538174, 0.02726066805001709, 0.06054283698059379, 0.03213109118082831, 0.05335768301700873, 0.027654737932607535, 0.029395019650579463, 0.031527048089511456, 0.01990379930864419, 0.029971163734913837, 0.03227819921448827, 0.09897462978598573, 0.028149127028882507, 0.00451077166343889, 0.03675239400998239, 0.08239941356042702, 0.026770184086936138, 0.016804552306571317, 0.04120343379796513, 0.06822759901443798, 0.056586977274667834, 0.015035225322560198, 0.05510288110423473, 0.0030065367172937845, 0.11103444717704289, 0.2158765137315758, 0.0916976142194002, 0.21159610470696805, 0.1680774382886387, 0.11991960387076102, 0.1744000998235518, 0.307995752100983, 0.05119725378350385, 0.13250756227681715, 0.2581945518332143, 0.1027905903456192, 0.1536559863316436, 0.1589561349922611, 0.15012255899848478, 0.1752364533322473, 0.1728644612575731, 0.14717086819150757, 0.11347834426429003, 0.1536746329117206, 0.18258824674112184, 0.2156433318891833, 0.14773591932269836, 0.09843866701327986, 0.13141113723958694, 0.14842405013980406, 0.1068687521582169, 0.092655798690694, 0.16344726416132144, 0.2354070673426313, 0.09922396076182205, 0.1317830882485836, 0.10077915755250763, 0.2413816032029929, 0.24252403948095538, 0.1444159087634856, 0.1419982578485243, 0.13843054041987465, 0.10551083066891279, 0.1443415829130719, 0.1364069191678878, 0.16678605919643757, 0.15384701801644218, 0.10334729877931458, 0.20846081326805777, 0.22813353747610124, 0.11385606391535652, 0.25139196685725645, 0.16119590029120445, 0.13355748577704354, 0.17185072775088972, 0.14133527003709348, 0.12997377243253494, 0.23508480479640348, 0.16819576822942303, 0.12057974183511351, 0.2251615453391306, 0.1745759936109666, 0.20347123665194358, 0.137335111296946, 0.1754485371132051, 0.16105987371936922, 0.12647924704417107, 0.1100764082624547, 0.17489842469653777, 0.18585766485381514, 0.1430368892127468, 0.11168398248452334, 0.10449869062511191, 0.12702022003190172, 0.13846979476511478, 0.16215753981903677, 0.14038898291126375, 0.12347686419924422, 0.18646930945256066, 0.13064613716015894, 0.09711319700844827, 0.07931541170804732, 0.2916785389665635, 0.12009563555400218, 0.1608417531655681, 0.1362684870799703, 0.23554194478258011, 0.1226698901624449, 0.1425112303226225, 0.26085100767593233, 0.22397815400073606, 0.1713634498657719, 0.1703498542549149, 0.19958070509376066, 0.18681725126601037, 0.15939717181026936, 0.1091823147069062, 0.2220076532854188, 0.1084000776491819, 0.11584253756389504, 0.12328718849007161, 0.07541469118047146, 0.10682636451336647, 0.14603857491766253, 0.20110868278049654, 0.19260110784201853, 0.21520793347829775, 0.10563814682104897, 0.14686262505429407, 0.13418238369687913, 0.08029860895006888, 0.14081823729699658, 0.18679472828103652, 0.13658817557077255, 0.1798482566711403, 0.15248391777276993, 0.29243972392812856, 0.1869212247190937, 0.13402159716333115, 0.1834775369253851, 0.173507668678799, 0.12646566430527356, 0.19697113383200862, 0.13844379374096472, 0.1867380837399152, 0.09888746430196109, 0.128979267732751, 0.18088088190603643, 0.11557226940508812, 0.12308236722263599, 0.15202604234218597, 0.145973687270476, 0.1181668866305582, 0.20464419387280944, 0.11624357693137662, 0.11203347945645933, 0.1342210558152968, 0.11947886582704322, 0.08826306585462824, 0.11635217755552262, 0.24300480561871685, 0.18513388030471342, 0.14513368718326092, 0.16779940965915882, 0.1338327718117545, 0.14363998427025734, 0.1620926521718502, 0.18712866600723038, 0.27676332802061115, 0.10038047007495358, 0.13045073877419197, 0.11366591323167087, 0.21496165153240004, 0.0952790369610152, 0.23389039711365778, 0.1653089344261154, 0.23136909450254134, 0.12404895567845915, 0.21094494529308813, 0.13885506038223544, 0.183268946505362, 0.1957729569966755, 0.12206238243849048, 0.14693281402991665, 0.17382375655635712, 0.1204790855427423, 0.100805104950503, 0.22748061605999548, 0.12067293643110222, 0.2673007631974836, 0.1113435713153693, 0.10973409719524846, 0.102488414624766, 0.11801800510335354, 0.13725235847936523, 0.17098235176695933, 0.1891522412939418, 0.11936150115704346, 0.10931083361708349, 0.16902185615993318], [0.03771370028956764, 0.008369419599823173, 0.035799047383930416, 0.04712302966283695, 0.037533504918458006, 0.060594597711197795, 0.008252810484038727, 0.04125348615249799, 0.025800186539849928, 0.041142866886671514, 0.05021763417208868, 0.021982391199637807, 0.04042729863055772, 0.043299247345496575, 0.04317094293993808, 0.0775891628056284, 0.019930210189833757, 0.007069580502913244, 0.029959471317969506, 0.061676478569185546, 0.027667255809290275, 0.049737025082351706, 0.07922800873676616, 0.02956460661915762, 0.015367935392855397, 0.015061402546932862, 0.04659239503164445, 0.015324578646780744, 0.05397573594124087, 0.02815467925111373, 0.01765694961162104, 0.07928331262401997, 0.02790257503699151, 0.06040391842684439, 0.03213942238700486, 0.0473464860190307, 0.07962575392617334, 0.01629529535890587, 0.04823133289333313, 0.036463571201649406, 0.022478825750670606, 0.0077215969776584506, 0.02327438124695853, 0.042071074337488225, 0.05926507127080714, 0.015843555334985496, 0.028464605866540826, 0.036406861543054544, 0.11943372792654461, 0.023463049550510706, 0.032958492952128576, 0.051247792603868636, 0.10010546749277462, 0.02473305862006401, 0.01833087715861057, 0.004201286506178159, 0.1286100439967648, 0.028810634375399644, 0.03989660271233128, 0.08066981685377898, 0.08356660213922301, 0.00029859054906879585, 0.06812067612284614, 0.027869355549374898, 0.03835228053973087, 0.04332409157688099, 0.021730658538158865, 0.03448512232411773, 0.015691237903440434, 0.018650266875122345, 0.05261260505405165, 0.013487339883501972, 0.02229430198278879, 0.07354581202831, 0.058685230812238115, 0.02552522034684737, 0.051156256588235985, 0.10992408700047002, 0.036748234152553544, 0.04553779839507995, 0.010394097095535649, 0.06918110268851442, 0.06041001648672166, 0.0230514649827514, 0.030944307988149025, 0.0383625767614332, 0.024784279258681402, 0.036202687619914936, 0.13488998846902003, 0.05220296251918039, 0.010630732079246833, 0.08655344106016621, 0.018912397264953584, 0.03016040468918941, 0.10160559022258367, 0.01159810194475276, 0.052289059310550653, 0.02439513149100446, 0.03483737338214152, 0.03374834875425985, 0.04411038123972474, 0.041354897041474624, 0.04177478600233313, 0.09652333228939003, 0.0447190610782033, 0.016654050503406796, 0.09004629637685516, 0.07620643538933608, 0.023213189974006627, 0.08065803442150354, 0.04675393999223748, 0.04465496250157876, 0.037955749599683675, 0.05480079348349283, 0.022878959219181733, 0.07278736966151385, 0.03527709252892002, 0.027743054463738398, 0.030608648479345347, 0.020413088815046415, 0.044351584022684444, 0.05765290818207207, 0.026260164881786032, 0.046329776260761485, 0.06166671860903021, 0.050740891376570355, 0.008354253931752136, 0.03532678099168885, 0.03449254188566439, 0.04147239960730076, 0.12866045258218242, 0.010647981506471914, 0.030401630454786846, 0.039667611370884606, 0.039906607820622386, 0.037408571299766345, 0.004534860340607984, 0.013648122586610337, 0.08711833897377215, 0.03680925688616211, 0.03779711194276329, 0.04977925184873804, 0.01849818884605362, 0.03447426685823068, 0.01506612164854643, 0.057497112711350766, 0.054126578653531696, 0.08458924524846577, 0.007457935369588556, 0.029116883768790194, 0.08429378045782929, 0.041363791322275516, 0.019923518411815166, 0.05302977057233934, 0.04025341199350454, 0.06638393947674383, 0.018290872047204646, 0.06897577580304877, 0.009463380706766921, 0.1103988087045089, 0.07908141781245509, 0.0287267783912079, 0.0405790108526426, 0.03946261007278677, 0.016378864060126005, 0.01421432093446774, 0.03740787415975525, 0.02355254011138553, 0.030676880100321387, 0.02936657097551131, 0.02949150650942278, 0.04575614111437913, 0.02133494348175103, 0.09554244097202055, 0.029327916094071926, 0.08356555259876675, 0.05362070398405195, 0.03155896331243698, 0.04683598034804867, 0.04811918911253733, 0.00024466654776328904, 0.03476616934001927, 0.029925571927320094, 0.021086803772636963, 0.05581484874710441, 0.042037638430033004, 0.04416253650560976, 0.03630881761050513, 0.010455431052363448, 0.019017621356573318, 0.0064241021097968184, 0.013227558510768558, 0.007176657569699831, 0.0434620640120439, 0.004570231577681919, 0.026462404432916836, 0.1630412222396943, 0.04924421987286018, 0.022395055951370348, 0.008815600698242986, 0.05205967343382297, 0.05514822201803327, 0.05149120938092951, 0.02643010616602917, 0.07476009203181153, 0.015121917747291587, 0.04612610029477266, 0.055904232055669835, 0.009973581857799042, 0.03980174570554688, 0.04334032497999649, 0.03108266921293351, 0.019817869141397458, 0.017462715679298968, 0.07645822550740934, 0.026272043075052, 0.061037974927814743, 0.03764851003765099, 0.05644318640172001, 0.12468565135232865, 0.012777609217371191, 0.022971431777301817, 0.0818008384216697, 0.03688714887586333, 0.03514180906237133, 0.045909550221216296, 0.026432004148861574, 0.017761049469211893, 0.05750422583772771, 0.06849780588621093, 0.03472553603651543, 0.00719292784079669, 0.04946692929332776, 0.019533384305935715, 0.031398916053735924, 0.017382326242964596, 0.06094402956566023, 0.020955371813127593, 0.12134738491788027, 0.021299094397334323, 0.012316406092366144, 0.061645038320773074, 0.03828072409716345, 0.05896514784845133, 0.049393660644249576, 0.013642934256143147, 0.033679864324268796, 0.07995396131469358, 0.04026183896067162, 0.0252991114112158, 0.09540085260185505, 0.027800141420635967, 0.017390044578801722, 0.0034499383529633166, 0.04462500846373939, 0.05415181742019711, 0.021324697055763776, 0.04513957823115972, 0.1101813929515981, 0.04316078844450174, 0.06997444036026156, 0.02056570502088195, 0.055018324149592276, 0.04099098995568291, 0.04890216544510857, 0.02664880511621314, 0.05112385872991816, 0.0139756539025374, 0.07423082486756387, 0.03914181075449433, 0.017963831027549122, 0.038704512445556546, 0.03202579048041615, 0.01003346024757071, 0.06417427760278506, 0.034731312339464505, 0.03471002275604875, 0.08905566808196808, 0.05109295857349231, 0.09503551293164493, 0.06361920859724765, 0.10048488019815377, 0.018479226254707864, 0.020319783136308677, 0.09691224448503026, 0.07457578659898813, 0.07378712972445835, 0.02022610973536728, 0.046483951455522934, 0.06304398381842241, 0.06199270434257004, 0.034596522999626976, 0.0161165249113354, 0.04538342784789782, 0.02862407281363924, 0.005381104523210877, 0.03291226720677749, 0.055494145189802495, 0.03886930178850889, 0.029315984274651256, 0.10296921140604443, 0.024189659048833197, 0.030719246677753907, 0.019281337548407818, 0.0477433770204023, 0.020104393685957598, 0.06542642916282339, 0.035355348410385276, 0.03911975125271467, 0.09310467258816765, 0.0831150699166521, 0.051348988988226464, 0.01827124678980439, 0.04099677774995085, 0.036075601294156046, 0.040716171234605775, 0.0776588001979455, 0.03850655149548285, 0.022624430336779165, 0.005881495918372587, 0.04942657944235591, 0.0489595492610768, 0.009449637089405329, 0.05912275894755318, 0.04480224290502168, 0.02008822540031566, 0.0350022393338863, 0.05453416807276588, 0.023279939214849187, 0.02725836787102444, 0.029700280790547692, 0.08368048877004655, 0.04457274594554498, 0.03520992193971911, 0.028941723510562897, 0.017395267383225502, 0.047000018924835234, 0.08011524580539235, 0.02170770462872761, 0.0430480815890816, 0.06836475173552191, 0.012317850168103413, 0.018307501900820963, 0.047630317764536995, 0.031145034515629375, 0.024302197364909996, 0.014237981560009142, 0.028108179629329714, 0.026614974673476913, 0.04733776793845239, 0.07124883528318136, 0.05359067333742015, 0.2135350885650804, 0.26386688132920577, 0.09152556619336528, 0.22482858820547982, 0.13066364993010798, 0.13456662275618123, 0.06743511936116604, 0.09644715250619958, 0.11724660818975781, 0.12803933147581356, 0.15571104783204295, 0.13838661293829643, 0.11273192947790509, 0.0806898653747574, 0.15288910167592187, 0.11848566347673056, 0.10402432898239744, 0.20159281970512485, 0.09303975429746414, 0.1507023803048557, 0.23654297655147893, 0.07786462504056194, 0.1279690735522778, 0.12979490622397394, 0.16307649292772816, 0.1463107659571594, 0.18902611257808824, 0.17373343479008446, 0.20770454659096657, 0.070766904691775, 0.09898835042070958, 0.13983130154590453, 0.09588772446037301, 0.23950830372350834, 0.10374246225241693, 0.17371117227500485, 0.13672829305212345, 0.24762062325833306, 0.1843051417099853, 0.10485155838391474, 0.12923891025204814, 0.13340129577104123, 0.17495402735808205, 0.17571162702816148, 0.0813221560430623, 0.1387099020423428, 0.13539050435346944, 0.10292808014538982, 0.1760158252211348, 0.16138972053604742, 0.07935405318294803, 0.10906164819795279, 0.1372967915789735, 0.1740100997830591, 0.09978941791961271, 0.10963622180204238, 0.2981392035801565, 0.13489809367925892, 0.1140875986687118, 0.20673196732757554, 0.2929640038599891, 0.11904469315683651, 0.22231968089697823, 0.07529510485549128, 0.10380181874479018, 0.211299107740483, 0.18589264442843778, 0.27077016090193107, 0.19533461680816067, 0.08452947506861341, 0.1673633217691414, 0.16383504254683373, 0.11743167204962623, 0.12364914971253566, 0.19789629225288669, 0.1258438843632898, 0.11683147280446946, 0.2583770339767779, 0.09352565322431827, 0.11522166926654116, 0.11883591887571159, 0.10025373614963987, 0.2174761206392319, 0.12959874175008268, 0.1520458380541494, 0.10898156136634851, 0.07237580424595265, 0.14013634243559453, 0.25129308022799035, 0.12989425250599462, 0.20351160948555316, 0.14289553066895855, 0.15543596098019233, 0.14459744095802307, 0.18441066266067568, 0.1442864245825237, 0.1433534060995425, 0.11789886310936944, 0.0957261105518668, 0.09507218556058022, 0.12256454541197709, 0.22721032491855084, 0.21311452161640893, 0.2908340955693876, 0.23506867098471812, 0.15953321370386309, 0.21059200858637211, 0.15703472519113174, 0.10232915260618734, 0.17770645869595392, 0.1282869847190957, 0.10873239892985552, 0.13339202610715745, 0.12519904517478522, 0.10594230670962604, 0.1804237265981013, 0.17781744951442366, 0.2673111513497368, 0.1342517146540265, 0.07437727789604857, 0.14176323739511354, 0.09202034407926184, 0.14432619986755235, 0.17022046200450391, 0.16367883721907295, 0.14499268103991786, 0.06648102579938789, 0.08185304731370942, 0.1380194116744303, 0.15825665075211756, 0.24295718559334356, 0.12643990842925926, 0.1882669347668848, 0.2300969288954812, 0.273130661657741, 0.14500571985638913, 0.10826433452987864, 0.15157300858728348, 0.1698510084421404, 0.17557609075259778, 0.1400932729724915, 0.2106651853048994, 0.14633457596984603, 0.15429606811413843, 0.13963912072921955, 0.12126297735038305, 0.16186052753079325, 0.2790402639056406, 0.1554691938743476, 0.08370994485073513, 0.1698419532828754, 0.2776061779549045, 0.10055462484278026, 0.12031557939706311, 0.10023358037635204, 0.1668268916828017, 0.15722111438310918, 0.17753646378555607, 0.18525840023592596, 0.1366294523881328, 0.13523117338697757, 0.20231795256897328, 0.1214244916674591, 0.10961508543621148, 0.1877569347139328, 0.08764628080591079, 0.07908779166398511, 0.13755565268858788, 0.07107560748174306, 0.12349921098399548, 0.10685072610935858, 0.1320244672317659, 0.09725165207900348, 0.20184719153950292, 0.21660460369481196, 0.18202555516073782], [0.03690640066540049, 0.11083665859675217, 0.012015109457406066, 0.05181018157952255, 0.08257352236297824, 0.04419471985930878, 0.07099511462353891, 0.058839750746565486, 0.025113015247869398, 0.016168195626608307, 0.048129998613148935, 0.02410261996931607, 0.006217279916463961, 0.005675236799664075, 0.010052865254692733, 0.04867932962013349, 0.0328752038730008, 0.03503068034807521, 0.03918684523312315, 0.025769062302706223, 0.10092865195005171, 0.025636444822134032, 0.04197328321395382, 0.02419362929950078, 0.013376207338766226, 0.024324923363183776, 0.02462909665829953, 0.09746269398038426, 0.01696492515264019, 0.0780173906335427, 0.004759298246954718, 0.04727585654285166, 0.0059017747445332435, 0.0397331501928068, 0.04343128642968593, 0.035312443656185945, 0.023476936809358098, 0.03275008639320731, 0.028561109962362437, 0.004078446701544548, 0.05790106704338424, 0.03258155471074485, 0.03657661896619586, 0.04122692588416319, 0.05360687992745831, 0.021826729794303258, 0.011794115116278972, 0.05307188242553704, 0.015902703068399384, 0.020059286428975965, 0.027228390850547343, 0.015680396801701958, 0.032704013865441084, 0.05620097621313988, 0.026363167318425355, 0.04580775628827753, 0.03709589251347127, 0.012799474324340062, 0.01932618816593482, 0.03744808994534035, 0.024116348264919176, 0.05173831870178542, 0.048340703435843034, 0.031714515550242316, 0.09018809925163947, 0.04717269131252843, 0.04891357632474073, 0.06976805627346039, 0.10303183909385435, 0.049419642516201547, 0.06326545600689228, 0.020013600775611498, 0.007843076497421511, 0.028866604759147572, 0.06337617486414891, 0.004948488447905308, 0.01530326416550745, 0.03182963941306357, 0.035718608151880965, 0.019125561229884624, 0.052109488301099315, 0.07707412189413464, 0.03945135241073947, 0.033766577816418106, 0.04396167591274266, 0.038852627884836934, 0.02905954400287761, 0.03449965501204133, 0.008345584689278998, 0.03123554397344349, 0.04651466775084696, 0.012361572721161911, 0.05384757709238799, 0.03410857095713577, 0.08433484277057071, 0.03773046229335089, 0.025726094346253142, 0.05411130669076116, 0.023212849064880324, 0.05671080389630891, 0.008043990237638354, 0.03009993353888633, 0.04444211646313629, 0.06747917707769141, 0.05103018532897677, 0.07221466531195948, 0.003131437537846186, 0.07005167734478751, 0.030807896457131834, 0.029738083399171313, 0.01888119833423726, 0.09204143447981727, 0.029972466084385113, 0.02400601053640487, 0.045366995261922005, 0.02350643502488252, 0.03235545152077272, 0.026856319182702613, 0.09567885058781794, 0.03858865313832799, 0.03530010964060503, 0.04014872990909123, 0.048760580905382676, 0.02523656224741811, 0.028433950858250744, 0.06780899325085264, 0.06407484322065307, 0.021143379365845073, 0.027053230592320045, 0.04315367914856442, 0.0295591980384122, 0.04082171899837352, 0.032160462991845225, 0.05448702685234528, 0.05654613712742444, 0.024829545478907325, 0.03605938321279903, 0.011555033439259616, 0.05413908120845595, 0.021520729379488096, 0.05731789793278422, 0.0191357042340021, 0.03340643222233461, 0.014338449203229, 0.016681782886265747, 0.036786684105473186, 0.039440818701780615, 0.0497803358631509, 0.05181712233611653, 0.01486821911267696, 0.014726255359428545, 0.0272643567633725, 0.05439864711896066, 0.06825720065183218, 0.022276093988048456, 0.025628755214594068, 0.06104107758390808, 0.060397031296405106, 0.009013598037493086, 0.037396934424196525, 0.005981316217296427, 0.03199581345993906, 0.021859072111246568, 0.07647628219978464, 0.0360110737082939, 0.044040900895432125, 0.028335870536524924, 0.0444159698822806, 0.0177411311831806, 0.030735376658999634, 0.07922072324060625, 0.019501235426193284, 0.04267336500267829, 0.02434885978037792, 0.053369032609606945, 0.03258707437423929, 0.06823663885194449, 0.04915760214170141, 0.01061940068123682, 0.01812541429253836, 0.07549934389610445, 0.01646948268546933, 0.050322327747820854, 0.03472022321676055, 0.009145326856073112, 0.02908759239700533, 0.01850439798867991, 0.0883404254132221, 0.032312703814597867, 0.026890226234231266, 0.04202192596670601, 0.04967948804879862, 0.02951516713496418, 0.03502403453533207, 0.04434659679029738, 0.03768410248261306, 0.00533910566798201, 0.009249766665180365, 0.008052799291157675, 0.03631504973576915, 0.030089206392726595, 0.027462618402956475, 0.0502864518503268, 0.021627682914596894, 0.056857842982055685, 0.03601619883650734, 0.013925825628722388, 0.05615566211241869, 0.010058512280304587, 0.09202651874793154, 0.010433638723747385, 0.021167449848425966, 0.01666708548943843, 0.020020120183847124, 0.02245042878653734, 0.018336670698537942, 0.035935778756655996, 0.05054150167251787, 0.01785628951995844, 0.031156420497403994, 0.013177858556680863, 0.030244086388378378, 0.02638306645225854, 0.0389560152806582, 0.03364326830412592, 0.055016271033955205, 0.04338941589418439, 0.03709616830512401, 0.06148183477982398, 0.04324368298834851, 0.01289552834350616, 0.06988300776649868, 0.03034898106219067, 0.011091615362543494, 0.034825897385035796, 0.03149633562462705, 0.0798005675296149, 0.08280004690130872, 0.0388846043947964, 0.016201284879277793, 0.02687349295874517, 0.021268613674047015, 0.03535239131099755, 0.01970293297011766, 0.036015988162328164, 0.12931866000496572, 0.019948663332709865, 0.007538603470405384, 0.07801139216509559, 0.021889054877383095, 0.05138041391488045, 0.023729169343207634, 0.007512464071623982, 0.06772332163828035, 0.0482547905055746, 0.044211083497371406, 0.0553575900172995, 0.06410546375498657, 0.016498927274839054, 0.04707064074013503, 0.04377492282900118, 0.05436304701311935, 0.0649213856987415, 0.04302618296576604, 0.10814172215759756, 0.05465629397921505, 0.028375896715348767, 0.03077297433910351, 0.0034754924126900737, 0.01440889098786659, 0.002796517303889437, 0.05101131275296212, 0.01314310497799588, 0.08340254441023835, 0.06370851529702064, 0.020806775653674718, 0.04507605805091801, 0.07529309004425042, 0.049469553144468416, 0.04788265946591574, 0.03901515343797304, 0.05311748380922983, 0.035833728184262593, 0.03079793731411619, 0.03781107772562293, 0.025537841645399892, 0.006828676015439053, 0.048913530359465274, 0.01496926515227965, 0.021803676293441848, 0.03617854818942086, 0.012207840899786642, 0.00770133538847609, 0.01561265068894793, 0.06419202785999065, 0.02568345006194807, 0.0325319888220439, 0.048219791778753844, 0.08510537400481202, 0.02417753953787108, 0.04075416153477084, 0.06492119417676041, 0.021111887406497713, 0.0648749990749263, 0.008810654643081851, 0.028914981296346075, 0.0174033745086842, 0.052330144605929815, 0.02820946985945827, 0.060040528450401566, 0.07339293918301983, 0.024592266981339744, 0.02105372026562691, 0.0698732937716188, 0.025699415334290075, 0.0028491947065753444, 0.05371852575110332, 0.07909309299242112, 0.0400869602397565, 0.025545341646178596, 0.025350542724012368, 0.048667754031597614, 0.020422647677121625, 0.06879649590700865, 0.08008909922453665, 0.04185121093365935, 0.017640059288110466, 0.023603027220815424, 0.024015360639520714, 0.005101765883380487, 0.01674913733656849, 0.04547175395512774, 0.021169841957969532, 0.013527609295241777, 0.00966950336606392, 0.03228243568070954, 0.03461854802745004, 0.01769380035599874, 0.05720728249739736, 0.042780276402951255, 0.00619694842175851, 0.003905552148353309, 0.0275942572062054, 0.058181049197071025, 0.027149857262209542, 0.06276604711949345, 0.027857632488913597, 0.034411516596352866, 0.02665713057673026, 0.04952056310890664, 0.07232046971518187, 0.031267039763230475, 0.16133315260371855, 0.21219268801712224, 0.1633133366703987, 0.1847972306272676, 0.13695635742718174, 0.18780498374854365, 0.17057915969241053, 0.1380278233198389, 0.10907293267307744, 0.07274106730737033, 0.11693267301926691, 0.17948425765479767, 0.13117201055490202, 0.13451702622396333, 0.23161315479345862, 0.128729599678228, 0.1169509825206572, 0.13280999846756458, 0.10790261845555037, 0.11457712885232703, 0.11092638281444389, 0.11172781803555067, 0.1337653560744178, 0.11930791330674004, 0.1355319088625331, 0.09741794678472704, 0.1385873126526994, 0.1397150706860327, 0.10807845095593123, 0.14143285431688832, 0.05790784692151412, 0.18224867060780528, 0.10183660403615045, 0.2827239517242678, 0.12493734187897175, 0.17171339882958322, 0.09199434305511175, 0.13083801154167424, 0.10483661200851203, 0.15329246228981405, 0.09923296995581159, 0.09347234882654683, 0.13674405914160515, 0.11214735842640362, 0.10282353212636325, 0.17643910412105823, 0.17657100913986085, 0.11452005530196814, 0.13597927356679596, 0.16855956806290537, 0.07279094729212023, 0.16209090549138286, 0.27126673909444965, 0.17632728592763025, 0.10127100898253341, 0.2047421765183249, 0.19089457038189137, 0.1031262364478842, 0.14542136852058674, 0.13509355335225984, 0.20105908624827865, 0.16193117615917038, 0.1253436519313724, 0.11745424099987554, 0.16625679969306917, 0.08188945947275048, 0.13069856821769668, 0.16282190658873127, 0.21281498123801526, 0.1699821933382942, 0.08787846673400172, 0.05759252130144066, 0.2719068821639784, 0.19345370241470877, 0.1908730279894606, 0.1359516177927294, 0.14186063781380653, 0.13504931943551188, 0.1074291148313111, 0.12247995398337803, 0.135180167252979, 0.09869436417976696, 0.17330148377485816, 0.17400976270437243, 0.1080420081533732, 0.15963726376573886, 0.2553504044490476, 0.1265926663613608, 0.21411412846176855, 0.16264794334288568, 0.14301044385760062, 0.1253822934062731, 0.17208064605872478, 0.10597740119743733, 0.20186108837444938, 0.15564537877517362, 0.1258914890669046, 0.23426135220835287, 0.11764755562668848, 0.16577217247216933, 0.11978161611383963, 0.127468166962987, 0.1772520306610292, 0.17566630526656107, 0.11534084956492148, 0.17656762303123552, 0.1266331158037628, 0.11195353818156066, 0.09917959661012697, 0.1892529358907092, 0.0674840417360106, 0.1713737767309912, 0.16049278479429985, 0.05318264341762951, 0.1615726470106071, 0.08695498604567782, 0.1260356514924957, 0.12102386598745662, 0.20314759514745206, 0.10630501869825587, 0.11614022400951195, 0.15915073664678683, 0.1482457661580655, 0.17873719935455631, 0.09846553371678438, 0.2043145768825085, 0.14431486176627298, 0.22533166282359632, 0.07737479608265624, 0.13618306827641305, 0.13198921186549048, 0.19092257855640304, 0.2516905419648655, 0.2487480288912212, 0.18580713369432958, 0.0820468369150354, 0.1884711278422225, 0.16230628345041506, 0.10070449462340725, 0.11688479252399937, 0.16399022131677599, 0.1488438203570343, 0.15551610909883054, 0.1317455959055693, 0.099340858118188, 0.14820281926903034, 0.17595210202759312, 0.18551254224392677, 0.16972245888844614, 0.11085422499285591, 0.1010816703520475, 0.08549392613912783, 0.1998902812239624, 0.24140697603504507, 0.15318937749872286, 0.08860579827019284, 0.1203350303694606, 0.16873844959322484, 0.04207025462340924, 0.17036171329598274, 0.14762984678870247, 0.1299557080792804, 0.15026630773659677, 0.2041561498997673, 0.15802348423148357, 0.08307895653190152, 0.1062170411610315, 0.1261137924607723, 0.09385726970410156, 0.1112918833631181, 0.32625417074849533, 0.10449517428153947, 0.07036296185106039, 0.21119378597265293, 0.1367969192083805, 0.20695970994570564], [0.04074897511952347, 0.012307389237497364, 0.026844825948618596, 0.08154755443214409, 0.021200056465703155, 0.037627220454235236, 0.017665024178342956, 0.03953813102036234, 0.10342241370029027, 0.11929834486856578, 0.05395670248676212, 0.019720859427545822, 0.006359097155396857, 0.033675754262555035, 0.023716247355144833, 0.022225290867349794, 0.057783051198648835, 0.09261534158741275, 0.06557978464350586, 0.0969932889265399, 0.018593612757901994, 0.03101625896599745, 0.0666989624920872, 0.04711465249138494, 0.024423842551186684, 0.034618482909976475, 0.05079031553900531, 0.047097507443639545, 0.029507088737802643, 0.03904709547397591, 0.03505998704161856, 0.07898305212297747, 0.008454836488160635, 0.04862283829659705, 0.06648632712782392, 0.027608169362910336, 0.04044418320840886, 0.010043957567353164, 0.034023144492699255, 0.021946130342961803, 0.06686829090599092, 0.03762356621483642, 0.07458451234044568, 0.07641370047725017, 0.016138354586737774, 0.028065770917061358, 0.04321115106464394, 0.038133141088990435, 0.009798065368686954, 0.02788949600090423, 0.0594640089829843, 0.04870719223793957, 0.026847034197060332, 0.02477623533547646, 0.041705209897049976, 0.03708669562794028, 0.0386344537048811, 0.027922278818404003, 0.05055612629099239, 0.02795640995065051, 0.017420485082473007, 0.06693674852290461, 0.04601398715749384, 0.04293825905469637, 0.009854825780606799, 0.06510430451242194, 0.04602610666845595, 0.03431723032507204, 0.06633586745949523, 0.03225528169423342, 0.05792708721973243, 0.04157129006700651, 0.11218424555995773, 0.00489224131489473, 0.010468314736030035, 0.05478106671944261, 0.01664007897488773, 0.016693513607606292, 0.0400269870466042, 0.05691723011794591, 0.022882297447311784, 0.016871659693518476, 0.047679205665424954, 0.06161624107569937, 0.04054060686499842, 0.017704466215124535, 0.03165374179520915, 0.026387230140127005, 0.05447395739235705, 0.023710042042958162, 0.05062627313177913, 0.02506063590126653, 0.033819782622759385, 0.028743806610544844, 0.05346434160826668, 0.019249640660540714, 0.03350472896389904, 0.022655368797601234, 0.0323200122933955, 0.028546416395974737, 0.01312968407517239, 0.02976489839174094, 0.05840883395003696, 0.037361154287693, 0.02946128051037029, 0.04606721494647284, 0.015179635769116784, 0.05395530054586069, 0.02771459429735138, 0.0404912056852012, 0.06274520186707377, 0.01330875521225314, 0.05084945752675976, 0.029798514329858368, 0.05219376180320979, 0.03369247796194207, 0.01909672568041471, 0.05479162341103919, 0.05642730156861006, 0.035883903112863345, 0.011358172782967168, 0.0572642028301714, 0.02140068914741278, 0.011589957472507753, 0.02823973224768716, 0.022270566663674773, 0.06998462166877524, 0.009965265973380977, 0.03683337716445808, 0.07196729552120933, 0.05929283046674344, 0.01730072255727024, 0.05123605613686866, 0.02562136055090495, 0.04839958495370323, 0.038199457490155776, 0.005731557668637364, 0.042469378771080125, 0.09450396282538291, 0.04236243289685057, 0.015123329264292074, 0.02229648341815318, 0.04259847607764025, 0.021418596452642834, 0.037491829735377145, 0.056698155784679044, 0.02638735845985432, 0.03778921740670358, 0.014061569705635551, 0.05771139133421164, 0.03101861660158442, 0.023575806201645927, 0.05366083166952576, 0.08520279740614277, 0.07193005598721004, 0.12514687458714172, 0.035894532582812735, 0.05814871262578715, 0.01235810234286492, 0.02370135460589682, 0.052952411013745496, 0.04969943697834688, 0.018878394452434395, 0.05767093040049077, 0.023483272356491898, 0.10553661718844407, 0.02103427503888886, 0.07939568240075343, 0.07995301902654671, 0.0596506433230975, 0.03168999499100591, 0.020596754564453038, 0.044347374369540525, 0.029460148615462166, 0.04709835397079588, 0.06284312322555531, 0.0978160290528209, 0.03919876939166458, 0.008451906201850263, 0.054245709156196927, 0.03577973047691969, 0.02644786408411399, 0.05701140147603809, 0.02803720924402437, 0.05851882502376553, 0.017302339002790473, 0.048731086520297874, 0.03630407552625384, 0.028117106468867392, 0.002791511398109217, 0.02443675879359005, 0.025995998613296017, 0.01941229261818432, 0.024902884991118507, 0.04191180082759069, 0.05020723069807695, 0.03029344543333977, 0.015712766889332524, 0.04304349655285478, 0.030294646276161078, 0.05709285960502683, 0.03419809216152757, 0.0365135929126653, 0.030112183284795577, 0.011117901754445367, 0.047088689771631075, 0.03673933221087341, 0.05603564294776129, 0.028346298908394192, 0.016615887833458763, 0.09230372766333242, 0.05668348903136869, 0.04598490262944852, 0.027408789234956907, 0.04610605177379424, 0.037286070010234276, 0.05356781710419924, 0.055299788683412544, 0.0497602911726121, 0.04957078783322246, 0.048135380380817, 0.07064006351415189, 0.037453510017404636, 0.02729893797227452, 0.03144571636503022, 0.03500494745469863, 0.08248307036175843, 0.029954903518720984, 0.06341282068000687, 0.05764802054111516, 0.021789352364477613, 0.021593028927342068, 0.043193404637877984, 0.03744592957739388, 0.08314752906200387, 0.011310671501222157, 0.029101571586403637, 0.03839813473243867, 0.026033847187195095, 0.017773318367319244, 0.03617031657467446, 0.05386083041347804, 0.025943420083832838, 0.017088181038777676, 0.09050645474945346, 0.02824156702826581, 0.03908518536557113, 0.03218036978655765, 0.058105122222895586, 0.06113719097488831, 0.015731906638510765, 0.08558323666934045, 0.022734308412538904, 0.07006408796916086, 0.04414075279548284, 0.03115736853121029, 0.03825494140807179, 0.07431590659243446, 0.03883763937459838, 0.02373756949729737, 0.0499158721387146, 0.09685556930039199, 0.007812166286091651, 0.028614908486845034, 0.04223874800147549, 0.04141168330886191, 0.03723655391724841, 0.028756366622063424, 0.026452295902755954, 0.017100629967547232, 0.05200746454178326, 0.0037498981644955255, 0.003692863397337797, 0.06208861472025033, 0.03069996807513939, 0.12627378226287905, 0.02753484134201802, 0.06484085453614112, 0.057598086930210554, 0.014924183750765459, 0.027299108426837672, 0.008094964770510072, 0.05066266230818245, 0.01394645446130345, 0.05019415357720949, 0.05155313992872835, 0.0845135787441846, 0.08444435503934661, 0.03672487613174223, 0.06544872232141995, 0.0693371088334149, 0.039704640230704705, 0.04233829729679612, 0.02756369029802661, 0.0533305979784458, 0.024904026462125684, 0.03767774778328115, 0.022683589561511914, 0.057840798906381094, 0.031532535194269115, 0.07931210986909368, 0.007333236365323707, 0.05843853900930094, 0.01651514535619607, 0.02145439382612465, 0.041505873819152196, 0.03969586086309245, 0.040063368562128276, 0.03384224432069929, 0.04647319175062641, 0.030057739331236774, 0.05666611415724601, 0.018167202473588048, 0.04190968259448006, 0.048779403685682246, 0.023677705471674283, 0.017842314160999753, 0.04732791987818576, 0.049799434435103214, 0.026323437998672167, 0.030094611143032392, 0.03581016715015135, 0.07793706631468189, 0.030943082247470177, 0.0212315101206543, 0.03790069852144488, 0.028720394963578835, 0.07673280674122995, 0.010309809229276594, 0.030469540318834688, 0.015911240160705584, 0.029733061692827654, 0.06093009825675719, 0.014738411259567066, 0.04399760543639141, 0.03909021856323366, 0.053487029302144246, 0.004134153263763555, 0.010041213057364428, 0.03945293055186349, 0.022101337841201215, 0.03797759076640491, 0.025138215710138603, 0.03729862619131323, 0.03435444304599397, 0.018595510740734397, 0.032065454682695775, 0.03209406615144784, 0.05001143777682897, 0.017888890391576196, 0.023799998002246987, 0.02431797303049074, 0.15269203321827998, 0.12154679760457048, 0.14638237985632113, 0.21536380172737185, 0.2080672739013549, 0.20437278424299535, 0.10389068494400672, 0.1829183387059358, 0.1310575876625315, 0.28820141909583924, 0.2098050064617588, 0.17520795486146407, 0.11499061714857818, 0.1974843667760011, 0.14787114916309235, 0.116621671965526, 0.14326709863399306, 0.12807194383875017, 0.31630719320908673, 0.1766598446955604, 0.1766737874957823, 0.14640366177885764, 0.16424339805399218, 0.12567916013781102, 0.18583242991758933, 0.20170249285236483, 0.07266347026151997, 0.14803329933314555, 0.2677501197303495, 0.15202362150434526, 0.09454400624118506, 0.4111042306307824, 0.13846479987184848, 0.24832995938918284, 0.22367747981221447, 0.1295301309155841, 0.08799291260900997, 0.14690122056391933, 0.12680185432996482, 0.10116580212789197, 0.15927504207338058, 0.15470511310042875, 0.16942147826475484, 0.1340609127956052, 0.15656313678670317, 0.1768063666719583, 0.10075481893915324, 0.18506367600733237, 0.15864550166072386, 0.11696509386022245, 0.21970251004301736, 0.17243842444112226, 0.14323683816098398, 0.13225061638701346, 0.11600913870478831, 0.20802720750291503, 0.14520510189956234, 0.14317628657144887, 0.1567770745004377, 0.09577897061864216, 0.1280328963372496, 0.13117040177026104, 0.10057592208707526, 0.12254747697302412, 0.06445787186103483, 0.11421791022463192, 0.15574470973543583, 0.10424177537882522, 0.17077506369640752, 0.19981267651723278, 0.13822380393262834, 0.11513502472230505, 0.1632012580070765, 0.09776427215265651, 0.15831277435345037, 0.2525314460358312, 0.1693461411782811, 0.12883017170092753, 0.137422445320314, 0.1617981679737568, 0.14522235419961715, 0.15870062934775508, 0.1196089398957068, 0.17390070242747185, 0.20092391769491857, 0.14548936648474586, 0.09492891945786054, 0.14710883039139933, 0.1355202030390501, 0.13832698065427043, 0.1397537274826919, 0.07338516339058838, 0.12927356806974258, 0.11607260908931495, 0.21092813732402943, 0.13496233781258907, 0.11268950352865843, 0.172209256899453, 0.11159943702119975, 0.20823716155944333, 0.0728163201241724, 0.18260143877517793, 0.1361521336460306, 0.11819017570345633, 0.15967281024542548, 0.10304926759413174, 0.1722189402508159, 0.14984970912337303, 0.09021135768102062, 0.1203769277180395, 0.17520818468784133, 0.11000136228939218, 0.11915591380168354, 0.10222989825471755, 0.1328959228891519, 0.19544750752468265, 0.11798189171860296, 0.13219934978312062, 0.11244327520891545, 0.13969309928436435, 0.17940965601273123, 0.20711108891954347, 0.06619509114252944, 0.11573703193496312, 0.15623689058326906, 0.1506576407700777, 0.11814155210290225, 0.1523191475820157, 0.09511776779207493, 0.1441931457168633, 0.15253970429541605, 0.22063414956773483, 0.253980761814502, 0.14460873309402697, 0.10657756979907713, 0.13733092845687944, 0.1107413802416094, 0.1519790964741861, 0.20870292769564738, 0.23014971235346413, 0.12240228032873524, 0.18388920193237646, 0.14570725721216973, 0.10923551951324749, 0.1552834022309511, 0.15339075137049923, 0.11725734108157697, 0.253197145798514, 0.1422367410193528, 0.12315428755696743, 0.09869464763229895, 0.1578151849248717, 0.16638392432322427, 0.1547936422209586, 0.23535174047273977, 0.1676686844157596, 0.1629231374470457, 0.11075999617816941, 0.15240332532313564, 0.12290229825603387, 0.16324909253706857, 0.15996197779332438, 0.13362873195400163, 0.17892170397024001, 0.1142871875556246, 0.12429534487666623, 0.11442606397453817, 0.10961896184110835, 0.12013381737614832, 0.17845428308411954, 0.09335273185804968, 0.10222036046006026, 0.16259581872051762, 0.12005121011527316, 0.14587147581961848, 0.14218599535524845], [0.03162567807932294, 0.09162597733760074, 0.034395562815329725, 0.07939299343213921, 0.04635514909281366, 0.04299309179787675, 0.021285691689099037, 0.0455702728621902, 0.08620158453742344, 0.019359578108114582, 0.0636818056415406, 0.030492664682829095, 0.03980069616509061, 0.014039363689540375, 0.005416507840216641, 0.08306582578487935, 0.08410193671983096, 0.021072196391140743, 0.03397822492725907, 0.04973399137417155, 0.0205222237855196, 0.08744072409406786, 0.0034061875504126115, 0.04717770918843247, 0.07822001322863564, 0.05259146102734151, 0.01996383953448986, 0.014054514993462833, 0.013335163220612994, 0.017239960293555935, 0.01968537615011296, 0.03909830079083482, 0.047286819261048114, 0.08534591795215685, 0.019980816042891914, 0.08253697230811081, 0.01881585486473576, 0.04409443128914122, 0.04973135220127241, 0.03746954806809945, 0.017372627569843205, 0.03452739122533991, 0.03092420775623572, 0.040271284824778, 0.057700394142058596, 0.03365322361670194, 0.03547581573647838, 0.017058713466770226, 0.027745687890978112, 0.022797786457944783, 0.018551171486896854, 0.03664754721666536, 0.012779715001553059, 0.015821976553378327, 0.05455612415267576, 0.08238444420238657, 0.05787913394611209, 0.049739782998879115, 0.04925201481748973, 0.013680771338723361, 0.052450788132245504, 0.01383396977138135, 0.005192077115944197, 0.0029639668871588526, 0.03842835307061192, 0.10969822895863365, 0.0505668132175361, 0.05996658181351039, 0.03405474945001545, 0.07543732907863394, 0.029066578605242317, 0.022597801120531176, 0.05907865909619197, 0.025736911507743983, 0.060710162074575504, 0.04743059481223745, 0.07643588638353734, 0.08609284601745107, 0.006445104410240968, 0.03952077146799814, 0.03849740823610656, 0.04696219333357388, 0.06498302513312909, 0.005877245088002735, 0.06489625035394585, 0.06990639643082697, 0.0697364704683423, 0.020532315078702186, 0.06446757819503546, 0.07119117950600001, 0.015672537697208746, 0.048398347721705516, 0.025627108125556863, 0.05717382743774403, 0.04173962639704828, 0.04553905477927578, 0.054017135332668983, 0.0632972831297065, 0.07793348102319626, 0.06584380918572988, 0.04256919619717425, 0.060972405462375576, 0.01914412162507013, 0.017312568191799427, 0.020313914902808688, 0.07821578442329362, 0.06650916420884671, 0.050256808078096765, 0.05544377490878106, 0.025114210345031276, 0.012307187181807334, 0.10629225567343736, 0.009824733846941063, 0.00682825849752032, 0.02778354412575643, 0.07935267422468432, 0.029272324923846512, 0.04413297700305139, 0.019814044447435487, 0.030710875251961332, 0.021862153699921987, 0.05738518726561339, 0.02724133007558844, 0.037393379776227864, 0.055584329060248794, 0.05487430345026716, 0.06504005271821253, 0.012939288243350965, 0.029698135744359706, 0.03113582039312009, 0.042465257218047496, 0.047482972243620504, 0.06244626286770068, 0.05319767023226427, 0.062043817728878035, 0.07753303154341637, 0.05316254510093601, 0.04782855833670305, 0.10041245424579229, 0.024877293824007916, 0.07277335025249951, 0.05954871532477199, 0.05188604726666405, 0.027314652350821325, 0.08759553514180646, 0.02553737050132646, 0.053013337986363526, 0.03609510589270823, 0.03840676088246607, 0.04990343853170353, 0.03888478059501898, 0.06274917020252155, 0.01042765461944885, 0.039815788097198934, 0.02902562354481028, 0.09160930726436839, 0.060932055611403725, 0.023947266914371042, 0.02623155724347359, 0.03584479432432883, 0.06987208335269844, 0.052218533256241394, 0.12375362878364903, 0.0527782715676773, 0.03265532897785306, 0.07067246137246971, 0.08554641082282029, 0.06924035192857828, 0.040844736110058524, 0.08386068031071656, 0.054628768440095656, 0.04005498756023665, 0.042375318495736974, 0.0255324560472922, 0.03905053520875593, 0.01235358146650176, 0.027353923933039752, 0.06904955007015698, 0.04509082822609813, 0.041125457538592244, 0.018052030730271534, 0.05120457375362035, 0.009710048569456465, 0.027848336011952454, 0.054324980104161855, 0.032053967194271185, 0.06754944266210641, 0.031493872651950486, 0.02013072987357455, 0.04893840906480628, 0.024245909054673487, 0.013031261886710362, 0.06912003015919078, 0.03841406553082409, 0.031283217624971466, 0.020670239633369832, 0.02379884312470113, 0.028372466556667805, 0.07589850634817155, 0.05262217732266553, 0.07486782697660309, 0.07845820528605292, 0.07372038048361579, 0.039042146545985056, 0.027674989466885888, 0.016180615827080705, 0.058265230768630584, 0.03022489397065534, 0.01746810510784628, 0.026983328899669073, 0.04608726729789088, 0.0319085177409673, 0.025180716352957874, 0.07174295433346303, 0.02686294775846745, 0.03755175696325399, 0.037635363968870336, 0.026923769393995888, 0.05914897064588243, 0.0355378152321904, 0.03740276052286068, 0.016490636288278526, 0.023449032056716182, 0.03916064119567314, 0.09767706836423568, 0.03484811010440031, 0.042196662961355144, 0.05230601666675461, 0.009831507979411512, 0.03645516721712005, 0.060833100034224416, 0.0472483922907662, 0.022484163468283032, 0.02856751445740942, 0.01565307714871221, 0.015738623314386895, 0.06221773117900856, 0.026935184104067665, 0.03316523326981453, 0.04361695549901455, 0.024817284241679217, 0.07544466820094856, 0.08479052718969123, 0.014376945121424093, 0.015887510587250995, 0.03513065865263343, 0.08695031290933972, 0.014771837590923233, 0.044633619292008306, 0.03059349334498327, 0.07548605227061818, 0.05292983057217733, 0.14548591908908662, 0.044633879761902556, 0.04021026209116944, 0.02153133969723938, 0.1237264556449748, 0.05194889711997202, 0.05293870953121974, 0.035593563450440284, 0.05317169219075192, 0.050986395743224895, 0.04359150605816995, 0.027918480937519384, 0.026382099266254136, 0.01259853424985082, 0.0555672567908562, 0.015097793638555995, 0.025836363126854264, 0.10080269943442076, 0.04433328601261301, 0.05228696789051737, 0.04827339495081575, 0.08882635498359319, 0.08450581827351163, 0.04534970465747099, 0.05510529045075659, 0.016630828463202043, 0.0032393922541110267, 0.09429890407069076, 0.0248804232931786, 0.0355786209054772, 0.04153395094157707, 0.021813800145361214, 0.02752255712215218, 0.024713672765140093, 0.055166474062829256, 0.06686862032379835, 0.02811125164190608, 0.023884175743366924, 0.054867718924557975, 0.08058349406647106, 0.06379944993363273, 0.012267660875354084, 0.06559521365430086, 0.032118500525792765, 0.06927196071633408, 0.051461240021331664, 0.041755132016635714, 0.0263382445630287, 0.016234965934868784, 0.09197807134760004, 0.0372381282279328, 0.021651910445202264, 0.047999748344262766, 0.021607147927786556, 0.06756981294001303, 0.050025353763973525, 0.025648966529256394, 0.024885029396823338, 0.02311084445776238, 0.020886195988784877, 0.04312991127071362, 0.061188840622743296, 0.029712699075800278, 0.03163836832578865, 0.12231700708188357, 0.03955650180878659, 0.08865357151315098, 0.03596297487796795, 0.06629828318593002, 0.05125931456624981, 0.05828140671515177, 0.05097327265708197, 0.023704472583748644, 0.011246309581873639, 0.018708880262209043, 0.0710529542618221, 0.022399363280724616, 0.025477108109982747, 0.04696864379389633, 0.0493801162097483, 0.04684736058416386, 0.011929851532312892, 0.045641733543767084, 0.11318056588812221, 0.034137211154185, 0.0818778149363014, 0.06945729270697602, 0.028893126723086162, 0.05551039008423687, 0.04066838650032878, 0.02098357342484017, 0.03595627926950974, 0.05710012211854901, 0.02639074456847964, 0.05666122268584948, 0.045268077989138907, 0.03506490532609244, 0.04001345410342178, 0.03946032713077242, 0.08915275440461214, 0.09353709857790701, 0.1989962412945686, 0.13522847675748412, 0.2383867663241202, 0.11134282821008276, 0.15529285575593674, 0.17103170315104146, 0.1432407605311563, 0.20706478656539995, 0.06237327384071485, 0.14681848306809703, 0.15053615454704533, 0.1454613123449587, 0.15883610433628484, 0.13439814469987346, 0.12776848875106345, 0.26176286681044486, 0.15966029236874274, 0.12019086794386949, 0.16213126300323397, 0.14830225748160195, 0.18904410032255037, 0.18684694483395548, 0.204821374687937, 0.19072315054795436, 0.11624488694172715, 0.10215458415088155, 0.1457917107449424, 0.06844869965026457, 0.1003152759925973, 0.19552233899312635, 0.15135468885062203, 0.19258511192615957, 0.1846022918940552, 0.14677823280855534, 0.1442075328480813, 0.12107249724888995, 0.09420342653268769, 0.093509710934614, 0.11940028052777053, 0.11598617904969763, 0.08743657189751826, 0.12260494122822439, 0.08268843555162031, 0.17213503830134871, 0.28048767978625916, 0.16577502231924765, 0.16520059427186368, 0.1615393528294179, 0.10033890980506137, 0.13106612188200797, 0.13912571924588374, 0.13882601032814673, 0.09094941444815167, 0.12376695871353151, 0.15503974030575446, 0.17393623358539997, 0.17198126913318712, 0.11537606662680065, 0.10094095532211567, 0.2150956709538737, 0.11550354365740093, 0.10686572611091599, 0.14757684882610075, 0.07905305723749823, 0.2467868284833047, 0.3335143247198674, 0.1778848039647264, 0.1485277018359592, 0.2604528871034422, 0.14742450458147835, 0.10247418837201211, 0.1792207080870867, 0.1577273299617152, 0.21878079901779854, 0.11274462355481041, 0.22551601422169518, 0.19004356927208363, 0.11028626272755285, 0.10794285339333358, 0.3129777750901638, 0.23258426316803504, 0.1368990234069286, 0.1423753876118891, 0.21045880121809823, 0.29290458608058195, 0.1486148979635008, 0.07058908036279102, 0.11125912544347587, 0.13000153545891086, 0.14282400870034773, 0.18932715448881351, 0.18276153582959406, 0.25279896393899, 0.11729148562036215, 0.10408088159296783, 0.2035308536142111, 0.16928333729024858, 0.09537303594932442, 0.10354690298798586, 0.15842964872717857, 0.10576766930640706, 0.10211895340152326, 0.22427567190700964, 0.08241003153905754, 0.17384160640499285, 0.2580796999316062, 0.09988393018683119, 0.083986648148106, 0.1864482879999184, 0.1365586198986538, 0.19137015776528468, 0.1037025643933204, 0.0759110625292505, 0.13682846670910237, 0.24691998988630312, 0.1599688879064014, 0.14655277313243958, 0.11286764195369137, 0.1441178699174235, 0.13780024924105214, 0.14557398855686188, 0.11408785913860607, 0.17369588116003623, 0.2515904602384375, 0.20423087411590163, 0.1374041204971652, 0.10504845064133407, 0.09932173656359797, 0.10637654066686669, 0.12224159338661741, 0.1455826147068893, 0.10550737561237429, 0.2484004854434921, 0.16767671301720605, 0.17405658599830445, 0.07944712520486887, 0.12229305151249133, 0.16258919972085184, 0.10512625453092399, 0.28587894694459054, 0.14141848250742883, 0.1612564518807396, 0.11363380648676427, 0.14471377907020433, 0.16176968482473206, 0.12364600109116686, 0.13562451357082014, 0.09052878621244624, 0.18728081106899247, 0.11797924871526419, 0.16551320411024556, 0.07136148851244681, 0.185695959014758, 0.24672532694474344, 0.147324254315707, 0.1923883345819289, 0.09899228045176114, 0.18573772612838976, 0.2057975239210552, 0.14928772234387938, 0.26133903632721595, 0.3652488428258127, 0.1867213830231659, 0.12145698911720708, 0.1515944896926803, 0.14701362098416976, 0.15278534272745734, 0.2039571662223147, 0.20191500564256024, 0.1755797066876004, 0.2096883006273739, 0.15326146637239765, 0.12771754390409878, 0.09804885849476823, 0.2091310176277353], [0.016510924211733283, 0.020920671860597307, 0.03318693271026977, 0.07303152188298202, 0.04006448322005811, 0.009572103904980806, 0.04461095841120809, 0.03654808602145603, 0.01848901685838017, 0.059530333045028874, 0.016051101960211752, 0.034042281369047786, 0.010655560988872763, 0.07777854740138977, 0.058343379397786437, 0.024739844243853323, 0.03152979068428038, 0.05119855996341475, 0.036038783108515125, 0.025110872116901224, 0.010550691212918009, 0.03173018013307404, 0.061553019669748125, 0.04446900997971816, 0.048994030878548665, 0.04325717379669509, 0.03885108421766951, 0.023072480689734224, 0.032591341483977534, 0.026858874085930087, 0.017844070417566166, 0.0358823211412997, 0.0739990449660728, 0.03298819418095293, 0.019898023005695115, 0.026951450065919952, 0.06355380767115182, 0.06811254792996953, 0.009771296341392783, 0.034421590652557156, 0.02471789007916326, 0.049620395856759245, 0.0513268030819393, 0.025710069702097008, 0.013451284912955618, 0.04362865749205794, 0.10920880602732783, 0.05045819344119199, 0.03600254714969666, 0.05964883152515658, 0.06888506333193473, 0.043777546680141846, 0.05375747749161336, 0.02185074090507002, 0.040801934777728976, 0.05198266244523468, 0.04471845969918274, 0.03731016347545289, 0.026662832186106714, 0.04347374685288918, 0.046510350845393636, 0.07613584038711364, 0.06850575787886497, 0.029368882645822825, 0.033896594428487366, 0.03874045729096379, 0.048518462647353454, 0.06779969294345187, 0.03199850434377309, 0.03374777418831664, 0.06087637634106702, 0.03227274083802777, 0.010997112671424066, 0.038752527006210825, 0.04418776378095631, 0.05310310433889109, 0.0548198307684112, 0.026149304298263405, 0.11107043798772559, 0.004167295663782786, 0.02567509204269417, 0.007144085426379236, 0.04051539108097073, 0.036373080896033395, 0.08995703947279723, 0.03252499443929523, 0.019898616723836433, 0.02801216199934002, 0.06028424017131329, 0.023330629337579015, 0.058081204957899556, 0.009405304538837124, 0.1083010531240894, 0.04114979615194663, 0.07745185686695961, 0.031479288253092, 0.03234457307224793, 0.04209322193937917, 0.04883325200587992, 0.05671769868762744, 0.05188192571363142, 0.02987838665684385, 0.028242647212239045, 0.06252118626669531, 0.07765491613216939, 0.035741621433126355, 0.03461370635176859, 0.09491375091695979, 0.013104492231392333, 0.08845605872451298, 0.04450256080036202, 0.035961143927828926, 0.06440066041484957, 0.07678181338574618, 0.030323489486510237, 0.06854151120229114, 0.047584394623916, 0.038383184526596344, 0.021053760485242934, 0.00925244318486582, 0.042424512831794645, 0.08074605792400338, 0.03210600754696756, 0.028930092380652507, 0.044204579410894264, 0.03261442371313611, 0.016709877245668924, 0.016819242042519392, 0.024639735704347975, 0.04063884998040815, 0.016212935161386288, 0.08217209229065527, 0.024848776201026577, 0.026675480297736587, 0.0198015725360282, 0.01525507915029002, 0.032512855776135004, 0.004023827026568113, 0.027905001620491667, 0.026340180850257317, 0.057522711539340604, 0.029103605549842603, 0.029430811278401848, 0.059620574372069496, 0.01865659093093728, 0.05109138426280791, 0.01864968273308008, 0.05645612945720073, 0.04438827580381786, 0.048007156414490555, 0.03360588704386065, 0.010438464120060447, 0.04746427203738882, 0.11561976685639351, 0.02536537418622644, 0.02954182124906971, 0.028828813641842817, 0.04334220955629022, 0.0455491173441612, 0.04836479690106166, 0.027655940690648653, 0.017753003630787134, 0.011436906511775188, 0.056252342408462885, 0.03104788882117118, 0.053085208524979895, 0.013200652545257924, 0.04834308213884792, 0.022905490759219375, 0.04186957023076473, 0.04008643929996798, 0.0586402882641602, 0.07685420103371143, 0.05024306446073517, 0.07239014541189517, 0.03724142240600721, 0.004680293035738531, 0.03525678353804735, 0.0225959797464912, 0.019948584808697625, 0.014441059019807127, 0.05414198468168897, 0.03420673746375307, 0.07041872539106878, 0.02666369595024134, 0.017413873743686466, 0.05766840614078026, 0.023091527550751646, 0.061237188431644635, 0.05541955886949455, 0.03520773475869529, 0.02460574055270803, 0.028680657982946407, 0.09239498405687271, 0.07254933082168141, 0.04403533909710185, 0.06713529553024039, 0.02488794819181485, 0.06991735914902342, 0.027417547535151247, 0.06822881709423757, 0.021985503431830197, 0.010676434969589596, 0.018821464543561303, 0.012826920381837316, 0.036830737991558934, 0.006487402039760303, 0.04432864735023149, 0.016138289469264207, 0.034198218566035075, 0.028514780795141578, 0.02658139895497551, 0.13937154153902687, 0.017066324550297954, 0.012725703887671474, 0.030599524372167168, 0.039196693293389775, 0.04375582808748849, 0.012959536904799602, 0.010712379814996835, 0.02674129682653133, 0.014707417257370488, 0.041380495869464455, 0.044626720670250156, 0.06562341335079362, 0.0010058969060229438, 0.035170556511729956, 0.029861758718447342, 0.012210871735137078, 0.05128312840937607, 0.0344644456110414, 0.03098684118970508, 0.04664615525173084, 0.04328564545440097, 0.01337270727456217, 0.053911939969346415, 0.025231249427663225, 0.018659176477681727, 0.021446374800777244, 0.08658127303445533, 0.021593754795650323, 0.030410618581358465, 0.02272039625583397, 0.020303835100944967, 0.026232193096450744, 0.036135275713017875, 0.028045843054931012, 0.030688369503965786, 0.0491863074562242, 0.05628861284123794, 0.045384454405716354, 0.0241144732647245, 0.00665427370545184, 0.0934720040869809, 0.05429532484061295, 0.01713257583398973, 0.09362671554328934, 0.0966211693781999, 0.07635767646734753, 0.046682613376047344, 0.07126879953448811, 0.02028614421555352, 0.04576536481298747, 0.0635137489335912, 0.029764695378441005, 0.05154125790502276, 0.0820141019780309, 0.03561493730352771, 0.02119728131219745, 0.02697310737153936, 0.03565201212862327, 0.05105801347282626, 0.015336504720541981, 0.04447755569051351, 0.07347586820082319, 0.048913614629136945, 0.0621180133443446, 0.06904509909931691, 0.05481963541599051, 0.03532506878517809, 0.05812358877231037, 0.055596762667259866, 0.027083439354394234, 0.0364224054670382, 0.0551943481719542, 0.0368298723122045, 0.014914992610893905, 0.00818765757890839, 0.0947003647865307, 0.07043906502545842, 0.040614557332329215, 0.07032964468723343, 0.04356967638276758, 0.0321966108505524, 0.02612172896342893, 0.022235274908222982, 0.012637098158349194, 0.021618487944285718, 0.02492428374206347, 0.025929940766805125, 0.05953441246322567, 0.07121472138791315, 0.029861285659154097, 0.022968286986372644, 0.027393314258886442, 0.023939981418211135, 0.0616502323968997, 0.08007979891713589, 0.03249094183106096, 0.02765069107314752, 0.014703590648188708, 0.030320612826354565, 0.08347582838107502, 0.04338057140909857, 0.022098901681602005, 0.060716298438848994, 0.02940025969198154, 0.05683611289808347, 0.013888827412419263, 0.06054009055538524, 0.027147549422337647, 0.053799734901516676, 0.025021343251630187, 0.0221601274285105, 0.023810261665212534, 0.010989334006162902, 0.07734877207586843, 0.01739853474822256, 0.08116000587300909, 0.045772424313209714, 0.04531216251874163, 0.03197827004647303, 0.049359171365898465, 0.007053470631475531, 0.03612664956299048, 0.07791032218524525, 0.02918296842835844, 0.028262295452277028, 0.05846683063634461, 0.0334963288098093, 0.04752526795792003, 0.06767563266499389, 0.08305659442539177, 0.020661831818400853, 0.02845049452697558, 0.07664645331040507, 0.046711912408711455, 0.051390947623839306, 0.09304928443124218, 0.04130666414576192, 0.021424796019170075, 0.045113879811739734, 0.08597718972352245, 0.14847539335248933, 0.15709434215339924, 0.1725885929960397, 0.22680866501985059, 0.16398312734259715, 0.14536254828976047, 0.11180684766581944, 0.11771615113942854, 0.2741479038471176, 0.2138104358868253, 0.12290442798046336, 0.1666253645934405, 0.1868949325815324, 0.19290953484033385, 0.16312504758036908, 0.1245809960809927, 0.21286638573773448, 0.12002351603681043, 0.08950939897688166, 0.17026406772915395, 0.18009486037396616, 0.13777614811495428, 0.13742074460512207, 0.12913953332651046, 0.2114681680236132, 0.1399919042183507, 0.21654454240154838, 0.11988799508300521, 0.18934316572643098, 0.0930900020044177, 0.1292642984058588, 0.09102031588554384, 0.10360400718186172, 0.16550695283278344, 0.11095413051906133, 0.3026405217186097, 0.13408270033617176, 0.08645462337881328, 0.14861811553278279, 0.11858487952380412, 0.1330333590627678, 0.09457314056494544, 0.14703853416346735, 0.10797198005621472, 0.11015108651331357, 0.2900196828188435, 0.1314241760560582, 0.12713480380273637, 0.11847533661151126, 0.11575745583902444, 0.12262583244591953, 0.14289712413184105, 0.10281436205390962, 0.07148489761616915, 0.13713163834425712, 0.10191249270592967, 0.12600330726033257, 0.08964721053358048, 0.17196173389111796, 0.163000006709368, 0.12438870035111906, 0.12490081480674206, 0.16350122739470777, 0.16447199869059748, 0.12201586557972817, 0.11093242724816646, 0.13973995322181335, 0.14248260927777137, 0.11785600815088519, 0.1747154829002196, 0.12075007382419803, 0.1094202233117915, 0.1540858229441989, 0.13039548851309285, 0.15251474515084298, 0.15465321830443798, 0.13953349252621974, 0.21461424598049736, 0.1339762600799722, 0.11860708841272902, 0.21678293364182596, 0.15639288140641106, 0.13676589264744712, 0.23845439656607567, 0.15135015361011028, 0.11686021642338847, 0.20495899472265475, 0.172047397842811, 0.2652246955662005, 0.19962950489453732, 0.12788593769073486, 0.18615673025769575, 0.17420735210180285, 0.19674089376724538, 0.1950324410873075, 0.13011733730954508, 0.13464189855562103, 0.23065896164025032, 0.23919577049391888, 0.1327974499473649, 0.13811341066273952, 0.23986943757101414, 0.20200713537633422, 0.19461988741832395, 0.18640440648361561, 0.25536260056880217, 0.19033454478748385, 0.18548485582634328, 0.266705145158114, 0.18725548420221577, 0.11378228198736907, 0.23409454422372006, 0.13456243991611466, 0.11895931265767544, 0.19344286993145945, 0.17081470108560978, 0.1640869628998541, 0.09120672039927975, 0.11715545138764767, 0.1668976169199713, 0.17074040587871306, 0.11620952432314235, 0.10966282803565265, 0.16182937839579198, 0.12216199685128466, 0.20660484269742044, 0.0908543659193862, 0.1612498482028323, 0.243701501298816, 0.11276340036983452, 0.2120152314103419, 0.14602622558032313, 0.1464720734304959, 0.1472388661556667, 0.1319845387291524, 0.21048359182332793, 0.13578133176892035, 0.208002753976372, 0.10651673475701003, 0.12759224256320348, 0.13283059091096924, 0.15688703876108895, 0.1570936526742674, 0.11568057125494366, 0.17588503869070163, 0.23869664888949166, 0.09821634829765367, 0.12485987506806852, 0.13349043776191052, 0.2797259432413886, 0.09367652658012607, 0.24388994360643051, 0.2741472909767782, 0.12976205637378077, 0.08467700062019211, 0.11494671264963766, 0.1522611240826307, 0.12508345016789052, 0.194523467592174, 0.10558282761203666, 0.09457523964585797, 0.13001561615495913, 0.1988005364734319, 0.12994371114238618, 0.2827255451871503, 0.23335765957111315, 0.09081618409724006, 0.10594072856850202, 0.14853470387958712, 0.11498509365464411, 0.15693021547650138, 0.263065921082612, 0.2210563406228058, 0.17318067170919912, 0.13487350225688952], [0.012071929241140044, 0.043511131943594065, 0.027913539670407776, 0.052421998548051046, 0.024646674545722145, 0.03250369719500023, 0.054128524516859365, 0.009383719053960616, 0.06390546118059466, 0.07262480580398152, 0.06347063350521269, 0.04342246875767747, 0.021144660647898432, 0.05079557090216587, 0.003738807844779184, 0.022082214371391365, 0.034001674878621296, 0.0214461698722575, 0.028333844233965202, 0.03052501657587146, 0.07217149625742628, 0.03131734875721797, 0.04470421429423075, 0.041252804334245385, 0.02639825797579702, 0.07214364130049944, 0.03979724110855211, 0.019968736751545823, 0.04488650108537367, 0.026917188698726318, 0.09200918983908431, 0.04465116653591395, 0.09250627364963294, 0.03148713490865644, 0.06890842901362527, 0.028637937089848905, 0.02453197203125925, 0.04412318639937909, 0.05046578154208199, 0.0072254032655168455, 0.015635010880237867, 0.06158760853952939, 0.05347567970954603, 0.03652659342474034, 0.020984952383103873, 0.014453134480713597, 0.03526950442803002, 0.0122800667116779, 0.07116903956498831, 0.047580483745062546, 0.05411377732431697, 0.05695842649607409, 0.025472544141173847, 0.02731625347458307, 0.04213700769469143, 0.01683698846928535, 0.02349168974755993, 0.04962893007623573, 0.06596334188455535, 0.042808905108681614, 0.08765765721158636, 0.03860031682697516, 0.026166707900683248, 0.0730035443519873, 0.010903342551882229, 0.019015591223573974, 0.06529794855704231, 0.038934534175261375, 0.06415877964407687, 0.017173402574694446, 0.06494657466969182, 0.0311331371701653, 0.015803774304297424, 0.044220579157192866, 0.06756903153033027, 0.06414278755865752, 0.03762756519380116, 0.1572239642301875, 0.02810458093130541, 0.05850922977251392, 0.010731125986503979, 0.022295085307691368, 0.08645538180585831, 0.036772377413487246, 0.008437075697246098, 0.028523140729615287, 0.03424003547538192, 0.05908503294772199, 0.026738692127588778, 0.037051233417925336, 0.04391865624535469, 0.029684604716397105, 0.0161488653130589, 0.04442353117009325, 0.04276232696288536, 0.04685776405817559, 0.01664456058924477, 0.011689745212694811, 0.03444161619089785, 0.04697915068977783, 0.023131218566108617, 0.01167823857207212, 0.02256650642882432, 0.034196916216563795, 0.03878015979763962, 0.006391430375046067, 0.04315627235618811, 0.08920732284745864, 0.08183450032506259, 0.027896911732011268, 0.04296742019153411, 0.018006063539594892, 0.043268983042047876, 0.05293059282966199, 0.03932368002771851, 0.022789235001490004, 0.016781742038625865, 0.023552524789627043, 0.03090301201859069, 0.0519339852185259, 0.09006008595949219, 0.035473582590179104, 0.040621026944849765, 0.018372418276304682, 0.052297631834423354, 0.03812444982148948, 0.08008057266593942, 0.0368849961687961, 0.09878120790686339, 0.04859391464701584, 0.038429869924701994, 0.0482646347354016, 0.021102803518935558, 0.061308767856849786, 0.01589224884106267, 0.015351516213418256, 0.029612017885571527, 0.0659926830520553, 0.013487804324306069, 0.05133568587142134, 0.029421194959732316, 0.05177694102448802, 0.01784547427368741, 0.10964117073003324, 0.06234755626909676, 0.040416339742800886, 0.02759920038853682, 0.015565551603363167, 0.08668924546650342, 0.02425473055712158, 0.0723005207856336, 0.03539922992668806, 0.0160645870228989, 0.06168227019389311, 0.073178740999391, 0.01862029176986506, 0.058457848255432425, 0.08984376571231312, 0.02327765435761502, 0.00939324823012876, 0.09625384554026589, 0.03456010317970668, 0.020850482884974732, 0.03288754171902134, 0.03960169716587952, 0.060477447545816826, 0.03657903597359696, 0.05089168812358572, 0.03582465004235987, 0.04046396359861378, 0.04465535320642014, 0.06470570130453956, 0.03171356943165583, 0.08614457993497772, 0.0451728992254263, 0.08622244511160158, 0.07247899628935323, 0.05964377151441671, 0.019246254551915393, 0.08351905106176293, 0.02919103724942092, 0.037979961808530555, 0.023561212226688385, 0.004575315528669425, 0.03993890991794967, 0.04672687027543303, 0.059283143284940915, 0.04584790312594945, 0.004316567895828837, 0.02440596780469341, 0.015578661282967417, 0.0368100421262845, 0.0555550147058262, 0.07007435354734622, 0.04477930623256872, 0.027535494431973468, 0.050937339302993594, 0.06049712834459159, 0.014244728879402242, 0.024524713348176692, 0.018161052702775887, 0.006150681499181496, 0.032566543217868574, 0.06210441911412824, 0.050591021595943364, 0.03975920101267196, 0.04540180246676168, 0.012162838022284692, 0.03775049166213121, 0.06482915637353737, 0.08965747611176583, 0.05256796511070383, 0.05986600212993161, 0.08804097696537934, 0.04033493523996684, 0.011107701293733573, 0.008605407239238342, 0.032235443847434174, 0.060362614796406804, 0.035083965593648535, 0.03030060835543179, 0.10629759530626959, 0.04639336538891639, 0.0205934546407192, 0.05973136983811856, 0.07342630231212224, 0.06054184106629222, 0.03315680630264744, 0.061818143548143495, 0.0024502800360712554, 0.03878243124833511, 0.10720565464467773, 0.0732293870720652, 0.016650505431537187, 0.0543681568195743, 0.0538487070720763, 0.0193090392877498, 0.04140874919211192, 0.06272569343808197, 0.0922903900725707, 0.03680899641626785, 0.02280078186172872, 0.032728122652418194, 0.014936337735684169, 0.015241725280159905, 0.039690471434545134, 0.04147346063907589, 0.10195032212763064, 0.033905549996322205, 0.02751340620189665, 0.01146446844007099, 0.05794755325862958, 0.08249906627761741, 0.04084060689614665, 0.043537014224115884, 0.08129338178062633, 0.0641580671823073, 0.03069559179787194, 0.10760548359323895, 0.045392165080674236, 0.02604396529345503, 0.01977113969323616, 0.0442461971373808, 0.029535772984907515, 0.06686338794327552, 0.08533032806289774, 0.03545507390592848, 0.047370851445462436, 0.02544688019571045, 0.09127680978347218, 0.018711002325759302, 0.0385169051737795, 0.015646492623003022, 0.012723868149482917, 0.019177002118780248, 0.03390327088474747, 0.023097727117278886, 0.03564533567236316, 0.05561952313949024, 0.04563980683263752, 0.06432860218469175, 0.07018860023949416, 0.06197032691430181, 0.09099924846762612, 0.07010613853532462, 0.019338344066073338, 0.014090070091638596, 0.009274576422608188, 0.033901899587363005, 0.024339067261485804, 0.06720202944932446, 0.04218403017148376, 0.03522582975546679, 0.09032878363805433, 0.01960727540145238, 0.06165717315349368, 0.05944464611069811, 0.04817820086534466, 0.06629632200084387, 0.035056451545848, 0.020918641727597966, 0.034602724481374025, 0.02164570130257597, 0.02429004912565072, 0.05346179436591845, 0.028312843848740863, 0.07508168042066597, 0.020356086127820517, 0.03599354178614674, 0.05934140810202207, 0.05955733764435976, 0.04942313204669664, 0.020408059447823514, 0.056512157297542984, 0.049504720410632516, 0.05053401316305803, 0.047560101975837064, 0.043190489673326095, 0.011486725209491148, 0.038973983872922204, 0.0772240223182786, 0.06219949828641069, 0.03805648250084731, 0.032769774852861325, 0.03355438295271128, 0.04716460908492727, 0.08991703436139131, 0.0932417716830969, 0.029285476738286596, 0.026387073092102527, 0.01002896426906509, 0.07231460914256112, 0.021167007432649695, 0.06912166958734875, 0.018786454325421684, 0.07736623888054202, 0.09151681746927001, 0.08509395163386099, 0.04996291759814467, 0.024875790376456517, 0.01805505103191301, 0.06947748678466005, 0.021601925123362772, 0.016276112517281886, 0.018688261005727035, 0.007992855305107491, 0.06547707523549758, 0.1403180125259584, 0.06269988010547335, 0.07587307222908543, 0.03272237316254647, 0.017773620972049334, 0.12042704519004592, 0.15843101236368382, 0.12747698463499546, 0.18628140340649313, 0.17095687168259777, 0.07664228579209698, 0.20386348899093368, 0.11399117884256187, 0.11284924052175015, 0.18291343574322041, 0.2196071627399614, 0.18518399777671984, 0.09891295970808114, 0.14898905530571938, 0.2479833505687214, 0.1312855447852804, 0.1275034453119001, 0.15655481707184546, 0.1314074293740334, 0.059468295244920644, 0.17892167332672304, 0.15939991440503828, 0.08024394091579222, 0.16131416894495487, 0.1059012443968846, 0.16314131928788078, 0.1019870560435999, 0.14631871794981344, 0.14581538286180268, 0.1499252300709486, 0.1842018424142753, 0.1480048468276378, 0.2683814987540245, 0.18402732758512422, 0.20060482675269728, 0.130625314890377, 0.15388397409790947, 0.1506001535322397, 0.1242124388415006, 0.11024267998554053, 0.07766760254819548, 0.18965862541189119, 0.13754659752932288, 0.13406333363344594, 0.11537031330648931, 0.11176146461718506, 0.1388686507820122, 0.1686313964666859, 0.14108655193159658, 0.10337337641225708, 0.194975980407288, 0.09870183353702869, 0.23853906460346716, 0.15265581258122, 0.11643882209975874, 0.2473844383512774, 0.13569038181054976, 0.17360375142626225, 0.17501942062329862, 0.11451313752801189, 0.22540359847968627, 0.1544888158358874, 0.08363877528256948, 0.2616792100091135, 0.15622458721120513, 0.16238912819854676, 0.10497431631290144, 0.13553655135535425, 0.1161307321801301, 0.08802515724974294, 0.1561738415471008, 0.16286865327387087, 0.07432762773767596, 0.1038570000579761, 0.1692353035773962, 0.14331831927261046, 0.17377632039208568, 0.20353744197035992, 0.11337534374287052, 0.14801751792190537, 0.1168966975303427, 0.08025959975296452, 0.2812380169428164, 0.12276384318547866, 0.09897551078709865, 0.08823007044772949, 0.17838329737705572, 0.2389961126590929, 0.24441603150579239, 0.1179371904882212, 0.17434956866406626, 0.12543322293147927, 0.08389944435968515, 0.21381653394670258, 0.09080897520987258, 0.21026003204526442, 0.09881534478476933, 0.09020342867100432, 0.13397826723033382, 0.15202682375186874, 0.11906939949239455, 0.05456570408216888, 0.1663238477082022, 0.1698771013968414, 0.2905716032030121, 0.27778584089490677, 0.13018268460948623, 0.24045163374995035, 0.19268785963856405, 0.1293169899332908, 0.14829881008594267, 0.1240767953136275, 0.17517308253915082, 0.21695723396635827, 0.17102442531576081, 0.11918692504085841, 0.13353566759296004, 0.2671928673742279, 0.09253916946510155, 0.19063860508463076, 0.25964175320921407, 0.18111404842667042, 0.1560582082358099, 0.08406470484671094, 0.14933036279774484, 0.10714303461774703, 0.12377272735560134, 0.1143800910382021, 0.245939014299262, 0.17279434889074297, 0.13740980486956336, 0.08666985578113988, 0.0980359499132441, 0.2557781879459658, 0.1397872668120169, 0.13076555494579578, 0.10429883360742562, 0.1495105466775356, 0.12329424415985424, 0.20443796300359313, 0.21809862836474375, 0.2960607457545496, 0.14311552047729492, 0.1543204909971645, 0.21390428165754966, 0.1789006365523223, 0.21319644705903149, 0.1521313181447406, 0.2036182642463715, 0.09570423874162859, 0.1892923281317757, 0.19895726274098122, 0.1070412828196441, 0.1216019789177564, 0.17065894008884508, 0.15609315716691557, 0.13827427380507992, 0.17926792974673933, 0.07584968356475716, 0.17611186200332257, 0.2384698255768707, 0.1539531671592305, 0.16112243245926597, 0.16407099762751212, 0.1305200084443054, 0.16175592588561197, 0.08099039400657339, 0.1626410025862917, 0.12158889413600969, 0.1232612181094385, 0.16010826994334498, 0.28882415664772837, 0.14832312571665934, 0.22767966102448203, 0.09966595518973567, 0.11722897284574087], [0.009092979110597123, 0.01597747229219925, 0.03328328741894614, 0.06579781326675607, 0.12700820011236977, 0.043274939375659155, 0.03926855234068729, 0.025169274829808744, 0.01444441735774519, 0.04380802165776972, 0.029227843943742976, 0.037404131820245136, 0.05102067817783645, 0.0494366726507583, 0.04160533884480115, 0.04249486651632094, 0.018228901279789787, 0.05148577781754637, 0.06652499158536235, 0.020059527746672114, 0.08070412993190751, 0.018254536496956023, 0.035222937773552634, 0.01805688772771147, 0.03152424803814821, 0.05386446167023913, 0.05388297801536899, 0.07241420823359683, 0.017206397981593208, 0.04233624418115905, 0.017666962380791386, 0.059949298869938626, 0.03616815237628837, 0.07075981071759617, 0.021139774922161333, 0.03145024777510234, 0.0307280145540473, 0.025901428889483217, 0.045025082560436386, 0.04458091244281781, 0.012747798821017628, 0.02536072977818549, 0.08498889799680441, 0.06434845918368909, 0.03293984254161197, 0.043297010368757674, 0.03483309478108441, 0.015660816551967254, 0.04070604738268641, 0.011489938948333505, 0.02388277763290511, 0.040294715623942115, 0.04726179499900149, 0.06966962929694884, 0.02297906009780784, 0.02573323237048763, 0.07612806459468219, 0.010586130440295225, 0.02981242457134349, 0.06734813773824323, 0.08893965172671503, 0.0517040056236569, 0.08624164327498406, 0.019020806367118514, 0.02455698863242663, 0.07406362617808966, 0.056944621591678554, 0.07891244945987579, 0.012227648103068913, 0.032627891538844954, 0.07917426766887789, 0.012453155659679926, 0.044395718348002246, 0.028341070358310978, 0.053259654406217806, 0.04573029713825353, 0.06861495605159192, 0.045472803495584, 0.03577351367341415, 0.06648226686182522, 0.04003916784460026, 0.021540607445903366, 0.054246398635328784, 0.03894876042801527, 0.04847349711663781, 0.05276079710212447, 0.03479982358253291, 0.004472113430364839, 0.06743522661347544, 0.05893455795763482, 0.06640465449421637, 0.06260612243486029, 0.08652583125137514, 0.0797759761072455, 0.0579151439089929, 0.05919903832217378, 0.04242100414910144, 0.05784991535268003, 0.029943188119138923, 0.020749102639515075, 0.05354410285250314, 0.031028455085751992, 0.06520158235704707, 0.003162701825438548, 0.06774078844295395, 0.044263303880729986, 0.08312944938699085, 0.11719298203505817, 0.03483039432115132, 0.08673946252994, 0.09310924613307561, 0.05765721359620652, 0.07276054892328478, 0.008266120304113195, 0.03584038165788497, 0.04203173572257642, 0.029707175581866217, 0.018955346069208557, 0.08288921187481574, 0.05069015720378488, 0.07197134046544952, 0.06795351573776814, 0.013005939807983176, 0.02707269688647601, 0.06345201373821305, 0.04503804476811521, 0.01687738237031285, 0.0210347653351604, 0.05044222816884999, 0.023414646200234854, 0.006198712339204166, 0.01532239625380645, 0.053034397743402, 0.1499510165904799, 0.061707122086156765, 0.07098674128252654, 0.01518548389280876, 0.036363780588632634, 0.03143388413703971, 0.04934284220179243, 0.05681200028066674, 0.04879169939686695, 0.055942390895178246, 0.03458830287619945, 0.04872183600861219, 0.02416626272362567, 0.0728131178766489, 0.02627220203829629, 0.08060296036062703, 0.015037132881491657, 0.010205984205728578, 0.01313097780615452, 0.03999542039368422, 0.06274394548287796, 0.06757446309371341, 0.017695378497122757, 0.06393757175594088, 0.02549421676855174, 0.014698002994390986, 0.07483801083459009, 0.0068981434319979485, 0.05245128225895667, 0.037180181337340225, 0.017280382922880592, 0.018641068074371547, 0.027400549959331274, 0.06147695479974632, 0.01158873651987843, 0.09925170846643949, 0.05906761976920309, 0.019747793163743713, 0.01911912992176029, 0.02806285212206985, 0.03392487456421218, 0.10508451039992994, 0.020750150264751528, 0.04253519721509468, 0.009046881684973355, 0.026844732102847872, 0.059273348850828994, 0.050385794301907864, 0.042043813098702705, 0.029651852542414304, 0.05084557346098366, 0.06484121459746553, 0.03570872561765775, 0.0614988036273468, 0.0094882718610367, 0.05648016546582503, 0.01816244889801789, 0.017082192146429614, 0.027453061456101078, 0.01495727970670428, 0.032442885135570844, 0.05292715309488197, 0.03220629037147568, 0.04322499810387531, 0.048660399587524515, 0.024029835870849992, 0.042367324368247104, 0.030362713188233397, 0.05405249029037453, 0.08843696015256067, 0.09589013763733449, 0.060380832367246194, 0.04480957436645704, 0.07343731099559415, 0.027610029041346525, 0.051641695862335545, 0.06027927592156395, 0.053185838004273754, 0.023669324469782656, 0.016665903798815225, 0.06921749952579699, 0.08679108919515725, 0.023662274545659463, 0.043690442483151154, 0.09901184633734728, 0.00783475055809944, 0.10339454342160495, 0.06681418977677822, 0.02344514799094008, 0.014235085747655363, 0.0445318368503884, 0.0195130140280291, 0.03804577642210549, 0.010919981023987696, 0.06205300695352978, 0.05413461874629702, 0.020226942855984937, 0.01039415455212997, 0.02485266026680268, 0.03946806461880765, 0.057003840188225435, 0.04475786343156811, 0.03476852122994681, 0.02781503416988398, 0.021710391682122025, 0.04852988118786485, 0.02296187866088604, 0.06711018316808247, 0.05189157076059811, 0.039019278821445284, 0.06366669838767379, 0.04396072596371655, 0.05263725776345499, 0.0366277591655812, 0.050835258087083224, 0.08848452655177924, 0.039130177709364125, 0.07473298018017123, 0.03745914842452734, 0.07142794663987814, 0.015660399034048523, 0.06455733305624416, 0.07932047554922682, 0.027219741717882218, 0.033134448026577314, 0.04642423490182527, 0.021445754269558578, 0.0438705152801929, 0.03476439584647456, 0.07864932890140242, 0.043267178904986194, 0.042656449781310175, 0.019146402651864677, 0.10560813149617565, 0.05618278545537784, 0.05200912695257895, 0.011404425341395602, 0.06243631138556427, 0.0469266162103703, 0.05102432858679564, 0.03447636593914321, 0.023225692528930884, 0.02346978537858494, 0.07821298054149074, 0.03907323056351274, 0.06747781344118618, 0.022899178194723303, 0.01701774883023914, 0.012922918859628901, 0.027222716054248235, 0.05413915015636914, 0.03866881274828508, 0.020432700665907997, 0.06840959086173004, 0.04594007882499888, 0.03030841670660002, 0.025641476104576743, 0.07322479054451951, 0.08913635246215329, 0.061931260260603124, 0.02080450420297923, 0.018857553030454346, 0.0174506766075689, 0.07185748447814296, 0.07089815853584198, 0.026568185853501482, 0.065124467946589, 0.07590108040359712, 0.05433001713226399, 0.03971394819898471, 0.05968836166204945, 0.05142585825054877, 0.043535573978818236, 0.039136586034850734, 0.03491860168475298, 0.045531922500700726, 0.039040744605083624, 0.027817225181347424, 0.034785156829222556, 0.017717759755830613, 0.13843968750969057, 0.05495069007719717, 0.0077264922794946025, 0.06854362560496216, 0.017340289083339514, 0.043921709105732946, 0.0161866640912429, 0.06521485099989562, 0.056282556916196505, 0.033638147006352107, 0.00913423007248991, 0.08182242677937593, 0.02972296273876583, 0.027456376701593403, 0.029318631108429645, 0.07052865900820302, 0.058167221310037764, 0.023092481330217376, 0.005461423096412252, 0.0324518445338453, 0.025891215022232746, 0.028239364525483503, 0.03149039844321388, 0.046480530872941024, 0.04292191456883185, 0.012771483386806663, 0.02780187277934484, 0.03284002511551784, 0.023666097324401624, 0.0521741499523482, 0.03371592408286468, 0.06295851904958968, 0.05526442606482775, 0.01670607361912487, 0.007046978993927159, 0.015658841960342423, 0.018441406409105948, 0.02192694941655763, 0.030822377434120547, 0.22685800108217427, 0.1602318705690484, 0.12719992893717944, 0.21402300996405466, 0.30977056331692204, 0.25905057847980534, 0.07956289641198613, 0.14325969822464452, 0.14331897810822533, 0.11030181431241574, 0.12877531980554904, 0.1216517516501969, 0.3428981969914129, 0.08488710789430527, 0.11292260876225849, 0.08252232470699856, 0.14122737421383783, 0.22940230165277758, 0.22521624401692422, 0.1219424207304274, 0.20976117091073146, 0.1306016734170337, 0.0669161101142245, 0.1670439090699919, 0.09757286508477504, 0.1657684952501328, 0.17699942082887699, 0.22124698926364222, 0.17055737215184397, 0.08135293745585988, 0.1469572675564597, 0.13253630589573615, 0.15110684408535882, 0.2501296071756271, 0.20788240156346754, 0.10472055734886278, 0.12447144550782059, 0.19171046934300856, 0.2538394952012647, 0.13151446717881388, 0.17094864389829098, 0.18890335464910155, 0.16815959355763851, 0.23975954991915535, 0.1811344263654563, 0.2008746888849043, 0.13514451352098297, 0.17460181077401485, 0.09348939428286207, 0.12224276550114156, 0.09675407031130406, 0.18998427406674434, 0.08636913562734282, 0.1257652454378624, 0.06782151878841462, 0.0961609803620846, 0.1687361666512105, 0.22242797508595452, 0.11392110478012793, 0.12502990828286256, 0.15778884682203495, 0.17210689223101064, 0.16447441952843822, 0.14289242035198596, 0.16057061932740674, 0.169142882730211, 0.15004677758101495, 0.1639596544085972, 0.11749023947143748, 0.11587026994675399, 0.1333761987306418, 0.1269108609807107, 0.1618521618506601, 0.18531764947598983, 0.21216786676837554, 0.16153492484121554, 0.2278425006736671, 0.13802920227810261, 0.1424099841425496, 0.2589586785724086, 0.14798210933804512, 0.11035616825064344, 0.09207117401303784, 0.08912672273694508, 0.12360582744041759, 0.11151055550022472, 0.130813205614686, 0.13309594844618153, 0.1757998803570386, 0.09452322993667857, 0.24797398897428669, 0.15814201335512823, 0.19184902400499393, 0.15709198260259244, 0.13156824655109836, 0.1392332779904527, 0.15865978153963245, 0.12243698411170514, 0.09246365617840521, 0.08682177101652469, 0.15441471981185098, 0.16446714169315754, 0.15114930067812243, 0.0907757269939588, 0.11015534596217257, 0.09601517084745631, 0.22592715828889803, 0.15149163472796642, 0.14431486176627298, 0.24702489796665408, 0.21898817901890125, 0.1264341704307064, 0.18088250601243588, 0.12306571247116213, 0.10053172647472351, 0.1778986395126389, 0.14176034158275974, 0.08398742189690953, 0.08993398022627638, 0.20826443428954772, 0.13868898784200992, 0.24140029574834534, 0.08599398237082266, 0.1555525748840263, 0.23185991171386935, 0.08186209481209517, 0.1613764212496819, 0.13183219448452996, 0.08106019993823382, 0.16963293385361472, 0.14910738524650374, 0.06697707539123875, 0.17081221896073512, 0.15799883152208022, 0.12157415460434653, 0.18084744982902082, 0.07080107221319791, 0.19079220571344901, 0.14422270138898205, 0.24229433567773914, 0.15743784065688812, 0.1610825805654449, 0.1097895849436041, 0.11041562433444685, 0.1722218054196527, 0.1311471126973629, 0.21134196269896724, 0.07272824299551787, 0.14302916704647003, 0.09837344228740662, 0.12079602377789637, 0.08714244776074925, 0.13275556025966523, 0.15874409717657875, 0.19005096968143217, 0.14622283438521047, 0.14417544908581242, 0.08986480248671386, 0.12792031205589735, 0.19850959160154868, 0.1452269966924383, 0.14202767562481666, 0.2012213743141582, 0.0728675943889445, 0.16737692749067662, 0.12725520984179553, 0.1520206184396821, 0.10820595096916923, 0.18152660209565394, 0.25450868832488216, 0.20346748282111463, 0.07276261736068033, 0.16866721873802526, 0.1416489983638448, 0.14652239008536264, 0.19471111316834727], [0.01854894983191644, 0.036735118727289864, 0.0661721927744727, 0.05365325505995462, 0.013270208540733063, 0.003613652778796912, 0.05908974438845631, 0.006243721919975454, 0.04809459002928869, 0.06409494536778619, 0.02013687389872728, 0.0933946521892663, 0.031773278324474255, 0.05751138492938011, 0.05460148038823278, 0.02913722340317984, 0.010660695693185254, 0.0064748377189971515, 0.02678592144812067, 0.015054666718858627, 0.023313290852632736, 0.043133485070880384, 0.05536317479826751, 0.02178907082716544, 0.02937034778897801, 0.02399702432505306, 0.05312391511735417, 0.027790220582016537, 0.015321514295083622, 0.036303566077784184, 0.03558890563586066, 0.06774442736059427, 0.03828366970523231, 0.058411457801177624, 0.05276359715348771, 0.06772933542848596, 0.029511982124418985, 0.06116839373604425, 0.01017877563548785, 0.06622497623245563, 0.025284622773347844, 0.0038809011147672976, 0.06718531341081665, 0.05289226545081024, 0.059469930842638984, 0.028987229133265156, 0.06456243520181987, 0.015403879280652732, 0.007250932187983587, 0.01468730457652841, 0.07561148384646063, 0.03744182717655936, 0.005821588800303759, 0.022360777347198418, 0.06404096298220177, 0.0323359047873847, 0.05350998512679531, 0.03390865265241554, 0.044047274746962135, 0.05539778282024688, 0.09372243056854895, 0.12302153218056887, 0.024469828894061428, 0.07988470696633862, 0.0746337334895807, 0.033449233554664164, 0.006461410591709278, 0.08477775650399347, 0.05764772942770393, 0.06574164370014783, 0.035789785380925865, 0.01508179963791683, 0.05322434924422734, 0.028520783094028314, 0.02263954333630541, 0.05752445055892872, 0.029280907023818265, 0.03591281910156531, 0.06361035645128259, 0.013698422004498783, 0.02008114866311512, 0.06015734153709585, 0.013603824509998724, 0.11538075508489726, 0.015913915722781134, 0.021515230783411575, 0.018841459438385024, 0.0696540700512067, 0.03158767054217958, 0.05231643929296444, 0.06547853080255371, 0.05281351927307345, 0.06431239942509322, 0.15834165586819574, 0.024221874961269, 0.06305755506600104, 0.04865662660449744, 0.04788640946630509, 0.012692730505800536, 0.03192224220613078, 0.05031526058671936, 0.041202820927625707, 0.02305718191388634, 0.047999085678208264, 0.041309196066351674, 0.0421724047872328, 0.0026556430713108353, 0.029238620885617794, 0.03945435547540265, 0.09594242313816663, 0.020400655208035343, 0.08420103785371588, 0.02628257869923067, 0.08226544776510808, 0.06619723618871744, 0.04830324556678534, 0.027909691993808074, 0.022541468760239023, 0.041272190189169305, 0.04112613935684485, 0.012225948345486917, 0.050801699605560115, 0.005368251004256309, 0.051660675690659595, 0.09278657756024793, 0.07640757943473517, 0.024319484138921387, 0.03266785451541505, 0.023759772640562827, 0.013168981512858263, 0.03461988868131753, 0.04968920204367849, 0.026642538516992526, 0.07024417225752147, 0.04739530497200547, 0.036136103087976094, 0.004796883956934776, 0.0583929835908836, 0.013333428031464499, 0.038765558161802834, 0.03950518923961828, 0.04219382843603531, 0.015536982269446938, 0.04324972359163146, 0.049168453777148846, 0.0595968256464168, 0.018503865557572535, 0.04224265504988932, 0.005077273573636288, 0.04810740284982228, 0.01294499847121657, 0.02606789788020955, 0.06279946387475056, 0.04098020343770904, 0.018066676416163965, 0.05088357525246759, 0.04765112471256045, 0.021752760174774358, 0.05818998944314738, 0.05252732414632075, 0.006883637557151698, 0.023382614148900877, 0.05402620581369247, 0.04725001639716568, 0.011093617724855582, 0.02457151748991061, 0.04155620579577742, 0.03184885481342433, 0.05725582182827977, 0.028160516841096744, 0.02305898605094802, 0.0365804570666965, 0.025057692208417484, 0.023217683079682534, 0.023172711803307457, 0.06306862120606727, 0.03462553474931948, 0.051808025042015704, 0.04623822875380997, 0.010712152861449267, 0.005991635421636485, 0.032837680886469545, 0.06405985854085415, 0.02226138509990227, 0.02014069667746944, 0.030523932561458602, 0.02287867959708937, 0.07632237513579669, 0.039358138662552646, 0.05374589041175862, 0.03270885171068292, 0.07729859331682806, 0.05047489032750169, 0.016181715163252047, 0.06586935821800463, 0.0270224396034234, 0.035045446692815715, 0.044278989530979626, 0.02201329327128347, 0.010862109784577644, 0.06642787461920131, 0.020068908493304928, 0.03542541864237959, 0.04466889764092142, 0.05916269894148554, 0.02519375899986875, 0.058460135027886405, 0.024579779748173974, 0.04294566329448454, 0.0919653772706947, 0.015584944161556423, 0.05953492574213494, 0.09235229763773181, 0.01673523667118242, 0.008582751146487651, 0.030021715961817293, 0.03532389284021432, 0.01739331768945821, 0.02460650855585212, 0.07147287003575795, 0.05835660973623876, 0.04295784026204098, 0.11253609442182126, 0.016031821442377425, 0.017990582817864996, 0.08381610165440267, 0.04820549274764715, 0.11421283106169394, 0.03790475112656432, 0.021126309011672294, 0.03454220736579549, 0.0411711048875605, 0.03261306007663089, 0.038399517521142, 0.061371456831693656, 0.014454318086556612, 0.02272023537736987, 0.05251407082523069, 0.031811969595090035, 0.06234733410359872, 0.008757838626362143, 0.013292514148258395, 0.03119044054690148, 0.053316540265035246, 0.03740972043165276, 0.049871067486463055, 0.00986214958116292, 0.03739098575146448, 0.04271160428141875, 0.0544159607060494, 0.013018405016121126, 0.09725496157883637, 0.04076479866559948, 0.020044150446811994, 0.054887032001129085, 0.03242937134458654, 0.008343289298335872, 0.016676720960306066, 0.015816558396533852, 0.020065235101708004, 0.05400746730306456, 0.03004969540803183, 0.028748579338313113, 0.050266280755280494, 0.05377351554230817, 0.03966953808201417, 0.01552405166289499, 0.04259771382015559, 0.05119753723603584, 0.10601339966899927, 0.016453023286416166, 0.049714145866493066, 0.10874647196502456, 0.023062647951226083, 0.021122216186936826, 0.055058593561332074, 0.02262386917737463, 0.08184436753752732, 0.03429754186541804, 0.03801507544853995, 0.02025986548453089, 0.027009594224153027, 0.029606436935043143, 0.020177468897834904, 0.03195805298615127, 0.04077702159843138, 0.006284538126971212, 0.03539125878183592, 0.016357130145714167, 0.0759654700936329, 0.09462580910973972, 0.0269493471545678, 0.03067808285836251, 0.08080908397753393, 0.03919209676584409, 0.024801100634278792, 0.08599421219719995, 0.031613374707259, 0.015651467406461318, 0.039578266366715395, 0.06367271983875863, 0.03864149788334485, 0.05041456473390422, 0.005663640622515232, 0.04802796719295364, 0.04921410112611709, 0.01747566256521931, 0.012811974964044508, 0.06587213911716977, 0.0017877636081163563, 0.014719416109484532, 0.010657436946677345, 0.011094150155962957, 0.017261650157912124, 0.008897710959577273, 0.0870056474401105, 0.03357365772488617, 0.03586582726828995, 0.012036416277800117, 0.06712945794025738, 0.05958701972098601, 0.04436884398361848, 0.04170193487117368, 0.03591258927518803, 0.06783250448924881, 0.03594034081024509, 0.018321948403853084, 0.06686777762708164, 0.02357964047170695, 0.02898926309670412, 0.01937478495341155, 0.018957820533203985, 0.04079217481757364, 0.02384464177603443, 0.16284950107576388, 0.04537425394500456, 0.047627858622300054, 0.034328679509100415, 0.028514301990188902, 0.0384375499561429, 0.04511714717673679, 0.011248416323665411, 0.0539732538163662, 0.04822548381203125, 0.04248071304191986, 0.025983555430185892, 0.07445826105052426, 0.023455562956270673, 0.01998724926623606, 0.051105943763808864, 0.0023926493961499225, 0.006054144844623102, 0.09015796135269827, 0.12506484189220976, 0.2104536990725225, 0.1315559585007929, 0.11318671757415419, 0.08314041976606654, 0.1385485792472478, 0.15707407146692276, 0.16773865888676337, 0.17335235201303037, 0.2020565633692088, 0.16681970577807198, 0.20120940802078094, 0.1884185435670999, 0.16350357162375606, 0.21229211090793534, 0.1195034342667749, 0.05912249081677968, 0.0861672331548987, 0.07471690765551983, 0.11979286228456806, 0.17445348083011566, 0.30874182980868126, 0.11564887819751618, 0.09037522388802421, 0.11248647490696562, 0.19205523955245174, 0.14520789045960675, 0.11042156151586002, 0.11633875569508922, 0.11697586505643784, 0.2131711814792887, 0.08746618119579169, 0.18053344571061675, 0.08526935512500425, 0.16171219758689404, 0.143819754462569, 0.0837707186057683, 0.12720872362655017, 0.14136844164421483, 0.15943273361171448, 0.06988939693978719, 0.12366555931587374, 0.14614630220157487, 0.1414914447213373, 0.16884164163662543, 0.27767822086330385, 0.08720707493804156, 0.07855927526590326, 0.1021226842497145, 0.1764199672447097, 0.16123155402320047, 0.20385156866283188, 0.18224353781871258, 0.13537610190049296, 0.1276190403187948, 0.14399561760646684, 0.1111524630217783, 0.16922384290204895, 0.13931934030786639, 0.12011254311449106, 0.16232142134779887, 0.13140422712650993, 0.20888449053370187, 0.1174843176117828, 0.1487132636529784, 0.08421143366684837, 0.18690308375704676, 0.18021476845587456, 0.20839591029911272, 0.1329570260619925, 0.11403643165624912, 0.14187902392398927, 0.17536362392767785, 0.13699758827926653, 0.19332561251376906, 0.09968758185183811, 0.08578609675168992, 0.10950082342230505, 0.12203281910549249, 0.11723926140656395, 0.10428629274810515, 0.08674982769955551, 0.20294373915080102, 0.1470613635836109, 0.11291844890482965, 0.13413531525481132, 0.11238499123963619, 0.1683735159496146, 0.1575605066553239, 0.23986272664079744, 0.21298408748642092, 0.13161696974308262, 0.35230955649768153, 0.15002007175597454, 0.17503463512947484, 0.21538669243454936, 0.14720494378237955, 0.13755862510973407, 0.11920413137563776, 0.13275831817619263, 0.24491104687894547, 0.19072604636030813, 0.19224591883680514, 0.14386199655071383, 0.1045928811354022, 0.12255967309277867, 0.15807292754611663, 0.10292429567104387, 0.12811115221871486, 0.10523523819903213, 0.14471042360509598, 0.11739102342436392, 0.16493604878985113, 0.2613989444028947, 0.09021295114390313, 0.2113762987597335, 0.17200484931949647, 0.11513238171896628, 0.18277615278718934, 0.14332526002920445, 0.09451973657574385, 0.09778390698615583, 0.08866805823579912, 0.20208544488395416, 0.13080851715658942, 0.13547348699742748, 0.09050798692530201, 0.12597546762516423, 0.08554603543973739, 0.13038246501838008, 0.2096355018476325, 0.18340080555888916, 0.1682210491309243, 0.1303645538827104, 0.08925039231056169, 0.22118295963493087, 0.10217601163012367, 0.15813320334399902, 0.2119791180255913, 0.1486102095054042, 0.17965527912301404, 0.06189765581380456, 0.13664546362575025, 0.07256022459196468, 0.15875773354163095, 0.1356562755761608, 0.14803492343954502, 0.11221501165099683, 0.23760734846995724, 0.10840502657717276, 0.10667348400719705, 0.18361641334429865, 0.08156528936759119, 0.13809562210113774, 0.12290740806248882, 0.16420638068549095, 0.16346776467417518, 0.20891959268239238, 0.14520573009166027, 0.13364308844170264, 0.13217325682841963, 0.1377157650647625, 0.11059753957294649, 0.13494320093624054, 0.14699615417949616, 0.14630791611008107, 0.14917287044227123, 0.1286118213207491, 0.1500815273292603, 0.23719180705806903, 0.13619685785905009, 0.08305398972644921, 0.21365481278588697, 0.1929710517006536, 0.09432892705644332], [0.044647412705084974, 0.016166280406797608, 0.05652901506231678, 0.08808707247578329, 0.05255055576262455, 0.03138538694099313, 0.03227254548560708, 0.05663159423537793, 0.021180931080673492, 0.05250362521638313, 0.03425759038016681, 0.04321767813375881, 0.046776597042598074, 0.048297327537570274, 0.0510542098462822, 0.007724040319331952, 0.04128789116117743, 0.04648562918807711, 0.025834099337038015, 0.04579439188443846, 0.06606012943290895, 0.02790181660994647, 0.09414299751722044, 0.012856108331752401, 0.03049210543864437, 0.035696353297680616, 0.016228097956627607, 0.04051539491141035, 0.012237043213850309, 0.07646214021670242, 0.018767058894398714, 0.05321411430955895, 0.0010388245620209003, 0.014197963999674447, 0.02748535589254912, 0.03892392385751009, 0.029256217925238515, 0.05645485009036719, 0.013030840538352007, 0.005455771282750873, 0.07226518114968654, 0.014486701580725852, 0.06346620934744997, 0.045816167933686126, 0.08041266412023576, 0.04791945083847931, 0.01194213383695892, 0.04352111406924744, 0.02568337153793583, 0.04913571500970472, 0.005421041644313523, 0.03727647475898266, 0.017079156523029652, 0.040157049623948914, 0.08955845924755258, 0.03168022353953171, 0.056565178242782434, 0.029234095221205108, 0.04279960863172047, 0.011494891706763977, 0.0376933989595742, 0.032423422671854496, 0.04557003154449406, 0.0017483093618084829, 0.11997986434688492, 0.04628028315041335, 0.007069419145644192, 0.04343048586780506, 0.003423274902161211, 0.04828144270446032, 0.06237666761021941, 0.029000170273526065, 0.02463827630685222, 0.09852407049507865, 0.03011793468988711, 0.01977356819195613, 0.03570279609712382, 0.010255469655197476, 0.06135434625790485, 0.045387380861587105, 0.037306087887695724, 0.02115546823329022, 0.0469996550330712, 0.04419741265836262, 0.014781582229320082, 0.03851010997389113, 0.06772215718463545, 0.0277349473382797, 0.1036194515144152, 0.01545096687491863, 0.007961354248466031, 0.02606898764028184, 0.058089903886279756, 0.049724982180182016, 0.030122487167377147, 0.0721362255693924, 0.013206471940652739, 0.0037690247465375693, 0.03303838826175178, 0.06770102847968379, 0.010541509649145507, 0.07321847798002344, 0.05353636919490753, 0.012160181612407249, 0.05549970698813277, 0.0714861769830027, 0.012945328846633916, 0.02379582856871909, 0.04925396834169665, 0.019562608645027204, 0.036309162350071054, 0.03899107912495252, 0.026447574885922576, 0.011113095510330413, 0.03261997785058714, 0.026437320799056082, 0.011932392071391787, 0.03213276891338249, 0.042428990615712064, 0.013203556018490947, 0.0345281419915057, 0.04988550441339613, 0.0354507455091563, 0.050665703677241845, 0.03020781978604294, 0.054912408663620876, 0.06318177239248349, 0.05869271549125833, 0.052340892819507476, 0.0537936368416394, 0.0677825708783442, 0.010343965259380639, 0.006676306394154147, 0.0723062664450657, 0.01375954241431769, 0.011571353984876506, 0.048824660329809116, 0.07670520459331813, 0.036898065628784324, 0.03699438203306448, 0.04377019606650837, 0.06154133682890285, 0.012020700941643408, 0.027699856680908033, 0.05368135516501723, 0.015474447469797828, 0.026678590614709164, 0.03627797874111322, 0.03816748864107555, 0.04356195421649083, 0.014952881404409006, 0.010741915377307563, 0.022047577621114832, 0.012800283504710084, 0.04124937992122385, 0.02125641755429247, 0.004210372308960124, 0.03595292380440139, 0.03006237033273905, 0.01702058910121841, 0.059914120112455664, 0.09262852596058961, 0.04667399488689919, 0.01898705636361434, 0.0864664211328472, 0.0034153303309839463, 0.03125824890429935, 0.09468262985108361, 0.03838900679482087, 0.03262799496071474, 0.04712483763033825, 0.02496579804668023, 0.06079254716995263, 0.07894011289482156, 0.024780619273623152, 0.040041646139035304, 0.025559213583267508, 0.03754533331600889, 0.05533551519376136, 0.05348749278533844, 0.02501463998229273, 0.022077713604836215, 0.07829206379791422, 0.028037984908047705, 0.008010939768170038, 0.06456363029898175, 0.19238248167018737, 0.04284279300801216, 0.05708843544726411, 0.009096320211556892, 0.039272175936569134, 0.08197878532472157, 0.05591224533535781, 0.06506319623440504, 0.05725890916261462, 0.020710507129889824, 0.07487662932685307, 0.07448099087923765, 0.02409409149549902, 0.05234293444382568, 0.026275743279726278, 0.08475111962686624, 0.08918657718646912, 0.028840301130267403, 0.007535359088046057, 0.0741998672545437, 0.04149543587118387, 0.027271808883655938, 0.05523745593945346, 0.03414023720148591, 0.05042786018983011, 0.06897088050121261, 0.025539080792617415, 0.04509670029003774, 0.031897208367985104, 0.002367730471192889, 0.02223551431069932, 0.04025999651921373, 0.046685183601033305, 0.04342155328260795, 0.05966534838080407, 0.028056528066254915, 0.06204077635981864, 0.052409120610043894, 0.057485280483360254, 0.051397662384495627, 0.05352429947966049, 0.014725406917052404, 0.05410897395303173, 0.05024076236652271, 0.09036456760499748, 0.049050951211322705, 0.02400626143020007, 0.016788816860606594, 0.06307884847985641, 0.026426045900030483, 0.0631332560442388, 0.04968534096054012, 0.05979756366521601, 0.06805728234711193, 0.06246651440197903, 0.05616223131636939, 0.037756551417612264, 0.05155972445443754, 0.03428140039285345, 0.00960232607359367, 0.027239321010007013, 0.03544419928784332, 0.08501536633458831, 0.06581141132741206, 0.03157808295180721, 0.06092807578463709, 0.027504437227523135, 0.06324210181652058, 0.03529121919024376, 0.07534462477891676, 0.008403951970620022, 0.028842708561569456, 0.01343595262076105, 0.03460276661620986, 0.028231207604309725, 0.05553787348852043, 0.04482344438832614, 0.010008669642340994, 0.02565561425721934, 0.022194321763010758, 0.004471566156303931, 0.0423595026105402, 0.023485155017565817, 0.06116743229569928, 0.040402868086652416, 0.028250838607369412, 0.07112150380928671, 0.03718073292064571, 0.03471209885432355, 0.12006591900341934, 0.01167522497369998, 0.025992733163518772, 0.04903866699145687, 0.02409473117891579, 0.03880946649118297, 0.05081999378519193, 0.03768594492407095, 0.033538938620157784, 0.01515125891479153, 0.03040710415300583, 0.05504454733924039, 0.03164581661563247, 0.029601909355410648, 0.05388412714725541, 0.020216568110270366, 0.021011755884354635, 0.06357258448617593, 0.015888454790617672, 0.07211368726266008, 0.06443310423844284, 0.03272076437790548, 0.019851071392035773, 0.039717127463870475, 0.06538712119142856, 0.05826320446607086, 0.02024475823066408, 0.030615522203245954, 0.05959382258175362, 0.02350589876333552, 0.016432723871642546, 0.05197202148396642, 0.039731300090469664, 0.04416148696515349, 0.05139554798182461, 0.0383645647595967, 0.013206072617322208, 0.02180777677905656, 0.12091325821294902, 0.009280552866027482, 0.024559754209833282, 0.05749750341619215, 0.08200767450034618, 0.01739217430323122, 0.030940921879523707, 0.04545948888746001, 0.036852192283878406, 0.008308723411192338, 0.05192292673933891, 0.021980495132025213, 0.011968864559856875, 0.02663370743844538, 0.011298040626570584, 0.02495337018532859, 0.08335349180044667, 0.025949749885307207, 0.06702246610075235, 0.05693836265333718, 0.023000847638374376, 0.0542238871416738, 0.030008855260788437, 0.04271167705977156, 0.029480543791226325, 0.028624766123210712, 0.017491901713994243, 0.07506376162411706, 0.08447103022087006, 0.021326552903760346, 0.027995260184510585, 0.04099866232624458, 0.026187011145896492, 0.06754174347846739, 0.01493187623113514, 0.012253071688446067, 0.03433387358522704, 0.0063431232645657035, 0.04788496922100744, 0.10654705651705304, 0.25254477596571373, 0.16340391890656564, 0.1866992124386372, 0.17773313387747736, 0.17529397121360227, 0.3610665236990298, 0.1445694327835114, 0.07912700770482903, 0.1428633090108633, 0.2668315496656203, 0.10403923705340394, 0.17957624949274525, 0.11876566095217583, 0.13775103575279637, 0.17289795462162266, 0.13125206674298934, 0.08742947026246017, 0.149822604932612, 0.1340104582449121, 0.22834102472951337, 0.15707417871923218, 0.15272666039245744, 0.16113813726171372, 0.13464572899524244, 0.15789194693488462, 0.1508062924709051, 0.1199507223622453, 0.2163677446303829, 0.15354925496203287, 0.13350819567999533, 0.1485117518853757, 0.10651892576847347, 0.13952282858231377, 0.10863287644761224, 0.12390466301792091, 0.10566862179867684, 0.21126346933024548, 0.10634398959096401, 0.06688608712847195, 0.17185849588244193, 0.16101021590011735, 0.1408667919496375, 0.08182300134531914, 0.12688391766841375, 0.18249357359543925, 0.12688286046707822, 0.10493009771791198, 0.11145515202154076, 0.220196345640767, 0.13257825687046976, 0.09753092943179993, 0.14566478529764762, 0.12752892539626168, 0.19282190970355467, 0.1293826896336771, 0.130670023781638, 0.147658038824316, 0.09508067381478126, 0.1721580362608356, 0.08004190054752174, 0.09065091594933503, 0.1277958840552357, 0.11036437305231249, 0.19012235375421663, 0.09958406805150932, 0.21028468475466777, 0.12587066679712267, 0.08400536367609616, 0.09030293583148911, 0.14522397830601663, 0.13441191896075202, 0.21410298954334953, 0.24028424353849506, 0.23292195472505786, 0.1496438459763604, 0.09895690251141788, 0.09454959102215306, 0.10004743633251037, 0.16613255555350936, 0.16660138604141053, 0.16840127897599053, 0.08728903868506033, 0.1546034838763937, 0.1744320610117528, 0.16118958772670838, 0.21231604349468985, 0.17163852139586405, 0.22204739792693048, 0.12560416013002396, 0.04539553586754107, 0.13931842100235725, 0.14056692981431562, 0.09901157054569452, 0.10959653078668541, 0.222649451104864, 0.09226096463539908, 0.0869672587742248, 0.14775763025447247, 0.23630136774191934, 0.13371419672283436, 0.141139320067821, 0.11199139058589937, 0.0809145283194319, 0.09348197089087579, 0.14805022987627214, 0.08660086956355842, 0.13117144364983807, 0.08553810642972108, 0.12294646322486863, 0.12040174130590693, 0.09918501285175163, 0.11238602545833397, 0.11994437915423226, 0.09868802097175391, 0.13155966636634644, 0.1168940315443662, 0.11211086199769091, 0.12556714276152273, 0.1491188306000925, 0.21161812207391187, 0.13935693990319006, 0.16629789264932757, 0.1984433403178569, 0.1615377593665354, 0.148169647661909, 0.17019806159359796, 0.20015243651165118, 0.10112492367625238, 0.13495855333824314, 0.18190933962262448, 0.2089350216931874, 0.1724338892006105, 0.3467752454021285, 0.10621910959842706, 0.11255503211530948, 0.060408151062626037, 0.1445504644465062, 0.17581198454624222, 0.10724264136966198, 0.22565130534912312, 0.11224953157286491, 0.08936668445746745, 0.11158838237245237, 0.2113520290942923, 0.0912710334805231, 0.14304831924457706, 0.10962925806281068, 0.1283544234390701, 0.21533545647417346, 0.11473433775526863, 0.0493163662031293, 0.08403238359718554, 0.20689869870341596, 0.07491147866652859, 0.16713870478974235, 0.13011100942329054, 0.10468316459727865, 0.09587348288586063, 0.11043434752331627, 0.2245036903167925, 0.13084263871273688, 0.15826388262212276, 0.1337185327804858, 0.1820932926550027, 0.18519708255846656, 0.09045004003470944, 0.3028949241965048, 0.1357615820222324, 0.1337430016287873, 0.1509769768604348, 0.14217887073755264, 0.12788130285879298, 0.16483034397805893, 0.12161124092076095, 0.12385795463717754], [0.04869331455519123, 0.05610605791932153, 0.015580532452722472, 0.006198004665484111, 0.028482574458804824, 0.029254666597191847, 0.018701127452415325, 0.047665883396421714, 0.04698074798309996, 0.0404206911222108, 0.008689388670327683, 0.056479039316576336, 0.019531963212836175, 0.04865879080288353, 0.060672221570125515, 0.019674852017253157, 0.02360001841049281, 0.043265811438041354, 0.018808498505442854, 0.03869121315919104, 0.02474575844262877, 0.024205662625571413, 0.04719172093656756, 0.07411604957474817, 0.049490463514361656, 0.044351358026746786, 0.04249331135783465, 0.012348293544604413, 0.023144111825874256, 0.045756753984718554, 0.12104747681728295, 0.07125928472246855, 0.0063631502393212535, 0.020024046384459062, 0.045188167357757214, 0.061248875102929534, 0.026427191201477285, 0.0576475800405587, 0.051882645836280245, 0.06437806848196254, 0.031500660190959616, 0.06343535515629957, 0.02478408390626071, 0.042939412017022414, 0.05821569169300699, 0.029660392507550218, 0.04905143001627538, 0.014037992392155915, 0.0370332571647821, 0.03279819671485213, 0.045620309894964586, 0.017254548522854046, 0.02909627217318743, 0.02467802477880351, 0.0943495961086404, 0.0451422403866966, 0.05747837803116249, 0.03481099697490854, 0.047208900458269545, 0.06228721152330118, 0.008647833188484994, 0.04446518337053638, 0.05315140235207735, 0.02645817945801443, 0.011930068909761407, 0.08641000641810317, 0.08110723007590541, 0.07428602916338752, 0.008821372213142534, 0.023616994918894865, 0.1616643170916265, 0.05630054466065861, 0.02246547475337021, 0.060207087456459, 0.06754914388781594, 0.04374563145721632, 0.08314228902060179, 0.038408381158425924, 0.06652789505859537, 0.02275104360324481, 0.05682081795267521, 0.042154566429915934, 0.08890561444023926, 0.025050538862424514, 0.008409849890027075, 0.01787085668183863, 0.013556757025540838, 0.03596474837151266, 0.07313102904346681, 0.02361482114440972, 0.06426527735687072, 0.03023825454405479, 0.012655268806303221, 0.048163940138634176, 0.0639816754377417, 0.013491594544311446, 0.07359406790666043, 0.0529636150496381, 0.045749813228124575, 0.05792135688205881, 0.05891403063170372, 0.08071707681782785, 0.015383827886844595, 0.0848797228067152, 0.07077429744024431, 0.032149255125513004, 0.02944742389503987, 0.08249991663521336, 0.034473052608870694, 0.07421597808359132, 0.028176654483221715, 0.024345454519554496, 0.04643222902931514, 0.04762533819302917, 0.08693086959782147, 0.07743285022555821, 0.053591358986112385, 0.02891832910057518, 0.03897966058444112, 0.021636916189304283, 0.046927447415768146, 0.040976005275883985, 0.03953705849726835, 0.04052845288007971, 0.016706730539519942, 0.028774936593347983, 0.012216061023214172, 0.0514456233189952, 0.017274493621962688, 0.030559099827622695, 0.02803275444274468, 0.051619525277806874, 0.07852697699901559, 0.03261888234485542, 0.039889558533867525, 0.029455904488361655, 0.02286945398326122, 0.09345679724168393, 0.019076196439263803, 0.028202418020115267, 0.010564204046292412, 0.044195213986019936, 0.07186837058754698, 0.0788876818372838, 0.028961952062203523, 0.022514266893267635, 0.08827841059575159, 0.010783031316203697, 0.01668847657950415, 0.029881834052503112, 0.04006309277047554, 0.00714856943476104, 0.0722586234370547, 0.016879678718865882, 0.06970714462260086, 0.022026854942763047, 0.06948896278176578, 0.032325279147874926, 0.13846668444814222, 0.05726230293211918, 0.022692797938361767, 0.03573044804075072, 0.010253255661096304, 0.03964770457617218, 0.028101679373292193, 0.014783717699409013, 0.06209177866337761, 0.035829307856939496, 0.07333151425325102, 0.04019436193630099, 0.04930159219750955, 0.05825432167658883, 0.055808302525791435, 0.030928126295968413, 0.0055988252748765295, 0.011970333533451684, 0.05837677317040582, 0.03220905977932196, 0.08381909705818662, 0.051115270884286974, 0.06846753775232262, 0.040167008766964565, 0.031210420119966713, 0.04753611576292784, 0.008228888430993163, 0.06278088624258676, 0.004532087581127041, 0.04441816089374404, 0.04088972845385152, 0.053193855114401355, 0.05030249373146123, 0.0457215752272356, 0.012331196377354284, 0.02534570870921016, 0.029848133844714013, 0.0013373334748452651, 0.0518474172830822, 0.03462460012205186, 0.010259189969679762, 0.040668918931436156, 0.06659109731234851, 0.02906159328807506, 0.01430013810374564, 0.01860204930116813, 0.024355842671807737, 0.020978023117828756, 0.029548601127199592, 0.04422203855468862, 0.039787159391468575, 0.033847537988256064, 0.036082948077349894, 0.044254693052461075, 0.02053680052349885, 0.05347813885178297, 0.06823286203847778, 0.04153873516066421, 0.019312578613959977, 0.11756520117482833, 0.05920055134582424, 0.02179685811091575, 0.04215074748161339, 0.057507937533720854, 0.008546716285749309, 0.016988283173451503, 0.019425551684933807, 0.025880018647219387, 0.047435007478681304, 0.031106733949854973, 0.0218107549458622, 0.03744257028184591, 0.08128933683638612, 0.0451374446762906, 0.04603899226734235, 0.017013847527484742, 0.03517886473526878, 0.047718866037264954, 0.03933776072376678, 0.07924016655212449, 0.022961658410607808, 0.07676053912408891, 0.05111953033314598, 0.075146866842143, 0.04893759318116692, 0.03832242992376128, 0.038957340612767205, 0.07818232936364028, 0.06022574935829448, 0.01551512099291769, 0.04876486716731902, 0.04389797570183874, 0.028754436080494238, 0.05114619785379018, 0.1545842091042188, 0.015755496400919174, 0.047138175221099976, 0.020555901010670972, 0.012522661859439987, 0.010799104798465006, 0.07172840632378094, 0.030055211241086646, 0.028739131558986924, 0.05092780916921554, 0.07904986265085398, 0.03339724299768287, 0.01823548772071879, 0.029254622547136202, 0.04186644459203367, 0.04230678810047046, 0.0441111971233641, 0.05650531613237916, 0.06637683784168574, 0.017222545199817228, 0.052703080037909175, 0.10066634344477808, 0.018395263018206726, 0.05541759385396877, 0.04082704330944727, 0.014266320109938183, 0.0474227462414532, 0.042265419352559314, 0.017925898183978373, 0.06760383490473032, 0.012204057383050602, 0.013126128469593825, 0.06606139347798402, 0.012488612124035436, 0.060418918428401795, 0.07891729879643648, 0.009470996578344175, 0.03389074151674586, 0.03837195750806601, 0.06478319875895977, 0.059523970684817726, 0.052870271066504146, 0.042133024037485166, 0.0675198563464707, 0.03368812275209254, 0.013573377303058102, 0.04627176808313497, 0.049421109574576544, 0.011005609544114241, 0.013139981254484626, 0.015975203714333475, 0.04900084140019552, 0.0049159780704236085, 0.056351297985642194, 0.024532590647258108, 0.05917516702245321, 0.05185291779437854, 0.05952084121564704, 0.09926411142993359, 0.03505395409921485, 0.0179854653505308, 0.06748267809950537, 0.029259529340291218, 0.04226775209028875, 0.039495808492985465, 0.022173338614764716, 0.032676453852365096, 0.08030874429330712, 0.011298402603114805, 0.033676520350479314, 0.15080868266522884, 0.053802887353325085, 0.020943497450301246, 0.041572872038570144, 0.029592310273719412, 0.06567580610393517, 0.041000952929138176, 0.022651881182325945, 0.011711945483130554, 0.07241645287121497, 0.022995839338569392, 0.04998016223732022, 0.05075290746566269, 0.08299600453146043, 0.025029917690722693, 0.022580129387337836, 0.025614766449096705, 0.004817314564265432, 0.07450951999353786, 0.055412721534770344, 0.03566120135327501, 0.00833458175146652, 0.14460651143904657, 0.08364635955301986, 0.10616291704918109, 0.025394393596798185, 0.03130836446108597, 0.04226471072122936, 0.02008696710090003, 0.042559156614926555, 0.18664874256618563, 0.11121385730803014, 0.16843276518967845, 0.1688031380575511, 0.11805843922399706, 0.1792637315849143, 0.14349027536809444, 0.14804115939524867, 0.1056420538694628, 0.0791404448870209, 0.13358262878271843, 0.1205983884151905, 0.11938287501013088, 0.14452783420922297, 0.10858536367454838, 0.16226702910517493, 0.08002246489688274, 0.11469326778164796, 0.07645398138030883, 0.08910518800539356, 0.165616549371231, 0.22471663211622547, 0.09382232843387513, 0.13101632616692974, 0.14603358002439623, 0.15402209975065725, 0.16678494070806812, 0.09115451916811929, 0.07211396305431282, 0.09853126406068764, 0.20202955110899865, 0.1241012794836875, 0.2216438534519365, 0.28013932428533034, 0.1469508630614127, 0.16579711629498392, 0.17281218341762022, 0.1376647436090054, 0.23787212377834707, 0.22506428281626395, 0.1579854403051638, 0.2562083156719323, 0.11153403609510391, 0.18080859384950132, 0.1435990292098253, 0.2965183453934808, 0.1286269438963744, 0.0738190143038669, 0.09548264014865122, 0.13386068805571527, 0.1398200553751761, 0.07296527059929026, 0.07857454339823416, 0.12259763274942675, 0.19241455011069777, 0.14410853896650577, 0.19030996868687292, 0.0969955105815203, 0.12769440038790628, 0.20839823920640255, 0.12880170387366127, 0.18247716399210115, 0.1881823739818027, 0.20338261560086282, 0.11931408031453049, 0.32933028955613414, 0.313698326748225, 0.11539636029591484, 0.19282508130756118, 0.19228865122122152, 0.3356411073717379, 0.15574705396448413, 0.09946435149158202, 0.1301386345538401, 0.16696927678440848, 0.15643225832571908, 0.22837663249623394, 0.06351237380576712, 0.1454912357392811, 0.24187563798360287, 0.23507001929946486, 0.14051488180074, 0.15704522059569437, 0.1324845183520548, 0.06529034130395421, 0.17878115747965154, 0.1452576402094095, 0.13186968682754424, 0.2564149142633523, 0.10855983762491135, 0.15172804946139937, 0.13677292533459204, 0.14321903427762372, 0.17000831693651217, 0.21555109490309993, 0.13746983551930997, 0.18885334442940452, 0.24413712953607886, 0.0752169332436977, 0.1945705513560003, 0.10756778440648511, 0.24190497915110282, 0.19913196143123413, 0.24347276276638433, 0.14301265019082254, 0.13045478371843217, 0.1368595239135527, 0.1466548773309877, 0.1347903510735881, 0.19275666965592295, 0.2280928122420465, 0.12782458170887925, 0.08629352274921634, 0.1746111110814156, 0.20007176745322444, 0.13922943222907283, 0.17151138144395045, 0.17812492656371287, 0.12985418610755475, 0.16939438939575227, 0.24854291651037433, 0.06512024680212622, 0.11255677879577684, 0.17138177468892069, 0.1537256390457192, 0.11612726180183312, 0.09525531887887947, 0.12412525037483824, 0.08057148180781834, 0.1491392698259123, 0.1416728696635654, 0.17347259717362543, 0.13787362514243973, 0.1423220219270837, 0.18658877320347295, 0.089371434202598, 0.11952749708847654, 0.1635054408782913, 0.1348830936777015, 0.10050901962864785, 0.18635186817376845, 0.1943285595024786, 0.13940434542394456, 0.15269780952122905, 0.11698040029694957, 0.13430368605880968, 0.18489332869648936, 0.21133096167637458, 0.12338252813224831, 0.11848182537622991, 0.07779355506382643, 0.15376454099051415, 0.13293503933856565, 0.15631409692427806, 0.14372486681226762, 0.1112813036888838, 0.09849534985879738, 0.1517533610064176, 0.21582245856763857, 0.25023068481635663, 0.1360325319992919, 0.1200681100148828, 0.08744068578967164, 0.1494899848776479, 0.17916771012448496, 0.1614275346359899, 0.11166899014384517, 0.10890957208410387, 0.2317674295796502, 0.23303858395065033, 0.18580409998614944, 0.12777499283754057, 0.09045187864572772, 0.15040683890542678, 0.05468715966168431, 0.12786654800537134], [0.11233417662761866, 0.046743417774597486, 0.015398361532378103, 0.006039916197844451, 0.02969379968670828, 0.03935723084836237, 0.028055802197946657, 0.05424739071919073, 0.0410640632523404, 0.0754348163102423, 0.07744785022711562, 0.013479123590514066, 0.02037674560391855, 0.02518060335498904, 0.035145988071998285, 0.014969872276959641, 0.08483008030922183, 0.03425580156486362, 0.059930100706556154, 0.03244375081492528, 0.027742251986637715, 0.08088501095170937, 0.030729924028198567, 0.004364403862235767, 0.04817712451181105, 0.03263872019165466, 0.048001759325064, 0.024516910742667895, 0.030184701167707963, 0.02651767001577443, 0.13447374225624148, 0.0784042956788213, 0.0460153776070764, 0.022497391891515544, 0.10114183123674124, 0.04362165544843001, 0.035166534550127485, 0.03653567922752231, 0.01966548659237883, 0.018549759969896367, 0.0034960867713145433, 0.024748313345856244, 0.0639097091381348, 0.016343164362854535, 0.01885057588468396, 0.03543379198339197, 0.041241228745709506, 0.07002088061023144, 0.020858042257567568, 0.05218125924828553, 0.05606738963134347, 0.05088652469097607, 0.0376952069270755, 0.06006955169141293, 0.06296988396394639, 0.015377113126188278, 0.10576566215604545, 0.034072472894143675, 0.054201425443733894, 0.04694752274982391, 0.028069852250477964, 0.022304826115648595, 0.05381758475015241, 0.04483952074341717, 0.057502697492318774, 0.051608811538185806, 0.03444096118572258, 0.09790949177958312, 0.03234802046790719, 0.03080026239096638, 0.04704507255566217, 0.04087539877922785, 0.011085181181589443, 0.055676627333366105, 0.03428307812540762, 0.0027353004148725664, 0.02086454634404471, 0.050510593855212775, 0.010785410019208588, 0.0140629745193667, 0.06089435642464988, 0.033461977427284566, 0.09130234349398844, 0.045479640830308206, 0.060990833707394145, 0.01924529311157042, 0.09189264488316352, 0.08847036924693855, 0.03730102404651623, 0.03994771609863928, 0.054647372885336803, 0.02644176410901691, 0.039594614683019544, 0.07263590641800435, 0.07327895296076614, 0.031549427432999495, 0.03573143246373342, 0.057409610148639455, 0.026200758593697703, 0.02512884262438503, 0.0033105153781962733, 0.023878410931736715, 0.029717423923073277, 0.03324105682212018, 0.10263514344490345, 0.047241206386036454, 0.07487896589502212, 0.11454656960502749, 0.0018424284104595803, 0.05187907203611347, 0.06635571679761333, 0.05142180947586895, 0.02661331800834066, 0.012816218133535118, 0.0749012437318602, 0.08209958972950136, 0.00757051534169624, 0.03773524651243802, 0.08945993267961087, 0.026278627600761193, 0.061018091115740046, 0.012233745205336282, 0.08145890273754636, 0.026845344973187295, 0.08147280723337205, 0.0751590706227768, 0.04157706253951596, 0.03390173487845929, 0.02334115538565863, 0.03253200414380239, 0.04438335751934398, 0.049179811030626304, 0.07632537053958063, 0.09641687671143202, 0.02204973224340187, 0.03038817412039686, 0.039332995656877756, 0.00010509978936522292, 0.07583712738367819, 0.04998824446492138, 0.023757679305309733, 0.025268400861551205, 0.0819450161690193, 0.039306596267007055, 0.03897330205466959, 0.028520030412642706, 0.1973492441879165, 0.05268751313128779, 0.04031332006918327, 0.08348110672687331, 0.01807090139106637, 0.024898949214407516, 0.051849788325207855, 0.06363369915033541, 0.04502914282643507, 0.14291590860774442, 0.04394909291858635, 0.01733664442003975, 0.01200931495986879, 0.07143935368907067, 0.04608716770646073, 0.09612564072613755, 0.011376246712320756, 0.03314408158222514, 0.03508987213154474, 0.04842736330183764, 0.04993090661422861, 0.03195367862410363, 0.0071320817862156665, 0.0682519069842754, 0.04825265695070548, 0.00845018920728997, 0.0650219347388033, 0.05132335568628004, 0.09442522430852537, 0.08272455659725013, 0.02149088450917794, 0.05849585004691636, 0.059556027634009245, 0.026589521402192694, 0.01634372360703926, 0.04096518811439315, 0.021588147032044588, 0.02092444484362439, 0.006034986422051706, 0.0577991352146191, 0.013931505213071023, 0.06308360588586619, 0.0436367052457025, 0.009293314933236088, 0.04869473947873039, 0.017274227406409, 0.008348137677286663, 0.05539171157344695, 0.04413015779949004, 0.08815854081823941, 0.017266922758050987, 0.03852774914834769, 0.030861599220623894, 0.025841723827104417, 0.021417156207345186, 0.04529437012670021, 0.06191908712348631, 0.09339153421141448, 0.06610664629167126, 0.028335981619273944, 0.07549880763455745, 0.04096471697031971, 0.01262728265681935, 0.012537392772613995, 0.03937940526333067, 0.053631463688948465, 0.036046053282916546, 0.0306438444738066, 0.010216878933621752, 0.07337254592247548, 0.018802396615125963, 0.02691918435776907, 0.0014617706925022388, 0.07738931344882136, 0.14274317110257764, 0.04108439139541119, 0.011280868765747836, 0.07099247162020014, 0.09129711877434485, 0.05475860885194233, 0.05867257120928938, 0.02263124851930526, 0.05646195938630451, 0.026468002620423516, 0.05130601528611395, 0.05890553854706307, 0.047534319286745404, 0.04675491675434094, 0.03994541400442681, 0.04495311243038985, 0.024258193274539326, 0.016970887231910904, 0.03499519132498292, 0.023870257841002558, 0.012678311773455672, 0.01612261722555324, 0.026964998330860853, 0.06514368143172995, 0.03888435924666063, 0.05100411152647388, 0.035054168603833646, 0.07569451245569414, 0.03146425760801762, 0.08784746315570609, 0.011177439235090729, 0.03374765544468838, 0.02574226071667527, 0.010000214904486653, 0.05441657357638883, 0.06100762252425475, 0.03680854059395291, 0.020913062692289392, 0.050507280524940266, 0.03362957065203979, 0.0601860928168941, 0.022385883963696902, 0.07467710938785346, 0.04284385020934767, 0.03539489003859701, 0.03354887095009608, 0.020337177162629463, 0.038814836767532175, 0.04239892932556329, 0.06691125311678456, 0.07226311271229098, 0.031158285921499617, 0.023647933379716934, 0.014742003254322036, 0.039053021164070216, 0.08815657963315326, 0.03104117789095448, 0.07236793652297029, 0.004705415931605404, 0.03381202981296567, 0.04398331789660358, 0.063776268113044, 0.07965079734041806, 0.038622732559639605, 0.03941018284568864, 0.032251876433409994, 0.03060581586924532, 0.033709546400895046, 0.07590581482696919, 0.020382583193901568, 0.05179149286460973, 0.06835909034576147, 0.03142068635732417, 0.05442611137104612, 0.024669986601258, 0.04648845988295732, 0.05512226695915865, 0.04326382727031747, 0.030993033095353076, 0.08054542715751356, 0.020291095058764183, 0.058464156989488876, 0.027313095277115226, 0.08833451887532588, 0.06665673572570086, 0.007553309485721853, 0.01698969086001237, 0.07077330152594274, 0.05335512811378126, 0.04768511603376077, 0.02053975953810638, 0.02455734486331142, 0.0064986831632502864, 0.01697882581802626, 0.02835325690196647, 0.07102184343121706, 0.008893006222112285, 0.016490760777566223, 0.03085183159958932, 0.0745957202067779, 0.04284732441808428, 0.025765678109300715, 0.13335621915757656, 0.03289897558129123, 0.04016314385338657, 0.0917917740861735, 0.06302393912788361, 0.04040970542137662, 0.027819716882321145, 0.03241535959645145, 0.034882300608460946, 0.06670329854973862, 0.02876602124512917, 0.085252056859674, 0.03992819234788899, 0.02014905661194315, 0.09159508867249375, 0.07563347056988748, 0.024963497867687576, 0.06080205815153257, 0.06290934003529049, 0.0016771069955035685, 0.05536266918023748, 0.034368251780829126, 0.020367163759205612, 0.009759586687470156, 0.02916912905000631, 0.05607781608799293, 0.0496347063791848, 0.020119843764170524, 0.06626481280451821, 0.06149443309573878, 0.16796451692859973, 0.11056188584095049, 0.2287683638954355, 0.08138858352697666, 0.11981535462602494, 0.1479952400850673, 0.11045891596304794, 0.12267016595409763, 0.11738238961345727, 0.1777818570694616, 0.1900661841876084, 0.1306135171363431, 0.05904275255518095, 0.17036231084456369, 0.14089181238124449, 0.1140686609752236, 0.1696989706326877, 0.18460155644964787, 0.21159097191787538, 0.2711142263104839, 0.16603314798445473, 0.16268162056803703, 0.1041939178661954, 0.17772194899378285, 0.20443056259424458, 0.08838636770604119, 0.23402627046790817, 0.1857293910917736, 0.16560459839961222, 0.13149413520530348, 0.27748985516448177, 0.20746237087634303, 0.1205226299803584, 0.15197644580996808, 0.14813440761739208, 0.14575544414260697, 0.1902486816529305, 0.19401545936782516, 0.1255874517523954, 0.1508896581588253, 0.11600294105348088, 0.06914765528974033, 0.11294629620087725, 0.1375160306211441, 0.23329004465091616, 0.11919618704386296, 0.14725277831237163, 0.29567779372296027, 0.15327528659855166, 0.08358402297862115, 0.13360403327932283, 0.1675869275124804, 0.1416395448388592, 0.17773757718743818, 0.14026335981344024, 0.16680662099632526, 0.17294675442239932, 0.08383009808077928, 0.12460358035300048, 0.14238196064627942, 0.18897492258298784, 0.05067352926538837, 0.10284465317043567, 0.1405640799672373, 0.14513172599817478, 0.17992826689395214, 0.09002001190017309, 0.18391920193549127, 0.10817690857595975, 0.14971087866973493, 0.10214143042122165, 0.1906324763812365, 0.08748606883830602, 0.173174420431737, 0.0904326881432245, 0.17546424191565285, 0.10190854735311963, 0.11927523965676946, 0.17100882776562246, 0.2697501301525101, 0.11988034952552089, 0.095746120768449, 0.1760101868140121, 0.13636582621162938, 0.2217595940155368, 0.10371974774546201, 0.21677818389669543, 0.18873245575495307, 0.1141181655768906, 0.12862112162814987, 0.10480601445681627, 0.1335792579958516, 0.1962568334514095, 0.12460660640030138, 0.1965216394033163, 0.08792807858797812, 0.19990618520927048, 0.102169806317937, 0.19471702736712274, 0.2078317784734311, 0.1901760718394672, 0.12091687414795162, 0.12444143784382652, 0.1381391971822708, 0.1914506276408511, 0.13607884967519393, 0.2367838345948727, 0.1999682996181711, 0.18531089258049765, 0.12174744369281877, 0.19678895812361472, 0.12634600137150095, 0.15844019009701668, 0.1650655482925715, 0.21162440399489096, 0.17266687186014268, 0.16559404170801564, 0.2198517133271502, 0.20373670143946526, 0.08685077510533795, 0.14872869266377342, 0.08359177578841487, 0.11640749676453492, 0.11294147750783352, 0.1792280318876428, 0.23258622435312118, 0.18462075461303035, 0.13932576012467185, 0.11594911571592094, 0.13642551978268933, 0.12279267873494856, 0.1570738416405455, 0.15029016371455886, 0.2584352566590232, 0.1128222052789023, 0.15448939806270987, 0.09274271136570363, 0.20198056744712017, 0.14342312010065203, 0.12161134051219111, 0.16376850014973074, 0.1328077461690672, 0.1640149966002472, 0.10741786866058266, 0.15236253880204695, 0.11015346904675807, 0.33911044378915145, 0.1039206236600876, 0.24481660355964016, 0.1736134960646591, 0.14222331915891942, 0.12400169571441029, 0.09572662383077607, 0.15424535309355106, 0.12206674913965887, 0.2596021617852873, 0.25211285559400437, 0.21479734099440037, 0.12706246978092578, 0.10448179072550229, 0.17130237733644826, 0.16089917911637217, 0.13001808295807532, 0.14178644985921923, 0.08262881092847356, 0.11161559381552282, 0.10423224524504716, 0.15125784001523448, 0.1153760742876799, 0.13122271025373092, 0.17109951725409878, 0.10625842523070113, 0.19560611836852568, 0.11161597685948496, 0.1897155610664237, 0.15832268753119055], [0.043819325285092484, 0.022021471259875164, 0.029780834935785785, 0.006795091678448503, 0.03732860704222995, 0.026049165115241083, 0.01950214515560337, 0.027908878025388526, 0.022421512797835375, 0.02975558659302131, 0.04423608094634068, 0.12659381549324722, 0.0335805525162047, 0.019377611817852147, 0.05913246145111419, 0.031264618925389745, 0.04516182542448083, 0.05411577298335972, 0.01915799356215904, 0.03555019521304677, 0.0772596760502746, 0.029326406900861093, 0.05433590834840171, 0.03383104794568593, 0.03170990178571834, 0.06567168455090254, 0.05270528254069148, 0.010385217178883332, 0.04946237490061791, 0.06628804825126164, 0.11919535966890475, 0.038161727659884966, 0.04113807117626552, 0.11318130133252953, 0.053710700162956794, 0.05934006744815458, 0.029655935791050716, 0.04821714111453584, 0.0515043784323479, 0.03195946067271214, 0.015992218527131747, 0.032286112902746085, 0.02008760486909699, 0.06783704739063978, 0.021463029552251104, 0.03940287053645138, 0.021854234266004736, 0.049097119500079466, 0.040222331806416475, 0.018845452671690334, 0.03975200744706296, 0.03114119449990892, 0.06679499161339576, 0.03722661392643087, 0.028298609935107733, 0.09774878951570681, 0.04158531330646046, 0.02155782718722138, 0.009375523828390625, 0.04521471230433353, 0.05519423708920518, 0.04743164052225409, 0.04429080643721166, 0.053915854678639484, 0.048823875089686726, 0.1380556323114903, 0.07049632243691914, 0.08093009522605328, 0.044879552667900446, 0.021334799840265227, 0.051105848002818324, 0.015964306113610587, 0.025903610324847604, 0.01696219213397032, 0.07877497498186366, 0.0205775257575536, 0.06378733425311024, 0.027506944250255346, 0.004559429737949564, 0.00805723685545907, 0.027458129127720193, 0.022712919237692992, 0.016629667839996757, 0.0407081924288744, 0.05027398759979875, 0.11427967989396666, 0.057157007977366454, 0.07241207850916732, 0.029981563378485943, 0.02481294626880798, 0.022573975786086053, 0.020809686787786986, 0.057329837413084124, 0.00942762355290113, 0.01636718888015997, 0.05531362423132505, 0.025911558487062013, 0.016798764512303378, 0.015452458831151168, 0.05258898656334608, 0.028462301857108553, 0.03327707061544061, 0.03282099549147872, 0.041340417979705724, 0.06688796404388643, 0.08545431939344253, 0.029273341905565995, 0.012612034634296453, 0.04950970764301958, 0.04914260597058362, 0.04656422214822904, 0.05267243269049833, 0.03439324539935878, 0.0596123963834778, 0.03076991956350544, 0.11218013932868359, 0.02094217211819224, 0.04611566234680434, 0.02323438762687147, 0.08917949087316952, 0.08078510542550395, 0.009866393708263435, 0.010900684226784977, 0.03701238126884546, 0.030078714818603573, 0.0244010801637365, 0.07051844705617236, 0.07393940502116758, 0.01872053437475716, 0.03910539476501365, 0.015252807699594528, 0.014609767860102077, 0.04907165090703676, 0.04499673730723801, 0.046187333702560396, 0.07691130522758731, 0.09244416690161152, 0.037905831310537555, 0.029219422722235325, 0.01764138845065909, 0.05750798732943593, 0.03422315855841002, 0.02204983183483203, 0.06069110946789865, 0.022990660584201256, 0.016529999801047867, 0.04375229642215756, 0.04292952565235957, 0.013094987953081729, 0.004542958847577534, 0.01270676236374364, 0.05983758409838042, 0.05563196823782018, 0.05353739575272607, 0.03590188319644621, 0.032087230731943445, 0.026905383283813155, 0.01121130798222317, 0.04943537413172665, 0.02066234318209031, 0.03748698805969569, 0.007105315631751212, 0.06521514211330684, 0.019453759042305813, 0.009802054771552644, 0.11740937123015044, 0.026401768573710037, 0.026638328863848603, 0.09028784389938078, 0.014351026451725875, 0.014037349835909424, 0.05179640731864399, 0.030050871352995598, 0.04189690424790306, 0.052555807295345494, 0.1701237050996673, 0.029277304495354334, 0.0637707024842741, 0.014728150469431234, 0.01500558059272026, 0.027485428670901927, 0.04543664414555796, 0.03522129068451543, 0.011871465098773761, 0.01520739017700356, 0.09243236148669835, 0.015194503620507257, 0.07371525535540235, 0.01945552104453166, 0.026239141513923966, 0.06342842206058484, 0.039734337629089435, 0.07826329719635748, 0.02095157010180335, 0.020038452667875156, 0.020056440412337263, 0.0886655837718037, 0.04456038128644709, 0.056016567358446706, 0.025454249961542028, 0.019144429975459655, 0.06985622533266583, 0.06440209299926797, 0.05821536610563917, 0.05394017030935615, 0.05105881786514675, 0.04945779752527033, 0.06054293274158432, 0.012456534107426002, 0.06431527225480926, 0.034438482891287536, 0.0093733893159116, 0.0110994016886839, 0.03452759423863984, 0.07754033236133476, 0.053771175143699494, 0.03928116214792094, 0.12207064086631422, 0.030128213674611146, 0.02483605339582409, 0.019125620601698756, 0.04537854020694091, 0.021116531814538667, 0.02565462983423664, 0.03602786252515451, 0.04727360424435428, 0.0078017814854730765, 0.008885243836219513, 0.045037163767002286, 0.023724017401916847, 0.04069285151819068, 0.033729265504066026, 0.03997086727571103, 0.023368221272023457, 0.04443560854621953, 0.06178463103189584, 0.0408041947371056, 0.08070439040180176, 0.04199198342018551, 0.021715683434458993, 0.03213825410292034, 0.07408128450474433, 0.07923943876859643, 0.03223211136496356, 0.026099805442255833, 0.047168171393775174, 0.035063036071557196, 0.013386809038028363, 0.004856495173542851, 0.009866634068349677, 0.059108961704036886, 0.05657350944895899, 0.04146029158765751, 0.038141361212417964, 0.042334612413880326, 0.040306647443362785, 0.014706457732245328, 0.04584300016323405, 0.006798271422139219, 0.0741027043231072, 0.033659754516256433, 0.06690486394349607, 0.022744227335938526, 0.0496439760430686, 0.04202577555852552, 0.023145776151889758, 0.016397441692289808, 0.05264257058320988, 0.06929937134226484, 0.022827322977865418, 0.013221490136798353, 0.012451112120141907, 0.006699875089144635, 0.023704960964800372, 0.022895106437405752, 0.02673842591203509, 0.02995052532623372, 0.02786485095238013, 0.019514124855519305, 0.05159875663417963, 0.061709952781036984, 0.03000909083282515, 0.03051136105862116, 0.04010713516524242, 0.08980755273613239, 0.02834576647728682, 0.07732316941743897, 0.0425452751017386, 0.012269258168676208, 0.04298865231835554, 0.060481174563568454, 0.027324306973887068, 0.029050733991748387, 0.027852683560922745, 0.06712377356785922, 0.07586963249430542, 0.04276901491046433, 0.06297257676300022, 0.020494265406722986, 0.05430916421896508, 0.05019261374048168, 0.048216516752877546, 0.06723050493746996, 0.042250802394964045, 0.027970571085930835, 0.05349181352123138, 0.04127919989367647, 0.01595180355868633, 0.06817903670091784, 0.05754592017300668, 0.012831739074881039, 0.019921241215460246, 0.059809039662321734, 0.07085899612115276, 0.03245967778287107, 0.013124060032198267, 0.03337381602895837, 0.005004845706055002, 0.020469794643201658, 0.041698518119031386, 0.05405879136355174, 0.07287199173362986, 0.03619784594423348, 0.015102439961816757, 0.01758349901666084, 0.012062282278953541, 0.05178392008547822, 0.10051922391979926, 0.01539517364900319, 0.05506797047752527, 0.014211807208466194, 0.021912813179134842, 0.020128014091882977, 0.03680981613034683, 0.04315547179430724, 0.023476821896169456, 0.025684198912894054, 0.03910328419278226, 0.021818111305155104, 0.025152727330644286, 0.007164711386130582, 0.08105152016205174, 0.02300509751113432, 0.06545924836949957, 0.06152617594888134, 0.03916485467925668, 0.04742108766109713, 0.11880910579836178, 0.031163740467520493, 0.024757165491821307, 0.043157471283789606, 0.08713737625869052, 0.14551280877522885, 0.17000667750835421, 0.1723105030795259, 0.20931509323418143, 0.08198933435543891, 0.19448946861009445, 0.10080988533915052, 0.16297855624748817, 0.08803018278652623, 0.16114372970356097, 0.12168751263450231, 0.22075240289972675, 0.1447596983803857, 0.16769180494931438, 0.1729637156090429, 0.2227762846216079, 0.10716151265848069, 0.09636909580759465, 0.1553827485129718, 0.12014009929712742, 0.255505430001405, 0.09696692018018616, 0.13186237834874662, 0.1382648509236113, 0.14131314541784026, 0.146095035597682, 0.15721208986736115, 0.12896164771049254, 0.1291791094286788, 0.15595530730582055, 0.2642089855526724, 0.17207080948977702, 0.14677431043838302, 0.2110317430549091, 0.14960310542054717, 0.12320586825690924, 0.11586849262276966, 0.10854766448779453, 0.1214217720553279, 0.1687539398910538, 0.10096163969607123, 0.18530280269201727, 0.07029923865751875, 0.16277810168122092, 0.19069517301695962, 0.1504851790565637, 0.14755153728108253, 0.1621287655566008, 0.10584148187791148, 0.09799570731458165, 0.12238490545461256, 0.07884386160801496, 0.18515623475034393, 0.13781336466631583, 0.1267599033552312, 0.1321516531489549, 0.14132261426458437, 0.052363113199751225, 0.2163339141876467, 0.14860974985264963, 0.188411510879955, 0.19500193546616262, 0.10531976834059724, 0.14366118958400143, 0.27854151002341704, 0.2510125388301188, 0.19601072004485517, 0.22420247986672387, 0.09733528589769717, 0.13516400279777666, 0.1263376510131263, 0.08917739945313624, 0.08535855074202822, 0.13041805746334215, 0.18289083614945414, 0.1116698021970449, 0.09080991749801944, 0.1498991524380061, 0.13265334880880772, 0.1359498251469866, 0.13380493217658612, 0.17479389966014894, 0.17696969661741488, 0.13377412012027157, 0.09636487466313186, 0.3057968958971962, 0.08623793540943055, 0.1494832892691897, 0.17394554921455924, 0.05949193671826394, 0.15871175294441564, 0.12093732103465066, 0.17420301604415142, 0.16202574205254355, 0.07327035745425571, 0.1638896799375934, 0.07873514607068031, 0.0946046497612711, 0.200576925830495, 0.17485693337455874, 0.13115219952118012, 0.07650055952610509, 0.11672019853346771, 0.15522027658599039, 0.1231873365900209, 0.1664735259668481, 0.1332396052537426, 0.09753595496858321, 0.2485905212139891, 0.1171428032760178, 0.170270410937167, 0.2118980965667194, 0.08928104348841215, 0.1948224717090207, 0.19389974944774183, 0.18077490130259147, 0.10436010531960957, 0.14122118422340962, 0.2285982464109698, 0.20650359651734754, 0.17803644340845848, 0.10679510046517658, 0.061714514834626075, 0.1553853991771898, 0.17468606512392723, 0.14367148580570377, 0.1851718935875162, 0.1421016337530267, 0.1349053561927811, 0.11929727234547177, 0.11708311736583711, 0.09153282104600823, 0.24427009175621697, 0.23106193921018034, 0.1667192869729573, 0.16939219838428884, 0.3999689281467469, 0.18250419157406977, 0.10598665553956263, 0.12819581259522708, 0.1962827272232502, 0.061589286272083564, 0.12947992151302676, 0.17146823537205497, 0.1469684524401542, 0.10641508255033724, 0.08123489862848675, 0.11271757299020407, 0.09715714747266424, 0.10347208684130062, 0.15000079698379964, 0.17507061061839904, 0.1974453882224137, 0.1951716086196323, 0.13233359903097153, 0.07621818717809455, 0.09539681531849409, 0.08887475641864924, 0.17862685204994294, 0.13005828725234156, 0.24303261461036824, 0.14823997453335794, 0.16342798938914654, 0.09766324813808165, 0.06047029994548329, 0.21129684012022712, 0.08690928124011525, 0.1305776029344528, 0.2125177697669114, 0.08831227934288402, 0.11900186118098999, 0.17809852717384217, 0.12141247940880638, 0.13528116828491613, 0.1822301006365207, 0.2529611600743186], [0.03276624701797001, 0.06416529139143325, 0.025443398326094595, 0.02895004322542058, 0.02027369145634434, 0.0796581594453704, 0.057998429157681046, 0.0789708866467399, 0.017559309790451682, 0.05420353984640491, 0.013312129829559597, 0.0606308413308955, 0.02485996108472107, 0.04183512691768908, 0.0549973716448632, 0.05093387275513622, 0.046484713713007594, 0.016615778665929552, 0.015230737664105912, 0.03809707366951531, 0.0400977352664115, 0.0462448745665531, 0.09279508879708667, 0.034966374927711104, 0.055895253505197265, 0.04243831007531093, 0.04847738118241391, 0.020592131223830006, 0.031597022560515234, 0.08119531486543917, 0.024457274628202283, 0.033983457307781906, 0.018097536352973793, 0.027060855082386447, 0.08029615746871119, 0.09874072782094441, 0.05419131691357302, 0.004073583958445177, 0.05593327827931893, 0.00971956529669584, 0.023287636483268394, 0.04798919165266618, 0.012152570528879523, 0.04309014747700384, 0.15342730908624588, 0.0264502638545368, 0.05776758005301799, 0.01335849155551724, 0.021667898700181997, 0.012886523937566147, 0.054433860350400216, 0.1127464468440702, 0.025604253807555766, 0.05972031518937119, 0.05275623121809575, 0.028019466647698034, 0.011084688012488188, 0.011525905818768568, 0.053718066098348755, 0.014282069920051484, 0.0124973934068675, 0.05073485843416664, 0.02760818468466882, 0.016545966988609686, 0.06817110003002229, 0.09847000000938293, 0.0898004511010743, 0.044629206625564445, 0.09310383755233019, 0.020023460327196988, 0.06596902625695353, 0.022744914899850567, 0.06499067835149265, 0.09071218000063974, 0.010281517602232917, 0.007700140291314213, 0.07504453281721762, 0.027106665225038608, 0.040233945699348565, 0.02407793661639575, 0.03689361465794425, 0.04392203469310076, 0.06097966797589775, 0.036699997426401225, 0.06343858421690042, 0.0193866420792596, 0.053650826561234655, 0.035395797852787285, 0.017181178367125894, 0.004551694165134142, 0.021484566199022437, 0.01170978990323361, 0.05865603520144379, 0.021571768072223472, 0.03454912130931213, 0.030489906766301686, 0.012925147217878652, 0.03526898731868114, 0.01216850036965503, 0.011797055936298304, 0.041894694084241506, 0.05723648193863131, 0.0759739353651962, 0.1036192523315549, 0.08251570570733278, 0.010644043814541112, 0.018896012559473034, 0.05790805376525368, 0.034313744625016566, 0.05443234349631014, 0.010976644717307102, 0.08308506225265803, 0.048951934347109455, 0.053100043817633585, 0.04252603097308067, 0.01576673299554856, 0.060366165613935846, 0.09069221574933299, 0.027968299635235342, 0.023487418807382067, 0.05224662186998514, 0.06035987220163788, 0.021717093036239667, 0.04968256006137498, 0.05622788888191985, 0.018215919919912855, 0.025115989584235415, 0.0585616301865347, 0.08650198293429229, 0.017097575191949165, 0.008912491668466358, 0.05236372990053027, 0.027188876035412955, 0.07067878925872427, 0.03633257782747669, 0.12109793902885531, 0.05549522920421535, 0.03880660515278578, 0.034117886586295026, 0.06697417191800571, 0.04937279240919217, 0.03192375714500104, 0.05756367043021226, 0.04000793060948772, 0.07113446601696553, 0.018868864318656347, 0.03144260221761802, 0.060231341800141724, 0.051133783398977214, 0.06128386616887105, 0.03288326694840386, 0.10918936271580959, 0.03677772470719872, 0.048871533419456215, 0.017240684246644378, 0.04514871382965677, 0.011295519239689794, 0.037443409148123, 0.03194244585991387, 0.006359833078609119, 0.034440451737252936, 0.05017263799785607, 0.03551454148105076, 0.04503178582977384, 0.016154342841717507, 0.028165846897829926, 0.02032725249357041, 0.07701412954878423, 0.04534792350304704, 0.0636442749941301, 0.03152466555606694, 0.011747356939820514, 0.1180188937653457, 0.026031732784524083, 0.01419228920337534, 0.038618748902433345, 0.028483037941999016, 0.08022805991312189, 0.015090632631683783, 0.0613435635703706, 0.0026349268568259094, 0.024487648099180193, 0.05769935992336082, 0.10175384355769043, 0.043913975448137334, 0.039645927252187844, 0.04833614138225394, 0.10269008727083284, 0.06314241845581321, 0.04512766556393716, 0.016223556970456438, 0.029159681270680124, 0.009117633735220279, 0.021597753774615067, 0.004198744051879453, 0.027275894047512163, 0.05816781502817908, 0.0316436026215313, 0.05835707704987257, 0.027989493457660563, 0.04704262107430447, 0.06553716717227813, 0.0735435214254164, 0.006752281248824852, 0.007790701460063218, 0.041636629706068386, 0.039149984912646395, 0.052624448773361025, 0.021082437071468563, 0.04841157806015784, 0.019588910358687563, 0.03576101877936914, 0.024847849234638196, 0.04338522539323857, 0.022066591923395475, 0.014090928110113789, 0.0529494768969955, 0.06390844509305973, 0.05426695660477685, 0.050343069578370744, 0.03761308230159264, 0.05149670989222584, 0.04079015617589316, 0.047809417629914905, 0.05059492864435719, 0.053340514986625606, 0.10394086370304709, 0.034992713030547865, 0.04278017298108147, 0.06637877604413418, 0.0772071454013067, 0.007483589738952898, 0.04632788402358851, 0.008984655235713769, 0.029234859393909577, 0.04030885377658471, 0.06416260625325865, 0.024817205717666976, 0.024879718492288264, 0.020357367409873876, 0.06870058169888874, 0.1189930052045853, 0.07946544236713841, 0.051523427208585125, 0.08526775400124251, 0.022831900353212992, 0.003402986739303977, 0.036261465715905356, 0.029083095460889802, 0.024465701595369368, 0.010724002326418076, 0.00972367631601951, 0.06034972919752041, 0.03795732391036807, 0.04994145947538557, 0.025911663824151603, 0.041530009419206655, 0.0248554028615716, 0.028451538321772413, 0.028998680232513337, 0.04477186368838434, 0.04865696751362374, 0.03501596379904978, 0.009282371367237741, 0.05017834535289196, 0.02896929501495775, 0.0467032594456067, 0.04989193572152046, 0.03229311494637401, 0.05543662730844752, 0.04305309946498564, 0.04320152900031498, 0.021315793198863828, 0.04348708827409052, 0.04917511108121084, 0.04496095334029487, 0.02696830400025412, 0.022936277917676398, 0.03175618498766374, 0.04712012618960393, 0.027225169450825742, 0.007544916513706408, 0.016886525629689137, 0.06896531870288235, 0.03490829397173178, 0.027852599291251074, 0.020301726443933386, 0.010099090042433912, 0.018604292023566463, 0.017132652442782156, 0.042894668651804815, 0.005318480187035617, 0.024955948071193793, 0.06689951664978458, 0.007795573779261641, 0.044257696117124254, 0.05055392378821008, 0.04982836191512404, 0.044722991109254866, 0.03165685594262135, 0.04625037124740981, 0.03610888015358679, 0.0396009425692741, 0.05013214642061822, 0.015755414046467315, 0.08276303719368674, 0.02265129129462425, 0.07629147880981046, 0.09423852868137822, 0.0561700530740763, 0.03371071085453995, 0.04550256984188192, 0.013688441794065219, 0.03748586574088662, 0.05275047406734479, 0.09237284411586101, 0.025517387097821604, 0.03583922869555893, 0.05230207514438418, 0.031464926019731554, 0.011008266911601589, 0.027795240373140382, 0.010142206428422323, 0.030734857634430936, 0.026158340305330294, 0.11334733556835883, 0.07453798015992488, 0.022228920208891074, 0.010404803174277468, 0.06600698591360162, 0.0257867761707354, 0.021346181991600224, 0.015995322140834985, 0.03037608142251209, 0.045152666843346054, 0.05460599647654642, 0.018087356959679918, 0.053463177154621774, 0.023113324667417237, 0.0466708654177285, 0.02246954076502833, 0.066899340449562, 0.07450804910472325, 0.04857390059999401, 0.027062791369615063, 0.04490806263000254, 0.03390260821869297, 0.08031686482530448, 0.10765468942061548, 0.045638803257456714, 0.04437191982663447, 0.05378366237686527, 0.09877095765043652, 0.12903747509323782, 0.10717671184289841, 0.14505726225193472, 0.13217843558278777, 0.1201618025680223, 0.1505427582249526, 0.2050683154694496, 0.14931413705550856, 0.12906658643436048, 0.10688509281364181, 0.35122192614982206, 0.12431269676815118, 0.13823495817280587, 0.10589212795058567, 0.1580087446998204, 0.1514064763943034, 0.22415086086238586, 0.1534709454544129, 0.08706616838612864, 0.1105801263944276, 0.07817574866837071, 0.2283782719243919, 0.07964951797358452, 0.1233369765442706, 0.13770975893543613, 0.11403732797912053, 0.1394105507361312, 0.09810619251502138, 0.20707620127547174, 0.14762621553194138, 0.1416585131758644, 0.08273203361539111, 0.18694034627368375, 0.15523510804820448, 0.16125945494540278, 0.21805591130208588, 0.0907616233152728, 0.15274743669696395, 0.1264361009722756, 0.13091463565586076, 0.22455825109875974, 0.16096805042076498, 0.1310206315810642, 0.304218111259322, 0.09688765306266085, 0.16502120712351415, 0.11992832195133933, 0.17788996739733606, 0.12662859588500955, 0.14707274765016573, 0.17344802107301452, 0.10082284754682934, 0.12686725525606063, 0.15994114020178396, 0.07555956606783214, 0.14411569422771855, 0.06553172794801575, 0.14203181249960778, 0.10088958912679266, 0.15801795307667027, 0.09486193272976146, 0.07598210952334827, 0.14298603629633305, 0.1744925053489785, 0.24049911587949724, 0.12378448680523904, 0.20501383129627476, 0.16184047134893556, 0.14717393254320468, 0.09897857513879577, 0.12846029679020568, 0.10352655569271696, 0.23503347690547668, 0.09905855471809065, 0.12745661435708885, 0.16908032399031425, 0.18480528987223105, 0.07895064660378041, 0.11270405919921976, 0.10702559333895484, 0.13529164836772029, 0.1124273022756942, 0.13424812936254088, 0.1526522885767683, 0.16414536944320127, 0.13341628045084017, 0.08969152872000011, 0.1622518299207572, 0.08432615533350937, 0.18938776736538257, 0.13123671434098674, 0.14729065369934807, 0.1419944274089029, 0.17851999810626432, 0.15783790709270587, 0.11933801290128501, 0.11754892180643736, 0.06762119445709452, 0.1437014551653016, 0.1369604483366974, 0.15758261595281864, 0.13141950291972007, 0.13671330837232454, 0.15111786042970998, 0.13805748624426706, 0.1100587422749208, 0.1574779683423619, 0.10708182419259703, 0.1375120929292133, 0.1371971541835416, 0.15801793775491177, 0.08054555739246069, 0.15747628294892851, 0.10705032265715062, 0.07058695063836153, 0.07176792113891534, 0.20797387246162663, 0.11686853613824615, 0.13679462094460765, 0.1348292070531076, 0.14674150655346532, 0.14469372288834664, 0.10064075610810712, 0.12389376158675841, 0.1556834227014934, 0.07911434427144066, 0.12312393515340744, 0.1773866323093253, 0.10450623659116608, 0.09862040605155692, 0.13313198522213968, 0.1717035316171185, 0.18649227676853058, 0.07541668300907459, 0.14658655760990036, 0.07287140184592816, 0.14503696092194127, 0.16077951618259953, 0.17618585077504959, 0.11548822189891532, 0.09908112366833996, 0.10261226039860519, 0.14676194577928514, 0.17795629528982027, 0.1091779633274963, 0.10440400215767084, 0.11192814236687076, 0.15154648662334488, 0.15574968930694366, 0.26052021091022803, 0.26140942448569887, 0.1243469179157288, 0.10976006757588157, 0.09036974635936561, 0.1646062172949314, 0.09747878182679416, 0.17495787311946193, 0.11794796168443658, 0.1813654478399023, 0.07866193870863608, 0.12229416233998154, 0.09551827855888875, 0.09924671357317318, 0.11330693975211152, 0.12946671415721217, 0.11337574210859115, 0.22123388916013703, 0.18616111228062263, 0.16940168255279142, 0.1035899188249342, 0.13445938576854047, 0.33470507050233506, 0.20807070597525568, 0.17514282206614173, 0.14672263014701106], [0.044165087578397606, 0.07732513060252513, 0.05159415627619432, 0.09097503242833961, 0.05701180367219833, 0.03268214205520288, 0.07199299777106893, 0.05080499378363452, 0.04783899628467137, 0.03985038079741982, 0.051813548535949765, 0.056734728822184194, 0.050721478708569086, 0.024509889546841867, 0.052969854835781364, 0.03685923263190254, 0.06139615933681208, 0.08465743473460598, 0.025859219360075174, 0.03696268131475776, 0.05474667703252166, 0.11589402633328592, 0.06942102610464058, 0.07595977039947625, 0.04468399340346937, 0.014571284390835753, 0.1005207177912516, 0.06378107531476887, 0.014982741596477648, 0.011889917284039962, 0.022187248856249838, 0.015297918787015783, 0.06698720307359773, 0.030408619091876095, 0.06425524543550226, 0.0188960240507919, 0.04156803036288869, 0.05067819857128686, 0.025072372368266507, 0.030069318750212272, 0.037775309080438274, 0.03736080954812708, 0.029475516339223233, 0.016720606307048472, 0.04457608608889484, 0.07054972642612073, 0.013211236049931858, 0.049425755897837306, 0.06422503092776864, 0.019517727383983233, 0.026718480812926448, 0.055409760604943, 0.012394822852295494, 0.024005259770239075, 0.06446991476320452, 0.04314274324344532, 0.03894659622962918, 0.08828505257805509, 0.0842541583903855, 0.023301678874920455, 0.04328950270709973, 0.033251839509654435, 0.05794099171555812, 0.021247586475745327, 0.09625512490709943, 0.06340040239475428, 0.026748779590331742, 0.03724100488808848, 0.008182509468057224, 0.060169660230918284, 0.051862497723871664, 0.02104779649075241, 0.022545324097717964, 0.04005858051260153, 0.09580615141819562, 0.018047167987172163, 0.07015330656882256, 0.06932116654371062, 0.05288030681831222, 0.05884396806058865, 0.11243942944753556, 0.04541449654366701, 0.044377879990685376, 0.057951609694188645, 0.1338095593476488, 0.00879699721061174, 0.031449500839376164, 0.05399894457490695, 0.07406086826156225, 0.061554004092730825, 0.03494775899115109, 0.03722697398775528, 0.04998211959196676, 0.02851030684166378, 0.07824187737799461, 0.043284224361301436, 0.036708140941036325, 0.021765594062725865, 0.04730279219426936, 0.09621687413704011, 0.06382939631059285, 0.08299329258020847, 0.01983347243719524, 0.05729167091269648, 0.10647915048344482, 0.012557823379944651, 0.0336116939903267, 0.055879418467802394, 0.05895366036002675, 0.044157522460145336, 0.014972135109165985, 0.04011080089596011, 0.037357040395539616, 0.039662631799376784, 0.054700340204421556, 0.06607735875032603, 0.06754465461257966, 0.05513454351814524, 0.06969233614302452, 0.049437886900118286, 0.07376818437009089, 0.0484002591110766, 0.03297625087021339, 0.011429016763765005, 0.04750141964083718, 0.02661174752809588, 0.04808530121320679, 0.053984090130055146, 0.009614285663701594, 0.05140047392717773, 0.018782081878593853, 0.059470547543418024, 0.033537521357497865, 0.03963651969247768, 0.0597374449153581, 0.0032443454913464527, 0.047533147172221256, 0.037316763322920575, 0.03817015845749167, 0.07931647657026207, 0.037542648177834294, 0.02389880419228106, 0.04109281070169903, 0.04278617144952859, 0.020663743207771933, 0.014149348059999607, 0.056489385333993745, 0.007442107993072921, 0.02981903782534984, 0.025228932011692275, 0.06447152354784551, 0.06021120900949163, 0.026102101790808865, 0.06738527768081234, 0.030797741961695498, 0.027070605466442726, 0.029772373494662108, 0.02246771747576854, 0.04685122549774186, 0.008242581295029772, 0.08334265931719735, 0.02105290821242717, 0.026517373156703772, 0.056694118501318086, 0.015401206591406898, 0.03429104160938052, 0.045423754716231945, 0.0633001980942584, 0.05626512841591912, 0.0535498944772107, 0.05438844282780925, 0.06691692982830348, 0.0105839604962497, 0.00688634232632936, 0.05089952903349073, 0.057736971010003364, 0.03379890672682274, 0.05760852487817888, 0.07942157617259411, 0.05263220541359437, 0.025293934572067474, 0.07585234955073365, 0.016153948306436502, 0.06336311306503993, 0.021358230639429345, 0.015347768128248713, 0.017449623236673015, 0.04594641437213268, 0.06982615638163782, 0.053875642723494, 0.014720105588616384, 0.009370433174133783, 0.05200648394924018, 0.04016966326162219, 0.02522779245590491, 0.025790537662443616, 0.08079568509973827, 0.11413610735607725, 0.07049704255956797, 0.05107878977733274, 0.02848942328484789, 0.02346724196667633, 0.0570791811051388, 0.025965489161711548, 0.01095506402048012, 0.015300494757661176, 0.04741183714941145, 0.023878334322944287, 0.020631391314729568, 0.016764039661915555, 0.010512927866300509, 0.03833369907712744, 0.028415459410978422, 0.04066616101490875, 0.014986957952890907, 0.03487700694090417, 0.016611844804438374, 0.02757098728550538, 0.031461959344244776, 0.03366892458871007, 0.07896604497105845, 0.035387420681335276, 0.010433032556677298, 0.033023154603377465, 0.05180896733016257, 0.02148558892640135, 0.051698033968287135, 0.06603767539584829, 0.008038166054194013, 0.017802196051624995, 0.08491972791812114, 0.011297980297146546, 0.05044829941564991, 0.06221827127099518, 0.047861833365694176, 0.020514911476282344, 0.041848008686135856, 0.028964422695759325, 0.06178144410613084, 0.05345206504928009, 0.0771259630639707, 0.032498744436569756, 0.06469999394950367, 0.07963870847297293, 0.05806429739741068, 0.059682734746245615, 0.03215293234754955, 0.013095142128276489, 0.027504082911858158, 0.017017632001830686, 0.04332765771616851, 0.00724586068592485, 0.013205216514066824, 0.06778743553666339, 0.026467163754146428, 0.010897559545663817, 0.09183900340670541, 0.04970373090116247, 0.016687114858218742, 0.06791745597917227, 0.03030287789090747, 0.05178242238358625, 0.05384195017658415, 0.056046486922329476, 0.08394750871605451, 0.03451240271510136, 0.018307779607693517, 0.030701724331705805, 0.0172510149423033, 0.046112785686648665, 0.06921347756419452, 0.037168272500557285, 0.043975174381968477, 0.035450971505093964, 0.014565748447972923, 0.06285089518754713, 0.05321429817066078, 0.08075603238877752, 0.04252709583529542, 0.04214668721561471, 0.08205060606762286, 0.034155126120294296, 0.0027808960529059294, 0.11069067288190128, 0.0209889666838271, 0.03310553586831497, 0.027926356321380987, 0.01744213089677355, 0.00039943025366219156, 0.03211534424354473, 0.04377119964168918, 0.06211777202664845, 0.04176791802409195, 0.058871160351460984, 0.022019287909290964, 0.03637925939514272, 0.06536216204685551, 0.008257443400760813, 0.05063646210117206, 0.012853967116004037, 0.016399301370726, 0.02034016490553416, 0.03282366530789483, 0.040170996254610444, 0.03404434980644334, 0.02850099887338377, 0.013170193846998437, 0.02605779126526848, 0.05515336629844481, 0.023156838461516366, 0.053413331643828464, 0.009978097946112676, 0.03846752697662, 0.029828548806929783, 0.0402061750120934, 0.019682407559406374, 0.06004566890037349, 0.05349002087548856, 0.03679940116501624, 0.020066887936404636, 0.03519333996659806, 0.01856699886341249, 0.040050467641483393, 0.06335316158290352, 0.01989785255113196, 0.0210028367056962, 0.05844168763066973, 0.07043728770147409, 0.010140455917515343, 0.04625442385252926, 0.06849881712227099, 0.08332126248147219, 0.026159431980622393, 0.017111041102438204, 0.04203872244444586, 0.018210101482127945, 0.1071090049921505, 0.00748870337584747, 0.037281864187529976, 0.010988146569880267, 0.032816927564600785, 0.07780259490133294, 0.0991217033456891, 0.0926906097259733, 0.008535869438351404, 0.014490525317077917, 0.0701668280206861, 0.0461797456016704, 0.0148621411626077, 0.02420920769744102, 0.025529506608783722, 0.026876993980559132, 0.13998534650571887, 0.17987445687815068, 0.14649897843839663, 0.21517342887818816, 0.14752640959716615, 0.21955085527752677, 0.12039339094753228, 0.2955295710313705, 0.1040711752589672, 0.16159296366235903, 0.08929643419481094, 0.23286083623045878, 0.18699677631018624, 0.12936805735432333, 0.1366602031574134, 0.1017251688866846, 0.14789122066670848, 0.11165803508652795, 0.12750529924467688, 0.10116924952355125, 0.12071720865224639, 0.24752392764053038, 0.21817514522662088, 0.23846657736407173, 0.14544298752180992, 0.1688362483776385, 0.25491975578329257, 0.1685628315974628, 0.09996197156367764, 0.09746066384738493, 0.12334431566658521, 0.12584254370942233, 0.21518148812315158, 0.17985689814292616, 0.1460383144477683, 0.1578800419285413, 0.1420207042247057, 0.14612480577441955, 0.14366480551900404, 0.10811714605698663, 0.07001036988391031, 0.12175991560422605, 0.1455534267569742, 0.11439512934415572, 0.2732846759740384, 0.13730396216194476, 0.1252413868543602, 0.09892091170073518, 0.1668287149720615, 0.11685722868048376, 0.12177133031429783, 0.19860858548312418, 0.12961337402943643, 0.12292659856499204, 0.1924869147760253, 0.1455752602628162, 0.11480572948893232, 0.16912268865252697, 0.2069529530502135, 0.17590250549537523, 0.1655156096263278, 0.13549023367945226, 0.12094471378311997, 0.08540264676294981, 0.20351461255021636, 0.15293430086345444, 0.11808981818537559, 0.06952345972099612, 0.06708239715906882, 0.12968599916465823, 0.12431048277405002, 0.09297267563881413, 0.1138177595191425, 0.13399388010223068, 0.26456500193284405, 0.15828370897760316, 0.1818754785363713, 0.1920793560003081, 0.21313238678680313, 0.17400355739218576, 0.26581636059188074, 0.15774626765520344, 0.1247384577929493, 0.12978240366904967, 0.4098232703343515, 0.1124956526402985, 0.16088574193418026, 0.15222452040160858, 0.17090310763207175, 0.1861513216769503, 0.13399528970401134, 0.2039086268914323, 0.1315178532874392, 0.20293096080422404, 0.19195324260621302, 0.16962888890937453, 0.1535370588422783, 0.09746666231583204, 0.07135188943075557, 0.220943802306729, 0.1266509962959155, 0.21612595195972154, 0.09472643475859396, 0.13721771598342927, 0.23479799679931135, 0.07894809553099257, 0.13555000385930463, 0.2010627328267982, 0.13957706760735283, 0.15424336126494795, 0.06610109215422023, 0.10045075098112707, 0.08430889537257534, 0.12748890496309728, 0.17092057443674535, 0.18649665879145746, 0.13468126015317056, 0.14009406970393273, 0.12817533506501105, 0.11089702632518546, 0.2237936187415354, 0.16396296390843007, 0.16427401092744645, 0.0932487890484833, 0.16994468567352142, 0.09298317104337678, 0.1980228652997363, 0.0870059538752802, 0.16261679420788444, 0.16124362756888713, 0.12414552872219395, 0.07915059555201762, 0.12061267595497832, 0.12719219911002344, 0.19993024037009288, 0.22201653990534045, 0.09746242584961076, 0.12416131013343412, 0.10763760565990403, 0.11624899317300129, 0.27326690273419507, 0.12646443856459472, 0.129727230016743, 0.10990468199334799, 0.16723875587265338, 0.14069416169678012, 0.11102406668566889, 0.16361961862252605, 0.138951342312559, 0.16155833648818155, 0.18082955401510964, 0.20639305002987388, 0.1295255650315554, 0.14718920833641483, 0.1779334505479182, 0.1421319708348282, 0.15846988366496179, 0.08827500150448854, 0.10055379746782203, 0.1471942645167151, 0.20535284052452735, 0.1861247231042193, 0.05852383906922995, 0.20464926537486816, 0.15227764093827817, 0.1385048049832544, 0.21319073204311634, 0.20447698752245597, 0.11145725876333253, 0.13028828216896904, 0.1601592607555851, 0.2007326715055012, 0.11152259074151517, 0.09794761997557457, 0.1708092465395889, 0.1661348384955237], [0.02538846407626425, 0.009294140392974501, 0.073182211377688, 0.02608056897447715, 0.037246386655756546, 0.02680793881506449, 0.09643278069674008, 0.07437662672131293, 0.030346320821873607, 0.010762538464229194, 0.018360710537601865, 0.02026716055678985, 0.0519413779669952, 0.03270514001468978, 0.0653336329325553, 0.05393037587524422, 0.020074803539882266, 0.006701338317080011, 0.03824708134596867, 0.026479668224290497, 0.016162260360414946, 0.02697095083403251, 0.013808035779924644, 0.08424715634675757, 0.04379121368871101, 0.010562987881712617, 0.026917671334118615, 0.09972027082356716, 0.05227644184243776, 0.03979692701250315, 0.032862705148516164, 0.02755248626213401, 0.038038602008694605, 0.07065005330068451, 0.06342205203949444, 0.03975639713086909, 0.055364515452135, 0.04037633463139496, 0.016881796951976516, 0.035998249396441445, 0.00684413327572627, 0.02561863327789451, 0.042984400530375784, 0.02701998429162608, 0.0042509787993866115, 0.04826650782037647, 0.013655222306448608, 0.012144210594405812, 0.06294285638197776, 0.025677595234986757, 0.05795770775406592, 0.026498747644044703, 0.006513557239105144, 0.009448805884007485, 0.02276907348254275, 0.03572465641604316, 0.04948012898826311, 0.052658612464344313, 0.013657829878220876, 0.028631076772486972, 0.042182222203982454, 0.007566450766452979, 0.030972783476294532, 0.05544314671668315, 0.02328871283680201, 0.03463723674236286, 0.04180733707823581, 0.012291901812498129, 0.08630355084014517, 0.03834556194863493, 0.07802950248362557, 0.021519744956505396, 0.012759930780908514, 0.05300966842520622, 0.03671875125878761, 0.019159723005648104, 0.032843097128094204, 0.02083752642295534, 0.04470099289450915, 0.05681710625668207, 0.010697501429897404, 0.033472507305803804, 0.043610359481986494, 0.010273381748477058, 0.06547419474490228, 0.031901548256076155, 0.03418151784928576, 0.04127239320246924, 0.01751871479134406, 0.05660102732719914, 0.00844960027719818, 0.04955281158007922, 0.02501468977800781, 0.009656737468415692, 0.07559540366092998, 0.027689910944431063, 0.06386780412867665, 0.02543653226307323, 0.06424794461758387, 0.03018050492110272, 0.08915554296465651, 0.05842943788476049, 0.03984887926508823, 0.04766763390732869, 0.0666525911900305, 0.0394857382672208, 0.04568823125033129, 0.04993372198735034, 0.027261579694646983, 0.03256444413695605, 0.04356381197970721, 0.02441949117177677, 0.04535188417761557, 0.059349153250936544, 0.03035105716046547, 0.029002217643503702, 0.02922547290161733, 0.043622865867350376, 0.04969211700823038, 0.03083121234310731, 0.03268828608035561, 0.049927237053071304, 0.06582069631305433, 0.02922823081814474, 0.005192635402519016, 0.034103928464314634, 0.0793331083390982, 0.04566305377069981, 0.0320470072854791, 0.049205547754442504, 0.01173684525588948, 0.008383387297902618, 0.015792199673371452, 0.07245643499998317, 0.0867154992996685, 0.028489532452377102, 0.030503426302945426, 0.05413802783756007, 0.011099902518664398, 0.05484872760491506, 0.030695118738578695, 0.015220334190094184, 0.06829189677392283, 0.05994382517171964, 0.04373754539917554, 0.03455907279144853, 0.03569374093785882, 0.12376325850885724, 0.09232826545954713, 0.03135557079898014, 0.03225598266468414, 0.016136973713254257, 0.09446386578342608, 0.01868788945308376, 0.10048618254762504, 0.03643098182135052, 0.03774201106880942, 0.015577116658190086, 0.036961244899899735, 0.05387640498097866, 0.027180330324617606, 0.03951825103872726, 0.031000812718224142, 0.03526624089347259, 0.04808781398159843, 0.07201868469917005, 0.05478943623001537, 0.0106978049922374, 0.08662380623601137, 0.0498803984373808, 0.04990807719408505, 0.011996520333923401, 0.07936372121255245, 0.018531281929162723, 0.03211984501009987, 0.04456375207331392, 0.08611428881845168, 0.018751082130737843, 0.05118244913436713, 0.016115576877529104, 0.05813783800770199, 0.02567173083192639, 0.038910053835640994, 0.05109941669469399, 0.05021299550970716, 0.019613679896499363, 0.015566008383288019, 0.07956224523725049, 0.07388252299278975, 0.025771354820819634, 0.055686789489681685, 0.027251467334046483, 0.05303974886755309, 0.06527724886132825, 0.05885230309720482, 0.07620592211042682, 0.016817635173098217, 0.02920608321625379, 0.051253549754619605, 0.04324906475601658, 0.024304290700163093, 0.01855836888294547, 0.02565037421581726, 0.014391534308332109, 0.023817826783464804, 0.052360565957402995, 0.03484361316828478, 0.06442887543310082, 0.07802980125791605, 0.022142781282684976, 0.01895545715195758, 0.02992539189665789, 0.028404734180038495, 0.06625703701208677, 0.0763900819865446, 0.06073206452833069, 0.05009669953236177, 0.03621242842787216, 0.03604345241441362, 0.036915854190386115, 0.036067063244239944, 0.03383570959070518, 0.06592843891872514, 0.012717328631439278, 0.056146560987878236, 0.06975832695682203, 0.049673834319917426, 0.03654384572479514, 0.06438255775719881, 0.052062496467823946, 0.04617335259794228, 0.01882281668874766, 0.06567668710504809, 0.02923053099713739, 0.054696712778100086, 0.04580039035288557, 0.043228610208438295, 0.05564370087438053, 0.03300199525490884, 0.004990318763790833, 0.04110835079524306, 0.032168296240870996, 0.046229751990927805, 0.04485392319639364, 0.0191000888064023, 0.06100567666092708, 0.06783788242647726, 0.05032960175266189, 0.032989381617235566, 0.01279723160194173, 0.06803669756458652, 0.03779912292356453, 0.05972506493450173, 0.006889533082533989, 0.021832327981809938, 0.10031487762687669, 0.019458707970296665, 0.041179596972201145, 0.05045282699528241, 0.021502525215187383, 0.0065081228028922794, 0.06567687096614992, 0.08149087158662659, 0.028693813627826113, 0.045869127591891636, 0.08035439547271499, 0.04978462595552687, 0.041271588810148745, 0.026869214357688066, 0.00939562501791384, 0.07278222155066268, 0.009662245640591269, 0.06019974450370478, 0.008197721101403719, 0.05071305557184162, 0.034093471364148205, 0.024211597891764778, 0.033763996100113276, 0.07759646362354679, 0.009037248129325529, 0.054363962488188866, 0.046991664736020955, 0.05551221720393627, 0.02864532983831821, 0.02620282894631307, 0.020570062145951296, 0.0360984651882562, 0.03872169196725853, 0.06309715415080709, 0.05339404921077433, 0.024179412622845942, 0.07507181320820125, 0.053990448659826676, 0.018822420238246842, 0.037898557305696516, 0.03403268611779617, 0.028256854312794826, 0.008901238794468583, 0.04831677084908851, 0.08178138744927223, 0.02773592984604259, 0.03191282507032156, 0.01721050038242773, 0.044917887707631436, 0.030233246244249806, 0.023877847857112368, 0.015091380525019862, 0.06344371317555347, 0.12966047311502119, 0.07098766058803567, 0.06184575335693456, 0.021005489285134023, 0.013124328162971766, 0.1369918579415929, 0.022679165403749195, 0.07306196621709293, 0.027500685311913974, 0.0458269008255053, 0.038565999918407014, 0.007696943789450152, 0.05213057870165475, 0.014295644040459828, 0.11756828850916318, 0.08147193389313837, 0.0841083335539987, 0.020819789572288434, 0.023154182051638925, 0.01940841238284784, 0.08022360128140257, 0.08681172760383737, 0.10959166612836624, 0.034145481073327606, 0.033421688863346656, 0.018767995436886148, 0.029486710799016783, 0.054986416587545994, 0.03660555027665631, 0.11356947042288319, 0.0643931680749501, 0.04600208981202976, 0.05464649188422388, 0.044518556716221, 0.07777404280439501, 0.09023254767300622, 0.015932800747724553, 0.049860916821466345, 0.052279410433144345, 0.016970163278822458, 0.02342486006748532, 0.05119897365089386, 0.004555575358080528, 0.016388997488144427, 0.1560443573661389, 0.16823316864188642, 0.15101499014323758, 0.08064611409340175, 0.15420186994296892, 0.12072598801985865, 0.19752227280649448, 0.23119808835608346, 0.1617812527523887, 0.13845704706205478, 0.11431200114349205, 0.16743502759885404, 0.11472099250362766, 0.19362524482271365, 0.18210098417776246, 0.1332461016793405, 0.14337893214917954, 0.1819594570946309, 0.177852766167733, 0.2072732237678382, 0.04743699164640519, 0.13737605103561956, 0.14355277282095727, 0.26933279609487903, 0.13929752212378288, 0.06709498398366474, 0.08146048853954962, 0.11596848241864674, 0.1593111094928557, 0.20600291209355479, 0.11415299959480764, 0.13772327272642043, 0.1760733890677652, 0.1267758839493317, 0.1019710754494994, 0.13686955966536077, 0.19269264002721156, 0.1401472362058778, 0.22234067170610353, 0.1630482549268392, 0.09436125596684795, 0.1280769463928957, 0.16702555360332613, 0.10039091185336152, 0.20131462253630164, 0.11363208278893464, 0.21613422570930374, 0.09952022994477903, 0.24667216044279838, 0.17330390461269887, 0.14133487167137285, 0.1033941220732466, 0.13363020284281624, 0.13050890016940334, 0.12313321247817048, 0.1023560805967258, 0.1596879174992923, 0.12442488268378282, 0.15026693592869467, 0.16674078340011259, 0.10321622113547019, 0.13187287375330925, 0.07097200941174261, 0.1159980763951617, 0.14723764041498785, 0.12287569968330285, 0.11499989447334122, 0.18861524430253815, 0.16861673354381518, 0.09242393451953128, 0.14559497936598717, 0.098242356982683, 0.15803618596926813, 0.11498935310350311, 0.16877103897352375, 0.08422274112461076, 0.14179784924753253, 0.10986331324543684, 0.11039058858108138, 0.17870050374298327, 0.15948400021560732, 0.08126224030650432, 0.19053692989532026, 0.09890318442616733, 0.15068040890318735, 0.17648591209323178, 0.14178729255593595, 0.13171093808787485, 0.155113177494176, 0.1897995855899588, 0.1473983503397434, 0.1118798252014864, 0.08320054234636408, 0.12526286029887776, 0.11372173805871319, 0.054026914445022424, 0.1801375314713486, 0.0730393742842059, 0.1641205328726961, 0.08079825915516385, 0.18168833857822805, 0.12011194556591012, 0.194240290851843, 0.11712663882081548, 0.15963586948571667, 0.13184652032871402, 0.17080840384287221, 0.1791919491464092, 0.16244044076771508, 0.12563302632301085, 0.15658570573695246, 0.10570546296695549, 0.12590557742383213, 0.09785232629867331, 0.12062448903077072, 0.3098028922273267, 0.08332581304374241, 0.2003104038416378, 0.1711445325805295, 0.12976686740594526, 0.07916959453253977, 0.15377986274899977, 0.2101674120152189, 0.20959653861580357, 0.07037969321132669, 0.14393937143106617, 0.14147725677297962, 0.14381324271521262, 0.13568852787777302, 0.16360798940783547, 0.09969176469190467, 0.14758211951101982, 0.3347365413942645, 0.0978617568410212, 0.1520122067942735, 0.19430113355478934, 0.1301825007483844, 0.350959035417726, 0.08709933999325, 0.16991796452672253, 0.20253924472678095, 0.10241650961219304, 0.12294235699359449, 0.16827318907505082, 0.08543753440702155, 0.13208943148774485, 0.16601974144577983, 0.18151166338113048, 0.3129066514872736, 0.10544330767926671, 0.08037910946915228, 0.14837168036930024, 0.22860697981330658, 0.17435454823557409, 0.25394743698979577, 0.09389317624511258, 0.0825914334986479, 0.114060785591362, 0.059267947930962815, 0.1621742252140276, 0.13210774098913516, 0.19614378951730269, 0.15781844845942913, 0.1271875336345646, 0.21790652415685116, 0.13829888054920783, 0.15421670140518298, 0.12838018697596368, 0.2221756563672135, 0.20656419407215812, 0.15140978589413628, 0.06833608472539533, 0.15201399944001628, 0.1340707033992775, 0.10293857554995245, 0.16355511401930165], [0.03896850251382397, 0.06774107955636517, 0.02357134182426718, 0.03284880831356972, 0.043833409811580376, 0.045069519490484274, 0.07548831989087405, 0.06430528246827664, 0.07154432305645558, 0.05741045284535616, 0.08618423264593848, 0.034069676673220056, 0.02846702287394193, 0.05530858337278328, 0.03807422509717365, 0.020166272522821542, 0.07252693041077546, 0.01641285346610652, 0.0060067235233051885, 0.025670210147396694, 0.028299833760566773, 0.028041623825688037, 0.04835849965832407, 0.06455885757121348, 0.015449478749125717, 0.07019228512240995, 0.03773197531700134, 0.007610780922996422, 0.03815694727123745, 0.06177721147034919, 0.08281452596307763, 0.045415025144334764, 0.03361365900585248, 0.06304838882398701, 0.05547664774161193, 0.05052206219143925, 0.0276649154106816, 0.015493858222579284, 0.11219330838010197, 0.03918050202511011, 0.07479621307744135, 0.08753152849573283, 0.07672149162258833, 0.01668328633381715, 0.02469337718080609, 0.09151667957344363, 0.041393205268128265, 0.017704657737105604, 0.027479610233117017, 0.03204381078361504, 0.034868365469118284, 0.09066962381644596, 0.01819487356941306, 0.018694600383300456, 0.02812086221491618, 0.03483317522031646, 0.05715143851815693, 0.011439143488514087, 0.04875881890315683, 0.04836516845370493, 0.02325222598418834, 0.05390643945805008, 0.03575333108704898, 0.03151193508998521, 0.03505504577450695, 0.02937987600753625, 0.041712958876404076, 0.04125421393602606, 0.06028238240809691, 0.03937270965487246, 0.04155526350763056, 0.053593745349996516, 0.02456915027822458, 0.05360443993741947, 0.03593331578397944, 0.034257352892910285, 0.049662798823368166, 0.05218843749213604, 0.03595287783912594, 0.06638147267362764, 0.08057169631243714, 0.09412065839334842, 0.03352544015093196, 0.07362258936008138, 0.038454124268384716, 0.01891140709631145, 0.03292652027260873, 0.025760112480530818, 0.03171031164275783, 0.010153717857094543, 0.006661508927091717, 0.037935762365739194, 0.03271245615436666, 0.0552008445975521, 0.008569640509273497, 0.11620925619236885, 0.050973751462034644, 0.0692857809424881, 0.07439702764273652, 0.017789676259722442, 0.0902349608499677, 0.07245148607199231, 0.00858245716024671, 0.04403371116026275, 0.048346445264835516, 0.055406753709840204, 0.016066311678338437, 0.023847876582294706, 0.019843623102191957, 0.04014403762055501, 0.03325028435116814, 0.012027195452021496, 0.011802603370480001, 0.038517518044118924, 0.012320113000309756, 0.03598620266383214, 0.02266134428341062, 0.05199568977038707, 0.04207174466442197, 0.04095656579480537, 0.029862139847189672, 0.03200623034048946, 0.03300090741005636, 0.01847948863982193, 0.01414654417819674, 0.10957040718846744, 0.025041025965624762, 0.024770987633195136, 0.02300000685687748, 0.021221573960276383, 0.026327017544498368, 0.052515947740645184, 0.00842708208027386, 0.016813063543410074, 0.04903648747131229, 0.04213624160676714, 0.025146267294222792, 0.08018391792692485, 0.028592917932978565, 0.04919290730369188, 0.02682066928114622, 0.0790364790948168, 0.03573388394509112, 0.06831304846151222, 0.008309238605321416, 0.05554458824917675, 0.015490035443837124, 0.05513504147529603, 0.052799526677136464, 0.007333214340295884, 0.031246303678340012, 0.0652721543766318, 0.053244428408722726, 0.08618568055211537, 0.06396666394486543, 0.026453935330913916, 0.04558787756269017, 0.05631695809443632, 0.07879294740456728, 0.08316661997307694, 0.0145606798187439, 0.04752986831590534, 0.0019368102033284584, 0.0249606020553338, 0.08776811176850911, 0.05969332591179879, 0.03879040622362687, 0.055532081863812865, 0.04987513158290137, 0.018190349820220185, 0.07886680594134717, 0.013903116867426905, 0.06383284753669174, 0.05660667339520109, 0.015391410242075161, 0.05538699247183339, 0.04420788891072716, 0.006895156167898208, 0.048791584483678305, 0.07991748786861859, 0.0917454181058753, 0.01859595507173048, 0.021531351188558246, 0.06790552032931198, 0.06445668442475219, 0.03720344742760062, 0.02501809886927086, 0.02443681241974475, 0.052425629804812135, 0.06078584390061517, 0.05960349444179766, 0.0883451521757149, 0.04717367573551113, 0.022607794737503416, 0.04431095454962023, 0.058607829118808435, 0.026059166393092564, 0.05544847868863614, 0.04166055080150405, 0.03913521856790589, 0.05168502579533285, 0.040023980151501395, 0.0806875364674676, 0.05578178439229246, 0.03568674272467052, 0.02624298152964442, 0.055835870199746666, 0.061915559288595, 0.033357387273422176, 0.059878887728818005, 0.051344166464743116, 0.031139126062513362, 0.02748702404900424, 0.028983423591501294, 0.03934758580139568, 0.004871346266759981, 0.04093734081834555, 0.040496177595829776, 0.013563860575818728, 0.01982571005130247, 0.027621250314217423, 0.03973596173548891, 0.06871583450946116, 0.03827351137935635, 0.03324664543352781, 0.023492545850815314, 0.02295791990153732, 0.034567909615655104, 0.020242044364192316, 0.040182721230291554, 0.056236361814362396, 0.021855188045470465, 0.06902331155875037, 0.06748090077552103, 0.03377204768419747, 0.06219455701929908, 0.01506105493453722, 0.08519599454537516, 0.019656193945857308, 0.015470883245730113, 0.017974784169646523, 0.034810188752148426, 0.00571129895228472, 0.05886218563142804, 0.12370555676640042, 0.03694998723785243, 0.06833967001688096, 0.04312841739926127, 0.07104360798914587, 0.013841803020407117, 0.022678180980766495, 0.05671550384572437, 0.01736228346764561, 0.022751215973027775, 0.05357689907654159, 0.04223783252640598, 0.058230649559728564, 0.04550997408167009, 0.059850680371446, 0.023196883792538318, 0.029148846872210987, 0.03881695117020319, 0.033935224412069205, 0.09083278522255922, 0.01882763155135176, 0.03891769939312532, 0.06030581320726103, 0.001454557256487709, 0.03889991849240276, 0.009238356743158113, 0.09170498398523177, 0.018638239294711142, 0.0614851672622946, 0.031813134048734946, 0.1351543807334477, 0.035763309382262735, 0.07140187666781488, 0.03313205400181394, 0.03885645832445833, 0.03558837320475328, 0.032459624156716375, 0.011343931208454795, 0.008451623706928185, 0.014430827915578362, 0.06788948610905679, 0.0362793347167392, 0.03397673105580672, 0.025699183592692982, 0.07771728335008507, 0.04868572262386161, 0.024668067551007675, 0.03987624775618315, 0.019373976730651433, 0.0353581982574636, 0.03189863137630446, 0.04557018859251853, 0.03372424762816199, 0.05377987024164008, 0.0222907779783371, 0.07921334581389543, 0.04651152295991779, 0.04367212532088161, 0.049928033784512556, 0.037600035824242144, 0.07035053590492857, 0.015816898348050255, 0.042032038327306516, 0.060441062199853124, 0.04181604366749526, 0.037081731378190944, 0.008399335333266327, 0.03405563811200761, 0.03347259923635471, 0.033862825272785085, 0.06417303270990811, 0.026994611459573912, 0.016468258860010295, 0.022707380422000444, 0.009229784219285414, 0.08860074208989259, 0.0041986296174957635, 0.015822525263854092, 0.02045914985149378, 0.05204516755897672, 0.08177205649835449, 0.028167336938842654, 0.08354476097250178, 0.024058257732840798, 0.04566669651877977, 0.1148633546225967, 0.02708498493678147, 0.022363498874549425, 0.011372226665938094, 0.02409645296152561, 0.07654636392309781, 0.049902764374330166, 0.07410045968548906, 0.045518075461469354, 0.015895691448672405, 0.037081409621262745, 0.03402900506532, 0.10351373904174375, 0.0472174461690649, 0.041221620725287546, 0.03448656256941538, 0.08133270507377964, 0.0775974671987276, 0.0282428540559786, 0.021259769188961195, 0.059665773559602044, 0.044761238048874566, 0.0454465113580227, 0.1401577775757159, 0.14400370749494723, 0.2601009463110278, 0.13472650530597857, 0.2598102006220049, 0.10625610398429056, 0.15140918834555536, 0.10908563441086201, 0.19822685919221372, 0.17514685168862346, 0.1108086734048782, 0.12892132084215843, 0.164646084510511, 0.1601263649401165, 0.1496806794837598, 0.1671778672044316, 0.10035875148230022, 0.07172138129751529, 0.17791203072955533, 0.1292727100512674, 0.21110206992635805, 0.142240785963593, 0.11812466752505112, 0.1424877114233471, 0.17072307696986586, 0.1740125359426583, 0.2453459549935595, 0.12893811348945866, 0.1413970933325829, 0.17149405253510322, 0.26203801494932943, 0.17733129011767526, 0.0899367917689585, 0.17228768898114083, 0.2057041224813269, 0.2335969547951414, 0.14254659294120728, 0.12694233953351938, 0.3324634665923734, 0.0831118293647324, 0.08466104300872934, 0.17249315376243285, 0.14499683323646748, 0.12176367709593428, 0.0965492413829892, 0.1869261276818091, 0.2348942021208425, 0.12860484992063817, 0.11971492049915176, 0.1361412551975058, 0.24324584752321246, 0.16575490485035604, 0.14743412664580732, 0.13517819074613435, 0.14585289052657543, 0.1124044651946714, 0.1733228269844286, 0.16145929664133057, 0.1503615631091018, 0.12476884850090551, 0.1026481822613747, 0.27319041651583487, 0.06907495354572613, 0.19482421838948805, 0.10407241632140453, 0.07589335823732038, 0.2160535719726355, 0.21163762667246405, 0.2467212207134693, 0.10249969143901141, 0.21262083923624409, 0.16970391956067857, 0.13236093304810986, 0.11807504801019547, 0.11134312698437322, 0.16144676344288936, 0.20225547043786896, 0.11072498596002979, 0.1143076267814444, 0.2506926205129393, 0.17310439999545776, 0.19770492348940144, 0.1881738857276017, 0.1444158934417271, 0.13221053466681512, 0.10108429037274853, 0.13761243512553556, 0.12242156276178938, 0.10685999577324237, 0.11712680736015882, 0.140312067683666, 0.12777185187705103, 0.09252366384551411, 0.16512384758360926, 0.12913767939373372, 0.1596351033977924, 0.1629101445958499, 0.12818055978465465, 0.31753186136484146, 0.07622989300157755, 0.17538813874125483, 0.19466796709645182, 0.12401766098675229, 0.12984110132580803, 0.08095480922249057, 0.1236398494051349, 0.042044073568596955, 0.20021525572144216, 0.15463469429842888, 0.14470141441110643, 0.1369242276996374, 0.12028884292850572, 0.15533468415660245, 0.18629870167182339, 0.12590652737285823, 0.11679217249395386, 0.12014058193251972, 0.05632036718569937, 0.11836594691680324, 0.1663552419913392, 0.17542570769306154, 0.12060804878391566, 0.10294175481483822, 0.17378028872753346, 0.10437583310469505, 0.16171091055918127, 0.17030848550700373, 0.13916095929040065, 0.1638467790138337, 0.11329379368333087, 0.15625982725572202, 0.13399979430100611, 0.18354766461397373, 0.0853530349089734, 0.17372574326732468, 0.1656803185300481, 0.18118183188621076, 0.1948843256480271, 0.21608176400824902, 0.16561598246616704, 0.24020792585947823, 0.12946441589343932, 0.19813459156261337, 0.1530776359140873, 0.1092326237008937, 0.10988455686357715, 0.14440339088680285, 0.13560208251639722, 0.17030413412759382, 0.07244158821601061, 0.11788342643769519, 0.1268409401358616, 0.2811807442095972, 0.2075961451496809, 0.14205602087801503, 0.10483568504212365, 0.15872629329321847, 0.19077939672335503, 0.16844405732568235, 0.2618270649784996, 0.1385558264390115, 0.08627779496413085, 0.1319594876540284, 0.1920648769385392, 0.20559739111171615, 0.23102394124913603, 0.12053683325047455, 0.16674047696494287, 0.11870119465334762, 0.12624985733700375, 0.20362852982455687, 0.09242660050550777, 0.1515629881572339, 0.14579762494371784, 0.10960338727360773, 0.13726752702026598], [0.04941591932888954, 0.04648091391690316, 0.038221356113471334, 0.033520732540637255, 0.039654227814847426, 0.060705090572516766, 0.05121361359112686, 0.029063732588603616, 0.019491490787796436, 0.06938007870508779, 0.03347595470146306, 0.027393729861585364, 0.039726600141054204, 0.017488322168168043, 0.056086986160446564, 0.06046346644119871, 0.02435972865280365, 0.0688212022425667, 0.019321618451466484, 0.04400348516121026, 0.057189432648761626, 0.09426706545655766, 0.006431375635832909, 0.0498310930185741, 0.046959841443646344, 0.038989481831630396, 0.046999218362954356, 0.029372638391871608, 0.0444078799938002, 0.052893632917755076, 0.04755766198579823, 0.05905110291355561, 0.014699018060890658, 0.03032243420039454, 0.07668782971919545, 0.08637350998939046, 0.012939537221926355, 0.05845193405665698, 0.08976308899300714, 0.060858208565942706, 0.08759403360947486, 0.03346938166707274, 0.016495700129458023, 0.057061411695735115, 0.013030727540383176, 0.0448958856624461, 0.03248471353623656, 0.019876174178094636, 0.09448576823718126, 0.05595445294954604, 0.05606743559661893, 0.0165493167080586, 0.026296776223687396, 0.02046414857519971, 0.04938069077569151, 0.011318646476513917, 0.034050279326977274, 0.04855463348869835, 0.039870000309160644, 0.07311435897023448, 0.034540437702690406, 0.03742711828841317, 0.060845954989593845, 0.043716052802459854, 0.03853252187611596, 0.027261533729371526, 0.04101387683242079, 0.061471691775706515, 0.07370455310710015, 0.04535349296225656, 0.07481708131249874, 0.011627309046865953, 0.017110843834797704, 0.045904654919380145, 0.06724754273290597, 0.062031947196491306, 0.01664692971615061, 0.03511258280806003, 0.062329281241663044, 0.015473428572858534, 0.043724885796226805, 0.0982814657712175, 0.05655281741412417, 0.10090400690152761, 0.056228957574574225, 0.07167023726769033, 0.03070379085388155, 0.06722667449784857, 0.03149043100195066, 0.04983602279436685, 0.025046124280760848, 0.08114650740378326, 0.049758824114237106, 0.032237225001858126, 0.042547998544309414, 0.010593244524282074, 0.02179761653796079, 0.046520045688075405, 0.06320160640884312, 0.061346792630971446, 0.04842056044107003, 0.08266621900181617, 0.025125988946867087, 0.04129062609506711, 0.0321435094660809, 0.037130075356652664, 0.020505442629538236, 0.04256318623740827, 0.0261867085411664, 0.02901758345204496, 0.0442471087820107, 0.030753734040885206, 0.02100941931618558, 0.046846923914047024, 0.021122926733486598, 0.011915428011918501, 0.02321585021432369, 0.011967958660886414, 0.04037008335393283, 0.03984084300276253, 0.05695427429952449, 0.04229875183814476, 0.036568295420898546, 0.037433285296203635, 0.07358980079692218, 0.043297021860076536, 0.06436912057500693, 0.04664757251439076, 0.06371752449101017, 0.05230056212073373, 0.04834309363016679, 0.05343988425128403, 0.032897922210395336, 0.025429137599384113, 0.03797051594442418, 0.028723422926099553, 0.026607949647211263, 0.04088510128278886, 0.036149704979071696, 0.024590949310109984, 0.061297134811719584, 0.023090627397440618, 0.03787636373853011, 0.09261809184306091, 0.06763027259899725, 0.0598137051377806, 0.0557896827587918, 0.022424881669482397, 0.015192943673971442, 0.03205512781747647, 0.06350771599118749, 0.03352016563557329, 0.010521058932006841, 0.005749152793038276, 0.04930615425109864, 0.038004882648707404, 0.03660656151271636, 0.044194451728535276, 0.0451727919731169, 0.02447649385900267, 0.019002508357047074, 0.020105251704432794, 0.02062653431728963, 0.07301642228999446, 0.04579165312010915, 0.10595504675180682, 0.037386726302605484, 0.05773725829297497, 0.06255482901789008, 0.047204740600840706, 0.04072476291067658, 0.047966818054837566, 0.05731029451013573, 0.03531134048957498, 0.040701627055363315, 0.03297920796960112, 0.01680057056458487, 0.027606363310628844, 0.06719088287002618, 0.026291633858495665, 0.038140962846697345, 0.0492627285571108, 0.048625190186524586, 0.029449810258924004, 0.046206056891429814, 0.027024358653673725, 0.050412277961450244, 0.042856142090092746, 0.06587891899529966, 0.03552214490369924, 0.016963337435417117, 0.05935839993218261, 0.08402955673274495, 0.029591356494253682, 0.007016666331178239, 0.0641137566567669, 0.06283271209066434, 0.10569445428348358, 0.05027264311549164, 0.014359980104340902, 0.008728590347023021, 0.03983053145930171, 0.061079381980122104, 0.03912676478766146, 0.020211699621511564, 0.05296521234296022, 0.0362283285827406, 0.005126349644870648, 0.023012352363777258, 0.050140335900528785, 0.011700778794024261, 0.07935750057860728, 0.07600076376430451, 0.03557458745255586, 0.014098762316749463, 0.06136809753614569, 0.07094430767240063, 0.049450508198670806, 0.050649022112690636, 0.011594082855980003, 0.004542881759980153, 0.034565887143535, 0.05229531058801278, 0.0677201806777908, 0.018584030913189054, 0.09889956849116473, 0.027241751423946796, 0.03837022231891751, 0.0769100871477877, 0.02381380290664252, 0.0005926850597813515, 0.04618829131246575, 0.009895875644419464, 0.04286729633027027, 0.03565245262917972, 0.06718377357408886, 0.027997809342078628, 0.027110133688115788, 0.06502322942739533, 0.026598837031351946, 0.0855639159318901, 0.020850850607178385, 0.05926928092395106, 0.04441492800270358, 0.012936201866626019, 0.027615621483193773, 0.0728831842782036, 0.07705380524238271, 0.04245906339717969, 0.045462296599702495, 0.04915567926101146, 0.031306788235181765, 0.04563093553447435, 0.04597854793011662, 0.016715483094054847, 0.09140345943911422, 0.05938273471509738, 0.03087335292460217, 0.02463890066851051, 0.08402513640542185, 0.054223113392870274, 0.09348550255620673, 0.05568599658868006, 0.10213863420029802, 0.04608480432521432, 0.031887157294418544, 0.037647165553343874, 0.05014415484883132, 0.022262578281844338, 0.04179610239882623, 0.029020249438021454, 0.08034265134483576, 0.02660166006535292, 0.013204509797956676, 0.048970067648277174, 0.08882228705671527, 0.021218521099898125, 0.08456529733995277, 0.015584097634400091, 0.035955463385870384, 0.045315487340333006, 0.06755145747334727, 0.04631641951780166, 0.015356103164864885, 0.01930445425152298, 0.08388465886274654, 0.052429912236308863, 0.0160157096557199, 0.009581309409000942, 0.006190898721181458, 0.04225977711499699, 0.028526410009832154, 0.03706163306149744, 0.052074834313844486, 0.03665692030241893, 0.04644979542541889, 0.07022036224483483, 0.056372445842791954, 0.01869319269673959, 0.08834970273798512, 0.04548020390493255, 0.04376161205131681, 0.050741668955813495, 0.02512351256765185, 0.055348665092981635, 0.033677700125882705, 0.053997255351033904, 0.08951071664811143, 0.03738654627194328, 0.005473940973094995, 0.03349370878910826, 0.03273772939498867, 0.008106056766043748, 0.022490508591515884, 0.05183163970228165, 0.08881118644269244, 0.05776483745824906, 0.01701703636846956, 0.047032558509419044, 0.032449504135236625, 0.06245465536091117, 0.05094554793510226, 0.06979047200612484, 0.03907051095138154, 0.025013423817712935, 0.05421077554684974, 0.01738459769366009, 0.022796972489525235, 0.02510182844895509, 0.011241032193685252, 0.04419840474222456, 0.04096797667443752, 0.011665551198436128, 0.02895897389539788, 0.012692570584946343, 0.007497681447515085, 0.023315826603662104, 0.06076411764708258, 0.0729577629376323, 0.034373848053115996, 0.048684891418463765, 0.02099775562753841, 0.06387613533485322, 0.06345117870237559, 0.05850425403144571, 0.052002473478956576, 0.020685986570653417, 0.057368758510077195, 0.028931647539138797, 0.011979595536456234, 0.04239840455533516, 0.08058514881638751, 0.11304767261589728, 0.2320405552464147, 0.1680395016146283, 0.13418950831457493, 0.09332643972048837, 0.20476529705187968, 0.1285431338774581, 0.18939702170750788, 0.11294853317761615, 0.1056288311918897, 0.13069129038241603, 0.18350055020663048, 0.12221982116780936, 0.11058892108379834, 0.16713251479931418, 0.14702517359006792, 0.23179637238142953, 0.13468092307448387, 0.102083828270195, 0.13805056080943154, 0.22170311801375883, 0.24982982164909764, 0.10762901781427284, 0.06151227911393489, 0.1457662459823393, 0.07298044680107026, 0.19391942258563735, 0.17297021203464077, 0.0824635197979308, 0.1466608374950386, 0.16362369421028322, 0.11196344369842161, 0.07625101404564996, 0.14892306449192186, 0.15771761596683534, 0.17593869548891822, 0.13723224101047363, 0.13740030537930228, 0.1441438402980566, 0.21200461343171137, 0.24195394749122284, 0.18059909944572758, 0.11879061243586964, 0.12210590389346886, 0.10393133356926904, 0.15646775884013023, 0.11185034613816008, 0.1890632218771404, 0.26475431758069223, 0.1910367869441548, 0.16728490500921206, 0.12525207378090392, 0.20272120593055604, 0.06808268582268108, 0.09758652443246496, 0.11939419778965174, 0.07335053621641091, 0.16396927647292614, 0.10391861650972598, 0.16869485919033328, 0.28141869111887874, 0.1292348959513249, 0.1295874189705618, 0.19124957552600294, 0.21970722914463092, 0.10316529927114326, 0.15997599720233874, 0.1245188050632996, 0.1348999322902772, 0.15208952038759185, 0.17132505353900696, 0.1629940618670756, 0.06743853611330833, 0.13421595366972108, 0.18227971249049713, 0.12891770490715582, 0.1642182550483173, 0.1570741480757152, 0.17525255650041566, 0.14122240996408847, 0.09151208304589795, 0.18343011608287213, 0.0960050201824596, 0.2495013997559586, 0.12641545490271625, 0.18811459052226237, 0.14346263491578642, 0.19159828342737692, 0.11808669254664453, 0.2039437290401228, 0.10671393344959906, 0.2797267706163468, 0.11024179898442761, 0.09226370723016801, 0.24955128740158775, 0.18565963112538864, 0.11952271669982903, 0.14622755348682404, 0.14464503033987938, 0.15506903550797893, 0.13640599986237867, 0.241614677793076, 0.10039481124089611, 0.12903168346853028, 0.12669440283770525, 0.13133054478995262, 0.20155445402187688, 0.17234194332793837, 0.12373812316406159, 0.16173806071521776, 0.17132591155748214, 0.08355204646866168, 0.10190964285885135, 0.11062373977995689, 0.1835745389783575, 0.10285523284466998, 0.14886327899031102, 0.11189986606158557, 0.0961918154010369, 0.13911902363742554, 0.15052783483218762, 0.11540952168645398, 0.17439363404147087, 0.16010940375347293, 0.14499462690324555, 0.10246448203801148, 0.1543559455463002, 0.11648974396408567, 0.1018103578638646, 0.15406774326918588, 0.10638048601967674, 0.3379295958626655, 0.12323144027182173, 0.12063216523177202, 0.12152926185198369, 0.06069665594447044, 0.0888540414011767, 0.22725310326824266, 0.22363614170782029, 0.32615068759168353, 0.1151211125656001, 0.09351193258959441, 0.09440888365310046, 0.10462347102621872, 0.16942601350526657, 0.19871548539207828, 0.12416556192141388, 0.14669845241212076, 0.11293013940655416, 0.09309125072773426, 0.15355631829269473, 0.08372014914188655, 0.23183938055749864, 0.10168503354033155, 0.11465485613312452, 0.12855133101824792, 0.06249788953291793, 0.13058521784842014, 0.12085039303788256, 0.09862086570431149, 0.10146257692887899, 0.20646783553304213, 0.1557731775627021, 0.09171115865390148, 0.14777828398491108, 0.10406011294934059, 0.1614915336211843, 0.13905674068918153, 0.19800265590029378, 0.23705455474555495, 0.10272964805124268, 0.1169654232780299, 0.17611529407722337, 0.13456446238823477, 0.11067021833432299, 0.1578040153629357], [0.031744004189667684, 0.03285309074506645, 0.06459461855551889, 0.04177286695208281, 0.020824252034447367, 0.07151096758823242, 0.049248467830400315, 0.10543095068104806, 0.009992169066061898, 0.0218416991523437, 0.027809066344953837, 0.02303639411806099, 0.03147120219505122, 0.005853093208579888, 0.053560983599914666, 0.021703479653825204, 0.04067647638880918, 0.01154405061125515, 0.04094412069647543, 0.015961861335522225, 0.01010234687372201, 0.008826056840799509, 0.025709299783733104, 0.02083752642295534, 0.004121280592610879, 0.03573556167764529, 0.027178796233549237, 0.06170996044191623, 0.05065477543300198, 0.003408018739954118, 0.04269451669026767, 0.05687277020526029, 0.006269066023730463, 0.029419890695041227, 0.06358380384382702, 0.015117706178927855, 0.030924885744048707, 0.04894170707332031, 0.04564329636313262, 0.037588567488015666, 0.042186585074711236, 0.0676778543199743, 0.051680777837792714, 0.03698197140869114, 0.049249402457667936, 0.03378255074963935, 0.04237835220391712, 0.03388177828803178, 0.05387076274341634, 0.03407870118896808, 0.10623494463582193, 0.0679750734519574, 0.02150522184468085, 0.06730738952155076, 0.03572440743746777, 0.06968505830774385, 0.011064466164116899, 0.03250981440707561, 0.03710254981753327, 0.03125244770349274, 0.08587860952942603, 0.04029700622683571, 0.054923359890498465, 0.043643496615151246, 0.01463109287508433, 0.04927718080580235, 0.03256707181853633, 0.031581434586475936, 0.036861913939637524, 0.05763539924256264, 0.03471877148014403, 0.05486977970107429, 0.03215025487025419, 0.007128192932390038, 0.01928429464779554, 0.03262611421486063, 0.09494779586431482, 0.03206670340601235, 0.04485013489160807, 0.07458123348412976, 0.05902589862084678, 0.06296916001085794, 0.04051601544262902, 0.10647453097326141, 0.028300034858646895, 0.029728423030446136, 0.02692309523662252, 0.02062017387229829, 0.0351653203007675, 0.07868622369583576, 0.03245579754753459, 0.05589772796919269, 0.03749995409781414, 0.07834683908450027, 0.07535765593450877, 0.08742672766769126, 0.06913429471634089, 0.02402804897076661, 0.04732463719143022, 0.06103412916643485, 0.03657515190782086, 0.1025055596725114, 0.012269336692688447, 0.014765119957437199, 0.07176445842149758, 0.04035800214736693, 0.015898649505670034, 0.04212759247410201, 0.03918462740858236, 0.09442193013045097, 0.08399859911972478, 0.032223358810428655, 0.0267851572754162, 0.016486413228595932, 0.042017869531146945, 0.00737050079718052, 0.02243551688509122, 0.05044467581976807, 0.07239003815958578, 0.05617309827357531, 0.017247967827584476, 0.02911242130663126, 0.03239272169828896, 0.022252925573998404, 0.039125615655775034, 0.02371232881541214, 0.051691070229055426, 0.013950814459202512, 0.022639773162682692, 0.018299013646619938, 0.04834875501992722, 0.009578065026641614, 0.04064171897968458, 0.037073706607184106, 0.016804717015475035, 0.05781878153943728, 0.033326142377430396, 0.05177461977807745, 0.013159952209060712, 0.08721641354983853, 0.01473937844557147, 0.0329663185402751, 0.034527575086441734, 0.03513873704979497, 0.027615351437200463, 0.012966624175709103, 0.05446979753492821, 0.02359463472760493, 0.018378351627278234, 0.06267079174698842, 0.016048737621355443, 0.04386872646488971, 0.0016797295299306092, 0.005367167468648405, 0.07201367448414527, 0.04996209405362607, 0.03944749515804072, 0.05756550138035128, 0.053170297910729726, 0.058597483101391026, 0.0274945872520367, 0.03215467519757729, 0.08148075156514684, 0.02018117101772899, 0.04517979401674482, 0.03288763364957225, 0.02873614764652185, 0.005844206109853281, 0.014059937938356833, 0.021908071094883547, 0.012713107486976492, 0.06222734175201866, 0.027650005424455292, 0.02838750677784124, 0.029669721543248144, 0.052906403603452834, 0.006722895073659358, 0.05055796107157104, 0.04270701541475231, 0.0509119626405018, 0.05380913096990797, 0.01232101028079107, 0.05069463115726268, 0.0793368851525649, 0.0323261333359105, 0.06859319915454234, 0.06584401602946943, 0.03790927104531758, 0.04665246781622691, 0.08190303455076872, 0.05008196766157785, 0.0021366280787098674, 0.06234783972162874, 0.008880823508896416, 0.026686027413234118, 0.012686132573552672, 0.05297523277300981, 0.14685240544138417, 0.08636263154086568, 0.058067147244489005, 0.06196484172476396, 0.06328859952308478, 0.04165736004529942, 0.028628805321791483, 0.004106907825541473, 0.016997476228542866, 0.028963036076616377, 0.09411895767815652, 0.015555555113561213, 0.036546435101979205, 0.04161961872370974, 0.022953662367898132, 0.023807459698629477, 0.045216340241172624, 0.06520693731163779, 0.0527128744720211, 0.04609131607257071, 0.03524996535552125, 0.10259743659727036, 0.025611332459976117, 0.03146002497223597, 0.03684867977074558, 0.054004437425324035, 0.05250308512439651, 0.07133753294305456, 0.0897355557930085, 0.0484522151941013, 0.04734656262782313, 0.008991123890624413, 0.08980323966111868, 0.05870954261251515, 0.1057185860530984, 0.02935141967158885, 0.0392908186862065, 0.06825042843458153, 0.05030312192355914, 0.015954306750978916, 0.041785281406895775, 0.042127159634424795, 0.02627430686486825, 0.01801283192640591, 0.043083030520187277, 0.0455518561084905, 0.025142915659554066, 0.055856956769862486, 0.029156513497113224, 0.009348928128489324, 0.014249680680222811, 0.03467707331442545, 0.027134198425037247, 0.06898976456854614, 0.08295589982862435, 0.03637638273498705, 0.014988577271240854, 0.031198465317908316, 0.10313886923775559, 0.03550867324755077, 0.026744209875863408, 0.04032534764959447, 0.06352566543125338, 0.031898499226137515, 0.07713501056235644, 0.038574549459641984, 0.12582800336061947, 0.05082182856577058, 0.0985477043075427, 0.01674550799502721, 0.04742358127729066, 0.041430563545755805, 0.056834768413776354, 0.05618735900028579, 0.04150520349221845, 0.019648058092101447, 0.019206056003308585, 0.09334354646383755, 0.058314497883041064, 0.027649917324344, 0.028833639995765784, 0.013936384235538784, 0.04192831768323818, 0.08079743944108486, 0.02377297233549818, 0.03887993125845829, 0.044482788071036346, 0.01043062225254553, 0.06979180499911308, 0.1402934364253475, 0.009809553814721445, 0.0729385034872159, 0.047733249338043314, 0.08769477417151775, 0.019148057401781122, 0.03053930220043948, 0.056921137166359735, 0.062221933171273246, 0.07179006874080628, 0.009459152859034798, 0.020261284662410617, 0.06122086692841784, 0.024177664027158773, 0.04093519194171794, 0.031511808685477705, 0.043479220551108165, 0.04402806126182118, 0.01923474599607289, 0.04645960135084968, 0.0250997715028784, 0.04268515892627259, 0.039591209422196114, 0.02513126920788519, 0.052573909952996246, 0.04661599437015192, 0.007947997984311153, 0.09976007675211276, 0.05296702797134077, 0.01194410459814413, 0.07434064357150948, 0.029856798299137625, 0.053803676423887094, 0.027949685613895138, 0.07615729850987274, 0.10175821791973808, 0.027391086858246597, 0.027251287303384275, 0.04735637621413316, 0.10972783059602785, 0.0620442582294345, 0.027926714467485587, 0.0345015280970162, 0.030733731485182242, 0.031693637739085866, 0.0781271174069374, 0.03528579528773985, 0.06451389587093746, 0.034117373307385755, 0.01611545621868103, 0.02435213672147403, 0.037158872601726366, 0.025679422354686166, 0.024256069295769258, 0.04336914903814754, 0.10562844048704832, 0.02770025504662866, 0.06774426648213018, 0.03341395903619067, 0.02276776730263185, 0.06506981523407084, 0.03198224987323967, 0.06335634084778928, 0.054933594825166854, 0.06876333196076655, 0.055570573951568336, 0.12190396311662852, 0.09067671779062479, 0.1768540786278825, 0.13161724553473536, 0.20077572564684576, 0.18246740403194583, 0.14716411129601542, 0.15287160422773133, 0.12740768432136507, 0.2062275597164708, 0.11002268251632491, 0.07602023771933972, 0.19054716482998865, 0.1502327377637548, 0.15663042994997195, 0.10994726882105875, 0.1656402674533667, 0.1258377786425333, 0.08572012125965088, 0.13156665308821586, 0.11678388342261316, 0.15767653833233541, 0.14310188411224273, 0.11740632986109104, 0.12753517667372383, 0.1575076006232731, 0.12880790918584795, 0.09791341414975543, 0.19776867732646006, 0.12190942532352864, 0.08371101737382912, 0.1919308115517901, 0.06777099528980833, 0.10329167313513257, 0.21501607441854095, 0.19775283462818594, 0.12726016643066562, 0.11541468511906364, 0.23366576481250026, 0.16280693723069084, 0.09505535460888379, 0.10978110435028231, 0.20301323864729176, 0.1231866930761645, 0.09196929964086703, 0.1872000654017733, 0.14247234369958603, 0.16613721336808898, 0.20019739055104796, 0.17095465002761734, 0.31854294420730683, 0.1876471543143834, 0.12038018359171769, 0.18995025976290628, 0.14815769669029022, 0.20301365233477087, 0.09215975675972239, 0.1570639284628053, 0.09990560281420909, 0.15698273846459004, 0.14219566338485287, 0.0918249533541741, 0.1837193295960465, 0.18342722027051836, 0.07146471886024361, 0.13075205647656996, 0.09969403997303979, 0.1442871447051725, 0.14397618961670708, 0.1587701288442458, 0.11444120187192194, 0.15128761019197204, 0.09886913181793305, 0.1606299604980215, 0.12092384554806257, 0.17550672915193344, 0.23950897788088168, 0.1285770102854698, 0.11256441669238192, 0.18552171997725966, 0.13197989623633125, 0.15115397381446055, 0.1982930032235961, 0.15765350972933156, 0.18801262421954065, 0.1863892072991979, 0.07950416045083154, 0.23638133199945574, 0.12322354956620163, 0.21575508879557734, 0.13052206155994248, 0.1747939456254244, 0.09279475937927924, 0.23429942677818963, 0.12301398621451472, 0.1055574547799845, 0.2115658289122005, 0.14477134291683474, 0.15875546592137507, 0.16880954255259809, 0.16400440926513365, 0.20009453558633405, 0.054889923983043244, 0.11920337294859272, 0.19577012247135564, 0.220397612260234, 0.13598399266840952, 0.09164323729853477, 0.16168068072968916, 0.21875824538930772, 0.2596824784432688, 0.14271680235622392, 0.17810851696037477, 0.18061339464639464, 0.14449126117171782, 0.1122987297393622, 0.1368478946988621, 0.13123289922312384, 0.15326361141858563, 0.18693248621158062, 0.09760393761098386, 0.12069162897645466, 0.10479612426171381, 0.19322050525055778, 0.14140198097353981, 0.12959472744935943, 0.20466558304765534, 0.08952540255361989, 0.14476536743102536, 0.13354737341644304, 0.1252429113693295, 0.15427092510846355, 0.1345045083472806, 0.1611369881298273, 0.139597108467452, 0.15516721733635472, 0.11263335694468792, 0.1678473514414603, 0.1530801946477544, 0.1701136846696177, 0.2562040409013148, 0.05999165970171171, 0.1579971614504053, 0.11563721067842939, 0.12229088348366561, 0.2697891699931314, 0.11544391903425417, 0.13090702074189342, 0.13376391582912014, 0.2148769375297331, 0.16121272358202166, 0.09873838359189611, 0.1822274499723027, 0.0794979244951279, 0.19973914739826035, 0.1774402891075419, 0.16600667198579158, 0.1632066665878219, 0.12648817962936817, 0.2810291200876236, 0.08283557805923686, 0.10554895886490423, 0.16033319335791374, 0.13424445214050432, 0.1344983949656448, 0.15546976077941158, 0.08041013603008564, 0.15142454074755793, 0.11282957504473387, 0.121639134182084, 0.11008747823296056, 0.10707025626494039, 0.12803105772623133, 0.08026703080583004, 0.15696711027093474, 0.13318484528891503]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.08107112435203406, 0.006378589783825221, 0.06061198024619972, 0.013556139367151887, 0.05758466890021678, 0.014095079349053484, 0.01788491631046899, 0.0507765872434022, 0.08743018272422975, 0.03956166907183586, 0.04876126272363528, 0.07188087314247124, 0.03823961964958618, 0.04773468958334096, 0.009130960792273043, 0.06678533890554983, 0.05045887142900498, 0.038355283604394046, 0.049176183604304834, 0.06533888063483662, 0.07188808969071797, 0.05817628029974238, 0.04548092785802099, 0.061691463248984474, 0.048656572978342735, 0.06268869522177885, 0.03741184632564264, 0.002480683671761184, 0.015382501597125686, 0.029697775683035294, 0.07211552587367835, 0.012559368004721981, 0.044276453779950264, 0.08963371206435466, 0.054306034749794396, 0.039633842215182326, 0.027510303545803316, 0.059371036552493615, 0.07263358517159378, 0.031729053983825355, 0.02796162317897524, 0.021281656320957888, 0.007951869601158486, 0.08463529479359427, 0.016892880329021046, 0.11795355412628382, 0.07513739033451966, 0.08053385922985692, 0.03479141576756393, 0.030583681673893047, 0.06520041024252292, 0.030144682649763364, 0.05707849162600695, 0.052251363954236435, 0.043606479246650016, 0.055085877782755324, 0.07269271949846899, 0.03576915080268537, 0.06278592327068891, 0.027614051002949, 0.05322637554678706, 0.04032736629127495, 0.026178683770159562, 0.04251695666161757, 0.03476831055576763, 0.03222654190575404, 0.049330787808303876, 0.034286805143159245, 0.03792045209857245, 0.04540791967883707, 0.03192811427007039, 0.03487812542927361, 0.07381286261783493, 0.0645160332562462, 0.051949211216020974, 0.0438110783485876, 0.03414975584394509, 0.03387581429354126, 0.02726083467414062, 0.05555031092597112, 0.0369237448960062, 0.026275607299119718, 0.07519615693919121, 0.041280287738528945, 0.05320273024300414, 0.04562360790347861, 0.049632339167498776, 0.08227936758269226, 0.06163352784971076, 0.03276257745681271, 0.03148632477067652, 0.03107591614788098, 0.013346655497087107, 0.053557283395240386, 0.09347699131936797, 0.018545600112467524, 0.05187576253628058, 0.011001829857817821, 0.021151130260418982, 0.024954119036274574, 0.007956415854184138, 0.016658334850123333, 0.0896545343341366, 0.07841198720158109, 0.05826818403757869, 0.04104151728472883, 0.03596789316244183, 0.006731293791334235, 0.09737189723959855, 0.05582543608221797, 0.046110770875407804, 0.03660132913219352, 0.006631517542466041, 0.009042315800944644, 0.05371011410569472, 0.05755395643533238, 0.04990683613164772, 0.06672900079959823, 0.02628379103337084, 0.07858527629005332, 0.0532012018975952, 0.030152910434070136, 0.034223844207102255, 0.05443776739881404, 0.01648518174225765, 0.031061527101443182, 0.06328609441557238, 0.04465939815066034, 0.010085501557876988, 0.024883711725593578, 0.0753706717683423, 0.06029010840481328, 0.04692569307442154, 0.01657715251278733, 0.04105492382340374, 0.07197365405098086, 0.05729742806344744, 0.04403735007790308, 0.13066934962426463, 0.010961668655997323, 0.062110455886971574, 0.04250577177792307, 0.03831763038291566, 0.018323610814648773, 0.04313091867633405, 0.06575471316013606, 0.08469406905914507, 0.07208584762749172, 0.02423414385937635, 0.0554837646984285, 0.013919374210790042, 0.04298685201173348, 0.06609553035588996, 0.008172740889412743, 0.025071522010670557, 0.023636317571565032, 0.031948492208856254, 0.04397069276761144, 0.08222465358314016, 0.04486649469923108, 0.040113880569415714, 0.055737335970925714, 0.01503651235027299, 0.04460754931994504, 0.0018653599357592965, 0.0012503701662119, 0.04798343067147559, 0.016047832679994885, 0.05157883834814833, 0.047566583079676476, 0.03031716351547549, 0.040220274860339786, 0.07200440482026146, 0.0642283710711185, 0.07002386069225688, 0.04474071072294347, 0.03048680985586778, 0.07381810265923701, 0.039246132777583216, 0.05251559534020001, 0.05786588828590128, 0.026383880420678088, 0.030361094827493353, 0.0316718980790146, 0.022716351311593767, 0.04649264655346352, 0.1211594329065373, 0.0750635011542228, 0.012192120775580408, 0.009418264831296139, 0.06303432344969723, 0.07196233893233923, 0.055745946799194625, 0.005849527069292362, 0.03357181528342828, 0.026410392808517622, 0.03252730419438693, 0.028337385475395188, 0.03535880346692378, 0.047885333112771475, 0.09197873784409416, 0.008199964781411955, 0.02959762500869411, 0.03343429484014069, 0.02646189115400757, 0.0924695244119052, 0.017380658086509477, 0.01693632900564661, 0.06181434758247868, 0.04612700044808369, 0.03313183566675552, 0.05502631827708214, 0.05341126703687253, 0.06923920279669185, 0.007444073487403653, 0.003297628342895018, 0.0608158975298847, 0.07350503316810054, 0.021512507340840755, 0.032634989343463414, 0.06719332669050464, 0.010750681338381144, 0.04618190980005649, 0.04395061743355567, 0.020036282723829634, 0.007183003171737637, 0.05044821514597824, 0.05343668583420016, 0.012948646964955957, 0.021413436850472804, 0.07666294718341482, 0.012649637102449854, 0.008727764887284608, 0.03896978188065752, 0.03574111581509633, 0.016924318662213705, 0.02910334699516816, 0.07025723405663045, 0.009341764248787396, 0.04462065325388986, 0.1298465865153459, 0.044335070997476585, 0.02317345873903363, 0.02322707148719459, 0.03876900938790172, 0.10203154276936285, 0.04765611194494752, 0.04139551119278035, 0.04541365384695031, 0.04711885831408924, 0.030239932276608966, 0.05138290753107398, 0.03411403316403589, 0.03165387394537609, 0.051295945060349284, 0.02109969511718279, 0.03746294055975253, 0.02854027237082201, 0.014662930531607521, 0.06693370715384522, 0.041491900375413324, 0.05472695792935068, 0.03169940446593589, 0.03273371126382582, 0.02188859905506815, 0.07358578649619896, 0.039119666983043, 0.06186254983467441, 0.020842184237534964, 0.022920647808801264, 0.0491775740538874, 0.019966442318212603, 0.10234057497713836, 0.03119804205433015, 0.030069483459115993, 0.08618104572017347, 0.056903900188063426, 0.04058334691029403, 0.02436344800967603, 0.03459017213073469, 0.03825237118308583, 0.042456719168131395, 0.08215709228909786, 0.034961207664661834, 0.0501159091870631, 0.027893983360920704, 0.014541579331571778, 0.06561759874344834, 0.20620606328931548, 0.049773402767436165, 0.05869234776905468, 0.038269110204231356, 0.016173705714003696, 0.03316200420921368, 0.032503026868066484, 0.04508299497707237, 0.0824336117253669, 0.06951827330574875, 0.08117492160489483, 0.020905013023425015, 0.07254549272118077, 0.027892014514955304, 0.043362759864859046, 0.06608502729044807, 0.021858893995804173, 0.04320527900070433, 0.028952590467768814, 0.036095653645574086, 0.03183142248270733, 0.03351882115126618, 0.08956611246591614, 0.047481003397655104, 0.03709824823383843, 0.003604853780181598, 0.09132570151479975, 0.03550638264465717, 0.01794164320604215, 0.049541481139679114, 0.027830855800740184, 0.08405519003469138, 0.014606388454746096, 0.04911559754081311, 0.008204866786517443, 0.046951242106696295, 0.13544670456359464, 0.05696047195083192, 0.02068878279157704, 0.07135191241339331, 0.06169099593535066, 0.024235440463188197, 0.07960384381153891, 0.012608693533336685, 0.043080525412674875, 0.020853254208040815, 0.05293972076727979, 0.0190046783010926, 0.019765298272813522, 0.051569151166345806, 0.033007775388297536, 0.008902002009563148, 0.00932560936968413, 0.04392557784975056, 0.08146894615023367, 0.05957384683912801, 0.02558323618535313, 0.007322588700786114, 0.05687310728394697, 0.04076620443694053, 0.03721938205642566, 0.05534256703310436, 0.032969888510002245, 0.06729110249228056, 0.1968710827490976, 0.14518432559505587, 0.13759101530717266, 0.11168873222965388, 0.2772680267451271, 0.10823700817361956, 0.07876049592009476, 0.12010884290981678, 0.11410898018267848, 0.13372291480341267, 0.20882974589063277, 0.18790740970401995, 0.24414194056824332, 0.11883958077598965, 0.24430982107597016, 0.18783323707119112, 0.15758195711720377, 0.08702468472502886, 0.1674074790770969, 0.13838304296856926, 0.21108769811689856, 0.13131143855712107, 0.12556237769463371, 0.1653703899994012, 0.12964273051869485, 0.12393968089693978, 0.12409881268057132, 0.11607888334941481, 0.1663759110435363, 0.23707105627944394, 0.1011544410439749, 0.09272854639998368, 0.18872447311878207, 0.2739151663357212, 0.17515970664399286, 0.2013226204942311, 0.14775975997890198, 0.16039248856325306, 0.1363792327503043, 0.1312049370138876, 0.2069351644886117, 0.15119273786342916, 0.08378993209090926, 0.12782604493681463, 0.1904163782995555, 0.1544189639389515, 0.24179101591148686, 0.17113933850440288, 0.09430577587937156, 0.11615857181529846, 0.20600729411648167, 0.13761972828257468, 0.11562264734698881, 0.14920486227398919, 0.12354088616707634, 0.126796621949442, 0.37494288877614085, 0.11668819904087052, 0.1203172418078588, 0.13437646441161633, 0.12682446924548957, 0.11229470777775973, 0.15502942876229364, 0.10956447000705427, 0.1213510238355206, 0.14243463685195293, 0.20652797343509816, 0.08918653122119366, 0.16229912818920228, 0.11640000442463545, 0.13642409485915016, 0.10194141252507126, 0.2520532079882199, 0.12214917253943221, 0.1732160343277839, 0.17128173892776813, 0.1575329428118083, 0.13722274152021255, 0.33631287455078096, 0.08797590545709096, 0.11584746350924816, 0.16024918415613715, 0.2254264432215883, 0.1041008152007576, 0.14272208836290146, 0.23198371152243308, 0.11821972371469583, 0.1347094215452671, 0.11778535952250804, 0.10240828948876551, 0.20313167584038552, 0.19173195044840538, 0.12443510229669272, 0.14691117970693499, 0.2509162262562783, 0.07638717085243234, 0.17807082543450017, 0.12076115145558312, 0.11427142912702215, 0.1546171968502383, 0.18221177581337192, 0.08880901841386672, 0.11584927147674946, 0.22103626911918964, 0.1903019094419095, 0.13301137233934096, 0.14762529622643225, 0.16384078820626582, 0.17726580492190777, 0.14462143483181156, 0.20734235554212527, 0.13982497365965, 0.24301082706980168, 0.14784289584044488, 0.11640462393481886, 0.18242457971697856, 0.11664807901627595, 0.13711884467592164, 0.10318291929340172, 0.18746880904561092, 0.10933354046315917, 0.1280394463890022, 0.15171671136012002, 0.15693392334205492, 0.09487213702091286, 0.09640745382996337, 0.2133461099959189, 0.13309259298107318, 0.06936440454615701, 0.09688676440066869, 0.11644809942452178, 0.0811356672596547, 0.1922415061703613, 0.13303089225965162, 0.21563603873214415, 0.11918380706300659, 0.15665056274062203, 0.19726675184023, 0.2570338060538615, 0.13803522372918745, 0.13147352744014035, 0.18397388529152642, 0.1374398814814706, 0.13185681655041634, 0.2012708023070328, 0.12216710665773962, 0.14993125152203346, 0.16175491464955194, 0.2529052203340877, 0.13316291985252213, 0.08337544788035654, 0.22070214753189396, 0.148667941891378, 0.13875271103555156, 0.20357510285271754, 0.15315358587090047, 0.16880315337930957, 0.07965399192706232, 0.20082161431351017, 0.23670010118474885, 0.13559658200510089, 0.1928563683383888, 0.19552760967804542, 0.1727813253960302, 0.10931977386315984, 0.11897483359902136, 0.15790083355480627, 0.1488764863461256, 0.17898771010579603, 0.12379031673434282, 0.13617710811236214, 0.11487540518564564, 0.1994002913875926, 0.1308121484133505, 0.19448628168432944, 0.14290026509233061], [0.05318814009848622, 0.029384721513657324, 0.019674712206206976, 0.019984386012619062, 0.00993208479016058, 0.06372793945634077, 0.07177921327491922, 0.011100013601413418, 0.04623535975453354, 0.0622080018623702, 0.02013081414324622, 0.055900761677372846, 0.020218274571121703, 0.03276995488352353, 0.03097726317543176, 0.037498326160975044, 0.07676232410895248, 0.04933696247697358, 0.04238676384932572, 0.009683151222434978, 0.038275223585867116, 0.019487604806800524, 0.008572392680141474, 0.01749064341457861, 0.05830768736139421, 0.02044191287319747, 0.008698603750446872, 0.03390883268307775, 0.015975953522889365, 0.010319590256849845, 0.021092306199153105, 0.05318452416348362, 0.07604397878411316, 0.03725760218296801, 0.07827704081371908, 0.036320534925307, 0.029918447309624285, 0.054166104959984945, 0.060411514188613624, 0.08251927567705994, 0.050430334653825536, 0.03885692946853177, 0.06754160558264102, 0.012253638593510035, 0.02437617464531814, 0.056063919253046476, 0.05547275984539621, 0.009734549976494766, 0.06234452639135623, 0.05117876042101172, 0.010051221996095153, 0.05469246482055995, 0.01159199909682596, 0.014962203736837595, 0.007992939095974209, 0.05151559778999898, 0.06784060203860845, 0.015556919707676337, 0.025403952458873395, 0.017806911322798942, 0.027708580507145777, 0.021835851986261628, 0.08372623188000533, 0.061330976745774674, 0.020240841606151194, 0.019905565141309655, 0.0366168960388149, 0.03634175556080957, 0.04678750230420021, 0.049232598319048845, 0.03501362723088072, 0.06460883714739354, 0.09843878958734775, 0.040980682242661715, 0.008576359100369437, 0.08576587203048891, 0.020200422807266156, 0.03814767760735366, 0.06680216985724627, 0.039926526106653676, 0.06459071150710506, 0.08077051145054641, 0.036404130439604485, 0.08965026722439835, 0.07871709703918427, 0.0140769699881334, 0.04776131496914933, 0.033454860470468, 0.017695991367462183, 0.018602778999916008, 0.014204018009496073, 0.031298598755271204, 0.08058368558845214, 0.02728266051910337, 0.04466990887698147, 0.040951831371433316, 0.02737325233136935, 0.01494113631891988, 0.036384840345671104, 0.049208140962066195, 0.01501373464106432, 0.07986275088642875, 0.060541955979480866, 0.06963351591219825, 0.0013733836573420935, 0.03931062205904915, 0.02379372757258675, 0.029787335191823305, 0.05680361544833549, 0.047214339682531935, 0.1414975274594561, 0.06283641229533861, 0.050177280490677205, 0.040532972798832965, 0.054334146346175866, 0.042108570510942134, 0.0779455162644867, 0.07659781438809249, 0.029953568610512925, 0.023595230360966057, 0.07010842913821821, 0.0237398122196957, 0.04293751977984944, 0.028777698340315013, 0.03142307655164792, 0.09640765301282368, 0.05607817614931734, 0.03767227791550179, 0.08656377558626475, 0.08691139564278626, 0.02080279008124865, 0.021185092853322145, 0.02349122434914593, 0.01700408373688979, 0.059489144327779936, 0.07328410873249655, 0.08136471222725608, 0.02330174207717421, 0.04061490973277439, 0.03352071338843915, 0.02135210576647472, 0.01321842195466161, 0.12569194614526727, 0.03954815911129117, 0.05613966619655971, 0.005725400715750913, 0.010669349613899906, 0.04168560570706764, 0.039400062824208895, 0.05454197833915392, 0.049430505642967845, 0.04820142865120884, 0.041337832432961276, 0.028387334408058275, 0.03100113447515234, 0.10480798330278167, 0.06899190961473411, 0.08295206938900294, 0.018120197233774008, 0.037985741941919254, 0.0615305886153252, 0.031208206125865542, 0.02940088022320021, 0.009739387821736596, 0.04613345856928537, 0.026818710011279872, 0.031402828847809185, 0.04243853224080898, 0.06178628195137267, 0.023235251391006094, 0.03265798730295032, 0.022356347443776268, 0.06734649064920603, 0.043718010157106385, 0.04711060371670512, 0.05595043864882281, 0.0746712105108365, 0.03636292257015744, 0.008551255356700671, 0.032815981446014296, 0.0488167466415513, 0.029991514860622348, 0.03376247541558358, 0.03992253095812855, 0.053838192515315554, 0.014486054236429834, 0.057226476830340205, 0.018534804018394604, 0.041901018140056444, 0.06486160785800989, 0.043533900076703685, 0.07733880527197354, 0.033774548961270245, 0.059359855499238744, 0.03130111535410247, 0.005451564981241621, 0.040623512900164055, 0.06888242032859596, 0.052756591279420166, 0.030838564871960593, 0.07474515331728805, 0.029065488845170028, 0.05132167029284662, 0.0702798642939137, 0.04997985580215051, 0.04647379312964697, 0.09788387379939519, 0.07287864903769187, 0.09649589868082155, 0.045678306581272234, 0.10825807559153727, 0.05282939261486454, 0.04658793256948552, 0.052461524854504296, 0.024090149973128593, 0.049150891211484714, 0.020272534663578676, 0.04787740410275517, 0.0391793375714652, 0.04762195591484347, 0.0713423899404945, 0.08813769556581975, 0.037113715549029654, 0.02352356475086943, 0.021893258784867583, 0.12030101606562255, 0.06081052342309587, 0.05277464414135583, 0.03441532405333654, 0.06006634944388944, 0.007835388805101356, 0.04262203328131188, 0.11459087246968863, 0.026949653589737513, 0.06399010623534841, 0.03350213575627535, 0.0460075558493695, 0.03682653982973388, 0.027680775345934015, 0.06287903359700596, 0.011135547632171262, 0.021208899035569162, 0.035701443951937466, 0.00987161172463769, 0.04624579387206224, 0.01105735208013005, 0.06097948411479593, 0.0660551268787634, 0.02850063881205936, 0.10491299863544204, 0.012168329915091878, 0.06417504752114897, 0.03423227883514858, 0.031538441732165315, 0.10433711502100192, 0.04534602743543444, 0.03734244259014245, 0.04991933102569273, 0.012796974962487096, 0.056305056918532624, 0.018544148375851013, 0.013175274925156227, 0.01914761307078504, 0.04466093798738815, 0.03258462672332122, 0.01884954166598618, 0.008637205633755413, 0.06733311475404809, 0.028654047918896523, 0.02439225866128841, 0.045128025625261574, 0.06369808500993156, 0.025911196510517792, 0.009273905138064538, 0.029303970100778728, 0.04866666618674513, 0.017485003092236096, 0.03238177430185099, 0.04988333638457041, 0.022119310263904835, 0.04416055616832549, 0.04268724651586625, 0.08814570884550772, 0.010520723768539969, 0.011068100293707705, 0.019591352263946208, 0.02979701854318621, 0.0345491711050272, 0.020153791035315203, 0.05727808817379898, 0.032528698474409125, 0.052367908910157225, 0.038414356644235315, 0.030234429850092823, 0.05233387928456069, 0.006415573157174814, 0.023117528574901725, 0.04478764509962452, 0.03398650250728092, 0.06380974232489545, 0.016506754778205388, 0.0681534723468846, 0.06696401359212976, 0.06403573826255818, 0.06321807346877552, 0.04698904088488029, 0.056793851657740535, 0.0279471192193488, 0.04234232308883821, 0.0777565913214799, 0.04296983719893521, 0.032444716085709875, 0.028944201804997943, 0.0621580490992675, 0.0357068908370791, 0.07524852670969502, 0.08254700039903964, 0.08423896686684701, 0.08097307275860541, 0.040702144164712205, 0.038031998330787305, 0.06728097480992157, 0.03702203397669139, 0.056512398615239136, 0.08595423006843175, 0.06346207247265885, 0.02905962635732947, 0.062487861441989104, 0.007629185227767355, 0.061825229861443086, 0.019039079479332414, 0.007239276639020612, 0.04051170619805494, 0.024578147980895255, 0.031603145518250046, 0.05763953611735375, 0.07145807687794009, 0.03995828428155473, 0.018369807831702695, 0.013528427094100945, 0.054852856818826935, 0.07829023284777518, 0.018826884615625587, 0.04209791805835501, 0.03386498564073155, 0.017598723098936103, 0.03591017226778692, 0.0047480822409382995, 0.029577785246675054, 0.032427433142138105, 0.016761976970179428, 0.02365262375303334, 0.1575572124772495, 0.11144486346071768, 0.1272526128037322, 0.11181417146637557, 0.262195001686773, 0.11755456021356007, 0.19910714018248743, 0.10524374177499164, 0.10680453866840371, 0.17912776630011298, 0.09188706010219552, 0.09605640169954109, 0.11918974424441976, 0.15055942829818497, 0.12365086574948604, 0.14856545464886775, 0.16257783097605552, 0.2174998846866431, 0.1380364494698663, 0.19731319209019985, 0.1536987033943015, 0.1514459605659208, 0.07200926947858065, 0.09980110842133723, 0.14224187380844547, 0.22336211205730516, 0.1285513463400064, 0.18765063235355964, 0.11727165926488177, 0.09529851857692966, 0.18331413037113606, 0.13576256261477548, 0.160108239299828, 0.20098846826341846, 0.2099686581641436, 0.1676128059625626, 0.13396991687195917, 0.1855281551158236, 0.1928992692621485, 0.18347137757847387, 0.16487808657750008, 0.15929391847983485, 0.13998897776247995, 0.1800772709952247, 0.12931772537769812, 0.17786168343117162, 0.1845326698234966, 0.04622212941608122, 0.12490602420462717, 0.1782298806093393, 0.20809469984904413, 0.2660855945319899, 0.07766610867674313, 0.12446029892852231, 0.06009138902769454, 0.1802040585466931, 0.17404622848956816, 0.06475201131956232, 0.1346170313415989, 0.10528992921594651, 0.11018617334024561, 0.1198030359322025, 0.13025635162428503, 0.18999863055444535, 0.12925283773051155, 0.11365134223935106, 0.18592932471825233, 0.15015470404778758, 0.17424303647731582, 0.10515849151077772, 0.13752805820155528, 0.18634901832669012, 0.1556978098327114, 0.18631216949753224, 0.1223086337408712, 0.20371042462366246, 0.14438675145708746, 0.11615793596232131, 0.26216484846607335, 0.23873559679956208, 0.15720911744621494, 0.17463458401541557, 0.11554197062768283, 0.21332393941139022, 0.09782922874775626, 0.07663844003071708, 0.20032546513022917, 0.13444055532736165, 0.12033213455710681, 0.05495053685961231, 0.08205729401520184, 0.11081975103626329, 0.17363960434111858, 0.11847801025836699, 0.10835928346721396, 0.13930395726234684, 0.12841146634591202, 0.14740152194374992, 0.1110413726118784, 0.12906935967264638, 0.11856799494595298, 0.15878021056132932, 0.18240455417863785, 0.11451090055127298, 0.09398945051455691, 0.16344041533527837, 0.1361871591859287, 0.13453106095473613, 0.13692055047760088, 0.1327215306340687, 0.16648379154503348, 0.1390497539673121, 0.13210993200059862, 0.2767414179059767, 0.10149007182448141, 0.1426858370823245, 0.14943127189913105, 0.15350492911473398, 0.11749429973743616, 0.10055723720260205, 0.2209654213079522, 0.07533157830156627, 0.10311921142161855, 0.18855362018990904, 0.11668315052144951, 0.2406950658487697, 0.19186630694856568, 0.11274839270739787, 0.16123345392125268, 0.15957283577130688, 0.15139014339975773, 0.13639622458046483, 0.11685494573846941, 0.08403582333196556, 0.24828460698406546, 0.18219853781404036, 0.10331706894982247, 0.18719191422625897, 0.1582495874214557, 0.19420155744639137, 0.12981234238513056, 0.21465477203169178, 0.15494318258377815, 0.15924639038501248, 0.13420532036933208, 0.10987433725066724, 0.08456134432626349, 0.1579089694085621, 0.1377116128682129, 0.16770326562466162, 0.08538805278799227, 0.14963007171548184, 0.1673117946953543, 0.10956531270377098, 0.0935484596618241, 0.21666454241400768, 0.1605356550745426, 0.19041932007718473, 0.14368179734916459, 0.16848222382607, 0.315503046036728, 0.1946510518750837, 0.14450347261323085, 0.11480161559677894, 0.10643389766975757, 0.24247307931223225, 0.11135163822121198, 0.2592143374344995, 0.24921229349509363, 0.13553472806609448, 0.09237538752776962, 0.09009560945654109, 0.14677932065340782, 0.1592921717993675, 0.12035214477368902, 0.2671436538859721], [0.05867765037222736, 0.011310535520615598, 0.04533114234706567, 0.014749994508982187, 0.057394813160381974, 0.013983286053483045, 0.04083117252335914, 0.016558092245231235, 0.022590318356730768, 0.016381081884666797, 0.02782923169434071, 0.03364576958119869, 0.05882829390165787, 0.02352476559369074, 0.03364500732371404, 0.01085453509022632, 0.057449603768726515, 0.0461673426381763, 0.07035399096146708, 0.06932465990464534, 0.08725673275729341, 0.05443047424177489, 0.01560099753400972, 0.026910889540768923, 0.02076274666544651, 0.051417546196570324, 0.04442002248740004, 0.03371360666689373, 0.03175786272021792, 0.14249249181199458, 0.057214123662561185, 0.03468854931153117, 0.00912565180295778, 0.013604526438059346, 0.11938315080178362, 0.09783914958637568, 0.0614829111333576, 0.03149301846391492, 0.016099638418264447, 0.054430144823967457, 0.012868174216559818, 0.0986279366958526, 0.025370305877238996, 0.028094575823014303, 0.032259502838696205, 0.07770171644346369, 0.05805623815244725, 0.04160504773138993, 0.015555597248397049, 0.05879289680911649, 0.014643514033166632, 0.029300356080995935, 0.060660668964227366, 0.018154351348658244, 0.08854764453586071, 0.07568477547817654, 0.06697269336831185, 0.02518808803400926, 0.040594347932886694, 0.013953423946194593, 0.09440874575727409, 0.02393393506926875, 0.023207739258425373, 0.07150013510498308, 0.025959122971060778, 0.08006267685202823, 0.021656181385380127, 0.01790198666464177, 0.07953504911593853, 0.013348638707201087, 0.026906831189990047, 0.03642751910393277, 0.053491039772427855, 0.108546637929976, 0.013729955141072073, 0.016884466768392635, 0.016577711756972056, 0.04574656884576525, 0.026692163777507605, 0.039325120273016156, 0.032311294212817185, 0.0584052256759136, 0.009883383623204164, 0.024345588584941243, 0.018671679032605984, 0.010279342870137865, 0.07122279595463507, 0.0110831692431783, 0.05483295768499375, 0.01426520449439845, 0.04235697452039008, 0.028485941415232037, 0.017909212788987546, 0.02439062114835026, 0.01667446100092944, 0.006700548288908097, 0.08315153570184786, 0.039792020219348134, 0.06353111231639501, 0.08464477896209686, 0.03033693241436155, 0.03731951357856874, 0.011816392953117049, 0.06909248163743366, 0.04299157877422629, 0.03232941985310566, 0.009489239047041104, 0.05554291051662257, 0.03695960164130215, 0.025786140317758246, 0.06002994494572763, 0.03051896448126964, 0.011974580533381914, 0.060049100974274267, 0.028637632569899003, 0.07452925441846733, 0.03856236100076668, 0.04208017546202868, 0.027547702043046875, 0.032292938746151426, 0.12455523254409914, 0.014833929017186167, 0.053920221379807884, 0.03643773488640305, 0.012022776082308303, 0.013247221114955122, 0.08737906167704253, 0.03850510741974558, 0.011840546747759707, 0.04814618605098898, 0.07169418517620334, 0.03788546486307056, 0.0571003174709697, 0.02980587451959089, 0.061592726006863587, 0.017305334406574408, 0.0816670718092111, 0.022011990921812195, 0.014465073003403604, 0.06220466937989958, 0.07176219846212095, 0.05864138376989192, 0.0058602973078978405, 0.04336338422651734, 0.01910901564593998, 0.12567537566346507, 0.06679678425913857, 0.053875171579420573, 0.01793637635156272, 0.016660979768681913, 0.029188087810912443, 0.048756781109278245, 0.003864429984992791, 0.03922814503312111, 0.062323386195085706, 0.05111997083370244, 0.06458089792079504, 0.09433500213368286, 0.0367368079511629, 0.020258509508904912, 0.06382984830246818, 0.012658036298929684, 0.06812985385617903, 0.08053434952612847, 0.009249307012425797, 0.02282890877986868, 0.05193285140839796, 0.0693400429501649, 0.028498627831258123, 0.04158951912916476, 0.055882827559065436, 0.020307740234138987, 0.018663072034776695, 0.036082699098774505, 0.05010753584605071, 0.03165034228004515, 0.0209318203551154, 0.034021934073778896, 0.10654045283914575, 0.057798503192081574, 0.0325113159394072, 0.034138080663979053, 0.040618023880186586, 0.0206927128226286, 0.038333423285474705, 0.02521274265863242, 0.05392052398453798, 0.05621564296645023, 0.0015328030830489532, 0.035266313671825394, 0.011138604322989142, 0.03525026412981172, 0.016144895062391317, 0.05947311010752475, 0.022814458446396936, 0.12190889672286088, 0.011291945439523027, 0.05211506542118807, 0.010453257277878302, 0.012911243679662867, 0.02343953831211454, 0.0030070049885375007, 0.042341380800691344, 0.020882386616581393, 0.06030981984710502, 0.04338625961193635, 0.03531199166431062, 0.019390334623054634, 0.026135072299850085, 0.05464030572423532, 0.013073516423783958, 0.05447069768823924, 0.05216549698924346, 0.07446767627111367, 0.0653947897315506, 0.060143172740936286, 0.08005549094729847, 0.07865102961659431, 0.06055910102722626, 0.04510745999493426, 0.0023021602875462946, 0.04331548840949132, 0.025892226258292798, 0.10472759769688691, 0.017426736359935135, 0.04400015267873964, 0.08557500122415443, 0.045767341319832115, 0.04206943107889064, 0.06412539736277635, 0.06326992612993045, 0.01805707924969254, 0.045882411556498665, 0.011000926831677076, 0.033568364057329395, 0.054663303683722214, 0.020863966032442068, 0.008793159110111096, 0.011898288709832536, 0.06865569660740514, 0.0647246083545108, 0.09581026531034902, 0.024565821626193585, 0.02353413484900469, 0.047619037119851965, 0.017624076778790163, 0.01193385817215688, 0.08917059659236863, 0.046795887136531454, 0.04680024617682061, 0.0715382939444915, 0.050462567803239634, 0.0447430779346295, 0.028882152513570847, 0.01972885355503569, 0.08096916571019158, 0.06407749388487109, 0.06230847812407921, 0.035670654878260634, 0.01492366664141657, 0.03002913743858376, 0.028928632983156753, 0.06284447154030204, 0.036779184104694475, 0.048937026276102955, 0.025922220515748187, 0.025581531639721607, 0.03441895531009763, 0.032155368507148764, 0.025266571826631987, 0.029317811394350666, 0.023375954929619067, 0.023112206179047787, 0.056605980085629615, 0.04474961266462361, 0.0335643727392439, 0.02379987159773948, 0.02518031990245706, 0.032065983283363526, 0.07211139665976649, 0.068411230289888, 0.020223493545105862, 0.007895708174234437, 0.06618235110034866, 0.022469636526018865, 0.05047495161453563, 0.05478579348193542, 0.03806539976428594, 0.022957006341687614, 0.031145691436024445, 0.03797354582216471, 0.09813806943355069, 0.026289590318957647, 0.051236071458627144, 0.04343766028121595, 0.047910292257344535, 0.05656394867166396, 0.10263675989042367, 0.06881493564334608, 0.032818367809898434, 0.061292898345498316, 0.043831015786817, 0.06825536970169314, 0.08574550175258229, 0.06314134593271921, 0.08030538116731951, 0.04356472745477673, 0.08081432401893601, 0.05006872583180667, 0.026807266572910934, 0.01906747261302606, 0.0076395154446213245, 0.03588562298025336, 0.017743829727893876, 0.017079223555723028, 0.03171049741907947, 0.016216470657156843, 0.03715313077273388, 0.06983294392064696, 0.03371008266244204, 0.06179540605855085, 0.043901005579579266, 0.04594945191075245, 0.10141439765932099, 0.03570842684336728, 0.02508690888662973, 0.018794456113790794, 0.04359827444498097, 0.024630236214086897, 0.02203536234916218, 0.019230218416440393, 0.02261696097951743, 0.06730073221748875, 0.023532512657825026, 0.0096188505901204, 0.02109901521414999, 0.041884382540780696, 0.003641486428903356, 0.07077998947352171, 0.027539560443631587, 0.049484016884478836, 0.022722372762678612, 0.053846201964563904, 0.019106575655901147, 0.03410052703393083, 0.024542883038520816, 0.015322992844777483, 0.03508165583855683, 0.0599779122539105, 0.03213041702345495, 0.04033448324809152, 0.020599087302182472, 0.0947337432373916, 0.09855906539145978, 0.16047832105428944, 0.18026056519198805, 0.1621654918116908, 0.2386135589932242, 0.11775550507609883, 0.0950418791222957, 0.2774396610836829, 0.09299640904270834, 0.15294597604342047, 0.14139857954315602, 0.17125671849616114, 0.11653801516419458, 0.12685369549980088, 0.15921447516208695, 0.14769314097300654, 0.13939636278777354, 0.19106611278989624, 0.1883981043412801, 0.13470202113591856, 0.24804382554946408, 0.10138168570495422, 0.07847132071131661, 0.08392696223792531, 0.2464960215072478, 0.1332731445830676, 0.11874406493359035, 0.09845611849619497, 0.27057655516170687, 0.13634638290011114, 0.17165084008968648, 0.13874082135096674, 0.10939721769142537, 0.19015517296089282, 0.1929488964378834, 0.10617644616192388, 0.15592238084683496, 0.1982140195586028, 0.145557900710452, 0.1502084680983136, 0.20159266648753998, 0.18851706247416236, 0.18718460574746135, 0.21785067634717112, 0.19821032701480776, 0.15550002125242066, 0.14513993846072307, 0.17252528348997717, 0.10096203040091262, 0.23359113252691685, 0.14103035172147138, 0.12461469628878179, 0.13600080063746822, 0.21534443502464604, 0.17912768969132056, 0.16808589589932274, 0.12463062325672758, 0.09504683571116579, 0.13290260317585162, 0.17128104944863629, 0.15386486786507791, 0.06580275453386769, 0.1672984800872303, 0.2091096131311309, 0.21601802549294888, 0.08146720713064556, 0.11636789001884962, 0.2287815712512501, 0.17877823102378076, 0.17407226015723523, 0.158589975607972, 0.10885297350825802, 0.21962243853317154, 0.10885658944326063, 0.07734065154387106, 0.11222268785199813, 0.1479422114789486, 0.10097917544865802, 0.180846729706372, 0.20992462343025595, 0.1374260612553166, 0.14899676215023766, 0.10947558082520001, 0.15615482724482016, 0.15172765109567873, 0.1407091004113036, 0.08608475612897067, 0.270463603158151, 0.17544636142350015, 0.13929974377876328, 0.11826036467907891, 0.11938531116973009, 0.1486993208527565, 0.07984555221252865, 0.08741464646112534, 0.17070645286190897, 0.13947248128393006, 0.1440420731781952, 0.17793222480723936, 0.13119505447966437, 0.07578360082040872, 0.09349814300695736, 0.2455310878013411, 0.12205252288690499, 0.22898201049575884, 0.1316449779175943, 0.11119474341431934, 0.13668508569319404, 0.2591464620444083, 0.2049052919591627, 0.1413673997646378, 0.09989624888065363, 0.07409659094147145, 0.09170421023642825, 0.1337431088810967, 0.12939888473239639, 0.12522593486092745, 0.13287244995515193, 0.1013747219657225, 0.2044866249085434, 0.20889596653080758, 0.14532608250456472, 0.1962262818649892, 0.2148821775711352, 0.07026572997171072, 0.17837854763192518, 0.1506441269790934, 0.11154674549376774, 0.18216797090586156, 0.10874197502890903, 0.13464920703441868, 0.15079709941581373, 0.16297313234498426, 0.22000822509008072, 0.13762732787478354, 0.14304704753862274, 0.09669375620902547, 0.1274991092542487, 0.14487298746262828, 0.16901997158363943, 0.307461267877971, 0.1029883023171175, 0.09541289550402472, 0.1228969892667186, 0.23420168928080992, 0.14760815117868686, 0.1726593948420017, 0.12740722466861049, 0.14375716507915529, 0.145267216308463, 0.20653957200627174, 0.139994784708946, 0.13340564715045114, 0.13625249116411134, 0.15985161516695254, 0.10670414284592676, 0.15773353527390188, 0.19962233431156606, 0.07426386623973809, 0.17143229052664774, 0.06682920510009413, 0.20677100716819688, 0.22697646891878498, 0.12108713718912295, 0.1268763410588426, 0.19993538848094403, 0.13695471799902378, 0.10373493926900049, 0.13145967657046934, 0.14903192558596212, 0.11916460889962413, 0.11373168187997035, 0.14591263006291083, 0.19119332935060226, 0.11345404395533186], [0.07552439497122843, 0.01945533526821002, 0.04357431887558872, 0.05772744470666494, 0.07599809011744876, 0.041462168503071994, 0.05560615490521154, 0.04457450028689158, 0.06440307359181105, 0.012381707427031811, 0.08393781770381235, 0.05737630447613136, 0.030731521321520693, 0.06292184259021474, 0.009442808373170275, 0.04037447303773896, 0.05661550638896804, 0.03935000280879679, 0.0619977260489137, 0.021804492177081206, 0.05289321156939673, 0.038983824272309585, 0.01005181571423647, 0.009325007033053665, 0.054667938515664115, 0.04198991498278995, 0.07984251084346926, 0.054063506634725686, 0.04143309546634555, 0.025092116369295026, 0.03393443151106758, 0.010356281080373354, 0.0650261941876623, 0.05765615256443139, 0.030616108260508028, 0.056506223946569435, 0.056743745677052974, 0.03843946134551399, 0.05329776345001114, 0.0739437947049737, 0.043480538222337925, 0.01848817799210308, 0.04547429736703635, 0.04419011567088385, 0.022108020043120753, 0.0651173280071347, 0.05803792482061733, 0.04724102635537425, 0.07262635330158858, 0.08004866510389314, 0.031589899858039235, 0.04560120366213303, 0.008506057126778028, 0.045646012144824194, 0.06044095877798335, 0.05556783901767866, 0.025587813560700706, 0.028039484525159485, 0.036190031847405824, 0.0851082544954073, 0.027900998811087305, 0.07416377685243085, 0.06548144959754522, 0.009132876012083745, 0.029654449580477613, 0.009225070863331278, 0.04565816229930328, 0.06340810923927254, 0.05881688685246533, 0.08215873171725581, 0.05676363331956729, 0.052952460809460575, 0.019870292538055973, 0.024405841400185903, 0.0435569363405868, 0.012057285470467423, 0.10380151230962047, 0.02235154215727122, 0.022153879981487993, 0.06883860776020635, 0.05867147187311804, 0.045852101287774505, 0.02745309209961805, 0.07929792958161525, 0.010423054261463545, 0.024761003592321952, 0.04355905457369743, 0.040736258059980414, 0.018022287366611343, 0.06202733917762676, 0.030555238744484323, 0.08354600969581835, 0.05684120355234031, 0.023532979971458836, 0.026678425905805443, 0.05198718236398794, 0.039473136120866385, 0.01817267234136741, 0.008520337963296522, 0.07667230111697028, 0.03789963748966975, 0.06769910559899385, 0.007252427974655744, 0.04589606324330934, 0.014714875123313358, 0.005590728204321838, 0.07985501339839352, 0.028773023288757093, 0.012799519332005613, 0.02379405507517438, 0.0443552803969191, 0.11897055882840388, 0.010805786042774638, 0.020622502779588103, 0.015474544188398269, 0.07875872625698967, 0.06896648315652724, 0.017763577559362018, 0.014455774611222648, 0.05117173539474607, 0.05546349784239166, 0.025253460231807925, 0.03469598419483631, 0.061767413205797636, 0.06986576312732312, 0.04135134622394558, 0.030467718944794712, 0.010515352534580856, 0.06023313061544492, 0.02839534385730663, 0.07330581966427065, 0.04487992805098334, 0.043560548445149776, 0.014327407003410403, 0.032983321861754504, 0.07813487021673111, 0.0396622947206901, 0.029620780016205488, 0.04167592618614436, 0.012136498961838023, 0.0384778002156846, 0.033717387310800054, 0.0873902618824955, 0.018381927342664812, 0.030871242352370775, 0.03036334521077093, 0.05847637609188115, 0.008190031493863752, 0.03001624417881812, 0.05575667586057417, 0.06336662940861237, 0.06354030154104676, 0.02040894810981568, 0.04579530735950797, 0.015879342174758355, 0.058999847800981615, 0.028044686262165348, 0.0463098771269283, 0.005942895471478903, 0.022773512962063956, 0.027300234576086366, 0.028768539759180242, 0.02958875562575075, 0.015615461274020135, 0.04783757136113221, 0.03195142824082606, 0.06774651111974832, 0.009865958953366406, 0.03990448575707213, 0.06985511450517563, 0.03307104658996386, 0.03731560653015491, 0.0408532511773369, 0.013624531866592026, 0.01806428239140059, 0.03242955520568836, 0.02238621146628453, 0.07666922144351468, 0.03801981370235163, 0.02490816525213661, 0.013587212850970608, 0.05803344703669991, 0.10480525602977123, 0.0260193872776243, 0.0975240882666361, 0.04381344939071325, 0.06368798414064993, 0.04853095371095885, 0.04221093900982411, 0.030277867035399524, 0.01718302846946303, 0.05769053842091273, 0.10268622618769446, 0.04931171221898929, 0.024395533687164708, 0.013870117630088523, 0.07535410128654012, 0.04431193897260293, 0.02837687730789185, 0.032966985036769224, 0.004802208746813479, 0.03170580321532344, 0.04585882370931007, 0.028894881064432765, 0.013594617090758779, 0.04342379025934685, 0.033701759117144736, 0.02662589334161772, 0.060949131711235935, 0.0498722204487891, 0.03687196501320408, 0.027199884718884865, 0.05511939029900297, 0.024106067364975333, 0.032603346081751014, 0.03166857134220341, 0.031063005651137045, 0.021220535911138982, 0.029005686106580882, 0.06423875539293213, 0.012617611754385215, 0.029646066663366173, 0.081977000339858, 0.11583073980986111, 0.02593733926093386, 0.07226073783972571, 0.04216879651310944, 0.01778655828187062, 0.008141770827463798, 0.007033740036985687, 0.04003325747626443, 0.0741503626528767, 0.05450630162452018, 0.02416465202376487, 0.0417282116869765, 0.0335478367313983, 0.013368223744985318, 0.008403148535909432, 0.05423341344501223, 0.01626890746035403, 0.039321603929443706, 0.05311841077561821, 0.08145719436147521, 0.048501532104226856, 0.037041078922489, 0.042449042967130104, 0.07700054680988674, 0.06305808366666879, 0.018379410743833553, 0.03855196901807382, 0.027365493775916197, 0.08129822345630777, 0.08286090492601357, 0.03716410881268882, 0.02279471636058823, 0.04263895999399885, 0.07622076889439937, 0.02201405744398794, 0.051650980847977826, 0.023368847548901554, 0.06141482506908717, 0.05257826133240616, 0.030386877516585014, 0.04779491941594789, 0.0072885686512886285, 0.027292642644756747, 0.04710712184708926, 0.011139979450813225, 0.033802944010183696, 0.05711245613412992, 0.02697652795412127, 0.050359601755776716, 0.059845536091034456, 0.06493945005199601, 0.019332002773280108, 0.10414732439864068, 0.03080146706422731, 0.02605382867548014, 0.05606358983523904, 0.03918726658148151, 0.027578856923707554, 0.08785416642504354, 0.026511487686225486, 0.05738101591686568, 0.01932098259848933, 0.0021836445704402946, 0.055815844661405975, 0.05421050358563662, 0.002199535628014635, 0.03815280273556709, 0.02576044381355807, 0.03756572657655324, 0.05164439249182901, 0.0641552249961082, 0.042827750871618914, 0.03194759205554522, 0.02860908813384031, 0.011807889377157535, 0.10085791139112366, 0.020991896970137473, 0.060708300480919505, 0.04054116227874353, 0.09884310015026601, 0.014867802552368133, 0.029203934339626186, 0.044572052635973504, 0.04776473555173125, 0.04317220315457352, 0.01994496312803559, 0.03833795469554682, 0.03331172077225582, 0.08387289941310884, 0.02242466333442398, 0.07155317903286026, 0.03933817058080628, 0.01738859475740502, 0.019491462059499278, 0.03201293360982691, 0.060038636213228594, 0.04978097171612805, 0.06344672390109589, 0.03974240070449249, 0.02536994390069477, 0.008927470602605854, 0.052130502092862324, 0.016674233089771964, 0.04223355775578849, 0.041506379437182224, 0.04642764782352794, 0.07819673181661675, 0.03563228919501266, 0.014698925172729839, 0.03564915845110532, 0.033320327770085104, 0.03723394538786623, 0.05197652225052157, 0.04439980159663866, 0.07365451224388615, 0.021772473532285903, 0.020319032370142882, 0.027819669001825878, 0.03201882865640425, 0.02313220873475075, 0.05836197235170872, 0.03487719080200599, 0.060020257763925104, 0.032714961261879054, 0.0496447459614325, 0.07222815612030607, 0.038811255306486166, 0.05049295468075622, 0.02727639966554219, 0.2348960866971362, 0.1355542939516806, 0.17635486509290435, 0.13021535059857753, 0.1723536338296629, 0.11284832887712026, 0.15434914268553257, 0.3112762325233029, 0.22447388949653796, 0.10280328442252452, 0.103457837605909, 0.11537300227510354, 0.1380648866536156, 0.16846396028995517, 0.1035095255581602, 0.17860396134276546, 0.31482793871433506, 0.13066771019610668, 0.20340860130325442, 0.09779800300396259, 0.32268318978528826, 0.1857940182690659, 0.07591966569664017, 0.11303615831439534, 0.1647156912593111, 0.22327251041368132, 0.31676381225547484, 0.13499771575293235, 0.13634265971279916, 0.1478048672358836, 0.10384308024039192, 0.08015798585068795, 0.2540812878719261, 0.1793477101431739, 0.15218039373717002, 0.10606632102280857, 0.13618774141275114, 0.15453485772013664, 0.08873784118482182, 0.0922777189783031, 0.2020083151517376, 0.10061747469608823, 0.1409820881822417, 0.1804319084171326, 0.09195824499211966, 0.22513971183328862, 0.16727326047276297, 0.15808037392074065, 0.1148772054922677, 0.14755768130623526, 0.08347569814612789, 0.14334508638468482, 0.11452569370909084, 0.13985601554234184, 0.18557965154609374, 0.146220704660781, 0.15755981717619205, 0.16929211665786084, 0.11632823730788885, 0.21601338300012776, 0.09842409602096004, 0.1664197772380806, 0.15564470461780028, 0.07689407591017024, 0.13502207734892446, 0.12056768361118533, 0.1824341098507566, 0.162652907592635, 0.1618646184403089, 0.16399038985611933, 0.31234553804801357, 0.12023768357692227, 0.10166714538729961, 0.12517644558101892, 0.1558816709345387, 0.2345801980024384, 0.24062794122484424, 0.12191592174912654, 0.23064871138382345, 0.11082764940276263, 0.1493770481958505, 0.2107276674360037, 0.12767010773982734, 0.12288838609932892, 0.16900578363528176, 0.08907307359960773, 0.1412892434746027, 0.13772869662892434, 0.0768561622187976, 0.11756811996981983, 0.15764414813489686, 0.15773407153544888, 0.09260194270961708, 0.08368025128279002, 0.1929273693672111, 0.18235690350974762, 0.14093105140472614, 0.12513071013193938, 0.10845370380388153, 0.2307185019937254, 0.0940384341764354, 0.1275666552265325, 0.125287888391364, 0.14767559755954052, 0.14594213976975412, 0.12088958609608874, 0.1579752206922539, 0.15040323829218266, 0.21193948063638904, 0.0667267944663763, 0.10474519473650765, 0.19230006593129328, 0.08928187086337036, 0.15553372912108898, 0.09013712376115784, 0.176988189979907, 0.1962619509187437, 0.1202262152406958, 0.16158335691978856, 0.14806564356530869, 0.15846282033429993, 0.11928608746177728, 0.15339786066643654, 0.10747171698078033, 0.20399286591958618, 0.11422019316664628, 0.2108120903252594, 0.1336758157178279, 0.11567533887442082, 0.11488155687167761, 0.11995176424182231, 0.11051632659209353, 0.15030350896619982, 0.12762059547728108, 0.07697432362023862, 0.17468595787161784, 0.07420835550874472, 0.1333805654318102, 0.14479743587153573, 0.08284792739657626, 0.1601237142758985, 0.11611127354685338, 0.2699935622513294, 0.1430724510141919, 0.171380901348687, 0.112651091880135, 0.10645566988856563, 0.13068597373222152, 0.13189075424546196, 0.15774297347712904, 0.08525273867792661, 0.08772613015025855, 0.13016304211510768, 0.1955935238830505, 0.10214709947186132, 0.292407303087173, 0.158963703940953, 0.18423397214181964, 0.1688559368372925, 0.13057521274012904, 0.15390871873786374, 0.1286048192771212, 0.07353650406002998, 0.11643512189508447, 0.14769635854228852, 0.13604538695466134, 0.17142243863594148, 0.10797273082238053, 0.17102747434569945, 0.12444908340131083, 0.1800403149137574, 0.08708091557867105, 0.17922872136677467, 0.18995401359373526, 0.17491823573025966, 0.14584032668461724], [0.016959173747548656, 0.010652578034017597, 0.06573946034956364, 0.06500506548271065, 0.06654863305870565, 0.025238743682782498, 0.018370796085125016, 0.06175684885332181, 0.01203244889996225, 0.014826449126215472, 0.03538631368428469, 0.02144046634766123, 0.07389081972500972, 0.01863828717520641, 0.034295626645607334, 0.047598754942056634, 0.047322714310740276, 0.005682813409235208, 0.05834199277864349, 0.058925234667596325, 0.03102216358867384, 0.010804942388448023, 0.010476446759346272, 0.09700494112386819, 0.057996065776434645, 0.03947003729521267, 0.05947704779945555, 0.03200825089738975, 0.043379774677657315, 0.029768430057071874, 0.07637892774636708, 0.05453476562134681, 0.02474031538792676, 0.015404381068243135, 0.010062899091280997, 0.025411042602612607, 0.02086292989852448, 0.04995576999781113, 0.008385181858865245, 0.06913925130521098, 0.014678302085808208, 0.06890801532614617, 0.02210340436337696, 0.021597975940113107, 0.009723017480404628, 0.061777697936181104, 0.039592546245623986, 0.024889936189978354, 0.0808321125805378, 0.044495746448275544, 0.03274837418669655, 0.04442216370314841, 0.04719792241831461, 0.025275397159519698, 0.03940832508247226, 0.05507787216394659, 0.02723551163780353, 0.03833977415436699, 0.05539203333037515, 0.01749587771032126, 0.032766503657424645, 0.031160463526424383, 0.051828927751029694, 0.013714525172667158, 0.006034206448783798, 0.028853717245041367, 0.008212864744446931, 0.01981587922801414, 0.027642744826152924, 0.03221983480597696, 0.0246140219631695, 0.026603035193177003, 0.05071977799337718, 0.04659624845390359, 0.014740012383328812, 0.0427139753235444, 0.0482404723222698, 0.050043965870093916, 0.0967764630613308, 0.024088987434703498, 0.07728163979106373, 0.04887349077410275, 0.015767120827560224, 0.0717795503536059, 0.006816696315523118, 0.04304544241618245, 0.04896873465528892, 0.03209955134098569, 0.047035642013314276, 0.030016747881628336, 0.017714266394895893, 0.004902493007736462, 0.05077341563939568, 0.07888590451329947, 0.028542852171907024, 0.06380135366212457, 0.023947029427114516, 0.044745062102353385, 0.01375411946942369, 0.06775950397094412, 0.02854568286678724, 0.03799810277057752, 0.06589188120297848, 0.02717749579929777, 0.05937864763602134, 0.06564908495713627, 0.014572342549781165, 0.06025070084198829, 0.01721975663977285, 0.034732775567399884, 0.05388007454213597, 0.05784552566887391, 0.05074875526911309, 0.06148905515851033, 0.033897605664547414, 0.050158951837088794, 0.051383164170528614, 0.026967022718200763, 0.02195355373494808, 0.030349890791600755, 0.030748553371297258, 0.01552432745454773, 0.014453201513406972, 0.028385055296483542, 0.056125007104128606, 0.03981373498156186, 0.03413591646559296, 0.02084796628614347, 0.04417255693565934, 0.09545968049356053, 0.06660277249231454, 0.05963003172749474, 0.035739656417600574, 0.03881738017944079, 0.16080525673685536, 0.02642182667078751, 0.011440499464140065, 0.031417328976996006, 0.04405015140711781, 0.03472969206350465, 0.044903642302679445, 0.03100113255993253, 0.05666558938701788, 0.08319613734079946, 0.04177134626755311, 0.05343460207504611, 0.07643928781392113, 0.05048716688648828, 0.05291249017201124, 0.04828464112154419, 0.021067109567323522, 0.11967677698140183, 0.03875039728178132, 0.020115013579807935, 0.03908770962528164, 0.04211908123726326, 0.031538638999805815, 0.11633115610288036, 0.05438021887394209, 0.021141399028560808, 0.010097775244033866, 0.030153504152211453, 0.004766647424173332, 0.031150379894121043, 0.013104437647627728, 0.05724986549466849, 0.027827852736077005, 0.032162994912434975, 0.004357959626377711, 0.05020032441543956, 0.023991897281619812, 0.09735955556313838, 0.03045439284535185, 0.024074535186011947, 0.03451647447241891, 0.017701478472219843, 0.022211055038496855, 0.030491172726596558, 0.037420307766766324, 0.02563871052717009, 0.047511792471331936, 0.009617350015398717, 0.04696231207720215, 0.03266796176772445, 0.020254974013134357, 0.009927299613463543, 0.02001644487703039, 0.03423342030615576, 0.01771919617068864, 0.03676080182495137, 0.025289525736063242, 0.07526077645560426, 0.05540091611985719, 0.04133289499628929, 0.02437898810322006, 0.04401120732748701, 0.03393199152102874, 0.04465570177642569, 0.022050287657146974, 0.06550101548313134, 0.14253214452295535, 0.03562030757987692, 0.05505439539950702, 0.05228409506080132, 0.027598556874680425, 0.06668138077422496, 0.03282699012948621, 0.03164118178369057, 0.022218932337578268, 0.0271662438829099, 0.04713715249372106, 0.030771903731229327, 0.06440292803510543, 0.022285606884848208, 0.011006887953337884, 0.04837916104964191, 0.02619061942001985, 0.03832727926032197, 0.03409939705424252, 0.023384167392167355, 0.05605586383852267, 0.1314234099681339, 0.06774356934211909, 0.016826512216920816, 0.08596268001823656, 0.03781662803263434, 0.06353744403308918, 0.08713389821951428, 0.0377659896208394, 0.03310261707332346, 0.06887416956165145, 0.05526521130495014, 0.009446730743342591, 0.02898516261108941, 0.09377241014472901, 0.1076142629608512, 0.09267665926487216, 0.049751036830486796, 0.041966338626920216, 0.024777068456094113, 0.06701451410809833, 0.03434308196207689, 0.01096353120726323, 0.07330987993026934, 0.01896761879775553, 0.007556388680372508, 0.03866186433081185, 0.017460206741346948, 0.05834760437268884, 0.0680346367880702, 0.037142857533669284, 0.03458111314103007, 0.036863606993950186, 0.057390764385702155, 0.042130158868648356, 0.039348803881195285, 0.050894120452745314, 0.0396409246980423, 0.05449412082652411, 0.025174800238962618, 0.03498005725803875, 0.024415404092700734, 0.07301993097268766, 0.04666220479374451, 0.020274084076405536, 0.06544935817439711, 0.05213967216531596, 0.01082933558556702, 0.027988947620014512, 0.02681506917841973, 0.05501885275026003, 0.047310671408570586, 0.02943076148268677, 0.09592997420939708, 0.05858034188408525, 0.039999882855843154, 0.04170118410500788, 0.0624776954552339, 0.05121052625679201, 0.035619074178318826, 0.0459788850088033, 0.015145654024015513, 0.12643734969559217, 0.02250761916530469, 0.049560989568670916, 0.10665252384158874, 0.06304493376744852, 0.08589512638507352, 0.055019802699286136, 0.031679654719247934, 0.055773231020617875, 0.05136455206440822, 0.10566809319800909, 0.007264457949091711, 0.036591174636757186, 0.08520079025578114, 0.04235720817720698, 0.017363610714974425, 0.04310634640616275, 0.025341370736338922, 0.07943332030047333, 0.0056899653188133194, 0.037234209688200105, 0.043528797931127974, 0.05769828740026682, 0.09175629655440008, 0.00967922693704285, 0.009280976129605645, 0.042766708985812245, 0.04055107162604409, 0.057433205656707294, 0.03205679405871178, 0.034529919315490036, 0.05665122906887724, 0.0246445907865681, 0.0294091654641013, 0.08292538654660025, 0.03565878051543429, 0.041748279360153025, 0.05353673308667156, 0.05190247985263986, 0.0504157062049114, 0.00947566684185257, 0.03956037438324383, 0.028625695004818902, 0.03073165538690744, 0.018920791673383886, 0.01478362768407791, 0.04834222412037273, 0.04713067138988165, 0.04526530475085301, 0.04952454676611289, 0.05266378355783321, 0.08391458991794817, 0.032834294777844227, 0.024220561120478858, 0.03293232338863515, 0.03176231943671742, 0.048745749443168604, 0.02499505685972831, 0.0166395005785049, 0.025509651525006182, 0.028716621980551752, 0.03679296219601266, 0.057528813429657495, 0.021293699223127578, 0.0723181484687713, 0.028781613049608086, 0.008783745804741498, 0.05753912497311831, 0.039352925434227914, 0.06443468237956686, 0.08884346938782162, 0.10610127761479347, 0.11433127591566694, 0.15711957708962504, 0.19614311535992932, 0.15470178827883738, 0.14665789571740936, 0.15420162479483313, 0.10840727121479089, 0.09447114361870675, 0.09988247461977506, 0.11912968295115618, 0.1118538394990948, 0.1693067489372146, 0.12889219417927728, 0.206143765019313, 0.0960395630869654, 0.16590176390544062, 0.10603128782203121, 0.1607918961634559, 0.2298118829006149, 0.1500006131226978, 0.09603171068574153, 0.18874894196708358, 0.16281937849858116, 0.14506904468421014, 0.1460656484649066, 0.15332074625597847, 0.08837702143336497, 0.10920103789577562, 0.10471021516188499, 0.18425608143931438, 0.09183467500993321, 0.09621816882563215, 0.18549291507130672, 0.10417920897804922, 0.16486746859886955, 0.1528609862491008, 0.10126169335337416, 0.2541404145379221, 0.16999046708787643, 0.21012700853809235, 0.11214512911054397, 0.07184150388404247, 0.10623098396125341, 0.23169777686557463, 0.15653797845926978, 0.10553132352088729, 0.12376282183874039, 0.1554952868290486, 0.23769649046082653, 0.14563496915563462, 0.12445920342279058, 0.12318123853014362, 0.17094487474570352, 0.18184863481550448, 0.0901008571588224, 0.0817392526134368, 0.11550524437259282, 0.305788591504097, 0.17968158658233382, 0.1731244714990739, 0.08732296105834746, 0.11909085761515364, 0.10617653043159556, 0.11742936612497415, 0.10274844784890452, 0.17778539639567176, 0.11162238901541119, 0.1439063223980127, 0.13674425832446546, 0.09557737458136775, 0.13647102540539158, 0.17803190816794673, 0.13534798647367186, 0.12549080209986818, 0.1629385971013577, 0.09630023216408107, 0.18982106669535562, 0.11809501992238146, 0.15980735060668763, 0.21337633982541102, 0.1071604937615414, 0.11454125295483297, 0.08873866089890081, 0.12333014303998602, 0.1486574005215399, 0.13153150497424987, 0.10966679637110043, 0.16473171781868706, 0.13291429367757615, 0.11227715670341447, 0.13801948828322275, 0.17629229103124913, 0.14244324768022185, 0.21863105947211867, 0.1312553149557883, 0.23109036107217115, 0.1475485955034533, 0.1733147370959482, 0.12581614431955163, 0.14653242583717072, 0.2428929721035304, 0.24320170553701542, 0.14504727246540208, 0.17624205098517481, 0.13169770008854328, 0.18971297168923965, 0.11063202119041836, 0.25642487340636794, 0.15629875984403396, 0.11296320376136612, 0.17922043229543394, 0.09218635533245341, 0.1305929400146969, 0.14407455530618468, 0.1686506712388608, 0.18651763427882426, 0.10633716374755868, 0.14758282431191014, 0.13183315975531457, 0.1210903317757672, 0.1438098719283458, 0.11144752944669417, 0.20505428073867676, 0.17448413966884538, 0.1430931047446305, 0.09089838533151536, 0.14355150111500295, 0.19460288026640493, 0.13138830781944338, 0.16021288691028474, 0.16553143700284345, 0.10706113215776221, 0.2703771271532582, 0.15490257992379128, 0.16220794840445443, 0.1724600894076209, 0.18582815514697185, 0.10246992892315311, 0.13583183228488893, 0.13611157695131917, 0.14051443746974393, 0.18316123454320818, 0.1654301295357366, 0.123753123165619, 0.1449256483465433, 0.09823289579681813, 0.10333481920702804, 0.10588909424240552, 0.10047970910466487, 0.2659786180142434, 0.1518822016735231, 0.11487050988380948, 0.2378585793438458, 0.1381147130122108, 0.14288454496812436, 0.1884834771795619, 0.12712052392382778, 0.2156490928703739, 0.11573138586696118, 0.10838657151907684, 0.16742627887475878, 0.08985806857385943, 0.10178723733030981, 0.14241300252897127, 0.1399895599893024, 0.16534837263245739, 0.13995018306999438, 0.14893679278752497, 0.1615103793841216, 0.17461567696544433, 0.13230804233781754, 0.23202812930028285, 0.1472068130369148, 0.12280587842988393], [0.029522393259309956, 0.06324625018263055, 0.06550938882414373, 0.021475020743485902, 0.02053494467550228, 0.016813710887706088, 0.04995761626970865, 0.031376749299646865, 0.07135995633659825, 0.024202220975571585, 0.0516766754369582, 0.025880777074264425, 0.07912891526376048, 0.01604014307245492, 0.03954399925386233, 0.01964986797482256, 0.050929031079454776, 0.06583659263748316, 0.05648273186037137, 0.05779820058735148, 0.06215682718902827, 0.03584430019761767, 0.01545618201846317, 0.04206743541984789, 0.037493147406606905, 0.061053767830373785, 0.043307107407599695, 0.09608734399080278, 0.06818006325873636, 0.021412862284529596, 0.02197772572417894, 0.09465969317863066, 0.06386236107397465, 0.06644789249666276, 0.04768805398095039, 0.03285413645508309, 0.042171887677883914, 0.058012356636144465, 0.05879963455241054, 0.02217308197531008, 0.015022628921865216, 0.05078740823533266, 0.04316161198902034, 0.04541446206971042, 0.04156074486672879, 0.030499113227931723, 0.05119481762390464, 0.08221676287752006, 0.03161566914059222, 0.06748958055170313, 0.025838165348696134, 0.03697966931447868, 0.03608322003856301, 0.0467389821255159, 0.03209494140690133, 0.05677727734549873, 0.022138640577454242, 0.03832137655286539, 0.0144647502888655, 0.04557608363909587, 0.013211382564247377, 0.015875877542120796, 0.01135510172800071, 0.03251999571558929, 0.029166168120178967, 0.0465227653002066, 0.019341335639417655, 0.03522416351423149, 0.034236362083785, 0.049821229636548996, 0.03567740411287354, 0.03368865901363954, 0.12089673369642227, 0.03518408945491237, 0.008884635753929615, 0.03171316532027577, 0.0779527481344919, 0.016723530847699414, 0.023664925209877473, 0.03862088628774209, 0.02191952410935154, 0.13283232226967812, 0.002073512249250686, 0.022759706142448613, 0.048406479745021755, 0.0114197988108161, 0.018613000528045723, 0.031207608577284603, 0.057740391592585275, 0.0325746369367886, 0.045962965701736753, 0.01916350556477424, 0.05830446596167261, 0.02327099705355302, 0.02565061936395303, 0.013536446119448351, 0.04592234005911216, 0.02843227504091638, 0.015393516026257027, 0.011850026128212772, 0.03711300308726007, 0.02003417789725767, 0.030559729934940418, 0.03156448297593142, 0.015854202041913186, 0.06679496096987879, 0.061637423406805725, 0.02437814157606373, 0.038807187379608234, 0.03131574763345622, 0.023455181827528343, 0.048093620928064476, 0.05353277241210303, 0.06682727455852494, 0.08745396209339942, 0.023431638030395396, 0.04943628194591692, 0.13274072879745116, 0.06330749508173716, 0.028868629146487485, 0.02202762677634676, 0.03474558455749385, 0.03869704691873443, 0.029310546965608676, 0.030698391849235184, 0.023295400784380978, 0.045732740958731984, 0.037259931090257825, 0.012140462509236269, 0.03358446339505815, 0.042331892801749135, 0.07986418347084716, 0.033759556620592074, 0.029463067410453677, 0.032690825661824595, 0.013263075304548106, 0.066797933391025, 0.019333178718243877, 0.06822124814554568, 0.01187247250439419, 0.007455145373129316, 0.040751759849128225, 0.1513114968134511, 0.05037912933696663, 0.014272222817394764, 0.04601708598314755, 0.023337244506805174, 0.05884381867344341, 0.05397824870963251, 0.026831089992136247, 0.04708882766745744, 0.03977289100387885, 0.04237907998744519, 0.030189789906744997, 0.10089452273302502, 0.05895165704010476, 0.02421712138569884, 0.020653397190354524, 0.034985929321978367, 0.026205786045700796, 0.00949574217590834, 0.03594072385420723, 0.029438123587639104, 0.026187091585128542, 0.03739639816264953, 0.05025180169351159, 0.03538447507326642, 0.06990138621580216, 0.0678124406465119, 0.02810691558425465, 0.030237275866731524, 0.016626425372857242, 0.0417191565277115, 0.05815107600703355, 0.028483974484486446, 0.05060105351731182, 0.07210157541257721, 0.033815638087089026, 0.020084262810527317, 0.0034790496940859746, 0.07092260440150577, 0.04994967193793386, 0.026153299446788528, 0.046674550300644296, 0.03532846255468265, 0.04340493683553031, 0.055063462050090876, 0.05119863274176756, 0.046833195618443915, 0.10572526633979813, 0.026787168256217436, 0.06955208842672649, 0.07813537583476113, 0.05381174716016939, 0.009248125321802594, 0.040114336391730655, 0.03525665713353984, 0.024478125626281388, 0.08333139782471043, 0.04783790077893965, 0.021399013330078414, 0.0744914326576456, 0.02783500225163035, 0.03795987881359555, 0.07124010188084456, 0.015472754415485169, 0.022669713793983384, 0.05907927962741064, 0.059516340449091897, 0.011965544526315024, 0.028725343891569687, 0.029216524994661732, 0.025783068305181883, 0.01273875228024178, 0.015164901025503155, 0.0313416222530988, 0.005017431094236071, 0.04965635985436459, 0.03796001287898229, 0.04841591028736965, 0.07083760694630685, 0.045757807355614445, 0.06265771079568133, 0.03383850198118918, 0.019538800547560378, 0.06235684508517866, 0.01630964035528802, 0.0451570412053937, 0.05208946276275862, 0.06960988976061344, 0.08836552245362152, 0.04082323585246359, 0.06855779823156134, 0.07783239572158746, 0.08314442640591053, 0.08132568004751399, 0.06718846203218545, 0.07619275305900844, 0.0590386271717087, 0.03325229150152976, 0.03368051166856482, 0.11503370193343972, 0.028368209023028616, 0.024369879317800366, 0.03810801340507404, 0.027152009969276768, 0.03905979721176048, 0.029670399531061133, 0.02982040337707487, 0.03434023977587781, 0.054634230646995775, 0.019831955583105167, 0.031095709944624576, 0.021759840742414518, 0.04614652419883398, 0.07779493402209013, 0.026586945431547302, 0.1484673187857674, 0.01261518421327515, 0.010993459389635153, 0.06220746943126283, 0.045916268812312235, 0.034577677236689676, 0.0458038492398637, 0.06581262940721166, 0.021210865966314753, 0.015242135137199395, 0.02577798339658447, 0.06202875644028668, 0.004161402532425259, 0.0671913884880562, 0.01692687356544118, 0.049259216043977976, 0.03765095385812944, 0.106006765347575, 0.05940759043780066, 0.061424416489899165, 0.04421897803343112, 0.019441710394476692, 0.014421761264994502, 0.03895456354404169, 0.017597522256114793, 0.05880467158051268, 0.0177857309069124, 0.040464243220706145, 0.06519366866878926, 0.07274064595901197, 0.01803017615701162, 0.05976329655236295, 0.03646363248868335, 0.04130168074381448, 0.02011351779313578, 0.033712070660605546, 0.12505400174808118, 0.05759938544924221, 0.01386502889105149, 0.058307583939524434, 0.01990440834854399, 0.06237141990793809, 0.03272328480717636, 0.084584204389924, 0.03137900159814425, 0.002279536274727434, 0.05123678775083634, 0.00735567843226055, 0.07751541152115791, 0.057909130118787296, 0.020536271922831095, 0.07366576607549384, 0.08008705376977883, 0.02970589813025248, 0.029324388259180614, 0.01607093693418128, 0.004646428597850665, 0.030209334724913203, 0.04000378607381736, 0.03184079173802128, 0.0560657118987893, 0.05591460488616459, 0.09065800992351386, 0.10845050155635803, 0.002773297897111925, 0.039916551641879544, 0.030222406100121238, 0.02873568416332766, 0.023461952129559174, 0.07027860024883863, 0.055199480961046876, 0.0391949619346809, 0.062484980951393806, 0.15432504155943472, 0.032024982257656036, 0.02939757646902675, 0.047296265125154495, 0.07018927439686752, 0.03163447276869368, 0.03320323889173808, 0.025063217617571357, 0.09050909009191299, 0.08345254696905614, 0.041398583205356713, 0.027913139389467337, 0.07262693552841103, 0.06188059120529121, 0.04389993305648527, 0.07878766139788974, 0.036209157232435486, 0.046653567152398254, 0.038055482756106124, 0.026968558724488945, 0.05958253044574972, 0.015194874215540628, 0.1709972904814828, 0.14852829938454015, 0.14304838053161098, 0.171457571428149, 0.1292580011631212, 0.20441933174527463, 0.12805990859745972, 0.08564571113956553, 0.14747678242143125, 0.1814598911592076, 0.18488258814379094, 0.1526855214709236, 0.15852038418093037, 0.2033495359242924, 0.11000064216674336, 0.15610032774988683, 0.19277974422420227, 0.13230197492145723, 0.15062180317697987, 0.11683134256952232, 0.18448990679556326, 0.21628148313010895, 0.318470380359119, 0.13688785384499258, 0.19989161421695065, 0.12729506939649582, 0.13263562153423988, 0.1987722525072675, 0.1749075258210782, 0.14637983644441252, 0.08809663325307832, 0.23103754697067125, 0.17631047795857155, 0.08735433235884675, 0.12593409887725307, 0.2010330392588531, 0.08426204143512635, 0.08321836921236209, 0.2190955692241269, 0.1149064853727337, 0.0687769223605433, 0.1626547308818948, 0.1022556771133696, 0.09601098800738973, 0.18774758844125658, 0.14177854383184066, 0.2122058187641444, 0.15934570602351622, 0.18490866577673346, 0.26304554314382617, 0.1793967857356033, 0.14122541302875166, 0.12645496205697138, 0.22014169292824887, 0.13227002905501475, 0.12939476317936374, 0.15200445398447976, 0.14624117453011776, 0.15648041461263934, 0.1423338350028761, 0.1482931563570615, 0.1667340724698959, 0.1511200514411734, 0.16372794345501931, 0.18412983014939294, 0.18969236392407648, 0.18914759880112064, 0.12241946368087685, 0.10882521814276135, 0.11919310737040736, 0.19637015317716908, 0.08718561681528246, 0.24253292610087704, 0.18511624496069648, 0.18392134698167925, 0.16387112528806733, 0.18329231218705255, 0.10630502635913511, 0.11981110283804518, 0.19332777288171554, 0.08376201584694848, 0.29661413702753286, 0.1632455378890999, 0.08472622943020637, 0.16415738170185398, 0.2111896490978618, 0.12940509004458306, 0.10576938534335745, 0.2046663797790966, 0.10007978822555273, 0.19194823239118824, 0.14026634755634493, 0.2985324824769651, 0.1350734512051267, 0.1707991495007469, 0.07995417581931238, 0.12292537282431319, 0.0978163508097491, 0.15211736002276022, 0.19507264538157373, 0.12402526823984039, 0.17494771479358598, 0.12845748524752357, 0.08370497294010655, 0.13361390049178756, 0.20633882632659328, 0.17986714839935306, 0.1127731143647144, 0.11765979005083924, 0.16668291311831246, 0.15579966888312372, 0.13918150576852983, 0.17857685715200441, 0.18958051508713156, 0.23678915124506722, 0.1351556677611605, 0.17268997707193898, 0.2315039412989732, 0.11593759375353975, 0.07848483450230091, 0.1139536175516344, 0.09438923349784267, 0.21910571222824438, 0.12820790146267222, 0.13861657721140694, 0.14026142927187105, 0.08485123965769045, 0.13579786394632634, 0.1796511575699814, 0.15177949992639406, 0.20247234992923277, 0.18942165909515274, 0.1115515718476907, 0.12970686739971563, 0.1256636928226198, 0.12526957888997373, 0.27503812865864846, 0.10049667795218768, 0.12124285988149144, 0.08946382440626623, 0.08961892656741605, 0.1511653272374984, 0.22114211182680824, 0.2858467099647368, 0.17906085618080633, 0.12138391199010996, 0.09695516073054845, 0.12036359778815701, 0.1438066543590638, 0.08429610170423986, 0.21131625278822838, 0.09470183567534532, 0.11760638606163765, 0.15440411715497895, 0.2743370969208979, 0.08951013442128898, 0.11830798470445218, 0.12371222173134166, 0.10595975819254115, 0.08914631160516893, 0.16222340805876642, 0.15853794291615486, 0.17595706627734248, 0.321661320424849, 0.12267582734385807, 0.15285482690218957, 0.19184153166509446, 0.15642203871280919, 0.21516749935765422, 0.18158097901651937, 0.11730716744017218, 0.18633703671155438, 0.18637953926959347, 0.25095089939573123, 0.1064362648814436, 0.11924438163517945], [0.04918046220536194, 0.06456042039057901, 0.11131170971859848, 0.02072396346427981, 0.03765518649391109, 0.04601602495137242, 0.034484616706087705, 0.02444194903927705, 0.0653706273184188, 0.040362016448090156, 0.07277862093741856, 0.009762054448196245, 0.0953002805791555, 0.05309896363366035, 0.024824269048328844, 0.017035728913822004, 0.058900926697758905, 0.013187192380428316, 0.012796617773992401, 0.05469660552579069, 0.015552345205158477, 0.09224003511330775, 0.028420456219464544, 0.015135327158796211, 0.048831984130365234, 0.08992889340245917, 0.03780991710241764, 0.018994228861805414, 0.02160112073104228, 0.0442888107781689, 0.00797331479618386, 0.021937586547386263, 0.03200843092805195, 0.05670752503999299, 0.06300900424379977, 0.02811496908355865, 0.06712780319034092, 0.0655109593043885, 0.03648554643375739, 0.10375865735113622, 0.029598484942389112, 0.009199385850449965, 0.026551571321643652, 0.030927095907710256, 0.0510691715434434, 0.024755380506957733, 0.06274375013045727, 0.030052865096818537, 0.025694418525803956, 0.025246958060550596, 0.03505670818530264, 0.09750357243202387, 0.03315256217554693, 0.021890558324934497, 0.028928782370301987, 0.03845790108185142, 0.07800235232758908, 0.013685230928052579, 0.01694266455278041, 0.02161256608463103, 0.014280705325936359, 0.1064742781642464, 0.056644200212171966, 0.07069977240697031, 0.04908551709846624, 0.01640828949729762, 0.05647825024601433, 0.0317484264322106, 0.03540057058055555, 0.05296421642865866, 0.03190205961976561, 0.014875410763066144, 0.04521809458251923, 0.004428327675052589, 0.010520487238893346, 0.042737318022597226, 0.04345214700386409, 0.029987462255502903, 0.06836425377837113, 0.03579690233774243, 0.042433935713263295, 0.03720198419966525, 0.011363852367315803, 0.005638257256754104, 0.012681263127183963, 0.03735625132497761, 0.009030522834960251, 0.062236255185017665, 0.008963304365264073, 0.056281411614749706, 0.008935407273501398, 0.04195260267043787, 0.016139620547032645, 0.05191957127423056, 0.04414986158090253, 0.054414122095031124, 0.0251836562153673, 0.024674236474017945, 0.02402166362791773, 0.03454345225867245, 0.05981166351346239, 0.053898640682980906, 0.034625519427560994, 0.03743156925925324, 0.050529401313753865, 0.04473464713702279, 0.07605940779490818, 0.015303065940257043, 0.028764536949775876, 0.0382039544262713, 0.06237788952045864, 0.012366726577672507, 0.06508587243696375, 0.021814372796084613, 0.06608290522689782, 0.018174120247544303, 0.007355707639362664, 0.008928794019495048, 0.035748351515541156, 0.047484519741227554, 0.04756153456025547, 0.03127240812435987, 0.019590381247502182, 0.025036000428841482, 0.01720417058095336, 0.05997892732041017, 0.0010380169377669753, 0.023000479916170723, 0.12904637703491798, 0.012736053735528503, 0.020002151591583126, 0.04330625321956412, 0.03366286866366863, 0.0421344259783866, 0.05497023681058519, 0.0472375636379565, 0.03050630870876053, 0.042637837675189784, 0.07628108299667798, 0.04988029884595064, 0.01624604931191331, 0.04339308162490207, 0.07943754144493612, 0.043206294067204006, 0.03787393907024976, 0.02667066160469286, 0.027790659167353186, 0.061593664464570826, 0.024705617350616285, 0.024876092981186607, 0.04586267330112957, 0.012295386554943699, 0.06263508821927732, 0.06897228244211405, 0.06253560404143026, 0.09459073760456617, 0.042363827176872766, 0.02423247187248161, 0.05725757616962637, 0.053378355899645444, 0.03025687814149405, 0.07683006160321736, 0.11175804020416354, 0.01552857636969777, 0.03511776156242817, 0.012355499559142178, 0.0483227999610526, 0.0856342887686145, 0.003822130679656121, 0.047028544208695816, 0.05536619701512879, 0.01843436031542238, 0.07173019130864451, 0.02829979928661018, 0.03347190975722286, 0.01717655311128305, 0.013913071222393023, 0.06898254035942017, 0.055065396422099684, 0.036828006888108875, 0.05961427329889229, 0.022683564663654374, 0.05309717481835716, 0.021052414085716013, 0.028026664043746652, 0.017796201413617502, 0.07408218082761572, 0.04489893469238474, 0.052776681935234424, 0.03623361841985776, 0.006769902228693208, 0.03342558442044162, 0.037341875685078484, 0.012988729642764216, 0.03759822402630122, 0.045674725120226224, 0.04409519354662588, 0.10204622867487131, 0.0170404709980733, 0.04472795152856458, 0.0719235672224914, 0.05012366582729644, 0.07111785723076713, 0.040271660207860896, 0.010993937236977922, 0.061890749531167175, 0.027041277705481457, 0.05767224424128091, 0.006103713606153765, 0.01174973276999569, 0.0728383681346332, 0.030143477976502433, 0.13041413509316985, 0.029181275374045777, 0.015955928942158578, 0.04678267978071686, 0.03458669792199808, 0.008351275764946497, 0.01844373531639576, 0.05984267858307689, 0.023149516576180057, 0.02914399562043048, 0.03215741013146697, 0.007519352159673169, 0.016293487391404567, 0.042937994754362496, 0.03775891862929829, 0.05016140331844649, 0.011647452371225003, 0.027596486522065058, 0.043020211310396274, 0.06846192232783764, 0.06466892142329486, 0.033991528044064204, 0.03190092580963767, 0.014400043629951056, 0.03788330449512409, 0.05429803679186491, 0.013830660271548457, 0.00120160328327573, 0.05602575275265882, 0.06321775171184732, 0.04813893885922529, 0.05441803297388458, 0.03142667333445242, 0.04179025714796397, 0.04531315077216395, 0.05995763773699442, 0.05243845411666459, 0.025327594560240547, 0.0721630156641045, 0.03467602377396918, 0.011137378582310294, 0.049072922612991066, 0.02550651247973644, 0.023205460146850636, 0.07544951753750925, 0.01736788548559191, 0.03576175805421607, 0.038662052022353295, 0.01860072779949875, 0.09791894530456874, 0.04283480271096191, 0.0722673568393915, 0.060028041217235796, 0.047693255717956254, 0.026233248382566438, 0.02364191767429152, 0.032191841953223756, 0.025841003704455592, 0.027702373279739293, 0.018595010868363807, 0.040311508271242344, 0.04175771756338016, 0.025960756653559305, 0.03029085031049627, 0.04987346151122644, 0.02752701000821206, 0.03334001622973912, 0.044679615210982106, 0.02862634234911492, 0.04547058184060358, 0.03777992476018206, 0.051027323990579576, 0.10051323311223138, 0.017541461857035756, 0.07347577627027228, 0.06029811785406163, 0.042504844811534694, 0.037389308018910314, 0.01710592746554363, 0.06874232582988278, 0.07868623901759425, 0.04781956063403238, 0.01992098074556599, 0.035306330274550185, 0.03387994350745313, 0.013754875981248917, 0.02758299571371848, 0.06033168016602436, 0.018904692335655133, 0.06527678920857369, 0.047722861185790076, 0.02215720671829918, 0.04000667039485228, 0.024513821493113236, 0.01737877925587518, 0.037179488027768756, 0.03669644660887219, 0.033998882488137296, 0.03409600711517757, 0.0689319862172969, 0.03042401937437394, 0.03288992425246585, 0.016950813813074943, 0.040949567581617066, 0.05908037130270274, 0.043211687326190934, 0.018931825254713337, 0.014294069729775432, 0.04872459775557922, 0.03986333917465903, 0.045494296092299685, 0.02235599887377072, 0.008981150383460186, 0.027905346360057596, 0.025684191252014814, 0.06365089782423551, 0.043582542829455874, 0.039118196094228376, 0.010933748581596922, 0.0441779003989312, 0.05902229034672341, 0.041915558488859285, 0.04128846955756026, 0.029761215424044963, 0.024862985216802167, 0.041280693765128815, 0.05984499982948746, 0.08335489374134811, 0.009451217145749159, 0.03746066144817779, 0.03895797646574436, 0.03417454644917481, 0.06483354605734348, 0.04107127213970788, 0.02683372341937596, 0.03795595261298361, 0.05906312283308757, 0.030045838155333075, 0.04354653286657507, 0.06074545957568673, 0.10391244950193552, 0.28323067292090387, 0.17252831719815734, 0.16491366370070368, 0.14182709848448155, 0.10653034047854525, 0.16090219750279383, 0.09629813308316855, 0.18923608195637504, 0.11832208072225894, 0.1954916341891212, 0.161931605168408, 0.15585714079920324, 0.12786168334705214, 0.09106553039483486, 0.11216082625211247, 0.10389251589414575, 0.0808434430209379, 0.11352874518882845, 0.16861766817108279, 0.17458072803433866, 0.1876455302079839, 0.09740690745773817, 0.14162587783029004, 0.12912434946385123, 0.13051539659500122, 0.1622467277751815, 0.08511187043040992, 0.16455674333678139, 0.13961555586466867, 0.07433680547100883, 0.22435093238469095, 0.2232678525991017, 0.15800230956125647, 0.15665275375208548, 0.13896130145557467, 0.14480854414643782, 0.15775146173133006, 0.09034663348669007, 0.2686358705884026, 0.07214590892075531, 0.1984269307145188, 0.12461902468555397, 0.1265487312189033, 0.2503617318166841, 0.21174359195415052, 0.11671389362985089, 0.1303249318152666, 0.14689023486308514, 0.12382584789227094, 0.16436830102916689, 0.13640459026059798, 0.15692002650710846, 0.16091174295833036, 0.1528903580601177, 0.12127963210185691, 0.18425205181683266, 0.15622757495410983, 0.1321881036123922, 0.13301596886688663, 0.11623348755341385, 0.21696631976914024, 0.16951472648689825, 0.14960555690190486, 0.1663898538437582, 0.14131780323241988, 0.14786063843677122, 0.16302637545572174, 0.18343751649222068, 0.19041201159838708, 0.16662904181547705, 0.1870225934732345, 0.0906220957216236, 0.15311684429405198, 0.1105701749122912, 0.11561448084971598, 0.1599885916878139, 0.23577246063899612, 0.08415291987119183, 0.10136893800189418, 0.1747635932218644, 0.12152512497719258, 0.10040958141607624, 0.24094084217663736, 0.09262972871863073, 0.12438941281288864, 0.06865380437023218, 0.16300478709801552, 0.11615985884301125, 0.13071157639065098, 0.11331139072295159, 0.18298587701734037, 0.24346306409326293, 0.09585261465080323, 0.10724988856142569, 0.14198587786766792, 0.203316394960688, 0.12402427998641807, 0.10505521519770546, 0.17302722429796574, 0.15026506667415943, 0.0823647250992156, 0.1314671842321273, 0.0779938564125088, 0.1480912921890136, 0.10763386715083353, 0.18206856333680693, 0.10559592771554187, 0.17794952307256962, 0.27788815959807367, 0.10620205648123257, 0.15610115512484507, 0.14165331909973777, 0.21298450117390003, 0.17782020743095106, 0.17136933342103036, 0.16802776514762835, 0.10814104800022419, 0.14997577655219263, 0.12820007970496533, 0.11121721277313848, 0.07355171090532696, 0.12053149361764232, 0.24530397337530893, 0.14019500944883595, 0.18733904907299628, 0.19042095950534269, 0.200164862457783, 0.16006564481123803, 0.08630221784715691, 0.16092328024247002, 0.11601224902176088, 0.12667575625762825, 0.15073412698843788, 0.11650185581416854, 0.17376207115669406, 0.11005088987369692, 0.10893070844993477, 0.1564343574066316, 0.1625057880676562, 0.1282334734775847, 0.30872292275871005, 0.1366547486113925, 0.08548164574970162, 0.13572894667665805, 0.1846866075310015, 0.2073723249017231, 0.19361217536272543, 0.143169728858817, 0.16722082941522523, 0.11046368102993696, 0.1683924689648613, 0.15916205942630768, 0.19929803397145965, 0.1190097212430931, 0.14693440749279915, 0.12923083568532623, 0.12538174182296763, 0.17611892533398446, 0.08728564491555577, 0.13142748555589107, 0.10411314921633852, 0.18182526913381394, 0.19904226785705936, 0.20892227399012736, 0.10854140554945316, 0.10051576886326076, 0.2077949143225147, 0.10467931883589876, 0.0977311235281729, 0.25353575666104594, 0.1034866884771374, 0.19059781856354208, 0.10138481900456453, 0.1889137274795963, 0.11265526705932234], [0.03791350368109923, 0.1038575899456778, 0.01985335241883032, 0.028722683651252624, 0.03168545400483474, 0.0378117174090397, 0.026494744834640337, 0.00958899231327157, 0.04650588072235546, 0.02317353343260625, 0.006914326560593421, 0.008682604004148274, 0.03849053259698614, 0.06564461866453772, 0.019043156982309396, 0.023204680652387684, 0.09148222859948875, 0.01787748525760347, 0.050778130910569624, 0.036171358454251484, 0.06510859460479791, 0.04885731865802119, 0.042572279701069485, 0.03357753029934341, 0.03736290479859999, 0.03189028293314961, 0.06269660891003667, 0.049345772488102804, 0.04691158556529591, 0.0076149225858370626, 0.0404184541454719, 0.07698221432585871, 0.039715269700654095, 0.10493447207995962, 0.12981817997511358, 0.03432767976435923, 0.008862101277636905, 0.0742435036227107, 0.011940346936875535, 0.020567047589969252, 0.06121152831662086, 0.02612401956632253, 0.01487941740291013, 0.06147006766930704, 0.009689219596405185, 0.03743426588874671, 0.061355909077270385, 0.0409730366851774, 0.06638793079482933, 0.03444474182962891, 0.04379470321920611, 0.03504718188196421, 0.018819346310450666, 0.023652830596772895, 0.02376199238032343, 0.044864870592831604, 0.07785286559092422, 0.027346521608471393, 0.03504967166771812, 0.023243172740143155, 0.09069898796658363, 0.042735058063220595, 0.02729761647060514, 0.06415036799866827, 0.0007052853212489056, 0.014501903637973292, 0.05636614093917513, 0.011350929421643096, 0.04312944012664018, 0.03361921314330351, 0.027251176220635255, 0.06918160064566521, 0.019093088677994186, 0.018039472633972764, 0.05812616282773595, 0.09865352403252356, 0.04365609876150566, 0.006800684599100703, 0.023902016015903606, 0.034437218846212474, 0.027398092732314142, 0.022926623294610652, 0.08668229704903019, 0.003646217740043217, 0.01689038288238789, 0.027109156926012328, 0.02794064960682825, 0.0229969501660596, 0.019945516626560883, 0.025635203759696697, 0.06820364344504572, 0.0858709639719417, 0.040642201615076874, 0.045626737372649294, 0.02966732943370458, 0.07009011197594867, 0.04188947319503754, 0.015339338288251913, 0.027800926660758354, 0.016926197492848002, 0.013670709731447841, 0.06117647596364541, 0.08181147938293797, 0.014083770933681199, 0.03112360895160706, 0.025415681264994126, 0.0022905428035770573, 0.06636345428564856, 0.04736985936160049, 0.034376249738758614, 0.03408162764483883, 0.00819823342270308, 0.019949733940584045, 0.039402587083919395, 0.040259310870521495, 0.0072692991459682105, 0.032161715545601426, 0.041136305343600056, 0.01822458820477609, 0.036600268100418394, 0.00973488897040126, 0.006340931774297309, 0.06757392683216641, 0.026918303356656147, 0.0713324384583581, 0.04565846490403337, 0.007203197728226623, 0.018107537630825274, 0.012317138663943739, 0.02289596828632057, 0.027589641526461612, 0.051098083701705745, 0.019373486434379895, 0.04998002817193347, 0.06371017387737671, 0.04898662280832087, 0.0349887638472982, 0.1084053942993764, 0.03212180236474641, 0.06936242037843313, 0.06775421796426659, 0.026606151255809014, 0.04402352219086982, 0.025802806560550968, 0.027641871485919244, 0.014423658290217, 0.034264220871151455, 0.032139659874261386, 0.051365643739700324, 0.026551249564715454, 0.017568901211263675, 0.011550469470450716, 0.03155810529396179, 0.11099952888945419, 0.04642691620956025, 0.02544491518018467, 0.020470143213207205, 0.039270662912918676, 0.04685219076852645, 0.025068072699791482, 0.040890777994307785, 0.05998811654506191, 0.03984428273754255, 0.02246522577479482, 0.03435441623291662, 0.05004685402156846, 0.014848521076923898, 0.05370238810897835, 0.028493037304630684, 0.04418541189102877, 0.0536581541922304, 0.04043815792688439, 0.044387574833367145, 0.04209413358400907, 0.030024042953887296, 0.010353928232835907, 0.01381055525158562, 0.06830810719440061, 0.05436922168178905, 0.07045600322946426, 0.02894514792358443, 0.028720808651057944, 0.007459291824019484, 0.015356813711414655, 0.0337091097307782, 0.03944997728291539, 0.0247888068383139, 0.033351162809037396, 0.061646378974640564, 0.038730904174548005, 0.0460484879271638, 0.06097356991602048, 0.07222242578263245, 0.03551295184860787, 0.012004502970094403, 0.07906591219286765, 0.02737099045677291, 0.03470608506411795, 0.030493915321365483, 0.09266619450382649, 0.01819938582728707, 0.07404545457252572, 0.03330712041427051, 0.035471908688064546, 0.0377291216394834, 0.019632213478607517, 0.012748043011543492, 0.03334882241042872, 0.028421306577060493, 0.025057270860059128, 0.026754902548066554, 0.047178329719651135, 0.004361517625981041, 0.020828678107429898, 0.05759565460105097, 0.001263354638321025, 0.021793782267899766, 0.010569094560079036, 0.021565522540420778, 0.024530118098482493, 0.022014019139591726, 0.045426685002542315, 0.05446253119096641, 0.04517239360739628, 0.0551854538911533, 0.059864002640449235, 0.03615339369242711, 0.039279335028221535, 0.025467780989504633, 0.0076399540299579745, 0.05033389950591711, 0.01968556575687422, 0.1081527385019487, 0.011950371197364744, 0.02841077478332145, 0.009978301917022515, 0.06051773994019436, 0.07543506145837807, 0.04652147827249381, 0.02885952610672722, 0.031473464069647655, 0.019493469209860892, 0.041737048511183074, 0.06590984596480286, 0.11383799190122275, 0.025262059568757975, 0.021420312489593224, 0.06322599864835221, 0.021809065721989162, 0.029008836643169486, 0.04392868433628352, 0.05855009673283466, 0.008296663272044352, 0.013378057441103363, 0.051794587859823826, 0.01846418603353443, 0.0251368903780296, 0.08732515206981091, 0.042168038086064404, 0.06315430814039803, 0.03065468270271536, 0.03760799930821504, 0.0166697112557989, 0.012615846879329654, 0.07712798553609079, 0.04366849406412052, 0.06897030593526941, 0.044899547562724164, 0.021536043477094462, 0.041692182571897586, 0.06285629993785294, 0.021310572309659857, 0.02641963948976369, 0.02587935023550545, 0.06335103185847402, 0.06459266503131197, 0.05635571831296529, 0.0116121941321199, 0.028843673832354047, 0.022912289789547364, 0.009277023115916359, 0.025296906993213682, 0.03204862181577952, 0.06837861792695138, 0.01589043608551184, 0.05006164717938631, 0.005272274551492546, 0.037999454915763876, 0.023633433250530113, 0.04073599375964653, 0.010810530042245744, 0.09383735907894951, 0.014302807920161757, 0.04672520786463734, 0.05576632856842011, 0.044234433857303475, 0.062156352214515216, 0.026065231894233057, 0.016335892273233305, 0.02889975721407081, 0.032715018718473377, 0.05605761434942965, 0.04489483995242946, 0.03486908942220673, 0.05162163585003826, 0.03544300802112107, 0.029021352604632417, 0.018454962334926092, 0.08268026139346824, 0.04306570161134005, 0.040934287957967296, 0.10381106542603624, 0.004770565006296121, 0.030857856881113786, 0.04953821760512168, 0.04169574105030587, 0.025340035828130863, 0.047413920908565485, 0.06800737171884506, 0.03568630605455368, 0.04522635684078259, 0.03064921091971619, 0.07574764065324299, 0.019436282661533164, 0.018042186500444528, 0.04970716297506325, 0.014633162270089792, 0.061523973446099035, 0.04275515254947447, 0.06975675647657725, 0.04793057443513986, 0.0361261171318831, 0.019343530481320717, 0.035845916643137896, 0.03445486568154828, 0.05444981030098373, 0.056841938996747624, 0.03832738651263137, 0.003824314509045273, 0.0690513427158998, 0.01864078079139994, 0.02514692229939805, 0.009218723824878615, 0.039877297296639413, 0.018444457354264397, 0.0400383519609609, 0.033601711864673325, 0.03833131654368293, 0.05333990977716543, 0.04086465439608982, 0.06852394480618738, 0.10985716922028411, 0.16524413870947977, 0.27326595278516896, 0.13965484085342578, 0.10892987341409731, 0.1503461187765483, 0.16804342398480063, 0.1129582088680998, 0.07454390968045882, 0.1825853049634926, 0.09626595739034877, 0.12269637382198727, 0.10287415521639971, 0.15029131284644529, 0.20390920911825475, 0.1282112262842636, 0.12987929846971266, 0.21333379130209648, 0.0956467898081868, 0.13777938100599474, 0.14499352373663457, 0.09394189177621758, 0.17811911961724683, 0.13672280786258562, 0.17954355286013696, 0.12162872304719304, 0.23001624451529598, 0.1285203274399523, 0.1013628552637754, 0.10714222256454731, 0.11123379091581992, 0.09553132503623925, 0.2986515631839153, 0.16018952122859417, 0.19515820208095735, 0.20292140002692902, 0.08207066991035977, 0.08024253131401154, 0.21139951122383918, 0.14026645480865432, 0.08357732737016293, 0.1366156934490127, 0.123708667083373, 0.11351418951826711, 0.0838542068677564, 0.13685394679346394, 0.08624280772862897, 0.1247013561547764, 0.09042958548713116, 0.2866907243526751, 0.14550520918301998, 0.13885869163899653, 0.1771830674260855, 0.14080942728586737, 0.13611280269199802, 0.1449150150461543, 0.11011265188215241, 0.15500471476585637, 0.19875204310782496, 0.11502761153444169, 0.09664879450874944, 0.24300672083852753, 0.19056719036832934, 0.17056029860771474, 0.14586759941472163, 0.1285106440885894, 0.15889694703923118, 0.071931442606353, 0.105186928694527, 0.1692350737510189, 0.16225979723516973, 0.1448922315912862, 0.1704264783691014, 0.14705132783180283, 0.20879537918634955, 0.15737068538944568, 0.1420826960595385, 0.17367190260800625, 0.1024509376035102, 0.24118965221268518, 0.20688285600514184, 0.1208910110196279, 0.1820252487255681, 0.17490292929353254, 0.16130134463310242, 0.12486253339316576, 0.0691322032963076, 0.11239744782928499, 0.09889783713245585, 0.14310940709565917, 0.12549419586937274, 0.13298613740311516, 0.17150776550894783, 0.17903952829299435, 0.16642756069139128, 0.1524770383032099, 0.15524866780446422, 0.16408179946724447, 0.1254071376376575, 0.10655441862200538, 0.13600486090346692, 0.11836764763199514, 0.190749074963312, 0.17243232638124498, 0.15607169138327723, 0.09822864400883836, 0.08995893937084945, 0.08603596398907323, 0.19871226782279633, 0.12124452995316637, 0.08809975123093014, 0.16758937899383808, 0.14447468302903638, 0.17909169888063786, 0.13694802239056558, 0.09448637344664144, 0.22072943558375682, 0.1396041258328384, 0.17555103967747382, 0.15051320255283387, 0.11668202437220082, 0.24907962238836676, 0.14452009672118774, 0.17969529955617844, 0.09991998994542707, 0.13616172506684257, 0.17639975784526718, 0.08532807576440035, 0.12502551859905645, 0.07750886146940532, 0.161196390587476, 0.07625204826434774, 0.1556909763284268, 0.1497038919478655, 0.30276806003624396, 0.1580128049658191, 0.1678637150795229, 0.12064883530500436, 0.19161057147768237, 0.17954188278846203, 0.2113334897665247, 0.12251914704158423, 0.13663692940627375, 0.1908702700729332, 0.1568372277242522, 0.12134105703162572, 0.18022403811975835, 0.21648570684896362, 0.10101270711710376, 0.16195369914414423, 0.14732578649155556, 0.12610584812899753, 0.18120634669978775, 0.25243144091819564, 0.16650741769661828, 0.15415720701698335, 0.12696212758460354, 0.14218748156582156, 0.11450138573925342, 0.12063303857200569, 0.1460067975905634, 0.1598576212962789, 0.1650077546195638, 0.08551815750017282, 0.2021776052612451, 0.11508748896660344, 0.1259962439296707, 0.15127239568579584, 0.11118156670202171, 0.08328336411185804, 0.18004451307558245, 0.10520352215896692, 0.1177082834164462, 0.17315606496507124, 0.16241629367634175, 0.14749559754085156, 0.13286727120078382], [0.014480513505517476, 0.00786029719634943, 0.019922679545538082, 0.026403455882363265, 0.048154206991556196, 0.04773241047176623, 0.08077575915282773, 0.05555049095663333, 0.030566147836526076, 0.042389920131573756, 0.010264429053471935, 0.05365029029968766, 0.10707661479471192, 0.0052741557761516065, 0.04260241760001068, 0.026396363823404236, 0.055651518801647815, 0.025961241204171412, 0.049864831530759414, 0.03642785618261945, 0.022479226031611045, 0.07784379510990075, 0.03359393607224188, 0.0036939797310849595, 0.05411262436199093, 0.024613631258328116, 0.007231478821561342, 0.03766083256191304, 0.030862991585426276, 0.04074040259565077, 0.01623091524496915, 0.05576414904827553, 0.05348712123269516, 0.033921863838669755, 0.04896233782112118, 0.057539776147853945, 0.049797220441002044, 0.031574311883999936, 0.08096073108214526, 0.07112627653705497, 0.06752800752198504, 0.06334530535124003, 0.05037980732477961, 0.02136040249869468, 0.04650999078406923, 0.08085995221570616, 0.027233157832656178, 0.025562869737886136, 0.02532099662799268, 0.024208177309182864, 0.05496254145738579, 0.03864984441127989, 0.03260412749143378, 0.015553227163881305, 0.04204997244561392, 0.006749280578186435, 0.035202552173887534, 0.03768389180843388, 0.04110217612657336, 0.024957210201049046, 0.03797105986685042, 0.05829404333546277, 0.029019132864871816, 0.05073527595208538, 0.052984272610516324, 0.031772981465403596, 0.07562203287717796, 0.05838569426428407, 0.04183793846037119, 0.044804801638688774, 0.04253858332372001, 0.055684893422069094, 0.04865058600121448, 0.022885369459888148, 0.09447298989060426, 0.044260783451459104, 0.01583526051798535, 0.10407454604583402, 0.056878772504147024, 0.014703671087420758, 0.06768870212498211, 0.03239290555939078, 0.004903189190137651, 0.06191074442599089, 0.06404337615916325, 0.06006900010810745, 0.03247748166623135, 0.03705034475593317, 0.051071990747004754, 0.035800951112422257, 0.031050558637587294, 0.053728350828732216, 0.009580178471702722, 0.04569939698182768, 0.015855412460833548, 0.05569173841767254, 0.026597496377484455, 0.09949051339419619, 0.05755525878480366, 0.0545755138380393, 0.012985802229283559, 0.01842537410407057, 0.03606394909682774, 0.03664837076118396, 0.03337691485461208, 0.020615517972938476, 0.047294989588760564, 0.038595842873497356, 0.06549238933310395, 0.006461778792717885, 0.05973128939888651, 0.006526263286134289, 0.04896978802618481, 0.02049798859403499, 0.016568108844841202, 0.02129754881494709, 0.01738473367426665, 0.08704812701551184, 0.0633452478946457, 0.05340601933459121, 0.009795922237718779, 0.08955166404766422, 0.01726908695643708, 0.0978028906449195, 0.0166847629682912, 0.0036097689524232862, 0.026206031193836566, 0.026052616341339967, 0.043130098962255066, 0.025338785189594475, 0.039929885402201645, 0.0349278407051198, 0.08698582108463011, 0.007803194917693375, 0.012711767790718906, 0.02891308331351367, 0.004421774271665322, 0.011910111361723996, 0.049514614436174595, 0.039286827368120995, 0.0219604121370902, 0.043970416975958694, 0.05580218531371606, 0.03472740529105067, 0.03181104262870166, 0.05613520373440078, 0.007463408589002587, 0.01651593634197789, 0.058996116952790376, 0.02435464565942605, 0.024515457090831572, 0.02732185166208975, 0.014239835492785902, 0.07682056211295628, 0.08139592264929126, 0.020696964610608357, 0.041461502006577874, 0.0719577347439143, 0.023464631522074345, 0.0640871082883208, 0.0636981807709221, 0.061955763582861235, 0.036149176378403945, 0.03142629603614971, 0.036812593199072347, 0.046836995414548346, 0.02829043960739528, 0.01650829461493319, 0.05989243982419853, 0.049238884070467566, 0.09600714990688909, 0.044156082214847694, 0.08191621892394559, 0.023917634633459875, 0.07653292674090593, 0.027736494835886746, 0.022032612093514013, 0.03674266852378365, 0.027230941923335198, 0.019480367191135883, 0.04315221209018942, 0.017941798338846817, 0.026171532339386405, 0.07055307423034984, 0.038713521639546083, 0.027459935180001685, 0.012040583796108202, 0.055178026668727405, 0.027962864241412574, 0.05272555322716794, 0.032213629493790294, 0.03745005879130575, 0.008513993797673574, 0.05019141098244056, 0.06920684324277025, 0.028399741201992, 0.04360188654954395, 0.061001118437777606, 0.04217470688144526, 0.01596195518129295, 0.0378920225757024, 0.01194067348185326, 0.03140316401127606, 0.06270133567252947, 0.04582228897620113, 0.09130923828530697, 0.02098052631012134, 0.018927826275748592, 0.06961748169194307, 0.030266088433563713, 0.01803808793004963, 0.031005482024122632, 0.011740582807350063, 0.021931111189206282, 0.09102513457858756, 0.056157155983871034, 0.05493568241476052, 0.022668704473143144, 0.046243491777849775, 0.10092430823152104, 0.008757504420505177, 0.07323015315998947, 0.044976405333727605, 0.07116604416120438, 0.023669159760878935, 0.02175189832585954, 0.04960562951201874, 0.03035638721719865, 0.0345310952604538, 0.013793301036311014, 0.016225987384396217, 0.009288319082359874, 0.04525119724172739, 0.013749492298361036, 0.06625335212917098, 0.03344329637325099, 0.04876659086514865, 0.015863079085735785, 0.03194704430267936, 0.07182484147168937, 0.047748463844219526, 0.04042883080640628, 0.010693731319700039, 0.06935772425945728, 0.049879440827475446, 0.058819453247011676, 0.05358643304075926, 0.0709321498570423, 0.04879172237950468, 0.01890462721818157, 0.08308064958621418, 0.11658391149173822, 0.03461740272600324, 0.06879490244412614, 0.04501591248798274, 0.029801764457877127, 0.04263101949266369, 0.08101798849360597, 0.03377713067757507, 0.011196101136926201, 0.015432369132946818, 0.043400650573593956, 0.043535206256614584, 0.06270857520341393, 0.03304868831389374, 0.030847690894358584, 0.022197029883823088, 0.04581371262188881, 0.014812491961844988, 0.056938259231467406, 0.02246918836458316, 0.04663410085824229, 0.01920104387306398, 0.05079452902258885, 0.03269270257723909, 0.04012460196991602, 0.01330571958885318, 0.031146624148072257, 0.02389359096395633, 0.0570980804942308, 0.05842489115292988, 0.020146392541186466, 0.039680914487689734, 0.14259591368177246, 0.01681032669430058, 0.031999716677913265, 0.05807495368043742, 0.041144908510989724, 0.05394092873640118, 0.020591388118543455, 0.03442840117420401, 0.03543262369930744, 0.028386665996344342, 0.022521161684586156, 0.0313992167432462, 0.03465973674469898, 0.044375041634925914, 0.06223569594083294, 0.052746321870795185, 0.09457481829749961, 0.029477485185188633, 0.00506413564453983, 0.041171281087783076, 0.0334939654285629, 0.024752712605761427, 0.027999774357604406, 0.0076945339641233375, 0.04064727311713561, 0.030582339104805744, 0.009067760453739715, 0.01726611645051068, 0.033080749093524875, 0.038465937344177116, 0.061593220133574746, 0.06418728960617896, 0.02790106775900049, 0.004877667928550152, 0.053168466960590695, 0.039378374875072515, 0.033061424525634896, 0.06746456778097538, 0.03690792134993019, 0.07714399677370826, 0.057037965574812506, 0.04637679873755382, 0.049946117289965196, 0.020668738101038243, 0.029141551799952026, 0.020723160987179128, 0.03460703755638773, 0.07395049797431116, 0.04397894353455594, 0.019593271314196532, 0.043199246058300625, 0.015038191998046974, 0.04313913496932195, 0.04078375934172542, 0.07129646296943389, 0.038459157466047236, 0.030518142851970853, 0.1605106193211771, 0.02431072392350724, 0.03209252439950022, 0.03071414836261782, 0.026567607457118652, 0.06257897227882378, 0.0380942621268332, 0.05505543344864442, 0.037831723795182286, 0.03676477016039914, 0.03859999890048658, 0.025460028179710912, 0.14688939216636843, 0.13638044316922465, 0.12765005921884892, 0.12312153729820445, 0.09635949672590341, 0.09748966027531894, 0.2480481616071155, 0.1652807577122604, 0.10441706395677983, 0.13456841540192405, 0.08950866353247436, 0.17636295498138474, 0.1540137493922826, 0.2182044097853284, 0.10217936709523202, 0.11379407208052375, 0.13762722062247415, 0.12100898089908785, 0.2182681789441455, 0.18006202584553152, 0.10047001809242273, 0.14754306434863998, 0.11948507113922989, 0.12349208636629967, 0.18142000862186958, 0.1746482050587093, 0.12145252282460853, 0.1654315238157588, 0.14123799219246835, 0.20161629263912478, 0.10428311348321939, 0.12075935114896107, 0.1980097805179896, 0.19396255333577433, 0.11643155958623656, 0.1490201278319282, 0.12280554135119724, 0.08038857831589638, 0.21217679935357264, 0.13974122492776764, 0.11323842850904312, 0.10518977854160533, 0.15508428065767213, 0.17328352667391303, 0.09449023452977981, 0.18839292558691195, 0.09553031380017919, 0.16190450097764694, 0.13744786411764162, 0.10292369812246292, 0.14257242542601403, 0.1226499718764136, 0.09188365867181171, 0.15773975590784706, 0.11516448080299363, 0.21293118145437012, 0.07858343767903506, 0.1696332862540599, 0.15946363759857995, 0.07294610307942476, 0.18405263913014244, 0.09360878142498194, 0.20217573600670985, 0.17575051365119798, 0.1294227100668415, 0.11316679162724365, 0.22354847060576563, 0.23333185772982337, 0.08819635491818191, 0.14602176694860383, 0.22455843495986155, 0.22130914963781836, 0.14749251786739598, 0.1877522309340777, 0.3064693065900957, 0.17242054394896955, 0.15912343327316547, 0.2557189999929359, 0.1361020927828166, 0.09051662073620866, 0.10748677060849245, 0.1505796070541105, 0.07736203305783772, 0.1325794826111486, 0.09318051529267142, 0.1769523370650507, 0.13565023880331747, 0.1187030332643659, 0.08989483313334566, 0.14650797231062768, 0.16814923604890225, 0.09893750516517509, 0.08352406127678771, 0.15383348890369938, 0.0701925992184589, 0.12494620551625568, 0.2408050607529379, 0.19288454505224384, 0.14949035259985155, 0.19206480032974677, 0.11188087474194267, 0.11403810172792404, 0.13349337953953974, 0.1325821332753666, 0.13683807345167284, 0.16250096171373324, 0.09812374358936664, 0.17953253651578582, 0.18152413529253777, 0.06578848997671759, 0.16424523666501045, 0.23329528469231822, 0.14493286489479004, 0.07787085333538633, 0.08668599725370446, 0.13070534043494733, 0.11516923054812417, 0.19436867186619392, 0.16097595644814355, 0.21725533409945427, 0.11195546106225061, 0.16784203479126578, 0.1593884077644156, 0.2107219370983301, 0.12446492609958495, 0.1217098824018913, 0.19837330455981916, 0.09441353380680086, 0.10933577743989807, 0.18910137305576957, 0.0732914555156904, 0.17083915461215282, 0.17356213753021535, 0.06565688373220545, 0.07817153518478717, 0.0951204644215684, 0.14084740992515318, 0.1033919234009039, 0.12853446176215527, 0.18405660746559022, 0.12209697130827174, 0.14469044403203074, 0.1321009074848506, 0.12932334846306232, 0.17203437434809823, 0.15607611937147958, 0.22722514105900643, 0.08778039981881458, 0.18143586664190217, 0.11843117930355573, 0.12180138394356736, 0.20659525127660847, 0.08806186052219522, 0.18865897260125608, 0.29546549543738365, 0.07418610065454438, 0.10803009548615064, 0.1846120824977275, 0.08172242166174036, 0.12021846243090208, 0.08709495030944386, 0.13392638775610155, 0.1310510912369336, 0.06980665178308565, 0.17764831262250103, 0.09545420296490194, 0.12208611584238468, 0.18153067768341113, 0.12676548047532, 0.19506991810856328, 0.1601964160199127, 0.12126634813724987, 0.14176457038810178, 0.08101925253868103, 0.181265672548644, 0.11325457764248695], [0.041144920002308585, 0.01910741452217823, 0.03583246413918753, 0.03618486075391693, 0.056717533978723714, 0.039542612634719386, 0.032522722988599734, 0.036320845190916336, 0.02620358928857792, 0.05188373368113272, 0.04110697566741898, 0.08371894638384543, 0.03938609321090964, 0.01929101132367167, 0.026948245903176647, 0.028971696700600368, 0.049101267866189444, 0.02191671256666943, 0.036305186353744044, 0.06822415927965796, 0.04206406846342068, 0.07825797288528374, 0.02854739698851782, 0.018733362517049237, 0.013099418814113785, 0.0790918366082253, 0.0908831095383052, 0.044791797296174114, 0.03492739637412372, 0.055768948589121146, 0.05853772441285753, 0.05161942185593709, 0.017174436793392225, 0.1213342005447034, 0.055112472525046724, 0.0028646747100978132, 0.05358089422506671, 0.03219209476223877, 0.028871917578902458, 0.053100043817633585, 0.033586420749704686, 0.03863624635062391, 0.06425116218686586, 0.05988188313260194, 0.024033482449369568, 0.04242563515060371, 0.020171495327245326, 0.07130971629052393, 0.03450253550263663, 0.06526640105632044, 0.013649553255808931, 0.07094636844891695, 0.014335300581860206, 0.059981604797705534, 0.07138644765701986, 0.019223997782495235, 0.06136481867982976, 0.03305473274761631, 0.038936280855728735, 0.050792399298159346, 0.04029811705432592, 0.03027916555443118, 0.07069509160975296, 0.025421051541343335, 0.025445355680741133, 0.03416396677494049, 0.01654748192747995, 0.059600671407796686, 0.04916294177453365, 0.05457267165184022, 0.03720812056393873, 0.06028928486029468, 0.011984347196806584, 0.056160595718651056, 0.010972577748039078, 0.08918509097589601, 0.1077089207847753, 0.1150124200109032, 0.03384045933583572, 0.04190541165430219, 0.022012705298801585, 0.023067571981359395, 0.014526178091464025, 0.0375488956248568, 0.028559344129696972, 0.06305052620929576, 0.05369777242923456, 0.08721396206848084, 0.044714012558782296, 0.03022507974697698, 0.09212990231331318, 0.01837109868985511, 0.0415315569168137, 0.014013409588275658, 0.04680936262311955, 0.11157485325970959, 0.058500224408964, 0.042363582028736996, 0.04438611926631101, 0.04445771401327464, 0.025031275581568483, 0.005471570888579253, 0.015399220508463202, 0.0502993566014113, 0.02253974506240939, 0.026743409313982534, 0.016170867358244235, 0.06411444996633837, 0.04514566479971813, 0.050943402888914274, 0.01159621736845903, 0.02864084056308193, 0.03806458005020696, 0.06697715200003117, 0.03760514180025747, 0.05501126847980965, 0.10220663216445716, 0.0326037367865924, 0.0429765289769538, 0.0519274351667733, 0.010859765555529345, 0.04778858769925372, 0.04386979515754408, 0.013615493944305326, 0.03543498708055385, 0.008691726196106643, 0.0364918475069346, 0.019922643156361677, 0.045473971779668526, 0.04517516301524255, 0.010440022151376451, 0.00972187600939745, 0.018962629650148655, 0.034304333234866785, 0.06188597297295929, 0.048519002739340074, 0.06980008640957457, 0.03156915419704972, 0.021780885177694505, 0.02040253403866964, 0.07633363662828362, 0.0220562880408139, 0.0051887053714674575, 0.046563111320738836, 0.008847168308772869, 0.02261573715405839, 0.06231374880899826, 0.007369413909937947, 0.05824451575115804, 0.04166806612404124, 0.10885755471404522, 0.029858102563828714, 0.04479619464085949, 0.12227680278761734, 0.057468254179243124, 0.09627430774872342, 0.12547648391656338, 0.04240459837620297, 0.06967813287290835, 0.02400252100590977, 0.02288168266175255, 0.04931198801064203, 0.009428203864503772, 0.019432025127893975, 0.01175623685647283, 0.037006026569513545, 0.06615173056601517, 0.06143217696057213, 0.026043605232130618, 0.0003313762693235936, 0.04802467684531885, 0.02888871788708193, 0.03512221253326824, 0.031065242627875942, 0.033714874542408416, 0.0332092373601852, 0.02346049464728323, 0.059407004380538586, 0.12488067435521273, 0.07832646114571441, 0.0466019060132244, 0.02158478007561738, 0.009703626837431183, 0.032855028947514874, 0.05334471314845066, 0.04411650228223974, 0.024537777062505487, 0.04236778019056205, 0.061859834052982836, 0.02903287648223341, 0.05063878717802225, 0.04493075032388011, 0.042489078722053, 0.04285649066009829, 0.036589048742767305, 0.05830261585933547, 0.027613371099916198, 0.03427952730787858, 0.058630658538951996, 0.046105504020928376, 0.06853864603345433, 0.015825515879588505, 0.0173441520816977, 0.04094869041094377, 0.035862276450760906, 0.041411767578533584, 0.028770361133220217, 0.06506618397730975, 0.04489158024831165, 0.03421360161155462, 0.046258966753920244, 0.032501724518595204, 0.06572865084895203, 0.018353338856550477, 0.056727887657020366, 0.022067536126762148, 0.01805819390762237, 0.04773159458812687, 0.05680129803236454, 0.05986704400950863, 0.004331834112939936, 0.027532868665612997, 0.016768528937151837, 0.040867626817236026, 0.05222083918089348, 0.0387074580536254, 0.042202653768923015, 0.03003801448240636, 0.0811199547963277, 0.02294669096778718, 0.00927327024269729, 0.060677905942523674, 0.004740015335095626, 0.044304109554016785, 0.05950900515721691, 0.07480886884995046, 0.025052402371300325, 0.06509453689138736, 0.07098202984179221, 0.008807931200511033, 0.01697495132834921, 0.04944992597184835, 0.10180186194878432, 0.061981891011518825, 0.04245642039384093, 0.07153324542507049, 0.033053882390020356, 0.004151836009470806, 0.017091097918549375, 0.04152961488392565, 0.02299828315904785, 0.03717974083678376, 0.028603648909577922, 0.018306249347064766, 0.06873546168208122, 0.07399736723351864, 0.0843766481885987, 0.031607452847604314, 0.048850362579668724, 0.02565291379728625, 0.027728766923950567, 0.02465775409232705, 0.05804293886608174, 0.113131022982059, 0.13256273592912382, 0.05049460943067267, 0.02514814612485709, 0.05749796306894672, 0.033147559621401375, 0.037760979405814604, 0.037783575169141256, 0.08563438069916542, 0.035151511565932346, 0.026321045889128602, 0.04751774114406398, 0.0759966115677549, 0.022774541435102304, 0.10227128232438719, 0.08256955402753047, 0.08180645384615468, 0.06724349778866576, 0.033673785416589636, 0.032171705332134044, 0.04460459605099694, 0.011560882520561498, 0.01115848430462422, 0.01626514022298638, 0.02252772705809724, 0.07441965021914052, 0.040872916654353185, 0.01830237677260753, 0.03917517388359674, 0.11215832114460007, 0.0033096140278728622, 0.018934033503155076, 0.05020308233196697, 0.04629741670683988, 0.03013811919147209, 0.010391058599305971, 0.017284004603542628, 0.04106120957482246, 0.0404074646141981, 0.014032582853800588, 0.02439742592433768, 0.0336102805581064, 0.011712277773767711, 0.029601844237937085, 0.0076145735370265625, 0.015045296505934771, 0.022148423520247304, 0.06983393217406927, 0.031623791587809404, 0.02661813670138438, 0.04437573877493701, 0.02208037192993347, 0.0026774892654840747, 0.06392790755677609, 0.005719687136250639, 0.04223566449758026, 0.009281738387090305, 0.03507674521496219, 0.027208259975117062, 0.022325198308775024, 0.025699329149398594, 0.0728483732429243, 0.022672881567550283, 0.1486387692632214, 0.03461541472783974, 0.0464237560968726, 0.11314745556803481, 0.018729091576871373, 0.02735175590421404, 0.06473069109262959, 0.0255552031129839, 0.01949821512455181, 0.018015398320952253, 0.006176958793789269, 0.011187035443952248, 0.015080185107616408, 0.03761185656091379, 0.02362612477173248, 0.005621135670451388, 0.045045946965054165, 0.02242963907549218, 0.014912071900682585, 0.04459594691833181, 0.036784558211483305, 0.026098097066184687, 0.048204374259277705, 0.03627894018145819, 0.025497949531962796, 0.026836201713811007, 0.09784661128275818, 0.1303658562321817, 0.20684016958600093, 0.1817204376622554, 0.16703491519776084, 0.08049914778600778, 0.1398757346455128, 0.2175052013368376, 0.14361965229674695, 0.2166664423120599, 0.14055379906729346, 0.2032173091485616, 0.12765254900460282, 0.13517314988759258, 0.17219965015688252, 0.12669938240921305, 0.14000609216670837, 0.14395717531442642, 0.16881810741559153, 0.1731872907088649, 0.16262071657805674, 0.2614082600320539, 0.13185606578425055, 0.18078303715634733, 0.2224541906147234, 0.14799611342530097, 0.24411266068777732, 0.1329696971562601, 0.15506103755004946, 0.10465386173417492, 0.13805313486485712, 0.1867346669877729, 0.24295199151721694, 0.19864010234032908, 0.09828605463788395, 0.1335635991586793, 0.13465031020102963, 0.08731767505166993, 0.14149458568182685, 0.178760411818662, 0.1668636332596502, 0.14866564362760515, 0.13026528420948214, 0.239851511113586, 0.1260746989939963, 0.10905112214987317, 0.07055989241287594, 0.1464408476867022, 0.1237632355262195, 0.14156664391198467, 0.12321734425401497, 0.1328508922409627, 0.11864209863086862, 0.1377089622039949, 0.14946910132083202, 0.18320542249468066, 0.11761399331472575, 0.13871780806972137, 0.14738692030791314, 0.1365768374694932, 0.13418920187940522, 0.1708576939399204, 0.12346917267648444, 0.12576577403853018, 0.11398290509297965, 0.12640128227611705, 0.25312065958015384, 0.16001940374412846, 0.11184935022385852, 0.17981318516596673, 0.15588127256881806, 0.1255588690119405, 0.13004241391055046, 0.1913191363095276, 0.09283523180431898, 0.14478808959885953, 0.18938096450461497, 0.16735193770258658, 0.14601556163641716, 0.14181828847335232, 0.1852569753123868, 0.09917925187056104, 0.11876556902162491, 0.10288814398189707, 0.12229093710982031, 0.12808220175605628, 0.15240170121673616, 0.29156053078270733, 0.20327076676391787, 0.15481814171277708, 0.1403605150839975, 0.12638622864840493, 0.1224304263990733, 0.1095004557001014, 0.11369738412360031, 0.247761782619261, 0.11735608215413748, 0.12291215780761935, 0.18549115306908087, 0.21741521664925162, 0.13649871182297507, 0.19046412089899664, 0.18463793030429274, 0.18487100489437583, 0.149246598744104, 0.08441693675253661, 0.24223019879671837, 0.17396957373186467, 0.14337709353816125, 0.14714256890358465, 0.10389788617049495, 0.06770377107445272, 0.20294795263438456, 0.10702863470801424, 0.14549129702631505, 0.17088351110296865, 0.18753760374121128, 0.19809432598131319, 0.14988997470467322, 0.1493323086610725, 0.12400680552086524, 0.1490451482635352, 0.13602255753451778, 0.08426281518392986, 0.09027954716716083, 0.21492075775900196, 0.11232856120313368, 0.08863887794676328, 0.169954736747088, 0.13080005954590537, 0.07948631826307505, 0.0780865990166222, 0.11915496385265743, 0.15205705358136087, 0.20220362160715366, 0.1426075888617385, 0.09658732361370519, 0.15237556229675972, 0.10678761578615635, 0.08907544081129375, 0.1796118725812243, 0.06779109743694145, 0.21772568144144552, 0.20502268727267944, 0.08560343840790373, 0.17007948650467783, 0.13670474350933107, 0.13317802710638893, 0.2159819121081983, 0.10266387174206396, 0.285133206315579, 0.22903116269698068, 0.12540388942485856, 0.25766248844804307, 0.11903854147080453, 0.16457460850717562, 0.22592832274254293, 0.2290391300113932, 0.11569812232928893, 0.15036245177109397, 0.13936832396974488, 0.13346671967977478, 0.2049716198516469, 0.13235523335395322, 0.11560269075656131, 0.07180557436039371, 0.20077561839453636, 0.13683425833380994, 0.1303479604182705, 0.13494127039467135, 0.14767454035820501, 0.13868210837244987, 0.1370012501795446, 0.11380542550356158, 0.11677449884554071, 0.10921785352571357], [0.02204394444913393, 0.0401177263307956, 0.028484788452905994, 0.1505537439257868, 0.05361487405494817, 0.023322141083377986, 0.0529572986547024, 0.017004240784914266, 0.1027453298710527, 0.01600281256551464, 0.060466032835745046, 0.04576152671248682, 0.034158336028697035, 0.030074459200184193, 0.006025941317690717, 0.039685415254244884, 0.04388757222782701, 0.07261077107320871, 0.022452861115696932, 0.046757674670868346, 0.020171736644941474, 0.03197080835009054, 0.030359532008127823, 0.007531768529705944, 0.07634681334058124, 0.06794261430660564, 0.03738477277839857, 0.08292435232790248, 0.08916459046304227, 0.010012095970582339, 0.038304009339621956, 0.06312102545052767, 0.05648877629409394, 0.08500019779368755, 0.031061011907314102, 0.010886680139529129, 0.027485993660746083, 0.043184571644111026, 0.08364721757149504, 0.02043011894960317, 0.020342886432885163, 0.042134697939599716, 0.04133645730513719, 0.03685275152806313, 0.034518075596180656, 0.0218367598004519, 0.003929997774614623, 0.09181787470175375, 0.022975267962582653, 0.06813854895411961, 0.023947655703992616, 0.02151299955233211, 0.020726560502343123, 0.09885960168415502, 0.07545171620985193, 0.020598296316400654, 0.0399336890287457, 0.03905082632216715, 0.03910497724709492, 0.04156575125131396, 0.06340700990310119, 0.03803091431637445, 0.012559779776981281, 0.018394933600399285, 0.09106608197814034, 0.03924083911002644, 0.03200118373628826, 0.057222899199733814, 0.036236617654081316, 0.033065446487237374, 0.034969864458206205, 0.06705013719657738, 0.020626457708497203, 0.0344071728778222, 0.04820663038821471, 0.0750473750034167, 0.020095124022073804, 0.01660525453306975, 0.03920664094508656, 0.04759267986481709, 0.021132889706941865, 0.06299273636672767, 0.006534871720378438, 0.061440079157511075, 0.030380049757959864, 0.054134637898495125, 0.10701251621808737, 0.026584656743873513, 0.04196548443888465, 0.032671497263495004, 0.11829233352815914, 0.032141812581328616, 0.04770812548456654, 0.026222779791081147, 0.016940534828350912, 0.03864095779135823, 0.05096208394294785, 0.001659021455129879, 0.01999582179010876, 0.07575946905079388, 0.007844732683752815, 0.03288338569203212, 0.0773493389809324, 0.013528278664565616, 0.027869238720966444, 0.006783635312345841, 0.0726888737370891, 0.014078082730843416, 0.06186386750590417, 0.08227772049365506, 0.031404437632450176, 0.024372738740977742, 0.029631378842637907, 0.13042380312277427, 0.06232207618473519, 0.0422929065872825, 0.012842782232309542, 0.05006491454438337, 0.03376298869449285, 0.025279566593047594, 0.03988541016775755, 0.03689672880535645, 0.044367855730196165, 0.0412917330921177, 0.023750863038003448, 0.05655865883454681, 0.031049225644599047, 0.01592131421690987, 0.03989359198678886, 0.04030996460407492, 0.01719040206573423, 0.04363111663429488, 0.01178483491868622, 0.02422993037579281, 0.039096902680373004, 0.009987637655989779, 0.057131259762231386, 0.02851706182193612, 0.006923243824032046, 0.050052147689125234, 0.09252281348791816, 0.04928196119444986, 0.022232970898790706, 0.05419625051980538, 0.05485401744203222, 0.01357121501989182, 0.05748147302637658, 0.06731112803062124, 0.08726376544443831, 0.060323640073259036, 0.04035288084959311, 0.03946861237167351, 0.05048669957285447, 0.05273303024530892, 0.036620860543823054, 0.04216598497042733, 0.07461127945252004, 0.02988087835781757, 0.02164578365702783, 0.08402078502601193, 0.02920965127076113, 0.036951370026555755, 0.044864893575469335, 0.04599691871854086, 0.06990853381613571, 0.09070054312506992, 0.014117117783415222, 0.021502619060958107, 0.053820798488994764, 0.017909162993272467, 0.03209167021146465, 0.03297984765301789, 0.024839544841538996, 0.0005722670809313235, 0.015075890227190912, 0.020834791489065658, 0.025217438777608257, 0.043264842336817134, 0.05368872876128843, 0.05822748944704091, 0.056245248434284044, 0.04450142315979447, 0.04254954987235608, 0.03308727616263974, 0.03479575565565498, 0.039829577679835984, 0.06779669753966794, 0.04862851883855559, 0.04808600601409713, 0.07650376943450782, 0.07231935888769166, 0.07995709461430389, 0.02230825244388994, 0.08119929852264543, 0.014250186298252835, 0.03153034418280567, 0.1419933702075674, 0.014696187366010442, 0.050663183247970964, 0.03152343981538809, 0.027541437359046073, 0.04774951721511541, 0.025142423448062716, 0.0802141554172962, 0.04830594602671843, 0.0194225084006546, 0.023320693177201098, 0.04128815929195093, 0.05689473394604941, 0.034153011717623284, 0.032219819484218475, 0.05822760436022955, 0.028330438973141775, 0.013091035897002347, 0.052994116840343324, 0.028678798304510214, 0.062440582325742136, 0.010395601500696953, 0.033022959250956774, 0.004196590387202319, 0.029794049952479622, 0.03140289588050256, 0.06504167682461201, 0.047685836156409596, 0.015170159261493434, 0.10958431168429314, 0.08705265459514434, 0.031954567286095796, 0.005294448966460844, 0.06930124059680008, 0.022121872828011552, 0.04191657355535896, 0.007706881386242928, 0.03881255765595744, 0.06864528547251417, 0.03738000388106993, 0.024866038077180425, 0.023452458384957527, 0.05626452703689856, 0.08540838476150267, 0.02747013564071348, 0.02373191768363599, 0.032319583284157904, 0.059265427501691934, 0.05077568325965155, 0.00450006749991688, 0.007172470420388686, 0.05579201932696085, 0.07991537346594757, 0.0570611588867201, 0.0300297349871647, 0.0320776661242088, 0.02374517100472604, 0.015541275234652624, 0.05926831948360609, 0.05731659558331294, 0.05447489968050392, 0.02046406813596766, 0.03241807537814302, 0.02453839567850434, 0.023612700996079275, 0.0286781509602142, 0.0764107893431379, 0.03222784808566494, 0.059830811881129785, 0.06344213886486907, 0.06164372831042256, 0.03505161753104579, 0.016288756798472137, 0.04217287593130623, 0.03769388542540612, 0.025687705680367448, 0.08013112680806268, 0.0415345101857618, 0.029547459656192415, 0.08969251697342243, 0.05309102313232519, 0.0447250020900561, 0.06817706019407319, 0.02491005174365015, 0.06476036933881622, 0.018075015283219757, 0.0874748073458191, 0.08090516672499719, 0.021474377229629506, 0.046914201755557335, 0.06252201364165352, 0.04287044495163907, 0.018727455979153033, 0.04223037466046311, 0.037514034793862415, 0.08601574692875148, 0.054102826097439376, 0.026066218232435566, 0.01572971658465723, 0.014621844278618455, 0.02396566834631226, 0.008773392126444847, 0.04085325500777653, 0.03693043667402479, 0.05356249662356512, 0.09223621233456558, 0.014012232685701983, 0.027529557250560294, 0.05406095939237745, 0.03451788790463921, 0.006507467318912067, 0.043001606865155126, 0.04460794385522605, 0.03365366794769803, 0.040185881342979214, 0.06597137814688106, 0.05691885422434538, 0.007240344852870031, 0.048437012179243955, 0.05204523267645029, 0.07090565853662069, 0.014501569432116326, 0.06863561744290976, 0.05918763510342087, 0.05423713663232423, 0.0516705735466413, 0.05037377055193629, 0.07184382513045304, 0.09675814589906125, 0.07342400404834941, 0.1001782152020643, 0.05435229496910207, 0.05149399028009465, 0.09617207331522819, 0.08373690348479056, 0.029703705203569228, 0.026447574885922576, 0.04069264467445113, 0.0217846428389631, 0.024423957464375326, 0.06130762255540299, 0.03055131828953182, 0.04697163153680102, 0.018961890375301726, 0.055497217202378865, 0.0876992404641163, 0.03400661614573291, 0.013568210997618737, 0.05565140005801955, 0.035533984792568994, 0.04834593964680549, 0.05965768367112164, 0.0285752959955003, 0.0019985880123473887, 0.06791400092263376, 0.013197387095480679, 0.09356924362720982, 0.12038612077313086, 0.20175037334763235, 0.18380862480450064, 0.1334608667680333, 0.10246335588876279, 0.13147890537736878, 0.1028129447912497, 0.2385742740044671, 0.1358937168674123, 0.1702590268706122, 0.10513515647260413, 0.1049341120186352, 0.1489216395683827, 0.1316917246027339, 0.118468955099102, 0.13763115831440495, 0.20962267753578004, 0.09529897822968422, 0.12726379002654745, 0.20253869314347545, 0.16761826050858344, 0.1438562662130402, 0.1807323834227939, 0.09033490468056933, 0.12513316927417634, 0.13930460077620324, 0.257845706036014, 0.19281002001896982, 0.17610455352452495, 0.1732615093069692, 0.1755592521400221, 0.14130145491611573, 0.15368992402668924, 0.13771230234734474, 0.18810962627251304, 0.19688314097302576, 0.0986309627431535, 0.20926586442416717, 0.1912756838024624, 0.13643560149977285, 0.12724940289532946, 0.21064669194240726, 0.12595881287369037, 0.13085982972575774, 0.16731170276480337, 0.1929205665064435, 0.10849132638184295, 0.09505622794911747, 0.14569794158301047, 0.18254005981068458, 0.10633829755768662, 0.13551424287499922, 0.19880539347087184, 0.07654216576127276, 0.09326553573050807, 0.1978198366780435, 0.07883341982960701, 0.16556016530000395, 0.10497966360661293, 0.2105353640452508, 0.09336232327886167, 0.1416234569924493, 0.1473123339876052, 0.189496475241838, 0.09603686645747193, 0.1093467708016115, 0.12172151161658189, 0.2190297622714312, 0.15861481217847717, 0.12737898666772152, 0.15778330034546315, 0.16358767275608357, 0.18088097383658733, 0.13333953376258575, 0.18581396719861418, 0.07399505364798731, 0.14513800791915388, 0.15790618084851774, 0.14601761475205421, 0.10567820555860959, 0.10825539428380229, 0.13427655122453167, 0.15215082274329278, 0.12436351138016871, 0.1767390735086895, 0.26414506317627046, 0.11433193475128182, 0.1393120777943442, 0.1528877993264506, 0.2507301128559536, 0.09506988729680739, 0.08811305051729565, 0.2690116213935037, 0.14223669505407735, 0.14505550024970887, 0.1678299918890961, 0.10050824587984432, 0.18832183262753874, 0.16584568626938329, 0.14556508661518175, 0.08095173720991419, 0.17128457345308798, 0.11013532808471112, 0.1347945185918962, 0.13198669909709884, 0.17327116201481513, 0.12691875168633077, 0.1397954639528067, 0.2780040227357419, 0.14970243638080938, 0.12851298065675845, 0.09681210147156831, 0.21737712675765639, 0.153403238603665, 0.16334842349733078, 0.12034935621364463, 0.09373581412458613, 0.12547674438645764, 0.10138015352910566, 0.13655477413727393, 0.15292041935026646, 0.09106151609411163, 0.28886656727521653, 0.1552328404279486, 0.1692068510718884, 0.1600941892472967, 0.11034251656383277, 0.15773229421146456, 0.25840540987349325, 0.11999107987409639, 0.12451352671750131, 0.2158883421291267, 0.12708853209210982, 0.13054159680201163, 0.20780099706063349, 0.18193979927849385, 0.15840249857114208, 0.12335419820080842, 0.1299055752855155, 0.1627961200692, 0.1503072627970288, 0.1381584719544457, 0.11142331340740766, 0.134867113083601, 0.12285311541129505, 0.12079079905825278, 0.23368091803164254, 0.12942568248798772, 0.1967457354429268, 0.1515638614974676, 0.1483147753582847, 0.19396563300922995, 0.13066375718241738, 0.21771052822230325, 0.15791374979720962, 0.14460851858940818, 0.07695311064561529, 0.10357564660690485, 0.17406159621332923, 0.15664673230100065, 0.2001971300811537, 0.14422043376872618, 0.09720392480132081, 0.11900852614593123, 0.12957909925570413, 0.11537916928289399, 0.10463627235543345, 0.13236035082128741, 0.16638680481381957, 0.16361162066459656, 0.17156822516793208, 0.09438465995293471, 0.10294932376353011, 0.10895878557235965, 0.0788805418978295], [0.01468295894277793, 0.048688507353466366, 0.051012389106495734, 0.06343723590215368, 0.040254637734183384, 0.040714114288529085, 0.03840471925814787, 0.04582014776045277, 0.041008518047390446, 0.043688768581036604, 0.024114844817367774, 0.014628938252797291, 0.03860780916687462, 0.05665294510582763, 0.04918929902956851, 0.007285745617287655, 0.03276099931568869, 0.018909556993974314, 0.04666775893119555, 0.03484112721297049, 0.0299879448908952, 0.04019702409183787, 0.04332039137220672, 0.030621392351965752, 0.013336594847421493, 0.012652880527199277, 0.043980736180298755, 0.019262652663934617, 0.07312047235187023, 0.025255588041017615, 0.03794733029339583, 0.0491751761986844, 0.04181758350422306, 0.04146561589873126, 0.02097011900566999, 0.10160999522814829, 0.026000365314464417, 0.035900462103346666, 0.05477066324543088, 0.032132818709097566, 0.054235412934494596, 0.0358128791014033, 0.09187204477887961, 0.007972265734532549, 0.03718635983644955, 0.037364030947848674, 0.075137811682878, 0.050950619437161, 0.11800166444792864, 0.032566478100395015, 0.021843886333367517, 0.031911758292887005, 0.015009318144180843, 0.042224598357514034, 0.014751412729252011, 0.009046089741581631, 0.03343234897681302, 0.004431355158768354, 0.07612210443063129, 0.02050062010605489, 0.012587957448446223, 0.03128096149603446, 0.009038758280146266, 0.02155531633404955, 0.0072410697635683806, 0.07527761506817995, 0.03763567806491929, 0.03621017229893515, 0.04905169814704888, 0.031715325688222246, 0.052887040731166644, 0.021912324798083114, 0.08872705466684797, 0.02757983943147044, 0.01618489634335762, 0.006940049877870949, 0.019002288106768843, 0.092686940164816, 0.09356460879526793, 0.03678264682211223, 0.03866760615980433, 0.01938899396918714, 0.07762071030635027, 0.022467698323570436, 0.060914217254086855, 0.07696079450749582, 0.029353093573703404, 0.02766644758653016, 0.06946751231988592, 0.08463610684679401, 0.025208441074937585, 0.008356117440627949, 0.057830682715340975, 0.02925434675548346, 0.06963165431854225, 0.02366691320804098, 0.03341580147764856, 0.02146630266290759, 0.06417992367078701, 0.06146667773024209, 0.08150780212975318, 0.0644855889221353, 0.059684592509461995, 0.029810390607904524, 0.05984860810361082, 0.008496865986906474, 0.04925119510341076, 0.06778327567923455, 0.02350010905384777, 0.004168363398827252, 0.04896067541032549, 0.029970972212932767, 0.019391903188079596, 0.018924828956744844, 0.055633879627191254, 0.017046172607449755, 0.027142853303361806, 0.00901687402097929, 0.0587777933856893, 0.02649619848647666, 0.0947944863489078, 0.06040507905004967, 0.04348129281894334, 0.023414249749734037, 0.014568523601478627, 0.03399880587934487, 0.028017419277720397, 0.06628724385894115, 0.026548635289673845, 0.025753391974215067, 0.008392726867309502, 0.04140927396234005, 0.012111156773302826, 0.020241525339623614, 0.06896423851890911, 0.03898983040163594, 0.06816282628044006, 0.0330018267155655, 0.04153892668264528, 0.022991221743605794, 0.0524844155616818, 0.04412376862620154, 0.0050798390105727224, 0.023963350930341312, 0.011250603504689231, 0.07167625105789593, 0.04101928541316621, 0.02927108960706861, 0.005438403590702482, 0.07047563040208432, 0.03495652686744448, 0.041120435832248586, 0.01732309040943942, 0.031905733011362535, 0.036965025543806054, 0.029045492035126495, 0.07661988538119101, 0.03459775640118507, 0.02837204329308964, 0.053926909327386856, 0.035292452591801846, 0.06096102522626039, 0.05635785952871365, 0.04329002747732786, 0.07015262475056995, 0.06183042010713009, 0.10300471958133484, 0.0022513684187640227, 0.07804834058568363, 0.05144894814058658, 0.10502463296776819, 0.014988724743166279, 0.03511514154172713, 0.07830320271633326, 0.07925840710560161, 0.058979477523075, 0.056281855945745786, 0.013133619851883382, 0.06505836988048208, 0.055380722042173154, 0.07831398157342788, 0.08004178563433309, 0.016618787476252166, 0.01328149205824781, 0.06164531028198619, 0.08986245825766556, 0.04620829003772909, 0.03305168754811729, 0.06076746928175131, 0.03615570344751881, 0.0275993574365613, 0.036620653700083494, 0.06460597963943597, 0.03160928188252353, 0.018504070486092282, 0.01619327351480963, 0.06382715167297472, 0.02246735932966394, 0.07712827664950202, 0.03578019396011387, 0.016732984372685035, 0.07323167767495879, 0.027668429839034236, 0.05226413080949457, 0.03852389955652818, 0.07562841438958723, 0.009281927993851564, 0.05918921707498451, 0.06218176718140322, 0.003701129246638307, 0.03514411115658379, 0.06346861486353221, 0.028544849746169585, 0.019383070194312645, 0.0214239054419581, 0.058601378658486, 0.0387778653643064, 0.09045934800298945, 0.047134252850927656, 0.06129064987744055, 0.041105160039038434, 0.03737957104139271, 0.015658185039947353, 0.039269666998617114, 0.05514503126182864, 0.06823201168088183, 0.04770038416609169, 0.04015102434242445, 0.052160184169488574, 0.09433163900769527, 0.05478395487091715, 0.06023282801071483, 0.04374803314285894, 0.0407898229276461, 0.026235529409360983, 0.046309329374062444, 0.05714131849667719, 0.023154980698299986, 0.06897193770254813, 0.04522603508385439, 0.07124345734595292, 0.029588027842222687, 0.05081870292703952, 0.030758137131230007, 0.03140535693795931, 0.025861283967031107, 0.0036113581060612156, 0.11184998607683568, 0.01060293362130441, 0.02026522810000085, 0.01340085238729033, 0.044009805386585575, 0.062069627231047045, 0.0769078501710488, 0.05539136683388103, 0.09333282889377686, 0.044719390496010744, 0.06888797446604698, 0.03580911377925546, 0.05799277925923948, 0.03031267807067883, 0.03239449519183367, 0.03215659041738799, 0.04700846504420043, 0.028295174030767336, 0.04476151384052731, 0.04543363725045516, 0.050564890336846156, 0.011733678439932485, 0.02227332074976256, 0.05796362195284136, 0.019798270697074554, 0.05906526021839631, 0.03179347048693847, 0.05858789551101866, 0.0499456346545729, 0.011801142057764434, 0.0055691273976868445, 0.02674965101534561, 0.07923681874789539, 0.007775906387025551, 0.07579369785925073, 0.04908026173530568, 0.04964941143689137, 0.020600048742527445, 0.040787126298152634, 0.03832584284546395, 0.05029511247431079, 0.004288914994592028, 0.07874640756316724, 0.049463240579972347, 0.039593312333548264, 0.022639675486472347, 0.019793381140897834, 0.022446425977132978, 0.10267913221351563, 0.09507391691928911, 0.0116976895444696, 0.054047506888427084, 0.00930541912243972, 0.06031351239090005, 0.02064005385393337, 0.0188443552507388, 0.02818161681775124, 0.0236963214082343, 0.012807520162764818, 0.024076312509996277, 0.052889882917365724, 0.062447818026186964, 0.065379467973065, 0.11457213395906073, 0.030229088302040776, 0.09132642929832782, 0.013643391036068, 0.028815579472950874, 0.025387786088451266, 0.008171196264635411, 0.0577002332635945, 0.03177002053557625, 0.03505937800171875, 0.058882793396591186, 0.04777499346903736, 0.059524782738017465, 0.025305437382250547, 0.06729263466812911, 0.012969867600458524, 0.07250288291083229, 0.08483964108651684, 0.008573307197601085, 0.074110648654882, 0.05627157887624157, 0.04894157300793356, 0.07881092748815015, 0.08471198785569399, 0.044780516651489084, 0.018219246656724045, 0.06831760668466169, 0.057366123167617675, 0.07082380970279056, 0.024455853535102743, 0.012497829119374436, 0.0738898161498289, 0.094410699281481, 0.009800242016001815, 0.049585580991040316, 0.0454499127884065, 0.10599589455992946, 0.025180599524549423, 0.036852736206304644, 0.0357104339937289, 0.08962680195127765, 0.0884742456518354, 0.08988916408270599, 0.1453164144749603, 0.16935801554110744, 0.08874624516935119, 0.1326048247996838, 0.10448572841743309, 0.12657295491906906, 0.09611389659825834, 0.15060735475872794, 0.132961837094157, 0.16979497677135855, 0.1523080852723891, 0.13079794514323437, 0.20338615492707302, 0.1010533557423661, 0.12265450711692534, 0.21230881162468465, 0.11354176868354121, 0.17430691288844233, 0.07042378157136903, 0.09982313344916029, 0.0580013747657499, 0.20405868819404036, 0.12912585099618282, 0.09186485887414987, 0.17355423150283678, 0.08709104326103004, 0.12534766623209562, 0.1922137125004684, 0.12847038616816844, 0.12564365962339988, 0.14728405002144077, 0.13830510118315298, 0.100291917971786, 0.16716643717260132, 0.16395727953603192, 0.09761286253530173, 0.09077679185617356, 0.14212896777016504, 0.10137697426421989, 0.23526249122956108, 0.21108490955685416, 0.18138585642220514, 0.13229998309285412, 0.11634625569586793, 0.12804558275327568, 0.11462045112444509, 0.15027389200704713, 0.18983658763670153, 0.14947429539695864, 0.10792242182839303, 0.12775107557254453, 0.11466026471386995, 0.15663153311658293, 0.13101027407232793, 0.146325551454098, 0.18281520794956915, 0.15917777955051393, 0.14932130763847984, 0.19055974399370534, 0.15699916338968664, 0.19674599591282108, 0.12127934864932492, 0.13122332312407034, 0.1451118843209359, 0.16668481301636467, 0.18227156131498276, 0.09565288786806407, 0.14998999514406727, 0.14482426427064404, 0.1148810359318891, 0.20750536373065365, 0.209754751093926, 0.11956638371151303, 0.17558059534959256, 0.1369821899119885, 0.17626838908801157, 0.149767232097445, 0.26277869939804077, 0.11801263482700433, 0.15440477599059382, 0.17020285730400395, 0.19208556131249477, 0.25540591518004097, 0.16655217255315474, 0.1482802554364166, 0.19974029653014677, 0.1604321412742138, 0.09377892189208539, 0.13176436505971417, 0.17168752037950102, 0.12658924194833926, 0.18102948764158835, 0.13883577028830207, 0.16300270333886147, 0.2471248724407727, 0.1371204994258381, 0.08932941427995121, 0.1389716129990355, 0.15704293765368002, 0.14844170080557947, 0.15926045575930228, 0.15325656340968224, 0.13568000898005503, 0.07582991849631071, 0.14654534207957406, 0.18648090802373427, 0.17411695372673774, 0.09282331913709642, 0.07510718348766528, 0.16428665137819706, 0.14555540326381886, 0.239778027959889, 0.14179976446734321, 0.22806584594711182, 0.1769077201043406, 0.09439538518387465, 0.06490003482829179, 0.13014105539168083, 0.13469593839779978, 0.20104097592974865, 0.1487577886831376, 0.146582160265215, 0.12289400918469315, 0.1297459532056124, 0.08479981217533351, 0.15680249329776536, 0.12918664773385372, 0.07564038834384373, 0.12706418581787618, 0.12824581515404487, 0.11964144500633402, 0.13279556537107115, 0.14860023504063008, 0.21239622225684507, 0.1018411775810584, 0.18436647470920317, 0.1096527616403276, 0.11235043301337189, 0.14642630733789938, 0.11323740195122459, 0.14768641472103136, 0.080708404702525, 0.0933557962097468, 0.13780440143760175, 0.2357552083389413, 0.21563870471812066, 0.19893942821410396, 0.19459629191025613, 0.1165952189495006, 0.12494805944903244, 0.12391790101725249, 0.11507713911874641, 0.21260888826462532, 0.17108451725254137, 0.17856928820331253, 0.26200207010392224, 0.15867043016177995, 0.21531555350990067, 0.14247983603948547, 0.1746624542941009, 0.16163584926436025, 0.16151198816876258, 0.10818168130372802, 0.1782346763197453, 0.17168775020587831, 0.26250137556945125, 0.10556129288048514, 0.1962181919765088, 0.11013197261960277, 0.3257667856110681, 0.1122687527188851, 0.07399856999155975, 0.2006550667987716, 0.2145646800917964, 0.19797996437597662], [0.06974951694569281, 0.008606658835384634, 0.016643348255104596, 0.02495700144208968, 0.022012701468361963, 0.024686601133115833, 0.04921121297464256, 0.11575822192694872, 0.006652036728712941, 0.025290745731082656, 0.022331215929420247, 0.034855717357488415, 0.01897250835393225, 0.02667440011376335, 0.010606517955180137, 0.05492075519155591, 0.018590935280606635, 0.01948797252900418, 0.02877662581722102, 0.024747275296718847, 0.0597733820998861, 0.03339014519306441, 0.03317734895033702, 0.0525440133717512, 0.03131603491642783, 0.045499938329862016, 0.07340516594629135, 0.02066990446990296, 0.021915871785172535, 0.013358065419109359, 0.007902887854499803, 0.040811472572386265, 0.026411490229469155, 0.055923150596959945, 0.06362700737231682, 0.016683384010027495, 0.0320169938758256, 0.02349780695963531, 0.08961952411599698, 0.028742077167055784, 0.018697182099605282, 0.017610367635385166, 0.034314162142935305, 0.06694525975974337, 0.011728378069106371, 0.07282817916524026, 0.03561355451482438, 0.07946708179529637, 0.05543283517322233, 0.03482419666984389, 0.015901110563126784, 0.04057048812448498, 0.05626684062242989, 0.058530994330442725, 0.03971299058907936, 0.02211189836323742, 0.013736058946608776, 0.044986322341907414, 0.04278959586255012, 0.043979050786865335, 0.024241310611907995, 0.033851828080632036, 0.08009969422052945, 0.04141467488220623, 0.007742881773024678, 0.049450174950423746, 0.03910243000474669, 0.04445179598405958, 0.02028881786240926, 0.04742123321780274, 0.0014552831247959647, 0.04375901884369312, 0.022436667932197455, 0.011920563673840897, 0.057278563148312034, 0.048358714162942865, 0.009683716212279134, 0.10077022496731051, 0.019590720241408677, 0.01906966553970931, 0.039529857270780115, 0.014260171296735926, 0.05226287442529875, 0.005334215633000338, 0.04700851100947588, 0.042525659420437394, 0.0624172741006459, 0.040530291491097985, 0.13118924753319833, 0.05464896634821931, 0.07258176698439545, 0.0481431293601711, 0.04883300685774415, 0.03638349203092437, 0.03548767860798586, 0.0717870120499884, 0.05216886011523105, 0.033265878070866874, 0.01125782484098548, 0.026116799187636184, 0.016057018074207008, 0.013694755316171195, 0.03965564890794697, 0.008878477364628306, 0.05990747813015215, 0.04498824905303698, 0.030966627959822936, 0.030817418930030642, 0.04192195532302703, 0.013629452066285717, 0.029449756632769303, 0.04287635915041451, 0.046250991778628486, 0.026803085648064173, 0.01666957719041215, 0.04303158771607184, 0.0666440722923125, 0.03998044720520416, 0.12512582249098247, 0.03434798492479228, 0.08404412006418552, 0.03327454252529048, 0.031280427149707274, 0.09669018623929831, 0.02212833669487267, 0.04172936464930254, 0.019354226983963482, 0.07438372069549176, 0.04036973095348766, 0.006788039839105501, 0.03170496243382654, 0.012194918911723841, 0.03209077580381305, 0.06060454536289458, 0.021854088709299124, 0.02632138679825491, 0.09023851549793636, 0.03569572893602233, 0.02802768102546613, 0.07698098092430061, 0.04318141153142337, 0.05215359964377938, 0.0843861323571013, 0.06189566398520143, 0.00970790352326848, 0.014978585569488426, 0.010890224253788832, 0.038735749680669083, 0.021249630015283343, 0.04034760250379482, 0.015987876723820887, 0.09565003036010651, 0.027216028106669267, 0.012459344692498207, 0.07084660847941715, 0.04785172866597291, 0.05529313904022979, 0.023056448384698842, 0.03789658079885187, 0.025180609100648475, 0.03939551609237829, 0.02766780930781557, 0.03530558333882401, 0.02789699983212256, 0.024835624386586493, 0.10796149231253133, 0.02936356982606794, 0.024890834428069573, 0.019189887717666648, 0.06891781359069771, 0.08457085913828305, 0.028472868124804193, 0.025379198242820082, 0.035142092514903314, 0.049623678543514786, 0.06486959049418088, 0.03983500924321913, 0.04214582153626027, 0.03845411660750547, 0.00733353944885875, 0.08053629538945614, 0.031945761105406194, 0.031031054039035114, 0.04513968548346912, 0.029073266552821286, 0.00825690235116429, 0.039604232916908885, 0.026161234202464263, 0.09569131483834598, 0.04180177527990553, 0.031011334935864134, 0.007913769175854303, 0.06333516234712255, 0.1360454635634538, 0.021162148519989946, 0.05653280336710234, 0.08493557061639526, 0.022366417669540933, 0.04644653572130107, 0.021399930720367742, 0.01779368864522586, 0.05210204192647531, 0.03098955122573722, 0.0229141571288628, 0.07216565866744326, 0.04918375638343635, 0.06405252324897917, 0.03843150169198071, 0.027703713933606783, 0.06037452363318974, 0.06810191462958051, 0.0507694281517498, 0.03053791175085691, 0.07153820201394058, 0.011339751241217938, 0.009460982851563923, 0.01772506631940844, 0.015175005725224414, 0.002747431656556024, 0.021021408592200568, 0.010195159383358495, 0.039673391504273306, 0.038285596416361874, 0.034975303682468595, 0.0342984113752121, 0.05217187850165272, 0.028245935644654017, 0.029835326769839854, 0.013543232700847571, 0.06272478945433133, 0.07861412716128173, 0.0235970459893466, 0.029563053375891143, 0.014145561670433852, 0.0303721092566247, 0.044261189478058974, 0.01621397321052369, 0.054612381819395296, 0.08062349917787699, 0.11535944251884377, 0.024251062911184087, 0.009255228872080485, 0.0396982855313728, 0.015549858292234282, 0.020964440378931262, 0.055005607090049216, 0.08522428617241883, 0.05397406970000556, 0.034457918541926535, 0.03009518379375579, 0.05091379742108045, 0.038675014230032126, 0.08468551185703085, 0.0325816887761316, 0.013235659890567825, 0.04250946049127848, 0.011444498443104809, 0.05327920880048506, 0.05806054739702133, 0.058081982537142696, 0.04360437250485824, 0.049456755645693316, 0.04626204259693623, 0.03972173548273502, 0.10282979872558387, 0.03377594707173205, 0.04446023444254552, 0.05394195912465934, 0.058970958625357, 0.028445853949374253, 0.02466083568100247, 0.04545102361589671, 0.047983388536639755, 0.05501792961431127, 0.020937711571253115, 0.03110467700377828, 0.034971699238784855, 0.028805635651693712, 0.027320777223775947, 0.061251062283953356, 0.025131043211947528, 0.09966284487276308, 0.022817063145339492, 0.01868414711357365, 0.03853082499136368, 0.05407880541057356, 0.03853295088535355, 0.061448123080716024, 0.008302563106671216, 0.01442349166609347, 0.03740191016526472, 0.051042592122910485, 0.017015519514379483, 0.048898457579555056, 0.06893547957823162, 0.04106232806319191, 0.019328540055862358, 0.062034605521588564, 0.04233954218967308, 0.029046951432622252, 0.0651881834792514, 0.06690009887660704, 0.046225075024150075, 0.025491008775368817, 0.05323415900009775, 0.032218773774201834, 0.019919961848626697, 0.03340861174247919, 0.04315595059925991, 0.02801712241864974, 0.041618174647972475, 0.012678811645826266, 0.023702942323119893, 0.04266410683011336, 0.0473802053790179, 0.022353562714171507, 0.02892488489798721, 0.03921221040429608, 0.06371092847398212, 0.027315146477532484, 0.1050659251068869, 0.011933889773283756, 0.025230441204903108, 0.04328330122535268, 0.01929620156935867, 0.048141566540805564, 0.024967914364571055, 0.03052786450772997, 0.017609408110260003, 0.05947934989366801, 0.016142292278668573, 0.05726505701820697, 0.013810345535016349, 0.028116175672039393, 0.0094045307900336, 0.054034123332389904, 0.004378642563918425, 0.042943755735553084, 0.05403632583517221, 0.02727839915502456, 0.02994550361989006, 0.023395034349373272, 0.03547789183475318, 0.10833329776482237, 0.018108629306117376, 0.06687356925178921, 0.05147689119762471, 0.021851256099199096, 0.06263402335706257, 0.020096386151929057, 0.022157022857197353, 0.032845962296931014, 0.17250295968786364, 0.08970349501337736, 0.1208053011026594, 0.08621532049390578, 0.08315790955337786, 0.1674353953210577, 0.09906863643517418, 0.18623062709887184, 0.12131753047147106, 0.18270447760099368, 0.2518585756901772, 0.2080675037277322, 0.12360143775661146, 0.1066494748116501, 0.12961087658280326, 0.1252297729614281, 0.0978075637812576, 0.2444827884075142, 0.08261833850654864, 0.1626469474285841, 0.1959046475108593, 0.2282076947871716, 0.0751890323214954, 0.1699021065066899, 0.11132381390780212, 0.2520663080917251, 0.1343770466384388, 0.08657843084825624, 0.182667919885247, 0.08452189845904227, 0.12256668279728583, 0.16219189120156152, 0.12883450775857896, 0.14967168561152874, 0.1433602242820686, 0.1194531252727874, 0.2681853189583748, 0.11076631640354473, 0.17780030446667827, 0.13732440138776458, 0.10082669330820923, 0.1656420141338341, 0.13800831872128672, 0.0977472113745828, 0.14318128146471518, 0.13301477376972476, 0.15029037821917765, 0.22641181615331482, 0.126531494240607, 0.13405141330534412, 0.12961702060795602, 0.1889581146139291, 0.19727304908296756, 0.18589030019938949, 0.23077712304169135, 0.09239951163650521, 0.09262921543972147, 0.13021372649217808, 0.10920009560762875, 0.12081256361618159, 0.10390513336225864, 0.11559440168522059, 0.14735730334876046, 0.2132273970111724, 0.14433387606855363, 0.10773488350452916, 0.1072073323772319, 0.1226067491957257, 0.07285585792194452, 0.12400123606165572, 0.14750325842009437, 0.1438902498733613, 0.12915499298082245, 0.12238249227765108, 0.12190348048123623, 0.1142317764160614, 0.20762004709291845, 0.3296414438274599, 0.12238844478082274, 0.16807877128162693, 0.11818626099416327, 0.11555086490848374, 0.1529061241495994, 0.12900916048355643, 0.11366697043300637, 0.13431055020661126, 0.1621143937471413, 0.14713521445951155, 0.20763083361089232, 0.0939402676698181, 0.1394300553346834, 0.13216833854394575, 0.17761019208738882, 0.19679908580597372, 0.10592689302058951, 0.21142980234036524, 0.11015192921003027, 0.1767612287714597, 0.15390274325205436, 0.14302129166260844, 0.1527456593729796, 0.11442706754971897, 0.14765356487083822, 0.142471301820009, 0.1396699327855341, 0.16628387324031324, 0.1468390908332602, 0.11085021835301193, 0.1382463269176022, 0.1615920443568499, 0.15200915776433485, 0.1463614196907128, 0.10287209443988339, 0.08413878554898886, 0.18591073942520928, 0.16769917471514595, 0.13046530976651177, 0.08263036608695984, 0.14369952462373242, 0.1764216832816601, 0.2180403443954645, 0.1879195138932236, 0.09375462924400646, 0.1265582153874059, 0.14197945805086246, 0.15946605843642067, 0.19534111323375858, 0.14018857431027199, 0.11291014451173045, 0.10674563416790579, 0.10804871142271066, 0.08700601516231414, 0.10479659923622686, 0.17109861327034814, 0.11944053844819147, 0.10381013079876862, 0.2245154574273094, 0.13515435008993074, 0.12638756930227243, 0.18280311908212402, 0.14566136854550532, 0.12435818706909496, 0.3043850877832982, 0.1721525204277808, 0.2424287534649334, 0.07939719159396426, 0.09335741265526704, 0.13295471247646118, 0.07536043683367391, 0.1452213582853156, 0.13151989108131779, 0.13479402829562465, 0.07172774748816606, 0.19308450932223953, 0.1694261820446099, 0.13137329249612748, 0.11847576562074885, 0.10330648161470891, 0.09301733090392045, 0.20757300929436762, 0.141329922743382, 0.1381486660290149, 0.11682345186390224, 0.12541618513604327, 0.15723124206546815, 0.22768070290405906, 0.19010519338471277, 0.18480878323316577, 0.1070876694434593, 0.16072084916935814, 0.2001053527478249, 0.20376518458849002, 0.1869414494402947, 0.13979249153166048, 0.10847222780989063, 0.12361108280357816], [0.02083103191257725, 0.048414129132945696, 0.05223208535162192, 0.013018374372604153, 0.01921691146919564, 0.011575910292806165, 0.07124904212692092, 0.027674864977598194, 0.04082469908039897, 0.006726175845195089, 0.028175815616944627, 0.0355759549195007, 0.0076578790509712795, 0.0637290004881159, 0.027281540115514112, 0.027354726410140435, 0.0040625206912086615, 0.030904699327243917, 0.029501036643200827, 0.029628858413367026, 0.09066315803436503, 0.16440749408737307, 0.03298806011556618, 0.028060988613194036, 0.04698083608321125, 0.06148276174621237, 0.009001897959669512, 0.01221639522907114, 0.012612700173180672, 0.024084578598699263, 0.017918681635731654, 0.03862205074138699, 0.05696656234982995, 0.05955849826756505, 0.04794669675550634, 0.02211061133552463, 0.017701915142336683, 0.028310036136498375, 0.020935034093957756, 0.022751009129288218, 0.032364548814873544, 0.04340519347498494, 0.02465890322421347, 0.042109577916562564, 0.0651546441499264, 0.014940280215664497, 0.01424920283288004, 0.03268713694846919, 0.009227256129135289, 0.016460856535441933, 0.0023331504593032504, 0.0120355898604518, 0.08025609873115055, 0.058852337571161414, 0.027167270440728437, 0.027016435389316855, 0.01676317972822055, 0.0669932475073203, 0.03055697201841301, 0.0416644616803575, 0.06521951647535448, 0.05451796148272772, 0.02390890889200232, 0.030468080921338934, 0.0449327536438021, 0.02547973196112341, 0.03615318301824793, 0.04702766320758289, 0.030937171879134355, 0.046862682342649474, 0.06257814107342594, 0.07071135565638542, 0.03628762761851953, 0.023286456707865003, 0.07953625953485889, 0.08189758000474784, 0.05439132331840454, 0.00047578300514179587, 0.07949969415823299, 0.05719327841014151, 0.07043321977459616, 0.017168365546592304, 0.021106314116848574, 0.061847128484758644, 0.03971675208078758, 0.04354976575761553, 0.030950222186924472, 0.026350992266088728, 0.012672188815720862, 0.008699391863398976, 0.022278158595004392, 0.03756089256175103, 0.01768700324089056, 0.014391630069322646, 0.03894792156173818, 0.11311162563581621, 0.03325228767109013, 0.04790772969323782, 0.04347467764971718, 0.00615054073052541, 0.03316013495467844, 0.047605247537214915, 0.035611692921168385, 0.03880061051477829, 0.025351728245075193, 0.08322441364608466, 0.02449075841615277, 0.06001543141000214, 0.04813062297480722, 0.012252548833437746, 0.034532466557838266, 0.03304328739402756, 0.019486210526778333, 0.02956055592925799, 0.04998460171684142, 0.04224423702145296, 0.045686339013158314, 0.15513631334948927, 0.04080730122363856, 0.08276688295506662, 0.016275365581555713, 0.06406414863323012, 0.047086180833679055, 0.009860080186157458, 0.06654387565269586, 0.046803141989174395, 0.037782357089341655, 0.008319141249352647, 0.022408761264335726, 0.06360630384616314, 0.007206483766616833, 0.0963443358458819, 0.03338605811398837, 0.0389649095614591, 0.05443008353693351, 0.03437816112812969, 0.0028973397415792274, 0.08651167394653445, 0.06678058916041929, 0.03685798390858597, 0.027693557522950635, 0.009092570211167538, 0.03069122509670354, 0.03910103189428488, 0.053990559742575696, 0.09856653474872151, 0.015370995914112898, 0.028037385444246957, 0.013814617432804118, 0.011883346164869446, 0.027038763021870006, 0.04054462499616127, 0.015487574386380374, 0.0641656208092407, 0.01739378500309202, 0.050572704433673815, 0.039966914262021744, 0.03715378577790914, 0.04757495259024924, 0.04199830364556082, 0.04554909436152347, 0.017227496043027892, 0.030730760979255846, 0.016991876125816378, 0.04030274039494895, 0.017756659785405766, 0.009954226646392096, 0.01677343189986723, 0.0540303465189232, 0.007500640462122618, 0.02934478343494477, 0.021388328318754514, 0.06179290478147807, 0.04323611787009624, 0.04430996246575829, 0.06456238157566517, 0.016142372717900623, 0.049067743858622934, 0.11187388802007323, 0.011913107723117837, 0.03913775431893526, 0.028347804271165403, 0.051167280593466376, 0.024134895253566005, 0.02496020177439336, 0.06315392892687552, 0.10516067486136191, 0.05867259419192711, 0.04248632080552559, 0.049736917830042304, 0.05683290298968073, 0.08568914832487222, 0.06736247890418576, 0.01638736572086571, 0.019062958439932238, 0.010204431920072005, 0.03716913051903248, 0.03362188295971963, 0.022938294644137065, 0.023930422556135925, 0.011737068378997427, 0.05404626199555013, 0.012137504452238641, 0.012500900174340895, 0.028175700703755985, 0.07145741804232521, 0.05062821133422756, 0.01781903657942049, 0.030281034808966423, 0.023704811577655138, 0.04153434164641846, 0.02477418796549882, 0.03390988988441325, 0.031913541362530766, 0.03204349477234627, 0.017963861671066093, 0.05870521804618259, 0.06356490445473502, 0.03947503218847898, 0.08251587424667613, 0.04876545705502072, 0.0053026207305881526, 0.013841922721645285, 0.0434257859183896, 0.018822041024724324, 0.058871811526196624, 0.07890545507712711, 0.053312863042998704, 0.040211123940084255, 0.015729885124000573, 0.06346529387238045, 0.030768350998480475, 0.012960246493739468, 0.08650187568198289, 0.008465409459125613, 0.022606624538199078, 0.0014719417067094436, 0.039445327129215, 0.032964939582011396, 0.03758992729408126, 0.04686411492706788, 0.06879513227050343, 0.07857281203952529, 0.03477499084246736, 0.08809565266053523, 0.008127349222289219, 0.01932766863084849, 0.03627799789331133, 0.029296946989732887, 0.02779233498468755, 0.05097427623226278, 0.08313406889717426, 0.06722515764375848, 0.13253452857175183, 0.08970207775071745, 0.008225440077723996, 0.0852022305010788, 0.02977674977192956, 0.02539932720303055, 0.058958352648562966, 0.004681523564466906, 0.052308257473933126, 0.012809971644122516, 0.07371981357855183, 0.002781285081929978, 0.026245687735236944, 0.036429212158245426, 0.06514350523150737, 0.019524610683982892, 0.01107803070842619, 0.04733727381174122, 0.0552112250889261, 0.0599576875327095, 0.028393011119577195, 0.018456149771208727, 0.03859642126988019, 0.04795199808394236, 0.06101254846960787, 0.035897692695500395, 0.04356335615739227, 0.033497504754773075, 0.07129956562552722, 0.017062011475284255, 0.011582353092249364, 0.02922678674240747, 0.052409024849053354, 0.029770960062441808, 0.017041692908312527, 0.027540236516224764, 0.05634504287774044, 0.030931941413831328, 0.021878599692436478, 0.018008304346773415, 0.03459294153858097, 0.0425397630991234, 0.029606268395699804, 0.04605076703873854, 0.07141228780270585, 0.018122447617051583, 0.04837640696355412, 0.016731973136624983, 0.03393078876298762, 0.04163625049254587, 0.07262285227977461, 0.06352799816898282, 0.03020623398403968, 0.06730732823451681, 0.05936921709367345, 0.018353988116066304, 0.057615427330376646, 0.03970391244717664, 0.02793343880424096, 0.07006831677450288, 0.036627751504701954, 0.03824028231564068, 0.06064123714402799, 0.03073159218465369, 0.03463326457647547, 0.02447944712795077, 0.06617783118159541, 0.03807144036756889, 0.016630558417208733, 0.029695515723658666, 0.0528103438386273, 0.03326322357620924, 0.020061341459832845, 0.02503438398332125, 0.11451915897909673, 0.05630275865475978, 0.022176808993061705, 0.0646220368423289, 0.03477750744129862, 0.01964647995097743, 0.030726545580452493, 0.06584313502835651, 0.03010632271217483, 0.006699316802569816, 0.02797651209778363, 0.038832832172873526, 0.04242557769400939, 0.0644511379481804, 0.03123845893799538, 0.018350278335292975, 0.03527841020014978, 0.030619984665404887, 0.03540071613726116, 0.035232923729645635, 0.03144946828063938, 0.04588149608142915, 0.028169368987061807, 0.03664974971944767, 0.030268407764754472, 0.07335380741184758, 0.1287138182669878, 0.17181096778761956, 0.09273384006754046, 0.10694652540428985, 0.10985236584899888, 0.1565509406669486, 0.1639530200871729, 0.16086266736590094, 0.10384190812586777, 0.2025539842584441, 0.13730501936328027, 0.08020190567138695, 0.1587703280271061, 0.08907680444779897, 0.11456978206913318, 0.10389115225764052, 0.2007795254429502, 0.14838395309784722, 0.12613521227913518, 0.13266962051631945, 0.26590727990673435, 0.1467689018576376, 0.12016124332383757, 0.18030593291886393, 0.11140764690935613, 0.10832521553722121, 0.09252600041368315, 0.17574219393634027, 0.13399176569955965, 0.12696712247786984, 0.09887587339166673, 0.22797914011584175, 0.1436386512772691, 0.18866473358244668, 0.09869643261716252, 0.1015928348586444, 0.09748467304293187, 0.0676759927263183, 0.1250183709987229, 0.09661044414725997, 0.1703738940939788, 0.12549395838211622, 0.19408794660722056, 0.14219437635714008, 0.08314757502727932, 0.093537382030439, 0.11619855394406665, 0.09416830140135943, 0.16329427640284264, 0.3658710287943963, 0.15046780418244102, 0.20486882617396696, 0.17391381785273555, 0.2327257902511666, 0.20381691084513742, 0.10777920935182803, 0.2071718703354559, 0.11837795151457672, 0.11080677350682598, 0.1376266537174102, 0.14274922319717948, 0.09537279846206789, 0.23974671028554442, 0.23238958490471687, 0.16655378133779572, 0.16911996137951651, 0.1502870227540693, 0.2779194466289013, 0.18787420745338165, 0.18171407913248386, 0.19488567396277384, 0.10869172732195548, 0.07916330495068143, 0.17081024245389048, 0.14232790548234217, 0.13929963652645388, 0.22036658569930062, 0.14620423377040895, 0.1948614349408496, 0.20530937269570368, 0.07769247742309686, 0.15724362204632453, 0.19047965716210105, 0.11768366901143906, 0.08851218232584578, 0.11243169962037956, 0.10506120600527334, 0.11659233079802607, 0.10559265652010519, 0.12018112330547265, 0.13731168432822152, 0.1308615917279836, 0.08287690850275178, 0.12452634336847453, 0.21060250399093475, 0.15386548073541734, 0.12587192318131848, 0.13589109684671127, 0.17974249057231412, 0.12143345489617317, 0.1469515831840615, 0.157163811006373, 0.07777391256944788, 0.1276965530949735, 0.18025371636594498, 0.1528887799189937, 0.11226219500625327, 0.09394274979469278, 0.15829109406519323, 0.13947271111030735, 0.15017753346793114, 0.15153027620286713, 0.14425431017673787, 0.11726141666933415, 0.17607783237772603, 0.1120400601517289, 0.2899905408342039, 0.1210860187007535, 0.10326942594181146, 0.11979683062001584, 0.1539676308992409, 0.18766511141532854, 0.10102511008059788, 0.15104719647957435, 0.1312256979966356, 0.0809379016620017, 0.22961329758888294, 0.13789291523637312, 0.12343753324521166, 0.11242961586122552, 0.2264282410784114, 0.1989661033956274, 0.16598171284121854, 0.16926550276337132, 0.21882509422158042, 0.19775044443386217, 0.15640179866984968, 0.19689328397714323, 0.16401761662094824, 0.1213454390545526, 0.08918270078157225, 0.1668305382613213, 0.21572672822062047, 0.14239521396736946, 0.17636146877081166, 0.1740119383940774, 0.15172095548722053, 0.13095874699854082, 0.07015151392307974, 0.15443445423678046, 0.20628861692403594, 0.16248340297850872, 0.17846341485217695, 0.19245014255565984, 0.1939819813255341, 0.18626982015707802, 0.1441187279358987, 0.15925800427794456, 0.19406675661523498, 0.16939134036581363, 0.11341842852773205, 0.12011332452417382, 0.12175525778964644, 0.14703835030236553, 0.10342121860312839, 0.10779487584987957, 0.1415818277746439, 0.1156405967870547, 0.1262865529485768, 0.0808150364807056, 0.08672420971936758, 0.20330482703303138, 0.12040590882421502, 0.10255234466204721, 0.16182311179657138], [0.08013667328463447, 0.10353510523395193, 0.07885785037351233, 0.04129291286752109, 0.04739505599343008, 0.04199099516676318, 0.0444256340814454, 0.03562286631354401, 0.048360533621763034, 0.10685816482310334, 0.032926401528980465, 0.054257162170664924, 0.09981752568555456, 0.0955231202345702, 0.05347529666558389, 0.03495245511012693, 0.007097270750936362, 0.06002150648724168, 0.026979699558127793, 0.019644009317421628, 0.05353025198283215, 0.04134874918588227, 0.04537780859297322, 0.07433269923973469, 0.07809523282752884, 0.026393416300115567, 0.057311554724771174, 0.01331293039144047, 0.052002856522918715, 0.04433872906731502, 0.06439063232392073, 0.05302234718035306, 0.01485289160853192, 0.01949083386740137, 0.059839422709398696, 0.026429901237509427, 0.017787010273745945, 0.05460321557738128, 0.03760773500788116, 0.06449075235474495, 0.07607089911377238, 0.04508215611079528, 0.04737640558291347, 0.04337811992774087, 0.0912516667777973, 0.012822889801745695, 0.08570793280077559, 0.021614680487302043, 0.03440214734103891, 0.02403691069283072, 0.07287947641265008, 0.06115558091551066, 0.05713327074303262, 0.004545035903462239, 0.03968676739943124, 0.06263175573680671, 0.05421691574156285, 0.0356399194307385, 0.03508411115035415, 0.008329468114571947, 0.07206808970940691, 0.046614795442550414, 0.033787415407958536, 0.019301131345151414, 0.028979935976226005, 0.06622895988966189, 0.047363703845128904, 0.04122857297320039, 0.06111733780633058, 0.03435985928761863, 0.02918056482749601, 0.034887054184031104, 0.02693822738834687, 0.01618622933634587, 0.0388950385123251, 0.05079466691841522, 0.03803397866807157, 0.019574871797475125, 0.031673918635914886, 0.03888627063603171, 0.0391629969160403, 0.052117631815734415, 0.10984534848361246, 0.01210165249499222, 0.03224605416518546, 0.03742768519347714, 0.02871600911021233, 0.012983003135530219, 0.040243108110922965, 0.0032994645598885277, 0.022900524594250227, 0.02136163206981315, 0.017969220456096436, 0.03882796751455434, 0.03046793536463332, 0.04566350193213552, 0.013519484932804781, 0.024519364139245405, 0.06438439636821709, 0.043272568333533504, 0.10683043244024439, 0.01436976208952406, 0.0840504173069231, 0.035844847950483524, 0.06379753854426165, 0.021575740238110867, 0.04456570559752084, 0.012630714730720126, 0.0275544359559013, 0.11246829564052244, 0.0037169800845966226, 0.054809948234187986, 0.01699027308683482, 0.015078757311247531, 0.03709423010267558, 0.019113240620842385, 0.05918741293792283, 0.01660590379258558, 0.05588728236034513, 0.07603389706702963, 0.03077480337402273, 0.049955655084622484, 0.0355127067004721, 0.03358118453874223, 0.02412198475682207, 0.008423785986979643, 0.030158472232400414, 0.021674713052268473, 0.01576741385619126, 0.04112790901994994, 0.02083856638731255, 0.05237745436569376, 0.03028951923272783, 0.07808529666715092, 0.07321136102320687, 0.02397880483899386, 0.04435406997799874, 0.02590345710726275, 0.012039723862413199, 0.008416497617990019, 0.019417572879202424, 0.011094913371057521, 0.0459664284191545, 0.014114015127321886, 0.016017057970466635, 0.049415735467787714, 0.05477585349111788, 0.024686333002342332, 0.028142699551197792, 0.04540318525546501, 0.01961687448314361, 0.05134734572962888, 0.020684046452985178, 0.04100846442123575, 0.051643159090270924, 0.0451493113782377, 0.03894011129535014, 0.007258750115250869, 0.06632407736634055, 0.013866909636905598, 0.007885606826147846, 0.06961889895460299, 0.07868527374680966, 0.019351392458643646, 0.011158731367979801, 0.05098529257661393, 0.04724419029850153, 0.04143882197357955, 0.026534447341316172, 0.011319648136474915, 0.02065513429472283, 0.031316678430284225, 0.026230584311809753, 0.0287076817344754, 0.027476946162360332, 0.04925205312188595, 0.09842051839035365, 0.033257546864690325, 0.11949353641079319, 0.03231796683863767, 0.05854578365782096, 0.03009332220009979, 0.04874285363081483, 0.018108707830129613, 0.09289320933842853, 0.05115771598573174, 0.028003487968817357, 0.041496339854934526, 0.07979674475087274, 0.04475552303295943, 0.010764495818875732, 0.05614596343929729, 0.07903761290494474, 0.06750787473133496, 0.027385233946505095, 0.04527110020600019, 0.012080765107736714, 0.021819411739406568, 0.0610980132384406, 0.03395817257584103, 0.061111178459419366, 0.014678782805980695, 0.0848410277056598, 0.041911164974613536, 0.024593902579058084, 0.04192423826504139, 0.06148738125639577, 0.17637524303169022, 0.054368589659251516, 0.006449073224493693, 0.026187386528979388, 0.020590715876389897, 0.04102966207410059, 0.04548938163826543, 0.02937251007214429, 0.023184199291732044, 0.07457171101123095, 0.04629657784056279, 0.1021257792449286, 0.038284585180301825, 0.05332898536336519, 0.01731710534753098, 0.09007897002682572, 0.0434567128878928, 0.07091587814953058, 0.04851229180912337, 0.04882554133092204, 0.06013825828690202, 0.026540736923174515, 0.087010427828758, 0.05104941030543658, 0.015741368781985537, 0.007045367336456454, 0.03726503323583353, 0.04852314727501043, 0.015251239134569564, 0.04094751063554038, 0.09638244872011485, 0.07522598840296268, 0.10315932378533388, 0.032588154558212526, 0.010509932462516572, 0.03268927050333831, 0.023081419020590764, 0.09376137847861937, 0.013882912256033912, 0.017609963524005106, 0.039956935966807994, 0.008552644848673335, 0.012149821230841261, 0.09182289257765779, 0.060689516005016146, 0.026246428925303683, 0.03443305132790439, 0.061713013302294485, 0.08119284040144376, 0.03151688401797607, 0.08425056543802062, 0.0867291739691169, 0.024184275365945314, 0.018050002512492, 0.02479830441335517, 0.04714736444575172, 0.005694181675226578, 0.028906981423196774, 0.05482012954270167, 0.030737876020852598, 0.08587913046921454, 0.01802620399112423, 0.030408019628075343, 0.06790752747967359, 0.007297966156094786, 0.0362337869592011, 0.032302361627620076, 0.060613282595670996, 0.02808196410056084, 0.01824742337057908, 0.015358730846445168, 0.019261434584135012, 0.042743496521706545, 0.022117347163598866, 0.011401925979542636, 0.07806925478601649, 0.032855163012901624, 0.016435788223339666, 0.011398418254459338, 0.0782959248810526, 0.09488581935124052, 0.027513555589041887, 0.015054371775007777, 0.04446472371778181, 0.04130967104086473, 0.04902598823631003, 0.05152733042655934, 0.025956573813492735, 0.025844274899892272, 0.09507737963670686, 0.04434596859819947, 0.0421136113694839, 0.009564144251447533, 0.023164485934220498, 0.05992363492447523, 0.01894380112418965, 0.017311325214142283, 0.02916934546984492, 0.04352624685834012, 0.04100965951839763, 0.060537505008640795, 0.02547378328839137, 0.014245326427983181, 0.01941999180182334, 0.023047255329607476, 0.06140357506791912, 0.04943604062822077, 0.04723776282081681, 0.0039010580850674984, 0.031906420575274576, 0.03902025175310912, 0.025462899094207153, 0.035852631403794216, 0.02827757699114661, 0.03417870630660365, 0.046850750523228804, 0.01666245065749653, 0.020996614156531233, 0.021549846466270187, 0.04909393257431446, 0.035739062699459256, 0.017778998909277782, 0.030145582803074392, 0.017918967003483447, 0.020272599781052243, 0.04894533449964178, 0.0085915113619018, 0.07644232152210129, 0.04397965982676514, 0.027194029891923554, 0.05714206543240336, 0.11297349998306845, 0.022331235081618352, 0.023310389294619524, 0.033202710291070324, 0.06054326982027101, 0.02733553016197778, 0.02955646885018195, 0.025694667504379348, 0.017438026580719218, 0.011273460695520045, 0.044410986480333155, 0.024578253317984845, 0.010625487249795227, 0.044646696412875775, 0.2371044270694256, 0.1610544498168653, 0.25934389822425385, 0.22104969097962304, 0.1722350127754673, 0.07479447405785322, 0.10875039433519687, 0.16029781541757046, 0.23702533615212287, 0.1425020525892896, 0.11285953674345248, 0.16395228464276562, 0.2677650431231145, 0.1897730789477787, 0.12532977041818444, 0.08388050666619694, 0.14061991245515887, 0.16065289717047446, 0.09552505077613939, 0.05550279432246762, 0.06410519179377346, 0.10450188521175616, 0.2163151756770188, 0.13200716896643563, 0.11028389551586683, 0.13136033028844865, 0.13313051433332507, 0.16167968481538758, 0.08581559113677471, 0.18295961552329604, 0.16752231565694656, 0.19724001537167257, 0.1355642990599717, 0.14958052114853937, 0.14346991275106707, 0.08814544071473422, 0.13812085703736351, 0.18717872219220286, 0.14178686354669834, 0.2536196126452377, 0.1322428022901858, 0.15465637458668602, 0.38090167386877927, 0.13578899264816316, 0.15966968460669442, 0.09966170340175591, 0.16022895943493615, 0.14929573562356735, 0.19370752266578137, 0.13010618306936758, 0.22290621313356587, 0.11517369684072272, 0.13637938596788915, 0.15008552630822505, 0.1549614614416515, 0.11706648559700097, 0.16441581380223075, 0.12281862613294395, 0.094057762574765, 0.08912653121496401, 0.16303487903168126, 0.277761080933194, 0.1541553377624481, 0.21425475156114948, 0.07992341738915251, 0.14788892240293566, 0.14060649059472546, 0.1120540182737093, 0.1579122942301535, 0.10283410413971833, 0.1327844417744106, 0.14155051010029931, 0.09102422293395766, 0.14051791550892015, 0.18983559172239997, 0.22828923718583202, 0.1586452411908296, 0.15914356606381555, 0.15221376452715168, 0.17884897158270885, 0.21891025255524346, 0.20836200324758408, 0.180116341479363, 0.10685476339271954, 0.09371149849386946, 0.13058791447791362, 0.15019490834205382, 0.097225007540997, 0.1175872645070476, 0.14880641994457092, 0.1628725603222847, 0.18546795592673365, 0.14865084280890806, 0.23497261888077184, 0.1526535909262396, 0.10415083308133388, 0.11315213636525216, 0.1141455838637006, 0.1690253341991094, 0.1384203820939987, 0.18931728727634878, 0.09010913090840464, 0.16968718820041226, 0.11400605627005139, 0.1139246058019419, 0.0884724376843341, 0.1711943589391247, 0.08845006025606587, 0.14962011257246619, 0.21471455753330262, 0.14099339564000407, 0.20414579239103103, 0.13672133697377098, 0.1373839110977227, 0.1253817571447261, 0.12198903718061986, 0.17490060038624272, 0.14451689447366423, 0.10658399727676185, 0.11249094886044342, 0.20430290170254248, 0.15929986332212726, 0.15359958693865808, 0.13272071858086895, 0.11803541828187243, 0.24124778296437957, 0.19157387586610933, 0.11396513951401557, 0.14573180266926367, 0.09552654464759174, 0.1668518355056163, 0.17306716812233772, 0.11516101042469663, 0.16024066525841915, 0.1554814359593776, 0.1802848961444632, 0.2905113580486467, 0.18484134196994767, 0.09415179986747042, 0.17217351123690608, 0.1307909890648819, 0.14595260453079978, 0.14140224144343408, 0.07627202783741298, 0.08928947045557922, 0.14328528556131548, 0.18576689875654637, 0.16816273451812808, 0.09486069932820336, 0.16217413328347668, 0.08533703133223519, 0.146465546361381, 0.09407859250542619, 0.09598219076231604, 0.1223806536666328, 0.1314536551193845, 0.18142573895954317, 0.09421435094648793, 0.16820578865947264, 0.1429512865480877, 0.12803934679757203, 0.21918302582156277, 0.238342271937478, 0.21979647838780958, 0.16777042089210403, 0.0712032224081697, 0.1398364343349972, 0.08297403312979207, 0.12762366748985746, 0.13793886519007145, 0.19956443338624894, 0.13129896664571378, 0.10120200744319348, 0.10648602995300487, 0.08412052201287401, 0.12600430317463415], [0.03124999239169542, 0.14846750264686925, 0.04206954599207929, 0.04539498045379597, 0.09206296155048956, 0.018815626953578284, 0.05372872621181512, 0.03990230623692755, 0.026147898526922352, 0.06907240247293826, 0.03662701606029465, 0.07500854966741416, 0.05431423572102382, 0.01127377862200862, 0.03340691102728729, 0.018259711420884537, 0.03223898700408397, 0.038899064304367195, 0.06472288465668118, 0.020903226123341632, 0.07806104998434744, 0.04225863181355019, 0.026627021406086224, 0.030979818078659238, 0.020803598304008766, 0.017273541757716768, 0.012080667431526368, 0.03219789787826519, 0.01191959074217706, 0.05481187494531755, 0.030794018774383494, 0.05763459101980252, 0.08241624451212345, 0.03829737501819769, 0.062139685971722494, 0.003200848216018189, 0.03327428205539623, 0.021315618913861054, 0.022755594165515036, 0.06114867080243365, 0.007698279176463163, 0.0398112183827306, 0.04352935334487308, 0.046953394813763524, 0.03716774773032915, 0.051583262505911054, 0.09658956059044409, 0.03968544206732223, 0.038760130428859306, 0.07845017668460647, 0.07484985455389946, 0.013905510892190281, 0.015685133140293822, 0.02026311752776946, 0.06419387413188815, 0.046348020644678224, 0.04844826218041201, 0.018942791803349412, 0.09936977027645034, 0.07260034461655925, 0.05560227083943545, 0.025552466263874404, 0.057635751643007806, 0.03226871121554606, 0.010746528184221638, 0.06286563471921029, 0.06451735858835521, 0.04203419103437374, 0.030722535110168883, 0.038796914140543634, 0.036101533370392944, 0.07937450773052632, 0.011446009551535451, 0.03520861959024783, 0.03660165471956134, 0.021961321866500284, 0.07223490535491897, 0.03599687809905699, 0.027183084410705396, 0.0452020718535829, 0.01577435365517534, 0.03371999967062185, 0.006878399430969431, 0.03615602520444701, 0.06760172050205931, 0.028994983858278686, 0.026264931863894867, 0.0333655001445403, 0.023787213910010555, 0.02807511527451777, 0.022663987286749388, 0.01910000836717025, 0.0052030551558991354, 0.036794831450547905, 0.052108699230537306, 0.00989865271314498, 0.07030404968968323, 0.027170135609565244, 0.07957880039729419, 0.029162006347530314, 0.03180948555499556, 0.05668834602880863, 0.10276523283532552, 0.10244478591747823, 0.04495874700707294, 0.027575202684308735, 0.017954659039875673, 0.0275664980102691, 0.0562669134007827, 0.05377801630886332, 0.05424234986064896, 0.029996934932686632, 0.0860824348825601, 0.04476031491292581, 0.022314775682565187, 0.09203944265121415, 0.030483193920865178, 0.07218453507389753, 0.05354785285289249, 0.015358140001133566, 0.03311810737115241, 0.11960674888424336, 0.011402454580210391, 0.03321276902551613, 0.034656442566624576, 0.007000071430323466, 0.020353297567776134, 0.026828816626220945, 0.019807745289478092, 0.03045528533778364, 0.032291831749100844, 0.0881003181359941, 0.05723711396116884, 0.03272486294830038, 0.04032525188860394, 0.030362052437398705, 0.042753704643297585, 0.029294543388870456, 0.053275600526361704, 0.017500181209235903, 0.04314699120098545, 0.021243378737821214, 0.03216672959106584, 0.03478932434753065, 0.027569244435477643, 0.05223840557699723, 0.06295917788520455, 0.033289496561572436, 0.03560081064220398, 0.030661108265180263, 0.029776054547138275, 0.0656383903697133, 0.06961689946512062, 0.036001681470342224, 0.055257002672841476, 0.02369414954896896, 0.01032499979520517, 0.045449135209163355, 0.02687089975112148, 0.041865406542896264, 0.020331477468472817, 0.007599784209648328, 0.029437665850104346, 0.03769140330053145, 0.009012179817223262, 0.0482775739604427, 0.026178147508612564, 0.04287645874184467, 0.11514375812464184, 0.030071521252994577, 0.055805353087282954, 0.0790864127057214, 0.03636027956681867, 0.03430684983369804, 0.03506198653110093, 0.03822114160885254, 0.03693848825810898, 0.01937636692497519, 0.06817483853909277, 0.03461854419701042, 0.05666829750783021, 0.02597278806441013, 0.0012820735179458656, 0.10505784287928574, 0.025938672253922112, 0.053525015771869695, 0.0043425406704867085, 0.02993942854265052, 0.07140481078456487, 0.0365961350560669, 0.035808673278699, 0.06567193735991755, 0.037992763137745286, 0.07804696162741992, 0.018952415782898184, 0.04170508349254247, 0.00993089448104823, 0.07038549249691349, 0.051721395819538066, 0.05481305089028132, 0.058860615151183265, 0.08016558544289681, 0.037025255376412984, 0.027594236138787483, 0.03441120250030391, 0.0330798412793346, 0.056152789282702634, 0.018356587069349426, 0.07774097078870382, 0.026571070174536398, 0.07441450210828936, 0.040428271562221556, 0.02558864859653817, 0.10362098369026378, 0.024522924532873497, 0.027304492109725555, 0.03503953249404027, 0.021945927329661868, 0.022534677390790275, 0.05629407887857768, 0.03831850755358896, 0.026655406878900625, 0.055466523889692566, 0.03113303183307571, 0.05117137916386128, 0.053857122547924526, 0.027438750933675517, 0.03472327224669918, 0.03035594288620257, 0.03284612700583474, 0.018985656337932717, 0.04405281739309431, 0.035955275694328936, 0.07347305665814108, 0.04119654283708623, 0.07571906557366734, 0.03371511586010456, 0.08333358883617387, 0.040849148776502385, 0.06401209678921489, 0.06054972411103307, 0.050602941924045165, 0.03734485959754356, 0.06572709569046575, 0.0315271993918765, 0.019189654060849742, 0.013818590556301419, 0.07749694880218276, 0.05535903792347639, 0.035658290219162746, 0.017651175223891775, 0.02813141316085333, 0.053492441713329286, 0.004009287874777652, 0.02459072139895251, 0.0655404919938695, 0.06526200371163507, 0.031199424843033476, 0.05104750657694475, 0.040964169217453855, 0.0267391613564424, 0.0886186915299585, 0.06567110232408009, 0.027624155702670256, 0.015201069951628246, 0.009595555771562842, 0.08899275694162616, 0.007218248004304066, 0.042708865517089446, 0.03193100242154493, 0.028857111014545928, 0.09595366930889507, 0.013729915879065952, 0.045144668885416565, 0.03037277383789901, 0.0641592699403484, 0.040318200049260934, 0.1042647733383121, 0.027334160779813127, 0.04327308927332202, 0.028036228651481292, 0.12063376635553376, 0.025583900766627445, 0.018777711346985835, 0.05678640528311653, 0.02683643154018829, 0.03007055023655055, 0.010427907428463862, 0.013196706234837973, 0.02094916841616073, 0.019126769733585177, 0.06418581488692472, 0.03974565274773106, 0.08796789217740299, 0.028497846421575355, 0.018835949350989634, 0.019474200183345426, 0.04831695471019034, 0.032298128991838426, 0.1032474009139884, 0.06317279767245054, 0.004761562036770967, 0.05677929598717921, 0.052710599190885984, 0.02287857234477997, 0.04206182765624216, 0.048135460820049054, 0.02335933082166218, 0.04310377618117679, 0.026812395531563993, 0.02148092153572267, 0.06420079956672366, 0.13962778262794018, 0.044972471472236424, 0.053642322985275145, 0.03412475839497582, 0.041027229744940996, 0.002569045449960076, 0.02420808154819233, 0.020995962981795593, 0.013279182303156103, 0.06591446547498626, 0.058362795896227324, 0.026767033550347534, 0.059116032695578, 0.051685389687096885, 0.022112043919943036, 0.054516406324241436, 0.06001590638451519, 0.02038436434832552, 0.06394421756868401, 0.032400666030063745, 0.026485980788786567, 0.05659544637667076, 0.042393133870416114, 0.039215378177862976, 0.04514458844618452, 0.036737064590617534, 0.02624232843968897, 0.08471196487305627, 0.06481895208238594, 0.055328268001997666, 0.06846113325727564, 0.030029256182212024, 0.02258778452092121, 0.04202417443476377, 0.029050460115315455, 0.04229960602618033, 0.0769409604911362, 0.027678643706284707, 0.006498706145888015, 0.026336595558771686, 0.16517857690491985, 0.2234625921494538, 0.09651897324910087, 0.18400576987093498, 0.2526873449284223, 0.15407376472027073, 0.1287516323669303, 0.2136083418924001, 0.08667436037813464, 0.18213112207670368, 0.07245312550015028, 0.20768095108289875, 0.13164430376022093, 0.17210641725649758, 0.07692113413565582, 0.11640178940949902, 0.15562115507500787, 0.12088309733137009, 0.09650680011198406, 0.11577513714831685, 0.15098854478809143, 0.14232549996625993, 0.13106687264817377, 0.1943241774795517, 0.17158717818317876, 0.17074178483697677, 0.2265971021786813, 0.19644110824071592, 0.16788413898358423, 0.08416894643056778, 0.12616008715403657, 0.12999258755195525, 0.195535515705424, 0.13756843103516486, 0.25999053771938047, 0.08541204666178073, 0.11383704195219664, 0.13902715437354582, 0.13914845673547638, 0.10441915537681311, 0.19326332956552508, 0.06722740994225587, 0.12974161714796098, 0.20497998553178004, 0.13837935042477426, 0.09062962636591927, 0.14759681307740752, 0.18940877349626636, 0.1974528499187962, 0.17288477790932502, 0.18010777661636954, 0.1402431657357562, 0.11006032041604481, 0.11041276682648929, 0.10373507716482687, 0.15594269749858689, 0.25760138527520243, 0.2784846969429524, 0.14555506618513217, 0.12989658141328445, 0.13825346685705647, 0.13741035645286884, 0.23032896160598726, 0.13935386022973445, 0.15389158901187683, 0.11105560652551152, 0.1893355814559806, 0.24315889654380662, 0.1635759209673251, 0.1667233319171975, 0.1260725003216536, 0.20554258518161314, 0.15998776431285566, 0.13402139798047083, 0.13650269548018135, 0.11241289216183847, 0.13905626571466848, 0.10638915047410036, 0.20470279959901688, 0.18190198517855138, 0.12685111378349606, 0.1277256184708207, 0.14647981091853113, 0.0997164863492212, 0.11350678910891857, 0.21143565525210675, 0.22109671345641538, 0.1331044979874165, 0.10669154836045158, 0.09559035211080506, 0.21165304036150057, 0.175124972217506, 0.10973678616386269, 0.09398352865490223, 0.10716207190266541, 0.2156892358776062, 0.13135141302501002, 0.13456547362429483, 0.1373440592039016, 0.2466841727014511, 0.10078792925924064, 0.15350434688791154, 0.1921069351655822, 0.13491113249573017, 0.09593729034907396, 0.14898790617383298, 0.14579472913136407, 0.12187749477884463, 0.14007790524873043, 0.11796239478093003, 0.1662406045943499, 0.09326267822255051, 0.2557661910090716, 0.10777421445856172, 0.12564523776452388, 0.14050342112539277, 0.1668069121097365, 0.18188280233692738, 0.10894736320140863, 0.12572222194003482, 0.19904556203513377, 0.2761180061967142, 0.10383336624551205, 0.18943953958730544, 0.10702914032604426, 0.15177186969066822, 0.10137498243561677, 0.10196881549012277, 0.06583874534455038, 0.1885615108955291, 0.1427023386162135, 0.2416748310168905, 0.13783625537349334, 0.16000831079098488, 0.07869206128581878, 0.2133628413561852, 0.23408017241426055, 0.0788624622228165, 0.29312307435658674, 0.13514324181502865, 0.11946009667289835, 0.13458903848884568, 0.1290590328074271, 0.09840163432302014, 0.09629794922206672, 0.11994049508845615, 0.20565838703224737, 0.12424093731228383, 0.1753371632507732, 0.13374813441787997, 0.15241519968596198, 0.19797089389495312, 0.1632779280865385, 0.1270547399537698, 0.1800849318744675, 0.17927418102420148, 0.11148414844947477, 0.18055451312853446, 0.1048010808505839, 0.22732166813746577, 0.1462092899507092, 0.05815442764170228, 0.16582536961763136, 0.22848831279383552, 0.11953027798764168, 0.17564044213823735, 0.2893045550632862, 0.09945014056058661, 0.09062318356647607, 0.15308207922404812, 0.21841122288136713, 0.16020634451941138, 0.24066561742896037, 0.12927565182889664, 0.07914254396793344, 0.10423417578661635], [0.002765332737321695, 0.06126781662685737, 0.030837672379528804, 0.018862743276141344, 0.03574059870574744, 0.028461809645617203, 0.013270874079617282, 0.04357198230741967, 0.04270051132827517, 0.044806027379367626, 0.025133239969070402, 0.029979627091257326, 0.032342968118046565, 0.08316380843039482, 0.029021431128644658, 0.04258275978387364, 0.02204405361666314, 0.03443484780408683, 0.0642190094766838, 0.05239947173263758, 0.03820131142293254, 0.029885051621785088, 0.02821630527896266, 0.016588065435268706, 0.05354455484437847, 0.040964123252178394, 0.06111421216759951, 0.039803840956019784, 0.037197069745630994, 0.06718529042817893, 0.03930620173172605, 0.028385522610117352, 0.11336317060575371, 0.018387366566927205, 0.011148921612109388, 0.0527913180450278, 0.0341553942510678, 0.009751176957281367, 0.01141490925463938, 0.06349342079052041, 0.03165619710700647, 0.015766362400515186, 0.031151825885078123, 0.020703326970819506, 0.03288643855241037, 0.05728971355804994, 0.011495295818144036, 0.01837566840432344, 0.01670745832304801, 0.07620570760580801, 0.04891744889919797, 0.08271141818934873, 0.09667156264185907, 0.020898625765356327, 0.06013518627432566, 0.023254190999714118, 0.03441480694398765, 0.02511480023273297, 0.01742035484752588, 0.02187243268464602, 0.010368026165862479, 0.04877252421612221, 0.041700031142681844, 0.05565085230515369, 0.017603476674506263, 0.01577694782040893, 0.04766516710421251, 0.003511063311429274, 0.007708496874153255, 0.05075546236889017, 0.03694302349862072, 0.02878877980213973, 0.04229386419718785, 0.008065010732670706, 0.024126008633644353, 0.17483686187094258, 0.062162557526701884, 0.04111272898773032, 0.034379582221229235, 0.011000535169225788, 0.055848012693346515, 0.03989246583754017, 0.059464441822661515, 0.04357119323685766, 0.014731928240507843, 0.058386249678029176, 0.014147067033205063, 0.04578704510124461, 0.011873264447785916, 0.03204113905197911, 0.017410209928188595, 0.01859868042952111, 0.06796679970237517, 0.07277305913908828, 0.03879432093291994, 0.010256439714031595, 0.016665246878420154, 0.0209352026333011, 0.04701033429873567, 0.03728427353405184, 0.031182017410174016, 0.019612484799337485, 0.01962919509218585, 0.05062084156839598, 0.03504628938953242, 0.03457672345722395, 0.013001826873439695, 0.010380524890347114, 0.0552220001155811, 0.07463304401044885, 0.01994294831679473, 0.039127902428229014, 0.08502243732612941, 0.03556186273213356, 0.03499398090606255, 0.027905105042361447, 0.014394365003212325, 0.02321964043432907, 0.031022703680660457, 0.05064916766939625, 0.07609657838099426, 0.07783416538469254, 0.02242744997924855, 0.01602740494549395, 0.06362842080453712, 0.021162770966428424, 0.025522918252634908, 0.027116616707175013, 0.017028410858925314, 0.03117610704183819, 0.02114705467266181, 0.022274395188076362, 0.017338209154625094, 0.02011209670003624, 0.020279354761324583, 0.061449417769308054, 0.014444350325051817, 0.06544577288291147, 0.050385951349932345, 0.030100000571579705, 0.06077873077423823, 0.057810423520183375, 0.06310754230306034, 0.022969863212276852, 0.08075573361448704, 0.03311400497031789, 0.060955317871224504, 0.07991048582499066, 0.0451270641849166, 0.09109970557713702, 0.0700322033897523, 0.031552514767334346, 0.009396089458717935, 0.06396602809188828, 0.012235865353666728, 0.0429775670260912, 0.038564203442224575, 0.07426749749649918, 0.015744556665360447, 0.038489249399712974, 0.017822079863699696, 0.07327702241919695, 0.07848540140736489, 0.06594448079985958, 0.10176400954444563, 0.06875510417645977, 0.050406693180482236, 0.06555258086131466, 0.04030319238682428, 0.051912009986417915, 0.026654282644871744, 0.05295884232186983, 0.003904297439974823, 0.006876077226948955, 0.043787647549423485, 0.03951473852559444, 0.06806575527955448, 0.08452343829577008, 0.017995797961409536, 0.05243932745689827, 0.04732157667017272, 0.031228174207611915, 0.030784647603849732, 0.01209741411355114, 0.03313333336864749, 0.07060286994542807, 0.028522286541579712, 0.018762399164599278, 0.06602392411760746, 0.042617758510694395, 0.03424637102251572, 0.07341937687728675, 0.03307994087076476, 0.07421152711275124, 0.018177196090560288, 0.022744158388025338, 0.05188846810450477, 0.02210275127342151, 0.03352620240841662, 0.03379534441797483, 0.08244737832536621, 0.07050193786140412, 0.011753800696873618, 0.07313105202610455, 0.023998633109694047, 0.014719975353669257, 0.04463243568616529, 0.07932069771472486, 0.059386549832960295, 0.046276077327709046, 0.03531535095985859, 0.014110112866957583, 0.053238215435656815, 0.09183085989207031, 0.03205720583097108, 0.06813795906641791, 0.02161690597272208, 0.09695133795180629, 0.06341355612441417, 0.028152428867836154, 0.03441922727131075, 0.051141926913612315, 0.012919572013009702, 0.027973323256798813, 0.06443133457533776, 0.06300432344658241, 0.03447737717520326, 0.0435011153439841, 0.05773510941634736, 0.013468893443895204, 0.02078546691806086, 0.052113966085016734, 0.05358493150842767, 0.04814867966718251, 0.035479389536645145, 0.004540741501841694, 0.02803962816664529, 0.03159971344434927, 0.07195296201614604, 0.0492467824369669, 0.03232104268165366, 0.021679466627838633, 0.052263985252788955, 0.023680718112436515, 0.024643723191993854, 0.037187501307456725, 0.02447647470680456, 0.03409468178306857, 0.04104178924594195, 0.034500631774144794, 0.0854609537148668, 0.06912589839269077, 0.044504123619727554, 0.07201552075604278, 0.023985864339216102, 0.019290455909926566, 0.08690425570333198, 0.05974928097378823, 0.07431398371174451, 0.02860099058448067, 0.04728227252921751, 0.03405052064467342, 0.02338989389940135, 0.02769433701741359, 0.018640160260181275, 0.04062977949938467, 0.04444284041622474, 0.008371983121539797, 0.05662751864762076, 0.07291707600797377, 0.03291990893382219, 0.06575298180142719, 0.05797374580476073, 0.05636008884457331, 0.04214091474310525, 0.05332786304455611, 0.06438126306860678, 0.03396224050271896, 0.04248345946712841, 0.039765831503656604, 0.02018050069079524, 0.0682823513183863, 0.03227930238109923, 0.02663012406217956, 0.04926143769895838, 0.01447738020590717, 0.035517866302642136, 0.05038798914381093, 0.042857766196492224, 0.05196067955224745, 0.02198149870720602, 0.043302533862691735, 0.030284122143301274, 0.035198430620854905, 0.032416386154269984, 0.036736899881713816, 0.04218739329747135, 0.07094218560885038, 0.042734211536064264, 0.04419060596715539, 0.02255476038572529, 0.023853453702383468, 0.04434552809764301, 0.04077051368151461, 0.04644187407628183, 0.04418923466977093, 0.04392991007696237, 0.05522521385442346, 0.025678761603851474, 0.025300932785255775, 0.05986230958613658, 0.019144906865192518, 0.03353131604531119, 0.023957134126835776, 0.0316090080060906, 0.01125788038235999, 0.08596678624951071, 0.04579270649100504, 0.00241500168715814, 0.025771209264114022, 0.05740843420367568, 0.025842999363498344, 0.03683124744002858, 0.0433207820770481, 0.009351953218180326, 0.06775960356237427, 0.07869621348236838, 0.06684079601038849, 0.0273469525329288, 0.03198801085443026, 0.024219097892543482, 0.027899083591276602, 0.03381267715726168, 0.020737879451424367, 0.010657466632584411, 0.054561145859019416, 0.038430314255698074, 0.03244814432917103, 0.01401595108496446, 0.07562539600316556, 0.05467119055890268, 0.020936773113545873, 0.06295546618921143, 0.052393990373539354, 0.011435417428372369, 0.05807691103508396, 0.08323520782493776, 0.059815015148131125, 0.03426841903297651, 0.0721014145341131, 0.03893058116157209, 0.059430477314538536, 0.24996079204063265, 0.16221089018208368, 0.119158893883709, 0.21220594133821227, 0.08247397689809723, 0.12083256617188455, 0.1364426648304347, 0.11021405894068942, 0.1357477617960784, 0.19896973465238849, 0.18788476414497823, 0.05244484328995309, 0.18858450885501601, 0.13854554553906764, 0.09652164689595662, 0.28411709793633033, 0.11857407768407177, 0.2332042887686722, 0.07964331266139785, 0.15769644129660823, 0.10465760024324541, 0.08519540465767346, 0.19767896843052682, 0.14483223158505656, 0.12079713460538657, 0.14207186357628915, 0.08919440660505526, 0.1933665828959596, 0.09277887071572966, 0.1311946254704268, 0.13211871136821088, 0.12683357803090928, 0.1980266191305653, 0.11121728938193091, 0.11086822908011176, 0.1849612040865806, 0.13871164872281014, 0.1485333402430819, 0.09568557683979312, 0.20476206416083922, 0.17437149410045918, 0.16229877578875712, 0.16701415421501284, 0.07727823836067993, 0.09747230072295475, 0.19806369778610047, 0.11422773147182119, 0.2053637342948106, 0.1742399721256187, 0.2020692038199594, 0.18104897691838204, 0.18380499354773955, 0.13248672468527672, 0.12183124605085581, 0.1637251702167334, 0.17538083026245718, 0.11575288995499573, 0.09744350347788104, 0.14978920349911337, 0.1125635203695105, 0.20668488356374926, 0.1660109161128921, 0.11905551797920659, 0.16052509838294599, 0.20303573098874864, 0.055079331561442346, 0.13980261921401949, 0.1173836843020493, 0.20674843821794758, 0.12265160364369232, 0.15831026158505873, 0.14075192472627088, 0.1765847834007394, 0.1491308581805037, 0.10337081001771074, 0.2702230821934439, 0.16691163632898562, 0.24953216584699772, 0.15105548555091505, 0.12331887388661986, 0.12179786759999492, 0.15368659920509786, 0.18800853331002498, 0.16383280557009483, 0.15466411207472125, 0.17558601925209646, 0.1078480193691869, 0.08905841833761624, 0.08753097691242734, 0.14036754777114238, 0.0898281911448125, 0.1456905718171789, 0.13874431471190146, 0.24227515283611514, 0.19252304348253435, 0.24630318185494793, 0.27249447160190154, 0.15883159973929006, 0.1908181760940821, 0.15974718206111463, 0.1792381442482433, 0.10435756190770096, 0.18144771036121154, 0.2783357694504723, 0.11268493764462972, 0.20806937298226744, 0.1672374688449406, 0.07496233158294233, 0.12992684188629353, 0.1148976983442422, 0.16575861271590958, 0.10688310864591792, 0.17259006388485434, 0.13625881905036588, 0.09130504778436116, 0.11913875343217967, 0.15090931597496235, 0.1477642952194137, 0.13392317018681957, 0.13739926349972525, 0.14288848266005516, 0.14487565344860479, 0.1531893162116889, 0.1270654958282267, 0.13924288473302318, 0.1021765172481537, 0.08354741929759903, 0.12906877744582393, 0.06866571703745473, 0.12391372583806516, 0.11948481066933564, 0.1532136165206471, 0.2392308879643679, 0.1495782535282835, 0.16778322988219802, 0.1172331480249282, 0.12492117742376944, 0.12438211965584949, 0.19217307919696455, 0.11537466468589923, 0.1308111984643244, 0.23006159692041336, 0.14982237510623472, 0.14951653748510346, 0.14966384087118412, 0.16152398510565683, 0.11292002704595366, 0.16857151903452414, 0.18873130662306664, 0.28826261419923077, 0.16694174358440986, 0.1170429896803633, 0.19743976513704947, 0.16840008387882865, 0.08089855538621064, 0.10348730134747683, 0.11228140849139422, 0.19976073575596656, 0.19548837065456376, 0.13286478907590912, 0.1596814057519359, 0.2313115459776694, 0.22320510999810314, 0.10226281705282389, 0.20044148148548221, 0.14666886609648505, 0.14572506109553, 0.1172139805050627, 0.10180691812908459, 0.10400320793832503, 0.1473197803622292, 0.15928402062385313, 0.09807469097957497, 0.18953300231406767, 0.10419890509858247, 0.19823740056205183], [0.11679536708059812, 0.0388434769645814, 0.011895829567595596, 0.11562666930859128, 0.01717564721231259, 0.10280064141918575, 0.07313888144469069, 0.11004500631843844, 0.01628769576669701, 0.03977663717382858, 0.03220035319006251, 0.012305337079470197, 0.0512767622187253, 0.08250558568585305, 0.01188637316978026, 0.03562607239150713, 0.10672790689333793, 0.007538649435680841, 0.05269882824992942, 0.03558929634070204, 0.013366485683007107, 0.03145287545668262, 0.10813457455726401, 0.022644084322476582, 0.03324327081622135, 0.03924969508643112, 0.016277167803397583, 0.012129891453491104, 0.02342233389255501, 0.04741426947857103, 0.028021021806184324, 0.036208950388695926, 0.016941471370838342, 0.12472177239795848, 0.028908260790030324, 0.05543912092464105, 0.02101968872481056, 0.014636031269366223, 0.018303217554104426, 0.03222238587876482, 0.021372485620480393, 0.04272032236199706, 0.009713802400285439, 0.10083724233892657, 0.07765145341475164, 0.013309955097464545, 0.03360484133384401, 0.024855140476457538, 0.017998735908599153, 0.019472794412004373, 0.05381501835560607, 0.0597179364863663, 0.02331240410586038, 0.025955815386447697, 0.03580989901937785, 0.04609407015865849, 0.06596929438772701, 0.009849002554772363, 0.07970501338281939, 0.08885260881675829, 0.06532004253277857, 0.012766386029280484, 0.048870755840213075, 0.019051260277328473, 0.05092647234578768, 0.09298003774376647, 0.05876302321050918, 0.01812670132025115, 0.021858156636177052, 0.07143799005256546, 0.08519415593435688, 0.04154116365938418, 0.040364441116370504, 0.04671872293035831, 0.021801092661917213, 0.013569192547771721, 0.056076908273802656, 0.00632478695009805, 0.01700069954348428, 0.011466018810507753, 0.05360547798655687, 0.021770159946754578, 0.035654291240198, 0.09959090921667316, 0.01836457545117986, 0.01309627498079452, 0.0459457210625612, 0.05347399814655224, 0.008154191027936197, 0.024180917985617154, 0.02163889844180836, 0.039850147140602914, 0.024552353800484733, 0.030805441145334515, 0.048166992999012434, 0.038368188355478554, 0.02626922387149065, 0.04093699990921924, 0.00670370600757099, 0.08789805560222558, 0.05665848009108056, 0.06160626278048562, 0.045695244785278075, 0.04170014988631011, 0.05351479615895979, 0.0031402868109815306, 0.023349869635797316, 0.05468587646441114, 0.027493286817785234, 0.032554519467896996, 0.022018064083831928, 0.04430909295596423, 0.05719168877769863, 0.021087656045452725, 0.012976738451529416, 0.049300960174972014, 0.05389769839483404, 0.04789247305222577, 0.08804027982536825, 0.0298909773118794, 0.013697082308241198, 0.019621919172125, 0.020822982243712873, 0.014312341884379427, 0.06265662678126847, 0.01624386021566968, 0.06550583417617506, 0.040797211845675786, 0.06976861551764511, 0.01033091303637071, 0.09702259945052286, 0.03253547069165976, 0.041713970112464124, 0.022016189083637252, 0.06722232311843865, 0.026756536230565082, 0.0183858803563541, 0.03870951883014172, 0.0411308546280188, 0.13928356400180247, 0.08211570821942822, 0.016137465924745607, 0.012666542747718914, 0.037084385872848576, 0.03939810546956236, 0.05074205583021526, 0.05792588829213093, 0.06497309663363042, 0.0468274308068137, 0.046085279299727375, 0.03212380759988821, 0.03621378823393776, 0.0692811614323047, 0.011827778934891666, 0.04077334820683445, 0.008688418611493564, 0.034017149854691765, 0.056959679049830285, 0.04364110259038787, 0.02721163842286314, 0.030757974337546096, 0.060931626602166125, 0.01991415490216065, 0.05441691831595475, 0.014658769716568773, 0.03481843951909292, 0.01575933450141982, 0.03935172267618679, 0.011318277796700357, 0.008026129376488708, 0.07193685884797765, 0.04811853793780169, 0.02408850096887158, 0.01652538603652389, 0.05127800328116264, 0.024900695894874876, 0.02563045592978597, 0.02982050871416446, 0.024956599245929433, 0.028546713255045396, 0.03919245682716851, 0.07856744176317608, 0.035547992710264466, 0.08650654115744176, 0.01890979448123084, 0.05899874846481028, 0.07098613607306635, 0.06039276035622724, 0.02937693422990701, 0.04515061372770898, 0.03428686259975357, 0.05105365826297672, 0.05306967992275473, 0.064972483763291, 0.06954812775215796, 0.024565281534206965, 0.041655709125822594, 0.021650029699348157, 0.0780927736852919, 0.023681758076793725, 0.06368482785840189, 0.02089098978397106, 0.01213149257725285, 0.05216315659063478, 0.03443464862122651, 0.03807876799856463, 0.025725136736347794, 0.0069803815342546, 0.04079495188629916, 0.03474294538459471, 0.08482035865346271, 0.03609200323661489, 0.04009076003586093, 0.06197003197045096, 0.018571957367502393, 0.04282793090228112, 0.015049573191772065, 0.01268945260709452, 0.011426967478567555, 0.06096371419487461, 0.038764144729582534, 0.016003087399557473, 0.038516732803996534, 0.04915685903641486, 0.0027711930705399644, 0.03146284609101713, 0.024791430689454563, 0.05218512416186352, 0.05379372877219031, 0.08147014124739556, 0.030859300956851056, 0.020784557188650774, 0.1285984147820742, 0.016167460182201, 0.042298165780882684, 0.044822908126779144, 0.047404570805449645, 0.043403626825179786, 0.030723575074526093, 0.05763252641284659, 0.01914392818786925, 0.06866616902933007, 0.03259995614268607, 0.059107398884671355, 0.04831816895955032, 0.020604040060612946, 0.11860079116999142, 0.019289737702497554, 0.012975293418182241, 0.05109493124989733, 0.0274187924280282, 0.020173437360133377, 0.07227682568613561, 0.024550344734903307, 0.03239804217892309, 0.03737460296120375, 0.0621077937314347, 0.08920854858813748, 0.04575984897993265, 0.014164946567747864, 0.02133948255270239, 0.02159910400458161, 0.04762271434188851, 0.06873908527796307, 0.020248355013468576, 0.03871657833036396, 0.0396901956428924, 0.008509849262003218, 0.048934846755958376, 0.04424859882302342, 0.06702120971655653, 0.07413700974035649, 0.056653787802544334, 0.05645167082548142, 0.023245199042702877, 0.06369431202690448, 0.014813076103887251, 0.036577028823235345, 0.02948993028351857, 0.023386130492473324, 0.01778068238749139, 0.05404780566271755, 0.025112787336711923, 0.06399962870824723, 0.014993969572617885, 0.046024237413920706, 0.06815267561544334, 0.0571502510818743, 0.060779393440292734, 0.08924342857132997, 0.02461558095209541, 0.01973371246769544, 0.03599391333879002, 0.030997434270478068, 0.034169225968540676, 0.06011250241088772, 0.018082524860097517, 0.057752591542779445, 0.019634804771011396, 0.016901843557735125, 0.02506096148863435, 0.01960075599321675, 0.02560125840377183, 0.08739207751087605, 0.04570996133430351, 0.026575044255643606, 0.03426435876697783, 0.009543495309058457, 0.0987688432477655, 0.04491366273272903, 0.005602180739984878, 0.03578610049801008, 0.02831799579003165, 0.05516662728041411, 0.028617947940684618, 0.0846387728327705, 0.04912805030002229, 0.05206040121735104, 0.11374596175887894, 0.05754710377884969, 0.03898314245405697, 0.015249625561879048, 0.04929050690524521, 0.020594182424247265, 0.14924747208433767, 0.029345315866052147, 0.11624245078212793, 0.056332195583250255, 0.059943668123695164, 0.0530447973869741, 0.01798518764365825, 0.06514248633456808, 0.033297134458177516, 0.08531058597708903, 0.04258857822165855, 0.07763730377079019, 0.0718390753853225, 0.01630403259168229, 0.02313969532899078, 0.029993577552358472, 0.032433324358275825, 0.08335531508970646, 0.028787044612991235, 0.01869602913727924, 0.03931399284591598, 0.030658963218992277, 0.06584195525295312, 0.03936855362788324, 0.02035792090839917, 0.028904719548600338, 0.045853847968241865, 0.06446390863387816, 0.2098449043208553, 0.13368174523836182, 0.16754031872316716, 0.25850126279457925, 0.08677994261585897, 0.19314472383308798, 0.12997792462908453, 0.22351836335034142, 0.1139787299137923, 0.11792848772940137, 0.10712820315553297, 0.12866745462581036, 0.09207210097942622, 0.13950335462727856, 0.1266857154006439, 0.1388079306531337, 0.27124510477146796, 0.12176366943505504, 0.1385310205120233, 0.15441116516388234, 0.09760620523123972, 0.20599908165393338, 0.16727027272985828, 0.0965818154415296, 0.1956053216370844, 0.1018574109841739, 0.09967181576235641, 0.1040804832272472, 0.15774994487723998, 0.14465494351761957, 0.1344693602333146, 0.14303443773138907, 0.14564690480549491, 0.1877557549385294, 0.12227360054009384, 0.08919864307127653, 0.14327190966615755, 0.20786946999930567, 0.14602591914515342, 0.11377003224145983, 0.20952780520723713, 0.1220384575126152, 0.15259529163520183, 0.2528621508709846, 0.11265325990896072, 0.12305772217411189, 0.10375445918931116, 0.09589905490077312, 0.11735488705697561, 0.08588609420844624, 0.1432744071127907, 0.1629619014960143, 0.1566810530400084, 0.1963417006716613, 0.17234727529989136, 0.10936846641162712, 0.19032248656355566, 0.10944905120038217, 0.18000715862839453, 0.19191319152953165, 0.1565108129814748, 0.21611018587023983, 0.09259672565085274, 0.14419982600356304, 0.16705002245162764, 0.1714597930831294, 0.1795667346807257, 0.14198679717317705, 0.2050925851348908, 0.2109931935105593, 0.25457098659488464, 0.1859859692593736, 0.16761571709667483, 0.11577584961008643, 0.2238170303885014, 0.11029020041948366, 0.1652537148085333, 0.23952253763714146, 0.17226381768142024, 0.0742600204783582, 0.21270921513918908, 0.09766789829178203, 0.09759521953040555, 0.18691947803862635, 0.21760778050989876, 0.14901159361245173, 0.22453759736832113, 0.18550275164025445, 0.11330508581933477, 0.16754978756991126, 0.20744498068046188, 0.10604369078552532, 0.15861730962511034, 0.11479722591297281, 0.14548144513560882, 0.25611914303754607, 0.18441545837108167, 0.1269091449437603, 0.09498439188445769, 0.11323616088878725, 0.14629870773323123, 0.1432555613498534, 0.13708133701114886, 0.12101119489318903, 0.1576334382257154, 0.062035206900609124, 0.14507197114008089, 0.2702507532892689, 0.10587531232064772, 0.10618820561156159, 0.22421712746783612, 0.2034694440062008, 0.13792852300309366, 0.16096242733540075, 0.1789807233839266, 0.10788528954670315, 0.11451732036807846, 0.20438104267081908, 0.16074639054075365, 0.14053083175132353, 0.06838682272862043, 0.21190338257339694, 0.12289279876577279, 0.10708826699204023, 0.14135068372613, 0.1742139098144347, 0.2427607146842826, 0.20092623128044992, 0.14419959617718575, 0.1722771782548197, 0.23372686798534087, 0.16136951113660492, 0.21029010865717165, 0.14122378892235218, 0.17782871100691058, 0.15508135420180139, 0.12848980649704897, 0.1708343742235053, 0.16366438880082101, 0.25423176286201327, 0.15927334135818869, 0.10490360639749036, 0.12750381303410377, 0.12944342508431406, 0.2864429102309289, 0.09694665715458894, 0.23360006511211398, 0.18977081132752283, 0.1622859361551462, 0.08794467205241804, 0.23692782848112046, 0.1484878959074136, 0.1543019516693969, 0.13008375201494465, 0.06842424612372153, 0.16016811673198977, 0.13649299680705995, 0.22528945137896847, 0.18341729177101967, 0.2713309985495383, 0.1452754440927698, 0.10244305455876936, 0.08923084174673404, 0.1116904023013288, 0.10825739377328467, 0.2265011573270444, 0.10148009735970728, 0.13511814477462925, 0.11663305603208081, 0.12187459896649085, 0.21295028768720167, 0.08598950075646562, 0.12225375120197574, 0.09617648598167206, 0.1937194429938832, 0.14684319706453433], [0.050464831593055884, 0.07159800283730992, 0.03644923769658612, 0.031193905179539037, 0.09532742307431276, 0.01759796275667125, 0.06784214953621549, 0.016555878251130064, 0.012589660078857937, 0.04061078434930213, 0.044198155763649175, 0.006253333929400411, 0.051021494061475804, 0.014816865366282723, 0.03334282777242122, 0.11030299408781914, 0.04020139845388551, 0.008205378150206902, 0.04654649870410081, 0.03252584096645156, 0.06486874013658493, 0.03710241575214652, 0.01808258614713146, 0.019089290797109568, 0.019810706219305436, 0.1147667815788619, 0.033101590515504924, 0.05665710879369609, 0.03793260991393078, 0.04800146821165278, 0.06025118730782021, 0.059868959229319334, 0.01506712043567771, 0.0072627639371691454, 0.07800201524890239, 0.010810730182715963, 0.03665498976084975, 0.06357223208573076, 0.028274598824340972, 0.044420531935869687, 0.07971842758237355, 0.037886073902970364, 0.037996099450655525, 0.025260402903621717, 0.035009329477625514, 0.10451598122956292, 0.08183373423713831, 0.035627757784940546, 0.006824509454740873, 0.018356883928420085, 0.008627421733352446, 0.06657039761663446, 0.03420336667688624, 0.10155659889982593, 0.0939511307965844, 0.018702096553639542, 0.047011000795229796, 0.07273140693864516, 0.016057801399109586, 0.048320555323434454, 0.07821880280971527, 0.022675566705724886, 0.0392853066835913, 0.03730201996081779, 0.06832570423402133, 0.06180983915504429, 0.017396711458962773, 0.03376839727523827, 0.009565083666764682, 0.04095405302641373, 0.03638927599475269, 0.015111030680277656, 0.05481529169745984, 0.11770034674555065, 0.024462610430594896, 0.06954698628115077, 0.06406334041047, 0.03308318142268447, 0.019883542028706402, 0.04702296708860705, 0.09860668541683305, 0.018261013770355813, 0.050158902041373715, 0.045275252402549794, 0.03702129853228408, 0.058834181287355965, 0.0811538695087356, 0.06612006815210467, 0.02968454151414335, 0.025964274912351565, 0.02186331049268765, 0.026329064914476008, 0.06792830378418008, 0.05536851443109974, 0.08001082036043368, 0.03683870147553183, 0.038835590089400934, 0.01345567172393203, 0.01461865448002373, 0.025646346508555358, 0.04264709584775471, 0.05796701955278555, 0.05760720337650949, 0.041904438722638354, 0.0064965577480653606, 0.05343429947031602, 0.033825884513076276, 0.030531829012738123, 0.016243006027634108, 0.048179610467125336, 0.03663324435511905, 0.0585394366193683, 0.029484456585299586, 0.016570939539721417, 0.08311076450251764, 0.055870141143039356, 0.009083106152472958, 0.021464161447159225, 0.03228348139072618, 0.057602660475118514, 0.10137305955492681, 0.009566266314997789, 0.04815919422394326, 0.01990929215906128, 0.08442282796867433, 0.022706669875450676, 0.06317326115564474, 0.08622220762434506, 0.014762128384092884, 0.049748209966046196, 0.02984703067810305, 0.0750208683612366, 0.09300999944248507, 0.07734061323947485, 0.04833164444613842, 0.050350718966294686, 0.024549959775721355, 0.0435209455299041, 0.03437176812440157, 0.032104191918587016, 0.019628708626353936, 0.0574699319117973, 0.06484216454649164, 0.063118148790372, 0.04001292550275403, 0.0038196906896172875, 0.05032444981137111, 0.016454532479627, 0.049019518623789476, 0.053260137041610096, 0.015047351536791653, 0.0991611875173065, 0.019492908050456358, 0.04872945092257954, 0.017898878262889002, 0.07111106203087876, 0.023510003079389854, 0.0726268052934639, 0.042355166552888776, 0.041272990751050176, 0.07822443355595873, 0.025461491407646288, 0.008213739042290518, 0.026070659627176584, 0.015426182015348348, 0.03308854403815443, 0.04179417951813629, 0.0481516674100872, 0.05998654606481714, 0.01788422491611733, 0.06481201132579197, 0.025068356152323466, 0.022595728852695996, 0.038467649550687884, 0.021827204768816312, 0.05651910954545583, 0.034203879955795505, 0.025304159930636807, 0.009018832333235732, 0.05537451672998648, 0.03121098510981087, 0.054446014335318926, 0.011267636512075702, 0.0027871767768726475, 0.021631737434936148, 0.06566750171083598, 0.08240770263176772, 0.017839860764422247, 0.01929000774849086, 0.014074141208472994, 0.026480298331608216, 0.05949950949739545, 0.02077118512393246, 0.023731929174954855, 0.013562784222285114, 0.13399527438225287, 0.030086722352632114, 0.02668382491045181, 0.01028008118737489, 0.0335673987865448, 0.03343553590257803, 0.07833587636630382, 0.05144949589345244, 0.02294702230081443, 0.025111741626695282, 0.01702684229390035, 0.05317931859603813, 0.03203023379037698, 0.038951522174982295, 0.06314203541185107, 0.022691296406030174, 0.01942706087814464, 0.009451649985426377, 0.007421978554057499, 0.01837623530938741, 0.06660354624111807, 0.05082146467400655, 0.06842291313073329, 0.05613132732950392, 0.05327960333576607, 0.014597128366961356, 0.07875393054658368, 0.05373552907258273, 0.027204230352635347, 0.04326236021194247, 0.021875667490906293, 0.036207502482519034, 0.07913777124016516, 0.030217060721629573, 0.06644767799204396, 0.04251018827480655, 0.033529427638577844, 0.0652308852201508, 0.05808581680720372, 0.0790489356844656, 0.04431870352897433, 0.06919367419135186, 0.06825694784281716, 0.020823418913829713, 0.12500024535843443, 0.01738195277510151, 0.02245567074315923, 0.032051347173570145, 0.02667748361765858, 0.02763505713383277, 0.02790068663025816, 0.03472640554630949, 0.04021835197964984, 0.03252907768793164, 0.07711221178572986, 0.0058504463748014985, 0.03028618100459778, 0.05047952132900396, 0.044224578136157607, 0.02918175034855883, 0.03812521590941376, 0.08076513351331796, 0.008726993053700895, 0.09158895996909949, 0.042235802393406637, 0.04101437862001119, 0.017880118684843183, 0.03908695502867622, 0.04403884777979505, 0.03168692680886917, 0.05327055966781993, 0.05718937136172768, 0.0362716393635398, 0.021072476013233105, 0.04580907778994692, 0.05723489996706767, 0.08086277908014675, 0.0905803056253541, 0.012432334347507887, 0.019251442882382584, 0.010345610433198031, 0.04069265999620961, 0.042503898692948204, 0.018071993066358472, 0.0583262266891618, 0.01604672951338392, 0.04210498138901688, 0.0903392483991, 0.04221794871433128, 0.019147436870562456, 0.024220057417668646, 0.01564906955125832, 0.023408471531565153, 0.07599694864644159, 0.04355298332689751, 0.042982454667048114, 0.030054447068382176, 0.009177582030515037, 0.04897963225601181, 0.0626426724897277, 0.05472668213769794, 0.038932255063686645, 0.019158974154702118, 0.0395398777008297, 0.03419687408172796, 0.02634905980929973, 0.025396833586837017, 0.09037703185552552, 0.0029044928481697196, 0.05636358220550803, 0.024014466231869116, 0.08916601538658143, 0.04414610391963394, 0.022646911186917175, 0.019313563036942677, 0.014027835981499766, 0.013259350202016294, 0.013175618707112247, 0.03693681052555481, 0.11381771355386704, 0.0551847912250988, 0.0359497751830326, 0.014333356633752346, 0.025216197715170925, 0.019318460253998637, 0.05107892384271949, 0.0498819574263067, 0.02833793322826105, 0.05045878715933331, 0.04809775014197634, 0.01342376990754518, 0.02534393713088526, 0.10699639006728127, 0.04992180548968816, 0.09308663121755086, 0.02965195404906427, 0.03139270691110963, 0.07163784707025175, 0.097285428895585, 0.06237665611890055, 0.042838847655202114, 0.04082993146092181, 0.006546268235862016, 0.01092057953017854, 0.018075741151528015, 0.09504475195201174, 0.05177417544708137, 0.0330224804460041, 0.02938774373051861, 0.00842598657454214, 0.034349333239539016, 0.07166826842172493, 0.02615788639823516, 0.012930491638760413, 0.042210762809601524, 0.060191876780722416, 0.03938570633650788, 0.08648263921420421, 0.16060147734899677, 0.0949456278354891, 0.165716094836112, 0.19956198190489124, 0.147191169521501, 0.12082601612013195, 0.08036607065268102, 0.13089258764539996, 0.1578204096445153, 0.18678193461270104, 0.11764220067209775, 0.11539233067343313, 0.15145906066942602, 0.16254801483404252, 0.18213201073869584, 0.17769755675427376, 0.08669643137123316, 0.1572008590183912, 0.2485799951659095, 0.20447335626569488, 0.12953809822999662, 0.06337291516003109, 0.15652002135832466, 0.16362712628418402, 0.16012497066009432, 0.15940976629574455, 0.11963536226821524, 0.18914405947491048, 0.14819517371154603, 0.10594597627078334, 0.11175673785469226, 0.10267151729954828, 0.14272860011025784, 0.13591412544971512, 0.07887007713678383, 0.0966273823512658, 0.09727166995646493, 0.14440976473833286, 0.11608040786438412, 0.17839633619352696, 0.17226913433161475, 0.15028389711533824, 0.17986451305689352, 0.0892172666687158, 0.12819984987858804, 0.21420924593844723, 0.12147287011987741, 0.09262916181356677, 0.1577985761386733, 0.1148507524762423, 0.22331283728201545, 0.16164384722228975, 0.21969141708987378, 0.1346508004973012, 0.09005764979989299, 0.12877562624071875, 0.12054255592726892, 0.18631092843509492, 0.17732886927983454, 0.14639984666099473, 0.09786030893484432, 0.13019967643964675, 0.2788602945304686, 0.18441522854470438, 0.1046410067788055, 0.09924336576894408, 0.0936486869449577, 0.0678586510701045, 0.09542277803824795, 0.09178397531110434, 0.14898922384506272, 0.1625294295409995, 0.19068697587616984, 0.15143525065673938, 0.17045589614539378, 0.15924649763732188, 0.12217620012140083, 0.15884462323400284, 0.0881435561384405, 0.18355941640273218, 0.10790976605588391, 0.1300070053266902, 0.13957758854714133, 0.11814656231792704, 0.14991920861986377, 0.20001227306502484, 0.12665513317070662, 0.1969105515989565, 0.13757290498864266, 0.12165342172187184, 0.12845122630918218, 0.13130851210125033, 0.11046630105063801, 0.16274707512028758, 0.2378422769928171, 0.23110301684468026, 0.11895349038945091, 0.13447129077488376, 0.15239650714060954, 0.08715794571945745, 0.1270471173789232, 0.15622987321788268, 0.11290814502224808, 0.13791844128601013, 0.09189960096151599, 0.20729654348425328, 0.12138382772043829, 0.08994971567224111, 0.17696621857823866, 0.09570268358314231, 0.08786640084919431, 0.1695133781721515, 0.09017175093533532, 0.1653002316672956, 0.12044998952337813, 0.2067327640590168, 0.12855008995581058, 0.15117323326487697, 0.20053569497841023, 0.15465873413749281, 0.16143156425847163, 0.20509805500267014, 0.11920515027257705, 0.13957363553345203, 0.08414306798048558, 0.18673051479122332, 0.14260380438739254, 0.12243349075077042, 0.1571810326629108, 0.16167628338500378, 0.1408333445508634, 0.18883918712456382, 0.129180503708701, 0.14392788011220195, 0.10518499049207858, 0.14700447389435384, 0.19712686418525635, 0.22598199486251802, 0.2064986169458397, 0.14019651098116753, 0.17226245404491503, 0.22451118265669193, 0.1539042907496614, 0.13737612764441198, 0.2697476480276354, 0.26834392980221783, 0.11749200913454257, 0.13265000866545787, 0.10901923757046462, 0.06852795910691062, 0.29324923371595724, 0.0831684585840952, 0.16552227459126906, 0.09525043123792257, 0.1231720531359315, 0.14564068417154974, 0.29946425989750897, 0.13264067771454013, 0.15532126229616905, 0.12826780187747172, 0.1226451761660076, 0.15385005172462235, 0.12993117794394493, 0.17193712714699008, 0.2047288619102009, 0.18603979459693357, 0.1707417695152183, 0.09875952761860625, 0.17840295519319274, 0.1742122857080352, 0.13571649008700926, 0.06377770835834165, 0.10298915267471345, 0.19311925907048488, 0.2069446486571143], [0.09223329353957407, 0.041006204461859125, 0.05562954739997945, 0.005389622942123923, 0.09110401099127147, 0.012017441237525595, 0.05149659114859758, 0.048253717982480605, 0.02988830174980385, 0.0506708671098515, 0.029320958100499648, 0.017547670999662052, 0.05503706649065979, 0.009819318562926305, 0.02495916372525596, 0.05561948866553365, 0.009750508545567433, 0.023614087615222223, 0.0646873994640285, 0.007161451203207816, 0.02960527439661805, 0.04017301489629092, 0.10864952353820687, 0.05855276271881116, 0.023026984643131014, 0.03245676281831918, 0.013461841604552202, 0.009704932059732177, 0.029602328788549192, 0.08308771291687604, 0.021374954338816386, 0.024271908163603757, 0.028165731984641285, 0.08993544345421177, 0.10207682622656708, 0.012646227053576901, 0.0510028091770026, 0.03895871574059129, 0.03730383175875872, 0.0621393833669924, 0.023986168859166004, 0.07954072582745746, 0.039545753595208934, 0.040358733761334614, 0.062084933667774164, 0.03045168280931971, 0.023379944332484758, 0.023845197189779534, 0.04581259030307974, 0.03372500988564665, 0.02107978832247036, 0.07330664703922887, 0.034884545246079084, 0.043786517569735166, 0.019628308345413497, 0.029638145314229113, 0.08519532038800179, 0.026529486922006455, 0.051218639127910144, 0.014629036886617543, 0.02651612060294757, 0.09884206593156823, 0.020369605664464257, 0.052663530748818195, 0.026559174744292136, 0.07218628941524415, 0.11061723569347975, 0.05202681975319021, 0.012867820858504745, 0.05328435691133623, 0.039299636358214964, 0.03939844254824904, 0.033781968522816896, 0.01725669165382222, 0.00887182580622574, 0.027277340038469242, 0.18026488592788098, 0.1042550363607945, 0.06959009404865003, 0.05351268175628878, 0.013774134474055422, 0.04334131706385844, 0.05345554691889594, 0.09011876829449209, 0.15276147142773674, 0.020444670789724877, 0.032419228340469064, 0.011138787226481064, 0.02280187353702082, 0.03028121483962863, 0.015130360036217158, 0.04038414872822262, 0.03331608364298459, 0.08753494524787511, 0.09137473880283295, 0.016364517148524042, 0.03636517869909445, 0.046508098546896255, 0.04302240998273896, 0.06617781585983692, 0.03671738762228239, 0.03312708209118536, 0.024800838249164726, 0.05824425145082417, 0.074199813628389, 0.05713286471643275, 0.05006186934488435, 0.01768773102441863, 0.022647547039894328, 0.06186731873200305, 0.008508850474871935, 0.051580615672132665, 0.04639944429659555, 0.049070620518778606, 0.01567730084887796, 0.04423947088540562, 0.05077543428107616, 0.056202991024380734, 0.044001658041510856, 0.07186507640947258, 0.006830046834018563, 0.03918535902255005, 0.020511986935631405, 0.0478319138018114, 0.05710789408054083, 0.062499471504481575, 0.007796438501006173, 0.033244875770422726, 0.06566446034177657, 0.05354031071727795, 0.06535814774613227, 0.053140454955639384, 0.02253633597114634, 0.10478651751914334, 0.05356245065828966, 0.0446528940641832, 0.08207089207585781, 0.06021508541438849, 0.014324107079676563, 0.05690753910570376, 0.071066897062044, 0.06140264810153073, 0.04483799239800823, 0.031867409462950406, 0.03909152091270493, 0.040029538119392055, 0.013206836790026677, 0.018053095592486284, 0.06027847535968308, 0.0294306063498821, 0.011384082834176239, 0.04987158842625157, 0.03001922043040395, 0.02686944418406535, 0.02376023612375702, 0.006701613151122846, 0.050502140074968345, 0.04780516967237477, 0.005763729052212571, 0.05065571389070923, 0.030378082827214273, 0.017397098333364534, 0.04199968643426415, 0.05295113547735157, 0.08956203687815897, 0.027345077532734123, 0.044354633052623084, 0.06741360761225224, 0.08226514899081762, 0.05660509908451669, 0.07454810018140463, 0.027873955907360203, 0.09030920243070972, 0.054390449978170864, 0.11407840561362044, 0.06262897483764157, 0.14261975433797608, 0.04590395394892943, 0.03604209643878764, 0.025586821476838766, 0.05669287743888075, 0.055620285396974896, 0.020800786761326656, 0.009697441635052524, 0.031616630580937194, 0.052285022027189695, 0.02359272525345366, 0.06607165905616938, 0.058030597189621586, 0.018935967875163884, 0.04474330010012754, 0.05132226018054832, 0.009348977924204402, 0.01707877730950713, 0.0877468987938858, 0.04141949740568957, 0.055324935519527045, 0.06633606664235554, 0.044849809304240255, 0.049893969684959426, 0.032410222976919145, 0.047565292221524065, 0.05263899295260349, 0.03055564094064457, 0.016357620441985708, 0.04230195408566825, 0.047485477351132906, 0.05861813300139001, 0.06122771192402129, 0.037320294988251505, 0.08025663499269756, 0.018062248427961624, 0.07287243606462594, 0.08142108863760388, 0.08297871392700942, 0.007682226761619771, 0.05672457049630823, 0.02413826987087246, 0.02503162415157403, 0.09797680792548964, 0.00527699125908135, 0.021147069994420297, 0.02682093932713953, 0.039978524324514216, 0.04004577535294718, 0.04006652101393669, 0.041541550533785936, 0.03592588473111391, 0.047192230385037205, 0.07178484402116268, 0.0773409273355238, 0.017396583139235457, 0.038050966667792493, 0.01661947887060383, 0.036855107248430295, 0.051344779335082545, 0.004564883805165489, 0.07503700983380118, 0.02082696207047951, 0.046887469117439566, 0.03302762855685527, 0.013882221819292155, 0.0410166883751029, 0.027871048603687557, 0.052341436741933714, 0.03987363156592173, 0.10690383898514895, 0.054017625628940524, 0.04776965383620513, 0.07380913176964368, 0.06463515226759257, 0.04564756730331048, 0.05980487597445327, 0.07521839647163307, 0.05690280085189208, 0.017043006749102668, 0.042077915502652045, 0.02124380200139938, 0.0186837449174134, 0.08411574928510575, 0.0808943572243856, 0.03391400377656664, 0.013251046766526999, 0.04630837559459671, 0.03158717833068823, 0.02252262108208191, 0.058320756821382436, 0.07076977752149105, 0.0008317177789942963, 0.07335631251935998, 0.11088502172741199, 0.006305315389087605, 0.04134561205583234, 0.0524803169912869, 0.03353095598398678, 0.01666567205721813, 0.02578440129817013, 0.03299737574472543, 0.036488369467758366, 0.02627818901542454, 0.02222426622475107, 0.08680013669354301, 0.10408235248178245, 0.05371312866167677, 0.01876464763265704, 0.04110338654549372, 0.03670298899974554, 0.0258074835273287, 0.04659552450081514, 0.07849266392088707, 0.0445440597832203, 0.06388944611253758, 0.07972297814464377, 0.030217179465257836, 0.010627118059464041, 0.024011869193805803, 0.0688141695554218, 0.08573210287478664, 0.04445056641294111, 0.016943608756147085, 0.04249125824219758, 0.036285478741891926, 0.01951004543732251, 0.026095019307948893, 0.038889790810043776, 0.004604587269451229, 0.03771197659173801, 0.015321407042774222, 0.015015365450733132, 0.06081480202415298, 0.006184505717453337, 0.013538659155939617, 0.07405440247948132, 0.04821300423974472, 0.08873274670012536, 0.04686606079039555, 0.04035532083963195, 0.04093425731445032, 0.03877265596642129, 0.014862235965988329, 0.056552748466210986, 0.06332532960861441, 0.041505816362557874, 0.05491553047191232, 0.0594472048443652, 0.015260458045128374, 0.0069783882692366125, 0.011045211501750014, 0.007528738173160463, 0.007159045208320623, 0.013661572217730986, 0.030578324804082516, 0.03319990640926746, 0.0126762940893851, 0.01355566918068836, 0.05007590407565717, 0.03094560459196087, 0.0055531544644655964, 0.033720608710521655, 0.019407600329648104, 0.07426766603584252, 0.015369216674908757, 0.03353939444247273, 0.08279897437821473, 0.05349680458405807, 0.1342672509171309, 0.03137852470841139, 0.03727525284874343, 0.059107226514888395, 0.09376017572057825, 0.06120962841856865, 0.015193521112744367, 0.2732927045754848, 0.19456495891415304, 0.18886118916974914, 0.12200681808134242, 0.1689296038520913, 0.1043799929621239, 0.1382403514317928, 0.12735756684935864, 0.19383142972665449, 0.21148716700413536, 0.10577047318820992, 0.27825269487596327, 0.15298250311565015, 0.12096146046514474, 0.08035393581996042, 0.1629114316235627, 0.12946250067362863, 0.14591350340314452, 0.1766100183369652, 0.18410968203698436, 0.12485626679394515, 0.20342979129524003, 0.18035733741858315, 0.13543947269358944, 0.062339661733037045, 0.10623918110204321, 0.13215107092213246, 0.0857852693767317, 0.17693951275319825, 0.1741644818215601, 0.15277777377876545, 0.12433107521745468, 0.19063318118212685, 0.10786819812511245, 0.24202782901064043, 0.11992230050025449, 0.18916523414513758, 0.13266677066924112, 0.19280350827161344, 0.1436908218649126, 0.13481831328282434, 0.13256328751242932, 0.08893128604658189, 0.2135529997007501, 0.11735392178619101, 0.15304933662616438, 0.15428186484402226, 0.1712176939772983, 0.17906877752994338, 0.12135185887135806, 0.23064786868710674, 0.1533753530032212, 0.1369319345441557, 0.16949704517760586, 0.15819767730370646, 0.1286250286765637, 0.1388939929705474, 0.1721639964248865, 0.16798426667528768, 0.19035489208275275, 0.09887645561848918, 0.3758907846866116, 0.15663514905158551, 0.14888123609125614, 0.18506816528256864, 0.21724869977803002, 0.2289204017048882, 0.18481420713566965, 0.10990580814259668, 0.09409736165957105, 0.2275292626431873, 0.12567062591833453, 0.14490664936602116, 0.1645809210716717, 0.1396805660859231, 0.15263895864688581, 0.26254982296978274, 0.18713004496549407, 0.1522564509462926, 0.15833304503992682, 0.15221748771446367, 0.13049374695026106, 0.13735919710128539, 0.19465580162021423, 0.31028390351322394, 0.12377848833679192, 0.17638769962133902, 0.06788369448434922, 0.1033732002120345, 0.08461097916287762, 0.14003426888056342, 0.10029096036188065, 0.17105436403184168, 0.21137738660458597, 0.2726635012415148, 0.15932853033225383, 0.15308080751809383, 0.14213908013076554, 0.16422685055482775, 0.10698302183300258, 0.18380978925814553, 0.09612586289163559, 0.2275808969692838, 0.09907706340234126, 0.11407449856520661, 0.19769689488795497, 0.18945224132509003, 0.2265730316961004, 0.12829631567001343, 0.1891066590624471, 0.14132659792179061, 0.13476497824153594, 0.23134991166091737, 0.16880604919166337, 0.06014698402835958, 0.1700726989656687, 0.21550735128262352, 0.11536033884171518, 0.13303227121791533, 0.14430288015113724, 0.20207514866225182, 0.14983481637412502, 0.16011513409114655, 0.12883527384650323, 0.10699654328486613, 0.2159968355009633, 0.07926684939452718, 0.18837581118268354, 0.1274067803376144, 0.14169882472244003, 0.20105937736168986, 0.13240656124488, 0.15340536832809448, 0.19070059691946353, 0.17405729079919477, 0.151623034128739, 0.19395912126187356, 0.10212004890725498, 0.16924386844038966, 0.15598167605217428, 0.1336044776103189, 0.1139414827189138, 0.18594953411769483, 0.10210995952929221, 0.12563760752879805, 0.09348887334307356, 0.1333278739043782, 0.07261181295278572, 0.13110434966942958, 0.13891852310588285, 0.114800481786651, 0.11740554079052903, 0.11282022111117841, 0.11548309677070188, 0.08995103334347088, 0.1355114849584718, 0.11283896728268555, 0.13623839514630456, 0.22429657078558402, 0.15744894893179018, 0.16740364863747553, 0.08784622209326876, 0.11889697608327675, 0.20980571126264913, 0.2806189566129639, 0.18694164862315502, 0.13645145951980545, 0.17310986986323712, 0.1368963420991936, 0.22093713734178777, 0.15657550144580104, 0.055546694990968516, 0.15618922459262033, 0.17904542717001132, 0.13361451336212699, 0.17852626470548494], [0.08403713334231608, 0.0862220544067602, 0.03502617958152006, 0.046390496389639956, 0.032640252367503224, 0.06830032374108992, 0.02213819433123835, 0.03793901440897777, 0.038017986582652215, 0.03489515556383037, 0.047909552982497605, 0.024580844610388723, 0.03987550848133622, 0.03620761356526806, 0.025213920518816, 0.06600044352272827, 0.03507192652191847, 0.04952207230211747, 0.03361298867891874, 0.055616964405823144, 0.05547950141912988, 0.037188359325931925, 0.058589684326321854, 0.06368704568294269, 0.01801097224796972, 0.033273370410766334, 0.052867478676020145, 0.05403858962498846, 0.028698590186034, 0.012167483387935546, 0.09382189176375828, 0.05788579508061371, 0.0696342743392433, 0.011973447680863883, 0.026368683151480173, 0.054496147129083836, 0.034083765030147574, 0.04105592356814493, 0.03445408810230513, 0.02714919842659466, 0.07693267141979548, 0.015140505913164348, 0.00884553462627434, 0.04753840636582144, 0.05031619521398699, 0.04657590881951394, 0.05392969405699161, 0.04447429215595607, 0.07511665999528862, 0.05444573854366618, 0.06175367724931529, 0.012911150791502048, 0.022957847123184515, 0.02460582673759951, 0.04455600692439945, 0.11351613538159479, 0.012887686475991242, 0.0575616747711695, 0.03358800272126833, 0.03085833760128627, 0.004028576771698652, 0.022884632100261027, 0.033863936100275285, 0.0955088556774201, 0.020188016013332435, 0.060998705260816126, 0.0571649101743054, 0.017055875111010768, 0.010135100005314717, 0.09122358965537242, 0.04153210466967956, 0.0940147390769374, 0.017339408082226594, 0.042156523784562465, 0.044788610370409106, 0.05410519713956503, 0.03192573939750512, 0.11197714135050775, 0.04702891576133909, 0.04846114011841917, 0.027717350298658978, 0.10752340493303154, 0.031894931171630184, 0.016733332942690582, 0.07218573783193866, 0.04069778129398342, 0.043078751919130166, 0.04600234262104477, 0.02662681264712686, 0.01904895818311601, 0.04546559843865614, 0.02439837395814398, 0.015233321295630549, 0.03226612949924123, 0.0459939539582739, 0.026136525951686407, 0.012226675171405079, 0.010492482894821274, 0.04884954286558975, 0.050551399528499574, 0.032568197967785026, 0.01575748056864306, 0.01053946994004711, 0.07382924923853529, 0.03841347564312239, 0.023066307936284332, 0.012364568124945846, 0.036051821924986384, 0.06332716821963269, 0.07476759203259023, 0.021047788829873168, 0.02411540214633269, 0.04053252080695764, 0.012736543074190136, 0.0250825900659566, 0.014696601053489553, 0.017663384750184995, 0.02080095913110962, 0.04560200039357428, 0.036729595233355804, 0.02936824487762586, 0.07734809025761581, 0.06949987187380753, 0.019414814962675015, 0.05035762524893207, 0.07258178230615393, 0.0157822213781577, 0.0651653463982286, 0.022978422329610875, 0.04786330042406917, 0.005881757345876747, 0.07254389159741902, 0.033932627374005896, 0.04005284251404866, 0.1200731968387, 0.05381805972466546, 0.04068976801429545, 0.04485814817129605, 0.016207679798225724, 0.006337069254744077, 0.05527079991635777, 0.047246618797221494, 0.038848073492127086, 0.019713606490122697, 0.03343236429857151, 0.017093484282433506, 0.03185383821537178, 0.04846097157907583, 0.03904799945772656, 0.04586402927675555, 0.02953417569158539, 0.05718929092249563, 0.033023782795475375, 0.023750715566078023, 0.01914881582882616, 0.04116774559201252, 0.03156580256238099, 0.04366699636222855, 0.06799277008300827, 0.0591515944970231, 0.02036128594960657, 0.02599234054345758, 0.03873481122296184, 0.014329371061326276, 0.03178469303454603, 0.020459404575728604, 0.020447643210871086, 0.02480967124293168, 0.033938545403220964, 0.017742646122050863, 0.03311590103793048, 0.017777058791609544, 0.025392838438311895, 0.04775432441684027, 0.02798235160298646, 0.011225412618519079, 0.007985763246148464, 0.07386061287815533, 0.03374913016394262, 0.06164275537875872, 0.007683594228564612, 0.01338962728397981, 0.04052169981502718, 0.027477087888626323, 0.04327226572880342, 0.008328104478066728, 0.045439222031423164, 0.010643267192907873, 0.03883277088583958, 0.048221358428559, 0.033608453438406995, 0.03535851618395217, 0.04489825670457175, 0.016411698588560668, 0.024660812698364742, 0.043285051736259655, 0.06626728726851364, 0.038991990769582416, 0.08322502651642408, 0.014460360605059373, 0.029064255443611936, 0.0663801396806394, 0.04365498027313621, 0.06519952924141, 0.02383366182085968, 0.042133123628915324, 0.07500317939106496, 0.042565381079311335, 0.042414266405807394, 0.0431257743959225, 0.018287478277700085, 0.032491290401066505, 0.015271301062086658, 0.0016062642117181134, 0.02362872947067503, 0.02941489580177492, 0.07578057477310782, 0.05860956813839655, 0.026261995831925063, 0.004698510606577921, 0.09341354391747907, 0.014986578739368388, 0.012831036189210512, 0.0257256212869599, 0.05434705492769999, 0.009966359563892888, 0.03433560877437553, 0.06447310934984876, 0.012225825771419032, 0.029380119240452206, 0.037419066704328985, 0.015207244620297947, 0.030073313898737394, 0.012870930217867418, 0.05227427764405167, 0.0544738233269703, 0.09069138071349553, 0.043960205023928035, 0.023021930378050576, 0.09792293662265425, 0.07240355195057008, 0.056608772476113615, 0.05631891161864323, 0.021610020757502606, 0.03660651937788052, 0.03430140294855641, 0.015991386364123995, 0.06390825740151829, 0.024659380113946337, 0.05687288511844893, 0.0035877444034051755, 0.06044452108683125, 0.040034153799135844, 0.04814851495827879, 0.045626511376711636, 0.0050549722753555305, 0.05393837383317371, 0.04138317334675982, 0.055731218758850336, 0.1538399853292973, 0.06434982282019432, 0.03312979404243731, 0.042208793963636124, 0.06181164329210597, 0.010496971212447652, 0.03831595265036149, 0.012989794504978966, 0.024602657048812798, 0.06256286911065541, 0.0374139147630382, 0.08716245797733146, 0.06418463128108172, 0.033733969283921104, 0.03410339220276764, 0.054566106278329134, 0.048662935338553884, 0.026710360280929074, 0.013958659199547144, 0.06183569462248876, 0.05453424851199793, 0.007944572134874761, 0.07575450480104455, 0.032893873435715516, 0.02697908668778837, 0.04533301160160092, 0.03224832178544133, 0.02526803696978717, 0.04568780224109369, 0.05183717085709495, 0.03753064741050044, 0.056789718613389044, 0.11943504559777438, 0.05277958923890706, 0.02008723714689334, 0.019430740015400995, 0.040537278212967424, 0.018685976148492867, 0.03969281183315381, 0.06656735624757505, 0.04319885918389886, 0.0325348693126392, 0.012157612345031193, 0.06387757558015085, 0.020453534427008802, 0.0926544197324303, 0.031979013151759585, 0.02807181343556412, 0.02237088396213949, 0.07595507428050041, 0.04125169350675518, 0.018840245189025037, 0.015313190749786315, 0.05553842890226553, 0.06708066580035994, 0.021625338685548594, 0.06343948053977182, 0.031048769822284102, 0.023804803288752036, 0.03298053713214975, 0.036928387388827345, 0.013714374827912018, 0.06150467186084679, 0.013138358105695056, 0.027188948813765764, 0.026856616041773272, 0.046937636385161075, 0.07273720622423195, 0.036544282394911975, 0.034202313305990356, 0.025568004442198623, 0.07678077150616916, 0.02631773638929571, 0.032684880819532185, 0.007426985417447625, 0.051803225501170086, 0.04727850720706967, 0.04762739513910586, 0.013100993124798182, 0.024464081319409515, 0.0124173745655665, 0.07805779411066925, 0.04043732672148655, 0.08420394898782815, 0.04490672197613505, 0.004936668190038613, 0.042386905575591716, 0.011189178574920423, 0.02902477127199452, 0.013838581620685518, 0.048199134217875625, 0.0042390517680154696, 0.004705953150762305, 0.1895050554265899, 0.28255642361698613, 0.10060039093537677, 0.15101759484218014, 0.11059441393421543, 0.14793494896542642, 0.20920569587859417, 0.09883596787169095, 0.1490893515367662, 0.17744249544076382, 0.1863699172052645, 0.10856166091417113, 0.1322831751237954, 0.18168988607583508, 0.10194024041054711, 0.20463057282951572, 0.1809476847730337, 0.15560529705497528, 0.13222645397388166, 0.2559701389362735, 0.12566898649017658, 0.23472409995813526, 0.16138916895274194, 0.1162503568095065, 0.09315661334943387, 0.1504346938623536, 0.11955481578385639, 0.20892005233514696, 0.19184324770204483, 0.10260965569966263, 0.20069001572987727, 0.17247781668218876, 0.20741490406855462, 0.122904542893652, 0.09463139389070774, 0.11788063021677157, 0.1391510154691435, 0.12387713747880152, 0.19752242602407935, 0.08332393612832793, 0.21796840873937454, 0.2276990736924833, 0.1358603767209476, 0.21800355685334052, 0.140042174907942, 0.11731364088313234, 0.1430021547862599, 0.13570859938138916, 0.2502106745997744, 0.1692619174718857, 0.17008252021285797, 0.12227272719986017, 0.11834117929421126, 0.1199576324753223, 0.09579654467562515, 0.35987807618033507, 0.19160770630884558, 0.12214056937204254, 0.12808556488204387, 0.15607164541800178, 0.17793181111976025, 0.1504959349310206, 0.10592183684028926, 0.1959676659035106, 0.19016310963178837, 0.16682732069203932, 0.20529112448134731, 0.135775325639594, 0.09932916761646349, 0.15527057791909865, 0.10531323361060313, 0.1516149595620171, 0.1930288606954198, 0.14859940766567184, 0.1349585839817601, 0.14430879434991267, 0.1544059710877557, 0.2592438471413428, 0.18693663840813024, 0.16749223904503932, 0.18795130654208123, 0.21941740276111713, 0.28976987686849415, 0.25328095581743026, 0.12080369997889766, 0.26253655432693423, 0.15934452624811282, 0.27797984500085154, 0.09639286751588506, 0.18301871154577504, 0.10797006483640402, 0.09909244644786082, 0.1273574366144115, 0.18795620950479663, 0.16293214664103525, 0.2059155014613944, 0.1591172432827373, 0.15926177343053205, 0.3067047713745025, 0.17092336299678973, 0.1587009204611663, 0.14192345702359754, 0.12365859557664204, 0.14562355444556283, 0.09907062060289806, 0.23286051447353057, 0.12620432107078453, 0.09928867986966526, 0.169119440439728, 0.13951941183017147, 0.0945578494499768, 0.14040929956301568, 0.1832020976730893, 0.1294746814716247, 0.1554960222734559, 0.16738445047409306, 0.15222763071858114, 0.14568064331768021, 0.2273093034783679, 0.16488300486197396, 0.144258416408012, 0.23966417197258244, 0.1391074557097689, 0.12062561518001942, 0.1125983467265483, 0.148261746752166, 0.17791212266010625, 0.1732621528208256, 0.13837476921898706, 0.19839495420455935, 0.1520975796325553, 0.2724851253292253, 0.13599096406852046, 0.1265595560412734, 0.12404528611730184, 0.25066602194020826, 0.15613834103268964, 0.2171645986457025, 0.1262775514154665, 0.0967956688855925, 0.1472395249912816, 0.22096160619008928, 0.15287137440135404, 0.1539661600104263, 0.14707932068455606, 0.1469662154634153, 0.1371955300771421, 0.11162266480706393, 0.18054748044138957, 0.08276863729641323, 0.14104967245892172, 0.11141815763567725, 0.13807738920853985, 0.05479715073541288, 0.2767042779634076, 0.17474010496610598, 0.1603155733356553, 0.09747194066163033, 0.19528224703765687, 0.1522548115181346, 0.09392647808718105, 0.13679397743075125, 0.11986020141311231, 0.09593922089064315, 0.1856890335799225, 0.11621255037044326, 0.14843227792411082, 0.18808416150990995, 0.11245197796773528, 0.12586316679634396, 0.10573822088659772, 0.17554196919645035, 0.1849583389177438, 0.1456131662933096, 0.07231391200255002, 0.08102147419366144], [0.0727885800804342, 0.013002823745351166, 0.08203357593306611, 0.0126542269267262, 0.053993513011523796, 0.025323375330997572, 0.01160310066845869, 0.03029853225715699, 0.03660520553709038, 0.052400138229131706, 0.037402124669883526, 0.02843197243618629, 0.006021301218894341, 0.027785277399685115, 0.024156824520398534, 0.061793713004238186, 0.017517603963853854, 0.03982065275551812, 0.0043420633019488905, 0.13391840511993056, 0.05739133512120574, 0.022657975411763596, 0.010498285053237792, 0.03984149034705855, 0.0327662623397285, 0.09874013027236347, 0.00384515353700056, 0.02765764715149999, 0.024229547331830668, 0.02065898005610272, 0.010912430269884007, 0.03471737720012184, 0.07761150959037966, 0.07335411384701729, 0.023829231917437528, 0.07407067418699304, 0.07280455301365546, 0.01803000378722866, 0.05814071466785766, 0.04881551707043283, 0.04103674455696056, 0.044647523787833994, 0.0438443495471391, 0.02059506151014038, 0.008697745731971677, 0.016279732282724113, 0.006834469555366424, 0.020670812284093232, 0.05658996501757253, 0.06875511949821826, 0.03777653482111712, 0.04262772148414966, 0.059249653751331, 0.05136418434220457, 0.01213881063214954, 0.030518705926595197, 0.07161943797743128, 0.038842048210602616, 0.032600136173348275, 0.050665320633279706, 0.03993264331872906, 0.011366967472337909, 0.041726775272118474, 0.025906180549833565, 0.03736226511518321, 0.0215458398264262, 0.03433002399340753, 0.020769503560938665, 0.0321478225410946, 0.08621756513152393, 0.019319492557476607, 0.059940565467601827, 0.043353781314386476, 0.029569260603297624, 0.059105541121454976, 0.015019217915382358, 0.03677882021293044, 0.015796912071715682, 0.03135462276517384, 0.029501996168325988, 0.051629760212475256, 0.018454910623991204, 0.02701401838191575, 0.06635810699193709, 0.052262939542772315, 0.01876226701443234, 0.02966334386127851, 0.006673315778419737, 0.03696265450168041, 0.010748138884082438, 0.04789287907882564, 0.029432998459425666, 0.02348808147343657, 0.094630045575961, 0.07723277870325312, 0.04362730534687158, 0.059369990842476975, 0.05773152412486173, 0.06578263706497608, 0.032146363143598845, 0.031938255358968055, 0.06592942717214746, 0.09468285201658165, 0.10623950285897141, 0.021612887841559226, 0.08141039405018091, 0.05518528918224958, 0.0863707597337423, 0.03319719445801551, 0.051352765801693165, 0.09021444501535547, 0.013573287287727, 0.07027989493743067, 0.07394306692144564, 0.015511725308193315, 0.03830409360929363, 0.058319144206301826, 0.016904111177990996, 0.020671026788712032, 0.022547543837478565, 0.06617734088532387, 0.11263420730228386, 0.05359084953764274, 0.03992616221488964, 0.07017638879798113, 0.019022602843300953, 0.06269039210653113, 0.0190140207433292, 0.0680149483284162, 0.06862103112883146, 0.04723999596711609, 0.03896548029696269, 0.031419410820930235, 0.03313530604505251, 0.04427683299347278, 0.03408147059681435, 0.02677079504205575, 0.0593843664823761, 0.05428010650399712, 0.022438410782225193, 0.034341262503256725, 0.05707336649779351, 0.032665667334391225, 0.007234500559617676, 0.04012138823107366, 0.059596132336845326, 0.023900330622470187, 0.03895250276752538, 0.02348728665721513, 0.02084365129590996, 0.04466456158326999, 0.04287894469715896, 0.07366244125390246, 0.11860322732959064, 0.05788066995240027, 0.05739938287485031, 0.02848201329940029, 0.027810696197012742, 0.011463976228579639, 0.07845004644965933, 0.033760023934225884, 0.036426553833148176, 0.018853397003465125, 0.019656000508656426, 0.011298175649567237, 0.04268139360412475, 0.04802168910241416, 0.052705960528504466, 0.09093950893129073, 0.05784845595518428, 0.041731536508567875, 0.024163652279023683, 0.031121684155697306, 0.023683853327266635, 0.09501250731127878, 0.00769633139791568, 0.05632725814657827, 0.04261866249444504, 0.007705848603960007, 0.06531523916149332, 0.021620119711564436, 0.08056837149084577, 0.013324207205685877, 0.05168486108642913, 0.02806203432321068, 0.06387913456907676, 0.0412930392720286, 0.03588694831236236, 0.03342726598343542, 0.0356581753059741, 0.03076887768392842, 0.030309688412554325, 0.037413098879398844, 0.08809911537795298, 0.029165520775882952, 0.06010327488183976, 0.030158039392723195, 0.07405296223418367, 0.012464480354420602, 0.03298673095301755, 0.01469084102990887, 0.04460626612267187, 0.048685542593199405, 0.027626369696771427, 0.011935832763781712, 0.026681386835632787, 0.027851484633321245, 0.06429810422442614, 0.05113174943553825, 0.08679558613127278, 0.03882894810709742, 0.039626732919245, 0.07568055433371375, 0.0371232993089624, 0.04675682048283277, 0.026804514402042956, 0.045201822875007514, 0.027956802570711703, 0.06747601313456413, 0.03662753700008316, 0.023139521043988007, 0.12099264024366295, 0.0029174011902913695, 0.058245400582710584, 0.008237785584623776, 0.04225509248734002, 0.007590346006421193, 0.010748192510237137, 0.06832238707330919, 0.08262036863954798, 0.03293652921133945, 0.04876138146726355, 0.07797071289631628, 0.03299471741962818, 0.04666748696998243, 0.0335306380574982, 0.0384070519958773, 0.05113769044739105, 0.0501394970342517, 0.03114501536343127, 0.03218106692656875, 0.035903059141409975, 0.015654908098851242, 0.04647516442703144, 0.04532365000716621, 0.10316903011933451, 0.014591112661535942, 0.03422784701650662, 0.013108450033131146, 0.05496647914931659, 0.0748374592512846, 0.0462037816102947, 0.028829575899327477, 0.03944006793561482, 0.036532017327244246, 0.04516806521062409, 0.01745089494262732, 0.021995087191762946, 0.038923678709374326, 0.06962492806656707, 0.027482521367229285, 0.03197856115988426, 0.04707442138404135, 0.04957955570951585, 0.04405955130594873, 0.034492549546543634, 0.07219297736282311, 0.029549757919965253, 0.04527080526214935, 0.04879181814049521, 0.03871902598128204, 0.057303089453207876, 0.013916329968900932, 0.0037304725687605364, 0.05597416439183778, 0.05229342984215868, 0.03598588856778318, 0.11855993570098955, 0.04312729891089182, 0.07639062590897083, 0.03871589651211135, 0.020553865132012197, 0.0378056499926794, 0.04333990746207776, 0.12244267614498255, 0.08805790750850594, 0.12361859812611535, 0.06668336494194885, 0.07648566677685707, 0.035693472807085326, 0.01911885413010755, 0.0546563207922924, 0.09195052282584291, 0.042571444665232015, 0.007515223424566249, 0.05213001945747003, 0.013452582474377368, 0.018867303414510626, 0.033993826307837045, 0.015215213849930274, 0.03597674147796727, 0.08102015652243169, 0.07754063113562523, 0.025305052423068596, 0.10684266686439516, 0.05708946200508264, 0.054720503638588616, 0.05419037079498653, 0.026678699782238375, 0.06372237382757087, 0.04007283740887239, 0.02329276161148183, 0.02522749368161444, 0.046310103122865966, 0.048762132233429345, 0.02033047772373163, 0.08786721290239403, 0.0237634364560607, 0.025400028173481266, 0.033310050700580886, 0.029357441122673696, 0.01314981303538286, 0.04161288098041569, 0.015151174645119858, 0.026514191976598194, 0.02322417950528043, 0.059313476536302805, 0.1117945979199102, 0.0817464308572873, 0.03039727141449769, 0.12867623399342262, 0.0196060266781358, 0.05733800007991734, 0.0345458424529962, 0.07398360063351932, 0.06690665658923887, 0.022636251073450814, 0.1198748566751038, 0.034997190814465284, 0.08322193918208923, 0.048425926886979616, 0.028015559599284205, 0.08470280246148187, 0.019080482701200153, 0.04043246972404661, 0.07749082009878851, 0.0017501382770264643, 0.04260889487341047, 0.06076933853628655, 0.07388090654726952, 0.05990925545413649, 0.02486626790355771, 0.2029096175946536, 0.11023796088392697, 0.18178298108039365, 0.16949249461533564, 0.21375395988504733, 0.2172062125417494, 0.10189104224404982, 0.17128471134891435, 0.06775136811718827, 0.13744544327980088, 0.13592276692150101, 0.1021646888506028, 0.11226908213669255, 0.15801176308624207, 0.11238709032054871, 0.16444677907613017, 0.1543957514748458, 0.159823453774856, 0.13286079009694438, 0.24191722123613282, 0.19270190969109538, 0.12473874124548129, 0.12301234678635675, 0.11931534435960556, 0.11153798144791396, 0.1901319758185456, 0.10730740644278065, 0.07583130511545366, 0.09554167488409628, 0.15618018475511383, 0.09055994300832672, 0.1590239644170769, 0.16016397985719866, 0.19724016858925744, 0.10778527676818833, 0.13167624962666344, 0.17597655555413616, 0.16763093160285106, 0.1899130738550617, 0.18804965690980036, 0.13119977358127796, 0.1470417823762663, 0.1626078003356534, 0.10867039177326426, 0.11691248660246212, 0.13347784327643533, 0.13009711258834408, 0.09538286485739293, 0.16080890331537495, 0.20391325406249494, 0.17307639182094606, 0.11766316083770607, 0.1734534602972769, 0.19446729802556578, 0.11383423040951453, 0.1255659706469986, 0.15480041443820924, 0.14789863639781553, 0.18618792535797243, 0.13053575921202862, 0.1548224011616361, 0.12364865175538486, 0.09138300489153593, 0.12259530384213695, 0.07869913227735989, 0.09541487967174861, 0.14580741554739016, 0.18251229678430866, 0.09962972689179644, 0.2295460503908896, 0.06789492533331917, 0.16003463357206316, 0.07096944301719628, 0.12576523011610394, 0.11552237409857974, 0.11896122787748614, 0.1711612332972788, 0.06461496585078778, 0.14507745632961874, 0.1111331346234487, 0.0940955077267943, 0.09163777509163465, 0.08100471218987819, 0.1914779003709555, 0.17921266416388174, 0.1345138546199568, 0.11522929184138776, 0.23930533638884946, 0.12618712239688443, 0.10594601457517956, 0.16198264194592354, 0.11854708840649937, 0.18316966151037525, 0.20055929048647805, 0.19989346814972742, 0.15666121136276953, 0.10063926223665477, 0.08390938818094232, 0.11806233095065241, 0.16962312792818393, 0.1476329417839166, 0.23367984550854853, 0.2022120945395962, 0.2340231601509356, 0.09302319147654119, 0.21601575787269303, 0.15647617048553883, 0.18353500884146462, 0.14515498442755592, 0.15478218154561135, 0.18401344607193626, 0.15182238552839528, 0.18078559589001442, 0.1492314761684787, 0.09933063850527811, 0.13041644867870117, 0.26256419477924225, 0.10517469427037625, 0.0864656703666814, 0.2144653338097757, 0.19719349851291026, 0.21269744802867213, 0.14181219041347504, 0.11637272403365183, 0.15979210545699443, 0.10457885406550863, 0.22308740824941667, 0.1573167987648518, 0.19787283464064523, 0.2569355782602103, 0.14586951463453232, 0.16952059472039824, 0.25296146650948836, 0.17019648345247393, 0.20745670182570336, 0.1383631093607795, 0.11858671047394315, 0.21930962951192934, 0.1970774208706233, 0.12634727307745527, 0.15252121093292392, 0.16966397573630657, 0.15127314645196163, 0.16385131425434546, 0.13221286357410494, 0.1335976594277928, 0.15936208498333732, 0.10477605275809766, 0.07756069497836214, 0.13014261821104636, 0.10452821565371369, 0.2692866469583204, 0.1520227328423531, 0.17287583000236945, 0.2095664773256548, 0.18102957957213928, 0.11027188325721411, 0.11563206256757821, 0.1447771651850593, 0.21377406203218047, 0.140404166773923, 0.18136995243689708, 0.11215466690520126, 0.2533569364177604, 0.11003675555149395, 0.1654290416908841, 0.1414531096816063, 0.2113962017240063, 0.15513835114336785, 0.25266384135090536, 0.0972695172493977, 0.23950626592962976, 0.18773038210647722, 0.16765396020585493, 0.15376657878439273, 0.21688326051638973], [0.047057146101348826, 0.020339391156730634, 0.02189264208408854, 0.017375199710048975, 0.014585991363762128, 0.07005959103304533, 0.0425065991528813, 0.005606745666403685, 0.04138681992527939, 0.03368395906422408, 0.0671978312874994, 0.04030815663657362, 0.059710172185253714, 0.013672413319469461, 0.04854514932019576, 0.03856104715997654, 0.015905466730586224, 0.019962485474083694, 0.013382808143843808, 0.025355937898219116, 0.1065799063672462, 0.10894048373184859, 0.02177844518765567, 0.02033360910812213, 0.07547677494585514, 0.04093718377032107, 0.05483733970792063, 0.06057834132544457, 0.03712266345598525, 0.016155045727388035, 0.02302092488764996, 0.09043447312808807, 0.06022506370960225, 0.020736891198002046, 0.010491676587280969, 0.06708025211288084, 0.04923732891198128, 0.08750146720558406, 0.04556481065529008, 0.04794955426346391, 0.027620083945352706, 0.09080340575066306, 0.045367749858527415, 0.05107755637577465, 0.011508932183196229, 0.03395860158507863, 0.04253264614230683, 0.019377560106917255, 0.0863269318435942, 0.029450493992396423, 0.04613810489254613, 0.014518537322029233, 0.022215611346426512, 0.05870884547250406, 0.014357755576530773, 0.006634679091568556, 0.03480708992649471, 0.09253702441891355, 0.05689220585589928, 0.007292551829689934, 0.03604124991163131, 0.0562471559932155, 0.047051538337743094, 0.04869080561723921, 0.04109216335740301, 0.01350326780905767, 0.050495559379698775, 0.0054690868484847735, 0.03764553761650478, 0.03686638023223608, 0.0645300450043813, 0.021964874599249135, 0.04745579910494628, 0.023968581395644336, 0.01254453654250791, 0.11307355872685872, 0.030984399284446434, 0.08819180435591167, 0.045502684755070556, 0.04060433771941931, 0.013378759369163985, 0.026695802695147937, 0.05143368000825567, 0.027163708131880532, 0.03611713475097091, 0.018540923145689794, 0.06004743473303895, 0.06136983272529418, 0.10794439323006139, 0.05247822174081399, 0.024381811137221033, 0.09710141457617284, 0.030258615245862357, 0.04316523941534181, 0.06681003758022863, 0.03601038039872243, 0.020609115393111305, 0.007112982256653449, 0.0984832380087145, 0.05036637780346698, 0.026040590676148574, 0.0021345881302089944, 0.013357821228583495, 0.10377582538151935, 0.029070244335959998, 0.05531539006399051, 0.03258271533395014, 0.06866626095988097, 0.07666570509994224, 0.050326154357002634, 0.02156279718263015, 0.044817089688994234, 0.01670992512616419, 0.03514946228073489, 0.019344200808254462, 0.015974665537566667, 0.017572291150328614, 0.07717768932061811, 0.047904512123955835, 0.07214472914535193, 0.07179921583062218, 0.055175567526490464, 0.017793928047702197, 0.10230207905894327, 0.05441294231962773, 0.022768066076922323, 0.03868219247388263, 0.04261518062482919, 0.047979921988782384, 0.03211513739980517, 0.04174358707161681, 0.06559232550282633, 0.06271787551081469, 0.05596052802678558, 0.047860829790513364, 0.019480508917401877, 0.06707529552401074, 0.043438284642874234, 0.08588176581167406, 0.04677960393770088, 0.0029722480582178483, 0.049729869821138924, 0.06380691929089446, 0.01872823547361599, 0.039087295937802524, 0.02736738409786936, 0.05931762107197316, 0.03253851206071916, 0.04937612489166279, 0.042434000830736854, 0.06521375549416389, 0.027092942675094933, 0.012826827493676496, 0.10889624981510063, 0.04847898230617566, 0.010496746174119895, 0.04780987345222985, 0.032415646879423055, 0.02083829634131924, 0.05283563623144742, 0.03759552356636813, 0.04726799265030892, 0.02930211616800197, 0.060520122473638874, 0.03325827847865801, 0.025482641180015864, 0.048935563048167575, 0.03840409489648958, 0.04741502024473683, 0.02572603114399939, 0.03416090242324337, 0.05133164858806038, 0.03321763751427493, 0.039774220166427475, 0.05547565182731037, 0.12458823561187714, 0.08871279010969786, 0.06692445281171991, 0.043960883011741024, 0.04068659257984931, 0.002768508411170314, 0.05395728088314495, 0.04952889048464356, 0.023821760644955982, 0.05659732712252487, 0.06896367927472438, 0.04659522572652467, 0.006627035449304048, 0.08889477429611069, 0.061101659816960176, 0.03197326940754729, 0.02498991449453658, 0.05318681476637722, 0.016269621837343422, 0.05151529135482927, 0.01519817126644475, 0.02220625932809086, 0.025513887991227453, 0.01829738187934122, 0.018701286415659615, 0.05538968527088723, 0.1317712751727912, 0.054678273041762655, 0.007500001736315749, 0.026172246716375795, 0.07113398338157324, 0.025465716382548697, 0.12322330441806587, 0.05344024431260844, 0.02749313743064, 0.04086218376253401, 0.07780718376799937, 0.07814892026926241, 0.07691161166275702, 0.07534885358425879, 0.0474405003290984, 0.03765732004878022, 0.0440652012043903, 0.04160636923305931, 0.04911388150386272, 0.08263730684355383, 0.025557493715877497, 0.04456228884537855, 0.04213031208623321, 0.0038524931381201193, 0.041782711181909814, 0.06882072726805365, 0.021737840612448996, 0.038494772893647035, 0.04661802450315126, 0.039558152728263414, 0.05211909887410941, 0.04021629503357314, 0.0321585975677496, 0.04258175237825321, 0.07875888713545377, 0.05717578479239056, 0.019110499941293272, 0.019327515413263635, 0.016223365448475364, 0.029168431909995216, 0.03395850582408809, 0.03071542964467118, 0.023575888556097786, 0.028749151989036513, 0.06419724874919461, 0.024900646099159797, 0.006742659663300842, 0.01760601051031582, 0.02925734982014664, 0.012850514932295248, 0.07323591414118007, 0.01881484362867571, 0.012254843266770966, 0.0321390355126031, 0.03248295536445033, 0.04963403988269068, 0.08955017017621188, 0.026666731573641304, 0.01939674486376105, 0.05779266177165893, 0.02906388389096866, 0.04217629651388815, 0.020559179866986892, 0.027317601789329803, 0.0263602580995329, 0.017122668401908972, 0.05667369842769639, 0.012500143662515669, 0.042607994720099435, 0.0628609998872684, 0.0348738813021731, 0.07425211445097962, 0.055563732786404516, 0.0674983599193154, 0.09984125908944877, 0.05485591734008444, 0.03417079261834583, 0.008566988887445582, 0.03033770616316507, 0.1185475250766162, 0.03857231248290308, 0.038360734319975304, 0.11122663565460714, 0.1122443758011345, 0.06304729714869492, 0.013679357906503063, 0.03951121835158237, 0.04787406778984493, 0.05213810934595043, 0.020410733094679254, 0.06150681307659515, 0.010787462177235755, 0.04822584004291604, 0.020743303353928273, 0.03550912906986571, 0.12036116928943705, 0.04686118847119713, 0.034765387930336504, 0.11340623240797751, 0.09290637072896765, 0.02804767017463042, 0.03704793540941131, 0.018616294706120126, 0.024576872444501328, 0.05483762316045262, 0.04571422844404175, 0.02798527805885721, 0.04731440608720145, 0.05427819128418642, 0.04551649348990572, 0.03492042880445238, 0.03945475001068365, 0.00941471592898691, 0.02751209619154613, 0.04322489851244515, 0.033878794375566706, 0.06503385506690511, 0.030709946370353142, 0.058952250758246075, 0.024415978658643943, 0.0660167918390324, 0.05947584887185405, 0.07924724520454485, 0.03324576060197527, 0.03320121641961798, 0.04389002753962432, 0.06731691965532881, 0.028686964801783045, 0.036108937610181115, 0.016579519724473357, 0.045625009844380046, 0.03286830525124266, 0.022541009107484453, 0.0026354542604812813, 0.04265099140484968, 0.04501097122087114, 0.030008112155501882, 0.024271931146241488, 0.03899287560113496, 0.03559125369534858, 0.0631978449171349, 0.0733060954559234, 0.043934418504396756, 0.04597277162716754, 0.062485348673597466, 0.04072528002002547, 0.004019797882891351, 0.017471192442181132, 0.03649508039797506, 0.060923801014019605, 0.058792463969439275, 0.23453668420833929, 0.24970654278032242, 0.0984828779473901, 0.09764998715611235, 0.14730543919628666, 0.08435596381464312, 0.13076944667245113, 0.13829780802611383, 0.1288122145999824, 0.30035776356535576, 0.1759016934421755, 0.16291011395233293, 0.13718672006601287, 0.10049365190488678, 0.12765978087460803, 0.0712695503006539, 0.1510296683878668, 0.14963402472917112, 0.08218385940117222, 0.09490298738162364, 0.17123770419388049, 0.20931126279456003, 0.13292448264696907, 0.09872208124086743, 0.22745211758921224, 0.16368157981384188, 0.1369596975705316, 0.15228352449353666, 0.11126569081698695, 0.19185008120632943, 0.16557813772270757, 0.19916357021898995, 0.12361887391776809, 0.08420903581164538, 0.20874045068217864, 0.21124517515061364, 0.08665602023322737, 0.18524678634299388, 0.18592852798681106, 0.08098411208559429, 0.15732332583396666, 0.14704461690158616, 0.15855959256089505, 0.30105462778479825, 0.09649913157186202, 0.16156399021706275, 0.1394537121297852, 0.07853178037030083, 0.1509251280297195, 0.21904986441856433, 0.21302801496799917, 0.1137527033326126, 0.1136316461188178, 0.1998745151344807, 0.11984242051238976, 0.15847651798638607, 0.06824099789223365, 0.1816892578837372, 0.18059051926097563, 0.1102303766134766, 0.14649237476048932, 0.12346113641415873, 0.16123086454406862, 0.12423352924205604, 0.1602673251181841, 0.12026019124013763, 0.20283420389938742, 0.13187750092437192, 0.10887291477692705, 0.16980674388187547, 0.23661698064496442, 0.12077675666660072, 0.19827443325231153, 0.1464589580052322, 0.15684286613137494, 0.24389510703904016, 0.2315636808353086, 0.19218651637915643, 0.16655102342126832, 0.12024057938927606, 0.08276541972713125, 0.1289629653817223, 0.09556274230201399, 0.11430994802785498, 0.1447346779487787, 0.09866248726123765, 0.13823270587430847, 0.33945732840126563, 0.18481765453132892, 0.13406618348052426, 0.14984108297334564, 0.1998778246343136, 0.19049933029999658, 0.1610640565594358, 0.18640763937465607, 0.16623458314326503, 0.12370813848270525, 0.1183624305732308, 0.10014174941686854, 0.18358904868364337, 0.09188123783397098, 0.19153829874290576, 0.17985375718243662, 0.24488912144255257, 0.28582372732700845, 0.11773463684104143, 0.1307440278751235, 0.16148627825802372, 0.2535535145791308, 0.14833886116262407, 0.07046249965506216, 0.12159765818186345, 0.11336532331282094, 0.21336469528896196, 0.12970960999448455, 0.18857327800604606, 0.09138393951880355, 0.1290387774427091, 0.11034128316227468, 0.13310052965196872, 0.2637549405617099, 0.14925721672273454, 0.1325173988457649, 0.1908158318650338, 0.1633314623106872, 0.09723240028946631, 0.18381699048463376, 0.09332870734074424, 0.16754185089901572, 0.10535318509585435, 0.16650058419233368, 0.1235592952598968, 0.2568201747752967, 0.08929043572636382, 0.16416594656484743, 0.1119091587081071, 0.1540599598158752, 0.11035979184652529, 0.1775389765539477, 0.17209158579428352, 0.10851466142001653, 0.19207201687799347, 0.1628035817655825, 0.1367918170628048, 0.15656993964747076, 0.1870344065490269, 0.123286253862804, 0.1125651291541515, 0.13962336996149632, 0.1404888041677975, 0.1110150115264039, 0.13770954443081734, 0.09268340849948507, 0.17709813891879975, 0.19707044947051233, 0.09132645228096554, 0.17017429754618676, 0.08023817993460164, 0.09689528329838669, 0.14259379927910146, 0.14078385527095488, 0.1734261109583801, 0.08172229908767246, 0.12012339858037811, 0.15047914228372036, 0.10327936210218938, 0.11823394230657047, 0.09947877692719621, 0.11138778224947954, 0.22537444117328814, 0.10513009263142463, 0.0688420168514694, 0.12086566117021347, 0.18752188361700506, 0.20602842282143333, 0.2899091516531283], [0.055175456443741444, 0.007651393637887293, 0.023274118861844464, 0.04993342704349949, 0.033930941980572484, 0.06371424180425464, 0.022287962605215372, 0.03880039984059911, 0.04143072825465952, 0.03430676173358675, 0.0511289302319769, 0.02792666084133089, 0.013027536784178548, 0.09853973699313018, 0.029628906293862292, 0.03949886135336372, 0.05421200128752859, 0.03937339147312507, 0.049370191540689244, 0.005446160230935822, 0.034969129013798894, 0.03151991006527697, 0.027607347733611544, 0.01951848772624808, 0.018190075943787253, 0.009944887076985213, 0.05573153668533891, 0.04507477868408446, 0.03363394884452705, 0.01141910262841491, 0.049021008664802204, 0.0026856969399828346, 0.05727259149294227, 0.03568845876162091, 0.10734289163543333, 0.028264664579182867, 0.029840164615081686, 0.014412586404491338, 0.046652532933700475, 0.025734626650509816, 0.009352131333622721, 0.027579896888064764, 0.06292520954664196, 0.05473381058583337, 0.035012478098994305, 0.027221047897793116, 0.04041874908932275, 0.0082128053726328, 0.0359456766126377, 0.02999784083165709, 0.014915466627797053, 0.01411550133789499, 0.06506508847157802, 0.029905308901722875, 0.03201441982040002, 0.03223148700330527, 0.028660096183058717, 0.022298199455103567, 0.02980699492318015, 0.002369637790721871, 0.06297236225838143, 0.040063801401805495, 0.005203549282610296, 0.06229038695774733, 0.056735839649674394, 0.02129930315629369, 0.06048198661676819, 0.08208969187351965, 0.02362853794869396, 0.03140503901147074, 0.025020282219855056, 0.0093859531578698, 0.014179221658606925, 0.056707038574161074, 0.08123985521735684, 0.10029738017868611, 0.03551559485194664, 0.07921624162624921, 0.025525262481683207, 0.057166063136631445, 0.031728632635467, 0.02663317883777763, 0.029192711151535475, 0.023270332472278707, 0.02254634874031669, 0.04351479384387213, 0.0714186310107189, 0.04940407944001979, 0.04097153898328543, 0.018988760909245863, 0.09582148849843972, 0.10052144557477967, 0.050532622713475465, 0.04289668346304567, 0.03894354719969054, 0.04004421253358165, 0.02410210094474737, 0.01660992958462767, 0.028178485433360743, 0.04390721472220556, 0.04845044936143583, 0.011420101415546191, 0.03853787300026706, 0.05910181027326373, 0.022369786541187958, 0.06281905274297442, 0.0913712224592605, 0.017002545815381794, 0.034181759166981907, 0.02142606389468476, 0.0081099676448972, 0.06801232830771516, 0.024915310937250336, 0.07945661703425069, 0.039437865432832515, 0.04079215183493592, 0.03837608289153826, 0.059353864691670866, 0.01671161818047685, 0.018537671102451223, 0.0029740313672640874, 0.043282749642047195, 0.07693311575079158, 0.018533854069368496, 0.03303924628022698, 0.03004068429882248, 0.10745922974761456, 0.08184914026529559, 0.02299935376692203, 0.050381155639526345, 0.027612714179521127, 0.09230862296516858, 0.013760869661646505, 0.022204062570967985, 0.06590911052039554, 0.029553147859030196, 0.09354667467696053, 0.0679479769220756, 0.05113978186742433, 0.020568610409334786, 0.026648117552301096, 0.05475301257965546, 0.029347491555757103, 0.03389678595046844, 0.03812035125109457, 0.09811393000305661, 0.023673388566220963, 0.061113174118462114, 0.06970221867724773, 0.04150306227647009, 0.011584202236976596, 0.06032820212684813, 0.023394109298204704, 0.09096930975154524, 0.03443835265634041, 0.04864186792063618, 0.042221434414386756, 0.07957641786384968, 0.02263146110870425, 0.024832412562963944, 0.027297036159002495, 0.0147647263797661, 0.045787937593676394, 0.040401010323436036, 0.040822688099597736, 0.05239737648216467, 0.04197066319325278, 0.027660426135445317, 0.01309203372652372, 0.007584541932784863, 0.010504927035541305, 0.05367948974092161, 0.02668633959406326, 0.07536461201286124, 0.024471899246676795, 0.07423860832087456, 0.0419146123702728, 0.025173450008996075, 0.007854978630935113, 0.04559970212980144, 0.0889916537750152, 0.025122357690105998, 0.03611859797890629, 0.02837674132728529, 0.06878998415965228, 0.07717673171071276, 0.02186861373634348, 0.04549844828884929, 0.06903897039592266, 0.039428151437952634, 0.05179598980072526, 0.057875269032534093, 0.040428593319149754, 0.05870284317361732, 0.07014645774277949, 0.022206718980845426, 0.042196969396524855, 0.0178019643100279, 0.04858913808880795, 0.010925439400448194, 0.024308437151053262, 0.0005108563956098571, 0.021164690016678745, 0.03437759805350535, 0.05013539080297755, 0.014285388995983429, 0.10712660969265046, 0.06678826536142057, 0.015492347114148642, 0.08719739158667865, 0.04715017598843382, 0.03679647087870586, 0.017205769789495298, 0.03795821640279986, 0.03797896972466861, 0.03628419554461876, 0.034236932819288586, 0.07316999993617497, 0.04320033773359272, 0.05436673572647476, 0.010941010137509194, 0.05173591318570318, 0.015048955533383115, 0.032901476858364, 0.08132465348969545, 0.014103505358610664, 0.04691732356384878, 0.027278958399209286, 0.039954193372039065, 0.054058944581136595, 0.007160124434683953, 0.04052235865064206, 0.05464067344643897, 0.03334036863018428, 0.022422522118675615, 0.049599753617639505, 0.0824511168344367, 0.019586945343161785, 0.04953691908609002, 0.04365550887380396, 0.03148817295779384, 0.02739376433554196, 0.040602947269836744, 0.08018937247294573, 0.07081270908876773, 0.05482899701042522, 0.04540900369324992, 0.022873782380033406, 0.03247537492443958, 0.0261412316467613, 0.10126413717385262, 0.15302880546979367, 0.06849714705059606, 0.07774092482342836, 0.06676760397010273, 0.04406800891663279, 0.0803914817891294, 0.11687999681359339, 0.006174730435539518, 0.016694729772186088, 0.05079597692876574, 0.05014851388912048, 0.059690338168894096, 0.03122698677132928, 0.08827931457950224, 0.017414467461827784, 0.09725653205908115, 0.04429276379185819, 0.025691624220100143, 0.03883388937420903, 0.09707401161112132, 0.055407795589417226, 0.0011065776174467418, 0.03148023820211811, 0.06961227229405796, 0.07161595227737581, 0.04799210661721807, 0.03963591065257788, 0.06110610695736063, 0.04630436895475273, 0.044688229869690635, 0.032525021252372575, 0.05847384800173103, 0.0379002541904488, 0.03540152436002128, 0.023958555219935316, 0.041456752261447335, 0.0804172376651437, 0.04890650916363924, 0.0338230614790753, 0.016534778274475567, 0.03975019947956166, 0.07157265298789547, 0.07028062272095872, 0.02539724918953594, 0.020452438921277082, 0.03225613971270862, 0.00928385278976132, 0.0696525838406336, 0.0262939665962251, 0.04571879432807046, 0.03469375104853704, 0.08754655914080721, 0.033252996302420096, 0.004513938000590931, 0.02514334275357185, 0.022774005173555305, 0.07631252324509044, 0.04490826181286285, 0.0038476758814912533, 0.06875623798658771, 0.03397701450833871, 0.086103824057406, 0.01030385385327522, 0.006783413625652752, 0.05200560677856688, 0.048478323470560775, 0.005837557424280432, 0.03643719096397681, 0.00621306499646556, 0.01062160222640922, 0.017650692588499477, 0.05834215748754721, 0.06853051784057772, 0.029185278183450142, 0.12008148591004073, 0.02584457175896293, 0.02763867115361556, 0.0248516796742596, 0.023257017864154714, 0.04201629139002293, 0.07987571309410757, 0.031086932492232135, 0.03864449711756841, 0.05209765990354842, 0.0614648352887842, 0.01570805353337839, 0.09558908806573, 0.05192822806777493, 0.021000113263125383, 0.02513744004611527, 0.13008211258678667, 0.03559510711760771, 0.033430154134909955, 0.02585247204068207, 0.04924978550163008, 0.07775990848219203, 0.023947870208611412, 0.02348005287199011, 0.0851416482680267, 0.01297142563177453, 0.005928600749616782, 0.12458589904370809, 0.13965528518442186, 0.08073678826011958, 0.12199109029625693, 0.2102371413380869, 0.18368309363722804, 0.12519044200739554, 0.0782922553198953, 0.11611464433372022, 0.1758099161088467, 0.1877076139733676, 0.10983160486625088, 0.12303502298891546, 0.21947830675109742, 0.10613032000800295, 0.2403137838888553, 0.16446404669794346, 0.16644047693379466, 0.21424938894567952, 0.08238008516209741, 0.1205720809558707, 0.12361341937174722, 0.05492215713245734, 0.07112329645502953, 0.08750318324253445, 0.1304371636961737, 0.18713369154401366, 0.18319845109456973, 0.1686437458040253, 0.11769324511049256, 0.2518459045959096, 0.11588692469822785, 0.17088222407525586, 0.11272322671908526, 0.24989988805065233, 0.13380735301442687, 0.08587286386999392, 0.11134600747496852, 0.1986958888629752, 0.12004046956257475, 0.08251645647349858, 0.18624219502652847, 0.1479199642856275, 0.17089670313702476, 0.11964776523170934, 0.19171953982403203, 0.1313936091478794, 0.07325616950589804, 0.20392165038614504, 0.09328608220863728, 0.22338768407221765, 0.11849713181295704, 0.17050071228896418, 0.1308540074575332, 0.0953954746646266, 0.11039438071630656, 0.13242513121616456, 0.09967635100286815, 0.1504504599518353, 0.14187479511864726, 0.21045065004258387, 0.09826059753616011, 0.08415675031081324, 0.10946937551301335, 0.16567357695631443, 0.1535290608843488, 0.15559411217128077, 0.13700429920948323, 0.18792656190212698, 0.1917049688317122, 0.12398431317940836, 0.09630703502484868, 0.1511498675831864, 0.16898027290740322, 0.22718265382272584, 0.26561775995839026, 0.24567103674334867, 0.1738050333674877, 0.13374591276289957, 0.14088692474028758, 0.1496395865275014, 0.17371075858752574, 0.10727220470265997, 0.09146457027283408, 0.2042982132444459, 0.10216599120007408, 0.28660492250515573, 0.06870425892092528, 0.26888723935811754, 0.1540412059834888, 0.21532145238691763, 0.15460202830933756, 0.18566556064592254, 0.15119655298129206, 0.2539450621172305, 0.2194531024583886, 0.17474372090110857, 0.1578598018855818, 0.16859917480859066, 0.1995351075405075, 0.2067357518019215, 0.133371724777164, 0.21301523662142216, 0.21304258596031897, 0.12905737805751064, 0.12922176520430273, 0.21685246378183368, 0.15425761050033956, 0.10961398226960052, 0.14120914132123993, 0.11027952115381918, 0.28482925327074143, 0.10516344043876856, 0.17694824615553503, 0.10327191572756537, 0.12594936700958398, 0.14247231305606906, 0.2332006575119111, 0.11946440974791205, 0.1416518022456477, 0.10529262584543998, 0.09779932067519236, 0.21007794826742143, 0.10109796504219694, 0.1173124687686082, 0.09501455276603661, 0.23061063681398672, 0.25125678298213794, 0.11599998395409315, 0.14512555132950508, 0.09814878700361138, 0.15139535279764285, 0.13279351225543407, 0.08452013645681643, 0.156294469751658, 0.13572030520487216, 0.2523814766637741, 0.31196004260451565, 0.12638753865875546, 0.093644657322476, 0.16241773392163938, 0.18164218944166938, 0.14020060189068317, 0.12346306695572792, 0.17241916499070584, 0.13559543287321446, 0.1013311775281064, 0.16537639612872757, 0.12488085055543531, 0.2094998429980009, 0.14471682810014294, 0.13492426324275233, 0.12050507890601313, 0.1432531098684957, 0.1167036050690278, 0.19778847303842345, 0.09049914627065582, 0.12957632601741823, 0.11714373024240618, 0.1794268470257521, 0.07075586536478612, 0.14049448854019567, 0.18976823727209724, 0.08436453633851583, 0.16662395499165983, 0.34875003620982176, 0.15788859146977627, 0.1154499558070975, 0.19914388175933592, 0.10028344503934346, 0.17941918614650929, 0.1072590203294831, 0.12138900647480642, 0.23316324177768924, 0.08304878798944336, 0.12852902253789286], [0.01713339746328852, 0.0404967368400145, 0.017298567934983203, 0.03640938580276505, 0.058024104594463305, 0.026646368956613927, 0.01447358615546217, 0.05143775176557322, 0.051220918239484874, 0.039075471370691256, 0.06171584016673508, 0.019702693567641323, 0.043795584220319025, 0.03094628066455405, 0.04229056618867382, 0.0651869653994518, 0.057337620866394816, 0.06353061818968385, 0.03212159552100686, 0.051838519171841686, 0.020521789030622573, 0.023951039897398125, 0.025813470504456953, 0.01611676622903155, 0.04601879052877907, 0.060068134428753014, 0.013857865011349562, 0.05744715228736882, 0.04861701219793289, 0.011550362218141316, 0.03245430367608224, 0.07440438974768886, 0.02863008851906465, 0.04647538659252948, 0.04501221228330847, 0.02683118000746735, 0.031856674655911424, 0.04123910285171963, 0.04778359663642703, 0.06553630915380294, 0.020084655430588513, 0.017754150847453746, 0.014178831911375447, 0.09161830113659944, 0.043565014737748334, 0.03947256155492317, 0.056941484461628625, 0.02811800087651899, 0.026662339974615364, 0.03577682317324704, 0.05660252119865149, 0.0751173724570582, 0.09355855670066611, 0.022198362876811338, 0.05792270519680554, 0.014680903911921046, 0.06015022074983967, 0.03170822596838398, 0.030464451579797654, 0.020216152507571444, 0.015440196636313153, 0.06256370031605325, 0.06473593113403167, 0.05283716457685637, 0.01591407277080561, 0.01631572883906624, 0.025592932943254713, 0.08781273639009846, 0.05258218753301809, 0.05469545639390427, 0.013517837843767578, 0.059150613904480016, 0.041360359248374744, 0.05891093563648963, 0.035876694225495866, 0.21517591100306283, 0.018965247755629883, 0.043259219251452916, 0.0882497589073835, 0.019029719800117518, 0.027056513279075586, 0.03714563843283442, 0.0033183373753056535, 0.04397951427005953, 0.11433411044098678, 0.011454723801674142, 0.08970863546334928, 0.010743905290690883, 0.0861542403037029, 0.03939839275253396, 0.017176595246118885, 0.03887481379112409, 0.01408041738379266, 0.060029002657580766, 0.016141334668763222, 0.04883791365089917, 0.020336820931744673, 0.04141521880463247, 0.05020005628466607, 0.0960209318286469, 0.04427994331044536, 0.02455597931158639, 0.04919525536317979, 0.10695921182031594, 0.027560235241488106, 0.05755758386165385, 0.009056466402516011, 0.054196442041786454, 0.025363284681412964, 0.08064160949640697, 0.023998841868653416, 0.06030904609830149, 0.06307051727367986, 0.03930089657285041, 0.11746388604684223, 0.05356564524493391, 0.012102189714149123, 0.05881480692375091, 0.02103176227049722, 0.014898039085129577, 0.1025825515089016, 0.030805247708133636, 0.05834240263568298, 0.06981361552231735, 0.03983302890593487, 0.021007306828734376, 0.014931260487966001, 0.04914274386640999, 0.029244751504231847, 0.04669837563508942, 0.030211387840550274, 0.052442445434750094, 0.018704132432298317, 0.03651429771355564, 0.1102017785512632, 0.04209034910966312, 0.026322064786067894, 0.04510764385603609, 0.08411168901910705, 0.08543284594892495, 0.03740315505814168, 0.03485963972766073, 0.05396581893306106, 0.0374201430578626, 0.02531383179068085, 0.009314607389481559, 0.06247515587376491, 0.045643591306983464, 0.08067284290107989, 0.011225955583335412, 0.04658378420337554, 0.07022187143804566, 0.04053467734446449, 0.022948677050730875, 0.05448268696425423, 0.014223106047739426, 0.04846092178336075, 0.02457501659650476, 0.05057541638492577, 0.04949862235075524, 0.042641032261834036, 0.023830788991143628, 0.03445707967564945, 0.04319702823375983, 0.03508072121128921, 0.031720996654081735, 0.06241161654132509, 0.034352271186728636, 0.03419307045518391, 0.06797806119486209, 0.06459500926036028, 0.03637668917015676, 0.018799807237941894, 0.01646794476396134, 0.029912362656285687, 0.014832155523641456, 0.03492657282960511, 0.07272343196335339, 0.043071508557806094, 0.02996748268243767, 0.017016406261151838, 0.014756673838072007, 0.05362572185995598, 0.06680221582252173, 0.020948840913573102, 0.028649824859213927, 0.08896732282254005, 0.05001717960582145, 0.015371679647585318, 0.047504483992534305, 0.05042682597113233, 0.05965871788981942, 0.03384019886594146, 0.06952661600324415, 0.055881866118720466, 0.02688636323587308, 0.028096621277772134, 0.05545268068090082, 0.020276014617974722, 0.09103418973785254, 0.022821659672885172, 0.011705100487527108, 0.02835787258171026, 0.02886156964626524, 0.034362176703589584, 0.011004809939843273, 0.016514239457225608, 0.0258657387683108, 0.0246058075854014, 0.035342321085232886, 0.06254429913937085, 0.09888755623251201, 0.030649011736855875, 0.029558481746203, 0.009645596634776843, 0.05666528295184817, 0.08093368051753891, 0.08948135249797376, 0.04897663302178826, 0.03645784469441541, 0.010049238785981171, 0.04607849559115787, 0.10592383632977163, 0.08256127261706898, 0.0723466239569168, 0.08354630847010883, 0.03333563037637261, 0.02723523967659041, 0.04007034762311847, 0.057279854006464445, 0.047238337386760025, 0.031853780758777456, 0.03399732349921138, 0.053747307674418536, 0.11128412289244514, 0.024809795732219374, 0.05616256073417683, 0.059454551627559055, 0.03295448248184497, 0.036521115896081736, 0.005965439045065714, 0.06673909017756101, 0.006075348243147376, 0.0274298164332586, 0.06605400072951471, 0.04778923887398936, 0.017203498338799805, 0.032366808774250175, 0.026642149727370952, 0.03973460192942331, 0.07634109066378686, 0.20472331543362912, 0.025476546950578213, 0.009851269217418327, 0.09798082988709213, 0.05481714946067622, 0.04387776630239622, 0.038978852361681006, 0.0649612988795965, 0.023749522384135954, 0.08646954677157825, 0.10307251836263365, 0.03259714076956434, 0.025529052701688586, 0.08420401793574134, 0.010309909778316657, 0.038791980534311266, 0.0297414273729608, 0.039685216071384574, 0.060217268764972694, 0.011124294758173487, 0.017238876279143077, 0.04554237577042753, 0.04971647477378288, 0.04336146134582739, 0.05254258844821204, 0.038995794396126465, 0.07752987526116834, 0.04330980786753278, 0.028958029692031206, 0.06323694221435056, 0.0011755711368037268, 0.06244044059947614, 0.015749364824695213, 0.011141053889127029, 0.10481381323188545, 0.012229817089504533, 0.043483476169527545, 0.05906756231260877, 0.07011572229525737, 0.03439222650241948, 0.07233095745886527, 0.013861338262476269, 0.06956659813201235, 0.023775506171307737, 0.020792652822790608, 0.01786276296291861, 0.050020446970818505, 0.022010420441567417, 0.03783851133419141, 0.050436647218321605, 0.07254308720509853, 0.047097101417039676, 0.0621031588994928, 0.014053383098554709, 0.05227898525434637, 0.0289580641659878, 0.044297689737211314, 0.031053640226262714, 0.05159506025994497, 0.01306968885699227, 0.1157239624749749, 0.01699802398140873, 0.0012049212818965316, 0.05282512167468668, 0.04978719618051283, 0.08690494518246382, 0.030174849277001717, 0.0556060208398248, 0.0657924123468899, 0.026954359284812407, 0.04051084817957975, 0.08545081071074932, 0.07221078890706263, 0.05572645752240093, 0.01834901620543772, 0.039989310842488086, 0.08321727370663036, 0.1377563370812324, 0.04625769121752632, 0.0023927494663850317, 0.03886488529162542, 0.0476560200143966, 0.06315976651685853, 0.031207466851018613, 0.02388053299528697, 0.053416281082336946, 0.020042894062616175, 0.06560318096871338, 0.037440310322469285, 0.040685083386638475, 0.07391115935939936, 0.05138143281181974, 0.02211268551857962, 0.04333815312073116, 0.08546685259188376, 0.06022549271883984, 0.010469432266789579, 0.006451119158056475, 0.0781209810426639, 0.030861649016338973, 0.04638080537739781, 0.16108049680629086, 0.1661404769026464, 0.11491276729371279, 0.07826490598099847, 0.17927534547784638, 0.08084335875126623, 0.16143505761940635, 0.1405807960057451, 0.10521043227204394, 0.14635287014947784, 0.23784776218235495, 0.08131623418340761, 0.12944371619772527, 0.07602427500270068, 0.13871293575052293, 0.19877962227309906, 0.09696267605308564, 0.14516370250813423, 0.226520232916359, 0.1832112294411467, 0.1297315813961529, 0.14269653166974747, 0.09861860574493486, 0.20949380622515756, 0.1421250453999927, 0.11709189673344936, 0.07123737460783414, 0.0853274935375779, 0.11305560162591358, 0.0943401655662925, 0.12169302080667789, 0.1869861736533142, 0.14896428002224815, 0.12602324086812236, 0.14733562306050332, 0.3439077783015467, 0.1393592381669629, 0.1628870547058121, 0.13127762343614333, 0.1552142091696301, 0.1616761608109359, 0.19878210439797372, 0.11132346150735695, 0.18455249617897695, 0.16055039460620574, 0.0975048134944612, 0.1710399769006237, 0.12197965260354743, 0.12240585029846239, 0.16434159520412647, 0.15997841804017945, 0.19609600095258606, 0.10913117833796049, 0.19045957033672642, 0.19172902399253464, 0.11349856898549104, 0.13215013629486486, 0.2261665454434772, 0.17679801631358363, 0.15706991927037317, 0.1584967273858286, 0.21329017025568794, 0.11190965666525787, 0.1663312940828262, 0.09353736670868051, 0.12115164945322661, 0.13747073950306063, 0.16469037971429287, 0.1890938807158701, 0.160934480447923, 0.13285628549994963, 0.17590192326855275, 0.11866748678467928, 0.22686016145012072, 0.14740913685771728, 0.39636384094915084, 0.1342376646014952, 0.2759041450917721, 0.17086319445121675, 0.16855777541716255, 0.11487414880144982, 0.21398902630373356, 0.14514091905326615, 0.10778266440836654, 0.2316810914705838, 0.19846989292531245, 0.16850157520703732, 0.24516566386145933, 0.18001938539166606, 0.12109659837498782, 0.12146694826022272, 0.1265848292818954, 0.20179937233126935, 0.1534401640416153, 0.20559829509546682, 0.08709301976787467, 0.14023898289568965, 0.13497971268671174, 0.2441214247336311, 0.24849508198038225, 0.16447671779221104, 0.24641222681009003, 0.09109451150101039, 0.24305484648193085, 0.0970205999610405, 0.16605024706692467, 0.12328878961383335, 0.1408616591605448, 0.13816513691938695, 0.1768654626944373, 0.096563559566294, 0.10797070068938118, 0.15873885713517666, 0.11842280596254334, 0.32037597810549123, 0.17376220905252043, 0.10102942315561157, 0.21499309178081252, 0.09586848799259433, 0.10843885701990898, 0.1785126896274667, 0.19468443798682383, 0.19298425905646818, 0.14835433613869453, 0.11283892131741009, 0.19264515789766468, 0.12642315408635524, 0.15898867840728453, 0.10412928302802386, 0.16741530849568306, 0.09810029363800442, 0.11071895684806571, 0.125797099373754, 0.18221107101248157, 0.1536611037989778, 0.17016942522698836, 0.07840168331899951, 0.13830562212294148, 0.1719578574862211, 0.16495135522657828, 0.10871214356513755, 0.08288683700225047, 0.13417945724100838, 0.1338207135878263, 0.14855370286010927, 0.19349910078510163, 0.180089206645085, 0.18911021371041575, 0.15195286562365873, 0.09927642246287677, 0.1842098250504463, 0.13218710769809064, 0.21947793902889376, 0.1281868110621168, 0.11754226450237537, 0.0992382176580929, 0.12739542691457656, 0.1564348017376277, 0.12814250053657641, 0.13037799106490228, 0.11329911799440462, 0.13369104554576258, 0.15395779433029314, 0.12084733634706467, 0.18014445690618408, 0.15886431169365683, 0.1383305199804806, 0.12669957393119413, 0.11313689887643823, 0.142908891242358, 0.10731125986503978, 0.12122445078867099, 0.16210379109026926, 0.12077726994550998, 0.15900501140183018, 0.09553684086929407], [0.03354034822193846, 0.0036640204263911134, 0.06295201879355215, 0.05260839923134735, 0.04064930325013496, 0.023108239758819826, 0.03359732601130682, 0.04768407032374413, 0.04212200003225477, 0.021625392311703295, 0.024457876007222844, 0.05137373362818072, 0.08240585635987022, 0.023865534908949368, 0.009387172195279311, 0.09267950911195048, 0.03410829133504341, 0.045452356608884956, 0.024664210298308925, 0.07269566127609822, 0.030856952897363135, 0.02546499242946025, 0.02117641499235986, 0.04177518819849338, 0.031037368518750996, 0.03738956082792532, 0.0054203914271877904, 0.0757546580186294, 0.03852666513393483, 0.026979121161744963, 0.021769340232675596, 0.04688808198777899, 0.033014222018180356, 0.06299355608080665, 0.0699230128779046, 0.04867643380777971, 0.03166831661796859, 0.08091962280412836, 0.05586626090770287, 0.1224137103605655, 0.0391806973775308, 0.07741254123468554, 0.0265258441739265, 0.021076346672470533, 0.014718992845906366, 0.02280471763843971, 0.01426287271427892, 0.0164769577883905, 0.03328844702111618, 0.03980509350977598, 0.04473955776061743, 0.031189785541726217, 0.032695521780800436, 0.07918187492196599, 0.01677568994402405, 0.025654777306162065, 0.0381197115676778, 0.05418793846582694, 0.08251017455251948, 0.041675646564051996, 0.04040026721814948, 0.054645572578714746, 0.02860628999769688, 0.022306348715398102, 0.007249423952382659, 0.060075737851401495, 0.04568845724626895, 0.014400380708637738, 0.043752698618317806, 0.07436798524952705, 0.05295625677512539, 0.04540127769653355, 0.02034705778163287, 0.121203942614938, 0.02418346905840501, 0.22700582540804343, 0.11504809672553694, 0.06434565530188623, 0.04826022206895775, 0.03193559128821137, 0.029978395604919043, 0.021044228436245073, 0.02782303404303328, 0.044593529910930706, 0.07154383276018404, 0.03920374513273278, 0.053293684031814344, 0.039101219585826325, 0.047772833101090886, 0.03274928200088682, 0.0518603028819686, 0.024642284861916018, 0.043676131960725596, 0.037139892773402315, 0.08897024161753156, 0.07748422408176046, 0.03510852254206135, 0.018209829520914825, 0.04596391182032324, 0.13488473310585947, 0.07843164501771813, 0.07211500493388984, 0.04987632668006325, 0.15309599138075305, 0.08676367090834726, 0.033287715407148484, 0.04619142844251568, 0.040831398519296805, 0.03341124325449909, 0.013019199832342567, 0.06693441195473557, 0.06364136002957821, 0.02749362389647192, 0.07192672350473943, 0.08173305496212938, 0.06304442431897887, 0.02822769317595709, 0.07496866713007612, 0.006473275378436572, 0.029468278723558592, 0.0660362274896714, 0.04356473128521635, 0.015620300076871872, 0.06192076102560086, 0.016428347594375094, 0.06188827889761137, 0.029141174501649318, 0.016616743936714147, 0.063035357668395, 0.11787807148310447, 0.05424538739926873, 0.007139934666244494, 0.011692396834522728, 0.059181946900583086, 0.05369114193824991, 0.04823410230117941, 0.07282589622322591, 0.03016488630354645, 0.006031225409148442, 0.015072848858131517, 0.029508929264040726, 0.09529654973096426, 0.06569956249046711, 0.045265982738666, 0.12261493101475701, 0.03853770829136333, 0.02973924785281622, 0.05532618424284363, 0.025429112701526573, 0.05904183708011143, 0.04991502178111865, 0.06251934382523741, 0.04154600533506563, 0.06102512763332456, 0.0649747207400299, 0.07218559227523304, 0.01215225164478104, 0.08097327194146572, 0.04907628956941828, 0.035176509014901616, 0.03156949702139584, 0.026306905821266196, 0.05840859646278043, 0.040082915295516296, 0.027768063404026534, 0.03081473570707585, 0.04103937989942009, 0.05227511267988913, 0.03679584268660795, 0.12097479039502722, 0.010390661191195251, 0.042422026876480355, 0.055825317338589704, 0.045893914366681735, 0.07979786323924219, 0.09368823240360907, 0.07467948426041873, 0.02041274407548049, 0.032714493948245243, 0.02662138108374371, 0.04064852184045219, 0.039906217115781004, 0.015537019616233246, 0.03993462748645295, 0.0311065596648522, 0.026110570892811786, 0.0542323524132371, 0.023738710968304547, 0.04937941523929758, 0.0815871075516747, 0.015578449651178335, 0.011338481450483445, 0.06293472435866153, 0.047144686968456355, 0.011379661549243235, 0.054775504921112335, 0.03526973425440731, 0.029383608770947305, 0.037872395403082335, 0.01205783801138281, 0.022294338371965195, 0.021677888486714616, 0.03902369914876838, 0.02017330904040606, 0.06184765325498678, 0.018981071301705895, 0.011908547584748557, 0.036882812818211895, 0.05706862441354221, 0.07519228053429435, 0.05190920993505467, 0.02682743958317705, 0.0481314963150409, 0.030487263762962916, 0.05544793093577028, 0.09338250203478722, 0.0676337736208112, 0.10487618811068036, 0.03224911085600334, 0.058528397292379415, 0.0285639310811436, 0.015533316538729256, 0.026813314837073127, 0.04313531985145904, 0.06193291501051957, 0.014667086558596743, 0.038705830116786306, 0.03121756580508044, 0.03668462970264016, 0.026259400709081563, 0.026394521381946343, 0.028413934896009106, 0.12474534492338858, 0.058195463141366366, 0.037049674428999424, 0.04703314456668112, 0.031375052414894584, 0.06664969537767672, 0.013873548746379393, 0.034264550288958896, 0.04619141312075719, 0.04105555201550165, 0.044508612894963835, 0.01721402247165961, 0.07671052124351263, 0.03596482498030509, 0.04213772015646101, 0.04335288882195469, 0.04730470358364044, 0.03509205165168932, 0.03249627763345357, 0.15665365773583614, 0.07134448136052779, 0.028756989068501902, 0.05323087631334221, 0.031474471475268086, 0.05865688555903974, 0.028773004136558984, 0.02864666091608665, 0.05018313723285833, 0.1367973328958596, 0.10068547266024737, 0.10033656557601306, 0.07134425919502974, 0.1239089377885384, 0.08653651817791885, 0.07522271720752602, 0.008873792736971331, 0.06936396021516093, 0.14931458138650464, 0.15602459229769247, 0.03809998480362758, 0.02048047773930575, 0.0977179314941168, 0.03635972798351319, 0.05522563137234219, 0.07795826396754674, 0.025102814787157604, 0.013746211526825303, 0.12510346804535197, 0.03168976707984844, 0.011516989512939849, 0.06914540299124296, 0.10248219399082084, 0.007424762326052353, 0.05212767522842173, 0.03258676027819034, 0.016715345198228475, 0.019261559073422706, 0.010257409772865716, 0.05593734237575724, 0.011553171845603616, 0.03878062328083381, 0.008854360916771957, 0.01251096465444613, 0.029716464397948117, 0.04072926367723173, 0.040573418410795356, 0.006251377053558827, 0.060882516535780126, 0.04976173524834937, 0.05541387832753601, 0.01330011948612669, 0.01994354778059548, 0.01689158947086863, 0.07712192578060974, 0.09940479581634845, 0.01773422490054321, 0.021943686522483345, 0.04579041588811144, 0.029406612476093635, 0.029547135984044404, 0.022099437943149, 0.07104936897033645, 0.014252371564056846, 0.06083147975826456, 0.01822628317430856, 0.032486123138017235, 0.034934586109293085, 0.06346929668178482, 0.06956031621103326, 0.06675706260026464, 0.03995888949101491, 0.029001757990749135, 0.03964665503571591, 0.10099849618610837, 0.044394415998530966, 0.028149243857290958, 0.039500742099217834, 0.04842728286260559, 0.041600451203844244, 0.055567360212725986, 0.05156815142160462, 0.04767717936286523, 0.02949686720967293, 0.04006971943102056, 0.03265420665904399, 0.0678371929473454, 0.07456020437060826, 0.06631735877524461, 0.01066866492281758, 0.014954630000096177, 0.017133140823833885, 0.026114265351826628, 0.034411665983498096, 0.07834192846090564, 0.005464793404474134, 0.05638404058352594, 0.04351294374153499, 0.021750017580005433, 0.08526007013936197, 0.03017482054870456, 0.10218884360285536, 0.09164637059814508, 0.12289793155486546, 0.14217384520076937, 0.12802730389540234, 0.11359168697268733, 0.12791754647849068, 0.27738349151707464, 0.17225286262410303, 0.16399772897843393, 0.13691216947570925, 0.11974836789792585, 0.19369581684229836, 0.12696880787130327, 0.07022513497260309, 0.15599659944493927, 0.20874590522819952, 0.12010323514621105, 0.07964355780953362, 0.11459196031454111, 0.09025250426343373, 0.1057441044418562, 0.12954179077379166, 0.0937899305755573, 0.10751768225623716, 0.09435644493468347, 0.11180849475485664, 0.1566472072755137, 0.13774080081812798, 0.14171046925888908, 0.16008145686599518, 0.1718457635011404, 0.11128717192238378, 0.12971327189476262, 0.1280723422044708, 0.23945250187910375, 0.1092320874393467, 0.1601957725060563, 0.2345686913618157, 0.4362651934066127, 0.15894747819871674, 0.11239946264052585, 0.09909996177039801, 0.18773091836802422, 0.1549831570516671, 0.18044611168724878, 0.17028813821173486, 0.16037065505741105, 0.14027707278728485, 0.10715361429198135, 0.10451578204670262, 0.08667223831458438, 0.1329828891903162, 0.2384489573418133, 0.10758228645089174, 0.15171265109412133, 0.20255154809884487, 0.21289845417824485, 0.2161522900625583, 0.17801506955537105, 0.18480631643004958, 0.16237169203739013, 0.07816232680793732, 0.07201254833489656, 0.2139152213931084, 0.1917035132646561, 0.1470710622567323, 0.12284348568608686, 0.1161665621123487, 0.2178780563295849, 0.08064443636084757, 0.2984720228179809, 0.212591651286329, 0.24488493860248597, 0.1355055094726624, 0.3886846368831973, 0.2667329388280069, 0.20518974040544805, 0.3047174167248511, 0.16152616079536178, 0.23175593826078603, 0.10685422713117254, 0.28053389020985176, 0.10595867034768867, 0.24956690027348458, 0.18350672487530018, 0.30013676252095933, 0.14114960096776485, 0.26097128348004434, 0.15895299403177154, 0.17190266851215594, 0.11701799989227327, 0.15167713525795168, 0.2592852465327709, 0.30891643656838325, 0.17710622880728016, 0.13622647481820277, 0.21156550715527228, 0.12765764348929928, 0.17000914431147038, 0.1435046012122785, 0.1601422229601491, 0.1014127352485253, 0.4409982071768853, 0.19989628735328877, 0.10541131584754876, 0.17611898662101838, 0.29543978552664485, 0.19925844254753283, 0.11056757021334865, 0.11351193721976974, 0.09382736163153764, 0.12801807253591477, 0.14719215011404407, 0.12705551370257331, 0.14994873364846553, 0.18762902867409492, 0.11588942980574024, 0.1506140197236692, 0.1240547089987705, 0.13380163799851172, 0.12311697141417574, 0.12662427514911662, 0.11198121693826492, 0.09792562559126847, 0.1364204329588721, 0.2197273772570395, 0.11008217690452454, 0.20287119062437167, 0.15878722792671573, 0.13963201143328222, 0.1760960959138409, 0.13726427880746706, 0.1532782283761809, 0.21408143182916028, 0.16020721785964506, 0.1761503809041554, 0.17225692289010172, 0.11785118179696223, 0.14734763531915604, 0.07747179047474939, 0.1420242435509159, 0.21707389383546769, 0.20284777897740566, 0.17413279642501187, 0.13337889536013528, 0.16649865365076452, 0.17162837839174658, 0.11590625309655744, 0.266797780509918, 0.08384552709157429, 0.1250260318779657, 0.10701845339950054, 0.16263565529258023, 0.17023414433483156, 0.10455935712783568, 0.14984748746839263, 0.18874685820792952, 0.1516636980757598, 0.10073515346213695, 0.12921424222088632, 0.22029990540637126, 0.17307755627459095, 0.1806808410272483, 0.05506858717830432, 0.08652531031158664, 0.1813949575467456, 0.13047586645810835, 0.29864347329543484, 0.2182792565755306, 0.1304722198795888, 0.2019751895098917, 0.12993873157087835, 0.19050124551980727, 0.19957610856621497, 0.1675179183122612], [0.023574182095246452, 0.015845867005297016, 0.07435309250027904, 0.02733540375747027, 0.01296019478280458, 0.053019022358761686, 0.026643379298489422, 0.033770159277464115, 0.02547801592417302, 0.03563372944031031, 0.025555708731013923, 0.024075624946084236, 0.017010666347379168, 0.05030330578466097, 0.09990141231326327, 0.07610891239657518, 0.038980135558954174, 0.0730486975742444, 0.017295570615979455, 0.020277604250417604, 0.03081766599338622, 0.03436752399730106, 0.021408997370951602, 0.03923663711776176, 0.008289356708466526, 0.047200327934396845, 0.05233755267615761, 0.018988496608911984, 0.03610834006160017, 0.06083873844134712, 0.017448343869839466, 0.04788819445116867, 0.1313101208858913, 0.0268243522488422, 0.010762785527584775, 0.03043471779223652, 0.032237213510539264, 0.06334232909965419, 0.045556000644160856, 0.009830459396565154, 0.04654307046063966, 0.0020949224915145148, 0.0782805341746538, 0.07285159081220627, 0.0878431347589339, 0.03143372325857561, 0.03183367861164434, 0.021211170486264655, 0.03685377808588167, 0.09331700151726123, 0.05720475440724723, 0.032644136433279326, 0.0386721107567991, 0.0320098347841732, 0.008365245378245751, 0.054046499482806654, 0.019604165084479798, 0.04800966152200296, 0.05343105125751707, 0.033006913539382725, 0.055090773084591475, 0.024647869642884023, 0.05160836337675011, 0.018821056601741624, 0.04710797220468522, 0.06114725353977373, 0.0460790012091879, 0.020996700341422713, 0.06243750265228653, 0.07638190016751328, 0.016424662711459304, 0.030142252235823584, 0.03603969858358464, 0.024829830846659122, 0.01741934935712526, 0.26540503266357607, 0.08713800445078843, 0.0629605453521494, 0.0506899465296057, 0.1110262883406493, 0.055825129647048256, 0.06248469366842221, 0.08947231266046725, 0.07809419094795182, 0.2895086408863145, 0.04043079965237168, 0.061979948978630774, 0.03463470482177312, 0.16836803076007675, 0.05936239125026811, 0.13177642328364234, 0.059364233691726005, 0.08472166354617766, 0.19646409087844435, 0.1617000014671395, 0.014560041092937032, 0.07160294410442153, 0.03050144213522154, 0.18017172963628847, 0.18510588745196022, 0.02052241147706105, 0.05070542150567617, 0.09665450186378534, 0.08114431639231982, 0.03571740922427947, 0.06892748928118138, 0.02116205467421922, 0.08204961015332131, 0.0423447017918431, 0.06510628868014583, 0.025289698105846203, 0.0494461223453043, 0.1280093774379742, 0.027663310456480232, 0.044642800855780804, 0.04708241934197084, 0.07487183361644707, 0.0892260000710526, 0.021196511393833547, 0.023497598200675943, 0.027800905593340437, 0.04621888886416151, 0.03619287786404452, 0.0393240554108014, 0.037746033030411894, 0.01498239111125229, 0.02937455361168231, 0.07855647904497963, 0.06261025547921177, 0.03360931145688219, 0.038077105587768945, 0.051631495401623755, 0.013102759915073554, 0.023576980231389887, 0.022089622441619154, 0.01938780844812432, 0.02671430371851931, 0.047697733501873674, 0.0012666441480471424, 0.08529616820235407, 0.059165525805926135, 0.01962968155801777, 0.02316036438118787, 0.03714307203828808, 0.025878153223123763, 0.05184459424908123, 0.07231444060321778, 0.030952030154425773, 0.04921917262817583, 0.010832934283591326, 0.029113250596809293, 0.05457729882290287, 0.014843712917589133, 0.06775839314345392, 0.003692262257719713, 0.03934290500417833, 0.04720369106038444, 0.06533885765219889, 0.09296840086819665, 0.052054375935826576, 0.011996048232240063, 0.07870503115437685, 0.036185833685580766, 0.039100901659337745, 0.08441566504658231, 0.03427703752212467, 0.10131491348147394, 0.009861461059640973, 0.03262247912765991, 0.05441865733554287, 0.06724221076095296, 0.02246560307309753, 0.03852617100722367, 0.06789940694767622, 0.0028268802411583888, 0.01915520883255428, 0.011542499283208482, 0.042238303670479406, 0.024471675165958946, 0.07410797500802625, 0.010195347074899944, 0.013348272900217244, 0.015602060481004659, 0.024698301210939407, 0.01948328024046796, 0.050404479186381065, 0.012830520995081434, 0.024194801414024927, 0.009391667216175027, 0.05822804486078601, 0.019015273297085397, 0.058407914644527825, 0.10587823877651846, 0.035962683764556726, 0.013351645602303888, 0.009108522076970868, 0.03578902695388083, 0.05014801976240931, 0.032856465362372904, 0.009008255531831134, 0.0024791040942223085, 0.08791442690116745, 0.04461308813563759, 0.07529299811369951, 0.026545714579462528, 0.02294461103907276, 0.07914567726754373, 0.07007315845018433, 0.06748134510651713, 0.037706836141766086, 0.09330865881976583, 0.07317264293951374, 0.004809509085926918, 0.031663132117941015, 0.03451183197959777, 0.02158519950875592, 0.02271930649576168, 0.04185357814534538, 0.045814298679150885, 0.02592955197718355, 0.08231909690244545, 0.041462574529671864, 0.05274828305588134, 0.02928458616107462, 0.06705357693135738, 0.1480689377433831, 0.06058392993685219, 0.03669394916223903, 0.013439829983267815, 0.01684190292331961, 0.02525562826063364, 0.08263408161339261, 0.01096460851840675, 0.052225998783063506, 0.027521363940210115, 0.0010862637188233015, 0.06161559373140336, 0.00456806977332059, 0.05467598626930868, 0.05277546002499519, 0.027189100116130807, 0.07570920602208184, 0.035348882628304344, 0.017779330242305033, 0.028597102688264944, 0.0610204276839091, 0.055847491753558, 0.06125027321339135, 0.053028889571226416, 0.01876650348065361, 0.07576578161528996, 0.37632203090094757, 0.12628591709559964, 0.09554338326016742, 0.06476614564176529, 0.06330037429448097, 0.02308815676388481, 0.059028139428025296, 0.19629536767400083, 0.11810943769711642, 0.3134096035313222, 0.19044970312426168, 0.13925154152656757, 0.04471244590897714, 0.2775442167635887, 0.14740162919605934, 0.11778977984983115, 0.13550800691929557, 0.32077756139539904, 0.4062850472907866, 0.3500007207114851, 0.02362350858147106, 0.09768983904993343, 0.05604515775978085, 0.05407876710617735, 0.2022663948516692, 0.0539931912545956, 0.03116250323552278, 0.11037492208302983, 0.06084518507122994, 0.015288399186946694, 0.0451693905427331, 0.013914210778180391, 0.06384365320686372, 0.07472781674756158, 0.03191110328771174, 0.04843464879799755, 0.04313143195524331, 0.08719203663208792, 0.06037384947581638, 0.019239597247853395, 0.03667876146914017, 0.026807676429950425, 0.0200011805751391, 0.01567646294021078, 0.04235897784031207, 0.01894060079188597, 0.033113223560635126, 0.07343349587773124, 0.03836152339053731, 0.03481933584196433, 0.028499478188854073, 0.027502738427551045, 0.046009708556436726, 0.05197711596866289, 0.03870162812452163, 0.04077238293604986, 0.055789345680105115, 0.01739119179546833, 0.011483840888456233, 0.0714916008855066, 0.0466436961094939, 0.03934154902855235, 0.0470711731712424, 0.0031536801825202405, 0.06263015461304496, 0.06975446587368365, 0.05784052311472836, 0.08822450098851997, 0.03320061887103704, 0.07126590372213433, 0.06016174271222084, 0.09413259404320871, 0.013479941389373234, 0.03431829135684717, 0.04327598125523618, 0.04602105814903494, 0.03849406426231708, 0.013875637293582963, 0.007659509381835139, 0.024311784955282367, 0.042795667109350045, 0.055452155910672686, 0.09835383043654504, 0.02915467488609495, 0.029683074455768354, 0.01971495288964962, 0.03037640317944029, 0.004187150747560326, 0.005577840211410677, 0.021475114589256626, 0.05286596948280931, 0.03404340751829647, 0.005420533153453782, 0.044821674725221056, 0.027999797340242133, 0.016615625448344697, 0.04994126412296488, 0.0265767794447921, 0.010734982281592826, 0.029119323758829026, 0.026048586718858253, 0.10181304683247883, 0.09051989959252459, 0.14422326829404603, 0.14927206350670708, 0.09893992600301582, 0.15041993900893197, 0.17198197393407746, 0.12231526806229547, 0.08907750158781007, 0.09978121311794366, 0.16816863339514504, 0.11317371706207914, 0.053687326820387, 0.11388512929120373, 0.1912572823705212, 0.17463683631391297, 0.21453779040565416, 0.150309193338598, 0.16420339294258626, 0.14548735933438425, 0.10192559280943486, 0.19276239999359657, 0.11260620678865141, 0.07281293401554709, 0.11909642707436316, 0.15308695154324656, 0.2345686913618157, 0.17336716815348596, 0.14044745074164483, 0.10428526619028661, 0.15795622171173174, 0.15084890228125358, 0.24664373858080757, 0.11254358676172073, 0.13787817570470995, 0.14991962230734288, 0.08903655418825727, 0.09362364353071298, 0.10094179035795313, 0.1352736299797412, 0.16981799005260392, 0.09981895826997296, 0.1157509134481511, 0.2325423581585769, 0.2884878440489692, 0.13674978947927877, 0.11928149859511084, 0.12298727272859505, 0.09542630970357888, 0.3098203896755173, 0.1977324413676416, 0.13615461577090526, 0.10694330783500787, 0.09404125337999675, 0.16800623807695605, 0.132550846244539, 0.1299150288105011, 0.119311950590101, 0.10990714879646418, 0.18086018221032235, 0.13322783814322564, 0.10230694371726244, 0.1380118427257384, 0.10868668646341371, 0.1581319469598032, 0.17999652532800553, 0.14606304376596405, 0.1298174138871893, 0.1679268560462421, 0.2561951389596347, 0.12328519666146849, 0.16795068138068722, 0.16372420494594883, 0.13181711787418013, 0.17552517654915012, 0.5678021222833665, 0.35296330528874553, 0.19720474468363872, 0.221984027133834, 0.17912654055943414, 0.28312259323654637, 0.22782011558451962, 0.30278273828087315, 0.2791582720894968, 0.49206081717725725, 0.41409166710030654, 0.14133093397944205, 0.14066710347129455, 0.4168688890434081, 0.33266939102642, 0.5995733206791263, 0.24573750253165924, 0.41437570185911277, 0.4063488777366377, 0.38595757837737765, 0.13094134148090117, 0.21103416389274984, 0.15539698242660493, 0.24263725195440555, 0.5194568874374513, 0.11917361809361367, 0.11593494308932174, 0.19966652226303855, 0.21482865866874495, 0.1403403822933474, 0.151251450841946, 0.11688737424030421, 0.15408835103434904, 0.19143429464630543, 0.17900528416277903, 0.08617042774154295, 0.17081748964565416, 0.24542575071175254, 0.20326638474099099, 0.2185367846921567, 0.10401334328156325, 0.13694062198121704, 0.13957245575804866, 0.09814550814729545, 0.1481156844285227, 0.10415643318406037, 0.1318550545481905, 0.11390936065224871, 0.10949501647583901, 0.09237266025475918, 0.11090975104560775, 0.1404043659567833, 0.14411578615826948, 0.1449239782748684, 0.09792521190378936, 0.14901433620722065, 0.1426620883566718, 0.09777796980474265, 0.10435601441009391, 0.16072965918048737, 0.23354069329798224, 0.19739240558157045, 0.10035918815241707, 0.03907534496618375, 0.12660339159230072, 0.191075413097297, 0.21410180976794613, 0.1412925529744356, 0.16919013503338062, 0.15952374485711898, 0.1322669647033176, 0.21986004836376638, 0.10110803909840123, 0.23425779756038423, 0.14931805942568088, 0.13763903369826658, 0.11392383205313837, 0.12710047540284936, 0.21478978736746698, 0.09055389091372491, 0.14273665935522126, 0.12952792458236217, 0.23468435531662357, 0.18235544794269148, 0.15611086911972494, 0.25150118035174185, 0.34006247657441324, 0.09178950646591764, 0.07706597071862029, 0.15196713018080882, 0.11698626086957033, 0.18610448306125982, 0.07639116983139708, 0.13270270019288988, 0.11561089555823034, 0.1929627473075544, 0.07567929028863869, 0.14964142513851966, 0.15654249837802303, 0.05207139457906446, 0.14055035167163418], [0.025611895534600464, 0.010365075769744093, 0.019967589534879215, 0.06463823194104819, 0.059421904790665836, 0.02996964113516433, 0.07303495395688281, 0.03238534044113851, 0.03193970518036476, 0.014171699632800395, 0.01340695715043694, 0.023319789193450444, 0.024895097707368197, 0.04734809097323207, 0.03428689324327054, 0.058281073466904705, 0.04162599257523975, 0.05100030023905058, 0.06102824178073676, 0.04821765822388473, 0.05278491738042044, 0.04859565749704357, 0.02077416520595791, 0.08071165291532394, 0.017697542695508852, 0.0384388906100104, 0.04929794561898997, 0.05852352880362061, 0.04377499560735399, 0.12163183336416561, 0.03409734010816582, 0.041290289016380426, 0.00977740397736911, 0.06112062049308612, 0.03886825607849225, 0.04495935221653312, 0.03812266100618628, 0.021214815149564418, 0.04901966035005547, 0.05316120444706852, 0.00858057449917279, 0.015103540255598005, 0.057748006506552624, 0.0304740525767087, 0.023180730828654864, 0.0405093006819727, 0.044385989031363884, 0.029148295288905505, 0.017814545388964396, 0.07790522003966956, 0.03295770388156657, 0.028894501850910248, 0.051501406011201685, 0.053209429681901975, 0.018369867203516826, 0.035307031245000904, 0.011709771708645409, 0.10303569251611348, 0.062187087662037344, 0.10373739075035819, 0.018676815652138284, 0.09200699882762087, 0.050272271562848365, 0.03987253222975039, 0.05498026490151402, 0.05788249324166006, 0.0660907576281217, 0.03093813906513876, 0.0398040592910782, 0.03357122539572659, 0.06133636617432199, 0.1225694713573302, 0.042732449533838424, 0.13344713847243017, 0.12038316367374313, 0.4230981644603514, 0.4458499952189384, 0.15643072614987052, 0.12110045179724695, 0.19147166441525185, 0.16039239663270213, 1.2880297557961558, 2.6976186661951007, 3.0853836911339916, 7.86187227695219, 3.5900512818367254, 1.293999112902149, 0.6976589284116222, 3.2645825657152363, 2.7533366699372572, 3.0956826094658147, 3.1672482144448066, 3.4404523286127278, 4.390505052381947, 3.2089452157097482, 0.6959705319135421, 0.5590872286308197, 0.19203167468790086, 0.07252376646764817, 0.5829286202788353, 0.07950887189156587, 0.03640441389213647, 0.14420197104975102, 0.1563377996846553, 0.01809307580603467, 0.058027793307818716, 0.05762918626949672, 0.06543435051196045, 0.07053556912128003, 0.06540141639209564, 0.07791095803822241, 0.04727270409104325, 0.016366162322341435, 0.06534747614134705, 0.0342254989570187, 0.014519782214906189, 0.07652581744496861, 0.03740381006331694, 0.04364040161993715, 0.05917375742067253, 0.014941499253074008, 0.06299189367001096, 0.044790085089663347, 0.06310834286494121, 0.06196822783338928, 0.04770467425846765, 0.02704169522340019, 0.060507573953439156, 0.0756962591361615, 0.11028689858053001, 0.018564043679244576, 0.03777801337081098, 0.011531042438300868, 0.04346213295995709, 0.027827155596065908, 0.03201200855865834, 0.021925210396969513, 0.016591463035212892, 0.01760390759896367, 0.020584813168933316, 0.07302810513083974, 0.06254180552317731, 0.010686509025793885, 0.05437921529876129, 0.0908306708198882, 0.021674651765234528, 0.040465311913360516, 0.022239446256970687, 0.03629545320666606, 0.0862166305042563, 0.07011187653387747, 0.026973808341990077, 0.04190564914155872, 0.023221978917717937, 0.058863039819463614, 0.041968196390136596, 0.0361984932885295, 0.02426377805550733, 0.06944485909996495, 0.054900404065847404, 0.05596053951810445, 0.03167911654248113, 0.03911186820797382, 0.062311776132593234, 0.04915839121226342, 0.008521936214228552, 0.0834895873201951, 0.03403502268596523, 0.02992859605940119, 0.052140821297202385, 0.09826916239915356, 0.015284021952069335, 0.05238293572479198, 0.00841850572596154, 0.036799110051605015, 0.029648340029281475, 0.03505240277116818, 0.03467174134247246, 0.041988578159362085, 0.03977711980922088, 0.032999003681564526, 0.021347384749641343, 0.07843089425155232, 0.0036669897353051296, 0.01762087453126667, 0.06062558213729532, 0.03711288434363181, 0.02452538175989063, 0.028247211181047945, 0.029768929929442467, 0.05070285894156945, 0.023914256185713797, 0.06797511175635361, 0.024624796989824504, 0.06361241339735928, 0.040239124453716704, 0.04166032863600601, 0.03398055000410926, 0.07506598327909747, 0.04110102316424732, 0.022215350876532258, 0.01817897341454462, 0.013354952229307064, 0.04229096455439445, 0.026862570460164742, 0.07588665496798293, 0.028203463730131908, 0.039101012742086765, 0.01340834089675017, 0.018805474373361757, 0.07385652196863968, 0.04028958283484944, 0.025463218935915542, 0.013810667291944547, 0.06265089644359485, 0.05588051014309449, 0.014748971781603273, 0.09357116650789978, 0.047971012386223005, 0.046367739747849204, 0.024836055311043898, 0.05170931078253254, 0.05013047251850367, 0.08928328046515104, 0.011969336661540214, 0.012267246230265066, 0.06534369932788034, 0.01653992255488711, 0.017260797885096362, 0.05136087484237167, 0.036696883278989026, 0.03769930549747041, 0.03604412657178698, 0.01267416244973579, 0.028350161906752377, 0.07298357243980132, 0.02434101887047291, 0.03278304349570986, 0.055320001913294684, 0.021918909323792306, 0.04675815730626064, 0.04340215976680479, 0.021788366026275104, 0.0706337662714143, 0.0472797291173089, 0.07090542104936416, 0.01628475398906777, 0.07751315922266053, 0.023508367481671517, 0.04269954605749057, 0.2711395684990191, 0.3139620754987963, 0.05149234319105745, 0.11892669263385958, 0.038144249363892505, 0.2514084837129039, 0.8770669756397125, 4.25346871537547, 7.8001640785125, 9.766042770877961, 20.104849646168372, 11.143033965941399, 5.078774133036214, 5.843871168551907, 11.634862903625736, 10.058656488695453, 10.405619548213098, 10.965886000664005, 10.796366064779221, 14.355613012467662, 11.346254906346722, 4.689850047711404, 3.559296712760003, 1.1331528857831032, 0.20737695207278575, 0.31661326065659523, 0.19346674123118002, 0.029724261257797483, 0.004681396202349495, 0.15298464816183815, 0.06792464188390201, 0.10962464621350651, 0.029404511479961298, 0.01920376923085461, 0.038187069848420165, 0.05533239338546992, 0.06931046429540842, 0.02387206197806424, 0.05374346191303865, 0.00855969381518662, 0.05101453798312334, 0.03277139129838155, 0.03847412682408768, 0.09096613048665947, 0.02410686409641658, 0.033437497087664185, 0.07892933403772694, 0.04885030895351403, 0.06652126839805035, 0.0463536705431198, 0.05276422917602524, 0.03778416122640333, 0.01674053225395901, 0.05715104781331555, 0.07157611570531322, 0.013910848609802705, 0.06329359441635109, 0.03530374855824536, 0.04531420414305983, 0.14250859498016297, 0.0753908581851471, 0.040020509773204406, 0.07748875166139296, 0.04399642949142764, 0.05018065510798366, 0.014591722659045651, 0.0472879798842534, 0.01836510022140799, 0.04798505860831469, 0.027403857543944355, 0.022482322942044948, 0.02473261620428774, 0.06932430750420017, 0.02663370552322557, 0.03344209361520987, 0.031498174235645326, 0.0419887428682658, 0.04102691181845242, 0.02138192956936696, 0.016774492931642362, 0.021335037327521754, 0.03165923464562624, 0.06165191012945387, 0.10324144841081674, 0.11777101835656552, 0.07960818753006958, 0.07229249984506639, 0.027302366215735677, 0.029145954890296828, 0.04362095064753967, 0.03662003316886483, 0.03654227907498998, 0.04757115279414481, 0.029456433089029406, 0.02036939499028508, 0.06576041285429271, 0.05490537214603636, 0.016202466569900993, 0.04981435016698895, 0.04872417640722087, 0.0920226116995177, 0.019623577752481067, 0.11053589247767964, 0.11635537214216687, 0.12883878252919645, 0.1524020842606983, 0.08467087191679785, 0.08335322366967317, 0.1538246482490532, 0.08049365493559069, 0.1659380764730515, 0.15880544549755513, 0.11591603603935051, 0.07713744672195566, 0.19143522927357307, 0.16562771893316702, 0.14255440703803493, 0.10254490594830244, 0.19892455078661445, 0.1508455621379037, 0.13742112764908423, 0.23631436059311514, 0.07842979874582061, 0.11844050259359422, 0.194308442033587, 0.20844308599348993, 0.10427189029512868, 0.094777517501385, 0.12801578959390042, 0.13352455931805796, 0.11273029004974712, 0.2663140419510103, 0.08083643331643074, 0.21282556857312881, 0.16076059381086982, 0.1359851877655714, 0.4757441556261432, 0.14701650147476505, 0.1777667498155948, 0.09304192998716909, 0.1482382891399245, 0.1773291144279703, 0.1112173047036894, 0.24645007155354948, 0.09038809416515213, 0.13200583597344737, 0.08402006490336311, 0.12909172944003536, 0.13787135752218385, 0.14200501474401644, 0.08475475088362733, 0.14692228798183704, 0.1631733417631157, 0.11190812448940932, 0.1382084055653503, 0.13793045354466285, 0.12469901958660734, 0.18486064738563954, 0.12824900974068912, 0.23586696524533535, 0.11034624741202402, 0.22153031922155814, 0.09639952481994707, 0.24470080170900593, 0.19328568401115556, 0.15876678870089594, 0.2001007715420377, 0.21014959281010015, 0.16134452134851487, 0.12334744130531627, 0.11458500423618864, 0.18912345170974734, 0.15584031750838603, 0.22545998255091332, 0.16371620698801934, 0.17205174922222094, 0.29988355514022613, 0.7782869245256148, 0.7531566052667557, 0.15999303499777473, 0.16356020084311887, 0.22505576391854595, 0.4674372497585512, 2.927439650220256, 6.172907035196982, 8.26712469900808, 15.890542364889576, 9.51195163111533, 3.500371926253842, 4.495088679175224, 9.625564063749007, 8.196497521092816, 8.805068942808337, 8.426458239555359, 7.900896428092834, 11.051960452910393, 8.127336329029452, 3.1925899126837334, 1.8534975162436886, 0.4256196662543282, 0.14170463166890607, 0.7569748487684035, 0.20187829470922872, 0.15914566514472808, 0.14270175638939106, 0.30589608896163206, 0.18909360492421737, 0.18342636225204315, 0.20512699780444946, 0.22722920132500513, 0.13053966626044244, 0.16092389311280944, 0.23406100489439505, 0.18601287426727434, 0.10901055013340329, 0.12824474263095087, 0.1550316044519986, 0.13877330347895622, 0.1403904384783199, 0.15074938745988956, 0.180399548863211, 0.1281701716324014, 0.15956538939668288, 0.17573632570284028, 0.1335549730086519, 0.23364075970265175, 0.17973659169529715, 0.21324311713537863, 0.12895162728044296, 0.318108388493138, 0.16836858234338223, 0.1985820788409441, 0.12953290415387, 0.12715910411169454, 0.1379918478309147, 0.2768189460039139, 0.17753312364220622, 0.11468415899622826, 0.14596484661582979, 0.16149658980148454, 0.12573454063385725, 0.10011793174330266, 0.18672541264564763, 0.19363665953278544, 0.10017164982855321, 0.16771685602443834, 0.1785828326378138, 0.0855327744577681, 0.18544310403446998, 0.10190654786363726, 0.15973861719812119, 0.12274012510334292, 0.21166171247680343, 0.17723534526603837, 0.14651448405798406, 0.0722429109737277, 0.15192767665270837, 0.17350717838252747, 0.15135885636893012, 0.1403465722837756, 0.2009626511003702, 0.21507687115621185, 0.1319733232019409, 0.08961596946802833, 0.1236502682009051, 0.27893886450798283, 0.14454048998173208, 0.14971282453306262, 0.22664326663699844, 0.18169953878368103, 0.058457821442355076, 0.15407829996078246, 0.24549135848158793, 0.0979670096609381, 0.11990969835390007, 0.11885414410743023, 0.13592740941432216, 0.16550364333295053], [0.03859000528351434, 0.04078243400961642, 0.08427825185560411, 0.03202036657791225, 0.11821777785136817, 0.06049894780341176, 0.04750861320644618, 0.012045695517782964, 0.07232463723348995, 0.07383442033202418, 0.1121985407606248, 0.028993733219742298, 0.02263219655311156, 0.08028428310588484, 0.07886662208024534, 0.051775067939513156, 0.051372235926288756, 0.0578961372675915, 0.037158949210518794, 0.017256344999036482, 0.015843121537698374, 0.01737985369418898, 0.024510188321132335, 0.07125861056509518, 0.013920615273227376, 0.02836489186231648, 0.015683753224420213, 0.03692721527430319, 0.03813936938381484, 0.04490292218003062, 0.046245226966998274, 0.09972756398060631, 0.01532743615473831, 0.053299812735208583, 0.051832478568558736, 0.025509460003025113, 0.06403944229767208, 0.05185011391257567, 0.03447576072968302, 0.05623513607368354, 0.017589307878346696, 0.04380665036038526, 0.046908984696792985, 0.09174179450999345, 0.10623921174556018, 0.02735012413693532, 0.04773934739792059, 0.04537838315891643, 0.005817436603754158, 0.0458287624191613, 0.07550377954518603, 0.07653552377896924, 0.01923922569521012, 0.0985522318871752, 0.03613634440567225, 0.018640058753531308, 0.0554229143346029, 0.04057040385481331, 0.0505451405901582, 0.04237033892422915, 0.05381884879522747, 0.07692574598495999, 0.0660913858202196, 0.026674415435521837, 0.03328537883897943, 0.022228096664372473, 0.07151010956975722, 0.06256325215461754, 0.12081195074584215, 0.05107307859185723, 0.047233526354595545, 0.15361303944260846, 0.47048511524354264, 0.23136057560482334, 1.816116347908974, 11.439412178531772, 20.988942077082974, 41.8357962946738, 42.959119965953214, 49.15862606417749, 62.661557966663, 73.41199013494676, 90.95862680865874, 98.15710175421931, 121.44398596978958, 98.42721969850602, 91.90192545613935, 90.3438658868113, 101.25673124867102, 102.75085618419033, 103.7772463214013, 107.61645440132388, 98.93373889307823, 106.01139699259113, 102.3330923818773, 88.89732714622252, 83.54762215768137, 68.08958484280494, 44.783237826439645, 19.23507974993798, 3.489681016052923, 0.5949968952805765, 0.15648292738103098, 0.49886177804681564, 0.313059531993443, 0.15986802477029063, 0.04005749649818867, 0.06377689630514191, 0.08395891576524704, 0.04368140264564464, 0.01960545019697278, 0.08067861920402897, 0.042263779924401355, 0.022406679420401494, 0.10224531194375408, 0.017506553145546108, 0.02342110432143654, 0.0978213610247739, 0.028875862931712504, 0.07075266311726264, 0.02127813614694582, 0.08848655668477859, 0.020757581317617048, 0.0729750152376871, 0.10000929281476045, 0.030961064246272853, 0.01106165462143479, 0.06778015004050347, 0.00820660389088575, 0.014380134920018816, 0.005552932298967556, 0.06481276209195776, 0.06852998923990997, 0.02159465111852173, 0.06974370233834752, 0.044618799321113095, 0.06451563489052557, 0.013808318274846722, 0.08379485037538313, 0.01773646762294154, 0.01544754820755653, 0.029580725109084483, 0.005260840689222659, 0.033607618402569525, 0.008163041258681445, 0.03665886999618623, 0.01223617178883644, 0.01132192724804965, 0.04121414370714657, 0.022167596785772233, 0.054180928761319774, 0.08731420467337293, 0.04820982880529858, 0.03984943850927296, 0.05547421541245234, 0.093381138398282, 0.03153850876485869, 0.05869887100772993, 0.005877857958342159, 0.0428813157392846, 0.01120294134448012, 0.024307452728070562, 0.020597214217207605, 0.04139998897669777, 0.026865717166313724, 0.04015685810196785, 0.042257310311880805, 0.05055026188793202, 0.040637440378627473, 0.04607513246517028, 0.040133523063794266, 0.023151868466107596, 0.03177954683891468, 0.0403763959184289, 0.03363082703623561, 0.030588159457810467, 0.05037269802884229, 0.03710564098230774, 0.13290529980534507, 0.03695637258070131, 0.10909747046929215, 0.051788700474125725, 0.034335283187007716, 0.05849164422421206, 0.08762145189628487, 0.011825610906065953, 0.057220520496728926, 0.03070657941392593, 0.07352556432447127, 0.05859275633889822, 0.04316024069163588, 0.0446859852320725, 0.03769199701867277, 0.04524756981540592, 0.08238999067895836, 0.03907175201381888, 0.024425246407307928, 0.04314662730922142, 0.04334867533837115, 0.0475160634115098, 0.052080346316459684, 0.10968539698590195, 0.038210542782420115, 0.021324423179330847, 0.05127207376062871, 0.03271740125191789, 0.06267477540419468, 0.023077613478826902, 0.04749101616682545, 0.013854547850637427, 0.04840391335047541, 0.03571277822277719, 0.08742899528794712, 0.05361756685400202, 0.042529014885545745, 0.05117373105378882, 0.050117985285337896, 0.1116822587866937, 0.03922830974202483, 0.04015390483301975, 0.11061001914523302, 0.03881211715540098, 0.11833951688341557, 0.03886735592518122, 0.031018003731244997, 0.02565998287360755, 0.07161113358433209, 0.07501044956546637, 0.03858288449625816, 0.038630768821965304, 0.09032383471006349, 0.07402582739990565, 0.039741703564481395, 0.042596158661669305, 0.05275821155538002, 0.0165299519205526, 0.03868739804132812, 0.09228909538397867, 0.052705159966623595, 0.05034417657542133, 0.07975113187586108, 0.09191715203586126, 0.04506670411736254, 0.09174321177265338, 0.12763112918623995, 0.026213596312088833, 0.04060076391925255, 0.17657640239884778, 2.0395265856096825, 0.891711512400258, 7.914359963709309, 25.101770777856153, 41.16465130159932, 68.87605144131568, 68.29248905181885, 76.44602975537701, 92.1750714701991, 102.68020645264657, 120.41137495348532, 125.38819589922507, 146.32535288410804, 124.96552913419663, 122.0561267483619, 123.55189907935359, 128.49705080832206, 133.13564577410298, 134.27250554484706, 138.84363574366418, 128.86795013181626, 134.31351784736881, 134.73142285500805, 123.65797565829371, 117.63899664725028, 101.79481767839002, 75.76106625218546, 38.12960755440497, 11.943626000035195, 1.3133147022416516, 0.2083768959968321, 0.05836861816445186, 0.11180526186381617, 0.22761668859710618, 0.02469467953027737, 0.011553043525876298, 0.14731993357981407, 0.061326939462413715, 0.04586815082978818, 0.09650017345143903, 0.045692486868750666, 0.015664557933867458, 0.004718948874787818, 0.06944973141916337, 0.017981269103925557, 0.028050709628470005, 0.017345203537373774, 0.07452126412141709, 0.02274858829144749, 0.04597284440552035, 0.032623792968450055, 0.026222936839105624, 0.05637747137957523, 0.049502977560604774, 0.015178232870605445, 0.044053855442231706, 0.058458277264670025, 0.03131610961000045, 0.007879424975403856, 0.04059659640094446, 0.027876009022997274, 0.019021170258882548, 0.10445729123368379, 0.05515389872955219, 0.043684252492722966, 0.0392581029014001, 0.07713835070570631, 0.02612658787608868, 0.04723859402621466, 0.019216896147437153, 0.05635856049916437, 0.012858159532169662, 0.06947698882750927, 0.012987274075708082, 0.031041053401666786, 0.013466062749014988, 0.059669240107459415, 0.05271541022305047, 0.06970051030117659, 0.04714693543651412, 0.0285742215571865, 0.0906965135025882, 0.05030960302739855, 0.07404235957731163, 0.0492419675743628, 0.023279144398627744, 0.05839760693150663, 0.031220032608196623, 0.05049780784775654, 0.013222067575571279, 0.0315290973747089, 0.05313943988913971, 0.016930213708791043, 0.03644173003492817, 0.0877769677449138, 0.021858646932448593, 0.019610441259799466, 0.03418457837054326, 0.029318657921506997, 0.05935003425204947, 0.04431217645985946, 0.056051776759446635, 0.026768561895756472, 0.043322092087398616, 0.2070698427457002, 0.16061969491983616, 0.20892800432780098, 0.13111726591183295, 0.19355399864575557, 0.11482057627290489, 0.08490113496419885, 0.12750231916265142, 0.2405543048535624, 0.11015033574714778, 0.17895184186918123, 0.08111011822737994, 0.16601768833014274, 0.2189183884089993, 0.17883892050914227, 0.17045356723810398, 0.16660114089327474, 0.17631418582412506, 0.11292537433966515, 0.1763823829711445, 0.05078016104356897, 0.09640301052000254, 0.10558474283184736, 0.203554357191728, 0.22901775615830577, 0.197210842743516, 0.08272022820047795, 0.12392710939410234, 0.13426136736187244, 0.17969882356063013, 0.1885643913861244, 0.13055863459744763, 0.24219281370601348, 0.080377270858134, 0.1112034155296222, 0.21562888347093137, 0.3465019052307452, 0.29606598579595167, 0.20714896430651988, 0.17916196446505286, 0.13453147464221524, 0.1939017872416204, 0.11965160333220998, 0.31629928718170813, 0.27350074341220243, 0.11825509399415986, 0.1535661548616425, 0.1800866325896594, 0.10619383635780505, 0.1425049330798849, 0.2690811208899944, 0.17829211759230784, 0.17694544227373216, 0.2516926563675365, 0.19221781873174254, 0.217710267752409, 0.1520274213004497, 0.12905992146941925, 0.11084259577816534, 0.20953324443149954, 0.0999923163063584, 0.15739127783285034, 0.1839265257360474, 0.14776564353416044, 0.2792109176516533, 0.23002968169748786, 0.12530953803610417, 0.2013569105897219, 0.24629179778839314, 0.19854014318796898, 0.18761387545495264, 0.2107705836815219, 1.3881927488311645, 0.6650997626204646, 5.461325347423554, 20.92892981344654, 36.24419089286558, 65.25768456920501, 66.18574480856618, 76.07888021776753, 91.14904219104399, 107.98022285584481, 130.38486403803674, 136.3216458597491, 162.6593888190485, 134.34820728917276, 129.24028504279354, 133.72403267891178, 142.9293961678782, 146.66319447178995, 149.00323344815163, 149.63465659849106, 138.46898663428524, 150.1117737062516, 147.81232341643303, 131.72238442205614, 122.61478993200488, 103.65193443913614, 73.51278720363494, 32.286395834338286, 8.880323536934393, 0.9380109247661407, 0.1276399621800069, 0.43394725649587573, 0.42827082076861017, 0.32952165831961944, 0.1280678299465968, 0.12818887949951235, 0.2745759324921716, 0.12633571281067787, 0.23140886978757, 0.26045120171000885, 0.16066418930647836, 0.1474777783357328, 0.19382562278018844, 0.20566853003636484, 0.13885605629653702, 0.2172596701571057, 0.09844463483821, 0.15694268738790867, 0.1509897398852533, 0.22331749509659507, 0.1752883021629626, 0.22327516107789933, 0.1843439976895048, 0.22543119296671885, 0.10264062097356205, 0.15777609911897492, 0.16916517588880756, 0.18318211810002405, 0.10059007939191596, 0.11096442674076366, 0.16339271870111266, 0.10731744219458873, 0.32211705080924496, 0.16537651870279543, 0.14554431031067527, 0.1513681260328139, 0.190448829784028, 0.1474310316505932, 0.09304545399162079, 0.11477336227413147, 0.10469026623233672, 0.1624159259541381, 0.10316129263129928, 0.1361039926808688, 0.14068358968342506, 0.16470138073688553, 0.10569216368058998, 0.18527036652930323, 0.1789073628042975, 0.16837075803308718, 0.09253923075213548, 0.16150834159024302, 0.1502919103950262, 0.19567731858020831, 0.17289701999435503, 0.14307015275041904, 0.1894409798326031, 0.15057763054726586, 0.1340134153442998, 0.10462592250757641, 0.10225376955443814, 0.1303134711399194, 0.21911988485484354, 0.10929710532148039, 0.15755024107713855, 0.1262140503874229, 0.1500884527640958, 0.16083062956890753, 0.21681206030470712, 0.17077579914081484, 0.21603265777230266, 0.18953848750360552, 0.08218043498815068, 0.17708304698669142], [0.09141427660060507, 0.03643231864477839, 0.004524233743488308, 0.05092782066053441, 0.07795582014706828, 0.04826056297808405, 0.036956905011808684, 0.04803015437397746, 0.07937221712763272, 0.054467384357966726, 0.02222856014756666, 0.021381316699027535, 0.08374332330159603, 0.03135060463401099, 0.0575144607723961, 0.048536902383690884, 0.009771056938916445, 0.022298404383623315, 0.0996393106517292, 0.04375434953779463, 0.0722876351867472, 0.03240515147486041, 0.03424435621127486, 0.03524510069720207, 0.013191426931429776, 0.0422326997373133, 0.06762864849259777, 0.09757882524882594, 0.059376276593895695, 0.011486818097651967, 0.029667157063921614, 0.03675085800369421, 0.007764698041888375, 0.02276073270026715, 0.08815268790649791, 0.040498525655317696, 0.05513342886021542, 0.0393696376422961, 0.03567789057870546, 0.04792200574170678, 0.03632097542586346, 0.047693267209275116, 0.04576771287247539, 0.020681453245361487, 0.02713201124401343, 0.06654669485625721, 0.03823078665581923, 0.004684748794628127, 0.06500963136673936, 0.12758775328796718, 0.03442424514721479, 0.11285530027723122, 0.027255380128119743, 0.03772826362100821, 0.05197536928819553, 0.06401896093701644, 0.1178655842499387, 0.02358911889455011, 0.06520768041692435, 0.11938069165954668, 0.0029167466639210622, 0.07502479839228815, 0.03422074155100892, 0.12363118495071128, 0.3309076339487107, 0.21928034963146334, 0.12420736733944186, 0.8830438097638469, 3.1999796580883766, 16.01437061063705, 28.176595203338135, 40.8116772097926, 61.824637920625754, 62.33070212025797, 84.21321699696203, 95.74245145243984, 104.90081710200157, 106.52075598316809, 108.56289094494237, 115.96384648353823, 117.06518527000182, 113.35969078925349, 111.47564303490424, 109.5037655676565, 107.71980101062407, 118.10357001519974, 115.7959141269807, 109.82377606053507, 112.51471811725249, 109.74423823818084, 112.77877992199315, 101.07438025936004, 112.00128770643666, 115.01592728399463, 120.66123777820219, 116.48658075640279, 119.50505641198929, 118.17567886844759, 122.69702634503766, 123.63676348040183, 94.61432287769934, 56.33876392918249, 47.79260573848602, 27.582514978224232, 15.085312128067018, 2.7183966867385374, 0.13773819611918542, 0.11888899344710574, 0.1254577683885732, 0.06475185810197746, 0.09450963953690183, 0.08541734799021676, 0.04263381188314769, 0.0630043042943843, 0.045730684012655294, 0.02360894333481068, 0.015500673532275664, 0.030061150337719632, 0.04429641420081739, 0.04549890411116424, 0.029448214880821687, 0.0720470222914892, 0.09595432048363071, 0.025965483416052117, 0.039097615142142585, 0.01725507903874161, 0.04446967264577266, 0.018532522991600058, 0.046638827620735096, 0.014647197000862611, 0.0331746791339209, 0.08203106316467447, 0.04205432765546345, 0.0463466378559749, 0.04184529290444428, 0.04370576041119714, 0.029612006394252665, 0.02688138557958507, 0.03590695086806532, 0.04350072846958234, 0.12103714995206365, 0.033456427120273156, 0.11195039722107111, 0.01946603751651222, 0.0334771421377457, 0.08939336729987014, 0.011470169091837542, 0.032179726272701256, 0.08493446744978429, 0.1254860293720999, 0.031215951274780017, 0.0570352076582851, 0.01611439327168609, 0.013773875919380977, 0.06726228226456912, 0.03527154222190861, 0.0390310574232811, 0.022130730719636046, 0.031844765819128484, 0.021611290548237103, 0.030488568027654005, 0.03087142046781317, 0.09842680031133276, 0.01697543779418113, 0.01981653231796959, 0.035292096360917055, 0.02522601513192058, 0.16729143207832692, 0.033996534428649375, 0.050117318788843776, 0.04140416798632472, 0.04046636145381678, 0.1085978432468349, 0.051003422047342026, 0.03468762617558241, 0.06172056692922789, 0.04681490909969134, 0.09668201208114625, 0.0343561667438236, 0.040965107675161094, 0.042004734953685154, 0.012506679350119686, 0.05212407078473799, 0.09202359995294003, 0.05125964781449688, 0.03152415036193786, 0.05046363266545439, 0.11254647491319526, 0.03953448061140315, 0.0076961197661265975, 0.03251650235465458, 0.07151237719001309, 0.044226941517404014, 0.04319413625184567, 0.08353015167578574, 0.027189010100799705, 0.045584035631749904, 0.05183546631146343, 0.018991794617426012, 0.03582521694742384, 0.09606924899403127, 0.03393277676115113, 0.013063549619889068, 0.07398409092979086, 0.04920097420953455, 0.02459645365184594, 0.031173716847514434, 0.009656485617010584, 0.05412547548692073, 0.04489369848142228, 0.13414490667562332, 0.07366009702485415, 0.015721629569006544, 0.05918082458177402, 0.01842611146369769, 0.04723205546578092, 0.02332480515413467, 0.07061367944603966, 0.0959573082265354, 0.014491707007701119, 0.00395074199918928, 0.11430398786380408, 0.059323562083825956, 0.0325199612416327, 0.05044771718882746, 0.07081335260262413, 0.06673960345647027, 0.05500883998108968, 0.028645634358268113, 0.020420464326537425, 0.05282785277813674, 0.08739632163797656, 0.08184580778282496, 0.0692935107696441, 0.017832705503209464, 0.04121809672083586, 0.015153522704607778, 0.14735252296011295, 0.0299241412581215, 0.1343835277422782, 0.19882200225707025, 0.03742510347717232, 0.17994459988849779, 3.776729135744034, 8.606897073407328, 30.157911854405558, 48.21713955171647, 65.55223103492492, 89.71523546403455, 96.54323470207953, 111.06559061234998, 119.5643783384754, 124.8792762141074, 120.21660574020879, 124.44349304322274, 137.2947858995007, 130.06920737604943, 125.76877563230454, 123.54660387962096, 123.64812266442084, 116.52815788022934, 127.31535050176807, 123.0883063039472, 119.89171581883585, 127.58692756775888, 121.29746975437288, 123.43213342851209, 113.61281702595373, 122.14347793209939, 127.09965936599241, 135.18721795851187, 126.75672654182681, 130.51110159966254, 131.33403839603548, 140.839416134742, 139.54825032141903, 126.14249906232281, 93.2453215506769, 78.41242374912386, 54.03726223976382, 33.46461111499418, 9.54583110347871, 1.7154642843431043, 0.04403479900511523, 0.12408128458886378, 0.16866963957586598, 0.13928851292979333, 0.04346561099913332, 0.032805980168162815, 0.03544255219880612, 0.04160412076500155, 0.03348545419172414, 0.007110142464479132, 0.06366266493475245, 0.025258765390683568, 0.06110252549631461, 0.05895312792891937, 0.04125572312923689, 0.049639142028266386, 0.04628474561257228, 0.03712289328236253, 0.03362160716806689, 0.02943439656988748, 0.09042681224884526, 0.06264803127475804, 0.04229757589318099, 0.021609331278370756, 0.021002815638278282, 0.06542203181813802, 0.05824917739617729, 0.03153277076630583, 0.03428364886091121, 0.03415350584433444, 0.027593035295966174, 0.05730500467301858, 0.026006480611319986, 0.11994537506853381, 0.010126004626433696, 0.03415109266737296, 0.03666323669735463, 0.019482205802154158, 0.05177192314858398, 0.036204028273782426, 0.0355091980177789, 0.05349479360325683, 0.026975604818172516, 0.036438439687293385, 0.023132252784806396, 0.02463273749115967, 0.042908806804447405, 0.05155585571041992, 0.018619315007761605, 0.06034686785912322, 0.049968149978667505, 0.007331877516868014, 0.05883355692569768, 0.031445168612164356, 0.03474025258554086, 0.07386815118333025, 0.02208297662887602, 0.04659726735084288, 0.06626413864714485, 0.03157633627133985, 0.09737533697437856, 0.022223626541334297, 0.15007875409097443, 0.04110512939552146, 0.020053255401792067, 0.04248781084653832, 0.0045674885041080415, 0.038816928187565464, 0.10047098336320731, 0.14762580184446228, 0.1937800099051768, 0.16293046124760183, 0.11537962127476932, 0.12418302872608747, 0.15039111878122055, 0.13280964606711942, 0.13860165381864195, 0.18539652588867372, 0.1773708662198436, 0.1511491321387791, 0.27652728100938184, 0.20019069494258976, 0.15916293276654137, 0.1378220214598602, 0.14062486138314972, 0.1437518331072023, 0.09834184116053005, 0.18406529490265156, 0.07034148840654282, 0.16655376601603725, 0.07591706865857686, 0.09524666208533511, 0.10892963592684078, 0.14077645486160634, 0.1478023085022165, 0.14662184361969272, 0.23812404413136745, 0.1229000153140195, 0.1221214478174525, 0.1778831032495345, 0.14800326868651376, 0.1507349543633961, 0.12272277321185797, 0.31463267822419444, 0.11241945753534956, 0.13550514175045875, 0.1348871386219417, 0.16941101350370916, 0.1480332380461116, 0.09540063043635699, 0.1685827192399771, 0.16298848474698682, 0.17500195381862504, 0.1759802634196897, 0.1716427348794476, 0.12931427798203884, 0.14632984154647397, 0.16917107476582452, 0.21860867438297119, 0.17519211216318994, 0.1945943154034115, 0.10982739138266734, 0.15421771264124304, 0.17172254591939912, 0.17506855750276198, 0.16824516557878064, 0.18863661815562557, 0.12629381546209897, 0.23557309391758136, 0.10035427752882244, 0.15711824409663677, 0.10812822368837173, 0.2328648658529405, 0.47282753632433955, 0.30067948985003656, 0.1323105244626922, 2.424481232320109, 7.2336826305235595, 28.769275142300515, 47.01892606673702, 64.96597005474952, 93.49200725555421, 96.59026392044561, 119.1269713063394, 133.4201431274414, 141.26274970269972, 141.91061542880152, 145.30580336047757, 151.16869557288388, 148.47708671323716, 144.82871763167844, 139.92087548778903, 136.00214527499293, 133.08570615706907, 145.9205799718057, 145.10580955013154, 138.45861588754963, 139.768546319777, 138.19737034459268, 134.99462958305114, 128.61810299658006, 140.28339662859517, 141.74702121365456, 146.55882804624497, 141.471466864309, 151.87778165263515, 150.73056682463616, 160.4249086687642, 165.66447350286668, 137.47968642942368, 97.07036987427743, 80.11000987022155, 55.159358209179295, 32.80585492810896, 7.292950624419797, 0.8937211142432306, 0.20130417309701445, 0.3597304970026017, 0.25413181903141163, 0.2636835718106839, 0.13673455965134407, 0.1615946950210679, 0.19575083237742225, 0.1554279783440213, 0.16339469520795732, 0.1586210787776978, 0.17710144841863265, 0.14232536207043356, 0.1709044559468185, 0.089887019036518, 0.18488692420144237, 0.22439493647506162, 0.14486405487743118, 0.15732099692667686, 0.1563068037672389, 0.16209217719733715, 0.12287523236966903, 0.12921038113774794, 0.1415924917185499, 0.10956508287739371, 0.18898627600602566, 0.20693553221081534, 0.1410364957466241, 0.2184688786585485, 0.16002269792220286, 0.15985501659733636, 0.1375614902785709, 0.1406310513735779, 0.13504528981303016, 0.22891798086704748, 0.10235401215933024, 0.1783556262812307, 0.12435490821277904, 0.11265304540434193, 0.2122316665707096, 0.08582447775669637, 0.20918694204620777, 0.16571304580617338, 0.1564506750794188, 0.09382922322519364, 0.1587836579569886, 0.09801361845025132, 0.1527048881736494, 0.13756620938018446, 0.1080655423744071, 0.13893321667227054, 0.1071983844702763, 0.11887269875695629, 0.19968763564623174, 0.12517290625480876, 0.15043234963330532, 0.24825459165919214, 0.06080382015375842, 0.14114460607449855, 0.17680575380161886, 0.14460804361489513, 0.2534503072139717, 0.12713390747986494, 0.23387288434370873, 0.1072038236945387, 0.06755629148814948, 0.2424753622542466, 0.14599211934593417, 0.18340675040118157, 0.17899216873751533], [0.08180441605227609, 0.09219922560958133, 0.07591248745278967, 0.006200388635343482, 0.05865177575258478, 0.04521603380600291, 0.06122715267983656, 0.025195258616980527, 0.04462469819813006, 0.06018490538061146, 0.06911578603209027, 0.06318403618229974, 0.0934437967296089, 0.03196045275657408, 0.060343458767860174, 0.07787954843332691, 0.04238833816001012, 0.005924917781920803, 0.05707609377080395, 0.06019542759825146, 0.04008586090358515, 0.08206560606918029, 0.027812090477034934, 0.027227055942339283, 0.019399272953911174, 0.03361464342883518, 0.032611489596386115, 0.03829047256599992, 0.02341112028056335, 0.023467538825746988, 0.06899320430332614, 0.025931555297105544, 0.03230121632617328, 0.0871865361207916, 0.041525324791549675, 0.0561486485774719, 0.04008497607203261, 0.05384863046328387, 0.08319756226433862, 0.0534618211789958, 0.01860878704446218, 0.008025029561512412, 0.04632836665898081, 0.01889539585869399, 0.02691823057830334, 0.012106656964357582, 0.011933146667997203, 0.07044635818249757, 0.030335880958685474, 0.022271204431871736, 0.11990821214332698, 0.06935632231855585, 0.013235244287868903, 0.013067674045751413, 0.02835478716259522, 0.060260361210713466, 0.0546970192132698, 0.08322465879422042, 0.10428728866240672, 0.09593211159470583, 0.02081964210036301, 0.30499664045149283, 0.05352160668060665, 0.9082611566109042, 11.262127910890888, 22.7298782333251, 38.12405740061114, 64.59645140555598, 70.3325294679211, 93.05766751689296, 106.58855807396674, 99.44090920109903, 91.25882933216711, 85.67048734234226, 92.09029336129466, 99.32476782029676, 92.94779408362605, 92.7362685049734, 91.83610808464789, 73.13540027987573, 93.9625818498673, 91.67929956989904, 90.94354921771635, 94.53746795654298, 101.28935752376434, 88.61002922058107, 87.8924943554786, 93.09356504871, 97.00934563913654, 101.93829797929334, 106.72812384943809, 113.357721759427, 92.72180280377789, 102.38228674857848, 94.32215336830386, 102.72652179964128, 112.09202781800302, 96.31859271757065, 83.89301038557484, 98.33254152728666, 115.47060058962916, 127.40639655820786, 119.72743911127891, 115.81385504814887, 112.50195472471177, 95.14539610955023, 66.39759986631333, 34.2531487249559, 10.3568870405997, 3.4806188700660585, 0.236642460729326, 0.1433963376668192, 0.2195177449574394, 0.10796813429483484, 0.07808911178501383, 0.012546126174950793, 0.04045950113645485, 0.10489061354629456, 0.061879219907906756, 0.03565570084197867, 0.02715586722197552, 0.020950214126177376, 0.020172853218091112, 0.05182119026299446, 0.051411245123393116, 0.05976087954496184, 0.026636607081238783, 0.034047119214289615, 0.009982103628346757, 0.060187720753733194, 0.061503442289728316, 0.028971417078508005, 0.03977540377227049, 0.05104873997850284, 0.06473364819201731, 0.0277951005620942, 0.059929372923028086, 0.012034931982446824, 0.06772776494824118, 0.05378317591103335, 0.07286774760652935, 0.03972224110076505, 0.08254089467828313, 0.03262117677818864, 0.041914754096538796, 0.030869583772014708, 0.025820417006710367, 0.02855093248428837, 0.05601767052505767, 0.009305007350180418, 0.06265125267447964, 0.06468662571522497, 0.03208951558917761, 0.05674674874171615, 0.06432375284813105, 0.04559891688967905, 0.023359704289525267, 0.07600218868784367, 0.0035345331331970353, 0.038680185323521014, 0.02942366750850793, 0.052553899736414035, 0.039268939215089047, 0.020289790794073094, 0.08450762624101293, 0.02368428425172404, 0.0971946704591955, 0.032162749764299205, 0.08558568815069814, 0.0906281095118292, 0.030597308462846185, 0.042811954138620247, 0.014445827917135773, 0.047399047311515584, 0.05450787593520457, 0.08987412577675236, 0.042546826429785266, 0.11072644918796518, 0.0356894585063621, 0.03777925443324832, 0.03722203272064367, 0.016318230116139018, 0.030321472760049567, 0.07629998238576997, 0.03364730558748688, 0.020754900009882067, 0.051100791822518074, 0.05922063434075925, 0.07254128689847647, 0.06068142611653574, 0.0434893750465445, 0.06027190232529275, 0.030160125067097046, 0.041363507869743535, 0.06081364906182694, 0.014101237738354793, 0.03440448007876835, 0.05187722576421596, 0.01367178321215174, 0.019308100830042557, 0.026720005327895768, 0.03860736100543891, 0.09376758379080603, 0.03323700038656112, 0.016839901518617428, 0.04975328146810493, 0.042749609903342305, 0.052139013329701084, 0.009455258259549737, 0.06357188734616484, 0.11721811737985381, 0.043038869381792126, 0.05189787949465456, 0.03618298766894206, 0.04015965815333109, 0.0253007221110766, 0.03211781870754015, 0.08808257553966777, 0.02007705583837965, 0.011644480907688699, 0.041570926175242474, 0.035907119407408664, 0.03701752171881738, 0.022009127668195197, 0.03464823776495553, 0.09777989268543259, 0.03780774141271268, 0.06010721257377056, 0.01757091410728472, 0.08798793303750216, 0.046044090582478436, 0.010735701446631744, 0.05390290396227952, 0.05802886966135233, 0.08094563915003693, 0.04108927520592848, 0.0871621975074372, 0.15754307049416727, 0.5292283695551657, 4.271292455734746, 21.66173250444474, 40.22240384932488, 63.1378709885382, 90.55564249715498, 96.28987312316896, 116.63672124185871, 126.36111628624701, 111.56561436191683, 102.21869253343152, 105.1362063807826, 114.8155883050734, 121.52495153488653, 110.81439418177452, 116.30291969545426, 110.46930405401416, 93.57264334155668, 115.76128744309949, 115.10146633271249, 115.31375285117858, 117.62616265204646, 129.0753415323073, 109.64035034179689, 109.67979369624969, 120.81838361678587, 125.84871353641634, 130.03467482905236, 130.5705725762152, 134.37469113257626, 113.21257837357061, 126.4816350321616, 114.2240321251654, 127.33231867513351, 135.48726358721333, 119.34118763093026, 104.60365833774691, 113.4684032009494, 125.41044358284243, 135.30426148445378, 132.2472446195541, 133.678376290106, 133.89751126689296, 123.38358233051916, 97.0033993259553, 58.69855203936177, 23.346708205438432, 10.963170739912218, 2.9403275780139433, 0.14867497457852288, 0.048787508895921136, 0.01521487677124359, 0.031667163655642545, 0.0648873484122657, 0.03697419178582007, 0.03371527290812904, 0.060192727138318365, 0.027814967137190606, 0.04745198398708336, 0.05626691723122232, 0.026983250375656832, 0.0527800067568258, 0.06015851365162, 0.05819153694075443, 0.032250953297461235, 0.03874228824110281, 0.060056064713505976, 0.03239126996167245, 0.016307901335699905, 0.06894604393070744, 0.051245739488231565, 0.023439036524524132, 0.020807451726267898, 0.0530851548988252, 0.004106953790816929, 0.027098427864632783, 0.0018751018210276663, 0.034054240001545805, 0.02702792670818106, 0.022627295505615975, 0.03788945235071644, 0.04988741963320682, 0.04154569889989592, 0.024796628596020803, 0.03227225054175623, 0.06102201731635198, 0.022518895979550098, 0.035806773380646785, 0.048704782891417706, 0.13990175099142138, 0.07394176457197436, 0.04269248272682871, 0.06082714370061314, 0.028172364390845743, 0.08107668615036434, 0.08397734784070524, 0.046243204494878176, 0.042828953629660035, 0.01431771694877816, 0.07150919792512733, 0.016865113472205498, 0.025753007015033115, 0.07324124611313305, 0.021330107551729007, 0.0452931865208572, 0.05467559939490692, 0.07183289305577356, 0.036061811711518996, 0.020471562391086932, 0.050082825680053046, 0.03791636884993604, 0.056909868012993574, 0.045124310098828814, 0.07786206630689484, 0.2021710935138887, 0.245135648536586, 0.13018538123897969, 0.12800704086980513, 0.141660520326226, 0.08642632409089035, 0.12127402433825117, 0.16417601296017248, 0.06865977219516231, 0.081132143255203, 0.1058640355064023, 0.15377264620075304, 0.16445289245776593, 0.1359538547694683, 0.12302539326370725, 0.15977293793712893, 0.2202296857872317, 0.13570628579585783, 0.1483243667790967, 0.09574419022687981, 0.09285163374677782, 0.10883952100430766, 0.0814017985436705, 0.1434634163254692, 0.11976224175023457, 0.2017558585371702, 0.28013834369278723, 0.11111471020886976, 0.11977800783971626, 0.08212539923167037, 0.12392285760612258, 0.1113342633470893, 0.06512177131709553, 0.15386610892751526, 0.39931196178640094, 0.16536478223579545, 0.17665100404091422, 0.13478558600669907, 0.15259276354505172, 0.22824045270681384, 0.13573622451193873, 0.2165890214664321, 0.23095503930122624, 0.16098179403812657, 0.13232699535306425, 0.15307562876372569, 0.10199115461399479, 0.15238262562742158, 0.14146605656752664, 0.13333640812385467, 0.22935483484498917, 0.1535170486256961, 0.11559408758917164, 0.12022914169656655, 0.2505227328548508, 0.10660536346897002, 0.12233728542923929, 0.2043236320417735, 0.3730139100263196, 0.21534998150121784, 0.21334106913737713, 0.36831359288865523, 0.35867464398184135, 2.955183800189726, 18.642176235875777, 39.04663024410125, 63.199024661894775, 93.28820090140067, 105.53905733170049, 128.08306817085514, 140.18102276709774, 132.0721813940233, 115.39538521920483, 113.88629251910795, 121.42494678497316, 122.41474120847641, 116.5774699180357, 117.84230093802176, 116.53505340699228, 97.82405330288796, 118.2624024729575, 116.20329933781778, 116.52683996385144, 120.56979164000481, 129.97034011348603, 117.01787364098334, 115.5677184750957, 119.83027581245669, 122.53790363188713, 130.59608367181593, 133.4599316504694, 138.60316307313983, 124.4158011098062, 132.62059150203584, 122.37438001940329, 132.13170728375835, 140.14751003634547, 123.38257820375505, 107.18636651192944, 122.25731295924034, 139.41992605886153, 152.7962124732233, 153.59466583498065, 148.89598015815983, 150.0320711443501, 134.31025443538545, 101.76121865549396, 58.97873086314048, 20.819487840898578, 8.8347073524229, 1.7161772976959906, 0.20856930663989437, 0.24043810463720755, 0.37259703562144314, 0.21623518077596543, 0.16598277004255405, 0.13098652534667524, 0.2641350121027039, 0.24048575530609778, 0.1386588652648272, 0.17058156520849274, 0.16256820891172657, 0.17183080946485843, 0.3322780120276636, 0.11548999922289965, 0.20254166556462166, 0.11643413364166215, 0.07425750770996656, 0.19685301839584307, 0.13068447219988993, 0.17148813833632778, 0.12980777650110184, 0.12373018649316604, 0.11753456531873635, 0.10708966893294167, 0.09342105924001626, 0.15794787135335708, 0.12769073082674898, 0.2385279563285651, 0.21586123793836565, 0.11430355885456647, 0.06025483005590016, 0.2339819292988508, 0.29838456622054504, 0.16391327544566126, 0.07115551045224552, 0.08247342531479175, 0.11089282050248116, 0.12602482667012563, 0.07064716514920996, 0.14994640474117574, 0.1319378992963222, 0.1324678789223394, 0.1253451381419455, 0.10441332544770934, 0.23924964179675426, 0.12141066378042584, 0.17160974713342805, 0.1490500665480091, 0.13101004424595064, 0.13064701050039262, 0.15710031763920862, 0.09221570416083259, 0.1141841180862919, 0.18774187342534143, 0.12155435889238313, 0.20981522607466868, 0.15489024590821038, 0.15398970955321867, 0.17421222442100126, 0.1679539142717277, 0.11516363044539768, 0.13654634717010683, 0.14692267102579917, 0.1769804371701133, 0.10376589688202066], [0.04242018060458284, 0.056189864107798186, 0.019381007502576517, 0.020550950167460308, 0.03510220231668603, 0.055083257762054284, 0.02574304212635804, 0.06458925594004893, 0.04152604108375888, 0.09136268823978402, 0.04104760768372686, 0.026233752085376653, 0.029462571368522705, 0.04349301779462446, 0.06870646525414721, 0.035556634182050344, 0.07336419556410083, 0.06974836781380639, 0.049624850658038934, 0.03183919827513878, 0.04551738981277712, 0.05112689626853793, 0.02019360270952025, 0.014449851793958055, 0.08000694395553681, 0.010491205443207537, 0.03466984910529948, 0.017639287454526753, 0.03197278485693519, 0.051810595267001665, 0.047179452038460204, 0.015298167765591175, 0.02438453074935223, 0.0570584392745889, 0.03254922963077984, 0.03943205848636647, 0.11063463355024016, 0.07083385311547788, 0.04055499016577679, 0.055409113260646986, 0.07225240280310954, 0.05511749806183, 0.056934731396576094, 0.054770203592676314, 0.03129215595582801, 0.045369385456245755, 0.029731269047084837, 0.017593483057534023, 0.0805592320619091, 0.01962162039783453, 0.04524219187817747, 0.0393095035706797, 0.05229841324410612, 0.07277658314353998, 0.06028178485951597, 0.04473033023156947, 0.09316232070446977, 0.10265311586760706, 0.04794201212784937, 0.30674742715012643, 0.539659055009965, 14.703031066925297, 38.22564678807413, 71.61351280827677, 99.92136032350602, 105.51826092504687, 107.26745759287189, 94.57716234268682, 97.14462034163937, 78.39624789453323, 76.45402354578819, 85.82625250662528, 91.33640596943518, 80.0206425882155, 72.06009818661597, 60.4677684845463, 60.580466024337284, 69.46911381136987, 100.50116508237778, 107.08898190529116, 72.52219261661654, 60.46767827003234, 64.27650759297033, 56.656173890636815, 58.04193942777572, 72.46185871862596, 66.18641945623583, 71.82282617015224, 52.097356011790616, 47.42018453536495, 49.04743863690285, 51.92682704617901, 54.68940334935343, 56.629340956288004, 62.79970776650214, 71.95252326227003, 60.255191710687455, 65.58991324517035, 82.76416793946298, 89.95224860406692, 106.36264524152203, 93.33206084466751, 104.5832698575912, 99.18604143204229, 92.64145697316816, 100.8185475872409, 105.53235792344617, 111.94082829260059, 104.69839142214869, 99.18053442432036, 70.99635924062422, 44.97936025742562, 12.287954207389587, 0.7357585033582104, 0.18923906969927973, 0.10952435764333895, 0.07020263497026698, 0.08862078294999177, 0.10157783485708699, 0.029645765973855893, 0.03435637741800278, 0.0699542079781813, 0.01794003250618135, 0.016267241219118718, 0.07084365138002942, 0.07945930600286492, 0.08524268760436005, 0.043322138052674077, 0.09166360757644139, 0.03817395442315648, 0.0727587639384212, 0.08899906950612223, 0.04800565105171935, 0.04979949955257678, 0.023369448927922115, 0.018667771984192155, 0.019059792581585147, 0.03352273969099887, 0.010526083511180215, 0.06290529892148991, 0.04614162889699783, 0.07012245620811178, 0.009338652974204912, 0.009906951360584748, 0.024534025146896322, 0.07817332783052999, 0.057817398750733946, 0.011235126613398955, 0.04381949382443582, 0.014946007680508399, 0.031841138392807014, 0.030865948684813998, 0.15085179809360735, 0.04527738595741891, 0.017544020590702855, 0.03628800300160243, 0.049481224493994835, 0.05450186980587821, 0.06496262421170551, 0.08687870667105721, 0.026477915798163703, 0.08265441358690301, 0.024480942914622928, 0.019007675620096347, 0.024323473541787075, 0.07269225984571442, 0.04346487938516563, 0.017855239979502176, 0.03547716022078549, 0.05709525746022982, 0.011992507948419981, 0.0759797882769377, 0.04529983233360033, 0.05073389699382167, 0.026007208394848054, 0.044634630528068354, 0.049511301105902086, 0.03199804469101852, 0.019275681904306816, 0.01703424844890833, 0.03779250392389875, 0.03624142485580618, 0.03955768924506922, 0.07205410860478878, 0.03502311906026256, 0.05360005025361335, 0.041167826031244574, 0.035321533289407535, 0.05862457580083321, 0.04039406573640243, 0.04932175180123699, 0.03863737633031222, 0.041366901639248096, 0.04216044232429516, 0.11726893965275058, 0.032678472494045575, 0.06275158337948304, 0.02520425248921158, 0.053963041864335544, 0.02896666924859728, 0.05357788349952429, 0.018218235420663993, 0.018432378062918302, 0.019896521473363526, 0.07462408078173477, 0.06101056813232361, 0.01372566121825648, 0.042741389779914776, 0.07879942084752745, 0.04032434024397404, 0.016904856198497357, 0.008846507557938177, 0.052006104735717665, 0.07864840959589328, 0.0479829135621267, 0.0685785515534301, 0.03252454627785952, 0.01342777367455945, 0.025610311647817015, 0.03910980360101789, 0.018653432733469436, 0.07147730568483954, 0.0560826079679593, 0.023752266894124692, 0.07364746423498278, 0.018105095725566633, 0.05708812135121515, 0.06734968523585028, 0.05836723537574853, 0.08024207932213623, 0.05687275105306218, 0.04876660618690714, 0.14515152171013818, 0.041253949635692184, 0.1391637631722035, 0.03734180290672568, 2.9463844530044065, 28.717615565946026, 57.32706785202027, 94.54041757891255, 117.66763779424853, 121.06644215122347, 120.10029961985927, 111.24039496144941, 111.24217571750765, 95.96204926890712, 100.10804160948723, 117.1559646052699, 115.78927747664915, 103.46040510362195, 77.56233630641815, 83.31344881365376, 85.13838644950621, 94.39085760424214, 130.54959574053365, 127.35338964769919, 105.14729099888956, 89.20589216293828, 99.65729851876536, 82.3341114290299, 90.5806750635947, 100.50592683976697, 85.96239797530636, 98.83373414316486, 79.94039873923026, 79.54672613451558, 78.39467110172396, 78.99802577111029, 79.00859263635452, 89.77021924911007, 86.55850410461427, 95.2388426565355, 99.93771660712459, 97.22250292378088, 113.20165065027054, 116.60335756117298, 134.37834678157685, 113.39598840282811, 121.63284809358659, 115.85489088489165, 100.89639879042103, 112.12110042572023, 116.93728462342294, 126.03376311640586, 127.38942838484242, 126.5238711141771, 102.1917615398284, 70.39104338615172, 26.488087408004272, 4.727140511235883, 0.07938812877382002, 0.15740428600580464, 0.08670966937056473, 0.12556655287382104, 0.036073854613688686, 0.07510709155711436, 0.017632695267938318, 0.01970468539624445, 0.006874217548512764, 0.05577832167487472, 0.05000629349641743, 0.056790921371430166, 0.06929372527426289, 0.067796889061649, 0.07067740263958132, 0.05009579554861111, 0.03280672710388899, 0.04953356362098167, 0.05472070665188855, 0.02397891783696269, 0.028918507216017575, 0.024789063477768533, 0.025057117642474272, 0.045947042564230586, 0.04124893559022777, 0.02603888038485762, 0.07561280917856963, 0.015609792223380459, 0.05825985666184176, 0.08634952377648124, 0.04445351585144958, 0.03401487457355665, 0.046303139383634256, 0.01925545143744638, 0.06376484574209298, 0.014909292916737258, 0.03415284317827994, 0.04757932312185726, 0.02933327679432208, 0.018034485401585698, 0.035106894605222254, 0.017013786240450798, 0.021961235681608803, 0.07289090644448035, 0.043529705745318246, 0.031750508276144826, 0.03305407774244105, 0.08496459002696699, 0.060265762130579645, 0.015688574790293654, 0.0454538504803373, 0.0686975862951048, 0.03433874590442546, 0.03785401312333923, 0.01596080987984615, 0.07114160595641983, 0.014529487591296917, 0.03675510213079472, 0.003455590406027172, 0.0726956382934605, 0.0768275641565842, 0.04466716245177292, 0.09919570743917458, 0.14009820657872385, 0.07771026598469866, 0.10859860933475918, 0.21141372981571385, 0.1454452551420658, 0.12357921354592809, 0.15205979617612977, 0.09388966756241937, 0.2030886676643164, 0.12161751518086081, 0.10058139195485462, 0.16841702974371373, 0.1909728032807189, 0.2392490748916903, 0.116009192330943, 0.16252284118485066, 0.10902280754019177, 0.17812400725820374, 0.0970975611539137, 0.1697512637943991, 0.1283785628695642, 0.15346757466754607, 0.07771375934563338, 0.2270836752629088, 0.23448186295647777, 0.15771439839755336, 0.11595555085448489, 0.19328776777030962, 0.22021601877866254, 0.1883564598017162, 0.04483566732115803, 0.09903675185576563, 0.2147364216826616, 0.2273142983716342, 0.11642862546948657, 0.25273372389135823, 0.14661433595803477, 0.20158143563857003, 0.13494435006812697, 0.19457039813841545, 0.1744056463001236, 0.11599976944947436, 0.19058464185124446, 0.16937741288735023, 0.1370878027932298, 0.16882504817218552, 0.11854453733371151, 0.25511225835690576, 0.14611769647848222, 0.14890021975001982, 0.13674493248183883, 0.19232920791593291, 0.1322972251763267, 0.18652177115361537, 0.12429433364060619, 0.26282619684934616, 0.2545655014053468, 0.196969662943194, 0.3431912103006917, 1.947690294154229, 25.47579230800752, 58.23172330856324, 101.16672854269706, 128.85471605485486, 135.59784304711127, 137.66256301633774, 122.22657726657008, 121.67667665789206, 102.60332015252884, 98.18587626180341, 108.055799084325, 114.49031399142359, 103.74029759437808, 90.51114712992023, 81.79943746136081, 84.56357094549364, 94.93241140919348, 120.55926399846231, 131.09109463230257, 97.53087182198801, 82.37062085059382, 90.34870609160393, 81.61680406139743, 78.43700916536393, 96.79154426820817, 92.10813230083835, 94.93267813036519, 71.53872105383104, 69.40642649127592, 73.30222652804467, 74.35817564687422, 79.5029289491715, 81.86686300462293, 85.60849820413898, 96.14745186221216, 86.07260088766776, 88.17233193305232, 109.53460324195125, 117.83124769887617, 135.90509014744913, 119.4083699872417, 130.72671428803477, 124.33473356308477, 114.31628627161827, 124.11384920920096, 133.28428791415308, 143.747618275304, 141.88176247381395, 137.73983370873236, 107.25419213694911, 71.04910727470153, 24.183889089092133, 3.5603135872271756, 0.45290039431664253, 0.48540829350390746, 0.16118284615297473, 0.2232816115382218, 0.19441600077815596, 0.2925206534564495, 0.17008443543266866, 0.25524459238494596, 0.12839871098197278, 0.17357462476338112, 0.14711718074977398, 0.35211153809101353, 0.1391636559198941, 0.19256413643879278, 0.22684430343008813, 0.10104580211543268, 0.23301227649133052, 0.13729682222249048, 0.17022029346516057, 0.27073792392207735, 0.11541053292251403, 0.12004397824526795, 0.10729879561451175, 0.12319659859302545, 0.1291197069710301, 0.09639899621927932, 0.16156779001316718, 0.13726349739778426, 0.14798669054383232, 0.2442337332233306, 0.14977110850234188, 0.22064253056962646, 0.18777020335678132, 0.12195410357127268, 0.11384939895041528, 0.10849576969180377, 0.11747471853009156, 0.11582375308799168, 0.18638009085289894, 0.08997754764653022, 0.13090148958708012, 0.08360680643348925, 0.08094907888481695, 0.18013409939744782, 0.10406590457404814, 0.23992194523734434, 0.08636588741454386, 0.2584639389909083, 0.17152458879976504, 0.11184315257255109, 0.2648801398613761, 0.19450914174798997, 0.22079044682604654, 0.173578470524761, 0.11502622491529874, 0.18439431434437153, 0.08348821602281063, 0.20439542980203707, 0.218989527333648, 0.1791837520056194, 0.14610211425010236, 0.17525459429429424], [0.06983906496316195, 0.0162064406510082, 0.03178893716164655, 0.10722018733260133, 0.08413705419027999, 0.016134095137878772, 0.036663535471645095, 0.02516784224539034, 0.025546961922138452, 0.10213439007319751, 0.025403320436335863, 0.09516821468188878, 0.07960057261610225, 0.02625173982983876, 0.02189799320823964, 0.09057670501210997, 0.020431827325674317, 0.0686027829144751, 0.05716219439261383, 0.05827933061687697, 0.05153161285805607, 0.10224820009522861, 0.05200885882180545, 0.06791839826731913, 0.06516438112744401, 0.03905671370786525, 0.07456387393176556, 0.020493464844842112, 0.05441410294283302, 0.047985935778987986, 0.05512086501825721, 0.03148285439237952, 0.049886442871103366, 0.04376480280752144, 0.0528068351559341, 0.0259093904582363, 0.00969693793224231, 0.05473123653040779, 0.034735234709636825, 0.012008741351535485, 0.05206283354651063, 0.02160186575154864, 0.02611123738930591, 0.018296583232680158, 0.044786001841026934, 0.03094112106238402, 0.09117135778069498, 0.02275153006907673, 0.03688799923345928, 0.06748857697652233, 0.06057455685109862, 0.043014856355805556, 0.1866592073272313, 0.052019515104832194, 0.06213848704412099, 0.031596775497159654, 0.4157676223304964, 0.040100240373923894, 3.1669199610910113, 18.661701794593565, 56.946856821736986, 91.90300018556657, 101.02030646416449, 86.39241526203772, 83.48508388765397, 84.03063066544073, 84.64760380406534, 74.45211641250118, 71.12065130664458, 68.96819576140373, 69.59933650109076, 51.651904198431204, 55.35058552219022, 48.4813896302254, 77.51209858925112, 100.97479128068494, 68.88243705995622, 63.94766000009353, 40.941633178341775, 34.39578963864234, 39.86708810252529, 36.29901778313422, 29.45885527518488, 34.5747987685665, 29.541040697405418, 33.95280891849149, 38.227957064105624, 34.64719395483694, 33.566310328821984, 33.8513058231723, 35.4892836847613, 23.1167455257908, 32.66819346335627, 30.667937647911813, 26.960058366098714, 47.88916272501792, 20.9257330817561, 31.508940881298436, 53.27878567480272, 43.522113446266424, 60.71575641632081, 74.2385825803203, 95.46225301681027, 72.16878706409086, 93.16082585242488, 86.0986218913909, 80.28019366725799, 79.0595599143736, 82.41758731103714, 93.1205980239376, 106.26172265698834, 105.3381613762148, 103.9323054590533, 70.14951167568084, 27.924549579620365, 4.7706704851119754, 0.24041772669842168, 0.2126465031817075, 0.08288316744109316, 0.08798768022848714, 0.014499423428318434, 0.13249276145812006, 0.08459559611735806, 0.03498677201869507, 0.02088355490066592, 0.035869439372852925, 0.04671352119335244, 0.03494819566126793, 0.05851740393066599, 0.07840238811988985, 0.03501833101073581, 0.03486877532615777, 0.010550726644484507, 0.021128760493029992, 0.053001632162880515, 0.012284746551285348, 0.02793445004030101, 0.05601783140352177, 0.048963843183892394, 0.055716310687843836, 0.03544126517109333, 0.05089555303716371, 0.04114691566135134, 0.05919400512451126, 0.07280030888655493, 0.06624972853328913, 0.06582094146119011, 0.02701131983720247, 0.041233257600857366, 0.05463108202562698, 0.05953763386294727, 0.0362834524393322, 0.014786639367230238, 0.06309810793027282, 0.010885714868744536, 0.11110406924760151, 0.05853599305414866, 0.12216081707588128, 0.06822196826819452, 0.04876050046615062, 0.09168433791567242, 0.019700791754369295, 0.03768586831527852, 0.021376802525933714, 0.03255912748676154, 0.03453953754937938, 0.07495558234832941, 0.02776750607506162, 0.04088665261083553, 0.06721325263741516, 0.06032150651838991, 0.07712307491249616, 0.03173389757472662, 0.009701807378611017, 0.053221671766931974, 0.004668360258707958, 0.04676869484565912, 0.0607666265850346, 0.04536900624272324, 0.05398707404252022, 0.08615399515556713, 0.022505608184503454, 0.048015705955725525, 0.0045973769456688915, 0.037352072315350655, 0.061384204534753684, 0.04631651144835257, 0.0571665381111445, 0.04969750643677769, 0.07773255148241598, 0.06370864936240739, 0.04764277052374617, 0.021967958103144364, 0.04065205733622274, 0.0205756469269193, 0.027083176969280167, 0.03932534626895382, 0.020022025827558774, 0.013499324371467435, 0.058483052548141255, 0.08095625712866746, 0.1500271504083949, 0.0058527106434227, 0.050355380611313935, 0.0392790783887669, 0.025017953312565244, 0.03613704537612296, 0.01917164907940934, 0.00892575935370499, 0.007986426869812872, 0.039965742147497596, 0.09010034387991314, 0.014362826120979605, 0.0738991777442636, 0.03606674914819098, 0.047069572047480655, 0.0329164040815686, 0.020075916282592282, 0.03907882683579961, 0.018216166983268434, 0.047948772853781144, 0.0346647163162068, 0.0955475507784755, 0.021624869456694975, 0.009546381545313185, 0.018455958249227657, 0.10085444101282667, 0.0395063192193066, 0.12327822526135754, 0.03584007139227564, 0.028726050607679833, 0.09681565611953698, 0.17466869024980455, 0.27369076386094093, 9.098184724007885, 35.882752326227006, 82.91957224569013, 111.50284859441943, 114.01173776195897, 96.55597456039922, 97.73117157720752, 99.0588625015751, 98.64609579886161, 99.15391722033101, 94.65679430192517, 100.29056518308579, 95.01764451303791, 87.80348793152841, 83.85092335362589, 77.88854414416899, 95.25793675453433, 101.81403729223437, 75.50043259897541, 73.50714683532715, 64.27420908404936, 55.79557841823947, 53.22795960210985, 47.85337501956571, 46.52848074513097, 44.178098478624904, 45.39423719529183, 50.97426376035137, 53.0069968008226, 51.012161700956284, 39.07153729469546, 44.965977130397675, 50.290171023338075, 36.817488439621464, 51.08637294461651, 47.311072041911466, 44.04897405255226, 62.8571665671564, 38.444569956871774, 53.24811666242538, 73.47688967181791, 73.82077955430555, 101.15322774456394, 104.53083561312769, 125.46864371145926, 94.91053242837229, 113.85947919661, 117.82896487943589, 105.87243526212632, 102.48311519622804, 96.18413386806365, 101.78077559317313, 113.16936169901203, 116.34930564511208, 122.58614094026628, 96.17788945474933, 50.08467412764027, 14.516548841230332, 0.5596889447300666, 0.048822250983287255, 0.12243229565360855, 0.07742303663924818, 0.1573249039750907, 0.03444662257548302, 0.04967051715920529, 0.04580147053685881, 0.044920423458660805, 0.05124852804827595, 0.028489545858915777, 0.0679685234002048, 0.05364534520213643, 0.08518319321616043, 0.06742836246567388, 0.052507543756115826, 0.054411436956856525, 0.04230563896858404, 0.02461972931820539, 0.05311006041724355, 0.06759522407646142, 0.03753287289592047, 0.06725711117108023, 0.03975571148217686, 0.035075772283298355, 0.04029642016957364, 0.024832163584388556, 0.03568543654475962, 0.04410783399737651, 0.009891485960613336, 0.05266484075916871, 0.048515643443792104, 0.028599182616979368, 0.040248635435296644, 0.06209652074762891, 0.04844263909504779, 0.02098529520744999, 0.0551440391779667, 0.03048607632668028, 0.030045232945872895, 0.05050307087179634, 0.02673536156033797, 0.06424126433088415, 0.025590835777561993, 0.055634975132922974, 0.02902678608323538, 0.06457052509030027, 0.02258008533728219, 0.023035637606235764, 0.03669809752834901, 0.05011081853280625, 0.023505986863446814, 0.04505648450445264, 0.05340857806825831, 0.048571885788753155, 0.018160093177650726, 0.050668545863440925, 0.04768272966987664, 0.0580427703267384, 0.04523574141785503, 0.13973281328235904, 0.1563627128639529, 0.12973538119225733, 0.30224623158574104, 0.3329597077062053, 0.12380233665387477, 0.11496578823895225, 0.08758127824553559, 0.18444204162205421, 0.2346952031216314, 0.08666007283834681, 0.2553831164034144, 0.20860977140405487, 0.15964817285778063, 0.13164430376022093, 0.18949010139030797, 0.17086679506446087, 0.20177174720071978, 0.1569276567428343, 0.20227175746713916, 0.17510762798690027, 0.15705654337521524, 0.14715292641232092, 0.15700487840560176, 0.19240753274531136, 0.21408595174791353, 0.15914448536932468, 0.11474305583584694, 0.1450763531630078, 0.10479656093183065, 0.15617146667453552, 0.14260028038294087, 0.060423296620889064, 0.15210995961341167, 0.22298447667591034, 0.2325301160735469, 0.1188352600400967, 0.14166606680279778, 0.25024867256081873, 0.11209609948339001, 0.12591300847669765, 0.07743750804013784, 0.06755827565587337, 0.11138798143233984, 0.07529951752193513, 0.08575993484907574, 0.17620460460743598, 0.11334624772350635, 0.15857172739361564, 0.12831926000334565, 0.24659601130312492, 0.1542211447151438, 0.2704224795583756, 0.12381947404074094, 0.12202181808289983, 0.15167145088555353, 0.5209120867713806, 0.20827632397413257, 6.675612215072879, 33.55795175798478, 87.91484402072045, 122.67927369763775, 129.28598850004136, 109.05991015895721, 105.11476670542072, 102.10025264370827, 102.57678139594294, 97.51474303583946, 93.3140100971345, 90.93495138229864, 86.35721591211136, 66.15009830844018, 73.46146691230037, 63.78956102555799, 97.74118146588727, 113.45159192239086, 84.1657014046946, 80.84988655582552, 57.139707995999245, 48.69359377891787, 55.71005898137247, 49.8704578030494, 45.27749961422336, 52.90385415477138, 42.42150029828472, 50.40053867524671, 56.511909115699034, 53.8877179545741, 50.39418051319738, 50.947579876069106, 60.02872974641862, 40.895510027485514, 49.928171557764855, 47.64508931867538, 43.98802826481481, 69.7374745338194, 30.858864899604555, 42.97802579018378, 71.97864624761766, 60.36940328536495, 80.60142793963033, 94.57996291498985, 124.00596833998158, 94.38638610224571, 117.18910078848563, 113.75356735721712, 102.79886599509948, 103.52233148390248, 104.28690341211136, 115.4381625883041, 126.64060869524558, 133.64770335535852, 138.25253455869614, 101.70390498253607, 47.06036982997772, 10.708906035269461, 0.2599191996118715, 0.3191537307875772, 0.25777522594698016, 0.2654234494172758, 0.16060469491827875, 0.233127296932282, 0.2281176334907932, 0.2139887811555978, 0.17159807195346202, 0.13775367109525588, 0.16195875532444448, 0.15648399990412498, 0.2492469513127881, 0.38010451341828994, 0.21701740251193125, 0.09955691789547283, 0.12982738835196342, 0.14217631200388556, 0.17979095329440412, 0.0843392247934976, 0.20078648152130268, 0.11685913623941523, 0.2024292038573373, 0.11871173602318573, 0.18300533565061708, 0.23902952941435002, 0.1827975113185183, 0.18326934487108262, 0.11557856664782572, 0.09259880941000678, 0.2217136747053554, 0.18199117313469612, 0.10318046781204401, 0.13734860976617183, 0.18417711309607954, 0.19637709393376307, 0.1758651357264288, 0.19909955591203707, 0.14211330893299273, 0.23082310363890665, 0.11299904135446395, 0.15410558801264534, 0.12450920598160838, 0.126769709280662, 0.17799260785743115, 0.13195199531412896, 0.12893671920943645, 0.09001831118498119, 0.17925443127751353, 0.08984371208615842, 0.2435255921896427, 0.18384004973115461, 0.09671804119622517, 0.14556266577734103, 0.16176488911432607, 0.2221641803701078, 0.16654261177585972, 0.12065985164935551, 0.16684072723071422, 0.05416699362197711], [0.0721119022777965, 0.01663412264127645, 0.04383771905615445, 0.05967035859582886, 0.05680525870693307, 0.031428860515476234, 0.030429688425013618, 0.020544091765318188, 0.04786972024087464, 0.01889359172163231, 0.037745439312270576, 0.09370800513293474, 0.08077604260535971, 0.019414452986130794, 0.10839738101968843, 0.022746703715153763, 0.05387113046561999, 0.05710348141409698, 0.04396533781302072, 0.06342544197855939, 0.027032224461436275, 0.007866444094331876, 0.03663046728639353, 0.0778565121694438, 0.04780638775217438, 0.04789762882395618, 0.01097832532269099, 0.034746653250148224, 0.04090058775017819, 0.038345922009959336, 0.030204426016538378, 0.04098620190615616, 0.059449116233736284, 0.007373720281682308, 0.056629686676446474, 0.031334899831563234, 0.05795858875517884, 0.02859605506302849, 0.05758675265937083, 0.0629215284941658, 0.014830743049031064, 0.10969662017399266, 0.048363130659826344, 0.0188067882141519, 0.03501419796638432, 0.08022271261941041, 0.03542301695673697, 0.07279181297147468, 0.08397682690091672, 0.01983935024679428, 0.08187403812283471, 0.03803048530713685, 0.0762687566419763, 0.06017151033325542, 0.07811708165512932, 0.061013349031488744, 12.761633357694073, 42.57867359345959, 75.95104232911142, 94.26286282077913, 92.26075956898352, 74.85812879377796, 83.22537591380458, 73.26399910834529, 65.90762522912794, 81.07579938827023, 68.67928181925129, 73.92569511167466, 57.029865941693714, 44.02857772765621, 42.477064594145745, 25.773582573859926, 32.40427090275672, 36.42733812332153, 22.365105652040054, 87.39609487595098, 100.67910732761507, 68.75462270552113, 37.712902792038456, 41.04388544636388, 51.03757473730272, 58.67921475441226, 49.904335314227694, 67.50513599764916, 50.41572217018374, 65.07563168002714, 34.40759205049084, 57.350092164931766, 63.10409545898438, 72.32368146219562, 61.01830451719223, 45.76910595740042, 42.147844376102576, 59.718991941021336, 59.2849777590844, 35.69325477846208, 62.60340490648824, 44.37444840708087, 37.252224337670114, 30.039532761419977, 25.16336571785712, 27.812348219656176, 30.13732529455616, 40.601555839661636, 33.778777276316, 44.88155595717892, 50.36848898856871, 56.393579052340606, 68.47600890744117, 87.40188429432531, 64.51653703566521, 67.48957987754576, 78.90739548590876, 95.36958309911913, 102.01439980537661, 83.93836082950716, 44.25286277647942, 7.181699948926126, 0.3063147713340098, 0.26743492051478357, 0.08156226332029028, 0.1099181421581776, 0.038117650791161486, 0.022257006907415007, 0.035515606343265504, 0.0828400060474392, 0.043569308660563924, 0.07359546984756186, 0.05560871363887864, 0.015099443600422915, 0.05344514727532383, 0.01060539084832154, 0.03955926355575362, 0.008925927893048333, 0.07199983893623275, 0.03950597831018029, 0.017761306108666525, 0.03424606075690639, 0.014850429593465261, 0.07279306169479124, 0.11905388621192788, 0.028322919820164962, 0.013990072634882264, 0.07642939761881867, 0.04066637934996717, 0.03950379495959609, 0.06486913084142631, 0.03767607005072698, 0.055571742235652866, 0.062498942903813824, 0.06890615373249016, 0.08586742464573154, 0.03150155459861121, 0.040726157190698775, 0.0328357043796249, 0.08044167586992826, 0.07242559996103087, 0.02584429788253, 0.030461776017722104, 0.04347832805867638, 0.0737294203211223, 0.013674029764989692, 0.024829765729185556, 0.04202420124784113, 0.04310960994072018, 0.04560297715567774, 0.0397969001994258, 0.05768842018780209, 0.060280693184223876, 0.024641842446139744, 0.06964260171498023, 0.03539537650442893, 0.11984753797972396, 0.03638959392124126, 0.11299977679887127, 0.03985799571138717, 0.07038002262913412, 0.015739763827784168, 0.07065102623234834, 0.05583550630798263, 0.03963669206226065, 0.04581841257130427, 0.06400883325465745, 0.015749993016793123, 0.07568184902230579, 0.021217699470599333, 0.018889868534320307, 0.02749718045966039, 0.05778105553960609, 0.02943284141140119, 0.04996726897755458, 0.05799600831984032, 0.037367191060536334, 0.13623428891503042, 0.021692469055133484, 0.052587063682656136, 0.04558827209797117, 0.02929561974240407, 0.03446051174955022, 0.014011204212663636, 0.05331792305373857, 0.06733497634770409, 0.04003636396279739, 0.04361116004386737, 0.06669608966237114, 0.016547740482154395, 0.02516966744986994, 0.026280002728585276, 0.05534268960717225, 0.016503502734966816, 0.1488601993168554, 0.012741378046602253, 0.016830578228578936, 0.07471826363114581, 0.012312915604261142, 0.051413742570026275, 0.11175213366626732, 0.07931459199396834, 0.027149916634023673, 0.05136784241204301, 0.043947568403617035, 0.05755250469871587, 0.10492872642052752, 0.012846444132587603, 0.08079835108571476, 0.06280289211821172, 0.04922746936039579, 0.034184628166258335, 0.07461807465240841, 0.10203836095188895, 0.11813008376667578, 1.7677475175549908, 24.35115856509055, 64.45091970505254, 96.98948275658393, 113.05911171820857, 100.58013808342719, 90.90492956099972, 96.53813562085553, 99.76257493419033, 96.61078576118716, 120.87324188601588, 98.92147756391957, 98.74945809764247, 89.77839346854918, 56.77981484320856, 58.48836398893788, 28.658362280937936, 35.50417692430558, 22.283135960178992, 31.96927416709162, 84.9553608125256, 96.000606167701, 54.38764364488664, 24.365469332664247, 24.591941102858513, 45.3524443411058, 52.21026928194108, 36.54255774713332, 69.04967907936343, 34.33854264597739, 55.79209927589663, 38.837818945607836, 52.40980809734714, 53.72885019548478, 59.09205598215903, 52.21145383773312, 36.974908844117195, 34.594830313036525, 43.82095882969518, 45.201629207980254, 36.126037336164906, 39.95873428160145, 29.61279653733777, 25.241462069173014, 27.671911678006573, 34.70141287772886, 40.37301894157164, 48.38634275620984, 51.500383038674634, 54.75955886225547, 73.59640429096838, 78.53441730622323, 82.24609344236313, 91.72251624445762, 120.06774394742905, 91.98103966251497, 88.29920491864605, 93.21535464256041, 104.12371712346231, 115.54341546950803, 105.00163770491078, 66.6842859022079, 20.15027657631905, 1.383792952664437, 0.0875244191997955, 0.2188777244619785, 0.01680246088653803, 0.05386735748259291, 0.05394801121926116, 0.10006631273896464, 0.07390632534459715, 0.12604147376072022, 0.07008654200622151, 0.07722102691449466, 0.034881944377576156, 0.10192976032774295, 0.012333849914402012, 0.04958556183884221, 0.062465223543826616, 0.03933313355270413, 0.014213817231657525, 0.0395888268887516, 0.04211402505696301, 0.016940707198133873, 0.08318152038320419, 0.05576442100948865, 0.024788649790289424, 0.06523909768269909, 0.05744563543327874, 0.03963238664812619, 0.05014886628956564, 0.06322224098708361, 0.042745044019313595, 0.03890924561288088, 0.022499134741543282, 0.07820268431978841, 0.054678483715941834, 0.06220669951289893, 0.029372217043513255, 0.06588739958862144, 0.016068226898149136, 0.08023708442886991, 0.04175271500923461, 0.03571752413746811, 0.01882191845065644, 0.042073977810721246, 0.05833422081665166, 0.05102342077260537, 0.022593915139535264, 0.07722784509702076, 0.08397845866819544, 0.01311967034839214, 0.030612817912873243, 0.04347987938672305, 0.028051830032059265, 0.056382987212630055, 0.0650223101218862, 0.1005890145297012, 0.03792310276279046, 0.050960440684350274, 0.018265600721802444, 0.1090500726094169, 0.08907868136321345, 0.155277687215036, 0.11393857158480153, 0.25992116079695765, 0.153672058856295, 0.16513575258995258, 0.11897386832823677, 0.21148448569640038, 0.17104878691175293, 0.25629336675328596, 0.209922953358581, 0.2814770670187089, 0.08817849740866693, 0.18430592311966806, 0.10951884181028414, 0.073922727287056, 0.2813986502587795, 0.11639878634483584, 0.1495474874372444, 0.10481872385548008, 0.10269580228674798, 0.08097491903050293, 0.20737079272587455, 0.20844305534997296, 0.30184336126812045, 0.0852752693237797, 0.15872218706194433, 0.20064066434579514, 0.13756574972742988, 0.1868236864045743, 0.14529389148998648, 0.22809575401967574, 0.12012930511827431, 0.1891309287278883, 0.08353657149259122, 0.1508453935985604, 0.14559979039815166, 0.22477669340948905, 0.16088738136233824, 0.20090778388323324, 0.2600838472285579, 0.1502560421584114, 0.12390640203750904, 0.20862374484779375, 0.16590767810421606, 0.18059125470538295, 0.20463097119523635, 0.25864596148171737, 0.1290550644719793, 0.2859823075273345, 0.08169828989212552, 0.2724778015286692, 0.27107153989134297, 0.24822074589469742, 1.0310104441258217, 20.73098740270061, 64.58491179250902, 107.38006884051909, 122.72128228218325, 115.31580032840853, 95.45421215795702, 101.73471912260979, 95.67078974939163, 90.41168366709064, 103.12819603950747, 89.42117537221601, 94.39041829878285, 79.80313147267988, 58.14238740551857, 57.59316144451019, 35.87606468508321, 44.957504810825476, 49.88949306549565, 29.494189946882187, 92.84354532918623, 118.85327616045554, 88.25033218629899, 55.84814210091868, 54.87646510524135, 71.6364194500831, 80.93082858670144, 69.64513409522273, 94.89386235513996, 71.10089825045678, 87.29432505946006, 49.76458518735824, 77.87410982193487, 92.31437052449873, 94.48608490728563, 86.6773989892775, 69.74531142942368, 59.071600821710405, 83.5687872671312, 76.43550995857485, 52.699180956809755, 83.72150082742014, 62.49919929812032, 59.166557481212, 43.344955675063595, 40.525489314909905, 42.98952225715884, 46.44627571105958, 59.15390391503612, 52.95151095236502, 63.811922457910356, 67.15546454152754, 75.61224368310745, 93.41716843266641, 112.88265212889641, 88.54315280914308, 89.94808304694392, 99.48125470069148, 115.99383692587577, 131.51781712808918, 117.36336385050129, 68.12867518394225, 17.323106681146932, 0.782319856507163, 0.6682408456840824, 0.2057747251444286, 0.18985511164271063, 0.09412234378678185, 0.2503493518358277, 0.12415750267645045, 0.21540648814651275, 0.13595020819094875, 0.24442733896355479, 0.17741497756252367, 0.14788834017611321, 0.1674729949163814, 0.13375446230413454, 0.1837638239826887, 0.131117740886346, 0.1594554864230656, 0.12076915707439186, 0.15994362232665862, 0.24484842685201477, 0.10047752575408067, 0.2893659340277795, 0.19650273235334506, 0.17138859287144678, 0.12781472981817302, 0.11431400063297442, 0.19537690486158096, 0.1795348960665926, 0.12022929491415141, 0.1480044024966417, 0.0929171342643038, 0.11183613520716468, 0.18338857879561765, 0.19707575079894837, 0.11316472318984809, 0.16247419460165888, 0.1682914219676487, 0.17065912394994692, 0.27405428790277053, 0.11703213421447624, 0.12081405748763394, 0.2005208175509207, 0.1920223743805001, 0.10239314393050249, 0.16884223918520636, 0.10341947192266103, 0.18152958983855863, 0.23054588706262652, 0.1515045356486113, 0.2049739487589367, 0.18484177097918528, 0.18327516713930717, 0.1525025949963639, 0.22154035497336622, 0.2078145108516178, 0.1232995531491695, 0.1947932990808641, 0.1523234989614256], [0.013588428057940498, 0.040168475825339556, 0.060806692983474464, 0.015905984797545018, 0.017724987795396198, 0.06056426445983591, 0.010981424148344706, 0.01594733152042834, 0.05487829476835267, 0.05620636564168719, 0.022438290123377117, 0.04523045158073787, 0.056077574770296776, 0.04692424899868427, 0.020053322434485443, 0.05017761373892427, 0.051496621792114554, 0.03212719370851354, 0.05298066050595334, 0.011814183747065405, 0.0518807229555903, 0.05174062079599789, 0.05862426170478425, 0.10419597864271173, 0.07669620306020783, 0.061702893280814734, 0.075405590055931, 0.024722716433086225, 0.031423779437318444, 0.039669790891029184, 0.07904124416170583, 0.016678189933900873, 0.023155463333692283, 0.030206109494751984, 0.005316327001163436, 0.014923904128673096, 0.058328839048983595, 0.0023800570652970387, 0.07715938748010705, 0.00455992290705082, 0.06111602396554044, 0.045657832881495844, 0.05882825559726166, 0.041110338793406566, 0.0348326274674506, 0.06667686085547171, 0.019587619500535152, 0.0769828578397151, 0.08780940390762784, 0.03785749116251546, 0.1437966339290142, 0.09980395826841555, 0.05396070912660611, 1.0667378431366337, 18.28803720012788, 57.20672561276344, 85.90056573190998, 92.55419208157448, 79.47763750630041, 79.21195184030842, 77.05644469107352, 82.84151707926105, 71.04573403635334, 53.51073111257246, 48.235602148117565, 21.202677911327733, 28.244889551593413, 28.790040169992757, 21.62411109093697, 53.22782231915382, 52.87377742029006, 87.15100949810397, 57.50487281430153, 89.47061292586788, 62.32773288603752, 30.008006711159986, 31.52566194534302, 64.24861561867499, 98.60884897170529, 96.77910251002159, 51.412576859997166, 53.96588294736801, 68.21356311921151, 42.726762679315385, 69.26038880502024, 48.81572461897328, 46.04176559755879, 57.43339154028124, 45.687304927456765, 49.61875538672171, 54.67012882232667, 59.99890404362833, 77.84638650955694, 65.78324687096381, 74.47638019438713, 61.39049037810295, 81.41413519459387, 96.06289340603738, 92.51739240461781, 85.85982799530031, 72.71040362696495, 49.15815145738664, 37.049159311479144, 23.58682001790693, 23.889738782759636, 27.581171566440215, 25.25788111071433, 26.634280027881747, 34.3212136145561, 33.010337891117224, 38.41677996420091, 59.91799339171379, 78.35838917763003, 80.34496768828362, 80.26435513650218, 82.92850740494268, 89.00367829107469, 80.17672938685264, 38.63162386801935, 7.2550703344806555, 0.6785186199891953, 0.20777029225662833, 0.1391305455998067, 0.0330042245707685, 0.03724730596126568, 0.030777929012753794, 0.013073210946224151, 0.09819506637511716, 0.023387275793920123, 0.05371820782461474, 0.06852880946450657, 0.04336688907877092, 0.0371389772983328, 0.09880533201559898, 0.0365736197319723, 0.03953980875291652, 0.028690701395633723, 0.007520226457516753, 0.0811190584734563, 0.07901464558897481, 0.06416434910328639, 0.035186349414289, 0.09499589852508038, 0.013755561629941147, 0.025119584451820103, 0.01344820523950001, 0.018329590130897782, 0.016243576763137695, 0.04486600440295954, 0.021485135019306215, 0.09606105951412071, 0.09807416237890722, 0.09148448855886537, 0.040886438106216734, 0.041634438694604946, 0.10463539901519976, 0.007641215681008274, 0.04759574038607459, 0.03627169682013412, 0.08385195456925901, 0.0443321751851228, 0.07947506443146737, 0.03551223172595905, 0.06112080435418795, 0.04377008498375935, 0.035915914096779404, 0.05069700219938832, 0.03246495612866936, 0.09124954471424704, 0.04882963607087732, 0.00364320342346365, 0.04633549127667662, 0.0511699695620806, 0.038917971354338436, 0.06920805366169061, 0.03593781272009496, 0.018200783937748884, 0.05151916009884688, 0.07815439013704177, 0.024653149903902126, 0.025491093045040488, 0.03848944092169404, 0.04473683814848623, 0.02112345916459397, 0.07166656770653303, 0.060733114068786946, 0.003637820698185674, 0.04592529332806026, 0.02974774376789649, 0.024094853752983675, 0.025337425383528876, 0.034546934128288305, 0.045468647468594775, 0.07030297716658923, 0.04199490987605626, 0.036111316313186, 0.022930405853736787, 0.04411290932987486, 0.03372215237768908, 0.005009078820641603, 0.03959971299815563, 0.05839070064886924, 0.09518915952573861, 0.02697059843358734, 0.08753144422606116, 0.10144402227935292, 0.053887114890160105, 0.0661434491555537, 0.08413558330146537, 0.08944942961416899, 0.01482787309214473, 0.05508083692421356, 0.07213592679510195, 0.043453882193012584, 0.10360472730451054, 0.07416412925287601, 0.023773075757367958, 0.07343750251757522, 0.03444048621120953, 0.08422499342310814, 0.04751974063354635, 0.07137365398868438, 0.060699865852873174, 0.04388888223817752, 0.08062906097620726, 0.03498836548157758, 0.17929105028029413, 0.17547709687102228, 0.08619266727398481, 4.8472743745773075, 34.70082844457319, 80.89508794969129, 104.16673767951228, 103.72241158639233, 95.350049695661, 95.68388262102681, 95.99556199965939, 113.81305402325047, 104.58832187037315, 77.51426373758625, 66.66050849422332, 25.072186300831458, 33.9055561250256, 25.967526128215177, 25.549901570043257, 27.489339074780865, 20.446929354821485, 29.443210901752597, 27.784697471126435, 44.68149938891011, 29.569450424563502, 17.133116875925374, 25.160488659335723, 49.44896382670249, 55.531375408172615, 52.65852166760353, 26.57714286158162, 21.02445717780821, 28.178840760261785, 18.93433790053091, 18.55717259068643, 21.713725482263875, 13.16140720921178, 17.505934238433838, 19.549671488423503, 16.76828153671757, 22.456687112008375, 25.432640352556785, 37.69485204450546, 32.05404050888554, 36.11199525094802, 29.93321691789935, 36.476912959929436, 35.88058717789189, 64.47212403820407, 45.7144045829773, 24.83397879908162, 21.658420062834217, 22.003004204842355, 15.245921419512841, 22.47711285468071, 20.446758731718987, 21.14951018364199, 23.811944453947007, 52.39296936219739, 59.71570107244677, 54.69410627119003, 88.57144094282582, 113.6378574371338, 107.52354914142241, 90.17825557339577, 93.85552467838411, 98.98461987895351, 102.4545995650753, 63.093661954326016, 20.642726229083156, 2.1830135055126685, 0.07570284749231032, 0.43977053595646737, 0.1018178578646433, 0.05013971153887049, 0.06384631153196096, 0.03647285235685207, 0.11402233563844236, 0.010012568072265676, 0.05126414092017278, 0.12816749032466643, 0.03207925384143188, 0.020267369315749215, 0.10961394396520431, 0.030018762692869193, 0.014145647855325332, 0.042052427757411234, 0.029253892848388325, 0.06944418494259158, 0.03822074707357153, 0.08327816237485217, 0.03264525109120915, 0.05910990016174413, 0.08481252923487656, 0.05431975155407864, 0.04316498277588718, 0.030658043913483143, 0.04431971093459476, 0.04442736160971465, 0.04796027949440384, 0.023139624465857784, 0.01804792832943701, 0.025515916209006985, 0.04776450189491434, 0.042222483954843015, 0.03413326197093533, 0.014277191855193628, 0.01958283528144802, 0.008023585485775144, 0.009108293208203489, 0.03756740430910741, 0.020258859994130272, 0.049614443353587584, 0.08547802981469901, 0.029732789731614535, 0.03769422633453243, 0.03290324652146909, 0.04006929042178296, 0.04157380666583777, 0.0568099701476674, 0.0662505482473681, 0.06426910013561288, 0.10158735732998579, 0.03704260726789794, 0.04397838045993159, 0.01993223074673405, 0.18722718491429285, 0.23755453436845736, 0.14985084293350098, 0.11338226151682677, 0.1229286670023876, 0.09466147816349423, 0.1335046257102682, 0.07772318222710202, 0.25088023544559557, 0.2165878416910287, 0.0950900430700952, 0.12455595266674796, 0.15247428038668248, 0.11788428445617039, 0.09950965027054472, 0.12954698484991828, 0.15383549605406102, 0.18198487589195853, 0.1320804376155138, 0.10708114237434442, 0.16585996614829188, 0.11915658795905691, 0.10167561065886291, 0.15084338644819875, 0.21984890944534735, 0.2068490408841641, 0.276418557811168, 0.09615770150576869, 0.15086998502092977, 0.23532756273784947, 0.24860953551626977, 0.1469144585632509, 0.25591519511034416, 0.12955397157178772, 0.07154949414994448, 0.18752271099196327, 0.13152952846740523, 0.1279330827415951, 0.1712556919383426, 0.11802626353117729, 0.1857096873103611, 0.25548420936590244, 0.16151946518690358, 0.1455145707774547, 0.14094678685069084, 0.26142606391541423, 0.1392822616523312, 0.21349149816218885, 0.1665530765369054, 0.12860264358741622, 0.2789808154827164, 0.20839410233161143, 0.1478719612162921, 3.5273092937084938, 30.96930511536137, 83.56150734809138, 116.30848161635862, 112.7272399779289, 101.08225637866606, 98.42318750196888, 99.62738652383128, 104.43953852499686, 92.55722015134751, 68.90773634756766, 65.1992137970463, 28.82848135886654, 40.273700606438425, 42.82685764374272, 31.475043758269283, 74.86906436181839, 72.6121090304467, 114.46766622604864, 79.09555158307477, 124.30879885150541, 84.71200127755442, 42.540332425025206, 47.87735639079925, 83.53037157366353, 123.06210487119614, 125.47782990240283, 69.5639959458382, 74.40950378294914, 97.28700237889444, 60.32058546620031, 96.12681235036543, 73.6831984981414, 62.36053174541843, 80.4117028943954, 64.25356957220262, 72.19995421748008, 75.20976143498575, 86.3572943595148, 107.45682962479131, 93.65811178761145, 99.00976227175806, 79.00663145126836, 113.78317340727776, 130.332288588247, 117.33970411362188, 107.29636546104186, 95.3473432602421, 68.29092794849028, 50.03510713577271, 37.091552288301536, 41.2819968500445, 41.250861075616655, 40.020664584252145, 40.334705229728456, 51.01009853424565, 51.95641740675896, 57.56476348446262, 83.97949080313407, 101.27652352856052, 104.82663723730273, 99.7298937459146, 104.28027460652014, 115.51688455766248, 114.44078230088758, 67.79186125724547, 18.81083030854502, 1.1689982010472206, 0.16832312268595542, 0.41825305670499807, 0.30217170655246706, 0.12687912195800774, 0.17452667287040144, 0.09316417463724652, 0.23280986073997714, 0.07565475249242398, 0.18909435569038316, 0.204202804654356, 0.13851507056143977, 0.19883128724271254, 0.23512505505594516, 0.15144956117916494, 0.15891611455909668, 0.21980963977834872, 0.15779998574045398, 0.20612579259660938, 0.12896164771049254, 0.20633470477356067, 0.1914941874002257, 0.21483547685127105, 0.21036297894052922, 0.1234778294700288, 0.1358383746757623, 0.16471014478273932, 0.17761132589751677, 0.10878666093753231, 0.11745214957984225, 0.21908174899797286, 0.2080616354942322, 0.19456952479818176, 0.13322972271951938, 0.14800389687861168, 0.16556722863066584, 0.09754887121098657, 0.12569435932222875, 0.134443374530923, 0.2142895472746703, 0.12912621871838648, 0.13604685784347598, 0.20293500574846424, 0.17826922688513033, 0.12701977570090564, 0.10188008718673261, 0.15108976032464735, 0.15730310111276566, 0.18518145436481123, 0.1351711887025064, 0.11879264256886898, 0.15212370323077326, 0.321270584939949, 0.18883031582640064, 0.22259012525600774, 0.09381162618557293], [0.03176061872152552, 0.06422605365514755, 0.0688302574018317, 0.02584402017565745, 0.0777774978609335, 0.045322562162313736, 0.07853118282171988, 0.09771558726506849, 0.10891395410703075, 0.05514858207935768, 0.06144777451071048, 0.049344554408303196, 0.027979702853988257, 0.03886627957164761, 0.04878899127605462, 0.04109350018083088, 0.04470953094442526, 0.06627347725894182, 0.029591011754687757, 0.012532101977886933, 0.07510034232250146, 0.05932620508716472, 0.042201228845383854, 0.0115784402981761, 0.06256187702679346, 0.06140231102284405, 0.020651650509887168, 0.04337276880358977, 0.01487104501950765, 0.028824215199077324, 0.022186666629427386, 0.023771262044207226, 0.04306721080455088, 0.03317674757131646, 0.06261613520403063, 0.006796937471541066, 0.03970819104823374, 0.07333892998435805, 0.04220438895807151, 0.01769950579581482, 0.04516200545514303, 0.08709545592747389, 0.07485725496324801, 0.09394426664878285, 0.0631282611509725, 0.058300926635462436, 0.08998897767836049, 0.06806011687243177, 0.08360112972197034, 0.020678065221516356, 0.10223324605894667, 2.314651680569495, 27.002769054905063, 61.379805841753566, 87.93008635121008, 87.12680062940045, 77.36934784919985, 76.31082565553727, 74.41597569373347, 83.85656372193368, 67.99682863297002, 40.467810861526, 20.307302782612464, 30.683693808894006, 37.69639745835335, 77.09166757522091, 59.59723372613231, 61.11909374114006, 64.24415588378906, 72.88580417633057, 86.88817931759743, 79.6323985438193, 72.07607792269799, 53.987012755486276, 71.76660291610226, 80.47730845789756, 77.17835980076944, 71.01277828216553, 67.95648313337757, 60.64708748171407, 74.75801421749976, 83.66880770652526, 89.59924313329881, 93.8426749936996, 85.81075129970428, 82.39830493927002, 93.23567252005301, 87.11185639904392, 89.17903177199825, 84.80678927513861, 80.18384456634521, 80.7948164786062, 75.85809784550821, 78.13550441495835, 71.39502110019808, 81.62484492025068, 96.07326415277298, 77.75497175032093, 93.62466965952228, 89.68337012875466, 90.97127253009428, 88.49931640009727, 83.35992105545537, 72.7589233459965, 62.30870154596145, 80.77372197181948, 74.3675422668457, 61.788053974028564, 32.21717776790742, 38.009539881060206, 29.206746893544352, 24.180957117388328, 25.800999941364413, 37.76210108110982, 77.22695012246409, 77.99931187783518, 76.86481337393485, 75.16569752846995, 81.97061754042103, 67.51710707141508, 45.006573661681145, 11.983629272830102, 2.0154738762686333, 0.26620338821122724, 0.014687856159833892, 0.11252137021191659, 0.01929636244782277, 0.030462111181188977, 0.04410012715285824, 0.048489971837449464, 0.06093909595942786, 0.07447422632286627, 0.025627655878422723, 0.02337921463373688, 0.18224516192511206, 0.009158687429472564, 0.07750805707708483, 0.03239524212755984, 0.0873271898636895, 0.030724534599651254, 0.05490110886673774, 0.07018037245518739, 0.09439732338632308, 0.029075536088296966, 0.09373886315452476, 0.04009063746179304, 0.08325584623361788, 0.050804786939894965, 0.04272990995236943, 0.0664732423460772, 0.0455470412458864, 0.023263966281627937, 0.016354575242486694, 0.02710445697659687, 0.015429807526450005, 0.02515713425142871, 0.03980402864756123, 0.06674556362052118, 0.04578533289473384, 0.0674699610399623, 0.008351796704735006, 0.039518591947853565, 0.12064937156655135, 0.06636531587930457, 0.12467548536557345, 0.025550166084881754, 0.06434580851947108, 0.047000164481540846, 0.0712252167924758, 0.06332455969025051, 0.0614671795178325, 0.03847830966415425, 0.10043395833382684, 0.1512271658547463, 0.02299017028792972, 0.1033451384113681, 0.007318071176057622, 0.021086729079064344, 0.017205580182734038, 0.03412765803776922, 0.1593057928426612, 0.02434401810469647, 0.061973218896215966, 0.04770744366631393, 0.03690307967424874, 0.03632127036971431, 0.037962835912983266, 0.01776776422986821, 0.005636147163327663, 0.028998243562396497, 0.04785139924816547, 0.035587925043317585, 0.003477480889658534, 0.032724380312908086, 0.03714353552148227, 0.08184186243001493, 0.10397876207266124, 0.04262593649928609, 0.023916876206414837, 0.04100190670860391, 0.0033243037638209403, 0.08549426321781452, 0.04255057259973499, 0.04766329018879802, 0.06575026218929599, 0.03858325221846181, 0.03589439085654674, 0.008034223574213684, 0.11678454225822804, 0.04737787647172809, 0.0650313499593927, 0.03764449956736738, 0.030539145152415, 0.022523888957596595, 0.05714038003896994, 0.05344042817371027, 0.04663313175701807, 0.0861591432664183, 0.05408304953767408, 0.03922813354180225, 0.0523151254521743, 0.08287713066824982, 0.026058940397154902, 0.011720579294037196, 0.02413157809285387, 0.07159217290820614, 0.11156584406572004, 7.1456146336370905, 46.024648374126805, 85.1258191754741, 106.98374471356793, 100.25944509813863, 95.41678490177279, 98.14296553211828, 102.88215360333844, 111.64159067215459, 90.60667253309681, 53.40493302191458, 34.87280476477839, 25.438908300092145, 24.361090006366855, 38.49700812370547, 38.62815649278703, 30.609231533542758, 23.228844904130508, 55.375080723916334, 63.73919779254545, 61.305069000490256, 62.03773244734734, 56.8371206714261, 68.55279322593444, 70.95420160601216, 63.27096877559539, 62.095677621902965, 67.45736152895036, 59.182454847520404, 60.220969030934, 72.34217935992827, 78.96475622730871, 74.1284659601027, 69.29128139249741, 65.14675209599157, 66.25297423331969, 66.46373102741858, 57.980052271196925, 58.17438217901415, 62.073033778898186, 64.12879897702125, 66.6319065709268, 66.04905805280133, 61.732681874305975, 74.0422522637152, 85.4423858273414, 74.29638262717955, 84.04435896104383, 78.31785540426932, 65.18581105816749, 65.5088339313384, 54.79333046943911, 48.174809332816835, 36.971504226807625, 38.055310018600956, 38.28289770310925, 37.55217190711729, 22.677959780539236, 26.39791996248307, 32.28813736669479, 31.305564026678766, 37.34714961821033, 55.04561731892248, 102.76246639990039, 99.82148893417852, 92.08381360576999, 88.59777573616275, 94.42601773046678, 89.72307235963883, 69.66236898975988, 26.152165820521695, 6.28231272582085, 0.16575844417656624, 0.19414238481511994, 0.07526285255387907, 0.06926394743664611, 0.052552287121333426, 0.002082120444092359, 0.04670961414493861, 0.04919125638421505, 0.04103567203386657, 0.030921781172735557, 0.026638020513459083, 0.07575622083799494, 0.028724081761714433, 0.06457757309920366, 0.06859027269867159, 0.0537511304531607, 0.026842284451929793, 0.018057581037282944, 0.09115502478614931, 0.03092484169399306, 0.05751837165124955, 0.05119812329329791, 0.047838670697303555, 0.07910427787611563, 0.0335386015414711, 0.02302751515901858, 0.022377478063947732, 0.0056263441107265895, 0.06759002233945555, 0.02267679819206317, 0.03676371295906363, 0.04485119209294358, 0.04465628400324814, 0.04112967102217578, 0.020820371799110886, 0.01638463461741565, 0.04581524862817699, 0.05218210960588148, 0.024659236472460534, 0.03336735790775668, 0.06308435282159237, 0.07530708647062702, 0.07941192346474818, 0.03549579147910399, 0.061479011745823015, 0.12893918601255264, 0.022770113446899963, 0.01907840085726592, 0.03051122316279479, 0.014207311229960573, 0.08144940324728528, 0.03045725992940847, 0.08461523861173662, 0.10839057815892082, 0.18025322606967342, 0.14555425413193243, 0.14078814536333084, 0.27008907809372873, 0.20414599157389135, 0.14848611858342925, 0.13459792510876734, 0.22065869502482877, 0.222994972080473, 0.15649910715799178, 0.11519814270638651, 0.1457855207545142, 0.08402066245194405, 0.21556025731467435, 0.11461891128771728, 0.06117244634116369, 0.15523068006000212, 0.10591733990417374, 0.18499914076059096, 0.245790469850744, 0.12317145558735057, 0.31430154437980345, 0.13797804292651916, 0.12324070227482628, 0.2214640066508324, 0.08390694436046385, 0.15292297808393357, 0.18162006482241616, 0.12182568425252555, 0.13908522383820626, 0.04771631113403747, 0.1688294301951124, 0.1408506887814691, 0.21145961848237824, 0.21522656473661625, 0.09438604657207766, 0.2258454320291358, 0.1677926221201497, 0.16037480725396067, 0.1315856673904965, 0.23606391112890937, 0.21172226406633857, 0.17887149456768267, 0.1837743653525268, 0.27425123378634453, 0.1782164587489059, 0.09319244328165248, 0.15844909203869684, 0.14227035695747023, 0.31634378156835036, 4.8534609329315925, 42.40907030720865, 93.324310241207, 119.84200369927191, 108.99233556562855, 94.78602070962229, 94.2307621432889, 97.53334291519658, 103.8898418795678, 87.01568772715908, 53.46412158781483, 30.326199185463693, 44.22712418340868, 51.77168553875339, 107.17209692924254, 84.0207306031258, 83.17265141394832, 82.92698552531581, 106.88141007577221, 124.30391942301105, 115.70334619091405, 104.66258802721578, 78.88040957912322, 104.9823082647016, 114.87095648242583, 105.5815758243684, 97.95848861817392, 102.03551000164401, 89.29001131365376, 111.50899887084962, 121.2131074167067, 130.31441826974194, 132.78602138642344, 121.25063665451543, 111.73288776028542, 128.575466832807, 121.57390271463703, 118.49098251711939, 116.73979328524683, 110.82580043423562, 110.91356738921135, 107.50440013024115, 108.82351675341206, 101.99792585065289, 116.71606294570432, 130.45574911179082, 115.02346607946582, 120.64619156622119, 127.81181273921844, 134.87978258440572, 128.01817647872434, 112.25581030691825, 98.28805400479226, 82.84659262626403, 108.28972924140193, 100.42985639264508, 90.27800144687777, 50.991212321865945, 55.817751576823575, 49.227671546320764, 39.05392977499193, 40.94272751961985, 56.343874777517016, 102.9155957314276, 99.87172665134554, 98.84977663716963, 91.4945637795233, 108.39225999770626, 102.8061459141393, 76.13018481962143, 23.469062620593657, 4.517203982799284, 0.30257825409212424, 0.25816151812191934, 0.2449424105185655, 0.16120487884167703, 0.20304815693488046, 0.08390528194966816, 0.17736251586146895, 0.1750777965231288, 0.2146635973645795, 0.10887672223391072, 0.17148637633410194, 0.22269641229462242, 0.12409007927823452, 0.21653000205274553, 0.22211283715742253, 0.15805163030182162, 0.22202390967117203, 0.195303391064367, 0.23215344596293666, 0.21396270352265528, 0.1828679760857936, 0.23519959541097765, 0.11021144658086762, 0.17374124888691211, 0.21006608922635356, 0.13581243493864614, 0.14088335477056044, 0.15999131896082433, 0.11515118917750737, 0.0741610649011789, 0.09752365159651927, 0.19360293634235862, 0.09917159099131824, 0.14324670537344872, 0.1327004172508755, 0.29460502548083184, 0.24416383536111927, 0.07078085515287615, 0.11307455464116029, 0.18842988166837923, 0.17506373114883902, 0.23099789425971048, 0.17627896110136665, 0.1612642966210842, 0.18999835476279262, 0.26334866881370544, 0.12598878989416745, 0.13089804219142084, 0.15588493446909613, 0.2287463158849747, 0.2743803655668613, 0.17352105989571542, 0.17026897069186936], [0.03374669400434341, 0.034331889417503154, 0.02419949753300077, 0.0758989813226846, 0.026899392476245284, 0.04272519851163511, 0.03863925324572671, 0.013325409006117093, 0.014042406016209675, 0.0445671841472147, 0.08435826973929521, 0.11100176586619309, 0.025137731159526496, 0.05594363195761558, 0.030794809760165312, 0.027937970214313077, 0.0842275828002922, 0.10078909371288554, 0.03149343789705346, 0.07118836030243866, 0.08651636240463104, 0.05149543435583192, 0.14022117901232936, 0.022448316299086137, 0.010008080712249203, 0.015457024715179879, 0.04333479382518319, 0.05831236432817194, 0.027207139571527802, 0.04679587947565221, 0.01772745268329257, 0.0356942197428115, 0.056952320775317575, 0.017134858776004087, 0.03622036126832809, 0.06958434072833869, 0.05815229791727278, 0.020465062135049415, 0.013758128024487486, 0.05193183251145867, 0.02746921250476472, 0.002674008114075649, 0.04053252080695764, 0.08625214634042594, 0.03160476962464952, 0.027475594017173977, 0.04922615551960565, 0.016948799001834085, 0.18107695444937677, 0.37421930340989945, 14.565327436693254, 69.24666835415748, 87.54361521813178, 84.54163705149006, 71.01418249068722, 76.97465542824038, 70.57173129050963, 44.01497102552845, 41.70567950894756, 31.033706511220625, 33.79559247724472, 34.49327230453491, 51.27356021634994, 69.73411698495188, 83.61721284927862, 145.8318716479886, 58.71575555493755, 52.249826385128884, 67.28164718997094, 37.841407483623875, 36.75394996520012, 39.55261991870019, 39.53636169433594, 29.97967347022026, 38.182245762117454, 41.0987711721851, 48.937463222011445, 53.74004463995657, 88.16599338285386, 80.93863410334434, 45.175027693471606, 41.66711868778352, 27.793658125785093, 28.99877498226781, 27.925477220166115, 32.88984071823859, 30.654168167421897, 37.444930384236, 45.92570658653013, 45.40547086346535, 43.3604411925039, 44.04308657492361, 42.40004493344215, 48.11853508795462, 42.726154711938676, 33.20296549027966, 32.11300942205614, 46.57415282341742, 56.75396250140283, 57.367640849082704, 60.585208169875614, 48.05831493869905, 59.756391740614376, 57.3382701412324, 59.524203115893954, 63.54977869218396, 62.307799400821814, 57.45386239021056, 79.72611965671663, 82.50540917919528, 52.66861000368672, 64.14615546503376, 59.57384071042461, 46.023165718201675, 23.702161235194055, 34.9511541089704, 57.67589992092502, 68.44722655511671, 62.72762636984549, 70.16854301575692, 78.34779877816477, 73.34036765560028, 52.25504313745807, 20.730100947041667, 0.29984040906833065, 0.47161524814944117, 0.10902801693807687, 0.1551310426645702, 0.051372864118386666, 0.07262445340353636, 0.04680165577860129, 0.014825159225672966, 0.09213875062883863, 0.023103507250667583, 0.061056954756138794, 0.028320648369469473, 0.10084191547526468, 0.08662766731914975, 0.02795507312722264, 0.03921859574714496, 0.07160945585177791, 0.015072536677302373, 0.033672065549199624, 0.06848832171770834, 0.027397433896699262, 0.04562812016135262, 0.03695942161063995, 0.030763951738575296, 0.02105522562839812, 0.040217214339082284, 0.0637383429303525, 0.028327026051439108, 0.08091606049528045, 0.02695470019393871, 0.04766488365168053, 0.0653365134231506, 0.0447222096995721, 0.021467813771338235, 0.048374422795830235, 0.04840941386177175, 0.03465541983924566, 0.01736289250754541, 0.023647144309154922, 0.11037928878419823, 0.06558080354044515, 0.058519024206625844, 0.08406785346807973, 0.030648967686800227, 0.09300689678639175, 0.05079936303739106, 0.06855091876200131, 0.04861331582369824, 0.05773295287884051, 0.05536082290833997, 0.06456280292402353, 0.05012892885133625, 0.02057826503240053, 0.019936589787023205, 0.01554122256610783, 0.10366435958853654, 0.08256046056386926, 0.08336940344663397, 0.01394597469874087, 0.021344707272345984, 0.054674576667528, 0.059562719412027836, 0.017304512777275616, 0.052648534577700405, 0.02235250168239638, 0.06306521594524384, 0.028609716325938225, 0.06038625243931048, 0.04626296190244537, 0.05646065703683323, 0.013066537362793762, 0.008548634378389727, 0.03509420818919617, 0.06095890699314976, 0.06796672309358275, 0.06964439436072303, 0.049983835628917145, 0.04562065080409089, 0.023258188063459053, 0.07085164933795891, 0.020847650274874705, 0.05720447095471525, 0.022478046256207654, 0.09548928979183398, 0.07232237727411332, 0.018484774646499467, 0.04692449031638042, 0.054804846088612275, 0.06307671492498729, 0.042483034288330425, 0.003920945966984296, 0.07589186436586803, 0.018633765341233344, 0.04870978544556326, 0.07254847280320621, 0.08628230722200486, 0.01514820413919346, 0.03004304001918964, 0.07633614939667525, 0.06016241686959421, 0.018550843984309225, 0.6585223155636942, 30.05906616487811, 92.10727722414079, 100.67597727621757, 99.25975061232045, 88.29787131278746, 101.06847316988053, 97.66456973168158, 70.90728221401092, 61.409027499537316, 47.224819121822236, 51.82498662702499, 22.638879245327367, 16.569613487489764, 41.979370732461255, 62.97864237139302, 138.31592006068078, 53.18553916869625, 56.373610265793346, 65.69981413502848, 44.20995989153462, 45.478783884356105, 46.13419232829925, 43.2102850175673, 30.562023847333847, 35.58772340897591, 42.44991394781297, 49.339592456817634, 59.63482964423395, 97.31925210645123, 88.9285727470152, 49.06414401146674, 39.75924253463745, 27.030180538854292, 26.182793648012225, 24.280263685411025, 28.26841985025714, 27.95597953181113, 36.590493033009196, 46.572274008104884, 48.545630208907596, 47.19869221410444, 49.76595017217821, 44.27603613945746, 47.438152913124334, 45.839963574563306, 33.99385652234478, 30.530193813385505, 47.39730142777967, 63.55267340137113, 66.27846963943975, 68.79322667275706, 52.564914303441206, 61.143534029683764, 61.337177522720836, 61.59620300416024, 65.25181670342722, 62.48359218720467, 58.81946694466376, 54.92255295476606, 51.476240850264034, 35.61509370803833, 41.029964954622336, 36.75110624682519, 36.5507358889426, 34.06590261766988, 53.38339136492822, 80.32553626644997, 101.87202561286189, 86.09916317847468, 82.10875557314965, 92.05420755570935, 90.14710410948723, 76.0340867503997, 39.912701345259144, 2.021898473462751, 0.2987913895518549, 0.06524203179944908, 0.10120250540034426, 0.018198139019190304, 0.07726344520286207, 0.044988846601617914, 0.0505096132626697, 0.07702823322747024, 0.03318587167849464, 0.07798404282619877, 0.043020996550518664, 0.0496231614341659, 0.04177501965915004, 0.0714495962846183, 0.01118763203492328, 0.04199214046820999, 0.037491718652628125, 0.040028668609597993, 0.04483393596244916, 0.039924902000254205, 0.03980890096675965, 0.03745789587077114, 0.042904447764158256, 0.07010281371373324, 0.039752765874108004, 0.021813574149423552, 0.04902068307743438, 0.024446708360506643, 0.007703522090694958, 0.10336884883262458, 0.02437650023268596, 0.1401833342688699, 0.06737385530986133, 0.08037833572034875, 0.04723986573216896, 0.039754106527975494, 0.0276489329013613, 0.0418051882016082, 0.01437057318511389, 0.04968415735469711, 0.09263230277405632, 0.029424077365547422, 0.08397275131315955, 0.06163723188482466, 0.051382202730183645, 0.039005450934412024, 0.023411629729033, 0.0032860862707058272, 0.07926642038528958, 0.04109609721889419, 0.16294657973752869, 0.12028838327575116, 0.14728910620174102, 0.17896886434285872, 0.23194896177418772, 0.24993296772722276, 0.11180631140427244, 0.0702945578603014, 0.1803508869582607, 0.14650279355625953, 0.12655984715468463, 0.13194039674295535, 0.16328454708620427, 0.07646920354736429, 0.12952352723767682, 0.14325458075731032, 0.1850317148191314, 0.22457113669764614, 0.20550222766976203, 0.20743808588914334, 0.21827620754559196, 0.2736356055303928, 0.21332536433492938, 0.3367502494685112, 0.132341627632418, 0.15963651299957307, 0.12486945116712202, 0.2102896336826586, 0.3099897257503002, 0.0884516767015861, 0.13735585695793553, 0.09970980606252149, 0.17298862878834048, 0.18961721069870457, 0.0885999376975721, 0.11667781088861728, 0.17287619772457308, 0.24926104733059484, 0.2441527424079757, 0.06826545141877667, 0.19040370720528788, 0.08215536859126822, 0.24231240003099366, 0.12253132017870104, 0.23421423780100964, 0.07970507466985334, 0.1178842155082572, 0.1546838618214092, 0.19377067895425906, 0.31527092139567103, 0.47624358366574016, 27.910603592472693, 98.77384739537393, 114.39243516614361, 107.00918520650556, 89.85887265974476, 96.33731811277329, 88.59587730899935, 60.7099905321675, 55.98473471979941, 42.62812683659215, 50.14591017077046, 50.8335957988616, 69.1820590726791, 94.63762175652289, 108.41542551594397, 162.77826801423106, 79.36757579926523, 77.53104363718342, 102.71014982654204, 57.43710210246425, 59.39156816851709, 59.36884980047903, 62.667088508605964, 52.084729902205936, 58.652958408478774, 62.81295361057405, 76.3929130185035, 79.2559608336418, 111.59496938028644, 105.32307594053208, 68.56059874257734, 61.16880978307417, 47.092768607601045, 45.534301111775065, 43.84450874020977, 51.17652862302719, 49.74161186525899, 57.32874662645402, 73.22012347559776, 71.73091719227453, 69.77313672342609, 68.78352272895076, 66.01767909142279, 73.02286747963198, 70.272980043965, 53.088315379235056, 53.4078630324333, 66.8391175423899, 81.07822341303672, 79.45520154891476, 87.37540045092183, 72.56694686028266, 89.00627490012877, 89.92622760034378, 90.28764263276132, 93.6865411266204, 92.09324298366424, 86.3214203619188, 111.50465288469869, 111.30156040191652, 73.21431052300238, 87.58030506872362, 78.50832569983699, 64.5036010588369, 41.13013444408294, 51.55603754904963, 81.12196568519839, 92.36442781263783, 82.69675024094121, 88.91299309269075, 102.5099128292453, 102.51579638450377, 84.97402344980549, 38.597785580542784, 1.1460626317608742, 0.5095152418699957, 0.22727289898020608, 0.24911369797923874, 0.15390583824726844, 0.18827648022242133, 0.12705935946395322, 0.0970999743308752, 0.2137385768395278, 0.19418985162290836, 0.20181564403878105, 0.13476626526924873, 0.2043360886314223, 0.1804967654208022, 0.18674039732544653, 0.1693866978729925, 0.11446783108816994, 0.14257875331226857, 0.19032388084357788, 0.15078081238654353, 0.09001538472911043, 0.20833054767741313, 0.11358194999516973, 0.14694842690181348, 0.15632935739572973, 0.14136998914182186, 0.13081743442002805, 0.12967392561897156, 0.2035023244999109, 0.26096662566546475, 0.2502647910507456, 0.11295855360766573, 0.26748943533147534, 0.12013323514932588, 0.1780520716021138, 0.10250240339026337, 0.11345710830702899, 0.07475721154121623, 0.12429532955490774, 0.18522277714744692, 0.13810490708678, 0.11642534661317065, 0.14912590925251284, 0.12067401661507546, 0.16404041539757483, 0.24193356955243697, 0.12273626402020456, 0.13521882404963817, 0.1456211489294806, 0.1888250451414816, 0.1619255071085307, 0.27428104992835756], [0.021326112403203885, 0.016517753885578246, 0.04168203956778011, 0.020352031607481263, 0.027289141622942784, 0.06250962983035753, 0.07023495621979237, 0.03504673372052851, 0.020273729760740555, 0.06147414325706421, 0.03040975864766346, 0.049974389764810764, 0.038384057866830024, 0.012447820814897217, 0.016610764620465138, 0.049151358525118524, 0.08791392894401666, 0.052878908707850406, 0.05388520350078902, 0.04137850787130095, 0.09678237726010623, 0.03865984568913137, 0.03504772963483007, 0.05300776086627476, 0.01922548782350796, 0.0794754474754295, 0.010442657493835977, 0.012954130239273994, 0.03330707061855543, 0.02739349428954865, 0.0303454608881786, 0.028155274884474855, 0.025241074505292123, 0.03428066111800652, 0.05826866284253136, 0.020134717361220432, 0.07167440478599842, 0.09951526569502969, 0.030850941022377343, 0.05850229667679918, 0.05723277024263817, 0.036613023464357665, 0.034280496409102794, 0.036583303083335204, 0.0844277998793029, 0.061868226546193325, 0.10388876206331676, 0.26766364372545676, 3.150425659072015, 33.08914223024922, 76.0966956230902, 80.12145534638437, 80.48241538386192, 70.11839943547403, 69.55437044943534, 63.70974079255135, 34.17880412070982, 30.00737717074733, 30.47361166246476, 34.11751316439721, 37.97000631209343, 60.10062679167717, 68.715422538019, 52.78564568488829, 50.33215999603272, 52.760491524973226, 43.45572733109997, 35.60399732282085, 28.68964710543233, 27.433488445897257, 23.3555394218814, 21.53313563716027, 14.142002694068418, 5.94507126077529, 4.668836930105764, 7.2798553013032485, 4.76731832950346, 13.08946897906642, 24.17930187717561, 13.180998467629957, 8.429051906831804, 3.247872288188627, 2.400507950975049, 1.730820976438061, 1.3870153023350624, 1.6864411965493233, 1.4363094443275084, 3.009894980538276, 4.353291075075827, 4.820682665994091, 5.895859733704598, 6.787670898822046, 6.67999497344417, 4.978657595572933, 4.82257422900969, 5.303715198270736, 1.5022747627189084, 3.800760272049135, 14.547694421583607, 41.25186520238077, 36.388185024261475, 21.49221747152267, 16.756379104429676, 18.13341344556501, 27.222186442344423, 32.44716790414626, 42.59291964192545, 39.07947617192423, 59.08476821837887, 50.6793446694651, 64.96534639789213, 43.82658743089245, 137.55057150317776, 90.59894546385735, 27.54948469900316, 23.106059028256325, 14.50991415208386, 28.941500533011656, 38.71211090395528, 55.268466780262614, 62.81988051629836, 65.29643366413733, 72.54961782886137, 83.27998315134357, 46.39017012811477, 14.995110361806809, 0.6916086724208248, 0.8226069495562585, 0.042843176051974304, 0.054394311061309236, 0.0244890634466203, 0.06235359687237971, 0.09574102628375254, 0.025367852480661486, 0.03949907585798253, 0.008287883904432098, 0.027930960509805914, 0.026365467497418006, 0.03276931520010675, 0.09789290597602245, 0.08791667919966482, 0.050046647177828904, 0.07731894061209695, 0.049607920114912336, 0.03181105412002052, 0.019617052598586007, 0.047011448956665494, 0.07755534768465065, 0.04510657516338172, 0.031998904624713526, 0.023591482275796515, 0.05064870418620206, 0.02687362510891211, 0.01604475109131947, 0.13901413087883305, 0.012537685801245034, 0.09511124838383929, 0.05987222659431639, 0.08686601259415189, 0.03179691596737793, 0.05838614625615939, 0.07232363365830914, 0.05245402485372559, 0.052166960217178836, 0.025214454865143187, 0.04117377087353699, 0.0645496262117259, 0.03846429408557954, 0.05196792674401114, 0.006946711012372568, 0.09107951916033223, 0.04287992912014166, 0.07049688934198312, 0.01720389478930062, 0.052043677517964, 0.01857267940537103, 0.021865892208992474, 0.05926080799150852, 0.029927782090981642, 0.06147485571883379, 0.04940793669271854, 0.023949222353797768, 0.04282070669315515, 0.04965375898586166, 0.03124946379102767, 0.08465701338624762, 0.0392695214419115, 0.061894281196498105, 0.022476240203926162, 0.08797719248480375, 0.024600632661472888, 0.022784079229759596, 0.041643382771120924, 0.03193752182978055, 0.03639695985663322, 0.019022064666534146, 0.06373840421738644, 0.0459995923653966, 0.01896884645365419, 0.04635242948068246, 0.05152569865928062, 0.11908056139345131, 0.03009354436559783, 0.04743036115542055, 0.05659177681551345, 0.03744245919909689, 0.07130290576887709, 0.03686140066072826, 0.09043972849124864, 0.035346913782338944, 0.03494543008386128, 0.014315814177896229, 0.04848429512593055, 0.06087731096833464, 0.013265294086698805, 0.03850891104628963, 0.05330100783237046, 0.039102449156944795, 0.048712397805385055, 0.06372757556457674, 0.10311914247370536, 0.08212276388921085, 0.1203410824640624, 0.25707253945931313, 8.03343870947438, 57.2158412010439, 93.47807499670213, 92.68608570098878, 101.62828953035417, 94.82777041773643, 95.8590478281821, 82.53073984576811, 55.37227230687296, 36.385094196565696, 28.43878995987677, 19.586675128629132, 25.237512242409494, 40.80571912950085, 53.497077342002626, 55.764481867513354, 53.78246899574034, 57.5485287943194, 43.33633822779502, 35.597807822688935, 26.83890811858639, 24.264183928889615, 18.090012419608332, 16.32391327811826, 11.244708664955633, 3.9596415142859187, 2.809835715639976, 4.16809146442721, 2.6219975756060694, 8.119092487519788, 14.965369970567766, 6.786162747490791, 6.057560914947141, 2.4915459175263686, 1.1251577470571765, 1.4137620671141533, 0.9781436357767352, 1.4441228057107618, 1.8016050491602191, 1.993602862761867, 2.391285723255527, 2.73135962986177, 3.6127708756154586, 3.304661098987826, 3.958757755256469, 2.0436880977884417, 2.154641286019356, 3.136990070343018, 0.7234729658211432, 1.0723627671118707, 5.869414623706572, 28.481896808070523, 26.689618787457867, 15.894408841286937, 13.063760784364517, 14.643993512276682, 23.384725778333603, 31.02173543745472, 40.268224977677875, 40.24795024625717, 64.6390954140694, 55.848518648455226, 57.014039178048414, 35.37034565402616, 114.39576918079008, 73.90754238251718, 20.075245557292817, 18.034342219752652, 23.01500120470601, 44.609414069883286, 63.56702143146146, 85.56612091679727, 85.2529824164606, 81.2546516233875, 83.23951213590561, 100.13861256261026, 67.81910604046237, 31.09897278970288, 3.2912360516286667, 0.35267274346082444, 0.08699797889998845, 0.014803549800548824, 0.03667007403207883, 0.08454249856332618, 0.01994251164667789, 0.02679356700560499, 0.04686935496846995, 0.02597513803911786, 0.11157310657924223, 0.0784486981349126, 0.03392474432926505, 0.02702341636552686, 0.023903877609559608, 0.06722745590753133, 0.17116938447279317, 0.028486232528643265, 0.056694478562642495, 0.07196185629694693, 0.05652275612397541, 0.03973673931473205, 0.01604994133700647, 0.011467726228968992, 0.03999185042395707, 0.0038573692877581648, 0.09340643462154175, 0.05394577424252226, 0.08343807556816647, 0.028187722538507758, 0.0238138527023576, 0.008028556917598772, 0.04748461550221809, 0.034858513578412034, 0.02416770871458275, 0.05021550061721956, 0.01573448452437597, 0.03374375222671417, 0.027492934417340065, 0.06230776949274925, 0.026194424961783716, 0.05274290511865289, 0.03741185015608226, 0.04162026606800576, 0.017329833898392898, 0.08876340553885506, 0.05664126609542197, 0.10125826127947339, 0.02746287695763092, 0.026092037310703628, 0.13569605086118947, 0.16525065045683615, 0.18180844584299674, 0.22167242853151214, 0.13536493233855695, 0.1932336972846139, 0.08471387243198772, 0.09797000506472203, 0.1448997086094272, 0.2802030015135965, 0.2788193547917951, 0.16109191151636262, 0.16039685526442143, 0.11402108691512577, 0.08170696966830762, 0.15880909207607471, 0.18689016751464338, 0.16773061496355843, 0.11517818611595901, 0.08804981762002553, 0.163564873979457, 0.1381687834979065, 0.18732587236069864, 0.13782810419797897, 0.16090097176211496, 0.2020283253683198, 0.12985444657744902, 0.1334679913857291, 0.19394859521379396, 0.11591604370022975, 0.12105435628684298, 0.1185161844196339, 0.10255134108686641, 0.09880557716373475, 0.17293276565690197, 0.06902048469430978, 0.2223593489296975, 0.14015334958751358, 0.14834949446301307, 0.20137169608666053, 0.3136356301125019, 0.10722945699648512, 0.14938018915634002, 0.14519443795565637, 0.2525088617638234, 0.28958733343789655, 0.1908203211402701, 0.33290304784332553, 6.142550831840885, 56.00378174935618, 105.40073886994394, 101.12956800768453, 102.46302481620543, 93.1700591118105, 89.53325317751977, 78.33522365939233, 46.45146500679755, 43.470302858660304, 43.35891539050687, 49.52595603081488, 52.1937600258858, 83.95983188383042, 96.6305309726346, 76.29839958683138, 72.03318288249355, 73.54528011814241, 65.27488808478078, 53.78579516564646, 44.033335562675234, 44.50573798148863, 40.41947549389255, 35.490530998476096, 23.706734718814975, 10.658568297663043, 9.311039005556415, 12.198911501515298, 9.178068695529815, 17.456888921799198, 31.223619830223825, 20.523141007269583, 14.561627661028217, 7.663482716006618, 6.3688838481903085, 4.405121274532811, 4.023798497453813, 3.540902512688791, 4.513800346082257, 6.855358260293161, 7.650595278509202, 9.222534644988276, 10.86392398803465, 10.965123099665488, 12.426375631363163, 9.775575110989234, 8.158395617238938, 9.889727850114147, 4.395107463482888, 7.33789804481691, 19.738923888052664, 51.18462047269268, 49.775238344746256, 33.80375492957331, 28.106865267599787, 31.882666272501794, 43.02185043211907, 48.22143454705515, 61.57308455436461, 63.20841089371712, 87.4539969044347, 77.58236392851799, 87.5833252937563, 66.53676556002709, 150.84790845071117, 112.12054344915576, 46.829495199265025, 37.049551548496375, 25.780789929051554, 41.423453207938906, 58.29475971960253, 77.86072669490692, 84.53575349623158, 86.5451680460284, 91.8848317669284, 109.5665313351539, 70.73830650698754, 27.774652281115134, 2.0878386641702344, 1.120182955938001, 0.18340376265827688, 0.1735714378376161, 0.11305602297427193, 0.17933825661818828, 0.18186227118055667, 0.09729923379998054, 0.13544135726988316, 0.13211756223632445, 0.258274715273611, 0.1230744228908612, 0.19238772171158947, 0.14649032164485226, 0.15042588385122438, 0.1711139809941092, 0.21134810672411997, 0.2096257878527526, 0.2281397734318049, 0.1544634889691107, 0.13994408501011713, 0.13554505493131377, 0.10811431919254604, 0.11904142196139983, 0.17750355264832898, 0.11091969486686493, 0.26066708528707105, 0.17029435884568, 0.3018706646417418, 0.12795175996518907, 0.20167629264535444, 0.1356854482043174, 0.1463772164237115, 0.14888986224128356, 0.12705154536712554, 0.10193314643636828, 0.24984456118076082, 0.1809145744529463, 0.07757607036300244, 0.1576373759176462, 0.1309529247303163, 0.12254881762689161, 0.12135210401949384, 0.1488113382290448, 0.27968083598440696, 0.17272054398011777, 0.10735096620215524, 0.15039649671844899, 0.11279855614467976, 0.11478544348069739], [0.04121559544376308, 0.03551089490253118, 0.030849801466589978, 0.05651223390633541, 0.045554782564361254, 0.004378507062116819, 0.07855110876863042, 0.02459176519374934, 0.023947764871521823, 0.07407347040791666, 0.029553724340193217, 0.04604407909115957, 0.011425912192451858, 0.06950187902416914, 0.020835253057040034, 0.03605950195642729, 0.07084742053261689, 0.013407097919093025, 0.05585339063057496, 0.007910074716839459, 0.05737030217724462, 0.06528356142582432, 0.013724086907572083, 0.07195381237374199, 0.06055858391787737, 0.032049550697387706, 0.11785826811026182, 0.0326195411804703, 0.03564386478354854, 0.03064795453552037, 0.041734907295434706, 0.04123495448560965, 0.09695644775826125, 0.042535388737075755, 0.05428653015124221, 0.06371945503257936, 0.04512156367362027, 0.049770116250241, 0.029165760178359288, 0.09674847786945683, 0.008872172461011478, 0.03797306318677241, 0.09630436137799295, 0.005789668789328707, 0.05674367672913978, 0.2017833304501349, 4.112431805941367, 19.76928303318639, 53.80480689387168, 90.59009659674861, 88.67808234307074, 82.31414656485282, 66.31102531186997, 61.55255879125288, 34.11848983457012, 40.7299820838436, 34.43048300281648, 48.378317586837284, 56.275162696838386, 77.93709524216192, 74.19746829617408, 60.73014367011286, 47.30178779171359, 44.19431747928743, 33.86934480359478, 18.619359808583415, 19.980592881479573, 12.577314319149142, 7.3326165733798865, 2.084924833428475, 0.9748259234812953, 0.5712407538967749, 0.16687667207612147, 0.013220243328701586, 0.19399771677149882, 0.3418914961718744, 0.22974629045253803, 0.6263468678920501, 1.0027827394585456, 0.2008274212599762, 0.17176535491260791, 0.14135549475829448, 0.028559708021461006, 0.22122331714678198, 0.04119865340931762, 0.2468091829289352, 0.04130675224587321, 0.11867369209686596, 0.2236047321029248, 0.13048564174002217, 0.08067572339167518, 0.099058439804902, 0.06422571657646088, 0.022233166251211398, 0.03549665715845843, 0.06769565820333458, 0.12109530368639577, 0.17211818436701454, 0.6957770487473858, 0.7565820601678664, 0.5868569352934437, 0.24633776306384997, 0.46758783200094783, 1.0455619471688424, 1.9144831405531977, 5.724914016262178, 8.408561445051625, 10.895928567455663, 16.253086059324204, 24.65101395883868, 39.838819580693404, 58.68468253843246, 37.526025387548636, 33.94576434166201, 53.82807439373386, 64.55653736668249, 44.718397125121086, 42.56180740171864, 24.897407447138143, 26.13960639122994, 40.60497222408172, 64.78784738048431, 58.34477386166973, 71.2559966118105, 78.5625171661377, 83.39275129379766, 56.42319686951176, 10.879453632139391, 0.49151588351495806, 0.21954403709500067, 0.041654073528104255, 0.03004027252656318, 0.05026733412617638, 0.02637981440901997, 0.02064955525941426, 0.03034296727198507, 0.043582381950991775, 0.026863755981227564, 0.046555718572269526, 0.02646995422941062, 0.03913074078398847, 0.06027934869991676, 0.029025895506023403, 0.09200170516006409, 0.057143980652214064, 0.06258379480230712, 0.029022557277893348, 0.04120343379796513, 0.024963833031154452, 0.02655444032092008, 0.025594409577728763, 0.03220510676563267, 0.05650111414011448, 0.0681824840965771, 0.050143951835531386, 0.04946098445103534, 0.09104830107741779, 0.029636938725748373, 0.08919138055775436, 0.0765568669885397, 0.035525630603754715, 0.057355459223711686, 0.0729490984832087, 0.06134073670593001, 0.03950007943316333, 0.054595654289568626, 0.04220969794738678, 0.09456167988959821, 0.024872486622283058, 0.03911680947508543, 0.05542763343621647, 0.023178269771198114, 0.05219305700231945, 0.02998187555931509, 0.02487423713319004, 0.051350084493958184, 0.06902187897433197, 0.024570960160945694, 0.028012257760330558, 0.04589090364113931, 0.01750568555097186, 0.025396500338589954, 0.07590004618489936, 0.0626409717745358, 0.05503114846144473, 0.044580579194570744, 0.02148471175572805, 0.032429279414035624, 0.020649991929531097, 0.008272585128584217, 0.024818647878184438, 0.02385954793182112, 0.05975359021836232, 0.014468932171322167, 0.06978199141280306, 0.04789074935439614, 0.04168707659588226, 0.0446865406458176, 0.013543590846952173, 0.10616592011384426, 0.08110337665364628, 0.04997529374856142, 0.003909534608547186, 0.08717965665123156, 0.0523773892482202, 0.019263206162459908, 0.035116401756362575, 0.06449835960783305, 0.0324846675709611, 0.04535175011222882, 0.022332631276860353, 0.06809774711127244, 0.010289085593314902, 0.02460454354032634, 0.009092644904740155, 0.03615362351880439, 0.04773876134065851, 0.009274362875599294, 0.17119897078842888, 0.14472292616002022, 0.026091041396402066, 0.15467954108551626, 11.594490928034629, 41.24020791822865, 77.07644877895233, 107.74962671341436, 105.31303467289095, 101.39661081375615, 91.5321949989565, 87.09057361848893, 53.73621248429822, 56.84646375717656, 31.443043101218443, 23.61096024513245, 25.667017659833355, 43.93072243659727, 49.39668647704586, 58.71593990633565, 52.99955606460572, 45.631089518147135, 28.18742878975407, 13.118547470338884, 13.27727794647217, 5.7371655394954075, 3.7219745641754525, 0.5689325003374008, 0.18820049962209118, 0.3662956560090665, 0.3345258059280534, 0.07042315337927112, 0.12766983960905384, 0.2827230324187587, 0.24115179214746724, 0.5870496830151928, 0.8919554960823829, 0.13353978914599265, 0.14359515280492846, 0.3284588492205066, 0.08217995235275838, 0.19255336524257738, 0.08641923011671152, 0.2759942676751845, 0.533612598815272, 0.2658049305600505, 0.10474876470623479, 0.2506244386876783, 0.11383467474051061, 0.15457631839859873, 0.07832301375005515, 0.10026282195242182, 0.15907127800728046, 0.03255713565815841, 0.11716441461636175, 0.06744461885142712, 0.5581429792988686, 1.104618991094251, 0.8905104703960881, 0.5982943215677815, 0.3804505706554459, 0.05688447219830367, 0.7262353563020307, 1.725303672494427, 2.366127395822156, 5.952745868313698, 10.991694215805301, 21.790658850823682, 37.71104358857678, 60.659850874254786, 42.2293080822114, 39.72181920082339, 48.125175660656346, 49.40223270846952, 29.311717364095873, 26.490713434834635, 28.171562802407053, 43.72160127086025, 61.98475691580004, 90.26200602131506, 87.48513267886254, 93.28314888861873, 93.67967697881883, 97.87970389089277, 81.51588147686374, 27.611544439869544, 2.4376307331746627, 0.15963380104832112, 0.02666219633312956, 0.16711316341834684, 0.03210748609666142, 0.04643460007144078, 0.03253366655459808, 0.03488037389733138, 0.08064856557475944, 0.022330601143861012, 0.06536053794045603, 0.060242756510213505, 0.0030584573687519882, 0.031116626060177243, 0.07262533440464929, 0.029377413034859686, 0.05470453836624661, 0.012178103281785885, 0.061840252845638224, 0.030134993552741025, 0.003924533173689739, 0.0053782934593337205, 0.0633313931945351, 0.048869158546890945, 0.10954765437711632, 0.017943707812998085, 0.01520037089639734, 0.050880752218466614, 0.052901492979858196, 0.04690274491064972, 0.06002224193164899, 0.03836238906989175, 0.013900859780879992, 0.04757721254962587, 0.03229636315917296, 0.01862831845609171, 0.02606745737965309, 0.0938832630673724, 0.06248905270871136, 0.013762204569854565, 0.01407617038386243, 0.05066516741569485, 0.059957335132264325, 0.060498963125170245, 0.06850830129077358, 0.055814159267972556, 0.006278310789756718, 0.029352407925011172, 0.23126643872068775, 0.15007409627639479, 0.1171833599707292, 0.11848703477411501, 0.16695881202336282, 0.09882995408148536, 0.16842617683352964, 0.14430288015113724, 0.18529751668533972, 0.21160609449350068, 0.20311879024149912, 0.12433241587132217, 0.12482117996701311, 0.13128974294710544, 0.14471897314633095, 0.10780930894637301, 0.2553891991415332, 0.10402360885974862, 0.16603688649352522, 0.11099531540587065, 0.1637003949332622, 0.12325975488150313, 0.09538301807497779, 0.14537204778002155, 0.21612849537163012, 0.11768787483414335, 0.11227868887926302, 0.14070698600863257, 0.30005905056192034, 0.09890382794002373, 0.2119033366081215, 0.12364211702539075, 0.16800738720884248, 0.14258763993219023, 0.11400077026337387, 0.26810377655971435, 0.09742838856313499, 0.12696308519450888, 0.13550713357906188, 0.22477906828205432, 0.09911160630684707, 0.20952573676984157, 0.24613505619908535, 0.17957326174984056, 0.22504488547002116, 0.19091274198745528, 8.36502117495383, 40.373536694434385, 84.6848741654427, 119.28727857528196, 107.45868098351264, 103.47294884343302, 86.27397537231447, 76.175017510691, 46.094623458000925, 55.98582121633715, 48.89400728287236, 64.10466855572116, 73.36756537037512, 103.82190642818328, 102.24836134141492, 86.43615753419938, 68.00112755067887, 67.00122910161173, 48.660630179989724, 28.442345588437973, 27.657740154573997, 18.993726507309947, 12.071004971381157, 3.8948549907053676, 1.895398971053862, 1.3892938316829744, 0.6221582055572541, 0.425312189205039, 0.3834697844520692, 0.6248845592621834, 0.8800477931095708, 1.058783153853109, 1.3950473358554225, 0.6787764545409911, 0.4386175429869083, 0.4356410156094259, 0.22752936989549669, 0.45896468503821286, 0.20372773821075119, 0.5312358876389842, 0.58149058131441, 0.30548892855163545, 0.4956387235752998, 0.480280070295257, 0.26106741219278307, 0.2957083146658636, 0.20530584869125199, 0.17095690232611474, 0.3692142671394733, 0.1840806779481711, 0.1976111543274695, 0.3797407748718416, 1.009186499061123, 1.314325570579498, 1.0324157558141216, 1.1458440821978355, 1.2286416393133903, 2.9933871953718127, 4.191004480085065, 8.39381725557389, 12.466743684584095, 15.6238829705023, 24.384730131395404, 41.00844683185701, 64.73972382084017, 87.05348368613951, 58.48137040292063, 51.77645514088293, 74.53684745296356, 88.57895620407598, 64.23825663904991, 62.32991372385333, 36.756546574254195, 38.398199696694654, 56.51494503021241, 84.77213121229603, 81.01701090412756, 94.0912042125579, 102.06991703279557, 109.54440132264169, 86.03261624613117, 23.7918834917007, 1.253931120999398, 0.2494742649216806, 0.10835523852297377, 0.22368699462423403, 0.14780310523365775, 0.1676736027002335, 0.14056879906885086, 0.14799047501817827, 0.22055254588204048, 0.10381922426242983, 0.19838758443872775, 0.178029487330106, 0.178731668199743, 0.10964700065913702, 0.17205781663858122, 0.1920147135012573, 0.1843047893095401, 0.15011448443176287, 0.12315660114249877, 0.1319393855068953, 0.09754227519395853, 0.17484148904200525, 0.19499076590422662, 0.1473437589142592, 0.19731346788185258, 0.2027071099127493, 0.1401802545954143, 0.11528952933487394, 0.12890385403748483, 0.21093276449509207, 0.20184953576855122, 0.18160880332992924, 0.19193917723192325, 0.1336493243974063, 0.1517871148403614, 0.15625855554976772, 0.2345685075007139, 0.16536960858971844, 0.18024459991964603, 0.17044137111834942, 0.14218791057505917, 0.18502618366431806, 0.10475824121385814, 0.14518147574797755, 0.2434346881965476, 0.13471161255673056, 0.06545285153533183, 0.1866348304094807], [0.1099477437955718, 0.035118592767826015, 0.014267878141254188, 0.03930915883111377, 0.032660745219477726, 0.047756768237318725, 0.03352909439033078, 0.09173283128127938, 0.06355789091978824, 0.006613678227539265, 0.007850270541835456, 0.1301122351639694, 0.01702835340233099, 0.0812884558352732, 0.044560005903364196, 0.014781366767091377, 0.04535681778384794, 0.015367066840671245, 0.08249355810544184, 0.07270713727320395, 0.03767278353353182, 0.050315241434521256, 0.09049569121411732, 0.022118908067744587, 0.024953224628622976, 0.038731045900814, 0.02113394116261794, 0.05803613600531413, 0.01638801689560135, 0.0702299153612506, 0.02153799700130138, 0.0728507174719726, 0.03936491087980328, 0.040722223329207594, 0.07878948468714952, 0.03269258766405044, 0.04634363479131172, 0.01225724399480368, 0.05261877206184211, 0.06180019027763798, 0.03131366004386256, 0.09621312030621114, 0.036586034186785264, 0.1451236207879359, 2.083560338904781, 22.05043938852126, 64.72841562763338, 88.02583925185665, 79.68951609826858, 64.13367056077527, 58.23523382986746, 57.15109071423931, 41.87710277495846, 32.548272878892966, 31.64140912794298, 29.09085850561819, 60.24720184264645, 86.09159300404211, 66.02103664029029, 64.53806300317088, 53.01973273677211, 37.43937238570183, 23.026044637926166, 7.284980858525923, 1.4882457929272808, 0.3267253454654448, 0.07317543916043735, 0.19635052600454903, 0.17144205048680308, 0.031085528636110887, 0.07343229311969011, 0.013023537805213804, 0.1017158762401631, 0.0890192329402893, 0.1508899799157535, 0.32701691852942594, 0.11658564285044709, 0.20961936803594713, 0.7731956880419486, 0.35276292733127074, 0.42581753144341133, 0.2549297762133422, 0.035344584875049136, 0.19426995377627113, 0.08941506290988577, 0.16120538445970706, 0.26859698396536613, 0.3922269661580363, 0.39020725195446326, 0.3609042662766672, 0.1434799025375997, 0.30917273894433056, 0.34889923949395457, 0.18235815989394344, 0.05647858732470101, 0.11891124064042685, 0.15097155295793088, 0.23160641321972494, 0.6555257473261126, 0.32364030939436733, 0.236063236971536, 0.04101627851806341, 0.017592992761262485, 0.18541259841332514, 0.05925133531432479, 0.3362688704604103, 0.23311859417346217, 0.3165270910868722, 0.06430673037445353, 0.0856054915235408, 1.973814995538804, 8.519734163438121, 36.78167719994822, 50.02094345708048, 51.89016857454854, 49.52186107635499, 60.09898724094514, 67.48673223680066, 51.79722409094534, 34.983678402439246, 20.096028235650834, 31.109425906212103, 33.324970814489554, 46.22987462628273, 55.10963040013468, 70.79123497009277, 74.47057508653211, 83.93647809182444, 47.26008122967136, 8.667066231850656, 0.06271682980079805, 0.0914019349241449, 0.12233931556223862, 0.016330014463634263, 0.06854937126439425, 0.05618968790757561, 0.023844496219328815, 0.13009809318088716, 0.02224663790735987, 0.05888389656320215, 0.004514279867327142, 0.051275754813104875, 0.010422668344671688, 0.048860769884120074, 0.04926559755638723, 0.035367985030696276, 0.06513942964375019, 0.03449326966919246, 0.04689370890358283, 0.05270501440991798, 0.05146769431209372, 0.019529781777471788, 0.10287964040593756, 0.020601887353545716, 0.01693381623725497, 0.04674414938856517, 0.014639815743712169, 0.050289864772029465, 0.01195418056956823, 0.03447503677659458, 0.0707548771113638, 0.025473890540700768, 0.07131460393148084, 0.0733765755449572, 0.05105805177722247, 0.019469109529088584, 0.04673327094004039, 0.031613654329351364, 0.03198084984755805, 0.043759784931617404, 0.061526432588335976, 0.04127447313118366, 0.09074748133219059, 0.05945548242438705, 0.0514086289331317, 0.051597737737240336, 0.022506380018087167, 0.08179400491738513, 0.02879248958291306, 0.01916548015639907, 0.021759181906799638, 0.03366892075827045, 0.09162832922752827, 0.02810379760640283, 0.04275127231413799, 0.08102655335659943, 0.04175719279315203, 0.05885380845997603, 0.024423275646122716, 0.06342081863793635, 0.022514142403979937, 0.04577219448683243, 0.02957045187001988, 0.04344857320369732, 0.020024144060669408, 0.04929130363668646, 0.012446863204991866, 0.06510435813857664, 0.07596529389341032, 0.04879803877444037, 0.01110500179141039, 0.04336987299123599, 0.04430789019792311, 0.05131992744281889, 0.07641488025265356, 0.03883544836313494, 0.00783512641998729, 0.03402171956916009, 0.026799203497507883, 0.046006356921768, 0.061039449647068984, 0.009122492647880029, 0.060357865051276265, 0.09337069661987406, 0.06912915426636897, 0.07282971134108883, 0.054957175011476206, 0.19446447882200443, 0.0682987992261206, 0.0779586163679919, 7.304129379410898, 42.704154137642156, 84.25979906512846, 108.67160335663827, 101.62608515831732, 86.75853713866204, 83.50631175502654, 87.20262004483132, 62.85762548446656, 41.95182000437091, 27.3605578560983, 15.165229439735414, 24.886256148738248, 60.99082439176498, 61.24970866787819, 63.64901857991373, 58.881193284065496, 38.81669305985974, 18.19414350294298, 4.144581758206891, 0.5190215043483243, 0.28697690415766935, 0.43287019816137134, 0.23703733308901712, 0.25717568553743825, 0.019738000644851598, 0.050463031286433827, 0.03484778834747211, 0.13932379893958569, 0.07928399444227258, 0.22309496187635008, 0.42961729690432554, 0.18342277696055753, 0.22549297029693283, 0.5827410819549715, 0.3246508100100102, 0.5668503346462404, 0.24262752263776718, 0.23725255783046448, 0.4304659384633265, 0.17513863922607514, 0.25970843350214345, 0.19605182832287205, 0.5639374232099903, 0.28546041778979764, 0.7217878175358619, 0.26103918951365257, 0.20568852493118858, 0.5435605875907407, 0.23974787473918932, 0.16932642207511012, 0.20532090997984334, 0.16762677940630144, 0.2072214821894323, 0.605744802423062, 0.6685378426505674, 0.5147602168783065, 0.04640315982302831, 0.028645255144745595, 0.18238774620957915, 0.023302933343896465, 0.2168209009593533, 0.3141576730676236, 0.6360926707425426, 0.5811077212133716, 0.5746893752967158, 0.7464856341961892, 5.979976923235002, 35.94017190317954, 53.21119539199337, 55.53422304891772, 50.53447977189095, 55.652270701623735, 49.934549331665046, 29.81708730420759, 24.349644530204035, 23.65061736875965, 51.34648100022347, 54.61675320902179, 71.57161405009609, 82.18689703172254, 89.11189648412889, 83.75948506016886, 102.07627127247473, 71.10470294952393, 21.378500115486887, 0.42689330275020293, 0.27795634142333464, 0.11876271151366735, 0.017138572387217034, 0.04912971271081798, 0.04826762630874592, 0.05500383359650451, 0.12883090714533485, 0.10679516941308977, 0.040661242730434866, 0.09395856184944992, 0.04028065024965233, 0.06129535748773526, 0.01783025785229139, 0.032074128713218436, 0.010627050069160761, 0.10442301645995149, 0.058442273687931805, 0.021238985223575466, 0.011166593345302728, 0.044051469078347574, 0.0698450174663336, 0.050596617868230234, 0.015568449330936759, 0.015783972846674585, 0.009227923583239317, 0.03225186111165151, 0.007820054118882024, 0.027454342738154437, 0.045213865777177197, 0.06087914191847367, 0.007045639776474526, 0.04493769491091371, 0.07663922144039985, 0.029677978055852077, 0.054756954102025884, 0.004020737777013452, 0.008164784108709184, 0.04949065886678235, 0.016324339667335153, 0.02464936351433637, 0.050265913033076835, 0.03328564696975293, 0.03167050954465184, 0.015154075245523166, 0.007459581979820806, 0.19961176229821098, 0.11069585929714865, 0.18547751670402868, 0.11895526771343524, 0.131073568256632, 0.11101936290581381, 0.14068628631291852, 0.1490699541905234, 0.12915937500374933, 0.1466182430064486, 0.1358097383091527, 0.19286527028006895, 0.08131337667545004, 0.18570040232471882, 0.13472961562295116, 0.10766081046313049, 0.1770862645559734, 0.1187933090653631, 0.08669379602877364, 0.21507685583445335, 0.11246887020646565, 0.12886591736347447, 0.209242605994786, 0.1439285695913338, 0.12569188485823332, 0.1025890862388957, 0.07422728554135369, 0.14874828919287653, 0.11698843655927528, 0.1326922507536027, 0.1346603765963547, 0.12412295977194464, 0.10181639463670793, 0.13788445762568904, 0.2204622394375263, 0.1018111086300304, 0.1341237473271547, 0.15107613928135366, 0.22370512026452252, 0.28729195015565046, 0.13236444173080306, 0.33113497820112014, 0.2358020622763903, 0.2500930647816389, 5.220841400084957, 41.82950089054723, 95.58628620639925, 120.160045162324, 104.44892867918938, 85.96646155080488, 78.6250005229827, 75.05562013195407, 57.642673523195334, 42.047008083712676, 45.682970708416356, 39.99328644044938, 79.0800895998555, 109.3651411610265, 92.23329513303696, 91.05590943367251, 77.72996271810224, 59.23359470982706, 35.308544789591146, 12.11687610995385, 2.536497260293653, 0.9536924994280263, 0.6794101624719558, 0.40700661018490797, 0.4659649206986351, 0.13605160758860652, 0.11635336499180525, 0.12129769645511143, 0.4517961245390677, 0.20431731947727744, 0.4793674144293032, 1.0573592109064902, 0.4568155939059873, 0.4726626742030344, 1.4574522452969707, 0.9023505124834277, 0.8529855226797443, 1.157148598182586, 0.6612605589532083, 1.1046724333878488, 0.7524661455423601, 0.8145321376862065, 2.057436372964613, 2.1518024706071426, 1.0172333640436972, 0.864768935547721, 0.6832095295671494, 1.0925666507213347, 1.0338914250173876, 0.7720693549321545, 0.3694827349916581, 0.6342036817823687, 0.47186174459995767, 0.6778138190988572, 0.9558015701270873, 0.7460584022825765, 0.5369626706646335, 0.24313988224152597, 0.13187000858447245, 0.42842060627956546, 0.1775538846249542, 0.6760353919479155, 0.6147701149025272, 0.8333914450580074, 0.9161532718327738, 1.4874312882461858, 3.844116435896966, 15.573215753801408, 58.83886306516586, 75.8672369680097, 75.50597883039906, 70.84809364811068, 89.4673102901828, 97.39781718100272, 72.20622216501545, 50.22819365224531, 34.075088808613444, 45.758829347548954, 47.16763488708004, 65.14811315844136, 75.51773809617566, 90.25244328283495, 91.95500296931114, 113.94657934865644, 76.42382129546135, 18.5721246657833, 0.26203856653263496, 0.4260705856065597, 0.22242722431978873, 0.12031980820240513, 0.12466245420998144, 0.0944253009173178, 0.1946709548393565, 0.25598403577122, 0.14621187932789326, 0.10391198218830171, 0.1592340257259146, 0.18299067272774636, 0.18018677560312135, 0.1606387858309092, 0.1079053993547155, 0.13728145449872942, 0.203150337742221, 0.17978525360024747, 0.11596274442009388, 0.1793280063617614, 0.1284742089469106, 0.16429872492388373, 0.14936652214777085, 0.11469690669928828, 0.09214878638064669, 0.14547425923087906, 0.10741987581094427, 0.125044877640903, 0.057393445693437135, 0.09082378368944892, 0.16815947098357065, 0.12620481902793532, 0.18545732262634462, 0.16141327007883982, 0.1645739803150777, 0.15055199724531945, 0.11844650872292058, 0.1109218935392076, 0.14708013273775578, 0.11425345670431854, 0.18605864035987085, 0.1336178841489938, 0.14977167540740582, 0.11308195505050883, 0.1772403401593047, 0.09611420303342805], [0.05390419482043194, 0.03381339344947088, 0.011943415119012278, 0.04876213989430859, 0.06346778748857398, 0.02912457146111035, 0.11115594872183378, 0.03356020522093581, 0.03774221025166973, 0.033633757322545976, 0.06819441208555814, 0.03414912382140756, 0.04515746638419167, 0.050498757796782645, 0.028512947929782734, 0.03579158568754792, 0.03779109815255769, 0.041978588372829466, 0.042948256502108234, 0.02019803069772259, 0.03982268288851746, 0.042960398995708075, 0.05389948337969761, 0.03964347960126977, 0.0652531324134719, 0.07437567677228682, 0.10138732411207692, 0.007688357380233826, 0.028227179897047823, 0.08936683001417307, 0.025420375468750155, 0.145556858830875, 0.04979652330099095, 0.003272168128938985, 0.034056002003771645, 0.025880369132444746, 0.037525989595920815, 0.06495546895049273, 0.018736825234466986, 0.09285989217460157, 0.023475477411862344, 0.32275057487910797, 0.4237939868002169, 22.60368577895626, 66.08708150925176, 84.36447143554688, 82.81357411415347, 66.66812573709797, 56.40988042277675, 58.55828415962958, 44.3530361883102, 27.71721701468191, 37.94201235617361, 46.138197068245184, 64.40342764700613, 76.15942216688588, 87.42017038406865, 51.796439616910874, 36.51107680413031, 38.16735252257317, 14.31418493870766, 4.677470557151302, 0.12924382853652203, 0.08109635928825987, 0.07108570452058507, 0.07156870763508544, 0.1631204357310649, 0.13258700559456504, 0.18241348676383498, 0.11014259825911253, 0.06814339829068031, 0.05977259685976371, 0.07635027605799899, 0.05719065455900085, 0.033603703693276456, 0.05761034433699905, 0.1025611853166934, 0.24727995928016402, 0.24693275291112163, 0.0676466209153014, 0.1261377556910438, 0.08970900318555294, 0.12233543915734177, 0.018205028064849398, 0.06825307909879955, 0.33781072966033415, 0.5142056305081614, 0.5789892123110834, 0.08036734235863532, 0.7937389179583519, 0.30367366789329436, 0.035505015177712325, 0.06461091324566834, 0.008919785783115414, 0.5548591587331988, 0.07198741299010093, 0.016150740313253576, 0.09669708869149608, 0.12179636606766332, 0.21915782152885394, 0.13699692944365163, 0.1511755468504083, 0.08964092095172213, 0.15771707970528834, 0.03259732846110579, 0.22893497269720803, 0.1818764284853974, 0.14007520861923695, 0.10967836429875706, 0.14852935658587565, 0.055286883932328036, 0.022051030762433525, 0.14351347251044166, 7.211344732392219, 29.810978212664207, 37.39567325961205, 45.388949840299546, 44.00887566228067, 60.647695449090776, 67.3709281798332, 48.98665758871263, 25.1052636484946, 32.02573864690719, 35.541965038545676, 48.05674206825995, 47.54842642814883, 66.12249266716742, 71.65250901252993, 81.45703807953866, 76.0933380742227, 37.33227991288708, 3.649094965188734, 0.21141503216518512, 0.11961473152041437, 0.043165553511390765, 0.023436035375080766, 0.1322118370162864, 0.060863337524595766, 0.028187360561963533, 0.08352470479064411, 0.06781008109570512, 0.018894947697258285, 0.02750600387732829, 0.03440551812790575, 0.028735345169421167, 0.028789829342595996, 0.03888422518127388, 0.11854096736398437, 0.018825540131318475, 0.044347891478889415, 0.03225171172450627, 0.027813138102271387, 0.03135550568150657, 0.02479615745194737, 0.033147180407878854, 0.016615322843614607, 0.03894506788422023, 0.036604071726962444, 0.00866009729854282, 0.01659960463462818, 0.052723538415927085, 0.04021697685182576, 0.021378750304481196, 0.029447054257616404, 0.01261949728828885, 0.029972607810651104, 0.09717961683148339, 0.049754802152634635, 0.03518561396988169, 0.0701377243404427, 0.06542755531207209, 0.03202827452051063, 0.07330647849988553, 0.04079380275441274, 0.017856094167537747, 0.04764554376203207, 0.0604349909530532, 0.014658028526502031, 0.015915555150939092, 0.08451249089933212, 0.0651237708065779, 0.07388528090931716, 0.05736527281002172, 0.024967812857921087, 0.0723758502112281, 0.03575036249634239, 0.05498858844681133, 0.07132250229798018, 0.04073427389225653, 0.039410998729327996, 0.08939142909742172, 0.029326575440204436, 0.022558330355452436, 0.01627401535158917, 0.05597327189940599, 0.06794983085485236, 0.06239031546659047, 0.027963747157745307, 0.050913092620190115, 0.0517486417365651, 0.039877737797195875, 0.015387327951048652, 0.021403383861686436, 0.04177311210021858, 0.02868741870887818, 0.02668549115168712, 0.013681715542090037, 0.022960721868120378, 0.022048188576234445, 0.06518490462293548, 0.038233644163776795, 0.0272253226684106, 0.030954797647052237, 0.06538393426566355, 0.04636927958457701, 0.18396371164389197, 0.05137895068694508, 0.23040268990782, 3.362963454377267, 42.47417772969892, 88.22649202039166, 103.21335069594845, 100.96743291424167, 84.45146960596885, 79.51662586581323, 82.7046577392086, 72.7149143526631, 40.4406641375634, 34.5177008259681, 29.762123130982925, 31.98567555796716, 43.34932911780573, 73.09889085831182, 53.48974643215057, 36.2191818606469, 39.69493919803251, 11.340803792399745, 1.7888703389513878, 0.18906020349071873, 0.15050240071310153, 0.01314471759307649, 0.03966860345474655, 0.0463151554727266, 0.028117409073597485, 0.18005517701948845, 0.015338518574172932, 0.12449769168010644, 0.2433968740966051, 0.14215299228747047, 0.024547935388381445, 0.1352382673611564, 0.14178301778531846, 0.2788306316060405, 0.2980150360493891, 0.15639786097791888, 0.10083718871277186, 0.24333348798175014, 0.2202095836400986, 0.11686971591364954, 0.10213108823424387, 0.2401053466864171, 0.29744353445787586, 0.5897620019893492, 0.32193628470263175, 0.14224286972274705, 0.6461014562556822, 0.7148499414324762, 0.17542642781571036, 0.10751379052958182, 0.06287247971481373, 0.3219831692835977, 0.1461697751355748, 0.0610148620551392, 0.07528706859316557, 0.01973377375472938, 0.20134718127308354, 0.22442898142241666, 0.08908351537801566, 0.11775977218583708, 0.11206263676285745, 0.02635653874266052, 0.1602902311471201, 0.15934487864855798, 0.23122192901228708, 0.13269902297085331, 0.16708546167900487, 0.05472551002317379, 0.34010721610919126, 0.44345063848360894, 4.773552936892356, 28.49398163057143, 41.61643774278703, 49.49980951124623, 47.14972534487325, 52.988153734514796, 42.56671036443403, 28.787259209540586, 14.803490811778655, 31.665049252971528, 53.2364397664224, 72.29600521825975, 74.72857290698637, 93.94020080566408, 88.57075845041584, 94.99234522542646, 91.40216842774423, 57.78116849160964, 11.289563909653696, 0.1781224444388382, 0.070708628383375, 0.036679489252668236, 0.026176557876169685, 0.10030840418391651, 0.09253983596159567, 0.029745773006711277, 0.03533998068662421, 0.059840862954696344, 0.04091887809937039, 0.05621629797162549, 0.07715755652996802, 0.011686993041826833, 0.05790060356019005, 0.009687919162153717, 0.06133714375356513, 0.04743038413805827, 0.04683427197197753, 0.011699056053804535, 0.054427333281285344, 0.03348255454893074, 0.02995063640898274, 0.06010749219586292, 0.04468212414893412, 0.04311838547789282, 0.029164647435649272, 0.0555394439687652, 0.027709310205893654, 0.03520175161200666, 0.04514073885436501, 0.010233435051275358, 0.05346949354955747, 0.07416316398209141, 0.022226439999236215, 0.02388060768885959, 0.03794661783162625, 0.038770170011107004, 0.03454099694687513, 0.04562040948639474, 0.059429186456386125, 0.030670896953632756, 0.08688008562932092, 0.005660291860676221, 0.036397817875108415, 0.17393646341177726, 0.12415436171596089, 0.13813607154353974, 0.18063571844850818, 0.17080867963452495, 0.14121900853370467, 0.16770603886294752, 0.09212143704174988, 0.10295009751233364, 0.12006155996313018, 0.13605675569945766, 0.22729168345610942, 0.16472355132141422, 0.10351951534469282, 0.13232086664967, 0.116181684687974, 0.10859459503403596, 0.12363018903640971, 0.17361709667790323, 0.14043893184392683, 0.09523414420865237, 0.1122955964397519, 0.15865564466484133, 0.10189352436892449, 0.2509849749866032, 0.16525691705605677, 0.11846288002186245, 0.0968965013781863, 0.13422053487550828, 0.12013811512940353, 0.10716283032971044, 0.14488018868911653, 0.10454090973061901, 0.12696634106818708, 0.16441446548748404, 0.053040626038226395, 0.1288015659778349, 0.17111175933912878, 0.1964518947586898, 0.22230359305056835, 0.18037927817673455, 0.6814406019064688, 2.2581291006457422, 37.080734391366285, 98.80893691893547, 118.0467584056239, 108.73628324077977, 85.34285960658904, 78.8689641029604, 77.9692586775749, 60.006862532707956, 37.118008675113806, 50.55740602554814, 61.78030337056806, 82.11011271322928, 100.96820954353579, 114.12008931559902, 71.26291567279448, 55.54551947501398, 58.75054305599582, 23.67043906642545, 6.84371421414037, 0.42039071780539333, 0.3691701711185517, 0.21418376585408566, 0.14486623056713613, 0.3415690957298202, 0.45827045616122986, 0.5580302111564145, 0.3987361701025117, 0.33966162872891276, 0.6931738819806808, 0.26461666690245755, 0.42279151478602045, 0.286548170711725, 0.32098526315342996, 0.43300122983994027, 0.644542804408458, 0.37743846615475996, 0.7966581419590981, 0.736207124446669, 0.8634440937349874, 0.38217849729041903, 0.2791699472694628, 0.5014948835296016, 0.7609411617440562, 1.7936792873567151, 1.2095298906487804, 0.5518842861056328, 1.9502853097454196, 1.6677018279029479, 0.3392995755758978, 0.28727828314708126, 0.3245911470824673, 1.2598977814758978, 0.3944370685325515, 0.22494875675728246, 0.29041780339133355, 0.3024843317126074, 0.2534726616596022, 0.37126793435985045, 0.37301982422509505, 0.3720510907230839, 0.3211977453001084, 0.5240277357159123, 0.6582562072623162, 0.5172334551330536, 0.5609605281103043, 0.341326552292993, 0.2947701940373067, 0.31686377140783495, 0.6947844439456541, 0.4694299057366387, 12.194553748253854, 46.44410271798411, 60.25255587793166, 68.33772966938635, 64.2196136136209, 86.25242587058776, 94.95374125819053, 70.36660701997819, 36.19108200073242, 47.364879115935295, 46.78332105759652, 60.496044851118526, 66.54283738905384, 86.06151626956078, 89.08254146575929, 103.17264433830016, 105.26637415732108, 57.23547658612652, 8.33031310189155, 0.26329776993201626, 0.2289221177418386, 0.1476463483225915, 0.14124808923131035, 0.2056835913249562, 0.18084466126897644, 0.12141366684508902, 0.1280450158482117, 0.1793081187192471, 0.11559349770146994, 0.14920046492930383, 0.21590380178343868, 0.10732753923343075, 0.17344131014279782, 0.10607087158507879, 0.167315824317836, 0.11734816846587967, 0.15721624206391074, 0.10698507494863965, 0.1365262603447322, 0.13498099971442454, 0.15704894378300638, 0.17980190835172133, 0.12259643765226488, 0.11901027282639859, 0.1262431157632701, 0.12003922850013742, 0.10365256183450261, 0.11526775711606588, 0.1972057252761818, 0.11134226896589804, 0.09075407734921864, 0.15843424525472427, 0.10314949487726535, 0.25907362240456766, 0.129809737686188, 0.17108232624107794, 0.12057375868842488, 0.14838013797998428, 0.20314940311495336, 0.19024017807697097, 0.17501503860037174, 0.12623846560956972, 0.20254178813868956], [0.08003803946438336, 0.0965187817271198, 0.05914386850030673, 0.013573735449162704, 0.013440669807154807, 0.03344966639434138, 0.07354869251890529, 0.030619706958532337, 0.08727037678322486, 0.021030243501187335, 0.01596405234698567, 0.03280917092436745, 0.005541222166239975, 0.05505752869911733, 0.06216483663827662, 0.031035782716747735, 0.038455713900827596, 0.06045554509206165, 0.010798066749327607, 0.03222306003613818, 0.055728269320341854, 0.02157915890547297, 0.05271232288871562, 0.035770767248205604, 0.05115552880470792, 0.043815142445025906, 0.05136889961337851, 0.10380997758118377, 0.016207313991241878, 0.02936190741527225, 0.05889693921011302, 0.03982760117299134, 0.010899314844620325, 0.006751089503297643, 0.12811322065611042, 0.03289196204634444, 0.014082375696049103, 0.057053578446709344, 0.020461942241977782, 0.15158865210269729, 0.1395164087655083, 14.80279557166561, 52.69830234589116, 87.75985548573156, 85.05469091476934, 73.50153784598075, 60.37603209095617, 70.56481222952567, 47.61686786528557, 25.253303704723237, 16.96711236430753, 48.20399961163921, 52.54793436296525, 60.27088119137672, 76.57877060674852, 67.04884667550364, 50.33761993531258, 34.40588581946589, 21.693442906102828, 2.9927157346279394, 0.40464157418858626, 0.13529924795992915, 0.07046739495689831, 0.044722121599460804, 0.13331990658996568, 0.015532952646965222, 0.05330994041756757, 0.01628993465865572, 0.12157112855704562, 0.06652060190155622, 0.03828380377061906, 0.09983045724971641, 0.08817316543671393, 0.1286950031475675, 0.16862709105255144, 0.19911477041821327, 0.0623348928357084, 0.12990677038267737, 0.2405186357998079, 0.1213198823613986, 0.21548940950343687, 0.12090942777332761, 0.17163184110916432, 0.06654194511112667, 0.19739965277333416, 0.039506242610514164, 0.12441794192718884, 0.16260551739363902, 0.1673285107338621, 0.6765239108954707, 0.13203868582364053, 0.16438417437095798, 0.39363803882752696, 0.05850023206984324, 0.24778206862749594, 0.14038817085806402, 0.21469687622401024, 0.2506837798582931, 0.37116935416575403, 0.41618514024922926, 0.16627224402562266, 0.025092849898482525, 0.029788265988651304, 0.08128315450683718, 0.04043296768119739, 0.053217412318072976, 0.09109761415710373, 0.13199960001774375, 0.11007784850775235, 0.08241087423577424, 0.06353279770982843, 0.08030161201473206, 0.02697759281633602, 0.1454294890525841, 0.4682959423911187, 6.6522030195882245, 21.644787865300334, 52.238769223613126, 51.361409541099306, 57.04604964102469, 49.494730041873076, 134.15185343834662, 79.55580249909433, 24.8973564563259, 32.77276777452038, 34.39277333597983, 49.65489610548943, 52.03303698570498, 62.84275970151348, 66.02851267783873, 82.97125339508057, 59.45928004480178, 23.133394025987197, 0.18389206710121325, 0.2943286209577515, 0.03412224179614456, 0.09881140709283853, 0.14526804368342125, 0.032217590168358824, 0.05543408772697853, 0.021985424907817956, 0.04265657618581768, 0.030676031657945246, 0.028168116433305607, 0.07818295755573819, 0.03161942871708063, 0.025556499716795744, 0.04331513600904615, 0.07842916289284345, 0.03794528100819838, 0.020328108596825795, 0.030219797570739063, 0.1069332720831998, 0.041822471145179965, 0.05554093400977793, 0.03515845998340557, 0.0369532929072457, 0.01397670248538376, 0.05346011663336427, 0.025583626890194514, 0.04383007349867014, 0.03699099592443916, 0.024465203638218587, 0.03606501395904249, 0.03556225726741456, 0.02173332260891555, 0.0599508157240287, 0.023221166864518198, 0.031056748628015482, 0.07163393236095868, 0.048730837541722485, 0.03646721011928974, 0.04295368423505176, 0.06844764244892905, 0.035622812687389316, 0.039999476829243284, 0.03748279372831026, 0.06928297706068524, 0.04679233248856279, 0.0348011642364004, 0.022979973657657544, 0.055324540984246044, 0.02549531035906365, 0.040567492720701044, 0.060078331059025186, 0.04347367024409675, 0.02727614877174699, 0.010530848578069239, 0.025648776922495137, 0.030414102366194132, 0.04548025370064763, 0.055672689641435305, 0.04386054464585839, 0.018210239377954317, 0.01860854955720565, 0.021993284969921076, 0.1488032330188059, 0.024410730956362623, 0.011890839462378814, 0.07346683602419592, 0.015988367977702332, 0.049282911143475966, 0.03084793029683492, 0.1414848257216715, 0.04038255526534012, 0.07068208343679867, 0.07312546724513655, 0.048553281343512, 0.09986092456646505, 0.019143125710768566, 0.060994265781294923, 0.015458159482917719, 0.03679658196145489, 0.05006497966185693, 0.06916363588384083, 0.20508072609382294, 1.45866867034666, 31.142528749281364, 78.03328744826779, 100.45921141101469, 102.30158790465325, 95.55368346552696, 89.81010975376253, 90.759778330403, 53.54116086036929, 23.409479856491092, 17.348480493791644, 25.500587571051817, 22.230523247872632, 31.526809238618423, 59.72578156378962, 64.61599657612463, 51.002622496697214, 33.16916250413464, 14.26528278858431, 1.307650186842488, 0.2985012873766884, 0.18650275685133474, 0.007981106389178745, 0.10119610856617652, 0.016777666450868693, 0.14661108774523582, 0.0799552713250441, 0.0027415526499446003, 0.06745747380679654, 0.010296353852496514, 0.07665989815347618, 0.08672798653283427, 0.0994327580255847, 0.19358827341948787, 0.18059015153877198, 0.2259994769889501, 0.06370733552161725, 0.17414497722300792, 0.3283740586090473, 0.3476579012649675, 0.3208135368843233, 0.10932856855253059, 0.37562286841773224, 0.33446326250991515, 0.4870275582277006, 0.43686148560335564, 0.23272701599184545, 0.1927728800764007, 0.6197362645499168, 1.4469758397148502, 0.9926689079692288, 0.6583102624262533, 1.019897572696209, 0.4136606047470724, 0.5771103969985439, 0.2729821018874645, 0.31870799018971385, 0.30169247259055415, 0.599504434052975, 1.534831783463878, 0.7904964661405933, 0.2914783448701905, 0.09916538567913157, 0.16644631452377767, 0.09043645729581196, 0.0281855468488028, 0.11335613025772957, 0.36000947558110763, 0.4221124544499382, 0.11954338575202612, 0.04681033555478339, 0.04807601622756451, 0.25007523025476164, 0.011415921448309337, 0.44536319230833366, 3.2235153500110876, 19.896385477435206, 54.905608315621656, 55.251365246311316, 56.63397327546151, 40.72387887585548, 90.9040980185232, 45.06834314715478, 14.703110494921285, 32.115054938101004, 46.52899457562355, 76.28867995354437, 77.948501494623, 84.2089573029549, 81.24582629049979, 94.30200807509884, 77.90618696520406, 42.63233553978705, 2.827893327320776, 0.2765445026659197, 0.02675407134266871, 0.17839360892051653, 0.09730525525106538, 0.006127675400010401, 0.014305396339735918, 0.05185102555720557, 0.09270599277149286, 0.040304295553435246, 0.018478031157545986, 0.05038994649845747, 0.02791044275997387, 0.021040987884325367, 0.05400821423879074, 0.05712810347998335, 0.05293823072626706, 0.06669660294128042, 0.03537738875996682, 0.043488976680823875, 0.05605684826150537, 0.025509029078567703, 0.012505335823422479, 0.007212227510829126, 0.021380156075822252, 0.05702318390831352, 0.01596838553180738, 0.028288239019832788, 0.008388061391850634, 0.007373458854178148, 0.058680580658537734, 0.027893736297565124, 0.006598473297462108, 0.07142987718144733, 0.039190269646144686, 0.05519513724251621, 0.10042834290934187, 0.07655445381157822, 0.014916943262271104, 0.021018154633742188, 0.09091451148232145, 0.03215622269518433, 0.0019700878657468207, 0.16150863270365423, 0.17147336816114767, 0.1493891677068126, 0.12521307224467879, 0.11182628331645844, 0.11829783403945547, 0.17716832789442233, 0.11971074531996444, 0.09396302048116924, 0.11647050749630698, 0.06934882231777714, 0.15246911695407284, 0.14449565851640317, 0.09037065034311625, 0.18189795555606966, 0.15807360170349, 0.15963504211075846, 0.16994666218036608, 0.1127483084377262, 0.10546308040859238, 0.2121584132433899, 0.08085196191865592, 0.14978964783010945, 0.09981589391827585, 0.08738620927737606, 0.14615007135416233, 0.14553537772547814, 0.2571339184238065, 0.0780402813407202, 0.14197446315759613, 0.2773233995802941, 0.1345059639143367, 0.2164202676184716, 0.12461884848533139, 0.30039076663313374, 0.10419800111483182, 0.09704779608235245, 0.18518827254733733, 0.1883597693015491, 0.29990877475469346, 0.7668228783915121, 28.13873648643494, 82.56508411899691, 119.14332758995795, 105.88176265839608, 93.98471186237951, 83.60958776166363, 93.88485616253269, 64.47874107668477, 36.43168803184263, 27.032022091650195, 64.70786240793043, 70.45982606949346, 79.11673238200527, 104.08709787553357, 89.90142253137405, 73.56286802599507, 54.08174976225823, 32.6197188515817, 5.141291320323944, 0.8839272010710932, 0.5509624065410706, 0.1802133282105769, 0.39127876381239585, 0.3257461931676634, 0.2874412453703342, 0.3446780643876522, 0.1978977784634598, 0.31712617184365954, 0.24354273723738812, 0.2451221194238432, 0.23959959076056558, 0.3783575878027947, 0.4129522185652487, 0.5820981809689153, 0.6164027401997197, 0.38127264428523283, 0.41418951184999564, 0.579090703639292, 0.5712978121253752, 0.6657191906725207, 0.46784980342753474, 0.7238910659666985, 0.5938787746333307, 0.7454686984419824, 0.5381114961158845, 0.3083382853336873, 0.8590594967526775, 0.7429347860236323, 2.17805685535554, 1.0492128157807936, 0.5632899256963884, 0.9762043301616946, 0.27434855759624516, 0.9548681073131101, 0.49193968335467003, 0.4628992513302834, 0.5698041245341301, 0.7805311331345189, 0.6536273201627116, 0.6335516490282551, 0.146921782363807, 0.1570806445013131, 0.17803973758653288, 0.27351453299483947, 0.1249412872317818, 0.3064556702250435, 0.35257146663723454, 0.5386994226324944, 0.2135056248235126, 0.20997463364995297, 0.3364471237986319, 0.47955930413257697, 0.42384393573288, 0.8181098908666642, 10.417530805833879, 35.726116395765736, 77.72308288082, 74.72534087396438, 81.28482249475296, 74.61207066812824, 168.64796946125648, 97.70617038972917, 35.57705063973704, 45.99868228358608, 45.864815711975105, 59.52387755916965, 69.65130790587395, 83.4662643555672, 84.33517917510002, 106.37751102447511, 86.476848202367, 41.09821027325046, 1.800129747679157, 0.4153976631501029, 0.09147220816943916, 0.2291026846655915, 0.2909091415424501, 0.14007957532040535, 0.14042711876813443, 0.09413312264387647, 0.275387863117841, 0.135104033435064, 0.10736761329274987, 0.17718329725246276, 0.13865858947317447, 0.1250149542465806, 0.1462539069114193, 0.1588793729822482, 0.08966374271098645, 0.23296795064403167, 0.1239571706842511, 0.13316563180377408, 0.23862892671698527, 0.15674096111568714, 0.12881301133142364, 0.1284095281434636, 0.07337551834362169, 0.16199551222305145, 0.12093958865490653, 0.2506558023272984, 0.08754529509573214, 0.08256046056386926, 0.19377962686121467, 0.14764380491068288, 0.12226846009012192, 0.14922429026374895, 0.2157013553885683, 0.1822386195342387, 0.2455573952606609, 0.16997892980373677, 0.12176286504273454, 0.12545487257621943, 0.15539655341736733, 0.06570936075501865, 0.13387637753640452], [0.02303137241171733, 0.05846567767401857, 0.07737570006640689, 0.10869112977337454, 0.07739615461398518, 0.0794702917036991, 0.09027674328535797, 0.05446071173214624, 0.037181702021869927, 0.014033502159309725, 0.01598019764998988, 0.04248578071353897, 0.01322963460904336, 0.048105050959894737, 0.06594592104515722, 0.005594003230198137, 0.032954080285684716, 0.016415768430658405, 0.05850917997679884, 0.06506986119934628, 0.08612279239441119, 0.02571941597477323, 0.01887237108612974, 0.037666861673877124, 0.018277676182708914, 0.026866586676107782, 0.04125627088210276, 0.05102173154873233, 0.07932124929803033, 0.0389510931657447, 0.04714460652922431, 0.05086456861106619, 0.01730654291027496, 0.049413766621822314, 0.044713495449433406, 0.04106858317109366, 0.09674712955471008, 0.061707589399790576, 0.11663381445912585, 6.612268388271333, 41.14445893995224, 87.11126804351808, 92.8779915840395, 78.60143492298742, 72.88072862932759, 57.86864126882246, 43.598289797382975, 24.582084186615486, 44.081827825115575, 154.41230743162095, 122.5246617101854, 66.43831406870197, 65.84857002381356, 73.02159663169616, 59.25950588718538, 39.543849498994895, 16.892265696679395, 2.923464818346885, 0.2043211958821743, 0.05815941487408935, 0.0009572983230276394, 0.16974403192439388, 0.11188000140170898, 0.09128264737345519, 0.05547684309403262, 0.07106553342553877, 0.1192939475238804, 0.047178379515366214, 0.05107048538423354, 0.03612830431290692, 0.07372736720548523, 0.0881107522535228, 0.09749061022434505, 0.015441728812161715, 0.12490695117101555, 0.07967299856846372, 0.02943765052834586, 0.10144360093099457, 0.27278249001791405, 0.09663166478276254, 0.22260748480837192, 0.10788536615549557, 0.03484960014541303, 0.15945861206179665, 0.3557696385729698, 0.04453492035428363, 0.15180884109389398, 0.05937706183401808, 0.10937356089632358, 0.03067770747527961, 0.5657160342220338, 0.18424535620837443, 0.2754465148093239, 0.07512396081320702, 0.21751123810968093, 0.03474941116667563, 0.09629611061104844, 0.14040219026707834, 0.15904115543009775, 0.23549720524780213, 0.2661541747229715, 0.1607677337503241, 0.07246876901556408, 0.15471977602329948, 0.12423870033554493, 0.1670951143868508, 0.06373394558566713, 0.15682982731490366, 0.2058113594689677, 0.047914386997299815, 0.03809179532371702, 0.0401424250054744, 0.08499308083687099, 0.12177606473766989, 0.03475350590663091, 0.1263056132161329, 0.44410405019598626, 3.702507595862112, 16.107351376164345, 37.9110844673649, 48.585301060830396, 39.06415931640133, 51.89443219092585, 78.19113931348248, 57.58120998259514, 37.12442567271572, 20.218951394481046, 31.356909813419467, 37.850876085219845, 49.456102540416104, 60.14636555025655, 75.62925108017461, 78.45643274245724, 55.802438643670854, 7.5681509798572915, 0.09900662161770368, 0.2894407961397402, 0.025221610126355966, 0.011999245691714028, 0.014488003930197129, 0.051867894813298225, 0.003452664189558897, 0.05221879755657527, 0.01118676539795894, 0.003774736410818033, 0.030249414529891747, 0.052634806282097296, 0.011784605092308935, 0.02125080021458768, 0.03692356103490438, 0.007322091222440283, 0.039243179508635116, 0.06238614028740314, 0.0465782645398811, 0.0329958857037127, 0.0424115123197196, 0.005180995175314527, 0.023961904939384233, 0.022926837799229452, 0.021485876209372957, 0.04007666401805417, 0.029199324405541825, 0.08496177082340564, 0.028589786548588066, 0.05708268212695276, 0.019419694942752683, 0.0464416174368272, 0.0019874682461264574, 0.031384915796919696, 0.04164227194363072, 0.06498881675783666, 0.02485321185010816, 0.039336048517256014, 0.030876451750255884, 0.019333912247431376, 0.03694670072065727, 0.023198385324869907, 0.01793768253147362, 0.018678259727875554, 0.04251499547653141, 0.031210242004524318, 0.033792437114302194, 0.06961291580791436, 0.02599047894980158, 0.03855954945808457, 0.015967570605777925, 0.026592853884663314, 0.018785249652160753, 0.026593365248352773, 0.048153272364288575, 0.0642362809289367, 0.024762043556679162, 0.02531328978347442, 0.014834692232280731, 0.03815751800674104, 0.047308817475793824, 0.08653122451036208, 0.06567022132296717, 0.021405404418586724, 0.04100985870125794, 0.038831847749890826, 0.05390589170518422, 0.016894358878714905, 0.1270817292313422, 0.0800201130069552, 0.013450986138665149, 0.035315136455239794, 0.14144497382785046, 0.010813350203417001, 0.013601987814200262, 0.024306102498104016, 0.04284842375425562, 0.030600416864598953, 0.12039539809789389, 0.6572286688512372, 16.304748577456323, 66.58295539117628, 107.2298969761018, 105.47397736580142, 99.88046569208946, 100.54261669035881, 84.60537556679019, 74.46819028546734, 44.71048570448353, 47.413638099547356, 122.33318728785362, 70.01798675906274, 37.153815992416874, 54.999957007746545, 65.89763102992889, 61.66715083583709, 37.674624381526826, 12.25096429547956, 0.9265762964083303, 0.3747435220547261, 0.01666507450863719, 0.08588373465763946, 0.10085500791789064, 0.038843733604036035, 0.041244430993233, 0.09438633768548889, 0.054490167812834826, 0.13833831875554978, 0.0719274512882675, 0.1150712479026087, 0.1301082668285216, 0.24119288510372563, 0.41054348491372605, 0.7005842811157627, 0.38253782317042356, 0.6043251495688193, 0.5535223046618124, 1.2005539142316388, 0.9961080911659426, 1.1192474706519036, 1.1493626933905388, 1.1897465586662292, 1.485843341196737, 0.696695741386183, 1.0510525299656777, 1.9955249467203695, 1.078052042472747, 0.7114478368912974, 0.8379282790326303, 0.78142004027482, 0.3932496016063998, 1.6747272831778375, 1.1260104948474516, 1.3444182396896425, 1.0255368378373886, 1.61603526482659, 0.8890693670799656, 0.9988954867566786, 0.5725559123581456, 0.5511677181047778, 0.43822484631692216, 0.3582635918451894, 0.5756992017549853, 0.24697668039269988, 0.2872228796683973, 0.16435150838186666, 0.18246682180512339, 0.16933170808178766, 0.5245628328092637, 0.5879895196807, 0.1410868583667663, 0.25332040934553074, 0.2547468190952655, 0.1100430834377485, 0.05531897535547615, 0.034747599368734707, 0.27255428774702933, 0.28842490226511036, 0.6975991122664944, 11.111125484589609, 37.74144195741223, 54.89522972414571, 45.31912380649198, 46.96749987140779, 36.87864603534822, 29.441789042565134, 23.081673652895038, 19.20276334208827, 45.63537666874547, 58.36664499775056, 74.18626600696196, 79.40303402562296, 92.55947943656676, 90.46720873924994, 76.75016249379804, 18.570743991482644, 0.10382311598908517, 0.44889206907922224, 0.18253106593845353, 0.06874283144791281, 0.021089665111034148, 0.09384677429953892, 0.06118182325735689, 0.042087273266647136, 0.08522715900213489, 0.028331616833325357, 0.12179197638385719, 0.05663208836208909, 0.058598785450862306, 0.021996037140789054, 0.04622483370645393, 0.08776252698754111, 0.016452523414045572, 0.03138971725298512, 0.015212830358875856, 0.014445214089186443, 0.02020941667949721, 0.00576221842258688, 0.03630931173721629, 0.0931689473650148, 0.07684140736537595, 0.02391836241698794, 0.02009774021233522, 0.026829023469960498, 0.05265768166751631, 0.08454331827740516, 0.024989255658921697, 0.025111735881035848, 0.039295744631559625, 0.07236243601167396, 0.010025775428080272, 0.04983788055758323, 0.014321598141724545, 0.0261664665829871, 0.04149542054942539, 0.023206461806811636, 0.020254669493184458, 0.09563836284101972, 0.17690365983834191, 0.1320008257584226, 0.22362613659952918, 0.16645186100034945, 0.18731885499531226, 0.1995551024353312, 0.09684552588770468, 0.1460321397790986, 0.143842093586441, 0.10587428576282917, 0.1292530062698549, 0.1077989974029122, 0.16395185563352802, 0.1649646545129438, 0.09380215733882882, 0.13792046375813025, 0.12789696935684453, 0.15218525073460995, 0.09697300291830495, 0.14500533681242697, 0.1411161535689908, 0.09550445833273473, 0.16021235064873773, 0.09717089875090508, 0.15321862673567188, 0.12991956405101285, 0.2942557506743939, 0.23885809425865454, 0.16052322912841074, 0.2249903400098124, 0.2686117847840632, 0.12299158580360875, 0.11301203420565975, 0.24090348772944944, 0.1536387646751058, 0.11647197072424235, 0.43384214923266445, 0.33415045348867295, 13.638372325128126, 69.10357244553106, 120.20290882356706, 118.79044763503538, 98.71117576476067, 95.4525569177443, 77.6902683319584, 57.22361533872543, 36.46423193716234, 57.084029951403224, 168.661525172572, 139.07794244827764, 89.87413852445542, 91.72466570331206, 104.43658890262728, 82.10215814651983, 61.80963093234647, 25.63288519459386, 3.900031783888417, 0.6627624590070017, 0.1602964977463407, 0.23614111746991837, 0.5588784237061778, 0.24504797743453136, 0.3067784690328183, 0.1939778291289845, 0.15832117067710047, 0.3732771684806193, 0.23293526933318187, 0.3850209899246693, 0.3775652077409529, 0.3961610727973523, 0.366037484378584, 0.31068677383084453, 0.14046887056000773, 0.31565580396882953, 0.3420835084492161, 0.6940797656293839, 0.5953752814281372, 0.8383813127875329, 0.7925275184454457, 0.6678331030472633, 0.7143310241160855, 0.2643999253069201, 0.554196584609247, 1.1612185475326355, 0.5577224889589895, 0.43164831856566094, 0.35510540969910165, 0.43116792015010313, 0.2294259124826039, 1.27211841604402, 0.5258222200697469, 0.551457176766088, 0.37195787314445744, 0.6393077272561289, 0.3466168184193873, 0.6570486688325483, 0.37895277683292666, 0.390377875056959, 0.27874357337432526, 0.3691125613066458, 0.3939035649020826, 0.2620799352805461, 0.5012960377479754, 0.3802401109808876, 0.88754644557353, 0.2771986191791873, 0.43487704208781647, 0.4407084114368885, 0.26404161066297566, 0.3631058191099475, 0.3264874598431972, 0.23821050481450176, 0.35285743193761, 0.26634958843069695, 0.4426799540317828, 1.2999525353793175, 6.715111463300644, 26.651299192059426, 57.00066781813099, 70.39182786018618, 58.0158595885, 76.12067699432373, 106.8218449623354, 77.33971042017784, 51.76884182037846, 31.046014908821356, 38.92779027262042, 51.126224225567235, 70.25784753984021, 79.22890432419317, 94.81155533944407, 104.49282784615795, 82.09155205757388, 15.101439933623038, 0.14144315053859066, 0.3889408473285937, 0.2576720185818211, 0.37023377694910575, 0.11734251473699847, 0.2722922550334085, 0.09847108019335617, 0.1763941960469369, 0.15548298345698466, 0.10313354492668184, 0.31034283099635956, 0.18343330300863714, 0.14768578652893344, 0.09206257084564817, 0.11976402673509814, 0.1687713913739689, 0.09232310202693747, 0.12227388399262583, 0.17408103952484746, 0.11869917218122752, 0.13490708755148997, 0.07833629005378293, 0.1213124206650161, 0.1684069480266302, 0.17198617209590253, 0.28717948844836605, 0.11285797392408695, 0.14953748232895328, 0.10470805479393852, 0.17208305157480702, 0.19368613349093547, 0.09534217026685515, 0.14730982121921357, 0.15201896368976564, 0.12006771931004141, 0.17004930264046117, 0.13223782271867798, 0.3096919320523739, 0.10489717891980564, 0.1252975334383307, 0.16166525171889415], [0.05527405579003596, 0.06996943014523677, 0.04603863603645756, 0.050285386988112045, 0.029670056706715017, 0.027042869253144152, 0.024192528048109625, 0.02102244664133797, 0.03252834607396395, 0.02423992973842448, 0.054834194916991465, 0.06812310462156612, 0.012552016433478605, 0.09309367922645423, 0.07147244102652035, 0.024776873103673422, 0.022659419487500866, 0.044689459440809105, 0.0047546859188455975, 0.04569166715467169, 0.018677859446935115, 0.03252828478693001, 0.10754468685556805, 0.0305948052705536, 0.028250792642093958, 0.059191174429631045, 0.04003219261404969, 0.03466881488660171, 0.05398851045737824, 0.03548132773909358, 0.013930674965283083, 0.0615008797256216, 0.08159054728645472, 0.03351532779033146, 0.09224905196817652, 0.06765013725887384, 0.004588224588998504, 4.7374421261972, 46.51987114260274, 87.26105551565848, 99.04464783207064, 99.24187244907503, 68.65231160194644, 58.299141007085005, 43.171630059519124, 40.9546083788718, 30.032335212153775, 33.08180347565682, 25.161988965926636, 43.61276334331882, 102.03361157448062, 70.13892127621558, 52.209206319624386, 27.08845715368948, 11.18039454183271, 1.5373251851527923, 0.1167243124256211, 0.09943828151951875, 0.08448900264357367, 0.14770139940083027, 0.04490092652098787, 0.10033093482976961, 0.06824687378661287, 0.1620571976227145, 0.12098468825100891, 0.14756194075509427, 0.08384906641778447, 0.08124227605519757, 0.04185464683799975, 0.03714275028135988, 0.20246859609840379, 0.20866609418824797, 0.07243276288312289, 0.258924204615816, 0.12084072500827814, 0.08732333644143037, 0.05667859755997216, 0.12583334299345172, 0.30309272809855403, 0.34620300836620793, 0.7727828585813123, 4.891958505876603, 5.11277029591222, 4.497307269803939, 14.722090844185123, 4.27777172096314, 1.4090278888902357, 1.0195641099445283, 1.848271570859417, 1.523588431939002, 1.973489071092298, 1.2814617469426126, 1.2844874878083508, 2.7515968536176993, 1.1648806929588318, 0.4951472934936324, 0.4670772803646903, 0.6623642158604438, 1.008332586817203, 6.35936180430074, 1.6632603565531394, 1.7584176698038656, 0.8457033973067039, 0.26874658561521964, 0.06113029235313016, 0.10522181633859874, 0.09610143234773029, 0.32123200475208225, 0.7442827330481622, 0.11137148755933009, 0.047673559597423004, 0.033343647486500205, 0.1654990927706803, 0.10034093227718147, 0.023892489712565176, 0.047539076692755186, 0.04056268551897618, 0.1763847425219513, 0.36477414410441156, 1.2772339221931275, 20.562911879631784, 35.891848302656605, 48.98668112293367, 67.85527813819148, 57.369602034168864, 67.29299852924963, 62.56143946801463, 34.59432824965447, 25.85824497284428, 29.340778204702563, 47.20248514606107, 46.618573665618904, 61.69034773303617, 68.05471497197306, 76.69734385705765, 27.100028145697813, 1.0493011916837385, 0.2981530544498275, 0.028067013894718502, 0.02044866019259057, 0.10941279991980522, 0.035244821075109706, 0.08166845842835405, 0.06200871174974788, 0.13959445780323398, 0.026407937496720303, 0.05562905710370791, 0.02179884610907926, 0.038815622007654565, 0.007582365285470001, 0.01886397859291925, 0.07617918564186943, 0.059642879021984924, 0.033527497097008654, 0.1673231634401506, 0.024206765792182377, 0.03511464358457635, 0.014659621989384536, 0.04877286129480889, 0.055962922051548965, 0.03607295829081728, 0.051849075863438274, 0.019677077502673192, 0.02331423122555979, 0.03647444198929495, 0.07578773769519984, 0.07608305692913071, 0.06897071196186928, 0.00988117250193271, 0.01826261680933737, 0.030857795594079845, 0.06846395246083699, 0.03634670831924004, 0.013911965182952344, 0.04150273285866265, 0.04622365776149016, 0.032381276344700206, 0.05974407157590313, 0.04367877113362474, 0.02769337366184881, 0.04899739783497588, 0.038158690121265194, 0.0380214914349058, 0.07722535531126684, 0.04197396120176681, 0.004263544556564622, 0.08427004705393508, 0.031082376184302474, 0.023550728313444604, 0.022190016348876303, 0.01732011415785359, 0.018189587562735525, 0.0397381795600297, 0.04975822656565616, 0.01876964252592335, 0.027682702057063583, 0.1575270592565498, 0.03560569445272127, 0.08828895962646893, 0.030232045401428497, 0.01844616381511573, 0.04813408186178535, 0.015930242971667362, 0.08622745532662639, 0.0405790644787973, 0.01781206900974916, 0.05932985932656354, 0.05443877480443447, 0.008648838678885613, 0.03564989389551263, 0.08768442432366072, 0.11725336508524996, 0.14281683811737647, 13.038187911433559, 70.71500762816399, 108.53585796971475, 116.29998576256537, 119.20919987463184, 85.63042425340223, 84.87420697366038, 73.95003734096404, 54.68563395161783, 27.830961827308904, 16.650628082213863, 19.25343251997425, 41.40291960008683, 81.64047948775753, 68.13739069046514, 58.52467729199318, 27.310010271687663, 7.44952428725458, 0.7891647601800581, 0.23940885018917824, 0.2395292179238412, 0.31387890899373644, 0.1657772133307111, 0.0776404906965552, 0.20973271840522367, 0.0424689267792048, 0.1127364417357791, 0.20826038934530752, 0.36540788267889335, 0.3967002454784609, 0.3029668445308363, 0.26174245822814207, 0.6354813325789668, 1.184727886030751, 1.1987409211935536, 1.688063219189644, 2.46999028709627, 1.494388960061535, 1.4455881786923257, 1.613121311510763, 1.8616105712229207, 2.2126641725340197, 5.080467616358112, 6.394590572003396, 17.71696952081496, 16.329902737371384, 13.258185809658421, 21.117789976058468, 9.304827932388553, 5.846262343468205, 6.450333335707265, 8.530315737570486, 9.716301233537736, 7.052424021305577, 5.755052528073711, 7.815179892124669, 5.932817776356974, 2.4215007212854203, 1.6891281426914277, 0.27200678002930456, 0.9487973201659419, 1.0168987981254056, 2.0029278075502766, 0.5547159922219093, 0.5160329034251552, 2.822627545364442, 0.2640366770567433, 0.09228854380067318, 0.1479330643891327, 0.27832890530267074, 0.4732109786522004, 2.8721531071970543, 0.2808717962714934, 0.11740695039230971, 0.15266813127504242, 0.12954387453294572, 0.3644682911615218, 0.09172920002451829, 0.030985104085336772, 0.016616460484182163, 0.09119499925403826, 0.549056318498427, 0.22070377163829344, 15.389173242353625, 38.036941559084006, 56.31794791067801, 69.37562019594255, 42.15131959607525, 38.92085552215576, 29.789583644559308, 21.03075062074969, 31.26697574892352, 48.418749378573516, 76.83854918326102, 71.86201064817368, 78.6341396454842, 80.13483062867196, 95.79749799543812, 45.76896475207421, 4.72231452503512, 0.26891009942177807, 0.07581245169163713, 0.05309606782130657, 0.08710375265969385, 0.10854526663259154, 0.057879781290408105, 0.03319048352779881, 0.0391669882341258, 0.01819386424857282, 0.04539165946264421, 0.05546429840427253, 0.013146626109617853, 0.059364593753050414, 0.022110542387611443, 0.0475765383922525, 0.03931663584925475, 0.02762643289902518, 0.05455252353943164, 0.06504438111498471, 0.10343933658253762, 0.011937803524966923, 0.14176524454547515, 0.03364968429049177, 0.028331722170414946, 0.07309992587374103, 0.08223543244023478, 0.026629572478874076, 0.05131264194665898, 0.04947272474847494, 0.01101050771878011, 0.05234448194143273, 0.024193012598721732, 0.0691492947178983, 0.052348906099195444, 0.02397514102349599, 0.03691997191297912, 0.02512132155618841, 0.041273446573365125, 0.06831356174042148, 0.18656703162818186, 0.14776768132803902, 0.1201205334115413, 0.12700834566907537, 0.11580026483223324, 0.17086167759712667, 0.1321997941141167, 0.18853085205679943, 0.1606479482424836, 0.14990284498180115, 0.21183014456783572, 0.09935158334912793, 0.16958067133542032, 0.14983161412660154, 0.19392668509915953, 0.1141891283013167, 0.18125338449833855, 0.16055732004104123, 0.09456254556895265, 0.11749402394578343, 0.21075941411958588, 0.09319664910435678, 0.15513841243040177, 0.14881524527745862, 0.1062364078637573, 0.12315324567739042, 0.1998780391389324, 0.17149829666220373, 0.18844020853359855, 0.09113244051414152, 0.20070282471997125, 0.2128848791002266, 0.15150277364638545, 0.12863498781957936, 0.212189746239493, 0.2311710914176318, 0.12127245385800639, 12.195742226416066, 75.46467627248457, 119.78560786093436, 127.63933827800136, 123.98919628512476, 88.75562760137743, 80.89534682612266, 61.889921849773785, 54.549668911964666, 41.43909954255627, 47.63673074783818, 34.24147967369326, 57.860302309836115, 127.10833564881356, 95.53232223756852, 77.3558235168457, 42.3334470102864, 17.46741852452678, 3.1555014512231274, 0.36560602365962924, 0.4841894169728603, 0.33093144396139734, 0.4362556939163516, 0.339641097572542, 0.32457466087033676, 0.23973112805716454, 0.4211936085935562, 0.282554431788383, 0.23536241973840424, 0.39401320740580564, 0.20779336682490765, 0.22706988568027175, 0.19181067364350443, 0.6259420057458263, 0.39869483199811756, 0.4349117918360618, 1.0488442355586638, 0.6950522069969486, 0.7611250841329176, 0.3849150552864998, 0.843937963006958, 0.9910847607158846, 2.388165722931585, 4.566122312699595, 14.359601082340365, 13.995622781015213, 16.450724486381777, 30.01401774344906, 10.978513090841233, 5.245286591591374, 7.287923616747703, 6.369502111788719, 5.078808944071493, 7.609357439702557, 4.482911680975269, 5.533859287538837, 6.359175491717554, 3.216446258368031, 2.6312926123219156, 1.8068802693197805, 3.0249063814840014, 2.541437485525685, 12.47178981381078, 5.767410445597864, 4.864457297709681, 4.9996452177724535, 0.723867164023461, 0.26968305149386007, 0.25958975116091393, 0.2332186605781317, 0.9018125961865149, 2.6175192094618276, 0.3118540466793122, 0.23011134667021615, 0.1817963416537931, 0.48400944759768827, 0.2875908470201877, 0.2652513554259654, 0.24255678207883913, 0.10749446213125222, 0.3517280344761187, 0.962028332775639, 2.6840024032900414, 31.676883043781405, 58.949870063412575, 69.4929696667579, 93.79977995349516, 83.37947799313454, 94.84053381027715, 83.64710130999165, 48.50321762023434, 37.05104204916185, 38.96599415809878, 61.860562909033995, 64.21611878179735, 79.0144448126516, 88.09889731868621, 108.62836314785866, 46.850589706051736, 3.344024044852103, 0.3581580862162575, 0.14791075590877764, 0.15532012848604113, 0.2821020109038199, 0.13877224627762072, 0.15548073115848726, 0.10332130541604373, 0.22056993607792164, 0.12009714474721302, 0.22836138734654074, 0.15465865752870037, 0.22606683143925285, 0.2046509354465431, 0.11534950635846584, 0.1365342583026617, 0.12911181626541, 0.1909193456653626, 0.24482251775841563, 0.18257301691318714, 0.1656815902360024, 0.08968325497041787, 0.1852090488518438, 0.16839010941405452, 0.18312847662356593, 0.13361783818371836, 0.0993063688398369, 0.10889472530013132, 0.13215036612124215, 0.20517236553132537, 0.1981878040298339, 0.15538322348748485, 0.08961810685333707, 0.2362227517991297, 0.19215421811226877, 0.09595792109687483, 0.20772800420320806, 0.08385205416068917, 0.1387737631317108, 0.23022051419942613], [0.033324690640813885, 0.012730605892776962, 0.07849443358399215, 0.0799793801120212, 0.07233802845040638, 0.031801497173165126, 0.020787719216558243, 0.023390688715622793, 0.025440010302249464, 0.015692261588429252, 0.038177080061887546, 0.022656927786527142, 0.0784330009933441, 0.037796751881438884, 0.023561003467729016, 0.04155403010607247, 0.04527807543655077, 0.01641467867058612, 0.016420797797881307, 0.009447548542201761, 0.016857203614387303, 0.05651030336476623, 0.041724614904172, 0.03371585130451187, 0.04019842603273931, 0.023658371327685255, 0.023284424659645846, 0.016104964644558007, 0.09167222606558954, 0.03121816909932081, 0.04863331837940121, 0.09764087070981342, 0.07999957418970524, 0.00331229557501032, 0.07877784015070047, 0.31999204548135884, 26.441395513473022, 80.82591302933233, 95.5204531454271, 85.51407890935099, 64.51236755617204, 61.72412718496015, 74.34012489934122, 50.39258018616707, 37.685752145705685, 39.22567859772713, 59.59347609550723, 87.25857657770958, 54.4018308577999, 47.167842772699174, 36.777209620321955, 32.27820592541849, 10.693224399320542, 0.6111723208619703, 0.11777009905105638, 0.07090831686171793, 0.23304420703601456, 0.11197725626369638, 0.0569990368169402, 0.05211756286782123, 0.04361278798070647, 0.1003676074587049, 0.03614787019849305, 0.08097275866255646, 0.009822722866139826, 0.01882175182653291, 0.22389874132650517, 0.18879567333046468, 0.17391990059085433, 0.4622498232751124, 0.9894427585024989, 1.0235658468257998, 3.195036736226851, 3.868303731564553, 0.8443216198394377, 0.2587841024562236, 3.5317675577056025, 8.560939642690844, 3.1896716692755303, 7.576103095085391, 3.687367737293244, 21.666427581541, 21.284241637875958, 15.785985704391235, 12.365103306308871, 12.205527559403452, 6.880952215963795, 7.823501200445238, 2.3843887256037806, 1.7413491082768289, 3.0428605406515064, 1.3851775493352645, 5.375375430430136, 7.013628838523743, 6.823909676844075, 4.505733011230346, 3.421444032461413, 1.1042345988173639, 2.5914687879623908, 0.3404127319733943, 0.8695221740391947, 2.8164588828240675, 0.3163564373408595, 0.09028930712731616, 0.4000809914883106, 0.31086591583105827, 0.13778580082280023, 1.7976995942092713, 3.234605851673311, 0.6232069492820771, 0.2892662813105891, 0.13442960027004444, 0.10200633081577479, 0.05042629354002495, 0.02556148694918281, 0.060160815745832465, 0.09679206061146914, 0.026323210087514697, 0.02908431545590922, 0.09518182806430325, 0.44087076078980203, 1.7057135172428626, 20.01418602082037, 39.09856634755289, 44.38202250388361, 54.98474213384814, 60.21804294278545, 71.99634398183515, 43.104647744086485, 26.47630068563646, 18.89004453536003, 39.318544633926884, 54.46766784114223, 56.80026608128702, 61.87433827307917, 75.84406360503166, 46.13328626078945, 8.267756200605824, 0.1063514129829503, 0.059072499749280756, 0.03921371959750691, 0.04922465398727406, 0.05205228068535367, 0.08019881067617286, 0.027153201235999024, 0.05566734234772383, 0.0757072295152372, 0.02311803419293175, 0.09019266513566818, 0.011339625794320338, 0.04559136326274565, 0.052083299585407784, 0.07656848854235104, 0.05017095260442265, 0.025531866159590504, 0.02960361007060255, 0.054072217054424755, 0.06777414391117711, 0.05812904714877087, 0.043692874812310746, 0.01750281655169543, 0.011862947158665668, 0.06194994897551595, 0.029882481396799127, 0.1003932714041683, 0.11961478514656906, 0.03132067166358954, 0.04228591220453382, 0.051556686915817766, 0.017750998395645333, 0.03151119006947885, 0.04853010718380252, 0.03205243693364244, 0.038574315802825075, 0.015487738137674189, 0.03737363002953991, 0.026525009138089035, 0.035890571908244205, 0.06467523398779093, 0.044917025858716625, 0.024968113547431368, 0.018227579778120406, 0.030763296733400038, 0.052200694898924524, 0.013731183754580637, 0.07082690469800465, 0.019437021936380097, 0.005969604648153989, 0.046676974968924645, 0.014460878672018168, 0.043218831096084855, 0.015831116939924898, 0.024523116054854566, 0.038223213876687714, 0.03212407764588152, 0.01430130351500045, 0.0335105742147613, 0.024250563038813493, 0.010930706254927623, 0.03881485208929066, 0.07772361123633963, 0.0200735031056308, 0.005065638134481325, 0.038765669244551854, 0.043936326063328215, 0.01428022747859359, 0.018235252148682074, 0.10480436736777907, 0.0332099000262397, 0.12080890171590353, 0.187976572121824, 2.90985468414522, 47.557655765164284, 107.06876600942304, 106.70371886222594, 102.96951263181626, 86.58640784602012, 89.49977182572889, 116.0752574859127, 68.73941175399288, 40.18394500978532, 21.51316685061301, 26.844195473578672, 51.20896662435224, 44.167433554126376, 50.689393781846576, 45.816947106392156, 33.092758655548096, 7.624564468860627, 0.26033448055386543, 0.21342621214928167, 0.12329697909374392, 0.4099152315287821, 0.25829536900404965, 0.09458011196505639, 0.1763833329201706, 0.04711182562694435, 0.40148375976470213, 0.22042669295783968, 0.43749562254355806, 0.1394789317442525, 0.15538216628614934, 0.4359065110404646, 0.94816692173481, 2.1670857408354363, 3.7391349336793347, 5.03804277027807, 4.146703760470114, 8.783989144909768, 7.420709575376204, 6.102070010477497, 6.967173266795374, 7.110859982429012, 19.56532370659613, 11.110539090248848, 13.672854861905499, 11.37548735064845, 16.309230865970736, 19.985870430546424, 21.166741155808975, 12.733133416022024, 17.604954473433956, 11.141306161880495, 9.846137569796655, 7.002992841505236, 10.01692541183964, 8.63060191754372, 3.7791352646966136, 4.559424375334094, 0.9611280875340585, 3.3486222884347363, 2.9485265574147626, 1.475294249192361, 1.8082141203265039, 2.0763966200813173, 2.8398724909751647, 1.4765003780203483, 1.9389528468731914, 0.7875480082246565, 0.8306306480400024, 0.35212826945127984, 0.5451241424006801, 0.374275135897821, 0.4512779733106014, 0.7906540963918932, 0.7717700903454136, 0.439182149787103, 0.6331902393890966, 0.14325842651869022, 0.3970641372424941, 0.08593477143515503, 0.08197157643735409, 0.09955667274733705, 0.010065985468005943, 0.019926029264987, 0.06038838982461922, 0.7843092949159685, 0.37401435956839596, 12.882897353941395, 38.28025794798328, 52.44986334154683, 58.73775612923407, 46.38194491786342, 37.765544922121116, 22.591457789944066, 22.382332701836866, 26.912338810582316, 58.89844386808334, 82.55956926653462, 83.27455459102508, 78.2729442657963, 86.61358202657392, 66.90038496448149, 19.423608472270352, 0.09767314599406335, 0.0642194040119648, 0.09781633548799062, 0.0698545016348362, 0.13622423784146387, 0.07716825111739098, 0.02986511418355569, 0.02939315422648384, 0.061237690219235044, 0.028457341437798836, 0.051003448860419374, 0.0822164104770749, 0.031815966658834974, 0.02440447393324106, 0.032332047534685944, 0.018600664597244996, 0.06617837510402165, 0.029484460415739207, 0.07009236427444605, 0.045181598153806506, 0.009330208770059531, 0.0738987104306298, 0.06778273941768755, 0.007768409737881514, 0.026255217869014993, 0.037058407831336224, 0.09801657554963905, 0.058385893447144385, 0.07375413431755959, 0.012112150772384579, 0.03623214753104314, 0.0340183028170178, 0.05685119333887293, 0.04802447383201892, 0.043272920733978676, 0.032922080793087526, 0.01116831704313236, 0.017406831480442517, 0.16098799935031324, 0.07997674476956168, 0.14309428452003387, 0.09866845508616778, 0.13845844134207697, 0.13462171979969548, 0.0972970427885171, 0.1176033906578537, 0.151238166877339, 0.15579162495991877, 0.11003268762461602, 0.1476683503677768, 0.20030851926534407, 0.08519060894726746, 0.16155153362741395, 0.12259996165671658, 0.14130356931878676, 0.11549746858016138, 0.12301073800171576, 0.1923378493877188, 0.12824039125154096, 0.1692434853964275, 0.12624908358820025, 0.11433510635528835, 0.19121369196762963, 0.132853772731558, 0.09458984128169476, 0.06315078413594635, 0.20999347941289026, 0.11947927951452234, 0.09360112820661838, 0.21688313794232186, 0.24556758423005384, 0.17371478821000746, 0.47111401214234294, 2.8336763718435845, 54.46526735059677, 122.20552982822542, 122.08778812039284, 104.86581387058382, 85.03331399733021, 79.85014500156527, 98.20637456832394, 62.42039495898832, 52.40353230507144, 58.60045748372232, 80.39090648774179, 115.23831782802459, 78.33304282157653, 67.07042755619173, 56.02134220061764, 50.63206049703783, 17.611055720236994, 1.1769877013660248, 0.5325847539690234, 0.3876435846811341, 0.9480377286672593, 0.5675751151096436, 0.17743609094571683, 0.12890118805150833, 0.16651978235571616, 0.20304454099987784, 0.29946937736484314, 0.38075908958431215, 0.11361211087674865, 0.22572699483604203, 0.33861971850837436, 0.5542470851252156, 0.9356559091998685, 1.1914726466901842, 3.0191956556612447, 3.205043192832701, 6.966767791778811, 6.595962605168743, 4.737535772785064, 6.831510739941751, 9.158298969268799, 19.781197232584802, 12.385854605705509, 18.204371083167292, 14.740623062656773, 40.38830441813315, 40.62940074551491, 34.841253219112275, 24.85608135500262, 23.537506018915487, 16.98660458287885, 17.450397399164018, 10.443615548072323, 6.183966648194098, 6.652336870470355, 4.456990697691518, 12.132834272999919, 13.694497519923797, 22.213660978501846, 16.881122243019842, 7.229339586150262, 6.444815051171088, 5.6490303720197375, 12.813503761445324, 6.364857044912155, 6.586156679737953, 2.6365206414653413, 1.601801351193459, 1.3732845552505986, 1.1256702292350032, 0.942678300123061, 3.5715661318071428, 7.4618361169292085, 1.535036482157246, 1.2176129149813806, 0.7440277176999277, 0.20697650259300587, 0.2895079054419072, 0.19288198631857673, 0.25317197214932213, 0.3033109099393891, 0.23969159792027167, 0.15857249348153993, 0.3516966555147402, 1.0026082552729114, 3.201429709311455, 30.618992351716567, 57.11100801344841, 63.3944175320287, 74.4333282593758, 86.36029105032645, 97.37631474771808, 58.434494156991285, 38.61925663486604, 25.703870288787353, 51.40195900394071, 71.96665948437106, 76.77862321176838, 76.88998714570077, 100.34339166456654, 75.2297890570856, 17.7746715084199, 0.18998248142100152, 0.1221365167669231, 0.12474208138883115, 0.2308080576720738, 0.20449327455172617, 0.13325681158852193, 0.3178779798890314, 0.21786579892279642, 0.18266991171385014, 0.11100380366007168, 0.18975274697426828, 0.15087343241658904, 0.09634274238299939, 0.11347105110725088, 0.15899951089053385, 0.12380101132176577, 0.1337392784414753, 0.1015728782682169, 0.11099173011438501, 0.13430852773449115, 0.13416180657523294, 0.09699640690439171, 0.12208112094911838, 0.15061394311487675, 0.1972802196659388, 0.21872542618263155, 0.2042399445969251, 0.23757829841586853, 0.2059878967702389, 0.13336486062936245, 0.11993455790704298, 0.0646662630981976, 0.17634725017893702, 0.13533067288658313, 0.16192579822194192, 0.14658038294123066, 0.18138426295932264, 0.1468218078896884], [0.02272596571504349, 0.0244502438562772, 0.029372854811710217, 0.044183431553744504, 0.08812651068212525, 0.04407833961229171, 0.053401484094079466, 0.030996384730021802, 0.01750071555556309, 0.013756972189331728, 0.1179574688355769, 0.04387544122554603, 0.04330129663069402, 0.062200383117963234, 0.062085741890534285, 0.04971018902236416, 0.017739943746897965, 0.035328646415784475, 0.09944966558607356, 0.04411897674623517, 0.028383264565960537, 0.025495021160872235, 0.07942765124983366, 0.04662963839608335, 0.06738251976428494, 0.04644968817310949, 0.023053945192406257, 0.041530947876913894, 0.07524411404325117, 0.007215323942458078, 0.0381916050889319, 0.27217056962751573, 0.12109800031588924, 0.08982485100146263, 7.209920421723397, 57.92841426787838, 105.23441468515705, 80.72669275345342, 87.16527123605051, 63.76250843847952, 72.38123047736384, 48.86042394945699, 21.135907403884396, 47.026319734511844, 52.96552165862053, 68.32730400946834, 63.93282167373165, 44.537532714105424, 60.92940399723669, 53.086852335160785, 16.388471568784407, 0.6384856229828251, 0.19251262468676414, 0.06845202447185594, 0.23723512166930785, 0.16335157977957881, 0.04481314816662381, 0.052388210240150654, 0.11001925810330337, 0.05650107583571827, 0.08153533532975182, 0.11460743529061157, 0.12159259434068397, 0.036985790356993675, 0.19289936119269943, 0.656809342965003, 0.40808486361657426, 1.0638356569313234, 1.1549026735367314, 4.860922261591881, 4.1716809234311505, 6.820301096285544, 11.05775869661762, 8.412802507800441, 4.63455492450345, 3.656742116135936, 11.703621072153892, 11.751342588855374, 6.043136398638449, 11.039723638565311, 7.958390039782371, 9.931256924906085, 21.505282886566658, 16.00927447119067, 9.248410521015044, 19.260212336817098, 15.495157645594691, 19.496162514532767, 20.55651253269565, 31.83796694201808, 15.932446026032972, 8.539294042894918, 9.754327631765797, 5.443659972759986, 4.849882260445626, 2.9004306995099594, 1.0017909313882551, 2.5744707065243877, 5.872696666948258, 4.321506638680735, 5.354030872544935, 3.802501068961236, 1.7989429855538954, 1.075332981924857, 1.4345747761188017, 0.973894483139438, 0.7677025924767218, 0.6130074998063426, 0.48146738400382383, 0.18944710853599733, 0.9395557870307277, 1.8976425667924268, 0.5405421398820416, 2.5704120339885836, 0.03073069011612285, 0.14453053083871642, 0.06222154246643186, 0.15251468386380904, 0.022474340305873947, 0.2042543010846261, 0.045572027203536807, 0.17923716365570025, 0.6732089565165582, 1.6812305729235373, 23.27341087402836, 63.077152698270744, 70.24126375875166, 56.1130315257657, 55.31126376121275, 68.74087087569698, 52.80795220405825, 31.314493302376043, 21.301656961441044, 41.59067169312508, 55.41357094241727, 54.638188962013494, 69.98162638756537, 69.67735244381812, 26.669624505504487, 0.7428025286043844, 0.43156049424602144, 0.027676617403724985, 0.09479060994401094, 0.013186585255748322, 0.06214615941468266, 0.056850488537982594, 0.04892307198456219, 0.03814815258186671, 0.02813602884059712, 0.0031208444570731977, 0.031191089806417306, 0.02315827104593477, 0.0743627528690042, 0.0394346057287147, 0.022269296872940277, 0.009564038914357944, 0.02999487990182975, 0.06278353307636515, 0.02355251521352799, 0.01121602421100702, 0.0326007490436877, 0.050536020313419645, 0.0355371180921793, 0.09422373552356036, 0.025939970772953767, 0.06183726510273353, 0.05763195950778262, 0.043425632700804746, 0.09521587301165828, 0.03251829500039739, 0.06524236887813577, 0.01461153848081707, 0.012612705918840103, 0.04165084063706379, 0.03854575221456828, 0.07280285229846355, 0.013671921107978111, 0.01953192682365977, 0.045595626542044264, 0.04251190048131732, 0.0908580891066982, 0.059189473714439146, 0.09145920765736411, 0.02959816893112035, 0.02802567195988471, 0.03568113113062517, 0.052047822053634354, 0.07148593949574618, 0.03533001388272932, 0.05430333812030093, 0.0440267589123499, 0.04359535181954984, 0.0497967837708852, 0.024907221048769933, 0.08707503968429181, 0.019266643982020118, 0.05554094167065717, 0.015014190463379267, 0.06506134230162829, 0.0975093410740937, 0.05667180236008379, 0.04739956442086447, 0.09917408077707214, 0.10553100942483834, 0.13182217405448038, 0.04368756582299548, 0.0635941613525633, 0.17344659614947536, 0.08029154561940702, 0.09138644462631595, 14.276795925632602, 82.60698287717759, 123.14631815879576, 93.78916601980887, 109.50407151252993, 93.06330788520076, 113.99422830150975, 69.26431117519256, 28.626202767895116, 31.96288266489583, 24.67507573866075, 51.82777543221751, 47.59365135623563, 50.15584553441694, 65.25861024856567, 53.915755056565814, 11.052546847251154, 0.24407132258338315, 0.1317247276705119, 0.07354886871912787, 0.16337609459315577, 0.13901083670075864, 0.10122129753712686, 0.1863724759389316, 0.5148583987066823, 0.5227672452888181, 0.3664571779870218, 0.7254617300725753, 0.938709045369779, 1.0864035040140152, 0.6956509200315322, 2.6281304465186213, 4.149064537017576, 2.8939730073175127, 6.076129415342885, 6.076782489976575, 8.000950207633357, 8.133106625849202, 8.89006180147971, 11.306577190276116, 7.778102217182037, 8.33525921067884, 14.857367507873045, 15.487852231148752, 16.593330098736672, 13.868297742259118, 13.660329753352752, 15.667499726818455, 24.226668419376498, 20.73207389923834, 15.979297757148744, 16.57786419314723, 18.56017908742351, 22.58048495938701, 18.824825325319846, 12.83969734945605, 4.775114530517209, 0.8684638082500428, 2.3689865585296386, 1.1943042302323927, 2.730825697222064, 2.5903614538331188, 3.9631164891104547, 6.288999386372105, 11.774299240881398, 10.778457503164969, 12.77573722024118, 10.19286822888159, 5.963432856144444, 3.8922194030977066, 4.295020343795899, 3.4405528393483933, 1.4819650976888596, 1.0682397431904271, 0.8140317290540665, 0.47119374657350205, 0.4770863723129996, 0.4885394480680266, 0.8816285695760482, 0.6670399262539802, 0.08767717713189703, 0.04270075264597132, 0.10319838660859293, 0.16658941974803326, 0.07371862614226919, 0.1347328791575086, 0.07705454068679003, 0.08313629821303391, 0.7703174037798759, 0.7614595274771414, 15.986069729251248, 59.77718422489782, 79.56432188710859, 56.95375234849992, 35.97604197840537, 32.07770612932021, 21.371333945182062, 22.604882101858816, 32.15763226632149, 69.89160799211072, 90.43084836775257, 75.47590994065808, 83.89283780128726, 88.87652289482855, 45.64979530149891, 1.5513395686303417, 0.49099503565699826, 0.10613087925218767, 0.14727130231838073, 0.05733787367540983, 0.020063467353822726, 0.026830701202514674, 0.038285052493935635, 0.004623142397782255, 0.050208303221170945, 0.008544987799870151, 0.048447212639955745, 0.05627075533172297, 0.03682401173958375, 0.06402520455359932, 0.11686855912088387, 0.06986541072687796, 0.035524351236921166, 0.01998355863766084, 0.056843758455567786, 0.05400149181725518, 0.03582856858209257, 0.044788522270297816, 0.016113224987601562, 0.045587368114220525, 0.012866411256724069, 0.010845840949895642, 0.04628664168018488, 0.06338098206587377, 0.12064629189309575, 0.05266182620318667, 0.0775863895673425, 0.03244760423718441, 0.05295230759187572, 0.026863093315173062, 0.039972732699806654, 0.024410474316907987, 0.12755077422386216, 0.1310706724442782, 0.24260535205323852, 0.11981930763971423, 0.16609973634683317, 0.1200227422880069, 0.16684834214468158, 0.08726078536241286, 0.1492431053831693, 0.08158285576369494, 0.19082111787171135, 0.2043629017087721, 0.20383286079572094, 0.16116312704980373, 0.22313182602726647, 0.0856390844790205, 0.15028965809652883, 0.12049657533005362, 0.2090532750251793, 0.1509972781904282, 0.13929830353346564, 0.10946632648307471, 0.15314532744307674, 0.2505017267239671, 0.12529946397989988, 0.19225695050291478, 0.158444648728736, 0.18607406937066587, 0.29573693571071474, 0.17127937937696136, 0.17164135592118387, 0.4380860005415255, 0.19828552620545511, 0.16738840348778233, 15.608702417342895, 91.89311581273233, 142.503207114435, 101.59603980279739, 111.42765675821613, 86.98507755033432, 92.81174275182909, 60.82349215784381, 26.704521832927583, 59.926924628596154, 70.58171764496835, 88.87157286367109, 89.8781785657329, 65.80892270611179, 81.96249823416434, 77.5681963274556, 23.355133456568566, 1.7169965827657332, 0.36407890399136855, 0.20424841752936765, 0.6056614520569003, 0.5010751286341298, 0.19792878970263467, 0.3531524983625258, 0.5248141096484277, 0.24469289568162736, 0.30653485307289713, 0.3263095129401453, 0.49011688439115403, 1.0057522188271246, 0.6596332043409348, 2.8493572723480964, 3.5632909113360993, 3.258798295451749, 5.883227740564655, 10.50669216340588, 13.144724388276378, 18.449864387512207, 24.08755175528988, 20.476235343563943, 14.24647698479314, 18.040563098845944, 27.402990056622414, 24.35343942334575, 25.82716803396902, 24.529951964655233, 20.459567231516687, 28.540104781427694, 44.20006767396004, 33.38102540662212, 21.665397959370768, 30.68721413612366, 29.587709057715635, 37.676299233590406, 39.440965729375044, 46.34784775395548, 30.30223546489593, 22.947901218168198, 25.774053258280603, 11.566700935363771, 12.83686932056181, 6.148953610850919, 2.7012939270465606, 3.0830133538092337, 7.175780111743558, 5.08134622727671, 7.61311605092018, 5.953651935823503, 2.8546617877098823, 1.921058381276746, 3.37409048311172, 3.8472835046629754, 2.790175080299378, 3.754758469520077, 3.450306057929993, 1.3002484291791916, 6.150112671236839, 5.781436351037795, 1.5645079458913498, 5.1523509333210615, 0.14619738494436588, 0.18618155150644242, 0.2032533612462782, 0.5498239385985559, 0.23819582656987254, 0.5326983801299526, 0.26335219281815714, 0.4328501266577552, 0.9621897015360095, 4.673404039875154, 34.23118345199093, 80.39514264752789, 87.86346881620346, 78.66313380579795, 81.02656579786732, 93.64947472849201, 68.25654445155975, 43.453934807931226, 26.966463596590106, 54.37107555327877, 74.49229717254639, 72.16207196635585, 90.11949846821447, 100.78780404983029, 45.818590579494355, 1.0162066223640596, 0.5327871850421352, 0.3165653954830862, 0.30875853052543056, 0.3546896691043531, 0.1290871175907312, 0.09813295962709574, 0.18385223052915067, 0.10394923704405946, 0.18159279209231177, 0.12341818952512358, 0.11790205003513445, 0.2075077845684944, 0.229641413015704, 0.13736232274001645, 0.18341176061620637, 0.18256363999699393, 0.10032815393060447, 0.09126894972136906, 0.1583530705782675, 0.13008275610064307, 0.1351586401823067, 0.12165540588959572, 0.14601396817353465, 0.10673474805850176, 0.1424513835339777, 0.150346425211718, 0.1719278574831063, 0.12383959150963253, 0.2988833813898025, 0.1780131236920434, 0.14154658773012702, 0.10399386932652804, 0.1460998159863295, 0.18648856890297708, 0.19739134838023495, 0.1367694472954158], [0.02562325278807792, 0.0608752272091806, 0.03842501292726205, 0.009678774945167525, 0.10230688243022851, 0.06437291271023213, 0.05666599541361775, 0.013216968302825286, 0.0628180836417502, 0.02771612455798013, 0.11400758844589996, 0.00959411456865529, 0.024691119136649276, 0.01964899463458888, 0.0221925750825434, 0.016420684799912478, 0.019537760583203168, 0.07681818724039101, 0.04624503161457758, 0.0861289517413224, 0.034346713218837976, 0.037523951802042224, 0.03743341936159038, 0.019955131030010603, 0.08127359372954215, 0.11513931481468101, 0.03147996432568518, 0.04411744840082623, 0.01942078661804478, 0.10786833602093882, 0.04294880042453447, 0.12686695648177018, 0.12470687964871047, 10.714942562964655, 87.36767338168237, 94.78230230269894, 83.53865561946746, 79.20329124696794, 64.27515829763105, 40.82520546451692, 25.122912353084935, 41.65104481481737, 68.13052654266357, 78.18116864850445, 85.99784051218342, 51.232030160965465, 63.181503434335035, 80.1030045170938, 32.19005653935094, 0.4233121787828784, 0.5087218199285769, 0.03674808859584793, 0.21708586012884495, 0.06879748416043098, 0.08348626249860372, 0.03711775666283023, 0.00659967270386856, 0.06676720560438211, 0.08459521307339592, 0.4534351543313073, 0.34716984197016687, 1.3672897027384852, 0.5861855971236384, 1.4864451798700518, 1.147907984352881, 1.4043954471426627, 1.2460588014894918, 1.889921871404494, 8.048687904111802, 15.807196901690578, 8.421625879503067, 6.486576526395737, 12.978885596798314, 8.822187146832867, 8.593519829934644, 9.290357328230336, 5.594196617603303, 9.08207751089527, 11.868644010636116, 8.965753739879979, 13.228646439890708, 1.1662804888140772, 5.992990366874203, 17.957287257717503, 19.060255788987686, 11.72525098246913, 9.748270511627197, 11.22941436306123, 15.922943103697994, 26.625558637803604, 8.169419928904503, 3.29495519399643, 2.4636264866398228, 0.22257235201616443, 17.06554816615197, 43.41712336386404, 63.88884798172982, 68.85916956009405, 72.42072874499907, 71.31370252178561, 66.3651304860269, 58.50923884299494, 55.48867256410661, 47.629999960622484, 39.937282839129054, 31.08685854942568, 20.964699868232977, 11.486324706385213, 4.675530454804821, 1.8021338336890744, 0.6485719365939018, 0.6555597616299507, 0.35555053742662557, 1.5574185069530242, 0.16866829126111924, 0.169211033911955, 0.20780527183125097, 0.07198315354124193, 0.08526295829083651, 0.18765043317069932, 0.1117328895376094, 0.06306495164490997, 0.23997198610055834, 0.24613045967153965, 0.5185221988827952, 2.740883144640154, 42.8610489445348, 81.02594606338009, 61.034296020384765, 51.80547675778789, 65.42976287103468, 70.97340553037583, 41.95488337547549, 25.04287442853374, 24.480612470257668, 29.789903317728353, 46.03279905934488, 65.98253465467884, 70.56971519224106, 38.213922823629076, 3.421447219387178, 0.23508907956702096, 0.12685351163869904, 0.0812286090466284, 0.03489438564546647, 0.03835580454418256, 0.07565537302364266, 0.07078983370334872, 0.07250918781444912, 0.041921166252465024, 0.013950440991339425, 0.07855270989239216, 0.0497016777855254, 0.06731063007347046, 0.04194412590755571, 0.05916337692929853, 0.03228626612033094, 0.03399446982169344, 0.023789483445486235, 0.08524271058699778, 0.029491489272444483, 0.02473892493834419, 0.0426928925838682, 0.077599183235678, 0.014620624283599037, 0.02350416548940684, 0.031725867058060346, 0.03994307743625776, 0.03455299388376936, 0.07532149658448274, 0.04422570045496668, 0.04266498017034704, 0.009703618218942035, 0.045475990421349005, 0.0043924005454285975, 0.02320833297656669, 0.0607100892962227, 0.02697980106477776, 0.03345147053140306, 0.01602775255788959, 0.08762794066100352, 0.07293644271069959, 0.046273779063936205, 0.09446178968515127, 0.06921109503075, 0.029032893719211705, 0.03731233150427861, 0.07761601418737443, 0.060424403617939645, 0.07908805213387936, 0.037088434647528395, 0.03914269558604687, 0.0397999070945286, 0.07203564588581363, 0.02745341768698587, 0.025290690189708146, 0.048064999883213354, 0.026221737911504124, 0.02773025313452367, 0.054712275854281844, 0.08240340487851251, 0.021074299302492893, 0.022016033950832584, 0.06411112131430738, 0.03515568674511967, 0.04654414298373365, 0.10297229874037928, 0.1301868674495528, 0.023082926298581788, 19.614494539076283, 109.57472908881404, 107.3016292818131, 99.71582812647667, 106.82721860947149, 88.0870125370641, 65.966900087172, 31.82104975946488, 27.729445003694106, 36.929730984472464, 59.02427350321124, 65.57576917832898, 50.864523687670314, 73.28163408464002, 85.61777853196668, 27.95737981796265, 0.2847426853352978, 0.5244642219716503, 0.08125120864039467, 0.27982452343548503, 0.09005147513122329, 0.14750158834841945, 0.03099744576179693, 0.11737710360677973, 0.3081734538558991, 0.5607842666006858, 1.5374581780164474, 1.121592557718677, 2.811605440032098, 3.168917428101263, 1.7991263563594513, 2.0018240280689734, 3.8380504904254793, 2.047451857116915, 0.4116703083197917, 1.999228767329647, 2.089571616341991, 1.9128146623411488, 2.4272710181051687, 2.4906418112016495, 0.7304878184391607, 2.118352988073903, 3.7693151206739492, 6.48481636278091, 9.904360252041972, 12.924498011988979, 14.088937928599698, 13.46701377822507, 9.686353937272104, 18.064962202502837, 26.258183563909224, 22.156225712068622, 14.023072508073623, 11.19837272551752, 12.709417785367659, 20.139227259543635, 13.738329026006884, 3.474644364849214, 1.1597164023307063, 1.7713167518377306, 0.9397930291391189, 25.07732460575719, 57.19252271036948, 78.80012650643626, 83.59652626898982, 83.96272659301758, 84.39570919159921, 82.22690520748016, 75.76247830544749, 73.56464878205331, 66.89879248219152, 59.065783946744865, 50.237454368222146, 37.41177066679924, 24.44573671587052, 13.541800629708076, 8.157231163594032, 2.925081080006015, 1.6319588619855143, 0.5030634638763244, 0.8897029524368625, 0.445432017647451, 0.00950915446024268, 0.20218678299457798, 0.021090038578897234, 0.033537559661894076, 0.07750337627986748, 0.1558309865574683, 0.1496383148215471, 0.15786429116081807, 0.19624282936415366, 0.7653185881433949, 0.5094156197963223, 35.13746276978524, 83.14793263712238, 69.87584790875836, 43.642643959291526, 51.170613688807336, 44.80920783935055, 9.498998003621256, 18.20415927517799, 36.64723011755174, 57.06675975553451, 73.61801655061784, 85.31092366864605, 83.08838321316628, 58.64840845907889, 7.2934217991367465, 0.2821949220472767, 0.0722831612332694, 0.033395021342702454, 0.010147736625625722, 0.02780465942416941, 0.1022384784394695, 0.0455198910898499, 0.07559646852314472, 0.03592022334135348, 0.01441318108024256, 0.12364381007970342, 0.019728820996298906, 0.08011215081017825, 0.03555514414103762, 0.030917312964917194, 0.019213184451444015, 0.07339719097099959, 0.019821711072337725, 0.031588337038673704, 0.057036797290727984, 0.03772711831956141, 0.07994541943433785, 0.06626023925961026, 0.027209960690308965, 0.014289758569981544, 0.031590428458706986, 0.02049908984542614, 0.022962635172711268, 0.05700056133190951, 0.04095376957388174, 0.043032200586411266, 0.04948856744674906, 0.09141777762241902, 0.019728713743989507, 0.0435683740332963, 0.19847364675614143, 0.07925702048645866, 0.0900625374408499, 0.07569762277266673, 0.1788260195884974, 0.20469717651365266, 0.1806358257008176, 0.16721505311227616, 0.23020217405451884, 0.13147979403936094, 0.26115431720691346, 0.24836135367231987, 0.10039704821763501, 0.22737250573212103, 0.13205331810299428, 0.16658931249572387, 0.16542881186450684, 0.172063930020217, 0.1329689463900943, 0.231426443844553, 0.1966242645416529, 0.14583137877766164, 0.19230794131515488, 0.12388063083973624, 0.20906504213569627, 0.26103134477330797, 0.09138505034629377, 0.22766315949059304, 0.1449882836952325, 0.1479972778789459, 0.2045457362527809, 0.1591276620785075, 0.18016880318041772, 20.72342899537856, 123.6235607824018, 118.86899702010618, 103.68970686389555, 104.43953852499686, 82.19397298751339, 49.749821386029645, 31.501751176772583, 55.31267189210462, 92.50662942086497, 103.00132305391374, 113.47523596978958, 74.39472429213986, 82.93831333037346, 101.09114446947652, 47.51714160365444, 1.444528280727325, 0.9345686159306957, 0.15253490858501004, 0.5935161392534933, 0.2731606310173389, 0.3863370676915492, 0.19199211390749102, 0.2304182721361999, 0.3085088165056321, 0.33242657179794005, 0.7291401778498005, 0.8945680397652811, 3.0382041969606957, 3.8418255265681975, 2.759847559275166, 5.064784019224105, 8.246656790856393, 7.053929721155475, 6.9295989217296725, 14.975302392436614, 34.125397128443566, 24.978845657840854, 20.939467260914466, 30.525126111122873, 26.63585093713576, 23.595564942206106, 28.35167411834963, 16.085873457693285, 23.474393121657833, 29.410886649162542, 22.912756781424246, 30.19795729267982, 15.412805522641829, 22.07201046328391, 35.903948814638206, 33.06980494529971, 26.409794938179758, 18.88665560753115, 20.334204358439294, 31.695984986520585, 52.377723109337595, 29.385259843641713, 14.786746213513037, 8.338955063973705, 0.6585728160796628, 19.622227491871005, 54.40897741625386, 84.56632444935461, 93.67757458840647, 98.37254970304429, 101.45565032958986, 97.55053858603202, 89.34544224892893, 85.6541310587237, 76.65961065599996, 62.7996567756899, 50.55671176602764, 34.911620540003625, 21.771235273730372, 11.584187842184498, 7.101183985510181, 2.0756913288947074, 1.9147575838911919, 0.8969389899603782, 2.8920542328588428, 0.5692164431656561, 0.9395312722171507, 0.6735991710616697, 0.3086770800573211, 0.16394935818689485, 0.35544064977476675, 0.2897361689998258, 0.30011371859619695, 0.30142011301171395, 0.39237503563204124, 1.361257097413463, 4.701099405365606, 54.3703773713881, 96.6856324288153, 81.57674881719774, 75.99247040287142, 94.10796057793402, 96.40346496335923, 57.66221869376398, 34.36411257713072, 29.387044522070116, 41.32254239051573, 64.61458060049242, 82.27659379282306, 98.83773496074062, 62.590837632456136, 6.102604923709747, 0.4062054354336954, 0.15515811621181427, 0.17025320460238766, 0.3386923436435961, 0.1308559226773439, 0.205782845676426, 0.1318478992869777, 0.18784059151526422, 0.10719010305981483, 0.07050441998627878, 0.1770919029630961, 0.14458604156970978, 0.10810235289916878, 0.12145629963807522, 0.21264106395744511, 0.13220792996787256, 0.15390505683758568, 0.13681251675851885, 0.16195422008393273, 0.1264712567471208, 0.14264829877403476, 0.21661077836348167, 0.24867057740207643, 0.14773264046638243, 0.1714609728585328, 0.11260122721714359, 0.09903467575749082, 0.09650988744631891, 0.20501259023383742, 0.15492802936463587, 0.14265966751883108, 0.11513203697940035, 0.2824987525180463, 0.11224125016240344, 0.15730489375850848], [0.052401321834974715, 0.13981866109515392, 0.06659686595441834, 0.1796294466382073, 0.05292327285954549, 0.09225468271441999, 0.023356253063426386, 0.032171238018500234, 0.034419526045601216, 0.07978947457647131, 0.05078116078831015, 0.12838941833545126, 0.1496206028687377, 0.10865376000442814, 0.207367651765385, 0.0958889731836896, 0.14177590848938112, 0.12720734466828648, 0.1934517412296226, 0.2220437666701694, 0.061739807227446195, 0.057500606072285486, 0.0836582875420009, 0.16582708565458176, 0.04810976623106868, 0.06599466721977919, 0.066269570210528, 0.03493932053266514, 0.03783780270286145, 0.11045301708603099, 0.04050132570668094, 0.27416037575852487, 12.320582443667996, 98.50540822552097, 99.12977895429059, 93.94611573988392, 74.13524381576046, 61.397370215385195, 43.58766801895634, 34.52287050985521, 80.22937543930547, 86.43759312168245, 66.12043734519713, 58.44062089920045, 66.57744053871401, 107.13988642538749, 77.93390243284165, 16.107171927728963, 0.2693072394017251, 0.10623530469714634, 0.8119343641784884, 0.01208862133940021, 0.0657347642305878, 0.01634260128823019, 0.11057975867222394, 0.06021946360687575, 0.22528937477017605, 0.26222383723624293, 1.7266818953137246, 2.1597920935000143, 0.23959439668443896, 1.8992428938227317, 2.48500021715318, 0.21281361760151005, 1.912772742009932, 3.220971202658069, 5.838728450959729, 4.828980930389897, 7.597993352720815, 4.696617116851192, 6.433743671063454, 4.434672411411039, 5.320632380823936, 9.652069480188432, 6.145389156956827, 6.254812007950199, 11.670501559011399, 11.720473535599249, 8.731094021951, 6.716580881226448, 11.340460585009668, 17.112520510150542, 14.58455881764812, 16.2676517809591, 17.71358451535625, 14.866129102245456, 12.784572359054321, 8.467922595239456, 2.7077761340525845, 1.6336131216056886, 0.9090982149204901, 1.7510617548419585, 5.630239767412986, 50.135476666112105, 68.21630093359178, 59.39889515599897, 54.73380065733387, 50.91454175210769, 55.74696456232379, 59.96313595002698, 65.10288430798438, 68.09961042096539, 63.28307320994716, 60.65816425508069, 59.731006160859145, 59.97604839263424, 58.45651826550884, 54.278146759156265, 47.55601621443226, 38.44856685207736, 30.938577267431448, 19.878709316253662, 8.925172898077196, 3.904847719015614, 2.2700624215987424, 0.8104199615697708, 0.2796535938978195, 0.1753721887906713, 0.09665822505109734, 0.03726061673895006, 0.08959608948639325, 0.07411269410963982, 0.31318752996383176, 0.08010547818435777, 0.09701469342314428, 0.3695849924077911, 0.2630015390534555, 10.15720211690472, 58.869304580073205, 53.52528702828192, 24.907758582022883, 53.53272776449881, 94.05358868260538, 77.63323706965294, 44.49253920585879, 17.52333191133315, 34.280201312034364, 49.639979331724106, 54.69093307372063, 73.06103998614897, 52.611963133658136, 10.483451139542366, 0.3560538878363948, 0.09157763718957863, 0.1189218432972989, 0.08478064465546802, 0.1585253484306797, 0.025062466851405563, 0.018291184228033792, 0.08455988875920735, 0.07292487478304295, 0.0424659735102567, 0.07498896079919032, 0.09438807670507701, 0.00764108065801162, 0.01860163561368902, 0.110715180034599, 0.014105851502878772, 0.05033045594069747, 0.05302130913121566, 0.028798095431298982, 0.0905866411724879, 0.12709883597469138, 0.10099908607381006, 0.15090570003995973, 0.1521811598250943, 0.12336914457621113, 0.01399486834528826, 0.08701534611323188, 0.08124334857829156, 0.12625952536660817, 0.10458486785571422, 0.03868375912368779, 0.0827959253482761, 0.026622842396459272, 0.017288336830754435, 0.0728441137940653, 0.10809678343995925, 0.017468786926098892, 0.1497593720353419, 0.017765483203073664, 0.044025318667052254, 0.041899551081681446, 0.027291441801935438, 0.05814238856997221, 0.03139822082894464, 0.051019414132761384, 0.09568802066027157, 0.07138670812691413, 0.07387444076518859, 0.17063117706246916, 0.08963740460814969, 0.16917217793243547, 0.020434311365768797, 0.2007647246242531, 0.12009080920007922, 0.10697932162832831, 0.11613902891235006, 0.07891813383227395, 0.056431174143067295, 0.0948409649032739, 0.06002495005246132, 0.0771849365123818, 0.05172511900685007, 0.032965395404326345, 0.15110831497417343, 0.11056407685241393, 0.24686706853249382, 22.922982400463475, 117.79187494708647, 110.27877100052373, 106.81700475754278, 99.18393119688957, 82.99556424540859, 73.13623182235226, 31.005641952637706, 34.91758646503572, 64.00353416319817, 60.13042503787626, 58.287001271401685, 72.55936099636939, 112.2259767593876, 70.21050453186035, 10.09507961811558, 0.1785898500032002, 0.08042574890198247, 0.5686706821283987, 0.026274837380755815, 0.09314205767887254, 0.10592438025219787, 0.23189680650830272, 0.33436118895488404, 1.0348459092840072, 1.7816966916284256, 4.4604458155170565, 4.969390015448294, 0.9598568718760245, 2.6780237305548886, 1.4733665268267355, 0.35268052691413515, 0.05921388893658596, 0.35831020063450264, 0.3766019900719966, 0.7741529915121295, 0.79930090014973, 0.5346388501986381, 1.2931782343695242, 1.4928893889150312, 1.7914812891714036, 1.080987446250454, 0.9507501089284498, 2.2240601287734125, 1.9477622451320773, 3.947841063622506, 5.4347164784708335, 7.987111105072883, 11.012030724556217, 20.900516163918283, 16.191969648484264, 20.4928465812437, 30.3100037190222, 28.588457799726918, 22.36055962501034, 14.053142378407141, 5.403147282138948, 2.8906191356720465, 0.9306961334040089, 0.391412767912111, 11.39758990656945, 66.09040767915788, 76.13595854851508, 65.54506486462009, 58.850943965296594, 57.74502777284192, 63.89923049557594, 72.57127715695289, 80.39010632422664, 81.57092801986202, 80.28893270800191, 77.55486026886972, 73.7045205023981, 72.70526532203921, 72.9504213025493, 73.87100942673223, 69.44032361430507, 62.886054823475504, 55.92036470290154, 40.0691411572118, 21.51421804581919, 8.89061975863672, 6.220413802131531, 1.6584559433883237, 0.1716235520378236, 0.24601148621689892, 0.19121243558343382, 0.058483079361218604, 0.017857589954209906, 0.07946833817949218, 0.24032106172413598, 0.027790293360369343, 0.03711572652983089, 0.18187203114071201, 0.5791555453212031, 5.775797453618819, 54.64856363111927, 63.82054382754911, 28.06508614170936, 52.07104083030455, 82.12293101895241, 39.70470589976157, 9.330777352856053, 16.111383572701488, 55.58208380976031, 77.29462669741723, 76.72668318594657, 83.06962643900226, 70.73447827369937, 19.810869962938373, 0.27922832316929297, 0.08605271833197725, 0.12397364157462314, 0.041126307896188194, 0.10972231476297302, 0.1495459859049128, 0.0392680888574931, 0.06410466702354532, 0.062393345344331, 0.09919342449716023, 0.12567717597008715, 0.042822729165275256, 0.0433698385172794, 0.05108730484461112, 0.020989257797238328, 0.04755888772647708, 0.08809690138385182, 0.029996775969442342, 0.04575626368844702, 0.019954179165764682, 0.05096841182920241, 0.046696142488790136, 0.14765256895653664, 0.10283022773482146, 0.05759453611268152, 0.04413672700344075, 0.007518415138380783, 0.024432258027034904, 0.09522456810959885, 0.08557901552487766, 0.11502831633533202, 0.1811563671236077, 0.031195477575003624, 0.0916663654929688, 0.2907859852477428, 0.2255466577386664, 0.18490111214980004, 0.22806986024783504, 0.2503700208880248, 0.20412104775107678, 0.14034988178360847, 0.1586561962481468, 0.13288743463495087, 0.22223823042886875, 0.33805805348580886, 0.19272182797712667, 0.28699522898081814, 0.1528301129057523, 0.4279725674179293, 0.3264379399197717, 0.30439400504673686, 0.25658648731487416, 0.4051355170386453, 0.2738677301714497, 0.37852931407190143, 0.22327267895302466, 0.1936314654566588, 0.2928567515505899, 0.20795775397169977, 0.2200564733075519, 0.16966631996535486, 0.1999013588553475, 0.09506070956347451, 0.19510371790778255, 0.1698904160049654, 0.3050408590464823, 29.207931449336392, 135.55229648467034, 118.42717339915615, 111.81824637997536, 93.22193637970956, 73.5563176678073, 55.98813933710898, 47.03520782532231, 101.39100182440974, 111.44628017179429, 91.38128572894682, 83.73214614006781, 83.40608735238352, 123.46054707804035, 92.44636612553751, 22.126535331049276, 0.9805850660608662, 0.18714944231173686, 1.089315741292892, 0.22387874643168143, 0.23422179142794303, 0.1828742426850142, 0.3639887814079562, 0.21194351025887076, 0.49325340157074316, 1.0366665019143013, 4.218647383874463, 6.032360176886282, 2.7930241919332937, 6.470266330626703, 7.990568184083509, 4.735315711267533, 7.371921664284122, 7.197178602218629, 13.160299139638102, 14.727146779337238, 18.81763562079399, 14.387349890124414, 19.948364726958737, 17.339892464299357, 15.73807885569911, 23.31622354445919, 19.267529518373554, 17.155362598357662, 24.888356577965524, 26.470474004745487, 24.19450302277842, 22.917800949465846, 30.889608437015166, 35.47104074108985, 26.77987644749303, 28.837789143285445, 39.23131896603493, 33.10497683863486, 27.20718925999057, 17.85292083217252, 7.357397127536036, 7.434024551222402, 3.53970643493437, 3.650248387167531, 9.200185960338963, 70.11762280617991, 90.68924626996441, 78.62077220793694, 71.50893457474248, 64.83588072561449, 69.74230689387169, 72.54229868611982, 83.17924884057815, 84.03048161537417, 84.27222513383435, 83.38645196730091, 86.5432539293843, 88.79956599204772, 90.74790139352122, 88.57135465068203, 83.82545932646721, 72.06485994400518, 62.53347296868602, 39.73627313490837, 16.304724062642745, 4.942952750190612, 5.0174571910212125, 1.915791496153801, 0.4571471261160989, 0.7132166419779101, 0.35586098689706097, 0.17345326111441658, 0.20027171640146166, 0.17174463989513536, 0.6055927492918507, 0.13976872748424932, 0.18583929406539088, 0.6984700010188165, 0.5077289393351925, 15.990224499856273, 75.05788726191368, 69.46057873387491, 34.61269670917142, 71.94955010567942, 122.51042350645989, 112.79324562318864, 59.365139238296024, 22.132813084510065, 43.00508229963241, 65.53823209577992, 71.66817495899816, 95.4052060650241, 80.25055623823597, 21.306173570694465, 0.3941748213143118, 0.16632629918955988, 0.2736881591619984, 0.24795073054490552, 0.24970160917409007, 0.36536752516704224, 0.12132002791810421, 0.2198390728763996, 0.20113590954532548, 0.23212362982092366, 0.19378880459454753, 0.2013095510342429, 0.12463394807831896, 0.0956322571202632, 0.1869315669060715, 0.2492880442690465, 0.15331461755258424, 0.22005147841428557, 0.11160432466215665, 0.20834191642220945, 0.269743786944497, 0.33643765495188777, 0.23766930966127306, 0.3049809203272866, 0.3211711467273774, 0.24590870786097743, 0.20408358605157947, 0.24447194060250638, 0.24328401402360011, 0.14670168530316124, 0.19034317093751124, 0.22999274093777905, 0.1560865381672498, 0.16528051256412463], [0.10969534846803836, 0.10250523025470396, 0.05512736527429474, 0.045568384455456856, 0.03355125731398021, 0.023135972141678778, 0.036102084953698425, 0.04814469600997625, 0.036134000176623944, 0.0938795245583019, 0.03862098204873262, 0.023745035024119482, 0.018259684607807188, 0.08140561366153341, 0.15594209995000594, 0.08861843872094348, 0.20498223783027744, 0.051096666439045826, 0.07612190524777097, 0.013825752520783535, 0.044362592706156355, 0.14093888082331227, 0.054640106541375, 0.051917939506951845, 0.18178086667772264, 0.1192004694753597, 0.09453444546389003, 0.05069240567184264, 0.11549364580141923, 0.02614790044214216, 0.3470368491065118, 28.807641806141024, 91.03974926856257, 84.44836308879238, 88.45391888772288, 80.54100774949598, 54.7252106666565, 46.152956947203606, 32.455842225782334, 71.3881020392141, 90.97200993568667, 63.24022523818478, 68.81962422401675, 101.06866144364881, 119.44738188097556, 33.03222863904892, 0.10186625929969935, 0.321494190683288, 0.030085356800907084, 0.04197782228490518, 0.46042052788599847, 0.02594063726944789, 0.11241537428671315, 0.11120200592784152, 0.28904509640509085, 0.054860755185326265, 0.29310707844072775, 0.6608974945641334, 1.6053537928288983, 3.8903427941183892, 1.6038614535524, 2.648389978754905, 4.641992718942704, 1.770464494343727, 2.4133475845859897, 3.804946666763675, 1.8062800241093484, 0.46489215245650667, 1.4359728559370966, 1.7272430393965015, 1.0047463147390274, 1.3205959695962168, 1.4274068897770298, 0.6822026448865092, 0.7120770095817505, 1.0663821331916317, 2.334513337381425, 3.048187609641783, 5.58577528884334, 13.172547721093702, 8.85820136916253, 8.920821028371012, 3.795376083543224, 13.29258107369946, 24.363049230267926, 14.234919721080413, 10.158101320266724, 8.09991111678462, 16.738040062689013, 0.34732600133265223, 0.3232713920935508, 19.580369918577134, 80.511166357225, 57.24293301182409, 49.35113599223476, 50.18937787702007, 53.508381612839244, 62.56010193978587, 73.25837442951818, 87.13309995589718, 99.33283221337103, 100.95032353555003, 103.89098721165811, 97.75318391861455, 92.30021861291702, 82.86531802146666, 78.339153874305, 72.19478453359297, 67.23068775669222, 63.42809107995803, 62.414676143277084, 62.69843216865294, 59.257317204629224, 49.59535452627367, 29.25500773614453, 12.604661083990528, 3.860155742975974, 1.2507010491624957, 0.36673824032468183, 0.19206351330203397, 0.19986055701250033, 0.24087230795093123, 0.22022678997487793, 0.10622464075324037, 0.1552780855807566, 0.06022255477165023, 0.034166628930477366, 1.0880621763006335, 2.629058087064374, 28.19832709527785, 74.75583337968396, 88.24162452451645, 98.97281354473483, 131.71320607585292, 94.44147186894571, 65.75753965685445, 22.9902647772143, 26.964396507509296, 43.181486975762155, 54.072571416055005, 68.08310508728027, 69.55755541401525, 24.61805428228071, 0.16559623271947907, 0.04323971465290074, 0.19330891179701976, 0.06209685016543635, 0.3708964123600914, 0.049830296287132855, 0.19619589881791225, 0.056734778617899266, 0.048944480311606205, 0.07978593525026115, 0.17258719871601752, 0.1767356567565472, 0.06336955969492275, 0.05737321331135689, 0.09275994068312068, 0.05490632975594171, 0.057078706130625746, 0.04383246752343351, 0.02888644835160625, 0.008452628239718898, 0.015557765277222762, 0.07018293884973373, 0.0772973139499945, 0.08746046617987656, 0.12837128503428352, 0.08918960323377002, 0.2752873523821754, 0.07152806667070236, 0.05070718350790201, 0.026911557952482856, 0.04820170061242196, 0.10499951294473103, 0.10167135121000391, 0.056850454064026, 0.14838072020680676, 0.06113215011634654, 0.010678508195034679, 0.05909668131461067, 0.03208801405684602, 0.0711739425277037, 0.06795860256158537, 0.033346773125231266, 0.030451623437505577, 0.03730596914406746, 0.017341386504291047, 0.1133989622335761, 0.057276372136848594, 0.05802638370603804, 0.0643238677613197, 0.10768056020981844, 0.04956332230640035, 0.05291344778191659, 0.08809228953454765, 0.019398667744450995, 0.07540885359048843, 0.06761901110651032, 0.055158207974126267, 0.0872219753481688, 0.13950002980568718, 0.11790054850280286, 0.07602710952802051, 0.03773174549062406, 0.025087276608833385, 0.3134423920944814, 45.73937046912409, 112.75040549616661, 95.83502723324685, 109.96347519659228, 110.1725139925557, 90.7819789455783, 74.52498620556247, 28.200943316182784, 33.23804716910086, 81.50766803372292, 61.351392192225305, 66.30583993850216, 114.96061401982462, 124.50770224294357, 26.57066506724204, 0.4347150604571066, 0.30444073641011793, 0.089751789196124, 0.06280194983006486, 0.3045256495956452, 0.015667376179818907, 0.1096127258854047, 0.4195629138379328, 1.4572193545679895, 1.1557577502342964, 3.399317206874971, 2.2477811526867653, 1.791638429126432, 1.1868257412026006, 0.9314207300063103, 1.524044162323398, 1.325346572745231, 0.9952777131430566, 2.4118325691069327, 1.9552703970862975, 1.5733381817417762, 1.1014613605314687, 1.7620578744719106, 1.7083935992371653, 1.056075370119464, 1.3108456927922465, 0.9276634058164013, 0.4181856103241444, 0.8063030050646874, 0.5710516833970624, 0.7919685194088567, 0.8807191925664103, 3.4576305939305216, 8.798080259753812, 12.400717446880957, 10.397326677076279, 4.348113056152098, 12.058549484898968, 33.48325806279337, 17.387492387525498, 16.367301556371874, 10.044554587333433, 7.912992037111714, 0.7421603017757017, 0.3724719487851666, 28.031165484459173, 97.87025882351784, 64.88734614464545, 60.04900055546915, 60.96946708617672, 67.84094579758184, 76.6857728650493, 85.33710941191643, 92.92336556219286, 105.04486222420971, 107.43036147086852, 110.49341878583355, 106.9827013631021, 102.74457254717427, 95.85717293523973, 92.86404363570675, 83.57194869749009, 81.61459968936059, 77.9742322429534, 79.38641102083268, 79.15419101715088, 79.6174935371645, 74.67092191019367, 55.351793612203295, 27.299827798720333, 9.891442906471992, 2.976027765581685, 0.40924432236821423, 0.32079343473719013, 0.08957236374337828, 0.10667530729645684, 0.09891212467224368, 0.08949702665690454, 0.1061819619949787, 0.09224751979232797, 0.16276838768634105, 0.863230447134664, 0.386339457885873, 23.77484275448707, 71.15898070796844, 82.45579904125583, 102.66816477621757, 139.01044630235242, 78.65585388675814, 26.25407291996864, 13.808241351958245, 40.56547003407633, 68.66398457557925, 74.4021297270252, 83.03416821264452, 87.4471249118928, 40.77865869768205, 0.20341238577760037, 0.037783759030243086, 0.15904474072158337, 0.07639853959722866, 0.2144325452466165, 0.06272509588950104, 0.15229238046994134, 0.03455524618226675, 0.1081885684341673, 0.04999477536447587, 0.15350066966587497, 0.14150590846134772, 0.08582613250661282, 0.05310688881323703, 0.14944412685450048, 0.02941407800291575, 0.06573137812196247, 0.04344309567503872, 0.03460201585004407, 0.04246419235583275, 0.014171719742608408, 0.03667943945695316, 0.03394533677266971, 0.08281575170375648, 0.06437775438591357, 0.067700277713518, 0.13523351761602587, 0.044398342199142904, 0.06642742262732598, 0.05045545850730231, 0.07746370824714822, 0.07510960432550601, 0.06613954210713988, 0.26216895469734747, 0.2883630636478624, 0.23884120968080338, 0.16865039544720806, 0.18581079559460764, 0.09228622255426261, 0.29046171555115335, 0.20566817763591969, 0.09876620790530598, 0.27453465567481133, 0.287773666242438, 0.13257886974080918, 0.1478540347588639, 0.21132481765122185, 0.3172489604161632, 0.12121707336196016, 0.18202937027860075, 0.24202612829544853, 0.27627198986949464, 0.1819047124515618, 0.07263532419118189, 0.2671160134336641, 0.20356252368900085, 0.11849161597990221, 0.39924589436381097, 0.2902101935638536, 0.32432415011909704, 0.29106238977082316, 0.17778698985855426, 0.09013726931786345, 0.43535786951261185, 52.3679603299787, 129.9634288972424, 105.65001333913496, 113.6472083676246, 103.04812477480982, 70.95002820414882, 60.60616931607647, 41.99601727147257, 96.90984295260523, 123.78368762231644, 85.09204756829047, 89.20553914962277, 120.55430612256451, 142.92015506375222, 44.22364111869566, 0.6812853618494926, 0.5943488461836692, 0.18757429935278433, 0.2607886174753789, 0.5082069169129095, 0.08675570359393474, 0.1291063923629061, 0.32375154536097284, 0.5453911087205333, 0.5891558119366246, 1.6288550414385337, 1.8545811935778589, 6.309548193408597, 8.971818704758922, 7.509340922678671, 15.641588549460135, 9.851641635740958, 9.074480860464035, 10.113151938684526, 9.940759847241065, 4.6737889224483125, 1.0606915095160085, 3.235358456450124, 3.079237827370244, 2.056077761996177, 2.189313812601951, 2.7558727274017953, 1.7654939933169274, 2.9738736489126762, 5.100683512226229, 8.264848743715595, 11.060974059566375, 16.348887989597937, 32.56169522962263, 19.011332065828388, 19.78112270755153, 10.790702162250396, 21.38274019764316, 42.33859708232265, 27.089337725793165, 19.60928367030236, 17.473886512940933, 33.26700602808307, 4.046159194361779, 0.7222467348460229, 27.260388366637695, 104.23373960679578, 78.29232077444755, 68.69045272950204, 70.14783290124709, 74.35197045726161, 82.03419131617393, 90.26302583755987, 98.6187647235009, 107.78950937332647, 107.23907532230501, 109.19389832404353, 104.63746916863226, 100.2172717740459, 93.62711721850981, 92.95636054008239, 89.65853368082355, 88.44685862141272, 88.67717235319077, 90.73607152508151, 95.17563758357879, 97.64149050558768, 88.53957560754593, 56.9502418271957, 21.49426494875262, 5.949564335807677, 2.2080002292510006, 1.3256951733942957, 0.6123978163926833, 0.47364783263014215, 0.2590321923696226, 0.2198364834992155, 0.16380321925445912, 0.2720103653207902, 0.348470781839663, 0.19376986690105932, 1.5934024534879194, 4.781545256414722, 42.886791459975704, 95.39586297927364, 96.03123987874677, 103.43595304796773, 146.79792004246866, 131.2680249060354, 91.39495126662716, 32.44182367478648, 33.22397762729276, 57.815018546196725, 72.9517392189272, 89.53087622119536, 100.85628078829859, 41.00188470655873, 0.3486286878826157, 0.14479873822100703, 0.26173887293665643, 0.19875711460988368, 0.3519501693306431, 0.1648791131353186, 0.2772866580034456, 0.2898506225357133, 0.1808216939530065, 0.1646676575464587, 0.1819251823208986, 0.25694314720890216, 0.25220938267246373, 0.16645578337052178, 0.28260281790168057, 0.10739673229475176, 0.2489637286071816, 0.12116521687036562, 0.14538643491123954, 0.13076523318886757, 0.17484679037044126, 0.14268894739929708, 0.18002917599533835, 0.23113643359993738, 0.18905589807658427, 0.14780152709253375, 0.3588797410409297, 0.20127052651538005, 0.23107871653572207, 0.15813761601044288, 0.13075942624240153, 0.14406021414024217, 0.2969988357395895], [0.057384356060215545, 0.03822332878987636, 0.03846533213471694, 0.08182461012996013, 0.05271352181631712, 0.10646899981844811, 0.03812704302911316, 0.10899822377870161, 0.16240582891529606, 0.14922019935423328, 0.12402071767757017, 0.21124304542618416, 0.03875643788506428, 0.022933313157409433, 0.00806659366184425, 0.011630535234637078, 0.03269036217863041, 0.0952836181668024, 0.028733726808681127, 0.05382489705938966, 0.01211153694443525, 0.049925107328641805, 0.12663336861277782, 0.049224673139472166, 0.03947102937907462, 0.109730328042661, 0.028555383455128442, 0.009716951021654232, 0.07728507952584375, 0.42243506939661124, 43.69095187033377, 103.96791273547758, 97.27005773975004, 89.42260311495873, 90.9488130384876, 54.18687712761664, 32.390901504024384, 40.31401472706949, 82.71127870005947, 91.33127550924979, 51.14625577003726, 80.00873427237235, 130.34203960049538, 85.89159919369607, 9.149564831487595, 0.22177785755165164, 0.054672860630577615, 0.26660561501499147, 0.04681597396190609, 0.2192906152096487, 0.35230232462767636, 0.1771634708969824, 0.24551869249872624, 0.08872469511604117, 0.03985280546570017, 2.430341253357549, 3.047427405272761, 2.8456731861637485, 6.670334175709756, 5.637630493410173, 1.4722980486769832, 1.8745069566272923, 1.7970799822961132, 5.277011702137609, 9.849232319862613, 14.479797213308274, 19.137601006415583, 21.9650121273533, 19.01149876656071, 22.75485588658241, 21.866786172313077, 18.250964918444236, 17.791102317071733, 11.957304285418603, 6.053157073836173, 1.8364252774946153, 0.39584807991500826, 0.23179537646712797, 0.4593197514693584, 4.401766667442938, 10.568115499711807, 11.743039911793126, 6.740049892856229, 3.384931669119866, 15.625711775595143, 10.955259319274656, 7.546453898952854, 3.4620185004126642, 1.0057172852177774, 0.28807161315794916, 12.261936145444071, 92.03325425424885, 62.0024585723877, 61.86593263379989, 75.11829960730769, 86.10452898087041, 89.40402676982265, 90.5273308292512, 93.38127090084939, 93.38192201429798, 94.1817403608753, 95.31765091803767, 97.13538708225374, 101.40890352187618, 106.66368715224728, 108.31000005045246, 107.12438521846649, 100.40311367281022, 98.47704164443478, 89.25241931792229, 82.38754980025753, 75.98333912511026, 66.06108403974964, 61.938382733252745, 65.46414244559504, 58.68309790088285, 42.06514120101929, 20.980958092597223, 4.836828612512158, 1.0560587000462318, 0.16329753993740007, 0.34977604244505206, 0.0943286206212736, 0.11044020809593702, 0.30828499625767436, 0.1646537300679953, 0.0904725476979248, 0.1496997397513159, 0.19065948864144666, 0.5107476321920272, 4.774836532531246, 52.67315995308661, 80.78453986875473, 72.04211019700574, 53.37512300860498, 74.67933147184311, 70.5695112289921, 31.11492899156386, 27.566129276829383, 28.609250284010365, 51.49033784866334, 68.23483805502615, 81.39007537595688, 25.702320952569288, 0.17131710154635293, 0.08196773067597421, 0.07055066105338835, 0.08720189618367342, 0.12833979115971636, 0.013379571422363722, 0.05120011512190104, 0.01755198790511537, 0.03822152082237505, 0.0108231216548912, 0.028298389684829502, 0.09923535248925609, 0.14255250713998271, 0.15954962330720118, 0.05853174892704814, 0.04758371663610301, 0.04611605305164572, 0.022377470403068492, 0.037217133588367896, 0.08474277692937082, 0.07833708678522418, 0.06510949092766931, 0.046454399613843816, 0.02883977636003927, 0.08311181404297391, 0.051767747969396656, 0.053891619487154874, 0.07116274998312996, 0.05444607562235287, 0.07983839695131587, 0.04605718685554401, 0.03380661740178063, 0.09265476447199622, 0.05096037173643709, 0.052331017946163495, 0.0876280096089167, 0.04144467105488143, 0.12167413673934438, 0.0663357908507028, 0.043937517330050475, 0.06434945509799066, 0.08644266474631526, 0.2990463436130555, 0.20645758527661526, 0.037030740565950834, 0.05473976691944465, 0.03376718685631791, 0.055519544834932016, 0.015464900099041482, 0.0533772565634741, 0.017434493000168475, 0.023188878173729586, 0.050165471245324424, 0.016611492403993205, 0.04893915983097208, 0.018564775293212266, 0.14250629671639012, 0.22408695380774238, 0.02347120264124486, 0.07098050532682289, 0.09652240532300166, 0.6466152867482555, 69.42258665638586, 124.10323527551468, 112.62685083573865, 116.26535907868417, 117.74679122432586, 82.21534206021218, 45.64402941734561, 32.80326812498031, 36.82230511019307, 81.85026353405368, 54.292086862748675, 82.40145852488857, 145.06520517410772, 79.17144160116874, 5.363057717200249, 0.36923127429139235, 0.1499670891151313, 0.7145636084098971, 0.06494197814214615, 0.1746869537859194, 0.2594159104891362, 0.6857374971432071, 0.6819381300480135, 2.090116825795943, 2.1872094610045036, 1.0314618844178416, 1.5867879890626477, 1.804441535665143, 1.211916407750499, 2.5672341787046005, 1.366060039689464, 2.2557783751718463, 6.292967844393946, 11.040008990995346, 16.37092778759618, 21.705884664289414, 29.527945864585142, 31.91221348700985, 29.184059904467677, 33.277078674685576, 32.20352988089285, 29.183720619447772, 30.030676049570886, 19.05555678952125, 10.440924802134115, 3.321596912799343, 0.7952968956482026, 0.3534977588682406, 0.41089931743279584, 3.376969993114472, 8.492830626426205, 4.338906272765129, 6.482339876313364, 3.9996923458191658, 14.054857434764987, 14.224837268552474, 10.160645957916014, 4.155644312981637, 1.5502748902766936, 0.22518374656717624, 18.193904238362467, 95.5733580743113, 63.91522984350882, 68.44570467548986, 82.40765586976083, 94.43751027507167, 97.9361624871531, 100.32871415538173, 100.69136865677373, 102.08987405223232, 98.12425582639634, 99.01946621556436, 96.9430575832244, 97.31925995119157, 103.17087142698227, 106.98422324272894, 108.25640478441792, 107.51228409428751, 105.85188988716372, 99.23010533855808, 92.76258760882963, 88.85385159523257, 81.00078798109486, 76.39430153754451, 82.21106667672434, 82.90761686140492, 68.0373388721097, 39.84897459706953, 11.514906037238337, 2.5666313594387424, 0.36992096792786355, 0.14256134779462892, 0.182168583776201, 0.12413149399142112, 0.08457283564512769, 0.09141112031835703, 0.15208728341085298, 0.386701419108337, 0.17770160169851396, 0.803199797388046, 2.100702322298481, 52.05654375014767, 81.66948933755198, 74.87034305449455, 60.25686264038087, 81.03834075312461, 45.96584420050345, 17.701819366024388, 41.69749744476811, 51.151021449796616, 73.88082319690336, 78.80106003053727, 93.67619391410582, 43.77474546432496, 0.3170669379253542, 0.0645284362197403, 0.09328095708042385, 0.0651145700906073, 0.0762881922926153, 0.054836853242088715, 0.04110791795556584, 0.05213193467728073, 0.08883414609778313, 0.05024095005806416, 0.025794527065309308, 0.08397327225294807, 0.015369002170289959, 0.1538785042301301, 0.09506030353687464, 0.10858899493130947, 0.014051002480330007, 0.07319437685392557, 0.006782179266484755, 0.009133965772156034, 0.03840795214918833, 0.06386094381131473, 0.10006547004224793, 0.08655334912961529, 0.06254235327604317, 0.054897550388329455, 0.07431295715392598, 0.05655491266459708, 0.05842388757774907, 0.023961755552238995, 0.07719219136502474, 0.05913187539385212, 0.1913766388691241, 0.1738811671854027, 0.09299925888978666, 0.2593379533819614, 0.18064914030894158, 0.26722360282175006, 0.14684966284661524, 0.16910604922281158, 0.3037556086576754, 0.1882882013676628, 0.38490926366179223, 0.33794562242204146, 0.1740450333924063, 0.19332754305533825, 0.1112835406656227, 0.13504571882226776, 0.15768897960022574, 0.25471738599721466, 0.1035163437406863, 0.1275827813773386, 0.12757302141718327, 0.18348898227897384, 0.25943466432152257, 0.11889590356018274, 0.2223809679309207, 0.3526417322216496, 0.12495396598692864, 0.25034025071128724, 0.2506974928321377, 1.564551214537313, 83.98105975120299, 142.6500920326479, 120.677531303898, 114.96185348879908, 107.95495494719475, 69.5790421578192, 41.810414637288744, 52.04042280873945, 111.75632784443518, 127.25371437688028, 72.10857083720546, 97.00189313580914, 150.5702046425112, 105.76524473005726, 12.454784377928704, 0.6657706104939984, 0.13120752639107167, 0.9780843712149129, 0.297423125875573, 0.32475276099097344, 0.34446634832889805, 0.5708235730567287, 0.6846653417714181, 1.0929745772192556, 1.4789773547841658, 3.45867786676653, 6.8094719225360505, 9.573320054238843, 16.773304131723222, 12.982306884181115, 4.286170986390883, 4.133448600769043, 4.541248602251853, 7.383777518426219, 12.419560513188763, 17.419408713617635, 25.14494626752792, 28.872984570841638, 24.77792028457888, 29.182337983962032, 29.003403379071145, 27.660838827010128, 25.997420472483483, 16.831796476917884, 8.70766374372667, 3.0359064234841258, 1.419608850152262, 1.7692888864586431, 4.324344963796677, 10.254849522344529, 17.564632508062548, 19.11412758211936, 19.29572351517216, 9.592074867217772, 24.865442091418853, 19.264628925631126, 18.121369807950913, 10.831527171596404, 4.88869313270815, 0.645410628809083, 16.660459503050774, 99.07335173699164, 74.3324919669859, 75.27062093057941, 90.15051657153715, 106.12282368444629, 104.37155600517028, 102.11966053132089, 102.37666991449173, 104.02164136209797, 101.8227606434976, 106.25565082796159, 104.95414564686438, 105.65341795644453, 110.28077140931161, 110.25966905778455, 110.82014437644713, 108.86871814727785, 105.88285307730399, 99.16882222698581, 93.96932048182335, 96.04797270990188, 87.60048174089002, 86.95788768029983, 101.04289931635704, 106.21884330626457, 79.66703307244086, 38.772731134968424, 7.068931316175769, 2.2408145329644604, 1.884633535819669, 1.0471527134218523, 0.9447111297518977, 0.320349594037379, 0.2924773848104862, 0.3451918029496747, 0.38657486138324587, 0.8489540615870107, 0.3725555442994641, 1.0953618297653815, 10.187748555214176, 73.0985378449963, 95.26947636758128, 82.37076205592003, 65.43399118608045, 105.47000008244669, 103.89361519967358, 47.10286478842459, 37.55398011976673, 39.17901023741692, 68.16649467714372, 83.12332368666127, 110.40644414963262, 49.11104379161712, 0.2681342975026177, 0.19081043860604688, 0.12532399411523534, 0.1856094217228313, 0.1707103599103228, 0.1501460778977602, 0.07391324311855339, 0.24427202229778616, 0.16713700407455045, 0.35110440826223743, 0.17954592773270223, 0.15264804444966779, 0.32718778678005744, 0.3137726679203972, 0.26089504240982, 0.11984407526230621, 0.10583111670829597, 0.15022130773192452, 0.13748506534724467, 0.13074396658808957, 0.158364791723509, 0.13931233826423847, 0.2227569025971236, 0.2639365033997644, 0.21982971128196488, 0.1436861487285745, 0.13157633643957878, 0.19020092373173084, 0.1131721695644721, 0.1538414562181119, 0.29705932604209073, 0.18013000848793215], [0.03262464332604601, 0.02064852295593629, 0.02448129723028791, 0.06311839776894738, 0.15806339741233857, 0.2024759352207184, 0.0339975954604245, 0.034528739540086645, 0.017048210401328343, 0.08838196270047657, 0.131404671457506, 0.09412995103986994, 0.028637693856932947, 0.04330906093180661, 0.0584856380948857, 0.01791033510779662, 0.043229460566034245, 0.025421344569974372, 0.014474999587682467, 0.0474910238277047, 0.0865326953991767, 0.046447489500766805, 0.0427885003568184, 0.04820202236935016, 0.04799275396151408, 0.028371713875282197, 0.04972885092419963, 0.06433314508608272, 1.3619911935060256, 42.18103155013054, 108.84461910493913, 88.3491994488624, 82.55240701859998, 51.67648176993094, 40.71126061101114, 42.10562006119759, 59.65305689842471, 90.54853516240274, 75.73230743408203, 65.12297861037716, 109.53272050426854, 133.73164207704608, 47.640857081259455, 0.6191785525410407, 0.3871523078170515, 0.2627996595636491, 0.03376742051313481, 0.024917794977344816, 0.07527587604859183, 0.2354373278156404, 2.227659393702784, 1.3345322733925236, 0.808723597757278, 2.3680586728357502, 5.82880191264614, 2.699412169956392, 9.882230239529765, 3.26087347442104, 0.23714391124104303, 0.6350444173139911, 9.50289095601728, 36.209168049596975, 55.39757943922474, 61.53754003586308, 67.77257104073801, 77.32312663908928, 84.34362011571085, 88.09004060683712, 90.11257940723051, 89.18698633870771, 84.33096654953496, 94.31875659573464, 99.45246450362667, 92.90960588762837, 84.11759745690131, 60.6829575569399, 35.27007418294107, 11.624114628761046, 1.9358617740292705, 1.3071146607398987, 0.6438118339546266, 0.6889510827679789, 2.3647128910787645, 3.427133920692629, 4.57417493866336, 5.8886430628838085, 6.6312511890165275, 2.81373038407295, 0.3923487434944799, 7.302813914514358, 58.0518747914222, 69.58161523265224, 64.88549870829429, 78.74151060658117, 86.56401895707654, 100.49374395801176, 105.63900716843145, 109.25926854533535, 108.081725951164, 105.03341674804689, 102.0626606479768, 96.51784912232431, 92.50437798038607, 88.78582985170426, 90.61116756931429, 91.43533598992133, 92.51852989196779, 93.44274228618991, 96.49327155082457, 98.40072016562186, 98.41590758292907, 91.25673478649509, 87.17379846880513, 81.17960883725075, 74.77237793707079, 68.47997050131521, 67.24316089384018, 60.710857375975586, 44.43827713689497, 17.55437158769177, 3.367950502903231, 0.12803825895271956, 0.1275143237604249, 0.4428915168729521, 0.3335926495492459, 0.10957269779136104, 0.12709883597469138, 0.21122856636441525, 0.2069079224020243, 0.20405196194206515, 0.1448930896097614, 1.750897260442857, 19.141835205016598, 60.815439531880045, 53.65444283331595, 35.34963553951633, 51.47115745852071, 75.93473311393493, 32.31229916695626, 24.746225572401478, 42.22148295371763, 56.963566118671054, 61.37571480966384, 78.86770894450527, 43.97936374910417, 2.22299397953095, 0.1673386077727041, 0.10083911925434105, 0.2507570178638543, 0.03114463423468894, 0.028164737985559532, 0.074504318256532, 0.08120810087289541, 0.07501696131282276, 0.0749146119661389, 0.06492638825288703, 0.054950019750263424, 0.05193865835486401, 0.19289071972091354, 0.08490543271745406, 0.055257102264271635, 0.03563929889951983, 0.026592714073617133, 0.036457174367481665, 0.029273512360129147, 0.08245386709008487, 0.08986616612321909, 0.03578912654531098, 0.05853501246160558, 0.07567559774484366, 0.07005548480177118, 0.04799056678049026, 0.026375487927467595, 0.01945325725471541, 0.12480309263112084, 0.035591667382827694, 0.05127074459808008, 0.0743912436789082, 0.05333585717204598, 0.10357299594268685, 0.132453951443876, 0.15750720225755246, 0.09390415428506751, 0.06929215479401812, 0.04400065829676967, 0.06596729489824464, 0.0287692483905102, 0.07400991575371835, 0.026036114807450966, 0.021119950481900768, 0.02593140974039993, 0.06201392497807261, 0.062228935214901165, 0.06438811189464985, 0.02079330782796587, 0.021611736794452996, 0.041996786791470744, 0.1331456981959843, 0.0580428239528931, 0.18978132205384393, 0.0778060959231469, 0.0846549679314898, 0.11069307073710427, 0.06248828662078708, 2.363831828678808, 66.4816641038464, 123.96068849871237, 105.26853146091585, 111.87869010433074, 80.0896135453255, 77.38569628807807, 54.73383203629525, 25.009620574212846, 38.05572578983922, 66.68852990673435, 72.98209836406093, 121.51742842889603, 145.3101650361092, 39.11069431612569, 0.3072564159670184, 0.4366516694426537, 0.34979501078205727, 0.08090576427357812, 0.1247935624973428, 0.28569603579178937, 1.1519632248147842, 3.2104239492647113, 5.344395079920369, 1.1230009337586742, 0.7437999750817976, 1.3464600785124687, 2.3749872945970107, 1.423682231576212, 1.0679678739078584, 1.038557697207697, 3.642297007383839, 17.994116352450465, 48.27385702440816, 71.54545184104674, 78.3927805193009, 82.7007039900749, 94.52120580980855, 97.16682880155503, 100.72470095849808, 101.30021464440131, 99.698467716094, 95.98181016983526, 106.30162885112148, 109.89162521977579, 103.76004280582552, 95.55157323037425, 73.06780999706638, 45.07915712171986, 16.737626252635835, 3.6944218749000184, 1.2433483211263534, 0.37056117228442625, 1.0640636446975893, 2.1385669227569335, 1.982577570503758, 4.682791742586321, 9.29279508129243, 9.177432290969357, 2.6609180290852827, 0.3698141139841849, 10.193107493462103, 68.20094877673735, 74.78168179911953, 72.65248590900053, 85.43516082148399, 91.40325884665214, 105.08267387267082, 107.82267693550357, 110.68414011309224, 110.92791541930168, 107.32715606689455, 103.02341384272422, 97.18207113204464, 96.7532148668843, 95.21093891512965, 97.2336502998106, 94.20033239549207, 95.60314455339986, 96.50481116387152, 98.6722501631706, 100.75138092041017, 96.94730158775084, 93.8846992677258, 89.99413167276691, 87.96254004201582, 83.61567528017106, 79.19064552553239, 80.34451269334363, 81.09356772515082, 70.70114597197502, 37.25606433806881, 10.241675261528263, 1.3518155846864948, 0.11033588990328774, 0.31590809204405357, 0.13782408989725575, 0.07948867781388183, 0.27878445182596484, 0.03267584864290492, 0.08085374690351949, 0.4517960019649998, 0.2989391832342071, 0.31156811202245377, 16.696319772351174, 67.02722657111384, 56.27321327886274, 34.676749014085345, 56.18867835690899, 46.4768466641826, 11.988456729919681, 40.49281597137451, 65.87797211062524, 81.79430700117543, 76.46649668293615, 88.89538949535739, 63.930923246568256, 6.968807424268415, 0.10107305952377858, 0.05417920889392976, 0.15388852466017972, 0.0320388465338657, 0.08489183465679807, 0.10993999098577809, 0.01602296355075293, 0.15678111944467793, 0.013390353152288065, 0.05844377138982377, 0.02298583997593772, 0.08243357342097067, 0.13520783834880398, 0.04391062381346861, 0.12395506394245934, 0.06803754026130324, 0.030899533979414456, 0.06490288467537011, 0.03633840392614084, 0.006096900211677196, 0.04431678447872401, 0.03420987842424262, 0.05825610666145241, 0.042637159687376795, 0.07709012547087285, 0.01663704718192739, 0.017310287165004882, 0.02540358856710936, 0.04218632460481698, 0.012734291733302658, 0.179548317927026, 0.15331470948313514, 0.10493193632893025, 0.21751612575063783, 0.21304712120083072, 0.32549776617557774, 0.14153857445043905, 0.12037226224258063, 0.09047673819887062, 0.18230657153312238, 0.2323006574184664, 0.17408270959652242, 0.1542922836397925, 0.1472744279571118, 0.14551441755986985, 0.13022465090597832, 0.19888958653375027, 0.15381807521466287, 0.20038667555537917, 0.21183569104440753, 0.17597658619765313, 0.21059433749366194, 0.15477983731656306, 0.27652495210209205, 0.2957595506262395, 0.13864977946204526, 0.30193354513856674, 0.2145500937777181, 4.625835495610391, 86.6473065653155, 139.2170924525107, 111.52518257018059, 108.65324666423183, 68.15616315410983, 54.51008435218565, 53.77754249880391, 76.16699234131845, 123.40570449829103, 112.86767651957851, 89.03833635391729, 133.26786102787142, 156.56041699071085, 61.56743634131647, 1.7727436365619784, 0.9430899038430184, 0.5625850022319825, 0.25641091528438753, 0.18319727131916633, 0.2363952288344022, 0.37854356330729305, 2.286402035144068, 7.2933105018831075, 2.859795925117308, 7.317302659634621, 15.853040583672064, 16.016203338100066, 23.950035418233565, 16.59270840306436, 5.411680888745093, 1.7834448429845997, 13.136083406786765, 43.96392137773576, 70.34631267670663, 85.4415621296052, 90.2083166183964, 102.35152752168717, 105.80441351859801, 109.77371092765563, 111.31191545917143, 110.67028630164363, 104.6875499909924, 116.58776221736785, 121.48757134714435, 113.27400269046908, 102.44427588678177, 75.25962260461624, 43.12319271026119, 12.975898711912095, 2.5125769309459196, 3.9253992226815995, 1.9126947849027574, 4.30968951794409, 7.9843953540248265, 6.512792177738683, 8.557197701546455, 14.203428972151972, 21.31165704419536, 8.888198675647859, 0.6676280979187258, 8.4831472750633, 64.09223071990475, 78.01218509674072, 78.62232546652518, 89.63923561957576, 96.29362290905368, 105.06491338053058, 109.35753960763256, 112.74008181787308, 112.18415644861038, 112.51730688156621, 110.33558261009955, 109.21874261671498, 106.9112357785625, 105.91472625732423, 104.34835126323085, 101.89399088582685, 99.08400489437966, 98.85380883370676, 100.968350748862, 104.32163207761704, 103.36748415423979, 103.36637804585119, 98.69092064519083, 96.89693050999796, 92.106963434527, 88.73679237980997, 92.28751797829905, 99.17792997052594, 85.6368883194462, 36.149591169049664, 7.3729439320102825, 1.0777682835055937, 0.9572258807959096, 1.091978540343623, 0.5998363646288073, 0.26052750406726716, 0.2822415921236238, 0.2788043088249622, 0.30536699799760697, 0.445671588663132, 0.7090722901686546, 3.6113274433920464, 29.970697126080914, 81.49890545875796, 65.5495128323955, 46.907695493390484, 72.26927034316525, 105.65945056176956, 48.500742604655606, 36.45674021013322, 54.292871336783136, 75.33873681099185, 76.18191303745394, 101.94501307702835, 70.745327549596, 5.9980208066201985, 0.3631914064528481, 0.12192662399742873, 0.37973504453416795, 0.16019764176059156, 0.3226384196069933, 0.15889498585414502, 0.14149444778600048, 0.2962864352570426, 0.14279178704225248, 0.23445429911296214, 0.15058139969985332, 0.26359871991219064, 0.24158893723882016, 0.19080481552068265, 0.2838229201734066, 0.2039718751104609, 0.15289591985844797, 0.15956692157253144, 0.12506599868497542, 0.15018052121083583, 0.24956150701449764, 0.1675824229154856, 0.229359814416497, 0.1552374216337358, 0.28556865069174, 0.13593336957837307, 0.1493046069217305, 0.12212886354855954, 0.2763320511627582, 0.10712913012192135], [0.029116498809608243, 0.02778354029531681, 0.13631518779983445, 0.19814766102260162, 0.2399874610766288, 0.3200405235252073, 0.10572701302026549, 0.014144150153433364, 0.03785769800625501, 0.03431553727075939, 0.1706109983065436, 0.20162144074997596, 0.21708324010814392, 0.07301308214664459, 0.029464396573002302, 0.018522872198973934, 0.09032795626309612, 0.04456887337108774, 0.021893038534589356, 0.06491383207180808, 0.05620362687735789, 0.0374266394834605, 0.28874730270716453, 0.08955950112712961, 0.04313924222163135, 0.2995506439718508, 0.15298944387224414, 1.92471893324006, 64.76923573401668, 100.85813214701992, 87.56654539415914, 69.00737239468482, 67.74897406178137, 48.58046085603776, 30.142808768057055, 52.299209025598344, 81.25463593390681, 70.07725377236643, 67.87463111262169, 112.51109384721326, 97.858334818194, 25.33564406056558, 0.13092654066220408, 0.1968846118618404, 0.3890939423393819, 0.23821082657142995, 0.019048266788764347, 0.18534679146062943, 0.06497899551064738, 0.9030495523925751, 0.927721199489409, 0.7212215253422338, 0.5283541100159769, 5.231757356274513, 4.577468749015562, 0.6118878469832483, 1.0174437624312218, 1.7536320104714365, 19.513544497951386, 50.81418398887881, 77.18268225269934, 82.50478159996771, 85.28833081645351, 82.80078718739172, 85.37540743427893, 75.26805570048671, 81.34396399221113, 76.83436793665733, 72.56925321394398, 66.69149521858462, 69.51836309125348, 62.480038519828554, 61.765982797068936, 68.00779557997181, 76.6783203617219, 84.16641527606596, 88.04523929472893, 85.80653082939887, 56.916407462089296, 24.680723951708888, 3.5181679648737756, 0.08364671961434426, 2.5798553853265704, 1.0514593532969876, 1.7743154038344662, 2.9438724200571738, 4.270759503687582, 2.858058315130972, 2.3403672297154707, 42.597524504507746, 59.54647041136219, 70.94680401586717, 76.06020189100697, 91.387891000317, 113.20305485879223, 106.76532360815234, 97.45156934184413, 91.9606747165803, 84.25251914608864, 81.01439076085245, 79.1402901372602, 81.91550823949999, 82.62673593336537, 88.44498372847035, 86.96224935593145, 85.10285762048538, 86.32214992277085, 88.681502649861, 96.36142499985235, 90.91235068536575, 77.79323839372205, 75.03856566644485, 72.9305584199967, 74.44671138640373, 76.98197457098192, 79.75088550198464, 76.84152233985164, 71.11347336922923, 70.00872212071573, 60.12476898008778, 38.06120141859978, 14.734426698377057, 2.1861661105386676, 0.04317769217455099, 0.36819414445950144, 0.4403946524666202, 0.10448930604803948, 0.0855024756803628, 0.13788205210960683, 0.19494683842264837, 0.307281298502799, 0.09867432331966777, 0.4686879036166976, 11.211876465428261, 74.89875670402282, 75.23024405202558, 29.020944218481745, 46.13155649554345, 82.58694741033739, 42.12542410819761, 23.845380698480916, 39.24936971356792, 54.16683773840628, 75.99054844148698, 75.15014140836655, 71.45526086130451, 8.820833929123419, 0.14787167010288085, 0.0657637223541256, 0.011772819787203785, 0.11173497329676345, 0.023126290705535683, 0.10736754434483667, 0.026242090952432445, 0.08374952861378271, 0.13484797620725247, 0.058202488167632016, 0.10589649465175406, 0.1451073184369072, 0.09794621803467313, 0.14778663434328573, 0.16562129911636153, 0.10640061114944759, 0.06371377832106044, 0.04783341916458261, 0.14544939201685692, 0.22775930352509025, 0.18601938601463072, 0.0072927467033056725, 0.15197826909922785, 0.35570087452088633, 0.36400211133783866, 0.1947184522906619, 0.24057627625523076, 0.13526563202181172, 0.09611736697655532, 0.04620568533878654, 0.03482913410651588, 0.13345751130292494, 0.14431757371752493, 0.10527071573080556, 0.20731966401780808, 0.08299844069105965, 0.021356179439012083, 0.018729560805724996, 0.04232522017592865, 0.015555293686057051, 0.06511994802783574, 0.08727245288149965, 0.09717775523782739, 0.048712213944283225, 0.05493329222043676, 0.04602201958937992, 0.03336240131888659, 0.06098938963165688, 0.05546130683092822, 0.03172617923888949, 0.06882633503165937, 0.2724957892731313, 0.08476747560404962, 0.12471883828120849, 0.3098282650593789, 0.3174975712693507, 6.773310611324926, 95.58011239574802, 116.7173965515629, 102.59786805798932, 90.05843500937186, 97.46961224463679, 71.15685478333505, 31.241203815706317, 19.68919215663787, 41.66588314117924, 59.695496943689164, 77.28996692165252, 120.73413110548451, 98.09207670150265, 17.562459514987086, 0.27013804643384876, 0.20385866263701072, 0.2680289450912707, 0.07708051106742314, 0.06998937907478503, 0.5558223457586381, 0.3753612953568659, 2.8053539174218334, 2.9573746890791, 1.7493122551710376, 1.6886302468276795, 1.3141918422714358, 0.9013832192267142, 0.9098591547339194, 1.9074090233733578, 5.750560923930138, 34.41085154010404, 67.59790005222445, 92.17968417752175, 94.15308352439635, 95.04972950104745, 93.85956471966159, 90.15735718511766, 83.0057074946742, 90.60977905027329, 85.46637504331528, 81.76919598733225, 76.0556911653088, 76.6908327225716, 67.53817019924041, 72.19929525929113, 76.43868707841443, 84.94806520400509, 92.34678499160275, 101.6583662648355, 98.6319988004623, 70.72094609660488, 33.8212683123927, 5.724795854860737, 0.2886440646984885, 1.375409376717383, 1.2812305722505817, 3.349524678722505, 0.6144633120106113, 2.202605744523387, 1.7104334768749054, 5.277949638905064, 55.320575468001834, 72.11695686463388, 76.70184673801546, 81.56152217618882, 95.49242388817572, 112.33173170397359, 106.94877286111156, 98.3439713139688, 93.18683116666733, 85.99639707996, 83.14166468958702, 79.83563223192769, 81.23558890435004, 84.87285767832111, 91.94001951525289, 90.63423110592751, 88.54792241127261, 89.10638163166662, 88.54877748797017, 92.74357195823424, 93.20238728677073, 85.76473405284267, 82.11927536995181, 77.66809125100413, 77.91938181846373, 79.22297370049262, 81.63042253063571, 81.30157101538875, 82.73368327848374, 82.45073918373355, 84.53532988025297, 70.41691533980831, 34.43729223743562, 6.261171640888338, 0.5847914396755157, 0.3114881017996419, 0.37203334812675753, 0.16009852530494814, 0.04077357420277211, 0.15609485788210747, 0.1479559397745517, 0.27460758724520284, 0.08807121445575068, 0.9114075716464751, 6.512633321746704, 74.73968890405472, 83.46011407913701, 28.569067562780074, 47.88746433873331, 56.63157670728622, 14.253373492148615, 37.34449417360368, 64.46158855192124, 80.8144832426502, 98.36348902794623, 87.58960108603202, 92.76517637314336, 20.45599591347479, 0.0802875543013215, 0.20043518424274462, 0.04553219063147422, 0.041863878197487325, 0.036319014240777305, 0.07147705287582452, 0.01324756776974086, 0.09790271956233249, 0.1933318637912312, 0.13634763928430696, 0.2038819823534258, 0.1184603289490746, 0.06059501139867691, 0.019015541427858898, 0.08417677584915392, 0.046931595781878124, 0.031189599765404582, 0.10918550929355045, 0.12371348577641672, 0.12383554656539233, 0.17877695931782647, 0.08211540178425851, 0.1616772333340299, 0.281369446987106, 0.24741805428939484, 0.28634831369403874, 0.14136789006090936, 0.10505120855786147, 0.10481489341585867, 0.2066341685431619, 0.08882084681141762, 0.21963310247707754, 0.26781790318988985, 0.2576713444244477, 0.41751966541332586, 0.16938029337794552, 0.1237083453264448, 0.1106761631766154, 0.2011952047506648, 0.41955341434767174, 0.2313948044132802, 0.4316513522738411, 0.1462303726903854, 0.08802325735169073, 0.21990872559047517, 0.10927801441040733, 0.21000756010893853, 0.16696504797906647, 0.11155623732314957, 0.11994595729535627, 0.2664817232758768, 0.3498918442956863, 0.25624985295918684, 0.2925557402833816, 0.631577777526071, 0.3294330372685387, 10.885822580706689, 119.538420092675, 128.62146054544758, 110.22799199627293, 93.99163092336347, 83.5733215270504, 60.61406112486317, 39.79896829974267, 68.92861120162472, 115.64298091396209, 100.89690869854343, 89.93924986931586, 132.39849121339861, 116.90454067722445, 33.49158133229902, 0.5682156259013761, 0.24610865680921465, 0.5892875177725669, 0.625544069034438, 0.15431935718703657, 0.43696686865821965, 0.13469290468961964, 2.770878980236669, 7.980335210600208, 4.951984497808642, 4.273300709262971, 18.0904419191422, 14.247840989020563, 5.3312521980654815, 2.7627778149420217, 2.7764884598793524, 30.107797691898963, 69.93427553484517, 101.24181839727588, 106.9994891074396, 111.63234172328826, 102.64091999300065, 103.4080022381198, 90.18256233584496, 98.07391612760483, 91.90396508862896, 88.10722843293222, 81.8049366243424, 84.12079026622158, 77.49639341908117, 80.41979082169073, 85.40881033866637, 95.73500679385279, 104.32790786989274, 111.3631808373236, 106.9736328432637, 75.57280817339498, 34.72609243085308, 5.262527369683789, 0.8922154756803667, 6.436787920613443, 3.652639807231965, 7.3627295897853, 6.379654186387216, 8.799609984121016, 5.2797573612582305, 3.3338646158095333, 52.66919051447223, 74.54185239730343, 81.23923670861029, 81.8137070440477, 94.96310787816202, 118.17614955286827, 109.89444932629986, 104.64361944506246, 97.29884793681484, 94.50793250914543, 89.61998462677003, 88.72629611722886, 91.6618214884112, 93.49458817512759, 99.7205271259431, 99.61984772836009, 97.91446393535983, 97.37709922175254, 94.07440077873969, 94.25464153289796, 95.87057175174837, 91.96535018182571, 89.97797150765696, 85.2006030851795, 87.0006101362167, 88.40801931196644, 89.08221983140515, 89.18321301860195, 86.2276835595408, 89.98545538994574, 96.58110910846342, 80.84534445116597, 33.082858593233176, 4.005704113552648, 0.39706784510804766, 1.081180255259237, 1.0526543278847973, 0.24587965780688872, 0.2010057665287487, 0.29000858986569994, 0.27968319553521376, 0.4719640939466415, 0.2171458448133161, 1.3528572191153805, 15.604833979760448, 91.75245177361273, 93.90012202724334, 39.06976830574774, 65.44768025798183, 115.75304262099729, 57.54412397261589, 34.141141522315245, 49.14703153794812, 74.31198581572502, 95.69301389878797, 96.93043539600988, 107.52800495393815, 21.513761089694118, 0.10794628546723437, 0.251844372420061, 0.1747202632888671, 0.22309946647334486, 0.10597101202414883, 0.46052097733463015, 0.21275678919928692, 0.3896902958231588, 0.4115806453891339, 0.2003601382696821, 0.23605572930987806, 0.14922245165273068, 0.3012509607980329, 0.27714444144118217, 0.3078035559625395, 0.12261420323122894, 0.3395898309686492, 0.15532821837452152, 0.23450345131418399, 0.4461715989295514, 0.3023712264914667, 0.19306639900370953, 0.3203122395901911, 0.5463748881893774, 0.5290622204061478, 0.404123300386052, 0.43051600997005746, 0.24227538266249243, 0.23522794066417604], [0.1495072371777027, 0.09347562002198351, 0.13611290994430744, 0.0850370389619662, 0.03810695237329891, 0.06705585987337175, 0.05599647670263245, 0.0162572686695644, 0.06278102030797351, 0.11789077322088903, 0.02826915385441915, 0.09082990473196392, 0.1232553115715423, 0.02042765980736623, 0.14150638343586078, 0.15170111380998166, 0.04701754701654277, 0.01256925628460463, 0.07675490837784545, 0.07136334244522356, 0.034928239070840424, 0.09646778325400046, 0.0489234511980847, 0.15070011268459982, 0.08498720494249175, 0.516316294670105, 5.06706879984948, 59.77003766644386, 99.47839921520603, 77.82271108319684, 82.96346356791835, 71.55091962506695, 37.84659677936185, 48.126728919244584, 93.91365420433783, 93.61036869787401, 52.26490397607127, 62.61015922792497, 91.32499971697408, 67.66101883303735, 7.743473572115745, 0.15567190073911222, 0.045140509027987726, 0.11826303832593466, 0.14228662866498196, 0.07208940993633962, 0.18645558115695754, 0.020972767754668192, 0.8203819850760122, 14.423391569045283, 1.8721233813032028, 1.4943807475989865, 0.29868030680283425, 0.9036145575584904, 0.3789318779543523, 4.4180547998797515, 34.18653903468963, 67.21291941981163, 80.19595684543734, 82.61713397118353, 78.97879046778526, 68.39928734687068, 65.65022360893988, 74.76539611816406, 69.64269438097554, 74.1999315446423, 78.63947406891855, 78.22180440348964, 78.55958323324882, 80.53175095588931, 79.6270170519429, 79.56474550308721, 79.47600580030873, 78.28432698403635, 76.23550830348846, 70.74727304520147, 71.14070246296545, 65.3842516099253, 77.27663086306664, 89.97644178328976, 72.52265545629686, 37.111897622385335, 10.354234537770672, 1.939225696748303, 1.1878950773708283, 4.5937715903405225, 6.249100056386763, 3.1170080457964255, 14.351999528946417, 55.51264216822963, 45.05348520894205, 62.581545537517925, 74.10483760218467, 86.44776774990945, 83.79704567693895, 77.38786143641319, 69.15331594405636, 67.36691951751709, 65.2340248323256, 65.95336006533715, 66.84208285424018, 72.30591312531503, 74.43328903567406, 73.75581725951164, 77.96336727757608, 82.30425434727823, 79.30440995001024, 83.7689144380631, 74.61385142418646, 74.10461794945502, 83.96611552084647, 79.51088351588096, 73.33078922763949, 67.48303736409834, 72.49848581129505, 70.3298230325022, 77.94615591725996, 87.52770608471286, 83.95538391605501, 81.84994189969956, 77.39241138581308, 57.989858196627715, 31.8678593251013, 9.76020432287647, 0.8465706088369893, 0.23127656640304675, 0.2078583617244036, 0.23309924279249486, 0.06854027013985381, 0.11517725914957062, 0.09377897551824009, 0.10510762327260549, 0.12572650437153157, 0.9748492125541934, 1.1089452428202475, 50.554095545122706, 103.15486031193888, 53.69481578949959, 38.900667082878854, 82.40540442928192, 43.821374600933446, 25.854573634362993, 26.318095807106268, 42.01017310542446, 59.11857120452389, 55.52767661310012, 68.2012939453125, 15.55627601761972, 0.5070119729686169, 0.06455027738646155, 0.024987576011147712, 0.017780634506996122, 0.039931003890571096, 0.04498742550851838, 0.09986640209512365, 0.294951910092946, 0.26075539990298213, 0.36374010926773476, 0.2652921725905711, 0.07439724214735531, 0.10529101706079899, 0.1807388798483918, 0.21745733616332855, 0.1500821708431167, 0.1779547477922132, 0.2495416500155003, 0.2432671907327829, 0.3470979522793524, 0.21596726450708606, 0.18029503914858067, 0.15524704369806475, 0.14114336501206123, 0.05993384687650589, 0.0600771704358199, 0.1602084436003239, 0.21177103322359825, 0.05414575383427644, 0.05096267383064955, 0.05645548594334433, 0.07889665272687713, 0.009576097138286119, 0.05752753789326357, 0.018136380841174436, 0.06916683813136432, 0.0945995322939369, 0.08936329068796289, 0.11158567808207967, 0.10993932448928395, 0.20003055192289815, 0.07811996980660385, 0.07747249527563972, 0.09176453199958609, 0.10423738569501909, 0.03858603694806657, 0.04813334258693842, 0.0815477689367629, 0.00719451172758014, 0.07599619021939655, 0.07825267155684772, 0.0821231852375692, 0.1413607960867305, 0.4590615185518419, 10.947443996706317, 87.93149055973177, 113.34873168699204, 101.04627255470523, 106.16891937871134, 97.31595731550648, 58.303490915606105, 35.64739834877753, 38.41541497938095, 79.99745353575676, 55.8660202641641, 72.51435572101225, 102.50694751739503, 66.80986450564477, 4.4598991351742905, 0.6452198422724201, 0.08747870673335369, 0.31576210632920265, 0.08236545288274366, 0.051999006931099205, 0.7876825332641603, 0.1492190042570714, 0.6086440468507429, 4.65076853190699, 0.8840479978149938, 1.54665429745951, 0.5048890513998847, 0.22653230646204567, 1.8374176371482112, 10.67385377422456, 48.18066935385428, 84.85988247779109, 90.54422839995354, 93.38332622281968, 83.8004110705468, 78.48898057014712, 76.53514600569203, 83.30837326665079, 79.27612966106784, 83.60674796565887, 87.87458481327181, 87.515076052758, 90.25768356938516, 94.06075877528038, 93.49333301667245, 92.14661859696912, 87.95158878449472, 88.97989303834977, 88.71169705544749, 86.20623603943856, 84.25499808403754, 79.37400064160748, 90.3875454010502, 102.13323977685745, 87.07289941849248, 51.20253001489947, 16.499640364800733, 3.685428370391169, 1.2037280922935856, 3.208985910300286, 5.156624845920071, 4.339574546583237, 23.22879783568844, 67.81048467082363, 53.61527012240503, 65.41747408528482, 76.68920886132025, 86.33456030199605, 82.48876264018398, 77.59802203024589, 72.61061068504088, 71.7111562913464, 70.83609119538339, 70.17990219977595, 71.51074670976209, 74.07616507622504, 78.2524694934968, 76.28347889069589, 79.97237390087497, 83.85694811421057, 83.39134708527597, 84.45744729811146, 76.88997145622008, 76.60192043550553, 88.0677850784794, 85.03064678561303, 80.90046944156771, 79.10993099212646, 80.27086627098822, 76.75970954279747, 79.37594613721295, 87.31787496997465, 87.30226393668883, 85.23985816586404, 90.93356286325763, 85.7275656730898, 62.07834074574133, 22.061896631794593, 3.2937549487237012, 0.15793786624506598, 0.6011400624148308, 0.14944636383123938, 0.14927305942100866, 0.09223574502093178, 0.05247016632629018, 0.13210680636186756, 0.24906256927117226, 0.7312761535567622, 0.2963626150402331, 47.2794145922507, 110.16968988603162, 55.61343531454764, 44.26211172534574, 52.90436014052361, 12.432159166182242, 33.593762997658025, 46.90536168313796, 71.41537035665205, 84.96755153902116, 66.59328691421017, 85.31365363828598, 30.643358115226995, 0.34685344765743903, 0.08494310892157017, 0.13454465135451288, 0.02778436000939579, 0.10424251848411176, 0.06251138800214376, 0.024630308992439703, 0.12083206055385452, 0.10297867259190929, 0.21841706047135018, 0.20118123130692592, 0.1745095737879315, 0.11497613808680927, 0.09546594709278115, 0.13031514121159432, 0.10529850173981921, 0.3136158956875724, 0.27715066207512734, 0.15298121608793736, 0.16198359189494965, 0.08066530459590497, 0.21098184008752147, 0.0459906789323976, 0.12622331239042744, 0.031067960324787328, 0.042962191641450896, 0.0736368922216277, 0.19534957084444263, 0.2146768047203941, 0.09145222859637392, 0.16852648838633494, 0.10858406898595634, 0.13283399234135307, 0.1281247119749746, 0.09918458384251404, 0.14006695019141321, 0.09842267875830013, 0.23450199574712785, 0.202912375511181, 0.14969609317279634, 0.2076355527125059, 0.10044734955074326, 0.3842105301878145, 0.33615257831350454, 0.246139683370148, 0.1823989617367906, 0.10280531455552387, 0.19620656276181822, 0.12496524280117405, 0.2408126143798713, 0.13293004444529935, 0.26553918998087606, 0.5391156841670314, 0.7136444254748283, 15.80080245771716, 111.47316409695534, 127.29503262427546, 104.3975377851917, 101.26856111711072, 90.04618936969389, 54.42048957270961, 65.67163190534039, 120.31329216495638, 132.68984486979824, 75.31979176305956, 83.55968736833142, 108.11905122572377, 85.35850986357659, 11.07373352973692, 0.7683576282954986, 0.1756917087421302, 0.4859431760926401, 0.469662765822103, 0.16114178384023328, 0.41375559964968317, 0.23454393140010296, 3.8185778837050166, 28.94370294386341, 4.902987720504885, 6.633810535553963, 4.146121778795797, 2.883118583310035, 1.4304073803847837, 6.139256040896139, 43.31196854191442, 91.20632448504048, 105.37115635410433, 104.0855210827243, 96.37340391835859, 89.8219160879812, 82.94211018470027, 94.39988690037882, 88.25058321799003, 89.4961004872476, 94.60953758608912, 96.6598310778218, 94.85537605900919, 100.19763638896328, 95.50146887379309, 97.6349558368806, 93.93060668822258, 94.06091567008727, 94.30167075126403, 89.33817017462947, 86.0101253755631, 85.06597165138491, 96.73022977767452, 109.65821281556161, 86.22293749163228, 47.30230946694651, 12.439347890115554, 4.1793462153403995, 4.297449271525107, 9.311722478558941, 10.322041684581388, 3.84561772308042, 19.91774082183838, 73.66556352184665, 61.7822684780244, 71.55581474304199, 81.3114240092616, 92.02355815518288, 89.7341412882651, 82.48899013765397, 77.81928293166622, 78.69264571897446, 80.44267392927601, 82.03026894600161, 79.34272366185343, 82.00032557210615, 86.05786846530053, 83.39679917981549, 87.20396149543025, 91.99587406650667, 87.32794761657716, 91.33562149540072, 86.51576595921671, 84.04180942043182, 87.55805738510625, 87.53447609563028, 88.88548158830213, 84.77235870976602, 87.9769665195096, 79.21919253564651, 86.02990981071227, 98.59906658049553, 92.15219620735415, 89.79149418492472, 96.18175691173923, 101.2644269389491, 74.19091009324598, 21.60159472496279, 2.0190552453840933, 0.36332400095078254, 0.818992853164673, 0.4172128012343761, 0.2249848088549991, 0.1655394656042899, 0.20846714115431234, 0.3210554368072941, 0.24763606759088658, 1.262087567198661, 2.4155274418092545, 62.47736738574121, 123.7187723959646, 69.32907735147785, 56.86550294199298, 116.8018687155939, 59.02770949948219, 34.777036174651116, 34.41226359336607, 57.42773156012259, 77.35709436478155, 73.56410749496953, 102.54650069821267, 36.100522318193995, 0.5692000182405595, 0.3381240596213649, 0.18040682669849167, 0.11663776747281514, 0.3685691291766782, 0.18811258337190076, 0.17913983984579965, 0.4299078280887296, 0.3118264675140381, 0.5118555791916386, 0.29563225745674104, 0.2621456043374154, 0.14066782359394336, 0.25951436810916473, 0.3087276418603236, 0.21653527273766457, 0.35323214086313404, 0.46022667699763853, 0.31090976670384407, 0.33788222098542803, 0.38770422820122014, 0.28881903918039414, 0.21624354645609858, 0.31486213687927495, 0.10475256450233922, 0.15807534838395734, 0.17962383887460157, 0.2894981914470273], [0.145330602423318, 0.07930648678372945, 0.05753639386966825, 0.05089076498763696, 0.06618674078415479, 0.03591667252382444, 0.042092923165088704, 0.08908192191513316, 0.12336660116430252, 0.11615556875063528, 0.10835490144428708, 0.1212660646847179, 0.17424651451649206, 0.08148129548757307, 0.02604734948686054, 0.09234191714635781, 0.018302248452880213, 0.050094661738483176, 0.037756390539148164, 0.04684030108394162, 0.1915666746396211, 0.14986182863433517, 0.07562494401129023, 0.07238228534979206, 0.0628265297611154, 16.92283272743225, 83.29924983362999, 101.58214676764705, 88.1456833501016, 65.29661409316525, 46.045597753217145, 33.539955923634196, 41.728633219195956, 77.96874092471215, 82.05298731403967, 33.38559496787287, 87.969372810856, 110.84665175407164, 81.49778366088867, 3.3879067868955675, 0.5179372754308486, 0.046724460928911166, 0.11772212662523794, 0.07612501556474356, 0.22342195884594995, 0.1486591931672827, 0.15621591509590227, 1.9786154863334473, 13.411012138089827, 0.9508364623592747, 1.9649315625429156, 0.5853376297220108, 0.4457888307590639, 11.124942033521592, 42.26318951575987, 81.98150604001938, 83.15347886854603, 78.91718572185886, 69.51682552214592, 68.05627607530164, 63.409718698070904, 66.99502391199913, 68.93028997605848, 66.65257746173491, 73.3633605895504, 72.0960114079137, 71.23762422992338, 77.3172430838308, 79.96508613709481, 80.79789161682129, 83.5062333076231, 80.04909546144548, 78.31496853982249, 78.0735388109761, 79.60575780560895, 82.33682570918914, 84.39879217455464, 84.27020119082543, 76.12443462494882, 75.03297236657913, 79.7844845248807, 88.44353245150658, 90.5144105419036, 40.51937826218144, 9.640478876329238, 4.287410455365335, 14.253255821043446, 31.229034662246708, 30.982466628474576, 40.24716577222271, 49.11450724447928, 53.25724009544619, 51.003116715338926, 55.384364974114206, 56.06295462577574, 60.21773699791201, 60.035546825778106, 57.65577816194104, 59.82409969452889, 57.67265219842234, 63.47014281057543, 66.15908053613478, 64.90210602360388, 66.55522423405802, 71.80748970277848, 68.86525707860147, 70.24842600668632, 65.72219125686154, 59.165357235939275, 79.39631108314761, 91.09725906002907, 86.02238670472177, 87.09025982887515, 77.42269208354335, 73.49378724252024, 74.62994883137365, 72.30182601559547, 72.46568695191415, 77.08634099652691, 83.62653240080803, 85.33263006517964, 82.45321812168245, 68.98790174914946, 43.04441975009057, 20.260044105591316, 4.14774073708442, 0.04153561335237276, 0.03806384077536003, 0.34374542894863314, 0.13622927870000565, 0.024073569915227355, 0.04598831172071157, 0.1687532044466465, 0.15606347892072894, 0.28106270538222405, 0.2674299869085512, 28.138987518125965, 99.97468886836883, 72.28484999748969, 45.26096682394705, 69.07174633395287, 55.20167666096842, 31.457234236501883, 36.058643171864176, 44.97891702959615, 61.85719751542615, 67.57955120455834, 64.50560931236514, 17.635635252921812, 0.6208885220750686, 0.07939617269702497, 0.20613647186227385, 0.04832327493556565, 0.13703279768026647, 0.12402866200934495, 0.19350985665955853, 0.22314904768380428, 0.15490018972946754, 0.09621820713002836, 0.1551826923124252, 0.11724892177528913, 0.22865161209577517, 0.2056914667088178, 0.20349098639863156, 0.23883454471586213, 0.44899876980531606, 0.22651460983099478, 0.09682222149304806, 0.11531111003170091, 0.20931815758587854, 0.06262533975044085, 0.007371072969098966, 0.029432092560455207, 0.0766562515749566, 0.05480617908160052, 0.014184930928862624, 0.10128409376428013, 0.14464233371038593, 0.035328730685456146, 0.04060691560528452, 0.0631364582917623, 0.028378064744174484, 0.014969043944391512, 0.018553847048972404, 0.17239985957501397, 0.10186995950437362, 0.11183877054962421, 0.16218942439844533, 0.10249461227607343, 0.05977901667656918, 0.0489368194323634, 0.041781910620028936, 0.035587729690896894, 0.024192150749806917, 0.023435736600790295, 0.06287612246289369, 0.057099930596567934, 0.1536449393437755, 0.09670005345176305, 0.21661143719909653, 0.09183866632801872, 30.41269921487378, 112.42413490049302, 112.08516367020147, 113.94554384293096, 90.05386937049128, 72.2558323029549, 62.758566025764715, 26.45918542338956, 35.39031051820324, 71.427364964639, 37.37966214456866, 94.03465932415378, 119.3186261576991, 81.01662651185067, 1.5661148919213204, 0.9384554396233252, 0.03853644041584865, 0.11391908230800783, 0.03554739899212315, 0.14662213473310395, 0.7828317871016841, 0.6309860512133568, 1.6273517930699934, 1.1559216317630585, 1.4349033971948009, 0.7704369747830976, 0.35952806592948977, 1.0518100377052062, 20.373231941653838, 59.01255738350653, 96.70809976516232, 93.42877864837648, 84.49987949863558, 79.74854776936193, 76.87278363012499, 75.02330764647454, 78.27652146739345, 77.31451311419087, 76.02690881298435, 82.87838735888081, 79.04194062755954, 82.32266595286708, 85.11881382234635, 86.97425965339907, 87.47098076728084, 90.50387505562075, 88.24634705820392, 87.53707270468436, 84.80757374917307, 87.3611936261577, 93.4103278190859, 93.04579842475154, 93.27216625213624, 85.92817137318274, 81.10716266016807, 86.88511202412268, 97.94393662483462, 103.80091390302105, 53.80570511664114, 18.597573003461285, 8.6651756494276, 20.3730672021066, 46.259782698846635, 33.603980771956905, 43.680545822266616, 59.19929750504033, 59.957852517404866, 57.50190750245125, 62.62195771740329, 63.830302684537834, 66.58904290968373, 68.13166403001355, 64.02527586106332, 65.26045376254667, 63.61936938378119, 68.59798677505987, 70.49247587880781, 67.05203164008357, 68.82468408153903, 75.47026172760995, 72.63308586612825, 73.10526078747165, 72.54081603019469, 73.86269400196691, 83.99710224520776, 90.96320813701999, 84.29015821026218, 86.81316006568171, 83.83554766255041, 80.26467677085631, 81.47559873519405, 79.67322257257278, 79.29892647650935, 78.4859368108934, 84.84779373292001, 86.62207788036716, 86.35965562635853, 89.98999749460529, 79.13833679691439, 43.09469669095932, 9.923558292850371, 1.139348759766548, 0.124755012952993, 0.09201940945199422, 0.39403024520124164, 0.12770649691623065, 0.09036881939297722, 0.12626995948413688, 0.1432525736069487, 0.3006420128287808, 0.6852156380491873, 24.77340759769563, 108.50664415667134, 76.57947663337954, 54.315821124661355, 42.56431771862892, 16.130825781053115, 33.81911885353827, 52.49710829027238, 65.43342244240546, 86.33831008788079, 77.5267682536956, 78.04448973747992, 31.026854130529593, 1.2155632314182099, 0.09734709131261034, 0.2889323895496707, 0.11620460603866847, 0.1083946001205233, 0.01874702569517878, 0.0845213468757368, 0.11760460107677406, 0.18625710309753496, 0.09937440510839225, 0.1509961290585418, 0.14832597556373767, 0.1288761982634183, 0.1577272380311643, 0.18058825164071976, 0.06885897037723372, 0.1582807978434909, 0.1703269482259789, 0.09585822241440897, 0.05161474488915936, 0.07961453073808263, 0.04724454652938632, 0.058941854945113586, 0.08073538631921814, 0.028141854939261274, 0.10738561635897045, 0.07132512231868121, 0.2517772477961356, 0.23681273143137657, 0.17049553353459607, 0.13451259823576098, 0.11198437322051295, 0.2393676959458859, 0.11352882179762087, 0.10393928556192307, 0.1743444052314566, 0.17887854257658606, 0.12702858571203487, 0.18284575953598947, 0.2515074929162379, 0.20429101201795763, 0.1265285064977023, 0.21819812786434928, 0.12839160934691468, 0.18205002400903933, 0.18290408947054418, 0.2408907553481479, 0.21995240792391763, 0.31000694740683804, 0.36551182548845973, 0.3354773790605607, 0.18698197549148915, 31.766158150088405, 130.63756665875835, 124.2407221947947, 115.09998367678736, 91.4120057321364, 61.82210799186461, 47.76059919787992, 59.812999386941236, 107.4917544088056, 116.60277705038749, 51.60113696129092, 115.78498640368062, 131.6464630250008, 104.52750159848122, 5.982948608936803, 1.4582750850146817, 0.17832360380599577, 0.2685526427963088, 0.2410547134857024, 0.26959826088240074, 0.5084262632073895, 0.5569302927582496, 7.955656638068538, 35.64146380270682, 7.233892477327778, 3.8885684119116877, 2.712709495136815, 0.5155726990872814, 15.89739376498807, 53.9404385320602, 104.15919888404109, 104.84325239735266, 94.1493494279923, 87.3604013073829, 85.71699096310525, 84.88005130521714, 85.70502773407968, 90.56828821859052, 86.67019751764114, 92.67634253348075, 87.37270186024328, 88.60535375533566, 90.16913214037496, 91.73720159838277, 91.15210948451873, 98.5622198350968, 96.03525638580324, 91.34918505145659, 88.81067414437571, 92.72994564425562, 94.90409189654936, 98.5462087200534, 98.12755846208142, 89.82134342193605, 85.7135549668343, 98.45694341967183, 105.52503878070463, 106.52562756692211, 52.61097469637471, 16.841066998820153, 8.405948165924318, 19.054431069281794, 43.48376051072152, 40.41265449216289, 54.37034599242672, 65.06003241385183, 65.53701223865633, 61.65158687099334, 66.8347401772776, 69.18429482367732, 70.62717791526549, 72.16934404065533, 66.73965407956031, 68.53717434790828, 64.67140005480859, 71.19373290769516, 73.91995276174238, 68.84162872068345, 74.5929765701294, 81.99885860566171, 78.57182102818643, 81.118451241524, 79.78013853872977, 80.08527540391492, 87.1042234666886, 95.22047811938872, 87.69526973847421, 87.14429440036898, 82.9147320408975, 85.52975270055956, 88.15232000043316, 83.70818830305531, 84.94245621465868, 85.17337399144327, 96.94529333422261, 94.63669607716223, 91.21291406692998, 99.17492543497394, 96.29505065179642, 49.84929269359958, 6.739775326944168, 0.7624102119476565, 0.14777944843855598, 0.7391016497727364, 0.6805554945622722, 0.379872358133716, 0.32273834811583646, 0.4564878614919801, 0.5037383260505816, 0.5039123505834611, 0.7840787943813109, 37.006370175269346, 119.54012240132978, 87.74783734352359, 66.45986357042867, 99.35534661816013, 69.503214897648, 42.43792718456638, 43.83076475512597, 56.243022795646425, 81.40331729765862, 83.53142276886972, 93.22083811606132, 37.33645331475043, 1.3939233316529183, 0.23492813981588812, 0.40268740646781465, 0.18419413556975706, 0.3052033616169807, 0.24064925379089772, 0.27342701511036965, 0.2542047352800446, 0.39369718081528143, 0.20985740687577956, 0.1994231820947701, 0.30044653783402137, 0.3436799131093487, 0.2912956175784911, 0.37558131580871923, 0.38788088807655924, 0.4072562629176725, 0.37253528893474613, 0.10752496009151782, 0.3114066819750494, 0.2104000729178229, 0.1664408752995153, 0.13285728141425118, 0.15792180904217307, 0.13433278207817387, 0.22984038137139814, 0.2062211705431823], [0.049441725000618934, 0.12296035239893584, 0.15704096114683538, 0.09125968005748526, 0.061582077384716084, 0.17375274020577633, 0.170693076966751, 0.10033335566761033, 0.087420598964297, 0.19895646600953995, 0.35774865818600504, 0.2582464006639296, 0.20729000109337992, 0.14325320179904663, 0.05208691168997077, 0.03477832332493798, 0.06644333427351329, 0.01021586003668246, 0.01522915856537199, 0.09230099272944274, 0.046794726513326175, 0.09968629482412532, 0.04373928441876366, 1.3464329896434661, 42.94403845264066, 93.71032637934532, 93.55360415674026, 87.69186512116464, 73.79167556762695, 53.343292974656634, 37.10268789722074, 30.980589774347123, 70.86329675489857, 60.28755910934941, 55.85735967082363, 102.14070796966554, 97.91935905333489, 57.24095221488707, 3.0019095251637125, 0.20775972024327327, 0.2630312326214006, 0.1809469340068679, 0.09657961676918692, 0.16604451672925105, 0.05449556490226139, 0.4083415030712082, 2.46793128790394, 1.037857186409735, 2.104790167462441, 0.39476133822914095, 0.8493016203564983, 16.685017462699644, 55.63423564357143, 80.24705748404227, 95.6187242077243, 73.25611514429893, 65.00287171333068, 71.59264579896005, 70.23588226687524, 63.87370763286468, 69.75527424966135, 67.75437124313848, 63.60038118977701, 68.20148221908077, 67.29377515854375, 71.65203832810926, 76.29774847338277, 77.17570043379261, 81.36745898954331, 83.05386635564989, 85.17873194909866, 84.06921109845563, 87.75394839625206, 89.56405947285315, 88.37525967628726, 89.64990446644445, 84.2824468305034, 80.85496994756883, 81.39577850218743, 81.4176025698262, 74.5210010774674, 70.91683710775068, 73.78929861130254, 91.77750002953314, 87.11614747201243, 53.882916973483184, 70.71452125426262, 87.51508389749836, 49.01041146247618, 51.22244388826432, 58.194260751047445, 59.73981972663634, 70.80183321429838, 74.0730820932696, 70.83181581189557, 71.7791937243554, 77.82283659904235, 73.84256439824259, 73.4103427394744, 74.75517442149501, 76.72793834440171, 67.54286919870685, 70.43353834459859, 59.791445962844364, 65.66019035154774, 70.91870415595271, 68.28243993943738, 66.5833790071549, 77.00759549294749, 77.58756499136649, 78.87788357273226, 69.31703567504883, 74.90970796154392, 86.29107690626576, 79.95200895494031, 75.50631615423387, 71.82231626202984, 73.5379139069588, 69.48097505877095, 72.79891583227342, 72.4425292784168, 79.44168506130096, 85.36954741324149, 77.63673582384664, 52.65527786747102, 32.42795221267208, 11.435158368079893, 0.5102801040535974, 0.2265481491603198, 0.27160482901719313, 0.2714225920217653, 0.20666720225445687, 0.07790587887528443, 0.14774819205124534, 0.034695796503294865, 0.017594245315018683, 0.6990490409155047, 20.637044675888557, 90.51849765162315, 81.98527151538481, 51.639725239046165, 71.62225184902069, 62.38172823382963, 36.5058365175801, 41.877055706516394, 38.85718760951873, 59.75153584634105, 61.80117822462513, 75.48981866528912, 35.71094074556905, 1.2741656481258332, 0.05571094041149463, 0.10464792455276174, 0.05667684321862556, 0.03186261375254441, 0.009890565697494294, 0.02332357175257658, 0.11516644198807979, 0.11820550512282119, 0.10912412266817786, 0.022046210154169993, 0.06254838238800726, 0.029396285610874335, 0.07485434382913575, 0.08083654822961939, 0.12176134818864447, 0.052783630352707646, 0.14418925399020796, 0.080762705014598, 0.08119844050417024, 0.08275953617187277, 0.12371501795226529, 0.21396981281859262, 0.07116793639837735, 0.06448985603187354, 0.037079735719148195, 0.0369238329961175, 0.10992126013602942, 0.07722592221633082, 0.05405573084229424, 0.02043768598307525, 0.11670614082005717, 0.08442138006249744, 0.0592341021664681, 0.0627314620801518, 0.10952395927761832, 0.18774253226095633, 0.17327739797051878, 0.05239946024131872, 0.0664429052642757, 0.037760155861296, 0.023348634319019415, 0.09379127889030403, 0.03756812060131662, 0.05124985721082457, 0.1064150365850618, 0.05083893147868015, 0.05628729133956856, 0.1543577535138015, 4.5231478444991575, 66.38586413475775, 113.72739730342742, 105.22692295812793, 110.35619858772525, 99.63941251077961, 79.8915103174025, 59.54743923679475, 22.354638807235226, 44.277310909763465, 68.4079400954708, 58.58075934071695, 96.10497259324598, 108.79956676113991, 56.516682640198745, 0.6255923632171847, 0.2455334320303894, 0.23718465179685624, 0.08123577196872042, 0.12259052345348943, 0.3962621044728064, 0.43733612303772285, 0.8259253360090718, 1.780250195053316, 2.6726343939381265, 0.7850761182846562, 1.5191728237175173, 2.5995684823682232, 31.663878425475094, 75.55416122559579, 95.18756943364298, 100.05773328965711, 79.01981061504733, 75.0781031577818, 84.22855346433579, 79.36739537023729, 73.4112056609123, 80.2263944379745, 74.73666867902203, 74.19416566048899, 79.27651405334473, 80.72324106770178, 81.6681714211741, 84.75879515371015, 86.00862703015729, 88.84478307539418, 90.61662750859415, 91.8057881632159, 94.5116352265881, 97.25305034268288, 100.02797034478958, 98.7711331152147, 94.6892793716923, 86.23191187458654, 87.70404800291985, 92.47545442273541, 91.39941492388326, 84.68286591191446, 78.39059183674475, 82.88274118977209, 100.01618754479193, 98.68947721296742, 68.6316877795804, 85.94440998569613, 95.64754578375047, 49.326221096900206, 52.94942425143335, 63.912280221139234, 65.53726719271752, 79.93813945401101, 82.42835813953032, 81.96373770313879, 78.98040648429625, 81.58956712292087, 82.52584472779306, 83.37022904426821, 84.24102660148375, 82.41419838320824, 76.3355444323632, 76.01158803509128, 63.03203367417859, 68.68166662031605, 77.93558905201574, 76.4179063612415, 76.02679114187919, 83.95589382417741, 81.7690783162271, 84.58370839395832, 75.44122049885412, 75.65168703756025, 82.40113689053445, 81.06530312568911, 79.43595840084937, 74.3414741946805, 76.2298208667386, 75.61722509322628, 73.35379000632994, 76.25146450534945, 82.53020640342467, 84.24841634688839, 89.45561378232895, 83.93603878636515, 57.745631817848455, 24.374696708494618, 2.2303057678284186, 0.09315424613774785, 0.2642343583847246, 0.16814882236142314, 0.1827331752546372, 0.05369620960986903, 0.09523965238082795, 0.07656913205620743, 0.032508818492774046, 0.7116550483530568, 16.85695848157329, 96.05491530510687, 88.32386878228958, 60.53722581555767, 52.91287952853788, 17.888757567251883, 30.7733807640691, 60.11947770272533, 56.792539012047556, 80.06875438074913, 73.43157845158731, 88.00337191550963, 54.10173423828618, 2.2484702640964143, 0.08491838726425364, 0.28248860951392885, 0.13202809848852698, 0.0291813328306401, 0.06439610985257933, 0.04736550798219058, 0.023060979794770963, 0.05674111033459345, 0.020869635083081744, 0.030815620538628394, 0.02873874276936535, 0.03811480094408316, 0.08096558807958519, 0.11657338544365861, 0.13566025923336708, 0.09427247403730309, 0.07880307508692627, 0.03399683703337947, 0.037290597589866775, 0.0862123174292426, 0.05191320508357979, 0.04694375742767607, 0.009042707463395933, 0.05492636678560127, 0.013384204339085808, 0.12312863127238328, 0.18370328771491207, 0.23957334458827975, 0.10457561351358892, 0.25227681373155886, 0.22972272558798715, 0.4539260634731862, 0.2169534801355293, 0.16128390847194582, 0.3035038108787229, 0.5171467339800251, 0.26945769907005374, 0.253408509456823, 0.28728747620217265, 0.1872735638772288, 0.19457338588132014, 0.1755456310967284, 0.17189627933886745, 0.17550502843674154, 0.21569752494894692, 0.16889672335838118, 0.21449819898172734, 0.21016531293430638, 5.205430407677928, 75.94465671047088, 134.47154229687106, 116.58658550631617, 116.62527576569589, 99.05744260357272, 70.0935394533219, 53.6149484880509, 47.41870972418016, 103.83996502045663, 88.95944180027132, 77.01785641331827, 131.12256773056524, 116.69870253532164, 79.01358973595404, 5.578611079723605, 0.4363281351904716, 0.6768712245168225, 0.29277851865176235, 0.20958213616282712, 0.5864215522043167, 0.2885572209713921, 1.1840841270262197, 10.874088810336206, 10.364005161869912, 6.644727472336062, 2.940456035637087, 1.5861488878726961, 31.36527426781193, 81.26650502604824, 104.39290154364802, 109.69822099131923, 86.78787646755096, 82.1699994610202, 92.73455050683792, 92.01124975758215, 82.68831714507073, 89.56994302811162, 86.75795662787654, 83.54187196300876, 88.38874478493968, 88.05455884625836, 90.65413321218183, 92.07815754798152, 93.86110228876915, 98.11357129004695, 97.68962583234234, 98.48866754962553, 100.72141401229366, 103.69084435124552, 105.03347950596964, 100.42099183605563, 93.9958200147075, 88.10561241642122, 87.35779685358848, 96.69305355318131, 91.91923879807996, 89.61808619960662, 85.23839904415993, 86.80544868592294, 107.79860927212624, 103.199842053075, 65.71729613888648, 84.55979762538787, 104.5210139982162, 58.087642885023556, 62.94571015142626, 71.80326923247307, 70.41851566683862, 81.70102519373741, 84.23895559003277, 82.73698591416883, 81.0315550527265, 82.55647843883884, 81.23487503297868, 83.35845408901092, 87.04621161184004, 85.78469891701975, 75.92509192805137, 79.97260924308532, 72.4401915457941, 71.43402514919158, 76.17551957407306, 75.43608219392839, 75.94521368703535, 86.72424777861565, 87.9713418406825, 93.60074320147115, 83.55515310841223, 80.62401294708252, 86.92515942358202, 80.57885862165882, 79.24775523524131, 79.18337345123291, 81.65936962250741, 79.98975784547868, 78.3321406764369, 79.37005473721412, 91.26085327517603, 91.58026756778841, 93.79173909464191, 99.09360685656148, 80.76823065357824, 26.70019545862752, 1.044516880666056, 0.429333599224206, 0.6429294232399233, 0.5540010789709707, 0.64223246708993, 0.17000444053161531, 0.3330716791172182, 0.39292879462722813, 0.17605348610349242, 1.3992798184194875, 27.804738821521884, 109.62903822621992, 98.38841961276148, 70.21022212120795, 103.462750680985, 80.087644515499, 50.25479516675396, 54.183068506179325, 47.89237906855922, 78.98146552424278, 77.43776967448574, 103.12104948105352, 65.24093604856922, 3.880431700137354, 0.22604784778048917, 0.4017555064732029, 0.19999502076497003, 0.11216762911288009, 0.11357237389611621, 0.09560024230590752, 0.25749146697982667, 0.2607031527065462, 0.17902316465493173, 0.1718269177382031, 0.10222913216679327, 0.1384481757638916, 0.18396518253270658, 0.22195919056332883, 0.28326477915529286, 0.09112111773462066, 0.2602321312071816, 0.21005953151372173, 0.22088744887901893, 0.21347721828328026, 0.21616054849038202, 0.25846810650921637, 0.21924776025116446, 0.17229248469154682, 0.14098605651768947], [0.08496420698300486, 0.04014197301359908, 0.0798876564048471, 0.09449742043450957, 0.1697335824851067, 0.11151671484713593, 0.10834195455836673, 0.05173797013177987, 0.11204412041772759, 0.11337162055555852, 0.08602736848256282, 0.12017872545026964, 0.0891615184504659, 0.12165921334657939, 0.15152451522167654, 0.18689327783161597, 0.10362987031018543, 0.03803796998615708, 0.03967449467088427, 0.12617586856527677, 0.050713250924262314, 0.08522309107525695, 3.8974839593133623, 58.76872716411468, 92.2612145639235, 85.1675610388479, 75.68367004394531, 76.77393990178263, 54.34298353810465, 37.36130545216222, 40.853309246801565, 92.06619431895595, 50.179352298859634, 37.372150805688676, 85.58945901932256, 97.73177562221404, 59.66758535754297, 1.6764847501631708, 0.443084325881735, 0.05463157998277776, 0.16334758080061407, 0.06226655779286258, 0.1962549335533573, 0.03475384298531759, 0.29564206338217186, 1.393944782114798, 0.14118818115563164, 0.4060186019107219, 1.2722700401659937, 14.720100241322672, 54.889330479406546, 84.33965852183681, 72.84764735929429, 74.01456033029865, 68.16444719991377, 67.46660263307633, 65.53698085969495, 65.8038785380702, 56.68548968530471, 63.44214100991527, 61.964478262009166, 55.493202901655636, 62.61982002565938, 66.06730491884294, 72.32972191226098, 75.00117763396233, 81.54113369603311, 84.4218635559082, 87.40551640910488, 99.70675176189792, 103.37900023306571, 104.27802316604122, 97.91253412923506, 106.44803524017335, 100.06544466941588, 96.04573695890366, 89.02478064260175, 92.4209491668209, 92.3971482246153, 97.45642523611747, 91.21059202378797, 89.68035774846231, 82.29424445859848, 76.16808276022635, 87.8455122055546, 94.31926650385704, 90.64292307822936, 83.80685944711009, 69.96560742778163, 69.7886065513857, 60.45218098548151, 66.6844977101972, 79.32539463043213, 77.6195401530112, 77.44970936929026, 80.0608233482607, 88.88703484689036, 86.30216152437272, 87.93789971259334, 87.80617083272627, 83.8088990795997, 79.45221270284345, 69.34461778210056, 57.00117772625339, 69.3247470548076, 73.63832658337009, 81.59146555008428, 88.54526304429578, 82.75998669285929, 80.68142075692454, 81.36696477090159, 76.11177321403258, 76.68814197663339, 74.39124122742685, 77.51993548485541, 77.9701529779742, 72.60317387119417, 64.85697523240121, 66.13555415984123, 69.81454126296505, 78.28423284715223, 79.12003501769036, 71.45260933906802, 73.72472855352586, 76.75700310737857, 51.419084072113044, 32.045703511084284, 19.147879577452137, 2.1186000973947587, 0.4924841267206977, 0.21014174806975552, 0.09609472907839284, 0.21812682040035727, 0.06795074249948226, 0.06824789268355216, 0.021427040656788215, 0.06100800939865651, 0.32998394641664724, 18.92372985039988, 81.26172757917836, 90.74507728699716, 54.57581543153333, 64.25268703891386, 73.55405053784771, 35.53654432296753, 42.43640138256935, 48.743631455206106, 52.681279259343306, 69.29392506999355, 72.64451565281038, 50.86972082814863, 5.076758525063915, 0.19617780382114072, 0.049175865677816254, 0.07878265118286495, 0.09503632498484466, 0.02345215961066706, 0.09958711708144796, 0.05948287772855932, 0.038983797459232236, 0.06809289777471174, 0.02844896043590721, 0.03177493690483032, 0.0352327743425004, 0.046047660552205584, 0.010347752606556302, 0.15724415830787153, 0.017435211207597487, 0.05638500202387091, 0.1307155906913742, 0.06989816098564094, 0.04075745188240563, 0.012802983964643171, 0.03276882490383522, 0.07363826351901216, 0.019898974869941032, 0.07539864929933703, 0.07253287525306787, 0.0576368777922565, 0.06270990436596256, 0.040784100250851725, 0.09900197146400329, 0.02204803918908921, 0.02172413912992324, 0.09077344405194444, 0.06996941482347828, 0.019072810330638484, 0.050452811673523924, 0.03061687626365212, 0.10901410478137194, 0.1083200597654908, 0.06023656651978532, 0.022071268890173208, 0.020704351613418232, 0.03776294059090076, 0.13388106599450111, 0.02048441543123655, 0.06556023407967822, 10.811076914110492, 85.23322151553246, 107.42600763997724, 102.58872109074747, 107.66441714379096, 112.59413042376119, 88.05862242175688, 47.59889948752619, 9.281897756361193, 37.258680558973744, 52.08017603043587, 40.65310755083638, 92.19746035914268, 110.85107618762602, 57.265055179595954, 0.519792556522354, 0.25577463329799716, 0.151128999348129, 0.13268880335794342, 0.06057802722939561, 0.2262269131719105, 0.4343711482661386, 1.66883232853105, 0.655071671691633, 1.6363939594837928, 2.809691813684279, 4.545247458642529, 28.908564390674716, 80.81773096515288, 97.79427466853973, 82.89264125208702, 79.94686280527424, 74.5504580774615, 81.7114116299537, 78.31975383143272, 72.40945585312383, 69.361585955466, 75.71062457176947, 74.0532741238994, 69.76574697802144, 76.4406325740199, 78.72085540525376, 81.81711166135727, 82.789412313892, 87.62229796378844, 93.26219558715822, 95.64935007402974, 101.89265727996828, 108.00765591282999, 106.13535173477666, 104.27595215459024, 106.56009735599642, 106.37383968599381, 101.3975678720782, 92.72839238566738, 91.30346590472807, 94.99144308028683, 100.35162079718806, 101.68252806509696, 101.74124594657653, 88.28913227204355, 83.94295000260877, 86.80757461055633, 93.36703269712388, 91.27225168289678, 87.62932685113724, 68.59628446640508, 72.82419158566383, 67.80740953260853, 72.47310807628017, 81.12746484817998, 80.53042519477107, 79.39176897848807, 86.68210583348429, 94.02566925171884, 93.95694932629986, 95.05748010450795, 94.92398615806334, 92.34696542063068, 84.7650944802069, 75.5138941734068, 68.54211653432539, 78.74954362069407, 79.65663094674387, 84.95984800400274, 88.074445263032, 87.042250017966, 85.566160140499, 84.66793737103863, 82.24155133770358, 82.58310348756852, 78.27048101732808, 78.99029870187083, 77.9728437239124, 75.55111746634208, 69.43585211230864, 69.80173864672261, 71.94642005428192, 76.73664600618424, 83.65627965619488, 82.72233193920505, 74.00449552843648, 79.50655321921073, 82.49433240582867, 63.10956324300459, 35.09830574835501, 6.23979276226413, 0.6432365938540429, 0.12593140990863885, 0.11233886508571525, 0.2331943602691735, 0.0338290024909281, 0.0512313561874532, 0.13249602499267749, 0.1366569855881314, 0.30862909230974417, 16.31813660744698, 85.67117767949259, 99.01699512235581, 64.3033052259876, 50.18954261656731, 29.183504889088294, 31.92625164985657, 62.10045114640267, 65.95161068824031, 71.94605135148572, 83.258072791561, 80.3928441386069, 70.03953626078945, 12.234930626807675, 0.13180875219404697, 0.05787689313893357, 0.007137241388385695, 0.06179231489377637, 0.02324328956855161, 0.10914294544847743, 0.05419768693466341, 0.038532809159087564, 0.05142077525717117, 0.03268096227979949, 0.04625446981780472, 0.06036166867782032, 0.03749547631389672, 0.04558181397676949, 0.10919240408486898, 0.0577319837776163, 0.04953148752270688, 0.1231603473124485, 0.02748523523370105, 0.036627280360628525, 0.023948781853241306, 0.11786284931604901, 0.05227802764444102, 0.033982744846012325, 0.18802891124881085, 0.11469530557552654, 0.21917801560653796, 0.185251459479332, 0.2826529200519285, 0.1311922812413785, 0.2064460326707171, 0.2214346041962985, 0.1984925231625957, 0.17488596810688897, 0.11822257356177415, 0.2864426650827931, 0.16085276950991925, 0.20512414795737113, 0.3425965728538652, 0.1997380442316494, 0.22280887400190677, 0.09345917977512845, 0.20652451071768038, 0.3026850773922859, 0.10575991649661334, 0.23206251132632458, 14.249433471310525, 103.93028151604437, 126.35203207692794, 108.90297612836285, 105.43699725981682, 100.51903540088286, 73.65038394927979, 51.99062439703172, 62.45998736350768, 136.26458321848224, 81.44122308300388, 57.8195135824142, 112.91359962955599, 116.66773934518139, 79.00191676232123, 3.858381851065544, 0.8679714895063831, 0.4766567195615461, 0.5069119831727398, 0.12629609840411332, 0.5219760296806213, 0.22499571794704085, 2.1647788968778428, 8.849202471394694, 8.26725511781631, 7.08492232907203, 3.7769338344374015, 31.271158956712295, 94.2800663363549, 108.94342360957977, 92.52176976973011, 84.53360403737715, 79.49558627220893, 91.52224002345916, 86.87969130854454, 87.9044811187252, 79.7330230282199, 82.89943479722547, 84.71376634413197, 78.2724343576739, 85.96012300060642, 87.13144471568447, 88.27592957404353, 89.30468882283857, 94.94708107363795, 97.72532724565076, 97.93247545919111, 103.19453900860202, 112.93925977522328, 108.10087496234526, 105.47220445448353, 112.66070089032574, 113.12002612698464, 104.98662287189116, 93.16210454510104, 90.72224909259428, 94.4323641254056, 95.77111613365912, 101.81240558624269, 108.66116200723957, 90.02996644666119, 89.8597042022213, 95.9676504135132, 105.3481085069718, 100.13360761827039, 94.69561792189076, 76.91541194915771, 81.0255616711032, 69.72658603422104, 76.23831672053184, 82.56346810248591, 82.55677653897195, 79.72440165858116, 89.0285853416689, 99.57126525140579, 97.37216488007577, 99.71241566442676, 97.43573081108832, 93.44995944730698, 88.49413887146981, 84.95560399947628, 67.03838179188391, 74.6081090742542, 84.22865544596027, 87.41706386689218, 91.7126161821427, 85.61864929814493, 86.80265595836025, 85.19040492273147, 82.63225078582764, 85.99513407676451, 84.64689777743432, 80.89686086100917, 80.91464488737046, 79.57983093876993, 72.26446151733398, 75.02210740120181, 77.75620337455504, 79.59650101200228, 83.32480799767279, 89.95340178089758, 89.49769296953755, 83.83211166627946, 87.27152039927822, 82.23674251187234, 48.146140729227376, 3.949268806365229, 1.4600834202381874, 0.45538166117283607, 0.27029199946311216, 0.5720597938183816, 0.12205236966932013, 0.35223340735800807, 0.26645095718483774, 0.27329579957069894, 0.5737130728460128, 27.78009064735905, 99.1746744032829, 107.84343411845546, 72.2669953684653, 96.15037010562037, 97.84224525574716, 47.92668804045647, 52.64038070555657, 58.652726988638605, 70.63107675121677, 83.76039505004883, 94.07119227993874, 85.91343110607517, 17.678812703778668, 0.21139702909896452, 0.19644680793487257, 0.17067369494226672, 0.15447939295441876, 0.1341301211786847, 0.24454266583967596, 0.17890668864692413, 0.09202947584731926, 0.1405352290960089, 0.10333524821626563, 0.08742645187603851, 0.12358157309673487, 0.156903479007944, 0.1817488595242462, 0.2768707029040783, 0.18392761358089987, 0.1178913018215568, 0.21281286683534423, 0.12560207637086993, 0.08409946225583555, 0.12870225033933116, 0.2061931623686706, 0.1686313811449274, 0.17721651482485956], [0.15040443338934453, 0.06797635281879096, 0.12501691543166676, 0.09511759925273158, 0.05003514436764583, 0.014178671032911348, 0.13647375267840203, 0.03937089019605229, 0.0558887264360824, 0.16309933766963022, 0.07390130746869311, 0.12022809215611029, 0.17414195883658626, 0.19012082157836807, 0.13137416583636116, 0.12015043382322597, 0.03128803631801519, 0.13059220457028958, 0.03259794133144521, 0.0326146190655568, 1.0964349657297134, 23.580524613780362, 74.77743779459308, 96.3291988065166, 83.03788661956787, 64.11400771910145, 54.64195835974909, 46.89518705491097, 37.2119455183706, 48.28756570816041, 137.5603146706858, 130.61025127287834, 93.89264598969491, 119.77548814588978, 103.72539258772328, 66.29476316513555, 2.429192489193332, 0.1270012287122588, 0.2763293851767817, 0.17217512002154706, 0.09530391183591659, 0.282756740287427, 0.11423664873525982, 0.5163175204107838, 2.320898790513316, 1.0603000079431841, 1.3230948871181858, 6.438137706248991, 29.56150370259439, 59.385904265988266, 46.514846586412006, 59.19694408293694, 72.15124622468026, 62.8097019657012, 70.98209750267768, 63.53104545224098, 61.323598277184274, 52.891439853175996, 62.50139974778699, 64.40648709574054, 58.850532116428504, 69.96246168690344, 71.55519500855478, 79.0586656139743, 80.88325808125158, 86.37576872302641, 90.83396603984218, 97.05104827880861, 98.3291918231595, 102.40717026495166, 97.744931251772, 97.30603371897053, 103.78990773231753, 98.9695893564532, 95.200317136703, 93.37117472002583, 89.9426309524044, 80.19779251467797, 85.33326548914756, 89.99626544214065, 99.6963417914606, 104.87896950014176, 80.64280894494827, 80.91510772705078, 70.15333990896903, 88.58545949382167, 93.49247793997489, 85.6100122390255, 78.30721009162166, 71.42320725225633, 78.05321308874315, 87.91131388756537, 85.39658038846909, 76.1069957671627, 87.97174976718041, 98.3949621262089, 95.71741888600012, 86.44954850596767, 89.93285640593498, 91.63356473368984, 88.86137470122307, 87.18231001207906, 91.82127368065619, 88.08121527394941, 87.33675725998418, 81.61068516392862, 83.03901626217751, 81.43144069179412, 86.91307067871095, 85.81264188212734, 80.54656967040032, 85.92915196572581, 88.27126979827882, 83.86725610302341, 81.37822197329614, 74.16841922267791, 68.44018197828724, 65.99040292924451, 66.34981755287417, 67.14796496975806, 79.82729327294135, 85.32790753149217, 99.03284934259231, 79.47995170470207, 62.29134898031912, 67.39472912203881, 55.32179140275525, 30.53791499906971, 26.015679105635613, 4.988587565960423, 0.2541492092272928, 0.0953139705703624, 0.13319719462625443, 0.2085775803894766, 0.21828923104030473, 0.17101553869583916, 0.15984861210228937, 0.02861060307271058, 0.5130902677774429, 13.14047646137976, 71.93722601859801, 86.0047831073884, 66.44229919679704, 74.89193177992298, 63.76452061437792, 31.250521406050655, 35.755710678715865, 36.61629830637286, 52.47122064713509, 75.81368877041724, 69.68630329255136, 63.59193240442584, 19.221192598342896, 0.27299092722035223, 0.09558419276389385, 0.07192615659967547, 0.11142502178347881, 0.14600865152334014, 0.019836383571307507, 0.06329387020800384, 0.05343124660993776, 0.053156715171832236, 0.2381476243176768, 0.058093914356563366, 0.02267691310525181, 0.03324276136775171, 0.030062343519661697, 0.06756677157095364, 0.0839088672411538, 0.08279766436786422, 0.09453765537229278, 0.05235652484360242, 0.07246448658406734, 0.07601685161071439, 0.07951414257648491, 0.04463618185611502, 0.056582851891195586, 0.11458673559489752, 0.13804106131917046, 0.10248704332738154, 0.03629205177628225, 0.028942378515738155, 0.01825466290146353, 0.039174944057219455, 0.012514298094526656, 0.06350649025050864, 0.0047606815144629975, 0.08098145376049704, 0.06503054556707222, 0.07909410422848118, 0.18825239441808195, 0.08648541245249011, 0.015772558136602804, 0.21027290232239232, 0.03237861035872371, 0.07325639933227532, 2.823606667018706, 40.78317726812055, 100.89415519468247, 109.69945261555334, 103.99179996982699, 91.42462007461056, 84.7308208096412, 60.77490183614916, 41.67866614557082, 29.60081369646134, 84.20868273704284, 131.5135182103803, 92.79082082932996, 119.43885464822094, 115.75950668704127, 68.11628833893808, 0.6197607793634938, 0.00955729446779456, 0.2386065416278378, 0.07678805700232906, 0.20098423945807642, 0.04551058312156989, 1.1628062494339482, 2.04118354185935, 1.5229698006183872, 0.6475483818400292, 2.7908033949713555, 14.854945444291639, 53.32502649676416, 80.17196762946345, 60.812050604051166, 67.92751250728485, 82.61081111046576, 74.73044779992874, 79.27404296013617, 69.86496725390035, 69.56012848884829, 66.49661617894327, 72.087186075026, 74.3793015326223, 70.38678369214459, 81.92911101925759, 80.48164659930815, 84.1841757682062, 86.81123810429727, 91.04334215964042, 96.07058909631546, 100.6918550306751, 101.3395481724893, 103.12346566107966, 97.97053813934328, 98.25146613582488, 105.39452583559098, 101.48310692079606, 98.01548065677767, 96.48769394043954, 95.74089034911125, 79.42644273081135, 87.85614182872158, 91.81604123884632, 103.02724992075275, 109.83426447837584, 83.34711059447258, 87.3120149489372, 75.2180847044914, 89.17367381434288, 95.92017404494747, 88.45079668106573, 84.12052354504986, 77.78184783074164, 81.87054218784456, 89.74398643739762, 87.01199285445675, 77.31062212297994, 89.23620423962994, 101.8462242618684, 97.64262014819731, 92.1501487301242, 96.34892832848334, 95.37825153719996, 89.50629080495527, 96.33061870451897, 106.0728213094896, 94.63602927423294, 91.49273595502301, 90.4308012993105, 87.00385001397903, 84.63589160673081, 88.02869473734211, 85.87856907998362, 81.19534538638207, 84.36025096524148, 86.36454289959323, 86.39706719306209, 83.96067127104729, 78.65640301858225, 72.43028363873883, 72.03956850113408, 72.30523847764539, 68.65509648476878, 79.47412306262602, 79.33742061738046, 96.81477254436862, 101.82714585335025, 76.83498767114456, 63.18599847055251, 79.34854445918914, 64.00056100660755, 41.20950360451975, 11.936237235223095, 1.0539563096338704, 0.06519890871019134, 0.23624953423296255, 0.07767731654307536, 0.2590291893049594, 0.0966445273990112, 0.21073249378992667, 0.06898112309676024, 0.5073503080394961, 10.975259484783297, 78.17348080296671, 91.29159681258663, 74.57716941833496, 67.27861912019792, 18.043648042986472, 30.396541010948923, 58.636021614074714, 55.380568119787405, 76.86726093292236, 92.541593428581, 76.47944834924515, 79.56429050814721, 31.887100511981597, 0.2168395475394303, 0.1244558939229577, 0.004206789890304208, 0.07042359004938795, 0.08493708747048533, 0.05095496315569167, 0.06427486111680347, 0.018961130033036875, 0.08621725869635422, 0.10054016876364909, 0.11757881455724278, 0.09227400345187034, 0.10797712050618664, 0.07776395342643223, 0.04706744615349078, 0.09661507897920187, 0.016468209064295216, 0.0222432786118119, 0.040858954701933174, 0.018317604685322415, 0.041266532629848494, 0.009525781441029281, 0.10002492100841577, 0.4343395241566243, 0.21862342923639283, 0.34690431589561127, 0.142338186382286, 0.12454456093931392, 0.13342184224917045, 0.15880572128920786, 0.12184138139409405, 0.25852433736285857, 0.19374567384441055, 0.2820514184573005, 0.2767348295498279, 0.22297891487758006, 0.2013247808621776, 0.5155706766151613, 0.17971426789318362, 0.12951692355976951, 0.40184210505216356, 0.13204001881662877, 0.23018490643270556, 3.594860843112392, 47.91817257481237, 118.80776882171632, 126.8716206089143, 106.72317381828063, 88.95897111585064, 68.96184152172458, 62.676910123517445, 54.23533408872543, 72.75038042376119, 172.8374687317879, 162.8499532515003, 117.39034191254648, 151.63093905295096, 123.1813527691749, 90.25336896219562, 3.8974454710560464, 0.4988010732396957, 0.8930923705620151, 0.5509974014374518, 0.5238077152640589, 0.3840663830839819, 0.7076415443612684, 4.037567487647457, 8.051847863581873, 8.098799124840768, 4.7749546939326875, 16.346227642028563, 62.55588539185063, 93.38840176982265, 69.79215237402147, 68.88776363865023, 88.4972296991656, 83.38204322322723, 91.23090990128057, 78.2938426540744, 82.53492893711214, 78.89350245075842, 80.91696693051247, 82.978956930099, 77.84127173885223, 89.14603679410874, 89.59389302038377, 92.63701685013311, 94.80132579803468, 94.75839937886884, 98.65505449233517, 102.11572247166788, 103.184568343624, 107.8645129357615, 102.49112467611991, 101.97174795212285, 110.78170514875843, 105.52754909761491, 103.21716323975595, 99.90046977996828, 95.43081129750898, 78.91516177884995, 88.16843309710103, 97.77692994763775, 102.14072365914623, 108.2240766094577, 86.09859051242952, 89.58560897457986, 85.9687679044662, 98.36377928333899, 104.087858815347, 97.58367476924774, 93.45758453492196, 79.00973796844482, 79.8468815895819, 89.77095665470247, 89.98335299953338, 79.38878797715711, 89.70147578947007, 103.72960521328835, 103.61831188201906, 100.80470162053263, 99.66092278880458, 101.00376190677767, 97.05443720663749, 104.17977563796505, 104.6696404487856, 91.50317730442171, 95.72663645590507, 91.24945486745527, 90.75800541908511, 85.75273160011538, 91.62260563142839, 91.54351495927381, 84.15680546914378, 86.40349988014468, 90.64462538688414, 89.34508139087309, 86.19303334143855, 78.76366415331441, 75.99744396824991, 75.29707339502151, 76.59129865707891, 69.13327263247582, 78.8560438156128, 80.4430426320722, 91.22841527385097, 93.64341858894595, 86.81564684837096, 77.00754057976508, 82.19842880002915, 78.9207786129367, 60.806594587141475, 9.689666378882624, 1.3163123736458442, 0.1936700150010086, 0.5962992447518534, 0.5858023080133623, 0.48138158215630444, 0.33231757280807345, 0.29810007180898423, 0.13171714340006152, 0.6067451293910704, 20.215154540154245, 91.24771333509877, 103.01794605870401, 84.47176394924041, 105.90619117982926, 86.90227631599673, 41.74711150507773, 44.724582702882834, 48.07856221352854, 69.41834265185942, 90.18008339789607, 84.21924960228705, 96.5166174980902, 40.64613749904018, 0.5339976039624984, 0.21796140669574662, 0.1314405550158793, 0.15918487352469277, 0.30626120646634414, 0.1266105851579097, 0.14406436633679176, 0.11171777462286335, 0.19005950390090867, 0.25432046052188645, 0.2078530450742091, 0.2099709564279164, 0.26396674855101493, 0.31222887817890416, 0.2482540707194036, 0.19798926468337738, 0.24915790125246973, 0.10079657839190576, 0.21305029280483725, 0.14456710387622157, 0.12083180008396027, 0.20585418378393497, 0.18819309921274263], [0.03848499761173322, 0.06449382436732132, 0.06268565002227984, 0.06136851505406442, 0.05075327135742672, 0.06353534878261628, 0.07020006857572064, 0.03692972038181559, 0.041854727277231794, 0.0057894001797502564, 0.055749440160129345, 0.010376856286799716, 0.047357567480855414, 0.12428232138195347, 0.14790421351790428, 0.14678145037783732, 0.03985963896998475, 0.13906749656363843, 0.03853609950672235, 0.6921891219192936, 50.30140861388176, 98.4143151006391, 91.68185695525139, 65.66075125048238, 61.20021227867373, 69.21761928066131, 55.76516435992334, 59.48481075225338, 59.54137133013818, 63.10642142449657, 82.83906167553317, 97.03240133100941, 104.27028040732108, 96.94629746098673, 67.36406403203165, 3.2730843030637313, 0.3263400032395317, 0.16988154470680222, 0.24692325342086055, 0.262381375556992, 0.35237746253128976, 0.13491624996306437, 0.5171785419506412, 1.091340787468418, 0.6630204774198994, 1.1229163576518337, 18.64894428560811, 41.90917207348732, 67.54057068978587, 80.42174416203653, 83.8322920953074, 75.05524358441754, 74.56314302259877, 55.27683711821034, 55.94378517520044, 55.05348951585832, 53.75340815513365, 53.60329512626895, 58.95882875688615, 68.66640860034575, 75.85765854004892, 75.32300026186051, 78.9896240542012, 81.44108187767768, 86.13695913745512, 88.639847078631, 91.83166796161284, 92.23218117990803, 91.5869120628603, 92.58800291245984, 90.3716911808137, 90.0644362357355, 93.35364172535559, 95.43045043945314, 98.87716262571274, 92.57753018409976, 90.7651755117601, 84.82160798964962, 84.57119603310862, 87.49260871641098, 90.5994475272394, 97.2774867088564, 86.8317364108178, 78.20320452413252, 66.66920831126552, 71.6896224791004, 76.05279645612164, 72.73534990126088, 73.80584316868936, 80.30781499801144, 88.22155767871489, 83.90097279702464, 80.52887978092318, 83.68729775951755, 93.92365624827724, 94.06409278992685, 85.70233698814147, 89.86223805335261, 87.84384912060153, 85.25508480687296, 79.8467403842557, 92.48286770236109, 98.59770159567557, 87.80888511288552, 84.17421294796853, 86.9213939482166, 90.87010675860991, 86.62066582710513, 85.29589314614573, 85.61630372078189, 81.30794094454858, 79.39520497475901, 78.94265759375789, 77.12399575018114, 75.78886801196684, 84.34233357829433, 85.32515402763121, 73.37531597383561, 64.48409511196998, 57.992297910874896, 71.37055335506317, 77.33275213549214, 106.28587661250945, 126.65394475383144, 101.7656744680097, 55.243485204635135, 56.28762406687583, 56.549132408634314, 29.54812449793662, 29.672504817285848, 9.389716848250359, 0.21765549246582294, 0.18052653559753973, 0.12737347083466669, 0.30175755942060106, 0.0024379895917410336, 0.1059225033367834, 0.05363206889840865, 0.3060828611975716, 0.5194502071507516, 13.318912925258761, 68.87461585383262, 86.76025513679751, 69.403014029226, 74.57170163431476, 69.07921452676096, 31.527124989417295, 32.682337530197636, 36.78997301286267, 39.124336319585005, 75.08229224912583, 63.55723904025171, 72.26463410162157, 24.37312383805552, 0.5811337682027972, 0.07909352200165873, 0.06950675900424681, 0.18055247533465588, 0.053570628646881356, 0.051662445353764685, 0.08272762860982649, 0.07874043207735786, 0.04774451849140948, 0.07801632577132794, 0.0015998028585829983, 0.011986338067799808, 0.04228618416574694, 0.03646545960838276, 0.010494217126359864, 0.04261805345454524, 0.035570013907647906, 0.09350974157813097, 0.04847987479860744, 0.032286197172417756, 0.05149774794136325, 0.0801235042332161, 0.025195103484175863, 0.08999771874157653, 0.01776386292711381, 0.023046004691071088, 0.16281994540364514, 0.024019489853432583, 0.03774421740203135, 0.07176154728738532, 0.02301336551505712, 0.058968771444333185, 0.0771431617378708, 0.06604110746974907, 0.012285391980361555, 0.05718151896050381, 0.024080891800563664, 0.0008031632281809806, 0.11852070433838714, 0.11936600575403822, 0.06148423263502698, 2.070756006625391, 70.70393869953772, 116.90465834832962, 105.78413486480714, 87.65121367669876, 91.63853829906833, 92.16586958977484, 70.28674756326984, 33.784296051148445, 25.697825916351814, 47.493936861715014, 97.0692402316678, 106.92170066218223, 111.39832527406755, 112.00338225210868, 70.22698633132443, 1.7232702912822848, 0.17291059507237327, 0.20538432673821527, 0.024881629881659345, 0.12733358829732866, 0.5879082530736923, 0.23543267000106075, 2.204556633387843, 1.5639416536977215, 1.3390700879596895, 2.3836272954940796, 32.501900657530754, 65.79455898654076, 83.28174037318077, 88.12992326674923, 95.23114696625741, 87.37225471004363, 79.92456805321478, 64.24800372892811, 66.97518456366755, 66.94683367206206, 63.34911807890862, 65.86326322247906, 69.81596900570777, 76.35167321851178, 81.49667755250009, 84.17847264197566, 85.3970589176301, 88.526898507149, 90.28943907830023, 93.77355498652305, 94.51214513471051, 96.92193954221665, 95.01768373673963, 94.10861953612297, 95.09759026189005, 93.29268024813746, 96.02002190005396, 99.05611684245449, 99.89322908463018, 99.10385993219192, 97.05532366229643, 86.68424744759837, 84.77704986449211, 88.00907504174018, 95.47780913691368, 97.10262744657456, 91.25309482697519, 81.60025950401061, 74.08088760991251, 76.54274755908598, 78.48883936482092, 76.09938636902841, 77.1608268060992, 80.77367490337741, 91.33522925838348, 85.42584911469491, 80.06937411523636, 84.27810084435248, 93.6410730115829, 92.76352113293063, 88.39101975963962, 92.68017861150926, 89.95095422191005, 90.94787166964625, 85.33544632696336, 95.094083662956, 97.64851939293646, 90.62369561964466, 86.56054373710387, 90.76257105796569, 95.38630024079355, 87.72857066123717, 88.61351228529408, 88.35491041983329, 84.95695329481556, 80.98622814301523, 79.05742614499985, 75.68002223968506, 73.60220155408307, 80.96552587324574, 89.650508511451, 83.70361481943439, 72.99959213502946, 68.55342864990234, 80.1878140049596, 81.20159764443675, 93.75475114391696, 104.9031783688453, 114.09337797472554, 91.70412032834946, 56.54705747481316, 74.31128763383435, 63.865156865889034, 42.39899766060614, 16.97231342715602, 0.5340869604579864, 0.20635811642052668, 0.17560207645498938, 0.45932980254292494, 0.2051660529668293, 0.05011638799201577, 0.06598880664715845, 0.19089542840036655, 0.5891168333830372, 12.419818409027593, 77.38266821830504, 94.42950863992014, 76.75699526263823, 64.61577692339498, 22.11960058058462, 29.52121899973962, 49.98849761101508, 54.34537226153959, 55.71072186193159, 92.60986620380034, 72.93491225088798, 79.86253969130978, 38.78088966492684, 0.598700593315786, 0.04882838734756074, 0.05670669766503477, 0.06941862824943758, 0.09464383515859805, 0.022530088524123835, 0.0526703680835424, 0.03827618885665171, 0.029092110400538773, 0.035779500650542403, 0.04620682297935409, 0.01618661238030801, 0.03138628709430416, 0.026407801516113744, 0.07193167243273028, 0.050608097695775574, 0.026115726664542194, 0.11139623219928435, 0.04002358944666001, 0.032003074058241425, 0.048394927139123606, 0.1323131751269102, 0.1609862220263289, 0.19977746711623287, 0.11514890623549301, 0.1023216832489256, 0.31097283106177087, 0.21262255527319449, 0.1540684633918347, 0.15545306006266227, 0.15282225284364917, 0.17481965553616324, 0.14690767102424176, 0.11556716725951242, 0.15399537860385834, 0.2911767513761598, 0.18044669391407123, 0.20777629838595468, 0.1672166006098832, 0.21394994049783678, 0.14681952494767406, 3.4332893452336712, 85.89203849915536, 137.12350383881602, 117.63217172315045, 90.71691466915993, 87.18016055322464, 84.57962912897911, 73.15178009771532, 79.03709257802656, 80.37321659826463, 84.41519552661528, 107.4693968988234, 114.13621810174759, 130.40737059808546, 121.96694774012413, 88.759487213627, 5.108963145363716, 0.44247614400040725, 0.6797680787501797, 0.4281576849039524, 0.28203076472686184, 0.5795006526093329, 0.6026525651254963, 1.0723992941841003, 6.996060052225667, 5.563750199733242, 4.215250611305237, 31.69058192160822, 79.35886029274234, 93.07916210543726, 91.2888119297643, 95.56054761332851, 98.25084640133767, 93.76578084884152, 77.07870806417158, 79.42481102481966, 80.8584451675415, 73.3566847155171, 73.61509830720964, 79.6514141944147, 86.28007073556223, 91.31324829593783, 93.13402821940761, 90.5207569368424, 94.83028857938706, 93.32326689074117, 94.00559456117692, 97.43501693971696, 102.61609923455023, 98.41335804231706, 97.0950258931806, 98.15363437898698, 95.18925605281707, 98.6223654593191, 100.59054020912417, 104.03761325343963, 103.37431692307996, 100.63521600538685, 89.62382070479855, 82.82544320629489, 91.11638453698929, 96.61470813135948, 95.41686334917623, 90.61751396425309, 86.10910246449133, 78.87633815888437, 84.67899061018421, 89.80537937533471, 85.36319317356234, 81.36736485265916, 82.44344357521304, 93.9509637894169, 88.9081842668595, 82.53602720076039, 85.42599032002111, 98.54580863829582, 96.57368013935705, 94.19311523437501, 97.20038075600901, 95.16483537612423, 94.24598878429782, 88.80934053851713, 98.09762293292631, 99.04296121289654, 98.48830669156968, 92.80627496780889, 93.52032676819833, 98.22847320187478, 91.3525269108434, 94.0506233707551, 90.45279795123686, 86.9216920483497, 83.4801495459772, 80.74921500298285, 78.94849408057429, 77.896420263475, 86.59936735706945, 90.92412564062303, 81.78781155617007, 78.51828067533432, 67.93542000555223, 74.0353802711733, 77.10248547215616, 91.24906263043805, 98.97994441370811, 95.64242316830544, 82.36669063568115, 70.8574681128225, 79.02294851118519, 75.78128214805358, 64.22206509497859, 16.70441750557192, 0.40785797901691934, 0.41680610047713407, 0.36558641180876766, 1.0332068488482506, 0.29367744622211306, 0.16111690130445266, 0.2072069878059049, 0.33124275145030796, 0.6513935303495777, 21.08899389543841, 88.89440105807397, 106.40870955682571, 82.51808627959221, 105.70950000516831, 89.9549707289665, 40.77335957557925, 44.087370134169056, 45.41206436772501, 53.71527094994822, 93.95531762030818, 78.75978885158416, 99.00199597881686, 50.91084687940536, 1.322751924876244, 0.09718031397149449, 0.2800642783122678, 0.23367874234193758, 0.19667209907164498, 0.16072467960897954, 0.23556457501986336, 0.1307215508554251, 0.2712543591135933, 0.13248234266234984, 0.12019083730035252, 0.07041091895512036, 0.11990597516658807, 0.14200810973923053, 0.10628526129068867, 0.1196060057789568, 0.1818635275647525, 0.26672754556901995, 0.14891575601312423, 0.11961856962091501, 0.1753374696859429, 0.2425281763557465], [0.07786699225224795, 0.044231013274721565, 0.07998494957123073, 0.014577500236731385, 0.026476117406761455, 0.09180161831600052, 0.04839239138809424, 0.12446643529279579, 0.020464782512957053, 0.07595565650732287, 0.09318609241276019, 0.024108639505181103, 0.04545536733442738, 0.025565562536939982, 0.030059870970886082, 0.1418096776450834, 0.17909942104691462, 0.25918121179265363, 0.3761049522267234, 30.318254424679665, 96.50814517851799, 75.5553928498299, 71.9970029400241, 68.77803141070952, 47.02839466833299, 43.72589234382876, 49.01530265808106, 98.59075115573023, 124.3888387372417, 44.75028207225185, 60.743346368112874, 85.33688191444644, 91.50581313717751, 52.49608847402757, 1.9570124197390772, 0.1837937626987696, 0.08199701055644021, 0.2335848046406623, 0.13899697050932916, 0.08516900526780276, 0.06674004778746637, 0.20191529675597147, 3.211175573448981, 4.0773800351927365, 1.28344904030523, 8.414614642820052, 47.59269037554341, 68.4968759167579, 87.98625469207765, 90.17933030282298, 91.6328900860202, 64.07980465119886, 64.68834861632317, 54.8455136822116, 53.81050609773206, 50.93464782161098, 53.08067852450956, 57.13267126391011, 67.07645231677641, 73.86493759770548, 73.16741466522217, 80.08094510724469, 83.46962974917504, 87.09847327201598, 94.67135414000481, 94.15519375954905, 98.944227310919, 97.06455692168205, 94.5871094734438, 92.73410335663827, 93.45216381934382, 91.32404265865203, 95.08413653219901, 89.42080666941982, 89.10161987427743, 88.33678906963718, 91.8416464713312, 88.75314081868818, 79.01144812183996, 82.30529769774407, 90.85501347818683, 85.92361357904251, 87.97131830646147, 80.38507784566572, 76.05466350432366, 68.59262097266414, 82.95413617164859, 85.50935637566351, 69.64325135754001, 79.1986785396453, 86.63406464361375, 81.87616686667167, 77.55699403824346, 85.43607865610431, 87.65930160399407, 86.68862481271067, 92.20051980787709, 91.21649126852714, 90.67719674879505, 91.73572678719798, 89.25347051312848, 89.15737244390672, 86.59718651925364, 87.41070178247269, 85.82133385442918, 89.19690209050333, 88.467647183326, 86.36075389000678, 84.6540286464076, 86.50545012566351, 87.71562683966853, 86.26900965167631, 84.42420913327126, 83.49704711667954, 75.55705593478295, 79.61152368976225, 90.22057794755506, 92.56639065281038, 72.7642499246905, 63.89533558199483, 84.4657862570978, 86.09557813213718, 78.26344428523895, 86.08836097102012, 129.13443596132342, 151.0551037326936, 71.33073345307382, 54.576768567485196, 61.47264834373229, 27.966158082408292, 28.21315953808446, 9.231196218921292, 0.329326152681343, 0.3348752645955932, 0.0488118245266378, 0.11938350320222879, 0.19510779349553972, 0.2855671491594084, 0.08012074631668868, 0.14706752293052214, 0.41853053375117244, 14.02687720714077, 63.48899372162358, 85.32884890033354, 71.51729706794985, 82.60298205960183, 70.29905596087056, 30.081861019134525, 28.85744021784875, 41.42473190061508, 34.37851552040347, 56.34223914915516, 66.53343154538062, 75.2432349420363, 34.38807041414323, 0.7731539515718338, 0.17725955364444565, 0.09779614141030658, 0.17066431802607354, 0.04730787135720734, 0.12254887891392555, 0.05340895728178082, 0.1273636649092359, 0.050736536166720816, 0.058737795935162616, 0.00818210248384745, 0.0413608533750859, 0.02227047473312386, 0.018393276935263027, 0.06778140642469929, 0.10314980897331431, 0.12424947919263957, 0.08236198250444667, 0.05131255384654768, 0.07770319499315755, 0.061353411630637227, 0.03301974934255404, 0.013087828861429326, 0.045422774123688864, 0.02072172265710129, 0.050545109946641235, 0.04353878005678135, 0.06804831911839786, 0.035341091514114416, 0.05103986868033967, 0.0660541616079788, 0.034186964734427394, 0.10698613981085439, 0.08372107610827492, 0.009968343731616775, 0.08284267969429493, 0.0668567076565758, 0.05805762094115058, 0.18756323704315772, 0.13014070299123565, 49.630118493110906, 110.32215241462954, 90.19029724982478, 106.67892163799655, 98.6049658252347, 67.0782252280943, 76.93652999016547, 48.06600278423679, 86.58631370913598, 111.76616514882734, 39.70956963877524, 70.36956448708811, 94.99117635911512, 107.40174385809131, 53.39292272444695, 1.7339909869816996, 0.3141648436505949, 0.09386125336130781, 0.09261403157706223, 0.0473944507839699, 0.2684764017260844, 0.02696403114485645, 0.7364955412284021, 0.5346600555123822, 2.3246169522885354, 0.7611520504278522, 15.839386813102232, 64.27385999310401, 79.44881593027424, 96.04600368007537, 94.81194757646131, 92.68002956144272, 74.76822806942847, 79.38050393135318, 70.475248829011, 66.27857162106422, 62.58730357693088, 64.42580869120937, 67.12983577482163, 74.78905585504349, 83.8652321600145, 83.7752765224826, 88.58385132205102, 93.26086982603996, 93.03909901649722, 99.0601255047706, 93.9236484035369, 101.20303400101201, 100.74828224797403, 99.74530081595145, 97.25659616531865, 96.80968130788496, 94.97450628588277, 95.50949404316565, 90.2040647691296, 90.5723596388294, 93.33624209127119, 96.73760383359848, 92.30218764274352, 81.2166517011581, 80.03382959673482, 91.57229731159826, 88.28801831891461, 87.87961329183271, 87.682859359249, 82.55527034882577, 75.21799841234761, 83.6416256812311, 88.48310916654526, 74.47582321782266, 78.92707793943345, 87.58156807191911, 84.32145872423726, 78.10152884452575, 85.60248128829464, 88.50378005735337, 85.09105913100704, 90.92259591625583, 93.73478627973988, 91.34989892282795, 93.13620905722343, 91.78841990809288, 93.62483439906951, 87.13705370503088, 90.19855776140767, 88.88637588870141, 89.42309733360045, 88.87734659256475, 90.37178531769784, 88.89278504156297, 89.8477174389747, 90.85360142492479, 88.70648030311831, 86.92321392797655, 84.80853080749512, 77.68989178442186, 80.40642338414347, 85.10203392274919, 91.42563989085536, 85.20370175761562, 76.19931267153832, 86.04777228447699, 85.81704278146067, 82.01093950579244, 83.97916916877993, 94.50943085455125, 131.81995730246268, 114.33972635576802, 59.294536575194336, 73.17940927320912, 61.27435684204102, 42.08909119329145, 17.5370680516766, 0.28137131624164124, 0.16497784654699987, 0.037663659426353635, 0.33779883997574933, 0.42778487587648056, 0.09300846726663652, 0.1639114215128845, 0.08294683700848011, 0.3726076995653491, 12.931574948372381, 74.4603455451227, 91.26770957823723, 80.84550134597286, 71.71909516857517, 18.736981884125743, 19.550824665254165, 45.90998572687949, 62.44179933301864, 65.13556549626013, 74.40660907376197, 78.12208206422868, 84.49016771008893, 48.543567042196955, 0.9448052666360333, 0.09392491526781552, 0.01603197274474247, 0.20015012292611986, 0.08739860457999092, 0.11205991715072625, 0.035463481720897465, 0.06215723321562814, 0.1377267354438382, 0.04305292709520267, 0.016653663629005035, 0.017696948977367535, 0.05497256188743538, 0.03958846299698757, 0.049638567462323174, 0.033845825781745296, 0.07096748183211012, 0.06061533954174769, 0.079034655805557, 0.08038891539458307, 0.03719081846816886, 0.3094795418362464, 0.0859852719511236, 0.19027459074652966, 0.08340179364407256, 0.14708636869345942, 0.10163981903104052, 0.19573477517452934, 0.19601464241502747, 0.13424773099682025, 0.13808757817793277, 0.15538746761458536, 0.21531820417411868, 0.12711726805014958, 0.1504691984624632, 0.1792918316899769, 0.1606966407909509, 0.2105424273759127, 0.39238076596971483, 0.3700281589502289, 63.68097020733742, 129.79004444614534, 100.7035593832693, 101.53998128829464, 92.76827504557949, 65.00509961958855, 59.60061088685067, 66.28620455341955, 115.8101680201869, 137.32026561614006, 62.96316469869306, 82.72404993734052, 115.03607257719963, 115.94578004652455, 75.24771428877308, 4.026831715337692, 0.49731443365735395, 0.19668735954309666, 0.28494146982989005, 0.39244569958217684, 0.5418180746416892, 0.4226705035375011, 1.627227748113294, 6.276629211441164, 14.976694833847786, 7.558950570321853, 15.248734739518936, 84.45980072021484, 84.3414314331547, 98.68016550617834, 96.1489345181373, 104.83312483756774, 83.43069630284464, 91.75092204924553, 81.85671975535732, 78.74608409020209, 71.15839235244259, 76.89766714649816, 75.3670092551939, 86.40277816403298, 93.92763353163197, 88.67502289433634, 92.29064018495622, 94.31673265272572, 94.45141115496236, 103.96966211257443, 98.70628849152597, 105.7141205572313, 104.35672944591892, 105.80857907572101, 102.06766559231667, 99.92023852563675, 99.4913116578133, 102.0470182357296, 95.41862841575377, 95.91803243083339, 96.77869458352366, 99.94878553575086, 95.14450180915095, 81.9477815012778, 81.73227079453008, 94.87881614315896, 91.01688969519832, 89.71240351277014, 87.34952849726524, 84.78844042747252, 76.7257575065859, 93.6058501274355, 97.6797571489888, 85.51901325102776, 83.12901896815147, 89.37372253787133, 85.1433051017023, 80.78785034918016, 88.86372027858611, 92.42645617454284, 88.38297105604603, 95.77236344737392, 97.28196605559319, 96.62023867330244, 96.82624155475249, 99.57815293342837, 98.07858374810989, 94.1847998096097, 92.76185020323723, 91.6291638343565, 94.82158091760452, 91.67255309320267, 94.14995347299885, 90.32935311717372, 92.62131167996316, 93.80733443844704, 91.64058577629828, 90.47169593072708, 86.77836079751292, 78.98444652557373, 84.6511653161818, 93.38250252508348, 89.92729448503064, 83.57554158856793, 80.32970966831331, 89.47764181321668, 88.85229833664434, 87.28664505866267, 88.20557794263287, 98.70942638766383, 113.85067739794331, 94.81478737246607, 70.39022753315588, 78.85486710456111, 70.25729056327575, 65.58783438897902, 16.709228292588268, 0.5525983413380962, 0.5059423916522534, 0.2436475074219127, 0.6640244203229105, 0.9896760782407177, 0.40728224862006407, 0.2303700085969702, 0.2893695806062991, 0.40918472072770523, 21.679773446052305, 85.91911854282503, 104.36184421662362, 87.52163425568612, 121.34871944304436, 93.23493511446061, 41.41644393244098, 41.177516675764515, 54.54396578573412, 49.45135255013743, 75.84337326788133, 85.74980551196684, 98.05002889325543, 62.81445980072022, 2.0866082656768064, 0.3051670184058528, 0.13846821662399078, 0.4469774314953435, 0.1974293923065547, 0.2473038459016431, 0.1445933806920244, 0.20833650784146404, 0.19125369707903556, 0.18665237382294672, 0.1684403801036458, 0.10970651802997436, 0.12000712175523082, 0.11311084422613345, 0.14733056688020307, 0.1683736078801655, 0.24840525051038115, 0.268032836817926, 0.16684121752698577, 0.22393581998204032, 0.13178152542921806], [0.1815342016878628, 0.1525138871323678, 0.05156425969494928, 0.030808469107855233, 0.011577091025819462, 0.03988043825712897, 0.09457616661224635, 0.06091588349532216, 0.06300025551970448, 0.06305460945793218, 0.07031293630960488, 0.05029316661098311, 0.16556396509610838, 0.07628549566312183, 0.04042197814992359, 0.07998527132815893, 0.300218029127967, 0.19544836554315784, 6.881798467328472, 83.77344085324196, 79.08131337934925, 87.10421562194826, 56.194244200183505, 55.09889487297305, 47.1794569107794, 34.54365122702814, 80.96132893716135, 128.1561968403478, 118.49778390699818, 81.75536571010467, 93.23636285720333, 109.90458473082512, 48.41656461838753, 0.8239408618500157, 0.12370591682772483, 0.21233041530414937, 0.12300571246493248, 0.07240836298273456, 0.21136220274192674, 0.11034723566544634, 0.07527882548710031, 0.15869655375999792, 8.961495026465386, 2.279823730068822, 3.532854544539606, 31.745291140771684, 63.259142829525864, 93.78712638731926, 83.17394579610517, 96.10924013199346, 75.87390499730265, 71.45379389486006, 68.45505560598066, 59.5978573829897, 56.48874359746134, 55.783732860319084, 58.95906802146666, 67.52780729724516, 72.33622520200669, 78.78309557514807, 87.07573921449723, 91.21209036919379, 92.68887058381112, 91.6867442284861, 94.52767772059288, 93.26661217597224, 93.26399203269713, 89.9188143207181, 92.07266622974028, 89.52901701773368, 84.21161666993173, 83.3387637907459, 85.16845533924719, 83.78250152834, 82.76656843000843, 88.67224585625434, 87.8181262170115, 89.8059912650816, 82.87692039243638, 76.59799806533321, 86.54180265242054, 93.29638296558012, 86.02203369140626, 88.73726306423065, 87.66440068521808, 62.053049302870235, 41.38374313231438, 57.37739970607143, 52.90207339871315, 71.13809800917103, 83.31861065280053, 77.90769315535023, 74.3522842468754, 76.37913765445833, 80.61667027011995, 82.26544641679334, 86.819608442245, 89.33464004147439, 86.69090763215097, 84.01739658847933, 80.29175681452598, 84.2015047996275, 76.44568458680185, 77.65608879827684, 85.52279441587388, 87.4994650194722, 87.11171519371771, 86.93709911838656, 84.96861842370804, 82.97764685846145, 83.7186610314154, 83.98333472590294, 86.38618653820407, 81.21546714536606, 87.28249519102036, 90.56638979142713, 82.70315939380278, 86.3685594066497, 94.21985010946952, 67.97083900820824, 61.484082052784586, 69.38873660179877, 76.91899699549522, 82.27451493663173, 69.79522751223656, 104.66491007035779, 152.75832237735872, 83.62211581199401, 51.653096598963586, 62.30224532465782, 25.489677498417517, 28.729698427261848, 3.5076702314038433, 0.3013123704060432, 1.1015528007861108, 0.37031069217670354, 0.33679998389655547, 0.3201041701099565, 0.07649151968859857, 0.1633821466877576, 0.20672364761271786, 0.3898669250549809, 17.00065451283609, 61.34729723776541, 78.2036595190725, 66.92329945102816, 68.95161982505553, 61.72477829840876, 47.375951966931744, 26.840282909331787, 31.489754607600553, 48.64084966721074, 56.9330265445094, 70.1482565172257, 67.86434665802987, 45.491696326963364, 1.6040227610257365, 0.08782495549249072, 0.029658576879169674, 0.14048983072561605, 0.03911109062873068, 0.03866334671094533, 0.05982233894868724, 0.07421306694947905, 0.029713995679612124, 0.07055745625327672, 0.06062843581481327, 0.03272130063945248, 0.0471002921732443, 0.09239070162537599, 0.1243115169927478, 0.10545291442183718, 0.1070764692380063, 0.0735751302131722, 0.07284530889122717, 0.07584160899803524, 0.025413386831660906, 0.061888435945635846, 0.07062500222556053, 0.031825918140971375, 0.058045681460850665, 0.0293679480185552, 0.04175187614295752, 0.033729686852424376, 0.0161209452386585, 0.06874208068174702, 0.11976217280232138, 0.04752220743666253, 0.059250530922004295, 0.06160943821493176, 0.03986838003320079, 0.1002358096922117, 0.10107302121938237, 0.27355614689088636, 13.444295410187015, 105.02677225297498, 88.88520702239006, 107.67638821755688, 73.59955787658691, 74.65070601432555, 63.58153027872886, 30.390426035850282, 58.29408899430306, 142.64381624037222, 123.02908635908558, 83.68792533874512, 103.56721908815446, 124.4046772679975, 51.58730668406333, 0.09823039068930572, 0.04276687369471596, 0.1746099772712877, 0.1057626284478653, 0.04880094990855263, 0.056771045220234705, 0.0328665585707753, 0.16526433278716382, 1.1275458576217776, 7.389658622203335, 1.2101933840782413, 5.694732848675021, 60.665255900352236, 75.22758468504875, 101.88053715613582, 86.08168509698685, 100.12200524730068, 83.93221055307697, 78.19545392067202, 77.52796849896832, 69.8095598528462, 67.15597444964995, 67.37696862989857, 68.34190307124969, 78.04686669380435, 80.97290777391004, 88.72722964132987, 92.1816453626079, 96.09801430856028, 96.28404448109289, 97.4115219423848, 96.50988671087451, 99.59467395659416, 96.31424673141973, 92.90429499841507, 93.86971581366755, 92.1595859527588, 90.43804983938895, 86.83394862759499, 92.53784364269626, 88.72369166343444, 88.86938418111494, 92.23546812611242, 91.46606383785125, 89.83213778465026, 86.31567801198652, 79.01620987922915, 85.14583895283361, 95.920299560793, 89.20962625934233, 88.09468469312115, 89.66142839001071, 57.51607902588383, 44.66074612832839, 53.46825576597645, 51.295662772270944, 75.63631919122513, 84.9522150716474, 77.67614779933807, 77.06323823621197, 80.22576685874694, 79.13366917640933, 86.3543761161066, 87.39025054439422, 88.94824735579952, 90.35366396750175, 88.36231585471862, 81.83273053938343, 85.33561891125095, 84.47657277507167, 78.82733206595145, 86.39519230011972, 89.74047983846357, 88.1524690504997, 89.51284116314304, 89.73638488400368, 87.60293714461788, 85.91174448690107, 87.64553408468925, 85.84648409197408, 82.92187075461112, 88.32451205099784, 86.9933694408786, 84.05863638847106, 82.80308569631269, 91.86543956879648, 81.06859791663386, 71.03958375992315, 73.47147680098011, 79.11395534392327, 81.7711728618991, 79.7531997003863, 80.12342437621086, 118.90695771863385, 121.87748632123395, 58.05360847903837, 79.79454932674285, 56.94897490163004, 40.45964448682724, 9.505251242268471, 0.19477085270468267, 0.6028372229587647, 0.45520794307512624, 0.2150839344868737, 0.19531676695952493, 0.045123658924093174, 0.3809958413964318, 0.2355794524473529, 0.3169101656925294, 14.810048034114224, 72.95824250867291, 86.13715525596373, 75.95489409662063, 54.72499493629702, 25.31448091230085, 18.7990024012904, 39.24490605631183, 45.749203851146085, 63.97821526373587, 77.59019297938194, 78.19271610629174, 79.25730228424072, 62.80339871683429, 3.14133801767903, 0.0790599060635413, 0.0055510740569462225, 0.010997758100500271, 0.08168190327142516, 0.03518601233560232, 0.045364551441443544, 0.030337899600365953, 0.022794823612897627, 0.04570405862684693, 0.08811764704484133, 0.03913079441014317, 0.04836274378542458, 0.08596323926242129, 0.031481396910103585, 0.03919869661331177, 0.04040253100796573, 0.0736150587157857, 0.04623509545419966, 0.07216837827957447, 0.2050205728700084, 0.20115634877114527, 0.1818232773052108, 0.18754854347677002, 0.16884536482393744, 0.12953317994552274, 0.13492692922872884, 0.08399690606541212, 0.18038393599131416, 0.3378464600011226, 0.217109241132294, 0.08937985350888583, 0.27021842437886423, 0.24978624656796458, 0.14738007148187007, 0.25000174710106465, 0.5755163212457012, 0.4884092437644159, 20.4337364627469, 126.94384713326733, 104.49598927651684, 118.3804109019618, 78.43008225963962, 74.1242298003166, 65.93360700914937, 53.07338291598905, 103.81145723404424, 142.29505477413056, 131.65088745855516, 106.94742356577228, 119.46950404874741, 134.67732552559147, 65.04205226898193, 1.4667237477917827, 0.3805952080555501, 0.4818744831267865, 0.24683288568931244, 0.2564662881195545, 0.3372883189830088, 0.3173604415309045, 0.3184513507350799, 0.8662290378443657, 32.02284982127528, 8.969892821004315, 5.110933155782762, 71.71388626098633, 80.64721768902194, 105.73920803685343, 87.65730119520619, 102.64264583587648, 87.34323701550885, 88.32422964034542, 88.5152647572179, 80.49907761235391, 79.36545771937217, 82.01335568581858, 78.44603061676025, 83.12534762967019, 85.03824833900698, 92.43566589970743, 95.25319068662583, 97.42855287367298, 101.18203363110943, 101.8587915359005, 99.5205411603374, 104.260968700532, 100.76496801068707, 97.9987007571805, 97.56393740254065, 100.13744369629892, 93.55030152105516, 87.4333103241459, 94.26435332144462, 90.70392377914922, 90.35684893208166, 95.57860620560186, 95.35661574332946, 93.42174191628733, 86.63489618609029, 80.4567160144929, 88.3480776509931, 97.81909542699015, 91.5845351065359, 90.53052363857147, 90.98054501318163, 72.72394364879978, 56.826734235209805, 68.2503314172068, 62.905698053298465, 79.37384374680059, 87.67981559999528, 78.51475054217924, 76.63904174681633, 81.1222324063701, 84.91524281040316, 86.46102536109187, 92.23880214075889, 94.39473290597239, 92.6497410189721, 93.03606310198384, 84.95835750333725, 90.66373517436367, 89.06404356802665, 85.14938477546939, 91.81680217865976, 94.40354254937942, 93.01219155711513, 96.97723711690595, 92.2713029000067, 87.77061062474405, 88.02980084573069, 88.71712561576598, 86.33892197762766, 87.01029839054232, 92.33655545019334, 94.6474669056554, 87.69451664340112, 87.53890052918466, 89.3571230673021, 79.50962835742583, 80.31504000386884, 79.80670867427703, 81.76875668187296, 83.22883544429656, 84.44895928905856, 88.23788258337206, 108.42343499583583, 103.64132835019021, 67.07123556444722, 83.33894421977382, 68.12422721616684, 61.822335489334606, 8.17634585403627, 0.6194366322409722, 1.8016815353785793, 0.732786143499036, 0.6931247910664928, 1.1308720275279016, 0.13152611171526293, 0.35701143645471145, 0.46404400119377726, 0.4763996817411915, 23.896043992811634, 83.20869015109155, 102.01382713933145, 82.50512676854288, 94.55918219781692, 77.72785248294954, 64.53466623060166, 36.84594523522162, 44.15300315426242, 63.841959968689956, 76.27225306726272, 87.3716506650371, 91.65325503195487, 79.62583249615085, 4.808204135587139, 0.20364854004113905, 0.10678606062767007, 0.27186434896242234, 0.17551756163518276, 0.05739527281313654, 0.18636096929830892, 0.20447839712423665, 0.10415614973152838, 0.18511742473609988, 0.32054464002290084, 0.1598382392717946, 0.25537623693385436, 0.2554312267250592, 0.2920812867101162, 0.14684931044617008, 0.1767933738207625, 0.28228905893141226, 0.2555220387876034, 0.15065836089272655], [0.06574054053353687, 0.17009379702710337, 0.15444816721062507, 0.06960441223195485, 0.11895140663029687, 0.02190831815823913, 0.024163499061438828, 0.05570745854187877, 0.058234192716378363, 0.10376419616682876, 0.1076127767502781, 0.038774103872598185, 0.006767404782060053, 0.059702469171175075, 0.05821268479790419, 0.1474623646466963, 0.1007955824776042, 0.33488675591445743, 42.25857288606706, 83.26237170926987, 71.88540366388136, 66.76842858714443, 68.64136818916568, 55.79861825512302, 51.35716553657286, 97.30404115492298, 54.45183323275659, 77.2615768063453, 87.62309812730359, 85.65651585978847, 98.1467466969644, 50.47962542503111, 1.757213257012829, 0.06632224641620152, 0.12177586555480958, 0.1217092005836387, 0.26792304109661813, 0.08011595826716193, 0.12769559548506815, 0.20128022518850144, 0.29213509672591764, 0.3717378526926041, 0.9339986465150311, 0.29128075547276006, 20.70620390676683, 77.21684609690021, 84.46919087440737, 94.6643409421367, 98.04240380564045, 86.89444726513278, 68.57108716041812, 65.18626997547766, 63.0009606576735, 57.49266247595511, 56.32893054716049, 54.74196703203263, 68.32280897325086, 78.30513123543032, 89.43701390297183, 87.83259976294734, 87.24775868077433, 90.0276130245578, 90.21938554702267, 91.79505655842443, 91.67401221490677, 90.38471344978579, 89.42098709844774, 88.68244401870236, 88.46037510902651, 88.33037991677561, 85.21140529263405, 83.94504454828079, 89.63423067523588, 89.29709511418497, 89.24028350460915, 85.70283905152353, 86.49517351581206, 82.06481718247937, 80.72793222242787, 78.3675753685736, 80.29627538496449, 87.57717501732611, 90.48093703485306, 78.46989431688863, 87.0732210528466, 28.052444342643987, 42.9807714493044, 30.24929327349509, 31.311953567689468, 71.22390377906062, 85.04361414140271, 80.1555093642204, 77.12805932567966, 74.6976254063268, 75.3616120738368, 86.11833572387697, 84.59837021366243, 86.57617045987038, 86.82793171175065, 88.42596807787496, 82.71871551390618, 81.68501407869401, 84.31748144088253, 75.44066352228965, 78.84825398845058, 86.22099199602681, 86.05531107994818, 82.86312933891051, 84.92366806153329, 83.67163965778967, 82.65035644654306, 85.26669502258302, 83.0008202214395, 83.31065608609109, 80.55566956920009, 85.6562412938764, 89.18501730888121, 86.333603243674, 93.26743587370842, 82.87364129097232, 59.153123363371826, 51.84957596563524, 48.24001089219124, 63.89978747214041, 89.92483908130278, 74.72461915785267, 95.61453511638027, 153.51309622487716, 74.53490980209844, 57.85721148214033, 56.43501889321112, 23.691027587459935, 20.04906177520752, 1.5907391641409168, 0.4091276318555878, 1.9046095542369352, 0.9790310107411878, 0.14115592885401942, 0.5209153349841795, 0.12631994672119617, 0.23548982016021208, 0.3620343991825658, 0.46479534958639457, 19.469562961209206, 62.174281920156176, 79.68954747722995, 71.77228250811177, 52.84597173813851, 75.97953442604312, 48.337513169934674, 47.826020409983975, 40.16023035972349, 37.828232242215066, 55.26643891488352, 63.084087448735396, 63.9579209204643, 57.40468763536023, 1.7455114784740633, 0.04657754441723228, 0.05320705097889709, 0.031429645755598624, 0.017529214026346322, 0.04726046583645287, 0.0435927126466507, 0.13498714373957726, 0.04786939465350682, 0.011221475884198182, 0.048327821667396256, 0.1155305099523356, 0.06736944264341747, 0.021144767900207834, 0.07023424375802279, 0.08274700297343154, 0.25578594075575956, 0.03818941024702884, 0.023855299974280982, 0.04928217952950828, 0.058343601563284476, 0.12982323615541383, 0.0975096628310219, 0.13235540189329656, 0.014025337577256707, 0.07854743154659387, 0.04490717013757076, 0.039317053367173484, 0.0705852652449281, 0.10611567240689071, 0.10404160426508996, 0.022569693354589325, 0.035810239928504156, 0.1597239236317335, 0.1439149332262816, 0.09269881452764235, 0.1662421827354739, 61.563757158094845, 97.12736975762152, 88.01161673761185, 89.46669840043592, 87.04646264353107, 72.68490822084489, 42.426932780973374, 44.17333279886554, 41.54780803188201, 86.89503562065863, 95.96277882975917, 98.2375652559342, 110.04134208925309, 53.156384191205426, 0.8129959781804393, 0.060691473359662684, 0.13646725625280412, 0.010147434020895633, 0.2820681191740498, 0.0853418117208827, 0.08008686224779776, 0.16576650342152965, 0.9014157013547037, 2.094716295119255, 1.8841380914372785, 0.05434326662291443, 36.19012494241038, 95.60479194887223, 91.88566330940493, 98.45625308252151, 100.80734529802876, 89.08809554192328, 76.21337829097625, 72.94434947352256, 73.8572262179467, 69.58680060602003, 65.38227081298828, 70.37854671478271, 78.2021297947053, 82.13479226635349, 93.80604790103052, 92.53814174282937, 91.61228979787519, 98.8596139415618, 91.64694786071779, 96.87741279602052, 94.8999890973491, 92.15873087606123, 96.86579473557012, 90.82287357699488, 92.21523654076361, 90.74117060630553, 90.10777842613959, 91.99266556770571, 91.86179960927656, 94.4444764044977, 90.23231367911063, 90.88443909921955, 88.05275455597909, 87.38578688713812, 79.3420882378855, 80.91884966819518, 83.51450166394635, 90.08724089591735, 91.45643834144839, 82.5493867935673, 79.92880421300089, 31.63681407128611, 52.100972437089496, 40.72620484136766, 31.472976669188473, 65.30617683164536, 85.96188806718396, 81.57658407765051, 78.56418809583111, 76.04113132722917, 78.32510394434776, 88.80247639071557, 86.21437103517594, 85.37994953893846, 87.46179457633727, 91.73576601089971, 89.25667116718908, 83.19004320329236, 87.73128494139641, 88.36663046190816, 81.12464074165591, 84.96382528735747, 88.92431305300805, 88.06080325957268, 87.20127074949204, 88.76959908393123, 85.17123237732919, 85.84645271301271, 87.3709132594447, 86.69383372029951, 83.62032721119543, 83.90829978450653, 85.85550554337041, 87.47172601761358, 88.67896095398935, 90.25664021891933, 74.86278072480233, 65.29948526813139, 57.36748787664599, 66.98303714875253, 81.98471453882034, 86.91066234342514, 74.76032057116109, 119.644175037261, 105.11878321247717, 61.47731596423734, 77.01921355339789, 56.054203817921305, 31.572165566105998, 5.601952124026514, 0.5114081532003418, 1.3126883487547598, 1.7646960361349968, 0.20392590983500405, 0.1011003552365207, 0.3948018489585769, 0.479610386875368, 0.2871983035677864, 0.4036098069721653, 19.027605979673325, 74.53508238638602, 89.0768854079708, 81.35533886571085, 49.42581792031565, 44.007039993040024, 16.699734195586174, 54.93482212866507, 59.668358064466915, 51.05628836539484, 76.91552962026289, 70.82116265450755, 71.20456649411109, 75.25995992845105, 3.059255557675516, 0.11771905461266158, 0.061869356525881644, 0.0901949250950448, 0.062460994738484585, 0.04227286572718332, 0.06795594423648811, 0.10130896863918151, 0.03266266810016767, 0.05283424961230448, 0.053555364344990065, 0.06517234844185653, 0.04420335750065504, 0.06659502734340007, 0.04759135070226846, 0.045747499642593246, 0.15032171121528073, 0.015008234129767987, 0.05002690892245981, 0.136397649504004, 0.1829730833490049, 0.4501023654255175, 0.1990547857337421, 0.20668725843631452, 0.19085177671044104, 0.19435474438773048, 0.12263043663434445, 0.18222535089139016, 0.15869295314675377, 0.26837052837494885, 0.13653890079548284, 0.18965166933353872, 0.09090698849890502, 0.23201731213879204, 0.36076649302436464, 0.532353088980721, 0.4692117238958036, 77.91250982592183, 116.65696851668821, 102.45903968811037, 91.66726573821038, 95.52178675128569, 79.5475184532904, 76.07374975758215, 137.0023967373756, 80.63154389781337, 94.1850273070797, 112.59090623547955, 110.78508623184698, 119.37813635795348, 65.34962884841427, 2.8073128961747695, 0.21368908755961927, 0.37855015166344186, 0.38039136738065754, 0.4257168674901609, 0.1924376093572186, 0.39633191040446686, 0.46358630962429515, 1.0685959434317005, 3.242621950564846, 5.052346673703963, 1.0003299097861014, 43.31571832779915, 105.9863801156321, 97.03837117841168, 103.74277653232699, 101.44313012399982, 96.03131832615023, 83.65634241411763, 87.83109357280117, 84.40870008160992, 80.9389086692564, 74.76753773227816, 76.6002259715911, 82.00427932123985, 88.0056861139113, 98.46776916134743, 94.27397881784748, 95.1927391175301, 103.22037958329724, 94.36607606949346, 100.81846129509711, 101.89850945626537, 94.71963851682602, 99.08495410796135, 95.09932394950621, 97.11976035948723, 95.96783084254112, 94.56883122844081, 93.36127465771091, 93.99207022882278, 97.75782800489857, 93.66823934739637, 93.52046797352453, 91.81436246441257, 88.7952043164161, 82.58406839063092, 84.16727819750386, 84.69389561683901, 90.60599788542717, 93.72026566536196, 84.96723774940737, 88.21898460388185, 40.81586237876646, 54.392856474845644, 43.03987372306086, 41.822354332093276, 74.95275989655526, 88.50341919929751, 82.58106385507892, 78.31647472996866, 81.27504794828354, 81.29011769448557, 92.93248115047332, 88.4719539457752, 89.87814718677153, 94.17525276061028, 96.3487086757537, 93.79862677666449, 87.03871204007058, 90.32183785592356, 90.95510452024399, 86.41516500903715, 89.22054613790205, 94.18878493770477, 91.2218806051439, 91.40120352468183, 89.22075794589135, 88.16396943984493, 90.71992704945227, 89.6936075149044, 87.13099756548482, 84.91551737631522, 88.38657179186421, 93.14600713791387, 95.25049209594728, 94.28085081038937, 87.52812970069148, 75.22454092579504, 71.3385860381588, 66.71795552776706, 72.13882015597436, 86.06106911936115, 93.42049460257255, 83.70181837389546, 109.43575166886853, 96.85081128151187, 68.93034488924089, 80.95612002957253, 66.15747236436414, 48.85761553241361, 2.8910106372448707, 0.9695570158862299, 3.9688757542640936, 5.383336370991123, 0.3976343518062946, 2.01133344682955, 0.20779021054265961, 0.33633968762813077, 0.7137809116994182, 0.4622272390031046, 27.95464396476746, 86.859647996964, 103.14102218997095, 90.01924268661007, 76.77986268074282, 103.73238225137035, 65.47250101643225, 67.04281407017862, 55.596396538519095, 53.50509466663484, 72.57984361340924, 81.06156902928507, 82.9934383207752, 92.68860386263941, 4.62767606781375, 0.17605334820766605, 0.17438529900485472, 0.26389234609180884, 0.15637342277313435, 0.14100959073872338, 0.14999633835208032, 0.25664365279578394, 0.18053483999063893, 0.10968100730209582, 0.19344712938031844, 0.22532325117818772, 0.13285317518297704, 0.22913839968462146, 0.13689520828906568, 0.14757715526127047, 0.2996524417352292, 0.14090783894062042, 0.15777444436905846], [0.030449424765162894, 0.09690872814145782, 0.0825934023446133, 0.14897347307733952, 0.04666415065707219, 0.18145982987217366, 0.026566872012711344, 0.1771089560802906, 0.09532325555600467, 0.03048815050973527, 0.006191092637187291, 0.09092106153407405, 0.08049963042140007, 0.027172165742564588, 0.07542374633973645, 0.07704590687588339, 0.20592820319917896, 3.5608845372353835, 70.70670004813903, 70.48834170064619, 56.84080769938808, 61.621667031318914, 47.25751207720849, 42.723624783177534, 53.00405110082319, 50.129181261985536, 30.072604225527858, 43.03040904383506, 82.62340976345925, 98.1940269470215, 65.75031465099704, 2.556010316456518, 0.2064855474858515, 0.09960116713397926, 0.017616869806642496, 0.23479750650303982, 0.12713625170891324, 0.2033909353157205, 0.3054828304917582, 0.050491165865453026, 0.3512990865255556, 4.471306368227928, 0.8738372715250139, 2.3833184088430097, 61.40577585466447, 85.58177117378482, 92.25575462464364, 79.67138690333213, 85.87034779210245, 71.38742739154448, 65.69426398123464, 75.09348669359761, 65.66779974968203, 65.06930097456902, 64.21014108965474, 73.82307806322652, 76.67395868609029, 80.01537876744425, 86.40700647907873, 91.93006453975555, 88.14594222653298, 90.66042469393824, 90.78434805716239, 95.02496365577944, 89.24338217704528, 88.96115195366644, 88.9034931121334, 88.92639975393973, 90.16131093425136, 87.5996894221152, 85.12656442580685, 85.53426342625772, 77.99341263309603, 83.49184605383104, 79.44585061842396, 86.00432811244842, 82.78799241588962, 86.53916681966474, 81.29850372191399, 82.45696006282684, 75.82833490064068, 83.08159751276817, 82.38187020824802, 88.85059602798955, 66.71928913362565, 37.700566937846524, 65.0868849600515, 75.99611820713167, 28.34970508852313, 33.99259351914929, 90.25173725620394, 73.09234834486439, 77.22633823271721, 70.78292739006781, 79.2115988269929, 75.42807271403652, 81.464216016954, 82.05405419872653, 85.01267448548349, 82.32785132623489, 82.37501390518682, 80.06203928301412, 79.84007235496276, 82.0417614906065, 77.00733661651611, 78.57233093630883, 82.25841752944454, 86.28078460693361, 83.65767601997622, 80.70424895132743, 77.69674024274273, 78.78349565690564, 79.45115366289693, 76.38322476417788, 82.30646656405541, 85.43441557115125, 86.05218102855068, 84.54626544829338, 83.30281919048679, 92.01991819566297, 81.6297321934854, 67.20125429091915, 54.37636683064123, 49.280454881729625, 62.90867513225925, 77.72316132822345, 68.70666780779439, 103.51310606925719, 133.57937566695676, 67.32257320034888, 65.70717250147175, 55.03990242558142, 19.14405134416396, 20.201749840090354, 0.29664658851200537, 0.8289573281522721, 1.2353714459365415, 0.3641660541536347, 0.3078752311487352, 0.2285513924735208, 0.1305686703492557, 0.08897281567295713, 0.12521104211167944, 0.5042016560271864, 20.34226090677323, 68.09809638607886, 84.28523171332576, 71.41069489140665, 47.035874628251605, 72.39409585152903, 38.16401458555652, 27.22309054866914, 44.74247263323876, 51.16955464886081, 56.82014857569049, 65.5903015598174, 67.26580865921514, 50.80049099460725, 0.6406622319932908, 0.20151549079004796, 0.06285784360502036, 0.08911229730133088, 0.04238148550352743, 0.007765099280438717, 0.019775786016496922, 0.04715353911442142, 0.017521235220614943, 0.04650141826019653, 0.06230491581523131, 0.05487787341999431, 0.022622001838059198, 0.09626228782919147, 0.06597865598216172, 0.1556398782638773, 0.0537418416370788, 0.07958820029612511, 0.02780481264175427, 0.014194763667370765, 0.07078047976979325, 0.12618421126277218, 0.05080946773711232, 0.10158954068057, 0.06640382711925814, 0.11085582611661766, 0.0765429778144725, 0.04393867029237651, 0.06823588042489945, 0.015979179710660492, 0.08377538408122717, 0.014257783017631982, 0.07677242880867374, 0.13428727645547162, 0.22978499321447265, 6.667492908816184, 87.46921570070329, 85.72511811410227, 73.99053189062303, 79.23474081100957, 60.15986242601949, 60.330434537703, 59.43849540525868, 41.16908750226421, 30.448037808941258, 47.24222660064698, 96.54518804242535, 107.43946921440863, 71.14279700863746, 1.8862496749047313, 0.09380298471378704, 0.14299103118959935, 0.05300877976321405, 0.1124097282187112, 0.10688075675599037, 0.21105247339414013, 0.08674841809777484, 0.39103854928285847, 1.564415892766368, 2.3048741923224543, 1.5089339666789578, 5.620309306729225, 83.37692060778218, 93.69435448800364, 102.31595946896462, 90.69764014213317, 87.11537868745866, 75.05840501477643, 78.99793163422616, 87.08385852075394, 76.5551971620129, 75.74336851796797, 74.27334262478736, 78.11777530177947, 82.50721346947455, 87.58411761253112, 89.23982850966915, 95.8985225615963, 95.14692583391744, 92.99217962449598, 98.832212263538, 93.58574405793222, 94.62228528914913, 95.61172669933688, 92.15412601347893, 95.67197430518367, 89.99051524746804, 91.97871761937296, 88.0856240180231, 89.65601551917293, 83.5651159286499, 84.06465330431539, 85.2840946566674, 89.08661288599815, 86.67826191071542, 89.21683557571905, 85.38140081590223, 82.36800855205905, 77.4012210292201, 90.90685152238416, 87.6248239701794, 89.53443773331182, 67.81781950304585, 44.2915451911188, 68.54831387919765, 78.5441840079523, 36.104252492227864, 29.490198935231856, 86.8563610507596, 72.67828725999402, 79.52811056567778, 71.33409100194132, 82.46023131955056, 80.26711648510349, 86.1022618509108, 84.51084644563737, 85.42731608113935, 84.44924954445132, 86.05356954759168, 85.52148434423631, 81.61579993463333, 80.95353910999914, 84.01683176717451, 80.16075749551096, 82.02822931351201, 89.62870013329291, 86.60780045293993, 83.85758353817849, 83.82433752859794, 80.35745651491227, 82.25422059336017, 79.56912286819951, 81.33012587024321, 85.76888392048498, 85.99109403548702, 85.6816739420737, 85.62091642810454, 86.75517174505418, 87.97388353655415, 84.73448430338215, 70.88399902466806, 59.889838618616906, 68.08960053228563, 70.78628493893531, 76.91887932439005, 79.83196089344641, 112.92995591317455, 93.48482147339853, 67.55046290736045, 81.36624305478989, 47.15420469161003, 28.46628381359962, 2.2044938754650856, 0.6665531233433755, 0.9178037929438776, 0.1842220977789933, 0.21168962872076422, 0.25353338178848067, 0.08421882641531768, 0.09371357459214427, 0.09145814279514937, 0.493097088990673, 20.882590932230798, 80.60406377238613, 90.13084980749315, 75.16426194098689, 50.093687734296246, 48.65498196694159, 12.073556473178249, 41.7576156123992, 62.40150874660861, 66.4419069597798, 77.7234515836162, 74.00211072737171, 75.61146705381333, 68.36829277776903, 0.5700805903442445, 0.1352809537802973, 0.05427870456309569, 0.10945641330533451, 0.03260555241497294, 0.039753639214341684, 0.04497594568097303, 0.03906262024576145, 0.023989505172076247, 0.09591495122520194, 0.026900166225048806, 0.1141469781437228, 0.07671395331741342, 0.02590910892092413, 0.07890042187946458, 0.031307856927836136, 0.011865502061893143, 0.07108598031223783, 0.11105388282768189, 0.20047829967112313, 0.2445375330505833, 0.1982683045489173, 0.14345961652936476, 0.19975499009653447, 0.13237669913759156, 0.2002719768713559, 0.2570710992140155, 0.1984533301043895, 0.15266595558533747, 0.13465774125389515, 0.2424806022956487, 0.10275708932069041, 0.25938453152775764, 0.3988676001468013, 0.3703470966748653, 8.561022012464463, 108.430950257086, 100.79498983198597, 86.18841278937556, 86.68341590512185, 63.58360521255001, 56.175671777417584, 78.47664863832536, 68.8713445971089, 44.06737781340077, 68.07598206304735, 111.81844249848398, 120.39826639236944, 84.21228347286102, 4.204854369163513, 0.23872905440868872, 0.5141077551149553, 0.20507756981157488, 0.4158705232604858, 0.29698149150898384, 0.3733321735935827, 0.3140386536477074, 0.38471335965779524, 1.2287328344198967, 12.77610102007466, 3.1902759594302026, 6.761075267868658, 94.98649304912936, 95.41561603546144, 105.15468074429421, 93.36069414692541, 95.56373257790843, 87.20284754230131, 89.04053288121378, 91.85715552299254, 83.59521619735226, 82.69453802416402, 80.81220826795025, 83.8400976119503, 87.930949272648, 89.58405571599161, 94.45003832540205, 100.16525330082064, 97.73333672554263, 97.28987355386057, 102.01192871216806, 97.55759100760184, 98.65517216344034, 96.28136942463537, 96.71509727354973, 97.9351269814276, 97.88703872311501, 98.1519869835146, 92.68272815212127, 93.59694634714435, 88.650727733489, 86.7814516252087, 90.33850008441557, 93.79166849197881, 92.95941214407645, 89.99011516571046, 88.00974184466948, 82.0512536264235, 79.53935992333197, 93.45137150056901, 88.48299934018044, 90.53272801060831, 72.14519792987456, 43.1829264856154, 70.67394825720018, 74.57242335042646, 36.22648923627792, 41.03723702892181, 91.0261857125067, 74.89728973757836, 82.18022115768926, 73.5336228339903, 86.83590981268114, 84.85831352972215, 89.18740995468633, 88.13262970216813, 88.52810659716206, 88.96669034034976, 90.65500397836009, 90.24561835873513, 85.97331000912575, 85.30643647716892, 89.00274476697369, 84.42812365870323, 84.47530192713585, 92.2331460829704, 89.52973873384538, 86.43004648147091, 84.42988088054042, 81.08640547721618, 85.6581554105205, 81.32503463375954, 84.36060397855698, 89.26088379275414, 89.30379452243929, 87.55764161386799, 92.98528409773304, 95.11344448212655, 90.99001361477761, 79.90912960421655, 68.03228685932775, 68.46495566829559, 79.05409997509372, 79.82773257840066, 83.34005032816242, 87.76415440344041, 100.60538245785622, 90.77044717727169, 71.4084199167067, 86.0029709723688, 59.56263057647213, 39.25500615950554, 0.8014509105874646, 4.146774363133216, 2.973916549836436, 1.7659507042938665, 0.3828085586428643, 2.5930916686211867, 0.5333619961334813, 0.15515238587414065, 0.4130685107121545, 0.635104172172085, 31.03671104677262, 91.01172785605155, 99.65281132728823, 86.79547802094491, 64.87126050456878, 98.49415102312642, 53.17340335538311, 42.965940967682876, 55.18769733367428, 69.03455441997897, 76.13143997807657, 87.41851514385593, 87.83748703618204, 84.24589818523776, 1.2914797255108434, 0.31690584495663643, 0.20840930151602916, 0.19603423894413058, 0.12345544438088134, 0.13086652533421594, 0.13945521366211677, 0.13083874698608153, 0.09944699960009706, 0.1487123290257108, 0.10680312906662304, 0.2777801105572332, 0.1726423876900827, 0.1384965159119137, 0.21757310737044583, 0.22258073301805606, 0.10096653499790739, 0.21681870994788988], [0.06901286978034243, 0.04309528792697576, 0.13143686247208428, 0.13369504452472733, 0.03110169500653302, 0.04902994891087856, 0.09605331436520624, 0.07702588899842194, 0.019740314230382926, 0.025625754065150698, 0.026324928039684895, 0.028312780646487113, 0.03518685120187941, 0.03917158093123187, 0.03691010470051439, 0.10683833080674372, 0.4274376541856797, 12.107520276500333, 76.03162350193148, 67.83358743113857, 74.27328771160495, 45.571900952246885, 56.826428290336366, 54.26598348925191, 32.361056189383234, 34.954546959169456, 59.10744344034503, 93.74441177614274, 96.71301057261806, 77.25978820554673, 4.905354870903877, 0.22982410966388642, 0.13383579019817615, 0.05353448078817418, 0.1990360625448727, 0.15506272294348286, 0.06009677079536262, 0.2556139386950001, 0.20213441322407416, 0.1621479330764663, 0.7812924406701519, 1.6705927372940126, 0.6963505115239852, 27.256375781951416, 64.3439252914921, 90.33980231131278, 83.66486964687225, 57.841725964700025, 72.09575253148233, 66.90108314637216, 76.62230107092088, 69.84793632261216, 67.3726697121897, 72.89713982612857, 77.03305952010616, 79.18128675030124, 89.23673768197337, 87.14968373698574, 87.6163673400879, 91.7541854612289, 90.88061871067171, 90.62620593655495, 89.77886415296986, 90.46786769743889, 92.52648445867723, 90.62090289208197, 89.13827834590789, 88.69164589912661, 83.9293707570722, 85.19893215548608, 81.48144306675081, 80.70118165785267, 75.3717710125831, 79.77362740424373, 80.88803552812146, 84.37580708534487, 83.70562307296261, 81.83612731195267, 84.12035096076228, 78.42066072648572, 77.30785292963829, 77.55089083025533, 78.57247998637538, 77.39765951710363, 71.02871094980549, 67.59134969403668, 69.64602839562201, 67.55866850576093, 65.19238887294647, 18.88492976465533, 72.3733857370192, 77.00508517603721, 76.77164139286165, 70.05589254440801, 76.80422844425325, 80.49649669278054, 83.33447271777739, 83.24116737611833, 84.02359393335159, 87.72329899572557, 83.50685304211032, 79.76821453340592, 80.97751263649234, 82.75084757035779, 81.12879060929822, 75.79447700131324, 80.70738684746527, 81.06287125618228, 81.0865702167634, 78.57433134509672, 81.03906246923631, 78.38286476750528, 81.37064395412322, 78.53731986015075, 77.07369527509137, 75.1999633542953, 83.63628341305642, 88.44044162381081, 88.37657759266516, 82.31890047750166, 86.51993936108005, 84.97656514567714, 79.20053774310698, 56.18427353520548, 51.97290705096338, 55.968398048031716, 61.65572497152514, 68.29466204489431, 112.51927591139271, 114.12182300321518, 62.69722800101004, 70.62062755707773, 41.566968810173776, 20.76439619064331, 16.891600854935184, 0.12481574840362995, 0.41931991074835107, 0.6702617243413003, 0.4777973325502488, 0.3093932803359724, 1.5722102551690995, 0.21608706533668504, 0.16501768311906248, 0.3487945918834979, 0.9075078163896838, 38.404651995628114, 80.77365921389672, 91.06997505311044, 79.7954200929211, 49.92928158852362, 64.22013136648363, 40.16315644787204, 31.93599089499443, 35.64153440536992, 39.25711247228807, 52.75108960367019, 68.27781154263404, 70.5926767472298, 33.50873385706256, 0.978133216980965, 0.07452505625664227, 0.04135642538688356, 0.01442233008527828, 0.060901327824760834, 0.005804391084013568, 0.10040546752392285, 0.0538061470574429, 0.057157092247038126, 0.08243886708852746, 0.06901024975964139, 0.023137956309402664, 0.051335762480213765, 0.1276403911892445, 0.05317164622547646, 0.21080216182576073, 0.20335695165539944, 0.07576492359681476, 0.03113652902445005, 0.10688484766550603, 0.018168037509425514, 0.0324941708916618, 0.008965557621371363, 0.05065916128636849, 0.0632665898170202, 0.09998615695944718, 0.015204599701739369, 0.015050857346655141, 0.07624623365700245, 0.05896461541734396, 0.08219228636833929, 0.11406725903432216, 0.07251887116581202, 0.46414420549427315, 17.36290304891525, 89.93153848955708, 83.6249791422198, 89.44755723399501, 59.43921319900021, 70.44400322821834, 31.861405064982755, 16.95365078987614, 30.70440980695909, 63.33258921100248, 106.94256767149895, 109.44748740042411, 84.77324516542497, 4.111632132722486, 0.3688462997876829, 0.09377169768295943, 0.04811825065483009, 0.027500957273127093, 0.12728971444190512, 0.1493842647440972, 0.1374538242816925, 0.23201118343539778, 0.33976980034382115, 1.1992672542410514, 2.0436192111622904, 1.1008736178759606, 41.846394538879395, 81.04795056004679, 93.558287466726, 90.30005301198652, 70.96549018736809, 82.80114804544758, 77.24568336240708, 84.26598856526037, 73.22781132113549, 74.72473682895784, 77.44060947049049, 82.60646512431484, 85.37299125425278, 93.94495471831291, 93.65268322729295, 95.07932770636775, 93.53450221400108, 95.52167692492085, 95.23037818170364, 94.09478141415505, 95.92277849874189, 94.39772959678405, 95.56351292517878, 94.25081329960977, 92.27258159268288, 90.33778621304421, 86.27319874302034, 86.26313394115817, 82.56638634589412, 80.98029751931468, 85.74766389785275, 86.0037083779612, 88.5153510493617, 85.72621637775053, 87.09982256735526, 86.97025883582332, 80.33382031225389, 76.7085147673084, 76.96396304715064, 83.4003528471916, 79.51527657047396, 71.82625432168284, 68.05824510512814, 68.59881831753638, 67.03544785899501, 70.68398952484131, 29.643687163629842, 70.00447027144894, 76.31586197883853, 77.1668201877225, 74.02536253775321, 76.70395697316816, 83.26615287411599, 83.87248854483329, 86.49473421035275, 85.22457661167269, 86.44558691209363, 84.58635207145446, 84.15061596901187, 84.62276735613423, 84.02770457729217, 83.40204731110605, 81.63343491092806, 83.73323655897572, 82.8163746864565, 81.80930614471436, 81.96209030766641, 84.06527303880262, 80.24191917911654, 81.2334551349763, 84.58199824056318, 81.12500159971177, 77.31474845640122, 82.67119992163875, 84.55322373297908, 87.72984935391335, 85.10255167561193, 87.4729262628863, 87.23191230527817, 89.2888032236407, 73.91843088211553, 62.93977168298537, 64.14335097036054, 61.51507662188623, 69.56362724304199, 87.13045627840104, 108.22160551624914, 83.41670128606981, 73.5760550345144, 78.76918685051703, 37.993034547375096, 25.00452541535901, 1.5513438587227177, 0.7035158850973653, 0.46404856707780595, 1.5437193839780747, 1.2042199820280075, 0.23148800667014816, 0.16850315334816135, 0.2922301222720454, 0.05218400184305445, 0.7110844047800188, 40.06941180075369, 92.77778287087718, 95.86690825800743, 84.87939234702819, 53.401500948013805, 35.03218635436028, 21.49712239542315, 39.320698015151486, 59.037189868188676, 55.18659122528569, 71.56118839017807, 75.48202099338656, 81.71586744246945, 51.896220791724424, 0.7309145600565019, 0.059089598831750696, 0.09967940003280679, 0.1050017805649869, 0.01385626292997791, 0.05569319015428905, 0.030773968338185263, 0.025865039713079893, 0.11815356436155497, 0.016005099337968617, 0.05812571849673987, 0.04886201860743666, 0.05512326670389983, 0.017310003712472898, 0.10707628537690449, 0.14375025496607827, 0.067417859400232, 0.1946114451293984, 0.15381248277281562, 0.2950043717940008, 0.2019689229106711, 0.19737314613115406, 0.16211037944641807, 0.21553774965145897, 0.20719937289193754, 0.18283894135346337, 0.12499996190590244, 0.09325711642422023, 0.24826386132307593, 0.10673265663846847, 0.18609121441841128, 0.2507715582126572, 0.35585473561959885, 0.47724994740659193, 24.266847218236617, 113.50601873090191, 95.5398924120011, 104.00936434345861, 68.38711230985581, 84.0739179426624, 85.91470979875135, 46.8716489115069, 51.08857731665335, 85.32331835839057, 120.9010514905376, 120.4642955718502, 98.2203931193198, 7.405721708651512, 0.6696788233614738, 0.5309980326602536, 0.35977128352369037, 0.3882643304044201, 0.37856280743595094, 0.2852796823267014, 0.3833738702439493, 0.45725781049939895, 1.111699236977485, 7.7557554937178095, 11.442349053198292, 2.695033088807137, 50.57655503672939, 93.5604133913594, 100.821395227986, 98.48002264576574, 81.80446593992173, 92.82136824823196, 86.43426695177632, 92.38176468879946, 84.2404382459579, 85.06181393900226, 83.60080165247764, 90.20036989642729, 89.74450419026037, 97.18294974296325, 100.3736174491144, 99.19110913430491, 97.92569760353335, 99.6833352119692, 97.30762620126048, 96.70233388100901, 100.10394665502734, 98.12719760402557, 104.12375634716403, 97.92820007570329, 94.73124088779574, 94.95822844966766, 90.02385539393272, 92.14435146700953, 85.65950470585977, 85.0744047472554, 88.69196753348075, 86.75731335916828, 92.0598949924592, 90.8037010315926, 88.53675150102185, 90.22209982718192, 83.14305320862802, 80.65889850739511, 80.61055921739148, 87.13997979317942, 81.72433191730131, 72.42732617162889, 68.62149746187272, 68.25039417512956, 69.72201255060011, 67.40145206451416, 31.618259299185972, 75.18628997187461, 76.54408116494456, 81.23036430728051, 74.67994336158999, 80.3655287527269, 88.58417295640515, 88.16920972639515, 90.14431922666489, 89.4749039988364, 94.87131657138949, 90.51924290195589, 89.51837954982635, 89.00671420558807, 87.35568661843577, 85.81142594737392, 83.81071905935966, 85.54894878018288, 84.49998148026006, 85.3367171748992, 85.11700168732675, 84.8142731574274, 83.45277924691477, 83.29813588050105, 84.67291093641713, 80.66648437130837, 80.1065032712875, 87.12295670663157, 91.72283787881175, 91.70990190198346, 89.99825800618818, 93.78439641767933, 92.9236715070663, 84.8245026988368, 70.92876111307453, 62.226072895911436, 70.6132064327117, 70.56040348545199, 80.05014665665166, 91.25871950580229, 100.36556874552082, 83.56278604076755, 78.54074801168134, 81.23163515521635, 55.84075235551404, 29.926256672028575, 1.1121857334529202, 1.2100000847731869, 0.9773670064826167, 1.2207133034544608, 3.0867359282508975, 4.325276526712603, 0.3364713628205561, 0.3278466836819726, 0.7051457524780305, 0.8650658712271722, 54.48400059053975, 100.89775593050065, 107.36956473319762, 94.35005710970972, 66.39848632197227, 87.36305282961938, 59.228150460027884, 47.02292688431279, 49.422883987426765, 53.13625066511093, 74.05321136597665, 86.15168371508199, 96.34421363953622, 64.56572747999623, 1.611234651457879, 0.2264838284181972, 0.1825314489824157, 0.21497046154352928, 0.10049146089342334, 0.08151776127276883, 0.2311420260417846, 0.18736123497928345, 0.18398464116598331, 0.15365569521823239, 0.2692375560441325, 0.2354917047365058, 0.19506008153961552, 0.14358770643030444, 0.18637906429508042, 0.33362611226977845, 0.4339271237052256], [0.056423164693818945, 0.08325389270941097, 0.012176063572687489, 0.08872502453384862, 0.16707682020721898, 0.08158482460966034, 0.12184791612408816, 0.12181099068613783, 0.008399960652534521, 0.013406192020122564, 0.108230144025818, 0.051339983624676545, 0.027236802495955944, 0.09030474379899041, 0.05787819931884447, 0.08956507824721838, 0.09389737440693764, 22.256659961515858, 71.3462503494755, 60.03187156492665, 74.6487997424218, 67.61708044236707, 44.35710760854906, 70.99673578816076, 86.8595067916378, 49.42684950367097, 82.26996498723184, 82.37390779679822, 86.92917593063848, 12.191604125884272, 0.09818515319737697, 0.07984530706439288, 0.1338153050070809, 0.016958359779129108, 0.11205817813113814, 0.04649540830043055, 0.03714776049638468, 0.14260924361165495, 0.19611290085219568, 1.1695340948720132, 3.7832902804497754, 1.4992826071477707, 6.948533183143986, 63.918391273867705, 47.32575347346645, 60.76039298888176, 67.1562333260813, 61.762809599599535, 68.23117456128521, 66.19903379871, 63.54025909977575, 65.78128176350748, 73.52347958472468, 75.14629748559769, 81.93109573856478, 89.61284591305642, 91.82400365029612, 91.27577397131151, 86.1022069377284, 90.53687003351028, 92.07405474878128, 86.76121219511955, 88.19080629656392, 92.29257783582135, 86.10564293399935, 83.69034151877128, 80.05116647289645, 81.47361401588687, 84.64124171964585, 84.84485195529076, 81.0558266793528, 80.26577503450456, 81.11353258932792, 79.59911331053704, 82.13592190896311, 80.50707140276509, 78.35918149640484, 80.85483658698298, 80.98923267856722, 83.65052161678192, 80.9275887089391, 75.49304285357076, 76.09154162868377, 71.88670589077857, 68.86130332946777, 68.30783336393296, 69.38888565186532, 67.81902759305893, 70.8451989389235, 55.122774262582105, 59.452157020568855, 70.55026023618638, 73.42750703134845, 76.82376184771138, 75.43148517608643, 78.16882887194234, 75.08899165738013, 76.35903158495503, 73.76469750558176, 76.46215069678523, 81.79889617427703, 77.88795578864314, 78.25779607219081, 78.92037068643879, 80.07554008114724, 79.25350542991393, 75.1054185436618, 79.35398870898833, 79.19716450475877, 77.78274997588127, 79.73423111823298, 80.63261862724059, 76.9788052958827, 79.26730432818013, 78.09798302188997, 77.79002989492109, 78.15342964664583, 82.29507600107502, 83.22179871220743, 83.89574035521477, 85.0344357951995, 81.73362008986935, 76.81622305224019, 74.40872715365502, 62.39192247390748, 52.87239282361923, 53.02716955061882, 57.1728402568448, 72.85598631828063, 111.7790226782522, 101.7759196988998, 66.36858217177853, 71.01347646405621, 29.524013688487393, 22.61681983547826, 9.902091160897287, 0.45983713660990044, 0.7138296348914024, 0.2244980365879113, 0.14527417238681548, 0.36552276522401844, 0.11851249187583886, 0.16450111003172013, 0.03753876794249781, 0.09800760466004572, 1.920263120724309, 62.884662382064334, 81.60331110800468, 82.36043053288614, 67.81504246496385, 32.73053953724523, 57.382008491023896, 47.78956590160247, 28.31483521769124, 39.78170202624413, 36.26159444932015, 50.10752977863435, 60.341836867793916, 63.88643964644402, 19.06646097860029, 0.5674792009015237, 0.06985201950996153, 0.12351911394826828, 0.07072043379828816, 0.043297856895914005, 0.03498835782069833, 0.047899390826182026, 0.017578948454390612, 0.1113640641673438, 0.03017056493028518, 0.0265027561991085, 0.05871546447216984, 0.023785578312292218, 0.020030418320769267, 0.16619186608060715, 0.20488745743228545, 0.06385400688516037, 0.06842413887141213, 0.07343563326303998, 0.0336766084505906, 0.04689516064019934, 0.10351758480312363, 0.12498640214964268, 0.023498260866730444, 0.05510136041970504, 0.03688443692461137, 0.02878659645155553, 0.06620416928443217, 0.07580513555196024, 0.047613463830202825, 0.014495573836498925, 0.02833192709893469, 0.045636700346104564, 30.680599058828047, 91.64869723781463, 72.68382564667733, 92.91730157790646, 74.43315567508822, 48.92151486489081, 49.26073712687339, 68.51041593859273, 59.63752039017216, 94.69461379512664, 93.82313374550112, 97.65113169147124, 11.472459127826076, 0.1930827166764967, 0.24244156245502735, 0.18963365094555965, 0.010695589082916419, 0.06854593919049348, 0.03198569535367912, 0.1383240388766412, 0.09339495862443602, 0.13621712854552653, 1.2589918365401607, 0.5200692674806041, 1.4669975782594373, 14.128985328059043, 83.25819830740653, 62.490197458574855, 74.01430929860761, 78.30619812011719, 74.2607988849763, 80.57233179769209, 75.98879906439012, 72.94276483597295, 73.66598713782527, 79.16886068159535, 81.23613803617417, 88.83305518857895, 94.67175422176238, 96.02661148194345, 94.78486753279164, 93.9914426495952, 92.56917553563272, 93.58888195407008, 88.65414019553893, 92.88143542505081, 94.56701124868086, 88.1692881737986, 86.38935581330331, 88.87635815528132, 86.41773023912984, 89.64766871544623, 87.7817815349948, 81.55446975461899, 86.73398310138334, 84.27382546086466, 84.7645845720845, 85.31384191205426, 85.58963160361014, 83.82365503618794, 83.93970228010609, 84.28434525766681, 85.65312693195959, 80.38190072582614, 76.0744793184342, 80.21010875701904, 72.47936817907518, 67.01392189148935, 67.15511152821203, 67.99280428117322, 68.64503952764696, 71.28798746293592, 58.45122698814639, 63.660134576982074, 67.76737782262987, 73.23641700129356, 76.07553835838073, 77.60509798603674, 80.29316886778801, 79.85852318425333, 80.27844429016113, 77.75275953354375, 77.99032180540024, 80.2636726440922, 78.80082468832694, 80.70836744000836, 80.84520324583977, 80.45433121342813, 84.00903409527194, 81.98007045253631, 78.81242705929664, 82.33706889613983, 78.99710793648997, 82.21037633957403, 83.93836082950716, 79.36846225492417, 79.85605209104477, 83.02293454447101, 77.46197854318928, 80.33027448961812, 79.89792731500442, 83.45997287381081, 82.4856561230075, 84.19211464543497, 85.9657790583949, 80.07310036690005, 82.81240524784212, 82.0438168125768, 66.11833495478477, 61.20164394378663, 58.3279037475586, 68.00858005400627, 86.7333947458575, 105.88228825599917, 77.41956203214585, 77.05683692809075, 64.66167257678124, 35.358323589448005, 19.225669983894594, 0.39646551613846137, 0.5402028548621363, 0.3129968353577199, 0.9204878585953867, 0.18106687273229324, 0.28456820114966364, 0.0886309719193847, 0.11680626085088139, 0.04953367470373069, 1.1097132919296142, 66.85657208965671, 91.24307709355509, 91.96718585106635, 74.33762242717128, 40.794422703404585, 28.33668281955104, 32.73216339849657, 37.012398858224195, 55.138710852592226, 52.21357191762617, 71.82149256429365, 66.6169152721282, 78.81545512906968, 33.28379769479075, 0.5588874329001673, 0.039244412910193205, 0.11217472308705892, 0.06578314268300611, 0.027024569327852903, 0.10005328158337264, 0.03047891340458826, 0.03447320965689517, 0.07143302580281612, 0.07986507213283932, 0.03199796425178647, 0.07074553083868758, 0.045613844112883654, 0.056138616656103445, 0.043947855686588634, 0.07331597799014661, 0.13517575458653514, 0.2764795996969746, 0.14159999938020784, 0.1125320188340641, 0.17958188789986795, 0.22467969135651666, 0.2904087022667931, 0.11997521419318453, 0.14303534171513974, 0.08227673224023274, 0.25912976132765897, 0.15934556812768982, 0.10682601977380053, 0.1215825968932721, 0.16358640105012925, 0.39495852926085073, 0.253348907816314, 40.81959255280034, 110.83828926086427, 88.78670846262287, 106.37884463033369, 94.67666502921813, 72.89742223678097, 109.80211673244354, 128.07601574928532, 74.32430990280645, 109.8200890325731, 103.89443889740976, 112.31698359212568, 17.15966151606652, 0.2781101412350132, 0.34994960732517705, 0.41340902147273867, 0.25663216147691975, 0.3238905137104373, 0.20399392312092168, 0.6247677461754891, 1.0293678290420964, 0.4541263801436271, 4.0047448488973805, 14.361378896620966, 5.5434690944610105, 15.311053356816693, 97.40985885743173, 73.8665771484375, 92.07666704731604, 91.91111949182327, 88.25168932637861, 91.15257232419907, 85.21078555814682, 82.79332683932397, 82.96172988030219, 83.00777066138484, 87.08888699931484, 92.2242501474196, 97.30793214613392, 100.72091194891162, 99.86321510807161, 97.59416318708851, 94.19145999416229, 97.356577381011, 94.45177201301821, 94.97062313941218, 98.18851209455921, 94.9049234390259, 89.2879795259045, 93.61709948508971, 89.41587232774305, 91.26110430686705, 92.1670384560862, 85.78884093992173, 88.29229370240243, 88.67128879793229, 88.18707220015988, 89.55811315967192, 89.9358138730449, 88.82419063198952, 89.56394964648833, 87.31983615506081, 87.76500948013799, 82.95114732557728, 80.75524760830788, 86.16496486048545, 77.87325474523729, 69.370850593813, 68.44149989466514, 66.93327796074652, 67.82634673580047, 71.93804971633419, 61.45200490951539, 67.05049407097601, 70.92767069416662, 75.83235140769713, 80.3418690158475, 81.3169231722432, 85.83145356947377, 85.10743894884664, 84.51741249330583, 83.38675791217436, 81.59148908430531, 88.06747128886562, 82.75182816290086, 83.97443879035212, 85.91741623417025, 83.22816864136728, 87.82692801567816, 86.83550973092356, 81.9985761950093, 84.48680231648108, 81.72739136603572, 85.8210906674785, 85.47116817966585, 81.13911428759175, 81.18648082979264, 85.04344155711513, 77.27069239462577, 82.08062433427381, 83.82629086894374, 88.59863865760066, 89.49554351068313, 89.4122088340021, 87.53013010947936, 85.07915865990424, 80.42928295750772, 78.79887919272147, 62.22059334478071, 66.44402503967285, 68.00770144308767, 76.82067886475595, 85.36917871044528, 96.7693671872539, 80.6251504344325, 81.5162266454389, 69.99718250766878, 56.105033812984345, 19.07308586182133, 0.6802569654199385, 2.0100765723374585, 0.3479829370494812, 0.7653134400325438, 0.6299791052456826, 0.5045589900785877, 0.2390254997918683, 0.19357491284608844, 0.21778254048718562, 3.824958354234696, 80.16171455383301, 97.01644512914844, 95.45317665223153, 86.67194689473799, 49.94077413312851, 88.5350570371074, 73.5315518225393, 40.42095422744751, 58.15729633454354, 49.68195261493806, 72.324873862728, 76.56531687705748, 93.53832260254892, 46.581511189860684, 0.8400971658768193, 0.14017784907933206, 0.2536583920159648, 0.19495701207028282, 0.1288814229830619, 0.2176159470071716, 0.1214437128134793, 0.09828923390276971, 0.154637253032096, 0.18423700584999977, 0.21590018584843607, 0.2822655859974123, 0.15457959725491463, 0.11010512123785673, 0.22968006981236322, 0.21695358738783868], [0.13740217463383753, 0.10924740919783231, 0.07742992376968746, 0.04760952613827202, 0.08646185524881848, 0.24307835005944778, 0.09225909538086384, 0.03038692156664066, 0.06378084165795196, 0.0554757475883009, 0.05381054823256789, 0.18147892078324673, 0.07281473432216914, 0.026840068542608814, 0.10790244991620702, 0.09841675689864544, 0.15443054718836663, 19.081071807492165, 58.69875208024056, 62.284033759947754, 61.29705559822821, 48.0107875793211, 59.17262538786858, 30.21720632430046, 42.375836064738614, 65.90548361501386, 89.17645085242488, 89.39837855677452, 22.308413674754483, 0.36900288815940585, 0.12583436189039102, 0.18473615809794397, 0.056998427777040395, 0.1570112216136148, 0.046425311255358884, 0.2988248829159045, 0.255569857995837, 0.2680869532688972, 0.061117242045340046, 0.8277001472250108, 0.8742988241776344, 1.3238115776931088, 58.01956622831283, 67.63458205807594, 48.68144227612404, 44.51876025046072, 62.02964844242219, 60.62432988997429, 61.3546242252473, 58.904441172076815, 67.3736346152521, 76.8042205995129, 81.15525091848066, 83.82298823325866, 93.41235960683515, 90.29106293955158, 94.21209166126867, 90.70026028540828, 90.40363496349704, 87.74210283833166, 87.26336971406015, 86.2183012500886, 89.08020373313659, 82.09979687967609, 82.53457592379662, 83.08748891276699, 85.71360203527635, 86.27379494328653, 86.2876565994755, 84.85240644024265, 86.70725607102918, 83.88959792352493, 81.4598935650241, 82.3963829778856, 76.7189561167071, 77.91454161367109, 77.4347572941934, 76.76072151430192, 76.94911295367827, 82.74603874452653, 77.39207406197825, 71.78319454193115, 71.3947073105843, 66.26781648205173, 62.56485193006454, 68.46271207255703, 76.23256652585923, 71.33138456652242, 80.46056778200212, 75.05147810905211, 66.08337094706874, 63.65838519988522, 75.1261757266137, 73.18284526948007, 79.24529983151344, 78.18069011934342, 77.78654683020808, 73.9072129034227, 75.32304733030259, 77.27208091366676, 78.10233685278124, 76.53214931488037, 75.39449722536149, 76.11031409232848, 77.45036048273887, 80.63644686052876, 77.46119406915481, 73.33831233362999, 77.87940502166748, 76.13137722015381, 77.03029032676451, 77.7515749777517, 76.75270418966971, 74.59462396560177, 76.5172835319273, 75.38610335319274, 79.15153165017405, 83.50795130575858, 83.12330015244024, 81.67675356711112, 84.03246633468136, 87.75995746735605, 85.15261680849137, 78.35771452996039, 74.39877217815769, 66.51607113499796, 58.1101494450723, 55.86728718972976, 59.698685830639256, 75.73185243914205, 110.1911138719128, 87.00713696018343, 66.29110751613494, 64.10009507210025, 23.411070377595966, 24.10229398358253, 3.1089085965387286, 0.13070258251841993, 2.866135455908314, 0.9685829810557828, 0.240020249639788, 0.42842756235791796, 0.12460888934231575, 0.07210784967267705, 0.06823843915856655, 0.18296890050893833, 5.644890310302858, 67.66370957897556, 80.5689428698632, 89.779891813955, 61.14732303927022, 51.47594275013093, 47.70420728191253, 39.266765425282145, 32.669026967017885, 46.61982882407404, 35.42618843816942, 60.16123917794997, 60.64344359982399, 74.03282288582095, 26.84279714861224, 0.5601269018746192, 0.12728954590256178, 0.026257872363672625, 0.20878804006403495, 0.043450212631855285, 0.12950187759293666, 0.014158835101331917, 0.07619277604164616, 0.22157732637659197, 0.049675236260818864, 0.045065148958876255, 0.04361844170958765, 0.09386644743743444, 0.03430869227515594, 0.21980240790834352, 0.06094048640901043, 0.1271891500800848, 0.11317714913597993, 0.012175737985319669, 0.02517240429897943, 0.0883513804705393, 0.05055418808854396, 0.053999783441184036, 0.018356939469794595, 0.05365723105628164, 0.06833256838182289, 0.05257523911554487, 0.08560872441458126, 0.08730000140325678, 0.13443087197599873, 0.011211303194173643, 0.1859912093007757, 30.466647494223814, 75.98345679621544, 77.00031557390767, 86.83743953704835, 65.25670397666194, 66.63429137199157, 36.09909457545127, 50.998660902823175, 75.06675966324346, 103.08028036548247, 102.27293106817432, 24.622253179550174, 0.3369224660338894, 0.08896993518236185, 0.23412224596306203, 0.021280748506767616, 0.12775047036308435, 0.03533510070654654, 0.4634219684427785, 0.4158800840377808, 0.8679628480345973, 0.07909760525029513, 0.37613311361881996, 0.7216355192565149, 3.9336452705244866, 74.9593573231851, 76.58921195614722, 67.17025187707716, 60.14458871656849, 72.61819654895415, 71.43124026636924, 71.55783868605091, 71.66511551026376, 79.60444773397138, 82.07545465038669, 87.43708364425167, 89.14460905136602, 97.69845116523005, 92.20753300574519, 99.35822563786661, 94.47175256667599, 96.094342970079, 93.19669985002088, 92.29674339294435, 91.19265894736014, 92.6262067979382, 86.80831986088907, 85.29102156239172, 88.94319534301759, 90.77017261135964, 92.36713424805673, 89.26670459008987, 89.15457971634405, 90.26696389721286, 85.23684578557169, 86.52227709370275, 84.96627284634499, 83.77015390703755, 81.38955762309413, 79.91250284256475, 80.93661016033542, 81.99888213988274, 84.47345841315486, 74.70587807316934, 74.38861323941138, 75.74409023407968, 72.06216919806697, 66.05815795160109, 67.3138733833067, 71.0988978416689, 68.85323109165316, 85.03498492702361, 79.98302705826299, 69.22210647213844, 66.55992323352446, 72.71248248315626, 73.65229022118353, 79.51759861361596, 81.916214266131, 80.70546488608085, 78.42834857202347, 79.3953775590466, 80.04412189606698, 79.15224552154541, 78.0475256519933, 79.64238489827802, 79.44275194598784, 80.08047442282401, 84.82160014490928, 82.01878424613707, 79.95014975147863, 80.10187487448417, 79.44983574651903, 78.00268511618339, 79.37716207196637, 80.79229831695557, 79.3059318296371, 81.18693582473263, 79.23581554043677, 77.15925001328992, 82.14098961122575, 82.4236826742849, 83.2410026365711, 82.5920621810421, 86.94833278656007, 87.54697276699929, 82.24029617924845, 77.68491821904337, 81.1063938756143, 70.0548727281632, 63.492319891529704, 63.47810129965506, 70.5096793943836, 87.92115119195755, 97.03619034059587, 75.01810658362605, 79.34212746158724, 55.20336720251269, 34.48849485766503, 8.586356601407452, 0.5235230982784302, 0.3559521513600504, 0.33494335449030327, 0.3180634957407752, 0.09106406716689949, 0.28209986585763197, 0.028203007907816963, 0.030003419866965666, 0.31100745823594833, 6.51008427143097, 76.14363854931247, 89.3326396326865, 97.23929851285874, 67.23989748185681, 60.84716366183374, 25.324310371952674, 41.86428446923533, 46.5130893645748, 63.25874667013846, 46.56564912488384, 81.32256354055097, 70.78473168034708, 89.87034951486896, 40.35499172825968, 0.6576496494873878, 0.21049753462354984, 0.025874062313608108, 0.15490314682885525, 0.05408303038547597, 0.03227773190085446, 0.02951934614459113, 0.01578143805325512, 0.14979729338759376, 0.04913405259890903, 0.08752647997631181, 0.05308435433694432, 0.029639846029421015, 0.07326979054919175, 0.07812134110398831, 0.18475744002048047, 0.3004989076045252, 0.18173125482374625, 0.0836101618985976, 0.16338700368519754, 0.24487617455663221, 0.22491564643719505, 0.1593784026561245, 0.11093536136491645, 0.13945522898387525, 0.15689684468651974, 0.30625379073523706, 0.1404801780177701, 0.2286710400855349, 0.26011452138904606, 0.17350486479699614, 0.3136824840499509, 46.06469185121598, 97.62906443688178, 92.69163193241243, 90.44316461009365, 74.74398782176357, 96.20384770054972, 48.48957169440485, 65.43936875558668, 90.21372164449384, 119.36611037100516, 117.073179060413, 32.43760712685124, 0.3939408274187196, 0.32812802181128536, 0.35693062950045834, 0.2696692006241891, 0.46676168278340374, 0.28457092842267406, 0.8778823383392826, 0.860723072002011, 0.9139085729275981, 0.27460302136117415, 2.360905250233989, 1.886372248972616, 3.398499637842179, 87.82178971075243, 85.46796752560525, 79.88000992805728, 74.11404732734927, 88.01961052802302, 80.47175438173356, 84.80579299311485, 81.38775333281487, 86.85174834343695, 85.83671739024501, 94.37159092195573, 91.52255381307295, 104.68481217661213, 95.6307658841533, 102.9935646057129, 98.35534618746851, 98.81666398817494, 98.29710683514996, 96.74426401815107, 90.80521506647911, 96.51424838650613, 88.24434664941604, 90.6096927581295, 89.78803465443274, 92.12532797167378, 96.23859205553609, 94.46637107479958, 94.54226893763389, 94.210232457807, 91.36558055877687, 88.21630170268398, 88.30551208988314, 89.79050574764129, 83.04907321929932, 82.26257524182721, 83.20808610608502, 83.4963724690099, 90.68950514639579, 79.22826890022525, 75.43138319446196, 79.88408134829614, 75.54035448258924, 68.90199399763539, 72.08359318394815, 75.804714387463, 73.14433543912827, 88.4671215857229, 89.65856505978493, 74.78469417941186, 67.80165149319556, 76.99609510360226, 79.77733012168639, 84.85419504104122, 85.1811638186055, 84.37585415378695, 81.5402001719321, 82.24610128710347, 81.50303963691958, 84.66647040459418, 84.58123730074975, 81.32440705453196, 82.12189551322692, 83.76805936136554, 87.64753449347712, 82.4858679309968, 81.85811611913866, 81.63871442118, 83.74130879679035, 83.77528436722295, 83.52855159390359, 81.57633304595947, 79.95319351073235, 83.21480904856037, 79.62766032065116, 78.0608146421371, 85.57614649495771, 87.02320298840924, 86.03935487808721, 89.10883703539449, 94.37495631556358, 91.9990276521252, 88.15518333065896, 77.48399872933665, 78.07189141550373, 65.76054027003627, 65.82261177801317, 71.97057400980304, 76.88448798271918, 88.06402744785433, 87.90444189502348, 75.942656301683, 83.30422339900848, 68.94131968098303, 52.960022495638945, 6.2189061410965465, 0.6812324711392004, 9.079340677107535, 4.003035676094794, 0.44027940219929146, 1.3722328697481465, 1.3583444924123826, 0.15444205382898932, 0.16069029758293785, 0.46276757613785807, 19.162747321590302, 99.01948190504505, 91.55838858696723, 99.16799852924963, 79.61902326153171, 73.34157574561335, 70.19951405063753, 63.318103897956114, 46.159322953993275, 62.571135567080596, 48.06847387744535, 84.95062258935745, 79.63519911612235, 106.89843316232006, 48.55249043433897, 0.674274860610885, 0.23026828744238426, 0.18589098967852133, 0.4014439844796735, 0.1671525250158964, 0.330198175243793, 0.18301112727532465, 0.19130818125221039, 0.29913119551154876, 0.180037526353713, 0.2507228656641899, 0.26941841408129663, 0.22961754171598345, 0.21093069605769652, 0.3058530348202875], [0.1479122880846262, 0.14018947829402265, 0.0164264879159389, 0.07168041857620401, 0.15381141024972164, 0.15302857564341638, 0.15496060342317627, 0.11669228995038618, 0.06402173417530234, 0.03129894157961732, 0.06748890639432976, 0.0807545998043591, 0.02630975566834452, 0.02058705972177127, 0.13646011631334984, 0.0421418532008125, 0.4649987918955665, 21.804638178117816, 61.369231131769, 52.747779123244754, 59.97866853590935, 53.11957666950842, 31.700680063616847, 36.50054524021764, 57.198516091992786, 85.32236914480887, 96.93364389481084, 36.21437303481564, 1.272872123987444, 0.1486121400469734, 0.1044240047133738, 0.14901943835279635, 0.10569249309839741, 0.10712446464646248, 0.11987212940209335, 0.15868317786483996, 0.013924537643399692, 3.4702716575514887, 0.3868852495666473, 0.39876561852232106, 1.1058170300337578, 31.5047949360263, 61.51287224984939, 42.74180104655605, 53.7058376496838, 46.691772937774665, 58.763667306592396, 59.33666675321518, 68.00668162684288, 68.472180674153, 75.67730795952582, 76.40146378547915, 84.47327013938659, 90.2224293062764, 91.79012221674766, 91.46409480802475, 92.60447686718356, 88.02326617702361, 88.69328544985864, 85.08795261383058, 87.60827156805223, 82.12139344984486, 84.06535148620605, 85.58225754768618, 86.3758707046509, 91.91694028915899, 91.01089631357502, 84.60685822271532, 81.36570961244645, 82.7862665730138, 84.18404240762034, 85.58994539322393, 83.60122526845625, 79.5177084399808, 77.94929381339782, 78.06512924932665, 79.57120956913118, 78.24293028923773, 78.99621363609069, 74.62221391739385, 74.85600286914458, 74.86901729337632, 76.9337215731221, 71.14904926669213, 66.11458516890004, 68.20590665263515, 70.28997959629183, 64.10150712536228, 70.80306483853248, 59.08613320319884, 59.46022533601331, 63.32407766772855, 64.98665663503832, 74.68318323935233, 78.0836820602417, 76.52877607653218, 74.7453292723625, 76.54383797799387, 73.20482623192572, 75.03868333755001, 76.15333464837845, 80.48919323951968, 82.23520494276478, 82.33520969267815, 77.22309835495489, 78.85223911654565, 80.70276629540228, 79.01384861238542, 75.8048555927892, 78.43555004365983, 79.2808835737167, 72.82064576302805, 70.76254675465246, 72.51906256521903, 72.76252408181468, 80.14385992480864, 76.57599356866653, 77.25446162685272, 79.11862296442833, 84.16567002573322, 81.70678323315036, 80.37729586324384, 82.76483474239227, 83.58948953690069, 76.15707658952283, 70.1253028069773, 71.10517363394462, 63.681829206405155, 64.99038680907219, 66.61103171686973, 76.42080891516902, 97.27848299088018, 83.55160728577646, 63.54816659804314, 49.26388286775159, 22.769890331452896, 26.411293283585582, 0.42148830729626846, 1.0025638221733033, 2.7498992027774936, 0.5211479192779911, 0.15331490866599545, 0.07140609781227766, 0.06445317574205899, 0.0668314190941953, 0.12447323049268416, 1.2105361011720475, 7.237780036464815, 68.1500913250831, 82.06146747835221, 88.34196659826463, 59.76298524487404, 54.116074423636164, 47.11509473862187, 42.87201196916642, 28.622864830878477, 42.21090039899273, 40.240948815499586, 56.03585104788504, 58.10863933255596, 70.70368766784668, 10.48276178298458, 0.3224844972212469, 0.2910733907934158, 0.029691011126663898, 0.1328238493372356, 0.08353066495469502, 0.15255450511411314, 0.05036704813040072, 0.06896537998991628, 0.022252159486074122, 0.09788946624124244, 0.03852091947450273, 0.06459051232424474, 0.13765864554912816, 0.09418166197475888, 0.056487121544177496, 0.025344632355676546, 0.07829993152089658, 0.033421761641699466, 0.06221089001384474, 0.005808473853845029, 0.07385284474660313, 0.017466011772593184, 0.045049773574235945, 0.03413146166431327, 0.033921063276788885, 0.07316675938425526, 0.010506056057619713, 0.02487287924234425, 0.06546270342603808, 0.05983638900121855, 0.5294081244257189, 32.5402771272967, 77.14902831662086, 69.95799018490699, 78.45309088307043, 63.281033577457556, 47.32781664017708, 39.28168219904746, 65.0577574391519, 93.6614614917386, 110.209760819712, 44.01280195482316, 1.092922850962608, 0.061055893724363666, 0.20105622107944182, 0.09858044690542644, 0.2114803334998508, 0.10608189559030919, 0.16584646767906605, 0.21997637115418914, 0.017848950397643833, 4.333163922832859, 1.0106099517114702, 0.17909009009599688, 1.0271544478112653, 43.02797717432822, 74.8733554347869, 55.993873842300914, 66.6161072638727, 60.1762540109696, 71.00150539029029, 67.93475320262294, 77.92346892818328, 79.79599275896626, 85.83318725708993, 84.74455694998466, 91.07640774019303, 92.18496368777369, 97.27966754667221, 95.78431883165914, 98.32237474380001, 91.31564094174294, 94.27888178056287, 90.98991163315313, 92.92167109827842, 84.00550396211686, 88.15683857087167, 89.81566382992654, 92.87825830521123, 94.50149982206284, 91.50621321893509, 86.18744788631317, 88.8197426642141, 86.22632641946116, 86.03097669539913, 88.58982901419364, 87.89963306919222, 85.64278756418537, 84.38143176417198, 85.52985468218404, 84.98009527883222, 82.42353362421836, 82.61034827078544, 77.54337556900518, 76.98496341705322, 73.88833845815351, 75.05708709839853, 70.75397245345577, 74.35677928309288, 73.20397115522816, 72.64172292524769, 68.5338560227425, 73.08702961091073, 71.81040010144635, 67.09644071517452, 67.36584478808989, 70.46176372035858, 73.99567019554877, 78.77187759645524, 77.19031518505466, 80.78372401575889, 78.20988824290615, 77.10253254059823, 78.42335931716427, 80.5457067489624, 80.89889264875843, 84.49400378811745, 84.9731840625886, 82.4986077893165, 81.82543493086293, 82.3789127411381, 81.22775200874575, 80.16558985556327, 79.71989093288299, 82.53215974377048, 76.17025575330182, 77.65244883875694, 76.36497005339592, 75.26036785494897, 81.32284595120339, 81.82660379717427, 77.54172032879245, 78.35155640878986, 79.62864875793457, 83.59206261173372, 83.71497400345342, 83.15435747946464, 84.21076159323417, 81.62489198869275, 72.9130175805861, 77.50214361375379, 75.56850141094577, 73.17089772993519, 69.54923998924994, 71.55460665302893, 82.86727136181247, 91.90835029848161, 73.36491384813863, 70.51469218346381, 48.27100153892271, 35.44567477318549, 1.5395269831342082, 0.794641737255358, 0.47349657623037217, 0.15275053169217803, 0.3470393618749034, 0.10125988538587287, 0.05482607821543371, 0.03745030393944152, 0.12690260255288693, 2.7154870235150863, 6.338969401774868, 75.55902496460946, 92.25673521718672, 93.84460479982438, 69.010039606402, 52.83347114439934, 17.24722646897839, 37.2190293189018, 41.929325211432676, 53.56301238459926, 51.33611417585804, 79.50209740669497, 61.88444622101323, 87.01080829866471, 16.010432550984046, 0.2954632278171278, 0.16174058880536787, 0.03362174506389326, 0.03257280598664957, 0.019989126181650548, 0.062337474552013224, 0.03402583346131348, 0.08128048852086067, 0.020264906343072653, 0.04278879147022963, 0.07078913656333763, 0.13043362436996353, 0.03632705816398225, 0.04658235161895714, 0.17640862914343036, 0.23236765946832397, 0.1644729179961066, 0.25762010846407185, 0.22556141259208803, 0.1650035871012557, 0.19248535195665975, 0.1402657346860055, 0.15071753352399797, 0.22033231092556832, 0.19023700647296446, 0.23881994308002535, 0.10934064209821726, 0.14778753832703637, 0.27271084547523533, 0.2119446134254817, 0.6446845000309329, 48.58561485044418, 98.40409340397005, 83.70675271557224, 92.62503008688651, 79.59867400507774, 49.33696054643201, 51.227684174814534, 88.86022152439241, 107.46893405914308, 122.67277040789206, 55.569277271147705, 1.571356894508485, 0.34066354915980374, 0.4510914768663145, 0.409541625769869, 0.39952701798850493, 0.3495081261761727, 0.6534954304656675, 0.667593838466752, 0.1414298972175006, 6.998637049428879, 1.391950869752515, 1.0431873197517088, 1.3262712715133544, 48.489387343006754, 88.54066602645382, 66.9932980691233, 84.59585205201181, 73.90961339396816, 84.59039211273193, 81.14394664764404, 91.22402221925798, 86.39271336217081, 93.05172904845207, 88.22214603424074, 93.14644644337316, 97.36973301056894, 102.69375431922175, 100.05382660896548, 102.60532840605705, 94.813124287513, 98.20678249482187, 93.21286001513081, 94.97802857429751, 86.39530212648454, 91.37830472761586, 93.59624032051333, 95.39157975104548, 97.16561286680161, 95.81094388038882, 91.87158984522667, 91.55699222318589, 88.83597343198716, 91.24391648077196, 91.9440830907514, 92.9067425574026, 90.64961464174333, 85.43794570430633, 88.58591448876166, 84.46320533752441, 83.1387778251402, 86.19431987885507, 79.25125398943501, 77.90191158171623, 75.58878006473665, 79.28955201179751, 74.73564886277723, 75.13554234658518, 79.05914414313533, 78.89940169549759, 66.73839107636483, 76.99677759601225, 71.08459688002064, 68.56895339104437, 68.77875312682121, 70.90923555435674, 75.5807548953641, 84.2400852326424, 83.10761067175096, 83.92106317704724, 83.29113052737328, 82.5202984963694, 81.064071501455, 83.01567815965223, 81.65161117430657, 87.92445382764264, 86.7140260819466, 85.38611550484934, 84.879729670863, 87.34646904853084, 84.48554715802594, 82.36318403674711, 80.21773384463403, 83.6725418029293, 76.07651110618346, 77.8958240632088, 78.7620089131017, 79.86051574830087, 84.86647990442093, 82.64593201298868, 78.43652279146256, 82.03974539233793, 85.05725614486202, 87.54054007991668, 87.28608023735785, 90.33580933847736, 88.92214790467294, 87.07195020491078, 73.74758812689012, 78.0017045236403, 71.34584242297758, 76.21044435808736, 75.82042740237328, 75.14567775111045, 81.08019244286322, 86.50319084044426, 76.69801065998693, 74.31651223090388, 60.71691351552164, 52.760079676105136, 0.8881495099875235, 2.1431494768588775, 6.894863882372457, 0.5625859215374917, 0.5960353427836972, 0.3111796748013266, 0.09459778561346954, 0.10548827704042198, 0.29169965234975664, 5.814267079676352, 23.50088873217183, 92.75760619871079, 94.75230401562106, 98.89218530347271, 73.54145188485423, 74.53025002633372, 66.515867171749, 63.5388784254751, 43.88506997016169, 61.508777295389486, 54.76375972071002, 79.4221830368042, 73.8363435191493, 103.54951350919663, 19.98606066549978, 0.5460129882539473, 0.5453035295490296, 0.13811212363502673, 0.3091234948125578, 0.1492378653417672, 0.21228855625996668, 0.1316563926276661, 0.17883721979395037, 0.12649990077460968, 0.13668004483465226, 0.22033865413358136, 0.2168458294604094, 0.21735216761308335, 0.24665703786717308], [0.18644787431243928, 0.08599299411740034, 0.1079124856680151, 0.05019419954248494, 0.06701062238144298, 0.05716757999072152, 0.0892267891416146, 0.12236400657603819, 0.10479463039026146, 0.043878026772290475, 0.05860601732086751, 0.06582127087899754, 0.03630443175713863, 0.04783456063558979, 0.03310313418267235, 0.04073247741607409, 1.0655308562901713, 29.972881886266894, 60.75441137436898, 55.39320207411244, 63.60768072066769, 46.45802320972566, 48.17853950685071, 42.542011199458955, 70.22264818991385, 98.76630859990274, 64.46535794965683, 3.2005305059494513, 0.06773414646065043, 0.1336285327711413, 0.15310654807234966, 0.045094984253087354, 0.06546230506031744, 0.02324124219857397, 0.09566565855376183, 0.09644077099379032, 0.20166703830322913, 4.0917582185037675, 2.4020011482700228, 0.5289830988453281, 9.922658108895826, 67.06920377669796, 52.69164608370874, 49.55238103866578, 46.19362800352035, 54.44313341571439, 52.24198164478425, 65.46113791004305, 72.72762283202141, 78.82694767367455, 76.5432810014294, 83.34536121737573, 92.94419334780787, 89.97841081311627, 89.8270308586859, 92.28179131784748, 90.56771555254537, 90.53017062525596, 89.40042603400447, 89.14722919464113, 81.26259050061627, 83.4376859664917, 87.65203737443494, 88.34049178707986, 88.05354687475389, 87.91938612538, 82.27209091186523, 88.77329395663354, 87.58442355740456, 83.35479059526998, 82.37480994193785, 81.99305349780668, 80.2905487245129, 84.44485648985832, 80.21545886993408, 80.49390008372646, 77.98960008928853, 80.81855466288906, 76.24139185874694, 71.66883391718711, 71.38354424507388, 70.08244699047458, 72.30115136792584, 70.23487029537078, 69.7215183319584, 66.54876016801404, 69.20259660290134, 76.88093431534307, 76.72891109220444, 76.46464532421481, 69.52516448113226, 66.1632147142964, 72.54536597959458, 72.1520777671568, 75.94253078583749, 75.46889674278998, 76.61593898650139, 72.59348561686855, 71.31662076519382, 77.29978853656401, 80.54635001767068, 82.62146426785378, 84.28266648323306, 84.90416603703653, 84.22134414795907, 81.54521296101233, 80.34827816870906, 77.50328110110375, 77.18679289663993, 76.9881405368928, 78.53925751101586, 78.98374049894272, 77.78473469518846, 70.49040486735683, 69.62404743317636, 70.16370281096428, 74.84124691255631, 78.70435007156865, 76.97963683835923, 72.70532807996197, 81.22765787186162, 81.57667821453464, 81.00653817576747, 75.81028415310767, 78.39609884446668, 71.51354728206512, 63.277970206352975, 69.52492129418158, 71.07511258894398, 65.36243146465671, 71.54118430229926, 73.24945495974633, 87.89924867691533, 77.13307995950022, 61.03673181226177, 40.09993176306448, 27.750821921133227, 13.616160923434844, 0.11853152149987799, 0.2140052980112453, 0.14659797231997215, 0.3413999128726221, 0.13847655166060696, 0.09697929250016328, 0.04450944410036168, 0.0935734264672764, 0.41880007412645126, 0.9667563210091284, 9.310366319071862, 70.2534152615455, 78.73572118820684, 83.8700488305861, 46.4552971624559, 66.47898120264854, 48.58403413526474, 37.00654275955693, 59.33958107425321, 39.53184704626761, 31.593162013638405, 50.13835176344841, 62.45483336910125, 46.59118767707579, 0.7679095587903454, 0.0664471647131347, 0.023076992947608236, 0.12937156603701655, 0.07030727491984445, 0.08469352513671884, 0.04090432625924868, 0.11070381895068193, 0.032506742394499244, 0.11873910834472026, 0.07252381243292363, 0.08210928840262276, 0.082401022345068, 0.07850829977542162, 0.06269069471126122, 0.014752629851441712, 0.07775683646961566, 0.11055024896538067, 0.07886358837206518, 0.055634331619066585, 0.052218923961082776, 0.08268478131222148, 0.02618971352104939, 0.021129746831232504, 0.04252936345555129, 0.035271086399593664, 0.04608149482538143, 0.08374807304672657, 0.07909898420855885, 0.14078420767140004, 1.3609689257798658, 40.48543407071022, 79.79347459731564, 74.0141994722428, 87.46062571002592, 68.88598288259199, 28.6651401365957, 29.06416285422541, 84.15254577513664, 105.27005334054272, 76.27463786832749, 3.033840560143994, 0.028080627277132966, 0.08184175517770552, 0.10711422205091485, 0.04837724199939159, 0.1797527561504995, 0.16619204994170897, 0.29515930541580726, 0.2876937173066601, 0.07837644838277372, 5.878895973005603, 2.424760946343022, 0.6494145107365424, 17.39534301142539, 81.09597606043663, 67.59793143118581, 63.948911236178496, 60.9637325809848, 67.3800673023347, 60.877463971414876, 77.51454614823865, 79.26441746373331, 84.95740044501521, 86.4132587371334, 92.11068184145036, 97.77939319610597, 94.55237296319778, 94.0296700692946, 95.52569343197732, 93.01791821756672, 92.59386293349728, 94.4887678084835, 94.07628351642241, 86.07052203147643, 89.14869616108557, 92.48015342220184, 90.96177254953693, 90.13186962373796, 89.8758408331102, 88.00953003668016, 88.81451806714459, 88.9336718282392, 87.14635756707962, 87.19177861367503, 85.94830097690706, 84.79928970336914, 89.47700638924876, 84.18566626887169, 83.78967946575534, 83.46133001389043, 83.05136388347995, 78.38673222449519, 74.71458573495188, 73.0675668101157, 72.02289842790174, 72.834028890056, 70.45940245351484, 70.702055961855, 73.4614198438583, 75.01540014820715, 76.78761328420332, 76.60357567571825, 73.00302813130041, 68.49005883739841, 68.33004966858896, 76.16319548699164, 74.60168423191195, 74.91617987232824, 77.01433412490353, 80.02942085266113, 76.72079963068809, 74.85376711814635, 78.94133967737999, 81.36157543428483, 80.42001831916072, 83.0612325668335, 85.42158942068778, 84.35655609253915, 81.02855051717451, 81.11385422368204, 80.91928112891414, 80.42514093460576, 80.03460622602894, 79.52362337420064, 81.11075555124592, 83.49914166235155, 78.70344008168867, 75.35695229807209, 73.65537320413898, 78.45713092434791, 82.7050107525241, 78.00849806877875, 75.96368020580661, 79.1467228243428, 80.43132258999734, 84.0834100784794, 82.15718115529707, 79.31263908263176, 79.72930462129655, 70.86972159724083, 70.70689616664764, 77.38833212083387, 70.02416841445431, 74.5547648399107, 73.30694906173214, 81.08345585484659, 84.75462959658715, 75.90922986307453, 63.74527746631254, 43.98401568012853, 21.61981805678337, 0.15561318776059538, 0.1678536180406809, 0.184762189765611, 0.03909108041214847, 0.0720782173917659, 0.1076537088280724, 0.0752881104727426, 0.13834493775521556, 1.9216448981915752, 0.9382690657531062, 10.35163204516134, 78.8870148504934, 88.4214573521768, 93.823745635248, 53.47203300845239, 50.49441668295091, 25.100900011677897, 38.39255932838687, 67.26284334736486, 55.152313632349816, 44.867384433746345, 68.97116107325401, 71.7803547459264, 62.291431350092736, 1.4441353082656863, 0.014134838354713736, 0.0768451918397219, 0.11090717699018218, 0.07462151438718842, 0.1282237365000671, 0.036618792106427496, 0.09629182051867248, 0.04590419143618596, 0.09845696885379092, 0.13667993758234287, 0.024004654560778892, 0.032803249064712756, 0.04347706401360132, 0.2369795240942509, 0.17627350655534577, 0.18205481971944534, 0.20545802439653105, 0.3643799765456108, 0.18068448760576789, 0.27475645345064903, 0.3221141703186497, 0.11181057851401069, 0.14946586842979157, 0.28328028477488026, 0.08839317822768804, 0.10698446973917947, 0.23450723578852994, 0.1916911486055582, 0.27334317444793643, 2.211095714761365, 58.19236624625422, 97.18758598450692, 88.61952135639807, 98.50798914509436, 75.46481747781077, 75.86970021647792, 63.50457729831819, 92.2186097791118, 118.8173080259754, 89.05921120797434, 5.8200780710866376, 0.19105607703808816, 0.1735012795055105, 0.3104977646181661, 0.16166090033948421, 0.2590192608054607, 0.3059032595446033, 0.4227119029289292, 0.7620514989379914, 0.45029535829540224, 9.311839169071568, 4.075164141193513, 1.0698194777773273, 18.19904842684346, 93.11598531661495, 78.21014711933752, 75.87646238265499, 71.32441059235605, 78.8128585200156, 73.84953837240897, 88.85310634489983, 87.08538040038079, 92.36230188800444, 93.20662344655683, 95.76282424311485, 101.06382123885616, 98.01959130071826, 98.4310636212749, 97.65760360225555, 95.89480415467294, 96.74555840030794, 96.90029590360581, 98.53101345800586, 90.3030026343561, 89.58635422491258, 93.21547231366559, 93.02930878054713, 90.75616190510412, 95.14576481234644, 90.17180719683248, 93.24205813869354, 93.92735112097957, 92.0323834880706, 92.109967970079, 91.6740200596471, 88.2992127633864, 94.19668459123181, 86.99536200492614, 85.88363678224626, 84.5615940709268, 84.84005097419985, 79.91321671393611, 77.01613057044246, 74.71883758421868, 74.74268559486636, 76.03420442150485, 77.68056438815209, 76.1899382068265, 74.14614016009916, 75.20654509144445, 78.88794837459442, 79.07200167256018, 76.23914041826802, 73.8715664032967, 71.75170575418781, 79.43635848260696, 77.73925089067029, 79.71948300638508, 80.8104588908534, 85.43525495836812, 78.92597183104485, 79.1644754717427, 85.46577099830874, 87.94062183749291, 85.16535666681106, 87.16982903019075, 90.14161279124599, 89.03478268654116, 83.23253816173923, 83.73700203434115, 84.44350719451904, 86.19871293344806, 82.46332214724633, 81.33909240845712, 83.43091595557429, 86.22036441679924, 77.9528082570722, 78.21606205355737, 77.5898870345085, 81.5753524534164, 83.7850824479134, 79.76641808786701, 78.61732836692565, 86.26176895633822, 86.15522953771776, 87.83846762872513, 83.05588245391846, 83.0377140352803, 80.5284090965025, 71.53792089031589, 72.00307476905085, 74.44777827109061, 70.314863112665, 79.87317715921711, 69.81018743207379, 79.7689833179597, 80.00921280153337, 76.67831251698156, 72.198973624937, 61.29014045961442, 24.67808419658292, 0.3037758027353595, 0.549237237822625, 0.581334115516755, 0.47795992705129814, 0.2825032571150411, 0.31909982884122484, 0.1352118832930442, 0.261411385670785, 3.940649397911564, 3.508999179447851, 28.599709118566206, 92.73560954678445, 92.87810141040434, 100.80820821946668, 62.54625597307759, 101.89234349035449, 72.06012956557736, 57.80396530705114, 70.32017400187831, 53.18351522568734, 46.131509427101385, 72.0822831123106, 81.81820208026518, 76.624693716726, 2.1119031406218007, 0.17151541106643217, 0.11127374240107114, 0.3184192056857771, 0.18086505452952079, 0.31778604933811777, 0.24830653242045836, 0.18286368599341762, 0.17730746478323015, 0.19065668475964379, 0.2483346172037625, 0.20300688011752022, 0.15994028218330877, 0.17441572801720712], [0.18064310353609825, 0.08479738367661353, 0.08410831823224023, 0.028424995290415905, 0.03702245149461012, 0.06249576363892806, 0.08607902579129705, 0.21645383759131356, 0.06745678432766469, 0.058007829056511966, 0.06916088562819266, 0.005008591876004733, 0.04644605308590878, 0.04879413938690578, 0.0775235703575515, 0.023725101416329705, 8.932316514753527, 42.898644862636445, 64.56866925762546, 57.34242785361506, 48.80482435226441, 50.785029011387984, 56.695734916194795, 61.07411200000394, 92.69678592681886, 86.6940612177695, 12.102083871441504, 0.5713889459448477, 0.12446431322924553, 0.07618771986134591, 0.07274694320174956, 0.1688357121160915, 0.13013622903775784, 0.15340853993210102, 0.21712859251326133, 0.315488183930997, 0.08358103523571646, 2.6546606229197596, 0.044984353495942014, 3.233997884296602, 55.71400880813599, 49.661799476992705, 50.10662371112455, 58.24620469923943, 50.69176289343065, 56.669435424189416, 67.5249518117597, 72.95422600161645, 79.2962121963501, 83.33423737556704, 91.97078658688454, 85.01706754007648, 86.89365494635798, 89.03849324872418, 91.02409901157503, 92.90208278163787, 88.6478251795615, 88.63500687383836, 90.6899993650375, 85.4510150417205, 87.99692353894635, 87.19459487545876, 85.82742137293663, 84.71805741710048, 87.30173833908574, 83.14425345390075, 85.98426911138719, 84.5944086197884, 85.39276784466159, 83.64933706098988, 84.3615924158404, 84.80199613878804, 87.33494512496456, 85.08788201116747, 83.06697491676577, 79.3148434546686, 82.00659351964151, 76.3327830837619, 77.91112915162118, 78.4617514764109, 76.19449600096672, 74.00949262803601, 72.76654058887114, 71.55165703065934, 69.13063679972004, 79.44774120084702, 81.77245939931562, 72.33260877670781, 72.99846249241983, 72.19731053998395, 70.22964569830125, 70.05881863255655, 70.85529511974704, 71.01457472770446, 75.35135115346601, 77.16811456987935, 80.0170026286956, 75.93740817039244, 72.44076421183925, 71.94230156560099, 74.37543407563241, 77.58084204889114, 78.859189556491, 85.29254344201858, 81.00098409960347, 79.52487853265579, 79.20104765122937, 78.51256970436343, 77.4104856675671, 76.78973136409637, 76.07329476264216, 75.01336836045789, 76.26365523184501, 75.4983772770051, 74.75309556530368, 71.40113215292655, 67.18258380889893, 71.60085139736053, 78.42258268787016, 80.1213219857985, 77.45840134159212, 79.22861406880041, 82.5326539624122, 83.11810693433209, 77.39475696317612, 76.7371480695663, 70.41576216297766, 60.727853005932225, 70.12112940511396, 71.35513059554562, 74.35554765885877, 83.44789197368007, 72.31228305447486, 76.30887231519146, 71.59822340934508, 55.851248618095156, 33.65233575144122, 27.824558558002597, 3.8061645627021794, 0.14039264481154182, 0.3274937010099811, 0.4112746698721763, 0.08531984031921433, 0.030103953585268992, 0.028964930229009162, 0.3704220813608939, 1.2405589030634974, 0.5346359697080428, 1.3102752330803102, 29.891008292475057, 77.59751212212348, 76.4674380517775, 68.20293349604454, 41.173770812249955, 43.735996369392645, 58.85667062574818, 68.8619936666181, 44.08172976586127, 36.52347149387483, 32.62383145670737, 49.752543510929236, 71.42064202216365, 15.939928927729207, 0.19185118437294038, 0.19946383072003243, 0.03185612498782575, 0.05361773922378498, 0.09971172128233219, 0.10341289122739147, 0.023518763294804002, 0.0570664027585618, 0.033029991938101674, 0.16432049714269178, 0.01604655331316134, 0.08323413530184377, 0.10351635140156555, 0.15064299316896548, 0.06473917168595138, 0.06232891734989901, 0.06224585043626928, 0.11735422056048148, 0.0466218970776085, 0.04411489349759875, 0.14207013221758027, 0.012514796051677438, 0.01831789579873364, 0.07199577867023407, 0.023864968003885403, 0.020368925761431456, 0.02023077712604596, 0.04280295643594958, 0.0885501113389769, 10.779020363284696, 53.05648534528671, 80.06112144839379, 75.04504542196952, 52.47162857363301, 51.130695727563676, 42.73392492725004, 66.02944620193975, 103.72231744950818, 97.05151896322928, 13.50683662199205, 0.5818679868694275, 0.16251727938652039, 0.17786028915114943, 0.10960727900026307, 0.1457592439387114, 0.32958138253419633, 0.10534313402228779, 0.37128463507659976, 0.7177281031204809, 0.08357906638975106, 3.3666914220779174, 0.06333430815908699, 5.313741266727448, 68.1196145088442, 65.04835551784885, 67.22487480409684, 73.3261686755765, 63.70516338656026, 70.8091131333382, 78.58907161220428, 76.66718083043253, 85.70502773407968, 90.35477007589033, 97.22166353656401, 92.76882417740362, 91.73804098559965, 92.97044969374134, 95.23268453536495, 95.75907445723011, 92.53560789169805, 92.66085701604044, 92.93568964927428, 91.3229287055231, 92.12287256794592, 88.9172370972172, 89.74493565097933, 88.00532525585544, 90.513531930985, 89.89178919023084, 88.29806743129608, 89.28005633815643, 87.35993062296222, 88.58051730740456, 88.66942959447061, 86.89323133037936, 87.93527172457787, 87.7939095035676, 85.30615406651651, 84.30566726192352, 85.42788090244417, 82.03769007036763, 82.22371239815989, 80.0165476337556, 79.08393352262436, 75.3775368967364, 74.67974724308138, 73.00542077710553, 70.77080726623535, 77.72328684406897, 85.35959243774415, 74.77993242202267, 73.7136439354189, 75.45452517847862, 73.58270737432665, 73.25755073178199, 75.07866013434626, 74.35301380772745, 76.39695305978098, 80.32998423422538, 81.86810247359738, 79.25495670687768, 77.50502263346027, 76.45117590504309, 77.23673251367386, 81.39937923800561, 80.23833413277903, 83.03914962276336, 81.39088338421237, 81.23275695308563, 80.55801514656314, 81.9848322099255, 80.04158804493566, 79.82683827800136, 80.21357613225138, 76.84731960296631, 75.80342000530612, 80.32440662384033, 77.77863933194068, 78.00911780326598, 71.96520036266696, 74.07293304320305, 79.77054442128828, 80.68797895985266, 77.51366753732005, 78.29816510600429, 81.19936189343854, 84.35024892130207, 80.19006544543852, 78.61587708996188, 76.5856739782518, 68.4996529548399, 68.76787247196322, 78.052867920168, 75.46778278966104, 87.23357539023124, 74.83040548140004, 71.77113717602145, 77.77854519505655, 77.54635657033613, 57.01792624688918, 39.62941208193379, 6.501065271516, 0.0556944158949679, 0.05488167704653837, 0.1932041109689782, 0.36437381719869955, 0.027525677015223814, 0.18926310953834366, 0.19410588838640722, 1.3209214037464512, 1.3912013293273988, 0.6818573537372774, 31.569918047997263, 86.76934719085695, 87.22670339768933, 75.52502585995582, 49.04819957671627, 33.19950988215785, 38.68199102340206, 76.3631030051939, 42.895824678482555, 29.308740285135087, 52.07750489634853, 61.16099642169092, 86.0748758623677, 21.8956155930796, 0.3551956548565819, 0.23109575433115806, 0.09377451688652078, 0.08375309858350985, 0.05919226610492315, 0.12317100359547524, 0.05975545564245793, 0.057525611182134, 0.014860072725212142, 0.019254813669249415, 0.08138315196359351, 0.1049716043616495, 0.037051283213640415, 0.3676839605454476, 0.26711481833650225, 0.4391484112749177, 0.26798371526022113, 0.27161402207228447, 0.245267691451215, 0.12267752805904997, 0.31488940960937933, 0.20028702283818878, 0.1693365497574691, 0.17420667794442948, 0.12914926264314883, 0.09853765323397615, 0.14333770129709475, 0.1947271703712402, 0.3497151231333133, 14.861716435801599, 71.40649011058193, 93.66163407602619, 88.74993231988724, 74.65930384974327, 80.3164363676502, 87.81254076188611, 89.25703202524494, 113.19895205959197, 119.89595197862195, 21.820876790631203, 1.003709644559891, 0.5282076952918884, 0.37259820007508804, 0.3862341974050768, 0.36355440955488916, 0.8035978566735023, 0.21657213688858096, 0.7842953214722296, 1.4174191870035664, 0.30649133927879796, 6.414185262495472, 0.1693231278970357, 5.0521613417133215, 76.36591926697763, 72.48084299025997, 78.73849038154849, 86.61137765453708, 74.36059967164071, 84.1058538806054, 85.81126905256703, 87.60685167004986, 91.86935409422844, 93.6735894603114, 99.30705439659857, 99.56991595606651, 97.51613155488046, 96.77813760695919, 98.71852628646359, 99.7935224348499, 98.49929717279251, 94.91779665793143, 96.65744627675703, 94.36344023673766, 96.51154195108722, 94.44293883539017, 91.61153670280211, 89.77036045443627, 93.540464216663, 91.2559267782396, 91.22761511033582, 92.53713761606525, 94.01503962855186, 95.44005240163496, 95.25656392497402, 90.9016033910936, 92.96932005113172, 93.00282493714364, 90.024043667701, 85.42476654052736, 89.91049105121245, 83.33098965306436, 84.36565599133893, 84.4131088256836, 82.99647423528856, 77.97765254974365, 74.92551511333835, 76.59074952525478, 75.37258686557894, 82.22995681147422, 89.36957267022903, 78.41566362688619, 77.79251667761034, 79.14246313033566, 75.7264317235639, 77.07156935045796, 78.5776653597432, 76.94540239149525, 78.89172169470018, 82.987743039285, 84.83426155582552, 82.90820521693077, 78.72244788754371, 80.18717858099168, 80.11917252694407, 86.48019790649415, 83.04799064513176, 86.77915311628773, 86.45849150996055, 85.57659364515736, 85.51731094237297, 84.06418261989471, 81.91047976093908, 83.81408445296749, 83.83901503778274, 77.97137675746795, 80.34319477696573, 83.15031743818714, 80.22786140441895, 80.28787366805538, 74.50808863486014, 77.11767288946336, 84.19146353198637, 82.74041406569943, 79.81067026815107, 82.5153249309909, 84.49813796627907, 89.74388445577314, 83.23719793750395, 85.45552576741865, 80.57612080727854, 70.41160445059501, 70.0739589814217, 75.27340581340175, 75.04738315459221, 84.86284778964135, 75.51509441867952, 73.27837067265665, 76.01671849527668, 79.12031742834276, 69.0895538945352, 57.25115822207544, 5.612293452985826, 0.18174170426303343, 0.7119895529843147, 0.7171479600571817, 0.3629750325795143, 0.17194579926229295, 0.2498962108286158, 0.6603134291306619, 4.577610934934309, 1.8946722294053726, 2.8559696530142142, 54.600087058159616, 90.31772721198298, 91.31265994041198, 84.56970553244315, 53.986581294767326, 64.00000795241326, 82.7672116987167, 84.3946893753544, 57.60772912733017, 50.66695782446092, 50.495209001725726, 66.14937659232848, 99.57685070653116, 25.272744932482322, 0.40423652818126066, 0.3597391691179045, 0.16644937887547478, 0.2744021837509448, 0.24208582186650848, 0.22801154563503884, 0.16015993491295846, 0.1893065007583749, 0.1076053150538956, 0.2363324096246112, 0.1603156652662062, 0.2993376102418669, 0.22782969168357312], [0.11925329123773884, 0.13527814989849446, 0.06267497075661536, 0.08772556324519458, 0.028044450690128633, 0.16126818834773957, 0.11452845928649749, 0.057234559057941364, 0.02264610104893725, 0.11980701958940876, 0.03219904701015161, 0.03115695675895099, 0.11660947584577146, 0.0585037139394591, 0.027888429223469673, 0.09304667973229963, 18.45190990355707, 56.02204822724866, 58.71699110154183, 57.09457328242641, 95.84538229050176, 116.66491523865731, 47.9932035938386, 60.86321007820868, 91.436261669282, 26.30468522348712, 0.46852475753234285, 0.03621310258524553, 0.1083352895934255, 0.04280132849911048, 0.142079463168498, 0.136819809915558, 0.062028970944905476, 0.11178056318913737, 0.22616804697580878, 0.2271577866087037, 0.2510603580383524, 0.14630063827480042, 0.6518536734004176, 29.043797908290742, 81.73347888454315, 87.5300516620759, 66.42799039040843, 53.248610881067094, 63.53058261256065, 68.2597529503607, 73.80859667255034, 73.61903636686264, 85.22887552938154, 87.4367541651572, 90.07960011882167, 87.0065172256962, 81.82006128372686, 88.93034565833308, 89.22383308410646, 85.46386472640499, 90.3382255185035, 88.97389181198614, 89.2525448337678, 87.65937220665717, 90.29193370572983, 82.27269495687177, 88.67711744000836, 84.01199940712222, 83.78217989398588, 88.61978023282944, 81.10964159811698, 83.02859060225948, 87.42965467514531, 86.74235343933107, 86.36169525884813, 83.90042366520052, 84.82240815316477, 83.4738031510384, 80.89482907325991, 81.1663120023666, 79.43839811509656, 79.81872681648501, 75.16485029651274, 75.34507536119031, 76.88202473425096, 75.40060043334961, 75.09602054472893, 75.11742099638909, 70.61879188783708, 68.33242662491338, 69.27980453737321, 69.08077563008955, 69.42433603348272, 80.40093206590223, 75.98684572404431, 74.53250931155297, 72.42135632422664, 70.62719360474618, 75.65811972464286, 78.69385380898753, 81.71655777961978, 81.69256071890555, 80.51719896255001, 79.71579597842309, 77.88882655482139, 79.896483882781, 80.0732651064473, 80.89089885834726, 79.47879068313107, 78.88343764889625, 78.78791224571967, 78.31512543462938, 78.47297729984408, 79.61458313849666, 74.35722643329252, 74.51051265962663, 75.98726149528258, 74.67662503642421, 75.96110713097357, 73.59588653810563, 71.41136169433594, 72.45300985151722, 70.04302717024281, 74.63540877065351, 81.20389615335773, 78.87736581986951, 78.92785456872757, 80.12750364119007, 81.48917798073062, 73.88866009250765, 72.54596217986077, 70.54236058265933, 56.12941134360529, 69.87468688718735, 66.63065141247165, 79.5387480335851, 74.38859754993071, 63.37450365866385, 68.01384387477752, 68.29641926673152, 44.62170677800333, 31.782955700351348, 16.6448563145053, 0.09805802090634262, 0.35492973041630566, 0.2518665889698652, 0.46829143779412397, 0.4477000669125588, 0.24292605178010082, 0.3009551282851927, 0.15816730957838798, 0.08001429073873066, 0.4817232573705335, 2.708556195420604, 45.50952742176671, 75.93736110195037, 84.19892388005411, 53.077426879636704, 40.88236616503808, 45.17377253501646, 38.15107076398788, 73.98645262564384, 102.23210703942084, 61.32127231167209, 48.41313254448676, 76.92801844689154, 37.27458969239266, 0.019157181508959304, 0.09106997370479569, 0.09111067595621271, 0.009131009630378216, 0.07431899392676931, 0.08626233530981887, 0.10776787125054868, 0.035457923753006805, 0.013641583068566698, 0.15464833066348108, 0.07595119021472431, 0.08674133944535449, 0.06698260654605205, 0.034433809754949425, 0.05253882695650382, 0.05333870318868468, 0.04568229406891812, 0.043910294395661166, 0.09737016588088968, 0.04588803464186288, 0.05660890271106074, 0.01865978360236172, 0.03676725994615305, 0.08384672218873616, 0.0612250650902429, 0.022760349656305006, 0.09981200985249974, 0.08917096431457228, 0.037465035810225436, 26.147194216328284, 71.15917682647705, 77.07653507109612, 69.64370635248, 107.31686376756238, 110.77531168537756, 43.45164806612077, 75.09116465045561, 99.27819359687068, 33.84528498495779, 0.375246137020088, 0.17052093701016519, 0.1820975674256202, 0.04841862989950085, 0.16057903097281534, 0.13850293572871916, 0.08102258502115166, 0.015006162819542713, 0.053967715000673655, 0.2744883226771509, 0.4740445129573346, 0.14792543415340687, 1.4706363120386678, 39.52339041617609, 91.17875806746945, 94.90591972104966, 81.12580176322692, 69.58244677512877, 74.31093462051885, 77.49276130430161, 78.22924121733635, 79.82386512141075, 92.1668109586162, 90.3198060681743, 93.6023670627225, 93.13767602366786, 90.13498398565477, 94.44246815096949, 94.23297436006608, 85.85958480834962, 95.69786194832095, 90.50086267532842, 91.95540305106871, 90.49213932406519, 94.82096902785763, 88.8359655872468, 91.11858890902613, 89.61937273702314, 89.09383789185556, 87.0798969268799, 86.1366061241396, 85.70797735644926, 89.62273813063099, 90.54781344629104, 87.49544851241573, 84.65071032124182, 87.8262298337875, 86.74815070244574, 83.6501999824278, 84.28730272477674, 82.72063747529062, 82.4336454945226, 79.91739011579945, 78.53986940076275, 78.97543291891776, 76.47811474338656, 78.08830261230469, 76.29913699242377, 71.11820374765705, 70.89693500149635, 71.43626874493015, 69.16698148173671, 71.44292892948275, 79.66394224474507, 77.20590268411945, 77.35117943056169, 75.78920533580165, 73.52282062653573, 77.76565628667032, 80.51145661261775, 80.59496387358635, 80.54609898597964, 83.53121880562075, 81.82492502274053, 79.77831855896981, 80.20283668271958, 83.96040454987558, 82.69853099699944, 82.07063013507475, 79.89710361726823, 79.31779307703819, 79.84397903565439, 79.55162125249063, 78.90347311573645, 78.56104235495292, 79.76298209159606, 78.57779872032904, 75.6326243185228, 79.57983093876993, 78.29579599442022, 78.08343887329102, 76.76872314945345, 73.3727664332236, 74.72738050645398, 81.2727729735836, 79.49381336089104, 81.6011381149292, 78.12035622135286, 79.4124084903348, 79.96952626012987, 77.02333204207882, 76.51639707626836, 67.32291836892405, 69.34783412564185, 69.05618236910912, 74.30121498723184, 79.34387683868408, 73.28987106200188, 67.25368853538268, 76.67821838009742, 66.87566618765554, 50.551981387599824, 27.15884800880186, 0.28270602526683963, 0.2584542862830624, 0.024444362216238535, 0.28147700573167495, 0.7122435877400061, 0.23107038149910591, 0.8527336942572749, 0.30945220781910804, 0.5522021819506923, 0.7452287597040976, 2.3968513213819076, 53.67608647192679, 83.0441467223629, 94.63280508595129, 58.71292752604331, 42.11857172750658, 26.78324772465614, 25.473897803214292, 75.80437706362817, 107.16541321046891, 62.90751018831807, 57.30043495855024, 83.26352488610053, 47.23627636509557, 0.08507940362417891, 0.12856257718897637, 0.050006128787513704, 0.08053977342863237, 0.07761473482054088, 0.03166754286916506, 0.04337096849696771, 0.0663938679762425, 0.039070748438638066, 0.027757680997432723, 0.055765041540707314, 0.060868148556760246, 0.02394741821673609, 0.2240577658578273, 0.2110271771708804, 0.19657261489379793, 0.17885877750813964, 0.1925816645305003, 0.20166466343066386, 0.2656700071548262, 0.21725570182165793, 0.18271368597784352, 0.17274971660827437, 0.16928361308190132, 0.15518062387502965, 0.3401624357267734, 0.21725047710201434, 0.2183276886541036, 0.18838408493226577, 35.9613880034416, 89.8686707404352, 87.40565761443108, 87.13813627919843, 118.20799919866748, 152.75438431770573, 74.61954670567667, 84.20440735355501, 113.12974576027163, 50.854435351587114, 0.8857269561098469, 0.26582389889705565, 0.34614647107739605, 0.20935054778331713, 0.6112827600971346, 0.4229698906983099, 0.42892662267531123, 0.45961791288948833, 0.5940361597364949, 1.2746539832122865, 0.7331145194268996, 0.5568473101142914, 1.4868200113696437, 41.381448545763575, 99.6492027467297, 100.05294015330654, 87.0776141074396, 75.17542500649729, 82.43183335950299, 84.86458932199787, 87.16648717080393, 88.5356689268543, 99.33281652389034, 99.16842998996859, 103.16912204988542, 95.88002466386365, 95.3990871675553, 97.24370725693242, 96.99854343168198, 91.7969471408475, 97.18338904842254, 95.50565796513712, 96.18859752531975, 95.81556443245181, 99.31085909566572, 89.68539407176357, 94.32343990572038, 89.77192940250521, 90.61808663029825, 92.05362704492386, 89.08082346762382, 89.57707389708489, 92.67314187942013, 96.15764217991983, 92.68893334173387, 92.48910427093507, 94.30276901491227, 90.2439631185224, 88.65651715186335, 88.94537618083339, 86.42878347827543, 86.95664821132537, 82.83637092959496, 81.62258563503143, 83.18336732925908, 79.83337294670844, 80.64469952737132, 81.22537505242133, 74.59440431287213, 75.47035586449408, 75.39533661257836, 72.8479846831291, 74.27789257418725, 85.3992005317442, 81.39076571310721, 81.69471802250033, 79.31700075826338, 76.74005062349381, 79.50991861281857, 86.05091802535519, 86.95921344141807, 85.32444015625985, 87.2938386855587, 87.58159160614015, 82.31872789321407, 83.83641842872866, 88.71630976277014, 86.03955884133616, 85.70045425045876, 83.83113891847673, 85.01116045059698, 84.64155550925963, 85.03431027935397, 82.83044815063477, 81.33727242869716, 83.11951114285378, 82.47679156641807, 80.0549005693005, 85.32605617277085, 79.94295612458261, 78.63806986039685, 79.385940336412, 77.30470718876009, 78.62830315866779, 85.70248603820802, 81.76319476096862, 86.80471912507089, 85.04548118960473, 83.41577560670915, 81.74381825231737, 81.7591154959894, 79.15537557294293, 67.5224022711477, 71.88027320369598, 72.47382979239188, 77.13155807987337, 75.60640719629104, 72.14722187288346, 68.23515184463994, 76.57119258757561, 70.93658231919812, 64.4240044009301, 36.113344546287294, 0.3595656348812965, 0.6002121767209423, 0.3421067055915633, 1.2885449346034759, 1.6924810337443508, 0.4236407385718438, 1.3365885759553602, 1.406424538262429, 0.9042955177926248, 1.27953096022529, 8.45655752766517, 75.98162112697479, 88.64529917317053, 99.94695771125056, 71.9137231765255, 57.820972704118304, 65.59535749496953, 52.681887226720015, 92.51553320115613, 119.83626134933965, 75.16921197214435, 68.50590521289458, 96.6159789792953, 57.26987577253773, 0.2777716835900661, 0.21110674306269617, 0.21279006805871764, 0.1787223066053083, 0.132582776789223, 0.195718641362844, 0.33127508036071257, 0.21969236703889988, 0.09877486469885034, 0.26291726938178467, 0.1322453763456114, 0.2240409425670101, 0.1640068147812159], [0.10313643307815637, 0.02752206299544102, 0.12110306415706874, 0.10037881532503713, 0.05289720671792185, 0.12928276112483394, 0.024120465987512184, 0.01010851579673228, 0.0776967598545936, 0.027324498495868137, 0.07812707144166194, 0.1348975727394704, 0.09709861835524922, 0.07581967590076309, 0.08091274333456833, 0.3477541219082571, 21.16061245241473, 48.793374953731416, 43.747551671920284, 48.148419626297496, 32.155978987293864, 27.0298824387212, 40.3894889739252, 81.38110883774297, 53.8970963416561, 0.726188103998861, 0.3025072837068189, 0.062153130814793615, 0.033275829553003275, 0.12383707874124089, 0.06008036885290377, 0.19280079632036148, 0.05335836866570096, 0.08015488319459461, 0.16513898548099304, 0.16666104896895348, 0.2668463504843174, 0.39526137913907733, 14.405531056465643, 70.59985468464514, 87.05033794526132, 85.14004168971893, 78.7937879562378, 82.56022037998324, 73.52961417167418, 68.71296713429113, 77.64630640706709, 83.87673254935973, 84.12307308566186, 86.50360661168253, 87.42838382720949, 90.62873194294592, 85.62056341478902, 83.46606039231824, 83.67200051584553, 87.3223150930097, 89.45608446674963, 85.85854930262413, 88.92538778243527, 87.25585445280998, 91.09587838572841, 85.32356154534125, 82.20416330522107, 86.27060997870662, 81.60930448962797, 79.883987211412, 84.46911242700394, 85.2385010257844, 84.95336040373772, 81.40613355944234, 79.3554792096538, 82.4597292561685, 80.35938632103705, 80.49911683605563, 79.16654648319368, 76.26978197405415, 74.78593364838632, 76.18015581561674, 77.10117540051861, 76.31305356179514, 73.56583333784535, 71.7960677608367, 72.67241939421623, 70.91646056021415, 69.28036151393768, 69.58918540708481, 71.68906550253593, 71.95766156719577, 74.87086865209764, 76.33880784434658, 74.26316015182003, 72.81005536356281, 68.72831929114558, 70.26671209642964, 71.4410932602421, 71.75163515152471, 74.12638710391137, 76.46483359798309, 77.63610824461907, 74.9807656195856, 71.83434224897816, 72.28020591120567, 76.01751081405148, 77.47531460177514, 81.44072101962182, 80.0484678822179, 77.81195594418433, 77.18451792193999, 76.03393770033314, 69.52685894504671, 74.88431453704834, 71.63363456726074, 73.22650124949794, 72.21320398392217, 69.06079507643177, 72.71034871378254, 71.6140619401009, 72.40377626111432, 74.43928241729736, 67.41261513002458, 73.50031406648698, 79.65964332703622, 79.10522414791969, 80.65398769993936, 77.74043544646233, 77.44541045158141, 77.14589826522335, 72.26860354023596, 65.53930682520713, 64.02487185693556, 59.08090860612931, 58.496338167498195, 85.78107464698054, 73.84623573672387, 65.12317865125596, 67.69991305566603, 64.15218022561842, 32.14841273523147, 28.8623922101913, 4.170679248148396, 0.07250934103203398, 0.45440465392124274, 0.016715090473993652, 0.28397675062860217, 0.09283564549179808, 0.2027104040908237, 0.36118713658182855, 0.2009562925705987, 2.030987708318618, 0.6110439245258609, 8.955631083057774, 26.720172089915124, 75.59354182212584, 69.07333881624284, 31.68384328965218, 33.42659942565426, 45.07448557884463, 24.521032494883386, 20.139588117599487, 47.82935834700062, 60.89107851828299, 58.09211438701999, 45.93169996815343, 0.5932676203308568, 0.10619358354879004, 0.044288841421685876, 0.14742946883122768, 0.04460374952384061, 0.103602375414583, 0.06094905510244351, 0.010527000901469541, 0.04345064930197212, 0.051842284493989525, 0.09417170283174324, 0.09563586539438657, 0.027158481497017127, 0.032818069035607966, 0.018409171344472036, 0.1091900981602169, 0.021800671313558857, 0.04047946538776159, 0.15180096571003238, 0.035711855086828434, 0.03180760289392164, 0.09870925692901497, 0.024589980208885767, 0.02856721376789914, 0.058262522647818255, 0.047470052170777516, 0.1016232408883591, 0.12355546482027539, 0.3812393347822851, 31.458656095689346, 62.66408005068379, 57.52944254106092, 69.29259930887531, 59.18034068999752, 27.580498879955663, 40.88943427608859, 99.28962338355281, 62.91344865675896, 1.617779493812592, 0.12891940562234772, 0.09570615396143929, 0.2392659901130584, 0.10448464823345985, 0.19837826880956852, 0.22549978847945892, 0.0982248365518547, 0.06263686554326166, 0.3529835912969805, 0.666577025286613, 0.13718342588793847, 0.8577422545321527, 21.332329896188554, 81.23320410328527, 92.10414717274328, 91.49183380988337, 86.34667258108817, 89.89913971193376, 80.205213639044, 76.0520512057889, 84.01504316637593, 88.1700961820541, 90.087460548647, 93.3770033621019, 92.2816736467423, 93.24055979328772, 90.82401106434484, 87.64424754727273, 89.88985153936571, 92.18160613890618, 87.97751565133372, 89.951613180099, 93.13854678984612, 90.31165538295623, 95.28996682936146, 89.1251854742727, 86.67793243162095, 87.75567423912787, 86.36171879306917, 86.16713785356092, 88.87407533584103, 88.40557175297891, 86.43059561329504, 82.12147974198865, 78.64549882950323, 82.05625072602304, 82.43804639385593, 82.10831626769036, 82.43368471822431, 79.19503858012538, 79.43553478487077, 81.39754356876497, 82.00296924960229, 79.21593696840348, 79.10451027654833, 74.92222032239361, 75.4427972916634, 75.0354826834894, 70.18478162827031, 73.23247109690021, 75.14780367574384, 77.62167392238494, 79.13805438626197, 76.62841212364935, 76.59661739103257, 73.52522111708119, 71.45815557049167, 73.31547629448676, 72.1115126148347, 75.26338807998165, 75.19951620409566, 79.1699589452436, 77.30546028383317, 77.18414137440344, 75.65561725247291, 74.00332666212513, 75.08504575298679, 77.27411270141602, 81.55332442252868, 82.09592157794584, 81.00273347670033, 78.96872566592309, 78.97145563556303, 73.47976869152438, 76.04519490272769, 75.84232207267516, 76.5828263375067, 73.50160844864385, 71.33537753935784, 75.54426116328086, 76.33882353382727, 75.71341729933216, 77.66341578575873, 72.15913803346696, 73.79839066536196, 79.72649620425317, 78.1247414312055, 80.94538058004072, 80.28517507737683, 78.64702070913008, 81.68238609067856, 77.38611990405668, 71.78950171316825, 71.67204241598807, 64.38548280346778, 58.225600488724254, 82.93759161426176, 80.28202149175829, 76.73966623121693, 69.85011716042796, 79.62525983010569, 59.19378265257805, 42.25876115983532, 9.158346037710867, 0.041770947901832486, 0.18285783308167614, 0.17544292934959935, 0.2636443787524777, 0.08858527477470138, 0.049370141744974165, 0.6248440485327476, 0.6845601119341389, 0.839910117849227, 0.9655234710343423, 6.817802056189507, 37.36044253072431, 86.71697570431618, 78.91079225847798, 37.160636994146536, 37.82422357989896, 37.71392653065343, 36.360085164347005, 41.32514684431015, 53.76354355965891, 70.66094952244913, 64.54074590436875, 53.66155801280853, 0.8813964755785082, 0.12250613886862995, 0.12117047989440542, 0.0975906306637391, 0.058131031316494754, 0.034366777061574885, 0.03909602167926008, 0.040052972748995795, 0.05646459855920365, 0.12135777307013351, 0.10661021280553072, 0.08940381673915733, 0.019574086557352738, 0.1639197259059837, 0.10683716635309881, 0.21519373020818158, 0.25739181426263624, 0.17287858791889685, 0.2808850649143419, 0.18165864501028292, 0.143720208997688, 0.15085192066767525, 0.1984391881213073, 0.19971337620048754, 0.15748539939522743, 0.232034380577745, 0.16798772939270543, 0.21674162618094878, 0.4772178330008061, 45.834083941675004, 78.49477783326181, 68.11002039140271, 73.61343522225657, 46.91158648460142, 41.661745040647446, 65.9020789977043, 110.17212175553846, 85.32990009553971, 2.459802911166222, 0.9877079064326902, 0.22723575903763696, 0.4381360720482565, 0.6020329532123382, 0.49923614989365306, 0.6150555286195971, 0.3254965404348989, 0.389712451085929, 0.8901239943600471, 0.906199154353911, 0.5835567510897114, 1.1254927419847058, 22.74180223864894, 90.57057888277116, 93.3511314084453, 95.44129187060942, 89.04564765191849, 98.73744780017485, 88.19824311041063, 85.50348066514539, 88.48104599983462, 97.2365136300364, 97.58802075539866, 97.05480590943368, 96.84690460082024, 100.44315322752922, 95.92596346332182, 95.95179619327669, 91.98404419806697, 93.36309463747087, 93.0525605909286, 93.13471855655794, 94.61843352163993, 93.38703678500269, 97.53331938097554, 93.55963676206528, 90.90285854954874, 91.11002245256978, 87.91873501193139, 87.15201362486809, 90.21745574089789, 91.87187225587907, 92.05399574772005, 88.38635213913457, 84.19551926274454, 88.49440559264153, 85.89836135987314, 86.14387819843908, 86.64313316345216, 82.79473104784566, 81.93144090713994, 84.27126023077196, 84.4303515649611, 82.84097579217728, 79.48139513692549, 78.20085110202913, 77.55914349709788, 76.39878872902163, 73.04208709347633, 75.3797883372153, 76.48428855403778, 81.96499286159393, 81.29357722497757, 81.37345237116661, 81.25721685348019, 76.13282849711757, 71.26678312978437, 74.88171008325394, 75.49572575476863, 77.00501457337411, 79.47361315450361, 81.64766526991322, 83.55624352732013, 80.58420088983353, 77.7922264222176, 76.8554545987037, 82.10946159978067, 82.22672477845224, 86.87178381027715, 87.65470458615212, 83.75989298666678, 82.06284030791252, 80.17594491281818, 76.72944453454788, 79.48981254331528, 79.046184632086, 80.22839484676238, 77.15005597760602, 74.1761855156191, 77.99010215267059, 77.73663074739518, 79.30699086958363, 81.31329105746362, 74.67500901991322, 78.41419666044175, 83.41778386023738, 82.46499307693975, 86.26650717950638, 84.61016085840042, 82.92521261399793, 85.30255333069833, 79.10003092981155, 72.41522173727714, 75.70216009693762, 65.93274408771147, 60.37632234634892, 82.5546584590789, 73.81019699958064, 77.12531366655904, 70.73068141937256, 77.90588886507096, 66.41772947003766, 58.56490512048045, 9.340850980051103, 0.26883618725884345, 0.6928691628479189, 0.5458336011055978, 0.5408243053863125, 0.2982369257557777, 0.5527526620895632, 1.465733226749205, 0.965895360756305, 2.523296033182452, 2.220584663652605, 16.0671127611591, 69.7523638509935, 90.98822501397903, 85.45821651335686, 45.802293131428385, 50.18140762082992, 65.50941051975374, 37.90514992129418, 29.897395872300674, 65.63294164596066, 82.25793900028353, 77.32262457570722, 63.609767421599365, 1.2636978227284648, 0.17261431822853704, 0.29049168491075117, 0.24480350345613497, 0.12442110587031611, 0.14872758949716247, 0.19578622563952403, 0.07460656035090647, 0.10477359361586072, 0.27335552378527583, 0.19473677711381068, 0.13829020843390497, 0.13680753718701102], [0.04913117976919298, 0.05421034653761214, 0.25106955109344375, 0.19306619982084922, 0.0674570371366797, 0.011943116344721809, 0.09188141403419357, 0.03277313031796967, 0.09829820479236304, 0.09499533928089565, 0.030679875504105326, 0.02870457333272263, 0.06187308737407289, 0.05952546455627007, 0.04709774876133569, 0.21923724952484333, 16.903954359792895, 61.14825264100106, 54.76936086531609, 51.145847843539336, 43.12542846125942, 49.42335467184744, 53.99349251101094, 74.55907160235991, 6.080947066507032, 0.5534922127281466, 0.009470072484785512, 0.2251440938562155, 0.024796023386560624, 0.3423021499428057, 0.06348053136119439, 0.022578177778350732, 0.02502641283846911, 0.013421292570720037, 1.8006878274102367, 1.8462718975159431, 0.11077207738473532, 14.485333638806498, 54.79588393242129, 75.28219976732808, 92.88304359682145, 92.01951026916505, 87.66909968468451, 75.31663033270067, 68.16750664864817, 68.9059163678077, 81.62872806672128, 81.02529494993149, 89.92431348369968, 88.72449182694959, 91.91144897091775, 88.35824443447976, 94.03159203067904, 79.87474610728603, 86.07017686290126, 83.7691419355331, 87.06475657801475, 92.73950053799538, 91.21958209622292, 87.7993929770685, 88.70706865864416, 81.84927509677026, 80.82137092467278, 82.82872230775895, 81.47280600763138, 84.83044901201802, 81.7406411324778, 79.54885205914898, 77.28365975041544, 75.64541124528455, 80.60668391566124, 81.4360769333378, 83.01437593275502, 80.06350624945857, 81.9707352115262, 80.30915644861038, 78.5677025395055, 78.98440730187201, 76.94326077738117, 76.46309206562658, 78.81386264677971, 72.01808960207048, 69.447446638538, 70.94083416846492, 72.67982482910156, 75.74393333927279, 75.14194365470641, 77.93235701899376, 73.33378591845113, 75.15032183739447, 73.523236397774, 70.44689009266516, 75.4649429936563, 68.4009268976027, 71.29906423630254, 77.77011994392642, 82.33770432010775, 78.60987586359825, 78.96117902571156, 80.71319980006065, 73.46695823054161, 71.6737368799025, 72.9428275938957, 72.38047738229075, 74.68071999088411, 76.58405011700046, 76.75369262695312, 77.7034318062567, 81.87581385335615, 74.14632058912709, 73.24057471367621, 74.41148850225633, 73.39119372829315, 70.7352392135128, 69.50884742121544, 65.25981833857875, 70.63656806945801, 71.96344314082977, 72.2827240728563, 73.51423063585835, 70.3149886285105, 73.88749122619629, 80.30625389468285, 75.4151681161696, 81.16106387107604, 79.03564130106281, 77.30341280660322, 72.42090132928664, 70.72013808834937, 65.76478035219255, 66.83150029951527, 61.48916936689808, 70.34732464821109, 81.34038679061398, 73.86716550396335, 62.33975887298585, 67.72634983062744, 51.82380599360312, 26.720281916279948, 19.37013872208134, 0.11663841098667153, 0.2242600743568713, 0.1484168642350743, 0.3046761399074909, 0.12483872338047913, 0.3012772835791111, 0.09401398064989237, 1.0947215028347508, 1.747685084419866, 0.7425521097836957, 0.7787086406061727, 10.617255933823126, 33.83858557670347, 77.52028065343058, 45.94454965283794, 17.249322975835494, 24.873841847142867, 31.19686338209337, 27.394105888182118, 43.06932287831461, 52.069758215258204, 61.887286017017985, 43.311846948439076, 0.3355778591527093, 0.16442080869549708, 0.07513034232561627, 0.042539617542417786, 0.055847300231576934, 0.09390845969920197, 0.04891575201444569, 0.014982291519822133, 0.027898985915066257, 0.12470668812672939, 0.028427475500070763, 0.007244695274670038, 0.08023559821829682, 0.027013738759823387, 0.009254870725975884, 0.044805981414092165, 0.09661722402538984, 0.06811958061711443, 0.05689834222017277, 0.08847141112651556, 0.042809517979021036, 0.08199119594909492, 0.0626703244333546, 0.02335733707783924, 0.03655474332551803, 0.08395886213909234, 0.05840110795332059, 0.02855789622352008, 0.14561397834650933, 23.886979395343413, 79.06476882196243, 71.03289219640916, 76.90749660614999, 34.71653753711332, 28.879362344741825, 63.640632552485314, 89.33991170698597, 6.433625999958285, 0.6895416446270481, 0.0671484339381418, 0.6340515060770897, 0.2781950850640574, 0.3717000385926616, 0.0318056627762534, 0.11906193779601205, 0.035572166614715135, 0.029874902872008183, 2.526907555518612, 2.473138479455825, 0.14937804411015204, 21.681250218422186, 69.70512282463812, 84.16774888192454, 97.15743080262216, 93.66608988854193, 90.77203965956166, 83.89528536027478, 77.08114777841877, 77.93935452738117, 84.43141060490763, 84.60076285946755, 91.73567971875592, 92.53404678836947, 93.32746382682555, 93.21024771659606, 96.10469802733391, 88.78273902400848, 90.96167056791245, 87.65224918242424, 91.32189319979761, 96.24603671412315, 92.66102960032802, 90.52759755042293, 90.09946300137429, 86.38106392275903, 89.4014144712879, 87.24836272578086, 87.60995034248599, 86.3397378306235, 84.45654515297183, 80.51035050422915, 78.73245777622347, 79.72326417123118, 84.12071181881814, 81.99399486664804, 85.05029001543599, 85.52027625422325, 84.08260991496425, 83.01091640226304, 83.61651466738793, 84.92256979788505, 82.37637104526644, 81.8110712112919, 82.36598460905014, 76.32129053915702, 73.51335202493976, 71.65638431426018, 74.70037891018775, 78.54101473285307, 81.03710128415017, 79.09745001023816, 76.10599164039859, 77.44239022654872, 74.40787207695746, 71.67154035260602, 75.24926754736131, 67.68407452491023, 77.23017431074574, 78.08870269406226, 83.74345041090443, 78.53614314909905, 79.66973166311942, 82.20766205941477, 77.8699521095522, 75.08084881690242, 74.90808410029258, 75.68952222024241, 76.74780907169466, 76.77535979978501, 77.27055118929955, 77.72615017429476, 83.82304314644107, 81.96928393456244, 76.4494029937252, 75.99436098529448, 76.37177144327472, 75.89474847239833, 76.0524042191044, 70.1750070818009, 75.2135504445722, 77.79005342914213, 76.66695333296254, 77.47222377407935, 72.59134400275447, 73.17587129531368, 78.32450774408157, 77.03797817230225, 80.02873836025115, 79.4404612818072, 77.29833725960025, 76.1007905775501, 76.71646933401786, 69.43960974293371, 73.21533818398753, 67.28994692525556, 71.14528379132672, 78.88020561587426, 82.9329945964198, 69.44764275704661, 71.1546504112982, 73.8233918528403, 48.279979844247144, 27.05047880449603, 0.6698092421697033, 0.19693382535009615, 0.16714708579163398, 0.21253416404849101, 0.14723603163034688, 0.2787293547824506, 0.5013285198759648, 1.2254406175305768, 0.241423538855968, 1.0502196391743999, 0.8856464249472465, 9.061487028675696, 40.368186581519346, 91.71826439519083, 55.457689762115486, 22.595695910915254, 23.12633179849194, 29.75109930961363, 33.6547754656884, 44.107570340556485, 55.762195125702895, 70.35052530227169, 48.926782608032234, 0.3427435085177422, 0.08463605322063932, 0.06049537783368461, 0.047561503916738496, 0.015949034150840057, 0.04391340471263375, 0.03690407175811068, 0.09375544895808544, 0.050733203684250196, 0.09362435599248256, 0.07644940017452163, 0.01064959699438224, 0.02439892554144946, 0.14225308933565695, 0.11011128058476795, 0.2614205174388424, 0.27601268442888416, 0.1733099567073007, 0.14574191502986417, 0.19606865161368925, 0.1995942801717789, 0.21363950634915985, 0.24648653733874523, 0.20171737027985437, 0.22971040689416472, 0.22793196442146457, 0.08229926288608583, 0.23111590244356664, 0.34861394835095255, 34.20157740193029, 95.74445970596807, 78.34753205699306, 75.6407279352988, 59.439126906856416, 76.46938354738298, 74.6420846446868, 107.86828625586726, 13.630390301827463, 1.340397442540815, 0.27081444078395445, 0.7239470210286879, 0.6733901209888921, 0.5499360938706707, 0.20004199727648692, 0.349314030139677, 0.3412291365525415, 0.2586850013223387, 3.9022153183337185, 3.8173771481360164, 0.3082430146394238, 19.960751571962913, 72.19711442147532, 91.36204258088144, 103.56104527750324, 100.74821164531093, 96.8109521558208, 88.20169479616227, 84.24812609149565, 85.48353933518933, 92.98986542609431, 88.70935147808444, 98.40891007454165, 99.83007892485588, 99.63234439972909, 96.12529047073858, 103.98082517808484, 90.84040657166513, 96.30245608668174, 91.41814816382625, 94.75451623239826, 100.13504320575346, 98.3368012212938, 95.1114126943773, 94.86444457884758, 91.36220732042867, 91.47792508525234, 90.05125707195651, 90.05203370125064, 89.82351641501151, 88.43069845630278, 83.4121827156313, 84.33519486458071, 80.33539710506317, 88.47196963525589, 88.62421251112416, 90.19913042745283, 90.82170471068352, 90.82732154477029, 86.00888590658866, 87.22356550155148, 87.11886175217168, 85.43519220044537, 84.47381142647036, 88.90142210068242, 78.67938026305168, 76.16910257647115, 75.14461086642358, 79.54195653238605, 83.23437383097988, 85.4290811477169, 85.71558675458355, 81.11246570464104, 80.79675412947132, 78.93053746992543, 72.35783746165615, 79.860382387715, 71.3332280805034, 77.97082762564384, 81.70266474446943, 86.330120178961, 84.09658924225839, 83.7559784612348, 88.00705109873127, 81.4220662270823, 75.10014687815021, 75.58023714250135, 77.35623928808397, 79.31859324055334, 77.88031501154747, 80.05420238740983, 81.82978091701385, 88.19744294689548, 81.79844902407739, 80.706037552126, 79.55552008844192, 78.62578499701716, 77.98526194787796, 76.31938426725327, 70.71470168329054, 77.07069073953937, 78.99164015246977, 79.94809442950834, 77.60557651519775, 73.95526978277391, 79.51180919524163, 84.22099897938391, 81.10671550996842, 85.73861106749504, 85.33597192456646, 82.63564755839687, 78.94668979029503, 77.69495164194416, 71.10485199959048, 73.41371597782259, 67.69684576219129, 74.0393183308263, 76.9444453331732, 78.89484390135735, 70.9639447735202, 70.63182200154951, 76.29408497964182, 60.14896215931062, 37.779077099215606, 0.405160338287392, 0.528849064102096, 0.44625243652732144, 0.7458421203397936, 0.18094193911360157, 0.4835319296727258, 0.7066707577436202, 2.158197650024968, 5.072655725863672, 1.2960762530565262, 3.0026197193130373, 26.32220841223194, 65.82573398467034, 98.99158600837954, 66.36339679841073, 27.198662027235958, 37.71435406900222, 47.73929680547407, 40.68030918798139, 56.04146003723145, 67.78929602715277, 82.78726285503757, 61.11811707096716, 0.7900221044978788, 0.18807866099861362, 0.20481002126489917, 0.1905154794334404, 0.08884760626261273, 0.1487968591672759, 0.19215895253564083, 0.12670934921310795, 0.09762606989111632, 0.2027820333117439, 0.13672666894572397, 0.10893339741854899, 0.12231833241399258], [0.0690007655911388, 0.06043056296485086, 0.07774822564134676, 0.17033978785958984, 0.18391832859525759, 0.07821354744655472, 0.10822889530250143, 0.046481660852629336, 0.08723817810776734, 0.03318179226029785, 0.04263631699066009, 0.09314415675978507, 0.037372932889528816, 0.06497838264030796, 0.0773494998593965, 0.15932946495952147, 17.711315424211566, 55.86106238826629, 46.790667656929266, 41.78305610533684, 54.684700427516816, 58.10820002709666, 84.82391434331095, 35.57635638021654, 0.7811928492399954, 0.06542606144061973, 0.22358179543047185, 0.2302159483153974, 0.8675578633143056, 0.22958548859723155, 0.06723032107636814, 0.274034614764875, 0.14056882971236784, 0.08431524624146762, 0.9018493684068803, 0.035826381401068745, 6.152474918673116, 64.9723360615392, 74.52285243618873, 74.999326275241, 74.908139013475, 72.39059709733533, 72.807647028277, 81.83338949757238, 68.76460905997985, 75.7984229057066, 78.15714020882884, 87.63517118269398, 89.47106007606753, 89.69963227548908, 88.68346383494716, 93.58133531385853, 83.58735576752694, 90.06594242588167, 81.91906190687611, 86.79012790802987, 89.08800924977949, 89.15037493551932, 88.59496731911936, 90.1633034982989, 85.29522634321644, 79.06381960838073, 79.28263295081355, 80.57037845734628, 80.59139451672955, 80.11200243426909, 76.53719348292198, 77.71900361584079, 77.9765542860954, 81.99730534707346, 81.4268672081732, 83.09417263154062, 83.92059249262657, 79.94263449022847, 76.91185043704125, 79.07335096789946, 79.40798405678042, 78.82425692773636, 77.50030794451314, 76.00717929101761, 68.78285592602145, 72.36578418362525, 71.74643408867621, 71.72607698748189, 73.61560821533203, 73.53440730802475, 76.97624006579, 68.95557357418922, 72.70288052097445, 74.66879598556027, 73.40133697755876, 76.25506524116763, 67.96497898717081, 69.43032941510602, 77.49148261162543, 70.07693213801231, 73.06530752489644, 74.74373679007255, 75.9455745450912, 73.97223795613935, 72.94524377392185, 71.55612068791544, 77.4726003216159, 76.74658529220089, 73.84382740143808, 75.89893756374236, 75.18049270875993, 76.59986511353524, 77.92385332046017, 75.86402846920875, 75.5456732165429, 74.12273145491078, 72.94445929988738, 71.72173100133097, 76.36049070665914, 70.91452290934902, 63.6584165788466, 68.44818361343877, 75.18329328106296, 71.41136169433594, 74.21501698032503, 70.62023532006049, 72.73717772576117, 81.4523704590336, 74.87742685502576, 78.36053079174411, 77.96338296705677, 72.28304570721042, 74.52238175176805, 68.30378547791513, 65.59559283717986, 66.9137445572884, 66.21559404557752, 74.70553290459418, 74.99783577457552, 69.60051321214246, 65.10064855698617, 69.23891775069698, 31.747030711943108, 25.32747768586682, 5.834796274861982, 0.3835889264460533, 0.47322786323005156, 0.29095899854456225, 0.5041057724625834, 0.7140210342984046, 1.5252000357835525, 0.35861893406798767, 0.2235235727482265, 1.1162191557307397, 0.32369969653025754, 2.199033691037086, 4.322532828777067, 53.73900913423108, 63.10105562210084, 30.024284547375096, 37.261096738999896, 33.00238332440777, 57.838250744727354, 66.5334786138227, 57.60077084264448, 53.24760283193281, 11.9166842199141, 0.08961740205244673, 0.21149472063106878, 0.15126211478585197, 0.06560662836437264, 0.08892159503433975, 0.1094503612107327, 0.027878916326669917, 0.034283874856848875, 0.04633131609748929, 0.14606797737219643, 0.05319773534973783, 0.04788102769863702, 0.050156737842987624, 0.07916473753509984, 0.03984111113353603, 0.04328232446324922, 0.042198382828745155, 0.05676518081717434, 0.14801241577632968, 0.08232038393015824, 0.04276485888347511, 0.04971212722481259, 0.1403240799423187, 0.09303495092617889, 0.049209163689445105, 0.05825147565995013, 0.10681487319450225, 0.09494603386208897, 0.23068375224548004, 23.370081609295262, 69.05706098002773, 66.76514948568037, 67.73632834034582, 33.0060193615575, 56.202622382871574, 100.6040959204397, 41.64353739830756, 0.5984806954380005, 0.2892744631296204, 0.21811779588460925, 1.0199334256110653, 0.6505208642732713, 0.3105607676890589, 0.06308643275030679, 0.09411293622707168, 0.04986397351228422, 0.01698180015439228, 0.8617119995817062, 0.24755683877775747, 10.42453125599892, 78.32323689614573, 82.90886417511972, 87.45000393159928, 82.36013243275305, 78.66139227344145, 79.19137508638444, 85.70698891916584, 77.32542514801025, 78.98738045846262, 84.49784771088632, 91.23822119928177, 90.74440263932752, 92.54256617638373, 93.40736250723563, 93.92000844401699, 88.1692881737986, 94.46124845935454, 88.08662030004686, 92.71224006529778, 91.1608014568206, 91.75595837254679, 92.61345909487818, 93.21480551073628, 86.83830245848625, 83.00830410372826, 81.24475940581291, 83.64856827643611, 83.94098097278227, 84.97559239787441, 77.15462161648658, 78.87985260255876, 82.98880207923152, 85.95521219315069, 83.13783645629883, 86.59022823456796, 85.32302810299782, 85.01699693741338, 82.32874562663417, 84.24648654076361, 82.43625779305735, 81.02322393848051, 80.40135568188083, 80.67472134867023, 74.93982391972696, 76.61911610634097, 74.95447004995039, 75.93801221539898, 75.58839567245977, 76.88925758484872, 78.10079143893334, 73.2999986217868, 76.18706703186035, 78.13854032947172, 74.23375806500836, 76.81340679045647, 66.48685732195455, 73.61512184143066, 78.60967974508964, 73.88209404483919, 74.43524237601989, 76.11406387821322, 76.40826517535795, 75.09015267895114, 77.63304879588466, 75.06192730319115, 75.62812143756499, 80.47027957054877, 78.17563026182114, 77.86160530582552, 75.13020792315083, 77.31845901858422, 80.11500696982108, 79.1161754054408, 78.36213896351477, 76.88312299789922, 74.86969194104596, 77.0116041552636, 78.57994817918348, 76.52945072420182, 68.05443256132065, 70.18684479498094, 77.00370450173655, 77.85467055536087, 75.94463317624985, 76.46430800038, 71.68783387830182, 79.13763077028337, 73.23494219010877, 76.95003863303893, 80.05436712695708, 75.7107343981343, 77.227813043902, 76.13655474878128, 63.83267179612191, 71.20116972154187, 69.6934812299667, 74.89903911467522, 78.8627040001654, 78.56212492912047, 68.27005309443321, 78.91541281054097, 61.58819352426837, 35.886447198929325, 11.100861622441201, 0.3523758690684073, 0.14896585816337218, 0.15106348350884455, 0.17285551335061752, 2.0927080415910293, 0.34017141427724595, 1.3875147916616932, 0.5464234275202597, 0.10474286582921782, 0.4125843431440092, 1.318817787593411, 11.726583607735174, 62.78240619167205, 72.00585180713286, 34.66926120942639, 30.562014041408418, 26.059123277664188, 53.58448736129269, 59.12426648601409, 58.258191462486025, 62.918857605226584, 13.738472192518174, 0.07766206373250292, 0.05082247207962698, 0.12976081531134345, 0.08138211774489573, 0.06225331213265177, 0.050168125739982056, 0.09897110578153404, 0.043392223606426875, 0.03316837806074369, 0.07803560820438209, 0.061239636082562714, 0.02819707072640379, 0.06500830603463036, 0.26229995573239945, 0.17542667296384612, 0.14550959120594686, 0.27310378729335727, 0.28718797670256707, 0.23320241951413695, 0.31796617193087456, 0.12569308761627446, 0.15268697703797973, 0.27063738254289477, 0.25290664525762685, 0.15098191046666715, 0.18484806822192285, 0.15498393846134986, 0.24884162951380978, 0.2738892725638805, 33.43251435987411, 82.66070365905762, 65.46867278314406, 62.64779436972834, 82.58406054589057, 82.83886555702456, 111.7749983264554, 55.22572863486506, 1.5444475965153788, 1.1286134777530548, 0.7090120450142892, 2.1815644348821333, 2.0903840372639317, 1.1946973252680995, 0.17432473209356109, 0.37733286859527715, 0.3771072097363011, 0.32214478319210393, 1.9603682525696295, 0.6005672737956047, 8.868465231310937, 92.04688056822746, 90.57860405214372, 94.90630411332654, 89.30841507450228, 92.16397900735178, 88.18900200628465, 95.1241917763987, 84.01196802816084, 86.59736694828158, 86.41310968706685, 97.93773143522202, 98.50955809316328, 96.9654856958697, 98.60235352669993, 102.49854580048593, 91.48846841627552, 96.77997327619984, 91.76188115150698, 98.06585173453055, 95.36301705145067, 96.90645402477634, 94.40249135417324, 96.1886759727232, 90.52041176826724, 85.90080107412031, 87.28605670313682, 88.50734156946983, 87.89247082125756, 89.87253035268476, 80.68565691671064, 82.11281130390783, 85.84893949570196, 87.43637761762066, 84.481883664285, 91.37281340937461, 91.307811890879, 88.88833707378757, 87.98918862496653, 89.28980735040481, 89.1171524601598, 87.74156939598822, 86.9577072512719, 83.56990906500047, 76.3957763487293, 79.13689336469098, 77.57827681879844, 78.32665720293599, 79.77672607667985, 84.11113339085733, 82.09200705251386, 77.24871927692045, 79.61574416006766, 84.2965752078641, 77.20160376641059, 80.70382533534881, 68.90631644956528, 74.49883968599381, 84.54019361926665, 79.82293159730973, 77.78779414392288, 80.45428414498606, 79.7602128982544, 79.32518282244283, 80.77417696675947, 80.76230787461805, 81.66096210479736, 82.6714038848877, 82.61794982417938, 78.89099997858848, 76.74376903041717, 81.33789216318439, 81.78698785843389, 81.77407541582662, 81.31000411125922, 80.0601722348121, 78.8942555458315, 82.02742914999686, 81.64977550506592, 81.65391752796789, 69.44863119433003, 74.13941721762382, 79.1225924030427, 77.6738336009364, 78.5554490550872, 77.58842791280439, 75.68942808335828, 86.82597837140484, 79.54532192599389, 85.55305157938312, 84.47228170210316, 80.83965701441612, 79.2331640182003, 78.28216968044158, 63.76870186098161, 72.81058880590624, 70.9162409074845, 75.44693146982502, 73.82672586748677, 80.29620478230139, 69.16514581249606, 79.78973265617125, 67.22519643845098, 54.13173252536405, 9.586903222145574, 0.37192857794223294, 0.9502275143900226, 1.2248742027628807, 1.2740369453545541, 3.940510644066719, 3.9988644805646714, 1.6075418625147113, 1.430501762417055, 2.1600178749330583, 1.9009670206616003, 8.754701787425626, 38.216935203921416, 78.19872517739573, 79.93968486785889, 51.3748279694588, 51.790050075900176, 46.62897579131588, 78.40143326790103, 85.12972585616573, 70.26567659070416, 74.94722150987195, 20.155346239766768, 0.3893987534026946, 0.306353933748699, 0.2250164176427549, 0.146689688366267, 0.12356648882550579, 0.2545406954783586, 0.1791613975599889, 0.23489850753497696, 0.12363358280591427, 0.28030633145282347, 0.16702438914968123, 0.1718986695331912, 0.1946848823178199], [0.020455064687637553, 0.05805276011327102, 0.03295313416709823, 0.1217294789309944, 0.35697285626684466, 0.10410265381177587, 0.019425126506135832, 0.042324170635472384, 0.03576299528621378, 0.1256581616678065, 0.07210564333945513, 0.1558131060653156, 0.06161288561059102, 0.0962664630083788, 0.0091716515523712, 0.264921723113906, 32.05513877253379, 60.94889033225275, 45.182338991472804, 41.42215882578204, 45.316134960420676, 73.82000292501142, 83.62806996991559, 2.5112651432714155, 0.6052093376075068, 0.06817220319663325, 0.508098867872069, 0.566577178335959, 0.10084406052145267, 0.04332445929908464, 0.08230837167150552, 0.2653055638074875, 0.039889064407156366, 0.2594930708648697, 0.12015831686796681, 2.1527024094135534, 40.01438879197644, 69.56045012320243, 82.1202559624949, 80.726637840271, 69.10860092409196, 61.724621403601866, 62.35249873130553, 72.68951308342719, 76.92165636247205, 79.6501668806999, 88.47321694897067, 89.90082633110785, 90.56135346812587, 88.45861788718932, 90.10568388046758, 85.50343359670332, 89.67205801317769, 85.72878160784322, 87.60277240507065, 85.61253824541646, 86.41114065724035, 87.51538199763145, 83.99558821032124, 85.39918484226351, 77.8901287817186, 85.13433071874803, 79.30072292204827, 74.68879222869873, 75.74082682209631, 78.26260489802208, 75.43565857794978, 78.66239640020555, 82.00506379527431, 77.7941091599003, 81.47406901082685, 80.59896469116211, 78.43257688706922, 79.3611038884809, 76.58942376413654, 78.97467197910433, 77.24598146254017, 77.05344800026187, 75.92488796480241, 74.91758408084993, 72.09884335917812, 71.19282291781518, 67.58435218564927, 72.5093743108934, 70.27541191347184, 74.65389882364582, 78.50018285935926, 75.74827932542371, 76.206953448634, 70.64292230913716, 73.77329534099948, 71.23903628318541, 68.7035063774355, 71.59107685089111, 68.43007010798301, 66.17862178433326, 68.96647776326826, 71.86541526548325, 74.2696399073447, 75.36609142057358, 76.28269441666143, 70.25579221786992, 66.85705061881774, 73.48569147048458, 73.33326032084804, 75.17354226881459, 77.42362560764437, 76.5121530717419, 78.31673360640004, 74.70615263908141, 70.5461182132844, 76.65666103363037, 74.42602480611494, 72.28095116153841, 72.64544917691138, 70.34428088895737, 66.78614201084261, 61.81305123913673, 66.89332469817131, 69.7284766166441, 69.68986480466782, 76.75224919472971, 71.65520760320848, 72.83140090204054, 77.83483120702928, 77.58158729922387, 75.14141805710332, 76.3147323362289, 70.09823845278832, 67.80383233101138, 60.49956321716309, 60.47013759613038, 67.92282135255876, 76.27193143290859, 79.22986138251521, 71.98001123243763, 65.31755170514508, 72.38040677962765, 53.51773254333004, 22.169306816593295, 22.048842983861125, 0.2661531021998775, 0.353930659832493, 0.12171794930773398, 0.8135332816070127, 1.1956511966643797, 0.1805169901420032, 0.06706208816819614, 0.241614141531529, 0.09997688729556338, 0.03125626282135566, 0.6162509935036783, 5.121538264136161, 18.78771185874939, 66.29360214356454, 35.074014509877856, 30.430806836774273, 46.41789736286287, 41.55356607129497, 50.77337957197621, 53.306481530589444, 45.93442601542319, 0.6708456059136699, 0.09150386292247042, 0.13704792025589174, 0.05781532648289877, 0.08775793045999543, 0.04365010029305855, 0.09212835481570614, 0.06190939994168378, 0.051022719802154656, 0.06267670594576387, 0.005479175268837642, 0.0399657612996957, 0.06412710190840787, 0.024320903316801114, 0.029995894968329422, 0.007922866948760085, 0.11066006000844703, 0.07542438985359284, 0.07153236442395756, 0.10091031946602369, 0.08915062468018263, 0.13180165821986814, 0.07897297040589395, 0.12513591186894527, 0.052919469233001434, 0.04854082092342358, 0.09261537989180896, 0.10528669632490605, 0.026457399963551474, 0.20553066485351135, 44.30568141321982, 72.2441279503607, 58.629710520467455, 39.14647025446738, 34.75068176946333, 85.0783271174277, 92.09618476129349, 4.738593832139046, 1.5413679230597712, 0.281173512339592, 0.8142204931186092, 1.0715128385251569, 0.05188146989131647, 0.37873637231607593, 0.08789115315002781, 0.5357518840220667, 0.2567718959143085, 0.3293866736273612, 0.13266468691008707, 3.4149701604920053, 52.10715017011089, 80.81449893213089, 91.39188397315242, 87.33242696331394, 82.02704475771996, 75.1413631439209, 71.06434960519114, 77.78183214126095, 81.81599770822834, 83.73478197282361, 90.21790289109754, 92.72828255930256, 93.26190533176546, 91.3791911832748, 91.517956795231, 88.34778739560036, 93.6649602459323, 88.43670752740677, 90.89332719003, 89.93389191166048, 91.81670019703527, 90.07847832095239, 85.4318581857989, 83.04481352529218, 81.48557724491243, 87.49340887992614, 85.92489227171868, 83.58410020028391, 81.51087653252387, 81.04431844526722, 83.07489025977351, 82.49770564417686, 84.53518867492676, 82.40400022076022, 82.52647230702063, 83.55278399682815, 83.26456039182602, 82.80762780097224, 80.46878906988329, 82.46056864338537, 80.21871443717711, 81.77171414898288, 77.94177070740731, 76.33247713888846, 76.87873778804656, 76.22709089709868, 72.13383090111518, 76.39069295698597, 75.3705943015314, 76.79280650231146, 78.46569738080426, 78.07948512415733, 75.91594496080953, 73.41981918581071, 77.07706851343956, 69.12912276483351, 67.96359046812981, 70.7463316763601, 70.21172831135412, 69.96867472125639, 70.42996114300144, 74.3818118495326, 77.30924144867929, 76.67119733748898, 77.61383702678066, 74.8589603362545, 70.56661651980492, 73.62630844116211, 75.13613070211103, 76.55422441421017, 76.32668772051412, 78.47415401089576, 79.40105715105611, 74.63100002657983, 72.06979428568195, 74.22526221121512, 74.63658548170521, 76.03021144866943, 76.8205847278718, 72.85175800323486, 73.90849159609887, 65.52591977580902, 70.89551510349398, 75.08102140119, 76.58522682805216, 78.04853762349775, 73.93659145601335, 70.3561499810988, 76.59988864775627, 80.3138005348944, 77.4329294696931, 78.34810472303822, 74.53327809610676, 72.57210085468908, 66.73123667317053, 64.39523381571617, 68.94808969190045, 72.49581859957787, 76.29484591945526, 79.95932809768185, 71.31144323656636, 75.57926439469861, 76.11688798473728, 39.92838298120807, 30.494327660529848, 0.8157829447619377, 0.31935337330064467, 0.20100541412830356, 0.3430368282621907, 2.159979876972014, 0.5003167322326092, 0.15378677286207676, 0.40632669183035053, 0.2038517678456922, 0.15460590471423444, 1.3603811831243577, 10.873826992127205, 24.864267341552246, 77.65197030959591, 40.33377562799762, 41.140238469646825, 30.70911861235096, 37.87559093967561, 58.84358559885333, 56.47845129812918, 52.37792315021638, 0.20080903514979348, 0.18231628552800228, 0.030963155666306138, 0.026110900310619224, 0.06405191037863975, 0.02490623279534761, 0.05848987456110697, 0.05415064530567296, 0.05347761025111522, 0.04108944757571144, 0.06201595128063233, 0.0255573156004351, 0.03230013997263966, 0.036135459574119705, 0.12256505869088635, 0.15529120100602029, 0.2896047695990532, 0.1878544423849352, 0.44548018925612975, 0.16196823949294706, 0.1828795899787257, 0.25336517952382565, 0.21786921567493872, 0.21920130467943608, 0.18749752202101294, 0.1523372579005457, 0.14509780362488764, 0.18320552974699006, 0.10438559306485039, 0.43015447775683097, 55.968649079722745, 85.96477493163079, 66.17441700350854, 60.96028481760333, 71.72628879547119, 94.8267270672706, 108.08666029284078, 6.988999295619227, 3.2070048682151304, 3.4552222586447194, 2.5388391604346614, 2.2200370027172953, 0.34362095498269607, 1.4170806374280684, 0.20249251336339982, 0.9313946830168848, 0.7903067827705414, 0.6898785394526298, 0.5754051465661295, 2.7122510681229257, 58.569043221012244, 92.25291482863888, 92.3761792336741, 92.69069840831142, 89.59974519668087, 84.30412184807562, 81.54606019296955, 88.02172860791607, 87.31093237476965, 88.12974283772131, 97.44754499004733, 98.42659211927845, 96.06072041296191, 97.73258363046955, 97.79065824324086, 94.48239003458332, 96.12094448458765, 94.11439326501663, 91.79532327959615, 93.41943556262602, 93.36967637462001, 92.48624094070928, 87.55918702771588, 89.65287762303507, 83.0706697894681, 90.65985202789308, 86.39778106443345, 87.4506550450479, 85.92803016785653, 85.44220539831346, 83.9404239962178, 86.56215190887453, 88.41473440970145, 85.35910606384279, 87.19290041154431, 89.58604828003915, 86.80655479431154, 86.38481370864376, 87.32854381684335, 87.85655759995984, 84.26292127178561, 86.00789746930523, 83.08686917827976, 80.90988312998127, 80.70903424293765, 78.94010805314588, 73.46889588140672, 79.23897697079566, 77.28267131313201, 78.98788252184468, 85.08264172461726, 83.22077105122229, 79.7829548005135, 77.96066084215718, 82.341579621838, 71.79100790331441, 69.61343349949007, 75.27622991992583, 72.64599046399518, 72.60219327865109, 71.82245746735605, 76.93116418776974, 79.99606501671576, 79.22447989063879, 83.10310779079315, 78.57804975202008, 74.59245097252631, 77.43778536396643, 79.88678778371504, 80.3873057519236, 81.85192661900675, 81.37256591550766, 85.63482515273556, 78.7818011929912, 76.17453113678964, 78.58615336879608, 77.2430710638723, 81.73918985551404, 78.76015755438036, 76.95342756086781, 79.85525192752962, 67.86133427773753, 72.76903521630072, 76.33221041771674, 78.33860474248087, 80.61607406985375, 77.51782524970271, 73.896316559084, 80.98200767270981, 85.70250957242905, 80.9169198620704, 81.7913495340655, 78.27877290787237, 73.74144569520028, 67.50646175876741, 65.8182736366026, 71.3252107558712, 77.47980179325228, 75.42214993507632, 77.69587732130482, 74.25646074356573, 74.33632804501441, 77.14083056296073, 52.27755754224716, 43.79070166618594, 0.5536198736198488, 0.4526276670155987, 0.30705922493530863, 1.832328361849631, 5.515670766753535, 3.424620907152853, 0.5105953951997142, 0.7385781972158341, 0.42958294552180076, 0.4068005018897595, 2.5092041828939995, 23.747682302228867, 44.573920542194, 86.97441654820597, 53.79612276631018, 52.24802601721979, 61.77139174553656, 60.77558432855914, 71.07998417269799, 66.5045472114317, 62.478771594262895, 1.2390603125095367, 0.2182542514656821, 0.23822821676731112, 0.1613857215570827, 0.21983838339726772, 0.14887144548758385, 0.2290994058092756, 0.2251904115321175, 0.15766392852510178, 0.15862567530524346, 0.16361633976621015, 0.16936011462201997, 0.26951625883098573, 0.20188633863243366], [0.04189162207166514, 0.06207852917272718, 0.07085115138080812, 0.15004262538446536, 0.1507101484364079, 0.11049217183984096, 0.07051611048800331, 0.03021164448000491, 0.0609682762484637, 0.021017277463068886, 0.01890465786169854, 0.07510476264982455, 0.03975879498607209, 0.032914948514512474, 0.16221024666822728, 3.3696761006309144, 58.20498058872839, 53.30975670968333, 63.000438982440585, 65.07642792117211, 52.868725407508116, 89.15486212699645, 32.66072134817801, 0.7822361997058316, 0.7591247366320703, 0.6055088473423835, 0.7438841221794006, 1.4174533851685063, 0.18751328811049464, 0.07031598533954352, 0.043751296677416375, 1.6142977774143221, 0.025701682954545946, 0.3464544077794398, 0.07618933630686614, 19.86395728203558, 55.95398333764846, 71.01608876259097, 94.92920291039252, 81.85965368824621, 83.08066398866715, 65.10843053940805, 73.88846397399902, 75.46145992894327, 75.20167350769043, 85.01005434220838, 89.1620243749311, 87.27094773323306, 89.34719162602579, 90.17391743198519, 86.94932906858384, 87.45562861042639, 86.2114606365081, 86.93001531785535, 88.50369376520958, 88.60715804561492, 83.1528591340588, 77.37072852350052, 78.44692491715955, 77.57887301906463, 83.54313496620425, 85.43554521376088, 85.02184498694636, 78.30096567830732, 76.58990229329756, 77.21646954936367, 79.78922274804886, 76.54643458704795, 80.78934084984564, 77.58511743237896, 79.48906729298254, 80.95779095926594, 82.12283688206827, 80.22146794103807, 76.89519605328961, 76.5153694152832, 73.42306690831339, 75.82852317440894, 75.51316461255475, 72.116344974887, 73.5724150749945, 67.89337219730501, 64.98943759549049, 75.34290236811485, 70.69520750353414, 74.8651655258671, 78.05784933028683, 74.9538032470211, 70.9492515748547, 75.12097466376521, 68.72173755399643, 69.81417256016886, 66.52695178985596, 67.19320558732556, 72.59862392179429, 68.55012601421726, 67.59934348444786, 73.0660919989309, 69.77195216763404, 70.72154229687106, 71.82052766123127, 71.72053860079858, 66.95975395940965, 69.63033891493275, 72.87719849617251, 72.95315911692958, 74.35357862903227, 75.46453506715837, 76.11707625850555, 74.43412842289095, 68.86797135876071, 63.536356341454294, 69.32815951685753, 75.32041934228714, 70.58569492832308, 75.27262918410763, 69.27928678451046, 61.518563608969416, 65.77859493993944, 69.32632384761688, 72.12298162521856, 70.48070092355051, 75.062515658717, 74.31571991212907, 70.96871437564974, 76.42553929359683, 78.9944407247728, 76.58474829889114, 71.0395602257021, 69.538178905364, 64.16283338300644, 66.17265978167134, 62.911832640247965, 67.70855795952582, 75.70365844234344, 76.69228399953535, 65.47232843214466, 67.48906996942335, 70.70559393975043, 25.927604244601344, 21.501990056806996, 7.238727779157701, 0.06347895705051, 1.8037222710347947, 0.24739096542039227, 0.7932456799091832, 0.28722113298792995, 0.39218814082203374, 0.6054126879861278, 0.16558584456722583, 0.3817785381069107, 0.34756002587176144, 4.232268304594101, 14.61085242609824, 24.615300778419744, 57.058765965123335, 47.925479950443396, 31.33825698206502, 42.26710404119184, 33.24689211383943, 53.33779773404522, 30.962435084004557, 0.2487176764876612, 0.21108054285568578, 0.08112323365264362, 0.05548343911106068, 0.014048160294130927, 0.08533271059634225, 0.059816198753974134, 0.01739186978328132, 0.02642606122178897, 0.04943693695109218, 0.015286171786306847, 0.10569695173011673, 0.059904252899990934, 0.0052897624235840575, 0.06697622503364278, 0.033401736103358774, 0.014051098241320541, 0.017468024668614232, 0.019048278280083212, 0.01796196751867331, 0.05191823828124231, 0.027459423816312226, 0.05861742053962043, 0.03879114166803418, 0.06825953722000122, 0.04103098357576997, 0.058777100076117826, 0.0233735628200755, 0.2831626443132278, 5.28973832245796, 70.69634499088411, 66.12436756010979, 77.82106368772446, 36.7009352099511, 53.041858826914144, 104.33660768693494, 42.96249320430141, 1.2142477665216693, 0.47032564638122437, 1.1330696579910096, 1.4229009444675138, 2.0126646012067795, 0.3158445986768892, 0.04544973275774429, 0.052488479658120105, 3.6464348627674967, 0.09009515746466576, 0.13343897197515736, 0.10396333306186623, 26.951083983144454, 66.36833898482784, 81.06134937655541, 101.06270728572723, 88.3770953455279, 90.39448799625521, 75.97779289368661, 84.31060160360029, 82.01654065039851, 80.22907733917236, 88.47939075962191, 93.99610242535992, 88.7172354421308, 91.81495866467877, 93.83949002911969, 88.77078363972326, 91.30664302456765, 88.02532149899392, 92.54185230501237, 88.88210834995394, 92.96926513794931, 87.34212306237991, 78.69758006065123, 78.18413396035471, 79.02891835858746, 89.39866881216727, 89.32655211417907, 85.95580839341687, 83.8020113975771, 83.03569793701172, 80.78279833639823, 84.46809261075913, 81.21666739063879, 81.57665468031361, 84.03618474160471, 79.76411957894602, 84.36778191597232, 84.16546606248426, 81.89989720621418, 81.17785161541354, 79.2053779478996, 77.45651075916906, 76.44207600624331, 77.64339600839924, 77.40063267369425, 78.17031152786748, 70.6556543227165, 69.1906019949144, 76.93815385141681, 73.40752647769067, 75.86363623219152, 77.23612062392696, 77.32973191045946, 74.70992595918717, 80.47577088879001, 70.75460003268334, 71.78397117122528, 67.86351511555334, 69.15832873313659, 75.05188603555003, 71.45226417049285, 70.08003865518879, 73.3393870630572, 72.89861463731336, 71.09010388774257, 73.00680929614653, 73.93743084323022, 69.462265353049, 71.73232924553656, 72.63504705121441, 74.53404688066053, 74.67454618023288, 78.4437007288779, 77.84340550822597, 75.75794404552829, 70.45573111503356, 64.48445597002583, 67.63044003517398, 75.98068760287377, 73.58247203211631, 78.44500295577511, 73.34789860633113, 70.2198633070915, 65.9397808198006, 71.16570365044379, 77.18106623618834, 73.88720097080355, 77.50811346115606, 73.91221784776258, 72.43705364965624, 75.58828584609493, 80.47789681342341, 76.80047081362817, 75.47633355663669, 74.29695529322471, 71.09848207043063, 72.42442361770138, 65.66859991319718, 67.50755217767531, 73.3878126452046, 77.58792584942233, 77.05254585512223, 66.54690096455236, 82.4133119275493, 53.631002749166186, 30.665721508764452, 13.66998858990208, 0.05373218126835362, 1.4336511805172891, 0.5711599162990048, 0.9358798520218943, 0.5189289609270712, 0.609113505530742, 0.531893007216915, 0.19556907035650747, 0.3087819421723966, 0.8515938780000134, 5.426631002656875, 26.63719827128995, 26.404813528060917, 74.12084087248772, 56.93042993545533, 32.616969270090905, 44.72803438863447, 41.0040694667447, 58.89889494065316, 36.80556051192745, 0.11080997575434948, 0.22199116707328828, 0.07001892708602452, 0.09230348251519666, 0.04451102607192532, 0.14745625126506054, 0.05996596511273135, 0.03775671229607636, 0.06353565138734638, 0.01813068114701779, 0.040244598151935686, 0.12627161423405334, 0.05379487407363711, 0.08044853235685057, 0.13819337492027592, 0.202579096620602, 0.2834587219742037, 0.19195782381200022, 0.18092772052172693, 0.18768340559496036, 0.1705366724561299, 0.1238843999923237, 0.15878753436188545, 0.15575227868412772, 0.17881273562389036, 0.20588349430791794, 0.16631137579679492, 0.20213985244833654, 0.32313024805438134, 8.057201408570814, 90.52484404656195, 71.20665319504278, 86.01418110632127, 89.84946681607155, 73.57487832346271, 110.30687870517855, 57.43908289940127, 1.9279925188710614, 1.1414371767351705, 1.9650972826826958, 5.092706391888281, 5.89135391096915, 0.36391226454607906, 0.24113388101179756, 0.1889041360587843, 5.110482083212945, 0.2900195602447756, 0.4001246278564776, 0.22020697894115604, 28.90742494213966, 82.1642884900493, 90.1757295670048, 101.57156421292214, 90.70528876396918, 96.53916328184067, 82.23157282798522, 93.38188279059626, 90.68388046756868, 87.13735964990433, 94.70852251975768, 100.86374898110667, 94.83877658843996, 97.59357483156266, 98.76320208272627, 96.16685974982478, 95.43740087939848, 93.35768961137342, 96.63219405758767, 95.44303340296592, 96.25627410027289, 91.2793747071297, 80.42881227308705, 80.9716526154549, 82.3545155986663, 92.64024103841474, 92.14872883212183, 92.09753405663275, 87.47969627380373, 87.40837973933067, 86.48420656881025, 89.74021311729186, 84.00634334933373, 87.01000813514956, 88.80825011960923, 84.08000546116983, 86.37953419839182, 90.54331056533321, 88.78658294677736, 90.05495194465884, 86.04605428634152, 80.94384301093318, 83.33010319740542, 84.09607933413598, 80.2365533767208, 80.54136860755183, 74.92417366273942, 71.54092542586788, 77.96351632764264, 76.40703355112385, 77.97313397930515, 82.34399580186414, 79.98495686438777, 78.63151950220909, 85.25342172191989, 75.88233809317313, 74.23387573611352, 69.4972764292071, 72.18885390989243, 79.50576874517625, 75.3582545249693, 75.13697008932792, 78.2684100058771, 76.00273132324219, 73.80415654951527, 76.39419171117967, 77.18597704364409, 73.90383182033416, 75.98628874747985, 77.28586412245228, 78.82526889924081, 79.09268040810862, 81.57315592611991, 83.3438628719699, 79.17006877160843, 72.24666180149202, 65.30941670940769, 74.40586382342924, 79.57412781253939, 77.13429589425364, 81.98618150526478, 77.5471253548899, 71.88281489956763, 68.9154085036247, 76.20977755515807, 78.80492748752718, 74.89441071787189, 80.14497387793757, 77.08357180318525, 77.24235719250095, 78.78029500284504, 87.63866209214734, 82.11040296862203, 79.0353588904104, 75.53071329670568, 72.11986726330173, 70.93341304409888, 69.00243020826771, 71.51135075476863, 76.44825766163488, 75.35614428981658, 76.9101167494251, 67.7210703203755, 78.69840375838741, 59.851419002779075, 49.49784048141972, 12.644589831752162, 0.1104148276030056, 3.2973446528757773, 1.2133267449755822, 2.0001648654860835, 1.3569008150408346, 1.5298515990857156, 0.7669536649219452, 0.22487485991610637, 0.4977660884539928, 1.707768961787224, 10.062036591191447, 43.763025422250074, 39.91322694286224, 87.26071034708332, 61.06661635060465, 47.19858631010979, 57.517644051582586, 49.127454988418094, 68.80351112734887, 43.16281257137176, 0.45634834155921017, 0.19060538751223396, 0.4250697989857966, 0.18810080093962533, 0.12919148940953518, 0.2425380588899697, 0.19880487253108334, 0.11127702125738706, 0.16670828595036463, 0.0959995273320425, 0.11800305106707158, 0.37072079436432936, 0.15382150728856364, 0.1914415724815861], [0.05253871204331518, 0.06063909975871925, 0.04436356946825982, 0.04155039118843214, 0.013953657603011498, 0.016894839598887393, 0.051286411096131614, 0.04784887881889459, 0.04249561345204712, 0.010572987244344287, 0.07287003820942295, 0.03889123871622067, 0.0682737251683589, 0.08154612950860493, 0.33504245562418816, 17.816358458611276, 71.60296163251324, 44.570013861502375, 46.875135898590095, 43.507702658253336, 60.20406753786149, 67.9218093810543, 2.3881760191532875, 0.9546469836946457, 0.3135725044675412, 0.326415233073696, 0.71468599861668, 0.74441499046741, 0.54134021963804, 0.16348788214306678, 0.201630434622207, 0.2513821149665502, 0.1699420350093034, 0.26649940458516924, 2.3294784849689854, 39.49103478462466, 57.31562237585745, 74.35015832224201, 78.40843077628844, 93.64058663768154, 78.0752960328133, 79.75123067055979, 82.85016982786118, 68.97368707964498, 79.46868665756719, 85.02154688681327, 84.66847081338206, 82.72246529979091, 83.35357466051656, 84.27449226379395, 86.99336159613826, 92.00670765292261, 87.84913647559382, 90.30622682263775, 86.19834423065187, 81.20857161860313, 76.08580712349185, 76.85822379204535, 81.76835660011538, 86.01603246504261, 82.99342263129451, 82.1048802714194, 79.09745001023816, 83.05145017562374, 79.07346079426428, 76.6203712647961, 78.07442526663505, 79.0600541330153, 78.81398816262522, 78.7723796598373, 76.88632365195983, 78.9415201064079, 74.72359934160787, 75.90509568491291, 74.09014440351918, 73.41264909313571, 74.06325263361778, 72.52690730556365, 73.87390413591939, 73.97684281872165, 69.29506255734351, 63.06313022490471, 66.54136257786905, 72.6598128964824, 65.5398912583628, 74.39108433261995, 73.18008392087876, 78.54890654163977, 77.90864236893194, 74.33680657417544, 71.47079344718688, 70.071393751329, 71.26173111700243, 69.13626932328748, 71.82212014352122, 72.92704397632231, 67.16690217295002, 71.11457947761782, 69.5498832579582, 72.43641822568833, 69.33465496186288, 72.37270324460923, 63.562812728266564, 65.73435060439571, 69.57128370961836, 73.82798887068226, 74.27984591453307, 72.92410219869306, 73.84535712580528, 74.17648361575219, 73.23839387586041, 68.3725916954779, 63.652144708941066, 68.2783842086792, 71.32925079714867, 70.6234359741211, 73.1604250015751, 69.82046404192525, 60.100140417775805, 65.48920246862596, 66.93952237406086, 72.43503755138767, 71.0218075783022, 75.36618555745771, 70.43371092888617, 72.90714187006797, 77.62222305420907, 75.803325868422, 71.8334871722806, 69.43104328647738, 68.41552595938406, 65.0630565612547, 67.51607941042992, 64.91484588192355, 71.18159709438201, 72.586621469067, 69.76240511863463, 61.340264428046446, 71.31572646479454, 50.47231412702992, 17.537160227375647, 22.41952265462568, 0.5960019413501986, 0.5682980569620286, 0.25554007249734095, 0.6197681338075669, 0.2924182428227317, 0.12769744175696565, 0.0288602385684968, 0.40302957197831524, 0.1334942835232904, 0.06378629237353321, 0.9016324123067241, 13.184057916364363, 10.787396584787677, 39.154522880431145, 74.49124597734021, 25.675319356303064, 32.2696747702937, 43.3688860554849, 56.03532937265212, 34.95500195410944, 0.07398129470886723, 0.05341356913108499, 0.10129130265164761, 0.053964371026884166, 0.1322810607211244, 0.2124739188941256, 0.019232951435110262, 0.045111209995323615, 0.11160941914685311, 0.07333978800283325, 0.05844852113495431, 0.056865852431304036, 0.08015777134606916, 0.19334920802183692, 0.018448224591632045, 0.025865620024682536, 0.15601320823113765, 0.014462971049661358, 0.03630466158351591, 0.04189921400299476, 0.007942685164556268, 0.12324925947694049, 0.05468691068310892, 0.03055935838229714, 0.0796132743538868, 0.08557693942660287, 0.14725107759717973, 0.1704069124835153, 0.3227200845797216, 22.47600478510703, 81.36939664040843, 59.15082093208068, 59.28675851514263, 33.17941557976508, 67.09201628162016, 84.35726996391051, 0.6880852195524401, 0.7848067004834453, 0.19350591896762773, 0.2897524100638205, 0.5313273278936264, 1.7951055592106235, 0.7162731489346874, 0.280012981064858, 0.07152860293224936, 0.2303842731541203, 0.14634741560345696, 0.13724051476005586, 3.14876968341489, 51.6442398871145, 67.06474796418222, 81.45841090909897, 80.04223915838426, 97.6400000049222, 80.47776345283755, 83.95968283376386, 85.3609181988624, 72.62958711193454, 83.34082695745653, 89.42599988752796, 86.6031720561366, 89.27299607184626, 86.61046766465711, 86.99911963555121, 87.41197263040851, 92.01310896104383, 90.22999948070895, 93.02672786097374, 87.9730284598566, 80.1347678707492, 80.11604247554656, 82.98043958602413, 86.2132727715277, 89.61167704674506, 84.33407306671143, 86.8216480747346, 83.74608624366023, 85.18483515708678, 81.71394548108502, 80.55969392099689, 80.1302493003107, 84.09445547288465, 80.32236699135073, 81.87351534443518, 83.77133846282959, 77.41978168487549, 76.19547659350981, 77.24977047212663, 75.54179791481265, 76.22382748511531, 75.871841830592, 76.5820183292512, 74.49247760157432, 77.90884633218089, 70.86498337407266, 67.93455708411433, 73.5296533953759, 74.81748519405242, 68.40614364993188, 77.43493772322132, 74.87091572053971, 75.9707796958185, 79.16742509411228, 78.53655892033731, 73.59256821293985, 74.51842015789401, 70.83450655783378, 69.3077475024808, 73.84082286588608, 75.36212198195919, 72.14293864465529, 74.7466471887404, 72.13811412934335, 74.1710864343951, 71.00216434847924, 74.3058982972176, 71.31165504455566, 68.94424576913157, 70.87043546861219, 77.7699395148985, 74.92842551200621, 77.06053180079307, 75.79312770597397, 75.309217053075, 72.27791524702504, 72.78092784266319, 66.48608853740078, 66.92704139217254, 72.6521642746464, 73.04091822716498, 74.22079070921868, 76.95825207617976, 67.23517494816934, 66.33084112598051, 71.64938680587277, 75.54993291055003, 71.51215876302412, 76.83831384105068, 72.29443627019083, 72.54837051514657, 75.49217993213286, 75.77892088120984, 73.81780639771493, 72.83644507008215, 74.34967979308098, 71.9662280236521, 68.30245187205654, 67.8966748329901, 70.04876167543473, 68.29957285235005, 75.84873907027706, 67.48593207328551, 72.7923890083067, 73.23501279277187, 38.52942259080949, 29.89895305325908, 3.8267673023285407, 0.47189180589010643, 0.40740148254459907, 0.0803353735095551, 0.09318828342422363, 0.17723451789108016, 0.056837200742935946, 0.4516279529179297, 0.13785862514088232, 0.10246249020940836, 0.24695306956287355, 20.53764985453698, 14.339192990333805, 50.516876174557595, 83.52469198165402, 31.472631500613307, 36.66930913925171, 51.72208716792446, 64.95206917485883, 41.180705562714614, 0.06397935036089152, 0.051167897294245424, 0.11089822142234734, 0.06331639319297767, 0.04063023915213924, 0.12935091230657794, 0.05149868256863087, 0.1253660293596406, 0.029384269521781997, 0.06905966243075748, 0.06172036391592795, 0.04955426714713535, 0.10518675249430443, 0.10854895151550732, 0.08964439133001913, 0.2037580446490357, 0.20462183942717893, 0.12452137145784595, 0.3081900932856145, 0.2297382158858161, 0.26058042542107646, 0.15084502587635673, 0.2973164557929962, 0.19391143994946636, 0.1466691418881378, 0.24049061230353772, 0.27532063124160616, 0.3669614477023002, 0.6547888933170227, 29.329266048246815, 96.00415199033677, 65.22733326881163, 67.48370416702764, 64.79450364266673, 79.56214889403313, 109.63018355831024, 9.617866412285837, 2.969917203149488, 0.7161951305404787, 0.8729497739864934, 2.696642976614737, 4.891024001183049, 3.3989617420781046, 0.7830770578115218, 1.0188033539922008, 0.48148675070654967, 0.41187329097620906, 0.4332752441686969, 2.6274702625889934, 62.74784226571361, 77.37276815599012, 89.44654526249056, 85.01575746843892, 99.92077196798017, 85.6581554105205, 90.77207888326338, 91.89333546546199, 80.31634223076605, 87.64777768042781, 95.42384516808295, 93.3392152478618, 93.59180804221862, 92.53404678836947, 94.05762087914252, 93.26781242124497, 98.9087926187823, 96.09702587127687, 98.78762275941911, 92.40432616203063, 83.67212603169104, 81.30768991285755, 84.18539954769997, 87.67645805112778, 93.76473749837568, 88.77793804291757, 91.58688852863928, 86.99722120838781, 88.50796130395706, 88.3168948081232, 86.83197175302814, 83.74843182102327, 86.53811562445857, 84.84702494836624, 85.67577469733455, 84.82109023678689, 83.49836503305744, 81.26379859062934, 83.93072005241149, 81.52140417406636, 84.29179776099421, 82.78665096529069, 81.07763505751088, 81.12944172274682, 83.65706413022934, 77.07820600078952, 70.9894323348999, 72.99300255313997, 75.04391577935989, 68.84016959897934, 81.80868641022714, 81.13494088572841, 83.6145377928211, 82.8189399165492, 80.29439264728178, 79.10336494445801, 79.11441033886325, 72.51568148213049, 74.04124029221074, 77.84098148345947, 77.90683807865267, 75.45695704798545, 78.54106180129513, 75.39773710312383, 77.51902549497544, 73.27570346093947, 76.62412105068084, 73.61167800041937, 72.33178507897162, 74.8262869927191, 82.48050212860107, 79.9903932694466, 79.89870394429853, 79.80292750943093, 80.41452700091948, 76.80827633027108, 72.93707739922309, 67.20962462886688, 72.50782105230516, 78.24819411000898, 76.40295428614463, 79.58188626074022, 79.66586420612951, 70.58320814563383, 69.63716383903258, 74.41596000425278, 77.42379819193195, 74.89229263797884, 81.5762467538157, 75.95397626200031, 78.66499300925963, 80.94924019229028, 79.70529971584197, 78.65600293682468, 76.27825429362636, 76.05441247263263, 72.63368206639444, 70.61225721913, 70.54194481142106, 73.42849546863188, 69.43543634107037, 74.66350863056799, 69.33679657597696, 69.9048734480335, 74.52815548066171, 50.85327433001611, 45.66226059390653, 2.311675091904979, 1.0480191895077307, 0.8501305274905697, 2.657567834661853, 0.7289917406535918, 0.3889438197497399, 0.18581932981408414, 0.903831207223477, 0.5707090275902902, 0.23640765478053402, 2.0884400125472777, 31.29342821336562, 24.28704938580913, 66.17881005810153, 92.70590935983967, 34.68497422433669, 45.31604474590671, 61.784504229022616, 69.7049580850909, 48.12126505759455, 0.39628802888816406, 0.17518014586981268, 0.2620985358953476, 0.32301515100463746, 0.20679094077598667, 0.28872312497227426, 0.16186072671365354, 0.256949704921534, 0.13489686793858005, 0.1760876689466738, 0.1730311160246211, 0.11919165180335123, 0.20167042441185445, 0.2639566055468975], [0.06411257688136351, 0.06465839537521524, 0.037964816250267534, 0.09474096744651757, 0.03159027524112213, 0.09658678735215818, 0.14494981075967514, 0.03395647952152837, 0.07265307444838748, 0.030796290225078984, 0.1308662495425632, 0.03403588070444042, 0.08833703164371752, 0.030791456210276777, 0.05108943839948024, 43.64390304011684, 55.765282031028505, 49.83348161943498, 34.352941666879964, 32.76862379043333, 81.74432031569943, 25.02484525403669, 1.8422332045532044, 0.3162230154679668, 0.37311917050711574, 0.25686146691441536, 0.4099491845455862, 0.11632805344678702, 1.0270488502517825, 0.2800624703447665, 0.1330318881739532, 0.019149505307958014, 0.7941064563009047, 0.15270190043074472, 15.042512205339248, 49.64939694250784, 58.68988752365113, 77.34789248435729, 65.87588540969357, 77.37260341644287, 71.57586589936288, 76.09002759379726, 64.43143729240664, 70.39604048575126, 76.61500546240038, 82.65126643642303, 83.74089302555208, 84.52451982805806, 80.79512242347964, 83.46890803306334, 90.11918467860069, 86.84825743398359, 88.13695215409803, 91.09292091861849, 79.01602160546088, 83.46242827753868, 85.917478992093, 85.08355955923759, 82.31878280639648, 78.60377265561011, 81.6046525586036, 83.27224039262342, 85.01525540505686, 78.99887300306752, 78.77875743373748, 74.6966605032644, 76.3425890091927, 76.6947550927439, 75.05012881371283, 76.90118943491291, 76.04164908009191, 70.33376893689557, 71.65661965647053, 71.45690041203653, 73.51645854211623, 71.60485221493629, 72.21967589470648, 72.49492429917859, 71.77507523567446, 74.85540666887837, 62.13552890285369, 64.8882600568956, 71.6064525419666, 64.14763419858872, 68.31694110747307, 63.192270340458045, 62.708822527239406, 65.56954045449534, 73.39193113388555, 68.95703269589332, 66.70306621059295, 70.96716896180185, 71.50967198033487, 73.17492208173199, 76.53402420782274, 75.55092134783345, 70.48820049531999, 71.36287335426577, 72.48679714818155, 73.70449696817707, 70.87870382493543, 73.01376758083221, 73.21234933791622, 69.0611167107859, 68.84948130576842, 71.52367484185004, 68.79946324133104, 75.62090427644792, 72.8229050482473, 73.29855518956339, 73.29408368756695, 71.28098210980816, 70.41384020159322, 66.15463256835938, 69.3066963072746, 69.59308424303609, 65.52895961269256, 74.440184562437, 68.62276046506821, 60.95615063944171, 63.88300757254324, 64.90743652466806, 70.00822005733367, 70.83409863133585, 71.67448997497559, 70.71809061111944, 75.26607098117952, 76.8573530258671, 77.65855989148541, 69.93042376733595, 70.3385228495444, 64.81876742455268, 66.55804049584174, 65.93670568158551, 65.78881271423833, 77.89088972153203, 70.42843926337459, 60.328732229048214, 64.3491381214511, 63.367592442420225, 30.275708475420554, 20.93060858788029, 15.74034990802888, 0.3570899757887087, 0.4338662656805208, 0.12460582499061862, 0.21587397031966718, 1.4271014351998608, 0.2554575188626205, 0.16496145226542028, 0.12712711227997658, 0.17682953317078853, 0.5439084527953979, 5.008471040956436, 4.108457954660539, 13.721692292921006, 70.47504486576204, 27.093477787510043, 33.812372376841886, 35.16189521358859, 51.47075737676313, 40.630334269615915, 0.03697655516706648, 0.05742522302053629, 0.02856177071319713, 0.0968166826773555, 0.060885887322646964, 0.11515561716570971, 0.1269818083833783, 0.049456625410746184, 0.036114131686307734, 0.10265778900394518, 0.016064879093920032, 0.035339766182005405, 0.11504138579532025, 0.02450022917811669, 0.10582683427679924, 0.012499913836138384, 0.04615579386271777, 0.10364747501068539, 0.05207246710215846, 0.036587485923401775, 0.06006865919898114, 0.018187775764794602, 0.089794919946261, 0.051355381991954586, 0.09137519079470828, 0.034323600346162435, 0.014505331881434448, 0.026037731252971198, 0.17173212201845262, 51.81652999693348, 65.75281320079681, 61.060826932230306, 38.77763017531365, 30.280836974420858, 98.09450072626915, 34.73853418903966, 1.1433175855105924, 0.255602861063615, 0.12412962473688588, 0.22337757171161715, 0.2069684893133179, 0.18309807825473048, 1.4872514720885985, 0.40832569101645105, 0.26162058896114754, 0.04478689816389834, 0.4506900161504746, 0.035337023587236484, 18.526334916391683, 62.29490264769524, 68.36670814021942, 83.09673001689296, 69.83180753646359, 79.18906088798278, 76.45836953193911, 82.90564783157842, 70.27716913530904, 74.39410455765264, 77.82396624165197, 89.43416626222673, 87.12644761608493, 87.65295520905526, 85.11675850037606, 91.43725010656541, 91.58120109188943, 87.95825681378766, 90.01987811057799, 91.95831344973658, 78.00424621951196, 87.16945248265421, 89.17908668518068, 88.4048657263479, 87.38605360830985, 84.15705650083481, 85.64672562383836, 84.9479789118613, 87.76205201302805, 81.22669296879923, 82.65525156451811, 79.38676403414819, 78.44324573393791, 80.1587963104248, 78.05930845199093, 76.63335431006648, 78.1826199254682, 76.0966250204271, 73.5856334624752, 72.074916901127, 73.16231558399816, 75.55935444370394, 76.47097602967294, 76.27044877698346, 75.7623214106406, 74.67312628223051, 66.56892115069975, 68.02852922870268, 76.0402919400123, 69.00092401812154, 67.56030021175262, 66.30603605701079, 64.54685695709722, 66.13321642721853, 73.94991182511853, 73.39737538368472, 69.16240015337544, 74.19040018512358, 72.60786502592026, 74.10630456862911, 76.54470874417213, 76.00488862683697, 74.30161506898942, 76.17274253599106, 73.77928087788244, 77.31049660713443, 72.16247204811343, 74.34057204954087, 75.69870056644564, 73.01201035899501, 72.21064659856981, 74.00588404747748, 71.51349236888271, 77.12005769052814, 72.43266843980359, 74.676938826038, 76.6938372581236, 74.56947372805688, 73.36149354134837, 68.82839464372205, 68.09076939859699, 74.4352972892023, 67.28830737452354, 74.50478599917504, 74.12293541815974, 65.43956879646548, 66.30867188976657, 69.70249483662268, 72.9025605417067, 73.0601692199707, 75.5685406346475, 70.37586381358486, 73.65916221372544, 77.46032330297655, 77.5741897090789, 75.9813779400241, 73.41496329153739, 72.64824190447408, 71.11763108161189, 67.66352914994764, 64.25172605822164, 73.47480297088623, 70.94989484356296, 71.80217096882483, 62.83359704479095, 75.62041005780621, 61.39991191125686, 32.42176075135508, 24.088644135382868, 0.6931174366224198, 0.3497996379531199, 0.16756130953229245, 0.050390563199236516, 1.6467021934447752, 0.763663838226949, 0.2251910550459739, 0.1141017176691563, 0.04207976560498919, 1.5463870859915212, 6.683051970697219, 4.8967722346705775, 14.801650239575295, 88.2830447535361, 28.315129395454164, 29.05267030962052, 46.40593021146713, 57.60449709430818, 48.942205367549775, 0.15113045491518515, 0.057083950002467444, 0.06379827398866897, 0.038755629662304156, 0.052896252938456116, 0.12361034735917084, 0.08474423249642696, 0.027331529267793222, 0.045270391574670235, 0.021958987213551037, 0.0625939569586227, 0.06229023374016247, 0.04792702744805044, 0.05463086752100818, 0.1727966318327573, 0.15086924957652248, 0.164805767877448, 0.22206189231045786, 0.20341961764760558, 0.2160841388808143, 0.2780641453160394, 0.18265403837205904, 0.2098826264902469, 0.17156897593409787, 0.13258676044642925, 0.2807940843124544, 0.1632924071483074, 0.14426918760422738, 0.3367929665311691, 63.86764757094845, 76.32143174448322, 68.39322336258428, 47.09714597271335, 50.2361011505127, 105.91525969966766, 57.07524776458741, 3.8888787694515723, 0.556901058843059, 0.8760941665499442, 0.7854793256809636, 0.9022486534330153, 0.8316168177031702, 5.439504221562417, 0.6422316090714547, 0.6772874247643256, 0.15224734982175214, 1.2416716304517563, 0.4038883258979167, 20.199829839891006, 74.75430365531676, 75.75835197202622, 89.47637881002119, 79.90683109529557, 92.14670488911291, 83.31073453349453, 89.44598828592609, 82.51084558425411, 84.75757921895674, 85.49650669097902, 92.81811268098893, 94.39299921835624, 92.5244212919666, 90.53890966599988, 93.06508864125898, 97.25474480659732, 94.3774195640318, 95.1309774767968, 96.69339087701614, 82.310804705466, 88.45706462860109, 91.76290881249213, 90.77678572747016, 90.55112392671647, 86.73306526676302, 87.81729467453496, 92.09634165610038, 95.41367838459631, 85.15908087453535, 86.45151753579417, 83.11358051915323, 82.58491562258813, 84.95830259015484, 79.90984347558792, 81.18592385322818, 84.65966116997504, 80.90933399815714, 77.94307293430452, 78.78581770004766, 78.20203565782117, 82.8207520515688, 80.86050833425215, 82.20711292759066, 80.20136971627512, 79.94381120128017, 69.67601883795955, 70.58177255815076, 81.12864155923167, 71.03319814128261, 71.94841261832946, 69.51919463373, 69.26270300342192, 71.1823501894551, 80.23832628803869, 80.1814832995015, 73.61478451759585, 78.4938286196801, 78.81987956262405, 79.01311120679303, 82.82687879377796, 82.02631519686791, 78.42435559918805, 81.01574790093207, 77.66932287523824, 81.28588153469948, 76.88014199656826, 76.41312106963127, 80.30847395620039, 77.20080360289543, 73.9816673340336, 78.17089988339332, 73.35229950566446, 81.44216445184524, 77.77871777934413, 79.53262129137593, 79.78393539305657, 78.01001994840561, 77.58011248803909, 72.65797722724177, 71.63358749881868, 80.26649675061627, 70.98004218070739, 79.68156153155913, 77.72457338148548, 69.15846209372245, 68.66863650660362, 70.04970304427609, 74.64856440021147, 77.28866469475531, 77.07331088281448, 74.00167142191242, 80.68204049141177, 83.08067183340751, 82.52113788358628, 79.66863339947116, 75.1090741926624, 72.65035213962679, 74.28763574169528, 71.33005096066383, 66.61256144123693, 78.42765039013278, 68.91061536727413, 71.7008561472739, 65.74251697909448, 71.52432595529865, 66.96533156979469, 50.57579017454579, 28.670125469084713, 0.7460123757200857, 0.983704821236672, 0.3663532658209724, 0.456153663295892, 1.9473946455024906, 1.0015389803917178, 0.31103384230406056, 0.37735744469588806, 0.3568375344958998, 2.5857154063640104, 12.47479631054786, 8.886384579443163, 23.981226105843824, 99.32940406184044, 39.044453328655614, 46.64357485309724, 50.2835657519679, 67.12902776656613, 56.64778001846806, 0.3672987408936024, 0.19479951971480924, 0.11189548403865869, 0.26510080382708584, 0.2563568447986918, 0.2967286212069373, 0.2180511002699214, 0.16541793341598204, 0.15197264601386365, 0.1687790675749702, 0.10010420344769956, 0.1302709685818803, 0.17317711706123046, 0.12148701210295963], [0.04821926700852571, 0.055051897952873866, 0.14422429485186455, 0.0787220766106921, 0.07849117771031396, 0.12410714005630825, 0.1258775309449242, 0.10911111449522358, 0.06393210188816152, 0.027711583571808956, 0.08211204631915016, 0.12270895298570396, 0.06362464782151003, 0.2516707462529021, 5.172813448213763, 59.588208352365804, 57.979432536709695, 50.13498244747039, 43.71718075967605, 50.18373358634211, 63.51517554252379, 1.7730713996195027, 0.3592269320882136, 0.0906558878599636, 0.16503101304894494, 0.23652410014502465, 0.22767017685597946, 0.2487939022361271, 0.16143637529063612, 1.427491833606074, 0.515029144383246, 0.2504245969917505, 0.6448489331430005, 0.7581212840253307, 34.709343910217285, 61.65429722878241, 64.14068768101355, 66.12475979712703, 58.07316149434736, 49.490595863711455, 69.82317832208449, 72.57800794416859, 56.591188061621885, 67.06910179507348, 74.9847193687193, 83.20148867945518, 82.26205748896446, 86.76152598473334, 83.45047289325346, 87.06906334046396, 86.85620415595271, 86.1656238186744, 95.21416310341128, 84.15146320096909, 80.78016250364243, 89.62044746645036, 83.56195449829102, 84.18624677965718, 79.39074131750291, 76.15200104251986, 78.00263020300096, 80.52307467306815, 78.02374824400871, 79.26773578889909, 77.93712662112328, 75.22828286693942, 72.22319818312123, 77.12404281862321, 73.32332887957173, 67.1500281364687, 71.80957640371015, 69.50752166009718, 68.10284245398738, 70.98150914715183, 70.3707568876205, 71.13481890770697, 71.85761759358068, 70.76101703028526, 70.36515574301444, 65.67128673676523, 59.84826149479036, 58.9768010570157, 60.347092843824825, 56.50825738906861, 59.701929630771765, 55.93150031182074, 64.72697611778014, 65.99459986532888, 72.34430528456166, 66.88037303186232, 62.48276848946849, 64.3963752254363, 65.32385495401198, 73.74941595139043, 69.66591481239566, 71.11504231729816, 71.22369981581166, 66.6400101877028, 68.08864347396359, 69.64906431013539, 70.98508634874898, 69.5655256702054, 72.17378416369039, 67.03411425313642, 68.72227884108021, 69.48536811336395, 70.66973563163512, 71.31273761872323, 70.9770219556747, 73.11823598800167, 72.72420252523115, 72.38151288801625, 73.20164911208614, 66.70370163456087, 66.96031878071447, 65.77654354033932, 65.88514220330023, 68.43898957775485, 71.95739484602406, 60.78746911018126, 60.52499978773056, 66.80568325904109, 67.70167027750324, 69.07047548601705, 69.84388843659433, 71.51952497420773, 72.31591516925444, 74.37405340133175, 77.77742339718726, 75.97382345507222, 66.23734751055318, 70.48656094458796, 62.5683859855898, 66.35031177151588, 63.97643843004781, 71.57996869856312, 76.07436949206938, 65.61926041879963, 58.25668919471003, 65.66100620454358, 58.47001514127178, 17.46714395861472, 26.438810671529463, 6.204627242780501, 0.251330649179797, 0.5499845719145191, 0.13219607092680472, 0.9643188743822038, 0.17197302602712186, 0.10013933623990706, 0.04555244216575258, 0.012398722239830082, 0.8553137558121836, 0.80270582389447, 0.21072665619994366, 1.9894994506912849, 49.227043967093195, 45.278664558164536, 39.537146168370406, 37.88183927536011, 43.11832897124752, 46.7780533144551, 1.0248599225474944, 0.14173692993579373, 0.03749418545574431, 0.05731980549171568, 0.19337291078221416, 0.13797488664427113, 0.1128255530831314, 0.11166974857089021, 0.02218900319759644, 0.0358514477979512, 0.08299004436740953, 0.05728338567179538, 0.09145638079292352, 0.11247146724452896, 0.08105220964118358, 0.055676608181168, 0.012208229689408216, 0.10006479588487457, 0.055385372195873535, 0.10145827151474454, 0.15326793215447856, 0.0708186462701809, 0.021682458201182947, 0.08897677634752567, 0.08110141546856012, 0.15082213516917922, 0.03661014297376237, 0.3662765038109595, 6.103129050424022, 71.60633487086143, 68.97339682425223, 70.65315185054656, 27.60818296863187, 51.05964591426235, 78.67044510379915, 3.9432577740761543, 0.546102712471639, 0.24231687398447146, 0.11724971084585113, 0.12761272775429872, 0.1622427747614922, 0.1864464953541756, 0.46874425704440764, 1.7528237570678036, 0.7790587734310859, 0.6803498152763613, 0.702811329355163, 1.2598603963851929, 45.40149750248079, 73.20956445509388, 71.68884584980627, 73.27393839436193, 72.76443035371842, 59.858192936066665, 73.53737261987501, 77.59788866966002, 63.46428671190816, 71.31687179688485, 80.57745441313713, 84.06379038287749, 86.89557690774241, 87.0098747745637, 85.96160565653156, 93.17455414802798, 87.72118876057287, 90.05497547887987, 95.37587458087553, 81.47975644757672, 83.13734223765712, 89.9741981875512, 85.72097609120031, 87.79639628625686, 84.56300612418883, 82.43982714991417, 79.67639184767201, 84.33063707044049, 81.26671683403754, 81.26308471925798, 80.58922152365409, 78.87123123292001, 78.35551015792355, 78.64855827823763, 78.37329418428483, 72.49902709837883, 72.29125130561091, 74.7684947906002, 68.98105329082858, 73.75036516497212, 72.97811323596586, 73.43148431470318, 73.18713634244858, 74.92605640042213, 72.61276798863565, 64.7396767523981, 63.52973538060343, 63.70209217071534, 64.43027627083563, 63.69813449921147, 61.1328455709642, 61.945388086380504, 70.26509607991865, 66.70106580180507, 73.37762232749694, 68.16030517701181, 66.11313389193627, 65.30696130567982, 68.40943059613629, 73.1827825115573, 71.03813248295938, 71.62320890734273, 71.99628906865274, 69.6266205080094, 69.91445187599429, 70.03171505466585, 73.79289150238037, 70.51326444072109, 71.64587236219838, 71.0423529532648, 72.96076851506388, 69.73611739373976, 75.9590204300419, 74.95194404355942, 70.62044712804979, 75.52275088525589, 73.92371039236747, 74.2708009289157, 75.3273384032711, 70.51209557440974, 68.37780844780707, 69.26924551686933, 72.55062195562547, 70.06631820432602, 70.14274166476342, 67.42122081018263, 65.19308313246697, 66.77494756637081, 71.32139036732336, 70.83172167501142, 72.75984902535716, 73.6250062142649, 70.1146339601086, 73.18120571874803, 75.00181305793025, 77.95608735853627, 73.08763365591727, 75.84026675070487, 70.35252571105957, 67.65425666686028, 65.7004613261069, 69.49514265983336, 70.90595645289268, 74.72395235492338, 68.84615513586229, 64.36908729614751, 80.52895822832662, 44.74206862911102, 32.12864398956299, 13.269213553397888, 0.07497766866318642, 0.5009020234067594, 0.05420250945814675, 1.039281619652625, 0.1159892357405155, 0.23984334461631315, 0.07876730644174161, 0.06391093870925327, 1.5355365843542161, 0.8456281368290225, 0.33682701147852406, 1.4806639739582617, 59.933070982656176, 48.025214056814875, 29.35623626555166, 52.81160000831851, 48.34849972878733, 55.39837568036972, 1.1133856110034452, 0.06341088630799806, 0.1486943259594902, 0.06093157297601143, 0.044349370028583274, 0.11914661349428278, 0.13494779746378624, 0.053700289028065826, 0.1487723596754574, 0.015919078197780878, 0.016074847813034733, 0.08811909495101822, 0.0938019581559685, 0.04256147403089751, 0.1768947119313863, 0.19983124648851736, 0.23136823648406615, 0.20260160428381738, 0.23298085156467654, 0.22291591180668724, 0.25439783540223876, 0.1737756462347123, 0.23200727638698396, 0.17520570256296666, 0.25102954598203786, 0.2323237779520212, 0.3198849770330614, 0.7022143936445636, 8.574711084365845, 83.28906736066266, 80.01104062603366, 66.71462935786094, 61.691728407336825, 72.89715551560926, 91.57880060134396, 11.606680673937644, 1.7255409758898521, 0.778358017484988, 0.45752934270328094, 0.42317002350764893, 0.5305854483477531, 0.354311773253064, 1.287673800703018, 2.8477687124283086, 1.356472418673577, 1.2364635808813957, 1.0560046448822946, 1.7788604502716374, 51.25083008120137, 82.29573495926397, 77.10958496216806, 81.80933752367574, 84.74998551030313, 73.35082469447967, 86.40655148413875, 87.84797545402282, 74.2114790024296, 80.07481836503553, 82.31248347989975, 87.88762277172458, 90.50334161327731, 93.18368542578914, 90.10254598432972, 97.24853177224436, 93.27811256531747, 94.67229550884616, 102.01881639419064, 84.59257295054775, 85.66468223448723, 96.96368925033077, 89.82907833591585, 92.45905107067478, 89.20391528837143, 83.76682773713144, 84.3743714978618, 87.65140979520737, 85.40618235065092, 86.66614963162331, 84.86149064956173, 82.61430201991912, 81.25703642445227, 84.6954567201676, 82.68856033202141, 76.54457538358628, 77.80071443127048, 79.42843529485887, 73.07982029453402, 78.3661711600519, 79.46101450151014, 78.98945146991362, 79.44914540936871, 80.32355939188312, 78.91511471040788, 71.2476811870452, 68.24596974157518, 66.46428015924269, 66.86186728938934, 65.17696611342892, 63.8537702252788, 63.610430302158484, 73.47127283773115, 70.68406012750441, 78.41128626177388, 72.25774641959899, 72.59732169489708, 69.77617263793945, 72.71889948075818, 79.84169621621409, 76.56874502858808, 77.849210616081, 76.77870165917182, 73.9316100458945, 74.14705014997914, 75.5081125997728, 79.77922070410945, 74.52756712513586, 77.43588693680303, 74.67635047051215, 76.14555266595657, 75.4849313920544, 79.92696854376024, 80.17538793625371, 76.0806139053837, 80.53502221261301, 78.99873179774131, 78.50013579091718, 80.52520844244188, 74.1644968525056, 69.53762192879954, 73.99901205493559, 73.6405937133297, 74.32398826845231, 78.51665681408298, 71.90434871181365, 70.51256625883042, 69.92504227545955, 74.39728952223255, 73.389005045737, 75.94049115334788, 75.17194978652462, 74.31258201599121, 78.92102179988738, 82.94040003130513, 84.19774716900241, 76.04895253335276, 78.42029202368953, 70.41813911930208, 72.6120384277836, 69.43323196903353, 70.70107536931192, 74.26170103011593, 72.03963125905683, 70.4069289853496, 63.329298342427904, 80.96332934594925, 54.40093655740061, 55.36280762764716, 12.89281310573701, 0.29522022472754605, 1.5454017130597946, 0.41727362861556394, 2.1874249462158453, 0.33292554018478243, 0.41620891961839895, 0.2741323675840132, 0.09692439463950935, 3.3505851895578447, 2.5136097400419177, 1.0100594715725992, 4.210224584225686, 72.53679167839789, 62.94720065209174, 55.20239837708012, 47.20407370598086, 54.60171484178113, 65.778175246331, 1.4911146389861263, 0.3185903190845444, 0.3367768480412422, 0.2835265973642949, 0.22706444645600937, 0.22114436412530564, 0.18057846103704747, 0.1828580782298119, 0.3138489702776555, 0.10193890741755886, 0.11585818874018809, 0.1785136395764928, 0.1661612838506699, 0.18637166388573187], [0.08321290700546197, 0.01661505471284111, 0.08348885953666703, 0.0858553204565279, 0.11659800750954498, 0.16297277994453907, 0.02438617400794981, 0.007290819992176107, 0.04852697771463183, 0.1297390430925354, 0.02508070357444306, 0.08625471273497229, 0.06704950900447947, 0.2341607955074118, 17.263604325632897, 70.65363822444793, 34.586969883211204, 34.00496467467278, 44.67104627240089, 62.05994090726299, 25.537322528900642, 3.66522767370747, 0.08564754975058379, 0.14117877359592146, 0.11856668493560246, 0.18842211353682703, 0.11353384733440415, 0.34015437648180996, 0.23569643407339053, 0.6080569783526083, 0.24114302810161348, 0.45202996521707506, 0.44159955555392855, 4.335404576793794, 63.84120687361687, 60.465513121697214, 57.38816661219443, 53.92398418918733, 54.80038289100894, 46.817716321637555, 56.8249221001902, 53.685402101086034, 53.52540077701692, 66.14910987115675, 79.44057895291236, 77.94589704082858, 81.99691311005624, 81.29722502923782, 84.88854715901037, 86.58814153363629, 86.7681626350649, 88.01695900578653, 85.31154340313327, 80.77266293187296, 89.46035200549711, 82.85179368911251, 82.64754802949967, 80.60714675534157, 76.45585921502884, 77.45919366036692, 80.00838125905683, 79.22024373085269, 78.49713910010554, 74.39644229027533, 71.64458582478186, 73.47539132641208, 73.50390695756482, 70.71020664707308, 69.37329815280053, 71.3555855904856, 69.81207801449683, 67.92726932033416, 70.57128414030998, 72.53548945150068, 72.1066959442631, 74.93827066113873, 72.67424721871653, 72.1478965205531, 64.08911243561776, 58.077891872775176, 62.089401829627256, 61.79312167629119, 65.53386649777813, 63.07945120719172, 53.70791650587513, 64.04818250286964, 65.49638825078165, 66.2437488186744, 67.7447614362163, 64.91782296088435, 65.64715631546514, 60.22211436302432, 58.795795440673835, 60.56460395936043, 65.91780770209529, 66.52052694751372, 68.32660582757765, 66.55487122074251, 63.4935672052445, 65.52265244145548, 63.49332009592364, 64.0784514334894, 62.99517516166934, 67.54379487806752, 63.32069658464002, 65.25615092246764, 67.84260103779455, 69.48249693839782, 69.94816072525518, 74.12881112867787, 70.21485051801129, 73.2226808609501, 74.63471058876284, 70.84750529258483, 65.44968851151006, 70.26662580428585, 70.19967879018476, 68.6204933351086, 64.77739818634527, 63.37473507850402, 57.093961392679525, 60.22304004238498, 59.485406952519575, 65.56824214996831, 67.94017391820108, 73.51541519165039, 69.42702677942091, 73.21158055336245, 74.77050304412842, 76.30345944435366, 71.03345701771399, 65.79244090664771, 65.80940123527282, 62.86890622108214, 61.31893457904939, 69.3641511855587, 72.72085282110399, 75.56670496540686, 61.88140638412968, 61.16201623793572, 64.42748746564313, 40.891536666500954, 17.98918789432895, 25.21193054414565, 1.6438916926422429, 0.4283634254768972, 0.2908531251934267, 0.1023135933604452, 0.16555844926305358, 0.17040728020571894, 0.11024385210006468, 0.31728187155339027, 0.16556293853828985, 0.15901241181117876, 1.0489220700917705, 1.085067691822206, 24.86047244841053, 45.21562814712525, 23.9587156234249, 37.65481248978646, 37.00766455742621, 48.322247305224025, 0.4124918303662731, 0.21440852072931108, 0.031129044345429832, 0.1272140249549862, 0.032764829755310095, 0.0691461460965295, 0.14629817147168422, 0.14431568914123122, 0.04428481179920416, 0.012454422577584704, 0.0259794760119891, 0.14109170004244775, 0.08998627338798777, 0.03064700267127445, 0.08031614470265566, 0.10776429361994229, 0.08515667125222184, 0.03778002818205184, 0.05297989058758944, 0.19941869281953384, 0.026015003339477608, 0.05023003713558278, 0.04285284408157872, 0.21819426678121093, 0.028382496562816446, 0.10133859325921345, 0.10186332518294935, 0.3190587358849664, 21.716961437656035, 77.08245000531598, 54.07760381698609, 49.83696860651816, 30.51925628416, 74.23736664556688, 30.043600259288667, 3.8929744593558775, 0.04391944148547707, 0.14629682315693748, 0.06137614912022987, 0.13121063670804425, 0.1731869689519367, 0.1741463868247886, 0.1826968933305433, 0.7269063880366664, 0.23092375227039863, 0.5219481440801774, 0.2605153079475126, 6.718209645440502, 73.77139691383609, 63.64100910002186, 75.01713383582332, 67.93688697199669, 67.42152675505608, 56.882533873281176, 64.18660686862084, 60.8272340989882, 64.01629363336872, 71.3387115540043, 83.43660339232414, 79.41108272921655, 88.06865584465766, 87.54996945781093, 87.23185739209576, 90.07046884106052, 90.29982551451653, 91.77149095842915, 83.46792744052026, 81.19245067719491, 89.21492145907494, 84.26490599109282, 85.5752992630005, 81.94299620966758, 82.57343092272359, 80.99521821545017, 85.44860670643469, 80.55705808824109, 79.81660089185162, 78.34145238322597, 75.92844947691887, 76.43314084699078, 78.37592217230028, 72.30221040787237, 72.30751345234533, 76.16544692747055, 72.74461453960788, 69.9579038927632, 73.69601680386451, 73.57884776207709, 74.7112124966037, 75.55482802852508, 74.5239350103563, 71.77647944419616, 64.00088264096168, 60.58307440050187, 66.99816965287732, 66.60249663937476, 69.49323638792961, 64.6583228726541, 62.52308261009955, 66.80296897888184, 68.32908476552656, 71.26843052525675, 70.22853174517232, 68.51655052554223, 69.04035168309366, 64.86706749085458, 60.736564590084946, 61.5802271904484, 64.75756668275403, 65.56578674624043, 69.82772827148438, 68.57810820302656, 66.84434213945943, 67.5341615369243, 66.37522666685044, 66.31271193104406, 64.27335792972197, 67.51958600936398, 68.73121400033274, 66.26052871827157, 71.35717022803523, 70.52273304231706, 71.92231316720286, 74.45873737335205, 72.70831692603328, 73.13634164871709, 73.79939479212608, 74.58057403564453, 66.38836660692769, 69.18258467028218, 74.55526690329276, 73.81721019744873, 64.62891294110206, 66.89661164437571, 65.27806128225019, 65.7953199263542, 64.21286321455433, 68.24071376554429, 69.67378308696132, 73.9019569273918, 70.7536429743613, 72.78613675025203, 74.33873638030022, 75.79113514192643, 74.49832193313107, 73.0848801520563, 72.04680919647217, 70.60818579889113, 61.950220446432795, 70.51019714724633, 70.67264603030297, 74.89969022812383, 73.44181583773705, 66.97003056926113, 69.69344200626497, 73.82359581608927, 33.08163089136924, 34.532025321837395, 4.497478383202707, 0.4876421139605584, 0.1787541298976829, 0.10073040371700641, 0.08741817046557704, 0.04109908879223851, 0.06640630158325357, 0.27559286824637846, 0.1318126745642193, 0.17994565708983332, 0.8470131012220538, 1.550052050621279, 26.441699497161377, 58.1090158800925, 22.519794125710767, 35.4447804727862, 43.30528090077062, 60.01137718077629, 1.177920122300425, 0.016067252051265492, 0.04330971210654225, 0.05307453308975505, 0.014653206003018686, 0.06240878967688449, 0.0685997951715704, 0.05910659066191124, 0.029601786781342763, 0.0339231240533052, 0.02425372889716058, 0.14133585226391593, 0.08380865527977867, 0.03527609661461846, 0.19573414698243144, 0.1820319596557848, 0.21294192200706852, 0.23733000931960924, 0.16961270913241372, 0.3520108741377631, 0.1254117188434447, 0.18794160786895983, 0.18711512157272908, 0.28407336963761237, 0.10366289636060115, 0.24990773279099698, 0.4067010943207049, 0.3898680895086258, 26.76043521973395, 96.00991002974972, 50.41288629654915, 47.97489396987423, 66.76896202948787, 87.63132725992511, 38.72526653351323, 4.527514423093488, 0.11919299245721872, 0.18480279242559788, 0.578299610605163, 0.31341239209136657, 0.41692165717963253, 0.4649818460306814, 0.4005091427074325, 1.0663757593401018, 0.5452483099314475, 0.9150442216665515, 1.433354306124872, 6.427612516187853, 85.21582188144808, 72.14639817514728, 79.34990159926876, 79.34179013775241, 77.13348788599815, 67.56181424663913, 79.11440249412291, 73.74208896390854, 73.57242291973483, 77.76998658334055, 89.29543987397226, 83.09175645151447, 92.18336336074337, 89.81210231781007, 91.73582092408212, 94.52331604496126, 97.02717673393988, 96.03669981802665, 92.80874606101744, 87.19537150475287, 98.20885350627285, 90.79115729178153, 91.47423021255001, 86.45983296055948, 86.90266855301397, 87.0049168986659, 89.2593619131273, 86.21652833877071, 84.6429910967427, 82.3927116394043, 78.94325379402407, 79.5910410727224, 82.84940104330741, 76.93513362638413, 76.27061351653069, 80.25730271493235, 76.0247907330913, 72.28346147844869, 78.19126482932799, 76.8643819132159, 78.90778772292599, 84.7495226706228, 79.8029431989116, 80.73469438860494, 71.59270071214246, 64.02691541179534, 70.86914108645531, 69.22927656481343, 73.13750267028809, 67.91776933977681, 63.25524399357458, 67.94228415335378, 71.95141715388145, 74.00057315826416, 73.71749570292812, 71.15789028906053, 74.63744055840277, 66.7441177368164, 67.75117843381821, 67.48815997954338, 70.29358033211001, 71.47844206902289, 74.9482334813764, 72.42857348534369, 71.4154488040555, 70.72715128621748, 69.84609280863117, 68.93225900588497, 66.61635045082339, 71.21018332819786, 71.80530886496268, 69.39487118874827, 76.33086112237747, 74.64006070167788, 74.13246677767846, 78.35234088282432, 74.40642079999371, 79.52058745968728, 81.61468598150438, 79.07371967069565, 70.71713355279738, 72.95857983250772, 79.85918214244228, 76.48828937161353, 67.2877739321801, 71.60348723011633, 67.66778884395477, 67.88377807986352, 64.87752452973398, 72.0425416577247, 74.86782489284393, 74.99297203556185, 73.56061658551617, 77.52954529177758, 79.75187393926805, 82.93524603689872, 77.33963197277438, 74.78796543613558, 75.45977330976918, 73.55715705502418, 68.66099572950795, 72.13279539538969, 71.39510739234187, 73.12363316935878, 72.76677593108147, 69.35450215493479, 68.15154260204685, 76.99073714594688, 47.27533140490132, 50.71176305893929, 3.1869130173037132, 0.6358192692841254, 0.5458169310323654, 0.5086025860040418, 0.30365837677832574, 0.3449890960849101, 0.17844544242947333, 0.3386671240291288, 0.4148830665696052, 0.2818802131279823, 2.1316034899603937, 1.8439390678559582, 35.13867085979831, 64.23885676168626, 38.997686909091094, 46.318594717210345, 46.90319653480284, 70.91976319589924, 1.4227183091063655, 0.43467902368114847, 0.0756587821149057, 0.11212667405244806, 0.1765116220039706, 0.11024646445988648, 0.24269749710877098, 0.15456361666081414, 0.12913584078271545, 0.1398626498637661, 0.10101020200959138, 0.21325738169252875, 0.2752414790372695, 0.2065521971352639], [0.10400445666164161, 0.06708516273647547, 0.07149360037498897, 0.04285184050639791, 0.029220849560994296, 0.11021957477374424, 0.1331451772561958, 0.028642031829804186, 0.07227409841312517, 0.026059195121389725, 0.045348632134376995, 0.0849594725596328, 0.033119670190517946, 0.05731592908681882, 34.52494936604654, 56.46045938614876, 29.910975117837232, 43.04872651253977, 29.663626532400812, 58.96661858404837, 1.5162777468081445, 4.209947566832266, 0.19787078152500814, 0.18347801189989815, 0.03338063421148447, 0.11333441166507621, 0.05610593534525364, 0.11740900350794678, 0.1327353661819812, 0.30484225841299184, 0.22023466535873953, 0.2222666829343765, 0.44141023990608036, 26.711248697773105, 60.75293264081402, 49.53789964798958, 53.75307867603918, 45.08561726539366, 47.79091127457158, 46.19614616517098, 51.62343955809071, 48.04799126040552, 52.50467846470495, 59.281757493172925, 66.16328531695952, 73.49512084837883, 77.57675493917158, 82.0038321710402, 82.4734575517716, 82.9275111229189, 87.3263551342872, 90.79985710882372, 84.27422554262223, 80.17940444331016, 78.96911005819999, 80.02555339567124, 77.39936182575842, 77.48646197780486, 79.32642229141729, 75.69035376271894, 75.81137457201558, 73.35319380606376, 74.31294287404707, 76.43520401370141, 73.86767541208576, 75.59486758324408, 69.40532822762766, 66.54995256854643, 69.78439392582064, 66.83750937061926, 66.38765273555633, 69.20007059651037, 70.47393091263311, 75.06774810052688, 73.60107191147344, 71.00086212158203, 77.73321828534527, 61.995927826050796, 62.529880077608176, 66.16267342721262, 69.61151938284598, 68.05608780153337, 64.65360818370696, 55.19973508773312, 64.04515051072644, 60.815314016034534, 63.66714385248, 67.22086614178073, 71.1315711852043, 66.37470106924734, 68.99504046286307, 64.28099086207729, 61.91070648931689, 58.6075726632149, 56.831354787272794, 57.41692150792768, 55.52509177115656, 61.41736253615349, 62.19930271948538, 61.78295881517472, 65.70097907896965, 64.79591961829894, 62.87932011388964, 63.07865888841691, 62.77154514866491, 62.16143223547167, 61.69475255473968, 64.52913961102887, 66.65136152698149, 66.44105188308224, 68.59165606960174, 72.12784536423223, 72.97753272518035, 73.31661378183674, 66.85705061881774, 68.71736803362447, 72.38265822010656, 70.61504210195234, 68.7520339412074, 64.38064259867515, 66.77367671843498, 64.4511668143734, 64.27576234263759, 58.41667482929846, 64.55345046135687, 73.1327252234182, 69.61015439802601, 70.80835219352477, 74.90528352798955, 76.84221267700195, 72.70683427010813, 71.26635951380577, 63.70477114954303, 65.35497111658897, 54.92091732640421, 59.861209238729174, 72.81200085916828, 73.6008914824455, 72.07213201830464, 57.687423844491285, 62.97667726393669, 58.21295476728871, 27.89490822822817, 23.468199699155747, 19.226809432429654, 0.565052418218505, 0.11321656435968415, 0.09687095234591155, 0.08788576755192011, 0.11830507357033992, 0.09423182541204077, 0.0419591948570263, 0.20372522544235955, 0.1671034341017085, 0.32713272038006014, 0.3874332169371267, 7.345842805600936, 61.24808480662685, 29.787673450285393, 61.88914914284984, 34.02507074417607, 53.541360901248076, 3.5938243567943577, 0.107030488640791, 0.06609514731192781, 0.021949390047079614, 0.1396925017357834, 0.023851590193507653, 0.10594395379866324, 0.12199999223793707, 0.0638570903890556, 0.11261377573734331, 0.03764386371439023, 0.09070500941766847, 0.04400602091223963, 0.03099722168107908, 0.06065719475549075, 0.06677744053905049, 0.05992752282069095, 0.02698526327167788, 0.051074966998590585, 0.05382762816283972, 0.06213233535808902, 0.011398332069567856, 0.044270696629199295, 0.013583298141677535, 0.009748199748085632, 0.024689973835202477, 0.12396072533221976, 0.09975111352339869, 42.4142203792449, 68.31428174049624, 44.59521508985951, 32.965803300180745, 27.05921784523995, 75.31608904561689, 1.1353201178773757, 4.818438579959254, 0.408350205830028, 0.17716339428818997, 0.09074354364025979, 0.11043999359131822, 0.14991450484000868, 0.7567591796959601, 1.2219254384117744, 0.3780145336303019, 0.8438579221406292, 0.4977902968324, 0.36841511486038087, 35.17188941278766, 69.15521437121977, 57.47135616117909, 72.02700122710198, 61.0176573261138, 64.69842126292568, 57.13310664699924, 56.01597247585174, 55.18420250185075, 63.79915514299947, 62.801727787140884, 69.1719001339328, 73.36654555413031, 80.05246869979366, 86.04890977182697, 86.46770123512515, 84.9946786511329, 88.18552678631198, 89.38323036316903, 85.49998975569203, 83.24457983816825, 83.10411191755726, 83.66293199600713, 82.21857409323417, 80.81662485676428, 81.98823682723507, 78.58964427824944, 80.15484256129112, 77.62747118549963, 78.56061089423396, 78.59580239941998, 78.53787683671521, 75.74675744579685, 71.77960949559366, 73.20636380103328, 73.07938883381506, 72.44462382408881, 70.77414128088182, 71.00887160147391, 74.83433569631269, 76.80187502214986, 73.88466711967223, 72.81943767301499, 74.97146960227721, 64.80701600351642, 65.45857660232052, 70.21417587034165, 71.27567906533518, 71.93617482339182, 65.58433563478532, 57.270864209821156, 68.26084336926861, 66.04415509008592, 67.16083034392327, 69.69126901318951, 71.79780144845286, 67.98036252298664, 69.60477290614959, 68.49247501742455, 63.6116187803207, 60.195501081405155, 58.49652644126647, 56.07626715014058, 57.067179449142955, 61.50213672268776, 63.70787374434933, 64.82402340058358, 66.33835638723066, 68.30939446726154, 64.85318622281476, 65.14089599732431, 66.63844908437422, 67.43803208874118, 63.67460812291792, 67.00974064488565, 68.71135896252048, 66.62434424123457, 69.5498126552951, 72.77440101869645, 73.19239231847948, 74.80308225077968, 70.96152859349405, 71.24457466986873, 71.21855366614558, 75.4000513015255, 67.38970064347791, 63.842175699049434, 71.53326895929152, 67.62266589749244, 68.42966218148509, 62.48317641596641, 63.93848949863065, 74.98316611013105, 72.86347020056941, 69.1745359666886, 72.21595748778313, 73.99989851059453, 73.07417992622622, 76.10833721776163, 70.86364976821407, 71.07286899320542, 59.75453645952287, 60.59497487160468, 74.1660971795359, 70.56801288358628, 73.14508068946101, 69.99986540886664, 62.946918241439334, 74.82762844331803, 56.26752191974271, 31.77662499489323, 29.069212905822265, 0.9281101882938416, 0.4337929357444087, 0.13533169944440165, 0.1631340567743586, 0.29295830416583246, 0.14954905025660992, 0.05520006701830895, 0.2557475444289946, 0.30789444463387616, 0.19435491292707383, 0.4216038639987669, 7.913807890107555, 68.32799434661865, 31.336756675474106, 57.15635453501056, 37.45356744335544, 61.02072461958855, 5.323084842774176, 0.33288864539034907, 0.13830537697480572, 0.0422930674657466, 0.13253098924554166, 0.05230107923008261, 0.07434819719844288, 0.061007810215796196, 0.06852862560340474, 0.07755779916600836, 0.040665781801386226, 0.06171680543751967, 0.04316266919035585, 0.029710525301315134, 0.1978711645689703, 0.14940615953697314, 0.24458832467996308, 0.15148651726063223, 0.1517567777585599, 0.21156291777808822, 0.32965949285895596, 0.13942936585555155, 0.10142077917173024, 0.17639563629223456, 0.12779445913169654, 0.17094272969951554, 0.17404180050136583, 0.21796600322329232, 52.4309535949461, 79.53714770655479, 40.75218269901891, 65.99717294016193, 47.406487618723226, 83.26039483470302, 3.8069914473641306, 5.741441413279503, 0.5779521744097433, 0.3232180723740209, 0.1319999524181889, 0.3135058548181288, 0.2639999048363778, 1.3344264919719389, 2.811160005869404, 0.8725326544334813, 0.9490904560492885, 1.184378672511347, 0.8975688980952387, 39.00703391721172, 92.23443262038693, 67.62868281333678, 76.55805264749836, 69.33240352138397, 77.85055991142028, 66.511246619686, 76.42702979426231, 70.10896221283944, 74.90512663318266, 69.52586266302293, 76.68107386558287, 79.83900547027588, 84.86205547086655, 89.37713499992125, 88.55369614016625, 88.09310005557153, 92.76352897767099, 94.08789373213246, 92.1970053642027, 89.80392809837096, 91.54449555181688, 91.37343314386185, 87.86096634403353, 86.24644817844515, 88.39895863686839, 82.76828642814391, 83.82629871368408, 80.28033487258419, 83.52309165462371, 83.18227691035118, 83.53375265675207, 79.76407251050396, 75.52046022107525, 77.65369615247174, 76.54874094070928, 76.48098591835269, 76.63306405467372, 73.50376575223862, 80.0305897189725, 80.46742408506333, 78.4461247536444, 78.84527298711961, 82.67594598954724, 70.05124845812398, 70.40739182502993, 73.20577544550743, 78.61591631366362, 73.26738803617417, 70.99049137484643, 60.081258127766276, 71.14933952208489, 69.87938588665378, 70.69261089448007, 73.33802207823723, 74.2967591747161, 70.4162956053211, 74.43317920930924, 71.10124341903195, 66.98015812904605, 64.79656680937737, 62.91503329430858, 62.89573915543095, 63.338421775448715, 64.87688910576605, 69.25678022446172, 67.61839051400462, 71.40544676011609, 73.19823665003624, 68.22129803319132, 68.46361421769666, 70.96107359855407, 70.22293060056626, 66.79972910111951, 73.62964245580858, 73.79692369891752, 71.2869127335087, 73.70639539534046, 79.13907420250678, 79.70096941917174, 80.10789963506883, 73.31612740793537, 75.26753010288363, 76.19835561321628, 78.3688775954708, 72.66249579768028, 67.10808230984595, 73.86380011035551, 72.00090962071573, 71.35894313935312, 62.19947138140279, 69.01899829987558, 78.44456365031581, 76.12593297035464, 74.38771109427176, 81.95642640513759, 81.93044462511617, 80.64639399128576, 79.628476173647, 73.37002077410298, 73.1298932721538, 64.1680109116339, 65.26961249689903, 72.81020441362935, 71.39042408235612, 70.83789548566266, 72.1861945429156, 66.77134683055263, 72.72234332176947, 66.64858448889949, 49.65653173385128, 39.283043261497255, 1.1379999547235429, 0.7980367937876333, 0.3402509954908202, 0.328278573410165, 0.382002879294657, 0.4890204899974408, 0.2552945106740921, 0.5375290241452956, 0.3345952747810272, 0.7698874752367697, 0.5367099842236889, 12.209773525114983, 75.85895292220577, 49.13608028042702, 84.56011925974201, 42.36926609469999, 75.30295695027998, 5.735244558703515, 0.3849909592780375, 0.20078756936615516, 0.19257395768598204, 0.22568924202313348, 0.15486101199301983, 0.15850492452661838, 0.2483235089288604, 0.19961508711980236, 0.15800483765140658, 0.13205751626481935, 0.13567902838751195, 0.1271937849120267, 0.11010903594714981], [0.048106429918158444, 0.059444994680703654, 0.15609105808600304, 0.0564808396231984, 0.07877624668781796, 0.06581996852952628, 0.1535068290127862, 0.052164083557023164, 0.09204246869851505, 0.07846966596140016, 0.018411414066870368, 0.06085528594051158, 0.03922484702460709, 0.9537464320178956, 57.88705287441131, 46.762497194351695, 43.17657616830642, 38.271079601780066, 36.17911877170686, 44.41117355900426, 0.41575649873383586, 4.6338694903158375, 0.6353179413464762, 0.11672870210942723, 0.14368247150653793, 0.45883509360494157, 0.1198095859839551, 1.3410950115611477, 2.4477048506659846, 0.34725876945641737, 1.9215757664172881, 0.20013614948238098, 7.760748180650896, 45.812671722904334, 43.83398894340762, 46.86092515145579, 39.61567594159035, 44.41135398803219, 40.942292136530725, 53.86402291636313, 46.32256023345455, 48.297858007492565, 52.4719423632468, 54.85657868846771, 60.90255145103701, 65.49678048779889, 68.62071298783826, 77.48613249871039, 75.16146136868385, 83.41426941656297, 90.9746693026635, 83.85105671421175, 76.11937476742652, 83.84708727559736, 80.42664712475192, 83.42385568926412, 81.90632204855643, 78.72360106437438, 71.77359257974933, 76.03459665852209, 71.15298732634514, 71.20586087626796, 73.05456807536464, 72.75198859553184, 72.66779099741291, 69.71863931225192, 70.83369854957827, 72.77000011936312, 65.05742011531707, 68.90522603065737, 68.05239292883104, 68.12775734932193, 74.67493841725012, 75.17714300463277, 72.81010243200487, 69.2667979578818, 60.47560538015058, 66.01048546452677, 67.80558955284857, 70.71511745452881, 67.2255180728051, 70.76311942069762, 56.23504861708611, 62.53508114045667, 65.28815354070356, 61.11654420052806, 66.61574640581685, 68.99005120800388, 69.07216210519114, 66.88213025369953, 66.3678918346282, 66.36553056778448, 64.0611380915488, 63.513673274747795, 60.392466821978175, 54.812797192604314, 56.64630520728327, 54.70277470927085, 54.0979334615892, 54.54536214951546, 61.69207357591199, 64.06799047223984, 62.09228084933374, 61.235580290517504, 64.84213298366916, 60.364119852742846, 59.001872847157145, 60.69646619981336, 64.28922783943915, 63.625405911476385, 65.4667547441298, 67.63848873876756, 70.3088697310417, 70.674513078505, 73.55526647260113, 68.80404456969231, 72.62233072711577, 70.67547013682704, 66.59481663857737, 64.86336869578209, 68.20025843958702, 63.19146625457272, 64.36023450666859, 65.69713907857096, 58.77125709287582, 66.60086493338308, 73.67224724062028, 67.69912858163157, 71.11289285844373, 74.2510243385069, 76.28593429442375, 68.95602072438886, 70.28946968816942, 63.40350566371795, 56.6369503544223, 53.503055034145234, 71.0353946685791, 71.41639801763719, 74.76443121510168, 63.63123063118228, 51.77153648868684, 59.45081164759975, 47.49549404267342, 21.413226819807484, 29.05015018678481, 7.081039672897709, 0.08391429114365771, 0.42720923741017625, 0.13374900775811366, 0.9236533951855476, 0.6329254181154313, 0.07141706819135336, 0.12071707841729927, 0.11893309712890657, 0.13648597944167354, 0.09769156274776306, 0.6066009210002038, 52.65426589596657, 33.372800196370775, 34.03440206281601, 34.190618299668834, 45.60002434638239, 7.466930785486776, 0.1327168268542136, 0.0797258816178768, 0.07987464823189282, 0.1317796868181998, 0.05549830504723134, 0.03599078386961933, 0.1648160794209088, 0.2267298958594761, 0.04690176048766702, 0.11553128370113912, 0.06579355381789707, 0.049480194105736675, 0.08489770289029806, 0.05490690432188492, 0.04771105194043729, 0.0482906204377932, 0.010484683162142194, 0.057447880070896885, 0.05171769944530341, 0.12234657807576081, 0.08896818850189449, 0.0250990379736909, 0.020146698976356178, 0.019108797310881557, 0.06904794894639524, 0.057670160482126864, 1.5951597978991847, 65.16505387521559, 59.31398368650868, 52.80967804693407, 30.426239236708614, 46.81340563681818, 52.66741760315434, 0.7454655115162173, 7.9894713913240745, 0.33418848209323426, 0.02991529294259606, 0.17399949712618706, 0.1754328935977913, 0.5628652065511673, 1.531518361260814, 2.8553263843059544, 0.24843825357815913, 3.194444213182696, 0.25502380584516837, 10.472606766608454, 60.92664264863538, 56.052579956669966, 60.17340244785432, 56.02434673616963, 65.12213530079012, 57.831241469229425, 62.67431351446337, 53.06066266952023, 56.0621387727799, 63.48380050351543, 64.9278328495641, 68.01615022843885, 72.81776674332158, 76.94235078750118, 79.35697755505963, 76.25461024622764, 86.18871088950866, 91.69933503673923, 83.4666330583634, 80.2857320539413, 90.11655669058524, 83.56805770627915, 87.04269716816565, 86.53267921939974, 81.79562491755333, 76.75035076756632, 79.63257897284724, 79.06037576736944, 76.24646740574991, 73.60260948058098, 76.6146053806428, 74.74551754613077, 71.5898609161377, 73.30433676319738, 75.79880729798349, 71.51896799764326, 73.45816427661528, 73.46778977301814, 74.53356050675916, 76.97080366073116, 77.8591420573573, 73.40616933761105, 67.34001990287535, 60.79537268607848, 69.100999370698, 71.88456427666449, 73.40458470006143, 67.62006928843837, 71.37022387596869, 58.96237457952192, 65.76541185379028, 68.10381520179011, 66.72558061538204, 69.77592160624843, 69.2090920479067, 70.87551886035551, 73.57918508591192, 67.94000917865385, 67.57898638325354, 66.2551393816548, 65.43881177902222, 64.15412179885372, 57.21471548080445, 59.514052021888, 55.49575244226764, 57.55424368766047, 57.60525803412161, 62.56479701688213, 64.34509023543328, 65.63537351546749, 64.23606795649376, 65.79908932408979, 65.43239478142031, 64.64673226879489, 62.86484264558362, 66.55270607240739, 66.06601053668608, 66.86268314238518, 67.14435638919954, 68.97240838696881, 71.93228383218089, 74.55542379809965, 71.38759213109171, 70.64001975520965, 68.93218840322187, 71.57133948418402, 65.99060689249347, 68.8696736674155, 65.96642940275132, 66.73926968728343, 67.0166047926872, 61.25161493978193, 65.54461379205027, 77.44497899086245, 70.74046381058233, 68.89672233212379, 72.12199318793513, 76.17036557966664, 71.11326156123992, 75.1483920312697, 68.64958947704685, 64.3369552396959, 57.5839791759368, 68.55076928292551, 72.15709055623701, 71.38099470446187, 72.37448400066745, 62.27128213451755, 60.08256819940383, 72.34804722570604, 41.64704791961178, 35.702958722268384, 13.90777639804348, 0.07558497720428052, 0.8811396216192554, 0.07593548541227657, 1.347585308455652, 0.7285095955575667, 0.1260402173765244, 0.06776934053989188, 0.11153441147818682, 0.16441851043172423, 0.05961985807986029, 0.6303818836327523, 59.62929517992082, 37.58449615970735, 35.25594580558039, 41.32337001062209, 54.727987704738496, 9.945925608758005, 0.2939014196876557, 0.28821376843317864, 0.08057378007159119, 0.19826994397707526, 0.07177941245777954, 0.020412981562737017, 0.03858175068613022, 0.13846654655231586, 0.04450914915651084, 0.1496201891812586, 0.08031383111712434, 0.0745979571835168, 0.0384599925018847, 0.1735505696025587, 0.1998827429187875, 0.20303776878262722, 0.15359618550827428, 0.16159765212045563, 0.17994633124720666, 0.28285047880584197, 0.19498595487206213, 0.1959631919500328, 0.1581807161170629, 0.1977586262528935, 0.2631079027008626, 0.317932709210342, 2.5634875797456314, 79.5510015180034, 65.92810000142744, 58.63995182898737, 56.7619013786316, 60.228931442383804, 64.80894188727102, 0.9196508615728348, 10.754996826571803, 0.6544498534452531, 0.22595702039618648, 0.3404927115526892, 0.5526053893469995, 1.0710903257131577, 3.30936941408342, 5.308590704394925, 1.0428096690485555, 5.291947597457517, 0.6071190415851532, 10.995730334712613, 81.72628525764712, 66.57897026308122, 70.17630146395776, 64.80465865904286, 80.66264829327984, 66.79678732349028, 77.84978328212615, 71.76665782928467, 71.47282523493614, 76.03109790432838, 75.22647857666016, 78.51375426015547, 80.34778395006734, 83.33648881604596, 88.16646406727453, 86.2471071366341, 93.35379862016248, 99.43883034490771, 91.40479641575968, 83.92272626200031, 94.09516580643194, 87.25180656679215, 89.15567797999229, 87.60473359015681, 84.8788667494251, 79.79296468919324, 84.22834950108683, 82.12428031429168, 79.43012975877332, 81.53770554450251, 81.09610157628214, 81.11266182314965, 76.77919587781354, 78.05430350765106, 80.08324361616566, 73.21128245322936, 75.72848704553421, 78.21669747752529, 76.27638724542435, 79.75909894512546, 83.55285459949125, 77.4500310036444, 74.37802283994614, 68.78286377076181, 72.77363223414268, 80.30080964488369, 78.1898606208063, 72.1079981711603, 78.70198880472492, 64.37832840027349, 66.17235383679791, 73.09017535178893, 68.35465861905006, 73.57002242918938, 72.21850702839514, 76.57937465175506, 74.26748260374993, 70.1034865840789, 72.31122401452834, 67.80680548760199, 69.7951098411314, 66.42424844926404, 62.114328492072325, 63.96561268837222, 60.076213959724676, 59.380024633099964, 59.72536187018118, 67.35829814787834, 69.92491675961402, 70.10131359100342, 65.60118221467542, 70.14946460723877, 67.00102513836276, 66.96026386753206, 67.16270523686563, 70.64947266732493, 70.52612197014594, 72.28908615727579, 72.88845569856706, 75.65757843755907, 75.75826567988243, 79.73533722662157, 75.5803861925679, 78.29707468709638, 75.26708295268398, 74.26111267459008, 68.64958163230651, 74.32813813609462, 70.40823905698716, 70.45129099199849, 70.68526037277715, 61.727257236357666, 68.80164407914685, 81.73372991623418, 73.78649019425916, 75.08407300518405, 79.27725145893713, 82.34452924420758, 76.96048782717797, 78.77933009978264, 72.68974058089718, 67.13651949359526, 64.74880803015925, 72.23053301534345, 72.170042222546, 73.39833244200676, 71.15070450690486, 64.09706307995704, 60.96449352079823, 72.60636668051444, 54.472382530089355, 54.4613528251648, 14.495129758311858, 0.4295777054803987, 1.8279339589418906, 0.14230493816637224, 2.0209963283231183, 0.7698492321275896, 0.2318356880137036, 0.23863880925120848, 0.24081895758788432, 0.26979719859457785, 0.5285036503787964, 1.721798667023259, 70.70502911844562, 44.96376099125032, 50.19911319978776, 44.270266332933986, 64.62168401287448, 11.349216295826821, 0.6090585310612956, 0.385644187129313, 0.2800323477675838, 0.27222542152289425, 0.2157275402738202, 0.15857948020340937, 0.205477804786736, 0.2266674596936472, 0.13205023842953867, 0.35261822864413267, 0.18581525422632697, 0.11891328609518467, 0.16651978235571616], [0.052802073919484695, 0.03123409798248641, 0.06231239666381191, 0.01988339264156117, 0.06284477797547175, 0.13044372140880556, 0.07609026581649819, 0.05594081275405423, 0.07020627388790732, 0.08153609375679687, 0.08718177105390257, 0.09904572274535896, 0.020660527553709767, 4.979429321904337, 63.65568268683649, 35.91508834592758, 45.550222012304495, 28.69687407247482, 53.53277483294087, 8.667005435112985, 0.8439710580052868, 3.13523922235735, 0.6246485428944711, 0.09572537510745949, 0.12132875365956176, 0.277064798940574, 0.5271496972249401, 0.12006724433552836, 0.6799564138054849, 1.2402305271356338, 0.7076815035073989, 0.24547108779511145, 22.70313943586042, 48.310138948502086, 44.93135044651647, 43.59574810151131, 39.26973465950259, 41.60454119405439, 44.713262742565526, 48.29192738379202, 43.41759797065489, 50.909787839458836, 50.776701819512155, 53.681389516399754, 58.29259457126741, 64.00412644109419, 69.19567754191738, 69.30548037252119, 68.39068951145296, 76.35405801957654, 72.98553436033188, 69.21299872859832, 86.8289436832551, 88.0058116297568, 87.27548983789261, 84.41252047015776, 82.08154216889413, 78.95123973969491, 76.7535121979252, 71.63625471053585, 74.17114919231784, 73.04925718615132, 73.18814831395304, 72.09153990591727, 70.48623931023383, 69.36873251391997, 70.13668552521737, 68.13454304972004, 71.50538090736636, 71.34168471059492, 75.40150257848924, 73.93019799263247, 72.73434577449676, 74.4113394521898, 66.40203214460804, 60.255368217345215, 68.46477523926767, 71.04583601797782, 70.70969673895067, 66.93664335435437, 66.21476250310099, 57.339489998355994, 56.0846100314971, 62.83111810684205, 61.02916948256954, 66.3030158319781, 65.03204238030219, 64.85942671375891, 70.65098670221144, 68.15375481882404, 64.90920159124559, 68.62287813617338, 66.6328557845085, 62.721731047476496, 60.76342890339514, 58.55162789744716, 59.15767723514188, 55.89402206482426, 52.85083547715218, 52.02430186733123, 56.0405461249813, 58.07698580526537, 64.88265498991936, 63.11975356071227, 61.83035281396682, 61.72695129148422, 60.98946725168536, 59.02388518856418, 61.67614090827204, 61.7749571800232, 64.85639079924553, 62.76727368754726, 67.1368803516511, 67.94146830035795, 70.3798803206413, 69.38096246411725, 69.21850573632025, 68.62153668557444, 68.94257483943817, 67.62011635688044, 67.59593886713829, 64.832068181807, 62.662542481576246, 61.61875271028089, 62.7272145209774, 56.7844706966031, 69.12927965964042, 70.97029901319935, 69.9953939068702, 69.05087147989582, 75.75416288068219, 73.34651793203047, 71.08464394846271, 68.29935319962041, 57.96595919516779, 50.76259697637251, 57.986594784644346, 76.95432970600744, 71.32139036732336, 67.16549011968797, 55.579279315087106, 49.78648770240046, 56.9517715515629, 34.40122604370117, 20.398288042314594, 30.387715678061213, 2.9035359909457545, 0.1855551060889998, 0.2959185598358032, 0.09910522479443781, 0.5749272915624803, 0.11955722129993862, 0.07185761471309009, 0.19933687462922067, 0.2597656449483287, 0.22236150929764395, 0.3351707293862297, 31.56968858934218, 47.096083010396654, 32.102603373988984, 23.007325126278786, 50.6069024147526, 10.77633353971666, 0.4976653325701914, 0.38348351274767234, 0.17605469652241276, 0.07414872322471873, 0.09606752529620163, 0.10438160174676489, 0.1051060144879645, 0.09708976237884454, 0.06813540033275081, 0.08714524398167288, 0.02363118286725254, 0.03267590609949923, 0.055575925075719436, 0.10871249596558272, 0.040435618345415404, 0.030083730779287797, 0.11430261656641962, 0.01401359057654777, 0.11516674076237025, 0.09197397277720513, 0.06519779022182189, 0.05178389710284049, 0.023653828426294272, 0.05771987958841267, 0.02259144642119927, 0.2660579847231988, 6.639432272603435, 73.8707427055605, 48.54816013766874, 53.19156392928093, 21.67575497781077, 70.05082484214537, 10.493380619633584, 2.9250906407833104, 6.284878936506087, 1.017081556060622, 0.0710897877692215, 0.13368480959005896, 0.2041872530694931, 0.6913550053873371, 0.13002703086503092, 0.6499823351060191, 1.670195107017794, 0.9887661496477743, 0.31506793873925365, 38.059550100757235, 64.83915982707855, 60.89473024491341, 65.72388572077598, 60.15830916743125, 59.82573924526092, 58.680826848553075, 54.51126498560752, 48.43212466086111, 58.882491588592536, 60.83725183240829, 62.86004950923305, 67.21757919557633, 72.98833493263491, 78.14156839924475, 78.02946705971995, 78.09974024372717, 83.74141077841483, 77.17931685909149, 72.10189496317219, 88.34760696657243, 88.18921381427397, 88.20724887232628, 86.1182729659542, 83.75161678560319, 81.05223378827496, 80.56459688371228, 75.55959763065462, 78.98766286911504, 77.39743986437398, 78.27357184502387, 73.71120422117173, 74.36891509640601, 74.57265084789645, 73.73875494926207, 70.64636615014845, 75.74123474859422, 74.96677844755112, 79.50360359684115, 77.66120356898155, 75.70318775792276, 73.22439101434523, 65.0543842008037, 63.49292001416607, 69.13282548227619, 70.47987722581433, 70.03054618835449, 70.88574055702456, 67.30331436280282, 60.28165986461025, 59.23835646721625, 67.47975826263428, 63.839645770288286, 69.20658957573676, 70.68187928968861, 67.78658174699353, 70.98792614475374, 70.17603474278604, 67.10989444486557, 68.97713092065626, 66.94065986141082, 63.90638097640007, 62.39097326032577, 60.21702704891082, 61.7253391973434, 58.7577719842234, 56.68186933763566, 54.72254345493933, 57.87933364991219, 61.10558509826661, 68.43081535831575, 65.13837783567368, 65.37603816678448, 65.09575343901112, 65.41868609766807, 63.89368818652246, 62.932264266475556, 65.04442530293619, 65.22608595509683, 63.28165331194478, 66.10815248181744, 69.59151529496717, 71.22914406561083, 70.4870080947876, 71.56249061707528, 68.3191062558082, 71.35600920646422, 70.52348613739014, 70.19272835023942, 66.55746782979658, 67.20581992979973, 66.07451423521965, 65.56219385516259, 60.05091859448341, 71.08268276337655, 73.06582527775919, 68.68354151325842, 68.59576671354233, 72.71246679367559, 75.54648906953874, 72.78699182694959, 75.39725072922246, 62.86694503599598, 57.47172486397528, 58.542245587994984, 73.62397855327976, 72.95299437738234, 68.3129716688587, 65.83208822434949, 57.060797752872595, 62.22491971908077, 64.99162627804664, 33.88085696005052, 43.99842254577145, 5.42393829553358, 0.21560827570576824, 0.41901635606923415, 0.0692000710255196, 0.5634015293851976, 0.13670169447939243, 0.2857307242530008, 0.1936823490165895, 0.2258200898406006, 0.34962742138774167, 0.33044929886537217, 36.74903523537421, 50.81385058741416, 29.904664024229977, 36.65408249824278, 59.93736205562469, 13.234015184064067, 0.7024235050043752, 0.3339242736899084, 0.15441793738113296, 0.13704045855950925, 0.03709233020462337, 0.0920984237605045, 0.028577766629056107, 0.06635129647029024, 0.007908666551473641, 0.11921820441080679, 0.008713859433849013, 0.08635730722979193, 0.034818753615141876, 0.19355606708315112, 0.1600604354133529, 0.12640098350182657, 0.2243704523050016, 0.10722161991701973, 0.2161258447074121, 0.2440840702864432, 0.35046402004457294, 0.23302952879138533, 0.21789025244933946, 0.24303976987158102, 0.3417604644933055, 0.364243459677504, 9.499245112942113, 88.14983321774392, 52.976265030522505, 64.57338394657259, 43.98553755975539, 80.21516861454134, 19.910353037618822, 4.779523274590892, 13.626900372966645, 1.211718328056797, 0.225110033587102, 0.36777454278161453, 0.8913523703813554, 2.0675504496020656, 0.8157950795946584, 1.1562631231161857, 3.5922039276169198, 2.132025880198325, 0.455520169869546, 54.049625550546956, 81.08416972621795, 71.52932305489817, 74.33799897470783, 67.59680178857619, 70.99758302011799, 71.5289229731406, 74.63494593097319, 63.98964897278817, 76.29208457085394, 72.0477976337556, 71.25569851167741, 70.81958586169829, 77.72905272822227, 83.76231701143327, 83.80539248066565, 84.52877952206521, 93.83137072286299, 85.30372219700968, 74.52812410170033, 93.1316355736025, 94.39981629771572, 91.79562137972925, 90.14921434463994, 89.44623931761711, 85.39314439219814, 83.53276421946865, 80.62846875959828, 81.47747362813642, 82.81300144810831, 81.98431445706277, 79.82401417147729, 79.81602822580646, 76.99864464421427, 79.93027117944534, 75.7713036383352, 78.72046316823652, 78.70429515838623, 81.5697983772524, 83.83481810169836, 78.3216130348944, 81.71565563448014, 73.63570644009498, 67.78356152196085, 73.88920922433176, 78.03549182030463, 75.97957364974484, 75.84993147080945, 71.7017347581925, 64.28643903424664, 62.24817937420261, 69.98576056572699, 68.14027755491196, 72.28488137645107, 73.87121338998118, 68.86901470922655, 76.91593754676082, 72.9717040831043, 68.42347268135318, 73.26661140688005, 69.99594303869432, 67.7087305438134, 67.58728611853816, 64.8489147616971, 65.38810729980469, 63.34676073443506, 57.209035888794936, 58.3017768398408, 64.29531535794659, 64.01468546159806, 72.36959672743275, 67.4962635963194, 66.72454510965656, 68.71057448848602, 68.89659681627828, 66.0827669020622, 65.94644884909353, 69.72937876178374, 68.6497385271134, 68.2908965695289, 73.21234149317588, 75.0491560659101, 76.60726270368023, 77.58003404063564, 75.2740647715907, 74.1320510064402, 74.06304082562848, 73.24168082206481, 70.35345139042025, 70.68466417251095, 67.92446090329078, 66.99256850827125, 65.21495819091797, 60.390823348875976, 74.99984402810374, 77.29053958769768, 73.82872627627465, 74.47386987747686, 81.88892241447203, 79.5814077315792, 76.95143499682027, 78.9441010259813, 65.89816447227233, 63.40387828888432, 63.75831934713549, 73.59893029735935, 72.18638281668387, 70.1752188897902, 66.46937924046671, 61.17349701543009, 65.23538589477539, 69.42708953734368, 49.09837061359037, 61.089048385620124, 4.767852262143166, 0.21572763220437113, 0.7684111931631643, 0.260803418294076, 0.9530791387923303, 0.39297987737001916, 0.3769080575195051, 0.23844014733068405, 0.39187842679600565, 0.32437428291286197, 0.543811496707701, 45.99503055695565, 63.34743930447487, 51.43421657623784, 33.496260719914595, 70.1179365957937, 13.902027183963408, 0.8628273010253907, 0.45823120181598975, 0.429049319317264, 0.2873934721273761, 0.17940835366325994, 0.13990093893822164, 0.15900838218869703, 0.2197342873701165, 0.13649466687873488, 0.23803281838134413, 0.13388949296166822, 0.23534516743834943, 0.21065225374073754], [0.04402765140478169, 0.05458042829207355, 0.0672263220974034, 0.0070594657482879785, 0.030001382073087078, 0.04688949541999929, 0.08969098479757387, 0.01937915548501957, 0.09574312536466507, 0.01357346827599911, 0.01838937946294825, 0.07175848293568819, 0.2927058935165405, 19.32461961623161, 62.000046314731726, 36.11493702857725, 50.27429719125071, 35.19205039547336, 71.36152405892649, 1.2661393755866637, 2.108887573403697, 0.5622873311081241, 0.3319377464152152, 0.17257610576287394, 0.21578478236352244, 0.5129808091348218, 0.5114470091798614, 0.456153632652375, 0.242671373510553, 0.8962115128674816, 0.32860789928705464, 5.502386189276173, 44.257365657437234, 43.0399953165362, 45.43599867051648, 43.50030506810835, 49.04192770681074, 45.028817422928356, 48.39892571972263, 48.6548250721347, 49.38144414655624, 50.42159003596152, 56.09899336291898, 64.7978219678325, 64.75873162669521, 70.18617799205165, 69.4269169530561, 76.24987202305948, 77.64295670293993, 71.39655082456528, 67.24344330449259, 85.97927201178767, 85.21866952219318, 82.34263866178452, 81.96866420007522, 78.49994751714891, 78.96181444967948, 75.7569242292835, 74.03015567410377, 75.19795510076708, 74.76494896796443, 76.48594379425049, 73.90034875562115, 70.54519253392374, 69.38736377223846, 71.95151129076558, 69.12698899545978, 74.03102644028203, 74.07052470791724, 74.86442027553436, 75.21039685895367, 70.62209452352216, 68.31760791040236, 60.18781323586742, 62.56298488186252, 69.51390727873772, 67.75881921091388, 68.89215669324322, 70.21346984371063, 67.33543857451409, 57.720509036894775, 57.436384308722715, 62.11892158754411, 64.78604309020504, 66.01215639422017, 66.38261641225508, 65.79177018134826, 64.51606242887436, 65.77498635938092, 66.28337260215514, 64.12588465598323, 67.7351830082555, 63.60221293664748, 57.33457134615991, 56.58588109477874, 58.12857281777167, 58.27121373145812, 59.25073938985025, 58.86025567208567, 51.84436705804641, 51.737513849812174, 52.7720703617219, 57.741191694813395, 62.24057389843849, 66.1231751595774, 66.58281418585008, 62.3210491672639, 61.74272706431728, 57.95026971447853, 60.47423255059027, 60.18502835304507, 60.65730133364278, 61.61062555928385, 66.03573768369614, 67.1480747961229, 67.59456603757798, 69.37713423082906, 67.74167060852051, 72.15583539778187, 67.62919272145918, 67.86145979358305, 65.18233583819482, 64.72050420699581, 60.754238790081395, 59.16953456017279, 61.991793647889175, 66.94460576580417, 67.09257325818463, 67.63085580641224, 69.24062790409212, 73.55679619696834, 76.71012293907904, 69.39911519327472, 69.37077214640956, 57.10564221105268, 53.6888498644675, 49.17853209280199, 65.8566971748106, 76.96375123916134, 66.45809065911078, 62.05088415453511, 46.765890044550744, 49.91753408985753, 51.30364087320144, 24.35497307008313, 27.72407135655803, 21.915088199800064, 0.239507062661071, 0.37163577913757295, 0.1262558404836924, 0.16195578290329826, 0.1055278531425903, 0.06707056876151793, 0.05972653965375597, 0.04978937570065741, 0.1650337250001969, 0.2838183849328949, 9.108348565716899, 59.606121816942775, 24.528475192285356, 30.10423814096759, 49.962331479595555, 13.92178318192882, 0.36193612542363907, 0.16337857671803044, 0.12256472161219967, 0.16848515028194075, 0.12410979072052626, 0.06433686061251549, 0.09022424327990702, 0.11621006824556859, 0.11883616402384736, 0.05708586139183852, 0.056599521964427926, 0.0672648563199947, 0.054542572057295235, 0.05449817343164356, 0.05495412215109795, 0.1252310063629862, 0.07394043157898611, 0.07153475461828132, 0.02277354935124036, 0.06071552085960585, 0.04593946212421983, 0.10322240346501912, 0.0847254480205236, 0.06180675948158868, 0.1265053629815098, 0.4325228232529856, 25.497859562596968, 67.9622176385695, 49.617162904431744, 47.007637485381096, 32.7146755110833, 79.17370088638799, 1.988643025678973, 1.3169661837239421, 0.9677509482829803, 0.5166172140067624, 0.12828126204230134, 0.18254723039365586, 0.704328551167442, 0.807462984756116, 0.6093207782795352, 0.4321915974780437, 1.629603110974835, 0.21618650354925664, 12.70662211602734, 66.68570580021029, 57.494556980748335, 66.64143793044552, 65.46485239459624, 67.90467646814162, 60.60239207360053, 61.50773394492365, 53.92094827467396, 55.33986176213911, 56.12024476451259, 63.091183016377116, 68.91827967859084, 69.46024925478044, 71.69665136644917, 73.92538916680121, 81.14088719890964, 80.54879757665819, 75.61728785114904, 72.16661407101539, 85.36434635039299, 86.26737010094428, 83.98218939381262, 81.55284589336765, 81.84168923285701, 81.02402410199566, 78.1581521803333, 76.70478067090436, 75.19168715323173, 77.48749748353036, 78.68362426757812, 77.90952882459088, 74.45579559572282, 72.35712359028479, 75.52906590123331, 74.16895266502135, 76.06970971630466, 77.05479729560115, 77.15499031928279, 76.07772704093688, 74.23648803464829, 71.69803204074984, 60.09515508528679, 65.99463124429026, 72.45603007654991, 68.63080132392146, 70.17578371109502, 70.79440424519201, 67.40278567037275, 59.032326129175004, 62.02699299781554, 63.82259130477906, 68.28796263664, 67.7041256812311, 68.45238054952314, 68.5501495484383, 70.41433442023494, 69.46142596583213, 67.46266457342333, 67.28943701713317, 67.60923570202243, 62.63716866893154, 60.339326550883634, 58.66496086120606, 58.828174606446304, 60.6552303221918, 60.80448042961859, 61.234399657095636, 56.13814646197904, 57.01558459189631, 54.579282806765654, 59.64962090215376, 63.621303112276145, 68.48761912315123, 70.14268675158101, 66.14746247568439, 66.05145854334678, 63.49156287408645, 63.21784811635172, 67.50479867381435, 64.26800389443675, 64.51188510464084, 68.18319612933745, 67.68736147111463, 67.52916443732478, 71.0674012091852, 68.77428162482478, 68.98946285247803, 71.20173454284668, 70.35644023649155, 64.25744487393287, 67.14973003633561, 66.23584916514736, 61.55521423585954, 62.687465221651145, 67.66873805753647, 71.50400807780605, 70.01286414361769, 68.41207427363243, 71.03340994927191, 74.98583332184823, 69.36026019434776, 72.15166199591853, 63.27543243285149, 56.89405779684744, 54.57429747427664, 64.40676950639295, 78.4978686609576, 74.05328196863975, 68.52347743126654, 60.33181128963348, 52.65134373018819, 65.03061463755947, 48.34296918684437, 37.246250567897675, 32.30884552001953, 0.66541122332696, 0.3952008888365761, 0.19117779308749785, 0.18935310954768814, 0.12950152519249147, 0.07177666220213137, 0.08401925285016337, 0.028301431053888895, 0.12954444143800967, 0.25311224793474524, 10.640686212047454, 68.99763707191714, 27.22008797430223, 32.20138630559368, 59.425167191413145, 16.70047356236366, 0.6026387142558253, 0.2184043740553241, 0.047963225102472695, 0.1239574388150246, 0.13066841499699702, 0.15018870302986714, 0.11631156723465651, 0.05305083415981743, 0.11813572217379847, 0.0978123594916636, 0.03373089727134474, 0.08018467635396989, 0.0251027247718265, 0.1807123732062117, 0.15237775330822315, 0.30320332055130317, 0.2736724083942752, 0.24974588905611347, 0.11246385999144086, 0.2804147788593846, 0.21612258117285468, 0.22259907316296335, 0.15406863193117804, 0.11819792851325005, 0.40541296344130273, 0.5183934961115161, 29.328591400577178, 84.22575289203276, 52.494778402390025, 69.28808858317714, 55.04648024036039, 93.2115028750512, 2.8667130249161876, 4.880133540399613, 2.0594941464162644, 0.5992696434259415, 0.4652011003946105, 0.6364609445295026, 1.5803405930919032, 2.6337713051226834, 1.3140327411313213, 0.9893731364319402, 4.854006142385544, 0.40081346347447366, 21.668580962765603, 87.26430323816116, 67.3497473809027, 76.62801204189178, 72.43167215777983, 79.86349674963182, 71.86725877946424, 75.45769445357784, 72.75295349859422, 75.06144877403014, 67.91407446707449, 73.97589360513996, 78.3274652111915, 76.0931105767527, 79.02416444593861, 76.99963308149769, 84.77758330683555, 85.68925980598696, 82.29571926978328, 74.08649659925892, 89.39100450085056, 91.18199010049143, 87.2869666930168, 86.76657799751528, 86.96853299294749, 87.12210947467436, 83.34014446504655, 82.95051190160936, 79.99730448569022, 83.27270323230375, 85.35789797382971, 85.95772251006096, 80.14432276448896, 75.863738213816, 82.77111837940832, 75.32380042537567, 80.95875586232832, 78.61332754934989, 81.84925156254923, 82.41546923114409, 76.31736032424435, 77.1696521389869, 66.49405094885057, 69.2757958750571, 76.48150367121544, 74.88791527286654, 77.56128511121197, 78.5824663408341, 73.60409998124646, 66.14731342561784, 64.36089346485754, 68.96700336087135, 71.64483685647288, 70.73921649686753, 71.60498557552215, 71.2351845156762, 73.66139796472365, 72.5910851263231, 73.50942181002709, 70.18661729751095, 73.18194312434044, 69.04355233715427, 63.85257390237624, 62.50684007521599, 64.68897619555074, 65.296790599823, 67.60714900109076, 64.50529160038118, 57.32541261180755, 59.01703673024332, 57.3417845849068, 63.953229765738214, 65.46406399819159, 73.1800054734753, 72.16516279405164, 67.94560247851958, 66.21918693665536, 65.00396605460875, 67.67887346206173, 69.34152695440477, 65.50713946742397, 67.68437262504332, 73.88873853991109, 72.94251380428192, 72.60125190980973, 76.03887988675025, 73.0059620641893, 74.34014843356225, 74.93827850587907, 73.51196350589876, 66.9106694190733, 69.54775733332481, 68.4160594017275, 63.83773557601437, 62.77802490418958, 70.91563686247795, 72.88848707752844, 73.47533641322967, 75.65047894754719, 78.98749028482746, 82.78687846276068, 73.67515763928814, 76.26361600814327, 67.29924294256395, 62.94270169350409, 62.72990918928578, 68.66990735453945, 75.30771086292883, 74.65382037624236, 68.94131968098303, 64.47099047322428, 57.79146863568214, 66.9457197189331, 59.1753985035804, 50.58328974631525, 37.94371074245822, 0.6872810110930474, 0.8286790850181734, 0.36895722931911873, 0.4511078098608602, 0.3247187466871354, 0.23847011669028192, 0.1652339037748114, 0.19097148560948912, 0.5032312064882248, 0.4855384978075182, 15.422276085422887, 79.91196940022131, 36.35048320216518, 39.568921289136334, 69.20449503006475, 19.488913974454327, 1.1467446338745857, 0.32934315983326207, 0.38924357463275233, 0.2856652084137163, 0.2830393654444526, 0.17027462442075053, 0.2735668108347924, 0.22517133594280292, 0.31031519054405154, 0.15807879577961662, 0.156317345137077, 0.19100989725801254, 0.15761339736561622], [0.037148553397386305, 0.06579458037571562, 0.017120197768353166, 0.06356523387254247, 0.10335728090496794, 0.06622050227897783, 0.10927377794418605, 0.11106449314543318, 0.10567535571153126, 0.06311132677740629, 0.1476784627283773, 0.15329258486388192, 0.0552768022152445, 30.94201718607257, 58.90408031402096, 36.41311953144689, 41.8622487591159, 35.84439546831193, 55.582668242915986, 0.11064581077305541, 0.21999065103309773, 0.3402804745541465, 0.21681661086697734, 0.0971380795442289, 0.18029664793322164, 0.04037072303734961, 0.04751067398296249, 0.08988753997630651, 0.39746403513896855, 0.08832402347076325, 0.2569180961337782, 30.720860227461788, 48.022342881848736, 44.39019280095255, 49.292276905428984, 48.2543981459833, 50.30292264876827, 46.63024271688154, 50.05153402205437, 50.25416366515621, 53.08078050613404, 59.03786451585832, 61.68677053143902, 61.744805920508604, 68.4555890483241, 64.51043382767709, 71.19989887360605, 75.88104371101626, 75.26671424988778, 68.57859457692793, 73.90729135082614, 81.4586462513093, 81.48737369045135, 81.96353373988983, 79.79473760051113, 80.38647420944707, 74.76555301297095, 74.09849120724586, 75.08584591650194, 73.9032748437697, 71.18916726881459, 74.34164677896808, 70.59375147665702, 71.75942497868692, 68.73525404161023, 74.94077313330867, 75.16572890743133, 73.7650191399359, 72.99558347271335, 70.56331388411984, 69.81918534924908, 70.03057756731587, 59.18782849465648, 63.7835088083821, 70.23265023385325, 69.0047836303711, 68.4107328230335, 70.82867791575771, 64.64517508783649, 59.267370239380874, 61.79933078827397, 60.79437640405471, 56.57708714085241, 56.622739607288, 58.94558683518441, 60.343672537034564, 63.637957496027795, 62.76854061311292, 68.19031915357037, 63.514316543456054, 66.19692356355729, 61.44872580805133, 58.031737342957534, 59.098571039015255, 55.43564604174707, 57.6134204864502, 58.072745723109094, 57.70263479601953, 58.61981045815253, 58.04594024535149, 52.74233879581575, 53.56002746089813, 55.871625331140336, 54.921046764619895, 59.49481671856296, 64.86803239391696, 68.98303801013579, 64.65179604868736, 63.5487667206795, 61.52847936076503, 61.85899788333524, 60.8226723824778, 61.10889557869204, 61.17773317521619, 65.23817862233808, 66.66709807611281, 66.23843792946109, 67.18580015244024, 68.30763724542433, 70.55477096188453, 68.56479567866172, 63.862948571482015, 67.27558320568454, 62.22043252760365, 59.018064391228464, 60.99957912198959, 58.39287388709284, 65.45898845118862, 68.91070165941792, 67.16701199931484, 70.19904336621686, 69.87547136122181, 74.00206365892964, 66.30249807911535, 64.54591166588568, 52.81353765918363, 50.22929191589356, 50.70502442698325, 75.70866338668331, 68.80282079019855, 61.996606396090606, 53.13977687589584, 41.82774759108021, 47.28264662527269, 42.987282583790446, 21.55071766145768, 34.706508036582704, 8.021938320129149, 0.025536832324559652, 0.6412991881370544, 0.09885653733245789, 0.04352181887013778, 0.01993127696726832, 0.12877000315535453, 0.03243455009895467, 0.38988996897974326, 0.07551789854563053, 1.458082153431831, 47.23376212581512, 45.255165638462195, 29.62016667089155, 44.24139376609556, 23.69945872214533, 0.36806881247508916, 0.09149213411634968, 0.0450134878197024, 0.04847489139666, 0.058192119167576876, 0.06361078546052018, 0.011953855939810316, 0.010869197055487143, 0.04706037516194967, 0.14123619954672553, 0.09025081120912107, 0.09548547467397106, 0.0663030559136983, 0.06749027003083499, 0.04150092489116135, 0.03431398211227309, 0.07326182323477923, 0.08909150567506591, 0.039921025595357346, 0.01775645485688602, 0.04184726175040968, 0.028924781476117434, 0.04515667348319004, 0.025602095354829105, 0.11369674827062315, 0.1301503403773231, 37.799014506801484, 66.5053395302065, 50.42080556192706, 33.47272257651053, 44.07524216559626, 63.436673225895056, 0.049301890971800016, 0.41697871540823295, 0.9894888463520235, 0.19040257339515995, 0.13154652029756578, 0.05720800262004618, 0.14519198647429868, 0.06599073718872762, 0.11314786159463468, 0.5942772629280245, 0.04190500562770232, 0.7207680012910598, 50.55908479998189, 64.05785506771457, 61.62357722559283, 68.70501256758168, 67.44499821816721, 66.59713868171939, 60.899464545711396, 62.508597297053186, 56.83285313267862, 57.73349600453531, 65.45120254639657, 64.96530325182023, 67.73160580665835, 72.838194447179, 71.99049180553806, 76.68887153748544, 80.30595579454976, 76.68530218062863, 71.37835102696573, 74.28427034808745, 84.82697379204535, 82.67354549900179, 82.36840078907629, 82.42918968200684, 83.35835995212679, 77.71483021397745, 75.0329331428774, 78.57565710621496, 76.85270109484273, 73.1236880825412, 75.62747032411637, 72.12865337248772, 75.52309605383104, 73.98980232977098, 77.17694774750741, 78.16367487753593, 77.3847706087174, 74.53520790223153, 76.01091338742164, 72.64169939102666, 69.05033019281203, 62.67340352458339, 70.01156976146083, 73.0096020237092, 71.28462991406842, 72.76442250897809, 71.0405251287645, 64.35594343370008, 58.899040068349535, 62.16866900843959, 63.87357819464899, 57.61606416394634, 60.25012400842483, 61.89582109451295, 62.27650673158708, 66.75841869846468, 67.43054036171206, 69.94191631194084, 65.57640852466707, 67.69151918349728, 64.61715759769564, 61.098262033154896, 60.73229705133746, 59.84083252568399, 58.140112430818625, 59.82229540424963, 60.3015737379751, 59.939848838313935, 63.51887041522611, 57.13844107043359, 57.0457083948197, 59.678199291229255, 58.060311809662856, 60.96254802519276, 64.84059541456162, 69.96225772365447, 71.04690290266468, 67.73908968894713, 66.12493238141461, 63.981788542962846, 65.06393517217329, 65.03940074674546, 64.51361094751667, 65.98049502218923, 65.35120956359371, 67.11419336257443, 67.60454454729634, 67.2926768948955, 70.94564299429618, 72.37036551198652, 66.26114060801845, 67.1547742043772, 66.93603930934783, 61.44430137449696, 64.82169351270123, 58.53338103140555, 64.74703119647118, 73.6249356116018, 68.4713726658975, 69.50827475517028, 70.22879846634405, 73.87188803765082, 67.77680720052412, 69.39219613229075, 57.508069545991965, 56.84956242961269, 53.13516024620303, 71.21110116281818, 78.10747515770697, 68.37238773222893, 64.82877731323242, 55.710157040626775, 53.469373641475556, 64.86438458965671, 39.28041135111163, 42.56383526709772, 14.61930121144941, 0.07507476264670973, 1.1858776307875112, 0.08131620353989064, 0.09300335746018157, 0.08282197233770164, 0.14736307965170953, 0.04622576067284231, 0.27627140764267216, 0.075275439378475, 1.9802555273617468, 54.540435652579035, 45.116070547411525, 29.05722418139058, 54.760433550803896, 31.01748162700284, 0.1771262083803454, 0.0862607112034194, 0.09238931500623304, 0.12006123054532275, 0.1210337408608006, 0.07608501811421688, 0.0437180293093045, 0.027748392181350823, 0.018275519645202066, 0.060465021599685, 0.1331080986006606, 0.026533217770197702, 0.06173269410106925, 0.1740107432969155, 0.1698980768842082, 0.11025234801514495, 0.15916771315518888, 0.152529637900091, 0.21076465416098797, 0.19380260949894307, 0.30317788643221705, 0.17607867507444275, 0.3222395635900959, 0.22552488551985836, 0.25886478683640884, 0.1791051667063467, 46.66945072912401, 79.87421266494259, 53.41551949900966, 62.93418230548982, 52.30934443012361, 72.45418656256892, 0.28034947752471895, 0.9604441855222949, 1.6414269732852138, 1.0661219084455122, 0.4443346426611947, 0.3436290142276595, 0.3584516204653248, 0.29303767087478794, 0.4164337204588998, 2.180711319369655, 0.8796537174813209, 2.327619771803579, 72.76053936250749, 77.76989244645642, 72.72583423122283, 81.37387598714521, 77.60680029469152, 77.11309940584245, 69.9824579300419, 74.9772511759112, 68.78485633480933, 72.073528382086, 75.83992942687004, 75.01395671598374, 73.87685375828897, 79.6126219534105, 77.3484573056621, 80.93992064076086, 85.4341096262778, 82.69248270219373, 76.63329155214372, 77.00373588069793, 86.59204036958756, 87.22929216200306, 88.67582305785149, 86.81594494850405, 90.69586723081528, 81.635937383098, 79.00914176817864, 82.55090867319416, 82.88979361134191, 77.10603913953229, 82.90619696340254, 77.30268324575117, 81.39976363028251, 78.51973195229807, 80.8846152213312, 85.29103725187241, 79.32328439527943, 77.93073315774241, 79.00453690559634, 75.86011394377678, 77.65681051438855, 66.83078642814391, 71.5436710849885, 79.01580979747158, 76.08256724572952, 77.13024016349547, 76.36234991012081, 70.56620859330701, 64.24699567979383, 67.64917327511695, 67.26756588105233, 63.399646051468395, 64.63986812099334, 64.2336674659483, 68.95988818137877, 70.63940786546277, 67.1258584914669, 72.07694868887626, 68.58025766188099, 71.82562674245527, 68.21589300709387, 65.33002484229304, 65.21821768053117, 62.80969019859069, 62.77501252389724, 64.04036129674604, 63.595270341442486, 62.522058871484575, 63.20632419278545, 60.449588298797615, 60.572821324871434, 62.39840615180231, 61.96919295095629, 65.07774191517984, 70.27412537605532, 72.90568274836387, 72.21116435143256, 70.57351989130821, 68.31892582678026, 66.91969871520996, 70.20989264211347, 68.12204637835103, 68.69197460912889, 72.58270694363502, 70.64812337198566, 72.6081003681306, 70.89083963824858, 71.50192137687438, 75.23596286773682, 73.57629037672474, 67.84442886229485, 70.9857217727169, 68.29904725474697, 63.40860474494196, 66.13683285251741, 60.907489715083955, 68.52592499025407, 74.80683988140476, 71.91897130781605, 76.9465006551435, 74.75582553494361, 79.29735752844041, 74.94838253144296, 74.72840032269879, 64.1749809634301, 64.54562533286311, 62.30838775634766, 71.1294452605709, 76.19309963718538, 68.73497947569817, 66.35857228309878, 60.2130066194842, 55.99985937918387, 72.99804672118157, 48.65946131367838, 56.90463642920218, 14.374339388262841, 0.19505514793338316, 1.9511054528336373, 0.3311523530752428, 0.3635372185418683, 0.12045677706238725, 0.4451983914740624, 0.17298567168895276, 0.6942496532874723, 0.34733424443871747, 4.234326568342024, 62.861128161030436, 63.914076666678156, 44.42834569561867, 60.591432971339074, 34.70259351115073, 1.3207537224215846, 0.18920278777518582, 0.26944173379771175, 0.2054831980457229, 0.31630707063501884, 0.12909139236134867, 0.11429009102885762, 0.15896301446182115, 0.12512668817033692, 0.31408265773807803, 0.29380219597970286, 0.19762528098879323, 0.14266427936813525], [0.07107772954529332, 0.053785838066570224, 0.0617320774002902, 0.013352939333286018, 0.04029694493980177, 0.03676308476696572, 0.029069143084568844, 0.04003167167426117, 0.11987071213943344, 0.0461565867637194, 0.05470672171683081, 0.12286056178591906, 0.11788017056401699, 39.922130723153394, 44.308262332793205, 43.85007066111411, 27.089382833050145, 44.121475142817346, 39.61944533932594, 1.0184748554902694, 0.6865426249081089, 0.31054333152790226, 0.2510131210569413, 0.10904518496846, 0.13986666416448934, 0.067973640867539, 0.1958566137980069, 0.21567693250554226, 0.34298332468155895, 0.3513744695773048, 7.6522887618311, 49.07193383862896, 44.00795390529018, 49.52822708314466, 49.158371110116285, 55.17992319599275, 54.11328561844365, 59.034926660599254, 55.427993497540875, 56.8651460063073, 58.57032583605859, 53.6760276363742, 56.30370186221216, 63.76945103368452, 60.0594066035363, 61.734713662055235, 71.7746594644362, 62.646190120327866, 63.900081649903335, 69.21411268172726, 76.71886982456331, 81.78265756176364, 79.03128747017153, 79.36494781124976, 76.70467868927987, 77.92730500621181, 75.84668374830677, 75.65793929561492, 71.84068864391696, 69.8284892112978, 71.66629222131544, 69.78877129093294, 74.81488858499836, 71.6579532623291, 76.17879083079677, 70.88547383585285, 73.08852795631655, 73.98857855027723, 69.14208227588286, 71.72402951025194, 67.06772112077283, 57.82399685152116, 67.66508240853587, 70.86180625423309, 66.59855857972177, 71.39355413375363, 70.0536411039291, 65.57908750349476, 57.10764654221074, 60.72748430313603, 62.70567678636121, 60.83696942175589, 56.80887568381525, 54.89040913120393, 56.91959242666922, 56.44649967070549, 60.71879233083418, 63.854072247782064, 64.47254373181251, 64.16738333240633, 64.14198598554059, 63.69193323196904, 60.73684700073735, 60.61402974590179, 56.9073820883228, 53.95861479543871, 55.47975701670493, 56.15144721923336, 57.70387034262381, 56.425742487753595, 56.428166512520086, 50.31788256860549, 54.947915000300256, 59.23601481222338, 56.3307426821801, 55.36685159129482, 60.74184410033688, 65.52799078726, 67.50311205464025, 65.31875979515814, 63.74790545432799, 62.81847630777667, 60.30125994836131, 61.12474587655837, 64.90581266341671, 64.13434128607473, 63.82230889412665, 66.12479902082875, 66.84886855463829, 70.62631499382758, 68.17040920257568, 67.34326762537803, 67.36145173349689, 65.37347293669178, 57.747698906929266, 59.94135110608993, 57.96111114563481, 59.46502631710422, 70.10533009805988, 66.33768958430137, 69.25186157226562, 68.47316911143642, 73.13798119944911, 67.8651782005064, 61.65152019070041, 55.27993971301664, 52.32110761827039, 43.37766431993054, 55.17877001916209, 76.36904931837513, 53.87944567588068, 57.94415866175006, 39.10104528550179, 41.21490470824703, 45.744493084569136, 31.318080309898626, 28.77716498990213, 26.91858518508173, 0.5825487019554262, 0.26228300986751435, 0.055347592569887645, 0.056399484916079434, 0.06621011412672459, 0.0737655183841144, 0.051136525993746136, 0.06365409241087976, 0.0706360568743079, 0.349767615477885, 30.97657522847576, 50.513738278419744, 20.403993129730225, 40.828614004196666, 31.728730893904167, 0.10575914274780981, 0.06289053257674941, 0.04757831188579721, 0.03227953220747652, 0.06139481485250497, 0.038373956997548385, 0.1137400858644997, 0.09688975980445262, 0.05321990210382689, 0.042879737598160585, 0.02727424312803534, 0.03165459023758529, 0.07131265806815318, 0.04298523939665287, 0.05699127634626724, 0.03193639376531205, 0.042536867286769614, 0.030780451357244488, 0.059842766683188185, 0.056133411088657964, 0.047679795553126646, 0.09775314855599597, 0.07340784725402633, 0.09706674143671991, 0.07403518899434036, 0.04425875331845976, 48.064488749350275, 52.76563375226913, 49.8593065046495, 35.13281868350121, 48.38627607591691, 45.70688539935697, 1.179868437109455, 0.5781098659480772, 0.6266849884583104, 0.14134093908773315, 0.09908837852098289, 0.10666369340352475, 0.10551013352890169, 0.4109850886367983, 0.3088404712898116, 1.1210137629701247, 0.3040459866244947, 16.823445750821023, 71.16356203632971, 58.52959594418926, 68.0763429211032, 67.84736279518374, 70.41700947669246, 68.61235833937123, 71.00891866991597, 64.91590884424025, 63.34747852817659, 63.36546259541666, 59.36679447850874, 63.96028218730804, 69.25372862046765, 63.8418972107672, 66.68467029448479, 75.95452539382443, 66.88304808831984, 68.51836266056185, 73.46809571789157, 79.2573336632021, 85.28734237917008, 81.75931945923837, 81.3617793975338, 78.77564307182067, 80.84558763811665, 77.67218620546403, 78.50907095016973, 76.48624973912393, 75.03560035459458, 74.09791854120071, 75.15754684325188, 75.74749485138925, 76.91123070255404, 78.03117721311509, 75.01578454048403, 76.03681672003962, 75.81233163033762, 71.43981456756592, 73.85218989464545, 66.88850018285936, 62.41833179227768, 72.2111878856536, 75.12181405098208, 69.80628075138216, 73.60744184063327, 72.02708751924577, 64.40209404114755, 59.29823537026683, 62.22563751282231, 64.34181897870957, 62.85631149045883, 60.084858863584465, 56.96649612918977, 60.63142153524584, 60.926066060220045, 65.82989954179334, 68.48730533353745, 69.34581802737328, 67.50792088047152, 65.94189889969365, 65.75340547869283, 63.16293885630947, 64.09061862576392, 58.671401393029, 56.90641326289023, 57.74636530107068, 57.9255783942438, 63.26612464843258, 58.191530781407515, 60.58425111155356, 56.88916267887239, 57.42427595200078, 63.14507246017457, 61.481963972891535, 58.460770114775634, 61.69391708989298, 67.5368679723432, 70.79238814692344, 67.95656158078101, 64.21060785170525, 66.69735523962206, 62.95256645448747, 62.81130621510168, 65.75364474327334, 65.05280740799444, 62.99045655035204, 67.40742975665678, 67.95792656560099, 68.79324236223775, 69.28437017625379, 68.80422499872023, 68.7733559454641, 68.4486307636384, 60.30535882519138, 61.92644303844821, 59.509419702714496, 60.10183880406042, 70.10809929140153, 71.20357021208733, 70.24470759976295, 67.66552955873551, 72.00711481032833, 69.2725795315158, 63.85862219718195, 61.99534339289512, 55.73590740080803, 51.018147237839244, 51.85236477082776, 78.99199316578527, 66.05240775692847, 66.34878204714867, 57.25158576042422, 50.278298008826475, 56.791130881155695, 51.82780288880872, 40.075413027117335, 33.72819439057381, 1.1201068374418444, 0.2559475546642657, 0.29099944798696425, 0.1179947849783686, 0.05251930320575353, 0.158088494452738, 0.005518224206753076, 0.02246285090222955, 0.07614904774292823, 0.010053090293020492, 36.651328994381814, 54.34034378297868, 23.97305973114506, 51.32986191780337, 38.92115362228886, 0.15391435714498644, 0.03985010500576708, 0.11191539466381074, 0.06342697798484756, 0.0983061261415001, 0.06551514980533431, 0.05950764918159093, 0.04919370403513313, 0.017067745643397494, 0.08863589020385858, 0.06420547270306176, 0.06404723724230163, 0.09235527005887802, 0.14848487752099193, 0.13109008511227946, 0.16139492993393253, 0.14356791071834105, 0.11417509357054388, 0.12017422851415412, 0.14686748205173403, 0.18655249127937903, 0.2797983538719916, 0.1703308859179097, 0.1735187463101841, 0.24705509715262922, 0.23789288476109507, 56.15854670924526, 63.04797418655888, 57.12717994566887, 42.70720966400639, 62.01639867598011, 59.47423996463899, 1.6581302640899536, 2.430812182926363, 0.5945457614237263, 0.4986233408412626, 0.20928869384431073, 0.3423059803824271, 0.1779223882382916, 0.9016473050559721, 0.4876174459293966, 2.778180717460571, 0.4723006516935364, 27.105896011475597, 91.91960750087615, 70.35480068575951, 82.01626608448645, 77.47069404971215, 82.74392066463348, 77.35298372084095, 79.5137546908471, 75.55959763065462, 76.25179398444392, 77.0992063706921, 71.37375400912377, 74.1845166298651, 77.6240038102673, 72.72006050232919, 75.13710344991377, 84.21870831520327, 69.47233015491118, 72.29523643370598, 79.3629317129812, 83.18413611381285, 89.20054205002324, 83.34361968501922, 85.09429900876938, 83.53454497552688, 86.32631547989385, 82.2335732367731, 81.17448622180571, 79.85091378611904, 77.65968168935468, 78.75562329446116, 76.70456886291504, 83.4106529912641, 79.67482289960309, 81.79188297640893, 79.87531092859085, 79.06544346963206, 81.62719049761373, 74.71482107716223, 76.77342214891988, 75.13944118253647, 66.45678843221357, 72.35822969867338, 78.72681740791568, 74.12208034146217, 76.01918958848523, 77.54972980868432, 73.10680620131954, 62.60848829823156, 66.91346214663598, 69.54050094850602, 67.87303863033172, 64.09562357010381, 60.99164024476082, 66.07701670738959, 62.957277221064416, 69.8466968536377, 70.86737601987778, 71.4983049515755, 73.73035323235297, 68.76548767089844, 68.87818521068942, 67.25608902592813, 68.28906874502859, 64.60302922033495, 61.53475907541091, 61.2209733839958, 62.37034943795974, 66.18194010949904, 60.22263211588706, 61.712387531034416, 56.39099421039705, 62.64789635135282, 63.98367128064556, 64.06885339367774, 62.10909605026246, 64.84698495557232, 71.08083140465521, 74.40653062635853, 71.95743406972578, 67.65258573716687, 69.35503559727823, 66.13650337342294, 66.18753340936476, 70.98452937218451, 71.99042120287496, 67.65104032331898, 71.63104580294701, 71.4382299300163, 74.16390849697974, 73.43921922868299, 72.1744195876583, 71.4209165880757, 69.57920689736643, 61.149805899589296, 64.6944792809025, 61.20471908200172, 63.952264862675825, 74.57647123644429, 73.48020015224334, 76.08470101510325, 73.5249936196112, 80.06793068301293, 74.44584062022548, 69.67356343423167, 65.52050690497121, 63.70336301865117, 61.65092399043422, 61.0446471552695, 75.28794211726036, 66.71626106385263, 65.31548069369408, 59.49606403227776, 57.06872486299085, 60.09890487117153, 61.17528169385849, 47.679508116937455, 42.319691258092085, 1.0702536351257756, 0.5626831227733243, 0.5591641438584174, 0.28738155179927427, 0.31133825500165263, 0.4360976040122971, 0.14141428434560377, 0.17133061533733723, 0.11897064309807555, 0.5913586517976177, 45.50564035292595, 67.1471255825412, 31.380234187649144, 55.147681313176314, 47.45834527477142, 0.18838837502464173, 0.13389491686417213, 0.21874987970917456, 0.14937430560108156, 0.18508766988112083, 0.12692257446507293, 0.2941506740546996, 0.17984493184954892, 0.1655856760278825, 0.1316079299055761, 0.14149267046201613, 0.15199052650601635, 0.17919101451914157], [0.05020838366040299, 0.07421201740902278, 0.06659214685280478, 0.009580507889510164, 0.035217226588077126, 0.03379149482615533, 0.020080233188045603, 0.058748279848406394, 0.049304844240748116, 0.022426071020984845, 0.07756485483579098, 0.06623011668242755, 0.5633684956739026, 53.498665901922415, 42.96956131535192, 41.85323907483009, 22.19924822930367, 54.55606237534554, 23.10896158218384, 0.8620214991031155, 0.33268661268295785, 0.20139575124748293, 0.2893706531293931, 0.11441084180748272, 0.2924678853202251, 0.1095734945228023, 0.1516905264748681, 1.2499311614421107, 1.2179935074621633, 0.04177283630856583, 17.61747467902399, 53.957489075199256, 46.923628161030436, 49.285879519677934, 56.185203136936316, 56.55577298133605, 60.841182047320956, 53.70084055008427, 54.326050666070756, 52.74516682470999, 52.77036020832678, 55.75347177443966, 68.31443863530313, 62.72417076172368, 62.96258418790756, 59.880424930203354, 66.04940322137648, 63.99955295747327, 67.65322900587513, 63.961392218066806, 77.19899931261617, 79.23709423311296, 80.79451053373276, 79.80031521089616, 79.38992546450707, 75.5393817347865, 74.70065347609982, 74.17070988685855, 73.73258898335119, 70.90131236660865, 70.00392113962482, 71.36234775666269, 72.8199318916567, 74.03388192576747, 73.15432179358699, 71.40245006930444, 72.55805876947218, 68.62908332578598, 73.57093241906935, 60.18990778153943, 61.2877909598812, 72.03945083002891, 73.81408014605123, 69.4669565077751, 72.7107644850208, 68.83711799498528, 66.29624582106068, 55.83824596097393, 59.621701471267215, 61.38772510713147, 59.82688457735124, 56.82581640058949, 53.80827819147418, 58.718387465323175, 59.7465975822941, 62.23279976075696, 61.81484376230548, 62.44465481850409, 65.50872018260341, 62.62205185428743, 64.05391308569139, 63.29740947292697, 61.41174177969656, 58.19371161922332, 52.19753726836174, 51.55671611908944, 55.03866687897713, 53.539117305509514, 58.61055758691604, 57.62171237699447, 62.73807948635471, 57.15029447309433, 48.02933646786598, 54.23982912494291, 61.7195733131901, 59.36196211845645, 59.42142917263893, 55.53848666529502, 64.11409793361541, 65.16662282328453, 68.44260600305373, 62.992307909073375, 59.684996758737874, 58.41329766858009, 62.80378310911117, 63.79717434606245, 64.32294061107021, 65.45600744985765, 66.42946520159322, 68.86348416728359, 67.90474707080473, 66.52682627401045, 65.44583282163067, 65.71782173648958, 61.286045505154526, 57.84906079692226, 56.95702360522363, 55.67081566779844, 64.4024117531315, 70.10439657395887, 64.76086539606895, 66.4860571584394, 67.41790248501685, 71.32637962218254, 61.382853523377456, 56.87045297315044, 54.26132763585737, 53.97168805522304, 33.30656705364105, 69.93509138784101, 58.13964174639795, 49.33143392685921, 48.877254839866396, 33.26356218707177, 42.66575021128501, 41.901546985872336, 25.118166285176432, 32.14404517604459, 6.846393192968061, 0.21192155417896089, 0.6384764912147677, 0.03009872695040559, 0.06739399576139066, 0.08442576974630357, 0.05867153316015198, 0.05250351413363411, 0.03846532830427732, 0.07044582958182982, 17.41616295230004, 51.6704373974954, 30.585742419765843, 43.090476220653905, 38.866573841341086, 0.0400803029356945, 0.017603436454890237, 0.05353379130904233, 0.04940739660073192, 0.06273462219283947, 0.041441438163840966, 0.0062151013539292884, 0.03528735810710538, 0.025720059488629623, 0.06111529618201237, 0.08047189803854113, 0.047009074084100225, 0.08015531220383222, 0.021981671076988982, 0.03701092570178932, 0.05401284907073264, 0.056185792350480636, 0.013935872871849327, 0.07288553616813115, 0.020648773849731492, 0.0949535032193507, 0.06260419955417033, 0.031651307550829746, 0.06125965012958454, 0.0817925876547252, 1.0918428508504745, 60.81771058420981, 51.843970898659, 46.22472455424648, 19.031271434599354, 64.06124007317328, 28.386908769607547, 0.9372385242773641, 0.1349670875577196, 0.2701639708492064, 0.09941510735980927, 0.12520731892436743, 0.13175215361820114, 0.15345173196927195, 0.05597839702761943, 2.1483240637087055, 1.7301851847479421, 0.05848478390685013, 30.9152489708316, 71.40670191857123, 62.53913687121484, 68.63674763710269, 70.74636305532148, 67.45946391936272, 69.69341062730359, 65.59881702546151, 64.51521519691714, 59.02658770161291, 61.48584319699196, 65.27397809490081, 69.213241915549, 65.46351094399729, 70.32816779228949, 67.85076741249331, 73.15129372381395, 69.48487389472224, 73.05955733022383, 69.64098422758042, 78.90819564942392, 78.79947539298766, 84.41742343287315, 82.33516262423608, 80.75330995744275, 75.67548013502552, 81.08568376110446, 76.23077792506065, 74.78094439352714, 75.1283722539102, 73.17099186681932, 76.36060837776431, 75.43404256143879, 76.03218832323628, 73.30192842791158, 75.80797779944636, 74.18103356515208, 73.84064243685815, 77.6327036273095, 61.6838405209203, 67.7831849744243, 77.5728011900379, 75.85258299304594, 68.36207189867574, 75.9006477171375, 69.84023278759372, 65.19868819944321, 58.9086655647524, 60.91245151335194, 61.89797055336737, 60.799208764107, 57.9649236894423, 55.75373457324121, 60.88963508605958, 63.07033561891126, 66.09354557529574, 66.17860609485258, 67.25783840302499, 68.12803975997433, 67.82182816536196, 67.43431368181783, 67.49135278886365, 64.47012755178636, 59.462300269834465, 54.0765251651887, 53.536477550383545, 56.40405178070069, 54.831785386608495, 58.1903854493172, 60.42128839800435, 64.6363183759874, 61.84215522581532, 53.81082773208619, 57.599366634122795, 65.47154788048037, 63.416265133888494, 63.563459919345, 58.80136520631852, 66.00132280780424, 68.652939181174, 70.53179371741511, 65.5165570782077, 64.70616402164583, 62.1681434108365, 65.47409742109238, 63.46432201323971, 65.59037608485069, 66.5071673547068, 67.25189208984375, 66.85599942361155, 68.10048903188398, 69.84512006082844, 67.7235649478051, 67.67466868123701, 63.291341566270404, 63.00299244542276, 57.534420028809585, 56.44459339880175, 65.52279364678168, 70.16808802081694, 68.07373846730879, 67.75699923115393, 68.02451272164622, 72.31171823317005, 64.23553843652049, 60.368093213727406, 57.129027382020034, 57.32412215202086, 39.39222635761384, 68.02993343722436, 72.07243796317809, 62.51410430477512, 65.60666961054649, 50.26700942747055, 50.17206845744964, 56.635522611679576, 44.11163783842518, 39.673197500167355, 10.367018522754794, 0.1763582052362542, 1.242048790858638, 0.04980262136086822, 0.1306124139697321, 0.04859825836554651, 0.11733308419465058, 0.02643051410784885, 0.04897836821093675, 0.12959245982910358, 22.11551739323524, 53.983537535513605, 33.65975295343707, 56.45971021344585, 44.84657233761203, 0.28137189846846367, 0.11292072418596476, 0.10572862180490648, 0.03452825307425472, 0.07625105235004619, 0.02038125211613313, 0.08905217472103336, 0.08970717223541391, 0.05969841273561601, 0.03693407559166512, 0.09967020697771542, 0.07691121329703639, 0.1097935609399311, 0.10699491151758742, 0.1567984943188006, 0.09369723393671936, 0.10228683390925009, 0.13124264386152068, 0.12009670041621694, 0.15309380036928963, 0.2391675018495129, 0.20153513328442652, 0.2313285990948639, 0.17176120271605833, 0.20272808540011608, 2.016014795630209, 77.45982123959449, 58.03935850820234, 57.71543741226197, 38.08440223816903, 76.33002173516059, 38.82294531791441, 1.3172180734334455, 0.57226590211353, 0.2938590397036845, 0.5163707788432799, 0.2806042170813007, 0.316021595630915, 0.4256129859676285, 0.1419759800116862, 2.1437731337162758, 3.8232040741751274, 0.12766876708595984, 45.049252971526116, 85.27199806705599, 74.25872787352532, 81.10273038187336, 82.9820163788334, 78.38248821996874, 77.54112412852626, 73.6758715106595, 75.09173731650077, 70.24667662958946, 71.21885176627868, 73.47656803746378, 80.05293938421434, 75.24740834389964, 77.02304178668608, 74.96265211412984, 78.04213631537654, 72.97619911932176, 78.26552314143028, 74.13817774864935, 83.35693220938407, 84.63018063575991, 88.52631799636349, 87.50468961654171, 86.54190463404503, 82.2146281888408, 83.59236071186682, 80.95968938642933, 80.77452213533464, 80.15404239777597, 75.79630482581355, 80.53458290715372, 78.47085137521067, 81.16755147134104, 80.89727663224744, 79.77039537122174, 79.11082529252576, 76.04429275758805, 80.47010698626119, 66.94418214982556, 69.65112747684603, 79.73996562342491, 80.31270227124615, 72.60417015321794, 81.16835947959655, 75.83682290969357, 71.22671219610399, 64.15457287142354, 65.2619795645437, 66.92779448724562, 64.3813015568641, 62.07084117397186, 59.20478097854122, 64.3364727881647, 65.91051209357478, 71.18229527627268, 68.20412589657691, 68.29234784649265, 69.52539982334261, 69.20466761435233, 69.48146927741267, 71.12283214446038, 67.17330348107123, 63.896943753765484, 58.77044123987998, 57.62239094703429, 60.92789780709052, 57.86528764232513, 64.43982331983506, 62.64833565681212, 69.20276918718892, 63.79948854446412, 54.747183784361816, 61.26454307186989, 71.27914644056752, 65.17070601063391, 64.93494018431633, 60.295749018269206, 70.63590126652872, 72.19615736315328, 75.24686705681586, 69.02550943436162, 68.02899991312336, 64.72510514720794, 70.33980938696092, 70.87715056634718, 70.24889669110699, 70.18837451934814, 71.55232383358863, 72.04434594800396, 72.30490115381056, 73.757919649924, 71.54586761228501, 67.92457857439595, 65.65425188310685, 62.057705156264774, 59.32778258477489, 58.264035794042776, 69.80639057774698, 72.35876314101681, 73.5574394656766, 72.07629757542765, 74.42750746204008, 77.83469784644343, 70.33629494328653, 65.14431630411457, 63.87081684604768, 66.08293164160945, 52.24606875450381, 70.02532943602532, 67.777191592801, 61.02170128976146, 61.881814310627604, 55.98145954070553, 56.38361230973275, 64.81823398220924, 49.631048094841745, 48.74407468303558, 11.513968590767155, 0.492461419874622, 2.3486373020756632, 0.204803831274471, 0.3191095121925877, 0.22231980347104613, 0.25024537838274435, 0.1951318639781206, 0.13170336913918296, 0.29791853961444675, 27.567005926562896, 66.31517517951228, 47.046088480180316, 55.15962885272119, 53.79781330785444, 0.30720049154854595, 0.17058839871277734, 0.22302267381981497, 0.20721588974758504, 0.15552781492231355, 0.18076713317103926, 0.1767115862739663, 0.26834867954734837, 0.13556135728234245, 0.1006502939027644, 0.2855856272001421, 0.11065365551340003, 0.11640596458868635], [0.09771414701977084, 0.03817857776377951, 0.06693403657165266, 0.11449841331810721, 0.031163081631905613, 0.1149815466675547, 0.14065683789310918, 0.06323579308246413, 0.0897656936919497, 0.04603554870212271, 0.09825351888373976, 0.18660931968160216, 3.82872260385944, 59.18814620664043, 35.912440746061264, 47.89136709705476, 36.45896811639109, 69.28864555974161, 12.343737175387721, 0.3767381392178997, 0.18016575415047908, 0.03601782677334643, 0.15253254903420327, 0.05940892343078891, 0.1787310246858866, 0.2424010670473499, 0.08140872397850599, 0.716213945659899, 0.8324857452704061, 0.3745265353110529, 34.754160911806174, 51.69270861533381, 47.35260209729595, 52.51335474752611, 62.75594588248961, 58.35751764235958, 65.70172040693222, 59.65597906420308, 56.723469995683246, 45.83366032569639, 48.92337799072266, 59.05784899188627, 57.258673483325595, 62.02239597997358, 63.80248523527577, 63.81636650331559, 69.07643748867896, 66.32872304608746, 67.89341926574707, 66.61058456667008, 77.1586851919851, 77.33567037890035, 76.01532213149532, 79.68309910066667, 73.66994873169931, 76.6214930626654, 78.83862064730737, 72.5288292669481, 69.48795687767768, 69.36416687503939, 69.969098337235, 70.13479494279431, 73.12774381329938, 69.46579548620409, 69.10834204766059, 67.94625359196817, 71.63599583410448, 74.12198620457804, 62.97594378071447, 66.10689732336229, 75.64676054062383, 72.56573092552924, 70.75689854160433, 72.12068311629757, 69.38828945159912, 64.71523254148423, 56.65757417678834, 59.48641500165386, 59.3144622156697, 56.62439484750071, 54.4661694957364, 57.14779592329457, 54.2894627971034, 52.67425821673486, 57.843400816763605, 64.5377335240764, 65.47183813587313, 65.56672419271162, 67.79914117628529, 62.49969351676203, 62.863163871149865, 65.09909529839793, 59.528247079541615, 52.228888773149066, 48.363538096027995, 50.959601940647254, 53.88652947641189, 50.549306331142304, 56.78511396531136, 55.66898392092798, 56.026107880377005, 59.05862954355056, 59.61407638365223, 49.41426261778801, 55.54251101709182, 62.69946767437843, 62.63490153897194, 61.92161067839592, 58.16010867395709, 59.384182345482614, 62.08919394400812, 65.34354525227701, 64.1454690502536, 60.79557272695727, 59.83944008427282, 59.80917507602323, 65.01132049868184, 65.99820060114708, 67.1533150826731, 64.09005380445912, 65.70063391039449, 66.90600179856824, 64.32752586180165, 66.49749478986188, 66.07451423521965, 64.32504300148257, 57.102339575367594, 57.905119311425, 60.04856517238002, 65.7966927559145, 64.47990602062595, 67.80948838879986, 64.50320489944951, 69.76947322968515, 61.07691257230697, 59.775058300264426, 56.82716177355859, 58.36533100374284, 34.40626236700243, 44.021960689175515, 70.19647813612416, 42.48960441158664, 46.084460596884455, 36.407475240768925, 34.29764801456083, 44.152242214449, 32.665551747045214, 31.86265433988264, 14.309115275259941, 0.2649953594851879, 0.6415012514879627, 0.04866668916938286, 0.10100500793346476, 0.04408847112509032, 0.058093853069529425, 0.030446228263298833, 0.0249889875281482, 0.19504342678814166, 7.174259212709243, 51.88054307814568, 40.888755706048784, 26.971523454112393, 49.126901934223795, 0.45101520515257315, 0.0488187691136714, 0.030620090002494476, 0.06844342896534551, 0.023808172160399058, 0.013972001578358394, 0.09445638110440585, 0.01677023348278336, 0.0632763076423397, 0.023224192911819107, 0.05651446705263469, 0.070298173795304, 0.09952003842279797, 0.014804249813389635, 0.04382238580634998, 0.0556024240570203, 0.023559461715781403, 0.036328092382680026, 0.05623050507218127, 0.15004967339336872, 0.034787271231893575, 0.026623026257561102, 0.05358600403152166, 0.12530905540071188, 0.2528467525037066, 5.381407055162615, 69.72268719826975, 44.94101124425089, 44.75447508596605, 31.06551693331811, 78.90387319749402, 14.894263282898935, 0.5487489027361716, 0.22903356821306292, 0.060831135018698634, 0.06441317063065306, 0.2357985382719386, 0.05481593138087661, 0.19228587798293562, 0.22271072281704796, 1.3422093324122892, 1.7289351744036523, 0.20589448000875213, 45.868898899324485, 65.3641337733115, 62.13596036357265, 67.77195915099114, 71.02732243076449, 68.53982587014475, 71.08411835085961, 69.3832923519996, 65.66291247644733, 56.79319012549616, 58.60195975149832, 63.32090447025915, 64.98454639988562, 69.0549664343557, 68.42369233408283, 68.59587653990715, 76.18768676634758, 72.22235879590436, 74.11555351749544, 74.38320821331394, 80.95706924315422, 80.27489846752536, 79.06255660518524, 81.19482763351934, 76.45450991968956, 79.83657360076904, 81.9357241353681, 75.28975425227996, 73.38809505585702, 71.69154444048482, 75.1912086240707, 74.75110300125615, 76.51183143738778, 71.21557266481462, 73.32533713309996, 71.46649452947801, 76.5113058397847, 75.1802573665496, 65.66712902438256, 74.63606772884246, 79.79355304471909, 74.58732051234092, 73.81837906376009, 74.59519663164693, 70.22646073372134, 65.79905402275824, 57.288824742840184, 59.88764209132041, 62.634587749358154, 59.55806885996173, 56.5687717160871, 59.461429503656205, 55.921294304632376, 56.720755715524, 58.89327418419623, 68.59531171860235, 66.94919493890578, 68.95591089802404, 70.19235180270287, 65.69886492144677, 66.24897341574392, 67.87132063219624, 61.29549449489963, 54.494743962441724, 52.594300700772195, 53.48529846437516, 55.16654006896481, 53.7295130760439, 58.342443973787375, 56.87381052201795, 59.647357694564334, 61.66182033477291, 64.28378358963998, 54.23419267900529, 60.06474494934083, 63.95661084882675, 65.0157880783081, 66.07968391910677, 61.992382003415024, 59.59808880282987, 64.67767976945447, 67.88394281941076, 65.86777394817722, 65.50839070350894, 64.19599702281337, 60.776415871035674, 66.40395410599248, 65.0119637673901, 68.29849812292284, 66.78049379779448, 66.9145211865825, 67.20960893938619, 66.84962949445172, 65.17048243553408, 68.01640910487022, 65.97352104802286, 57.85712126762637, 58.59063586881084, 61.456503868103034, 69.04790616804554, 68.59195416973483, 68.73172390845515, 66.77937199992519, 68.2739911540862, 62.09814871511152, 62.36104165354083, 60.9038850568956, 58.94632816314698, 41.69632857845676, 46.85671252589072, 78.69940004041119, 60.68542472777828, 60.171986472222116, 54.9357948764678, 45.719268321990974, 48.60399507707166, 47.80469056098692, 45.501141394338305, 17.75951547007407, 0.5394371959470934, 0.44748887179359315, 0.3754937059936985, 0.16332977691725378, 0.038239462601561705, 0.10674378789600827, 0.032130913065385916, 0.04997276182797167, 0.17387813347722256, 9.474086050064335, 58.20786745317521, 38.938855278876524, 34.667017613687825, 58.10195169141216, 0.92551406953604, 0.05317811200755739, 0.04997925442312995, 0.06260219623424834, 0.03154173016458029, 0.045857023402688005, 0.06094690239537628, 0.024607841548840367, 0.07335334009821377, 0.028844121993789752, 0.08824550711940374, 0.02151841579395677, 0.02515357768824024, 0.16438195271597755, 0.09237364084730226, 0.22593618280464606, 0.19047973377089347, 0.19570742583563253, 0.19312685866269375, 0.2334975931913622, 0.20279522534580002, 0.20707552711809837, 0.17562544213667994, 0.18694747089137956, 0.45349794289758133, 6.415020237045904, 84.5401700850456, 48.06175093497, 63.22374736109088, 55.561346238659276, 92.35493567682083, 21.895097840216852, 0.9984078871146326, 0.47375808800420455, 0.07168008149751733, 0.3883166695314069, 0.59070888666376, 0.3934892645526317, 0.7441585042303609, 0.8121119127158196, 3.3350143605662934, 4.2480509415749586, 0.7878047396098414, 65.54808901202294, 80.9262001898981, 78.63182544708252, 81.17042264630719, 81.24559879302979, 74.96096549495574, 78.05345627569383, 79.61353194329047, 76.0777662646386, 72.11055555651265, 72.83791203652659, 77.30531907850697, 77.01762107110794, 78.0576139880765, 79.10655775377828, 76.3889592693698, 79.51090705010199, 75.82768378719207, 82.16079758059594, 80.13301849365234, 85.42575497781077, 83.65096876698156, 81.55413243078416, 86.4241550814721, 82.48458923832064, 82.13116015157392, 86.6007480313701, 79.32359034015288, 76.88376626660748, 76.32134545233943, 79.05392739080614, 77.65574362970169, 79.8206409331291, 76.57896672525715, 75.26088560781172, 76.29962336632514, 79.10903669172718, 79.51081291321786, 71.38259503149217, 75.70782399946644, 83.75681000371134, 79.29145828370126, 76.14750600630238, 78.18352207060784, 76.14709807980445, 72.70987018462151, 61.19689395350795, 65.58065252919351, 65.70167333849015, 65.00398958882978, 58.981119586575424, 63.374331074376265, 60.73159886944679, 60.173645634805005, 63.94877787559264, 70.21695290842365, 70.101713672761, 73.70295155432918, 73.1726392622917, 70.4873767975838, 70.84914484331685, 73.29082812032392, 66.51434529212214, 58.61928878291961, 56.064013665722264, 56.69139677478422, 61.31663214775824, 57.86385205484206, 63.3382531135313, 61.41173393495622, 60.3182202769864, 64.88529474504533, 66.76106237596082, 56.192977274617846, 64.75400909300774, 68.17617508672899, 68.63581411300167, 67.98693641539543, 63.85901051182901, 63.643287997091974, 68.54643114151494, 71.42520766104423, 67.87564308412614, 65.68538765753469, 66.12249266716742, 64.40747161065379, 71.55585396674373, 70.2391613683393, 74.12586935104864, 70.65826662125127, 70.67255973815918, 71.06641277190178, 68.69204521179199, 69.88515177080708, 70.93578215568297, 67.4209854679723, 61.28117784377068, 61.3540005683899, 65.77783400012602, 72.80690962268461, 70.8912318752658, 73.47453624971452, 74.66081003988944, 77.91900527092719, 68.57573909144249, 66.25040900322699, 67.88935569024855, 71.6323244956232, 50.06667044854934, 56.68630946067072, 73.74947870931318, 58.91580035609584, 57.21933995523761, 54.67456894536173, 50.0586845028785, 55.09749066445136, 52.77316078062981, 52.3500939338438, 23.037499920014415, 1.3143369699678114, 0.7353518026009683, 0.489513237750338, 0.32404952292000094, 0.352981997834098, 0.23155623446068457, 0.1501536315246936, 0.24002262451235326, 0.30098359611245895, 17.309929478553034, 69.455777752784, 59.67600276393276, 39.276873373216205, 66.22649823465656, 1.124704590728206, 0.17339784231397415, 0.1501349849446166, 0.1655244349592155, 0.1913161485666229, 0.13890044343086982, 0.21986263774095044, 0.08098577449638998, 0.15023431590487882, 0.07888292443127402, 0.17272016093615564, 0.19769831981149413, 0.09845946630042407], [0.10505890774150049, 0.0849425956426609, 0.05178582381397005, 0.06463493776297377, 0.07001041584918577, 0.02717910649915857, 0.12074037515107663, 0.02514217255426751, 0.013337991042663495, 0.11105109426763751, 0.12837758993790035, 0.5124835567849299, 13.755652173872917, 67.24517699210875, 36.29099653613183, 41.70250631147816, 23.465571711140296, 69.65863489335584, 3.76715928796799, 0.049221118491503506, 0.08088219940902726, 0.03541917119535708, 0.08374729163704381, 0.13353715380353312, 0.0638844933541071, 0.21603829617942535, 0.26464899581286216, 0.997512054539496, 0.3653447876774496, 1.691658561748843, 55.11636510972054, 52.34057826380576, 60.72122420034101, 60.86027222294962, 62.343336074583, 70.9974104358304, 66.62150444522982, 53.814169591473, 46.100809035762666, 41.77652535899993, 40.76112570301179, 44.82304596131848, 52.526886924620605, 56.48556647762176, 51.1393210195726, 62.10704072829216, 71.03311184913882, 67.65562949642059, 65.44726448674356, 68.4139491665748, 73.09208946843302, 73.6508232547391, 75.74732226710167, 73.58259754796183, 74.75721405398461, 72.85011845250284, 70.76543361909928, 73.60383326007475, 72.05841156744188, 74.05012053828086, 68.17735179778069, 67.84017701302805, 64.30774927139282, 68.73802323495188, 69.23377160103091, 71.80660324711954, 75.19455832819786, 59.94756021807271, 68.33754139561808, 79.28274277717837, 68.13355461243661, 73.65547518576346, 75.3610315630513, 70.37027051371913, 66.72171315839215, 57.20705509185792, 57.0281950120003, 61.22220893060008, 56.97103823384931, 54.81471523161858, 56.834704491399954, 58.217575319351695, 51.6215842769992, 51.922049599309126, 50.57860251395933, 61.67699990733978, 65.57558874930105, 64.31817493131085, 68.09076939859699, 64.09439979061004, 63.865584404237815, 62.21381941149312, 55.453257483820764, 51.84767753847184, 47.30878922247118, 52.579430995448945, 53.359178573854514, 50.77975342350622, 53.2783071456417, 55.13155644939792, 55.197562094657656, 57.30213334483486, 55.831817196261504, 58.18732992295296, 51.43869984534479, 52.92537619990688, 62.588629338049124, 63.4880131290805, 64.95484621294084, 59.73465788748957, 53.725814280971406, 59.710080315989835, 66.66098702338435, 62.371212359397646, 58.5703101465779, 60.39194122437508, 63.84373288000784, 66.329099593624, 64.97973365168419, 65.68990622797321, 63.00473397777927, 67.02550072823801, 64.127700713373, 66.15370688899871, 67.46846183653801, 68.2700687839139, 60.77977341990317, 60.0772729996712, 56.3338452769864, 60.62205099290418, 66.41483476085048, 61.343527840029815, 64.02681343017086, 64.03347361472346, 61.89579756029191, 60.810309071694654, 59.567580607629594, 53.151802862844164, 46.39968972052298, 30.28039570777647, 61.92527417213687, 52.51190347056235, 36.77518567731304, 40.68465125176215, 32.476601369919315, 41.86600638974098, 40.0159538176752, 35.26033493780321, 19.496693995691118, 1.8261981875665727, 0.16400324481148876, 0.5066920546514373, 0.10483647411268567, 0.0771919691995267, 0.05383073464937268, 0.0013413966136736676, 0.05551470698969019, 0.13058118822593845, 1.797137714682087, 31.56312058048864, 55.95776450249457, 41.46349276265791, 45.26238279957926, 1.1924359562896913, 0.052367529696634704, 0.049963905851566986, 0.045474711054515456, 0.04493198755587782, 0.14150488190352917, 0.06438770586804998, 0.10179331240754935, 0.06862437893306056, 0.05513682262971998, 0.029706782961805022, 0.0954901707929469, 0.033026341529142474, 0.054111919561100584, 0.016026511495452256, 0.020577121646173542, 0.007918578771603926, 0.11620007845903597, 0.0960100687018806, 0.0842427053759175, 0.17063608002518454, 0.0839944162796582, 0.11715532881357979, 0.07510788828855561, 0.43055667391707825, 17.146537265469952, 75.47465478220295, 46.453288908927675, 51.16710708987329, 30.437847491233583, 76.6700755396197, 4.842608715257337, 0.11591680978815402, 0.08965275701015227, 0.06649477707762873, 0.04473490760691705, 0.10325246475516789, 0.23696136781044547, 0.09629183584043095, 0.22200874113027128, 3.5266976491097486, 0.5511929683627621, 2.8171072996431783, 71.38039850419568, 63.73284355286629, 70.38847815605902, 69.4561307660995, 70.03439011112337, 75.50150732840262, 72.58950833351382, 63.23315320476409, 56.63578148811095, 56.69618206639444, 54.64444906480851, 60.683600825648156, 64.38564754301503, 64.07481539633967, 60.90383406608336, 69.7294258302258, 73.70210432237195, 75.79854842155211, 72.93512405887728, 74.51179135230281, 77.31911013203283, 77.3050445125949, 77.48759162041449, 78.0944371992542, 77.57047914689588, 74.19751536461615, 75.80210208892822, 77.25228863377725, 76.4484537801435, 76.95247050254576, 72.80679195157944, 69.13528088600405, 68.38035798841908, 72.72035075772193, 71.46647883999732, 78.03440140139672, 77.25764659143265, 61.85855857787594, 75.98093078982446, 80.3839325135754, 73.95687795454457, 78.1854675662133, 77.91017993803948, 75.19121646881104, 66.89081438126104, 58.97849159855997, 61.502878050650324, 65.2826936014237, 57.92069112100909, 56.50056169879053, 59.29843933351579, 60.55505691036102, 54.87855965091337, 53.12713507683047, 53.81080812023532, 67.29935276892878, 67.71426893049671, 68.30981023849981, 69.42697971097886, 67.05127854501048, 68.29590935860911, 63.346552848815925, 58.62014385961718, 54.19228215371409, 50.850760090735655, 54.007126669729914, 55.79858295379147, 50.473145669506444, 53.670583386575025, 57.963703832318714, 59.512220275017526, 62.84230470657349, 59.35534900234592, 61.99554343377391, 56.728518086095015, 55.8355865939971, 66.89068886541551, 67.28847211407077, 69.64525961106824, 63.48267478327598, 59.02495599562123, 60.35938555194486, 69.2946546308456, 66.13127093161306, 62.09490491497902, 63.84204626083375, 65.05088936898017, 67.42672781790456, 65.74654917563161, 68.24114522626324, 65.43060225825157, 68.232421875, 65.2832035095461, 66.4760394250193, 67.3778158618558, 68.01169441592309, 63.01612454075968, 64.15556523107713, 58.76258081005466, 62.06551067290768, 67.61071051320722, 63.36477225826633, 62.9722842093437, 62.925855113614, 62.48709878613872, 61.790085761777824, 61.99474327025875, 56.19619754052932, 51.96528980808874, 39.089521361935525, 64.77058895172613, 68.90150762373402, 56.55547095883278, 58.74594603815387, 51.69685063823577, 46.71913931446691, 50.71727791140157, 49.779788294146144, 24.866185380566506, 2.601161945250727, 0.22822407374699272, 0.7512090871891668, 0.15953091544009027, 0.015945926706697193, 0.1298131544383303, 0.02203221947345282, 0.13647438087049993, 0.2170600429657967, 2.573766641078457, 37.9381880452556, 53.93332335256762, 41.351320820470015, 56.172318150920255, 1.25410775023122, 0.11393212112447909, 0.1067630167029077, 0.08155477864127006, 0.0513423546668022, 0.07845727831966455, 0.013731151195843855, 0.10164940279097327, 0.02593635100751154, 0.055521747337714325, 0.04345153413352467, 0.016828689821845582, 0.0359658285554859, 0.11879297198667643, 0.15248082277755584, 0.16615336250153281, 0.14084400849476938, 0.21893355694990005, 0.2656163810001266, 0.266536942893459, 0.21168907713745871, 0.23257836429101808, 0.30927677368444784, 0.3612357678432619, 0.5869857606387908, 21.89987724827182, 88.78686535742976, 50.282789122673776, 60.23329311801542, 35.63952222947152, 90.51175117492677, 7.806184426430733, 0.1284686777920973, 0.3471702403358875, 0.2311446000972102, 0.21356678928338715, 0.2643326321436513, 0.9815013685053395, 0.4408129977603113, 1.1150038338476613, 7.057514767492972, 1.560984431735931, 6.320414629674727, 91.57389763862857, 74.25878278670773, 85.88086758890461, 78.66726013921922, 80.53187647173482, 83.54599045168969, 82.28534852304767, 74.77785356583135, 70.31980529908212, 66.90849642599782, 63.59823957566292, 72.1033227059149, 73.36362731072211, 75.23703759716403, 71.9389126377721, 79.98201508675852, 79.03085600945258, 80.41984573487314, 77.92362582299018, 80.20741801108085, 82.47105706122615, 80.72354701257522, 79.6101116365002, 83.79829299065375, 80.54503994603311, 78.56143459197014, 76.45139555777274, 81.91532781047206, 79.82557527480587, 81.14717083592569, 74.98444480280723, 71.17983202780448, 72.0081267818328, 78.03196953188989, 75.08971337349185, 79.1517513029037, 81.22725779010405, 66.29007201040945, 75.02436668642106, 85.62984374261673, 74.15021942507836, 81.91460609436035, 82.93550491333008, 78.68093352163993, 74.09225463867188, 64.20262582840459, 64.3766535482099, 70.14271813054239, 63.288419400492025, 59.49602873094621, 62.65951441180322, 65.26310920715332, 56.77029132843018, 59.20038400157806, 57.398980586759514, 70.09998782988518, 70.06059154387444, 71.02773820200275, 75.42307561443698, 69.45524431044056, 71.7208053219703, 68.53773916921308, 61.97668860035559, 57.30175679729831, 53.451154232025154, 56.40837423263058, 58.323510692965606, 54.50482445378458, 59.420778059190326, 61.61989412000103, 62.71012083176644, 64.49906679891771, 61.5436863899231, 64.43502233874413, 57.74403541318832, 59.41005429913921, 67.57602107140326, 69.07301718188872, 71.90059108118858, 65.99668656626056, 61.37924102044875, 65.71198917204335, 73.49028064358619, 68.573087569206, 63.787784191869925, 66.79975263534054, 70.39913915818738, 74.60941130115141, 70.17317141256025, 73.03194384421073, 71.2954007425616, 73.51054360789638, 69.82608087601201, 72.89837145036267, 71.49985821016374, 72.39863011144823, 65.43174759034189, 65.35297463017126, 61.613873281786525, 65.2976692107416, 71.98666357224988, 67.96220194908881, 70.77902070937618, 71.09994903687509, 69.27532519063642, 69.38866599913567, 69.06401926471342, 65.12770114406463, 58.884582211894376, 47.56055439672163, 69.56639643638366, 64.11543546184417, 55.451916033221835, 53.869486778013176, 53.825403259646514, 52.82045279779742, 54.377669057538434, 52.93806898978449, 30.677051275007187, 3.302902896558085, 0.8034783469573145, 1.6118763267032563, 0.4545400676227385, 0.12318289328006007, 0.32554422174730613, 0.0898012554933948, 0.24926988798524105, 0.34273247685163255, 8.297138675566643, 45.995944469205796, 74.63611479728453, 58.19005597022272, 60.54289756282684, 1.9767290714286991, 0.25079067976724717, 0.21351088018667316, 0.30198542461279904, 0.18699935036561183, 0.1873847998438343, 0.12751083806036942, 0.23158493211432812, 0.1514524723132772, 0.1389522003310342, 0.1963964299929719, 0.18159057043733137, 0.1538183663280741], [0.01790047938665075, 0.02377897271916511, 0.04066375932926613, 0.02887604679281433, 0.040826108682179646, 0.13552433991384122, 0.12728649687262314, 0.11187848454761891, 0.04220902379001341, 0.08011740617333882, 0.08622654368199649, 0.11412043319714647, 24.65218282515003, 58.48914061823199, 43.98689469983501, 34.19112428542107, 45.07001015447801, 53.865674234205684, 0.7979933412805681, 0.08783747336917347, 0.048279489180253404, 0.1576287804111358, 0.29768096042736886, 0.5311326802738252, 1.3758899896375596, 0.39654954066199644, 0.6557392713523681, 1.8297524678130306, 1.3258319660540552, 12.465415962280767, 69.15330809931602, 58.549827529538064, 64.6258887936992, 72.69209400300058, 80.10665232135405, 64.43675994873047, 48.45307011758128, 47.11365522876863, 47.96729633885045, 52.41559751572148, 55.842387983875895, 59.268241005559126, 65.3529824749116, 56.90729187380884, 59.42171550566151, 58.677045683706964, 65.14609313780262, 73.51572898126417, 63.55223017354166, 70.51805757707166, 69.61252350961009, 78.34935203675302, 71.82503054218908, 74.28703169668876, 71.1469154973184, 70.70979872057515, 74.12369635797317, 72.1674063897902, 67.79299874459544, 67.79002558800482, 68.8905563662129, 64.10362128288516, 67.74990758588238, 70.43152224633002, 73.26646235681349, 77.02530107190533, 62.919532252896225, 71.1857234278033, 77.78657820916946, 72.08486403188398, 75.84676219571021, 74.13205885118055, 68.65313529968262, 63.943565045633626, 55.678354463269635, 56.99296428311256, 58.86859855344219, 56.38036458723007, 54.876135626146876, 54.11624700792375, 54.92939749071675, 59.81828674193352, 53.55235922721125, 51.32631217279742, 53.071751209997366, 59.715552022380216, 65.00125177444951, 69.16713053180327, 70.5935553581484, 68.61365272152808, 65.71659403462564, 60.865414450245524, 52.34839162518902, 48.09394967171454, 48.60948247294272, 51.181631626621375, 51.40903495973157, 50.6884837919666, 49.911285754173036, 51.30187972899407, 50.753277424843084, 55.764583849137836, 56.500051790668124, 56.40831147470782, 56.95541543345298, 52.52698890624508, 56.953458170736994, 64.31083617671844, 64.22902730203444, 64.60666133511451, 65.36368270074168, 55.01654471120527, 59.53478174824869, 65.53960100297006, 58.37203041199715, 60.484144380015714, 60.842719616428504, 60.670194164399184, 62.1980397162899, 63.084942525432965, 59.829524332477206, 64.70105709568148, 62.86839631295974, 65.17353796189832, 64.14297834519418, 70.31392958856398, 63.25607553605111, 63.573681616014056, 61.123298521964784, 60.028400267324145, 66.13153765278479, 61.83918991396504, 58.20829106915382, 58.8582395738171, 61.65388930228449, 60.842750995389885, 59.37196416239585, 54.56235385710194, 49.75031952704153, 41.69965082599271, 38.0861908389676, 55.01944726513278, 41.140242392017, 39.18729820559102, 37.36584363445159, 36.96275341895319, 42.037523792636016, 37.70333220881801, 23.790347883778235, 3.5290069445486996, 0.16087875521231085, 0.2868890798380298, 0.14971182861876103, 0.0060430676920429595, 0.02804451772282201, 0.06854339577858487, 0.05850538401113403, 0.26516009903242516, 0.2842834615899671, 15.283078032155192, 56.418646920111875, 30.01031698719148, 46.85757152495846, 5.3578542028704, 0.34331424402133115, 0.16546969031614644, 0.10211424962166818, 0.04156068741013447, 0.04975245026270709, 0.04099966590142539, 0.055270439855033354, 0.0807792984790379, 0.033230350743378365, 0.01965773378258511, 0.09453019367591028, 0.036449582436152046, 0.10371625438452729, 0.07656802122871723, 0.048659219812121124, 0.011159599920163953, 0.00992139116034753, 0.06765080375536796, 0.07761023788442535, 0.10277339933259834, 0.046749998469867056, 0.03783297251849886, 0.06281959666540066, 0.09151855648885812, 32.70440870715726, 70.95152654955464, 56.3071378584831, 32.586414006448564, 45.385862934973936, 62.325002916397594, 1.2401645822871117, 0.04296421794401061, 0.08215223529165791, 0.010326833618173917, 0.18161398208429738, 0.4990741682629432, 1.6716458936852796, 0.43339935041243033, 1.1164484918117523, 4.288117462588895, 1.3140599525743917, 15.042168017356628, 79.69776092037078, 66.75131920845278, 75.28673402724728, 76.36264016551357, 83.98906138635452, 71.07112746084891, 58.115189690743726, 61.27805563711352, 58.389708534363784, 64.10744951617333, 67.16692570717105, 69.71314014927034, 72.01399464761057, 65.75785344646823, 65.34141148290327, 67.89275246281778, 70.52103857840262, 79.0971597548454, 71.20174238758703, 76.71504943601548, 75.95554521006923, 82.2768840482158, 76.86981047353437, 78.53462911421254, 75.1037476139684, 75.21457810555735, 77.27141411073747, 74.90925296660393, 72.48613034525226, 70.73841633335238, 72.432950850456, 67.4356080639747, 70.43133397256175, 72.8505342237411, 77.24476552778675, 76.58967479582756, 65.60808166380852, 75.13336150876938, 75.9022637336485, 76.58614466267248, 78.63963880846578, 76.56574833777644, 71.27496519396382, 64.07008109554168, 57.55120385077692, 60.69322239968085, 59.37844391792052, 58.95045057419808, 57.074008295612956, 56.51027348733718, 57.970944527656805, 60.061505071578495, 56.329883683112364, 52.11795629993562, 54.974512592438735, 60.58718112207229, 67.69890892890193, 70.68251471365653, 71.80253182688068, 70.11159804559523, 67.05359274341215, 64.8242038296115, 55.461439548000214, 51.20198480544552, 50.698207347623764, 55.982789224193944, 54.07430902604134, 52.16425987981981, 51.64695808964392, 51.28773566215269, 54.61363884710497, 57.742011470179406, 60.88463406408987, 60.86962315344042, 63.00094889056299, 56.92391487859911, 59.5555506983111, 67.19265645550144, 67.88628839677381, 67.52182960510254, 68.48039411729383, 59.52831375983454, 60.881762889123735, 68.65209194921678, 64.999396493358, 64.23444017287224, 64.24521884610577, 63.327423449485536, 64.94935097232943, 64.75273432270174, 65.5352040260069, 65.25219325096377, 64.85964244411838, 65.53696517021426, 68.62806350954118, 70.75444313787645, 65.4199569456039, 66.05108199581024, 62.34562673876363, 58.20191329525363, 66.83607378313619, 63.22863071195541, 60.5292869383289, 59.62782821347637, 60.78981076517413, 60.777910294071326, 62.78378294360254, 60.13580652975268, 54.088025554533935, 47.71033794649186, 46.208650681280325, 68.43222741157778, 62.31927233357584, 55.745242641818145, 54.14833199593329, 49.15485274407172, 45.71467914888936, 51.70076124129757, 31.716985356423166, 4.592651263360055, 0.23156437031444044, 0.43130976899016293, 0.2931411233880828, 0.030709762509251316, 0.07653330212398883, 0.0647375475795519, 0.14466307937137543, 0.2929718179568168, 0.4160249052989868, 18.211858887826246, 59.46351228221771, 28.346006293450635, 61.352619894089244, 8.062014156772245, 0.2977241677862983, 0.1277938769048741, 0.1557796739883, 0.0666571723958177, 0.03318961401800475, 0.0929128211892901, 0.026432348888427503, 0.11763666951728445, 0.05770868321339931, 0.04522404708569089, 0.02738057804714528, 0.05581933419190108, 0.18194807302807608, 0.163911406191126, 0.23230234281189982, 0.1375077109062864, 0.18695548417106753, 0.19992087877565817, 0.19170630182470047, 0.28333964126725353, 0.2134415185860088, 0.2507081414542852, 0.20648452092803296, 0.2702035622731332, 39.01694574663716, 82.83321734397643, 54.59852203246086, 46.94660540549986, 61.00464682425223, 74.79013058447069, 2.610493509038802, 0.16724177425907505, 0.28071039686760596, 0.2950328089777501, 0.5435238153703752, 1.2396148375926481, 2.869624649324725, 1.2228040493303731, 1.2324337132515446, 6.706796528831606, 3.609356697528593, 25.298389388668923, 97.4642542869814, 75.71210722769462, 86.66618885532503, 82.12108750497141, 92.6697607963316, 80.12796648087041, 68.63899123284125, 68.70344361951275, 66.04399819527903, 70.51352331715246, 73.25136123165008, 77.72946849946054, 81.67811070719074, 77.91003088797294, 75.06708914233793, 73.58978333011751, 77.83571766268823, 82.5881633450908, 74.0311284219065, 79.07862263341104, 78.87483981347854, 88.69086926983249, 80.29391411812075, 83.56819891160535, 78.19647373691683, 77.39042666650589, 78.87527911893784, 77.23136671127813, 75.1715575495074, 73.7103569892145, 76.37396797057121, 71.47467659365746, 72.97062935367708, 76.31609732104887, 78.67858794427688, 84.27306452105123, 69.58345874663323, 77.89445907838883, 82.41401795418032, 80.6045501462875, 82.7835601375949, 79.79210961249568, 76.07582076903313, 69.95510332046017, 61.12308671397548, 64.53290900876446, 64.06913188195998, 63.60555871840447, 60.089977556659335, 61.544929781267726, 63.94698143005372, 66.73582584627214, 60.38122923143449, 55.45201017010597, 58.70648699422037, 65.43952172802341, 72.44470227149226, 74.65359287877237, 75.70513325352823, 75.20386219024658, 71.42495662935319, 66.98480221533006, 58.791465144003595, 54.0792316006076, 52.930220327069684, 57.88781773659491, 57.47851448674356, 54.87759474785098, 55.831570086940644, 55.90866035030734, 56.721426440823464, 63.0955917604508, 61.9369157668083, 62.91947733971381, 64.37480611185875, 58.656092382246456, 62.99800711293375, 69.63791693410566, 70.04798504614061, 69.57763794929751, 69.75183825339042, 59.26746829863518, 65.7924448290179, 72.08484834240329, 66.4576905773532, 64.9393920744619, 68.48438709012925, 68.31358355860557, 68.5556879351216, 71.4340643728933, 68.65453950820431, 69.44175135704779, 70.16311445543843, 71.44881248474121, 71.70415878295898, 75.65870023542836, 66.41645862210181, 70.39565609347436, 64.53001429957729, 62.75310216411468, 72.11313647608604, 70.1788039361277, 67.6543664932251, 67.27759145921277, 69.64710312504923, 70.55992495629096, 71.98564375600508, 65.38398096638342, 58.26998210722401, 53.17687857535578, 54.38193659628592, 67.45363527728666, 60.71739204468266, 52.420363195480846, 53.37737444908389, 51.10734978029805, 48.603167456965295, 53.734871033699285, 34.8312041067308, 6.500277855703908, 0.5954792242377036, 0.8161900745284173, 0.45869324476488177, 0.28543326763376115, 0.19612339625675834, 0.2804598248293323, 0.34529216046775546, 0.5838866591934235, 1.5219792795758096, 25.179686700144124, 72.45492396816131, 44.03290802432645, 67.38231874281361, 9.131274819374084, 0.6742054224014283, 0.2330617198059636, 0.5602366056653761, 0.08999571159121492, 0.18455919178743518, 0.15356040920221037, 0.11505221061769033, 0.20432190068306463, 0.15206054694229557, 0.12693461736724262, 0.18153934979871397, 0.12476623614108372], [0.009705993091507305, 0.15280719155505781, 0.06455701129931597, 0.17231456334552459, 0.05216290761205939, 0.03631657042029885, 0.025363236800917698, 0.08483230196420224, 0.19442084245383742, 0.035686363511148005, 0.01397745420915946, 0.8320252344973627, 59.313207057214555, 39.446653166124904, 31.00228048140003, 46.54226395391649, 52.47125594846664, 40.15732780579598, 0.4686470864520919, 0.12424430809915067, 0.15358424985841398, 0.10941279225892599, 0.3376694324035799, 0.27224386892011093, 1.2769502858000419, 0.4322896260888346, 0.060895815822145635, 1.6287761037388158, 1.9712290504286367, 33.27949877708189, 70.25232484263759, 65.992826954011, 78.90247683371268, 80.37549157296458, 64.25455408711588, 51.72611544209143, 58.883727135196814, 62.13690565478418, 71.74783045245756, 68.12734157808366, 72.96687956779235, 66.40353833475422, 63.72498704541115, 57.257375178798554, 55.76466229654128, 64.23384005023588, 63.80021810531617, 64.77008688834407, 71.0064083530057, 72.13207367927798, 68.41281952396517, 72.76836056863108, 72.62069117638373, 70.99527666645666, 73.22427334324007, 72.07963943481445, 69.8859284001012, 72.61517632392146, 69.45704860071983, 66.93786713384813, 63.95782678358017, 68.36002442144579, 71.10700145844491, 72.8159938320037, 73.91234336360809, 62.36090044821463, 67.9319840092813, 74.96494277831047, 69.07462535365936, 75.01101493835449, 70.01441740220594, 67.6129384194651, 57.11645618561776, 55.48533070471979, 60.33481974755565, 60.373639445151056, 57.716304256070046, 56.482954179086995, 57.544920213760875, 53.57938828006868, 51.56560813227008, 57.34307896706366, 50.56404659824987, 48.71418622232253, 51.300153886118245, 55.626794907354544, 63.92930723005726, 67.03447511119228, 70.17193978832614, 65.09770285698676, 66.83683472294962, 63.33262451233403, 47.304615820607836, 48.419427948613325, 46.867506888604936, 51.64447915169501, 53.05703839948101, 50.452192368045935, 50.25542274598153, 51.69445407006049, 51.13175084514003, 52.420673062724454, 55.27122028412358, 60.35795780920214, 56.93013183532223, 60.08312909833847, 50.74260073323404, 61.52372544811618, 66.00364485094624, 61.031593507336034, 63.85475081782188, 65.96457019928964, 58.40608050746303, 59.88786174405006, 61.87030607654203, 59.428265863849276, 61.50507457794682, 62.00643585574243, 58.06801142231111, 59.46111571404242, 62.37817848882368, 59.777466635550226, 62.751148823768865, 62.592477183188166, 62.21123849191974, 63.22777171288768, 66.26867155874929, 65.0970321316873, 61.05153091492192, 54.59253649557791, 57.39517588769236, 57.52280981309953, 56.18468538407357, 59.96714853471326, 60.521991329808394, 59.853752813031605, 59.18272156869212, 60.11986601737238, 59.44215889899962, 50.33690214157105, 50.09238550739904, 45.33243633085682, 50.34061270375406, 40.21499449206937, 36.79506424934634, 35.30830552501064, 38.21799816623811, 38.730498975323094, 28.307920079077448, 7.118110483692539, 0.37794454383753967, 0.32869161737542, 0.4017612674543935, 0.07364212460215054, 0.009874916436421055, 0.09678916479911535, 0.095283510914493, 0.06797446058161798, 0.21310600271869093, 2.4553220935406226, 50.85592192988242, 29.414406976392193, 35.24920325125418, 21.733502072672692, 0.4950762618212931, 0.24503423381716977, 0.18778201643257372, 0.03713087974897316, 0.04927300562661502, 0.04184711619370407, 0.08711582620538051, 0.06450684020115484, 0.07154716524265467, 0.05090480737928903, 0.007391763567518924, 0.012889549984867054, 0.030206063529476527, 0.05353968252518004, 0.024680167909771688, 0.14897096030894788, 0.0013979441967920492, 0.07073066107207729, 0.13558305289235809, 0.04513544901724785, 0.07157958608361022, 0.04949146325910284, 0.05695326306346444, 1.6448031534110348, 67.96278245987432, 52.991150425326445, 40.00144889277797, 33.19611310958862, 58.315846381648896, 43.08274915141445, 0.8819073642934523, 0.058431176904348604, 0.1169714370682355, 0.19609374865408868, 0.17982581029495887, 0.271354777918708, 1.8164901988160227, 0.37598121370519366, 0.1983474107879785, 1.4885898583358335, 2.5483653718425385, 38.93339141722649, 82.20326116008144, 71.44272496623378, 79.79993081861927, 81.47475150323685, 68.56754133778234, 62.433248566043, 65.74817303688296, 68.93666774995866, 76.10422657382104, 72.67545530872961, 76.61306781153526, 75.42411896490282, 71.49803038566344, 65.91718012286772, 63.86342710064304, 68.99336168842932, 70.98984026139783, 71.96530234429144, 73.58381348271524, 75.29384136199951, 71.81041579092704, 76.31388510427168, 77.57994774849185, 75.97671031951904, 75.66922787697085, 73.99800008343112, 74.50504487560642, 77.6887386075912, 74.6572014593309, 69.46151225797593, 67.12219499772596, 71.53554393399146, 74.96165583210608, 77.0809595046505, 75.5291521933771, 65.31520220541185, 73.95948240833899, 77.3566315251012, 71.33634244242023, 75.11720918839978, 74.01866312949889, 70.1050006189654, 59.95436553032168, 60.22551113559354, 63.812530425287065, 60.80316643561087, 58.39426632850402, 57.838533155379764, 60.14802863520961, 56.65048645388696, 55.97121823218561, 60.286198046899614, 54.16569240631596, 51.187817204383116, 53.750666418383204, 56.10727348635274, 64.86994258819088, 67.49088210444297, 72.85545287593719, 65.88668761714813, 69.38738730645949, 65.72438386178786, 51.71254796366538, 50.2467699973814, 50.45929970279817, 52.58016840104134, 56.632082693038456, 50.996256489907545, 53.07953711478941, 52.770854426968484, 52.974252854624105, 56.604932046705684, 57.23182485949609, 65.1731143459197, 61.218694486925685, 64.9276053520941, 55.41865825653077, 60.47545240771387, 68.2732145247921, 67.72522018801781, 67.90860668305429, 67.854493664157, 61.439265051195704, 60.83852268034413, 65.18878029238793, 63.94325517839002, 64.99535252971035, 66.24560017739573, 62.56787999983757, 63.69949163929109, 65.20287729078724, 61.41557785772509, 64.68389280380742, 64.18043698033979, 65.01377198003954, 64.38221939148443, 65.7228188360891, 65.75896739959717, 64.88982116022419, 58.055859919517275, 60.366406594553304, 61.067408669379454, 61.04243886086249, 63.80359134366436, 63.12378575724941, 61.65491696326964, 62.92114826940722, 63.13907907855127, 63.11340716577346, 54.869079282206876, 54.408467508131466, 56.92296566501741, 65.62597159416445, 57.871516366158765, 55.27059270489601, 50.95389096967636, 43.42012789941604, 46.54184818267823, 36.884180499661355, 9.639729703626326, 0.40761252444597984, 0.10794872162683357, 0.5185966626290353, 0.09174333434672126, 0.016248177121123, 0.08746879355561349, 0.272499313277583, 0.07042315337927112, 0.2452228446641276, 1.9405581994402794, 54.7751110599887, 28.924398999060358, 45.79510342690253, 29.740969788643625, 0.5270399934341831, 0.20435010804043663, 0.23739177132806472, 0.04721526664892032, 0.032892942638887514, 0.09468187908491782, 0.10739634925078963, 0.06823568124203913, 0.019998491606524876, 0.06886196578101766, 0.03206175830846112, 0.027689819013880148, 0.11535173567432551, 0.1610616050780781, 0.14509172088676883, 0.23827568357509954, 0.1713507787715043, 0.24813235466999395, 0.1548128097408241, 0.20712314714347163, 0.2648544912376712, 0.14647008160189276, 0.18494271072408847, 2.002550769717463, 84.13917049284905, 56.1564717754241, 40.24425929592502, 68.16548270563926, 69.44520304279943, 56.32362750268752, 1.386619755817998, 0.16515845943602825, 0.23136256743342648, 0.5170197472456963, 0.7616075356641124, 0.3524072480297858, 3.036357250905806, 0.868613655048032, 0.8796698359712478, 3.3924501172957884, 3.7815450708712306, 50.124658769176854, 92.29704933781778, 79.1610316307314, 89.95779483549057, 87.88959964629143, 80.14615058898926, 68.74014915958529, 70.41267918002221, 73.25802141620268, 81.51042153758388, 79.74755148733817, 83.59934253077354, 82.35609239147556, 78.22630728444746, 76.55363605868432, 71.4571749779486, 77.9864308141893, 75.88276170915174, 76.71395901710757, 77.12141483060776, 80.61950222138437, 74.030775408591, 79.84976060928838, 80.0509781991282, 79.02233662143831, 81.33820595279818, 78.23022965461978, 75.51128971961238, 80.16396599431192, 78.26586046526509, 72.8679338578255, 68.27302625102382, 74.75515088727398, 78.69176710805586, 79.9759824814335, 82.202955215208, 69.25499946840348, 75.00951659294867, 84.11223165450558, 74.05444299021076, 80.85723707752844, 75.69757876857635, 73.94418516466695, 64.29765309056928, 62.06642066278766, 67.0488388307633, 65.95831009649461, 62.861575311230084, 63.40787518408991, 61.9966495421625, 60.66444789209674, 56.674699244960664, 64.84593376036614, 58.09574650179956, 55.13514149573542, 56.88316537487892, 61.97441754802581, 69.01573488789221, 71.99603803696172, 75.99747534721129, 69.4068971756966, 73.75959842435776, 68.16682415623819, 54.31266753904281, 54.55386977041922, 52.280970004297075, 54.89643781415878, 60.35732238523422, 54.51717991982737, 56.14401432775683, 56.48467609959265, 55.889829051110056, 59.18805599212647, 61.70067141132971, 66.8139123916626, 63.20362167973673, 65.53771434291717, 56.22313245650261, 65.59543986474314, 72.45722247708228, 68.2595411423714, 68.03855480686312, 72.113340439335, 63.28447349609868, 65.9955333894299, 67.21363329118299, 64.6774052035424, 68.50013932874127, 69.23386573791504, 67.27516743444627, 67.36214207064721, 68.57671968398556, 67.59897478165166, 69.61212342785251, 66.4217459770941, 69.89822895296159, 69.76218546590498, 69.43070596264255, 70.7447156598491, 68.17591621029761, 60.39875830373457, 65.75287595871957, 65.08968160998437, 67.59229890761837, 72.16157774771415, 72.1454175826042, 70.95899474236273, 67.88875164524202, 69.09993248601114, 69.14219994698801, 57.80737776910105, 56.53925588054042, 60.749833968377885, 63.445965320833274, 57.19859453939623, 50.49755850145894, 50.8522270571801, 44.78881151445451, 47.66903931094755, 39.13648390000866, 10.608069742879561, 0.9762619399736006, 0.9729517659833355, 1.4177608009307616, 0.19279197098747378, 0.15678657399069879, 0.3491670638322831, 0.4031678661704064, 0.35005431622266775, 0.35309372409697504, 4.555583394342854, 70.81840915064659, 40.413807668993556, 52.649814005820986, 32.16876591405561, 0.8121959985263887, 0.23999037221074107, 0.3774277102803031, 0.11854819157311033, 0.2738814891105698, 0.2941408374857518, 0.1050002407282591, 0.1807236653422156, 0.1794031902306503, 0.2600084641768087, 0.12818576918253977, 0.12873891530738724], [0.03385758140094338, 0.07374921603308571, 0.05622665164992214, 0.04569073635784369, 0.07001298990461134, 0.08236267198357852, 0.20851889805447674, 0.08975861503952935, 0.09445687140067739, 0.10130146097752357, 0.3572565845904812, 23.92864869486901, 63.33557021233344, 26.002790197249382, 37.652878761291504, 35.876013694270966, 59.204522102109856, 19.31434496756523, 0.4744637775565348, 0.057176604506469546, 0.08168343544727372, 0.06962556391954422, 0.2631424685880061, 0.17380019169180624, 0.17037299011022816, 0.08844561694610505, 0.18094241408811462, 0.5109004514111627, 1.6987126993556179, 36.60074218626946, 70.55054264683878, 80.69776135106241, 73.00722506738478, 58.81859225611533, 57.36329878530195, 67.47236851722964, 71.66976744128813, 66.77013874053955, 71.73958563035535, 71.70415093821865, 69.59608093384774, 67.74950750412481, 63.120616482150176, 57.76990344447475, 55.21338885830295, 59.121269795202444, 65.8848362584268, 64.08622949354111, 66.64042595894107, 69.03974763808712, 73.06263246843892, 68.56785512739613, 74.25030262239518, 74.2886398684594, 71.01332741398966, 68.022504468118, 71.60605246020903, 71.2884424578759, 70.34853273822416, 66.69714343163275, 69.39543601005309, 70.54266652753277, 72.71365919420796, 73.19575771208733, 61.84556376549506, 65.31526496333461, 75.86555034883561, 69.08738874620008, 71.76104099519792, 70.20978281574865, 70.50465091582268, 57.17846885804207, 56.56056611768661, 64.96081998271328, 60.96202634995984, 57.65777072598858, 55.134286419037856, 52.16641326104441, 54.315887804954286, 54.87093848566855, 54.14720627569384, 55.795143035150346, 53.27243927986392, 49.64407820855418, 51.18101581450432, 53.23836565017701, 59.8090377930672, 67.1494633151639, 68.86672404504591, 70.75288987928822, 67.6120598085465, 56.46177730252666, 47.1775310270248, 48.13642894068072, 48.696837579050374, 53.29878976268154, 51.562870317889804, 47.462612813518895, 48.56513223340435, 49.066571958603404, 48.585265759498846, 50.62628284577401, 52.000100843368045, 55.20854080876997, 59.940805896635986, 61.97544913138113, 60.99361711932767, 53.54377708127422, 55.88857781502509, 62.10066687676215, 62.95636330881427, 63.043545830634336, 64.84485903093892, 57.082068766317065, 54.538490156973566, 64.47289674512803, 61.43802165985108, 59.69492820001418, 60.89263962161157, 57.75584959214734, 61.60869575315907, 60.865520354240175, 59.94180217865975, 63.67075243303853, 60.19972939645091, 63.63731030494937, 64.2274191302638, 63.54782535183815, 61.57213926315308, 62.43250331571026, 55.686783636769945, 56.19772726489652, 57.0250218145309, 56.491014649791104, 56.48304047123079, 58.412725002534934, 64.48763701223558, 66.28156831187587, 61.75478835259715, 56.828354174090975, 53.1510615348816, 40.07422454895512, 53.66577456074377, 46.127512531895796, 36.7246106363112, 33.96341500743743, 33.08168972692182, 37.30136379118889, 29.06946982106855, 9.029174543196156, 0.4722170561792389, 0.18782071919450838, 0.043415275192068475, 0.1434886359399365, 0.13625056062254215, 0.08481617581339614, 0.03773805039424089, 0.033747463922707305, 0.07574913452469534, 0.1665966975833139, 28.641692207705592, 51.35167814070179, 24.50686881619115, 50.77598010340045, 0.29457858012568566, 0.09012150322838176, 0.02883681926065155, 0.08556627548269688, 0.03321966764727428, 0.04532647304116719, 0.02105836084322824, 0.08279243964822063, 0.12018631738159927, 0.03421503802641265, 0.12293432073126878, 0.09287795652785609, 0.02048772684628925, 0.09641680010263959, 0.013559555161684273, 0.04267500443083625, 0.10296506687037407, 0.16427254003863181, 0.0538902098853742, 0.09302475429590672, 0.1629995930218889, 0.08679894925726038, 0.3191212793031047, 34.14267909142279, 73.05068492889404, 37.62353551003241, 32.4422316012844, 35.22437072569324, 64.4258322254304, 24.278553532015895, 1.2298358784567927, 0.02248626063397575, 0.07070422337781038, 0.04954081847362461, 0.06051338856078445, 0.0568301948688684, 0.13436345623866205, 0.25730754459096544, 0.36149593130234753, 1.413132281553361, 2.6120783917365538, 44.56690342195573, 78.99513890666347, 81.99377521391838, 79.4983397760699, 66.58544217386554, 63.94807184896162, 71.5341789491715, 72.1425699418591, 70.71175990566131, 73.17039566655313, 78.49275389025289, 77.11968898773193, 74.24019075209095, 70.44510149186658, 65.72331697710099, 62.32333590907436, 64.86830695982903, 71.56682875848585, 73.0051540559338, 70.76053850112423, 71.57062561281266, 75.04051900679066, 73.21880555921986, 77.27184557145642, 75.29853251672561, 72.62550000221499, 73.64306480653825, 74.44518166203653, 73.89143713058965, 71.79751119306012, 70.80590463453724, 72.76623464399769, 73.62772049442415, 76.80338121229603, 75.11713858573668, 64.97136331373646, 73.44267875917497, 79.08128200038787, 71.51237841575377, 73.72158281264767, 74.96302866166639, 70.42054745458788, 60.472977392135135, 61.8729026855961, 65.90479327786353, 64.0036008434911, 60.00836872285413, 55.863317751115375, 53.364277655078524, 57.41277164028537, 58.69372752404983, 57.6283686391769, 60.45873918840962, 58.910826790717344, 52.29843239630423, 54.685892828049205, 55.69732696779313, 61.85622476762342, 71.7419155182377, 69.8506349132907, 72.53227310795938, 68.06368935492732, 57.79832493874335, 50.51824115937757, 50.623344990514944, 52.27775366075578, 55.99482305588261, 55.05810614555113, 52.65092795894992, 52.73142676199637, 52.52197611716486, 51.79489028069281, 53.31759752765779, 56.60936824737057, 57.788185611847915, 63.821140027815304, 65.01052033516669, 66.75026016850626, 58.51428301103654, 57.015765020924235, 65.2857255935669, 68.43676167149698, 66.56794055815666, 66.816038316296, 61.099281849399695, 56.16503823188044, 66.04977192417269, 64.58504515309488, 64.60050713631415, 64.29705296793293, 61.9246465929093, 63.24879561701129, 64.16335898060953, 62.349800140626975, 64.69574620646816, 62.49591627428609, 65.52730829485002, 64.74660758049258, 66.56234725829094, 62.56826439211446, 65.08848920945199, 58.913595984059, 61.15527368360951, 61.3687212236466, 62.463152716236735, 62.14485629912346, 61.59705023611746, 66.35272795154204, 70.31032100800546, 64.78478008700957, 58.05763283083516, 55.668066086307654, 48.921185385796335, 67.15403679878482, 61.45402493015413, 54.94807189510715, 52.55905820477394, 38.84380840486096, 44.55501079559327, 38.614883192123905, 10.126184013582046, 0.9007000526593578, 0.37594223515160624, 0.02990613436146129, 0.0906348051202874, 0.17225764301275054, 0.04430432788907521, 0.07647708659210513, 0.10074730361661605, 0.13410375243233097, 0.1464044431885404, 33.498343498476096, 50.3286063286566, 27.572546274431293, 63.6526075486214, 0.7430541731657521, 0.048559180220528964, 0.020224380291878216, 0.019863822925535422, 0.010722179994768193, 0.024742186557681813, 0.04395214960940423, 0.03964683506637812, 0.1374153053808597, 0.027798344944453532, 0.3379321699180911, 0.042097596301426815, 0.13391564720340315, 0.24656956594797874, 0.07535172641397485, 0.12805714302005308, 0.17674544736021952, 0.325118460722508, 0.37717220463579704, 0.28272036643278214, 0.40708272868106443, 0.2459008631206328, 0.4652926325798035, 42.08321156040315, 85.93959331512453, 40.61456634152321, 51.49563304839596, 50.687295313804384, 72.58020447146508, 36.140816826974195, 2.4956420977269453, 0.11405336219937572, 0.3266565507698444, 0.12133937929907154, 0.48900905996561056, 0.3752348602058426, 0.49717111392847957, 0.5064692762830566, 0.6314902596416012, 3.229024564066241, 4.4292732688688465, 54.14792406943537, 89.11385766921505, 87.7198237757529, 89.06026240318053, 77.1792305669477, 75.44323659712269, 74.88373402626284, 76.20800464384018, 76.06148842842349, 80.17679998951574, 86.59352302551271, 84.6463486456102, 80.93549620720648, 78.36786562396635, 79.77551798666678, 69.77819658094838, 74.0303517926124, 75.78631847135483, 77.03884109374016, 74.91253991280833, 78.39794235844766, 81.72561060997748, 77.71984300305768, 81.66948933755198, 78.87039969044348, 77.79557612634476, 75.21901038385208, 79.00391717110911, 77.09154990411575, 76.07807220951204, 73.70925872556626, 73.48275753759569, 75.22568625788536, 78.71359902043497, 79.70006727403211, 69.44808206250592, 72.18764581987935, 83.74549788813438, 73.75410710611652, 78.21039815102854, 78.81573753972208, 76.77868596969113, 64.60688098784416, 63.59138327260172, 70.98831838177097, 69.66735824461907, 64.44421245205787, 62.37886882597401, 58.18333695011755, 61.949824287045395, 63.34106937531502, 62.92301923997941, 65.82544372927758, 62.606436898631436, 56.36694223650041, 57.50032678727181, 59.4138393863555, 66.32577342371788, 74.99476063636043, 74.45461103993078, 77.77209681849327, 73.73378922862392, 62.817719290333415, 53.08964506272347, 52.909961285129675, 55.61053668299029, 62.353436177776715, 57.647078344898844, 53.48490622735793, 54.88859307381415, 56.225070107367735, 54.838182772359545, 57.78365135192872, 60.20759767101657, 60.498723829946215, 67.64293670654297, 66.59889590355658, 66.7629921820856, 58.45304304553617, 61.445733039609856, 68.37413710932579, 70.48731403966104, 70.20260487833332, 70.7464022790232, 61.800425129552046, 58.52393988640078, 70.31253322478264, 68.55760989650604, 67.4740316021827, 69.18434189211938, 66.87353241828181, 67.07687593275502, 66.22844373026203, 66.23056181015508, 68.55844928372291, 65.76073638854488, 67.97089392139067, 69.48941599938178, 68.52618386668544, 64.77512321164532, 71.39522506344703, 63.60813963797785, 68.25678763851043, 67.6133777249244, 69.5734880816552, 71.31319261366322, 69.64858578097436, 71.2421271108812, 76.69440992416875, 68.70282388502552, 63.2007779613618, 62.07826622070805, 55.04711958669848, 68.01084718396588, 60.720314210461034, 53.81453437189902, 50.807527726696385, 40.39843982265842, 45.75445198243665, 40.80741751578547, 11.631908378293438, 1.419372282201244, 0.9080533322788055, 0.2846501419140447, 0.29119939693520147, 0.27289936439164225, 0.3008337493144697, 0.14384483618120994, 0.433108022496585, 0.31481025740504265, 0.7826611639991884, 43.57273555571034, 67.9841358430924, 35.460673916724424, 68.17793230856618, 0.5565172794365114, 0.29700027598488715, 0.14062219539717322, 0.1599324834082396, 0.15607375982067279, 0.11247393404764515, 0.06839506583468569, 0.1932975736957404, 0.3201011364017764, 0.12173676442715431, 0.4385979311360467, 0.1982502861609382], [0.27412038596887744, 0.04182184678352168, 0.017036563949659467, 0.11597696301196853, 0.11523822442658486, 0.4794499680640236, 1.0366475029337792, 3.3552714413212192, 1.6144630072578308, 2.1213006492583983, 13.21410817484702, 65.09220761637535, 42.79844399421446, 35.7531689828442, 33.87877025911885, 46.71752722032609, 50.825374510980424, 6.302888499152276, 0.2667613453682392, 0.046693782937983354, 0.1563057465659034, 0.06853941978225786, 0.1502645610561294, 0.0904564751732734, 0.11341394691337502, 0.22578524816180431, 0.06039017097904317, 0.6575418455946831, 1.31214534563403, 43.34458304989723, 75.96874790806925, 64.88577327420636, 49.59932396488805, 68.21167253678846, 80.59596800035047, 73.43651279326409, 73.89715594630088, 64.97459142438828, 72.44180756230509, 66.4788164631013, 73.13250557068856, 68.13932834133026, 60.20229070417343, 54.8532211396002, 51.26988495549848, 56.24479570696431, 66.04059357796946, 69.02877284634498, 65.73183636511526, 66.03125833695935, 64.93039023491644, 71.94741633630568, 69.73374043741535, 71.67296809534874, 71.59398724955898, 72.8299496250768, 67.58499545435753, 70.05719477130522, 65.79524147895076, 72.06225549021076, 72.9482404647335, 69.04572533022973, 73.56289940495645, 62.87784138033467, 67.64595693157565, 75.33533219368228, 73.91723063684279, 68.81379558194068, 69.17405743752757, 69.68939412024714, 55.50220081883093, 57.26867944963517, 66.16828241655904, 60.41742486338462, 61.35847599275651, 54.925949727335286, 54.078364756799516, 53.1247071296938, 50.120053906594556, 56.63234156946982, 52.23148145983296, 53.23531404618294, 51.18470676483647, 49.466708629362046, 52.23206197061847, 52.064376723381784, 53.09042169201759, 54.45192736964072, 62.250819129328576, 59.864347134867025, 56.28638459790138, 49.904052903575284, 48.01639656866751, 46.43436739521642, 47.23058892834572, 49.06150425634077, 51.42501077344341, 50.19069971576814, 50.3063194213375, 48.25201726728871, 47.82027413768154, 48.79587350353118, 49.098790307198804, 54.12878682536464, 56.30548261827039, 61.30296268770772, 63.91307646228422, 61.92336790023312, 56.55559255230812, 54.924506295111875, 60.12427476144607, 66.90821401534542, 62.338590006674494, 65.40150611631333, 57.477922208847545, 56.824647534278135, 62.20470382321266, 59.63849706034507, 60.264232773934644, 59.24199642673616, 58.71705778183476, 61.25139528705228, 60.605624106622514, 61.80731281157463, 64.33386441200011, 60.79834584266909, 62.85656252214986, 63.0094761233176, 61.442810873831476, 57.59046677620181, 55.25221247826853, 55.87844633287, 58.52811328826412, 53.56465978007163, 53.36696447864656, 59.47033328394736, 66.97889512585056, 65.4363916766259, 67.02965059588033, 55.5401183712867, 50.771959673973825, 42.92548564172561, 42.790697313124134, 55.80810254619968, 38.3435453907136, 34.519756147938395, 28.774303620861424, 36.28922754718412, 33.384975233385646, 8.867701349719878, 0.4089929842420163, 0.5998117885281963, 0.03545435378327966, 0.12511367999738263, 0.1870017405599356, 0.044284551329309904, 0.11067127553565849, 0.17216647854976116, 0.014945510680967522, 0.09444764770206907, 8.562619397717139, 66.24276822613132, 28.913153563776326, 39.834273553663685, 26.91355278415065, 0.15742218181971582, 0.1280233585425923, 0.03971744155991943, 0.047649630841108105, 0.08431418137925287, 0.0629379764019001, 0.02899652752544611, 0.3045725341766112, 1.6242129163395975, 2.3838064987813277, 1.8600734924116444, 0.1106481550021037, 0.13785644945117737, 0.042186811070648894, 0.14235363071483953, 0.1235177579726423, 0.41117976690011643, 0.9198914131810589, 3.525819283339285, 2.7639108896255498, 2.864717519091022, 17.815254311407767, 76.16437219804334, 57.98307641859978, 46.473700923304406, 36.944333968623994, 50.235246073815134, 53.534939981276, 11.67074376536954, 1.901060054379125, 0.1530470690059085, 0.04815885714525658, 0.05495573476617856, 0.036882395300293164, 0.07348873081707186, 0.10933604557067157, 0.8083286641105529, 0.44531437718579847, 0.43679128130597455, 1.7411502931387195, 51.917935032998365, 89.5411842100082, 77.14120711049726, 62.17664710937008, 69.72393451198455, 80.70471179100775, 75.91232069077031, 72.97654428789693, 67.45330579819219, 75.71033431637672, 72.62739842937839, 79.19373635322818, 75.18432878678846, 67.86673145909464, 64.72165738382648, 59.548286468751975, 61.16911965031778, 71.93194650834607, 73.43826217036094, 70.3147768205212, 71.68070300932854, 69.07788092090239, 74.68223402577063, 75.55769920349121, 73.36951871072093, 75.00702981025943, 76.35676445499544, 73.72670542809271, 71.80537946762578, 70.4973082388601, 74.3412623866912, 74.20881963545277, 71.61483072465467, 75.52037392893146, 64.72076308342719, 74.10220961416923, 77.81338368692707, 75.02187990373181, 71.77196871849799, 72.99088447324692, 70.7960908643661, 58.628019978923184, 62.49329220864081, 70.90895314370432, 64.46174152435796, 61.657282152483546, 57.00676318137877, 56.27585303398871, 56.48638625298777, 53.035100583107244, 61.37979407464305, 58.04274743603122, 56.716711751876346, 54.920815344779726, 52.54596925550892, 55.21300838839624, 53.16625287455898, 56.032007125116166, 55.84011693154612, 60.97998688297888, 60.24300882893225, 55.09092069441273, 52.53370792635026, 50.68186283111573, 49.918542138991825, 49.52324175065564, 52.28277037220617, 56.025982364531494, 52.670406449225645, 52.825598947463504, 52.249465527073035, 53.48234884200558, 50.70661298690304, 53.51149597475606, 58.91109743425923, 59.30179296001312, 61.10926428148824, 65.90535809916835, 65.46574669499552, 61.611484558351584, 58.13029866064749, 64.72348128595661, 68.29899234156456, 65.17906850384128, 66.78425927315989, 60.064682191418065, 58.43788700719034, 65.9150855771957, 63.475077152252204, 63.24821118385562, 63.2834929035556, 63.066672125170314, 64.88145082227646, 65.05730636658208, 63.52744079405262, 67.26060759636664, 64.28257157725673, 65.68004538936, 64.43685800798478, 65.06171511065575, 61.797361758447465, 59.03749581306212, 58.94790887832642, 63.07230857110793, 59.46620302815592, 60.76936737183602, 65.03580001092726, 67.31749765334591, 65.46444839046848, 68.77942777449086, 59.3916230816995, 56.05288982391358, 50.31980845236009, 52.69433682964694, 66.88847664863833, 54.24888587767079, 52.635822911416334, 37.030065213480306, 40.629996945781095, 38.53987178494854, 10.109805176334998, 0.618304047853716, 0.7379313125725716, 0.3585454509142907, 0.092011388511427, 0.12669259487020393, 0.05239905038427922, 0.0912653950734004, 0.027083175054060358, 0.13918982548338754, 0.048706713432986895, 10.981558811280037, 72.6914821132537, 29.316383023415845, 49.34924933218187, 37.94916283699774, 0.08204886704803475, 0.02795891697338272, 0.03932946782198645, 0.05751429223305276, 0.010742172974372103, 0.03512811524072482, 0.0727877373837175, 0.1396651370751281, 1.0463084232422615, 1.3181736608666759, 0.986899959464227, 0.4200040272647335, 0.21395636031464224, 0.16192757554592627, 0.2548110785503542, 0.3972428808769872, 0.7933231467200864, 3.6517800727198204, 7.713037450467387, 9.790726246372346, 7.073254258401933, 22.553775579698627, 97.59144890692927, 63.26792893871185, 50.41596143476425, 47.14440268854941, 62.9162766856532, 65.04542158495995, 20.58352001251713, 5.179196615372935, 0.30494068538950336, 0.4689860037497936, 0.15472970452279816, 0.39970591484058293, 0.20014195642884702, 0.46795285757510896, 1.0345858071119556, 1.193772626499976, 2.6634700211786457, 2.1651946681161083, 65.93931798012026, 96.62962882749497, 83.15677365949078, 73.53239905449652, 77.45614205637287, 84.20163816021335, 77.43340015411377, 75.56907407699093, 71.86437191501741, 84.62830574281755, 80.39629582435855, 84.24471362944573, 79.94341896426293, 74.40530684686478, 76.1181745221538, 68.57131465788811, 72.18775564624418, 79.73723565378498, 80.17252460602792, 74.8878054465017, 76.61710785281274, 73.08262871157739, 77.063489267903, 78.24163590708088, 76.5534556296564, 80.23097576633577, 81.23958972192581, 77.64676924674743, 76.95173309695336, 70.27454114729359, 76.92569640374954, 77.71317497376474, 72.4504760003859, 80.81314963679161, 70.53374705776092, 76.48020144431823, 82.61152498183712, 80.4061488182314, 76.14584292134931, 77.41807153148036, 76.31388510427168, 63.787835182682166, 63.3389473730518, 76.2248473013601, 68.61631993324526, 66.96467261160574, 61.33165090314804, 61.29862846866731, 60.21900392347767, 54.67126238730646, 64.98269111879411, 60.5055409093057, 61.24292688985025, 58.893497759296054, 56.57231753872287, 61.5585913965779, 59.30449547306184, 60.198301653708185, 59.64825983970397, 69.7443308368806, 67.25069968931138, 61.35264342831027, 57.5046217826105, 54.040388368791156, 52.305284776995265, 54.941050852498705, 52.867230984472464, 56.73277385773198, 55.31471544696439, 56.855771541595466, 54.400732594151656, 56.21172228167134, 52.86715253706902, 55.7106355697878, 59.44290022696219, 63.0778391130509, 65.92220860142862, 70.27651017712009, 65.82993092075472, 64.41009959866925, 63.393354569711995, 68.60242689809492, 73.38305873255577, 68.3683398462111, 70.85511469071912, 62.94077973211966, 62.92557662533176, 69.44856059166693, 65.91381472925987, 66.46445274353027, 67.33875689967986, 66.68739241938438, 67.99176877544772, 67.70723219840758, 67.81905897202031, 69.80262510238155, 67.23475133219074, 69.87318069704118, 66.69581767051451, 69.97190675427838, 66.86491104864305, 62.66369173603674, 64.73103969327866, 70.47096560078283, 68.08603902016917, 65.64368109549245, 70.16273006316155, 72.00040755733367, 69.62549086539977, 71.78701493047899, 66.35527749215403, 56.09335299461119, 55.9685274862474, 57.591612108292125, 63.215271119148504, 51.933173441117816, 49.43050907504175, 36.76972573803317, 41.07107531639838, 38.43813726978917, 11.020571685606434, 1.4825839741576103, 1.805711770730634, 0.8706966174706336, 0.4364929053812258, 0.48778610784680615, 0.37305356273728035, 0.23461217451239788, 0.2780020615506557, 0.1873923841142847, 0.2808996818719372, 15.617172775730012, 87.8647396641393, 42.2056326558513, 58.342090960471864, 40.86870062735773, 0.24702938724189039, 0.11177941405725096, 0.21773524221874055, 0.14135236911956342, 0.14202726193733756, 0.14530846248230628, 0.17217780132928204, 0.40939254505980405, 1.9719948932047815, 2.5371601408527744, 2.01081361020765], [20.466045025856268, 7.2488278823514145, 2.8251530614591416, 0.30337743701473363, 1.7277378709085527, 3.506640854381746, 4.767759596147846, 6.0510885138665484, 2.5960655606562093, 1.1353918237070884, 35.35569167906238, 56.60162548865042, 32.51815103715466, 28.313146637332057, 27.9433318491905, 66.28007781121039, 25.42434846201251, 0.4634091288091675, 0.728101485198544, 0.2054440509527922, 0.12394154249059579, 0.2651822849387123, 0.127612421319129, 0.21932677455967475, 0.1269514559798183, 0.7412895355974475, 3.781751730749684, 7.577865710181575, 2.059215412985894, 46.12762628063079, 51.70105934143067, 49.892211268025065, 71.11532472795056, 90.39790830304547, 86.11624902294528, 83.02230696524344, 83.35870512070196, 67.73006039281046, 73.08236983514601, 71.34682301552066, 73.32463110646894, 68.27614061294064, 61.329034682243105, 53.92582378079815, 54.088778649607015, 51.82370008960847, 62.0520059524044, 67.82999454006072, 66.34163548869472, 73.12469220930531, 67.59013375928326, 70.66200071765532, 70.54968757014122, 73.12186810278124, 69.54297204171458, 70.93512319749402, 69.09770457975327, 68.64925999795237, 69.63540661719539, 73.84281542993361, 74.53353697253813, 73.7451405679026, 62.08748771298317, 65.48933190684166, 73.27464442099296, 68.60147768451323, 72.11517610857564, 69.07016954114361, 64.37170351705244, 57.62636823038901, 59.84010296483194, 68.40510029946604, 62.074053595142985, 62.18626083866243, 53.37498572564895, 52.313325635848514, 54.49817211397233, 51.057461154076364, 49.225424028212025, 52.57207262900568, 52.25451753985498, 49.42562180180704, 51.065250981238584, 51.385265396487334, 51.26177349398213, 51.848583605981645, 54.468016932087565, 51.74590379961076, 52.20208329539145, 53.44199549767279, 50.161329007917836, 52.70442516573014, 49.83260300851638, 48.3655071258545, 45.976101198504054, 51.35481995920981, 50.708432966663, 51.490930126559356, 47.642531933323035, 48.07975461406093, 48.01964036880001, 48.4871986604506, 48.873387382876494, 52.96401154610419, 55.62981121001705, 55.89239035883258, 59.02768988763133, 63.55122604677754, 64.73390694587462, 56.163790918165645, 53.065836275777514, 58.64628253444549, 63.727987658592966, 64.52648024405202, 62.429757656589636, 55.751589036756954, 57.83545017242432, 62.220942435726045, 55.94402443978095, 63.03539122304609, 58.30740544103808, 60.125898622697406, 62.83433837275352, 61.23472521381994, 60.73511331312118, 63.34732947811004, 61.98695344309654, 61.98573750834312, 59.62030510748587, 55.76223827177479, 52.86051980910763, 50.476189428760165, 56.7621563326928, 55.530469340662805, 57.44347203162409, 64.13838917209257, 62.02842466292843, 65.9528580019551, 58.6431642501585, 58.27421434463994, 64.06165584441155, 53.25457680609919, 34.33014092906829, 50.043732427781634, 43.647029169144176, 30.901222575095396, 28.05047139044731, 28.482869555873258, 35.88773373634585, 9.460330297870021, 0.3629139294066737, 0.026185000165095253, 0.5009574881724773, 0.8886018082980187, 0.176647495358221, 0.05744125724079148, 0.09549897314319689, 0.07932139485473595, 0.11323691931583228, 0.047311161704842127, 4.489404674499266, 48.37023750428231, 73.69083927523705, 20.311962558377175, 56.1713061794158, 21.15659006180302, 0.07770808263411445, 0.0481316035673503, 0.06351655664583368, 0.0355567337734805, 0.036866744124000116, 3.6594551705544998, 12.491359499193008, 15.203461762397522, 19.54060689095528, 20.302464539004912, 18.34100684811992, 6.195047343930891, 2.2392502427101135, 0.24993396364152434, 1.6996871631953026, 5.986994043473275, 8.420858075541835, 9.114787136354755, 8.03739147801553, 5.852333682198679, 47.277751507297644, 66.59320846680673, 44.29056852094589, 37.89060969506541, 24.86836425719723, 63.88532961568525, 31.884709827361572, 0.11094196504282375, 1.6290773907976768, 0.2726574951121884, 0.031905227393332514, 0.29870598607005616, 0.07547553388341781, 0.29007447342718806, 0.3225376637231919, 0.7354040191538873, 4.1710842328686875, 6.42348422158149, 1.642344440183332, 64.76445436477661, 67.92531597998835, 61.42836086211666, 74.95079086672875, 89.62860599640878, 85.71633984965663, 84.08396705504387, 85.00552008228918, 71.49615549272107, 74.78778500710764, 75.89714111820345, 78.53967328225413, 74.3160415464832, 69.29308568277668, 61.98216422911614, 62.860775147714925, 60.19850169458697, 68.14081884199574, 72.22751279031077, 72.69926409567557, 76.49989174258324, 72.41531587416127, 74.7797441482544, 72.62564905228155, 76.13237350217759, 71.74037010438981, 74.32588669561571, 73.73859805445518, 73.3504795259045, 74.42515403993669, 76.76633834838867, 76.70026994520619, 73.82826343659433, 66.40800983675065, 70.41711930305728, 78.1544102391889, 74.09472573188044, 75.79953685883554, 73.34359184388192, 67.10878049173664, 60.66968033390661, 64.85020914385396, 69.73239114207607, 65.99306229622134, 61.90452091155514, 55.94298893405546, 53.411416699809415, 57.94577467826105, 53.8088979259614, 52.46986742942564, 56.99368599922427, 54.88099936516055, 54.482047250193936, 55.13930705285842, 54.1815701607735, 54.182550753316576, 55.520949748254594, 57.32357302019673, 55.23183968759353, 56.270620592178844, 55.323713364139685, 52.538528519292036, 52.80381018115629, 51.51720216197353, 51.5134092300169, 48.81978034973145, 55.563217209231475, 54.37440564555507, 54.697000980377204, 50.675559582248816, 50.925104694981734, 51.99979097612443, 51.03011831160515, 53.51235889619397, 55.46980988594794, 59.49569925185173, 60.55157776801818, 61.21970253605997, 64.27604867566016, 65.78211722835418, 63.673133311733125, 56.449629722103, 59.60629440123036, 65.12048790531775, 67.12530151490243, 65.97688644163071, 60.013444269857104, 60.10512575026482, 67.57749588258805, 59.86273111835603, 66.83215925770422, 62.672564137366514, 64.08297000392791, 64.544621206099, 63.6767222804408, 63.970092035109005, 67.09907654793032, 64.85799112627583, 64.45290442435973, 61.563149190718136, 59.89318832274407, 56.4479156463377, 54.113489581692605, 62.09798789793446, 61.894397274140395, 62.58503252460111, 68.26110224569997, 63.20158204724712, 66.42875133022186, 61.05529246791717, 62.655352777050396, 64.80448607475527, 56.503256367098906, 47.73733562038791, 59.73734471105761, 58.643156405418154, 49.94306871967931, 36.83314654134935, 34.133798845352665, 40.02379071327948, 10.621778426631804, 0.9114563561254932, 0.2431039986831527, 0.6362129159031377, 0.9123131488600086, 0.30765125768319257, 0.025858056821650075, 0.09312611538916828, 0.04264986142516137, 0.1783225925699357, 0.08411966399439881, 5.881790682192772, 57.275378857889486, 70.83467914212135, 27.786664539767852, 67.63187562265705, 29.819899643621138, 0.05380835339066483, 0.0776981388128573, 0.02575968155607341, 0.002844135414042901, 0.021297838013138504, 4.257167020151693, 14.588471381895005, 18.211756906201764, 23.03281072647341, 24.52666501845083, 29.87407345925608, 12.094871613287157, 4.710867087687216, 0.9310948055598044, 5.354872711243169, 12.891806037195268, 21.677374916691935, 22.93791094133931, 25.643793306043072, 4.929659837676633, 68.24798583984375, 82.69097651204756, 51.43571492164366, 38.86977449540169, 43.4513028975456, 79.53119354863321, 40.50034299973519, 1.9927173876954665, 2.881211575961882, 0.4759724191840618, 0.3004489280283451, 0.33631609212006297, 0.19610072005419962, 0.5876004695892334, 0.6864102449147933, 2.0176243157156053, 9.186280177485559, 13.45310897596421, 3.395528442436649, 78.96690568616314, 73.26183396001016, 71.63352474089592, 84.2653609860328, 93.9321050336284, 89.62322450453236, 90.09080240803381, 92.16313177539458, 75.51446683945196, 81.50887612373599, 82.49022176188808, 84.60874880513838, 79.33480047410535, 78.23634855208859, 73.97188494282385, 70.52004229637885, 69.46072778394146, 74.91589746167584, 78.45738980077928, 78.25372465195196, 79.52978149537118, 77.37240729793426, 77.31118694428476, 76.51679715802594, 79.12882112687635, 78.22910001201015, 76.7266361175045, 75.90834340741559, 76.50482608426002, 74.68989049234699, 77.01775443169379, 77.95241602005498, 78.73635661217475, 70.11239036437004, 71.22886949969877, 81.54611510615196, 76.57462858384656, 80.29395334182247, 76.78399685890444, 70.57160577466412, 64.36937755154025, 66.6906322971467, 73.59541585368495, 67.59658998058688, 69.39622832882789, 61.772254666974476, 55.66713256220664, 63.336872439230646, 58.14475651710265, 55.13137602037, 59.760388635819965, 60.42292794873638, 58.487799167633064, 59.189695542858495, 59.92031151248563, 58.60463480795584, 60.66610313230946, 61.40390880646245, 55.824486286409446, 58.39816124208512, 59.41493765000374, 55.54903391868838, 56.79725762336486, 55.88244322807559, 53.730379919851984, 52.845995272359545, 59.919162258025146, 56.41460295646422, 57.286377183852665, 53.06960175114294, 54.97700329749815, 54.29676625036425, 55.04086340627363, 54.043153639762636, 62.150767310973144, 61.241942374937004, 60.48757253154632, 63.953441573727524, 68.26086690348964, 68.49894692820888, 63.174694199715894, 58.93162319737097, 64.55848678465813, 69.48722731682562, 69.35268217517485, 66.83835660257648, 61.95502142752371, 61.90060638612317, 69.91275741207984, 60.83252929872083, 70.78487288567328, 65.23933179916875, 67.32413430367747, 67.84930829078921, 67.24547509224185, 69.17331218719482, 69.66770341319423, 68.8213892905943, 67.14244227255544, 64.47212796057424, 65.60644995781684, 62.49470033953267, 61.46894562628962, 68.1213560412007, 68.61537856440391, 68.00881539621662, 74.6905259163149, 67.70137217737013, 73.42638523347917, 69.2833189810476, 66.93570983025336, 68.95738570920884, 58.935176864747085, 53.64367200482277, 61.406874118312714, 60.41092157363892, 47.95943198665496, 36.812471728171076, 32.94943524945167, 41.00052364410893, 11.863927360503904, 2.1397627553632184, 0.3656255435799399, 2.155621143118028, 1.8820077541374394, 0.6220459277110716, 0.2741961367428303, 0.20412095582052586, 0.14448326321378832, 0.3779982619227902, 0.229813399754705, 8.406166838061425, 69.83885211329307, 82.5591064268543, 34.47438216978504, 77.83209339264901, 32.25398528960444, 0.3157844148095577, 0.17657810311403968, 0.14895781424016724, 0.17440898644347347, 0.1110271463591245, 6.994467079639436, 22.118233634579568, 28.76600192439172, 34.65206946096113, 35.15309341492192], [28.832586119251868, 27.881328982691613, 15.315234603420382, 6.450859423606627, 4.369697368914082, 1.8631389472753772, 6.211524730728519, 5.103369355201721, 2.9905383288860325, 3.6593296547089857, 23.931108020967056, 52.763307786756954, 44.17631772256667, 21.025767249445764, 58.80657411390736, 62.32054710388184, 3.5944806183538134, 0.11084455696325149, 0.12833853477552054, 0.2548267680310434, 0.10495032243911298, 0.11323833657849221, 0.171246744031387, 0.38463803789308, 0.150067477276729, 0.8218371231229076, 5.398624789330268, 12.904138949609573, 10.64346815309217, 41.69587750588694, 42.57164862848098, 75.92412702498898, 82.92923696579473, 82.56478601886381, 84.87953355235439, 77.63694763183594, 80.18801796820857, 77.0113923472743, 76.08823899299868, 70.37394185220042, 74.41238280265563, 67.58510528072235, 62.361763369652536, 57.91698055882608, 56.74163449195124, 56.357477557274606, 61.1786235532453, 67.40923404693604, 65.75926942210045, 69.14679696482997, 71.1350856288787, 72.35251088296214, 69.42661100818266, 71.78350833154494, 71.34009222830497, 69.36284111392114, 69.15504178693219, 72.60320525015555, 73.7316240802888, 71.66816711425781, 68.62642395880916, 63.16755156363211, 63.197742046848425, 70.24023609776651, 70.3882977270311, 71.61333237924885, 69.45980210458079, 63.048503706532145, 57.05376494315363, 64.16773634572183, 67.19687692580685, 66.79172746596798, 61.8891256086288, 54.22119002188406, 50.26939815090549, 53.87942606402982, 54.36638047618251, 52.124600795007524, 48.78365532044442, 52.50439997642271, 49.810167051130726, 50.852438865169404, 48.42035362797399, 46.68151986214423, 49.51682475305373, 52.68766880035401, 52.427533288155836, 58.34150652731619, 58.18622381456437, 56.281889561683904, 53.48533376570671, 49.125262383491766, 48.324761544504476, 45.8710640476596, 45.60623345836517, 50.03660548117853, 49.372057914733894, 50.27739978605702, 50.142038791410386, 50.0490354722546, 50.82129524600122, 49.14149315126481, 50.23344570590604, 46.568335948451875, 53.04081547644831, 60.88921931482131, 58.77040201617826, 59.758286245407604, 61.53263707314769, 64.73559748741889, 59.11531955965104, 56.26861626102079, 57.34079614762337, 63.744869539814616, 63.95136271753619, 59.77419930119669, 56.02002036186957, 59.943786897966945, 62.11544636757144, 60.46644664579823, 59.97258886214226, 60.46573669679704, 60.6580073602738, 60.8838221334642, 59.26360476401545, 64.06206769327964, 62.12143190445439, 63.03174734115601, 61.43572707330028, 53.71989150201121, 55.80067749946348, 46.91843494292229, 50.095668531233265, 59.509027465697265, 59.176853702914336, 61.898747182661495, 62.044294572645626, 59.48658758594144, 55.31369170834942, 61.731414948740316, 62.506102669623594, 62.82813318314091, 36.0236713194078, 39.69149535702121, 47.54981886956, 27.80490552225421, 27.095287961344567, 29.589327035411713, 38.15821340007167, 10.503589568599578, 1.055370691803194, 0.24405906517659468, 0.8837895503928586, 1.849598189996135, 0.04404212663611097, 0.4179104008982259, 0.14415709361914666, 0.014526992059883573, 0.14945030152317018, 0.16589718269965342, 3.333370887464093, 29.56712838142149, 77.43122716103831, 39.36307530249319, 21.672958327877907, 68.81327782907795, 3.3939033554446314, 0.11024712329550136, 0.009306086576543748, 0.06307827774435282, 5.932412791636683, 19.863606229905162, 20.43079468511766, 9.38856072964207, 10.753938767217821, 9.3153977394104, 43.39948446519914, 34.2794599840718, 20.53891089654738, 9.75101322897019, 10.84316582449021, 5.7494602088005315, 6.710322249320246, 5.697098037888927, 8.750898068951024, 4.867614805698395, 46.11512568689162, 66.43985163780951, 59.88521414418375, 25.945604001322103, 43.71015187232725, 70.80378655464419, 4.316926290912013, 0.030295305111775958, 0.33510806339402355, 0.45489341801693367, 0.006477494128874594, 0.18431269533691869, 0.07107227499927245, 0.4952936775742039, 0.05314295623271216, 1.7304982389173202, 9.238685004172787, 21.96863247502235, 10.345533740135933, 54.7834421742347, 55.92152180210237, 81.51029602173837, 85.75208048666678, 85.52828573411512, 87.038311958313, 79.11713246376284, 83.47017103625883, 80.39706460891232, 78.12660063466718, 76.74002708927279, 78.60269008144256, 73.41359830671742, 68.4688937279486, 64.82317616862636, 64.91390059071203, 64.25634661028462, 66.51631432194864, 72.43824605018862, 71.2277163228681, 71.66407215979793, 74.34043084421467, 74.53125415309783, 75.43712554439422, 73.71271825605824, 75.29248422191989, 74.79329985956993, 73.47461469711797, 74.02940257903069, 74.38436923488494, 73.2507493419032, 69.28732764336371, 64.87324914624615, 69.01760978083458, 74.72159893281999, 73.39546911178097, 75.88464444683444, 70.48923600104548, 63.376825701805856, 62.564365556163175, 70.00598430633545, 70.11231976170694, 69.81298800437682, 65.66157887058874, 57.113961558188166, 55.81925384459957, 54.533469523153, 55.85163693274222, 54.839449697925204, 51.45906086890928, 56.43417950599425, 53.659334028920824, 55.52249123973232, 51.43764080539827, 52.588574040320616, 51.52221887342392, 56.66138279822565, 56.11898960605745, 61.27057959956508, 58.95828746980237, 55.85328825058476, 55.23424410050916, 52.90028872028474, 50.826033469169374, 49.19187991849838, 49.08025318576444, 54.22053498606528, 51.0281414370383, 53.11059444181381, 51.48616444679999, 53.13735285112935, 54.654447186377745, 53.97731273405014, 54.28010009950208, 49.504469287010934, 55.44882520552605, 63.49324557089037, 61.970867803019864, 63.14476651530113, 64.32907519801971, 67.76725230678436, 63.936469477991906, 60.28456634090793, 60.91423619178034, 63.61163054743121, 66.6971512763731, 63.73516559600831, 59.818526006514034, 62.06008603495937, 66.78389841510405, 62.785218531085604, 65.03077153236636, 64.48207116896107, 62.783649583016675, 63.736008905595355, 61.038147787893976, 65.59605175449003, 66.62515224949007, 64.17996237354895, 65.50537440084642, 58.37996144448557, 61.582462941446614, 53.35871965654435, 54.24483406928278, 64.7964059922003, 64.27492295542072, 66.91317189124324, 65.26993413125315, 62.20855559072187, 60.557163223143554, 64.36732615194013, 67.1764099982477, 65.4564977461292, 47.04860664183094, 52.79936613575105, 58.98847010827834, 46.777641465587, 34.836565986756355, 32.973934373547955, 40.40232296912901, 11.652177226158882, 0.9628408149846139, 0.9659625313455059, 1.9224454294289313, 2.1218659608594836, 0.034055090359141754, 0.13500145426200283, 0.14574776794160568, 0.12138729043785604, 0.2556841889576566, 0.21410622243438998, 3.6690635065878596, 41.03112205382317, 77.37399978022422, 46.57858117934197, 29.87809781105288, 82.7280350654356, 6.3181808398615935, 0.07165820202639989, 0.10429969162590082, 0.08458127027317401, 6.378637311920044, 28.010408301507276, 33.93578975431381, 31.3056012891954, 35.78734459415559, 29.8388623422192, 51.96663125868767, 48.2256510949904, 33.60343556250296, 20.01387615357676, 26.255453594269294, 10.588173520180488, 20.63194755584963, 16.555718491154334, 29.767006481847456, 2.613186461310233, 82.47927050436698, 78.89508708830803, 65.24104587493404, 32.55449964154151, 79.0421602802892, 80.02520038235573, 8.33691837326173, 0.24723374885657143, 0.4763607338311211, 1.137324694183565, 0.14055163869934698, 0.5088351702978534, 0.21006037421043844, 0.9624667802164633, 0.2662437763665953, 2.0090806580358938, 14.05960056089586, 28.039618192180512, 11.896027057401596, 62.81258883014802, 68.88650848019508, 90.41445286043229, 89.73531015457647, 90.58490337864046, 90.6330700843565, 86.1518955230713, 86.24802497125442, 85.49331388165875, 82.66756780685918, 81.07225356563445, 85.80777814311367, 79.39481273774179, 75.0413505492672, 75.84491083698889, 71.21223865016815, 69.87561256654801, 76.39062235432287, 77.07644877895233, 75.24186995721634, 74.21562102533157, 78.75290116956158, 78.38047212170017, 78.16079585782944, 77.23056654776298, 78.3980364953318, 77.24621680475052, 76.39354844247141, 76.16365048193163, 77.79831394072502, 75.04521800625709, 71.86031618425923, 68.0108864076676, 69.0737545874811, 75.4590908173592, 76.99807197816911, 77.73113942915394, 75.94096968250891, 70.60835838317871, 65.86712283472862, 72.79962970364478, 75.82068627880466, 73.93575991353681, 69.50737261003064, 60.70405990846696, 58.09660942323747, 58.55136117627544, 59.75581122982887, 58.68881671659408, 53.89972432967156, 60.91572277007565, 57.10368887070687, 59.97038449010542, 56.11642045359458, 55.21799764325542, 55.61683993185721, 61.40169266731509, 59.33368182951405, 66.94629238497826, 64.76188521231374, 60.56143860663138, 59.201497954706994, 55.91828584671021, 53.94510615256525, 52.15432451617334, 51.11323333555653, 57.49770664399671, 53.5293427590401, 55.603613699636156, 55.333483988238925, 54.349302476452245, 59.38370773869177, 54.78344609660488, 56.27164433079382, 51.99556658344885, 58.41125803609049, 65.42237312563005, 64.2389234419792, 66.06339039341097, 67.26288257106658, 70.0812545899422, 66.85777233492944, 60.48499945671328, 61.140678544198316, 70.19422669564524, 70.68220092404273, 64.13345090804562, 60.72131833722515, 66.35927046498945, 68.04274389820715, 66.60870967372772, 68.57744924483761, 68.29875699935421, 66.15279689911874, 66.23846930842247, 64.60498648305094, 71.37667225253198, 70.59768169156968, 69.42537938394855, 70.68288341645273, 62.39917885872626, 68.11464878820604, 58.02732859888385, 62.44806335818384, 71.79410657575055, 67.07627188774848, 72.24290417086694, 69.37652234108218, 69.00271261892011, 63.80749017961564, 68.71186887064289, 70.43244792569068, 66.58503424736762, 51.424112550673954, 54.28687011041949, 58.52956456522788, 46.499623867773245, 34.60959803673529, 31.348682641983036, 40.15311518023091, 12.1552368902391, 2.3001516586349857, 2.063037027274409, 4.367959268631474, 3.6204317548582634, 0.21990085020661357, 0.6355006992816925, 0.2624775962002816, 0.16029412287377542, 0.41979568199284617, 0.32219298544429964, 5.160484948465902, 49.73006048510152, 84.70488609806185, 53.78717191757695, 35.670956104032456, 96.1365790520945, 8.300275591111953, 0.2292745488305246, 0.2008219973574723, 0.10561961515416061, 10.72952397408024, 41.8157333712424, 46.803682081161014, 43.62720158792312, 46.605131703038374, 36.2914397639613], [5.821585241825351, 14.549474197049296, 16.192264806839727, 19.235636726502452, 5.509276322780117, 8.662343698163188, 11.365867737800846, 5.269975460344746, 3.389651506177841, 5.838405345716785, 26.813342109803234, 54.04874301725819, 28.51790808862256, 32.64606933439932, 61.237055101702296, 27.209995715848862, 0.47059978328404894, 0.0410688589627464, 0.04461568134326128, 0.14330586268296167, 0.024279932934610594, 0.18845481016943533, 0.08664891859816928, 0.0025927826842939063, 0.13309908940667106, 1.4762694484764531, 6.537423681828284, 2.0780219522214707, 27.028476269014423, 58.584697400369954, 70.11373181496897, 75.80306699199062, 81.46022304411858, 82.6929690760951, 79.33230584667575, 77.60898113250732, 76.18294069843908, 74.04229933215727, 77.13582561862084, 72.34311288402927, 71.852981352037, 66.27326857659125, 64.8500483266769, 61.5051491029801, 61.88576413739113, 65.68028857631069, 59.780624143538944, 64.14793229872181, 65.76585508161976, 69.26864931660315, 69.6525473748484, 70.74983827529415, 73.86231745443037, 69.3089085240518, 69.9481136568131, 69.1401916934598, 74.58260582339379, 71.78346126310288, 71.07101763448408, 69.37238816292056, 64.79632362242668, 67.14621559266122, 70.09543788048529, 71.37213014787244, 70.46334051316785, 67.59654291214483, 57.59123556075558, 61.32344138237738, 70.07572404799923, 67.65469597231957, 67.96959169449346, 65.74410946138444, 56.71157736932078, 51.562921308702045, 55.409252412857555, 53.918787048709014, 51.09166422197896, 51.01304423424506, 49.23525741023403, 52.71135207145445, 51.927666433395885, 49.23536723659885, 48.351684693367254, 46.58895192607757, 51.734889784166896, 51.8037901386138, 52.106373540816776, 50.195575221892334, 51.14999378881147, 47.490049792874245, 48.99872279936268, 50.43918186618436, 46.880380107510476, 41.918793647520005, 44.043223857879646, 48.13032965506277, 47.76149349827921, 47.10205285779892, 48.366515174988784, 46.387000853015536, 46.214961774887584, 48.893411082606164, 51.447717374370946, 49.32653096414382, 46.663677000230365, 52.0773676133925, 61.23873779850622, 61.80205683554373, 58.444351073234316, 61.444368054789884, 62.49737147362002, 61.30686544602918, 64.7653212085847, 55.67044304263208, 60.518692616493475, 63.94183135801747, 59.46104118900915, 54.73483224068919, 63.375633301273474, 60.28762971201251, 60.46835291770197, 62.232470281662486, 60.90496370869299, 59.3279787032835, 60.242228277267955, 59.58042244757376, 62.32779564396028, 59.51748801815895, 58.86058907355032, 53.76078221105761, 55.782787569107555, 52.88091613400368, 47.664995347299886, 57.02174663543702, 60.209154851974986, 65.45228512056413, 59.05143591665453, 58.56275566162602, 57.538307097650346, 59.3726937232479, 64.01592100820234, 61.60135307619649, 47.5610682272142, 35.243880594930346, 43.9531897729443, 25.27915800771406, 26.441524951688706, 32.1548964131263, 33.78412346686087, 10.473174529690898, 0.6645585368237188, 1.0853043823472917, 0.21191966960266714, 1.4913029127543973, 0.29754560801290697, 0.20257301388248322, 0.051061399581451575, 0.2207820658241549, 0.25818630872714904, 0.2515416910811778, 2.4390778426201116, 29.19429925180251, 40.679701220604684, 44.59101030903478, 21.822937996156757, 56.71480940234277, 15.615552836848845, 0.2943549743823467, 0.22527587630095022, 2.5968980837252835, 17.621908918503795, 24.541528840218824, 19.6232198515246, 34.88752542003509, 39.18070077896118, 26.316054213431578, 23.903818130493168, 34.02938142899544, 31.791333883039414, 40.45441204501737, 14.457558355023785, 3.6716240788659746, 2.90266350873055, 2.2462806009477188, 10.007634297493967, 7.081098508450293, 55.82747513248075, 60.625051606086, 49.604627009361025, 26.1647468228494, 62.26157819071124, 33.20646816684354, 0.17299336321171255, 0.04304130171095172, 0.17254535499359333, 0.029357190228878494, 0.12626399932008597, 0.04689894894498491, 0.25954295851049886, 0.1928792590455663, 0.7794139930798162, 0.8244294420846048, 8.643552603260163, 2.36015877416057, 24.65455782028937, 62.085538295007524, 77.04483447536346, 82.17931901254963, 85.26497702444755, 83.28605498037031, 81.13734137627387, 81.97912123895462, 80.6580904991396, 80.62580939262145, 81.4724765285369, 78.18990768924837, 75.73831650518602, 74.44539347002583, 69.69266537697085, 67.4361022826164, 68.16113671948834, 69.70550721691501, 67.41554906291347, 69.60826381560295, 70.48776903460103, 72.60720606773131, 72.96125488896524, 73.62060531493157, 74.77743779459308, 71.95216240421419, 73.64446117031959, 71.37777836092057, 76.25772460814446, 74.83199796369, 74.95414057085591, 73.03193599947038, 67.16958507414788, 67.86290322580646, 73.14846177254954, 71.88589788252308, 76.27121756153723, 68.41336081104895, 62.52381609332178, 67.64161094542473, 72.60503307465585, 72.3551388709776, 71.0658165716356, 69.79909496922647, 57.00752019882203, 53.946349543909875, 56.68989450700822, 56.819120914705344, 53.41568031618672, 54.48202371597291, 51.57036204491892, 55.12188388455299, 54.802916742140255, 53.24714391462265, 51.915852254436864, 50.55996733327066, 51.843515903719016, 52.85309868474161, 54.896837895916356, 52.407387994950824, 54.1562512613112, 51.01881404076853, 51.264903545379646, 52.49362130318919, 49.58929054198727, 46.9529478780685, 48.57221995630572, 51.33073660635179, 50.374176425318566, 50.38070717165547, 51.59682235410137, 48.53190191330449, 48.96571605436264, 54.13722384360529, 54.40008540307322, 54.7595823964765, 51.63286501361478, 53.15243044207173, 64.21289067114553, 65.95078699050411, 63.05443433023269, 65.14217469000047, 67.31951375161448, 64.83852440311064, 66.29786968231201, 60.596834075066354, 62.681420849215606, 66.02512375000985, 63.40340368209347, 59.182184203978515, 66.2607640604819, 64.09586283468431, 65.17793886123165, 65.34289413882841, 64.32350543237501, 62.25387465569281, 63.228869976535925, 63.10062416138188, 65.84673435457292, 63.947483493435776, 62.512841301579634, 58.90247606462049, 60.34514342584918, 58.47156447748984, 54.11071254361061, 63.46172932655581, 64.20160208978962, 67.18750246109502, 61.92948287533176, 60.246617409490774, 60.443865560716205, 63.27299271860431, 65.05910673449117, 64.9989571878987, 56.99938912545481, 50.78287955253355, 58.00976030288204, 42.947474448911606, 30.51640275985964, 34.490734531033425, 27.842452410728704, 10.309719558685057, 1.376735995854101, 1.289143096054754, 0.932529351163295, 0.9085439349855147, 0.31256470048139173, 0.1201605691664642, 0.16124243247172526, 0.24763753847970119, 0.21921677965550654, 0.08735799425912481, 2.1029554788143408, 34.87044349793465, 48.44894770653018, 57.5097365533152, 30.038252107558716, 70.18312638805759, 21.426821754824733, 0.2975241881945441, 0.3310653254870446, 2.3308510693811604, 26.194784333628995, 41.42618709994901, 37.69092575196297, 39.379419819001235, 43.13731324288153, 32.48425783649568, 35.621396956905244, 42.85937409247122, 47.51840068447975, 86.81694123052782, 31.81716072943903, 14.479034312309759, 28.157355977642922, 30.27703227535371, 39.75106439282818, 19.228466633827455, 81.43872061083394, 76.5813672158026, 42.16933896464687, 43.164958107856016, 82.5197728987663, 37.49836483309346, 1.2913147408154704, 0.27688207164887463, 0.31927081966592424, 0.36767504328200895, 0.2606988932576872, 0.4636114985952455, 0.3709381488302062, 0.24171062264471288, 1.0310100764036179, 5.114195587173586, 13.510878624454623, 5.388361907774403, 31.422203548492927, 74.29011467964419, 85.6562412938764, 90.14777875715687, 89.8652582783853, 87.80646893285936, 84.33928197430026, 85.61856300600114, 86.6336488723755, 87.26766078702866, 84.80209812041252, 82.36141112542923, 81.80961993432815, 79.86996081567581, 78.31853005193895, 76.79130031216529, 73.59071685421851, 73.75839817908503, 71.13121817188879, 74.91912164995748, 75.15458937614196, 77.63689271865353, 78.41861324925577, 81.25731099036433, 81.91750864828788, 76.88758665515532, 76.67730054547711, 75.23938317452708, 79.47558218433012, 77.56783546939974, 77.0904359509868, 75.23911645335536, 69.78266808294481, 70.64777035867014, 75.47605114598429, 75.74979336031022, 78.63655582551034, 74.92519347898423, 65.3159906018165, 68.83197969005954, 76.48709697108116, 75.24259167332804, 74.68405400553058, 74.53840855629214, 61.20192635443903, 57.89160674618137, 60.1460752948638, 62.40775708229312, 57.029638444223714, 60.14558892096243, 55.94316544071321, 59.13444895898143, 61.28927753817651, 55.817661362309615, 56.04906551299557, 52.754804088223366, 56.58912881728142, 58.48891704313217, 59.82347996004167, 55.6994568147967, 58.122818700728885, 54.33152237246114, 55.01562687658495, 56.142453224428245, 53.30841918145457, 48.86169479739282, 49.43830282457414, 53.4064745133923, 54.54247528506864, 53.76205305899344, 54.23511835836596, 51.01784913770614, 53.02843647618448, 56.5725685704139, 57.89008094418434, 57.4839783483936, 53.46632988222184, 57.2751082143476, 65.18805073153588, 66.46272690065446, 64.07536452816379, 68.45045074339836, 68.55874738385602, 66.42848460905014, 69.06230126657795, 62.318746735972745, 64.66956438556795, 67.70274500693044, 64.8658319442503, 60.53043619278939, 68.61053051487093, 64.73630743642008, 67.2119309825282, 70.10395726849957, 68.66555352364817, 63.53215548299975, 65.88145517533826, 65.04553141132479, 69.92053939450172, 65.49773362375075, 67.68112490254065, 64.14472379992085, 69.08813399653282, 65.16028819545623, 58.6544842104758, 67.37208135666387, 69.03628810759514, 70.96570984009774, 69.41427123162055, 65.7567120367481, 67.4005969878166, 67.09834698707827, 69.41056066943754, 69.07158159440564, 61.337071618726185, 53.81239275778494, 59.88614374591459, 45.21506724819061, 28.428036782049364, 36.46072926059846, 39.213687912110366, 14.970177815806482, 2.439770631251797, 4.696897566318512, 5.213875760955196, 3.11421801486323, 1.0778331251875048, 0.3845008775111168, 0.27397587114284117, 0.3894623387004099, 0.28354308357642544, 0.3619132040729446, 3.074313291618901, 48.02061703897292, 53.62649986820837, 58.21927762800648, 35.41863003084737, 83.21641722033101, 25.903709165511597, 0.48210725128169984, 0.2980559451445457, 5.692675565519641, 39.42672360327936, 52.38432053596743, 55.59758501668131, 63.01897610387495, 72.90656920402282, 64.25588769297447], [17.470368146896362, 12.934084284690119, 17.774724460417225, 20.983123240932343, 9.733653799180063, 27.909664184816425, 21.078297591978504, 13.180968069261121, 19.441814153425156, 19.86485746599013, 45.904380659903254, 51.90606594085694, 41.452196336561634, 36.66672429730816, 54.118106211385424, 14.577084741284771, 0.2978723598343711, 0.11198279507938894, 0.04593535206250606, 0.05388609982366043, 0.19564973941493422, 0.15271673189295878, 0.1741551202271254, 0.13819898268388164, 0.15562510808869717, 0.5067450985793145, 4.805947792145514, 5.9184045368625275, 58.191224836534076, 77.90260191886657, 81.79263607148202, 78.23923541653541, 86.4807705725393, 80.24701826034054, 75.02439806538244, 72.41105618015413, 71.59039435848113, 73.95657200967112, 75.36746425013389, 78.38312364393666, 72.2643752251902, 68.3420285870952, 65.90021194950228, 61.738188882027906, 64.48818222168954, 72.10225582122803, 65.65727995287988, 60.918970492578325, 66.64967490780738, 67.92038948305192, 68.17860695623583, 70.69672153842065, 69.20516967773438, 66.55987616508239, 70.0205441444151, 71.19330929171655, 68.0932326470652, 70.65672120740338, 71.12724088853406, 63.897889044977006, 65.94213424190399, 66.87499153998591, 68.6926257225775, 68.20923282254127, 69.96634483337402, 57.12286533847932, 64.78570184400006, 72.16313885104272, 66.24239952333512, 67.72237254727271, 67.15432705417757, 58.93601232959379, 50.00141397599251, 55.77387594407605, 55.5786713477104, 54.402713391088675, 51.5807367140247, 49.15986945552211, 48.11701320832776, 48.817011156389796, 49.21624568200881, 48.178998424160866, 48.31013502613191, 48.988324596035866, 48.96794003825034, 50.109122260924316, 50.07066342138475, 50.992440023729884, 52.49962252955283, 52.22468791469451, 50.80392306850803, 47.05028933863486, 45.68537512133199, 45.435500529504594, 43.56852293014527, 46.648575875066946, 47.2938959829269, 48.59296144977693, 47.22758831516389, 47.707804095360544, 48.122712412188136, 49.16833785272414, 49.26388679012176, 51.088051719050256, 52.694187779580396, 48.129796212719334, 53.249179624742084, 62.1057032000634, 60.512930654710345, 62.59360682579779, 63.46670681430448, 60.72675081991381, 57.237728026605424, 59.28105146654191, 57.18715298560358, 63.37638639634656, 61.78253519919611, 59.21155883419899, 58.58889825882451, 60.09278597370271, 61.49345259512625, 59.97385186533774, 61.2821388244629, 60.13977596836706, 59.64482384343302, 58.222623409763465, 58.235602532663655, 60.4846150644364, 57.88848061715403, 50.96659944903467, 49.45462380686114, 53.633352248899406, 52.076316418186316, 53.73869142224712, 63.58147144317628, 57.89140670530258, 59.704588997748594, 57.39299897224673, 56.861925740395826, 55.01831370015299, 61.30728906200778, 56.65024718930645, 52.24125600630238, 35.6374708298714, 40.62347404418453, 20.907354816313713, 24.291126689603253, 24.49146370733938, 8.528070180646836, 2.058327976734408, 0.0894402135764399, 0.05946547221091967, 0.149166741738877, 0.05401965193150025, 0.295472635376838, 0.16108665615320206, 0.10833486824506715, 0.04758996408312552, 0.25453177821491996, 0.1139318912981018, 1.723993968579077, 34.13564235933366, 34.17765094387916, 33.63008806782384, 22.86633945280506, 56.385043974845644, 28.900917730023785, 0.4202597780573753, 0.23971315563446094, 12.009914055947336, 13.653629364505893, 20.363255393120554, 43.2757140744117, 57.233087862691576, 40.12745111219345, 32.233300670500725, 31.20452573222499, 26.44929712818515, 28.36749892080984, 43.92389359012727, 9.31055361224759, 17.853693539096465, 17.51584214548911, 11.755476767016996, 23.930821687944476, 21.838472543224213, 66.92209920575543, 64.0572980911501, 37.69407933758151, 27.937218835276944, 64.10586880099389, 17.427757478529408, 0.14577055139647377, 0.1629471006773172, 0.05653517823966761, 0.06855165420640862, 0.03503655241201482, 0.0717345197054167, 0.2567129071441389, 0.23283331835221863, 0.38982724170050315, 1.279030490306116, 5.833498460631217, 4.6613829558895485, 55.461133603126775, 81.52784470588931, 84.2268668451617, 81.05414790491905, 86.92766189575197, 78.34649655126756, 78.34373520266625, 74.32327439708095, 75.33290032417544, 76.40160499080535, 78.91108251387074, 80.14593878099996, 75.16736845816337, 76.55705636547458, 70.14449888660063, 69.70867649201425, 69.90450474523729, 76.60963181526431, 69.07024798854705, 68.84238966049688, 69.2595729520244, 71.1043107125067, 70.9701499631328, 73.22317507959181, 69.88814061687839, 70.37333780719389, 72.43313912422427, 74.26937318617298, 69.93878626054334, 74.19291050203385, 71.95190352778282, 67.06017448056129, 69.18187079891082, 71.38988279527234, 70.48294451928908, 72.17398812693935, 69.54378789471042, 59.39961294974051, 70.48940858533307, 74.00734316918158, 72.22267258551814, 72.35240105659732, 71.61736457578598, 60.186358036533484, 52.171327990870324, 58.8883476872598, 56.83627736183905, 57.454568416841575, 51.8490582127725, 52.7088652887652, 51.05973220640614, 53.19461161090482, 51.853239459376184, 52.54582020544237, 50.654115984516764, 52.579430995448945, 50.508639197195734, 52.533362757775095, 52.52471785391531, 57.104069340613584, 56.648701775458555, 55.71218098363569, 53.43520195253434, 50.314113170869895, 48.23525305717222, 47.86838985258534, 46.68304958651143, 49.63977929084532, 48.58128063140377, 48.580719732469134, 49.37908680208268, 49.705231881910755, 51.545325556109034, 53.29848774017827, 51.58041507967057, 54.2188326774105, 54.70283746719361, 49.83249318215155, 52.23780039818057, 61.51096597794564, 62.33810363277313, 66.77253923108502, 67.12989068800404, 65.15336913447227, 60.41524794793899, 63.240048731527025, 59.63804206540508, 64.78554102682298, 65.50907319591892, 62.20770443639448, 63.03062554328673, 63.866211983465384, 66.01097968316847, 63.56720578285956, 64.95721532452491, 63.34080657651348, 60.80232704839399, 60.81491001190678, 59.730649225173465, 63.753118284287, 61.77103480985088, 55.481243595000244, 56.73844168263098, 60.10032869154408, 57.17011028720487, 57.402616623909246, 65.64677976792859, 61.40259873482489, 63.2892313311177, 57.70775741146457, 60.34592789988364, 59.2352185710784, 64.56638643818518, 62.16537813986502, 59.821287355115345, 47.359815336042836, 56.61196877879482, 35.311910183199, 24.91945508987673, 21.98763635850722, 2.9226626936466467, 1.9478500081646828, 0.2183546396272798, 0.14764587334807844, 0.2755774852008589, 0.11924624322883545, 0.057035629006643454, 0.22277631526512487, 0.19860990315435395, 0.155837697487685, 0.3030551897902643, 0.10678625981053037, 1.878605220587023, 39.834967813184186, 41.55529975891113, 43.666342919872655, 26.314950066228068, 64.8953870034987, 35.700636679126376, 0.437095326281363, 0.4141737610822724, 14.907360076904299, 28.59864223387934, 38.563123595330026, 52.147009295801965, 75.18233622274091, 60.5723584851911, 49.598833668616514, 71.5667660005631, 48.5166125143728, 67.40955568129017, 94.59319699195125, 56.497678756713874, 65.91202612846129, 57.55129014292071, 47.51991471936626, 49.658465462346236, 49.00128018471503, 80.66574696571597, 71.52449853958623, 56.432159485355506, 51.1051610977419, 76.8320772724767, 24.083072408553093, 0.3900877422382755, 0.4759038696365972, 0.1219048900830169, 0.18169322621918496, 0.34464843210674106, 0.33461261901163286, 0.5322474301342042, 0.8713072201898022, 0.7232906981821984, 4.509485248596438, 8.788702853264349, 8.573451022947989, 64.71661713815504, 89.62824513835292, 90.73549101429602, 83.7176255256899, 91.41628896036457, 83.33806560885522, 82.17345114677184, 79.6132573773784, 79.28015401286464, 82.56768072805097, 82.66380233149376, 85.13185178079914, 83.29320153882428, 82.94293388243645, 75.65837075633388, 74.03874566478115, 72.9859422868298, 81.54693880388814, 75.05737735379127, 75.91988302046254, 75.17799023658999, 76.99790723862188, 75.80884072088426, 79.83091754298057, 74.9216555010888, 75.12379092554893, 74.46362464658677, 79.78092301276423, 72.51892135989281, 76.4694227710847, 77.41258021323912, 69.28520956347066, 70.04027366638184, 71.46750650098248, 69.43233766863423, 72.91820295395391, 76.69713989380868, 63.50935474518807, 70.86383804198235, 79.05122880012759, 73.96633086665985, 75.06721465818345, 76.9658536295737, 68.09370333148588, 56.01620781806208, 62.428937881223625, 59.77463860665599, 60.496260581478, 55.29852782526324, 56.02280132232174, 54.11254821285125, 54.06910404082268, 55.760214328765876, 56.88123164638397, 55.19696981676164, 57.247635933660696, 55.39750883656164, 58.52263765950357, 56.991450248226045, 59.423755138151115, 59.62855385195825, 59.562261873675936, 58.11018474640385, 51.73873370693576, 51.534323307775686, 53.14504069666709, 49.15961450146091, 52.86339098407377, 53.05910548856182, 53.16939077069683, 52.05339016452913, 52.97979908604776, 56.132682600329005, 57.45473707875898, 55.080412664721095, 55.791648203326815, 56.75441357397265, 52.147260327492994, 57.0904234147841, 67.38286002989739, 65.27135402925553, 68.9135963686051, 71.00603180546915, 65.29954410368397, 63.77939816444152, 63.901756501966915, 60.751147962385616, 69.34846954960977, 68.29812942012664, 64.21858203026557, 66.50714382048577, 67.10514053221672, 69.04606265406456, 65.80588679159841, 68.26038052958828, 65.50532733240436, 63.750525597603094, 63.76937258628107, 63.86302309651529, 67.40222084906794, 67.08826649573543, 59.86086014778384, 66.25124054570352, 67.07248287816202, 61.75952657576531, 62.43259745259439, 67.97920934615597, 67.37597234787481, 67.72205091291859, 64.23437741494948, 65.56044447806575, 61.918417869075654, 69.13968178533739, 68.12610210910921, 64.03954152138003, 51.911337606368534, 58.274983129193714, 39.64860031681676, 27.085933108483594, 38.00340137174053, 20.834892949750348, 3.1062212826744204, 0.2866861584686464, 0.25542914296590513, 0.5788625932989583, 0.3844596313372735, 0.9766251269367434, 0.328276367076943, 0.27363637161831705, 0.2536081672916489, 0.6067396135580155, 0.19917025050568968, 2.5106880645598135, 52.31117225462391, 50.26933539298273, 45.48998617356824, 36.77156140727382, 77.9960092421501, 46.19917815731418, 0.5577837759929319, 0.7531810587932988, 24.97840831356664, 41.47194547037925, 55.84593380651167, 80.44867515563965, 107.63426980664654, 88.25321905074581, 81.59430534608903], [1.6418277904871972, 46.7410732084705, 41.589898986201135, 23.387738158625943, 48.26438450044202, 47.56870900430987, 38.60250026948991, 26.10799797119633, 30.148798227310184, 35.74013886913177, 57.91942419544343, 56.12613616451141, 49.51797400751422, 46.749310185832364, 53.1581453354128, 1.793726355798783, 0.08044723766825854, 0.16374910280348795, 0.06247165102151133, 0.06141963610125165, 0.03854419322564237, 0.10495240619826703, 0.6952083050724, 0.39403033713179253, 1.7460157481893417, 2.9535013485339383, 3.8016996797054046, 25.559493726299657, 50.21957620497673, 63.37753172843688, 85.6783320826869, 74.47076336030038, 79.29968741632278, 75.06897188002064, 71.14408354605399, 66.3727241946805, 66.95485884143461, 71.36616814521052, 74.03431338648643, 74.48341692647627, 68.80327578513854, 69.77244638627576, 67.49286682375016, 64.41079385818975, 67.39441533242503, 69.18783280157274, 70.37008223995086, 62.310097909742794, 63.920281856290764, 72.75678957662275, 65.37014284441548, 69.75929075671782, 67.26471824030723, 70.25498420961442, 68.58591371966948, 66.80959778447306, 69.18955079970821, 68.91333749217372, 64.13433736370456, 65.61582442252868, 72.45078978999969, 67.84598212088308, 67.1675140626969, 67.59472293238487, 58.75898791897682, 63.2167027842614, 69.40801897356587, 63.56853938871815, 68.06807456477996, 68.68249816279258, 63.54951589338241, 52.94052831588253, 51.76411536432082, 59.81566659865841, 57.38707619328653, 52.253580093383796, 52.0672792773093, 47.03263475048927, 47.88906074339344, 47.64747019736998, 49.65183665675502, 47.767737911593535, 47.05173277085828, 48.321035292840776, 46.95355192307503, 49.97757773245535, 49.283894800370746, 49.69111527166059, 53.44661997210596, 52.61587765909011, 51.020018208411436, 46.342685914808705, 46.493524582155295, 43.51099352682791, 44.11750178183279, 46.954701177535526, 45.136502173639116, 44.765336128973196, 44.73033289755545, 48.22372128886562, 47.422996874778505, 48.599762839655725, 48.39759211386404, 53.84338340451641, 51.834055146863385, 53.19571379692324, 47.21436208294284, 49.09996309588033, 58.258583699503255, 62.43979107949042, 62.741695911653586, 65.80617704699117, 61.06803624860702, 60.94314798232048, 62.70310763389834, 60.00563875321419, 60.11826569034208, 59.4351064774298, 58.22497290949668, 57.82110998707434, 58.72386309408373, 60.4683921414037, 59.94737194430444, 62.40534482463714, 56.55263116282802, 57.14001786324286, 57.37011194229127, 58.88299365197459, 53.426619806597316, 51.64883298258628, 47.142759215447214, 54.74748188449491, 52.20489955717518, 53.32082171593943, 57.924429139783314, 59.01048244968538, 63.07671731518161, 54.27779766821093, 54.97179438990932, 54.890577793121345, 57.87265777587891, 56.576945935526204, 55.962102643905155, 35.27023892248831, 33.32569645297143, 17.24596150459782, 18.191835188096572, 7.494109869003297, 2.2896056309823067, 0.22202398627996447, 0.13649639823744375, 0.17833365487956232, 0.07484263800565275, 0.09200231036952428, 0.23686142397984383, 0.06779115872397538, 0.10929274628119123, 0.12320749236330872, 0.13253356330096722, 0.04339196313653262, 1.4516493437751647, 39.605877860899895, 30.341143415820216, 61.52258403839604, 26.609253344997285, 53.82708595645044, 28.876467635554654, 0.7284263677654729, 1.5075632208778014, 12.243009728770103, 7.418040402473943, 31.76223577991609, 28.993709241190267, 21.641045924155943, 2.6948673686673565, 1.6556692219549611, 21.675180350580526, 30.51431998129814, 48.484358864445845, 20.16107290021835, 33.176893495744274, 48.520303464704945, 39.03241165222661, 29.789693470924135, 40.27140994225779, 51.509471170363895, 69.10894609266713, 68.11173838953819, 46.568692884137555, 41.971223969613355, 66.40787647616479, 2.3533620420963537, 0.168746279011811, 0.06201668289460002, 0.06460399547171208, 0.04180384754774071, 0.04747348041423867, 0.05054216433857238, 0.49318954048137514, 0.47617408416924945, 1.1431141125579034, 4.567994263864333, 3.8540924941339805, 21.768756335781468, 62.271603768871685, 74.8348456044351, 89.61020223556027, 76.41429778068297, 82.03930608687863, 73.77969664912071, 73.30831404655211, 69.13729698427262, 73.56792003877702, 75.49759280297064, 78.36470419360747, 81.7477092435283, 72.04338888968192, 74.22943561307846, 73.51668603958623, 72.5570232637467, 71.30697173456993, 74.33790483782369, 74.83194305050758, 71.19589805603027, 67.45401966956355, 75.26934223790323, 71.55032342480075, 74.03439183388987, 69.34024041698825, 73.51704689764208, 68.14991089605516, 70.6862017416185, 70.99289971013224, 71.27773438730549, 66.50838328946021, 69.37653803056287, 73.73470706324424, 71.24626913378316, 68.0824931975334, 68.77443067489132, 60.85660088446833, 68.91550264050885, 72.67996603442778, 67.25984665655321, 72.75619337635656, 70.17095135104272, 65.89068843472388, 55.52219313959922, 55.082821000006895, 61.74606107896375, 60.01091434109596, 54.77274979314497, 52.674011107414, 49.47727549460627, 51.3090302098182, 50.37550218643681, 51.442559457594356, 51.38821501885691, 49.6531428060224, 50.441339169779134, 48.3926813064083, 51.15026050998319, 52.81821312442903, 52.358358367796875, 54.36604707471786, 55.12629262862667, 52.61081387919765, 49.71313545780797, 46.827094708719564, 45.5873276341346, 47.3540690637404, 47.412637895153416, 45.50204353947794, 48.80564412763042, 47.13639713102772, 49.54881168180897, 50.023285112073346, 50.31346205742129, 51.2570744945157, 53.86376011756159, 56.039887166792354, 57.40239304880942, 48.03940126972814, 51.149629008385446, 59.257995774669034, 67.86921039704355, 64.97245373264437, 65.81454738493889, 67.37443477876725, 63.470134965835086, 64.64591641579905, 63.87725737787063, 63.096995968972486, 63.77889217868928, 61.197800021017756, 63.51424986316312, 61.46549786290815, 62.78071172775761, 62.723692232562655, 62.22409209897442, 60.46958454193608, 59.8601423540423, 60.14040354759463, 63.937983512878425, 57.1055402294282, 59.41412571937808, 53.940430687319854, 61.57532030536283, 55.17820912022745, 56.30649851214502, 59.34031847984561, 62.35928050933346, 63.27272599743259, 59.68018401053644, 57.9178277907833, 59.40938357383975, 62.494284568294404, 60.54904783925703, 62.77046257449735, 48.6639485051555, 48.45236016858009, 26.964196466630508, 16.7432842716094, 3.1420460054951334, 2.0261134279351083, 0.6841896931009909, 0.12047496398970967, 0.15285983711721438, 0.10476774836499846, 0.003696703652460729, 0.13842117882543994, 0.04114108956268719, 0.06939543110709037, 0.06097016082475744, 0.1989402402673037, 0.04384253774919818, 1.4717546778340496, 45.81495454234462, 33.49732368223129, 53.446572903663885, 33.84435146085678, 63.28639545748311, 38.47351312637329, 0.5103779488032865, 2.0175698928294645, 22.307631161905107, 19.691486743188676, 41.407799028581195, 50.004849972263465, 45.833974115310184, 25.19274623163285, 28.520789069514123, 49.10971018575853, 133.23681154558736, 101.03597241063272, 99.48299623304798, 110.60390410884735, 87.12814207999938, 85.85110464403706, 69.86914850050404, 60.7382002184468, 73.03061023835214, 77.18936597147297, 74.9964080318328, 66.80385543454078, 63.78755669439993, 74.85208049897226, 4.848874701607612, 0.5237778684785289, 0.29151174630368915, 0.36256753509083106, 0.09216117402238232, 0.37190495179064814, 0.13912999401650122, 1.6402362887897801, 1.102213720160146, 3.91614439026002, 8.645839345070625, 5.50647133781064, 24.51202084941249, 75.54771284903251, 85.38169107129498, 97.44243806408298, 83.78923231555571, 86.55584473763743, 80.51082903339018, 77.59683747445384, 73.83976382593956, 78.06902808527794, 81.33589175439651, 84.39944328800325, 85.43925577594389, 77.46432412055232, 80.01297827689879, 77.75617984033401, 74.95835319642099, 76.22500419616699, 77.69462216284968, 80.44396046669253, 76.59409922938194, 75.07965641637003, 79.42411284292899, 75.48836738832536, 79.12540082008609, 73.87719108212379, 78.59676730248236, 74.47754906069848, 72.8402340796686, 74.43611314219814, 75.89876497945478, 70.4246659432688, 70.49002831982028, 78.18188251987581, 70.5081496700164, 71.71144654673915, 71.98808347025226, 63.47795224958851, 70.64710355574086, 76.69280959713844, 69.7940900248866, 75.39705461071384, 75.33381031405541, 69.37607519088253, 59.246244353632775, 57.092941576434725, 67.42559817529494, 61.652202683110396, 59.45328666317848, 57.4296142978053, 51.668323239972516, 53.51388077582083, 53.3648895448254, 55.5076019225582, 56.26694140895721, 54.39738681239467, 54.400983625842684, 52.18229886024229, 54.52633473180956, 54.5041262718939, 54.188971673288655, 58.08091602017803, 57.11161990319529, 56.20568183160598, 50.959013585121404, 50.40540241426038, 47.698425708278535, 51.009651384046, 52.21070074266004, 50.74162798543131, 50.78588801045572, 49.28116090836064, 53.425286200738725, 52.126632582756784, 52.9224540341285, 52.32891705728347, 58.40879478762227, 58.385229187627, 61.857566218222345, 51.63317095848822, 53.36264594908684, 62.70537476385794, 69.51097334584883, 69.38701075892295, 69.87651471168765, 69.25333638345042, 65.09073280519056, 67.16698846509381, 66.54486133206275, 65.49204226463073, 65.8607058371267, 64.7292197135187, 65.27460959649855, 63.107978605454974, 66.13877834812288, 64.82950687408447, 65.61676579137003, 62.6995147428205, 61.61361048298498, 62.58473050209784, 67.74720115046348, 61.67015929375926, 64.31177754555979, 60.919256825600904, 71.2478929950345, 61.055923969514915, 60.06832999567832, 65.87305345842915, 69.85491814151888, 70.00704334628198, 64.27409925768453, 61.09943089946624, 61.732858380963734, 66.8197645679597, 67.72805998402258, 72.40667097030148, 55.30700014483545, 57.12015890306043, 31.505071463123446, 24.00417785490713, 27.37124239244769, 3.8298328797663417, 1.1274502498488272, 0.249119290421086, 0.2954210010507415, 0.17624966589914215, 0.3634200377329704, 0.39061683320230056, 0.1558292858422764, 0.2828853204846382, 0.2393087991062672, 0.43076694973053475, 0.14431542867133695, 1.926568330776307, 59.03816261599141, 44.24526906782582, 76.22378041667324, 43.97954025576192, 74.99480770480248, 49.72961333490188, 0.6019130144869128, 3.484169105368276, 36.00754645562942, 36.366215828926336, 75.8643893272646, 72.68107214281636, 49.80730764327511, 28.413161193170858, 44.145899741880356], [19.124551280852288, 82.31999089640956, 27.294138400785386, 58.9106777406508, 29.566238003392375, 20.10878574463629, 15.121758791708178, 18.99595049119765, 25.86554450373496, 42.32496292360368, 63.61685122213056, 53.3503963870387, 29.76927165062197, 45.29364408985261, 44.59931396668957, 0.8339243971051709, 0.02587267186402554, 0.1121172511709794, 0.05770545798323809, 0.07570162175163146, 0.057276739859052246, 0.08585717438930467, 0.40058100175473, 0.44377104709706, 0.45809158995266885, 1.838989404420699, 2.454974718632237, 32.158885463591545, 23.658342476814028, 32.343882091583744, 69.04963201092136, 82.0690925659672, 75.1997672357867, 71.94317233177924, 69.40319445825392, 61.717702342617905, 66.78790707742014, 66.88919836475004, 70.90532887366511, 70.81458876209875, 70.1022941835465, 71.5200819507722, 67.97795418770083, 68.46272776203772, 65.00346791359686, 71.23823611967026, 70.76564542708859, 71.15418757161787, 58.573142097842315, 60.24278133146225, 66.76096039433634, 68.77104174706244, 64.01479528796288, 66.32789150361093, 65.34041127850934, 68.4751695202243, 66.74130147503269, 68.109981167701, 65.19988059997559, 71.31207866053428, 68.82473899472144, 70.72733171524541, 68.50756045310729, 59.862240822084495, 63.21360411182527, 70.36161776511901, 64.78139508155085, 70.7267512044599, 68.04328518529093, 66.25999527592813, 52.09713635906097, 50.56165395244476, 59.0497689093313, 60.178387780343336, 56.041244306871974, 51.59555935090589, 49.07726041732296, 46.99654110016362, 47.79004835313367, 45.25476555670462, 48.71501384242889, 47.08389620627127, 46.6960326317818, 46.031351704751295, 47.54864608087848, 48.93726318113266, 48.18767078461186, 51.536970907642, 54.796640949864546, 53.20700237827917, 50.77046525093817, 48.236676877544774, 45.34002219477008, 41.80592352344144, 43.58109412654754, 43.237945572022475, 40.43640836592644, 42.98055571894492, 45.64655934610675, 45.25407129718412, 48.52687343474358, 47.396003123252626, 50.20348272015972, 51.43542466625091, 52.95136190229847, 53.71620055167906, 51.99584507173108, 47.46271087277321, 52.53829709945187, 60.244566009890654, 61.616156101226814, 60.90206115476547, 61.63645828923872, 59.418471705529, 59.32495063351047, 58.868323987530125, 57.87292057468046, 61.74464510333154, 62.294726141037486, 58.97330230282199, 59.65805007565407, 59.01960196033601, 59.61719466793922, 58.96100174996161, 60.43456169866747, 57.88336584644934, 56.83574784186579, 56.68474443497197, 50.648177516075876, 52.50967948667465, 45.08480533476799, 45.464380941083355, 51.1611686214324, 52.67227349742767, 47.43269297384447, 54.70487317731304, 53.734102249145515, 57.02304493996405, 52.38226521399714, 51.57998754132179, 51.65718763105331, 50.0987946602606, 50.178034382481734, 25.682405118019354, 23.0286608588311, 21.798254520662372, 11.767269372940065, 4.3031994661977215, 0.4823366792932634, 0.26847431796693033, 0.19615407041724653, 0.015338158512848522, 0.12924750575855856, 0.06179166754948036, 0.1153381682571865, 0.048186895963285244, 0.10319248773157598, 0.03656215522618544, 0.17439058501153223, 0.08989571413445858, 1.7107220162307064, 38.68234795908774, 28.518812194947277, 49.10822360746322, 26.124750414202293, 48.86130648274576, 31.281255137535837, 0.7997457214420842, 0.5417843667730209, 10.616854871473006, 5.031951329400463, 12.339880504915792, 4.535987723258234, 2.5209244701170155, 0.8856284678463013, 1.2821557613149768, 11.275484561920168, 72.1019498763546, 52.941124516148726, 56.23790018020138, 48.67775132579189, 40.74327107398741, 37.835327809856786, 39.54823470884754, 41.11556676126296, 54.474830089076875, 77.37776525558965, 61.22144799078665, 29.660143467687792, 51.21089643047702, 54.958576002428615, 1.2080050692442925, 0.15439493942164606, 0.020395221729432384, 0.042667102233897296, 0.07705620309758572, 0.0900910282507539, 0.2583505886216318, 0.10447297305349382, 0.7039082446886648, 0.647220557495471, 2.520260363817215, 3.379619799314007, 35.66432729844124, 46.14586530193206, 59.58812206022201, 80.75832274652298, 78.56388215095767, 77.95650312977453, 70.68726078156503, 69.91106294816541, 65.11779323700937, 66.73223295519429, 72.44332944193195, 76.20708680921986, 75.73443335871544, 77.46074691895517, 78.0135500815607, 73.54131067952802, 72.39153062143635, 68.55451122406991, 74.67868820313485, 75.60407730840868, 73.82459209811303, 65.63608346446868, 64.16981127954298, 68.63169562432074, 71.47612787062123, 67.57233404344129, 71.92574131873347, 66.29409636220625, 70.16770362854004, 71.55716403838127, 70.54471400476271, 67.91157199490455, 72.54521692952802, 70.97418215966994, 72.19844018259357, 70.09266868714364, 62.276973493637584, 67.20994626322101, 73.708387959388, 68.16172507501417, 74.15633832254719, 73.08137355312225, 68.78495047169348, 54.5201373869373, 56.351186075518214, 61.6610437054788, 61.97553934589509, 55.28837673125729, 54.83341317023001, 53.417280643217026, 50.00343399663126, 48.907919929873565, 48.942758421744074, 51.70190657338789, 49.815105315177675, 47.4725442547952, 48.23160525291197, 47.61223554611207, 50.93962923172982, 51.06804370880128, 53.11896870213171, 57.22131682980446, 57.08526157563733, 52.64586417905746, 50.0694670984822, 47.59080371549053, 43.49680239154447, 43.72676703237718, 45.20344134299986, 42.68653485082811, 47.45152427304176, 48.0669088517466, 47.7073569451609, 51.28834755189958, 49.57577797674364, 51.12087019028203, 54.89661432081654, 55.379924851079146, 55.136965397865545, 55.659899711608894, 49.06415970094743, 53.49972494186894, 61.501179664365715, 62.44984803661224, 64.20550877048125, 62.34798408323719, 63.90065823831866, 60.851399821619836, 61.742809434090894, 63.53685448246618, 62.94165049829791, 64.60036200861778, 62.523051231138176, 59.90675187879994, 63.334695523785015, 62.997995345823234, 60.000123900751916, 64.56588829717329, 59.33859655933996, 59.712057190556685, 58.8018358907392, 54.839430086074344, 58.75779551844443, 54.3729269120001, 51.113099974970666, 55.137302721700365, 55.17334930358395, 53.03633220734135, 58.88701408140121, 57.14352838454708, 59.48712495065505, 56.83497905731202, 56.44687621824203, 54.808388448530636, 56.070532644948656, 55.20297104312528, 39.48013059554562, 38.40706817565426, 23.823625272320164, 12.722662648847027, 1.7325006088902875, 0.8109502782744746, 0.34695074082382266, 0.1682889858080495, 0.05064284361358132, 0.050889347724977045, 0.09148323983554879, 0.1688711666652272, 0.006303848330712607, 0.2054398834344841, 0.054499334054848844, 0.35673766727409056, 0.198260628347916, 2.1627414707214605, 47.29083261182232, 33.14757377870622, 52.78294709420974, 30.736082946100545, 58.61950451327909, 42.073644899552875, 0.5931718899838386, 1.709455213239116, 21.050958671877464, 14.957602697034037, 30.49637317657471, 19.05474485889558, 9.231732603042357, 1.952093767542993, 6.898362636566163, 48.81716805119669, 153.1358269722231, 76.69669274360903, 148.43776887462985, 59.20565174471948, 34.053162759350194, 47.0223149945659, 66.05597711378529, 55.76486625979024, 67.4941925848684, 86.4849361296623, 70.56410620289465, 43.92530564338931, 61.2396046423143, 68.08656461777227, 2.220580005838025, 0.26952876138591, 0.2331314644505901, 0.14100352332236307, 0.2468949847764546, 0.23694829835045725, 0.33456432482888626, 0.5365008728638773, 2.328589087532413, 1.2696747794266672, 4.517327047163441, 5.538388154199047, 40.736944290899466, 52.64842940915016, 71.36584651085639, 90.87072649309712, 86.23633630814092, 85.02562615179247, 77.01449886445077, 76.58384615375151, 70.21544671827748, 73.89572035881781, 78.50168120476508, 80.58212987838253, 80.732191916435, 82.80005762653967, 81.00862487669914, 77.93489087012507, 75.23236213191863, 72.82607432334655, 77.57944568510979, 81.02887215152865, 78.83842452879875, 72.02875060419883, 68.76705661896737, 72.95113517392066, 76.8819933552896, 72.44985626589867, 74.71176162842782, 71.18010659371653, 77.39039528754451, 75.00870073995283, 75.66735298402848, 70.24626085835119, 74.59984071793096, 73.88730295242803, 75.02584934234619, 73.44685216103831, 64.90625589124619, 69.06202670066588, 77.25494015601375, 70.59373578717633, 77.25250828650691, 75.52817944557437, 75.37763103362053, 58.12906703641338, 57.89829830969534, 64.26498759177424, 66.1705966149607, 60.365033764992994, 57.44903395252844, 55.74178703369633, 51.64407906993743, 51.92028061036141, 52.422045892284764, 54.00103130648213, 53.84748228134648, 52.194717084207845, 53.255149472144346, 52.20481718740156, 53.850788839401744, 53.39924950753489, 54.45682640998594, 60.17868195810626, 59.08401512330579, 55.45187680952011, 53.41433494321762, 51.0430464436931, 46.938819500707815, 48.103371204868445, 49.44987381658247, 44.275812564357636, 47.552858706443544, 51.070656007336034, 49.5649875363996, 54.55967880064442, 53.135917263646284, 56.077255587424006, 58.42114633129489, 57.20263458067372, 56.489908541402514, 58.77724655212895, 51.51108718687489, 59.77572510319372, 66.86210263159968, 64.996733204011, 68.91768347832465, 67.0092228920229, 63.84864368746358, 65.31890100048435, 62.516206695187485, 65.66208485634097, 66.47134042555287, 67.45878927169308, 64.45029212582496, 64.8547081024416, 64.42230209227532, 65.26807885016164, 62.613053937112134, 65.66250062757923, 61.74502949560843, 64.67365541765767, 66.97880098896643, 59.585066533857784, 62.794989155184844, 61.824712445659024, 60.53304456895398, 63.11759233474732, 59.43957405705606, 58.14379553641043, 64.48917458134314, 62.70253889022335, 61.88966689571258, 59.55730399777813, 61.33613809462517, 62.88909858272922, 67.81426583566974, 66.38324399148264, 47.94142830756403, 44.32989028192336, 30.132467439097745, 25.94612567655502, 14.780808725664693, 2.412528544664383, 0.6415859501688712, 0.31550470078664444, 0.1254895303939139, 0.36671237719635813, 0.1809417092872243, 0.25846421478256104, 0.15261867263865087, 0.307307927719047, 0.11402589794729026, 0.5184200946842471, 0.32407008471988863, 2.9181107830616737, 58.43965991850823, 42.244903426016535, 69.2931092169977, 41.19251974167363, 71.33306334095617, 57.24330171462029, 0.6580896903910946, 5.002951285531444, 38.145752030034224, 41.444010350012014, 61.77856576058173, 22.820724248886112, 5.884120079778857, 1.9531867605063225, 12.059926236829451], [45.13529800599621, 60.260843846105764, 59.889324788124334, 31.655566923079956, 11.866395511934835, 2.6812538023917907, 6.306854995989031, 12.313677110979635, 20.865675710862686, 39.12022567564441, 69.3985660614506, 49.29257500556208, 43.89847270904049, 56.23134197727327, 42.62046252527545, 0.19147327319989282, 0.102519019837341, 0.08718550956297307, 0.09400198371299813, 0.12077214481729655, 0.15191016388275932, 0.004320946567121052, 0.14622433591754208, 0.5384390140252729, 0.25423484253546885, 0.6700861369890552, 4.95087887971632, 21.000515030276393, 14.060596842919628, 15.386842373878727, 39.32206299997146, 66.6797516422887, 68.66324716998686, 71.4307774266889, 68.43817372475901, 61.87142787441131, 60.7779848191046, 62.918520281391764, 66.61472658957204, 71.19546659531133, 66.363357574709, 72.45727739026471, 70.20974359204693, 71.2367142400434, 66.22289749883836, 68.214598624937, 69.39031339460804, 70.22788847646406, 68.78227541523596, 58.15221294280022, 57.410284857596125, 61.51502170870381, 67.10306167602539, 66.15977871802546, 69.67783097297915, 65.83244908240535, 67.44393133348035, 64.54811211555236, 66.38641326658188, 70.73514507662865, 66.16880016942179, 69.25919640448787, 60.24471113758703, 61.10018399453933, 70.83838185956402, 63.98224746027301, 66.77173122282952, 66.1384645585091, 67.81829803220688, 54.96049404144288, 51.22824507374918, 58.34119273770241, 58.57189870649769, 56.894912873545, 52.22580186782345, 51.82000129453598, 48.883346280744, 46.52831600558373, 45.04945693477508, 45.16934810146209, 47.426970235763065, 45.95961547666981, 43.85937452316285, 41.39012090621456, 45.44493382976901, 48.14881970805507, 48.23595516143307, 51.68703686806464, 52.18556227222566, 54.93410433492353, 51.30439004590435, 48.447794529699514, 44.4486871073323, 39.96459038026872, 43.10966837790705, 42.41828003237325, 42.658693867345015, 42.96110468526041, 46.16653227037, 46.89725414399178, 47.34276087053361, 46.830228682487245, 48.56022142594861, 51.46587794826877, 55.04442884076027, 54.62694352672946, 53.571386644917155, 49.52272007542272, 47.881855349386896, 53.95931689969955, 56.40353795020812, 59.65140165821199, 60.445324682420306, 57.625470007619555, 58.20263108899517, 58.83163805930846, 57.462503371700166, 58.60088894444128, 59.246405170809844, 58.540982584799494, 57.8187487202306, 59.3858415080655, 60.20355762973909, 60.02958090074601, 58.80964140738211, 56.04637084468719, 55.49418349419871, 51.702141915598226, 54.13923601950369, 57.244643165219216, 48.59953534218573, 41.271877134999926, 46.281744049441436, 48.38437764875351, 49.09995132876981, 51.47517396557716, 50.18075258501115, 48.73024048343782, 47.16298687842585, 52.26165625356859, 49.55480114106209, 45.070590665263516, 32.104801862470566, 11.107360989816728, 16.842082892694783, 18.155584642964026, 9.454321226766034, 0.6813897336682966, 0.40607097168122575, 0.14122041813548536, 0.08589271320811204, 0.08817614551873938, 0.08320399740290257, 0.068873051073282, 0.1584628509778169, 0.03739496940867074, 0.036253517553690946, 0.1211556024669159, 0.09767529104025134, 0.029479373591921987, 1.9864656199370663, 41.167012568443056, 26.57790380139505, 36.06205955628426, 64.29598608324605, 45.082318552078746, 22.551275068713775, 0.17025328121118008, 2.9037683913784647, 13.06442758729381, 3.1469276403227164, 0.8191825365347247, 0.9624339303662701, 0.4213751714316107, 0.36013404147759565, 0.8728996411927286, 26.487216641826016, 76.33911378922002, 57.69422523437008, 72.58080067173128, 20.205834988624822, 12.887289427941846, 18.817802321526315, 31.94893667774816, 44.1286648473432, 48.160135746002204, 79.91488764362951, 60.03426028836159, 41.02814105249221, 69.02178318269792, 48.38349903783491, 0.34422254850787504, 0.4195968974982539, 0.14678771697705792, 0.42776924768282526, 0.14068294616956867, 0.22068048256539533, 0.0247316605096022, 0.18235584630841212, 0.10307676248973417, 0.21840512482148988, 0.9877863538361366, 5.71735070597741, 30.234421606986757, 24.378803430065034, 29.940318369096328, 67.05429877004316, 76.9896859507407, 72.14352700018114, 75.72159151877128, 66.75651242656093, 65.81006019346177, 64.51085352128553, 66.13232212681925, 72.35272269095145, 76.37369340465915, 74.22198310975106, 76.81354799578267, 77.74775458920386, 73.84151320303641, 70.3229824189217, 69.75707853994062, 75.70355646071896, 73.38436095945298, 74.26250119363108, 65.07010113808417, 64.85376281123008, 63.499642956641416, 69.05722571957496, 70.15137087914252, 70.12178051856257, 68.81433686902447, 69.74436221584197, 66.57611477759578, 71.04496525179955, 71.44528235158613, 70.53242914138302, 72.1332896140314, 61.971593441501746, 63.97784656093967, 73.13432555044852, 67.63634712465348, 70.20718620669457, 70.04579636358446, 68.694822249874, 55.04446414209182, 54.84532148607316, 63.24690503458824, 59.78874737216581, 59.202658976278, 55.83009527575586, 54.50068635325278, 51.15453981584119, 50.43321594115227, 48.6667686893094, 49.906382791457645, 51.52054794373051, 48.4532936926811, 47.00264823052191, 45.231596116096746, 48.682309119932114, 49.50479484373524, 47.68446991520543, 53.1991772497854, 53.87363272328531, 56.89264966595558, 53.135525026629054, 50.4743851384809, 46.74714503749725, 41.648071658226755, 44.848098139609064, 44.687108378256525, 46.24891773346932, 47.99758488132108, 48.76277262164701, 48.67886135655065, 49.57213801722373, 49.915655274544996, 50.79707461018717, 53.96722047559677, 58.30644053797568, 57.88551922767394, 57.11575408135691, 53.57248098619523, 48.421530339025686, 55.75374241798155, 58.02531642298545, 61.16986097828035, 63.1817780002471, 61.823461209574056, 60.91080804024974, 63.64288007059405, 61.50735739738711, 62.588252790512584, 64.5304104589647, 61.875769938192065, 61.17703499332551, 61.13231605099094, 63.53528945676742, 60.99344061266992, 60.00558776240195, 58.33532094955445, 57.73322143862325, 55.95189271434661, 59.35368983976303, 60.50296783447266, 58.738332717649406, 49.03459287458851, 53.763555326769435, 52.23769449418592, 53.19502345977291, 55.294868253892474, 52.02646701566635, 52.60694642220774, 52.848046671959665, 55.67420459562733, 54.055885653341974, 50.03001982165922, 41.692763143970126, 20.457810009679488, 19.05733166202422, 19.157556064667244, 11.88078276572689, 1.924705082370389, 0.8650580264868275, 0.23742126571314953, 0.08291847643352325, 0.0954642004123138, 0.11386613031068157, 0.12370897351854271, 0.03813241713590199, 0.08976466713413116, 0.11646364334850542, 0.07862276863306761, 0.19667032174766066, 0.10329561848794261, 3.522476688508065, 51.29089709251158, 32.72336356101498, 45.69481234396658, 66.90281683398833, 53.76047626618416, 36.11982430181196, 0.2192543179637963, 4.032943013214296, 24.830587910067653, 18.21960949128674, 7.5198190442977415, 3.12859570787799, 0.7124400126837915, 0.6004522380328948, 1.943886085383354, 75.85113956082252, 131.24503981682562, 122.98828586455315, 119.24206149193549, 15.08824606095591, 5.908102921901211, 20.858742921583115, 64.06580571205386, 60.46152799360214, 63.619945972196525, 89.91442911086544, 65.18164157867432, 57.50091514279766, 76.38859056657361, 62.61905516347578, 0.6252932824915456, 0.57235948741436, 0.6341987788196534, 0.454698218813827, 0.2551062675493379, 0.6315215773159458, 0.09286721597515768, 0.44216529616425115, 1.017082414079097, 0.6245725469723825, 1.6338994546282677, 6.318586805174428, 32.75818244103463, 31.499925313457368, 41.22378887668733, 79.94758452138593, 86.7991336699455, 82.24316735421458, 82.26330480267926, 73.59617679349839, 72.52189451648344, 71.05394747949416, 75.33656381791639, 77.13645319784843, 83.60554772038614, 78.00346959021785, 80.21917727685745, 81.26591667052239, 79.33571046398532, 74.99346625420355, 74.53617280529392, 77.76671532661685, 78.03201660033196, 77.2891196896953, 68.24532647286692, 69.28886521247126, 68.76726058221632, 73.97042582111975, 74.34261168203047, 74.02750415186729, 73.03483070865755, 75.15805675137427, 68.69728549834221, 71.76303355924546, 77.6487696555353, 70.10888376543599, 75.8854289208689, 64.16993679538851, 65.09693799480316, 76.38842582702637, 71.35053357770367, 71.64740208656558, 73.57232093811035, 73.08711590305452, 61.01690815341089, 56.23637830057452, 65.75466455951815, 63.04088646365751, 63.20898355976228, 56.868166231339984, 56.7101300147272, 52.74090713070285, 51.329783470399924, 51.259129816485995, 51.41069804468463, 54.09877284880608, 53.14690774486911, 49.96759922273698, 46.33518634303924, 51.10790283449235, 50.91968005703342, 50.09651184082032, 53.69676520747524, 56.18246532255604, 60.54699643965691, 55.015093434241514, 52.276596561554946, 49.180014748727125, 44.69508647918702, 48.6216143638857, 46.78570585866129, 47.447405784360825, 49.830316266705914, 49.17005192848944, 52.09828953589163, 52.680961547359345, 53.67198759509672, 53.12842553661716, 58.09408733921667, 61.31159582445699, 59.93495764270906, 59.4302035147144, 54.34499963637322, 53.97144094590218, 60.22131027713899, 60.92488150442801, 65.22213220596313, 66.46029503114762, 63.39232690872685, 62.885517458761896, 64.08226789966707, 62.992966867262325, 64.33622960121401, 63.95309640515236, 63.27564424084079, 63.24975659770351, 61.76155836351457, 63.4378146356152, 62.05810916039252, 61.23154417161019, 62.28063306500835, 61.98435291167229, 58.67528846186977, 60.57606512500394, 64.548445517017, 61.071060396009884, 55.69270641573014, 60.9385548868487, 58.72429063243251, 58.826888069029785, 61.90883159637452, 59.19156651343069, 59.33831022631738, 57.09337303715368, 62.416048972837395, 61.554343469681285, 64.82825171562934, 57.34446748610466, 36.88750666956748, 24.937533294000936, 29.125802901483354, 25.923452415773948, 5.861867493198765, 1.4815172120448084, 0.29944069503295806, 0.18207694433869856, 0.17861756706430068, 0.2265520715304921, 0.21901909832752522, 0.25380034810833396, 0.23936752740654255, 0.262365379641133, 0.2498577685365754, 0.2773149113260931, 0.18446805796796278, 4.782110568015806, 62.36975716006372, 43.53789706383982, 53.65208548884238, 78.15664599018713, 67.29443411673269, 53.37592317212013, 0.36864714757088696, 8.904397083866982, 48.152702854525664, 47.273789913423606, 39.63884145982804, 4.498108904207907, 1.2730889575135325, 0.6299539775617662, 2.46658272800907], [58.395431272445194, 75.97302329155707, 85.92555122990763, 17.18991671839068, 1.8177788199916964, 4.313268190430057, 4.626973963552906, 12.397072584398332, 23.882680477634555, 46.584860893987845, 68.49955097321542, 33.14026248070502, 34.97965797301262, 42.41316133929838, 38.99174059590986, 0.4409797291361517, 0.14634255860601703, 0.22108989527388928, 0.19305671565234664, 0.0802486600174058, 0.13160947740318316, 0.047361608594656, 0.09359366651023589, 0.136682971290523, 0.4178835878208761, 0.2038745206570433, 5.8368913108302705, 22.70876999824278, 13.928851292979333, 16.09595787140631, 21.413866166145574, 34.930926445991766, 41.942178818487356, 55.56492344025643, 65.96635095534786, 67.93885600182318, 62.30554011560256, 56.60454373205862, 60.562658463754964, 66.10109221550726, 67.06436357190533, 69.92151214230445, 71.93477061487013, 71.28105271247126, 68.62688679848948, 60.682067178910785, 67.62738058643957, 70.11036642136114, 70.24976745728524, 68.87718892866566, 65.12225689426546, 60.657642579847774, 59.91384744644166, 62.93815566647438, 64.29467993397867, 67.74777381650864, 62.69845962524415, 68.83165805570542, 68.83951848553073, 67.35240674787953, 66.76125849446943, 62.62335800355481, 60.22344012414256, 69.54082258286016, 66.89806292133947, 69.3018953261837, 69.07839082902478, 65.89102575855871, 55.41838761298887, 51.27859261728103, 60.15374352855068, 59.545505508299804, 58.2350298666185, 55.59570620136877, 53.75225105593282, 50.17424537289528, 49.57805687381376, 49.483770939611624, 49.2479698119625, 50.0834228915553, 51.932855729133856, 44.61669791129328, 44.234647289399184, 42.80218593535885, 45.219401467231016, 46.29346801388649, 46.82383914147654, 50.10651388475972, 51.61839146767893, 54.092077362921934, 46.27259315982942, 45.39442939143027, 44.98579686687839, 43.23446642967963, 41.54674899193549, 43.089848641426336, 44.93647698433169, 46.00482863764609, 50.70050977891492, 48.317811104559134, 48.07110971020114, 46.41974479921403, 47.29765753592215, 48.51961704992479, 51.460712186751834, 56.099883740948094, 56.082335056797156, 55.5482376775434, 50.35827905901017, 48.67418196893508, 56.802682261313166, 54.16010302882041, 59.52223408606745, 61.28623377892279, 60.355510250214614, 59.52659576169906, 58.46562600904896, 60.386281244216434, 59.19841497175155, 60.50149302328787, 58.3639620965527, 56.70105365014846, 57.799403590540734, 58.492325582811915, 56.32072102638983, 51.449572655462454, 54.396437598812966, 54.91814421069238, 56.28196800908735, 53.720911318256015, 51.37629101353308, 43.24139725777411, 42.81796955293225, 47.13158438282628, 47.611866843315866, 44.87928882721932, 44.52636180385467, 44.98640875662527, 43.567271694060295, 43.56802478913338, 38.77301354562083, 28.698170415816772, 4.727380266112666, 8.503153324127197, 15.546703473214182, 8.642323920803687, 3.227881193161011, 0.18428048900058194, 0.1073008104257526, 0.06092655510010739, 0.07281406016479577, 0.06109211819186326, 0.11557544100909464, 0.0879136837958809, 0.043482422798631654, 0.08067540163474698, 0.091101061552763, 0.014968698247215681, 0.02473488573976342, 0.07560904002598218, 2.2012785125163297, 38.12114307957311, 29.988789058500725, 44.80060608156266, 55.3819291822372, 46.01972972193072, 11.494431264938848, 0.10792625226801443, 3.4173966367398543, 11.806758815242398, 8.543428221056539, 7.409933353624037, 3.3376550962848053, 0.10840196988635487, 0.1826311783083985, 1.058396677817068, 66.89088498392414, 47.344514170000636, 62.07485768102831, 29.857226879365985, 6.098275607632053, 4.096405491713555, 10.054178122551212, 24.498653411865238, 41.234708755247055, 57.44434672017252, 79.44034361070203, 44.784379236159786, 33.90959616630308, 53.9794151244625, 42.50663926524501, 0.6371233347923525, 0.31378048201722486, 0.18438594866423838, 0.42430977847787643, 0.10694718423990474, 0.07649864430629438, 0.0547589267784309, 0.10703701570990587, 0.01875344168154463, 0.15597249831884138, 0.08965078816418687, 6.419023996399296, 24.42521487512896, 17.90180140925992, 23.685708853506274, 50.15249583028978, 59.53402080843526, 57.34640121459962, 64.73136525000295, 66.93873005528604, 67.16784354179137, 63.82836503367271, 61.84910958813083, 65.65307124968498, 68.44282565578338, 72.44518080065328, 74.04717091591128, 79.13974100543608, 75.70139915712419, 75.18763142247354, 66.13826844000047, 70.51683379757789, 74.1921260279994, 74.17322804850917, 71.86041816588371, 68.79629396623181, 67.15679030264577, 65.67055717591317, 62.972448948890936, 67.46948165278282, 68.53657814764208, 64.51873748533188, 72.07951391896894, 72.44724396736392, 70.60645995601531, 69.28477025801136, 62.504015968691924, 65.59361596261301, 70.28193873743858, 69.69137883955433, 74.50000855230516, 70.49380163992606, 69.55094229790473, 57.620531743572606, 57.65170674170218, 63.196584947647594, 63.53962759817801, 62.79762498794064, 59.98113178437757, 55.65381219310146, 51.241675269219186, 50.92737966968168, 51.262856068149695, 52.5428548935921, 52.91280892587478, 54.288129191244806, 48.978981510285415, 46.8621567756899, 44.78800350619901, 48.26383929098807, 46.849287479154526, 49.65275841374552, 50.1830824728935, 53.27623221182054, 52.99752427685646, 47.654153916143606, 47.45472492710237, 46.611513399308734, 44.74650090740573, 44.11268118889102, 43.340833264012495, 48.231362065961285, 49.20758508866834, 52.32303350202499, 48.90919470017957, 49.565673951179754, 49.5673252690223, 50.263443992983916, 52.84540299446353, 53.97885422552786, 57.03459632012152, 57.19664119905042, 59.021672971787, 52.627817353894635, 50.27119067407424, 59.83228175870834, 56.815112252389234, 60.52886332235029, 63.76782325006301, 64.36207017590924, 61.87923339105422, 63.38897328222952, 63.45526526051184, 62.047663888623646, 61.63336746154293, 62.7119682681176, 58.210785696583415, 60.61595955202657, 60.009094361336004, 58.44753211544406, 53.042996314264116, 58.50701485910724, 57.62738020189347, 59.281345644304835, 55.81688081064532, 54.540219922219556, 55.02900608124272, 49.114997540750814, 50.936314828934215, 51.983540596500525, 49.91171721489199, 49.765150008663056, 49.892281870688166, 49.01625187166276, 46.10969712657314, 41.72463240162019, 31.140338105540124, 6.061688228960961, 10.439551972573804, 17.436822075997632, 9.360397131212297, 2.034309710706434, 0.5338005048613395, 0.026091773010369752, 0.051359652932132446, 0.03025152510212314, 0.053418054575881654, 0.020831102775710247, 0.04569286608227319, 0.0676874304190278, 0.031137599632324233, 0.05259423043518778, 0.04243367141292941, 0.19896973465238849, 0.13851511652671522, 4.21498094835589, 53.12205952982749, 34.96751431495913, 48.337548471266224, 66.69690808942242, 54.27826050789126, 23.985952561901463, 0.06038547869050696, 6.129424129762958, 22.51553050933346, 24.940063222762078, 18.27469918035692, 7.024277583245309, 0.14262349284704656, 0.1484219817024085, 0.7125926786853422, 98.95076197962608, 132.1737237130442, 175.6993555253552, 64.69955482790547, 5.322489132804256, 9.98981006683842, 12.649190771964289, 52.70428396040394, 54.48220022263066, 72.88494125489267, 90.63696107556744, 48.796265740548414, 47.895654247653106, 60.70605639488467, 56.4920933015885, 0.7683863719144176, 0.5361280025493714, 0.8783081606511147, 0.40661167653818286, 0.3190923824666008, 0.3769736959328575, 0.14967298796100004, 0.28232546342957404, 0.30918049175412426, 1.0470290361873567, 0.47017098855107065, 7.644752417841266, 29.427178213673255, 32.57208166583892, 47.223461981742616, 65.58546527739495, 66.9281239663401, 68.87403534304711, 71.85587606122418, 73.2037515024985, 74.90517370162472, 70.58453390675207, 69.43243180551838, 70.76573956397273, 77.61393900840514, 79.22142828664472, 80.76350027515043, 81.51710525635751, 81.55110436101114, 77.89036412392893, 67.80536205537858, 73.80865943047309, 77.1895856242026, 79.0401049583189, 74.78088948034471, 71.51652043865573, 71.92885568065029, 69.63928976366597, 68.99449917577928, 70.6111511107414, 72.66473939341884, 68.87099942853375, 75.72162289773264, 73.85928938465734, 73.40892284147202, 71.23071301367976, 67.1511342448573, 64.39633600173458, 72.50253369731288, 72.41206030691825, 76.50374351009246, 74.64834474748181, 75.54665380908598, 61.89290285110474, 60.84681064851823, 65.55680451854583, 67.1617324890629, 65.47258730857604, 63.80809422462218, 60.29848291027931, 54.0196115739884, 53.29857010995188, 53.86232845244869, 54.47763850612026, 54.688050131643976, 56.26803967260546, 52.10251785093739, 50.80768462150328, 47.70001426819832, 50.09762187157908, 47.971457973603286, 50.853399845861624, 52.57479867627544, 55.249243244048095, 56.9204318138861, 48.5071203785558, 49.334567900626894, 49.542637871157744, 47.86595013833816, 47.77431180400234, 47.56947778886365, 52.73361936692269, 49.80475810266311, 54.11461530193206, 53.09415971079181, 52.218729834402765, 52.337095199092744, 50.6468713668085, 55.14597508215136, 56.33416691134053, 61.486043237870746, 62.07577159327846, 62.120392476358724, 53.70767724129462, 53.98449459383565, 62.61627028065344, 59.990784737371634, 63.688889472715324, 65.07165047430223, 65.83619102354973, 62.21936564291678, 64.89203337700137, 68.10066161617156, 62.45760648481308, 65.2576296560226, 65.0083238078702, 59.866555429274044, 61.382480898211085, 62.275635965408824, 60.090295268643295, 58.52519112248575, 62.76410049007785, 63.349906475313254, 64.51541523779592, 60.01879438277214, 59.04740764248756, 59.51406378899852, 56.03624328490227, 59.547753026408536, 58.68096413150911, 58.0466894180544, 56.08544941871397, 57.66705105381628, 56.756527731495524, 54.866619956108835, 54.0348695939587, 47.749447899480025, 26.811922211800855, 16.765253466944543, 26.75759150135902, 17.387886585727816, 8.4077504950185, 1.9973310756106533, 0.29465387124688397, 0.19853274277862043, 0.2438057352217936, 0.24443700699315918, 0.1808563058054255, 0.21419524185119138, 0.1596425497724164, 0.1227430362374552, 0.2937540550145411, 0.14562363105435527, 0.30367893857821343, 0.37232369545005983, 6.9171091145084755, 68.44325711650234, 46.49799608415174, 63.66144072624945, 68.59835547785606, 64.1384127063136, 53.86318352914626, 0.28626680193889525, 9.222001202644842, 47.79957579028222, 50.72603656399635, 47.27229941275812, 9.084528011660423, 0.561661345343436, 0.34099330404593103, 1.357414645533408], [54.326674322928156, 76.64738855054303, 33.37105081927392, 10.196492498920811, 1.1454905785860554, 0.9294635285773586, 4.599849793218798, 9.84549920405111, 24.334055069954168, 62.823442028414824, 47.39965484988305, 45.95890160529844, 81.05571685298797, 47.535580665834495, 31.918200985077892, 0.5143446295011429, 0.27075330696759686, 0.14848604197463683, 0.4780817963182927, 0.15890298381207452, 0.1638474225276901, 0.1007171733785541, 0.03409389271250656, 0.03330170800308547, 0.06245135352195752, 0.06538535152832348, 3.9665291963085054, 30.878009988415627, 36.21031730405746, 31.971853125479917, 27.94092155271961, 24.221263393279045, 22.255553853127267, 31.741160884980236, 55.98160074603174, 72.93337468178042, 66.91519583425215, 62.903348553565245, 57.063476731700284, 57.47542758141795, 62.62628409170336, 65.50604904851606, 69.87846020729312, 71.65185005434098, 67.32681720487534, 65.60364546314364, 61.762366371770064, 67.80811555923955, 67.89524709024738, 68.66788341153052, 68.22664030136602, 69.43055691257601, 65.5068649015119, 57.95702795828543, 59.333885792763006, 61.168064532741425, 62.45001669852965, 67.32233785813855, 64.95038255568474, 66.13178083973547, 66.07778549194336, 61.628405663274954, 66.93350545821652, 68.74724864959717, 67.73558309001308, 66.6338049980902, 66.06702250819053, 58.09829996478174, 50.72971966958816, 61.311740952153365, 62.2938592972294, 60.28697075382356, 59.612185801229174, 54.91354719285042, 51.04317195953862, 49.06902736233127, 49.12457204634144, 48.400122042625185, 48.82274566158172, 53.80499516763995, 51.72511523769748, 45.85328786603866, 43.61635623439666, 41.7541011687248, 45.24266112235285, 41.49245554401029, 44.68036190156014, 46.09309765600389, 48.161332068904755, 48.02234680421891, 47.3621020778533, 43.313098184524044, 42.94760780949747, 40.368331709215724, 38.671718335920765, 44.4764849447435, 48.450249933427386, 51.86746981836135, 52.96293681667697, 50.005273588242076, 46.02923362485824, 44.490217162716775, 46.622084186923125, 48.901518621752345, 53.94940114790394, 52.62489518811626, 55.148195143668886, 57.3369247682633, 55.83998749333044, 48.606321042583836, 50.97274188072451, 55.98528385162354, 55.83524534779211, 58.12829825185961, 60.54123447787378, 59.74642107563635, 58.12452100938367, 57.800435173896055, 58.63804555708363, 57.68555679628926, 58.367441238895545, 57.858356814230646, 57.46111485265917, 58.730315393017186, 53.90257589278683, 47.61980964291481, 53.43786916425152, 53.91280543419623, 51.05021261399793, 48.69409584229993, 47.0180513781886, 46.38429833996681, 37.18155891664567, 39.4484809906252, 38.8864641804849, 40.88799084386518, 39.32551076335292, 35.62553505743704, 37.81442157683834, 31.819369023846043, 16.039365914560136, 3.6079350834892647, 3.2831140487424793, 3.8781125987729723, 2.576404925315611, 2.2429534504490514, 0.07124976224956975, 0.03501613616883274, 0.06511133719956683, 0.03519369236704323, 0.04021990713813613, 0.09492244601490037, 0.01098008445208712, 0.057500740137672236, 0.04594593939761962, 0.020868823029882005, 0.1178195883309649, 0.09087590831181697, 0.026354432000868747, 0.03925854723239618, 0.4493842958923309, 31.120681147421564, 29.908978631419522, 49.36489566679924, 43.885215097858065, 47.012203124261674, 5.512733401790743, 0.3180812383371015, 3.3523867832076166, 17.13076933737724, 13.252219884626328, 23.82439405687394, 14.08938802057697, 0.1477977579399463, 0.5081000936127479, 6.003064974661797, 87.5620738921627, 59.04821957311323, 59.36910475454023, 14.2070238244149, 3.1150022437495575, 1.8864567025053887, 8.822835318503842, 24.41501671268094, 39.735323921326675, 71.88891026281541, 64.26390893997686, 46.15968381204913, 65.66629355953586, 53.94849115802396, 39.45631004148914, 1.028752874943518, 0.21114729975740756, 0.1511559656430637, 0.3483487899986006, 0.1642387095958956, 0.1870818886785738, 0.006011317656826109, 0.08814680435123944, 0.0400807855710868, 0.05412804954234631, 0.08007596847751448, 5.292218240999407, 34.52983271691107, 36.556854786411414, 34.97877543972385, 44.1008238638601, 38.8053495653214, 39.32048620716218, 46.17531837955598, 62.64098905747937, 72.06438925958449, 67.22722822620024, 65.76472543901014, 59.3041620715972, 65.40989606611191, 67.94061322366038, 70.86262210722893, 76.6313539012786, 74.82310202813919, 72.5899790179345, 68.85716130656581, 66.60465394296955, 72.74120992229831, 72.76904306104107, 72.99698768123504, 70.7249390694403, 70.7371219511955, 70.20459744238084, 63.6371063417004, 64.16497499712052, 62.45406458454748, 68.87157993931925, 68.09458194240447, 66.64594081140334, 68.94079408337994, 69.1454476694907, 64.16753630484304, 70.98984810613817, 67.58214781361242, 70.34795222743865, 66.89982014317667, 66.60925880555185, 61.16325570691017, 55.62247245542465, 66.2604110471664, 67.255539894104, 62.04207843349826, 60.00437575001871, 58.22006994678129, 54.32969454796084, 50.24401257115026, 50.35319174489668, 51.56572580337525, 52.706025492760446, 57.87688609092467, 55.27659785362982, 48.75498279448479, 46.73622908130769, 46.80129335772607, 48.144720831225, 44.32055111854307, 46.74954160567253, 46.768349370648785, 47.87589334672498, 46.920796209766024, 48.21624132894701, 44.82416383681759, 45.01177864689981, 42.25260303866479, 40.5505964063829, 45.19841286443895, 52.74561005253946, 56.076612318715746, 58.74425157423943, 50.906261628673924, 48.74006602071947, 47.94057323086647, 48.53011331250591, 51.496888206851104, 55.3693619082051, 53.94750272074054, 57.5129803534477, 59.55590763399678, 59.52306562854398, 55.07292093769197, 53.63764332186792, 59.463979044268214, 58.55974328133368, 60.407924882827274, 63.938948415940814, 63.66211145154892, 61.23811414164882, 61.286147486779, 63.133399486541755, 61.7715564850838, 61.373247638825454, 61.58805624131234, 60.9140439956419, 61.696827488560835, 56.19658585517637, 51.66977451693628, 56.936964604162405, 56.457902000796416, 53.360374896757065, 53.93999530423073, 50.759035464256044, 51.86230797921458, 43.319777980927505, 44.87778655944332, 43.232940627682595, 45.71260813743838, 44.40467026925857, 44.087601554009225, 40.68400798305389, 33.62345533986246, 14.044165053675252, 3.1211231024034563, 4.990400681572576, 1.774671236353536, 1.002353301211711, 0.5837787327266509, 0.029288251891792304, 0.035007705371226036, 0.04677873825834644, 0.08033780966915431, 0.0318292870126184, 0.045339726362257235, 0.02166091197831256, 0.008307383714934752, 0.05487536448204229, 0.09030159517762162, 0.019902968103246346, 0.050636944736564354, 0.0690634239224657, 0.05881198005931032, 4.375972180597244, 47.90306360490861, 37.41639121886223, 50.92778367380942, 47.8477228841474, 54.781684952397505, 17.03754048193655, 0.6322148562439027, 5.739453261898411, 29.219212185951974, 26.654894044322354, 42.24660573467132, 24.838779780172533, 0.37946694440418677, 0.1940844072810104, 1.787161411296937, 101.64755621264058, 113.36136956368725, 145.10648419780117, 17.178169219724595, 1.8713505518051887, 1.4679460563967306, 20.924823091876124, 49.84866903674219, 60.3850103962806, 89.77064286508869, 66.70566281964703, 60.1629218747539, 94.40968498106926, 66.13072964452928, 50.70575006546513, 1.3097898397714862, 0.7611103752447713, 0.559785287947424, 1.7439060033329072, 1.1579233888656864, 0.2790202230455414, 0.23592475891834308, 0.13824358432283326, 0.09322163123156756, 0.19460087311604332, 0.15917466923354134, 6.54332047508609, 37.31739059571297, 55.38825596532514, 67.22222328186035, 64.71468733203027, 51.53719056037165, 47.73382509908369, 55.64623025155837, 71.32524213483258, 79.3649164322884, 74.96575078656598, 73.77442498360911, 66.26590236540764, 73.6212093599381, 75.18502696867913, 76.86375433398833, 81.58336977804862, 80.0326842646445, 74.4095822303526, 71.06110188268846, 68.77326180857997, 76.29616383583316, 75.87428154483919, 76.8895713744625, 75.50463737980013, 75.92774345028785, 73.94899399049821, 68.46099407442155, 68.51015706216135, 68.02041776718633, 71.13328918333977, 71.88494866894138, 70.67795691951629, 69.74896707842427, 74.16233954891082, 68.96359089882144, 73.24511681833576, 72.36066941292056, 72.50391437161353, 71.15112027814313, 71.06547140306043, 65.13250996989589, 55.82738491796679, 67.19912052154541, 70.15835269804924, 63.804791588937086, 63.874017500108295, 61.91621741940899, 56.8828280510441, 53.80676415658767, 52.950914752098825, 54.458497339679354, 55.481726046531435, 58.66228972711871, 58.97891913690875, 50.9098074513097, 50.230625521752145, 47.767153478437855, 48.421071421715524, 43.36368107026623, 47.30929520822341, 48.56097452102169, 50.42167632810531, 51.52208551283806, 52.174140330283876, 46.593682304505386, 46.149838662916615, 45.457767824972834, 41.638301034127515, 51.049039825316406, 54.35751199722291, 57.422440282760135, 60.72355408822337, 52.902202836928836, 51.18138843967069, 49.82730780878375, 52.57062919678227, 53.86452105737502, 57.882499002641254, 56.40074130027526, 61.253552590647054, 61.9973869477549, 59.880781865889034, 57.781070432355335, 57.0591111336985, 63.0303745115957, 60.92509331241731, 64.48808416243523, 66.60126501514067, 63.938666005288404, 62.51996432581256, 65.05523535513109, 64.2695689201355, 63.42739682043753, 64.96476980947679, 62.329890189632295, 63.90735372420281, 63.02886832144953, 58.7655500442751, 53.14728821477583, 59.610812971668864, 60.71243416878485, 56.019420239233206, 58.442319285485056, 57.147054595331994, 58.751904118445616, 53.525996977283114, 54.98427144942745, 52.68433478570754, 53.815683626359515, 53.59434427753572, 56.24114005796371, 50.598328113555915, 44.36325396260908, 22.391048208359752, 7.387443953944792, 9.483942966307364, 8.087656651773761, 2.955399775697339, 3.2681580512754382, 0.33406229209034677, 0.22539340951029332, 0.19949211468619688, 0.22838941084281092, 0.2863792023591457, 0.15413080762711265, 0.06873790550255968, 0.08295324916440634, 0.12468385104570659, 0.29384653714876025, 0.19385075046410485, 0.21819325554515087, 0.24405607743368996, 0.1514724978516179, 8.163747201042792, 69.65004490267846, 45.40073656266736, 70.35412603808989, 56.87548537408152, 69.21383027107485, 40.118327679172644, 0.5748569340475145, 7.831847513875655, 55.138604948597575, 44.769258499145515, 66.2548569710024, 26.920260037145308, 0.7238553356259101, 0.7273898814474383, 8.338269629786092], [67.7297858268984, 68.16766354345506, 11.287235982956426, 3.197523028619828, 0.9516471059572313, 4.211388057278049, 6.908873608035426, 9.660908541371747, 33.43891174562516, 64.26730571254608, 38.5784012271512, 80.978893310793, 104.3130107079783, 44.52966443953976, 27.87163680599582, 1.995225253124391, 0.48934944815212683, 0.21915144767732392, 0.10544234240848212, 0.04387401247156724, 0.08633243235489053, 0.06403407202132287, 0.1320394519115648, 0.027985952216230577, 0.00796414424492527, 0.122841470874846, 2.312843222771922, 24.6752816630948, 60.78964994799707, 65.81219396283551, 42.0484632830466, 26.780415773391727, 22.77303803351618, 27.220013449268958, 50.86382942814981, 73.98640555720176, 73.37997574960032, 63.640761990701, 59.56851413173061, 54.51991773420765, 56.04527650340911, 62.38625072663831, 67.61042025781447, 66.44293462076496, 67.49875822374898, 65.77584928081882, 61.83579314139582, 63.30344600062217, 65.65314185234809, 67.83405811555924, 66.19496237847113, 64.99725095687374, 65.15637367002427, 63.80757647175943, 63.53188876182803, 60.61161356587564, 63.1761101753481, 61.76763019254131, 65.68861969055669, 66.58599130568966, 63.10652732849122, 65.16164925790602, 65.43403040978217, 63.902450761487415, 64.55329356654998, 67.17668456415977, 62.89959484531034, 49.0363226398345, 58.97119991240963, 62.303233761941236, 62.54387117201283, 57.734649181365974, 54.583707240320024, 53.89247971196329, 51.0791479387591, 48.48983841557657, 50.89175278140653, 48.719297070657056, 57.04914046872047, 58.268656346105764, 49.41665134122295, 42.882296423758234, 43.26514720916749, 45.1708346797574, 44.43730438909223, 43.186178130488244, 46.105476656267726, 44.307407256095644, 43.494084189015055, 43.07032308270855, 45.70797581826487, 41.441958950411895, 42.679447127926736, 44.5086326906758, 41.0157738193389, 41.47862134441253, 50.208695550118726, 51.74659021439091, 58.03066261353032, 54.71342394428869, 47.92312260596983, 45.02595801507273, 44.79940191391976, 45.70053900441816, 50.39517287285098, 56.63567558411629, 56.22202634811402, 53.31201207253241, 57.426951008458296, 58.18976963720014, 50.42705389761156, 55.187771858707556, 58.10850204959993, 55.52215783826767, 58.5005743272843, 58.17464105544552, 58.11992399154171, 54.32602320947955, 58.657127887971946, 57.51538476636333, 55.74671745300294, 55.963153839111335, 55.20081373953051, 51.9492277022331, 52.54979356642693, 43.56869159206268, 49.9738161794601, 54.17654560458276, 54.26285736022457, 49.249954531269694, 43.476841449737556, 38.321713478334495, 34.138219356536865, 37.10548846952377, 33.41056477638983, 32.85878927476945, 38.20900809380316, 36.159644203801314, 23.02558375943092, 9.470492178393949, 1.4209152445677788, 0.4016285810259081, 0.1111679073543318, 0.11966530098429612, 0.3400980843411338, 0.054936448502684795, 0.13464819579835863, 0.06450031313203997, 0.0837025827457828, 0.058194838779708075, 0.05476358459301053, 0.039630781693924824, 0.03741481874678885, 0.011631850033037124, 0.07149305645256274, 0.06896193259425702, 0.017367054280194066, 0.06865533654608073, 0.03586689596094432, 0.02624081733125833, 0.729305652841445, 23.864859188756636, 27.83129915114372, 49.782941879764685, 48.821631708452784, 41.46414779847668, 1.6948619124389466, 0.39551774280205854, 2.064313758765498, 16.80244145854827, 15.314905124325907, 41.75509745074857, 37.37420612765897, 0.17520839919246015, 0.5796948712198966, 13.812620678255636, 83.96018489714592, 78.15153906422277, 32.42719715641391, 5.775505237040981, 1.6434467487758206, 4.236187242692517, 2.433072203590024, 21.71485120250333, 45.78852561212356, 85.09826844738376, 46.928268324944284, 76.48996814604729, 104.02346134185792, 52.01737103923675, 35.67441563452444, 4.306968863933317, 0.4777014796291629, 0.4047726977977061, 0.14673635844261418, 0.1325380832197205, 0.10025340673183242, 0.05283642530200943, 0.08965349245455959, 0.018226673879149943, 0.10022755126438795, 0.16657271903128396, 2.629434144304645, 29.065243467207882, 65.07278796165221, 68.66110555587277, 54.42148193236321, 39.34375370702436, 32.9916242630251, 40.044645955485684, 58.81266947715514, 72.57468961900281, 70.39935881091704, 66.14590137235581, 65.68183006778841, 57.78795811437792, 62.682405364128854, 70.5698642423076, 72.5861821636077, 73.10027937735282, 71.55677964610439, 70.75982462975287, 65.21211447254305, 66.76795790272375, 67.6426072274485, 70.13733663866597, 70.64992766226493, 68.67198621073078, 64.46361641730032, 67.29338292152651, 65.99310151992306, 63.29522079037082, 64.55369364830756, 64.93953720215829, 66.43957707189745, 69.01431498988983, 64.95836850135558, 68.6317034690611, 68.04687023162842, 67.73111158801665, 68.69624214787638, 69.77891829706007, 63.45142918248331, 54.42483163649037, 63.75476960212954, 65.42822922429731, 67.06306134500812, 62.0507586386896, 58.48311585764731, 55.625402465943374, 55.15197238614483, 49.95090953765377, 54.35973598111061, 52.472154171236106, 63.405623743611, 63.14280533021497, 53.27753836108793, 46.109544154136415, 44.25430228633266, 47.748573210931596, 46.115604216052645, 43.87190257349322, 45.784968022377264, 44.85117327782416, 45.273455650575706, 42.89809965318249, 45.92704019238872, 42.724268051885794, 41.62771847940261, 46.45771726485222, 44.19891057475921, 43.64544060922439, 51.22281259106052, 56.29005985875284, 60.976519507746545, 60.18748375677294, 49.46340599367696, 47.05482359855406, 47.68030043571226, 49.69450419948947, 53.44296824547553, 58.25338263665476, 58.73795617011286, 55.47565421750469, 58.85094788766677, 62.32128843184441, 52.44184209454445, 56.0949807782327, 63.704684857399236, 58.43001088788433, 62.072967098605254, 62.2337293624878, 63.06803710999028, 58.142838478088386, 60.145494784078295, 60.18774263320431, 60.30475870255501, 59.53661741748933, 59.95998628677861, 54.4228155382218, 57.23113059997559, 47.328204954824145, 51.1195993423462, 56.433869638750636, 56.982162075658, 53.23935016509026, 48.049246418860655, 44.16397010126422, 39.59130233333957, 46.0755568165933, 42.266299955306515, 40.03074899796517, 41.910356629279356, 38.14761907823625, 24.083499946901878, 9.891414469288243, 1.26517005985783, 0.3581359615970043, 0.23198245513823726, 0.15023704317788925, 0.18512957489057896, 0.08311760566768148, 0.09204436093568803, 0.04223420510008451, 0.13954570396773278, 0.1100178485015227, 0.024579678241524006, 0.02191018166711494, 0.07422170842126494, 0.0325309316207084, 0.07258739006975967, 0.08775946263584398, 0.08051905841115983, 0.07297176702488815, 0.10342190808226025, 0.03260954756349806, 5.751188503157708, 43.74326452132195, 36.2171265386766, 54.335480043965006, 57.00874397831579, 53.753357164321415, 7.423923957732416, 0.8183066222456195, 2.690496377406582, 25.811156918925626, 27.078378623531712, 61.48536074546076, 53.49925817981843, 0.2758061164809812, 0.7889497652649881, 14.644478905585505, 106.99253866749426, 114.52479162523824, 57.05711856965096, 5.12696486326956, 4.330624188146284, 4.828338151977909, 20.818462141098518, 46.65925256667599, 61.319244446293006, 99.08449911302137, 52.61342225536224, 89.71883619985273, 122.10008082851287, 59.80195007016582, 46.42748363556401, 4.434637110079489, 0.6045175295683646, 0.8010143017576588, 0.34275328379965603, 0.18319253689579426, 0.3203773570637549, 0.3557368500098106, 0.29091278812096966, 0.21335436842374264, 0.19243479015365725, 0.19029214948175416, 2.0334107524925664, 33.46635656972086, 67.55685637074133, 79.66864124421151, 73.78958102195494, 59.85214071889078, 48.18803164266771, 53.90506659784625, 69.8306308254119, 80.97388052171277, 77.56257949336883, 75.39420696996874, 74.39334361783921, 66.48007946629679, 71.84253215789795, 79.22275404776298, 78.66610696238857, 75.64245377817463, 78.08439593161307, 74.5378751139487, 70.31356873050814, 68.55451906881025, 72.99956860080843, 75.59624041280439, 73.59460000068911, 71.76315123035063, 70.1958191779352, 71.45078935930806, 69.47742139139484, 65.51039111229682, 70.1718064277403, 67.4178397270941, 67.60445041041221, 71.81618951982068, 69.3840846707744, 67.75270815818541, 69.97806487544891, 69.45392639406266, 73.54450348884829, 73.47011181616014, 70.53636720103603, 56.15993130591608, 65.63270630375033, 69.06725914247575, 69.92475986480713, 64.47116305751186, 60.994056424786976, 59.79842385938091, 56.765811981693396, 53.53379464918568, 56.97323083877564, 54.13988321058212, 64.19203150656917, 64.92766418764668, 54.52327920544533, 50.297603914814616, 48.33650119843022, 51.68713884968912, 47.476050853729255, 43.95100109038815, 47.81439058242306, 45.672113587779386, 45.504651915642526, 44.89941450857347, 47.60859950896233, 43.75131322491554, 45.88657309932094, 48.320858786183024, 46.07958116839009, 45.68354729683169, 54.53518752128848, 57.71997951692151, 63.18036594698506, 62.859472920817716, 52.93986151295324, 50.49217700958253, 50.39387064595377, 52.67739219050254, 57.136605401192945, 61.002905291895715, 61.20084378027148, 57.292135223265625, 63.56315397447156, 63.645425688835886, 56.09135258582331, 60.89539704784271, 64.8850711699455, 60.276172468739176, 66.13630725491431, 63.93331981474354, 63.318617728448686, 61.27156019210816, 64.25238109404042, 64.41226474700436, 61.68408370787098, 61.634622619998076, 61.34882696213261, 55.99394052259384, 59.81512531157463, 48.55564794232769, 56.580005384260616, 60.135382913774066, 61.930283038846916, 57.46725336197884, 55.20630898014192, 51.436107158660896, 47.38081178357525, 55.898595548445186, 51.21466975058279, 48.461985664982954, 53.84332456896382, 50.821393305255526, 33.13291980374244, 12.982531439873481, 1.8515302024541365, 0.725890126439833, 0.3275490125581142, 0.3398161946285156, 0.6727633997797967, 0.3066907366437297, 0.21456731543425592, 0.2519852713110947, 0.2548101745666035, 0.4263237623437759, 0.0854327310357363, 0.1233452273112151, 0.21091692179681795, 0.11170515715475045, 0.1824140996341744, 0.17424631533363175, 0.15662993965370042, 0.18698741471575153, 0.18778975392060895, 0.1721268258388004, 13.262952470010328, 69.11698695152037, 45.00778959643456, 71.56739357979068, 61.65572889389531, 66.6026770684027, 32.00612679604561, 1.1178405655007209, 3.965629992946502, 50.72906855613955, 47.28423518519248, 78.53730417067005, 60.60443955083048, 0.4121458344161511, 1.3750502346984803, 30.135493547685687], [59.73479909281577, 47.3547907798521, 7.988008837546072, 0.7130855490123073, 5.492916116791387, 4.897267433904833, 5.849121751323824, 8.419593111161264, 34.08465546946372, 54.72580294455252, 43.70797887925179, 85.40886525184878, 85.86061246933477, 38.015925499700735, 36.01212386162051, 7.8332914363953385, 0.31037224877265196, 0.08189410962645086, 0.05283562090968894, 0.051366957580490466, 0.08944509355651756, 0.0077095325292658905, 0.159952279120203, 0.07731088136713352, 0.02251576076471998, 0.1258221887532742, 3.310186737968076, 24.335769145719468, 56.99103055461761, 76.65651198356383, 63.640573716932735, 34.55363758148686, 23.721900563086233, 27.774197286175145, 44.76425747717581, 68.91031726714104, 78.42716401623142, 73.59802815221971, 66.69901832457512, 56.42261243635609, 54.23991149471652, 57.94264462686355, 63.22458282593758, 69.35784401432161, 65.86823678785755, 64.54838275909424, 63.633784094164454, 60.54570597987021, 63.709034765920336, 64.09917723747992, 66.73013056478193, 64.94502852039953, 63.01544597071987, 61.390592359727435, 64.46749564140075, 63.29360085148966, 60.06248958649174, 62.543627985062145, 67.88713562873103, 63.676126080174605, 63.34633319608627, 68.22460851361676, 64.6641162133986, 64.7205787320291, 64.2586882652775, 65.45304998274773, 51.85685980704523, 57.653514954351614, 65.1858385147587, 61.345920485834924, 59.91956233978272, 54.17396860737955, 58.28837802333217, 52.50747511463781, 49.59978680456839, 48.907013862363755, 49.271296147377264, 55.675730397624356, 66.30188618936847, 60.848207012299575, 49.966963798769065, 42.769265482502604, 43.795451656464614, 44.897570994592485, 44.16507228728264, 43.3137139966411, 43.64490324451078, 46.1202992931489, 46.70294777039559, 43.45105971059492, 44.5944502276759, 42.46874132464009, 40.881373805384484, 45.34979674123949, 40.88257012828704, 41.24087079878777, 43.74828515514251, 56.499890973491055, 60.953444204022816, 58.31082967019851, 50.882527366761245, 46.926695454505186, 46.371546714536606, 45.0390822656693, 46.94435788739113, 50.31642736927156, 58.816474176222286, 56.843635728282315, 56.06357828263314, 58.46852071823613, 59.74757817483718, 50.3966006155937, 59.12181892702657, 54.77476981378371, 57.69577457058815, 54.70409262564875, 60.034158306737105, 56.51092067841561, 50.934965533594934, 57.392740095815356, 57.58303780709544, 54.66041311140984, 57.061441021580855, 46.43207673103579, 50.96130032693186, 44.44229756632159, 49.317842914212136, 49.823236388544885, 48.119323484359256, 47.33060152299943, 41.64173310802829, 32.74447571846747, 28.61598107122606, 33.293344743790165, 36.858359536817, 37.72125744050549, 30.689345944312315, 17.778284011348603, 6.836476950876175, 1.0777058933050403, 0.3487394641964667, 0.08481057571066965, 0.05497551132594386, 0.06309211712270495, 0.09606747933092619, 0.09954337346097154, 0.1682637508718237, 0.0383809398889782, 0.059766449004171364, 0.023306112608782226, 0.03567867198838823, 0.134517899564197, 0.05023729581866534, 0.031579050137811614, 0.035582462836417465, 0.017453032327936064, 0.0406885958997713, 0.07015704507789305, 0.09677869237719045, 0.024218234128408858, 3.0585662011177313, 24.55863037417012, 28.245523014376243, 36.71345149317096, 51.969031749233125, 47.214283635539395, 15.550176732001768, 0.44342946381338183, 0.294787997920667, 7.301028745789682, 22.352634476077174, 44.35674282812303, 63.16118163447227, 1.6907772542007509, 0.055139450311300256, 13.556385963193833, 87.42926243812808, 81.19972275149438, 8.626239261319562, 1.3687402442578347, 11.01860853933519, 8.11521130223428, 4.05930134077226, 18.97400679126863, 48.08908593270087, 74.67945698768862, 49.109667039686634, 91.82449786893784, 92.45517576894453, 41.1551905447437, 44.044977157346665, 12.749261221578045, 0.5499652052117933, 0.27150686169343613, 0.0813264537963175, 0.0742778473443562, 0.03457943157803628, 0.05448578195946832, 0.05247390866580029, 0.060829756060434934, 0.04041163213250618, 0.10636468928667808, 3.2373885281624335, 28.12926200128371, 66.04189580486667, 85.77574806828653, 69.46245362681728, 44.392448163801625, 34.54590658987723, 41.07076544915476, 58.675049197289255, 74.39256698854508, 75.39464627542804, 70.53941096028974, 66.01867537344656, 61.00350541453208, 59.76369127150505, 62.608433385049146, 69.57577874583583, 72.99780353423088, 68.55925729197841, 70.54816569051435, 68.21602636767973, 64.42154899720224, 67.37274815959316, 68.41259987123551, 69.8534276408534, 68.35721600440242, 65.57381583798316, 67.5144398596979, 68.75885102056688, 65.66187304835167, 62.81520112868279, 65.44596225984635, 67.94654384736093, 65.47266575597948, 68.3367176978819, 70.68139291578724, 65.2052071786696, 66.3469934463501, 67.19989715083953, 66.99502391199913, 54.24676387540756, 62.35680549375473, 69.49089081056657, 65.37544588888845, 62.85284803759668, 57.23038927201302, 59.95406350781841, 54.181397576485914, 49.70085843916863, 51.08258785740022, 50.77826684521091, 59.60391744490593, 66.81802303560319, 63.19514151542418, 52.69636077265586, 46.880505623355994, 47.35070759250272, 46.837461533085, 45.323395267609634, 42.775043133766424, 44.56338505591116, 44.04639313297887, 43.07071139735561, 42.84069576571065, 43.988228305693596, 43.51126024799962, 42.19130031524166, 47.8783409057125, 43.76623392105103, 43.51684178075483, 47.96300134351177, 59.23567748838856, 62.41435058655278, 59.05780584581437, 55.784521256723714, 47.56637519405734, 50.3022676129495, 49.17112273554648, 49.66558456420899, 53.83737041104225, 59.294536575194336, 59.693053307071814, 59.04196339268839, 58.61847292992377, 61.68938675234395, 53.117929274036044, 59.32739034775765, 57.87637226043209, 58.588388350702104, 58.63670410648469, 61.826936429546734, 58.788774398065385, 56.829676012839045, 61.85048241769115, 61.57461035636164, 59.40874030513149, 60.354102119322754, 50.781749909923924, 54.43595155592888, 47.615808825339045, 51.41036072084981, 53.739417060729004, 52.68877883111277, 50.36883807951405, 44.257004799381384, 38.0389537349824, 35.680385481926706, 39.76753050281156, 44.02902487785586, 41.14578862344065, 33.18195727563674, 18.63102689866097, 6.664642816589725, 0.8355225790892878, 0.29613876414875834, 0.2078434689751556, 0.0914115799711116, 0.011106194973352456, 0.17312620285778277, 0.15433161459382505, 0.049862678823692184, 0.053198616350850755, 0.026495735003282467, 0.056783199205153415, 0.0323407732761435, 0.05969491937468129, 0.05332947949007635, 0.0514800398189935, 0.05569445802980373, 0.038007246029953805, 0.09580157787328768, 0.05983475340350021, 0.13737041262849686, 0.12423834027422052, 8.51005571503793, 41.3501048857166, 38.82294531791441, 42.137524620179214, 53.38582715680523, 56.4167171139871, 26.062027792776785, 0.5410692083739466, 0.4647423056585174, 19.572815433625255, 36.28479919125957, 58.45708700918383, 80.02261946278234, 2.681865937286808, 0.5968790813799828, 29.77911876093957, 100.36169344379057, 103.79905469955938, 12.062965093120454, 0.7721181394111726, 13.253343643680697, 13.623833079491893, 26.067746608488022, 46.271377225076, 61.30393935788063, 89.71579244059902, 55.31711985988002, 96.49603289942588, 94.3951722114317, 50.28008660962505, 57.18774918586978, 12.61039755036754, 0.5842146061120496, 0.27645627998055955, 0.18437836439378802, 0.18694514198408974, 0.16210397495137108, 0.12460191028132556, 0.21543130939525945, 0.17296236729429615, 0.12290595249543268, 0.2782358409416291, 3.412601294056062, 34.04300774297407, 62.12422855438725, 78.963807013727, 78.22775071667087, 62.816950505779644, 49.31540712233513, 58.918683298172496, 70.16893525277415, 82.1509288972424, 82.89803843344413, 81.50980180309665, 77.57852000574913, 72.7603667782199, 67.67948535180861, 69.96392865334788, 77.71101767016997, 76.54587761048349, 76.38651171038228, 73.5650331743302, 73.56819460468908, 67.29375946906306, 72.0958858920682, 70.45777074752316, 73.38262727183681, 70.64143180847168, 69.49774711362778, 70.59204132326188, 72.60703348344373, 68.73919210126324, 65.7989324292829, 66.65422485720727, 73.33410755280526, 69.19821923778903, 69.72923755645752, 73.73361664433634, 68.24954694317233, 70.27463528417772, 70.13901541309973, 72.12405635464576, 57.22441550224059, 64.26432471121511, 75.25864201207315, 69.31206995441069, 66.82820550857052, 59.549106244117986, 63.27430671261203, 58.070886519647416, 54.370444051681034, 54.86129337741483, 55.211055048050426, 60.75183829953594, 72.65137195587158, 67.02124103423088, 54.849643938003055, 49.70398456819596, 49.44008358063237, 47.20985527961485, 46.494469873366825, 43.76096225553944, 44.33421273385325, 44.968436456495716, 46.1342276296308, 44.843108884749874, 44.99643433478571, 44.522678698262865, 43.42044168902982, 50.048635390497026, 46.02458169383388, 46.12220948742282, 50.570036057502996, 61.865697291589555, 66.3062321755194, 62.06498899767476, 55.522106847455426, 52.367560248221125, 52.558854241524976, 51.11583778935095, 52.28406083199286, 56.45218710745535, 64.28570162865424, 62.34852929269115, 62.72155061844857, 63.93793644443635, 63.790121924492624, 55.3904015018094, 62.61822754336942, 60.12935030844904, 63.29561694975823, 59.34874765334591, 64.40041918908396, 59.517841031474454, 60.34273901293355, 63.53096308246736, 63.83571163300545, 61.21287368958997, 63.716432356065326, 52.992044725725734, 56.09844423109486, 51.01514270228725, 55.5576317541061, 58.048744740024695, 57.6719500941615, 57.30518887119909, 53.42827112443986, 46.20134722801947, 44.998332761949115, 50.29469743851693, 55.80581188201905, 53.853942425020286, 43.04460802385884, 24.092772429989232, 7.368613145043773, 0.920763282525924, 0.3408909240557302, 0.5792790386945971, 0.21322748894172333, 0.3567754507305161, 0.304172360488484, 0.3532511398436562, 0.3713647678734795, 0.1907264294042703, 0.30279839711804546, 0.16845867428327763, 0.1955225075324697, 0.2571264720491825, 0.18469197014647146, 0.16081742221309295, 0.13015349665957113, 0.13930141385043823, 0.14682569961634376, 0.2216582099396375, 0.1920091670246855, 0.4014770181909685, 19.61439844100706, 61.88841958199779, 47.4942075052569, 55.45490095692297, 63.41798313202397, 67.93952280475249, 41.830454026499105, 0.6724594160914422, 1.2917225447393235, 43.06496512505316, 58.47153309852847, 70.35030564954205, 93.12151585855793, 2.280238030418273, 0.7659546249816496, 44.8377077810226], [75.54279419683641, 29.767555613671583, 2.1255944188564055, 1.1442278205387055, 8.923921661992228, 4.6078514283703225, 5.426037253872042, 18.620246264242358, 45.684771076325454, 59.120038170968336, 45.41716737131919, 74.96362486193257, 83.912794820724, 52.7998132859507, 36.15516093469436, 23.277839229952907, 0.5539763190092579, 0.04602631351219551, 0.05047408976562081, 0.07247249986375533, 0.13233891568116604, 0.0909425656221086, 0.021625528292309855, 0.03346749709077901, 0.021365089041571465, 0.03622580049259048, 0.2951555362632198, 16.599903991145474, 43.81603625512893, 67.3805928999378, 77.95763277238416, 54.283226228529415, 36.520004118642504, 31.400783484981908, 34.75016401660058, 48.19896721070813, 60.5367394416563, 70.51480200982863, 72.35947701238817, 57.32004680941182, 49.85311700451759, 57.01992273330689, 63.50212581696049, 65.54301738739014, 66.74579651125016, 65.27201298744448, 64.8105618261522, 57.58641104544363, 59.73900779601067, 62.89372305716238, 67.54354384637648, 62.418598513449396, 66.61240454643004, 63.70922303968861, 61.99200153350831, 60.81124259579567, 60.76258951617826, 61.16566404219597, 62.475688611307454, 62.402269686422045, 65.0401734536694, 61.90343049264724, 65.44575829659739, 59.91924462779876, 64.53632539318454, 54.77915110126619, 54.90323135929724, 64.42004672942623, 66.9159803082866, 63.347305943889005, 53.780029281493164, 58.27493606075164, 52.4717580118487, 47.77456283569337, 49.07623275633782, 47.1519846300925, 52.868584202181914, 61.35215313203874, 63.782132056451616, 56.47624692609234, 47.83821898121988, 42.438158604406546, 44.6164115782707, 45.72546174449306, 44.15167739314418, 41.26220064778482, 41.759368911866225, 43.29089364697857, 37.181625596938595, 41.37184266121157, 42.6626633059594, 39.57521277089273, 39.78187853290189, 45.318331487717174, 44.21706330391669, 39.167266661121005, 45.671148684717, 49.79235164580807, 58.49519675777805, 61.43475824786771, 60.363123570719075, 48.10944303389519, 42.13988588702294, 47.83330032902379, 47.14185314793741, 48.07343567571333, 52.628809713548236, 57.33416341966199, 60.06052055666524, 57.487320207780414, 60.34689280294604, 53.92594537427349, 54.432076254198634, 57.891661659363784, 56.52267209945187, 58.388088595482614, 54.93938776754565, 58.23533188912177, 48.758807105402795, 53.412036434296645, 57.49651424346432, 55.24770175257037, 52.668284446962424, 46.52746092888617, 48.00908527066631, 44.51643820731871, 44.699656040437766, 48.74953854468561, 45.01619131334367, 37.99033203432637, 36.68475935536046, 33.11736760600921, 31.047938831390876, 31.982267018287416, 34.28291951456378, 23.554534989018595, 11.876997678510605, 5.212092553415607, 2.3579566084569503, 0.3823258006764997, 0.20723539434613722, 1.6494885471559342, 0.9246360102007467, 0.8665281798570388, 1.5381151750203104, 0.8782919808741539, 1.4204130586116546, 0.20022775827636644, 0.12058636083477929, 0.08428286370490828, 0.06792558417204889, 0.14071950388531532, 0.057693384437551426, 0.042240341464358, 0.10998272337019445, 0.004704981655513327, 0.05634248414407334, 0.026019452395097866, 0.028573369284370737, 0.02883701844351186, 4.4609978891188105, 26.16491940713698, 28.429084054885376, 31.707393200166766, 53.64867694916264, 49.57398153120472, 35.76500277365408, 0.22975755194502495, 0.09518607219140376, 3.5510187956594654, 27.56950055399249, 39.5759815554465, 82.4785017198132, 6.445617175871327, 0.2900996317546214, 10.205090334338527, 91.62569645912417, 57.94926951008459, 1.8546808462950493, 0.9467506396674341, 15.267740584188893, 7.0596225511643205, 6.532185356463156, 23.1153570067498, 59.7247499804343, 79.99968928675499, 48.265753407632154, 84.39741934499433, 91.78492115389918, 56.26099901814615, 43.843481079224624, 32.68854664218041, 0.43663098506869813, 0.08589079798830133, 0.10441202309823806, 0.13980893177851555, 0.07511531934142113, 0.08839745299830552, 0.0631532088042267, 0.016355869931078727, 0.023288670701966174, 0.054658270486059694, 1.2032908705934402, 23.97940024252861, 54.40021484128891, 75.93333675015357, 85.7280912706929, 61.97483724163425, 42.56962860784223, 45.183817725027765, 51.03529976260278, 61.60125501694218, 72.70831692603328, 74.60201371100642, 70.04792228821786, 58.93002287034066, 57.43010067170667, 62.14778238727201, 68.40400988055815, 70.53006787453928, 68.9736557006836, 70.10658525651502, 68.46990569945305, 64.65412985893988, 64.32971846672797, 68.01379680633545, 70.51893618799025, 67.28426733324605, 69.87648333272627, 68.04095529740857, 63.35348759928058, 64.05446221751552, 61.6407258279862, 62.750168231225786, 63.99878417291949, 65.57460815675798, 66.59826832432901, 66.20143428925546, 69.14958184765231, 64.51691358320176, 64.2633362739317, 56.10024459900395, 59.889411080268125, 67.68984040906354, 70.04271338062902, 64.07260710193266, 56.86142367701377, 60.72419735693163, 52.74360572138141, 51.893530045786214, 50.667593248428844, 50.0171426803835, 56.64514810808244, 63.470354618564734, 65.12167246110978, 58.870551893788004, 51.3055589122157, 47.18007664526663, 45.35408389183783, 46.86487105584914, 45.30011992300711, 41.32585679331134, 42.938115673680464, 43.5070986132468, 38.689863220337905, 39.77233148390248, 42.62875049344955, 39.62492489045666, 38.74740831313595, 46.26999262840518, 48.72441576373193, 43.01010685582315, 48.00129544350409, 51.92184563606016, 59.504646178214784, 64.14991309565883, 61.750383530893636, 51.33913440089072, 46.78834561378726, 50.786488133092085, 48.81597172829413, 50.16793820165819, 53.98607530901509, 60.047761086494695, 60.501202767895116, 61.301970328054125, 61.3143140269864, 58.5524162938518, 55.36881277638098, 60.48209690278577, 60.24052596861317, 61.527349718155406, 57.772994272170536, 61.50990301562894, 53.63563506833969, 53.82120632356214, 61.81709128041422, 57.38167508955925, 54.7950602346851, 52.27585915596255, 52.13422236904022, 48.68765923284715, 49.83066143528108, 51.47648403721472, 47.06706531586186, 42.41804076779274, 40.32801366621449, 38.892928246528875, 35.71799316713887, 39.435564625647764, 39.877199972829516, 24.895340358057332, 12.286126382889288, 4.112356300315549, 1.89276693809417, 0.6138919329931659, 0.3991291425641506, 0.653576942220811, 0.8715739413615197, 0.8262454381873532, 0.9266239164337036, 0.9558484547080534, 1.647036698076033, 0.0721687613235366, 0.08606237103982319, 0.1049105931193598, 0.03917791264792604, 0.07960113186028697, 0.029279752146272413, 0.07640177248826913, 0.09762200962511763, 0.040057711002807465, 0.0930240877994126, 0.02086157009245888, 0.10484798841418759, 0.050220100975204865, 13.831634367665938, 49.41501963523127, 38.78575340394051, 42.46601527737033, 55.84674573713734, 57.365675741626376, 42.172076779027144, 0.2004205059981154, 0.02578007673183757, 12.382746127343948, 41.9068931764172, 54.27999419550742, 96.51287555694581, 8.435361039253975, 0.1396209491236556, 32.34238178499284, 109.28019831257483, 74.77149148141184, 1.9828893989324572, 0.9449659612390303, 21.133969753019272, 14.250371898374251, 30.914631197529456, 50.795921433356504, 75.94401344176262, 95.57881016885081, 56.35343751599712, 88.91469540134554, 98.532268616461, 65.23247157373737, 56.78044634480631, 34.63732527148339, 0.6858201120649615, 0.13327193416414723, 0.2172017692317886, 0.19239870741242365, 0.2276284097423477, 0.2079637754227846, 0.3800358106532405, 0.1706138634753804, 0.12776149436831474, 0.1122273916318532, 1.6932276323918374, 25.31586354778659, 62.93408816860568, 76.18683168965002, 85.75481045630671, 73.42351405851304, 61.12640503914126, 61.30532787692163, 62.648386647624356, 68.35054797510948, 82.87641832905432, 85.94848140593498, 81.48625973732241, 71.26297843071723, 70.72554311444684, 71.67460764608076, 75.69096565246582, 73.97475611778998, 76.29934880041307, 79.2024753939721, 76.21055418445219, 67.5368836618239, 67.78453426976358, 72.2264615951046, 75.66491326978131, 69.63533601453229, 74.31409605087774, 71.04604782596712, 68.04541895466467, 65.72414067483717, 63.89764585802632, 67.7488407011955, 69.19790544817525, 69.38307269926995, 70.72218556557932, 68.61557468291252, 70.88854897406794, 64.85082887834119, 69.00585051505797, 59.703894738228094, 62.58462852047336, 70.17277133080268, 72.90488258484872, 70.09342178221672, 59.753469574836, 64.87544959591281, 57.692252282173406, 53.52591460750949, 53.95853634803526, 52.82997239020563, 57.02835582917737, 64.86592215876426, 68.86831652733588, 59.54519171868602, 53.005090528918856, 47.61505180789579, 47.51200722109887, 48.63218515150009, 47.02362114383329, 41.998178497437515, 43.394067671991166, 43.432883447216405, 38.2376649302821, 42.163447564648045, 44.29883687726913, 40.87015190432149, 40.83865134946762, 47.834112259649466, 52.057669470387125, 45.70477124183409, 48.24957363067135, 53.09821544154998, 61.63193579643004, 66.35330846232753, 66.19136948739329, 53.57812135450302, 46.933508611494496, 51.66353402599212, 53.13956899027671, 55.5703402334644, 58.73014280872961, 62.51835615404191, 65.46999462189214, 65.02319743556362, 64.51901989598429, 59.01194157138948, 59.044108929172644, 61.822731648722005, 62.803900780216345, 64.25305966408023, 62.170449764497825, 61.694489755938136, 53.657247327989154, 58.12759222522859, 63.66217813184185, 60.364355194953184, 59.842381861902055, 54.50127078640846, 52.94930658032818, 52.743468438425374, 53.921654301304976, 55.571007036393695, 55.53161467275312, 50.69741502884896, 51.51097343813989, 46.37412371173982, 43.97942258465675, 52.017539701154156, 51.48117519194081, 30.192554227767456, 13.131066695336374, 5.010256699977383, 2.6384783944775982, 1.0416655626989182, 0.6560252366527435, 2.4034227623093516, 1.5180332526083917, 3.070434802962888, 3.3078862678620125, 2.481456845998764, 2.4777945779985, 0.3308094214768179, 0.2205327195265601, 0.25458975574902953, 0.13188908417378703, 0.26392341861801766, 0.16460466979732438, 0.1428616236174299, 0.2783978838593729, 0.12323526305056388, 0.18984421787242736, 0.10223153768287552, 0.22905766933916077, 0.24991341716339513, 26.29616583547285, 68.62903625734391, 50.56889072541268, 53.884529067624, 70.94248940867763, 74.33689286631923, 51.321781835248395, 0.2290354068240812, 0.12516752831758032, 27.5580648837551, 64.70710539048719, 64.99512110987018, 114.83943631572109, 9.641850725297006, 0.5467946430848492, 52.31408657566194], [78.95633882091892, 15.15347605751407, 1.37823814105603, 3.2914299638040605, 7.479746149432275, 3.3348148099837767, 6.245757706703679, 27.020739393849528, 46.24908639538673, 54.55241849345546, 55.259390415683875, 47.10641845580071, 113.12492908970003, 80.89244427219515, 38.59174905284759, 38.554333563773866, 0.4808025422596163, 0.13624481496311006, 0.048258785654099724, 0.10720367047695384, 0.09413418750609122, 0.04283664515241981, 0.05955430010573999, 0.005102711523162021, 0.04672082584171046, 0.11868516043309243, 0.3196129238893909, 3.8963964821830874, 46.61727928346204, 67.00256270747032, 76.27226091200306, 66.53811485536637, 53.33053742685626, 48.641689054427616, 43.31319232140818, 34.70167959890058, 32.380734720537745, 36.50185923422537, 54.561753734465576, 66.15118088260775, 57.36550315733879, 50.864256966498594, 59.9858739299159, 66.27541019070533, 63.997497635502974, 61.75089343901604, 58.98956837192659, 58.15269539433142, 55.88285507694368, 60.31315257472377, 60.280738107619754, 63.48816610151722, 62.93220543092298, 61.60760141188099, 59.65358641839797, 61.92763936135077, 57.60172790096652, 58.6659610656, 59.19622236682523, 65.88168267280825, 64.04095357464206, 63.79165557123, 61.52427850231048, 65.24887884816816, 58.072102454400834, 54.39445680187595, 66.5439199632214, 64.48089445790937, 65.25082434377363, 58.446312258320475, 62.041337105535696, 52.557324517157774, 49.736626532769975, 47.54596317968061, 48.83768989193825, 53.1528030672381, 59.1915939700219, 61.62265939097251, 59.462747420034106, 55.538902436533284, 47.52902638527655, 42.61030358652915, 48.67700215308897, 43.59124129818332, 41.338255405426025, 40.845142872102805, 41.372356491704146, 39.55097644559799, 38.915607390865205, 39.84375, 41.28126728919245, 41.144729583494126, 39.07726003277687, 43.77449051026375, 45.482243414848085, 42.721432178251206, 43.84884688162035, 48.64091242513349, 53.87671570624075, 60.091009140014656, 61.647731181113954, 56.45134772023847, 48.33315149430306, 49.53375762508762, 46.8088831440095, 42.983399437319854, 50.61411957586966, 55.077918037291504, 61.100493861782944, 58.907100539053644, 57.82946463554137, 58.83723135917418, 51.89092951436197, 56.38240814208985, 58.791304326826534, 56.316441720531834, 54.55356774791595, 55.768239498138435, 54.08653113149828, 47.36291793084914, 55.284171950432565, 50.568023881604596, 47.341062484248994, 50.054679762932565, 46.85601826637022, 42.4961979158463, 40.88535108873921, 42.71348545628209, 37.055792039440526, 34.8393234129875, 32.645769273081136, 36.16837539980489, 32.20429866544662, 34.449388827047045, 19.912161250268262, 7.996644425776697, 4.90750874242475, 2.569572401623572, 1.1876734634560924, 2.4250906705856323, 6.8355684318850125, 9.796648044740001, 12.150620260546285, 4.426163809914743, 2.6284219276520515, 2.6463888345226168, 1.3010159879922867, 1.8951725767504786, 0.0658845114371469, 0.08865438356635072, 0.02999853797166819, 0.08193140278660482, 0.13634774653661635, 0.1013307638406273, 0.06344862762958774, 0.022987877769816308, 0.0888926292499227, 0.02839788918443505, 0.1111906371830452, 0.2377761329614347, 9.131340519074472, 35.42700429116526, 32.25035513600996, 26.92447070152529, 41.238984138734885, 35.08693087485529, 22.65968938027659, 0.43444156706813847, 0.07848199231610184, 1.0673395592358805, 29.507704473310906, 39.92736316496327, 82.15130544477894, 9.122794655061538, 0.24208868703534528, 19.343178310701926, 98.2764437890822, 33.219886595203036, 1.0762184569912574, 2.066238416779426, 14.526545982207022, 7.697284721559094, 11.458876940511889, 31.462629456673902, 60.620062351226814, 79.78866577148438, 55.11178378135928, 58.99295729975547, 136.1322424488683, 77.22484773205173, 46.33158560722105, 52.22781796609202, 0.31446208576521567, 0.14613258922773023, 0.12198214238930134, 0.11231824199879363, 0.12795612666635744, 0.024585774386181466, 0.055457395952074766, 0.06551097462614698, 0.061341801568144755, 0.06993368448268983, 0.889936639897285, 8.295091198336694, 53.38528586972145, 71.24328028771185, 81.32203009820755, 71.83242813233407, 58.79973350032684, 56.027139463732325, 52.31296085542249, 50.746585861329116, 51.29907523432086, 49.48973294227354, 66.74884027050388, 67.7902687749555, 57.17957888880084, 57.98872463164791, 64.8865302916496, 68.48325744751962, 64.20946251961493, 65.71096543342837, 67.41025386318084, 63.74627374833631, 59.21590482034991, 64.44815051171088, 63.087170431690836, 67.38129108182846, 66.73846952376827, 67.67609642397973, 62.95243309390161, 65.1065948701674, 59.452839512978834, 61.03876360001103, 60.681784768258375, 69.24589956960371, 65.49874559525522, 66.04046806212395, 67.12514462009554, 67.2456947449715, 56.8354771983239, 60.55094626642043, 68.159285360767, 68.96705827405377, 67.0044925135951, 62.847223358769575, 63.422968464512984, 54.647634029388435, 52.6242950654799, 52.084431802072835, 52.24813976595479, 56.217668594852576, 61.09026432037354, 64.18182157701062, 62.34729766845704, 56.506892404248646, 48.25376664438556, 45.665963311349195, 52.58539692048104, 46.534050510775664, 40.3546622491652, 40.769762762131236, 41.260270841660045, 40.76685236346337, 41.22563631303849, 42.238862975951164, 41.141874098008685, 41.98900407360446, 40.1176961775749, 45.20344134299986, 48.35494418298045, 45.066405496289654, 47.5164669559848, 50.74001981366066, 55.47059043761223, 60.90315941841372, 61.02160715287732, 59.415808416182, 52.444768182693, 52.09619106784944, 50.81668646104875, 48.52741864419753, 52.540187681874926, 57.36611504708567, 61.22092239318356, 62.9776970801815, 60.19691705703736, 59.752638032359464, 55.98937488371327, 58.012572642295595, 62.69825958436536, 57.515808382341945, 57.88715485603579, 60.019629847618845, 58.06656406771753, 52.058634373449514, 58.25697160536244, 53.9337508909164, 53.226072942056966, 53.46603962682909, 52.33281981560492, 47.81684598615093, 44.50796588774651, 46.96478559124855, 43.318142352565644, 41.9267992050417, 38.38560888844152, 39.18062625392791, 36.67186260223389, 36.37804961973621, 22.785848494498964, 8.27461446485212, 4.665178339327536, 5.079194807237195, 3.143573033232843, 2.0699239738525885, 5.84297392637499, 7.788990226484115, 11.798419856256055, 4.449930431381349, 2.628846279075069, 3.510462468670261, 2.5451404481164874, 2.363731072795007, 0.15604037370893264, 0.1206443690124058, 0.07441378198564053, 0.03306651134945212, 0.12739027880372542, 0.15177729359317213, 0.07749657341909987, 0.07097747161864273, 0.10777548616451603, 0.039428446381803484, 0.08025855021250826, 0.12557115706224597, 22.255885293406827, 55.101950399337284, 43.97397833485758, 37.0273313214702, 47.02125595461938, 48.24029722521382, 29.844173231432517, 0.3414942336178595, 0.08606382660687932, 8.583067694017965, 47.062585969125074, 50.32151076101488, 95.66337646976595, 12.3828451671908, 0.17190355717414812, 30.65893973073652, 120.0403344246649, 39.662728694177446, 1.6262177377939226, 4.260463281985253, 22.09077508218827, 13.122861096935889, 30.585373716969645, 51.722593153676684, 70.77056407928467, 88.96438398668843, 67.36717839394846, 65.18098262048537, 118.92765214366298, 86.66194485079858, 55.20952924605339, 57.976129901024606, 0.4449061748962249, 0.21637008885943124, 0.19352896289239008, 0.2667088836671845, 0.15849098172639647, 0.16742132994676792, 0.14160595954425875, 0.11508121470650358, 0.21682638614889116, 0.13218220473537523, 0.8359011490979503, 14.346560182109958, 58.86629612215104, 77.19088000635948, 80.90386621413693, 74.69909237277123, 68.43985249919277, 67.64149327431956, 64.40003479680708, 68.70305922723585, 64.288427675924, 53.82182605804936, 74.55491388997724, 80.982376375506, 69.56127382093861, 70.73618842709449, 74.3196815060031, 76.80564834225562, 69.7260682813583, 73.9222748048844, 73.36318016052246, 68.54686260223389, 63.795966256049375, 67.53756615423387, 67.73490844234344, 71.9659456129997, 70.03838308395879, 69.28805720421576, 65.08449623661657, 68.88658692759853, 62.02523185360817, 66.00292313483455, 64.55991060503068, 72.00443190913047, 70.25847511906778, 68.96680724236273, 69.4136122734316, 68.37709457643571, 62.42999692117015, 60.668621293960086, 71.3713848975397, 70.0502835550616, 72.47043301982265, 64.2254069543654, 68.0115375211162, 59.42482202283798, 58.05556574175435, 55.826435704385084, 55.42343570340065, 59.368987083435066, 62.86087320696924, 66.68510959994408, 62.850682889261556, 58.442946864712624, 51.71233615567608, 46.86119187262751, 54.65294099623158, 46.72624664921915, 41.03857063478039, 39.75347665048415, 42.35950723771126, 40.29655233506234, 40.708762061211374, 42.05757494895689, 42.73849841087095, 43.27716142900529, 40.040276435113725, 45.44087025427049, 50.3497596709959, 49.08654466752083, 50.50884708281487, 52.82171972336308, 57.96760266826999, 63.864584199843875, 66.2658945206673, 61.25099128292453, 53.71765575101299, 56.28072461774273, 51.3949614955533, 52.07500242417859, 56.06131115267354, 63.042427955135224, 64.9973411713877, 63.99872141499674, 63.6714937610011, 62.19562745863392, 57.98043274110364, 59.850779656440984, 66.6461447746523, 62.46111308374713, 62.053014001538685, 60.829846397522964, 57.85307338160854, 52.39444025101201, 65.48390334652316, 57.01660440814111, 55.98955531274119, 57.628788332785334, 53.6947294973558, 50.15837546317808, 52.08741672577397, 52.96188954384097, 52.02904793523973, 51.42241808675951, 46.763960238425966, 48.85628192655502, 48.88738632202149, 46.7190412552126, 27.917622673896055, 10.0375884579074, 6.046113477599237, 5.506752277574232, 5.038315375005046, 7.847524246861858, 10.456061228629082, 11.309974943437885, 16.44218058355393, 7.170322623945053, 6.8586687407185964, 8.616354888485326, 4.866445939387045, 3.6204986802993284, 0.5699935627560462, 0.44834738056505885, 0.37034492098516036, 0.10542552677854415, 0.30988878600539704, 0.3736050541122114, 0.16734188662902003, 0.162993096596291, 0.3262956007834404, 0.26984555406435845, 0.16466254007912454, 0.40725577262140095, 33.68289101508356, 72.12720994026431, 54.222990389793154, 50.12814183388987, 61.78877961251044, 65.10552014074018, 39.71152690149123, 0.3399267564377477, 0.16904785718408324, 21.574471535221225, 67.47239205145067, 60.897734780465406, 108.70848932573873, 14.507762732044345, 0.7441912315064861, 58.2239217142905], [61.13072356870098, 11.91094873412963, 0.6032040258569102, 3.1380214085502014, 5.339813751559104, 4.254986672632156, 8.394767449748132, 7.433411190586706, 41.44059396559193, 54.40529038829189, 47.52417833574357, 40.22947588274556, 63.38635706132459, 69.8008051226216, 43.26273495151151, 49.573820714027654, 2.523404633806598, 0.46541566630044295, 0.12066159832982287, 0.11646578839469342, 0.15442372900584053, 0.0593150508469872, 0.03008985373702261, 0.06474976668194418, 0.015127105120148872, 0.10964783569497448, 0.4860812251365954, 5.029900910392885, 66.65673517411756, 78.20454597473145, 78.30190704714867, 73.26784303111415, 63.68387276126493, 60.13413560005927, 52.59943900569793, 54.512696650720414, 25.67736291116284, 17.622367835813954, 23.295276126553937, 62.89771995236797, 73.63117218017578, 59.15184859306582, 53.60812748632124, 64.94601695768296, 66.22845941974272, 64.52356984538417, 59.615088355156686, 60.44344978947794, 55.108508602265395, 55.818979278687515, 59.97127094576436, 61.4226028227037, 60.91010201361872, 60.28948499310402, 60.16196481643185, 62.035202518586196, 56.248172867682676, 56.20709388486801, 56.98111872519217, 63.456944034945586, 61.92505059703704, 65.23995545602614, 65.75849279280632, 62.28543796846944, 56.21547598992625, 62.39737064607682, 64.82147385997158, 63.735330335555545, 62.82546204905357, 63.61669432732367, 55.11277614101287, 51.548816465562396, 50.30288734743672, 48.27954446115802, 54.79190664906656, 57.14374019253639, 62.201954241721864, 58.258156161154474, 56.965366486580145, 49.36796296027399, 43.905666335936516, 46.03829037758612, 49.13384060705862, 47.60650496329031, 40.887418177820024, 41.214700744998076, 43.393855864001864, 40.24833856090423, 38.55142316510601, 40.22913855891074, 41.547933547727524, 37.479706118183756, 38.63196903659452, 44.826540793142016, 49.4950673657079, 39.628855105369325, 43.139819637421645, 43.849043000128965, 54.96797007899131, 55.88103509718373, 55.00526005221952, 54.544765949249275, 55.81481372156451, 49.45552595200078, 50.4519138797637, 47.86330646084201, 45.68485344609907, 55.762375554730816, 58.41752598362585, 58.59174197719943, 57.017781119192804, 57.70404292691139, 53.58487959830992, 53.320668743502715, 57.55846415796588, 56.11354535625827, 54.64511979010798, 54.35634705328173, 58.29451261028167, 49.09722135912988, 44.16870832443238, 48.81796821471184, 47.421729949212846, 46.55720426190285, 44.90541965730729, 40.81692534108316, 36.73810358970396, 36.783999243090236, 31.466900917791556, 32.67867795882687, 32.9368209069775, 38.69688034057617, 31.616743303114372, 21.050211460359638, 8.21911390750639, 3.746551400230777, 3.958662392631654, 3.2730529241023527, 10.039394709371752, 20.277312340274936, 21.616844900192756, 30.578221274960427, 20.54123293968939, 21.606287840873968, 19.40864266887788, 18.80963594682755, 14.780920513214605, 6.020220441202964, 1.1013223615384873, 0.22740388469349956, 0.051967627969720674, 0.0983281205258062, 0.09050828569959249, 0.0702123029998714, 0.010180574026890099, 0.04537054224901142, 0.04910098058321784, 0.035712161521998145, 0.04869424918245885, 0.2233539915253078, 18.198699335898123, 44.352169344502116, 41.135563004401426, 25.337769985198978, 31.068760733450617, 14.168890541599644, 11.747835989921324, 0.7007086937946658, 0.18447433988894188, 5.145838818242473, 31.75369678005096, 41.89084283767208, 88.16407142146942, 11.327643259879082, 0.3651105486337216, 21.888792630164854, 93.6909341812134, 19.25894933362161, 0.12050140168397658, 3.576817204875331, 8.736450018421296, 5.7476299328188745, 10.753953476105968, 18.406649674138716, 55.63759319243893, 74.29764563037504, 50.017134835643155, 40.848920114578746, 93.75168385044222, 77.67433566431846, 46.142684259722316, 64.65780511979135, 3.3913266033895555, 0.5776583030819893, 0.23834587255072212, 0.032174080204699314, 0.07197415966901087, 0.04770030755729926, 0.05054475754619606, 0.021010189234549483, 0.07493371053809121, 0.020933494257229953, 0.7331046522144349, 8.876305068692854, 71.24557879663283, 78.9683569631269, 81.81592710556524, 77.65310779694589, 70.1101859923332, 68.90564964663598, 62.49896395590998, 65.32711444362518, 42.653630087452555, 29.90234394227305, 44.81283603175994, 68.82140498007499, 71.18611566482052, 58.53795451502646, 60.40273166471913, 68.8832607576924, 70.64087483190721, 66.8014863229567, 64.04009457557433, 64.74288525119906, 60.82008754053424, 59.82967338254375, 63.12524880132368, 64.90049000709288, 63.83291890544277, 64.94795460854807, 64.48164363061228, 63.359445679572325, 56.81265684866137, 60.03456231086486, 61.25211700316399, 65.09716549227315, 62.7128468790362, 66.78581253174814, 67.191895515688, 65.26993805362333, 57.65901019496303, 65.6823125193196, 68.78342859206661, 66.1524203515822, 63.69043096419304, 64.67368287424888, 54.943298370607444, 55.04543688989455, 52.110052724038404, 53.22492368759648, 58.74797390353296, 62.91856734983383, 62.986565559141106, 59.712445505203746, 58.9041313048332, 53.25563584604571, 46.756186100744436, 48.06946623709894, 50.544238628879675, 51.72174592171946, 40.79635250952936, 40.498032723703695, 40.6795011797259, 40.624823339523815, 39.27513184085969, 40.77569338583177, 40.05408710049045, 38.097185242560606, 38.33311188605524, 47.34729513045281, 53.982219619135705, 42.974699620277654, 47.500106749996064, 44.91368016889019, 51.99932421407392, 60.78020488062213, 57.02586512411795, 57.9500186827875, 56.82125468407908, 52.87224377355268, 52.798538515644694, 49.617127603100194, 47.1216921652517, 57.25033844670942, 60.71441888809205, 60.44711720558905, 58.3454014408973, 60.80074633321455, 56.71143224162441, 55.425247838420255, 61.3776053920869, 59.42529662962883, 57.722062295483006, 55.916556081464215, 63.142562143264286, 52.700620466663, 47.5445197474572, 51.55026774252615, 49.51403202549104, 49.01241971600441, 49.458793286354314, 46.32045784304219, 41.8169100822941, 41.575335225751324, 39.48293901258899, 40.04359868264968, 38.99559628578925, 41.28855113060244, 31.758221234044722, 20.57736777490185, 9.432784472742389, 4.068817746254706, 5.278546329467527, 8.452832256594013, 12.13817556058207, 19.868742573645807, 21.52609302151588, 31.677083084660193, 22.955171331282585, 19.65446937468744, 20.414499198236776, 21.13563087678725, 19.6329394848116, 6.912918552275627, 3.4604573970840824, 0.19265703226049102, 0.18058837421478766, 0.05729822096444907, 0.06554102825541651, 0.08468669163243425, 0.01342434255826858, 0.08253940846771002, 0.03454835139094822, 0.12506121063544867, 0.06435964406738359, 0.29248700687481516, 33.83953479028518, 62.620004377057484, 53.21564335976878, 36.13256808250181, 38.805675122045706, 24.867197352070963, 18.307513729218517, 0.5227250185224318, 0.03784495413363461, 10.167660136376659, 52.11378289807228, 52.28917952506773, 99.450377802695, 14.06730507650683, 0.6234502588068286, 36.2721142461223, 99.71858947507798, 30.61592309705673, 0.8067317078671148, 7.669943349976694, 16.941199225764123, 11.43516327104261, 36.08890033537342, 24.57613395106408, 63.62509604423278, 82.12919896648776, 62.768403330156886, 55.758774818912634, 73.54906128298852, 83.93932573256954, 55.80908706111293, 72.47177447042158, 2.8218710182174562, 0.5174143131702177, 0.31675039039504144, 0.20313866256225496, 0.17139721902147417, 0.17185411385951505, 0.12136433078276536, 0.27142964003066866, 0.19168004033065614, 0.34932212002815743, 0.8669652789831163, 17.848090433305313, 74.93498371493432, 86.76930012241488, 86.59585291339506, 80.59053944003198, 72.3586376251713, 71.32680323816115, 68.88862656008813, 78.8238254670174, 65.38093328475952, 41.12583552637408, 52.57378278240081, 79.27359580993652, 81.63256414474981, 71.02354126591837, 68.11930071923041, 76.34165548509168, 78.50256766042402, 74.11324716383412, 71.78164912808326, 72.13019878633561, 67.07296925206339, 62.71399613349669, 66.791044973558, 66.20529390150502, 66.8184466515818, 65.18328505177652, 67.75665406257876, 65.69658994674683, 59.381487677174235, 63.79966505112187, 64.00648770793792, 71.0587876842868, 65.28128154816167, 71.20684931355139, 71.68516666658464, 69.70269095513129, 60.68262415547525, 68.27636811041063, 71.17434070956323, 67.51219626395934, 68.21782281321865, 68.05638590166646, 60.92063749990156, 60.23477185157038, 56.80313333388298, 56.480863555785156, 62.72293913748957, 62.74783442097326, 67.03169807311028, 63.35565666998587, 61.2398595963755, 52.6624361930355, 48.6360800650812, 50.315435009617964, 54.81604883747717, 51.97992809357182, 40.57753916709654, 43.05673207006147, 42.78328403349846, 39.772304027311264, 40.23379048993511, 41.029666854489236, 41.91377693606962, 39.9051703945283, 40.6775164604187, 46.44498917364305, 54.97917629057362, 44.266610683933386, 48.85577594080279, 46.032795136974705, 57.420745818845695, 59.90711273685579, 60.76025570592573, 59.307288200624534, 61.01017344382502, 55.63706759483584, 57.601402344242224, 52.387599637431485, 50.93644818952007, 61.401308275038204, 66.69380941698628, 64.6832142337676, 60.57369993579004, 62.96174087832051, 59.68345134488998, 57.355693309537834, 63.5550582024359, 60.62983689769622, 61.615285335048554, 59.82206790677963, 66.64415221060476, 56.38010963316887, 50.524293376553445, 53.656282424926765, 53.39679018143685, 52.695384102482954, 53.94122300609466, 50.32352293691328, 47.991214952161236, 48.237528031872166, 48.28807953865298, 47.73453504808488, 52.70344849555723, 50.3982440886959, 37.87617929520146, 25.689424199442712, 12.198608498419485, 5.3142658837379955, 7.435493969148205, 10.997196320564518, 20.18107698809716, 25.961275831345592, 28.328936138460715, 38.6600532070283, 26.337790027741466, 31.65716725011026, 22.967477767698227, 25.869392348874, 28.07210522313272, 9.391906511399055, 5.256668819535164, 0.9186908614731605, 0.29642779380083084, 0.2096174987814119, 0.14249583195534446, 0.3020195921342219, 0.150012671346626, 0.2536157822056163, 0.1918085745625919, 0.26822656513221804, 0.12015940471281929, 0.49560587372510667, 49.110592719047304, 76.41958513567525, 63.69467889108966, 51.054017313065074, 51.54210921256773, 50.20699324146394, 25.283498110309726, 0.7250607290094899, 0.3043000520237031, 19.46565235814741, 78.37236066018382, 63.918838424067346, 119.14135856013145, 18.539376797214633, 0.7897282944571588, 55.85402565617716], [47.21642917202365, 5.948636204965654, 0.2330126135700172, 4.449237642749663, 4.027267833871226, 2.4421537162796145, 18.986470122491163, 3.1932172467631683, 23.541453884493922, 56.21041221003379, 48.19811997875091, 60.82528468101256, 47.74166591705815, 27.435082889372303, 48.78291399248185, 50.68918589622744, 8.628903531259107, 0.818939533445143, 0.2331647739535378, 0.12755694123165262, 0.2886702649054989, 0.1012860396276078, 0.22396948188543322, 0.0511268541337021, 0.14473473923581262, 0.05968169669710821, 0.14498037766785393, 7.043006410521846, 71.30589700514271, 84.82707577366983, 65.44767633561166, 68.77232828447896, 58.84260500631025, 61.78967391290973, 53.73883262757332, 55.185959723687944, 28.732251890244026, 17.993596638402632, 7.138082212017429, 30.790739213266683, 62.09151990952031, 66.78472211284023, 61.84215522581532, 58.98481838164791, 68.54949059024935, 66.46661004712506, 62.76846608807964, 62.16212649499217, 57.43453295000138, 54.2422806063006, 56.37816805993357, 58.858714180607954, 59.48422631909771, 60.953538340906945, 62.3685843713822, 58.78351842203448, 56.343713960339954, 56.774139173569225, 59.40704191884687, 59.303330529120664, 62.27958971454252, 66.0843123159101, 61.54841676835091, 58.05972345413701, 58.37228144368818, 64.01691336785593, 65.23857870409566, 60.88592844624674, 63.3769041492093, 58.5601512078316, 56.435921038350756, 50.12332516331827, 49.2201013718882, 57.196539217425936, 55.54988899538594, 59.452639472100046, 61.56609096834737, 54.76577189660842, 56.16229257275982, 51.660474577257716, 43.95901449265019, 48.803784924168745, 52.24367610869869, 56.636063898763354, 46.14230771218577, 42.74194617425242, 41.822730879629816, 41.7981219291687, 41.02257913158786, 37.554458648927756, 40.87603545957997, 39.344279304627456, 41.81871045020319, 50.05065541113577, 46.948056682463616, 45.97612473272508, 43.42103396692584, 50.49085517083445, 45.53243406357304, 56.83053893427695, 57.32276108957107, 58.065556018583244, 56.50738662289035, 53.00452178524387, 49.089482522779896, 53.65088916593983, 47.97337601261754, 46.86219207702145, 54.416567202537294, 60.125208285547075, 58.115727055457334, 55.35283304029896, 58.28465961640882, 50.69095096280498, 56.76026575026974, 55.49072004133656, 58.00323347891531, 55.956862357354936, 55.1120779591222, 45.54087108181369, 44.510276163778, 47.308683318476525, 45.03142579909294, 42.07705736160278, 39.526057627893266, 39.470775742684644, 34.96159938073928, 32.14058368436752, 31.59878080891025, 35.938485284005445, 38.54895599426762, 35.219067681220274, 21.436164840575188, 10.88187667631334, 4.22640141940886, 2.1771757929555835, 3.4159132453703114, 5.1690636623290285, 21.343844013829386, 29.154746070984874, 39.1196608543396, 49.88253870318013, 46.78932228396016, 44.39664509988601, 29.21666264533997, 37.665175391781716, 33.305429566291075, 25.37185734318149, 8.573133310964032, 0.7939160374864456, 0.20768041482135174, 0.07183545178944065, 0.06414847959193491, 0.18443644918020696, 0.07113994354562414, 0.14489911106084624, 0.06197480469821923, 0.1572641072374198, 0.0841638136414751, 1.4069170408671903, 24.707146998374697, 47.21068682209138, 45.08266764302408, 21.972315580614154, 27.02909011994639, 11.03443040001777, 5.613124995462356, 0.47787152050483617, 0.13399892096077243, 4.954843415367988, 45.82631372636365, 57.98000912512503, 82.84841260602398, 7.8653063120380535, 0.3362147540094391, 10.93752726431816, 79.58679706819596, 14.086872800703972, 0.7079396444943644, 6.463320303347803, 6.6007979069986655, 3.953346845603759, 23.79385840508246, 5.6109520023868935, 40.31444226541827, 77.79322270424136, 48.75237834069037, 59.43587526198357, 64.58260543884771, 34.655179900507775, 58.08086110699562, 67.77686995844688, 10.128765913747973, 0.8038230865232406, 0.14811753836129943, 0.08965258847080892, 0.19803987245165533, 0.09429193267057981, 0.09557349817647089, 0.0520982114868539, 0.09135033124156537, 0.17237284731480385, 0.3909290906402373, 7.944328342714618, 76.64346618037071, 82.22606582026329, 73.1015972937307, 75.66959657976705, 65.96174609276557, 68.44783060012325, 62.00530229076263, 72.0967488135061, 49.53716224239719, 29.99247020290744, 23.746236908820368, 46.61458853752383, 70.79320399991929, 62.79322801097747, 61.04632592970326, 62.98475734649166, 69.90491267173522, 70.0697071321549, 65.86472234418316, 66.2399362748669, 61.85501275524017, 57.828817444462935, 59.27702711474512, 62.904093803897986, 60.8266104421308, 63.97403009476201, 66.74585142443257, 62.310007695228826, 59.62518453598023, 59.75045719454366, 62.403552301468395, 62.707112373844275, 65.39228854640838, 69.75086550558768, 63.05221819108533, 61.1607297005192, 60.69372054069274, 68.4546241452617, 68.77206156330725, 64.890272232794, 63.46499273853918, 61.456648995799405, 56.86863299339049, 51.59402178179834, 53.52871517981253, 60.03912402737526, 57.632298854089555, 62.00709873630155, 65.39463020140126, 57.30109391673919, 59.46626970844885, 54.02369476133778, 45.698413079784764, 52.621039498236875, 55.08313478962068, 57.6552878656695, 49.67997181800104, 43.81569500892393, 42.29769852853591, 41.94234748040476, 41.24908031955842, 39.72712224529636, 41.15699875739313, 41.12076390174128, 43.48813395346365, 54.385541254474276, 53.22380581209737, 48.69015778264692, 46.280359452770604, 53.20954015178066, 46.96041999324676, 54.74538341645272, 57.072227539554724, 60.25829038312359, 57.44779056118381, 56.17853118527321, 52.01350358224685, 54.432825426901545, 53.18387216137302, 49.8243817206352, 54.06990028196766, 61.213701309696326, 58.45527095179404, 58.3277193961605, 61.979673524056714, 55.55696887354697, 58.62755713924285, 59.56601950430102, 58.038244555073405, 58.68422362112231, 56.054972602475075, 50.9902984096158, 47.2044502535174, 51.024583847292014, 47.83530073781168, 49.70971907338789, 43.42053974828413, 43.355828485181256, 40.81692534108316, 40.11856694375315, 39.71560616647044, 42.759173224049235, 40.89534528793828, 34.4301260671308, 22.53733104275119, 11.145751187878272, 5.0780558489984085, 3.2245373725891118, 3.460614537039111, 7.714078349451865, 22.999882428876816, 33.06934210561937, 44.92925590084445, 52.61528538119409, 47.296025829930464, 49.44476296824794, 28.276737236207534, 38.66877655829153, 39.61790777021839, 30.738297124062818, 12.318110369866895, 3.6323471799973523, 0.27029487995370743, 0.0509935739870754, 0.11030242718275517, 0.21009069597048147, 0.07016060738674096, 0.06567031325351808, 0.16004485318497305, 0.020152050100507277, 0.19086745086937182, 2.5257933572415383, 46.525778232082246, 59.791481264175914, 59.5700595455785, 32.93131782162574, 40.38053812519197, 13.212318593455901, 9.044705167893442, 0.47260451280782306, 0.4013886116445065, 16.633638335812478, 66.3004506018854, 69.25487395255797, 92.52061659289946, 8.524365502019084, 0.40659672250190093, 32.31343665430623, 81.65226228775518, 25.556487229562578, 1.6727284678528387, 10.330836619100264, 12.182788598921992, 11.930036948573205, 57.48837924772694, 7.355090773874714, 51.140787986017045, 92.35938364459624, 56.66243791580201, 76.6583162738431, 74.21995916674214, 34.04265472965856, 72.6346077457551, 77.71195903901132, 9.644667967673271, 1.1275054081793756, 0.31074521101770863, 0.21631788762827076, 0.32700282251161916, 0.172858179336594, 0.4055988776587671, 0.2431774511933327, 0.27121709659695625, 0.3236659886615892, 0.6399859295737359, 13.48946346390632, 84.36113742090042, 89.98333731005269, 81.2319960132722, 82.22213560535063, 72.8094042501142, 70.83883685450401, 67.79481087961506, 78.15233138299759, 66.00309571912213, 48.905888142124304, 32.62739493000892, 52.96964406967164, 79.95587641193022, 72.17502363266485, 69.14103108067667, 72.09815302202779, 79.13153540703559, 74.16835646475516, 72.61315238091254, 70.41354210146012, 69.83190167334773, 62.18173834585375, 63.22445731009207, 65.75733961597567, 66.31723834622291, 65.9876415806432, 70.83747971442439, 65.41631698608398, 63.75040008175758, 61.90438362859911, 66.2506208112163, 65.5206088865957, 68.06083386944186, 71.04305113515547, 67.30255342298939, 61.97275838544292, 62.25962092799526, 71.81458134805003, 72.47574390903597, 66.38977081544938, 67.93345882046607, 66.43465057496103, 61.382837833896765, 55.76959271584788, 58.02552823097476, 63.05730158282865, 61.33402001473212, 65.33149573110765, 66.03021498649352, 59.76072203728461, 60.72624091179141, 55.12098566178353, 49.33140647026801, 54.688709089832926, 58.88868108872445, 60.919664752098825, 48.78032915053829, 41.57892027208882, 40.561696713970555, 43.443701344151656, 41.447932720184326, 38.195648500996256, 41.83405868468746, 40.31452855756206, 42.23743915557861, 55.992712820729906, 53.900991255237216, 51.4558994385504, 50.89509071842317, 49.131145938750244, 48.30840526088592, 60.19693666888822, 62.66331518850019, 66.78669898740708, 60.63459473271524, 59.63538269842825, 53.48225470512144, 57.45985577183386, 54.66233507279427, 53.10842144873835, 58.562320278536895, 66.67478592165055, 60.473624583213564, 61.27365081541, 63.24603034603981, 56.73881430779734, 62.7517960148473, 61.234599697974424, 61.66873547338671, 63.015328299614694, 61.34541057771253, 53.34664267878379, 49.21858733700168, 53.617188161419286, 52.0193479138036, 52.72975975467313, 50.9916163259937, 49.35271278504403, 46.39815215141543, 48.916749185131444, 46.61562404324932, 52.2312500399928, 50.531651742996715, 42.28882612720613, 26.87093230985826, 13.050640456138119, 6.0780606923564795, 5.072185041442995, 5.225347222820406, 12.874954554342455, 31.53158472430322, 40.970658717616914, 57.365212901946045, 59.77513674766787, 57.100288175767474, 55.22185333313481, 38.872049470101636, 57.138813695599964, 53.440759951068515, 39.23145232662078, 17.621699071699574, 6.2693188940325095, 0.32041832744594545, 0.21915538536925472, 0.19218781872862772, 0.28672063242523904, 0.14353928967348992, 0.22422618262710112, 0.2117017788752433, 0.3736702022292922, 0.27379746458703474, 2.9529737897457617, 63.64035798657326, 71.11934907974737, 71.24967375109273, 45.10955941292548, 55.93825463325747, 40.36645289390318, 11.67964852625324, 0.4898957914162067, 0.7608858808394402, 26.226051507457612, 82.02883335851854, 79.18223596388295, 110.64078223320746, 11.936829513119115, 0.38367825229802444, 40.14536065440024], [50.54490543180897, 11.842333732112763, 0.9651281083783797, 3.3396062302973966, 1.9251836115314116, 2.931414972389898, 13.986052197794761, 4.474970842561414, 5.902298794638726, 56.65416955947877, 47.02338580162295, 58.781270903925744, 75.52421785170033, 57.16380311596779, 55.71941383423344, 49.9590249215403, 13.223644437328463, 0.7029494703296693, 0.17995825157530848, 0.09288740239196247, 0.040701960303610375, 0.014560907729901375, 0.09281172822680205, 0.03974568339124803, 0.10609232204695863, 0.14279385547964804, 0.26489570676799745, 11.091927443781207, 83.41684249139603, 70.7049742052632, 49.511600155984205, 49.880926609039314, 49.64289757513231, 55.957791959085775, 50.65901110249181, 48.9669829799283, 32.928258372891335, 15.22808247996915, 9.439863370310876, 8.878049542826991, 29.46560371306635, 58.00922686053861, 68.45418483980241, 59.25577571315151, 66.77280595225673, 71.04171752929688, 62.5998826180735, 59.5588807905874, 59.29817261234407, 53.53204527208882, 53.93879898132817, 54.058505796617084, 58.50267279532648, 58.51310629998484, 62.59307338345436, 61.91063588665378, 62.53976445044241, 57.24910682247531, 57.681395161536436, 58.14290515838131, 60.647358125255955, 61.80314333208146, 61.296479009812884, 60.648746644296956, 59.95434984084099, 65.94387577426049, 61.627119125858435, 63.49981161855883, 58.917561500303215, 56.31286059656451, 52.0825529867603, 48.83326938075405, 55.84178786123953, 54.93284525409822, 62.33853901586225, 58.95354532426404, 60.8351259077749, 53.386223316192634, 52.72261711858934, 49.2158926686933, 48.690200928718816, 51.904045920218195, 58.15306801949778, 55.42969188382549, 56.6011038134175, 50.8972833233495, 53.228677395851385, 47.21089863008069, 43.610343240922504, 42.24842571443127, 47.88615034472558, 47.62068825383341, 50.718187901281546, 52.765143455997595, 51.427179844148704, 50.49229075831752, 44.737852081175774, 50.43879747390748, 53.78948611597861, 46.332523053692235, 52.94745129923667, 52.17719585664811, 53.417351245880134, 51.52752191789689, 49.18288200132309, 50.22146678739979, 54.205426016161525, 48.13493451764507, 50.66269420808362, 56.76864001058764, 56.56873641475555, 56.81390416237616, 54.20795986729284, 56.679527682642785, 53.18611183474141, 56.76043441218715, 54.288007597769464, 53.18108727855068, 49.749676258333274, 47.45539565240183, 42.14060368076448, 44.95863837580527, 41.70747987685665, 40.85981253654727, 36.91709310777726, 32.81819078230089, 30.07281211114699, 30.138788338630434, 37.10018150268063, 37.17296500359812, 31.539313754727765, 29.393887096835723, 14.976236897130168, 5.849378176273839, 4.240230225747632, 1.373923043570211, 0.5833777316635655, 12.612096917244697, 37.88917018521217, 44.28339450590072, 48.85451293760731, 66.76337657436248, 64.03419925320533, 63.216589035526404, 58.75086469034995, 25.178160898147095, 23.118949897827644, 27.28420892069417, 21.210138259395478, 2.462043319979022, 0.7182971532306364, 0.1200551707898417, 0.08010616000261038, 0.10170535785296272, 0.011676339631629808, 0.07578422901250663, 0.041757997185472524, 0.09902899138509266, 0.4251083791736634, 9.192901138336428, 44.79927247570407, 42.17479498155656, 52.610166688119214, 22.5779079621838, 30.61231843886837, 4.733490828544864, 5.333081493454595, 1.705400953369756, 3.259640624446254, 37.3457807110202, 37.04626460229197, 61.72365257816931, 74.61420443750198, 1.7853774683129404, 0.06226329808874477, 9.23427822128419, 70.79460036370062, 14.302232496200071, 1.095107733722656, 4.843613332317722, 4.7511571838009745, 0.8377249286540094, 31.328217675608975, 4.498877688761681, 12.652756206450924, 83.1945147052888, 50.32135778857816, 61.57000549377934, 69.67095898043725, 53.42054797757057, 57.14662705698321, 71.35717022803523, 18.22158636585359, 0.9184259176254274, 0.1589446436733969, 0.27786297062712334, 0.17267756644756566, 0.04823974070830211, 0.09249192482281117, 0.10580753652198661, 0.10787145399879064, 0.1317992527037859, 0.28231973309190045, 11.742174048577587, 89.0876954601657, 78.7676335919288, 66.79475553574102, 67.28982140941005, 62.750383961585264, 65.5595580224068, 59.0046420404988, 65.45634869606265, 51.04201093796761, 35.207602593206595, 18.093907333189442, 23.335058766026652, 50.43925639121763, 63.08343633528679, 65.48307964878698, 61.975923738171986, 70.57261774616858, 68.4534631236907, 64.22616397180866, 62.568068273605846, 63.97628937998126, 57.91716491022418, 58.5618652835969, 59.2350342196803, 62.40948684753911, 60.949702262878425, 64.74502294294297, 65.97427414309594, 63.9265105801244, 61.21494077867078, 59.74830773568923, 61.595402840645086, 60.681674941893554, 64.09353294680196, 64.24902354517292, 64.01179859715124, 62.36007282810827, 67.72799722609982, 64.66098223963093, 67.09963352449479, 62.08038037823093, 60.35997390747071, 52.770297450404016, 56.28247399483958, 56.992179809078095, 58.599724000500096, 64.33649632238573, 61.92682350835493, 60.53695517201578, 55.38396096998646, 53.79996276670887, 52.21889457395, 53.20109921116983, 55.900811687592544, 59.26980210888771, 57.561201972346154, 58.08358715426538, 52.377044539297785, 54.301963390842566, 48.673087627657004, 40.809955289286954, 45.28550124937489, 51.51982622761881, 49.91835778759372, 53.52764829512566, 57.010046205213, 53.87349544032928, 52.600788301037205, 46.25875503786149, 52.868082138799856, 54.7802689767653, 50.58776909305204, 52.0227329192623, 53.26541823725547, 53.39735108037149, 53.76686972956504, 51.43490299101799, 54.419991431697724, 56.72053606279435, 52.886466287797504, 53.72518670174384, 59.985968066800034, 58.86457027927522, 58.33234779296383, 56.15266315398678, 60.76383682989306, 57.39576424321821, 58.22663207207957, 57.66730993024765, 55.86497299132809, 52.64759002193328, 52.03161316533243, 46.855939818966775, 51.42871741325625, 45.87354690797868, 46.077310116060325, 43.29636143099877, 40.18317622523154, 36.65561614498016, 38.093137356542776, 41.69061760748587, 41.99444832340364, 33.17033137044599, 30.74940331520573, 15.99237297811816, 6.182698742035897, 5.128218550835887, 2.465147140526003, 2.4775288374193254, 14.492954804051308, 39.7369909286499, 44.713423559742594, 52.62514621980729, 67.01698134022375, 66.9599186989569, 60.38600667830437, 64.15150165557861, 40.33086915169993, 27.338635729205226, 33.5297106927441, 25.943270191069573, 7.909901209415929, 0.7438635910230299, 0.04762927205452035, 0.01698863174345705, 0.03360572999583618, 0.024058179208828558, 0.09962892249947596, 0.005216676199192843, 0.08360772573899838, 0.466253490697953, 12.617042045439444, 63.44597708794379, 54.1375494003296, 67.90197003272273, 30.90988709080604, 50.16548279793032, 27.269541217434792, 8.09474927763785, 1.6102840895614319, 4.379453284125175, 61.991440634573664, 51.33995417625674, 77.33643916345413, 81.76697592581473, 1.829750016331673, 0.0830015816515492, 24.441043599959343, 82.94341241159748, 27.033030140784483, 1.9113168072315956, 6.256731517853276, 8.078784250443983, 18.195120173115885, 58.836980327483154, 7.378436230844067, 24.279381152122255, 105.17543792724611, 59.874435470950225, 74.57456496454056, 105.23574044627529, 71.41454665891587, 67.48625370763963, 84.58711301126789, 19.04727666608749, 0.9770546877576459, 0.333489258322985, 0.4277625980396425, 0.4087374785975103, 0.16067964896079034, 0.21901033428167144, 0.25959526699396873, 0.3431840703612374, 0.3656593740226761, 0.5736018981664412, 18.9728202742915, 96.76833168152841, 87.2489824602681, 81.33024354134837, 76.02547322550129, 71.63638022638136, 70.41735464526762, 68.89563975795623, 71.91939492379466, 71.24830876627277, 57.724148996414684, 28.866512660057317, 30.382691121870476, 60.574103939917784, 73.71944119853359, 73.16822267347767, 69.77715323048254, 76.79755257021996, 73.6806332680487, 68.69792092231013, 69.46141027635144, 70.68577028089955, 63.070535659790046, 61.7950201034546, 62.2897643427695, 66.46871243753742, 64.50161633952972, 67.64535288656911, 67.82598587774461, 66.66650187584662, 63.01510472451488, 62.213168298044515, 65.66538749202606, 65.27680220142489, 67.8847586724066, 65.59946421653994, 67.07262408348822, 66.43268938987487, 67.72970737949495, 68.11797495811217, 68.48141393353863, 65.60174311361006, 63.362869908732755, 57.57848393532538, 57.500636654515425, 62.13855305025655, 61.9998658857038, 68.90608895209529, 63.432288016042406, 65.65628367085611, 56.729514368118785, 56.93530151920935, 54.3408223121397, 54.58833171475319, 60.059759616851814, 64.20423400017523, 62.61294018837714, 59.69882311359529, 55.561918904704434, 56.39902330213978, 49.361714624589496, 43.00188164557181, 45.345533124862186, 51.75138727311165, 51.679360789637414, 57.21043225257628, 59.134174393069365, 55.23573852354481, 53.894182020618075, 49.526928778617616, 55.68076279855544, 53.581012141320016, 52.48998134366928, 59.25044521208733, 56.84474183667091, 56.79354706118184, 56.57818540450066, 55.07351713795816, 55.56172670856599, 60.07729261152206, 53.63411711108301, 58.10972975146387, 63.43146431830622, 60.708131328705825, 61.555127943715746, 60.71130060380506, 63.401160086354906, 58.91766348192769, 62.294369205351806, 60.828238225752315, 60.252497042379076, 55.582225015086514, 56.105994793676565, 49.4224250701166, 55.402266671580655, 49.65572764796596, 51.86695598786878, 48.990446598299094, 48.220520634805005, 44.69976978917276, 44.82497968981343, 51.11734005712694, 47.40218870101437, 41.34890071807369, 37.21153366950251, 19.52508803336851, 7.369693758026247, 6.171449384381694, 3.8109057276479663, 9.714361621487527, 23.348012393520726, 46.78239930060602, 51.52328183574062, 60.790661919501524, 73.59376845821258, 70.99418624754875, 69.83187029438635, 71.98861691259569, 47.20502684193273, 33.01961429657475, 39.16214404567596, 36.9485701284101, 13.47157451414293, 2.1362514986145884, 0.3211769996391189, 0.22131409856580922, 0.25308460748243716, 0.09355350052036586, 0.12487209417046079, 0.1397447642539778, 0.182835616531872, 0.7774358314852562, 15.135395892204778, 78.80392336076306, 64.42542037656231, 81.65774576125607, 42.130538878902314, 62.05943099914059, 42.586883114230254, 17.98811120371665, 4.013596412635619, 5.047193169593811, 76.64690217664166, 60.37710682038338, 90.29072561571675, 102.6040340239002, 3.6848061844225857, 0.27765085620264857, 23.208799631364887], [66.32727961386404, 19.66329666876024, 1.5558985885112517, 1.8010428019108313, 2.2137322829615687, 3.5834884210940334, 9.117756370575197, 2.046812755926963, 1.7641080483313532, 40.55525225977744, 49.54250451057188, 40.47266675579933, 105.38067986888271, 78.32060890813028, 54.06515029168899, 52.849258684342914, 22.397871171274495, 0.5485639997547673, 0.3942572523749644, 0.09428290049395255, 0.09867136622028005, 0.027892914668266332, 0.06761298965542548, 0.143152185445351, 0.11128184761131003, 0.1463311898612207, 0.20815885205182338, 26.288703526220015, 78.3359375307637, 56.2235168487795, 38.83085673855197, 38.01296018785046, 31.036169759688843, 40.846252902861565, 45.878422414102864, 51.17511264739498, 42.90497949046474, 23.305131081611883, 6.222185732856874, 10.295773571537389, 11.420957426871023, 36.83972043375815, 62.92724755502517, 60.751846144276286, 59.45030958421769, 65.57897375475976, 66.32281595660795, 60.21282619045627, 59.94230424204181, 50.57218551635743, 53.32150420834942, 52.82718358501312, 58.585019034724084, 57.934984237917014, 60.832768563301336, 58.91810278738699, 60.16445552149127, 56.264591909223995, 62.087103320706284, 57.83273196989491, 56.1602686297509, 59.43984862296813, 63.687034191623816, 58.284341904424856, 61.893134270944905, 60.768339710850874, 63.73812698548841, 62.9347667386455, 61.0671615600586, 52.93993603798651, 52.38093945287889, 56.584857356163766, 53.489197300326445, 55.69114531240156, 57.31645784070415, 58.82050245038925, 53.378629607539025, 49.687879316268436, 47.457796142947295, 53.709112828777684, 53.419453636292495, 51.54911456569549, 54.075160180368734, 49.899702995054184, 53.49502202003233, 47.88589539066438, 50.31433674596971, 51.73928283875989, 44.441811192420225, 46.610532806765654, 53.97183710528959, 48.08342987491239, 53.20490391023698, 49.236920495187086, 54.93761485622775, 51.01467594023674, 50.17583393281507, 48.390959385902654, 43.82284548974807, 48.34468326260967, 47.76978146645331, 50.35851047885034, 49.08102981505856, 49.70499653970042, 51.318800833917436, 52.20791978220786, 51.08818115726594, 55.00485997046194, 51.1607293159731, 51.56390974598547, 58.487281414770315, 57.976953598760794, 55.316959042702955, 53.63914166727374, 52.94459189138105, 53.896143205704234, 53.14961418028801, 50.83079914892874, 46.62477101049116, 42.776463031768806, 42.34179381401309, 42.440672843687, 39.3762936899739, 36.92968391603039, 36.06033371340844, 29.489557627708685, 31.3949332698699, 34.87113775745515, 32.52569963855128, 32.810977543554, 30.895652809450706, 31.40219553824394, 13.405309992451823, 4.040116292815055, 2.8454042586588093, 0.9983268656557607, 2.641828098604756, 13.665007179783238, 37.56795160232052, 59.19189207015499, 62.514590678676484, 71.04985252503427, 68.10329744892736, 64.95245356713572, 37.848808996139034, 25.916823610182732, 22.628975260642267, 12.6682387821136, 21.629622021029075, 19.41812303758437, 1.6252411901950838, 1.3546111314527451, 0.206508974454576, 0.13024346602539863, 0.011333210765564395, 0.09488660842180253, 0.015251534078420411, 0.07787362657367222, 0.11645950647371432, 7.926601681017107, 37.71380101480792, 47.83683438454905, 49.07257318496705, 25.080629202627367, 27.316213500115182, 43.29885998079854, 9.796553907855865, 2.9532917468778552, 15.756842494010927, 36.91127231044155, 34.7925962171247, 82.59682393843129, 35.30162572860718, 0.34478926971074075, 0.25858534860514826, 7.44520575769486, 62.80517162815217, 21.905576452132195, 1.962754769671348, 2.6628706339866888, 3.846626017362841, 0.4862057910330834, 27.29400504019953, 1.8228397806805952, 3.1991088919101225, 65.404867587551, 55.879007231804636, 44.95014644438221, 109.98458539285969, 78.91380463877033, 55.017584139300936, 75.23079318384971, 32.863352952464936, 0.6214816579895636, 0.17379893530761042, 0.11012839498899638, 0.16449580870328412, 0.09466920799065022, 0.0677223257239788, 0.07511795468388066, 0.06215054143760955, 0.041188908770920775, 0.26786153955805686, 27.421229077923684, 85.44781438765988, 70.9178961476972, 56.96615096061461, 54.59362691448581, 54.72807791925246, 59.40241352204354, 61.22629604031963, 65.55606711295344, 58.75229243309268, 42.13393172910137, 22.094330710749475, 15.927178282891552, 32.636479139328, 51.04310527924569, 65.53350563972228, 60.637140350957075, 60.94322642972393, 67.32196915534236, 67.4671596096408, 65.38205508262881, 61.84606190650695, 59.044210910797126, 55.20327306562855, 55.383937435765425, 61.3462068188575, 62.455072633681766, 65.05651797017744, 65.372111874242, 62.04046241698727, 59.475334305917066, 64.24053945849019, 60.418213259789255, 61.00211297312091, 62.347713439695305, 64.92531468791347, 61.49627277928015, 64.08365641870807, 64.69684054774623, 65.39582652430381, 64.5935723858495, 63.101898931687884, 56.32301953531081, 56.877760348781464, 58.080833650404415, 56.995866837040076, 57.5031626609064, 58.58434438705445, 59.32604889715872, 56.52705338693435, 50.62405101714596, 49.65591199936406, 58.68703988290603, 53.777781763384425, 54.95305330522599, 57.0768637810984, 52.65927084030644, 53.48754990485407, 51.63140589191068, 53.66459784969207, 52.32396310375583, 46.154165037216686, 49.350947718466486, 54.87252312321817, 48.38880600467805, 53.50125858860632, 52.48459200705252, 56.07640835546679, 50.17299413681031, 49.565956361832164, 53.214023420887614, 47.27998725829586, 50.388210665795114, 48.38975521825975, 53.885446902244325, 53.35030617252473, 52.36140604942076, 54.08153010952858, 52.61470487040859, 54.29804494304042, 57.95405480169482, 55.56987739378407, 55.322591566270404, 60.02573697797714, 58.7145866886262, 58.30134145675167, 58.8253269657012, 56.8898412489122, 54.364540884571696, 56.640519711279104, 53.2904076576233, 53.003580416402514, 49.25009965896607, 46.445856017451135, 49.30720544630482, 44.79683668382707, 43.76853635234218, 43.11964688762542, 37.20300251437772, 38.84403590233096, 42.398903523722005, 35.79149053942773, 35.19739658601823, 32.30570762388168, 28.338981328472016, 12.765789108891642, 5.678771743851324, 3.8076249101469597, 1.2786291828078609, 4.761271995882835, 19.419442915147354, 41.509384493674006, 58.88053824824672, 64.32629031519737, 69.23104163139098, 71.85874723619031, 69.1804430561681, 52.04659269702051, 30.225090288346816, 26.570319898666877, 14.900894049675236, 26.650616699649444, 22.391226676202592, 3.2183223770510767, 1.528602201611765, 0.24080498414414547, 0.09583056664034244, 0.07995505682042531, 0.03889829821644291, 0.12966862429053555, 0.1847294165242103, 0.4235953555232094, 14.748197159459515, 53.67050493917158, 60.89600893758959, 62.190473464227495, 36.53996506044942, 37.991575425670995, 68.75236342030188, 15.861578602944652, 4.771282865155128, 26.03311992460682, 48.86502096729894, 34.549891717972294, 95.4628727512975, 35.52553815226401, 0.29291010191363676, 0.3964284068394092, 14.992115632180246, 93.25164441139468, 45.92849146935248, 2.990097797686054, 3.422723215433859, 5.001230345618341, 17.827670574188232, 49.88690822355209, 2.9882648250749035, 5.2618174206826, 84.1317964369251, 69.81510608426987, 50.62624362207229, 130.8898299740207, 92.17550293091806, 63.26816035855202, 93.29547297570014, 32.97835880710233, 0.49186855975177984, 0.41410974677531953, 0.22254530911243733, 0.18440225101526708, 0.33588787961390715, 0.12579986495116066, 0.2751380265239747, 0.30595388263463974, 0.15350007211729405, 0.3715759017054112, 38.833292530428984, 89.38320682894799, 80.63668220273911, 72.98342412517917, 66.3519670117286, 64.39619871877855, 66.25556299763342, 68.9311372080157, 72.82554872574346, 72.10748041829756, 62.45114634113928, 47.261869830469934, 26.034941865551858, 44.330172692575765, 60.84816386622768, 72.79797446343207, 67.21544542620259, 67.26466332712482, 73.3592656350905, 74.11674591802782, 69.01921010786488, 66.64261464149722, 62.23845581854544, 60.014938692892756, 59.613287987247595, 63.4242981480014, 66.09344359367125, 69.1771717994444, 66.72099144228044, 65.73267575233214, 64.04741764068604, 68.46034296097295, 62.898316152634166, 63.09115948215608, 68.62025799289827, 67.2592112325853, 61.392306435492735, 66.19526832334458, 67.81548177042316, 67.81493263859903, 69.53178544198313, 66.01126209382089, 61.82595191463348, 60.129805303389034, 61.024580309467936, 59.960794295034106, 59.739698133161, 61.7656768521955, 63.53179070257372, 58.395286144748816, 51.45596219647316, 49.973365106890284, 59.39580825067336, 59.29301861793765, 59.5362251804721, 61.66989649495771, 55.89918390397103, 58.107242968774614, 53.28135482726559, 55.71742127018591, 55.7430814158532, 45.53850589259979, 51.50700399952551, 61.50002648753505, 51.89101188413559, 57.46504114520166, 56.655350192900634, 60.04881620407105, 55.900188030735144, 54.16706523587627, 56.602005958557136, 50.457915106127345, 49.12270499813942, 52.94998907273816, 58.74287874467912, 54.74234750193935, 54.734565519517474, 56.82891507302561, 54.77246346012239, 55.7636817039982, 61.563741468614154, 58.904123460092855, 60.11690855026246, 63.8951982990388, 64.27204001334407, 60.77732586091565, 61.388207558662664, 58.39175208922356, 60.03831994148993, 57.41061041432043, 58.04585003083753, 56.262646413618526, 52.69596069089828, 48.45275240559732, 53.19397226456673, 47.571576256905836, 49.89274078799833, 48.07253353057369, 41.626428019615915, 44.918296798583, 51.85573800917595, 44.78171986918296, 41.051949839438166, 37.29318564937961, 34.19288542962844, 14.303997562777612, 6.846530475924093, 4.232876762267082, 2.08263490469225, 8.81681546088188, 25.739304980924054, 50.07529966292843, 66.00951271672403, 72.9599448173277, 73.05945534859934, 75.2335859114124, 73.52203615250127, 59.609495055290964, 45.85560990918068, 55.35363320381411, 22.116888261610463, 33.84543795739451, 35.93120144259545, 8.740678333467054, 4.476286307457955, 0.6195213309218807, 0.18279107617995433, 0.15228683399336954, 0.10966023099758934, 0.20775066508400827, 0.3048288671960754, 0.6652608249456652, 22.362673782533218, 72.25621669523179, 70.7412875083185, 78.21616403518185, 48.40910819268996, 44.22144851376934, 79.56849528897195, 29.406901521067468, 15.594176900002266, 43.77415318642893, 69.76933986909928, 59.99407560594621, 117.0560775264617, 50.30044371081937, 0.48308860991270314, 0.563812091225578, 17.93957187283424], [66.44325625511908, 32.76265982658633, 4.766049933048987, 0.44495701249088015, 1.285803075278959, 6.445703468015117, 11.628761656822698, 0.8817782937999695, 1.1366392599959527, 27.59094415172454, 50.87280381110407, 40.126780386893984, 40.78419708436535, 45.269144965756325, 50.82220915825137, 56.52059716563071, 35.92238787681826, 0.3803903561445975, 0.13875743013716516, 0.08254234258446001, 0.1825532518447407, 0.0949242233388847, 0.13031932405166088, 0.016353083286254157, 0.05402001582326428, 0.10116616985009563, 0.9480565437866796, 40.122767802207704, 70.09802664479902, 46.11523943562662, 32.780665466862345, 30.176199905333984, 25.843822417720673, 31.50053720320425, 35.95388450930196, 49.042955367795884, 43.643557871541674, 39.605556226545765, 20.754686363281746, 12.290310571270606, 11.738361504770095, 21.045643860293975, 44.42157960707142, 55.40480444508215, 60.793085944268014, 56.21026315996724, 66.11911942881923, 61.620380493902395, 61.09017802822975, 51.94385405509703, 50.46158644460863, 49.12209703076271, 55.50280486383746, 58.88194245676841, 62.80360268008325, 60.97498978337934, 56.60463786894276, 59.45269046291229, 61.47362893627536, 56.02215805361348, 60.182416054510306, 54.474186820368615, 60.21515607833863, 56.30401957419611, 60.381695993484996, 62.417461026099424, 60.530851964027654, 64.85659868486466, 56.11119585652506, 50.1681774662387, 56.20989053480087, 52.22566458486742, 56.780575783021995, 51.557947743323545, 54.994571593499955, 51.75759638509443, 51.42333592137983, 47.56284898327243, 50.03265173204484, 50.99674678617909, 47.17987660438784, 47.894959988132605, 51.4753387051244, 48.36611901560138, 51.24339718972483, 48.51660074726228, 49.44771259061752, 46.37626532585391, 49.51256898141677, 46.37468068830429, 48.10106485120712, 47.382455256677446, 48.592753564157796, 47.992019038046564, 49.93669094577913, 47.14648938948109, 45.846651215707105, 51.57082880696943, 48.53866015711139, 43.19039860079366, 50.25281044744676, 47.67143587912283, 50.40033471199774, 50.03096119050057, 50.84214656583725, 50.263714636525805, 53.130123922901774, 52.412608669650176, 56.62303378505092, 49.47359238901446, 57.42901809753911, 57.04146046792307, 54.4238353544666, 52.754215732697524, 52.8630458154986, 49.57820984625047, 53.438190798605646, 46.37091521293887, 45.618537933595725, 43.50801644786712, 43.529989565572436, 39.27619480317639, 37.73285588910503, 34.93037731416764, 31.340398596179103, 29.43338928684112, 33.38592836933751, 24.026976631533717, 25.587952483084898, 33.77918912518409, 33.33591030490014, 23.78569399156878, 8.850610602286554, 3.0724727194155417, 1.9393936232213054, 0.3978941168996596, 3.2118208033423272, 19.998849553446618, 46.524958456716234, 56.246749047310125, 67.14509379479193, 67.7818670580464, 68.58239927599507, 57.565834291519664, 56.54905003886069, 53.22142885577295, 62.503870840995546, 34.976245510962706, 35.03057818258963, 47.882765339266875, 7.872918651949975, 6.716607357225111, 2.700539851380933, 0.06207816911140277, 0.0468746792795437, 0.1952504697105577, 0.06368337995222499, 0.21594431251287463, 0.1979163024694689, 13.091801808726403, 40.55332245365266, 53.030405506010986, 48.588548783333074, 33.321993735528764, 27.29377558154445, 51.39500464162519, 26.34359709678158, 6.34395081189371, 21.052933585259225, 18.145004049424205, 52.14182392243416, 58.95754221946963, 5.3077831864356995, 0.25390501104054913, 0.24120563280678567, 5.5440383284322685, 77.14964020636775, 33.81357654448479, 1.4207198615035703, 1.1544998951496617, 2.343612010440519, 3.9245223277999512, 20.77389617120066, 1.720576358418311, 1.0265711791092351, 44.58244385257844, 60.552185735394886, 41.82024801931074, 52.953801616545654, 46.19254935172297, 53.62514272812874, 73.04494257896178, 48.99473374889743, 0.26925309230723693, 0.20780542504883584, 0.02199615971485694, 0.16120155402008565, 0.036861776043811155, 0.06332747082436277, 0.07872334065576715, 0.06776187884350938, 0.05430957024556495, 0.8230789822916832, 45.42791074322116, 78.90304949975784, 62.084463565580315, 49.79350090026856, 43.322613854562086, 44.99651670455933, 50.50636814486597, 54.827686509778424, 62.69536095280802, 62.397880554199226, 51.99726496973346, 35.032476609753026, 20.39561494704216, 26.314591169357303, 36.01665027679936, 55.59522374983757, 58.52503422767886, 58.33461100055326, 59.28072590981761, 66.76550249899587, 65.08710853515133, 63.9596075396384, 56.028088677314024, 54.354346644493845, 51.42441065080705, 61.0172180206545, 63.28710148411413, 67.25938381687288, 63.13943601423695, 57.80646777922108, 61.02125413956181, 62.97239011333835, 58.718991510329715, 61.07299804687501, 58.74902509873914, 61.44276380538941, 60.10369016278175, 63.252474800232925, 63.30249678704047, 64.36156811252718, 66.89445434078094, 60.51886127841089, 55.153149097196525, 60.27502321427869, 55.27085942606772, 58.475282884413204, 51.94917671142086, 55.660935217334384, 54.15563937156431, 53.9823333678707, 48.301890204029704, 53.35577003417477, 52.38142190441009, 50.468399601597945, 52.08361987144717, 52.6405885911757, 49.382467885171216, 52.62360472832957, 51.543736996189246, 50.89725194438812, 48.99858551640665, 52.70059301007179, 50.274199131996404, 52.31228228538267, 49.73363768669867, 50.58680811235982, 49.973102308088734, 52.09226085293678, 51.7157329282453, 47.76156410094231, 50.926889373410134, 49.5714202234822, 46.34429800894953, 49.62771800256545, 48.3452167049531, 52.91975544344995, 50.7204471865008, 53.604687567680116, 51.94839615975657, 56.434889454995435, 54.34202255741243, 59.240109766683275, 52.55416700916906, 57.49812633760514, 59.481982723359145, 55.73922572597381, 55.44479300898891, 58.814430621362504, 53.45989719513924, 58.539927467223144, 50.77122226838143, 51.701784979912546, 47.015748946897446, 48.230895303910785, 44.7127136107414, 44.04641274482974, 43.210638030882805, 39.87536822595904, 38.2915622188199, 40.057856498226045, 28.01486215283794, 32.34123056934726, 35.49499857810236, 30.936822006779334, 25.588311379955663, 11.953438789613786, 3.9677789615046595, 2.430989425028524, 0.24701826364522983, 4.897125247986087, 21.712299700706236, 49.32238501887168, 62.40707458988313, 69.39640875785582, 67.59859038937476, 73.28681161326747, 62.519132783336026, 59.31768248158117, 54.58215005936162, 64.99235583889869, 31.66072876222672, 35.9326684090399, 44.99892111747496, 11.054041270286808, 7.359411264619521, 1.4573789460043756, 0.09962423404137935, 0.08950012165211862, 0.1793552790918658, 0.6489199243726269, 0.17860000832907616, 0.18414092310253652, 23.404531786518714, 58.689271711534076, 64.24412058245751, 62.2177888501075, 45.22968592182283, 34.2059390775619, 63.3317498237856, 39.61852750470562, 11.954805735618839, 32.9589666089704, 26.639857638266783, 66.79166470804523, 66.49581601542812, 3.494344714187807, 0.34540351900842886, 0.5005107976255879, 11.59095883369446, 95.75847825696393, 78.56766331580378, 6.448049535674434, 1.2069298495208065, 3.611085237033906, 24.281356065504013, 37.96071813952538, 2.4854248137243333, 7.025027736540764, 72.5483234467045, 73.36325860792591, 51.5295615503865, 59.514055944258175, 58.249346517747455, 64.97939240547919, 89.21896934509279, 54.29769585209509, 0.2998173345000513, 0.27323969129112463, 0.18268900262492319, 0.22751694394936486, 0.1936484113215439, 0.32518057513140863, 0.2145114523028174, 0.19941884603711868, 0.14367317119913717, 1.6539047682477583, 55.65716581959879, 83.74653339385986, 75.90623317226287, 65.837767816359, 56.90502082147906, 59.169777747123476, 60.13388064599807, 61.449906441473196, 69.92832137692359, 70.57129198505034, 68.01301233230099, 61.210994874277425, 44.255039691925056, 42.98269341068883, 48.823785089677386, 62.89529984997165, 64.63075645508306, 65.13655785591372, 68.90249606101744, 70.88164560256466, 68.2321237748669, 69.0473727257021, 60.01526817198723, 58.83702739592522, 56.95831406501032, 66.75080145559004, 68.41381580598893, 73.01003348442816, 66.09040767915788, 63.187261473747995, 65.63054900015554, 67.78564037815218, 60.81129750897808, 64.66678342511578, 60.90639145143571, 63.27236906174691, 63.22606548186272, 67.50265705970027, 67.38862591405069, 67.32542868583434, 70.28820668497394, 63.025220517189275, 55.91363391568584, 63.67192522172005, 57.73120534035468, 63.22666168212891, 54.36679624742078, 58.56008452753867, 57.50091514279766, 55.67613832412228, 49.44508852497224, 54.76211624760782, 54.85478616529896, 52.52147797615298, 54.2630377892525, 57.16303825378419, 52.80571253068986, 53.66961063877229, 53.55263771549348, 54.27433421534877, 50.187051911507886, 54.84621970884262, 52.20972407248713, 55.16449651410503, 52.22946928393457, 51.139450457788286, 52.11982727050782, 54.69145474895355, 52.07333149448518, 50.997590095766135, 55.312358102490826, 53.004698291901626, 49.716818563399784, 52.084408267851806, 51.264817253235854, 56.671667252817464, 55.20453999119421, 56.89709371136081, 54.911617386725645, 57.50645745185114, 56.10912876744425, 62.98507505847562, 53.83129073727516, 63.224041538853804, 62.52298847321541, 60.24316964610931, 56.630376462013494, 61.5474557876587, 53.27259617467081, 60.73838064747473, 53.694953072455625, 55.47319096903647, 50.95989611841018, 54.34018296580161, 47.4532893396193, 49.408057428175404, 46.86573397728705, 45.55921208473944, 44.86155971404045, 49.96729327786354, 37.92473823793473, 38.10788939076085, 41.60459218486663, 34.54560456737396, 31.147570956137876, 14.602958656126454, 4.7882260334107185, 5.43352751001235, 0.36094005790448963, 10.53788677338631, 33.00308935103878, 57.732813512125325, 70.60354955734746, 70.94962812239125, 70.26352713184973, 73.82086584644934, 68.29525040042016, 68.49066288240495, 66.25025995316045, 71.67423109854423, 52.871400463965635, 45.64368424877044, 57.48668870618267, 20.796630228719405, 14.09905666305173, 2.428497494228425, 0.1769958815026668, 0.23916578581256254, 0.3140739856227752, 0.2762483943614268, 0.2421403060396833, 0.25508814190904944, 29.09906802638885, 73.40138404600083, 75.4077156128422, 75.55922108311808, 59.23278670157156, 43.06563585035263, 73.76923176550096, 50.29214397553475, 31.16011665713403, 51.90434009798112, 51.10558863609068, 106.01739821895477, 93.80583609304121, 8.32810284629945, 0.5252137011097324, 1.533026390018002, 21.580015805459794], [84.66147330499466, 43.97064039784093, 9.834287108913545, 2.457226404259282, 2.7968980227747275, 12.10259574074899, 14.26609766098761, 2.3388311314967374, 6.306034730326745, 28.26431901224198, 54.83537043294599, 36.07532893457721, 54.63054426254765, 44.62742559371456, 48.254213794585205, 59.71640317670761, 43.577807180343136, 1.3059606258907628, 0.22585395092685379, 0.13278125484864559, 0.17368350117917986, 0.050997454222411885, 0.06297136251364024, 0.020131746855294032, 0.18626638808317725, 0.3016365481720817, 10.53936452634873, 62.50725584645426, 69.78382125977548, 44.37006319722822, 30.92922437575556, 29.029181195843606, 25.163606943622714, 27.549712196473156, 33.02984776035432, 41.365994407284646, 49.44481003669001, 46.90606378739881, 36.680487894242816, 33.59658318181192, 28.690102100372318, 20.57741484334392, 34.881830138544885, 50.062081275447724, 60.56757319358088, 59.42621054187898, 65.60032321560767, 62.11442655132663, 57.02092293770083, 51.218768627412864, 45.23260808760121, 47.68528969057145, 52.72516273683118, 57.233891948576904, 58.72125471791914, 58.20757327541229, 58.09793910672588, 56.12010355918638, 58.0664973874246, 57.403938462657315, 55.14097013781148, 58.58022589837351, 58.27043317979383, 57.81406933261503, 62.298883853420136, 55.751428219579886, 61.621678798429436, 64.53752956082745, 53.60469933479063, 54.91195078819029, 53.62238137952743, 55.40779721352362, 49.370826290499785, 51.19394786896245, 52.982325092438735, 45.97164146361813, 47.01855736394083, 47.813237405592396, 54.17721632988223, 44.44898520746539, 50.469752819307395, 48.07398480753745, 50.033553877184474, 47.337096968004786, 50.88234301536314, 50.26770368699105, 52.16981395598381, 48.82092568182176, 52.35181585434945, 47.9612401993044, 50.48699948095506, 50.777074444678526, 46.807996688350556, 47.22448572035759, 47.07026596992247, 48.69716313577468, 49.12878859427668, 41.64693809324696, 49.21744200491136, 44.91581393826393, 42.472232234093454, 46.43309654728059, 46.828251807920395, 48.097024809929636, 50.29867079950149, 49.0269011066806, 52.39846852517898, 47.55899721576322, 54.76646615612892, 55.07472130560107, 50.90095466183078, 57.69099320134809, 50.350736341168805, 52.399633469120154, 53.27188622566962, 50.43070562424199, 50.49411858281782, 42.04925560182141, 42.65146493911744, 41.166283007591005, 38.887225120298325, 38.96694729405065, 35.50884846718081, 32.55022621923877, 33.322974328071844, 33.158509346746634, 23.069229933523363, 16.291055583184768, 28.52977914194907, 36.14144832857194, 31.93792070111921, 11.865204091994993, 2.340348843605288, 2.108120014590602, 1.706237889105274, 0.23664161803260927, 3.0603038111040672, 24.626652117698427, 35.47142121099657, 39.5459597341476, 60.23764302653652, 63.33782557518252, 61.38094332910354, 62.00170155494445, 57.636287904554806, 62.07366528049592, 60.47100836230863, 61.583812236785896, 65.19772329638081, 54.975230386180264, 47.112482440087106, 19.80688875721347, 4.455890963154455, 0.7598079031994267, 0.1213902705198815, 0.10518008752936318, 1.6434739602188912, 0.3639478723127996, 0.11890705013948104, 22.26383005419085, 45.23335333793394, 51.52023415411673, 55.58460589378111, 31.674478630865778, 29.701653911221413, 29.21662538282333, 28.62053494299612, 15.72192555473697, 11.560799729439521, 8.628155339148737, 25.65118697381789, 9.580136153005785, 0.26315546143920193, 0.22015338342997337, 0.14887106244362172, 3.7787084617922386, 88.90607403170678, 43.50489424120995, 4.798823787320045, 1.5828581418721908, 5.129965476451382, 9.89921998593115, 13.910947634327798, 3.982130668817028, 9.641635975530072, 48.35656412186162, 61.818679840334006, 37.277288283071215, 53.6439230365138, 51.83090156124484, 55.203626078944055, 78.41094109319872, 57.979377623527284, 1.2081210243125116, 0.20140215574252993, 0.0910473358066332, 0.08104040422627042, 0.026031956865241932, 0.07106785467194934, 0.0595979709478636, 0.08603659218117114, 0.16307333664548013, 7.122858022489856, 62.81857044466081, 79.87954708837694, 59.41552600552959, 48.1130398473432, 41.8726626519234, 40.25493598753407, 44.17066950951853, 52.275906224404615, 57.17120070611277, 65.7086786916179, 61.22881027960009, 52.65868248478059, 42.465152355932425, 42.34627316074987, 33.91919420611474, 46.16284916477819, 59.09596266285066, 59.61772026554231, 64.0914737024615, 66.9719054622035, 64.37249583582725, 62.82468149738928, 55.9099978785361, 51.23658011036535, 51.15104498401765, 58.622669866008145, 62.00564353696762, 62.45894793541201, 59.99157313377627, 62.52085470384168, 60.082630957326586, 59.44680298528364, 61.41725663215884, 58.518056331142304, 60.17348873999811, 58.89940484877556, 59.81621573048254, 67.18031667893933, 58.87658057674285, 65.8622355614939, 66.5228803696171, 58.087595816581484, 57.62221836274671, 58.11966903748051, 57.10292793089344, 52.0346490798458, 52.68985356053999, 54.43757541718022, 48.74253711392803, 51.259843687857355, 51.461175026432166, 57.38526013589675, 48.181512663441325, 52.570158512361594, 50.45833872210596, 52.50436075272099, 51.62693831228441, 54.4566342138475, 52.93957125756049, 53.363348053347686, 52.28393531614735, 54.463110047002, 52.51709276630033, 52.670794763872706, 51.5781008812689, 49.983206333652625, 50.12553345772528, 49.25968985403738, 50.45988805832402, 50.2788471406506, 44.572029959770944, 49.75378297990369, 46.56000483420588, 43.379841235376176, 49.64551379603725, 45.69978983171525, 49.43544341671852, 50.1443608345524, 51.092613435560665, 55.33779075068813, 53.71638490307716, 55.950766994107155, 59.43034864241078, 52.80413966025076, 60.480775064037694, 52.698467085438395, 57.00106005514822, 55.49385401510424, 55.415441912989465, 52.53044843673707, 47.78774984421269, 47.17874696177822, 47.89071990597633, 44.939305013225926, 45.87810470211891, 43.785147590021936, 40.48477119015109, 41.036350573262865, 39.047144074593824, 26.937204676289713, 22.858985008731967, 33.37188628412063, 33.621164675681825, 33.23688614752985, 18.67286878247415, 6.165856574812244, 2.2410145738432488, 2.449461337058775, 0.23743249656211948, 5.354216204535577, 33.92177512568812, 42.370129016137895, 50.140862080358694, 69.26766872406006, 62.199565518286924, 69.18284354671356, 62.67879678357033, 65.79782239852413, 62.33743682984383, 70.29799692092404, 62.791066785012525, 68.2795452302502, 55.94242411275064, 43.86106898707729, 20.74715345136581, 6.022217908213216, 0.438097246712254, 0.040738311175617485, 0.35666911772662596, 2.5677310939758056, 0.3875207348215965, 0.031538355547273834, 33.455079755475445, 56.958945566608065, 63.72131570692986, 65.10431989546746, 43.331015571471184, 41.1201520119944, 36.964993092321585, 47.00560177526167, 19.697299695784046, 23.49840194948258, 35.86643134394, 47.197633174157914, 11.214765291060171, 0.22077786766232985, 0.07365807455273406, 0.3451502503406617, 7.50308572284637, 112.6407281814083, 86.5468389757218, 30.145030790759673, 8.258056179169687, 14.452981929625235, 36.234608542534616, 26.124116951419463, 8.785972883624416, 32.344935247975016, 81.04565989586615, 73.20182954111408, 48.433211157398844, 73.05885914833316, 64.76281873641476, 62.05147251006096, 87.00643093355241, 72.02581667130994, 1.2407645823494082, 0.1800173169542705, 0.18958767034834434, 0.20734330549115138, 0.08959098734081754, 0.16741907764827052, 0.12064516574384705, 0.21109853060014788, 0.3767377714956961, 14.544981122016909, 74.41515984073763, 81.61493701319542, 76.75852498700543, 64.11169352069979, 57.18469758187571, 54.04933137278403, 56.8293426113744, 59.38318606345885, 63.92744410422541, 72.07141030219294, 69.99098516279652, 66.87561127447313, 61.79111734513314, 61.75116016018776, 49.90349200464065, 57.06975644634616, 68.52147702247866, 67.09356954020839, 70.69661171205583, 70.74862234054073, 68.12883992348948, 68.41038765445833, 59.62837734530049, 57.83289278707197, 55.07559599414949, 61.93786498039, 66.39562299174648, 68.66547507624473, 63.623962479252974, 65.1868308744123, 64.95176715235557, 64.80024207022883, 65.2588063670743, 65.2446936791943, 64.18973692001836, 64.46527557988321, 63.33553098863172, 69.2252286787956, 60.61934063511511, 67.62319149509554, 68.66684790580504, 61.670708425583385, 60.09872836451377, 59.11886538228681, 59.472176797928356, 53.170500801455596, 54.1608129778216, 58.78169059753419, 49.205827866831136, 52.328748395366055, 53.323041777456964, 61.0153901961542, 49.44476296824794, 55.1343648664413, 53.84876489639283, 56.30712609137259, 55.12979138282038, 57.977255621264064, 56.42056888149631, 55.684591031843624, 53.67392524596184, 57.223179955636304, 54.316174137976866, 56.00049872552195, 56.84252177515338, 51.65563829483525, 53.35024341460198, 51.89170222128592, 52.64477376014956, 53.98625573804302, 46.94795470083914, 52.45349937869657, 48.08874860886605, 48.03846382325696, 50.53949256097117, 50.47572266670966, 50.97289093079106, 54.34414063730548, 53.877833581739864, 59.286017187180065, 54.20371194039622, 58.50335921010664, 60.913259521607436, 55.14626141517393, 64.13875003014842, 54.50376541383805, 61.41078864374469, 57.75015431065714, 57.120719801995065, 58.63397413684476, 51.95456604803763, 50.795152648802734, 53.20286427774737, 48.66520366361065, 50.95272210336501, 47.4626402701101, 45.36681982778734, 47.467496164383434, 49.211483924619614, 40.40982646326865, 30.995657559364076, 39.388872731116514, 39.04935629137101, 37.726399667801395, 21.471530891233876, 9.347641583411924, 3.407904991219121, 4.191520271762725, 0.786578631208789, 11.470628361548147, 45.36190117559126, 46.47975706285047, 61.92974959650348, 71.673611364057, 65.48158130338116, 67.88984990889027, 66.22663159524241, 66.37364987404116, 62.81141211909633, 68.25277113145398, 62.87540558845767, 78.9072621253229, 65.27992833045222, 59.86649659372146, 31.450430885438, 7.54123273395723, 0.6127003904792571, 0.14645741050762517, 0.4002912979452841, 2.5935853969666267, 0.9559227345931915, 0.12543007431011047, 45.995089392508234, 70.34991341252481, 74.58799516001056, 76.87894175129553, 52.53899920371271, 49.285965811821725, 51.66231024649836, 66.61095326946628, 38.25402905864101, 43.35515775988179, 64.51453270450716, 69.01620557231288, 15.386558982633776, 0.6147250689325795, 0.33145694963393674, 0.8074783065146016, 16.55601070773217], [81.1771926572246, 58.58653699198077, 29.45096346639818, 8.522845583577311, 9.715036269157164, 18.945253856720466, 18.708634914890414, 2.0499054222337665, 11.432795140051073, 26.999405622482303, 50.941484512821326, 42.629923282131074, 42.725695794628514, 34.640239592521425, 47.93711370037448, 62.177274688597656, 37.948943184268096, 4.39842039538968, 0.5541221821500409, 0.21212868903192783, 0.05469018570898522, 0.13863261909254138, 0.0524525041691959, 0.03571563956117438, 0.03088944651667149, 0.5409550919167457, 32.14569453270205, 81.29244758236794, 71.08141976018106, 47.882498618095156, 34.08132145481725, 31.5734972107795, 28.156644067456646, 30.738269667471613, 33.995005776805264, 43.7240017614057, 51.896287472017356, 49.23643412128572, 47.75140123982584, 46.02553090741558, 40.95073307714155, 25.3180443856024, 30.87598212303654, 43.958987036058986, 51.21779587961013, 58.25058990909208, 63.67676150414252, 55.99132822405908, 52.62748003005982, 44.55303784339659, 41.79493304221861, 45.64317041827787, 51.773097592015425, 57.65062808990479, 60.12192918408302, 58.08079050433252, 58.44869313701507, 58.59984559397544, 57.30298842153242, 56.64084919037358, 52.987855634381695, 56.428386165249734, 56.76656507676648, 54.49528132715533, 60.01609971446376, 58.53713866203063, 64.28504659283546, 56.84261198966735, 55.41268448675833, 58.66271334309732, 54.71827983856202, 50.50680745032526, 50.14854600352626, 50.698470146425315, 49.14703153794812, 47.91463067454677, 46.593239076675914, 49.748534848613126, 51.80286053688296, 49.860440069629306, 48.44004392623902, 45.0207491074839, 45.152277946472175, 48.11238088915425, 47.013587720932506, 48.90222857075353, 50.3738744028153, 50.92306506249213, 52.13620708834741, 50.33332101760372, 49.53357327368952, 46.63591054178054, 47.27426452021445, 45.832067843406435, 47.93531725483556, 42.906505292461766, 44.80868616411763, 47.29569242846581, 47.029226210809526, 47.73413888869747, 41.79598031505462, 41.87287838228288, 44.552880948589696, 45.90056027135542, 47.6755347559529, 49.56858434984761, 48.13276544693978, 52.35861332185807, 51.99837107812205, 58.08606216984411, 52.52964042848157, 53.20084033473846, 51.228841274015366, 50.8500736759555, 55.190501828347486, 48.58963920224098, 44.59414428280246, 41.24297318920013, 42.740957736969, 42.55601013860395, 35.991060733795166, 38.29899511029644, 34.031574033921764, 37.73675080268614, 33.42923525841006, 21.748312942443356, 14.208258390426638, 12.78245427916127, 24.489198538564867, 25.463650611139116, 21.262033177960305, 6.4933455567206115, 0.9233571336634698, 0.9607660650245605, 1.1421923555674092, 0.38836281866796557, 1.2017884802433754, 20.812751170127623, 41.44699135134297, 56.94680975329492, 57.28218024776828, 61.90177133006435, 59.22947622114613, 62.85282842574581, 62.91408408072687, 61.86719563699538, 57.85350091995732, 65.68422271359351, 68.23016258978075, 39.422428607940674, 34.40555241800124, 19.62622634826168, 4.542465027301542, 0.6293894626921224, 0.15014909628418185, 0.23272153080230762, 4.648611228312216, 0.056316065602004535, 0.38841243052194196, 31.354440681395996, 47.49093624853319, 56.88938233160204, 55.878917017290675, 29.52336257503879, 19.40069986927894, 26.57454429134246, 16.14543857113008, 8.591588062624778, 8.612377605130597, 3.038794758819765, 2.6644770897203878, 0.20753116557194343, 0.18371416616343683, 0.28730629132159297, 0.3977453732682813, 5.220623218244122, 92.39278654898368, 58.972223651024606, 9.78999178255758, 5.188796616369679, 6.481220529925439, 18.064499362822502, 23.08954388864579, 4.9912998849345795, 20.577958091612786, 49.69986607951503, 68.96660327911377, 39.22676901663504, 54.05061006546021, 43.10517726405975, 46.60425309211978, 80.15762744411346, 63.462007814838046, 4.450782076005013, 0.21442385780955517, 0.08881487898648747, 0.056393934609068025, 0.05011303252690742, 0.015424878708267165, 0.02596235394688143, 0.041670295439900897, 0.6115201247795936, 34.59612469519339, 86.45225494138657, 79.6424162772394, 64.0059111195226, 48.48955992729434, 46.49995726923789, 42.40814462784798, 45.32894934377363, 48.16347368301884, 57.592663303498306, 65.18865477654242, 63.684931801211455, 60.41442817257297, 58.35647429189375, 54.304548232786125, 37.26540742381927, 39.93006567801199, 54.540074794523186, 60.661455123655266, 63.76550905166134, 67.85506633020216, 59.41519260406495, 57.76928370998752, 51.62109005835749, 44.367399907881214, 50.16078379846389, 57.755312227433734, 60.655073427384906, 62.20798684704689, 62.89558226062406, 61.62362821640507, 62.70286052457748, 58.71330015120968, 58.84572329059724, 56.571646813423406, 60.6974232581354, 60.03738249501875, 60.21419509764641, 61.54139964811264, 61.709343771780695, 64.53343460636755, 59.99680165321597, 59.01413025394563, 61.922195111551595, 55.6889723193261, 52.382477021986446, 52.08005051459036, 51.093397909595126, 50.25537959990963, 50.621936859623084, 50.044873837501775, 53.30259838411885, 53.85641351822884, 54.01700712019398, 50.88325300524312, 47.18938835205571, 48.68158740382041, 49.2995293678776, 50.23263377528037, 50.35385854782597, 50.113848716981956, 52.51165243887132, 54.30644665994952, 52.87242420258061, 52.06732634575137, 49.792551686686856, 47.390213704878285, 50.03661724828905, 50.018327236175544, 45.17753016564154, 47.37665407119259, 47.62008813119704, 51.22818623819659, 50.16927180751678, 45.38053635627993, 43.91440537668044, 44.52666382635794, 47.748910534766416, 50.633966768941576, 51.68218097379131, 50.92197072121405, 56.05057170314174, 56.361133206275206, 56.76214456558228, 56.07888729341569, 55.97735674150529, 53.969275797567065, 53.55281814452141, 57.36592285094723, 52.148272298997455, 51.23265381782286, 46.240884719356416, 50.16210171484178, 46.495972141142815, 45.85168753900836, 44.804846163718935, 44.719895470526914, 45.91145269332394, 42.183628159184615, 29.099119017201087, 23.76386207918967, 20.366265812227805, 25.596152197930124, 29.65119850250983, 29.459180831909183, 9.562261912130541, 1.4440840723053103, 2.807996614325431, 2.3500348915976863, 0.47342591228023656, 4.849725365638733, 34.98956980243806, 44.912562293391076, 54.97673265395626, 66.12891750950968, 61.80931322036251, 65.44416581430744, 63.11428577669206, 68.23942722812777, 64.38569068908691, 64.59540413271996, 66.77254707582536, 77.55014557992259, 47.10464554448282, 47.86184341676774, 35.17603928042997, 4.414933083518859, 1.2200901368933341, 0.02370126842100534, 0.628150484013942, 4.495561324780987, 0.13806032076958688, 1.650682296003065, 43.465203777436294, 61.38481078609344, 66.7704995985954, 69.22533066042008, 39.264415925548924, 29.50319374761274, 36.0235026574904, 24.547724223905995, 19.380634984662457, 18.33032819532579, 16.886925389689786, 8.144289303210474, 0.19777711961538563, 0.16147176855273787, 0.0367680566775943, 0.5371853877459803, 7.352440232230771, 113.41347432905629, 91.44046645010673, 63.635513859410445, 16.280745633186832, 12.639230893504235, 44.93106411349389, 52.8308980695663, 16.874152191223637, 40.60053210104666, 77.21205296054964, 76.96509268976028, 53.26544569384668, 63.06567584314654, 50.81219142483127, 62.73876197876469, 86.35160692276494, 84.44435442647627, 6.252591456136396, 0.6010806752789406, 0.47862835408699134, 0.11930314057897176, 0.15784504703216015, 0.14496747674720903, 0.11820372779883685, 0.21591935336830156, 1.0483196185481165, 46.48063175139889, 88.90513266286543, 83.81956008172806, 77.04578368894516, 66.51486304498488, 66.46929294832292, 56.41553255819506, 58.411458076969275, 54.79447187915925, 63.52544823000508, 71.18807684990668, 68.32203234395674, 69.09748492702361, 68.1587048499815, 64.99537606393137, 53.37040047491751, 51.307853498766505, 66.32880933823125, 69.45281244093373, 68.62164651193928, 71.2660143452306, 62.11748992243121, 66.36236913742559, 57.05333740480485, 52.69257568543958, 56.246709823608406, 64.37801461065969, 68.02276334454938, 68.38181711012318, 65.72498006205406, 66.67393084495299, 64.87480632720455, 62.47766940824447, 63.50516173147387, 60.893934003768436, 62.50735390570856, 63.105946817705714, 62.19872613107005, 64.67486350767075, 62.001544660137554, 67.95020734110187, 63.78406578494657, 62.750168231225786, 65.46753137342392, 59.45072143308578, 54.7807788848877, 54.37688850587415, 54.93041338459138, 54.7476113227106, 53.0772856743105, 53.12324408561953, 54.285760079660726, 56.920031732128514, 54.819877070765344, 53.4985835321488, 50.07614297251548, 50.339055522795654, 52.23987140963155, 53.611783135321836, 53.74189992104807, 55.89801896002985, 56.02764544948455, 56.6332241027586, 56.67261646639917, 56.453053951263435, 51.90139439798171, 52.77613393722042, 50.4557538801624, 52.40640348003757, 46.82222312496555, 50.63671635043237, 49.753563327174035, 54.92965636714813, 52.5687974499118, 46.12145639234974, 47.46046727703464, 47.46910433615408, 49.67284879376812, 53.786359986951275, 55.54273851456181, 53.36174772631738, 59.10445067190356, 59.60203078485305, 60.35028957551526, 59.51325970311319, 57.154593390803186, 57.52066427661527, 57.90901814737628, 61.55418265250422, 55.03883161852437, 55.690454975251235, 50.73493642191733, 54.631140462813846, 51.6728457327812, 50.18572615038965, 48.887292185137355, 49.99955869490101, 50.815497982886534, 51.06308583290347, 40.57025924805672, 32.9411708154986, 30.609364894128618, 35.536905181023386, 36.530982832754816, 35.16322097470684, 11.649873814275189, 3.358573341561902, 3.9909594337786403, 4.023983339148184, 0.8968373760581018, 6.735273916875163, 42.91435395517657, 58.96248048351657, 63.62800252053046, 65.79759490105414, 63.4488090392082, 69.18461645803144, 65.97796117105793, 72.31387553676483, 67.3306768171249, 67.60659986926665, 68.38513543528896, 79.75217203940116, 57.40336579661216, 46.63656557759931, 46.72913351366597, 13.459337699797846, 2.1109605460397662, 0.27754473770337723, 0.9868237796810366, 7.9239467267067205, 0.23096460007852126, 1.7819724832811665, 57.9513797452373, 70.08776572442824, 77.84216603925152, 78.51776292247158, 49.21125250477945, 35.502709957861136, 60.975484002021055, 41.76358545980146, 35.844709257925714, 31.44837360228262, 22.330023973218857, 9.200795888900757, 0.3588805990594049, 0.42494391541807885, 0.6122861514168402, 1.0300402703785128, 10.104583521043102], [59.88929340916296, 66.94728866700204, 28.865620320843114, 32.45088631106962, 13.264537107559944, 22.071737858556933, 18.353919290727188, 4.084410883726613, 11.961348249066262, 18.10176972419985, 50.6358338171436, 46.04874741646552, 36.43144484489195, 34.67619595989105, 49.25322578799341, 70.16351453719601, 48.818383985950106, 9.868179328979986, 0.596360225350626, 0.3660882606862053, 0.07353436667472124, 0.2565537600387489, 0.03225932663847362, 0.1540120486770907, 0.20112611894165316, 0.90439229001922, 27.064322810019217, 72.3820855540614, 68.70445559101721, 46.06931632564914, 39.51768336757537, 41.24464804126371, 37.67805253305743, 39.464480338558076, 41.134778530366965, 46.6060063915868, 56.17920191057267, 54.66543766760058, 53.39703729075771, 47.45937293575656, 45.61802802547332, 35.796087557269686, 32.194147571440666, 38.18011983748406, 47.53842046183925, 61.12574215858214, 61.27877735322522, 56.47753738587903, 48.147478257456136, 38.802717654935776, 38.45902389095676, 45.83540578042307, 47.71501341173726, 55.13236053528325, 53.77788374500891, 57.11318492889405, 57.58493231188867, 58.25274721268685, 56.0846100314971, 59.51317733333957, 57.7240901608621, 53.398814124445764, 56.401102158331106, 57.79040567336544, 51.75509783529466, 59.8133445555164, 56.18934515983828, 57.76034462836481, 56.47486232942151, 58.70565152937367, 53.84685470211891, 51.8108033364819, 49.30425190156507, 48.86156143680696, 43.712909298558394, 45.33828458478374, 46.387181282043464, 46.96305974837273, 47.22241863127678, 49.620261576867875, 49.085544463126894, 46.82018741484612, 45.20435133287984, 44.68510404709847, 44.87069883654195, 45.00815437686059, 45.11498012850362, 50.87644377062398, 50.46926252303585, 50.98922368018858, 42.95328347913681, 45.73245140814012, 44.4596815109253, 44.39484473197691, 42.92770962561331, 43.06288626886184, 43.02717701081307, 43.93278952567808, 46.99332867899249, 47.40518146945585, 41.67570083372055, 42.856408780620946, 43.085643860601614, 48.08957622897241, 45.842975954855646, 49.75641881265948, 44.63461137587025, 51.95618598691879, 55.004695230914706, 57.12252409227433, 53.92418030769595, 54.19045825158396, 50.09060867371098, 46.672910259615996, 49.7752893355585, 46.664963537646884, 39.231146381747344, 42.76653943523284, 41.12058347271335, 41.16205469254525, 37.66765040736045, 40.084061853347286, 37.894857621962025, 43.455825390354285, 33.21827842343238, 29.738765416606782, 28.731377201695597, 18.581324585022468, 21.973880606312907, 25.064480804627944, 16.544851564591934, 3.458009347800286, 0.3703514480542752, 2.6533914910208796, 1.6977411772935622, 0.8105614733311438, 2.0679757816176263, 15.003351261538846, 48.87062211190501, 60.843504090462964, 56.06473538183398, 58.13193821137952, 57.09838974860407, 60.613072687579745, 59.54924352707402, 63.89354305882608, 62.87786491455571, 63.32283427638393, 64.75070645732265, 54.96588730042981, 35.092057412670506, 19.637244286075717, 11.618514464747522, 2.7497697645618073, 0.5406030591937804, 1.4968842003614673, 2.605729300168253, 0.33885570423256967, 4.885411089466465, 42.204342196064616, 53.361335877449285, 61.60688754050963, 53.20655522807952, 25.730693417210734, 29.437941197426092, 18.341618737866803, 8.971831452461982, 3.3942431307608083, 4.2671680834985555, 0.48897118457863414, 0.3630012634300417, 0.09479349043460623, 0.40391734530848844, 0.16378287195919022, 0.24213013239204886, 0.7017866714346794, 98.98382756017871, 73.15341964844735, 18.740998391182192, 11.19286964016576, 14.727831232932306, 25.884654291214485, 33.90249667629119, 14.879901524513, 27.64206244099525, 39.95793804045647, 68.2569053096156, 40.4837356844256, 42.18489900712044, 49.52603447821833, 49.4681324497346, 80.73190166104226, 74.00458182058027, 23.182276564259684, 0.19711607766728248, 0.020744619109938224, 0.035629443178373965, 0.03443803472985183, 0.026640772684327057, 0.07739043959807004, 0.30413454638854154, 0.5542697613277744, 40.18692993348645, 75.1203235503166, 78.465760138727, 59.5359427698197, 52.84574031829835, 52.94272484317903, 48.99456116460985, 50.3282376258604, 52.90508970137566, 57.0787622082618, 66.10959591404085, 65.81407670051821, 62.18676682441466, 57.897757022611565, 59.35136387425085, 45.48563626504714, 42.750132160802046, 51.97116551860687, 58.97182356926703, 65.02916728296589, 64.8238076702241, 59.106451080691436, 53.501697894065614, 48.34199251667146, 44.62398567507344, 52.16009040032664, 55.52480936050416, 61.441704765442886, 60.48926699546076, 59.938762341776204, 60.86976435876662, 58.42917542303763, 60.65081765574794, 62.21351738898986, 60.93200452866093, 57.7676441592555, 61.210834057100364, 59.79212845525434, 56.524241047520796, 61.782080204256125, 60.42918412916122, 61.725621607995805, 58.85252075810587, 62.181608907638065, 56.517733835404925, 54.867561324950195, 51.05332697591474, 49.88040101143622, 44.830859322701734, 48.7727628984759, 50.189781881147816, 49.32837840049498, 51.83356485059185, 51.47500530365975, 53.42980869354741, 47.49600787316599, 47.44823732683736, 46.440078366187315, 47.68547011959938, 48.22666306649485, 49.56614855797061, 51.1280010592553, 53.49026418501332, 52.09346502057968, 45.715094920127626, 49.224565029144294, 47.416524963994185, 45.737632859137754, 45.736350244091405, 44.61151253792548, 44.046008740701986, 46.428260264858125, 48.900859663563395, 48.277622499773585, 45.09003777657786, 43.6242990339956, 44.52920159985943, 47.16594434553578, 48.670463562011726, 51.96370124816895, 52.18706846237183, 54.45973288628363, 57.20605488746398, 56.955807670470215, 57.19930056602725, 56.656687721129394, 55.13553373275265, 48.191228374358154, 54.97537551387664, 49.48388076597645, 47.24900445630474, 46.345447263410016, 46.67898601101291, 46.23732712961013, 46.15359237117153, 44.13463861711564, 47.43929824521465, 46.20468516503611, 41.48827037503643, 36.80503099195419, 38.86286327915807, 28.283748472890547, 27.1251783832427, 33.748673085243475, 21.876317531831805, 5.619801850088182, 0.7334201578651706, 3.7809983905284636, 1.516836194261428, 1.604385457692608, 1.1179616686797913, 25.799209379380752, 60.05687667477516, 66.32480067591514, 61.862233838727406, 60.931110228261645, 63.807090097858065, 64.05440338196294, 63.749968621038626, 67.11191054313414, 65.4463388073829, 66.82149825557586, 69.61348841267248, 60.9102039952432, 42.31073648698869, 32.531922478829664, 13.411861331232133, 3.4856169502581325, 0.19450328883624848, 0.5186514532373798, 3.1120793425267745, 0.47266325642985685, 7.017473741885155, 56.74528229621149, 63.26965870395784, 71.99543399195518, 62.39907687710178, 36.19805205252863, 35.74533993198026, 30.598437170828547, 20.09000151388107, 17.165005745426303, 14.181883392795442, 3.7222917858631384, 0.6318221289303996, 0.2228225716539929, 0.3363946314540602, 0.2635449405399061, 0.20222992906647347, 2.2941180727174206, 96.53574297505041, 94.52307285801058, 72.39946949866511, 57.00996383543938, 21.982688288534842, 35.01328837487006, 71.41013791484218, 40.51780931411251, 49.90664166788901, 65.97526258037936, 83.18628557266729, 52.353600532777854, 50.87095245238274, 57.93278771062052, 64.38682425406672, 89.47020499936997, 89.50953068271761, 27.385959125334217, 0.5486193419464174, 0.2777615405859486, 0.3488314253908973, 0.29351399370258857, 0.24838119534955871, 0.1672562073555685, 0.40908031826538427, 1.3207073894239243, 62.831016125217566, 78.78437426782425, 83.04354267735636, 65.86211789038875, 70.42454827216365, 66.42497801011609, 62.15962402282223, 59.51593475957071, 59.739906018780125, 60.762346329227576, 71.25230958384853, 68.91229414170789, 67.70507489481281, 65.7163312358241, 66.37981583995204, 62.1963530971158, 58.7893666759614, 61.77172122463104, 67.27936437053066, 68.76392656756987, 64.8828197294666, 62.547083593183956, 61.26553935389365, 55.57595314518098, 52.07246072830693, 59.624807988443685, 59.73306540519961, 67.01651850054341, 63.382799471578295, 64.42578123461816, 65.14490073727023, 64.91840739404002, 63.0227376568702, 67.59258131827077, 62.757852154393355, 59.081779372307565, 61.769316811715406, 62.926702345571215, 57.345781480112386, 62.894468307495124, 61.654108955014145, 63.77244772449617, 61.653187198023645, 67.05955474607407, 60.23002578366188, 56.99594136207335, 54.07760381698609, 50.694124160274384, 48.43953401811662, 52.15789779540032, 53.107197669244584, 52.980775756220666, 53.482282161712654, 56.4818206141072, 56.60601462087324, 51.597438166218424, 52.70282483869984, 48.58332026389338, 49.0800178435541, 50.047497903147054, 51.64955469869798, 56.21406393666422, 55.96571514683386, 55.41807382337509, 47.06439418177451, 51.82599859852945, 48.55393778893256, 49.431317083297245, 47.82192937789425, 48.719618705011186, 46.90725226556101, 49.189832441268436, 52.26289180017287, 53.51767763014763, 46.89697173333938, 45.979309697305005, 49.001660654621745, 51.550157916161325, 50.89824822641189, 54.97920766953499, 54.69191758863388, 61.29659668091805, 60.39776986645114, 61.76758312409925, 59.85522370184622, 59.29383839330366, 55.90187072753907, 51.18101973687449, 56.94131059031333, 52.67270103577645, 52.05183298357072, 49.89824779572026, 53.02374532145839, 50.91723642041607, 49.602952157297445, 48.053349218060895, 50.42790505193895, 51.652472942106186, 47.36416916693411, 42.1073615935541, 45.61224252946916, 37.37656739450271, 34.43303646579866, 40.12865527983635, 26.670524689459032, 11.361579606609961, 4.344064679837996, 4.621137967032771, 4.362442454984111, 3.416086074806029, 5.790863277450685, 34.31558109098865, 65.14191973593928, 60.337094722255586, 64.56701009504258, 59.90382971302156, 65.5098419804727, 63.754891195604884, 64.22202979364704, 68.24845652426443, 67.86092635123961, 67.94283328517791, 71.26239007519138, 71.83836660077496, 59.52535629272462, 46.7578060396256, 32.78687261766003, 11.702017803345958, 2.1075667152481694, 2.5720677644975725, 8.498304294001672, 0.7067726780810665, 9.939177170876535, 69.92470495162472, 74.23195377472909, 81.55141815062493, 70.4766216585713, 47.236209684802645, 49.8785614198254, 54.99875676247382, 29.777728280713482, 21.08937632653021, 17.08728986401712, 3.7638566522829, 0.43861760427394225, 0.3009061599450727, 0.7389622217705174, 0.6098245576985422, 0.6062509720363926, 1.3463004870760826], [27.590465622563517, 54.22263737647764, 40.18827138408538, 47.01383483025336, 37.43741512298584, 21.65372890810813, 19.918395857657156, 10.396099955804887, 12.233697041388481, 20.561860684425604, 40.86479786903628, 46.09378407078405, 33.72336987526187, 25.901310636151223, 55.29865334110876, 74.19610331135412, 63.40230934081539, 45.2486192026446, 0.45376831064781836, 0.17013226996266073, 0.1035895434418513, 0.2094801392165884, 0.06790211123804893, 0.26628165175357177, 0.6773023788006075, 2.5365521734760654, 27.96913123899891, 74.02398970819289, 64.23073353305941, 45.92020742354855, 48.823059451195505, 45.56694307634908, 52.94097938845235, 48.622508664284986, 47.906154432604396, 47.65321646967242, 58.50674813793552, 57.857521349383944, 55.51534468127836, 45.315817248436716, 47.12848963276033, 41.92697963406963, 34.80046841406053, 36.113379847618845, 49.45309408249394, 66.2680753584831, 62.46270164366692, 53.84827852249146, 41.870156257383286, 35.118305913863644, 35.763323999220326, 43.67604294130879, 49.36699021247126, 53.163016919166814, 52.69902798437303, 55.18586166443364, 54.362136471656065, 53.856978339533654, 53.532253157707956, 56.377038417323945, 54.14906155678534, 56.44780974234305, 57.75869331052227, 53.46717711417906, 54.915912382064334, 58.455172892539736, 55.51990639778876, 59.231908090652965, 57.54992123573058, 57.260042390515736, 55.12684960519114, 50.57093428027246, 48.782231500071866, 46.54110293234549, 43.86542281796856, 47.3523824445663, 44.9084359599698, 48.02865789782617, 48.338117214941214, 45.08712737791, 44.25818935517342, 44.73446707571707, 42.717294077719416, 48.45862811611545, 43.97455884564308, 44.601106489858324, 46.94662109498055, 50.678842606083045, 49.317340850830085, 47.3132215007659, 47.54935995224984, 43.800017295345185, 41.363138921799205, 43.215627285741995, 42.64800540862545, 44.22196626663209, 42.25260303866479, 45.004914499098255, 45.33939461554251, 44.965102441849254, 44.200491289938654, 42.87671096863286, 42.019092575196304, 42.68613869144071, 44.26789329897973, 45.322861825266195, 53.137199878692634, 49.1673807944021, 51.4687216666437, 55.06426426672167, 52.08871895267118, 52.75170933815741, 51.08449020693379, 43.69357593597905, 44.42171296765728, 44.63953787280668, 38.53625535964966, 39.85209288135652, 39.6611205224068, 40.56423448747204, 41.70643260402065, 42.81289400592927, 46.38725972944691, 43.27597295084308, 48.80934292270292, 47.8274912987986, 46.919799927742254, 35.93152699931976, 33.25928288121378, 29.967186604776693, 19.544401784096998, 10.602268557394705, 4.637888448853647, 5.629090512952497, 5.799544953530835, 4.969558187069432, 7.481060633736273, 23.805219550286573, 50.270112022276855, 57.788934784550825, 55.52199309872043, 55.318955529120664, 57.09258071837887, 58.93876191108458, 58.11266760672293, 62.84312840430968, 59.338612248820645, 62.56010978452621, 60.40293955033826, 64.84534540484029, 54.561667442321784, 49.56421090710548, 31.803732495154108, 18.141103252287834, 3.919881428441694, 0.654188035236251, 3.393632711902742, 0.41085491497670457, 11.422333198208964, 48.763494337758715, 53.304073195303644, 60.499398477615856, 45.51389694213868, 24.383378874871042, 21.853703106603316, 15.197374243890087, 6.344194489140665, 2.511338932860282, 0.34809049579405016, 0.43832688922843627, 0.11549677910102953, 1.1607161164283752, 5.615456354233527, 2.886553353840305, 0.6098179999859102, 0.842193917882058, 57.57053721335627, 88.6665976432062, 38.89093568248134, 31.388024014811364, 13.754046943879898, 29.828130737427745, 50.54940439039662, 32.78810031952397, 37.789314485365345, 53.90264649544993, 66.3641106697821, 45.913935553643014, 39.646415556630785, 38.009916428596746, 57.69205224129462, 80.51930135296237, 81.11973777894052, 58.784404877693426, 1.0322329978789053, 0.18261112212654085, 0.12010492053964447, 0.03034805792624191, 0.03929546883990688, 0.13965543840200673, 0.3473244385132867, 0.9346873289154423, 42.131695978103146, 78.54067740901824, 73.97921977504608, 57.13158084500221, 62.03750102750717, 57.09363191358505, 60.03159307664441, 58.944076722668065, 54.48022334806381, 57.69173060694049, 66.92107154477027, 65.31392351273568, 62.59942370076334, 58.0473130749118, 61.705244894950624, 55.49371673214821, 46.51423077429495, 48.77535950752997, 58.82889240018783, 73.43852889153266, 63.62998331746748, 57.41895721804712, 49.92274691981655, 42.15268850326538, 43.05743025195214, 50.50482665338824, 57.69440174102784, 59.4900510388036, 58.948869859018636, 61.1960937899928, 58.597535317943944, 56.171317946526315, 58.15233453627556, 60.32997169802266, 56.500122393331225, 58.69723804535405, 58.620900877060436, 53.33795070648194, 59.37348604202271, 59.024159754476244, 57.052097935830396, 62.83336170258061, 61.16090228480678, 60.62449462952153, 57.28643994177542, 51.22806464472125, 48.989144371401885, 47.30804397213844, 47.53989135065387, 51.379342617527136, 50.45276895646126, 49.9653713164791, 52.57002907414591, 49.36600569755801, 48.614542330465014, 46.369193292433216, 44.85054962096676, 48.45828686991046, 46.359136335311405, 48.10997647623862, 51.00317555089151, 53.017520519994925, 52.369521433307284, 49.94079374497937, 50.41943665473692, 45.93719520876485, 44.30263765396611, 45.55102609818982, 44.2667636563701, 45.05378723144532, 45.573826836001494, 46.47497177124024, 48.25697122081634, 48.727926285036155, 47.544103976218935, 44.15906321617865, 45.38285447705177, 43.68868474037417, 46.20980385811099, 45.13929490120181, 52.15639160525415, 56.35666954901911, 52.87775470364479, 55.361136697953754, 55.489104024825565, 57.052313666189875, 54.63605911500993, 47.33422187066848, 48.606878019148304, 48.24634159764936, 44.92536883200369, 45.83446833395189, 46.24088079698625, 44.92458435796922, 46.94528748912197, 49.743314173913774, 50.51428741024387, 48.3000623795294, 51.20935101662913, 47.812488232889486, 50.515091496129195, 42.077124041895715, 38.13558132417741, 35.51330427969656, 23.977743041130807, 11.96153554224199, 4.27951374361592, 5.413227283185528, 4.674794029804969, 4.8529029757745805, 9.426140958263028, 29.931753873825077, 59.31945539289906, 62.28631265701787, 58.54285747774186, 60.29078722000123, 61.58700896847633, 64.20810145716514, 63.75738974540465, 68.89522398671797, 65.45449341497114, 68.1017049666374, 66.73136218901604, 72.21896202333512, 62.61999653231714, 56.00099686653384, 34.9980931128225, 20.52525712597755, 3.5399606535511636, 1.177938140688404, 1.169805964154582, 0.22526096822994374, 15.507987718428335, 63.62576676953224, 62.763253258120635, 72.87697099870252, 52.044031389297984, 34.46918110693655, 33.02799640163299, 29.138560410468813, 14.072427691951876, 8.320040414410254, 6.170858087078218, 1.6401124889812164, 0.11649375060392965, 2.8235323871335676, 11.106363727200417, 7.329566440274639, 0.44674720675233875, 1.6360464620013393, 49.261596125941125, 102.98688873167961, 69.89294944270965, 75.69054203648722, 70.76695549872615, 33.27988709172895, 60.0735192914163, 64.22501863971834, 69.53857898712158, 77.00995675979122, 77.21175486041655, 60.60032890688989, 47.21798243061189, 46.389695521323915, 73.92150602033063, 88.90086512411796, 93.06254694538733, 69.20729560236778, 0.8489046029506192, 0.377867506035874, 0.284310152093249, 0.2507512875261807, 0.2514516757500749, 0.5657214274810207, 2.9116376465366733, 6.1790700593302335, 56.752832858793205, 83.51672172546387, 81.97787392523982, 67.43879302855461, 70.71023802603446, 61.94666285668651, 66.03099946052798, 62.47532383088143, 58.05133742670859, 59.300867280652454, 69.55051083718577, 70.7072413352228, 67.93228210941439, 65.24979276041832, 67.41320348555043, 67.23110352793049, 60.96379533890755, 60.143196275157315, 65.8113153519169, 79.05767717669087, 64.66590481419718, 64.06145972590294, 54.068080302207704, 50.20394948221023, 51.29618836987404, 56.40084328189973, 63.46607923507691, 61.1782705399298, 62.57858022566765, 64.25014926541236, 63.558764842248735, 59.22671095017464, 62.938469456088164, 64.33039311439761, 59.64738907352571, 61.098642503061605, 62.58268302486789, 59.22101174631427, 64.39231949467813, 62.87798650803105, 62.105926775163226, 63.41896372456705, 62.22593953532558, 62.62248723737655, 59.77394826950566, 53.26174297640401, 53.16222460039201, 51.006650770864184, 50.80914374320738, 54.14177771537535, 52.235007670617875, 51.62816601414835, 54.35902995447959, 50.46314362556704, 51.33456876201015, 49.21295089106406, 48.4220245576674, 53.74300602943667, 49.604627009361025, 51.74850825340518, 54.269109618279245, 57.926570753897394, 55.25119266202373, 52.48242293634723, 54.15510985159106, 48.35974908644154, 44.83069850552467, 47.530983647992535, 46.59796945510372, 48.95993840309882, 50.81817303934405, 50.35767893637381, 53.52913879579114, 52.00292887226228, 53.24973660130655, 45.292714488121774, 47.530250164770315, 45.20227639905868, 49.864491878017304, 47.02361329909294, 54.961286360217684, 59.83106582395492, 58.37761194475236, 58.72760895759829, 56.793876540276315, 58.85367393493653, 58.5284427673586, 50.29889829697148, 54.846651169561575, 51.98117540728662, 48.40370316659251, 52.687719791166245, 50.084077927374075, 50.15051895572294, 53.92776535403345, 53.66998326393866, 55.147697002657004, 51.94711354471023, 55.939533325933645, 55.40702842896985, 58.26089005316458, 50.217089422287486, 44.64335041661417, 42.902763351317375, 28.897981835949807, 18.264646145605273, 11.283797044907848, 7.480214382371596, 10.076930811328273, 9.691264744727842, 23.56223067929668, 42.444987450876546, 62.78867021683724, 61.60194927646268, 60.91819778565438, 58.08720357956425, 63.29209466134349, 64.59636511341219, 64.0289903456165, 69.23949041674214, 68.01078442604312, 67.11435810212167, 65.92089068505072, 71.28904650288244, 68.95316523890342, 72.49577153113582, 54.80330113441714, 36.021353198635964, 7.161980723181079, 2.932390416822126, 6.655707167040918, 0.6307637018542136, 19.608673741740567, 76.4551139646961, 71.2529371630761, 83.83032306548088, 63.36192461752123, 48.344710719200876, 35.490217208862305, 52.33761295195549, 19.733891487121582, 8.956673452931067, 5.754558799728271, 2.2237205986053716, 0.15421827954630699, 1.8871841795982855, 15.275343118175385, 14.746978282928469, 2.2072432118077434, 1.352662939217783], [6.291702389717103, 58.837423555312625, 35.84258333329232, 33.17491662117743, 43.21665102435697, 55.99425431220762, 24.36473192707185, 7.332881823662789, 11.970737422666243, 12.566737647979492, 33.0744529539539, 32.63369817887583, 28.03106938638995, 26.918647943004487, 48.60322237014771, 74.71729217037078, 74.37796008202338, 55.95747424710182, 3.0214828877679767, 0.25912856623049707, 0.21644694279999505, 0.09510019373509193, 0.05369724382856681, 0.033695534652759956, 1.3494489245837735, 2.0840219528444353, 43.89524852075885, 76.400663621964, 64.37841861478745, 57.16742346363684, 54.73517740926435, 58.13438577036704, 53.9672871558897, 56.39068826552361, 53.0748067363616, 50.11881835999028, 56.26342304291264, 60.91715835755872, 55.90190995124079, 50.15161721937118, 44.941191673278816, 41.549247541735255, 36.740931618598204, 36.77038469622212, 46.72647022431897, 61.148880220228634, 61.109817335682536, 51.662063137177505, 40.755865804610714, 37.40742075827814, 37.582825230013945, 45.698730791768725, 50.78790410872429, 54.34324241453602, 53.28601852540047, 53.59954534038421, 49.456208444410755, 52.12533820059992, 51.61971722879718, 55.46263979327295, 56.33079367299234, 56.691949828978515, 52.444348489084554, 52.37152576446534, 50.98658000269244, 53.8610105360708, 53.292035441244806, 56.66477957079488, 55.91383003419446, 57.25033452433925, 54.03441459901872, 50.02190051540252, 46.138856026434134, 44.77332991938437, 44.56922154272757, 45.28375971701838, 46.0211496199331, 45.15789085818876, 48.09575396199381, 46.4936932440727, 44.12359714508057, 42.904987335205085, 43.933138616623424, 45.17792240265877, 44.12806080233666, 41.847402588013686, 44.83072596211588, 46.18409272163145, 45.45492018422773, 42.877267945197325, 45.611748310827444, 44.351726116672644, 43.36225332752351, 42.66209456228441, 41.901460693728545, 41.38231538957165, 42.72176557971586, 42.17540687130344, 41.6080674048393, 43.09571258483395, 44.51739134327058, 44.859975076490834, 41.227934821959465, 40.70919352193033, 41.60475692441387, 42.298439856498476, 48.11342423962009, 56.73405647277833, 53.9000577311362, 49.77829387111049, 52.77399624547651, 49.53492649139897, 49.914588389858125, 44.161553921238074, 43.30017789717644, 41.71215534210205, 40.364836877392186, 39.53546739393665, 42.68172210262668, 44.725025930712306, 45.97405764364427, 48.092443481568374, 48.702328897291615, 58.04726208409956, 56.07025807903659, 38.912540097390455, 48.55989194685414, 48.361894622925796, 43.46866723029844, 34.683887727798954, 25.56843476910745, 17.876704123712358, 13.426786930330339, 11.986982899327433, 12.408420981899386, 18.352550383537046, 21.93121502476354, 43.124259594948064, 54.51590907189154, 55.66498702572238, 55.29111062326739, 52.30907770895189, 52.19670180351504, 54.63255643844605, 58.171969921358176, 60.17558328567013, 61.30680661047659, 59.57803372413882, 62.48158785604662, 65.14789742808189, 69.5156958795363, 69.10153281304144, 59.27715263059063, 39.78836221079673, 18.85951280593872, 3.3446754034488433, 0.6515235201485696, 0.0867234436314433, 21.43929881434287, 56.33824225394957, 54.11463099141275, 51.8283716324837, 39.61107892374839, 22.42834798751339, 18.34085975923846, 12.269374920475869, 5.294267679414442, 1.128385367412721, 4.260610861162986, 1.0761864651595394, 2.9804992675781254, 6.196678069330031, 8.784459829330444, 11.74449413053451, 8.044554706542723, 0.5306753564265467, 17.842910943492768, 73.57835354343538, 62.217494672344586, 42.24501325238136, 33.94616050104941, 30.935882599123065, 56.0516542773093, 35.3922011006263, 35.30115896655668, 53.0965131328952, 66.59854289024108, 32.191768653931156, 31.244404469766927, 36.182856790481075, 49.956055687319854, 83.14736781581756, 77.82936342300908, 70.74451169660016, 7.522802987406331, 0.2817034306785753, 0.27857399215140655, 0.21932398599963035, 0.18148325684089817, 0.080049071130493, 1.985456590210238, 4.712270805912634, 55.24127298785795, 79.11164899026194, 75.96382925587316, 63.646014044361735, 67.4510229787519, 61.100246752462084, 61.4972141481215, 61.49493917342156, 60.95494254942864, 56.800262158916844, 64.74123393335651, 67.03859359987321, 66.0200874267086, 59.09572339827015, 58.78415776837257, 53.992025544566495, 50.3253193824522, 46.77520175133982, 54.7097251492162, 65.35485736785397, 62.597168337914255, 56.29633565102854, 45.3514951275241, 43.63907460243472, 46.459937326369754, 53.94346267946305, 59.23474004191738, 59.34004783630372, 58.64036367785547, 57.142681152589866, 55.668544615468676, 53.12626823302239, 56.16536378860474, 59.54035543626355, 60.88075091761928, 56.68472482312111, 55.22762706202846, 53.044369143824426, 53.30092353205527, 56.12285314067718, 55.2112001757468, 60.3309012997535, 58.75060581391858, 57.89247358998945, 56.405079441685835, 51.78808496844385, 48.13781353735155, 48.56975278546734, 46.43961160413681, 49.17531574926069, 48.652157860417525, 47.70730987671883, 50.11424879873953, 50.92740320390271, 47.550556275152395, 45.235130171622004, 47.877752550186656, 46.93772123705956, 46.18321803308303, 44.4589872514048, 48.67229923125237, 48.64657240529215, 47.738284833969615, 44.20482943134923, 48.92198162694132, 48.24702409005935, 45.215177074555434, 44.56812720144949, 44.27592631309263, 45.852338652456964, 44.97326097180767, 45.5568233613045, 44.09278692737703, 44.77360448529644, 46.198401528020064, 49.01884063597649, 42.43314581532633, 45.352722829388036, 43.27193683193576, 44.965957518546816, 46.687411262143044, 58.47517305804838, 58.085595407793605, 52.93819450563001, 57.738944176704656, 53.271376317547215, 53.784222295207364, 49.50301016530683, 46.76249327198152, 47.01641967219692, 45.53037481923258, 46.63884055229926, 47.01375638284991, 48.915482259565785, 48.07860535960044, 52.287940056093284, 51.39126662285098, 58.834905393662, 56.33282938311177, 42.0674357875701, 47.41952949954618, 48.67183246920186, 47.16617184300577, 37.67942144024757, 27.381842597838375, 21.59445797243426, 15.170877652783549, 14.33296524709271, 13.199651298984406, 17.7979076293207, 23.166385081506547, 47.70928675128568, 64.06535463948404, 60.74395433548958, 61.52193684731761, 56.897101556101155, 58.716783215922696, 59.798988680685724, 62.70324883922454, 63.83820626043505, 66.74445506065123, 64.93230042919036, 66.26194861627394, 72.93891306846373, 78.6601371149863, 78.1305386943202, 71.3805946227043, 48.07980952724334, 24.943769862574918, 4.301067167712796, 0.2849695392914357, 0.17910559571558432, 29.733848725595784, 68.0390960939469, 66.21516258485856, 60.271649975930494, 51.821162316106985, 31.430921016200898, 25.337009045385546, 23.1720587899608, 8.440724880464616, 2.1973201055680556, 5.19580049860862, 2.974639491688821, 3.580660147051658, 13.780075792343387, 18.98960409625884, 19.8099874296496, 10.48952296856911, 0.6912915120201727, 9.75392460823059, 107.94672581457324, 65.05404295459871, 66.79666180764475, 77.99389116225704, 71.05520263794931, 64.03989845706572, 50.96495597593246, 59.04221442437942, 68.79714904292938, 71.31669921259727, 42.26349153826314, 46.082840658003285, 43.330082047370176, 64.7933740000571, 86.24716204981651, 91.5484885246523, 87.66167071557815, 9.418419772578824, 0.33941550000059995, 0.37851564706333224, 0.2589017429178761, 0.35828902596427553, 0.33931737945925805, 4.657851842141921, 20.722415062689013, 68.46834459612447, 85.77228069305421, 78.74638219033518, 71.5031922248102, 68.69654809274982, 65.86732679797758, 60.24643305809268, 63.08725672383463, 59.919432901567035, 58.73269234934161, 65.05605905286728, 71.41382494280415, 69.06408202263617, 66.90597041960686, 64.87823840110534, 66.71100508782172, 59.88956405270485, 57.052243063526774, 60.73916904387936, 68.9555186610068, 68.3839822584583, 62.59499534483879, 53.72065636419482, 50.39253704009518, 50.919809495249105, 59.12540789573424, 62.86840808007025, 62.56336927413941, 63.00797385554161, 62.871079214157604, 58.240274075538885, 59.542834374212454, 60.139823036809126, 63.7360873529988, 63.40808699207922, 61.25460770822341, 59.85199166882423, 56.30814982998756, 57.01514920880718, 61.49784172734907, 61.234619309825284, 62.43583340798656, 61.36093531885455, 60.92905098392118, 58.93628689550585, 53.85600166936075, 50.34649625901253, 50.915796910562825, 50.15629268461659, 51.30471168025848, 50.65806973365046, 49.95565952793245, 54.005534187439956, 55.59880879617507, 49.10545441412157, 47.339862238976266, 51.11250769707465, 51.12287844381025, 50.07847678276801, 47.468763089949086, 50.39103869468936, 52.017041560142275, 55.03360309908467, 47.68424634010562, 53.115697445407996, 50.89310992148615, 48.0643436216539, 46.93219853985695, 48.493490142206994, 49.1331345804276, 50.17959156344014, 48.944099872343, 47.36394166946412, 47.39077460381293, 50.918350373545, 50.83811044692994, 44.087174015660445, 46.0170978115451, 45.732674983239946, 46.11839302124516, 48.79999591458229, 59.757054621173495, 63.44148205172632, 54.922525498174856, 61.34392399941722, 57.31885833124961, 61.083823788550596, 51.45335774267874, 49.70422775514665, 50.45745618881718, 50.89341586635959, 49.77772120506533, 52.10478105852681, 53.312255259483095, 55.74444247830299, 55.39760689581595, 58.14149310511928, 62.71599654228457, 67.151149934338, 52.889278627211056, 58.791108208317915, 57.93603151075302, 50.28422863252702, 39.697637788711056, 29.789885667062578, 24.125879195428666, 17.610357538346324, 16.457631780255227, 18.64534551097501, 23.294925074423514, 35.39228739277009, 55.135914202659364, 62.26550056088356, 62.67078730367846, 60.05291900327129, 56.39643453782605, 59.24776231088946, 60.136920482881614, 63.451417415372795, 67.31333209622291, 66.88005924224854, 66.51805585430515, 67.50804639631703, 71.15850217880742, 75.12578348959647, 72.608837773723, 70.46193630464616, 56.82765206983013, 29.648850963961696, 7.050926656492296, 2.115588942843099, 0.4012745258308226, 34.535712349799375, 79.21232838784495, 72.96534984342514, 71.60340093797254, 60.09836358408774, 40.9972131636835, 31.525714897340347, 50.59841440569971, 17.31403620012345, 6.26057053765943, 7.457860794759567, 4.5292696837456, 5.29273207149198, 19.622345162976174, 34.090154632445305, 41.16106625526182, 23.37590829018624, 2.4164967575380882], [0.1405093353241682, 34.70311518638365, 57.05095260374008, 24.637499432409964, 15.541702451244479, 25.35240827068206, 34.842218122174664, 13.945967535818777, 3.340255137412779, 8.806216236083738, 24.061722947705178, 29.218753268641812, 39.65562528179538, 27.680344773877053, 48.00680245122602, 71.95078172991353, 76.37352082037157, 66.01140329914709, 7.244965328324226, 0.09483334998930655, 0.23036744986330313, 0.04626544019688041, 0.1323260913693136, 0.49814674222180927, 1.1079358453712156, 6.916722270750231, 61.14727989319832, 67.26176861793765, 60.22484433266425, 66.96520605394917, 61.719471331565614, 60.49919451436689, 57.79214720572195, 58.845221227215184, 53.37295001552951, 53.50615762895154, 56.39124916445825, 62.266186975663715, 55.72672905460481, 54.34052028963643, 49.38185599542434, 46.14756368821668, 40.76624439608666, 41.76068682824412, 48.184254400191776, 57.34220427851523, 57.80957037402738, 46.97789415236443, 41.36237798198577, 39.344946107556744, 44.083165353344334, 49.46564174467518, 50.53595066070557, 55.1903723901318, 49.967681592510594, 49.0315334258541, 47.105728118650376, 48.34012154609927, 48.002856546832675, 53.70727323716687, 54.9675464630127, 55.76642344074865, 54.277848659023164, 53.80266920212777, 50.60165820583221, 51.89908019958004, 49.224439513298776, 55.34819679875528, 54.24378679644678, 55.40722846984864, 54.73311032018354, 48.36346357099472, 46.5093356563199, 43.29787546588529, 44.23811466463151, 47.3828867173964, 46.07659624468896, 47.57479652281731, 44.543341744330625, 43.95781424737746, 44.38478385248492, 46.53286595498362, 42.570440538467906, 43.897711769227065, 43.436821506869414, 46.648544496105565, 46.31609224504041, 45.88552582648493, 41.01115326727591, 41.46106089315107, 44.93224082454559, 41.38744584975704, 42.841162527761156, 41.02252814077562, 41.600022623615885, 44.65175605589344, 45.7406020933582, 40.69965431767125, 39.2332213155685, 42.29235626036122, 40.3486688675419, 42.59470432035385, 42.49436616897583, 41.531047744135705, 41.37379600155739, 44.17174031657558, 44.94276062134774, 53.02128991773052, 57.50602599113219, 50.346472724791504, 49.98357111407865, 42.170578433621316, 45.43260582031743, 45.11754143622614, 41.292504879736136, 41.822699500668435, 40.00588117107269, 47.206866433543546, 44.60131437547746, 45.83496647496378, 46.312001212950676, 47.76492164980981, 54.17427455225299, 61.1563797919981, 51.35850698717179, 37.33838312087521, 47.45837273136262, 42.89669544466081, 28.108928434310425, 32.86037391231906, 28.674292987392796, 23.518319745217603, 17.711413483465872, 19.82232916739679, 20.28407842882218, 33.29359969785137, 45.405172763332246, 50.303342342376716, 58.07576594814178, 56.484860450990745, 53.305391111681544, 51.139289640611224, 48.22838890937067, 50.18820116596837, 53.779158515314904, 57.48567281230804, 57.137244747531035, 63.336178179710146, 61.590515567410385, 64.2159854212115, 67.85388177441013, 70.95444479296285, 71.25306267892161, 50.287515578731416, 31.65834199997687, 11.04645638696609, 0.2799132057735997, 0.3126274584041488, 31.813079503274736, 55.622550902828095, 56.59982512074133, 38.97397225902927, 37.51032806211902, 20.09925634630265, 34.80280614668323, 18.69256300310935, 12.400971420349615, 10.922738948175985, 7.96709377919474, 0.9985605531161832, 0.38303369656205183, 5.346983844234098, 7.5940518609939085, 13.040054959635581, 2.8923366435112494, 0.23007149477639507, 0.9462644496271688, 57.25986196148781, 53.07902328429684, 53.65136769510085, 60.31025394316643, 40.61872013153569, 50.438240497343, 28.558861555591708, 23.478113489766276, 39.74035239988758, 53.31337313498221, 25.40995336348011, 37.123429390691946, 40.14481152257612, 48.19594698567545, 83.01578798601705, 77.26630718477311, 76.84593108392532, 17.02059192042197, 0.3882418687064802, 0.3039716148088056, 0.09332132225315418, 0.10256670881062747, 0.755489067204537, 1.9768527486631948, 17.10130057027263, 70.5234076899867, 76.07240046224287, 71.48739291775611, 72.5292528829267, 69.49136149498725, 64.9585214737923, 64.20446934238558, 60.26442104770292, 58.66097181074081, 58.31301835275466, 63.08123980799029, 68.8519916226787, 64.88564775836083, 62.61148891141338, 62.42251303888137, 56.55780869145548, 54.68041327691848, 51.474691514045965, 55.19077639425955, 61.90795690782609, 60.17209629858694, 51.305751108354144, 47.1970683528531, 43.89228320890858, 49.62594116887739, 52.108479853599306, 55.65645979296777, 57.13887645352272, 55.216711105838904, 51.82245277589368, 53.10681719933787, 53.082161180434696, 54.133791769704516, 56.87553636489376, 59.67682253929877, 57.36036093004289, 58.75592847024241, 55.50163207515594, 57.19612344618767, 51.88292787921045, 53.82644661011235, 58.30372625781644, 58.19123268127442, 59.18850706469629, 58.03744831392842, 49.69418256513534, 50.85876957062752, 45.11488206924931, 48.37242618683846, 48.67775524816206, 51.46613682470014, 46.77819844215147, 46.79595501192155, 46.63432590423092, 47.31967379969936, 48.20981648660476, 46.77147549967612, 45.01565394863006, 47.10363357297836, 48.59957848825763, 48.14608189367479, 47.438953076639486, 44.551865054715066, 44.07415566905853, 49.82297358974334, 43.614838277139974, 46.102146563991425, 44.95202918206492, 48.371414215334006, 48.88051040710942, 47.10373163223267, 44.24822653493574, 42.58706746562835, 45.4446671085973, 43.2206989103748, 45.387396581711315, 47.63226709058208, 44.12150652177873, 41.79634117311047, 45.20839137415732, 46.99083797393307, 53.242491983598285, 59.64114466021138, 53.286191109688055, 53.159023946331395, 45.36397610941241, 47.56206450923797, 47.33224499610163, 45.31684098705169, 46.02807652565741, 46.51130076377623, 50.16851086770335, 47.511587527490434, 48.70712595601236, 50.63605739224342, 50.61246433565694, 54.98104333877564, 62.13462675771406, 57.34399287931381, 47.64473630535988, 55.11849495672411, 48.90297774345645, 33.013460097774384, 37.274005259236986, 31.747970119599376, 26.484669062399096, 19.90601489620824, 21.544516394215247, 24.95260500138806, 37.69276926594396, 47.022687619732274, 56.108352138150124, 67.04214726724933, 63.00627154688682, 61.03769671532416, 55.700245211201334, 55.89843080889795, 54.63409792992377, 62.19580788766185, 61.81186276097452, 65.12404549506404, 67.80585627402029, 68.94619126473704, 66.16188110843783, 73.41737162682318, 81.75368693567093, 81.87779857266335, 62.55771321635093, 42.30216218579201, 14.57704649817559, 0.27200445112201477, 0.3662237356747351, 42.41654634475708, 67.9195422510947, 67.3503278916882, 49.11784125912575, 52.07406497770741, 26.301855233407792, 33.3851085939715, 39.79379861585556, 16.792402152092226, 13.4730807042891, 8.844668211475495, 1.6724911644574136, 5.014602686128309, 8.947814779896891, 12.847679372756714, 22.45699894043707, 10.856015509174718, 0.8250021694167968, 0.2729692928973706, 57.353394800616854, 90.96032127257317, 54.96593829124205, 63.06905692623508, 49.93066618519445, 70.33456125567037, 62.21438423279793, 51.24289512634278, 58.32817831347066, 57.75422180852583, 43.73488241626371, 60.695634657336825, 44.155595840946326, 62.044706421513716, 87.50995343731296, 91.2164677343061, 90.25756589827999, 20.199119890889815, 0.674801990389824, 0.499196803617862, 0.350087012855276, 0.18188091776063367, 1.175297772692096, 2.4670269364310853, 40.5099331948065, 78.1992115512971, 80.04378457223216, 72.49331612740794, 72.7882940538468, 68.55135763845136, 64.38714588842085, 64.04000043869019, 64.40697346964191, 58.954161136381096, 59.29174384763164, 63.9253338690727, 74.46684099012806, 68.59309165708481, 68.07004359460646, 68.01243182151549, 66.34742490706905, 64.89087235543036, 62.735443653598914, 64.01213592098605, 66.00733972364857, 63.29497368104997, 57.04202136685772, 52.68507219129994, 48.70764763124528, 55.87823452488069, 57.10625017842939, 60.41364369853851, 66.74828329393941, 58.262105987918, 56.7911583377469, 56.04828888370145, 57.25312332953177, 56.973105322930124, 62.31568728723834, 64.81621003920033, 60.06903602230934, 61.72037347670525, 61.95116966001449, 61.820217409441554, 58.07564435466644, 55.92043530556464, 62.56385564804078, 59.98594845494917, 61.6655348193261, 59.651778205748535, 54.12531160539197, 53.14618995112758, 48.2595560627599, 49.992368990375155, 51.905132416755926, 53.63901222905805, 51.78444893129411, 47.089787606270086, 50.22101963720014, 51.4050498316365, 54.619573393175685, 49.70135658018051, 47.81490049054546, 49.10273228922198, 52.429831797076815, 52.8283759855455, 51.33326653511294, 48.882248017095755, 48.70894985814249, 54.06005121046498, 47.69811191866475, 50.59013820463612, 47.62304952067714, 49.63581377460111, 50.745534666122936, 53.48161535878336, 45.79353055646343, 44.93591216302688, 47.08804999628375, 46.95679964557771, 47.651110156889885, 48.51958174859324, 47.67684482759046, 44.67321142073601, 47.24247370996783, 51.55064036769252, 55.031955703612304, 63.16667295271351, 55.71588762344853, 55.66797979416386, 48.94103650123843, 54.41015804967573, 52.47726501957063, 49.52159435518327, 50.32204028098814, 47.80489844660605, 55.490904392734656, 53.907749499044115, 53.504831867833296, 55.43109609234718, 55.553070037595695, 60.27447016008439, 67.47412573906684, 64.94636604862829, 55.41228048263058, 59.778415849131925, 56.69114574309319, 39.899812436872914, 38.68698812300159, 30.930569748724665, 25.96070904885569, 18.741137635323312, 24.41588551767411, 31.55909230632167, 39.30517327400946, 50.24670331708847, 56.94747263385404, 66.07490647223689, 63.3683337703828, 60.02799234082622, 56.50404476350354, 53.87812383713261, 57.962511431786325, 64.03517200100806, 64.22356344038441, 64.25688005262806, 69.11952080265169, 66.56113132353752, 66.74617305878671, 72.8047287848688, 75.2077139577558, 74.81120155703637, 60.62618124869562, 46.58178967814292, 16.52444347258537, 0.6090869682450449, 0.5453098421135257, 48.890700724817094, 78.75516045478084, 72.84739632760325, 59.156802546593454, 57.182905058706964, 39.566614935475016, 50.53199691157187, 55.092179775238044, 28.077355315608365, 26.44896176553542, 14.400858532997871, 5.7213946696250675, 7.307854160185784, 32.337496472943215, 23.88762462523676, 50.366971031312026, 25.04860305017041, 0.6806015211247629], [0.1917593763960946, 4.634601992945518, 46.194459545996885, 28.60221355192123, 4.661589860916138, 4.552870094776154, 19.831046635104766, 11.793850295005306, 5.084606207186177, 6.335575080687001, 18.345450893525157, 28.676314969216627, 33.65966666129328, 28.189550792017293, 39.54337881457421, 67.48910134838474, 76.45674567068778, 59.473906563174346, 20.25827903901377, 0.020534988725557923, 0.15379527643803628, 0.18221330798922047, 0.09580779084635359, 1.5868959768164543, 2.8004869914823964, 12.599685557426946, 70.58189807399627, 53.7634886464765, 65.81155853886759, 66.13611898114605, 59.48335163054928, 59.086737248205374, 58.92045620949038, 57.51305880085115, 56.43229284594136, 52.624710836718165, 53.943937286253906, 63.83885345151348, 64.01446188649824, 54.4722334800228, 52.196066379547126, 55.06177356166225, 46.65851123871342, 48.475925768575365, 49.006383188309215, 54.75992364268149, 55.33799863630726, 52.00599224336686, 47.51742793667702, 46.05459174802227, 49.469293471305605, 48.58723478932535, 49.45454143708753, 49.52139431430448, 47.82602825472432, 46.83321360618838, 45.80360320306594, 48.08193152950656, 47.83489281131376, 52.560411422483384, 56.19205943999752, 57.77014270905526, 56.09915418009604, 58.26668731627926, 45.69327085248886, 42.93631530577137, 46.70145334735994, 51.673347796163256, 52.04947563909715, 56.218029452908425, 54.56848844405144, 48.565548004642615, 44.8610145045865, 44.38616844915575, 45.33466815948487, 46.56923809359151, 45.45007605706492, 47.47413673708516, 47.75988924887873, 47.62984306581559, 44.81783313135947, 41.330320450567434, 43.94694535962997, 44.7077125887717, 42.28395846582229, 42.54266231290756, 42.5835177206224, 47.87858017029301, 40.69277055801884, 41.45387511099539, 42.342460616942375, 40.249452514033166, 42.19229659726543, 45.42472185627107, 43.620843425873794, 41.7061972618103, 42.55393912715297, 42.48023386924498, 43.34674427586217, 42.20631514826129, 42.94965920909759, 43.03276246593845, 43.749457943824034, 43.84007253954488, 42.048937889837454, 43.37092176560433, 44.352706709215724, 53.81494229839694, 53.53938010431106, 51.65601092000162, 46.37984644982123, 42.485497690016224, 38.16235934534381, 40.02382601461103, 42.44194369162283, 45.67387080961659, 50.2073540995198, 49.522849513638405, 48.65773154843239, 49.61190692840084, 48.11374587397422, 52.21563508433681, 59.044214833167295, 58.55830377148044, 55.94092968971499, 54.25405948392807, 61.791364454454, 55.82052077016523, 36.97905478938934, 27.642809652513076, 22.19744197783932, 19.396638254965506, 30.30645005164608, 32.853174401867776, 30.267761753451442, 42.302789765019575, 54.03210432298722, 55.696805292560214, 57.457992646002005, 58.529391980940304, 53.79192975259597, 51.379899594091604, 49.14411329453992, 51.46924334187662, 52.72624923336891, 54.4551750921434, 56.81568491843439, 59.5627913936492, 60.17201000644315, 64.06325224907168, 67.924147113677, 69.20993143512358, 64.29261284489786, 57.95661610941733, 33.70931210056428, 13.46410632133484, 0.15960363250586296, 0.6832591720646428, 35.800300182834754, 59.63563373011928, 50.00191603937457, 33.62375736236572, 39.620441621349705, 37.0142541393157, 42.77289759728217, 21.97438463088005, 23.18804244841299, 29.53535718302573, 13.994591197659894, 5.003478844319621, 5.35232856389015, 2.8587032998761828, 6.9206843549205415, 12.60566128838447, 1.6894182755101113, 0.35967938361629365, 0.3220507995255532, 18.91132143235976, 56.937019517344815, 27.607714245396277, 40.939617080073205, 30.489461960331088, 40.54116702848866, 30.52722065679489, 14.89876812504184, 29.60290628094827, 31.604629062837173, 22.008419036865238, 38.82749134494413, 39.318183775871034, 41.41223130687591, 81.37964971603887, 76.05159621084891, 71.59884314383231, 30.828276295815748, 0.10380669872486785, 0.09694276542793359, 0.2031940813626974, 0.06681616628362287, 1.7200543154631893, 2.404307011635073, 29.0549688185415, 83.02868473914363, 61.28021294070829, 73.84680840276903, 69.41969979193904, 67.12701951303791, 62.67841239129344, 65.09577305086198, 59.68382789242653, 60.310959969797445, 56.248035584726644, 63.31380890261743, 66.49405879359092, 70.62163168384184, 61.87415392168107, 61.83851526629541, 62.147574501652876, 57.4545213483995, 56.278092707357104, 56.58902683565694, 59.6528450904354, 57.36105911193356, 54.1236210638477, 49.19303309532904, 49.945657483993045, 52.378860596687566, 53.34920790887649, 52.88402657355032, 52.79408662549911, 51.51420939353205, 50.093899542285556, 52.49895964899371, 51.08424309761294, 52.17887463108186, 56.25313858832083, 62.37767250307145, 59.90751281861336, 60.933836275531405, 59.28654278478315, 49.559943368358, 49.84307181450629, 51.70862559349307, 51.182027786008774, 55.51072805158554, 58.314257821729115, 57.02744583929739, 49.310515926730254, 46.57563940171273, 45.301908523805686, 48.0004717457679, 48.9571927439782, 49.32738604084138, 49.09528763063493, 51.10646332463911, 50.35463517712009, 49.350484878786155, 45.357304157749304, 48.863330425754675, 47.71134599562615, 46.20923119206583, 45.99803509250764, 46.440823616520056, 46.230992501781834, 44.079423412199944, 43.36963915055798, 46.909440948117165, 43.59332407674482, 48.15608001524403, 49.6328680746017, 46.88006239552652, 44.335534572601325, 44.377111696427875, 45.399273518593084, 47.83046445538921, 46.15308638541929, 47.38030579782302, 45.65095632306991, 45.87123270957701, 44.975959562486224, 42.77971859901182, 43.42075155627343, 43.704939042368245, 55.462812377560525, 56.65616604589648, 54.90907176848381, 49.71431216885967, 45.086939104141734, 44.14827277583461, 42.74586854442474, 45.80008483702137, 48.74193699129167, 53.67859678883707, 54.2833125206732, 53.371173181841456, 50.39252919535483, 51.486403711380504, 53.32804672179684, 58.782992824431396, 60.69146910021382, 60.746213620708836, 60.83853052508447, 64.94285944969424, 65.2475138633482, 44.658137752163796, 32.52280492936411, 26.546854319110995, 21.486349605744888, 31.684767007827762, 34.65681552886963, 35.90037161304105, 46.94978644770961, 63.033367280037176, 65.3015523572122, 64.65218828570458, 63.95311601700322, 61.287528161079656, 56.80944834986041, 55.515525110306285, 57.44639419740247, 57.44457814001269, 59.96703870834843, 62.219655898309526, 64.61349802632486, 68.48233176815894, 69.93246339982556, 75.50479427460702, 75.2910800133982, 71.08669142569266, 66.75481796264648, 43.98970311687839, 21.8881062153847, 0.023659512798692432, 0.9420415278403991, 43.529969953721576, 70.6737050702495, 57.16346971450314, 43.64488755503009, 48.50490816177861, 43.67598802812638, 57.03478067151962, 49.189232318632065, 29.55415906444673, 28.422869059347338, 15.013042457642095, 5.18803910863015, 4.772775817301966, 9.16602211613809, 10.5224306737223, 30.566336493338312, 4.07390040255362, 0.13240387993714503, 0.4142969173769797, 7.758445259063476, 76.60398360221618, 54.58193432900214, 39.110859055672925, 23.4114900712044, 33.57025231084516, 53.72011507711103, 46.15201950073243, 55.28703135828818, 40.18161119953279, 47.45658020819388, 54.194251183540594, 46.03096731247441, 52.55695973673175, 83.30070895533409, 91.67194904819613, 82.94077657884168, 35.21620827336466, 0.20604926041297375, 0.31968613125143513, 0.23464514693665892, 0.6669526535176462, 3.575246050473183, 2.165541797876358, 51.8077281982668, 88.43295774152203, 67.47926404399257, 78.48583482926892, 67.31279865387948, 66.27606130415394, 63.242598272139034, 64.96696241440313, 60.03282862324869, 61.690457559401, 58.26478104437552, 64.53802770183933, 70.54672225829094, 72.54997084217688, 66.08159803575086, 65.82745982754615, 68.95158060135381, 65.76248968801191, 65.25454667306715, 62.68957937917402, 64.75527209620323, 61.71934189334993, 58.04827405560402, 55.109045966979004, 54.73517348689418, 57.35607770181472, 56.899380453171275, 57.18708238294048, 55.87173123513499, 55.848126411437995, 53.50302365518386, 55.020545528781035, 55.963067546967544, 55.485785699659786, 59.33569792778262, 63.73938998868389, 65.7240818392846, 64.07845927822974, 63.24369261341711, 51.76286805060602, 51.923995094914595, 54.310365107751664, 54.8205634855455, 59.2243928294028, 59.56135188379596, 60.03307965493972, 51.33084643271662, 49.44874025160267, 47.45017497770248, 51.11480620599563, 52.44709807057535, 52.33075664889429, 52.166954548128196, 53.64102048258628, 52.417319436227125, 51.970992934319284, 48.10864287038004, 51.81316068095546, 50.84595126490439, 49.11862573316021, 48.684070264139486, 50.2410315698193, 51.97800220981721, 48.8549679325473, 48.201140203783595, 50.72468726865707, 45.5022749593181, 50.51356177176199, 50.938632949706054, 48.48174264354091, 46.14704201298375, 48.389672848486136, 47.53899705025458, 50.3054408104189, 48.622030135123964, 48.989254197766705, 47.21006708760416, 49.327472332985174, 48.039707214601584, 46.516886218901604, 45.13566278642224, 46.50719796457599, 58.32678979442966, 60.771508985950106, 58.7148141860962, 53.99045659649757, 49.242639310898326, 49.543155624020486, 48.53095662209296, 51.495103528422696, 52.251567917485396, 59.199783878941695, 58.32799788444274, 57.862369398916925, 56.42637791172151, 54.95548517473283, 57.25828516867853, 65.27778279396796, 66.51362357601043, 64.26805880761916, 65.09729493048884, 66.24144246501308, 65.23946908212477, 48.56677570650655, 36.71200806094755, 27.52100633036706, 21.75925243285395, 32.3730762927763, 39.50264500033471, 41.86189182343022, 46.72294793590423, 60.440994385750066, 64.28497991254254, 64.87522994318317, 65.74541561065182, 61.11903882795765, 57.239775503835375, 54.59172848732241, 56.56347651635447, 57.505363110573064, 59.67465739096365, 64.10307607343121, 65.13808365791076, 68.41239590798655, 68.5096549987793, 74.55160340955182, 76.2489071199971, 74.10613198434153, 71.76825815631499, 48.96062874024915, 27.682625632132254, 0.6120793076772845, 1.0961103895979545, 49.57063182707756, 78.51189505669379, 65.02087931479177, 53.626244914147165, 57.71042854555192, 58.31412446114325, 54.95371618578511, 52.713427005275605, 48.67372305162492, 54.051857379175004, 38.66097496401879, 23.430466498098067, 24.55386273322567, 12.956611437182273, 32.98554066688784, 62.796769911243075, 3.992054020204852, 0.39276500502901696], [0.02850579841422939, 0.11195085687382568, 11.14226027842491, 13.509229267797163, 3.5696833941244313, 5.395444727713063, 9.529359109940069, 14.15661548414538, 10.41704345133997, 9.186787143830331, 17.892630907797045, 15.541371991557462, 32.00212597846985, 39.7358024504877, 34.089495674256355, 68.3781300821612, 72.49705022381198, 62.62428760528565, 48.002895770534394, 0.9858629215628871, 0.07257985176458474, 0.05341847592424001, 0.11195040488195036, 1.6920673462652391, 7.273833482496201, 22.477707093761815, 66.6522087589387, 67.05937431704614, 66.87966700523131, 66.55066643991779, 63.75471468894713, 62.37421297257947, 60.67754860847228, 56.94292660682433, 53.141016344870295, 53.73102711093042, 53.4994189969955, 62.869118029071444, 63.177439858836514, 61.14144340638192, 55.61898939071163, 56.88531483373335, 51.81090139573621, 53.9525939572242, 53.15122235205866, 56.22224992321384, 57.94875960196219, 54.712388438563195, 52.59850155922675, 48.706286568795484, 50.645004318606475, 49.5641520715529, 47.63496960363081, 48.64258727719707, 46.951586815618704, 46.17121558035574, 45.42317644242318, 46.3277534515627, 46.61451793486073, 53.79222785272906, 54.01171192046135, 53.91957936748382, 55.968947179855846, 50.58076373992428, 47.02467233903947, 52.07021713256837, 51.08873421146024, 46.53493304406443, 50.431533244348344, 55.537153059436434, 52.975908094836825, 48.01072482139834, 45.30746652233986, 45.66190365822085, 44.04365924096877, 43.21640783740629, 43.23647076083768, 44.63106555323447, 46.08822607224988, 48.456655163918775, 49.344656236710094, 49.3972199193893, 44.621749924075225, 44.592049737130445, 44.26928181802073, 45.846898325027965, 45.942921869216434, 44.87399754985687, 41.984006974004934, 40.7570582051431, 44.84111632070234, 47.28849487919962, 46.156969531889885, 47.73478607977591, 43.63830581788094, 42.15435158821845, 45.363807447495006, 48.610474832596324, 46.05353663044591, 47.15424391531175, 44.08232988849763, 43.389917804348855, 44.55664642395512, 41.753257859137754, 43.02404303704539, 44.240652438133, 42.84133118967856, 46.796088372507405, 53.77797395952287, 47.82005448495188, 43.43126743070541, 38.5287126418083, 41.597422092191636, 35.64960272081437, 45.21035255924348, 52.257882933462824, 52.48732197669245, 55.58456667007939, 54.747791751738525, 53.485451436811886, 54.06588769728138, 55.908173976405976, 52.04560818210725, 54.08645268409483, 53.838343158844985, 56.19633874585552, 53.93045609997165, 58.518103399584376, 58.286393304024976, 60.53468804205618, 38.179696221505445, 35.89862615831437, 41.371642620332786, 48.90286791709162, 45.1805543130444, 46.752389246417636, 56.849750703380955, 61.05083665540142, 59.02600719082741, 58.25438284104871, 54.29368718977898, 49.82547606191328, 50.60755745057137, 50.705942261603575, 52.172998920563735, 55.0143168049474, 56.67045524043422, 58.745341993147335, 63.59812582692793, 61.868278211162945, 69.29915751180341, 67.77499506550451, 72.40596494367047, 58.509909568294404, 38.90252236397036, 13.775173810220535, 0.17772297555160138, 1.3881602667031752, 40.80074556412236, 61.243103396508005, 45.31083583831788, 31.587384362374586, 39.323926125803304, 46.80432927223944, 33.27350539545859, 38.148191744281405, 41.517425352527255, 35.90513729280041, 9.451103902632191, 2.8721955178245424, 2.3562589576167445, 1.42462580675079, 22.28593064892677, 13.592507070110692, 0.42940922742409093, 0.09609119741306191, 0.021016178126897544, 1.5654469858254156, 36.640911179204146, 27.97833900297842, 15.123236544670599, 8.981808000995267, 22.875515837823194, 22.812200938501668, 19.71575640862988, 21.230022714984035, 20.697349156102828, 19.487868662803404, 45.8891853978557, 44.50823260891823, 41.41652630221459, 74.21511111720916, 80.52200778838127, 70.37136877736738, 61.55772847513999, 1.8651658320619215, 0.08854150051070798, 0.17333514567825103, 0.4772819392383099, 2.7303447165796837, 7.551465217144259, 33.56883241284278, 80.40002992076259, 69.89472235402754, 75.12176698254001, 69.50663520443824, 70.33551046925207, 65.47008091403593, 68.1698130023095, 62.44754560532109, 60.600215158154896, 56.698390360801454, 58.85360333227343, 64.45290050198956, 69.90422233458489, 66.21509198219546, 63.83671968213974, 65.29624931273922, 64.7496081936744, 60.45625240572038, 60.18203166223342, 60.94073964703468, 61.196070255771765, 57.41816882164248, 55.15113299892795, 53.19504699399395, 51.225691610767, 51.63221782253635, 50.94814469737392, 51.24296572900588, 48.520676089871316, 49.139473130626065, 49.260219374010646, 50.06792952937465, 50.74935897704094, 58.00102910687847, 57.99079956546907, 58.34366383091096, 59.686279373784224, 56.12484962709489, 52.32342573904222, 55.44748375492712, 53.264476868414114, 49.59284813173356, 56.021471638833326, 58.00324524602583, 54.35149900374874, 49.08558368682862, 47.74629823623165, 48.8064835148473, 47.66914129257203, 48.49662803834485, 47.648415488581506, 47.6342478875191, 48.089285973579656, 50.53874338826826, 51.54408216476441, 50.511773170963416, 46.74990638609856, 46.575859054442375, 47.1226570683141, 48.416348888028054, 46.47675644966864, 47.40247895640712, 45.56394638553743, 46.33985788591447, 47.734272249283336, 49.38491544415874, 46.94475404677853, 49.52361437582201, 44.9869147423775, 46.148461910986136, 48.920969655436856, 52.71615697491554, 47.76222305913126, 48.79173540299939, 46.85191546716998, 44.96582415796096, 46.14539069514121, 44.52578913780951, 45.16054630279542, 45.13618838402533, 43.408192126981675, 47.74129329189178, 56.02699433603595, 49.73573615474086, 44.58339698853032, 42.94030043386644, 43.14521681877875, 41.363182067871094, 46.437709254603234, 55.675263635573856, 54.35452707352177, 55.22866256775395, 52.48563143514818, 53.55972543839486, 55.56878697487616, 56.2553664945787, 53.993072817402506, 55.963746117007354, 57.010026593362134, 60.08105024214714, 59.61904210429038, 65.2393239544284, 62.80504611230666, 65.62716399469684, 40.65428426188808, 38.45608211332752, 45.47386130978985, 54.72402611086446, 52.45163233049455, 52.76148388462683, 63.98359675561229, 67.7379757358182, 64.73816271751159, 64.86596138246598, 59.723875291885875, 53.81927259506718, 55.146665419301684, 56.4925875202302, 58.361451779642415, 61.84220621662756, 63.753337937016646, 65.3022034706608, 69.40087241511192, 68.13682586916032, 75.7765753038468, 76.01488282603603, 79.25827503204346, 66.53159587613999, 52.86588168913319, 21.722529242115638, 0.2877573332478923, 1.660549998764069, 51.04478405367944, 70.21117133478965, 55.512246008842226, 40.973561271544426, 45.119279046212476, 63.65602001067131, 49.116990104798354, 56.989983281781605, 60.27180294836722, 48.013694055618785, 32.47369097125146, 19.986364649188136, 13.951566719239759, 8.164532165373526, 35.863787666443855, 27.253630122830792, 0.7514223660672865, 0.2912791926533945, 0.1915622006861433, 0.5480925186026482, 22.22999372789937, 40.07411864496047, 27.444488733045517, 16.177206827748208, 17.866031354473485, 43.12816627563969, 42.19530113281743, 35.8399788794979, 32.00911564211692, 41.20298854766354, 51.00598004556472, 56.82139196703511, 50.63890111061835, 84.41878841769311, 89.30990557516776, 79.25304259023359, 68.75514830312422, 1.5720653726208595, 0.26397937368000707, 0.09075697316157241, 0.43109973832484216, 8.71264515384551, 20.322652978281823, 50.44630096804712, 80.57290446373725, 72.94932303890106, 75.51242720696234, 71.00425889415126, 71.54087051268547, 66.37757224421348, 65.98557841393256, 63.6527056078757, 61.34344154788602, 59.45814647982198, 58.532584790260564, 69.22704081381522, 73.539671128796, 68.35170115194013, 66.68162653523108, 70.79685964891988, 66.4764238172962, 67.97969572005734, 64.72867842643493, 63.857441563760084, 63.51503825956776, 59.70099218430058, 57.37035512924195, 55.58249565862841, 54.86245047661566, 54.589798681197635, 54.75906856598393, 55.445181323635964, 52.268775355431345, 53.1126223071929, 52.507973255649695, 53.380645705807595, 53.875299730608546, 60.39468296112553, 62.00516108543643, 61.085733982824514, 65.50863781282979, 60.5146368857353, 55.918458430997795, 55.90374169811126, 53.67176794236707, 54.50225137895154, 56.997149452086425, 58.1779593806113, 59.05366774528258, 53.26427290516516, 50.72142385667371, 51.54111293054397, 50.201243046791326, 49.19678288121378, 48.53774232249106, 49.76430669907601, 52.81743649513491, 54.40844005154025, 54.01036262512208, 55.56353492121543, 50.39891873636554, 50.56055568879651, 52.059057989428126, 52.3494702769864, 51.32574342912244, 52.0000929986277, 48.245427685399214, 47.8590859905366, 49.55630340883809, 52.39778211039882, 51.549569560635476, 52.965411832255704, 49.140951864181034, 47.17374986217868, 50.59097759185299, 54.97095500269244, 50.82099714586812, 52.484744979489236, 49.94260195762881, 47.26678456029585, 48.099256638557684, 47.9902853504304, 48.640657471072295, 48.34414197552589, 46.72389714948593, 49.215170952581595, 59.61248390136227, 53.68760647312288, 50.2670447288021, 46.16497901178176, 47.47962413295623, 42.84290013774749, 53.3012451664094, 59.49221226476855, 56.941330202164195, 59.01294962052376, 56.91785089431271, 58.16303476210564, 59.472804377155924, 60.49995545418032, 57.135801315307624, 59.17293133274202, 58.36097717285157, 60.67548151939147, 62.08155316691246, 66.08147251990535, 62.12524837063205, 65.64179443543958, 40.625874534729995, 40.90621025331559, 46.275507480867454, 53.29414567639751, 51.41795835187359, 52.77460421285322, 60.9591277184025, 65.02788074554937, 63.59205007553101, 64.87967006621822, 60.57198586002473, 54.75086688995362, 55.528166909371656, 56.34527506366853, 59.89567510543331, 61.92161852313627, 63.88880483565792, 65.51734547461233, 70.0344842480075, 67.46633591190462, 74.32001098509758, 72.02043517943352, 77.57495064889231, 67.85792966042796, 60.27900049763342, 33.24515842622326, 0.533956419075689, 1.9919358554386326, 55.77962221637849, 77.94042925680839, 62.627974633247625, 49.14235215033255, 56.08958359687559, 66.62947470141997, 39.294794682533514, 69.61343349949007, 70.74541384173979, 59.78740592156688, 45.8621524226281, 25.042964643047704, 27.848483054868638, 38.491724691083355, 90.25988794142201, 34.243382023226836, 0.7449785247445108, 0.3042042297461341], [0.06385500662990155, 0.06525103333255937, 0.6834327982318017, 5.089227739841708, 6.576384584749899, 6.581371878423999, 5.1923311621912065, 10.337842952820564, 13.905027797145229, 16.27743809453903, 17.294671458582727, 15.067200583796348, 23.046874384726248, 29.276445450321322, 34.0648788790549, 53.638745507886334, 74.66757220606651, 62.31500871719853, 68.60722003444549, 6.205378866964772, 0.2422336615141361, 1.328646266652692, 0.1869806424985009, 12.857664746622886, 37.23091410052392, 51.582266438391905, 74.50045570250481, 65.06561002423688, 71.03067997963198, 62.450330488143436, 67.67349197018531, 61.8739225018409, 61.653701028516224, 58.23518676142539, 53.36760774735482, 51.6911514343754, 52.30724988445159, 61.414307009789255, 66.34843687857351, 59.78936710665303, 60.39226285872921, 59.768107860319084, 58.28719346754013, 57.04553188816194, 58.05647573163433, 60.425218612917014, 57.31911328531081, 62.4815486323449, 60.7759726432062, 61.21790216815088, 55.598020399770434, 52.301060384319676, 46.81616306304932, 46.64632051221786, 46.57422342608052, 45.77891188283121, 46.28931814624418, 49.65967747472948, 51.69484630707772, 51.40448501033168, 52.66476215854768, 55.20239837708012, 50.20000357781687, 54.498289785077496, 51.91325172301262, 46.83498259513609, 52.50173276470554, 45.947734617417865, 49.29891355576054, 49.54019815691056, 45.167685016509026, 47.72462714102961, 44.285187029069476, 44.698342046430035, 44.76073518876107, 45.44667143975535, 42.521469746866536, 44.122404744548184, 44.702601740437174, 44.43946953742735, 45.90399626762637, 48.016475016070956, 46.52451130651659, 42.03377400675128, 44.243668740795506, 43.677878610549435, 48.038373608742994, 44.978101176600305, 44.45568853808988, 45.686038001891106, 48.3132964564908, 44.96063093985281, 44.576862319823235, 42.23773333334154, 43.04039932066395, 45.029903919466086, 45.48815050432759, 42.06491762591947, 45.7245909783148, 41.79354452317761, 42.11124081765452, 43.00363102266866, 43.43528001539169, 42.701447702223255, 41.89464361436906, 43.29318823352937, 40.59086738094207, 41.1799563900117, 42.893879182877086, 39.14719589294926, 37.22264182183051, 42.733626827116936, 42.335949482456336, 46.73882961273194, 44.871577447460545, 54.68939550461308, 58.42861844647316, 59.22502433100055, 59.484763683811316, 57.13851559546686, 54.322500921064815, 52.63409314617034, 52.5270438194275, 51.40820733962521, 52.112798383159024, 55.372864584768976, 56.523813509172015, 56.13051745199389, 60.69044536159885, 61.78958369839577, 59.31966720088836, 47.81586931597802, 53.98368658558015, 62.8740837497096, 60.40486543409286, 59.40702230699601, 61.19687434165709, 59.769978830891276, 61.64331459229993, 60.083184011520885, 53.099796156729425, 50.667734453755045, 50.35937340028825, 51.07587275966522, 53.76550866711525, 52.93962224837273, 58.5726204226094, 58.53680526056598, 60.68762125507478, 62.7244649394866, 66.65105558210804, 67.0034570078696, 69.51923385743173, 61.09255498455417, 41.09484095727244, 7.2676773225107505, 0.4784608566232266, 4.163302740743084, 57.48456670391945, 60.68431861938969, 38.97531763199837, 28.23055132742851, 44.91765352987474, 32.89065068767917, 26.97400043087621, 38.134412457866055, 42.218031267966, 31.09831383151393, 10.962573559053483, 6.161221313861109, 3.8159660754665254, 7.527526991982614, 24.87344764894055, 0.1865762706485487, 0.04890436028701164, 0.11011741694904144, 0.044643892531072905, 0.18028933945442402, 5.252061015175236, 15.763890993210579, 8.250660550209785, 4.573036961017117, 16.165877061505473, 20.776282933450517, 20.48636486453395, 22.554052106795773, 15.068140972045162, 23.607592890339514, 37.5912191021827, 37.40938586573447, 43.854804961912095, 60.18795836356379, 85.6135659064016, 69.55125608751851, 75.85435590436383, 9.42653319528026, 0.32131501803955725, 1.3776326251606787, 0.36468297964142216, 15.117363775930098, 40.29447740124118, 57.51125058820171, 82.62314304228752, 73.57200714849657, 76.282639503479, 65.8823573204779, 73.32678841006371, 67.07933133648288, 65.54615920589816, 62.74714016145276, 59.140897335544715, 59.097641437284416, 57.60499915769024, 65.85301014684862, 71.37098481578212, 67.0107526163901, 66.38493061065674, 66.1212924218947, 65.81705770184918, 64.00341256972283, 63.86700430224019, 63.033528097214244, 60.58691440090057, 65.02320528030396, 63.03316331678822, 61.66384427778183, 59.521261338264715, 56.84404757715041, 47.451006520179014, 48.374426595626346, 49.39197571046891, 48.32482038005706, 49.915976908899125, 54.865588372753514, 56.33796768803751, 54.54477771635979, 58.54942352541032, 56.68515628384006, 53.907302348844475, 60.369113029972205, 54.21693817261727, 49.36127924150037, 51.6649539239945, 50.328006206020234, 49.57101621935445, 49.00425334130564, 45.2425120722863, 48.00317033644646, 45.65458451547931, 46.62133109185004, 46.82278402390019, 47.25494292474563, 45.669685640642726, 48.146744774233916, 46.922898600178385, 47.193318566968365, 47.803396178830056, 48.74705176199637, 48.89865529152655, 47.36900937172675, 46.93060997993716, 44.95712434091876, 48.785902838553156, 47.635597182858376, 47.291338597574544, 48.16139874919769, 50.2713514912513, 46.46991583608812, 47.33102906134821, 45.709270200421734, 45.93275900809996, 47.21442091849543, 46.74605854095952, 46.40643227484919, 45.803634582027314, 43.68327186953637, 45.36108924496559, 45.726328588301136, 45.38652973790323, 45.62943820030459, 42.43908428376721, 45.18450413980792, 41.13741436312276, 41.800287077503825, 44.42461944395497, 42.455954397878344, 40.36675491640645, 45.77308324075515, 45.15223480040028, 51.78681412050801, 49.84114593075168, 55.978706036844564, 58.74121958209623, 57.300638921799205, 57.55398088885892, 58.42404888522241, 57.7102324270433, 54.29616220535771, 54.78326958994712, 53.21308205204626, 54.14681011630643, 55.57327416635329, 59.99223601433539, 61.415393506326986, 62.92208963824857, 63.82620380770776, 61.829776225551484, 54.089186576104936, 62.726724224705855, 67.81615641809279, 66.37605036458662, 65.17555406016689, 67.19591202274447, 65.66530119988226, 67.07677395113053, 62.44701216297766, 57.41940044587659, 53.77042339694116, 54.71175693696546, 55.775943033156864, 59.21024091782109, 58.23375117394232, 64.01388137571274, 64.06509968542284, 65.80234096896264, 69.35085435067454, 74.5395617331228, 71.8554759794666, 76.02679114187919, 66.80737772295552, 52.117873930162006, 8.536965135605104, 0.497329326406602, 5.329140001727689, 68.51369504005679, 65.2168958417831, 49.96996441195088, 32.04068876081897, 55.00345968431043, 40.13716682311028, 24.75396833112163, 36.312216558764064, 57.694876347818685, 54.9052200009746, 21.868157040688303, 10.730868366456802, 18.53945524461808, 28.020639804101762, 50.62174858585481, 0.9089715346213311, 0.07671977558563794, 0.08594993997605578, 0.16827000214928584, 0.19960341193983633, 1.4376966150537616, 14.022347850184287, 26.842028364058468, 13.849570385871397, 20.11618333478128, 22.938495374494984, 42.922230074482584, 38.14805838369554, 32.692753384190226, 37.80570999268563, 41.52958077769126, 42.97185590190273, 52.831910041070756, 69.6535671910932, 90.46020338612219, 80.96707913183397, 86.8191691367857, 11.18103192698571, 1.0216642327366336, 4.859743099058829, 0.2367904229510215, 23.722314373139415, 58.211389741589954, 69.00610939148935, 81.54583269549956, 68.39825968588552, 73.02825681624874, 67.71617520240046, 71.59563464503135, 69.4209941740959, 65.4908537864685, 65.90042375749158, 59.67116255914012, 59.36817123043922, 56.53009714618806, 69.46077485238352, 73.12798700025006, 67.60919647832071, 66.85457952560918, 67.95340799516248, 69.68619346618652, 69.12266654352989, 67.91812235309233, 65.93583491540724, 63.417939985952074, 68.25729754663283, 64.35863025726812, 64.10056183415075, 60.99128330907514, 58.22571423745925, 50.44652846551711, 51.64062346181562, 51.90253580770185, 51.183431994530466, 53.71397264542119, 58.833359979814105, 60.70058861086446, 60.14702058607533, 59.6575637017527, 61.961520794899236, 57.8661427190227, 59.40928551458544, 54.5289078066426, 55.740567176572746, 55.87808155244397, 53.02269412625221, 55.85078970078499, 54.057223181570734, 47.83055466990317, 51.1843341396701, 48.96534735156644, 49.367476586372625, 49.87562748693651, 50.032981211139315, 48.93978526515346, 51.21368131329937, 47.55628685797415, 52.36352020694364, 51.98305814496933, 52.604389036855395, 52.76626133149671, 47.09196059934555, 48.73471198543426, 49.47436509593841, 53.42252877450759, 51.33246637159779, 52.051272084636075, 52.774878778765284, 55.010492494029386, 50.96783107326877, 50.43617340826219, 48.5220959878737, 49.45258417437154, 50.605694324739524, 50.68933102392381, 50.09218546652025, 49.73124896326373, 46.89559498140889, 48.648823845771055, 46.537133493731105, 47.70590566819715, 50.36102471813079, 45.98716228238998, 47.22218328906644, 42.08647105001634, 42.65353987293859, 48.2105617369375, 45.634494135456706, 46.09601982178227, 51.05811226752497, 50.66014858984178, 51.7885870318259, 52.411133858465384, 60.29675706740349, 61.23618041315387, 61.80624200451759, 62.62538194656373, 61.812800207445704, 62.835244440263324, 58.27763857380037, 57.812182672562145, 54.958379883919996, 57.58359870603008, 59.318914105815274, 60.05360541805145, 62.778354383284054, 62.450008853789306, 63.31844906653128, 61.22403283273021, 56.01917705228252, 64.1946320379934, 66.34487536645705, 66.773221723495, 62.5658364449778, 64.34423908110588, 65.0804679624496, 66.32450257578205, 63.37693160580051, 59.58202277460406, 55.04482500014767, 54.644209800228, 54.69029372738254, 59.682407994424146, 57.13344397083406, 65.71580563822101, 64.29633125182121, 65.67448346845566, 68.61928524509554, 74.21187123944684, 72.71004276890909, 77.22792287026682, 70.26417040055799, 62.32055494862219, 14.419048524671986, 0.5672605900514511, 5.411468100163245, 71.70015012064289, 73.14707325350854, 57.206278462563795, 40.62865157281199, 67.24692636920561, 44.26441415663689, 41.119485209065104, 59.97452651300738, 67.27291599396737, 59.62027372852449, 37.489782687156435, 35.722637253422896, 43.101690276976555, 58.8838565734125, 65.47189304905554, 0.3960035957636372, 0.20899788686825385, 0.168541856110096], [0.06489716965945498, 0.12574045483263271, 0.02540549612604082, 1.4398650728887128, 6.783118497940802, 3.052139887886663, 3.116965635168937, 12.767303143778156, 14.000239410708028, 15.843034617362486, 16.17148703144443, 24.001290990460305, 26.265736087676018, 18.019260706440097, 39.550070378088186, 39.206309933816236, 69.1318605792138, 65.78800470598283, 72.12231482228925, 25.487371144756196, 0.23482353817070686, 1.4563720000367013, 0.21481699881053742, 20.341364645188857, 71.08707581796955, 65.5386321775375, 75.61645630867251, 68.37644346298711, 70.32118597338277, 67.6418149086737, 67.59807263651203, 62.05552039607879, 62.25795392067202, 58.28378492786039, 57.72107385819959, 50.14764385838663, 53.27261578652167, 55.978788406618186, 63.925737873200454, 64.4709590942629, 64.03893355400332, 58.47329424273584, 61.48041855904364, 58.99897029322963, 61.140219626888154, 61.91721370143276, 64.7407122581236, 61.1197683888097, 62.551523716219016, 64.33298972345167, 61.1930617978496, 59.676528361535844, 49.90573560037921, 48.538287531945016, 47.74346236259707, 51.06195619029384, 51.83502397229595, 51.61826987420359, 52.29550630815568, 52.172747888872706, 58.541159091457246, 46.60813623859037, 60.67701124375867, 57.967284956286036, 54.69745989768736, 47.246427459101525, 47.07607500014767, 47.27453516375634, 40.9075830828759, 37.463738149212254, 39.60797632894209, 46.826788763846125, 42.61311984831288, 46.40210982291929, 44.10640147424514, 43.17347749587029, 43.908321780543176, 46.22117480924053, 48.24111700057984, 48.07715016026651, 45.889275612369666, 44.9803408499687, 43.62877053599204, 45.13378004873953, 44.705990668266054, 46.492689117308586, 42.306535628534135, 42.60454162474602, 44.232846921490086, 42.21976103321199, 40.12246970207461, 42.569624685472064, 46.67120795096121, 46.80600020193285, 43.2611777705531, 44.175548938012895, 45.829020161782545, 43.7364709761835, 40.508854543009114, 41.417322543359575, 45.27391064551569, 43.34841520555558, 39.71374696300876, 40.85367402722759, 42.8882231250886, 43.22357400771111, 39.0578443004239, 38.55899726190875, 36.98640923346243, 39.77735996246338, 38.78589853163689, 43.31771481421686, 46.85675567196262, 54.29623280802081, 58.63353090901529, 56.347867750352435, 61.53113088300152, 59.26927258891445, 52.81792286903628, 54.43589664274647, 53.908482982266335, 54.43349615220101, 50.230931466625584, 51.6353988647461, 48.670145850027765, 47.731479521720644, 48.64562319171045, 57.283011790244814, 59.03089446406211, 61.61477542692616, 53.99426521793489, 56.069807006466775, 61.237737594112275, 55.11071689667241, 57.94609239024501, 56.58713233086371, 60.05848092417563, 62.01007973763251, 59.918099295708444, 55.26974547293879, 52.40921189708095, 49.73549689016035, 51.22281259106052, 52.73746328969156, 57.49112882921773, 58.16712971656554, 60.56009715603244, 61.5974699297259, 64.80462335771131, 64.8311189682253, 67.8024673461914, 66.84980992347964, 68.80919071935838, 59.74046691771477, 36.89748125691568, 1.993366294810849, 0.45197355050233107, 9.970648307954113, 64.06869649887085, 54.99156313557779, 40.28620904491794, 31.2860208172952, 44.329423519872854, 41.94903904391874, 47.87261424526092, 34.13348505573888, 40.02127647399902, 30.610076804314893, 31.583813044332693, 16.114076279824783, 5.060641015729597, 11.893151960065289, 1.0174077256552636, 0.1973296476588134, 0.10578398697919424, 0.08096094558676405, 0.12504778877501527, 0.10537457427070027, 0.20644154339548082, 5.1595465214021745, 6.245518442123167, 7.377349244010064, 8.48873959433648, 17.04098040057767, 19.69840580417264, 17.97675790325288, 17.532043495485862, 34.482728973511726, 26.677296661561538, 24.653900823285504, 46.5913994850651, 46.99436026234781, 79.18691142912834, 73.05481126231533, 80.852993073002, 31.063910722732547, 0.342780954895481, 0.3957097550794002, 0.30545638513661205, 24.677152633666996, 75.94941846786007, 74.76147374799176, 79.5846240751205, 72.85552347860029, 72.28699161160377, 73.97207321659212, 69.15644599545386, 66.86429131415584, 65.72993401558169, 62.62332662459343, 59.577327697507805, 55.30931042086694, 55.94955890409408, 60.40431237989857, 67.90011082926105, 71.29661667731501, 68.28224382092877, 63.372566007798724, 66.40681743621826, 66.11484404533141, 67.34603681871968, 64.40784031345, 66.57787199943297, 63.16908521036949, 64.83910099152597, 65.43788217729139, 64.00139254908409, 63.21918956695065, 52.25099525144024, 49.74687960840041, 51.087016213324766, 53.77093330506356, 55.7030693177254, 57.09166288375855, 54.723527969852576, 59.67333947458575, 56.88418519112372, 55.74514458256384, 65.75819469267323, 56.139460455986764, 57.31711287652293, 52.43735098069715, 51.56916572201637, 49.788139020243, 44.65793378891484, 40.163395712452555, 41.24565216802782, 49.90583758200369, 46.257645007102724, 46.47055910479638, 47.33479453671364, 46.62152721035866, 49.09689188003541, 49.1849765469951, 51.39676970820273, 49.34090645082536, 48.39089270560972, 47.39708569742019, 45.48749154613864, 46.469602046474336, 46.87641459126627, 51.13074279600575, 45.58087533520114, 46.445856017451135, 46.608516708497085, 44.56189063287551, 45.042761448890936, 46.202661222027196, 50.8351686693007, 47.17169846257856, 44.99898779776789, 46.4539086434149, 48.72677310820549, 44.30171197460544, 43.5240157958, 45.831459876029726, 48.42257368949152, 44.969644546508796, 41.588416330276, 41.84006775579145, 43.452848311393495, 45.482102209521884, 39.33088048811882, 40.09432669608824, 39.56097064479705, 43.610558971281975, 39.97913845123784, 43.87216929466494, 51.485889880887925, 56.63714255056074, 59.82615109412902, 57.81226504233576, 59.179760179212025, 60.54950283419702, 57.21957921981812, 57.878862965491514, 58.65107959316623, 56.271812992711226, 52.50920880225397, 52.362512157809356, 50.99650752159857, 52.55519467015421, 51.529463491132184, 61.61468129004202, 63.969456611141084, 65.9799772693265, 58.67034627545265, 62.07846233921667, 66.27864222372732, 62.808607624423125, 64.17220000297793, 62.17760416769213, 64.7832582073827, 67.39775719181185, 63.888585182928274, 60.06929097637054, 56.18738397475212, 53.0399250984192, 55.8972187965147, 57.911273510225364, 62.37422866206016, 62.77082735492338, 65.39416343935075, 66.40160852862944, 70.10183918860652, 70.45919849026588, 75.90351889210363, 74.45232037575015, 78.54444288438367, 66.6320634657337, 48.18496042682279, 2.470202830529982, 0.5805586506762813, 13.02765928929852, 74.5743453118109, 61.813941617165845, 47.83284141171364, 36.02227103325629, 55.97246946827058, 47.08555144648398, 33.491589177039366, 26.33904322501152, 48.382043838500984, 38.10302957411736, 33.00084183293004, 22.746532617076753, 22.04740739637806, 35.20986972316619, 5.486593256073614, 0.016905469068836783, 0.014752283196655974, 0.031906320983844424, 0.23754304304959314, 0.2774458204305941, 0.16993878679650445, 2.3229680859273483, 12.352078095559152, 12.669735166334338, 13.575231971279269, 36.180538669709236, 45.854758754853286, 31.416384712342296, 36.59872216563071, 48.4525994331606, 38.39339087086339, 33.089640371261105, 56.76742799820439, 56.5196361849385, 84.05244688833915, 80.99469261784708, 91.17805988557878, 35.6892421937758, 0.5254772966427188, 6.197040398274699, 0.8822125124354517, 27.21263154860466, 76.80208683013916, 72.48715800623741, 80.26672424808626, 73.66671669867732, 75.26354497478854, 73.86519647413685, 68.43847966963246, 68.27549734423238, 68.29787054369527, 63.247732654694595, 62.50951513167351, 56.39287302570959, 57.67002028803672, 60.5380573580342, 68.4097679199711, 70.68801387663811, 69.12418842315674, 65.34495338316887, 67.2779130935669, 67.62399165861069, 69.38582620313092, 67.78183567908503, 69.94048856919812, 67.3056834743869, 67.79523449559366, 66.76010531763878, 66.78161559566375, 64.06519382230698, 53.68402142678538, 53.06135300667056, 54.7812887930101, 56.93902384850287, 58.096864377298665, 60.08165428715368, 59.48579526716664, 62.7492033281634, 64.82391357421875, 59.224565413690385, 64.78127348807551, 61.86491673992526, 59.98282232592183, 54.26388109883955, 57.381561340824256, 54.3819248291754, 48.942201445179606, 42.554507870827955, 41.36197397785802, 53.01594372718565, 49.31462657067084, 50.74175350127682, 49.02806997299195, 49.810614201330374, 50.29064170775875, 52.02438815947502, 55.47201425798478, 52.21574491070163, 52.65868248478059, 50.012714324458955, 48.33165707126741, 49.593911094050256, 49.27154717906829, 52.81183142815867, 49.63793969923451, 51.54163068340671, 49.141857931690836, 50.280333718945904, 48.12966677450365, 47.51290152149816, 53.119694340613584, 50.8783814214891, 48.34685625568513, 49.90958736788843, 50.25603463572841, 47.416277854673325, 45.38544716373567, 47.02399376899966, 52.15785072695825, 46.4037101499496, 43.24931652315202, 45.59210508100448, 47.05260353703653, 48.84516200711651, 41.112887782435266, 43.68045560775265, 42.06616101726409, 49.6744530431686, 44.342041784717196, 51.60742452067714, 53.37999459235899, 60.18902524825066, 60.602588192109145, 60.15112338527557, 65.97388975081905, 67.42653169939595, 62.57056290103544, 66.43356015605312, 64.25156916341474, 61.27161902766074, 56.0283750103366, 53.7744987395502, 53.9030897232794, 53.80264566790674, 52.68469172139322, 62.571029663085945, 65.26862798198577, 64.12982271563622, 58.34909239122945, 60.65280237505513, 64.16790893000942, 62.1010002782268, 63.771953505854455, 60.49193812954811, 64.18115477408132, 66.33316316912251, 64.7496081936744, 60.05260129128734, 56.75442534108316, 55.210788326878706, 56.47889844832882, 57.83068449266496, 63.112807043137096, 63.61641583904144, 64.0702615245696, 66.14491293507238, 70.55834031874134, 71.33928422004946, 75.5558321552892, 74.63064701326432, 78.62119582391556, 67.93478458158432, 57.37630144242318, 4.278988146012829, 0.7690922146843326, 12.82170641806818, 77.72027446377662, 68.65584957984187, 54.02555396479946, 44.00184285256171, 61.94083813698062, 62.56120412580429, 66.84827235437209, 51.478025528692434, 57.9798992987602, 52.80107628914618, 53.59498754624398, 40.5572840475267, 46.22978833413894, 46.22817623999811, 3.1709977551814053, 0.22731828202884044, 0.22670403273115236, 0.1848879507592609], [0.044564410908928806, 0.10133798038887401, 0.07186270153690731, 0.07820053927360043, 1.7636563628911974, 0.5507059203040215, 6.667729721915338, 11.196278179845503, 12.499184627686779, 11.078724745781193, 13.678209877783253, 28.313378057172223, 49.64219939324164, 27.543289315315988, 37.32549029011881, 36.4529315886959, 56.45750191903884, 70.7711132111088, 69.33472556452598, 55.43955664480887, 1.8018954271270384, 0.34059156753843833, 0.2759119285450828, 12.549416461298543, 67.57425600482573, 73.2720164329775, 74.06822619899627, 71.84344999251827, 68.2920575910999, 65.98604909835323, 65.27185609263759, 63.51188859631939, 60.40964288096274, 59.263946010220444, 55.41857196438698, 52.674877951222086, 51.316376809150945, 54.87414698446951, 61.86174354245586, 61.56804038632301, 62.07589710912397, 61.500897253713305, 62.20759853239983, 61.86803502421226, 63.36619607863888, 62.995857654079316, 64.20528911775159, 65.5977422960343, 64.58757115948585, 62.80597963640767, 61.2748275264617, 58.9045000076294, 55.56616290923088, 47.25053418067194, 51.72214208110687, 56.18012758993334, 55.53871024039484, 54.57155573752619, 56.09170559913882, 54.92263140216951, 44.456967230766054, 59.517837109104285, 60.35213701186642, 53.810925791340495, 55.194475189332046, 53.699981551016535, 47.05327033996583, 45.744885321586366, 42.93861773706252, 37.7000178060224, 37.30720812274564, 47.08195463303597, 43.12240039148639, 43.01405668258668, 45.08750392544655, 44.60409533592963, 48.42985360853134, 46.841995793004195, 44.25174882335048, 44.793275171710604, 45.55483471962714, 44.68362531354351, 42.049455642700195, 42.67255552353398, 43.31638120835827, 48.16055936198081, 46.488786358987134, 43.9465021318005, 43.02892638790993, 42.46490916898174, 43.92843569478681, 48.896101828544374, 49.478424749066754, 42.779208690889426, 44.313788952366004, 44.34621518658054, 43.51347638714699, 42.05957535774478, 42.75270915800526, 44.3950016267838, 42.37427103903986, 43.25692984365648, 40.43170544408983, 41.2437419737539, 41.45387511099539, 44.13301867823447, 35.310953124876946, 34.05174678371799, 36.80089681379257, 41.145227724506015, 42.864147616970925, 47.52995990937757, 51.38927405880344, 54.70797184974917, 61.51155825584166, 62.45167978348271, 54.20745388154061, 53.26913664417883, 50.915369372214045, 49.437522272909845, 52.9571670101535, 53.98624004856233, 53.98345516573999, 50.87573382162279, 50.014067542168405, 52.62869596481324, 47.26287395723405, 58.34057300321518, 59.343264179845015, 57.78851509094239, 57.12050407163559, 56.962334494436945, 56.21482487647765, 57.91504290796096, 59.81029295152234, 57.723721458065896, 56.775335496471776, 59.29631733125257, 54.553842313828014, 50.65982303311748, 49.18405479000461, 48.517110655384684, 51.89305936136554, 55.15262349959343, 61.55815601348878, 63.61774552252985, 64.15491019525837, 66.46028718640729, 69.27428184017059, 69.0010573787074, 68.9366049920359, 70.59662265162315, 69.86250400543213, 62.81985305970716, 35.459999269054784, 1.28401986773937, 0.21619201938231147, 16.637231226890318, 63.275150022199085, 59.06299121918217, 35.855566378562685, 34.68348372367121, 43.68133814104142, 41.118575219185125, 28.751608787044404, 45.3603792959644, 42.29910665942777, 35.9423880423269, 39.09844867644772, 31.12288355827332, 16.311896116502826, 0.3638024688247712, 0.08711312957588704, 0.040834056844394055, 0.06298709795960496, 0.03452171451382099, 0.06260815256785962, 0.12345097808828279, 0.07136770914639197, 0.6066174684993683, 4.307503286869296, 2.5373795484342887, 13.814591669267225, 21.661087274551395, 26.211856449804, 15.425953307459432, 24.72426618299177, 36.03128856228244, 44.080274566527336, 29.085002406950924, 44.42428996486049, 44.7773778054022, 64.35506482278147, 81.00063108628797, 74.36769131691226, 63.93050355295982, 2.84437904915502, 0.23511797640352483, 0.3619572081633153, 15.065690471280007, 74.51923601088986, 80.8726284580846, 80.69117176917293, 76.80193778007262, 73.36728295972271, 72.38947529946604, 68.53885312234202, 68.43927983314761, 64.19063906515798, 62.98593405754336, 60.043693588626006, 57.5849558461097, 55.097349459125155, 59.937299297701934, 65.1377659459268, 68.22637358019429, 68.47265920331402, 67.11485232076338, 68.01593842044954, 67.11764504832607, 67.02842681638657, 65.90234571887602, 65.13416913247877, 68.25346931334465, 66.64559564282818, 63.66954826539563, 64.34010490294426, 61.947525778124415, 58.20626712614491, 49.95468285775954, 53.127966619307, 57.75208019441175, 57.81002929133754, 57.112141578428215, 61.552527412291504, 55.80301130971601, 55.19343576123638, 65.61751888644311, 58.3998086375575, 58.132361827358125, 59.17633595005159, 54.73341626505698, 53.18750035378241, 47.850656817036295, 46.17751490685248, 41.051114374591464, 39.16834923528856, 49.240148605838904, 45.303124458559104, 44.84206161191387, 47.639092014681914, 47.69197733171525, 51.284852720076046, 48.90367200297695, 45.58048702055409, 47.733613291094386, 45.93566156202748, 45.52045906743696, 45.923062909033995, 45.78558383449432, 46.71229477851622, 47.52612383134904, 49.298074168543664, 48.839254917637, 44.75145486093337, 45.56470732535086, 49.004818162610455, 51.098642118515514, 51.6525710013605, 45.758205690691554, 45.237695401714696, 46.408970048350675, 46.33507259430424, 43.9161390642966, 47.667027135049146, 45.40370187451763, 45.3152955732038, 45.38881647971369, 44.739472020056944, 44.24289211150139, 42.4552797502087, 45.69292960628387, 38.38562065555204, 36.276828935069425, 39.401706726320334, 43.41107506905833, 47.13687566018874, 50.93878592214277, 54.80774517982237, 57.63751560641874, 61.48898109312981, 64.56303281168785, 59.87630251915225, 57.842741858574655, 56.90740170017366, 56.80443556078019, 56.59938581528203, 58.28780535728701, 55.87524960117956, 55.33784174150037, 50.15755961018224, 54.4268673466098, 50.2914144146827, 60.306912083779615, 62.313522138903224, 62.96662422918505, 63.23094883272725, 62.376080020781494, 62.84035136622768, 62.290572351025006, 63.62713959909255, 63.661185772188254, 62.24075824983659, 62.62691167093093, 58.28057642905944, 54.53186527375252, 52.81965263428227, 53.82921188108383, 56.1267049081864, 60.31196409656156, 66.63574264895531, 69.31780445960261, 69.55678662946148, 71.6906266058645, 72.21469448458764, 72.91326076753678, 72.1708345413208, 77.64589848056917, 73.24748592991983, 68.53355792260939, 43.66641744490593, 1.343743592020004, 0.23871042315037022, 19.48224006160613, 72.43881087149344, 66.17591534891437, 44.134528790750814, 41.96126899411602, 53.75037616299045, 46.75954757198211, 24.293136904316565, 45.24017826203377, 54.486040223029356, 37.023416796038234, 39.158782574438284, 36.96517352134951, 24.137334477516916, 1.942905370266207, 0.11580531335165424, 0.03688905260435516, 0.05887035595914049, 0.020166063763862176, 0.09967772230025261, 0.24265058188428804, 0.1887747897736488, 0.2788702536734843, 3.031731550731967, 3.6967108230437007, 25.18214406505708, 81.12353463326731, 43.54889931217317, 31.320521985330892, 42.93054549924789, 51.51463300951066, 64.40153706458308, 43.23656489772182, 55.06546058962422, 54.7444655818324, 70.66427569235526, 90.84961629682972, 80.21465086167859, 70.50950681009601, 2.846107588660333, 0.8145450692503684, 0.7898784476903178, 17.022666854243127, 79.85201989450763, 78.50113207294096, 81.8712874381773, 76.1521344031057, 75.04926589227493, 71.8097411432574, 70.09433961683705, 67.85631364391696, 64.91180996741018, 64.40998584993424, 62.29756985941241, 57.89487408053491, 55.96132601461103, 60.23899232187579, 67.16804750504033, 68.69757575373497, 69.12218016962852, 66.70777305479973, 68.1006851503926, 69.7047305876209, 67.39554497503465, 65.67602495993337, 69.87056055376607, 68.67266870314076, 69.31299563377135, 66.04579464081796, 66.0201580293717, 63.71999779055196, 61.030197143554695, 54.27402434810516, 57.00351153650592, 62.88166176888251, 63.38578047290925, 61.1777880883986, 63.49745819645544, 61.65587009922151, 55.085837302669404, 66.86063566515523, 64.64641455681094, 62.34073946552893, 62.72461006718298, 57.98129566254155, 56.76129733362506, 51.9113846748106, 52.09684610366822, 44.85786091896796, 40.67284491754348, 50.41114868656282, 48.4873398657768, 48.6785004984948, 50.73746635067848, 51.31749860702023, 52.891224122816524, 52.179082516700994, 49.38171479009813, 53.00996603504304, 50.795544885819965, 50.479880379092315, 47.09541620746736, 48.65226768678235, 48.81643849034464, 54.20637522974322, 52.793294306724306, 50.962414280060806, 47.821027232754616, 48.28445919098393, 51.035884195758456, 53.36428549981887, 54.35423289575885, 49.296399316480084, 50.80207955452704, 51.10329012716971, 49.6362687695411, 48.227153362766394, 50.29829425196494, 48.66386613538189, 45.85461362715691, 48.384699283107636, 46.69060407146331, 46.903537781007834, 46.754017030039144, 47.5546786862035, 38.21154586730465, 37.90410264845818, 42.891902308310236, 49.48780313614876, 49.974686945638354, 54.02694640621063, 56.710333977976155, 61.174461918492476, 64.78748260005828, 65.44827253587785, 63.8775594003739, 66.1532283598377, 62.61119081128029, 59.97085909689627, 61.832533651782626, 60.97675877232706, 58.72793059195242, 58.17486855291552, 53.27336103685441, 56.46518191983623, 52.961767950365626, 60.604549377195305, 62.520576215559444, 59.72866450586627, 62.64409949702602, 62.702723241621456, 61.98404696679885, 61.09027608748406, 62.021336940027055, 61.6816871396957, 61.02817712291595, 63.11403474500103, 59.22808377973495, 56.38018023583197, 54.78028466624599, 54.78961206251576, 57.08217074794155, 60.744413252799745, 66.97296450215002, 69.3140782079389, 70.47873973846436, 71.45948133160992, 73.8684206624185, 74.93990236713041, 74.8623727983044, 78.8524587692753, 74.56966200182515, 74.72117531684138, 51.133998363248764, 2.982628869433557, 0.39755599633339916, 21.31457136523339, 77.90776375801333, 74.06339383894398, 49.72519282371768, 47.25165597854122, 59.59386441015429, 61.933424857354936, 42.870760733081454, 57.95734567026938, 60.84598302841187, 54.03826636652793, 55.496878162507095, 60.985933196160104, 43.90918470198109, 0.9923543216240023, 0.5348483292806534, 0.159039807115351, 0.2208418053604903, 0.12182763777673246], [0.05508569775209312, 0.05918959628850703, 0.0174698805166108, 0.0974140550580717, 0.23179085654837472, 1.5695409596927705, 27.612534838338053, 48.14043368062666, 20.639147066300918, 10.190212784274932, 8.68314108540935, 30.135528849017238, 55.68757987791493, 39.658057151302216, 35.36533286494594, 40.95835816475653, 41.455330310329316, 70.36646581465199, 65.91284982619747, 67.05087061851256, 6.3444332634249045, 0.27447385893714044, 0.6000965280878929, 9.811696217906091, 65.55941289471042, 72.84344257846956, 73.71389496710994, 67.33661528556578, 68.53528376548522, 67.38364450393185, 64.89598712613507, 61.8654501822687, 59.98806261247205, 58.940903525198664, 57.35035104136313, 51.62240012999504, 52.371353180177756, 50.195022167698035, 55.686179591763405, 60.194806821884654, 62.01194678583453, 60.15832485691194, 62.50807562182027, 64.53867881528794, 64.24149259444206, 62.03356296785417, 58.35471707005655, 62.08317310579362, 63.22022115030597, 60.297820029720185, 62.23025022014495, 58.06423417983517, 56.755598129764685, 48.981017220404844, 51.76267977683775, 55.601848633058616, 56.921686972341234, 55.577447568216634, 53.516547987538004, 49.94810896535074, 58.78739372376473, 59.826606089069, 52.46428589667044, 52.847830941600186, 49.88509216616231, 51.12628306111982, 48.24035606076641, 48.65936717679424, 42.7976869767712, 42.35372566407727, 37.960157240590746, 40.98157859617665, 43.559121008842226, 44.80326544853949, 42.854518198197894, 43.19572517948766, 48.051603763334214, 45.29011395669753, 44.13574864787441, 45.97064910396453, 44.19228961390834, 43.3147063562947, 44.18000867289882, 45.925396719286525, 42.06953033324211, 42.58079559572282, 45.79402869747531, 45.03913325648154, 41.27101813593219, 43.16017281624579, 46.03730978504304, 43.27418042767433, 42.15213152670091, 42.577128179611705, 39.53997027489447, 40.030058660814845, 40.39080296793292, 40.61449181648993, 43.58412611869074, 40.88089919859364, 45.46066645653018, 42.03872796027891, 40.39277984249977, 39.48182113708989, 39.77010750001477, 41.29304616681991, 35.61211662907755, 33.89638562356272, 34.040034586383456, 40.031113778391195, 47.44609571272328, 55.13949924899686, 54.643978380387836, 58.88092656289378, 58.203619526278594, 56.194546222686775, 57.26168194124776, 50.32151860575522, 51.316647452692834, 54.04011772524927, 54.53570527415122, 58.618425861481704, 56.29331150362569, 52.49657092555877, 50.57324063393378, 47.24973401715679, 50.414737655270486, 53.48100346903647, 54.56662139584942, 58.78960594054192, 59.80208343075168, 60.67913716839206, 59.45201973761282, 57.6556997145376, 52.37361246539701, 52.93378183918615, 50.60500790995937, 51.161305904388435, 48.068195389163115, 47.55614957501812, 47.79029938482469, 51.82876386950093, 55.640731088576786, 61.330654621124275, 65.21118094844203, 68.4072183793591, 67.98700701805853, 68.52538370317029, 69.54289359431114, 71.17117927920434, 68.13153851416804, 69.91016080302578, 64.61286652472712, 59.473177002322295, 28.043132635854906, 0.08042421672613391, 0.07834663224076072, 14.55994692540938, 68.03925298875379, 54.00957422871744, 34.60797809785412, 35.97386114058956, 42.58792254232591, 40.963935775141564, 31.85316024288055, 48.5383189109064, 37.6547928779356, 33.34524946828043, 67.38207555586293, 51.3732982450916, 8.63342700466033, 0.2787567194431059, 0.10155829961501783, 0.12876156086642898, 0.04557882240342517, 0.1654750529316164, 0.07447310783449682, 0.06522812730362339, 0.020558210765762676, 0.11055302986454581, 0.6847624817202169, 1.2807810931436479, 23.950708104718117, 66.49698488173946, 33.866873710386216, 15.8002935301873, 23.149061933640514, 42.07233482791532, 63.49867020883868, 40.67375882979363, 42.53545691890102, 52.278687184856786, 48.39940424888365, 78.81407445476901, 72.52329872500512, 76.2452357815158, 7.489061288295254, 0.13304659706209937, 0.715221586006303, 12.662424848925683, 73.82587079078921, 76.39202656284456, 81.00474173022856, 73.03077497789937, 74.10871290391492, 69.24771954936367, 71.07623438681327, 64.0382706734442, 64.5288650451168, 62.63523101806641, 61.22220108585974, 53.67214841227378, 56.34570652438749, 54.37281316326511, 61.64114159922446, 64.07834160712459, 68.38246822357178, 65.81711261503159, 66.68301505427208, 70.07293132043654, 67.44708491909888, 66.49134451343168, 62.16589197035759, 62.934209762081025, 64.31607646326866, 63.089825876297496, 63.96419671274001, 61.79303930651758, 56.339387586039884, 50.325382140374955, 53.29977819996496, 58.24225879484608, 59.121179580688484, 56.75717492257395, 53.42516852963356, 55.406985282897956, 66.27832843411353, 57.94444107240247, 57.00356644968833, 55.54391914798368, 51.77093244368031, 55.26150457320675, 52.85386746929538, 50.484194986281864, 46.133984442680116, 44.31026666395126, 40.46142524288547, 42.280345962893584, 49.435404193016794, 47.61295726222377, 45.70945062944966, 45.1361923063955, 51.85267856044155, 46.52846505565029, 46.35828518098401, 46.263171626675515, 46.386020260472456, 46.2443873959203, 46.29276983199581, 48.27565346994708, 44.08050990873768, 45.93757960104173, 46.531159723958666, 47.34773835828228, 44.595881892788796, 46.57101492727957, 47.654350034652225, 46.28196762454125, 43.8604570973304, 43.516747643870694, 41.78796691279258, 44.015700586380504, 42.73363467185728, 43.8230965214391, 43.35904875109273, 44.030123141504106, 48.23238580457626, 43.83202383595128, 43.21490949200046, 42.19269275665283, 42.540654059379335, 42.88254745544926, 39.13670747510849, 36.4778111826989, 38.27439400457567, 44.8904283585087, 50.297890247837195, 54.7945503265627, 57.497035918697236, 59.73821939960603, 60.186856177545366, 58.59862965922202, 62.21934603106592, 58.39776900506789, 57.204866409301765, 58.54197494445309, 57.897258881599676, 61.83012139412665, 60.77537644294001, 56.399286100941325, 53.05773658137168, 50.93451446102512, 51.79740844234344, 57.21784160983179, 58.93366675223074, 63.67378050281156, 62.83004337741483, 63.67188599801833, 63.6006518333189, 62.32499899402742, 57.21794751382644, 55.89670496602213, 54.09641550433252, 54.114878100733605, 51.94683897879816, 51.80646127270114, 51.77569812343967, 55.5383062362671, 59.147016233013524, 68.9003622916437, 69.2382509477677, 70.48224633739841, 71.49132313266878, 74.07106599500104, 74.6603472002091, 77.26770354855445, 73.49154364678168, 75.73793995764949, 69.25437973391625, 68.4667678033152, 35.96580066988545, 0.09346898570055924, 0.11992756352429429, 17.423764505693992, 75.12674839265885, 61.41199281138759, 39.99499659384451, 43.98030511794552, 46.84588678421513, 46.056717672655665, 27.671486100842877, 57.76608697829708, 50.710649105810354, 26.196767091751102, 72.67076415400352, 64.51577217348161, 11.960543182588394, 0.14762528090467378, 0.1140272998881917, 0.032402324610419815, 0.08576813965074478, 0.03904398515700333, 0.28832834454313405, 0.16012929139598725, 0.20673867825779224, 0.20751700826710273, 0.22540182115570193, 2.919476503326047, 58.41379973196215, 87.23279876093711, 50.17163699673068, 31.67990326881409, 38.734437034976104, 57.34961755814091, 76.40321316257601, 54.95306114996634, 53.99287669889389, 60.998480858341345, 57.13399310265818, 86.01330249540268, 76.47984058626237, 81.18133468012657, 8.095126805766936, 0.33422255768410625, 1.0177520974989862, 15.146946291769705, 77.60225819003198, 73.9820909500122, 81.01823468362132, 71.6546114029423, 76.08816839033558, 70.56186260715609, 71.91045976454213, 63.29951186333934, 66.80876624199652, 64.58945389716857, 63.587876673667665, 54.229764323080744, 57.78499280252765, 53.949679636186175, 62.50801678626769, 64.18374746076523, 68.75120239873087, 64.98600159921955, 67.30849973617062, 72.64235834921561, 68.50653279212214, 67.69047583303144, 62.55304951821605, 64.81759855824133, 67.50373178912749, 65.21461302234282, 66.73883038182413, 63.515030414827415, 59.930952902763124, 54.74083738942301, 56.14696787249658, 61.1941953628294, 64.58289569424045, 62.165440897787775, 61.215999818617306, 60.403680878300825, 65.8674366243424, 61.86175923193655, 58.72557716984903, 59.88475130450342, 55.26737636135471, 60.15602242562079, 59.095954818110314, 55.38182327824255, 49.10856485366822, 50.039060884906405, 42.01396603738108, 48.714358806610115, 48.98729693505072, 51.71227339775332, 50.96360668059319, 48.38052195887412, 54.03820360860517, 49.9206562965147, 49.43179561245827, 50.77533683469219, 50.038688259740034, 50.36746917232391, 49.75098632997083, 52.54060737548336, 49.55274189672163, 49.90532375151112, 53.53455951136928, 52.62584047932779, 47.92875512953728, 50.02736829942273, 52.432867711590184, 51.45724088914933, 49.2151984091728, 48.72524730620846, 45.09565461066462, 48.00950496427475, 44.317354386852635, 46.02571918118385, 45.92615373672978, 45.74634444329047, 52.8728791975206, 50.20556942109139, 45.41871670753726, 45.752890879108065, 42.92266937994188, 44.361084891903786, 40.290778606168686, 40.37518408990676, 41.76330304914906, 48.90508405623898, 57.170832003316576, 60.35881680826987, 59.84440580491097, 62.26177823159003, 62.93974422639417, 61.81141953314505, 66.45299942262712, 63.11561938255065, 62.82965506276777, 63.70152342704035, 60.86431618659728, 64.65816990021737, 64.44564411717077, 58.76083535532798, 55.624221832521506, 53.584279475673554, 54.87604148926274, 58.27904670469223, 58.65081679436469, 65.58695577806043, 64.129089232414, 64.30751000681232, 64.36373718323247, 62.71199964707898, 57.83757609705771, 57.672624741831136, 55.40316881672029, 55.976725239907545, 54.04352626492901, 51.97299726547734, 53.31332998891031, 58.55002757041686, 61.46217169300203, 68.27034334982595, 70.49731608360045, 73.82457640863234, 73.58076187872118, 73.48937065370622, 77.42498274772399, 77.14456465936478, 74.07383518834268, 76.00683412244244, 71.42732574093726, 73.52574671468427, 44.51314733874413, 0.2665967590385868, 0.3926029927547901, 20.7796287152075, 82.80355638073337, 67.21081702939927, 46.355480686310806, 44.94169765903104, 58.27009193358883, 57.166713514635646, 46.276468461559666, 65.12616749732726, 56.56131529038953, 46.001188678126184, 93.44429554477816, 83.39341809672695, 10.7144473637304, 0.39802533243933036, 0.432835417769609, 0.2598096183951824, 0.18883252215962257, 0.1951572061666558], [0.08439498833350598, 0.01320850015843227, 0.04102062989747332, 0.09377227224890264, 0.03586940489889633, 0.8335585747995685, 25.504274599013794, 43.37884103098224, 27.571903005723033, 15.293728247765573, 14.70670436659167, 12.78201497370197, 34.15746642697242, 61.06518468549175, 34.36191604983422, 40.348182493640536, 37.645190915753766, 70.55788532380136, 65.21145943672427, 70.43331869186895, 12.022086151184576, 0.04091336226631557, 1.2561842775152576, 4.859857338090097, 63.634262623325476, 72.57648606454173, 73.33651588809106, 70.07020919553696, 67.08480696524343, 65.67302434675156, 65.50717869112569, 65.17608750251033, 59.632221268069365, 60.7171174787706, 56.62441445935158, 54.43641439560921, 52.44547420932401, 51.23350104978008, 51.446944667447, 55.90698942061394, 57.49614946303829, 61.57103707713466, 57.81738373541064, 60.44055900266094, 60.34738702158774, 60.655732385573856, 65.66034332398446, 56.40707200573337, 56.84560475810882, 60.24045536595007, 62.18326414785078, 58.75050775466427, 54.51419499612624, 48.663046360015876, 50.546317485071, 54.202131225216775, 54.662256625390825, 54.18626916023993, 50.53055347934846, 55.40821690713206, 56.71827285520492, 56.48573513953917, 54.71559301499398, 49.78335765100295, 47.373186695960264, 46.889652590597834, 49.88858307561567, 45.981608206225985, 49.53107080151958, 37.57283887555523, 40.263376928144886, 37.42850349795434, 62.27320017353181, 46.1544592149796, 39.89972222235895, 42.67039429756903, 44.987228531991285, 46.64438286135274, 40.73679916320309, 42.905010869426114, 42.004046363215295, 40.46391202557472, 42.236737051317775, 42.99384078671856, 43.45495462417603, 44.155850795007524, 43.70513908324703, 40.15512343375914, 40.35778837819254, 43.24826925031601, 43.53886196690221, 41.33013609916934, 39.597028993791156, 38.996827910023356, 42.003242277329974, 40.89669458327755, 44.267034299912, 42.446964325443396, 40.94160572175057, 44.91285254878383, 43.93531945443923, 41.1613957343563, 42.57996013087612, 41.03370689576672, 40.89678872016169, 40.80457379741054, 35.9387323933263, 34.335361603767645, 36.38098747499528, 45.39526877864715, 51.91160040517008, 54.51402633420883, 54.73261610154183, 55.940564909288966, 56.48843373021772, 56.24777670829528, 55.48041597489388, 54.44919347763062, 46.93957651815107, 46.8616037214956, 56.106940084888095, 57.51729103826708, 57.839705944061286, 55.63643217086793, 52.06693410873414, 49.396090276779674, 47.169588227425855, 54.35141271160495, 59.47551865731517, 58.27353577460013, 59.861581863895545, 62.72744594081756, 56.54133081436158, 59.049882658066295, 48.48617492183563, 45.50065502043694, 47.781591723042155, 50.435169281498084, 49.28304756841352, 49.48941915265976, 46.861289931881814, 54.59944771182153, 58.924378579662694, 64.55548224910613, 63.94524382006738, 66.94016564276912, 63.18171916469451, 65.5103793451863, 68.34559009921166, 70.96505872664913, 69.20465976961198, 70.84800735596689, 62.36383045873335, 64.7874394539864, 21.16428182971093, 0.05509276874363423, 0.2495001280500043, 19.291861941737515, 72.9371166229248, 52.25995786728398, 40.40547655474755, 41.877553847528276, 40.684674785983184, 48.015439510345466, 33.370093760951875, 50.294505242378484, 34.197356931624874, 43.21817290398383, 77.8817270648095, 30.78061753703702, 0.33986433559367735, 0.10671780219361668, 0.17172050812552053, 0.07670833023204919, 0.15785142088369017, 0.005693560186398006, 0.00460417932763155, 0.09911025799210034, 0.033108232497808435, 0.1036765403865326, 0.04720077226539293, 0.427423435593805, 32.917687585276944, 68.1825371711485, 37.61644778713104, 17.449103017007154, 19.473514749157815, 23.233071257991178, 46.3936649599383, 66.08308853641634, 42.26177746249784, 49.05496174289335, 43.46443891525269, 81.02435358109014, 70.46521540611022, 81.01621858535275, 14.364390296320762, 0.011981597898768322, 1.2121944057364618, 7.861291275870416, 69.20775059730776, 78.06396822775565, 82.25948441413142, 74.30821249561926, 74.87035874397525, 70.37570691877796, 69.76035764140468, 67.38545663895147, 64.6752675117985, 63.36679227890507, 60.32288789749146, 59.08725892343829, 55.02314606020528, 55.46359685159499, 55.06758259188745, 60.681525891827, 63.72852894567675, 64.95851755142212, 65.24127729477422, 68.0040144151257, 64.6432884277836, 64.93395566940308, 68.05666831231886, 59.38080518476425, 58.88752791189379, 62.82503451070478, 62.72320193629112, 60.319283239303104, 54.794844504325624, 52.236929632002315, 53.23657704937843, 56.88325558939288, 58.67173871686382, 60.11575145106162, 57.8255501101094, 59.682764930109826, 56.46713526018205, 59.29669387878911, 58.08590527503722, 53.44180330153435, 49.73198636885613, 49.4441314666502, 52.57917211901758, 51.099869820379446, 53.83334605924545, 42.684416770935066, 42.44890589867869, 39.4520228908908, 60.49281674046671, 50.469933248335316, 42.84857580738683, 45.980290289848085, 47.42237714029128, 48.57045488972818, 44.026290985845755, 43.70979885901175, 44.32689359111171, 44.31263185316517, 45.06489538377331, 47.10743042730516, 46.807910396206765, 47.49277976251418, 46.1972483511894, 44.96942489377914, 44.19272499699747, 45.011923774596184, 47.03725530255226, 44.043333684244466, 44.82970614587107, 40.64146595616495, 43.760311142090835, 43.0220583177382, 45.568763056109034, 42.02145384204003, 43.70442521187567, 46.07220711246614, 44.73798544176164, 44.77160799887873, 45.62239362347511, 44.974712248771425, 44.75829939688406, 44.54580891516901, 36.44209800227996, 36.928267940398186, 41.45257288409818, 49.591718489123934, 54.81580172815631, 57.63266363451558, 57.493344968365086, 57.8729284194208, 57.117868238879794, 62.349105881106475, 60.648213201953524, 61.64730756513534, 54.410126670714355, 50.88977590683968, 57.173561972956506, 61.569181796043154, 61.20777068599578, 59.49923722974716, 53.33296145162275, 51.37265497638334, 49.72903282411637, 55.805890329422496, 61.06146235619823, 62.80846641909692, 63.058913676969475, 66.44870050491826, 60.232139941184755, 62.217569197377856, 52.21402691256616, 51.01534666553621, 51.77811822583599, 54.98375761893488, 52.70878291899159, 54.27718970083422, 52.73252502564461, 59.15456679559524, 63.2868229958319, 70.91882967179822, 67.41807506930444, 70.10575371403849, 65.63313776446928, 71.26227240408622, 71.36406575479816, 74.31787721572384, 70.64165146120133, 76.96288831772344, 63.904792416480284, 72.52085901075795, 25.5053218718498, 0.18757022376502716, 0.27969385947911973, 24.065582559954738, 79.98933422950007, 61.37596976372504, 41.87969153927219, 44.424603754474276, 42.32831655010101, 60.31698865275229, 31.24006436717126, 70.08258819580078, 35.43892437411893, 43.59794462880781, 85.00452380026542, 38.892928246528875, 0.5208127404893599, 0.128419510269117, 0.1662472848810496, 0.05108632808250766, 0.12317124108273177, 0.009381770317803228, 0.15967763659934844, 0.16444469531697614, 0.13396441636066284, 0.15340215075881253, 0.10661038900575331, 1.0322580029887538, 33.17068046139133, 76.88564900429019, 59.62868721254411, 33.338965831264375, 42.278471069951216, 38.03035589956468, 55.63450236474314, 83.39255517528903, 51.928007679600874, 56.396716948478456, 48.60162596548758, 89.43427608859155, 75.0228448067942, 86.12200706235825, 15.494834050055474, 0.21334119171144503, 2.152085126407685, 11.669473898026252, 72.6860692424159, 76.3202314992105, 81.6060410776446, 75.20314831887522, 75.66565852011405, 71.35364793962049, 70.46320715258199, 69.04796108122795, 65.16914098493515, 63.88021092261038, 62.6465392112732, 61.4139186951422, 56.754546934558505, 56.87556774385514, 55.65784831200877, 61.105200705989716, 64.31781015088482, 67.87835736428538, 63.25012922286988, 66.4877986907959, 68.08818063428326, 66.98280965128254, 70.5191558407199, 61.35289053763113, 57.21856724831366, 63.64907349309614, 65.01524679122433, 64.56331522234025, 57.595624692978404, 54.0341753344382, 56.45937681198121, 62.72407662483954, 60.36661448017244, 61.16759384832075, 59.99872753697058, 62.49482977774836, 60.61488482259936, 63.104660280289195, 63.411644581825506, 58.91846364544284, 55.062832601608775, 54.9099660688831, 56.77306052177184, 56.627109127659956, 56.06163278702767, 47.16463819626839, 48.18243834280199, 44.46756547497165, 61.99583761153683, 53.8632345199585, 46.56600213819935, 51.805206114246005, 51.491898951991914, 52.164197121897054, 44.404658502148045, 48.108772308595725, 47.554910106043664, 46.6810570224639, 48.879467056643584, 51.70910804502426, 50.45102350173458, 50.04869030367944, 50.77346978649017, 47.06918339575491, 46.90830346076719, 49.96155877267161, 50.63460219290949, 47.557667532274806, 44.07390855973767, 44.7412919998169, 47.71986930601059, 44.5803532292766, 50.457883727165964, 46.790648045078406, 47.29642591168804, 49.489293636814246, 48.02410402605611, 47.18192015924762, 50.062347996619444, 45.85480582329535, 46.25981407780802, 47.99734953911074, 41.674508433188166, 42.236831188201904, 44.586166181871974, 54.0715672892909, 57.44468012163716, 60.655379372258345, 60.036515651210664, 59.36013429395614, 58.12843553481564, 64.97065336473527, 65.85365341555688, 63.8023950207618, 54.21336489339029, 55.32392124975882, 60.33654951280164, 65.14412410797613, 62.7956324238931, 60.956052580187404, 55.25961791315387, 52.94111667140838, 52.481854192672245, 57.23146007907007, 64.05376011325468, 64.76086931843912, 64.95839988031696, 68.56769038784888, 60.49215778227776, 63.2625513692056, 53.89917127547726, 50.011733731915875, 53.80886262462985, 56.614169228461485, 53.83675067655502, 56.17131010178597, 53.27682056734639, 59.33375243217715, 64.22510493186213, 71.05969767416678, 70.02189343975436, 71.6885006812311, 68.21673239431074, 71.50710675024217, 73.66666178549491, 77.22937414723059, 73.95352040567707, 79.26996369515696, 65.17731128200408, 75.93970667931342, 30.787887650151408, 0.2297769799347847, 0.4397117923344336, 25.360288312358243, 87.09767310850083, 64.91643444184335, 51.59316670510077, 52.20020055770875, 56.53481183513519, 66.62146522152808, 43.210226182014715, 67.08007658681562, 53.25862861448719, 57.794567308118275, 93.70561953513854, 46.720994595558416, 0.31968220888126286, 0.26413142681121826, 0.3317948863390954, 0.2165244862196907, 0.24010963677879305, 0.07673640735447407], [0.051327392969641, 0.032406201015316674, 0.09601723162397262, 0.08204916582232522, 0.13548235829559066, 0.14133848760637546, 8.012095622477993, 35.33219275936004, 28.235383687480805, 14.482269287109377, 13.880821870219323, 39.62026903706212, 40.691821344437145, 49.12224608082926, 35.01535154158069, 40.59774721822431, 44.37658609882478, 65.43115923481604, 66.92209136101508, 70.23991446341239, 23.613350929752475, 0.21537166178947498, 1.6328214157012202, 4.412561030157151, 61.075053368845296, 69.41845247822424, 73.0305004119873, 66.88843742493661, 68.41343141371205, 64.86105841975059, 68.63377448051207, 62.5475307433836, 62.71887163962088, 57.844789335804606, 59.16083866550077, 53.008734410808934, 52.5636826792071, 49.41831442617601, 51.16058026590655, 52.90004553333406, 53.580498310827444, 53.313981102358916, 57.85516400491038, 60.31064225781349, 59.91808752859793, 60.39625975393481, 63.12713546137657, 60.253748278464045, 59.38470794308571, 62.12964534759522, 59.0179741767145, 57.457631787946156, 52.302613642907914, 49.053290813199936, 47.40811932471491, 54.873715523750555, 56.0016401352421, 62.4033679500703, 61.150092232611875, 53.77579312170706, 55.54594701336276, 54.36273659429243, 51.98607052526167, 46.7735622006078, 46.156075231490604, 42.53213859373524, 46.88865630857406, 46.84439628354965, 49.50880350605134, 42.34529649057696, 34.68023207879836, 37.27258928360478, 58.27740323159003, 48.5546124366022, 38.039549935248594, 40.159759675302816, 42.909713791262725, 47.29872442060902, 42.934667910299, 41.112389641423384, 39.71454320415374, 46.03326974376556, 40.997519108556936, 43.565683134140514, 40.93951509844872, 45.74333990773847, 45.842014974163426, 44.505957634218284, 41.49152594227945, 45.989045020072695, 44.50476915605607, 41.41382378916587, 44.24917574851744, 42.80537482230894, 41.671460751564275, 42.66756234630462, 40.547395752322295, 43.41142023763349, 43.27782430956441, 42.04950271114227, 38.508375152464836, 41.7322967129369, 39.750444658340946, 45.206422344330825, 44.88489781656573, 34.69486644191127, 36.04009428331929, 36.45006825847011, 43.74359400041642, 48.73185649994881, 53.39572329674998, 52.57048406908589, 51.65481067472889, 52.98438825914937, 54.90738514930972, 56.09723614108179, 56.24114005796371, 54.52402445577807, 53.93972073831866, 49.56962770031345, 53.242546896780695, 56.890931667820105, 56.1264342646445, 56.330322988571666, 49.8784202144992, 45.86237599772792, 49.11261666205622, 53.83960616204047, 56.626716890642726, 59.10784744447278, 58.850532116428504, 58.82105158221338, 59.9143651993044, 57.41151255946006, 49.54239860657723, 47.5645395248167, 48.442460106265166, 46.86337663281349, 47.48729236664311, 48.437313956599084, 52.64155349423809, 57.059695566854174, 60.04514094321959, 64.93803885675246, 64.62472384975803, 62.93171905702161, 64.46192587575605, 62.80658760378438, 64.8089026635693, 66.96692405208465, 67.20434511861494, 67.81719976855864, 67.50116655903479, 72.91757537472633, 27.466057846623084, 0.1637932294679265, 0.3960582025108799, 24.783093890836163, 77.36575495812201, 45.48886829806913, 57.430320324436316, 46.64436717187205, 51.77598053409208, 30.949785440198838, 27.438850325922814, 50.90856798233525, 40.419836351948405, 55.505632892731704, 71.54298074783819, 4.4403632802347985, 0.3521076463643582, 0.0983129826284224, 0.03321619343853766, 0.0074856165203175725, 0.05454668977988824, 0.043931515031163736, 0.026080425332991347, 0.07029093426441954, 0.08615691395055863, 0.07242656523181547, 0.02574506651369795, 0.031143647896486427, 12.362423346888635, 51.89863697175057, 41.5930917955214, 21.93742217556123, 18.898909091949463, 44.61857280423565, 45.02531866873465, 68.97461275900565, 40.86333874733218, 54.18621424705752, 50.535428985472656, 74.63008219195952, 71.69938918082946, 81.06851946923041, 26.07525206381275, 0.058138987139588406, 1.729640343016194, 7.943111917664928, 69.35507482097995, 71.98478083456718, 78.37625165139475, 74.00509172870268, 73.5455939077562, 68.36850458575834, 72.00741291046143, 66.87103779085221, 68.01817417144775, 63.9321352589515, 62.79205522229595, 57.78570275152884, 56.95850626114876, 53.929016590118415, 54.57483876136042, 57.49202705198719, 57.76871496631254, 59.36846540820215, 60.45160831943635, 61.28069539223949, 63.63762801693332, 62.965624024791104, 65.0069352888292, 65.74749054447298, 61.15919605378182, 64.15776960311398, 62.785324435080256, 59.31150474855977, 54.68930529009912, 52.04138771180184, 49.538358565299745, 56.64404199969385, 59.058033343284364, 64.21246313279676, 62.93963047765917, 56.321854591369636, 60.078265359324796, 55.97835694589923, 54.59193245057137, 48.17045157955539, 48.40984167591218, 46.71228693377587, 50.79547036078669, 50.77370905107068, 55.914488992383404, 49.22320788906467, 39.48519829780825, 40.279548860365345, 58.11253424613707, 49.742918014526374, 41.41964850887176, 42.69601914190477, 45.89386870784145, 48.235304047984464, 45.492676919506444, 44.364344381516986, 42.01432689543694, 48.307503115746286, 42.418711493092204, 44.9633805213436, 42.34959933065599, 48.90967715171076, 49.033020004149414, 48.02006790714879, 43.92827487760975, 47.52244857049758, 46.642735465880364, 43.724907828915505, 45.91278629918253, 45.064063841296786, 44.51801892249815, 44.53211984326763, 41.84070710212954, 43.19245000039378, 44.12400114920832, 44.195141177023615, 41.93691892008628, 43.577340418292636, 43.18420910066174, 48.428771034363784, 46.553764343261726, 36.04146319050943, 39.43878489155924, 40.218379497528076, 47.57151742135325, 52.390717921718476, 55.77969281904159, 52.32069576940229, 53.4974068210971, 53.58660151881557, 55.93093549051593, 58.12842376770512, 60.44621506044942, 60.14521629579606, 57.89600764551471, 55.90814651981477, 56.224642569018954, 61.23164615323467, 58.49216476563485, 59.27914519463817, 51.70869227378599, 49.97119211381482, 50.56235213433543, 57.71975594182169, 59.877502764424975, 63.97741117785054, 62.19506263732911, 62.06780918182866, 62.1361800163023, 62.243543132658935, 52.284284407092684, 51.626855942510794, 51.93477769051829, 51.40967822843983, 50.899232741325136, 54.129677203393754, 56.68085344376103, 61.057704725573146, 63.72976449228103, 69.06354858029273, 69.579128449963, 69.01139674648162, 67.99969980793615, 67.92950507133239, 68.77129277875348, 72.03467338315903, 71.66201683782762, 74.67031786518713, 72.37723750452842, 80.61419133217105, 32.777949225518014, 0.1702412383090104, 0.25206590972600446, 28.78280535820992, 84.61824094095539, 53.53881136063607, 61.58806800842286, 43.210065364837654, 50.83849876157699, 44.679761778923776, 27.394443212016938, 65.34216457797636, 35.22946196217691, 63.727203184558505, 82.07754135131836, 5.68178314355112, 0.32048807209057195, 0.0844042809800275, 0.11866357973626546, 0.04269503379961656, 0.02608971606429306, 0.07174364381259488, 0.13455675554371652, 0.1436862559808839, 0.20339666565339412, 0.2249317649271219, 0.12466157320886852, 0.219557014624438, 9.07478484415239, 57.38040031925325, 59.29253616640645, 35.98106653459611, 46.167646223498934, 67.03397304781022, 52.75051693762503, 78.99647251252206, 55.60909717313705, 59.83126978720389, 58.06131985879714, 81.92234100834017, 78.37285487882554, 87.48365786767776, 28.920504085479248, 0.22585177523714883, 2.2769682445833763, 11.29787443145629, 75.2370297524237, 72.69212538196196, 78.55661007665819, 74.51430166921308, 71.74485729586694, 67.83698420370779, 74.20087291348365, 67.07325950745614, 69.32950881219679, 64.3362884367666, 64.55720024724161, 59.1359120030557, 59.91155678226102, 55.14802648175148, 54.252549371411725, 58.04770138955886, 59.45724825705252, 60.09501780233076, 63.518917483668176, 64.35345665101083, 65.37551256918138, 64.0562351288334, 66.20870636355492, 67.59019651720601, 64.05777662031113, 65.78798901650214, 65.04790052290886, 61.20173023593042, 55.91853687840124, 55.57902436102591, 53.69295266366775, 59.94595204630206, 59.75711737909625, 68.7125748972739, 66.46676694193195, 56.234805430135424, 61.4097099919473, 58.78083159846645, 56.73597451179259, 53.368305929245494, 53.687771212670114, 50.94055098872031, 53.650253741971916, 56.00846113697175, 58.26145879683956, 50.35897724090084, 45.47261791844522, 44.12393446891539, 62.91348395809051, 53.38586245813678, 46.35060125781644, 43.9300674007785, 48.80767199300951, 52.12958612749654, 48.589548987727014, 46.80317217303861, 45.00401235395863, 51.48097122869184, 44.80409306864585, 49.019040676855276, 47.23061638493692, 52.15101011337773, 54.68407284828925, 51.3527960162009, 47.496702132686494, 51.93696637307444, 50.51297341623614, 47.12760709947156, 49.40807704002627, 47.98468028345416, 48.368476360074936, 46.386220301351244, 43.834192906656575, 47.84180794992755, 48.6724365142084, 47.79075045739451, 45.45701472989975, 47.04634735661168, 46.209384164502545, 49.837729546331595, 49.88917143114152, 41.5167389377471, 45.04260455408404, 45.75801349455311, 51.37201563004525, 55.45518728994555, 58.98714826953027, 57.11878607350012, 56.59593412953039, 56.11416901311567, 57.537452020952784, 60.997178631444136, 63.29766834935835, 62.29458101334111, 58.19763791176581, 55.22137088160361, 56.10377865452921, 62.911087389915224, 61.322276438436205, 61.89251845882785, 54.652042773462114, 52.97408027033652, 52.60680129451137, 59.32618618011475, 61.311737029783195, 64.11157977196478, 61.9905855578761, 64.02815880313997, 64.364796223179, 63.20511218040221, 54.324254220531834, 52.87969627688008, 52.9657530784607, 51.645914739178075, 51.89621294698408, 53.95530823738345, 57.70229747218471, 61.97107961100917, 65.86587552101382, 69.44526580072218, 71.38762351005309, 70.01503713669317, 71.11559144912228, 71.43461350471743, 72.00502026465632, 76.27492812372024, 75.03217220306396, 74.69944538608675, 73.71853120865362, 77.42763426996048, 33.09855591866278, 0.2978284783180683, 0.6045976317217273, 30.044163119408395, 91.51873342452511, 56.50234245484876, 74.04826917955953, 59.54686657074959, 67.45929917981549, 45.307333161753995, 36.220099695267216, 69.7482845860143, 53.145166212512606, 75.70975380559122, 95.62247399360903, 7.820056378841401, 0.40376198267744434, 0.22806645881745125, 0.34497650159943494, 0.18379454410845236, 0.20989330575591136, 0.16345100267039192], [0.08307879565343743, 0.08914913846960953, 0.05761633897500654, 0.05875881355736525, 0.11829545150601095, 0.011258540175584777, 0.17096689211264735, 14.546318650245668, 13.518156582309356, 9.04708702718058, 8.090160104536242, 19.450288434182447, 18.555195716119584, 46.768922036693944, 47.25928498852638, 33.50054394814276, 43.62900195583221, 59.18301966882522, 64.98202823823499, 68.0142282670544, 29.642257459702034, 0.10423573860598188, 1.8042460300268668, 4.719861082492336, 56.233518892718905, 65.20534053925546, 73.90071745841735, 68.26235740415513, 74.63461645187871, 68.66806384055846, 71.25299207625851, 67.55487165143414, 66.95316437752017, 62.633662069997484, 62.32101386593234, 56.671679019927986, 54.70851313683295, 48.36477364263227, 49.60418378153155, 49.33478755335654, 52.00375256999847, 50.658662011546475, 53.89087546256281, 53.339315691301906, 54.43810493715348, 58.625576342305834, 63.33148310261389, 58.02014673909834, 57.92242480862526, 61.68042021413004, 61.61738772546092, 57.33457134615991, 50.64176444084414, 48.028422555615826, 49.34407572592459, 55.539165235334835, 59.09914762743058, 58.459518878690666, 53.98214117173226, 59.434043515113096, 54.85751221256872, 56.686227090897106, 53.18645308094641, 45.295083599705855, 42.18634636171403, 43.67477993811331, 47.0830411295737, 50.02436768624091, 50.98392455808578, 45.442039120581846, 39.426096024051795, 33.691465316280244, 50.38447656939107, 44.23733019059704, 37.95430506429365, 43.55245297954929, 42.20282031643776, 44.82802737143732, 42.944964132001324, 43.4051993585402, 41.64993086168843, 41.71192392226189, 38.200339655722345, 39.82080805686213, 38.41527377405475, 44.99157451814221, 44.42058724741782, 46.42747971319383, 41.05074959416544, 42.769783235365345, 42.76749649355489, 43.53918360125634, 40.516593379359094, 40.19260952549596, 39.246153370026626, 42.851486206054695, 40.9838378813959, 40.896290579149806, 39.360188438046364, 40.40894000760971, 40.84426818355438, 45.04728001932944, 39.80109814674624, 46.7995047569275, 45.9892136819901, 34.57870152688796, 34.96089335410826, 36.92093703054613, 44.400626305610906, 49.878145648587136, 49.90528060543922, 48.50105247189922, 49.2853892234064, 50.463998702264604, 51.5615249449207, 50.60399593845491, 58.24376498499225, 56.46783736444289, 59.10718848628383, 55.76292076418477, 54.56884145736695, 59.133264403189386, 58.058283944283765, 56.559954227939734, 55.81975590798163, 45.9914808119497, 45.38540794003395, 51.112994070976015, 60.83049358860139, 60.03974768423266, 60.126114353056884, 57.26472570050148, 60.382554992552734, 53.63067719244189, 47.390370599685184, 47.44331082990093, 48.083406340691354, 46.56717884925104, 49.01906813344648, 49.73941141559232, 54.599337885456706, 56.34333741280341, 59.78373066071541, 63.03348887351252, 65.98149914895335, 64.75166743801486, 63.69357670507124, 63.01316707364975, 66.06853654307704, 64.3556845572687, 71.13386969412528, 73.5649468821864, 71.75724414087111, 80.96757335047569, 38.91971411243562, 0.670464400562548, 0.48688331919331707, 30.35451673692273, 73.09023810971168, 47.84155691823652, 51.88605008586761, 43.14005105726181, 50.16604369686496, 33.617171702846406, 31.96103522854467, 39.352433912215695, 47.5409347011197, 73.88567909117668, 30.998287508564612, 0.35713560398547883, 0.10061067949619987, 0.06418365451897826, 0.030893177364862738, 0.1179134953887232, 0.03544761987042523, 0.07573362124422867, 0.030892372972542242, 0.03312181906714555, 0.020106161433842876, 0.09654733382405774, 0.0760711366010289, 0.07840925226769141, 0.1858294728182016, 25.21182660133608, 23.198064104203258, 20.444464145168183, 17.921766273437008, 29.869033213584657, 21.62800012096282, 70.05054243149297, 49.82882184367026, 42.9941741881832, 52.000124377589074, 69.2670960580149, 72.65975013855966, 74.99903601984825, 33.74952423957087, 0.03870686050504446, 2.4349370454588244, 9.524967035939618, 65.50748463599913, 71.34658767331031, 77.786727259236, 73.44024688966813, 78.37967980292537, 70.87519722600138, 75.39746253721177, 72.08396188674435, 72.16578252853887, 68.68351797903739, 67.5495921411822, 61.86672103020453, 57.28932680622224, 53.62012209430818, 53.772792508525235, 52.3576601859062, 54.52332627388739, 53.929518653500466, 57.30937011780278, 56.24215595183834, 55.74269702357631, 61.61845068777762, 66.39817253235849, 62.988440452083466, 61.83179624619023, 62.52287864685059, 63.69052510107718, 58.16545878687213, 52.213042397652906, 48.5538044283467, 52.41217328656105, 59.15497472209316, 60.5885539516326, 60.16374165011991, 58.372591310931796, 61.7393381364884, 57.024429536634884, 59.69728946685792, 54.762449649072465, 45.851962104920425, 47.6122865369243, 46.77678638888944, 50.975997447967536, 54.044440177179155, 56.69081626399871, 51.08233290333902, 45.71030570614723, 36.11272873417024, 51.0339504672635, 47.23959076789118, 41.04304605914701, 48.363824429050574, 46.49119861664311, 46.92219649591754, 43.984482442179036, 46.315621560619725, 44.896535488866995, 45.1714151905429, 40.28535789059055, 41.95274568373158, 42.38555177565544, 45.30347354950444, 46.29811602254068, 50.61573559238065, 45.84485869253836, 46.27282065729941, 44.40169319029778, 45.455516384493926, 44.08190235014885, 42.927046745054184, 42.044285958813084, 43.84514808654786, 44.09292813270323, 42.792638886359434, 43.07666555527718, 42.37710691267445, 43.57018601509833, 48.86681741283786, 43.28724192034814, 49.11992403768724, 48.1379625874181, 36.11757678370322, 40.35933379204043, 41.20248256191131, 50.39176825554141, 53.14624486430999, 51.672261299625525, 50.86695555717715, 51.98230504989625, 52.80836405292634, 53.2002676686933, 55.45135121191702, 58.992117912538596, 61.395730664653165, 61.5606035724763, 58.09425992350425, 58.26363963465537, 60.10713008142287, 60.56127386708414, 59.72647190093995, 56.86519699711954, 47.912861685599054, 48.336458052358324, 55.278005984521684, 63.10975151677286, 61.750885594275694, 62.74987797583304, 60.73319135173675, 61.791172258315555, 59.86615926988664, 53.183978065367675, 51.83040342023296, 51.15161372769264, 51.09533163809007, 53.32702690555204, 54.70579885667371, 57.7445492436809, 59.82452723287768, 64.90799350123253, 64.89785417433708, 68.97809582371866, 67.11653109519713, 70.27411753131499, 70.3298387219829, 71.43812010365149, 70.02003423629269, 75.15105139824652, 75.94060097971271, 74.4533323472546, 85.05759346869685, 47.877736860705966, 1.2224125477575487, 0.5119590623484505, 35.72286082852271, 79.75629837282243, 54.51756823447443, 63.21608304977418, 37.42420458024548, 59.23525779478012, 46.64680296374906, 34.036920224466634, 43.46335634108513, 40.906347536271625, 88.68020826770415, 33.551993677693034, 0.4859314089821231, 0.25423793753068297, 0.11464549453868983, 0.01601505465054464, 0.10418421919307402, 0.0329304886080565, 0.026148992117434263, 0.19725112364657466, 0.20474494975661078, 0.11756996624171735, 0.19411258399486545, 0.18687654647134966, 0.2133267586149516, 0.27917420671832177, 20.959849857514907, 36.418257836372625, 24.93639188428079, 40.88523341763405, 51.10816955566407, 27.750578734182543, 69.43429100898005, 65.02473108230099, 50.66414940741755, 57.960424730854655, 76.1826269088253, 76.10515225318171, 83.17832316121748, 36.44158417178739, 0.20831672745125912, 2.5774499918183973, 13.290145281822452, 70.87264768538937, 70.07559068741338, 77.35049693815171, 73.4724417040425, 78.7946508776757, 73.47698380870204, 74.45345001835977, 75.40514253800916, 73.29761382072203, 69.38063298502277, 67.931089708882, 62.948714686978256, 58.63590002059937, 54.89935605756698, 54.90674580297163, 54.594183891050285, 56.35066047791512, 57.07722463915425, 59.150448306914306, 56.89489326169414, 56.76226223668745, 63.29908824736073, 66.90799436261578, 65.39193553309288, 63.028570221316436, 62.760813543873454, 65.7233012876203, 61.296902625791496, 55.94551494044643, 52.346630480981645, 56.05002257131762, 62.05980362430696, 65.90051004963537, 61.70995566152758, 59.93858583511845, 64.98530733969905, 60.666860149752715, 63.06487960200157, 59.39483158050045, 50.06025345094743, 52.091456767051454, 50.26842932547293, 56.01121464083272, 56.76137970339868, 62.55856044830815, 52.274909942380845, 48.77149205054007, 40.18019914627075, 57.989646388638405, 50.76945720180389, 43.31864833831788, 50.705957951084265, 49.00028390269126, 51.77094421079082, 47.48377792296871, 48.83882737928822, 48.38880992704823, 47.67649181427495, 45.21563599186559, 45.15557273741692, 45.16843811158211, 52.29633392826204, 49.3484805476281, 52.54845603819817, 47.5254060376075, 50.60577277214297, 49.86832795604583, 48.746753661863266, 47.13863288202594, 45.26008036828811, 44.83719395053002, 48.293990550502656, 47.604202531999164, 47.73124025714013, 47.34760892006659, 45.87485697961623, 46.939819705101755, 51.24824916162799, 47.30493353259179, 52.049169694223714, 52.21785514585434, 41.413470775850364, 45.244037874283336, 42.88551276729953, 54.47249627882435, 54.887102573148674, 56.78154853082473, 53.14514267829157, 55.061247964059156, 56.53587479745188, 55.88096057215045, 55.32323483497866, 61.35153731992168, 61.57901125569498, 64.19214917767432, 62.33604831080284, 57.4860611269551, 61.35596567584623, 61.54210959711383, 60.8208720145687, 58.797831150793264, 50.56660790597239, 51.40595197677613, 55.705410972718276, 65.88368308159613, 64.0049462164602, 63.93749321660688, 62.293267019333385, 63.507934847185695, 60.90318295263476, 53.11588179680609, 53.58281250922911, 52.76836372190907, 50.65406499370452, 55.29557428052349, 57.73207218416276, 61.83763665537681, 62.744268986486624, 64.95346161627, 68.06699983535275, 70.41210651397705, 71.51523390123921, 72.28412043663764, 72.39573540226107, 73.57840061187744, 72.5589766040925, 76.97617730786725, 79.55139375502064, 75.49018736808532, 84.7091850157707, 42.722353935241706, 0.9517534389611214, 0.6467967576557591, 38.32484745210217, 84.49846744537354, 62.35173386912193, 67.86568026388845, 55.91708560143748, 66.83789376289614, 51.602913794978974, 40.62832993845786, 61.03500204701578, 57.994867063337765, 100.8626820964198, 37.256731140998106, 0.34088485663936985, 0.3219000334220548, 0.16869619218332155, 0.13478295066423956, 0.16031304524550516, 0.12937092252316015, 0.135981893587497], [0.004895825648770458, 0.04686737463118569, 0.12895827692362571, 0.058224068864458994, 0.02175519441915376, 0.06183244640968981, 0.1165467868709276, 1.3937636176424644, 9.994066819067925, 4.414524176428396, 1.2680229712878506, 34.11661494162775, 23.560151823105354, 30.00939915257116, 51.22831959878245, 34.93676685517834, 35.08539330574774, 50.20028598846928, 66.94168752239597, 63.660613106143096, 25.816012813198952, 0.2874213577278199, 1.622630239975068, 9.647030215109549, 40.55293806137578, 63.195302332601244, 78.22502074703094, 67.99316513922908, 72.44208212821715, 68.23870551201605, 72.6955456887522, 64.28235584689726, 69.13384529852098, 65.51837313559749, 65.81667330957228, 60.54561968772643, 59.16952671543245, 51.40677175214214, 50.01123559090399, 47.94738246548561, 50.21891332441761, 47.73774746925601, 48.485304155657374, 48.80633838715092, 51.22478946562737, 55.138765765774636, 63.33963378783196, 63.635494247559585, 59.45276106557539, 57.238332071611964, 58.28428306887227, 57.20359556136593, 49.07134548310311, 49.72405141399753, 49.11525249481202, 51.38871708223897, 56.09076423029746, 57.49090917648808, 58.615213440310576, 57.32240023151521, 58.266408827997026, 55.768490529829464, 47.72279931652931, 46.034348395562944, 45.127994552735366, 44.405066428645966, 44.73907586066954, 50.7780275806304, 55.77081649534164, 46.19008610325475, 39.304294663090865, 31.798556927711736, 38.96329164505005, 43.01646501787248, 39.58793301736155, 43.11047246379238, 46.18546947356194, 47.106869528370524, 44.687127990107385, 44.71981702312347, 42.55737904579409, 42.42217886832453, 39.08731306752851, 41.53989661124445, 41.75040629602248, 43.083592461001494, 46.06615489529025, 48.511815455652055, 46.45459898056523, 45.058199897889175, 41.85864802329771, 39.47683972697104, 41.050345590037686, 43.60989216835269, 40.259183914430686, 43.151751487485825, 40.75207679502426, 41.63373147287677, 41.12041481079594, 46.912790652244325, 44.59838436495873, 46.010076768936656, 38.67324806028797, 46.72002184775568, 40.358380656088556, 33.247311807447865, 40.50399080399544, 43.36777602472613, 43.995194435119636, 49.11109478242936, 47.00295417539535, 47.11205097936815, 44.1510929599885, 46.89764638100901, 48.17251474626603, 50.64277248997843, 54.876547475014966, 56.83731678993472, 58.513027852581395, 56.959655515609256, 61.4825640955279, 51.270720420345185, 57.74794209387995, 56.95971042879167, 55.03801184315836, 48.60976096122496, 42.708060818333784, 54.59885151155534, 56.69553487531601, 58.60249711621193, 60.09546103016023, 57.141916290406265, 59.00810941573113, 55.25746845429944, 47.63258872493621, 45.68989369177049, 46.34477261574038, 46.75637829688288, 47.97334855602634, 48.92550391535605, 54.7933461589198, 57.526806708305116, 60.761299056391564, 60.0926604578572, 63.23461624883837, 61.96948320634904, 66.14725066769508, 66.48241719891949, 66.77137820951401, 66.48348408360636, 69.0147856743105, 68.53791175350067, 68.60173656094459, 72.219801410552, 50.52139082262593, 5.555256307125092, 1.1705344218400218, 40.275661791524584, 68.42640661424207, 46.625312297574936, 52.05539841805735, 40.082971434439386, 49.37639605614447, 32.44857211266795, 40.8708579309525, 48.06698729915004, 63.6637431575406, 65.50802592308291, 1.8470835829934769, 0.06805139879185347, 0.10343215067780788, 0.017091051953273918, 0.07928915787488222, 0.024410487723446662, 0.06567025962736338, 0.011858035577461125, 0.035350675274047165, 0.0600775649711009, 0.06715173577709545, 0.07465644799653562, 0.031514426790958935, 0.15423586892504848, 0.036654813560627164, 2.6872974393829225, 14.161583165968619, 11.257486766384496, 19.49070061406782, 36.907173433611476, 17.20685939635, 43.689018141838815, 64.15958958287393, 39.48826951365317, 47.18449715645083, 54.988884156750096, 76.55749567093389, 69.13016611529936, 29.19195955799472, 0.5457973804685378, 2.679632147473674, 11.940813660621645, 52.80586942549675, 67.9208601674726, 80.51884635802239, 73.21344760156447, 75.9457157504174, 72.70541437210576, 77.42654385105257, 68.51921773725941, 74.47090456562658, 69.46686237089096, 70.85225136049333, 66.00918323762956, 63.42158779021233, 55.584005771144746, 54.678816872258345, 51.88763080104705, 54.06649566465809, 50.822644541340495, 52.81641275651994, 50.260055065155036, 54.14278184213946, 59.293952142038655, 66.53889932940083, 64.77222850245815, 63.49667372242097, 62.08030977556783, 61.785665250593624, 57.29884247626028, 53.1078330932125, 50.975075690977036, 52.32612825209095, 54.672701897159705, 58.1773788698258, 58.25025258525726, 63.680566203209665, 59.026583779242735, 59.89598105030676, 57.43423877223846, 52.16323614120484, 47.80052108149375, 47.04514318896879, 47.50339761857064, 48.9157215241463, 52.75659661139212, 57.787099115310184, 50.541563572422156, 42.56039927082677, 36.55779615525277, 42.10686737491239, 46.505028893870694, 43.52647119952787, 46.36968751107493, 48.58773293033723, 51.28595098372429, 48.19417407435756, 46.615098445646225, 43.83283184420678, 45.46424365812733, 42.23800005451326, 43.470569579832016, 43.32510455962151, 44.18083629300518, 48.31382205409389, 50.170334769833474, 49.25238640077653, 47.38574612525202, 46.23422061243365, 41.85909125112718, 46.11309389914236, 45.47339062536917, 44.569319601981874, 43.04569844276675, 44.602569533932595, 43.3609236440351, 44.410059605875325, 48.48894019280711, 47.35370820568454, 50.02434415201987, 40.89985601363644, 46.73489547544911, 45.60869278446321, 35.291910017690356, 46.285376164221, 46.67580889117333, 50.30025151468093, 51.99403685908164, 49.9657125626841, 49.73743846339565, 48.07658141659152, 49.45465910819269, 51.31720835162748, 52.12527152030699, 57.28100745908676, 59.592695543842936, 62.404909441548014, 60.362927452210464, 63.41849304014637, 54.539011832206484, 59.83310153407436, 59.284463928591826, 60.01248721153506, 51.470733842542096, 46.11141120233844, 57.483288011243275, 62.00461587598247, 63.21860513379497, 62.633673837108, 62.15516821030648, 62.356542694953184, 59.163541178549494, 51.320691416340495, 49.95996629038165, 50.14541987449893, 49.9196364802699, 52.26460979830835, 52.80669312323294, 59.38140138503044, 60.80414310578377, 65.80169377788421, 67.13132627548711, 68.14914211150139, 68.15347240817162, 72.65851851432555, 69.4713338728874, 71.95459427372103, 71.47073853400447, 73.4601019274804, 72.63207389462379, 76.67772416145571, 76.83858056222239, 57.09997830852386, 8.127823193227092, 1.6790996227533588, 44.396460748487904, 76.03705990699031, 53.68394297938193, 58.135605627490634, 42.25022608234037, 64.32478804742136, 42.369219026257916, 42.67224957866054, 47.776186696944706, 66.56703056827669, 73.36347826065557, 1.2691816639515663, 0.06959632234347445, 0.12243098564325802, 0.040103618821669976, 0.06044382011638053, 0.03316257111427765, 0.057728026933487386, 0.05748584738842422, 0.13598877305705703, 0.21634352093021716, 0.13824488667230453, 0.13803309400475797, 0.10004497719027343, 0.14271432023134925, 0.2821734715853968, 1.2656626850366592, 18.957713265572828, 9.674267153586111, 48.90418191109934, 57.39872171032814, 39.580064742795884, 41.8699562165045, 71.71204274700534, 50.340267535178896, 50.14044238675026, 65.29576293883785, 79.2950668642598, 75.93988710834135, 32.04287940456022, 0.7281242839751706, 3.1436865368197044, 13.660165013805514, 63.29143962552471, 71.11786642382222, 82.530441745635, 73.81134233167096, 77.22847984683129, 74.1035589095085, 77.79329330690446, 68.89379624397525, 74.65863704681396, 70.93303649656235, 70.52284286868188, 67.18995786482289, 63.207959821147305, 57.98954440701393, 54.787140969307195, 55.270820202366004, 54.71919375081217, 52.805771366242446, 51.657752452358125, 51.71147715660834, 55.26532888412476, 58.623077792506066, 67.158798556174, 69.27169307585686, 63.27647578331732, 61.78025237975582, 63.19285085124355, 60.49446021356891, 53.580408096313484, 54.969805748231956, 55.56987347141389, 57.35372427971133, 62.26302554530483, 61.29039541367562, 65.52777897927069, 60.644290831781205, 62.51404546922254, 61.390808090086914, 55.783430837815814, 51.63443788405388, 52.670653558546505, 53.702687986435436, 51.94918847853138, 57.8387684975901, 62.47057384060275, 55.01903149389452, 46.31614715822282, 42.51482525179463, 49.67202117366176, 50.672084362276145, 47.21853548480619, 50.86949333067864, 55.32965183258057, 52.86219466117121, 50.60256427334201, 47.2520129142269, 47.271848340188306, 47.36088222072971, 45.76972569188764, 46.93118264598232, 46.464381371774984, 48.04576335414764, 52.89912769871374, 54.787035065312544, 53.17572539852512, 52.99155050708402, 48.15344418248823, 44.174619336282056, 48.28379631042481, 49.24688331542477, 47.13256497536936, 47.350542852955485, 46.79141290726201, 48.38406385913972, 45.78793725659771, 51.4098939587993, 51.50983595078992, 53.775106706926906, 44.33407937326739, 52.98232117006856, 49.88970095111478, 40.54855285152313, 50.89769517221759, 51.23163007920789, 54.41623380107265, 55.79744938881167, 53.944235386387, 51.55338602681314, 51.57986987021662, 52.920339876605624, 53.126719305592204, 54.055869963861284, 59.345299889964444, 61.54192524571573, 62.6554508363047, 61.91599776667934, 63.98800549968597, 54.56460529758085, 65.04347216698432, 61.911600789716175, 62.35256933396863, 54.03970587638117, 47.5066335739628, 59.04595636552381, 62.80889787981587, 65.44975519180298, 64.43122940678751, 63.488664242529104, 63.127712049791896, 60.9253208098873, 53.322308294234745, 52.59380648213049, 51.02781980268417, 52.33114104117117, 53.53932126875847, 56.26964784437611, 59.82457822368991, 63.16268390224826, 69.52467026249056, 67.1765668930546, 71.03327658868605, 68.84500980377197, 75.62448932278541, 72.69098789461198, 74.64617959914669, 74.07813410605155, 76.67990499927153, 74.98512729521721, 75.47177576249646, 77.93998210660874, 57.12778399067541, 7.427442814073256, 1.5918896443420842, 48.77311983416158, 79.57461418644075, 61.85712691276305, 66.83171995224492, 51.920343368284165, 65.60787377818939, 46.74785890886861, 52.896719363427934, 68.12595305904266, 76.10920013919954, 88.49754348877939, 2.3984509129678053, 0.1583378560720913, 0.16594212141729173, 0.1324289463340275, 0.14103367654306276, 0.13594879858916806, 0.14264371756824756, 0.18786334432661536], [0.020929234808370955, 0.1277636853797782, 0.028178267098302325, 0.05408753115203112, 0.033497834172580516, 0.03808118883640536, 0.14401892200112343, 0.16462841852297708, 3.0790135168260147, 2.95958322863425, 8.261943248010452, 36.90873845931023, 34.436872543827185, 27.156176874714514, 34.85381657077421, 42.68933542313115, 31.126399963132798, 45.68608899270335, 67.73475154753655, 71.57918422452866, 23.182796278307517, 1.344761692227856, 2.682974006860487, 12.542753334968323, 17.424003770274503, 62.302770922260905, 69.20191411049136, 67.90730445615708, 67.9902861195226, 70.2206007126839, 67.04575584780785, 66.58100989557082, 65.21966895749493, 65.2689653058206, 65.94854339476555, 65.61411034676337, 61.0533469723117, 54.06243993389992, 50.29161053319132, 50.788896468377885, 49.937655848841516, 49.59476224837765, 48.516867468434, 51.26047911182527, 49.09422074594806, 58.53961367760935, 62.15099088607296, 60.298796699893096, 56.9348112229378, 60.04588619355233, 58.992780793097715, 56.29132286194832, 51.56374500643823, 50.56472124591951, 51.57311162640972, 58.13217355358986, 57.257681123672, 56.33698317312426, 57.15984544446392, 56.333037268730905, 58.63615497466057, 53.76879169094948, 49.26649124391618, 44.19656107502599, 43.03005603051955, 44.340210037846724, 45.83329554527037, 49.09376967337824, 56.2230775433202, 54.911491870880134, 36.762983183706964, 29.287369251251224, 32.75685079636113, 45.44036819088844, 40.22610656676754, 42.57929332794682, 42.10223113336871, 46.072316938830966, 46.16979175998319, 42.31277219710812, 41.802067833562056, 42.06647872924805, 39.52004855678928, 41.77911020094349, 41.57878298913279, 42.78206809874504, 43.69968698870751, 45.904113938731534, 45.53891774146788, 43.612928082866055, 44.07917238050892, 42.24906113839919, 40.79058662537606, 42.42581882784444, 41.96239471435547, 41.159830708657545, 39.95940108453074, 40.19337046530939, 44.61277161875079, 41.878891375757036, 44.570994454045454, 44.648853501965924, 39.04082513624622, 48.164289536014685, 36.47806221438993, 31.181736761523833, 41.00994125489266, 41.51123193002517, 46.26219495650261, 46.95940017700196, 45.49217877849456, 45.08901403796288, 43.98411373938284, 45.395492353746974, 47.14257094167894, 49.119143486022956, 50.67244914270217, 51.74622151159471, 55.77642940705823, 54.638596888511415, 56.87578347421462, 57.02567292797951, 53.748791525440836, 57.14368920172415, 53.981592039908136, 47.32168989796793, 43.04985223277923, 53.56417732854044, 56.69100061539681, 57.11286721691009, 58.27010370069935, 57.57047837780368, 59.19009562461608, 52.97862629736624, 46.42747971319383, 45.30674872859832, 47.214903370026626, 46.033752195296756, 47.966825654429776, 49.664905994169175, 53.910102921147505, 59.536538970085886, 61.11942322023454, 61.6536618048145, 65.9725247659991, 64.89529286661457, 68.18933071628695, 64.7333146679786, 67.85549779092112, 62.075477415515536, 64.59228192606281, 68.38258589467695, 70.92450926380774, 64.68554412164997, 53.944513874669234, 15.92897374783793, 2.5240569729958815, 37.452378965193226, 65.77739469466671, 35.73532219856016, 45.91128403140653, 35.298276024480025, 39.79453602144795, 35.15027715313819, 48.603751890120975, 59.81345438188123, 70.42177123408165, 17.791065054555094, 0.6048157522755285, 0.3204739760727652, 0.08947207517321072, 0.18592425321619357, 0.055859381438142834, 0.08582658449848814, 0.015738255592183243, 0.13171234768965553, 0.09416850058421974, 0.1469050816470577, 0.06474882439379731, 0.0319654859542366, 0.01320782887388862, 0.08449928354351752, 0.038668988948507656, 0.05695414023413774, 3.7996727949188607, 4.315668680975515, 22.753145733187278, 49.42247213855867, 27.73835074517035, 31.12929467231997, 50.00840756200975, 39.67899868565221, 43.065071029047814, 50.15194669846566, 74.24264615581882, 77.9227158331102, 28.665693190789995, 1.5302476358990518, 2.8064762055873875, 14.677022810905212, 25.676333288992605, 73.25501688065069, 69.66294950054538, 72.72959970658826, 71.3337693675872, 74.7302124577184, 70.98421558257073, 71.61112016247165, 70.04876167543473, 70.20582906661495, 69.62231374556019, 69.3573497956799, 67.10631724326842, 58.218716729071836, 53.39391508410054, 54.36130100680936, 54.45720687989266, 54.38874583090506, 52.475115560716205, 55.44731901537988, 53.09215930200393, 60.13375513015255, 64.70238677916988, 62.346148413996545, 60.475456330084036, 61.22255802154542, 60.9852820827115, 58.679148074119325, 52.99160149789626, 52.71640800660657, 54.294153951829486, 59.09223248881679, 60.65115497958276, 57.90621757507325, 59.08359542969735, 59.55674309884349, 61.14666408108127, 55.532104969024665, 51.008376613740005, 49.072314308535674, 45.506848442939024, 45.0778195934911, 48.12897643735332, 51.47644481351299, 57.6930328338377, 59.746907449537716, 42.87959783307968, 33.824461121712964, 34.81400843589537, 48.13749974773776, 42.048580954151774, 45.29905696069041, 46.42296898749567, 47.337116579855646, 47.75979903436477, 45.574407346787, 43.04836957685409, 44.48487489454208, 42.39315332904939, 45.084585682038345, 43.42088491685929, 45.35987723258234, 44.58908050291, 47.88797816922588, 47.79103679041709, 46.3813094938955, 47.00031442026938, 45.25182770144555, 43.88133587375764, 43.15717612543414, 43.238733968427105, 44.02453768637873, 43.06261562531994, 43.00071277926045, 46.04717846839659, 44.33401661534464, 44.22213100617932, 48.51341186031219, 40.46851688815702, 50.47154926484632, 39.88819045405234, 34.96971868699597, 44.054602653749534, 46.89750125331264, 52.32998786434051, 50.2017843338751, 50.17440226770217, 45.69675783957205, 46.133505913519095, 48.21010674199751, 50.18087417848649, 52.463972107056655, 53.52192555704425, 53.70106020281392, 57.558150368352095, 58.498852406778646, 59.892835309428555, 59.07823354967179, 58.08966682803247, 58.419196913319254, 58.203097851045676, 52.684189658011164, 47.84138041157877, 56.64756821047876, 61.18160063220609, 60.45901375432169, 61.19574077667729, 60.63691285348708, 61.67144975354595, 55.89309638546359, 50.00824282246251, 48.57737787308232, 50.46918799800258, 49.03850740002048, 53.655039033582135, 53.14544862316501, 58.43399209360923, 63.30065719542965, 66.44735120957898, 67.33649761446061, 72.38257977270311, 68.6589325627973, 72.07049246757262, 69.91198862752607, 70.37022344527706, 67.15479773859825, 69.3952791152462, 71.43424480192124, 75.56030365728563, 68.38905780546128, 62.31555000428231, 20.192520503074896, 3.2407583344367246, 40.26468699978244, 69.37317263695502, 42.21303809073664, 51.80621024101011, 39.970215059095814, 54.30644665994952, 42.168099495672415, 46.08200911552676, 63.053014432230306, 77.27558751260081, 15.265197907724689, 0.627542516637233, 0.3752799981063412, 0.12875284278585067, 0.1446866442359263, 0.04720778580033972, 0.14306598523211095, 0.05081786023032281, 0.12282185136310517, 0.13564155136625614, 0.3449429469483514, 0.1445255512672086, 0.2118711609153017, 0.21770560993782936, 0.1809518063260663, 0.17747441066368935, 0.2622690057802585, 4.504863715940907, 2.369262840478651, 59.3214322674659, 59.949333129390595, 57.96211135002875, 38.02316227266866, 51.57771648899202, 58.68564351912468, 46.01768224470077, 63.21196456109325, 78.75732560311594, 83.10539061023344, 31.28428124612378, 1.6603244624791609, 3.9163990991730846, 13.659941438705692, 36.27903330710627, 80.85189480935374, 74.51612949371338, 74.39908596777147, 73.07802384899509, 75.375865967043, 72.4582266038464, 70.65086118636593, 69.86837971595027, 70.96807895168182, 71.12789984672301, 71.60282042718703, 67.37524278702276, 59.32655096054078, 55.698942984304125, 56.90296942187894, 54.43122902224141, 54.57941224498134, 53.397488363327525, 56.13700505225889, 53.3861566358997, 63.32493666679629, 67.02764234235211, 65.13979381130588, 64.34445481146535, 62.288968101624526, 62.349749149814734, 62.50213715337939, 56.541981927810184, 55.62610849257439, 57.48333115731516, 63.22980350063693, 62.892860135724476, 60.226397591252486, 62.310917685108805, 62.77820141084733, 66.45980081250592, 58.508838761237364, 53.68131891373665, 52.13949403455181, 51.417515124044115, 49.497640440540934, 52.776392813651796, 55.8141782975966, 62.19229736635762, 62.710175744948856, 46.444247845680486, 40.41808305248138, 44.100670891423384, 51.95335403565438, 45.263316323680264, 49.362146085308446, 49.53848800351543, 53.610979049436516, 52.85024319925616, 50.186181145329634, 46.99245791281424, 48.788934830696356, 45.67581630522206, 48.431889318650775, 47.100911448078776, 48.773978833229314, 49.82746078122047, 50.562050111832164, 52.01686113111435, 48.34418904396796, 48.38810782278738, 47.96565678811843, 47.75084426326137, 47.34955833804223, 45.23234921116983, 47.68251265248945, 45.06531899975192, 45.28350476295718, 50.13141701298375, 45.730482378313624, 48.72068166732789, 53.58202411282448, 44.041262672793486, 53.599160948107325, 44.487757836618734, 38.98334672374111, 49.37377983523954, 51.11934438828499, 56.668239101286865, 53.38004558317123, 52.52059936523438, 49.65865765848468, 48.45069316125686, 51.48593302695982, 51.224707095853745, 53.85271864552652, 53.94543170928956, 54.9658598438386, 60.61299816254647, 59.19879544165827, 60.839824907241336, 59.66214895248414, 57.69057350773966, 61.16541693287512, 57.6115220592868, 54.819939828688106, 49.219289441262525, 58.311888710145034, 63.45355118474653, 61.78121728281822, 62.12570336557204, 63.99059034162953, 63.340175074915734, 59.59100892466884, 53.187672938069994, 51.61799138592136, 51.67443821507116, 51.212241803446126, 54.218671860233435, 54.92738923718853, 59.771587002661924, 66.85727027154738, 70.23196774144327, 69.62061928164574, 74.75034206144272, 70.5657849773284, 73.97931391193022, 72.43616719399729, 74.74266990538567, 69.4109764406758, 70.5770343349826, 74.27915557738274, 77.70793468721452, 72.59656859982398, 67.67379007031842, 20.186731084700554, 2.98000235230692, 44.08897046119937, 79.13052343553113, 47.86619332528884, 62.40527422197404, 43.57546160298009, 55.047037216924856, 48.82431853202082, 66.33746993157172, 76.7312958932692, 89.52691462732132, 26.41163452979057, 0.9389653477457263, 0.44200634824172147, 0.2509668799898317, 0.3218446299433708, 0.09666498960746873, 0.24378874339163306, 0.25104784016166964, 0.3221620354921587], [0.03160533269927387, 0.04331756833820574, 0.055487120163536845, 0.026140865839777455, 0.018102751496518334, 0.04585984643668898, 0.1377552492363799, 0.08320300914948026, 0.11871047197811066, 1.670277231643277, 11.777444981759595, 53.609414023737756, 36.921297888601984, 30.598896088138705, 33.381558848965554, 43.98000309544225, 31.195651369710124, 39.10197488723263, 63.57130465968963, 71.05474764300932, 30.105775710075136, 1.5511705389907284, 3.3244021429169566, 12.374016892525459, 12.989732911509853, 55.71911965647052, 65.43117100192656, 59.50914121443226, 61.77949928468274, 60.73941223083004, 60.8345453969894, 60.7300534555989, 62.48638883713753, 64.85717135090982, 63.3214496797131, 66.3355322807066, 65.0304538203824, 59.52197913200625, 49.28462043885262, 50.217109034138346, 50.671409714606504, 49.20498063487392, 47.259618389991026, 49.75636389947707, 48.04820699076499, 53.81030997922344, 59.29855700462096, 57.45064212429909, 55.23973934112057, 59.35663946213261, 56.508575101052564, 52.57766985124158, 50.70777400847405, 50.61921473472349, 54.26945870922458, 57.51946795371271, 59.47791130312028, 60.109679622034875, 57.566183382465, 57.332547403151, 56.822600057048184, 52.739420552407545, 48.84431477515928, 45.732659293759255, 44.35046703584733, 43.88420704872378, 44.04446332685409, 47.07492574568718, 51.20838611356674, 53.44517261751237, 47.43494833669355, 29.45832967758179, 26.86958693688916, 43.75273704528809, 40.57051027974775, 42.62059980823148, 44.27249031682169, 42.34801861547655, 43.750881764196585, 40.05946466999669, 39.536899059049546, 38.43219880134829, 38.617926951377626, 42.609307304505386, 43.46470955879458, 42.880798078352406, 44.68139348491546, 44.55037847641976, 44.503404171236106, 45.797586287221606, 42.12935824548045, 42.196430775427054, 41.79104989574802, 46.511124257118475, 44.34182997672789, 42.348108829990515, 42.908662596056544, 44.92872245850102, 43.70336224955898, 45.86063446537141, 40.83643128795009, 39.54046057116601, 39.939404841392275, 46.21249068167902, 31.483888703007853, 32.975895558634114, 39.60907459259033, 48.81173164613786, 49.04275140454693, 45.251443309168664, 43.94081861742082, 41.876145716636415, 42.4546286367601, 44.29582449697679, 48.28445919098393, 48.04055052418863, 47.60447317554105, 49.56969045823621, 52.09705006691718, 53.75868374301542, 56.60217462047454, 54.429205079232496, 54.4244864679152, 54.96275332666213, 56.20637609112648, 47.68299510402065, 46.33442540322581, 55.73045530626851, 56.3765638105331, 58.5975706192755, 57.484358818300315, 58.9407427080216, 59.11858689400458, 52.501662162042436, 46.447479878702474, 47.91914140024493, 47.235264393591116, 47.520659969699004, 47.9364743540364, 49.29009606761318, 55.294687824864546, 58.59545646175262, 60.40615589387956, 64.35690049202212, 62.93096596194852, 65.12629693554294, 66.18332862854004, 66.37870188682311, 63.90030130263298, 63.814703418362534, 63.31826471513318, 62.14883358247819, 65.079930597736, 60.03971630527128, 56.80802060711769, 26.039266278666837, 2.896928268094217, 35.521949183556345, 60.60142324816797, 35.52514591524678, 42.625161524741884, 32.948795903113584, 39.713664593235144, 48.142736111917806, 53.68464508364278, 62.55849376801522, 40.828512022572184, 0.2688211412920106, 0.017035933842341748, 0.04981939485597034, 0.0321625352596804, 0.03607603796427289, 0.09775532424570092, 0.04592260818988566, 0.04211482178840426, 0.06596067589857886, 0.06131645171873032, 0.021893369867616606, 0.0719085518991755, 0.025739299786847927, 0.005057726361443319, 0.01730588407466008, 0.03851134720588884, 0.20774046079285685, 0.12465057218627584, 1.8375687709739132, 17.538774282701556, 66.80535377994661, 35.315710959895966, 32.13619259095962, 50.66475345242409, 39.54475948887487, 39.07032528231221, 50.844005769298924, 68.3048366731213, 79.73491361064296, 34.07957600009057, 2.158873523435285, 4.300625901068411, 13.461734267973132, 18.06700575736261, 64.77828856437438, 69.84032692447786, 65.28685131380635, 65.01155584089219, 65.41739563788137, 65.10552014074018, 66.79284926383727, 66.86784498153195, 69.04971830306515, 66.42507999174057, 70.76693980924546, 69.98624693962836, 66.00348011139901, 53.55968229232296, 54.30814896860431, 53.16839056630289, 52.07962297624158, 50.22478903493574, 52.14748390259282, 50.86050718061386, 57.727518312392704, 62.88634900123843, 62.38269705926219, 57.86241254498882, 62.637509915136526, 58.861797163563395, 53.004898332780414, 51.80548068015806, 52.67286969769386, 55.474308844535585, 60.546435540722264, 61.32719116826212, 61.714427163524014, 61.76659860918599, 59.2132140744117, 57.508748116031775, 54.41244479148619, 50.57934776429207, 48.97740079510597, 45.344983993038056, 45.11900448030041, 47.19376179479784, 49.38683348317301, 53.37617812618133, 57.06114292144776, 53.320633442171165, 33.76717098297612, 31.187877232028594, 46.08434292577928, 44.45311546325684, 44.05334749529439, 47.265592159763465, 46.6469677032963, 48.2503031915234, 43.447125573312086, 41.47521672710296, 42.11643795813284, 41.2878058802697, 42.59937586322908, 46.031061449358546, 45.91294711635959, 49.3805145448254, 46.077043394888605, 45.81266387816399, 46.77225997371059, 43.57383774172875, 44.75225502444852, 43.66194986527966, 48.47869888428719, 45.17040321903844, 44.053637750687145, 44.858563023228804, 45.73174930387928, 45.893998146057136, 48.59778988745905, 44.66545689490534, 43.06969550348098, 41.5761040103051, 48.42448780613561, 33.18205533489105, 35.979505431267526, 43.159455022504254, 55.05861213130336, 52.3122783630125, 48.31682266727571, 46.787474847609, 44.8823521983239, 45.14005976338541, 48.410245680039935, 50.308982710684504, 51.79299969826975, 50.80778268075759, 52.33329834476594, 55.81736718454669, 55.80705527336367, 58.954576907619355, 57.59823699151316, 57.21530775870047, 58.60914945602418, 58.21295476728871, 51.03826115208288, 49.115727101602864, 60.272963969938225, 60.924391208156464, 60.24891199604158, 59.84464899186165, 62.528617074412686, 62.389451380698915, 54.201468344657656, 49.92348432540894, 51.06301523024037, 49.46278233681956, 49.82937489786456, 51.47544853148922, 54.491386413574226, 59.81712964273269, 63.835954819956136, 66.19876707753828, 66.65482105747347, 67.99150989901635, 69.09722605059224, 70.09149982083228, 70.62896651606407, 67.13588406962734, 67.67239370653706, 69.53307197939965, 66.5664186785298, 67.93979737066454, 67.66458818989416, 65.82032111383253, 32.345649119346376, 3.5023904760037703, 38.92534663600307, 67.65843006872362, 44.80622291564942, 47.1948443689654, 40.796223071313676, 47.2246112362031, 47.93271280104115, 52.17907074959048, 67.71046423142957, 38.25022828194403, 0.2949266291914448, 0.08201883640140295, 0.02470983849507907, 0.011908294775733545, 0.006603192399075676, 0.11164626797601102, 0.007146091140325993, 0.011513205996203807, 0.059855093037889856, 0.17993500846768581, 0.1392613014867229, 0.15192049074797861, 0.21912736187298454, 0.13755323185074714, 0.2315447124983034, 0.21380470554915168, 0.2165563095120653, 0.19224270126752316, 1.1585088026139045, 49.996456100094704, 76.22029735196021, 51.09826949334914, 41.84421370106359, 53.78606580918836, 60.922928164082194, 41.918907396255, 57.40940232430735, 75.11436939239502, 83.73187157415575, 36.73276524389944, 2.7551321348836346, 5.213845852882632, 14.002786009542405, 22.658700942993168, 68.71376729780629, 69.85300402487479, 66.99102309442335, 67.70640850067139, 65.67751938296904, 66.1206256189654, 66.34080394621819, 67.07778592263499, 69.06481942822857, 69.19581090250324, 71.54706785755774, 70.73825943854548, 66.54469659251552, 55.320991239240094, 55.3577713043459, 54.55708219159035, 53.65606277219711, 52.39077675727106, 53.83451884792697, 53.18061659413, 59.93347106441375, 64.02901387983754, 62.18879861216392, 59.73255157470704, 63.18550032954063, 61.12562840984714, 55.37080926279868, 54.48448304207095, 57.00161703171269, 57.421585206062566, 62.597148726063395, 64.51726659651726, 65.02000462624335, 65.35322173949211, 60.22171428126674, 59.09564102849653, 57.71062858643071, 54.88979331908688, 53.869828024218165, 49.74476152850736, 49.447010486356675, 50.4365264215777, 53.87793556336434, 56.48611560944588, 59.20234126429404, 56.26989495369696, 40.38045183304818, 37.517627593009706, 50.13667298901466, 47.481742212849284, 49.813536367108746, 49.16376044673305, 48.32774646820561, 53.46824399886593, 44.63830624857257, 45.00684822759321, 44.33503250921927, 43.766806587096184, 49.55678193799911, 51.35339613883726, 48.25965019964403, 51.233136269354056, 49.37030069289669, 49.76306723010156, 51.621811774469194, 47.492599333486254, 47.80261954953594, 46.58586894312213, 50.22327500004923, 48.36378912771902, 46.42425552491219, 48.03715375161941, 50.07007898822908, 48.43599604022119, 51.53677871150356, 45.423270579307314, 46.30812198885026, 42.94673704331921, 52.010997187706735, 41.16435320146623, 42.44445793090328, 46.49805884207449, 59.21188439092329, 54.802987344803356, 51.50713343774119, 51.249398416088475, 50.07468777318155, 46.89674423586938, 50.1600738494627, 54.69934655774025, 53.621930306957616, 52.23305040790189, 54.315370052091545, 58.42289963076192, 56.31254288458056, 59.91605574084867, 59.687240354476444, 59.71941555699995, 58.39563131332398, 61.61304173930999, 54.06079646079771, 51.76244443462741, 64.62626926360592, 62.12114949380199, 63.31877070088541, 63.01841912731048, 64.7197275777017, 68.11746504998976, 58.5586214834644, 53.51635971376973, 54.04258097371748, 53.71332545434275, 52.10133721751552, 54.16473534799392, 57.66052030747937, 61.2479357565603, 67.25029176281345, 67.96576346120527, 69.59935219057145, 69.02106146658622, 71.00123866911858, 74.61561649076401, 73.52584869630876, 70.03468821125647, 71.85398547880112, 73.55050471521193, 70.61333194855722, 73.79118134898525, 77.11382112195416, 71.53893286182036, 32.8194792809025, 4.106480344649285, 42.508725966176684, 73.69946064487581, 51.59628891175794, 54.95610098684988, 44.57894117601457, 56.886923005503995, 66.39224190865794, 74.20829403784968, 78.22106699789725, 61.83058423380699, 0.3679551250271259, 0.14359351337677048, 0.11498227445108276, 0.1089853918059699, 0.10668600188387979, 0.19188412615368444, 0.13615692935643658, 0.09773887633796662, 0.15952720757453673], [0.11017775403395777, 0.06800397028846127, 0.0449159303529849, 0.004486929570820424, 0.04796026034220573, 0.06851207810424029, 0.04507227740701168, 0.004915882788238026, 0.12599679551297618, 0.4864535745113127, 8.132171140563104, 50.62645150769142, 50.72461666599397, 28.769310443632065, 39.04891306354154, 34.608095768959295, 39.53454171457599, 34.9708051835337, 55.598553842113866, 70.51790068226477, 33.03983803718321, 1.68410248333408, 3.901601467401751, 11.22897505760193, 15.494223140901136, 61.124973374028365, 66.82794663213915, 63.262943606222834, 60.38173129481655, 66.70646298316218, 69.75832585365542, 69.78192283261207, 68.57010656787504, 66.14405001363447, 63.9520844336479, 65.37148037264424, 63.4710253438642, 56.6389193842488, 50.2366110586351, 49.833254121964984, 48.84688784999233, 46.94335376062701, 46.92924107274702, 45.87834004432925, 46.36992285328527, 51.907383857234834, 57.14260662755659, 58.41596488029727, 56.14063324466829, 57.8036593621777, 55.3215717500256, 52.33683632266138, 48.595052073078776, 48.511474209447066, 54.49970576070971, 58.95263533438406, 59.58596475662724, 57.576099134260616, 56.807157685679776, 59.99699777172458, 57.71633171266126, 54.87008340897099, 48.628109808891054, 46.180233109381895, 45.61530590057374, 44.723566809008204, 44.20643760311989, 45.71819751493393, 50.132750618842344, 52.621592552431174, 53.02116440188501, 33.86360245366251, 23.30814346190422, 38.93487015078145, 40.644184158694365, 39.59527177195395, 45.139494942080596, 44.983874905493956, 45.826917771370184, 40.806691877303585, 36.84903214054723, 39.03121925169422, 38.209839636279696, 35.99907413605721, 42.91936674425679, 40.91918937621578, 42.99320928512081, 45.94904861142559, 43.478186822706654, 43.27229376762144, 41.31088118399344, 42.95020441855154, 39.06342583317911, 42.96805120283558, 44.33602486887286, 41.46549709381596, 43.090103595487534, 44.4211716805735, 44.50839342609529, 40.2540103081734, 44.470444494678134, 39.47443923642559, 45.07218314755348, 41.3900738377725, 26.418431997299198, 33.75998127845026, 44.49411599866806, 53.23828328040339, 48.75202140500469, 44.605923160429924, 41.25756048387097, 41.421064484503965, 41.92514788719916, 47.98081282646426, 47.03629432186004, 45.85421354539933, 47.464570076234885, 49.598814056765654, 50.18337272828626, 50.36130320641303, 53.542521922819084, 55.33471561247303, 53.58662113066643, 56.01638040234966, 54.429773822907485, 44.928573408434474, 47.097114593751975, 54.42603972650344, 57.74477281878072, 55.03428951386483, 56.041456114861276, 57.67047528297671, 56.651361142435384, 49.91607889052361, 45.104303436894575, 46.37023664289906, 43.4518559517399, 48.62801174963675, 48.307020664215095, 53.6071547385185, 60.8043941374748, 61.49572364745602, 61.800695773093935, 63.3361703349698, 64.45020975605135, 66.7672283418717, 64.86170168845885, 63.25615398345455, 62.43431937310004, 61.89073770276962, 57.70554519468739, 61.49439788633778, 60.52226589572046, 60.69556013230355, 63.46381602748748, 33.83857380959296, 3.0394593554158367, 41.090494971121515, 57.41881209035074, 32.8264356044031, 47.10743434967534, 29.306832052046254, 45.98796244590513, 47.222999142062285, 49.6322444177443, 61.027404415992, 4.5195216132748515, 0.40599804011083424, 0.154569638111899, 0.0629637131257163, 0.12489857783000316, 0.030254327068706195, 0.1766289713522119, 0.0597073951165282, 0.030066133739667076, 0.06015513903431355, 0.09360544128163208, 0.022076558727290363, 0.03329348404921832, 0.016295521354843533, 0.08179164536657833, 0.0887002339286189, 0.04507541453706161, 0.03960440145625223, 0.16990153960162596, 0.41447069676172354, 9.933006302002939, 68.84572367514335, 57.79764636870354, 23.402335259222216, 50.61670441781321, 38.94225205144575, 41.587239619224306, 50.17069562788933, 56.92629967966388, 80.97423353502828, 36.40522380029002, 2.468254883443156, 4.169933997815655, 13.033524213298676, 18.63995421317316, 70.19969447966545, 67.16230515510806, 66.87100641189083, 64.54779048119822, 71.91540979569959, 72.94322767565328, 75.23459788291686, 71.3265129827684, 71.25323526320919, 69.06305436165103, 70.45457793820289, 67.21992477293938, 60.691928017523985, 53.829517825957275, 53.22264479052637, 51.47011803042505, 51.44339492244106, 49.485747814178474, 50.339200650492025, 47.263274038991625, 52.47334264939832, 60.95671546074652, 61.08084670958981, 58.07868026917981, 62.39658617204236, 58.2603487660808, 55.82456473381289, 51.10512187404018, 53.06530675580425, 57.159370837673066, 60.52301506842337, 62.47079741570258, 60.51837882687969, 57.76143504727272, 61.8255949789478, 58.55435394471692, 55.79844567083544, 51.196568012237556, 49.88866544538929, 48.86738615651285, 48.1881610808834, 47.84378874686457, 47.13267872410436, 52.180522026554236, 55.16219800518405, 55.82310561210879, 39.49470220073577, 27.26817427142974, 40.487363876835, 41.38493161047659, 43.160718025699744, 47.15451455885365, 47.56685764558854, 47.18182209999331, 42.1277500737098, 39.17574290306338, 42.977500192580685, 41.6198698166878, 39.20534110838367, 44.6987578176683, 43.970436434591974, 45.60324853466403, 46.62615952953216, 46.159534761982584, 46.64468880622618, 44.81638969913606, 44.09179064535326, 42.588110816094186, 44.34393236714025, 43.839986247401086, 43.38432450448313, 44.65041068292434, 45.81837484913488, 47.88092967002623, 42.5256117697685, 47.31740666973976, 42.978245442913426, 49.16957732169859, 44.87570378088182, 28.52123818089885, 38.3536337267968, 48.907668898182536, 57.86699387335009, 50.679646691968365, 47.70841598510743, 45.158200725432366, 44.44551390986289, 43.080685984703806, 51.207005439266084, 48.56043715630808, 50.37602386166973, 50.22419675703972, 52.8475171519864, 53.86245396829421, 54.07794898556125, 56.33097802439044, 59.19628512474799, 56.40978236352244, 60.23028858246342, 55.385722114193825, 47.63238083931708, 48.57065885297714, 58.53278483113935, 61.94045374470373, 60.46293220212383, 59.76393053608557, 62.45049915006084, 60.941735929058446, 52.5106365449967, 47.20136334819179, 50.33216391840289, 48.125732637220814, 51.782213180295884, 51.89078830903577, 58.37714910507203, 65.47814922948038, 66.05680081152147, 66.14942366077055, 68.17495915197557, 68.74209465519075, 72.4538335492534, 68.23523029204338, 67.93530233444707, 68.29992586566557, 66.40517788548624, 63.087739175365826, 66.50160543380245, 69.65330831466183, 69.57193482306697, 71.80456361462994, 37.00124363745413, 3.524085350574986, 45.894963049119525, 63.50481264052853, 42.57774399172875, 49.068305646219564, 33.84662251318655, 55.34019124123358, 43.766198619719475, 53.26538293592392, 67.73700298801546, 2.1187251229440016, 0.24667741580595895, 0.0915877418892999, 0.13096818520176795, 0.04185706767584047, 0.03765804783230828, 0.039081251504079956, 0.05214067191005715, 0.030710900149818872, 0.15624616024715288, 0.30617684486412233, 0.12859007974545802, 0.13891830860126403, 0.1011086060034652, 0.270758516365482, 0.23613868131031915, 0.20811221261899318, 0.29710179795661285, 0.34156661360494556, 0.6691273013430258, 28.033893492914018, 86.11489972760602, 69.17726593632852, 46.78701593029884, 49.392387559337, 49.72203531572896, 51.65213954064154, 50.76651150180448, 66.14139064665764, 84.62293209568148, 40.798168566919145, 2.98684002410981, 5.001703971816648, 14.076717784327847, 24.646158064565352, 73.01572876591837, 66.30079577046057, 65.58468472573065, 64.27879041241061, 71.40644304213986, 75.94670418770083, 74.53417239650604, 73.53312077060824, 71.5577837728685, 69.38133116691344, 71.63330508816627, 68.53576229464623, 60.054852731766246, 56.838391519361934, 54.33567224010345, 53.8184763539222, 52.285586633989894, 51.79726331464706, 50.58502343393142, 48.71481772392027, 55.614988573135875, 61.90102215736144, 63.387467092083355, 60.32243290255147, 62.72345689035232, 59.64456888937182, 58.89396844371673, 52.33524384037141, 53.81136117442962, 60.38668132597401, 64.65078799955307, 67.01328646752143, 63.53346947700747, 60.83826380391275, 63.3864825771701, 62.30611670401789, 58.19174258939682, 54.004773247626524, 53.45751239407448, 51.84178221610285, 50.05584470687374, 50.48917247403053, 50.43644797417426, 54.766066074371345, 59.32648428024785, 58.64068923457977, 43.20039672236289, 33.806308392555486, 45.24144126522926, 45.61360751428912, 48.633291259888686, 52.665287756150775, 52.78100552097444, 52.89744107953964, 46.71918638290898, 40.54391268760928, 45.45718731418733, 44.27724422947053, 39.495219953598514, 46.511787137677594, 47.83594792889011, 48.42346406752064, 49.65795555422383, 49.79292038948306, 49.03405158750473, 47.53972268873646, 47.70312470774497, 42.645502936455514, 49.15030279467183, 47.05150527338828, 46.17186277143417, 47.90179667934295, 52.18435025984242, 50.56197558679889, 46.487782232223026, 51.15557532156668, 46.81069135665894, 49.362000957612075, 46.59099940330752, 35.957861792656686, 43.98081502606792, 52.35706790801018, 60.07253477650305, 55.182570795859064, 51.076465037561235, 47.29098950662921, 48.177252969434186, 46.215051989401545, 53.68511969043363, 51.41989600273871, 53.26366101541827, 52.88182612388365, 54.57175185603481, 56.020369452814904, 57.09716204674014, 57.59560115875737, 61.31884436453543, 58.19138565371114, 62.85926895756876, 58.980174295363895, 50.332850333183046, 51.257470653903106, 60.37394931239467, 63.96896631486955, 60.92977662240306, 60.37409444009105, 65.48051441869428, 62.481980093063854, 55.51120265837639, 50.32895541960194, 52.11657954800514, 50.35259162226031, 54.23546352694112, 54.45564577656408, 62.86370123586347, 69.18399672354423, 69.91416162060153, 67.60060648764333, 69.11054641969743, 70.18116520297143, 74.9133949895059, 71.00628283716017, 72.33534659108808, 71.20262884324598, 72.18232708592569, 64.33794759934949, 72.12635486356675, 72.46288637961112, 74.37282177709764, 75.05350205206102, 39.92431548333938, 4.011528833258537, 49.53985691070557, 68.75768999899589, 49.26340041622039, 56.26155207234045, 42.43895092318135, 69.34773998875772, 66.63127114695888, 67.05007829973775, 86.63924217224123, 10.074317532200968, 0.817632035863015, 0.4857777011009955, 0.20971816273466234, 0.2705741649673831, 0.14161354381470911, 0.3404959291219712, 0.10659397174153598, 0.1581931420631947, 0.2858680072090318], [0.07585968867304825, 0.053486251722901106, 0.04116612148561305, 0.039346340908518726, 0.08614484806575122, 0.044402620800200014, 0.06759463418875972, 0.07298044680107026, 0.038583838275723883, 0.0543383215253632, 0.9465468602795756, 43.58354953027541, 49.53882140498008, 44.87558218740648, 35.799048946749785, 34.53891692623016, 37.46321255160917, 29.92603309692875, 51.54338790524391, 69.06550976537889, 41.89344336909633, 2.003189012888939, 3.1722683579690996, 11.392211356470662, 19.59830495619005, 70.31093289775234, 65.67343227324947, 69.50687839138892, 63.32217531819498, 68.4422294555172, 69.12825984339561, 66.10938410605154, 63.75033340146465, 64.69445574668147, 64.50420902621362, 64.32847507538335, 60.24510729697443, 55.51348940018685, 50.915494888059555, 50.14451380698912, 47.95298361009168, 48.17016916890299, 47.08793232517858, 48.69281714962375, 45.872232913970954, 47.38793480780817, 55.556443275943884, 53.66357803344727, 54.962019843439904, 57.08999587643532, 52.72008326745803, 48.83363416118007, 47.89614454392464, 53.74681857324416, 56.94868072386711, 58.10229293761715, 58.225423982066495, 58.25017806022399, 59.522508651979514, 59.574103509226155, 56.26774157247236, 52.35298864303097, 51.469286487948516, 48.318168040244814, 45.83898298202023, 44.62762563459335, 48.171400793137096, 44.837307699265025, 48.234123414562596, 51.53164825131817, 52.83737390272079, 40.645184363088305, 21.713190078735355, 33.454471788098736, 42.58599665857131, 36.46244725873394, 42.88911350311772, 44.391804895093365, 42.087271213531494, 41.256297480675485, 38.27706906103319, 40.36007119763283, 40.44977972584386, 41.003441887517134, 42.325755242378484, 43.467447373174856, 49.63387612373599, 46.04959857079291, 45.228152275085456, 44.0692291721221, 43.051181916267645, 42.408313289765395, 44.1196120169855, 42.77433318476523, 44.62760602274249, 44.858578712709495, 44.03870136507096, 41.77783150826731, 43.77713026538972, 45.548743278749534, 44.629398545911236, 37.782807273249475, 44.834832683686294, 35.67752607407109, 21.295349790203957, 32.05173219403913, 52.585130199309326, 50.459966505727465, 46.5428013186301, 43.113830012659875, 41.999857271871264, 43.294588519680886, 43.086608763664, 46.185010556251775, 44.799037133493734, 45.337551101561516, 46.38469449935421, 48.853096961975105, 47.80346678149316, 50.929952744514715, 50.150699384750865, 52.65844714257025, 54.73720527464344, 53.79487545259538, 45.66634770362608, 44.08962549701814, 48.732691964795514, 56.28241123691682, 56.54157792368243, 58.05842907198014, 58.947069491109545, 56.74060290859592, 54.53221436469786, 48.709722565066436, 44.5209450106467, 45.62415476768248, 47.52161702802105, 48.755186757733746, 49.14668636937296, 54.269854868611986, 60.42207287203882, 59.64962090215376, 61.1717672501841, 63.53440300110848, 63.8758296351279, 66.05355308901879, 62.34965893530077, 62.442854450595, 59.399781611657914, 57.91226194750879, 56.974474230120265, 58.70509847517937, 61.36970573855985, 62.55244939557968, 70.95134612052672, 33.17723474194927, 4.083527124697163, 48.02075039955878, 47.710475229447894, 36.37885762799171, 50.382856630509906, 31.655649292853575, 55.10639444474251, 41.50197905878867, 56.68659187132313, 38.804894570381414, 0.049300159613091143, 0.06776624554467779, 0.11695616127502535, 0.19171852858797198, 0.005096517702294213, 0.06725204732990073, 0.12367012519990245, 0.01876756451242874, 0.05339498000760233, 0.02029931518219171, 0.021556009643621022, 0.08734566790442314, 0.02963193042594339, 0.010571208005140146, 0.061250211926357406, 0.053254736121743924, 0.04670381485935181, 0.044944953593996265, 0.24387489763959763, 0.14649416740623214, 2.0120942640689115, 47.39196308197514, 59.93889177999189, 30.358713673007106, 37.57662788514168, 43.93966936296032, 35.27252958666894, 43.245170577879875, 57.97963649995866, 76.03615776185067, 47.81854045006537, 2.4894550490763883, 3.7324553824240163, 12.547620015759623, 26.288193618097615, 75.7132839387463, 68.72731516438147, 71.84258707108037, 68.41011308854627, 73.83504129225209, 70.61245333763861, 68.528427462424, 68.14621602335285, 69.36217431099185, 67.15791210051506, 66.90878668139058, 62.19964788806055, 59.4365655991339, 54.02342411779589, 53.567746685397246, 50.7954115252341, 52.20901804585611, 49.12485837936402, 50.638497106490604, 49.905476723947835, 51.917593786793375, 55.47856069380238, 58.93785584357477, 57.234947066153254, 59.185910455642215, 55.5949923299974, 51.1479776905429, 50.13132679846979, 55.0765295182505, 59.51408340084938, 57.98610841074298, 59.69908983476701, 60.01298927491712, 62.348854849415446, 59.57617452067714, 58.82475429965604, 55.52623710324688, 54.24717180190548, 51.662169041172156, 50.07663719115719, 47.58988980324038, 49.71373950281451, 48.18007315358808, 51.27525075789421, 54.35027522425498, 57.817979935676824, 46.779202568915586, 25.699943996244862, 37.205014690276116, 46.62735585243472, 40.903386146791526, 46.82560420805409, 48.148317644673014, 43.930322354839696, 42.39028215408325, 40.614785994252856, 44.00969936001686, 42.00583496401387, 42.63374367067891, 43.00469006261518, 46.531426445130386, 52.713744717259566, 46.88618913773568, 46.14835208462131, 46.441757140621064, 44.99318661228303, 43.89114572155861, 45.15006180732481, 44.29981354744204, 45.78580740959414, 47.32941304483722, 45.19716947309433, 42.971349916150494, 45.743010428644, 49.60114786701818, 48.76863656505462, 40.550376753653254, 51.00010041267642, 37.770341980841856, 24.71085559937262, 37.04353463265204, 57.11715044513826, 55.20107261596188, 48.17666069153817, 45.486934569574174, 45.696699004019464, 44.24617121296544, 46.04620572059385, 50.28924926634758, 47.60225311402352, 47.396203164131414, 50.10772589714297, 53.16131461051203, 51.76748860266901, 53.11118279733966, 53.86680387681531, 56.959573145835634, 57.03388637112033, 57.115997268307595, 49.06586200960221, 47.37672075148552, 51.9876669299218, 60.130393658914876, 60.09794781284948, 61.01679440467589, 61.256098208888886, 60.98587436060752, 56.072693870913604, 51.204055816896506, 47.61897810043828, 48.35354781919911, 49.8886929019805, 50.6206307103557, 52.33766394276773, 59.05736654035507, 66.26523556247835, 64.58370762486612, 66.77672832242905, 67.59208709962907, 67.53602074038598, 69.5047289325345, 67.43324679713096, 67.70214096192392, 62.228622436523445, 61.67630172544911, 61.88319890729843, 64.24492859071302, 66.44731198587726, 68.87392551668229, 77.20682051873978, 36.32025349524714, 4.639240195674281, 52.62267120422856, 55.51985540697652, 39.43676879329067, 56.832653091799834, 40.21365696384061, 58.04896439275434, 44.024671046964585, 64.17868760324293, 41.717474076055716, 0.17766766400346834, 0.06686764739213452, 0.10405401488946331, 0.10527713554761103, 0.10459173200351578, 0.06471909252145598, 0.07360414962374395, 0.03711288051319219, 0.09173059430454047, 0.009643351039548796, 0.1865743707504965, 0.1742177402540561, 0.1333447891257463, 0.10959700576119846, 0.12664874399741813, 0.15879662016466742, 0.20414707941874383, 0.11761626093498162, 0.25606945457477726, 0.35985990457477113, 4.399962377163672, 77.85276428345712, 61.97235830368535, 61.34808171179987, 46.372472393897276, 51.84507700704759, 52.781354611919774, 42.63617946255592, 66.60220638398202, 79.70699417975642, 51.05092256299911, 3.383233282835253, 4.879515767097473, 14.012591934973194, 31.598547427884995, 76.69980710552585, 69.69392838016634, 72.15083829818234, 69.44785456503593, 73.28704695547782, 74.17460872280982, 69.6488211231847, 70.14100797714727, 69.05391523914953, 69.6963837838942, 68.55095755669379, 65.80552201117239, 62.364163860198, 56.490045824358546, 55.008174373257546, 54.5400865616337, 52.29363141521331, 51.45547974494196, 51.63179420655774, 51.6145710791311, 53.968973775063795, 62.17479182827858, 58.97432996380714, 59.26906078092514, 62.11719966703846, 59.810806782014915, 53.304712541641734, 52.61930581062071, 57.012376093095355, 60.2455230682127, 60.28569206114739, 60.66722493017874, 59.95294170994913, 64.74893746837493, 62.43513130372571, 60.473012693466686, 56.877187682736306, 56.969500664741766, 53.511570499789336, 51.43444407370783, 49.564709048117365, 54.02606779529203, 50.63391970049951, 55.32420366041122, 60.102454616177475, 62.04259618636101, 49.90760264858123, 33.74235806926605, 40.32752729231312, 48.42036931745468, 43.738032079512074, 51.34426878344629, 50.52048475511613, 47.980212703827895, 46.86278827728764, 41.04046513957363, 46.812205391545454, 44.591602586930804, 46.885926338934134, 48.648929749765706, 49.99050978691348, 54.981019804554606, 50.94799956967754, 48.2321112386642, 49.890073576281154, 47.61049009138539, 46.06915943084225, 46.84100735572077, 46.80549421618062, 48.05051726679648, 50.75462279781219, 49.79470114554129, 46.60231936362482, 50.553691540994954, 51.693567614401545, 49.42607287437686, 42.334313854094475, 50.24279271402667, 44.43829282637566, 32.39977586653925, 42.48718038682015, 57.366338622185495, 56.96486050082792, 52.21827876183295, 49.45215271365259, 48.741905612330285, 48.632294977864916, 47.906746710500414, 54.57168909811205, 51.275372351369555, 51.32786935375583, 52.414036412392896, 56.981675701756636, 52.34649712039579, 56.354465176982266, 55.94365573698475, 58.31495208124961, 60.72550350619901, 60.179705696721236, 50.346437423459946, 51.73383466659054, 53.00498070255403, 62.148535482345096, 62.78914482362809, 62.64356605468258, 62.36988267590923, 63.22506919983895, 59.08171661438481, 55.07376816964919, 50.77624290220199, 52.90378747447845, 54.54331467228552, 53.96584372366629, 54.72413201485911, 62.43946552276612, 68.36161690373575, 67.2323351521646, 68.21761884996968, 70.51414305163969, 70.25383103278376, 72.0832872390747, 70.30020129296088, 70.45919849026588, 66.8180779487856, 66.89629001002159, 64.88587525583083, 68.97729566020351, 70.5707428532262, 75.17406786641767, 81.22280982232864, 40.28001562241585, 4.9537510352749985, 57.5878466329267, 59.14785954260058, 53.16281295591786, 60.69370485121205, 52.911891091254454, 69.28724919596027, 61.872843850043516, 75.76038375977548, 55.27506420689245, 0.3721379957372143, 0.21500979249756183, 0.1574678713035199, 0.2446470836237554, 0.21740833717969157, 0.1579604045517983, 0.1914373283544856, 0.13040325664464505, 0.2171753545201594, 0.12810690043073508], [0.03743328146576401, 0.10462867276322459, 0.030260057406379815, 0.033374107142369595, 0.10859214355267825, 0.05951574673095058, 0.059390805451379675, 0.09660249981548517, 0.11301915116247632, 0.09616721631778825, 0.5285118628413447, 8.464926885020349, 58.868645621884255, 53.41145592351114, 42.74014188397316, 43.156721130494155, 41.03380495502103, 26.493272781372074, 46.77799055653234, 65.7664591266263, 43.846724879357126, 2.316196849269252, 1.932666022931376, 9.812402244537108, 37.75729225527856, 70.30131524608981, 68.11697083134806, 72.78256739339521, 67.2356064088883, 68.78204007302561, 65.61971541373961, 67.00242150214412, 65.90728790529313, 63.244775187584665, 61.88900401515346, 60.57589254071636, 54.4624157874815, 50.838867464373195, 53.25450228106592, 51.202635918894124, 47.125481174838164, 48.35601106766732, 47.96528024058188, 46.89330039485809, 46.04782958184519, 45.73729945767311, 48.12817627383817, 54.69480445308071, 53.41162458542855, 53.725010195086085, 50.05921794522194, 47.670918126260084, 47.316955597169944, 54.821140073960834, 57.4284375867536, 56.48029873448034, 57.00136207765149, 58.40928116152364, 58.647345496762185, 59.46388098501391, 56.91400697154384, 50.30645670429353, 50.638210773468025, 50.157920468238096, 51.17989401663504, 45.809157279229936, 47.0113637370448, 47.67278125209194, 47.4095941358997, 52.48084614353796, 54.27865666727866, 47.277928013955396, 19.461718220864576, 30.8560388318954, 47.46469166971023, 38.382635731850904, 38.51569429520638, 42.35723226301132, 45.702492344763975, 41.13088361678585, 39.2897387473814, 39.804232120513916, 41.79114795500233, 36.2768328574396, 40.47611059681062, 42.65003327400454, 39.62806670896469, 38.63763293912334, 42.62514583526119, 44.07790545494326, 43.57610879405853, 46.51194795485466, 42.769340007535874, 42.46866679960682, 44.41995574582008, 43.22101662235875, 39.209663560313565, 44.026000730453, 47.32025823285503, 44.54397324592837, 43.77079171519126, 48.235406029608946, 43.38728589396323, 22.588708208453273, 15.807956860911464, 43.939449710230676, 56.550269895984286, 52.68864939289709, 43.25166602288523, 42.465136666451734, 41.296623368417066, 39.80877030280329, 45.85492741677069, 45.750572758336226, 46.88099591962753, 45.00950759457004, 44.16757868182275, 45.52196525758313, 47.09467095713462, 47.876097309973936, 48.59128659771335, 49.8711795191611, 48.28013281668387, 43.96274074431389, 42.637054151104344, 44.489107131958015, 47.612780755566014, 54.54131426349763, 57.009559831311634, 54.601922727400265, 55.37901486119917, 57.38328718370008, 50.27707422933271, 46.20105697262672, 45.41037382618074, 45.600981404704434, 46.24101807994228, 47.56553580684047, 50.068886587696696, 59.663317818795484, 61.91854338492117, 62.926023775531405, 60.69850583230296, 61.37120408396567, 63.70601846325783, 62.90352898259317, 61.31798536546769, 63.25075680209745, 55.785552840079035, 56.701759676779474, 55.4149555390881, 59.60015196954051, 64.64570068543958, 65.61319251214304, 73.26064155947778, 35.17135204807405, 3.80163447030129, 56.240873336792, 41.45968414122059, 41.89958580078618, 45.58053801136632, 37.73293433650848, 58.69864617624591, 28.48527789115906, 57.370170777843846, 23.934948021365752, 0.1687080665461479, 0.0386763165795034, 0.13682276701494572, 0.09530103900620053, 0.07339019658825091, 0.032238600129682216, 0.11519608959074944, 0.07321881505871013, 0.002825333461758771, 0.0047167209953430204, 0.05383680972661223, 0.06817374303336106, 0.006873530942210628, 0.023274637886413166, 0.03536448783932194, 0.11463276215738828, 0.10993781529607312, 0.09157391400226662, 0.07493532698361144, 0.12021806406518144, 0.24691865689331488, 6.989749448914682, 72.7252301862163, 50.208503353980284, 34.74705749942411, 50.760369070114635, 37.13695372304609, 38.39155127925258, 56.91687030176963, 70.07156633561658, 51.744232869917354, 3.0244494253589265, 1.5440708038307007, 9.57765329268671, 47.76498048536239, 73.23762509130663, 71.91174630195864, 75.12036277401832, 71.3206058932889, 71.5254791321293, 70.85484796954741, 73.28681945800781, 68.8402166674214, 66.43558409906203, 64.44684044007333, 63.2774563758604, 58.32569545315158, 54.533999043126265, 55.285827190645286, 53.092790803601666, 50.00124139170493, 51.54148947808051, 51.373961125650716, 50.56648631249705, 50.16447082642586, 48.95143470456524, 50.36393511679865, 56.14939189726307, 55.73578580733269, 55.58941864198255, 53.32544226800242, 52.55736766322967, 49.26274538040162, 57.964900155221265, 60.329140155546135, 57.93960871235017, 59.83113642661803, 59.94366922686177, 59.43276090006675, 62.76235895772135, 56.759595024970274, 50.272947895911436, 50.30162434424124, 51.92264972194549, 53.61580356474846, 49.22789512142059, 49.87518033673687, 51.64465565835276, 50.531741957510675, 56.16792117395709, 55.41983496758246, 52.03409602565151, 25.85117490060868, 35.851824437418294, 49.78593464820616, 42.26643723826255, 41.805009611191295, 44.6569335845209, 48.55125881010487, 44.63926330689461, 44.023666920200476, 42.0745470446925, 43.353988893570445, 40.67293120968727, 43.501481779160045, 43.63613282480548, 41.34742982925908, 41.72129446460355, 45.67349818445022, 44.95593194038638, 46.32350944703626, 49.2183716066422, 46.77595484641291, 42.66978633019232, 45.238122940063484, 42.045513660677024, 41.75810198630057, 47.3682366648028, 48.77987415559831, 44.53215514459918, 44.14689210153396, 49.42414699062225, 47.5696542955214, 23.289912285343295, 21.726598701169415, 49.535169678349654, 55.929139044977006, 53.966973366275916, 48.186325411642756, 46.79927333708733, 44.66236998957973, 43.627460464354485, 48.19462514692738, 51.412572937627, 49.93272150716474, 49.761906208530554, 50.16672226690477, 48.906421584467736, 49.89553351556101, 50.243000599645804, 50.55471527960993, 52.58530670596708, 51.70578579748831, 46.24640741655904, 45.847722022764145, 47.72517235048356, 52.32881115328882, 58.92716738485522, 60.928686203495154, 58.1522443217616, 59.24931164710753, 59.63550036953342, 52.6444560481656, 48.011093524194536, 47.93712938985517, 49.63964985262964, 50.40600645926691, 51.208821496655865, 53.59828233718873, 62.66363290048415, 65.84190983926096, 65.37481438729071, 62.521627410765625, 64.34334870307677, 68.13043240577944, 66.9207420656758, 64.39974454141432, 65.80617704699117, 60.31283094036964, 59.65575156673309, 59.46190018807689, 67.52259838965632, 70.66872366013067, 71.8827364521642, 77.65084851172664, 34.38267323278612, 4.498740405805649, 64.01297138583276, 43.72011861493511, 46.091218840691354, 51.759243780566806, 46.49807060918501, 56.79160548794655, 30.505582901739306, 67.22472575403029, 24.934291455053515, 0.18204363483575084, 0.06105566006754676, 0.10625852482213129, 0.20877310134951146, 0.024133636954150373, 0.034958105008568496, 0.10157694619509483, 0.004736431480024852, 0.0541535143049494, 0.04069964671807905, 0.20282303433745139, 0.25506961790304034, 0.10401108332218663, 0.106044280673227, 0.2352449324943366, 0.25993458265739106, 0.23856869688437832, 0.25306197724515395, 0.23640354854925988, 0.47531217396739994, 0.7334954183428519, 18.66400814825489, 88.18066304729831, 70.72880652643019, 54.90283519990983, 58.21701049804688, 57.6856509331734, 37.16125280626359, 63.9895744477549, 75.85518744684036, 57.04686549402053, 3.4040436629326116, 2.532392990204596, 12.76942220426375, 52.01387620741322, 72.59883572978359, 71.75747948308145, 76.47278816469255, 74.30409400693833, 74.02025561178885, 72.71944861258231, 73.76114383820565, 71.08995483767602, 68.12236016796481, 68.62402346826369, 64.89305711561634, 59.991282878383515, 56.86523622082126, 58.59249114990235, 55.82485891157582, 51.00386981041201, 52.801994123766505, 53.361692813134965, 51.956209521139826, 52.534327660837484, 51.17538721330705, 53.84329711237262, 58.55089833659511, 57.51849520590998, 59.92229623179282, 56.692593097686775, 53.73973869508313, 50.4595507344892, 60.16971149752217, 61.12612655085903, 60.299530183115316, 60.81594944000245, 62.99896417125579, 60.62734227026663, 64.9406550776574, 61.319617071459376, 53.89345638213619, 56.381811941823656, 54.82255212722286, 55.44124326398296, 51.88013515164776, 51.66382428138487, 56.410339340086914, 53.91027550543509, 58.48491622555641, 61.04190149614888, 54.826345059179495, 30.936914182478386, 40.52989805898359, 47.70496822172596, 46.068892709670536, 44.786928776771795, 50.00472053404778, 51.604992651170306, 48.04424539689095, 44.62403666588568, 44.51278255831811, 48.67334650408838, 42.98374068352484, 48.145713190878595, 48.97960124477264, 47.43489734588131, 45.47638339381064, 48.41821593623008, 51.057512144888605, 48.715817928314216, 51.88583827787831, 50.49458142249815, 44.94925998872326, 50.97773898032404, 46.474238288018014, 45.97506177040839, 50.02000993297946, 52.490840342737016, 51.48576828741258, 51.19497160757742, 48.32452227992397, 48.20155989739203, 30.89445256417798, 28.644798724882065, 51.56104641575968, 60.13029559966057, 59.044450175377634, 50.729703980107466, 48.26219189551569, 46.61558089717742, 45.99730553165559, 51.50035558208343, 53.18469978147938, 52.42802358442738, 52.57396713379891, 52.47155797096991, 52.65150062499508, 55.37492382910944, 53.35617403830252, 53.786575717310754, 56.12659508182157, 55.00750364795808, 50.18585558860533, 48.74059554069273, 49.35259903630903, 52.90490927234773, 60.832964681809955, 63.28883124936012, 61.60078041015133, 61.93792381594258, 60.988015974721606, 55.590583585923724, 50.542795196656265, 52.66311868544548, 51.26377390277002, 52.15763499659877, 53.50523587196104, 57.3299115703952, 64.85897171881892, 67.54920774890532, 68.77357559819376, 66.32691091106784, 67.16767095750379, 70.45202055285054, 71.09601882196242, 67.89805550729075, 70.6788355304349, 63.748434974301254, 64.1881444377284, 62.655999968128825, 70.4259289464643, 76.63552730314194, 75.29564565227878, 85.07106288786858, 42.32635144264468, 5.733100493108073, 69.59713997379427, 54.06506007717502, 55.25781754524478, 55.37983071419501, 61.945442999562914, 68.84305646342617, 39.71041294836229, 78.60306662897911, 34.900049547995295, 0.40125938793343885, 0.17679841467930427, 0.17860301139373935, 0.41559868462143407, 0.17769040149306098, 0.11004033318210034, 0.18764113286329856, 0.12286798517790534, 0.22501816432322228, 0.1393571084425334], [0.08907765480539492, 0.039147387874583085, 0.08917762927951352, 0.11406329835975364, 0.053103031560538284, 0.09473345212398038, 0.043447592611154245, 0.030543929371502132, 0.09284209595212052, 0.0312554469377163, 0.062383983749896295, 0.3112720037179609, 40.92849716063469, 50.92466146715226, 52.62229857906219, 56.24517225450086, 57.20141472355012, 24.772909456683745, 42.768692816457445, 64.67947229262322, 50.744965922447946, 3.385831607926277, 1.788444394065488, 6.072128107470851, 59.2662758981028, 70.00567051672166, 73.29952793736612, 68.89924049377441, 67.58136333957796, 64.9688216178648, 64.5560392256706, 62.36617995846657, 61.466349017235544, 57.793253314110544, 58.430179549801736, 54.090065187023534, 52.839115435077304, 50.20530269991968, 48.770715421245946, 49.14304248748287, 49.46197040619389, 47.563268676880874, 48.408551216125495, 47.19631918015019, 46.63788741634738, 45.583652373283144, 47.502295432552216, 47.81640668069163, 50.71622279382522, 48.58441852754163, 49.844825113973315, 44.60723323206748, 50.448772061255674, 57.649176812941036, 55.81552759293587, 56.63560498145319, 53.657384610945186, 60.52181874552081, 60.44278690891882, 59.04804698882565, 55.940427626332934, 52.20810805597613, 48.70373702818348, 51.07613555846676, 51.75037137923702, 51.06768285074542, 49.08770961146201, 48.374057892830145, 46.38872669589135, 51.630280171671224, 53.210779620755105, 52.111904082759736, 22.819645597088723, 22.716685341250514, 49.17360559586556, 38.90160845172021, 39.031383991241455, 36.277844828944055, 43.73347036300167, 41.03679380109234, 41.10636880320888, 38.39216709136963, 42.453651966587195, 39.764761309469904, 38.275684464362364, 39.25941490357922, 38.80515736918296, 36.357178688049316, 40.03533032632644, 36.41030326966317, 42.092738997551706, 39.43329357331799, 44.58636622275076, 40.46986618349629, 52.867619299119525, 45.89049939186343, 48.398211848351266, 42.591695862431685, 39.040774145433986, 43.01692785755281, 48.70104628224527, 43.381163074124245, 37.44465189595377, 13.720672476676203, 26.146860814863636, 61.38170034654679, 50.74453053935882, 53.21470983566777, 41.35612180156093, 46.648171870939194, 40.85113233135593, 43.95318585057413, 49.31284973698278, 48.972156586185584, 45.69027416167721, 47.247961105838904, 47.12276297230875, 47.699170958611276, 43.36974113218246, 44.717326318064046, 45.342128507552616, 45.02568737153084, 43.86506980465305, 42.710288724591656, 42.97724131614932, 47.50065980419036, 48.938424202703665, 55.042922650614095, 58.06050792817147, 54.937642312818966, 56.99208174982379, 53.89102059025919, 45.859559735944195, 46.76222262843963, 44.35480517725791, 46.006946717539144, 45.58802973839545, 46.294954592181796, 49.143470025831654, 55.88451816189674, 61.77663203208678, 59.16101124978835, 62.53495954698133, 61.39746435226933, 65.20967868066603, 61.85163951689198, 63.99649350873886, 56.75955972363872, 59.22913105257096, 52.86818804279451, 59.8544470725521, 62.6477002328442, 66.95096000548332, 67.24052506108438, 76.93306261493315, 20.28408039000727, 4.438977702971428, 57.36650336173273, 36.005036138719134, 58.56250855230517, 32.661615648577296, 46.13979739527549, 53.52788755970617, 33.75734936806464, 56.777273147336906, 16.70042061036633, 0.400326537989801, 0.16695052295202212, 0.19376896291730866, 0.019681850230441462, 0.16121753461418614, 0.05725576820212507, 0.11001542000280273, 0.03883664346029682, 0.09118713919193515, 0.03032625314869708, 0.06785531858763388, 0.01548182872694827, 0.05464106798171998, 0.13460921724477123, 0.06445126818312753, 0.09026549711462953, 0.08553118865576484, 0.012658663533417689, 0.15390582292550994, 0.05608625454647888, 0.034442569970363573, 0.34726474494222676, 43.429082670519435, 57.651428253419944, 48.074275062930205, 69.06804361651021, 53.58889610536637, 29.403710672932288, 56.24119497114613, 66.11370655798143, 59.972616318733465, 4.398206135919017, 1.8785194187395036, 7.846506882098414, 68.56539187892791, 71.54985274038008, 78.85075646062052, 71.47684174199259, 71.44725138141264, 69.51022025077575, 70.24048712945753, 63.69422389614967, 64.16307264758696, 62.830859230410674, 60.91931173878332, 56.83754820977488, 55.35240942432035, 53.41650009155274, 53.8836504567054, 52.857405447190814, 52.77602803322577, 50.64895022299982, 53.2696936207433, 51.2346738384616, 49.94233523645709, 49.74207470493932, 49.29963527187225, 50.36204453437559, 52.266064997642275, 49.7253026500825, 52.32772073438091, 48.257959658099765, 54.385776596684615, 58.10672913828204, 58.941915496703125, 58.44434715086415, 55.89290811169533, 59.98454816879765, 63.238338578131895, 59.95096483538228, 56.19555819419123, 54.726971810863866, 51.26090665017405, 53.260483895578695, 53.285940077997026, 52.38160233343802, 52.83894677315989, 52.487361200394176, 50.34630406287409, 55.75418564581103, 56.474623064841, 56.486017550191576, 28.98048104778413, 26.772463167867354, 54.04826841046734, 42.00516031634423, 44.49370022742979, 40.173287930027136, 44.30554020789362, 44.36084954969345, 43.99503754031274, 39.35657593511766, 44.89972437581709, 40.50601474700436, 41.728311584841826, 43.22520571370279, 40.99747988485521, 39.34243186827629, 42.545698227420935, 37.0011338110893, 40.77720742071829, 41.22779753900344, 43.71785932971586, 43.39824499622468, 51.88160996283255, 48.84855877968573, 55.55447032374721, 40.84800227995842, 41.4143297749181, 45.70110774809315, 52.165636631750296, 46.74371688596664, 38.78754984947943, 19.601344793073594, 32.79666285361014, 61.172857669092, 53.63122240189583, 54.860234337468306, 45.34325815016224, 47.54229184119932, 42.89636596556633, 48.02882655974358, 53.27146653206118, 51.046639334770944, 48.675978414474, 51.33640050888062, 50.93708753585816, 49.773547803201986, 47.9627699236716, 48.3304254470333, 48.935662854102354, 47.50504893641318, 47.52034225771504, 45.8674515447309, 46.113305707131666, 50.832132754787324, 52.12676594334265, 59.173649126483554, 61.37531080553609, 58.139684892469845, 60.20713090896607, 57.54054284864857, 49.55380485903833, 49.28413798732143, 47.43702719288488, 49.181297363773474, 50.055966300349084, 48.362341773125436, 50.388332259270456, 58.56071995150659, 66.06182144534203, 63.84223845697219, 69.98439558090703, 64.87840314065257, 68.37456072530439, 64.96584846127418, 68.27121411600422, 62.56979411648166, 61.91793933991463, 56.84834649485927, 67.72398071904337, 67.28701299236667, 73.32912614268642, 68.35818875220515, 78.0381041188394, 17.210787650077574, 6.047362262202848, 65.52647283000331, 40.3727404532894, 66.3333357534101, 38.57511035857662, 55.16524568680794, 61.78716751836962, 40.19722615518878, 64.76091246451101, 16.93610602809537, 0.3920853318225953, 0.06123071115824485, 0.14980987255131045, 0.06955321457597517, 0.13112863465662927, 0.04255082923918963, 0.02690711655774184, 0.1465993053129604, 0.0220312312200305, 0.017568441558509104, 0.19123474406378885, 0.09205837268382312, 0.1434215572812865, 0.21679794896514187, 0.17405231122768697, 0.14800115428384275, 0.2006279013209766, 0.11053796857595445, 0.29770961211573693, 0.0804490762792768, 0.14338179731801634, 0.9308725787747292, 59.044807111063314, 62.7040058566678, 65.61630295168969, 75.08038597722208, 79.1390271340647, 31.662278098444787, 57.73387647444203, 75.1804691745389, 63.19583969731485, 5.150938389762755, 2.207804601038656, 11.791491969939202, 70.10176074120307, 72.36965164061516, 77.51920592400336, 73.13101507002308, 74.26573322665307, 72.12222068540513, 70.77181923773982, 67.6565787100023, 65.75551963621571, 65.11782461597075, 63.02118047591179, 59.721863115987475, 56.19525224931779, 54.69233728224232, 54.01365741606682, 54.06249484708233, 55.080236158063336, 52.03550023417319, 55.40129392377792, 52.8218020931367, 53.45409993202456, 51.18329471157443, 52.83245132815454, 53.28234326454901, 55.65087433784239, 54.48616966124504, 56.52831246775966, 49.778270336889456, 54.85924982255506, 60.63555571340746, 61.52391764425463, 62.611390852159076, 58.8967925502408, 62.2788130852484, 65.031218682566, 62.886015599773785, 59.51244777248752, 57.069497569914795, 54.57118311235982, 56.101554670641505, 55.80626295458887, 55.00595431174002, 55.55324654425345, 54.48713848667761, 53.0434238526129, 60.07580995559693, 60.65187669569447, 59.73141408735707, 34.4626856619312, 36.17972673908357, 49.63802991374847, 43.247335726215, 47.04346441453504, 42.80778707996492, 50.976303392840975, 49.04144525527955, 47.451363455864694, 42.86150393947479, 51.73000251093219, 44.40772971799297, 44.2034173780872, 47.9265272232794, 46.80898120326381, 43.26609250037901, 48.26184280457036, 42.49319338029431, 44.764696782635106, 44.822477217643495, 47.12600677244125, 46.62633603618991, 54.72869373136952, 53.02886793690344, 59.6252316044223, 44.3042536704771, 42.75226200780561, 42.344049176862164, 51.46445020552605, 47.176256256718794, 41.38169565508443, 26.396817776464648, 33.83954655739569, 64.50171047641386, 56.98604914449877, 60.433671320638354, 47.36875049529537, 52.44520748815229, 44.33439316288118, 48.54671670544533, 56.734009404336255, 54.88475307341545, 52.30932481827275, 53.24248021648776, 52.44554481198711, 52.31217245901785, 50.89721664305657, 50.5929034756076, 52.78798341751099, 49.096487875907656, 51.045752879112, 49.00133117552727, 49.19586896896363, 52.67532510142173, 54.43577504927113, 60.052138451607, 63.7162087809655, 58.884919535729196, 61.99637889862061, 60.7061662212495, 51.79729469360844, 51.97351894071026, 51.2599652813327, 51.373921901949, 55.47677601537397, 52.69372101752989, 53.369415960004254, 63.03068045646914, 69.7422049122472, 63.33157723949802, 71.06404366031771, 67.61939464076873, 71.73817357709332, 68.65570837451567, 73.1546591174218, 64.90747182599961, 67.15279732981037, 59.25893322114022, 74.02700993322557, 71.07557542862432, 78.42146089000087, 72.46643220224689, 85.86953193910661, 23.436628541638775, 7.069760407170943, 69.33296834268879, 52.70156183550435, 72.2979114901635, 45.446047782897956, 68.2856092145366, 63.72090385806177, 50.967034832123794, 77.9631946932885, 24.74413691028472, 0.7043438116388937, 0.38835307402956876, 0.3030136678247683, 0.16571601822731957, 0.18895183269295002, 0.13719707757474917, 0.25542083857280595, 0.24965834052812672, 0.21874672342692653, 0.12218369246130029], [0.09918767117684889, 0.07551158598113446, 0.09556460389567, 0.1280561854101477, 0.052034545749906576, 0.12045647062721754, 0.04732153070489726, 0.10407289895679682, 0.10392867524417178, 0.10095386390363979, 0.06711579093168821, 0.7329405255375371, 26.072602502761352, 62.600945580390196, 36.17686340885778, 39.79097843170166, 57.200234090128255, 25.04790879064991, 27.18614378283101, 59.23467728399462, 60.36623008789555, 9.235224493088262, 0.5794798763048264, 10.124519948036442, 68.63018158943423, 70.27659646926388, 71.89845731181484, 68.7078131398847, 68.77914536383845, 66.1654112415929, 62.675290184636275, 60.55029123060165, 56.779363770638746, 58.93008562826342, 58.584995500503055, 55.3078003083506, 51.683867592965406, 50.72377335640692, 50.385480696155184, 49.23067608187276, 47.80742053062686, 47.50041661723968, 48.6667686893094, 46.07748270034791, 46.10666905680011, 45.45048790593302, 44.77322401538972, 46.424483022382184, 46.9822754398469, 45.103267931169086, 45.506244397932484, 48.6436031710717, 56.3212780029543, 54.2951149325217, 59.7521085123862, 56.454163982022195, 52.46954187270134, 55.93100609317903, 59.2209646778722, 59.99518955907514, 54.094925003667036, 51.838346219831905, 49.033055305480964, 53.71637705833682, 52.540222983206476, 51.159364331153135, 50.14886763788039, 52.26937547806771, 46.14478665013468, 52.544517978545166, 53.18291510305097, 58.07350274055236, 31.795552392159742, 16.36154155577383, 43.46823184720932, 43.55790899645898, 38.10240591725996, 38.59395342488443, 36.03807818505072, 37.10511192198723, 35.17211298788748, 35.38520359223889, 38.67204781501524, 34.73187400448707, 37.3139585218122, 37.68402630282987, 34.44643528230729, 37.06164813810779, 36.989794238921135, 36.501886690816576, 38.38287891880159, 44.026000730453, 42.93392265996626, 39.19586858441753, 43.14073747204196, 56.69422088130828, 44.209704937473425, 48.325565630389804, 50.3808169980203, 64.50786859758439, 45.91078981276482, 49.74944876086328, 37.98409154338222, 13.278184013981974, 51.252799111027876, 51.94357556681479, 54.32625462931972, 47.52631994985765, 43.75211338843069, 41.53638216757005, 43.31738141275222, 47.1793863081163, 52.37784862518311, 49.313281197701734, 46.64625775429511, 46.04695489329677, 47.76652197684012, 47.39739164229363, 49.036871771658625, 45.00662073012322, 46.167807040675996, 42.877942592866965, 42.85407889273859, 42.694814974261874, 44.8055874916815, 46.97722342706496, 51.09828126045966, 53.66260528564454, 56.97719243264968, 58.40360156951412, 54.861928801382746, 48.26811075210572, 45.57983982947565, 43.2813112966476, 44.44955395114037, 43.31957794004872, 47.03609035861108, 42.186711142140055, 46.479368748203406, 50.289527754629816, 60.791697425227014, 63.590528195904156, 64.57274852260467, 61.26639050822104, 63.15629828360773, 60.10893829407231, 63.29568363005116, 58.55080812208114, 54.86303098740117, 53.7222017780427, 66.97622006939304, 61.612178817872085, 70.80318250963765, 65.40550301151892, 71.82342237041843, 5.851578625940508, 8.934682684559977, 55.70079042065529, 46.94985312800254, 44.017073415940814, 29.165660065989343, 58.62453691421017, 70.13599518806704, 43.38446963217951, 49.543728290065644, 9.630357200099576, 0.34637697161205355, 0.10515230152034953, 0.07109405487895974, 0.10488269985803675, 0.08012762578624873, 0.03971402097733752, 0.050980121483125036, 0.04715832716394817, 0.0824758691352702, 0.09617671580804933, 0.0744381895469081, 0.09995481630246486, 0.07991821565214666, 0.09850478040114527, 0.05351859978550384, 0.058455902392104755, 0.07028855173097504, 0.007340093331050969, 0.11672412856451927, 0.24483338088518192, 0.20472903044954424, 0.8471283208458655, 30.184085830565426, 73.27024352165961, 38.64025308239845, 55.95922362419867, 61.476115718964614, 25.900079011917118, 35.07928225301927, 66.45731402981666, 68.75651328794419, 12.50587324942312, 0.5188383786909042, 14.25574456491778, 75.14164555457332, 72.35561740013861, 75.68086947164228, 73.83347234418316, 73.0916815419351, 68.2246869610202, 67.22649866534819, 63.59412108698199, 62.093630144673014, 62.58426766241751, 61.81612637735183, 58.33858043916764, 54.2198956397272, 53.8629364198254, 51.3691601445598, 51.96306582420103, 51.32289578837734, 51.088655764056796, 51.635414554226784, 49.116060503067516, 50.30178123904813, 48.70114041912941, 46.662484599697976, 49.46997988608576, 47.80718911078669, 47.6901416624746, 47.885103071889574, 50.55305611702704, 58.62078320595526, 58.48211957562355, 60.87049784198884, 58.465798593336544, 56.54065616669194, 58.854379961567545, 61.016402167658654, 61.56744026368665, 56.607034437118045, 52.14821346344487, 52.96703569350704, 55.83557482688658, 55.72509342624296, 54.74122570407007, 54.22359835716986, 54.3333698088123, 49.63808482693088, 58.587745081993845, 55.07428592251193, 60.40246886591758, 37.967856853239, 18.704039858233546, 44.92156021056637, 48.64104578571935, 40.83866703894831, 41.08168140534432, 41.5333148740953, 42.30925775343373, 38.98277798006612, 39.42735510487711, 41.79566260307066, 38.71986150741577, 39.65505261575022, 38.54844216377505, 38.67487976627965, 41.69760334876276, 41.78764135606828, 40.6069726328696, 44.96298828432637, 45.33073009983186, 46.52895535192182, 41.05547997259325, 44.717165500886985, 61.903814884924124, 45.448444351073235, 53.12945711997248, 52.752038817251886, 61.75829102916103, 45.32374828092514, 51.75402702823762, 37.73319321293985, 20.07219199211367, 53.93247219824023, 53.50699701616841, 55.27125166308496, 48.34480877845518, 48.01131317692418, 45.14440574953633, 46.86377279220089, 49.4398521607922, 54.64993253830941, 49.76510294022099, 50.81581177250032, 48.99249407552904, 52.66728032019831, 50.9867133632783, 52.92532128672446, 49.42608856385755, 49.941291885991255, 46.508131488676995, 46.86288633654195, 46.344682401226414, 48.3006154337237, 51.220871017825225, 54.1205184690414, 57.099397797738355, 59.94309656081661, 59.07016915659751, 56.94215389990038, 51.28267580463041, 48.86203996596798, 46.118691121378255, 49.566030886865434, 47.0405226369058, 48.76163121192686, 46.43383787524316, 50.13196222243771, 51.51203640045659, 61.64347933184717, 64.53760408586072, 66.81880750963765, 65.09959343940982, 69.33430979328772, 63.048966546212476, 66.96987367445423, 62.199887152641054, 60.0140679267145, 58.67975996386621, 73.97485025467412, 67.00515147178405, 75.36243577157298, 69.27199117598995, 73.19527918292631, 4.629633820826008, 11.039947213665133, 64.13930308434271, 52.188315776086625, 57.610333581124586, 32.284036528679636, 65.97307389782321, 83.27435847251647, 51.4325221123234, 61.475848997792895, 10.79198673848183, 0.3554975547857823, 0.08669479960395444, 0.06471996586168967, 0.16163019553547905, 0.10868215122290197, 0.0005986948998460937, 0.055437029504607764, 0.04954664074184914, 0.04366171418599064, 0.08119695429359713, 0.256212375937931, 0.161368882944507, 0.1845031754384118, 0.1912036102505461, 0.1381517763459875, 0.2393800452832253, 0.1932225277226779, 0.26270763708218453, 0.3722272603021514, 0.3349082063763373, 0.24764670089127558, 0.8301746725074707, 40.43952665021343, 87.5772613094699, 48.10696801831646, 56.047571089959916, 74.99541174980902, 35.9064002959959, 35.97897983366443, 73.03821179174608, 71.36897656225389, 13.74348007863568, 0.42000629488498936, 17.64358001370584, 75.77536721383372, 74.92532683957008, 76.25773245288481, 75.88352264896517, 73.20152359624063, 72.13052042068975, 67.71304515100294, 65.87105304964128, 63.4476480176372, 65.63710328071349, 64.21380458339569, 63.172356467093195, 57.250189396642874, 55.48561703774237, 54.31187522026801, 54.568445297979544, 52.90171254065729, 53.48154083375008, 55.72720758376583, 52.485066613843365, 51.57019338300152, 50.94028818991877, 50.21237865571053, 53.01433163304483, 50.57958702887259, 50.01575023897233, 48.41366598683019, 53.20663367548297, 62.566715055896395, 60.219674648777136, 65.2104356981093, 59.66667144529281, 56.81457096530546, 59.328021849355395, 61.41961005426223, 66.80718944918725, 60.04978110713344, 54.274530333857385, 54.13859275079543, 58.34484054196266, 59.01351051945841, 54.470209537013886, 57.6129105783278, 58.05986073709304, 52.70227178450554, 60.77037934334048, 57.61053362200337, 64.91511260309528, 40.467865774708415, 27.776127092299927, 50.069423952410304, 42.84171165958528, 45.22003689119893, 46.42826810959847, 42.620435068684245, 44.66563732393327, 41.8666692703001, 43.003403525198664, 47.289910854831824, 43.83687973022462, 45.05302629163189, 43.88626237069407, 42.94814517421108, 41.7141753627408, 44.89969691922588, 42.90412833613735, 45.05188095954157, 49.912109451909224, 48.42215007351291, 44.886478531745176, 47.74694542731009, 67.58665853931059, 49.34360111913374, 50.81668646104875, 52.370713833839666, 63.36500760047667, 50.22874278406943, 56.70018288397021, 46.30036354064942, 26.259450489474883, 54.034206713399584, 57.3347007843756, 59.725373637291696, 51.683530269130586, 50.53527601303593, 46.61883254205027, 51.0256624990894, 53.311506086780184, 57.78468685765421, 53.22893234991258, 54.56691949598251, 53.212772184802645, 55.612956785386615, 52.26742606009207, 56.052168107801876, 49.73863086392803, 52.09260602151194, 48.75411987304688, 49.24250987268264, 48.90937120683732, 51.79796149653774, 53.91790059305007, 56.487645333813084, 59.30137326640468, 63.11053599080732, 62.203217244917354, 61.63415585794757, 53.69130526819537, 51.44517960086946, 48.376140671391646, 52.62611504523985, 50.16684386038011, 53.61072801774549, 48.05845614402525, 53.92105810103878, 54.85829668660318, 65.65160820561071, 67.854948659097, 71.2961067691926, 67.76291416537377, 73.44417710458079, 66.90767272826164, 71.35031392497402, 65.89088455323251, 66.27617113051876, 61.145224571228034, 78.01443653721964, 68.68326694734635, 80.88706278031873, 71.47194662401753, 84.32152148216002, 7.149383050780143, 11.258819391650539, 69.34885394188666, 59.76371088335591, 56.03898502165272, 43.053198014536214, 77.75384210771131, 84.5853557894307, 59.8360433117036, 80.06144308274793, 17.456114253690167, 0.72686213879816, 0.47939851759902896, 0.26674908796145075, 0.27510300098407653, 0.2450051071542886, 0.21813256605978937, 0.17189341417003065, 0.1881030532381227, 0.2760663718706177, 0.1999717163703134], [0.026719976599598606, 0.09598555388830363, 0.02536343598377801, 0.04492862442989023, 0.04074308007294613, 0.08634763153930826, 0.05420022268569278, 0.10076686184132293, 0.14624886605287754, 0.12764141774706303, 0.04881054515980425, 0.26208453180809177, 10.920210000007383, 62.68080503709855, 39.97699291475358, 46.58658281449349, 57.21023221169749, 38.96326811082902, 18.669930927215084, 50.822719066373764, 66.96002852532172, 25.542849148473433, 0.19172301786320825, 23.87517306112474, 73.73979045498756, 71.86186944284748, 73.791471604378, 66.2253999710083, 66.69721403429585, 64.27056520215928, 59.99346371619933, 59.35725527424967, 57.31761886227516, 56.41675241531865, 55.557882785797126, 52.10611858675557, 51.07963823503064, 51.36387671193769, 49.604109256498276, 49.60495256608533, 49.631620760886904, 48.86309508354434, 48.16100258981028, 47.02140500468593, 48.532227470028786, 48.27399038499402, 43.91582919705299, 44.23489439872004, 45.134811632094845, 44.5908808708191, 45.26066480144378, 49.10852955233667, 57.782517786948915, 60.27324245822046, 61.13997643993747, 60.936672149165986, 63.01447322291713, 58.65425279063564, 59.94322207666213, 58.28323187366609, 50.36468428950156, 50.1192262864882, 50.811556000863355, 54.48118040638586, 53.64429958405034, 52.831662931749904, 50.83554521683724, 49.17808494260235, 48.00571987705846, 48.66937314310382, 53.00372946646906, 52.34856813184677, 49.473160928295506, 15.801923274993898, 28.399936922134895, 41.652170535056825, 40.949795630670366, 37.622802026810184, 40.621991388259396, 37.424086909140314, 38.16828212430401, 36.28008842468262, 38.008904457092285, 38.591137163100704, 36.66474742274131, 32.474238141890496, 36.042388869870095, 43.7588990888288, 39.824875554730816, 43.51003646850587, 45.70799543011574, 44.51910541903588, 45.26506962314729, 47.535243341999674, 55.480921960646114, 51.68768405914307, 51.578512730137, 53.68117378604028, 43.907145069491484, 38.56475922369188, 36.6789032566932, 40.62923600596767, 17.239756314985215, 27.19134876804967, 50.63540627879482, 53.37810793230611, 52.351945292565134, 45.013579014808904, 44.289293750639885, 44.10223199475197, 43.73259567445324, 47.04372721333658, 47.21882574019894, 50.81067738994476, 48.52255490518386, 46.070410666927216, 47.938000156033425, 49.693907999223285, 46.24059054159349, 48.62310486455118, 46.043542431246856, 45.99086892220282, 43.99608873551892, 44.2633355048395, 43.9317814765438, 49.03889179229737, 54.85244843267626, 52.923885699241396, 53.74776778682586, 54.26235921921269, 50.95126298166091, 45.66636339310677, 44.65655703698435, 43.43174988223661, 43.33582831967262, 44.69805179103729, 46.20084908700759, 46.26126535477177, 45.863089869099284, 46.21195723933559, 50.06256372697892, 55.3310364292514, 60.18782500297793, 59.756427041945926, 60.46485808587844, 58.82644876357048, 58.02455548317202, 53.04349053290583, 56.47183818201865, 60.62327477239794, 66.84083554052538, 66.6281646297824, 66.80362009233045, 69.75171273754489, 50.17491609819474, 0.41057860238417504, 14.352343716929036, 58.48755990305255, 57.016067043427505, 31.517783864851925, 26.728748352296893, 59.029003881639056, 62.87375034824495, 50.10637267943352, 55.83916379559425, 4.4878474935408565, 0.29947648666078047, 0.1613162680258674, 0.10018583777691088, 0.01915603046185307, 0.08880070635988828, 0.06364994404476977, 0.1438651221894449, 0.032696284038285096, 0.1078514744257254, 0.029073505955297622, 0.14161340591888275, 0.0834853814974908, 0.05304359462893298, 0.021967801055119886, 0.04313839569447502, 0.04495485911085721, 0.014065069769839606, 0.05825855048193086, 0.04959547884702202, 0.08935264972669464, 0.29919315670286456, 0.39254133799864405, 10.970256501628507, 72.33031026778683, 43.66884931441277, 58.02081354202763, 62.5719710319273, 34.73799682432605, 22.10658419516779, 59.07800997457197, 72.37543321424916, 33.05411154224027, 0.21355851553380492, 30.233721463910996, 79.98238378955473, 75.97633377198251, 79.39283586317494, 70.7100183733048, 68.79412881789669, 67.92976394776376, 63.50646395837108, 61.27944023378434, 61.3953580394868, 60.10474135798793, 57.465476528290786, 55.077113951406176, 53.14740196351082, 52.96206605049872, 51.12556918974846, 53.118039100400864, 53.185421497591086, 52.3730751006834, 50.34065192745578, 51.162502227290986, 51.19534815511396, 52.004988116602746, 47.9352270403216, 47.062621270456624, 48.67886920129099, 47.02544112359324, 48.17797076317572, 50.75079848689418, 58.529105647917724, 60.25967890216459, 63.45160961151124, 61.681298825048636, 63.142546453783595, 63.3717619219134, 61.39960596638342, 58.83080651683193, 53.32586588398103, 51.73439556552518, 54.07062592044954, 57.086457898539884, 56.28413707979264, 55.03297944222727, 54.633140871601725, 52.68557033231182, 50.692390472658225, 49.51659725558374, 55.47969818115235, 53.656498155286236, 56.738057290354085, 22.599588863311276, 30.063814193971698, 45.08215773490168, 43.51331164759975, 40.54889017535795, 42.17470476704259, 39.80969205979378, 42.86432020125851, 39.16958870426301, 39.34598161328224, 40.502378709854625, 42.44089249641665, 32.79471735800467, 36.3976614705978, 46.984103264347205, 37.96677035670127, 42.50892992942564, 44.47670851984332, 43.001477641444055, 45.719393837836485, 48.168764960381296, 53.13843542529691, 51.37574580407912, 52.3243357289222, 53.44546287290512, 46.056078326317575, 40.08852551060338, 39.15530343209544, 39.066500971394206, 19.715091566885672, 34.58193748228012, 51.49898667489329, 54.897732196315644, 54.90786760084091, 47.22586247228807, 46.35322532346172, 47.78293709601126, 46.37877956513436, 50.38877156472976, 49.59571930669969, 50.83675330685031, 48.858219577420144, 48.1525694939398, 50.73076694242416, 52.30279407193584, 51.43392632084509, 53.047660012399, 51.073644853407345, 48.37293609496086, 46.910260723483184, 49.048046604279556, 47.40655037664598, 51.59328437620594, 56.32496895328645, 57.33043716799829, 54.0070442999563, 56.93752158072687, 52.19554862668438, 48.01877352499193, 49.34964549156928, 47.469382824436316, 46.93380278925742, 50.01387926840013, 50.45223551411783, 50.62358425509546, 49.93161539877615, 50.49374595765145, 53.594509017082956, 54.99149253291469, 63.59482319124284, 64.1321643706291, 63.26652865256033, 62.168704309771144, 61.20540941915205, 54.59409367653632, 61.20656259598271, 65.60572431933495, 71.88228145722421, 71.68991273449313, 72.11093994878954, 72.13004973626906, 49.56761944678522, 0.1726503703262537, 19.933312631422474, 64.25946489457162, 61.55621836262365, 43.84648953714679, 32.29426607008904, 65.33574758037444, 75.97233295440674, 55.824505898260306, 68.30966118843325, 6.588208569634346, 0.3333068681099723, 0.23454855857116563, 0.173040263114437, 0.10326310571643615, 0.09159127355463083, 0.05790203997504808, 0.06460224113036549, 0.10286308524589385, 0.2155576372939733, 0.07108329900450285, 0.2919809904790694, 0.12426662424038495, 0.1941376350699894, 0.236656817217027, 0.16051150798316927, 0.18196843564510348, 0.14471163402401632, 0.15756231462282522, 0.25782612482866935, 0.31841623326463087, 0.43719120984596593, 0.5655282507500341, 17.494728026851533, 80.9461493645945, 48.23963826702487, 62.2259787590273, 72.25358086247599, 53.53572445531046, 26.320362937065866, 65.3597838647904, 76.18414878845215, 33.18279274048344, 0.2886226142366087, 33.19062571371756, 80.44942825071274, 75.62001782078897, 82.3984932130383, 71.33466366798648, 71.13218307495117, 69.7186157780309, 65.35672833842617, 66.64012001406762, 64.2258737164159, 63.544248150240996, 58.97431427432645, 57.078338592283195, 57.49909908540788, 56.18984722322034, 54.703421900349284, 54.375664726380386, 57.289087541641734, 54.67731460448235, 52.6671548043528, 53.1455349153088, 54.645229616472804, 55.729376654471125, 48.98968173611549, 49.612456060224964, 51.5232700686301, 49.520029329484515, 50.77870615067021, 54.91213906195856, 63.608343601226814, 64.68358685893398, 64.46844485498244, 65.47791388727003, 65.48261288673648, 65.45365795012444, 63.25541265549199, 62.53973307148103, 55.99550162592242, 53.51831697648572, 56.21382859445388, 60.679729446288086, 60.456366154455374, 59.26680934044623, 55.67345150055424, 56.19009433254119, 52.590519535926084, 54.10919850872409, 59.41775783415764, 56.79117402722759, 57.668239531978486, 29.144989175181237, 37.358120487582305, 46.92807220643567, 42.8351769908782, 45.73678954955071, 48.18882003907235, 44.658996751231534, 46.97824716567994, 44.18780634480138, 43.703213199492424, 44.39349151426747, 45.14055398202712, 39.03284311294556, 44.962843156629994, 54.282994808689246, 40.61495073380009, 44.331792631456935, 46.62328835456602, 45.365239112607895, 49.19433139985608, 49.67193488151797, 55.25963752500473, 52.67650965721377, 52.79660478714974, 59.311171347095126, 51.766355037689216, 43.43301288543209, 41.19121359240624, 43.24087558254119, 27.594484090805057, 41.515373952927135, 56.183065445192405, 60.844786705509314, 61.39196126691757, 49.937569556697724, 51.345810274924006, 51.84118993820683, 49.60779236209009, 52.498186942069765, 53.03536338190879, 54.769545216714185, 53.56385569418631, 52.80828168315273, 53.58717418486073, 56.484644720631266, 53.060874477509536, 57.731793695880526, 54.32727052319435, 51.44380284893898, 51.45674274813745, 52.97343307925809, 52.344273136508086, 54.74097859474921, 61.039610831968254, 59.71010777258105, 56.23139296808551, 61.47359363494381, 57.04841875260877, 53.78236309174569, 52.90357566648915, 52.63888236015074, 49.47008579008041, 52.193093222956506, 54.472602182819, 53.996371530717425, 53.69884406366656, 52.82167265492102, 58.26613818445514, 63.36851419941072, 68.84548048819266, 69.60598884090301, 67.07363605499268, 66.7404777772965, 66.7547316705027, 60.59022880369618, 67.08086106085008, 70.17504630550262, 78.1207327688894, 75.22097941367858, 79.10036040890601, 76.9947301187823, 65.37617937211068, 0.6489258079278855, 21.50993089522085, 72.54222023871638, 69.87926037080827, 42.534927398927756, 39.85268515925254, 74.0928900626398, 83.14996442487164, 67.90417440475957, 80.14150650270524, 8.168414821547847, 0.5569285767212991, 0.4517802511972766, 0.3171010748032601, 0.24770755891598042, 0.2517860578072648, 0.19584585792355, 0.29097956034444994, 0.255785481103005, 0.38952892706278835, 0.19342177187002477], [0.5684998138777672, 0.5419798724112973, 0.0935270551652197, 0.1995264813904801, 0.2245168670290901, 0.14629631753890746, 0.05163093615743903, 0.12283822266204704, 0.21186886265152888, 0.1320518165706627, 0.10478326164546514, 0.26698991536132755, 4.922026905321307, 66.27872851587111, 46.07567841006864, 31.581094841803278, 54.9662991492979, 42.236811576351045, 21.326975860903342, 43.21818467109434, 64.84128575171194, 44.91098550058181, 0.6097611256184117, 33.59509660351661, 75.60533246686383, 70.95271895008703, 73.50874716235747, 67.37054378755631, 69.5091925897906, 65.11357668907412, 59.78086733048963, 58.008842468261726, 60.10707909061063, 52.62309482020717, 49.81947875791981, 48.03419628450948, 50.54813354246078, 48.917745467155214, 49.654366585516165, 47.74920863489951, 49.6750335539541, 44.85632334986041, 48.91480761189615, 48.64086535669143, 49.251021415956565, 47.144234026632006, 49.455792673172496, 45.26788588493101, 47.41907058223602, 42.32033060443017, 43.125714794282, 44.64260516628143, 55.469994237346036, 57.44597450379403, 58.15218156383884, 59.874847319818315, 60.52339161595991, 57.56182955157373, 57.11239261011924, 55.23962559238557, 51.40015863603162, 49.469579804328184, 52.87266346716112, 53.3416259673334, 52.86583462069112, 50.25037857793993, 53.81783308521394, 46.576086551912375, 50.498566550593225, 46.93902346395677, 56.04284463390228, 50.076233187029445, 57.38370295493834, 22.342706957171043, 24.771352275725334, 34.762362587836485, 30.35005896322189, 43.23788281409971, 37.671812042113274, 38.172239795807876, 33.19344197550128, 35.95974845270957, 37.71344407912224, 37.5600480264233, 38.05426274576495, 18.39983259477923, 51.448572451068515, 70.41322831184634, 48.41120273836198, 35.45198586679275, 42.66058837213824, 36.06527197745539, 40.11950046785417, 41.615555209498254, 45.00823674663421, 47.5073003768921, 46.817143655592396, 40.04702291181011, 43.39656229942076, 42.588004912099535, 44.27698143066899, 21.120916105085804, 21.44347809976147, 35.33131807081161, 52.21873767914311, 51.458645097671024, 48.32988808231969, 39.01693005715647, 40.002037248303814, 44.2767107871271, 44.13556821884648, 44.27543209445092, 47.437803822179, 45.103824907733554, 44.46025809934063, 44.43821830134238, 43.15819986404912, 43.526141720433394, 44.14125957796651, 46.04025940741263, 45.24426537175333, 44.77760922524237, 45.147323992944536, 45.75549925527265, 44.093947948948035, 49.70361586539976, 52.45366804061398, 54.14902625545379, 49.541386635072776, 51.15483399360411, 45.772518419450336, 43.81768757297147, 45.41313517478205, 44.499254303593794, 43.32459857386928, 44.01826189410302, 44.35971990708382, 45.358692676790305, 47.76725153769217, 49.66118366487565, 47.55955026995751, 45.385525611139116, 48.50315878468175, 51.71632520614132, 52.701051927381954, 51.17636388347995, 50.53634682009297, 48.75531619594943, 53.6192121044282, 62.646798087704575, 63.70742659414969, 68.06191644360943, 63.48653047315536, 67.59640170681861, 22.55925120845918, 0.5638021627260793, 24.632333670893026, 52.52978947854812, 42.830289717643495, 17.62825139107243, 24.30438626197077, 52.15127683454945, 48.62860402753277, 43.79917006338797, 62.170539979011785, 4.752866846899833, 0.29692691540525806, 0.06157217186785514, 0.1735057381372298, 0.10969469729330271, 0.023631573572093924, 0.10376326920044038, 0.24824904518262034, 0.4449978602990028, 0.20074784004640198, 0.5854518687532795, 0.6970395616466, 0.5493283103550635, 0.1514222271620266, 0.41043537458585155, 0.2359077977316995, 0.04816287527641943, 0.05269311323401429, 0.09108601558593013, 0.4070626265339313, 0.2743479753694227, 0.12087165197778134, 0.07335595245803557, 6.631788063433863, 76.68602389674034, 47.79378244953771, 35.05129221946963, 64.07081065639373, 43.41108291379867, 21.17142446579472, 48.969693337717366, 70.29208198670419, 51.96775305655695, 1.2543401506639298, 37.97956905057354, 78.84898354930263, 72.86315641095563, 78.32667289241668, 71.17619206828456, 71.69704360346641, 67.04688549041748, 62.31905660321636, 60.358275521186094, 64.06746879700692, 57.77612040119787, 54.75279277370822, 50.53178510358257, 54.24710119924238, 52.891153520153416, 52.53225272701633, 50.92944283639231, 53.55563832867531, 48.75494749315324, 54.558349117156006, 53.372491098219356, 52.350286129982244, 50.243126115491314, 52.15555614040744, 47.30585528958229, 50.884668980875325, 45.039784369930146, 45.613030925873794, 49.24614590983237, 58.658857653217936, 60.241930177134854, 61.94621962885704, 62.35717027418075, 62.6813933926244, 58.96533596900202, 59.858267461099935, 57.199892843923266, 54.33194206606958, 51.27402697840045, 57.08042137084469, 56.96157747699369, 54.613654536585656, 53.631700931056855, 59.027313340094786, 52.413553960861705, 54.79490726224838, 52.142549560916045, 59.29275189676593, 52.43091437124437, 62.23096409151631, 32.134682478443274, 30.726120125862863, 40.83467014374272, 35.27954670690721, 47.21375803793631, 40.66878134204496, 37.8218230893535, 35.59111625917497, 37.09485884635679, 39.25610834552396, 39.774743741558446, 41.48301047663535, 20.73132472653543, 64.68975674721503, 74.88052552746188, 46.950566999373905, 37.531053866109545, 42.131625375440045, 35.25200382355721, 39.14830200133785, 39.41609005774222, 41.61042867168304, 43.93637457201558, 44.28080966395717, 40.45514160586942, 43.47808484108218, 40.93523579259073, 42.2345366016511, 26.387264843909975, 28.86117627543788, 39.48664565240183, 54.3000178952371, 54.887012358634706, 51.61464560416437, 42.010467283187374, 44.293592668348744, 48.84146321204401, 46.00560134457004, 46.14110354454287, 47.6720634583504, 47.75318199588407, 47.53863619219872, 46.50256172303231, 43.832212109719556, 45.8326248199709, 45.129049670311716, 48.09521267491002, 47.08291561372819, 46.352754639041045, 48.42175391412551, 49.70163899083292, 48.4388279914856, 52.97830466301211, 56.30205446673978, 56.55127794511857, 51.73662739415323, 51.644004544904156, 49.44992088502454, 48.80494594573975, 48.54286101556594, 48.20984394319596, 49.01765608018445, 46.613976647776944, 48.44732776764901, 48.635738818876206, 52.79733434800179, 53.199365523553666, 52.205268259971376, 49.22282349678778, 50.85496487156038, 54.31358537366314, 54.63109731674195, 53.16195003447994, 55.47477952895626, 53.76269240533152, 56.6066853461727, 67.32024331246653, 68.85127775130734, 74.51075584657731, 69.46553660977271, 72.26794458204701, 21.34129447321738, 0.5622248796205367, 31.947667790997414, 57.02846565554219, 52.58016447867117, 22.94014669233753, 30.957153612567534, 64.59601994483702, 65.24651365895426, 45.474830135222405, 69.84031907973751, 6.558250486850739, 0.4822415005295508, 0.06196974468747936, 0.25295883116702883, 0.09527641694031416, 0.04386296548369912, 0.09815005870956568, 0.3348634055545253, 0.3944970378952642, 0.30116200266826537, 0.5737344007338248, 0.900203750258492, 0.9754020216003542, 0.3772331852345698, 0.5113232706583316, 0.46878896593566866, 0.32949564197371084, 0.24043327828328456, 0.19898536284604382, 0.4780635634256948, 0.6312599429680456, 0.3202086032157944, 0.8746152491338792, 9.633613747935142, 90.48896220422561, 55.00643676327121, 41.68024293838009, 70.00767092550956, 56.7540370264361, 26.647855351048133, 53.70106020281392, 74.7127422209709, 50.50265366031278, 1.1097843848889875, 40.5347421861464, 78.57974421593451, 71.58597776966711, 77.98970207091301, 73.75704103900541, 71.6307790817753, 70.26635908311414, 65.98753175427838, 60.963540384846354, 65.72745115526261, 62.734196339884114, 59.04863142198133, 51.9599396951737, 55.26179090622933, 53.36699585760794, 54.0475506167258, 53.98578113125217, 56.51822805404664, 48.72502373110864, 55.81726128055204, 54.736718900742076, 54.73400462058283, 53.55528139298963, 56.9690848935035, 50.07606060274186, 54.33520940042312, 48.75665372417819, 48.94861059804117, 51.163145495999245, 64.29039278338033, 65.68386185553767, 64.34806731439406, 65.42574244160807, 64.1102030200343, 60.86207259085871, 60.995044862070394, 57.54852094957906, 56.31417066820207, 52.52193689346314, 58.595570210487615, 60.76902612563103, 56.9380275664791, 54.27223574730658, 60.960896707350216, 54.31690762119909, 56.562801868684836, 55.28744712952645, 62.78501064546647, 55.11406267842939, 63.71603227430775, 37.83392752370527, 37.464820723379816, 44.6854962841157, 36.59575685378044, 46.01665458371563, 43.02126599896339, 43.294694423675544, 38.618036777742454, 39.80228270253828, 42.074947126450084, 42.0095298367162, 43.551099761839836, 19.743120824137044, 74.7633800198955, 77.9160556485576, 49.41651013589675, 38.61183943287019, 45.160142298667665, 37.28752959159113, 39.72799301147461, 40.46735586658601, 42.418821319457024, 46.20136291750016, 49.426057184896166, 40.04707782499252, 46.95279098326161, 40.54713687589092, 45.17859312795824, 28.71323035609338, 33.28258176003733, 44.97224507793304, 55.540910690061516, 59.38529237624138, 59.30557020248906, 45.05108471839659, 45.92092913966025, 52.35119611986222, 50.84085218368038, 48.86169479739282, 50.58426641648816, 47.2477061517777, 50.13705345892137, 52.77198014720794, 50.91467903506372, 52.296781078461684, 49.82855904486872, 52.77491015772666, 53.73731074794647, 50.391023005208666, 52.66727639782814, 51.93655060183618, 55.03929445820471, 54.86176013946534, 59.6889034394295, 62.26248425822105, 56.61131374297604, 54.639185244037265, 55.621174150897616, 54.012296353617025, 52.74864988942301, 49.25354349997736, 50.163215667970725, 50.98022184064312, 53.619125812284416, 51.32361358211887, 55.25916684058405, 56.907531138389345, 55.91092355789677, 52.40477569641606, 54.22734422068442, 59.77899243754726, 60.31084229869228, 56.74694538116456, 59.11151093821372, 58.06013922537527, 58.75255130952405, 70.97425276233305, 75.96187591552734, 82.19773846287882, 76.50301394924041, 80.87558592519453, 29.99213484025771, 0.5828295191449504, 34.341123565550774, 65.53874984864267, 56.47827479147143, 21.895040965849354, 38.252060028814505, 68.58313668158748, 67.09875491357619, 54.189916964500185, 84.97712212224161, 9.024248046259727, 0.7160257944656957, 0.2838368016865946, 0.24843102170815393, 0.3381320882228113, 0.13614940637302014, 0.1821396103309047, 0.3864784875223714, 0.5144368664872262, 0.2890526959972997, 0.8887849339554388], [0.27173733158457664, 0.46479921066953295, 0.15663398459794062, 0.44371959663206534, 0.3370313118061712, 0.063726763511377, 0.04595728515977821, 0.6450814561497781, 0.5770883949533586, 0.6364277882441398, 0.03980794718729393, 0.382707649541478, 4.602808240921267, 57.79736003568096, 49.24761287627682, 37.16312377683578, 31.6729449841284, 32.072667844833866, 22.190403284565097, 28.728358937848, 52.59885065017208, 66.76962883241715, 3.510894419685487, 26.24425522742733, 78.22526393398162, 69.00878444794687, 74.9792358952184, 63.806078126353604, 64.68645803390011, 58.05635021578882, 54.018085771991366, 55.758814042614354, 57.578009328534534, 46.76225792977118, 47.758861587893584, 46.077455243756695, 52.33251779310165, 50.44048801545174, 47.78270567617109, 47.261238328872196, 46.891166625484345, 49.01460839856056, 51.80022470412716, 50.274183442515714, 48.33566181121334, 50.54788251076975, 45.416673152677475, 41.60327426848873, 46.61998571888093, 42.03131075828306, 44.324112630659535, 47.16186115818639, 53.61288924371043, 55.19235318706882, 58.25898378126083, 61.531295622548754, 64.91570880336147, 59.34095390381352, 60.68801741446219, 55.89416719252064, 52.41241647351173, 51.215787626081905, 54.77443248994889, 53.490193582350216, 53.26672830889302, 57.7078946944206, 56.39396736698767, 49.89680436349685, 50.51747629719396, 47.77550812690489, 50.24905673919186, 50.92988606422178, 59.32118515814505, 36.06421293750886, 23.66885639006092, 42.705421063207815, 34.259467663303504, 38.03328198771323, 35.913099704250214, 33.47248723430018, 31.368068956559707, 33.405316645099276, 38.319446348374896, 38.43563871998941, 36.89135059233635, 32.5113163071294, 102.86674653330158, 88.52270941580497, 47.8953992935919, 39.82445978349255, 44.95006407460859, 38.50437825725925, 39.70469021028088, 36.85550012896138, 40.31244185663039, 34.554626018770286, 38.79845403855847, 44.34359112093526, 46.51905136723673, 39.08339854209654, 27.604321395197225, 35.03224126754269, 33.077496713207616, 39.757006783639234, 50.098253373176824, 48.885691858107045, 44.30301420150265, 40.9558125465147, 42.82651639753773, 50.415965357134425, 45.680436857285045, 45.365180277055316, 51.714105144623794, 50.17015826317572, 46.26975728619484, 42.04998516267346, 39.4527171504113, 39.13672708695935, 39.50095053642027, 46.06091853111021, 43.045494479517785, 44.35782932466076, 42.52599616204539, 42.171986564513176, 42.775482439225726, 48.95053648179578, 52.065769164792954, 46.89124115051762, 43.664915177129934, 44.1909207067182, 42.14836997370566, 43.052515522126235, 44.750113410334436, 47.00022812812559, 45.48644819567281, 44.84774904866373, 44.138910078233295, 45.7109332853748, 44.42290536818966, 47.298751877200225, 47.48452709567162, 48.43660792996807, 48.29309625010337, 47.948194396111276, 47.77128373422931, 50.959044964082786, 49.95046238745413, 52.73421556718888, 56.3059768369121, 63.97841138224449, 63.73147464567616, 69.27243048144926, 60.82599070764358, 61.940716543505275, 5.581467055505322, 1.0997768251165267, 32.76893561886203, 50.28858246341829, 30.170053551273963, 26.022835470015004, 33.094770831446496, 47.03417624196699, 53.04345130920411, 26.40252482506537, 65.00786096818986, 6.087452317437818, 0.19143239474825322, 0.09797689985604056, 0.4928095302274151, 0.5338235487861018, 0.3241060602088129, 0.29334649623882386, 0.37009805681244023, 0.14668645547522655, 0.1353945799412266, 0.21982156010645054, 0.28376668931976445, 0.3881916133386474, 0.0868453971681095, 0.8301451934441444, 0.4178253344951138, 0.12406841431173588, 0.0721271321057312, 0.44238124102834736, 0.447206951437458, 0.6692895894089054, 0.0579897761945763, 0.45137964849991186, 5.270115685078406, 70.67921992271178, 49.338239239108184, 39.904621262704175, 38.18335971524639, 36.942051149183705, 24.58838547429731, 33.29165812461607, 57.77933674473917, 76.10676042495236, 5.653305755507562, 27.196508646011356, 80.36556013168828, 70.76828125984439, 79.0566965841478, 66.65300892245385, 66.68317194907897, 61.72234642890192, 58.55963345496886, 56.89228096315938, 62.00419618237404, 50.62317240622736, 48.68771806839974, 47.88834294965191, 54.60083230849236, 55.03966708337107, 51.46460317796277, 48.69255827319238, 50.70503619409377, 51.2459663421877, 55.68119033690422, 53.11892163368964, 51.00869432572396, 54.152423028023016, 47.068324396687174, 43.5677816021827, 47.160405958852465, 44.33139647206953, 46.16208822496476, 49.31558362899288, 56.91264983146422, 56.37292777338336, 60.6220196139428, 64.03899631192608, 68.28807246300482, 62.985318245426306, 63.50306326343168, 58.51787982448455, 54.240978379403394, 52.80126848528462, 58.98069597059681, 57.201583385467536, 54.93797963665378, 58.55099639584942, 60.90621494477796, 55.18762673101118, 54.06309496971869, 52.187833324555434, 53.67485877006285, 53.90555297174762, 62.77757383161976, 42.19613267529396, 29.132106150350264, 44.116501577438854, 35.054975325061434, 39.80802113010038, 41.365868891439135, 39.57386739792363, 33.92327347109395, 35.82013560879615, 40.28182383506529, 41.15663397696711, 39.85177124700239, 36.45606948483375, 104.39438419957315, 84.87325776007869, 43.63552877979894, 38.453089344886045, 43.276549539258404, 38.067273247626524, 37.82588666485202, 37.87619498468215, 37.75756289882045, 32.995252455434496, 37.18562641451436, 42.89822909139818, 45.51134740152667, 38.479455517184356, 29.729696896768388, 40.13376220580071, 37.0358899331862, 43.646782059823316, 54.20943467847763, 51.02625085461525, 49.08501886552381, 43.38721136892996, 46.15449451631116, 54.52541297481906, 48.78570672004454, 46.69658176360592, 55.14746950518701, 54.500964841535016, 51.319710823797415, 46.83743799886396, 43.08878567910964, 40.88162875944569, 41.48775262217368, 47.734558582305915, 45.80802763662031, 48.202481654382524, 47.85419087256155, 46.76839251672068, 46.56062849106328, 52.1145163812945, 58.318391999890736, 53.34296349556216, 46.01503464483446, 46.25896684585079, 46.75424844987931, 46.582240750712735, 47.06208782811319, 48.894372063298384, 50.5771904606973, 48.441695244081565, 45.561349776483354, 48.40780204342258, 48.66501931221255, 52.541187886268865, 52.937076630130896, 52.19426601163803, 52.501642550191576, 53.46460403934602, 50.54811000823975, 52.7995857884807, 55.697585844224506, 56.38503220773513, 59.41076817051057, 65.60466920175861, 66.30198817099294, 72.69425130659535, 62.70289974827921, 65.91947863178869, 4.812076985836029, 1.4057080928356418, 42.096253441226104, 53.687147555812714, 36.437551975250244, 25.064684767876905, 40.030309692505874, 57.18986334339265, 58.674758941896506, 26.144627025050504, 77.8025971689532, 12.567298546914133, 0.8307080535638718, 0.1463056638115837, 0.34882560312267274, 0.6304301778154989, 0.43417165897065596, 0.3307989107504968, 0.2943668947104485, 0.2466377784167567, 0.2195220810150908, 0.16397466973191308, 0.3982365888453299, 0.44094997428117266, 0.29631272739460396, 0.733267430576586, 0.816649359560782, 0.13143594316657514, 0.20631492438335575, 0.7825778749200606, 0.6539552670813377, 1.1418075955683187, 0.23417536649973164, 0.6104222288535488, 7.1421845209214005, 80.40656458946967, 58.369473026644805, 48.22215234079669, 42.75718850474204, 43.50210151364727, 28.131652685903735, 37.50512699927054, 62.169092624418205, 76.56108071727138, 5.34702600971345, 30.505657426772583, 80.36907457536267, 70.60011356107651, 78.53957914537, 68.39621220865558, 64.63406693550849, 61.98348999023438, 61.780032727026175, 56.74844372657038, 63.700052538225734, 53.307050274264434, 52.71038716839206, 49.11823349614298, 56.2735309908467, 56.95640779310658, 53.96723224270729, 51.71302257045623, 51.75459969428278, 54.04626015693911, 56.32686345807968, 55.68974894862021, 51.46392853029313, 56.430414030628825, 51.811054368172925, 46.29484476581697, 49.61667653053038, 46.525993962441724, 49.64492936288157, 52.318511009216316, 61.78473172649261, 61.390808090086914, 61.96765145947857, 67.69457863223168, 70.0002811801049, 62.68892042098507, 62.17459570976996, 58.979585939838046, 53.88484285723779, 49.981209847234915, 59.46627363081902, 61.00949487378521, 56.176111082876886, 58.31742317445817, 61.92719221115113, 60.443830259384654, 58.22769895676644, 58.3679864483495, 58.666757306744984, 59.339945854679236, 67.2757871689335, 48.49325087762649, 36.77540140767252, 50.16825591364215, 37.63113706342636, 42.1107622884935, 43.97527663938461, 41.60940885543823, 36.58709626043997, 39.65240501588391, 42.13794431378765, 43.33713446894, 42.91893920590801, 29.138393709736487, 95.22425928423482, 75.32351801472326, 48.78525172510455, 42.03061257639239, 46.42940167457827, 38.60051947255289, 39.38025528384794, 39.048783625325854, 37.77225609748594, 34.009232213420255, 37.60893252588088, 42.67665440036405, 47.25901042261432, 42.28272684158818, 34.60202393993255, 44.668532033120435, 45.07885902158676, 47.91782348386703, 57.08303759174963, 55.58167980563257, 54.096442960923724, 46.61176443099976, 49.31865876720798, 58.35044168656873, 51.90036281462639, 46.34273298325078, 56.36225500414449, 55.501957631880245, 52.50673378667524, 50.10961647956602, 47.53166221803235, 46.93597578233289, 45.379645978250814, 55.451880731890284, 52.80238243841356, 54.79720184879919, 50.55637444219282, 52.46492524300852, 51.275356661888864, 57.24969125563099, 66.47052457255703, 59.7151009498104, 50.143231191942775, 50.877463586868785, 50.89310992148615, 52.06113684561945, 52.8239123282894, 53.34631712205949, 51.598081434926684, 50.07369149115778, 48.767824634428955, 51.75217566951629, 51.51481736090876, 53.76761497989778, 57.21776316242834, 55.90506353685933, 54.20021318620252, 56.002452065867764, 54.81388761151222, 53.971695899963386, 60.00253223603772, 60.26980253957934, 60.47051414366692, 68.22473402946227, 70.98991870880127, 81.09114370038434, 71.10323598307949, 76.59355794229816, 8.356077190368406, 0.9606164020876732, 48.26865988392984, 60.898232921477295, 38.293386120950025, 30.515977182695945, 53.033441420524355, 64.55370149304791, 74.96363270667293, 33.52828295000138, 87.12913836202314, 12.862141151582042, 1.0273214549787584, 0.4226936087492974, 0.7661260448155865, 0.735236092680885, 0.6477569416165352, 0.38501476929072415, 0.46064575773573696, 0.24490959131188933, 0.39727481142167126, 0.4000850670760678], [0.17544357286345574, 0.12079411621896491, 0.04959290862203606, 0.13307578501201447, 0.2791184968044681, 0.08924706748897031, 0.024797478953616756, 0.4689053193696084, 0.28985148055418847, 0.06472939640403756, 0.13920876317687575, 0.1991618082167641, 2.9457039217795096, 62.79283185159007, 56.886828868619865, 50.29066916434996, 25.277781255783577, 31.52457544880529, 18.4991999595396, 31.989478295849217, 47.85863099559661, 72.14572352747764, 11.909825955667804, 20.50910676679304, 85.57263205128332, 65.68243803516512, 73.52850021854525, 62.00314498716786, 67.7337944892145, 58.2650673773981, 58.77359482549853, 55.740500496279815, 54.90179969418434, 46.88111751310287, 51.376706784771336, 48.900557641060125, 52.65312056387625, 46.98284418352189, 47.436544741353686, 45.87781836909633, 45.69314533664335, 46.99099486873996, 48.09856630140736, 47.28178762620496, 48.24301542774324, 46.16823065665461, 45.59239533639724, 44.333251753161036, 44.81649168076054, 41.77686660520492, 46.635584985056234, 44.62449166082567, 47.703375739436, 51.72728430840277, 55.72854903436477, 57.36587186013499, 57.08794839920537, 57.449900796336514, 61.0832707343563, 55.68139037778301, 55.09779268695463, 56.53173669692009, 59.96966277399371, 51.08841257710611, 60.02932202431464, 57.738783359527595, 53.37025926959131, 51.48281082030266, 54.387486750079745, 45.55076329938827, 46.52667645485171, 52.39660539934712, 54.41533165593302, 43.094147559135195, 26.010766336994788, 31.374972328062984, 34.35790738751812, 37.50601737729965, 33.42035501233993, 35.42142275841006, 32.654604411894276, 33.902441763108776, 39.22090507322742, 41.119610724910615, 37.348118443642896, 40.780945439492505, 59.553279645981334, 45.41628483803042, 40.03312203191942, 47.19058075258809, 45.89443745151643, 42.214575659844186, 42.010126036982385, 38.98413512014574, 37.228890157515, 41.343833015811065, 42.50382692583146, 43.84755642183366, 38.989720575271114, 36.505244239684075, 34.96573748127107, 38.624614592521425, 30.990887957234538, 39.1373428990764, 48.38942181679511, 45.3384179453696, 45.2338122552441, 43.737757513600016, 45.97637968678629, 48.393332419856904, 45.62582177500571, 49.62587056621429, 49.2074909517842, 47.09532991532357, 48.04112319023379, 45.99212015828779, 43.58647954079413, 44.19938125917989, 45.87774776643323, 44.55083347135975, 42.50622349400675, 43.839276298399895, 44.57566991929085, 42.342511607754616, 40.77541489754954, 46.10989324508175, 45.87151512022942, 45.646316159156065, 46.14035829421013, 45.11884758549352, 47.11076836432181, 44.36028865075881, 41.63142904158562, 44.21532569393035, 46.936913228804066, 45.592579687795336, 45.81187548175935, 45.79456606218892, 45.78905905446699, 46.24274392281809, 43.965141234859345, 47.914732656171246, 50.61800272234025, 50.3410598539537, 52.49161304966096, 51.406285378240774, 50.58763965483635, 56.54461776056598, 59.22701297267791, 63.90531801408338, 64.89733642147434, 68.98648185114708, 62.64256977265882, 48.249542251709975, 1.1418399551222402, 3.5884328138443733, 46.73526810061547, 43.3879566192627, 19.94815488015452, 30.314673300712343, 30.83919813556056, 42.59977594498665, 49.172954482416955, 42.854306390208585, 68.07267158262192, 12.571785738391261, 0.45152468426573666, 0.0734931588052742, 0.14628484154180174, 0.11570748392372363, 0.14342308945713506, 0.19766015331110648, 0.13680678642084523, 0.10478455633405717, 0.1218268410452912, 0.10776539678655325, 0.13798769563436508, 0.16280759606630574, 0.09146594923109778, 0.16421724381225725, 0.34452469358521126, 0.3248958355717121, 0.10962025652970038, 0.2847906730828747, 0.20479538898554542, 0.0005878028053801597, 0.16587482825402292, 0.16799816351023414, 3.5534580196103747, 75.28132115640949, 55.27741762899584, 53.965871180257494, 33.72006723957677, 37.583307681545136, 23.250198287348596, 36.57979280717912, 51.86670887854792, 78.21181020429059, 14.936025738716127, 22.42321360495783, 88.42288509491952, 67.58619569963025, 77.09272661516744, 64.44258074606618, 68.65280582058814, 60.316372840635246, 61.330062343228256, 58.927116394042976, 58.46703806231099, 49.58474059258738, 52.66923758291429, 53.721389847417036, 57.8083073708319, 50.059692552012784, 51.12034851504911, 49.53726422402167, 47.33449251421037, 50.858263584875296, 51.83775394193588, 49.68880107325893, 48.90992818340179, 47.76077962690785, 47.23804535404329, 46.14581823349, 47.71915151226906, 41.86545725791685, 47.56930128220589, 45.71232572678597, 49.7306017721853, 53.962090015411384, 56.8574385489187, 58.33137112279093, 58.13655091870216, 58.4470025954708, 61.49896744758853, 57.754492452067716, 58.05301227877217, 57.475855119766734, 63.61919287712344, 56.43646624780471, 63.427443888879594, 62.22168376368862, 58.68457271206764, 55.031692904810754, 56.28803199337375, 49.79722715193226, 51.66771919496598, 55.68179438191076, 59.01342030494445, 45.79929251824656, 33.49198925879694, 37.61684786888861, 39.152859795478086, 41.227738703450854, 35.77046271293394, 38.93499566662697, 36.61094034871748, 36.80032022537724, 41.812485648739724, 41.86473161943498, 34.87181632749496, 39.04583400295627, 52.82177071417532, 45.33126746454547, 39.98059757294194, 45.99452457120342, 44.81309490819132, 41.05211850135557, 38.1420571573319, 36.72996074922624, 37.652231570213075, 40.60645488000686, 40.291935705369525, 42.10407072497953, 39.132161448078776, 38.79239005427207, 38.162080857061575, 41.793387628370716, 37.714824753422896, 43.46247773016653, 52.55859144272343, 49.821863558984575, 47.41763891712312, 47.585053520817915, 52.05026011313162, 52.15944713161838, 48.662748259882775, 51.64155306354646, 51.00024161800262, 49.712574558873335, 46.93030403506371, 48.682250284379535, 48.195084064237534, 45.0577566700597, 47.73047539495653, 47.27369969890964, 46.79310737117645, 47.74090105487455, 47.6876627245257, 46.070555794623594, 47.20170459439678, 48.58546972274781, 50.53572708560575, 48.9795071078885, 48.749248289292865, 49.80782931850803, 50.02636025028844, 46.91023718926215, 46.431358937294256, 48.94142873825566, 49.37832193989908, 48.713790062935125, 49.58270488246795, 49.051792467794115, 49.462123378630615, 51.66563641640448, 48.99918563904301, 50.57296999039189, 53.3574801875699, 53.9184340353935, 55.10772412823093, 53.977975614609264, 53.17908294739262, 61.252532774402255, 63.33897875201318, 69.05827691478115, 68.20895041188886, 71.36923543868527, 67.52460664318454, 53.395189854406546, 0.10196340690937736, 5.28105027252628, 54.59678442247453, 49.38218155214864, 23.228458550668535, 29.604916495661584, 32.645035789858916, 55.458262428160644, 58.46228022729197, 47.240041840461, 80.55555974283527, 16.28041321231473, 0.5566960537145215, 0.15562610400299873, 0.3030074165473062, 0.13835396227096358, 0.1577569622426264, 0.09167486906892831, 0.10479700526282673, 0.058417509895779436, 0.05594215340792172, 0.04611930126444467, 0.2122436022205699, 0.3143533625670018, 0.12478115187296945, 0.22630842492705394, 0.4511212010777766, 0.46599905757654103, 0.20809028718260028, 0.558050987460921, 0.33547664361615337, 0.22928999316307808, 0.2416361435767143, 0.25192547048772534, 4.805158415148336, 88.50774949596774, 64.99357961839246, 64.23504029550861, 33.95082812155447, 45.43544169395201, 24.44582300801431, 44.34529342959004, 57.12163371424521, 83.5396832804526, 15.381589339625451, 23.46609142518813, 90.21281165461387, 68.06285781245079, 79.73571377415811, 65.23103206388413, 70.52353320583221, 63.48922514146375, 61.72060097417524, 60.25192045396375, 60.82327250511416, 49.86773960051998, 53.14227150332544, 57.162885281347464, 58.33620348284322, 52.77933066891086, 52.25094033825783, 52.52696537202405, 50.676112636443115, 53.20316630025064, 53.10320861877934, 51.63483404344129, 51.96815313831453, 50.505979830218905, 49.38105190953901, 47.568524652911776, 50.1847259459957, 44.57522276909121, 48.2821959833945, 50.515075806648504, 52.442352002666844, 59.36181699076007, 60.90252007207563, 61.42961602057181, 61.45554680978099, 60.7294297987415, 63.89508062793363, 60.39463589268347, 59.07886897363971, 59.00636003863428, 67.68351754834576, 58.72107036652104, 66.70264259461435, 63.60460166008242, 63.03508527817265, 62.13605450045679, 62.564294953500074, 52.63199467812815, 56.059216607001524, 62.02420811499319, 60.70967674255372, 49.48867782469719, 40.45525927697459, 44.370745689638206, 43.34929381647418, 45.95128828479398, 41.09273072211973, 46.164916253859, 41.08440353024391, 40.855042934417725, 44.39020849043324, 47.07829898403537, 38.364078998565674, 45.92395720943328, 49.97688347293485, 45.4819727713062, 42.19806640378891, 48.028297039770315, 47.4319241892907, 43.715243108810924, 41.13648476139192, 38.46988101159373, 39.38366774589785, 42.08495309275966, 41.17783046537831, 43.80906228096255, 42.439284324645996, 43.64314602267358, 43.24051472448534, 45.86706715245401, 44.75120775161251, 51.274697703699914, 56.98724546740132, 54.84707086317001, 51.782154344743304, 51.39573420247724, 52.7582714634557, 56.40173365992885, 52.38190435594129, 55.750408403335086, 52.515457137938476, 51.18276911397135, 49.74780921013125, 54.6225465497663, 52.4589357837554, 48.86237336743263, 51.39476145467451, 51.54796138886483, 50.114193885557114, 50.91909954624792, 54.01481451526765, 50.48637582409767, 50.47967249347318, 55.16811686177408, 55.043365878443566, 52.29870303984612, 52.84204152322585, 52.9753589630127, 52.994523663674634, 50.674849633247625, 50.93874669844105, 50.07158517837525, 52.90000630963234, 52.61312023285897, 51.1774621471282, 54.637380953758, 53.37931994468936, 55.076655034096014, 51.21533263114191, 52.97008729750111, 56.00833562112624, 55.8015678774926, 58.732582522976784, 57.63795883424821, 56.62929781021611, 64.48419709359446, 68.00819566172939, 72.31571120600547, 71.97330397944297, 78.76773557355328, 70.3173577400946, 64.3382025534107, 1.7322049602385492, 4.420050305704917, 62.27104679230721, 54.86739266303278, 28.890188086417417, 41.486493541348366, 44.053480855880245, 60.13535937955303, 69.8017543362033, 56.20063374119421, 95.11694323632025, 24.966629435939176, 0.7529238983988763, 0.23785523920049592, 0.45222494991556295, 0.38642210345114436, 0.28447918173286224, 0.21397128370740723, 0.17093635584798553, 0.2180640931211172, 0.25761480713563584, 0.17560484969327528], [0.2639659211760567, 0.15635351980886153, 0.1665340009475908, 0.2444660876907649, 0.09205523172333356, 0.16377711097799963, 0.3435339580380148, 0.2792221025353478, 0.17896635157446708, 0.18170651018379197, 0.31848643756201195, 0.09905361345097904, 1.605650299499112, 55.79504105352587, 54.15215238448113, 45.2788685214135, 24.011469541057465, 29.3278088877278, 22.315962276151105, 28.742391217139463, 45.3968769504178, 72.88618072386711, 21.695623743918635, 14.558397589191316, 77.88939922086655, 62.50487889012983, 72.06743301883822, 63.50133349818569, 61.43313830898654, 57.258940204497314, 60.200329519087276, 53.74715589707898, 53.825348346464104, 49.69149966393748, 51.17066860198975, 48.758756114590554, 50.341891396430235, 49.37083413524013, 47.70841206273725, 46.677319003689675, 47.516808202189786, 47.01790232812205, 46.31644525835591, 44.073053483040106, 47.88846846549742, 47.77334297856977, 48.76861695320376, 50.59935577454106, 47.18022961770335, 45.44944455546718, 46.28835324318179, 47.741642382837114, 49.85725510504938, 48.63367565216557, 53.29518510449318, 56.55348623952558, 58.492023560308645, 58.710562336829405, 57.110168626231534, 57.46641789713214, 57.61997476700814, 52.396656390159364, 55.902643434463016, 57.762552922771825, 55.99937692765267, 54.35966145607733, 53.296742285451586, 49.95709119304534, 52.442257865782715, 46.75731574335406, 48.70181898916922, 46.45287313768941, 53.30864667892457, 42.244048349318966, 25.923938789675315, 35.686841703230336, 33.800213029307706, 38.282513310832364, 34.04283908105666, 32.39954836906926, 31.220479972900886, 29.974870527944258, 33.36013486308436, 36.170803346941554, 35.73798156553699, 35.7755970954895, 41.594652898849986, 44.46528657790154, 55.52388368114349, 62.21051677580803, 53.63151657965876, 44.46121515766267, 39.10585411133305, 38.841851142144975, 36.357947472603094, 34.62184759878343, 33.76978720388105, 40.54591309639716, 40.69240185522264, 44.42078728829661, 36.045542455488636, 39.5201309265629, 27.840655965189782, 40.66971878851614, 50.753238201141365, 50.31514083185504, 46.83188000032979, 42.248272741994555, 45.30756065922399, 46.97108099537511, 48.69969698690599, 46.26617616222751, 49.785722840216856, 47.98375460409349, 49.45093677889917, 45.28738790942777, 48.92581770496984, 46.38807558244275, 48.104795025240996, 47.33455527213312, 47.36467515268634, 44.05124510488203, 42.38485359376477, 43.43880230380643, 44.238267637068226, 43.616885754369925, 46.0032400777263, 45.85138551650509, 44.57832536389751, 45.36756507812008, 45.84548234939576, 43.12000774568127, 43.01754366966986, 45.412464449482584, 45.45159009195144, 42.22068671257266, 45.12857898589104, 44.609057134197606, 45.820583143541896, 44.47544159427766, 47.23881806096723, 45.46583614041729, 47.76472160893102, 46.69647585961127, 49.39525873430314, 51.2452014800041, 53.897025738993, 56.929849424669825, 62.40084978841967, 62.51335905444238, 65.15868786842593, 59.678222825450284, 66.20602346235707, 27.675545753971225, 0.03218258378065882, 9.031614257443337, 53.37471508210706, 36.57551742369129, 20.901637961787564, 32.8028876550736, 32.49758408915612, 44.647210028863725, 43.072809865397794, 40.80910413495956, 63.93669305309173, 11.130246058587106, 0.4235334862624446, 0.07469629989035668, 0.18282168905340856, 0.07913678298674284, 0.10633693392118139, 0.1462068384693515, 0.0646750501266891, 0.13049981436662136, 0.17605506424461642, 0.04087763575596675, 0.16741595200953946, 0.14042287464103392, 0.20925926074625986, 0.10068702781873365, 0.17425304158560692, 0.20692652301682582, 0.505563791000074, 0.34799620569232975, 0.24475913164356064, 0.15819387750760203, 0.2040174420201971, 0.03568537142728606, 1.8992810143578438, 63.23815030436363, 59.39656919048679, 54.92259217846779, 30.52276876664931, 33.66509129924159, 28.253242238875362, 31.9478541035806, 50.01969222099551, 76.9152158306491, 25.43580766647093, 14.503529514035872, 79.26210326533165, 66.17530345916748, 73.0799928788216, 65.235923259489, 65.43206137995567, 58.70234889368857, 62.964266884711485, 55.95869410422541, 55.78803962276828, 52.665272066670084, 53.948287194775, 52.56118412940733, 54.76104936292095, 50.57904966415898, 52.55279025723858, 48.02602598744054, 49.04552844262893, 51.247327404637495, 48.90446824412192, 47.09871492078228, 48.255359126675515, 48.18376802629041, 51.464905200466035, 52.305692703493186, 48.54040953420824, 47.229792687200735, 49.50672464986002, 49.66014815915016, 50.577421880537464, 50.655935964276715, 56.92493077247374, 57.97283118770969, 58.15338180911157, 58.33786264542611, 60.348434294423754, 59.884810140056, 62.073928079297474, 59.25395181102138, 61.30479835694837, 60.51542135976977, 62.896358889918176, 59.97872344909176, 57.510446502316384, 54.0983021643854, 54.786874248135476, 52.25075598685972, 51.903743897714925, 50.3830135253168, 57.28303532446585, 46.523318905984205, 32.405073027456964, 41.47112177264306, 37.603190175948605, 40.94982700963175, 35.66350752307523, 38.57067023554156, 35.26339046416744, 33.6618592662196, 34.693956452031294, 36.611014873750754, 37.52863376371322, 36.21327477116739, 40.08631721619637, 43.083329662199944, 54.72068032910747, 59.66920921879431, 53.372495020589525, 44.75647157238376, 40.08667022951188, 36.609677345521995, 35.28828574765113, 34.451491217459406, 33.52836139740483, 40.96644216968168, 43.19539962276336, 49.39407810088127, 38.68951805176274, 46.74835312751032, 33.49640976998114, 44.62706081328854, 55.038925755408506, 52.53821865204842, 52.6644758255251, 45.29905696069041, 49.952168618479085, 50.65524562712639, 51.99577839143815, 46.30745910829114, 48.365534582445704, 50.451909957393525, 53.11825483076034, 46.29516247780093, 47.437274302205736, 46.43140600573632, 47.83146465978315, 47.39308487984442, 47.56425319179412, 48.84388331444033, 46.18266497888873, 48.321215721868704, 49.75035090600291, 46.789918484226355, 47.7300831579393, 48.87264605491392, 50.38420592584918, 48.88483678140948, 49.47353747583205, 47.080283703342566, 49.09917469947569, 48.22895765304566, 47.568493273950395, 47.10630470706571, 50.481237519171934, 47.81830510785503, 48.97157215302991, 48.37467762731737, 52.93473497513802, 49.90465302621165, 49.55580919019638, 50.293132412818174, 53.67807903597432, 56.74359175466723, 60.68407935480918, 59.07660184368011, 67.29579125681232, 64.81835165331441, 72.48966832314768, 63.42511007862707, 70.39686418348744, 28.791540476583666, 0.04201008607783625, 11.360110678980428, 60.3158825443637, 40.63779854005383, 24.83144102558013, 34.86588570379442, 33.63825836489278, 52.473762343006754, 50.27703500563099, 41.54777665292063, 73.75147911810106, 19.85346886419481, 0.5081105430520351, 0.14830276309963197, 0.2433289680629969, 0.16278265224349114, 0.02914779541653491, 0.06443156440171503, 0.17305417527114192, 0.18135495243533967, 0.11231892381704624, 0.039728852439551585, 0.34609437709854496, 0.2605206399194656, 0.3274836192928976, 0.42157720413900196, 0.3554321002335318, 0.6076204308098363, 0.6202689101619105, 0.4474174723990502, 0.38555011153221136, 0.20992779503426245, 0.3212962642071709, 0.31029993007259987, 4.0621305954071785, 78.48693309291717, 66.73151908382293, 65.41586591351417, 34.28066022934453, 42.059524366932536, 28.38351199703832, 39.57959798074538, 56.34461610547958, 81.65601991838025, 24.606999081950036, 15.941540041277486, 83.5576634253225, 65.44037680472097, 76.8888339688701, 67.61583312865227, 67.21450405736124, 63.51524222281672, 65.45922379339895, 56.20088869525541, 59.81920065418367, 53.935025661222404, 55.91376335390153, 54.38745929348854, 56.887260329338815, 53.63521537473125, 55.341611139235965, 51.746358794550744, 50.620116879863126, 52.10681284627607, 49.520048941335375, 47.738892801346324, 49.88064812075708, 49.81709003448487, 52.15197501644012, 53.698392991096746, 50.103619175572554, 50.8137878294914, 49.39663156386345, 50.54097129452614, 53.1313673142464, 52.693156196225075, 59.384766778638294, 60.5035287334073, 59.5672825074965, 61.72802994328161, 62.90964788006198, 60.8971542696799, 65.2855843882407, 59.01785258323916, 63.31146332525439, 65.48282469472578, 66.3557638660554, 66.87981605529785, 63.8724014835973, 58.342196864466516, 57.19460941130116, 56.32067003557759, 54.497364105716834, 53.25547895123882, 59.41879333988313, 51.29207380356328, 41.65781874810496, 48.01311354483328, 46.10924605400332, 48.228294772486535, 42.58883253220589, 44.57770955178046, 38.44532305194486, 36.705485159350985, 38.62614431688863, 40.14215215559929, 39.75931705967073, 38.307663548377256, 43.253121222219164, 49.47807565812142, 59.68453391905754, 65.27284452992102, 56.531909281207675, 47.344161156685125, 41.753575571121715, 38.05410192858788, 36.06111034270256, 35.86095963754962, 35.349357051234094, 46.63002306415189, 49.696975292698035, 56.651498425391416, 45.227410947122884, 50.8293596390755, 41.61440987740794, 53.07795639960997, 60.26060458152526, 58.14073216530585, 55.60880299537413, 48.822129849464666, 53.53257086969192, 54.415516007331114, 56.186258254512666, 49.673354779520345, 54.169893264770515, 52.76109164760959, 54.051249411798295, 46.81367628036007, 50.72577768756498, 48.04000923710485, 50.03099649183212, 51.46125347383561, 52.032374105145855, 52.529083451917096, 50.490890472166, 55.141346685348026, 52.94767879670667, 51.39311798157231, 52.409564910396455, 54.0720340513414, 52.84002542495728, 54.281892622670824, 52.33363959097093, 48.47580417510002, 51.256901910228116, 51.8051786576548, 52.58702862647272, 50.81204237476472, 54.21221171655963, 51.47629184107627, 53.8837642054404, 52.54266661982383, 56.75203661764822, 52.39067085327641, 53.47633977090159, 53.097352520112075, 56.469708335015085, 59.609330315743726, 61.196944944320194, 62.75596941671064, 70.30281359149565, 69.20771137360605, 75.98556703136813, 65.85661872740715, 77.33065758982013, 41.13491189095282, 0.18137189830022474, 11.039810911301645, 67.88979499570786, 46.695981640969556, 29.47851419448853, 42.74742964775332, 48.28462393053117, 63.334287597287094, 59.58655311215309, 56.33700670734529, 83.92868826466223, 24.78610234875833, 0.5579813041033284, 0.5392830590567281, 0.3797367605711184, 0.33425887025171713, 0.20059878997985395, 0.2753701818085486, 0.2874753209612062, 0.4194050690820141, 0.3188669074687266, 0.17354033466789032], [0.24280945319802533, 0.11303146985629875, 0.24069909547125143, 0.141184595864146, 0.28508414604490806, 0.09766671851637865, 0.11590483583389752, 0.06065437938236903, 0.13573319080375856, 0.2571588316031041, 0.23653542292454552, 0.11429196794427211, 0.4358257653732454, 43.76083673969392, 57.866809521951986, 32.6219153788782, 38.309307021479455, 34.55703043168591, 23.6488111172953, 28.437434780982237, 39.51664786184988, 72.98050588177097, 36.05739585814938, 14.456908222167725, 72.34096342517485, 69.6935518326298, 68.9587506940288, 62.983502188036525, 61.72878303835469, 59.17829713513775, 59.852062271487334, 51.63938399284117, 49.99618937892299, 47.37297881034113, 48.88738632202149, 48.88459751682897, 49.74121962824176, 49.69222138004918, 50.95115315529608, 49.13390336498138, 48.220038183273815, 49.1704833892084, 48.32272191201487, 48.35436759456512, 49.90124056416173, 47.08379030227662, 46.326404156223425, 46.76876906425723, 47.66815677765877, 44.39493886886105, 44.99541844091108, 45.13555296005742, 48.50521018428188, 47.4544229045991, 54.7813593956732, 58.32632303237916, 59.22262384045509, 57.53382382854339, 60.05085191419048, 55.89238251409223, 53.480717136013894, 53.06181192398072, 53.184338923423525, 52.35776608990085, 57.75569269734045, 55.933151629663286, 52.24792403559531, 49.8361135298206, 51.70759008776758, 45.620840364886874, 47.21596240997315, 45.97533633632045, 50.933322060492735, 42.614053372413885, 27.853415435360326, 34.263460636138916, 31.850714645078106, 31.965738150381277, 31.86793188894949, 29.719065312416326, 26.452256556480165, 30.13307344528937, 33.140984196816724, 34.27607105624291, 35.699573716809674, 41.95465195563532, 40.02453596361222, 48.64927884071104, 49.78491090959119, 47.75683372251449, 44.48838933821648, 36.202307824165594, 38.76655340194702, 36.171627044677734, 34.20393474640385, 34.535104382422666, 39.74080739482757, 44.43814377630911, 40.89756927182598, 38.640892428736535, 34.28259788020965, 40.804691468515706, 26.450103175255563, 42.91913140204645, 50.25227308273316, 47.563641302047245, 46.03555256320585, 45.37480577345818, 46.37644575488183, 46.48262431544643, 48.78168236824774, 48.13442460952267, 50.26664072467435, 51.43017261259018, 52.29738512346822, 49.689558090702185, 51.197536837670114, 49.29980785615983, 49.19018545458394, 46.52532323714226, 47.70415236873012, 45.02294563478039, 43.265990518754535, 41.656826388451364, 39.76961720374323, 43.82352405978788, 43.73343113929995, 42.348434386714814, 45.75815862224948, 46.1178203552, 44.88909083027994, 44.41039300733998, 42.07270745308169, 42.6662483522969, 43.93034196669056, 43.367273961344075, 44.987299134654386, 44.87736294346471, 47.61804849870744, 46.953383261157626, 48.12081006265456, 48.98917182799309, 47.77262910719841, 47.57051329458914, 50.943108374072665, 52.06242338303597, 55.51891011576499, 55.26709787307247, 59.404233501803496, 58.191264060235795, 64.72882747650146, 60.090314880494155, 61.52274485557311, 14.171243963703034, 0.22141205056780772, 19.276176383418424, 55.08896735406692, 33.84796004141531, 25.364636259694255, 26.00224106542526, 34.002599485458866, 26.099149104087587, 30.941405296325687, 31.558135247999626, 62.30960369110108, 18.283222490741363, 0.5313889826497724, 0.21935806159050236, 0.12701564648699376, 0.13734937585409612, 0.083932347836033, 0.01911079871558374, 0.09940537038229166, 0.1888564394246186, 0.11650799983932127, 0.20477225313023215, 0.2874207448574805, 0.08700007798090097, 0.10936324169198353, 0.1540643111952851, 0.13269773594314052, 0.028046421451313842, 0.09581154467718256, 0.0961227295920253, 0.23031403821322227, 0.12505263045069673, 0.15077063873890909, 0.22353440523147586, 0.5150225253835802, 53.82098274846231, 61.71678450799758, 37.03936515315887, 37.78458410693754, 36.23508707169564, 27.452884566399362, 31.672235035127212, 43.1467818444775, 73.23768784922939, 41.817204260057025, 15.546090602874758, 72.7430534362793, 72.69281571911228, 72.49758366615542, 65.9651428653348, 66.92400547765916, 64.7847330185675, 62.553771234327755, 53.75844840080508, 54.17707120218585, 49.8430835816168, 52.49395862702401, 50.59786919624575, 51.43731132630379, 53.470856297400694, 53.25489844045332, 50.96508149177798, 51.40242576599122, 49.80046310732442, 49.84273449067147, 52.30085642107072, 52.556485129940896, 50.908842548247314, 51.325147228856245, 49.68913447472357, 50.879840543193204, 49.11739018655593, 48.8369171850143, 47.15605997270154, 50.92730122227823, 49.04083336553266, 57.2199361555038, 59.44772474227413, 57.93528233805011, 59.664043457277366, 63.6803779294414, 62.42971843288791, 59.475067584745354, 59.97073750342093, 57.526559598984264, 56.76491375892394, 62.12762924932665, 60.958492294434585, 55.44708367316954, 53.159894712509654, 53.803508589344645, 48.87103003840293, 53.23939723353232, 50.576562881469734, 56.26277977420438, 45.557372493128625, 29.398244850097168, 38.95036743533227, 35.75827198643839, 37.974685699709006, 35.281535348584576, 33.17419098269555, 32.02569353965021, 32.49500316958274, 35.71191349337178, 35.26834834006525, 36.10218932551723, 39.19629612276631, 37.91026861436906, 42.95030640017602, 43.64572694224697, 42.797808570246545, 37.74027309110088, 30.854314950204667, 33.27278367934689, 35.13785500680247, 33.380841055224025, 37.10526489442395, 40.67737133272233, 48.47427445073282, 46.43924290134061, 43.80035854155018, 43.0528881472926, 44.86768645624961, 32.08101857093073, 46.84556907223117, 54.12365244280908, 51.87418883846652, 48.65677056774017, 47.36254530568277, 48.792821899537124, 50.0861567835654, 49.98132359596991, 48.17262457263086, 50.33546655408798, 49.463888445208156, 51.23973761835406, 51.4278035010061, 50.85821651643323, 50.25636411482289, 50.73777229555192, 48.970587638116655, 50.32401715555499, 47.73904577378304, 44.860669336011334, 43.70709634596302, 46.349424546764745, 48.382506678181315, 47.037247457811915, 46.365321913073146, 50.7138301480201, 50.530886880813114, 48.312335475798584, 47.387817136703006, 46.441482574709006, 45.364686058413604, 46.54982236123855, 43.884822860840835, 47.97295239663894, 46.593329291189875, 52.44911024647375, 50.17159385065879, 50.91056839112313, 53.90486263459729, 53.09401066072526, 51.170543086144235, 54.90016406582248, 57.68566270028391, 61.987137794494636, 59.23927822420674, 65.84553410930019, 62.44299173355103, 70.1370071595715, 63.26643843804637, 67.91861657173403, 13.091629224438822, 0.3577060024103811, 24.94051037296172, 63.42830681031751, 38.24582738261069, 29.641537704775413, 28.107788985775365, 35.81064347297915, 37.59147013387373, 39.131898649277225, 44.41281310973629, 73.57284653571345, 23.713949918746952, 0.4835092534701671, 0.28205478924416727, 0.16907778057840564, 0.33929697087695526, 0.11700484616261338, 0.1152970753009281, 0.11842894998769607, 0.1435323948821714, 0.13624415612749516, 0.28702682244681543, 0.3541279427947537, 0.16738988969835544, 0.3937839632553439, 0.24003918733327623, 0.5549514570063161, 0.20630390803900459, 0.2939647904807522, 0.15387082802912883, 0.30067994950279114, 0.31621970596813387, 0.3168518510797332, 0.3967205008431789, 1.1926013087072682, 66.5468382066296, 76.03096454374253, 46.04585662964852, 49.993675139642534, 50.6447454421751, 29.02893408652275, 34.957473047318, 47.1793157054532, 77.50070802627071, 41.16485134247811, 16.948926295003584, 77.08178320238667, 71.19326222327449, 73.88239998971262, 67.50736390390705, 66.9969537181239, 68.33926723849389, 67.04148046432003, 56.95164211334721, 55.77364844660605, 52.805688996468824, 53.40780027451054, 55.71800962571175, 53.38292068050754, 56.52573547055645, 55.94977071208339, 54.96874278591525, 54.53116316949168, 52.76728114774151, 52.001783540171964, 54.8838823072372, 52.87628773720034, 53.84787451836371, 51.12139971025529, 50.43167052730438, 53.35614265934114, 51.231712448981504, 50.36765744609218, 51.272560011956, 56.04932438942694, 50.96985893864786, 58.344177661403535, 63.47130383214643, 61.74033441851216, 61.59240222746327, 67.00552801932058, 63.099494518772254, 63.49370448820053, 66.55241581701463, 63.87793202554027, 63.628347689105624, 71.09353203927317, 66.38683688256049, 59.54464258686189, 55.8825962005123, 56.15482045758156, 50.926689332531346, 56.88638956316056, 54.17686331656672, 60.81715753001552, 50.23929788220314, 38.475607672045314, 43.77847563835883, 41.670962610552394, 44.33943733092278, 41.117096485630164, 39.3559758124813, 36.88006985572077, 36.6001969768155, 38.07580440275131, 37.60507291363132, 40.185043273433564, 43.192897150593424, 42.60948773353331, 46.618695259094245, 45.00743266074888, 42.79910295240341, 42.973130672208725, 35.545785427093506, 37.091516986969985, 37.62480243559807, 38.00275810303227, 41.55657060684697, 45.884321658842026, 52.84204544559602, 52.18826870764456, 52.929859469013834, 48.639308175733014, 51.39712664388841, 38.629717596115604, 52.96831046381305, 62.55980776202295, 56.29146406727453, 54.00968405508227, 50.10868687783518, 53.24405700929704, 50.660693799295736, 54.235898910030244, 51.890552966825425, 53.724319857935754, 53.149504353923184, 52.74668478196668, 50.51943355990995, 51.85060362662039, 50.17522204306818, 52.6664880014235, 50.62169759504257, 55.80667088108679, 52.96998531587663, 49.33687033191804, 47.70262656673309, 48.61483258585776, 53.627190205358694, 53.34284190208682, 48.66114793285247, 54.276970048104566, 51.90959607401202, 50.18607916370515, 52.60758184617566, 49.552267289930775, 48.30215692520142, 50.857855658377375, 47.017604227988954, 51.33618085615097, 50.286374169011275, 56.74111281671832, 53.447337765847486, 53.895252827675115, 55.5686261576991, 54.87894012082008, 54.12656284147694, 59.040398366989635, 60.524662463895744, 66.1813517539732, 63.593203252361675, 68.85214851748559, 63.9458792440353, 72.22446118631672, 65.66119055594167, 70.81579685211182, 17.540560922315045, 0.4494667269529835, 23.917905322967037, 71.81265154192525, 44.85705683308263, 31.65510996695488, 33.239572971097886, 49.83139099613313, 41.33350541514736, 43.200224138075306, 45.317527401831846, 84.12103345317226, 32.57695128840785, 0.7376799131593397, 0.5532440615277137, 0.2655373820133748, 0.43151106625314684, 0.18252795562148097, 0.1840048965307013, 0.1775505904468798, 0.37684189816636426, 0.29245204262195096, 0.5027961604777844], [0.16154065517888916, 0.04928119510652558, 0.06766309180567343, 0.058369261678308255, 0.07201077101091224, 0.09245715975280731, 0.04742864128803054, 0.04611733241847927, 0.04211869819330112, 0.0676314293917629, 0.14904262017338507, 0.058154688111596534, 0.461746626082928, 37.549971457450624, 52.195403498988, 38.350629191244806, 46.310789200567434, 43.196031124361106, 24.215711278300134, 30.816179706204323, 37.386538059480735, 65.11441215392082, 53.58394215183874, 10.91916076598629, 54.71181577251804, 71.7931495174285, 69.71909430719191, 65.06878714407644, 62.61361483604678, 53.61892577140562, 56.32947967898462, 51.06294462757727, 48.12989427197365, 50.21569305850614, 50.764562083828835, 48.803518202997026, 52.76393144361435, 51.55639448473531, 49.02292382332587, 48.01502766147737, 47.77190346871653, 47.39542261246712, 47.32290191035117, 46.13272928422498, 45.8206106001331, 47.80588688388948, 48.15505235425888, 47.31487674097861, 46.676922844302275, 46.83312731404459, 43.76024053942773, 47.28389001661732, 48.42546055393834, 47.85723855418544, 52.407850834631155, 58.618480774664114, 57.77230785739038, 60.083235002333126, 59.00280637125815, 55.709678511465754, 51.70425607312111, 47.029186987107806, 50.17611634346747, 49.42223679634833, 48.020154199292584, 52.74026778436477, 55.92315743046423, 53.26532017800116, 50.769802370379054, 47.642531933323035, 45.31853937333631, 47.321140766143806, 47.73416242291851, 45.31828834164528, 23.999127803310273, 35.514535903930664, 32.82970882231189, 36.92981335424608, 31.870412788083478, 30.232758522033695, 29.02751418852037, 29.22204805958656, 31.596537213171686, 34.38001386580929, 38.77495119648595, 41.24917837881273, 37.72045727699034, 37.35583374577184, 32.265420959841826, 18.642584162373698, 19.81935404962109, 24.696895883929347, 37.2996340259429, 34.33021937647174, 32.99473078020158, 33.874898879758774, 40.16838496731174, 44.58342836749169, 42.40661490348078, 42.55728098653978, 39.136279936759706, 37.683998846238666, 28.240641624696796, 42.61618714178763, 47.06207998337285, 44.88941638700424, 45.007997482053696, 44.41553523463588, 46.59589452128257, 46.7062190271193, 50.29699594743791, 47.03018326913157, 51.186440452452636, 46.885942028414824, 44.63458391927904, 48.858945215902025, 47.362470780649495, 47.17023934087446, 47.98853597333355, 48.69557849822506, 46.059714363467315, 44.914119474349484, 43.53994846343995, 43.17812158215431, 42.5972617057062, 42.74305228264102, 44.57424217654813, 44.564663748587336, 44.36635263504521, 44.526408872296734, 44.374244443831905, 44.22852054719002, 46.0365645347103, 43.12389481452204, 44.85368359473444, 44.742429487166866, 46.35237024676415, 45.538474513638405, 48.208416200453236, 47.29120915935886, 49.6102556105583, 50.21109604066419, 48.60957268745669, 45.0915478890942, 50.99612312932169, 55.088025985225556, 55.091501205198234, 54.867600548651914, 59.68458883223995, 59.891976310360825, 62.92698083385345, 59.94620307799309, 56.29246819403864, 5.795580908175438, 0.23471688340988853, 39.38478169902679, 52.35732286207138, 38.73000083431121, 22.53329884621405, 27.306240873952067, 29.90705470885, 33.904634368035104, 39.15376194061772, 46.80171697370468, 58.9857126820472, 12.752997279167177, 0.31772706056794814, 0.09063521114688727, 0.11625487672825975, 0.14218725173944427, 0.1024340606865383, 0.1360672817475373, 0.0334964896882734, 0.12172695084084427, 0.10080899667715836, 0.037895558071472955, 0.10760874712779638, 0.06294594371631261, 0.00599507084717193, 0.12123668521282174, 0.08834823184917051, 0.13786699082101547, 0.02970503053567823, 0.036268000445899465, 0.005110717620775705, 0.0735669483941409, 0.09869407306635573, 0.07320628952114813, 0.45147409181921716, 47.3661538862413, 57.50103281390283, 44.82341858648485, 44.083149663863644, 44.67657681434385, 28.14240194136097, 33.796733886964866, 43.87498163407849, 69.10714964712821, 60.575488536588615, 13.550623020818158, 55.125625825697384, 75.28096814309397, 72.65985212018414, 68.39404706032046, 66.44304444712978, 57.49065814479705, 58.13392293068671, 53.96595355003111, 53.559799963428134, 54.94465551068706, 54.229085753040934, 56.510673569094756, 56.88329089072443, 55.718841168188284, 53.27173717560307, 50.726993622318396, 52.78593594028104, 51.66800945035873, 51.58496895144063, 51.10872653222854, 51.45593081751178, 51.63217075409428, 50.05445618783274, 50.41170174075712, 48.788079753998794, 48.954023468878965, 47.39282208104288, 48.659343642573205, 50.063006954808394, 50.84597087675526, 53.16808854379962, 61.57364545329925, 60.003708947089414, 63.96610690701393, 61.418943251332934, 56.341203643429665, 53.09042953675794, 51.13758733195644, 50.86612401470062, 50.61940693086194, 49.0075755888416, 52.96069714330858, 55.92745242580291, 55.84480808627222, 52.77860110805881, 50.34311125355382, 50.26731929471416, 50.11364083136282, 51.59757152680428, 50.67438287119712, 29.554635632422666, 38.29525709152222, 38.4884181330281, 40.31597591215565, 35.517936598870065, 32.082363943899836, 31.131073467193115, 29.76823614489648, 31.74224149796271, 32.840295299406975, 36.37029509390555, 37.608108828144694, 40.433419519855136, 43.37632286933161, 38.883694987143244, 28.059592862283033, 26.996956102309692, 29.83173147324593, 37.07612952878399, 33.22023568614837, 35.4257373655996, 38.548042082017474, 44.77525580313898, 49.149506553526855, 46.52077328774237, 46.51546632089923, 40.863436806586485, 41.938507480006066, 32.56939876464106, 46.16964663228681, 51.11170361118933, 47.52915582349224, 47.86034114899174, 46.710086484109205, 51.42533240779754, 52.49395862702401, 54.6809349521514, 50.623807830195275, 54.43078187204177, 48.88538983560378, 50.81427812576295, 50.718121220988614, 52.11059008875201, 52.150735547465665, 50.683549450289824, 50.57596275883336, 48.03556519169962, 47.6816693429024, 48.36278107858474, 47.97524698318974, 48.09851138822494, 45.64613573012814, 46.015697525393584, 48.035694629915305, 47.530571799124445, 46.35669662106422, 48.22205820391255, 47.11919361545194, 49.006689133182654, 45.33595861927156, 45.658832442375925, 46.5845274925232, 49.4366083606597, 48.77925834348125, 52.47179331318025, 52.46459184154388, 54.526299430478005, 54.19061906876103, 53.68724169269685, 51.36781869396087, 55.66395544236707, 59.66696170068557, 62.76686968341951, 57.87021806163173, 64.79062441856631, 64.73405991831135, 68.5955156818513, 63.656569142495435, 60.60208220635692, 4.5230360569492465, 0.35886245809735795, 46.12655939594392, 57.51222725837462, 41.11674347231465, 28.087757441305346, 32.60653772661763, 35.88604711717175, 35.43786533417241, 36.93369650071667, 56.29911661148072, 68.67954069568266, 20.973919399323005, 0.4695228475236124, 0.18765947300820582, 0.10558977602950989, 0.14978986233472824, 0.23458644927990055, 0.18846191946537266, 0.02465122127755275, 0.016295117243463476, 0.035960174826604706, 0.025289765138539578, 0.20840813706238426, 0.19739684889153128, 0.12856067729092416, 0.18923962128258523, 0.25635079270409, 0.256970971522312, 0.18482025923027148, 0.19386526016939074, 0.1544770946906459, 0.20225350925278282, 0.29090322734367463, 0.31983637641514506, 0.683934003595383, 55.8378537239567, 71.9874558910247, 55.64161362186555, 62.41448786950881, 59.83190128880163, 31.983610430071433, 37.99281097227527, 49.83068104713194, 74.96610379988148, 62.090327508987926, 14.617865623966342, 60.94056314037692, 77.28806064974877, 74.76453319672616, 70.06907170818698, 68.50504229145666, 59.764201179627456, 61.46616074346728, 57.20640790077948, 56.14809751510621, 57.7820667143791, 57.17355412821616, 54.63570217932425, 59.78973188707906, 58.22534161229288, 54.85773578766854, 54.92663221974527, 55.18582244073191, 53.3216061899739, 54.05089639848279, 53.02765200215002, 55.099432237686656, 55.102181819177446, 51.40176288543209, 53.01883059163248, 50.676096946962424, 52.19142621563327, 50.45271404327885, 53.06297294555172, 53.643573945568455, 52.52223107122606, 55.96965320648686, 67.01414938895934, 63.14335446203909, 66.0938907438709, 64.65562428197553, 60.724460155733176, 58.43128173582016, 56.04690428703062, 55.15059563421435, 53.832267407448064, 55.0472294130633, 58.04154719075849, 59.14741239240093, 59.90924650622953, 57.26075233951692, 53.59559551362069, 53.44696906305129, 53.1825424778846, 55.01574062531995, 55.6617824492916, 35.52761308608517, 44.11759199634675, 44.032049025258715, 47.173043835547666, 41.3735959606786, 37.21456566164571, 33.99337014844341, 34.85076104440997, 36.04031393604894, 36.454535838096376, 40.840867488614975, 44.12176932058027, 42.25523887142059, 48.86746068154612, 45.19903259892618, 32.48788995127524, 33.85986835725846, 37.16853664767358, 46.93216716089557, 39.25472374885313, 42.114363024311686, 44.67920872472948, 50.03899812698365, 56.13431430632069, 53.711501552212624, 53.90565103100192, 48.059354366794715, 47.18297527682397, 36.79195773216986, 49.555934706041896, 56.44657811810894, 51.80030707390078, 52.46359163714994, 50.35069319509691, 55.65015654410086, 55.63209010708717, 55.63842081254529, 53.077050332100164, 55.679903799487704, 50.09801410859632, 53.02724799802227, 56.20065727541524, 55.318143598495, 53.8341893688325, 54.6412484107479, 54.03898808263964, 51.201117961637436, 51.70238118017874, 51.0823642823004, 51.371270379712506, 51.56132490404191, 50.76287154228457, 49.90680640743625, 52.375726622919885, 50.13239760552683, 51.50170879979288, 51.095108062990256, 49.84978691224129, 52.03769676146969, 49.498122892072125, 50.51462473407869, 49.27361819051927, 52.44233631318616, 51.698745143029, 54.331290952620975, 53.47052289593605, 57.56508119644658, 59.52642317741149, 57.15498955019059, 53.837613597992934, 59.35327014615459, 64.02227132551133, 67.60568203464632, 62.86017110270839, 69.1712333310035, 70.35309837710473, 74.27409571986045, 68.49350267840971, 68.67652047064998, 7.223310412899141, 0.3167667233895871, 45.77264393529585, 63.650489468728345, 48.34874683810819, 27.556305700732818, 37.63765604265275, 46.27930041282408, 52.77997393761912, 54.3008533600838, 58.52070000863845, 80.63931019075456, 26.63440554372726, 0.5146017898955654, 0.417156447806666, 0.1782953504833483, 0.29494832480146044, 0.26463768835509976, 0.3557389644124816, 0.13188222002598549, 0.16963918513107687, 0.13308965120344393, 0.14284616396311792], [0.030420585385253354, 0.007149550027304119, 0.07188314076272712, 0.031683906507227695, 0.0484096207055113, 0.04174801889025877, 0.10380052405619815, 0.09601632764022197, 0.07095243586527725, 0.07427330444296522, 0.0177942861938068, 0.046368965488528056, 1.4982106969241173, 45.15785555685721, 56.586524363487, 32.55199520818649, 39.93151303260557, 49.69104466899749, 24.13252172931548, 26.375415363619407, 33.05733180815174, 52.508012479351414, 68.98371265780541, 20.34298654525511, 35.08657786153978, 77.74410678494361, 68.88245274943691, 71.62502104236235, 61.44237549074235, 59.96832916813513, 52.3967936731154, 56.07990710966049, 49.640481395106164, 53.42650213549214, 55.19769545524351, 58.340341583375015, 53.03866993996405, 52.13301820139731, 49.76411842530774, 51.57662607008412, 46.69287512379308, 47.484523173301454, 46.53974971463604, 49.362051948424316, 46.98393852479997, 47.67749986340923, 46.52707261423911, 48.237669237198375, 47.225744801182906, 47.51362715998004, 44.579815864562995, 44.65451348212458, 47.707537374188824, 47.191765308380134, 48.15611531657558, 53.85318540757703, 56.17081588314426, 57.53571441096645, 55.59587094091601, 51.578128337860115, 50.937083613487985, 50.76165952990132, 46.89459085464478, 48.38831178603634, 46.75471913429999, 50.54470931330035, 46.91687776196388, 50.63414327559933, 50.31790610282652, 47.669827707352184, 42.49238929440899, 47.97099513392295, 47.77023253902313, 46.22101006969329, 24.2305790224383, 33.67141415995936, 34.01098943525745, 32.92498319379745, 33.63097844585296, 31.8089472862982, 29.312137057704312, 34.90667835358651, 36.048429319935465, 29.436474230981645, 28.91194743494834, 22.164527408538326, 19.749402499968006, 9.432018629966244, 2.3484014695690525, 8.1290013751676, 13.433725603165167, 17.45249782839129, 28.509537750674834, 24.254944785948723, 25.35748774005521, 29.35487324191678, 39.87569378268334, 40.69618302006876, 39.927833849383944, 38.15149045759632, 33.65450089977634, 36.81395830646638, 28.95688799119765, 44.38245004223239, 50.395392525580625, 46.0758823733176, 43.946600191054806, 44.82688988408735, 48.24989526502548, 49.74347499109084, 50.47428707922659, 50.30110659137849, 47.22204600611041, 44.48181152343751, 45.612673990188114, 47.105261356599875, 47.85464586750154, 47.14941155525946, 48.43134410919682, 45.76419907231485, 44.67917342339793, 46.1082850733111, 48.43752968695856, 43.5423489539854, 42.909074444924634, 43.50734180019748, 43.278844125809215, 42.54367820678219, 44.1169330381578, 42.47999068229429, 42.943230444385165, 42.938507910697695, 43.7870656290362, 42.84698724746705, 45.013398585780976, 44.894519390598425, 47.99168563658192, 47.866295306913315, 48.00719468824325, 48.87704303187709, 50.990890687511815, 46.33664546474334, 50.59750441581973, 47.27299759464879, 55.30032034843199, 57.04164481932118, 58.50471242781609, 57.282725457222234, 59.629938448629076, 59.96763098624445, 61.873075269883685, 52.82921145039221, 44.43912829122236, 1.6888565185569948, 3.0681600734110805, 54.57983978333012, 48.33838001374276, 33.99315441808393, 20.414567839714792, 26.76065879483377, 28.523260162722682, 33.49381316092707, 43.58218846782562, 31.831289106799712, 56.72026934162263, 26.825524991558446, 0.16254577785730362, 0.19889482657515234, 0.04892625507988757, 0.09350225689911074, 0.06099386358513467, 0.06520449349115934, 0.03331080146674668, 0.156812988702328, 0.12124877408026688, 0.036794682063402674, 0.042239387684892264, 0.03967761264873609, 0.031033107154672186, 0.08093924997674842, 0.05240708664660493, 0.0980343028242069, 0.11910365894436838, 0.02372413039988568, 0.04343507090403188, 0.037457681366152344, 0.08948132185445679, 0.10979168402451663, 2.027540435233424, 58.72724025480209, 63.292784998493815, 38.68730975735573, 47.815073074833045, 53.217624156705796, 23.960892538870535, 37.956485902109456, 45.069304127847, 55.80446258667977, 75.75526898907077, 25.918574948464673, 34.64147906149588, 79.89426382126348, 72.62220521127024, 73.95492461419875, 65.3728885035361, 63.34593703669887, 55.42858969780707, 58.87823973932574, 54.33010639682893, 58.44316651744228, 59.86085622541366, 61.41308323029549, 55.439737073836795, 54.29985315568986, 54.845721567830736, 54.606790388784106, 48.86933557448849, 51.57055816342754, 50.85709864093412, 52.932656118946696, 49.98326909157538, 49.224302230342744, 49.53650720657841, 49.566152480340776, 50.61015798199562, 49.531867042664565, 47.05300754116428, 45.99563852433236, 48.54998011742869, 49.24960151795418, 50.26789980549967, 58.610334011816214, 58.98477915794619, 58.950474108419115, 56.08958359687559, 54.94468296727827, 51.11430806498374, 52.02365075388263, 49.45238413349275, 51.495982139341294, 51.2008394733552, 50.810736225497344, 49.698614843430065, 51.96546631474649, 52.49762212076495, 51.232387096651145, 47.46795508169359, 53.748654242484804, 51.94192424897225, 50.75955713948896, 30.53285121917725, 37.36072101900655, 37.49553680419922, 37.74219897485549, 39.51114477649812, 38.45008088696388, 35.166402016916585, 37.745383939435406, 38.88366360818186, 33.2831387366018, 34.73088556720365, 34.28744592974263, 26.932054604253462, 22.836786354741744, 18.097208007689446, 24.9469744390057, 27.640236577680035, 34.102345358940866, 45.28154357787102, 33.38864657186693, 35.69162307247039, 37.342595746440274, 46.84141135984852, 45.26351636455905, 45.21151750318466, 42.651970924869666, 38.203477551860196, 42.03710802139775, 33.38234724537019, 48.55582052661527, 53.215855167758086, 49.54241821842809, 47.54399022748394, 48.96495511454921, 52.34259043970416, 53.64060471134802, 54.50575405551542, 51.73485056046517, 49.694374761273785, 48.342196479920425, 49.454368852799945, 50.41231755287417, 50.26338515743133, 52.35769156486758, 52.35054108404344, 47.760999279637495, 48.58086878253568, 49.4347373900875, 51.50055562296222, 46.43097454501737, 45.67046226993684, 47.35522224057106, 47.06743794102823, 46.67530682779128, 49.28130995842719, 45.59835341668899, 44.762378661863266, 45.93982711915047, 45.78631339534637, 44.72409240661129, 48.48726141837336, 47.383526063734486, 52.036582808340754, 53.40756100993003, 53.82617596657046, 54.1002005915488, 54.682915749088416, 51.128467821305804, 52.16044341364215, 49.39900852018788, 58.981103897094734, 59.29756464496736, 60.50907496483096, 58.75629717303861, 63.70410826898391, 64.00990016998784, 67.87966743592294, 59.93709533445297, 51.129644532357496, 1.441125624602841, 5.31093284968407, 64.31086755567982, 55.023149982575454, 40.66697312939552, 22.080380801231634, 22.812842246024843, 31.380391082456036, 32.690243067279944, 35.13148507764263, 38.23967318381033, 65.66581110800466, 38.841937434288766, 0.30640446490818457, 0.07198074036428044, 0.08333991672242842, 0.029677271339741927, 0.05984847403822407, 0.06300694729772306, 0.1060934941614828, 0.04670051302039816, 0.07249088597393806, 0.03801609817591887, 0.1857720775109145, 0.06151519024804716, 0.15240338661016958, 0.19715807460729154, 0.13146497789890538, 0.15796668647277742, 0.24906204833138376, 0.1610262731030103, 0.17669421139984362, 0.301443494015163, 0.17823112167177663, 0.3316505860176779, 3.282696071170992, 67.90108357706379, 72.63036374122866, 45.74232793623402, 54.65871472512522, 71.0883858896071, 34.69141475615963, 36.53753319094258, 48.29943480030183, 63.89993259983679, 80.48322339211741, 26.186978816986088, 39.86090252476354, 82.75446399565666, 74.28764358643564, 75.82774654511483, 65.72846704913725, 65.887527004365, 57.51949541030392, 64.33008716952416, 55.551097085399014, 60.347343875515854, 58.92279001974291, 63.890330637654955, 58.24324330975933, 57.02620244795277, 56.52173857535086, 59.17999159905219, 51.42479112071376, 54.12201681444722, 54.5957685285999, 57.79655987216581, 53.01191153064851, 53.08712690107284, 52.463760299067346, 51.75634514900946, 50.57078523020591, 53.26669300756147, 50.21626964692147, 49.66871069323633, 51.76952431278845, 51.08270552850539, 54.178879414835286, 61.32650083111179, 61.273584135117076, 61.11530080918343, 61.15463041490125, 57.86619370983493, 54.29404412546466, 55.26445027320616, 51.59106431468841, 53.05404563103953, 49.97022721075243, 53.623911103894635, 51.44187696518437, 55.62194685782156, 55.09132862091065, 54.37944981359667, 50.39666337351645, 56.66630537279191, 56.89122584558303, 55.521765601250436, 36.52285960412795, 43.59787010377453, 42.15921532723212, 44.977795231726866, 44.02464359037338, 45.038501754883804, 41.64988379324637, 43.94427422554263, 41.59159737248575, 35.682040722139426, 37.40726386347125, 34.35510681521508, 31.488226844418435, 22.758244814411288, 14.063070877905815, 33.953624771487334, 39.90354261090679, 42.76622172324888, 50.43533402104532, 35.49521823083201, 35.30355553473196, 37.94791944565312, 48.29731672040878, 51.152927721700365, 49.2766462602923, 47.9429344977102, 44.34836856780514, 46.00454230462351, 38.46959075620098, 51.30505292646347, 56.780913106856815, 53.956708523534964, 51.331532847496774, 51.61666954717329, 56.07760860073952, 58.05386735546974, 57.549913390990234, 57.38281649927939, 55.41534777610533, 51.3259473923714, 50.405092547016764, 54.14415859406995, 52.82925851883427, 53.80036677083662, 57.13110623821136, 50.72386749329106, 50.06913369701755, 52.25821633492747, 55.89566553792646, 49.94552412340718, 49.09869617031467, 51.21376760544316, 51.51893192721952, 49.54348510311496, 53.70430400294643, 48.96810085542741, 48.141861423369384, 49.10373249361592, 50.19153125824467, 46.765599789157996, 52.60771912913169, 51.97753937013688, 54.20051128633561, 55.01112791799731, 56.012579625652684, 55.75651553369338, 59.11005966124996, 54.70851313683295, 57.80240420372256, 52.64210654843239, 64.19408682853945, 64.91854075462588, 64.8506288374624, 64.73434625133392, 69.25839624097271, 67.21233890902612, 72.73555386450984, 63.80291669599472, 59.12627081717215, 2.2642075486721533, 3.7539100118221778, 65.17221612315025, 60.890478395646625, 44.86858860138924, 24.760046043703635, 36.15198773722495, 41.62129755943052, 56.729785011660674, 63.00019971786007, 45.489935182756, 76.99103524607997, 45.61690622760404, 0.30369836656797317, 0.29259836541548856, 0.22422175463889876, 0.14730376912461174, 0.10874765174042796, 0.2327340027137149, 0.18962493286498133, 0.1505001943798796, 0.2240217750471446, 0.1474008171428596], [0.04387223131714329, 0.09724070468256552, 0.11764166441055075, 0.06143734039318177, 0.029582500517849, 0.06151443182100212, 0.022970820822182204, 0.019047412600728775, 0.04723416603801232, 0.0279451503733834, 0.02420767552159246, 0.12069363612681629, 1.0326430081359803, 48.93975388619208, 53.08012154794509, 33.67070421095818, 39.44790832458004, 49.09635059295162, 31.66965215436874, 17.672209393593576, 22.684463070284938, 45.56768048194147, 68.21521051468389, 36.186775238283225, 20.283595977290986, 66.06955635932185, 70.7968988726216, 67.38602930499663, 62.79745240365306, 58.88763773825861, 55.17936621942828, 51.68126706154116, 54.70729720207953, 62.52131362115184, 59.62115626181326, 58.79781938368275, 55.81373114739695, 54.224782912961906, 50.38479035900485, 50.83021079340289, 49.03509493797056, 49.41423123882663, 47.55203893107753, 48.43931828775714, 46.57522363047446, 48.85053565425258, 46.12489631099086, 46.88313753374162, 47.367565939503336, 44.18632368887625, 46.068539696355025, 43.598591819886245, 48.27672427700412, 48.73729290500764, 48.38750377778084, 51.50495259992538, 57.08669324075022, 55.944220558289565, 53.75494180187103, 52.12195319514121, 50.89166256689256, 50.2972234449079, 53.22282129718412, 54.60483704843829, 54.64658675655242, 54.383760498416045, 49.40188753989435, 51.46578381138464, 46.923628161030436, 46.26925914518295, 44.92793798446656, 48.0122741576164, 46.41616367524671, 47.099573919850016, 26.191299307730894, 31.804477745486846, 31.10254606892986, 32.944465606443345, 33.476884211263354, 29.611264851785478, 28.917901592869914, 16.631433963775635, 14.074796803535955, 6.371856514484652, 1.419252037040649, 1.1098461622192015, 0.922631924190829, 0.7694668010357888, 0.7038244040262315, 1.0983260384490414, 2.2166488103328215, 4.333672850362716, 2.538577097077524, 1.5591903151043, 5.316476139330096, 24.97616275664299, 39.227329915569676, 38.59085867481847, 38.80980537783715, 32.17897976598432, 31.432015357478974, 37.073301499889745, 30.123789195091497, 47.87482253966793, 48.3777762997535, 48.07006243736514, 45.11256394847747, 43.96958920263475, 46.976666450500495, 45.38193272006127, 47.55609466183571, 48.14794501950664, 49.12783938069498, 49.54746238646969, 48.50057786510837, 46.75427198410035, 47.940741892783876, 47.573984592191636, 48.387856791096354, 47.82212157403269, 47.358156173459946, 45.980894334854625, 45.916073245386926, 44.12892372377458, 44.19870268914008, 44.14414644241334, 44.858684616704146, 43.65267345982213, 43.99940313831453, 41.84140920639038, 43.05391973064792, 44.18240524107411, 44.17473308501705, 44.16453100019886, 45.62855174464565, 42.85002316198042, 48.288126607095045, 49.6194653357229, 49.06969808763074, 51.845390796661384, 51.960135813682314, 48.137013373836396, 50.4491368416817, 48.66072431687386, 52.50127384739538, 56.1981548032453, 55.38842070487238, 54.98422438098539, 59.189974031140736, 60.23479146342124, 62.92416064969955, 53.160749789207216, 35.16275813502651, 0.2586913445303517, 11.431809644545279, 61.713980013324374, 45.06908447511735, 30.977134166225312, 22.022308149645408, 45.11403483729209, 28.93505019526328, 84.29302154048797, 80.17529379936957, 40.45016804049092, 56.46986522982198, 28.688439015419256, 0.20171353984023296, 0.052415735779270056, 0.03307514132991914, 0.051648632788489905, 0.04590783418426591, 0.05624561998692732, 0.06395859703902276, 0.05692554600236397, 0.027913857596896352, 0.006728016850238125, 0.04519810734857475, 0.08778859695960438, 0.07016976979831535, 0.019736299929659695, 0.08390323649491034, 0.11088018005173053, 0.019800605350023797, 0.02057155218696402, 0.01899990365810452, 0.028782043974065495, 0.08814566288023226, 0.03840484949309499, 1.7190694328277343, 58.4014089645878, 61.00125397405317, 41.685275339311175, 44.55705435045304, 57.22293284631545, 30.03442583545562, 25.93336816756956, 32.64880322640942, 49.47809526997228, 73.41064868434783, 42.08114447132234, 20.534706115722656, 64.16984265850436, 73.89800317825811, 70.0529036983367, 66.40772742609825, 61.087412757258264, 57.940173533654985, 55.190713636336795, 60.20250251216274, 68.4012956003989, 66.3211214926935, 63.42835780112975, 59.64720079975744, 56.19992379219302, 54.505636384410245, 54.86953819951704, 52.96263871654388, 51.27696875602969, 50.77911407716813, 53.09541486924695, 51.257451042052246, 51.13486128468668, 47.18451676830169, 50.86707715065249, 48.647717737382465, 47.269655735261985, 48.48382934447258, 46.77722961671891, 48.26551414305165, 52.0973442446801, 50.880546569824226, 53.18591179386262, 57.78126262849378, 57.296057593437936, 56.0101830574774, 53.32481076640468, 51.8805116991843, 52.87581705277967, 56.55210556522493, 58.53514609798309, 57.116989627961196, 57.007226021059104, 54.013598580514234, 54.813150205919825, 50.15443740352508, 51.26099294231784, 49.122179400536325, 51.04965563743345, 52.57337093353272, 54.11073215546147, 32.304895693256015, 35.76233948430708, 34.92701192055979, 39.510156339214696, 39.10193174116073, 38.40493440628052, 36.41750474129954, 25.33902514365412, 23.335623587331465, 14.543748517190258, 9.706091303979198, 5.4016582523622825, 4.870045694612688, 2.0320624377458327, 1.6809752511401332, 4.702917914236746, 7.786454414167713, 9.884959228577154, 9.125724665580258, 4.621746915002023, 11.40649466745315, 33.13787375727008, 46.341277783916844, 45.76405786698865, 44.844034564110544, 38.17056102137412, 37.53505860605548, 39.70853413304975, 35.677628055695564, 51.544364575416814, 52.368929155411266, 49.74721693223523, 50.343872193367254, 49.385358671988214, 49.7111625056113, 49.109733719979566, 50.224028095122314, 50.56469771169847, 52.03353512671686, 53.94968748092652, 51.99686881034605, 50.654523911014685, 53.52775027675014, 49.76812316525368, 50.99195364982852, 49.71249611146989, 51.28249145323231, 50.24078053812827, 49.08435598496468, 47.69488380801293, 47.17478929027435, 46.311161825733805, 47.26702774724653, 45.464718264918176, 46.75869641765472, 45.40309390714092, 47.38452626812843, 48.25988554185437, 46.527457006516, 46.92454599565076, 50.23901547155073, 48.178108046131754, 52.76432368063158, 53.300809783320275, 54.52096500704366, 54.33882190335182, 56.35619101985809, 52.32034667845696, 54.5608005985137, 52.637278110750266, 56.838466044395204, 58.03823278796289, 58.9154238085593, 60.79503928461383, 63.389145866517104, 64.00613077225225, 68.71738372310516, 64.08411533601823, 40.032827854156494, 0.14557676179514778, 16.450128286115586, 67.41292891963836, 48.628890360555346, 36.22317091111214, 22.85533328210154, 40.78917457211403, 35.80661912118235, 101.21708393096925, 85.90480973643642, 49.15609613541634, 66.17331873986029, 37.63069775796706, 0.18282089232196733, 0.050729698831996614, 0.012816542763293031, 0.05013799167148048, 0.03906908602784238, 0.02208534384056205, 0.03637430280627262, 0.06774457291729989, 0.03970962746309177, 0.05771335634973742, 0.12529138941317797, 0.12982340469475717, 0.15235903011935373, 0.12142603916506614, 0.11682283899356281, 0.16275813742991418, 0.1057618240555448, 0.13582294566496728, 0.2761617038519152, 0.1465327475940989, 0.2298388338737911, 0.26595554344596406, 2.4495410102029003, 70.79753429658952, 70.58585966787031, 45.2669955069019, 51.60809132360643, 70.3649204008041, 42.134029788355676, 23.501916393156975, 31.586050756516, 60.958547207616995, 77.6736217929471, 43.2592793433897, 23.66172944345782, 70.11493990498205, 75.80760125190982, 72.11619592482045, 67.55666809697306, 65.34209005294308, 62.63790215215376, 59.19021329572124, 60.06232092457434, 70.40575227429791, 69.07904978721373, 64.95181814316781, 60.95486410202519, 60.36248814675116, 56.91060235423427, 57.52110750444474, 56.47931814193726, 54.799943585549634, 52.15323409726543, 55.861391867360766, 54.54833922847625, 55.349134245226466, 49.39465861166678, 52.69546647225657, 51.7461391418211, 48.77801102976645, 50.56208149079354, 48.22645125850555, 53.472993989144605, 55.13360784899805, 53.18981847455425, 55.315511688109375, 61.652077167264885, 60.42861146311606, 58.7831340297576, 57.277249828461684, 55.6462537857794, 56.264023165549006, 56.62414381580969, 61.59374760043237, 58.7144023372281, 59.84932053473688, 54.68000142805038, 57.58905472293977, 53.58506394970802, 53.47878340751895, 52.162306539474, 55.57907142946797, 58.27351224037909, 58.988858422925404, 38.92682536955803, 41.33869078851516, 40.211566340538766, 48.378427413202104, 46.47301843089443, 45.27158468000351, 42.6019803170235, 28.69997274491095, 21.339890264695693, 11.828627009545604, 5.442484732597105, 2.0693961699162764, 1.9371076168552523, 1.2681821950020329, 1.056374695993239, 2.5278290673609707, 7.0683027563556555, 10.458535263615271, 5.609987099324504, 2.0207524059280275, 8.578955088892291, 30.768646463271114, 46.59549051715482, 48.61797440436579, 51.48306577436386, 44.98076838831748, 44.749093594089636, 46.17363960512223, 41.71976474023635, 55.34519226320329, 54.142777919769294, 54.5859351465779, 53.08784861718455, 53.25109374138617, 54.09477595360049, 51.90872138546359, 54.31457381094656, 55.14010721637357, 53.09572081412039, 56.40829186285696, 54.09063393069852, 53.145864394403276, 56.34597716792938, 52.85558938980103, 53.25727147440757, 52.90572904771375, 53.33527957239459, 53.64175004343833, 52.18792746143957, 50.026568135907574, 49.82488770638743, 49.86706103048017, 50.38742226939048, 51.008627645431034, 49.49665200325751, 48.169741630554206, 50.36838700694423, 51.09988158748996, 50.3447586490262, 50.822770057186005, 53.573759678871404, 52.08961325307047, 56.58996035975795, 57.79038998388476, 55.6981388984188, 58.053718305403194, 58.78892344813193, 54.092575503933816, 56.99612571347145, 55.46812718914401, 58.7830634270945, 61.60613052306637, 62.530774378007465, 64.47335566243818, 66.09871525918284, 67.89654147240424, 75.24212098890736, 69.08052459839853, 48.02118970501808, 0.23867495327947602, 14.954204943872268, 70.07869720458984, 57.800686205587084, 40.267263996985655, 28.22054143874876, 58.83120267621933, 47.17264767616026, 101.65001161636846, 98.5330452457551, 58.284322292574, 73.17482794484785, 51.77694543715447, 0.22548236764006077, 0.185003369565933, 0.18773064257637148, 0.1495084016313476, 0.12927601955110027, 0.1442483040474115, 0.1655023256617208, 0.12318330696753918, 0.16410991489406557, 0.17926040676332292], [0.024486165719046712, 0.13484121931176032, 0.05403907609082038, 0.03467405492800378, 0.0397267610195183, 0.035347021034648346, 0.18816478460306124, 0.034403645042930885, 0.1374982420595423, 0.017606433773893985, 0.12927609615989272, 0.18968421274856215, 0.9276282270589183, 51.03711189762239, 57.1056971242351, 45.730741254745, 38.6848621983682, 45.54898646570022, 25.382184943845196, 28.111627024988977, 24.99872030750398, 37.33843803405762, 62.83429130431145, 54.62265245376095, 15.921605575469234, 47.12640293182866, 73.13776939145981, 69.40000164893367, 65.46495045385053, 60.22956294398154, 53.898069089458836, 53.327532891304266, 63.218299188921534, 63.46987608940371, 65.33825789728473, 62.18929283080563, 56.60727370169855, 55.708050727844245, 52.3627043539478, 49.090765137826246, 49.707816723854314, 47.58472796409361, 50.26450303293044, 51.348179386508086, 47.39675229595554, 46.64461035882273, 47.274841108629786, 45.960074393979966, 47.348954293035696, 46.39566144635601, 46.18007229220483, 44.629257340585035, 47.19425209106938, 46.78445462257632, 49.355266248026204, 49.73333958656558, 49.4328389629241, 50.04653692245484, 49.907433986663825, 50.79113614174628, 51.05138540267945, 53.648029758084206, 53.64181672373126, 54.40607486232635, 52.86494032029183, 53.90383105124197, 51.704103100684385, 52.59505771821546, 49.78040018389302, 45.15555312556606, 45.96897817427113, 51.657215087644516, 44.4349705788397, 49.41363503856044, 27.041035698306178, 29.631235599517826, 29.864189086421845, 25.3474719678202, 28.872639402266476, 30.47062477757854, 18.05687427520752, 1.5586843293520714, 1.4616143703460696, 1.4524150639772417, 2.8251128571648754, 1.8041711372713891, 3.795746747524508, 4.422168385597968, 4.494484634168686, 0.6797248713912503, 2.6885994211319955, 2.011623947370437, 2.0755287956806923, 1.3311644283033188, 0.7486406088836732, 10.691019046691157, 34.494727503868845, 38.35544978418658, 39.07433786699849, 33.85761299440938, 27.958901697589507, 30.96915802647991, 28.69018643133102, 49.99455375056113, 47.086292774446555, 45.91454352101972, 46.491316287748276, 41.95034911555629, 44.54590697442332, 45.565731063965835, 51.03302478790284, 50.888199114030414, 53.433452575437485, 50.184286640536406, 51.258882707165135, 48.70716125734391, 49.741545184966064, 49.0787430732481, 49.891250287332845, 47.73370350560835, 46.32045392067202, 45.5907008724828, 47.7632507201164, 43.50951479327294, 44.55221806803058, 41.74130247485253, 47.460471199404815, 43.442473642287716, 45.509860823231364, 43.767551837428925, 43.860935626491425, 43.742480047287486, 45.60674336648757, 43.19521919373543, 44.02485932073286, 45.909248321287095, 48.19832394199987, 48.5939577318007, 50.706640443494244, 51.16804453634447, 53.09619149854107, 50.75619174588112, 51.48899247569423, 50.105203813122166, 56.22696853453114, 56.58950536481796, 58.05139233989101, 56.43062583861813, 59.40173102963356, 64.01133967984107, 59.889407157897956, 54.069398218585604, 22.957626735010457, 0.051866787816247636, 29.71849656874134, 61.907733332726266, 39.469669634296054, 22.38813977087698, 30.442885775719922, 30.583141888341597, 31.38882810069669, 48.04276666333599, 55.40312959301857, 29.72419185023154, 52.0537902462867, 33.96270113606607, 0.98649442316063, 0.04539556268061842, 0.046081870208464326, 0.06060763269722943, 0.07565437710934109, 0.05948370127307792, 0.04479537109634088, 0.1044776768333489, 0.06278840922600319, 0.0301746673311197, 0.034726589407411315, 0.009310798017278073, 0.08458367578925625, 0.02955648991759987, 0.041814189734718496, 0.05820720726924558, 0.07903910677639708, 0.11075911517705649, 0.03782269927943426, 0.04491305752326885, 0.22150041114899421, 0.03944682483110697, 2.9591113184728934, 63.708968085627404, 63.70069972930416, 50.01263195468534, 40.209444338275546, 56.25438590203562, 29.563170709917625, 33.37250601860785, 30.483084186430904, 42.870258669699396, 64.90720510482788, 60.66733475654357, 18.100781286916426, 44.79479312896729, 75.60723089402723, 71.57819578724524, 69.16102732381513, 64.48909613393968, 57.732778210793775, 57.56191584371752, 66.96905782145839, 67.55362433771934, 68.70261207703622, 65.26500371194655, 59.72412240120673, 58.79147691111411, 55.59542379071636, 54.13820835851855, 52.87094939139582, 52.59814462354107, 53.32841934696321, 53.23877357667493, 51.41388693163472, 50.923622039056596, 48.97100340935492, 48.56862706522788, 49.05322805527718, 48.92443703066919, 48.58608161249469, 46.13059159248106, 48.40027501506191, 51.29296418159239, 50.87691837741483, 51.68922162825062, 51.78282507004277, 53.545251892459014, 53.605687772074056, 53.56247109751548, 52.70345241792741, 54.79836287037019, 56.722634530836544, 56.624418381721746, 56.55885988666166, 54.5686924073004, 54.09641158196234, 55.13912662383049, 52.65443848025415, 48.48116213275541, 48.789527108592374, 55.581209121211884, 48.01693785575129, 54.42263510919387, 33.14016834382088, 33.497955183829035, 34.50132885286885, 30.98339426902033, 39.15939446418516, 38.209133609648674, 27.24158844640178, 5.632823138467727, 6.078751519803078, 6.282266637971325, 4.551230544044126, 1.7636350350033854, 1.7026239152877563, 1.696268940164197, 2.644516393061607, 1.1779184062634747, 1.2292687282446892, 1.5859460277903465, 1.8335607215281458, 1.4157668885684784, 1.7996720561096746, 17.036020563494777, 37.9507984653596, 38.82815814787342, 44.933794083133826, 39.67633539630521, 33.45552298330492, 34.51953257283857, 32.264055975021854, 53.47690851457658, 51.16174128747756, 49.901711248582416, 50.16617313508065, 46.243912789129446, 49.243839556171054, 51.11588878016318, 54.079008025507775, 54.41468838722476, 53.76135487710276, 53.67025390748055, 53.896217730737504, 50.87683600764121, 53.168759269099084, 53.92878124790808, 52.087726593017585, 52.079721035495886, 49.01644799017137, 46.21086289805751, 50.21196680684244, 47.365071312073745, 47.02551172625634, 45.38530988077964, 48.60361460716494, 46.71419712804979, 46.71080427785074, 46.61811474830874, 47.444997449075025, 46.95071604944045, 48.333728082718395, 48.70166993910267, 49.13151464154644, 50.62691434737175, 51.53563337941324, 51.52753760737758, 54.48625203101866, 55.68670911173667, 57.381329920984086, 55.28758049011231, 54.64065613285188, 54.531594630210634, 59.57575090469853, 59.801608823960834, 60.73431314960603, 60.613770869470414, 63.4185597204393, 68.81902802375056, 65.427903667573, 63.76869009387109, 25.646272243991977, 0.1294927458248792, 38.0530938794536, 65.854202547381, 43.131390463921335, 25.36366547307661, 35.084251896027595, 34.90806687262751, 36.77167907837899, 59.81427807961742, 65.83318648799774, 40.09041609302644, 64.15656935784125, 49.98543031754033, 1.1121856108788521, 0.019959131924195156, 0.03326456806051635, 0.08467126262163924, 0.03653071114733335, 0.040396586165673314, 0.03698479827313173, 0.05178155670423181, 0.045568461064249284, 0.05390981790579615, 0.2101445213080414, 0.2476437131483709, 0.2617269526085546, 0.14134294623809476, 0.1545283000075048, 0.2768668418209399, 0.3802026339596318, 0.2242361111265998, 0.36872908833526796, 0.1152969527268602, 0.4753891811255486, 0.2725755237042904, 4.903199038197918, 77.98378713669317, 72.22828157486455, 60.050451832432906, 50.79117144307783, 63.07495617097425, 35.984035768816554, 36.65067395856304, 31.281157078281527, 51.18931947215911, 71.52669506688272, 63.959897795031154, 21.34416957055369, 52.92407789537984, 79.24187167998284, 74.74716494160315, 71.20821429837135, 66.92261695861816, 59.97238097652313, 58.579096255763886, 70.43015726151006, 69.67786235194053, 70.94975363823676, 68.16098766942179, 61.01983424155944, 63.5580901945791, 57.76434544594058, 57.22274065017701, 57.04480232730989, 54.469299547133915, 58.081653425770426, 57.385860258533114, 53.98590272472751, 52.88541901496149, 52.734784310863866, 51.95983771354922, 52.515104124622965, 50.318878850629254, 49.64706313225531, 48.535153558177335, 52.56888374205559, 53.2937652064908, 54.29377740429294, 54.34570566300423, 54.312447886313166, 56.41374787976665, 55.28059867120559, 57.57302791841569, 57.207059014228086, 58.315811080317346, 61.37978230753253, 58.19064432574857, 58.9529138226663, 57.62196733105568, 57.061425332100164, 58.035196873449514, 57.17223621183827, 49.70929937977945, 54.14537845119354, 60.39541644434775, 51.369823025118926, 58.4425114816235, 40.11142038529919, 38.46170286978445, 42.0695891687947, 38.68357566095168, 47.56493176183393, 41.65517507060882, 22.930374107053204, 1.9765542808078953, 2.743926903893871, 5.455156439735044, 3.5456387746718625, 6.486474544771257, 10.667046500790505, 6.500222452225224, 6.196885954949164, 4.94003156500478, 5.380139149004414, 3.592980556911038, 3.4014951029131493, 1.7091261018668453, 1.0656689972646776, 16.679059382407896, 42.4857840230388, 43.151049383224986, 51.80018548042544, 42.49156951904297, 39.56881930751186, 40.42560615847188, 36.66502591102354, 57.82818594286519, 52.0348765773158, 55.40639692737211, 52.534445331942656, 49.2313507295424, 50.190993893531065, 52.65809805162492, 55.67089019283172, 56.79062881777364, 57.30498098557996, 56.1047004115197, 59.476495327488074, 54.17267030285251, 56.59392587600216, 57.7484598467427, 56.140868586878625, 56.00095764283211, 53.896072603041134, 49.4010873763792, 54.05510510167768, 50.59305644804432, 50.542140160837484, 48.316826589645885, 52.33867983664236, 49.59358553732596, 52.09739523549234, 50.136543550798976, 49.992263086380504, 49.48001723135672, 51.47810397609588, 50.54649399172876, 52.025509957344305, 53.740542780968454, 53.57390872893795, 54.842893538936494, 59.056621290022335, 58.92941098059378, 62.47132693567584, 59.55005545769969, 59.22106273712651, 57.08136273968605, 64.52866108186784, 64.34469799841604, 65.56551218032837, 62.96979742665445, 67.66868314435406, 71.89299737253498, 70.9396888363746, 68.62407053670576, 31.40171700908292, 0.15698808575830153, 36.68467306321667, 70.71299152989542, 53.41785723163236, 30.028918827733687, 41.535629072496974, 40.89883227502146, 49.20742819386144, 61.720840238755756, 67.19187982620733, 49.82762944313788, 68.2604903559531, 62.44100701424384, 2.0389870145628533, 0.13073972246098903, 0.2317219699222234, 0.16716878140164962, 0.15474727857978116, 0.2419884827348494, 0.153915889320835, 0.24478418271868463, 0.211196911611384, 0.18528829298673138], [0.044508612894963835, 0.020290125957539967, 0.0027716843244214094, 0.009249814545675632, 0.02056026962705918, 0.03617140441952694, 0.09326406484169346, 0.08175129551560649, 0.03604797616360649, 0.053544773179436886, 0.0832588033330056, 0.06299207370067317, 2.7970691361734947, 52.629135270272535, 52.24097359564997, 28.657975927475963, 28.341625005968158, 48.41836498629663, 27.44220199123506, 30.006251450507875, 27.630003113900464, 24.852892468052527, 51.79436076071955, 65.45403449766098, 15.289749003225758, 26.487277438563687, 74.35742255180114, 65.6016372096154, 67.53880562320833, 59.22432614910988, 54.29667995822046, 60.793709601125414, 64.42494969214162, 64.899423122406, 63.26379083818006, 63.21218813619306, 59.06829426365515, 53.766426501735566, 48.32418495608915, 53.22376266602547, 48.71087181952692, 46.71252227598622, 49.73644610374205, 47.780560139686834, 47.77016978110037, 48.86023959805889, 47.69039269416563, 46.92472642467868, 47.37988610421458, 45.51551295864967, 46.87571640937559, 46.85357462975287, 45.09468970760223, 46.76205004415205, 47.840941106119466, 48.91728262747488, 48.72309000261369, 48.30808362653179, 50.17216259433378, 50.92265713599421, 49.21628098334036, 52.38229267058834, 52.65378344443537, 54.09057901751611, 54.6809624087426, 54.07452475640082, 50.70147468197731, 52.50911074299967, 48.381879098953746, 45.50041575585642, 45.280931688124134, 49.22486312927739, 44.858045270366055, 47.905511163896136, 30.44953811553217, 29.104851561207926, 31.541641681425034, 23.43147454723235, 29.98671216349448, 26.147080467593288, 8.281721799604355, 7.593891043816844, 9.965798297236043, 8.340340641237075, 15.711386146083957, 23.087976901761948, 7.340601048161907, 1.0276695653315515, 1.9058838342466664, 2.6325710598499548, 0.6258280731497273, 0.8131970609388044, 1.358899998088037, 1.4206236408602808, 1.4161278691983994, 14.272802952797184, 31.70074478272469, 44.246222203777684, 33.869462474699944, 38.65309099997244, 31.532031874502863, 31.631728718357703, 29.246321647397934, 49.6592499363807, 48.5167968657709, 48.124803035489975, 47.756206143286924, 45.69699318178239, 49.22586333367133, 46.74409343350319, 50.03142010781073, 50.04777246905912, 49.49413776397706, 51.144122000663515, 52.88436389738514, 50.80642946304814, 50.70327897225657, 50.22164329405754, 49.68557296260711, 47.892375146189046, 46.338904749962595, 43.74229569588938, 44.45182892584032, 42.792458457331506, 45.6171807935161, 44.89910856370003, 44.72658311167071, 42.624777132465, 43.53832067981843, 43.78753239108671, 46.223826331477014, 44.20927347675447, 45.52958250045777, 45.96766025789323, 47.31668103125788, 46.40204706499654, 48.25774000537012, 49.46248815905664, 51.84972109333162, 51.954126742578325, 51.44802724161456, 52.92437207314276, 50.86945018460674, 52.011424726055516, 56.18674462841403, 57.59861353904971, 57.60299874890236, 60.677807484903646, 63.524746125744244, 67.52801910523446, 62.96403154250115, 59.3997698445474, 15.55759491459016, 1.5095094519276775, 52.718110315261356, 56.12978004640149, 33.42634839396323, 17.246279216581776, 23.670572427011308, 23.484671692694388, 39.41945937372024, 27.515416952871508, 38.92299713626985, 29.3096875375317, 39.5046728657138, 47.696817536507886, 1.6023110141677241, 0.043278199079776966, 0.12970001857367255, 0.0893902646437768, 0.0551438246733479, 0.03000581389172904, 0.02084599744017807, 0.04773581190215004, 0.053367408503207474, 0.04704021172778261, 0.03184711004817679, 0.051958511523421735, 0.06098812941702143, 0.1110450421730357, 0.04342755175105507, 0.010717121899248132, 0.039463579174010985, 0.07936831007921889, 0.1547934123945813, 0.03788093728343806, 0.1417812711048511, 0.15043143032779618, 5.14128984943513, 63.31066316173923, 60.361464408136186, 33.158293616387155, 35.6798481172131, 55.31874764350153, 31.455388761335808, 34.63682320810134, 31.20101324973568, 32.67481246302205, 50.973557733720355, 72.26926249842491, 17.13136161527326, 24.810311217461866, 75.53059562560051, 71.20557846561556, 70.75470201430782, 62.728504980764086, 57.20538023979434, 65.1036060240961, 68.49361250477453, 66.67265215227681, 64.32402710760793, 66.90728833598476, 61.47574309379824, 59.48580703427715, 53.340943474923414, 53.532484577548125, 51.8238099159733, 51.67442644796064, 50.95616202200613, 51.15953691544072, 51.04389759802049, 52.28824600096672, 51.63012327686433, 50.99688406913511, 50.02324196600145, 47.52232305465206, 47.916215312096384, 50.89290595823719, 46.64496337213824, 47.39648165241365, 50.50339891064552, 49.58147325823384, 50.27864317740164, 53.27613807493641, 52.54780492474956, 55.6980251496838, 52.2876968691426, 55.87238627095377, 57.216849250178186, 58.175362771557225, 54.37322108976303, 55.605112045041984, 55.28434061234998, 55.93994909717191, 52.53541807974539, 48.64119091341573, 50.02812923923616, 52.223417066758685, 49.42756337504233, 53.82871374007195, 36.40225456606957, 33.541293451862956, 36.54197723634782, 32.12450000547594, 37.4734224811677, 33.28492341503021, 16.19370137491534, 14.636708690274148, 13.936930394941761, 9.861367152583215, 3.8161161061256164, 15.081645692548445, 11.345959747991255, 4.980212325049985, 5.11883084812472, 2.319679668834133, 2.193674752789159, 1.2918590922509472, 1.908700341178525, 1.8313811094530168, 3.521684369733257, 17.894739181764667, 33.94604282994425, 47.071513283637266, 38.90325192482241, 43.46751405346779, 34.58770728880359, 38.50896743036086, 34.90206956863403, 51.69477962678479, 50.21417117887928, 51.57267232095042, 52.71595301166658, 50.20086257688461, 50.38131906140236, 47.43900014508156, 52.686252824721805, 54.30866279909688, 51.44686622004355, 56.56148787467711, 57.50387260990759, 52.81145488062213, 56.04911650380781, 51.642808222001605, 52.869760913233605, 51.06680423982682, 48.89900438247189, 47.67473459243775, 47.66890595036168, 45.13344664727488, 49.30399694750386, 47.12642254367952, 46.99760798485049, 46.909742970620435, 44.883591667298354, 47.00642939536802, 47.68324613571168, 46.9954389141452, 48.50763813141854, 50.45043514620874, 49.37573317558535, 51.83900125565068, 51.67870967618881, 54.67506708637361, 54.213219765693914, 56.95203042799427, 55.563946770083525, 56.33156245754611, 54.93826204730619, 56.36613815061508, 58.15748853068198, 61.267453470537745, 58.74756989940521, 62.682028816592315, 64.32161877232214, 71.62649585354713, 69.84791278839111, 66.97396862891414, 14.295775294303896, 3.1300612034336215, 62.56003525949294, 58.161669777285674, 35.52750325972034, 23.13248795847739, 15.525282429110622, 9.604751967614698, 34.26650439539264, 41.94076284285515, 52.12436937516736, 35.00317650456583, 49.90770070783554, 61.59100978605209, 4.762132956135658, 0.1645460640711169, 0.046287752507675084, 0.10541284802339732, 0.03276514385135905, 0.03605028974913782, 0.03365662887752537, 0.08727016993948529, 0.05988260708569039, 0.043331832895355846, 0.23001474298296437, 0.12273423388720521, 0.17084191252868022, 0.22175547246250416, 0.0712406458032708, 0.07003218806799381, 0.19972096047093793, 0.19789670594036582, 0.23005280223104263, 0.1970770991136951, 0.3320726391769225, 0.24012751727094575, 6.682949989072739, 74.95250102012389, 68.40730467150289, 40.63711604764385, 38.806620413257235, 67.35220278463056, 36.62422149412094, 39.07901333224389, 32.35182685236777, 39.16523095100157, 61.66547598377351, 73.89276289170789, 20.176001441094186, 30.785479314865608, 80.61652906479375, 72.59006531007829, 74.22875312066849, 64.2301530222739, 58.87136382441367, 67.61371504875922, 71.67759649215206, 69.76023997029951, 67.88442134857178, 68.34726887364542, 64.12453928301412, 61.95608831221058, 55.769310305195475, 60.869564317887836, 55.48365585265621, 53.82398336164413, 55.23897447893697, 54.131081411915446, 55.70843512012113, 54.36059498017835, 54.27917049777124, 53.48025821870374, 52.838668284877656, 50.132770230693204, 51.126843960054465, 52.936005823073856, 49.699167897624356, 49.934823897577104, 52.43992797790035, 52.532276261237364, 52.68835129276399, 53.944902189316295, 57.24097182673793, 60.28226783198696, 53.988012959880216, 58.560629736992624, 60.5383829147585, 59.155480707845385, 60.466474102389434, 59.727958479235255, 55.37221347132037, 60.42083732543453, 56.51916550051782, 51.88057053473688, 54.858900731609715, 56.3909863656567, 54.29683685302735, 56.580401543648016, 41.74026696912704, 39.16628214620775, 42.19461864040744, 38.268679111234604, 44.771670756801484, 35.13214403583158, 11.945413620241228, 12.98892294206927, 17.240989900404408, 12.360068944192703, 27.52537585073902, 47.28120319304928, 20.42841772879324, 9.796427411417808, 10.004644470830119, 6.46255789264556, 3.8606041189162967, 2.767557222996989, 6.277225902003627, 4.203494777602534, 10.605569231894709, 21.500909443824522, 38.95322684318789, 50.024638329782796, 43.175018987348004, 49.31589741860667, 41.65695582666705, 43.04822444915772, 39.840616026232325, 55.05801593103717, 52.151802432152536, 56.05291335813461, 55.1125447211727, 53.3253324416376, 54.496897343666326, 52.70096955760833, 53.47770867809173, 57.24855769065119, 54.89861865197459, 57.42256972097582, 60.89641294171734, 56.28233671188355, 58.24142725236955, 55.47437160245834, 56.0573927048714, 54.66708898544312, 52.616995534589215, 50.85649459592758, 49.862044319029785, 47.105598680434696, 53.067620954205914, 51.02867880175191, 52.03886955015121, 49.7718454945472, 48.13637794986848, 49.7174108412958, 52.0855849789035, 50.02706627691946, 52.47526853315292, 54.20263328859883, 53.578321395381806, 54.60954389264507, 54.24727770590014, 58.12652534054172, 58.78099241564351, 58.89104235556818, 59.45871130112679, 60.12595745824999, 57.60600720682452, 60.001975259473255, 63.27902532392933, 64.2518005832549, 63.80429737029537, 67.45354898514287, 67.44776741150888, 75.28645946133521, 72.47382979239188, 72.97037047724571, 19.978108059975412, 2.529704450599609, 64.18045266982048, 66.32935062531503, 46.86784029006959, 24.488184605875325, 30.536191117378976, 31.96768560717183, 53.79919790452527, 43.64147901535035, 51.624306401898785, 43.6437814466415, 52.30652424596971, 76.16754147314256, 6.380491122122734, 0.2748403860436332, 0.30023895865005834, 0.2647827854079585, 0.15299448473078592, 0.16986321988365344, 0.20862254975063188, 0.14780777836999587, 0.15417965339316478, 0.12369346023807604], [0.0833847098833611, 0.07274267609201132, 0.052515714083828276, 0.024651508560524355, 0.042582503144419005, 0.029116828227415684, 0.04075719141251138, 0.030588454401661313, 0.08898950106794797, 0.09857170584221041, 0.08004091995497865, 0.161478556091747, 5.6104332689316045, 57.64925526034448, 57.325722479051166, 55.635420199363466, 27.524036361325173, 51.28023216801306, 34.723103584781775, 26.19166801052709, 26.45603576014119, 18.38872052008106, 34.10233751420052, 77.83712187120992, 21.85543091066422, 10.993220017802331, 66.88406005982431, 68.87344698752128, 68.95512642398958, 63.487789553980676, 56.30646713318364, 63.77267129959599, 66.23462538565359, 64.77202061683901, 61.942018770402484, 65.11690678135042, 59.6790426008163, 53.93774386375181, 51.37401603883313, 50.17281370778238, 50.01394987106324, 49.49456922469601, 49.08153580081079, 49.67208000921434, 46.25316958273611, 47.912183115559245, 45.704559433844786, 46.76367782777356, 46.03255195002402, 47.3761284735895, 46.3670987467612, 47.102802030501834, 48.493180274963386, 46.92171012201617, 45.74026869189355, 48.1398884711727, 49.133640566179835, 50.86081704785747, 48.14770183255596, 52.963415345837994, 50.90032708260321, 53.40657257264661, 53.415088038290705, 53.29308663645099, 54.18947373667071, 52.872687001382154, 53.51327280844412, 51.894153702643614, 46.73487194122807, 47.786690804266165, 46.633745393445416, 48.451536470843905, 43.866352419699396, 48.72583958410448, 33.07370770362116, 27.509823653005785, 32.408230535445675, 27.81504681033473, 27.00124913646329, 20.640682674223378, 27.78481121986143, 26.648682971154493, 15.043160377010224, 18.600716783154397, 45.48474588701802, 20.343718067292247, 2.078963811359098, 4.363458839155013, 2.325964531590862, 0.5614892513521257, 0.46068182515521205, 0.2852690183827954, 0.5070357829813035, 1.0539050736734945, 1.641889690391479, 12.9132241395212, 22.10424646254509, 29.287545757908976, 33.397832762810495, 35.53202575252902, 26.587682270234634, 32.30823363027265, 31.837755134028775, 49.2659931029043, 50.069388651078754, 46.82733397330008, 46.44256514887656, 47.43298322923722, 46.360905324259114, 46.017089966804754, 49.165694175228, 51.47261265785464, 51.06472146126532, 48.10461851858324, 51.47476996144941, 50.571463800245716, 52.27726728685441, 50.15653979393744, 50.31455247632919, 46.22989031576341, 46.362584098692864, 43.66118108072589, 44.10298508982505, 43.58038025517618, 44.57079049079649, 44.750431122318396, 43.112084557933194, 43.29328629278368, 42.83711071937315, 42.880245024158114, 45.628128128667036, 46.79351137530419, 44.769940991555494, 49.323369533784934, 47.5360042818131, 49.280529406762895, 49.841953939007176, 51.663028040239894, 49.753186779637495, 53.08627182437528, 52.16158090099212, 53.09249270346857, 50.56288165430869, 51.76834367936658, 54.01465369809059, 56.790719032287605, 55.276236995573974, 61.30565343364593, 62.1387727029862, 70.57189603005686, 64.52946124538299, 58.13448382962135, 7.015222301406245, 10.98069392865704, 61.46123424653084, 46.56068732661586, 27.287848880214078, 15.663389082877869, 44.18668062456193, 55.6270420166754, 41.392042867598995, 42.21346170671525, 32.82916361285795, 44.34365780122819, 44.087581942158366, 56.4451660648469, 14.487868470530357, 0.2505048983279736, 0.10054871064400482, 0.05299997358252445, 0.04221913232017429, 0.13312553476181724, 0.0327552919606528, 0.061724359064453074, 0.1093576186066193, 0.11821567110957638, 0.053880583990605614, 0.08206290177880757, 0.033453144433517615, 0.03351723917970254, 0.04115417817487352, 0.05354965315951456, 0.032214273007646683, 0.06061787529277706, 0.044854241122882214, 0.07690297785185038, 0.1626081067708231, 0.23400360958710795, 8.916823152572878, 69.85899740649809, 64.4956111907959, 54.908087253570564, 31.347502008561168, 58.108039209919596, 37.49221455666327, 30.85672720786064, 28.755140881384577, 24.006978427210164, 36.169128494877974, 82.16593588552168, 26.64610597395128, 10.129958314280357, 65.28958128344628, 74.69431492590135, 69.82736741342853, 66.75741457170056, 61.31329028837143, 66.76314123215215, 68.41546320146131, 66.09794647462907, 66.53291379251789, 67.46615548287669, 62.88618426169119, 58.16976554932133, 55.489158938007975, 53.001007341569476, 52.681993130714666, 53.20716319545623, 52.92762371801561, 53.59409324584469, 49.131216541413345, 50.927328678869436, 49.822522517173525, 48.91190113559846, 48.6952333296499, 48.51464740691647, 50.21157849219538, 48.4718543483365, 50.56104206269788, 48.10037059168662, 49.2156102580409, 50.99834711320939, 51.91582087547549, 53.432005220843905, 52.622055392111506, 53.47087590925155, 53.9390774696104, 56.45225378774828, 56.644230273462114, 56.406024732897365, 56.54982274578464, 54.44736565313032, 56.59848759251257, 55.17778158187867, 50.949152746508204, 51.65335155302479, 52.208300252114576, 53.29043903658467, 50.10296413975377, 53.95211150569301, 38.21389928940804, 33.16700912291004, 36.63827142407818, 37.17161570825885, 35.52302391298356, 26.71604575649385, 30.28179599392799, 25.347864204837432, 14.002898777684859, 9.474305702793984, 39.23678675005513, 37.68251619031353, 15.79564650212565, 4.616683135109564, 2.999360719996114, 1.5524598956108095, 1.3971416363793037, 0.08785679410662382, 0.7668598957600132, 1.6503579650194415, 4.754862352724999, 20.366087344384965, 28.084713682051632, 31.949205360104962, 36.82747087171001, 40.17724167916083, 32.8609916856212, 36.00846821261991, 39.5683172441298, 50.487368183751265, 54.087421509527395, 52.01287992538945, 50.40148004408806, 50.17620655798143, 47.83782674420265, 48.98932087805964, 51.17104514952629, 54.26959206981044, 55.48754292149698, 53.06877805340675, 52.90114771935248, 53.06525184262184, 54.33990839988955, 52.335130091636415, 51.702020322122884, 48.50658693621236, 48.75606929102252, 45.32304617666429, 47.42535814162224, 46.88789536876064, 46.799975441348174, 47.69184789349956, 46.13021504494452, 44.833620671303045, 46.176044018037864, 46.9100881391956, 49.59062022547568, 48.138868654927904, 47.814182696803925, 50.571310827809, 52.46594505925333, 53.205609936867994, 54.042757480375236, 57.52009161057011, 55.248905920213275, 55.45550107955933, 55.14020527562788, 55.977023340040645, 54.80988287156629, 57.717124031436065, 57.7551474878865, 59.36689646013322, 60.48659193900324, 64.20571665610036, 64.85453944052419, 72.83620188313147, 70.00560775879892, 62.86215974438576, 7.410982587645131, 15.382829789192447, 71.14206744778541, 48.33424191321097, 35.27031344752158, 20.511009116326612, 32.01952757373933, 35.98105476748559, 46.74405028743129, 44.087601554009225, 43.19235586350964, 43.979046037120206, 53.536893321621804, 73.64865026166363, 30.58565612762205, 0.5917132585760086, 0.13196679613282605, 0.022343592079836997, 0.02856381425273515, 0.04842988373110852, 0.04108949354098689, 0.0713339246689312, 0.027155440127957734, 0.024560001273188862, 0.14996206357834801, 0.164285640142137, 0.1892101268975004, 0.11892113083552931, 0.2606148687341521, 0.14556406005736322, 0.2056678252354745, 0.14479889143859187, 0.23792188884990834, 0.17269062058579537, 0.2842065463623693, 0.4714066577294181, 10.658813445798813, 82.1806683078889, 73.29621745694068, 69.5371747785999, 37.47162995799896, 70.9899030193206, 47.86120014805948, 35.31405571968325, 31.895262964310188, 29.49244841452568, 45.66915219829929, 87.00826660279306, 27.83608836512412, 14.94691227712939, 73.03695663329094, 74.04965769860053, 76.14473681296073, 69.48409726542812, 62.98981720401395, 68.69307287277715, 71.02577701691659, 68.93986055927893, 67.75246497123473, 72.4342687668339, 63.90001889198058, 60.810666007380334, 58.200658136798495, 56.68381483324113, 55.859999425949596, 56.357120621588926, 55.80732199453539, 55.48153777276316, 52.96854188365322, 53.82963549706244, 51.67798011533676, 50.685687142033736, 51.28304842979678, 50.05580156080185, 54.10526437144126, 51.182004251787745, 53.92460392367456, 53.77041555220082, 50.39241152424967, 53.79125510492633, 55.748255022110484, 57.354230265463556, 53.92812228971913, 57.605873846238666, 55.127908645137666, 58.961492046233154, 61.683275699615486, 59.86342930024671, 59.16110146430231, 57.75927774367794, 60.55975198745728, 60.715995680901315, 52.22592738366897, 56.673659816865005, 54.29277327752883, 58.05029015387259, 51.722302898283935, 56.893638103239006, 43.67046925329393, 41.06711764489451, 42.45389515353788, 42.906007151449884, 39.923907556841456, 33.18958628562189, 39.10930579708469, 41.65189596914476, 23.715038376469767, 24.462275389702093, 62.85753526995259, 57.21162073073849, 36.068347115670484, 10.449981554861992, 3.5766556522538586, 2.0636930436857286, 1.72012381495968, 2.544935013978712, 2.7006754183000137, 5.814738254393301, 6.897562473051011, 19.775600010348906, 30.038138358823716, 33.93762150118428, 39.284827939925655, 44.69844402805452, 37.76769045860537, 44.108088093419234, 45.02744459336804, 54.167363336009366, 57.526273265961684, 55.962800825795824, 55.20042542488345, 55.214126263895345, 50.455867628897394, 53.29789546228225, 57.17920626363447, 57.30344341647241, 58.4066374840275, 55.95189663671679, 56.88299671296151, 56.14137849500103, 58.99391828044769, 55.44902132403467, 56.35416707684917, 52.35376919469526, 52.5042038579141, 48.84998652242845, 49.27950174577775, 49.145623407056256, 50.22665216076759, 51.99303273231753, 48.922220891521825, 48.1588609756962, 49.379867353746974, 50.219415387799664, 51.90724657427881, 51.7124891281128, 50.20005849099929, 55.001361216268236, 54.256844366750414, 56.22352861589002, 54.74437536731843, 60.62987219902777, 56.92977489963655, 59.80286790478615, 58.527183686533284, 60.35760087351645, 57.13840969147221, 60.779569456654215, 59.57450751335391, 65.70231660719841, 61.986780858808956, 69.33549434907975, 66.19221671935051, 77.46791701163016, 72.92000724423316, 70.26879879736131, 9.534957312768507, 14.295638011347863, 73.62910901346515, 57.61012177313528, 43.59348097155171, 22.056132708826375, 55.90704433379635, 66.97037573783629, 58.0576838216474, 59.581414807227354, 43.6881709098816, 61.71552150480209, 57.69972439735167, 85.44770456129505, 30.085055789639874, 0.7396749899752679, 0.23602401326981284, 0.21591829616696606, 0.1780945588383944, 0.345885694747971, 0.17133092177250694, 0.30950292283969544, 0.21283745825771364, 0.2088957367044303], [0.033788254274235624, 0.050526976645473516, 0.043883465996552865, 0.02899136217761665, 0.004288395491218375, 0.03122469425321587, 0.018877597720993143, 0.06479719518533637, 0.1416883906049113, 0.03254314689266105, 0.10937827233705791, 0.1169917843635044, 8.539780416796285, 57.03329409322431, 56.960957742506466, 31.590967447526996, 34.021760263750636, 50.98388533438406, 38.89818422255978, 29.767539924190892, 26.315916930475545, 21.82139454349395, 24.637040515099805, 68.78376591590144, 48.35767023025021, 6.315260144972033, 40.406394389367875, 79.04495300785189, 63.24496738372311, 64.31826906819498, 58.54526581302766, 67.7393485653785, 63.37453503762523, 66.76414535891625, 63.214925950573345, 66.85370091469058, 58.53756620037941, 52.29432959710398, 48.00198578065442, 51.467274312050115, 46.925538355304354, 49.34285979117117, 49.033890770327666, 48.97455707673104, 46.792252294478885, 50.904316133068455, 45.21750696243779, 48.70679255454771, 46.881698023888376, 46.957435069545625, 44.748383645088445, 46.85392764306838, 46.31782593265657, 47.62278672187559, 45.437300897413685, 48.98863838564966, 47.0177964241274, 48.022535077987186, 48.41983587511125, 52.615050038983746, 52.52219576989451, 51.148593502659956, 51.83920129652947, 55.30397599743259, 52.64137698758034, 54.021133453615256, 49.74730714674919, 47.71081255328271, 48.569525287997344, 48.600453176806056, 47.14799165725709, 47.62181397407286, 46.398787575383345, 47.28843604364703, 33.7547762932316, 25.74913444057588, 27.787954999554543, 27.45476926526716, 30.99004660883258, 30.479165738628758, 29.38510294883482, 20.651231888801824, 20.23287384740768, 51.835333839539565, 51.5828626386581, 40.14147750792965, 12.141798850028747, 3.9089706203629895, 7.514042373626464, 6.046979340814776, 2.213575633302812, 2.770453157924837, 4.213065360822986, 3.606665216145977, 9.539158171223058, 14.677520951917096, 25.684827181600756, 33.80173883130474, 40.900232561172984, 39.067571778451246, 28.2024004767018, 28.24947480232485, 29.612561195127427, 45.13576476804672, 52.265260911756954, 52.1433497244312, 48.94616696142381, 47.596538220682454, 48.57383597281672, 45.27876653978902, 46.6939067071484, 50.46180609733828, 49.46841093801683, 49.376925576117735, 47.58897196862006, 50.55788063233899, 50.949905841581284, 50.37892641559724, 45.94990368812315, 45.3309654420422, 44.618094275074625, 44.33883328591624, 42.22173790777884, 46.651164639380674, 43.71405855301888, 42.67528549317391, 43.63597592999859, 46.47288899267874, 43.92410539811657, 45.6926275837806, 42.90241426037204, 46.43572061292587, 44.73484362325361, 48.394791541561005, 53.457998767975845, 56.74824760806177, 55.742371466852006, 55.10993242263795, 53.84387762315812, 54.19774601536413, 54.91296668206492, 55.187454146723596, 49.72533010667371, 54.40586305433705, 51.86863083993235, 56.01136761326944, 53.26804622527092, 61.21059479251985, 61.610809910681944, 70.6302922771823, 65.56275083172706, 52.09798359101819, 4.229438804811047, 21.996226349184592, 65.96868084323022, 41.547019635477376, 21.928822378958426, 30.663866227672948, 89.45522154531172, 50.55815912062123, 28.080271597831484, 34.309207239458644, 28.384771077863633, 41.73800376153762, 46.75744518156975, 51.764915527835974, 60.026670502078154, 3.8195631340626752, 0.10405917066119372, 0.0541039216031711, 0.04598694425376673, 0.10761215621905942, 0.038689658000704744, 0.057040597086832415, 0.08138987055468945, 0.04354188271287469, 0.08990967225643898, 0.09804747953650453, 0.12549396604299545, 0.014286509399572688, 0.10457911453540288, 0.041422481318154646, 0.08824758321767853, 0.053264392660029476, 0.12268417004135349, 0.11367385756344565, 0.3088336071420101, 0.32226947166265985, 12.503126609709955, 65.5351177338631, 61.790834934480735, 27.802630547554266, 37.02651154610419, 54.179201049189416, 33.796788800147276, 28.969865152912757, 25.06210777067369, 26.560602226564964, 30.110819878116732, 68.74267516597625, 56.06307621925108, 7.78651423031284, 35.49446121338875, 81.05554426870039, 66.19344834358462, 70.10036437742173, 60.27823563544982, 72.13322685610864, 65.0825781976023, 68.2525985471664, 63.705218299742675, 69.82157015031385, 61.36521854708272, 57.29513583644744, 50.43822480786232, 52.87535029072916, 49.178818425824566, 50.74582884388586, 50.9787509518285, 51.95970435296336, 50.55693141875729, 51.75846715127268, 48.334171310547866, 51.58853438592727, 48.697531838570875, 49.87310148054554, 49.78877836658109, 47.78549840373378, 47.08715569588446, 50.04869030367944, 45.908177514230054, 50.63460611527967, 47.84868386483962, 50.19551246396957, 51.20816646083709, 53.22612393286921, 53.211348364430094, 55.217848593188876, 54.76671718781995, 57.197500198118156, 55.55176388832831, 56.866310950248476, 54.36207763610348, 52.0160884241904, 52.44723143116121, 51.38959569315757, 51.91590716761928, 52.97703773744645, 51.94646635363179, 52.72424097984068, 40.386621721329234, 30.197163012719926, 31.48190398370066, 33.07939121800084, 41.582144460370465, 35.58474633001512, 29.23982228002241, 20.911288953596546, 14.849898334472412, 36.63629062714116, 57.78800126044982, 42.84231178222164, 16.067493231065814, 6.7859700610560765, 7.422503569433767, 4.715015484440712, 4.9954943695376, 2.5221533977216293, 6.193253840169599, 8.00929799195259, 7.6232107608549065, 15.884719606368774, 29.13621287192068, 33.234116954188195, 42.45885302943569, 42.140356571443625, 34.419010070062455, 33.520971652000185, 34.348536845176454, 49.60996143279537, 53.3512318518854, 54.070861262659875, 52.843445731747536, 50.614641251102576, 51.94510136881183, 49.08006491199617, 49.99769556906916, 52.80962313375166, 52.40701144741428, 52.46576070785523, 52.18579369206583, 53.9970971691993, 52.74209953123524, 52.17953358927081, 49.391367743092204, 48.27009547141291, 47.44862956385459, 45.859128275225245, 45.668301043971894, 47.03111287086241, 47.063437123452466, 46.45632874581122, 47.098436432500044, 47.0161098049533, 46.13035625027072, 46.94127490443569, 46.429256546881895, 48.43559595846361, 47.10660672956898, 51.29621974883541, 58.893960598976385, 62.37328337084863, 62.16856702681511, 59.210550785064704, 57.42182839301325, 58.75201394481044, 57.49139947275962, 57.614452069805516, 53.90661593406431, 57.502648830413825, 58.503182703448886, 58.9733729054851, 57.20004189398981, 63.675451432504964, 64.56331914471042, 72.8774259936425, 71.59415198910621, 52.86311249579153, 4.601054941454242, 26.674043055503603, 73.71894697989188, 44.46190941718317, 27.496340505538452, 34.445807703079716, 101.92886075665875, 62.304198665003625, 40.89059922002977, 36.26941565544375, 33.618222898052586, 52.79411408209032, 52.2766593194777, 62.79059610059185, 72.36627840226697, 11.186137872357524, 0.5864775072663062, 0.0800273601987189, 0.08817260619252922, 0.0820711219022351, 0.09562199920295708, 0.12965788373783713, 0.1340937166805229, 0.01394663353435575, 0.2527913796685396, 0.1351542888028968, 0.18723397245330198, 0.12220829154454893, 0.1974870021184606, 0.18204787896285135, 0.205669418698357, 0.18580995289789093, 0.31602588572329093, 0.26124085449884016, 0.4837358009911353, 0.4071156704618085, 17.463762875526182, 79.70406024686753, 74.05449790339317, 44.70597890115554, 46.769647675175825, 71.432464045863, 51.75524688536122, 41.745213077914336, 32.92375549193352, 32.382442912747784, 35.81548367777179, 76.47121137188327, 57.57422031894807, 8.407571046583115, 45.52864113161641, 83.74656477282124, 69.31306623643445, 71.79720524818667, 64.44766806017968, 74.20676431348248, 68.12428997408959, 72.5878530933011, 67.83277942288306, 73.81321722461333, 63.56989652879777, 60.299510571264456, 53.435409838153475, 55.95117884297525, 52.75886374135172, 55.45859582962529, 55.98029459676435, 56.242148107098, 55.06577045686784, 57.165321073224476, 51.51622156943045, 53.89010667800904, 52.30830500202795, 53.04988007391653, 48.62341080942462, 49.8194513013286, 51.042575759272424, 52.72675129675096, 49.54087672695037, 54.50089816124209, 50.441139128900346, 53.078132906267726, 54.750592324041556, 56.44153395006734, 58.00755200847503, 57.09149422184114, 56.313354815206225, 60.882563052638886, 59.074542599339644, 61.133124059246434, 56.846271561038115, 54.46977023155459, 56.08286457677042, 57.72349788296608, 54.985961990971724, 55.180841030613074, 55.23470694018949, 56.34496911879509, 43.55570462442214, 36.676036004097234, 35.26879156789472, 43.2244957647016, 42.960822274608, 39.61202029258975, 40.628247568684245, 26.190691340354185, 26.28292783614128, 55.80020289267264, 60.345241485103486, 57.28136047240227, 40.20528662589289, 38.04240542073404, 21.309693897924117, 15.395320577006187, 13.348208127483247, 11.561120383201107, 17.176933673120317, 24.988973217625773, 21.513076636099047, 20.04512763792469, 33.355220133258456, 39.06829349456295, 44.98499278099307, 46.762999257733746, 37.299018213825846, 38.76117583244078, 39.248526403980875, 53.747297102405184, 56.28331730442663, 59.956946449895064, 54.40358415726693, 55.8354453886709, 55.43165306891165, 52.668708062941036, 52.97850862626107, 58.15394270804621, 54.52924513047742, 56.18264967395414, 53.94311751088789, 59.17768916776104, 55.62294313984533, 57.955411941774436, 51.25845909118653, 51.07738287218156, 50.34389964995846, 51.41955475653372, 47.22925140011696, 51.38106061566261, 48.948571374339444, 50.542140160837484, 50.21558323214131, 51.67692107539023, 48.443746643681685, 50.797349176099225, 48.16851392869027, 52.59562646189044, 49.33177125069403, 54.42319208575834, 60.36149578709757, 65.80069357349028, 63.03168850560343, 61.93667650222779, 60.55239362101401, 61.59080190043296, 60.05727283416256, 62.161361632808564, 55.99718432272635, 61.86137876202984, 61.12440855272355, 63.177777182671335, 59.00063337818269, 66.93234443664551, 65.03105786538893, 78.12054449512114, 73.97100633190524, 62.15060257142591, 6.42471682640814, 25.82147275247882, 77.72812704886161, 52.90646645330614, 35.089598086572465, 37.533391598732244, 92.2348327021445, 52.19535250817576, 37.24695267215852, 49.236394897584, 37.00744882706673, 63.556980163820334, 62.57981184990176, 67.22832648984848, 82.20941928125198, 10.9868912735293, 0.6323734058007118, 0.22575648922112682, 0.18072861427020642, 0.17824869572875962, 0.2963525026796326, 0.20482610911130908, 0.30215123668313026, 0.2121536481765009], [0.13277641317296413, 0.03950331998508304, 0.027646764872535586, 0.11058604825408229, 0.028871798835274194, 0.024687897736927675, 0.049984459990575436, 0.03199683427209816, 0.024111550639293367, 0.07652365707702215, 0.2083302718857604, 0.10745637990053623, 11.226345108401391, 61.04705941292548, 53.85687635790918, 48.64763536760884, 28.284152477018296, 49.931611476405976, 43.99899913418678, 40.398533959542554, 29.29157599326103, 17.051460973678097, 33.01702553226102, 55.894783004637695, 72.70021330925726, 18.55642734035369, 13.958857424797552, 75.30432977984029, 64.01402650340911, 71.5313313084264, 62.14091039473011, 67.38088315533054, 64.55112841821486, 66.83368898207142, 64.25049051161736, 63.78493262875465, 57.86855889904884, 54.62054614097842, 51.41005869834654, 49.080249263394265, 46.07812596905617, 48.97681636195029, 46.53785913221298, 49.49946434267106, 44.8864040067119, 47.918725629006666, 45.71780920028687, 49.42572770580169, 47.784282468980365, 47.756170841955374, 46.66108431354646, 47.32106231874036, 46.338316394436745, 48.25717910643547, 47.32307449463875, 47.56855995424333, 46.47586607163953, 45.648030234921364, 46.77317780833091, 45.904196308505156, 48.11691514907345, 49.25806207041587, 49.3124496552252, 53.81664068468156, 53.230458151909616, 53.12180457576629, 50.938507433860536, 49.228452097985056, 47.84440455898162, 47.88172198880104, 47.85399867642311, 47.518483054253366, 47.513007425492816, 47.31898346254903, 33.82803440093994, 30.24286843115284, 30.764682908211988, 26.49806199535247, 26.37059477067763, 51.265852758961344, 34.39647213105233, 19.692588929207094, 52.75055616132675, 57.291460575595984, 55.98036519942745, 42.79321155240459, 32.825149066986576, 21.0252377294725, 6.173102663409326, 3.903493520713622, 2.7677418195432235, 3.797556676210896, 4.463148818862054, 9.209194664032228, 18.27157501251467, 22.998917525814427, 19.556780784360825, 37.193514300930886, 45.468962269444624, 30.916843414306644, 29.504595994949344, 31.06312820988317, 33.860492014115856, 41.97067483778923, 51.908360527407744, 49.693072534376576, 49.888881175748764, 46.03740784429735, 47.288592938453924, 47.127920889085345, 48.06287665520945, 49.586227170882694, 52.87232222095613, 49.5976451904543, 47.40018436985631, 50.644294369605284, 48.48984233794674, 47.8919711420613, 44.15653328741751, 44.83950814893169, 46.28713730842837, 45.6352040844579, 46.21660132561961, 46.612246882530954, 43.963023154966294, 44.29318474185082, 42.581713430343136, 44.40414467165547, 44.852338221765336, 45.88997771663051, 45.38446264882242, 45.415833765460604, 44.65709047932779, 51.77369771465179, 60.03731973709599, 58.54861943952499, 59.097841478163204, 60.42690130972094, 60.58058369544245, 58.16277980804444, 53.97717545109411, 54.60988513885006, 53.78299459334343, 52.2282886505127, 56.00413476267169, 55.693557570057536, 55.35705743297454, 60.09537081564627, 64.75118498648366, 67.85145774964364, 67.15601367335167, 38.89108473254789, 3.0575767832417644, 42.94238321242794, 61.61395565156014, 34.19276775852327, 15.89209464288527, 40.82882188981579, 52.19082609299691, 17.916471073704383, 24.50356225813589, 47.4477352634553, 29.881449476365123, 30.11527765181757, 37.27637044845089, 52.748763638158, 69.34693198050223, 28.957321413101692, 0.22176184631403417, 0.07755033746962586, 0.016097372713228388, 0.03662755998272089, 0.040849286672328754, 0.10570021526467417, 0.09077319890380868, 0.050388226631067456, 0.04705832970719184, 0.034157435875386, 0.13994171013755186, 0.028908059691950202, 0.022686194260454467, 0.02749753094488575, 0.03173254734476007, 0.015741912704411776, 0.07144949669318815, 0.05187676228102177, 0.18432210289662887, 0.20361757476723966, 19.15026241733182, 69.69585034155077, 65.29786925162038, 50.529035522091775, 30.820084425710863, 53.39556247957292, 34.0269652489693, 34.00022252913445, 32.1430665446866, 21.952735108713952, 37.67862519910259, 62.24072294850504, 73.73325578628048, 26.372606946576028, 11.826102964339718, 76.41671396070912, 65.86511458120039, 73.66590869042182, 64.659185794092, 70.20554665596255, 66.26403531720563, 69.531918802569, 67.38516638355871, 67.13256574446156, 61.81540466124012, 56.90331459045411, 53.27181562300652, 51.95126733472271, 49.45363536957772, 50.50683490691647, 49.58616441295993, 54.09698817037768, 48.98551617899249, 49.59839828552739, 47.64737213811567, 51.81928742316462, 49.41512553922592, 50.38388429149505, 47.87417142621933, 49.75374767857213, 48.278391284327355, 50.14120724893386, 49.11331092157672, 50.48666607949042, 46.19255719646331, 49.236794979341575, 49.05185522571687, 49.864166321293006, 48.96559053851713, 51.312987881322066, 53.144118939676595, 54.98709163358135, 56.088022493547015, 54.927879533460064, 54.17517277502245, 54.59650985656246, 51.124706268310554, 53.096266023574344, 52.14005885585662, 55.05492510334138, 51.657713228656405, 51.6551205419725, 37.39492800927932, 37.3292596878544, 34.840217713386785, 34.43023589349563, 34.14511096092963, 55.02753911479827, 38.46961036805184, 15.341620387569552, 42.32348026767854, 60.217697774210286, 59.93784058478571, 50.09000855107462, 36.54800984167284, 19.14321784050234, 7.752319987743133, 8.159744912578214, 8.449576689350991, 7.297867805727067, 8.879560635935876, 20.722844562222882, 33.781264059005245, 28.810695371320172, 28.492997115658177, 41.116884677640854, 47.86006658307968, 35.67744762666764, 34.036563288780954, 36.60622565977035, 38.81538691059236, 45.47740713242562, 54.888957854240175, 50.92943499165197, 53.31822118451519, 51.0110830491589, 52.087730515387754, 48.45955771784629, 49.55165147781373, 52.10562044574369, 54.32197140109155, 52.010012672793486, 49.285377456295876, 53.451903404728064, 49.50383386304302, 48.58534028453212, 48.45270141478508, 45.84276022449617, 48.8215022702371, 47.97826328585225, 48.68279157146331, 49.41752602977138, 48.81174341324837, 46.319061479260846, 45.39722996373331, 46.27078494717998, 48.17090265212521, 48.7807253099257, 47.66755273265224, 47.00889656620641, 48.73298614255844, 55.28406996880808, 65.30544727079331, 60.71345790739983, 63.36732964361868, 63.07731743781798, 64.97881973943403, 61.59188055223035, 59.29922380755025, 55.909774303436286, 58.0178560749177, 54.84581962708504, 59.82245622142669, 57.6686906045483, 62.65390934482698, 62.751360631758175, 69.29896923803514, 68.37762801877915, 71.0943635817497, 37.848679557923354, 4.9955002530928585, 52.74113855054302, 65.11751082635695, 35.04366713185465, 21.559215476436002, 34.864501107123594, 60.28290325595487, 28.402239353426044, 31.919128625623642, 50.118269228166156, 29.178776471845566, 40.95506729618196, 46.57221125018212, 68.60527453884002, 72.93732843091412, 46.57999715497417, 0.4291169802027364, 0.04315225039458564, 0.048787807670211604, 0.11042443434557608, 0.05357625939312482, 0.07019617684906529, 0.18358232243166817, 0.012332694079246254, 0.25175418854961473, 0.27990719964427335, 0.1880815568109674, 0.2618207830575205, 0.20112461740932158, 0.2620172999318569, 0.13252300660937064, 0.18645907451789226, 0.1854149732858904, 0.12914670390948174, 0.5745001822229355, 0.28341539204120636, 24.862331651872207, 85.71001698893886, 67.23155852287047, 61.543576563558275, 37.24226151743243, 68.29053571147304, 59.3389456502853, 52.94483900070191, 37.53471735985049, 26.668302666756418, 47.95656865642917, 67.21109159531133, 83.49068503226005, 23.899978130094468, 17.01451813021014, 83.08881467388522, 68.83297597208332, 77.08616841223933, 67.38773161365141, 73.09766707881805, 69.0223793829641, 71.82950988892587, 68.79623120830905, 70.02684347091183, 64.28144977938744, 60.02889056359569, 58.020680181441776, 54.15573350844845, 51.46633294320876, 54.80346979633455, 52.34626570055562, 57.29972500954905, 49.941346799173665, 54.094230744146536, 50.30813547872728, 56.55046209212273, 52.15876856157857, 53.216835760301166, 49.28861341168804, 54.17210155917753, 49.69391584396363, 53.1839035403344, 51.60098006648403, 54.098011908992646, 52.040344361336004, 51.35977391273745, 52.14049423894575, 53.094681386024725, 50.322208942905554, 52.939308458758944, 56.89820766448975, 58.29464597086753, 59.777752968572806, 60.54244256788685, 59.29558384803034, 60.27877300016342, 54.44680475419568, 56.7566022565288, 55.591364137588016, 58.934180582723315, 53.823763708914484, 57.372367305140344, 42.29331724105343, 39.920487250051195, 38.313441199641076, 41.08873774928432, 37.457227014726215, 54.124221186484064, 39.914658607975134, 24.952820731747536, 59.30350311340825, 63.06305962224161, 62.39988880772745, 52.115504818577925, 46.508088342605106, 40.37738453957343, 37.31675517174506, 29.659717890524096, 25.12851938124626, 24.552815460389663, 25.105118520798225, 33.41322414336666, 45.101471485630164, 35.357091965213904, 27.23885259320659, 44.06181589249642, 49.40195029781711, 39.387472444965, 36.10210303337344, 42.286535463025494, 41.37729475575109, 49.580324003773356, 57.116907258187574, 56.438117565647254, 54.518525292796475, 53.64035760202716, 52.99816754556472, 52.8215471390755, 52.028302684907, 56.27501364677184, 59.5523068981786, 57.1576802961288, 52.725213727643414, 57.33383001819734, 55.35789682019142, 52.054782605940304, 52.08190971805204, 49.40107168689851, 51.398421026045284, 52.231226505771765, 51.707723448353434, 54.00525962152789, 50.748358772647, 51.62422795449534, 49.605693894047896, 50.877498888200336, 51.61650872999623, 51.917664389456476, 50.0556525107353, 50.30282458951397, 50.438052223574736, 56.81202926943379, 66.13921765358218, 62.80292411004344, 65.64883116752871, 67.04006056631765, 67.28461250182121, 66.17092609405518, 59.83720041090443, 59.5165741059088, 61.09080952982749, 57.64528974410027, 64.52798251182803, 61.73234847284133, 63.36470950034357, 66.32093321892523, 68.97120814169608, 74.00867677504017, 73.20481054244503, 49.99113736614105, 5.158683599964266, 51.830148466171764, 71.6195297241211, 46.8873619264172, 26.240470140211045, 46.95906285316714, 58.385229187627, 21.3761035473116, 33.46860408782959, 67.53082752227783, 40.3987536122722, 43.23068918720369, 54.61380750902238, 68.80405241443266, 85.42700229152557, 50.969121533055464, 0.38587453444638564, 0.18491168416315512, 0.08710583641884789, 0.15345600673988943, 0.13179321593094256, 0.16855051290364037, 0.2426892846462227, 0.09619883276642331], [0.18219702095995027, 0.1131002951954161, 0.22191062058892944, 0.020605455408053055, 0.05461022911232807, 0.060842706776794896, 0.11897317118822567, 0.07023770647544055, 0.03636116439837121, 0.12710964547530298, 0.12294342951668848, 0.07675896098296489, 20.178325445421283, 65.00508785247803, 48.781768660391535, 30.56341824993011, 27.271172923426477, 53.3927736743804, 32.222904428359, 42.81520820433094, 23.842644845285726, 18.73395185316763, 26.07463036814044, 59.31508979489727, 62.27486718085505, 55.31907320022584, 8.609578013420105, 39.37295967532743, 75.50657503066525, 59.77906304021036, 69.6462009799096, 64.9457267022902, 70.06242721311509, 67.63753168044552, 67.10813722302838, 64.84801261655747, 59.14276438374674, 50.54815315431165, 53.26451609211584, 48.56399474605438, 48.12796838821904, 47.69276572811989, 48.0658733460211, 47.251346111297615, 45.714008423589895, 45.17310573208717, 46.81011084587344, 47.0409187962932, 46.88884065997216, 46.25240864292268, 47.02328381999847, 46.8862715075093, 46.039855403284875, 46.97867470402872, 47.609870356898156, 46.09389781951905, 47.96578622633412, 45.868647867633456, 48.227263189131214, 46.83813225838446, 48.236476836665986, 46.48373042383502, 46.544283974555235, 49.339733662143836, 51.356757610074936, 48.27545342906829, 49.997844619135705, 49.457043909257465, 50.39872261785692, 46.026856668533824, 48.58931756788685, 48.385256259672104, 51.90248873925979, 50.698172046292214, 34.517226219177246, 35.67706323439075, 35.86929859653596, 29.138307417592696, 34.02205444151355, 43.52632607183149, 25.825389239095873, 45.03902735248689, 55.76403471731371, 55.68456749762259, 44.52791506244291, 44.173748570103804, 39.76414941972302, 31.74092946514007, 23.024585516222064, 12.340503181180647, 7.715683089148614, 8.025252722924757, 9.686441210008438, 12.363004838266681, 17.329982596059, 28.473724549816502, 21.79713664516326, 29.126163759539207, 39.493023426302024, 33.19338706231887, 33.040308721603886, 33.18693868575558, 33.05682190002934, 39.501923284223004, 52.391859331438624, 50.95842915196573, 51.207378064432454, 48.06273544988325, 47.8300408394106, 45.16071888708299, 46.14248029647335, 46.97203020895682, 47.79150747483777, 48.11410673203007, 46.50555449147379, 47.59192943572999, 46.136643809656945, 45.15089727217152, 46.973034335720925, 45.93684611781951, 46.8871775750191, 47.69916311387093, 45.496756184485655, 44.529813489606305, 44.7001894827812, 45.25592657827562, 44.8752958543839, 43.13716027044481, 43.41481308783255, 44.01024064710064, 44.457053522909845, 44.52695015938052, 46.05629797904722, 55.144437513043805, 60.90894491441789, 58.17654340497909, 59.64756558018347, 59.51461684319281, 62.321382568728545, 56.727160946015395, 62.04782862817088, 54.51117869346373, 56.151309936277336, 53.243880502639286, 53.7375892362287, 52.76708502923289, 61.19991025617046, 58.669306847356985, 70.08808735878237, 64.09740040379187, 75.85305367746662, 18.047005591853974, 10.396602999779487, 62.65521157172419, 53.0440749660615, 25.095889183782763, 18.787639294901204, 46.642606027664684, 20.413742180793516, 19.834859178912257, 43.774663094551336, 43.89495434299592, 36.66750877134262, 33.04407419696931, 29.395491346236202, 47.600668476473906, 64.11198769846271, 58.529286076945645, 6.425461096148338, 0.49221182842889144, 0.06359000149513445, 0.18973584707465865, 0.0500044816984765, 0.08670945486594593, 0.0835249346170214, 0.0790060194389474, 0.14242294635022842, 0.09575937408953906, 0.06870525483522685, 0.03278674370038413, 0.11423132442418607, 0.016924318662213705, 0.1840192530184023, 0.1162720294368844, 0.0751035369091457, 0.09640784453480475, 0.07377674157220511, 0.06513729225844145, 30.317862187662435, 74.87041365715766, 57.92857116268527, 34.320295779935776, 31.461923430042884, 58.35887086006903, 32.85799891717973, 33.420135359610285, 24.29438421803136, 26.469718948487316, 30.097266127986295, 62.836079905110026, 66.78306687262751, 63.551896772077015, 12.196422757640963, 31.167626034828928, 79.61558726526077, 65.82862084911716, 72.12229913280856, 65.79288805684736, 70.25377611960135, 68.38493147204, 68.84219354198825, 67.12109673407771, 61.767194809452185, 53.12829609840147, 53.44836150446246, 51.51941437875071, 51.34462964150214, 49.6992894910997, 51.69179470308366, 49.73433194621917, 50.213994672221524, 48.71651218783472, 49.51540877742153, 49.88161694618964, 50.25131994678129, 48.60932557813583, 49.095405301740094, 50.05932384921659, 50.00904690834784, 49.771657220778934, 48.91864368992467, 48.54307674592542, 51.137936422901774, 48.96888532946187, 50.742486984499045, 50.43620478722357, 49.8582160857416, 49.358329619130785, 50.551047863498816, 51.57768118766047, 54.20890908087454, 50.415949667653734, 52.89392663586525, 51.674312699225645, 55.04644886139901, 51.885057726214015, 54.304712972333355, 50.99135352719215, 54.23002712188229, 53.70932071439682, 38.78976991099697, 39.546701062110166, 36.202197997800766, 37.75323260215021, 36.65662419411444, 50.12318788036224, 23.45766813524308, 33.43474618850216, 60.20604441242834, 58.726789182232274, 51.68085913504324, 49.50493997143161, 46.32664734317411, 40.32485615822577, 24.494191715794226, 11.736164977473598, 10.417317036659488, 10.999235953054121, 11.85015788001399, 19.79219751973306, 32.80526265021294, 42.418158438897905, 28.503416892020937, 32.585584425157116, 40.92440220617479, 37.19951160492436, 40.765204967991004, 39.158249132094845, 39.2553944741526, 40.905139446258545, 53.33048643604402, 51.997429709280695, 54.294620713879986, 50.82600209020799, 53.23319204391972, 49.25419853579614, 49.951772459091686, 48.328064180189564, 50.250253062094416, 50.76728028635825, 49.8524070555164, 48.69270732325893, 50.281985036788456, 47.97455272366924, 50.541281161769746, 48.170765369169175, 49.537021037070986, 48.2160020643665, 47.30498452340403, 47.93944751062701, 47.24106557907597, 47.806620367111705, 46.036435096494614, 46.435265617985884, 46.267874548512125, 46.277394140920336, 47.783733337156235, 47.132431614783506, 49.397286599682225, 56.616573641377116, 63.900670005429184, 60.74263641911169, 62.663221051616055, 60.152500137206054, 64.86194095303937, 61.342351128978116, 64.83606899938276, 58.32810771080756, 60.388866086159986, 55.76043790386569, 58.254586804297666, 57.56411237101401, 63.23185882260723, 60.982493277518984, 74.35245683116298, 66.38435009987124, 74.68265764174923, 16.36764672494704, 14.86224203340469, 70.94278750881072, 54.63740056560886, 26.777017039637414, 21.648268968828265, 43.30960727507069, 19.706521188059163, 24.661710262298588, 44.02207836028069, 51.40979197717483, 31.665153195781095, 44.283155241320216, 33.10184286486718, 60.84847373347129, 68.92656372439477, 72.03853299540859, 12.644309382284842, 0.683314330395191, 0.023555817052481637, 0.24089188915827583, 0.08223088953884379, 0.07027886071873289, 0.12313471401050208, 0.01493670641549773, 0.31133770341834716, 0.24258560230655057, 0.5960243111175876, 0.0992452503452378, 0.2052375902571986, 0.3079185610817325, 0.20806633927408727, 0.22411824083857, 0.269258332348639, 0.19735235450488908, 0.3511226717983523, 0.22887321068875252, 34.82156292084725, 86.0020217587871, 65.08764197749477, 40.267997480207875, 36.85221710512715, 72.83083608073574, 43.200424178954094, 55.61899723545198, 28.667683793652444, 27.03448534011841, 40.34909248352051, 70.84906639591341, 73.17429450250441, 65.40695821085285, 12.001404473858496, 45.70373181373843, 79.98154440233785, 67.59006315662016, 75.27761059422647, 67.22069355749315, 74.5196125584264, 71.95739484602406, 73.29683719142791, 70.28974425408148, 64.87369629644579, 57.41155570553195, 58.89229359165315, 54.225057478873964, 53.43041666092412, 53.72082110374205, 53.27886412220617, 52.39374599149151, 53.792455350199056, 52.52743605644473, 53.233454842721265, 52.16214964466711, 54.3946489980144, 50.96330073571975, 51.786288522904925, 51.025599741166644, 53.03766189082977, 52.60695818931826, 51.62493790349653, 51.91064334684803, 53.62440140016618, 51.437754554133264, 54.64832044416859, 53.90671007094845, 52.60314956788094, 52.29573772799585, 52.91817472827051, 55.922969156695956, 56.40565995247134, 54.53129653007754, 56.315527808281686, 56.1524474236273, 57.51637712601693, 53.824140256451024, 57.87228515071254, 53.646496111346835, 58.00313149729083, 58.35588201399773, 44.30479495756088, 42.794400030566806, 41.06820414143224, 42.474032602002545, 42.34924239497031, 54.929495549971065, 31.164933327705633, 49.196002329549486, 67.12516030957623, 61.58209423865042, 56.38498121692289, 52.59220615510018, 46.993928801628854, 49.058229077246885, 41.9542008830655, 39.21172672702421, 33.20800573595109, 32.18014078755533, 28.687850659893407, 33.6936814554276, 41.9875253400495, 47.73639425154656, 32.31233446828781, 35.49770893589143, 45.73890762944376, 39.83189659733927, 41.40573586187055, 40.17492355838899, 41.75711747138731, 45.1647275493991, 56.24553703492688, 55.44768379580591, 57.539272000712735, 52.94915753026163, 55.558494675544004, 50.149295176229174, 53.9256041280685, 51.38192353710052, 54.234945774078376, 55.052320649546964, 52.87845288553546, 54.67472976253879, 54.09149292976626, 53.86199505098405, 53.623146241711034, 49.89236816283196, 52.45456626338344, 53.129766987216094, 51.32321350036129, 51.43928820087064, 49.69887764223161, 51.33340774043914, 51.006682149825565, 49.04470866726291, 49.29359089943671, 49.166513950594016, 51.33371760768276, 51.05858687431582, 51.875467531142704, 60.945709290043006, 67.25064477612896, 63.812173489601385, 66.96929316366872, 64.3115225914986, 67.39589014360982, 62.8497846664921, 68.38188771278628, 60.66029802445443, 63.48275323067943, 58.95352963478335, 61.0015050057442, 60.31887531280518, 69.0055759491459, 63.51817223333544, 78.14156839924475, 67.89438416880947, 82.40773431716427, 22.892574225702596, 12.755337953567507, 75.11212579665646, 62.61291665415611, 38.59301990078342, 28.124976811870454, 55.92926848319269, 25.362269109295262, 25.14080228344087, 57.1462465870765, 64.84966001202984, 47.26918897321148, 47.01689820135794, 42.36626155914799, 62.33340463330669, 78.93367536606328, 83.77200526575889, 18.946401149995868, 0.8155694820227162, 0.41405541581972954, 0.3356351931729625, 0.20127374408466203, 0.22337043177216287, 0.22096845501613235, 0.1474664861997289], [0.1619420086424197, 0.1472374718756445, 0.048420242514581456, 0.01975652656608051, 0.02678914667828189, 0.05099448180126567, 0.048421253750641505, 0.030511866676651185, 0.034858931096330766, 0.15751924515972215, 0.12183950447867956, 0.12877296025474227, 30.739609156885457, 71.71311747643256, 44.616654765221384, 40.45354520120929, 30.800354903744115, 47.90663296176542, 35.41283276773269, 27.489899973715506, 18.628222403987763, 26.013815979803763, 21.762270696701545, 42.5554923857412, 66.2853337872413, 65.74738071810815, 40.25604601829283, 6.988465853275792, 52.32608902838923, 75.56526937792378, 68.35156779135427, 68.7227887492026, 66.78303549366613, 64.33984994888306, 64.45719549732824, 60.92046491561398, 53.220263911831765, 50.55282861955705, 49.48203725199546, 49.23038974885018, 51.00657624583091, 48.29043296075637, 47.22824335098267, 46.4072520502152, 47.26784360024237, 46.66570094323928, 44.077454382373446, 45.52531888408046, 49.153734868572606, 47.620856915750814, 46.74674887810984, 46.029366985444106, 48.001856342438735, 46.40931129455567, 48.064865296886815, 48.94178959631151, 46.732334167726584, 46.6817081359125, 49.73342980107954, 47.95305813512495, 49.050772651549316, 48.534471065767356, 46.63739319770567, 48.95074044504474, 49.369814318995324, 47.546206366631296, 48.347707410012525, 47.10781089721188, 50.83814182589131, 48.26727136488884, 51.96817275016539, 48.316273535451586, 56.53660435830393, 47.772887983629786, 34.174054130431145, 39.18148917536582, 35.43919501766082, 24.710955619812015, 31.98431645670245, 33.22801374620007, 56.65487558610978, 58.315367852487874, 54.64242119942942, 42.83931509140999, 42.37794629989132, 41.32091460689422, 38.5226486575219, 41.78728834275277, 41.07265995394799, 27.306338933206376, 14.26093582184084, 10.55873122907454, 10.989858546564657, 15.336207516731756, 23.0515851513032, 34.2003575448067, 26.60138899280179, 30.83738207817078, 38.78212913390129, 29.078503039575395, 24.366157708629487, 40.130894953204745, 41.27150058746338, 36.477144379769605, 51.72775107045328, 52.14442445385841, 50.34165213184972, 49.81213608095723, 47.94009470170545, 44.90044609192879, 45.63098753652265, 46.72687815081689, 47.556832067428104, 46.19025868754233, 47.07343132265153, 47.601904023078184, 47.62947044064922, 45.921262541124904, 46.981679239580714, 46.31346033465478, 45.2952051931812, 45.30231645030361, 47.31758317639751, 44.37209498497748, 43.773560908532914, 43.21130091144193, 44.32241032200475, 43.22737478440808, 45.546499683010964, 43.95330744404947, 45.62109924131825, 43.29375697720436, 47.33893263724543, 53.21299968227264, 60.31853798897036, 59.49025500205256, 60.508204198652706, 56.89211230124197, 62.89804550909228, 59.287068382386245, 62.22939514344739, 57.037404737164906, 57.73975610733033, 53.03940342318628, 58.3681276536757, 54.887192787662634, 60.08372529860466, 62.533167023812574, 70.74031476051577, 61.274584339511016, 50.73367341872185, 6.5909684473468415, 26.46451592445374, 67.56718004903486, 52.00831428650887, 20.029671538260676, 12.882428630705803, 44.44610618775891, 81.31257718609226, 44.21957754319714, 35.71894238072057, 48.50925414792953, 33.16782497590588, 31.801220217058738, 31.503961432364683, 32.50756259887449, 59.58131674797305, 64.35884598762759, 17.230625037224062, 0.17037729552436262, 0.20788589492440226, 0.023587017898417773, 0.09122200385336915, 0.060182009568257686, 0.04288408514713088, 0.10940398224779677, 0.2983055978773102, 0.10842843056325951, 0.13325388513265118, 0.04760838849770446, 0.03370694170195249, 0.07332676450812048, 0.06933203733135616, 0.07863978344586589, 0.04933353806395204, 0.04152513710000823, 0.07733377207431101, 0.1462867874051294, 40.1392456793016, 80.72914815718129, 50.07434652697656, 53.802598599464666, 40.681893825531006, 53.221511225546564, 39.875795764307824, 21.08860165842118, 14.00344987069407, 28.437997641101962, 27.412948954489927, 45.22174704459406, 70.76844599939162, 69.07832807110202, 51.884092823151626, 7.809036970138551, 37.571454278884396, 80.28358259508687, 71.62156151187035, 71.19348187600413, 67.58785093984297, 68.37779275832638, 68.41700077056885, 64.4426513487293, 54.74077463150025, 54.459834867908114, 54.26652869870586, 52.978692977659165, 53.632877642108554, 51.71191646206764, 50.24118846462619, 47.65870778791366, 49.565673951179754, 49.90514332248319, 47.111611673908854, 49.43461579661216, 51.3621469466917, 51.9748447018285, 49.876698293993556, 48.94545309005245, 50.25604248046876, 48.59698580157373, 50.16374911031416, 50.47411841730918, 51.215473836468114, 49.639767523734804, 51.596885112024125, 52.432224442881925, 51.807669362714215, 52.400257125977554, 51.759353606931626, 52.04023453497118, 52.89050240670481, 49.76721709774387, 51.3919295034101, 49.348574684512236, 55.285238835119436, 51.89802900437386, 56.41778792104414, 52.718384881173414, 58.62160298132128, 49.1411401379493, 39.82704462543611, 41.1937984343498, 42.13595174974011, 28.937229071894002, 34.245005884478175, 37.91359086190501, 47.01097934476791, 53.33759377079626, 58.42215438042918, 48.31091950016637, 47.86500484712663, 46.30024586954425, 42.51072245259439, 45.52160439952728, 44.45814786418792, 32.926830630148615, 19.75030464510764, 17.051796336327833, 18.82936742997939, 23.329989102578935, 32.034962100367395, 44.83370304107667, 29.771736860275272, 33.000728084195046, 43.71449785847818, 32.431121487771314, 31.396431615275723, 44.41789257910944, 45.053194953549294, 39.61032975104548, 51.515037013638405, 54.24476346661968, 52.12435368568667, 52.809874165442686, 50.248864543053415, 50.35863599469585, 48.52883854219991, 49.45761265293245, 50.25815271562146, 50.9961348964322, 49.98739934736683, 50.916153846248505, 50.52121823833835, 51.4149812729128, 49.25652450130832, 48.42537033942438, 48.00659064323672, 48.50077398361699, 49.331943834981615, 47.34505937945458, 46.72494442232194, 47.06178188323975, 47.42892357610887, 46.19505966863325, 48.56598338773174, 47.92954352594192, 49.1142483680479, 47.08987782078405, 50.291845875401656, 56.472485373097086, 63.67597703010806, 63.43484540139476, 64.36862837883734, 58.904350957562855, 65.38430652310772, 64.15836188101, 64.2833835078824, 63.03958031439013, 62.25799706674392, 57.588207490982555, 60.611237018339104, 58.90528840403403, 63.80189295737975, 65.97921632951306, 73.24423036267682, 65.7834626013233, 51.629064236917806, 6.227113210385846, 33.0427445134809, 78.712234035615, 57.61781746341337, 25.10766806141023, 13.58260210483305, 46.052705087969386, 59.93249831661102, 33.30884202834099, 34.70235032420005, 58.448257753925944, 24.010608580804643, 32.979355089126095, 30.79141386093632, 34.27938545903852, 74.43670934246433, 72.40268584220641, 37.653980947309925, 0.26597457307000316, 0.0540255852824738, 0.03631231480187947, 0.053482846462077675, 0.01903469362596591, 0.014595419033280304, 0.15441894861719302, 0.38631586237780513, 0.23805187864890023, 0.2930254747550334, 0.08577260594334334, 0.14584521432557415, 0.1860096260544754, 0.14497650126295705, 0.16063311678026954, 0.187357465826696, 0.24420197121798995, 0.2520762978782577, 0.3224921274569727, 51.449015678897986, 94.1128243169477, 57.39708215959611, 53.28533211062032, 43.812208021840746, 65.18481477614372, 50.894651412963874, 35.96505541955271, 26.871340236356183, 32.22159827909162, 35.50347089767456, 55.98269116493964, 76.98773261039489, 76.26116844915575, 47.70003388004918, 9.314513244936544, 57.177268612769346, 81.20886971873622, 73.72120626511114, 73.05687442902597, 73.05605073128977, 70.82375926356163, 71.0437257828251, 68.51585234365156, 59.2457305231402, 58.00755593084521, 58.18908322241999, 55.72428541798746, 58.052470991688395, 56.32730668590915, 53.18044400984242, 52.16241636583882, 51.39123132151943, 52.29871088458646, 50.770939857729026, 51.71798044635404, 55.64330808577999, 54.66012677838726, 52.53732435164913, 51.34359413577665, 53.05667361905498, 50.86167996929538, 52.732215158401004, 55.168446340868556, 53.16197749107115, 53.777836676566835, 55.2934758124813, 55.64457108897548, 53.894503654972205, 52.8807004036442, 52.84299465917772, 55.429738952267556, 54.67286663670694, 53.36651732844692, 55.39920330047608, 53.117572338350364, 59.841271831143295, 56.37069594475531, 58.27697569324125, 53.65316806300994, 62.91464497966152, 51.12141932210615, 42.032075620466664, 44.40607055541008, 41.74564061626312, 33.636661960232644, 39.38257340461978, 40.642313188122166, 59.18314126230056, 62.761241082222234, 62.81080807408979, 50.52321472475606, 52.194269934008204, 49.01602045182259, 44.371659601888354, 47.64236327140562, 54.87584144838395, 48.33784264902915, 39.07967229043284, 35.21116410532306, 32.32477818765948, 37.30900849065473, 42.79188971365652, 53.04434168723322, 35.08709169203235, 37.28540758932791, 46.27480537660661, 34.6191607752154, 33.001265448908654, 48.359219566468276, 49.46452779154624, 44.24450420564221, 54.02797406719577, 55.61065043172529, 55.920243109426195, 54.172030956514426, 53.17958501077468, 52.57221775670206, 51.64599318658152, 51.894243917157574, 54.930938982194476, 54.60150303379182, 52.84208466929775, 55.740571098942915, 55.29842976600894, 53.83343235138924, 51.91453433805897, 51.803601864845525, 52.33568706820088, 51.06467047045308, 53.425337191550966, 48.87859629046533, 49.975181164280066, 50.931360875406575, 51.02403471546789, 50.016722986775065, 50.51245958574357, 51.91716232607442, 52.22900644425423, 49.76901354328279, 53.63380724383939, 57.763243259922156, 67.12681554978894, 66.11940183947164, 66.39366180666032, 60.91714266807803, 69.01094959628198, 64.96694280255225, 67.85847879225209, 63.126966799459154, 66.21205606768208, 60.23546611109088, 65.34684396559193, 63.21713424498036, 68.9773113496842, 66.915784189778, 75.88392273072274, 66.83446561136554, 62.21741622494113, 9.263746988388801, 32.39911102479504, 79.81176853179932, 62.00961689795218, 33.20788806484592, 21.502527421520604, 53.27186661381876, 89.16805698025613, 54.110296772372344, 45.40973055747248, 67.89173264657298, 42.27277971083119, 43.630484611757346, 45.815484062317886, 45.08109477258498, 78.65811317197739, 81.74949784432688, 48.399090459269864, 0.3464612412837244, 0.3509478811775485, 0.1028428528638136, 0.14426825297695978, 0.11010448538487959, 0.09531963196012283, 0.2776233383244084], [0.09467268602982645, 0.046389155735772465, 0.04902958884955414, 0.0834659458468518, 0.09094876327341603, 0.053135253218633514, 0.12646782467322004, 0.054852561874976086, 0.07423062568470355, 0.09260054076871566, 0.08315561895048426, 0.14633149629639042, 37.718817726258315, 57.232236708364184, 51.798808728494954, 20.721201089120683, 26.6379984348051, 51.97323653005785, 36.23141181084418, 27.561861738081905, 41.989608118611, 29.38249065030006, 17.053447654170377, 24.086855534584295, 58.40547254008632, 59.533404996318204, 67.06371245845672, 23.883068792281613, 1.6626233391223417, 36.84154041351811, 57.38030618236911, 71.0550614326231, 64.94696224889448, 69.39968001457953, 58.48453183327952, 55.41796791938044, 53.234007896915564, 58.742635557728434, 54.08622910899501, 56.2715894176114, 49.021076386974705, 53.357915570659024, 48.874207158242505, 48.35071194556452, 47.72004189029817, 47.58697548220235, 45.916285053376235, 46.73633890767252, 46.896155880343535, 48.68352113231536, 47.5776598530431, 47.558973681542184, 49.79295569081461, 49.645737371137066, 47.13607549667359, 48.113016313122166, 48.33563435462214, 48.638307971339074, 47.38303968983312, 50.15901873188634, 48.1727461661062, 49.99510288238526, 47.71007122532014, 48.32475369976413, 48.04330010567942, 48.827695692739184, 46.86681655145461, 49.93135259997461, 50.88670861336493, 56.2994029445033, 52.23956546475811, 52.86939221043741, 59.72609927577358, 46.97357954517488, 37.18341419773717, 50.789555426566835, 30.151804724047263, 27.74055511720719, 27.558190399600615, 37.2823481405935, 52.69444665601177, 49.46188019167993, 46.80379975226618, 40.332928396040394, 38.56961904033538, 39.38166733710997, 41.835447203728464, 42.805170859059984, 43.85687597336308, 32.63747542135177, 25.79494184063327, 20.86490692630891, 21.013582406505463, 20.07198214530945, 26.001431095984678, 32.04961019177591, 38.20719988115373, 45.54080440152077, 31.333842354436076, 10.544707775115967, 17.957228422164917, 34.3447046895181, 40.38789256926506, 32.201790309721424, 44.60862175110848, 54.120526313781745, 49.46357857796454, 49.40208365840297, 49.52217878833894, 46.51545063141854, 48.15593880991782, 46.18291993294993, 46.461455283626435, 46.56935968706685, 46.77650005586686, 48.8928109599698, 45.455790950405984, 45.45801885666386, 48.037726417664565, 46.91888209312193, 44.85306386024722, 45.28849794018654, 47.90436583180582, 44.1491670762339, 43.05075830028903, 44.098407683833955, 44.547817168697236, 44.06382414602464, 45.6346078841917, 45.01182571534188, 45.24079407415083, 45.58603325197774, 46.59726735084288, 54.9151514422509, 58.116083991143014, 59.107827832621915, 59.40460612696987, 57.680591075651115, 57.93859281847554, 61.898460849638916, 62.326430659140314, 62.98918178004604, 60.18722095797139, 52.32616747579267, 55.137977369370006, 54.39723383995795, 60.08473334773895, 62.0975564372155, 67.67887346206173, 56.76359584254604, 38.48373874541252, 2.850553840398789, 42.65850951594692, 44.90167379379273, 50.047478291296194, 19.836453622387303, 7.783789653931895, 29.596734431482133, 75.9131443885065, 61.466046994732274, 39.3861113825152, 35.30739553513066, 34.72136205242526, 33.82000923156738, 40.05322417905254, 27.287866530879853, 37.75356600361486, 71.02962093968546, 50.27800383106355, 1.460027403889164, 0.21900832713130983, 0.19032988697290423, 0.033898452191703746, 0.03508880343889037, 0.05073858928235789, 0.06610810951960665, 0.15001739044823956, 0.053313970040049286, 0.03913463634108344, 0.05869202218168686, 0.07661478323561531, 0.040452805527996634, 0.04173255923594679, 0.03615426320222117, 0.09356910573138345, 0.08485595109842478, 0.08247770008540924, 0.1574756547568306, 49.93844424524615, 63.5047891063075, 57.73194274594707, 26.551790621972856, 29.319819019686793, 59.92499090010121, 38.799971995815156, 33.528404543476725, 39.42592736213438, 35.416033421793294, 18.977483972426384, 28.0611559267967, 62.634623050689704, 64.15234496516567, 72.07599947529455, 34.41593493184736, 0.7234338034064539, 21.66024200377926, 48.508108815839215, 70.63091201166954, 66.67468394002607, 69.62131746353643, 61.60370649829988, 58.058836998478064, 56.612827777862556, 60.6662247257848, 57.19310714352516, 57.89936127201204, 51.440178578899754, 56.37540671133227, 50.89218424212549, 50.3006672859192, 51.95123595576133, 51.8476696937315, 48.9642765445094, 50.35896155142015, 49.38619021446475, 51.453153779429776, 48.98829713944466, 49.33683110821632, 51.318287003424864, 52.16693101390716, 49.629424233590406, 51.02049281520229, 49.08572881452499, 50.712433784238755, 50.871097580079116, 52.809038700595984, 49.665294308816236, 51.75357203329764, 50.35830651560138, 53.177741496793686, 52.78535542949554, 52.31873066194596, 50.578022003173835, 53.93097777520457, 56.90632697074645, 58.39866330546718, 56.644512684114524, 57.81067648241597, 61.2366432528342, 50.11600209820656, 42.1652400878168, 49.92107991249331, 33.07395481294201, 27.695161527202977, 27.589926296664824, 42.20139649606521, 55.11075219800396, 49.657202459150746, 50.71889000554239, 47.82577722303329, 42.88276318580874, 43.191308590673636, 45.436512501009055, 51.17328090052451, 54.0789766465464, 42.4590491479443, 31.081406454886164, 25.26458248015373, 25.049167871475223, 27.15211133803091, 33.695246481126354, 44.2651633293398, 37.50564082976311, 44.42098340680523, 41.07232263011318, 11.363654540431115, 15.42693978355777, 32.75925324809167, 41.88469256124189, 36.900830961042836, 44.30215912480509, 58.189495071288086, 52.957747520939, 55.41182941006076, 55.62731266021729, 51.52488216277092, 50.00006468065324, 51.34768909023654, 48.43814157670545, 48.37747035488006, 47.94529576455393, 50.57610396415957, 49.22155657122212, 49.6839451789856, 50.81498415239396, 50.74564057011759, 49.70670669309555, 48.86620944546115, 50.157171295535186, 49.526536541600386, 46.47380682729906, 46.248337222683816, 45.47965072816419, 47.50299361444289, 46.61594959997362, 47.559738543725786, 48.943739014287154, 48.6842389260569, 50.69635991127261, 59.2796786369816, 60.94657221148091, 62.26474746581047, 61.1443224260884, 61.0523271560669, 58.46099368987545, 63.81058100731143, 64.94290651813631, 67.52810539737825, 64.7023710896892, 57.61757035409251, 57.09922913582095, 58.561712311160186, 62.2869598480963, 68.75114748554846, 67.60103010362195, 63.5595924623551, 34.395303264740974, 4.414476127393784, 52.21066151895831, 46.940388448776744, 56.047394583302165, 25.661322378343154, 9.087377613590611, 35.28740713673253, 68.73434405173026, 47.169603916906546, 38.23648821923041, 49.04038621533302, 32.25993552515584, 35.40030471740231, 48.90837884718373, 31.850140017847863, 50.22531463253883, 74.4379331219581, 74.57903646653699, 6.523951811175193, 0.5458016705609138, 0.17179674919574492, 0.11856247911289816, 0.07724450750937385, 0.07466550315580062, 0.10442673964726348, 0.2719880261969182, 0.20639639017322373, 0.21524306627050524, 0.15910251907283263, 0.23832250686903156, 0.18430158706201663, 0.2712113049722487, 0.15721336157331545, 0.26196477694376824, 0.1492583964981379, 0.27683837399367367, 0.47427939551491893, 58.7734849991337, 75.80786012834119, 66.0616723952755, 28.27104195471733, 34.367219094307195, 72.0031375269736, 50.66818552632486, 33.40094320235714, 51.9175192617601, 36.96360849565075, 26.725302550100512, 35.695204196437714, 70.44661552675309, 66.84360473386704, 79.51495493611982, 29.17385978083457, 2.707949944080845, 42.158313182092485, 58.720387874111054, 74.01040261791599, 70.13471649539086, 74.3517194255706, 66.53682047320952, 61.11935261757144, 59.19501819918233, 64.99332858670142, 59.858553794122514, 61.84623449079452, 54.93663818605485, 60.23732531455256, 55.93497553179341, 53.393444399679865, 56.54904611649052, 55.02382070787492, 49.97695407559795, 53.72387663010628, 51.71031613503733, 54.519737305179724, 51.56350966422789, 50.54654890491117, 54.82434072802144, 54.820606631617395, 54.03895670367826, 53.67642771813178, 51.736568558600645, 52.67122230222149, 54.4347160093246, 56.191463239731334, 51.515856789004424, 55.28572913139097, 53.75976631718298, 55.30825922566076, 55.49669773347917, 57.15228311477169, 52.40853332704114, 56.29369981827275, 61.552672539987874, 62.424482068707874, 59.81578426976358, 57.48336645864672, 64.93825066474177, 50.44636764834004, 45.553642319094756, 53.94689475336383, 40.360753690042806, 36.34201872733332, 35.50058795559791, 44.85582128647835, 56.96913588431574, 51.61607726927727, 53.17918885138727, 49.294394985322036, 45.47495565106792, 46.57869885044713, 46.52666468774119, 47.47466625705842, 49.2465812929215, 42.859013234415364, 38.8780193175039, 38.26480380950436, 39.07291404662594, 38.06038556560394, 40.51068236750942, 48.915478337195616, 45.85251908148489, 52.51253104978993, 47.1450145782963, 18.108949622800274, 26.276540256315663, 39.35352825349377, 45.77131032943726, 41.78601749481694, 47.334104199563306, 57.866723229808194, 53.73372570160897, 55.288914095970895, 58.260580185920965, 53.729411094419426, 53.52318071549939, 52.78860315199822, 51.7034206082744, 52.12511070312993, 51.02515651333717, 54.38767110147784, 52.29541217127154, 53.668802630516794, 54.72890161698865, 51.91775068160027, 51.12534953701881, 50.811446174498535, 53.7166202452875, 51.81592202955677, 48.6744055440349, 49.576833094319994, 50.47169047017252, 51.04451341013755, 51.25144197094826, 51.149860428225615, 51.98611759370374, 52.28108375303207, 51.783601699336884, 60.780569661048155, 63.36893781538933, 65.93592905229139, 66.20063412574031, 63.173980328344534, 61.27801641341179, 67.89888704976728, 67.37840421738164, 71.5828634077503, 68.46421041796285, 58.81992586197392, 63.65800080760833, 59.79352874140586, 65.78658480798045, 68.9125608628796, 73.34358399914157, 64.02162805680307, 45.82692561611053, 4.191312876439864, 53.449244037751235, 55.8980268047702, 62.423230832622906, 31.666267148910034, 14.933220263450378, 39.805887360726636, 83.7818661043721, 67.92453935069423, 50.29633698924896, 50.97162008285523, 47.99801634204004, 45.358716211011334, 55.99178714136924, 36.7966841882275, 59.25219458918418, 84.18403456288, 86.23879171186879, 8.974171146269768, 1.0160986346102532, 0.3060968346413105, 0.25526772824025923, 0.23696674574767393, 0.19178874820711153, 0.2611956859548246], [0.056987848102806084, 0.25280437251973537, 0.08204512853896426, 0.09929771204629254, 0.05829217408092753, 0.07054699149223105, 0.08691617603143377, 0.06573079589514003, 0.03975559656898822, 0.04017185427308564, 0.07565569478057085, 1.1192209946532403, 52.16853526330764, 55.95494824071085, 40.67913639929987, 40.870230351724935, 48.021150481316354, 43.93859855590328, 48.00962263537992, 20.564257252600886, 59.58936545156664, 51.724821059934555, 11.755013927336663, 22.471213609941547, 52.81306305239278, 68.0497492513349, 56.70527804282404, 64.78434078155026, 4.921533667272137, 0.1304295334604479, 18.859616748748287, 69.24316175522344, 67.92402944257184, 63.12245999613116, 62.632732468266646, 60.341797644092196, 60.985913584309245, 63.24677951874272, 58.82413456516882, 55.64597921986734, 52.921194953303186, 49.004869153422696, 49.30434996081937, 49.65042068112282, 48.981621265411384, 45.81921815872193, 48.46996376591344, 49.07549927311559, 49.04287692039244, 50.12734167037472, 49.31413235202913, 49.24491428559827, 48.91513316862045, 50.33033217153242, 48.95822432733352, 49.74261991439327, 48.49378039759975, 48.43911824687835, 49.195206088404504, 47.3824474119371, 48.31502622173679, 47.463844437753, 48.049175816197554, 47.19657413421139, 49.28028229744204, 49.253108116888235, 51.33520026360789, 53.415370448943115, 54.37995972171907, 52.01517451194025, 54.38627081532633, 55.33203663364534, 58.236653727869836, 36.56552322449223, 33.07089536420761, 30.326273710496967, 24.282242521162956, 18.195463380505963, 18.854421569455056, 40.21323727023217, 52.62449510635869, 50.9761857217358, 48.01459620075841, 38.88384795957996, 35.244437571494814, 37.014662065813624, 37.68268877460111, 39.39275195521694, 40.56727040198542, 38.97453708033408, 34.90444652495846, 34.09829355055286, 34.316373409763465, 35.41586083750571, 36.33720597913189, 38.611388360300374, 37.03697642972393, 40.07722516213694, 27.911550844869307, 8.586234027339566, 8.488316958950412, 25.579393871368904, 31.37041453392275, 28.83667911252668, 36.59635305404663, 54.695753666662405, 47.31051114297683, 51.62753843492078, 49.47092517729729, 49.91247815470542, 48.550109555644376, 50.07050652657786, 45.29755077054424, 44.85320898794359, 45.53495614759384, 48.24601996329523, 45.48818580565914, 45.66988175915134, 46.95930211774765, 47.26134031049667, 45.73981761932374, 47.5365573360074, 47.39927437997634, 47.09562801545667, 45.30544257933094, 43.38037075534944, 41.81610991877895, 43.870682716369636, 44.79018826638499, 45.068433361668745, 43.747618352213216, 44.503000167108354, 49.0418061133354, 53.50874247089509, 57.36514229928294, 59.31615667958414, 56.111340984221435, 59.855231546586566, 55.86741270557527, 60.8966875076294, 64.07019876664685, 64.87996816635132, 58.31426958883963, 58.79086502136723, 55.948354736451186, 59.90874836521765, 58.482201945397165, 68.00011557917442, 56.42799785060268, 65.91191630209646, 13.34120963850329, 11.201955810669931, 52.73128163429999, 37.14365705367058, 62.45579827216364, 15.246136169279776, 4.93128958248323, 30.534041658524547, 53.62083596567954, 74.1828457001717, 48.715555129512666, 33.31274478666244, 30.10913129775755, 29.662491006235925, 30.96638491076808, 30.863826697872533, 29.80044664875154, 61.121051003856046, 70.55026808092671, 18.287484145933583, 0.7092313913087691, 0.22091522722715334, 0.10730546824033223, 0.018506633050199, 0.07386806691365858, 0.08715973836520026, 0.056049512969630386, 0.03352056400129392, 0.027821404190974373, 0.10192959944927886, 0.03213048405614832, 0.03686984678009345, 0.09931894034267434, 0.0897335333208884, 0.06983633002927227, 0.03407408933966391, 0.13574143390982382, 1.837451957887219, 66.84523643985872, 64.80372905731201, 48.481240580158854, 37.31979108625843, 42.63481447773595, 51.79339585765716, 45.20616346789945, 24.773827291304066, 54.65361956627139, 59.30184395082536, 24.310171757974935, 23.01264778260262, 56.522730935004454, 71.34915290340301, 62.95361372732348, 70.31988374648556, 9.25359099142013, 0.3179799615135116, 14.924719506694426, 69.23302635069817, 69.55487251281738, 63.62325253025178, 62.83997089632096, 63.03362615646855, 65.74837700013192, 64.94205144143874, 60.0181628811744, 60.319691165801025, 56.42691527643512, 54.05220254775017, 52.625118763216086, 52.43513484154978, 51.30935968891267, 48.58415572874008, 49.23870125124532, 51.158921103323664, 51.03062429735738, 53.59711739324755, 50.07909259488506, 49.8718463220904, 52.112261018445416, 52.29168591960784, 52.590943151904696, 52.0994701693135, 53.83820979825912, 51.56833810191001, 52.8207822768919, 51.42620317397579, 52.11806612630045, 51.960257407157656, 50.55311495257963, 50.99574658178514, 52.09707752350838, 52.64843333152033, 57.1192136118489, 55.764262214783706, 55.93659547067458, 56.285184352628654, 59.14925590638192, 61.0371946519421, 59.59439785249772, 33.31338413300053, 32.9991199124244, 27.69183731848194, 25.18251276785328, 15.220859435296829, 18.540096552141254, 46.22001378766952, 54.659918892768125, 45.68296286367601, 44.06596576013873, 41.56769837102583, 43.7605700185222, 43.45175789248559, 41.71616792678833, 43.752003562065866, 45.187457684547674, 42.288194625608384, 37.346035665081395, 37.61012884878343, 36.23192171896658, 39.63589183745846, 40.230840867565526, 46.45871746924616, 41.805401848208525, 47.598856341454294, 36.54591529600082, 8.006217950774777, 4.5631623941083115, 31.253114092734556, 36.53113580519153, 32.06276386014877, 36.48955868136498, 56.12584198674848, 52.161184741604714, 54.01308867239184, 52.96490192413331, 53.755710586424804, 52.224860498982096, 54.02558142139066, 50.317145163013095, 49.66035212239912, 49.1280629557948, 50.876090757308475, 49.3181880827873, 49.59942986888271, 52.08416508090112, 50.66619296227732, 48.28123892507246, 49.85392109040291, 48.88728041802683, 49.4608642978053, 46.87988588886876, 49.49593813188615, 47.30311355283184, 46.81287611684492, 48.63236558052802, 48.98222531041792, 46.30427022134104, 48.10492054108651, 52.482658278557565, 57.430822387818374, 58.23063288965533, 60.85518490883612, 60.034832954406745, 64.00285951552853, 57.055235831968254, 63.37487628383022, 65.1396055375376, 68.0955703796879, 63.83710015204645, 64.14883444386145, 57.1395589459327, 63.864976436861106, 62.67433312631423, 74.58710870435162, 61.01454688656715, 69.82734387920749, 9.1407444015626, 16.74860888911832, 59.56564687913465, 38.25914775171588, 68.75919618914205, 14.937721183223111, 7.30500259707051, 37.48187518888904, 64.73911193109328, 58.51900946709418, 36.36775732040405, 41.45153737837269, 34.7098655854502, 30.258830516569077, 39.54844259446667, 38.60072735817202, 40.08079451899375, 68.71383005572905, 81.12452307055074, 27.343364146447954, 0.7363879824838331, 0.24380749722401945, 0.14504704263902482, 0.12595338131030723, 0.031229514861479405, 0.04903565626591445, 0.19888748745283774, 0.27445167303085327, 0.14634292632822068, 0.24058609750242005, 0.13131497788333124, 0.24785302369104278, 0.31884395547451516, 0.2761046149797978, 0.18895330358176463, 0.24555851374903034, 0.16572116633817074, 2.1009209944355876, 75.85763500582787, 73.78919662967806, 57.7621449962739, 50.016671995962824, 62.39546829654325, 58.06038241232596, 62.353546004141535, 25.00461562987297, 67.5287800450479, 55.836720158976895, 21.633418875355876, 35.789674482037945, 62.67538824389058, 80.46435679158857, 67.37427003922002, 76.19735933119252, 6.332654876093711, 0.25242826931418916, 23.822272054610714, 76.09392642974854, 72.21835013358825, 68.09241679406935, 68.003998725645, 66.49773797681256, 67.51387503839308, 68.48779955217915, 62.66967727291969, 62.9958458869688, 58.89814576795025, 57.0002834258541, 58.01306686093731, 54.372228730109434, 54.356700066597234, 51.76147168682468, 53.335734567334576, 54.514069480280725, 53.50260788394559, 57.39177127038279, 53.172265868033136, 53.191112856711115, 55.238441036593535, 56.064386290888635, 56.59786001328499, 54.26856833119547, 58.4076847568635, 54.533073363765595, 56.030155766394834, 54.528307684006236, 56.874708744787405, 53.9834394762593, 52.19301477555306, 54.37238170254616, 53.8912167087678, 57.07652253489341, 58.012231396090606, 61.04038746126237, 58.79302624733218, 58.74061553708969, 58.66428621353642, 59.79083015072731, 59.09714329627253, 41.67444959763558, 48.8096998583886, 45.16366850945258, 36.97570116289201, 25.71362130103573, 26.108305877254857, 48.945107921477295, 53.95195461088612, 50.023512609543346, 47.95909858519032, 45.03951372638826, 46.147034168243415, 44.694651096097886, 41.358149666940015, 42.61991339345133, 44.36835304383309, 40.59088699279293, 41.90815617961269, 44.37947688564178, 45.96821331208753, 46.67477730781802, 48.93652185317009, 49.38903785520985, 46.088790893554695, 46.970233763417895, 42.074076360271825, 17.12828451587308, 16.493688168064242, 33.40786226334111, 47.64134345516082, 41.45804851285873, 42.976696106695364, 58.091996715914824, 52.55253922554755, 56.63853106960174, 53.159659370299316, 53.54675808260518, 54.8387985844766, 56.778328264913256, 51.83190176563879, 51.62925643305625, 50.97883332160212, 53.877943408104684, 53.51279035691292, 52.60385951688213, 55.28494857972669, 53.71535724209201, 51.92812535070604, 52.73169348316809, 51.68860581613357, 53.39653522737565, 50.80148727663102, 50.407089033434474, 49.44985028236143, 49.560292459303334, 51.41476162018315, 51.71536422544911, 50.0977473874246, 51.578249931335456, 54.9479228450406, 60.63513601979902, 63.043992980833984, 64.43785821237873, 61.457323643469046, 66.80125882548671, 57.766702790414136, 65.4595022816812, 69.97707643816548, 71.73094857123591, 65.44239290298955, 65.11818155165642, 61.171182817028416, 67.15963794339088, 63.56326380083638, 75.93341519755703, 63.89758702247374, 75.91079096640311, 16.720271725808423, 13.680454454114361, 70.11261786184004, 43.3014016766702, 75.14724669917938, 25.294725894927982, 12.369767985036297, 39.73588482026131, 63.39054223029845, 79.48838480057256, 58.48917591956354, 44.66084026521252, 42.08674953829858, 41.079296604279556, 46.95084548765614, 44.78878798023347, 46.395147615863436, 75.68417995206772, 94.32643659653203, 33.49246778795796, 1.0073136285908761, 0.3889006430343274, 0.2647298640541492, 0.1372191715504854, 0.180831806313607, 0.1981660930980598], [0.05525516789226283, 0.10691119342922203, 0.06625397266038964, 0.0728493768181051, 0.2142332398122357, 0.07555480100094311, 0.06802217253754217, 0.13275851735905295, 0.02798049383977008, 0.04726914561263496, 0.04768562931267004, 3.3549603483369275, 69.37669492536976, 52.50914604433122, 49.10040240133963, 39.33922729184551, 36.08558201020764, 42.113778591156006, 43.001920869273526, 44.205288348659394, 91.86946392059328, 64.80988325611239, 5.476830476714719, 7.249040670933263, 31.392350389111428, 66.37259867883498, 57.01987566486482, 63.3133029168652, 34.273568584072976, 0.29881170620360686, 2.1600933805588753, 64.19360045463809, 71.45475879792245, 65.94324035029258, 62.84084558486939, 65.5612564086914, 63.879132270812995, 62.43037346870669, 62.10163570219471, 58.67446476413358, 53.388074674913966, 53.931781861089895, 49.96684220529372, 49.16222679999567, 44.98340422107328, 47.78288610519902, 46.50198513461698, 49.96058994723905, 47.34384736707134, 51.44161024401265, 47.77498645167197, 51.891211925014375, 48.21903797887987, 52.28579059723885, 48.313139561683904, 52.62083945735809, 49.403668295952585, 52.155403167970725, 49.250703703972604, 52.77428257849909, 48.38611525873984, 50.70544804296186, 49.650801151029526, 49.96688535136562, 50.244887259698686, 51.98301892126761, 49.571463369554095, 54.09784716944541, 54.133066131222634, 57.078071871111476, 53.012797986307454, 56.87291229924848, 37.188313238082394, 5.0097090390420735, 8.359915229582018, 3.7040927237079995, 4.811027261518664, 4.958573589401861, 10.813221470002206, 43.874750214238325, 45.104483865922504, 62.61564662379604, 86.50304179037772, 47.02054992798836, 27.72403605522648, 34.594830313036525, 35.673929260623076, 40.28756618499756, 39.47381557956819, 40.85743165785267, 34.76118195441462, 41.68161184557023, 42.038186673195135, 45.61445082387617, 45.62717499271516, 55.82118365072436, 42.84371206837316, 29.770871977652277, 38.766008192493075, 9.06192535354245, 1.595684414909732, 7.089119755452679, 7.991124180055435, 10.166838399825558, 15.299157788676602, 37.53328177236742, 48.92163253599598, 47.4728423549283, 49.78913922463694, 49.84716676896619, 49.91818128093597, 48.40034169535483, 49.46296668821766, 48.83009618328464, 47.872214163503344, 47.29387244870586, 48.41934950120988, 45.635047189651004, 42.94595256928475, 47.383616278248454, 44.45286835393598, 47.905475862564586, 48.33853298617948, 46.663677000230365, 44.86205001031199, 45.090057388428725, 44.63894167254048, 44.704704130849535, 44.603224569751376, 45.846898325027965, 42.56852249945364, 45.00637362080236, 49.6691539210658, 53.237392902374275, 53.68100512412287, 57.24861260383361, 57.73432362464167, 60.45830772769067, 59.12040295139436, 56.52182486749465, 57.79151178175404, 64.13798909033498, 61.7896778352799, 61.15632880118586, 56.6664622675988, 60.70759396399222, 59.69357498230473, 62.66979102165469, 61.86677594338695, 54.6641864315156, 3.7738640894812927, 34.06097612073345, 44.60495041262719, 58.083594999005726, 58.91066597354028, 4.263322199544599, 10.307420069171537, 16.952352485349103, 45.4532806334957, 58.760070493144376, 57.99673411153979, 37.62517506076444, 29.300664124950288, 21.02030142661064, 35.57339106836627, 23.03628790763117, 26.503563119519143, 58.04934486266106, 65.00544478816371, 28.619607302450365, 0.4820922972454179, 0.2704718462642162, 0.07037308953341938, 0.056881783229689446, 0.08898668186438662, 0.04507690840851396, 0.10265915264045039, 0.11303316291061141, 0.011306640921130536, 0.0395629292864713, 0.1980330849126462, 0.10893586422166518, 0.0710406968550336, 0.10353164251653418, 0.08814675838596399, 0.03264393725041901, 0.1592824578044876, 3.6328340441949907, 76.92371952918269, 58.05880561951668, 55.107547621573175, 36.509645139017415, 39.364483433385054, 46.84369810165898, 40.25589304585611, 33.98996945350401, 80.60430695933681, 56.26335636261971, 16.723087987592145, 13.308710840440567, 28.071208961548347, 73.63386292611399, 63.471849041600386, 64.8423840153602, 44.35474241933515, 0.8918551692078192, 1.3524814070232454, 63.17808312754478, 68.13828499086442, 68.759627649861, 64.51044167241743, 66.17948470577117, 64.91756016208281, 64.21104323479437, 62.71635740034042, 59.835906028747566, 54.74407334481516, 57.078111094813195, 55.92369087280766, 49.074279415992, 49.865468548190215, 51.75913395420198, 48.720850329245295, 50.72853511379611, 48.95795368379163, 53.67223470441757, 50.54025742315477, 54.22493196302845, 53.09871750493204, 53.99490848664315, 49.705482913601784, 53.3304472123423, 51.00086919723019, 53.69123858790244, 50.131432702464444, 56.903396960227724, 54.1024245754365, 52.212654083005845, 53.82569351503926, 57.53026231642693, 55.0121634237228, 57.56441439351728, 57.433050294076246, 59.01445188829976, 52.88993366302983, 63.399324417114265, 57.50573965810961, 63.910617136186175, 29.630964955975934, 3.6623111463362172, 10.04621865287904, 8.7283875865321, 8.922826340121608, 8.174742094932064, 17.731688214886574, 48.17583307143181, 50.24734658579673, 60.256670444242424, 70.75009715172553, 45.412852764129646, 38.64525018199798, 38.93868661695911, 40.35843949164114, 41.45265133150163, 41.718529193632065, 43.10829162597657, 40.94333156462639, 46.92461659831386, 47.878827279613866, 48.41790606898647, 50.53426404153147, 50.10442718382805, 44.39020456806306, 34.95357813373689, 44.15089684147989, 12.472207546234133, 6.2750367291512035, 10.847646151819538, 16.848682280509703, 19.99721392508476, 19.70626623399796, 41.25305368054298, 54.92057215782904, 53.651187266072924, 56.684536549352835, 51.66596197312879, 51.9119377290049, 51.88022144379155, 51.97347579463836, 52.03592777252198, 50.78534280100177, 49.97937810036444, 52.87447167981056, 49.226024150848396, 49.655743337446644, 52.472499339811264, 49.20110925551384, 46.9887512730014, 48.37025711613317, 48.40045544408983, 47.478447421904534, 49.31315960422639, 50.00368110595211, 49.150153744605284, 47.46508782909763, 47.79099756671537, 47.402529947219364, 49.61370729630994, 54.31666051187823, 59.03830774368779, 58.66778496773013, 57.814430190670876, 63.066115148605846, 63.99557959648871, 60.35680855474165, 59.96832524576495, 61.99267618117794, 65.5429389399867, 65.05456462983163, 66.41088101171678, 62.171516649184696, 66.47145809665804, 65.5331212474454, 71.03148014314714, 70.67719597970286, 46.42753854874642, 4.394409281592216, 42.762220905673125, 55.34049718610702, 65.03494885659987, 54.30445409590199, 4.2152937573771325, 16.67245214985263, 28.0704362546244, 54.50035295178814, 57.2733941385823, 36.0004077419158, 40.167867214449, 36.03285751035137, 26.4963577255126, 40.97970762560445, 25.134055806744485, 27.879771801733202, 62.29740904223535, 75.2758063039472, 36.84813391777777, 0.38562650582002056, 0.22592456891171395, 0.0980779545141324, 0.01580251887771151, 0.17054571229363644, 0.028027085392105005, 0.14550603655797822, 0.17828176008357158, 0.07206738490851657, 0.13736373234179713, 0.22091478289615726, 0.163188494982258, 0.10015863399471968, 0.21840302574057735, 0.15033853450609794, 0.2657031940837061, 0.45023790170108124, 5.346952465272719, 92.70445023813556, 66.31454760028471, 64.33406837524907, 50.59325648892311, 51.36903855108446, 55.581530755566014, 57.33365743390976, 55.80278773461619, 98.36568555524273, 65.99128938490345, 10.753003281931724, 19.025717358435354, 40.8447035666435, 78.87756193837812, 68.41799705259263, 74.90073357858967, 43.35068233551518, 0.30957527218326447, 3.083304834942664, 69.7922622003863, 72.85775922959851, 73.57434488111927, 66.65691560314548, 70.85830750003939, 69.0203554399552, 68.30153403743621, 67.25730496068155, 64.47461082089332, 57.84725258427282, 59.202203981338016, 56.8887508300043, 51.89113347761093, 52.52718894712387, 54.68188808810327, 51.6400743299915, 55.47433630112679, 50.921574561826645, 56.956164606155895, 52.74737904148718, 57.17546432249008, 56.21269502947408, 58.494023969096524, 51.87106663180936, 56.977647427589666, 54.89370784451885, 56.036145225647964, 54.219295517090835, 55.90525965536795, 55.36120337824668, 54.014469346692486, 54.68246859888877, 57.09107060586253, 56.71690787038496, 58.88495875943092, 57.735755289754565, 60.20455391176286, 54.65828326440627, 61.0809604583248, 54.991308181516594, 61.79655375019197, 47.3508527201991, 33.69915316181798, 19.413643690847582, 9.950607938151206, 11.48802113148474, 15.008525848388674, 27.251757191073512, 53.44034810220042, 58.3665547832366, 69.61942688111337, 78.44919204711914, 50.21251593866656, 42.30813203319427, 42.60069770197715, 40.637323933262984, 38.45272456446002, 36.500211838752996, 36.42860897125737, 37.63376505144181, 45.11493306006155, 48.12461083935153, 49.62061066781321, 53.59324601388747, 52.722217036831765, 47.89518356323243, 39.23234662702007, 50.04341863816785, 18.718921330667314, 14.058777843752216, 8.590524119715537, 20.703803416221373, 30.869527862917995, 34.80043311272898, 50.80162063721688, 57.2290321319334, 53.601604584724676, 59.736497479100386, 55.10111885686075, 56.94581347127115, 52.297906798701135, 53.69404308257565, 52.34599113464356, 54.57813355230517, 54.070127779437655, 56.97944779549876, 53.298048434718964, 50.816796287413574, 55.39027598596389, 50.01366746041083, 50.710276480643984, 51.511538259444706, 50.66603214510026, 50.40599076978622, 51.554951052511896, 52.02154051872992, 49.641799311484064, 51.489984835347826, 51.604514122009284, 51.076300298014, 51.89451848306964, 55.151956696664136, 62.697898726309504, 60.84430033160795, 61.87190640357233, 66.98925018310547, 67.44568071057721, 62.14558978234569, 59.345013556941865, 64.45435177895331, 70.94880442465507, 69.86418277986589, 69.80938726855864, 63.4903077156313, 67.32321646905714, 67.39721590472807, 73.30519183989495, 70.62541284868794, 62.10585225012995, 5.963917759156996, 39.9473633304719, 63.77375779613372, 68.80591946263468, 69.70669177270705, 11.213417956905982, 18.466456013341105, 23.84661428390011, 54.9908531865766, 64.36417648869177, 70.34946626232517, 49.57377364558559, 39.752547048753314, 30.260109209245254, 52.64444428105509, 33.07749279083745, 38.93912592241841, 74.76101875305176, 86.47607941781321, 46.347051512810495, 0.6706630318395553, 0.45921200886368757, 0.21985022711657712, 0.1336009536058672, 0.34516970897393845, 0.12112600849040094], [0.068939057208838, 0.09884696123340438, 0.1003538255369471, 0.13368568293029262, 0.1466424207413389, 0.07161868721126549, 0.29329480062569346, 0.07297613372605655, 0.04487114485293146, 0.021749569418569727, 0.19954943338469153, 2.2412354523135773, 54.31284796807074, 62.539223163358635, 41.36686125109273, 26.95268431017476, 35.16175400826239, 38.32678902533747, 43.50276047183622, 47.9315007886579, 73.27746852751702, 52.91378951841786, 16.95456862449646, 4.921410112611709, 7.368835249254781, 45.57744718367054, 64.12793997795352, 58.021896116195194, 54.97868991667225, 13.227434427507463, 0.0682759621450978, 31.192231062919866, 80.21112072852351, 60.617030359083614, 69.32204846412905, 62.083486895407404, 66.72876557996197, 57.713703724645804, 65.97533318304247, 58.31998840455086, 53.059203547816125, 52.77278815546344, 50.410207317721465, 44.22749680857505, 50.02641516347086, 47.438545150141564, 49.36222061034172, 46.71779786386798, 53.04425539508943, 50.0803477533402, 50.65900325775147, 50.743828435097974, 52.16076112562611, 51.84449257389192, 51.22529937374977, 49.340322017669685, 48.867739169828354, 46.43791714022237, 54.20739112361785, 52.93311111388668, 52.34070770202145, 51.39667164894843, 53.20599432914488, 50.4396721624559, 53.77164717643492, 50.211605948786584, 53.77592255992275, 52.45022419960269, 54.6510817927699, 58.38326408017067, 58.12337959966352, 39.64830221668367, 0.8161071531714932, 5.0181661594298586, 0.9107341497175155, 0.8650524493667388, 1.7796483563800014, 3.5969845614125653, 18.565764542548887, 29.365999044910556, 42.525380349928334, 57.689451709870376, 73.75992005871188, 48.66781596214541, 27.929199549459643, 32.77878272917963, 32.150320968320294, 33.56270174826346, 36.97042165264007, 28.521920673308838, 33.82168800600114, 34.32441819098688, 41.07402493876796, 46.59322730956539, 24.418409562879994, 64.55290525190293, 91.76468172381001, 49.41740835866621, 23.761977380321873, 14.15586042788721, 2.6365807027586046, 1.366213502422456, 2.4152764101182265, 8.248755258898582, 5.584924624812219, 13.863818395522333, 35.577893949324086, 47.36508307918426, 48.65064382553101, 47.5049901008606, 49.41619242391279, 49.24518885151033, 51.03070274476082, 48.35290062812067, 49.297442666945926, 47.69488773038311, 47.75231515207599, 45.39932058703515, 47.666513304556574, 49.00004463811075, 48.23654351695892, 47.24649413939446, 47.44121236185874, 47.11048987603957, 45.07060243237404, 45.3569354549531, 45.69303158790835, 46.65109795908774, 46.01759987492716, 44.318295755693995, 47.006409783517164, 42.721059553084835, 51.50461919846074, 52.375385376714895, 57.22811429731308, 54.61455668172529, 59.406963471443426, 60.959221855286636, 61.37763677104827, 59.387230027106504, 56.72656082337903, 59.98280271407097, 65.30363905814387, 60.19170030470818, 62.5149711485832, 58.97820134316722, 66.71509219754127, 60.65896441859584, 65.96605285521477, 16.510489640697358, 3.980050341736886, 55.65311793358096, 40.58108106736214, 63.65857739602367, 29.933305171228227, 1.606214507933586, 10.900501070484038, 27.540941776767855, 36.191466393009314, 36.812205006999356, 41.01791935582315, 53.96151342699605, 26.21935994394364, 34.147331022447155, 42.24400912561725, 46.1694505137782, 33.3311132461794, 46.94840185103878, 63.32194389835481, 33.3909607702686, 0.4169944048889222, 0.2513973294727264, 0.04441379419257564, 0.13807027991260254, 0.12015802575455559, 0.08358548620655652, 0.006177968593434461, 0.21090022108006864, 0.038925367933247364, 0.30432891821668995, 0.1511327378571995, 0.008681942295703677, 0.31231320913760896, 0.05842553466678627, 0.012744891517344984, 0.3074405222169815, 0.19669420836913973, 3.42819957963882, 65.6862231223814, 66.91929863345239, 46.61114861888271, 26.282957253917573, 44.90982840138097, 40.39014793211415, 45.24277879345802, 52.0596424225838, 78.94488550001576, 44.085161839762044, 12.24020621468944, 9.99771168155055, 8.058207986816283, 50.54799233713458, 73.69388303449078, 60.2970394780559, 63.871342443650775, 19.928025276430194, 0.06709639358544542, 25.693656436858642, 78.38655179546726, 62.01535532551428, 71.64424065620669, 63.60239336567541, 67.71987007510278, 59.27540717586395, 64.34578841732394, 58.861887378077355, 58.32847641360376, 54.34512515221873, 54.18392750524706, 49.0817750653913, 52.47477431451121, 47.62257883625646, 48.86396192735242, 47.03846339256533, 54.324842576057684, 51.77544709174864, 53.17355632781983, 50.81669822815926, 55.55031653373472, 52.66034164736348, 54.29097290961973, 54.00993508677329, 53.73535348523048, 53.04291786686067, 57.675888153814505, 56.15385555451917, 57.93809467746366, 53.79623651504517, 55.105460920641505, 54.46042714580413, 57.79748947389665, 58.027724758271255, 61.25649829064647, 54.182111447857274, 55.47550124506797, 56.11980545905329, 62.80881943241243, 40.187251567840576, 3.6110055638897807, 5.269200301939442, 6.021875681415682, 2.1077765620523885, 3.272551596164704, 6.5599969221699626, 23.821640553012973, 38.613792773216005, 42.22218505797848, 50.76963763083182, 65.15092549785491, 50.018135040037095, 32.93553044719081, 40.673354825665875, 39.330664757759344, 44.43252694222235, 44.69238004376812, 40.1161233071358, 40.689895460682536, 43.117662168318226, 50.199426989401545, 49.651405196036066, 42.0093023392462, 55.85813237774757, 74.26545081600067, 49.58789025583575, 35.681726932525635, 17.496895136371737, 4.205687382528859, 8.806227022601712, 5.665769086730096, 12.543145571985553, 10.562580054806126, 18.485163757877967, 43.30074271848125, 55.26840009996968, 55.995980155083444, 55.42159611178983, 53.99286493178337, 52.02301532991471, 53.75356504994055, 51.94409331967754, 50.70748767545147, 48.08899179581673, 50.690339073058105, 49.536397380213586, 52.68371112885014, 51.870795988267474, 50.89562023839643, 48.15458559220838, 47.796371213851444, 48.6147423713438, 48.49770669014224, 50.09795527304373, 50.90243339538575, 50.46447330905546, 50.38429221799297, 47.492332612314534, 47.81047605699109, 49.12060653009723, 57.0582325227799, 56.35106448204287, 59.772657809718964, 53.7895449515312, 63.303610740169404, 64.24776054197743, 62.99575567245484, 64.5430326461792, 61.275298210882376, 60.715654434696326, 68.04290863775438, 65.02718256365868, 69.99982618516492, 60.41927622210596, 74.3898448636455, 68.35747488083379, 71.29774631992464, 10.394571212030227, 5.788875616365864, 65.83273149305775, 49.343283407149784, 71.17565078120079, 29.80552611812469, 1.791455303469012, 17.99872317621785, 27.626792653914425, 45.48579315985403, 44.84127321550923, 29.995980724211666, 51.151841225162634, 26.801780923720333, 41.052561729185044, 46.843046988210375, 43.552005829349646, 34.773525653346894, 52.75092486412295, 74.0186474400182, 41.2293194186303, 0.4275567655361468, 0.1828380833349882, 0.11251441413356413, 0.10743962555763223, 0.06982436373589501, 0.02293617258058681, 0.2813048810968476, 0.4650225099777022, 0.1477353217741174, 0.36324972106564435, 0.3523212010341306, 0.1465769355455714, 0.942516502353453, 0.21765114108641304, 0.24511229817665395, 0.40088035827202184, 0.38071395168381356, 5.537486499355686, 81.14587645376884, 76.29188845234533, 56.905248318949056, 34.17796081112277, 50.62100333552207, 50.962630010420284, 57.956714168671645, 57.803216134348226, 88.48528215962072, 57.364855966260365, 23.520579030436856, 11.270914020076876, 16.313837689738122, 58.709420927109264, 76.67858708289363, 64.15376486316805, 67.40953214706914, 16.89525846512087, 0.1826809127364428, 40.54610137016543, 82.9419925135951, 64.8189203969894, 73.83226425417008, 66.39318327749929, 71.16105956415977, 62.414499636619325, 70.94681186060753, 63.78549745005947, 61.72489596951393, 58.93320783492058, 56.921365337987105, 49.51676199513097, 56.49481150411791, 51.6705080001585, 53.46240751204952, 50.73545417478008, 59.98694473697294, 56.829228862639404, 59.7798788932062, 55.45859190725512, 57.76882087030719, 56.9901401765885, 56.767471144276286, 56.83676373574042, 56.30199955355737, 57.926535452565844, 60.54191697028376, 59.21259433992448, 58.90312717806909, 56.49625101397115, 55.768933757658935, 55.10338990919052, 61.018077019722234, 57.99262738996937, 59.793175728090354, 56.54233494112569, 54.374346810002486, 61.76979141850626, 62.43789265232702, 55.8576616933269, 25.501921176910404, 4.876244510373762, 10.44740455765878, 2.6717410741313814, 6.734027093456638, 5.522454505966556, 27.94231595531587, 50.137598668375325, 48.68523520808066, 65.34382766292941, 82.59056383563627, 56.23654304012176, 35.07579134356591, 39.538111071432795, 36.6399541208821, 37.29413486296131, 36.211309663711056, 31.708405171671224, 37.78631387218353, 40.59830027241861, 46.237480102046845, 51.54110900817379, 43.92570964751705, 58.360949716260365, 82.02444030392556, 56.260602858758745, 41.88506910877843, 23.82819483357091, 2.543774727852114, 8.066936731338501, 7.124015611986961, 17.80212417725594, 16.453150472333355, 32.85836958116101, 56.01846710328133, 54.242296295781294, 57.03966010001398, 54.04405578490227, 55.09637671132242, 52.57414364045667, 53.93979918572211, 52.049848264263524, 53.57130427514353, 53.03658323903238, 54.79169484107725, 50.64359226534444, 57.87366190264302, 56.39211208589616, 55.124445192275516, 52.14976279966293, 49.83495250824959, 51.63121369577224, 51.03692754622429, 52.27898136261971, 53.719895424381384, 53.14518974673364, 52.734388151476466, 50.898091331604995, 52.194803376351636, 52.084074866387155, 58.455459225562315, 59.17772054672242, 63.44890317609234, 57.177927570958296, 65.16343001396426, 68.6435333375008, 66.79209616876417, 66.18473283706173, 61.24663745203326, 62.86421898872622, 72.73958606104698, 67.43347429460096, 71.25413740834883, 65.65476179122925, 74.83905038525982, 70.8117332766133, 76.7001679635817, 22.56795494787155, 4.476696195140962, 69.21452060822519, 54.746030607531154, 78.31674929588073, 41.162984294276086, 5.716392667062822, 17.25015647949711, 38.75714755827381, 44.6813738730646, 46.25353828553231, 44.560153022889175, 70.57505746041575, 33.328893184661865, 42.19104928355063, 53.85234602036015, 62.80544227169406, 46.00609164084158, 65.71695097031133, 84.95863206924932, 56.241202815886474, 0.9997717074809537, 0.3216154164364261, 0.19273661347406526, 0.2708375766392677, 0.23255613241945547, 0.2407092231536104], [0.19518965765112833, 0.03772585044404672, 0.0818900723430899, 0.2629847157626383, 0.10631942115123234, 0.08931818343098126, 0.09401021915818415, 0.2212273314475052, 0.08053989600270026, 0.11020547875593747, 0.11568082406395867, 3.634002665358205, 59.53927286209599, 53.57605034305204, 33.633661347050825, 37.498643321375695, 38.41674858523954, 39.64670973439371, 31.59031633407839, 15.968308256518458, 37.55399580924742, 33.716815594703924, 25.686178438125122, 9.946960133890952, 3.5488374675473864, 23.28559767815375, 67.43923233401391, 57.80934679892756, 56.2773278451735, 47.79410016152167, 1.6895435462074897, 0.767952643575207, 50.283306875536525, 73.79882997082126, 63.53530906861829, 60.972467699358546, 64.25727621201547, 60.5512914349956, 56.34498480827578, 56.41515993302869, 52.98940104822959, 50.17033869220365, 48.80602459753714, 50.53890420544533, 50.487136763911096, 47.23431910237959, 48.813520246936434, 46.721190714067035, 51.54640813027659, 48.47127775992117, 48.19563711843183, 50.98685456860451, 53.1236598568578, 51.121054541680124, 51.884841995854536, 52.8741539678266, 51.23865112181633, 52.83802893853957, 59.640101309745546, 57.72720452277892, 52.50150918960572, 50.41345504022414, 56.05549820007817, 54.54186731769193, 50.472820112782145, 53.778546625568026, 53.286175420207364, 57.372092739228286, 53.90519211369177, 56.71579783962619, 52.11469681032243, 5.8483108012906975, 3.2990768696031267, 4.719266843411231, 1.4665134106912923, 0.2073940664770142, 0.200755792039056, 2.0058089110159107, 9.643493217806663, 19.15315124296373, 54.474418240208784, 35.13629782584406, 24.31032080804148, 33.19640336498138, 27.42188019137229, 23.100030345301477, 20.608929126493393, 22.406141488782822, 23.036270256965395, 21.72315682134321, 28.87190199667408, 30.25549061836735, 22.450050461676813, 16.34270143124365, 17.545805131235433, 30.97053085604022, 54.82527032975228, 79.4447680442564, 31.203088183556837, 14.50156734835717, 5.88536641290111, 0.8517654816950522, 0.9219616279006005, 2.2686128606719356, 4.5425836789992555, 5.061130331408593, 12.869138659969455, 36.26758390857328, 53.04212947045603, 50.57634322874008, 50.67736387252808, 48.69042842618881, 50.80902214973204, 50.36862234915457, 48.01409805974653, 46.468209605063166, 49.0827948816361, 49.9042921681558, 49.10977294368129, 49.69810885767783, 52.07444152524395, 51.539351786336596, 49.07190638203775, 47.633796814949285, 44.511539166973485, 47.751177664726015, 48.81879191244803, 49.66869108138546, 46.79469200872606, 43.591606078609345, 43.63753703332717, 45.237624799051595, 49.45592211138818, 52.76553177064466, 54.68517895667784, 54.80323053175404, 60.23958459977181, 61.63643083264751, 59.73966283182944, 58.2427373240071, 61.58788757939493, 60.57929715802593, 65.12897983674081, 63.740484329961966, 61.37637376785279, 61.378130989689986, 65.5952202120135, 59.33305817265665, 49.256814756701075, 0.5092499915870928, 22.897563480561782, 57.94825361620996, 39.63307557567474, 63.75033340146465, 14.152949048626809, 0.8705724499398663, 25.251424889410696, 60.258223702830655, 36.92268248527281, 19.563193859592563, 20.018520239860784, 43.38883915255147, 30.097938814470847, 30.656470598713046, 36.92176857302266, 34.12738577012093, 24.694891552771292, 44.936167117088075, 58.59641744244484, 31.308044925812755, 0.6007276619634321, 0.29022085750775956, 0.05425099133243484, 0.1353716892340491, 0.30266258505082905, 0.054570005665863716, 0.17549744416629115, 0.18829017787450747, 0.1468858988054337, 0.4433734781078754, 0.15255363177387946, 0.07988204098036213, 0.3454176456697526, 0.30898372973165206, 0.054761715338475285, 0.2908014908673302, 0.13233165316764386, 5.688471765287462, 73.43176672535559, 59.47193361097767, 40.24654211536531, 41.62775378073416, 48.8079426365514, 43.31907195429648, 36.19689103095762, 24.3304229551746, 44.29992729617704, 33.89231812569403, 17.640812781549272, 7.8936611260137255, 7.425712068234721, 27.28941978946809, 76.35385405632758, 63.66521012398505, 61.02912633649765, 59.960755071332386, 3.773073486743435, 1.2050207584134995, 40.36016533451696, 70.53770865163496, 69.67109234102311, 62.65426628051266, 65.63962928710446, 60.387493256599676, 60.67765451246693, 57.843671460305494, 59.0687963270372, 55.13472572449715, 52.2278493450534, 51.25767461715206, 53.21394889585434, 49.26920160170525, 50.41775788030317, 47.969002569875414, 51.96412094177739, 50.682015803552446, 54.57094777014948, 51.49451909526702, 55.14294701237833, 53.46014822683027, 55.32928312978437, 58.13488391137893, 56.77290362696494, 59.125329448330795, 60.42897232117192, 59.08762762623449, 56.696017326847205, 56.15104321510562, 59.31057514682893, 56.52927737082205, 55.92769953512377, 55.36689081499654, 56.049085124846435, 59.35509012591455, 55.89595579331922, 58.260952811087336, 49.40677873549923, 8.141965789179649, 6.005931246665217, 5.327562228325875, 3.0681855688172006, 0.7006625446581072, 0.670497372986809, 6.993309980438602, 11.194856320658038, 25.799891871790734, 57.815732417568086, 29.263809534811205, 27.20698529674161, 39.08544994169666, 35.755373354881044, 28.161831402009536, 27.235901009651926, 29.390809997435543, 33.52340352150702, 30.026908613020378, 35.82036702863632, 37.85095453262329, 33.967051044587166, 25.38721734477628, 19.753189548369377, 36.02806045163062, 47.763140893751576, 66.81466548673569, 36.47661485979634, 17.226879173709502, 12.838236266566863, 2.811833427798364, 0.11422394699747525, 3.335688763087796, 6.170414859248746, 8.066039489161584, 23.447154221996186, 47.34940928797568, 56.848005248654275, 55.95836854750111, 50.82236997542843, 50.097057050274266, 50.252645707899525, 54.06954726865215, 50.32238937193348, 48.92520189285279, 49.43463148609285, 53.1959177601722, 54.711945210733724, 54.39088744501914, 55.34502360128588, 52.505011866169596, 50.82874774932862, 50.9869683173395, 48.46084033289264, 51.825637740473596, 53.63589786714124, 52.60600897573656, 49.527270024822606, 47.477137350266986, 45.92962895670245, 50.25988640323762, 53.541525640795314, 57.45923211497646, 58.93805196208339, 56.87590114531979, 63.298931352553836, 63.982376898488695, 66.88763726142146, 63.37181291272564, 63.44852270618562, 60.54569029038953, 62.85980632228237, 69.31792213070777, 66.67825329688289, 67.12613305737896, 68.7014824344266, 66.52421397547569, 39.629749405768614, 0.5145608501568918, 33.8809314850838, 64.95020212665682, 49.74667172278128, 68.7868881225586, 15.495417502618606, 1.421479453002253, 20.313280474755075, 44.6913053143409, 39.61831177434614, 29.7968674859693, 19.893684925571566, 46.814598037350564, 30.14718221079919, 34.93975570124965, 41.26018847188642, 38.26623939698742, 28.079489084982104, 50.57446833579771, 72.00647154162007, 36.10646470900505, 0.899263668444849, 0.3134862736107842, 0.05726632872416128, 0.1917500301234184, 0.3064531881001688, 0.04614144120545638, 0.2986830953628786, 0.30073253377791376, 0.16194757044074998, 0.5735421433083473, 0.27920405350385175, 0.25654422990497083, 0.3379564395835323, 0.3254540685203768, 0.15620928077447802, 0.21613594174625414, 0.2898353927077786, 6.741224152426566, 89.94835761285599, 71.57040596008301, 50.773956160391535, 50.20260803161129, 53.86723925990444, 53.70303707738077, 47.36027033098283, 20.24827503388928, 53.00587500295332, 40.964575121479655, 36.00913109317903, 16.212811162394864, 9.122283766346595, 35.6914661776635, 80.91752390707694, 66.84411464198944, 67.85147343912433, 63.449350326291984, 2.3337354823466274, 2.0979287162903817, 57.384699236962106, 76.16481934824299, 75.10685413114487, 66.83119435464182, 68.2665543402395, 66.66369345880324, 66.37893722903344, 62.93329192746071, 62.356562306804044, 58.452482146601525, 54.727756284898334, 53.684613704681404, 56.84612643334174, 52.877531128544966, 55.25743315296789, 50.53932389905376, 58.00465337691769, 56.995192189370435, 59.86447265071254, 57.81135113008561, 61.68217743596723, 55.74139087430893, 56.9245542249372, 59.29344615628643, 55.545817575147076, 57.874811157103515, 65.08415891278175, 61.047847809330115, 57.383130288893184, 54.76386954707485, 62.544000610228515, 56.49518020691411, 60.292238496964984, 57.850551297587735, 59.03826851998607, 58.26128229018181, 58.96330418125276, 60.01751569009597, 63.791832077887754, 35.9970776496395, 6.053155112651087, 8.558726445321115, 4.562413221405399, 0.8413904448670726, 0.6263667248910474, 10.516757945860586, 15.77148372127164, 38.09643214748752, 69.11344897362494, 45.923404155238984, 47.274472405833585, 45.49314760392713, 36.23840931923159, 30.82253198469839, 36.874103930688676, 31.304430461698967, 34.92761596556633, 32.82293881139448, 41.316168538985714, 41.26890397840931, 33.91820576883132, 22.26540880818521, 22.152899542162498, 47.39090011965844, 68.49084331143287, 73.51215177966704, 51.15661474966234, 27.853846896079283, 14.58342819444595, 2.152916668884216, 1.1561885980829116, 4.546769338269388, 9.296017308388988, 15.095992742046235, 39.795332262592936, 51.9406847799978, 56.8303624276192, 56.25130684145036, 53.44524714254564, 54.329725926922215, 54.69915043923163, 55.66838379829161, 54.71642455747051, 52.809909466774236, 54.94224325303109, 56.60119795030164, 58.299070404421904, 60.40506155260148, 57.88167138253489, 56.67140445401592, 56.936858700167754, 54.26608547087639, 48.29722650589482, 55.79208358641594, 56.114765213381865, 54.44791478495444, 53.47337445905132, 51.25935731395599, 48.827730994070734, 51.00339128125099, 56.00589590687906, 58.099770853596354, 63.1378278424663, 60.10642405479186, 69.26112621061264, 67.1441916496523, 69.95271067465507, 62.85234989658479, 65.59064672839257, 61.40375583402572, 68.27257910082417, 70.53026399304791, 68.69876815426734, 66.78131749553066, 74.90912745075842, 67.94518670728131, 61.786143779754646, 1.4742491826895745, 28.929417671695834, 70.2420090090844, 52.2643469995068, 76.0268460550616, 23.295409487139796, 3.801560190416152, 31.173511551272487, 71.82011973473334, 44.1722894483997, 27.147373114862752, 20.914122866046046, 58.281796286183024, 37.75113413410802, 37.535262569304436, 48.99781673185287, 50.18437685505037, 38.38532255541894, 65.74653348615094, 84.01351344200873, 53.76354355965891, 1.3083445689370556, 0.5949754448186967, 0.4054015027659555, 0.42471871621185736, 0.3692995174036872, 0.10663678839562402], [0.18786055576657096, 0.22106919557817523, 0.16649254026912874, 0.07960896127887311, 0.029295575692348426, 0.012745869237058347, 0.16900484900801413, 0.23691923297461004, 0.08597518257316082, 0.3117389189860513, 0.3632297721360961, 3.4647688173478652, 58.600939935253514, 56.41498734874111, 40.11566438982564, 30.998830756833478, 42.66991969077818, 30.35495408119694, 22.36504093293221, 27.44437498431052, 37.21464803141933, 32.17930728389371, 15.979234018633443, 6.930667277305358, 8.038519649736344, 27.90988579873116, 58.35290493503694, 69.2204276977047, 66.53065450729864, 60.70188299302132, 14.87496816342877, 0.1025309554872013, 1.974893402188055, 35.8219006753737, 61.15306146683232, 62.87382095090805, 64.69536573656144, 55.676801204681404, 57.11019216045257, 53.460403180891475, 54.09159491139074, 51.195144191865005, 51.75953795832973, 46.736240848418205, 46.97453268112675, 51.56161123706449, 52.74967362803798, 51.49060456983505, 48.70321143058039, 50.39753021732454, 49.48193527037098, 50.958939060088134, 49.95698921142086, 51.625161478596354, 52.222456086066465, 50.65027598411807, 53.33955495588241, 56.303513588443884, 56.80983666450747, 55.744940619314875, 56.05085803616432, 57.48323309806086, 52.341904024924006, 51.14097233741514, 52.81159216357816, 46.99769819936445, 42.67496385881978, 51.46231643615231, 50.90230395717006, 52.072201851875555, 24.496876578177176, 6.27305151954774, 1.5972018818701468, 0.3786115612714522, 0.8171479908689376, 0.40549612994636264, 0.3958303986057159, 0.9728412654611373, 3.8180069336968088, 21.778858400160267, 32.23216710552093, 18.562744317516206, 12.376883164528879, 15.200350342258332, 14.46148660875136, 9.684659473357662, 7.359023440268732, 10.220926903909254, 10.264525028967089, 8.78926375219899, 6.978215229126715, 2.1110198718886224, 1.5840409816272798, 4.7269409606533666, 10.500687995264608, 3.6647611568051004, 20.089064067409886, 38.55511411543816, 30.10161211413722, 5.493735892157401, 7.868272114184595, 2.6837295534149295, 0.5982861703922672, 0.16142549684211133, 1.3190929663758124, 0.30306321839171074, 7.424193130385492, 19.27922994859757, 40.714837812608295, 46.24119458660003, 47.13071753901821, 47.69586047818584, 49.03403589802404, 50.169958222296934, 47.41373615880167, 48.26353334611463, 48.23885379299041, 48.95928728965021, 50.979621718006754, 49.78450690546344, 53.33714662059661, 52.28457466248543, 51.338663716470045, 51.04580386992424, 48.74176832937425, 50.4015741809722, 49.887257314497425, 49.039829238768554, 49.57802941722255, 44.56413422861407, 43.78856397444203, 47.32546321807369, 46.537580643930745, 51.453832349469586, 54.77030615652762, 58.58789020969022, 57.410983039486794, 60.587310560287975, 60.06336819741034, 60.9448463686051, 62.02116827810965, 62.09344187090474, 61.71012040107482, 65.51910269644954, 65.18350862687635, 63.64370376833024, 63.581651872204205, 65.56616329377698, 4.568177144373617, 0.30253627247387366, 43.798252228767645, 45.04665244010187, 58.986312804683564, 55.81178565179148, 10.867938533906015, 4.769011812825357, 17.91279189048275, 45.93848959092171, 64.49455607321956, 48.86221647262574, 12.632519718139404, 23.092130691774432, 35.82317936804987, 32.348575207494925, 34.88126531724007, 41.77303837191674, 29.884142183488418, 40.410136330512266, 60.270736063680346, 17.71351391269315, 0.4039513596123265, 0.31264798956051953, 0.04625321726404852, 0.14907637400732887, 0.04112322822273259, 0.11213300193870261, 0.22859800126283403, 0.1197255231560238, 0.34548156804615454, 0.11895997149329032, 0.15536739611096922, 0.03369158546951029, 0.479719968092057, 0.43370459048498067, 0.12699536813963808, 0.23969556625571944, 0.20493314691608955, 3.6016073198087755, 69.90929003684752, 65.45226550871327, 46.76502712311284, 31.48085867204974, 48.41660776445943, 38.652055494246945, 28.225838599666474, 27.35821031755017, 43.102615956337225, 30.26532203920426, 17.986412817432036, 9.505865093200438, 9.963532147868987, 35.450656183304325, 62.989295528781035, 71.79526759732154, 71.46729469299316, 68.77290095052412, 20.010300913164695, 0.1456938659952533, 1.6102020875100167, 29.8790156456732, 64.87286867633944, 67.72275693954961, 67.6888676612608, 60.82721840950751, 62.74825803695187, 56.77400189061319, 54.823171861710094, 51.70651535834036, 52.54927189119401, 49.827907931420114, 49.3632718055479, 55.36305473696802, 52.949165375001975, 55.218029022216804, 53.69606310321439, 55.43509690992294, 52.358840819328066, 50.387673301081506, 54.60078916242046, 55.835312028085035, 57.21860254964521, 57.88334623459847, 58.12670576956965, 55.49750574173466, 56.26441148019607, 55.416795130698915, 58.42884986631332, 59.035962166324744, 54.45715588908042, 56.652392725790705, 54.86177582894602, 49.91811852301321, 45.19612220025832, 48.29868954996909, 51.559642207237985, 50.80465262936008, 22.903715718177057, 6.972370897569965, 3.3760857437887504, 0.6507538775763204, 0.9945358948842172, 0.3818586096167565, 1.2300872778700245, 3.6035846846718944, 7.815059769538141, 21.458749848027384, 34.345877478199625, 22.93744614047389, 24.484375984438007, 24.31586115590988, 22.11973394117048, 14.351747516662845, 8.840057465337939, 11.634196100696442, 9.502398698560654, 7.942700068796835, 5.549769891846565, 3.233297496072708, 3.3229400794352255, 5.672432213060318, 15.089574763851783, 11.701901112833331, 25.03022478472802, 41.904598589866396, 31.805073945753037, 13.080681889287888, 15.33704298157846, 4.755919921782709, 0.45760812718541394, 0.6682587414979936, 2.21090768614123, 2.458285689353943, 9.015760037206835, 24.585229927493682, 43.962697598241995, 49.74189035354122, 49.23624976988762, 47.246980513295824, 50.82700229460194, 51.25871012287756, 49.12954953409011, 51.79960104726976, 53.670865797227435, 54.17003447009672, 57.788236602660156, 55.54452319299021, 56.027516011268865, 56.48127148228308, 56.549897270817915, 50.938013215218824, 52.239965546515684, 53.74031136112829, 50.858444013903224, 49.854952673758234, 50.02891371327062, 47.937482403170684, 46.726948753479995, 46.132097782627234, 49.959868231127345, 54.41309590493479, 57.35801927505001, 55.32197183178317, 62.69961280207481, 64.01722323509955, 64.30337975102087, 65.40934693428778, 62.849631694055375, 56.6413983221977, 58.43456868202456, 65.05792217869913, 71.83204374005719, 65.13183924459642, 69.7781495125063, 59.153072372559585, 0.8222068677986822, 2.0504346970588934, 50.078621910464385, 51.72988876219719, 66.29206457445699, 63.53157104984407, 15.903199853435641, 5.352466337142452, 12.240936756134035, 42.62832295510077, 57.38082785760203, 49.509689961710286, 12.226950564692098, 31.238703304721465, 32.38326072692871, 31.91538864566434, 41.064701464868364, 38.51425086298297, 31.03116873771914, 51.07793592637586, 75.09830336416923, 27.657612677543398, 0.7465533563686956, 0.38614738432149737, 0.06063375629544739, 0.2061467374404592, 0.24060429975150094, 0.02193754824299005, 0.24714201748851808, 0.3369269399873672, 0.4315148047622173, 0.16312638057335732, 0.23179896175861361, 0.15981324948370457, 0.5180555594063575, 0.520394211334567, 0.3571669523033404, 0.8826739425140043, 0.7447726615974981, 6.6124287151521255, 89.09577554272067, 74.5359060841222, 57.084367275238044, 40.18471379433909, 56.9283079331921, 45.768811779637495, 35.987601203303186, 35.17577648162842, 49.31142591661023, 37.604433567293235, 23.778551355484996, 13.777630194540947, 15.166895466466105, 39.806585542617306, 67.21152305603027, 77.16087387454125, 74.92844904622724, 75.15905303339805, 20.439674931187785, 0.21666947602024003, 3.9036016310414965, 42.971989262488584, 68.9119960415748, 72.15119131149785, 71.82426175763531, 66.29548488124725, 63.05858027550482, 61.95031458331693, 58.12441118301884, 54.09332467663673, 56.875701104441, 53.94198786827826, 49.55888825078165, 57.762639214915616, 55.87196657734533, 59.01078839455882, 54.66673989449778, 57.98190362991826, 57.014443182176166, 58.80725268394717, 59.60668663824759, 60.03303650886782, 59.873364663893184, 60.87677755663472, 57.43962026411488, 57.856929071487926, 62.07236697596889, 59.07413467284172, 58.27726987100417, 60.12000330032841, 56.830354582878854, 61.98518837651899, 59.367955500079745, 56.034148739230254, 53.59064548246322, 57.786118522767104, 53.02483181799612, 57.16549757988223, 46.87450831936252, 16.35882825620713, 7.2040496141679835, 3.195193385885608, 2.164195199166575, 0.4884653520439902, 1.7030850389311392, 8.61512718662139, 15.064190164689096, 36.56631946563721, 39.927210192526545, 23.812695587835005, 38.261332511901855, 29.22831600712192, 29.89939824227364, 22.427488988445653, 18.82696693943393, 20.800697726588098, 17.396431469148208, 14.397895182332686, 12.020468173488496, 6.064320139346584, 2.8489005613711575, 4.8984514994006005, 14.35724275727426, 28.048882830527525, 41.358863538311375, 46.913096597117764, 37.132505755270685, 32.17022307457463, 21.326260028346894, 5.728437775565732, 0.6562929384170041, 0.49726396378490234, 4.64245310714168, 7.256673112992318, 16.62436193035495, 33.256133217965406, 45.66208408724877, 46.82324294121035, 52.85398514040055, 49.28956262526974, 55.37332350207914, 56.61106271128501, 53.07560689987675, 54.41306844834359, 57.10479105672529, 59.16402755245086, 58.36668029908211, 56.6457207741276, 60.75782775878907, 59.912266731262214, 57.28773040156211, 53.707367374051, 54.03733676479709, 55.797049307054095, 55.35663381699593, 52.869364753846206, 55.02907276153565, 50.0642817251144, 47.76945590972901, 50.4407782708445, 53.1982554927949, 56.308918614541334, 58.34385994941958, 60.65797598131242, 65.42961382096814, 70.33299230760144, 66.01389792657667, 66.14455992175688, 65.39511657530262, 60.89483222653789, 64.13100334905809, 70.55140556827669, 71.86215185349988, 69.06718069507231, 67.08855675112817, 78.1469734253422, 6.933318799541843, 1.247327565666168, 56.25931239897206, 59.3379964367036, 70.17567388473019, 67.57948060189524, 17.6383005034539, 7.940761437339168, 23.96399905604701, 55.15382374486616, 65.9101120118172, 57.55188242081673, 13.694532821255347, 29.034925506960963, 44.42408600161153, 39.73378635221912, 48.32343578338624, 53.5976194566296, 44.02700877958729, 58.29948617566017, 87.07416242168796, 39.167301962452555, 0.8710610301744554, 0.45584388798283, 0.15341629274189472, 0.2826640130050721, 0.2688637357806006, 0.13114153557727415], [0.08586147214255987, 0.06092493099370792, 0.09416050262629025, 0.05236367244393595, 0.03473314328960354, 0.0445164806179462, 0.08220728636989671, 0.1660074074301989, 0.04733291094101245, 0.17117909846767304, 0.10989803235016524, 1.8909479389267585, 53.61951804930165, 55.030320075250444, 46.49697626790693, 44.179345792339696, 33.817722489756925, 26.793298798222697, 21.542043339821603, 34.546871492939616, 33.71999663691367, 29.54623587669865, 14.961090664709769, 3.412863112265064, 4.317367067260127, 35.46260764521938, 61.42366970739057, 54.00598918237994, 52.92763548512613, 58.32076111147481, 35.86519971970589, 1.7981533634085811, 0.05373845552845348, 6.3498167164864086, 43.55931320498067, 65.90357734311011, 65.24601551794237, 61.14682097588817, 57.465429459848714, 50.84646901776714, 51.4849445896764, 50.3935960800417, 47.67136527645973, 49.00405722279703, 55.52386014692245, 58.50897212182322, 58.78351842203448, 56.73248360233923, 54.59538805869318, 52.98334883105371, 45.45063303362939, 51.902316154972205, 52.76324110646402, 54.07383049688032, 55.54392307035385, 56.57311377986785, 55.827769310243674, 52.474844917174316, 53.86834536829303, 55.606257377132295, 55.68328488257624, 51.354223758943625, 53.09115517523981, 50.47340062356765, 53.78765436910815, 52.70741401180145, 41.71967844809256, 28.71658398259071, 45.29504045363396, 42.24052606090423, 2.540800100372684, 1.903796275296519, 0.8705327359418716, 0.7969585097124501, 0.2919947187746725, 0.7026868553892259, 1.5218830589325198, 2.7224176064614327, 3.2028927533857288, 24.612202105983613, 26.314038115163005, 8.674571687175382, 8.425762999442316, 10.668822353886021, 6.9278980839637025, 0.3036682133472735, 0.37438159147577904, 0.45534378578585966, 1.2267096268553888, 0.4347714751718506, 0.1758470713731743, 0.28281897727039557, 0.05040077132082755, 0.23362107124299775, 2.3760080914343558, 3.426904462037548, 6.31256204458975, 24.95653129393055, 33.94357958147603, 3.967056019652275, 14.678873189034002, 6.9395342853761495, 1.9290734995757381, 0.23993683798659235, 1.5696556890203108, 1.914888370421625, 2.450641970480642, 7.566933083918787, 29.56931314160747, 46.399430844091604, 48.75062896359352, 47.695056392300515, 51.187283762039684, 48.7460829365638, 48.24561595916749, 48.55534199745425, 50.59914396655176, 51.599756286990264, 52.95915957420103, 51.53455080524568, 55.68423801852811, 50.89389047315044, 53.15967113740983, 49.81927087230068, 50.56676087840911, 50.03089058783747, 47.01793370708343, 47.782340895745065, 46.60339409305204, 46.823329233354144, 44.06434582125756, 43.45407209088726, 50.879977826149236, 51.438409589952045, 53.628614025731245, 52.88221051616054, 60.60539268678235, 60.73811784867318, 60.64491841100878, 57.54288058127127, 59.779784756322066, 58.724341623244754, 59.802801224493216, 60.224259899508574, 63.06258109308059, 65.97284640035322, 68.06135946704497, 9.661539062376946, 0.45741118130183994, 8.858292564269036, 53.33002359636369, 53.80733682263283, 60.10269388075798, 57.334124195960264, 26.422658351159868, 7.981583504907547, 4.517826168767868, 32.38291359716846, 75.6329067291752, 71.84858045270367, 18.148847972193074, 16.13414606740398, 33.87610696977185, 32.63104665663935, 36.933578829611506, 37.978717896246145, 34.48311728815879, 47.950371311556914, 56.69174194335938, 18.27123964986494, 0.4844970778832513, 0.1083192017470156, 0.05667534551673359, 0.18858340568840506, 0.05409595428875858, 0.004888946658015372, 0.19240549495143278, 0.04378185975515554, 0.3017112877099745, 0.12725173180261928, 0.06962118189661734, 0.06474373756998009, 0.185207256206101, 0.04890245272808018, 0.02838217863632787, 0.15691815725257321, 0.18141501372860325, 3.4253489971160893, 70.11300225411692, 61.60409481294694, 52.41287146845172, 40.06066491526943, 36.39438236913374, 35.56877051630328, 28.066043200031405, 34.28997585850377, 43.665021081124586, 25.698924180000063, 17.68833817974214, 6.660524818205065, 4.057698317112462, 36.53383047349992, 65.71075362543907, 56.75958718022993, 54.77827249034759, 59.91398472939769, 42.944262027740486, 2.2467821740335037, 0.060379330834914605, 6.076749149830111, 44.89431934971964, 72.66073073110273, 71.63751771373134, 67.5454971867223, 61.30495525175526, 54.34996535701137, 49.78865677310575, 52.32358263384912, 50.72100416306527, 53.439865650669226, 56.49592937961702, 64.27740973810997, 60.63632449796123, 61.23585093405939, 57.23095801568801, 57.548720990457845, 48.62351671341927, 53.15291289360293, 55.67301611746512, 56.358713103878884, 55.75927688229469, 62.74042506371776, 58.003762998888575, 54.873429190727975, 53.84418356803156, 57.378564650012606, 55.50458169752552, 54.72951350673553, 55.70994523263747, 58.5290232781441, 54.27235734078192, 55.76043005912535, 49.922750842186716, 37.63873077207996, 48.743454948548354, 41.17585359081146, 9.887736266659154, 2.851256434955905, 1.6925225863533637, 1.3908767531956396, 0.4272227818446775, 1.375329703573258, 2.796025295411387, 3.8142529802937664, 4.07358170997712, 24.585431929557558, 36.36395654370708, 19.686417079740956, 13.681297763701409, 16.7605838852544, 7.522545581863773, 0.31124978716815677, 0.46966123364625445, 2.0593269553876694, 1.6449251146085802, 0.6516234180138958, 0.21309608954095074, 0.1628724683917338, 0.016365403895296397, 0.3792620005626833, 2.596426909008334, 7.304507888132527, 16.39571520590013, 36.54327161850468, 39.39352073977071, 6.08547201079707, 18.40341567993164, 9.254161696280203, 3.384257756894635, 0.19677898365884058, 3.6264280782591913, 4.669152190608363, 4.124296240268215, 11.162007451057436, 32.31152057647705, 48.30371802853, 51.438715534825484, 48.17202052762432, 53.69245452265586, 52.48401934100736, 52.77679681777955, 52.47400160758726, 56.26370545356505, 54.61137563951554, 55.95894905828661, 55.5519913857983, 58.45795777536208, 54.4689896798903, 55.595612064484634, 49.56006888420352, 50.1683618176368, 50.85593761936311, 52.090150617784076, 47.537361421892726, 47.13657756005564, 47.34374146307669, 46.07007726546257, 45.75802133929345, 53.31993526028049, 53.58436969018752, 56.88539328113679, 54.187438026551284, 64.04608795719763, 63.46259224799372, 62.58403624257734, 60.11617114467006, 60.91540113572152, 55.595447324937396, 62.5439025509742, 62.887353128002545, 63.95002126693726, 66.57387902659755, 58.07944120899324, 0.5214425260501524, 0.39382315631355014, 10.994850743201471, 69.63521834342711, 60.379613214923495, 61.057045767384196, 61.835883355909786, 33.1056514863045, 10.02598608693769, 4.539760062771459, 32.97971986955212, 71.86652137387183, 68.86853618006553, 16.066701892883547, 23.653331648918893, 35.70537490229453, 32.43596757611921, 42.36546531800301, 41.848759728093306, 38.45453669947963, 58.504524154047814, 66.82959402761152, 26.325487513695997, 0.8304913426118513, 0.0645270036353219, 0.07840317719045185, 0.4407027730297658, 0.030898861737260898, 0.0868104635587623, 0.18576501418025265, 0.1535375184950329, 0.43339677635700474, 0.15462373924111167, 0.15144265106608792, 0.17452560034730744, 0.37424069258474535, 0.41849422118356155, 0.20687772321604914, 0.6720248910207903, 0.3916311642575649, 5.594859988458696, 87.61908946498748, 74.73612739193824, 61.53741844238774, 54.72741896106351, 48.353053600557395, 41.8749572384742, 33.67124942041213, 47.40143168357111, 48.58145713806153, 37.27733142914311, 23.438932934115012, 10.213904880708265, 12.00613191050868, 46.10659453176683, 74.23182041414323, 60.738761117381436, 63.667606692160334, 68.89210962480115, 41.438675926577666, 1.9294651237226303, 0.1597421105590559, 9.03239284792254, 51.80092288601784, 73.52257743958505, 73.92423598997055, 66.96236625794442, 63.70946622663929, 58.10578384707051, 54.35850827924667, 56.166646403651086, 54.614670430460286, 55.80396444566789, 56.35962309375886, 68.23023319244385, 63.6226837865768, 62.372153728239006, 58.91987962107505, 61.609205661281464, 50.96848610908755, 57.60201815635928, 58.40627270360147, 58.15360538421139, 59.32886123657227, 68.04300277463852, 59.24863699943789, 57.09204335366526, 58.90349980323546, 60.54305053526356, 54.69891901939146, 58.99156878071447, 56.96799839696577, 61.09309234926778, 56.22323051575692, 60.25636057699881, 49.274022194647024, 51.85846797881588, 51.69688593956732, 51.74521346246043, 28.75546055455362, 4.498325615159927, 3.9387225335644143, 2.3403983635287133, 2.1744521971671813, 1.7515096404860098, 6.119839327950632, 18.03765662254826, 19.398048347042455, 28.875404673237956, 29.65769590870027, 32.29094970610834, 34.02637689344345, 23.237109338083577, 14.851322154844961, 1.5234148670588772, 0.9576167694983945, 2.374518081065147, 3.641914085995767, 0.8166925669197114, 0.74144440793222, 0.2885889063679403, 0.19348483622795154, 0.4448770941986192, 4.511745024111963, 25.016563169417847, 36.28477957940871, 39.34512653658467, 37.17414171464982, 29.523915629233088, 30.24653388607887, 15.358746436334426, 4.612682807830073, 0.5417254086463683, 6.5264812496400655, 5.442237132979978, 7.9532840944105585, 20.857017078707297, 42.68434616827196, 48.410892871118364, 56.484864373360914, 48.96495511454921, 56.280195097769464, 57.375713086897335, 55.1707213155685, 55.843709822623964, 60.03395826585832, 57.107579861917806, 60.33175245408089, 58.74587543549077, 58.96239811374296, 54.50999413767169, 57.898580720347745, 55.120773853794226, 52.9971634188006, 53.63013982772828, 54.037591718858295, 51.168727028754454, 52.90405027327999, 52.5853027835969, 49.351963612341116, 48.76420036438973, 58.14025363614483, 60.09779091804259, 56.26544306355139, 57.9782283690668, 70.32550842531266, 69.39563997330205, 66.57393393977996, 64.9169090486342, 65.67159660400884, 60.32813602878202, 66.04354320033904, 67.27182557505947, 70.32262156086584, 69.37847568142799, 76.62415242964222, 11.571881405768856, 0.5265239566083878, 10.68997863800295, 65.50697865024691, 63.458869918700195, 69.89438503019272, 69.27435244283369, 34.13051189914827, 12.573395871346998, 9.41620755580164, 40.98810149777321, 81.67811855193108, 80.001556334957, 21.242646863383634, 21.09731128138881, 47.426672135629964, 44.52257671663838, 50.18617330058929, 55.33427238464356, 49.220893690663004, 68.31442294582244, 82.97438344647809, 37.93784287668044, 1.0635484658902692, 0.31771097272153825, 0.2507481006004157, 0.5728780370085471, 0.14564456057644662, 0.1512531668788964], [0.19431095480197863, 0.06480714666747278, 0.1828488085659281, 0.08730064491711317, 0.028609291147140246, 0.003960517999310528, 0.20825649761865217, 0.0653420445779639, 0.07190764791542484, 0.3545340000381393, 0.12647981394923505, 3.8147302837141104, 42.34828925901844, 58.90224856715049, 24.647848606109623, 32.47786241192972, 40.70590265335576, 20.43990242865778, 22.40304869990195, 17.03716197321492, 32.76410718117991, 28.106808393232285, 25.220951995541974, 8.500137021464687, 1.7281967882187137, 17.583479496740527, 61.34521445920391, 58.461915446865945, 50.85601998913673, 56.769004791013664, 49.59734709032121, 4.060350574793355, 0.08764416640323978, 3.4162473822793658, 36.26962746343305, 71.20096575829291, 67.10918841823455, 61.589323166877996, 57.77327668282294, 54.38981271559193, 49.7863543418146, 50.368920449287664, 50.98579945102815, 54.469691784151145, 66.31073505647721, 65.86607163952243, 59.43150966398178, 60.800930684612645, 55.83110724726031, 56.48786106417256, 48.277214573275664, 47.95060665376725, 52.44920438335788, 52.2015812320094, 53.816115087078465, 53.63083800961895, 55.43852113908338, 58.540606037262954, 56.025503835370465, 51.517425737073346, 52.60875071248701, 59.42538684414279, 54.813138438809304, 55.06640195846558, 55.478925474228404, 52.683585613004624, 44.253082429209066, 33.55255849899785, 43.34655207972373, 27.752184944768107, 3.04665151142305, 0.7765751163805685, 1.3831043315510596, 0.47328752615759456, 0.3587384437841754, 1.8097538957672736, 6.371413776951452, 2.2279690157982612, 4.85552704141986, 21.3605042811363, 16.299157238775685, 4.991791652094934, 6.1270618823266805, 4.108266003670232, 0.215181059113914, 0.09390958584845067, 0.15570119594133672, 0.8370508325676765, 0.6832092844190136, 0.046982958146761504, 0.10324453574515159, 0.09978878206663555, 0.08475321104689952, 0.1746491396859769, 0.1267727123453252, 1.8758991528903286, 4.1109359120169, 9.32362687203192, 20.176444668923658, 5.338837571682469, 12.317788735512766, 6.127109931361291, 2.531800712308576, 0.21598843917731317, 0.25697817274880025, 0.7051663449214352, 1.1380150313338926, 4.722871501599589, 16.420468303465075, 40.079500136836884, 49.102159623176824, 48.6030537082303, 49.826601782152736, 46.488339208787494, 48.329503690042806, 49.95163909850582, 53.01895218510782, 53.259805325538885, 54.41810869401502, 50.43289430679814, 52.832874944133145, 51.26766489398096, 52.70376620754119, 48.771998036292295, 48.00669654723137, 47.63458521135392, 46.70979230634628, 47.217221490798465, 48.62932966601465, 49.524736173691295, 46.945664036658506, 47.00463294982911, 46.32314466661023, 49.85950262315812, 51.057602359402566, 56.3150022106786, 57.34235332858179, 57.7095381675228, 58.477389197195734, 60.51602932714648, 60.56574929145075, 56.064633400209495, 61.58421231854347, 64.60617496121314, 64.04898266638479, 61.072594042747255, 7.245578688959922, 0.06571530559731108, 0.15886880096889314, 21.810711968329645, 48.09432621925108, 41.77991428682881, 61.4588180665047, 54.3421402285176, 54.95735222293485, 9.873591219225238, 4.737701002628573, 29.962924949584473, 68.39271345446187, 87.84757537226524, 37.25108685032014, 20.768030266607962, 31.611395151384418, 39.35513250289425, 32.95004713919855, 28.517400141685243, 30.40141259470294, 50.90035061682425, 50.66197249197191, 13.13481746181365, 0.5210667139580173, 0.21259850011237208, 0.03576320596039295, 0.03262484250890632, 0.1055580982938409, 0.04791872688539086, 0.08242570569798832, 0.03934136899789015, 0.10076035009396654, 0.09851550563208519, 0.06946868443441007, 0.04459769359879917, 0.2867811533712572, 0.04948911903005454, 0.1152683699864053, 0.17440121831192126, 0.10481942099549117, 5.076457973449461, 60.05678646026119, 69.89403986161756, 28.252669572830204, 31.089851317867158, 50.45746011118735, 29.527728173040575, 28.318849763562604, 24.052848585190315, 48.015765067069765, 28.921165004853282, 26.985418450447824, 16.66106354805731, 2.6697090412339857, 20.508565479709258, 66.64056716426727, 62.521631333135794, 56.049191028841086, 61.073253000936205, 55.03453270081551, 4.9839400476025, 0.030368954889596473, 3.13105748545739, 38.8830203394736, 73.12807329239385, 69.3886895333567, 66.18352474704866, 59.1234584777586, 59.03256147138534, 51.191794487737845, 52.422347914788034, 53.81620137922226, 57.63050633092081, 64.7896202918022, 70.7939806292134, 62.830035532674486, 61.11552830665343, 58.536593452576675, 58.28099612266787, 50.52135944366456, 50.79907109660488, 56.86773084825086, 54.30704286021572, 53.68715147818289, 57.63506412506104, 57.42839444068171, 60.955785859015684, 57.44187170459379, 55.40655774454917, 53.231650552442, 61.850753061233036, 57.769860298402854, 57.50879518447384, 60.01240091939127, 51.95449152300435, 39.99485931088848, 43.73658864728866, 47.72051649708902, 27.73608753758092, 1.9744624317653718, 1.749815421719705, 3.060665649752463, 1.516232516977095, 1.0724664647733013, 3.2942996678813814, 8.972624751829333, 5.711283289617108, 6.8110344967534475, 24.44151036200985, 23.821283617327293, 2.9854823937339168, 6.476306290395799, 3.214770180563773, 0.18111691359550725, 0.3057618397137811, 0.19279431521652207, 1.5094295336354164, 1.1931515436980034, 0.0839397559062608, 0.10125137414903411, 0.22041081961604858, 0.04491365890228941, 0.17258110065614024, 0.1172295167681671, 2.7357438591218766, 3.682335581510298, 13.194857182041293, 23.86126825886388, 6.412734475827987, 15.581715529964818, 10.474396347999573, 5.585843440025084, 0.27845757743043287, 1.6993066932885879, 2.051314411144103, 3.120042734569119, 7.3179287679733775, 22.437773443037464, 46.27941808392925, 51.26696278972011, 51.61844638086135, 50.52349713540847, 51.75499585367019, 50.495730676958644, 54.567868709564216, 55.15977398041756, 55.109493117178644, 54.13798086104855, 54.782257618442664, 52.854408756379165, 55.19974685484364, 57.009791251151796, 52.26735153505879, 48.94574334544521, 50.50515221011255, 49.780639448473536, 50.50681137269544, 53.203880171622004, 54.87136994638751, 48.55741300890523, 50.8315836229632, 49.85296795445104, 54.01909774349582, 52.96435279230918, 58.440271808255105, 61.758530293741536, 60.65291612379013, 61.15266922981509, 67.32105916546237, 62.77381620099468, 59.25636406867736, 64.42056448228898, 69.22485997599941, 69.22649952673143, 48.15402469327373, 1.4542727965501048, 0.13063312898720467, 0.9870311137168639, 27.71318874051494, 53.9968147585469, 44.39816305714269, 67.5443361651513, 60.77491360325968, 64.03272051965037, 9.909652509996969, 6.917727378106887, 38.3610156274611, 67.55481673825172, 87.51386796274494, 36.27594640178066, 25.998450094653716, 38.60367305817143, 39.33059807746641, 34.33083518858879, 31.35306981302077, 34.76076226080618, 61.5663420000384, 65.64263774502662, 17.63298176950024, 0.7713972200309077, 0.2542504860508827, 0.09017506043516821, 0.13941746084920822, 0.12634612394556885, 0.08102520504185269, 0.1853433287432117, 0.1395250195937772, 0.3039489998932808, 0.3246066527020547, 0.12609263311230368, 0.1966995556628512, 0.5375454490703921, 0.14613577615349524, 0.20027589924152822, 0.4168109421528155, 0.4886145553281231, 8.594029738057046, 80.59039823470577, 80.54731492073306, 37.91699155684441, 44.81580526598039, 57.94486861075125, 32.9584135547761, 37.30698062527565, 26.795775774986517, 46.6368793672131, 36.183872684355705, 36.67325112127489, 14.301671597265429, 6.968233287334443, 28.86741872756712, 73.68589708881994, 64.51581924192368, 60.886254002971036, 64.60381761673959, 61.5710174652838, 4.670067573747327, 0.17768005930608322, 5.424034883899074, 43.83846436777423, 80.0171438340218, 73.20329650755852, 67.86661378798946, 64.3677419231784, 60.55052265044182, 54.82852981936548, 51.99040082193191, 60.30230722119732, 58.01065852565151, 69.72162815832323, 74.05390170312698, 67.20574148239629, 62.39675483395977, 64.05584289181617, 62.15749809818884, 56.88318106435961, 54.127555201130534, 59.53606436329504, 55.66628533024942, 59.54344626395934, 62.02083879901517, 68.18651445450323, 63.271494373198486, 61.32207247518725, 56.1842696128353, 55.979200255486276, 62.54724441036102, 63.89291155722834, 58.640140102755645, 64.82953825304585, 57.14746644420009, 51.835690775225245, 45.64173875316497, 55.88917401529128, 38.27457835597377, 9.453760327831391, 2.4754252212662853, 4.840901013343565, 2.166904821511238, 1.1420125394098222, 3.421066504332327, 14.68238861330094, 21.97523186283727, 28.210855145608228, 35.587895993263494, 38.42901383676837, 31.47513201159816, 20.581890267710534, 9.17257639669603, 0.3754362493993775, 0.229806458998111, 0.5891080693371835, 2.0241734481626943, 1.2543891802910836, 0.1298089869200222, 0.22385705082166582, 0.30098849907517433, 0.1114551060562653, 0.6250339157639012, 1.1936787347639761, 10.448108623104712, 28.892296360385036, 35.653595693649784, 36.17918545199979, 24.026953097312685, 32.17378458669109, 19.69168874525255, 7.903276326194887, 0.2374584362992356, 2.323219853062784, 3.255824648564862, 4.9348510945996935, 13.976553197829956, 35.18179731984293, 56.41988638908633, 52.2482378252091, 54.16845375491727, 51.34313129609632, 56.771946568642896, 49.54629352015834, 58.690291527778875, 58.134942746931515, 61.05297042477516, 58.73517913203086, 58.20950700390724, 56.04903805640436, 56.39654828656105, 57.77626945126442, 57.55751494438418, 50.08285807025049, 54.041976928710945, 51.702714581643384, 52.2620798695472, 55.18514779306228, 56.29744568178731, 52.04277230847267, 53.677643652885195, 52.74090713070285, 60.32361745834351, 56.46946122569423, 60.624282821532226, 67.13290306829637, 66.26950310122582, 62.61724302845617, 68.42062504060807, 66.51407072621008, 59.291563418603715, 67.51155299525108, 70.42855693447974, 70.13395555557744, 66.26546305994835, 7.876605679911952, 0.24038570422318675, 0.7219418318521592, 27.466138255211618, 58.012572642295595, 51.32396659543438, 75.30094085201141, 68.48486561929026, 65.72565863209387, 14.87203521113242, 9.563359195186246, 38.129580097813765, 73.73793125152588, 89.86892177212624, 43.400347386637044, 26.4533567813135, 47.10687737311087, 52.61789767972885, 44.08975101286366, 39.02038958764846, 46.447499490553334, 70.1760268980457, 80.73660850524902, 29.404140172466157, 1.3940467637392784, 0.3649965241070717, 0.3396104846990878, 0.2592196387629355, 0.3022616146312606, 0.29934661943585644], [0.012777242452777442, 0.024807238913772088, 0.01616814774611304, 0.051688561291103406, 0.053412603860300396, 0.027728381964768616, 0.04680629827142243, 0.14216364090961797, 0.08828074716392063, 0.07202682821380516, 0.09379727735875115, 2.2738529020740144, 42.99938309577204, 48.18622343001827, 37.0634328165362, 41.429501502744614, 27.349467354436076, 19.60474548801299, 31.819465121915265, 23.615831828886463, 15.838747466764143, 31.187257497541367, 26.045667586788056, 17.133056079187703, 2.5149031416062386, 5.268047615405052, 52.66779807306106, 70.97817513250536, 63.32115942432035, 60.207111297115205, 55.34709461273686, 10.026883329114607, 0.10991441130998636, 1.1986856402889376, 24.64953914765389, 61.550762345713956, 65.9584669913015, 64.67070579528809, 56.834076912172385, 56.189945282474646, 52.83466354493172, 50.830771692337535, 50.22899773813064, 65.20539937480804, 64.12764972256076, 65.97882409249583, 61.78577899932862, 59.23645804005285, 56.20336371083414, 51.16249046018047, 47.95669417227469, 47.93506622314454, 53.51077818101453, 53.324783309813476, 49.84577432755501, 56.502118879748934, 52.16115728501351, 54.640201137911895, 55.51890227102465, 55.734365909330315, 50.06488577012093, 56.235958606966086, 52.99580235635081, 51.487600034283055, 48.33094319989605, 43.37473430941182, 28.465103180177753, 41.419103299417806, 28.90723078481613, 8.564878682936392, 1.5223468792053962, 0.49698173699359743, 0.36792674913041057, 0.04574071976446337, 0.26197997612818597, 0.8133538944586631, 2.8232516925181113, 6.1748245839149725, 3.515486534564726, 7.734237370952484, 3.884227573871613, 1.2940342916596321, 0.14248912102512776, 0.13967181736182782, 0.1542298781174806, 0.0571481213574448, 0.08794017511630252, 0.828985029891614, 1.7376474940007733, 0.08587998848768973, 0.13616622966383735, 0.07505854456535271, 0.037718917348331986, 0.16498414378973747, 0.011595641844905915, 0.43383295617757306, 1.2600041757668219, 1.2179687475004506, 5.257189023879267, 2.7916903409265705, 0.741385878814805, 2.037537943932318, 0.510425323680524, 0.22043706578833444, 0.21752550266683104, 0.8660722656115409, 1.6469839912268425, 5.628096192113815, 12.1888800397996, 31.529448993744392, 51.427054328303186, 51.686844671926195, 49.259658475076, 47.88354196856099, 47.666901619203635, 49.521045223359145, 50.97276933731572, 49.97879366720877, 52.38139052544871, 50.8889090630316, 52.66455035055838, 55.97723514802995, 53.7121291314402, 51.89941752341486, 50.0076073984946, 48.71721821446573, 49.88468423966439, 49.99395362792477, 52.89745284665016, 52.00334072113038, 44.97275890842561, 45.82545472729591, 48.50957578228366, 50.34510773997153, 49.91039929851409, 52.787571568642896, 55.869821040861076, 54.118157202197665, 60.849046399516446, 61.4943939639676, 60.35656929016114, 60.37039956738872, 64.32126183663645, 66.66716867877592, 48.60364598612632, 3.8002805171474336, 0.0916038144139513, 0.5162417083497971, 0.7959803686507287, 43.22740616336946, 31.803654047750662, 44.39519774529242, 64.31258947618547, 60.42205718255813, 51.41474200833229, 2.398731852731397, 8.439978649539333, 29.76748108863831, 66.87600351149037, 74.45660360397832, 33.762381768995716, 29.743833118869414, 23.751406592707482, 37.111219052345525, 39.04219404343636, 32.44678351186937, 31.871577732024658, 57.59593848259219, 47.323588325131325, 7.078878446932762, 0.6374628036733597, 0.03013153658098271, 0.22639206640662687, 0.022328885106910622, 0.16366964416398158, 0.027120788055922718, 0.06565730508056379, 0.07260744625161733, 0.029542474339025158, 0.050175713840872056, 0.11671730272111394, 0.06611181738516016, 0.02812035468166634, 0.16015523113310337, 0.03952296630990121, 0.022055701983551827, 0.1013046325815301, 3.4654179696113836, 57.560915639323575, 56.14139810685189, 40.154236978100194, 43.39581704908802, 33.61658334732056, 28.679201833663452, 34.181859647074056, 25.694389920080862, 27.11164620614821, 35.41854766107375, 26.593444232017767, 22.882836941749822, 4.994969752527052, 5.37778768808611, 55.67298866087391, 76.64086957131663, 65.4542737622415, 66.23746518165835, 57.86749593673214, 13.625687379990856, 0.02575415806213935, 1.5561789154045045, 23.851440760397143, 63.25211394217707, 68.07905720126244, 67.17739843553113, 57.35631696639523, 60.41962531305129, 54.60151087853217, 54.12583328062489, 53.68062465421615, 66.72008145240046, 65.80041508520803, 68.84853209218672, 62.513766980940304, 59.714375311328524, 58.580661281462646, 54.561353652708, 50.006273792636016, 51.70341276353406, 56.76524323801841, 56.215727021617276, 51.29070097400297, 59.3066410095461, 56.468994463643725, 55.02684485527777, 58.48748930038945, 58.91104252107682, 54.163174244665335, 58.98024097565682, 56.15473024306759, 55.10972845938898, 51.6903865721918, 45.748199724381976, 29.25162273068582, 47.85995675671486, 32.41973876953125, 7.387971022436696, 2.04048928233885, 3.7202984863711945, 1.8924846500158312, 0.892308877120095, 0.7321460617165412, 2.4879672450404016, 5.986641520454038, 13.064781581201862, 8.794061791512275, 9.11881737170681, 2.981498001083251, 1.9528537267638792, 0.5624938071254761, 0.06856683040818862, 0.11849401383510522, 0.06900160828785551, 0.10383541936114912, 0.4841454435260066, 0.7429594846983111, 0.14791190504066407, 0.12017657274320243, 0.1589092044460197, 0.0775718722011774, 0.14677254843615717, 0.09380830136398155, 0.5964937085105527, 2.1277357878223544, 1.6610352694988253, 7.358089916167721, 8.804177584186677, 5.354937920647283, 3.756896406412125, 1.8348812119614695, 0.708883403530044, 0.3952906743413018, 1.7378389546948096, 3.5184930313018064, 10.468485336149893, 15.285052945536954, 36.74202595987628, 53.3662074612033, 54.767548730296475, 51.877499318891964, 51.594355183262984, 51.7150386687248, 54.503228049124445, 51.35492978557464, 53.78399872010755, 52.94787491521528, 54.9929085085469, 56.85885060218073, 57.80187076137912, 57.71002454142417, 56.056200304339015, 52.046420112732925, 51.196591546458585, 52.4940449191678, 53.426604117116625, 54.82589398660968, 54.75745254947294, 48.03977389489451, 50.35318782252651, 51.927113379201586, 54.77398926211942, 51.87859366017004, 57.10723469334265, 58.06367328090053, 57.00812032145839, 62.13286169113652, 64.37018948216593, 63.439316903391195, 64.02897857850598, 68.68660880673316, 67.21149952180924, 41.65373163838541, 3.1265112132795396, 0.22568447695624447, 1.4210070525446248, 1.8742034632352091, 46.718535269460375, 34.897645135079664, 49.8738584979888, 66.75023663428523, 69.61519072132727, 47.10761085633309, 1.3488595884653831, 17.56607201791579, 36.37212684077602, 65.29247991500363, 74.74252870005947, 38.26977345251268, 33.97106755164362, 30.472234910534276, 33.31205052714194, 42.770355901410504, 29.660286634199082, 35.40171677066434, 67.0315804020051, 59.13495494473366, 11.369192927114426, 0.9127453450233707, 0.0741755286411893, 0.29643502567083607, 0.06501887038710617, 0.12952985512393136, 0.10293263070766004, 0.20239425492623161, 0.15219248260461515, 0.15844371410146837, 0.2118573560109062, 0.15695442385490865, 0.2490406898000548, 0.18450484551008672, 0.38623235879405854, 0.3029794696598284, 0.26915616686305693, 0.28633293064851917, 5.838406326309328, 77.01323586125528, 68.54425814843947, 49.63478219124579, 57.353500704611506, 38.51399983129194, 26.925535625027074, 47.81704602702972, 31.344979924540368, 26.102875355751287, 40.15571571165516, 37.803168296813965, 25.212560084558305, 7.8973373674577285, 10.804914870569784, 65.08922269267421, 80.77343956116708, 72.75438124133696, 70.32445723010649, 62.141679179283884, 12.33731919719327, 0.15961385211877285, 2.979323046822702, 30.61741948127747, 67.0151613604638, 73.66818366512176, 71.21695333911528, 62.3861095213121, 65.26797686853718, 60.087392714715776, 56.785655252395145, 56.104017919109715, 69.78483323127993, 71.8616968585599, 70.43773528068297, 65.59080754556965, 59.15293116723338, 63.26688166587584, 59.862989994787405, 53.59380691282211, 54.708960287032596, 61.0389244171881, 58.66108163710564, 53.89190704591813, 62.25761267446703, 58.80471491044568, 57.78708734819966, 60.800463922562145, 60.32167588510821, 57.70605902517996, 58.32437361440351, 59.6520802282518, 57.68584705168202, 59.168671638734885, 49.004080757018066, 48.49345876324562, 48.837619289275146, 42.302311235858554, 20.382771145912912, 1.9229488411257345, 4.160957163380039, 4.357601759895202, 3.206954612847298, 0.6504209664079451, 3.5237536651472894, 8.579092371848322, 27.395847420538626, 20.50551191453011, 22.572722588816, 16.69770044665183, 4.318399140911718, 4.948514671094956, 0.4341171441539642, 0.18451341037308017, 0.22104051324629018, 0.23893683277551206, 1.0125706465013566, 2.943630703995305, 0.19002815558304711, 0.29773964276236875, 0.2069871205716364, 0.16689715726721674, 0.20688277939634941, 0.11808368948198135, 3.0990014249278657, 9.773713946342468, 17.463556951092137, 18.168877555478005, 20.69371311895309, 22.286752385477868, 6.357615859277788, 2.51546232450393, 0.5042486631822202, 1.8948120864168292, 3.502943530198067, 7.0587517849860655, 13.291201379991348, 24.3718235723434, 52.84616393427695, 53.10175341944541, 59.258258573470584, 53.769352589884114, 55.54674717687792, 51.677807531049176, 58.58335202740085, 55.42826414108277, 57.148529406516786, 55.24195155789776, 56.16394781297254, 59.175163161370065, 60.66029410208426, 60.22054149258522, 60.50771390238116, 53.45155039141255, 53.28467315243137, 57.09758958508892, 56.840835155979285, 58.370826244354255, 58.6489732803837, 50.38672016512964, 52.88377946422946, 54.59296403392669, 57.81499108960552, 56.143147483948745, 60.78773975372315, 61.92022215935492, 59.78451513474988, 66.32061942931145, 65.99945575960221, 66.88286765929192, 63.05288107164445, 68.37557269680885, 69.99933981126355, 53.593014594047304, 7.0148285935002, 0.23054934978004427, 1.74264483874844, 1.9605244119321148, 48.03995432392244, 43.08216471825877, 52.99647308165028, 72.90777729403588, 71.58276142612581, 58.815466127088, 6.941970077253158, 15.374902679074196, 39.878663016903786, 72.92775784769367, 80.19831811228107, 38.46431124594904, 40.6964183622791, 37.77268363583473, 49.60960841947987, 55.103342840748454, 44.04709131486955, 50.76699395333567, 77.73914890904581, 81.29318498796033, 18.233618236357167, 1.0335896476622553, 0.2606090158224106, 0.39018629178885494, 0.1907205458490118, 0.277572684590855, 0.21614809190073322], [0.07265581704315639, 0.10045763811156636, 0.05818746518343688, 0.0264832305331384, 0.07117062536699158, 0.113356206866522, 0.07566866464912891, 0.06473755524043115, 0.08642091551014493, 0.12867716862069023, 0.0804738975280235, 0.6294375730137671, 36.55144976031396, 53.33189064456571, 33.145726342355054, 36.329741708693966, 44.93621810790032, 22.188824530570738, 29.435872147160193, 40.109435665992, 24.33476305777027, 28.549198796672208, 35.94254101476362, 17.84606452911131, 7.859090826203746, 4.149490114181273, 35.47421393855926, 60.467223275092344, 64.54160882580665, 59.1679891463249, 62.33752312198762, 17.77634047692822, 0.13288302196850701, 0.3297983999213865, 13.446184031424986, 57.49985610285113, 70.52303114245015, 62.44483916990219, 60.414432094943145, 56.89668578486289, 51.3694582446929, 50.04706252005793, 57.13395387895646, 63.408522375168346, 64.31860246965962, 62.2640492839198, 62.24910113119311, 60.04686286372524, 59.63233893917453, 55.09556478069675, 48.780109497808645, 46.888609240132, 54.48407511557303, 55.58574730350126, 52.87765664439048, 55.14283326364333, 56.27299362613309, 57.162273391600586, 55.79153445459182, 54.99572084796045, 54.42296066591817, 55.719923742355846, 50.45621279747256, 49.74453403103737, 45.85561383155085, 35.14459363875851, 45.08500537564678, 42.24216561163626, 21.46241334176833, 1.0921693881673198, 0.7306794629942986, 0.9934592042719165, 0.1266318440978085, 0.5041667837048731, 0.11562431741866375, 0.08959997355216935, 0.26200970033964804, 2.158885535693938, 2.4408468315678262, 1.237606951786626, 0.7905082332511103, 0.16139122206837903, 0.13909081628005351, 0.06296146848809815, 0.04746933204812869, 0.03970949339770502, 0.06570676371695534, 0.7122788890715569, 0.1918329821238595, 0.06756412090673562, 0.08003020238491797, 0.05892901914194227, 0.03303852232713853, 0.04470412619411946, 0.006116505359269438, 0.12141211168660272, 0.38911781363910247, 1.3211735386040904, 0.9920591019815015, 0.6154077452036643, 0.5636200789482363, 0.06588115597203856, 0.05532850931969382, 0.14189141922660414, 0.5769349322203667, 1.8871931275052412, 3.331364840269089, 5.245948001261681, 12.330066734744657, 21.328438904977617, 45.405510087167066, 53.426608039486794, 48.79999983695246, 47.50964595425514, 43.61674062667355, 48.23292316928987, 47.60591660776446, 50.862260480080884, 51.42773682071317, 50.3643822669983, 49.90092677454795, 53.59708209191599, 51.52317593174597, 52.442081359124955, 51.345810274924006, 49.07579737324869, 51.61151555276687, 47.60112347141389, 53.04931917498189, 48.303012001898985, 49.79727422037433, 47.294382356828265, 46.3573085108111, 48.77630872111167, 50.797937531625074, 54.63122675495764, 55.152227340206025, 55.4929950160365, 57.56106076701995, 60.3600601996145, 62.62434644083824, 60.52425061502765, 64.32770629082957, 53.08536967923565, 15.52728577967613, 1.416103722107026, 0.12958660691736207, 0.27142985453528745, 3.613028526306153, 35.42400760035361, 76.39837295778337, 59.56448193519347, 54.36831420467746, 64.89768551241967, 23.79496451347105, 0.7415804651475723, 17.229542463056504, 28.578412609715617, 72.45939547015776, 66.75236255891862, 35.28281404126075, 29.510046128303777, 25.0260906065664, 39.941366026478434, 37.03724315089565, 32.952149529610914, 29.124318284373132, 54.64204465189288, 29.14574423143941, 2.0020006573007953, 0.23601092848806615, 0.06270292913541198, 0.016462528522336678, 0.05526763597323049, 0.018882458548872702, 0.04457610907153257, 0.0837914949102748, 0.08595757021178162, 0.05559124683420505, 0.05285098097257076, 0.03784861220347305, 0.16682820935403148, 0.08637108915154973, 0.016888302953673467, 0.05214004371795924, 0.17210934371236833, 0.03799372074765064, 1.3924317278208271, 53.9445609431113, 66.62900401699927, 38.238633755714666, 35.758852497223884, 48.11908814214891, 27.664927897914765, 31.964906607904744, 35.400465534579375, 33.16357312663909, 35.763304387369466, 38.124320199412686, 19.238737360123668, 11.030575690730926, 7.272568027819357, 36.91387676423596, 66.05255680699503, 73.58152281853461, 63.34759619928176, 67.10879618121733, 21.4158881479694, 0.20716796328704204, 0.606612442962585, 15.023554409703902, 59.38616706478981, 72.90445112412976, 65.90008643365675, 63.616290323195926, 60.241894875803304, 52.634465771336714, 54.92285497726933, 60.91243582387125, 65.55322339457851, 65.8759952360584, 64.12826161230764, 64.01468938396823, 61.01783383277155, 60.46558764673049, 59.0883061962743, 51.40570486745527, 49.79966686617944, 56.15308676996539, 58.18931071988998, 58.257261860755186, 58.52218266456359, 58.41819278655514, 60.81711046157345, 58.79462657436248, 59.42198222683322, 56.624920445103804, 56.99070499789331, 51.91685638120098, 53.00054450188914, 45.40081893244098, 41.856894723830685, 52.015221580382324, 46.59878923046974, 21.62062998740904, 0.5698252072738064, 1.5578944620586213, 1.7351311709611648, 1.58908331105786, 1.079079703457894, 0.3568014364329077, 0.06433817828374525, 0.04335833953753595, 2.385733117980342, 3.6148333068816894, 0.6977109611034394, 0.87939704738317, 0.49159184879352974, 0.15869278460741043, 0.03639319070404576, 0.1073792348465612, 0.033630880662390304, 0.06592110745728978, 0.05952262237007099, 1.442427728925982, 0.0820598297662312, 0.06517879890217897, 0.08306088451776775, 0.10288257452268755, 0.03130306696308957, 0.03215360650492292, 0.1729008657557349, 0.26407568625384764, 0.9666889052717917, 1.5805863540980125, 1.3267665933216772, 0.2643217843386435, 0.04256479502204926, 0.07354875380593924, 0.27726606556004096, 0.761191703138813, 3.262380890307888, 7.474036159053926, 10.265864518380935, 14.22710341791953, 26.07019808984572, 50.77687440379974, 53.9348413098243, 53.15918868587863, 49.251786278140166, 46.60512385829803, 48.80673454653833, 50.79542721471479, 49.54849396982501, 55.0051776824459, 53.006231938639, 54.774275595142, 54.96454977220105, 55.62282939111033, 54.839555601919855, 52.405497412527765, 52.04591804935087, 53.44704751045474, 51.29039502912953, 56.285560900165194, 52.28207611268567, 51.221957514362956, 47.96153437706732, 47.85119810412007, 50.55426420704011, 53.144205231820386, 56.97320338218444, 58.49489081290461, 56.763835107126546, 60.51903778506864, 62.95557491240963, 63.011633426912375, 62.16695493267429, 66.8256716574392, 54.65710655335457, 17.710370133000037, 1.0829603984471292, 0.06365935926535918, 0.24893109326160726, 3.904371886484085, 42.75210119062855, 73.93065298757246, 67.44119351910007, 62.58748400595881, 70.41821756670552, 24.140817542229932, 2.2534644219183155, 21.34013149046129, 28.839224730768514, 73.07162254087388, 68.23565390802199, 41.311045923540675, 34.79672255054597, 32.51141828875388, 34.162569430566606, 36.4062043928331, 39.90778661543324, 35.58143584958969, 66.01645531192904, 41.718780225323094, 3.638035107043482, 0.2539842551754367, 0.0544901448301971, 0.009484962361203808, 0.014072564982568786, 0.05065875525976862, 0.07429679269872366, 0.262378096700676, 0.2610447666337413, 0.16421935821492828, 0.1282859658221564, 0.32154542664366387, 0.4148154669711667, 0.2637120396379502, 0.17786654042861155, 0.1975925077473925, 0.4988747096109775, 0.2211852885422207, 3.2559143727825535, 73.60091501666655, 79.33145861471854, 49.92839513286468, 46.76152836891913, 57.94410767093782, 29.59101757695598, 40.93591828500071, 50.84302909912602, 36.32489758153116, 38.117369759467344, 47.84016447682535, 25.67572924398607, 15.259543811121295, 9.740415965357135, 43.13399884008592, 70.5631648340533, 78.76632352029124, 71.10590319479667, 72.03457140153455, 23.301116535740515, 0.36861923132692614, 1.7847691332140279, 18.72706417114504, 65.62277094010385, 75.71675131397863, 69.7815933535176, 65.04051862224456, 63.126001896396765, 55.83102095511652, 59.22570682341053, 62.42727087390039, 68.16677708779612, 66.50412359545308, 67.85946722953551, 66.9423778595463, 64.96631914569487, 65.5003066985838, 60.89452235929428, 52.86680344612368, 53.081204122112645, 59.07693916751493, 62.29488695821455, 61.15568161010743, 61.85746423659786, 64.30932214183193, 65.98224439928609, 61.41661336345058, 64.62867367652156, 57.62343037512995, 61.02191702012093, 56.787373250530614, 55.67097256260534, 54.089331703801314, 51.96956126920639, 59.678289505743216, 47.33858746867026, 30.29594986669479, 5.775742540436407, 2.6446139620196436, 4.599207505103081, 2.2045725680166677, 3.0567099394336825, 0.6634927553034599, 0.10061211208061827, 0.36115352064371115, 6.624696418162316, 8.534446973954479, 4.203787974772915, 1.8506101615005925, 1.489765833943121, 0.18351528973829362, 0.203114653366708, 0.2264709274975523, 0.22630689275120536, 0.2286228378333392, 1.0390753274963749, 2.464448468339059, 0.21211172784528426, 0.2888095090466161, 0.23184500364286287, 0.1680118151970448, 0.18525190381032808, 0.09371322985257834, 0.2868499480668576, 1.3510450840957704, 3.073905610269116, 5.644796173418722, 6.993897355371907, 3.1118459615015217, 0.1184440955459591, 0.20223927533914968, 0.6979240561204573, 1.991101616332608, 4.130187640267034, 9.91062721898479, 14.915502917382026, 21.37489545729853, 40.886684694597804, 55.54538219205795, 57.526026156640825, 55.53154407009002, 51.456770204728656, 49.853003255782596, 53.52365532229024, 54.163193856516195, 52.435248590284786, 59.266440637650035, 56.25479775090372, 56.2494868616904, 58.885774612426765, 59.97346747306086, 57.81253176350748, 55.576412062491144, 53.71608288057389, 56.70882386545981, 53.91512355496807, 61.23200701129053, 56.05106984415362, 53.919853933395885, 50.687326692765765, 51.02316394928963, 54.74506178209859, 58.66005789849066, 61.479237925621774, 61.73339966804751, 59.9899531948951, 63.3871768366906, 67.33586219049269, 67.8902421459075, 66.98561022358557, 69.79923617455268, 60.90254360629667, 21.151183074520482, 2.522941303829993, 0.5902923799810872, 0.520285549423387, 5.280983101937079, 44.47130741611604, 82.91248844515893, 71.82180635390743, 65.81211551543205, 73.25701728943856, 31.174905953868745, 4.5589786960232646, 24.589605331420902, 35.65372905423565, 79.98261913176506, 73.77925734366141, 41.174449382289765, 42.512609112647276, 39.232554512639204, 57.01452947431996, 50.47638946963895, 48.11996283069734, 44.7126861541502, 74.92611131360455, 64.61500421647104, 7.465973236868459, 0.6433201280813063, 0.15284880545110474, 0.1161940876514681, 0.18029113210016684, 0.1636781170964241, 0.4063758133880554], [0.05472024316869436, 0.061349190486174446, 0.03722215912515118, 0.0530604217501898, 0.053276929688910325, 0.08803100250060521, 0.05301882317590137, 0.03714199185431485, 0.05736427689572016, 0.28070028450700546, 0.06242161398873695, 0.9201512089179409, 35.43187587491928, 55.29480157359954, 28.052499255826397, 36.66553974151611, 39.069179950221894, 29.598250427553733, 32.9356167393346, 33.94669786576302, 26.118486389037102, 35.67467843332599, 48.09354174521662, 22.016365758834347, 4.857793681083187, 13.778428396871014, 52.696878525518606, 58.969070065406065, 58.5814614449778, 62.10883325146091, 52.791693979694, 24.67554250071126, 0.951335461389634, 0.22799202571472815, 10.23234688466595, 46.238139060235795, 69.99129110766997, 63.67412174901655, 63.38135996172505, 56.56504154205323, 52.642679214477546, 55.38103488183791, 56.09358441445136, 60.68644454402309, 63.896084754697746, 63.42607498168946, 61.181847741526944, 60.32289966460198, 57.75212334048364, 52.98231724769839, 46.10122480700093, 49.14306994407408, 57.05105458536456, 56.74707089701007, 54.28523055968746, 54.4091421558011, 54.72240224961312, 56.82560067023001, 55.96427563698062, 57.05690676166166, 54.854390005911554, 48.45300735965852, 53.296887413147964, 50.961417998037035, 44.186406058649865, 59.19416312248477, 51.64478509656845, 28.61901894692452, 12.305192043704372, 1.254035431531168, 0.5101779998550492, 0.4133708396505925, 0.14543145023767026, 0.5898014708392082, 0.039111826073137984, 0.03217301534248456, 0.05639254032904583, 0.03847348331023128, 0.1940602295461201, 0.22316582500934604, 0.04092635894795099, 0.07064601601732355, 0.035844537684874195, 0.04965088232570598, 0.12178688189916073, 0.03141893393119737, 0.11396566811468332, 0.16502545125061469, 0.7778728080372658, 0.2934951172961343, 0.017072815230236422, 0.10370720688614155, 0.02871390811407999, 0.04604202214508288, 0.013448564343214517, 0.048812153944445234, 0.05131683627804441, 0.13102467652530442, 0.07608911668461177, 0.10671929606506902, 0.09805078137545817, 0.08866273392472537, 0.07616714273969974, 0.05262627589306044, 0.544390720465491, 1.3171391357337277, 2.6088372882335418, 5.551929646922696, 12.819199042935526, 16.20441140667085, 41.308406168414706, 49.75426935380506, 46.5284768227608, 49.9008208705533, 45.43372369581654, 40.00528889317667, 51.845516312506895, 48.74614177211639, 48.929206632798724, 53.22850873393398, 53.679569536639804, 52.13573248155656, 53.24276654951034, 50.38128376007081, 51.05662568922966, 48.59718192008234, 50.173021593401515, 50.3891755688575, 50.4649910619182, 49.85704721943025, 48.001962246433386, 46.037858916867165, 46.05874553803475, 46.60197811741983, 48.97325484983383, 51.74660982624177, 50.9607708069586, 53.83594266829952, 56.170890408177534, 59.1397794600456, 56.823612028552645, 56.908833365286554, 55.73294208895776, 38.56120947868594, 10.740882177506725, 0.1520357256935489, 0.3969709809509016, 1.0589083019764194, 5.569350854043038, 57.24839687347413, 43.89916304619082, 43.61547370110789, 63.90023462234005, 58.960464385248, 18.3674906915234, 2.343179569129021, 24.641894448188044, 33.738263114806145, 65.23306385163339, 54.32162623251639, 37.809993220913796, 31.813438400145504, 20.93649410432385, 32.571036354187996, 37.37916400355678, 25.893014823236776, 34.56939374246905, 55.96633488132108, 25.8470211105962, 1.1415152564164133, 0.08924465431200881, 0.08069973258722214, 0.054829805233185334, 0.03674338098555323, 0.016311582388176073, 0.018707867110929182, 0.04994807081417211, 0.033443993513262084, 0.044870022534122395, 0.00801455905480731, 0.0365087972022593, 0.09651268366724254, 0.017496103706258922, 0.0756695379893626, 0.010961415846982311, 0.3751500695943833, 0.13460255227982998, 1.5857643730217412, 49.209730625152595, 66.39686246072093, 33.41760935321931, 41.48545019088253, 43.10326314741566, 35.49079379727764, 33.6572975497092, 34.59241805538055, 31.0929480291182, 46.451217897476695, 51.00300296660393, 28.241645751460908, 8.19740947215788, 12.408354301606456, 58.72933480047411, 63.729823327833614, 60.74260504015031, 67.19701813113305, 60.1979878640944, 28.52416623023249, 1.2165782672743644, 0.14715569965060682, 10.046214730508867, 46.89415154918548, 72.72051549726918, 67.08190441131592, 65.07751441770985, 59.22021942753946, 55.75861792410574, 56.75745341085619, 59.069925969646825, 62.705704242952415, 67.20094834604572, 65.7216303579269, 61.96425860927951, 64.96252621373823, 59.20910735284129, 55.099506762719926, 49.88906160477669, 53.15198721424226, 58.121877331887525, 60.13694401710265, 55.719339309200166, 58.656131605948175, 56.91916488832044, 61.47717475891114, 57.30835814629832, 60.1196934330848, 56.46128700625513, 50.47470285046486, 53.661275602156124, 57.14503065232308, 52.03497071419993, 74.01518006478587, 50.52334024060158, 36.96517744371968, 13.240406686259856, 1.2428232138195348, 0.667128547305061, 1.2142684815391418, 0.6527566152714914, 0.7342930078025788, 0.10644777918294554, 0.007903754970269098, 0.07764502593706693, 0.10757079513202752, 0.11039629593611726, 0.09879108278020736, 0.10935989388775443, 0.08626839506529993, 0.043783836262000185, 0.010974746734474697, 0.14117774703810293, 0.027301190270771904, 0.06003438442524883, 0.28026140805694366, 1.432247830014075, 0.11588595176656401, 0.040722889825701714, 0.016523375055722652, 0.05166560163601272, 0.021473553685110905, 0.06676646249909556, 0.06412043311302701, 0.023077900761798508, 0.040698417146960576, 0.08914187595608736, 0.019994915891138297, 0.10664109380975847, 0.08500789697732657, 0.08198970207764257, 0.03549447763831385, 0.432919503580178, 1.527752640747255, 4.150915405442638, 10.227370377509825, 17.05391441622088, 19.793992004086896, 47.29396266321982, 49.085646444751376, 50.88818734691989, 52.505996381082845, 52.357734710939475, 41.03990816300915, 53.79083148894772, 49.64055984250961, 52.13247299194337, 54.13396827636227, 56.577957907030665, 55.50726459872339, 55.97188895748508, 54.363066073386904, 55.12955996298022, 52.24694736542241, 52.24526466861848, 53.28191572620023, 52.63318707866054, 51.99387604190458, 51.10927174168249, 47.72503114515736, 49.44025616491995, 49.9820335449711, 52.462905222369784, 54.679173807944025, 53.848486408110595, 58.31518350108978, 58.58657229331232, 59.85526292554794, 60.872133470350704, 61.9398340102165, 59.67424946446573, 43.98525514910298, 11.619234219674142, 0.2944601735761089, 0.13837043316133563, 0.8669109786710433, 8.798557808322292, 64.28467789003926, 45.718397555812714, 48.074290752410896, 71.76119004526447, 65.35662635680168, 19.691543617556174, 3.20012086341458, 29.456086081843225, 30.90548815265779, 66.59283191927018, 54.423160706796956, 42.247598094324914, 30.519091544612763, 29.60001353294619, 26.479638622653102, 39.57179638647264, 33.038241632523075, 37.18485762996059, 69.69902746139034, 35.598627598054954, 1.0005928924487484, 0.11614274443878282, 0.12720172158292226, 0.036049106143294804, 0.01979266676390844, 0.05959275388909925, 0.027540571679691636, 0.20588603771982655, 0.13997239961979852, 0.15027818209942312, 0.12468448689868375, 0.3014762825783222, 0.18042027920244202, 0.14101697582631342, 0.22920549366502996, 0.12451620802523629, 0.6905050768006233, 0.2624714981404043, 2.6082320174863263, 68.741576902328, 77.49163950643232, 42.660941385453754, 52.603694777334894, 50.755646536427165, 40.05198078770792, 44.1719638916754, 44.54282791383805, 38.599534957639634, 46.134949345742505, 58.92571610789145, 30.010564096512336, 11.880614103809481, 19.920282517710042, 63.70737560333745, 72.29211422704881, 65.89362236761278, 72.40742406537457, 64.796307932946, 31.30382053313717, 1.1243748664855957, 0.799574485469249, 14.442350345273173, 53.13281074646981, 74.8379207426502, 69.78917921743086, 67.54849387753394, 62.45055406324325, 58.51255324579055, 60.8503996172259, 60.90448125716179, 65.8219841987856, 68.10300719353461, 67.27355926267563, 62.68043241193218, 66.83987848220333, 60.43202392516598, 58.710617250011815, 52.32449262372909, 56.555922031402595, 62.110672843071725, 64.41090368455457, 57.80922912782239, 61.17479531995712, 59.93837794949932, 64.72962764001662, 59.53413847954043, 60.98499574968892, 59.52015915224629, 56.55603578013759, 56.135338044935665, 65.25367982925908, 54.21352963293753, 68.82435460244456, 44.755585116724816, 45.24160992714667, 21.87973979980715, 2.1192752353606688, 2.0705446889323573, 3.3470827581421023, 1.4169496057494995, 1.328568432119585, 0.20603695704090982, 0.12704658877825545, 0.25505307040387587, 0.24852656819407018, 1.0260957142999096, 0.32150047260426706, 0.17576297024084678, 0.1276605086581361, 0.20097058777126575, 0.07950147914309656, 0.15635670673462654, 0.26231304051414617, 0.3944743616927055, 0.43363027995632547, 3.0968728036649766, 0.3076494190721743, 0.10123240581202893, 0.18340590770446485, 0.10108897883084514, 0.11416649806403345, 0.1441449128211506, 0.13581465659362657, 0.16324304044246674, 0.544188411966447, 0.15644476088064332, 0.21943479295699828, 0.15329819262748764, 0.2032797912796659, 0.2822727259368666, 0.12585317700981133, 1.7565326032138642, 2.497256153052853, 6.28033192888383, 15.22595851652084, 20.485882413002756, 31.047980016277684, 54.90869914331744, 47.84175303674514, 57.04836776179653, 53.658957481384284, 55.25504442953295, 45.26386545550439, 57.13600527855658, 52.99309984330208, 54.1184356904799, 57.73811263422812, 60.36269995474047, 59.90879151128954, 60.68714272591376, 56.84377301123835, 58.29867032266433, 54.641805387312374, 56.53797718786425, 57.11288290639078, 56.856450111635276, 54.233878889391505, 55.896567683066095, 51.602199923607614, 52.11461051817864, 52.88638784039406, 55.33578641953007, 57.64535250202302, 57.341859109940074, 61.23983606215447, 62.149469006446104, 63.92320794443931, 63.64934413663803, 63.93692839530207, 62.5501665761394, 47.38150604309575, 16.51071321579718, 1.4390910176500198, 0.6908644026806278, 4.355431708597369, 8.141021968856935, 65.3501779802384, 51.454993371040594, 52.80056245865361, 72.58550751593806, 70.77152898234706, 25.58212580219392, 5.709980082127356, 32.882849093406435, 38.16761532137471, 69.91482057879048, 59.80851611783428, 43.525337634548066, 44.58097296376383, 31.489601635163833, 46.56789664299258, 54.01684238064674, 38.810707522976784, 49.321192618339296, 79.35607540992, 56.759736230296475, 1.8061447023384034, 0.4110241591209366, 0.30453634418306813, 0.18465780262504855, 0.12777492388962738, 0.16888932294903264, 0.0990571680989477], [0.09507007115790922, 0.05129608295617565, 0.10480387707150753, 0.11632146509063822, 0.06552644960221744, 0.07333205817567726, 0.05806671823525141, 0.06628126837313175, 0.09035906709370115, 0.24751228310408133, 0.04406548465692228, 0.4496835298355549, 27.538733482360843, 55.995780114204656, 29.866803346141694, 26.335095359433083, 35.72209204396894, 29.890194400664303, 33.754038887639204, 39.075271391099506, 28.518388578968665, 36.88170548408262, 58.97387496886715, 32.79504879828423, 9.516331938005264, 2.263449795784489, 39.4601696537387, 69.09870086177703, 59.071577287489376, 62.24773222400297, 60.71771760140697, 37.568335994597405, 1.827157084499636, 0.14959857018003542, 4.832985670335831, 42.96581545183736, 69.00375596938595, 66.53964457973358, 66.46996759599256, 59.602681898301654, 55.3626036643982, 53.66472728790776, 63.02577749375374, 60.384123940621656, 65.0938432447372, 62.20896351721979, 63.46424748820644, 64.24526199217766, 58.41405860839352, 56.37160593463529, 50.60899696042461, 50.99615058591289, 56.699782802212624, 57.51818926103654, 57.337116964401744, 55.76005351158881, 57.09163542716735, 58.31093557419316, 58.12784325691962, 54.92563986009168, 48.235264824282744, 53.55306525384226, 58.37112826685752, 63.318974664134366, 71.9117384572183, 62.49321768360754, 33.71269318365282, 11.273219393145654, 5.647024569972869, 1.0322668283216416, 0.3736307027359163, 0.5458644897707048, 0.2284328786716346, 0.3386034161573456, 0.0685734494078544, 0.1444906483013784, 0.08061728620481107, 0.24117601584763299, 0.2891175683227278, 0.2744087721070936, 0.08148667342480152, 0.05822105813891657, 0.008783283279157214, 0.06763443245642609, 0.05282894445342883, 0.08407087185450139, 0.02340159972288436, 0.08376172473353725, 1.0380007206432282, 0.24667061294519135, 0.02304636283717569, 0.014826985387762469, 0.09348746374129288, 0.11671908004509828, 0.08192177306139663, 0.07043026267520844, 0.07405104701437297, 0.06779059181891142, 0.0232551179661025, 0.2953473646794596, 0.26740363348395596, 0.16780726972126192, 0.12633301618118442, 0.11271136001713815, 0.37135588125355784, 0.37698831289045276, 1.5182264293393783, 4.371621291483603, 6.681154033830089, 13.642193694268505, 33.43715060141779, 49.180301081749704, 46.88163526596562, 46.173741586746715, 50.03795085414764, 51.126259526898785, 36.912598071559785, 47.61072151122555, 47.25998709278722, 49.55252224399198, 52.45499772410239, 55.8903899500447, 52.48762792156589, 52.61803496268488, 50.500547347530244, 48.53138023807157, 46.82026586224956, 48.06324928037582, 47.671255450094904, 48.43349749042142, 45.350867548296534, 45.85559814207016, 45.090343721451305, 46.441839510394686, 47.79171143808673, 48.37941585048553, 52.545553484270656, 53.7210839025436, 55.386969427908625, 58.13952015292261, 58.89953428699125, 56.64244559503371, 61.58396520922261, 40.377513977789114, 6.625417153681479, 0.0667443148972046, 0.08584095630794765, 0.15892864775753793, 21.069080022073564, 65.28052060834824, 45.94937416814989, 59.797258915439734, 41.491824042412546, 48.613914751237445, 7.817402895419829, 6.377961683657862, 37.45778399129068, 28.247078234149566, 68.18553386196014, 40.86168350711946, 31.540796410652902, 35.489483725640085, 20.24042440998939, 24.311579888866795, 33.843359101203184, 27.432121499892208, 32.827049455335064, 52.673705162540564, 18.969480376089773, 0.734142670708318, 0.1269931388237784, 0.07568958651034102, 0.09736901674900325, 0.03235893339038857, 0.09902034225242753, 0.05509478738531471, 0.08412011598627414, 0.06340352803348534, 0.12319803117744385, 0.07426554397229226, 0.0799002355685638, 0.06196215658658936, 0.06570683266486853, 0.02862420304858637, 0.05661886185407639, 0.05761830399053232, 0.17537372096651987, 0.38491517786056767, 39.484052965717936, 70.88755269204417, 36.22943101390716, 27.463351411204187, 39.86884924673265, 39.32985282713367, 34.02161513605426, 33.8877603315538, 32.49093959408422, 44.7083637022203, 65.3228743614689, 33.191147388950476, 15.08317541691565, 2.4814247315929783, 41.076429351683586, 72.43106026803294, 62.24020127327212, 67.06329668721845, 64.84435696755686, 41.37858913790795, 2.0645280182361603, 0.10139941297952207, 5.293464574121661, 41.667644285386615, 73.09303868201472, 69.43454204067108, 69.57776346514302, 63.628826218266646, 59.316176291435, 55.505864312571866, 65.20772926269039, 64.4795020164982, 66.00547267544654, 63.19718899265413, 64.47452452874953, 64.42096456404656, 63.240209548704094, 58.22856580057452, 55.19810338174143, 56.41921174141669, 62.90246602027648, 59.836439471091, 60.40040569920694, 59.97041979143697, 62.91834377473401, 59.63437072692379, 62.57882733498851, 58.162148306446696, 50.236650282336825, 57.16484254406345, 60.77392124360608, 65.04004401545372, 75.3032236714517, 53.338609664670884, 34.31715003905758, 18.043457808033114, 7.011648531882995, 1.794869726704013, 0.85435081393488, 0.23100819048141283, 0.30237995989380345, 0.34544556191371334, 0.020275041686310884, 0.02533254540345121, 0.18503134709692773, 0.18245883916895236, 0.5357581965865628, 0.32046855217026127, 0.04892892489630369, 0.056626461446285255, 0.06134943563431021, 0.04970814356760633, 0.027638600290482564, 0.04338386558717297, 0.028605753736149882, 0.03743182589870788, 1.5445249407522141, 0.6772569038214222, 0.05397917567602089, 0.07492767376524788, 0.03926902731520034, 0.051895044969334725, 0.07619622343730542, 0.05212931465657969, 0.052422147935196284, 0.06126108271400295, 0.07992217632671518, 0.11370106134563686, 0.2492528961550805, 0.13385547865783015, 0.08593985825897225, 0.0498625562496243, 0.18776093369289754, 0.5510950316825222, 2.3520122564608053, 7.805811801264364, 10.716972389528829, 21.48394715401434, 37.2835248516452, 52.42067698509463, 48.784832031496116, 50.13042073095999, 49.72998988243842, 58.43139548455515, 40.299796135194846, 46.94780172840242, 50.974683453959805, 49.88756325937087, 55.75031426645095, 56.59272563072943, 55.59469030749414, 55.48825679286834, 55.2202686955852, 51.244632736329116, 48.90694718207083, 49.412689747348914, 49.85513310278616, 50.81183056677542, 47.50128738341793, 46.8927316511831, 48.06055068969727, 49.00571638537992, 49.72349051506289, 52.37380466153545, 56.5257276258161, 55.74785886272308, 58.37638032051825, 62.57606206401702, 60.16598524585847, 60.06051663429507, 67.43473729779645, 41.5434463562504, 6.964379558640142, 0.2840581398096777, 0.24260737452535863, 0.787594463796385, 26.999899841124012, 68.71292791058941, 54.262955419478885, 63.71137642091321, 47.928190308232466, 47.93499169811126, 6.3339620059536355, 8.670909174026983, 42.70202821300876, 26.95303143993501, 70.94365043024864, 43.36053925175821, 36.42293330161802, 33.225189639676, 26.762696466138287, 23.515391695883967, 39.839957068043375, 30.222574087881274, 37.21086686657321, 67.26154112046765, 32.59374295511554, 0.8057310744639367, 0.09766189216245567, 0.05704606312417215, 0.08968611247837545, 0.05119304413035993, 0.04566156756012671, 0.026544866137086388, 0.19269427945536954, 0.19218380442790448, 0.15855167121175798, 0.17382187198006338, 0.2893851168694035, 0.18353764418392413, 0.21524879660817886, 0.1545171151238103, 0.17547127460279774, 0.33848690950582105, 0.3266677356535389, 0.9961676008759007, 55.085974585625436, 84.12610900017523, 46.74354430167906, 36.460568443421394, 46.90869569778443, 41.445669512594904, 49.73477517404864, 50.356137444896085, 40.83288546531431, 44.700067889305856, 74.37571648628482, 39.7724687668585, 17.726485190852998, 6.326875753941075, 49.2299622105014, 80.53940742246567, 68.52843530716436, 74.88530297433176, 73.6462027026761, 46.60476692261235, 2.776002331126121, 0.43335209810926073, 7.877026844409205, 48.03172911367109, 73.2942170481528, 72.89375874304002, 72.37314255006852, 65.23361690582769, 62.00543957371866, 57.140970999194735, 68.1163275626398, 65.35027211712253, 66.43665882848924, 65.86812696149273, 69.09685734779605, 69.98981629648517, 62.92114826940722, 61.7998642306174, 58.04651291139665, 57.968249859348425, 65.47380716569963, 64.54940257533904, 63.02019596099854, 64.0514341477425, 65.96156566373764, 61.980363861207046, 62.17181082694762, 61.62031773597964, 55.503012749456595, 62.67376046026907, 63.047483890287346, 65.13890343327677, 61.81871121929538, 57.12798010918402, 39.10412434608706, 35.23515332129694, 11.023600735972005, 1.9568394677292917, 1.5547586496799224, 1.8783370285264909, 1.6277392496985774, 0.5263669392274273, 0.20364544504592497, 0.22433044719359568, 0.5257502078048645, 1.642368954996909, 1.3010840165999629, 0.48879875350863705, 0.18268520282881875, 0.1913998513332298, 0.10905749600140319, 0.2748380571363434, 0.15764944946333287, 0.16879383775015033, 0.07900586622136255, 0.14016666419563756, 2.4244020494722553, 0.6399698110838091, 0.14431167484050797, 0.21554692738479186, 0.16975693284503876, 0.2070729224191558, 0.21594832681359785, 0.17126978795614936, 0.1637153030042687, 0.19180725689136213, 0.12426175958206578, 0.5639988941050346, 1.1546086183478756, 0.5072759055802899, 0.3157583371766152, 0.217208786597175, 0.5659230618226914, 3.2603961710006963, 3.846573555661786, 10.373146245556494, 16.065914477071455, 28.514779998410134, 48.8128299097861, 53.998407240836855, 52.61947055016795, 50.99248709217195, 54.50696214552849, 60.458417554055494, 45.96976264830559, 48.17565656477406, 53.84929833873626, 51.31599241687406, 59.36912828876127, 59.587278750634965, 58.87174037195022, 60.80782621137558, 57.73617106099283, 54.26956461321924, 53.07582263023623, 53.23620834658223, 53.980183909016276, 56.32334116966494, 53.67312116007651, 49.11732742863317, 50.8814565597042, 51.06620411719046, 53.349784497291814, 53.25209786815029, 57.36788403603339, 57.226651253238806, 61.327340218328665, 66.54677544870685, 64.52492306309362, 62.313145591366684, 72.05397144440683, 44.83796665745397, 11.582466902271396, 0.6315961023492198, 1.0197507289628829, 0.8640372909365163, 26.895382404327396, 76.31433225447132, 55.26323826082292, 70.98449014848279, 52.44073206378568, 57.24329386987994, 13.40264670310482, 10.700906361303023, 46.54080090984222, 34.48108157803936, 74.40777009533298, 45.82230506404754, 37.94356953713202, 53.2936514577558, 30.835787634695734, 35.251921453783595, 48.77170778089955, 40.03942528078633, 47.635471667012865, 74.8591015415807, 49.507803301657404, 1.3584752789428158, 0.24928110351245253, 0.29731302371909546, 0.2583435406127284, 0.15258038356419534, 0.2994625132170416, 0.2169292870788805], [0.023654335959544106, 0.013962942588653778, 0.11289947290694523, 0.044194045701935414, 0.030553900005836642, 0.01352834569725899, 0.05802060357264935, 0.028823037338893742, 0.035848992486153884, 0.060635081627556396, 0.09945929531128177, 0.1606458338398126, 26.343279384797622, 56.674711012071185, 33.56289002203172, 36.72127662166473, 33.64252982601043, 31.980413698380996, 36.7283643445661, 39.94700247241605, 28.56297023834721, 38.14594030380249, 68.71189240486392, 59.64052884809433, 17.026267590061313, 2.406073303953294, 25.712126878000078, 67.79414407668575, 59.21859948865829, 62.291913801623934, 60.99275419788977, 41.18936223368491, 3.9982084641533517, 0.21572505814894555, 1.7441227142849278, 26.774781288639193, 63.07402656924341, 70.7250802747665, 65.04310346418812, 61.405144353066724, 56.70496033084009, 57.54505749671691, 60.6073970179404, 63.66988166686028, 65.87168062886884, 61.988122309407885, 60.988333686705566, 62.314679238104056, 58.21288024225543, 55.01907071759624, 49.87050879386164, 53.691866167130016, 57.419455359059, 59.62550617033436, 57.13702509480139, 57.40526814614573, 58.8404869264172, 57.641602716138294, 57.92473116228658, 50.34946941560315, 49.562657648517245, 57.18838853220786, 51.72020050787157, 58.002460771991366, 49.24768347893992, 31.759597985975205, 10.852451055280625, 8.916132815422552, 3.656357723859049, 0.46369236683653253, 0.5271579709745223, 0.26436560456791236, 0.07293836559138953, 0.14755386618837235, 0.048902717028414054, 0.2704383529001667, 1.5040795432944454, 2.597282721150306, 0.8343936719240681, 0.9738238804763364, 0.006034966312243694, 0.08539338475994526, 0.08063750326513283, 0.02699113533561749, 0.05473102968666823, 0.09558567897446694, 0.003103523209105216, 0.06070243990829876, 1.0279140393099477, 0.41294884777838187, 0.17293864921216043, 0.06994464720088629, 0.14846207874436534, 0.08459352001908325, 0.04320901750977482, 0.08058916311711073, 0.07423373600167614, 0.18991463667442723, 0.392943840594061, 0.6749788034827479, 1.4152953461293252, 2.0244915278688556, 0.5638114170682046, 0.12252277063746607, 0.18945645480867357, 0.5944801230103739, 0.4414566035472578, 1.9050310864563913, 6.271542877920213, 14.154983778153698, 28.808924421187374, 45.87995606084024, 47.2148641463249, 47.456191893546816, 43.10351417910668, 54.55876881076444, 50.747821407933394, 39.95381562940536, 48.27533575796312, 48.28727937513783, 51.312917278658965, 51.68016487552274, 54.4815569539224, 49.08171622983871, 52.67430136280676, 48.1195862831608, 47.92169878559728, 49.086913370317035, 46.572721158304525, 45.10260112823979, 46.03907485162058, 44.3749818494243, 49.90206426189792, 46.887118739466516, 47.24391714219124, 52.316145820002404, 52.76263313908731, 50.555452685202326, 55.883321838994185, 58.60766287772887, 57.812543530617994, 57.666368561406294, 63.67205465993574, 31.336548789854977, 2.3640394691498052, 0.12959652009510225, 0.3878834314884678, 1.0146357131100472, 41.56763953547324, 58.06136300486904, 55.554517392189275, 47.56715966809181, 34.41091037565662, 44.772412084764056, 0.6946117370840043, 13.279519581025648, 22.8718170427507, 32.419727002420736, 60.32361353597334, 38.988002577135646, 29.982717229473977, 36.67223130503009, 22.052555507229222, 24.892045567112586, 39.561535466101866, 40.772410361997544, 43.18773923381683, 62.75907985625729, 26.008065785131148, 0.4046862217928133, 0.21293994550022388, 0.007904621128428487, 0.028796032739562855, 0.02499707358618898, 0.13023215856763626, 0.0086299728061403, 0.037166866729216236, 0.09730847282034737, 0.01362719593734871, 0.05899637359224501, 0.0966856203552696, 0.00865967690779437, 0.0290044718572209, 0.012940165414024266, 0.02481881833274759, 0.03748012774233376, 0.09651725721215049, 0.11364799443512194, 36.66053087480607, 73.74257533780991, 36.515705200933645, 38.05165829197053, 38.655169856163766, 35.61388169565509, 36.638989217819706, 32.740786729320405, 30.070670497032907, 42.65205721701346, 75.50379799258324, 59.04240269814769, 24.845008504006174, 3.0927677981315123, 29.65581120983247, 72.28361837325558, 61.06566713702295, 66.68688251126197, 65.3359083975515, 46.45075113542619, 5.955139004415082, 0.04282985761341068, 1.6411270345410995, 26.389616304828277, 70.21237942480272, 70.8612100539669, 69.74822967283188, 64.1977071762085, 60.4794571476598, 58.3642170506139, 63.666661400948804, 64.98338145594444, 67.78451858028289, 63.214317983196636, 62.296365691769516, 63.04164348110076, 61.585098774202415, 58.67945794136294, 53.207743706241736, 54.343948441167036, 60.402021715717936, 61.775059161647675, 59.317447139370834, 58.31190047725555, 60.52632947121898, 58.36955539641842, 62.05892109101819, 52.92293256328952, 54.989719621596805, 55.95624262286771, 54.84111670524844, 57.1620733507218, 48.00336645495508, 35.00953466661515, 24.423098756421, 10.5504059983838, 4.056786120899262, 2.421435757029441, 0.46203412355915197, 0.36442686112657674, 0.13003338939480244, 0.22501912959400686, 0.03826053384991904, 0.2216573825646793, 0.668903419808034, 1.9529439412778424, 1.310116009366128, 0.6485433155490506, 0.13895883465245848, 0.04214734988166921, 0.0468917707011344, 0.035835042025052735, 0.03218726457787618, 0.06785837527845176, 0.048815536222630934, 0.04616399100350757, 2.248150100631099, 0.37996309358746777, 0.06709947325890103, 0.08958601543018896, 0.06987956037083942, 0.014461042423311983, 0.05679973904343863, 0.03716314737234385, 0.0786071787438085, 0.23399372705288474, 0.3672712843023962, 0.5847335847154741, 1.0346359399057206, 0.7883732994237255, 0.42803615271564455, 0.36427152913904964, 0.08448560121318988, 0.9673977511063699, 0.5984481520229771, 3.5041957468755784, 10.619463247637595, 17.304181245065507, 32.76364826386975, 49.35079474602976, 48.0846614991465, 50.7307473305733, 47.5787228153598, 53.547036570887414, 56.44866481904061, 43.418009819522986, 46.7260975991526, 51.27867498705464, 53.53838382228729, 53.88874169318907, 57.0037547234566, 55.04573891239782, 53.629312207621915, 50.94881150030321, 49.35551727971723, 50.721898463464555, 48.63094960489581, 46.71679765947404, 48.5115683463312, 47.307224196772424, 50.531043775620006, 51.456472104595555, 52.309673909218084, 54.2879605293274, 55.52627240457843, 55.854602244592485, 59.29944738265007, 59.405480815518295, 61.51189950204665, 63.0195644594008, 67.5473250112226, 30.82284381312709, 2.302824263611148, 0.32662250582248936, 0.2871921442208752, 2.8402894879541094, 50.83235632988715, 62.72044058768981, 60.66679739182996, 51.08065412890527, 40.79035128316572, 45.28177107534101, 0.7805480483558871, 17.829563117796376, 29.858838973506806, 32.86113092976232, 63.60414274277226, 41.179489627961196, 29.921438040271884, 31.737909240107385, 24.545668901935702, 24.092362542306226, 48.070462519122714, 44.219903099921446, 48.70853408690422, 74.69588387397029, 38.874371513243645, 0.2523896278392884, 0.07791912453549524, 0.006147145524605989, 0.013704283534729434, 0.0732980974979939, 0.0721104696933781, 0.023781724890033086, 0.09978631526351937, 0.16234760623305075, 0.20202307000515923, 0.2028134582383979, 0.15216318740239068, 0.07714976541577809, 0.23522599480084835, 0.14743524513417675, 0.16529843902155278, 0.2044011448179522, 0.1838712448314313, 0.39610493387426104, 52.80560270432503, 85.96817954894036, 49.312265303827104, 53.174583988804976, 45.573520891128055, 40.52761916191348, 51.214171609570904, 50.986160309084006, 39.07458497631935, 46.57150914592128, 80.03847368301885, 67.7150063360891, 24.148560300950084, 5.500955995052092, 36.28332830244495, 77.94870545787197, 69.75794930611887, 74.43142198747205, 72.15363887048537, 50.388814710801654, 5.3942616428098376, 0.5784180171547398, 3.3666691135975624, 31.380247915944746, 68.92121361147973, 73.67021545287102, 74.35473965060326, 67.02018199428436, 63.741143288150916, 61.77442373767976, 66.06045646052208, 65.7266470693773, 68.90702247619629, 64.55057928639074, 65.14157064499395, 67.00549664035921, 64.78615291656988, 61.718722158862704, 54.86545501216766, 57.520927075416814, 63.08167519107942, 65.68491305074384, 62.018179432038345, 61.48357214466218, 61.762421284952474, 63.52085121216313, 66.18232450177594, 55.97325001993487, 57.33396730115337, 59.116523727293945, 57.26843626268449, 60.633751423128196, 58.77590902390019, 47.96556657360446, 32.793201361933065, 18.39972472959949, 7.561510897451832, 3.3466613484967143, 1.2468734287446546, 1.0531555332483784, 0.3188671526168624, 0.6346532221763366, 0.11135904629143978, 0.9225394420566099, 4.275078033247302, 5.851914969182784, 2.3809294402599335, 1.089046568639817, 0.23523102033763166, 0.15970806561170087, 0.21426576790550064, 0.0930142435695856, 0.20063753870706405, 0.1378936660025389, 0.0888222564131983, 0.1109536249010313, 2.8731302676662325, 0.37272543195755253, 0.3322202796416898, 0.21172425589494168, 0.23983804328787714, 0.13264541213791217, 0.17103372562316158, 0.1652738169556664, 0.1683219888758275, 0.31708333220693374, 0.7685099265748455, 0.7937302151995321, 3.1726083784334125, 4.992025523416458, 1.350661182115155, 0.3326547740688247, 0.24363275256849107, 1.7658289882444569, 1.3056218311671288, 6.644339157689003, 14.698824324915487, 25.450604807945993, 40.47794626605126, 53.40021048822711, 50.55288353273946, 55.121381821170935, 50.82473908701251, 56.87274363733108, 57.16981218707178, 49.16794953807708, 50.26932362587222, 53.6407341495637, 56.83685002788421, 55.87502602607974, 59.853097777212824, 56.179711818695075, 57.11557757469916, 54.724810584898925, 53.04808755074778, 54.188885381144864, 51.63479874210974, 51.28880254683956, 52.51564933407692, 49.4093478879621, 54.78090832310339, 54.73823293562859, 54.69816984668855, 57.29675577532861, 59.265091342310754, 58.66876163790303, 65.90119254204535, 64.25898244304042, 63.88946379384687, 65.53552173799085, 71.71062284900297, 37.06815535022367, 5.589531938875876, 0.7684409173746264, 0.5807988958493356, 2.11993174206826, 51.459198151865316, 67.77329275684973, 66.00647680221066, 56.62166095549061, 44.31595017833095, 53.52422014359505, 3.099718238076856, 20.942181541073708, 31.237095132950817, 35.419457650953724, 66.45143831929853, 46.990469271136874, 37.93994918946297, 54.22542225929999, 31.038811475999896, 35.00744012094314, 56.087383147208925, 54.48560483994023, 57.77473972689722, 82.40873059918805, 52.78498280432917, 0.5140863046530755, 0.4213406361879841, 0.13465859927237034, 0.16734023187910357, 0.2763550644440036, 0.21942409836957533, 0.08191552178393449], [0.0627758645362431, 0.07983622892249016, 0.08132941855658447, 0.028428473329592138, 0.06728063007035563, 0.0906185180910172, 0.06850926656155817, 0.08648608660986347, 0.1220678446453906, 0.1244057458074343, 0.18134707705147807, 0.03966763435352234, 23.135113985307758, 57.27913648851457, 42.31030894863991, 28.337435914624123, 30.86761178508882, 39.41084192645165, 30.500140613125218, 43.04383139456473, 29.47138332551526, 43.64026308059693, 68.542312652834, 74.65543639275336, 37.733067697094334, 2.618183315761628, 10.543891922120126, 65.13275315684658, 61.743464469909675, 61.90437186148859, 59.173821710771136, 47.73647269895, 8.35961320707875, 0.2547911909078398, 0.06499608693223807, 20.526643683833463, 60.66533827012586, 67.61085956327378, 64.25384021574452, 67.59141245195943, 57.4975222925986, 56.87729750910113, 63.92030931288197, 64.42900934526998, 66.54672053552443, 60.94292440722066, 60.293772143702355, 65.15050972661665, 60.651225582245864, 60.2965295699335, 51.15923489293745, 52.02103845534786, 58.3348737993548, 58.40723368429369, 57.3493782935604, 58.420087291348366, 56.02686489782026, 56.44737435925392, 55.24237517387637, 47.60518704691241, 52.436966588420255, 54.0864997525369, 44.68914801074613, 42.13789724534558, 28.107553643565026, 16.400836840752635, 8.753986935461722, 7.177201970931023, 2.0013306674457367, 0.8813314500354952, 0.33305810403919994, 0.12829132843762636, 0.32209471168537296, 0.08168903555000022, 0.8328845400002696, 2.8297540016712683, 4.618974289586467, 3.239055535485668, 1.4744540039570102, 1.418218247352108, 0.35497707465002615, 0.06120054261578668, 0.07564906045914659, 0.06548409260088398, 0.028610108945999416, 0.011084159411820433, 0.04972768647055473, 0.10431167324103656, 1.6121952644278927, 0.7646358505852762, 0.017867390133981264, 0.03573181550769556, 0.09362103117089118, 0.03099113511252067, 0.03477730059755906, 0.0011093905965437092, 0.08087762586411931, 0.15043958150331052, 0.3006436675786972, 1.829995777337782, 3.6433972322171737, 7.1755830126424, 6.3655478723587535, 1.7674274766637434, 0.7956319518627659, 0.24106082686733818, 0.49976530214471204, 1.1828055569241125, 5.735603945870554, 9.983950045800979, 23.342626979274137, 38.05001089649816, 45.716985502550685, 41.818380971108716, 46.4165323780429, 44.7898038741081, 54.37109516512964, 47.019008436510646, 38.05231725015948, 41.78925737257927, 46.65459279091128, 54.744532262125325, 53.923741002236646, 52.44765504713982, 52.85021574266496, 52.398688177908625, 45.91714405244397, 47.089379679772165, 45.71945267338907, 48.60883135949412, 46.64411614018102, 45.95301805003997, 46.15475339274253, 47.208808006778845, 53.193819292130016, 53.96876588944466, 53.771596185622684, 55.92485581674884, 55.805196069901996, 59.270437532855624, 60.94929825875067, 60.67521087584957, 62.29956634583012, 22.82375035747405, 0.48017110194890733, 0.1480042799225738, 1.4755010316448829, 14.57259362743747, 53.11167701598137, 51.58172122893795, 57.676813833175174, 53.95250766508041, 69.03372287750244, 29.41894319749648, 0.35993602307092765, 17.56060815626575, 24.349897523080152, 52.93316210469892, 67.9894624217864, 33.366398888249556, 31.731692283384263, 36.26683081350019, 25.583906558252153, 27.957942678082375, 37.04590766660629, 25.893324690480387, 36.68810121474728, 63.12264434752926, 23.208342675239813, 0.1383213728906647, 0.029128637472768466, 0.0347813876766351, 0.11188512652992241, 0.05153393410446663, 0.05217306593793535, 0.047615359897815415, 0.043151652846004696, 0.04544055502441141, 0.03927080463918467, 0.02578689108392404, 0.0387580351783864, 0.06095884187567619, 0.07766338140373269, 0.025254844935731064, 0.06257090537298111, 0.02208220862573193, 0.14770762003477544, 0.06962285962917152, 31.11610766380064, 70.94781598737164, 46.2496433719512, 32.249449068500155, 34.24004800858037, 45.90065833060972, 31.05907640149517, 35.314357742186516, 26.488973863663215, 40.057495640170195, 75.33829750553255, 70.51060507374426, 46.09843992417859, 3.8668240174170467, 9.675785110842797, 65.71073009121802, 70.27789085142075, 67.38587241018972, 65.42282812057003, 52.95065587566745, 10.275859698172539, 0.1498414506955493, 0.03764200212073423, 20.0500560960462, 63.69879737977059, 69.29078717385569, 67.21594748958465, 69.18124321968325, 61.9267999741339, 60.99734337099137, 68.19505737673852, 66.12147285092261, 65.51050093866164, 63.66057388244137, 62.27516920335832, 64.14877560830885, 64.97928650148454, 62.144436605515025, 53.982145094102435, 55.292993360950106, 60.078457555463245, 59.23999601794828, 59.18202730917162, 59.784456299197295, 61.16594645284838, 59.25205338385798, 58.816085861575225, 47.82535360705468, 57.7981758886768, 53.75237264940816, 50.65002495242704, 45.85369971490676, 38.61517736988683, 23.934465569834558, 12.958259813247189, 10.584163877271838, 3.483729554760841, 0.16629632982996204, 2.251523093831155, 0.09778421342132554, 0.3833021337707197, 0.12030384293006313, 1.163905371100672, 4.9722209861201625, 8.860265516465711, 7.148815777993972, 3.2782331493593033, 1.547387167811394, 0.023208612598659053, 0.049735611650131406, 0.020161413610161796, 0.08876181207597257, 0.13800166907810396, 0.016597258490360072, 0.07906765887333501, 0.1029123293776666, 1.513869901818614, 0.303351481955859, 0.0087832267801728, 0.11305023134956438, 0.11374171763177841, 0.04152381559833885, 0.15323270743172016, 0.062111566714461774, 0.05121725633920682, 0.044431847054511316, 0.1453461386864224, 1.9690460062796071, 5.072606696236519, 9.149192206321224, 8.253308150076098, 2.46062072534715, 0.8641540427361766, 0.41076151353697626, 0.34862715570676717, 1.7938896244572056, 7.895209971935519, 16.99892278640501, 28.000851446582427, 44.719146297824004, 45.99630140489148, 48.40844923450101, 47.640911994441865, 48.95896565529608, 49.913282240590746, 56.420035439152876, 39.85571322902557, 43.318138430195475, 47.453324640950854, 60.40892508722121, 55.85646537042434, 55.15467097682338, 56.11245885972054, 54.13965179074196, 49.57150651562599, 49.94314324471259, 47.8211292143791, 51.22508364339029, 46.15086632390177, 48.88376597435244, 46.37271558084796, 51.53961458513814, 56.888511565423784, 60.144725999524525, 58.77396745066489, 60.2906067909733, 59.54020246382683, 63.24384166348366, 64.60534341873662, 64.35074629322176, 63.3325146859692, 22.747638725465347, 0.6514661554847995, 0.2372352902086512, 4.005469016490444, 23.43190404676622, 59.526968386865434, 58.59325993445612, 63.07232033821845, 60.18715427767847, 69.21038643006356, 29.28590620717695, 0.5119161920682077, 24.31866761176817, 28.658479952043105, 55.685736363933934, 73.26421876107493, 36.563075665504705, 26.6435387826735, 35.54208270965084, 31.902064354188983, 26.66734560843437, 43.80660295486451, 25.46606286879509, 43.165283664580315, 71.25750280195668, 28.785354898821925, 0.11527934802636025, 0.03524215508913321, 0.05426941957745341, 0.04274834968870686, 0.05268695771754269, 0.15054082768338342, 0.08636321376768813, 0.17521817447437396, 0.16347571666682922, 0.16062498092651367, 0.07496364925417208, 0.1823991915631679, 0.26841928221045, 0.22385872089334075, 0.1350324808229362, 0.26310526735840306, 0.18954748137583657, 0.290056393752175, 0.2239582050711878, 45.151371878962365, 83.1842145612163, 61.476472654650294, 40.39752983277844, 41.09353873037523, 50.22928407115322, 44.178612309117476, 55.85628494139641, 39.30079983126733, 51.5707621266765, 73.16756371528872, 79.19374419796851, 47.92149482234832, 6.467409864548714, 16.691454072152418, 76.07877823614305, 73.95750553377214, 72.20379814024895, 74.40203559014105, 58.23672433053294, 11.613669356992169, 0.47613486046752623, 0.6083892766506441, 24.857348280568278, 68.01116097357966, 72.65136411113124, 68.57605288105627, 74.29998336299774, 64.31372696353544, 63.203123538724846, 69.89134127093901, 68.68426322937012, 69.88862699077976, 66.99305488217261, 65.27997147652411, 67.79579147215813, 68.09546839806342, 65.54542964504611, 57.15779796723397, 57.49409806343817, 65.87503817773634, 63.657498744226274, 61.588236670340265, 65.19637007867136, 63.10226371211391, 62.35640541199715, 61.513111514429895, 52.379790198418405, 60.52316804086009, 56.905856286325765, 56.44622510479343, 54.65198393790953, 48.38715076446534, 35.22886183954055, 19.79493925648351, 13.933515971706761, 3.1290369745223754, 2.1127064910627182, 2.220862416490432, 0.9127215656542009, 0.5509869213546477, 0.166384736376424, 1.4366460327179202, 8.660320735746815, 16.63611335139121, 10.13943378002413, 3.8369843411830167, 2.481802995166471, 0.3046307568588565, 0.16421514473134474, 0.12050317134708168, 0.30123753893759947, 0.2729952479562452, 0.13448527954038114, 0.2491851893043326, 0.14825851386112554, 2.2687856901076535, 1.117301729898299, 0.08821323949603305, 0.3043488671462382, 0.2045186933490538, 0.08938557618568022, 0.17882267944514754, 0.17014389917735132, 0.15268273291087922, 0.1421044989218635, 0.7204233230121675, 2.4376564737289184, 5.614156578817676, 14.061959866554508, 14.942668272602944, 4.7033493749557005, 1.5325565636157992, 0.3917517158533297, 1.0053614526987076, 3.068969307407256, 12.002978324890138, 22.582142160784816, 34.74890885814544, 48.49061896724086, 48.85197908647599, 54.63153269983108, 50.511153436476185, 51.410937309265144, 51.92969429877497, 55.96065528931157, 44.569017579478604, 44.48425123768468, 51.85589490398284, 64.05369343296175, 59.43041140033353, 57.87500727561213, 59.36641008623185, 57.32419275468396, 52.4496829125189, 51.834694493201475, 51.610362375936205, 55.456642489279474, 51.19267702102662, 51.3948477468183, 49.790519898937596, 53.974621988111934, 58.78054918781404, 60.619117060015284, 59.550306489390714, 62.31575396753127, 61.906148695176654, 66.12474410764634, 66.25455102612896, 68.24157668698219, 67.52792496835032, 29.73984799077434, 1.4292690350163368, 1.291718744943219, 4.4905862885136765, 20.21111842124693, 65.87605014924081, 63.22564578825428, 70.5489109408471, 63.689964202142534, 81.78030413966026, 36.35000859537433, 2.4467735328981957, 24.501889367257398, 31.74171982272979, 62.29678538537795, 72.66856762670702, 40.68885603258687, 38.31115445783062, 55.914555672676336, 34.40010816820207, 38.466892165522424, 52.418209814256244, 36.55445429586595, 55.75522899627686, 83.27978703283495, 44.18981459832961, 0.17241970125225284, 0.18190422215529028, 0.2377125783072364, 0.23076805256066785, 0.1727905031293631, 0.3564834793008143, 0.2378118326587062], [0.015981941457627522, 0.03380013246750159, 0.05511547942014952, 0.05524549220177916, 0.0834056853707279, 0.07164781387414663, 0.12612051105186825, 0.04268892807886005, 0.08994979994191278, 0.11818873545815868, 0.1162947592655978, 0.14136905451455425, 21.992666798253214, 59.53624086995279, 38.251008833608324, 28.612982419229326, 37.366839916475364, 29.318903146251557, 39.53704418674592, 39.61890012987199, 47.89889804778561, 30.74139383531386, 42.52925565165859, 55.08659039774249, 47.01076753677861, 15.541462206071424, 3.593160740790829, 53.845599543663766, 53.01233514662712, 64.05111643575853, 59.99918253191056, 50.571428498914166, 11.610423595674577, 0.27430381806146714, 0.1208783016209641, 4.86013533607606, 35.46133679728354, 71.46276043307397, 64.2388528393161, 67.08913726191368, 60.27432503238801, 63.005055612133404, 60.630205600492424, 66.17403261123165, 64.91840347166985, 61.52887552015243, 59.95630710355697, 63.692278400544204, 59.53566820390763, 57.94227984643752, 51.341068129385675, 55.65504381733557, 57.78391807310043, 59.53866097234911, 58.821879202319735, 58.66113655028805, 54.836507920295965, 57.285451504491995, 54.04616209768481, 49.85818470678022, 54.713941697151434, 47.49180309234127, 40.69912872006817, 33.8118467792388, 18.641470209244762, 15.977358145098533, 11.58942714814217, 4.513319855736149, 0.3288511781682891, 1.050339884334995, 0.49327760994915043, 0.08690409482486787, 0.09955058234833902, 0.1842821284287399, 1.2258931609892076, 3.9158352584608145, 4.3181495801095044, 1.349751805105517, 0.9765428797371927, 0.4324118630780328, 0.010416115420089375, 0.12400731113889527, 0.02858411366750877, 0.00854214178323145, 0.0610462716600347, 0.06306862503650688, 0.047629773842110756, 0.045777120432185556, 0.9932162624693687, 0.2301251515746117, 0.21085408726526847, 0.01862632088182915, 0.03665028981143429, 0.060951073744123986, 0.015581717973785296, 0.03996959940019635, 0.05001021203615012, 0.030836299166924534, 0.14485866161844424, 1.2469745523506597, 2.931598343195454, 6.512382780351947, 9.248849826474345, 6.779433431163912, 1.6449795374947211, 0.1540785757524352, 0.9634139713260436, 3.254024280655769, 8.771344404066763, 12.138311862945558, 19.64325727954988, 37.8350571663149, 45.2463089266131, 43.50026584440663, 39.97250572327645, 46.61820888519288, 46.020239630053126, 57.74829902956563, 41.25277126989057, 41.31321499424596, 45.11236782996885, 51.43929604561099, 55.92940184377856, 50.920393928404785, 52.478928104523696, 51.25685876415622, 47.604253522811405, 48.74643202750914, 46.09240731885357, 46.1918080237604, 46.9932423868487, 44.80887051551573, 47.703665994828754, 56.094886641348566, 56.949214166210545, 58.93638103238998, 57.48249569246846, 57.22596483845865, 59.62809493464809, 56.98752003331339, 55.56789267447687, 62.021693875712735, 55.67875846739739, 7.263301918583532, 0.03683310903368458, 0.4892869966645395, 13.434638534822772, 46.712490897024836, 49.881691471222915, 54.692333359872144, 55.52477013680243, 58.45131720266035, 61.096198866444254, 15.524188087832545, 0.47789845615625387, 23.826341513664495, 24.669745237596576, 62.15020248966833, 58.59500146681263, 22.74189441434799, 24.469196411871142, 33.3808292881135, 16.35081485394509, 36.84150511218656, 46.80749070259833, 33.293164314762244, 45.816947106392156, 58.800094358382694, 11.00763080581542, 0.37557616769786806, 0.011392955089949313, 0.10264755406927678, 0.07121143487071799, 0.06743277513211773, 0.05873269762002653, 0.029474706201243307, 0.0787055597550446, 0.03896011002061348, 0.02874868276018289, 0.06247946511833899, 0.039810459955685565, 0.09427748425232788, 0.05176084168675927, 0.02589780337838156, 0.13287320072131772, 0.04550045160877128, 0.10958823405446545, 0.10793166850963909, 27.73615029550368, 74.83023289711245, 46.128120499272505, 30.186184298607614, 33.33853044817525, 32.02735662460327, 44.21244667422387, 30.606166201253092, 51.528443674887384, 34.65457585550124, 45.76170444488526, 55.71161223996071, 54.507738774822606, 18.310233892933017, 5.010133145316955, 57.85872551702685, 62.21148167887042, 70.87786443771856, 64.5669630266005, 58.514788996788766, 16.922577773371053, 0.5687378527175996, 0.19436333989424093, 4.336298386896811, 35.153548409861905, 72.7201860181747, 68.49803693832891, 70.0994465428014, 64.49439133367231, 64.5006553588375, 63.29335766453897, 67.7354811083886, 68.31192831839284, 64.04237347264444, 63.09204593781502, 66.5466263986403, 61.531699626676506, 60.04529391565631, 53.904062471082135, 57.751601665250725, 60.29651388045281, 60.65503420368318, 60.52088129904963, 60.64611081154116, 59.160901423423525, 58.98777977112801, 54.8753668415931, 53.21652197068738, 56.22185376382644, 50.78293446571597, 48.6212888071614, 43.147683989617136, 27.44659700701314, 20.211469473377353, 15.243276761424157, 6.867246473989179, 1.4100046816372103, 2.54898363544095, 0.8500102823299747, 0.31869223942199065, 0.2706165755948713, 0.436729044323006, 3.28009995241319, 11.245170524043422, 10.643752524929663, 4.265809962826391, 3.0835536603004705, 1.5157082676887514, 0.09213131191509386, 0.01542121776559901, 0.09509683826998358, 0.027615031595492077, 0.030385021668588443, 0.04809409590257753, 0.042081910651177175, 0.05786502260654684, 0.4963737389733715, 0.13891034128685154, 0.04981807718474058, 0.10004132295087462, 0.07017994344594979, 0.06530171004875053, 0.020543318016514666, 0.03488596633917863, 0.10976200577833, 0.08291233240837052, 0.05473247759284512, 1.576333156516475, 6.566281539778556, 13.761877955928927, 19.168840723652995, 13.805186806186555, 6.101927824558751, 0.4718225208982345, 1.6162491565750492, 4.188541231616851, 13.778761798335662, 14.99789426403661, 26.758113176591937, 40.548199838207616, 48.193773992599986, 48.64350118944722, 43.60081188140377, 50.7243146434907, 46.285882149973226, 58.011788168261134, 48.16753333614719, 42.51018116551061, 47.2533033740136, 55.39860317783972, 59.50108074372815, 54.799923973698775, 55.62015433465281, 52.40421871985159, 50.70956653164279, 51.11980722796533, 47.289126380797356, 48.46742991478213, 48.06492805480958, 48.55571462262062, 50.96957260562528, 58.45925215751895, 58.117633327361084, 62.25351379763696, 60.869780048247314, 61.03430386512511, 61.504548980343735, 62.768670051328606, 59.887324379336455, 66.55524776827905, 53.98065851580713, 5.701098855464689, 0.05061154509143484, 1.957317384019975, 23.238437060386907, 52.601745359359256, 56.966131348763746, 59.432690297403646, 61.20204010317403, 63.05406170506632, 61.67534858949723, 16.57145700147075, 1.3889296641272884, 33.005011312423214, 22.625576526887958, 64.20102550137427, 59.3345525956923, 25.903713087881766, 22.40839881281699, 37.32874585736183, 20.22936724847363, 31.11497017645067, 52.05465316772462, 30.84431878982052, 56.16488525944372, 69.05648831398257, 14.92034508335975, 0.640797186042032, 0.05232124266424968, 0.11377103581664064, 0.0358143461597783, 0.07505076111204202, 0.028096851104149417, 0.06208326359609924, 0.08783198051875638, 0.15018615961795853, 0.248302104432256, 0.22952775621125776, 0.2790051464351916, 0.228889191282853, 0.315117642523781, 0.10945698787127772, 0.21965277561497307, 0.24209712932427085, 0.2962310011348417, 0.23565638299670913, 37.48759792697045, 88.17801152506183, 59.78331488947715, 42.51078521051715, 47.61570292134439, 39.41507416386759, 54.8817995286757, 51.5502755872665, 56.52524909665508, 41.82433120666012, 52.04183486200149, 61.37553045826574, 55.7239677060035, 22.47798558204405, 6.18968693479415, 64.3477221458189, 66.33699924715104, 76.70651435852051, 67.795014842864, 63.99101395760814, 17.14886715335231, 0.5535482903642039, 0.3163237407082512, 8.175611390221505, 43.66214598378828, 75.428174695661, 70.09968188501173, 74.6267403325727, 66.79595578101375, 68.06570545319589, 66.19024768952401, 70.90259890402518, 70.87139252693423, 65.1593585937254, 63.63771823144729, 69.16938197228217, 66.14546991163685, 64.37146817484211, 55.93145324337868, 60.23553671375398, 63.8396732268795, 64.37365685739826, 63.699887798678496, 64.85168003266858, 61.75401172330303, 62.438959537013886, 59.78702545166016, 56.88141992015224, 57.29301383418422, 56.57050148133309, 54.936575428132095, 52.94443499657416, 38.3113976447813, 24.657321130075765, 18.718323169216035, 7.765173104501541, 0.45211708473582424, 1.3544798546260404, 2.0793964978187316, 0.3362068479820606, 0.4040223606411488, 0.5237030370100852, 8.372603116496917, 20.01445274199209, 16.351989603811695, 7.06706868064019, 3.8242327157528173, 1.4765563943693716, 0.17221917007719317, 0.08679206978770033, 0.20441058302117934, 0.13338358381823187, 0.17849036582535316, 0.1478179826611473, 0.08264008774271897, 0.2730866269238534, 1.6490476482337522, 0.5688967087095784, 0.23274428361365873, 0.1683183576190664, 0.28221986587009124, 0.21160925077574871, 0.1477754801031082, 0.10786128801203544, 0.17655535030268854, 0.26717831170366657, 0.13556838996948736, 2.3432398755704207, 7.928651609728414, 13.943230702031045, 26.816399597352554, 21.408863182990782, 6.965781805976746, 0.36949030394035004, 2.9001480437094167, 5.490720079791162, 16.940973689479215, 23.182970823780185, 32.62206050657457, 46.78218749261672, 51.13487305179719, 51.982061862945564, 49.932446941252685, 55.698837080309474, 51.19804282342234, 56.94480542213687, 48.89875335078086, 45.565432963832734, 48.450571567781516, 58.55773502780546, 62.83777829139464, 56.56582209371752, 57.86549552794426, 55.690513810803814, 53.67649832079488, 53.497704921230195, 51.740286965524, 52.75875783735707, 51.85607925538094, 50.56365043886247, 53.08463227364325, 61.11668932822443, 61.18347160277828, 65.41891751750823, 64.95652890974476, 63.40084629674112, 65.37720311072566, 64.95229274995866, 62.86831002081595, 68.32301293649982, 61.801280206249615, 10.632188397069132, 0.6755794777024178, 1.0919928815095656, 21.16788648789929, 58.52569710823798, 61.70953204554897, 64.44700517962056, 68.64368238756734, 69.60999750321912, 70.77764787981587, 22.32792942754684, 2.6809731077763344, 30.68520784378052, 32.57645706976614, 69.21494422420379, 62.917284734787486, 30.90628831617294, 31.801161381506155, 52.28655153705228, 19.522134488628758, 48.326169675396336, 62.141675256913715, 44.80133564241471, 65.00816299069312, 80.84584651454803, 24.620148827952725, 0.6787363115337588, 0.20079277876404025, 0.1993805876061801, 0.13981312994034062, 0.2077465741744926, 0.1631983775164812, 0.1498402862419044], [0.059400523276699174, 0.03558442785194324, 0.019539555144165794, 0.1229716751784567, 0.04303744828869258, 0.06023047612078729, 0.09742910102490457, 0.05971938822298281, 0.09245670010005275, 0.04218663870086593, 0.22020633542729964, 0.11509427650561256, 11.33118712132977, 57.210071394520426, 43.26519819997972, 38.87537171763759, 48.238277204575084, 41.147314425437685, 23.322534638066447, 50.07171069422076, 28.498586493153727, 18.93336711391326, 31.62416442748039, 25.27148585165701, 23.3603992385249, 9.478874283452189, 3.909463368115887, 51.94407370782668, 53.56879003586308, 49.73182555167906, 62.52946038399974, 65.90884900862171, 39.99948378532164, 7.808660422602008, 0.12793803166958595, 1.0132523421798985, 16.626927160447647, 58.2183401815353, 69.10398037202897, 64.91898006008518, 63.742786761253114, 61.258310425666075, 66.64928267079016, 65.62606965341877, 62.80384194466376, 61.27367042726087, 62.46620824260097, 61.33834638903218, 61.86315951808807, 57.80206687988774, 52.991224950359715, 54.84471744106662, 57.5452849941869, 58.40075000639885, 56.88947646848617, 57.71732799468502, 58.08648186345255, 58.40613934301562, 48.88168711816111, 47.14784652956071, 51.28871625469577, 41.480233438553356, 35.055799022797615, 23.561248125568515, 22.35605674405252, 19.508425804876513, 11.023415403981364, 4.0912201183457535, 3.725077158981754, 0.9638074340839541, 1.9844670497602033, 0.03138886881060898, 0.202518422456999, 0.31179891899228096, 2.1347936026511656, 3.115940425665148, 3.0296759836135374, 1.0705472000183598, 0.20019090944720855, 0.1824586093425751, 0.01149454313675843, 0.07996209716844944, 0.06464108178812651, 0.00938499937840407, 0.06544853846031813, 0.10232601930657703, 0.11518886538162348, 0.02772683829760119, 0.8848779468286423, 0.10037777344546012, 0.07593920859958857, 0.05488340840524724, 0.05227812723587117, 0.05055926342104232, 0.06738549984631038, 0.058279683017322136, 0.03465915451787653, 0.02667819033376873, 0.08882931974386016, 0.06951880956729574, 0.42225773536389877, 1.5734504595879586, 4.4001869328560375, 10.993004287442854, 8.690013077951248, 3.5894420887193377, 2.188836999477879, 3.643931655153152, 12.20851444428967, 11.704075086501337, 20.36617167534367, 36.24679534666, 47.44668406824912, 42.92927465131206, 44.76337102151687, 43.91549187321817, 46.73298528117519, 45.38358796027399, 51.046655024251635, 35.54468716344526, 44.77779357664047, 49.732115807071814, 54.459885858720355, 52.70685703523698, 53.722390051810976, 52.181180984743186, 47.81160569960072, 44.54405169333182, 47.73287980787216, 46.41857201053251, 48.911414761697095, 44.49366884846842, 52.05858338263727, 53.60523669950424, 58.10696448049238, 58.920397373937796, 56.75401741458524, 58.797101589941214, 59.44753254613569, 61.895075844180205, 65.43253990911668, 64.81424100937383, 30.801315884436335, 0.18989589816379934, 2.3932662750444105, 30.48897754761481, 53.340351197027395, 54.458603243674006, 58.755434251600704, 53.363956020724395, 55.585339377003336, 51.36676749875469, 54.47406522689327, 5.395894819690335, 4.8960083530795195, 35.193501672437115, 41.499476586618734, 75.05148595379245, 44.0693703774483, 12.504325874390142, 22.346421441724225, 31.387955373333348, 29.758492977388446, 33.91416180518366, 32.25848424819208, 34.77187041313418, 46.58555123113817, 53.26371592860068, 5.161806787213972, 0.19736481109453788, 0.057927929916449135, 0.05390310314513984, 0.059903919651743874, 0.03228749186100979, 0.06681081132903215, 0.02800783934822727, 0.016900152418642275, 0.0651156809180975, 0.12226096008934322, 0.010421466544240473, 0.04712617445376612, 0.035484346125515244, 0.07136958606180645, 0.05871847902815189, 0.1132201343294113, 0.028935215593646132, 0.1327044928386327, 0.17323000777152278, 16.470959994100756, 70.96530191359982, 53.40769829288606, 42.64048230263495, 48.51339224846133, 14.686721851748807, 28.61239798607365, 40.19374701284593, 33.75843978697254, 26.388055201499697, 36.20150766065044, 23.787765003019764, 28.85817566225606, 14.247085932762394, 2.533844022020217, 56.03371335614113, 58.7935047764932, 57.79504191490912, 69.13841093740156, 71.39047115079819, 48.96102489963655, 12.990942962708013, 0.18591962604513093, 0.6231759380429023, 16.98084850465098, 58.560982750308135, 73.0024476205149, 68.72897824933453, 67.28322398278021, 66.0916942165744, 68.7955722501201, 65.9104101119503, 62.338299751281745, 63.703190434363584, 63.711960854068884, 65.57158008698495, 64.0544229938138, 59.187161691727184, 54.5209022491209, 57.67497031919418, 57.318521007414795, 61.12817402808898, 60.98916130681192, 59.65153501879785, 59.22239242061492, 62.01171144362419, 51.991687359348425, 51.102862588820926, 53.215890469089636, 46.05528600754277, 43.7275868077432, 29.07999942379613, 27.522341897410733, 21.581755376631214, 9.88948368257092, 4.919780858101384, 5.367601292748605, 2.1211481671179495, 5.601071551922829, 1.212808624390633, 0.31545248423372546, 1.8115462963619542, 6.059729005059888, 6.820909553958524, 4.343477304904692, 1.0361743670317436, 0.44476588887553065, 0.8007855172599516, 0.03681579927703546, 0.06114922238573913, 0.031292531338910905, 0.055363818312123905, 0.07793453056365252, 0.014986685991677788, 0.07376431562607327, 0.03535605704171523, 0.7967834126564765, 0.16787750466215998, 0.02996125630283308, 0.030233922316842986, 0.040325332327835986, 0.07527568452661076, 0.053207483818574305, 0.05502041940006518, 0.06545806093321693, 0.11044330309115111, 0.08241341764768285, 0.3345342635387375, 1.8555248913265046, 4.053565854987791, 8.400926551511212, 19.04011049578267, 19.423243691844327, 7.130596858839835, 3.9365117876760425, 5.354696204585414, 15.681869329944735, 19.700337571482507, 27.97842529512221, 36.20099383015787, 49.50991353681011, 47.30847543285739, 48.46593941411665, 46.72769008144256, 51.065588305073405, 45.95526949051888, 54.13015965492495, 39.59813510217975, 43.937060986795736, 52.415213123444595, 54.19150944679014, 55.23818216016216, 55.68763871346751, 54.85067552135837, 48.92939882893717, 48.88513095917241, 51.490180953856445, 49.435780740553334, 52.09768941325527, 48.156515398333156, 54.4674599555231, 58.62705899823097, 58.45125444473759, 63.72983117257396, 60.56749866854761, 61.588644596838186, 62.00247033949822, 65.558879452367, 69.07848496590891, 64.91219828205725, 25.691077478470344, 0.4452636315216942, 6.123679328349329, 43.00847122746129, 59.80023599440052, 58.10564656411448, 64.01520321446081, 58.762137582225186, 62.74034661631431, 58.4140899873549, 59.368316358135594, 4.689376421513097, 8.696826234940561, 44.29139614105225, 39.14085342038063, 82.85568468032345, 45.21719709519417, 20.421783039646765, 23.674975287529733, 35.291160844987445, 29.040136375734885, 35.863018881890085, 40.43959725287653, 32.9039789015247, 56.86587948952952, 61.84252785098169, 7.102712729284841, 0.2580661861406219, 0.04893218076998188, 0.11023180919789499, 0.03241222629684114, 0.09771312046195231, 0.0389518094579539, 0.1086501747129425, 0.19731040353015547, 0.31790614128112793, 0.21119973081494534, 0.21982758155753537, 0.182153660383436, 0.3540173196984876, 0.23814063759580736, 0.2268582615520685, 0.23876299210373433, 0.23901531082247537, 0.4014724216634228, 0.42851017727967233, 25.26655347116532, 86.97287897909843, 62.877978663290705, 53.690446269127634, 62.83525228500367, 48.893567977413056, 29.906956649595696, 70.33300015234178, 36.48565592304353, 29.453424753681308, 39.4119833361718, 31.447273377449285, 31.48228837597755, 16.435985199866757, 6.966282398469987, 65.59790703558153, 64.38279990226992, 64.26576422106835, 72.27367908723893, 78.54679630648705, 51.56865973626414, 13.12330432476536, 0.6085560386700015, 1.3330235091909286, 21.895056655330045, 63.635549160741995, 74.39625401650706, 72.2372010446364, 69.77461153461088, 67.03572242490708, 71.98056036426176, 69.65772490347587, 64.4564502469955, 66.52742247427663, 66.17109867834276, 67.59522499576693, 65.91309301314816, 63.94198433045418, 58.710880048813365, 60.90829772333945, 61.33567133257466, 63.47410832681964, 63.53488937500985, 65.57805199776926, 64.99308147738057, 63.557301798174464, 55.894837917820105, 53.1676374712298, 57.89978881036082, 52.86858027981174, 52.87990808486939, 36.015375506493356, 31.273229968163278, 26.878123975569203, 14.32855748361157, 5.742601454257966, 5.373003867364699, 0.9234151724846134, 4.6024630723461035, 1.0050963862769067, 0.5843988349360805, 3.504942958393405, 15.2657558648817, 18.111481512746504, 11.735275580037026, 6.605758724674103, 0.8598178625106813, 0.9810943000258939, 0.14164172052856416, 0.16976896042544998, 0.09762287530447207, 0.15734450050419377, 0.12989978366080793, 0.17558134611575835, 0.2274176742761366, 0.17853211761722643, 2.327714644132122, 0.6502545721107914, 0.2608951649838879, 0.29487750763373993, 0.12399372839999777, 0.14609276797742615, 0.11063569075157566, 0.20157760519894863, 0.13957363553345203, 0.20557453104805565, 0.2499382690556588, 0.45942118151053307, 3.818361417901132, 8.516350138571955, 14.51057409086535, 32.14434523736277, 26.937800876555908, 5.712891461387758, 4.7596368578172505, 9.193100198622673, 19.474254115935295, 21.811206186971358, 33.82354328709264, 42.49949270679105, 54.2119606848686, 49.56953356342931, 51.85660093061386, 50.586153076541045, 54.55504648147091, 48.426794159796934, 50.963791031991285, 41.4956561980709, 47.24213246376284, 55.12787726617629, 59.3068253609442, 57.4010790548017, 61.42530141338226, 56.43044148722003, 53.18857116083945, 51.94248514790689, 54.769490303531775, 53.18126378520843, 56.04901452218333, 49.9154709231469, 57.44587644453972, 61.03006770533901, 61.371643389424975, 64.74101035825669, 60.930215927862356, 63.83815919199298, 64.40835414394256, 68.58724732552805, 70.36681098322715, 66.80449870324904, 38.191180921369984, 0.8894573140048212, 3.768767950034911, 39.52908177529612, 63.78541900265602, 64.2121454208128, 70.27927937046175, 62.782241452124815, 66.03847549807641, 60.30746906034408, 65.24065363791682, 9.694440883974876, 7.705356469077449, 43.12268672450897, 48.21453509792205, 77.95646390607281, 52.10966833176152, 20.56254709920576, 31.727267849829893, 49.32496201607489, 36.65566321342222, 48.890802706441576, 46.73316178783294, 49.85216386856572, 64.63654195108722, 78.3296303595266, 12.168920078585225, 0.33375895191584865, 0.34470849340000465, 0.21253333667353277, 0.1431259699165821, 0.20404318257445292, 0.19293257876509623, 0.13322538666186795], [0.012862161383964123, 0.03915812076640226, 0.06121067412858529, 0.10512214063877061, 0.012218955877958047, 0.04343095318143887, 0.08185369848844506, 0.05093002316331671, 0.03835335306282486, 0.04418803574216943, 0.18502010092619928, 0.18843559668429438, 4.081503426836384, 39.929936239796305, 53.62505251361478, 26.59582511071236, 62.36239487125028, 193.55759313029628, 33.42124539036905, 36.3087256493107, 35.45714770593951, 25.028873528203658, 47.87281036376954, 32.81863008776019, 33.79544342717817, 17.50806212425232, 1.0041682554348823, 12.39225689441927, 49.79812537470172, 60.751489208590606, 44.48529066578035, 50.31415631694179, 63.398669381295484, 33.2496024716285, 1.0286768790214293, 0.041849912414627696, 3.6030331013664125, 37.90335347575527, 66.87182226488667, 65.53374882667296, 66.2970224503548, 67.45159564479705, 59.15504924712643, 66.70575695653116, 64.3405951992158, 57.27681052300238, 64.81015389965427, 63.66761061453051, 60.76412316291564, 55.38330593416768, 52.55474359758439, 52.39049826898883, 56.10199005373063, 60.42410858215825, 57.28740876720798, 57.14938056084418, 55.071591254203554, 55.92016073965258, 49.25364548160184, 46.72013559649068, 41.15928157683342, 33.663404680067494, 27.475500952812936, 26.83780004901271, 23.733318582657848, 13.207435242591366, 5.530198245279251, 6.1445502600362225, 8.329335451126099, 1.4234720170497897, 1.2017705844294642, 0.9618301305078691, 1.2186326086521149, 1.672074412626605, 1.8339790668218368, 2.3845336081520205, 1.7630524404587287, 0.5842816541271826, 0.057066923698350314, 0.035459681924793034, 0.03800760609127822, 0.0478917452686977, 0.039621186442673206, 0.1418555509899893, 0.03218122397459323, 0.06023291994126574, 0.01516112421203645, 0.044684414751827724, 0.3774304375533135, 0.10035096802898955, 0.06384951377948446, 0.159170777506886, 0.036710810757452444, 0.06184029115003444, 0.03679463992856684, 0.03848774020650214, 0.04001587494126251, 0.0977645556051885, 0.08650494769455926, 0.021443381312213117, 0.08386624210904683, 0.25742772846452655, 2.7051047548171017, 2.1524401009082794, 7.711671485054878, 18.85374692178542, 9.353384913936738, 10.229815975312265, 19.86434167431247, 17.714669050708896, 25.891375272504746, 37.47723894734537, 40.84353470033215, 46.62421403392669, 42.803974536157426, 43.198670879487075, 47.41751732364778, 45.29627207786807, 52.03665733337403, 49.99194929676671, 47.51967153241558, 51.306888595704116, 53.221421011032604, 53.32144929516701, 50.62765567533432, 51.41856239688013, 49.782298611056426, 47.14975672383463, 49.163164246466856, 45.11078319241924, 48.71361747864754, 47.68909046726842, 51.38854842032156, 58.131695024428836, 58.983331803352606, 61.39047468862226, 60.928650902163604, 59.87802051728772, 62.72967776944561, 61.06782836298789, 63.65730262571766, 53.289929128462276, 3.6732459789322274, 1.5390680658240474, 37.060836207482126, 52.93816312666863, 41.27305384605162, 48.32305531347952, 48.61520913339431, 55.333554590902025, 49.0221118927002, 60.03531148356777, 33.6171873923271, 0.2616916206334868, 11.154842261345157, 41.068125694028794, 31.474671133102913, 67.32242415028234, 23.69269459478317, 8.342540110311202, 24.66136117135325, 29.881202367044267, 29.548432403995147, 32.26047485105453, 24.512562136496268, 27.016271814223263, 53.44774961471558, 36.17637311258624, 2.013512936330611, 0.21478117653919807, 0.07237851619720459, 0.0675254411274387, 0.02870178668789806, 0.04148580614597567, 0.0017134988053341307, 0.06939511701104141, 0.037925784070525444, 0.053382427656962994, 0.04031303661665128, 0.10350255415804925, 0.09959829430426322, 0.030811784353347558, 0.19734691528062667, 0.061815684405906554, 0.14889099605141148, 0.07756850141431056, 0.19449607228800175, 0.20572477621176552, 5.688765943050385, 54.69335317611695, 62.480662176685954, 28.135659387034757, 72.72489286238148, 171.359582408782, 44.50965642929078, 35.344257970010084, 32.219974417840284, 35.93020908294186, 56.62811717679424, 40.029329099962794, 28.488670741358114, 26.57985321937069, 0.6395658069560606, 11.3986881702177, 48.806173647603686, 66.41510932676255, 47.003107147832075, 56.64361053897489, 69.4288859828826, 40.56944339506088, 2.9593206749808405, 0.07865325127157473, 2.7908239874147602, 35.668190833060976, 66.15915898353823, 69.82441779105895, 69.41085092483029, 68.50254766402706, 62.20028723439863, 67.8300965216852, 65.72058700746106, 57.47547857223019, 64.84378037914153, 67.38790419793898, 62.50731860437701, 57.2948730376459, 56.119989810451386, 55.58992855010494, 56.80699294613254, 62.11377151550786, 57.930810836053666, 60.15535954506167, 57.257673278931655, 58.123140335083015, 49.74574604342061, 51.9617243736021, 45.395135418061294, 37.16217848562425, 33.03585683145831, 30.7319664186047, 26.928094971564512, 13.507264160340833, 9.52385308281068, 6.863912949638983, 7.6850204506228055, 5.252453742488738, 5.991875923448994, 1.0584128575940286, 4.883688678664546, 7.715573753080061, 1.0682798249106253, 2.0402991699595607, 1.9745313183915232, 0.5668473315815772, 0.021388845428103404, 0.03395826833683156, 0.053593967515494556, 0.10733092534205607, 0.020071913473187916, 0.12413377693343548, 0.02789374778888399, 0.013146294776590602, 0.03258936114669327, 0.07133931792791813, 0.3738475669055216, 0.029415596772225636, 0.04766260454010579, 0.10811615780356432, 0.10100712999701501, 0.02775734774918566, 0.03838310025692467, 0.03245194029483584, 0.04472083457174801, 0.05281688622950066, 0.08862213892561775, 0.0926034135984317, 0.29178717023422646, 1.033925378034192, 0.8972328612881323, 3.958528051453252, 15.38697083150187, 26.962523575752016, 16.373346909399956, 15.245943973141333, 25.921240198996763, 24.666615186199067, 32.579430226356756, 39.95827144192111, 42.53220919639834, 48.634271852431766, 46.49536025139594, 46.94674268845589, 50.50114747016661, 50.342569966470045, 49.49133326930385, 57.315885174658995, 49.86768860970774, 53.751415591086115, 55.008052779782204, 55.99955343431043, 54.803740439876435, 55.01697617192423, 51.19588551982757, 51.38791299635365, 50.457648384955625, 48.65377779929869, 51.081438602939734, 50.23150805504092, 55.40853854148619, 60.725193638955396, 60.371184041423184, 63.407526093144575, 64.90079595196632, 62.38729015473397, 65.656326816928, 60.65594027119299, 64.11008534892913, 50.7783099912828, 2.677561136022691, 5.213547262453265, 47.122951246077015, 58.02830526905676, 46.59565917907223, 57.02239382651545, 51.717937300282145, 63.42006591058547, 52.591304009960545, 64.56247975749355, 26.697818502303093, 0.6290325882934755, 19.18808779408855, 44.90548241523005, 30.42418783710849, 68.31431311945762, 26.308391863299956, 17.02056642501585, 22.222209784292406, 40.6409913493741, 27.443533635908558, 39.94237015324254, 28.631929428346698, 24.312984097388483, 66.70267397357573, 39.30567925976169, 1.8534915101143623, 0.13926560690085735, 0.07318360565771019, 0.10689076952516072, 0.09124546912648986, 0.018683802374007723, 0.04916871807748272, 0.0633531041263092, 0.13363555013652773, 0.1643028158333994, 0.10971761098311794, 0.32685147418129834, 0.19874188478194899, 0.20518511323438537, 0.45174350962042814, 0.24818572035479933, 0.2465438407154814, 0.16650669757396946, 0.3766373220470644, 0.470879711811581, 11.052414467257838, 78.4136632180983, 72.98171397178405, 40.72531838570872, 72.77207897555444, 212.806483545611, 41.72064335115495, 55.42723255772745, 45.54797841656593, 35.00417278658959, 57.38124755121047, 42.325131585521085, 42.99255817167221, 24.666864256705008, 2.6085514455072345, 19.50677840940414, 57.402526409395286, 73.3952102353496, 55.79862217749319, 61.03551979987853, 74.02548020885837, 39.27066033886325, 2.1862281330170172, 0.1368451521040932, 5.543751505113417, 45.01558334596696, 69.96321478197652, 70.8675564489057, 73.131650493991, 72.54216532553397, 64.76503879793229, 71.34503441472208, 69.34157402284684, 58.15465657941757, 67.56243398112636, 68.50253197454637, 65.93386588558074, 62.01400995254517, 59.50343808820171, 59.03395783516669, 62.189132013628566, 67.19500203286448, 62.34279870986939, 63.82299923127698, 60.32284475141957, 61.22660198519307, 54.46586355086296, 54.27026671748008, 50.24018433786208, 44.32903912759597, 38.30224283279912, 36.21921323960827, 32.60518058653801, 17.087056482991866, 10.721028120287004, 6.818491903043563, 9.585477440587937, 4.6583367451544735, 4.3365587342169984, 1.206913302021642, 5.696461633328469, 14.48456387366018, 9.202069678614217, 8.603032558195054, 4.385505501301059, 1.413686684062404, 0.21578176397710078, 0.25385827967716806, 0.11653976184466194, 0.21774549247516742, 0.1614746183998162, 0.1927082682208669, 0.14339529578724217, 0.19037416685492764, 0.09518741284527125, 0.14875910635436737, 0.9823846985255519, 0.11988331428578786, 0.3005425746162092, 0.32109993119393626, 0.31235813253348876, 0.13892402361717918, 0.16527355648577213, 0.14525364123044476, 0.1409080687669977, 0.30194696699900014, 0.27753854771294906, 0.09828255361606998, 0.2827861274202024, 1.3384346639917744, 6.989724934101106, 13.113094395206822, 27.82455071326225, 33.24058102023217, 15.375978389093953, 15.192481087100122, 26.67193478153598, 23.686616882201164, 34.42481125554731, 44.02307464230446, 47.92511909238754, 52.167566437875074, 49.75970575886388, 48.911148040525376, 54.180966115766964, 51.107341935557706, 50.95602866142027, 50.23617567554597, 51.11382953582272, 56.523491874817886, 57.98606526467108, 58.245459448906686, 56.40493431398946, 57.86726843926215, 55.199719398252434, 52.66339717372772, 53.82736836710284, 52.31813446167977, 54.55305391742338, 52.414977781234256, 57.83003337921635, 61.89229096135786, 62.73006608409267, 67.14933779931837, 67.98394756932413, 64.77438580605292, 68.94665410441738, 65.27198945322345, 66.69540189927625, 58.38278555100965, 6.511512994766236, 3.0617249348471245, 45.61156395942935, 62.51038589785176, 52.76837548901958, 60.95840207992062, 60.75962812669816, 66.83717204678443, 60.91919406767815, 68.3660021135884, 43.05152708484281, 1.434650894614958, 16.23681606784944, 53.411734411793375, 36.62581005404073, 71.7703370125063, 31.980745138660556, 12.553939934699768, 32.93171398101315, 45.75846456712293, 37.129654192155414, 48.571662979741255, 34.40301464449975, 39.74494549535936, 70.56575359836702, 59.77574471504458, 4.057740237443678, 0.4294701467358297, 0.171062040232843, 0.3155096037493598, 0.2383742944127129, 0.17290143266079888, 0.12059165450233607, 0.3398356532617923], [0.01543972357701991, 0.14269758887108297, 0.037725030729967746, 0.03804766099839922, 0.01966057022312476, 0.012137179822480727, 0.08679744772492878, 0.05741263236550074, 0.028913311224671143, 0.14103549983232253, 0.16457843894679702, 0.14518788024302454, 1.4261799233575023, 30.91104222882179, 50.24318102867373, 37.69225935782156, 37.07368589216663, 36.876331836946555, 22.15736908297385, 33.989851782398844, 46.34943239150509, 15.681411393227117, 47.813664943941184, 36.267379945324315, 32.49345971691993, 33.38685404869818, 4.7588891560031525, 3.5582366922209343, 38.72046555242231, 49.00564186034664, 83.74793760238155, 69.13658311290126, 46.3197910401129, 49.884139030210434, 36.19738917196951, 11.301063318406383, 3.058861359473198, 7.8684245963250445, 42.80542581312118, 69.28080081939697, 65.51900855956539, 66.52234692727366, 67.66068935394287, 67.19229559744558, 58.62075967173423, 57.4712973256265, 62.63525062991727, 61.88255563859017, 64.12910099952452, 59.79616457416166, 56.740818638955396, 53.95427665402813, 58.07813898209603, 59.700894125046275, 55.2132398082364, 56.179378417230424, 57.22416447054956, 55.663390621062256, 40.789288320849025, 40.38548423397926, 33.49413871765137, 30.616746794792917, 32.22596779946358, 26.485757520121915, 20.805155500288933, 11.110319437519198, 8.209996358040842, 10.82835985768226, 6.4701388535961035, 5.492636157620338, 6.1346095031307595, 7.300734077730487, 6.281943532728381, 1.7745997756719591, 0.7690271278542857, 1.9403386692846976, 0.5527435916085397, 0.1412674406122777, 0.01991158850761431, 0.03203605797382132, 0.07700503608512302, 0.021593184060146733, 0.054192186423367074, 0.14361413646369212, 0.05869445068040683, 0.041433133770741766, 0.09380548982129944, 0.05369940419651328, 0.12747080230544652, 0.024932819876759767, 0.08247224553938835, 0.049274549293782444, 0.20724236574624816, 0.16297411293752734, 0.23821787458033333, 0.04712728528125633, 0.05365458039206363, 0.03725165734067559, 0.06156081078393806, 0.015670546826215524, 0.03396740010488899, 0.5427408735117605, 0.2833439620031465, 2.16770964284097, 0.08450362726204819, 12.2167278874305, 23.98235574845345, 14.298957317106186, 14.19650108583512, 21.37612904271772, 29.4124791314525, 39.27322949132612, 38.88203974693052, 41.45203944175474, 41.34116972646406, 48.5481366034477, 48.93985979018673, 48.11045892776982, 45.55692142055881, 55.87310014232513, 53.72866192171651, 50.25245743413126, 50.442245237288944, 50.23648554278959, 52.91988880403581, 52.281695642778956, 48.56457525683988, 47.931900870415475, 50.76066717024773, 50.00426553910779, 48.79910945892335, 45.902082150982274, 54.209881828677275, 52.66303239330169, 59.21959184831189, 52.59252778945431, 58.82618204239876, 57.193958297852554, 61.744127350468794, 56.58837964457851, 53.654234947696814, 13.353109129013555, 3.128198567898043, 33.69065730802475, 53.48680465452133, 45.64979922386908, 52.56417689784881, 56.223748268619666, 59.14246236124347, 48.11054521991361, 58.96377094330327, 38.222336307648696, 2.302031454540068, 2.470610511879767, 35.48111731006254, 33.56693790804955, 32.99542896209225, 30.826923078106297, 6.913258327591804, 13.113206182756732, 33.026278403497514, 29.726390338713127, 33.83878169521209, 36.00795438212734, 28.703114563418975, 38.179747212317686, 59.006363961004446, 16.550033015589563, 0.7154038536452478, 0.09187199881360417, 0.100237081398166, 0.013355790137974246, 0.02836404533516015, 0.0922759110108018, 0.05272893550535364, 0.03350757115009812, 0.014503524871543052, 0.03353360664820479, 0.031027259988590117, 0.08529953132834166, 0.07607379492612616, 0.05836046315849789, 0.04237840966051144, 0.053582637075094454, 0.06696547682006514, 0.12907366508678084, 0.16566482823221915, 0.12883230142535704, 2.257566240526015, 50.35576874209989, 63.62116582932011, 39.390724089837846, 40.76498139289118, 52.25917731561969, 31.21823637716232, 39.633832593117994, 38.82507908728815, 27.13918712831313, 50.31614103624898, 47.51255243055282, 30.22086785685632, 40.2975211604949, 10.922489877670042, 3.427146423247553, 42.98185402347196, 53.066585448480424, 84.29109173436319, 76.07785255678239, 51.596849810692575, 55.88519280956638, 45.765783709864465, 17.812628284577404, 4.736217366110894, 7.391439868557838, 39.18188141238305, 69.88146474284511, 69.824919854441, 68.96854877471924, 73.9351401790496, 67.44610432655581, 58.381326429305545, 58.664886336172785, 64.71322821032616, 64.36569444594845, 65.94698229143697, 63.26754846880513, 60.27978889403805, 56.700900677711736, 59.7819342151765, 62.05019381738479, 60.48570940571447, 57.55509091961769, 61.328140381843816, 55.28279127613191, 47.13860150306456, 46.23782134825184, 36.1004791721221, 35.833652096409956, 33.26196970478181, 28.11311556446937, 25.325638094256004, 14.150136709213259, 11.146504282951357, 15.367083434135685, 11.66085841194276, 13.927112702400455, 10.625357589414044, 12.31554808155183, 17.43441374071183, 3.605480415205802, 1.0786879567369339, 1.5919976320958908, 1.2424340411540002, 0.26454198865159867, 0.0494968795007275, 0.07887590706588761, 0.06584142665228536, 0.04514413262386957, 0.05684358991622444, 0.09654788540736323, 0.06288687450691097, 0.0569379183223411, 0.04713537133929711, 0.03738063973404708, 0.12129011218466106, 0.03403132631173057, 0.09296250965205893, 0.015622066867147243, 0.1604399247275245, 0.08905507053338713, 0.23494772102323272, 0.06423619665926503, 0.05165359320779962, 0.013552853807566628, 0.03281346484718304, 0.08277020011577876, 0.09700205297239366, 0.27915042734915213, 0.6770742684602739, 1.5572769339046173, 4.01067792407928, 17.556497512325166, 30.525761535090787, 19.887948459194554, 21.063912299371538, 25.26610043741042, 35.13594089015838, 41.399491448556226, 39.92236606536373, 43.34423003658172, 43.82055090319726, 49.60187742787023, 52.3558755074778, 50.4451987820287, 46.26592120816631, 54.92027013532577, 56.01148136200444, 52.443046262187345, 53.95285283365558, 52.24959496528872, 54.281924001632206, 52.84819572202621, 51.0270510181304, 48.508120582949736, 54.27187488925073, 52.97444112839238, 53.649473190307624, 48.99543977552845, 56.51616096496583, 56.12750507170155, 63.44903653667819, 53.62908078778175, 57.65707254409791, 57.17866889892086, 61.403359674638324, 55.31309550808322, 52.41600936458957, 10.298944807821705, 6.3536542654037484, 44.5202076050543, 56.38294942917363, 55.86504359399119, 58.59431897440265, 62.27026231827275, 68.84027942534416, 52.88306167048793, 66.24372528445336, 33.659654894182765, 1.4387751442770806, 8.572273331303752, 38.392920186442716, 40.23027604626071, 34.00574130396689, 30.671622714688702, 13.829502559477284, 16.72892643559364, 29.9603989431935, 42.83224698035948, 25.933311293202063, 45.306689893045736, 26.915776768038352, 41.26555427428215, 70.8883842345207, 23.042051830599387, 0.896027835626756, 0.10000127953507247, 0.19322871771310607, 0.045556835679998325, 0.07804618021773715, 0.06278932470107271, 0.04710554753640487, 0.1041220588188979, 0.16444487917807796, 0.2332962652848613, 0.1505958940833807, 0.16020421479498187, 0.14515883018893583, 0.18237219462471624, 0.1448891365960721, 0.1796076437758823, 0.11918776773757513, 0.1986374363543526, 0.31230977706370816, 0.23465850751005837, 4.757826683982726, 73.98542496465868, 71.77103519439697, 54.636137562413374, 49.23467689944852, 47.99049323604953, 26.47758133949772, 49.82688419280514, 60.267582478061804, 21.687255367156, 55.48205552562591, 47.17217699173958, 41.957319167352495, 42.83036424267677, 9.990431762510731, 7.249460854837972, 49.12980448815131, 57.13582484952865, 86.12492530576645, 78.51857877546742, 60.37579282637566, 64.35898719295379, 44.88603138154553, 13.953491622401824, 3.7010641636386996, 11.434860267946798, 49.535597216698434, 74.00846496705087, 72.18551989524596, 72.3617676765688, 76.5831950403029, 69.3190517733174, 60.02325411765807, 60.272305011749275, 67.68071697604272, 66.96548061986124, 68.69735610100531, 65.02885741572227, 64.09653355998378, 60.4271327295611, 61.694423075645204, 68.11048323108305, 63.21139189504809, 65.44525623321533, 65.17529910610568, 59.766895847935835, 49.79990613075995, 48.674887995566095, 41.27137507161787, 39.13208300067533, 40.91064253161031, 32.7839720249176, 25.867641010592063, 18.24016074980459, 15.425560089849657, 16.41163806761465, 10.417151316519707, 13.331609637506547, 12.064513448745975, 19.405218439717448, 27.875196356927198, 12.441776817844762, 6.321547214061984, 5.146714977679714, 2.094709676119589, 0.4986828811947377, 0.1010437643215541, 0.18947692467801033, 0.22282454816083755, 0.17336513035960738, 0.11976017331283902, 0.2692127041518688, 0.20650538916309036, 0.23782084185269572, 0.24673782949966772, 0.26127048677975134, 0.6458428862594789, 0.2356088242583698, 0.26075717722696645, 0.11943372792654461, 0.5210657333654742, 0.4837626447120021, 0.41524916466686035, 0.12194003819698289, 0.19183148059152788, 0.2812749117372498, 0.16006998086888946, 0.18316511094810503, 0.22737340971587167, 0.8990653436030112, 0.4546873097217852, 6.508872259047724, 13.745341243282443, 29.933673874024425, 39.36165148212064, 22.61638053001896, 20.360639172215617, 28.909091949462894, 38.260759845856704, 46.91278280750398, 44.82531701364825, 49.05942540014944, 48.43061847071494, 55.097016057660504, 55.24435204844321, 54.62387623325471, 48.55451045497772, 53.010711285375784, 56.59227848052979, 56.85089995784145, 56.53414895457607, 55.01399124822309, 58.761372720041585, 57.566312820680686, 54.59226585203602, 51.73037513609856, 57.33561077425557, 54.75276139474685, 55.717719370319, 50.81600004626859, 59.61773987739318, 59.22941346322337, 65.26598038211947, 56.42783703342561, 60.020053463597456, 61.646479945028986, 65.98491945574361, 57.80166287575999, 58.009117034173784, 19.362121397449126, 4.153379634503396, 42.44897257897162, 63.455857538407855, 57.25067184817407, 62.86687443333288, 65.17501669545328, 71.54369461920955, 59.552404957432906, 70.18199674544796, 47.18027668614542, 4.313372133239623, 4.757776673763029, 47.19167901623634, 46.340297191373764, 38.604649728344334, 37.278464994122906, 14.214420433967346, 16.413493348706155, 49.64739261134979, 43.51101706104894, 41.8287830968057, 53.925113831796956, 37.98598997054562, 55.349389199287664, 78.14951512121385, 37.98316194165138, 1.2519361054705036, 0.24327819175537557, 0.2635990263473603, 0.18902269582594597, 0.15060792166379192, 0.2860719398144753, 0.18624766489430783, 0.27212815900002757], [0.04663575177771911, 0.039566763556532325, 0.015627337552066294, 0.03960009987255739, 0.046465695580287326, 0.03386571725469924, 0.03662686667314941, 0.003661628556250024, 0.05609126476150367, 0.03134519796848538, 0.04358896647670096, 0.08975771105577869, 0.9849744434318236, 16.1133437771951, 58.0341496006135, 33.576182934545706, 40.19799493974255, 20.613298646865353, 32.923971222293, 29.618585955712106, 50.172146904853086, 18.264895216111217, 29.834959583897746, 31.432615480115338, 23.377210517083448, 43.45151862790508, 11.321899929354268, 1.5280715784718915, 31.346533183128606, 66.16359126183295, 71.68142472544025, 64.60398235628682, 44.48316081877678, 54.1251233316237, 64.07536452816379, 64.56979890023509, 41.44652851166264, 11.818425905319954, 9.737972328739783, 37.97332463725921, 66.10350839553341, 64.43707766071444, 62.403481698805294, 60.47507193780715, 56.289608786183024, 57.82427926217356, 62.907443508025146, 64.31795920095136, 59.85914214964836, 57.292617674796816, 56.86851924465549, 57.74157608709028, 57.9277043188772, 59.211747107967255, 55.40948775506789, 53.6258565995001, 52.36706602957941, 46.670239125528646, 39.1837445382149, 39.425919517394036, 32.39611433398339, 34.51798323662051, 25.5797056997976, 28.53164422896601, 19.423026000299764, 10.75107543699203, 11.530574925484197, 11.493319272994997, 16.1158658612159, 9.987942038043853, 15.257407099969926, 14.54732277700978, 4.105042060536723, 1.5311275951323973, 1.1822874363391631, 1.009397510318987, 0.3003638003381991, 0.05285019190200875, 0.05786449017543947, 0.06728570157241437, 0.049977722247281385, 0.05058995290328899, 0.06429935294774271, 0.040071883629406654, 0.05262465561710058, 0.19995302382496097, 0.1248497090813133, 0.0711034624386699, 0.05146857914364627, 0.06789651879620168, 0.05739566734841755, 0.4946672015132443, 0.6111616569180643, 0.3147308600525702, 0.1721273774221059, 0.19128161332299634, 0.01832691265360242, 0.028663583798334006, 0.025443609000273773, 0.014843901566740487, 0.0598629760826307, 0.10558526377163588, 0.25113958685148147, 0.5372268177809254, 2.950276179659751, 0.9745279459222671, 14.82374789253358, 26.40207963605081, 13.2793067924438, 16.37278404928023, 22.84012821412856, 33.41559717732091, 30.638462997251946, 30.398484545369303, 38.605304764163115, 39.91765922115695, 49.018636672727524, 46.667764109949914, 44.606931209564216, 45.26306921435941, 51.3246294759935, 48.294418088851444, 52.17561514146867, 49.85246981343916, 49.828300168437345, 48.70270936719833, 50.55891613806448, 48.39036318563646, 51.10503165952621, 48.581504206503595, 52.33216085741597, 46.82727906011766, 54.166241538140085, 56.746455084893014, 58.51147067162299, 53.08706414315009, 52.962783844240256, 51.2040989629684, 56.1834341479886, 43.35673063032089, 31.25382011936557, 2.740383532739455, 25.816365826514463, 48.074973244820875, 50.38535910267984, 36.27394599299277, 32.15236648436516, 40.92218214465726, 42.915903291394635, 60.27523502226799, 44.69052476267661, 4.558889952398116, 7.171752327872861, 48.1061403982101, 62.75463188848188, 35.85473483608615, 28.28771987269002, 18.562679598408362, 7.750650038642268, 23.920209715443274, 37.34861658465478, 26.734851560285016, 48.01620045015889, 36.39375478990617, 24.43724282326237, 42.943214754904474, 59.46261013707807, 7.186347957580321, 0.4545489542426602, 0.20173590960762194, 0.033048948783787994, 0.04831681681436397, 0.0713266391727713, 0.028996217259836775, 0.07097403188386271, 0.03235059069289315, 0.03103087783881253, 0.013154238150755485, 0.024969345033769647, 0.0438851360682278, 0.022969916838431553, 0.04113280049134647, 0.029182964597918817, 0.04139312482889622, 0.03034480971344296, 0.052446762340203415, 0.06340111485652386, 0.03466997934024661, 0.7372399948297009, 30.52679115726102, 74.2417283211985, 34.555057479489236, 42.130178020846465, 26.582787152259584, 17.584887627632387, 33.87597753155616, 42.32185248405703, 26.159216280906435, 37.688886119473366, 32.568527998462805, 26.279087835742583, 40.176712159187566, 20.847646536365634, 2.3119405873360175, 23.62954051263871, 70.82372788460025, 75.12736812714608, 66.08703444080969, 50.13296634920182, 58.19143664452338, 65.0057585777775, 69.77805537562217, 52.22539394132553, 18.17606333763369, 9.766428143747392, 33.53553149007982, 64.35774380160917, 65.55990319098196, 60.73850224095007, 60.414039857925914, 57.278461840844926, 59.23284161475397, 64.56499007440382, 66.99331375860399, 61.951950211678785, 61.314929839103456, 56.548842153241566, 61.26047165163102, 60.42614429227768, 62.55418700556602, 59.022802614396625, 58.02206085574243, 54.87174257155388, 50.86747723241007, 43.75900107045328, 42.92065328167331, 34.148966650809015, 36.74525799289827, 28.95364615225023, 35.30885465683476, 20.31697338627231, 13.676550715200364, 16.19551350993495, 14.59380482473681, 16.213995718186904, 15.290136337280275, 19.631141078087595, 16.11216804673595, 10.081826909895867, 2.645353328797125, 2.2836872646885533, 1.653503705897639, 0.49439517901309077, 0.11868600312980915, 0.09989059515177243, 0.03106960741382453, 0.028477794070157315, 0.013010286399343563, 0.039906167320065924, 0.027497871854012052, 0.04201998393381796, 0.10896453889267099, 0.0888688268981153, 0.02056513045493874, 0.06950063030085257, 0.05969910221474786, 0.11724770369548952, 0.06673438639770593, 0.3436564708188657, 0.2274935935894328, 0.2711679750392514, 0.18637572415173057, 0.07589195629641896, 0.04624791210517288, 0.03857387530226861, 0.05696428706869484, 0.07675277865341595, 0.06775615616671501, 0.638003355312732, 1.237135286773405, 3.0716313710135803, 9.1495285495635, 20.130117554818433, 28.0586201144803, 17.691613358836022, 20.93949471750567, 24.020071298845355, 36.83100884960544, 31.754039987441036, 33.644165454372285, 41.600077536798295, 41.858381302126, 48.139562914448405, 47.819207252994666, 45.08589183130572, 48.18809440059047, 54.79923363654844, 51.71242637019004, 54.49731311490459, 51.999088871863584, 52.012028771062056, 49.32134951314619, 51.29313676587997, 52.1754543242916, 53.02019949882261, 51.253728712758715, 53.86755697188839, 51.419401784097, 57.30236476467502, 59.66701661386798, 61.37425961032991, 56.104998511652795, 52.87319690950456, 53.59765475796115, 54.80805896943616, 42.16347502123925, 29.80390225687335, 5.151339452112875, 34.53167623089206, 50.75425017264582, 56.38971551772087, 38.693663997034875, 36.912919705913914, 46.924326342921105, 48.417309868720274, 66.55442407054286, 38.994352894444624, 2.176968642780858, 14.266780153397592, 53.64948103504797, 64.06909265825826, 47.011504942371005, 25.34202967920611, 19.62267856444082, 14.946020918507731, 21.793004428186727, 42.46908257084508, 32.218974213446344, 34.96297613266976, 45.70166472465762, 22.29544828014989, 50.09797096252442, 66.5227940774733, 10.689533448988392, 0.7532001190608548, 0.23330866058747615, 0.09805766850589745, 0.02832244484565191, 0.02776010375049326, 0.02678582185669051, 0.025421348400413993, 0.1039018851494597, 0.08406270535722857, 0.11867631211756699, 0.11558320147976761, 0.20825839751670439, 0.21337741234850502, 0.2519754960291809, 0.1329673529272118, 0.1137194857602158, 0.16096650292315792, 0.16568451669187317, 0.20243720181526678, 0.19186705771473148, 1.2464686891724988, 52.29398050615865, 87.51452692093389, 47.4457662336288, 54.32722345475228, 29.54775187277025, 39.08697182132352, 41.06399936060752, 70.61418702525478, 23.55992824800553, 42.938166664492705, 40.234421991532855, 32.41795016873267, 52.806787260117076, 18.730874753767445, 4.3820008635520935, 38.668309796241026, 77.263687041498, 77.81137543339884, 71.31299649515461, 53.431471778500466, 63.964443822060865, 73.00624447484171, 74.76447828354375, 51.02508591067407, 17.744261372473932, 14.222701537993647, 45.11132055713285, 70.84599910243865, 68.4657479870704, 65.11042310345557, 62.895605794845096, 57.01138373344176, 60.51815917415004, 67.15794347947644, 70.00749049648162, 66.91444273917907, 63.79200073980517, 61.08304715925648, 65.11271769000639, 62.21634149551392, 67.5303097694151, 61.568381632528, 63.75075701744326, 58.45715761184693, 53.891079425811775, 47.00486436966927, 42.471945901070875, 39.76631456805814, 43.65053576807822, 32.91578523574337, 41.7934190073321, 29.305237608571208, 17.434629471071307, 19.985746875885997, 17.089339302432155, 20.740797250501572, 16.382987114690966, 28.101258239438458, 28.124639488035633, 20.713832916751986, 8.754656680168646, 4.272550065671244, 2.316111537718004, 1.2477696903290287, 0.2800448503225081, 0.2736819691715702, 0.17223159602332502, 0.13771473850694396, 0.12397458386277, 0.26131731007368336, 0.21561964445056456, 0.24204112829700594, 0.33483806336599015, 0.2507564816023073, 0.2222392110214118, 0.4427500970421299, 0.23208068293188852, 0.2549787445534622, 0.8671887315088703, 1.0173035376975614, 0.5881053521748513, 0.9110926175790449, 0.3728118466754114, 0.20356108344370322, 0.1225888150774183, 0.13398985047974896, 0.13339437033620574, 0.14556482614528748, 0.18159430894640186, 1.804980371267565, 1.2070993694566912, 8.79239772596667, 18.8411110062753, 31.4569910495512, 34.54581637536326, 21.94779488348192, 29.184571773775165, 34.38897255928286, 40.729158386107414, 37.58337828420824, 41.476205164386386, 48.68717678131596, 46.03257548424506, 50.75123386998331, 51.571342637462, 45.842905352192545, 50.58772594698014, 56.25181674957276, 52.56842090237526, 56.15520092748827, 54.21564771283058, 54.21452199259112, 52.822661092204434, 54.21570654838316, 54.05469717517976, 55.25723703445927, 55.444181119242025, 57.66696083930231, 54.423396049007295, 59.82693949053365, 64.31732769935363, 63.31617016946117, 56.29990108551518, 54.79715085798695, 54.1050604081923, 56.56764599584765, 46.34734961294359, 38.45575655660322, 4.767667420448796, 31.55218501244822, 59.55200487567533, 60.05466445799797, 47.732993556607155, 43.70697867485785, 52.25076383160007, 53.74715981944915, 70.08140364000874, 53.62030644570628, 7.321142169737048, 9.778486490249634, 58.54785457734139, 74.31637887031802, 45.101593079105506, 30.444466490899366, 25.67590378945874, 12.86639202025629, 31.81159096379434, 58.791625961180664, 33.87385160692277, 62.78861138128466, 50.96154743625272, 34.81072148969097, 59.85304678640058, 81.05282998854115, 21.66466251496346, 0.8908062416218943, 0.3288991659158661, 0.36636524743610815, 0.14854455577029338, 0.32019971659587276, 0.2332538086920977, 0.15068286038454504, 0.16748912872806673], [0.1669008038457363, 0.08600610954266402, 0.054255047767993905, 0.032526940302622896, 0.042648133896892114, 0.06043652312890176, 0.04676279596864216, 0.15437088426082365, 0.03208945238692386, 0.07338680281874634, 0.07365143257043055, 0.20207991372914086, 0.1354279047659328, 13.218639492988588, 62.100490370104396, 46.55364667215655, 30.86466608508941, 51.904473458566976, 54.63947549943001, 29.721836466943067, 49.740745021450905, 27.9323511738931, 21.752488305491788, 29.920400573361306, 16.179292548087336, 45.842266005854455, 48.575299016890995, 7.872833340398728, 1.7615012656296454, 26.28854467022804, 51.82163692289784, 66.00689257344892, 70.33614589321998, 52.723052501678474, 48.62841967613467, 44.275243820682654, 62.60993565282514, 50.69733265907534, 14.980496591137303, 6.405685486332064, 29.734099757286813, 57.19507225098149, 59.712343523579264, 59.23815250396729, 59.19832475723759, 56.383828040092226, 58.715626116721864, 62.80808594919021, 63.124895788008175, 63.6705014013475, 59.90498288985222, 60.60138010209607, 58.39166971944994, 58.716963644950624, 58.593875746573175, 57.3637733920928, 54.30760375915035, 47.87762311197097, 45.53641919166812, 45.79882183382588, 35.795985575645204, 36.17440016038957, 30.571274757385257, 13.409764824375031, 8.389578154010158, 21.195092047414473, 22.415266882988718, 19.87664222717285, 19.374975004503806, 19.279581000727994, 22.411438649700536, 10.029380898321829, 1.9904422904214554, 2.466312329615316, 1.1804111950820493, 0.9849876201441212, 0.09280514753153248, 0.046767308226516174, 0.010368405379384998, 0.07019336530638319, 0.01853466229212861, 0.2616458392191318, 0.39962345313641334, 0.1803598195434578, 0.5535061861718855, 0.1835093602177597, 0.4761132261445446, 0.23442750135737084, 0.28895537218739914, 0.10641681390904612, 0.4352726498919149, 1.4061850285337818, 1.9066527413745082, 1.4942350070322714, 0.6649550026462925, 0.17245386877367574, 0.1202612944067486, 0.07203156263717721, 0.05840023461308691, 0.10062636131600988, 0.055896961881268414, 0.050322071108366215, 0.29101660835646814, 0.7108217285525414, 2.0847193992907003, 4.8705982585107135, 9.238180979605644, 23.232961431626354, 17.042759195450817, 14.481706426989648, 12.817793853821295, 15.493530842565722, 30.916494323361306, 14.966090706086929, 21.73255874264625, 31.85970275632797, 34.008588944711995, 41.423449285568736, 44.40259533543741, 47.19847648374496, 53.826493678554414, 50.95096488152781, 47.77065615500174, 48.19964578074794, 46.94624454744401, 51.285601892778956, 47.26280727694112, 51.5929078286694, 51.64603241028325, 51.45890789647257, 51.84469261477071, 52.46289345525926, 51.55073450457666, 54.65757331540508, 55.27077313392393, 56.17802912189115, 49.48371210405904, 56.00801790914228, 46.418364124913374, 41.22926450544789, 16.436139152896022, 19.271163594338205, 54.812938397930516, 51.31502751381167, 53.498057934545706, 46.037356853485115, 41.32025957107544, 47.7802816514046, 41.80740617936657, 48.48084442077145, 4.088794377542311, 1.2641371281877642, 45.36684728437855, 67.23279799184492, 53.17840437735281, 25.229518451998313, 12.76671184647468, 11.728723260664172, 11.153641035479884, 33.2922778591033, 28.75786300628416, 40.46356293462938, 42.79659263549313, 22.95852299659483, 39.71227215182397, 50.77355215626379, 44.48154872463596, 1.4157167557747135, 0.2796913467107281, 0.10874804244526934, 0.06668517290945015, 0.017838569906269832, 0.060601228202182444, 0.1232264607003139, 0.05555933927215877, 0.03657724332785414, 0.041025245577217116, 0.07968645107241408, 0.059978417871940526, 0.023299026295482632, 0.04409776760205146, 0.008880944167744488, 0.0801170078076182, 0.09523260437192456, 0.03379185871791936, 0.10716326699982728, 0.05160310801358954, 0.09934371562614557, 0.2660007426334966, 17.94007197503121, 79.90494051287251, 53.42541171658424, 31.064979568604503, 51.09056988070088, 27.198938554333104, 35.657549442783484, 46.04091836560158, 28.81912846719065, 32.24336547236289, 26.105428818733465, 23.63105650871031, 46.273648277405776, 43.80926624421151, 15.382373813659916, 1.3832081517865582, 19.00551126849267, 53.77389469454366, 76.09921378474083, 73.53146553039551, 59.96649349889448, 57.89770603179932, 49.7578897014741, 66.99306272691297, 58.726828405934, 20.900516163918283, 7.5610946359172955, 26.20669068828706, 53.615368181659335, 62.580925803030695, 60.76548030299526, 57.129168587346236, 54.576274348843484, 60.462798841537975, 65.60927014197073, 66.76325890325731, 64.71108267384191, 64.30818073211178, 62.66435853896603, 62.20864188286566, 60.67598358277352, 63.580494773003366, 59.24171009371358, 60.528208286531516, 50.630169914614775, 48.87923955917359, 46.07852605081374, 37.376183002225815, 38.74176794482816, 34.86145734786987, 14.04649886392778, 11.695594922188791, 25.066043869141613, 25.414234630523193, 20.073400082126742, 18.166484909672892, 20.537918536893784, 23.518292288626395, 15.31590630931239, 9.449413361087922, 1.8008601665496828, 2.2401827862185817, 1.0994667127247781, 0.0110875359443467, 0.19735865174762665, 0.04398065957150633, 0.1446850507730438, 0.05320937605574728, 0.05997862471568008, 0.16245003218852705, 0.053993965003399126, 0.18822619421107156, 0.2710733172153273, 0.04428404188084026, 0.07843265625377817, 0.1518204090215506, 0.09413277790431054, 0.06771340079966091, 0.6573772286215137, 0.7478490255532727, 0.6317185538430369, 0.7157149466295397, 0.16622701419457314, 0.11338981514376019, 0.03570052081598871, 0.06909166958423392, 0.10721317762809415, 0.03856360589364364, 0.07319160361563967, 0.1588491278309976, 0.566655932174575, 3.0495881409414354, 5.291977505530081, 17.372144153041226, 30.54478110805635, 23.56367999507535, 20.58663437443395, 19.64731889386331, 21.090115693307695, 36.18917572882868, 19.662165064965528, 23.69960188865662, 34.261322944395005, 38.103217847885624, 43.04099159855997, 44.28960754025368, 49.924657114090465, 55.104496017579116, 55.29713538385207, 51.430670753602065, 49.9787465987667, 48.771692091418856, 53.66165999443301, 49.81110449760191, 52.528651991198146, 55.421843221110684, 55.426655969312115, 56.9296964522331, 56.08848533322735, 55.19208254352693, 57.535596739861276, 57.085061534758545, 60.65392809529459, 50.789304394875806, 54.12524884746921, 43.43812765613679, 46.14398256424935, 19.559957904200402, 26.317325061367406, 60.89202773186469, 56.91781167061099, 61.11840732635991, 49.530302016965805, 48.530074088804184, 50.90824242561094, 43.129127256331905, 44.69872251633675, 1.6002428219203026, 3.4159142259628545, 53.515657609508885, 70.72652370698991, 72.40018337003647, 32.42870138537499, 12.749222978468865, 15.94763344334018, 16.28706359094189, 23.768629720134122, 44.100753261197, 31.220205406988825, 41.2015058917384, 25.800980329513553, 29.718620123401767, 65.01545859921363, 49.26688740330358, 3.0333149625409037, 0.4087236890148732, 0.06328219119759818, 0.06480639590130699, 0.027790211005917484, 0.01707708042475485, 0.11638765508729605, 0.04239081645444517, 0.012825913933826791, 0.24588259958451797, 0.2768301615311254, 0.16292831620141385, 0.17302976770987435, 0.19834566410751114, 0.20162709447885716, 0.2486688000780921, 0.17781464563262078, 0.11019934239166398, 0.12451015593063448, 0.23510838498271283, 0.3675782097683799, 0.34641215036953654, 25.746988904091623, 95.29228102776312, 62.62700188544489, 45.61840849538004, 67.78124732355919, 65.48905734092959, 40.33762347313666, 73.73236933062154, 35.337566406496116, 32.32142652234724, 31.824697563725135, 26.3131889220207, 55.883035505971606, 55.669705637039684, 12.764288802300731, 3.0747776021880493, 33.3407191307314, 62.863410980470725, 80.18527230908795, 81.23610665721279, 62.46052080585111, 63.72014684061851, 57.38062389435307, 70.3114898743168, 61.11228058415075, 19.558608608861125, 10.226252502010716, 35.673509567014634, 60.09859108155774, 65.3504760803715, 60.17785826037007, 57.50925017941383, 58.440534607056655, 63.93111152033653, 68.1597795794087, 67.8521167078326, 68.69184124854304, 66.77924648407968, 66.1002528282904, 65.38895845413208, 63.203394182266734, 65.84352585577196, 65.11592618880734, 62.764594708719564, 56.167572083011756, 49.163309374163234, 48.41468188070482, 44.20544132109612, 42.957802049575314, 44.20362134133616, 25.208398449805475, 14.525995869790355, 31.69975046188601, 29.46896714548911, 25.495104097550918, 25.129345040167532, 28.021481152503725, 36.367412151828894, 23.774040629786832, 18.294605208981423, 6.981722808653309, 2.2337032758420516, 2.465799479715286, 0.20095462249892376, 0.22710236780826124, 0.1885194679902446, 0.2700103242551127, 0.2008236980726642, 0.44530886135274367, 0.9970737296727397, 0.28081424774662145, 1.0797777627744982, 0.36924690248504766, 0.9809050456650796, 1.0517119784508984, 0.7555038373797172, 0.32386566181817367, 1.2167498709694033, 1.7479058403161265, 2.5644657208073527, 2.578965742741862, 1.5217592591239562, 1.0507257475006966, 0.37114082505145385, 0.22362019175723677, 0.1402608623668071, 0.22535320521602709, 0.1430204949311672, 0.11491207781458095, 0.8363330388261426, 1.8552513060069855, 4.308605963183988, 15.89701133389627, 25.167599916458133, 40.12108118303361, 31.948852346789455, 24.243556184153405, 23.93753678567948, 27.18506709221871, 39.15927679308, 26.013421781601448, 31.475357547883068, 42.26606853546635, 41.109922470585, 45.68674402852213, 46.57771825790406, 50.068513962530325, 58.15647263680735, 58.533600684135195, 53.0850794238429, 53.97735588012203, 50.48368507815946, 57.786546061115885, 51.92081013033467, 58.66100711207236, 59.72914303502729, 56.42919809587541, 58.97342781866751, 57.440714605392955, 57.90830035363474, 60.98571354343046, 60.78107564680038, 63.01714043463431, 51.11997588988274, 54.8574298427951, 48.874081642396995, 52.32142925262452, 22.123915187774166, 26.09761937972038, 65.23417388239216, 60.90961956208753, 63.29495799156928, 56.92333829018378, 50.18505150272001, 54.29871174596972, 50.17080153188398, 59.769233580558534, 6.5610343890805405, 3.190008012517806, 55.18874852888046, 75.48652387434437, 62.948400897364465, 31.812416622715613, 17.23680865380072, 19.815284590567313, 15.808642295099075, 45.40511392777967, 45.3532092032894, 47.55876187355288, 60.66068241673132, 31.013163097443122, 48.54768945324806, 67.47181154066517, 72.09699200045678, 7.727423233370628, 0.7089940879133441, 0.41972863397771315, 0.21820853133836102, 0.14845250264531182, 0.15179523537235876, 0.21458544107454441, 0.1033067497454824, 0.1711840473956639], [0.03647798514594475, 0.01514077117110813, 0.01866751534473752, 0.030651503437829596, 0.07697778633765637, 0.08296251882829013, 0.0764375641160915, 0.038440288720472206, 0.03377585131074152, 0.04711678221581444, 0.05834723665048519, 0.14804335040671213, 0.1464203165303315, 3.317493623302829, 53.75174899255076, 48.939440096578295, 31.825013314524007, 43.576983482606956, 60.9424654899105, 32.048831601296705, 42.733819023255386, 39.226870998259514, 11.681002724555231, 27.6548630960526, 10.995830355152007, 18.82826720514605, 66.13937454838907, 48.023574506082845, 8.181465527703686, 0.281804922006784, 14.169094504848605, 44.33659753491802, 66.31772472012427, 66.29266077472319, 68.61570804349839, 60.92386561055338, 46.747898132570334, 56.46649983621413, 45.929876066023304, 12.02325011453321, 4.887381590181782, 30.37703310289691, 41.826743464316095, 56.79763024853122, 61.772293890676195, 61.56502800603067, 58.436114095872455, 60.978778792965805, 56.52058147615003, 62.07144129660822, 60.524697765227295, 59.944606673332956, 56.3014425769929, 58.19381752321797, 57.17090260597968, 60.30713958124961, 51.69941979069864, 44.50368658188851, 52.89564071163055, 41.344550809552594, 33.858319021040394, 25.7719567514235, 5.2714733154542985, 3.3683915243994806, 21.936627895601337, 30.187739518380937, 23.56165801325152, 16.925405802265292, 22.163899829310758, 22.664908093790856, 20.522909587429417, 11.519770756844553, 2.8356914895196117, 2.3614433503920034, 1.6736266906222992, 0.40110595584396397, 0.09697419801546682, 0.04974227278463302, 0.009223010086814963, 0.10302373388361546, 0.1111488317650172, 0.10506866004077658, 0.32258555954021795, 0.7659180366223859, 0.6951403990387918, 0.6963667525879799, 0.3968175182179098, 0.19051285941273938, 0.5950332384917044, 0.05972354808041166, 0.27734785310683713, 2.428079761805073, 3.0028452555979452, 2.8686295930416357, 1.7652709085133769, 0.39597898901950934, 0.03646059111962396, 0.13510119890974415, 0.12431834283615313, 0.0987326532542225, 0.08838652858450528, 0.06891124821718662, 0.12826731158120017, 0.4130771828274573, 1.2953979281648513, 4.729320368459148, 11.055898512563399, 18.10385250276135, 20.356908998181744, 12.929305857227696, 14.986384068765949, 6.609313862939035, 14.404293548676277, 28.19115896378794, 13.528437114530995, 14.70383515281062, 25.513913823712258, 36.60535881596227, 37.869487731687485, 49.558433255841656, 53.8818383216858, 51.38710498809815, 53.73273726432554, 48.26497677833804, 43.01299764264015, 47.28414104830834, 48.116550368647424, 51.13366103941395, 49.420303067853375, 49.869245790666156, 51.4933463065855, 51.58124269977693, 55.31333085029356, 58.15675896982993, 55.57708278779061, 56.05675335853331, 52.972911404025176, 46.86327857355918, 26.385925354496127, 23.125139397959558, 23.899177966579316, 38.188792197935044, 50.76848837637132, 49.582285188859515, 41.54032807196341, 57.99238420301869, 50.42761871891637, 51.990016429655014, 59.78684110026206, 10.138868958719316, 0.6076236177356013, 18.831563957275886, 61.58363180775797, 38.17200445359753, 22.89854995666012, 15.307550680252815, 23.484108832574663, 13.015910810039891, 17.810335659211685, 41.36210341607371, 23.0955784551559, 46.45154737657117, 39.03038770921769, 45.91879144791634, 39.708796931851296, 56.85801513733403, 26.299996029946115, 0.7887121554343932, 0.05187287438480605, 0.05551257726526069, 0.029410140310984947, 0.08464995005558576, 0.013427937425853265, 0.028665414748473034, 0.02744645777819378, 0.03735750387873381, 0.059482590445587714, 0.1328940076693412, 0.030404193018893563, 0.07383165475461753, 0.0953513939654635, 0.05789999452029025, 0.025074030948622573, 0.15290687491576518, 0.05528316457545566, 0.1652040876327984, 0.029079063923188278, 0.16586338290043418, 0.29933757959834995, 4.327155832321414, 63.85982244245468, 63.11081840145973, 30.310062554574785, 51.05851627165272, 57.0788759569968, 29.231308775563395, 50.4628376806936, 31.55139857722867, 22.048899858228623, 30.048281608089326, 14.7084782585021, 32.2069521488682, 64.6079949409731, 53.06851133223503, 15.075383628568343, 0.48460721068324586, 12.346856440267256, 55.336174734177135, 72.4728491998488, 67.98342981646138, 74.39367309693368, 66.14938443706882, 56.096424210456114, 62.58859403671757, 55.16819530917753, 16.933805557989306, 5.628940482293406, 32.62164865770648, 41.384072611408854, 53.923725312755955, 63.37211885759908, 60.215595383797925, 61.259612652563284, 63.73947235845751, 60.64029393657562, 61.330584018461174, 61.320170125653675, 60.94031995342624, 61.39050214521347, 61.127754334480535, 60.37928373582902, 62.50650275138117, 52.26426070736301, 48.110753105532744, 53.566695490191066, 39.922609252314416, 39.36245949037614, 28.153751319454564, 5.504862185447447, 6.183874962791321, 29.69926322660139, 32.67003109378199, 27.25299862123305, 19.103231237780665, 24.972409048388084, 22.47661667485391, 25.896205671371956, 16.822072921260713, 7.552763031375024, 3.385604110456282, 1.2686113268136978, 0.31445797953394156, 0.029922850399969086, 0.05574295139541069, 0.05886609651028149, 0.08979145722884325, 0.08376567774722654, 0.03533376771355829, 0.10778268739100426, 0.6063318709211966, 0.4279736705845402, 0.5983692756102932, 0.9972344855627707, 0.4812345545618765, 0.2285872607101356, 0.15878938829466221, 0.23338013659081153, 1.965240939490257, 2.5721148329396404, 2.1092067562764694, 1.257075023266577, 0.8005951597325264, 0.026573651890841224, 0.08068077957197543, 0.13702820115272077, 0.048437356918809876, 0.041311471347486785, 0.07049530353997985, 0.016920495883471543, 0.05931251892639745, 1.620069545122885, 5.978837964996215, 16.16188604985514, 22.062196693112774, 31.5092860498736, 19.897952464319047, 21.668410339663108, 12.391344943354207, 24.19914318669227, 34.91538993773922, 18.214273106667306, 14.326284470096713, 28.89868982376591, 41.0123299783276, 39.32589907799998, 50.040700435638435, 55.862392071754705, 52.543757038731734, 55.230188369750984, 51.66633459829515, 46.69065506227555, 49.39774159462222, 50.45271012090868, 51.610950731462054, 54.39181704674998, 50.71764661419777, 54.315393586312574, 55.51471710205079, 59.23783871435351, 60.127632310313565, 58.74920160539689, 57.47789867462651, 52.649904220334946, 45.41945019075948, 27.314548453977032, 20.11511645009441, 29.738033894569647, 43.75529835301061, 59.01639346153506, 53.31916647572672, 47.79607703608852, 60.51184023580244, 53.59786656595046, 54.42797737736856, 64.29644107818604, 10.210522817027185, 1.73596479719685, 26.244400355123705, 71.81083940690564, 57.144108895332586, 35.00445911961217, 18.950684378224036, 17.637443465571252, 20.535094430369718, 16.165823128915605, 39.14104953888924, 33.286763006641024, 30.654827125610847, 50.63094654390889, 38.520103039280066, 40.12270112191477, 67.60685090095767, 32.51063381471942, 0.7509274119811674, 0.019691556564442093, 0.06935843672122687, 0.027803701814264063, 0.041797224717635306, 0.04288045772080941, 0.12209296466842776, 0.024852060803001928, 0.04279816838642282, 0.2018271813229207, 0.2761207947567586, 0.1252839506994332, 0.3381241821954328, 0.1703081177848001, 0.14891891229537227, 0.20623974051446686, 0.2197001351704521, 0.18680500918098036, 0.33449712359616834, 0.15143503615212056, 0.47907253186548915, 0.5561367482427628, 7.740859802692168, 81.99975290606099, 67.71120948176231, 46.955434660757746, 55.23484814551569, 76.88069897313272, 39.10626988257132, 64.35493930693596, 54.55647422421364, 19.8203444480896, 37.223947971097886, 17.292682816905362, 30.359419699638124, 72.41503346350886, 59.74631517164169, 13.343191416032854, 0.6662303245356006, 18.543091281767815, 56.42688389747374, 78.86951323478453, 77.71408496364471, 78.32976372011247, 70.89319306035196, 62.322116051950765, 69.35909917277675, 55.951641682655584, 15.687421444923649, 7.69378645766166, 41.37250161940052, 49.77548545406711, 58.502472754447695, 63.790208216636415, 60.937813558886134, 59.400103246012044, 66.56519489903604, 62.105538460516165, 68.99308712251725, 65.07578465246385, 64.9588470305166, 63.527276054505386, 63.56317750869259, 61.59979589523808, 64.66590481419718, 53.95598288505308, 50.72309870873728, 53.46659660339356, 43.829466450598936, 44.808231169177645, 43.729920617995724, 10.407230661761377, 8.781847530795682, 33.909643234745154, 39.19908100558866, 34.28542983147406, 25.79955062558574, 30.472925247684604, 32.05435429849933, 38.16107280792729, 27.58282288428276, 12.51823656020626, 6.389092389614352, 4.4705478798958564, 0.9171089205530383, 0.29105613849336104, 0.19531163417043226, 0.2936410723674682, 0.21554764750744068, 0.19694583760874887, 0.4075102670298469, 0.628489156163508, 1.4535210497917668, 0.9465536631403432, 1.3690919092585965, 2.785654058379512, 1.6194539781539672, 1.6409386381987603, 0.8132489097695198, 1.1592873930931091, 3.332199569671385, 3.558919184630917, 3.3507891528068052, 3.5634789399562345, 1.182790235165627, 0.1574758539396909, 0.31205739705793323, 0.35306458211233543, 0.49725461751222616, 0.23833209828984356, 0.16857960892300453, 0.12318090145145694, 1.4487492413290086, 4.6063736754079025, 11.677192141932826, 22.523336025976366, 32.050078915011504, 39.03017982359856, 24.73152452899564, 24.78140727166207, 14.961054382785676, 27.238215208053592, 40.623595637659875, 22.550912249472834, 18.984965893530077, 34.98743603306432, 46.04699411699849, 41.63243316834973, 54.41408826458839, 59.53945721349409, 58.6875537133986, 57.331786463337565, 52.13761521923927, 47.85691691983131, 52.916774442118985, 51.432078884493926, 56.06127585134199, 54.94407107753139, 56.05310947664323, 57.260387559090894, 58.40335838256344, 61.55738330656483, 64.14566124639204, 62.30169619283369, 62.49525339372697, 56.200625896453865, 52.351070604016705, 37.3945475393726, 28.55382719347554, 29.31361971362945, 46.70141020128804, 62.59037871514598, 58.38767282424435, 52.924795689121375, 68.03062377437469, 60.235062106963134, 57.56615984824396, 72.12479376023816, 15.196370117125975, 1.815216654250699, 24.07133471581244, 70.89478554264193, 48.7125898176624, 30.64398373326948, 22.706783317750503, 28.567582945669855, 20.718749607762984, 24.41523244304042, 59.0182722768476, 32.42187450009008, 57.878808052309104, 59.46249638834308, 53.644480013078265, 55.06371905726772, 72.27304366327101, 52.36808976819439, 1.6838585609389891, 0.4089573458317788, 0.17619492125607308, 0.1417647695709621, 0.17197370018449523, 0.1238782789498087, 0.17172675940298265, 0.11550663099173578, 0.09583751505781567], [0.05137639961415722, 0.012305454865488554, 0.0878665081015037, 0.03734588615536209, 0.024858666396129037, 0.0391780658655109, 0.10799726095771599, 0.06705323219179146, 0.021209475516732183, 0.07625696654882162, 0.0599692324777284, 0.09519063041455324, 0.08683846407239476, 0.04316601316414533, 32.68035869444571, 66.82672285264539, 42.4921186508671, 34.58783280464911, 72.31360097085276, 48.1466467149796, 28.272689350189705, 49.650958045836425, 11.819059368102781, 28.22170049913468, 20.213581669715143, 10.782339669043019, 48.86220470551522, 90.14519783758348, 42.888678120028594, 4.958893752867176, 0.6504500164620338, 18.36378993526582, 63.43672029433712, 61.65162217232489, 53.72284896912114, 62.11692117875623, 54.504616568165446, 41.66251774757139, 63.7663092151765, 46.417454135033395, 6.455843285206826, 14.957563473332314, 36.98347922294371, 42.12980931805026, 51.93523660782845, 55.81338597882179, 54.07667813762542, 57.61216140562489, 62.25920907912716, 64.69254163003737, 60.96353254010601, 61.05286452078051, 57.76704403661913, 64.11076391896894, 60.20318892694289, 57.89201075030912, 54.284944226664884, 63.0791138833569, 46.58873227334792, 34.51657902809882, 17.013131572354226, 2.458710531073232, 1.1724387325586811, 19.84040541033591, 36.371938567007746, 20.077626435987412, 8.51090588877278, 14.854230592327735, 20.680696733536262, 14.473441993036579, 17.962052937476866, 7.900968011348479, 3.094980750353106, 1.9416699462359952, 0.7717627971883744, 0.20054801367223266, 0.042265664500695084, 0.04047417938108406, 0.23898547935870387, 0.06617305845382714, 0.39018604664071915, 0.4113063859122415, 0.2975757305900897, 0.5422498417958137, 0.5227154577451368, 1.5207249791391435, 0.35451729932139, 0.31813927715824497, 0.5985267220004913, 0.3570209665884895, 0.7116764988149367, 0.9459296998477752, 2.1650622881227926, 1.8091154074476612, 1.6405098741092992, 0.162158872812025, 0.640798227921609, 0.26230921007452473, 0.17055669799447062, 0.09651880470975753, 0.3499090046651902, 0.19480620000150897, 0.0582775992581681, 0.05123303775044699, 0.5491184022638106, 3.830813717457556, 8.22964252964143, 16.287950046600834, 20.96123641537082, 16.823304545494818, 12.010518100953872, 16.240977702602265, 3.727627435038167, 13.280622747636611, 26.569023555324925, 11.381887678177128, 10.15583517089967, 23.160958482373147, 35.815773933164536, 43.760397434234626, 49.92737531661988, 50.51331466244113, 50.47773484260806, 50.149703102727095, 49.398553525247884, 47.14925466045257, 48.67284444070632, 50.61399013765397, 51.86317482302266, 57.97442366999965, 57.90149504138578, 51.84868558760613, 52.509063674557595, 53.83709976750036, 58.96758740948093, 57.8753092981154, 43.53692039366692, 30.9455120178961, 9.748384260362196, 6.676222633930945, 39.40609193617298, 52.51785762848393, 36.66399040529805, 44.456645596411924, 43.78229994927683, 52.85835858314268, 40.672315397570216, 39.12526984368601, 34.49090319295084, 1.9220151944506554, 5.042658419378343, 47.82681272875878, 35.94910706243208, 12.819557939806293, 17.461893866139075, 20.25968913109072, 19.707948930801887, 9.713398679610222, 30.073049414542417, 28.123037199820246, 29.77013064968971, 59.8401657227547, 33.639744943188084, 32.42899360195283, 40.037213064009144, 59.63752823491251, 17.3219633102417, 0.5085784082691516, 0.09908104705954753, 0.03987885245512571, 0.0876857802992867, 0.09358557662175548, 0.06456995818523631, 0.02118920483025572, 0.03463220354470034, 0.03389281378458104, 0.054199839641730634, 0.035171529443393794, 0.03622554002269622, 0.03721663180077749, 0.06805114598283846, 0.048767322479116346, 0.06296707242126427, 0.009334801467165593, 0.10856579012808301, 0.06681941449642181, 0.04805658823780475, 0.12315817928362278, 0.10803293001147048, 0.0816636550570688, 39.85873345405825, 79.9645919184531, 43.88923552728469, 37.81278987084666, 93.3507783951298, 33.093041066200506, 41.694190886712846, 41.93409481356221, 15.807935287875516, 35.47795587970365, 15.804858188475333, 20.38104726422218, 65.26621964669997, 88.17457552879088, 50.64785195935158, 7.840336013224817, 0.3233604727973861, 15.665484609142428, 71.31877022404825, 69.1669265685543, 61.39416563895441, 66.76994262203094, 59.598508496438306, 50.56166571955527, 69.00067298643052, 53.981384154289, 9.511137739304575, 16.22308973343142, 43.64891582919706, 45.26519906136298, 51.65274358564808, 54.3021006737986, 54.73209442630891, 56.31384511147776, 67.11744892981746, 67.97491827318746, 64.27407964583367, 66.78496529979091, 63.530970927207704, 67.36006321445589, 63.18111904205815, 57.27620647799585, 57.02224869881907, 62.07784652709962, 45.93614401355867, 39.093977174451275, 19.065348986656435, 2.6701789902102564, 7.301546008356157, 28.10360577798659, 36.78550935560657, 27.16639857138357, 12.576873052504755, 19.806714211740804, 23.414867231922766, 22.745928572070216, 22.515710938361384, 12.231961392587232, 5.0463204422304715, 2.018596573222068, 0.6080587556765926, 0.033159257784005136, 0.03301403815707853, 0.04243490481448751, 0.1702682812127375, 0.023634193592794964, 0.12789610367749008, 0.4788271385815836, 0.5626481891639772, 0.7110203598295489, 1.232427952270354, 1.2880254657037797, 0.9324637127499428, 0.40158889767143036, 0.5117834137091714, 0.18465985574068564, 0.6725366377542097, 2.7255932554121944, 3.0306234811582877, 2.762642248022941, 2.0207779013341476, 0.6378668690881422, 0.22795379792730655, 0.5235928429230567, 0.2939001020164259, 0.1280613028774819, 0.10432001593853198, 0.09855669817977375, 0.12838417063316993, 0.2070782543911088, 0.681674657089095, 4.216740621674446, 14.837731142197887, 22.604256483816332, 30.930771750788537, 24.148185714598625, 19.46546212319405, 17.07085317181003, 7.997915273712528, 25.632045807376986, 30.047159810220045, 17.891760141618793, 11.90054758902519, 25.09930164583268, 38.81248043429467, 45.65281944890177, 50.02595232379053, 52.540383800383545, 52.2457863438514, 51.88602655164657, 52.23092840563867, 49.80969636671005, 51.97387195402577, 54.49886637349283, 53.735526069518066, 61.46612151976555, 60.60301180808776, 55.41444955333587, 56.196613311767585, 55.4281464699776, 60.375902652740486, 58.75773668289185, 46.13208993788689, 30.41489378098519, 9.762272392549823, 11.607395525901548, 47.73861823543426, 57.89330513246598, 42.28872806795182, 50.30380518205705, 49.15281703395229, 57.668380737304695, 48.7805841045995, 44.899155632142104, 31.316305437395652, 0.6065888474545171, 9.03135440041942, 52.66900224070395, 44.38890626353603, 19.706668276940626, 21.64656077661822, 17.413548692580193, 14.68299658067765, 16.02659958024179, 21.78972532672267, 42.869211396863385, 27.944865495927875, 52.72459007078602, 40.288264366888235, 25.29307261590035, 46.86313344586281, 69.35751453522714, 20.619372437077185, 0.5345514548882362, 0.09824198926047933, 0.022736713928621144, 0.08671693188408691, 0.01820870337166613, 0.0271659757521364, 0.02107507879695585, 0.016179363273324508, 0.022618989197296963, 0.19221887593307804, 0.1942089578557399, 0.20099741617037406, 0.19070421285446615, 0.24480704278234514, 0.1434985337959182, 0.22770978360166474, 0.1964035699324262, 0.37870174514189847, 0.22386713253874935, 0.1669927803619254, 0.2103138267393074, 0.24307159316395563, 0.39767143046182973, 54.21347079738494, 87.24868436013499, 61.94582346946963, 45.62126005849531, 93.65051023421749, 59.230872584927475, 41.82994804074688, 74.72444657356509, 16.688167125948016, 41.09378976206626, 25.168227495685702, 17.64377417102937, 57.89052417201381, 96.00874116343837, 55.65713836300758, 8.375344853247366, 1.4985543946104667, 24.693910960228216, 78.07641783068257, 72.68244497237667, 66.3534967360958, 72.78071603467389, 64.09890267156786, 57.31479083338092, 71.77667556270477, 54.88228198020689, 8.727807075746599, 20.428292212947724, 48.399761184569336, 50.674881012209006, 57.03061119202645, 59.81147358494421, 59.281698657620346, 61.710677377639286, 67.73608515339514, 69.46798416876024, 68.4423000581803, 68.91263931028305, 65.39219440952425, 69.43363989553144, 68.82411141549387, 57.886668482134425, 60.939347205623505, 64.67309451872303, 49.700968265533454, 48.14461492723035, 30.99364930583585, 5.664377625911467, 8.787355519110157, 30.641110597118256, 43.328964171871064, 31.052786880923858, 18.013979235003074, 24.71883958385837, 33.39347108717888, 28.79219747358753, 32.94978434039701, 16.501664307809648, 9.06617916399433, 4.612028752603839, 1.6075229861082572, 0.37490587140763965, 0.12559612386769828, 0.3058529735332535, 0.330365366272388, 0.1401521391685932, 1.0317761643278984, 0.8078534444493632, 0.7793500707034142, 1.4938395830892748, 2.694287593326261, 4.4771531512660365, 2.405307706325285, 1.1255583191110243, 1.964012134459711, 1.029563212106305, 1.5696424510209792, 3.5498930754200106, 4.210573675171021, 3.7626622905654297, 1.8434667899723978, 0.944951436211986, 0.8097320146137669, 1.228068115249757, 0.9055159264995206, 0.29791746709135275, 0.6279142837851279, 0.49763315687737164, 0.28494502447785874, 0.3127827903916759, 2.2323681990946493, 6.91847360903217, 21.069819388851045, 28.23778025565609, 35.6915799263985, 29.415556230852683, 21.279056264508156, 21.615707412842784, 8.302832976464304, 26.76680122652362, 38.92760199885215, 22.288611588939546, 16.85262622371797, 30.685964861223777, 42.53281716377505, 46.34344685462214, 54.43439437497047, 52.40756057923841, 56.08082494428081, 55.31215806161204, 55.51072412921537, 51.507925756516, 54.10173423828618, 55.77051839520855, 56.15358883334745, 63.76590128867858, 62.62630762592439, 56.95064190895327, 59.329449592098115, 58.25901516022221, 64.1923374514426, 62.20313879751391, 49.27426930396788, 37.980683003702474, 12.916033537157121, 10.249197386926221, 48.31260611934047, 63.60164419297249, 46.89802292854556, 54.784077598202614, 53.64602542692616, 62.42577252849456, 48.096989508598085, 48.008865617936664, 42.52689438481485, 4.270028962242988, 7.709237654362956, 57.05109773143646, 47.04371544622606, 18.499217610205374, 25.48895185993564, 29.593882868366858, 27.28204965591431, 14.126008249098255, 41.0215397034922, 45.49255924840128, 36.38721227645874, 80.82832920935847, 46.51990252156412, 44.1294297095268, 54.98726421786893, 79.16871947626915, 36.431468379112985, 0.6591841542432386, 0.28538767008050797, 0.10468684948019444, 0.20088607295145913, 0.21061399530979896, 0.13933386533491074, 0.1253426866605878, 0.11797511184047307, 0.18329362985828232], [0.056074487435961926, 0.05406462129265551, 0.05773458847655885, 0.038642995585236824, 0.012649592094784303, 0.043490328826010234, 0.06198464509760661, 0.061092447609670704, 0.06421331361296677, 0.0921658778022374, 0.07364494380571189, 0.09350920531658397, 0.1956322879320191, 0.4192324235073982, 13.221419472848217, 59.101426524500695, 56.64674451274257, 31.217259706989413, 48.51952683541083, 75.42448766769903, 23.71919216648225, 41.00311633079283, 18.887693074441728, 19.21089441545548, 24.258002273498047, 12.344406920094645, 22.29753694226665, 79.37296513588198, 68.47724053167528, 21.871241984828828, 1.42391647061994, 8.515361701288532, 31.73681882119948, 67.46115053853681, 60.927650697769664, 60.35878150693832, 66.91051252426641, 53.57735649231942, 41.2561248963879, 56.48317383181665, 26.701703609958773, 5.872306391116112, 31.488309214192054, 36.5685591390056, 41.86974048614502, 50.25026482920493, 51.103490168048495, 54.563754143253455, 47.46312664401147, 50.342177729452814, 55.40666364854383, 60.028047254008634, 59.141626896396765, 58.325797434776064, 54.156490525891705, 59.688028750881074, 57.35564231872559, 45.73773091839206, 26.43887931300748, 9.922346280467126, 2.7046237741747214, 6.186303400224255, 21.48393342571874, 25.545690905663278, 28.39431420449288, 9.659659266471863, 9.54640769189404, 20.39414405822754, 14.269892554129324, 19.96401890631645, 14.304619258449925, 8.12071781965994, 1.6785528198365243, 1.0298063990569886, 0.2577123760936722, 0.06497473606178839, 0.10114915503729736, 0.1225913584893269, 0.1596100829661854, 0.4205931488785052, 0.12016993842177814, 0.1580596435815096, 0.2582742249773395, 0.4357693200149844, 1.1632634507071589, 2.877349021934694, 2.645370979462901, 1.015075570152652, 0.6006460276342208, 0.8110331383443649, 0.4431499030080534, 1.073537884700683, 2.8892298811866395, 1.5272678603087704, 0.4958848216600957, 1.134240362913378, 1.4752882430630347, 0.9617269231427101, 0.6917504293303336, 0.2760911011888135, 0.15750658938721304, 0.01740440489694236, 0.03964439124589966, 0.5196194819385006, 0.10502762071067288, 1.3218131300903138, 7.017464426255996, 13.013536795493096, 17.506834422388387, 25.229181128163493, 14.016283865897888, 14.307597318003255, 11.619267559820607, 4.9166709088510085, 12.877352103110283, 20.345647873417025, 20.55959551565109, 11.896606587594556, 21.45763393371336, 40.94725785716888, 50.138971497935636, 50.320675296168176, 54.06618187504431, 52.3789978796436, 48.448935939419655, 48.55521648160873, 51.63668932453279, 53.9778422540234, 54.93995651122063, 54.022333698887984, 54.22841502774147, 58.98947031267228, 56.429468739417295, 64.51506614685059, 59.53177329032653, 52.05120932671332, 27.76738020681566, 7.500998041322155, 6.424225059247787, 28.67652285483576, 53.08866839255057, 49.0654815396955, 53.12473066391484, 54.23929568259947, 55.10719853062784, 53.690281529580396, 35.609841654377604, 18.64804998520882, 2.325339403844649, 0.40151694669358196, 30.450954091164377, 54.93334339511011, 19.595806406390285, 30.889906537148264, 20.858109458800286, 19.33403330464517, 8.771114945411682, 9.905080987561135, 34.64524061449113, 22.536303381766043, 41.92648149305775, 34.018069313418486, 23.170762446618852, 31.282353401184086, 46.223163450917895, 45.88848329359486, 4.161560718090304, 0.13915254764499205, 0.04647900252753208, 0.03520675416615221, 0.17003796453918182, 0.022797129537549712, 0.07343606227227757, 0.0605823747783659, 0.09443093166356126, 0.04872848182135532, 0.07580428519436429, 0.04452617163018835, 0.06137141852729744, 0.02926756560261692, 0.05094667025391133, 0.0436224406885524, 0.05898406638974144, 0.11605085219226538, 0.21296838268397317, 0.017590451264573682, 0.13416854814896662, 0.19283876363788882, 0.21483333180508307, 0.36776501264783645, 17.71924057314473, 66.07266287649831, 67.39948303468766, 24.727025570407992, 64.51119476749052, 67.21127202433925, 33.389027041773645, 45.13467827150899, 22.75660918604943, 28.86532614308019, 18.934810546136674, 19.09389795795564, 41.376035674925774, 103.75160970995503, 74.91599944330032, 34.375295254491995, 4.6443515343050805, 3.853595824010911, 27.3504557917195, 71.91507247186476, 67.59741367832308, 68.30943369096326, 68.69932513083182, 59.05198112610848, 50.37490206380045, 60.67812127451743, 33.92082591210642, 9.023486125853754, 27.84136591419097, 37.24916488893571, 49.059546993624785, 56.504260493863015, 53.69111307205693, 57.998487411006806, 48.13740561085363, 52.40527775979812, 55.23910783952283, 58.82408749672675, 60.43847230172927, 61.699839868853175, 54.88960896768878, 60.620544802758005, 57.8132652467297, 45.10792770693379, 29.761995653952326, 10.361858644793111, 4.419600704023916, 10.656574753022964, 28.747592279987952, 28.279324039336178, 34.03340970316241, 14.557214994584362, 12.516018459873816, 24.569250191411665, 21.966147653518185, 27.85660432231042, 20.333988628079815, 13.418584273707483, 2.6355851561792436, 0.9356556640517328, 0.07985459205003516, 0.047702651786347555, 0.056285977498778415, 0.08373524873487412, 0.10446817734308782, 0.21031827004926823, 0.48631650605990046, 0.4695070048253383, 0.43124474344714997, 1.3447240619890153, 1.633673428047088, 2.979423802706503, 0.3787859841700523, 0.3929613993292855, 0.26939582980928883, 0.6587302011828269, 0.7336925174440108, 2.9738947316523525, 3.7130371985896944, 3.278406223943157, 1.6040451920801595, 0.9654479041214913, 0.47643596366528546, 0.7903806949334761, 0.20082074097327648, 0.3461813740432263, 0.07084267078748635, 0.2852940847796779, 0.20941390325465511, 0.4884346165964681, 0.8799228901343962, 3.0601755986290597, 11.346034273024529, 18.86918144841348, 25.285431838804676, 31.76558352285816, 19.04191086369176, 20.172328141427812, 9.057840205007984, 10.373744407007772, 22.02530876282723, 26.621110670028198, 31.043216297703406, 16.723629274675925, 23.74993178152269, 43.350443070934666, 57.25446085776053, 50.72695439861667, 55.390942788893184, 55.51435232162476, 51.02513297911614, 51.59744993332894, 53.746602842884684, 57.22899290823168, 57.82331435911117, 56.08976010353335, 57.85160641516409, 60.107541930290964, 58.62558418704618, 65.95903181260633, 60.312560296827755, 50.569894852176795, 24.02710214737923, 6.2592163393574385, 10.056536447617317, 35.5029413777013, 56.88465195317423, 55.80169339333811, 56.12420243601645, 57.78243933954547, 58.80971201004521, 60.83090151509931, 37.54984986397528, 12.159987861110318, 0.7372029161741658, 2.2007205553593177, 40.87503525518602, 55.133294059384255, 29.20159878269319, 31.059378423998435, 22.97450665504702, 11.899643482700473, 12.113291063616353, 12.116934945506435, 30.635838931606663, 32.61416673660278, 35.26979177228866, 39.88858269106957, 26.131232130912046, 33.10639281426707, 53.275353600901944, 52.42393647470782, 5.09163607512751, 0.24122237948881042, 0.03368387862499203, 0.06629198594319244, 0.07704595284115884, 0.027649275725707415, 0.11504548436571514, 0.03467016703178806, 0.04747224318224096, 0.10678481956523274, 0.3134568864780088, 0.23488617351939603, 0.14946694095288554, 0.13461045830720855, 0.2010471965636938, 0.188984330142698, 0.33499627584411257, 0.3008152406302191, 0.28582277737798234, 0.14490229798661125, 0.2523882642027832, 0.3046149754476163, 0.5920089685147809, 0.7170210958969209, 26.533808515917872, 84.68408184666788, 77.04156321863975, 43.04421970921178, 59.305613348560954, 88.16982946088238, 33.322452652838926, 61.32465339476063, 28.573633201660652, 31.14892221266224, 33.82163309281872, 18.61237798967669, 30.147674468255815, 89.8028612136841, 80.97788918402888, 31.083008743101555, 3.2381244628660144, 12.14076824726597, 41.68471051800636, 82.0245893539921, 70.15814089005994, 70.75081102309689, 74.84080760709702, 63.65261539336174, 54.12502919473956, 65.75807702156806, 35.26951328400643, 9.491354284747954, 35.27989972022272, 46.539235884143466, 54.320155343701764, 57.88425622447845, 56.599158317812034, 62.631394940037886, 54.8983480084327, 59.84547661196802, 61.643647993764574, 65.74647465059834, 64.62470816027734, 63.93070359383861, 54.065687656402595, 62.15638806743007, 58.40321717723724, 49.59957499657908, 41.56805922908168, 18.204094556070146, 6.508688397945897, 13.044633346219218, 36.265916901250044, 32.05209893565024, 38.755919856409875, 17.715014219284058, 15.670747449321134, 30.131500574850268, 27.014187074476673, 36.596094177615264, 26.06507351321559, 19.29739248368048, 7.203582361821206, 2.1135184216883878, 0.44024502017324973, 0.30167567994325395, 0.1837610507444028, 0.42467710231581046, 0.5837066591747346, 1.2431941229489543, 1.7117825270660463, 1.0123076638387096, 0.9601356053063947, 2.4433238083316438, 3.610288505592654, 6.676533972063373, 5.10659501437218, 2.302041505613635, 2.4768728210080058, 2.7495937482003243, 2.2157449491562384, 3.3540721766410337, 4.233484239347519, 3.4758637316765326, 2.030516656175737, 2.4618888766534868, 4.183713284231001, 4.256455600261688, 2.3027399326524427, 1.2529874232507523, 0.27667783260826145, 1.0488113857084707, 0.3050341174727486, 1.6314218649941108, 1.7238045916441949, 3.8311733497727305, 21.805518750221502, 27.55286774327678, 33.94277941796088, 38.178699939481675, 26.02111354950936, 21.397727574071578, 17.864760506537653, 9.440768457228138, 25.43706870848133, 35.341225977866884, 36.57954177548809, 18.2688646547256, 28.882317850666663, 46.73068677225421, 58.01300802538472, 54.42663200439946, 60.61706173804499, 59.09866909826956, 53.963623662148755, 54.88138767980761, 56.923365746774984, 58.85701187195317, 59.01595023370559, 60.172610129079516, 59.63064839763027, 62.25787547326858, 61.3987861910174, 69.3723097155171, 62.21620813492806, 56.20928256742416, 33.156532472179784, 10.49688917975272, 8.709141496689089, 32.66181765064117, 63.34678034628592, 58.64223464842766, 63.185551320352864, 61.97527262472338, 65.70863554554602, 62.08337314667241, 46.504295410648474, 23.8408915458187, 4.609143359045829, 1.506853639598816, 35.809247109197806, 63.940034912478545, 26.68061302554223, 39.71325274436705, 31.798531432305616, 26.541778772108017, 17.675480650317287, 14.430131181593865, 52.16304786743657, 36.12913993097121, 53.6749372174663, 49.309249001164595, 31.616611903713597, 45.70030758457799, 58.78910387715986, 71.25873442619078, 11.97510596244566, 0.39038081683458825, 0.20967256518140917, 0.20636056790188437, 0.3321892990460319, 0.10359761034769398, 0.27812337923434477, 0.17716443616776698, 0.2288017959724511, 0.13165253154452772], [0.04444067238739902, 0.06378988149545847, 0.03936640858169525, 0.04908806051037485, 0.024097965985176065, 0.04012087495216439, 0.05587393710870416, 0.06435828043087836, 0.039373602147304246, 0.10039046752236544, 0.03258223269855784, 0.061467941775317156, 0.18552260863925182, 0.2269102482786102, 0.722082669456159, 14.710766961497647, 73.2779941251201, 40.290708003505586, 44.492178347802934, 48.27008762667256, 31.356399905297067, 30.867674543011574, 20.551138885559578, 13.715264508801123, 23.632109665101577, 24.068351753296394, 20.096298879192723, 22.235145761120705, 54.50949207428963, 79.19001794630482, 15.63127467709203, 0.46485446093063204, 2.645477128605689, 32.765509428516516, 59.82842606882895, 55.148552079354566, 54.03277112591652, 63.22928574777419, 49.53242009685886, 43.20087917389409, 54.35619800321518, 15.117796217241596, 3.9737277261672483, 4.268065325675472, 25.318171862633, 49.0570798227864, 47.069128482572495, 51.35407863124725, 58.037224738828606, 56.0937060079267, 56.86536958140712, 57.02232714622252, 57.311429362143244, 54.34292470255206, 61.1654326223558, 61.56336099870744, 45.51963929207095, 24.75991660548795, 5.537292832328427, 2.45981173649911, 8.523198596892819, 22.635627600454516, 22.613530928088775, 20.23451732050988, 13.786292749066508, 9.114437064816876, 15.213830547948039, 14.673728019960466, 18.54691755387091, 16.141630930285302, 11.092613858561363, 5.049891760272365, 1.435456819111301, 0.9606139506063155, 0.1615694754066006, 0.0240541955516223, 0.0392596963642826, 0.08810705970972778, 0.3740731951209807, 0.5379810160206211, 0.44899723762946747, 0.42844361956081084, 0.9792968738944301, 0.9721973838825381, 2.8605759864853275, 2.2751641994522465, 1.175558732882623, 5.224156293176836, 2.3122195659145235, 1.2814024210937562, 0.8416665429549833, 1.4861359254967783, 1.2547204979965765, 1.8216565732033023, 2.841585586147924, 3.3895867870699976, 3.971357388842491, 1.5752645557926548, 1.0913606444674155, 1.138384101852294, 0.1250162565960519, 0.8748034003280825, 0.36675705544410214, 0.8761564341764297, 0.3259452840974254, 3.0751767033530824, 4.47783270189839, 10.72307461692441, 19.097212360751247, 22.044651931332005, 23.677295369486657, 13.05043355111153, 10.115552429229984, 4.852832863407751, 0.6819231760117316, 4.940271810177834, 9.927089406598, 19.723218717882713, 11.84569618394298, 14.736601652637606, 38.78449040074503, 48.54777574539185, 42.955550609096406, 50.906187103640654, 53.50322761843282, 53.193305461637436, 53.071021649145315, 55.12369209720243, 56.6732205114057, 59.64116034969207, 59.49652294958792, 56.79907368075464, 57.27199777480095, 54.46776197802637, 54.73669536652104, 20.51339195620629, 4.608142174059346, 5.620931002401537, 25.333031762030817, 53.81390679267145, 50.828704603256725, 49.97462026534542, 48.36226724809217, 55.5613148596979, 51.89648359052597, 49.60990651961296, 38.53161127336564, 4.946358348092725, 0.47422083575398694, 27.218673959855114, 60.099869774233916, 44.685861064541726, 49.19272322808543, 32.2842542202242, 13.207985355008034, 12.809895180886793, 2.2796788475205823, 20.702883620415967, 28.660880442588564, 26.39525471195098, 37.14320598110076, 28.09894404103679, 27.694804591517297, 44.48025826484927, 51.483046162513, 38.08227239116546, 0.6049765694525935, 0.05781750600304335, 0.03470193286756835, 0.023100262868308255, 0.073659208362862, 0.052049246977173516, 0.013757777539262129, 0.08910252201941707, 0.008349111566560404, 0.08713770567649796, 0.038554175351295746, 0.016973342543708223, 0.02759557296221535, 0.06294874759811549, 0.03940190526566679, 0.1608982751326215, 0.03655311538867893, 0.139933574283796, 0.05415447574529437, 0.06645681742098063, 0.062033337646073876, 0.04453631463430582, 0.03937893794969686, 0.25022673180266736, 0.8066975709892089, 22.259476223299583, 90.55982374375867, 31.7995963558074, 46.027143001556404, 60.17805830124886, 26.674188183199977, 43.76530824169036, 19.08560214504119, 25.80936831812705, 21.552837702535815, 19.18979794748368, 25.896593986019013, 42.06136395854335, 65.49720802614766, 88.25063028643208, 24.308169388001968, 2.6570870991676085, 2.838750938254018, 35.250270135941044, 62.89016546741609, 61.84721900570778, 62.07534797729985, 64.238440990448, 55.73311075087517, 49.36023589103453, 60.623164946033114, 22.198046022845855, 6.101568927687984, 5.3649350616239735, 21.991350843060403, 47.27984997533983, 50.109341913653964, 55.491853606316354, 64.2503846076227, 61.364155584766024, 60.66924495081748, 61.61632084077405, 56.7452666067308, 54.8423404847422, 62.516563630873165, 62.1892692965846, 47.718516088301136, 26.686837827005697, 5.851654621862597, 5.162429953775098, 16.831580746558405, 28.63451230910517, 24.080746443040912, 23.53901613143183, 18.79719222745588, 12.8444649904005, 16.966292588941513, 20.73024215236787, 25.316173415030203, 23.373847084660685, 16.662707021159513, 8.303055570971582, 2.2425626843206348, 1.119042404236332, 0.22615041163179184, 0.040414949293218316, 0.11279848719676656, 0.15810547096114005, 0.4814469141344871, 0.596806394957727, 0.5339685539084097, 0.2011225949372015, 0.5043732903657422, 0.9409633050522498, 2.035046748576626, 2.608527175841793, 2.24756297084593, 3.91128285757957, 3.498381813687663, 1.219865458626901, 1.3930183673097243, 1.6016227607765507, 2.8448428694278967, 4.145276998319934, 1.6608306933795254, 1.1408016301931874, 2.9291453909489418, 2.166297099282665, 0.9696642681956292, 1.2233884824860481, 0.3715513868918342, 0.17066653968105394, 0.299133095409601, 0.15653509796867449, 0.2460301021534589, 2.911106655674596, 11.312704913077816, 18.72734658179745, 25.961152276685162, 28.767688543565814, 27.477379768125473, 16.101045185519805, 12.953678484885925, 4.387602988750705, 8.065408968156385, 10.490281947197454, 17.42354485296434, 27.389181352430775, 18.744793284323908, 18.119791053956558, 38.03666699317194, 52.962713241577156, 47.05259176992601, 52.415017004935976, 55.854225697055945, 55.60395102347098, 56.74853001871417, 58.00699503191056, 59.818380878817656, 62.48526703926825, 63.98079226093908, 60.37484753516413, 57.94784176734186, 57.10277103608655, 50.76942582284251, 16.856534865594682, 4.075423262773022, 9.74544640510313, 32.239054787543516, 57.035718117990804, 54.986389529320505, 53.733015752607784, 52.244507651175226, 61.7605620814908, 55.803062300528254, 55.300092850961995, 34.30940728033743, 2.469855945917868, 1.7259507409987913, 38.63629541089458, 62.761645086349986, 53.50460044799313, 55.60453545662665, 31.08723705814731, 14.114257808654541, 6.346269913258092, 6.5599856453557175, 18.77036125429215, 31.592161809244466, 32.76864732465437, 31.39290148212064, 35.877872897732644, 22.584725041543287, 44.33782523678195, 61.88705851954799, 47.68117904663087, 0.6192159376317455, 0.06894341624912716, 0.031403995216673905, 0.07454161141668597, 0.12991487559291626, 0.05712493953685607, 0.026827378296143106, 0.06016694827966633, 0.02793406699633887, 0.05556054203019989, 0.20304547562714548, 0.14950550581899383, 0.12323782178423098, 0.14924485206363663, 0.19663851377704453, 0.3832154739047251, 0.34572772741798435, 0.28259570860574323, 0.2592575754369459, 0.25053379516447744, 0.13592454424548533, 0.2981616346345794, 0.37846591263528795, 0.8897913283398076, 1.571667864918709, 41.98494049810594, 96.47886076281148, 54.89081705770185, 54.510001982412035, 66.27339409243676, 38.633761559763265, 45.9808825677441, 33.04320343079106, 22.175033477044877, 31.847419854133364, 33.25055952995054, 25.191895077305457, 33.689751240514944, 64.57096384417626, 92.09339987847113, 22.30764489020071, 2.835234533394537, 7.012542832282282, 41.51893154267342, 71.12109061210387, 66.20086946795064, 65.81650857002505, 72.88050897659795, 61.43449152669599, 54.33579383357879, 65.25134209663638, 21.59975317216689, 7.066884819538363, 8.257412910461426, 31.075942593236125, 55.99060650794737, 55.83518258986935, 58.183737031875125, 63.321218259872936, 61.3295602798462, 60.9284390941743, 63.144880264036125, 57.80598925006006, 54.98480489177089, 67.98621469928374, 70.27203867512365, 55.76692942650088, 37.02244012586532, 10.942508674437, 7.336669852656703, 21.64134402428904, 37.815649278702274, 29.771836880714666, 27.129673419460175, 22.627445536275065, 15.5796209842928, 20.772227202692342, 24.63850355917408, 33.416248290769516, 31.055610987447928, 22.407932050766487, 14.279223872769265, 6.363534715867813, 2.1405827758773683, 0.5211616475735942, 0.10449157366829534, 0.11657835735428719, 0.3533900775496037, 1.015909257675371, 1.1688617761096647, 1.6218364503114455, 0.9015811150593143, 2.168024658195434, 4.037388529508345, 5.331254159250568, 4.173336653940139, 2.8301445226515494, 8.482616774497494, 6.388137782773664, 3.4551082647615865, 5.113333156031947, 3.0531633813535017, 3.354426170549085, 7.4775677630978254, 5.2808727852759825, 7.8897510132481985, 9.127987873169685, 4.13676937741618, 3.228836535446106, 3.512938464841535, 2.5849723623644922, 1.6719710826873782, 0.5196726790839626, 3.4352779869110357, 0.42589119845821016, 5.422852779588392, 23.457762272127216, 26.159857588429606, 33.85344351491621, 38.3649536871141, 34.9457137815414, 21.786002997429144, 17.042196335331088, 10.008015747993223, 6.184178946479675, 11.633263557187973, 19.006464404444543, 30.43560781786519, 21.655845026816092, 19.909382251001176, 44.01222144403766, 54.775318945607836, 48.28521620842719, 57.746965423707046, 59.962916297297326, 57.95813014430385, 58.16135991004206, 60.60475726281444, 61.390486455732784, 63.4952812810098, 66.72911859327748, 61.906289900502856, 61.37892723083497, 56.849625187535445, 58.320145299357755, 24.578765861449707, 5.8690625909836065, 8.5015873178359, 29.984866688328406, 62.65460360434748, 60.32253096180578, 59.16493754233084, 59.748727429297666, 65.03938897963494, 61.46664319499847, 59.787492213710664, 47.452751974905695, 7.599819216036028, 1.602735243016674, 33.53584920206378, 70.44027697655463, 58.87103826768937, 56.093780532959975, 41.940794221816525, 20.524396165724724, 22.283487012309415, 8.827788291438933, 29.535227744810044, 45.940588058963904, 39.341623860020796, 50.40031117777671, 43.44966334681357, 35.539203689944365, 59.833787948854514, 69.27246970515098, 61.56493779151671, 2.164740408620527, 0.20276605271764342, 0.1432191568516916, 0.2271342523876698, 0.19171975432865082, 0.21835283165977848, 0.10087808248616996, 0.277007281059219, 0.23540052495175795, 0.25118294742799574], [0.07351103163654767, 0.0354706829473857, 0.05199493900422127, 0.007166450884523652, 0.06475638568160996, 0.05791666842396221, 0.0686792231675598, 0.07781358060216712, 0.03021017167597048, 0.11999450428711793, 0.020976307080878366, 0.08372321349358366, 0.16317625289722798, 0.16119473583755956, 0.11730378133154686, 12.699387304244503, 67.19214654737904, 50.35858108151344, 49.09859418869019, 45.2485054539096, 45.67078390429097, 28.59747336756799, 36.63131706176266, 3.968527889059436, 18.9122510340906, 34.44751393410468, 23.41366698665004, 30.367750813884122, 47.257551300910215, 65.91051993831512, 80.0148610145815, 20.911004581759055, 1.3439967074701864, 14.618083315510905, 56.14891336810205, 61.61883115768433, 42.89536968354256, 53.11214377803188, 69.0486357288976, 47.105853634495894, 55.77739431012062, 35.73127823491251, 13.70390630537464, 7.560496474466017, 3.029297474891909, 8.001230657100677, 20.38906066648422, 26.066122747236683, 32.59416460990906, 35.69810675036523, 42.48030054953791, 44.300488195111676, 43.189257191073516, 32.540492857656176, 21.891732446609005, 11.777381243244296, 2.7380200595624986, 0.6731869544713729, 0.7050709210095868, 8.152928813811272, 20.551450713988274, 20.177450756872854, 12.425006724173024, 11.648977552690814, 2.7094198523029207, 8.094181024259138, 10.316264033317566, 11.67323152865133, 12.054733018721304, 10.315830611413526, 9.360986467330687, 4.271535642685429, 0.7718924805521966, 0.546125020951994, 0.08322183959065907, 0.09546103646918651, 0.4037827896254678, 1.1011465903251403, 2.1763704813295797, 2.1419529088081855, 3.218854348505697, 2.86997668204769, 3.0741169279621494, 1.9726466195237253, 2.3455023477154398, 6.042867716281645, 3.097970331868818, 4.801987178864018, 4.601841866970062, 4.209785769062658, 3.23117868073525, 1.4875284894820184, 4.532252646261647, 5.529057325855379, 7.531961231462418, 8.86895944995265, 6.8898020636650825, 1.995561718940735, 1.2979213605003974, 0.7238626287829492, 0.17348395059666327, 0.1379284617160597, 0.3438848569508522, 0.1902917817595505, 0.029853873758486686, 0.6500338775015647, 3.1368400396839267, 6.294272522772513, 17.780941417140347, 22.823152196022775, 19.817851781845093, 21.977857889667636, 7.975796047718295, 6.914581146932418, 5.079267861381655, 1.0373933661368586, 3.975278533274128, 14.127994929590534, 27.992936103574692, 16.17200674549226, 13.018026928747854, 35.29687573832851, 53.31680520888298, 46.68816435721613, 43.99340191195088, 50.99318135169245, 54.662237013539965, 55.563589834397845, 52.2747883489055, 53.41921829408216, 54.412911553536695, 60.76431928142425, 59.87172119079098, 54.45950931118381, 15.58614976944462, 4.21244562633576, 4.211863154365171, 20.21021039255204, 42.56718104885471, 49.48406903974472, 53.966243805423865, 52.12895854826897, 35.910958090136134, 46.65413387360112, 52.180808359576815, 52.21028889379194, 28.89977239793347, 0.6323056223411715, 12.582948803901674, 56.8552420216222, 56.25233058006533, 41.085164470057336, 44.70431973857265, 20.20122032011709, 15.929077690647496, 7.099800859728168, 5.040805589768195, 24.387260060156546, 25.082335433652325, 27.508703816321592, 36.832067889551965, 25.006941595385154, 37.31308383326377, 42.53037352715769, 61.92622730808874, 29.14685622338326, 0.1837711631050033, 0.060763389863554514, 0.08033899710543695, 0.009648234850066084, 0.15940543023809312, 0.0681444171876196, 0.05653509396999594, 0.02907975340232013, 0.06417505901246782, 0.04780580935579154, 0.11866469056375566, 0.02071749193653945, 0.05016590408500164, 0.06379172776735599, 0.04893613378367117, 0.08980269573869244, 0.12312761237544399, 0.07566393788663611, 0.08652166373306706, 0.08228592529532411, 0.023803391771751548, 0.08737474860202882, 0.09475858746877602, 0.04106910028044255, 0.08349697240778516, 19.863388538360596, 80.7595935944588, 55.334998023125436, 37.20977644766531, 58.86761403852894, 31.7127727308581, 39.91587846509872, 35.75084693970219, 13.683530572922, 23.956560281015214, 17.07986285609584, 25.815410729377504, 33.37156072739632, 54.45940340718916, 70.74163267689367, 78.83481594824022, 28.05975760183027, 2.4490999887066507, 13.471559805254783, 56.690682903412856, 66.79972125637916, 47.66153189443773, 60.221549541719504, 69.35677712963474, 50.433918045413115, 59.78011815778671, 41.573762355312226, 21.397086266548406, 11.573985757366305, 5.0265330653036795, 9.161943831751424, 17.106680100963963, 21.931430755123017, 28.627010776150613, 31.244180894667107, 40.13586851858324, 39.57204741816367, 42.81256060446463, 34.53732444394019, 24.479251407807876, 11.82776604929278, 3.750088397533663, 0.7645427555807176, 1.384110174352123, 12.49545249246782, 22.513255534633515, 21.675337245387418, 17.411461991648522, 12.38704308386772, 6.987406323032995, 8.804157972335815, 13.63601988361728, 21.17992228077304, 17.186398352346114, 18.95681896517354, 14.645927240771634, 8.74036846622344, 2.37763048179688, 0.7791089675118847, 0.21504538494252393, 0.12896921665918443, 0.17129307702904747, 0.1972124362063985, 0.5673912540078163, 0.670509078810292, 1.287251165316951, 1.1496895984295876, 2.069821011635565, 2.5239439597052913, 2.854401440389695, 5.319405659552544, 3.0539081413899702, 5.21681999006579, 5.0511400545797045, 4.123087169662599, 2.977783271381932, 3.273247326574018, 4.362251729734482, 4.246301074181834, 3.1781651512269056, 5.948827910807825, 4.679197380619665, 2.108382813392147, 0.5701830009779623, 1.4783121453177546, 0.39378224721839356, 0.7109427704445778, 1.0556447674189846, 0.7413540708441889, 0.42548216879367834, 0.419273087454419, 9.317906095135598, 13.948231724000747, 24.843370914459232, 26.315391332872455, 22.975636297656646, 22.5674803410807, 13.497803403485207, 7.508185294366653, 6.8956145259641834, 5.763008075375711, 7.738120517423076, 16.675335091929284, 36.57752175484934, 24.207042840219316, 19.385987058762584, 38.61980968906034, 55.00278895901096, 53.30456741394536, 48.670804808216715, 54.49850943780715, 55.5172078071102, 57.43585871111963, 52.45806109520697, 54.38348593250398, 56.47657640518681, 61.47234632122902, 60.96729017073109, 50.63642217266945, 12.434682230795584, 5.738834508003728, 8.075406599429346, 23.381668290784283, 48.3569485141385, 54.06624855533723, 58.340019949020885, 55.591819132528, 43.5619294258856, 50.41487493822652, 57.23112275523525, 56.68629377119003, 29.425462176722867, 0.8351915678189648, 16.54824833716116, 61.29200750781644, 58.708240293687396, 43.031566143035896, 41.374925644167014, 22.353981810231364, 8.80034738971341, 2.9341547479552608, 7.843054706050505, 21.323202540797574, 34.84719953229351, 26.980011463165287, 31.696751809889275, 31.92224887109572, 29.50931460626664, 53.36998862604941, 69.36317843775596, 31.21548875685661, 0.2634930304221569, 0.1053172019460509, 0.11081859424349763, 0.05271648657658408, 0.1766573932142027, 0.08376272064783881, 0.05713919643312693, 0.060672539496614095, 0.04549257622490968, 0.10414796791249707, 0.31324823477095176, 0.11323118897815866, 0.12977963043076376, 0.1667961562352796, 0.17146431300188267, 0.2424047749129034, 0.23552669963288694, 0.24409061267731652, 0.3341151521571221, 0.3059311757885641, 0.29787018414466615, 0.17880807780931074, 0.39489577133809367, 0.282753522718145, 0.31985007406723115, 32.492332035495394, 92.64423401125016, 68.4897921162267, 61.52987572454638, 63.16111495417934, 60.96777262226228, 38.87978046171127, 57.8899162046371, 10.195305981943685, 29.001550059164728, 44.95564168499362, 32.795917603277395, 37.17387107110793, 56.13650298887684, 75.5472578540925, 89.18538601167741, 27.885508268110215, 4.135833401833811, 19.93973747376473, 67.9674893040811, 71.76108021889964, 54.98046675036031, 63.87322910370366, 81.78757621395974, 58.36175772451586, 64.84198785597279, 43.44209317238101, 21.320921682542373, 13.78324898981279, 7.07938100061109, 11.813035588110647, 28.724069826064575, 32.68241597760108, 39.117703591623616, 43.993739235785704, 50.24910380763393, 51.2784121882531, 52.46799253648328, 42.311544495244185, 31.175649243016398, 17.460999565739787, 6.229852495654938, 1.1814264760863398, 1.446382090930016, 17.679304961235292, 32.86819707962775, 26.648837904776297, 22.836296058470204, 15.120417341109246, 7.501483924927251, 12.809885374961361, 18.029292168155795, 25.856185728503814, 25.762843124328125, 27.27753304666089, 22.654182372554658, 15.93573493342246, 4.146026661319118, 1.903508839107329, 0.37978349193449945, 0.13334062160743823, 0.8393201688604971, 1.3778704188523756, 3.664238991275911, 3.316903796888167, 5.41597931615768, 6.333458471682764, 5.257542037194775, 4.063316131791761, 5.173813162311431, 10.919785403436231, 6.116371462422033, 6.6201273472078395, 8.375634128047574, 10.139935843406185, 8.114964192913424, 6.18072529954295, 7.706376285322252, 9.83203076547192, 9.451948192811782, 13.711259768855188, 9.343246567633845, 3.4796042019321076, 3.281269799317083, 2.2349174945585193, 0.4612146239847907, 0.7373168487702647, 1.0199571436932011, 0.8046120957982156, 0.49522601668873145, 2.6274403545164295, 17.086071968078613, 23.04431307700373, 32.01357929937301, 37.09683572092364, 29.166774019118282, 32.763677681646044, 17.02670689552061, 14.831118026087362, 9.098543620878651, 4.341496017671401, 7.969847283055706, 19.377956005834765, 35.56318113880773, 23.515836884898526, 15.898434173676277, 40.42949714968282, 59.5485100438518, 53.036202769125666, 52.58167066881734, 57.99239204775903, 58.67630827811457, 58.49363565444947, 55.13839314060827, 59.47889189566336, 56.748541785824685, 62.00123871526411, 62.116254375826934, 60.782228823631044, 19.394824158760812, 6.466499384372465, 7.149794409351965, 23.870205379301503, 50.306076234386815, 58.358992453544374, 63.56873550722676, 59.84876748054259, 47.0753336721851, 55.93545798332461, 62.642463868664166, 62.82352439818844, 33.999034050972234, 1.7816569776304307, 16.262312454562036, 65.08383727842762, 68.0645836553266, 53.31101971287882, 51.1741320548519, 31.46452984502239, 26.103928512142552, 16.042987242821727, 9.003036848960384, 36.4156690720589, 47.5877756457175, 37.6455400066991, 53.033174699352635, 37.96286367600964, 50.8160981055229, 60.57712024258029, 76.21882254077543, 47.54737915531282, 0.20808176828488228, 0.19388815087656822, 0.13817468237492347, 0.13233260311666997, 0.4675138279074623, 0.23967642937937092, 0.1612836020367761, 0.18826773149832604, 0.1760892624095563, 0.22293100373879557], [0.053039913576456814, 0.2063336016069497, 0.06273182214147623, 0.137555499471003, 0.026649812521833568, 0.032154349610209465, 0.10378744693533068, 0.042179058260855176, 0.09040864064328133, 0.09969874375289488, 0.2045913338060341, 0.016715201556742672, 0.0923544273621613, 0.12816504650418797, 0.26649330652529196, 4.06577913511184, 62.14141638048234, 57.97025811287665, 43.501913239878995, 40.93782847927463, 57.35262601606308, 25.00893023706252, 32.167257762724354, 18.084187699902444, 12.538064141427318, 32.18479075739461, 31.25278461364008, 26.825295532903365, 53.88520371529364, 32.558288651127974, 55.93597181381718, 52.386579821186686, 5.081350639943154, 1.852136576367963, 32.3398224384554, 69.43979801670199, 65.1577151206232, 57.68928697032314, 63.910048392511186, 49.34389137452649, 43.83134918828165, 50.39349017604705, 23.17964465387406, 11.40728404445033, 9.319005339376389, 3.3130785053776157, 0.4499770947281392, 1.5716602653265002, 7.336403131484986, 4.730559347137328, 7.122894794710222, 4.417614513827909, 2.2888608709458382, 1.064735718311802, 0.9851021043235256, 0.42025545732148234, 7.05234214182823, 4.151023270622376, 1.7033786038237235, 17.277346349531605, 17.477355849358347, 9.169315926490292, 5.131604536887139, 1.7589872714973267, 1.9771694800546094, 5.112705086508106, 8.987097317172635, 8.301110075366113, 5.578971447483187, 2.5407574445970598, 0.758306309580803, 1.1624783638023561, 1.0704444829494724, 0.16593985379703585, 0.20203713537944903, 0.35568012885989686, 0.08107300892832779, 0.24151332436069367, 0.8009451699833717, 4.165739513212635, 4.751963721167657, 3.5464884581104403, 6.898915690760459, 9.172521483513618, 7.086344678555766, 12.870447751014465, 7.222718625299393, 10.081645500275398, 5.058864182041538, 4.831293657902749, 3.4081035612090944, 4.432260153755065, 7.704719083924448, 9.525954492630499, 11.253246684228221, 11.09449855742916, 7.162727934698905, 2.6926674092969587, 1.5088332107951565, 0.19534007135418155, 0.3787817553647103, 0.16222982787557189, 0.1817812190781678, 0.4523254300077116, 0.43872822737020833, 0.9133590120942363, 3.419181315168258, 2.529642918417531, 10.973437543838255, 19.839342448019213, 15.300812048296775, 19.278825944469823, 22.284232262642156, 2.6041784930613736, 8.118697799021199, 4.919368518937019, 17.17203659396018, 35.63712173892606, 9.401697727941698, 20.332074511435724, 22.276636592803463, 14.640078006252168, 23.513446200278498, 42.500273258455344, 48.99513775302518, 50.99688406913511, 47.648591995239265, 56.30544731693884, 61.456131242936664, 59.04838823503064, 58.3091587405051, 44.42400363183791, 22.971827676219327, 3.3001599340669574, 0.1669050632945953, 15.271976743974994, 22.699042520215436, 49.28944887653474, 54.12198543548585, 50.99956697033298, 49.648608546103205, 51.29188945216518, 57.779132781490205, 48.167623550661155, 54.98700534143756, 52.274600075137236, 22.212180283761796, 0.9196094315378898, 21.45126792692369, 69.17003308573078, 41.67669319337414, 55.63812271241219, 58.651122739238126, 12.129714027527841, 15.824468078151828, 8.120276553015556, 9.283248032293013, 26.286085344129994, 23.267578309582127, 27.132705411603375, 34.30372376595774, 26.29744060577885, 42.113598162128085, 43.52711446823613, 62.26504948831374, 6.096990050808077, 0.47015300080660855, 0.2527548372745514, 0.019847445880934116, 0.07844757198566392, 0.015424048460479227, 0.019191981052919742, 0.030099529427506273, 0.027247073819800734, 0.07576559009330888, 0.09913802101847627, 0.06891304852380868, 0.18189386464655402, 0.042682910458214825, 0.11228264189295231, 0.11280230997550873, 0.022262924936630075, 0.03604217304758007, 0.0169513251767644, 0.1032742829392514, 0.07992682648041556, 0.0959590089417273, 0.07731646614810152, 0.22942018214493032, 0.07294666998448872, 0.36377090600229084, 5.7362280930242235, 70.10257659419891, 74.80682419192406, 35.179683162320046, 47.311303461751635, 43.21636469133439, 26.527077728702178, 40.58354039346018, 19.469445290104037, 25.757089007285337, 24.47046529862189, 23.787641448359338, 29.095102510144635, 56.782858602462284, 41.008164421204604, 55.77105183755198, 53.27056830929172, 8.387421831007927, 1.477177844893548, 35.70088378844723, 73.43375928940313, 68.76078867143201, 61.768728456189564, 68.2276758070915, 57.355497191029215, 47.676425133982015, 53.9587010875825, 29.562225418706095, 15.505744122689771, 15.668850983342818, 7.2477531529242, 3.2370649326232175, 4.375941782228408, 12.113917662251382, 6.8266724963342, 10.524662502350347, 8.8413381191992, 6.345456021447336, 4.3302608786090735, 3.515738791996433, 2.8697038321725787, 14.60395101578005, 9.317786462845342, 4.173264090091952, 19.636465695596513, 21.748269796371464, 15.586981311921152, 8.913641129770587, 6.884458814897846, 3.7998211095410013, 6.500156752524838, 14.35599152118929, 14.978779573594371, 9.252715322279162, 9.280014038085938, 6.993540419686226, 8.262250173476435, 3.7010550931576764, 0.5281868577003479, 0.38185159225137005, 0.23538961585971618, 0.24356731333799903, 0.30553915327595127, 1.667975168074331, 3.754240961805467, 5.459392109224874, 5.986474819721715, 6.109606354467331, 4.465903303315563, 4.472518870907446, 9.312611875995513, 5.258238257900362, 8.131730854511261, 6.281289477502146, 6.3286290534081004, 5.6583410982162725, 4.76657945302225, 5.843276439174529, 10.334095128120916, 10.76156287424026, 10.237122370350747, 8.342161601589572, 3.6610792769539744, 2.2417000080308607, 0.8002682546934774, 0.34799056728520705, 0.23096515166182674, 0.33046676567004574, 0.9591775663918065, 1.6791732897681577, 0.17377273510060004, 5.127513504797413, 10.521353002517454, 20.631890681482133, 23.542805141018285, 17.328315588735766, 21.692809443319998, 24.180458976376443, 4.343254220101142, 8.934383603834338, 8.456728150767665, 22.16969709242544, 31.749189976722967, 13.946839282589576, 32.071622533182946, 31.872950561584968, 22.518770387095792, 27.637671347587343, 40.05660918451125, 54.167665358512636, 54.58586846628497, 49.70183903171171, 57.61724871973838, 64.11816150911393, 59.613892032254135, 55.41838761298887, 40.91260371669647, 18.12299955275751, 2.5385444923754665, 0.4969549239162476, 21.44782800828257, 28.489472866058353, 54.72392805161015, 56.99809474329795, 57.48763791976437, 54.49211597442628, 53.84760387482182, 60.662529853082475, 53.296683449899, 59.0249873745826, 54.42464728509226, 25.36343797560661, 2.217066787904309, 28.581695633549845, 76.63082045893516, 50.636269200232725, 60.209460796848425, 61.67042993730115, 14.195483230775404, 9.756519256099578, 11.124940072336505, 10.030424248787666, 28.206820987886, 32.493553853804066, 23.382444920078402, 38.84609906904159, 27.18150361891716, 40.39782401054136, 54.71604800993397, 69.64569891652754, 7.466027169458329, 0.5921371197027545, 0.3317989006398186, 0.11680479762294602, 0.039424397607123664, 0.140073569191079, 0.039651435424363425, 0.0035252771152543927, 0.039646172400323615, 0.12639017400121497, 0.106392452313054, 0.2967533811686501, 0.23549081607451364, 0.31715874590219995, 0.2585949093824433, 0.2821875982467206, 0.1729347421637466, 0.19379914678152532, 0.11854760168540864, 0.2786759124888528, 0.2578011810058548, 0.27603698473784233, 0.16284069106463464, 0.45619576748821045, 0.26291405181250266, 0.6248628023651339, 9.118851692445817, 86.8184317311933, 80.47234273725941, 59.56841999484647, 53.375295592892556, 77.2440359669347, 30.109288192564446, 52.52283119386243, 27.648781461100427, 23.013695055438628, 40.428681296686975, 43.41518571299892, 32.643706106370495, 64.51625070264264, 44.30676790975755, 68.88764596754505, 59.11897520865164, 10.093597942782987, 3.9415199189416827, 40.932415608436834, 78.6489740494759, 75.97078754055885, 67.11668014526367, 72.23085464969759, 62.40796104554207, 55.720335591223936, 58.659853935241706, 29.620590286870158, 13.520652190331491, 14.084947897541909, 5.588687648696284, 1.8833711454945228, 3.4026585759655124, 11.899316945383626, 7.933256472310713, 12.469575635848507, 8.06061141913937, 6.420409083366395, 3.424855513918785, 3.671702035973149, 2.082117887273912, 13.30638389433584, 8.817127289310578, 3.7488834944463547, 26.6367099362035, 29.45483680694334, 19.644063326620287, 9.552725649649098, 7.449795911389013, 8.788077235221863, 11.396167066789443, 19.95006899679861, 22.06176131002365, 15.962281534748694, 18.124803843036776, 14.785397898766304, 12.948528412849674, 6.875070621890407, 0.7291510256548083, 1.2677032981188068, 0.587235750450242, 0.4663909881586029, 0.39329522980316994, 2.9237678214426968, 7.061370457372359, 8.49362196460847, 8.618112110322523, 11.56824536861912, 15.908290109326764, 13.52412642971162, 17.60841400392594, 16.052521544118083, 16.65311290371803, 11.442890340282071, 9.868557837701614, 11.081651814522283, 11.295643583420786, 14.351307230611003, 17.906547477168424, 15.996641497458182, 15.271067734687561, 11.946929616312827, 6.291764167047316, 2.8640975394556603, 0.756199322640896, 0.7012918399226281, 0.48668012203228095, 1.033321455601723, 3.040122481123094, 1.6286803733917976, 1.5007255490749114, 10.005406391236091, 18.549233713457664, 24.73023799157912, 32.177732452269524, 25.196041022577596, 29.574998617172245, 30.482301673581524, 8.424118545747573, 14.417605092448575, 7.507087030718404, 22.718185647841423, 45.175102218504875, 14.865872186999168, 28.239302135282948, 28.359385498108406, 17.89033043769098, 28.919286189540742, 48.13639363934917, 56.62108436707528, 55.054313213594504, 51.025650731978885, 58.6205517861151, 63.61574903611214, 58.675657164665964, 58.87858883027108, 49.41558053416591, 28.869607410123272, 4.770236082615392, 1.3835783254715706, 22.179051945286414, 28.604070794197824, 55.60302142174014, 61.38632874335013, 61.834565439531886, 59.7177367825662, 58.11689199939851, 64.87638312001383, 56.01787482538531, 63.54356565783101, 61.461999108714444, 30.308854464561712, 2.762745700536236, 29.513501736425585, 79.5005206138857, 55.74611733036657, 65.73927710133215, 65.1842656443196, 22.406337607291437, 24.039555672676336, 18.478030927719608, 13.387043514559346, 45.388471311138524, 38.509912721572384, 39.120166840091834, 52.1575173254936, 37.368746188379106, 59.41616535186768, 60.48203022249284, 86.31849427377024, 16.488685184909453, 0.8248586964703376, 0.48808702718346353, 0.25709582853221125, 0.22069215774536136, 0.2221821681145699, 0.05170230107802538, 0.1360863420150934, 0.25819495019893496, 0.23468175061768104, 0.27391682108563764], [0.05289492760634711, 0.20279367784819297, 0.04071061709715475, 0.22630660163779415, 0.1108974629953023, 0.03924578420757767, 0.029291285599972454, 0.08451108129755144, 0.03333248558544344, 0.1477996578379985, 0.13991658245363545, 0.12342000515350413, 0.09471987704596213, 0.11145166632148529, 0.23057194937381054, 0.14137547433135972, 34.483615429170676, 69.5210224582303, 49.61538999311386, 41.25674463087513, 58.60624690209666, 40.11493482897359, 24.63288868627241, 33.009431823607414, 5.946713753284947, 26.73211374590474, 40.390367584843794, 21.550345036291308, 21.71922072287529, 26.42156008751162, 45.05236733344294, 79.32923855320101, 17.29315350132604, 1.4065902584022092, 14.440108710719695, 53.571116001375266, 58.174005631477606, 50.71475974975094, 60.39329051971436, 50.00526574350173, 40.83064579194592, 61.392981083162375, 62.44032844420403, 39.276732167889996, 9.544355311701375, 2.184856038901114, 0.24059896777954795, 0.8494393323217669, 20.1312413138728, 23.108926280852288, 15.859322259503028, 3.034627240511679, 2.8291161262219955, 1.4564796200683041, 4.302623368078663, 2.5183200163225976, 6.583235004255849, 7.1484539393455755, 8.915621926707606, 10.065326479173477, 6.325554405489276, 4.03475612882645, 0.6660435216561441, 2.7180069012026635, 4.26588595874848, 3.2650591336911727, 10.389574112430697, 6.851953642983591, 3.332832051861671, 3.7096776885371057, 3.2959710878710595, 0.4216787261107276, 0.9524595881662062, 0.5799795494925591, 0.2852717456558059, 0.07455993623983476, 0.3890904489784472, 2.569655751989734, 4.997933103192238, 12.192731807308814, 11.584645778902116, 8.940237741316519, 4.6166542076295425, 10.091038596245552, 14.026129995622943, 13.406666151938902, 5.9999344329680175, 9.211983469224746, 4.28457114965685, 7.031111332678027, 7.032643018230316, 9.266995691484022, 15.22462098829208, 13.083143176571017, 13.865256924783031, 8.543786137334763, 6.665582714542267, 4.79655763795299, 1.3536130108179585, 0.505372177088453, 0.4619661868820268, 0.3980566807571919, 0.22602583041354535, 0.5656510086790209, 0.8390099338946805, 0.36616015037701977, 2.688024058457344, 1.999630074827902, 4.070244998701157, 13.064437393219242, 13.686627284173044, 15.275232311218018, 23.82730837791197, 10.101648607561666, 7.518255979784074, 12.465657188046364, 16.72695348339696, 25.065149568742324, 6.506109439557599, 7.256483858631504, 17.02276295231235, 30.0789741546877, 14.725633725043267, 12.982407885213053, 17.257975724435624, 37.84285876058763, 45.75215347351567, 41.167922558323035, 42.24751964692147, 32.408210923594815, 21.03290400197429, 7.096131972728237, 3.6618985620237168, 4.779647319547592, 4.8568528025381035, 24.16950183530008, 30.081462898562034, 53.42051659860919, 53.95411191448089, 57.66224615035519, 53.832640032614435, 56.76402730326499, 56.125481128692634, 59.72092959188647, 54.68075452312347, 50.4981311675041, 14.49555435488301, 3.4620726781506694, 41.26388334458874, 38.411084682710715, 19.424516500965243, 20.03238189604975, 12.640278166340245, 13.746056095246347, 10.623669989647405, 8.140315451929647, 12.280167322004996, 28.152786416392175, 18.83938712458457, 36.087492204481556, 26.94877370711296, 29.401920110948627, 30.919092893600467, 56.040102897151826, 39.30747962767078, 0.43542396757871876, 0.032155651959680745, 0.04866600352069063, 0.05397847087513055, 0.06783371490816917, 0.0391638740867136, 0.01136829759249644, 0.0508238357161322, 0.03289161347633889, 0.08151750846375382, 0.1004324644623745, 0.007590382874402548, 0.19732004091624292, 0.024532307194726124, 0.1149374506466331, 0.03233353757569867, 0.06819962148344325, 0.038978722126733874, 0.08173336139729909, 0.07784814648931065, 0.18822662322030914, 0.09256201420700358, 0.054408793953517755, 0.08571278979821552, 0.07191742319733867, 0.05478711115316518, 0.07007306651963342, 37.055937167136904, 83.57201145541283, 49.53331831962832, 36.43854041253367, 60.4774449717614, 26.401771729992284, 38.310958339322, 31.47608710873512, 19.848167780906923, 32.60281147495393, 21.6950196989121, 23.396824329130112, 31.61947523393939, 31.252255093666818, 53.51680686396938, 83.70294017176475, 26.82076715653943, 2.076685404585254, 14.939509784021686, 58.958244323730476, 64.87068783852362, 53.39762956865373, 62.5058751721536, 57.0192833869688, 49.12122626458445, 63.514653867290875, 64.54397401502057, 38.52145233461934, 11.348556357045329, 3.3309468626976018, 3.0733474079639684, 4.251264343338629, 28.50876896612106, 33.37719717333394, 21.70756736109334, 7.636501712183799, 5.440748593499584, 3.621431959252204, 5.778711284360578, 3.8672937212451814, 10.021701878116978, 13.09238624188208, 14.565321553137995, 15.573006887589733, 13.452655942209306, 15.021050956941421, 5.177652672413857, 4.064121933714036, 3.553706354671909, 3.6684310243975733, 13.73229249831169, 12.059752671949326, 4.134910173954503, 4.2853820996899765, 4.7243580798948965, 5.376193734907336, 4.117300202769618, 1.07757841627444, 0.2332788138019462, 0.023080760184975884, 0.6950450977010112, 2.18150437358887, 2.3266131935581087, 5.044814742380574, 8.424612764389284, 7.22257104612166, 8.266875628502138, 11.421069214420935, 11.074972018118828, 13.491141257747529, 7.619676215033378, 11.887049732669709, 6.876056607692473, 8.105752996860012, 6.60933445538244, 6.5180854162862225, 14.905587165586411, 16.963290014574607, 13.21568496765629, 12.023098122689033, 10.266021413187827, 4.829128019271359, 3.4400235645232664, 0.6876601326850154, 0.4582080966041934, 0.4406592898791837, 0.7856053931097832, 1.1905249039972983, 0.9581316418705449, 0.23887245074635555, 2.8910113726892783, 6.779976679432777, 12.538123957572445, 20.073704065815097, 14.444382133022433, 16.78610282559549, 23.687842622880016, 11.286428955293472, 7.377557619925469, 13.041129689062796, 20.33758151915766, 34.77112908517161, 9.497988973894428, 10.544795047852302, 27.2393899579202, 38.81449653256325, 27.378814528065345, 17.59869044826877, 19.07848500436352, 36.077329343365086, 45.99965895375898, 36.24365745052215, 37.86665578042307, 25.81344758310626, 17.658718401385894, 5.510915873512145, 8.760189183296697, 12.1616764414695, 7.691221717865237, 27.968554650583577, 35.0728456435665, 56.94491132613152, 56.74452135639807, 61.35130590008151, 58.29904687020087, 61.52298019778345, 59.49841353201098, 61.85281622794367, 60.385818404536096, 55.56137761762066, 13.939363245041141, 4.3178544217540376, 48.871033960773104, 41.97170642114455, 23.11220734350143, 25.990354322618057, 19.418634906891857, 11.689294615099508, 9.769670963287354, 13.898281320448845, 15.583280555663572, 35.67601203918457, 20.97716712182568, 30.98859533186882, 31.1248270926937, 23.736993843509307, 35.6158781820728, 64.71815862963277, 45.99655635895268, 0.49966114483052687, 0.009083033374120152, 0.06472877587281889, 0.022539074735475645, 0.03728839508708447, 0.08324096880612836, 0.039929111653398124, 0.03594628948297712, 0.07592447672880466, 0.026515343023704428, 0.16097626288331326, 0.22889053959759975, 0.34292583744372096, 0.3251358662401477, 0.32598239339647755, 0.2768843699126475, 0.3108049965193195, 0.1244262386594088, 0.18956303296069946, 0.19538073530120237, 0.39146584248350513, 0.39051742563324593, 0.20760143115635843, 0.19523212956565042, 0.3036999600308557, 0.32776504935276124, 0.46725700459172653, 52.921018446645434, 90.24447302664481, 67.4965303174911, 51.93515031568466, 80.05552030378773, 50.602803537922526, 38.73445664682696, 52.90343446116294, 13.78237920422708, 36.80275601725425, 51.05275823223976, 29.939731974755567, 26.994806643455263, 36.826254936956595, 58.23631640403502, 87.9392490079326, 22.707491305566606, 3.0737925969785262, 19.721037880066906, 62.77642457715927, 66.96226427631994, 61.82249630651167, 69.12888742262318, 64.29770408138153, 54.2799981178776, 69.38570853202575, 68.3442408038724, 41.24384003300821, 12.81388815372221, 4.183449014540642, 1.91697433590889, 2.3413284555558236, 29.66786269218691, 32.351652306895105, 23.796968844629106, 6.334290504455567, 5.053437582908138, 4.276601874059247, 6.866109967231751, 6.165516309199795, 12.453691017243171, 12.946550557690284, 17.01246084705476, 23.64387873680361, 16.30391997675742, 13.256761008693328, 5.430658296231301, 9.79819247799535, 11.327329470265298, 7.171491980552674, 19.171305933306297, 21.080256815879576, 7.797158562367963, 11.738984181034951, 7.010187939290078, 7.380635209621922, 6.36140339797543, 1.4462608651768778, 0.8946527384461895, 0.16216654901302632, 1.4202533446012007, 6.362190813787523, 9.281146622473194, 15.197182047751644, 18.678007087399884, 16.275914253727084, 11.31009751750577, 14.736613419748123, 19.562287792082756, 17.092524267012074, 11.594928272308843, 15.703795379207982, 9.823942838176604, 13.091250715717194, 15.099316950767273, 16.375673855504683, 24.824496469190045, 20.41162802327064, 21.21831444001967, 11.602146414018447, 12.75723736132345, 12.389843656170754, 7.244485328274389, 2.0150675432335947, 0.5925003679529314, 1.646024236275304, 3.9525719323465904, 3.3248068824891126, 1.9153449588244962, 1.6130290132376457, 7.223253048235371, 8.521560026753335, 15.5871303619877, 22.718399417015817, 24.696270265886863, 23.477982090365504, 35.66258576608474, 16.971805480218705, 13.73354765676683, 15.290604079923323, 20.502050422853042, 34.01850469650761, 12.848482478049494, 9.566606917688924, 23.43190404676622, 35.68376656501524, 20.280463964708392, 14.762930562419278, 23.133233208810132, 46.860725110577, 54.94125873811784, 43.07117423703594, 49.87569416722944, 35.53949786770728, 25.709514579465313, 10.822164473995086, 7.193830859276557, 7.757405830967811, 8.907886032135256, 28.925185434279907, 35.603561939731726, 59.81109703740766, 61.408796079697154, 65.84067821502686, 62.94004232652726, 65.58431210056429, 65.32394124615577, 67.25513196760609, 65.59012113078948, 58.66640429342947, 21.559613597008493, 4.817582522669147, 50.312367716143214, 47.60752085716494, 32.82292900546905, 27.161340675046368, 18.615861054389708, 23.16865613383632, 18.68787184838326, 19.06741411455216, 19.551042356798728, 48.008685188908736, 30.602039867831817, 51.414451752939534, 41.21202176617038, 38.845632306991085, 50.47165909121114, 69.67765054395123, 66.2096320429156, 1.3338062671884414, 0.22856020248465, 0.27265608551040776, 0.16169865315239276, 0.20927053756050526, 0.17262945612592084, 0.26174558386687313, 0.13343884940108947, 0.23697223093721176, 0.22142331206029464, 0.4007046483457089], [0.01130293497079683, 0.06434669718146324, 0.09583707072681959, 0.2672586896486821, 0.04914517619556958, 0.055969096720218665, 0.06513896233011639, 0.039901563131641, 0.061887604740238, 0.2288042780973258, 0.16058741197470697, 0.2133856094892948, 0.053642828603305166, 0.06180797373094867, 0.13583203146774925, 0.20441432153024983, 6.327242985848458, 65.34668314841487, 57.305184948828916, 47.962742467080396, 53.10809981438422, 68.9553068530175, 19.980310470827167, 33.89212985192576, 11.619996140080115, 16.693864368623306, 39.88188328281526, 38.03651009836505, 12.749980976504665, 37.9071738643031, 47.241634322750954, 58.735681195412916, 48.199539876753285, 6.7351611487327085, 4.866357686058168, 29.295280671888783, 54.11167352430282, 67.0524944797639, 59.54732941042993, 59.90781091874646, 51.06002638416906, 56.11254515186433, 57.45447035758727, 54.37246799468995, 40.99218860749276, 12.92368313958568, 7.634527289098309, 2.795810300496317, 0.7494991176551389, 1.5438349713240902, 1.5623868016466018, 2.0890163558144725, 2.620708831856328, 3.752826702210211, 5.767733550840809, 5.797213104463393, 4.752329972482497, 11.628221350331462, 8.480868377993184, 1.9984543443687501, 1.725565613277497, 2.6159865433169953, 2.371457406590062, 6.774292184460548, 2.8042458478481542, 4.329824024631131, 7.776330286456694, 4.570205500048976, 4.216922031294915, 5.700526679715803, 3.091914437470898, 1.0433179837080742, 2.433767198554931, 4.185583274210654, 0.3805919598427511, 0.3115925961925138, 1.4808786011511281, 3.0814127816307932, 9.235287251011018, 20.159046996024347, 25.558974012251824, 24.645697186070105, 11.424421860325722, 5.841366244900612, 15.789828646567562, 15.522341632073926, 7.502858225376376, 4.457070125687507, 4.761333773213049, 7.165988895200915, 12.331684712440738, 13.309279584115552, 12.95289401085146, 14.412723702769126, 6.557935716644411, 9.739072553573116, 12.061644234964925, 7.136338718475835, 7.4325830801840755, 5.0334281017703395, 4.63639892878071, 3.1336217349575413, 3.9092160136468954, 1.691857744609156, 1.0455118143750777, 2.5292273923274013, 3.399744745223753, 5.218844913667248, 0.9073593179064413, 2.5823835980507637, 10.779456726966366, 9.74348423942443, 21.72024250030518, 14.359153932140721, 8.562954760366871, 12.29986350382528, 16.593726258124075, 12.776238303030691, 4.745104966625091, 14.113463528694647, 11.554902445885444, 15.181850483340604, 24.53190922737122, 22.537283974309123, 11.430931033626681, 5.45722843177857, 3.4752435068930354, 5.063420505292955, 13.240758718982821, 3.034736821728368, 7.293616446756548, 5.3274979995143035, 2.7493868431737347, 10.710859375615275, 5.5609246223203606, 34.87490323282058, 47.26376825763334, 57.20851813593219, 47.794570845942346, 54.46548700332642, 49.71607723543721, 59.02135525980304, 50.10460761285598, 55.59664757021012, 50.886861585801654, 47.95021833912019, 9.543577701814714, 6.196103932396059, 33.51255032324022, 48.516306569499356, 38.96939877540835, 17.30709948847371, 17.609186710849887, 14.162047966834038, 5.986134554109266, 1.341893091317146, 19.08540406534749, 22.479846746690814, 21.387284263487786, 35.1875396697752, 27.160603269453976, 33.37095668238978, 38.386056038641165, 60.75331311072073, 11.887734186264778, 0.41002521111119183, 0.14780425436554417, 0.07830346318622751, 0.01195815943872496, 0.08646937057135567, 0.12546329188250727, 0.08215821077746731, 0.027287555820939523, 0.038604036183847536, 0.16340287702698864, 0.10960701853036882, 0.008270541589046198, 0.1205334777853662, 0.12590845025354816, 0.23899252736760726, 0.2836799681667359, 0.050030099678664446, 0.07588440266948554, 0.11426867121049475, 0.01452287337968066, 0.037508178051681294, 0.14088687877501213, 0.16208062459143902, 0.16998764788431509, 0.18697330337618628, 0.08688227664078436, 0.37077521725047025, 8.099875325156797, 72.0603649077877, 70.97888115913638, 41.479684306729226, 62.347736973916334, 42.16350640020063, 23.928021115641442, 36.519200032757176, 21.543408324641568, 32.272494954447595, 34.025494360154674, 25.75204876161391, 19.449486309482207, 47.22311681316745, 62.221244458229314, 63.48208250537996, 57.318897554951334, 13.695792882673203, 4.967051792529322, 27.255712901392293, 57.87229691782306, 69.92464219370197, 64.65603220847346, 63.4580187643728, 57.44946541324739, 60.37769125353906, 62.55672085669733, 56.51698074033184, 42.32014625303207, 11.693869079312972, 8.008002629203181, 3.5547300932868837, 1.5301231006460807, 4.620271613520961, 3.2891973997316057, 6.197765546460306, 4.761720126675022, 5.635552127515116, 4.641862790430746, 0.6635854212987808, 7.946799926219448, 22.759115580589544, 12.282224605160376, 5.295960672440068, 4.095143469110612, 5.649777583537563, 6.625046979996466, 10.339372677187766, 5.209581746209053, 9.85385581370323, 10.805370846102315, 8.433945063621767, 2.5279842461309125, 5.152068032372383, 2.304588349596147, 5.5801256049063905, 3.6651487360077524, 7.007484445648809, 0.6286080530093563, 1.1099667751020001, 0.7030678155922121, 2.653774412408952, 5.445687347842801, 16.917998406194872, 20.169003932706772, 15.012994408607485, 10.628314075931426, 10.345186610375682, 20.6694414923268, 20.998644059704198, 8.443781387421394, 9.682449217765562, 4.494991110217187, 11.714523300047844, 14.702937910633704, 13.488583872395179, 21.296010709577992, 15.600889055959641, 14.131093602026663, 11.098164992947734, 11.375514807239657, 9.39270471372912, 3.001630791733342, 2.211695347101458, 1.9979964076511323, 0.5851868023314785, 2.350016505487504, 0.7310034875427524, 2.7403141558170323, 4.068573333563344, 6.8580941134883515, 11.807482492539192, 6.2010495508870775, 12.54457429532082, 12.01357460791065, 12.124024629592897, 23.22271620073626, 12.602921512819107, 8.030116461938428, 9.968524344505804, 15.360959633704155, 20.36231794664937, 11.471491282986058, 9.681258778418265, 12.3912468840999, 20.342711979343047, 32.097570973057906, 37.78913797870759, 19.975174127086518, 7.393168162915015, 4.050116375569375, 3.8766056731823957, 19.174753696687763, 6.570896698582557, 12.805195200827814, 8.486581310149163, 7.238773867007225, 16.206623623448035, 8.871365824053365, 37.017191994574766, 52.756710360127116, 60.27671375582295, 53.98037218278455, 56.889598061961514, 54.08798633083221, 61.080313267246375, 57.359137150549124, 59.883280415688795, 56.459235606655, 48.024253076122655, 13.036943539496392, 9.17759212755388, 41.45200414042319, 47.21566823221023, 41.310712522076024, 19.98957903154435, 21.70315077227931, 9.168880543401166, 6.50624966429126, 7.233011414927821, 25.002130808368808, 25.646656636268865, 20.281552422431208, 31.306993730606575, 30.064465307420303, 28.38860715589216, 48.184701550391416, 68.58271306560886, 12.237122251141457, 0.4291143448602769, 0.04575046823329983, 0.18127558572638422, 0.06383336464604063, 0.14749673135097952, 0.010868650260231188, 0.09164093903476193, 0.04556712807126103, 0.07453941274434328, 0.06266290104136833, 0.17691770989087321, 0.04435631461561688, 0.2490984068642701, 0.36812344986584883, 0.3172138429457142, 0.4367305458553376, 0.2702299769847624, 0.14393797715104398, 0.3188532711036744, 0.31988632534780814, 0.3185366929298447, 0.3178835263656032, 0.3599294347147788, 0.23327628571179607, 0.31406378133162377, 0.46029682000798566, 0.4483891476786906, 14.37051703852992, 91.14739479557161, 76.3652132403466, 63.90140741102157, 68.93494975182318, 92.52737875907653, 27.913466922698486, 52.19993383653703, 19.95715868088507, 28.384214101299165, 49.54172003653742, 51.457770409122595, 15.757816222406204, 44.906027624684, 57.67284439456079, 75.6434343707177, 56.997545611473825, 12.372387147718861, 7.433412171179249, 37.325639340185354, 62.82036296782955, 77.41834609739243, 68.89192135103288, 69.99805327384703, 60.10846368728146, 65.91189276787543, 64.30224226367089, 63.72870937470467, 46.15182730459398, 17.050329369883386, 13.556663470883525, 5.966049077049379, 1.1276936819476466, 4.7318110735185686, 3.382880024371609, 6.109632340169722, 6.948239985973605, 7.056631743907929, 11.520669960206556, 11.202698119225042, 11.381459159235801, 24.066598453829368, 17.383534716021632, 7.149566421585699, 6.176185646364766, 6.011316660911807, 11.302988221568446, 15.94345219673649, 9.244945106967803, 14.779905599932517, 16.123424268537953, 13.709629043456047, 6.289935852250745, 8.639539037981342, 3.7255289669959777, 9.01518148760642, 7.811357052095476, 10.88578139581988, 0.6867955564971894, 4.073264488289434, 9.770220095111478, 14.280730062915435, 21.32326529872033, 28.1167810193954, 33.09380592838411, 33.636995361697295, 23.134378540900446, 14.203406418523482, 25.86654078575873, 25.761407536845056, 9.741569142187796, 7.774378416999695, 7.691237407345926, 16.92597258475519, 19.357616555306222, 20.060732787655247, 30.33321434451688, 21.18566463070531, 13.027689687667355, 14.92854283701989, 19.264479875564575, 20.92730202982503, 14.162143084310717, 15.022060967260792, 9.851926988170995, 7.357146095845008, 11.102786525603264, 5.507000857783902, 2.403311465055712, 5.911749745568922, 13.970485291173382, 15.77192008495331, 8.53830462501895, 11.499783339038974, 20.854057650412283, 16.356972975115625, 30.678530008562152, 21.38560352786895, 15.68809118963057, 18.670130968093872, 24.033758409561653, 17.263441547270745, 9.648060817872326, 17.93409820525877, 12.084293961524965, 19.65866631077182, 29.57797765731812, 29.596187260843095, 14.457908426561664, 7.4084227508114235, 7.387130654627278, 11.153539053855404, 21.707312407032138, 5.942740392300391, 11.03301932734828, 7.942421580514601, 5.333410482252798, 17.525838305873258, 9.089589830367796, 38.67615845895583, 53.79709943648308, 64.81042454319616, 56.56604566881734, 62.35424810840238, 60.62605573285011, 67.55101988392492, 60.260149586585264, 63.962674833113155, 62.366842839025686, 56.062652603272475, 14.70754473440109, 9.41612518602802, 41.99192623938284, 55.37567300181235, 49.53155325305078, 23.31102836516596, 27.557317672237275, 20.911035960720433, 13.501910125055621, 7.36785710819306, 30.50273722217929, 41.01655044863301, 32.80602162884128, 50.08727858143468, 42.04172072872039, 48.7429803417575, 54.18510813866892, 83.14962710103681, 26.81579947471619, 0.7065284492508058, 0.3380595243746235, 0.3268926897116246, 0.14703884059863706, 0.25578260061240965, 0.2512671711343912, 0.26287010900916596, 0.15387635918394213, 0.28908097996346416, 0.3403317411580394, 0.2608687196287417], [0.04811385714058434, 0.08549679896884388, 0.13000409419257797, 0.1687800175239963, 0.13419761352481382, 0.12649504377716972, 0.0354360519427686, 0.06339185668395893, 0.07987565946795287, 0.04913275024943775, 0.0480170427791534, 0.1805955601195174, 0.061530837593900586, 0.07848890242917884, 0.13831363540262948, 0.08440575186884211, 0.18432938073190952, 38.90316955504879, 64.72547777237432, 41.706350234247026, 40.305397279800914, 88.37867213833718, 52.0191204163336, 28.69350671768189, 28.971224254177464, 7.828768943586658, 33.3675402979697, 48.70829482232371, 21.90390552243879, 16.783716063345633, 32.551349978293146, 59.504716780877885, 81.56867657938312, 37.03367379403884, 3.584975244537477, 18.876596689224243, 72.70961130819013, 66.23302505862328, 59.60089721987325, 56.7340603951485, 56.661108232313595, 59.89329030436855, 62.17914173679968, 53.5677388406569, 28.661751208766816, 19.892470952003233, 10.655766744767467, 8.624020180394574, 6.574873491641014, 4.521877486859599, 3.9009915388399556, 4.137127293694404, 5.098582592702681, 2.974915038193426, 1.6751740656552778, 7.363430223157329, 15.968197449561089, 5.315692645888175, 2.1455781594399483, 0.3722646453928563, 10.568801914491962, 17.614030838012695, 8.862406149987253, 3.1666586331782804, 2.435012551084642, 1.6029453349690286, 6.803506978096501, 3.807414818194605, 4.207767709609001, 3.5780868270704826, 2.124997483145806, 2.6639568853762845, 1.7542961167712368, 4.266635621747663, 0.7041300424645025, 1.3282184831557737, 1.3322861035985332, 2.1995847840462965, 2.0019714846726386, 9.551170429875775, 23.958641098391627, 30.779738926118423, 31.08893152206175, 23.10074813904301, 23.68755432867235, 24.683322521948046, 12.298216108352909, 4.135446067779295, 5.353357695764111, 7.8890645984680425, 20.348858333403065, 17.460270004887736, 13.610065560187063, 8.79784393695093, 5.602025668467245, 14.73277145816434, 20.09935244437187, 21.629535728885283, 17.774895083519723, 10.709875841294567, 5.561717921687711, 8.772672126370093, 6.995781563943432, 3.505340098373352, 2.5333174438245836, 1.770038672031895, 7.806082444806253, 8.915870997213549, 5.168275756220664, 2.5001241410932233, 7.129535367411952, 6.5889714706328615, 15.516901304644925, 16.77122135316172, 10.349279603650494, 10.791163040745644, 11.90027302311313, 11.219228948316267, 11.4627081155777, 22.080839718541792, 19.579920807192405, 13.944428005526143, 13.632795695335636, 16.320683206281355, 29.157583905804543, 20.34964280743753, 5.5843146962504235, 1.410964314014681, 3.167663985683072, 2.959057385883024, 2.3434259430054696, 1.5720236974377788, 2.3273981578888434, 3.067239297013129, 7.758793369416268, 37.379120857484885, 48.86841773986817, 53.462744835884344, 53.54396143267232, 53.239232493985085, 54.636580790242846, 53.53001740670974, 54.63087374164213, 57.442001142809474, 55.75890425712832, 37.01576032946187, 8.291644415547772, 19.842378362532585, 59.32287569968932, 57.69329955500942, 53.59375592200987, 61.60947630482336, 15.828579702684957, 12.529487879045549, 2.966714833051928, 8.473769868573836, 18.3389554485198, 37.946342652843846, 36.486915003868845, 49.72166269056259, 33.59209991270496, 25.886103606993153, 53.59957671934559, 35.09869798537224, 0.3494896481354391, 0.14164928947725605, 0.11732032116983207, 0.04454177301076632, 0.04109734594221077, 0.03586505351948642, 0.04312010534528283, 0.11582451151503671, 0.06033706959457167, 0.11382560425948714, 0.060684337250648014, 0.02080434715495475, 0.09422102357230841, 0.036665121273648356, 0.17004513512215308, 0.1553440917163126, 0.1990522423218335, 0.11871413387838872, 0.06716152638076775, 0.12566712489652057, 0.04188622115179897, 0.15901647207717742, 0.07266779865829215, 0.04607597516188699, 0.05883430386142385, 0.1071650213411739, 0.08486460023108991, 0.10070027347894446, 0.1486511186005608, 43.48867524054743, 78.9532950616652, 42.58730280783869, 41.59753976329681, 89.03515138933736, 36.96958226542319, 33.39598924882951, 32.6152277377344, 26.761080449627293, 41.5991283232166, 27.19438272137796, 24.461936104682184, 24.103480500559655, 31.735126318470126, 72.24399458977484, 80.75622820085096, 54.62764563099031, 6.609891922243181, 17.76605013878115, 71.08553040412166, 69.50060259911322, 63.88120720463415, 61.5706487624876, 63.1387064533849, 66.27307245808264, 64.40779324500792, 60.17260620670935, 32.77948287225539, 19.876973667452415, 7.381096578413441, 8.7982803006326, 7.703105518894811, 5.585820396100321, 5.436989491985691, 8.802398789313532, 9.102802334293242, 7.4915363038739855, 3.757497264492897, 12.421643291750263, 28.024095412223573, 13.497758296228225, 5.067630679376665, 5.94891224176653, 15.995063724056369, 19.354735574414654, 7.918293120399599, 7.845541979036025, 6.14066368149173, 4.872657993147451, 11.51779584346279, 9.89025737008741, 3.766291218419229, 3.894844939631801, 2.9043883710138263, 8.998457481784206, 6.694027743031902, 7.757436719632919, 0.7634314377942394, 1.6206645196483982, 2.331728699707216, 4.516089539374075, 10.705481806109029, 23.067927706626154, 32.47189256452745, 30.52975254674112, 18.652346941732592, 9.355091144961696, 19.665979569958104, 27.07784910355845, 12.007773422425794, 6.137531178612863, 8.35852082698576, 12.509152350887177, 22.773722487111247, 23.628879593264674, 18.55051632850401, 14.129819812313205, 7.5347083614718535, 14.980981984446126, 22.23314731351791, 11.323250205286088, 13.494599807646967, 6.241485755289755, 3.8191164741593027, 3.7460794900694205, 6.530721331796339, 5.69240148990385, 3.8550912276391065, 7.389936129893027, 9.82623154117215, 19.409933128664573, 8.401144243055775, 7.6058949674329455, 14.749041449639106, 8.518455470761946, 20.30360790991014, 15.198371506506398, 9.592674009261593, 9.980291455022751, 13.643989159214883, 11.48166395002796, 19.16737964076381, 27.815172326180246, 15.773698879826455, 15.179568644492859, 20.81792281519982, 25.107165998028172, 45.03883907871862, 31.319056980071533, 11.457085397935684, 3.447077947278177, 4.990870875696983, 4.152919736600691, 2.2759849554108036, 2.2603756381619364, 6.847813581266712, 6.188984830533305, 9.327567873462554, 40.06015892951719, 51.58753418153333, 58.08510903389224, 56.506217756579005, 57.91718059970487, 58.83982796822825, 57.979871842169, 57.60048058725173, 59.73800366924655, 60.3745965034731, 42.08995019235919, 10.161553986610906, 29.194030569445705, 56.004448552285474, 55.81353895125851, 56.22607423413185, 62.830894531742224, 17.441777990710353, 8.37693831612987, 6.786859458492649, 15.286713088712386, 19.973685587606123, 40.30167102813721, 39.60041007687969, 49.4827118996651, 36.44378069908389, 29.73474890955033, 64.34772606818908, 38.20377565199329, 0.05141610212083306, 0.20062096056438264, 0.027125126028793956, 0.17280898117009671, 0.011940925333258367, 0.038192876794886206, 0.07057659312962525, 0.1321050290378832, 0.05276505272054384, 0.07362451224077134, 0.048320873249923034, 0.010907531137608234, 0.20762462829870565, 0.12919705120786545, 0.5526234077349786, 0.2974631156652205, 0.4322224248561167, 0.3712708148504458, 0.1453331305134681, 0.22685726563776695, 0.2591898839079565, 0.44518313100261075, 0.356819209672751, 0.35966703427895425, 0.24681788568775503, 0.2149386076076377, 0.3136446699500084, 0.300035945350124, 0.5054790310321317, 66.57077250942108, 84.90131055155109, 62.579643187984345, 50.234155654907234, 111.4522421744562, 67.33634856439406, 44.88084208580756, 45.568155088732325, 17.003109916563957, 48.40870026619204, 59.86288801316292, 29.319787640725416, 19.767892552960305, 41.59688472747803, 78.78891637248378, 91.77547608652424, 46.48410697137156, 7.726247012615205, 23.649976061236476, 82.50059250862368, 75.567960123862, 71.58694267272949, 68.55993193964805, 68.32449559242495, 71.88972611581126, 68.81152845198109, 61.658192142363525, 34.12506764934909, 25.05885220343067, 18.000737313301332, 15.904176523608548, 13.556661509698438, 11.622368193441822, 8.947595127167242, 13.549232540592072, 12.646316655220526, 9.422802040653846, 7.256739302988976, 17.943764886548443, 28.77533716540183, 11.765128739418524, 5.682987801490292, 8.657393667005724, 17.8014495295863, 27.385806152897498, 18.642246838538878, 7.346064419515672, 9.960645283422163, 8.985527388511166, 16.793445502558065, 16.21453700527068, 5.774409915170362, 5.701484718630391, 3.4486432181250666, 17.199681458934663, 12.911566938123396, 13.32292550994504, 4.796764052683308, 6.377995514100598, 5.251096602409117, 3.808480722288932, 9.069812259366437, 19.87512230873108, 40.30776639138499, 34.73389794749599, 46.62806187906573, 34.23586676197667, 35.13309717178345, 39.212726931418146, 21.904744909655665, 14.758028580296426, 16.77518883059102, 19.109020656155003, 27.327390293921194, 32.17923079767535, 23.213214258993826, 13.833868157479072, 9.82876637289601, 26.140100609871652, 32.75206746593599, 24.119593597227528, 23.60263893681188, 20.525415981969527, 15.381731525544199, 13.477466894734292, 10.999865493466778, 8.769520501936636, 6.411369491008021, 8.792533047737615, 12.099315658692392, 27.223323929694395, 11.65164182263036, 6.219714639648315, 15.923784452099955, 12.936693641447253, 25.03843234431359, 25.3453891892587, 18.43714806341356, 17.869649740957446, 20.393432148041267, 13.694066059204841, 16.083083671908227, 28.49583298929276, 26.355060223610174, 17.837709880644276, 19.500430053280247, 21.017312580539336, 38.94802185796922, 27.112526778251897, 8.517663151987138, 3.0328379042686957, 6.0101929018574385, 6.282896178383981, 5.3761868707595335, 3.4158347979668653, 6.269891560077668, 5.895202736700735, 10.516648119495763, 45.70697169150076, 55.018176417196955, 62.782794506319114, 59.94126481394614, 61.74875574727213, 63.51655621682445, 61.75069339813725, 63.2834223008925, 67.67233879335465, 67.70761659068447, 47.64216323052683, 12.28726387023926, 27.310549597586355, 64.30421521586757, 66.68309350167551, 61.81935448800365, 72.16498236502372, 26.103298971729895, 20.791117337442216, 10.807692889244327, 13.588114015517698, 33.02043014957059, 58.38162060706847, 48.966143592711425, 74.20260660109982, 47.954580014751805, 42.21487375997728, 70.57369247559579, 63.34423080567391, 1.392351074084159, 0.29721910133957863, 0.29961649688982195, 0.2893427981724662, 0.15857690614798378, 0.13836549955510324, 0.18251860934880473, 0.3189786030880867, 0.22412729599783499, 0.2433582326217044, 0.20404960239125838, 0.15280642546713352], [0.17006123829032146, 0.10200886656680416, 0.20280832544930522, 0.02704286733792434, 0.16963500229101028, 0.045013139249696854, 0.07904016397773259, 0.11733239471551873, 0.0855717913157517, 0.05816150246368301, 0.14671015823560377, 0.140608589675638, 0.05591952700107809, 0.07515662680229834, 0.09837209397265989, 0.1073699651826774, 0.36025103842539175, 12.913869369414545, 68.71306911591562, 50.67291982712285, 45.69007019842825, 45.26816045084308, 64.08468800206339, 34.331725566617905, 41.656308635588616, 12.792689704125928, 19.01245386369767, 41.26812342674502, 31.80697237291644, 26.12418559289748, 73.20750128838324, 52.91087911975, 49.97868776321412, 23.111291470066195, 11.356880607143527, 7.962221214848181, 54.69021920234927, 64.27156540655321, 56.091446722707445, 58.43851066404774, 32.86515920392929, 41.342103250565074, 63.84813770171135, 51.062254290426935, 47.29030701421922, 22.61510575971296, 17.034469266091627, 4.066231188274199, 3.6635312486079434, 6.328271627426148, 6.1725432353634995, 11.679028791766013, 6.203272554182238, 9.000547124493508, 7.47192592390122, 3.462234966216549, 3.407405624466558, 7.2972157116859195, 4.147719164048472, 3.2319977206568566, 7.082302185796923, 10.534271328679978, 17.454339381187193, 4.920440796882876, 4.601680559496726, 3.098118401342823, 3.120639179983447, 3.5538676621452456, 3.069024956034076, 1.5095229350751447, 2.082556212140668, 5.660154704124698, 2.204711812157785, 4.206979313204366, 1.734181344509125, 1.466029120549079, 0.7638722754293873, 1.1821860675850224, 1.889124772241039, 9.985226777292068, 26.387606090114964, 40.16061082963021, 41.99236946721231, 37.9522850436549, 36.48751512650521, 32.69986464131263, 23.440856856684533, 27.05121424890334, 17.92217419993493, 4.297441917081033, 15.130076177658575, 12.903516273344717, 9.971637725830078, 2.5861223522693884, 14.324117360576508, 28.291104878148726, 33.113241272587935, 28.147149970454556, 23.403972848769158, 15.139771296131997, 14.90286700187191, 3.608952203104573, 1.061074308330013, 0.9262399531660542, 3.8920951129928714, 0.7982631268039827, 8.367896272290139, 9.015004000356122, 16.60119641211725, 4.0588483070173575, 0.5414089836901235, 7.095150889888887, 13.596075446374956, 10.33838620108943, 14.829603010608306, 11.83409087119564, 5.82555026777329, 11.628875405557695, 17.22035038855768, 9.173631514272383, 15.499041772657826, 14.876193904107618, 17.911236670709428, 16.35642678506913, 11.64085138228632, 16.172905948854265, 24.814333608073575, 7.83383664584929, 5.392399987866802, 2.143030580013029, 3.383793446325487, 4.499326800146411, 6.783731858576498, 10.564574580038748, 13.504691085507794, 32.22868796317808, 64.2096076473113, 49.239842660965465, 54.85421742162397, 46.435351910129675, 54.170626747992735, 49.67361365595172, 60.41564018495622, 51.635426321337306, 59.535126916823856, 30.130268950616163, 9.110715716115891, 33.98571760423722, 74.82991910749867, 40.89470201923002, 56.41195143422773, 13.04835077255003, 14.500479871226897, 11.08353945516771, 2.516572355262695, 10.01577615737915, 42.343045050098056, 27.63015804752227, 30.50796574161899, 62.11698785904915, 22.332926527146373, 46.83965021564115, 48.12006873469199, 14.636489037544498, 0.44755414248474185, 0.26981923128328017, 0.19568237476050857, 0.16768052813506898, 0.15147735484905783, 0.04179242134635006, 0.062368619856574846, 0.02567003394717411, 0.08908829576666318, 0.027628497505981117, 0.10372467369081513, 0.08688893394484636, 0.09312613071092675, 0.01433427402404167, 0.17259561036142612, 0.04273748656194057, 0.2744272501478272, 0.11627514741473621, 0.016171759850676024, 0.04735535731719387, 0.05622743689004452, 0.19418015294978697, 0.14302870739371548, 0.05849468176283183, 0.02702155477187086, 0.05477255548260385, 0.16651504793234412, 0.20417677298668893, 0.4276387675875618, 16.05029756023038, 78.3488578181113, 59.27743111887286, 44.50700490705429, 52.728167272383175, 52.28835582733155, 35.86539583821451, 34.43312275794245, 25.916486286347915, 33.345131797175256, 31.498407356200683, 29.67908851562008, 26.075734515343946, 70.30146429615637, 62.889494742116625, 55.78510176750922, 30.924497919697917, 13.237132487758515, 9.917761029735688, 57.961158214076875, 71.53602246315249, 63.01017822757844, 64.51811775084465, 49.36296193830429, 53.344061759210405, 67.4886541981851, 53.98224707572691, 45.98456175096574, 27.08111055435673, 13.279722563682064, 7.347531385960118, 3.701144081930961, 5.034993127469094, 7.279130643413914, 5.221881808773165, 4.874207819661787, 2.05311453390506, 11.077867707898541, 14.38044357684351, 9.765723097708918, 5.971413408556293, 1.5441682502146692, 5.51206365708382, 14.637680457484338, 16.857284038297593, 14.458353615576222, 5.843500014274351, 8.29521769477475, 5.092947617653878, 6.549220700417796, 8.28482831678083, 10.702213491162947, 7.64665819944874, 4.352423740971473, 13.195587723485886, 6.912697918953435, 8.917529179203896, 1.960500632562945, 2.251940335958235, 1.8357999046002667, 0.8338995758564243, 6.207141972357228, 20.855053932436054, 35.423199592098115, 46.7263525532138, 42.06609825934134, 28.40619702492991, 35.309027241122344, 37.93904704432334, 24.457246911141183, 27.805850813465735, 22.225412399538104, 8.4345922547002, 20.557771613520963, 19.427791680059126, 13.646745604853477, 7.39383202406668, 11.892873471783055, 32.20507725592583, 31.469642654542003, 24.61360239213513, 22.442133157483994, 13.525169780177455, 10.245255404903043, 7.249021549378672, 3.7326554233028046, 4.48650457205311, 5.471967227997319, 6.771143992100993, 11.121171655193454, 12.802305394603362, 20.770330736714026, 6.234480402161998, 11.576243081400472, 9.324459395100995, 17.705722124345844, 12.832510586707825, 11.764416829232248, 10.10341465473175, 6.567449915793635, 12.99995166640128, 18.63625737928575, 13.320018053054811, 19.280145822032807, 17.31105519879249, 20.150774717330933, 20.542497904069965, 20.976878827618016, 27.632246709639027, 32.90216088294983, 13.569511194382946, 7.817823079324539, 1.4708251986772785, 2.7909134664843163, 3.7382080285779895, 10.861234222688983, 10.340213044997185, 10.69914129472548, 36.2332788590462, 65.63830352598622, 54.19700076503139, 57.88180866549092, 51.53915959019815, 58.07205146358859, 53.98000347998835, 65.4929247979195, 57.32775034443025, 63.9840478281821, 34.163495109927275, 13.316337889240636, 43.47566081631569, 70.9648939871019, 52.77034844121626, 69.23141817892753, 19.499663229911558, 17.342241964032574, 10.594010987589437, 7.957908078547447, 12.898960440389573, 33.20008254820301, 34.41044753597629, 29.881710313981582, 62.667782768126465, 26.595711361977365, 54.96929584010955, 57.51562795331402, 19.239176665582967, 0.7043913090901991, 0.1154656146442698, 0.19410886080755343, 0.180158369062889, 0.09426346484331355, 0.17776687238966266, 0.022052522718666062, 0.09970623609279433, 0.012595624073348459, 0.021567257729569272, 0.07101681023355454, 0.08228905093405517, 0.3643408447744385, 0.23448861985196992, 0.5091399813611661, 0.08271572360348317, 0.37591379796785696, 0.24122172065319555, 0.2974383863470247, 0.17772504398899694, 0.24421715508064917, 0.39252129713854483, 0.29570191017081665, 0.3870596418217305, 0.1578848069954303, 0.21290539493483884, 0.35721181441218625, 0.22341258192975677, 0.7087739448874228, 25.069232756091704, 91.11523136015862, 69.58905204649895, 63.404549014183786, 53.35290670394898, 83.17207874790316, 49.699717029448486, 60.88403001908333, 20.207778523045203, 31.857741571241814, 45.73894293077531, 44.79191803163098, 30.99328060303965, 87.16228238997921, 65.60759528990715, 62.2122779200154, 29.82611660034426, 16.148406824757977, 10.404808598179972, 65.30731039662516, 76.44187204299435, 68.04734876078945, 66.78368660711473, 46.71205159156553, 53.61563098046088, 73.29175379968459, 56.93770593212497, 55.70141015514251, 27.86395484401334, 23.424445659883563, 13.241124480001389, 11.988039978088873, 15.825998783111574, 12.126552597168955, 22.404384266945627, 17.91717121678014, 20.317051833675755, 14.715716992655109, 11.686033164301227, 8.422425062425676, 12.375238710834134, 6.813497745221661, 8.56180158353621, 10.699759068027621, 21.934131306986657, 25.280069958779123, 6.6403437333722275, 10.941605548704825, 10.404625227374416, 8.820447575661445, 15.745631379465904, 14.481436764040302, 10.351153516000318, 4.681519423761676, 22.070261086187056, 12.673746770428075, 10.957249922137107, 3.885487880437605, 4.434616517636084, 3.7303534823079265, 1.1557128881254504, 9.103748606097314, 24.856956043551047, 42.72365616213891, 54.56333052727484, 49.43597685906195, 42.43440489615164, 45.460921410591375, 43.67756482093565, 37.15080753449471, 44.163158170638546, 31.688079449438284, 16.87817262065026, 23.68385357241477, 24.512730798413678, 14.50797159825602, 8.896190504873953, 26.804418717661214, 46.7783357251075, 40.80595054934102, 31.7591880982922, 30.44878109808891, 18.524989543422578, 16.036022093988237, 9.233464329473435, 1.9735140762021466, 3.0446574764866985, 10.150436028357475, 6.703019776651937, 12.173428843098304, 26.15348569808468, 30.60690360684549, 6.26697184578065, 9.157621379821531, 13.472528630687346, 21.91989702563132, 16.526049683170935, 23.654412261901363, 17.862346287696592, 14.71902257011783, 17.373597391190067, 25.295271104381932, 11.738411514989792, 20.69120280204281, 20.8788784088627, 22.80392473743808, 20.91402872916191, 17.471389924326253, 23.63526717309029, 33.47459746945289, 12.303324014909807, 9.395447431072112, 5.014183482816143, 9.041229947920769, 11.538020564663796, 18.71145902141448, 20.342615881273826, 18.989421706045828, 37.5363019974001, 71.07145693994337, 56.468335505454775, 64.36115234128891, 53.44244657024261, 64.61392164230347, 58.09273804387739, 73.93037057692005, 61.23585485642957, 71.83980218825802, 36.81841411898213, 12.795902125297054, 41.63356673332953, 84.52604955242526, 50.05301275560933, 64.95859599882557, 17.36768049578513, 22.470436980647428, 19.04143233453074, 8.72881120251071, 14.61604662479893, 66.89267358472271, 42.03229919556649, 43.85666808774395, 79.5692797630064, 38.082590103149414, 64.22555208206177, 69.35689480073991, 35.50685982550345, 0.8629693030830353, 0.330733762633416, 0.32993335397012774, 0.46047752482756493, 0.21102455715017937, 0.24500507651077164, 0.17263468084556444, 0.14709540853096595, 0.16783304091903473, 0.07081962686272399, 0.28166506499532734, 0.29684316667337574], [0.021837470347001668, 0.1260227658936093, 0.1238041292996176, 0.0344893932642956, 0.07813175989975853, 0.030780445611585053, 0.16695919506732496, 0.09673586806222316, 0.12005451195422681, 0.1329529811177523, 0.07690276334723158, 0.04428017696726226, 0.12607027100579393, 0.03774159738133031, 0.030470792872590885, 0.05581317867542948, 0.128575723257757, 1.0411219467078487, 57.25508059224775, 64.61776556507235, 38.03691802486297, 48.67088325562016, 59.034589336764434, 31.980448999712547, 47.80480038735175, 30.75143510295499, 8.392917071619342, 27.567321677361768, 30.381010386251635, 28.192159168181885, 38.44015729042792, 44.562922216230824, 62.2578009482353, 69.10004231237596, 27.311871436334428, 12.648530833182797, 58.42219752650107, 65.46069468221357, 54.7275483992792, 63.82767077415221, 15.99505784050111, 17.457483160880304, 66.39106519760625, 53.76588129228162, 73.08880252222862, 31.514642046343898, 11.093425789187032, 7.5053994309517655, 6.249965919602302, 3.5833979614319342, 7.287038631977574, 8.017001526971018, 10.29479984314211, 15.239872144114587, 6.598328774975193, 1.8457541446531973, 12.10077379980395, 9.021900507711596, 5.896270601980149, 4.398414021538151, 6.304855077497422, 17.756501128596646, 12.077583766752674, 8.391591310501099, 6.157525460566244, 6.072334031904898, 2.320168984513129, 3.1899717305937125, 4.021279110062507, 9.056258509235999, 7.001698459348371, 6.245890086696995, 2.128757074955971, 1.4912663856821677, 1.472536577813087, 0.12818704088849406, 0.3892167921989195, 1.9017843445462568, 7.976438826130283, 19.738647360955518, 30.03905619344404, 44.33943733092278, 41.07568410135085, 50.28053375982469, 45.788749187223374, 39.85330881610994, 28.558688971304125, 44.574034290929, 24.99001068453635, 6.7355455410095955, 5.754305316555885, 5.09734949757976, 5.993854268904656, 4.410310570270785, 30.88202649547208, 44.78518724441529, 43.58083917248634, 31.76708579063416, 19.77079118451765, 16.41261866015773, 9.594901915519468, 1.6365523251795, 0.3282824344933033, 1.4624073019912167, 3.366344782613939, 1.3277313738099992, 6.183898497012354, 5.2585976450674, 27.63284879346048, 11.531057377015392, 3.2069286271449062, 3.0032146938385504, 12.158352232748463, 10.58994839268346, 14.52194013903218, 17.680416953179147, 11.354529146225223, 9.322591366306428, 20.805626184709613, 19.906322802266768, 18.44451819696734, 19.056484430067, 22.25295332170302, 23.032751890920824, 24.735248819474254, 12.432608277566972, 15.391059902406509, 22.000221283205097, 21.435647087712443, 7.8557499474094765, 1.7808591430225682, 3.1374757087999776, 9.477192567240808, 8.237708883900797, 13.963784902326523, 36.05774102672454, 43.01219747912499, 53.381567462798095, 52.196999903648134, 52.286657441046934, 46.4145908048076, 48.176558709913685, 54.6262021987669, 53.582632080201186, 48.05178026999197, 12.374120835335026, 23.373735297110773, 60.66879780061784, 68.54352858758742, 40.11771578942576, 24.523838950741677, 21.38411302720347, 15.935069111085708, 7.604282382995852, 7.491585333501139, 24.781874033712572, 38.38393011400777, 18.334776163101196, 80.40004561024328, 31.534551997338575, 35.08362431680003, 50.363444820527114, 40.872509248795055, 2.1712885604750727, 0.08640301969623373, 0.145428002842011, 0.03285474166454327, 0.12395626670050046, 0.08034051395952702, 0.13284600460000578, 0.0882836199936367, 0.012997462087491108, 0.01900137454691914, 0.015288052532160956, 0.1490940093513458, 0.07397195609707026, 0.00629353822366665, 0.14909468350871918, 0.028847789639727246, 0.07813840954294128, 0.012455963371922413, 0.1049883050783988, 0.14351872787360223, 0.035162485775447665, 0.017509523651472503, 0.1322191608168425, 0.11958827084350972, 0.05614869837318698, 0.09807990803833931, 0.008879928143634912, 0.10287317462385663, 0.1666340826740188, 0.09990197921832723, 1.2669627056006463, 63.94930347319573, 78.2876374644618, 40.18963636890535, 58.92062094903762, 64.0545916557312, 43.08491037737939, 43.72007154649304, 28.287133478349258, 28.38951518458705, 29.369703723538308, 29.04954025822301, 33.74375835541756, 44.959807242116625, 51.66871547698975, 68.97037659921955, 62.96609470921179, 30.2946594069081, 17.46338044443438, 70.76945797089608, 66.77129976211056, 60.58313323605446, 66.84766830936556, 24.87549904854067, 26.724337647038123, 72.7082855470719, 58.25690100269934, 71.20876343019548, 35.61885133866341, 14.449066423600721, 5.284727984859098, 1.5582836347241558, 2.589658614127867, 3.5257055346042883, 1.1302332940601534, 4.830626854973455, 20.286373015372984, 21.029244430603523, 13.272705443443792, 21.08531863458695, 11.705052737266788, 8.598208042883105, 9.813620140475612, 8.922125216453306, 21.49473955554347, 12.440702088417547, 7.188147344896871, 9.733657721550236, 7.7229433963375715, 6.752727483549426, 5.75589632795703, 6.3476182280048254, 14.179575077949034, 8.441462286057012, 14.479909981450728, 4.270477093035176, 7.157170916757277, 3.3460082738630237, 1.119734702571746, 1.0317699130504363, 0.9009246083517229, 2.091588204906833, 18.39866961202314, 31.710697797036943, 49.917777276808216, 46.708533225520966, 47.0881990463503, 47.278873305166925, 42.93431097461332, 34.65803146362305, 46.24904717168501, 30.883187517043087, 11.476268729855938, 10.628295444673109, 11.376393418158255, 9.004330250524706, 6.837674254371274, 35.40509785375288, 49.064183235168464, 44.238499056908395, 33.37292178984612, 23.906485342210342, 20.000108634271932, 14.695705060035953, 4.494375788396405, 0.548871967100328, 2.917513111906667, 6.2892955253201155, 5.588248833533257, 10.08095222134744, 11.851323804547711, 31.66229182674039, 9.94835747826484, 8.08464623266651, 12.384812235832216, 16.526749826246693, 12.415163536225597, 17.86689623709648, 10.959128737449648, 6.865258322608087, 14.386656611196457, 21.51569874055924, 19.96199300212245, 18.06135754431448, 17.986169630481353, 22.48208445887412, 21.21634933256334, 25.001256119820383, 20.451977445233254, 26.886127571905813, 28.186191281964703, 27.99287726802211, 15.998724276019683, 3.7430769157025123, 0.9458752156746004, 7.047501446739321, 7.601835314304599, 15.15760729389806, 39.37157115628643, 50.84896364519673, 55.63918959709906, 55.49342647675545, 57.707729954873365, 55.937054387984745, 54.272318117080204, 60.02478776439544, 62.233058637188336, 51.98706680728544, 16.810239130450835, 31.442572416797763, 61.042587910929036, 66.00036574948219, 49.81342261837375, 30.770544890434515, 27.62509426762981, 16.83212399482727, 8.532915288402188, 10.542388673751585, 19.62533989260274, 44.876260757446296, 20.990922874019994, 71.23094835589009, 41.90348463673746, 35.87978701437674, 60.19144535064698, 46.300606727600105, 2.8412122255371464, 0.31676041082509104, 0.09745713218205398, 0.12086982102764231, 0.05476587519590413, 0.011960346619748782, 0.15782485295447612, 0.04469514764364689, 0.04516456418881013, 0.034398071753281745, 0.018453763407324592, 0.09609843694394636, 0.1300173628354265, 0.1827742988544126, 0.4001180395003288, 0.21515813776321951, 0.13990123005163285, 0.34361504078392063, 0.4042358846674043, 0.21411959832954794, 0.13272883911286631, 0.177928869342131, 0.22828506966752393, 0.17933583578034756, 0.20067437221446346, 0.2517997861028679, 0.16029285116782113, 0.16970106971360024, 0.3443180949937913, 0.4706801305855475, 2.776317591628721, 85.51088610003072, 84.0465868673017, 57.94209157266925, 61.069558128233886, 70.72438993761617, 43.99843039051179, 73.36241137596869, 43.51668880831811, 18.285613175361387, 33.967600176411295, 43.451106779036984, 37.434908728445734, 48.35791733957107, 54.14406445718581, 74.27879471932688, 76.5552834541567, 31.806407551611628, 17.29414782216472, 71.80885468759845, 75.67704908309445, 67.11448361796718, 75.80775814671671, 21.938942094003004, 23.727403648437996, 77.39721236690399, 61.60126286168253, 81.45528085770147, 39.1190803435541, 17.943835489211544, 15.486483323958614, 14.002610483477193, 7.766564075023898, 17.00807171483194, 14.005267889268938, 24.33764207747675, 33.28090690797375, 19.785711880653135, 8.353626689603253, 22.31242233707059, 17.251639135422245, 11.672755941267937, 9.473720289045765, 9.712842683638296, 28.08630616434159, 17.941446765776604, 11.726010941690015, 13.880583586231356, 14.649610346363438, 10.221759426978327, 11.066362415590595, 6.994996109316427, 15.444662032588838, 13.227963947480726, 19.665334340064756, 7.735948995236428, 9.482966296134457, 3.9090770146539136, 2.074142973269186, 1.5380939697065663, 5.383389813284721, 24.269296738409228, 36.378269272465865, 34.94646295424431, 55.24867057800294, 48.037424395161295, 50.987486070202245, 50.23817216196368, 47.99402336920462, 41.65956420283164, 50.878181380610314, 36.92294528407436, 20.263299672834336, 16.070424222177078, 13.983603658214694, 15.751438448506018, 25.05821285709258, 49.35557611526982, 56.19504044132849, 44.13367371405325, 35.86452114966608, 22.665851423817298, 21.917057229626565, 16.54528498649597, 3.9675875008106236, 0.34755647122379274, 3.2718700843472637, 9.774666101701799, 10.233407885797563, 14.185814588300644, 17.759707666212513, 47.98529217320104, 13.917270495045571, 6.072508577377566, 12.122618459886121, 20.536847729836744, 15.916702612753838, 25.572153176030806, 23.585064757254816, 20.131627667334772, 14.763258080328665, 29.231622565177183, 26.818441191027244, 23.241741657257084, 22.878383090419156, 28.182312057864284, 27.62727314426053, 29.763721496828143, 17.671677912435225, 22.647930114499985, 28.434153718333093, 33.69102601082095, 14.766678387118926, 9.484635264642778, 14.14491113155119, 20.484599797956406, 18.326643128548902, 19.59907570192891, 42.747763049217966, 51.68435396686677, 60.35470224195912, 60.97770014116841, 59.747535028765284, 58.12054764839911, 58.83508190031975, 65.65839390600881, 66.83765057594546, 58.89307022094727, 18.430891882988718, 30.201028508524743, 70.0372063729071, 78.2262602160054, 47.72132058297434, 28.81425492225155, 32.77788058404, 23.53882589647847, 15.736685433695394, 12.065940210896155, 37.9647111123608, 64.56623738811862, 27.417210609682147, 102.191706626646, 47.74503523303617, 51.482108716041814, 68.85693380909582, 70.33892293130198, 6.425964140122937, 0.8290575937398019, 0.316181309641369, 0.4259625059222022, 0.27582744436879314, 0.24895750797323643, 0.262180078294008, 0.13190048356210032, 0.12422906294945749, 0.26361036444863967, 0.06754279301892366, 0.2661102932066687, 0.1925836870026204], [0.07753300856077865, 0.030614618219495304, 0.04803411504854599, 0.10058334547906153, 0.1794211932968709, 0.09312993050703118, 0.10586578218686966, 0.10904028966662385, 0.14877786018675374, 0.048756643213451877, 0.07356205309230475, 0.06499239438844305, 0.12958801651914276, 0.029660593605630343, 0.021559956911650878, 0.2008479830598639, 0.16780268851547472, 0.28836747631430626, 25.65087514538919, 75.76612610970774, 48.31270025622461, 31.169210672378544, 39.99981718678629, 30.317028684000817, 33.62086657554873, 55.34187786040768, 10.682859536140196, 23.960918034276656, 33.91165933301372, 23.16803639934909, 28.64655398553418, 52.51191916004304, 35.23904431250788, 89.12023544311525, 24.0880302844509, 8.495525294734586, 32.73086313278445, 72.63634143337127, 56.20758810350972, 67.34071024002569, 63.012563028643214, 18.703771175876742, 61.65356766793036, 56.15720133627615, 59.08269328455771, 44.544996984543346, 15.712582468986513, 5.415035986131238, 2.8684861813822105, 2.3028448560545525, 3.97988437644897, 3.3903798412892128, 11.089470078868251, 5.196673716268232, 3.2383193556339513, 9.422763797544665, 15.210016042955461, 5.981303664945788, 3.7822285438737566, 4.512393686079211, 17.138157121596798, 17.272945450198268, 9.85256927628671, 13.139318381586383, 2.2179431924896855, 3.375416489378099, 0.5250116377588242, 2.1903576533640585, 0.9827641878397235, 6.441029963954803, 9.585469595847592, 5.175036451508922, 2.2829045066910405, 3.1695641288834238, 1.3931610435247423, 0.8660966578510501, 0.3191121168915303, 0.4624484545521198, 8.07583756985203, 26.166868825112623, 41.63920710163732, 51.799859923701135, 49.52580305837816, 50.81776119047596, 50.176355608047984, 41.26527970837009, 35.18609231518161, 47.96342495949038, 33.574331575824374, 13.953394543740059, 4.193156880717124, 5.72660259662136, 5.539002005131015, 16.426954923137544, 41.279011926343365, 47.5398874282837, 38.63200041555589, 26.784755875987393, 21.338019294123498, 15.183207623420225, 6.374625217530036, 1.1975798996225482, 0.8387127530670936, 1.8330429686654, 2.413328708179536, 4.430895659231371, 6.584059192288307, 3.3647689703972112, 20.48428600834262, 19.75895151015251, 9.790179075733308, 5.401618538364287, 9.353393739269627, 8.749083972746327, 10.71266072411691, 21.751923484186975, 13.842344399421448, 12.523508225717853, 21.02700475723513, 20.842476852478523, 21.54355541352303, 20.750895392510202, 23.22640715106841, 22.843509297217093, 23.402503921139626, 24.00778643546566, 18.615102075761367, 15.144357527455977, 24.1214959467611, 11.06610648093685, 3.7542375297315664, 2.467359357303189, 8.976303935050964, 7.271888477187003, 8.659074402624562, 35.549382240541526, 50.61067573485836, 54.43504941078925, 52.18545244586084, 50.433812141418464, 43.66317364477342, 59.166945795859064, 55.0179999105392, 52.94360345409763, 44.99178632613152, 19.135969300423902, 48.818584026828894, 64.60049536920363, 58.87764353905955, 29.95090288500632, 40.77628958609797, 17.701750724546372, 12.692160337202012, 7.48553115514017, 11.193422694360057, 28.692579077136134, 18.62132883840992, 50.16641632203133, 60.12157224839734, 24.86842309274981, 38.064919825523134, 47.42412651738813, 16.735223800905292, 0.5369626706646335, 0.29747859064129095, 0.10323717364019926, 0.06558848740232569, 0.059822534301107934, 0.12189526035780869, 0.11356615326217107, 0.05747853124874735, 0.050395378061840614, 0.05816036099267583, 0.07403737234492457, 0.019225800004337105, 0.20346742153408068, 0.04904881765645358, 0.15082846305543376, 0.02804515740623878, 0.08952600776308006, 0.09055076527499384, 0.015357531918843668, 0.05009494136057554, 0.14162486659423, 0.026300840320125706, 0.12705296262978547, 0.1577663238370611, 0.07600730615517787, 0.038458690152413426, 0.04036445643812899, 0.02664804477394829, 0.12833923957641089, 0.050927912591085325, 0.1116611224208628, 27.864239215850834, 92.50808854256907, 51.186726785475216, 37.84749500213131, 39.17335810199861, 32.84685742470526, 45.3636662421688, 41.422045077047045, 22.984049781676262, 34.11024501246791, 32.637214583735314, 31.393701645635794, 34.5747007093122, 62.8261798427951, 41.74620543756793, 78.70846856024959, 32.476195404606486, 11.08654889368242, 37.298312187194824, 79.33356884987124, 65.10308042649301, 73.76073591170773, 60.1485542328127, 24.140709677050193, 65.62162168564336, 59.907253942181995, 62.82631712575113, 47.433155813524806, 13.419731566982886, 5.025251921146147, 6.0936633906056805, 2.4217571462354353, 0.8416922835092392, 5.412424177892747, 23.16425915687315, 19.108606846101825, 11.586655993615429, 15.872564181204766, 16.688755481473862, 7.724775143208043, 6.931558145630745, 6.864360099838627, 17.056310984396166, 22.043938059960645, 12.835543559443567, 9.689073120394061, 4.497410722317235, 5.727020819340983, 5.255042016506195, 6.826577378857521, 4.738346232521919, 11.741566081200878, 16.72086008133427, 11.0689119562026, 4.549169828814845, 7.045954562002613, 3.04908313578175, 1.0814960060581085, 0.7382870225175735, 0.6438343262960834, 10.629823207855226, 28.163694527841386, 41.505983798734604, 55.17712262368972, 51.541281592461374, 52.96354870642386, 54.75911955679617, 48.540554661904615, 37.509841688217655, 53.21737704738494, 39.33523431901009, 19.326059126084854, 9.142293737780664, 9.406715419984634, 7.318303844621105, 23.398373665348178, 46.48718603195683, 53.01271561653384, 44.67118355535692, 34.04490617013747, 24.802566497556626, 21.730917230729137, 14.493633374091118, 1.6736345353626436, 0.024241153563883518, 2.061902971998338, 2.1179668797600657, 5.174127442221488, 10.239161022247808, 6.3936129212379464, 27.94358091969644, 15.215842723846437, 9.52707923227741, 12.958972704026008, 17.08082579797314, 10.004666043866067, 16.777699147501302, 12.489326730851205, 16.028837292425095, 17.02519089944901, 20.82980759682194, 19.70746255690052, 23.09358196873819, 22.467216714735954, 21.125687668400428, 22.70834638226417, 21.780386163342385, 23.52246961285991, 26.13751380674301, 30.85143985286836, 36.83763373282648, 22.32368934539057, 10.37011915637601, 3.313453336877208, 3.858048204452761, 2.2468459125488036, 10.328452798628039, 41.57803381642988, 55.290251624199655, 58.51756603487077, 56.843223879414225, 58.254139654098026, 50.821593346134314, 63.525012846915956, 63.35451526026573, 60.920951289515344, 47.760999279637495, 22.150646140498502, 52.014884256547504, 59.94816426307925, 65.11245096883466, 37.411072484908566, 38.56289217548986, 25.89141841857664, 10.708073512200388, 10.666797430284563, 14.584880452002249, 32.37622007246941, 25.07865232806052, 45.21682839239798, 64.584433263348, 35.064298798961026, 41.033267590307425, 63.748274157124186, 18.84274467345207, 0.5574658188608386, 0.17010872041986835, 0.08915168188151815, 0.08285291462896333, 0.024574767617929368, 0.014982839272687993, 0.10652832566730439, 0.07399249491432021, 0.04804909972834492, 0.049159747187889395, 0.10309820529073478, 0.04726137365064314, 0.11957353131184656, 0.26217655428955633, 0.3279817603047817, 0.15337503124629298, 0.24088459600123668, 0.36997131522624727, 0.197391287093201, 0.13123672966274524, 0.22807139242368363, 0.3032610835807939, 0.25523708472328804, 0.23714928917827147, 0.1219789478026571, 0.25449509792510544, 0.22532875168948407, 0.11624338540939555, 0.37262504379595485, 0.17891297056790323, 0.37349605512234474, 44.7653635855644, 100.83575110281669, 66.94497446860036, 46.22024912987986, 45.28371657094648, 36.44079185301258, 49.26433001795123, 79.16999816894531, 18.23068234228319, 33.87463608095723, 44.303892812421246, 33.05976367765857, 34.647103740322976, 59.8631468895943, 43.06652622838175, 99.51595198723578, 30.173401294216035, 11.584711478602502, 40.44175847884148, 87.5723740362352, 67.36192241791757, 82.62862651578843, 72.28250442012664, 22.736699235054758, 74.96627638416906, 64.78741984213552, 66.87387758685698, 49.05080010814052, 20.352039375612815, 12.60312645666061, 7.260212561776561, 4.2669111682522685, 6.8189782769449305, 6.235095723982781, 18.904549460257254, 14.37464435254374, 7.266250560360571, 15.95511438385133, 24.66616999718451, 9.180486836741048, 8.253846495382248, 6.439143303901919, 25.997877428608557, 27.25494215565343, 17.694027577677083, 21.430081244437925, 8.530234348389412, 9.410983939324657, 9.741807426175765, 10.282320822438887, 8.67746639636255, 11.382629006139695, 16.615899416708178, 17.732411892183368, 12.419786049473672, 12.010312176519825, 2.237707280343579, 2.07736887758778, 1.195442207878636, 3.8976506600456857, 28.08796532692448, 44.419704714129054, 46.40205883210706, 60.41334952077558, 51.45296550566151, 48.41713728443269, 53.49109572748984, 48.77649307250977, 45.836237322899606, 56.45774902835969, 46.60317444032239, 29.504670519982618, 23.43061358697953, 19.010792739929695, 23.008429273482292, 36.94981351975472, 57.86118876549506, 52.42542305300313, 40.602607034867816, 31.557078169238185, 26.124601364135746, 27.738154626661732, 15.00493884086609, 2.5858963256882084, 0.5573681886157682, 3.640826854013628, 6.736603110067307, 22.546185793415194, 14.96750177875642, 9.933126914885737, 37.8327900363553, 28.16809346598964, 13.70214908353744, 10.899612653640009, 17.91443536358495, 11.537322382773123, 18.206412676841982, 32.077053054686516, 23.686826729005386, 16.08253650126919, 31.09917283058167, 25.794496651618715, 27.48820354861598, 26.625154633675855, 29.980616800246704, 29.072411598697787, 30.704762820274603, 29.4013003764614, 26.038654388919955, 22.41849107127036, 30.531443088285386, 18.317400063237837, 5.626136968212744, 4.058262648121003, 24.212771461855983, 16.398961947810268, 13.57585955050684, 43.37391845641598, 59.64183499736171, 63.24210797586749, 59.16267433474141, 60.832748951450476, 52.21522323546871, 70.23730216487762, 65.87585403073219, 65.03476842757195, 54.72774059541764, 25.610231545663652, 60.3224289801813, 71.68754362290906, 70.27129342479091, 38.72941640115554, 47.71484082744968, 27.32332475723759, 18.920087929694883, 14.984177735544021, 16.373670504939174, 50.49041194300498, 30.749391548095215, 66.06856007729807, 77.77983173247307, 42.030322320999645, 51.08250156525643, 71.18213838146579, 35.76843484755486, 0.9404198116352482, 0.3730133890865311, 0.3304797891647585, 0.2840513369489101, 0.23557217461207222, 0.19445333990358538, 0.3059059868176138, 0.2006955162411736, 0.1425822466732033, 0.1823192273056315, 0.3985189075671858, 0.20523201313710984, 0.28710625044280486], [0.1686463198594509, 0.023405998982789538, 0.007134348927666584, 0.08337903317184218, 0.044164064851018696, 0.0694337355033044, 0.12183278588758362, 0.16846788266012747, 0.12790951787704422, 0.024446241046872833, 0.17195816392139082, 0.08754613779244885, 0.1395534567775265, 0.04745410988107324, 0.06331353568502011, 0.13183487579226494, 0.07218380729036947, 0.34319629712450894, 5.870866881262872, 77.66686747151037, 55.91635604058543, 45.83365640332622, 35.759880158209036, 48.77489274547946, 20.54038766891726, 47.86762106803156, 36.126284445485766, 24.163510414861864, 59.49056879166634, 37.804160656467566, 21.913652612316994, 20.500026479844127, 33.30231520437425, 81.09885508014311, 36.06536219196935, 10.463086193607701, 21.327511264431863, 48.379051070059504, 59.3256409706608, 56.762321072240034, 41.05873946220645, 29.413851961012814, 61.927898237782145, 55.67544406460178, 50.48180626284692, 44.47629667097523, 15.803013693901802, 3.497424755365618, 2.4496079356439653, 1.262648833855506, 2.9009908630001933, 8.904768728440809, 5.327185190493061, 6.379625258907196, 13.331248779450695, 23.31412115404683, 24.461983173124253, 15.348597303513559, 7.835695849310968, 13.149487126258112, 17.685980835268577, 14.173466966998193, 9.35682483257786, 16.65723139239896, 16.361451341259865, 4.2155286092912, 1.569634238558431, 1.0878995205125501, 4.812581010403172, 6.967634145290622, 7.76056775162297, 11.00282492176179, 2.7405063519554758, 4.010532306086633, 2.8834600746631627, 0.8702124499024884, 0.4049634843343689, 0.38699011168172287, 6.556417269091453, 21.35861565989833, 40.85717670379147, 49.172209232084214, 50.09910844987439, 46.648418980260054, 52.01725336813158, 43.03481778790874, 37.46212605507144, 46.66222964563678, 38.53491390905073, 20.884911014187722, 7.520555469297594, 9.942164055762753, 5.399153328710987, 22.361465692520145, 38.36112545382592, 38.019208523534964, 30.108301716466105, 21.966834068298343, 15.510998137535589, 8.216570250449642, 3.595676696108234, 0.1603167377893002, 0.8983527592593624, 1.9297067172104314, 4.592482601442645, 4.66014789958154, 9.338555412907755, 5.660923488678471, 17.322320245927383, 22.681576205838113, 11.700939151548571, 9.203761200751028, 5.815204035851264, 9.627083001598235, 14.12195546011771, 31.47390234854914, 10.5037425410363, 19.091858325466035, 21.083014242110714, 22.674698329740956, 22.5632579095902, 20.44500150988179, 23.33368789765143, 22.302326156247048, 23.54068902231032, 22.13721594502849, 23.398385432458696, 16.032647875047502, 23.735499420473655, 27.153105658869592, 13.17322236876334, 5.638354661003237, 2.5752510130405426, 5.9291096656553215, 6.032951474189759, 37.11036789801813, 47.48493894453972, 56.462236219836825, 48.886954861302534, 42.37632636101016, 53.88802782181771, 57.9915605052825, 47.95375239464545, 60.166102916963645, 37.62872088340021, 28.484387513129946, 61.52170542747744, 72.05679555093089, 48.64110854364211, 42.31347822373913, 54.47767772982198, 10.89011267308266, 22.080078778728364, 5.44789368106473, 11.764380547308154, 25.28551224739321, 31.067464390108665, 65.2628581754623, 42.95739804544757, 28.254846488275838, 46.45008433249689, 42.42470879708567, 3.0739308605271005, 0.40177554733330206, 0.11214924300269735, 0.11823643209232439, 0.1850373072609786, 0.04236977201916518, 0.06692641399680607, 0.06549314776014897, 0.11439707520748339, 0.12131861065544429, 0.09495544142179912, 0.12086550029174936, 0.05949701971164154, 0.03921815141614887, 0.0484560264815246, 0.1170667767104122, 0.06584397772507322, 0.05121233039385369, 0.20228615992011564, 0.12414010481969004, 0.029846168829188235, 0.06641534908163933, 0.0884199453397624, 0.053027131399440194, 0.32256652991617885, 0.17041509430254662, 0.08299622669695847, 0.04732951334106827, 0.07090148335743336, 0.26911335786984814, 0.22608708680397083, 0.3651508755020557, 7.2839330953936425, 88.03231116264098, 64.80170119193293, 35.558172272097686, 30.843467635493127, 37.18959977549892, 26.704968983127227, 37.97984753885577, 20.491997388101396, 36.12633543629801, 51.06816137990644, 34.95233474239227, 33.70006707406814, 24.594794627158876, 34.047028172400694, 82.19883672652706, 45.054277527716856, 15.655134454850229, 21.881008686557895, 54.63061878758093, 67.61194998218168, 65.04393500666465, 40.99412625835788, 27.643741215429, 70.3005386167957, 59.36823398836198, 57.902907094647816, 47.57147819765153, 20.212773661459646, 4.861412557863421, 4.419036863311645, 0.2866116640788894, 6.020704853919245, 20.581296028629428, 16.439385894806154, 15.515006799851696, 19.408328879264094, 25.814692935635968, 25.271228936410722, 13.460390856189113, 9.134744155791498, 12.69166906033793, 19.340236533072687, 14.266626200368329, 11.964340036915196, 16.786226380255915, 17.621414699862083, 6.39829574092742, 6.369038781812114, 4.8701515986073405, 9.918101295348137, 11.310234800461801, 15.004848626352127, 19.052644429668305, 5.080968699147625, 10.042036425682808, 3.271146161902336, 1.5437474534396203, 1.3422995469262524, 1.3286861032247546, 13.648454777656065, 38.369421266740375, 47.52225637435914, 53.10417352184173, 61.56568696421962, 52.07096630527128, 52.630865035518525, 50.00990198504541, 41.88903070265248, 50.969611829327, 46.11536495147213, 28.128973707076046, 18.16692617631728, 15.234199416252876, 17.57474437836678, 33.342974493580485, 48.15561717556369, 47.50304068288496, 37.13933067937052, 24.723301279929377, 26.009062067154918, 20.623135951257524, 11.602886761388472, 0.4591968403227868, 0.8101872547018913, 3.237523114488971, 0.6449778197753815, 6.200180255597638, 13.929102324670362, 8.750941215022918, 29.782284113668627, 27.24953320718581, 10.453835283556293, 8.01071543847361, 10.257940350040313, 14.854287466695233, 18.773697230123705, 36.262351466763405, 15.709028801610394, 18.480968782978675, 21.76034873531711, 23.434335916273056, 20.244537015115064, 22.318500049652595, 21.931385647866037, 20.414444285054362, 23.64285303700355, 22.897561519376694, 23.130336538437877, 26.142455993160127, 37.65081559458087, 35.146448919850016, 26.157794421718968, 16.319523165302893, 4.351481881833846, 2.1939946711063385, 5.409746179657598, 40.859836070768296, 51.84208816097629, 57.49586705238589, 55.48772727289508, 50.924120180068485, 55.98502889756234, 61.07675567750008, 53.5113626141702, 66.28731066180815, 41.31412106175577, 32.36770852919548, 60.21132392268027, 74.98773174901163, 56.78463151378017, 42.631558910492934, 51.4051478908908, 18.293991358049457, 14.789584048332708, 10.096842723508036, 22.385711823740316, 26.576266211848107, 37.55922825105729, 58.29760343797746, 54.404639274843284, 28.886081364847, 54.08376193815663, 51.83944840585032, 3.0022561646276906, 0.2958742186667458, 0.1693034241156232, 0.08493345621372424, 0.023748811837586186, 0.11722475170127808, 0.10954734028106737, 0.06995906497562124, 0.05211347961918481, 0.0599765332956468, 0.03140636625879955, 0.0689776603793425, 0.017563613289366328, 0.07430941016683656, 0.21257907212261232, 0.2580081473194784, 0.20699079779367294, 0.1801511371928838, 0.34135256863890157, 0.23346829798913774, 0.1610517991526473, 0.22592971702256512, 0.27528802653954876, 0.12212351625484806, 0.5243428736444443, 0.40244679357255664, 0.29784101151650955, 0.14395453997196692, 0.15817900008011251, 0.4977480700660137, 0.2861374250102428, 0.8391141831394165, 12.19245724139675, 104.47188238943778, 74.0162940179148, 61.24879867799821, 49.015279123860026, 63.75245932609805, 30.897841492006858, 73.48707214478524, 50.36746917232391, 34.851682801400464, 70.12056458380916, 50.1275848573254, 27.576762822366533, 25.665393798582016, 39.16064570027013, 93.5864265503422, 41.9178169773471, 15.688036276448159, 27.426184992636404, 61.88308515856343, 69.16227463752993, 73.84014821821644, 49.40492345440773, 34.40793329669584, 77.54329712160173, 64.9602355495576, 62.75304725093227, 50.95169052000969, 20.737973143977506, 8.919702172279358, 7.96895690502659, 1.98083370923996, 5.363308748891277, 11.935574354663974, 11.318975802390806, 12.164141651122803, 20.048351826206332, 34.86178290459418, 37.542856277958045, 20.811739198623165, 12.15710589962621, 14.99385226157404, 28.073989922000518, 20.713581885060957, 11.285164971505443, 23.21910762017773, 29.32706559858015, 12.876075371619194, 8.907862497914223, 6.772922786974139, 11.16716536783403, 11.307455801194715, 19.40002718279439, 27.76101420002599, 12.993277753553084, 16.67189125091799, 4.581649015026708, 1.9718501332306095, 1.0595195788529612, 2.0407019483466304, 20.415454295373735, 44.10000016612392, 46.88016045478083, 55.550755839194025, 58.20009331549368, 50.48967845978276, 51.450588549337084, 51.48778046331098, 47.76395674674742, 49.07038058004072, 50.5387943790805, 38.921063407774895, 28.53478212510386, 25.821178574715894, 32.69257099397721, 45.70004086340628, 54.52162004286244, 43.91929264991514, 33.60470248806861, 26.771135445564028, 27.053728488183793, 23.395751560887984, 14.71338318240258, 0.35744960810388293, 2.3984325268576225, 6.276424757895931, 7.935453489903481, 19.825304285172496, 20.522129035765126, 13.957144329624793, 30.328158409364764, 35.52041945918914, 18.85538451133236, 14.513587451750233, 13.794674854124747, 17.998126975951656, 26.564722676430982, 47.77781055819604, 15.976527583214546, 24.973326883008404, 28.26010246430674, 31.75175520681566, 29.517569234294278, 26.654913656173218, 30.622138092594763, 28.621511613169027, 31.763371306080973, 29.03764370949038, 30.49749105207382, 24.819436611667758, 29.48197960853577, 30.636235090994067, 22.97821133367477, 13.239087789289414, 8.601934294546805, 11.266171874538546, 8.80686342716217, 45.67310594743299, 55.78437220665717, 65.36123906412433, 59.1784304957236, 53.724100205206106, 60.49245980478103, 67.44277815664968, 57.36178082804526, 76.1729778782014, 44.46724384061752, 37.55980483947262, 69.63997225607596, 84.75979143573393, 58.8084803858111, 52.02243481912921, 66.30187049988778, 17.67516097714824, 31.484767313926454, 11.529556089831937, 22.744543975399388, 43.59065294265748, 48.214335057043264, 82.27086713237148, 57.398819769582445, 40.88772804506364, 62.733925696342226, 71.76747368228051, 6.611441748757517, 0.7730072304125756, 0.4695511927768108, 0.28038055005092777, 0.35802325474158414, 0.2366989826963794, 0.37972272584034555, 0.2991651178848359, 0.19945091447762905, 0.16947317387788527, 0.31652384287407326, 0.37892314455201553, 0.1395296007995644, 0.19520775264789983], [0.12623714027746072, 0.1740664378890107, 0.0232665901327686, 0.123385263066138, 0.17373587094968365, 0.12590183891476164, 0.03762718981071826, 0.08193674241943706, 0.06931454754404484, 0.0577372812756127, 0.07251191508745955, 0.11255258829483103, 0.06277203792706132, 0.11047459778285797, 0.049462666014029134, 0.05403314657028645, 0.027220781682239428, 0.21810564573013017, 0.11268935797195281, 53.71740864169214, 72.7887882724885, 48.62813726548226, 93.80876218118976, 69.27502709050333, 51.99967330501926, 61.67334033596901, 64.81423708700365, 26.43019518544597, 51.919268638856956, 46.53477222688737, 19.00957484399119, 50.305982097502685, 69.18162761196014, 77.2232787839828, 52.7716035996714, 36.77921787385018, 18.587421909455333, 30.42895743923803, 55.29477411700834, 54.668065655616026, 49.7726535028027, 26.031013611824285, 58.692644949882265, 54.0240320851726, 47.60208837447628, 34.30458276502548, 5.554185990364322, 2.143325738368496, 7.977374801712652, 2.63489923169536, 8.777442709092172, 8.69888351809594, 12.485597537409875, 14.865084771187076, 20.170768999284316, 23.264150158051525, 17.01412981556308, 10.922286895013626, 10.987154072330846, 10.796871069938907, 20.249502735753214, 19.85642044774948, 14.344283246224927, 6.183446443849995, 11.010616710109096, 9.074991749178979, 3.035089835043877, 1.9682589581897183, 4.470454723604264, 13.761207230629461, 12.707939051812696, 12.650625378854814, 4.064435723327821, 3.930809887186174, 2.1141629161373263, 1.639133367326952, 0.302196221366044, 0.38427693468909113, 3.85334552776429, 20.107687480988044, 44.02240783937516, 54.13387021710796, 60.77638841444447, 45.08698225021363, 48.243533180605986, 43.514139267706106, 30.79840744695356, 45.679389584449034, 40.75777599888463, 23.27952192675683, 14.69634440637404, 10.064027194053898, 9.55591747837682, 16.75923066754495, 23.362264325541837, 24.70013576169168, 21.576179727431267, 12.357987146223746, 5.840351821914797, 1.2594679142198255, 1.8658592335639463, 0.3357927927807454, 0.7819661077472472, 2.4502009489843926, 3.1545701334553384, 6.04669742045864, 6.249852661163577, 6.657997340925279, 21.954098132348832, 17.283604491141535, 16.445876436848796, 21.474906090767156, 16.009498046290492, 20.929218107654204, 19.39743449611049, 7.96267326801054, 11.737461320815548, 25.566716770971976, 21.40688434723885, 20.813416011871833, 23.76276577672651, 21.875619349941132, 21.301990362905688, 27.313548249583093, 22.601734399795536, 25.910514477760564, 24.972667924819458, 30.992178417021233, 20.908953182158932, 28.197772079898467, 12.27735988555416, 5.025821645413676, 6.911702617522209, 0.8784666489208899, 4.117351193581858, 33.911447525024414, 50.86116221643264, 56.477458938475586, 36.71987241314304, 58.870712710965066, 55.99917296440371, 54.03025296426589, 54.189591407775886, 58.0765425774359, 44.697910585711085, 59.10498019187682, 59.269543232456336, 54.40060315593597, 49.24705197734218, 62.333792947953754, 24.447342926456084, 14.252586076336524, 18.34883393779878, 11.32273441360843, 12.861680273086796, 35.87309545086276, 35.36266565322876, 69.48702335357666, 37.16569685166882, 46.00602888291883, 47.26381924844558, 31.359953572673184, 0.19972935679458803, 0.13780355874088504, 0.09051937865273607, 0.024537719605911164, 0.026530666697409847, 0.1267552991668063, 0.0765014941533727, 0.004308487104642536, 0.06094518635842589, 0.06573590570159497, 0.08998507062994665, 0.1090418754686271, 0.04550680247766357, 0.08615047881199468, 0.10972570853247758, 0.11850489228363, 0.0952451222486073, 0.1514799595480004, 0.2702974233656161, 0.09227363572966668, 0.05945110423189979, 0.03848679408791565, 0.11664119188583667, 0.09215106932266105, 0.13165193399594677, 0.23333990165302831, 0.05871613096866397, 0.10075209932702203, 0.054359082508111195, 0.06301784106800634, 0.08393152046107477, 0.10881364255422547, 0.08090600176083465, 59.10977725059756, 86.53797441913237, 48.55960953620173, 104.45049762725831, 72.7321727814213, 45.853480062177105, 56.3787603378296, 37.09387825381371, 37.89204528254848, 61.37857421751946, 41.45842506039528, 27.370646192181496, 44.97951322986234, 61.08114480972291, 81.26990179861747, 54.897159530270486, 40.80571912950085, 20.259059590678064, 37.82128572463989, 56.63282794337119, 62.15299129486085, 55.87138998893, 26.885044997738255, 68.20031335276943, 58.93203112386889, 53.42126969368228, 39.97340786841608, 9.837500510677215, 3.64509831513128, 3.450517865919298, 4.371765928883707, 21.30033708387806, 19.363908037062615, 20.474764454749323, 19.80719470208691, 22.258248521435647, 25.958387005713682, 16.04979157447815, 12.484211960146505, 9.983455827159267, 10.709168834071006, 20.15397733257663, 18.798292452289214, 14.004611872857618, 9.049897405409045, 14.599431464749, 12.678664442031616, 4.023780111343631, 6.191324524341091, 10.309242010116577, 16.716702368951616, 19.956713491870513, 24.145414560071885, 7.190881727203247, 8.37357194192948, 3.263666201983729, 1.7857287655914984, 1.3452669425356774, 0.4012547607623762, 9.980870004623167, 39.09714252718034, 52.35965274995374, 53.624138601364635, 63.492461096855905, 49.81576035099645, 49.36260500261861, 50.747017322048066, 40.36585669363699, 51.66059617073306, 50.25320660683417, 31.966438293457035, 22.454518041303082, 19.17210021326619, 19.620931148529053, 29.228219909052697, 41.227220950588105, 36.106731430176765, 25.7430390773281, 20.00545286363171, 12.885507691291071, 12.285077148868192, 4.349233873428838, 0.25347508249744294, 0.8448622940528778, 3.709775257495142, 1.5807436166271087, 8.090871034129973, 14.452208242108746, 7.871377160472255, 34.34496748831965, 24.307518274553363, 11.170067921761545, 15.155482349857209, 22.474679023988788, 29.58052915911521, 25.39201048112685, 13.38196796755637, 14.570884454634882, 24.92514252662659, 19.962293063440633, 21.48273906400127, 22.445257325326246, 21.006775133071407, 22.629430255582257, 25.571866843008227, 22.55342060519803, 26.44540221460404, 25.373665555830925, 32.026530965682, 29.38468521641147, 41.235975680812714, 20.497743660403838, 17.019558375881566, 17.20449028476592, 3.303307636130241, 0.8827851784806099, 35.46224286479335, 57.54230791522611, 60.391109681898556, 48.10418705786429, 64.56549998252623, 59.163945182677246, 59.895686872543834, 63.94733052099905, 62.0832750874181, 52.9829252150751, 59.19040941422986, 65.56120541787917, 55.571367894449544, 58.873666255704826, 56.64075113111927, 34.33376519910751, 16.250792453365943, 9.030847434074648, 21.012146819022394, 16.4556804010945, 41.140324761790616, 36.395884636909734, 67.19303300303798, 50.43019963848976, 46.872766787006015, 62.19546664145685, 36.62584535537228, 0.2893691515970615, 0.054677832541206194, 0.12842167829794268, 0.006480758621041934, 0.020970668673755664, 0.09115236646105206, 0.03565244113786086, 0.03868662046208497, 0.0681305126917939, 0.014031096643227485, 0.07988113699661148, 0.023376878065567826, 0.005029003809942234, 0.13196152544790699, 0.25988561431727103, 0.20046642530829678, 0.13357161243836727, 0.24882514330167926, 0.6660960446442328, 0.4252644159620808, 0.14073959071068995, 0.08857848723569224, 0.1449609190345772, 0.20184112412314262, 0.21241583410770665, 0.27335340938260483, 0.23909486139253264, 0.20137391774164093, 0.19820787553345004, 0.1535878657934166, 0.18914182249817157, 0.4351762453875234, 0.32687271013855934, 76.55550310688635, 93.67518194260137, 66.74544349793466, 101.07290544817525, 87.48474828658566, 65.71985744660901, 86.8565022560858, 83.57445901440036, 37.195742207188765, 61.91045937999603, 60.405681287088704, 23.026972278471916, 62.25191347060665, 76.78997455104705, 89.36504625505017, 58.32396568790559, 45.519733428955085, 21.443605576792073, 43.50942457875898, 64.97792936140492, 72.24434760309035, 61.1389958473944, 34.23963615971227, 69.41158048568234, 64.30211282545521, 58.48506135325278, 44.72697927105812, 10.272284457760474, 6.2286233229021875, 11.373564408671472, 4.786806625704612, 12.384231725046712, 13.492163035177416, 20.47370933717297, 22.790343530716438, 28.325225576277706, 37.094623504146455, 23.21802112364, 15.93281472882917, 14.664120174223378, 15.381344191489683, 27.59388985172395, 25.29692046103939, 17.76008225256397, 13.304306999329599, 16.93956163621718, 20.35100583107241, 9.519795390867419, 6.400017661433067, 10.020595769728384, 21.518289466058057, 25.35922338885646, 22.89255069148156, 15.672767469959876, 15.823237434510263, 5.26763919861086, 3.3163281890653797, 1.5520388536876248, 0.5396262051597719, 11.95208655249688, 48.86806472655266, 60.59757540302893, 60.85593408153903, 64.5882144281941, 45.47110780592888, 46.18797586810204, 48.56457917921005, 43.085463431573686, 53.79552656604398, 52.704531069724794, 41.759443436899495, 36.56533102835379, 35.848702230761134, 33.71708623824581, 39.80380850453531, 44.860026067303075, 38.6423711622915, 29.254950861777033, 18.838526164331746, 9.332338456184635, 12.040052567758869, 6.178375309513462, 0.3876636255412333, 1.2025933015731074, 5.238563649116024, 6.621690411721507, 22.0163441857984, 22.379951823142267, 15.332804860607272, 31.224335662780273, 24.584953400396532, 26.410857900496453, 31.655264900576686, 21.86564084022276, 31.136517716992287, 26.715628024070497, 14.47843909263611, 21.4154351142145, 33.18973141331827, 25.84328309182198, 28.671437501907352, 33.16449096125941, 29.19636437969823, 25.467314104880057, 35.974088638059555, 32.07910641547173, 38.103249226847005, 33.65406943905738, 40.09792350953625, 27.487783855007542, 39.768864108670144, 16.93419191145128, 11.993158671163744, 13.116544119773373, 6.929503804252994, 7.991726263876885, 40.30289873000115, 60.27724719816639, 67.04148046432003, 45.03371646327358, 65.24894552846109, 66.94025977965325, 63.821744072821836, 66.27551217232981, 66.7275574899489, 54.496454115836855, 68.76271847755679, 71.70762615819132, 62.50780497827838, 61.26491177466608, 71.42163830418741, 35.58867262255761, 20.057202654500163, 25.432314795832482, 16.967704642203547, 25.40363442513251, 57.68848680680799, 51.5818702790045, 84.8643147560858, 54.297056505757, 56.23188718672722, 71.31300433989495, 51.13259415472708, 0.6621291800852745, 0.12545915500771615, 0.37063149915587523, 0.16345707008675223, 0.24041267051812143, 0.24742295725211022, 0.19394744608190753, 0.1654224686564938, 0.16921627395335706, 0.18903515241559476, 0.1285274520576481, 0.2690780565382973, 0.16090564489845308, 0.2314251414950817], [0.04389133371953522, 0.12688620827130734, 0.035345067510441426, 0.05488426642372243, 0.1162731938905293, 0.23387009578366436, 0.14977431074986536, 0.18058593805518844, 0.08852054034509967, 0.03792162038265698, 0.021457473499580257, 0.06741576798019872, 0.0799730598866459, 0.13603941146885196, 0.06085111842220349, 0.052173211494640964, 0.20649018997867263, 0.04002371585116752, 0.506550696107649, 13.549492397615987, 82.47756035097184, 45.38418023817001, 46.84150941910283, 68.5257367164858, 62.85726854878088, 81.36003002043694, 62.5565129710782, 14.86668803999501, 9.581843364623285, 42.41982544622114, 25.200381125173262, 52.070970227641446, 71.28484956679806, 60.70978656891854, 70.963576070724, 69.48324218873056, 33.820785860861506, 18.70494592574335, 72.1824526017712, 58.1455566806178, 82.36465100319155, 55.94623273418796, 42.69334408544725, 61.3230844466917, 43.48940087902931, 23.3421504112982, 17.835070125518307, 5.088143694785334, 3.5158062077337697, 5.308305842261161, 11.6888141247534, 14.380951523780825, 18.18910914082681, 20.688229645452193, 25.36057072301065, 24.976082348054458, 23.842793895352273, 16.7598327513664, 12.928521383193232, 17.22019741612096, 19.24031415293294, 18.065183816417573, 16.280497543273434, 8.368520909740079, 3.5244466989271106, 5.660308166857689, 10.039842840163939, 4.648236151664488, 12.97347370655306, 16.481317012540757, 16.304848597895717, 19.147232386373705, 5.679524348628137, 6.57696754701676, 4.027959887058505, 1.6145473382165356, 0.6282401469445998, 0.4210837515852144, 1.5724793052481068, 7.925276900491408, 25.469532205212502, 45.61446651335686, 59.44212752003824, 47.670290547032515, 38.49970671438402, 35.13840021625642, 31.953131652647453, 36.507276027433335, 37.729765061409246, 24.155755889031198, 19.432765245437622, 15.150491133812936, 12.887967017389114, 10.883282846020116, 17.331053403116044, 17.071433682595533, 15.385887276741768, 7.3577702429986775, 2.2581545960518623, 0.8324331609952835, 4.3307183250304195, 1.000745435876231, 1.3874372022767223, 3.155365639155911, 3.4607304921073303, 5.4837681689570035, 9.243858610430072, 9.287033119509298, 29.45088698017982, 37.246246645527506, 37.961428088526574, 9.632101674233715, 1.1951329535053623, 7.177047527605488, 4.696471989154816, 2.308961792338279, 12.204881348917562, 19.273397384151338, 23.06267369178034, 24.03033418040122, 20.099166131788685, 25.22680417183907, 20.290048276224447, 23.95297327349263, 28.374064968478297, 25.56358671957447, 25.444517289438558, 26.59787258794231, 28.507129415389034, 25.047508708892334, 44.47018561824676, 13.389214546449724, 6.720232607856874, 3.892980588059272, 0.5907244535703814, 19.063383879200106, 56.64761920129099, 37.34754185522757, 37.950319936198575, 73.93302209915655, 65.2801715174029, 53.47994442908995, 51.337377179053526, 58.24572224770823, 60.10027377836166, 63.57692541614656, 59.28524055788594, 38.38232194223712, 46.65802094244188, 64.50240865830453, 14.084016334625984, 23.819128274917606, 22.840363556338897, 10.100435614585876, 34.78016230367845, 25.900047632955737, 60.46780770824802, 66.59570309423631, 37.67873894783759, 49.94841098785401, 60.624855487577385, 7.84310422597393, 0.519058031420554, 0.18493465147912505, 0.13362359916490893, 0.03477155493812696, 0.11725250706677476, 0.09811860313939472, 0.05970800798686762, 0.04440464327232011, 0.04358371877441964, 0.030669500758390755, 0.08147013358651631, 0.02922502857062125, 0.11001948026880143, 0.05584877878127079, 0.08706276695574484, 0.09009663601435962, 0.20257348885699628, 0.0708449537295007, 0.10795517974803526, 0.06437505009554087, 0.20351222235589259, 0.1245594153841657, 0.054065540598164645, 0.13833067319806547, 0.21651837283805495, 0.13102109123381878, 0.11687046667981534, 0.09538564575655807, 0.08968352310119138, 0.09290404182167784, 0.21044021592505519, 0.08127588433243575, 0.4420357966615308, 18.5915207862854, 94.08855269032141, 53.86304624619023, 54.935967460755386, 74.20921187247001, 59.81154418760731, 88.5908252962174, 75.99199187371039, 38.26812997941048, 26.015943865622244, 41.277023284666, 31.62889872827838, 53.31414976427632, 71.00414906778644, 70.41817049826346, 62.213183987525206, 63.41572384680472, 39.07671482332292, 23.126396517599783, 69.41367503135436, 66.99066223636751, 72.77451084506127, 49.718673844491285, 54.18917955890779, 66.89653319697227, 45.84129325805172, 25.25737120259193, 14.869303280307403, 2.519646512885248, 5.74507107657771, 17.34188110597672, 22.51096094808271, 22.3998539293966, 23.612882206516883, 22.006526493257095, 29.0296636473748, 25.770530969865863, 24.998004474947532, 15.870654967523391, 12.350639566298454, 13.572314708463608, 18.026085630539928, 15.849089776315997, 17.302661326623735, 9.562014802809685, 5.657623304474739, 14.776980492376513, 12.469497188445061, 6.859878791916755, 18.15604748264436, 18.823876111738144, 23.137094782244777, 26.26292178707738, 7.206566795226067, 10.950721136985287, 3.6394420121946647, 1.6662522669761413, 0.7587773004366506, 0.24335473926076967, 3.2474180286930454, 23.27530537882159, 50.14806747436524, 55.3005596130125, 65.74634521238266, 55.18384164379489, 47.59710304198727, 45.799975010656546, 39.030634818538545, 45.29091804258285, 46.04619787585351, 32.7213062778596, 28.784895981511763, 24.55828912796513, 23.13127790727923, 25.027667399375673, 26.193727254867557, 25.245194204391975, 21.948812738541637, 13.443944358056592, 4.926759735230477, 4.407700232921108, 3.9701546920884043, 0.2616297820162389, 0.7404226305023317, 2.453719560177096, 2.9736603700345565, 12.336874008178713, 16.03863537311554, 7.2312385036099345, 39.625862336927845, 32.27771366796186, 41.197626667637984, 21.20506859594776, 8.914131426042127, 11.792643185584776, 5.660776890093281, 5.2587604234295515, 9.889988687730606, 17.946741965509233, 22.459401392167617, 20.37583443426317, 18.982265341666437, 24.365494828070364, 20.13181790228813, 24.072913469806796, 26.12591535814347, 23.914528162248676, 25.517587123378632, 24.800858305346583, 24.105510327123827, 31.75798196946421, 54.90648692654025, 20.787530329919633, 18.535874120650753, 11.16818420348629, 0.15948035363708774, 16.471997461011334, 61.015417652745406, 40.01377297985939, 47.18030806510679, 72.37288367363715, 67.90590024763539, 59.71757988775931, 58.21306459365353, 60.03000059435445, 67.8707165871897, 69.00333235340734, 66.66909064016035, 46.923326138527166, 54.41986591585221, 63.1819623516452, 25.15888244875016, 12.579140182464355, 20.64773117342303, 14.451605177694752, 33.12788740281136, 37.75120081440095, 48.997397038244436, 74.8188501788724, 43.48496467836442, 51.14821303275324, 72.90839702852311, 11.01134725155369, 0.49868514881499354, 0.15086333537774702, 0.24058533141449576, 0.019307424757449378, 0.0335785300440846, 0.03380831045609328, 0.05593864472522851, 0.04548979915618416, 0.06555121722480943, 0.056938776340816295, 0.09855306692301266, 0.024013644602570324, 0.08252647690354817, 0.03674558348833554, 0.19976436701272765, 0.30205866261836023, 0.35311511327182094, 0.1688293076210445, 0.33275317040181934, 0.44343409098444453, 0.2577905783489827, 0.18506865557884017, 0.14896394294356147, 0.19754761499502968, 0.30184688527257214, 0.30158089954526196, 0.2975029828808, 0.21111687074505517, 0.27637139743854927, 0.11708060459744547, 0.41459486429249093, 0.4437226303402455, 1.1304944993988162, 29.35736983053146, 106.51888109022572, 64.18541839045864, 62.31036855328468, 75.65077704768028, 79.7079590828188, 92.42826830956244, 82.15085044983896, 24.980298895989698, 16.245552166815727, 57.274629685186575, 33.14828765007758, 63.12176181424049, 81.33981412456882, 75.54301384956607, 78.84594763478925, 79.18594652606596, 41.55686478460989, 25.833118269520423, 80.1162229045745, 71.1102334914669, 93.19479357811713, 61.96244255188973, 53.839398276421335, 73.02715070786016, 53.26482595935945, 31.21489255659042, 23.81182089928658, 9.319576044236461, 11.684313204980667, 8.80007968794915, 15.633279988842627, 24.21352259574398, 30.451679729646255, 29.00265616755332, 38.464644647413685, 37.866310611847915, 33.54727506637573, 21.115638556018954, 16.638156906250988, 22.728695638718147, 27.138120243626258, 21.474113771992346, 21.854938653207597, 14.782176652262288, 7.1350046223209755, 14.16160866137474, 22.09902774903082, 8.777304445543598, 19.4199606680101, 26.051370713018603, 27.356317773942028, 33.430976790766564, 17.58856288848385, 20.70993604198579, 9.71521669818509, 2.567069684305499, 0.7745455349645307, 0.5074229025312009, 3.5512009407243426, 19.04234624678089, 50.383503821588334, 59.56596851348878, 66.1853604162893, 48.67227961940151, 43.37987653670773, 46.756029205937544, 44.17256401431176, 50.489686304523104, 45.40124254841959, 42.58625553500268, 40.47813846218971, 38.02352313072451, 33.26949673314249, 39.75392772305397, 36.139173353871996, 37.00222815236738, 29.11654022432143, 11.653117614407694, 2.7647448835834383, 4.651549573867552, 9.010105940603442, 2.246649794040188, 2.9338201207499353, 5.793319171474827, 5.417430102825166, 25.392124229861846, 24.689659110961426, 17.071733743913715, 44.18011849926364, 48.16186158887802, 54.04147486532889, 18.573789711921446, 5.340375140790017, 11.67819626869694, 9.409105124012116, 11.96780054799972, 22.32598981549663, 27.571473506189164, 33.057794647832075, 31.06626218365085, 27.228589711650727, 32.24454610578476, 26.933231315305157, 30.437902404415993, 35.441540595023866, 31.586409653386763, 33.53986570912023, 34.19283051644602, 35.4165707865069, 29.08939350035883, 57.95729075708697, 17.097291907956524, 13.113869063315853, 7.786622585788851, 1.7098923123651937, 24.848652385896255, 63.609124152891106, 48.77086054894232, 45.039482347426876, 76.49788348905503, 70.8581349157518, 64.45553633474535, 61.44258729873165, 67.60419153398084, 71.662048216789, 77.9615943662582, 72.31983753942674, 49.223066683738466, 60.03479373070502, 75.30756181286228, 23.03065146169355, 33.713783602560724, 33.85653042024182, 14.05777567817319, 56.23631162028159, 42.79217996904927, 76.69392355026739, 79.66031012996551, 53.30942723058885, 59.37187394788189, 91.13072472233927, 15.672098705845496, 1.0215573481494382, 0.3063916559180906, 0.43643483591656534, 0.169065676389202, 0.14951471419584367, 0.12163117452855073, 0.16164377061349733, 0.14212331404128384, 0.16286943468355364, 0.14016032098762451, 0.17888975810379754, 0.1353497637976562, 0.2532726054590556, 0.12531306204055587], [0.008164973715470444, 0.1430493458023956, 0.10856311648122727, 0.28869107185352233, 0.19849980099787637, 0.128712531239275, 0.02430827052692973, 0.12349414714281598, 0.024988401470886126, 0.19557817148104792, 0.13055008505621266, 0.05622540675704518, 0.0499380465536829, 0.04489911089260732, 0.02994924978983979, 0.03531688696614677, 0.02537663184827374, 0.10333049081025586, 0.039702070005718744, 0.07981037345504569, 53.249658153903106, 74.93349321426885, 44.30541469204811, 45.77404029907719, 58.80837055944628, 45.739645035036155, 37.394473014339326, 15.401347298775951, 27.468701524119226, 40.84218932736305, 36.23996650019, 22.96405746090797, 68.27435985688241, 65.20323422647292, 71.79585595284739, 63.717381569647024, 63.58337379270985, 26.001027091856926, 47.84899373208323, 71.0985291388727, 85.20506674243559, 80.70348016677364, 42.623820074142955, 59.00306132531936, 50.532773540865996, 35.63075965450656, 7.465356934455134, 4.204984297675471, 2.2165978195205813, 9.988691210746765, 22.6561317905303, 20.446570457950717, 23.64085655058584, 23.446573711210682, 28.13980729349198, 26.019197471680183, 19.47255769083577, 17.408990898439964, 14.483463648826847, 11.930647857727545, 21.378641320813088, 22.070247357891454, 18.163833387436405, 10.048736814529667, 6.622586183009609, 2.1171385242092997, 9.149642298298499, 9.655663351858816, 15.837305995725817, 19.152996309341926, 21.961615354784076, 27.66494554858054, 7.323968727742472, 11.85009119972106, 3.9568357938720338, 1.033760025616615, 1.0047248642771476, 0.6321143455082371, 2.0948342113725604, 7.949954982726806, 23.601958405586984, 43.86479131637081, 54.214804403243534, 39.51264312190395, 30.621626223287276, 28.141817508205293, 31.321143681003203, 34.841912177301225, 33.594100321492846, 24.040542148774673, 23.248947051263627, 15.895534561526393, 13.634537227692144, 11.27085518452429, 16.708871356902584, 15.845881277515044, 11.532444915463849, 4.427067916239462, 1.4476653188467028, 0.04527270132976194, 1.0141012901740691, 0.6681853196313304, 0.6482887292100538, 1.8886830153003817, 2.2791998280632884, 11.033770461236278, 10.34273022605527, 10.447523209356493, 29.230712575297204, 36.52172211677798, 15.537335872650148, 6.300796895257889, 6.279969599939162, 9.277589032726905, 9.73638573000508, 10.250860471879284, 13.630604071001853, 22.402815318876698, 19.95376975305619, 21.861453710063813, 23.159811189097745, 20.646676055846676, 21.682587746650945, 21.790197972328436, 25.25332723894427, 27.801971589365316, 28.929851093599876, 29.238394537279685, 35.94284695963706, 24.727327592911262, 25.055465236786876, 50.647216535383656, 16.85756644895, 9.846189541201438, 0.644010526518668, 1.973259367289082, 55.178205197857274, 24.09831081667254, 28.60562993634132, 76.1572648632911, 67.10444235032605, 59.58415262160763, 60.032801166657485, 59.274179474000015, 56.844557485272816, 57.3752777038082, 60.08101494081559, 38.09761278090939, 60.2579059908467, 50.05413847584879, 11.184413010074246, 27.615172632278938, 8.016407778186183, 18.851405266792543, 28.77950860608009, 35.395833215405865, 73.73473059746527, 48.84855877968573, 35.89957929426624, 50.451447117713194, 24.80286067531955, 0.28855191964295607, 0.12263331712493974, 0.05515895107941282, 0.05240982541093423, 0.09468492045397721, 0.05199716832008093, 0.08404861700030104, 0.04603044272610738, 0.014342977740471403, 0.033008231210612485, 0.088292874335762, 0.05116209800865862, 0.21329400069530935, 0.02782465048855351, 0.14857141481291863, 0.04171379391224154, 0.0664317740067359, 0.12709033239873188, 0.30214550634545667, 0.1959713890908226, 0.0637998023340779, 0.07447273245141392, 0.018547785378271536, 0.011524421523415275, 0.320992740171571, 0.15010329954806836, 0.08350025892498032, 0.03248397809182925, 0.03778365560837331, 0.11409908232669677, 0.052478746511042125, 0.03771226770514923, 0.11212106628884232, 0.06936546174749252, 0.49933034806482257, 66.4509048769551, 84.89407770095333, 43.586420705241544, 43.87561313567623, 58.20047770777057, 48.973882429061405, 51.95944155416181, 22.13943796773111, 35.24302944060295, 37.57524328847086, 38.16701127636818, 34.12717396213163, 70.6760584923529, 71.42491740565147, 71.81436954006072, 64.92489107193487, 68.58069696734029, 30.68551967220922, 51.22449528786444, 74.37574002050584, 78.17793661548247, 72.50018811994984, 51.25796879491499, 66.00937151139783, 52.205911528679636, 37.13517296698786, 5.314108498634831, 1.9752862520756262, 8.904486317788402, 17.54992165873128, 31.60081259665951, 27.050257190581295, 22.304199088004328, 23.08933404184157, 24.824319962532293, 25.256965237279093, 19.441937708085586, 17.84704512165439, 12.515433046125597, 9.959853945239898, 17.958128606119466, 22.444264965672648, 17.53098641672442, 11.61420181874306, 8.483094323065973, 5.205230857095411, 16.71286040736783, 13.785770093241046, 19.65824857834847, 21.287442291936568, 26.958818897124264, 34.21422704573601, 11.125403892609382, 15.122582489444365, 3.102000567220873, 0.6105406966901595, 0.12292758681841436, 1.3789408581872142, 1.1852515224487552, 12.712928306671882, 35.10554252132293, 56.440596503596154, 60.99217368710426, 47.33385316787228, 40.819706301535334, 39.45908315720097, 38.04365665681901, 42.92764686769055, 42.404218335305494, 31.952064767960582, 32.597075008576915, 26.54875078508931, 25.267326178089267, 20.676552749449208, 23.11117576014611, 23.37629464364821, 14.980958450225094, 8.79518751175173, 1.5645253514089894, 2.826565850165583, 1.995177449237916, 0.6728091199071177, 1.308217459628659, 3.4237587211593508, 2.4967185431911103, 18.884463002604825, 16.079719258892922, 10.623160081525004, 36.10634311552971, 39.16855712090769, 21.14435030568031, 12.460773837181831, 11.70103426902525, 16.72329979558145, 17.340347459239347, 11.622005374200883, 14.0095167967581, 17.87647662624236, 20.81018594003493, 20.587893455259263, 21.2074573193827, 17.17072456113754, 20.533192080836145, 21.321890507974935, 24.828867950747092, 26.043204338319843, 27.719337055760047, 25.7312366654796, 22.866878778703754, 15.369732995187084, 31.175206015186927, 51.62717757686492, 21.18216391532652, 22.063820554364113, 3.6371807657903243, 0.3253239255038, 56.74926742430657, 29.415503278855358, 28.123837363335397, 77.51942557673301, 66.12458721283944, 62.03132721685595, 65.08391572583106, 67.30212196227043, 63.48100777595275, 65.38926047663536, 65.02786505606868, 45.67828739843061, 61.26183271408082, 55.97434436121295, 16.892116646612845, 13.76610234860451, 11.80327476993684, 9.231456075945209, 28.634933963898693, 37.27885330876997, 69.34049929341963, 61.22795520290252, 36.380069640374955, 59.345723505943056, 30.024974884525424, 0.5508693115365121, 0.08767932217808501, 0.035119309060035214, 0.010774526782634278, 0.07925168085362642, 0.05571351063648059, 0.08960558131577508, 0.11068501149214084, 0.03045643063923044, 0.07506111095989905, 0.028183246669810147, 0.06502791022461268, 0.004402396556425599, 0.05082406554250948, 0.05641992031145961, 0.13426254713727584, 0.16413009364999112, 0.25278992410148343, 0.3725335116107618, 0.41321262717247015, 0.12370854450930512, 0.10959747307483228, 0.19896762024971748, 0.11954216001134728, 0.5331967662899725, 0.4771265766072658, 0.19743948934539673, 0.18597564239415432, 0.16156374506892698, 0.13599929910513664, 0.12317186927482968, 0.1162239574196358, 0.21778229533904986, 0.39170997938321483, 1.8729104293930916, 88.77381170949629, 91.80409369930145, 64.82803206289968, 58.09036893229331, 73.08701392143004, 54.230799828806234, 51.24001218426613, 19.49810016539789, 35.40960465708087, 54.13619226024997, 45.5399493248232, 31.0393919867854, 77.31478768010294, 77.94093916493078, 86.09305997048655, 72.53061002300632, 72.94693823783629, 33.73918094942647, 59.52937672215124, 81.49784641881143, 98.83443232505553, 87.78919481462049, 50.313112966475956, 71.09704648294758, 58.862260003243726, 43.46552933416059, 11.71997735577245, 11.50187788471099, 3.553474444535471, 12.795530480723228, 36.47976060067454, 35.02441613904892, 29.565916369038245, 33.89244756390972, 36.205924249464466, 33.067655486445275, 24.30369200245027, 23.04679789850789, 18.73886658299354, 16.359317571886127, 29.100660508678807, 28.817973329174905, 25.29769120677825, 13.995539430649051, 14.196227500515601, 5.610490143299104, 18.74822731940977, 16.53299620074611, 23.596294503058157, 33.63124516702468, 36.034528440044774, 43.803331698140795, 18.424304262284313, 26.144258322254306, 11.059764008368216, 1.9834033519990983, 1.1646694978398662, 1.7508966475725176, 2.791854835325672, 17.580331794677242, 44.79324379274922, 63.04500102996827, 62.23743992467081, 44.42503129282306, 40.44840297391338, 44.16621761937296, 42.38848570854434, 54.00536944789272, 45.81478195805704, 41.17098592942761, 43.42897676652478, 40.53517364686535, 37.40944470128706, 35.34968653032857, 35.75252963650611, 36.01382224790512, 20.807336338104744, 7.332174326142958, 1.4941607271471333, 5.583310079190039, 7.278787926320107, 3.3473727683867183, 2.998794427802486, 6.054677482574217, 10.574144182666656, 30.666421651840214, 29.077271415341286, 19.37227641382525, 41.19526932316442, 53.50394933454452, 20.658009744459584, 11.634690319338153, 12.19056862015878, 15.021290221521932, 22.333663932738766, 19.265695810317993, 27.237315024099043, 32.45383789462428, 28.998412163026874, 29.73292304623512, 32.64240780184346, 25.247545665310277, 27.563016876097652, 27.473047510270153, 32.46325158303784, 35.95612810504052, 37.66509694437827, 39.037800988843365, 47.53524726436984, 33.71501130442466, 30.106789642764678, 61.860347178674516, 19.3448394344699, 16.621867302925356, 1.6189042334595036, 3.176078695443369, 69.43826044759443, 31.78302041945919, 37.4374072782455, 83.18030003578433, 70.98968336659094, 71.54589114650604, 73.86904039690572, 69.38304132030856, 67.43194457023375, 67.34092204801499, 69.87123520143571, 47.5158432991274, 68.11850840045561, 60.48935328760455, 17.92698302576619, 39.845009080825314, 14.44464591241652, 29.997839927673343, 41.1677578187758, 53.90550198093538, 88.76767712254679, 66.59824479010798, 49.92541413153372, 71.3939542155112, 46.20811331656672, 0.5945819207737523, 0.20524762600900667, 0.20607078748364605, 0.1442848464413997, 0.24051681251054813, 0.1274360755398389, 0.09788323028553879, 0.2099222025924152, 0.1011492316460898, 0.1280225694720303, 0.23930139869691866, 0.1639134439850046, 0.33301155653692066, 0.16164536407637983, 0.267500497641102], [0.05037060660880901, 0.27850317498368604, 0.09802625890100196, 0.2507713896733138, 0.2269789050783842, 0.22150657049590544, 0.04052285660779284, 0.06558049710527544, 0.1092160149146953, 0.07043007115322737, 0.1813820413043422, 0.0280978144597142, 0.08009935714184277, 0.08197367551826662, 0.14525148086249828, 0.06556401089314493, 0.062434384674434705, 0.1909265928571263, 0.16061964895456068, 0.6491058079465744, 12.285163441011983, 71.18917511355492, 62.14765294905632, 48.648164887582105, 74.76658851869645, 64.96301651000977, 27.110991170329434, 60.18921352201893, 30.599304014636626, 38.75001276693037, 44.17530575106221, 21.215759015852406, 50.03063955614644, 70.32619091772264, 63.29721335441836, 64.16958378207299, 73.875488773469, 74.70377568275698, 47.339826937644716, 65.21580150050502, 61.071433021176254, 67.41570595772036, 49.003159000027566, 59.29450911860312, 43.718737940634455, 29.83988411964909, 0.7774186711157522, 1.2688741256152432, 7.422735969866476, 27.494367553341775, 24.57316863921381, 20.94810628121899, 24.6383447031821, 25.013299757434478, 29.71392308512042, 26.531847330831713, 27.803691548685876, 21.02326673846091, 14.399757327571994, 10.81573276750503, 17.553812649942216, 20.30450221030943, 22.20291172304461, 13.597827765249438, 7.71516876835977, 7.510099411010743, 8.359993676985464, 18.16214676826231, 17.454272700894265, 20.63621117222694, 23.79392508537539, 29.362988625803304, 9.754991492917462, 14.466232676659862, 5.484648250764416, 2.0887542924573346, 2.088799399714316, 0.9733515413057421, 5.1791216000433895, 17.084824654363818, 31.287366190264304, 42.70536222765523, 45.42115642178444, 31.92435714506334, 21.515284930506063, 26.1610911738488, 29.382747565546346, 33.01813948538996, 36.66482979251493, 24.902541829693703, 21.379923935859434, 19.394700604100382, 13.984521492835015, 9.97133570332681, 14.577316161124939, 16.263178317777573, 12.502168570795368, 3.835568120402675, 0.920668594058483, 1.4578655650538783, 3.3395623487810937, 3.24428724185113, 1.810216490299471, 2.4037260105532985, 2.906493458055681, 10.541621850382898, 13.525294315430427, 13.851095207275884, 29.48512927178414, 35.86246190532562, 23.475159945026522, 18.295579917969242, 20.092892300698068, 10.94539357769874, 6.011399520981697, 5.082360159966254, 8.620186063551134, 17.146758879384688, 20.490959921190818, 19.88026845839716, 21.183117051278394, 21.5138199252467, 20.463564126722275, 25.704884221476895, 29.207413696473647, 23.976050538401452, 28.622868753248646, 24.356006614623535, 33.72091054916382, 61.83039203766854, 31.961409814896125, 33.482752077041134, 47.41264181752359, 19.62818164979258, 10.15163137066749, 0.27364562596044234, 9.434302429999075, 56.23456224318474, 46.765266387693345, 43.26198970117877, 49.481558722834436, 62.9357865548903, 56.85222571895969, 57.375768000079745, 57.82589527868456, 63.01098231346377, 51.15328857975622, 41.98312836308634, 64.7305376298966, 30.164717166654526, 17.106393767941384, 12.739146409496186, 4.118857874024299, 35.112936189097745, 44.0877466817056, 42.54149344659621, 74.50926534591183, 41.72793503730528, 49.59784130896292, 65.86992340703165, 9.002004285012523, 0.3367277877705713, 0.1612127848690556, 0.17036034965947752, 0.006854892023012884, 0.18215176048538378, 0.048709444536436955, 0.046635115924741954, 0.020212858329497038, 0.09436864105443801, 0.059802677302110585, 0.07477971920443159, 0.019232193008065224, 0.10465268195877153, 0.02026947988798061, 0.12169306677195335, 0.03542461041961947, 0.1335812957897302, 0.1781848193176331, 0.21457025721188516, 0.07104558449599051, 0.218942137134652, 0.007386146227814138, 0.049449194357880664, 0.06653817595853921, 0.10985358392879849, 0.21727753532749994, 0.1655258445609962, 0.19713541372649132, 0.028653390998501452, 0.009615585140343155, 0.06289601393584764, 0.027524280819981813, 0.14844012266445547, 0.255305802810096, 0.6568694655453006, 16.444214332488276, 83.96966918822258, 66.22925173851752, 48.58835266482446, 71.46709857448455, 61.41747628488849, 29.355779309426588, 43.11718756152738, 37.74306581866357, 37.7403554608745, 39.54980757928664, 32.97989637620988, 57.66385432212584, 73.63800494901596, 67.06778387869558, 70.70360137570289, 75.8098840713501, 75.14655636202905, 50.94472439058366, 72.21603593518658, 69.12305093580677, 70.53795183858564, 51.879425202646566, 65.34279215720393, 48.09457332857194, 30.26238810631537, 0.18328733261554472, 7.027538543747318, 17.893580121378747, 31.010670431198616, 26.05060192846483, 12.249056062390729, 18.250082385155466, 22.24785424047901, 27.234257536549723, 25.132063242696947, 26.96576737588452, 22.570345632491573, 13.323384427255201, 9.284727746440518, 13.53998359172575, 17.399026117017193, 16.852345774250647, 14.089810655963037, 7.9295253176842975, 10.02718044865516, 13.18448349352806, 22.67495720617233, 21.22331742317446, 22.26053330206102, 24.91780573321927, 34.25299183014901, 13.151560098894182, 20.323749280744984, 9.30013579706992, 1.1796022062340092, 0.8047776320768941, 0.956091519084669, 3.136470356295186, 8.805081690511397, 30.827028982100952, 53.33991973630844, 58.4617663967994, 40.09564069009597, 35.40687860981111, 36.27018051762735, 37.48784503629131, 43.206107693333784, 42.976162664351925, 31.552428199398904, 34.28033467262022, 27.625559068495228, 27.064805261550415, 21.648029704247755, 22.42769883524987, 21.434360550295924, 15.361303821686777, 6.536817675636661, 0.9939795311900878, 1.7764659658555062, 4.396763684288148, 1.3855355881875562, 2.3477167708258477, 3.195130627962851, 3.0258416216219626, 15.360372258770852, 17.96722262136398, 13.192637120523761, 33.50019485719743, 42.88243370671427, 22.596715727160056, 18.578884870775287, 21.219548025438865, 13.906269227304767, 9.564859501777157, 6.30084200251487, 12.092939845977291, 16.04684881625637, 20.2313696184466, 19.057555237124046, 19.5808425641829, 16.94249556910607, 20.25495875266291, 23.641692015432543, 29.47577638010825, 23.45657575515009, 26.17871242184793, 26.1473197321738, 42.120889848278416, 58.50777972129084, 36.06728807572396, 36.54668800292477, 48.67541359316919, 20.445929150427542, 24.118595354018677, 0.7552691080397176, 3.95507661084975, 56.417968350072066, 47.26604323233328, 47.98232686135077, 53.13173209467242, 72.18617100869456, 63.63728677072833, 64.58153463179066, 63.38867518209643, 68.05982974267775, 54.89439818166918, 46.83050324839931, 62.85357759844873, 40.79947471618652, 19.982689388336677, 13.589785925803648, 6.759637228904232, 21.277408869035785, 31.345256451637518, 40.47624787976665, 78.0831015494562, 54.029586161336596, 49.17107958947459, 77.17548078106296, 11.663418739072739, 0.4851797541543361, 0.10759016949563258, 0.04547918117755363, 0.015654936827148403, 0.06294657190841052, 0.01970828983992819, 0.018868906453492183, 0.03700461696773287, 0.08896771352738143, 0.032954559090637395, 0.06587481276402551, 0.040929959561195106, 0.08067553186969412, 0.06810288756124436, 0.13313432945118797, 0.16335363289521587, 0.3943223085614943, 0.15189223742533117, 0.32791305753973227, 0.32245808250961766, 0.4523960020272963, 0.11161318063856134, 0.1333121078148965, 0.19756702766303094, 0.2097300370974887, 0.33577014722170373, 0.2958565986444873, 0.31857594727508487, 0.17765293979356367, 0.3779248094126102, 0.176011351267657, 0.21356596190842891, 0.41234005302671467, 0.39380139941650055, 1.1355354805146496, 27.918609149994392, 99.10135746002199, 78.77463110031621, 70.67680374268564, 89.9589244781002, 82.31356605406731, 37.38065058185209, 81.19937758291923, 40.386747237174745, 53.39349146812193, 56.17385179765763, 27.75473056300994, 61.28919516840289, 82.07729816436768, 72.38709049840128, 77.76984537801435, 82.38990322236093, 84.61006672151628, 58.53430278839604, 80.62798238569691, 76.79945099738337, 80.1010041083059, 56.17114536223873, 73.12196223966538, 52.513746984543346, 37.49788238156227, 1.300462198353583, 3.417938904416177, 12.650809730252913, 39.71261732039913, 34.17282642856721, 28.392101987715694, 33.91173778041717, 34.03227613818261, 36.05316362073345, 33.54795363641555, 34.773592333639826, 28.08384095468829, 19.074776403365597, 15.556535874643634, 25.711177664418376, 25.72236426414982, 29.02158944837509, 22.40171705522845, 14.686514946722216, 13.383194688827762, 14.855568120556494, 27.613050630015714, 28.2272094680417, 33.4991358172509, 35.64630400749945, 40.76658956466183, 19.231153457395493, 25.608591994931622, 17.36990251848775, 3.695503958771306, 3.9300197747445877, 1.347721365671004, 10.98451235601979, 31.17136601478823, 43.18523676164689, 55.60650840882332, 57.310182048428445, 41.96843124205067, 37.88515760052589, 44.052727760807166, 43.501003249999016, 50.67980358677526, 49.01505162639003, 38.992744722673976, 41.054946530249815, 39.45662383110293, 39.55295332016484, 38.24283853653939, 33.646981716156006, 36.0466956323193, 19.83980332651446, 5.368530404183173, 1.9955739763475235, 5.012721909630684, 13.087948080032104, 8.593775764588388, 5.1421419843550655, 5.023480971013346, 11.188544246458239, 22.190413090490527, 36.4423333444903, 23.19155296971721, 44.51907011770433, 52.249555741586995, 38.347491295106956, 27.16663979714917, 25.51245862437833, 13.493843770796254, 11.559314131736757, 10.910129508664532, 20.563176639618415, 29.040865936586936, 31.515446132229222, 29.736865028258297, 29.5820745729631, 26.7219606907137, 25.97665152242107, 30.36666039497622, 36.84438020952287, 29.022699479133856, 33.818722694150864, 28.588877493335357, 41.0017748801939, 70.14908021496188, 43.65388154983521, 38.210129891672445, 60.054915489689, 22.501500191227084, 18.550839924043228, 0.35299682929631204, 14.179492708175415, 70.42530921197707, 64.78826707409274, 57.16204981650076, 57.126069914910104, 77.36350351764311, 67.8026242409983, 68.73316734067856, 67.28331811966436, 73.28170468730312, 62.405639002400065, 53.48478855625276, 72.3624344794981, 41.007544686717374, 25.379072543113466, 22.956950126155732, 9.498366502023513, 53.294177055358894, 62.87666859165315, 65.7721975541884, 85.6541310587237, 61.590837201764515, 61.007145374051994, 91.41159780563848, 16.512858752281435, 0.7783802646783091, 0.21142872981727126, 0.38523494296016236, 0.0958499946301022, 0.43048478422626374, 0.25427181393869464, 0.159806952240967, 0.13821664867141556, 0.19470101612950527, 0.19391687917372874, 0.2531828965631224, 0.14396206295538333, 0.3054795822789592, 0.18329899247375228, 0.16944427704138143], [0.0842309459262798, 0.09056890623704081, 0.13533226634946563, 0.2919412764810747, 0.26279549204534103, 0.08333657657907856, 0.10848650768879922, 0.05155751812121561, 0.104364441377261, 0.10149472963906105, 0.06392703804698202, 0.31126679432007576, 0.03379741285537039, 0.0662522642843185, 0.09754297999484886, 0.026458252236367236, 0.07250672101133293, 0.023933419875139673, 0.10930654352470752, 0.03663356228160762, 0.2655356659764244, 41.96979230450046, 63.7808023729632, 50.05329908863191, 54.35327191506663, 92.29368394420993, 45.99501486747496, 56.2844979378485, 45.99303014816777, 38.037298494769686, 50.620473815548806, 24.74748661441188, 39.66510957287204, 75.46139717102051, 74.79770075890326, 67.69373924501481, 70.81985258287, 74.15906829218711, 72.36503108855217, 66.89872187952842, 64.45462634486537, 64.83217016343148, 85.6722524089198, 63.4080320788968, 54.23839745983001, 12.577755585793527, 0.3539718140757853, 6.886804882557162, 17.154901719862416, 28.073817337712935, 26.388686703097438, 41.76813148683117, 25.451383398425197, 23.282010670631166, 24.366706840453613, 28.0620345377153, 26.71655958698642, 22.30745465524735, 13.10568601854386, 8.898391935133166, 12.357218361669972, 21.663434813099524, 16.72800663978823, 12.768179793511669, 8.833539466704092, 6.432357603503812, 15.803133326192057, 28.37617128126083, 18.44693437699349, 22.456139941369337, 26.211615224038404, 32.485924843818914, 11.759562896144006, 17.819553229116625, 7.413185488793158, 2.85912127744767, 1.5759876202191077, 1.1211356015936023, 3.030820825407582, 17.998685913701213, 35.112241929577245, 38.23149504200105, 42.381201867134344, 27.008219188259496, 18.040802363426454, 25.077354023533484, 29.493978138892885, 33.24439356403966, 36.02444402633175, 23.22874096132094, 22.789311947361117, 16.2611484912134, 16.400840763122805, 10.218601918989613, 13.81685487685665, 18.518523516193515, 19.562172082162675, 5.081041262995813, 2.810062477665563, 4.68269270273947, 4.512124023129863, 1.7878397361886118, 0.42641048349680444, 1.4592727153531968, 3.338717813453367, 11.31424444337045, 19.3740120626265, 14.744558180532149, 22.251990379825717, 35.286795246985655, 30.478371458668864, 20.737284768012263, 23.823409541960686, 23.066547032325502, 19.471380979784076, 11.81038308528162, 11.794204288913358, 13.98014706950034, 16.49094839249888, 20.173593105808383, 18.54151056658837, 19.59950520146278, 20.56107621039114, 25.94500191750065, 21.6475413691613, 27.147137772652414, 30.305085066826116, 25.416623353958133, 15.762749583490434, 26.87695707044294, 23.956330822360133, 29.481273581904752, 34.15694867410968, 45.02781329616424, 27.611858229483328, 3.9858081360017104, 0.5906898263962038, 28.159750584633123, 58.91263108099661, 46.22504226623043, 58.3239499984249, 51.50390532708938, 64.1225427965964, 57.06471620067474, 58.37153227098527, 57.350433411136756, 50.45165500333233, 46.88886027182303, 55.16018190691548, 23.4746108132024, 22.761998522666193, 4.317207720971877, 7.121344968195885, 74.01751779740857, 118.0768665190666, 60.31751425035539, 66.32160786659487, 36.97217102973692, 61.71840836924892, 54.41683784607918, 0.747274827332266, 0.20052656321035278, 0.04675472906279949, 0.11197865820459782, 0.047434019225258986, 0.08032192100560473, 0.013987508155555736, 0.016424141771670793, 0.03290740254845831, 0.07055916462934787, 0.09330558680718945, 0.09513973153286404, 0.0917782602951892, 0.05352534135923751, 0.14423324275882016, 0.09249066843861535, 0.14780073036109248, 0.07780623381897327, 0.239795602016872, 0.12634734202536846, 0.10551899716618562, 0.1206484675828007, 0.11239956989283524, 0.03580318425872153, 0.0518776624343328, 0.10402322581578648, 0.20003942322106133, 0.14544913154696265, 0.07955974779061734, 0.020621817130895875, 0.10077393283286404, 0.07538433111603222, 0.06577865340776982, 0.07842183909228734, 0.07830521752757412, 0.03480641959956096, 0.16329314259271469, 51.69854510215021, 79.96523518716135, 54.530916060170824, 63.60052631747339, 85.41918108540197, 44.14446023202712, 46.4178502944208, 40.62756507627426, 42.66153758571994, 39.83219861984253, 33.563976518569454, 46.941941707364975, 81.85775526108281, 78.98428963076684, 75.49207010576802, 80.20202867446407, 78.18874666767736, 75.56673634436824, 74.99760827710553, 72.25886037272792, 68.27418727259483, 81.88441168877387, 68.25799572852351, 59.31290895708146, 7.368859273772086, 0.6920585192499623, 21.266526252992694, 18.02714074811628, 32.746499661476385, 12.627952118073742, 25.52977784987419, 23.482524195025047, 24.515333291023012, 22.727964116681008, 25.927776828888927, 24.715933107560684, 25.298811043462447, 13.749812745278883, 7.956961316447105, 8.067657466857664, 21.406041037651804, 15.952896283518886, 15.027293409070662, 9.578490718718498, 9.134249937149788, 20.919665175099528, 30.830733660728704, 20.9291337766955, 20.714191813622755, 27.472261075050604, 39.28685188293457, 15.072410471977728, 24.316659358239946, 13.737413152571648, 0.8226890128947074, 3.354865230860249, 2.7608565890019943, 2.8575834631919865, 20.726851263353904, 39.870339747398134, 55.19352205338017, 49.09330291132773, 33.13150775048041, 28.905283328025575, 34.64446006282684, 37.31156587600708, 43.0141665089515, 45.36526264682893, 34.214897771035474, 29.417786098295643, 28.01041614624762, 26.097909635113133, 19.63806994499699, 22.183176317522605, 23.87841097770199, 18.793109040106497, 8.297810381458651, 1.8892403595870542, 2.9175327237575286, 3.4331510816850974, 2.826488138206544, 0.4146062330372872, 2.1433867802543025, 6.790715638668307, 15.980358758280355, 25.486357212066654, 14.275097539347989, 26.663387936930505, 41.604431367689564, 26.635803868693692, 20.301962475622854, 24.756186431454076, 23.540473291950843, 20.155838497223396, 11.038232157307288, 11.773049965981516, 15.678076397988105, 14.239728546911671, 17.678053725150324, 15.518233929910968, 16.76758727719707, 20.32736570604386, 25.60378905265562, 21.152571593561483, 25.7613447789223, 31.740586257749992, 28.624657354047223, 20.87830182044737, 36.80990649807838, 21.35841169664937, 30.51807368955305, 39.64598409591183, 44.56641704805436, 28.891578566643503, 15.899639321911721, 0.13138118320174758, 23.233328173237464, 65.62447324875863, 54.60967333086076, 67.54013138432657, 55.31494686680456, 71.45024022748395, 63.98856639862061, 64.69564422484368, 62.72616724814139, 57.09855056578114, 52.98955402066631, 60.084607831893436, 34.0361592846532, 27.31386596156705, 13.054825625111981, 11.186306534274932, 74.9723482131958, 101.84549470101635, 59.02216719042871, 74.49661962447628, 47.50722192948865, 67.36739020193777, 63.69400032104985, 1.6027813308661985, 0.2275496865472486, 0.05437448853626848, 0.054350789606330864, 0.06257514183920238, 0.05994737598924868, 0.0573191658082989, 0.05817837171977567, 0.04457463818271795, 0.07170756107136127, 0.05947220229333448, 0.012184690680324793, 0.00513475458700991, 0.03674377169039461, 0.12228661637392738, 0.05801662757632233, 0.38869407508642445, 0.16126250397534142, 0.350128565464289, 0.48014502431596484, 0.25197518959401116, 0.36680105953447284, 0.2515169157977066, 0.1342624705284834, 0.22354315395557114, 0.1677618407073521, 0.2869733188661837, 0.4120399610650155, 0.20674886722718516, 0.16507426637314981, 0.21738832696310936, 0.11543486387498918, 0.18703095915336765, 0.24542585796406194, 0.311032340771729, 0.3070605732500553, 0.616793261180001, 72.47607338813044, 90.48216865908715, 74.21349510069817, 76.89388598165205, 105.87729900113999, 64.37442564195203, 77.19739114084553, 57.154216843266646, 50.076911757069254, 67.52256701069494, 30.609931676618515, 50.547623634338386, 87.45988045969318, 92.43623072101225, 78.8432647335914, 86.10989478326614, 84.75671629751884, 84.85536390735258, 81.89521389622843, 77.6726019767023, 74.7662119711599, 92.46727235855596, 72.27753085474815, 65.35220584561749, 13.153280058214742, 0.3952655773009024, 14.043901274281165, 20.144881356147028, 39.9226406312758, 38.412853671658425, 59.23637174790906, 32.77435045088492, 29.501711091687604, 29.90968465805054, 35.94531805284562, 32.24129249972682, 30.51085848962107, 17.856774560866818, 13.436950772039353, 16.186412630542634, 32.04828246947258, 24.199335382830714, 20.762687998433268, 13.314756193468648, 10.788960629893888, 21.220446248208326, 38.957219816023304, 27.55494659946811, 31.038464346239646, 37.926950454711914, 47.369476133777255, 20.465299775523526, 31.539676573968705, 23.16694990281136, 7.291036507775707, 6.001680868287241, 3.082496826687167, 7.0794824919393, 39.560448969564135, 54.80897288168631, 57.230165696913204, 55.26408549278013, 35.021674402298466, 35.62192647687851, 42.446022956602036, 44.77062348396548, 51.777376897873424, 46.739861196087254, 43.35115694230603, 38.68376393471995, 39.37967477306243, 39.30323562314434, 34.70177373578472, 36.17003848475795, 33.51804164148147, 22.591024368040024, 9.133357597935586, 7.798611800516806, 11.105095821042216, 12.396394994951065, 4.194035981931995, 0.3847884362743747, 4.5153271286718315, 12.737416644250194, 22.2747048254936, 39.07823670294977, 22.72263949917209, 36.377269068071925, 47.51007349260392, 41.13332333103303, 30.32151391429286, 31.422317297227924, 31.86707485106684, 24.638174080079605, 20.108777899895948, 20.681777346518732, 26.076113024065574, 26.42957937332892, 32.177159786224365, 28.12013464589273, 26.308666429212018, 26.62068901523467, 32.70930970868757, 28.086390495300297, 35.80941184874504, 40.43198785474224, 33.821735074443204, 18.7782177617473, 31.73566956673899, 28.427807323394287, 35.59554853746968, 40.25125680431243, 55.83935206936252, 31.990874659630563, 10.39045762631201, 0.6694128989211975, 38.2060702385441, 75.4077705260246, 57.44954778302101, 72.70829339181223, 64.86321964571553, 74.94376982412031, 67.11472680491786, 67.73509671611171, 67.41173651910597, 61.19099863113896, 59.2793099341854, 64.51225380743703, 32.504687501538186, 34.0725157337804, 12.80855961384312, 14.485463077022185, 96.03204788700228, 128.89238649798978, 71.536375476468, 81.53535996713947, 55.424141730031664, 77.13369969398745, 79.11103710051506, 3.482912721172456, 0.35297957699625726, 0.2741084043537417, 0.15259428039914177, 0.21046941919672876, 0.4010940048723452, 0.24382003042246067, 0.20268127742794254, 0.1551239946556668, 0.14762275281452364, 0.15054442829662754, 0.2388777214312746, 0.1568654657251412, 0.12877052409514306, 0.3044430346738908, 0.14319099545959504], [0.1209784216517883, 0.16036664075668783, 0.21531916944490326, 0.1596853587656252, 0.15621242173496755, 0.024349011082742966, 0.11716774709883238, 0.15388685458850476, 0.09882336572533655, 0.08462231726415696, 0.053206464921635006, 0.18435162792523063, 0.03867620166631476, 0.09534468303524679, 0.04851709901084823, 0.06895532125547048, 0.06845135031448257, 0.05451289381110861, 0.03269549496772309, 0.08188000594776484, 0.5977227586892344, 3.3460558326013627, 58.882817145316835, 60.14184697981804, 37.561538527088786, 69.04650195952385, 70.75995799033873, 40.31885100949196, 65.94627626480596, 36.842517083691014, 53.41533514761156, 30.353396900238533, 35.13307755993259, 61.00169720188264, 65.81102509652415, 67.20991488425963, 63.95506935734903, 75.59941753264397, 69.37543192217427, 68.66837763017224, 70.35854262690391, 74.1743576911188, 87.40857585783928, 58.83895327967983, 28.83358044009055, 1.1466603029158808, 2.5660859048366547, 13.675370081778496, 31.909969891271285, 30.661142141588275, 67.0549028150497, 23.359812844184138, 14.63105361307821, 22.706624461758523, 26.834371897482104, 29.250722546731275, 28.30831035490959, 24.16173161998872, 16.374802108733885, 9.273920636023245, 10.290645072537085, 15.345304473753899, 13.617168972569129, 12.91930087151066, 9.361897437803208, 14.471433739508353, 14.321769822028376, 39.32000767800116, 21.874499513256936, 17.957289218902588, 26.50228442684297, 29.913199101724935, 15.30271439783035, 18.400907324206447, 5.591469099444728, 2.2348765548198455, 0.19397859521690877, 1.3717717461047636, 2.120752498026817, 8.788177255661257, 13.494462524690936, 26.44643968151462, 34.398617667536584, 31.263898649523338, 18.5240795535426, 18.73878029084975, 28.61801874253058, 32.88513387403181, 32.87349816291563, 23.07514879011339, 28.25786279093835, 18.710523536128385, 17.353634488198068, 9.654725905387632, 13.568997363890372, 18.21102342297954, 18.601922911982385, 5.665680343104947, 3.669114007103828, 9.470380390844038, 3.8801723334097096, 0.41867403734114866, 0.5407104340772475, 0.5602703748210784, 5.585684584033105, 13.393546804305046, 27.33188925250884, 20.716749198975105, 22.833462146020707, 38.124532007401996, 29.556994938081314, 28.201031569511663, 24.78668482072892, 23.676587381670554, 17.940615223300075, 17.515006680642408, 14.117944836616518, 13.034336143924346, 15.236008609494856, 17.09822347087245, 16.365359002544036, 15.753915425269836, 19.362692102309197, 26.078050674930697, 27.393919575598936, 28.3589187360579, 18.431125264013968, 26.912987962845836, 31.4310484932315, 25.612761474424794, 40.55007865352016, 30.535296816979688, 28.315070559901578, 37.32317216934697, 22.653184129345803, 11.146992618037808, 3.546105536722368, 3.8110515907887494, 59.36893217025265, 45.169606977893466, 62.67954595627324, 55.342238718463534, 57.55140389165571, 58.0464344639932, 62.84128096795852, 57.123343867640344, 52.8124511626459, 53.11845094926896, 49.3025182139489, 22.55995527390511, 26.972351074218754, 6.436499136109506, 29.613512369894213, 75.45664325837167, 82.50770768811627, 79.4552250831358, 53.93878329184748, 36.9004112674344, 66.15918251775926, 35.19962056990593, 0.36867215268073544, 0.07264648609223866, 0.1492274312242385, 0.13498171983707336, 0.05333946161572972, 0.013437298062678068, 0.10205526851237783, 0.07666660908369288, 0.027463721569567442, 0.0819621995211609, 0.012872775532155028, 0.040205795798570886, 0.0880115821717247, 0.07008268858396238, 0.21636184575336598, 0.061126312526363524, 0.10077240831789472, 0.10725224045135322, 0.3341689621729236, 0.12718308266372452, 0.17144151422525608, 0.146882374800982, 0.025162144466453505, 0.06312764445019346, 0.16769597246762247, 0.1769724392121838, 0.14579633791600505, 0.13803214405573186, 0.06346355485279234, 0.04136667564331044, 0.008333672022056437, 0.1157706402122013, 0.08156974033843126, 0.06143034217999347, 0.15370533771572575, 0.07450828659197978, 0.7246729046587022, 6.871512051551574, 80.62951211006411, 70.66125546732258, 48.0774914064715, 82.98405601132302, 62.338068331441576, 37.645724358097205, 49.61969283319289, 41.342907336450395, 47.078863805340184, 33.82842663795718, 45.835809784550825, 63.8272040121017, 75.09695406882994, 74.8884173362486, 71.88875336800852, 80.89402890974476, 74.05018329620361, 75.45570973427066, 76.27139014582481, 79.3287286450786, 82.12860276622158, 65.13347487295827, 25.817628829709946, 0.7421201587684694, 13.074649283962867, 21.262131237214614, 32.5615148005947, 34.13166115360875, 70.6111668002221, 36.18084853695285, 18.355007748450003, 23.012745841856926, 23.717648713819443, 26.828957065459225, 29.732377836781165, 25.528810985626716, 16.64758236177506, 9.356478683410153, 6.63587321196833, 13.406033669748615, 13.859158619757622, 13.199495384770056, 10.219124574815075, 16.50126814842224, 21.07983123871588, 37.1981034740325, 18.31938478254503, 20.260514790011992, 25.375754217947684, 38.79566523336595, 16.20307387844209, 29.009018251972815, 12.86822965068202, 1.5098275316338388, 1.8220011289081268, 3.0417296723012, 3.9250020827016527, 21.01356867820986, 36.98072964145292, 48.535102567365094, 47.044401861006214, 33.40705817745578, 27.052677292977613, 34.1477781726468, 36.29635841615739, 43.89007491450156, 39.44167175600606, 33.62800136689217, 36.50362822317308, 30.23913041237862, 26.044271223006714, 21.377437153170188, 21.30590096596749, 24.417183822201146, 21.438855586513398, 9.575563649977408, 7.109178266217632, 5.506451235663507, 5.796965014549994, 3.896568085878126, 0.6023722995192774, 1.3723104591331174, 8.729267178043242, 21.793800669331706, 36.582989538869555, 17.334809072556034, 25.11042352645628, 41.85647503022225, 32.09463115661375, 22.307050651119603, 26.417816185182144, 23.818981186036144, 18.314936814769624, 20.596316745204312, 14.739211009394738, 13.907447899541548, 13.769924698337434, 12.00353922382478, 9.357650491499133, 13.478939744733996, 17.017979621887207, 25.049897432327274, 22.60500957888942, 25.468765381843816, 18.748562682059504, 23.982685227547925, 25.792845333776167, 23.848516633433682, 34.363830166478316, 30.874428864448305, 31.532867339349565, 40.74926053324054, 24.167440629774525, 19.996284323353922, 11.70563913160755, 2.4000691358120214, 55.10755546631352, 56.59882491634738, 70.42345785325574, 66.83641895171135, 65.13922899000107, 64.58170329370807, 68.15055416476342, 63.95299834589805, 58.63661389197073, 56.852139426815896, 53.712493911866225, 31.548578393074777, 31.199369776633482, 14.284256273700347, 34.620953298384144, 87.59652799175632, 80.93630421546199, 77.4474657735517, 64.76089285266015, 43.723676204681404, 73.18138614777597, 42.202255495132945, 0.3935019509686578, 0.05855894121792048, 0.037800635947214986, 0.08398345356146175, 0.06844530588076, 0.207508182934215, 0.3104496849400382, 0.02594550192776707, 0.06800055353631897, 0.03128089637856089, 0.03502868851947208, 0.03949825997434316, 0.10341995455805333, 0.04116751576563524, 0.21311930200505644, 0.09851569715406626, 0.22805797056325022, 0.40317681407736194, 0.3551924372872999, 0.125805618271472, 0.43818093415710235, 0.27419307239113316, 0.14667291104072525, 0.18260002917339727, 0.34468636878075143, 0.2785721228968713, 0.2992681413888931, 0.33090509053680206, 0.12970193379348324, 0.3267521585427946, 0.19911821781387254, 0.2682012535871998, 0.38631316574831165, 0.20551347384049048, 0.24836115448945956, 0.22858926786049721, 1.1621409173934691, 13.790648541142865, 104.89159168735628, 84.83081771481423, 63.756566047668464, 87.66510671184909, 87.92336340873473, 59.64077203504501, 87.57742604901715, 44.82197515426144, 70.77702814532866, 40.13547235919584, 48.283717863021366, 71.31737386026691, 79.40548158461048, 80.88393272892122, 79.28273493243803, 83.97189709448045, 83.25220492578323, 80.79593043173514, 83.88863302046254, 89.95227213828795, 98.22268378350043, 71.6825779022709, 39.16856496564804, 1.7847980606940486, 6.519403822960393, 21.704696186127205, 44.39692358816824, 46.50346386817194, 75.91609401087608, 26.58571912396339, 17.425976722471177, 29.2966809580403, 33.0412422457049, 35.991025432463616, 38.89084939033755, 32.514805255397675, 21.841755567058442, 14.041140906272398, 15.38363975863303, 23.49913151033463, 19.411941382192797, 18.81139316866475, 14.492198767200595, 22.546785916051558, 19.073717363419075, 53.61119870216616, 28.497547065058065, 28.420925524926957, 38.48303664115168, 40.849994844005955, 20.261656199732137, 37.581848559841035, 22.436565353024392, 8.285526498671501, 4.06061043181727, 3.535160407904656, 4.570029973983765, 21.82450302185551, 37.054544725725734, 51.79699267110517, 57.7061100159922, 45.97796040196573, 35.550049043470814, 42.11036220673592, 44.761649101011216, 48.64695679756903, 46.46211816418556, 40.208004828422304, 45.34946333977484, 41.81074803875339, 38.06918344190044, 32.0090058157521, 35.72090356580673, 33.79769094528691, 20.465693973725845, 12.00163491310612, 17.230832922843195, 15.672003588368817, 10.919199989688012, 6.285552603583183, 0.6473226004069852, 3.783276552154172, 12.339448063604294, 28.627355944725778, 46.936093453438055, 28.240565138478434, 41.22729939799155, 49.50779153454689, 42.29514114318356, 37.434532180909194, 34.27909912601594, 29.597477720629787, 21.461756344764463, 26.8502555354949, 22.091516410150838, 25.512729267920218, 25.177558814325643, 29.297781182873635, 26.61376407069545, 24.027831708231282, 26.75250026487535, 33.98712181275891, 34.30881108007124, 36.3950962405051, 23.683933981003303, 34.068526683315156, 41.499617791944935, 31.319060902441706, 47.78817738256147, 38.72392508291429, 33.539030244273526, 45.1228170241079, 26.951527210973925, 18.61436467016897, 7.721941721054816, 8.291338470674331, 73.2804887525497, 61.82449671529955, 75.49822822693856, 70.942975782579, 70.75117188115274, 70.48026161809122, 71.50804811908354, 65.85381031036377, 63.3314242670613, 63.22948971102315, 57.49514141390401, 32.168263850673554, 39.6679062228049, 9.484592118570882, 42.15782680819112, 90.62266795865952, 84.2877890986781, 82.93790540387555, 73.16783043646043, 50.672052983314764, 81.34932979460686, 54.558051017022905, 0.5093926371585938, 0.1891684363926611, 0.16466839299086602, 0.3169074997065529, 0.31212079849454666, 0.32089765333840925, 0.4761501209389779, 0.15975075203084177, 0.1415408420706949, 0.14518291599327518, 0.11091999364115539, 0.14648975473978829, 0.1881516078907636, 0.13082010040600456, 0.4377415061237351, 0.2525213643187477], [0.10875720485684373, 0.09124742265069678, 0.3613013449695803, 0.20082938244506238, 0.2066015944846215, 0.08513053233224539, 0.01655698907862027, 0.08336218689838726, 0.04160278011113406, 0.05097540621195109, 0.0790548422223618, 0.1938978495496896, 0.08603114529602951, 0.07906609605396948, 0.06277959921487397, 0.08112001608336165, 0.11826531360706977, 0.051984581495485, 0.0559018993179404, 0.039250487987432754, 0.0442895615443347, 0.23616520327425775, 21.842489050280665, 61.66813535075034, 46.21656210191789, 50.8309599661058, 99.15610590288716, 55.16212740252095, 57.255747395177046, 40.03494201167938, 38.0675595806491, 46.07721597917619, 24.18657199029, 59.74773899201424, 48.28926017207485, 78.07889676863148, 71.60537781253939, 72.85434676754859, 69.50985154797955, 71.7290658335532, 65.3338413084707, 71.86228521408574, 71.2934866259175, 42.99877512839533, 1.6192326093873672, 0.16779947094619277, 9.0713615955845, 37.69263982772827, 31.306185722351078, 32.61307827887997, 13.74728968066554, 9.655210318103913, 22.99095315317954, 25.693338724874682, 28.537823923172493, 32.47710539448646, 28.062313025997533, 27.654643443322954, 19.686060144055276, 8.553652859503224, 7.9969974390922065, 17.1170175075531, 17.61253445379196, 15.505349924487454, 12.828011628120178, 14.949553993440444, 14.480663076523813, 38.798654079437256, 28.075611822066772, 14.34432835348191, 28.428183870930827, 29.568297247732843, 17.44994240422403, 18.78882581187833, 3.8917293519743033, 2.2820678161036585, 1.588778714499166, 0.7428757053229117, 0.7712933385083753, 1.4410167788305592, 2.688565100392988, 10.131830265445094, 20.726647300104943, 31.602636498789636, 21.31828388860149, 17.695690662630145, 23.255428767973378, 34.602020017562374, 31.287462288333526, 22.773094907883678, 21.581082690146662, 18.650895664768836, 15.156004025090127, 10.02379838497408, 13.293105690710007, 18.057907819747925, 16.246065997308303, 4.757522700294372, 9.214129005709003, 9.205415460371203, 2.2620399488556773, 0.7340168484276341, 0.1559454554151143, 1.1288936820722397, 3.9918078914765394, 12.740298605734303, 35.50715792563654, 30.613504955845496, 16.70301329705023, 35.214094115841775, 27.19156449840915, 30.573343807651153, 25.091798151693038, 30.56533628894437, 29.722220859219952, 16.20643731086485, 16.333208314834103, 13.771664269508856, 12.003101879550565, 11.128476089046849, 10.094567748808092, 11.476781579755968, 21.546773718249415, 23.19595975260581, 33.07818312798777, 31.78525224808724, 30.657115828606393, 38.212859861312374, 36.350561649568625, 39.36985708052112, 29.62252009299494, 30.06749337719333, 32.95868027594782, 39.49187809421171, 30.624214987601007, 15.452091982287747, 7.917266440006995, 4.815316863598363, 14.168712073756804, 46.58670048559866, 49.205961227417, 69.19229645882884, 62.74167237743255, 63.79583289546352, 57.34074123444096, 60.29344266460788, 55.48280077595865, 64.33448414648733, 50.99211446700558, 21.999026921487626, 33.22558579906341, 16.02531010104764, 33.046690417874245, 74.63284354056083, 65.69380114155432, 76.12135948673372, 54.47252373541556, 38.464742706668, 61.759044124234116, 10.91469906991528, 0.48966332969646303, 0.23319393125993593, 0.1906379309272574, 0.044068763513238206, 0.18255053989348874, 0.13756962613232676, 0.13470047363831153, 0.10956309104879057, 0.04514856061207191, 0.07536323305459754, 0.06887470582319845, 0.057099191321721005, 0.1410881147509621, 0.011985496328693005, 0.018650921880297603, 0.09506899097393598, 0.08783172004886212, 0.17303597302206103, 0.3334365514737945, 0.38039866053769666, 0.19027048451525552, 0.0038034431617556806, 0.025150327560221477, 0.05739982337540677, 0.02176421701968197, 0.03169945043121134, 0.15135646617460638, 0.10290602447404977, 0.030465024230521054, 0.006672605231869967, 0.04607270013601069, 0.07494040614654941, 0.06656982305069124, 0.019722895306204597, 0.01910063081360873, 0.0312816854491229, 0.03127673269069243, 0.23602530029752564, 42.43420093290268, 78.13014645730296, 52.85434207608623, 59.11223265432543, 90.64032646917528, 50.11865362044304, 43.69995370987923, 35.867404091742735, 38.20849426331059, 40.9648653768724, 34.92827492375528, 67.31650137132215, 57.6841486653974, 85.38054573920466, 79.02226601877521, 81.11471714511995, 75.57910749989172, 75.70220716537969, 73.56322103931059, 75.5406996511644, 70.75490597755679, 51.213222395989206, 0.8126847626220796, 3.6848360924951495, 16.317552174291304, 31.381836475864535, 39.43134807771252, 36.328564997642275, 24.993230950447824, 13.935718382558516, 21.07245129923667, 23.09073825036326, 26.965469275751424, 29.04435488485521, 27.494440117189964, 26.939454155583537, 21.618333439673147, 10.219046127411628, 6.337523027773827, 9.844755914903457, 16.53857381113114, 14.993418839669998, 15.329578711140542, 17.013784646987915, 19.90657579514288, 42.8236726791628, 23.043697264886674, 15.204619842190898, 28.358185252835675, 37.82961291651572, 19.409395763950965, 28.155214363528838, 11.989890356217662, 1.3888043934299101, 2.7617991835840288, 2.149173501999148, 0.6266560609782896, 4.804324911486718, 11.159239238308324, 27.435400601356264, 38.62415959758144, 39.36805671261203, 23.161193824583485, 31.240601731884865, 36.24711305864396, 42.01676268731394, 41.46354375347015, 33.537590734420284, 34.46841624475295, 26.20448043269496, 23.162847103611117, 18.165569036237656, 20.365667650776526, 22.795497525122858, 19.76808867146892, 10.644844905022653, 8.56117400430864, 11.098027709991703, 4.714701204530654, 1.328573702804504, 0.06964064052989406, 0.5026995721122911, 5.681359527572509, 24.330630840793734, 42.74117346732847, 24.928072537145308, 20.36512440250766, 37.46050611619027, 33.5146370241719, 25.383814688651796, 26.26486924386794, 30.094846025589977, 27.751884883449925, 19.63450254932527, 16.331099060273942, 15.238466955000355, 12.100970898905109, 6.528050688005264, 6.545737635704779, 10.857055917862924, 19.111650605355543, 23.101954267870997, 25.36288296022723, 28.384119964415028, 26.5838187356149, 29.870233458857385, 31.767701602751213, 33.77624342518468, 31.253455338939546, 28.646795211299775, 34.55654798015472, 42.72278147359049, 33.59173905464911, 18.73153567314148, 21.736961603164676, 15.456713514943278, 9.005618749126311, 54.205461317493075, 49.494694740541526, 68.28031401480398, 66.05724796172112, 73.61452564116448, 62.287206957417155, 63.9858050500193, 59.11401341038366, 65.74409377190375, 55.54452711536039, 32.25774292022952, 34.397056564208, 20.601078502593502, 53.718204882837114, 91.08718641342656, 68.90908564290693, 78.39490644393429, 62.21039518233269, 40.555828848192775, 77.67567711491739, 15.327838159376576, 0.5026540052025549, 0.24353444816604738, 0.09768626141932704, 0.10511293226192076, 0.1538934276228951, 0.22026000754727473, 0.15828989896803133, 0.017346908083005298, 0.08882141371648158, 0.037057262529889425, 0.061055181262594085, 0.05130283602122819, 0.06669304063243252, 0.04160260008047185, 0.06130139426057858, 0.04466424365678141, 0.21540596720672425, 0.33751615353168984, 0.5319496977233118, 0.37679486036781346, 0.24954659894349115, 0.19453532663324188, 0.22519638701792688, 0.2101665693185022, 0.13196495752180779, 0.17588307750561546, 0.30124421922429917, 0.1936366901763024, 0.17713434423410124, 0.16963330157581838, 0.18155854796209644, 0.1783790379281967, 0.1331014029922024, 0.2842024401310952, 0.14139661835806985, 0.11190288444800724, 0.21221269823370442, 0.42518495732257444, 65.8664874107607, 93.59926839028635, 67.82971212940832, 69.9376723074144, 109.83599032125166, 72.21416888698455, 79.03633948295348, 50.420068156334665, 47.281246339121175, 57.40335795187182, 31.4071887154733, 77.0614339459327, 60.02293248330394, 91.76514456349035, 81.95740699768066, 87.79204245536559, 78.11102098034274, 85.49834236021965, 79.69468578215569, 87.59082486552578, 77.9541418629308, 56.951528364612216, 1.6057059481259317, 1.7136796059147006, 13.675596598655948, 50.768641348808046, 44.62602530756305, 42.903955751849765, 17.961852896598078, 13.45159690226278, 31.035355867878085, 33.44241049981887, 37.008939327732215, 40.10062994495515, 35.16893194567773, 36.481564890953806, 25.885199500668435, 13.424757103766165, 14.480565997862048, 28.382835388183597, 28.11819895621269, 23.255185581022694, 20.141584604017197, 20.884463863988078, 21.99618712548287, 46.925946281802275, 41.96670147680467, 23.595353134216804, 43.219318236074145, 44.73229016027143, 23.957419280082952, 39.74607513796899, 23.69822317554105, 5.050798318078441, 4.215551653215963, 2.1712591426987804, 0.734367348974751, 4.165560064777251, 7.943643889119548, 24.630833364302113, 44.65039891581382, 49.09522879508234, 34.365222607889486, 41.95985694085398, 44.09850966545844, 51.17339857162968, 48.179210232150176, 40.358310053425456, 43.59440272854221, 37.47160250140775, 36.3513578907136, 28.632017681675574, 36.51278695752544, 30.574987280753355, 19.772497415542603, 13.450557474167118, 19.386596987324378, 12.40618032793845, 5.430374904986351, 3.6463838719552566, 0.163884271356848, 1.5426387709956018, 8.786797561953145, 32.37470211521272, 52.513750906913515, 35.806823084431315, 36.171944756661695, 45.186331964308216, 40.43258013263826, 39.55866429113573, 34.0242588135504, 36.316491942251886, 35.15164998269851, 21.77810138271701, 22.614127128354966, 23.682749425211263, 25.481375801947813, 25.622967481613163, 20.06031897760207, 21.023282427941602, 29.277478994861728, 29.51499615946124, 40.4649632207809, 42.51304841810658, 40.20979342922088, 47.37647756453484, 44.916414060900294, 47.049979471391254, 37.88485950039279, 34.94482340351228, 40.367049094169374, 45.925149609965665, 40.842240318175286, 19.363768792921498, 19.454975666538363, 14.915517626270173, 28.91864880438774, 70.2577926266578, 62.09924697875977, 81.68138196391445, 71.10038834233438, 75.78866404871788, 68.38172297323904, 69.95175361633301, 65.63045486327141, 74.24577620721634, 60.367096931703635, 34.2492381218941, 44.97962697859734, 21.710332632064823, 46.82803999993109, 88.02733759726249, 76.18800055596137, 81.48515362893382, 75.20861610289543, 51.665130430652255, 88.32275482916063, 21.72196049844065, 0.6634373518247759, 0.33029865533594166, 0.43198104587293445, 0.1764626689856091, 0.2958785700461557, 0.4009136371314526, 0.5207106975778457, 0.22503679558154077, 0.1534863897869664, 0.17084215767681601, 0.1673216772295775, 0.2207207175031785, 0.2236338128005305, 0.07235447635814067, 0.3130267434302838, 0.32927926810037705], [0.033386261127288305, 0.2559104606869721, 0.27047233656048775, 0.2275039970634445, 0.10115761264798143, 0.19417281382747237, 0.1990641932934523, 0.056701013292636604, 0.02664960567809401, 0.08304277419923775, 0.03265092780272807, 0.1411339114870756, 0.1093882927671075, 0.09987492099284165, 0.055509581861476746, 0.04137507962783979, 0.06062823280151333, 0.05121244530704233, 0.08720913571455786, 0.07825230383464406, 0.04944756642104157, 0.7393258377428978, 11.935120340316526, 67.18927537241291, 58.23273528006769, 71.71353324767082, 88.93364829401817, 84.13908420070526, 49.439769791018584, 60.833949196723204, 39.11367139508648, 50.929219261292495, 22.74160808132541, 58.32075718910464, 70.25630212599232, 80.72842644106957, 70.43786079652848, 72.87755150948801, 71.24881082965483, 71.41608422802341, 67.99988808170443, 71.28717945468041, 57.54450836489278, 30.552298330491592, 0.5459794642463808, 7.116231178083728, 37.296578499578665, 29.18992384787529, 24.741555990711337, 26.739258343173613, 28.622239212835993, 29.372869076267367, 26.641924727347593, 27.967226928280247, 30.37689778112596, 32.80214632711103, 31.75726809809285, 28.73986521074849, 19.431721894971787, 11.447194160953647, 5.281161569779919, 12.276017454362686, 16.871322201144313, 14.578569358394994, 13.61019499840275, 19.70559354751341, 19.96530544373297, 18.7958860781885, 20.137544562739713, 15.031186361466686, 24.31972469052961, 30.81041970560628, 18.883096056599772, 30.065679280988633, 4.085244632536366, 3.0600679785974565, 0.6347611486431092, 0.359617238563876, 0.7121493895688366, 0.4886565063028567, 0.9857215936626158, 5.3975299577559195, 10.756302975839185, 23.581717014312748, 22.78575239642974, 17.892375953735844, 17.938403006522886, 31.843064062057007, 27.817504175247688, 16.910512562721006, 22.120230120997277, 18.056815439654937, 13.28661907103754, 9.43153323665742, 13.865968834969307, 15.905364021178215, 8.997408247763111, 2.34505666840461, 2.7395588544107254, 8.96801596687686, 1.047973959676681, 0.6234206571694344, 0.4586616512988845, 0.14731529108699293, 4.466271515815489, 15.049262604405804, 40.477656010658514, 33.009875051436886, 15.33162618837049, 33.070008908548665, 29.038749817878973, 29.550607358255697, 32.416251782448064, 23.625831911640784, 25.87983369827271, 22.1280336764551, 17.7471423533655, 13.372522900181433, 12.650514571897446, 6.7901537591411225, 4.121070090801486, 9.692602272956602, 22.143709428848762, 25.494294128110333, 30.60970025677835, 28.152892320386826, 30.453476175185177, 27.825672511131536, 30.361188688585838, 30.648551333335142, 31.69739115622736, 40.38324456061087, 33.347485219278646, 33.11650860694147, 49.82716660345755, 26.250160355721754, 24.407240613814324, 10.560800279340437, 4.458635641682533, 26.213499922906202, 29.80682638383681, 27.484475335767193, 42.78438621951688, 55.64570465395528, 62.1380078408026, 58.755912780761726, 56.160888364238126, 70.35374949055334, 47.38645999662338, 23.231761186353623, 35.40946345175467, 30.088740856416766, 18.103373973600327, 54.75112184401482, 58.0964486060604, 65.84396516123127, 53.87604105857111, 47.728502442759854, 48.660712549763346, 4.631553330729085, 0.17543228072745187, 0.16421607935861235, 0.07748208669645172, 0.11155034610701185, 0.09453279837485283, 0.09889740812321825, 0.13068540682715754, 0.027059889811601852, 0.034210989251732826, 0.13040147932066073, 0.025523374074949853, 0.01438715132779532, 0.1364340540021658, 0.07917959964083088, 0.028778832150442947, 0.08180581033229828, 0.08173948243981408, 0.18111331298226313, 0.40183671179317665, 0.4041655884394723, 0.15861432188220564, 0.1461030335556115, 0.1569160428499022, 0.041506858242134896, 0.031170248384437257, 0.08172580777036567, 0.02662015725828467, 0.2409528391135316, 0.1289602993957458, 0.02196220669805283, 0.07759920621831572, 0.09533810233997722, 0.03937395071730979, 0.120533975742517, 0.06967596484408264, 0.11173015460371973, 0.1407135590430229, 0.782397507179168, 21.323981131276778, 89.26162904308688, 65.29909303111415, 74.30403909375592, 97.75930281608336, 76.1612029229441, 48.494129488545084, 45.06757828497118, 38.68178313778293, 43.46587450273576, 31.77675835547909, 63.49986653174124, 74.53543539970153, 85.41938504865094, 76.20304676794237, 78.93091401746197, 82.25464420933878, 80.10054126862558, 74.76999313600602, 74.83714411335608, 66.03545527304372, 36.69283943791544, 0.6831866695034889, 14.550496955071727, 34.57353576537102, 41.36550018864293, 32.9915968064339, 27.74857048065432, 27.47339071766023, 27.29106522375538, 22.953225835677117, 25.411206560750163, 28.750332055553315, 33.042289518540905, 30.99757952074851, 30.24519635785011, 23.038051013023626, 12.272831509190222, 5.17590525650209, 6.400692799398977, 13.574127824075761, 15.059970674976228, 15.967297265606543, 21.64941822328875, 23.035691707364975, 24.41556388331998, 28.425569611210978, 17.694761060899307, 27.22079400093325, 39.62530143799321, 21.47628284269764, 37.09590219682263, 14.535665492857657, 1.760837281903913, 2.2107819251475798, 0.5616103545311959, 0.41033060440132696, 0.9959727693949977, 5.492183123865436, 11.513290020727343, 31.97349463739703, 37.703379277260076, 30.741136920067575, 25.685497906900224, 35.69593767965994, 40.057374046694854, 37.3745003054219, 26.47979355627491, 34.623628354841664, 27.89558875945307, 23.67723653393407, 16.44036452616415, 18.839238074518022, 19.02362281276334, 12.707402667691632, 5.581977944220267, 11.915087815253965, 12.772993522305644, 4.315592194757154, 1.459424707197374, 0.2897259340651574, 0.23512571389156006, 4.360307214721557, 25.398802065080215, 49.782212318912634, 32.13056595094743, 19.939315818971206, 38.838430835354714, 27.492757420386038, 30.444456684973936, 27.783477614002845, 25.496622054807602, 24.219176692347375, 24.15808185454338, 18.953906605320594, 16.650728102653257, 10.248953219382994, 4.733165271820561, 5.464567676667245, 11.548550167391378, 23.96802144665872, 21.56253576278687, 25.18589188975673, 27.641048508305705, 24.755956972798995, 24.944301343733265, 27.719217423469793, 28.9326673553836, 28.682190679734756, 34.33842105250205, 29.41733502572583, 34.12608354322372, 45.7848503512721, 28.520865555732485, 34.09501444908881, 33.49694713469475, 5.29737860925736, 22.199256074044015, 35.72611247339557, 30.02301173825418, 44.8571745041878, 57.50649667555287, 68.23877611467915, 68.70648737876647, 56.83007609459662, 70.68827275306948, 53.319401817937056, 31.153034817787912, 34.578693682147616, 25.681328427407053, 30.345754161957775, 59.502147628415024, 67.36309912896925, 66.58113541141634, 58.4380203677762, 51.2707478769364, 65.47357966822963, 7.061610212249141, 0.224012827140189, 0.19734904500505618, 0.05886641443677007, 0.04665711796992729, 0.14942019426774594, 0.08582382658196074, 0.14054759375510678, 0.08523815236384831, 0.015247513074427845, 0.010089681525113843, 0.03370606070083957, 0.05545014876031107, 0.06753768321246871, 0.06091431301507739, 0.09247722359554422, 0.09522518097993829, 0.22964184202494162, 0.4556559512932455, 0.7515469013202576, 0.5029028918473951, 0.24162446839674828, 0.23306689856033172, 0.31583877640866465, 0.18894274689016805, 0.13734419709972798, 0.13994670503081816, 0.28379570873033616, 0.36082278516504074, 0.2828100600069569, 0.1577789949313287, 0.35566575705043735, 0.2062359713618794, 0.16959867440164092, 0.20294456652575926, 0.3364117611800471, 0.43831956542788014, 0.33918935084535234, 1.156562939286232, 34.11974107065509, 110.91010785871937, 80.2485558294481, 94.77905458019626, 104.21688125979517, 104.31698799133302, 70.49539412221601, 78.10461967222153, 51.16492232968731, 65.14491642675092, 29.93291489539608, 72.52460095190233, 81.77780166749032, 94.12153197873025, 76.98177060773297, 84.34787196497764, 85.70713796923238, 89.4998110494306, 76.7818630895307, 81.84176768026045, 70.23840042852586, 43.49285256478095, 0.9213948454107008, 12.837121332845381, 47.91140256389495, 44.97329627313922, 34.98463938313146, 34.584471333411436, 34.76406881886144, 39.633793369416274, 37.727643059146025, 36.25429884079964, 36.43903070880521, 41.08892994542276, 42.64978616468368, 39.13001983396469, 26.803922537834417, 17.396017659095026, 11.672141109743427, 21.918288853860673, 29.28112287675181, 21.616791948195427, 22.157035681509203, 27.257672125293364, 30.94257612382212, 23.1879698845648, 30.577068098129768, 26.296228593395604, 38.3107465313327, 47.29734766867853, 25.810990218193304, 49.225067092526345, 30.27074471596749, 5.544515877000747, 2.6088789634166227, 0.8460033360508181, 2.4650216246804884, 8.069959407852542, 8.935899599905937, 15.370723393655593, 33.8943342239626, 41.98481498226043, 42.97996736341908, 39.50331964800435, 42.774113532035585, 47.25400155590427, 47.32094072526502, 35.58282044626052, 43.26693580996606, 39.94936766162996, 33.63456349219046, 31.421601464671475, 34.1352815012778, 21.20097952504312, 13.414704069014519, 7.711972526965603, 16.661561689069195, 11.814197590274196, 5.139938592910767, 1.5437152164597667, 0.36588049764114045, 0.47293880293446205, 5.936493527504706, 36.04826458038823, 56.59683235229985, 35.37284420382592, 34.65235971635388, 51.67620720401887, 39.391277144032145, 37.70426573291902, 42.3566831311872, 29.33263340303975, 31.711594058621316, 26.72810116121846, 26.093273393569458, 23.910372411051107, 27.372117080996116, 19.125045499494, 13.522602588899675, 19.50900043210676, 29.75755160854709, 34.28163689951743, 39.92576283793296, 34.916001827486106, 36.11087737544891, 33.88707783914382, 38.99558451867873, 37.750985084041474, 37.48624470926101, 47.5981463924531, 38.1359931730455, 38.177072155860166, 59.774975930490804, 37.46702901778683, 30.153375633301277, 24.857161967985093, 9.06248821366218, 35.44294088117538, 42.735462496357584, 44.71747929050077, 56.70460731752458, 70.91713520788377, 75.34109023309524, 74.91957664489746, 64.64802665095176, 80.6626247590588, 58.71539861925187, 33.10863641000564, 46.544695823423325, 43.509577551195704, 27.54031811991046, 67.77804666949858, 79.07273907815257, 74.21391871667679, 66.71676312723469, 60.33029333237679, 79.33928766558248, 9.014635297559924, 0.7677979551015363, 0.35639602270337845, 0.252142028222161, 0.21201209044985234, 0.28942884516812145, 0.2995587645038482, 0.3901341671664869, 0.1530840557308928, 0.1655694656074047, 0.2009714764332579, 0.13873519826560252, 0.23603881408850994, 0.19057498914339852, 0.29415606731368654, 0.1487017876558727, 0.22982247023572847], [0.13892886529286064, 0.11047701095981945, 0.31297143188215076, 0.20813655889322683, 0.22536730123383386, 0.11205479202251281, 0.07025531883681975, 0.054638329217390674, 0.09489694294790108, 0.04425807150020715, 0.1285269694222558, 0.08268233749174303, 0.09402945562596284, 0.14528039302076065, 0.023243151672725237, 0.04355211764754307, 0.05019998350631326, 0.06318306708107553, 0.07581759980248828, 0.09333296678960325, 0.12093221122819571, 0.2533086115914968, 1.7716917059113904, 63.97744647918209, 72.40842034739833, 66.84070217993953, 75.91916914909118, 105.19213153469948, 57.998432497824396, 62.27795800855083, 44.61503874871039, 52.845316702319735, 28.29254242681688, 60.02516823430216, 91.88320790567707, 78.57032268278061, 82.62825781299223, 73.27037688224547, 70.97496663370441, 73.73383629706599, 82.76755686729186, 59.92594795842325, 63.160248110371256, 25.68784348426327, 0.8753086506359039, 24.571721284620224, 30.80808001179849, 24.70118695689786, 36.37377423624839, 37.65856619804136, 29.34433971681903, 22.997028904576457, 26.75551264516769, 24.38983705735976, 27.9075990569207, 27.583646582018947, 31.624133048519013, 25.175611357535086, 26.186045292885076, 13.726079463958742, 4.238953984552815, 7.0104085726122705, 15.475665427023365, 15.819095411608297, 20.718239699640584, 18.56892401172269, 24.15550485734017, 20.841204043357603, 13.374685106738923, 14.62319612503052, 21.71250758632537, 34.780974234304125, 24.722773721141202, 37.77749638403616, 7.962506076981945, 1.968988641615837, 0.7252306166675784, 0.19888063862679467, 0.6462072989633006, 4.465992046940712, 11.224683004040873, 1.9769066812530642, 8.676382841602448, 15.13209423711223, 28.23372256371283, 22.324977843992173, 14.48485707083056, 25.53951317264188, 25.695031227604037, 16.526045760800763, 19.195455966457246, 17.047046346049157, 11.046486785334926, 11.381380711832355, 14.603815694009105, 14.04409739278978, 1.9039407901225553, 1.902789084180709, 1.2148641915090623, 2.0562374760066313, 0.29931842740024295, 0.1570059968939712, 1.1195284104154957, 0.13841195512683163, 3.5472802865889768, 24.98771413680046, 46.46982954394433, 31.907155590672648, 12.42588141272145, 32.02851176261902, 29.068248002759873, 17.424554863283714, 31.503482903203658, 30.79737782478333, 33.96855723473334, 29.317495015359697, 23.83506290374264, 16.809988098759806, 9.606766104698181, 3.0603192554366205, 1.5805674776915581, 9.053930582538728, 20.336316554777085, 28.132484228380267, 21.33574039705338, 20.727202315484327, 25.235531445472475, 25.626527032544537, 29.047416294774703, 28.46145341473241, 34.67533696082331, 41.77836887298092, 40.37437608165126, 33.72493097859044, 53.19019109972062, 48.94117770656463, 23.8331978167257, 8.578620706835101, 4.249323750695875, 7.24891564538402, 26.39804743951367, 17.236928286090976, 19.79802812299421, 25.180557466322377, 42.43022364954795, 59.69557539109261, 54.754655899540076, 65.94954752152967, 36.271498434005245, 25.523451066786244, 40.950030972880704, 31.950817454245787, 37.73729601214009, 53.37993575680641, 61.77283517775997, 67.13174989146572, 50.747444860396854, 53.35710364003336, 34.91183234799293, 0.39262796722112164, 0.1139756502403367, 0.02303355767752134, 0.08590853292374842, 0.05701274212990558, 0.12164385328369758, 0.1336627156143227, 0.10711464339927321, 0.029569431057860775, 0.02405019848787737, 0.11916264005365873, 0.11814575792560655, 0.030189293864814025, 0.024787096547022946, 0.06023966151499941, 0.0993162130696639, 0.03954230619954967, 0.11110370152539785, 0.1831516124788792, 0.3375012914259588, 0.26981206070030894, 0.3283848757705381, 0.1057578327374593, 0.05596158905856072, 0.027370488669182506, 0.07648971172109728, 0.08781275171185694, 0.13532184755369542, 0.07026988216826031, 0.019641938964806257, 0.075843999192359, 0.08654113002722302, 0.04073943732486617, 0.04764741301656731, 0.012766078636500866, 0.05444740095446187, 0.03937799949198961, 0.190968926875822, 0.23798245576120194, 3.5776911579793502, 81.79041600996449, 81.99797215000277, 80.05095466490715, 90.1053544013731, 99.60444850306358, 54.754604908727835, 48.98077011108399, 36.584668313303304, 45.8680045989252, 36.163511660791215, 65.78811453234765, 88.81931120349516, 85.26625571712371, 84.25985397831087, 79.37130989566927, 76.40890059932586, 76.7731789619692, 83.43123758992841, 66.49461577015539, 74.38678541491109, 26.713782548904422, 2.1564529307426947, 37.683645832923155, 39.80427134421564, 34.55998789879584, 32.753669754151375, 34.80882698489774, 25.477698579911266, 20.834424226514756, 24.67826266442576, 26.477804914597545, 25.902197091810166, 28.167471770317327, 29.55908948375333, 26.14141852624955, 26.516265715322188, 15.926439896706613, 6.625428920791996, 5.862782386041457, 8.641059937015656, 16.661726428616433, 23.372366389920636, 22.947661953587687, 24.73634316075233, 24.15605006679412, 19.591852657256588, 18.834115459072976, 26.288417193197436, 44.989648634387606, 28.30734152947703, 43.07643805780719, 18.50406958210853, 1.8149267665801512, 1.2128794722018705, 0.4467520484280202, 0.38227894673905066, 4.7687073388407315, 1.4849657108706813, 6.747303335897385, 15.688633457306894, 24.12096642678784, 35.315977681067686, 26.766812993634133, 25.528269698542935, 39.079589920659224, 31.75644636154175, 28.07435666361163, 31.10784322984757, 30.288505208107736, 21.21961666691688, 17.343532423819266, 14.320747064005944, 16.253022320808903, 6.655686084301242, 3.7170617955346263, 5.81735888796468, 5.838561750227406, 0.8842761694423614, 0.42181588649269075, 0.2827710201663356, 0.145550990597375, 2.8553700206741213, 24.079948240710845, 52.162522269833474, 36.315479970747425, 15.396112895780995, 43.1140104416878, 29.61882914266279, 17.880397035229592, 23.772379506018854, 28.921749438008955, 28.768857409877164, 30.25051509180377, 22.62723961184102, 16.01463144825351, 6.578390386796768, 6.145134202895626, 6.106155159011965, 14.257727323039887, 21.251462390345914, 21.13859226626735, 21.615630926624423, 20.060515096110684, 20.997232006442164, 21.542714065121068, 20.640706208444414, 23.085384215078047, 26.14173427704842, 34.875711241076075, 35.32222601675218, 31.18270362577131, 51.71117513410507, 45.178040073763945, 24.495937170520907, 11.140273597932632, 15.487461955316606, 11.201316464331843, 28.93148279959156, 23.030418080668298, 26.432177943568078, 28.16826605027722, 44.02054079117314, 61.51995212801042, 63.468283607113754, 68.39497273968112, 46.538757354982444, 28.322238691391487, 36.63438435523741, 27.107949372260805, 37.29855537414551, 54.66505719769386, 65.71671170573082, 74.91680745155581, 62.71884810539984, 58.62916923338368, 44.58212221822431, 0.9579651249993233, 0.14894813088880432, 0.027195205836887323, 0.0934892563870357, 0.06725690432734067, 0.08204126745582589, 0.17352787807824152, 0.14066808406383763, 0.12257114908988438, 0.0636864940996372, 0.014253763928859225, 0.10582450536950942, 0.16849118705478408, 0.08695115560605642, 0.042787967925711025, 0.10573399974213493, 0.0862428690156629, 0.22717578967492427, 0.3675905897492363, 0.5617236742569555, 0.31832871538016105, 0.34359594987284753, 0.2497643824186056, 0.13548906922580736, 0.1275921736152903, 0.20263442349049354, 0.21602657503418385, 0.3379005151650598, 0.21912317903291798, 0.19383176680534117, 0.2959990909984035, 0.37169096811163815, 0.25279557783036466, 0.23367649004344018, 0.2786631341422758, 0.18242680137195896, 0.25384740122864324, 0.26845412388924633, 0.490783411528795, 6.474047985769088, 107.61994531077724, 90.35453473368, 89.05251179972004, 96.77271689138105, 120.95027723620017, 79.41429907275786, 80.67491746717884, 58.63790435175742, 64.44966846896757, 38.70260700102776, 72.03179436345255, 100.24920771198889, 87.17777575215986, 93.4930427612797, 86.98838018601941, 84.94145993263491, 84.05971111789827, 91.41477492547806, 69.94991010235202, 81.83964175562706, 36.78039850727205, 1.4426074225095011, 35.466773202342374, 40.85597645851874, 36.49637576072447, 42.268629843188876, 46.30584309178014, 35.579533500056115, 30.95204080304792, 36.795789887828214, 32.6497838189525, 35.80387738443191, 35.89872029519851, 40.10628208037346, 33.40842708464592, 32.400668205753455, 19.77458803884445, 11.384067535400392, 16.6412006655047, 27.228913307189945, 22.985155890064856, 28.614474881079893, 25.42937105701816, 33.76282107445502, 29.672965695781095, 17.63127749966037, 26.064867588781542, 36.95104122161865, 51.96026132952783, 34.045851461348995, 54.6726744405685, 36.21793062456193, 7.0168412596948695, 1.6635153106143399, 1.071888650617292, 1.4401489544299342, 14.616133897535263, 22.560926060522757, 13.08151048998679, 16.556436284895867, 28.39259424517232, 45.53090826157601, 38.18963550752209, 39.97631434471377, 46.87905042402206, 42.31956574224657, 38.32744013878607, 41.0467880002914, 40.66688683725173, 32.599646122224875, 32.67565773379418, 26.434166585245443, 15.696985163996297, 7.558876045288579, 6.7090033523498045, 7.487473708968009, 4.219188180661971, 0.28965122517078157, 0.24526755355538862, 1.0987657116305445, 0.5000689487543799, 8.86089603747091, 39.19431924819946, 56.160300008712284, 40.65760258705386, 25.93660412296172, 53.97353941394437, 44.40289735794068, 24.432069217005086, 41.173700209586855, 39.70673768751083, 37.53749832030266, 35.33508746854721, 29.873810660454538, 27.86321547723586, 21.09567565302695, 11.20587621965716, 12.048933794421535, 18.009044893326298, 28.323478160365937, 37.19450666058449, 29.642337868290564, 28.55311332210418, 31.040268636518913, 32.05943572905756, 35.94878150570777, 35.00782451322002, 40.80728415519961, 49.06282609508884, 45.97396742913031, 40.34489162506596, 63.24150000849078, 59.75031991158763, 31.61537439592423, 11.909613167085956, 15.435744524002077, 24.55895789207951, 45.865800226888354, 32.45347311419825, 39.65694319817328, 38.51724755379462, 50.849379416435, 65.89288496202039, 64.69402036359234, 77.7319239031884, 48.0298581430989, 32.95586009179392, 53.22173872301656, 44.30501068792036, 53.15417981916859, 67.52615205703243, 76.0890862249559, 83.68919618668096, 66.81132362734887, 71.40511728102162, 57.165109265235166, 0.9877065581179435, 0.4478985449719814, 0.134466816821406, 0.15534251357518858, 0.14602299268928268, 0.20195078194862415, 0.6567046034239954, 0.24842731384260042, 0.20924066013145834, 0.18242146940000598, 0.13784909500710427, 0.18274626003638392, 0.18577966178136487, 0.26191547152496153, 0.21670551279619818, 0.18431500892245, 0.2816620312871472], [0.14264325791549298, 0.24241631219704307, 0.2703154723971121, 0.11882652663775992, 0.15080692066300302, 0.09005107676550266, 0.06688247885434859, 0.08239287883043289, 0.17880361917759144, 0.06936472630308521, 0.030867708771820032, 0.05754877385052462, 0.07886908888336151, 0.06945494847792773, 0.01313403832741202, 0.09405560986769777, 0.012775040907605041, 0.022344566926720644, 0.1511319870910337, 0.06045463727787138, 0.05904747165679451, 0.06826880688388502, 0.11123213616590347, 43.42180275147961, 81.70224112849083, 65.82858947015578, 65.74758075898694, 100.9530064367479, 80.92636492944534, 58.8787418027078, 55.68048823264338, 51.24512303260065, 34.990487637058386, 51.067780909999726, 101.99731396090601, 74.74660012029833, 81.49375146435153, 85.25113890247961, 82.10629232468145, 82.37352340452134, 79.07500620811217, 61.910373087852236, 55.16025643194876, 17.113758017939908, 5.865751129965629, 21.54437715007413, 31.830424224176717, 34.301719434799686, 36.66932090636223, 34.64406390343943, 33.844198488420055, 30.10121987711999, 26.678467489057972, 20.161586730710923, 26.86923392357365, 29.4377843026192, 25.909967307121526, 30.97350009026066, 27.925145779886556, 14.288918991242687, 4.95965910534705, 2.975524231310814, 13.239647707631512, 18.761694777396418, 18.81464089116743, 21.26625757063589, 25.053105931128226, 21.3943523745383, 27.239417414511404, 18.069686697375392, 28.977115654176284, 48.35728976034349, 27.898265777095673, 42.203918580086004, 20.369739071015392, 1.9078414646848556, 0.30051236010847554, 0.7717432466245467, 0.20743586423416294, 1.8334771260138483, 4.555771668111125, 2.7599375286409935, 3.3952639275981538, 12.644414305686952, 24.271958066571145, 20.6813007785428, 15.314614868933155, 21.498838432373542, 25.522739156599968, 20.75225253258982, 21.89360537836629, 18.87490418649489, 10.536722810037675, 13.300392473897627, 17.10692524909973, 6.439828738089531, 1.0347240706605296, 1.054628505822151, 0.7993222893245759, 0.12769309803843498, 0.2649755024861905, 0.22073510463439652, 0.2846539723536661, 1.845308465342368, 2.7137812827864005, 26.98575185191247, 45.40990706413023, 28.971234060102894, 15.267840604628287, 29.17465994434972, 31.39693367865778, 22.398412458358273, 25.674654514558856, 27.558419858255697, 30.204960684622492, 28.488455010998635, 23.00978053000666, 16.644301299125917, 5.8640306803487965, 0.5096638016402721, 4.711267659741064, 11.832902393033429, 25.051219271075343, 28.251586998662642, 30.287379487868282, 40.532882982684725, 44.00424334310716, 49.58425814105619, 53.95286852313627, 47.71242072505336, 44.15047322550128, 37.21389101397607, 40.54896077802105, 36.95123734012727, 52.489110577491026, 62.17947513826432, 54.823689614572835, 33.823264798810406, 22.84304253516659, 2.719545941199026, 6.1882689979768575, 15.066226855401071, 21.798976236774077, 13.587129500604446, 14.890372291687997, 37.7343895358424, 53.25163502846995, 69.26246766121157, 33.286398226215, 33.64629137900568, 38.230098678219704, 33.73297183744369, 43.56651075424687, 62.716271108196636, 77.5987829700593, 47.85121771597093, 36.84478421365061, 56.747255248408166, 9.08339640786571, 0.11724540543171669, 0.1830884561904015, 0.05278131676717632, 0.09390659044466673, 0.18451036134314153, 0.09956475497493822, 0.02555496179528775, 0.14494507633630307, 0.10156873373254653, 0.04618003288464201, 0.003832252137550724, 0.036794854433185635, 0.026443372893657897, 0.05461610500670729, 0.15567323373210046, 0.13952359467023803, 0.0882024759606969, 0.13670976904611434, 0.05330430967132411, 0.41018140111719414, 0.26323816829150726, 0.1631131885393012, 0.018783282721415162, 0.08269016691032918, 0.05693441347008752, 0.04222097476163218, 0.045016548340959896, 0.07036653948166678, 0.0903426651512423, 0.16521663615299811, 0.13848995819928187, 0.050284268499742595, 0.1020193619713668, 0.040126340989504135, 0.09006750169059924, 0.06619139859873442, 0.0834395464569811, 0.1042805011233976, 0.08455390561251871, 0.05968178479721951, 58.36703331239762, 91.356182559844, 71.09917240758097, 77.19638701408141, 106.03420165277298, 71.53311990922498, 52.25072460789835, 39.120951314126295, 46.06051060461229, 40.90944228633758, 65.65775063730055, 95.21100951779275, 82.55851807132845, 85.38981822229202, 88.56021511939265, 83.15984879770588, 87.36126422882081, 84.38216132502403, 70.05277818249118, 51.59794415197065, 17.878765329237908, 16.595818842611006, 33.380946959218676, 36.62754766402706, 36.02979021687662, 33.15332397337883, 34.91329146969703, 27.781390913071174, 27.896473253926924, 24.992975996386622, 20.821592192496023, 25.889492534822036, 28.34571211568771, 26.84101050899875, 30.890085004991104, 26.169863554739184, 18.606935701062604, 8.63963709723565, 6.636694458223159, 8.649004697799683, 14.761889173138528, 19.94849024280425, 24.490155596886915, 25.011597448779693, 23.89634797649999, 27.35850057294292, 22.217852031030965, 30.590341398792884, 55.676569784841234, 34.36967449803507, 44.20715147449125, 32.22361241617511, 4.4489929849101655, 0.6500382288809746, 0.4293351926870885, 0.3715249108931711, 1.477828222897745, 5.782949405331766, 2.112279688158343, 9.755595537923998, 19.26923182702834, 36.51977662117251, 27.242674942939516, 26.465474943960867, 34.19612530739077, 30.77308854749126, 30.339148890587595, 33.54523151151596, 27.191235019314675, 21.669065375481885, 17.572261518047704, 16.016779926515397, 12.141390923530826, 3.2398618277042144, 0.5880235339845381, 3.3531330141329, 0.4303895441755172, 0.6916406029655088, 0.7809860055004397, 0.21676558941122026, 2.8390495286833857, 7.17478382971979, 27.718476095507224, 49.767483818915586, 36.966350232401204, 14.003037041233434, 41.5223204705023, 30.78322199083144, 23.010735627143617, 26.42714946500717, 23.69833496309096, 27.677854068817634, 24.87726019274804, 19.913051628297378, 12.015429889002155, 8.965831206690881, 6.161404194370394, 10.19332028204395, 17.186663112332745, 19.99217171822825, 24.00950247241605, 24.562574317378385, 26.557621225234, 33.32932072301065, 36.73853505042292, 43.9349978200851, 37.1169182562059, 31.94709904732243, 30.65229327447953, 34.37162783838088, 33.48625475360502, 52.800323194073094, 57.65684112425774, 37.9864881115575, 19.45228688178524, 34.74630832672119, 5.462403999220941, 3.776684028487052, 15.66964134093254, 25.64933365391147, 18.900128949073054, 16.056061483198597, 38.183477386351555, 57.61055323385424, 72.41507268721058, 43.48810257450227, 34.244829377820416, 31.791424097553378, 26.465839724386893, 47.97622757573282, 58.73746195147115, 81.20260961594121, 67.0055123298399, 44.134579781563055, 72.44740870691115, 16.306387147595807, 0.2264537824498069, 0.22984768985019577, 0.04331754152512839, 0.08603229442791593, 0.07487743371917356, 0.07577238529319726, 0.22001734153637964, 0.07202857489427252, 0.05729282770546214, 0.02799249843754355, 0.0639152939191028, 0.03620556044963099, 0.002700694547515483, 0.03242312006712441, 0.07765165259761196, 0.2636879538336108, 0.12361390200713951, 0.37773147946403873, 0.40119604778385937, 0.5264653662039388, 0.32572602973349635, 0.2544974727976707, 0.16253450104305822, 0.17344679533233567, 0.22580086103370114, 0.15301913744018925, 0.1888749021435938, 0.1011657868061335, 0.11915232084931866, 0.2063326363361651, 0.27314959935122923, 0.2535561652433488, 0.5983475800002775, 0.16499675359697114, 0.2231678781249831, 0.20990726387789174, 0.2162152165246587, 0.2372383545603483, 0.1709178624854934, 0.24381246147376878, 76.66078736705165, 109.64387263021162, 84.48009506348642, 87.1536688650808, 118.22816802609353, 96.93163564128261, 82.25717021572976, 70.88430496954149, 64.96232225048927, 47.294013654032064, 61.69109690573908, 111.89326563189107, 83.50003596275084, 91.96405579966884, 89.97127209940265, 93.87890200461112, 89.99153506371283, 92.85584588204661, 74.54655924151021, 71.18003599105343, 21.705910159695534, 15.567479287424396, 31.49355342311244, 41.76606832012054, 44.87099301430487, 43.44219123163531, 40.14243848862187, 40.43949527125205, 39.655260501369355, 34.24284465851323, 27.90024265166252, 36.13289756159629, 38.64904311395461, 34.140357048280784, 43.008875231589045, 38.10976036133305, 22.478707298155754, 14.101847429429332, 10.225072849181391, 22.247664005525653, 28.22816456517866, 25.79443193251087, 30.270105369629402, 35.121745832504764, 29.774374654216153, 37.36789895642189, 27.123277994894213, 43.079297465662805, 65.0384593779041, 39.019063826530214, 52.035013860271825, 47.03971855102047, 12.279329895973207, 1.3104210962210934, 1.7046867142761908, 0.33690861516421844, 8.793778400267325, 16.501542714334306, 7.0539993432260335, 11.680774246492694, 24.45305193624189, 40.87035586757045, 35.99160594324912, 38.2801285097676, 40.171832730693204, 43.05293521573467, 39.44666885560559, 46.83166426997031, 37.46385582031743, 35.59632124439363, 32.08455654882616, 26.836833184765233, 10.099609955664604, 2.6377598652916574, 1.8874478364183058, 2.123604061142091, 0.23503050448433047, 0.24199929989634023, 0.973686965242509, 0.40359325947300084, 5.12527039935512, 13.81377189390121, 37.5920545670294, 50.45050574887184, 39.07343572185886, 26.297040524021273, 54.848663345459975, 47.19742921090896, 28.72573094983255, 35.97990159065493, 32.63875215284286, 36.48503618855631, 33.522752408058416, 27.7931894025495, 26.941931132347356, 17.689952235068045, 9.83054026480644, 12.726143752374957, 18.206989265257313, 31.507099328502534, 39.54978012269543, 41.04284994063839, 49.079194145817915, 51.503822957315755, 57.45017536224858, 62.21547857407601, 52.69808269316151, 50.08996540500272, 42.32879115689186, 46.21949995717695, 43.99593968545237, 61.75673384820262, 69.16890344312115, 69.83176831276187, 46.592666410630756, 35.75205110734509, 7.208818235704976, 9.76540538572496, 26.585270012578658, 36.75600528717041, 31.09035730361939, 25.510566080770186, 47.47401514360982, 67.90149934830205, 83.56932070947464, 44.959148283927675, 39.44302497371551, 51.880339114896714, 45.08495830720471, 66.85664269231981, 71.61100249136649, 91.96724076424876, 63.18002862315025, 51.91498541062879, 83.45572886928436, 16.930165598469397, 0.624118410050869, 0.376255503825603, 0.10983476880937816, 0.20049593501514007, 0.37303483954841093, 0.3036217271320282, 0.40105806002693795, 0.18093536607921126, 0.20523336145185656, 0.19612350350906774, 0.24113765016438501, 0.11253592588247792, 0.15203440802231913, 0.11290577781056205, 0.2549071459760589, 0.39331493358458247, 0.16605306627048602], [0.13616986092059843, 0.09472242045787074, 0.09599139147828664, 0.15665393352748888, 0.09211122508971922, 0.02178584559700422, 0.06188529115470667, 0.037377242134102893, 0.01713015116570938, 0.041040306865808465, 0.08446283308008025, 0.07259593195011539, 0.07441988770639704, 0.12513968868241196, 0.06003189846993454, 0.03471952607674945, 0.09525739497715428, 0.011744964830276948, 0.07467361602691874, 0.13677759847093013, 0.08810538963805284, 0.23452533078530144, 0.21821948639567823, 5.716349520990926, 82.42146261276739, 76.77714840058358, 70.93724912212741, 82.62405303216751, 103.6332796465966, 62.933480201228974, 49.749138893619666, 53.46238005545832, 46.24836075690485, 41.75013957485076, 101.59746754554011, 80.65805912017822, 84.33837198442029, 76.97580860507104, 74.01633324161654, 63.93201758784633, 50.076978437362186, 29.207770632159328, 18.303301103653446, 5.687458813190461, 10.920229611858245, 46.381497767663774, 39.75574770281392, 41.90688925404703, 35.1339404813705, 37.48724491365495, 35.23435708015196, 31.667083001905876, 34.966776909366736, 33.392200239243046, 32.071546046964585, 39.032697985249186, 35.80368126592329, 29.184020680765954, 32.15933849734645, 18.665373133074855, 7.644009128693612, 4.825229183320077, 7.877309745357883, 18.812783648890836, 24.604167130685624, 18.492516240765973, 20.709459474009854, 24.84150190507212, 29.31063282874323, 24.673420498448035, 44.115983824576105, 45.9933517825219, 29.728763372667377, 52.102368800870835, 30.416007734114128, 7.561304973017785, 0.4241631186056522, 0.8754418886476948, 0.19412925406809778, 3.0923338859312, 6.384876822271655, 4.375086215234572, 12.118211676997523, 11.433828684591479, 17.33798619239561, 18.836768942494547, 12.49677138943826, 25.39552100243107, 14.687525937634131, 17.355428972551902, 22.0789118736021, 18.860962121717392, 15.081897704832016, 13.607972975700134, 16.08627255885832, 4.046405568238228, 1.397510584323637, 0.19207855926886683, 0.3509821099860053, 0.6719358409604719, 0.614580737967645, 0.33130388526666554, 0.43997872801076987, 1.3568722552830175, 4.909390009218647, 20.641327904116725, 43.754447198683216, 34.437625638900265, 23.429089746167584, 24.62825244472873, 32.2194762768284, 15.474589717003608, 16.455384262146488, 26.440479640037786, 27.767868541902114, 32.94408121416646, 30.295253645989206, 13.85045684153034, 5.352829646679663, 5.295206106478169, 8.892661352311412, 19.003395149784705, 37.71107496753816, 39.31906630915981, 48.298501276200824, 54.59029289983935, 58.9249865470394, 58.80641329673029, 53.18547248840333, 56.34225091626568, 62.42798866764192, 56.55860885497063, 54.4674168094512, 36.29762926409322, 39.9050291892021, 63.577949154761534, 45.91388456283077, 47.184155910245835, 36.9750931955153, 19.62127435591913, 0.11593512695042357, 3.1443692743778233, 8.121142416231095, 9.967033843840323, 12.220805191224622, 17.031249000180154, 30.243960811245827, 59.61848905009609, 35.040517468606275, 35.188936033556544, 44.68410384270453, 33.93860993846771, 48.86048670737974, 79.18229872180571, 62.109315702992106, 35.689179435853035, 62.45941469746252, 29.24137357742556, 0.5134052831319071, 0.14944670090992607, 0.09707680017116571, 0.07758477312182227, 0.03206782572482142, 0.09260673842002308, 0.08507098431789106, 0.12655930323225836, 0.1898182168482773, 0.1665270755127553, 0.05486312622745192, 0.0324957988285009, 0.08200856316233836, 0.03988672783898731, 0.07876973494046158, 0.21619874563428665, 0.16982733632528013, 0.05672466242685915, 0.06386027348438097, 0.14777310523054293, 0.19036186348286369, 0.307994679577889, 0.19743352918134582, 0.09259161584439779, 0.11600844922565645, 0.03883322287771491, 0.0494086453240485, 0.06721833946123239, 0.09411814562495678, 0.08706161782385842, 0.11225527723229702, 0.13322858890939143, 0.07720189003814613, 0.18872499405857057, 0.0628417787412482, 0.09502461916136165, 0.04638958091457044, 0.07315866949577486, 0.14979381534841754, 0.13047853244408486, 0.8878172116894877, 12.438815428364663, 100.76849029910181, 84.25526480520926, 78.60287835521083, 97.50515676313832, 92.25053002757411, 59.83759264792166, 37.299128040190666, 45.005573457287205, 46.67841334496775, 54.00955461686658, 101.67730346802743, 84.09331798553467, 89.79402803605603, 84.66247743175876, 84.93092444635208, 71.45761428340789, 53.77086270240046, 31.264084962106523, 16.608760702994562, 13.52881464266008, 22.902007525967015, 45.04513840521536, 37.39456715122346, 37.195455874166186, 32.89319238355083, 35.93065231077133, 38.18488943961359, 28.289451599121097, 30.02927576341937, 29.812551083103305, 28.195291180764478, 30.157123458000925, 28.746525395301084, 26.844458272380216, 28.206434634424028, 21.70904805583339, 14.68195224961927, 10.915785566453012, 9.644717977892968, 13.365866637999012, 22.464043517266553, 21.5878075938071, 22.622383717567693, 26.96895234046444, 29.269210638538485, 26.589937633083714, 41.8809937661694, 56.7136013123297, 35.16685701185657, 54.907997039056596, 36.80626653855847, 10.978148310415207, 0.44136458106579324, 0.6438137338526788, 1.7962215960987153, 4.669379688078358, 8.540195207442007, 1.0964168247676667, 8.523541804282896, 17.67659068107605, 26.487083281240157, 21.834534483571208, 22.961266694530366, 36.43279414023123, 17.537962352075887, 24.339720933668076, 31.56330689307182, 29.293095911702803, 21.466267070462628, 17.910238427500573, 19.338496961901267, 6.81068197373421, 1.7580579149146236, 0.5376329056678281, 0.3477818236475991, 1.303984119046119, 0.3640731736536949, 0.2983721555961717, 0.6932803375586387, 2.0657939632092757, 4.85332953353082, 28.10862445062207, 52.73421948955905, 38.50143255725984, 19.653018097723685, 32.16843643496114, 34.79055658463509, 17.38098321422454, 23.38650457320675, 26.06393994823579, 27.99286746209668, 28.294631088933638, 25.075328119339485, 9.940940276268991, 9.271112218979868, 9.348739847060173, 15.73016155150629, 16.64259114573079, 29.326463514758697, 33.87321226058468, 36.679762255760934, 41.87219196750272, 46.54249145138649, 50.06249312431582, 48.4452175324963, 48.09370648476386, 52.05855592604607, 47.02864177765385, 50.87592209539106, 38.79295487557688, 43.8456658394106, 54.6958399588062, 35.84346586658109, 46.48495812569895, 40.997005278064364, 31.224682792540523, 1.6156190032920532, 1.5856035558446762, 7.937904971261179, 12.465104133852067, 20.452408905952208, 25.408449134519024, 37.36041507413311, 68.46384171516665, 41.07304042385471, 36.07645073244649, 30.65141466356093, 36.46217269282187, 47.63612670283164, 77.3213380382907, 77.49882528858801, 42.48490933449038, 66.95686709496283, 42.02116750901745, 0.4879769556705029, 0.09848631002129087, 0.08964871206591207, 0.018824364186354706, 0.03419436514377594, 0.04276394723884521, 0.13949561713924333, 0.022498590819117044, 0.010110487515527395, 0.04163136285158896, 0.057017135644151326, 0.059540958684538646, 0.0824367986511319, 0.10870316501466498, 0.03392971623989363, 0.15337880039888044, 0.15909930150355064, 0.1678739500141913, 0.4019608180369101, 0.27880878277844, 0.37253357289779576, 0.36045864825287177, 0.3285613211412584, 0.13494191390852775, 0.22883447728330092, 0.08611284091227478, 0.1456474410670419, 0.22631469152627454, 0.17151086050416195, 0.14710250250514478, 0.15374757980387058, 0.2876432474342085, 0.15759292749627946, 0.2525541528819069, 0.2633466463415854, 0.21677712669535992, 0.2645227445229407, 0.3470464405273238, 0.31199451656110827, 0.3598757779165622, 1.0306598822916708, 15.809122785445183, 119.6890155730709, 91.80177950089978, 93.1588960463001, 101.87883484748103, 118.02320065036898, 86.13957928073022, 67.29709348370953, 68.34447614608273, 59.92886227946128, 50.65357077506281, 115.83527903403007, 86.36136577975365, 96.66402016916584, 91.55919659522273, 88.22751183663645, 74.08704573108305, 71.21042651514854, 38.89313613214801, 29.161933814325643, 12.565292254570993, 20.716890404301306, 56.644889231651064, 48.89187743586879, 50.566454933535674, 40.443350961131436, 46.38307456047305, 43.01313492559618, 40.74456937851445, 41.16666347749772, 44.09884306692308, 38.5441981592486, 45.077847050082305, 42.03906136174356, 38.48875937923309, 43.46458404294906, 30.245823937077677, 16.60042174400822, 13.675387732444273, 16.643510941536196, 28.79694942505129, 32.74643101999837, 29.165612997547274, 31.745255839440134, 36.4326137112033, 39.437117884236, 33.955872289596066, 57.05722055127544, 64.53512907028198, 37.04508789124028, 60.174539935204294, 48.55093717575074, 20.534698270982314, 0.9056671828992906, 0.9114860190499214, 2.075719520930321, 7.214474293493456, 14.152396975025056, 14.215851118487699, 20.538699088558076, 20.32586539945295, 28.19302405080488, 35.67322715636223, 35.488730630567, 45.69913479589647, 29.112566863336873, 31.267330723424113, 43.97786148132817, 40.37227761360907, 37.9540579549728, 33.022214827998994, 23.53227749947579, 8.989520361346583, 2.6164461960715633, 0.6255634357371639, 0.3768913568027558, 1.5617343398832506, 1.3969880510722439, 0.6703383331337284, 1.8274149803384658, 2.2318060744193295, 5.200406341783462, 31.366696126999397, 56.682453770791334, 43.025419788975874, 32.538561090346306, 40.80110642217821, 48.738450004208474, 18.771343808020315, 23.79077542212702, 34.980509127340014, 35.2957578628294, 40.380204723727324, 39.236778905314786, 20.117881721065892, 12.312499419335397, 10.831137876356802, 14.663277845228873, 25.930040036478353, 46.68823495987923, 48.09245917104906, 55.451221773701334, 58.41837321558307, 63.101663589477546, 63.82917304192821, 59.07251473396056, 58.88938319298529, 68.382609428898, 61.74335072117468, 66.54281385483281, 45.96628742833292, 51.83766372742192, 75.23058137586041, 60.241981167947095, 60.481736044729914, 45.54462871243877, 28.807943828644294, 1.4917304511031797, 4.158179635001767, 12.056337268121782, 19.451178812211563, 25.870031695212088, 36.93781498939761, 43.431722425645404, 75.5835868466285, 43.62519725676506, 47.05162294449345, 56.08992092071041, 51.04750225620886, 65.01754137777513, 91.62878728681996, 86.57053009156259, 50.163572603656405, 83.33120146105367, 53.41929281911543, 0.4504924267530442, 0.23231532034133714, 0.25841083377599716, 0.19239552048665864, 0.1615090004258579, 0.20707382640290647, 0.3811975676686533, 0.2639910795034901, 0.3200853243470192, 0.17572293448592388, 0.18976140376781264, 0.14838317168816445, 0.1993067367302795, 0.22942727611910915, 0.2037514409711284, 0.34169663404745443, 0.3344646414681789, 0.3268117908268206], [0.25355241141251983, 0.15276827428850437, 0.04721849953996078, 0.12287402195074867, 0.014549290006529662, 0.06277625907152411, 0.06864458067162384, 0.019047194265670354, 0.020232232693102092, 0.029756168819843765, 0.10512659927048992, 0.03713682459126558, 0.09795572518581346, 0.19361710896895779, 0.035440908940208536, 0.03851685920850404, 0.03363178081570133, 0.1112565513880503, 0.02936428803349695, 0.06331563476593265, 0.06460109199847906, 0.1620068656460893, 0.11115130622901263, 0.20781409716413868, 31.312904742456254, 84.66247743175876, 75.22324654363817, 76.74740898993709, 104.7517905696746, 78.4919458819974, 42.94562701256045, 44.21884798234509, 52.38355567378383, 41.91188635364656, 92.59340793855729, 92.64946645306003, 79.82331598958662, 72.96811119202646, 62.348854849415446, 35.09992568723617, 17.113216730856127, 11.377090619456384, 6.853375011874784, 6.614816948290795, 30.02695764264753, 51.93421679158365, 41.580426462234996, 46.25153787674443, 34.62479722115302, 35.57209276383923, 30.756557718400035, 49.34974747319376, 47.920655435131444, 56.70215975853705, 57.90640977121169, 55.68730531200286, 51.57551603932535, 40.47381208788964, 33.49561352883616, 28.40984286800508, 11.33752469093569, 6.6000609917025415, 6.996275292288873, 14.264468896773554, 24.376981489119995, 21.10409305941674, 20.362355209166004, 22.616772767036192, 25.644440497121504, 26.76311027619147, 41.130467845547585, 35.672277942780525, 28.56959119919808, 47.21350700624528, 33.782797705742624, 17.978217024956983, 0.7988551595518667, 1.2665981703227567, 0.6108390419713913, 3.035981438813671, 6.707800655595719, 4.7891909364731085, 6.642629494590144, 4.248598112213997, 15.9393846988678, 23.2380409009995, 15.476540115571792, 13.621291383620232, 1.8348741026655322, 16.12346055046205, 23.5013182317057, 22.18400589881405, 17.05885071908274, 13.148095665439484, 12.435869728365253, 1.7334243270658678, 0.2835069242263994, 0.547422896469793, 0.7445766656629501, 0.6207870920338939, 1.281468611090414, 1.3646245747804644, 0.4259474293118523, 0.07388970123664027, 2.2059145089118712, 11.246459022645029, 38.54990520784932, 43.57626961123559, 21.58619942203645, 23.627551870961344, 21.592077093739665, 20.087457856824322, 17.081800506960963, 24.058553672605946, 23.7139714917829, 30.68640808905325, 23.618726538073634, 9.47069319986528, 6.767554042800781, 11.174862038704658, 18.82533915581242, 46.65102343405447, 45.5837151312059, 46.922208263028054, 51.500414417636016, 54.833409247859834, 57.851516200650124, 55.58344094983993, 57.57459294411444, 62.96214880481843, 58.97629899363364, 58.817388088472434, 57.68757289455783, 29.669139423678, 27.770321984444898, 58.48590074046966, 25.84073747358015, 23.864249260194843, 33.63853685317501, 38.96450757980347, 2.96183638515011, 1.1101400948339895, 2.457763033528482, 5.237563935018355, 10.04584308593504, 21.874848604202274, 32.340791263887965, 51.616438127333126, 36.344772231194284, 36.95905070151053, 42.923744109369096, 35.110924013199345, 64.30494869908979, 82.5301593349826, 40.855023322566865, 50.9563502957744, 55.344070465334006, 1.4316267472121025, 0.1115699886013904, 0.04087688882024058, 0.046843219878933126, 0.05510316838720634, 0.040612799160542994, 0.03446900000375125, 0.011802298850530099, 0.06645468769655113, 0.01993097436253823, 0.10276097338646652, 0.08487123455251418, 0.018699039862821662, 0.08207817757201773, 0.11874996381060732, 0.05748122404780119, 0.11785967005116325, 0.030730963992555777, 0.05370667054047508, 0.2868756886211134, 0.16495255032374015, 0.2120671874933666, 0.321453710597369, 0.07941310324015156, 0.10238685434864414, 0.028581453427191705, 0.02961382202263321, 0.05569089189051621, 0.0875806347316792, 0.05499778916278193, 0.12745515112915348, 0.125711910396574, 0.19896147622456475, 0.04117254130241852, 0.0204264551341053, 0.06329041132102571, 0.04029819366311835, 0.0405073318360073, 0.09755830175333446, 0.12679899682200726, 0.0948774230275904, 0.18894430970953358, 0.15099072047779638, 55.28502310475996, 89.79584801581599, 77.83340346428656, 91.8884325027466, 103.26512598222303, 73.61981299615675, 43.085020203744214, 37.316527674275065, 49.30289083911527, 56.00432695881013, 101.15709520155384, 91.95644640153455, 86.188491236779, 82.98428350879301, 64.94929605914702, 34.144118601276034, 20.332264746389082, 15.414485277668124, 11.416466313023722, 12.49079369729565, 35.04091362799368, 50.24749955823345, 37.01657618245771, 38.99921271108812, 32.72935302026811, 33.99350743139944, 27.083126652625303, 44.31816239510813, 40.74109808091195, 46.41154704555389, 43.14085122077696, 43.27254479931247, 39.3958741618741, 31.845035053068596, 25.521531066586896, 25.748344082986158, 18.424180707623883, 15.152503309711335, 10.887010078276358, 12.14781576587308, 18.49158860022022, 20.056222061957083, 21.35000409618501, 24.492365852479015, 26.559696159055157, 27.984332384601718, 40.712735422195934, 45.60717090483635, 30.33657385456947, 53.315620653090946, 38.81383365200412, 19.40436532420497, 3.331358466417559, 0.28408642377584215, 0.9993947922222077, 2.7582347296899368, 8.103342700389124, 10.849829931412975, 15.52169934395821, 11.100296801136388, 21.83379707797881, 25.52966998469445, 23.079679127662416, 30.770023215201597, 4.07759306892272, 20.39503443625666, 35.086938719595636, 34.1645541498738, 25.70949692879954, 19.567404523972545, 14.975843679520393, 2.768263985072413, 1.369531214717896, 0.45573976131216176, 0.8080944250668249, 2.3231818551017396, 2.0076243555353535, 1.0781192130619481, 1.3339417115334542, 1.2120801667051933, 2.0397538379315407, 19.800205038439845, 48.24537669458697, 46.41959182677731, 22.208622694015506, 28.403231713079638, 25.761376157883678, 22.140283238503244, 22.183446961064494, 26.865862646410545, 26.91574735026206, 26.824809159001997, 16.039640480472197, 8.4323182605928, 10.369244467827583, 15.649866711708809, 19.79483139130377, 33.52030484907089, 43.1126925253099, 42.76669240766957, 47.446068256132065, 51.286657010355306, 54.29600531055082, 51.35596136892996, 55.503134342931936, 59.50077087648454, 55.923522210890255, 54.17552186596779, 52.638223401961795, 26.247722602659657, 28.288369024953536, 55.98760197239538, 32.968443055306714, 33.137344237296816, 39.967481167085715, 52.84593643680696, 7.940284869363231, 0.6816353721003379, 1.6668469963535186, 6.065979792225746, 10.641040205955507, 23.33108932741227, 40.91358038686937, 59.67570074142949, 46.36452567192816, 32.76107518903671, 31.022651310889955, 39.8100725297005, 58.6006457574906, 89.1512849253993, 52.59671295842817, 52.0483930649296, 68.85880870203819, 5.1503088493500995, 0.4160125253181304, 0.06833151884136662, 0.017306307338238243, 0.0442389652673756, 0.11462976675360434, 0.00841411891498513, 0.08286886457954684, 0.06373084292957379, 0.09534422338249222, 0.07685167294356131, 0.02536097684154107, 0.09896524520891328, 0.12266134062120992, 0.03676341801521279, 0.08434385196456025, 0.12766510518568178, 0.04163658374079293, 0.10365165785075196, 0.5688011622236622, 0.4512599855661393, 0.29767519944617826, 0.5823223076520428, 0.10376476307189274, 0.15341471460077072, 0.16065288184871598, 0.10946819573760995, 0.18385705688307363, 0.19272717527083813, 0.13745344123773037, 0.15109935174545935, 0.2568819521055106, 0.34855664497421635, 0.20757576721089505, 0.09538446598115469, 0.11981886330871813, 0.35610588988469494, 0.13036922701904852, 0.1960544483435731, 0.21760542095909197, 0.28735495322654325, 0.32599826673826865, 0.13785903882836142, 71.81045501462876, 103.36841767834079, 91.85970506360455, 102.10522620908677, 119.71970419729911, 98.993052974824, 57.22579617654124, 59.75082981971003, 69.85426702807027, 56.189823688999304, 105.19173929768225, 103.10274770182949, 87.73338733180877, 88.62830746558406, 75.86330675309705, 48.986524228126775, 28.42493222605798, 23.179809393421298, 18.74331847313912, 7.3567543491240475, 38.76717705880442, 59.8901524082307, 48.74541221126434, 57.26664373951574, 40.6036150840021, 45.88875001476657, 35.15596458988805, 57.44560580099783, 59.44660686677503, 66.60332033711096, 64.60231534896359, 62.90848685849098, 61.09783057243594, 50.61202895256781, 45.47188835759317, 45.95413200316891, 20.402961546374907, 16.03913841709014, 13.392727028939033, 24.61563417988439, 34.176478155197636, 30.351859331130985, 28.17522237377782, 35.241813505849535, 35.85382484620617, 37.14355114967593, 49.704780809340946, 49.93119178279754, 35.402214911676225, 54.09514857876686, 49.35202637026387, 26.532443531097908, 4.13075638394202, 2.0002244364830757, 2.2670019922717928, 11.488258434880166, 13.736803224009853, 18.260519812183997, 20.007337562499508, 8.32824601281074, 24.71153024704226, 35.44904801153368, 33.78184064742058, 40.766558185700454, 8.32890889336986, 27.928138548328032, 45.162836966976045, 46.4731635585908, 38.8994982165675, 32.093166151354396, 15.503434827250821, 3.1692128316048653, 2.351354769160671, 1.1194101264399867, 2.432579210688991, 4.487792090062173, 9.24028435061055, 2.2163119767942736, 3.353255343052649, 1.2509034189485735, 4.238399949765975, 29.384969588248964, 55.40805216758482, 53.22922260530534, 29.389280273068337, 35.07750541933122, 36.07693318397769, 26.15385832325105, 26.276450041801702, 34.109052611935525, 33.946242870823035, 38.22256380511869, 31.205008183756185, 14.611630035984902, 12.920190268947234, 16.22786129674604, 27.063671696570616, 54.18641428793631, 56.58212738652384, 53.61004160296533, 57.59764471361714, 57.126113060982, 60.63489283284834, 57.460687314310384, 62.06713061178885, 70.33128999894666, 64.70781141711821, 62.8070661329454, 69.8627628818635, 35.37355807519729, 36.55167725778396, 73.24560319223713, 38.90789601110643, 34.39002767685921, 41.95383610263948, 50.69809359888877, 7.938870854916112, 1.0206096054565523, 3.6033037449083025, 7.976659459452476, 13.789985660583744, 31.643709598049043, 51.50268546996578, 68.26829587259601, 46.01530921074652, 47.8464481138414, 54.61682381168489, 54.45675188495267, 73.62971305847168, 99.85371512751426, 57.53032899671986, 64.2602611357166, 79.94555273363667, 3.5989214768332825, 0.6965652612909194, 0.18893839551075814, 0.3338032317978721, 0.13484979949651227, 0.12245545449155955, 0.09968534487509921, 0.15672134926482556, 0.17734000819825357, 0.1535430343280877, 0.2580430502853086, 0.14113959585947378, 0.20240645104598617, 0.17729726049207872, 0.2521829219955591, 0.10119630774903683, 0.23310733268097525, 0.12329669564121193, 0.23092185237234641], [0.30470384164683284, 0.14952520960040633, 0.13963101551898066, 0.17654704590958936, 0.05959166987468639, 0.10301732938856849, 0.15130593501512082, 0.015446270755942793, 0.017440487638175968, 0.05255964922628576, 0.08233307034618433, 0.04094060435290298, 0.0176441999933412, 0.08506720750442437, 0.013876702155797713, 0.030663569322637016, 0.01839145173078343, 0.022532057370089238, 0.05320460332797901, 0.09564826069700141, 0.053996711428607666, 0.1183312890991088, 0.021714915431314902, 0.27902368576295916, 6.4290917400390875, 86.20731076886578, 70.96057937991235, 56.85400647501792, 94.33029620878159, 88.20043963770713, 38.595969523153, 40.384931179784964, 56.67959044056555, 44.78228469048777, 90.1540231704712, 85.14253631714853, 64.53804731369019, 35.42317605787708, 21.099690198898315, 13.930453581194724, 13.83553026183959, 11.080804582565062, 2.73582769978431, 29.093878730650875, 41.670123223335516, 46.095349096482806, 52.22524881362916, 38.12631276346023, 44.86422692575763, 40.76253383390365, 60.4387233334203, 53.191199148854906, 71.42824357555759, 66.94210329363423, 66.9442762867097, 58.76757398728402, 60.96163803531278, 51.807826257521114, 39.35652102193525, 34.35779756115329, 27.332179507901593, 12.565745288325894, 8.768649735758382, 9.305375103027592, 18.806343117067893, 24.34141539758252, 22.974596869560983, 24.1131373759239, 24.210580818114746, 29.758632221529563, 29.915174015106697, 36.1393420157894, 30.09056279736181, 48.512505792802386, 24.302305444594353, 10.797283899399543, 0.7849871907984057, 0.9314211590155479, 1.1570527452615, 2.075859010219574, 0.36005320387982553, 5.871589577967121, 6.169998597714209, 4.372511669512718, 14.970238612544152, 23.43530866407579, 21.77179421147993, 2.8900481856638387, 0.6828497133908734, 15.71723145823325, 28.7817031721915, 21.526240110397342, 14.336972928816273, 17.75883297766409, 11.96085108864692, 2.419469423832432, 2.0721660987023385, 0.5791724605425712, 0.6103564678661285, 2.4141803528031995, 4.741433628143803, 0.8044355278534274, 0.05743801285843215, 0.24425890687252247, 1.3599788950335596, 8.142814001729413, 33.90010795285625, 39.57721317968061, 18.573064073439568, 21.706508321146814, 16.559776183097593, 23.2079896619243, 26.850900765388246, 29.622649531210627, 26.168851583234726, 26.762890623461818, 15.025376350648942, 8.063989070154006, 12.174824226287104, 25.655436861899595, 47.15464007469916, 53.472240894071525, 49.60734521189044, 54.32698811254194, 53.45029131058724, 61.853620313829, 56.7388496091289, 60.59284502460111, 52.81135682136782, 62.95094259323613, 62.810031444795676, 68.80483688846712, 65.21444043805523, 54.074838546014604, 32.0990026381708, 50.289170818944136, 34.26454321030648, 43.25149343859765, 30.889977139811364, 27.734173420936834, 15.423551836321431, 0.22967066225265304, 1.0111242725003151, 2.146534972613858, 7.417890862111123, 14.795147930422138, 35.84078296538323, 37.48294599594609, 30.13308129002971, 46.34513347379623, 40.9925651550293, 43.00378791747555, 79.94082235520887, 65.83102133966261, 46.040161348158314, 63.586715652096665, 22.89987179540819, 1.065533430345597, 0.1151374685427835, 0.07582563606481399, 0.09060016262435144, 0.0287620356727031, 0.023915832411618005, 0.11567464939528897, 0.08175272043914565, 0.0837401133931933, 0.07967231675021111, 0.06460374266269707, 0.03757089000916289, 0.18373221519493288, 0.09456217018586975, 0.05882807173615983, 0.020188538868340756, 0.07781184924345824, 0.027051583503282843, 0.13720092333612904, 0.11674515001716153, 0.19688465782711584, 0.10206819241566044, 0.33381355866309137, 0.15632037884525715, 0.1539257105680243, 0.16095156420863446, 0.06444494029687298, 0.06483894697720967, 0.06762285686789021, 0.08098262587502118, 0.106749395659614, 0.03130466808685132, 0.11936946081057673, 0.04996219364505622, 0.04597219706122433, 0.08052886433659062, 0.0339308385587027, 0.027407762677138372, 0.17498839406236527, 0.03775563977298237, 0.18106996772750733, 0.1266721326617464, 0.7554152163286364, 15.3468842083408, 105.70109044351886, 75.21524490848665, 77.02070405406337, 105.28215777489447, 81.37884955252372, 40.95101941016413, 32.57723369906026, 49.00744222825574, 56.07968353456067, 101.73328353512673, 90.71282755944037, 73.33561374295142, 42.28120888433149, 26.079235230722738, 17.33582300524558, 19.48357758983489, 10.74668336299158, 5.339957408366665, 23.154368900483657, 38.91155166010703, 46.17056054453696, 48.60912553725704, 35.44496090181413, 36.31272646688646, 37.06564503331339, 49.67617888604441, 47.815108376164595, 58.485873283878455, 55.43654426451653, 53.29500467546525, 48.936353191252685, 47.85742682795371, 39.620280804172644, 32.140193408535374, 26.769301737508467, 23.119842237041844, 19.189076231371974, 16.569464437423214, 11.638682311581029, 16.588640905195668, 21.869647541353782, 24.411029623400783, 25.46883990687709, 24.200737630167318, 29.170861128837835, 32.66823268705799, 41.37572188531199, 33.407764204086796, 54.30950218631376, 35.59698412495275, 18.533893323713734, 2.0256561040878296, 0.8668237059347091, 0.39120402427450307, 4.979349403612075, 4.233140541661171, 11.98278498265051, 9.093117021745252, 9.712167055376115, 22.79517589076873, 29.715386129194695, 25.66979665910044, 16.0421262825689, 2.3630431871260367, 17.74655007546948, 40.93907579298943, 32.89558502935594, 25.410990830390688, 24.87766811924596, 14.345538404680068, 2.770870645200053, 1.4542837056421465, 0.19030857440685073, 1.9706777122712906, 2.815205930702148, 1.517044815324968, 1.542117953781159, 0.34723290632809367, 0.21921368466029245, 1.2543155132762849, 13.038446787864933, 43.977975230063166, 42.94116727767452, 20.094857408154397, 22.44654974629802, 20.455693890971524, 22.964783099389848, 28.17564206738626, 28.375688829729636, 28.604243378485407, 19.328761639133578, 9.767030227568842, 9.508439148626021, 15.71248931269492, 26.114054110742387, 39.62181837328019, 44.86192841683665, 51.218305787732525, 50.11838689927132, 52.689359341898275, 61.069562050604056, 59.616014034517356, 58.33307735381588, 55.64725399017335, 62.57944314710556, 61.51521782721243, 65.09429039493685, 60.74499768595542, 46.036521388638405, 31.17740058129834, 55.7055207990831, 43.422630371585974, 50.874521809239546, 37.70286152439733, 28.15844443536574, 21.82909219495712, 0.28267642362944545, 1.1151653864691335, 2.1133078394397615, 8.622917994376152, 15.675525876783556, 40.48635582770071, 43.95146393006848, 40.35518000202794, 30.166648933964392, 36.04589154643398, 43.113861391621256, 77.04922752995645, 76.30050197724374, 46.63118800809307, 72.00226676079535, 34.952785814962084, 0.9921541581711463, 0.10329892032689626, 0.04659420682958538, 0.17438212740084819, 0.08213286858893211, 0.06493542809039354, 0.031291054704436855, 0.16211177372644026, 0.104348476104919, 0.026558619330547033, 0.076118687678489, 0.043078395688245376, 0.17042211166793303, 0.12460007167030727, 0.06799935077827785, 0.07177460142561505, 0.11723270369393211, 0.02985653782924337, 0.1671922083703741, 0.5156629748882786, 0.5194725769181405, 0.36441567624288224, 0.31082071664352573, 0.3288791556992839, 0.23906709836615672, 0.23674159250672788, 0.0895218249230135, 0.14887069472141806, 0.15755871400958107, 0.11537150074277194, 0.16283198830581483, 0.1554025748684522, 0.2869565875059174, 0.14013257328300707, 0.14260124565372545, 0.10534373923174797, 0.11653840586903597, 0.12772574870576783, 0.3112844143423342, 0.21133227934760435, 0.4090319015085698, 0.2866907243526751, 1.0474620903691938, 21.44619041873563, 123.89561637755364, 88.75096782561272, 79.83285519384569, 116.12489115807318, 111.63087475684382, 56.22454058739447, 54.50063536244055, 74.3533746657833, 56.86293378953011, 105.84208396173294, 99.13522320408975, 81.83105176494968, 50.69426536560059, 32.436053868263, 26.622261885673772, 25.755267066340295, 23.60723791583892, 4.894656606258885, 36.624386233668176, 50.88052303560319, 54.7963506944718, 64.98568780960576, 45.19090152555897, 54.0671742346979, 47.03946359695927, 72.17708679937547, 62.623954203821, 78.92645820494621, 71.87642928092711, 71.77614996510168, 64.2887100865764, 65.7665297292894, 57.426860793944336, 45.33035747466549, 47.785212070711204, 37.363235258287006, 20.47745323950245, 18.782457843903575, 18.206740194751372, 27.450574290367868, 37.32834185323408, 31.868873257790845, 34.36867037127095, 33.27155989985312, 43.23879672634987, 35.991096035126716, 49.480538906589636, 32.69718174011477, 62.223150730133064, 45.88957371250276, 25.010928684665313, 1.5732945453736091, 2.2013959384733632, 4.060269921056686, 4.015782398562278, 1.6168793098580454, 9.654207171932343, 23.70570117427457, 14.930555993510833, 28.90019601391208, 37.464463787694136, 36.26499514425955, 29.512625086692076, 3.3615119322653744, 23.917775884751354, 51.5377357698256, 44.65520774164508, 37.322234722875784, 34.552221605854655, 16.059860298710486, 3.996075430224019, 2.687903445574545, 1.9330080045807747, 4.260980544551726, 4.973800720707064, 7.581242870899939, 3.707934194995511, 1.0760701423691166, 0.19551383541716685, 2.318699566587325, 21.410926349701423, 48.076667708735314, 46.10079726865215, 26.051647240115752, 32.463679121386626, 28.674771516553818, 30.765169282113355, 37.683630143442464, 36.679546525401456, 36.3527895558265, 34.44342682438512, 22.68019945390763, 12.566983776707804, 18.21567927637408, 30.629068920689246, 56.89832533559492, 58.727695249742084, 58.83255589392878, 56.12406123069025, 55.167218639004616, 64.57843203698435, 60.973471826122655, 60.32497067605296, 55.27243229650683, 66.17706852574503, 65.03636875460225, 73.0162072950794, 73.82048929891279, 59.889305176273474, 43.217231535142474, 64.17434553946218, 46.22624251150316, 52.50781243847263, 42.85718540991507, 37.32646303792154, 22.662621351980395, 0.3451990348196799, 2.519756094101937, 2.9176383826040455, 12.64509581750439, 22.872170056066206, 51.45818618036086, 48.94488434637747, 41.427606997951386, 55.93153953552247, 58.82012198048254, 59.63526502732308, 89.88445435800861, 87.33169740246188, 59.87013263087119, 91.85515511420466, 34.758887367863814, 1.3616636755966371, 0.2510897145276108, 0.2411686460818014, 0.23019587681178125, 0.4064542914350187, 0.22774989596538006, 0.12460061559273351, 0.2764112646541288, 0.1880452442433565, 0.23910952431540336, 0.1469079468158945, 0.13657165871512505, 0.2604526113117895, 0.26404029299174586, 0.21467888847954814, 0.12175879711585662, 0.18234247041325416, 0.19063512704545454, 0.2142012020152423], [0.15470525099625512, 0.0761389660258447, 0.06194192803494873, 0.08012101444746218, 0.05279060941369784, 0.11481510640512552, 0.24844920863547634, 0.07493079174309969, 0.08423499853139924, 0.06790900602936745, 0.0701381380279218, 0.05898799259035338, 0.06629658247073812, 0.027068638535697135, 0.0648222539213396, 0.03475582715304148, 0.0330609763641992, 0.0973096066304753, 0.07218710912932312, 0.08609130618072326, 0.011652231802262608, 0.05103367485947186, 0.11250398767691468, 0.14920840160019938, 0.1368754738641362, 44.66338980582453, 85.63340525473319, 45.12775921052502, 78.88204912985526, 100.86197606978878, 62.337931048485544, 41.909529009173, 49.118398235690215, 44.741162561601215, 79.72285624473326, 52.47646485605548, 25.358095707431918, 16.559909543683453, 12.506695966566763, 10.19626304026573, 3.953695691400959, 1.3854843522271802, 12.597077181262355, 88.68628009673088, 66.90876314716955, 54.63389396667481, 49.52185715398481, 35.31809968333091, 56.590046651901744, 57.97927956427298, 63.44788728221771, 69.02667045593262, 68.36838691465317, 69.04633721997662, 64.30854159016764, 60.42523038002753, 56.86276120524253, 59.30884145921277, 48.67469187705748, 40.23393169526131, 48.16486612443001, 27.998005767022413, 15.621123583086076, 9.209624163566097, 15.697125388729958, 26.62947512442066, 26.35588980490162, 25.405162188314623, 26.88942236285056, 25.637784234939087, 30.72415501840653, 28.352993995912616, 21.78216103584536, 38.39291234170237, 17.77516180469144, 5.265464734646582, 0.3409985440873331, 0.7662610601513618, 0.7764650448676079, 0.9602309066441752, 1.2244867461342965, 0.4919113993885056, 1.912565469261139, 4.957271852800924, 18.03949817534416, 29.46862589928412, 19.04065766642171, 8.029004469994577, 0.8825447494464537, 8.894996143156483, 33.253999448591664, 24.880933492414414, 25.400135670938802, 27.214818269975726, 12.560595216289645, 3.229891407874323, 2.41802599160902, 2.4559344735837754, 1.6368936939585594, 4.975417227514329, 1.7217888610978282, 0.230202526454964, 0.34865874917276446, 0.1943269507178376, 1.1531510901066566, 7.984089409151386, 36.44996627684563, 34.24002055198916, 17.5041260257844, 21.54683843735726, 16.97647702309393, 29.68528586049234, 27.06334221747614, 27.008454530469834, 22.422460509884743, 26.760662717203942, 13.289918764945, 11.755651312489665, 21.572818256193592, 43.65791766874252, 55.29711969437138, 53.05018994116014, 53.89733560623662, 55.1063395315601, 58.22444731189359, 60.58086610609486, 58.934961134387606, 58.90718290882727, 58.847676630943056, 62.67480381073491, 63.37718655986171, 67.74984482795962, 67.0391898001394, 58.17652771549841, 36.64139363073534, 45.19803239453224, 50.31179112772788, 47.72738064489057, 38.47577633396272, 56.617236521936235, 26.5213647965462, 0.1416673385087521, 0.7006100216700185, 0.540665265533232, 4.068677521521046, 9.019639261307256, 28.036915679131788, 35.49927788396036, 32.50115932956819, 47.48613918981245, 39.79820735992924, 53.8912167087678, 81.8284002427132, 63.04828013143232, 59.700933348747995, 43.9373355527078, 1.10826765337298, 0.21108999638067139, 0.021120911922245737, 0.04941028475220646, 0.12457701242378644, 0.1275068620640424, 0.13654263930455332, 0.08405780239451317, 0.038768178182503873, 0.05348269324449282, 0.07918057257249471, 0.05716605930619183, 0.03056293792812334, 0.08647241194041506, 0.0920095115960125, 0.08461558335130254, 0.027725520626371427, 0.04351757091259764, 0.06193697144607864, 0.032612351445300926, 0.114937573220701, 0.1200976963305185, 0.07149487974182253, 0.04697298368198737, 0.14278221094319898, 0.11017566261392449, 0.09870112107525911, 0.06773142684851924, 0.09960276825774102, 0.037549351447171746, 0.07246295440821879, 0.024869565912071737, 0.02505492854623064, 0.14589228276764193, 0.013835963515204289, 0.07654182102170683, 0.056086553320769346, 0.10411214564115771, 0.06000632645502206, 0.04520198758391123, 0.08171459224315421, 0.03520935120421552, 0.0677304692386139, 0.14345272173804624, 0.29589309507320005, 64.81562168367448, 94.80378120176255, 53.16915935085666, 92.78681216701385, 95.76429905429964, 58.61799832313292, 39.78132940107777, 40.22615755757978, 53.49951313387964, 94.85172825474893, 56.9948430984251, 30.886139100597752, 19.739986850369363, 19.223918645612656, 12.65677075232229, 4.191738943899832, 0.8885430953195019, 19.186244280107562, 88.44201057187973, 61.2770240537582, 41.3198830235389, 44.59036311795635, 33.56026987875662, 51.55462157341742, 47.52407243174892, 53.56023926888743, 61.2629113658782, 61.649582539835286, 60.933173394972286, 58.89600023146599, 56.66778410634687, 52.60600505336639, 55.205226405974365, 46.87397095464891, 38.53271738175423, 37.04471134370373, 25.907802158786406, 20.09481622326759, 13.530208064663796, 13.894036335329856, 12.624475917508526, 19.227554682762392, 26.290409757244973, 26.94459834406453, 28.218809712317686, 29.917321512776038, 33.15546950986309, 25.39313424018122, 45.68951714423395, 32.20648146444751, 11.284098086818572, 0.5793369549416727, 1.0722638498390875, 0.7760531959995147, 2.6478266283389065, 1.2833199698117472, 0.12893143320275893, 4.181917819284624, 9.63153979470653, 26.348172541587587, 32.372527160952174, 24.85163142604213, 12.461154307088545, 2.744372828352836, 12.194355668560153, 46.192423835877456, 32.56390352402964, 37.02710382400021, 34.9618935585022, 15.412332877036064, 3.2054876464028514, 3.4203604777013106, 2.222798351318606, 2.6693432802154176, 6.03831482510413, 3.5335331145794164, 0.22966716889171834, 0.42963292509798084, 0.3652946855272017, 0.6282539978142708, 12.331265999424843, 46.30492917952999, 37.4979765184464, 18.914571116047522, 23.245358082555956, 19.61829923814343, 31.98938023659491, 31.414945202489054, 29.43713515035568, 19.305352933945198, 11.05214088193832, 10.596780180931091, 13.766308273038558, 25.578174014245313, 36.84584325359714, 47.181943693468654, 53.7247670081354, 54.349565275253795, 55.918050504499874, 62.414036796938994, 62.542415972678896, 60.46958846430625, 60.02942400593912, 63.474206386073945, 64.65479666186918, 65.10874432902183, 65.50400941602646, 59.592605329328975, 51.98911820688556, 35.063498635445875, 48.6835015204645, 56.639233173862586, 52.54273330011676, 47.226297855377204, 58.34049455581173, 30.490877935963294, 0.32089756140785836, 0.629738002054153, 1.1065241598313855, 4.591624582967451, 9.257791849874682, 32.056344901361776, 45.05099450388263, 38.73741803630706, 30.140425928177375, 40.889410741867565, 54.984283216537975, 85.65420166138681, 68.20305901189005, 67.02046440493676, 64.88258830962643, 2.731580018035827, 0.6899533709210735, 0.01768969795516422, 0.06095192793215956, 0.11611053044156683, 0.1460696014785959, 0.06608130410313606, 0.1413197184522306, 0.16610676903397809, 0.08731050446869866, 0.11758627625362528, 0.05336641641934553, 0.04636611564144973, 0.12921122383446465, 0.08689982771512963, 0.13348982489157107, 0.019364178466099887, 0.06765210610483924, 0.0727284804827744, 0.021656223520215963, 0.460402969150774, 0.2243472704844129, 0.30506773341086607, 0.13675276190042496, 0.25451038904007406, 0.21648134014779524, 0.3619897822218557, 0.253715634105667, 0.3613691284291206, 0.20454561367871302, 0.1850187219679356, 0.09110636288119901, 0.12406918806053939, 0.2143707985599195, 0.15630188548276502, 0.1681427855885798, 0.10075371577254227, 0.2613341640080175, 0.2696839095123353, 0.12609404271408436, 0.18128127009878237, 0.15388878513007395, 0.11774808168411256, 0.27641601439925934, 0.2681984956706724, 76.14949072560957, 111.38512257606753, 69.83897762913858, 97.27759653522124, 124.23660370611377, 84.59349862990841, 57.66632149296423, 65.23865715149911, 60.80813215624902, 100.31273441929972, 71.01236251092726, 39.365895486647084, 27.141762164331254, 26.93763613700867, 18.325460533941946, 9.248263432133584, 2.6232152263964377, 21.42740030442515, 106.05044026528637, 78.45801738000686, 71.98943276559153, 59.961076705686516, 42.74492325321321, 67.18355655670166, 67.68015215473791, 69.25778435122582, 78.45596205803656, 74.04741410286196, 75.66969071665119, 67.40672373002576, 67.72070946231966, 61.77026602529711, 65.67579746246338, 54.12958306650962, 48.379525676850356, 57.95690636481009, 39.30240015829764, 23.08256991447941, 16.13280265561996, 21.91524901697713, 44.50908768561579, 33.09260568311138, 35.904968630883005, 34.835193157196045, 38.359336853027344, 37.329404815550774, 44.55059028440907, 22.101991099696008, 49.90525707121819, 45.85823397482596, 16.297982488909078, 0.35824925067924684, 0.831560678780079, 2.2406387617511134, 3.1674803697293807, 3.107126614739818, 1.413812445056054, 3.386243211646234, 12.97661650565363, 36.39842241041122, 41.99726066281719, 34.42301481000839, 21.945498335746027, 2.591118961572647, 13.505061749489078, 57.278269644706484, 41.44230804135723, 51.79114833954842, 41.27235174179077, 17.006608670757664, 4.890008107308419, 4.746991626677975, 6.827460892738835, 5.419301563693631, 9.006727799292534, 3.0675001346295883, 0.8099031280125342, 0.591527620150197, 1.018433731890494, 2.9905371031453534, 24.190425718984297, 50.14370187636345, 46.8960185973875, 24.30861065464635, 36.31087510816513, 27.7805083797824, 41.074185755945024, 39.070195844096524, 36.07265387811969, 36.34183829830539, 36.950107697517645, 20.312641128416985, 16.194822192192078, 27.83969890686774, 47.38882518583729, 60.95661740149222, 58.99347897498839, 57.886723395316835, 58.91625142866566, 61.69317968430058, 62.5844951598875, 61.351780506872366, 60.22667607953472, 63.36525078742736, 65.94007107519334, 67.90618265828779, 70.57984275202598, 70.7886540505194, 64.50502095683929, 41.51017681244881, 58.31311641200897, 61.517728144122714, 57.72663577910393, 47.34914256680397, 65.43263012363066, 37.23650347801947, 0.5615114372584128, 1.693754210587471, 1.8156278902484526, 8.517242477786157, 13.364126086235048, 38.536957463910504, 48.773621897543634, 42.930502353175996, 57.49165442682082, 59.95979016826999, 69.57819492586198, 98.15271654436665, 82.10530388739802, 77.1397715230142, 73.66281786272603, 2.2713014002769225, 0.7282932523277499, 0.08896647246494409, 0.16066651821376818, 0.26738607474873144, 0.395367129916145, 0.2099242557080523, 0.1793091912423411, 0.4357631913115902, 0.20006222199768792, 0.209486972720873, 0.2182068612666861, 0.13382334893028583, 0.1119740540161729, 0.1814537318122964, 0.2245598905269177, 0.13602070360174104, 0.2372894679466563, 0.16906863348858972, 0.23713848733853912], [0.21564851064355145, 0.16119346413160526, 0.01972197983113508, 0.05668934194311019, 0.11030885466043988, 0.21932056924748808, 0.02407929067680192, 0.0513998955307949, 0.10863559605974345, 0.12895515128489465, 0.03693150536667916, 0.07306603414397086, 0.06861977474463564, 0.01076219563988308, 0.03969886392775563, 0.05351697950954399, 0.04697256233362902, 0.07201114639399514, 0.05714591119378325, 0.026763701067876913, 0.0715753419565097, 0.024648239280307488, 0.14657304381891606, 0.05713087671826925, 0.15915383164200092, 3.9951794137877807, 92.59450620220554, 67.99893102338238, 57.058660061128684, 98.5831731365573, 78.87952312346428, 47.19557000744728, 50.50556013661046, 49.11997895086966, 62.34453239748555, 27.752308499428537, 20.51827334588574, 20.134726339770904, 8.158569672415334, 3.1588298274624735, 1.0219310764824192, 2.698782139247464, 49.171934666172156, 46.35597882732269, 55.93023730862526, 70.23875344184138, 67.89861248385522, 41.15189575379895, 51.31431364244031, 67.74765614540347, 68.7041025777017, 70.02166594228437, 69.89116868665143, 65.61269044876099, 63.780045355519945, 65.47853754412743, 60.1148767625132, 53.80202201104934, 49.31639163724838, 44.37431504649501, 44.26491622001895, 42.05585695082142, 27.745222737712247, 17.41182481088946, 18.101257854892363, 52.001818841503514, 55.54350729911558, 32.064993727591734, 26.116925285708522, 20.563629673373317, 27.698736767615042, 26.757105127457653, 24.234005212783817, 33.86766210679085, 27.7089721925797, 12.36503956779357, 3.520166412476571, 0.5172792978344426, 0.378407291587322, 3.7938054194373474, 3.4031241122753393, 7.110495202002987, 1.2388489948165033, 8.704296388933736, 28.790271589832923, 36.75172205894224, 21.05306694584508, 6.477884063797613, 3.0365796002649494, 3.095334989409293, 31.10447391386955, 32.14950903769463, 31.176712205333097, 39.486139666649606, 13.318206898627743, 6.443538319679999, 9.268641125771309, 5.13235665136768, 4.727453810553397, 5.233930839646248, 0.3535231929873267, 0.11630958306693262, 0.09490547716737756, 0.16402094144253962, 0.6448627227256376, 8.507471853686917, 34.27294884958575, 35.19734167283581, 17.769792079925537, 16.271925203261837, 20.52467073163679, 23.378385266950055, 28.947731218030377, 28.76018701061126, 52.0243057897014, 56.812829432948945, 18.515430727312644, 19.605631943671934, 36.25732691057267, 56.8956502791374, 55.475379651592625, 51.994989995033514, 58.322973328252, 66.16420315157983, 61.91350313924975, 63.420007075032885, 65.16421841036889, 60.552209269615915, 64.87848158805602, 66.96032662545481, 63.65467463770221, 67.27017817958709, 66.41190867270193, 64.1620175300106, 47.379638994893725, 49.87731410611061, 57.383094987561634, 45.023365328388834, 38.52653180399249, 48.73734781819005, 35.71068971387802, 0.7142326584266079, 0.20548440846464328, 0.605718019989229, 0.8367245403989669, 4.081958421776372, 18.513936304276992, 22.96196291523595, 38.52602189587009, 40.1130207123295, 36.674682786387784, 62.45413910958075, 80.17040652613487, 56.25221290896016, 77.09128318294403, 16.53096833536702, 0.7082986026521653, 0.06341207757472031, 0.01678871918439625, 0.032802609381295984, 0.0184242345482832, 0.020152680207824996, 0.03349730557191276, 0.09251558927879219, 0.0706964782288959, 0.151427099481225, 0.10082449463586654, 0.04578523330330368, 0.0480381982971824, 0.08701472558201322, 0.07254530886007894, 0.07479759203570505, 0.0570772850375262, 0.06706881442017133, 0.06178735447446666, 0.017889922695054163, 0.22796415543604284, 0.3000173140918055, 0.0974046781418785, 0.10396733970171022, 0.037063525298670415, 0.31266714175862653, 0.07237037268256949, 0.10195455859385191, 0.028862739845569578, 0.06794704229480798, 0.0732563227234829, 0.057093104753162593, 0.03464995380190592, 0.05159355106673414, 0.03491922221597164, 0.042310465322507006, 0.06931504550119562, 0.06385297266646259, 0.0029569145690108985, 0.10861445969391255, 0.06732033640747109, 0.10454993424636704, 0.221047607220469, 0.07164861826646714, 0.3861301013779256, 10.091618126438512, 110.2725971898725, 69.98482704162598, 74.46458954964915, 104.54531700380387, 71.97783823936217, 39.59406760431106, 34.12171010048159, 54.547460617557654, 74.70234009527391, 36.85766135492633, 29.983739006903868, 24.235407460120417, 8.62647754530753, 3.350608478630743, 0.8516139801471465, 4.215352102633446, 52.60191794364683, 51.17042149266889, 60.761597156524665, 62.919693070073286, 58.316042500157515, 35.71671055209252, 45.398406674785, 61.032993793487556, 60.36663016965313, 63.28176313830961, 64.14917176769626, 64.21791130496611, 63.03753675953035, 65.25753551913847, 58.61519382845972, 55.534160290994954, 50.861295577018495, 49.3575333779858, 44.22501394825597, 39.243572450453236, 27.480562771520308, 20.308775632612168, 19.564819682028986, 48.67809649436705, 48.73486888024115, 31.802567551212928, 25.1379075742537, 24.792127109343006, 29.73679050322502, 30.224966733686387, 23.62225471004363, 39.3989767566804, 35.296989487063506, 15.223093225109963, 1.0363891167986778, 0.3552184536332085, 0.4597954307833026, 2.5715208390066704, 2.95828860132925, 6.411561687146464, 1.5773016142268337, 8.244135687428138, 31.64015789185801, 42.27152455237604, 27.616682744795277, 12.54673356010068, 5.9474908728753375, 3.0185553287306144, 39.9152155845396, 40.43727128736435, 39.886064529418945, 46.010029700494584, 17.514518345555953, 9.341333431582298, 8.916137718385267, 4.447325977586932, 4.602268424726302, 3.292008513404477, 2.4398275056192955, 0.14445634288412912, 0.278526617274169, 0.30617834639645397, 1.213975529516897, 12.1333892883793, 41.238078071225075, 39.74591039842175, 19.334786399718254, 18.083738588517715, 25.125965918264082, 29.19891392031024, 30.28869152069092, 30.45772017971162, 43.42536818596625, 47.60873679191836, 19.39316499617792, 21.926535637147968, 37.38353352392874, 49.49920938860986, 54.67301960914366, 53.507471622959265, 58.79479131390972, 67.50991344451904, 64.22293978352701, 67.02805811359038, 65.37679518422773, 63.87491572287775, 68.48547750903715, 67.63287974942115, 67.18822417720672, 67.0267794209142, 65.48368369379352, 63.19280378280148, 49.75580300054243, 51.63291992679719, 64.02605249035743, 50.26958642467376, 44.57811747827838, 58.82368741496917, 42.02066936800557, 1.2949182958372178, 0.5941486827308132, 0.7862664963449202, 1.1149163159631914, 5.936997061775577, 20.15318109143165, 35.36654879969936, 33.95313055284562, 29.368750587586437, 40.61361320557133, 64.7496238831551, 87.89357692964616, 64.5852412716035, 81.89790464216664, 27.536811520976407, 1.4792791321392984, 0.053905765300676714, 0.06295607522911122, 0.023086885057930506, 0.11815344944836632, 0.06058778335911132, 0.05096176218601966, 0.1734641242411829, 0.059755206663882544, 0.10625314688490284, 0.12991915036353374, 0.040939949347727725, 0.06395888049155474, 0.1744325819515413, 0.08562936282326138, 0.07119913149865405, 0.18477921223928853, 0.011821022039399514, 0.031213534267378912, 0.1134023636639599, 0.4644886692685466, 0.43087760347031784, 0.21562460870031389, 0.25056829976458705, 0.20564902543781266, 0.3744714995545726, 0.2448707506541283, 0.14964015343256537, 0.31385237170803937, 0.2713438688266662, 0.13866842604212223, 0.24356962692353035, 0.14854974984642, 0.2337034410166164, 0.12468924430469353, 0.1147696084433025, 0.13778353320254436, 0.28535518795251846, 0.12865371100844877, 0.23080127013306465, 0.11044488123227512, 0.20232832539946805, 0.3614542561192667, 0.17956633631500507, 0.6370897494977521, 13.388147661762854, 130.3280681179416, 86.42362948386901, 83.64353195313485, 120.96522931129702, 103.48944633237778, 61.80730104446412, 64.57144629570746, 62.41611565313032, 78.97523680040914, 52.78624972989483, 40.62275232807283, 33.64398894771453, 11.453337573236036, 6.186821643383273, 1.9991535068519655, 4.90159478879744, 61.57519478951732, 63.1398674749559, 69.89797007653021, 85.05103526576873, 76.4567142917264, 49.96274725083382, 61.22412696961434, 77.94648539635443, 74.05621590152865, 76.35843538468885, 76.17985771548364, 72.10776282894996, 68.66670670047884, 69.51033007714057, 63.53838028446321, 56.70075555001536, 52.39440494968046, 49.9387776467108, 48.906955026811175, 51.46097890792355, 36.43164096340057, 29.15872923789486, 23.170944836831865, 66.70480774294946, 72.07923935305688, 41.33002235043434, 32.452774932307584, 32.06888864117284, 35.956865510632916, 41.14800084021784, 28.55785939001268, 48.49947567908995, 45.607343489123934, 30.612724404181208, 5.516434158048322, 4.680428514557501, 0.6160187769320704, 10.495735022329516, 5.612159602103695, 16.559989952271987, 7.872498958341538, 16.449362443339442, 42.7435504236529, 48.291107608426, 37.24156333554176, 23.978137239333122, 5.606406955949722, 6.371410835173823, 45.837829805189564, 48.49087784367223, 46.643159081858975, 48.96253501215289, 22.069676653031383, 15.309277503721177, 13.475191920034348, 7.135677799101799, 5.03914789807412, 7.621507471607578, 3.238794452721073, 0.5905697038096767, 0.23197290968270073, 0.38771155200177626, 2.0430292621735604, 18.77822756767273, 46.63327470902474, 49.984237917007945, 24.818632525782434, 30.603651961972638, 31.91695759373327, 32.589436192666334, 39.626768404437655, 40.500507739282426, 67.51348280137586, 65.90222804777085, 22.217004799073745, 25.025780739322787, 40.00286486841018, 59.2021490681556, 63.30616028078141, 57.705517738096184, 60.948713825595, 66.67355429741644, 59.991635891699026, 65.6115411943005, 64.62291563710859, 61.77982876377722, 68.18643600709977, 68.1962497772709, 67.74796209027691, 70.85724846009286, 71.80296328759962, 69.01474645060878, 54.45027212942801, 59.436020389679946, 67.30254557824904, 54.33269123877249, 49.88607275870539, 60.84777555158062, 43.98660052207209, 1.6868297563445185, 1.2796208070170496, 1.543084572880499, 1.966323513657816, 8.056532154160163, 25.997306723748487, 37.00512286155455, 44.98305905249811, 48.63357367054109, 56.058232092088275, 73.35407241698235, 102.84225525394564, 70.09177438674435, 94.08051967620851, 31.556895779025172, 1.4434051345432959, 0.26989951729774475, 0.1290244056332496, 0.11638259124611655, 0.17988011060703188, 0.17349832240612278, 0.13192967151201543, 0.2070953075083033, 0.30223602729458965, 0.33092577491075764, 0.20852821368363597, 0.16168492485678967, 0.19002216477547923, 0.27463513576695997, 0.19499651156365874, 0.34555036274175494, 0.27407938494316997, 0.21351835720481413, 0.25690269776650015, 0.2494756285581858], [0.15376550626129876, 0.18347873202254697, 0.06571866872329866, 0.0433964524117689, 0.23563313988908646, 0.1832923734740865, 0.05836714344519762, 0.05146107531242794, 0.06280024528443333, 0.06097741184696075, 0.060191493736760276, 0.04123237659974445, 0.022870785061029658, 0.04033864310552036, 0.032432067974080006, 0.10977505225568049, 0.12940538115799427, 0.07415777072310448, 0.08462173503733451, 0.03505085527356114, 0.12629300340889923, 0.0983044254263082, 0.060002997802991065, 0.09577517082253773, 0.13090653044562187, 0.0645936532847343, 40.72280022405809, 89.40002595224689, 47.46681367197345, 94.01665564506285, 80.17048497353831, 66.0115994176557, 48.643830668541696, 46.23784488247287, 54.78632511631135, 33.11442582837997, 19.225403262722878, 7.7268819462868485, 3.8427487544475065, 1.9931919944863168, 1.3265227935006543, 4.00569063040518, 64.13279979459702, 59.40982287929904, 44.14173810712753, 56.03816132391653, 58.84406020564418, 41.371254305685724, 60.03904557997181, 64.28904741041123, 62.86767067447786, 65.25162450728878, 64.47833707255703, 63.30591317146056, 66.66883176372897, 62.87632342307799, 60.06032443815663, 62.701103302740286, 61.86912936549034, 57.08932907350602, 42.1014113580027, 43.154355941280244, 44.66593934643654, 32.321942314024895, 19.97016918274664, 12.913995865852604, 24.982564064764208, 30.04498681714458, 33.977406101842085, 23.95047276250778, 19.02312074938128, 18.581206913917296, 27.350449908164244, 50.167408681684925, 35.443858715795706, 18.84344481652783, 5.514747048577955, 0.3941755261152022, 0.5185589711031606, 0.4443653781087168, 10.039885986235834, 13.074304115387703, 14.562203268851004, 15.669464834274786, 37.677617149968306, 43.71676498843778, 28.349526620680287, 5.641770555127052, 3.7349375072986852, 2.02600323384808, 11.075917309330357, 39.3995572674659, 34.980611108964496, 54.32244208551223, 18.791410653821885, 6.375949507759464, 16.75098584544274, 10.807723287613163, 8.552751694956134, 0.48430356407357805, 2.068141011461135, 0.3116377340930124, 0.2231617187780719, 0.0393393388648908, 0.39236002030872535, 8.533198679647139, 43.76216250081217, 30.826721076042425, 23.51041813050547, 24.114431758080762, 21.859886723179972, 20.870309991221276, 31.16881451299114, 29.84097649974208, 54.73731902337844, 57.60466967859576, 18.89823248309474, 30.11698388284253, 50.086737294350904, 52.79972307143673, 52.33502811001193, 56.587371595444225, 63.0121119560734, 58.77398706251576, 69.43712296024447, 66.38403631025746, 64.67272189355666, 63.89814792140838, 61.32752064735659, 61.65095144702543, 65.35090754109045, 71.73465128867858, 65.93655663151895, 59.35273670381116, 53.805838477227, 54.2945775678081, 58.8981379232099, 56.36643625074818, 59.30044758704401, 41.95615814578149, 28.59767733081695, 3.1236223876476292, 0.013179681845940651, 0.3824221438938572, 0.5315391358829314, 1.7752307869734305, 9.539494514465332, 15.141368681384673, 31.829327921713556, 34.18932391751197, 44.74438674988286, 75.97214468063848, 63.72576367470526, 57.10422623542048, 44.90406643959784, 1.9605760156146943, 0.06357884725495692, 0.11860793110944572, 0.06796833187822374, 0.03800206344514605, 0.036106478467944174, 0.06854097494074414, 0.09056702166074708, 0.03702822013667995, 0.09226039006945588, 0.0812721151798483, 0.11349475386762813, 0.13303778705097016, 0.06011605322841675, 0.1512657460426131, 0.09672638389372057, 0.032328010251324986, 0.10338776354347506, 0.09281779564316235, 0.09408836778734, 0.06150524642679, 0.0674354717616112, 0.12893786834132287, 0.09817208373738874, 0.021459946048355872, 0.07144501507883111, 0.0912872668836386, 0.11957535460110634, 0.040551619378909956, 0.0334232363609537, 0.04533390026359309, 0.13770856383827426, 0.11603301000450889, 0.032807749831267906, 0.03409698004684141, 0.1347476493326887, 0.005617160631734277, 0.0659589828442662, 0.09990010996379199, 0.04441796937176297, 0.042083094257020184, 0.03633815111712583, 0.042376463797183773, 0.08175077457581797, 0.04937283837446763, 0.09355691727250816, 0.05025234178549821, 62.38919250426754, 92.47890610848704, 57.509693407243304, 107.12171800674932, 79.22658228105115, 55.722598798813365, 32.38468258611618, 49.237493161232244, 72.45512008666992, 42.95212245756581, 20.35138826216421, 7.763259478153722, 5.532936549955799, 3.3393056786829427, 1.4053654983159036, 7.539323520275855, 80.75270591243621, 70.59637161993211, 45.91213910810409, 61.164248066563765, 58.36516234182543, 40.58390517388621, 52.20244415344731, 57.38896677570959, 61.38564625094014, 64.00595034322431, 64.88678916808098, 63.907549842711425, 67.52120987061532, 65.32384710927164, 64.03497980486962, 64.5917720179404, 63.82353267362041, 58.04916051126296, 42.31771830589541, 39.12038257045131, 39.80108245726555, 30.67110888419613, 21.938436108250773, 24.09067003957687, 28.21595814920241, 29.493048537162046, 32.02911776881064, 25.516826183565204, 19.758969160818285, 20.976990615167928, 22.30341657515495, 52.31091730056271, 47.71076156247047, 25.41953963618125, 3.898070598802259, 0.5959889484990029, 0.3877579462864707, 0.3126234441034256, 12.95981405242797, 17.638994762974402, 12.310816722531474, 13.926314500070388, 45.979556806625865, 55.24612103739093, 36.684539702630815, 18.023498827411284, 5.253713313610324, 0.9186970514635887, 15.8261723479917, 47.22224996935937, 45.975673660155266, 62.33587180414508, 25.067748138981482, 8.635067535984902, 17.990639171292706, 12.714994415160149, 5.102854544116605, 2.0655576404063933, 1.4141973276292126, 0.4126162124016593, 0.017519574725039063, 0.06468183766569822, 0.6361008832050908, 12.118352882323727, 50.083383667853575, 39.17341301518102, 29.910826067770685, 31.198393106460575, 27.527537076703965, 26.463694187902636, 32.37796944956626, 28.76824748131537, 57.07995460879419, 68.19822665183776, 22.155809940830355, 31.29962948060805, 47.80527891651277, 49.858176862039876, 53.10282030413228, 56.17922544479371, 68.24363200895249, 63.904521772938395, 71.27740490821101, 69.54231308352563, 64.53819244138657, 64.36149750986408, 63.64555904942175, 61.95644524789626, 63.166433688133, 73.67412213356265, 66.79309245078795, 60.9414025275938, 55.876030152843846, 58.41465480865971, 66.14740756250197, 64.38070143422773, 65.79812049865723, 51.63659518764865, 37.11308610054755, 3.532736873434436, 0.510725507572774, 0.7015191535315206, 0.6897362922468494, 3.419704951586262, 11.82356519083823, 27.259225383881603, 29.848797705865678, 31.64712206009896, 50.23416349964757, 80.38650558840844, 78.25032003464239, 66.28199977259483, 69.73075943608438, 4.636412166780041, 0.6206152431907193, 0.21159527733200983, 0.05042096539851158, 0.06803997642090244, 0.04311760406821005, 0.013895712627638734, 0.06628294610568593, 0.016171244656546943, 0.09179430217632363, 0.024498915337326548, 0.012308856295872361, 0.06089990290122167, 0.048397570142462376, 0.1706067541794431, 0.0750311262785427, 0.06418388051491591, 0.11547395734176522, 0.04265521254931246, 0.2226311569252322, 0.07452727791162268, 0.3580736633270018, 0.2512288360946602, 0.1560219875987499, 0.19975422400861018, 0.21449979244460984, 0.18973790019029574, 0.18685177118787843, 0.14445217536582103, 0.10324982175182912, 0.11041403087156434, 0.22052259184420112, 0.22245909357743882, 0.11259443201725522, 0.11198049681561609, 0.13177991664457706, 0.2189865395907433, 0.2551305218930206, 0.23023883902257491, 0.17476818974941008, 0.08814416900877992, 0.17319530398855287, 0.1676397262922218, 0.31831333233464154, 0.20893217184610907, 0.297784106505494, 0.12613810809148898, 72.85667665543096, 112.48704187331663, 72.88919310415946, 117.69451387466924, 102.23233453689083, 82.43857199145903, 65.92601330049577, 56.40389880826397, 75.2416895281884, 52.5003638575154, 31.09453658903799, 12.21320559901576, 7.3418934691336855, 5.851857114222742, 2.460812676337458, 8.581358521215378, 75.95817319808468, 78.34567285353138, 59.0375546486147, 69.30703363110943, 72.42697315831339, 49.7747362813642, 70.53249189930578, 70.2899403725901, 69.69992176178964, 69.4275680665047, 71.63928278030889, 67.72309426338443, 71.54245515023509, 65.5077160558393, 62.88770221894788, 66.12038243201472, 69.73566239879978, 62.82076304958713, 47.88523643247543, 48.466410098537324, 53.64659417060114, 43.540489750523726, 26.790435467996907, 19.83684193703436, 33.68795871734619, 38.65317336974606, 41.38484924070297, 34.36878412000595, 25.924852701925463, 27.69771302900007, 35.05871334383565, 60.66494603310863, 54.14966560179188, 43.88738416856335, 9.80877503272026, 1.0940566610905433, 0.9012605838717953, 0.2623829383763575, 42.416267856474846, 30.73124078012282, 28.981881333935647, 21.179506509534775, 53.47464138461698, 58.687887114863244, 44.91654349911598, 30.169643663590957, 7.9302891992753555, 4.594967913243079, 23.184596646216608, 52.71901638277116, 51.68899413078062, 64.47337135191887, 30.341015938789617, 11.286964358821994, 21.708514613489953, 18.66701268380688, 10.193424224853516, 1.5545827558925076, 7.820181894686915, 0.7582418969081295, 0.5779456166971115, 0.15694601220950005, 2.1873893997361584, 15.1010202400146, 57.82618161170714, 43.40630938929897, 35.96978187561035, 43.46344263322892, 34.02690249104654, 34.02136018199305, 44.17050869234147, 43.08291781333185, 64.57323489650604, 64.14755967355543, 20.639127454450055, 35.078525235576016, 56.7598892027332, 58.902354471145145, 57.57846432347452, 59.960723692371005, 68.14499224385908, 60.183024021887014, 71.05597926724342, 67.34872756465789, 63.16213477042414, 64.73249881498276, 63.058721480831025, 65.37502227290985, 66.05954647064209, 76.55038833618164, 67.29114717052829, 64.7273918890184, 58.80265566610522, 63.945420326725134, 70.3735496151832, 67.43822820724981, 70.04377242057555, 51.6336690995001, 36.55360314153856, 4.2946084949278065, 0.7253389721435886, 1.0483804152857874, 1.3038624029967094, 4.881440670259537, 16.378892160231068, 32.69071963525588, 41.0497493897715, 48.28767553452523, 63.56238911228796, 91.70774459838869, 87.62277649294946, 71.61776465754356, 80.68131093055972, 3.7827931200304343, 0.6281770212996391, 0.3948092953332009, 0.18939440168680685, 0.18079344063035904, 0.2048374778561054, 0.13744666902047975, 0.16555608971224678, 0.10718385944323194, 0.24937277359347193, 0.26160787190160445, 0.20020825367781425, 0.12453437196992098, 0.1367863778385424, 0.2625829792551456, 0.19161696065097086, 0.20399338685937468, 0.37815950810909277, 0.2725000793655073, 0.366270650899218, 0.20900660494883216], [0.024021920267372363, 0.16331618651747704, 0.11129373729589487, 0.07387314607659656, 0.05792429482924843, 0.11310490704472027, 0.24565925431107324, 0.05401385647635307, 0.10091008197876716, 0.15238840193037065, 0.04587244092216415, 0.13471469223018617, 0.02606289724128381, 0.04710253298042282, 0.08170139254821886, 0.0104124688415698, 0.020458868314181606, 0.12399328406900169, 0.034424225995016676, 0.03419512357082098, 0.160604924744656, 0.17383727034734142, 0.09819466800939652, 0.043596493290557016, 0.11917664414091457, 0.4438766753000598, 4.96592705288241, 99.00159589705929, 59.65841485608009, 78.78088335837089, 89.06712655098208, 64.57769855376213, 48.868362826685754, 46.389071864466516, 59.69723063130533, 26.278322973558982, 9.862646825851934, 8.437854686091024, 3.411331917009046, 0.931209167165141, 1.2653892222912082, 11.11244143978242, 43.452401161193855, 37.32591390609741, 45.51311246810421, 66.36261232437627, 59.41276465692828, 50.45910750665973, 56.94287169364191, 67.20083851968089, 64.58687689996535, 69.6133158283849, 68.00101772431405, 70.16846456835347, 70.44182239040252, 68.16374117328276, 61.8194172459264, 65.09096422503072, 64.78942809566375, 65.1609040075733, 59.393772540553925, 57.50419032189154, 45.05193979509416, 38.57613017482143, 31.728456327992102, 19.41531462054099, 22.826062594690633, 30.214625404727077, 32.5934507385377, 28.153486559467932, 28.476658482705396, 18.34050282355278, 28.509194543284757, 43.99481788758309, 31.18313116412009, 10.636883474165394, 1.6955486949413054, 0.8124120966080697, 0.3828481807103081, 3.4438437079229667, 2.6666147814643, 11.206345923485296, 26.36070255310305, 32.788725937566454, 42.850364408185406, 48.28521228605702, 30.65051840197656, 17.797450673195627, 2.7707147309857034, 0.5377483704397755, 4.482248800416147, 21.684307705971506, 49.56286553413638, 52.35602063517417, 20.828513214665076, 6.734658104758109, 20.281932892337924, 16.395789730933405, 9.392837093722436, 2.7876424549087404, 0.8918087749231247, 2.163354095912749, 3.021948424077803, 0.12336938206346766, 0.3341814034408139, 6.648629740361245, 29.766557370462728, 30.56899193794497, 22.618106372894783, 15.441069141510996, 26.077177947567357, 26.838674737561135, 29.007633655301987, 30.882014728361565, 22.459768133778727, 11.802663860782502, 20.08196653858308, 38.82959373535649, 55.262779343512754, 52.11867017130698, 56.4685159344827, 59.69670111133207, 64.03350891605501, 61.58433391201881, 70.09866206876694, 63.076242708390765, 64.64954068583828, 61.42786272110478, 69.01643306978288, 66.25701427459717, 72.62556276013775, 69.02962792304255, 63.24876031567974, 59.768268677496145, 62.771007783951305, 56.35250006952594, 57.303510096765336, 54.882501632936545, 58.494663315434615, 42.52092845978276, 40.535667865507065, 14.640108404621003, 0.2564039592060351, 0.5545456142675492, 0.12343901179490552, 3.222046912677827, 8.990043017172045, 11.319742625759496, 24.2804794157705, 35.98760904804353, 47.46517019887125, 77.42565739539363, 53.31377713910995, 57.0623980799029, 27.66794812294745, 0.45638468477033806, 0.12164159332432094, 0.11616658509498644, 0.22360192822112193, 0.0622071783178516, 0.06298688345498617, 0.10724158416832648, 0.13142656625038193, 0.1016170662196894, 0.045453601501761906, 0.04566661990998734, 0.02208595288046185, 0.08363345097149573, 0.028308218592898022, 0.07998647408620005, 0.09526159313897933, 0.0480552897187731, 0.30561766196643153, 0.03637037660566069, 0.0779303400627067, 0.09489756347911973, 0.06101027318847276, 0.21027236606084534, 0.11191940896453396, 0.08653920714653308, 0.01498496133623825, 0.13398738367663277, 0.030058622247569507, 0.0230749647298287, 0.077886650068385, 0.14096935580094017, 0.07104777550745396, 0.03625849712519877, 0.14021957022768838, 0.030872079303428054, 0.07986148684135369, 0.1082610173691665, 0.04111246468739645, 0.07328589371736012, 0.044335182080225605, 0.09326869201275612, 0.07447577382047331, 0.18289409968401157, 0.05815906247364418, 0.06879137843967446, 0.0850651543887873, 0.8293794119550336, 12.942661527664432, 124.47221263762444, 61.18338138826432, 96.70748787541544, 94.3115629688386, 70.01852020140618, 42.424344016659646, 43.065388741031775, 76.27164902225618, 30.83013353809234, 12.97089082579459, 10.143313984717093, 3.5455036980490533, 1.3727751374244692, 1.7766299699583363, 14.652357966669145, 53.49805401217554, 49.95162340902513, 55.341705276120095, 69.01390706339191, 66.15223992255427, 45.82874167350031, 53.07628939228674, 64.60274288731237, 64.82847136835899, 68.58277582353162, 69.8802488080917, 72.79569948873213, 71.9549943554786, 71.55590103518578, 64.6761461227171, 65.45696058580953, 63.514081201245716, 65.74263857256982, 60.15224518314485, 56.18660342308783, 43.945105768019154, 38.54878733235021, 28.629879989931663, 22.401281672139323, 21.337862399316606, 28.363305907095636, 29.944411362371138, 30.884613298600723, 30.106158141166937, 25.292313637272006, 26.40875158771392, 45.1818722294223, 43.44966334681357, 17.807384075657016, 2.623304215169722, 0.5056388063296196, 0.8181921380662149, 3.7702025569254354, 3.4384296113444917, 14.720641528406452, 33.3633747408467, 36.21163914280553, 47.92413457747429, 57.99747936187252, 37.45818015067808, 33.53781038714994, 4.135699060655409, 0.7179140479814622, 3.810791243468562, 28.436295332447177, 61.325202526584754, 61.19543483180385, 28.507715809729795, 10.708053900349526, 27.124797913335986, 19.748280702098725, 10.413369171081051, 2.5939614542068976, 1.9952973266763074, 2.331890987773096, 1.829506951955057, 0.18819273149053897, 0.3893755256168304, 7.9225969410711725, 36.83991655226677, 39.76972703010806, 26.04042926142293, 24.53333697011394, 28.212596677964736, 27.821618741558446, 27.806529383505545, 28.410231182652137, 27.043997087786277, 20.293872587142452, 24.10542795735021, 39.48389214854087, 52.835475475557395, 52.678164897426484, 58.55870777560819, 60.54975778825822, 67.52126478379773, 60.916009103098226, 70.61637570781093, 63.32996122298702, 67.63878683890066, 61.96632177599015, 67.58933359576811, 68.45214520731281, 73.85170352074408, 69.73896503448486, 66.82409486462994, 62.423003335152906, 63.11370918827673, 58.252770746907885, 63.375719593417266, 61.01262492518271, 63.903435276400664, 42.61042125763432, 40.38406825834706, 14.443628057356804, 0.19661674155823647, 0.525072495783529, 0.396858764391753, 4.0781326399695494, 11.752452619614141, 20.192791146616784, 27.32492704545298, 42.02533698851063, 57.38368726545765, 89.63212828482352, 63.199295305436664, 67.49270208420293, 35.848863047938195, 0.5581519272058242, 0.06558774429703913, 0.20939343338531835, 0.034134832451180104, 0.10177400699185749, 0.03045798579771673, 0.18104459489545516, 0.03326324655884697, 0.11140870411069163, 0.07431545460055913, 0.003855911805482221, 0.031694846242786415, 0.04572483110091379, 0.032510404294777306, 0.03165361347548183, 0.06078406274619122, 0.09967861096224478, 0.1738453755575803, 0.13707507041192826, 0.11515940164005566, 0.07588553647961348, 0.10520169120882789, 0.18429679135161062, 0.241847813670193, 0.1439506329235531, 0.1715383783824021, 0.1799831494328476, 0.5043241381645203, 0.26884819951749617, 0.16918541593176706, 0.259048770512304, 0.14618302845666487, 0.17724348111979424, 0.21408720813210935, 0.20881952627772288, 0.18381430917689878, 0.19240019362299673, 0.1368113982701494, 0.1562745667873852, 0.1869442226785806, 0.1407445549604393, 0.20897885724421472, 0.276382337174108, 0.140619222976027, 0.1723910955291602, 0.3178195733456843, 0.9198651210434976, 15.79467865728563, 144.91612372859834, 79.56307457339379, 108.22137017403881, 113.24714229952906, 86.56616841593097, 63.49976062774659, 59.10863191850724, 78.44381839998307, 38.66705463778588, 16.139020592935626, 13.43697528685293, 6.551241701649082, 3.0565930037729205, 2.6646957618574945, 20.423691272735596, 56.76491375892394, 54.33176555941182, 61.24071859544324, 82.23780155181885, 73.86993469730501, 59.67503786087037, 63.85527641542497, 73.67919768056562, 70.81405531975531, 72.65234470367432, 73.9864996940859, 74.30744371106549, 73.8189438850649, 70.66352259728217, 64.46273388401156, 67.33388531592585, 68.81163043360557, 69.53149518659039, 64.37943843103224, 64.20150795290547, 53.86932596083611, 47.45301085133707, 41.19173526763916, 27.882619442478305, 30.83581509128694, 39.40077320221932, 40.74833485387987, 39.6959041010949, 38.444012980307306, 28.45298109516021, 37.80499612131427, 51.82874818002024, 49.79631716205228, 30.07989198930802, 4.733506027729281, 2.3057790340915805, 2.0107363885448826, 17.59082805725836, 12.042405989862258, 23.57846733062498, 46.812829048402854, 50.07376209382088, 46.13257238941808, 58.43873423914756, 41.78764527843845, 48.21553530231599, 8.81676152829201, 3.265110124503413, 9.601859219612615, 32.24085711663769, 65.51172079578524, 60.79966768141716, 34.75632998251146, 13.325792762541003, 36.61775350570679, 29.40671128611411, 14.358701878978362, 3.8090720195924086, 4.7179592232550345, 7.340502988907599, 6.15961020031283, 1.0167220463195155, 2.348102879139685, 11.89205369641704, 37.98288345336914, 47.13514589494275, 34.13056681233068, 28.47609954495584, 35.75762087298978, 39.3330221022329, 35.71427083784534, 40.96465749125327, 29.341580329402802, 16.783188504557458, 26.05019988552217, 47.1094661374246, 61.73694941305346, 61.086820479362245, 59.97836651340608, 59.860275714628166, 64.90724432852961, 63.33143211180165, 72.41061687469482, 64.32401534049743, 68.13848110937303, 62.83282041549683, 69.93139651513869, 68.48414390317856, 75.60452445860832, 73.6372361644622, 68.82175799339049, 66.39505817044166, 68.90806582666212, 62.297401197495006, 70.88155931042087, 65.42664066437753, 72.41283693621236, 49.63679828951436, 50.34746116207492, 16.84809588616894, 0.22860779186650632, 0.9271026907428619, 0.6712993751129797, 5.522390767451256, 15.23860521854893, 26.577038918772054, 38.953026802309104, 56.4345403640501, 66.69639818130001, 103.4637704972298, 74.05609038568313, 76.40528417402699, 43.54741665624803, 0.5051949043427745, 0.18026372147423608, 0.3841500398853133, 0.3147748641429409, 0.13487316517820283, 0.2614368504333881, 0.2805998963454078, 0.1965031307190657, 0.1498259910412373, 0.21685304600865613, 0.09110862284057564, 0.1221712741760477, 0.20290762576605045, 0.10879058330770462, 0.14857737497696955, 0.20636648210065983, 0.1569506393805627, 0.5737113568090624, 0.3175477040631156, 0.38124114274978643, 0.33571051493767773], [0.08714705961005342, 0.04796724323363555, 0.04846477520561988, 0.02109229279261443, 0.06211174291468436, 0.24321158807123863, 0.1278058125547344, 0.033694381690433914, 0.061740692058998736, 0.10619578988201196, 0.07610355744198447, 0.17178435389313007, 0.04079956756604295, 0.0931954003810402, 0.03656718459340834, 0.04292791303727896, 0.04738827994573982, 0.05263850265633195, 0.042612296303794275, 0.13289003933389343, 0.015379523430320044, 0.022420875029638413, 0.028787500435306184, 0.11396703175118855, 0.08275903055384275, 0.05248903507186521, 0.1985945047870759, 25.970665985538115, 72.30072775194722, 65.71203624048542, 102.39279870064028, 65.46625660311791, 42.191759232551824, 43.29372167587281, 31.609826203315492, 13.322822547728016, 9.049503207206726, 3.0016942851005064, 0.5326999123058012, 0.6887650153329296, 1.1887980805289362, 23.012643860232448, 66.82540493626749, 53.34468933843797, 41.34491558997862, 53.61556430016795, 68.5906284086166, 56.34593009948731, 66.55097238479122, 64.03635655680011, 69.56521188059162, 69.06118731344901, 74.3080085323703, 72.42371759107037, 72.77240845464891, 70.24516259470295, 69.67191603875929, 63.964353607546904, 65.81115061236967, 59.70517735327444, 58.2886996576863, 50.972184904160045, 53.2144784158276, 45.316134960420676, 40.95072915477138, 40.64842031848046, 28.3699131396509, 27.346558916953306, 39.46245639554916, 29.594779129951235, 30.891028335017545, 23.294730917099987, 20.932824727027647, 44.35310286860312, 26.339292295517463, 8.487680554389954, 1.4315552865305257, 0.1988588051209527, 0.5177768259759873, 3.068674884496197, 0.7734397330111074, 8.07308945925005, 20.83374957884512, 28.36995432453771, 50.0811557615957, 46.74101045054775, 34.993594154234856, 23.630313219562655, 2.2603454849412365, 3.359115609238225, 3.3491876000358216, 12.261136962521462, 43.895950625019694, 57.160190613039084, 16.488777360608502, 5.010368487527294, 21.78450465202332, 19.656428598588516, 14.604305990280645, 6.359117146461241, 1.7787808997015802, 0.8727496718206714, 1.7206546832476894, 0.15232120069765276, 0.6726571280629404, 4.282434438505481, 16.557922863191177, 31.873278079494355, 37.12711641865392, 21.90067937297206, 27.67821688805857, 27.2809455087108, 28.603052939138106, 27.784434672324892, 30.17647643243113, 17.575393530630297, 27.2195545319588, 46.55958906296761, 54.00192560688142, 52.102757115517896, 57.00906953504009, 61.85433810757053, 65.57156439750426, 68.67864639528337, 71.89600190808697, 67.4664378935291, 71.4157469041886, 68.525877921812, 69.57618667233375, 68.87922071641492, 74.67570720180389, 69.48746265903597, 67.87784745616298, 66.38526008975121, 63.89763016854564, 59.89522011049333, 62.754980979427216, 55.41855627490629, 62.359978691224136, 58.95019169776671, 59.31399153124902, 20.51760065940119, 0.06816559185784671, 0.2828777821794633, 0.1208910110196279, 1.3087717395636345, 5.536224967049015, 8.621755011620062, 24.40894880602437, 35.23388247336111, 57.86491501715876, 70.16013345410748, 48.943554662889056, 49.07314585101221, 6.347047523144753, 0.7613903957028544, 0.0545562390658644, 0.1873875884038787, 0.1290673218787678, 0.09474629175759132, 0.04967563462653949, 0.04446471222646294, 0.062480441880442446, 0.036754431803860975, 0.018965739967121233, 0.10974390312067925, 0.0793787825011438, 0.10708871132303631, 0.027937989366511186, 0.029837510120424054, 0.06116607248963368, 0.04855477904540397, 0.04402450661385252, 0.07077108753184158, 0.10119262286612105, 0.060212641593910037, 0.10776222518254673, 0.11053120401958305, 0.013969034902871618, 0.05666089326804204, 0.09200495337286303, 0.2230981334803566, 0.24497241052168034, 0.06044405377319744, 0.09578226479671656, 0.11519157733287542, 0.10225429049422664, 0.07783832524212138, 0.053280384745448835, 0.06581040775223125, 0.11263684264474338, 0.022686288106225194, 0.08496531014961582, 0.05120360465239614, 0.10500499813426888, 0.19049629659181644, 0.04317422945713324, 0.05071897360105669, 0.01378239385948907, 0.16415957271331744, 0.048529915661821445, 0.09006724888158422, 0.48798118447584493, 54.16294674719534, 83.25768839928412, 72.73892710285803, 106.54060317624001, 70.93870039909118, 44.97930534424321, 36.66447285682925, 50.61073457041095, 23.119024422860917, 10.97227652226725, 4.4388119828316475, 0.6958192142267382, 1.0992329639773215, 1.3960139549547628, 25.661949957570723, 71.45226417049285, 53.703331255143695, 48.89566644545525, 66.22772985889067, 73.92356134230091, 53.73065448576405, 61.60576966501052, 64.31011446060674, 68.20765602973201, 72.22064864250922, 77.34676284174766, 73.89056636441138, 75.27821463923301, 73.67178440093994, 70.90973761773878, 67.56910985515964, 66.48039325591057, 62.566146312221406, 60.34559057604883, 54.990092246763176, 50.53144777974775, 44.75565964175809, 36.15795758462722, 36.24377904399749, 28.81912846719065, 28.5227188756389, 33.3872345186049, 31.56152809819868, 28.149099388430198, 29.289352009373328, 24.965515482810236, 44.5126844990638, 35.59030825091947, 11.651959534614317, 1.040540332755735, 0.41680842938442386, 0.7191996660924728, 2.0111983702067406, 0.7388641625162095, 9.878550075715589, 30.840672946745354, 37.85035440998693, 54.27367525715982, 54.82137541617117, 42.71730192245976, 40.821502747074256, 5.472377605976598, 3.624950080148636, 2.2793155379833716, 15.559911074176913, 54.97674834343695, 63.01305332491475, 26.04803473718705, 9.48928915685223, 27.62626705631133, 25.801313730978197, 12.145932047597825, 5.997342236580388, 1.5764355058631592, 2.4325434190611688, 3.4593265287337767, 1.574720449505314, 0.9694466992251336, 4.952443415118802, 22.163487980442664, 41.60456472827543, 30.786512859406013, 19.566769100004628, 27.841899356534405, 26.393511218409387, 27.815060538630334, 26.555665923703103, 29.880390436418597, 20.66290682361972, 27.284104977884603, 43.1907751483302, 53.71572594488821, 55.33238964696085, 57.84745262515161, 65.3424273767779, 67.03426330320298, 71.30617941579511, 70.63713289076283, 68.23152757460072, 71.1146265460599, 69.57731631494337, 69.27709810195431, 71.41656275718444, 76.75140980751284, 72.76726230498284, 69.8304033279419, 66.9529604142712, 64.83888133879631, 65.55465898206158, 65.88516573752126, 59.829508642996515, 69.03253047697007, 64.37539054501441, 60.45053751237931, 23.023773585596395, 0.061166080150512926, 0.30638681424240916, 0.09719203511673598, 1.774748948312575, 9.371957336702655, 10.813701960348315, 33.901210138874674, 47.1254615629873, 65.50073423693257, 83.9421106153919, 60.44917644992952, 67.34640552151588, 11.72795545670294, 0.40354278960054923, 0.18246069310172913, 0.12223301320186547, 0.10200664491182375, 0.058797880211063934, 0.09928363135024425, 0.05014682466524744, 0.010254982231755652, 0.07175329652044081, 0.06977499703005438, 0.05534889874979854, 0.09900776308871086, 0.03739752814233784, 0.03134282501113992, 0.02503848063849634, 0.01326753585148723, 0.1430262252688408, 0.04198690425724753, 0.13875686323210118, 0.06006380986242045, 0.13656419701874256, 0.16514931234621233, 0.2665884852890046, 0.15133602694878656, 0.14895931577249882, 0.14802743109964556, 0.3523994032894412, 0.5376102907523033, 0.2692133783092422, 0.16921834239075262, 0.3034940662403261, 0.16008744767356306, 0.3455291267844939, 0.15949262636563472, 0.18378925810177482, 0.27412240844099756, 0.06442657716932797, 0.21026046105450202, 0.13174872154430037, 0.23199843573233775, 0.26870442013586726, 0.17539641249083704, 0.1004109527134607, 0.13087597885920157, 0.2616026318602024, 0.1857383236769707, 0.2855770776589071, 0.534858196493118, 66.93745920735022, 101.47551321214246, 89.82266918305429, 126.7240688877721, 89.54145093117991, 58.606945083987334, 58.33962378963348, 45.813989639282234, 24.775329559080063, 16.233285934694354, 6.297626149269843, 1.4695648921112863, 2.1000051210003514, 1.4139459282159808, 29.23086750891901, 83.67119250759002, 67.38460940699424, 55.6637240225269, 68.43453376523911, 85.31868996158724, 66.53596539651194, 76.45140340251308, 69.69547379401423, 75.25940295188659, 74.52710428545552, 80.60590728636711, 74.12590857475035, 76.46091907255112, 72.77529531909575, 72.95308066952613, 65.37039779847669, 69.52582343932121, 62.14534267302483, 65.40101189767161, 54.56044366282802, 59.14776540571644, 52.75070128902313, 50.564815382803644, 49.340702487576394, 35.37431901501071, 35.1799734177128, 49.92304894231981, 40.40406842385569, 43.69041842799033, 34.617148599317, 28.99351900623691, 52.609076269211315, 46.20445766756612, 22.8298221865008, 2.2333475658970494, 1.598199389634594, 1.0765959851203428, 9.131861213714846, 0.7287907804692946, 17.683019445788478, 31.527493692213493, 40.473925836624645, 51.01808840228666, 56.416666123174856, 44.00900510049636, 48.1229438320283, 8.754387017219297, 6.929140985012055, 5.5994432780050465, 20.52555130374047, 58.38020070906609, 62.16122434985254, 30.809798009933967, 14.334805819296069, 33.68324402839907, 32.520084765649614, 20.94049099952944, 8.636195217409442, 9.241804269052322, 5.377228260040284, 5.230350696271466, 1.9988648449220967, 2.884996663178167, 7.691724271543565, 30.104291092964914, 49.74950367404569, 47.39099817891275, 36.05637996427475, 39.21548435764928, 39.28682834871354, 37.41961540714387, 36.72835649982576, 37.05166178364908, 23.065941026133878, 34.1131083426937, 55.020882852615856, 61.99775172818092, 60.30845749762751, 59.2244359754747, 63.94456525002757, 65.32472179782006, 70.62807221566477, 71.70397835393106, 69.51666862733903, 71.24050324962985, 68.33449763636436, 70.68197342657274, 73.09076370731478, 78.41796213580717, 72.70494368768507, 71.84291655017485, 72.05596400845435, 67.21393923605642, 69.55349968325707, 75.38106702989148, 66.3601569206484, 75.32001926052955, 71.05033889893564, 70.83208253306728, 26.533930109393214, 0.1146102698159314, 1.1466822436740323, 0.5289742735124404, 2.3676151998581427, 10.964324897335423, 16.839558847488895, 52.981364111746515, 59.367975111930605, 79.19446591408023, 94.93063849787559, 64.56033422100928, 83.55888720481627, 11.097135370777501, 0.8101604722680584, 0.24313954516283928, 0.33586786939732494, 0.162909516403752, 0.16340155935575887, 0.16679909801290882, 0.12487241592738899, 0.20309398431451092, 0.16345078816577313, 0.21507802028809825, 0.48161900812579744, 0.14571641962374413, 0.20560653820153207, 0.11465442712388693, 0.1284208739056222, 0.09245881450272377, 0.25909727919966946, 0.21679024212062362, 0.25229527645053407, 0.20918930159701457, 0.1910343048192801], [0.04893506126057717, 0.14411293631119115, 0.092232565756046, 0.04525764004117058, 0.04903191775684396, 0.29804595535801304, 0.28927369704169614, 0.03604685767523704, 0.020270611782888734, 0.09894288310240354, 0.04064297153344078, 0.10072804416619963, 0.0898483622398588, 0.014212871113071039, 0.06562297668067679, 0.023342867592169393, 0.06563572438373681, 0.02244520598211356, 0.011785063787453599, 0.21081282576966673, 0.05342730125712772, 0.06150840653947765, 0.030782900923382372, 0.037916533558839755, 0.0332643075906221, 0.09915429272598798, 0.11115621685260728, 9.870938716396209, 75.74382351290795, 69.28873969662574, 103.75109980183264, 82.730160990069, 52.67048881899927, 37.078039723057906, 20.52620045600399, 5.286598955431293, 3.982894305259951, 1.4758892237178742, 1.0304698924864493, 2.1160809551515887, 6.157898576028886, 25.548012948805287, 45.45859152270902, 39.68347411001883, 53.13997691677463, 65.21580542287519, 78.4794335211477, 55.383223564394065, 69.04494870093562, 64.7971983109751, 72.65268202750914, 74.3505270250382, 78.34574345619448, 75.89014360981604, 79.70144794833276, 73.59802815221971, 73.539671128796, 67.32384404828473, 67.32382835880404, 66.7481420886132, 66.2207401952436, 61.23986351874567, 56.373633800014375, 48.86897079406246, 45.34540760901667, 45.01269255914996, 31.072235953423288, 27.222245277897006, 31.819859320117583, 30.011146568482925, 35.138090349012806, 26.354856260361213, 22.069184395574755, 41.55977518327775, 28.588938290073028, 7.205193475369485, 0.8633511213044968, 0.28506778240684544, 0.1667987915777391, 3.765621718860442, 1.9752080498203157, 0.9290495959501114, 6.917851913359858, 16.821462992698915, 25.352880916287823, 43.57048411523142, 29.71427413725084, 24.980120428146858, 5.184793347312558, 2.1840343023500135, 1.5917071315550035, 8.508002354252724, 42.378291468466486, 52.3925143672574, 16.917370826967304, 4.737798571586609, 22.6408443527837, 19.82205460148473, 17.042670942121937, 10.773019136921054, 7.253636708182674, 1.9257492908547003, 0.9131818925661426, 0.10252805967484752, 0.36787064085083626, 0.22476924703486506, 0.4368913017453686, 31.26995675025448, 28.270906632946385, 27.604219413572743, 27.840624586228405, 27.946393259109993, 33.62945264385593, 30.927465192733276, 26.258397333083618, 22.501311917458814, 30.728828522466845, 46.47994925898891, 50.8912899417262, 53.33195732485864, 58.64475673244846, 66.11331432096421, 69.91837424616661, 66.45586275285291, 66.57506358238959, 67.34093773749568, 66.59498137812461, 66.39359904873756, 69.20180428412654, 73.91182561074534, 72.96913100827125, 68.26293791494062, 66.23521374117944, 65.12415139905869, 63.54009043785834, 59.612272093372965, 58.785048146401685, 56.85719143959784, 57.23600610609978, 58.90490793412732, 62.30899964609454, 14.185740063267371, 0.18892857426356888, 0.48800193013683446, 0.3475474007427693, 0.8212969392057389, 2.4897867345040847, 1.4621798045212224, 33.88766619466966, 28.46237321053782, 79.5325977571549, 51.48969457995508, 55.10430774381084, 40.85408195372551, 1.250678127811801, 0.12427862883815843, 0.08411909708933485, 0.17376504357784026, 0.035761290740582256, 0.12684582777681852, 0.070037052726313, 0.03439131102734997, 0.03981132946547963, 0.07909598114389567, 0.03333071209189873, 0.011890923732050486, 0.1375291154028908, 0.0376064364888495, 0.09079743792573292, 0.020219013845968633, 0.08507971772022786, 0.24720053128417463, 0.008773244654519424, 0.12178525779276125, 0.02486037094176056, 0.04838423638214027, 0.04609549125175803, 0.25315969942077515, 0.10167056980032114, 0.015549684007231508, 0.06477562981026788, 0.27488080484251826, 0.22241957876230442, 0.08706860454572786, 0.011141898501063547, 0.041084897013441216, 0.011699406539029893, 0.22861148441030135, 0.08690500646949777, 0.0645570725863499, 0.08763868887458118, 0.05538996872341922, 0.07333943560238808, 0.06586410285484406, 0.020562602364788615, 0.18106187783902694, 0.012371698488301087, 0.13183538141029497, 0.08489990156264075, 0.019015418853791013, 0.05949317395026165, 0.04508130958363895, 0.6228614129847097, 15.981667849325365, 95.8898070550734, 76.18907528538858, 111.65806462687831, 87.53603719895887, 52.74647297397737, 34.21900449260589, 38.05710646413988, 12.02507793903351, 4.089183182485642, 2.361324453546155, 2.239434839256348, 4.7417464371650455, 8.827773582550789, 32.764477845161196, 54.55985922967234, 49.95513393032936, 61.02783979908113, 74.86594999990156, 79.22269913458055, 58.077574160791215, 70.08902088288339, 66.4959179970526, 73.53841597034086, 76.21726928218719, 80.38383837669127, 77.85591002433532, 81.59348164835285, 74.70714892110517, 73.33962240526753, 68.14797324519004, 69.00737239468482, 65.39850158076133, 68.0737776910105, 62.308615253817656, 58.28586378405171, 49.997719103290194, 42.141144967848255, 38.3002188897902, 27.15182500500833, 29.39998834363876, 30.481460325179565, 30.626970452647058, 33.760581401086625, 31.646057136597175, 19.215207061459942, 46.01599170315651, 37.100044219724595, 7.662233931403007, 0.44355133308037636, 0.28811601561404043, 0.04154242770445924, 2.376442248782804, 2.69333666370761, 1.272297251609064, 11.261345398041511, 27.343956424343972, 32.21652665445882, 51.61973684064804, 40.914906147987615, 40.11568007930633, 7.461119303780218, 5.23727220873679, 1.7715161798461792, 11.103986770875993, 51.75341121612057, 59.92339841781124, 23.020031644452004, 9.559239725912771, 28.230959253926432, 24.482724666595463, 15.911435850204962, 10.493158025126304, 8.70290296693002, 2.1400888023837923, 0.7166476127120757, 0.44881481677293783, 0.5150836285564208, 0.16812861296198062, 7.347842233796274, 39.15153011198967, 23.573564367909587, 27.569451524365334, 24.919994415775424, 26.684564813490837, 34.102902335505334, 28.389660312283425, 26.858984770313388, 21.738267752432055, 32.56853388201806, 46.64836014470747, 49.91608281289378, 54.85837121163645, 61.16541301050494, 69.07561379094278, 70.70583712670111, 67.40383686557894, 69.84730874338459, 67.4206324546568, 68.03253789101878, 69.68029422144737, 69.81825182514807, 72.7256694916756, 73.68333185872724, 71.67456842237904, 69.72685275539276, 69.3466809488112, 64.94949217765563, 64.25531502692931, 65.29333106933102, 63.99989812604843, 63.60549596048171, 64.87746177181121, 67.03427114794331, 16.433942625599524, 0.1340677462998898, 0.3394417614946443, 0.226513292159765, 0.9742135434381425, 3.1229948084200583, 5.528872484161008, 53.11179860945671, 41.87703217229536, 82.20377106820384, 67.13698233327558, 60.19620710803617, 53.435535353998986, 2.225070874537191, 0.15566186498730414, 0.08805311179809994, 0.06925219564788765, 0.03225979012166781, 0.04522490510416608, 0.009950174998882557, 0.03627703262252673, 0.021803067253542044, 0.06448919719625866, 0.018637203160793554, 0.06837836511793637, 0.042610147427166664, 0.038248640334894585, 0.061690467334682905, 0.07016844446620635, 0.08920485604434245, 0.08547072899678061, 0.011936475320028202, 0.0945208014379586, 0.12413959920166001, 0.09504243836648042, 0.22862001862977782, 0.22070000248570598, 0.12157847534023947, 0.13236343049474303, 0.11944888880656612, 0.4609883522554752, 0.4362025274144065, 0.30253918360798593, 0.12025662127041048, 0.33364621441691156, 0.08597649258351134, 0.20703313181236868, 0.23185225083462654, 0.19243063795710766, 0.18372961049599035, 0.1647636023980956, 0.22832168867030453, 0.12713536304692108, 0.1850028486261445, 0.31225722343210255, 0.23666201129315362, 0.27523418588023035, 0.25725014928367834, 0.11511343636459882, 0.1396968531151933, 0.1572760428872801, 1.0108116473401747, 20.95330930525257, 123.15566908928656, 94.58445795120733, 134.97719857000536, 105.65962314605714, 78.02746665093207, 52.33479669017177, 45.4585091529354, 15.601024377730587, 6.858895257596047, 3.7524793273018258, 4.581684806654531, 6.125597367363592, 14.098172168577872, 40.16094423109486, 53.96467093498477, 53.67343102732013, 62.86050842654321, 79.82792085216892, 93.56788942890783, 66.68808275653471, 78.0361193995322, 72.41261728348272, 78.2652799544796, 77.87101114949873, 78.05411523388278, 78.53166380236226, 84.93560775633782, 74.62173538823282, 74.2872356599377, 67.84961423566266, 69.75604303421514, 69.36513177810177, 70.44077119519635, 63.49217084146316, 62.336377789897305, 58.71786186772009, 55.76337575912476, 55.08707284927369, 38.34709905808972, 35.10335383876678, 38.69350710222798, 38.62512057827365, 45.86547074779388, 37.56067560565087, 28.59029543015265, 53.07517936152797, 51.2666097764046, 18.16950317352049, 1.340023591633766, 0.811465150646625, 0.31972906281871183, 6.669267781319157, 2.54995834442877, 1.7641492332181625, 18.34793375384423, 33.746680521195934, 37.41839162765011, 55.06873969108828, 43.611465038791785, 55.57778881442163, 11.314271899961657, 9.220540119755654, 4.658318604192426, 15.755982514350647, 55.02706058563725, 59.297713695033906, 29.65022183233692, 16.265443486552087, 34.393036134781376, 27.46614217758179, 28.532222778566425, 15.335722123422931, 13.94927703565167, 7.047808372205304, 1.7222866343875087, 0.5616115189848409, 0.46353197866870516, 0.6976191531265936, 17.997668058641498, 49.40462143190446, 37.82987963768744, 42.98864364624024, 37.45275551272977, 36.65288225297005, 42.818467693944136, 38.95792192028415, 34.84826641698038, 29.06541605149546, 41.28124767734159, 55.06093809681555, 56.954972205623505, 58.744024076769435, 60.960186758349025, 68.82382900484147, 69.73661945712182, 69.51280901508947, 69.79790256869408, 69.03606061012515, 69.88311213831749, 68.20739715330063, 69.6545320941556, 74.64519900660362, 73.05848260079661, 69.37820896025627, 70.69465052696967, 70.65243013443487, 68.56120278758388, 66.08925450232722, 71.32253569941368, 70.65599164655133, 69.92231230581962, 69.07468026684177, 74.58000136959937, 18.872354645882886, 0.2165714474094491, 1.24454231512162, 0.4911033911330085, 1.6095590639498927, 3.990908197818264, 13.025717716063223, 70.2274570157451, 49.55534242814588, 102.00762194971885, 74.52703368279242, 73.52087513093026, 64.77239716437556, 1.563951704771288, 0.18898151093913665, 0.186746311524222, 0.16520306107497987, 0.1560611959787146, 0.1740730262451595, 0.11447758338744603, 0.07982119827741578, 0.11791762460263507, 0.19330252262373127, 0.09188698349340309, 0.21642245862993503, 0.18272824164840484, 0.25178251848105465, 0.1989870942047527, 0.10940478664011725, 0.1654789906235472, 0.29512345250095096, 0.2094062576971708, 0.24353637870761657, 0.2671849000598154, 0.2602468707388447], [0.17919484495876298, 0.10190361374688726, 0.07388116701716378, 0.10386890506431942, 0.12020232861921673, 0.20094673179330366, 0.2178943586806136, 0.05814869730402866, 0.10235276343601366, 0.08406331822756799, 0.05773961018290251, 0.07980707927697128, 0.07204534455893502, 0.040395624725328344, 0.032541250825048454, 0.012192385075914284, 0.10406857056002464, 0.059469708677140944, 0.17976133633525143, 0.04613410974402101, 0.05114294198011199, 0.02276090507005011, 0.00267388386419043, 0.06137241444159901, 0.07630202784052781, 0.030342340995106968, 0.24335539809638457, 2.3053289421143073, 66.01530997983872, 84.37485787176317, 95.262800493548, 103.08974112233808, 57.19808070890365, 36.09621947811496, 12.478693185314057, 4.000375083377285, 1.7972540374725097, 2.8955627929779792, 0.43373863543233565, 0.9838725638485725, 0.8662410501030184, 27.777070422326368, 64.58566488758211, 55.930676614084554, 64.63803637412288, 72.53513643818518, 71.07664231331118, 63.29636612246114, 68.91586349856469, 66.69638249181932, 70.33017604581772, 77.36984991258191, 78.25772546952771, 79.8399939075593, 78.70631910139515, 78.65293564334993, 70.7778439983245, 74.38796997070312, 67.16104215191257, 65.51777301296111, 61.623800800692656, 64.59022268172234, 60.367402876577074, 50.76144772191202, 40.813963951603064, 44.97436708019626, 44.18661002189883, 29.9620424162957, 27.920856668103127, 32.51878449993749, 29.242901340607677, 34.12141200034849, 51.049432062333636, 43.67538398311984, 27.074252290110437, 6.904978204158045, 0.9041381326894607, 0.020415360265741908, 0.26168987395301946, 0.33020540711379825, 0.524131249516241, 0.5366784214012085, 1.1875431672219308, 4.178772568702698, 7.006322443485261, 23.262820474563107, 26.933870661643248, 17.920518959722212, 0.946437708072124, 6.233033047568414, 1.877303116263882, 11.557160750512155, 45.758280215724824, 54.10255009128202, 21.797322957746445, 6.5742052178229065, 28.708311703897294, 22.11461720928069, 17.0920104365195, 17.71099575104252, 5.568054510701088, 0.7052268965109703, 0.5834383445401347, 0.1956247189833272, 0.08272261073392245, 0.23150040197276303, 2.176375629440431, 26.146800018125965, 21.912795574434345, 13.24063418372985, 28.860213333560576, 24.181535666988744, 30.387784319539225, 28.591719250525202, 30.071402019070042, 29.140131319722823, 38.99490987100909, 42.516625619703724, 49.37514874242967, 51.95764903099307, 62.09055500645792, 67.38643723149454, 71.79074902688303, 69.10312529533141, 69.55768877460112, 70.04296441232005, 72.60490755881034, 72.77910786290323, 70.87280458019626, 74.78399599752119, 72.72951341444447, 74.47257549531999, 72.56528377532959, 71.8928247882474, 67.53329077074605, 65.2272822779994, 55.162633388273186, 54.43696744980351, 60.29458015195785, 59.13626893874138, 58.15023606823337, 10.39233349984692, 0.19707139941953844, 0.5398930489055572, 0.24226899348920394, 0.533483712182891, 0.5503191991198448, 13.318547164240192, 35.04585973678097, 40.01206282646426, 91.41210771376088, 42.89983334079866, 71.59023746367424, 18.918599390214492, 0.7016822996158755, 0.09347175893884513, 0.07950300365806588, 0.0672507526413087, 0.01456164413191859, 0.018379657807189132, 0.08859889581799509, 0.022531009744852785, 0.053538782371869015, 0.04495192882454684, 0.11894678712011346, 0.10270689523989156, 0.05720309965733079, 0.022340960567817095, 0.03188602922995004, 0.09052161562947497, 0.04737697631841706, 0.05325286303676906, 0.1293389153696837, 0.1469219049378749, 0.08922989179770793, 0.15135278895256982, 0.11763623284716761, 0.08933339027627822, 0.11303505514778438, 0.05762203100828394, 0.07378556690509282, 0.2763489663841263, 0.21077930176210022, 0.1182225275964987, 0.06064955302844606, 0.14176984107302082, 0.09682468829616424, 0.16188827523541066, 0.10012140212159965, 0.03902414347976446, 0.05566676778178062, 0.0740363228044683, 0.07741670109211438, 0.033457465169410554, 0.10153838132898654, 0.11542936336369285, 0.10092311313435917, 0.055881755035971446, 0.019768699703197327, 0.045752371961791674, 0.029855534254062562, 0.056462150908285574, 0.1678115598136379, 6.639215561651415, 91.93222184335032, 87.76890831608927, 106.08706735795545, 99.54834292011877, 60.709865016321984, 36.59817695617676, 19.9694670784858, 6.6989679682639345, 4.89233309222806, 4.000166952610016, 1.8515442984719432, 1.559222306936018, 1.7198862664161192, 27.53153593309464, 59.89764805762999, 61.230975427935206, 71.6494966322376, 75.10461838014665, 78.25175562212544, 65.9551251319147, 69.75697655831614, 69.7197061969388, 74.49434464977634, 81.4286950326735, 83.24900427172261, 82.70957639140468, 83.08943440837245, 77.99684862936698, 70.33770699654856, 73.91898785868, 69.65672862145209, 67.1741428682881, 65.72240698722102, 66.55867591980966, 60.86931328619681, 50.12896160925589, 39.96220165683378, 40.16425078915012, 37.159554419978974, 27.549735730694188, 28.32799869198953, 31.97465762015312, 29.189488464786162, 24.201533871312296, 40.44903055314095, 50.273999091117616, 34.76500626533262, 6.464471518993379, 0.5377036921920315, 0.32325800087663437, 0.092719690423579, 3.2764070408959545, 0.9303608933283437, 2.5121246326354245, 0.8220724653332465, 2.874255007313144, 9.228317199214812, 29.3930830109504, 34.327603155566806, 28.847512698942616, 2.2391803754914195, 5.841440769933886, 1.4976338633606512, 15.580340739219421, 55.41641073842203, 62.011028951214215, 27.99266153766263, 13.894510942120707, 36.04161616294615, 25.6477705893978, 19.442555481387725, 23.169113089961392, 9.310470261881429, 0.11264562201235565, 1.7201517618471578, 0.024089385800424124, 0.040887533611948454, 0.2903248309608429, 2.770001595058749, 39.86854722422939, 21.63037903847233, 17.445835682653613, 22.5063717749811, 25.62414223147977, 31.32199875770077, 28.550204884621408, 28.241575148797807, 27.210515429896695, 39.3622947508289, 43.53649285531814, 52.23487038766184, 55.60135049204673, 65.08026792157081, 69.02266963835686, 71.50887181681972, 71.81767217574581, 73.21249838798278, 69.67397920546993, 73.77052614765783, 72.83973201628655, 74.03261892257198, 74.5404403440414, 74.90258493731099, 76.25941122731855, 75.46586867301696, 71.43731209539598, 70.7404088973999, 69.75915739613195, 63.224092529666045, 62.39347181012554, 65.49608622827839, 62.729756216849054, 62.419849749534364, 9.951880747272122, 0.16778321456043951, 0.17288837852256914, 0.19100615874894206, 0.2806109586550344, 1.0950306346339564, 11.531161319824959, 53.00651827166158, 40.43936583303636, 99.37951626316195, 54.754263662522845, 78.0394926378804, 29.478902509135587, 0.6633310188208857, 0.1436080077602979, 0.0634596478043785, 0.010309628241004483, 0.019880544709702654, 0.029028471476668795, 0.030634457981514356, 0.03341522691170535, 0.010530337214379782, 0.04784383029947358, 0.11375699342498857, 0.0280633979597159, 0.1051602075477281, 0.03547388519490919, 0.026166349754578648, 0.0917018736682592, 0.006241232134221543, 0.10545459215439136, 0.22147597294420968, 0.1480959346818347, 0.06527128869727736, 0.12480832501164368, 0.33885254795032166, 0.19530044928673776, 0.14094134762642846, 0.23335742974473586, 0.20930162540847258, 0.3569466867033513, 0.3283094927187889, 0.33044810376821027, 0.2048345820437516, 0.3358017100441841, 0.1949831203467423, 0.26162926107645035, 0.2277874649171868, 0.13585633177670742, 0.16324601286361295, 0.3146751194951996, 0.2549160479177391, 0.1788250543177128, 0.269518128085521, 0.1874655148675365, 0.1257895074424244, 0.18772662827564826, 0.14819198678578102, 0.15056724239501262, 0.16313201898048002, 0.12975004411512805, 0.6119054976490237, 7.258741672961944, 106.42540316427909, 99.22177422431209, 126.66386835036741, 123.41452198643839, 84.2438663974885, 56.42302428522418, 26.90003041298159, 9.701318760072033, 6.7443939178220695, 6.799024199285816, 3.6632449155853646, 2.2781518197828725, 2.54099793491825, 33.70846094623689, 78.48042195843112, 67.07988831304735, 76.78067853373867, 86.20542803118306, 86.81980456075361, 73.16509262208017, 77.14442345403856, 74.76634533174577, 78.35081900319746, 81.85278169570431, 83.71516227722168, 83.41761912069013, 83.59398457311815, 80.17636068405645, 72.84724727753671, 74.51733758372646, 68.3440995985462, 67.42782608155282, 68.6449218565418, 68.09308359699865, 65.23135762060842, 56.84180398141184, 49.523759503518384, 53.54648743906329, 53.343081166667325, 38.928174664897305, 33.12183126326531, 45.25240036749071, 37.79114623223582, 46.21482841430172, 60.040594916189875, 60.361017257936545, 44.783473168649984, 13.753470355464568, 0.978582512226797, 0.48369722080326855, 0.8534225605187878, 3.4859420166861628, 5.595317925176313, 1.9862362838560537, 1.0202938546576807, 13.899349185728259, 16.201402948748683, 40.623897660163145, 39.84818227829472, 45.27529916455669, 5.067471333088414, 12.69412152228817, 6.864229681030397, 16.149968908679103, 61.7623899059911, 63.98361244509297, 34.543360971635394, 20.66518964306001, 41.661337114149525, 31.842128576770907, 29.11976441260307, 25.636197636204383, 12.287862031690537, 1.2820293874509874, 3.0962491468075783, 0.4010632081377891, 0.211131947355405, 0.4274605448928572, 8.798017501831055, 53.447890820041785, 31.90142893022107, 18.708021063958448, 39.35260257413311, 32.45167470747425, 39.29306099491735, 35.9110051585782, 35.967993274811775, 38.31052687860305, 50.08294828476445, 50.188287458112164, 57.43308951777797, 57.01841262079055, 66.4831232255505, 71.50169387940439, 71.8088625323388, 70.4637876633675, 74.48295408679594, 71.41161272602697, 75.89561139383625, 72.51221410689816, 73.80019495564123, 75.52759893478887, 75.93933797651722, 77.14435285137546, 77.67905035326558, 75.16324212474208, 73.63946407072007, 72.83243640776604, 67.95997404283094, 66.55092531634916, 73.60990508910149, 70.18849219045332, 69.84810106215939, 11.651222129021923, 0.4664457787669474, 0.919352577578637, 0.33842424351361494, 0.6968821765434358, 1.1951495010045268, 23.217319019379158, 65.3301307462877, 56.25465262320734, 119.83445705906038, 61.539528677540446, 95.36789647994503, 28.75811403797519, 0.8741364135376869, 0.23651058635404035, 0.13738283857462869, 0.14268476455923051, 0.1669135821923133, 0.1254099645020981, 0.15114144061601933, 0.2027131620073511, 0.08471441635441396, 0.17172954796302706, 0.22460475263576354, 0.1856540080400244, 0.1494737131701362, 0.14887199707088933, 0.11954487196259922, 0.2810934408297462, 0.10783357861181421, 0.14938513808433088, 0.27333569742979547, 0.27132094747597174, 0.22891416574918458, 0.1971771961618816], [0.1551147709570585, 0.10974977901505847, 0.3407570731735999, 0.10843972269926341, 0.16058129859307121, 0.05576333316463617, 0.08297884416195654, 0.26744699406047023, 0.13315962567444772, 0.07524039085593916, 0.13478282809017167, 0.024251386583332094, 0.07604646090898784, 0.054451097328696525, 0.06957939946122708, 0.07427653733400569, 0.07761554687374062, 0.027056126404673825, 0.03478671198770885, 0.16394122233313901, 0.030788096914728804, 0.04736333995336487, 0.11246106377051723, 0.03105838614095363, 0.029965590445264697, 0.0531463461717771, 0.2709568412073197, 0.4776478841179802, 46.924985301110056, 97.78195058145832, 83.85464176054924, 111.31970528633364, 64.90522038552069, 48.31695602786157, 10.007765696894738, 5.016492778255094, 2.2756030146152746, 1.2903440767718901, 0.3783297022023509, 0.3359925578678808, 0.03114698803983629, 37.42316515214982, 93.2301498228504, 81.82693327626875, 74.88837811254686, 74.38874659999725, 72.87491567673223, 74.06303298088812, 69.78228369066792, 69.77312887868574, 66.91813761188139, 79.72291115791568, 85.66200717802971, 85.8003334845266, 76.51580087600216, 78.63577919621622, 76.55979417985486, 72.74452040272375, 70.04692600619408, 69.01125554115542, 66.6927033085977, 66.38580922157534, 59.24775446614912, 53.92742803019863, 45.801171333559104, 46.04649597598661, 40.410191243694676, 36.89880309566375, 29.124163350751324, 33.243977792801395, 29.17492470433635, 44.67168561873898, 31.392925016341675, 31.198679439483154, 29.952824846390758, 5.864902427119594, 0.5985090713347159, 0.26618766808702105, 0.14248598006463822, 0.23670629117517705, 0.6848447902068016, 0.14798705826603598, 1.2338755520120746, 2.477812964108683, 3.9623778577773807, 7.683816773276176, 18.99775085910674, 8.962111819174982, 3.130429415933548, 9.643993320003633, 2.337600733003309, 32.57410168647766, 41.44696781712194, 44.98442403731808, 43.91132631609517, 21.297101128485895, 30.969201172551802, 24.552682099803803, 18.845994357139833, 11.9902463113108, 2.1325826116146582, 1.465227363571044, 1.0468665029733413, 0.4059958337776123, 0.09601064326782381, 0.12319593209653132, 1.643686993948875, 21.46104443457819, 23.098734001959524, 17.576697718712595, 28.38839142553268, 24.5816566482667, 34.31064674931188, 27.392085867543376, 30.5380718938766, 30.861614481095348, 35.44088948157526, 43.11784651971633, 48.13978256717805, 54.173388096594046, 63.96822890927715, 70.94761986886301, 69.32994027291575, 70.06160351537889, 69.01237733902471, 71.98024657464796, 70.41604457363006, 71.43790045092183, 72.24774437565958, 76.84323249324676, 73.66419853702669, 75.12218275377828, 72.13644319964995, 74.71198128115746, 68.88306463918379, 63.36594112457768, 53.318938978256725, 57.77183325059953, 56.952795290177875, 71.85175757254325, 55.05826304035803, 5.661636869753561, 0.1042243238959101, 0.6882753319317295, 0.5175621987831208, 0.7019683874903188, 0.19369285974291064, 41.9195310531124, 33.86021352583362, 71.64893181093278, 71.80349672994306, 45.132654328500074, 73.18781883485856, 1.332598422323504, 0.2799357900456075, 0.22182927737312935, 0.07469414718328946, 0.04066728716415744, 0.09905200466633805, 0.0211929414241064, 0.02795517654909242, 0.050638875278133544, 0.06129885850954921, 0.052856619379693465, 0.04262779426250247, 0.03807859179834205, 0.06820294630503462, 0.04505533920300584, 0.07261972664104355, 0.05128194863397268, 0.11029045322849867, 0.008678126220230856, 0.09609095226492613, 0.11753292589057839, 0.09473666203238311, 0.11590302020551697, 0.13557969742724973, 0.2589829175943329, 0.4394093714654446, 0.1234701302863898, 0.05055971924335726, 0.054466809792023514, 0.16677513478263734, 0.184390100860788, 0.28144198019177685, 0.026883095870876027, 0.13988216978407678, 0.0914951065374959, 0.08861215679996437, 0.06977039284162945, 0.014838086001785293, 0.0592955079440388, 0.08710542273136877, 0.024150573242936405, 0.08270677569652758, 0.06821318123970302, 0.1280768697841033, 0.04756202868696663, 0.07513817174420243, 0.046575870515117725, 0.011977788526564838, 0.08141152019942961, 0.06664309936064867, 0.4673686695675697, 63.103016807187, 106.91764493142406, 99.64048724020682, 117.99699921761791, 75.49272121921663, 53.96716164004419, 16.265108123902355, 5.559237022553721, 2.6510184570666286, 1.7804731572827988, 0.4858192537100085, 0.9092481842925473, 0.16417426627970513, 39.02521802533058, 94.50051138477941, 86.60558823616275, 80.07090383960356, 81.11162631742417, 81.47603019591301, 77.77307741103634, 72.99762310520296, 73.74219094553303, 71.97544559355705, 80.53784631913709, 87.76417793766146, 88.3212015705724, 81.15691400343373, 81.40759268114644, 77.13212290117818, 75.17176151275635, 70.053570501266, 69.29061458956811, 69.94448938677388, 71.51856791588568, 62.88909073798888, 54.90134469924435, 46.49517589999784, 45.27475003273257, 35.471119188493304, 31.84026937330923, 28.51195981425624, 32.71044719603754, 29.72285039963261, 35.11371674076204, 38.886903485944195, 38.127940547081735, 37.696589654491795, 5.770055103686548, 0.6483473809015367, 0.09386590351500819, 0.06591832655812464, 2.569365251448847, 3.4943557458539165, 1.041335593308172, 1.4309707308007826, 2.554626455230098, 4.211606239118884, 8.125454081643014, 21.309754694661788, 11.829642903420234, 2.061188365182569, 3.071788020672337, 1.931122325120434, 40.878075092069565, 50.12896160925589, 55.38264697597873, 47.97740036441434, 29.31441007121917, 32.49564251592083, 28.29070479639115, 23.797074748623757, 15.421163112886491, 7.108062351903609, 0.5492199548790532, 1.9994359175043723, 0.5275420568162396, 0.059672748790152615, 0.21912181539641273, 2.1613698669018286, 35.859739780426025, 26.215270873039003, 17.808496067600867, 23.905585158255793, 26.572592912181733, 32.31873773759411, 27.48955284395526, 33.814721876575106, 31.226887164577363, 38.2995246302697, 46.19691102735458, 50.62483549118043, 58.040507762662834, 67.09632304406935, 72.22795994051042, 69.41087445905133, 70.15802321895477, 70.81512220444219, 72.55246546960646, 73.77237750637916, 73.40284316770493, 74.82150954584922, 77.71998420838388, 76.11496602335285, 76.53530290049892, 74.50349161701818, 74.91843131280716, 73.81981465124315, 69.1818315752091, 64.51321478812926, 69.50872190536992, 71.39521721870669, 73.09423892728745, 60.521791288929606, 5.150282863647708, 0.143963503200681, 0.38026318554916694, 1.1048110646586264, 0.13355333358049393, 0.48245196020410913, 39.96422952221286, 47.28582374511227, 63.737275831161014, 91.79404458691998, 47.17277711437595, 82.19585572519611, 3.6206901409933647, 0.37435266399575823, 0.19070793604177816, 0.027134135222783493, 0.061049021915682865, 0.07839000813903348, 0.19887834036302185, 0.0343292847185606, 0.06623207020663446, 0.04399488965469984, 0.04762360683432029, 0.10770836154059057, 0.008938085708406665, 0.15070083280724866, 0.044886497254934044, 0.05072915107913075, 0.07200406774157478, 0.10782838453568759, 0.04599013500997136, 0.16711486413353877, 0.1035629142256033, 0.10870419923336276, 0.04516839462843153, 0.2683686897639306, 0.4105336177012613, 0.685565219290795, 0.21369282606868975, 0.17171902191494742, 0.16646154435171237, 0.2237815911611242, 0.4250255803908072, 0.4438947856185898, 0.1871624964499666, 0.19290833974317198, 0.16459771371897192, 0.1456342490329858, 0.1811268574167644, 0.17144324558396495, 0.24421977510135023, 0.22300932856817401, 0.13455321621750632, 0.21024932213608297, 0.14603779350797977, 0.19669155770492172, 0.20880135467215893, 0.21851862840835126, 0.16142408724033064, 0.09991510230447016, 0.20746650775113415, 0.3522760018465981, 0.7210639563779677, 84.36477738042032, 121.70200732446487, 110.94795873088222, 133.7583612626599, 92.62539094494235, 77.05033363834505, 32.05003184656943, 12.247914652670584, 6.503909970483472, 2.4557672825551804, 0.732455070941679, 1.0012413705548933, 0.30561781518401643, 48.16663511337773, 105.27591336158015, 91.55423087458458, 85.61968480387043, 88.45328346375497, 86.28284777364424, 84.26254472424908, 80.80243372148084, 77.98357532870385, 72.72090773428641, 81.70876010771721, 89.86769799263247, 88.58580466239684, 81.95147637398013, 80.0128213820919, 76.1112476164295, 72.4044587535243, 71.15621151462679, 69.18752685669931, 68.04585041538363, 72.3543857759045, 64.52724510623564, 58.849355405376805, 53.61623110309724, 56.14431242788992, 48.1013511842297, 46.2670704626268, 35.72721073704381, 43.81080773568923, 38.00224035016952, 60.06748668609127, 43.92362686895555, 41.37538456147717, 45.92573012075117, 10.399786003174322, 0.9072613812262013, 0.4341594015638675, 0.19193831921344806, 1.9415232250767371, 4.271254702921837, 0.6076959977226873, 3.047462706604312, 3.724248067986581, 6.5774127360313175, 11.54026416040236, 27.123211314601285, 36.05216733870968, 3.6911351738437532, 23.36280953499579, 7.243948944153325, 43.10570678403301, 59.335137028847974, 60.13686164732903, 55.16009169240152, 34.264998205246464, 38.092800032707956, 30.295241878878688, 33.96490158573274, 17.216453513791485, 12.673247648823647, 3.520224757732884, 3.9946579837029983, 0.5874653929664243, 0.1411195396776161, 0.1709015754562232, 5.959575205079972, 47.35210395628407, 35.104004952215384, 27.864682443680305, 38.94824543306905, 32.56734736504094, 41.6800428975013, 37.32251713352819, 40.56805095364971, 42.09203689329086, 45.90147810597574, 52.57100182194864, 54.32671746900005, 58.777556419372566, 66.11880563920545, 74.43335179359683, 71.24499044110699, 70.68586441778368, 72.58151454310264, 74.9313045317127, 74.33237429588073, 73.27102015095373, 74.92611915834489, 78.08521962934925, 76.62554094868322, 77.36755924840128, 75.7813213717553, 78.40366901889925, 75.53363154011389, 71.41438191936862, 67.84584091555688, 71.3482899819651, 70.96474493703535, 80.7516154935283, 64.19517332507719, 6.135254733024105, 0.3418369200681487, 0.7866408988352745, 1.1193264083516214, 0.5784041049980349, 1.1449755223528033, 60.02416802990822, 55.40027410753312, 90.36360325351839, 101.37307659272226, 60.42619528308992, 96.23393227977138, 2.18281346463388, 0.31815101362524495, 0.336801577359438, 0.18495372706843963, 0.17234634067262375, 0.2317244367253396, 0.30677687556993577, 0.0734600484851868, 0.14146473889629688, 0.08541412276005553, 0.17858191333230466, 0.26592676918352803, 0.08466302717645323, 0.2502286929877535, 0.29753043947200625, 0.20380355027173797, 0.12480182858604578, 0.35315525627905325, 0.1701368971337234, 0.3151855485573892, 0.1775478325303524, 0.3312713418516421, 0.22455992117043466], [0.044351285248393976, 0.13864729733717057, 0.3097997972321126, 0.10302949486480606, 0.0664416718627176, 0.20587948000719472, 0.09378984630588563, 0.15686212558179133, 0.09842801839113237, 0.2502349595869741, 0.08134408914033445, 0.12106753299914061, 0.09264648306153475, 0.08405466143402361, 0.04412605922909514, 0.14511238993896594, 0.03691431052321869, 0.028663534002618927, 0.037194756160099665, 0.03519836167294172, 0.06308537554897128, 0.1700815242985564, 0.11206904891878368, 0.13858216454184827, 0.08244773838669062, 0.09862640452000404, 0.04952666499922353, 0.3079434742610301, 39.89273648108206, 104.45245881234447, 80.59705057451802, 107.97018943294403, 85.42561377248457, 47.639860799235684, 19.994011309839067, 2.0866119428988426, 0.9097813814878465, 0.24705583259703653, 0.5760376900434494, 0.8731228485703469, 0.16110720263133127, 33.63561468739664, 78.26287161919379, 73.17182340929585, 71.2291048419091, 65.10608888441517, 72.82600372068345, 70.12511453320904, 72.05001769527313, 71.1020984957295, 77.14760057387814, 81.57174387285787, 88.05960301429995, 84.71916352548908, 86.27177884501796, 78.75545071017358, 74.70980044334166, 74.10466501789709, 71.74700675472137, 70.22858665835473, 67.29401050075408, 63.908338239116055, 65.6890276170546, 52.55279025723858, 42.37138417459304, 40.039582175593225, 45.17044636511034, 41.6530530683456, 33.65680725343766, 28.78272887199156, 23.593846944070634, 27.497730985764537, 13.496550206215153, 30.40318746720591, 30.041423343843032, 8.395196949282, 0.4560912730953386, 0.5367834060903519, 0.25824306052057977, 0.13231676041839585, 0.03960351662469968, 0.2077883106446074, 0.6662946759212403, 0.675685565558172, 0.5494932337634025, 1.4478562892444673, 6.969900784953949, 14.314336930551837, 2.397079799444445, 3.3979407000926236, 2.9569196941391116, 31.7669524300483, 41.03206342266452, 42.05236604136806, 31.105236814868068, 20.894936592348163, 21.5654500838249, 21.36384221815294, 20.28820868461363, 17.893260448209702, 1.0485567993694738, 1.2383275647317211, 1.5197730689279496, 0.3966083149275472, 0.24191404963212632, 0.19463318670468946, 1.4382223352309198, 20.796665530050955, 17.89321141858255, 17.455274866473292, 20.209714212725242, 22.651642637868083, 31.59895339319783, 23.12409212512355, 32.50437763429458, 34.203326779027144, 29.88740755665687, 39.895125204517, 49.27499494244976, 57.527697086334236, 64.6524275502851, 69.61416306034212, 70.53659469850602, 71.42432905012562, 72.48858574898013, 70.32684987591159, 71.79953513606903, 74.69958659141295, 73.76381104992282, 75.11375750264814, 71.9410934755879, 79.79565543513145, 73.21507930755615, 74.58115454643004, 67.24622818731493, 68.30813930880639, 53.189524296791326, 46.32920080615629, 45.201860627820416, 64.8619644872604, 28.629568161502963, 0.8476202105802875, 0.12237121546340567, 0.3974508584266709, 0.6321979410225346, 0.3203430976117811, 17.851738237565566, 50.332422794834265, 34.62622104152557, 95.87325465294623, 48.371688781246064, 79.53605728764688, 30.349150934527, 0.39463398377260855, 0.20704384172155013, 0.02113467469180544, 0.053002616585863215, 0.056756267384175337, 0.0468133807542824, 0.1359944421076967, 0.1528157257745343, 0.05559757089001998, 0.032717382099719784, 0.023897944258586056, 0.04467832052239007, 0.019238775618554606, 0.09537131991237403, 0.06460962621795555, 0.01208540855816776, 0.11998300530737448, 0.08700230729676063, 0.07269762246118439, 0.029972224766688964, 0.026071647880598906, 0.0382562858923789, 0.09735496669647195, 0.20457582818644665, 0.1560808844383686, 0.17738031974482923, 0.15821249344416205, 0.07926372375579611, 0.21480803558182335, 0.27416601416564756, 0.20054183900356296, 0.07072993328854923, 0.25082383605261005, 0.07317672618815015, 0.051614285236404794, 0.017283996942663388, 0.08495235560281623, 0.09821549794005771, 0.133279120068877, 0.040729983799880555, 0.07085282145248306, 0.05075286916126648, 0.012352530010825685, 0.012255513593704711, 0.17892207169244367, 0.02721707573190572, 0.050892189911176125, 0.03370923230484609, 0.09682969851118904, 0.022810501602268028, 0.316462341335512, 56.988343731049575, 114.39642029423868, 91.24507750234297, 122.84167551225232, 91.44682068978587, 62.902364038651996, 28.93708198301254, 2.7740465392989497, 0.830072078012651, 0.40974577287993125, 0.7002122075326982, 1.355738690303218, 0.5719875364053635, 35.169343794545824, 88.25496058310233, 75.82486752540835, 77.64803224994291, 77.61061283849901, 84.47301910769555, 80.62904142564344, 75.656597845016, 72.95207654276203, 79.05425686990061, 85.17014195842128, 92.46168690343058, 87.43797009991061, 86.9051161120015, 80.75401598407377, 76.66994217903384, 75.60761528630411, 73.09271704766059, 72.0907397424021, 70.313247096154, 68.84191113133585, 66.89834533199188, 57.21663744218888, 45.47685407823133, 42.33547487566548, 43.69201875502064, 38.676723280260646, 29.618713432742705, 28.301805103978804, 27.525821039753577, 28.970033814830167, 22.665031648451283, 36.41237035874398, 38.53711828108757, 10.087919331366017, 0.291781225391934, 0.5652897829009641, 0.26226925092839426, 0.8408025796374968, 0.21265802514408866, 0.11715648560634545, 0.8649038283094284, 0.7855787945370521, 1.0598230722450441, 2.5492819807221814, 7.6933049867230086, 13.694225895789362, 1.4489196192833687, 4.231282318792036, 5.519455363673549, 35.622852156239176, 49.08481882464502, 47.278249648309526, 36.864513735617365, 22.4153257185413, 26.077933003825528, 26.71833642067448, 24.593686557585194, 21.875629155866562, 0.828197246357318, 4.83117941887148, 0.4869306940705546, 0.7154352938936603, 0.22431196915286206, 0.3411414041634529, 3.418306381471696, 34.08622441753265, 22.508329037697088, 10.44098657946433, 19.83243319296068, 26.34769401242656, 29.698890601435018, 25.6066680723621, 33.09524936060752, 36.478128894682854, 31.80308726526076, 44.04112931220762, 57.03305090627363, 62.00745174961706, 66.942872078188, 69.1596309600338, 71.5369716767342, 74.54783008944604, 71.24470018571424, 72.67776950713127, 72.72432019633632, 77.69489672876175, 77.41705955997591, 79.35699324454032, 76.39141467309769, 80.61161825733801, 73.85081706508514, 75.22169328504994, 70.29689865727579, 74.49727858266523, 60.12733421018047, 59.70247091785554, 56.10138208635392, 73.25604454163583, 29.762474183113348, 0.9397594438445185, 0.11260265214068275, 0.660302703899722, 0.3608028975225264, 0.5819211227278556, 6.306525516894556, 63.42405888342089, 39.912379710905014, 93.16200256347658, 62.037912876375266, 71.62353054169687, 45.84154428974275, 0.4485851742567555, 0.28352457489217486, 0.018972671147616162, 0.12793868284432158, 0.052599941620663296, 0.06448615582719927, 0.14247337025740456, 0.0403920739077993, 0.0632160816401724, 0.024913868776732878, 0.04441523826831291, 0.008486787142652658, 0.0966403752024616, 0.025904341938815294, 0.0841092451986286, 0.03049606994365252, 0.07943708945306079, 0.04265670259032519, 0.0753074771754684, 0.03704022090401381, 0.048596415924088615, 0.03249566476311415, 0.047287470435783754, 0.4010488363283296, 0.36619575814374034, 0.4136150071938192, 0.2834811836721436, 0.17164435898584707, 0.3534868497761988, 0.3448161440751245, 0.3889716747066667, 0.18152672466972183, 0.30805979705145287, 0.18797169980262557, 0.21422669742136233, 0.15512004164197754, 0.3356530889868737, 0.17638668838527896, 0.19583491818799129, 0.21836711153868707, 0.2216462130027433, 0.15794868340655682, 0.2202774896737068, 0.09403080394070956, 0.35405464350215854, 0.1287549418667632, 0.2300383691345492, 0.12451318197793539, 0.17331542657508006, 0.15315294235704408, 0.41351081923611704, 65.21760971315446, 125.4485768656577, 103.43356040216263, 138.0985893741731, 113.9288188565162, 76.86294632573282, 46.029068885311005, 3.9544257425492813, 1.9425181587857587, 0.6740870771388854, 1.211127398475524, 1.6756426663168016, 0.8356036005481597, 37.81924216978012, 98.55864263349964, 83.42555015317856, 85.89685516972696, 79.50605900056901, 89.71319583154495, 85.9304855715844, 81.6156195056054, 79.24039686879804, 85.4733725517027, 85.84942586960332, 92.88043914302703, 89.28699893336143, 91.04772736949306, 80.18506050109863, 75.90968485801451, 75.40049845172514, 70.95855543690344, 73.67915061212355, 71.84346568199896, 67.26514970102619, 69.35224286971554, 59.264126439248365, 52.668570779985004, 48.54972516336749, 55.6329216495637, 48.42013005287417, 41.57628443933303, 35.96418857574463, 32.29425626416361, 33.21229288654943, 22.208185349741292, 38.70945545934862, 44.120831874109086, 14.936213031891855, 0.5624209368421186, 0.7099355180417338, 0.8810839117054017, 0.470504910955506, 0.11706510663873727, 0.36228175365155746, 1.672384279870218, 1.5453714372650271, 0.5484775850369085, 1.2002476016359946, 9.95073345399672, 25.19179701805115, 2.719108596924813, 17.610857640543294, 7.962317803213674, 45.16264869320778, 61.83245520437918, 59.61246036714124, 49.00027998032109, 26.847898191021336, 25.11210818444529, 25.119497929849935, 27.00382809485159, 26.642711162567142, 0.8640011315864902, 5.021985567385151, 3.1294510297236906, 0.6078492765945773, 0.22219454809542627, 0.44539696146403596, 7.160114165275329, 42.03207954283684, 26.390853812617642, 25.87492092963188, 29.596377495796453, 31.251674582881314, 41.16339614314418, 30.909349726092433, 41.20781306297549, 44.10204764335386, 37.55985190791469, 48.60632888732418, 57.84785270690919, 64.29300115954491, 68.57137741581087, 72.41040506670552, 76.10355977089175, 76.64721596625544, 73.54367194637176, 74.41100212835497, 74.10196642721854, 78.3546237022646, 79.23875731806602, 80.84155544157952, 74.5299989946427, 82.49311647107525, 74.79989728619977, 79.0208225865518, 71.13467770238077, 80.6079626083374, 64.14429626157208, 62.58417352553337, 58.278211239845525, 80.25400792398761, 31.627051291927216, 1.1988389804478616, 0.2099042301697116, 0.8326969403893718, 0.6673660958486219, 1.4149447842951746, 25.592169031020134, 72.46204699239424, 48.93003817527525, 118.55170080738684, 69.0015672868298, 98.25165440959316, 41.75286954449069, 0.5908833708493941, 0.46260538000252943, 0.1214447163886601, 0.30324631340561375, 0.13986091850505722, 0.15268385139924867, 0.33807518321179575, 0.20606180893317347, 0.16942008398473266, 0.18030141300011068, 0.1346833592340831, 0.16942003801945718, 0.22309125401079657, 0.1219965601640363, 0.16083720260329787, 0.11495465698141245, 0.31500288255272374, 0.14075980011013248, 0.19571972920769648, 0.3021938005282033, 0.2605183110121758, 0.15707692131400108, 0.2933128190136725], [0.07152635063375197, 0.0646514622795005, 0.0608009894588782, 0.07185959888081397, 0.10467594038815269, 0.0618635687316137, 0.16970002783402321, 0.21469997121922432, 0.0285349729576058, 0.046254500461321686, 0.026092408863346905, 0.07323795193505865, 0.07170916985600226, 0.05758721997300464, 0.03635532297794858, 0.03277589589537632, 0.05983570335252632, 0.11444284896095915, 0.22775170393288138, 0.06013539311806521, 0.12983152522675453, 0.22714825647492565, 0.21809746391109883, 0.20962086956827872, 0.11759820424260632, 0.3722792623504516, 0.3708242162341072, 0.7721001210231936, 14.311669718834663, 108.62873185065486, 85.34247521431216, 80.03199392749418, 101.52423689442297, 51.11081323316021, 47.91939243193596, 3.441557456408778, 0.07102184343121706, 0.3783034713518235, 0.8936228098407869, 0.7742282519898107, 0.17034277560249453, 19.993470022755286, 79.11081744778541, 72.20891291095366, 67.31477552844633, 60.86674021136377, 70.30903447058894, 75.01700831997779, 73.02502478322675, 70.69477604281518, 73.69906840785858, 83.15209819424538, 88.70695098753899, 86.22299240481469, 88.15146492373559, 88.8449635044221, 84.31667343262704, 77.59508809735699, 73.69827608908378, 74.62272382551625, 72.62477044136294, 67.14007316097137, 65.08455507216915, 57.337740621259144, 40.391422702420144, 33.458449071453465, 38.952509049446356, 37.20892529333792, 29.905397507452196, 33.575935825224846, 23.523365874444288, 14.909514438721443, 14.88222356765501, 26.628378821957497, 28.712469416279948, 7.581429673779396, 0.46621111071398186, 0.4692066370719864, 0.14421121007011783, 0.3797896819249276, 0.06565009619319631, 0.09729185637326972, 0.10447940819205777, 0.5782157086556958, 1.2041081944780967, 0.6441559606502134, 0.8445758997432647, 1.562068476792305, 1.3725031455678325, 0.6135849462401483, 1.1409120694283517, 21.198012252007764, 28.433600664138797, 13.921482140018096, 10.084510791686274, 9.411913541055496, 17.647082690269716, 13.987329909878394, 14.575755057796357, 6.399708774781997, 5.848613314090237, 1.581833667812809, 0.13583051461365916, 0.06799342891862316, 0.25689197253556023, 0.25716125244094484, 1.5192180535485669, 18.22358089108621, 15.511720834239838, 20.166454392094767, 27.15815374928136, 24.29688080664604, 34.59550103833599, 23.05788447779994, 32.520537799404515, 30.2339901462678, 24.38747382933094, 36.37855168311827, 48.79086855919131, 58.956981320534986, 64.66497521246633, 70.76405294479864, 71.46075217954575, 73.66529680067494, 70.35424370919505, 72.03288478236045, 70.95463306673112, 71.49470421575731, 73.63471015807121, 73.62077789921915, 74.06852429912936, 79.95779052857431, 74.02349548955118, 73.05043389720302, 67.21901478305941, 62.5975880315227, 54.50572659892421, 52.22369163267074, 40.556703536741196, 44.084247927511896, 10.80421963045674, 0.10632545026319642, 0.6897918795866351, 0.6499390051730218, 0.2680173005548216, 6.485871970653535, 59.809841878952525, 30.076152009348718, 77.32881407583915, 76.42114623900383, 55.99237941926526, 78.06017137342884, 3.967870401759302, 0.17795258742426673, 0.19814717072633006, 0.11677722611855115, 0.03338708084136729, 0.08377364506163905, 0.01392071103421791, 0.0704124664527274, 0.07777212758458431, 0.05134252703658516, 0.06858752244302342, 0.0703285798250187, 0.2442772929827052, 0.06717448092756734, 0.11109555801076275, 0.09973874120342155, 0.019520113747867367, 0.04513147302092083, 0.04480066093345804, 0.028711324482555353, 0.07589268407994702, 0.06320398894228763, 0.06604270093263158, 0.05114954565801928, 0.053591175125010555, 0.10667013620296795, 0.14542671581429822, 0.06143793411132309, 0.05332135129719973, 0.03909397239406263, 0.2243612286063933, 0.2020037492677089, 0.09447361042182292, 0.07383478805422783, 0.06859518332226623, 0.08915791783722178, 0.044000355692039576, 0.023777589930461782, 0.03635212839130433, 0.04865244376443086, 0.04380682273016822, 0.079508465864966, 0.09839096271823491, 0.0946695450693369, 0.021270423556768128, 0.10538885414960886, 0.057774317796312036, 0.06286115693529287, 0.07404019154848591, 0.17557100392878058, 0.25014682883216494, 0.5596776066287872, 29.17912752397599, 124.78821446818691, 91.95705044654109, 104.80608401759979, 109.18730874215404, 63.41215841231808, 54.51225734526112, 1.085213432388921, 0.28247880358849803, 0.709759624254319, 0.20998609432530022, 1.0282315674328035, 0.10276572313159706, 24.85745026219276, 89.65055557989305, 81.4266554001839, 77.51750361534857, 64.26263416967085, 77.88633977213215, 83.99303866970925, 78.42518714166458, 78.22591504743023, 78.6700136430802, 84.11332207341349, 90.1127519915181, 88.24737471918907, 88.738659428012, 88.45362078758978, 83.46688409005442, 78.65431631765058, 73.08395447269564, 73.10628060371646, 76.176861024672, 72.25485171041181, 71.44551769379648, 59.37185433603103, 45.44058784361809, 38.196938960782944, 38.11117241459508, 37.05777675874772, 28.56906952396516, 29.701265596574355, 27.302030209572088, 25.401900737516343, 20.805339851687034, 31.65000107980544, 37.00005515929192, 10.00088684020504, 0.502382442355156, 0.4682698341146593, 0.0638220303752009, 0.6295907293115893, 0.9158885731331764, 0.22084410362426313, 0.16993445073885305, 0.871898272345143, 2.010925642905697, 0.37055930302989104, 1.139842855834192, 3.4051215792855913, 1.6320728558686473, 2.176665149388775, 1.618853732943535, 19.257160732823035, 31.115709543228153, 16.25467363865145, 14.89708935060809, 11.179777749123113, 20.39755455909237, 14.379632626810382, 14.833846034542209, 9.346088324823688, 7.0710415513284754, 0.457542090406341, 0.26269976169832293, 0.09219326544553043, 0.02536242283249815, 0.034107912121520895, 3.2603258134857303, 33.4136438369751, 16.963903865506573, 8.693608910806718, 28.673539892319713, 20.222760015918364, 31.25505174359968, 23.47609935268279, 36.29881774225543, 32.17239018409483, 31.00110180916325, 44.54111383807275, 54.037736846554665, 61.943069965608665, 66.68450555493756, 72.43734390504899, 72.07956098741101, 72.08656634053877, 71.19612555350028, 74.08940699792679, 72.80119080697337, 73.85251152899959, 76.39905545019334, 76.69485707436839, 75.89011223085465, 80.18976734530541, 75.58685025861188, 79.29654952018493, 74.08370387169623, 70.267425967801, 63.18635932860836, 58.90232701455393, 42.619423097179784, 49.75579515580208, 12.494144382015353, 0.13937995318443547, 0.7742023888614871, 0.5761894980265249, 0.6146099105958016, 2.4934715561328398, 61.49879878567111, 47.4078800601344, 54.26605016954484, 96.28065555326401, 54.41257815207205, 91.55005747272124, 8.885486356673702, 0.642495449752577, 0.14110866122909133, 0.04991719364038399, 0.061808314640074975, 0.022720626082211252, 0.026268882962364345, 0.060742303293438694, 0.06287697282048964, 0.06762070416082298, 0.09922097301891736, 0.031949133807492834, 0.0399678373979705, 0.03705115680913291, 0.024150649851728833, 0.029756938738207665, 0.031305014741637056, 0.0426908164855934, 0.009483170673070897, 0.05487885784297701, 0.08405633150569855, 0.034398588862630634, 0.05779185354889882, 0.008290282717245, 0.18506048908156736, 0.31965864401671196, 0.40754078797275023, 0.4503325901685223, 0.2330534307346229, 0.28533606639792847, 0.39784456633271714, 0.3632647976759942, 0.18834997869787679, 0.14639043910128458, 0.12318306948028265, 0.2203808655782092, 0.17381369016103207, 0.3115663653419864, 0.10008219374163498, 0.1442064603249873, 0.14430087300077563, 0.2566710787434732, 0.22796835359786788, 0.18234622424408314, 0.26420840332585, 0.36842853672081427, 0.1965552859849507, 0.2649772185231409, 0.21336000683086537, 0.5013660581842546, 0.45352451082679535, 1.5913201652226912, 28.81906767045298, 144.12507580172633, 104.08443850855674, 110.79519025741085, 127.34224227166946, 76.77278672495197, 73.37322927290394, 4.569266582688978, 1.0425328968032714, 0.7438922733549149, 3.946319429143783, 2.116931374034574, 0.3502694337118057, 26.90237206797446, 94.49662039356848, 86.17171918192219, 84.34778567283385, 77.30544459435248, 88.33725975405785, 86.88796750960812, 89.43662951069494, 81.15329757813485, 79.3946558429349, 86.53947276453819, 93.05735372727918, 88.91048277578047, 91.84725546067762, 91.58841825300648, 87.09866154578425, 77.36815544866747, 71.67463902504214, 72.6269434344384, 76.87206975875363, 71.13805878546931, 72.54078465123331, 65.81679098067745, 51.07957547710788, 45.25547942807598, 51.60903661481796, 45.195620136876265, 35.68241334730579, 38.40003928830547, 32.430552744096325, 21.052233442183464, 25.44782973104908, 39.701650373397335, 42.30148361575219, 17.432572187915927, 1.089134699394626, 0.861751591005633, 0.4891820119753961, 0.5215506363780268, 0.5620331124913308, 0.17594050345641954, 0.154356129407402, 0.8461347354515907, 3.5568417993284043, 0.8011645162778517, 1.3846644542870985, 3.444827242243675, 1.317592046914562, 5.605868610643572, 1.3488828775382813, 24.987741593391668, 38.30814599990845, 24.526347306466874, 22.489556574052383, 12.934274519643477, 21.7489444440411, 13.620793242608348, 23.40149587200534, 15.34610757904668, 14.547534584999086, 3.606598045556776, 0.16984507892160647, 0.29911320776708666, 0.24330621525164575, 0.4818264953792096, 6.928106950175378, 40.337933340380275, 21.603604939676103, 32.04869824071085, 37.13976606245964, 27.921533276957852, 40.395270547559186, 29.140552974516346, 43.247826022486535, 39.802518044748616, 34.886340864243046, 46.29544096608316, 54.552253753908225, 64.81205232681768, 68.10073221883466, 73.39917182922363, 77.25304172885033, 75.11989208959764, 72.18162105929467, 77.3118459024737, 77.61233868137484, 77.22685598557996, 78.40356703727477, 76.34611129760742, 77.36293085159795, 83.16547347653298, 78.45280847241803, 81.56164769203433, 75.22144225335892, 72.56424826960411, 69.04503499307941, 68.41844420279226, 54.95412803465321, 54.686249763734885, 14.084666467482045, 0.33099113753245724, 0.8222525266389694, 0.6614813761365029, 1.436096778319728, 11.553185428342513, 76.71440616730722, 45.28003346535468, 88.59312380513838, 102.62563843880932, 71.94447455867645, 102.99776938653763, 5.999532880321627, 0.7939037800796571, 0.2441737945041349, 0.1755725667481461, 0.18846470802541704, 0.16321898528164433, 0.08209684713473243, 0.2039735605038943, 0.2252785576086852, 0.19559419804042388, 0.20653080796041798, 0.24601265067054381, 0.2535253685087927, 0.29307156260455813, 0.1610791944568196, 0.18443952885366258, 0.10653967142946298, 0.15500070046513312, 0.11660212906257761, 0.1383389316258892, 0.17999258763607473, 0.1814168829831385, 0.14204986153110383, 0.182901117049398], [0.06462490967204494, 0.054751001598854224, 0.030922012914332653, 0.1069299779051254, 0.1148329639146405, 0.11922955783384463, 0.015082604987847229, 0.1923893917832644, 0.06663775206693719, 0.08340720988569722, 0.009002630531247105, 0.013667464391478609, 0.09219416176840182, 0.08110411975893282, 0.07153660089017884, 0.06655195021941777, 0.030566496406531626, 0.08000843782698916, 0.06827171035711804, 0.031718031893814766, 0.037422115734267625, 0.06761072969604885, 0.11936787500857346, 0.11491780815225457, 0.0714223925024271, 0.12580140478788845, 0.14982511770100365, 0.1216616648279371, 0.4308306576023179, 79.15130415270406, 100.76878055449455, 79.0335859790925, 111.79884633710309, 70.78526512269052, 51.51343276423793, 30.36854901621419, 0.058292710342474525, 0.5490213236020458, 0.4996586933491692, 1.4321399648343365, 0.5219545179317074, 4.922007783766716, 44.84383060086159, 76.54707001101586, 66.93752981001332, 73.08548419706284, 73.19480849850562, 70.80611644252654, 71.80140218427105, 71.91016950914937, 75.80298854458717, 81.96562828556185, 88.06610630404565, 88.5143155436362, 89.53967017512169, 88.98190913661834, 83.41659145970499, 80.68753965439336, 78.29586659708332, 74.32616910626813, 70.47107542714765, 65.36112531538933, 64.56782202566824, 59.47427134360037, 35.96088986242972, 27.37186016574983, 33.69836476541335, 37.44198076186642, 29.31948365703706, 34.485651139290106, 25.4588496300482, 17.277152192208078, 20.75028350276332, 29.040875742512366, 28.14441215607428, 7.52742353946932, 0.4179307175499778, 0.31424620218815347, 0.03898086717292186, 0.921202955707427, 0.9447233871586862, 0.9720671489354104, 0.29690963246168633, 0.8551051960356775, 1.92193785021382, 2.8947959696092918, 3.062575108581974, 1.8815309410133672, 0.15620794778148975, 0.6565898128094212, 1.6012111570565932, 4.211340008243438, 8.979993904790572, 10.890473531138513, 2.1656692749069584, 3.9130824900442556, 12.49136047978555, 6.557215961717791, 5.243666162413936, 2.6686181320298106, 1.614784396463825, 1.3780687436942132, 0.6941277533769609, 0.23599762920170064, 0.6976679376056117, 0.37658458455435695, 4.7157617153659945, 23.4428592266575, 24.36284330583388, 43.00321917380057, 16.349801901848085, 25.106389368734053, 23.38315094670942, 27.14019125507724, 26.727124491045554, 34.09055863657306, 16.64803735671505, 26.231346707190237, 51.28285231128816, 57.22215229465116, 68.0675881908786, 66.12753683520903, 73.72744283368512, 74.58989358717396, 69.99374651139783, 72.82165773453252, 74.34025041518673, 74.38426725326046, 75.30912291619086, 74.06192687249954, 75.3885744464013, 76.26523202465427, 77.07723325298679, 68.54238325549711, 63.07643098215904, 53.410365504603234, 53.981415533250384, 49.322173210882376, 42.40684632332095, 24.227666662585353, 0.8344392694773213, 0.8444938976918498, 0.4698471478637188, 0.7413518645109669, 3.56561123844116, 49.09289890719999, 29.779646319727746, 55.243041976805664, 107.9355392148418, 60.828257837603175, 74.99431348616078, 32.39476111627395, 0.2083684843514235, 0.26454655453562737, 0.013322482550246342, 0.10126843492710784, 0.03950496324368062, 0.052906798138733835, 0.02248776791196677, 0.1123036863282323, 0.07338089628085014, 0.07152556156318995, 0.04296039516526846, 0.10883225082990625, 0.05090425196554392, 0.028876776491562207, 0.01997552620577476, 0.12793082278221846, 0.03903360466562933, 0.0515611493779767, 0.019372772057390502, 0.10944682954540176, 0.06400465041459089, 0.07042043376713991, 0.013899256741898436, 0.02498309056635105, 0.036965626922826615, 0.014663040656746637, 0.02540875199971901, 0.08216558054329888, 0.06157418284865637, 0.070395857666529, 0.1577258743946591, 0.05701322859573749, 0.047876071109766924, 0.01814633615375046, 0.0861556192619666, 0.031051977815467025, 0.09077752730058086, 0.06364344761917187, 0.038407553783467704, 0.12928913497636396, 0.03812016738999275, 0.07372837078066603, 0.022529017916249654, 0.008118775740806616, 0.054957358872578035, 0.09484631219698537, 0.12797596068271708, 0.09126873521675026, 0.009335534038743185, 0.1773820511035381, 0.06701619950153175, 0.4700674441072249, 3.9006093528962906, 106.52616885400589, 106.1903747435539, 90.67663977223059, 116.69652169750584, 69.50752166009718, 68.2004310238746, 20.230553765450757, 1.4276347549692279, 0.25747498076769615, 1.327607083705164, 0.6753468321215722, 0.5016662420765047, 6.961026912735355, 57.88258137241487, 82.1040879526446, 73.91461833830803, 84.46158932101342, 82.33058129587482, 76.10031989312942, 79.37833093827771, 76.10543466383412, 82.82116782280707, 83.97714522577103, 88.36943887895154, 87.66294940825432, 90.34014747988793, 87.47439322933074, 86.85340358364968, 81.06769577149423, 79.9903932694466, 76.90351932279526, 74.94406007951306, 66.23524512014082, 67.25887390875047, 59.8625232327369, 41.299533767084924, 34.5251101832236, 35.155191882964104, 38.38113346407491, 29.474013274715794, 33.02309343891759, 24.195383594882106, 19.725870240119196, 20.86131991878633, 34.14762127783991, 39.180838061917214, 8.322573284949026, 0.24759760997708768, 0.4488172069672616, 0.371530334795675, 1.7908464780738278, 0.8846655872560317, 1.266017414389118, 0.47034409377844105, 0.508336355128596, 3.0281217444327573, 4.974259638017224, 6.384599804878236, 2.747635014595524, 0.4819698763951179, 1.5050308406353, 1.9730360373373956, 4.55910764394268, 9.072389256569648, 14.764480879229886, 2.542490641916952, 5.2413941294916215, 9.433917057129646, 4.770546930451547, 5.082108147682683, 3.142470111770015, 3.8438744746869613, 1.9777583258767284, 1.1040526989006227, 0.1736231028072296, 0.5529582188014062, 0.3851917968882669, 6.828025714043648, 34.06327462965442, 27.755014934847434, 43.44200295786704, 17.9914334512526, 21.81802130514576, 27.016046277938354, 25.284115883611864, 29.384190997769757, 37.54844173308342, 23.74010624424104, 38.70148520315848, 56.27176592426916, 63.42944822003765, 68.32367973942911, 68.34486053835961, 72.79994349325858, 74.71585658288772, 71.17072428426435, 74.93147711600028, 75.15884122540875, 74.6735106745074, 78.78681398207142, 77.75151221982895, 76.40888490984517, 78.27288150787354, 80.79294943040418, 73.61343522225657, 68.39476093169182, 65.59840909896359, 64.58462153711628, 52.25776526235765, 37.65197661615188, 27.03845673991788, 1.317480381938719, 0.6975542501576486, 0.5617780358560625, 1.3708720524464886, 4.028529611326033, 45.967989736987704, 55.25847258106355, 40.92825005131383, 100.57136766372189, 74.19060414837253, 71.65374848150438, 52.723887966525176, 0.3515738056552026, 0.08200565202822609, 0.0334058040302367, 0.013114116210941107, 0.03526720233381756, 0.049361841182314584, 0.07117372036220566, 0.08360079264328366, 0.03325949655845761, 0.051693556184369716, 0.16318915381787286, 0.13350572887687914, 0.0299768844964884, 0.013105669133966009, 0.06475244032879991, 0.059135521972371693, 0.05265443345471736, 0.1388845854108372, 0.06465159251444763, 0.06482573962139507, 0.06724884508237725, 0.05908561517454444, 0.03323097127459703, 0.07212119492431802, 0.31545315839109883, 0.11406070132169033, 0.12456809516034781, 0.21658611033231984, 0.17525316937075508, 0.15640325423690582, 0.37648036595313783, 0.4201052734448064, 0.30243419891884255, 0.17944636694606275, 0.13876150572492232, 0.1509648113841972, 0.20618957707718497, 0.21990129453760965, 0.17088930272767622, 0.16045475618973856, 0.1273487032120747, 0.20253339181503943, 0.13118815968834585, 0.12782717874694255, 0.1482882533943461, 0.1806952128367078, 0.1741169996920132, 0.2248447833041991, 0.09959779634711244, 0.303769919180101, 0.33258616323432616, 0.6220833128017764, 1.824309076032331, 111.2960220152332, 124.76168355634137, 103.92199747024044, 136.94737372859834, 94.36657813287552, 78.64400832883774, 45.519360803788715, 2.2973559892946676, 0.609364721082872, 3.2136018045486945, 2.1768127285665084, 0.6470632949663747, 6.8514334386394875, 62.384905353669204, 96.32414679373466, 82.98468359055059, 89.17525060715215, 93.7331545737482, 84.38988054952314, 86.96952927497126, 81.94935829408708, 88.04644738474201, 83.88271808624268, 93.50921861587032, 91.12065207573676, 92.77104423892115, 89.1377684377855, 87.91907233576622, 79.79804808093657, 77.94452421126827, 74.74581564626386, 75.05505531064927, 68.8248174421249, 70.86368114717546, 63.594576081921986, 48.2451884208187, 38.988112403500466, 43.748187095888206, 44.29418102387459, 34.48188174155451, 39.57556578420824, 32.81561182391259, 19.078830172938687, 29.256000095798125, 42.488435545275294, 42.917362413098736, 15.386226561761672, 0.6419604752332934, 0.47520044770452285, 0.7661136035476962, 2.5477804483905917, 1.6163577571991952, 4.727519510253783, 1.1993525657922992, 1.6508820917337172, 5.716059755894446, 6.636983733023367, 6.167936411596114, 3.335420325879128, 0.6112182861374271, 3.0603481829166417, 3.356165986868643, 7.451468802267506, 9.834488130384877, 21.59542875905191, 12.018936487936205, 6.964218251166805, 17.32183779439619, 8.64056375718886, 12.037764845355866, 3.8039521007768573, 3.848103770325261, 2.5058228546573273, 1.9129383395756445, 0.804489215295161, 1.169676158216692, 0.646905358279905, 8.984620340408819, 41.284016870683246, 26.114917032180298, 56.44270281637869, 22.01200604438782, 35.036489194439305, 31.563679518238192, 33.66222012427546, 32.01415588778834, 42.51169520039713, 23.875435859926288, 37.38988776360789, 58.26819350642543, 65.63899778550672, 73.55751791308003, 70.851333525873, 76.91828312412386, 77.79219504325621, 71.30843085627403, 75.93536853790283, 77.44991333253923, 78.45111400850358, 81.22932095681468, 82.25261242158952, 79.0833608565792, 80.86026514730146, 80.13755275357155, 75.34982142909881, 70.77175647981706, 72.09725087688815, 70.69537224308138, 65.88802906774706, 52.196085991397986, 33.52998525865617, 1.7677636973319517, 0.8209898911656872, 0.8212313620794205, 2.2295742457912815, 8.809359035184308, 66.60857631314185, 44.348803950894265, 68.83174434784921, 126.74616752132293, 82.5805853259179, 92.03820428540631, 51.14425536124937, 0.4973267523511764, 0.2825251365861585, 0.08730658975940558, 0.14644270161947898, 0.073094624545305, 0.11984700171817696, 0.25448179863873993, 0.2840245851585942, 0.1387276599604276, 0.14114092885246202, 0.30892942941957907, 0.24904226794117884, 0.14679516335168194, 0.1193249281195383, 0.13696340543608512, 0.17526227049529555, 0.2034154194857805, 0.24078416187436352, 0.12352032436718866, 0.17549600392099352, 0.15900395420049468, 0.3102002467118925, 0.16234089530283408, 0.1405503363498757], [0.05750244851374338, 0.03702913944218909, 0.019666181817170114, 0.06730299983774463, 0.027585529549528035, 0.12823640759433472, 0.06967738210674256, 0.1465577527039474, 0.019786011375066255, 0.11115584913040362, 0.032348740590556015, 0.012951698867724308, 0.03328821336429927, 0.035852570116760275, 0.10677961016734762, 0.08035362938479071, 0.027273501937968597, 0.03397244479387038, 0.027455669985483253, 0.08541108139099614, 0.05578793607832444, 0.048044985836191524, 0.13953156198465055, 0.1521295254989978, 0.04561654457281675, 0.22180260219160589, 0.03825465029466056, 0.19778062829807883, 0.4234576435579408, 40.59545655404368, 115.27084212149344, 73.92236109702819, 104.82484863650416, 102.38017651342578, 48.89471330950337, 61.70061257577712, 10.823917773462112, 0.30100572073171217, 0.29959241108548257, 0.9175541708546301, 0.14953008191960473, 0.47210352194886057, 21.7255808461097, 43.187405832352184, 75.9680732603996, 66.12424988900462, 61.97635912126111, 75.34094118302869, 68.17248021402668, 73.20799550702496, 76.24614577139579, 78.69560318608438, 87.41187849352437, 87.66815831584316, 91.61778111611643, 94.06095489378899, 89.35044719326882, 84.0363416364116, 78.1677149188134, 80.87935140055995, 73.26672907798522, 71.83431871475713, 65.3798036421499, 55.66161378737419, 36.56420138574416, 20.564651450803204, 20.62643466457244, 38.56903068480953, 32.34479992620407, 30.0604134990323, 28.207268138085645, 27.08398957406321, 21.400363406827374, 27.06596432193633, 26.456584891965313, 3.9252631654662475, 0.12379266862427035, 0.09194707543018366, 0.20233618546157114, 1.0215916688884459, 0.2733181693380879, 0.2845654738766532, 0.13462008037153753, 0.09915665227679477, 1.2683658109557245, 3.2075927334447063, 8.704177737236023, 1.6443425200639235, 2.418439066217792, 2.7554944638283025, 2.304771475253567, 1.21932368124685, 7.421465612226918, 8.025713601420003, 1.6909308395078106, 4.373013242598503, 6.049474948836911, 1.1008549866176423, 0.8640338588626155, 0.452523019405142, 0.2870048204016301, 1.1655782619791648, 0.4024273042957629, 1.1252425683121527, 1.4449619477795017, 0.7861360162496568, 7.845911662424765, 21.26295885732097, 19.525537144753244, 9.412509741321687, 10.467514549532245, 26.961850889267463, 23.990149497985843, 28.645269409302745, 31.11998884908615, 29.154112608202045, 14.492838113538681, 22.220327046609697, 45.060557242362734, 52.701463776250044, 62.65154807798324, 62.03444942351311, 73.65480053809382, 73.7696240025182, 68.81134802295317, 73.58990100122267, 71.3976961566556, 71.84038269904353, 74.96868471945487, 75.06018577083465, 71.78822302049207, 74.7351546441355, 70.07783428315194, 67.72256866578134, 60.135386836144235, 54.73862517264582, 48.76048980220672, 44.18483711058094, 37.7559547270498, 6.073966718489125, 0.6611359624132034, 0.04903099079045558, 1.8619963118145544, 2.7594871915155843, 36.11474483243881, 33.026435298304406, 46.239033360635084, 102.47219531766831, 68.04047676824754, 54.04394595853744, 57.874564047782656, 1.053504379045579, 0.5883375687464591, 0.087803382456543, 0.22918097885145297, 0.04113537837721167, 0.1448143970581793, 0.04740824419704657, 0.0784737338882781, 0.0820621203691248, 0.09306122774198171, 0.03298990638746369, 0.07269871796691611, 0.03230625335427542, 0.1174141975840734, 0.0764358634008996, 0.026778701069434325, 0.024326149103862625, 0.031056804169389992, 0.014453098091537194, 0.1364063675845823, 0.08388627530826677, 0.034281070975046006, 0.057400964846413945, 0.0865302975439737, 0.0036114928896553936, 0.08240466126270833, 0.08870905160062736, 0.054854224285771774, 0.03579766076478747, 0.02005883252188083, 0.1240541191110688, 0.02460826098197891, 0.06723459584698563, 0.03802025420290809, 0.07091112840440005, 0.04211668338206026, 0.030148557139440414, 0.008016271740123029, 0.07344942284567703, 0.013994807058254318, 0.04617907527473666, 0.092440459036058, 0.07794344016621191, 0.11726433546432566, 0.07310787786639507, 0.10835243464117089, 0.09532602113341132, 0.07066809467130131, 0.08858529009645985, 0.019698468592738914, 0.058683028309455806, 0.05963362084941999, 0.07886636161035107, 0.12177203511518818, 63.138890804782996, 125.85662103468373, 90.35429154672931, 117.97387292308193, 97.55852453170284, 62.10401265851913, 67.39201484187957, 1.196910400063761, 0.8666825618955397, 0.21208329066153497, 1.3996281739204162, 0.039839578957687465, 1.2336366551537667, 26.21544541851167, 69.37889145266625, 94.85206557858376, 72.53794485522856, 77.5632776752595, 85.46612401162425, 77.62413717085316, 81.19326653019075, 80.90454870654692, 78.80106003053727, 87.07046754898565, 89.08740520477296, 90.84745899323495, 94.28256880852484, 87.27985935826456, 83.030104637146, 76.83006117420813, 82.55537233045025, 74.10412373081331, 72.57970240808302, 70.04694954041513, 61.45331498115294, 45.97561090223251, 27.220001682158443, 26.64046560564349, 39.647043135858354, 31.89065221817263, 30.496887007067283, 28.11328422638678, 29.559028687015658, 25.54559676877914, 32.3027717298077, 35.61707450497535, 6.487965045436737, 0.0862648097738143, 0.3438053983113458, 0.23798789498546433, 1.0864334120865793, 0.9795783652413277, 0.8747500806085525, 0.133207751317851, 0.41899824575070416, 1.3248567667699631, 2.401416469966212, 5.705502696575658, 8.671286702156067, 4.6147405812817235, 4.6839365843803655, 1.3762303778240759, 1.4580068929541496, 7.304231361035378, 9.77887088252652, 1.7412470040782806, 4.719689478797298, 4.153402678428158, 0.3247519029724983, 1.6592855246797686, 0.9906177535172432, 1.1516683116074533, 0.5746158921430188, 0.05044770186706897, 0.5603285975033238, 0.5571856758286876, 0.9384029166352366, 10.340122830483223, 30.31968216742239, 18.48963918224458, 12.720153312529288, 12.56203668732797, 22.35191079878038, 22.044769602437174, 31.845023285958078, 30.703458632192305, 34.580411680283085, 23.878377637555523, 31.112304925918583, 53.750027072045114, 56.156699272894095, 67.17095790370819, 66.92210705049577, 74.90398914583268, 74.17846833505939, 69.64190206220074, 73.30486236080047, 74.47641941808885, 73.17536138719129, 75.54996428951141, 77.67555159907188, 74.52850849397721, 77.26727993257585, 78.95147508190524, 78.2472292069466, 69.19771717440698, 63.36506643602925, 61.13055882915374, 39.600100209636075, 35.29716599372126, 7.07480751699017, 0.17687937485114222, 0.2761004781050067, 2.6627838515466262, 8.138010078860868, 36.68369247067359, 55.24916479664465, 38.82736582909861, 78.60331766067013, 92.88757001200031, 60.11471594533613, 83.55794583597492, 7.126404335421901, 0.5926709297683932, 0.062435675532587116, 0.10109359068014931, 0.07351748975774935, 0.03307894878690282, 0.029335841273648605, 0.04001335834243125, 0.0218147462639477, 0.11793899079484325, 0.04822474836762394, 0.07209892474835919, 0.03491820331903235, 0.10518855280092648, 0.037083780663388397, 0.03673331842066781, 0.038551172286632567, 0.038321024152420224, 0.052570225070080454, 0.011370353580963229, 0.06697276997710429, 0.06694124545902014, 0.017637234338889682, 0.1320182925630962, 0.0980873314303256, 0.1548960681764349, 0.09710676953076355, 0.09662649368927365, 0.15407546543546263, 0.24981099120791883, 0.24239227235797914, 0.18502843596281546, 0.30770865299047967, 0.23798487659904266, 0.2076983566005384, 0.13987060185642014, 0.08511032293280286, 0.2083264261243805, 0.10441211502878897, 0.24209054096812205, 0.1977685241088752, 0.14259615882990823, 0.21279752975510013, 0.2624855941582111, 0.3099821874451253, 0.21829943533145615, 0.16626138089885636, 0.19405935620588644, 0.2113013447172219, 0.17212679519528346, 0.17196536514787905, 0.20126090445105108, 0.24718603690064725, 0.6534778410869261, 59.77692142609627, 148.705415725708, 101.88364367331229, 126.62146752880467, 124.42970198969688, 71.04938184061359, 83.55617292465703, 16.02144362465028, 3.269960870665889, 0.37718032516779443, 2.7241900274830484, 0.18367025400361708, 1.6033510551337273, 29.128130828180623, 64.754652361716, 88.24720997964182, 90.49126855788693, 83.01813356338009, 96.30564105126166, 82.07694515105217, 88.36275516017791, 82.76476413972917, 81.8520756690733, 87.28490352630617, 94.22873035553964, 93.00812013687627, 98.28989751877324, 89.0773953160932, 86.22369843144571, 77.00002531851493, 83.39861915957543, 73.05092027110439, 78.7510419660999, 73.33946551046064, 65.18071589931365, 48.69283283910444, 33.13899947750953, 30.57660329726435, 47.718672983108036, 40.88093842229536, 33.82789319561374, 35.96881697254796, 35.97891315337151, 31.85880453355851, 39.79999596072782, 40.826264504463445, 16.89900628982052, 0.3817165156285609, 0.3243257742254965, 0.6805406018130241, 3.2688518204996666, 1.0458164109337715, 1.1453585663149435, 0.3858877724457172, 0.385312011405345, 2.2097375940892006, 4.566152711068431, 13.711494130472984, 19.22555035160434, 9.60376254973873, 7.292451993111642, 3.471288532018662, 2.4730803793476475, 12.797025884351424, 28.25540738721048, 6.115117774855706, 5.986571898383479, 9.478162373265913, 1.7699126658901092, 2.1022592581087545, 1.4094224548147571, 1.3560043083083246, 1.2833947399931571, 0.9051995628303098, 2.5075303114229635, 2.4886306158957945, 1.6401738985892267, 13.47889267629193, 36.76882359289354, 24.661255267358598, 10.584950312491387, 16.102443510486236, 36.25134529605989, 26.74463983505003, 36.7894866389613, 37.49131241152364, 37.66450858885242, 22.722643421542262, 29.56787363175423, 56.19603280098208, 60.32842628417477, 71.37016896278628, 68.26111793518066, 79.16565218279439, 77.2821221813079, 72.8565982080275, 76.92111507538827, 78.83628291468467, 78.41299641516902, 82.12056190736833, 81.55512086806759, 77.54651346514302, 81.84195595402872, 79.87311440129434, 79.93530750274658, 76.99324746285716, 69.23513658585088, 66.30050551506781, 56.47203430052727, 48.30852685436126, 8.86427515937436, 0.446603212866091, 0.6678492828242241, 3.611974389322343, 12.550572579906834, 54.55490135377454, 45.070912299617646, 62.02279606173116, 113.6070276075794, 93.38361647821243, 71.72639862183603, 91.94813097676924, 4.222807547738475, 0.6899943719467809, 0.14717854439250885, 0.19336523458121285, 0.2141369885254291, 0.26739480815106825, 0.16656590084875786, 0.15593545030682318, 0.14066777762866792, 0.19522914182274573, 0.1422595244742209, 0.3281333537832383, 0.12112996916496947, 0.22098347033944823, 0.20290258490750868, 0.1354043705448989, 0.14511300280930536, 0.2061007568432439, 0.0479951901211133, 0.2746497527245553, 0.24259841129664453, 0.2771079450124695, 0.12747215062019326, 0.2765498959249066, 0.16791818393093927], [0.061752493643472274, 0.06085039063867542, 0.08396371147565304, 0.05214475132825394, 0.02340147523359666, 0.09396255316753542, 0.02602601968382876, 0.07662019181636072, 0.01783665277123932, 0.05805559080815124, 0.04018547148593972, 0.0062192712662621375, 0.012446481118639632, 0.06133970248723223, 0.08238623684812939, 0.056517148360369675, 0.013673874632185026, 0.10630448243670887, 0.03331327976118172, 0.14768217059393085, 0.0647987043785472, 0.05720240251731969, 0.06686816067104379, 0.17348729074001315, 0.006504420682998195, 0.14517464224369298, 0.183050167115946, 0.04209157485034197, 0.33725743031790184, 4.586427442489132, 121.18619211258428, 99.19616114708685, 87.52689023171702, 108.40114808851673, 92.37206074499315, 43.75944822065292, 59.93055282100555, 4.579307850330107, 0.7053771110311632, 0.41254407756270906, 0.7770736864016903, 0.07254827362034591, 3.729303022546153, 27.738597854491207, 44.70153877812047, 76.79945884212371, 64.63443956067486, 62.00125048237463, 69.97777462005615, 78.97014556392547, 76.08323404865881, 82.82232099963774, 77.41760869180003, 85.3961253935291, 86.69763057462632, 89.24389992990803, 85.82462864537393, 83.99357211205268, 80.3921224224952, 76.27222168830134, 65.74530186191683, 64.77302474360313, 57.9995660628042, 51.78502944207961, 27.553575731092884, 17.137021595431914, 22.26314756178087, 37.273703236733716, 40.87382716517295, 29.317087088861776, 32.081051911077196, 24.104280664074807, 16.321881490368998, 23.26053765512282, 18.57789839467695, 1.6028113615128303, 0.13635980476054455, 0.16737689684715965, 0.05418782738307792, 0.6346073794749476, 0.46248746374922417, 0.33644010643324546, 0.08044538373548178, 0.07301544935833063, 0.037695053709490646, 0.06510779021247741, 0.311488009869091, 4.2683232215143025, 1.7465501711253197, 1.0836721860593366, 1.2473784339043403, 0.24923838644979462, 1.531829454245106, 4.302778791996741, 0.4610895065049972, 0.7084141899981807, 0.10039651961696726, 0.2173555077564332, 0.36740835275380845, 0.540830311515639, 0.5095629538259199, 0.2092502668740288, 0.18634817562997344, 0.7294111278268599, 0.5645517031511953, 0.4769726235780024, 9.998828576457116, 20.340233041394143, 12.010690685241455, 1.9631365878928093, 10.501558761442862, 16.15708016580151, 20.971911145794778, 20.53253116146211, 35.11309308390464, 29.723623106556555, 9.08276588686051, 24.03843583599214, 40.647522095711004, 48.201834463304095, 58.52868595430928, 61.118536764575595, 72.13765913440336, 69.97651946160101, 70.51509226522138, 71.7047236042638, 68.19168413839033, 67.49216079711914, 67.17322503366779, 67.42055400725334, 67.31974124908447, 70.47954774671986, 65.15521657082343, 61.741413070309555, 58.89918127367574, 50.49528744912917, 44.770917661728404, 43.271713256835945, 15.8913964609946, 1.861202399576864, 0.6204299112000774, 2.919459588104679, 8.266013687656772, 27.71636978272469, 34.141208202608176, 39.79751702277891, 90.65183470326086, 89.95429608129686, 47.46693134307862, 74.8339669935165, 17.140016325058475, 0.4298300854861737, 0.13217380841172513, 0.10483870342854532, 0.1116740616459039, 0.16435927651341886, 0.05839667613467863, 0.11575374797347093, 0.08344588966499414, 0.0395189022134629, 0.0834168549326639, 0.039693493651406425, 0.01742743733038585, 0.041566647574185364, 0.03454950052283464, 0.017232500512393254, 0.0199765891527697, 0.07153156769251631, 0.07923761547933664, 0.07848216851632442, 0.09312026247742677, 0.04322599401817687, 0.036723604425787926, 0.036584632245883826, 0.06247777972490557, 0.03245074136723434, 0.02892461102155428, 0.1441118178228217, 0.035062338931546096, 0.07594385109240971, 0.06196019923194282, 0.036744924652720654, 0.013590949444821285, 0.07107422086260012, 0.12193708875847441, 0.10844936008535086, 0.037334800863097754, 0.045533830059632185, 0.04991337852252107, 0.04630153825987251, 0.029980151861485456, 0.047461173211735104, 0.017072338340503555, 0.014662000692389427, 0.07887453576850315, 0.16881410843662678, 0.04891997698934809, 0.06066629588003121, 0.08056498538222044, 0.17362932344117474, 0.044900148941744725, 0.06206412288931109, 0.09399767829886368, 0.09120630671180065, 0.18550402334620877, 17.775265747501006, 131.90706529924947, 97.33931110751246, 112.94447652755247, 118.20557517390098, 74.77429205371489, 64.36997375180646, 48.56249247827838, 1.4978511871830111, 1.3428236736405281, 0.08067848896908184, 0.9702471691754557, 0.06904695303209367, 6.132025641779746, 28.131097670524355, 60.871549037195024, 105.2858369581161, 82.37814395658432, 72.23472995142784, 77.53433842812815, 84.7263728418658, 83.9548740079326, 86.07427181736116, 82.75940618207379, 87.69415578534527, 89.39784511443108, 88.23717655674105, 86.10801204558342, 82.24375570974043, 84.22121863211356, 79.89014533258255, 71.4486163662326, 66.08697168288693, 64.21495383785617, 59.07992801358623, 40.20842452203074, 23.501386873183712, 30.599182421161284, 36.05129265016125, 38.67001210489581, 28.938284189470355, 27.34446829365146, 24.973068006577034, 23.94330463101787, 32.116155162934334, 28.138199121721332, 1.6828529632860616, 0.08305201321960458, 0.14708131251315917, 0.48020055036871667, 0.823340984361787, 1.1866329321938178, 1.1493140314855883, 0.4561704865867092, 0.19708388665270424, 0.310606426529346, 0.44726051630512365, 0.13291415578174975, 1.7599019191918837, 0.965023368837372, 0.6559988219411143, 3.819910263822925, 0.03633763017733732, 1.806292036368001, 6.200182216782724, 0.8396081566329926, 0.9697033080362505, 0.09771615417013246, 0.5750868217118326, 0.5202925974322904, 0.7343159904403072, 0.0725884702537329, 0.19339278310296998, 0.26847462440210007, 0.5957855368333479, 0.8055630867039004, 0.9778880075581613, 13.080951552237234, 26.024708401772287, 10.176620791035315, 5.850124407199122, 13.53550228380388, 23.38997979317942, 25.477541685104374, 20.83547934409111, 31.51339081025893, 36.62112674405498, 16.587062151201312, 31.440264101951357, 50.360201020394605, 54.14022445678712, 67.24004653192335, 63.81207935271725, 72.64860276252993, 72.00495750673356, 71.74299809240526, 79.02104223928144, 72.18233493066603, 72.513029959894, 70.68787267131191, 71.68380952650502, 70.25860847965365, 78.02057112416914, 74.38221977603051, 71.64235007378363, 67.45649860751244, 63.66122891826015, 39.96012672301262, 39.11141995460757, 15.819759272759962, 1.1814221859939638, 0.4524358692428758, 5.124050051935258, 15.268506426965038, 38.86841735532207, 54.37022439895138, 39.488493088752996, 60.6441221698638, 103.187345381706, 58.202066267690356, 74.6692745147213, 40.49240020013625, 0.5743224498245024, 0.15987897982760785, 0.13941347719200198, 0.11413954709085727, 0.11444513956385274, 0.049543449985644514, 0.022700885911622358, 0.03750856492608305, 0.03847257166560139, 0.0851400548051442, 0.020264582670924645, 0.04259008741486938, 0.08530165339189191, 0.09305939679184268, 0.05444269334416717, 0.05848167358987755, 0.017038502152107896, 0.10135088897039814, 0.06959066095371401, 0.056014579360283194, 0.04616412506889432, 0.08988227695226671, 0.04789088341978289, 0.05400664758898559, 0.020911559244737993, 0.07770399938547805, 0.3379487480607725, 0.1380859693932918, 0.18338310892783827, 0.19148755307880141, 0.2899261894485643, 0.12250013273930359, 0.14966005639683816, 0.23512199070424805, 0.14184500962015123, 0.23765132191681096, 0.12746149433716653, 0.12325957868128054, 0.12771283246336446, 0.2544235453129776, 0.15296518952856142, 0.17816105527022194, 0.21528198353705869, 0.2378534618765116, 0.28789945787960486, 0.18241688819421878, 0.10032783217367627, 0.21453248907721814, 0.20632696728552544, 0.16329424575932566, 0.25758538935934344, 0.2083640103979457, 0.094060160429968, 0.36697876128938894, 10.048618162831954, 155.67178049395162, 121.68030092793127, 116.87286361571282, 128.17615385978453, 116.90408568228446, 62.33337325434532, 81.35621747662945, 5.644453946621188, 3.5247940738354964, 0.2945011746018164, 2.109643365106275, 0.12268905768231039, 7.194116211706593, 40.3941918957618, 62.10054920565698, 97.37274539086127, 92.64435952709567, 83.07236425338253, 83.60869346126434, 95.56306577497914, 89.91825734415363, 89.83343216680711, 85.10141418826196, 90.54286341513358, 94.18199139256632, 92.0178158052506, 90.35637824766098, 87.55100496353643, 85.21476284150155, 81.63546669867732, 72.72156669247535, 70.88807828964727, 67.45546310178696, 59.541532147315245, 39.58971377341978, 28.9989044204835, 34.32614011149253, 46.26462290363927, 51.25478775270524, 31.749982295497773, 36.0667154096788, 29.557245969772342, 24.86384960912889, 34.91310319592876, 36.88401576011412, 8.704471914998948, 0.3366027928648457, 0.48777909048141976, 0.5246520667306839, 0.7746222663310267, 1.7206289426934336, 1.4472920808099932, 0.9333458170294763, 0.31359150344806336, 0.6398087487586084, 0.7622845735280745, 0.39968519982311035, 13.51949214935303, 3.978186235312493, 6.9366224158194765, 5.234428980658132, 0.8017001649545086, 4.3032048594567085, 12.594819857228188, 0.7381500459967122, 5.587711468819649, 0.2592498226271522, 1.3797750972932386, 2.080737458121392, 0.6853568433753906, 0.7005861810138149, 0.6573428465954719, 0.7666604677515646, 3.6154170045929575, 3.1150627953390924, 2.076522626223103, 19.038476828605898, 35.06910762479229, 17.10310289936681, 8.442925330131285, 18.837627941562285, 26.417063090109057, 30.62856293493702, 26.037354123207834, 39.26066613966419, 41.25240256709438, 14.387853914691558, 35.63734531402588, 58.24658909151631, 62.143726656513834, 72.8699185771327, 68.02782320207166, 77.68629104860368, 77.49105115090647, 78.00474828289401, 81.01887795232958, 77.46172751149824, 76.84640961308634, 75.5726905022898, 75.00273873729091, 73.28397181726271, 81.21066616427514, 77.94646970687374, 71.76817970891153, 71.30152748477074, 70.52365872167772, 58.18960882002308, 51.634751673667665, 22.88573165093699, 2.0027574295959165, 1.3411453895030485, 6.633594314898215, 21.592434029425345, 56.31440993278258, 47.166540545801965, 58.6343938304532, 107.37881368206395, 113.01981741382231, 65.80592209292998, 99.63153639147359, 37.74144980215257, 0.7328783191980854, 0.24790960694513015, 0.23555221036076548, 0.20649199794617393, 0.25936433745007365, 0.12141650137040885, 0.16788498168030094, 0.1884951063942525, 0.09971008185417422, 0.22503587627603164, 0.14008706766030482, 0.14692930534722345, 0.14518807942588485, 0.238861327149695, 0.22862916571959374, 0.1314288338706378, 0.11526139858629435, 0.2664438478889004, 0.21413704981246304, 0.19808456602115787, 0.1165746188452167, 0.19145513223784585, 0.18782096434264414, 0.15547903044329536, 0.20676564455272692], [0.037229670617248745, 0.044190146314400824, 0.03635143125129323, 0.0071973189610176755, 0.06064575323234163, 0.08281153822017294, 0.007185570045088929, 0.06648746093795185, 0.023448426847256, 0.055344053243677464, 0.049632316184861046, 0.033978895254192815, 0.050775595159540256, 0.03181741073457224, 0.05767047840861544, 0.09306211640397388, 0.07700074599274705, 0.044376294188682115, 0.019956933251852473, 0.1636309720455639, 0.033279594875151114, 0.057578747040562095, 0.06655895992392494, 0.06817910564883102, 0.0394423547080688, 0.1343045440772849, 0.11817155210601708, 0.054564888198529525, 0.07700135886308647, 0.600241165487997, 47.400584451613895, 122.55494240791568, 66.2842276788527, 85.13626052487282, 111.44200478830646, 66.0230762727799, 52.0083535102106, 60.01599381046911, 6.002182441373026, 0.6771436453826967, 0.26806577859867003, 0.22555968123337916, 0.7227962956793847, 15.14746012226228, 64.32680414568993, 52.03344883457307, 64.65200001193632, 68.4234256129111, 68.63444912818171, 76.63082045893516, 74.38630688575007, 82.05348153268137, 74.33903448043331, 77.1492793483119, 78.85110947393602, 83.12285300224059, 86.46144113233014, 81.91630840301514, 77.27694465268043, 76.46365688693139, 70.23318367619669, 65.12473975458454, 54.12719042070451, 44.664801859086566, 22.599120140075687, 18.16421974089838, 16.388661803737765, 32.79529982997526, 39.783529850744436, 28.99816897607619, 38.77639855107954, 24.58432189879879, 20.055119875938665, 17.28354173321878, 10.725044627343456, 2.016972221674458, 0.14858482135159357, 0.04247958306223155, 0.23186548883395813, 0.08366951839097085, 0.29472297237765405, 0.25801289706460895, 0.3119770497564347, 0.18487200080867738, 0.5624543382756172, 1.0974476726785785, 0.8362816190046649, 0.08391292750715248, 0.12265780129499974, 0.1544971355507451, 1.121434927467377, 0.6592985771356091, 0.18729798676025483, 0.3499710884305739, 0.5857270475356811, 0.5995385709308809, 0.1904279768707291, 0.1914268635934399, 0.2930058629041718, 0.1474879060180918, 0.041829542136721076, 0.39872952045932897, 0.2397694937404125, 0.02844904662079869, 0.2931964962232498, 0.5566507625964381, 5.93775898218155, 21.43477043797893, 17.021290102312644, 10.606021285057068, 11.223337631071768, 10.328683237875662, 22.09968866840486, 32.513055878300825, 34.00427041515228, 14.618541252228523, 8.664624556418389, 16.787889465208977, 34.42821587285688, 42.93663301775533, 50.90068401828889, 58.79960406211115, 58.15116174759404, 55.70462649868381, 64.11206614586615, 64.69045885147588, 60.20426365637011, 62.79144333254907, 64.76367381311232, 66.63567204629221, 63.43754006970314, 62.03246470420592, 59.43644008328838, 54.506632666434015, 47.66239481587564, 55.03670569389097, 55.80679247456213, 25.937731804386264, 5.624154210090638, 2.1530044319168216, 5.849248247761881, 6.3480751841299, 24.889056721041282, 23.87732840353443, 42.62999780716435, 77.51496976421726, 97.47490744436942, 46.22535213347405, 66.05301180193501, 50.222404233870975, 0.6000291736375901, 0.07782940031780351, 0.03800547636684872, 0.08279548101728001, 0.07232741813265509, 0.04525301670054755, 0.08321044786322503, 0.1605168859203977, 0.045205411996932766, 0.03718876535253179, 0.06629808400306972, 0.029863539872871294, 0.021374803036451343, 0.09370477224189429, 0.09670937674180155, 0.14484753802178368, 0.04785513392679634, 0.015567384468722007, 0.043343803019172726, 0.036040763445799394, 0.07436220128569873, 0.06139389937743545, 0.04822598559962166, 0.05268695388710307, 0.04763023349486532, 0.04265828073144921, 0.043686811226390065, 0.05487929068265423, 0.06158208504559533, 0.03272922581902916, 0.021901951967588356, 0.011571791612603253, 0.052414644103977955, 0.1140829791585284, 0.10358627990729387, 0.056770462993412256, 0.03908647239328392, 0.03554123964521193, 0.043179404381061756, 0.006749618135678072, 0.03133018839082891, 0.04110470038628386, 0.02433785875778525, 0.06388540116829738, 0.055112671707907034, 0.06934715224610222, 0.060242488379440004, 0.002763828092757913, 0.0056202340807255, 0.06127292643331232, 0.02623336329575508, 0.07334462201763546, 0.30776705953382677, 0.053121781562485045, 0.09962814875067243, 0.8688869952194153, 91.48824876354587, 124.39131767519059, 90.67635736157818, 116.56989974360313, 110.44660922019713, 59.91192156268705, 74.28710229935186, 42.585208262166674, 2.463112165850978, 0.7663612644518576, 0.03287299370933925, 0.21082011892670588, 0.4586243887822475, 18.10376228824739, 57.161830163771114, 63.9776582871714, 88.01637849500104, 84.61814680407124, 79.0455178291567, 83.90306734269666, 81.45217434052499, 85.21749281114148, 76.31621499215403, 80.30274729574882, 83.29992448129963, 82.99325004700692, 83.23415417825022, 80.93550405194684, 78.1593132019043, 76.17597456901305, 72.83697851242559, 71.53926234091483, 60.2143245358621, 54.62997944124284, 30.912040472030643, 23.90570479054605, 25.312131412567634, 34.11909387957665, 34.32786203199817, 29.53184666172151, 35.430028438568115, 28.600234716169297, 29.22764135945228, 26.102987143301196, 21.694672569151848, 0.6289240489563634, 0.16936428214032806, 0.10396860374678528, 0.045446358140437834, 0.4056599808316077, 0.3901147085332102, 0.2962585496565988, 0.26983179512523836, 0.5151414835164624, 0.26483913883566856, 0.8728712040089792, 0.7825078238402644, 0.05854649611959054, 0.09173379655206397, 0.2038027688620552, 0.5747490688677758, 0.3001166910173432, 0.4199110854777598, 0.11075104061033457, 0.15970532301693194, 0.506738173144479, 0.15589576695234547, 0.32176817436852767, 0.017143844987355897, 0.11704086761681304, 0.1661654054037025, 0.3316265002133385, 0.20354577700697607, 0.30477358629145934, 1.0684445644578626, 1.0393269720577425, 7.455564737319947, 25.929947860779304, 21.78382412079842, 14.455860949331715, 17.30660919220217, 16.721897548244847, 23.4660816192627, 26.448477352819136, 31.928316777752293, 26.177753402340798, 11.422776426038435, 21.833973584636567, 40.63818293233072, 50.14798118222145, 56.81474354959304, 60.79615716011294, 65.55244284291422, 61.04837732930338, 69.7161211506013, 71.94984036107218, 66.15745667488345, 67.78407143008324, 68.26633468750985, 69.56137580256309, 70.31090936353131, 74.26049294010286, 69.29965957518547, 66.22823976701306, 58.3219103659353, 50.55924561715896, 49.52288873734013, 27.55859048135819, 4.585863601776862, 4.534939960125954, 11.585908782097603, 20.92962799533721, 40.43267819189256, 43.69708645728327, 48.79378288022934, 52.35806419003395, 95.49250233557918, 73.92530287465742, 58.93026213492117, 76.88866922932287, 3.3750558764703813, 0.20801718707286543, 0.04974744770856154, 0.015087447621138587, 0.08351105310383343, 0.04188059806643475, 0.03505452866515806, 0.07450549803193539, 0.05158609320079127, 0.06043320596818963, 0.10571130821781774, 0.1167979411360237, 0.07720462497203581, 0.04088009106776407, 0.0915118762021584, 0.06766864594312445, 0.040616648752362504, 0.033693592619871905, 0.11192890845479504, 0.04156139987190405, 0.03894339015166606, 0.1018894641029258, 0.07516041127664429, 0.05829334619545168, 0.06677767802630702, 0.0256831148984812, 0.09886564611787758, 0.3348530174022721, 0.21258924577024677, 0.11697232573022766, 0.14183698101870476, 0.14385591381259505, 0.14683141463225888, 0.25989143658549557, 0.1985261850659886, 0.14990200228508443, 0.18852702161717802, 0.10446828459539723, 0.16322299958236758, 0.21247174320442064, 0.2004669309263268, 0.16691224919932504, 0.209285200483376, 0.19900800840508556, 0.14474275251550062, 0.17777082540335196, 0.17018765811958622, 0.16066880115578253, 0.19046048964223555, 0.16835370491589272, 0.19058024450655908, 0.25534973029167424, 0.4223611572336766, 0.20169713023689487, 0.30114413749787117, 0.4017524421215058, 76.07569525318762, 154.2405076180735, 93.0072650601787, 115.59594385085569, 126.62855132933586, 85.92632785920175, 71.63380715154833, 82.90476922065982, 10.667257328187267, 2.495049329534654, 0.2490697704976605, 0.5387060416321601, 0.8100959370213171, 22.665500371686875, 87.64380824181342, 74.49530170809838, 85.64987136471657, 87.62112125273674, 87.21157089356454, 93.65957875405589, 88.37267091197353, 88.52408224536528, 77.48190418366464, 82.60670046652518, 86.44425330623504, 89.0523313706921, 89.41289132641208, 86.77829019484982, 85.44103653200212, 80.5830712472239, 74.92429917858493, 72.87152674890334, 66.05294119927191, 58.32476977379092, 32.436657913269535, 31.333252037725142, 26.553296812119026, 43.86811356390677, 45.57285408819876, 34.66429548878824, 43.21089690731418, 31.444066839833415, 29.790309283041186, 26.93984050904551, 34.83229060326853, 4.988227688497113, 0.30634434232788704, 0.17458679545069897, 0.2519754194203885, 0.22816784289335051, 0.47694844584311213, 0.5460150720131013, 0.6054861711398248, 0.732533763493261, 1.1088504930657725, 1.5643880684529583, 4.509204308832846, 0.12319534986970887, 0.9042281020552883, 0.4976907054022436, 4.849175743518337, 1.798406846580967, 1.086977640947988, 0.2925427474321858, 0.4838185078434406, 1.9422248390413102, 0.1878710664928921, 1.7708687436196113, 0.3259177355756683, 0.3730553094177477, 0.15146381041455656, 0.7487676569050359, 0.3753317856500226, 0.8564073003588185, 1.578868355962538, 1.935020180479173, 11.405945535629026, 29.50936559707888, 26.102573333248017, 11.85174055637852, 21.1285961058832, 14.96701442426251, 25.16173008949526, 40.29293198739329, 45.72991755700881, 22.855439186096195, 14.575782514387562, 34.022336852165964, 50.59413509984171, 63.306905531114154, 61.8071755286186, 71.5874682703326, 75.35260631192115, 63.52635429751489, 73.97046504482147, 76.66978528422695, 69.37849137090868, 74.09505521097492, 71.42287777316186, 75.52683015023509, 71.87099287586828, 76.72763239952826, 68.51818223153391, 70.56599678531771, 67.78036871264058, 66.03364313802412, 64.36742028882428, 40.57504061729678, 7.054255277879777, 5.99378562742664, 13.334440608178417, 29.913826680952507, 54.38901647444695, 37.959800304905066, 64.82673375837265, 93.34894272588915, 115.74414668544647, 70.89988462386593, 83.3736885747602, 79.14082357960363, 1.5284651638038698, 0.21076918940149972, 0.17649351168544064, 0.1166068864685874, 0.16066258052183738, 0.1008454088361994, 0.11391136780261032, 0.14588341146947878, 0.18648620935217028, 0.14555765556231623, 0.12519917540973233, 0.2404737124039281, 0.17336994139177186, 0.19813171107201807, 0.19186966241367404, 0.21538848508029215, 0.1915519963949919, 0.11096948292106391, 0.20670526150253513, 0.1318359023500835, 0.14775393771067744, 0.15770243210417612, 0.19212400360453516, 0.09405162621049151, 0.18264317524529275, 0.1310060605887444], [0.08886658226049717, 0.034001747656974106, 0.03602188703934512, 0.022101688326426575, 0.06121444711161237, 0.04887390063114224, 0.05260564131481994, 0.027729686229459705, 0.06760214951129691, 0.06865702193951415, 0.024979819370914372, 0.04840939854001326, 0.013213720090026337, 0.03554419674459965, 0.044527186696688016, 0.09881504601047886, 0.02463995020896677, 0.0667885028486771, 0.0612343539063248, 0.07228994877227853, 0.06133689094455012, 0.0287557001255693, 0.046477922343558846, 0.029281655874764247, 0.14759757916533178, 0.04261555217747246, 0.03243419003763026, 0.07079163400997078, 0.15076984200746785, 0.1985991013146216, 2.3425176691624428, 97.02680803114369, 101.62813263554727, 79.81802863459434, 103.72423941089262, 106.91347152956071, 54.48078816936862, 45.69804437698857, 62.75268639287641, 9.416526248378139, 0.5100636995367466, 0.06355502958139105, 0.5610557068740168, 3.834345321501455, 26.943500080416282, 75.14652498306768, 71.5865033672702, 64.2663408094837, 74.1999864578247, 73.87150364537393, 80.42819253859982, 75.40180067862235, 70.28070711320447, 69.22602099757042, 75.69215020825787, 69.5762651197372, 72.1616248161562, 69.02652140586608, 72.20973660868984, 67.35403060913086, 62.214929442251886, 53.03040158364081, 47.40331049888365, 37.87362583221928, 22.284787278021536, 20.145185339835383, 11.638542086847368, 26.110359238040065, 48.11673079767535, 32.83686910906146, 35.89898309400005, 24.90652499660369, 23.060551689517116, 13.001756937273088, 5.808051103545774, 0.16551230012649493, 0.041477405991885936, 0.12727378747395932, 0.04990582489558766, 0.10694269496466845, 0.023204774498158408, 0.12776244431734085, 0.24618011749079152, 0.06060599709951109, 0.0548552125391941, 0.18790200112327454, 0.42052242364133563, 0.18198588712801858, 0.06983798477918872, 0.27431031448706505, 0.2829851264194135, 0.14023325255801602, 0.06567054307989537, 0.09875994130608537, 0.024459938698958968, 0.06121354312786172, 0.3176107377775254, 0.1624384949043874, 0.42227140237246796, 0.24052798207248413, 0.22567297031562175, 0.026278606533343275, 0.6625686694056757, 0.025614086546063907, 0.19662274768756283, 1.8121558572015457, 7.629169821739198, 26.075346200696885, 18.617482954455962, 9.805094868906084, 8.698751138102624, 16.301102734381153, 21.76824446647398, 19.88597550699788, 17.335760247322824, 3.4944866549584175, 9.61931965043468, 18.181362459736487, 34.28924237528155, 46.42275325713619, 49.44442172204295, 56.49388190238707, 53.06935464182208, 58.836140940266276, 58.0696980414852, 59.253979267612586, 57.626179956620746, 64.35531193210234, 62.334946124784416, 67.1498320179601, 63.61261113997429, 65.17777804405459, 63.401038492879565, 54.997889918665734, 57.84367538267567, 54.669685594497196, 37.15914649348105, 12.330129492667414, 5.823460134767718, 6.8819367308770465, 6.825395764843111, 14.192144313166219, 17.74534983019675, 49.759894032632154, 82.60336645187871, 105.0008846098377, 53.55899195517264, 60.29680805821573, 70.51735155044064, 7.350950221861563, 0.9488375857472421, 0.09890941272099173, 0.22897467137344424, 0.11944971618152435, 0.19761582746380763, 0.09791646317969407, 0.2559491328053898, 0.1939361999111791, 0.08498834641349894, 0.05649322726493401, 0.11946868451852953, 0.026048458399130933, 0.03603781783773053, 0.10125693594736439, 0.1529507104667925, 0.06517373506099948, 0.05791109513431307, 0.04902790345612073, 0.0083012176647542, 0.04485908279856367, 0.03808437959260998, 0.02927061846299518, 0.060281593337534904, 0.016078151567208192, 0.07042929740442384, 0.029292191498942917, 0.05336845804366374, 0.06314511125486705, 0.0669185998999784, 0.020782921590932438, 0.03273446202999161, 0.038232475879692265, 0.07483929020142363, 0.017332442427775072, 0.056935060814383535, 0.06394476532154987, 0.05579743939902514, 0.06268062448549656, 0.04916311414431661, 0.04061738802720943, 0.047716391573269526, 0.04470663513207147, 0.057083838919718424, 0.05672302299870118, 0.12597303912644425, 0.05455955239613691, 0.16857367940247062, 0.07291458622221986, 0.036318497131428415, 0.02337590513390399, 0.1447811028769901, 0.1287827355366561, 0.061985043463327234, 0.02682082824439051, 0.2145657679366489, 0.4666765857367747, 14.09934691844448, 131.86412319060295, 92.97162640479304, 98.16165954835954, 120.51745937716578, 93.70696098573747, 57.46423705931633, 74.9559134821738, 50.35241903797273, 5.60508462690538, 0.6406045608943509, 0.027828404319382487, 0.267054358677518, 3.898406206600128, 31.114328868927497, 60.63555571340746, 67.91962069849815, 81.42807529818627, 85.60851389361967, 86.69435147316226, 85.12963956402194, 82.7820304132277, 72.76493241710048, 76.35534455699306, 75.81959585989676, 72.14002040124709, 73.01928243329449, 73.61702811333441, 75.61126309056436, 72.04848797090592, 67.34819412231445, 60.73252847117763, 55.146363396798414, 41.038421584713845, 22.895008056394516, 24.78473932512345, 18.929179983754313, 35.54323980885167, 36.96586385849984, 28.455673802283506, 34.2103595887461, 31.13217369202645, 27.068547202694802, 25.910243834218672, 20.464640817334576, 1.0396747146883318, 0.5334786866461078, 0.13340227636358432, 0.10942339491579803, 0.28674076521588915, 0.16092211578882512, 0.04815517226234079, 0.09782695346662114, 0.03042757019190298, 0.20414223774306237, 0.2980200615861724, 0.45139199783725126, 0.40849714149390504, 0.31828039055389745, 0.47261422680270293, 0.36685523727247793, 0.15263966344777616, 0.6263115665604991, 0.4272251107519673, 0.10139658611508147, 0.1726989096571361, 0.3964643210412995, 0.37801248051466485, 0.20866486844756912, 0.47399364471916233, 0.01993157957199841, 0.080367962889854, 0.562320364819419, 0.35382227371296576, 0.4300053051162151, 3.621264768223609, 10.84010833694089, 44.49047603914815, 27.89127611344861, 16.03783619019293, 15.523077076481236, 22.4422743628102, 22.27736419247043, 24.307855598388183, 31.555297413179954, 11.79236371671, 11.156055254320945, 26.521617789422315, 40.68367850395941, 55.25371474604453, 59.16374121942828, 68.4759775284798, 63.983341801551084, 68.12268180231895, 74.25133028338033, 68.83401932254915, 67.2630630000945, 71.35101210686469, 62.828858821622795, 67.04761505126953, 66.78646364519673, 67.99769155440792, 66.4359841808196, 52.62950005069856, 52.594281088921335, 49.28346726202196, 35.04948792919036, 15.642060214473357, 14.490989696594978, 19.054482060094035, 28.37375902360486, 37.97639193073396, 37.63038396835327, 50.84943432961741, 56.78270170765539, 92.44750361288749, 80.28512800893476, 50.57954780517086, 81.44389029472106, 20.762986098566365, 0.24084875840813885, 0.20039095032599666, 0.10623834606620575, 0.04675418514037325, 0.030081432515514955, 0.01907914396255247, 0.04073769064439882, 0.11798778293474067, 0.1276075106955344, 0.18960012693799314, 0.18422477908672827, 0.01829189285936375, 0.04945977020167536, 0.09273891923047843, 0.07378791879502035, 0.0472489285523132, 0.09138067598424612, 0.04044629761107987, 0.02288895283615397, 0.04086301113749224, 0.020601632629310893, 0.08509136225667693, 0.10233308263723889, 0.049407760492495956, 0.05901231588194928, 0.03068150535616423, 0.284139804782406, 0.11476634490874507, 0.20852484289676915, 0.1040709990587446, 0.14683562811584244, 0.17096370518688234, 0.1983764761638257, 0.18439635213825012, 0.18971603604093676, 0.15599031752396017, 0.1345641253095481, 0.18229086673067463, 0.14002191954322402, 0.15357968397438526, 0.16087202896033564, 0.3363195548374807, 0.1762431388300273, 0.21513512448197414, 0.20756553227622665, 0.09893948933289898, 0.38783185844940526, 0.16350700369765683, 0.08898311955553871, 0.12110612850876586, 0.3268426488484106, 0.1821631445519386, 0.19974906057600053, 0.16325209560173173, 0.2344822613221984, 0.5362096368785828, 5.854010495447344, 140.7702882828251, 127.59379171556043, 107.01964224538496, 124.76125994036276, 125.4442701032085, 76.08299086170813, 65.3829219264369, 86.69424164679744, 18.425777112284017, 2.2091835593023608, 0.08480100727249539, 0.637053590147726, 4.5438157935296335, 37.59147797861407, 94.88962619535386, 90.49479869104202, 80.96918152224633, 89.41399743480068, 93.72680033406904, 99.34314804692423, 89.5843695056054, 82.74175551629837, 79.96846722018334, 85.30245134907385, 76.18097166861259, 79.39715831510483, 77.44392779565628, 82.48531095443234, 79.99928920499741, 75.11478516363329, 63.80465430598106, 61.723107368715354, 50.08498007251371, 34.7049077095524, 32.27302447442086, 22.616037322628884, 39.953717570151056, 59.43253340259675, 40.48017809467931, 41.63629278059929, 30.243397951126102, 31.106811646492254, 24.029018225208407, 37.325619728334495, 2.0190320788852634, 0.5810504178366354, 0.1847518782221502, 0.1967272114369177, 0.2951622471934365, 0.19258515789143502, 0.2127626421110284, 0.41036259623304494, 0.11816456538414764, 0.3926292236053175, 1.3891413495425255, 1.9072403614559483, 0.48613644475417755, 0.8959580909821295, 0.9532509876355049, 0.7287629561558847, 0.38317952905931785, 0.9528073920838295, 0.6746132876123152, 0.15089984712821825, 0.40300974562283487, 1.419082639678832, 0.39990595571937104, 0.3422852347214376, 0.41888296483985843, 0.3297049371946243, 0.14877520952253573, 1.05487659573555, 0.1752387822395371, 0.48528032617703565, 7.552209486884456, 9.92316311405551, 43.774929815723056, 24.20871965346798, 11.098318945976997, 16.734827641517885, 23.12025800828011, 27.29622314053197, 30.07203744303796, 39.02820294903171, 9.875382761801443, 28.83365300393874, 38.38957440468573, 55.27609971261794, 65.72945156405049, 69.72270288775044, 76.34003162384033, 67.82999454006072, 72.3144325133293, 79.2791969545426, 71.14404432235226, 72.98906449348696, 73.83464905523485, 70.01446447064801, 71.35242416012672, 70.18365983040103, 67.6280003209268, 71.79447527854674, 61.51115817408408, 66.68667854801302, 68.26622486114502, 54.72632069741526, 19.947554757518155, 17.010493778413345, 22.65185836822756, 38.148599670779326, 43.85198870012837, 33.89347914726504, 73.61138774502662, 99.58677430306712, 124.18807614234187, 78.36094656298238, 73.97266157211797, 97.11771288225728, 12.290800867542146, 0.9034855483520416, 0.2644197210188835, 0.3527656239607642, 0.2711288432680792, 0.48538004018126, 0.27841862952036245, 0.2214621986833311, 0.19747403991078177, 0.1429876910462495, 0.1943747699260712, 0.22078649381235724, 0.20956782564040155, 0.18581177618715072, 0.2616407523953146, 0.22381919075644788, 0.15671420932537125, 0.18581672511514158, 0.13694429920325357, 0.10391503887911958, 0.1795489614408824, 0.13470222031877888, 0.24630027072083568, 0.1798355702551142, 0.13190239878191104, 0.14783724211156368, 0.12265014807663618], [0.02966785611915252, 0.11838014252604016, 0.04790297994810728, 0.04646534317984216, 0.0674824865775243, 0.08871747090691522, 0.0443229936213503, 0.06543494039966215, 0.10698500600072647, 0.0071872908700888445, 0.10212951009311985, 0.03860371442691934, 0.03225349670936985, 0.07449255114601505, 0.02026737697662846, 0.045254215628149054, 0.053855057940968586, 0.06609271881320784, 0.013720303390836044, 0.0036421225212829853, 0.01119360560551286, 0.06682861521239243, 0.05423765374167312, 0.09647046456173544, 0.04280769085932163, 0.17998987568482278, 0.0709529108397903, 0.05990618727199974, 0.12330491576463946, 0.2996595816746835, 0.41109087005738293, 18.215224281434093, 105.85402365653746, 90.12183620083718, 74.3803527278285, 118.94873096096902, 91.04717039292859, 48.44264445766326, 34.29840895437425, 49.378137588500984, 8.967501155791744, 0.4144447417028489, 0.43846754297133417, 0.7506682904016587, 7.04503623708602, 40.702894195433586, 80.71070517263105, 81.52808004809965, 65.72526639507663, 57.87951015656995, 72.5677627132785, 74.25384844503095, 74.321226919851, 64.13496102056196, 67.24179590902021, 68.1419014161633, 65.53952647793677, 70.80388069152832, 64.02951202084942, 68.68875042084726, 65.43196332070136, 55.33871250767862, 39.89876124166673, 36.79232251259589, 27.832873982767907, 20.517218228309385, 19.5559629701799, 17.561727992949947, 41.065748737704375, 47.87013530731202, 37.55895368514523, 33.25674903008246, 31.52655624574231, 14.185059532042473, 2.9841777153553504, 1.2896597457508887, 0.4137151808507981, 0.01657042626081215, 0.11307474616314135, 0.042061513560193206, 0.060958443509955565, 0.05812358877231037, 0.04374260540991541, 0.07237408820900225, 0.11539046907977712, 0.308640951350812, 0.13876207262998627, 0.06319236355803667, 0.5113107068163734, 0.2753310193938594, 0.1561490356201126, 0.5199350488762702, 0.15239624667071527, 0.16690489475525197, 0.021616323745899627, 0.020395325151302164, 0.07721957900831777, 0.16939552320588022, 0.29294138894446436, 0.09483246132731439, 0.2727932458923709, 0.07870220428993625, 0.12261259444658795, 0.18587499376266234, 0.6790837477291785, 2.625297759809802, 8.179155251672192, 25.772790255085116, 19.476183922060077, 6.581064462661744, 6.174096493951737, 14.50140456999502, 18.59494697663092, 18.30140659886022, 6.426822648894403, 8.138105196337547, 11.724240972149758, 8.178067284245646, 23.258156776428226, 43.59908211615778, 49.239952487330285, 47.741642382837114, 53.45531978914815, 56.39055490493775, 55.420540994213475, 53.86457597055743, 57.840639468162294, 59.22727969384963, 66.9211970606158, 67.34432666532456, 65.57784411215013, 64.78536452016523, 69.67084130933209, 69.655042002278, 49.876878723021484, 29.191604583494126, 11.600706904165207, 9.861236733774986, 5.827373189310874, 5.084465001859973, 9.280594548871441, 13.037559351613446, 44.39795124915339, 90.99162178654825, 103.90492731525053, 65.6257519414348, 60.872133470350704, 76.89922824982675, 16.807854329386068, 0.5413869203579041, 0.2681479338676699, 0.1252639175002133, 0.1324732108942924, 0.06511880655682857, 0.15315617524808453, 0.34545264056613373, 0.37787139776252937, 0.09430191479623319, 0.1614445877531844, 0.028287988126037583, 0.05977920436811063, 0.03654086947320931, 0.029644247204546007, 0.04723192140039417, 0.06694286956541962, 0.04837450706550191, 0.11889182031154634, 0.02972777951658974, 0.04011672658605441, 0.012243952369317414, 0.05535014747311512, 0.009624637426778434, 0.08437703889344009, 0.0945766569085179, 0.06323301984417824, 0.05986160095480662, 0.02406003505682513, 0.04380403800056346, 0.06817393455534212, 0.01290061708254319, 0.04777655245796327, 0.04504888108180416, 0.0645067252879662, 0.07008738470293822, 0.06600134750647892, 0.05004004733036122, 0.08448645923166506, 0.1597933005541563, 0.039320274766895084, 0.05036215665900419, 0.024349738866271033, 0.0598639605056134, 0.11431213903931842, 0.030557123320778052, 0.02491160307169682, 0.12614912443584012, 0.02374852455461458, 0.07351013531367626, 0.09926354452486962, 0.06446085194306028, 0.06439469258991942, 0.3208373775405269, 0.1613330913166846, 0.325334620091223, 0.12262306686851288, 0.5401900458720423, 0.8757512043080024, 53.27114097533688, 128.73412670627718, 93.82344753511491, 109.64737922914567, 120.04580220868512, 77.0236458316926, 51.492377481152936, 68.7703670993928, 53.60410705689461, 9.550011369489855, 0.722520197591474, 0.21424758097817823, 0.9261010154601067, 6.658416544237445, 46.75529964508549, 69.93800178650888, 69.45682110324984, 75.17385605842837, 78.61633208490188, 82.51646241834088, 80.78438297394784, 75.82247487960323, 67.5177974085654, 73.29338550567627, 72.70270009194651, 68.92353565462174, 74.46184389052853, 71.18227958679199, 69.34436675040953, 67.70973467057752, 63.42226243788197, 53.50298443148213, 46.21118453241164, 34.41475822079566, 25.325479238264023, 19.328024233541182, 25.736518136916626, 39.59634650138117, 29.681175216551754, 25.348236830003803, 21.73476507586818, 22.677216491391583, 23.09814564643368, 10.9896114372438, 0.9069632810931053, 0.7296681043601806, 0.12866918598451924, 0.08360786363482477, 0.040645901819751154, 0.24628370789991272, 0.03676046857670431, 0.031510173087759365, 0.034147476732370355, 0.12048820964992048, 0.6732963518269601, 0.1427430178849928, 0.010796320068860247, 0.6878075892886808, 0.5047488573097414, 0.17594583542837253, 0.6362743255111479, 0.3190444866495748, 0.37641040680389254, 0.047496072347125703, 0.0747133223640342, 0.10978208494282539, 0.011412467349380737, 0.18602925322709546, 0.03394218049042168, 0.2955538406968117, 0.08839158476480553, 0.31137806093019826, 0.24521169042395008, 1.1704122154943406, 2.218672263045465, 9.255671808796546, 39.802165031433105, 27.247828937345936, 13.97666302419478, 17.906653381163075, 20.28921281137774, 19.4333496785933, 26.36066136821624, 22.288258575624038, 12.111625036885663, 22.885980721442934, 25.528408942684052, 49.007206886045395, 60.89550295183736, 70.16065905171057, 69.74957112343081, 70.48894574565273, 73.77315413567328, 69.77750624379804, 67.16364660570699, 64.5549213501715, 60.79728680272257, 67.72882876857635, 71.09512452156314, 68.88763027806436, 69.36949345373338, 71.16255006482525, 65.79763412475586, 42.831572332689845, 29.419286404886556, 22.390765797707346, 25.582525883951497, 22.365513578537975, 24.499694801145985, 28.18393199674545, 31.522896674371538, 50.78078892923171, 68.74252611590971, 91.94754262124339, 94.87094002385294, 56.132698289809696, 80.0953951189595, 41.737729195625555, 0.9032220141060892, 0.02833421578660848, 0.09929012011496291, 0.11393814257556394, 0.06943137595249761, 0.1375804432938176, 0.07904630800288531, 0.29599480090602753, 0.05859543381619358, 0.05600330637647741, 0.10130571276550332, 0.111631628035778, 0.04149404542160131, 0.07966415791381752, 0.0667747209269193, 0.04798801187726279, 0.05733472122360141, 0.06386634856162053, 0.054941860913869836, 0.10734764138056387, 0.0782024315107734, 0.04351432653023832, 0.03218631079841045, 0.10208854737180857, 0.05080626932002845, 0.05628664782571216, 0.03127746430466012, 0.10406453327666368, 0.17345436428102756, 0.19559730835739644, 0.1510173190505274, 0.15374016407276356, 0.15686399483632657, 0.1598227183304487, 0.15354997508468168, 0.25248621620478173, 0.10624781491294985, 0.10409133103225501, 0.17313127435984152, 0.17861652518472365, 0.12758966084689866, 0.11341750156134368, 0.15763346886923238, 0.3282645999664261, 0.17789742909371856, 0.12349683611143021, 0.31190828570435125, 0.09537365648054308, 0.18789015740396517, 0.14878034231162843, 0.149813044155317, 0.27575524824280895, 0.3753625517410617, 0.19815201240201152, 0.3474419870443883, 0.24248414162185886, 0.6930214611272658, 0.8174395945764358, 35.75019974862376, 159.5499377096853, 116.10634619189848, 106.4557779988935, 133.37202349016744, 112.53651865067022, 70.3822494322254, 53.07175905473771, 72.7339849164409, 26.422517145833663, 2.4184140611079434, 0.5866860057557783, 1.0343722830857, 8.778989103532608, 55.622872537182225, 101.12569270595428, 94.96248029893445, 84.78138016116235, 77.9243318496212, 88.92792947830694, 88.60459281552224, 86.03622482668969, 77.11469188813241, 77.34702171817904, 76.45501982781195, 71.0723041719006, 81.53210439989644, 75.94350353364023, 77.2542655083441, 78.71173197223295, 70.0974775129749, 58.33886677219022, 50.90681468286822, 47.1822770949333, 36.91720685651226, 29.152896673448627, 31.349790711556714, 61.06283518575854, 58.23950136861494, 39.1149853890942, 32.1887170499371, 39.48989337490451, 30.019869919746156, 22.009128985866425, 1.9395671881014303, 0.6934754754747114, 0.19724634325792714, 0.21430140631573819, 0.18892963146490438, 0.20046189006778503, 0.19158826299732734, 0.13718626041325832, 0.14606387114092229, 0.08046939293102873, 1.4345883818403369, 0.2896523283373925, 0.16869197869973798, 1.3283994024799717, 0.4007749445736409, 0.27718774073066255, 1.3504843077351971, 0.5520929071691729, 0.40976857165655783, 0.3835542686283589, 0.13038430362939835, 0.3100588881681043, 0.20280821819699582, 0.31763837822983343, 0.13352083613074597, 0.8284124251334899, 0.19102134261160128, 0.4515907823318436, 0.6166220252071658, 2.0421996808821157, 4.254275252742152, 11.69952807887908, 45.174655068305235, 28.167416857134913, 11.691511734839409, 12.806932810814152, 24.905411043474754, 35.35317351741176, 35.6453626386581, 23.427328601960216, 21.10513640988258, 36.0184584894488, 28.690021691783784, 52.3874270531439, 65.01543898736277, 68.09250308621314, 69.40878775811964, 69.3330781690536, 74.9866883985458, 71.9789678819718, 68.35584317484211, 70.74138948994299, 70.90072401108281, 73.0235029035999, 76.50369644165039, 75.48131496675553, 79.96600397171514, 83.48629197766705, 85.43372523400092, 70.78521805424845, 50.98881183132049, 31.150724541756418, 28.174681086694044, 22.727224749903527, 26.47216650747484, 25.961891643462646, 28.168923047281083, 73.02691536564981, 109.34226589818155, 120.92205186044018, 96.60241542323944, 83.91193189928609, 104.29272420944707, 30.191728568846184, 0.48299269570458325, 0.3389742027126974, 0.34832240593048835, 0.2156987200461088, 0.3180208706086682, 0.3103951088363125, 0.375250457755981, 0.3895067411565012, 0.18868636790542834, 0.15720199282851913, 0.1798643138740332, 0.35581051702460936, 0.1770392267574226, 0.16272301995946517, 0.15437149713116308, 0.15263613944332446, 0.14345109763164676, 0.2650403135245846, 0.18963791039441863, 0.17960162232479743, 0.10775598922684308, 0.23716006037448686, 0.13193644372926605, 0.14374743576251692, 0.3069877029666978, 0.1225341930084171, 0.19792950982528348], [0.11456430454047457, 0.037119346295273116, 0.07326343968029946, 0.06831070423246392, 0.13105389511873647, 0.03841557855447454, 0.11835590350411593, 0.012112543392445774, 0.1076331623499432, 0.13066512081892262, 0.09582490525058202, 0.16436868407312902, 0.11296989936982432, 0.10625949009291588, 0.07048635563302426, 0.07801679308496176, 0.15838988876390844, 0.02920796013166828, 0.11102868619585231, 0.06683654422240873, 0.06659402376821925, 0.03176923912589348, 0.04205476432558029, 0.14973275814085238, 0.34565372332449884, 0.17364953284061727, 0.11606474136633259, 0.24105999949237994, 0.25963691153353263, 0.05639812511001384, 0.5571690670424893, 0.2821042478805588, 48.04164486546671, 101.41133539138302, 92.53306619582638, 83.28367802404588, 126.42738865267847, 86.5042341909101, 45.17019533341931, 25.880818213185957, 33.1053259295802, 7.1042110746906655, 3.1431570168464416, 2.414783662365329, 3.817361213507191, 11.257490688754666, 39.45405467864006, 66.22962044131371, 75.42280104852493, 71.72364511797505, 66.86142798393004, 68.0016923719837, 67.83216753313619, 69.55490389177876, 63.17349787681334, 61.99870094176262, 63.92485141754151, 69.03730792383995, 75.23399383791032, 74.67263990832915, 71.03074273755475, 56.397285692153446, 45.85082853994062, 35.21097975392496, 23.511930204206898, 24.34716755344022, 26.66530989831494, 16.81816231819891, 30.651269535864557, 51.035405666597434, 56.701861658403956, 64.86918557074763, 52.72853989754954, 24.83436123017342, 5.624073801502105, 1.2589165760624794, 0.18586175576333078, 1.3211122515701479, 0.19450350334086727, 0.015117248441393097, 0.09576228522365132, 0.05522062498775702, 0.23107595861919467, 0.2321598044927082, 0.037164273521592545, 0.25384930112669546, 0.08495323660392916, 0.21331365851144637, 0.2277009735905355, 0.4016486831730412, 0.8697882210535388, 0.06662967750021527, 0.26726052825970037, 0.1723365807124684, 0.19396011717617515, 0.1001932152036217, 0.10059629236498188, 0.17499599365457413, 0.13999380411640291, 0.02224175409684258, 0.11294515472987007, 0.38250564747760374, 0.08796908727456486, 0.2923632989968023, 0.6270318117833907, 0.558956993683692, 5.925029420083569, 29.89468159214143, 22.736432513883038, 20.991538686137048, 25.408792341909102, 19.50568602931115, 18.11704147246576, 12.120311125632256, 11.614246926000042, 12.868893511833685, 10.344647284476988, 10.66454795099074, 11.840603966866771, 29.78647516619775, 39.5173538884809, 39.22092076270811, 48.66277571647398, 55.649952580851895, 57.78826798162153, 61.06150157989995, 53.68730837298978, 58.24937789670883, 56.720743948413485, 58.13544873268374, 52.83933116543678, 50.38725752984324, 52.2207223984503, 36.442309810269265, 23.103456535646995, 17.572253673307358, 12.374640549382857, 2.723984593345273, 6.142792547902753, 9.542071511668544, 17.93893841005141, 54.60620595562843, 96.48647016094577, 110.1504388932259, 58.164270308709916, 53.145064230888124, 68.81932612388366, 23.778504287042928, 0.06606022136345988, 0.04785753944287858, 0.02489385089927143, 0.09666508153801966, 0.04067364569392897, 0.10387833560666732, 0.3261589919847827, 0.296362737614301, 0.10702552439104165, 0.2031378811525722, 0.10113667546501083, 0.053460446051171714, 0.11813378397135005, 0.05406116240567738, 0.06940312262985014, 0.038894846990344026, 0.05367345296807828, 0.06455058382163126, 0.040801310416070685, 0.09426044645689188, 0.10337550613668658, 0.06490636271454635, 0.0510531717971448, 0.04614140673149978, 0.07252542121756463, 0.06682377353671097, 0.027365237136461565, 0.042567817238910545, 0.08786185794780332, 0.06628277756634258, 0.0378100166938478, 0.011621680215842301, 0.04933971273262174, 0.028127758921454513, 0.08122312385709056, 0.04312309691862714, 0.09731926699920047, 0.04782404990926866, 0.022929086267287214, 0.11539559420799056, 0.10007352162633212, 0.050690122729828285, 0.13640907953583425, 0.0855922305415715, 0.10082737512646184, 0.04881572391417238, 0.10189547023225216, 0.07289178744559327, 0.09936536527088574, 0.07146065859424491, 0.05770313290638789, 0.09917549803973207, 0.19599187428191786, 0.12998325660103752, 0.24063817615951263, 0.175397010039418, 0.3769142781534503, 0.12240834008421629, 1.0169012496067633, 0.7604707224715141, 90.79884513731926, 110.54491166145571, 90.33330686630742, 121.31236691628735, 116.08008200122465, 66.00490785414173, 45.87146412941718, 59.79425830225791, 49.10156342291063, 19.073809539118123, 3.020260088866757, 4.3648081344942895, 6.027333659510459, 14.598223374735925, 34.62085131675967, 57.89323452980288, 53.75600476418772, 59.22389468839092, 74.45490129532354, 77.451843138664, 75.53659685196416, 73.13818516269808, 69.74594685339159, 68.75190842536189, 71.03002102144303, 75.89619190462174, 80.9718644234442, 77.15155432301184, 72.46462791196763, 65.3129154636014, 54.68794030527915, 44.34684668817828, 34.07010347612443, 30.24097784872978, 27.203480658992646, 24.24154400825501, 38.131239260396654, 30.636727348450695, 30.57276329686565, 38.57039174725933, 30.505569173443703, 32.101346254348755, 9.484106725262059, 1.7048263261395118, 0.9962057826980468, 1.2642348197198685, 0.16006152325820538, 0.02069956356389148, 0.04308508363582435, 0.07993565947418252, 0.23134277172146306, 0.1655551091197037, 0.09782596521319882, 0.2892094375866075, 0.08353233502636995, 0.12095556158812777, 0.3834055862840145, 0.31322025723995706, 2.546250233727117, 0.6152010853252103, 0.3069778051107161, 0.4026021868471177, 0.1834895798275548, 0.26668369469623415, 0.09651060756896773, 0.2642980049694738, 0.2500187082877082, 0.11451610228827885, 0.27679740361148314, 0.21536698865313686, 0.2189651504158974, 0.08372608632329973, 0.461965941733891, 0.36942362364742065, 8.625782305194486, 35.096281805346095, 36.49781919294788, 39.36343223817887, 37.093211450884425, 30.216023729693507, 27.56965352642921, 20.71532145623238, 15.552191849677795, 18.101124494306504, 22.373430882730794, 24.036670769414595, 30.327209195783063, 53.228657784000525, 52.58412999491538, 51.4748562535932, 60.60964453604914, 66.07643619660409, 70.55957194297545, 70.81917793520036, 63.6096772070854, 61.782723472964385, 60.86386903639763, 67.435819871964, 62.92221515409408, 56.59383958385837, 49.282165035124756, 35.154834947278424, 35.937237970290646, 39.28410622381395, 31.38972632346615, 20.841209926912864, 23.197677750741285, 24.25495263068907, 36.69018399330878, 58.24224310536539, 68.4127724555231, 92.60296283229705, 82.64365703828874, 58.092832180761526, 78.52907503804853, 55.33921849343085, 0.25762326474631986, 0.14954267640507993, 0.07388950205377995, 0.13790425333765247, 0.11334139072606642, 0.11792735391927343, 0.19564685892433892, 0.21725269875699477, 0.12790202553714478, 0.04130408625989672, 0.09646756874938166, 0.08142570048690805, 0.09224468526700813, 0.11817710624346811, 0.06928302302596069, 0.05238155676652828, 0.03261149725726536, 0.07776107293583694, 0.09420658281493573, 0.02287889601692798, 0.05137053521109685, 0.06704488183341681, 0.038923521661349846, 0.045252729417575945, 0.043842909301841454, 0.049576280683639555, 0.13078049366031924, 0.08128145379164527, 0.15318551641558448, 0.10893517474253332, 0.19178520888090136, 0.1451912203863744, 0.3127052010067048, 0.11252170729060328, 0.2117701445616061, 0.14417822232409833, 0.3440684422610268, 0.19986454066970658, 0.24177652152795948, 0.30296724289655685, 0.231242751282069, 0.3165995936480261, 0.1636480098409999, 0.22640744945214641, 0.24173029578260838, 0.24477999987861804, 0.15302689024998298, 0.31685451706570966, 0.24314106201692937, 0.14550838078702652, 0.2734308455499911, 0.20601955152327017, 0.33203825715088076, 0.23639689890607712, 0.2364581552965026, 0.41750774508522404, 0.46243319408066813, 0.17443042158359484, 0.5847376909467482, 0.3650232452538706, 87.88602244469428, 148.18612529385476, 120.58826600351642, 115.63526953420332, 142.2239814266082, 108.53340256598689, 69.5900797074841, 46.82859697649556, 58.62312878331831, 37.66690907939788, 7.564778231805371, 6.712324128996942, 8.640751050364587, 15.150494075590565, 54.050496316725216, 87.45358897793679, 82.55966340341877, 79.48682369724398, 82.70535592109927, 82.97214769547986, 84.6140596943517, 79.63776434621504, 74.69237727503624, 70.47442513127481, 73.86082695376489, 73.99654096172702, 86.0308119558519, 81.02338867802774, 83.17440863578551, 75.60734072039205, 63.83988895723897, 50.370752196158136, 39.90199327468872, 41.98551708652128, 44.800551168380245, 29.554774876563783, 52.51948541210544, 72.14531560097971, 77.55073393544843, 77.78871982328354, 65.56949338605328, 49.826554713710664, 21.68557659272225, 2.9621616967262763, 0.927122854177029, 1.8900310848989796, 0.179881029912541, 0.12211272973687419, 0.26364021123416964, 0.13388699551503505, 0.9514932755020358, 0.5038567019566413, 0.3588473508434911, 1.4470366364525211, 0.5324941104458225, 0.3425558782633274, 0.7867302553307626, 1.1223255506446286, 2.923330232020348, 0.18124077469110492, 0.7725472712228376, 0.7027713702090326, 0.5051329737949757, 0.542744612020831, 0.23578551477722584, 0.4536689643657977, 0.22790055481656907, 0.25077020989791043, 0.4930188560918455, 0.6857761079745909, 0.35022411195020525, 0.32218866470840674, 1.5219611386137626, 1.8174606177114674, 10.537923055310404, 38.433783438897905, 38.121864795684814, 38.35875241987167, 35.96261178293536, 41.30189503392866, 44.95927772214336, 33.33480811888172, 24.083015534185595, 30.20040289048226, 27.307548984404537, 29.957476777415124, 27.032247627935103, 47.45335209754206, 61.42372854294316, 55.874798528609745, 66.44970463168237, 66.1237007571805, 69.5716759466356, 77.06084559040686, 67.56275561548048, 68.70077640779557, 66.95608262092837, 74.32128183303341, 71.33451461791992, 73.13487468227264, 75.86917461887484, 63.102397072699766, 49.40262102311658, 44.14755498209308, 31.042508309887303, 19.398640624938473, 20.436258546767696, 24.58277060139564, 40.65678281168784, 89.89509967065628, 105.52507800440635, 123.66232164444463, 86.97332612929806, 79.89708792778754, 99.07390086881577, 44.82517580832205, 0.14934735462790535, 0.20220987288461578, 0.1620313344943908, 0.2440838404600659, 0.14422365133800816, 0.16284885756190748, 0.49802824374168153, 0.41204492531476483, 0.17204024258159822, 0.23616547906591048, 0.16827991532702602, 0.30122574118356554, 0.5228422606183637, 0.31021425079914833, 0.159990583516417, 0.21121335185823903, 0.1064938210671948, 0.1249172703753556, 0.3020616963265404, 0.21311459822520135, 0.20503949524173815, 0.15037248752290203, 0.20304906091863112, 0.10362762567256728, 0.1804447020854681, 0.2439827934628533, 0.253902482950399, 0.18033135171619155], [0.09530239498182651, 0.020409760163015416, 0.04093250680354334, 0.07868879775126135, 0.07711984202145569, 0.04589515159867945, 0.08316580025899796, 0.025770883676746202, 0.040342925537017085, 0.045133461019084345, 0.11492647260667817, 0.07615208145110838, 0.08326906125031172, 0.06959770896261738, 0.14179167457886283, 0.05734019875226002, 0.07341376911368101, 0.1244640374375928, 0.0798712238188713, 0.10603616780210888, 0.07631091446044945, 0.07351124614116646, 0.1330473325065067, 0.20866839245202082, 0.37852119353990404, 0.22694507463564798, 0.17926724026760749, 0.10688159179182784, 0.022305664981925682, 0.16922488478162598, 0.19206904445684728, 0.27280685161390616, 1.2667410916859105, 61.79107812143142, 89.95151904321487, 69.51797869897658, 75.13318107974145, 125.33838964277699, 79.7754866077054, 50.395663169122514, 25.21978901278588, 23.987207720356604, 3.424951857136142, 9.574951760230526, 8.387792494989212, 4.214000355812812, 8.286096222939031, 30.666033337193152, 55.242241813290505, 71.77048606257286, 65.44378534440072, 55.86181940570955, 50.50087682662472, 58.27761896194951, 60.073432999272505, 58.814838547860425, 62.68491175866897, 67.28188253218129, 70.80752065104824, 74.21317346634405, 79.04159545898438, 73.1721999568324, 59.169448268029, 44.203946898060465, 19.409960585255778, 18.69467519944714, 30.84465415247025, 33.34289212380686, 23.549237828100882, 42.834317991810465, 52.9850079936366, 64.96858627565446, 46.70586601380379, 23.115590387775054, 4.275622752404982, 0.5713545639188059, 0.38954970336729483, 0.35448156898060157, 0.17212581460274037, 0.1704129492563586, 0.4379334571140428, 0.15442199764713166, 0.05697752889846602, 0.11338719512305914, 0.3585524989231941, 0.7250086963176728, 0.03003047809245125, 0.07322406276099144, 0.08811477421512527, 0.4358944374947779, 1.4768303474110942, 0.20133257963724677, 0.1158481683101385, 0.14249659804326875, 0.2169136435634667, 0.04897470248021907, 0.10614334350271572, 0.0772734196676362, 0.12112024750921035, 0.09901751538798695, 0.1722316113450835, 0.10185760250615497, 0.04984359940393798, 0.04231257206429878, 0.15180899431147885, 0.8576820706648212, 2.815379740730409, 25.522374376173943, 18.90870717263991, 18.373178128273256, 29.850315663122363, 20.340858659436627, 28.121517281378473, 18.97847044852472, 10.850575181745715, 17.536032545951105, 9.161173086012564, 5.506367395001074, 8.984128082952193, 25.47417825268161, 25.688757396513417, 28.672274927939142, 44.996963854758974, 51.36049955121933, 53.0775837744436, 56.589544588519686, 49.160347984683135, 49.64906746341337, 54.06405987278108, 43.98160734484273, 35.391287188376154, 32.259702144130586, 27.46901531373301, 17.015873309104673, 13.97263769180544, 9.528215739034838, 6.075687168105957, 7.553165564613958, 15.23263340996158, 26.790243271858465, 63.726932541016616, 95.208875748419, 107.03916780410275, 57.039134502410896, 56.36787968297159, 71.25714978864117, 27.16056404575225, 0.7283014647902981, 0.13234714346547283, 0.028139342170869632, 0.08105599411552952, 0.09539783421543338, 0.02988652634103933, 0.04894692030164504, 0.15897950067395167, 0.17131864904395996, 0.032271189509981105, 0.06973688415582142, 0.17359567685954033, 0.11285720017528343, 0.14626941253100673, 0.12035665703156304, 0.05716338948977571, 0.028331120791394385, 0.06172273112761398, 0.0836342706855747, 0.05539283389225603, 0.14009834447455022, 0.07876675485843614, 0.05320933009047182, 0.10826110929971743, 0.038456686832491434, 0.06927965223909387, 0.06156635343007023, 0.0988351711402497, 0.02135964598686945, 0.0469394137091454, 0.0750168617213926, 0.01974956665728842, 0.047462992670555273, 0.019185316087978504, 0.053313418456743804, 0.030176345063673875, 0.028565963129362756, 0.04530818652241461, 0.017505260372173884, 0.05098421622308032, 0.0411963589759844, 0.12967412480183188, 0.045044912746356386, 0.09376379165558085, 0.0574432643911531, 0.0412842522435371, 0.11225517764086686, 0.04556478767265235, 0.08303775632333371, 0.05997400137505705, 0.0843127181513175, 0.12647707901534536, 0.1667943329460198, 0.26054500151545773, 0.4021814207155859, 0.39194366684363735, 0.42685349682165735, 0.1493320022259028, 0.05735663899911508, 0.17147739778362936, 0.12538303651155966, 12.300891164810428, 112.33402236815422, 107.763731556554, 89.67434867735832, 118.58540181190737, 107.61647009080457, 58.59233817746563, 40.78623671685496, 46.54653933740432, 42.96064576795025, 21.518950385432092, 18.099098590112504, 11.227907192322517, 13.56896500433645, 18.27203000745466, 30.721897694372363, 54.97809371640606, 72.45925426483154, 61.42224196464785, 57.171051656046224, 56.21163598952755, 66.57158836241692, 67.05907621691304, 68.0515064731721, 66.78575761856573, 78.44330064712032, 75.42879443014823, 80.8021983792705, 83.82810300396335, 78.84848148592057, 67.52916443732478, 65.97532533830213, 37.111811330241544, 33.19055511105445, 39.82343604487758, 30.127929256808375, 34.85484030938918, 44.84213221457697, 58.03615000940139, 71.81353015284385, 54.79449149101011, 44.99695208764846, 6.0306436496396225, 0.4977481007095307, 0.8615666880242286, 0.5701082920835865, 0.10591848137518091, 0.1106584971890815, 0.1791278582306639, 0.2701685367332351, 0.09737326853698301, 0.1848923174604293, 0.19647676197271194, 0.3653058704108961, 0.035804348712366436, 0.0017559911887679671, 0.08277549378333554, 0.7416459809868567, 1.7379425297821722, 0.7520283722589094, 0.19321653691511, 0.1488149848075644, 0.2521120128972877, 0.07440802100444995, 0.03671269533374617, 0.046585193805156216, 0.05705674238983662, 0.2192858348210012, 0.07256108261043988, 0.09263538244751193, 0.1296980727103449, 0.03616810258057329, 0.45667757550554894, 0.31652194297602104, 4.431581583715254, 35.21403135791902, 30.41881222878733, 43.65423848552089, 48.176699915239894, 36.66058578798848, 36.07155953684161, 24.814702310869773, 19.209421565455777, 23.166904795554377, 21.36768025736655, 20.407915499902543, 17.982682643398164, 31.908761801258212, 42.63106469185122, 44.200185345065215, 66.02186818276682, 74.44354211130451, 78.09602183680381, 69.47086318846672, 55.620111188580914, 52.40401083423246, 52.79469459287582, 48.129152944011075, 35.49812078475952, 30.910161656718103, 30.196347159724084, 32.97746450670304, 35.90401157256096, 26.23204488908091, 22.312763583275583, 24.675228711097475, 33.66041191162602, 50.42211171119444, 64.85173886822116, 75.52750479790473, 99.65075600531794, 88.67894526450866, 65.37384163948798, 78.22290266713789, 63.01251988257132, 2.5724509310337806, 0.08074235005844986, 0.07771681603645125, 0.08182523066117879, 0.08851671756635751, 0.08919305062942928, 0.12210634822446494, 0.09739851113408805, 0.1675801093299543, 0.047491334093314026, 0.09545729029923679, 0.14476455537782562, 0.014048079854898877, 0.18461451865732673, 0.03471091524848054, 0.06903607458356889, 0.09305768841577154, 0.050924396247512875, 0.11643224140448917, 0.03338188676524066, 0.12050080413539564, 0.005296491069584004, 0.16080804529689974, 0.04991911269063431, 0.08241115768830623, 0.0901857780052289, 0.08296197490586389, 0.05939298497152425, 0.021047133824697906, 0.20711521047257608, 0.09053539755123277, 0.1505832536326301, 0.1637381017808953, 0.14293012719961906, 0.2581444190394494, 0.1528184070822693, 0.1264605315161809, 0.12032066622088033, 0.1580803126337067, 0.16659646775693665, 0.3002677635560113, 0.2219094101700091, 0.21627667209794446, 0.2973250359777482, 0.15931103288406329, 0.1123309437365782, 0.20057314135614904, 0.16113914849777378, 0.2291323782335366, 0.2303796919483331, 0.18038234252843166, 0.3163036079176011, 0.4740250849675748, 0.5476388719774062, 0.3387131199481026, 0.3465072372026982, 0.29388358516077845, 0.24176642448911745, 0.29007337026057706, 0.18062200547466356, 0.2711273110922306, 4.3209393658945645, 117.81327539874663, 127.12759448635964, 98.68935954186225, 106.10347855475642, 140.78340468868134, 100.195126072053, 79.52573360935335, 41.81218362623646, 39.140829886159594, 36.196012420039025, 28.943045946859545, 22.17477263942842, 21.688841965890703, 19.993071902182795, 48.18280704559819, 85.61856300600114, 100.55010841738795, 77.648557847546, 66.21573525090372, 60.32894011466735, 73.83932452048026, 74.8696997857863, 75.16179869251867, 72.72491639660251, 83.96771584787678, 75.7874402692241, 83.99109317410378, 86.69030358714443, 83.39912906769784, 73.3530447559972, 62.457465279486875, 35.63494874585059, 34.60947644325995, 45.61883995609899, 50.28420117593581, 45.40602391765964, 61.496955271690126, 70.63305362578362, 81.07975313740393, 69.09887344606462, 56.10292357783164, 22.65148770424628, 4.778498065087104, 1.4538387617757245, 0.5715463923350458, 0.16742110012039063, 0.18066175011617525, 0.6883639529828103, 0.4933545251767482, 0.20009527103074137, 0.33722240477800375, 0.5762399372554595, 0.7966360173398449, 0.1660608497237967, 0.14671029613143013, 0.37728993702800045, 3.4437628090381627, 5.431065242136679, 0.4524827844673588, 0.41103678424992873, 0.3704720915805909, 0.23037656630960204, 0.20427420404889893, 0.3054149857451839, 0.1292780267014619, 0.20332088423592432, 0.26707105939426734, 0.49080302337965664, 0.17699068742654017, 0.12129139921237385, 0.20631703878602675, 0.7872379571199418, 1.5652878846853011, 5.951138677135591, 44.25285885410924, 37.12443743982623, 55.04426410121303, 65.74752584580453, 46.74519561952161, 52.04534930567588, 36.23089798035161, 29.15900576499201, 34.68475064923687, 20.321650812702796, 14.807768156451566, 20.482807274787657, 37.11702808257073, 37.64563414358324, 40.24289823347523, 54.568460987460234, 65.6834460842994, 75.67051441438737, 71.54615002293741, 61.35405155920214, 55.49089262562414, 64.03623888569494, 55.54605291735742, 53.83926883820565, 55.98258526094499, 52.76445704121744, 48.10563441245787, 42.971616637322214, 23.968643142331032, 15.784789381488679, 17.29453025325652, 29.938206172758537, 52.214415227213216, 95.83163046067762, 110.82942470427483, 120.60747777262043, 84.39332439053445, 79.9890753530687, 98.11300646874213, 53.647817950094904, 0.7463242041487849, 0.1433512916968715, 0.2575163495156073, 0.5549964416892298, 0.3316342836666492, 0.3609134286882416, 0.20631164552703982, 0.22112338863793882, 0.27215062069796747, 0.1581531063082718, 0.2977474875027134, 0.422530064299222, 0.30814431187125946, 0.32602428308417725, 0.20084583801367592, 0.12670390998884556, 0.24206231828899155, 0.15779162006032083, 0.22919794003809654, 0.2354114340437997, 0.25952858670103934, 0.12643404785663853, 0.3026248935249544, 0.3348383391576429, 0.27745112175903014, 0.15763570584597128, 0.21805995624632607, 0.2034802611676916, 0.08696217961128681], [0.03537096128228211, 0.03077944969728349, 0.060108105066202344, 0.002430126896210676, 0.08502426827626844, 0.14066144974241335, 0.05162154774992697, 0.12065905491791426, 0.07826002600092082, 0.047334278407957286, 0.06753852590918541, 0.05095575988713292, 0.04807924145772573, 0.052400276124958074, 0.06428092087228453, 0.05694960116318638, 0.1230872012374382, 0.03250922068893429, 0.07819883089752928, 0.025030553543699846, 0.20645899487839592, 0.21966711678091558, 0.15228574614851706, 0.2697360647782203, 0.13045213305421416, 0.23472354837482978, 0.04590193913768857, 0.07248990538139498, 0.1934437432716931, 0.13577238386196477, 0.13582335935244638, 0.12083952225023702, 0.4597590875721747, 5.007576740557148, 90.26936438775833, 104.68056817208569, 75.7057608327558, 83.28319165014452, 133.21319887715003, 85.1075723094325, 60.34849705234651, 34.44958494555566, 16.442970941143653, 14.267627385354812, 7.065210948067327, 13.640413918802816, 8.311404335883356, 8.562798846152521, 23.652800167760542, 31.62679437668093, 45.79775494913901, 47.74455278150497, 44.0740458426937, 56.43753705486175, 57.389853231368534, 49.8341719565853, 53.509487721227835, 50.47765639520461, 49.13958687936106, 50.49560123874296, 45.71511845434866, 52.661153577989154, 45.39976381486463, 26.261729386545, 12.463003704624793, 20.003577970689346, 21.774828164808213, 33.955123116893155, 37.05498010881486, 44.10946484534971, 29.138829092825617, 23.28263628867365, 39.56910564053444, 16.65996724559415, 3.3355122564300417, 0.7034644039888537, 0.7545742356488783, 0.32497691831761794, 0.16567198349343193, 0.4157930870930995, 0.5934103578329086, 0.19450670558839075, 0.15993392365353723, 0.1295300236632747, 0.13755514707055785, 0.15489674233380826, 0.0631948380220321, 0.049018315865748355, 0.04832044807112506, 0.18301846639763925, 1.629133529720768, 1.5180283496456763, 0.02763096047865768, 0.06715996356140222, 0.18129798613729017, 0.06045943298827737, 0.13814672016568724, 0.042760189577576616, 0.036665550282885956, 0.0850416048459949, 0.07259466790504034, 0.15820333103258766, 0.12675149937070188, 0.09315548720018518, 0.20116522006930845, 3.263294802558038, 0.3883651475752554, 21.19230520340704, 26.572559572035267, 13.181834913069203, 32.95143958060972, 33.29361538733206, 19.924328442542784, 13.360441019458156, 16.53858361705657, 5.537442862987519, 1.340543060533462, 7.138779413315558, 14.417405051569785, 16.940636365644394, 13.121185264279767, 24.147007042361846, 33.94711363700129, 38.28499617115144, 35.785842326379594, 38.11788751233009, 43.40935707092286, 38.384757734114125, 32.52133011817932, 27.511824061793668, 32.02301063845235, 19.480049417864894, 19.125216122596495, 16.19588613510132, 6.096206557366156, 6.502144413609659, 11.095332061090778, 19.0127186236843, 35.36825895309448, 68.40146033994614, 106.76850857273226, 89.96905203788512, 54.44614579600673, 61.6319985543528, 69.63072330720964, 27.34252279804599, 1.197234118177045, 0.13928204714771242, 0.12647157850404903, 0.03455700818449259, 0.11558746858950585, 0.053069044069777575, 0.11819542340573766, 0.10248657601374773, 0.1170941949972222, 0.16240032840399973, 0.0828199805090985, 0.13519939605987844, 0.13226653569408003, 0.12863077433599582, 0.13064066729237958, 0.15205103213027601, 0.20108237532117676, 0.07941848883825926, 0.044269700714897726, 0.1465893921352202, 0.07967675239929269, 0.010171323515204413, 0.025326928063746423, 0.03080090015916334, 0.08021597870655599, 0.007227920821958012, 0.04679801686096095, 0.03581067659862099, 0.03872389830048046, 0.04472214075165891, 0.08377766702324153, 0.1118278691184617, 0.031492085751867106, 0.05667665169664449, 0.07635551609940107, 0.06704084455005585, 0.046513982102154725, 0.05089454946198291, 0.09907199956116178, 0.09290127624427119, 0.03826046873244547, 0.0706368076404737, 0.061883919857322216, 0.11067336695569177, 0.005868836794228804, 0.005732464525217732, 0.02489797819796349, 0.0519652339449573, 0.07820391772134651, 0.0565455740528001, 0.024150944795579683, 0.06880077833850538, 0.06281113522427698, 0.42556040169250586, 0.44940976065493404, 0.49975086904821864, 0.21497861271904362, 0.2691945631898219, 0.5864721752943531, 0.28862016275525093, 0.14927564879819272, 0.17574956370217187, 0.39178432055538703, 21.928812573032996, 114.1577519139936, 93.21760608303933, 89.35404008434665, 123.00483826668032, 108.93566516137894, 69.30812405001733, 44.66853987786078, 44.93329201975177, 37.92613460171608, 38.05683582059799, 35.45840286439465, 28.768653446628203, 23.348063384332967, 25.13981188497236, 31.732366931053903, 34.728543912210775, 42.916256304710146, 40.727499223524525, 38.569826925954516, 52.132300407655784, 60.89407520909464, 60.41427520013625, 68.3440133064024, 64.91107648418796, 60.62536539569978, 61.75232118175876, 58.09104357996295, 64.85634765317364, 61.115559685614805, 44.004074681189756, 30.38785492220233, 38.040691344968735, 33.12016425594207, 44.34486589124126, 39.560770603918264, 53.27347086321924, 48.42699027830555, 36.07063385748094, 46.90994301149922, 28.92211617962007, 8.400822608701645, 0.32336007443166553, 0.3776593446250885, 0.2173835006091864, 0.37742430884991923, 0.38886132740205337, 0.4557189850076553, 0.15266088408327874, 0.0209187911147432, 0.28392554531174324, 0.1269631771250598, 0.20261228354948185, 0.08418552457324921, 0.05202093619793173, 0.009975511441758324, 0.07142682815150869, 1.524818217562091, 2.106887900060223, 0.1711348492291666, 0.03119040990338451, 0.26628502254043857, 0.009789694900504284, 0.07742435431047794, 0.09988511762311382, 0.2023499750442082, 0.18817937091713954, 0.09295530076469145, 0.18990069387420533, 0.1889886815221079, 0.11723006069059334, 0.5547947460605253, 5.101969559346476, 1.4129763673390112, 34.04908741674116, 30.201048120375606, 28.171821678838423, 52.70040473630352, 42.18264364427136, 38.189462923234515, 23.463647788570775, 27.099118155817834, 22.256136325097856, 13.33631452052824, 16.46204052432891, 21.2591012062565, 25.88783533342423, 31.14482137464708, 47.30476487067438, 56.70137136213241, 58.16152072721913, 50.10503515120476, 49.877737722089215, 41.21890944819297, 37.65134511455413, 33.97592344591695, 27.2508099386769, 34.356703219875214, 30.89689031724007, 31.833962202072147, 33.10811865714289, 21.131277045895978, 21.158678723919778, 27.231325564845918, 38.82352975107009, 48.14781165892079, 56.88891164718136, 85.21644946067565, 95.89492182577811, 85.04706582715436, 64.31129509402861, 76.88801811587426, 61.93047523498536, 6.249153988976633, 0.1383007191602261, 0.03644156532602445, 0.08082923208994251, 0.15583432670081818, 0.17774179067102172, 0.10281655306537306, 0.08282899736396729, 0.1298151615886919, 0.06236709917204515, 0.05109692307850046, 0.06803000961700756, 0.15126424451028148, 0.0710474077852503, 0.23430863515503947, 0.05885476606988138, 0.05271907212332853, 0.11306758324104933, 0.06167457867113333, 0.11877061754104593, 0.04982763413159598, 0.00940656379586266, 0.04639136206899439, 0.025298772417309306, 0.0713529313103326, 0.06335475887622564, 0.015125390998418293, 0.023945167833458514, 0.04020674574759699, 0.04073353078696997, 0.11573525461097879, 0.20802048125093986, 0.20673193668405856, 0.1285584862794607, 0.27408713775296367, 0.2036848066434745, 0.31364935840810504, 0.15765020022949866, 0.15928792767226696, 0.1021541628025232, 0.22307047770629007, 0.13883999909364408, 0.13176727619382644, 0.1915692333732882, 0.1475302706803045, 0.2646158395274993, 0.2373219653964043, 0.2505552303045988, 0.23537119910601648, 0.14713199689022957, 0.3115650783142736, 0.21840290316650945, 0.1454750712840788, 0.44590297785978167, 0.35919785139060795, 0.5464533355928237, 0.18362816513305713, 0.3417180845093343, 0.5464544387594347, 0.3750001002223261, 0.3560938469825253, 0.14284930492360748, 0.5535960329636451, 9.19726771693076, 133.3766205080094, 127.44861695074268, 105.49249095301475, 111.70717270143571, 151.09349589194022, 108.12798638497631, 89.27381192484211, 60.14325118833973, 36.94861327448199, 53.41617061245827, 45.291373037522845, 37.332844734191895, 29.369505643844608, 30.127501718459595, 45.073179429577245, 58.09953158901584, 75.61163179336056, 72.04361638715191, 59.24538535456504, 67.47123887462001, 68.24502052799349, 68.21792479484313, 72.80126140963647, 66.73327630566013, 59.66491422345562, 60.438841004525464, 58.101496696472175, 66.71944602843254, 55.43737972936323, 37.36239587107013, 21.204490046347342, 33.30697890250914, 39.63154192893736, 47.62344568006454, 44.171018600463874, 67.77470481011176, 56.86193358513617, 41.09848091679235, 69.36054260500016, 37.2040968556558, 24.44363432545816, 2.2163891984570414, 0.5112532195785354, 0.3565600268062084, 0.5462558687694612, 1.6781059147850161, 1.0574626634197852, 0.40312521039478244, 0.3396044172827275, 0.46505578883713294, 0.3842396108854202, 0.29665066409976254, 0.2696960443450559, 0.1268015095903989, 0.09565476478347856, 0.5040522688819516, 3.745921124373713, 2.209048237531416, 0.20467580266056523, 0.2984696326236571, 0.38587640370092086, 0.10697045033016514, 0.260114552032563, 0.1313909431619029, 0.1979385343410315, 0.3382621393088372, 0.18310874219863646, 0.29330384046319996, 0.5321080021319852, 0.23947985121800056, 1.3537293336083813, 7.288026578964726, 1.7469755031408805, 40.138720081698516, 49.57111820097893, 30.363934347706458, 62.49266855178341, 58.470862373229004, 43.33140780848842, 31.982696517821285, 42.54323105658255, 18.832283712202504, 8.206030841796629, 22.206779180034516, 30.719516815677768, 39.21956362262849, 34.73278007199688, 47.91963169651647, 47.3213251175419, 54.298154769405244, 47.385702979180124, 53.18603730970814, 50.46452037749752, 50.30183222986037, 47.350617377988755, 44.20661018740746, 51.6879350908341, 39.97093677520752, 38.33783834211288, 28.58459818747736, 13.214196428175896, 13.069912041387251, 21.55097261551888, 39.26838144179314, 58.97239231294202, 88.7526858237482, 118.75828419962238, 109.25380860605549, 82.87842658258255, 86.31472879840483, 91.36225438887074, 51.8471872422003, 2.703929759802357, 0.43353025951693136, 0.18628642894327643, 0.19035000444179584, 0.43974130204127687, 0.2573620287641402, 0.4578940618422724, 0.16935818408045078, 0.22249025803419853, 0.1926423693376203, 0.16165509339301817, 0.20991388287755752, 0.40161607847098385, 0.17259334274117025, 0.3366772566110857, 0.21589871495962146, 0.22574567205963597, 0.19336031629673897, 0.13138164285450213, 0.20718017472855507, 0.15151374402546114, 0.1270066526147627, 0.08540140570051248, 0.08429604041720591, 0.19828583264062483, 0.12422605222391507, 0.08901787696466332, 0.31815291352329717, 0.17628957907999718, 0.09219109741670471], [0.04973549290650314, 0.039433632797050866, 0.06875691214396108, 0.02291544224135578, 0.06523807112488055, 0.03717239788402954, 0.02558104900432931, 0.02197143997276022, 0.035391565217005636, 0.05132367744320824, 0.062124433161150065, 0.06434727174740645, 0.05338830355134222, 0.1172699815323276, 0.027768724154861226, 0.10747226090320658, 0.0366776927764858, 0.030355990766697837, 0.04515889513817045, 0.08356540704206114, 0.06619619430914041, 0.02349730708726472, 0.223893593215654, 0.10925464872871676, 0.06403306844614207, 0.03780116071744311, 0.08812251936403975, 0.035035104505837925, 0.2346012041333222, 0.09641473932612328, 0.24507240031755742, 0.2015237798613887, 0.21263709562199734, 0.4619484749292174, 8.401437440226156, 100.37024421076622, 101.1790055613364, 61.467129568899836, 71.07636774739912, 119.16890144348146, 102.52259777438258, 73.21082745828937, 41.233598724488296, 15.629190917937988, 14.200046908470894, 4.081542650538107, 7.468915014497696, 6.3960599899292, 13.113816111318528, 19.542591610262473, 20.23589603362545, 27.42888358331496, 45.18761850172474, 57.16514456656672, 43.888655016499186, 40.581234039798865, 37.36855006987049, 27.563866069239957, 37.901258930083245, 41.76218125127977, 36.52140440479402, 39.71613176407353, 32.22783680885069, 23.391795850569203, 20.737908424869662, 14.578841963121969, 18.800286977521836, 24.6061538111779, 27.009782252773164, 33.04025773079165, 46.14720675253099, 45.83981452449676, 29.094920119931622, 24.357863856900124, 13.435542641147492, 1.5289435703908245, 0.9754191819698581, 0.06383961975394238, 0.24869164481999415, 1.3733989168559353, 0.09671593445443338, 0.3154713606401798, 0.3357019960399597, 0.23588198056865126, 0.13984423311006638, 0.09358261952236777, 0.10744121902051473, 0.09532409059184213, 0.04818711046790404, 0.09004558391508558, 0.8324673591602234, 2.6745328211015273, 0.08877714915621666, 0.055748946033418185, 0.05659054341395536, 0.09392982589141016, 0.0706273770981258, 0.10393987544962477, 0.06860079108587197, 0.045854698325837814, 0.05441890248367864, 0.15676238093405, 0.1487812003301036, 0.09997542406762801, 0.20870910236431708, 1.8866260998672055, 0.6487185351790921, 8.293062352365064, 30.307893483869492, 35.56044332442745, 25.861045545147313, 33.78286046366538, 30.463597851414836, 18.280255217706006, 3.7923421302149376, 2.3070788095074315, 11.798324738779376, 9.70270041496523, 6.935699678236439, 13.201887049982625, 14.927233745974881, 20.021805224880097, 29.810344749881377, 30.89201677230097, 21.03105264325296, 27.88051312969577, 33.5942336820787, 31.534153876766084, 20.48674141207049, 15.726676525608188, 12.426458001136782, 9.485345213643967, 9.479326336614548, 6.937898166718022, 10.506747076588294, 16.97703988321366, 33.27048517042591, 61.61703863451558, 96.45050202646564, 111.29471194359564, 75.74194077522525, 40.2357752092423, 58.59544077227193, 66.64581529555782, 28.257068510978456, 0.718997112445293, 0.07434767625865436, 0.10858898727043022, 0.054295010744564, 0.11102729191583012, 0.03309260430415312, 0.3359233035195259, 0.2954450255680469, 0.10892086422010776, 0.13713151577018923, 0.11535853087421387, 0.0795207615761507, 0.04436748034711327, 0.12027286233440523, 0.15588851976058177, 0.10243219143200306, 0.05788478001411404, 0.10738629051634382, 0.06788786200265731, 0.03242789279489267, 0.15603449015367418, 0.05771694930210229, 0.0428339944882018, 0.020746501771012144, 0.01752578961332479, 0.04078124274289416, 0.034364992076711315, 0.015042537631797455, 0.040665709023033424, 0.061206483627639474, 0.033279004987449415, 0.03631310387244148, 0.03391997543193641, 0.039365297754205046, 0.035870940905184515, 0.04439624694867, 0.039320152192827196, 0.027443282343747637, 0.015432729194271229, 0.08551685515070155, 0.05697216628299606, 0.04865077369275594, 0.058920484922465786, 0.051730891479359525, 0.06231225493754591, 0.02793433704233218, 0.03780021842929625, 0.04407304594473493, 0.09239840846989425, 0.09400643468383821, 0.03424624844844784, 0.035765768524499676, 0.023680352305452672, 0.17073577870765042, 0.11375316298536717, 0.23279040210670043, 0.3605696697148585, 0.5079564674487037, 0.22051870011754576, 0.32364132063042733, 0.19564258415372143, 0.17804741378753416, 0.05112108166119264, 0.4921987130036278, 1.1556373824996333, 36.82776504947294, 121.45695332557925, 96.36464134339364, 88.87761331373646, 115.46813734116094, 109.15651029156102, 81.89674362059563, 56.71954762551093, 41.45997831898351, 41.57181685970676, 35.22442956124583, 28.379377818876698, 29.00788860936319, 26.60333448840726, 30.62187529379322, 37.65573032440678, 31.369679089515444, 35.12009451466222, 40.75605407837899, 50.74023162164996, 39.788170014658284, 40.274410555439616, 38.89913735851165, 34.72244070422265, 52.28620636847712, 61.83840936230075, 52.05308814202586, 48.772621693149695, 41.78843759721325, 31.63168949465598, 35.75531451932846, 33.96235204512073, 38.360945024798, 46.95725071814753, 46.01960812845538, 49.30203184004753, 49.28580107227449, 42.46193601239113, 39.57385955318328, 29.44840019749057, 22.31604268473964, 2.1827940979311546, 0.20846810642509692, 0.09385734631289398, 0.08029431119681367, 0.12205628437861321, 0.2411370372940456, 0.33241167904869207, 0.2015578401305022, 0.4636214883817781, 0.1461943665579442, 0.2118329637713971, 0.008526831516064703, 0.13199956937422677, 0.07195111574424852, 0.07144294664143555, 0.5742364641158813, 2.781599553362016, 0.18565079047074243, 0.04685952606040144, 0.01391145094643317, 0.12644078176949294, 0.030988940270617608, 0.05942118466801702, 0.07543286278603539, 0.04724933457891307, 0.033562518806467136, 0.22617469661899153, 0.10620799366264574, 0.03866684390231967, 0.11614970051713529, 4.14721513948133, 0.9338264299496528, 14.802048360147785, 39.845397395472375, 26.228969750865815, 29.6454639973179, 37.742536298690304, 31.776756394294004, 28.12411585161763, 20.080834934788367, 11.276242559955968, 16.238395802436337, 15.022860150183401, 19.10580039024353, 27.326456769820187, 27.312144041061405, 31.209968020839078, 39.71715158031833, 40.63515486255769, 24.12890530401661, 20.233199404131984, 21.361312289391797, 28.748339491505778, 29.48522733103845, 32.29667636655992, 29.769238310475505, 25.019426499643636, 28.42965868211562, 25.16520727065302, 31.734402641173336, 34.60968040650891, 39.45413704841368, 51.27328172806771, 73.44156480604603, 95.73036270756876, 99.80590927985408, 69.81709080357706, 59.46965471390755, 77.761027889867, 59.163266612637436, 7.088837835096545, 0.05539027898902855, 0.028545363025078853, 0.006868537006554224, 0.005926604132964126, 0.034950367520533265, 0.1346173377767686, 0.2689608450858824, 0.10809608629994816, 0.07714802639618998, 0.10889001385939699, 0.01800537023002342, 0.025502343046208544, 0.12839316450540098, 0.14068573472961304, 0.0981883631057797, 0.05063195367373767, 0.07010521156893623, 0.11445600269061905, 0.0171902890677654, 0.07188049009850911, 0.0532128885688801, 0.03441688304226245, 0.04430147421155726, 0.04129401220369243, 0.05895020147304862, 0.04876298642146492, 0.026999501015750632, 0.018042100315553047, 0.01245500193157744, 0.06475856903219415, 0.18236234273401, 0.18565373224837167, 0.1393427519548324, 0.15017626176197685, 0.14148591356652399, 0.21076577264935742, 0.13432766461083967, 0.061315390686955185, 0.11563672804303708, 0.23770531579371423, 0.16328946537067815, 0.1703426989937021, 0.14913994398328567, 0.18445564734358944, 0.24360095991963343, 0.2692405284652787, 0.21942078886974245, 0.20728319823261232, 0.22800468148723727, 0.2884165978720111, 0.17907470705047732, 0.14240846728845952, 0.31020557868384546, 0.241271807481685, 0.29838055191982177, 0.30848899015015174, 0.6078213297070996, 0.39031021417148654, 0.6444321813121919, 0.2491611034999932, 0.2911755562789979, 0.1590101135474059, 0.6144896654352066, 0.5774024910023136, 16.411403705996854, 138.3199679466986, 123.95488339085733, 91.55695299948417, 97.12941723485147, 136.7623947512719, 121.56554022142966, 105.34770058047388, 76.83663506661692, 39.083069063002064, 32.831691580434004, 29.66725080244003, 25.710769737920455, 28.39870922027096, 31.586990164172267, 43.49261330020043, 48.54585770637759, 58.245031910557906, 75.33863482936736, 81.48018006355532, 61.66806474808724, 55.793432881755216, 54.21307071562737, 45.3716992562817, 58.51014098813457, 60.58935803751792, 44.26152729219006, 42.26812385743664, 34.57826614379883, 27.19676163888747, 33.18043539600988, 23.21485773209603, 27.886024059787875, 45.215624224755075, 50.206608849187056, 51.74169117404569, 57.65005150148946, 56.52619831023678, 41.03258509789744, 48.94146403958721, 45.64111509630757, 4.722479264582358, 1.0333489121929293, 0.1866224810721413, 0.23025930889191168, 4.608768772694373, 3.080265243207255, 0.6479057465349475, 1.1831025538905975, 0.8346573900311225, 0.22379410903780694, 0.2968594690244044, 0.3000038309443382, 0.3327410968561327, 0.41448929737652507, 0.4064216867329613, 1.965057813832837, 5.084759179622897, 0.3277065508788632, 0.10590359628681215, 0.12101040582262701, 0.3398907196617896, 0.1752356106355306, 0.33648006557937593, 0.21977236193995323, 0.18086572868689416, 0.14629276289093882, 0.5486919670816391, 0.3678939912107683, 0.22560714804116758, 0.38387452402422506, 4.916825352176543, 2.0572010307542743, 13.335595746194164, 60.2351091754052, 62.80444991204047, 48.262862620815156, 55.487213442402506, 53.679655828783595, 39.28347472221621, 13.268140785155758, 5.706330806978288, 23.939154763375562, 25.321951066294027, 28.941812361440352, 37.72116330362136, 40.14089307477398, 41.7031652696671, 45.977081791047134, 46.862337204717825, 34.46262682637861, 37.05448196780297, 42.78266037664106, 48.3955995498165, 39.866644874695815, 36.474151611328125, 30.60591320837698, 22.629785230082852, 22.181083733035674, 19.79518440461928, 26.989791893189956, 37.933485123419, 49.99428702938942, 74.84312180549868, 109.68392002967097, 125.71210522805492, 102.40429908998551, 69.09216619306996, 82.27129859309044, 93.16168092912244, 54.09201852736935, 3.400478473594112, 0.17540816427959552, 0.19132437635092966, 0.2545634789332267, 0.18680606638231587, 0.22615117771971613, 0.38908217522886496, 0.39138534196442176, 0.2147736841992986, 0.3005159453999612, 0.18715223087178123, 0.0978250842120859, 0.1369600193274598, 0.33189429390815, 0.24760629741414902, 0.17519695383887138, 0.14269044893162866, 0.12299619765291292, 0.23231728152642328, 0.14820484174115045, 0.1991291269059143, 0.12829947961314073, 0.09424559201204008, 0.10608558813410421, 0.18244575438720567, 0.13710206735037989, 0.1907556020324269, 0.16331906700807233, 0.13124898706953372, 0.1934378137511592, 0.1618397052610113], [0.019875082502802534, 0.07456835554612261, 0.01861507088066109, 0.11788893460987077, 0.05446722730994225, 0.05461343519029118, 0.03627715519659462, 0.007374515576708702, 0.03167985581732806, 0.010624738398849243, 0.06925211137821598, 0.0034522588811664577, 0.06100926961329195, 0.05669815195423942, 0.05688826816396848, 0.13312378808134986, 0.06727497634147445, 0.055257630864939386, 0.02954589300638726, 0.04305213419420104, 0.11268275429404552, 0.1853044727636922, 0.12237031147965502, 0.15894950067083682, 0.032138824838423924, 0.08523402314993643, 0.1544304552578157, 0.1917076348176887, 0.25079251837826544, 0.4666747164822394, 0.24050817103876224, 0.1698110952612854, 0.008455768242598543, 0.18052342528056714, 0.4818921644360789, 9.52098386902963, 110.32614538746496, 106.53153465640162, 69.2759370803833, 80.5018154267342, 114.34988529451432, 112.13866479935186, 82.88401988244827, 47.92923758106847, 16.16373250561376, 16.78170584863232, 9.093566133129983, 6.546457390631399, 4.735751094356661, 8.144806075480677, 10.257596162057693, 13.396532708598723, 20.54669091778417, 31.188075311722297, 39.12546596219463, 44.20757509046986, 43.543894367833296, 40.532263248197495, 30.875238833888886, 29.530934710656446, 25.58926843827771, 25.579272277893562, 26.643807465030303, 26.122722548823205, 28.7820993315789, 24.574470866111017, 10.335764096629235, 8.130803213965509, 15.266963954894775, 24.112366630185036, 29.080948637377833, 34.435680143294796, 37.01408155502812, 48.837552608982215, 12.044305397618203, 1.837263438970812, 0.055539451629644444, 0.23174597911777037, 0.24233913649955105, 0.3988896941225375, 0.7912213078910305, 0.04007005650970725, 0.09120377096077127, 0.06352438989485945, 0.09610003040682885, 0.08293640289095142, 0.18993389612484365, 0.06305892253294587, 0.13263117822427906, 0.09067807376625077, 0.656404787253949, 1.7155696980414854, 0.16667917460924195, 0.0415565773484207, 0.009802694454969419, 0.03351947232600182, 0.07916051639063705, 0.036830075325504426, 0.0567092985335377, 0.0670324941916812, 0.01298813975506252, 0.15121872356582075, 0.04322388344594548, 0.27181875140916917, 0.18445622957041188, 0.7819601629049547, 0.515148347664264, 3.8115313456904505, 11.678256084842067, 21.44410175661887, 42.223601033610684, 39.4729212791689, 18.394560929267637, 4.108711682981061, 9.564174067589546, 16.424139641946365, 11.49014215315542, 5.811990143791323, 12.659678209212519, 13.575334933496292, 6.473359609803846, 15.50866432728306, 22.782549781184045, 19.122066459348126, 29.253758461244647, 34.55991337376256, 22.237842390614173, 18.780651592439224, 13.524404917993854, 10.175882404850377, 5.899072154875725, 6.619049676002995, 7.32336615362475, 22.437404740241266, 29.897358609784035, 52.560176080273045, 89.09028422447943, 104.39436066535212, 104.68653801948794, 68.48936850024809, 46.93153565929782, 59.00737593250891, 60.143141361974905, 25.026400473810014, 1.055776289393825, 0.25854492980626326, 0.15353008744216737, 0.1125551623502566, 0.1121473354437659, 0.11618332411613196, 0.07676945638752754, 0.07852605769350644, 0.24665642499683366, 0.12351985705355484, 0.1013907561859777, 0.07203916222938607, 0.03635832604261176, 0.08698683232069017, 0.11960009158018137, 0.06730689922527922, 0.13591467703302063, 0.11810600562321565, 0.09318342642678369, 0.03497883151735991, 0.08586588480900373, 0.07284127160786621, 0.09383638614728566, 0.04395034547234255, 0.06219145436320574, 0.04180889989760134, 0.013128840420845778, 0.09216530323629418, 0.022727869443535324, 0.014934410066944698, 0.04202320533353956, 0.025694694317456697, 0.0672182168871645, 0.10714447486304468, 0.004459006144785353, 0.023255864901828672, 0.017094028204859748, 0.013427453832851063, 0.05795640157415502, 0.07045731323981477, 0.024568717438547362, 0.027515855768034538, 0.020682830288405382, 0.10017014063534238, 0.015094181533993013, 0.05793070315473503, 0.08622167136279807, 0.20465511828660968, 0.1070822838453516, 0.05104797006013894, 0.006868009363496377, 0.02931514732359398, 0.05013342578745177, 0.12354749750586287, 0.11881701182574035, 0.2421703213645566, 0.222972602313084, 0.1691017744521941, 0.3191711363052169, 0.35598729947401636, 0.17845521771138717, 0.21176496580723794, 0.11747848002179978, 0.16139827007728239, 0.10488464572136441, 0.24791369785464581, 1.5975031689290078, 36.540863283218876, 122.27611680184643, 94.38823746096705, 84.90726470947266, 114.7041694579586, 113.24652256504183, 91.66652048787763, 71.37170653189384, 52.089158258130475, 37.10626117644772, 34.38507764570175, 23.962965511506606, 25.949649926154848, 22.591936319105088, 28.89653055898605, 32.425479158278435, 34.72603359530049, 42.30661799830776, 52.10487127304078, 46.32776521867322, 41.5912639710211, 35.56071789033952, 32.43410248910227, 28.891092192742136, 30.25823823867306, 31.191980031228837, 34.42356394183251, 37.75968490108367, 35.13936511931881, 40.06821155548096, 35.25146253647343, 25.240799188613895, 24.845973407068563, 39.21214249826247, 40.75028034948534, 41.97913539025092, 46.26062208606351, 35.750682200154955, 54.541737879476244, 29.646462240526755, 2.9099804451388698, 0.08254493196164409, 0.1971084167880397, 0.08237224042175278, 0.6634008247525461, 0.5060225244491331, 0.009880600808819216, 0.18730681209314257, 0.06872056893283321, 0.0076955954747034185, 0.07425216807713432, 0.0669879308571258, 0.06219343470049001, 0.32733913511037827, 0.031011114685585907, 1.2803714506087767, 2.0155270734140953, 0.1630280302056382, 0.07391042391499204, 0.07909445662892635, 0.02183601669516535, 0.1313043599047007, 0.026551824130658663, 0.04032283105076321, 0.07357522214372313, 0.04633216262464562, 0.051649172880476525, 0.125621420090958, 0.1257172576902855, 0.1458487996170598, 0.9968642505907244, 0.6932490198842941, 6.285961020377375, 25.786087089969268, 45.71790725954118, 49.9443317228748, 46.973979626932454, 38.450273083102324, 27.250239233816824, 17.525465680706887, 14.237272162591259, 11.626911278693907, 11.65682621540562, 15.2780613207048, 20.151780805280133, 24.036541331198908, 27.412305685781664, 24.42531881793853, 14.264196292046579, 13.643913653589065, 20.76755173744694, 25.453911366001254, 33.99027147600728, 32.47875671232901, 27.21380433728618, 19.889597815852014, 20.969865629749915, 25.525451475574126, 42.03007913404896, 42.65621885176628, 44.61002988200034, 68.44685785232052, 92.28751013355871, 109.5918070885443, 96.77553315316477, 63.79120057629001, 57.40956706385459, 75.46855157421481, 49.28511465749433, 6.855346493182644, 0.1057698066917158, 0.020548674886325197, 0.10126046761269532, 0.07503717071226529, 0.06331461586899335, 0.2302986858112197, 0.18998638846941535, 0.18726895202792462, 0.0886392226863292, 0.0619694842175851, 0.10100730619723759, 0.01849153728765105, 0.017704759243755572, 0.18526573935824056, 0.17100014032856112, 0.09915804655681695, 0.08054227087526553, 0.06413098214374435, 0.09320635543835741, 0.04176814018959, 0.06474688619134888, 0.09597298238546619, 0.028873302282825596, 0.04684362207509337, 0.09358394485447677, 0.024998433392254577, 0.04866260592074645, 0.0556751219705949, 0.0481601326816505, 0.014181524710429293, 0.04762125494439275, 0.2711884449085882, 0.1460464043362487, 0.1506586366843793, 0.11862901384912192, 0.14731985697102162, 0.09233601826934085, 0.12553106768116837, 0.3180831382351537, 0.18575724604870045, 0.10036151705970688, 0.20971082361234775, 0.1737189097630401, 0.14143044880080607, 0.25061339169981023, 0.14680955048289993, 0.2392201167681525, 0.24626368236157203, 0.19575149121303714, 0.13255453878833404, 0.09920465534613018, 0.1480228192503414, 0.282496913907028, 0.1857129048796431, 0.30868210559410436, 0.1889612249309017, 0.3473257255409995, 0.5537276162255196, 0.5871728699534171, 0.2763693136793952, 0.4176466215041376, 0.3118274481065812, 0.30289550642332724, 0.2812960557639599, 0.332231770960554, 0.4519577384475739, 14.927258260788458, 142.34224873204386, 128.82693782929454, 95.6364768551242, 108.06810748192572, 132.33631380142705, 127.80205388222973, 108.93775970705094, 79.98014803855651, 49.49891128847676, 31.49456931698707, 16.05185866355896, 15.426893695708245, 17.18163267258675, 25.47729849815369, 28.746939205354263, 33.17554027803483, 48.091125565190474, 64.62179776160949, 67.456420160109, 68.42983476577267, 59.503732265964636, 54.794307139612016, 43.85356941530782, 39.81717201971239, 42.39224726153959, 39.0319017441042, 40.04966266693608, 34.47246805314095, 31.91137606097806, 25.989720859835227, 13.483789755452065, 11.623504700199252, 24.294674473424113, 42.037151167469645, 43.564043583408484, 45.67076429244011, 50.28041608871953, 73.1012442804152, 32.0349895569586, 5.5314749767703395, 0.13784866599786666, 0.3955380288102935, 0.26384111013143297, 1.1968513193630403, 1.7801594902430813, 1.137155541969884, 0.3440113227453924, 0.14822178760603552, 0.16019952633688528, 0.22172475233674052, 0.286448088985297, 0.22387062589968407, 0.6175815962976026, 0.3803489261096524, 1.9032443242688335, 5.59509385978022, 0.21111828034683583, 0.16502618669502198, 0.25311555743457814, 0.13411260840873565, 0.22335065138195792, 0.24629378961699627, 0.19861937200109805, 0.1830598351455504, 0.12012568152239246, 0.15136777363236875, 0.26001781044948485, 0.36882849590432265, 0.7290196262540356, 3.5754514846109577, 0.9442922328749012, 7.459675871556805, 22.393293765283403, 44.87898288234588, 72.20581423851752, 62.80575213893768, 39.95936578319919, 23.462433815002445, 24.21225174780815, 33.786308227046845, 24.528669349608887, 16.925921593942952, 34.2364158938008, 34.276992813233406, 33.73101457472771, 40.34795499617054, 40.858749574230565, 37.581275893795876, 43.037634049692464, 44.95188013199837, 35.42740829529301, 34.438284597089215, 25.63646043500593, 21.203266266853582, 12.310311717371787, 14.394110095116401, 21.128741233579575, 38.911947819494436, 51.42661502284389, 66.81718364838632, 97.88854491326117, 121.48066013090073, 121.48681040733092, 96.50707829383113, 73.96993160247803, 82.4217136444584, 89.96691826851138, 45.35309937692458, 3.3480336877607533, 0.36852684112325795, 0.21084356121718886, 0.3733225821727707, 0.2769322350861565, 0.2505374877082725, 0.527393680907065, 0.42240071801408646, 0.17646030943480231, 0.17420943586095688, 0.21579141668494672, 0.24321534190206762, 0.14116038748573873, 0.09714166483571453, 0.280796627724363, 0.17670927268843498, 0.2586187193951299, 0.2622654204887729, 0.17025024750299994, 0.22202502815954148, 0.182943680894471, 0.20196159911011496, 0.12461332499139732, 0.14201888093544593, 0.13914965183263825, 0.23394114277776212, 0.09861762515239178, 0.16126392889888058, 0.14888238522314257, 0.14893870800733566, 0.16271154396235943, 0.08409826715867366], [0.0758822116580221, 0.0325543049632782, 0.07350818945034858, 0.03136542652012601, 0.01015051560957105, 0.013716736293938613, 0.04526670669175444, 0.07251333235011947, 0.027039529109794288, 0.0745481844510763, 0.08665433483979396, 0.035354563170262886, 0.07689664996559582, 0.10106545993156972, 0.07058071468265788, 0.09554711410835867, 0.18664526452700939, 0.04675236951199271, 0.17411430306251974, 0.10573580770963624, 0.32494210728233863, 0.34248009684585756, 0.2551844391611315, 0.21400450127980403, 0.3663753291531917, 0.12071211416754993, 0.23144688307037278, 0.42377572326410207, 0.30687000121801133, 0.3267270002153612, 0.3576793425506161, 0.20432583837499543, 0.2003323752433062, 0.10436704607620355, 0.15257771757821884, 0.2648981276058382, 6.214265486886425, 84.15870389630719, 113.75062557958789, 85.11180062447825, 72.39031468668293, 91.7822382527013, 123.61833618533228, 113.88056585865637, 70.326198762463, 42.94035142467868, 28.010235717219693, 13.785551421103941, 7.221103589380942, 8.163841828223198, 6.572406811098899, 4.1537238224860165, 6.842651251823672, 13.244826216851513, 20.902087073172293, 29.34245501795123, 37.54553917915591, 32.97688007354736, 36.12301711113223, 36.267913387667754, 39.7057649397081, 40.99150611508278, 40.35727062532979, 33.54389006091703, 27.52600342996659, 25.142332007808072, 21.89124215033747, 16.15789209642718, 6.5156476632241285, 9.186081117199315, 30.562167013845137, 37.775962737298784, 42.684079447100245, 20.631614154384984, 10.71496609718569, 2.1548513779717107, 0.4532682084508481, 0.27415213265245963, 0.5126577651789112, 0.28394567810239335, 0.7357956433007795, 0.10312168588561398, 0.15433498538069187, 0.162288265062436, 0.05738004298520185, 0.09372016294829308, 0.10406157617727596, 0.29284792621770217, 0.3256435373858098, 0.028870588416353832, 0.24186621510213424, 0.9090082455546626, 0.06384171117397566, 0.059107571254454316, 0.06396641496629005, 0.13150286860764027, 0.14605763518521864, 0.013523273237590349, 0.17702134626526989, 0.08927211856409427, 0.06497169469272898, 0.02928483130921039, 0.0791337339568042, 0.3235226689327148, 0.4881591007353798, 0.7499049603939058, 1.5689298053902965, 4.845385263043066, 22.288082068966283, 19.766356945037842, 27.1112794645371, 27.24124327782662, 24.58266861977116, 33.157171818517874, 15.45098195152898, 11.436295855429865, 8.651877833950905, 6.581304707834798, 11.160899381483755, 13.025294100084613, 19.33670836110269, 30.747481353821296, 36.36331719736899, 34.33068221615207, 36.161154316317656, 27.25402432103311, 19.290085108049457, 10.61593311448251, 5.2780947666014395, 10.082945765987521, 15.804922907583176, 21.491132936170025, 37.57367041803176, 52.48808683887605, 77.7139594477992, 92.3104638438071, 90.58147522710985, 72.31255762038693, 48.13716634627312, 54.23782871615503, 70.57661856374433, 59.01005883370677, 17.98875839479508, 0.32849035075595306, 0.06907596478178617, 0.10767870627704168, 0.1344618832151736, 0.04298252744540092, 0.07390833249495876, 0.02807976159777853, 0.046811997965579076, 0.1309074650728895, 0.14013651097493787, 0.10729706425580288, 0.013710860399559382, 0.059662613446914384, 0.07868269203050483, 0.06057930276578954, 0.13424590770756045, 0.04168212766789141, 0.0884958110269039, 0.10539275353714343, 0.030870118118341894, 0.057601603273783004, 0.05024042911827565, 0.048826950932702715, 0.018678767261125388, 0.02940427207748496, 0.034456800053557085, 0.04824596517268689, 0.019993414358806708, 0.05845318277997356, 0.03853544833198671, 0.04385466492103954, 0.02607134144542919, 0.06704734863653299, 0.05044809257191035, 0.08624561927131108, 0.07487177232941312, 0.025799146575492718, 0.009272500324333388, 0.030422339726599957, 0.11799968028020476, 0.04125943099479041, 0.039360390961050026, 0.025568012103077867, 0.0731531460018408, 0.06619861514698114, 0.06636373007730131, 0.037017981371571945, 0.06002674652864376, 0.08714318320515656, 0.17986193900146794, 0.04425087027371891, 0.07559589395720152, 0.053736444547652244, 0.08068817232044474, 0.16760908277525058, 0.35445319308388623, 0.35385000609582473, 0.22496944113123804, 0.2956448825857332, 0.0483253778469178, 0.1671406966183455, 0.11876675645790755, 0.06591762941811355, 0.2121331783071641, 0.15871291739806054, 0.031036399417526783, 0.10888179373596946, 0.2024134224460971, 0.9972354048682798, 35.76630500055129, 111.57434555792041, 106.42101795442643, 91.94620901538481, 101.85510450793852, 111.29940309832173, 100.04218501429405, 82.22080984423238, 62.756087087815814, 46.17561255731891, 44.085228520054976, 27.902723550796512, 25.230471587950184, 23.64005638707069, 25.75033860821878, 28.273740545395885, 30.431065713205648, 38.090948673986624, 45.744493084569136, 53.26443372234222, 51.99465267119869, 38.49499594780707, 30.367770425734985, 21.61225964946132, 23.2401805539285, 23.4896432968878, 26.584256079889116, 33.19811744074668, 38.18600339274253, 33.75531758031538, 25.68804548632714, 23.36358420310482, 20.232330599138816, 28.703098873938288, 50.33126177326326, 52.041109223519605, 60.65093532685311, 43.840201977760564, 17.5127120940916, 2.17682768260279, 0.3947596834792245, 0.34309103664371277, 0.12462981886440709, 0.5126010746725145, 1.1971708699580164, 0.17719913995073688, 0.14728127678315486, 0.16039331593821127, 0.08108247011419266, 0.06159450333084791, 0.06476084431332928, 0.10269509748585763, 0.08597853037738994, 0.05664988841500975, 0.7448194848914301, 1.2989361512084163, 0.03409075175201701, 0.04024877333112302, 0.036569942509935754, 0.0745539837366631, 0.12672172153308509, 0.10313052654026017, 0.030110319775919762, 0.14472612840754373, 0.08250894115096138, 0.057676668399043625, 0.08969584945589305, 0.20327635920576512, 0.48053640331472125, 1.2660002540196142, 0.6335407399362134, 4.365866684144543, 14.554046700077674, 31.075728824061734, 43.14411463276033, 48.97379221454744, 40.47807570426695, 29.754649054619577, 20.61820749313601, 12.258965930631085, 10.386746083536456, 4.520586536776635, 13.966524677891886, 22.971237359508393, 19.21843909448193, 24.1559676970205, 26.79183183177825, 32.50767830879458, 43.18710773221908, 37.40635779596145, 36.87752031510876, 29.096644001622355, 22.830067334636567, 27.43780109190172, 28.980416328676288, 32.54365821038523, 42.11221356545725, 45.54672325811079, 59.95121194470314, 84.52692031860352, 102.07596532760128, 97.13900350755262, 75.64886293103619, 69.68853904354957, 77.15654357787102, 77.42471602655228, 37.33546879983718, 2.2753078562598077, 0.07842232938855886, 0.190383896171566, 0.17020742318803267, 0.06539340311240766, 0.08181891043580349, 0.12096950438834968, 0.08996861506133311, 0.08931360222519406, 0.08621737360954286, 0.11339651841309764, 0.09562019123545579, 0.019908842082405766, 0.05754389004000733, 0.10433169877937726, 0.09747305914999978, 0.13051846094669836, 0.18011657130574027, 0.06102611588674688, 0.0330833308098297, 0.04247582923140257, 0.0580666990830533, 0.05563752620571083, 0.023307642869410977, 0.04514219825186076, 0.0230538992271308, 0.03576741561353688, 0.02749524034199215, 0.07587254362841768, 0.05975596126048796, 0.06827544886618853, 0.05147965294459174, 0.03884566797604484, 0.14286680237179802, 0.10351701789805967, 0.1505279880497725, 0.10364124671586099, 0.1173212941014959, 0.09271870983103592, 0.15480997521550427, 0.14786191014272554, 0.15706834112924917, 0.14411166460523683, 0.1612404712866391, 0.12337139687470852, 0.19223163895789655, 0.18504245537182978, 0.19744966299303118, 0.20886477143053087, 0.30626531269761825, 0.18101428845717063, 0.4024501030723895, 0.16122351009999553, 0.3288569085059628, 0.4383159188493606, 0.5265621997175679, 0.5374160108547057, 0.510380553502229, 0.6692376792911561, 0.5770369751318809, 0.6258900343410431, 0.3976334018572685, 0.38201574957178486, 0.41823847039091977, 0.2601463906466961, 0.2683876274574188, 0.3270035273125095, 0.2979754752689793, 0.34408710416286226, 13.36964289988241, 116.39536211567541, 140.51913107595138, 114.67732475649927, 102.28590626870434, 119.54846136031614, 137.50888455298642, 130.4689988782329, 91.3222069894114, 76.95633795953567, 60.33624356792819, 28.819122583635394, 22.261598225562803, 14.80272496900251, 15.605176206557983, 18.662041079613473, 19.525107645219375, 29.887227127628943, 44.82576808621807, 59.972243693567094, 62.68913222897438, 47.1018998853622, 47.672396859815045, 43.82071956511467, 41.01505602559736, 40.958781780735144, 42.435095233301965, 43.94370548186764, 39.70069723744547, 30.334657776740293, 26.401665825997632, 28.55252104420816, 12.238602945881507, 16.435853800465985, 50.39213303596743, 54.69753834509081, 61.090844831159046, 30.3901828488996, 19.495221145691414, 4.269840688474717, 0.6550513243963642, 0.5921525027482741, 1.4307237440539946, 1.055751774580248, 2.4462092018896535, 0.23544578542632444, 0.45723056841281157, 0.3558237856674579, 0.14347378915596393, 0.19767889182173437, 0.15473313659669893, 0.5334004231037632, 0.9764165058732034, 0.18333363496968824, 1.042488647564765, 6.399650429525684, 0.09984479841565895, 0.10088064121983706, 0.20024976032155178, 0.23750738931759713, 0.1807414232603004, 0.1362200396796388, 0.18656681712356307, 0.1802653149371186, 0.16147558367060078, 0.12548117237465997, 0.1766100030152067, 0.36834052854007293, 0.9376863486343815, 1.531340751436449, 2.168575506056509, 6.397367119789124, 28.674646000708307, 34.06739311833536, 39.55824067515712, 47.527951655849336, 52.522682143795876, 69.63956432957804, 45.446212522445194, 37.42995869728827, 39.84683298295544, 48.5258496961286, 56.883428173680464, 60.7580787904801, 50.5320361352736, 49.61805720483103, 54.75182002590549, 54.484365370965776, 53.69266240827499, 40.07397351726409, 33.03828477859497, 24.164679281173218, 18.938621128759078, 22.550686713187925, 28.43988233996976, 41.84915980985088, 56.76568254347771, 72.800704433072, 91.4960229012274, 108.45246053511097, 115.65530500104352, 99.35834330897178, 75.59792703197849, 80.72119359047183, 94.09666415183776, 84.74920888100901, 31.50386925666563, 0.5827165058543605, 0.15428270754073897, 0.5282592989744679, 0.22326158599988108, 0.12127025518566371, 0.18647473335506456, 0.17192143766630083, 0.3053877130150795, 0.1924084520508205, 0.18214863484665272, 0.2554105729946206, 0.2676121932604621, 0.24796628212976843, 0.20301919881134264, 0.2593620085427838, 0.3569791381878238, 0.17347196898152753, 0.18122805763156186, 0.2152503594275444, 0.13805508072818481, 0.10371866756148877, 0.12592519693557294, 0.13932085716195647, 0.1303699931069728, 0.1035371047234343, 0.10281142027628037, 0.18306242452273447, 0.1766317445904978, 0.17164455816870736, 0.13242991160481207, 0.15224679823844664, 0.12624911423171722, 0.10635668366786935], [0.04330276368906902, 0.04848207730138975, 0.035944673037456895, 0.05695053962089362, 0.061310330676215316, 0.014571126385201371, 0.008513540848188342, 0.0948078009570318, 0.04650409573749189, 0.07337978545335994, 0.04357542970307893, 0.015072707131865527, 0.0952058908860049, 0.05129277345634276, 0.1257511724026934, 0.01104537716826364, 0.04532981318451705, 0.09872804140491832, 0.06371369405138878, 0.1732333938801481, 0.08568233780322537, 0.18514861983637657, 0.16926311256904758, 0.32536878761264587, 0.20885514936620192, 0.0730806281189284, 0.11119261368988984, 0.25663473553234534, 0.29764109321178933, 0.611552729481651, 0.41447103384041023, 0.20218690556864585, 0.18202573902183966, 0.17390837862847314, 0.3412209547335102, 0.32540675493017324, 0.3021911345422268, 4.280901772360648, 69.4889453149611, 106.03212279658165, 87.22504815747662, 76.95159973636751, 73.56316612612817, 105.61817938281645, 119.39013881068077, 97.32493954320108, 81.77568358759727, 52.406230895749985, 39.55087054160334, 27.87241343528994, 9.119205686353869, 9.93950370819338, 9.281686928964431, 8.609115173739772, 7.41751088250068, 5.342243659880854, 13.510324589667784, 22.280449136610954, 32.546894165777395, 40.51540097882671, 35.48576531871673, 47.53640436357068, 51.362700000886, 44.623805246045514, 36.25236511230469, 38.40136504942371, 30.635956602711833, 24.8114251705908, 24.898795966179144, 27.358106374740604, 20.150584482377578, 22.4593327506896, 28.16832292464472, 27.24838395272532, 16.43829841767588, 2.72248673823572, 0.5070039137236534, 0.1017962541851786, 0.395734423110562, 1.670328467603653, 1.882225200533867, 0.07761936199160353, 0.03129273052177122, 0.15127628741245117, 0.19761922889419142, 0.11360213641197452, 0.06795631195869177, 0.575428129203858, 0.2815573836766905, 0.2051619927008306, 0.3858851983902916, 1.5042869386173066, 0.12411091686977495, 0.1347704634310738, 0.12939916052404912, 0.05499662470913703, 0.008712639438829595, 0.11058407940811689, 0.11018716925454718, 0.1514805877400983, 0.034067822740443295, 0.14075820664724997, 0.31426406735854767, 0.1729756052936277, 0.15195766133406471, 0.28907779303769915, 0.9580265958943676, 8.71770206959017, 13.498437846860579, 40.88022847329417, 48.08598726026474, 25.03609657287598, 20.456464636710383, 30.407051001825643, 25.921193130554695, 6.290632072956332, 4.161876468889175, 14.467876149762063, 18.227709185692575, 31.634878381606075, 40.65449999224755, 35.40618042792044, 26.42498823904222, 24.82268237298535, 24.075206095172515, 18.54865320267216, 9.727285831205307, 15.674183445592082, 24.563890272571197, 24.63233563207811, 36.89808922429239, 44.45379795566682, 61.15757611490066, 78.04721186237951, 81.35391112296813, 73.86529845576133, 54.75366746225665, 53.12002381970806, 63.55712921388688, 75.7445687632407, 40.418126198553274, 6.903370032387396, 0.744791905726156, 0.08132595583916673, 0.0765824236816937, 0.13498499869338929, 0.058695638116689465, 0.039504258442790284, 0.0866802209507554, 0.04911706459918811, 0.12928709718248538, 0.09764887632862215, 0.11603281848252782, 0.14695366694321557, 0.040803329057751164, 0.12699345291982736, 0.14189426907368247, 0.04280299474034579, 0.09443733615860825, 0.08280221493013444, 0.01972133631727869, 0.025255513347444997, 0.054231084537722414, 0.20281433157863157, 0.071378848064811, 0.05723860017174194, 0.03589718707747037, 0.06785420776014367, 0.033126538168759115, 0.11826309961296859, 0.03370827852538036, 0.026613063284105835, 0.07618007430386159, 0.036862427218546795, 0.10356257714691663, 0.012531080208117924, 0.049648503622701096, 0.021139918563647137, 0.05643451811685678, 0.024002011557440125, 0.051016767298982996, 0.022278581858582558, 0.0360014631352838, 0.09652599827536652, 0.04099511150871554, 0.05072960307100608, 0.05191269180467052, 0.03438810111894723, 0.0571263951039122, 0.05028124245244169, 0.11612814280294603, 0.07501541381521572, 0.03993925082707598, 0.04195989965791664, 0.17383647361590018, 0.15838261092862777, 0.15069222197897975, 0.15557149725575603, 0.27593880290946654, 0.27631816964957023, 0.21133503726413175, 0.354523703816437, 0.16379649300248394, 0.4199365195968459, 0.1707349360109337, 0.1989130747895087, 0.06701212391377458, 0.2761753402169674, 0.0795519030502727, 0.05327811712519296, 0.13675856884689103, 0.1560729018021976, 0.9068511258209906, 23.96305572602057, 102.98891267468854, 109.63357248613912, 90.18735547219553, 95.20867962991038, 109.6336587782829, 109.05020621515091, 100.56548410846342, 82.36691813315116, 62.86500738513086, 48.48360576937276, 48.88773149059665, 41.24571492595058, 26.66912244212243, 31.53576400972182, 28.963008849851548, 28.82467862098448, 23.172388269055276, 24.205548417183664, 35.92685153407436, 41.9016646569775, 50.876251574485536, 56.15247095784834, 45.523408689806544, 49.50226099260392, 43.2171138640373, 43.54636546104185, 33.76738279096542, 27.64399813067529, 27.688418972876768, 24.907309470638154, 23.165257400082005, 31.1499616407579, 41.990153328064956, 49.7136571330409, 51.78018923728697, 28.732885353026855, 15.660576743464317, 3.733717405026959, 0.3852435844319482, 0.22009514542596958, 0.4687307126099064, 0.5537986478978588, 0.13787327274199457, 0.3342357037528869, 0.08789803261958784, 0.022669690811345657, 0.04562038267331739, 0.027300853192085223, 0.20830166616266776, 0.14427148586800023, 0.12219153720164493, 0.13253633653925312, 1.6402451141226677, 0.9572323772215074, 0.31872456833239526, 0.16667900606989863, 0.06445415633460207, 0.08122362947512059, 0.02534126156880971, 0.06759104123639484, 0.08109635928825987, 0.11613629397846038, 0.014876779187620889, 0.11741415161879794, 0.1578851593958755, 0.24570950967890604, 0.5885265166721037, 0.6383208834355878, 0.7115606050337515, 6.532555530148168, 16.23741520989326, 26.770753014472227, 36.19888751737533, 39.66991055396296, 35.661864049973026, 45.63700837473716, 26.58869424173909, 9.458403433522871, 9.145609121168814, 18.348408360635084, 28.445689409009873, 37.07772593344412, 45.53779986596877, 43.22413882901592, 43.398417580512266, 47.616146149173865, 42.67772912979127, 34.8497647623862, 29.551130994673702, 37.452680987696496, 42.07764571712863, 38.325122018014234, 44.213062486340924, 48.21455470977291, 56.385844138360795, 78.29280714834891, 91.2666662277714, 93.96619043042584, 78.64753061725249, 69.30874378450456, 66.60393222685784, 82.30646656405541, 66.19320515663394, 24.91920994174096, 1.4607937369615802, 0.14875602668091176, 0.05587956019406838, 0.15954170195806414, 0.032913592538886496, 0.0592781828656312, 0.11874546687449179, 0.05155834166573421, 0.15019346809675618, 0.210477156684764, 0.13475877292934926, 0.10939190104123085, 0.05411984474067727, 0.033088229942105474, 0.07625725000135361, 0.04105180584555192, 0.08168738080008377, 0.14148266535372506, 0.09712670313855333, 0.1747038690072875, 0.012907013916710933, 0.023216223682186777, 0.08197337674397616, 0.033490249902130134, 0.023540158215309345, 0.0768987950117838, 0.07978817988787928, 0.08280006222306721, 0.03329757495873398, 0.041552053599227826, 0.09212068627558409, 0.04283321690895865, 0.03867267766186307, 0.01932203596938522, 0.23688210835379941, 0.12187951725096473, 0.11913714464753868, 0.10201411426908548, 0.15354127232586184, 0.09612577096108468, 0.3014102151557323, 0.16106249374007026, 0.06303264571714305, 0.177128751792254, 0.13058779190384573, 0.19491892217868761, 0.21673165171617464, 0.10925201338625724, 0.30565323908963515, 0.25985071135144083, 0.10498109619103133, 0.1689057478741292, 0.3863357193768025, 0.26965200961116825, 0.21077370932025297, 0.24015259898958669, 0.26705846490879215, 0.3568608542123149, 0.4418256434221422, 0.6126607377682963, 0.49787606803640244, 0.6539978002828937, 0.4372680944300467, 0.8020300730582207, 0.4862730229093183, 0.49827979637249825, 0.2140343327435755, 0.18387810897923287, 0.4501984022077053, 0.3497849597084907, 0.35554545060280834, 8.534033163901299, 97.28216217410181, 138.31954433072, 118.24138641357423, 105.89987616385184, 108.76661885169246, 135.99734429390202, 140.64982445009295, 122.18147000958844, 111.7646981823829, 92.19155326966317, 76.51358081448463, 69.26244412699054, 35.48377275466919, 27.213521926633774, 24.663273326812256, 22.979797932409472, 17.154191770861228, 16.880763346149077, 27.633943134738555, 37.84256458282471, 48.18360720911334, 58.57408346668367, 49.94033482766921, 56.56359418745964, 56.46313444260628, 62.67644336146694, 52.98778895408877, 47.84282776617235, 37.74820804595947, 32.757331286707235, 49.41092468077137, 39.42510758676837, 34.53194295206378, 46.33098940695486, 53.68476275474795, 46.28179504025368, 26.49726575420749, 8.299471505226629, 1.5171741309665865, 0.22421797016455283, 1.5978657430218113, 3.106489229586817, 2.9611043728167012, 0.4274055397798939, 0.34665533732022014, 0.25721426572530504, 0.29076759913756006, 0.23759918197268443, 0.4039244852479427, 1.081266547403028, 0.42744715367594077, 0.3335981653823007, 2.3548375887255517, 2.8154358796535, 0.48889298232332357, 0.2423907095386136, 0.2856928795095413, 0.22173756132683448, 0.1277921761896822, 0.18449438074904104, 0.2528635451510068, 0.23883023930172767, 0.10552488838232334, 0.13801467725105826, 0.5718789357812174, 0.16717616648923966, 0.4281760403706182, 0.8068642717215323, 2.150848844358998, 12.089040029433466, 21.51850715760262, 52.745547294616706, 65.67794299894764, 38.601633425681825, 33.61560667714765, 53.5103427979254, 61.30920710102205, 43.67508196061657, 43.23437229279549, 54.35389557192403, 55.940247197305005, 61.17490514632195, 62.41616664394256, 53.17220703248055, 45.381709144961455, 47.39070400114983, 40.861350105654815, 35.52586763135849, 25.74024634976541, 35.329419643648215, 48.163826696334354, 49.17350361424108, 63.65121510721023, 70.6045929078133, 85.59205562837663, 109.88612605679421, 107.18075752258302, 103.79098246174475, 76.72451803761145, 77.12018320637365, 89.42665100097658, 97.82599879849343, 63.51222592015421, 15.872777950379158, 0.4724493340378808, 0.1338548964310077, 0.24942834561149924, 0.24749097053802785, 0.130763731656536, 0.19007903914297783, 0.24094404442416084, 0.25890042524664636, 0.340873028241819, 0.2703029085551539, 0.26560492032477934, 0.2617475144084423, 0.1655743992136371, 0.18914641902571727, 0.18556998351648932, 0.08225871385225365, 0.17742980902473773, 0.26206283619807613, 0.1379274045147242, 0.20957642114691197, 0.1586581114679575, 0.34195342671967327, 0.23883731795414803, 0.12607907335604393, 0.07010257622647671, 0.1406745804894355, 0.2601074120931087, 0.25197416303619263, 0.16993471120874729, 0.18698140858642517, 0.1586591839910515, 0.15968304518009388, 0.1987008837562415, 0.23632438102316475], [0.06580807118406219, 0.04616288400645699, 0.036605542615777066, 0.020210217241378083, 0.04751214487177711, 0.03552234025611993, 0.028985991901267442, 0.023917454602797667, 0.011665038877136765, 0.07771308518826, 0.03629231990705575, 0.013268424513479395, 0.011144788567757895, 0.04908090141872245, 0.04530337165981051, 0.05006081597398847, 0.07793751830655722, 0.09423532643385472, 0.14758409601786446, 0.1033622298329588, 0.1906023844475708, 0.1498961800168599, 0.11178861477322156, 0.2649008548788486, 0.2697943487474995, 0.1321983232253021, 0.20360213043468617, 0.252186737113422, 0.32441467106823, 0.4263578379346479, 0.43907808440346874, 0.23283619884281392, 0.25736184490303843, 0.017067860556586135, 0.09507809975935567, 0.14888503588736057, 0.024288380969195597, 0.13282228651787006, 1.5126426902509507, 38.09796971659507, 103.1362682773221, 82.5385610518917, 71.89473890489148, 72.51729749864148, 75.10577940171765, 105.19703449741488, 105.96602301443778, 98.17284614809098, 71.95866569395989, 55.70828999242475, 47.011399038376354, 28.635673330676173, 34.56655002409412, 29.62784863287403, 25.8549266476785, 14.095966815948488, 6.11719516015822, 7.234157727610681, 8.789835437651604, 16.356719001646965, 16.578870281096428, 20.949065300726122, 30.532749237552768, 32.59595124952255, 29.73102854144189, 43.77503571971771, 45.49191597969302, 47.4264838618617, 56.326118207746944, 41.62245858100153, 29.73355454783286, 28.3418172021066, 33.32655937440934, 25.19133810074099, 10.31942448308391, 4.49335204978143, 0.40608010344928314, 0.28794894715951336, 0.8209452742049772, 1.0869261598394764, 0.4311761019691345, 0.5745154426943871, 0.8797620116702972, 0.22606309293018234, 0.3162001247607893, 0.2140148587885403, 0.40676973579872044, 0.4127354769697113, 0.05742975443060841, 0.09063286691783898, 0.6679668313553256, 0.6489782696289401, 0.17905039141976065, 0.07880883606811685, 0.18867617893603542, 0.3325756218644881, 0.25155525083743757, 0.1535632590492887, 0.047144326907131946, 0.29411206322331584, 0.09857693822273324, 0.18452016726857234, 1.2344465020202822, 0.3933929213352742, 0.25850022091500224, 1.8907515752700068, 6.375054717063905, 9.811723674497298, 15.675315049386795, 33.14033700573829, 41.564921332943825, 31.932890261373213, 31.276210969494237, 28.62287659798899, 28.977570649116274, 17.991670754648027, 18.650083734143166, 20.16777623084284, 27.279100033544726, 40.65082080902592, 49.37170882378855, 49.553510681275405, 36.42558874622468, 34.770136725518014, 33.56108965412263, 37.36947967160133, 32.96245751842376, 33.0390888644803, 46.17982910525414, 51.06450573090584, 53.88884367481355, 56.30108564130722, 60.99710018404069, 56.24827092693698, 51.82227234686575, 52.61862331821073, 62.47020513780656, 62.23050909657633, 53.2936514577558, 27.901433091009817, 4.443484016003148, 0.37642998801123717, 0.0802144235480697, 0.21985304632013847, 0.18034802178942388, 0.40850725385450554, 0.35174277400778187, 0.17683327167985902, 0.13588325210636662, 0.10206876698160365, 0.0658284031575726, 0.17399568200832413, 0.2907604591981057, 0.05836233241303314, 0.009615742188367632, 0.16934324536592732, 0.14691623588723524, 0.10312586872568054, 0.28770162333403865, 0.09600642212336102, 0.04254504144492169, 0.01359047063986861, 0.2267211471353808, 0.12176295697328546, 0.15074946406868198, 0.1980476099396906, 0.1038324086356067, 0.13514292005810047, 0.10653568011137748, 0.09554827856200357, 0.021146185162867752, 0.05685582050993558, 0.06079043276728161, 0.02559259969500765, 0.04938562055148425, 0.05258249779862743, 0.058503032121206486, 0.03338315847119497, 0.015584733487377244, 0.05928011723764001, 0.05677510931667301, 0.0782752022027008, 0.030805611599897666, 0.05236569108561643, 0.034197739761082396, 0.022626644330880335, 0.0620598289664955, 0.04642514271601554, 0.004154048567157119, 0.1010598904723602, 0.04129281710653056, 0.10456386172483045, 0.04709740402176977, 0.08579112994935244, 0.20370308550134783, 0.12265027065070407, 0.1353779711550282, 0.14454707833788089, 0.168132474045119, 0.25639239127837843, 0.34684560291709443, 0.2931362817124013, 0.5024937089652785, 0.2793552792601047, 0.24019087274228376, 0.12379712725598967, 0.0344299754848884, 0.041635312034838626, 0.052540734515435276, 0.03827269549571699, 0.05038353817297086, 0.1462646781076347, 0.027765069915462407, 0.11299337230382428, 15.626743358950462, 77.04818417949062, 110.97009658813478, 93.09733836881577, 81.60771200733801, 99.15067734256868, 108.50469866106587, 113.03773480076944, 107.57002922796435, 92.91596797204788, 76.97181563223563, 72.61916145201653, 61.82144903367566, 38.24513704546037, 48.35723876953126, 46.31954000842187, 46.32414487100417, 33.47650766372681, 24.245915489812052, 27.390605172803326, 30.61364223880153, 40.35013583398635, 39.31868976162326, 41.35011273045694, 44.65550976414835, 44.84894537156628, 43.51280958421769, 47.49843582030266, 36.39057767006659, 28.111821182312507, 27.889260015180035, 32.39667131054786, 36.66258619677636, 42.17767007889287, 43.49750057343514, 37.20873309719948, 22.44262149257045, 5.580220722383069, 1.5738723595296185, 0.6408502606134261, 1.4505688533667596, 1.7190356023849982, 1.526344019559122, 0.25857358149463133, 0.3225143440067768, 0.11844679217545256, 0.20023958667391734, 0.03499471252003024, 0.040942029276442145, 0.32007135090328037, 0.23337681176922015, 0.10935417121096004, 0.5852173232743817, 0.14763016854563069, 0.3124168761555226, 0.1734257738796934, 0.01658708675794544, 0.1563860172586095, 0.14146905963218984, 0.23939532107643544, 0.06804089572641157, 0.17016475209065024, 0.20560515924326836, 0.30554929628006877, 0.6763705094495128, 0.7016172127858286, 1.9544842070148838, 0.12132613363886073, 1.8862108189252116, 9.421841059961627, 18.375068710696315, 40.675382691044966, 54.91684198379517, 33.72842973278415, 28.073393721734327, 41.507995974633005, 39.422746319924634, 30.14779802291624, 28.179599738890126, 38.75828112325361, 43.59788579325522, 53.012150795229026, 54.83535866583548, 48.78898189913843, 48.93880859498055, 45.470692034690614, 45.989041097702525, 51.6903434261199, 42.01025547519807, 45.364093780517585, 53.26305697041174, 50.79372490606001, 57.58677582586966, 66.22485083918419, 73.40059957196637, 73.78818465817359, 80.05525358261602, 70.58099592885664, 69.06456839653754, 77.94577152498307, 73.16288040530297, 47.29965794471003, 12.82371957455912, 0.26519959852580105, 0.11600897782632422, 0.1247908965113663, 0.19565065872044335, 0.3921154237562611, 0.29877873377934583, 0.17377284235290943, 0.06893845199937783, 0.07041156246897674, 0.2141018404114631, 0.18456040220635553, 0.19135845194180168, 0.04842226881714118, 0.01661552777213435, 0.194346240811771, 0.07972855526473253, 0.09680797991853568, 0.2854922870474477, 0.3862208061881604, 0.15096934662470896, 0.1816762497107829, 0.12183072511106731, 0.09957060788667972, 0.09137955749587667, 0.12610601666834087, 0.04558392071856126, 0.06166170073312618, 0.07777952033305362, 0.09046572185451947, 0.10622671685151516, 0.02170964666161566, 0.045974993282147956, 0.05753759279726975, 0.10788763377575145, 0.02278630279995982, 0.14207741005286095, 0.17829176519186268, 0.18877350274593602, 0.09667094977151963, 0.1796106928058209, 0.14589536244109755, 0.11654543855618085, 0.20944698293122554, 0.28376429912544066, 0.17787899701826035, 0.16278412313230578, 0.1533793673039444, 0.11398447557322441, 0.1613414263533008, 0.2346601622599748, 0.1640186278570083, 0.210791252733719, 0.28134968191865956, 0.2108763038150726, 0.24752313090908915, 0.205650802761797, 0.32513641782345315, 0.22404886391614715, 0.35622484801757726, 0.4929708683442685, 0.4576025500653252, 0.5490874523116697, 0.5014296434819698, 0.510080338966462, 0.47383172437548643, 0.3964615631247721, 0.3642249203497364, 0.2682229798407324, 0.19734516860015933, 0.17465742875731763, 0.2187016008481864, 0.3133695218111238, 0.22643374158970772, 4.280463447493892, 60.55134634817801, 135.923729250508, 117.58295382222822, 100.29484056657361, 103.9133054979386, 109.77599374709591, 136.48580489620088, 135.59630547800373, 124.88546571423932, 104.45204304110621, 91.3004299902147, 85.10202607800885, 53.32455973471365, 62.47324889706027, 59.55494665330457, 54.880622817624, 36.20074672083701, 22.792702836375085, 24.719857438918083, 26.314222466561105, 35.734118030917266, 34.193897401132894, 33.66401656981438, 37.49488961312079, 42.275760712162146, 44.950091531199796, 58.43090126591345, 64.34993044022592, 65.84751098386704, 74.66928235946163, 63.20945032181279, 49.10705866352205, 56.66470896813178, 57.9784401770561, 58.97971145568356, 30.87336982450178, 8.828232499860949, 2.488518338049612, 1.7253677787319308, 3.208842988937132, 5.887370253762891, 2.149268864623962, 0.7127034243556761, 0.7522694754504389, 0.2800020106857823, 0.548342937423337, 0.3004818391655722, 0.925523630313335, 0.734612129388317, 1.1650335428214844, 0.17631369552785353, 1.3255484522350374, 0.9430451030212065, 0.3613130507930633, 0.4487972273941963, 0.25227842251619986, 0.7300527417852033, 0.4213260498739058, 0.6049742405453037, 0.22576643304238397, 0.6855628903835052, 0.2202961362537838, 0.3707353193913737, 1.7116638753683338, 1.0273042946092545, 2.5558681305377715, 3.13664686295294, 7.003302708748849, 15.614829159552052, 28.080452026859408, 48.18277174426664, 57.847342798786784, 47.139083954595755, 44.53903498188142, 45.22204906709733, 54.76394014973795, 54.9612981273282, 55.778029734088534, 58.610294788114494, 62.375064126906864, 69.19577952354186, 74.1367421611663, 75.01418421345373, 67.08006089733493, 64.07436824614003, 58.21680653479792, 63.22151161009266, 54.5693866668209, 59.352622955076164, 73.96455795534196, 75.65514656805223, 84.0061942992672, 90.14509585595901, 93.51096799296718, 81.28955287318077, 80.08196492348948, 73.80791418014034, 87.04184209146808, 89.35360077888735, 77.7651777575093, 38.77019336146694, 7.017607102471014, 0.27272377703939715, 0.14840805422394507, 0.1896177316384931, 0.3883148922074226, 0.4126864473425573, 0.26143936320177974, 0.27275393026009687, 0.2617134388175703, 0.23785481019125831, 0.31666707067239674, 0.4860507041936921, 0.4812896209618738, 0.1321733027936951, 0.15161146620108237, 0.2921941161396042, 0.25281754923203303, 0.16424928160925067, 0.3634013758311349, 0.43098767498327845, 0.26831279598897506, 0.2890488042706444, 0.2537678046933105, 0.2450741163545078, 0.18929045887724047, 0.44561416271232795, 0.19539403458756788, 0.24267145011934543, 0.18597858417178356, 0.2283007285046962, 0.1347377667984655, 0.12206121032396633, 0.11381677126572018, 0.08876182739773104, 0.2401417511845789, 0.1879431553665669], [0.11702302542905654, 0.04654772444477966, 0.08505473559301707, 0.055930164131906726, 0.0803667831144506, 0.108918221216769, 0.14966344250546348, 0.02383721263838872, 0.03297879811256163, 0.06613892923680044, 0.05220901461378221, 0.0639261034197144, 0.015083520462916744, 0.09787723181709167, 0.07450636371128982, 0.032256120560510505, 0.0487691036335403, 0.0509042481351043, 0.1662588987739817, 0.30824666121794336, 0.4267774089690178, 0.34808096566027213, 0.32096378204803316, 0.19499758408675272, 0.1665571214811456, 0.15044583278077264, 0.25827876021785123, 0.480116066192427, 0.31164842868043535, 0.3904601222565098, 0.2611884234413024, 0.17112937936138722, 0.2637368302431799, 0.23519990184614736, 0.13421921720427854, 0.15317739588358711, 0.037573793482395916, 0.33820587781167805, 0.09204278279456402, 0.21531126341752468, 24.971820692862234, 77.45043108540197, 97.73354853353193, 77.85530597932878, 62.85777453453311, 56.307863496964984, 79.8918084175356, 93.97341543628325, 100.6719764586418, 107.61665836457284, 85.71440219879152, 66.06674009753813, 58.256245966880556, 47.96995178345711, 36.103236598353234, 36.348216072205574, 33.96161463952834, 36.14712007584111, 36.795840878640455, 52.3729338953572, 53.5244829423966, 63.22213918932023, 66.97258795461347, 65.28004600155738, 73.69770342303862, 84.05045432429161, 73.38072099993306, 61.313455027918664, 61.70340138096964, 61.57205297100929, 63.13258755591608, 47.79027585060366, 26.485626120721143, 24.52283678516265, 13.18398339133109, 6.388828610220264, 6.20652174757373, 6.315864680274841, 2.010299657141009, 0.9800828801047419, 1.0411896075933211, 0.4019567424491529, 0.24089135289672883, 0.25492776906298054, 0.40665439360084077, 0.6225679093791593, 0.5311494729211254, 0.44437549046931735, 0.3759049419914523, 0.09804326605292098, 1.0652222147872372, 0.633884069900359, 0.0577742028831234, 0.09312308934186736, 0.17767241374859888, 0.1331951108671004, 0.2652256148717096, 0.09358137845993043, 0.2696087716087219, 0.12316311288985515, 0.40804321907701036, 0.9909485809264645, 3.4407560671529467, 2.7733066822251966, 4.3503929338147564, 5.613161767682722, 13.879248019187683, 15.211755614126883, 27.258907671897646, 36.49246908003284, 34.44644312704764, 36.24990186383648, 48.04404927838234, 72.767834971028, 73.37753603535315, 63.534528516954, 59.969960874126805, 58.805962224160474, 62.043890568517874, 63.69696563290012, 56.633118198763945, 57.16070444353166, 57.91571755563059, 61.88934133898828, 62.15106933347641, 71.85681743006553, 69.23550528864708, 67.43088553028723, 55.53725111869074, 49.72683237444971, 49.66700838458154, 39.17078894953574, 40.08025323190997, 52.46161476258309, 59.39677707610592, 74.23833939336961, 49.68319992865286, 32.43628528810317, 12.157936461510198, 1.273214105636843, 0.24600558733988195, 0.3817220927486497, 0.2328300394959027, 0.13134693907153222, 0.47926258295774465, 0.6788970674237897, 0.6511305476869307, 0.25808071116766623, 0.03414444685462983, 0.0511779866722082, 0.07474534483926912, 0.134293251941281, 0.19389941236905514, 0.23567139832002504, 0.16843979787682334, 0.13756110723460876, 0.2521302457898855, 0.30458316747700015, 0.18181140294238446, 0.17187593204359855, 0.09628212950643032, 0.12698772258215374, 0.10723460510733629, 0.17915759776388446, 0.1971371604069587, 0.21078524660439263, 0.0995293310693195, 0.1577109356801356, 0.27695380812210424, 0.23510438600374808, 0.0993481053099517, 0.17907774075865748, 0.08168809326185335, 0.13712682731209264, 0.15811913796970922, 0.08449705422765787, 0.0867350958287716, 0.0370730975672843, 0.047294223500836285, 0.08071386690942511, 0.05930889533051561, 0.029391365411180644, 0.08670046865459412, 0.05793140795562537, 0.08600935009458373, 0.02781307298479782, 0.04064829967495415, 0.07620950740191244, 0.02456084205468576, 0.049514097326825705, 0.0458748655904445, 0.04514576056070867, 0.04254260528532248, 0.025828577758323763, 0.06878996883789379, 0.28234761869234426, 0.3100893478239736, 0.2632540722768153, 0.2602216817678944, 0.30807438336553117, 0.22653328705458875, 0.36356522671638, 0.32176155536886186, 0.5080848637848131, 0.3703334909533301, 0.26955817916220237, 0.05812899352261617, 0.085669957822369, 0.017970576431722413, 0.07497465027676475, 0.07686902483504626, 0.03670251785567211, 0.1729120506394294, 0.028173687807734937, 0.44729802396989643, 7.41218920676939, 63.04245148935626, 99.96417691630703, 108.02031732374623, 92.9767333307574, 87.67583831664055, 97.07861469637965, 106.09732043358588, 107.10483612552767, 103.58839988708498, 102.06438649085261, 88.77953052520753, 75.27531993004584, 65.27791223218365, 63.56559761108891, 57.61581705462549, 61.39179652737033, 56.304211770334554, 58.31699171373921, 54.82665884879328, 58.32374995754611, 54.30223795675463, 50.96739569017964, 54.04781733789752, 59.49820172402167, 66.00290744535386, 68.6893387763731, 62.23863624757337, 54.15959312069801, 57.231969987192464, 49.82346388601488, 48.520213250190984, 51.15861123608005, 48.71626507851386, 38.094141483306885, 23.598012501193633, 9.733737149546224, 5.1834558190837985, 4.109885942551398, 1.192396119717629, 1.9313076571110759, 0.9768503567864819, 0.646094163098643, 0.2029540047289864, 0.04256569134492067, 0.2099819421287506, 0.20710379576250432, 0.5280734154005204, 1.2172890742940288, 0.2714700281860367, 0.01136459259977264, 1.151772744713291, 0.3791961476447121, 0.22902811366704204, 0.4311884513064739, 0.3316114236029887, 0.22710713287515027, 0.2849184871921616, 0.14810396328328118, 0.15347721205363352, 0.19763140969218748, 0.3470910881315509, 0.9819044533275789, 2.7250929080670883, 0.8626832764956259, 0.9197456726143438, 2.1104128851044566, 5.614255128368255, 14.575143168049475, 23.940719789074315, 44.76130001006588, 46.6731495241965, 38.34801297033987, 40.933843351179554, 48.83044919660015, 52.91851205210532, 45.93906225696687, 45.08067507897654, 50.30941417140346, 57.42706867956347, 58.595177973470385, 65.45020234200263, 74.0676692224318, 74.27571958111179, 79.43983370257963, 68.63646522645028, 68.31234408963111, 63.834119150715495, 67.3194823726531, 59.25914502912953, 58.866947235599646, 66.35359871772029, 62.11694471297726, 62.001619185170824, 66.69411536185973, 66.85727811628773, 84.09877008007419, 79.9623404779742, 52.7538509522715, 23.21708171598373, 3.597058351001432, 0.3171227091262418, 0.14221411078206955, 0.07390662411888761, 0.24385965248990446, 0.39314660874585955, 0.6624142260801408, 0.6630871577128288, 0.37530733212347955, 0.1374837629977734, 0.09220893194358196, 0.017656903646345583, 0.05005396331750578, 0.20939665095460033, 0.10852615273888074, 0.05412711874551831, 0.14648403972387314, 0.15384228359307014, 0.21096483293560245, 0.15998638535459198, 0.4480576767556129, 0.1606161402718675, 0.23947805857225773, 0.23120152042998424, 0.13482755230319116, 0.15343961245830984, 0.13931990721293036, 0.0829352384373065, 0.06916912873425791, 0.08160694156803432, 0.026810549259666475, 0.026636174241561564, 0.07062330917124787, 0.030981233426099344, 0.019135832553729415, 0.16189094122138717, 0.030008776736776197, 0.2151267434800825, 0.12726910667674196, 0.26065249897299275, 0.15864337193629435, 0.22802510539129858, 0.20368007222010245, 0.14612376389484252, 0.15245782481806894, 0.17206989018426788, 0.17468850128352645, 0.14048696555677923, 0.2285077561053538, 0.12981387456097912, 0.1708516418453186, 0.23193788414280261, 0.1905264498125161, 0.10241932881575438, 0.15474960748707095, 0.18928618410662298, 0.3295001772142226, 0.239678482495008, 0.4321051214731509, 0.37733087676667404, 0.2959760777171581, 0.30495634422667567, 0.408143699169159, 0.539382221477647, 0.3936397242209604, 0.640936675331285, 0.3259948346643679, 0.2221622498285386, 0.1640309771943477, 0.2384984619434803, 0.27310295991839906, 0.1785735476521715, 0.258153336302888, 0.38794839574444684, 0.388222931012992, 0.21387939912176904, 1.890555701909527, 42.09538659741802, 112.26148989892776, 140.2257848555042, 112.68897333452779, 97.5096361098751, 93.07811875497141, 118.23676586151124, 128.29987325975972, 142.18257688706922, 138.76923622623568, 115.05697881021808, 96.02941205424648, 82.83510792639949, 73.09125008121615, 65.16577166895713, 70.15386550657212, 61.94608626827117, 62.97483374995571, 60.421688479761926, 70.75636509926089, 68.766570245066, 73.58910868244787, 80.5360028051561, 91.78384642447196, 96.74074172973634, 95.31270873162055, 96.47002758518343, 93.95185024507585, 83.11778529997795, 82.29265982104887, 87.12730269278251, 77.15234664178665, 55.471280774762555, 49.364817219395796, 34.42157530015515, 22.878942028168712, 16.215951019717803, 11.312060663777014, 7.344641579735664, 3.2931285952368095, 1.8040062751500838, 0.9508840823846479, 0.4961997450840089, 0.25718641076837817, 0.6749408668087375, 0.9309786053434496, 0.9665163822712438, 1.4377798428458552, 2.5135146225652387, 0.2888761586960285, 1.2058227605396703, 0.48275091835568035, 0.16315740713429067, 0.45104085377627806, 0.45116857595501414, 0.3139071929599008, 0.8187183485396448, 0.34366115927696234, 0.2384659644937323, 0.21234552255801617, 0.8301145499271732, 1.9651039016823617, 5.395302541794316, 5.432024751940082, 9.847160327819086, 8.558569550514221, 16.988324542199415, 25.75714980402301, 42.62195302594093, 53.79051377696376, 55.82792228268039, 64.78605877968573, 71.26581822672199, 91.04546808427381, 97.69072409599059, 94.23597889561808, 104.58176366744503, 103.48880306366952, 98.17327760880994, 88.79259201788133, 79.43570736915835, 88.38392026962774, 90.66542963827811, 96.4666308126142, 89.43232274824574, 87.94465403403007, 84.52504542566116, 90.11783538326141, 83.89721516639956, 85.54141782945203, 92.22033562198763, 79.9612186801049, 73.92997833990282, 85.11559747880506, 84.15204371175459, 105.14092891447007, 79.8736870673395, 48.93860070936142, 15.843948529612636, 1.179911215459147, 0.20729052203316845, 0.23689022888579678, 0.30669796851373493, 0.3556667376429804, 0.42709582575386573, 0.7100658755629294, 0.7765255351701091, 0.4706216321116494, 0.22233457364622625, 0.17094846003718916, 0.24039860514383163, 0.3023501437517905, 0.3020859353484646, 0.2290221994682666, 0.3253672860803143, 0.2352687425070232, 0.31189562993184217, 0.3625716719656222, 0.27039759702259497, 0.6612646038974486, 0.41157941964845507, 0.5279756625813823, 0.3531792807963587, 0.28749974384423227, 0.3301821180409001, 0.34017460120301096, 0.22193213233784323, 0.3343522104044115, 0.24528555662160922, 0.19753742602563676, 0.20529521539086298, 0.2364659234280548, 0.09112610496700772, 0.18805627590946614, 0.25778521573351276, 0.2774173526033279], [0.09965893782434926, 0.1752365452627982, 0.022481621971594232, 0.12384588875237013, 0.18099213319440044, 0.216645558755244, 0.10796750610273693, 0.11129292524269513, 0.08189961779862642, 0.050997097991527095, 0.11085985573909937, 0.1736624797265376, 0.0509340834293154, 0.07040756349001201, 0.21281868910356877, 0.1295181339786899, 0.19783630756841553, 0.1831272355611286, 0.2822954021394253, 0.5154857327861171, 0.367065972738689, 0.3533775443511625, 0.25304760543569443, 0.08174304474866198, 0.19816417787824908, 0.2881731657731918, 0.17474419587562162, 0.06936041322807152, 0.05880283679993403, 0.2138675094371842, 0.03839857906343476, 0.03771656545840445, 0.16885351599945178, 0.15674528185158007, 0.09482992557628502, 0.19717059248397428, 0.11450225141860786, 0.1031404473788796, 0.1104231319961048, 0.18224624976996454, 0.6921196837098368, 10.103801008193724, 55.379893472117764, 92.79606896062052, 86.1046152730142, 75.47675717261531, 66.92241299536921, 54.885659140925256, 75.85180636375182, 99.05290049891319, 99.53983137684484, 104.22462401851531, 92.42422042354461, 82.9712926187823, 74.30920877764302, 72.1487751314717, 75.53309809777045, 71.68680621731666, 73.35692790246779, 89.96577293642106, 101.6818847963887, 105.41054479537472, 94.70529833147603, 75.97037961406093, 86.47666777333906, 98.60005501777896, 91.80385835709112, 80.22102079083844, 80.01437464068013, 77.22899759969404, 57.50718309033302, 40.616229426476266, 41.56477228287728, 26.277764035809426, 21.460899306881814, 27.372899593845492, 25.554371110854614, 15.318056748759362, 6.552265930560328, 3.884477870118234, 0.8743448507401251, 0.4644385977618156, 0.6268030885727175, 0.22350259726085972, 0.1567609100452354, 0.06235966811917963, 0.2168644760404864, 0.6526055427328233, 0.42177580477249244, 0.8238183490691647, 0.9933403074260682, 0.607240696347529, 0.8270565720815813, 0.3162493076055281, 0.2924950048327446, 0.6362447851607878, 0.40283195193736787, 0.5614790777044912, 1.2261901579556929, 1.480249305886607, 2.2195383714091395, 0.9056331685954525, 2.564027395940596, 3.2086954097593985, 5.2064002137030325, 5.32632815261041, 9.307412774332109, 12.327044548526889, 34.58004689985706, 39.07237275954216, 22.95325525345341, 21.8915637846916, 37.11290174914945, 52.48323878934307, 66.82964109605359, 78.45801738000686, 78.08841243866952, 81.0550186710973, 88.684507185413, 84.31701075646185, 82.14540620003977, 86.99413038069203, 80.18466041934106, 79.9941038316296, 77.35041849074825, 75.01623953542402, 69.94750176706623, 51.52094410311792, 39.750589786037324, 28.482520464927923, 31.461362531108243, 35.13047310613817, 55.0684965041376, 49.338431435246626, 47.84487132103213, 33.23114379759758, 14.185945987701418, 0.8329156125264784, 0.19509927459782173, 0.29685318710342534, 0.4504359813947832, 0.33469670482220193, 0.2972882331138657, 0.30699606864683093, 0.7537618760139712, 1.1571125614066278, 0.7564654309422739, 0.4502641631951256, 0.1385158060058471, 0.13481307324142228, 0.03388730178196584, 0.09237548711919978, 0.17361602415480923, 0.027244474866517612, 0.044435294450170575, 0.14197706785653869, 0.16768916960685484, 0.0884418860979138, 0.20784524629913992, 0.10170478328701951, 0.13785934526353114, 0.02715858874932653, 0.10732385435051496, 0.25845060906102585, 0.2582324885072247, 0.4773804275018554, 0.16454583424473965, 0.12896558540242334, 0.21079405661552184, 0.22487455348093666, 0.2308438033346207, 0.27085130493487086, 0.2653143891403752, 0.06890626098479956, 0.10060292668640615, 0.05004461321438994, 0.06340215673610088, 0.14416768095426022, 0.04384731813784569, 0.07767586863689846, 0.0959824359104518, 0.05889050407154907, 0.09969449196491512, 0.07900871606844087, 0.13575522349246089, 0.020536712423387556, 0.011808234116723462, 0.09746130736124131, 0.0852821794368567, 0.05645743563711163, 0.11590048445448761, 0.023423525159277266, 0.09932737497072067, 0.14990973977311967, 0.22426833278469502, 0.3141834442653964, 0.3399470118024657, 0.29920853974838413, 0.3631157169659292, 0.10297984470643344, 0.27703096849783776, 0.16855212168828135, 0.18023177560779358, 0.05228821661383395, 0.11486405942348704, 0.16806306647917918, 0.03337888370057748, 0.02152590047297699, 0.03884754489145933, 0.04960719233138427, 0.10278384111100629, 0.07245535481600993, 0.09655144005533188, 0.3439850918948651, 0.08876945763345688, 0.5229108408093452, 3.0720164987348744, 32.39212528351815, 91.25978639048915, 109.93848969859462, 96.60731054121449, 81.80303035243865, 86.24592258084206, 92.25067907764067, 105.74784509597286, 114.58052850538685, 110.98285213593515, 108.60603701683783, 94.2949870324904, 87.79760437626993, 78.17952909777242, 76.50766588026478, 81.45834030643587, 84.82783671348326, 92.41986659265335, 100.0860135785995, 106.81851094768894, 110.67148654691636, 110.61767947289252, 105.75579181794198, 97.95848077343356, 88.75028533320274, 79.48441536195817, 73.5419382587556, 70.64893138024115, 75.95542753896406, 76.3014276566044, 68.32845718629899, 54.558407952708585, 38.013929013283025, 27.033222336922925, 20.740948261753207, 16.35266915444405, 11.018566373855839, 3.134383655363514, 1.551799343958978, 1.278730183839798, 0.2676199460702558, 0.7849972418719723, 0.4586037044082919, 0.23371572906692184, 0.11476614572588476, 0.21072760614896976, 0.6422265222476375, 0.9730154432116017, 0.07625929545611143, 0.7542000783066597, 0.34318158823636274, 0.7486513341146132, 0.2947415423489386, 0.3776761679159057, 0.4863442077992424, 0.4021267833248262, 0.6594349407861311, 0.7031351087554809, 0.6553366155393663, 0.8397215376457862, 3.4110772080959815, 2.104571250177199, 1.8134848052455534, 1.6722088763790748, 5.396953369340589, 17.649687144064135, 25.34220030230861, 43.13548149601106, 49.251382274012414, 45.02869190708284, 38.87717993028703, 49.22070541689473, 69.56319578232305, 87.49015331268312, 87.08630607974145, 86.01526368048884, 89.26559063696092, 87.17026833565005, 83.97235208942045, 79.48273658752441, 83.53169733478178, 85.40733552748158, 83.31617093855336, 81.69958960625434, 76.44417839665567, 74.88036078791465, 61.33190193483907, 60.7248955388223, 66.94670031147619, 68.4723767926616, 65.01998109202232, 70.58556941247755, 77.91697348317793, 70.97975192531463, 57.60342628725114, 27.777713691034627, 6.489483492989694, 0.729284263666599, 0.25811849462409175, 0.0365455924052625, 0.11834114098981505, 0.3914242898744922, 0.7062480610705192, 0.9115088791135819, 1.0840984986674402, 0.822932199845391, 0.6357497085006006, 0.2412081302534188, 0.08101734497974958, 0.05622903035292703, 0.13748181713444574, 0.07112736438190745, 0.051817310027657985, 0.052701394644475756, 0.2735002224724139, 0.2414553774701011, 0.19955527097467454, 0.2973899389466932, 0.39558279898858845, 0.17092970620480277, 0.22896051406860354, 0.21829004309350447, 0.18900887559979193, 0.09089959575043571, 0.06755960864886161, 0.24885679805471053, 0.0974298058257949, 0.17392115697505015, 0.03508210016955291, 0.046818360325790224, 0.031782555649237286, 0.1087054249740416, 0.07095084240239474, 0.03465405237230082, 0.06334487634200243, 0.2757708151494303, 0.2536952868103981, 0.23991728742276472, 0.18930473875614906, 0.20862719224345302, 0.16700871499075046, 0.20410394866860684, 0.21238632440086336, 0.21842044657997547, 0.09886709402405447, 0.20433187514783877, 0.3183620248831088, 0.2918521344902054, 0.23717956497303902, 0.4077378257868752, 0.346692691767408, 0.3547021103722434, 0.28317266474327735, 0.32609326164087943, 0.446525470263535, 0.3666247367378204, 0.4049899296895151, 0.4208415145835569, 0.2794723681384518, 0.41060167695245436, 0.35792985330185584, 0.17144122311184484, 0.1357198455521176, 0.26852245893209215, 0.2742346862871801, 0.08788246571296647, 0.08803725377806733, 0.22444234199581609, 0.18962657229313928, 0.1932979107744271, 0.288443380305844, 0.11991050274622057, 0.6057370802567852, 0.49517864181149396, 0.4151450379961922, 0.517113884129832, 14.354463758007174, 78.36076613395446, 124.43753104056083, 122.05376548151817, 102.6396805240262, 94.72342752641248, 90.383466136071, 117.62701772874402, 137.57986376362464, 134.09041343196748, 136.48043909380513, 118.74350470881309, 113.06451674430602, 101.19815457251765, 94.853391339702, 100.44083902912756, 101.53611383130475, 107.06776972739928, 116.7962440367668, 120.42917466932728, 124.38463395641698, 128.3640903042209, 118.83069899774368, 113.51348692371, 111.02155808479556, 103.47111317419238, 102.16654069962041, 98.37946091928791, 93.18420317865188, 76.27668534555744, 62.79538923694242, 69.04745117310556, 56.70954165920135, 49.144893846204205, 52.01140903657483, 35.387882571066584, 24.90670934800179, 7.643236421769665, 3.882415193703867, 3.7352620834304444, 0.46294714714730945, 0.8579924282047057, 0.3859922055515551, 0.5292309436105913, 0.2270955802692521, 0.31137499657850115, 1.1849329524463224, 1.431769913723392, 0.8952247303339743, 0.8061900530611316, 0.3729511827470795, 1.5341365433508352, 0.3009740966221979, 0.41446980809973133, 1.0809433195860156, 1.0489847054404597, 0.7036634642750986, 1.4844488160264109, 1.3562559528696922, 2.746040325972342, 4.878666573955167, 5.931466519832612, 7.315098777894051, 11.037368255276835, 16.259293210121893, 23.936140421898138, 34.01308398092947, 55.29957902046942, 61.42022978874945, 40.54999628374654, 36.96057650350755, 47.9855667391131, 69.70744486778014, 94.48821083191903, 111.6945505142212, 115.07873227519374, 111.39375963518697, 112.31709341849051, 105.2799298686366, 104.6800268850019, 109.37486863905384, 105.30937902389034, 97.0764966164866, 100.4018271353937, 102.39080613659274, 103.24328622510357, 83.97990657437234, 79.81517314910889, 86.26079620853548, 88.72832006023776, 82.5940155213879, 86.99552674447337, 82.35693962343278, 71.68621001705047, 45.451829356531945, 18.020676682072303, 2.4226159001550367, 0.3238487772403225, 0.43515770605975584, 0.30260580261388137, 0.29086896789170086, 0.6022725855150531, 0.8029632294370282, 1.0126829856345732, 0.9083824436510763, 0.6655399260982391, 0.5266383182137243, 0.3362089623847316, 0.1890796314804785, 0.1575132543521543, 0.16767323497802983, 0.2346753001573586, 0.1770027150069514, 0.18689974361369688, 0.3947522677481175, 0.35655328523247476, 0.14958142513229003, 0.30913345395557346, 0.4161924640497854, 0.23074687789044074, 0.2879579563535029, 0.35740771841618324, 0.4034885199319932, 0.5873126656778398, 0.5488483715922602, 0.503523790788266, 0.47380975297381805, 0.3439609754470087, 0.2892870269715786, 0.23794269579793179, 0.17357097818486153, 0.19523511730855514, 0.1361709640872094, 0.12419003843059465, 0.22429693850778767], [0.03945956104284814, 0.033326230477541685, 0.02423441007493004, 0.049187410622835166, 0.1079869723968929, 0.09310828852317027, 0.09737430275568078, 0.06532147511719696, 0.07488717069669117, 0.04537797330187694, 0.10745852494672423, 0.09420908792244811, 0.1054428403656329, 0.19835027595681531, 0.2663764627950807, 0.3508615277467236, 0.05082100502125198, 0.10513871878145203, 0.0900487555190921, 0.06275721029528687, 0.1581044750468385, 0.1958799181926635, 0.16771844948732084, 0.1965811491132744, 0.1366053665837934, 0.13483334392789872, 0.13547042264573037, 0.04677701073007719, 0.1397526549595979, 0.08421783816189536, 0.042342621863128684, 0.04966264177534369, 0.1068319569552137, 0.0554137327708304, 0.016669378007551836, 0.12158410608648293, 0.13559414584550167, 0.09217441968259313, 0.15855223811682195, 0.3294367144905752, 0.34349672616489474, 1.0172312189975092, 1.5129475319577803, 26.67333310650241, 64.51403848586544, 95.05369109492149, 100.46174526214601, 83.96300115892964, 83.32674564853792, 66.73488447743078, 63.647331960739635, 61.74032265140165, 72.66298217158165, 77.92694414815595, 77.79308149891516, 79.31873444587954, 82.43358273659983, 81.17920875549316, 98.07541447301065, 103.54999203835766, 118.10464474462695, 112.7626746700656, 92.46684874257734, 79.28883814042615, 70.76846953361266, 74.91569349842688, 68.55578207200574, 62.91566087353615, 61.55667335756364, 68.79517216836253, 58.11277351071758, 73.09631778347877, 72.68424926265594, 47.25005172914075, 40.67786162899387, 43.612782955169685, 36.26141009792205, 13.132521894670303, 7.659221551110668, 7.741243704672783, 6.718837714964344, 3.64336904018156, 0.42546231179468097, 0.045690705714326714, 0.23827977448461518, 0.1291344924679687, 0.04240362927497875, 0.1670788426793391, 0.5384081253601659, 0.8792481811777239, 0.8087258653775339, 0.9049827293042214, 0.2242364482052865, 0.6903635037522162, 0.672872674561316, 0.731941914606479, 1.0278060515561411, 0.8498665029483458, 1.7495105800128754, 2.9287200589333815, 2.906586124051002, 1.817828094766986, 3.9541131786761747, 6.176684767969194, 12.09197102054473, 13.44269508315671, 20.146018843497, 40.47684015766267, 57.42027513442501, 65.04288773382864, 43.4282942741148, 20.207123487226426, 14.882559910897287, 20.441569435981013, 40.848178786616174, 55.7156797378294, 63.06844111411803, 63.078596130494155, 63.7237750330279, 65.00848462504726, 60.17586569632254, 59.92373574164606, 62.57815660968904, 58.62191284856489, 54.799833759184814, 42.44022177111718, 37.78313282997378, 27.789427849554247, 32.57410953121801, 23.488890201814716, 32.56431145052756, 42.21632895931121, 32.79352691865737, 23.718454760889855, 11.171749637972924, 2.4680163543070517, 0.17193461437859844, 0.2084628204184194, 0.21727090100607566, 0.15490233477565551, 0.16793790303411024, 0.09016951395859642, 0.07199124342972232, 0.4652795171545398, 0.5778462704150908, 0.5291855299184399, 0.47877501395921557, 0.33879150606451497, 0.2896106837978286, 0.10477565439237703, 0.08326034316973341, 0.06340970270215504, 0.10239287579972899, 0.07148239250865675, 0.1735941140401748, 0.1358106729364203, 0.0761052121919009, 0.06224899139675883, 0.06601250940753568, 0.07515886377903723, 0.14877873352698742, 0.0381576175981712, 0.04393779695214283, 0.15210953060417406, 0.35344054742205533, 0.22346697417238068, 0.16577600291179073, 0.12491196904691959, 0.3807938393325575, 0.32542078966094606, 0.2977374364291468, 0.25351704879393505, 0.12537398135229466, 0.1092706906098512, 0.1189707963156604, 0.046083655193327897, 0.004096113646688361, 0.048537258614575675, 0.06946784173769337, 0.10767995500035825, 0.149366905191733, 0.08112755438853657, 0.1446689782483924, 0.16803207056176278, 0.1359343961361916, 0.019002144465283043, 0.03527544927032244, 0.0632764685208038, 0.2196652015611049, 0.17278582999302497, 0.24678685912682166, 0.13283753166756324, 0.13718410004531184, 0.1053373883628557, 0.10593787106054445, 0.06550555838452232, 0.2892157807946205, 0.2286530523410728, 0.2160311102746956, 0.27670942607425875, 0.12587746199701103, 0.13619241454908926, 0.20492479655771487, 0.08390283812918971, 0.13142443652595245, 0.0822191147674476, 0.060982073491979996, 0.07465384329759306, 0.07659921632899393, 0.048166747850876664, 0.0496954303385029, 0.16660264242560635, 0.17958004928884969, 0.09797295450323051, 0.375532592616735, 0.20778101748756825, 0.2766626640673607, 2.242179762932562, 10.923607753169152, 59.505426729879076, 95.65302141251104, 106.43301256241338, 97.42556402760168, 87.8776599514869, 96.88762664794923, 105.30556648008286, 103.60310093049081, 97.986784596597, 89.57387324302428, 90.19575718910464, 90.66167985239338, 88.45888460836103, 95.0521299915929, 102.59866037676412, 117.04325137599822, 117.96666360670521, 127.49917630226382, 129.5850770704208, 124.61584983333465, 115.0646823452365, 105.69804668426515, 98.74280575783023, 90.0477034045804, 81.36247757942446, 76.1235873929916, 76.14128512720909, 64.2593119221349, 58.951756723465465, 52.31445527845814, 46.46850770519626, 38.96685315716652, 39.9954515887845, 32.2721968543145, 21.221648454666138, 9.436447966483332, 5.9184432702679795, 3.558534056909623, 2.171394709617861, 0.3226112694509568, 0.0779532460916427, 0.14144786964020423, 0.12481733420563322, 0.09061036691550287, 0.6473737750803271, 0.8182195333703872, 0.8231587167228422, 0.4257545590160355, 0.5411909244233563, 0.2603872486900899, 0.7877596323528598, 0.5798059846124342, 0.8634824594182353, 0.29601214513663326, 0.28152051952577406, 1.3464177904590484, 2.5616710320595772, 2.9920960001407133, 2.433411243461794, 2.8911388497198782, 4.847668082483353, 9.43640580100398, 18.791716598695327, 22.485885235571093, 31.086566332847845, 52.23351324758222, 63.66982283130769, 52.05249194175967, 34.46665510054558, 33.623588700448316, 52.67981229289886, 73.05693718694872, 84.19459358338388, 87.93830763909125, 82.72334391070952, 85.3162580920804, 84.30631837537213, 85.89265038890224, 88.26052250400667, 83.60628512597854, 80.24846169256395, 80.8656152602165, 78.5874242167319, 68.92499477632585, 58.15396231989707, 56.16464599486321, 51.705915235704, 56.69440523270638, 61.59607748831473, 58.77393607170352, 38.17984134920182, 23.41041534177719, 7.396427652528209, 1.7370465133459339, 0.22119549283337211, 0.04664347777443548, 0.14061208303657272, 0.23801078569264184, 0.18875268047615407, 0.47098926238475314, 0.6478301183350625, 0.9979633109704141, 0.8336085850192655, 0.5422837335255839, 0.3308506676506612, 0.20006003098622446, 0.07260340130737714, 0.07947526361432769, 0.1004452428089515, 0.09380405723688104, 0.13229586153982148, 0.2764701921372645, 0.10013729844602848, 0.08657961828453888, 0.1373071337659513, 0.06229766479302799, 0.17257458890878385, 0.1775463309980208, 0.14212001986320943, 0.09991014571560007, 0.2235573265821703, 0.3331615259089778, 0.17820034025897905, 0.2054881010084383, 0.21172048674235422, 0.25347610905526147, 0.17957421169886667, 0.18214658173101564, 0.05587680227754097, 0.056300150125377604, 0.058281992772413846, 0.058343946302850405, 0.07486545976491706, 0.1787780011974035, 0.11706761940712891, 0.18033688287100486, 0.1954961234643575, 0.27580770994386367, 0.3037515943569522, 0.15443273819983006, 0.36896758682785497, 0.17563860352721908, 0.09778154743534904, 0.20150827424180126, 0.3081400217788835, 0.332165826112032, 0.44316265071111344, 0.5364602395603734, 0.5731622862719721, 0.5849060464289881, 0.3383188604587509, 0.39982787603812836, 0.329592383556789, 0.38259319600559055, 0.30162134898766396, 0.29105846740065083, 0.48067819086774705, 0.3286689105293443, 0.1821604785659621, 0.3494839790847994, 0.3028655677072464, 0.241863273324505, 0.17131442023861795, 0.15013401967383203, 0.20676713076330003, 0.2209575459240906, 0.17523786293402796, 0.14769165476243343, 0.3047639948706473, 0.2926815625640654, 0.1915325224399567, 0.6592603953134629, 0.2916669863606653, 0.2830125830106197, 0.8057280713992735, 2.571597815521302, 37.63380819751371, 91.15017967839395, 122.90330379239975, 129.5307836224956, 106.09300582639634, 104.10265399563698, 100.42117226508357, 102.94844165925058, 96.41574198199858, 100.62254674973028, 101.92946480166529, 104.39218767227666, 103.646513723558, 108.22536314687422, 114.25385782795568, 129.50772793062274, 128.65799350123254, 141.65246071354036, 142.08812621331984, 130.72036004835562, 119.67289463166269, 112.2983366443265, 107.89209504281322, 101.54690819401895, 99.9328136444092, 94.55662481246456, 100.22271602384507, 84.80099201202393, 98.10089418965002, 95.82917505694975, 77.29425799462103, 67.29943906107258, 64.88059182320872, 47.99619243990991, 31.45628502292018, 11.52877946053782, 10.17329756290682, 11.302004687247738, 5.124855608709398, 0.5480781161496716, 0.13255656126045412, 0.5305959284305573, 1.1777262101250312, 0.35744305039125107, 0.9983622282743455, 0.7363491877913476, 1.7347553588690299, 0.5441833251426297, 1.0754790902137756, 0.40790621191263204, 2.437176718827217, 0.6656349822878839, 1.5658774659518273, 2.6491957806771804, 3.0971245708004123, 5.263146613874744, 5.440656908096806, 3.708874338096188, 2.7560122166910483, 4.882461467096883, 7.537468239184349, 18.538584478439827, 28.889872335618545, 46.9870371972361, 67.55918625862368, 81.18298992033928, 83.38664808580953, 72.66349207970404, 50.121571863851244, 38.45748632184921, 48.72169756120252, 66.9456648057507, 80.1958627085532, 88.12023501242362, 85.60738425101005, 89.00058746337892, 92.15910742359777, 92.89470872571393, 89.77103510210591, 89.57567753330355, 87.78724147427468, 90.92331763236754, 87.35523162349578, 81.42601997621598, 73.88269808984572, 78.19368100935414, 64.68986265120968, 68.61673570448353, 68.50738002407935, 55.51763926782916, 32.58633555904512, 13.456354737281801, 3.4089191690568006, 0.6688941041788747, 0.42168794980933594, 0.5305480019700143, 0.4481230700208295, 0.29662382037889573, 0.5179670609293446, 0.48805050011123385, 0.7170112286844562, 0.7750512142815899, 0.6259910966600142, 0.42865815482312636, 0.20068909642436814, 0.2279231850538523, 0.15465816723242884, 0.11844214968263142, 0.2706161465856337, 0.1911165213753139, 0.27928688293022497, 0.316339951128729, 0.21712028812016212, 0.19717201740751344, 0.20404863712047377, 0.22582122365072851, 0.25493808060644135, 0.2571870236387176, 0.2470105108354361, 0.1369072358694769, 0.2535442295934885, 0.5197996045312574, 0.4283227002428424, 0.6011786119591805, 0.3239529039109907, 0.35143235518086346, 0.44643206882380676, 0.2846853819585616, 0.2535561652433488, 0.12948171415876958, 0.23559212354162049, 0.2672021217163532, 0.1326955296099186], [0.054890081031067725, 0.015596415370612618, 0.07219435632108681, 0.03315428204293693, 0.05013083257982808, 0.14331143980305042, 0.05176166906171749, 0.06013294929758676, 0.04304204864667789, 0.18153810873627665, 0.1479733299704329, 0.12628743394968972, 0.07517948686595886, 0.08769067560112284, 0.1300089358682594, 0.13853413082899588, 0.15935045576864676, 0.18988811471048864, 0.16569101311747106, 0.20864464372636812, 0.018712306590450388, 0.1565189948005061, 0.01976843923330307, 0.19824984182994213, 0.23254359922101422, 0.1608626980094179, 0.23854176123296064, 0.45308609402948813, 0.2855062604911866, 0.17469239301018177, 0.06182961188436997, 0.09916847301346642, 0.04793647714259644, 0.05809323636875038, 0.15574952076760032, 0.03253691093695741, 0.1486378806012292, 0.18133080534396634, 0.1585855169762527, 0.3139097670153264, 0.28573884478499817, 0.11102377557225766, 0.34396198668306877, 0.49352235971919955, 6.905354261398316, 30.83528753249876, 62.1418752977925, 80.98827562024518, 100.05388936688824, 73.47745449312272, 73.40179197249874, 62.59759587626304, 53.78756415459418, 57.31179414256927, 50.27124950962682, 55.35120917904762, 57.367746753077355, 76.25186458710702, 86.92617139508648, 88.01861424599925, 81.33234593176073, 77.35815340472807, 60.02015152285176, 40.234547507378366, 35.59974155118389, 29.248043567903583, 26.773865415203957, 28.604492448991348, 35.36622716534522, 37.85360997722995, 49.60205001215781, 52.573547440190474, 65.48580961842691, 79.94987518556657, 77.4201503876717, 68.2992825969573, 47.40185137717955, 24.65783888293851, 17.13544088025247, 14.58216421065792, 13.566706699709739, 4.383852712569698, 1.2030422903837696, 0.6761273837858631, 0.39596596552479657, 0.030420414930690202, 0.18265854296905382, 0.42960470241885035, 0.3370265007740067, 0.6131161617175226, 0.4756658614402818, 0.20280167580612246, 0.03247913258570818, 0.7273685535596264, 0.46442781124384175, 1.8627950044408923, 1.801876673294652, 0.3680971883718045, 5.497539120335733, 6.371108322374283, 0.8549597006170981, 2.2663685294889637, 5.635608021290072, 15.247638437055773, 33.93323629133163, 44.13726660513109, 63.259660582388605, 76.25800701879686, 90.44799697014594, 90.227245976848, 72.36904759560862, 45.126876677236254, 20.9197397001328, 20.388976335525513, 18.816782505281513, 21.458447825524118, 23.328220113631218, 31.00381608932249, 26.41014599031018, 33.43252612698463, 32.50848043349482, 32.044668005358794, 32.97105927621165, 26.2865383778849, 30.47084639149328, 24.74661192586345, 20.78240183091933, 22.18050518343526, 20.397827163819347, 20.18867265793585, 18.680136934403453, 9.530021009906646, 3.550555220534725, 0.20803891332639804, 0.5322753157346479, 0.06161125767375193, 0.32887648971330735, 0.4030963135582786, 0.37542751599704066, 0.2514924469494051, 0.5068128513953378, 0.16803818394339856, 0.1301984506989679, 0.11480126319633377, 0.16027929141156136, 0.1561059048699756, 0.04594479792661244, 0.13074678579165092, 0.2192640013151592, 0.16262526714032696, 0.18125894629666883, 0.04350964956346058, 0.06282079942344178, 0.0893736711793369, 0.15839742706908336, 0.04674719841850381, 0.07585256405535244, 0.2226729853258979, 0.1373168324390727, 0.07193849061525638, 0.03185870861935039, 0.04718466909722455, 0.01861783262762812, 0.0662036560055229, 0.1250846988912071, 0.18469262898208635, 0.21165754495849534, 0.14328375338546692, 0.14403252772265865, 0.2145212582282482, 0.16068530268967152, 0.14765721144935778, 0.05216754627444091, 0.036823146060229316, 0.09371275487806528, 0.10635970971517025, 0.0691127829674271, 0.021533569013099038, 0.07000495364228565, 0.11946794907412223, 0.07941743163692375, 0.08922483561740768, 0.05517056880278453, 0.017830407239436623, 0.02864838078347666, 0.12193757905474595, 0.12296984422831767, 0.09356522166560735, 0.06793867661467484, 0.12128517091754945, 0.11333625793697373, 0.14776314608752728, 0.18745298166909527, 0.20519177819932663, 0.10866687542969182, 0.10462997511269585, 0.14575044924934066, 0.2787145539637535, 0.12007243075077573, 0.2584688419536237, 0.2832336453420501, 0.15420686483623522, 0.06349609060693653, 0.2909346982356041, 0.3039837189980092, 0.0851841355043073, 0.07784789368029564, 0.08282127519769054, 0.11535284650181571, 0.15703087942975183, 0.1838912550480135, 0.0970346500135718, 0.30145538369974784, 0.17039286243098398, 0.20419739607361057, 0.20642456688707878, 0.16753798981587734, 0.22033673891377067, 0.5410077987659363, 3.1794502177546105, 21.186751127243042, 61.4047364265688, 96.73616824611541, 100.28175553967877, 108.62142055265366, 80.89837489589569, 80.69745540618896, 72.80280682348436, 77.96410468316849, 79.60176483277353, 79.85533821967341, 93.63064735166489, 91.77219698506018, 97.9702792629119, 102.74852629630797, 104.23910540919151, 105.6035489420737, 102.05766354837726, 96.00618377808603, 88.07997580497496, 80.62337752311461, 77.65597897191202, 75.92843378743818, 74.60780312938076, 70.42411681144469, 70.8965035407774, 65.62314356527021, 65.47328156809654, 77.80289526908629, 57.97349014589864, 57.008951863934925, 54.63237993178829, 48.81788584493822, 24.661347443057647, 15.759944108224685, 15.882004345616988, 9.068518857802115, 1.7206351939708957, 1.030360556417896, 0.5637599972467269, 0.3251130368200041, 0.07019495110838644, 0.6111300940955839, 0.09342496628843008, 1.1186165819245002, 1.1250680228394847, 0.527173108871906, 0.2512461956470244, 0.33337103563451, 0.9697817554396968, 2.215800842931194, 1.9364612837952955, 1.1730930329330507, 2.43878121337583, 4.533457794497091, 6.704243556145699, 3.462511003017426, 3.213333857636298, 4.911949355756083, 8.736709875445213, 20.42709392886008, 23.986970416961178, 36.045969993837424, 50.488046753791075, 77.7938267492479, 85.44469218100272, 74.08063657822149, 56.257088415084354, 46.07243460993613, 48.269495348776545, 53.81626413714502, 60.77292496158231, 62.769336854257894, 68.50223387441328, 67.09087094952984, 67.66523145860242, 66.58832903831237, 63.52887245916552, 63.64051095900997, 61.77011697523056, 63.645280561139515, 54.06657803443171, 45.27054525190785, 46.37599075994184, 45.16537474047753, 37.77983803902903, 36.61273287188622, 28.251406569634717, 14.44511071328194, 5.956392691981408, 1.5535895382204366, 0.4388134469909053, 0.3300715868751849, 0.2968005108977518, 0.3938902349722001, 0.37674671940265164, 0.5860275991501347, 0.3644742972908482, 0.47544197990529, 0.3155624944596522, 0.265612734421607, 0.2906863938175863, 0.0810767321156398, 0.1888297335995782, 0.06743736399878418, 0.16615426648528347, 0.1172833497666063, 0.01281764305707428, 0.10791601733334603, 0.04928353550513426, 0.1344603050740496, 0.043712597745921344, 0.08475984536832379, 0.12349330444609928, 0.055504452902823694, 0.0723965575678214, 0.03316655094104429, 0.05757157645759083, 0.07256763266219247, 0.04627362201591173, 0.1671352420723246, 0.2716182508776265, 0.19861057731172732, 0.16546785170512815, 0.3961339226413158, 0.10057551606047539, 0.1485663433108599, 0.07806498767627824, 0.038539891641947537, 0.06112170450749898, 0.12349894285322198, 0.11202151316308206, 0.1858983747661114, 0.161458331370546, 0.3190724641805695, 0.19744704297233015, 0.1763108456807752, 0.23630901329940368, 0.10054262790588603, 0.15706207453002854, 0.10843843567155062, 0.34080573507855016, 0.2939584166292222, 0.3604713959559318, 0.264760967223875, 0.21871857735658848, 0.2545089641165349, 0.16512297424337558, 0.20833309108932174, 0.23486804787910756, 0.22455514078178715, 0.2495911546171673, 0.24103856435225857, 0.31835834766107224, 0.1904950555293791, 0.4071919421755499, 0.5206483686643263, 0.3479325897510975, 0.34201146554081674, 0.4813158211688842, 0.40892035910679453, 0.3540080347128453, 0.36662492059892227, 0.2224501763140002, 0.28370702639222145, 0.3002633815330844, 0.21908113612763344, 0.23122937538691107, 0.5521593423139665, 0.3311424552192611, 0.4509134380327117, 0.45744936312398604, 0.27697029433423476, 0.41506879692596776, 0.3695558810666684, 0.6458271967787897, 8.68969830774492, 43.687319755554206, 85.32846450805665, 108.01459066329464, 124.89858212009554, 90.3619166343443, 98.594524475836, 88.30885394926995, 85.56688970135104, 91.86019928224626, 87.43374178486486, 97.52961666353288, 98.76272355356525, 111.90320491790773, 113.8345564565351, 114.00095908872544, 112.64190489246, 112.59893924959245, 105.18774632484683, 98.39797450650124, 93.35062934506325, 89.95446866558444, 89.85601717425932, 88.10684404065533, 88.65960013481879, 85.89996168690344, 97.36907405237999, 93.65887272742488, 94.18340344582835, 105.02160256908786, 101.9645151015251, 88.56210570181571, 72.37716690186532, 51.23393251049904, 33.3272732457807, 23.47874499136402, 16.263242056292874, 7.665514013459606, 2.6799329442362634, 1.1898408181244329, 1.0326426404137765, 0.15811846381233585, 0.7446180344108613, 0.38404202148798977, 1.6007280926550589, 1.751810682396735, 1.2133139972725224, 0.39663990839354457, 0.4792547382174, 1.577062594794458, 2.725096585289125, 2.909691905783069, 1.440128852282801, 4.402049078095344, 9.646841941341277, 11.212997282705, 5.468511619875509, 5.952452671143317, 8.634766494074176, 22.351067489193333, 46.35559835741597, 58.842597161569905, 79.8899256798529, 89.07231976909023, 106.03002825090962, 108.17997347924018, 100.57060672390847, 86.39881657015893, 64.80522348034766, 61.527263426011615, 57.89325021928357, 57.44878292083741, 61.27105420635593, 67.61336988018405, 70.16396168739566, 72.1628015272079, 71.29305516519855, 68.89178799044701, 67.92068758318501, 63.7993630286186, 71.98321188649824, 60.46789007802164, 49.667898762610655, 47.37719928064654, 42.88708171536846, 39.18306204580492, 31.195874944809947, 18.69267086828909, 7.724832998168084, 2.5792194710623835, 0.9392611802585664, 0.27971960003337554, 0.4977182539240007, 0.294588906990905, 0.5496808333743004, 0.41859991067359525, 0.8468603126464352, 0.4600582908718817, 0.3399031915731969, 0.352520996764783, 0.33730137312123853, 0.26675904710446635, 0.1712554927554823, 0.2352524707995115, 0.24590060265073854, 0.4449712004392378, 0.28194284847667145, 0.22647734731435779, 0.4560552976064144, 0.3776362394132922, 0.32195889961815655, 0.2645060438061914, 0.22515664237641522, 0.2740864942391073, 0.22152077376602158, 0.16220310672877297, 0.21029343347876303, 0.15978141086957148, 0.11007254717931633, 0.1602642454447285, 0.2416129617561256, 0.3692727043263374, 0.3519676361353167, 0.3107262426807035, 0.3745261982323662, 0.2084125497288281, 0.26738319425813617, 0.22725082032622831, 0.2090449093450462, 0.1587822636769664, 0.378490366161831, 0.1894998613504633], [0.024269606069391294, 0.07764318732604866, 0.04788157162106326, 0.09782906786929216, 0.08130432917706429, 0.11997637864682945, 0.07962945413084761, 0.09652611318855517, 0.04158766136594838, 0.02716566931696669, 0.030513126891286626, 0.08494188318089133, 0.03224940963029381, 0.08800648768702823, 0.04004144312573537, 0.05666332942764125, 0.047002244410255266, 0.06498905424509319, 0.059942584109282306, 0.04533675394111103, 0.03490557052916096, 0.07019230810504767, 0.04364976704481148, 0.24399764024682585, 0.1485474975479226, 0.3521678302316897, 0.2821031140704309, 0.20809188064548279, 0.1600130911796324, 0.01341142631586521, 0.05878600201779797, 0.050762839795600985, 0.009222623212413203, 0.09770816387308222, 0.09569250227462861, 0.13542412029158685, 0.05095148894695505, 0.21551476701373057, 0.15960992974860055, 0.23575988147527943, 0.21981120259771425, 0.09973782189791242, 0.09746136098739602, 0.04021499651454149, 0.08402909707999037, 1.0124079294262394, 8.132295185519803, 17.49805223557257, 32.68033712140976, 54.37783379708567, 56.62318283511747, 48.50486893807688, 38.62444200823384, 48.334567469935266, 53.387721661598455, 42.53795546870078, 50.99663695981426, 57.61216532799506, 54.46355327483147, 55.897281554437455, 38.89075525345341, 33.272646396390854, 25.710632454964426, 19.21714275113998, 17.11671744623492, 19.207548633698497, 20.966817948126025, 26.580180737280077, 24.864067300673454, 27.078009920735514, 28.48887666579216, 35.52766407689741, 45.67582807233257, 51.886144222751746, 51.100834723441835, 64.16319816343247, 48.97017186687839, 30.071645206020726, 20.029265572947843, 25.070670304759858, 23.709143054100778, 5.486065697285437, 1.2029894609605114, 0.9825927067187525, 0.6074443531613196, 0.5470280853971359, 0.271534655363329, 0.29208079641384466, 0.17999434963830058, 0.2862825527066185, 0.12335956847715764, 0.18947586747667483, 0.058918738241998427, 0.1702415447441801, 0.3654554414172327, 0.9156710041626808, 3.1137875347368182, 5.2106236257860745, 4.303259772639121, 1.8498790071856592, 5.871395420643592, 10.609990723671453, 20.712430669415383, 41.50352839500674, 63.49316712348693, 72.50305145017563, 73.56760624916323, 77.94860347624748, 79.2115125348491, 79.71606269959481, 53.252458726206136, 33.17876838868664, 20.556855740085727, 10.89340256106469, 12.433134855762606, 15.863445651146675, 12.713634333302899, 8.075078100927415, 7.899018103076567, 11.42806770340089, 11.974496033883865, 13.307169348962846, 9.261436712357307, 11.268213468213236, 14.936246372038319, 12.766472581894169, 12.53020175041691, 12.347264366765177, 7.9316840921678855, 5.137692545690845, 2.2797778873674335, 0.648715409540361, 0.2257571633785002, 0.09356275486249117, 0.049385026833342935, 0.16355969522508884, 0.19004549981365282, 0.22236345516097164, 0.18127933955721318, 0.2799915612464951, 0.26102717725499985, 0.19966546506170305, 0.16125035382086234, 0.08951581113280789, 0.042365884122949456, 0.0484107660069581, 0.07564359059136722, 0.1885837734106087, 0.10347386416528495, 0.12068425154974385, 0.22220660631935443, 0.23343558603477096, 0.13783453933654294, 0.05454155699079556, 0.21618307147535587, 0.3035055575591903, 0.4358539574088589, 0.2018087798909795, 0.1939570681462365, 0.08208072098392634, 0.04729761727034085, 0.018926885902821537, 0.02357786314772262, 0.05018270822362073, 0.025093700256078474, 0.02295234852710799, 0.08174843800764892, 0.1571067221342556, 0.1307431851784068, 0.10299795502496344, 0.056822081997750275, 0.12731555458759108, 0.06426376816365989, 0.047898038680995667, 0.07866931613534689, 0.00796370230795395, 0.07396919051966361, 0.04844028720512025, 0.03607883801563613, 0.06749225419855888, 0.11795628906017351, 0.04338012707810249, 0.046463519890582373, 0.04095464291411542, 0.05192397244935555, 0.04125095423190825, 0.07025211658929625, 0.01832584587616786, 0.030644035995787675, 0.07210075569849822, 0.07655231642626947, 0.0843442733129186, 0.022569139856064034, 0.05787512347582848, 0.09385373803877062, 0.06727397276629364, 0.066127683066072, 0.021071346033544793, 0.054302257936327696, 0.23710744545584728, 0.22392101916334323, 0.4399000661027047, 0.24860213510692122, 0.49260449445536064, 0.2643772797478784, 0.17215799029556014, 0.1643197310547675, 0.05618009265632399, 0.02903469019539414, 0.168564762139032, 0.04028651465271269, 0.07177110806468033, 0.25313872393340836, 0.4013775186913629, 0.2625622642376731, 0.1552218853706314, 0.2259573115095977, 0.04248238311359479, 0.17169711180031302, 0.08329126247835737, 0.7422728860570539, 5.136923761137071, 21.12873338883923, 44.283837733730195, 65.73868482343613, 79.3182166930168, 83.1357732895882, 71.41940255318919, 63.78186925765007, 71.22745744643673, 68.64941689275926, 60.23570145330122, 69.33552572804113, 78.72902962469286, 88.90335975154754, 88.17026876634168, 80.8620459033597, 69.69408527497323, 69.02853750413465, 60.900641256763095, 60.42421056378273, 54.62915182113648, 49.74651482797439, 53.40680791485695, 55.09794958176152, 64.46593061570199, 71.54414961414953, 73.19108224684193, 77.14888711129466, 81.07590136989471, 75.59590308896958, 78.8418762145504, 62.29344352599114, 39.56728566077448, 28.491891007269587, 24.847461946548957, 22.64172688607247, 9.06419542527968, 2.0209623753063144, 1.1542011821462264, 0.4992803072016086, 0.32174988018889583, 0.4422874412228985, 0.3619896596477878, 0.9993321568735185, 0.5593854513379836, 0.10335350409150125, 0.1503250360368721, 0.1471024718616278, 0.1859306270677236, 1.2233741413201056, 2.4818981126431496, 4.747599103758413, 3.7876372471932447, 8.48960643814456, 6.408796906471253, 4.425918171482702, 4.5185454333982165, 11.910738887325412, 29.531226927234282, 51.20528351876044, 58.23684592400828, 71.29042717718309, 84.51880885708718, 95.40760655556956, 99.4939474905691, 84.60419101099815, 66.644316950152, 51.15826606750489, 39.25126814073132, 36.662221416350334, 39.10498726752497, 36.38157190815095, 41.13038939814414, 39.366566211946555, 38.19316956304735, 42.18846444160708, 42.325523822538315, 40.31076308219664, 34.5547515346158, 40.16334864401048, 30.211844444274906, 26.37033981661643, 27.827123788095292, 21.48370985061892, 15.201982048250015, 7.893636120903877, 2.5385932768544843, 0.6853451988389415, 0.1557249446669894, 0.1723010035892648, 0.2218208044406868, 0.16413442970764253, 0.38374615833163267, 0.39379364660670685, 0.4247366733128025, 0.2666822238074195, 0.30348867298133914, 0.11149943956444341, 0.10743386457644163, 0.06079696749727573, 0.10582098902593698, 0.03553406523180104, 0.08435618598014118, 0.05587497132740194, 0.2419716594440322, 0.3427092184222514, 0.2484350972959111, 0.3102897564249654, 0.08491507776442074, 0.17115141205008955, 0.012021693983115258, 0.2241656157158075, 0.3003552507969641, 0.20415634908262761, 0.039306485184258035, 0.04544862576069371, 0.027838679473666895, 0.07980380042065537, 0.0229348108593014, 0.15678088961830064, 0.06565864573443128, 0.22277910382516924, 0.09360062258858835, 0.09807578648530668, 0.17027868468674923, 0.09030806095970255, 0.03395168764156199, 0.0683771700207745, 0.044708182629678524, 0.03266475185932171, 0.03691615296467658, 0.14984446908197097, 0.20820713091281154, 0.21814698383452433, 0.1637628004555741, 0.21954654986339234, 0.23015447742035314, 0.2230888638164728, 0.3480697194895437, 0.2276587315023907, 0.19021403915699453, 0.147844382051018, 0.173278225345477, 0.18149540699537725, 0.19985563872802645, 0.20997716174010309, 0.20508539923016103, 0.2023617881200006, 0.31166948077659457, 0.17178046216647472, 0.1671916874305856, 0.25886432718365426, 0.12378007413879519, 0.1627018146457211, 0.3864301320525908, 0.23097288914986197, 0.5621965650108554, 0.45502343845944254, 0.4833311839930473, 0.3847340133882338, 0.4367668890664655, 0.3392742333873626, 0.17175413938539644, 0.1473452451248323, 0.33277112750276444, 0.28445816028022, 0.2275443698970541, 0.38053775146122903, 0.5898637384656937, 0.3292364591071683, 0.2733538077483254, 0.47546459482081477, 0.17403521214521703, 0.16940508398317522, 0.19808245161848684, 0.25549387739550683, 1.2139728328874035, 9.301481170039024, 26.463598089833415, 45.716612877384314, 77.3024243693198, 87.96903548702117, 77.8122305100964, 69.6063732331799, 79.66442861864644, 81.39935570378458, 64.39830110919091, 78.34604940106793, 86.22889949429421, 92.34250176337459, 99.75623638399186, 87.90580687984344, 75.56967812199747, 78.85348643026045, 74.51610595949235, 77.27044136293473, 73.36806743375718, 65.54006776502057, 71.2046370967742, 71.2983895886329, 83.03330529120662, 83.63482429135232, 83.58620259069627, 85.0333296868109, 88.64902542483422, 80.88932206553798, 90.60728442284369, 80.67949095079976, 68.92698734037339, 51.15779930545438, 45.260174505172245, 34.71827906946982, 17.661214990000573, 4.6457072034958875, 1.938587943873098, 1.8584986607874594, 0.9013487146266046, 1.0215553869643519, 0.9223261631784901, 1.4383438061321936, 1.108104997584897, 0.970606678916562, 0.7082492665898416, 0.1797032515488325, 0.19490315608920591, 1.5226557658564661, 3.856237050025694, 8.57492583413278, 8.81332160965089, 10.503928853619485, 7.330383273863024, 10.066240391423626, 17.96223925006005, 28.955577919560096, 52.84566579326507, 79.18832348239037, 87.32273086424797, 88.42199079452023, 91.10237383073377, 97.2085157517464, 103.81363807186004, 90.01213535185784, 78.85508675729075, 72.31294201266381, 58.306267953688106, 57.41597621671615, 59.350430350149836, 51.33123474736368, 55.32839275175526, 46.13912666997602, 39.50360598102693, 50.284769919610795, 57.043472643821474, 47.62208069524458, 44.415998074316214, 50.892690227877715, 35.910863953252, 31.835211476972027, 26.486241932838197, 18.559673101671283, 10.307435758652227, 4.013602051042741, 1.261961070760604, 0.5390423235874022, 0.21233085963514545, 0.2838323583766338, 0.2552785454017501, 0.24344334499009196, 0.449202181470971, 0.3660216416803099, 0.34024526515314657, 0.2903480587467071, 0.3159879796927975, 0.27586862925560246, 0.32749740887553463, 0.1698126887241679, 0.2444452960644999, 0.24617032688711923, 0.23132875231244873, 0.18424992209240315, 0.39966641534720704, 0.6450831108996946, 0.4513359508447109, 0.595062411119861, 0.5137284803054025, 0.5109333625483898, 0.5199428936166148, 0.6127882760859306, 0.527521403085801, 0.537182568542419, 0.30630769268158947, 0.1990307305729197, 0.15435321827328977, 0.27755766926753905, 0.1407316693615529, 0.2779883026115356, 0.20165622114173828, 0.17423468611894116, 0.1570159100717114, 0.20325356042913853, 0.2575686273555602, 0.19524328380582795, 0.18654271599746522, 0.23305323155176258, 0.11602380928853828, 0.2250404881253358, 0.09973294191783476], [0.05727113592588613, 0.03548675164159748, 0.04774836808322899, 0.05146615830580554, 0.06985195822292758, 0.04363757475549656, 0.07962227588699711, 0.05518083438096989, 0.07248563827165673, 0.10741899480983134, 0.034728458661946564, 0.06450446532858957, 0.05183236365537009, 0.01001267628218498, 0.032603173711968046, 0.026668166073279518, 0.12226982372662715, 0.07102811003043767, 0.07256514287643856, 0.07888266396137976, 0.025300630180525686, 0.03323310865990577, 0.11183767504389248, 0.14005415652307773, 0.3121724021771262, 0.45444219222953247, 0.28684409515511605, 0.09585112077935089, 0.01310090502468689, 0.1326584815979004, 0.07019169523470825, 0.040402711038627935, 0.04672832201204954, 0.0446173667366947, 0.13388838979505724, 0.03602644526249459, 0.0692835439657492, 0.04206311851439457, 0.24074369711020302, 0.12500110337690962, 0.177720723253104, 0.1382424505127053, 0.1528323498824912, 0.04816364519478333, 0.09876855979523352, 0.057695203896371595, 0.03984710960198314, 0.09664342423240024, 1.6099247023943932, 8.054786699433482, 16.449290860083796, 30.762507953951438, 32.796908001745905, 30.642963917024677, 27.63823813007724, 32.4628181611338, 50.74718598396548, 38.66821173698672, 23.9601610168334, 31.617821954911758, 24.204848274107903, 14.977801922828922, 15.589227849437346, 12.755808637988183, 12.25479547054537, 6.5708913053235705, 11.452944355626261, 12.98840028624381, 17.53440280114451, 17.62672951144557, 21.35799396422602, 20.544278660128196, 23.781663756216727, 28.746717591439527, 28.887344368042488, 55.680229356212, 52.34180988803987, 29.80386499435671, 18.880889723377845, 26.054110488583966, 30.657511987993797, 16.44800628385236, 5.3249268858663505, 1.7628489675060397, 1.293964056718734, 1.1833725845621479, 0.5195244870358898, 0.3897409802002292, 0.19436004571616652, 0.2633403337770893, 0.09763959900385911, 0.2753427865043763, 0.06725279809606653, 0.16157705967705097, 0.2480826662072251, 0.3346260102285493, 1.1065213406278243, 1.366907639368888, 0.8311444172455419, 5.257329738909199, 15.051387548446657, 28.968515857573482, 48.50721451543993, 63.930193685716205, 75.04291165259578, 78.57692795415079, 78.60953069502308, 85.19429591394241, 82.6380245147213, 58.70249009901478, 42.84382973947833, 24.705731022742487, 17.608243380823446, 18.98996299312961, 10.574347165323074, 8.758837926772333, 7.837818341870462, 3.3085368910143456, 6.041005080746067, 9.285435734256621, 28.25253817342943, 23.850940658200173, 17.488579711606427, 14.999966256080137, 18.180428935635476, 18.21111559867859, 12.510833086506015, 3.5457878247384107, 1.2038977348035382, 0.2402112506810696, 0.038500135509116996, 0.04323228360003522, 0.03079258618996509, 0.09836244126481396, 0.0947198540633244, 0.10362916550929509, 0.15152325883748072, 0.15039148650342418, 0.1486830338234863, 0.04755666607149667, 0.10174884100354488, 0.0397091141841825, 0.13741591825119912, 0.02606933237984777, 0.15854895926050602, 0.09940062063716112, 0.1153291130979215, 0.09122580364947358, 0.12906948224671427, 0.14950146087475363, 0.11137250645626938, 0.2622256758472612, 0.0823299523683325, 0.16025767241033817, 0.1350397126929414, 0.23201885963639907, 0.2533440661406325, 0.38138311416391407, 0.15865710023189747, 0.172907178320231, 0.07250279864116062, 0.09987220138071046, 0.11879871764610853, 0.10459625192226903, 0.06672768312836848, 0.10903132643790976, 0.04103326268734471, 0.019633569454233495, 0.11210825729874835, 0.09501371773019915, 0.22155592187998757, 0.24804983167879044, 0.09540702727052475, 0.10014020958014073, 0.03517103148624301, 0.0432374163891279, 0.06617728725916917, 0.019510838338324142, 0.032419557758276506, 0.022984179480361844, 0.09017308392832357, 0.025223605785398714, 0.11968413908635417, 0.08272316997810718, 0.05141440140564115, 0.039869778143662604, 0.07699190533810085, 0.0882801496153397, 0.004118047222765464, 0.022485011910659172, 0.07116946091334667, 0.055351396196431694, 0.07918896889614482, 0.05647364222714978, 0.08174715097993612, 0.09261734107689512, 0.03908873618310017, 0.08050276372101038, 0.11799708324214143, 0.18116605047497059, 0.4475652660814024, 0.3718898751802983, 0.3641877191201333, 0.34927860623405826, 0.26026305051580556, 0.23797577547450222, 0.10293264602941853, 0.21113476655896635, 0.10487446441285073, 0.0975085520035317, 0.14914679280932874, 0.09049333166331054, 0.09236891408480945, 0.2195150483279459, 0.1676103238376879, 0.26420929198784215, 0.39214995899988764, 0.04242378504826658, 0.07123381995986547, 0.03807424424937175, 0.039169087315038334, 0.12098887875195473, 0.0753211135405206, 0.6011460685441571, 8.76177970440157, 25.208329808327463, 37.283101235666585, 50.04726648330689, 47.637068071673, 52.044070612999704, 54.455108411850475, 50.55217750610844, 65.73062827510219, 65.39279453216061, 56.62626189570273, 64.6265124505566, 54.79102411577779, 55.31701787825554, 47.01887507592478, 43.84099821890555, 43.64169082333965, 41.223455475222686, 34.82437918263097, 38.177001553197066, 43.54793833148095, 46.109599067318825, 45.92875426815402, 46.20922726969565, 56.93918858805011, 63.25111373778313, 56.77118562882947, 77.9809630301691, 71.19633736148958, 49.18310557642291, 35.89259747535952, 44.62425239624516, 40.941272320285925, 13.346213602250623, 2.635702827284413, 1.3781378754685003, 1.2737410515546799, 1.3584620409434842, 0.691363524285055, 0.32438108577362956, 0.33983550004420743, 0.44627008719309685, 0.48952233887487845, 0.35492332592125864, 0.03982932487082097, 0.19350282397241364, 0.43101363004215304, 0.5128544352708325, 2.0006505039430436, 2.5962356934624338, 2.8146359612864833, 5.038152596642894, 12.983442410346, 24.075590487449404, 40.04017445348924, 65.23575067520142, 85.75300616602745, 91.4993961395756, 93.24633352218136, 94.14993778351815, 95.33253239047144, 88.32337456364786, 75.09977033061367, 57.40460918795679, 41.28249499105638, 30.903244556919223, 26.236069240877708, 30.101759203018684, 29.695191806362523, 33.33487087680448, 26.568892155924154, 28.57899312050112, 32.66934467900184, 31.22046232223511, 23.454893058346165, 26.48097615088186, 30.03467098359139, 24.586112460782452, 18.097284493907807, 9.98532581713892, 3.7195851052961046, 1.2252323641892404, 0.17157534978562788, 0.05166630643690306, 0.07762565923434112, 0.04024062981648792, 0.034045996895480546, 0.17415079949123247, 0.2613376880124692, 0.2177401758249729, 0.11325993259707767, 0.250106823720759, 0.10874671711316032, 0.11144249624903164, 0.11832199645258727, 0.04894502806447206, 0.06239015458812637, 0.12499790879026537, 0.3538672583958795, 0.16454753495993155, 0.21100105357266244, 0.16360852566938247, 0.14517784449121646, 0.2840642685130719, 0.21848522697485265, 0.2614409566646622, 0.28408216432698313, 0.5046329022415224, 0.3805783847647329, 0.4128168048637529, 0.3203437411256375, 0.24540261485643927, 0.040980544346835346, 0.15249560827449446, 0.06365677754905436, 0.09559208346951394, 0.06265195364493036, 0.10185503611160864, 0.10457631065360001, 0.10319349130675678, 0.21072061942710033, 0.041021104871986375, 0.14314539790634187, 0.1593088725161168, 0.03691021195282379, 0.03187277973929961, 0.02095096106190355, 0.06661001968407823, 0.14865626671141194, 0.09580946857890776, 0.09653824802127578, 0.11075837207176994, 0.1582294699525641, 0.15982555285576852, 0.20786485815000152, 0.1985642749575838, 0.1981815067870963, 0.15977587971475818, 0.235467542323374, 0.21290007828464433, 0.1313545080202241, 0.11859968034250122, 0.21094537430232574, 0.20133257963724677, 0.21111311691422618, 0.1814632925895914, 0.11279045093444087, 0.21921094206552352, 0.21197039994501302, 0.23200954400723983, 0.3013813489627454, 0.40190728381276136, 0.46080930218581234, 0.7096869991190973, 0.5309238140621494, 0.6415792085951375, 0.2950629315549328, 0.33030365022920793, 0.17035000747249973, 0.30279839711804546, 0.20292867786220967, 0.22022876648172257, 0.267439762190465, 0.12625456111685884, 0.16496744307298816, 0.24218049501219105, 0.3063868755294431, 0.39480083772251684, 0.3678682506565125, 0.22461020718178443, 0.17383500272708555, 0.2513166450925412, 0.1565186883653364, 0.15360890256781734, 0.13172806781386176, 0.13438994755908368, 2.807344029988012, 12.311542361013352, 24.85067436772008, 43.03810865648332, 49.301494475333925, 47.84596173994003, 49.98953703911074, 50.19412394492857, 77.34309934800672, 74.13193333533503, 59.63924231067781, 75.15069838493102, 75.2146016397784, 79.39746425997826, 69.56524325955299, 66.12103354546332, 65.10039752529514, 55.92225136295442, 46.03612130688083, 47.351597970531834, 60.98670982545423, 63.789831669099875, 62.73001509328043, 61.250877534189534, 63.636404237439564, 74.43266930118685, 67.6879027581984, 91.97836460605745, 96.41435346295758, 78.51270306494929, 63.301535806348255, 64.95301446607037, 55.25755082407306, 35.04012130921887, 16.01577187738111, 5.677232703854961, 3.4115165135552807, 2.951137875356982, 1.326355847620195, 0.8344965728540575, 0.6176699722005475, 1.185496670584525, 1.0640875466408268, 1.418159656947659, 0.3571133261486408, 0.46396086533223435, 0.6096462124297696, 1.0693967198171923, 2.1399855950186333, 2.3485166891928646, 3.2567375802224685, 10.825252359913243, 20.499102761668546, 37.75358169309555, 59.549639686461425, 83.71689596483785, 96.9917969549856, 96.72364804052539, 104.00855633520312, 110.0840723899103, 106.64529908087947, 95.67974844286519, 92.87348870308169, 76.9273437992219, 63.380963802337654, 57.431661775035245, 46.324999947701734, 46.848397101125414, 47.36290224136845, 53.823728407582934, 47.239582923150834, 51.04187365501158, 63.97186494642689, 59.444171074898016, 47.04722204516011, 42.21286158407889, 40.61933594365274, 30.850014071310724, 18.350283253577448, 6.474307352496732, 1.7445171576353813, 0.5219796456156239, 0.15119223224539913, 0.14464385056447598, 0.17216920582277162, 0.17929668868741683, 0.1418016950089124, 0.2828532980094033, 0.2581326212854155, 0.21222834174911823, 0.1881715414985534, 0.33062709255083916, 0.16207153878865704, 0.18186574921973292, 0.3471213945698354, 0.22260625906769307, 0.3041037802975024, 0.20823297871937677, 0.4838876396177277, 0.20905762640458925, 0.320403894349452, 0.31031292292379564, 0.29555218594689525, 0.5870731559491927, 0.34758257950025223, 0.3821624400875261, 0.5382274511841036, 0.7973004913618489, 0.5340061228602163, 0.5911798162325737, 0.5001291326217113, 0.35036347866539036, 0.1780153453470238, 0.26619603376715417, 0.21247491480842715, 0.23617018284576557, 0.20196956642452749, 0.20132505665383033, 0.1200431815138267, 0.20433993439280218, 0.316100288182497, 0.30878322920010937, 0.37059889445381783, 0.25150035297678364, 0.18141748053171944, 0.12884697966998623, 0.07427799290106182, 0.17627264853687058], [0.12987367538434844, 0.05524784792214633, 0.04802423634476239, 0.01776276742138209, 0.07354407300872189, 0.0429665238686627, 0.06666948342876089, 0.05140890089434482, 0.059536825640187155, 0.04389889117690825, 0.044041222652360316, 0.049952636698200825, 0.0385265693729443, 0.05677860267760773, 0.09620271683219941, 0.09172874803264296, 0.03469917878148056, 0.0505927108198164, 0.02233535280421136, 0.02703366470673392, 0.08428111702444092, 0.05412302017512341, 0.18471346657362678, 0.1851195084952539, 0.2554537190665161, 0.1704056254558025, 0.2170552778989077, 0.18090334360397634, 0.13901678154305105, 0.13853348731513948, 0.1429947084116359, 0.1560403277436572, 0.07350786769342038, 0.02611842712447528, 0.0863223659595655, 0.03666648491015358, 0.06815849788366787, 0.08494638011700685, 0.04416937384033396, 0.09494186634378088, 0.04932845890101406, 0.12899314924593897, 0.04657137740944182, 0.02824287512339652, 0.05728347377190667, 0.06676044104801071, 0.11231128592044116, 0.04382056251709019, 0.03651002677337777, 0.2139412070955, 0.16209010875994162, 0.38363072420320204, 2.11643323302269, 5.845352353588228, 10.837416610410138, 17.71113891755381, 35.15856904368247, 44.92543943466679, 28.790950159872736, 27.451046935973633, 24.557184980761622, 24.56123482796454, 21.77585582579336, 18.74627790143413, 11.410834770048819, 6.2477689020095335, 4.441404179219277, 7.672637527988804, 7.944264604199318, 8.252195177539702, 10.877018820854927, 12.210534464928413, 12.793078018772988, 20.7976088600774, 22.861067787293468, 48.739497277044485, 38.378175996964984, 28.72370504563855, 23.596143491806526, 24.353845388658588, 25.412355815210653, 21.14392080614644, 12.470073776860392, 7.202365446475245, 2.9404447588228413, 2.68500040135076, 1.9127514141221202, 1.4594774140465645, 1.5476899257590695, 0.5692811622734993, 0.45799245817526696, 0.4356759492187731, 0.17754504397030801, 0.0491299846720311, 0.5942714406598, 0.3853925425679453, 0.3135909212212409, 1.113984140176927, 8.892252445220947, 24.34866197647587, 39.37255567119968, 53.05482226033365, 68.33765906672325, 69.92321445095924, 71.78384565537976, 67.36538979314989, 66.49511783353745, 65.38606374494492, 60.078528158126346, 40.31948643345987, 25.638017615964337, 14.606912405260148, 5.901671215411156, 5.440125917234729, 3.8458930244368896, 0.8319187789194046, 3.492202364629315, 3.3251062083628873, 9.064958326278195, 10.658186847163785, 13.123785795704013, 12.429246806329298, 16.51173303204198, 17.218163667186616, 10.989844818269054, 3.0209984750516954, 0.35784981243552705, 0.05000403736748042, 0.021264321666451234, 0.056374253810293255, 0.07725622099373611, 0.12996824127772164, 0.06851302039238714, 0.10518499049207858, 0.06691573473114161, 0.052255780451119914, 0.05759455909531924, 0.03628488885419023, 0.035626662279208826, 0.06268824322990353, 0.0765443567727362, 0.020090362785624403, 0.04609295933116828, 0.09364552300183043, 0.044567842982829585, 0.10251260768141478, 0.05708226077859441, 0.08292675018310547, 0.0790044259760649, 0.09405621507715795, 0.16223537435214366, 0.08044659415440214, 0.08907511905436555, 0.1432202293747856, 0.17443016111370058, 0.08893885499527378, 0.1760952225736072, 0.2680704670567667, 0.24691868753683185, 0.1117758440875238, 0.07845435952467304, 0.11532937356781577, 0.2587767480121505, 0.1228364070336665, 0.053586436871198885, 0.09303849025238907, 0.06310037172008907, 0.11091868363080487, 0.11139888286350236, 0.06590859724148627, 0.2542259099502718, 0.29833645589890023, 0.2837455452930543, 0.11168028227984907, 0.07426573549427333, 0.026203133466262973, 0.022811397925139438, 0.08023248790132423, 0.09425193522005312, 0.012108859467139889, 0.04248427152032814, 0.023807402242035158, 0.08804945755870112, 0.0538507831703511, 0.07989876467974917, 0.021694198498622547, 0.1704478981874643, 0.04858065366504654, 0.010298133091700655, 0.0790534096379434, 0.06838440955165895, 0.0744181946520844, 0.09065721319207261, 0.03159622199863436, 0.013058195622908253, 0.09250639622370083, 0.18803125547785915, 0.12625987010617412, 0.20617970986472023, 0.2852334719031088, 0.467371519414648, 0.39932470948946097, 0.4193407483398915, 0.11226473075728263, 0.21652188152074817, 0.10139822554323943, 0.07965583819895983, 0.11442032597598531, 0.08758865567224641, 0.09047191184494766, 0.11382522887640423, 0.07026248175891177, 0.05486083945499794, 0.060668889087654894, 0.0334976349897202, 0.1416651015320132, 0.06950541835037932, 0.1729401660662505, 0.023083579388537237, 0.03922021985354443, 0.022031696618444497, 0.07813467869475003, 0.009160663936317209, 0.08484307316041763, 0.2594072690173503, 0.6719158613874067, 1.6728807048451517, 5.187356616220167, 11.473682907319839, 18.43395721527838, 22.934306283150953, 34.46416047311599, 55.41703439527943, 57.080127193081765, 45.259601839127086, 52.49077758481426, 48.203317119229226, 38.65034534085182, 34.14682111432476, 33.350752553632184, 32.52719013921676, 24.645861925617343, 21.995379117227372, 27.718809496971872, 31.325379840789306, 32.38868732606211, 34.660169155366965, 36.69595379983225, 40.144195710459066, 46.35427259629773, 42.893475178749334, 70.37025482423844, 68.51160833912512, 53.80720738441714, 44.30086082027805, 47.629658714417495, 46.46233781691521, 30.719534466343543, 12.515649757077618, 4.415660192889552, 2.7195324580515585, 2.9870287881743525, 0.6520595978344641, 0.9858445967397383, 1.57104482093165, 0.9284784007937679, 0.7239063264381501, 0.29801975515100265, 0.19211140911905997, 0.16043764178551015, 0.13737971293589762, 0.19947740579805068, 0.3057691328708203, 0.4545093628187334, 3.976333650850481, 18.85730451153171, 34.1328025633289, 51.987941495833866, 78.61189196186682, 86.03107867702361, 94.83818038817375, 95.53081604742235, 89.96567879953693, 93.37229651789512, 87.83066995682256, 72.75442830977902, 63.073230328098425, 45.55724305491294, 32.048092234519224, 29.95241495870775, 26.006471341656102, 25.326999156705796, 21.17166961393049, 21.70585720769821, 15.797614551359608, 17.276916849997736, 29.134581165928996, 31.86809466731164, 28.041310694909868, 23.030963290122248, 19.300995180683753, 10.54912632511508, 4.14050200293141, 0.4511350825909646, 0.062033548320253054, 0.06895889122519763, 0.051450993595344406, 0.06908361033927049, 0.0413742407615627, 0.09721347791773659, 0.11196630886725842, 0.08499632904966993, 0.08956749142417986, 0.09754818939273396, 0.03627504462436323, 0.07058869731882889, 0.09158934301306164, 0.054837604008254506, 0.1291741145354125, 0.09250297181067929, 0.11098252173753516, 0.13749548414301488, 0.12521662689264745, 0.0961412919024306, 0.11753586766820763, 0.20276536323851158, 0.12543578166514635, 0.19305288521272523, 0.11380003224457465, 0.10589814174079126, 0.3803353203881172, 0.4435125690314078, 0.5213068365570038, 0.48952469842568525, 0.3457756845220443, 0.33169676579775353, 0.19371800274858553, 0.03428853650186812, 0.06599691185739733, 0.10171681852830995, 0.1338503152252205, 0.060837761679243665, 0.008659816718840552, 0.03279379553972714, 0.12907035558694793, 0.0978596960645049, 0.19539283949040598, 0.23203257261024368, 0.20692088460970312, 0.08766826752933764, 0.03972755009008031, 0.06254343346001641, 0.2096154609875333, 0.13225717409964532, 0.17622568734711216, 0.2170247109907289, 0.1520246174186468, 0.1816504785130101, 0.12044206817424107, 0.39474040870704963, 0.2260437568709735, 0.14843744135672046, 0.24791512277818498, 0.09440916710563245, 0.1695555589732624, 0.20671883658055337, 0.32724833836959255, 0.2592438471413428, 0.16706699896002972, 0.1225498901499856, 0.10387632845630569, 0.33030205676632546, 0.37009502310426007, 0.2300424906875818, 0.41895834789160763, 0.45891397001762546, 0.4192974796939281, 0.3861521340666279, 0.4372831403968796, 0.2613899045653882, 0.3960533608351985, 0.42581345585565417, 0.4382509545933816, 0.35904399029189543, 0.33980599033736414, 0.22491723990007756, 0.2600449606055214, 0.14037119434966197, 0.15270341728483477, 0.20540291203125832, 0.15612107341087636, 0.4597531120863653, 0.17364507420889794, 0.26488194782887736, 0.09279390136080404, 0.20296531218674876, 0.1759624442145709, 0.22144520685317057, 0.16629809183218788, 0.14944993380096652, 0.15874112475543253, 0.15907895420828175, 0.32509535551071167, 1.3054476534166646, 4.629735312154216, 10.58771558346287, 17.101216239313928, 30.47137983383671, 49.28143155190253, 64.61718113191667, 56.832704082612075, 59.46496748155164, 60.4708710793526, 64.17659305757093, 70.19032785969397, 73.33520581645351, 64.90955852693128, 55.76062617763397, 39.61516995583811, 39.778399390559045, 42.059951905281316, 48.71552375055129, 50.163733420833466, 51.00144970801569, 59.23144132860246, 60.013922799018125, 65.28000285548549, 88.03758282815257, 85.29291998955512, 85.41427812268658, 77.47891533759334, 73.08914769080378, 67.83429345776959, 55.76403079494354, 33.202224162317094, 18.359467483335926, 8.823650190907141, 7.115834038103781, 3.963557020310433, 2.9914858264307824, 3.0666852622262897, 2.6587217469369215, 2.0649854646575068, 1.372326026039739, 0.4492813030317907, 0.6836937584223286, 1.5411295164977352, 0.9851590399780582, 2.8128816812269153, 3.766513567778372, 13.173217465800624, 32.52581927084154, 49.93772252913445, 67.48461415690761, 93.09118809238558, 98.620223845205, 105.24615041671261, 100.80885148817494, 97.12535365935295, 94.65138143108737, 93.32063890272572, 80.85979446288079, 79.86825066228067, 61.448000169569454, 48.46328396950999, 47.93362279092112, 44.459708967516505, 42.86325723894181, 41.24127480291551, 40.7930028054022, 45.19477682728922, 43.50370184067757, 41.09307196832473, 36.225128173828125, 30.99835026648737, 26.785536427651685, 16.465847184581143, 5.754312180703686, 1.7515725209828348, 0.2758938488700698, 0.13014657122473564, 0.15679710003877842, 0.12734613681752838, 0.16792046687295362, 0.19531494367026514, 0.22042034974982663, 0.29360013262879464, 0.3299051925780312, 0.140169927730195, 0.13616930933729296, 0.13504539706533955, 0.20834447515587654, 0.13708879870753135, 0.09046242767644506, 0.2894886306697323, 0.3666649410320867, 0.1658899814731652, 0.207371374952697, 0.17737518695573654, 0.2059612675539909, 0.12141372047124371, 0.2621037452932327, 0.2518556951995819, 0.32927081048969303, 0.29076404448959137, 0.3286141199209998, 0.5297792174162403, 0.3949292340586263, 0.6331055407081881, 0.5397515984312181, 0.5051266918739965, 0.47791157158151754, 0.502126967354167, 0.2923379874517841, 0.3072991023861593, 0.28195293019375495, 0.1753870968616778, 0.19704329931447584, 0.12684618017726368, 0.34817353972504217, 0.26367159019554814, 0.22808954870748907, 0.4003857106210724, 0.2845907241346375, 0.44643660406431845, 0.35297522561684735, 0.17360549810672962, 0.15305428555415523], [0.10813897956282863, 0.06156270685155065, 0.1311441402762167, 0.026834516320377592, 0.1062143215489003, 0.12803240604097807, 0.08728320109507731, 0.01917473066808476, 0.07500887908522161, 0.04260111908097902, 0.06623228471125327, 0.03349336404954234, 0.09848271706892599, 0.16724281613865208, 0.13247583091499346, 0.13373328763390743, 0.1570382645173419, 0.06552127084784931, 0.10169654784183349, 0.09752140695890112, 0.01370619971215004, 0.11746731045986376, 0.16757194283268145, 0.05645022674974415, 0.07653765350339875, 0.11782433807609544, 0.12734426756299314, 0.1875448356112165, 0.276177883628876, 0.20505714590751356, 0.12773835851300147, 0.14393308951008704, 0.04457185728355281, 0.07328076092826744, 0.07935944644193496, 0.0686235975233778, 0.06781534411974492, 0.10385131568557794, 0.06796364342012713, 0.02416309686527858, 0.0114698214794419, 0.05665081921183775, 0.0020277104856851963, 0.05567225297131846, 0.0445545666791018, 0.11629187111412326, 0.0473917847979934, 0.06758767811040725, 0.014474681661193891, 0.015036765159288002, 0.07685174955235374, 0.07036101598773273, 0.1479222931929173, 0.0589868511193462, 0.09486756347600492, 0.8620951661179144, 3.671056315783532, 9.30322172180299, 18.503855812934138, 20.541128996879827, 23.45204737878615, 24.99437039898288, 26.650071490195494, 24.30264080724409, 17.08503253998295, 5.050183976850202, 6.379137414117014, 7.194301053400963, 2.793732670045668, 3.4810625881918016, 1.7943304008053196, 6.309397182156963, 12.786147190678506, 19.97295798793916, 30.066481405688872, 35.76817597112348, 30.376937004827685, 28.807010304543283, 25.17479354335416, 28.372790198172297, 25.383202798904914, 26.77147080821376, 23.509910183568156, 17.09886673958071, 11.362398401383432, 8.112371506229524, 4.691459690370868, 4.1927509154042895, 3.5482015532831994, 1.5789123600529087, 1.1826243924517785, 1.234458514278935, 1.7709768539474857, 4.054896519068749, 4.852295988990415, 2.4186555320216767, 5.385462295624518, 13.997465314403659, 30.797930878977624, 49.15950075272591, 68.12531763507475, 76.25333155355146, 67.18162675057688, 62.97707734569427, 65.23126348372429, 56.21793139365412, 48.37657997685094, 41.25048060570994, 32.20898589780254, 29.88693883342128, 22.150791268194876, 12.852056737869018, 4.318585943791175, 8.801250515445586, 11.107556127732801, 9.006379688939742, 6.333392771982378, 4.849342444250661, 9.27899226065605, 13.53075719648792, 8.157633696832965, 14.718686226875553, 10.719660193689409, 5.032221972942352, 2.387891402167659, 0.21851801553801184, 0.11100311418093982, 0.13474525913836496, 0.07345378188596619, 0.051263099040595755, 0.04437885292234921, 0.043322915631917217, 0.023511211583090406, 0.03125732959879022, 0.025416052817637404, 0.056733889955907106, 0.07046580915489505, 0.017723116625641144, 0.07799269961974314, 0.024916054042536887, 0.015679485157072064, 0.014187901434789022, 0.0746420915088346, 0.14710637891004164, 0.061432586817611615, 0.041693756882581985, 0.023513848840769742, 0.03277400365820335, 0.04777205169140812, 0.24923398910510927, 0.08931364819046952, 0.0869198685752288, 0.10952627286314966, 0.09986048023546897, 0.12177869241925017, 0.14856323299388732, 0.11612844923811576, 0.22672436470466278, 0.20334464828333548, 0.08106612945876776, 0.11712841614479981, 0.20355210489323064, 0.3350103718619193, 0.13219196469553057, 0.06210208637639881, 0.11969605175357674, 0.08951702155172826, 0.1725021476346639, 0.10218309794342327, 0.028106674266558503, 0.1874913013870678, 0.14513408554898155, 0.07198509174369036, 0.14810100618389346, 0.2437997750577427, 0.2691114886153129, 0.06491083666802415, 0.03361481962905776, 0.08421786114453308, 0.0495307942131354, 0.024059481558299834, 0.09125707535854272, 0.18708149031285318, 0.022502409767419584, 0.05794195698634271, 0.012472683240869835, 0.05746668752943797, 0.04278456649532722, 0.02033495550764905, 0.11552695530436694, 0.07069264012839525, 0.08927829323276397, 0.030083504783350135, 0.050096075170703476, 0.07144598801049494, 0.023931853225334518, 0.1234845940264002, 0.03581910356578808, 0.09791598054430178, 0.3070741483280736, 0.4237120153923189, 0.44040853397980817, 0.2670161768553719, 0.0318502816521833, 0.2827201212846464, 0.04687891574576498, 0.12614442065598505, 0.14494944303747148, 0.06854505052850132, 0.2109338063746691, 0.1579849193653753, 0.06191204677546217, 0.07562450734117339, 0.12159866941792351, 0.09630065351243942, 0.03424807556814725, 0.04048842095559643, 0.038318158983583414, 0.03777195744576954, 0.0656430941495684, 0.05098847950237894, 0.031195697825281855, 0.0496369242037256, 0.06388111490636103, 0.002915184562762959, 0.04784028714282378, 0.10878766451271311, 0.03221488587798611, 0.39091916214073863, 0.5343732934805655, 1.6390299148136571, 4.457947265717292, 13.077798947211235, 26.77070986840033, 31.072973359015684, 34.52685956032046, 37.607500860767985, 38.904820872891335, 43.16531112117153, 34.15450111512215, 25.949793092666138, 19.42435960615835, 12.988158079885668, 19.06416246967931, 22.116378353488063, 24.0208302774737, 25.985637672485847, 28.505897791154926, 31.70657538598584, 36.642982190655125, 48.28147818965297, 66.32094890840592, 61.0136761203889, 55.33294270115515, 47.167889841141246, 46.56303682634908, 46.577031843123905, 47.00976341001449, 32.569653718702256, 18.42124285236482, 11.725010737296074, 7.38965371924062, 5.379905767979161, 4.13350498484027, 3.8010725907741056, 1.9994140993202887, 1.3414984028185568, 1.6653392127444668, 2.7905398607254033, 5.145528950998861, 5.2630166853627856, 2.1816026779913136, 3.690321036884862, 11.130801073966488, 30.05961333551715, 50.84033835318781, 71.98029364309004, 90.04901347621795, 94.54085688437186, 89.72611611889255, 88.95518210626419, 79.6484096588627, 76.60234405148414, 71.88865138638404, 70.68353452990132, 55.849428638335205, 43.02505500854985, 30.62693319013042, 22.129545750156527, 23.710474698774277, 17.535493220052413, 14.385480880737306, 14.24034926199144, 15.053775291289053, 17.56865882104443, 23.821771952413744, 26.98562437488187, 25.053045134390555, 18.06238716648471, 11.8755817028784, 5.923716896964658, 1.1660620618251063, 0.2532862418241078, 0.12302903984222682, 0.02942222151755085, 0.0687990086754003, 0.01000883722407443, 0.08826689629424965, 0.021694284683514028, 0.011808502247496959, 0.04554981831461192, 0.06343733166314422, 0.07397128193969689, 0.0461527026979433, 0.0062794848195006775, 0.05958019770802029, 0.09996830711081144, 0.1400380073896339, 0.1221933221865085, 0.023319243355804396, 0.13162665309444552, 0.08745415361538049, 0.08995660280268039, 0.020536783286520553, 0.18930994815403418, 0.2859470061957836, 0.21234441939140522, 0.15625343808243353, 0.24367907024439306, 0.23435764946043494, 0.2819298249819587, 0.22487820005945622, 0.35157898440957075, 0.4413471449046366, 0.28864859993900027, 0.03210588688811949, 0.07394419307069433, 0.03647880869046335, 0.13383427334408607, 0.07224946868635955, 0.0678910795719393, 0.03895787687431421, 0.1168140136606751, 0.0558763962509411, 0.008078687317338924, 0.08528226370652837, 0.2897008676682749, 0.21829172848693787, 0.26248329589443825, 0.18642594887604638, 0.2251573012120301, 0.21371832147480982, 0.14103543854528858, 0.07989910175843586, 0.3230328936009638, 0.1948774002131916, 0.23895365606632926, 0.2105948890769674, 0.40785007298954074, 0.3405433346427256, 0.22756393578264023, 0.08470168397311242, 0.1760783073522391, 0.1595160686561177, 0.2535494083478566, 0.24342843691908547, 0.22262075345122048, 0.29032136824342514, 0.22749356294591583, 0.22118937945173633, 0.269062397701125, 0.27378680064312877, 0.4418771551741708, 0.38598990728778226, 0.5398607506386696, 0.357823244506313, 0.3770666990068651, 0.5332354384083902, 0.30451133907321964, 0.4199278168380261, 0.6579361663710687, 0.2742914380806108, 0.3143283268136363, 0.2559248171746731, 0.253627319489756, 0.270610508178511, 0.216532162420692, 0.19836437197462206, 0.2926463531630655, 0.15108809025297243, 0.1770511317637659, 0.11686626085711103, 0.20613446471191224, 0.18247249085576306, 0.14617322253123408, 0.18308801185940543, 0.22438352176498985, 0.16867140157809182, 0.16022637005775206, 0.11268608677651613, 0.11374553274964133, 0.08956664872746314, 0.2097592250474038, 0.15652121645548653, 0.207503923485356, 0.17677616748598315, 0.31050885757130964, 1.2569714481792142, 5.23796352647966, 14.234278413557238, 25.869621807529082, 29.313331419421782, 38.82338462337371, 42.734678022323116, 59.843982188932365, 61.287794882251376, 58.90731234704295, 48.99191748711371, 42.1245337301685, 53.69820471732847, 48.87856883387412, 45.91742254072621, 43.54672631909771, 51.597457778069284, 53.927988929133264, 59.344833127913944, 73.90584791860273, 84.93733359921364, 86.01133346557619, 83.90735057092483, 78.16371410123764, 85.02668519173899, 79.95579011978643, 73.5735917860462, 57.58365361921249, 38.28729860244259, 24.066092468077137, 17.372746236862675, 10.923991164853497, 7.369663849953683, 5.696167455565545, 3.103597462177277, 2.867528142467622, 3.4349948408142215, 3.8099513659554147, 7.869697895742233, 9.660227029554306, 4.558328072870932, 7.120120208109579, 16.822614208344493, 37.54397415345715, 59.85818509132632, 85.13932781834757, 105.1264867474956, 110.13627913690384, 104.20752248456402, 101.84268628397297, 90.7521846217494, 82.10873988366897, 79.8129060191493, 74.26303463597452, 72.14964589764996, 66.5985821139428, 55.31026355681881, 49.307201523934644, 48.294865239051084, 44.02847574603173, 47.88812721929243, 40.75781914495653, 40.34196161454724, 41.94563834897934, 34.01402142740066, 26.607680474558187, 26.393807357357396, 16.114125309451936, 7.695274997142054, 3.159957508887014, 0.45972292822214866, 0.17993398190986726, 0.22977227615492962, 0.1762501561954137, 0.22625669867040651, 0.1672595321771599, 0.14033691957592964, 0.18154694939092283, 0.10004328413596077, 0.11522003749926245, 0.23299163808265042, 0.1997643363692107, 0.1772366169719927, 0.18839877849865347, 0.35896263175433685, 0.2412762967569213, 0.16501481795022566, 0.22964219442538678, 0.3871962812639052, 0.29390344215977576, 0.1250826074711738, 0.27765281738773473, 0.1761430417818408, 0.3123684287551911, 0.3332268885306774, 0.35836511381691505, 0.2880722566718056, 0.27385887419504507, 0.34807171131814685, 0.40816116597383256, 0.43767222113186316, 0.6097219019166885, 0.6012264158456557, 0.5104335974301062, 0.58307699618801, 0.40348426048313424, 0.36338142690158665, 0.3018403275599403, 0.18514501922313245, 0.21773469063543507, 0.19284766557956898, 0.16710257608323328, 0.20917319842884619, 0.23652040760122964, 0.20873703393003634, 0.34212257893335435, 0.3131568251598266, 0.2675230512695928, 0.2735042367731371, 0.49556619037062893, 0.33055474320727013], [0.22584737789246345, 0.09550910848643511, 0.053172155673946106, 0.19839294705419772, 0.1069233206010634, 0.1494188765965162, 0.06497196282350248, 0.07774310051313332, 0.1397747029700587, 0.055428748094146295, 0.12608876436828606, 0.08545344605320886, 0.06867238966327521, 0.07798409645235346, 0.18772002459774095, 0.2231336952818017, 0.19292700164500745, 0.10883624214799174, 0.11714967508469859, 0.15703259546670223, 0.16510305595734429, 0.10045072799848934, 0.15799497043894184, 0.10390281211584808, 0.017003398088197556, 0.1649214011887389, 0.21364195783051754, 0.10834611441579559, 0.11455058390575071, 0.14842637904709385, 0.1088108386724226, 0.04361520498810757, 0.02894179245847608, 0.03387324023811567, 0.03752439613303831, 0.02524137327958259, 0.07081057170345899, 0.049597895854423125, 0.020988072276175506, 0.039219143500010815, 0.04560650116012943, 0.04819540336968438, 0.028442059898929253, 0.055932278534577745, 0.05914959883798034, 0.064575880044891, 0.04779982620910291, 0.07342044940038074, 0.05109912558128277, 0.08602793538762678, 0.04284786834051052, 0.07391969357887584, 0.03384396035764967, 0.030278257740240906, 0.12853150466276755, 0.09103861006517565, 0.2482457050392705, 0.1769281593301604, 0.7221642424983363, 1.6099912601132549, 6.1753771478129975, 11.763543121276363, 21.20293482657402, 26.154493747218964, 28.323627210432484, 20.885071831364787, 13.794755262713279, 19.645887228750414, 16.734354995912124, 11.404352072746525, 7.850732745662813, 7.5422834388671385, 9.75113090007536, 12.449105766511734, 20.420945613614975, 28.194740087755267, 24.952857994264175, 31.67864811035895, 35.1969612029291, 35.76985866792741, 30.749734755485292, 24.435744477856545, 26.8335933070029, 27.317784409369192, 21.839007946752734, 14.259279601035582, 9.908994532400563, 10.283639719409328, 8.582625446781035, 9.804474153826314, 10.130756516610424, 11.260738411257345, 12.801962187213283, 14.087857315617224, 13.492475844198658, 12.621877347269367, 23.755766307154012, 39.832881112252515, 57.487763435609885, 76.43856156256892, 79.25592945468041, 67.50504970550537, 62.36998073516354, 59.3585535787767, 54.15996182349421, 40.54387346390755, 35.26293154685728, 27.62326252075934, 25.618819575155936, 10.846476304915644, 10.824329622330206, 8.736158782436002, 8.40491952434663, 10.617232399602091, 10.95414242436809, 18.84200530667459, 13.057132959365847, 14.704748084468228, 11.691349937069802, 11.32617139047192, 9.202458973853819, 7.310812607888253, 0.8593558195617892, 0.23700117373899107, 0.030998326762909853, 0.08557288682148342, 0.05589645243279877, 0.040203202590947194, 0.037116419839402365, 0.05740808946410975, 0.0413917803445891, 0.1307985580135738, 0.006496168958443788, 0.02930555398756218, 0.01812284981321183, 0.00620430430224646, 0.14614336042394563, 0.026166863033487916, 0.09306079873274412, 0.058075819359791864, 0.042583464584763975, 0.03371464088559151, 0.08147527403648823, 0.03843969117189127, 0.011760964576575545, 0.012932908646161518, 0.09414339588294107, 0.09992365184570513, 0.1060188465541409, 0.03147541567863476, 0.11277181967612236, 0.13188850194696458, 0.07223099064562591, 0.05950007640245942, 0.0775170203057989, 0.0581666007788191, 0.04746541733883562, 0.1548111090256322, 0.24982672665388356, 0.17006793389877967, 0.20982677868056684, 0.19874893279085237, 0.322142607502399, 0.20006923936307433, 0.1185766057742219, 0.05928047729896442, 0.1690914475869748, 0.16620239212868676, 0.15032456106235906, 0.16832215741517084, 0.1613481372835175, 0.2795377920471853, 0.14767823290200005, 0.04547070441467147, 0.1571916966068168, 0.35006277383335177, 0.25478561378775105, 0.0637158122844994, 0.09605290067772712, 0.19723091424713213, 0.22484061578589104, 0.23404012133757915, 0.24111344178597777, 0.027427862909051682, 0.05322317712970319, 0.03137563272649723, 0.11619571175786758, 0.07223572506899796, 0.0815461218477257, 0.1042239638345857, 0.10191787830403737, 0.07882471707078718, 0.03305323504572434, 0.15741608375983854, 0.11221149530742439, 0.09865649645366976, 0.13356229680920803, 0.10523816465490288, 0.19556304890542262, 0.3678693231796065, 0.38686661830832886, 0.351365705531451, 0.25439572099956775, 0.12694466077992994, 0.09762989266985848, 0.11498462634101031, 0.09669407796595367, 0.09194215714570977, 0.08182446457325451, 0.0860639491809472, 0.15806471508356834, 0.12795306997553957, 0.08294069298332737, 0.009617436200290198, 0.025174658512696627, 0.0960157760569165, 0.03432628165389742, 0.049011474700584534, 0.026579257739227147, 0.09290258625462171, 0.0872491408259638, 0.03250208457991962, 0.04043546129739092, 0.041498986688712915, 0.051646663942524505, 0.028982667079676065, 0.04571885178466478, 0.03271688797300862, 0.10192521742635197, 0.05903124591455825, 0.08310087430741518, 0.15844832595077255, 0.6634143079000135, 1.319160504687217, 6.022191432214552, 9.334233941570405, 17.696704595319687, 23.837802679308002, 34.76845010634392, 37.99828267866565, 38.05127389969365, 25.198117917583836, 14.063296414190724, 12.21456568087301, 8.876712014598231, 13.428853038818607, 16.773021721070815, 21.80464602285816, 28.334868723346343, 34.092025603017504, 48.54599498933362, 49.4297795141897, 48.444099656997196, 51.19251620384955, 50.15085235718758, 55.452312192609234, 48.42744919561571, 46.76947901325841, 48.91832205557054, 42.344029565011304, 29.137020880176177, 17.274932130690544, 11.85974415271513, 12.349168677483837, 12.560172580903577, 13.519410760171953, 12.960421039212136, 16.87721360114313, 18.58814362556704, 19.400127203233783, 17.678581283938502, 14.429840926201114, 24.730573354228852, 43.49570412789622, 65.84532230131089, 87.60769105726673, 100.83764952998008, 91.42881701069494, 85.34887652243339, 83.47048482587262, 82.0840681752851, 68.57102440249535, 57.68568623450495, 52.410808301741085, 50.03112200767764, 40.70705975255659, 35.92206624246413, 26.326734827410792, 17.605354555191532, 15.65078748810676, 16.727651665287635, 16.9953965756201, 16.138871542869076, 17.052145427273167, 20.062476281196844, 17.89198175553353, 12.454395082689102, 12.45838217196926, 4.794155186222446, 1.3657722357780704, 0.13660247077143964, 0.11467514980223872, 0.09529258905639572, 0.06253577641121323, 0.059270027859677235, 0.007466516033145449, 0.010741196212268645, 0.05803843043864735, 0.06215506518680242, 0.004714876159860363, 0.03266120487223229, 0.04901000764220954, 0.07098532401986661, 0.047192280180752284, 0.09788290852861059, 0.059071653222124425, 0.07184721123907836, 0.05796256858194548, 0.12167311018152584, 0.0518289813771844, 0.051282216764746175, 0.02581326557593721, 0.05192431718892148, 0.12441913702435071, 0.16696187637505994, 0.1732050945922252, 0.1704663302629225, 0.31837976747943514, 0.2597865438269031, 0.2707581792867953, 0.18944739964940857, 0.28032594330368504, 0.3083004712337448, 0.3834047895525733, 0.20280484741012897, 0.2120953948507386, 0.11811139888220257, 0.23926713924494483, 0.2743633890584592, 0.1708376684015797, 0.06537736123127323, 0.06208551589459662, 0.1526090812178389, 0.0981706281703326, 0.12234486203881041, 0.029629582366455468, 0.09536365903313122, 0.1492927938459381, 0.1637356196560206, 0.14695254845484612, 0.18003665301347935, 0.3631189038916942, 0.39150537262039803, 0.3824528180543454, 0.2913848821434283, 0.5459382180725375, 0.29679704818033403, 0.28065640299070266, 0.4224048855323946, 0.15291896378321035, 0.21936656516646186, 0.10114494155371383, 0.2843650959191784, 0.22151869000686755, 0.15492931639234866, 0.34441376405377544, 0.268767453850277, 0.3107385613745259, 0.30510266702021327, 0.4233291246477635, 0.24977274809873876, 0.35438709501777926, 0.47022029396987736, 0.38677756824801046, 0.30410129817262777, 0.5162149872029982, 0.41473530353077, 0.4963567931084864, 0.41724601880677287, 0.5510277998062872, 0.19135756327980952, 0.19605470881346734, 0.29146302311170486, 0.2247193747109944, 0.26671816865282677, 0.19165120478118622, 0.26486803567217243, 0.21437176383070408, 0.2244760805080014, 0.16958191239785764, 0.09573043128775974, 0.15619711529824043, 0.10598226585575651, 0.09636462185411684, 0.17165611077460552, 0.1853140488627457, 0.21617125839956347, 0.11987735412173695, 0.10396525594255618, 0.1425574407462151, 0.1595174782578984, 0.19190231308100686, 0.18612784874295035, 0.19553746156875165, 0.23005611173087553, 0.1008056948382047, 0.2172311410428055, 0.12264267871937445, 0.22251782187771416, 0.29914933647359576, 2.1133671652886177, 4.031369162182655, 10.806069027992988, 19.221363221445394, 33.05013818125571, 44.03339832059799, 54.585146750173266, 52.454221094808275, 47.991179650829686, 55.913700595978774, 55.43149617410476, 58.4238096206419, 54.90083479112195, 48.077895410599254, 54.70856805001536, 51.86913290331441, 65.58689694250783, 68.74702115212718, 68.77969449566257, 77.80342871142973, 83.76526663380285, 84.9300850591352, 83.1821749287267, 82.3005594745759, 76.70026994520619, 64.31044786207138, 43.18099275712044, 25.52611435613325, 19.363404012495472, 17.64370749073644, 16.002378944427736, 18.134994160744455, 17.57708211098948, 18.97811351283904, 19.945624951393377, 21.833377384370376, 19.32564531603167, 18.453261160081436, 30.976643869953772, 51.13712841464628, 72.45081332422072, 94.70376076236849, 113.35459955276983, 112.60477573640885, 106.74749251334899, 101.42393404437651, 94.71675949711954, 79.00702368828559, 76.39088907549458, 68.89595354757002, 67.60332076780259, 53.223558702776515, 53.57408915796588, 53.21399596429641, 46.00788024164016, 45.90884823952952, 46.144327732824514, 46.627877527667636, 44.40195598909932, 35.775036196554865, 27.082171555488344, 23.786152908878943, 14.632478414043305, 9.382471249949548, 1.8257267677014875, 0.4034238621111839, 0.1499487642919825, 0.19284306905202328, 0.260951426481047, 0.1460959242596742, 0.1512762720906927, 0.12245109545127039, 0.18245729167134533, 0.17548319493089953, 0.13372133666228864, 0.11625051002709136, 0.16248545609414577, 0.1527332027833308, 0.31009042034706763, 0.13819391118182292, 0.17341987500267644, 0.18743304806130548, 0.14963575608788, 0.08908594387673563, 0.19342448382127672, 0.11542271372051009, 0.11519208295090545, 0.17424017130847902, 0.1784097886974773, 0.2953951379224178, 0.27371996713261454, 0.2146695575286304, 0.2649713962549164, 0.31233974642330603, 0.15928368354516645, 0.29630684383934547, 0.2841144932373878, 0.3358566538701135, 0.48519918214409585, 0.5431532739631592, 0.37542586124712424, 0.4048912575648677, 0.43872792093503865, 0.31716616163330696, 0.43239660260658114, 0.33939043360371746, 0.16965525765572825, 0.1731235368718063, 0.19088827313915377, 0.19572368222138575, 0.26549325534893625, 0.1923348463230556, 0.1639054460270751, 0.31675838835297093, 0.23958843652038808, 0.3082492659168859, 0.2865956988065474, 0.5310539264352091], [0.13537047881512873, 0.11304899794800628, 0.08969204965978862, 0.11159785888007573, 0.20874809623966295, 0.17193557964938302, 0.056738210691800045, 0.038979074527179046, 0.05285207264786286, 0.055480830581678506, 0.02932544546051612, 0.011729715850144144, 0.12422909359297446, 0.05888066367216169, 0.09191691454860473, 0.1447589322924614, 0.25126917828475276, 0.2183602780344025, 0.12466081478182348, 0.10716191868508056, 0.10800484522816636, 0.034978751078127854, 0.1171176755921014, 0.05031970006624057, 0.07621520709606909, 0.02139078171533202, 0.1763200080923496, 0.18701101022381938, 0.14915275297337963, 0.10753291208417186, 0.12006372033107666, 0.050522502691995715, 0.0434929182031943, 0.024787856889287793, 0.030188583318264257, 0.04333792712479349, 0.045525173266087814, 0.0904724404456154, 0.06529915131508343, 0.02878607359654721, 0.08651340530524332, 0.04179875689348386, 0.04436265782362992, 0.01250971018547012, 0.10807228394814077, 0.02941621155778487, 0.034438777835138386, 0.0383454317136878, 0.06805654690270463, 0.07614894049061884, 0.016203039220624393, 0.08446982746282894, 0.03583069447608244, 0.04018169850291264, 0.055234479687867634, 0.04355146264236781, 0.13811220024381915, 0.05166781179967427, 0.053633444026232734, 0.19838081222147713, 0.6850154133092973, 1.6666605611962657, 3.6531269165777394, 12.35385492924721, 23.318306323020693, 20.262999611516154, 11.257387726537644, 8.417958463391951, 24.74049695076481, 18.53883158776068, 20.630306043932517, 17.79830574989319, 11.123321114047881, 8.175706507698182, 8.809562998433268, 17.090343429196267, 20.025147084266912, 29.199349303399366, 31.648006554572817, 34.34821128845215, 31.753426136509066, 33.478684579172445, 29.444713169528594, 27.24606190958331, 27.4998471044725, 29.748202639241374, 28.649187857104888, 24.387326740449478, 16.53679109388782, 21.625144635477376, 20.784594435845655, 17.305442287075905, 27.66657921575731, 47.29918726028935, 51.260451655234064, 46.66267287346625, 57.879270891989435, 74.82736172214632, 79.34503786025509, 83.32935010233234, 74.5754514201995, 67.18038728160244, 63.42003453162409, 53.82152795791627, 52.111123531095444, 35.62915540510608, 34.649939613957564, 23.610358161310998, 15.692622507772139, 17.65262107695303, 20.522572263594597, 26.99963508113738, 16.766855755159934, 23.426444107486358, 23.737311555493264, 19.533289709398826, 8.84839544373174, 11.540944691627256, 12.327940810111262, 6.690629499573862, 2.341936913228804, 0.38258976393168975, 0.12506528622320584, 0.10200523531004306, 0.07871795505765947, 0.028299318566437692, 0.03065020108835832, 0.041640444823931304, 0.03444600587470397, 0.03634785362068684, 0.022548281197105686, 0.0631409858713948, 0.03802910634887315, 0.017147665850878242, 0.030618864261815627, 0.054400891756578806, 0.05362803927592693, 0.054596232685951464, 0.05250253354109103, 0.019628103416893753, 0.017250448037239335, 0.03263980803650714, 0.025596156258196123, 0.0330844224851218, 0.0443246943365422, 0.07683585322792492, 0.0462450354450172, 0.07560960693104614, 0.040838289480175705, 0.0762463485701911, 0.08201740381698455, 0.07958382593407747, 0.04063064134829948, 0.0810896713406809, 0.06325445881473922, 0.025852211570787816, 0.09218745083818514, 0.021411299465164062, 0.18328636734476014, 0.26841061009514716, 0.2175408550688336, 0.27535905821188805, 0.259855859462292, 0.20285350931507928, 0.038267846159156294, 0.09048928671907033, 0.20168876455676174, 0.12444471670014244, 0.06864007607462906, 0.057770763148343375, 0.19189767058818571, 0.11924393730418337, 0.09657767856673849, 0.08619369383180335, 0.2456240295883148, 0.16184868381148385, 0.3015546074077007, 0.271061917827014, 0.26933846514551874, 0.3617484032386734, 0.4329027109328778, 0.3742391297653798, 0.13049535573490206, 0.03365391692627342, 0.04773469341378059, 0.061736018922660625, 0.07878641267457316, 0.09075600789078782, 0.05612381966784597, 0.07361777832791691, 0.19821769678063933, 0.08019603743788697, 0.16754808685471936, 0.1353397586893651, 0.13264694431376073, 0.07343584010677953, 0.052361301401810306, 0.08660017242354733, 0.18048703610416383, 0.10014010998871058, 0.17787374165509978, 0.14414201700879684, 0.25354055237145195, 0.19066308925469078, 0.06851522672560907, 0.16914585515135722, 0.13227225070999515, 0.09630430775183825, 0.06622815549734139, 0.10118696913723985, 0.14967519429422196, 0.05694354523814494, 0.045683247848383846, 0.06614569379317184, 0.052989405399609, 0.027814361927730423, 0.09535121776524091, 0.021398946297385042, 0.03629032041757338, 0.020744211168118545, 0.034533784229068026, 0.053069917410011255, 0.1351627770570978, 0.08256660458902199, 0.02670851400903156, 0.058110274164186376, 0.0604936043401399, 0.0757295992826262, 0.01936432785324512, 0.05323973612018651, 0.07284611328354768, 0.07730011017091813, 0.054402014075387875, 0.022408067954764254, 0.2253369028649984, 0.5908532176286944, 2.8741505742073064, 5.824369634351423, 14.117824223733718, 25.20380927670387, 35.24239009426486, 29.51043248176575, 25.21964584627459, 31.22346881897219, 29.13082745767409, 21.911059925633094, 15.722914972612935, 21.18761012631078, 26.065526546970492, 29.526074894012947, 39.961389726208104, 42.90601107382005, 41.597422092191636, 55.976423217404275, 57.268871645773615, 58.39436831012849, 56.01188928850236, 52.734301859332675, 45.51925097742389, 44.85277752722464, 43.879759080948375, 41.684761508818596, 37.26829428826609, 31.36899659710546, 27.250268651593117, 27.746989765474876, 29.891565269039525, 26.42114627745844, 40.67858726747575, 59.167443936870946, 55.75782168296076, 55.918172097975216, 62.3042025873738, 79.61291220880325, 89.12030604577835, 98.9979951612411, 96.74063190337151, 88.98995784021194, 90.88466659668954, 84.416395771888, 78.41129410651423, 57.183528715564364, 50.29444248445573, 42.378644481782, 33.840311419579294, 29.698472869011667, 26.465108202349757, 22.884798126835978, 19.610723180155603, 24.48809046899119, 24.707121502968576, 27.728713481656968, 21.745888917676865, 21.56458127883173, 17.925429767177953, 12.594650214718236, 5.851000566636363, 2.2127173696794817, 0.6379126505024972, 0.1383290337699075, 0.04185627094439922, 0.031993342826383254, 0.045277665579511274, 0.10313429569284763, 0.03672404875678401, 0.04261650212649857, 0.05500252741659361, 0.028838368673478405, 0.021291305198364203, 0.03485934095337026, 0.01794099586174613, 0.05863314066382666, 0.056478227263376604, 0.011497457143700412, 0.04184226685714337, 0.02162548424225421, 0.022925424367009152, 0.024069258755433465, 0.03238581158521195, 0.032506014610971176, 0.10730284055875194, 0.019642490548111742, 0.05585036841371367, 0.016284570127965945, 0.036962562571129495, 0.09671183588403849, 0.3098391128643867, 0.17621539112540985, 0.05763617682180578, 0.10467349656767423, 0.2509169463789271, 0.16636307140992534, 0.3084838113957836, 0.3049089387059212, 0.22408301611581158, 0.02055821842664192, 0.16365674324333668, 0.2337494982226241, 0.4646062790866821, 0.26796676939533604, 0.08200192884091409, 0.1078507389813181, 0.15352778917839452, 0.14013033630626817, 0.11471389086856959, 0.07421090658153258, 0.11212690387882533, 0.08964882697910072, 0.18742063743693216, 0.10297346319402419, 0.11459720035594319, 0.1610012373496448, 0.42702096364190506, 0.33288524395996527, 0.3029370896758572, 0.32795099421374263, 0.26241505278214333, 0.44585005650597237, 0.15388763599818753, 0.090330729501382, 0.14323003530021639, 0.1048019924952138, 0.20222107309006876, 0.15644623176945796, 0.2380023893689917, 0.22258215794159522, 0.24922340176999572, 0.2670744914681681, 0.4843199889986746, 0.6050640873370633, 0.6139346500558238, 0.37713671944314436, 0.22086981353500199, 0.3249828938034273, 0.33026136217578766, 0.19408243077416576, 0.23858020352500103, 0.2581598327284859, 0.32726752121121655, 0.35639013914812, 0.24923051106593302, 0.27886718932178717, 0.23121131103365655, 0.15857788674052686, 0.1817076746374369, 0.296299887760993, 0.18706803780890283, 0.25156168597600154, 0.1791587162522539, 0.18159593305280133, 0.17847297562947198, 0.1009816422517742, 0.18463160241803817, 0.11220240184376318, 0.11267989678608795, 0.11851022425558298, 0.263035093704539, 0.11773705001800291, 0.2552709917748167, 0.12447699964527162, 0.13486199561626683, 0.20356756454754263, 0.1889475885658495, 0.17195129977358928, 0.17143728541991404, 0.12782871858367037, 0.14617647074403303, 0.11559445531137529, 0.3042845464041156, 0.17771952815594214, 0.16303926105460814, 0.34040896282080685, 1.0581746961801284, 2.2276287501858127, 8.107442067515466, 19.399481973340436, 36.302234126675515, 38.90496992295788, 33.72615868045438, 37.966829192253854, 58.99314165115357, 54.31691154356926, 58.61300906827373, 65.01115575913461, 56.070732685827444, 51.14061932409964, 56.395630451940725, 63.42745173361994, 63.25504787506596, 70.45781781596523, 79.79887962341309, 85.51669120788576, 87.50701950442406, 88.47967317027431, 82.36237602849161, 76.82289892627348, 69.2388863717356, 61.59225709976689, 51.80733596124957, 45.671023168871486, 39.40706468397571, 43.41974742950932, 42.5803876692249, 32.37223298318925, 46.42606373756163, 67.11259303554412, 64.93876057286417, 64.25759000162925, 71.3650385026009, 92.71325988154258, 101.44076101241573, 117.02022706308674, 115.43716630628033, 106.69925520496984, 110.45930985481509, 101.35019348513697, 97.84720313164496, 77.25044511979627, 73.59988735568139, 70.02647476811563, 52.40424225407263, 57.8712849463186, 56.351005646490286, 63.35282471872146, 48.94119339604532, 52.97049522399903, 46.383392272457, 38.8884332103114, 24.975342981276977, 25.532990271045318, 20.589499665844826, 10.652580799595004, 3.5555052516921877, 0.7485018550388275, 0.40777309647490906, 0.19217741525461599, 0.17685856790311877, 0.12306457100015496, 0.274274155137039, 0.20115023538950952, 0.1874676599137245, 0.09137120713750202, 0.21260225394320106, 0.12402161400044158, 0.13084640786532434, 0.12070767851846835, 0.14941477036524206, 0.1950322112609302, 0.1198975865038172, 0.1304776437820927, 0.1867680224559961, 0.08284693914315394, 0.12937973253428936, 0.1656780049445168, 0.18532515713764777, 0.17213784218315156, 0.1505601330990753, 0.1790472811027881, 0.15837079785283537, 0.15837645158171654, 0.08564748080267061, 0.2550442757145051, 0.4284612395830693, 0.1996975794674889, 0.1694519685641412, 0.1868970776277204, 0.29010033655551176, 0.2754254320696477, 0.37274427772048985, 0.4668250842200172, 0.38306155151897864, 0.47354585100566193, 0.44146104685721865, 0.4200742928491485, 0.5626615497373766, 0.2937487536861051, 0.1833532774640668, 0.21334424074138367, 0.33684548951925775, 0.1898751984680853, 0.13319065223538107, 0.1762901766285781, 0.32316649933495833, 0.1309656724333763, 0.2575123045713671, 0.1784842218002004, 0.2564468448080363, 0.33565183260267784], [0.19802867224620235, 0.05948177839238798, 0.1941033602962571, 0.17161019146442416, 0.16402759108572237, 0.07315191260028271, 0.08009934948096353, 0.10272361127839935, 0.08832736361411311, 0.019585985818036625, 0.07521555428543399, 0.09211284153523946, 0.046236662104004816, 0.016637093147202846, 0.14228586257705766, 0.13627323682510084, 0.1218650152065581, 0.01615096630919124, 0.1222470326108798, 0.0887078028773108, 0.0667493251122294, 0.09065001196558438, 0.07111398848674952, 0.07025708849992483, 0.028601630267897443, 0.11136096151125048, 0.12085869743098175, 0.07522943579862196, 0.09697287268335782, 0.045311836931373806, 0.029343862214215824, 0.06481661551421689, 0.11943381219621628, 0.03487051051530627, 0.0837165255460047, 0.06253186170192016, 0.03692488636701338, 0.07243890690827563, 0.06088964881435518, 0.00979386241881237, 0.0843777590160889, 0.03773824574666158, 0.06189904626338713, 0.0775632307293915, 0.018162182682464202, 0.10572748799477855, 0.008697839577742403, 0.053919164178472374, 0.08208144110657516, 0.06638141904747294, 0.03937278243322526, 0.04840568684402013, 0.06134289707387648, 0.014245350368230814, 0.13347516196870035, 0.04638899102686875, 0.09802137126004505, 0.05452849136124696, 0.07475120541188987, 0.025952157316609256, 0.039408233151921344, 0.15302428555104042, 0.7031398278570945, 1.667955065927198, 6.130030135954581, 9.529341459274292, 13.496850267533334, 7.383822135386929, 27.51670349028803, 32.03312054757149, 20.75642985682334, 31.465941898284424, 19.068090723406886, 25.014647091588667, 21.271411565042314, 15.785711138479172, 20.180453331239764, 16.974384438607, 24.14148042278905, 35.87110288681523, 32.03489542007446, 33.861413771106356, 36.57894949759207, 31.20291167689908, 37.156628331830426, 37.82772233409267, 39.84704479094475, 44.67152087919174, 44.54181986470377, 48.54848961676321, 45.81556250972133, 50.538927739666356, 47.70598803797076, 81.27409873470184, 105.32370351975965, 73.76039858787291, 71.43303671190816, 96.18650297964774, 89.57774854475453, 78.45335760424214, 56.79350783748012, 45.47798372084095, 46.39029564396028, 42.25844737022154, 43.74657500174738, 40.18079926890712, 31.743084807549756, 26.034749669413415, 20.61216704307064, 29.87942357217112, 32.01918632753434, 22.401942591513357, 16.367685948648763, 21.355903340924172, 14.447263113914, 10.52355541336921, 8.056533134752705, 6.667849354205593, 2.6277423770196977, 0.4941603883860573, 0.17783012060869127, 0.03874883063197617, 0.025248984363110318, 0.060379514696016434, 0.07989117274841956, 0.05737691734647078, 0.04224842369195916, 0.028702688756428903, 0.07388138152178257, 0.05015215280676081, 0.0350157339726725, 0.024737419575572978, 0.022990082187818426, 0.029675513167955705, 0.05264255143101177, 0.06866781611836727, 0.05407728472604387, 0.01894281287076733, 0.03955500793733424, 0.00896437784596797, 0.01649189650291397, 0.01472222382172702, 0.07323088094351754, 0.010254164432896482, 0.014270739479651375, 0.038989481831630396, 0.04359748154397934, 0.02097464275486287, 0.03502497299303932, 0.05983696739760138, 0.043897899093046304, 0.2179570706380952, 0.0941853698403124, 0.05780292351940467, 0.04584086660836493, 0.06039308594359506, 0.05604530331648647, 0.15272019461037653, 0.12252072518270825, 0.13491819582639203, 0.15592175265473707, 0.29771984705040533, 0.17824281217350116, 0.28681005020776107, 0.14796763027627624, 0.22190796992471143, 0.20580138500419357, 0.1913147849301177, 0.17082924143441264, 0.17682587127051047, 0.08150963307989222, 0.1941312765402179, 0.14719320731537958, 0.09884994131542983, 0.14855905015382076, 0.31683922595074104, 0.20454962797943624, 0.3677952271555701, 0.2680590370249364, 0.20244238056963493, 0.27274265344585147, 0.08520847411766168, 0.1555949242244805, 0.029014044125834783, 0.012235105011401879, 0.1279600720191675, 0.1747415758549206, 0.0686527701515344, 0.04773563953236707, 0.0313334787384637, 0.20628746779214954, 0.0924982833525827, 0.14580931544544237, 0.12186892991585117, 0.1656044145385104, 0.1195798745198596, 0.05783560099981486, 0.14472842667131655, 0.08119195173945158, 0.1732646962327342, 0.12292571756387911, 0.17762712263051542, 0.2710702528636302, 0.22270868502316937, 0.17251549288630488, 0.08726105349318636, 0.10333114198499149, 0.025516634416435997, 0.034002069413902304, 0.020602002266734358, 0.0826720412700407, 0.017342437959967122, 0.012097233125279027, 0.041915826619632786, 0.012924215463440747, 0.04305169369364458, 0.09701719086977745, 0.07299548510702387, 0.04674797982818658, 0.04990360324060725, 0.03560481345160835, 0.04022084559584337, 0.02545466173380133, 0.02677430947040839, 0.07269031398238675, 0.026455239595605, 0.025418929477793076, 0.045794257819051706, 0.074908115540541, 0.07248351620810647, 0.08428610425682799, 0.05752108360250151, 0.04283784408002131, 0.04017131418109902, 0.055118057306014726, 0.0809534915512608, 0.18647154642929956, 0.4738077917887319, 2.118116420122885, 6.30346950023405, 17.98217273527576, 22.958311188605524, 23.857581230901904, 23.988933563232425, 38.95264241003221, 35.324057763622655, 34.711305095303445, 33.35297261514972, 27.620558046525527, 23.263740270368515, 25.155248372785508, 34.836456160391535, 38.71986150741577, 43.46373681099185, 54.75359685959355, 62.86370908060382, 61.87459714951054, 60.855628136665594, 57.856305414630526, 49.88913220743979, 55.93423028146067, 57.17979854153049, 58.35149680414508, 58.80916287822109, 62.15380322548651, 70.25820839789607, 71.6241345867034, 72.38713756684335, 68.55120074364447, 95.7329357824018, 114.33119912301342, 82.12817915024297, 87.22721330581173, 112.12855292904763, 101.5059978731217, 100.1967970017464, 86.43078388706331, 75.68241488549018, 77.1422504609631, 69.45705644546017, 72.07304200818463, 54.03350068676857, 50.15695164280553, 37.29989290237427, 26.659292982470607, 28.32399199085851, 33.30734760530534, 33.54934607782672, 26.94558874253304, 30.691383615616832, 27.18223906332447, 21.268428602526267, 14.616882089645634, 13.238313121180381, 7.941273796942927, 3.515053602956957, 0.8763551267404711, 0.12652345031740206, 0.11563839045383277, 0.022143894025394996, 0.09084347980998217, 0.0684965648237736, 0.017197063200235847, 0.03869939497822235, 0.05008459151271851, 0.019773656292067423, 0.090691932296801, 0.026726725834211516, 0.009980765847308982, 0.06234261117154553, 0.01842155515576803, 0.007077101092304915, 0.06809254537426657, 0.02596093285378189, 0.07502456856591087, 0.056954216842930165, 0.02944775714328693, 0.034588509719939, 0.0802839383663189, 0.029383850088643453, 0.02948340129918389, 0.037689001614888834, 0.02090223978513912, 0.02304073017571242, 0.033393753467187766, 0.07218145540044194, 0.1483007253057534, 0.26846696352285726, 0.10390040659976583, 0.1139609719957075, 0.10139270204930537, 0.07655504369927991, 0.08112272037373436, 0.14024259883069223, 0.162867994438256, 0.07856882838231903, 0.04592428209200021, 0.1136943044501447, 0.15241401991055858, 0.27372165252604796, 0.23344931433037405, 0.15932764167026167, 0.3004382334409222, 0.16379209565779856, 0.2125103080705289, 0.10535159929385109, 0.08395005978884236, 0.19642849843348228, 0.14979540881130005, 0.19333371772400795, 0.05160690397925435, 0.19303955528284275, 0.4030621460368557, 0.41386726462552625, 0.38873581155653925, 0.2664960644418194, 0.1448446728529469, 0.08493422996252777, 0.2837769548979498, 0.13870547405414044, 0.17071615153503034, 0.2881610002969542, 0.23619223085622634, 0.21142206485233, 0.26354261163261633, 0.10166411167911946, 0.3447752962670019, 0.21912883276179915, 0.3269066325118465, 0.2726791600786871, 0.3296844979688045, 0.3942290603393509, 0.37361544226446464, 0.25427860147770376, 0.18126044782900042, 0.26326731027614686, 0.23765640874062818, 0.28025877271448413, 0.33665957530179336, 0.2456080796377313, 0.264024235788853, 0.12456308494532302, 0.2919199792367797, 0.14136801263497722, 0.19423000995189915, 0.13676633697844323, 0.16293449087008355, 0.2475336109918933, 0.15492861159145832, 0.14701343712306794, 0.15214146114885807, 0.13275169917652685, 0.15928915341294583, 0.12276351376767121, 0.14193454997674113, 0.21126222826780813, 0.1948612051144723, 0.15748506231654077, 0.0810907285420164, 0.099754499632024, 0.1598387755333416, 0.21040785637113357, 0.11660284152434719, 0.07720287063068922, 0.24028847234383707, 0.17851183160899148, 0.25532403570269385, 0.16538303045015182, 0.23760370189143767, 0.20256598119533833, 0.30665810129815535, 0.16841539031555577, 0.10938406396176546, 0.24210053075465465, 1.0722753718014688, 2.652410408181529, 10.336575046662363, 16.603073266244706, 26.07210240056438, 24.914273638879102, 47.65638182240148, 58.77758387596377, 59.05418549814532, 70.34062523995676, 67.58647811028266, 71.93616697865149, 65.24914949171006, 61.10381610931889, 61.86220638213619, 62.52475353979296, 71.67063820746638, 85.85228135508876, 85.51694223957678, 87.14460818998276, 78.70900200259301, 74.62676386679374, 88.9007866767145, 85.06659138587214, 86.31995339547434, 84.75049541842553, 85.03183134140508, 91.94013718635806, 92.01765106570338, 90.70493575065368, 80.49510817373954, 101.06822213818951, 117.26011137808524, 93.81960361234604, 95.3254956583823, 119.9932816720778, 112.94729278933619, 111.65239287960915, 92.65723274600123, 85.25629289688604, 92.00531913388161, 83.73728444499355, 87.96923945027014, 77.5684081354449, 76.83183408552601, 70.19262636861494, 57.620512131721746, 67.13550752209079, 63.24221780223232, 50.9317688019045, 41.880213214505105, 41.39367457359068, 26.522488555600567, 17.568143029366773, 15.040068568721896, 10.891777719220809, 3.9913369619077255, 1.5889918708032178, 0.3173721167108705, 0.1665061306689055, 0.13908651086591906, 0.18789283871170015, 0.199831077949174, 0.1865925423560604, 0.1170149815058516, 0.16624668733246867, 0.2796412752039971, 0.16215861234213078, 0.2035059404349135, 0.12984100939525714, 0.09157314791434235, 0.10304028138277993, 0.1730845429964604, 0.14244274206219182, 0.15780248318708714, 0.1619271312149302, 0.22420943594507634, 0.1103767606940481, 0.13404366049555042, 0.09454316354446834, 0.1463467567678421, 0.09188830882551209, 0.12643711220833564, 0.13255144379311992, 0.11326541012573628, 0.11179306574406163, 0.207524178850074, 0.18494153094868507, 0.1982287131249905, 0.3495085551854103, 0.1838919138836284, 0.19072247639058099, 0.2318702079355717, 0.19653055666675492, 0.18969136800977493, 0.1725230311914798, 0.1585987090103088, 0.19678129724437193, 0.2515283764730538, 0.41069976685027926, 0.21607516033034171, 0.37221987521456135, 0.4446820175695804, 0.4331656629520078, 0.3580997409599443, 0.22866596858347618, 0.27300698442324517, 0.2290657439058827, 0.0637757663254536, 0.18984682257136992, 0.16512262184293042, 0.2997289892406233, 0.1778955751609418, 0.3123442816638178], [0.08056827956029484, 0.03575960151670921, 0.24552348820913225, 0.09782873845148472, 0.12933491639071895, 0.0303782839252944, 0.007070675529840012, 0.07105323771435408, 0.07048543632751511, 0.17047811269519791, 0.06989276006577477, 0.1248027632133134, 0.003676255089944349, 0.06593344913374993, 0.28825305342193575, 0.046240009908233924, 0.04059965309176234, 0.04643329772196951, 0.07590783729908929, 0.027213764316853017, 0.030741505362393878, 0.06071379716177622, 0.03991537186647615, 0.12293481868841957, 0.0546267191548982, 0.15435404564824798, 0.12301593207784238, 0.029383581957869956, 0.03969044079102817, 0.06602733320887051, 0.03446087947175388, 0.05735617934636051, 0.015581336845042966, 0.04406934957050028, 0.05003514053720621, 0.027213231885745644, 0.11767826043069364, 0.025779354693968932, 0.06800610767377001, 0.04915639555322067, 0.03949030415124951, 0.04535528177755975, 0.10135854218876171, 0.09416570436329612, 0.05234933893887266, 0.025180206904488227, 0.03496085143377704, 0.019819033595042366, 0.07906445662581152, 0.07645655543573442, 0.0494178805139757, 0.03916706484291823, 0.11781547443881152, 0.022218867220104705, 0.03721107766332646, 0.0923288170428526, 0.08627841549534952, 0.06240346536581075, 0.017341989798531417, 0.047104800600678697, 0.018710050461513382, 0.05588940059345576, 0.14982467337000757, 0.06385811311643451, 0.38291409491531314, 1.3125727614087443, 5.029007100289868, 8.367395189500625, 14.585001064885049, 24.74064207846119, 22.8998561059275, 34.59202974073349, 47.37036651180637, 41.92619908240534, 29.80904840653943, 18.542893202074115, 27.994601149712842, 35.16530375326834, 26.977797285203014, 36.25598153760357, 32.30119297581334, 40.38750033224783, 29.602716045994914, 33.158097497878536, 32.27727044013239, 38.54661433927475, 55.89570476162819, 48.7501504344325, 49.70727151440036, 62.35575037617838, 57.94436654736919, 66.85927852507561, 55.10355857110793, 79.02950671411331, 124.63422221522178, 81.10722541809082, 38.89700358913791, 48.03733418064733, 49.54829785131639, 48.37186136553365, 38.86219647622878, 46.32427038684968, 51.1859776127723, 49.22001115737423, 45.635745371541674, 44.17523122602894, 40.583034407707956, 39.86770783701251, 34.415264206547896, 40.17506476371519, 24.476631264532767, 17.495743920726163, 20.228102284093058, 12.06887806615522, 6.245944509583135, 2.903370761102246, 1.2422614568664183, 0.5970998372762435, 0.23638153118231606, 0.04122535540391842, 0.024258794653559887, 0.013484430664609517, 0.05092446136498644, 0.056205228001119635, 0.06699471839613493, 0.0423158509206147, 0.07049419271248965, 0.04708149620602208, 0.056683933362364776, 0.02645775044877683, 0.018786370055750012, 0.016159941029224186, 0.02244705799967051, 0.04316285305145768, 0.03213946069140108, 0.07335095756476925, 0.04273587394685995, 0.021047043809366804, 0.06565772642892215, 0.016622799861755584, 0.01548647121976941, 0.021213418954322417, 0.04052649552543317, 0.027804753269940138, 0.04716873829883914, 0.0485775854829098, 0.03092255300631927, 0.010081010367420894, 0.05630492668358549, 0.0359372113410744, 0.03191686235368252, 0.10557042464854256, 0.06331982909731808, 0.1311829962557362, 0.04703659579278, 0.11654999677933033, 0.046301124572393396, 0.11687101826312081, 0.10690009281519922, 0.061286160602204265, 0.08442694952170696, 0.13824071915399644, 0.2273692268758051, 0.19469217547485906, 0.24228846744423915, 0.2487025385902774, 0.2655252778241711, 0.230479359987282, 0.07381583503898113, 0.07450530650995432, 0.1371071694959556, 0.3399576451028547, 0.13264360417041088, 0.1216216826991689, 0.1425265520811081, 0.16801039027350564, 0.19408891187800517, 0.2631746749243429, 0.18837225653471487, 0.06200928248525147, 0.17805202563683833, 0.04240556364698757, 0.025422292603780667, 0.037390552911787264, 0.11081153091283576, 0.16695187126676883, 0.1575660378101372, 0.09629749723019139, 0.07097506610256049, 0.09942458386743262, 0.18577799170968995, 0.1914061179324504, 0.16717077323025273, 0.13989913097072032, 0.1573461858976272, 0.08993755785688277, 0.09528511969913399, 0.14342935605635568, 0.06071648229995082, 0.14350516811734246, 0.07101320962031042, 0.22476871077331806, 0.13584114791404817, 0.04036176746951477, 0.0939027906485623, 0.12202063830749643, 0.08104144610584745, 0.05631121243500421, 0.034615223205858664, 0.04387492411619714, 0.05554378385685625, 0.04298280323705366, 0.04017063236284641, 0.01520216258453025, 0.028185686659848982, 0.027054864274818572, 0.04345353362300704, 0.01301803920913728, 0.079786088467846, 0.03783364667587223, 0.08936332133147987, 0.047064761015316176, 0.0460191888944997, 0.06311976523589223, 0.07431878708302975, 0.04666946730726669, 0.026989873205762238, 0.05378770732110547, 0.08520759311654875, 0.09113602580562716, 0.1140036047886937, 0.0731708809372879, 0.11875624573158643, 0.04698310753390674, 0.11560368667086286, 0.03236729907052171, 0.0910804997528753, 0.1295069337732369, 0.07889952555659317, 0.357182274061826, 1.7381917228621824, 4.983614000581927, 9.216826615795013, 13.027471996122792, 30.125597407740933, 41.76405222185197, 39.765561472985056, 53.74929751119306, 49.539696093528505, 51.401574611663825, 40.44415112464659, 37.01757246448148, 41.94199838945943, 40.10369331605973, 46.43716796751946, 56.21903750204272, 56.54170343952795, 59.534503259966456, 54.67629086586737, 60.92536003358903, 66.37343022131151, 62.42149714500674, 79.86953719969719, 73.83504129225209, 74.90440491707095, 93.4442877000378, 87.31768669620638, 90.19032078404581, 69.47764104412448, 98.42578411102296, 134.86147296044135, 90.61771792750206, 56.004821177451845, 71.9151822982296, 72.19235266408613, 75.2953161731843, 58.35503870441068, 59.37841646132931, 63.45417484160393, 61.0177279287769, 64.79764938354492, 56.09266265746086, 52.42749014208394, 44.52288266151182, 38.95308563786168, 46.01508171327653, 43.190520194269, 34.706986565743726, 29.882510477496734, 23.248784272901474, 13.477153105120506, 8.495598839175317, 4.920098570085341, 2.6232816615412315, 1.534468964222939, 0.1351657648000025, 0.03120107193207068, 0.08492096898055847, 0.07794722464055785, 0.03641972032886359, 0.0317425926726672, 0.06382619789350899, 0.06169236723273512, 0.008949938046205188, 0.06796787222546917, 0.07811492128718285, 0.06685085474483429, 0.0519849568785679, 0.07248384562591392, 0.06417370686728148, 0.06076151294814003, 0.03564771820580767, 0.016298909378688664, 0.08192613976256502, 0.020303281602419673, 0.01222708885888419, 0.10408710222691299, 0.047348880043794075, 0.044805870331343145, 0.030594747813959277, 0.06698685067315256, 0.0517712106868144, 0.016924464218919317, 0.07418872833612465, 0.04330661328088853, 0.0581474868851083, 0.04837454920033774, 0.10849239890493693, 0.10506075401339801, 0.06210826104506851, 0.1450253317072507, 0.060575686830786936, 0.1143222284172812, 0.250915460168354, 0.099995395979814, 0.13398315487129075, 0.03206201877835537, 0.0989275919874349, 0.12185967557372586, 0.13764618895947933, 0.22386399157825979, 0.22384764326195564, 0.1905014140591506, 0.33744512185935055, 0.08722055042462964, 0.0736451583103307, 0.022786396645730542, 0.17775515124442118, 0.18016310348626108, 0.23531630124536254, 0.12677266638004972, 0.32334628484902844, 0.3896020118507647, 0.38338545349336445, 0.364172090926478, 0.20565765158784008, 0.20507226848313886, 0.22499856779411917, 0.14719228800987044, 0.14372852871254568, 0.17762421149640314, 0.26946548252336444, 0.2411361639538119, 0.21795031374260304, 0.16130719754484393, 0.2624010486948875, 0.5362877165598254, 0.2894392026768577, 0.2033391018067637, 0.1802878379220924, 0.29265643488014903, 0.14693492843258768, 0.15063378479211562, 0.17406743380331224, 0.17933805743532796, 0.2544046076194894, 0.38407088768097664, 0.3672835417091847, 0.21412352069972024, 0.19849802367389205, 0.14947725249634636, 0.1788640175495417, 0.10068757174115989, 0.09578638634974919, 0.24095162869461123, 0.13986093382681572, 0.18454523366545478, 0.16133152849731908, 0.21654253525118675, 0.09797598821141067, 0.16267743772797047, 0.1773910909410446, 0.19587165976483978, 0.11597552276667088, 0.24035090850966595, 0.12670541918205638, 0.21056375526372464, 0.14597230831221228, 0.1581706190782209, 0.11794133502389155, 0.2684803240962567, 0.20212869820815904, 0.15323597096627758, 0.138776229934827, 0.24760392254158375, 0.2457142134587611, 0.17192388914765852, 0.13552453909670154, 0.17899409927908452, 0.11318515475478866, 0.2026853530156997, 0.14721514807353098, 0.1411792485704345, 0.09137401101930488, 0.15207114959916762, 0.1556835299538028, 0.4251123015438357, 2.070120092361204, 5.707302083892207, 14.542305084966845, 23.9133632183075, 41.99038474790512, 48.10636005093975, 68.81392894252654, 88.6179288741081, 86.0452070543843, 82.03528957982218, 66.68106171392625, 78.19671692386751, 82.64807362710276, 74.66865478023406, 79.08589470771052, 81.19277231154904, 84.3723318653722, 76.50168818812217, 83.7856472692182, 82.38805970837994, 84.97344293901998, 102.31133107216128, 90.90256044941565, 84.39392059080063, 96.28788055912142, 85.0450183499244, 86.94143725979714, 76.4328113678963, 100.51651723923223, 138.9483787167457, 97.73905554125386, 59.43294525146485, 71.6296023707236, 77.83006944964009, 87.39280792974657, 70.93239322785409, 84.76390992441486, 89.77081544937627, 91.63765968814974, 91.5715834402269, 86.87361947951779, 83.03978504673128, 72.61814163577172, 72.01249630220475, 67.58112799736762, 47.972783734721524, 35.66460186435331, 34.984713908164736, 18.70930171781971, 9.126252224368434, 4.88193488890125, 2.404435469258216, 0.9887658432126046, 0.7354152346810987, 0.1546187903131208, 0.15676636459125629, 0.13736938607067833, 0.1917437482024393, 0.17540592730285662, 0.1680710184718332, 0.11189038189308298, 0.12598374137474647, 0.17872662734120123, 0.13848243521586542, 0.13216653057644445, 0.18766704195689773, 0.1282103146396337, 0.14354114360626669, 0.11369023652326678, 0.08700198553983243, 0.11012412787925814, 0.09310042846106714, 0.12837780444251914, 0.11975612070771957, 0.09709134051996855, 0.12337834529218175, 0.19636721139953983, 0.14985772240306103, 0.0751695966708564, 0.12934047818904923, 0.14933718098027093, 0.09905268648459066, 0.09177629911010304, 0.1897955253239601, 0.1598919267135282, 0.20992961832352225, 0.18727293568513087, 0.23285129077492223, 0.23342170452158298, 0.2791298042622305, 0.34003449904341854, 0.13080462542993407, 0.3628865034589845, 0.15461218663521353, 0.15889881629376643, 0.12231773486541164, 0.18385661255207755, 0.21682851587332067, 0.261638178339889, 0.39373189992000984, 0.26358621735726634, 0.3232940376525925, 0.23340960033237937, 0.11015307068103745, 0.16946266315156416, 0.20878623209653363, 0.5680982612313763, 0.27539059039085145, 0.3884642487091403, 0.35230146660920114, 0.5431565834629921], [0.23475169444516783, 0.09540207068165464, 0.13101364485919476, 0.05218305955490759, 0.041029899561357115, 0.06129313966319446, 0.06156927605550136, 0.07779226803611364, 0.09549142717714272, 0.06251534484627266, 0.12424564109213891, 0.14233803316470117, 0.006407156723716687, 0.04204295124978789, 0.11559855388177019, 0.05121735210019735, 0.0877554023698453, 0.10087567697008772, 0.012894063200350973, 0.03574537909439495, 0.16170996061015516, 0.05431017545502513, 0.07090395782142878, 0.03030921343804127, 0.03643849714388771, 0.1311334763323107, 0.08434743725604589, 0.08525703643118182, 0.014065366628910265, 0.09360106691958443, 0.06971600059900554, 0.04065828180060752, 0.015099845796583161, 0.06588975147854897, 0.05522000445653835, 0.03074445480090236, 0.0696673846593307, 0.0486191074484058, 0.03285883257405893, 0.03627387250983908, 0.06889655465079893, 0.04000835195784608, 0.07453021202837268, 0.08437017474563853, 0.054527909134424506, 0.04936307458387268, 0.02644329628486547, 0.07230757645541623, 0.12288287792715336, 0.07634101405499444, 0.015495954430662097, 0.025700202489632274, 0.030546363615881533, 0.02545013415416883, 0.08634667392940291, 0.03473006361614793, 0.019249661727958632, 0.03194490691737062, 0.004608927157542278, 0.06349049816508928, 0.01540234518958436, 0.16371836735596582, 0.04505353123550454, 0.06549098739220251, 0.07358008680204231, 0.0068054127980083715, 0.16291785144036816, 0.8869750665560846, 2.950055056041287, 9.172653863506934, 13.681217355112876, 23.631850788670203, 38.061495596362704, 42.971973573007894, 40.98166488832043, 41.949811750842684, 43.8672153411373, 40.96070374211958, 44.769580133499645, 45.242829784270256, 59.206883368953584, 43.247182753778276, 47.93189302567513, 53.16985361037716, 58.357972637299575, 63.12983797442529, 73.63769115940218, 70.83365932587655, 61.41124363868468, 51.83354916111116, 28.425134228121852, 25.404110993108443, 56.246019486458074, 31.44701057864774, 51.283519114217455, 52.60032938372705, 55.44671889274351, 67.25349241687407, 71.82071593499953, 70.60457721833261, 54.99035504556472, 58.826319325354795, 53.47485319260628, 52.66040832765641, 51.41793481765255, 54.58866119384766, 52.74630431205996, 43.16453841424758, 35.00962880349929, 22.708613103435887, 10.05271900084711, 7.372266342563014, 6.14793477519866, 1.9612403670626304, 0.6077746902742694, 0.27284751556092696, 0.10136847834913962, 0.2204043078686922, 0.11093284093564558, 0.05459343263458821, 0.06819944528322067, 0.0943435823184348, 0.033073590001872474, 0.015453146395063209, 0.04496067754864212, 0.04132047288059708, 0.04995421100888522, 0.07083905485248373, 0.02299448910860285, 0.017876414649729288, 0.04104455865378823, 0.07016069165641262, 0.03860292152591771, 0.029916599122506958, 0.06311128847301006, 0.006229073840058259, 0.02831592160697666, 0.03084904495476475, 0.005236518834041613, 0.03606396058814661, 0.041233885792955276, 0.08636043286852299, 0.01664805395017949, 0.04474028171370587, 0.041684356983751066, 0.1096487703222421, 0.048844210893636754, 0.011727804460773065, 0.07385129724899608, 0.044962519990100015, 0.010826968373880993, 0.12962900222309176, 0.13035372139946108, 0.026986749482250987, 0.036420440451512416, 0.12101890939858653, 0.06584945525373183, 0.11306603574344229, 0.18590197537935552, 0.09179997122696332, 0.16332312727407103, 0.053256436836935823, 0.03861390722675189, 0.2314663723471665, 0.04831143887713552, 0.08485255732892022, 0.13770677119253144, 0.10881122937726398, 0.11028149766066384, 0.09350439428441948, 0.16956527296814228, 0.1652185513728088, 0.2597175346266839, 0.12166367963917794, 0.12232384058616816, 0.11555839555277941, 0.2577311912130925, 0.11201551469463496, 0.07746013061654183, 0.03400153698279493, 0.08792099993555777, 0.05680852607193013, 0.02566659229717428, 0.04604004180779861, 0.07849375176573954, 0.07877341216249813, 0.03262807539994678, 0.07600256407092656, 0.0345760339780921, 0.04141899178765955, 0.048033950339642265, 0.12452162426686096, 0.07529130505938685, 0.09292390648155444, 0.062032042957481846, 0.047424278417301756, 0.09112673315910563, 0.008319899676397683, 0.043729830893778035, 0.12023740778526953, 0.1818425520773857, 0.10058716059692445, 0.12111247937765815, 0.03924954569928589, 0.06209398882703916, 0.05311978207300267, 0.05757776644801902, 0.07087862329377283, 0.06478768037331682, 0.03538902946597627, 0.041237651115103115, 0.08368381359163793, 0.03568903715800374, 0.0063479673342719195, 0.04331506323069335, 0.02192905424312959, 0.04335191589029085, 0.08919068341774326, 0.04627017845069209, 0.03696539326600971, 0.022528449095965877, 0.04915918794370467, 0.008808759533079162, 0.027491951909577175, 0.05870767335797991, 0.04198210471640191, 0.03272438797378733, 0.02195281446010115, 0.021262971436484687, 0.03669972929562773, 0.05571994960548417, 0.10537876477164608, 0.0365983720328058, 0.010061039412844806, 0.01190449402201921, 0.023867980644647634, 0.030012396502218423, 0.1081434841598234, 0.04180431486137452, 0.11145253200083972, 0.2263502839712366, 0.2546705014162487, 0.9582589963270772, 3.156969888556388, 9.02008346972927, 22.119882991237027, 27.91601254094032, 44.237141916828776, 59.215398834597686, 62.444360640741166, 56.78154460845455, 46.895822478878884, 55.536560781540416, 58.53210233872937, 54.63074038105627, 60.69309296146516, 61.04882055713285, 61.66960231719479, 59.70543622970582, 69.66821332131663, 68.98241827564856, 76.26902887898108, 86.03136108767602, 77.71166093887823, 71.3352990919544, 66.19178525863155, 47.1576524549915, 43.163977515312936, 71.04290208508893, 47.114267118515514, 74.88698174876552, 69.63742271546396, 65.08755960772115, 65.14515176896127, 70.46900441569667, 77.05020812249954, 64.74098682403564, 68.64157999715498, 67.84276577734178, 65.62849367818525, 68.3426953900245, 67.02766587657314, 64.75793146318006, 56.32623195648194, 49.81580741943852, 41.34924196427868, 27.04868235895711, 18.55584682956819, 15.350578100450578, 7.371317128981314, 2.3240251646887873, 0.9855952197986265, 0.677359437029208, 0.3389066031142589, 0.036542179483559825, 0.08681695232348097, 0.04698308455126901, 0.08807527472174938, 0.06162344996306685, 0.012329058034435637, 0.05679264889969941, 0.016539286701909958, 0.023531367356378226, 0.026960662273209424, 0.042576389762783245, 0.05455098370270384, 0.033345332879933624, 0.0778721556848576, 0.05295011658041228, 0.04673582967370749, 0.0831389105728557, 0.05187821401763828, 0.03292793370482903, 0.00022486495547655657, 0.023518012528638207, 0.10319023543307859, 0.03622419936882873, 0.0968128675594926, 0.06057558723935678, 0.06447446532547474, 0.03277009660978952, 0.05834606453596104, 0.03301113085340589, 0.038708476950564695, 0.07607548031955957, 0.01627770406494458, 0.08630039455789713, 0.1775283432535587, 0.14430075042670773, 0.06229723578379039, 0.058205219271082076, 0.07162790324899458, 0.12958651498681115, 0.19127137838832795, 0.25873856619000435, 0.0740162436399729, 0.0965075049128744, 0.06021311656842309, 0.08476875497088318, 0.16942737714177178, 0.009579796385350487, 0.10500086125947776, 0.14427101089348718, 0.14312849800673225, 0.12608440532799692, 0.13820008585049262, 0.08792482271429994, 0.21182717214668953, 0.2505321557363195, 0.06511384230707923, 0.19045541814017683, 0.19957705851524107, 0.3097337910965566, 0.157904832533771, 0.16503135012763162, 0.1496745048150901, 0.09856203781260599, 0.16725849029758286, 0.2063520336824079, 0.09222488955504472, 0.16593390895474344, 0.12735728339682664, 0.14104843139648438, 0.28355393138143326, 0.17585742888191055, 0.16818766301918417, 0.24734103180948766, 0.22772980914000543, 0.17321448683017687, 0.3172211667462703, 0.265487096002025, 0.10871385960208793, 0.2735722960243302, 0.18823695008552846, 0.22313495166599753, 0.16994047218993788, 0.2505855060993664, 0.25121927531736515, 0.26074458274149126, 0.20921021579734742, 0.07942241120843158, 0.14644228793199987, 0.1262063741864216, 0.20277323862237318, 0.11059469738674742, 0.1088812268309055, 0.22052524250841912, 0.1524915326867373, 0.16309345411437173, 0.1530728555254398, 0.1896940646392684, 0.14564741042352494, 0.22705922173636578, 0.28173529993622537, 0.2185603189131906, 0.19814465795793842, 0.11635166427661335, 0.12905664261310332, 0.08417954908743983, 0.10897893368476823, 0.31273952174571257, 0.09208652641504042, 0.06362030027253975, 0.09638554371532895, 0.22189323039304829, 0.14891647613577305, 0.19844864164629292, 0.16435293330540582, 0.08737543042028144, 0.14179241002327012, 0.133514937253729, 0.09393531874182726, 0.2089206345619694, 0.23852107685900506, 0.23277293530202683, 0.17307430806179203, 0.23379203142418017, 0.16606158516820402, 0.2655819376870509, 1.1013606046476672, 4.152500042992254, 13.876690633835333, 23.1221721249242, 40.60607441010014, 60.13313147329516, 71.62404044981926, 80.09445375011813, 82.1122778615644, 93.74828707787299, 82.59651799355784, 92.77965776381954, 90.78535218392649, 101.58182513329291, 89.10885272487518, 88.04345069393035, 96.18372594156574, 100.4546065484324, 103.23331556012555, 108.5876097217683, 100.90582816831528, 95.41400001895045, 86.63782227423884, 55.373472552145685, 48.12091988901938, 74.74515668807491, 49.55143574745425, 81.71841698308145, 76.82999057154503, 85.53754252772178, 94.22947560587238, 96.99662147029754, 106.55459034827449, 97.47846895648588, 99.84824734349405, 93.64419521824007, 93.43855319484588, 91.44012128153156, 88.72803764958536, 83.15282775509743, 67.00559077724334, 56.08315875453334, 36.70021741620956, 22.66222519259299, 13.655124768134087, 9.202018687801978, 3.7634734857466916, 0.8546724482890099, 0.3816766790564983, 0.4094941589620806, 0.3388324764467055, 0.32170259724220923, 0.1647278107702732, 0.21013220261421897, 0.2529337034831124, 0.1486144689542632, 0.128458887188425, 0.1793105395570878, 0.20881794813659885, 0.10824354290361367, 0.11976836279274956, 0.18949949362825966, 0.12572739303352373, 0.30081272786182744, 0.14894377950939441, 0.18743759862357573, 0.23289687300641693, 0.17612499275034474, 0.10773312916318256, 0.10158682872931804, 0.13770827272486302, 0.07797213781985544, 0.21950763259683886, 0.09527055636769342, 0.21838005842460742, 0.14146614849807757, 0.12229836050180659, 0.12993229643231438, 0.2409780587279989, 0.0992384474844702, 0.13566646454555376, 0.285334411648012, 0.20265336118398175, 0.1733941804136961, 0.16835724424210288, 0.14739520937925385, 0.1769659581083444, 0.11205500652713161, 0.2035427739423129, 0.36203933278879813, 0.4952672628625747, 0.32246065656504325, 0.28149183719388904, 0.18369829282164576, 0.10042946905859056, 0.16807152408986323, 0.18047496255847717, 0.21689312772885447, 0.2580508030951023, 0.19513177204756968, 0.17391702010025903, 0.22620143308754892, 0.17212989019049754, 0.3093297563252911, 0.28028328752806114, 0.5256104120804418, 0.1452068792235467, 0.2595660330787782, 0.20486925518320453], [0.13651574961841106, 0.015285363563546732, 0.06455274418957772, 0.046898060282992746, 0.015093561002774345, 0.024349721629292737, 0.036188725667494925, 0.08368790450115358, 0.06931556644098413, 0.1383732063996215, 0.04651355309291713, 0.08162961777059302, 0.04202847601845861, 0.06506519572388741, 0.07421279115782631, 0.03887870551777944, 0.06842981558293104, 0.06669054318579935, 0.03596051190529139, 0.06355512151194197, 0.04884127294644714, 0.08753830071298346, 0.05379691569795532, 0.01669911179511297, 0.12838503631252435, 0.04161432888659258, 0.05480776488360378, 0.011250813221258503, 0.08172180113052169, 0.16225654902237077, 0.08638950590524944, 0.017124970496121435, 0.04669033937276371, 0.035435764659796996, 0.03154760414373971, 0.09480314314245217, 0.019917192440780423, 0.042815543260545506, 0.009985733927497941, 0.045558360194967645, 0.06194168671725258, 0.03953453806799747, 0.04672895403458707, 0.012144092808387453, 0.022913848778473276, 0.03155194594705057, 0.007221852447987805, 0.02901772517831095, 0.018851376446564833, 0.009818630041404357, 0.03291808947500202, 0.05398359217290437, 0.0543866808255834, 0.03861443582741964, 0.020531135303298795, 0.018055305756147833, 0.034650156815205856, 0.02679968613290018, 0.0454782082458898, 0.15607158413096783, 0.026291856023993705, 0.05055521847680212, 0.045171512606283354, 0.017000387362655134, 0.07111607224590356, 0.11301720529914865, 0.0712008398747252, 0.11730265518229817, 0.048643128135271614, 0.3301860710545894, 1.7307126209620507, 4.776368708379807, 5.167230934866014, 19.27189511637534, 27.18848151545371, 32.2984512390629, 53.48938949646489, 59.71239059202133, 65.60182156101351, 59.20882494218888, 65.87310837161156, 72.49271992714175, 81.57963568164458, 72.53001382274013, 70.42990622981903, 75.85204170596215, 102.53050527264996, 115.13867393616708, 91.79131461728005, 82.84310171681066, 79.79567896935248, 70.78360988247779, 65.21704489184965, 66.68287384894587, 55.89877597747311, 76.23724199110463, 97.73898493859076, 95.45106641707882, 75.96184453656598, 60.699486424846036, 56.123861189811464, 43.858794012377345, 48.521605691602154, 54.50822907109415, 41.93639724485336, 33.96800418053904, 20.02598843266887, 15.011522539200323, 6.17323455310637, 3.760472382268598, 1.9860965494186649, 1.0865968033190698, 0.20746607874189654, 0.09718366943660284, 0.13228737328562046, 0.04582616155065837, 0.01007314743248806, 0.052716061397786104, 0.08617772855946133, 0.03559371666802514, 0.031940559368400324, 0.019343057422027476, 0.04080724759748386, 0.049696985496989185, 0.059045966294023304, 0.06071312300440285, 0.02628833968042126, 0.07947226821054375, 0.0999185803436464, 0.017104270800407377, 0.04065697945113625, 0.12390713748191634, 0.05025365562628835, 0.011828580454382445, 0.01862703908925816, 0.023084289935087005, 0.041315455004693045, 0.026568725945488102, 0.03580654738470912, 0.018654260108427658, 0.037223135887254635, 0.011822955453798417, 0.112552871747363, 0.02153624840561421, 0.022747904557975072, 0.03597635077312589, 0.019873167282991835, 0.012917991956665873, 0.027861748296286792, 0.034669580974525986, 0.038851275739650575, 0.03645384571545067, 0.02191733118266829, 0.04444739480893459, 0.020797716663970102, 0.10651871892473391, 0.08515390567481519, 0.035758452384822795, 0.12801614965522481, 0.05690090861471911, 0.022260774144782655, 0.17474143795909422, 0.1806754018029859, 0.12171765819432274, 0.02185434534875376, 0.11775518331917063, 0.04531872789225271, 0.09152820153582482, 0.035505222021451885, 0.032221895582493276, 0.05258981776874393, 0.09175799726959198, 0.08526872693290634, 0.05258387292645151, 0.13595157182745396, 0.18408988632502096, 0.14668743606776963, 0.053403525718397675, 0.035111855024531964, 0.07196038540813231, 0.19282000980550246, 0.07534879229722485, 0.04886852652435342, 0.045619880885726986, 0.1091328101052392, 0.16907221878007536, 0.1522286419546412, 0.05861637482960379, 0.048580829865269126, 0.06475817066647353, 0.0828040152367565, 0.041630711676853324, 0.05357669989368128, 0.07930758995034042, 0.04185437487678663, 0.03857323178841222, 0.10314876709373728, 0.04507523067595978, 0.14957411665349238, 0.06344741338022775, 0.07850225534169905, 0.03202665232933097, 0.08075948744531601, 0.02163987711913163, 0.03465001125850024, 0.09403170026358097, 0.028176407419866132, 0.06728301260380015, 0.026719947871301445, 0.0447253966253371, 0.019212749696546988, 0.07243061783693491, 0.06085039063867542, 0.06047008161042487, 0.01587056472236591, 0.06184366193690127, 0.05300365846544024, 0.04065062858224396, 0.015601759791494378, 0.03627890187706198, 0.05909875358244585, 0.04622344325687136, 0.04074577287199997, 0.06747340077474233, 0.02288729042535828, 0.0268661423451117, 0.0744331410274871, 0.04987524649609001, 0.09258103617016347, 0.02395018379414274, 0.069445334074478, 0.05216667676464685, 0.06200671609070513, 0.08841427628912273, 0.01437173285070927, 0.08711204173103457, 0.05285636274023883, 0.0022789799033724255, 0.05837556658192508, 0.034594331988163536, 0.11094916626931199, 0.0698029745610491, 0.0745718642288158, 0.1496100921424166, 0.5405302501974568, 1.7189870630541157, 6.185611101888842, 13.268062337752312, 18.890026884694255, 36.79673517903974, 46.32424685262865, 50.955569744110115, 65.49683147861113, 67.35467387783912, 77.44319823480423, 74.84688728086411, 86.80448378286054, 86.2442438064083, 93.45015556581559, 91.79423286068825, 100.40543571595224, 98.53899155893635, 122.08834509695731, 124.4424653822376, 101.49117131387035, 89.05223723380797, 75.73615135685091, 69.4215040822183, 66.2679341531569, 66.16485426502844, 68.34608431785338, 80.0408192603819, 86.19899534410047, 100.20312770720452, 94.87753745048278, 92.01994957462435, 85.07692290890603, 72.49923890636813, 70.88621908618559, 72.99249264501756, 61.030255979107274, 54.37776711679275, 42.21863531297253, 32.130634592425444, 19.128214774593232, 11.921572473741348, 5.698592951220851, 3.4917152552835407, 1.550616259055753, 0.60507383197546, 0.28901429967053477, 0.13368545310391536, 0.02478737999955493, 0.028049397702899673, 0.055452182723750035, 0.06215750517684126, 0.03624269273132086, 0.02466195991503135, 0.026540602857787764, 0.02506276371047622, 0.07575907068507326, 0.05549106551634689, 0.004015539870447209, 0.07151942519891648, 0.14567082207049095, 0.010940425995466931, 0.019378676680066896, 0.05777134537516583, 0.04380379285242769, 0.06528068093522903, 0.05863081175653685, 0.02723908926840992, 0.055267080559485385, 0.0063962859360711475, 0.09189076796774903, 0.029598435146674037, 0.03455711543680199, 0.03331888752478746, 0.07824093508984774, 0.06530757828225052, 0.020324283902863824, 0.059943890289193204, 0.04712175412644302, 0.01673714997577331, 0.01892041629030099, 0.08549688323851555, 0.047237306998501864, 0.07940637698817639, 0.030926875657432025, 0.028763334191734755, 0.03262797963895625, 0.24992722206779067, 0.12334075335773731, 0.1736930313129579, 0.05306670750160852, 0.10617597118741083, 0.25334348391381006, 0.09680802588381114, 0.23880880416160633, 0.10258464292893488, 0.06571388833465115, 0.06362573949680214, 0.03262815200873921, 0.0685885566617212, 0.05634262203989972, 0.13868653636065223, 0.039138995381372596, 0.08395565989156885, 0.10504582295975379, 0.1334195286636391, 0.2236361263860618, 0.18712883454657372, 0.26598842393967415, 0.09182617909485295, 0.17471529903911776, 0.12408167529370516, 0.23011177567945373, 0.15528269743006076, 0.0955127397431962, 0.15599269239652544, 0.1882648969730062, 0.2547877435121806, 0.4535341022476074, 0.07640180313178609, 0.14554311521351337, 0.15182669094252974, 0.1576730449714007, 0.08988166408192727, 0.3099863549634334, 0.19014021892461086, 0.2775475262634216, 0.37101062074784313, 0.31916611076843354, 0.1258576279806514, 0.2857458008633506, 0.13285484525465197, 0.28161919165042143, 0.10243260511948217, 0.154535562521027, 0.27393637164946527, 0.1726512130229704, 0.2164392972425107, 0.24876301357102013, 0.13962496342437883, 0.1550880498102596, 0.20152715064825552, 0.09022869425074709, 0.13774530541512275, 0.1441654746210383, 0.16784272427039762, 0.10378930852898668, 0.192119391755231, 0.13732274663784813, 0.15704345859346852, 0.15799231977472383, 0.1340054327081288, 0.061369936147163955, 0.07757372613395415, 0.08393671453720139, 0.2857792329403662, 0.20506134406933862, 0.08666029500384485, 0.1388068734517982, 0.12692481910269107, 0.21160848468782442, 0.12199214749759245, 0.1125046005472541, 0.17993194411598867, 0.14865029122560255, 0.1758571837337748, 0.11356702660240474, 0.2419160721042464, 0.16928215751484518, 0.09777329666840454, 0.10932112217790659, 0.16697584981879882, 0.20056140488914906, 0.22947492678799938, 0.29142036733608095, 0.2927967821878772, 0.1993810166154177, 0.5187215656042099, 2.4009577978041867, 6.5205574900873255, 8.59343549897594, 25.994366907304336, 41.777129404006466, 49.945088740318056, 76.81684278672742, 88.58081540753766, 99.89426459035566, 103.37955720963018, 108.8145737494192, 113.81845904934792, 115.86197468542285, 116.118285886703, 119.78440761566164, 121.75277848397533, 137.36474529389415, 138.9856098544213, 112.91501952755837, 106.06924410789244, 102.27400579760152, 90.09029249991141, 87.07352699772005, 93.03097186550018, 81.81149482727051, 99.05341040703559, 114.86997588988274, 115.8160045070033, 112.31948606429562, 111.97676504811933, 102.29467668840962, 77.12372902900943, 78.02654881631175, 79.93893961752616, 64.75708423122283, 52.38659551066738, 34.11297498210784, 25.04029743133053, 11.77282246851152, 6.8605171576623, 2.899811700467141, 1.846950344981686, 0.6378646014678864, 0.3329503920770461, 0.38526126574124064, 0.23178828249294914, 0.09571990523968013, 0.14981837612726998, 0.11787571193229769, 0.2436022775908632, 0.09451025240724126, 0.1700476785340617, 0.15219144072503815, 0.09317300763101348, 0.20760821869536755, 0.1486101941836457, 0.08913036931546466, 0.20910457227258913, 0.1993297193680079, 0.1073988696800605, 0.2411113580268237, 0.21596458319935108, 0.1401591718557381, 0.14481260441243649, 0.16118807087261833, 0.0965111897957902, 0.13560042776648076, 0.05413900843010314, 0.1874167457102768, 0.0914159849766762, 0.20936007791709518, 0.10846050666464914, 0.1913225530616699, 0.1101504659820949, 0.07529681323156243, 0.12513185160294657, 0.12290347037055802, 0.08795839268714191, 0.22131757660498544, 0.1319575571124592, 0.13827009096501336, 0.17148424660967243, 0.09311759649145027, 0.13364812930024442, 0.10403820283470616, 0.37708192883479985, 0.2500873038004483, 0.2883525835650583, 0.1811846664115306, 0.18132168889766742, 0.29392863113072615, 0.2924593970660241, 0.2463385597952912, 0.18491143901501933, 0.126374967155918, 0.15985140066233375, 0.1035032972633358, 0.1708020299913422, 0.08298704896362559, 0.21706877636813351, 0.08911074980372384, 0.2075591890682136, 0.15635126751036416, 0.19036693498492244, 0.27849805751635187, 0.21568100809329943], [0.03164379797395199, 0.06926726459735824, 0.07630438739133459, 0.03566799272272376, 0.08650498599895547, 0.03446811517219871, 0.058651166712684985, 0.06763961887167347, 0.07996743680128167, 0.14116985633248283, 0.13023654059056314, 0.06099227012225217, 0.03480007639154792, 0.06828352343291044, 0.09240280581457962, 0.08203377511592642, 0.035306525626970876, 0.0931051475626807, 0.07706316683681742, 0.06341606123192657, 0.029477929516184716, 0.10869041731160496, 0.025930515332748334, 0.04079821542085659, 0.03279093803176957, 0.08180803964815794, 0.012347462339206569, 0.05794207956041059, 0.053338239705490495, 0.045613338494853634, 0.048188860978811025, 0.03305151134789471, 0.05234845793775974, 0.061923607042239565, 0.07761539365615576, 0.07142063050020127, 0.058814707332320755, 0.050280637242981506, 0.029080140276721893, 0.07323248972815853, 0.027631485248885812, 0.07283676701087145, 0.020287002234028715, 0.01726177847763944, 0.03312811630988314, 0.0737414479015335, 0.06822920779907896, 0.007170142470708778, 0.037786628029519514, 0.08979700370541505, 0.05800739621683475, 0.05599248921498657, 0.028740527754228924, 0.12410563852397666, 0.015388688714724156, 0.11555374539907902, 0.041038560185341105, 0.047037993903241815, 0.026651492169607553, 0.0161133571377685, 0.08528807065299443, 0.06392421501298105, 0.06694545128172444, 0.04605403823417522, 0.03448069816635501, 0.026506814549887375, 0.08501953385289639, 0.07401153219923859, 0.05894024999091222, 0.03701936416027527, 0.012998744327154373, 0.05757476721379546, 0.01851706525250789, 0.2659878417128517, 1.1841064355065747, 2.171359898582582, 6.756547872097262, 8.324314817305535, 13.607028665081149, 24.34477883000528, 30.195452859324796, 41.61107978513164, 36.92403570298226, 50.455118456194484, 41.22401637415732, 35.10361271519815, 30.205545117778165, 80.9892640575286, 102.0941572804605, 106.6716181847357, 100.38585524405204, 94.06384960297616, 91.57793767990606, 110.35535135576802, 104.2147082667197, 106.84440643556657, 104.44740679956253, 102.28761642209946, 59.236736528335086, 24.983474054644187, 13.761002286787956, 5.370222416616255, 7.9092922614466765, 8.622093316047422, 3.7166722551468885, 2.138996422290802, 1.6003452938410545, 0.4377156736389284, 0.13010006968773183, 0.10088054928928615, 0.02182078686723065, 0.07147892213035976, 0.016479838278985793, 0.05061606117974847, 0.02939285736741318, 0.08424860425293447, 0.07680349367400331, 0.06241867987198695, 0.02392141910780582, 0.03152914333998436, 0.028903624042868618, 0.057566213842120864, 0.0913700043794609, 0.031580810224817644, 0.04446724031661307, 0.04614051040862838, 0.012808795699158744, 0.056764192563752015, 0.0781038896210732, 0.03125192676370423, 0.05926690988182541, 0.12848946941836228, 0.08190861167085749, 0.022540572437367613, 0.016077538696868766, 0.1278482308431018, 0.06080252163472676, 0.06524916407802413, 0.05974432055447852, 0.04214657996330531, 0.09331205258927039, 0.05410594024485158, 0.01843979762446496, 0.017432491595466292, 0.12781905055406595, 0.03128469808988514, 0.04505432796694579, 0.09353481563589267, 0.023619203167336605, 0.07921268697828054, 0.05513391149560771, 0.037656990630972775, 0.03373028823144494, 0.01137171434463873, 0.024358037513710802, 0.038602143946674564, 0.061824272251537735, 0.05131152728872915, 0.09349495608119235, 0.061992118285307964, 0.08410834887575719, 0.07669499264128747, 0.09710568934679033, 0.05349023154966774, 0.09513177187933076, 0.15518698240480117, 0.06892564300928386, 0.0646276752494516, 0.04322443119881134, 0.025050347340443445, 0.15812624726564656, 0.0715995043696415, 0.032386493403464556, 0.04653590370810801, 0.04136834954542499, 0.11500119682281248, 0.08160616015835155, 0.0369701698242176, 0.034062226468156424, 0.03295072482057637, 0.1347371232846091, 0.06738905449427905, 0.01939622200875273, 0.029318299775402394, 0.036369215982455405, 0.06848495093084152, 0.09775132526673617, 0.08408466909801768, 0.057390825672736095, 0.11844120739448456, 0.060927972362767306, 0.1000119511398577, 0.041360914662119844, 0.09912416248792603, 0.03847685409709811, 0.05398305208091775, 0.1284598907636058, 0.031315423961308216, 0.04671693028461549, 0.006316369080225067, 0.023753393043373382, 0.05942329140980879, 0.046633097283061475, 0.066491030907679, 0.10220025065204791, 0.044844596075915524, 0.04044867631408476, 0.05556486659653245, 0.07988646130768523, 0.05352437991889254, 0.00588274942973869, 0.0548415225479872, 0.08525071620580651, 0.10095972447626053, 0.02188199729238066, 0.05505462139544468, 0.0444960069181698, 0.029916976420809666, 0.015270968771449503, 0.030388402031554334, 0.10775595858332612, 0.04013743394264772, 0.07730342733163027, 0.06817985641499681, 0.05647854135942556, 0.07566727802998598, 0.05685324645451, 0.039946406088288755, 0.008863124962625726, 0.056078865628449194, 0.010968667826795531, 0.0344914348886138, 0.006135287441148033, 0.0564655025429543, 0.027608280445659356, 0.02911764411105504, 0.05845996265810344, 0.08932791274761961, 0.05407103344858174, 0.027147748605197957, 0.047928402575874524, 0.06631044100128836, 0.12794014607225696, 0.055760092612716465, 0.05995627793092882, 0.07398900921426474, 0.03166327001376739, 0.4525802614948442, 0.608517182690482, 2.3934459686279297, 6.821873966724643, 8.970322320538184, 20.46737078697451, 25.864689427037394, 29.71265615955476, 44.21654162868377, 49.706263465266076, 64.73764104227867, 60.1793997518478, 74.11793047381987, 63.189924763095, 54.786372184753425, 43.08522808936335, 97.15372024043914, 121.46956766805341, 123.77878465960104, 114.22607960239534, 102.62364587476178, 98.3339535805487, 113.71340228665261, 110.3729392636207, 117.27813859139721, 120.67268325436501, 120.87892147802539, 81.98650313961892, 46.118957842549975, 25.081325423332956, 13.587830624272748, 18.37809874165443, 19.585223851665376, 11.801311623665596, 7.479995219938218, 4.825139459102385, 2.163874545404988, 0.9102675102410779, 0.5309673278562484, 0.24820674180744157, 0.10843055262680977, 0.17708459448429847, 0.07183188948059274, 0.054964521794670054, 0.07782150961218343, 0.06778163625107658, 0.04649443919920633, 0.05142441800525112, 0.04829459260368059, 0.04819140056028001, 0.07291989521153512, 0.05617841875420944, 0.027019011359962247, 0.019363713067685886, 0.032177094760681355, 0.03288022940978408, 0.008990940029522585, 0.03297798988980151, 0.037623753906377864, 0.08500871669140556, 0.06498108693068066, 0.06044106603029275, 0.0505443170456396, 0.02583105222231919, 0.03257163770256504, 0.006591870577164716, 0.09490526266275875, 0.02951967747761838, 0.01783547682627555, 0.021653683938746972, 0.0661452034969003, 0.0344376708380878, 0.05731912367346306, 0.06782380173042898, 0.021178801356243993, 0.04585842917402906, 0.062113497256030964, 0.049885607835265904, 0.06110528341284203, 0.019180813406203544, 0.09388210627460673, 0.023199030753946113, 0.02461573800011989, 0.038321920475291635, 0.04724611317919147, 0.047208459957713084, 0.10841038919264272, 0.14367340102551446, 0.10170977818028581, 0.05552490361996236, 0.07168324544064461, 0.14922971416625286, 0.01015271332430383, 0.04706231719483772, 0.01524627392721032, 0.016446869685164383, 0.06686459070131665, 0.03112188333855762, 0.08968758336719006, 0.12914161708566452, 0.05456490735072763, 0.13817152609267544, 0.052537007497683655, 0.11106057077526085, 0.11740422311929927, 0.37405100921469353, 0.16015696249181227, 0.1256372934327491, 0.11375734582543374, 0.2641620703281895, 0.1304998603318968, 0.16821931777221544, 0.11949824019064827, 0.13901664364722469, 0.23326923770289268, 0.13122012087654683, 0.26032691160517357, 0.1840768628303082, 0.23422666374714146, 0.292211399083176, 0.21666176917572177, 0.25156776871412034, 0.19235551537525272, 0.18937236899810453, 0.16293660527275455, 0.1473984575920528, 0.18411787917777417, 0.18656588249629547, 0.1517739994150977, 0.07677273524384345, 0.0975048134944612, 0.13913520341438634, 0.14417796185420406, 0.24795010235280762, 0.10643176794532808, 0.19946323317145148, 0.12694487528454873, 0.11641323476308778, 0.16614861275640228, 0.15500577196719187, 0.19756396331133383, 0.16955163660309008, 0.19515680780093517, 0.0916134441391595, 0.14475166977893922, 0.11566567850569565, 0.16255428143326314, 0.11406155934016551, 0.12701275833551923, 0.18724872730672362, 0.15120893296214843, 0.23292003950524717, 0.15903381630778313, 0.1589089746196424, 0.14250882480654026, 0.1390650604040392, 0.13949558649572635, 0.11417492503120054, 0.15136855504205152, 0.06778217251262358, 0.10389456134890357, 0.14170035689828858, 0.13761880897706555, 0.1186245552174026, 0.06959921815582822, 0.1923377268136509, 0.1728146655424949, 0.1638677545012005, 0.10017645319983845, 0.1256390477740957, 0.13573599468556144, 0.2846081602957941, 0.1267175923191732, 0.1331714693937571, 0.11020896445599296, 0.11041226120845926, 0.2068955730646849, 0.20916806563975351, 0.6210901564167393, 2.5760501959631523, 4.128421102800678, 9.943494719843711, 16.46146001354341, 20.83441245940424, 36.4733906715147, 44.65545485096593, 60.74107531578311, 55.93608164018201, 73.24328899383545, 63.53689762853808, 54.86686314305952, 49.827280352192545, 110.72858056714459, 144.9461377051569, 151.74346400845437, 135.72668506253152, 120.57043490871307, 119.39057027139972, 135.19787111589986, 127.2588840607674, 135.04736192764776, 134.4815992539929, 136.2228805788102, 91.29724502563478, 48.52000928694203, 21.652991502515732, 10.196277749153877, 12.814747152789948, 11.866402376082636, 6.38432720015126, 3.2097314057811617, 2.5108214251456724, 1.029595081363955, 0.5351152343134726, 0.3029643624059616, 0.1937223847715124, 0.16478014989726006, 0.3295826695619091, 0.13463029998444742, 0.14655058212097616, 0.21291115591602944, 0.18000827711676398, 0.280018282393294, 0.21640068641112697, 0.12266886360462635, 0.1575260173769728, 0.1821795388335182, 0.08849859192606904, 0.10863034069658288, 0.1514693109258529, 0.11975327852152048, 0.09858732637498649, 0.16683962406410327, 0.1718534090586247, 0.12649551875168277, 0.10462023047429901, 0.21361258601950062, 0.14327258382353092, 0.15688095602297014, 0.14257795658082734, 0.23470096410282199, 0.12713003873584733, 0.19548273224744106, 0.15793192140277357, 0.19856643532553028, 0.1310737521177338, 0.15349536833743896, 0.10616688538462886, 0.11271213376594168, 0.18302340000387163, 0.1548669874788292, 0.09987679024737689, 0.18207576456329516, 0.20632246268853066, 0.17927658654028372, 0.10435666558482956, 0.21101626807883864, 0.0888391869563249, 0.07517103691615405, 0.19952766116588347, 0.1616950985044241, 0.1217138200938221, 0.24499335536553016, 0.1696744864626277, 0.30563001130377093, 0.26406122251383723, 0.2086791789699947, 0.31521245356528993, 0.3223993695311008, 0.2562220746110524, 0.24725087858255834, 0.1573844136850488, 0.20377885159705916, 0.30381318782606437, 0.37702431902289396, 0.3391624458374516, 0.30385467914804337, 0.34662628726613137, 0.15824186525517897, 0.25088985750992454, 0.2039438362924322], [0.03470098291854224, 0.027227936943452206, 0.05067793427095298, 0.13138705143524756, 0.09664733894169332, 0.1787725619731411, 0.0762438434626787, 0.1003083658795203, 0.029022607073608427, 0.00388926942832768, 0.05789303844193778, 0.12059442774062196, 0.04857654360333278, 0.040843613791249456, 0.08073288887258499, 0.09784615163000361, 0.026449955504147277, 0.057465741410851486, 0.010969000117432688, 0.09642174903063044, 0.0372764824198619, 0.058525470836508664, 0.008139027275084969, 0.02780099943911116, 0.026500967383805304, 0.07448639179910384, 0.07387407304298493, 0.041762758421921925, 0.010007902596806808, 0.03772002434538257, 0.03390747670745177, 0.06851232325237605, 0.04820433212444187, 0.0346417528306765, 0.04865948028201538, 0.06312479843355476, 0.016734426533202493, 0.015838323912072568, 0.06068382397173874, 0.03789831981843999, 0.03792446256885606, 0.07792789624222825, 0.036034205733167554, 0.046591579148005095, 0.04462521530747895, 0.05041682086284122, 0.0411491105032544, 0.01972305809988851, 0.0580346268121033, 0.030302224800952023, 0.0801115685833558, 0.06525592097351629, 0.01920224088544567, 0.009369943835472148, 0.04519796945274838, 0.030510504955365777, 0.09136706260183165, 0.010659115636841425, 0.05373508474158664, 0.03584684360952627, 0.05561968401795434, 0.03436430259757946, 0.04461949263068457, 0.04730435118319527, 0.06255287932412279, 0.03680798901064742, 0.04723866297412784, 0.026348063894998164, 0.04638223796181622, 0.13318931924239283, 0.05274260251392281, 0.06407016625387535, 0.011769715215890639, 0.07166680519378955, 0.034201382509162354, 0.03260596227201243, 0.0649066768105953, 0.1314489973048049, 0.08397822884181816, 0.1109920671930717, 0.3271342219123918, 0.6784461787150753, 0.1565131418887646, 0.7049179485728664, 0.5585230201963456, 0.23091252142142868, 0.2154744707889134, 0.8883632178748808, 6.088686883449555, 24.535959074574134, 60.25796090402911, 61.753760691612, 59.35202283243979, 67.35764703442975, 72.0273385509368, 45.31150656361734, 30.60642900005464, 13.441731160686864, 3.1735024336845647, 1.0266944273344933, 0.17854160178572903, 0.11724784925219514, 0.08213235531002283, 0.09848199694627717, 0.0838966787822785, 0.07810677777254775, 0.0893659949783356, 0.07999243425025095, 0.03912443971081127, 0.07531555174219032, 0.00918033324377311, 0.04468703094208914, 0.033073478919123454, 0.09848375894850302, 0.06948482590697466, 0.06356699204432868, 0.09128074747540298, 0.039372816907181855, 0.03646617207015234, 0.057646296843285524, 0.010435712906802374, 0.07263828895144886, 0.023346284344311685, 0.05081509465291616, 0.08748900295505602, 0.015431741898458813, 0.05452330494599958, 0.008188410260293993, 0.040084665806423274, 0.002956298825841758, 0.023342505615625172, 0.00401885463713458, 0.02369318427818437, 0.07371918538645392, 0.018569002183334484, 0.02105663906061842, 0.08437497811692377, 0.05530850676399085, 0.01733369306631146, 0.05058729840863136, 0.01952525419783929, 0.04354794246835574, 0.060366686553724354, 0.02571592644427813, 0.06859164399605605, 0.026741723920549118, 0.031857929124887434, 0.01033367957138727, 0.015834934930617533, 0.0378673430532217, 0.031116959308424307, 0.04058124016850226, 0.05920082713747698, 0.05935335524320122, 0.06285867864085783, 0.033346907190618016, 0.0033090222249513553, 0.007003747694750107, 0.059757554723370465, 0.05658266036921451, 0.02879814714223387, 0.04969422375002215, 0.02120569870326548, 0.06752705757295893, 0.02940312486081835, 0.050643058118200114, 0.10930228407584852, 0.015666661802829517, 0.021595376986829985, 0.07171794922361452, 0.07775828437579256, 0.08681560400873424, 0.025169954732841542, 0.021774743067761584, 0.05437610881222833, 0.011104441589615759, 0.07279856220608757, 0.05076737886655235, 0.09578932812737842, 0.10694753664034991, 0.08221996512504355, 0.17956155592635756, 0.11315708529324302, 0.07335180026148597, 0.13979437610795423, 0.027462449863613136, 0.05352615341243725, 0.10014354206261136, 0.08759574964642526, 0.06366617744788527, 0.10960387756987926, 0.18409203137120894, 0.01502899223968627, 0.12065481079081375, 0.01655846571309432, 0.04291992274022872, 0.021822826576329047, 0.06540864826210084, 0.04733412519037243, 0.046275966244960026, 0.03299710761395193, 0.025465245238475265, 0.02961040910093054, 0.025293633882557193, 0.023021685229914806, 0.027299119918156537, 0.024556791364786126, 0.04953095892203912, 0.030923817051394336, 0.0660712147251733, 0.03666844609523973, 0.02492611086176288, 0.08512721517153325, 0.058665871770391544, 0.03861354333498786, 0.05711129168048502, 0.036377692745337566, 0.0697449357399056, 0.06829291567086213, 0.020168632073628328, 0.031467396653287356, 0.05531466611090207, 0.036446322732034235, 0.10227438498048053, 0.032132466308652394, 0.08360061644306106, 0.030434677572620493, 0.009124741115937791, 0.035388259547612363, 0.023213812420445106, 0.039041840110815344, 0.023236540333938696, 0.03698656027535758, 0.015984626595802125, 0.06214229833154429, 0.09814844992492469, 0.03718258302298285, 0.04766386092430161, 0.03210820047365081, 0.024613537412557392, 0.04432077579680951, 0.05047311683395698, 0.022922748804933602, 0.041079902120174906, 0.05364942845077284, 0.08574236845297199, 0.0035567697928091816, 0.12078064839325606, 0.03262598781035312, 0.025043395092530597, 0.05775161478067598, 0.0823941505363872, 0.15593374959163128, 0.2906621547956621, 0.30963652857368995, 0.8961088570856279, 1.5117693500172709, 2.539476545587663, 1.5290250821459679, 2.483570758373507, 1.7421318662743417, 0.44361271204486974, 0.4264691964753213, 2.782009441045023, 13.936210640015142, 38.30722816528813, 74.41013920691707, 80.5832830552132, 77.10757670863983, 89.00985994646626, 91.73319293606667, 64.38100345673101, 50.52668994472873, 25.78376308564217, 7.410904140241685, 1.88627639605153, 0.2501403477283255, 0.18424169430809637, 0.1084639540603084, 0.18245851741202418, 0.006068690460280426, 0.11318788968867834, 0.08833377577003934, 0.0498804712157336, 0.10141718621936538, 0.01925372582439694, 0.03592311915370726, 0.030253530337264946, 0.048700626864428484, 0.06525900064697189, 0.035471257513328906, 0.0652170879766345, 0.027656894470114383, 0.029310631235280347, 0.03149000007749325, 0.05024318703480306, 0.05125879745690092, 0.0391714085614489, 0.03714527454107039, 0.0374436772788965, 0.06608043076290239, 0.028675898661716815, 0.03860241590788768, 0.042686154840574156, 0.02410442410637775, 0.0418922042984876, 0.0024983637840411957, 0.009949244202054557, 0.026134909506166176, 0.07042444806786315, 0.052850574945970896, 0.020425915042118683, 0.010635206990334536, 0.02017590416324956, 0.04998591938807119, 0.03187867478587695, 0.05068479075787529, 0.030222994072603124, 0.022205328531262856, 0.06569401601389532, 0.14656098559498787, 0.013074447220611959, 0.020593249712199457, 0.04551522561439103, 0.05870387356187548, 0.03161642756763726, 0.058305492519491145, 0.06158225741537829, 0.04617545550929443, 0.07582601144789688, 0.0673582960641192, 0.01736174720609861, 0.014164874747004962, 0.01916061932851951, 0.044307798267372196, 0.027416396488045013, 0.01959269866347313, 0.07329664959181702, 0.057826270048897115, 0.08682151054663044, 0.04169297930333884, 0.03144863324480192, 0.049032032670032595, 0.05734981315570974, 0.09414131212378703, 0.013175566038567454, 0.048393797159435294, 0.04620819044629893, 0.04170703701674939, 0.012778937422309913, 0.0418716233464018, 0.08331855819109948, 0.20465139509929767, 0.14418085766655786, 0.13330820076648267, 0.22542535537673583, 0.315015415751165, 0.3848545649839986, 0.29245866162161677, 0.161950726722998, 0.25684403075325873, 0.09753832218026924, 0.17479860344000403, 0.225014180666016, 0.149125219773381, 0.2670646855427373, 0.2625079026385661, 0.5253080831420037, 0.057516858627599095, 0.22706266913202502, 0.12366403480090442, 0.21759713188775126, 0.14118986654906504, 0.22350533985562865, 0.14584165967760548, 0.14708998462846204, 0.14205767562793148, 0.12746671139593088, 0.15904274889298026, 0.08082449000569121, 0.10698915819727606, 0.07213428736694398, 0.1437337227886723, 0.09857323801805896, 0.12986656608841113, 0.24598202247533107, 0.1176704693165037, 0.15945491951800164, 0.13995914629870845, 0.1441386309001715, 0.10672714080541365, 0.13101450287766997, 0.140764044237233, 0.15723419916485587, 0.3028350161208261, 0.10190675470737681, 0.1101063852829318, 0.17514801614226835, 0.1133063805079268, 0.09924941020266664, 0.18191076454616364, 0.17398108037248736, 0.14940816668733475, 0.13867941174295642, 0.12724791668475638, 0.10649718419318238, 0.15899800935820227, 0.08723844623854084, 0.1934393152834908, 0.09001383723150339, 0.15725868333491588, 0.09993730353251581, 0.16293213131927675, 0.15761201840735253, 0.18611775170410835, 0.16552918470434605, 0.13746476401725125, 0.18245140811608684, 0.20197777888707577, 0.20409446450010424, 0.12706380277391405, 0.2353856628460269, 0.146565628087809, 0.2066298018419935, 0.16149338755396106, 0.10920314463756739, 0.18917848746622765, 0.178041760058653, 0.10867639024171138, 0.22285629484441974, 0.16126167660038318, 0.3274920156165477, 0.5629531534448747, 1.237839965089675, 0.7920769974589349, 1.2636396000462196, 1.0266005355984935, 0.30886685535792385, 0.3506871048481234, 2.404677675616357, 13.9771278250602, 41.210209631150775, 88.6432046274985, 101.21793900766681, 102.02087956090128, 112.84070630227367, 108.73199216781124, 79.07376673913772, 58.96105274077385, 22.526593554404474, 5.638754252464541, 1.4859444648027422, 0.36761341916937984, 0.2550759457892949, 0.2555542144804232, 0.203121594123302, 0.2212405541250783, 0.11702523176227847, 0.16529303044080734, 0.13987556610616947, 0.18915918205053578, 0.17663747492817142, 0.10185918064727899, 0.16607103869318965, 0.19043816584012202, 0.20470198754581714, 0.13315372679743076, 0.14191003516316414, 0.1120462884465533, 0.1245916983292949, 0.1287134045795087, 0.14801092956575657, 0.10831185496382176, 0.1913295551052978, 0.13584583637214478, 0.099513350475219, 0.1750319231782229, 0.105077002738272, 0.16210782071275098, 0.12858008995892542, 0.11386589282342505, 0.1345214082468902, 0.13483171982149925, 0.07045886073742183, 0.1441665471441323, 0.17604429304840105, 0.1264696632842383, 0.09289484876658648, 0.15143822307788557, 0.19863896853020116, 0.06732834968715906, 0.14816774776385677, 0.15976772853924384, 0.2300935121433389, 0.14723161896390302, 0.12440650423447933, 0.241840934200633, 0.07544571774140482, 0.14846921868381963, 0.11497814523717088, 0.12660767402379744, 0.15530419385721608, 0.14914970394344101, 0.13211511075496674, 0.26319379647893293, 0.15067950491943669, 0.1603653690507335, 0.14943619018360493, 0.18725274160744684, 0.09090794610881037, 0.16448609470840425, 0.13942768046211812, 0.06232909738056122, 0.14296182791792578, 0.3029779987710138, 0.15264701789184926, 0.1915005459299972, 0.21037278486596, 0.21325489956765406, 0.12573806463830894, 0.08999309157051387, 0.20082356017683783, 0.28368713874970714, 0.1917213784350503, 0.16618441970598313, 0.11843179217389516, 0.2503745867720535, 0.21296734080439617], [0.013600590661348355, 0.02010013615231841, 0.07563635106048278, 0.040989488423351324, 0.010363357817573894, 0.05505207798353607, 0.04837444194802835, 0.01972936874916477, 0.06542318861090368, 0.09743997181255011, 0.04339701548639325, 0.05843664677212796, 0.05504550877958537, 0.05446023292719357, 0.0035102014625144583, 0.019438023596341093, 0.042599334096115445, 0.044737336105637016, 0.07479132543648444, 0.05339378108000083, 0.04167505284591068, 0.025447874194792202, 0.018433998338878155, 0.06767106678096518, 0.03415690344427863, 0.016538639357613943, 0.023291710155805754, 0.05707765659016948, 0.059226625148327126, 0.06211133688808449, 0.07203468061502903, 0.002288327373061029, 0.04188642033465928, 0.00735653740834565, 0.03654121421277523, 0.00861724042483876, 0.06646435572615554, 0.04922072778666212, 0.04632841262425627, 0.023741319497686722, 0.03377043889955648, 0.05145843996996841, 0.04032393421737417, 0.06843546165093299, 0.010329771565363534, 0.03506918775758917, 0.03350116665505114, 0.004411952545671094, 0.030492260571449038, 0.07655955595715393, 0.10399390763092427, 0.03164233091557699, 0.06514283873501324, 0.09803279363099607, 0.040346541472019694, 0.04659019635930177, 0.0627765616762542, 0.025299837279524055, 0.062358875218178, 0.04007455727626239, 0.022210917142670483, 0.029214665316225543, 0.0814414972199067, 0.012528615320221552, 0.09793108779816859, 0.011529551439678237, 0.024391862210787596, 0.029132670925689802, 0.05263098733379476, 0.0420720894039879, 0.027995267845389825, 0.034752509992329345, 0.01363270985518372, 0.03770401310776511, 0.017445823440568584, 0.04295038622653773, 0.03745126154934687, 0.03460415323535281, 0.05597052930463707, 0.018688046501108238, 0.015563768533719404, 0.013268348862296872, 0.03319674246614018, 0.029386701850941586, 0.09822813839080835, 0.09829926199369854, 0.08412924009345232, 0.07549329946238188, 0.24161544388100026, 0.28086067267483283, 0.35065425499793024, 0.7962913390609526, 1.4206628645620039, 1.6810753941535952, 1.3554627760764093, 0.5908299898428302, 0.09033903389448121, 0.05104870933498587, 0.05131800456212894, 0.09182639359947174, 0.021842321598782174, 0.0191926896842497, 0.03698388279806222, 0.02462137640724259, 0.004419069981292612, 0.09233674605286891, 0.023069996649639744, 0.038843032633585316, 0.005057207336874619, 0.03464725334197283, 0.06151160878700115, 0.0671279257644088, 0.04949776816271967, 0.030053916552494613, 0.07405541371554136, 0.0709407760070697, 0.09459089082215102, 0.020338931503976067, 0.0500048034554047, 0.09055373003526081, 0.004593036099967938, 0.03485146939994828, 0.05443427786831895, 0.07544882039749816, 0.0647497896645819, 0.08133053704495392, 0.019399757504523284, 0.0918638629598483, 0.07186293136328459, 0.06707028530898594, 0.06040805147119588, 0.04403971345914949, 0.03990838514460672, 0.09851263280236915, 0.041203449119723616, 0.04019357669617861, 0.05641241648024129, 0.017947940448779735, 0.06919400360915931, 0.022569879130910964, 0.005180751463593615, 0.033136301959354075, 0.05445933277388254, 0.024546763273857297, 0.06884826046805229, 0.038326769811852325, 0.03048926708288491, 0.02246968057607451, 0.08444629324179503, 0.013062097883272557, 0.02867862018906782, 0.012086991487341303, 0.0252652139357862, 0.07954444901476945, 0.015141633977632851, 0.0565260656238083, 0.06831166950324852, 0.009544724880176927, 0.020709714228888194, 0.02858432817212757, 0.00897203585238106, 0.03481133788403484, 0.05514680092493373, 0.02381819642088827, 0.03261489485720954, 0.04335778795423047, 0.05077672130878895, 0.02840673558474068, 0.014142939734513001, 0.023055230304899237, 0.07373353421327568, 0.04413843154907227, 0.03991336471611454, 0.03440524233625301, 0.06647985368486374, 0.06177879727235245, 0.03986331236158167, 0.06907306130855315, 0.01860628193694978, 0.012682228397968556, 0.018343609539912115, 0.051933108047852596, 0.02514505879052224, 0.029543008685352343, 0.053928966273463545, 0.05312758850895109, 0.021548195546793363, 0.0537297259565563, 0.013954732041325302, 0.007478892662367153, 0.03669375764025796, 0.0867733619205894, 0.027161074704640818, 0.08012023303777942, 0.0510626214916908, 0.016231501302231225, 0.0071495313539109645, 0.019600380610133854, 0.017215763406467535, 0.06069607754808761, 0.041323418488665935, 0.029124370363030224, 0.029907302645545815, 0.032985057050903, 0.04801981984787891, 0.03724920202887828, 0.04058556856527444, 0.008624998022682004, 0.020231774955567335, 0.029726122851453485, 0.04670530106992491, 0.04170555080617628, 0.07013187908958043, 0.02609891869548348, 0.02912027945351457, 0.03564246284264711, 0.026797018231703874, 0.0733045019930409, 0.04829574173556701, 0.037399860880067276, 0.021916044154955495, 0.050124565980607466, 0.016452797290478504, 0.06317001294284579, 0.01059727797720341, 0.05433826406876888, 0.05630056381285672, 0.07739247739194863, 0.0731610750118571, 0.055035955663169586, 0.011351793185777722, 0.023618565399139643, 0.08850875791282424, 0.06563737913365326, 0.03089215272226401, 0.07143056666057918, 0.0337970566244856, 0.027199291000743548, 0.04684437284125917, 0.055666932490684336, 0.041756629718527685, 0.018907191697508097, 0.03770140840882256, 0.12746697952670435, 0.03416082581445094, 0.04484250082544262, 0.048028595385051547, 0.016287132692072662, 0.020742248067812576, 0.05148240320023991, 0.02926805589888846, 0.03609222923255256, 0.034203117698310845, 0.05133589654560051, 0.03476962439655777, 0.12430947919886921, 0.03443649872356365, 0.042847358892040874, 0.03203976392415503, 0.05336374660292941, 0.03511158689375847, 0.0775361495212682, 0.09684013262871774, 0.045805883203302665, 0.2516025031406072, 0.44098521432568955, 0.5867240650038565, 1.6576468319662157, 4.126767823773046, 4.226415638000735, 3.4341429510424217, 1.94057266318029, 0.18016034556973368, 0.09548732094586858, 0.07652549568804042, 0.16632079867826355, 0.035826653362281864, 0.06409511390712953, 0.019548114261499817, 0.04149702550362676, 0.03743951742146765, 0.04343060078099371, 0.03982949341016431, 0.012638496268811006, 0.060922939165104786, 0.09690724193088471, 0.044725170629399444, 0.006006983993199444, 0.03534058972652401, 0.052136209447898214, 0.03600809362626845, 0.0340398145659316, 0.07753085585371142, 0.017915439168592135, 0.06971834482805384, 0.037119480360659866, 0.04504125850695757, 0.043997184088033055, 0.05051014186333745, 0.08256007751990711, 0.07578184647906212, 0.06979735147568487, 0.014541934604846663, 0.02531889180142072, 0.025627171327810616, 0.05077418555775958, 0.017590750038864154, 0.01140795796433644, 0.0869393042258678, 0.0448148105774195, 0.03832326495959874, 0.006080428842500213, 0.07722331751738826, 0.01220043091433904, 0.07446681825263847, 0.017024503810511484, 0.07861934422004609, 0.004563156276896236, 0.00962178374926049, 0.07416864151075002, 0.04596150247380138, 0.023881310574530114, 0.029582345385044336, 0.02315312868074304, 0.06521025447234993, 0.027472937607296535, 0.05048383823445728, 0.02410500058754077, 0.06576155432529988, 0.0620611006724498, 0.04826146313139508, 0.019547091534120903, 0.014656526994170442, 0.0335550494492054, 0.012749971637892868, 0.07936704603414382, 0.03677763660708743, 0.03941643029271115, 0.04438504674321702, 0.029022281486240607, 0.034792932621654005, 0.03783867221265551, 0.024428146050101327, 0.053361180208383076, 0.03150539269911186, 0.011869027023954738, 0.029325146686225653, 0.027448223610859246, 0.025835733019536542, 0.0778843977698876, 0.04940558097235138, 0.0786914560763586, 0.07700694364405448, 0.12146537777997794, 0.2498034835462609, 0.10718287885068886, 0.11602341092281765, 0.15561134914957708, 0.1102743883647265, 0.08228918116900229, 0.17083454276284865, 0.20398906612348175, 0.1175745397866253, 0.13708089268015278, 0.10771709494292737, 0.1704298185124513, 0.20097556734277358, 0.20773735047588426, 0.249136297573005, 0.12100772451489203, 0.17159666235168136, 0.13377528457391646, 0.08167129295367388, 0.07629248238499127, 0.19464020407007587, 0.14876411656939215, 0.14339587801406461, 0.10684203867229725, 0.24400635832740417, 0.15448287099359498, 0.09782621802221383, 0.1758407894521952, 0.1940478955305392, 0.09146334453215522, 0.20117052139774447, 0.06132744125000412, 0.17043904221105963, 0.12124051565244315, 0.16386749403130624, 0.13910653640425977, 0.15088003609449635, 0.18802734842944532, 0.10942249093204738, 0.19578184361659712, 0.19732316655497398, 0.14748355463868187, 0.10462058287474418, 0.12384493114246477, 0.1440234265981182, 0.17795631061157874, 0.14656276291897222, 0.121350594826283, 0.17400645320453953, 0.13617854835765977, 0.22729709203685486, 0.21418214174768618, 0.0958093689874776, 0.17822140767689676, 0.2060525239475312, 0.1722524949018994, 0.13405211810623446, 0.12905216865962552, 0.10508129283064797, 0.16042754474666812, 0.35930017009377485, 0.21691209606585965, 0.19355804358999576, 0.12536647369063672, 0.22127838354677926, 0.1596825855273393, 0.1529937339646201, 0.12183421081112278, 0.13219515162129558, 0.1074184125830089, 0.1461217720662394, 0.10401941835880281, 0.12669828690348134, 0.28711985616434005, 0.12831339176984566, 0.20340377494933146, 0.16430070143072836, 0.14647938190929352, 0.1333963161995334, 0.27433832266157676, 0.1167621112038051, 0.10614529702692263, 0.185557036630569, 0.20273608335804558, 0.13932030557865097, 0.11146906417824569, 0.3815383848644072, 0.5374761334350032, 0.4583928463680129, 1.5466148286096513, 3.331574932221444, 3.7936975542576086, 2.8444474454849, 1.0775249739808421, 0.24565985185965417, 0.25610025130933334, 0.14122918218133912, 0.19433660342568354, 0.21191671250327943, 0.1283006210841479, 0.14903074581055872, 0.1262306438518628, 0.11656293600437143, 0.17469550332715436, 0.19263955013405895, 0.15057170102673192, 0.1829888341167281, 0.13545468719976564, 0.21561933801539485, 0.14287074006372882, 0.10193274807064764, 0.12644387676470703, 0.1655014369997286, 0.16080082874865304, 0.22313744911263067, 0.11889891428572517, 0.1907467460560222, 0.16361352056264877, 0.18318699041922248, 0.17122448151630743, 0.1912887992277261, 0.14992060289988596, 0.14791231872814317, 0.21279091075543435, 0.08367884168100935, 0.24183848271927527, 0.12465342203335417, 0.14712775276312906, 0.16588258106381665, 0.2008489483306485, 0.13778744025095818, 0.16305271355855852, 0.08628314225784234, 0.16362986887895292, 0.13366118343847413, 0.05421113177773453, 0.2340534819109786, 0.08800363017907066, 0.12075394256821564, 0.06794197079274925, 0.288245331255659, 0.1534825440255865, 0.13055328730373614, 0.0975425586464905, 0.08754349478911008, 0.07396723699545668, 0.23385627555751035, 0.13429401802920526, 0.13835141885905497, 0.147255566872416, 0.13466054513569803, 0.27157050827818535, 0.0999513152806509, 0.1510815172185821, 0.1452353010855375, 0.06163741191548686, 0.07831824102228688, 0.15169648663891902, 0.1638745880054851, 0.1228708963120176, 0.13779084168134198, 0.1524033406448941, 0.12332814355050364, 0.2896855765533063, 0.12843399699176514, 0.1397040083764061, 0.09679581444229811, 0.1553490866095789, 0.17407871061755767, 0.29467008166736175, 0.16270890861989992, 0.19830893785242112, 0.1394192994602265, 0.10325774310096618], [0.04402325789053594, 0.06629246091770549, 0.059862822865045844, 0.03882218738116565, 0.08485723046525832, 0.025115024313450824, 0.02804974627290522, 0.052788445215311744, 0.03823819855648664, 0.06925548982596205, 0.05347248512290178, 0.07136210138278623, 0.06718397275694916, 0.04831998075749125, 0.03576160483663121, 0.08446935248831589, 0.011772592833656217, 0.07828642539079152, 0.030704809750820843, 0.04995727919102196, 0.003441973911380516, 0.04308896004072121, 0.05689746121905985, 0.048929472649169546, 0.030366989874070695, 0.005235650760662412, 0.023943570540136388, 0.02406416235551719, 0.033258902840316296, 0.04550365002585515, 0.02580199642257104, 0.00894500922802235, 0.03760394287265597, 0.022187729576422323, 0.03174980347525449, 0.09327851325994538, 0.04185793718563453, 0.13591095384570862, 0.05120048667454431, 0.05994219723488054, 0.011411147762931163, 0.08406640556190284, 0.05883732607828514, 0.06827567103168658, 0.04760021050911277, 0.053973288290322795, 0.024251105046019922, 0.027726725299632358, 0.06318891233193778, 0.05847416975865922, 0.026361416807518374, 0.033223264430078774, 0.038088275149704955, 0.05790197868801414, 0.06561331631195161, 0.04153140369922884, 0.03789489157497883, 0.016992031258621046, 0.013487623336033957, 0.03608036253060545, 0.020389380309009747, 0.08346255973822649, 0.066790739825416, 0.020064583926972364, 0.009105422293707248, 0.06684810448918613, 0.06955434072522387, 0.07757871336634121, 0.059540380288155816, 0.00947031188726185, 0.0305974367825735, 0.05319084055841931, 0.046492650383903135, 0.03457525256840933, 0.025896068189233064, 0.04345438015016337, 0.02675677371782161, 0.07461097301735033, 0.056211368195832744, 0.06507370696072617, 0.05308185689031117, 0.06378832250653256, 0.014397878473955057, 0.04451531999474091, 0.01970488074866514, 0.08778262913467423, 0.05673494332680299, 0.037739843039983706, 0.08754420725087966, 0.10863102251483549, 0.15470987816731777, 0.06427632434473884, 0.049093721900135286, 0.10888142601376581, 0.06608125813786062, 0.12249121547586496, 0.07491839644048484, 0.04510376745113923, 0.12504434904023526, 0.13037443641693364, 0.04462024722728999, 0.06552134745664175, 0.112774868706061, 0.11698899580346, 0.038921874572312644, 0.019363195958336996, 0.01219794687424456, 0.03182237115388196, 0.033755262697776484, 0.007047783865052606, 0.04765258027961658, 0.042437551648265896, 0.03429343180370427, 0.034461500002972545, 0.10715204381173658, 0.03710002172738314, 0.06497629888115392, 0.006504043863500439, 0.02123385818014222, 0.031181410285494024, 0.03945037181819639, 0.00494428837086044, 0.03146795398225227, 0.047215484983978734, 0.040181920668410684, 0.035464860679161166, 0.03926802374001953, 0.04047550854363269, 0.01587509421721822, 0.09267023178718745, 0.0842488953663457, 0.03615825068986705, 0.037934333611760414, 0.08314382119645035, 0.029792533098389546, 0.056523005102550795, 0.014548689585119007, 0.0361642376669953, 0.03254791195955008, 0.021536642940895214, 0.07575759979625864, 0.03915487255360331, 0.05977584124212304, 0.016555301769967043, 0.031125039620805654, 0.035814717712421576, 0.142309473406884, 0.06606980512339262, 0.04081712630126746, 0.0761150027955732, 0.03641629208540244, 0.02389710922274859, 0.04424402910855509, 0.03747577253248423, 0.034608087096843994, 0.040131259273978016, 0.03211942749218114, 0.01208550910720782, 0.07225663926933082, 0.10831776150171796, 0.08857476404838024, 0.04410749691868982, 0.045281783302104285, 0.05530974782642819, 0.055718279533809235, 0.05187939379304167, 0.024508621671327183, 0.07826803161972955, 0.05751257619610237, 0.013489946497664338, 0.112409406461783, 0.018439449054459413, 0.02412630740793482, 0.05819527161938529, 0.013001821127780264, 0.034180824539714286, 0.028587645332839702, 0.019958520969075542, 0.01902931760395727, 0.029342220870838053, 0.028222026040537224, 0.037559747260304234, 0.033424554032183466, 0.04256832668738019, 0.05203230494272806, 0.0251148232153707, 0.049231219360785144, 0.021825684084286614, 0.04675415066641666, 0.047715054749841654, 0.033793214693545334, 0.04094188371973653, 0.04736299521379894, 0.008595192414377967, 0.0502232572574529, 0.04588675144458971, 0.03412144123426369, 0.06450523141651385, 0.027479169732560555, 0.057042232684550755, 0.035496561397467895, 0.04475221353312654, 0.04201303934678436, 0.04157019456127479, 0.10562433425577418, 0.008171079436226959, 0.023454503839715354, 0.037779281246325666, 0.04779549781233073, 0.015845197635973175, 0.045989254008858435, 0.04288658259376403, 0.03389105561279482, 0.02386148996470917, 0.019028233589544412, 0.019530838978807294, 0.08914497861218068, 0.012816339749993097, 0.025120681872771635, 0.0639703986234963, 0.007799906964083353, 0.04169954850728955, 0.04324663625729661, 0.023724858183413747, 0.013657121246890917, 0.043873970336731405, 0.01562924702621756, 0.022741819904636473, 0.027092174671950842, 0.020349737174148043, 0.04331689418083237, 0.048892397824073994, 0.06320941667523115, 0.022610001070725343, 0.058098576001582615, 0.05353304054287653, 0.056725884337098374, 0.04457630059351364, 0.023566703161885662, 0.055115215119815646, 0.02007923535852423, 0.05330832780248696, 0.06969950672599577, 0.05536921923199008, 0.04465323880374913, 0.039792928033538406, 0.02419702306900534, 0.07467857261578884, 0.0337988454397888, 0.07067639906440051, 0.028286101634524045, 0.040424203635343624, 0.016901652035754056, 0.04425642058073033, 0.06155845123313128, 0.06509779276506555, 0.04331599785796097, 0.05546426009987632, 0.03316517198278058, 0.06005048759341721, 0.019368767332766327, 0.07935636676847935, 0.05384771881865398, 0.06560994552508478, 0.01989959923159932, 0.03785014820976123, 0.07172276791665824, 0.026330340450869936, 0.07520700474419902, 0.057735519273386854, 0.02821006740803921, 0.03972470790388123, 0.03769498093113784, 0.06022286886769918, 0.048560720057256763, 0.04962259069866231, 0.06492634994849082, 0.07792719910221715, 0.06176207740340502, 0.06722654426290144, 0.018449978932978648, 0.08157477353609378, 0.01850345953097267, 0.024441294034101793, 0.04240252610836779, 0.009635313819613188, 0.08076881073535451, 0.016744969818260402, 0.05081625527612144, 0.00773557281542209, 0.029302485805425434, 0.060319572146381104, 0.012634080729537435, 0.010936990091126534, 0.03804069725916751, 0.02914452422109823, 0.01846104698826469, 0.02949692466626725, 0.02084176480439642, 0.07402247193479732, 0.09300559443692047, 0.03543712829630222, 0.011331480364465426, 0.011792762971092618, 0.05027373479078374, 0.03830088753133051, 0.0124930975688321, 0.02889508599295251, 0.029525419306610862, 0.05398562996678295, 0.02703343679557645, 0.021908421580108906, 0.04290807519047972, 0.05003267756452964, 0.04557817122868953, 0.013958202419622291, 0.05215399417906039, 0.019315175652023286, 0.03463824031754367, 0.039026100834411, 0.07190010961024992, 0.08622082100520212, 0.023879341728564714, 0.00874817346958744, 0.028466708777892976, 0.010608862184228436, 0.050169098671645894, 0.033235491193350286, 0.006003641934629771, 0.0518875602903145, 0.050208081055672905, 0.01532751467875055, 0.0432405496887382, 0.0218350418482817, 0.09000754764964504, 0.009055123833428708, 0.02996183086877629, 0.06360566033230675, 0.06988297712298171, 0.02976945661489041, 0.024801489423900366, 0.022958515534898447, 0.0012762124665201672, 0.026170358309642445, 0.06095061792180904, 0.004290587939096675, 0.05006564998879068, 0.018989561471126733, 0.02169019185877856, 0.053548044374873566, 0.02058946523785351, 0.048907750226076574, 0.14892029125363598, 0.11578941702722542, 0.17172003315100748, 0.10015705585359566, 0.18171866033827105, 0.11997000479529943, 0.07840310058165943, 0.13675276190042496, 0.1452791519583233, 0.11187722816342309, 0.14539581182743275, 0.11008202368693967, 0.1337569444290092, 0.13507967183907188, 0.14030082151293755, 0.20570809081677469, 0.07054872285093992, 0.16186520066713134, 0.15871930657134903, 0.16548236141041403, 0.1222190780625228, 0.16339915383967663, 0.11582286442599951, 0.16589191201473438, 0.12657048811595287, 0.17618813371706396, 0.11181820874973653, 0.13309453884440084, 0.1461437281461493, 0.1405868481003469, 0.13722922262405196, 0.0986676506938473, 0.18187750100849137, 0.08217569290389938, 0.14781579164968384, 0.17205652961086843, 0.10464497511425327, 0.3243979397079637, 0.1107302643058281, 0.198980919536083, 0.14080754270957363, 0.16004025665742738, 0.20318061353698855, 0.20319587400844022, 0.10625339969391785, 0.1539444337568937, 0.1175988630782212, 0.15604340741711278, 0.1260279369870982, 0.1162504104356612, 0.11957900884050517, 0.07813820269920173, 0.14698048002056538, 0.16262575743659852, 0.12545138687616395, 0.10432537855400194, 0.11597038231669896, 0.17129580430205793, 0.1155581427437644, 0.1402765978127718, 0.06990058182348168, 0.24936436194806333, 0.10822592288135521, 0.15659391819950075, 0.20641298363766364, 0.1923701170110895, 0.16886678464230032, 0.25009176243216763, 0.12647337114979185, 0.11029699561937202, 0.10425874422634802, 0.2134675042884004, 0.15927614523999153, 0.27137478813529015, 0.1053405063407075, 0.12048347522654843, 0.16891400630195297, 0.16202013428893783, 0.184364007906087, 0.13097083586598599, 0.11544599513252897, 0.19734372835486166, 0.19398499971195576, 0.2065556904961986, 0.16035639050026096, 0.15291717113746753, 0.15865757520641052, 0.17573657085097608, 0.18569972816734545, 0.1881584260732897, 0.1494788306374704, 0.1789080982487048, 0.18194174514182154, 0.18418223056341373, 0.17432500788521382, 0.21841569683484494, 0.12643705858218093, 0.3195266930326339, 0.2759627354962211, 0.21895391956692745, 0.1387122156278741, 0.20903087461427336, 0.26739407270666093, 0.2097762628428398, 0.12592874392266237, 0.1829889107255205, 0.08070249050374954, 0.1680072493130161, 0.10185089923681752, 0.053088996829765464, 0.09164057897343751, 0.13140139260119008, 0.235861495377556, 0.11645674089630766, 0.2116027543501508, 0.16433064014680926, 0.1578689796189147, 0.1989759246428167, 0.07599923158845595, 0.1460228394716978, 0.1581919929313083, 0.17937280718357335, 0.051017533386907274, 0.19812342200067737, 0.18467931437396234, 0.2552486986162201, 0.06410655543027867, 0.13249331304142553, 0.08113906102915926, 0.2824196616007436, 0.10214950498794356, 0.17558572813868525, 0.14913370802758202, 0.22798522285396056, 0.18740070382914237, 0.14744658323545612, 0.06959851335493789, 0.18281341530382636, 0.13414032546983612, 0.1434055613654275, 0.15626269242455884, 0.16358831626993997, 0.20918412284264642, 0.11138132412827785, 0.2311823069448433, 0.12485329437279895, 0.2806227564090683, 0.16215913328191928, 0.07573540622909224, 0.17880565697147002, 0.12580815402250137, 0.12469910385627901, 0.16091624755532513, 0.13267377271286904, 0.10868019003781582, 0.1394127264258362, 0.15914865288763277, 0.06677302787260664, 0.2168710490748767, 0.218253270873139, 0.177065396320916, 0.13423954917778894, 0.27078784221122343, 0.14565160858534998, 0.15156657344871952, 0.09822348823710796, 0.07755617505960888, 0.14915946390359633, 0.1659129641108936, 0.11871178964934043, 0.15985769790507134, 0.1132023457678095, 0.14757262002075874, 0.14510664427953382, 0.06888025996064948, 0.13958203185710216], [0.04293403024935434, 0.05050161147430059, 0.07562637659570864, 0.03453672983713689, 0.06454653121651181, 0.048365589802063284, 0.007678119572735722, 0.06576543073019674, 0.03201479137304329, 0.05122810797465425, 0.06106752676949386, 0.03821865182309862, 0.037649302938652617, 0.028693637427603527, 0.06279341178014874, 0.010933111771009864, 0.0066361193368662036, 0.0643583034135161, 0.02944298058507904, 0.031262378118211226, 0.037121181075851765, 0.031882271568681446, 0.02447808540666536, 0.02306534649593936, 0.04797238751404709, 0.024854539097436977, 0.054026002800392534, 0.023579215292908975, 0.033261300695519296, 0.009697027947573413, 0.13841832897836162, 0.10342028397586077, 0.03132193953910422, 0.02692287115590467, 0.011041995847687848, 0.06297618503712359, 0.06456078811278267, 0.03968763307878568, 0.025856381004315712, 0.0568576667818331, 0.0749518591610174, 0.04647944302808854, 0.008450989769170842, 0.005700267286175081, 0.06218311549614995, 0.011065613380783509, 0.0444570973124956, 0.050979952943781694, 0.03653320476352688, 0.022431123370845473, 0.013179598533878885, 0.018688293564463818, 0.01408357270843079, 0.06846672569912288, 0.03576276162939687, 0.024545784596534028, 0.021186805059832912, 0.04510182541825118, 0.04032134484019011, 0.025853199824210138, 0.03317673224955797, 0.06594914627531845, 0.05616579362521729, 0.06962221611531512, 0.04932574694976211, 0.0346188084973443, 0.04508666836866929, 0.053093558883354555, 0.016274798676491748, 0.040816222317516804, 0.051038003256244045, 0.023900024187300476, 0.032390120829786026, 0.020277554454702525, 0.045605156675822316, 0.03392798871162438, 0.05744959227740765, 0.05215985858212075, 0.07110983629019992, 0.021244748119985866, 0.024062837023408185, 0.015611756281296333, 0.0433340085850608, 0.03293066480827909, 0.05069619397662821, 0.020975941273894523, 0.05693578476747198, 0.07940023296302365, 0.06773459079164652, 0.01526507659770188, 0.058520904952479955, 0.11321362258205492, 0.08232099680049766, 0.04206718261083288, 0.02439280641415427, 0.12295541879270347, 0.06816148562657257, 0.10314310570397686, 0.04986055292970231, 0.04637651528502184, 0.050204342546602415, 0.05654546297005108, 0.0816147786474997, 0.015770319244644095, 0.08128121630438874, 0.12059854163277535, 0.044205276550905365, 0.03764255753447933, 0.016390694372896707, 0.032051123092852296, 0.023349478930955934, 0.04511332439799463, 0.014080911510503821, 0.05252201515700548, 0.0106905386482756, 0.009559426107443869, 0.05398245836277643, 0.030011207150715976, 0.03512822249303422, 0.028618221817117546, 0.015128736887427588, 0.03531781010209553, 0.00583046249249169, 0.04970428631490758, 0.06810739981911837, 0.016199080461275675, 0.033953874822585814, 0.0429755981801258, 0.05477118035477977, 0.03189995862363327, 0.01335681478057297, 0.04657755207811152, 0.030848623606406396, 0.062038688770224976, 0.024368801049046943, 0.048787462930645675, 0.03256073627140253, 0.025074214809724403, 0.05738589589694335, 0.04865961817784175, 0.032914542487912604, 0.03642936920626991, 0.05309928539058855, 0.003979430555538725, 0.035632645425897454, 0.03684198033184775, 0.05575556886352359, 0.010002614674909462, 0.034897457658042835, 0.0506197000973888, 0.019864935668245442, 0.022035952236863877, 0.03716050436900508, 0.04053226799794263, 0.012313460484297286, 0.032554952307574214, 0.03063990295143618, 0.07759886913962903, 0.044457426730303035, 0.069842474054425, 0.10445701544203105, 0.027545509116363623, 0.03587027057825077, 0.02527390137284754, 0.03661294685556524, 0.013050559641522987, 0.027295423543921886, 0.13645320620027282, 0.00929323832444366, 0.04391274970745848, 0.0267867507382987, 0.06765647280600763, 0.03502675797790289, 0.016211887536149834, 0.037731944673484376, 0.05879884548184853, 0.01711269585235465, 0.03334437527002827, 0.040004088678547454, 0.0709605870407916, 0.05597924355477576, 0.01054454718776528, 0.05987231086398806, 0.0317809641015746, 0.03441077349106631, 0.03564276161693758, 0.012720972337129136, 0.059068971914389444, 0.01939503265725028, 0.07755196157602534, 0.01563345093370205, 0.07241351875446497, 0.025414421050358686, 0.04848211943622559, 0.030616370645622094, 0.007847576306366753, 0.0576019786568659, 0.11172541251946842, 0.059582997759383534, 0.05617499817162753, 0.06731806878721522, 0.012346355342155984, 0.05931370253224046, 0.09094184549945979, 0.025505644885162194, 0.02737244027816961, 0.015319367333675827, 0.031500711901894504, 0.0506548137373982, 0.0021060101778036166, 0.01003119071209503, 0.04133941823496454, 0.02558405015377268, 0.012719954397799748, 0.02377477455734005, 0.09763272719517832, 0.020862627293794386, 0.036895978039190654, 0.01663628683966254, 0.041997572031593135, 0.04079785535953218, 0.013350966656880995, 0.06593432247398362, 0.0322544543192752, 0.03672966035082936, 0.0484222726475808, 0.03867669962346554, 0.052314753899531025, 0.027956103515480796, 0.047812409203259215, 0.023878924210645983, 0.031670003926621816, 0.02275560757205371, 0.02611296300235535, 0.06215086319453775, 0.025795917514891877, 0.05342798307538033, 0.08293238092934893, 0.021566202443453576, 0.07844241621393351, 0.08057278415728962, 0.049365686943694476, 0.0721609395658297, 0.052739139796505054, 0.035579758546044754, 0.03268415303600412, 0.05646374437116808, 0.05275480246411697, 0.013203628796843753, 0.028719297542627302, 0.04717487849355225, 0.06419604599115349, 0.03910563225227018, 0.03594283825687824, 0.03322590743341754, 0.031638638371781956, 0.03130070741228279, 0.03872498997577256, 0.056184463187932014, 0.05653762589058569, 0.05845259672271148, 0.021807548867899085, 0.04944794563456409, 0.08801239422492443, 0.08468789439047537, 0.02608924875065925, 0.07459575851117412, 0.03158773757487295, 0.05343845932774487, 0.022334657579420075, 0.04623018866104465, 0.06581105892696688, 0.05116777472017754, 0.00461434675080161, 0.015005231065104806, 0.0356676250005201, 0.03933621322615974, 0.023279334005389004, 0.05448962389040859, 0.04552420799530322, 0.02242275386027271, 0.015027337489769825, 0.056556712971219135, 0.014815057398781422, 0.021895696859686606, 0.009169866567507628, 0.02827986376360059, 0.045058905342293364, 0.02347592940373767, 0.07120956561618275, 0.045050244718309373, 0.05568306630236968, 0.003220713594102211, 0.046514472398426265, 0.0015982104730116384, 0.03523853149325137, 0.05086758316704824, 0.040861000156691, 0.025576170939471454, 0.024805804414133874, 0.09858587080793035, 0.062224580005051634, 0.026670318780346747, 0.059656657113303105, 0.07284956067920693, 0.04658644635891242, 0.05680588689903098, 0.038453833154973485, 0.027258712610590364, 0.04679351609440581, 0.09568262740128464, 0.031051952917609486, 0.05841940213295241, 0.02317468639493229, 0.03827539212521046, 0.03179214132438985, 0.0357358489606169, 0.04562661479858141, 0.018140770524980563, 0.05526530323550106, 0.06759296411708479, 0.0333002639273482, 0.07697574088289853, 0.04398157504657584, 0.013961778135008871, 0.012306993744606453, 0.006645360751257789, 0.01601319114166883, 0.04528802691868717, 0.024953567452969092, 0.03097228168870413, 0.03988650184304964, 0.020743554247723475, 0.04391482963617291, 0.07154794665233744, 0.008497741242359963, 0.060205605076325525, 0.04826005736005403, 0.007099325302988292, 0.0340375775891927, 0.038525692202271, 0.08552216414001682, 0.08662519285515433, 0.08925285911367786, 0.032160757935696074, 0.01853233146961899, 0.03444225587431462, 0.012837374609174028, 0.02742843172933546, 0.021786106066898476, 0.00900915855797188, 0.016321608563885093, 0.13206549890099034, 0.10063900176676051, 0.1043138106263453, 0.20816750884536775, 0.16568580371958597, 0.1227132047736837, 0.12737655816900154, 0.13935058137341855, 0.1624401036890284, 0.13941542305532964, 0.07265508159874909, 0.15098711986455227, 0.07749467352104765, 0.17042431800115496, 0.125611039599584, 0.12034098287263226, 0.0995782457832848, 0.2709752886045364, 0.1843228996280701, 0.14148425881660756, 0.11415373503921494, 0.17505167292491083, 0.24583042899687446, 0.18354806297969434, 0.12344636623897862, 0.1685719786872787, 0.11477471058887821, 0.14644388139488237, 0.10956755734138912, 0.10636635935835301, 0.19050938137356313, 0.23314896189878065, 0.17740604497732657, 0.09476333721390656, 0.06200063335258634, 0.10330344024564951, 0.10149272248869944, 0.14805185398267162, 0.13771029519698313, 0.23782818097501035, 0.14340787495095886, 0.11271509852620865, 0.13777982533699082, 0.11845384018435595, 0.2048167168733574, 0.12815443618643668, 0.1672683421882891, 0.0826642195123338, 0.08848110213875772, 0.15626298353797005, 0.16527940939751365, 0.19100986661449557, 0.13079783789092495, 0.130674283230497, 0.11326926354799541, 0.08194061116345468, 0.0614745531141037, 0.13144345082823308, 0.12621788848792354, 0.1149245267433505, 0.11405456495741684, 0.20114487277403956, 0.1391210920748211, 0.20512316736482805, 0.09856323290976787, 0.13186233238347117, 0.19991986753959812, 0.20878537407805844, 0.1657829743119017, 0.10760083343953857, 0.0886830888808735, 0.13480648488527344, 0.14037024440063586, 0.17646070780052295, 0.10494872131535124, 0.125768355754835, 0.15093409125843357, 0.10608486801145539, 0.06831919248666495, 0.1764113564164408, 0.051032774706160834, 0.09561443791514444, 0.12628194876015186, 0.11424438622329505, 0.14705229310258744, 0.11736794885608459, 0.12392563850528772, 0.2734997321761424, 0.14394681780569016, 0.25288908652240233, 0.31931752038578837, 0.15659111431769787, 0.14327138872636905, 0.203857819940294, 0.15053973983853094, 0.3698696400369368, 0.1877260460488258, 0.2988346275543013, 0.15798061395124083, 0.24629478553129783, 0.16111405145737434, 0.1365821847632047, 0.17348407317073117, 0.10793919915393477, 0.17983743950964945, 0.16727091624371468, 0.17277564102363202, 0.06457522887015535, 0.10629111420243018, 0.12609728326600406, 0.12877614718050728, 0.22070525784886655, 0.07023655734355412, 0.11856745868440598, 0.13977473361357567, 0.11290920222358358, 0.11896610785756381, 0.15472084854639348, 0.1652786126660724, 0.17106132011019415, 0.12080311775207521, 0.08396217929980448, 0.09757379971204266, 0.1455351172555839, 0.22031511991254746, 0.1339550854097451, 0.10369858839699339, 0.15461258500093414, 0.190741092327141, 0.2103578001861611, 0.15384366255133383, 0.09189510402540046, 0.09103044356790282, 0.287377598785585, 0.12873896127266268, 0.13994203189448004, 0.15537767701091307, 0.19480578631402987, 0.2649966771564176, 0.1831205093091534, 0.1583507416709777, 0.11723756069137205, 0.16094086962121149, 0.11930091126311211, 0.14768229316799872, 0.12730602445381303, 0.12148211680112347, 0.23780434031880673, 0.12772500560048128, 0.226966877497973, 0.11175844623076339, 0.11672023683786394, 0.09002900577240414, 0.10325889989373185, 0.12061885062364802, 0.12895224015078238, 0.15808873960087377, 0.16765595203445804, 0.13177236301764367, 0.20635800916821728, 0.35355371393023, 0.16512386290536774, 0.18455936032677853, 0.09125064021997875, 0.11291114042603201, 0.19427790576892515, 0.15960950073936295, 0.25271175248968986, 0.11006261867981766, 0.09699007901813715, 0.1356447842572966, 0.2387599583955542, 0.13989870196148274, 0.09742764545784843, 0.1136969704361212, 0.11519002983526838], [0.05610515010513126, 0.034583522487551935, 0.06156749107063778, 0.12004968560030384, 0.015588601273784955, 0.018827309794423562, 0.044654644575090184, 0.04616446980846025, 0.051745485454317064, 0.05879924767800878, 0.01778546660657852, 0.04694212949083698, 0.008740526954493216, 0.01136652218373192, 0.06394886006150516, 0.055754925349667195, 0.0898917611207693, 0.06831900096468388, 0.029768250026409666, 0.015104431790419886, 0.06457080854283226, 0.009088992580561148, 0.03591645801920564, 0.059358982159005064, 0.046076350544969884, 0.028419914212258115, 0.0266419792728078, 0.04428080515936018, 0.05986726617500667, 0.07299322514764725, 0.03706852402237635, 0.013822910334584455, 0.04369815698854866, 0.06240929912535414, 0.08658933227941876, 0.05304110484317907, 0.06398191675543785, 0.049329316919489254, 0.034250121022905075, 0.03956076891852483, 0.051101577062640464, 0.03385847772381479, 0.056574378958753044, 0.06892004290655737, 0.04730628555520408, 0.018460003193467855, 0.012069434667336605, 0.09083846193407813, 0.03604141845097465, 0.022660729497851386, 0.0365066674778298, 0.08875709297435899, 0.08359913023248797, 0.026007664217163, 0.01059598041578166, 0.06259108412890665, 0.04520369595998237, 0.012729518047924484, 0.08280257499145885, 0.03123736534748347, 0.021010664209062536, 0.026128941681236032, 0.021729900111113826, 0.0741731461077448, 0.05949057691219834, 0.009632077098133103, 0.051157329111329974, 0.023737123251081477, 0.058973865929029645, 0.00872535075271322, 0.05989084636131602, 0.04473188539005576, 0.03707975870178592, 0.021115489934961644, 0.07446013796593874, 0.017442088761937716, 0.053299697822019945, 0.016079105346673922, 0.0384789455171314, 0.03118751983669016, 0.0671635565137671, 0.015163753808836545, 0.020551972894839222, 0.022346805818679354, 0.06784087783026119, 0.02673828993142853, 0.006190601383305846, 0.05795097767165112, 0.015264262629282332, 0.042095244411499276, 0.08071384392678738, 0.0680168635482269, 0.03399239755385826, 0.15513600691431953, 0.02915467488609495, 0.07409629216718097, 0.06396707763234455, 0.04370992409906561, 0.027154654887835347, 0.030884394166810863, 0.017175773616820093, 0.05067721414830416, 0.05121681200821073, 0.0285349729576058, 0.03933432864986601, 0.0735987333821193, 0.015335170769943826, 0.032411624917820576, 0.018692983937780225, 0.04466829243146124, 0.02006806388136841, 0.04598757244586464, 0.04568784437592953, 0.06937743570174902, 0.07970459969534029, 0.02469317608272597, 0.01595153925835245, 0.04162400074663662, 0.12228280125606446, 0.029186511585008235, 0.03595475858498005, 0.0194751079975357, 0.06563017024628578, 0.014506599756949132, 0.03225140528933656, 0.009035646047953878, 0.06078604308347549, 0.03488739509315741, 0.007694759960061, 0.028097368213498307, 0.028477221419433915, 0.02913391964900638, 0.038067031531564655, 0.058129935810763034, 0.02721745686064805, 0.030920766106235887, 0.06281946643045352, 0.012569865324504435, 0.01744811021302256, 0.021371773158710812, 0.017827220313671618, 0.07771680837557202, 0.08268833596019015, 0.04370417460919388, 0.04897564476836593, 0.04840578643545028, 0.017090906396568302, 0.0012158869926239394, 0.008473479237798, 0.03590161123523309, 0.02589878971658407, 0.07570615699214321, 0.04584938550608293, 0.028024057429584286, 0.03780120668271857, 0.03872659109953431, 0.043444754255394784, 0.07389675690642289, 0.052072313884573604, 0.03270683306900244, 0.04156512305921605, 0.05498478482026727, 0.035032775598548116, 0.01163713795493447, 0.02687341060429331, 0.039279534211081844, 0.02893217805502636, 0.031271737797426126, 0.06431647501285039, 0.03456481462044101, 0.05383737280123657, 0.03368857857440749, 0.023387270048260692, 0.033998920792533506, 0.05333446672246341, 0.06310058239426825, 0.08314768227958873, 0.0060313522924609, 0.047861369882499984, 0.030092355014095386, 0.01791898041002212, 0.0666568506388895, 0.04609541081252598, 0.07252925165718602, 0.015608257174702182, 0.11505509110828561, 0.039172657284765475, 0.03002495076807757, 0.060234084394910646, 0.013878842413936172, 0.08440755217546418, 0.03288281878696815, 0.05876888761356954, 0.010678146218490458, 0.041885998986300924, 0.009303284609960693, 0.0019354501578603843, 0.024454353917990963, 0.060411870419498415, 0.02421540343352864, 0.04993193700248676, 0.023185719976261742, 0.12414899910049093, 0.06690000694605612, 0.01598491196355392, 0.0300322764838535, 0.01715917632194056, 0.03004683790007426, 0.025553205538721337, 0.05490125442344335, 0.05426652759553925, 0.0429874457298748, 0.04521327205903588, 0.03727953144980054, 0.05235509225918401, 0.03197702323837626, 0.06200255623327629, 0.04389706788764846, 0.06883614861796941, 0.042752069045579245, 0.04476511062333181, 0.02304150392451594, 0.0289451249409467, 0.0493893513996755, 0.042606688540188536, 0.043078100744394526, 0.04764963467154772, 0.04101201523876479, 0.023827826146096475, 0.02428592182695866, 0.03283500723961381, 0.0754998188706175, 0.030457698514745123, 0.03396491031913507, 0.03274444415564499, 0.05131002575639756, 0.027557448596663536, 0.04307420518729956, 0.01599700849187831, 0.03691219612054768, 0.019527050674021728, 0.019569009309634566, 0.01966554213375334, 0.061258297984398184, 0.06349710184299658, 0.04262957924736604, 0.04662889912123642, 0.012681259296744341, 0.004348914522016722, 0.0605447713526026, 0.0482533770733543, 0.03351260051732102, 0.0074877548632362205, 0.029325098805730383, 0.04588774352845165, 0.04053019956054707, 0.05502664003401034, 0.04974934377617413, 0.05669671170894177, 0.014533195456850433, 0.04988605982714123, 0.03343511455421967, 0.009479651456668733, 0.11987882501055157, 0.02408774254182654, 0.06307530532320661, 0.03297711271912821, 0.04169420887445731, 0.12078015043610528, 0.11453959054403728, 0.049879000326918985, 0.016693391033538407, 0.09925097302203217, 0.078398764524008, 0.03328135687737696, 0.021496201159372445, 0.08297807807403226, 0.05922618847821028, 0.02572076237430015, 0.03545539183241706, 0.06569390876158591, 0.041262070167689555, 0.0197446407119353, 0.0622197421598098, 0.026037149026148745, 0.06552969015413715, 0.020313031986475955, 0.09299972620342048, 0.07585814117544121, 0.13684651574059842, 0.06466297658100244, 0.043658431499235095, 0.04893348694989278, 0.03268277024730079, 0.05260684407286106, 0.008363256422472338, 0.04417025484144688, 0.033988513488082156, 0.06967881469116097, 0.016943365523231127, 0.015391945546012253, 0.01860438969977681, 0.09938205832675581, 0.011105462401774863, 0.07589600124065915, 0.08364095097227443, 0.011622705816050932, 0.0027979735891529994, 0.014201203593984248, 0.06719949369829509, 0.010390599904161309, 0.023587469890293096, 0.040814816546175754, 0.03488782027195539, 0.0073004698271923255, 0.09399854397821812, 0.057121346584491195, 0.051953727304334604, 0.1152731656968113, 0.042494720959615324, 0.029506772726533875, 0.06262445874932794, 0.023186518622922803, 0.032106382930050456, 0.04662771168495378, 0.021958569695632306, 0.057515345603948644, 0.0938785056613626, 0.017722055593866016, 0.020888869635640614, 0.022228238390638463, 0.06699513208361403, 0.0713867387704311, 0.02522566273147541, 0.04337471083647782, 0.025392371124678084, 0.035320499070709756, 0.03910207760430152, 0.051572989266846454, 0.024621654114115144, 0.018540053635895736, 0.05204439764061282, 0.08332009036694804, 0.051488240790222926, 0.06654464174062014, 0.04582158800575041, 0.011816070238578946, 0.05651900229314643, 0.04189151098891612, 0.08847026199462915, 0.06170479317886695, 0.035815606374413736, 0.22474932874883377, 0.20180127222932157, 0.12061230057189543, 0.17464779137123018, 0.1572401440071483, 0.11961529842547833, 0.12764355513237177, 0.15720620631210266, 0.13587151563936664, 0.14300273701308236, 0.15453347876187296, 0.12198233391128241, 0.1665445423174289, 0.10046623361807677, 0.22740017682794603, 0.057028837637194706, 0.17264444080571975, 0.1561947251039167, 0.18679820632021274, 0.11582704726606609, 0.1663236178818249, 0.12575019181015032, 0.1795225620510117, 0.16143801471879407, 0.12160002539354949, 0.1608844549064675, 0.1801840636518694, 0.11660870975784718, 0.1024977915409592, 0.14893958134756935, 0.14784565375697228, 0.17630686202356893, 0.11764557911984383, 0.13542533071050722, 0.20295489339097855, 0.17494141755084838, 0.13068315452866017, 0.16265811699052013, 0.1668982757555862, 0.10264634365035642, 0.16512357179195652, 0.14638233389104569, 0.1793954374208566, 0.21506121231903955, 0.1503311340967494, 0.09166553811801058, 0.15589288646175017, 0.19208698623603393, 0.16996314839249657, 0.21862968051385498, 0.14421108749604997, 0.14461221113320322, 0.1558464308900218, 0.09878347552711926, 0.08657327507652583, 0.15470235518390132, 0.16782234633161178, 0.1559835759502265, 0.21723452715143082, 0.169857305684878, 0.10894036881865994, 0.11755244581088906, 0.17583242377206204, 0.16266502710359712, 0.09287433293197425, 0.1246941625891674, 0.12390749754324076, 0.16580312242431028, 0.18445341036685053, 0.06850746625493612, 0.11278858934078487, 0.15794430138362994, 0.14054696556300889, 0.05944166219823303, 0.1541158535908307, 0.06473438363642463, 0.1441844123145265, 0.11298961847299531, 0.14937858037169904, 0.12995126476931956, 0.20962266221402154, 0.11423063494505421, 0.18878062736363183, 0.07771991869254459, 0.13904480503932123, 0.12994099919113422, 0.1012414762930524, 0.1884298050595868, 0.10559903803251444, 0.10743851473014202, 0.15177617510480268, 0.17837548328022804, 0.2795353712093446, 0.26691054865237207, 0.18052308820188048, 0.14634360048559406, 0.16727606435456585, 0.22685317472825128, 0.2017325541425136, 0.15814354553097681, 0.16831297968183795, 0.1467281306583074, 0.11571881436412373, 0.10107351151565391, 0.150317145331252, 0.19011954987241378, 0.05692749186569164, 0.09950923658306561, 0.09769102648621607, 0.20080250808067862, 0.08130112692954079, 0.16560147276088116, 0.2417498616681945, 0.2602183722680615, 0.15752137488415166, 0.10222756168654851, 0.14331079628919402, 0.13951132194169108, 0.21860124333010567, 0.14294462158314644, 0.16455914885286363, 0.17185238250080617, 0.14282324261242343, 0.07932642805239848, 0.1068246331546576, 0.14678555660911147, 0.14752450969911393, 0.20671373443497768, 0.21676589584638997, 0.1617623916676929, 0.14679346263649004, 0.09457012983940302, 0.1569148477527403, 0.180984073949437, 0.1095429965625367, 0.1094517018646002, 0.1985823852761138, 0.08498913548406094, 0.10778703877041418, 0.1123429176908347, 0.16025437823226377, 0.13523013150740054, 0.1293515864639513, 0.11964174378062449, 0.10389106798796885, 0.1882414700042817, 0.14038458556657837, 0.09931190765552944, 0.148567323903403, 0.19492111319015104, 0.1876631042649669, 0.45310331568602596, 0.06689690428996278, 0.11694651622805866, 0.1056784047414699, 0.198942048234805, 0.2869648306119827, 0.14993391750800997, 0.09296929719106806, 0.1271711623356227, 0.11263411537173296, 0.09848688458723408, 0.16500243796936928, 0.14572578121817883, 0.12762831764355784, 0.15102384611964226, 0.1806740228447222, 0.12494440520963362, 0.09054834443715312, 0.15454538376821628, 0.10303035288328126, 0.1560547914836676, 0.14780725743020737, 0.25155483714995847, 0.1430796982059556, 0.12262876656266952], [0.04453981182568016, 0.05436443746270192, 0.02250598356758635, 0.010703537245130828, 0.041319959601687814, 0.05967767473550574, 0.054433408358524886, 0.008228779263463954, 0.08397085141510734, 0.05694580519752157, 0.1236032687067505, 0.025654758153963956, 0.007809068418047842, 0.010737954702739035, 0.051879926224149046, 0.02519620090512739, 0.027903105552879073, 0.07196338081191625, 0.04357973128677376, 0.02499399199751356, 0.04046007953283768, 0.05501036066561938, 0.045720410773590694, 0.03521212827294104, 0.048914648847834724, 0.03689745658888452, 0.11615516272403541, 0.06833528033307484, 0.05299407087506787, 0.04986116580004173, 0.049169736974422014, 0.044142687167491645, 0.060521367366515824, 0.04497748168726121, 0.02588620289198814, 0.026824089863728133, 0.011208526125448126, 0.03936386133934702, 0.023025728258935195, 0.0488595211608035, 0.024078790804431326, 0.059012813839100065, 0.033464179930066874, 0.06916202709919984, 0.003696867882559497, 0.020077348867010687, 0.03231587541860438, 0.03402363095853118, 0.07357660876286608, 0.0094771042143205, 0.042428006192729364, 0.008603811861136028, 0.05208796506086665, 0.04911808732656702, 0.04826451216133372, 0.045102710249803724, 0.02713669012601097, 0.02305108576922888, 0.024150071455346003, 0.04731512237941066, 0.0018819889514669478, 0.07266574554265508, 0.039721800600208586, 0.025199401237431075, 0.09092856153485276, 0.04434154827087637, 0.027835515530539617, 0.010998686982108461, 0.024766410257847562, 0.041766742079128186, 0.007183333547154983, 0.01930904311818942, 0.02565699896114248, 0.023097832454368476, 0.06838345194175359, 0.06195542267373493, 0.09666465252878205, 0.015298449302903347, 0.054455598095251675, 0.06033467173936868, 0.046054869439573064, 0.054934012343085585, 0.08456980193694753, 0.03507624342737179, 0.03500118596299041, 0.028781316190537427, 0.03244726715849773, 0.06154981742222464, 0.07502346539929991, 0.02738002837905961, 0.02951958937750709, 0.03194543551803837, 0.04478134402644731, 0.08326361436517009, 0.017245426330895677, 0.05574893454209932, 0.10338113688293005, 0.008473538609612133, 0.027009337584698395, 0.06283766867953443, 0.06909062004377765, 0.01165673735686728, 0.021110579311367006, 0.01167844637342158, 0.04617391567256662, 0.04294218525530831, 0.044608686960512595, 0.017803971460389516, 0.025852960421733802, 0.050959456261367574, 0.026313417568622578, 0.007956121867943195, 0.03232670024097447, 0.03533279861233408, 0.015866508286806847, 0.02109979279339314, 0.017874595190909122, 0.10008222438515195, 0.07635987513969023, 0.046623475218732516, 0.038715141915505936, 0.02829919790758962, 0.025770125249701164, 0.04146388454002239, 0.028396801339582573, 0.028767716214661638, 0.06050908314664999, 0.027318120813898505, 0.03607960027312079, 0.017659701782489018, 0.07651997219410635, 0.041027842615280426, 0.03151391542726948, 0.039872030442159985, 0.0733313150703907, 0.051930342470445943, 0.028529443718012304, 0.06254397738244265, 0.06674446045391022, 0.018979395484371532, 0.03678614018304694, 0.04543692376765032, 0.01821063199801551, 0.0691411895076594, 0.06150992339356773, 0.049626432629602577, 0.11630931493615913, 0.0375126175312025, 0.02625742994789635, 0.011070638917566789, 0.026713964724612814, 0.022321026960027315, 0.05530946820433583, 0.09886120280791676, 0.02201059281135038, 0.06242521843242069, 0.03655497315189531, 0.04719766194842035, 0.0864270288917807, 0.035994066556374875, 0.065560732036829, 0.058661010942511985, 0.034796832009188594, 0.033602033621601524, 0.05566230148918206, 0.032766748805560415, 0.05048771846979376, 0.027806963433601686, 0.008871099937917485, 0.023372289198901386, 0.03739553631373471, 0.036244416429150494, 0.01923259520422547, 0.011487008662023132, 0.03246867165510212, 0.0327557937482432, 0.04175846832954595, 0.04535639260504996, 0.06482164105100018, 0.05608027523022987, 0.015640990196486876, 0.06494938621237394, 0.0377259883398731, 0.032355704329787724, 0.06354644173575986, 0.018101615771170587, 0.03334849299262128, 0.012610737072874703, 0.03370815595131248, 0.049789762575059175, 0.04053653510768087, 0.02299105511948226, 0.008946209113233754, 0.024504341155050263, 0.024617919435484276, 0.014345724165679948, 0.060654000168846506, 0.0364421475528469, 0.0064272167360139715, 0.07863419100401864, 0.030141208441026753, 0.0641390988453021, 0.02234294473554098, 0.028810036826818704, 0.05158727297619466, 0.047285896125099355, 0.0454438989982009, 0.027831110524975007, 0.062398512607380274, 0.009091986069125275, 0.04089617508373434, 0.01432040495978248, 0.027997803596419193, 0.05915674260787426, 0.08494902312034562, 0.0657459874186785, 0.02220238483841381, 0.008836855807702148, 0.022842612177614244, 0.04665619483397854, 0.03743526180304828, 0.0424370153867189, 0.06383096679083763, 0.029979542821585655, 0.04850848052170008, 0.016043811676002318, 0.031624454253863905, 0.024425493470663508, 0.022752098889360507, 0.02714562271120808, 0.015165786814665603, 0.0074645428779354745, 0.024804341186198498, 0.037454984736658876, 0.07866431358120135, 0.02873185946936569, 0.04385927677034371, 0.02552434317617407, 0.020441361289891987, 0.015165012108252175, 0.054756670649493897, 0.07300113117502582, 0.05480729756996997, 0.058423477720709584, 0.032907640035714836, 0.010131395012590914, 0.05914584883759099, 0.019348665185633208, 0.04174305464050943, 0.07444680803605626, 0.08081435466245299, 0.04002654271560811, 0.06618786693340348, 0.01777841668245533, 0.03725872067133746, 0.038296287173345205, 0.06504304046111722, 0.04401319915609014, 0.07757321285504488, 0.011151543548030239, 0.01723464172814162, 0.06803675119074122, 0.0540666246125775, 0.03879172389485663, 0.0279723005294199, 0.022671977583799633, 0.0627096247438702, 0.022592545757370613, 0.03049929517381374, 0.05227090302674521, 0.030897272104818015, 0.0019403951357103767, 0.048055170975144834, 0.0732657379440723, 0.016120106372381413, 0.039602018922807715, 0.07049073765595114, 0.05104453798623816, 0.05106477419875803, 0.05617219045938504, 0.005987848074460823, 0.04297098633082163, 0.03742815250711095, 0.033648286180029956, 0.04174927144401497, 0.06772792582670528, 0.03635360311055857, 0.036757296972697785, 0.02375979945364018, 0.077041256722183, 0.08494256499914393, 0.03756723576976407, 0.032065538952367446, 0.050750957771895394, 0.00921208471540482, 0.0501021464175034, 0.0923915290003342, 0.07088619224246472, 0.03097993873750731, 0.04551105809608295, 0.020139292821348197, 0.019364720473306316, 0.08598498083771237, 0.047774507003205444, 0.023483783720181357, 0.06483916914270771, 0.04259958690513046, 0.02184629184944976, 0.04192422677372252, 0.07888993413578119, 0.08364188559954205, 0.044849541173466755, 0.02245075437390516, 0.039325330947195335, 0.04825636864669862, 0.02685218613835112, 0.013840007501834584, 0.05383408628404141, 0.013596764052166574, 0.06685761930120569, 0.036123431993708495, 0.02878793710542302, 0.06755632213166646, 0.0409663066027626, 0.03204223264249102, 0.007958484770384648, 0.014703995717178672, 0.11778468536513469, 0.04636805001345854, 0.04142791671197742, 0.026816917365537058, 0.1109839236784366, 0.011061562690883877, 0.027199607012012315, 0.08566670960957005, 0.03216936493352537, 0.0485768155645459, 0.027097506643903833, 0.04452722883152385, 0.012574688805597685, 0.0527826382688457, 0.048709999950182055, 0.026122615710201285, 0.02046507554158809, 0.06716377101838589, 0.01809061666379773, 0.07084755076756401, 0.02729947423382152, 0.024587139937906496, 0.04617043763339039, 0.046255205262212024, 0.024765429665304484, 0.1352890743122947, 0.21293700372259464, 0.12423504609614612, 0.2096113241127422, 0.12759071804823416, 0.16084097175588533, 0.17239114149443566, 0.16682597237729258, 0.18341862476400791, 0.22031092175072242, 0.4398287892822297, 0.10525475045846355, 0.11196103052146013, 0.11520179694578533, 0.1015396606958201, 0.098939458689382, 0.11616458560550406, 0.24394591399017843, 0.1402181606259077, 0.09586268870700752, 0.2222654418719392, 0.14904252824283418, 0.10592534552298247, 0.22500786810151993, 0.09122855390512175, 0.13973046905331074, 0.18413831840359396, 0.12754144327294442, 0.1425729770093195, 0.1267259273557894, 0.18406052983576254, 0.10730987324589684, 0.20096194629947986, 0.10183964540520984, 0.20797215642467623, 0.1387682319768975, 0.07105602627439846, 0.14278999439650966, 0.1471697650248966, 0.18064958463993766, 0.08812416645307695, 0.10004935155232107, 0.16660005304842226, 0.18672956484219722, 0.15093134866366464, 0.15756326457185132, 0.19285299755152197, 0.13820480495210619, 0.11119715659128082, 0.1251435267829126, 0.11584466728832453, 0.12770209191066603, 0.158007564924417, 0.13176257241397135, 0.14845676209417083, 0.16114904635375546, 0.06524481269861422, 0.1625207880692136, 0.12927177542399976, 0.16745951176891405, 0.10451844037179986, 0.21924978272328455, 0.12837168340000416, 0.1401605354922433, 0.18569620416289379, 0.20806797870224525, 0.17166821496380916, 0.13522829289638227, 0.07116580667394785, 0.09708550292998554, 0.20374203341141825, 0.11778350558973129, 0.16753851075566586, 0.2550238671322023, 0.22150258683869917, 0.16738618183280193, 0.21727539028131196, 0.1072468854967625, 0.11626125057978977, 0.15353284535869477, 0.13063289916082738, 0.1718464836237892, 0.1772532104364326, 0.11294174563860702, 0.107756081157394, 0.11084064991483766, 0.16539226947051866, 0.22131690244761207, 0.10128499008715154, 0.10756763118890025, 0.14825851386112554, 0.1782721380192426, 0.1384150654438042, 0.18157527932236273, 0.18569070365159743, 0.21878873568869409, 0.2502842037187469, 0.22922983993926357, 0.1506601228949524, 0.24859597576001, 0.14855299805921895, 0.19357393225354536, 0.061088004299709876, 0.08862947038705311, 0.08787708777573802, 0.06898636313816232, 0.09011704459666245, 0.06470616095729413, 0.18263336931986196, 0.1290405700884519, 0.12845940046733426, 0.13892344139035673, 0.13999224129703738, 0.20109282476046395, 0.2209421015915371, 0.07128993590031901, 0.07486198172574082, 0.23503289467865424, 0.14736107250134792, 0.16160106887259792, 0.0889247206730708, 0.1094041507871401, 0.11596190938425642, 0.10861010065362339, 0.09286365366630978, 0.15681183957044156, 0.15208066441118717, 0.14099161831601975, 0.10627999060576963, 0.19018186346417476, 0.10992476115784339, 0.11953354152219912, 0.14618920312533457, 0.1372614442821472, 0.20435311110509982, 0.15520469435761053, 0.10758645396919982, 0.14736278853829832, 0.1635321620250902, 0.17347325600924032, 0.17146294936537745, 0.17443186182889248, 0.07340259189086576, 0.14514784448810164, 0.144072103824827, 0.18113373688632445, 0.15509191089339797, 0.13353294031994958, 0.07974475036345183, 0.0810833357935471, 0.08143297832218871, 0.18326752158182283, 0.20542557291205854, 0.17722572320170943, 0.12071179241062173, 0.12857557004017214, 0.13425422742241813, 0.13054193388069832, 0.25002112912554897, 0.13916039238533667, 0.1430661537714543, 0.09957842198350739, 0.1606812883889483, 0.11833354139760618, 0.13789979470593317, 0.2101380555259605, 0.1784461165868467, 0.1438708525271185, 0.10839985548368386, 0.09649202993680393, 0.19316891688973675, 0.062405380585621444, 0.1764378783803794, 0.09364033658658305, 0.12439012527465822, 0.15332335095492103], [0.04739827739315168, 0.027974811382591728, 0.014988845402014353, 0.03500596635163792, 0.048959292621622165, 0.015239770798343084, 0.062001759501835035, 0.02280812864492257, 0.04958787542437354, 0.028601040380195748, 0.058223747107530796, 0.06460499138601365, 0.019887211589863705, 0.03580514161336807, 0.026559469688142982, 0.024952809025924054, 0.04747656774857352, 0.03315579506658739, 0.012879997826061182, 0.0307052310991792, 0.013579471532495753, 0.03462825436145067, 0.07412968593980036, 0.10537943892901945, 0.09914467066165902, 0.04989770819402991, 0.11215245291110008, 0.012937850870883033, 0.058386694009025256, 0.020534649731651432, 0.020681809476246277, 0.013956120575688059, 0.06588233574744194, 0.0726113226565142, 0.06877810979682593, 0.028596937979361223, 0.03686045454214177, 0.041730820216358676, 0.09036171775791915, 0.025146476053182158, 0.047891174533194115, 0.01236384034141778, 0.012016718242047055, 0.03980438870888564, 0.11424371206592168, 0.039211417503294446, 0.03601495777407, 0.028109416861327428, 0.07762023533183722, 0.03713470635815494, 0.029839523016445102, 0.06092136102398077, 0.03091612935907418, 0.040220696208698135, 0.06113401937088179, 0.021955407667724837, 0.031727012359507145, 0.04222449493564425, 0.007149002274438258, 0.04910692925594988, 0.08234336656788666, 0.013992112343980661, 0.018707208275314302, 0.034277297992018924, 0.017035424393872102, 0.04570133901471573, 0.0219312395089336, 0.05717306134981975, 0.07124881230054364, 0.02163419466195328, 0.04657211285384913, 0.02546640777690036, 0.01991880122542141, 0.01461501747760321, 0.02415113248712113, 0.019909389835271626, 0.015166192841265472, 0.02357775781063303, 0.03772758563319522, 0.011054982953224213, 0.03909726657213704, 0.037276428793707204, 0.01759787657177977, 0.020907933733636336, 0.035517536884834694, 0.026144332387634826, 0.043195641614616885, 0.039039649099351904, 0.03709486212521311, 0.0931937915963992, 0.05412579724384893, 0.07136318156675947, 0.02394204027950764, 0.06355511385106272, 0.06294895827229466, 0.06791898815502083, 0.10497191079681921, 0.04857827879248127, 0.05913683198272221, 0.01632192457515386, 0.04883517488656987, 0.08638098700753144, 0.043790980031894106, 0.06665196299793259, 0.010730258391929731, 0.042805951839733514, 0.036470335758020805, 0.05027484944871357, 0.056854154268700274, 0.035066977593927615, 0.049400333270070054, 0.034202451201816725, 0.025616469079508417, 0.012362844427116217, 0.033026241937712315, 0.0335671651297279, 0.04082301368696555, 0.07499583260787111, 0.056151172837182406, 0.11093932203948499, 0.03916056075644109, 0.03210167531975575, 0.01943490753370908, 0.07959546280964729, 0.02912837700287421, 0.04873953647010269, 0.047159211995500716, 0.04380598769433076, 0.029663527722380338, 0.039547990571947834, 0.025138106542609395, 0.051503608513983994, 0.054528943353122285, 0.01985998674025459, 0.027946420164117892, 0.005400113079832086, 0.041703942021535295, 0.06028419803647746, 0.01955420466049785, 0.0710223337274886, 0.0380268961852116, 0.028761183399887338, 0.052948523117529775, 0.005778852585447772, 0.027763457300381798, 0.040798675073611165, 0.037321390493983225, 0.026223723994447824, 0.06092107757144879, 0.04094075757048784, 0.032838075421750546, 0.0567613082427171, 0.01964158464914128, 0.01878512516287306, 0.01736179125615426, 0.09712571488513101, 0.050791736632104845, 0.041103302275822054, 0.08383012872429625, 0.055238183722981525, 0.06696018315250836, 0.020497708971942627, 0.039253414443303505, 0.024573493996755253, 0.04040954837335214, 0.03473005212482906, 0.043751212407744704, 0.04459608481415818, 0.03353810741475994, 0.03146624560618112, 0.03829368247440265, 0.07333289321151472, 0.06940861548026724, 0.023432492218430967, 0.04318927159352649, 0.04490301794102115, 0.004057562665923709, 0.05396593001581008, 0.0844223223506443, 0.04603490135782669, 0.0039728275958388565, 0.06114872059814873, 0.0416541003411816, 0.04800975345255387, 0.023170317778544083, 0.0213352250190632, 0.025160790406047337, 0.09730582215612936, 0.05342516004137936, 0.058695933060540315, 0.051165273443104765, 0.014227523502232808, 0.15997440373945623, 0.018778927511565627, 0.03366040569099207, 0.009830385660602441, 0.02759876180320017, 0.02074802054032203, 0.0478431714638587, 0.03230233481454273, 0.0763203373419181, 0.06072630354714009, 0.05971667244129124, 0.09132072194329194, 0.044026498442455646, 0.056496885334772456, 0.019742905522786805, 0.028348488004637823, 0.050932256309615995, 0.05090417535675149, 0.04023362777285999, 0.04684655236140375, 0.02515446060457297, 0.049582160408458406, 0.05132945757659693, 0.05201170100800453, 0.016774944923517686, 0.04774133922652372, 0.03639578008122983, 0.07851941571120294, 0.07683420613888772, 0.021200774673132167, 0.04104058265746121, 0.03991626435890794, 0.07034339596547427, 0.0736795939625271, 0.060403749887501045, 0.06106895935391227, 0.06560121212274798, 0.011291025176403985, 0.03545257645929533, 0.04079008339754036, 0.02789943790694158, 0.04250043597553046, 0.06064239776723328, 0.04548850829803175, 0.035277284050901095, 0.03220817111732979, 0.08472012370944985, 0.04507749063533641, 0.031853535610641685, 0.007950818145482411, 0.06213155011796664, 0.049461344512359756, 0.016696376861223293, 0.05122576757604557, 0.03002798639147753, 0.031244170123470888, 0.031249994306915233, 0.020530974424834696, 0.03333745749607202, 0.025952503971394994, 0.059542732178083355, 0.021207550720822428, 0.03219331284203837, 0.022041247819640467, 0.08628959271816478, 0.04948235064324352, 0.023636300334586732, 0.05419918080611576, 0.05840223793300891, 0.0469601555396953, 0.02418224331772616, 0.0366073735659161, 0.045567265967087406, 0.12429500779797956, 0.05449177659747582, 0.08267516690877177, 0.03757270563754343, 0.04520371128174086, 0.010076068142699379, 0.05302024426900091, 0.07030579637015058, 0.0953906253280659, 0.0437884021460289, 0.07715040126875525, 0.07730476032461851, 0.04006121968550067, 0.08176009020497722, 0.029816289484921484, 0.03794432722873265, 0.06462012928339743, 0.07035742303536785, 0.0194784194125884, 0.06447648779759485, 0.026743415059641968, 0.020729958102287307, 0.01684097404171142, 0.023765064392899795, 0.04555809972507339, 0.019475590632927996, 0.031521834861186725, 0.07085685873584402, 0.06455443724389039, 0.037485348631537733, 0.028155956702727466, 0.024295775632884715, 0.06807287223637104, 0.027788992926117875, 0.03571877286078469, 0.05036531677169185, 0.06238952639602846, 0.021823833981949477, 0.027117551334442633, 0.0573340738793054, 0.07130365653504288, 0.04962830188413782, 0.0060733760455473065, 0.05103177113098003, 0.05702993697336605, 0.04934658837174216, 0.01360613618031024, 0.03772471663391879, 0.05024518652428543, 0.016259189635034532, 0.03744217957700453, 0.029850587241291523, 0.02953040845421774, 0.0708816416801945, 0.07152300282952286, 0.019724308738424894, 0.0491806690491015, 0.03798011502611541, 0.022236293805162274, 0.04567679355762178, 0.01249144952218499, 0.017280505496948477, 0.041678821998498136, 0.0221957792452867, 0.047279020485978936, 0.07055012479184136, 0.047854812169868144, 0.08196542475132212, 0.044406114161134734, 0.012996525545003674, 0.02296556162858202, 0.051736380499336994, 0.028935435843924363, 0.050589558368007985, 0.05352637557793529, 0.05475603862695637, 0.0696647722995089, 0.06098849330878547, 0.011543806420729287, 0.08618221783469762, 0.0368432596986813, 0.03734006005669794, 0.054777362684328715, 0.037314748511679714, 0.018387247823298942, 0.0645170521531855, 0.0284288065778392, 0.13134289412729203, 0.1688435874999531, 0.1965165372577406, 0.1451813225303927, 0.06317195114529421, 0.15232058782731334, 0.21636930744974844, 0.1021460575922843, 0.10797587178287008, 0.08065456404320656, 0.2526183510499616, 0.15098860607512538, 0.13679400807426823, 0.1727474489880185, 0.1411995039351525, 0.10222338650736118, 0.28163966151975817, 0.15674770268942081, 0.10966966920081647, 0.10086918820536907, 0.09892665736016729, 0.08331377780245197, 0.17522198959223687, 0.14536758914830225, 0.23624080083062574, 0.21467240737570872, 0.22332973718162508, 0.1198117157083846, 0.2660445628627654, 0.1654603593652287, 0.17787902766177732, 0.09452157518676213, 0.1569235964768356, 0.14365766557954973, 0.162459684896373, 0.122009928398315, 0.13440988116687344, 0.19872382042869446, 0.21562929715841048, 0.1668501347904244, 0.2580017734679484, 0.20867582350488634, 0.10854218695913592, 0.11252752189794857, 0.18023597376961864, 0.17137757652709562, 0.12539514070076327, 0.15574440330026612, 0.16214912817362817, 0.1006880007503975, 0.1381025781794902, 0.1834991406048498, 0.1608433313066921, 0.16829218805557297, 0.13340701078695635, 0.14851582747313286, 0.15535886189149273, 0.10936030757523353, 0.24538156276028006, 0.10802331560802077, 0.09673847276116572, 0.07492496181399592, 0.21587069146335128, 0.14412312528058407, 0.06911485906570189, 0.12610558765910326, 0.0849623377284696, 0.2496293977263474, 0.18427102015383784, 0.18035666326120978, 0.18268589230795063, 0.18808796130601438, 0.11610895230044281, 0.09786902701542263, 0.12272451989232533, 0.07797025324356172, 0.1478222267882478, 0.09118911569877979, 0.13896922280471172, 0.08225013366750172, 0.1597515640840415, 0.13637754735687088, 0.18596929918614127, 0.13057296044163166, 0.2413630791969838, 0.11399015994562257, 0.16390561456641844, 0.10635647682412978, 0.16416436842372342, 0.2428180027392603, 0.0993246247150725, 0.21970327613094162, 0.12952476830011414, 0.2435471039385565, 0.20847939856110081, 0.15437889754051162, 0.16686668228958884, 0.24066440701004, 0.1957336260426429, 0.1907556786412193, 0.1558902051540152, 0.14574597529586286, 0.127075286431899, 0.15456790675319013, 0.0855593883522576, 0.2299522148865846, 0.20525933183248968, 0.1204913276277723, 0.17877803184092048, 0.11166474601674466, 0.10140877457395678, 0.13296281768670007, 0.11030550685621078, 0.12760077678267995, 0.1252339941058909, 0.09320960365115635, 0.12859476820355462, 0.18314758285639748, 0.1804851515278701, 0.22815535566018474, 0.1414836459462681, 0.11746546418796625, 0.12474813348343297, 0.16950608501511236, 0.17356409871530148, 0.1569685351944739, 0.07186035730785902, 0.16292523652795823, 0.1265544538956977, 0.20644191111768448, 0.15127228843348642, 0.11542896499797223, 0.1971114658179783, 0.13198815466415498, 0.1545442806016053, 0.09008023407190077, 0.13084456925430607, 0.1605641688670843, 0.10079567440815511, 0.14382243577030399, 0.12958351192214798, 0.11344847449612235, 0.18506056569035978, 0.08717008055217805, 0.13054170405432103, 0.1527218033950175, 0.1486440552698989, 0.11988260182401828, 0.16039929142402065, 0.09500772692263128, 0.11559159014253848, 0.13334995255835597, 0.09952353178373269, 0.17790170386433604, 0.15715212050464847, 0.16649399583618488, 0.2475052657386949, 0.1377293707862977, 0.12361095256863103, 0.09142736904323102, 0.13294961033088545, 0.09887578146111581, 0.176408491247604, 0.17074327104754988, 0.2115063038804839, 0.12792922931933595, 0.17912459469610648, 0.21793644755117356, 0.17635701013909233, 0.20158666035821363, 0.06939062773580514, 0.21077498102620726, 0.13753950355514405, 0.11041969992220403, 0.15005713508975121, 0.20688199798666662], [0.020254410938510013, 0.02494768389771062, 0.019876425071889837, 0.027530961106681538, 0.035211791194254355, 0.008379178602368602, 0.011830516741611065, 0.029861572942125703, 0.0866518910193155, 0.022407522117118203, 0.045031950538677555, 0.03605706196638846, 0.06779560969481546, 0.04233385781727491, 0.014148963100817657, 0.06292186174241286, 0.042791139529717546, 0.03927577271937363, 0.05009918548767606, 0.06687441194850592, 0.08967207008672338, 0.04371656608136912, 0.12307109806926982, 0.053899085013976986, 0.04284745082259179, 0.030565785859981855, 0.04588117815494057, 0.052635396169798995, 0.027827013869799917, 0.06817781862111823, 0.03626282552197095, 0.0474213328092329, 0.09668322250006661, 0.04265226311080399, 0.08389445712729808, 0.01766898868335111, 0.05185451508770066, 0.05355320780748322, 0.06345767129753387, 0.042653875725884596, 0.02919124983881991, 0.03032942092226398, 0.035229495486184474, 0.01642495382487053, 0.05925585140263843, 0.030842199959161303, 0.051353072236862876, 0.027331908481315743, 0.0941043866858367, 0.014387020135238288, 0.0551984658945472, 0.026098085574865825, 0.01667471764038407, 0.08399714355266864, 0.0357462294519909, 0.05462770740832052, 0.026171118651907292, 0.04813615412962052, 0.02752992497276395, 0.036739964233410936, 0.06392659371598594, 0.018407616185985746, 0.05354736255662096, 0.03255653427913785, 0.03368151907418524, 0.05384130666272775, 0.11111054269056167, 0.0675339600251567, 0.01687590956627842, 0.03919132301704057, 0.03384492945887389, 0.028270260851469733, 0.022341154005017974, 0.02247823011730948, 0.04388572595592949, 0.03853656682035616, 0.07487574832574015, 0.0413868390774775, 0.03162433551023564, 0.02390314791081173, 0.014373168307957391, 0.0390663510939527, 0.032133040874595606, 0.016497736008116798, 0.08075265394103143, 0.01628442457126033, 0.052314079742157654, 0.05396372751302777, 0.009362224542025116, 0.025781944071153, 0.02586211517242895, 0.014983017388130388, 0.018059925266331243, 0.06370021473436106, 0.09104085470279379, 0.029409146311903195, 0.06937385807114263, 0.026823499976026437, 0.0585163850337267, 0.02976132076113455, 0.03386240775486635, 0.022041144397770687, 0.03224212796457353, 0.035073493171723626, 0.034758841709023526, 0.08465319826838472, 0.04012122735260956, 0.028686336609685135, 0.027829664534017928, 0.0038225922476305, 0.12985248539236285, 0.06925920535239481, 0.02403693559068826, 0.03017876781673441, 0.038791762199252844, 0.04955912797501491, 0.04971013922664908, 0.05693900233675396, 0.07297728285794297, 0.02969174657107121, 0.07260099579129489, 0.04715962951341945, 0.09933767885330225, 0.021710343801626758, 0.04862876398669136, 0.05386653776851393, 0.03972381541144945, 0.030490613482411832, 0.01983633569081224, 0.0196379553076, 0.055816361770754865, 0.01878259324228331, 0.051681180033952966, 0.03618698664790681, 0.033839478743292635, 0.07735313877703683, 0.019106045140013583, 0.012466622527778871, 0.033149834902536486, 0.0423848984252301, 0.05315596440566644, 0.04519601975898108, 0.010343611901325565, 0.031141893555139823, 0.07659471173199915, 0.054693636935084104, 0.03610989138964684, 0.04278295004980699, 0.020851015316082105, 0.018341204023829872, 0.010505283266426095, 0.029302167878936858, 0.019084443375768683, 0.013060302364700025, 0.02442326415480385, 0.02916628686380723, 0.0504233670841542, 0.07409927991008566, 0.05099388425268474, 0.04976295332814898, 0.08963162064432137, 0.03848135486365326, 0.019112420906763405, 0.03928127323066996, 0.03646210031283479, 0.05955981210835519, 0.05830743838281882, 0.06612600533351784, 0.0225957652418724, 0.07373644534738795, 0.04381603110701807, 0.026117605495176492, 0.020176850281836047, 0.01641039432386958, 0.017065884049741492, 0.038509634999378074, 0.03268764639693884, 0.0035607943878388938, 0.02301656393214099, 0.03973685039748107, 0.0373090909523589, 0.035340823383340915, 0.028951113833294764, 0.08019471210577796, 0.07555785003088175, 0.0610843577211903, 0.0253979578208659, 0.018169788020332495, 0.06389324590864201, 0.03596562937262558, 0.03410041595118181, 0.04061527745497804, 0.059783230160152724, 0.05496323093651764, 0.06018096385824104, 0.05770434332530826, 0.05597664651671245, 0.02234122486815097, 0.029479454031154036, 0.04592872923240066, 0.07161767597520544, 0.05515064668631362, 0.051818543429216074, 0.05011400162813164, 0.020194931872068875, 0.04574433569946597, 0.06296138804886611, 0.03802925573601838, 0.08200100953540496, 0.016451519838864767, 0.03306979020576804, 0.022904448879642353, 0.07384545199813382, 0.025152346201901956, 0.15799041987667162, 0.1294382463299459, 0.028173071106955893, 0.09008957268369776, 0.050790859461431546, 0.030032776356224093, 0.058883999985071926, 0.034572215029789556, 0.059624205628830584, 0.0162418952001439, 0.028742362534807577, 0.04240033126646473, 0.03639932706831925, 0.023648406439010176, 0.07042285460498064, 0.07594099358445214, 0.02455595441372885, 0.03369145906500278, 0.012403747776613362, 0.017529091452278437, 0.02380970242102781, 0.06310180430450747, 0.08547622950807696, 0.03168979197770598, 0.07005238980655709, 0.08127038382113942, 0.056001529052493074, 0.04511427817746036, 0.06877742797857331, 0.014824282054999664, 0.01781280062371685, 0.03595985306967651, 0.03823983032376536, 0.016256678781862703, 0.03810103051364422, 0.07877485240779578, 0.03336226725349984, 0.04398484624201252, 0.03939640475437045, 0.03096647091179846, 0.06012360685535016, 0.04325829994594378, 0.028579229856991482, 0.017417125786925038, 0.03139933740209428, 0.020693750871766, 0.041676596513078104, 0.0189789243402981, 0.05106299304433408, 0.023877558658920953, 0.056505300810620676, 0.022356209547949896, 0.04763079656948967, 0.027620074369253653, 0.03453293387147208, 0.04096724889090946, 0.08004616765725998, 0.029263128038315527, 0.03767081085712679, 0.050993853609167764, 0.04880918918417827, 0.029438008674450462, 0.02547308040272084, 0.03327272689690994, 0.0031068272026811517, 0.061566318956113635, 0.04868157808819125, 0.03256367804903177, 0.03727221147968404, 0.03652493484438427, 0.013207463066904776, 0.004662231555313714, 0.09552298999962308, 0.02441922304100327, 0.05457573217309771, 0.042940017226482594, 0.01941294570813977, 0.03167313914145193, 0.06490112267314427, 0.04537286732586161, 0.022278685280452334, 0.04946757663762377, 0.04148956763768389, 0.008659164586495008, 0.02961534845282234, 0.028012037510052327, 0.0718911387206566, 0.01846107380134204, 0.06491933258310442, 0.02828514210939888, 0.031518056132500215, 0.14845162930507816, 0.02756712811758682, 0.03968756413087249, 0.1115573711332775, 0.03807521335059597, 0.004263206041463081, 0.09654726487614455, 0.04288287855865013, 0.023569304030388597, 0.045363122687464764, 0.04442787871906354, 0.03146820296082766, 0.042010928774552966, 0.06785529560499615, 0.012470918365814274, 0.008699673400711148, 0.03628652828234819, 0.027405826389909755, 0.03201322472323814, 0.01369839997947096, 0.029087540686070442, 0.05136866212612198, 0.018675132173924677, 0.021719287878142732, 0.027317465808723244, 0.04355441208087629, 0.08501715131945188, 0.07495222688322106, 0.03810057469132928, 0.029968809929766485, 0.08378299899519452, 0.09243134258975906, 0.14925081222768755, 0.05884090753933115, 0.03368214343584353, 0.03135430292346545, 0.04263848118904618, 0.04834782805353884, 0.054474420875551245, 0.027724672183995287, 0.02027778428107981, 0.04238433918104537, 0.019975734964734124, 0.01967963623634029, 0.04639740267227735, 0.0216436845761153, 0.07146483377343224, 0.12963865493093768, 0.10890889026585127, 0.09539165188588443, 0.11124191144781728, 0.13595863515811582, 0.14291615375588018, 0.12412322790271814, 0.23341654108897333, 0.21559289266024867, 0.18109849684180754, 0.12999721472301792, 0.16978860291982853, 0.159503489492401, 0.1324661782071475, 0.1550401233497166, 0.17702683145480771, 0.2824984154393596, 0.23897571939854856, 0.09191013467047485, 0.22610633093262875, 0.15021802887560862, 0.1349046973571662, 0.1887600042767102, 0.21892824029970556, 0.11011410744920855, 0.1577493932939345, 0.1379841869516719, 0.1756123879984502, 0.08553479692988819, 0.23058762353274131, 0.15160382064359804, 0.13054095328815524, 0.1526364152349772, 0.12083158557934147, 0.2362360510854952, 0.11508255536037107, 0.17339241841147024, 0.18590874759660614, 0.19062833950644542, 0.20546263624583522, 0.09395711394327302, 0.11065231485953254, 0.1439796676558833, 0.28493736359861593, 0.1946524155115889, 0.145826751606599, 0.07040564060932206, 0.07149599056931273, 0.09735844473564818, 0.10853978910393293, 0.15876897971235937, 0.09734467047476962, 0.1413100197791092, 0.18363142866761456, 0.14713257911705202, 0.1490994638973667, 0.15384847358349832, 0.11481136789605503, 0.14286428960340639, 0.10508949763231701, 0.16667745857229158, 0.12394420081569303, 0.27079127428512423, 0.1239669229835272, 0.10832946732520096, 0.11238407959500629, 0.2317551262075863, 0.1469910213904035, 0.16687762202514758, 0.11046228674991478, 0.1522635602422299, 0.08217484254630343, 0.13530844101502051, 0.12926964569957028, 0.1062381775268624, 0.10588455134101453, 0.1895105865814032, 0.15173926498861084, 0.11789210621387729, 0.06806365619864195, 0.17892964064113556, 0.20366315699873433, 0.10521924994405239, 0.10589064940089181, 0.12982338937299867, 0.16039150797070997, 0.12413214516615677, 0.21942644259862362, 0.13897997867916861, 0.11282494021279198, 0.16134583901974464, 0.11183152335786051, 0.14969443842287988, 0.15845396435789524, 0.16337226415353437, 0.11961182804718135, 0.15661435742532054, 0.2237002479453241, 0.1377521695629243, 0.10205553664315133, 0.13455110181483532, 0.08293505457620468, 0.1222963763340827, 0.12581078170408166, 0.12066241804390185, 0.13595117346173333, 0.12238957093007143, 0.14296270125815946, 0.10777996777887307, 0.0621208593609833, 0.2084401288941022, 0.15883008288519998, 0.1162718685584203, 0.1088815332660752, 0.20282456651329997, 0.10442220440675175, 0.1207282173357183, 0.10962351240337857, 0.1873043146465094, 0.08147928833721146, 0.2227944715489303, 0.10738472769697828, 0.1519161393685687, 0.16220065524741528, 0.17260996684912713, 0.17935340983733056, 0.10932953382331519, 0.12960857831903044, 0.12982004922964882, 0.21294262680795886, 0.15270954598822903, 0.10432069775678458, 0.2199155897382767, 0.1585250266737515, 0.1227003881227105, 0.3244699213293291, 0.10279790648529608, 0.10613274850672293, 0.1309475008278124, 0.15838285607676353, 0.07215191505008167, 0.1364871745388354, 0.10351501074769806, 0.13571097425395443, 0.1258808710882741, 0.21843932298642976, 0.10706004431290973, 0.1526340863276874, 0.18188433451277597, 0.11782862050759217, 0.08399038665717648, 0.08459637752704083, 0.15885294294886051, 0.15173293710235627, 0.23638710830240484, 0.16139466946403827, 0.11607358968185803, 0.20907664070686988, 0.22814060080676313, 0.1493049593221757, 0.18319049910191568, 0.16600507852290908, 0.08347340754323429, 0.24764503081960065, 0.13672055556408821, 0.11515102829904326, 0.14307194539616186, 0.16000877044373946, 0.06633592874652917, 0.15602787115400837, 0.14837921867447515, 0.2805979351603216, 0.10621566220276779, 0.10077233936998153, 0.16176896470208324, 0.13723916644530912], [0.016318034763718327, 0.024814679542736664, 0.12052566368853855, 0.06591247364638314, 0.029341071738951632, 0.014935700925097111, 0.04322541562179404, 0.07749433644236096, 0.03609814726176762, 0.06042439978750003, 0.01274316207385592, 0.08694963875196635, 0.020593163527307973, 0.022078043022643656, 0.0232259453379459, 0.04279727589399104, 0.03948785650033144, 0.04351493557013812, 0.008440985618489645, 0.011802489414901264, 0.03507544286549091, 0.025340453346049594, 0.007956423515063381, 0.012183365348215786, 0.036803821492339336, 0.02779886971468166, 0.03528293394934266, 0.07854529416128513, 0.0435757476295675, 0.0823867577879179, 0.07615434141048501, 0.05061925959683234, 0.02329040589111467, 0.06972949140735211, 0.009809984739178853, 0.029188204639320894, 0.0504196975229969, 0.044583310298020803, 0.043113076488577554, 0.02005981502964372, 0.05859278698241519, 0.031226055974501277, 0.04672384422813212, 0.010486462401346335, 0.05480645104281364, 0.08792591822003165, 0.03224202837314337, 0.011711725232852323, 0.021317949736370675, 0.06919107715328855, 0.0696466236765827, 0.033922944022642995, 0.055853585982995654, 0.0841699346839901, 0.10548772545711649, 0.04833167125921577, 0.03208944855648423, 0.06884200919059015, 0.08325691109583264, 0.07501064874832669, 0.046501134807664546, 0.04146133729767415, 0.03877980739719445, 0.029225503545134302, 0.01691273158235896, 0.03177848580713955, 0.01635420560506323, 0.05595346852656334, 0.030892512783588424, 0.027430988547782746, 0.02776120117144479, 0.053872279597506414, 0.10178041914778371, 0.08353242695692085, 0.05099768787922879, 0.10656805498705757, 0.056843475003035805, 0.07882635649894515, 0.02933366941438327, 0.03612214496599571, 0.0508840425661014, 0.04481608611381343, 0.08373754699864695, 0.010562375968983097, 0.008556730012529561, 0.09913644287735225, 0.1011509323612817, 0.06393723084681457, 0.04154579849132607, 0.022199205573528044, 0.04135144964581536, 0.014409802632496483, 0.03085137003161494, 0.05077295598664111, 0.011327277414590843, 0.04029459688031385, 0.018236929881236246, 0.0561212302906619, 0.011606104690731775, 0.044960351961274306, 0.037693663259908076, 0.035801138803963704, 0.08905765224969195, 0.06671552531301014, 0.04441234628639875, 0.04728375873979061, 0.05571412733725964, 0.03757355599513939, 0.02298536691664448, 0.009256100297094354, 0.029873504761546373, 0.021960597913411838, 0.034381577880271984, 0.04460683685817546, 0.06727179707658869, 0.04747404731930264, 0.019582417763529286, 0.04340047437337138, 0.011647855524995155, 0.025218120595860868, 0.0292482333738477, 0.05698753400675713, 0.04352426269061623, 0.05955572502927915, 0.04798094088572168, 0.03559005093730746, 0.02852104739436219, 0.029629342963979132, 0.05444277761383884, 0.02398847478381809, 0.044531258454005566, 0.039714063112173355, 0.006139169112899371, 0.02073139451714533, 0.06431059911847115, 0.03327986683636423, 0.010113975130802682, 0.05265922916512336, 0.025652218572494966, 0.06750108719232582, 0.01798559558547793, 0.07270622562857405, 0.05236761013586676, 0.04065600651947241, 0.06171481360891654, 0.04364582552244106, 0.023978257086128, 0.03850785767539375, 0.019613664574740876, 0.09402658279624679, 0.011038871166566688, 0.04070385254078335, 0.014950617614592758, 0.03233362184537034, 0.07466123604606237, 0.05055862373762554, 0.030216434444751472, 0.035105787608171665, 0.012991989346882029, 0.057080812872417515, 0.053293178413784316, 0.034795123633117445, 0.02599073558925621, 0.024895316042426615, 0.05646842516838543, 0.04584969577169226, 0.026763455919741143, 0.03362036993606918, 0.03729387644618269, 0.014943561944810134, 0.05604297823963627, 0.00869160936769819, 0.04045045746850871, 0.02049826055524811, 0.035263322098481084, 0.006458559787021049, 0.043571346454442515, 0.06178482638431653, 0.08185347632294701, 0.06438431209854542, 0.01785082922827813, 0.029872935941262595, 0.01743128692220536, 0.04474207052900907, 0.01171969446248465, 0.020893188456313747, 0.03248160321926398, 0.012505067692648981, 0.041778689220307336, 0.036777694063681754, 0.027486233063222423, 0.02678669136648457, 0.027549063764332284, 0.027052611976321188, 0.07484515843492362, 0.045116105297159766, 0.08255028691623481, 0.05808099045328075, 0.021305654025185975, 0.10004115441153127, 0.0629250180246609, 0.07366083246926147, 0.025117575386238676, 0.03895065266518824, 0.0103916188011006, 0.031283661955967546, 0.0774393619729146, 0.06246028610715463, 0.0605778280465353, 0.027455461226523887, 0.045863470032570824, 0.04131135643429814, 0.048443631178909735, 0.027030950840262156, 0.03419903444967443, 0.07495444853820148, 0.11610560449621371, 0.042687231194107764, 0.09717084512475038, 0.03435844585539834, 0.0017146729547793287, 0.06082711688753578, 0.02575705962015256, 0.07901852965475091, 0.021442653528685053, 0.04086631680688551, 0.05147402985922752, 0.03627620524756851, 0.0519044372072864, 0.0557638387826662, 0.04111192842584945, 0.017386453541656657, 0.03750199955257197, 0.02629211266344834, 0.057709230966265165, 0.03438711669596453, 0.007247243953433129, 0.04815383543891292, 0.0698133550524231, 0.08354613993076548, 0.045250756741170926, 0.0226614304683021, 0.028130716020842234, 0.05042328281448253, 0.013243958538007593, 0.009295562443683946, 0.028817691960402077, 0.021918775258405555, 0.053999404227661515, 0.04600443787151768, 0.06212030777767782, 0.06661400334128449, 0.050864832911400065, 0.05661692365162796, 0.021955294669756008, 0.03299772048429136, 0.056522943815516855, 0.05946600081158742, 0.02209225586885887, 0.0487744547576914, 0.018988682385233623, 0.11397502970911803, 0.02632412173214459, 0.01824810901927131, 0.012207821747588535, 0.04148487151870805, 0.04147214679828575, 0.030012923187666365, 0.01994802364929309, 0.04578749709311993, 0.04584872667046805, 0.07364199436720341, 0.020044539236433564, 0.05467223626891932, 0.010220861633218104, 0.018858213781289036, 0.04789031651471892, 0.01762974008377041, 0.09279551780632428, 0.021208573448201342, 0.06591158498439097, 0.032353513318324284, 0.006429023745905368, 0.033253781542542486, 0.04419516419030486, 0.027223476396513083, 0.029530689991529913, 0.10950660738613337, 0.02210757954256429, 0.04031507058009025, 0.03912177372483477, 0.033246270050444914, 0.07244331957471949, 0.03791961323229536, 0.029804733048583713, 0.03353177186762614, 0.038403248369333245, 0.04244016400808769, 0.049563364441236185, 0.05631843664413018, 0.03570085406423577, 0.03977587491634392, 0.04728233764669107, 0.018120222131631548, 0.058925276802432154, 0.049642773285027475, 0.06088806301235192, 0.019473102762393897, 0.00586975609973794, 0.012789626264073437, 0.08975615589729241, 0.03368273715398485, 0.025957935534778143, 0.01735682509118511, 0.03464539940919607, 0.07707870309992183, 0.036125450635388974, 0.02994101625987359, 0.05474572708349555, 0.05248956750297258, 0.08583883424439738, 0.06517862270195639, 0.02544863262183724, 0.04565365770230851, 0.038197515457267725, 0.07504247970158055, 0.08346464349738053, 0.06008994112151766, 0.040795675839387605, 0.0901857243790742, 0.02053783474219663, 0.027494876450228117, 0.045874723864178506, 0.11087736084816918, 0.01587672119644741, 0.05319325756582041, 0.01734100920598834, 0.042501202063454736, 0.013505567030440415, 0.07239592937572349, 0.043332710066029144, 0.02021881849354794, 0.07936553684093299, 0.01646409325692202, 0.0066021399857896955, 0.02448963801256351, 0.050292312422947544, 0.015980605591809558, 0.012202500309344503, 0.010087095978369397, 0.03567586427614574, 0.03093816970865573, 0.11981663399285848, 0.06269078281137251, 0.19759794697165492, 0.24944526083286733, 0.15092143548592446, 0.12436486735579469, 0.14962706865081865, 0.1545466248306536, 0.14646456576883793, 0.1245618285611272, 0.1399904333295361, 0.1151501932632058, 0.11058263916281924, 0.1592217683191261, 0.07028570954477595, 0.11318029009646947, 0.1081026976387347, 0.06026832852512599, 0.15227836106092701, 0.13067953859365758, 0.2254783073740621, 0.12518269685848107, 0.1118060892387744, 0.1936657555521496, 0.11853876869164168, 0.2326432979034801, 0.1874490133336475, 0.1756039763530416, 0.15713039425111588, 0.1908585489276917, 0.21098147236531783, 0.14963079183813066, 0.16030388283393077, 0.181557429473727, 0.14001641903192769, 0.12285578139727155, 0.08206346102299229, 0.13982829848124137, 0.11534454210871652, 0.10777281251766029, 0.19157280334301535, 0.14759483657056285, 0.12306217314495195, 0.21949476231971096, 0.15802789689792743, 0.19523389156787627, 0.11058067031685384, 0.11886005830620566, 0.13060173470406763, 0.14598661883463784, 0.1405350145913901, 0.1364551214200835, 0.11750582169981734, 0.10306514859680208, 0.1665331429291156, 0.08922460579103039, 0.10695364236110642, 0.14254098517760155, 0.22332071266587705, 0.17960234244744624, 0.11430330604555146, 0.16359401596409662, 0.11139787928832155, 0.14368631726791783, 0.13644557596454698, 0.11840933813683449, 0.14952041389000031, 0.1448036565054809, 0.20942767751553368, 0.20195096580972596, 0.09165524955718748, 0.08959980501282601, 0.14844802869183404, 0.15097997992509796, 0.15620191100864642, 0.17363358289003375, 0.18931468257740622, 0.10936479685046982, 0.14287409552883718, 0.25299520502167366, 0.24891235475097936, 0.09711814593643912, 0.15437333574218137, 0.1321771332333165, 0.11320446017048053, 0.1581248223421074, 0.20931337719723103, 0.12290472675475383, 0.08174040174532322, 0.12930159156601276, 0.21151511389161312, 0.12754314398813632, 0.1257292163227835, 0.15165116487731858, 0.09152939663298669, 0.1074770795962503, 0.09276897285974796, 0.1730448136767072, 0.13660734309063804, 0.11296500406798818, 0.1400486560117814, 0.12220682065573432, 0.18594847691635932, 0.2865093760192394, 0.13015827704821864, 0.12808807765043553, 0.12888073350393003, 0.13636748096154583, 0.22832715853808389, 0.13849817066183015, 0.13628492732682537, 0.2532341938105322, 0.16023755494144656, 0.10258949226549557, 0.12737018431747152, 0.12548019944299615, 0.1357424145023669, 0.15247441828250885, 0.08288980942339667, 0.16285123243447275, 0.12657658617583015, 0.1555018905069559, 0.12220380993019189, 0.11981195319564113, 0.11854382487194193, 0.08284302443386087, 0.1237206410376295, 0.13337504959875537, 0.20875888275763682, 0.10775678595828433, 0.1278171046907383, 0.1680303392030539, 0.14906788575312785, 0.05760415434657086, 0.18598417661363081, 0.14721349332361452, 0.09988736226073197, 0.10825156384418089, 0.15796408177383486, 0.2577716406554945, 0.08858530541821834, 0.17425655026830014, 0.22180517624703147, 0.19400225201201057, 0.1486614301440216, 0.12660631804817146, 0.22173118747530446, 0.2233650538349344, 0.09943879479842802, 0.2196289809240449, 0.18397480459703555, 0.0913000605519741, 0.14725841671949433, 0.2075212983594787, 0.32350023787829185, 0.12357964255516568, 0.10491473765503015, 0.14837696637597778, 0.05535395876053841, 0.259367126010118, 0.16120314748296816, 0.10317006433803229, 0.10829616548313249, 0.19973304933838307, 0.13978755792542813, 0.11644821433771042, 0.13778799183426366, 0.10199624909869126, 0.09909607004374267, 0.10396731671907249, 0.13171486045804717, 0.11814779571948514, 0.16149168683876916, 0.12113032922629388, 0.11498661816961343, 0.12747875429810057], [0.05053851392961318, 0.04748177714645863, 0.01844747957112568, 0.02473740425381449, 0.022252716815039035, 0.05033299935260608, 0.024308167105059952, 0.028539186441189343, 0.03388400377345181, 0.05871010951757912, 0.03665194073091111, 0.03343472767981791, 0.01581251153707384, 0.03571547868271028, 0.021699869464482033, 0.04787880604365661, 0.02633870613100308, 0.005863332931297802, 0.014307642892573871, 0.02348106219283035, 0.04478507487463855, 0.006222278161364938, 0.01811440752428626, 0.011637628251206011, 0.04260735886712228, 0.060778937617977785, 0.007985777610297045, 0.04116208803269171, 0.060720431483200485, 0.034339971645104314, 0.04497305369905887, 0.09683493855259112, 0.029714302114781835, 0.020705811010913986, 0.0602907021229546, 0.061536437696627075, 0.03802030782906279, 0.006898803704027688, 0.05573645113937317, 0.14488643996657866, 0.06061366180919352, 0.025074446551321496, 0.013164919331639767, 0.09870730340480806, 0.02278917371445606, 0.04911695734687871, 0.03913935927313663, 0.03872627317304573, 0.04465921811999814, 0.053251982035656134, 0.04004493265623047, 0.06483521612901842, 0.02892821355001821, 0.06686871991522851, 0.10328644841548898, 0.016547882208420385, 0.011838970521855499, 0.03909217208744057, 0.04646279593749393, 0.03507755343772231, 0.04440149465095132, 0.07743837371949228, 0.08156699008278309, 0.05593664906618576, 0.048220404649093274, 0.03364196595465464, 0.07246440231439567, 0.023599861362468333, 0.04407023823249244, 0.038358221551583666, 0.02671159559770698, 0.03129896073181543, 0.032189911411654566, 0.046321310989198186, 0.014302818453870715, 0.08655884198003239, 0.054686960478823994, 0.06474805830587303, 0.023436548653990034, 0.03459370379606563, 0.05628004414780487, 0.018459392238348242, 0.05146977424080815, 0.02458280196503526, 0.015425353682780219, 0.028340430674894203, 0.028700135768421238, 0.0646337426658119, 0.032552037343022325, 0.040965892915283485, 0.015512279764328514, 0.02070999576620037, 0.04085523534506079, 0.042737701066559365, 0.04643577218596493, 0.02452814925251709, 0.032082875522093914, 0.03480063946617227, 0.05831219961926822, 0.06838542078771899, 0.04727603657351387, 0.07386641216374214, 0.08222024857757554, 0.06274292658593866, 0.03419870120142737, 0.04831258800902194, 0.08147702071695559, 0.037813418124231606, 0.05968505216221656, 0.07107999716554919, 0.014648541485169723, 0.024399865914376515, 0.046995514327840465, 0.03163724409175977, 0.08501084641583505, 0.017350334411246643, 0.05000499114694615, 0.03566125114899009, 0.03662462203553127, 0.02011972310532245, 0.02816211221919906, 0.03450898213251945, 0.0699334469954333, 0.014926337415442593, 0.06729114079667677, 0.029234167999557914, 0.0424396277465407, 0.060382908465520996, 0.04348885410675599, 0.05168544331325158, 0.08096764119522226, 0.055199664822148706, 0.0728526326917833, 0.04109918838366866, 0.025035563758724642, 0.0741348110680138, 0.050096615262690096, 0.03971589023187276, 0.024009463677723563, 0.03157188338527997, 0.07542065134452236, 0.05384064782711287, 0.07254926187376823, 0.07634842212522223, 0.03496657794101104, 0.020111652369040157, 0.0773930979231673, 0.03155295909833043, 0.04314663880054028, 0.08579932709014224, 0.06090026296254608, 0.03256483867223705, 0.03838209285130424, 0.03934406945782323, 0.0711106023781242, 0.048743313283569394, 0.01795112737454474, 0.08102224794246497, 0.031699419787694375, 0.026227203948843866, 0.04753262623243275, 0.08078790164642757, 0.05301952031591246, 0.06568345932229873, 0.06809845191216277, 0.020625747161947434, 0.018555982519061338, 0.04190530440199279, 0.030842807083841295, 0.07466782440221117, 0.0825111628059418, 0.0091470965191782, 0.03620066514779483, 0.011267065776572114, 0.005672651252919628, 0.06447215173994342, 0.11067611721133995, 0.0649838295254496, 0.05278326646094361, 0.07099138377534767, 0.017875271263502298, 0.023854930336857517, 0.0790765148497397, 0.05764995108268434, 0.022736028279928912, 0.0999665451085856, 0.013060848202346074, 0.04390893458959557, 0.015070469197516721, 0.03280142194501335, 0.06370463123124454, 0.03350919525649759, 0.03564489900224632, 0.027213185920470187, 0.022307616590912786, 0.0459916097292256, 0.0449603328090762, 0.04530697993393387, 0.017976536595773314, 0.016358786810850425, 0.02597746120074824, 0.01607337117856068, 0.0006191949937455056, 0.006719594671120567, 0.07528817175977653, 0.04377321062249042, 0.05618668484291243, 0.024758973459322608, 0.05041293679706512, 0.014009415397360442, 0.05851966772048224, 0.015546557410890538, 0.026886401540269295, 0.021406990220589985, 0.00981119611570912, 0.061551640711484425, 0.04721404090824147, 0.01632851293130267, 0.03778267501583023, 0.018780496076590592, 0.027876415049597144, 0.02687212740702014, 0.08176129296301834, 0.011947793311499541, 0.034562485713151195, 0.03447741547959947, 0.04662072879352397, 0.04833067151447458, 0.06404745940779967, 0.058944980583844654, 0.011559018054075781, 0.04135277114748474, 0.04223780571332863, 0.020227620843797922, 0.07030867686074588, 0.046988565910367236, 0.048268675849202185, 0.03165449064615513, 0.0699434137993282, 0.04961128324089993, 0.029891159257761417, 0.08500448022518428, 0.050520790485484954, 0.020337043097242713, 0.05881931535118531, 0.0395642890925369, 0.013798007688995813, 0.05884380718212455, 0.05210931976175597, 0.025009572310673616, 0.013617487688128267, 0.10783220731442976, 0.04694134808115421, 0.027979292996948766, 0.08935535401706735, 0.07952563389534913, 0.09303518075255618, 0.04062719395264022, 0.02460200587407716, 0.05382311207452609, 0.06288818451726148, 0.0496523876884772, 0.014306003464415911, 0.01269651114970686, 0.030462185874761596, 0.032538393317090894, 0.032902472772665566, 0.019429564070437225, 0.06402189888420605, 0.06593683524237526, 0.03419040063876779, 0.03602330813244466, 0.07690663975212844, 0.03508763515480584, 0.040125862184551456, 0.07349090650677681, 0.045544076485619436, 0.05078655021685747, 0.031648748817162654, 0.05313978845914526, 0.029667170470460292, 0.03176212025385711, 0.00229514196454998, 0.031955478930725686, 0.040512763399390445, 0.09584118461897297, 0.050995902894365217, 0.0249082705892262, 0.04488572733657015, 0.06406656947107085, 0.023760875807173794, 0.01613111314063351, 0.02417241249443783, 0.0308860297645292, 0.06645911568475348, 0.014042439532556362, 0.03106949058541608, 0.09098747369622992, 0.024549385209778146, 0.046044228478304805, 0.04070290259175724, 0.004276328648801052, 0.023831139476368987, 0.08491780503743118, 0.032005104191240766, 0.1278835781399281, 0.06392883452316446, 0.034965424978684996, 0.053180375797373634, 0.02913568739689166, 0.02093946399737991, 0.016310199599472747, 0.07271747179930249, 0.0237858081386695, 0.022123125381767753, 0.035832092586544254, 0.107862031117322, 0.07197848040490382, 0.012524443971473845, 0.036256842375282324, 0.040032602471089175, 0.024487912399514068, 0.04188213407272293, 0.030474606075233994, 0.03644432707299148, 0.061299088335926497, 0.07744118526217438, 0.039958314925071695, 0.030046924084965742, 0.014091253697481609, 0.023173989254921194, 0.029663899275023612, 0.03508026538897426, 0.030791431312419237, 0.03396515929771047, 0.02500379026206511, 0.005713104046956306, 0.0220461220540587, 0.01121951757194174, 0.019360018608671044, 0.053808349560225205, 0.06743003253734882, 0.05085549813004271, 0.04551415692173666, 0.03805614925260025, 0.029829190405566367, 0.04001261906758432, 0.025631459504966776, 0.07413877174258232, 0.08000427796956032, 0.026626433433604338, 0.04311119574272344, 0.18235580034313664, 0.2230173265261035, 0.14857473963451, 0.19753192551434043, 0.14854106240935866, 0.09076800482768206, 0.13905024426358362, 0.0894912197104385, 0.14701780382423632, 0.2076017529132866, 0.08967356395817573, 0.08622640578617012, 0.09900734940123174, 0.15749345864019088, 0.15511683939445406, 0.10495304205124417, 0.15756101227335392, 0.1377852952047702, 0.2990925233931311, 0.1757596454192554, 0.1410996213915848, 0.14523969843022286, 0.07779573841441063, 0.1203179236261114, 0.2398694835362896, 0.12450639443892626, 0.0913576014159668, 0.15625311632550534, 0.14516281384614207, 0.08426392601142008, 0.09414233102072632, 0.1477109601781253, 0.13168216382543887, 0.10789947749506082, 0.12907772535277953, 0.1732000690554419, 0.09942005628780012, 0.08018802415819899, 0.12521598337879106, 0.2287954067991626, 0.1508884783834219, 0.08357106843182156, 0.1283616553090753, 0.27700758749438875, 0.12710530941765155, 0.11826230288152734, 0.16999651918247824, 0.11985242562068087, 0.1328775827442446, 0.2220188228473548, 0.25188811604053746, 0.10793021294258295, 0.14563994872714245, 0.184797874141124, 0.16489397524104965, 0.1711615703759655, 0.11948449657328668, 0.08642415606206463, 0.14428847769816078, 0.08988989186623404, 0.20318478105529664, 0.16452636028970444, 0.16857674375416773, 0.13041657125276904, 0.1411252853370482, 0.13673170980426574, 0.20560276904894462, 0.1103469598737936, 0.2520274214686886, 0.17935437510811514, 0.12595361879756375, 0.1483345404267311, 0.15881397971703162, 0.16709580386598266, 0.06008264030359926, 0.2070516404966193, 0.11654551516497329, 0.2020612518273054, 0.21497626848999532, 0.15579646663560023, 0.2333172407722281, 0.1187059673811159, 0.1460195606153819, 0.10547402014415111, 0.18969947322001382, 0.09153677405969751, 0.11469582651531506, 0.1007088536636964, 0.15606680374232032, 0.18869404410642965, 0.19682344740196583, 0.09429659814603868, 0.12276274767974693, 0.19378626118263892, 0.19849387147734243, 0.1981394638818118, 0.15217601171424314, 0.15494103753759017, 0.17633388960553756, 0.11335288204493062, 0.21121310671010327, 0.182798354015235, 0.1738020762681, 0.2363465516076934, 0.26361799468436553, 0.13032404315327445, 0.14669472922480878, 0.07220708870238836, 0.19622038298797226, 0.1341548198533635, 0.1781678121657141, 0.1477499387317127, 0.1180739984697392, 0.12152465000267952, 0.20443839201283073, 0.06436074723399456, 0.22638647396477962, 0.09574008399560567, 0.14545306923889345, 0.12141016582327506, 0.09119306105158984, 0.2293513108405375, 0.19318627644210093, 0.08774300706723044, 0.1139669321597584, 0.09615776279280264, 0.10946919931279075, 0.21696506338494442, 0.11110494258783518, 0.23294568812895208, 0.1781568417866384, 0.13858086219237697, 0.1333534459192907, 0.15936407681194045, 0.04679392212100568, 0.15603147176725252, 0.2743067291955794, 0.13494672494069224, 0.1411691515315925, 0.14811303376430465, 0.18298759305429074, 0.17128445087902008, 0.2169542002581781, 0.1774090940072652, 0.1771896404604758, 0.0868503537569796, 0.1584974321867189, 0.22749750063784663, 0.10525795270598705, 0.18398064218701857, 0.1413198103827815, 0.16997474696367018, 0.11744047439987622, 0.11921360022238187, 0.14574713974950776, 0.13888817070232284, 0.1383461788176529, 0.17748729626257576, 0.1485595557718508, 0.13759450866810738, 0.1341527054506925, 0.22812904820086496, 0.11149845897190033, 0.18146641822832246, 0.19300102106025144, 0.15648059847374118, 0.16124109947873702, 0.18978997884738832, 0.21174513945175757, 0.21447178427009814, 0.11771158525539983, 0.08056831786469107, 0.14843741071320352, 0.13225797083108656, 0.10981130353625744, 0.20022489310752964], [0.017757393314593264, 0.062502482230024, 0.01744674657651734, 0.026709590362565174, 0.029153196336401087, 0.046277322220586004, 0.038913141169975844, 0.020319407753225778, 0.016539914894007867, 0.025974444729546388, 0.025416738466329636, 0.029955656200106588, 0.0782965530731505, 0.035151856305498275, 0.03904863531070371, 0.049241063590612144, 0.045918551754326596, 0.08503222026892247, 0.05415868539843829, 0.007909162593404613, 0.01808739526407613, 0.06537023661357742, 0.11863468289976159, 0.014308421429426921, 0.026391633230471806, 0.08139324900243552, 0.03606461942376148, 0.08299684722817714, 0.021463441324510404, 0.012364269350655379, 0.05215210960276666, 0.037764334870922955, 0.015071274547447121, 0.02331264159311691, 0.031891631247896346, 0.018690172395098115, 0.07129002783086992, 0.02120706425499051, 0.08558475352343052, 0.0717031637266759, 0.051500061526894576, 0.012492901258801502, 0.113650867264838, 0.0589096601000957, 0.06431924059025704, 0.07894838664440379, 0.017174635976252538, 0.033320645696573684, 0.04520100316092853, 0.08284127009251425, 0.024523324813813936, 0.05293866739638391, 0.014318501231290642, 0.04419873799047163, 0.016027961316848957, 0.03254931390045151, 0.015519535574581356, 0.05122672518595092, 0.03722185268998146, 0.017095169675866925, 0.020618233754630053, 0.06469242500081178, 0.02061506406584334, 0.06330500529598325, 0.040929273912502874, 0.019434650894254446, 0.06942922324543038, 0.036047098992933194, 0.08378021043515013, 0.0716468945686375, 0.015129416790460388, 0.005453725827993044, 0.028178629074846546, 0.00853232149365208, 0.011270441351488475, 0.007051615741088867, 0.07419479575248496, 0.05008707363759318, 0.03429874079301953, 0.026509191337672454, 0.019669018257709763, 0.035190953602713924, 0.04003537570937507, 0.01810978609888304, 0.05265845924675946, 0.07242996666219927, 0.03213429342835181, 0.05374233959422958, 0.020369925506172643, 0.04749554374645795, 0.05709378274097558, 0.05258747737013525, 0.035666066011594194, 0.029357546459763285, 0.029044559323078686, 0.021129202908806263, 0.021446547170560208, 0.015113327986440592, 0.0481179480501, 0.02305656904354692, 0.03480263895565464, 0.09987462987943042, 0.013614594748604202, 0.0648789903930118, 0.0417882040323269, 0.016349363929381775, 0.043840201181029124, 0.05458987032574031, 0.038576997110560056, 0.021270366100173806, 0.06152234933969956, 0.02793377013726821, 0.026767294020241788, 0.017658554565822406, 0.02960495263968985, 0.07778534260127815, 0.04623306532120032, 0.018983277634927825, 0.04971330316977636, 0.014390254941498561, 0.023206676311430433, 0.023615813228271665, 0.07986935456433604, 0.0463410530750069, 0.01165656881752394, 0.027310251175696333, 0.026088055568717183, 0.04387212023439427, 0.027238989676979762, 0.01489828806370497, 0.049795864465376066, 0.0697860440179225, 0.04007466452857179, 0.02675620681275764, 0.015502992863466424, 0.07301371799962175, 0.03021120397944845, 0.04323394218039128, 0.05351884876407924, 0.031156757576090675, 0.03382233752598686, 0.05562186353809892, 0.00769079928549247, 0.028249036385527546, 0.020976249624284047, 0.01625314903175158, 0.03431732225562296, 0.0479593793410928, 0.0455762675001977, 0.029980632581657944, 0.06751973377240282, 0.03374051933567371, 0.06640578064346506, 0.024280091897854884, 0.03734883176343095, 0.0630062539881516, 0.06327117102280741, 0.04563888369668876, 0.04276369059939058, 0.027962188168819395, 0.08454675801218518, 0.011578657675624616, 0.028846745844930414, 0.042707191614974896, 0.013932230123769374, 0.04413845836214962, 0.04382681379455232, 0.0927344222943629, 0.04392307274223816, 0.02803897507668984, 0.05168374259805968, 0.043029373721970667, 0.06950941732934407, 0.07205603914635797, 0.0038082908224990413, 0.03030953711018928, 0.03485407409889083, 0.10386994694389644, 0.054709295772256396, 0.06166727402277532, 0.12701445905071113, 0.038559380918741226, 0.004690289046735533, 0.0039943656790250495, 0.09098200382845056, 0.017795758997841228, 0.029476179005277735, 0.09675561014803187, 0.04856180790210924, 0.011674297049701696, 0.08157986035991101, 0.05004893011984326, 0.028767675995045615, 0.05265764719355972, 0.024812852423037254, 0.056913016634362365, 0.012420235903963689, 0.0268239404765829, 0.004746329814811508, 0.033030041733816747, 0.016190797135594393, 0.0862792888355832, 0.0028466489006419697, 0.07992880298726021, 0.023968587141303767, 0.021112735848873857, 0.054651122885726156, 0.07271018630314259, 0.047722926303263635, 0.02308432249382379, 0.03801839643969171, 0.03283291581958052, 0.07858445657597435, 0.05141399537904128, 0.08955622993169293, 0.020223037722790917, 0.030773169691524202, 0.0600840613966988, 0.05320867891573618, 0.02174564321795779, 0.03812990819794997, 0.04476015020402209, 0.010155394632038812, 0.045990284397116596, 0.05157390857235559, 0.024374194308033875, 0.07413811290696745, 0.08685590023355139, 0.02600307535049656, 0.031610846617108876, 0.08059503135061072, 0.03438771807498509, 0.022670305596904892, 0.03398462176142681, 0.014090853416541172, 0.07220333487155937, 0.05096540493409961, 0.02629841373662555, 0.02362370393389175, 0.04832303361786951, 0.02389699813999957, 0.028900925498155337, 0.031607071718861984, 0.01582730661011151, 0.016296235731832923, 0.03689767492394294, 0.033858485384694034, 0.048029618112430464, 0.021276182622738907, 0.017451638047913873, 0.0359516904028433, 0.037746967657679514, 0.012862207349239579, 0.041282241262735865, 0.03829062195314515, 0.05308574478652689, 0.029724138683729598, 0.009523090557195246, 0.04283747252737803, 0.032880022566044526, 0.033948485394038504, 0.0069267261724528535, 0.07903117010550154, 0.024220247024429903, 0.07290818938805212, 0.086221732649832, 0.033331064492343895, 0.012981350300833585, 0.05459149443213979, 0.02578176021005117, 0.06497634484642936, 0.04918945990803261, 0.051661349848032966, 0.023039820446302334, 0.03157660823255297, 0.04627264142336865, 0.05416949489904989, 0.07331158064546124, 0.03470502786278244, 0.04707727889199892, 0.01971025677067378, 0.02884580547200336, 0.04618494350823664, 0.04674455924560467, 0.03306399858106048, 0.01896288437438348, 0.039259723177359956, 0.052114743664259874, 0.05315087758184922, 0.04941221912421527, 0.08642244002511425, 0.05026965920302657, 0.02853874594063288, 0.016718903676636757, 0.07443925440912286, 0.01358194599649118, 0.05405490729777564, 0.08774900553567756, 0.0359693908643338, 0.03722482128068805, 0.04129198207069309, 0.08048144349407765, 0.04709165453189804, 0.030761630492164727, 0.062058208690535646, 0.02237333927393681, 0.04424721986475972, 0.02561433743985911, 0.06341356761573304, 0.0412930584242267, 0.0338037139285476, 0.042915728408843286, 0.027486210080584692, 0.04392271268091375, 0.0447471228788697, 0.046722319713162805, 0.08651473063735232, 0.06180890069733705, 0.031041769693875988, 0.04629602242681769, 0.0025484776650104794, 0.05072324071079493, 0.039319217565559575, 0.03023514039664259, 0.05363967615149675, 0.005803413364300204, 0.012851956135202802, 0.023529195497112892, 0.04323616766581132, 0.026491728363438483, 0.07416076612688842, 0.05814858239084002, 0.046600385328694705, 0.012538817696153157, 0.03642854183131168, 0.023052411101337884, 0.04551784946553169, 0.015452516287745488, 0.007945302791232544, 0.01901841234235514, 0.03924397624007637, 0.03167044442717827, 0.01960755693876455, 0.037190427763327476, 0.02307626899451979, 0.07937132080476131, 0.06388546628577095, 0.02215904341409764, 0.06758154940701301, 0.04911967312857028, 0.048968244359017386, 0.09812793409031245, 0.10578985521269423, 0.18288145923326093, 0.10693893347296024, 0.12681316944860643, 0.169604420061073, 0.12547351915629643, 0.11973723664038605, 0.07745541917580752, 0.19115366131788303, 0.1524893723187908, 0.08789284620434047, 0.1452801325508664, 0.1091224296138652, 0.17814610123393998, 0.14388283414225425, 0.1684752983912345, 0.08474980961651572, 0.1958594023580513, 0.15207999025381383, 0.1362330478525931, 0.12541537308284353, 0.14648791612877002, 0.19049159281196135, 0.07873661695949494, 0.07241182570015231, 0.13369581061265162, 0.17500491091801276, 0.10909108895688288, 0.11687334717041063, 0.1593597867195645, 0.1253214966686022, 0.22453223475285117, 0.13138075419250997, 0.11044994507345463, 0.11907384280235538, 0.11249422771675933, 0.18097383901476863, 0.16987089608465472, 0.16258118644116387, 0.12819457153278974, 0.1453748823053414, 0.1996418848753937, 0.24615934118628505, 0.13673031552424356, 0.11649000443397992, 0.15788898983549687, 0.0809031289311186, 0.16941196345273526, 0.1536579015514543, 0.1617766715466015, 0.11035484291853444, 0.12960842510144557, 0.09679704018297697, 0.141681281308974, 0.2459691215546862, 0.11274721293199448, 0.08753039468560489, 0.14283888612783727, 0.12282378956555359, 0.15657698765637415, 0.14144428434871859, 0.13925624530642264, 0.08095537612755453, 0.15089736500334355, 0.09890331466111446, 0.13495351247970136, 0.2656354719111996, 0.14837561806123103, 0.20338027137181452, 0.10239554944658473, 0.12568617750319744, 0.12818424466757045, 0.0836348605732764, 0.09367209859192373, 0.17576886911786374, 0.069484994446318, 0.2301487777261965, 0.17131612095380985, 0.13040475817697664, 0.12658123632953053, 0.13228879820915962, 0.1367434769147827, 0.07716871077014555, 0.11267317053411277, 0.10406436473732034, 0.15057275822806745, 0.13827925337658775, 0.15013481640527326, 0.17112404738943424, 0.2107524580412334, 0.17625774046586407, 0.14346220590654882, 0.16392458290342363, 0.10715942889932664, 0.2073191124345026, 0.15037313103675842, 0.14808012262707757, 0.12438729841021762, 0.1613331066384431, 0.12501202012983062, 0.26471245853650954, 0.14636019395003397, 0.09012462886711282, 0.158543121670523, 0.11042990421335544, 0.05708100056395896, 0.14928004614287807, 0.1197523515551321, 0.18393510592079934, 0.0960942387821213, 0.0919242460100401, 0.1257005952779324, 0.08174417089791068, 0.19169761438763913, 0.17927539144312182, 0.17123323024040268, 0.14554296199592853, 0.1109098659587964, 0.19959388180605828, 0.09063148029869603, 0.2647962072683919, 0.1537306339389855, 0.19932553652794133, 0.0904958674143399, 0.10704404839705076, 0.13397195466583775, 0.13060205646099585, 0.11034856099755534, 0.13874691941084402, 0.14355983615161913, 0.17208014044069475, 0.253585736237226, 0.15704106839914478, 0.10760317000770762, 0.13304261340489312, 0.16986200946473307, 0.10233692839861878, 0.1500081973931482, 0.19011309941209134, 0.14688896315713085, 0.20638480692380862, 0.14771189480539293, 0.09183282107715646, 0.15714859650019677, 0.1833236605049141, 0.15024113408740492, 0.15423268199928347, 0.1181816491448591, 0.056949589671867515, 0.20226081773158044, 0.1311875927832819, 0.0834498196960457, 0.24298957579078215, 0.15405764623034388, 0.11005212327525501, 0.13399014159316017, 0.12906223505495057, 0.2041861958681576, 0.20518607850516998, 0.1539994541916155, 0.17793553430707226, 0.08939419467482837, 0.04695657790908891, 0.13658103563131826, 0.09175276488906915, 0.17300601898422166, 0.06402551864964828, 0.19669204800119325, 0.16819688671779248, 0.13928379382817976, 0.15213778392682153, 0.09864944078388715, 0.24488104687583065, 0.2222718004017107, 0.1896180227519043, 0.14191607193600747], [0.03337722512022142, 0.027696223508927132, 0.04375363707602505, 0.06520181218342436, 0.023664354474373886, 0.026530023183553453, 0.009038448014536933, 0.01369924650662729, 0.12043711158537096, 0.009723915718495846, 0.03732096531518525, 0.019972431210560665, 0.03674957863686066, 0.04897042770960158, 0.03440542236691521, 0.04496106442304389, 0.06459047401984853, 0.010982915146967337, 0.0315169797789666, 0.05960043009010054, 0.022101167386638063, 0.047905435259904594, 0.06566490467277265, 0.037444382079786835, 0.05699641679623916, 0.018520763541962353, 0.039591098339447094, 0.03556610685923407, 0.02056570310566214, 0.010939205042837609, 0.022562584058652004, 0.018054064693710497, 0.027849569413510543, 0.018575228562939073, 0.027175513546793695, 0.04419057915407804, 0.03363045931403195, 0.049299458642640424, 0.03523642475145959, 0.041299600815100056, 0.011210702772762988, 0.07448216299376181, 0.01998472692174537, 0.012928706653896841, 0.02193189451410886, 0.018350081067652475, 0.07288408060107501, 0.04661163916030238, 0.01812893829699005, 0.041533908806741245, 0.028117711678327575, 0.030473594839173942, 0.07150351355272917, 0.04881453647788975, 0.038494857163318706, 0.026943023098752867, 0.036081542306008844, 0.03185439554433669, 0.06384802373847173, 0.04850023741563482, 0.024060594301009854, 0.013783470213022685, 0.12378078660056477, 0.017425045220842286, 0.05676796171633948, 0.01852973634677549, 0.021495898554642356, 0.0044795013907846185, 0.0444046049679239, 0.029631476518848253, 0.08527051957864916, 0.03316321462813405, 0.032845540948572664, 0.023633611365972508, 0.015222214935948292, 0.007892194703491706, 0.014301407894480133, 0.061528305673310836, 0.045220975073114525, 0.018306984791472074, 0.03621087326938587, 0.0064176377641307495, 0.026338589302594625, 0.007040561571146452, 0.013285241101027257, 0.03247823243239715, 0.042247527369087746, 0.0930507553200568, 0.06355202651672787, 0.03481409580056225, 0.022147147983853376, 0.053692294900575956, 0.033077282545667504, 0.02042169964331533, 0.02154496457097271, 0.03622753185129935, 0.059394114951212565, 0.12277030896755958, 0.038628121988186916, 0.02064172584082811, 0.04072371337022032, 0.03535673502952822, 0.002114315528512722, 0.06602440675299975, 0.012280961119329498, 0.019193436619975877, 0.055320990166717, 0.04524821715970193, 0.10365594794312794, 0.01564921606557384, 0.031362785432007045, 0.03568881882294532, 0.07266687935278301, 0.016637570036935712, 0.060897363319752686, 0.04136371471348309, 0.05498964947858646, 0.021459517039118275, 0.048576352081351706, 0.06237532695635192, 0.06913701432847208, 0.043459329078154224, 0.045100714590760975, 0.06168481360580172, 0.04472849928143044, 0.05643943257089104, 0.029398683466077335, 0.05301664365575679, 0.05982487086927699, 0.03548761732095192, 0.03379751244680055, 0.0034637676764114373, 0.07158132510319834, 0.05498654682249312, 0.009298600939913623, 0.0186701602632961, 0.09260057907311187, 0.041009061969816685, 0.05470545767175575, 0.13012464578834274, 0.05323454204405989, 0.07703219390203876, 0.028861640509398236, 0.01664220486887761, 0.0397937132736608, 0.0685778007872643, 0.06013686017644021, 0.04030753227491533, 0.03694225741069644, 0.03220474670430826, 0.10745416590643507, 0.04799166228622199, 0.04764847404834244, 0.009938809126915952, 0.027892759535461668, 0.04971100490600352, 0.012630687917642778, 0.05306860739966074, 0.02562040485621941, 0.01979416829624003, 0.0805247810879542, 0.02782929298137465, 0.03161444339991337, 0.052076519707277905, 0.08218615766494505, 0.03469513766767998, 0.04676973289479652, 0.08403287389345708, 0.013822578043947297, 0.14716112355311073, 0.034758757439351855, 0.031623201700107705, 0.04709772194825834, 0.020967472171891603, 0.02702907392484767, 0.022382821527219588, 0.0197747977630746, 0.011491465378522633, 0.028352768520914742, 0.024098492670624007, 0.020475953990112872, 0.028470152343112617, 0.02893198461782548, 0.03342732727046936, 0.08493349451812045, 0.10332390245410705, 0.031583566226125244, 0.003757828850329163, 0.025332796297246413, 0.031955637893969976, 0.012231094541118271, 0.01712706383137453, 0.08175477355478272, 0.04243958178126524, 0.033684525969288046, 0.03975213385157047, 0.006913109917208673, 0.02715020583221509, 0.0623088879811187, 0.03623280636665802, 0.04674831307643364, 0.04948553756900853, 0.05310290132559115, 0.024801357273733424, 0.05725781748732252, 0.08393726612050688, 0.05665614735335112, 0.04168345300000041, 0.03341490515477715, 0.030370734128800612, 0.06352406047705202, 0.0152840870695429, 0.020128155818148967, 0.07380111848995571, 0.0280169366423281, 0.013257833347926217, 0.06382215294926878, 0.032131968351501616, 0.06784896005786235, 0.036990157058162075, 0.010942857367016617, 0.02376062491337859, 0.04228282870063859, 0.019100918096580335, 0.07435320741346768, 0.10462106551013647, 0.017107266204191313, 0.0347566353758016, 0.035674925818438494, 0.04209267035607369, 0.04193425103421173, 0.024646641986985362, 0.0498881129427783, 0.04987498219575613, 0.024261385945963766, 0.03397964602035861, 0.024883767266968088, 0.06646979495041794, 0.026271056736849492, 0.011720762197529117, 0.026094484961621707, 0.026165089539943204, 0.015994235253592413, 0.04555581678305903, 0.006195672885364583, 0.012316111148515297, 0.045867698837912856, 0.043250003213723826, 0.0037776963830354715, 0.03355066742627852, 0.02196193665205952, 0.031058970282995896, 0.052223233205656854, 0.03084418412688519, 0.02706381984265341, 0.04106071927855092, 0.04297596973276908, 0.042106724239044616, 0.0680742971599102, 0.018399407553877083, 0.04036961987073864, 0.010421439731163124, 0.06273037423529933, 0.05963855828609198, 0.1353758414305987, 0.08603702885128799, 0.03932408222387876, 0.04462219692105728, 0.04343381068939644, 0.03930410648125314, 0.02176905103448418, 0.0506372205282171, 0.07805617000426977, 0.026079927375840566, 0.008637659540850549, 0.00835192789729204, 0.016507162720025066, 0.03390609774918806, 0.05858320705292206, 0.005168155541703586, 0.03317579762229035, 0.013354059736875278, 0.009235889940041929, 0.03829683492621107, 0.10496533776242888, 0.057909601262860724, 0.0612574054919664, 0.023792072822670304, 0.02417312112576779, 0.005544593431911762, 0.0413630367256701, 0.013814917164704493, 0.07313904998403403, 0.03563086044103388, 0.04647744736904579, 0.02108808505469032, 0.040147684199074586, 0.04656522189297023, 0.1179282425812656, 0.02993889036588371, 0.021552355404222207, 0.03648628570860432, 0.13069308302815885, 0.011303426224678274, 0.010112348151573492, 0.03159753966986412, 0.02308844787729604, 0.004114978083018815, 0.059997941622690815, 0.07843184420057843, 0.0214560313390628, 0.009077205360236188, 0.09140744309632048, 0.015353600930182204, 0.04355558419540044, 0.02683221805660475, 0.03560127795583779, 0.09316060466751938, 0.03312654582963836, 0.029389381243456757, 0.011009101947439055, 0.014689648805576709, 0.08292540952923798, 0.03912406049728875, 0.056960602185779044, 0.011224237631165214, 0.043019671218409654, 0.03408526656247916, 0.031427320678748434, 0.06392881154052674, 0.017070831062512535, 0.05189216447873943, 0.02677229657438734, 0.03850025042230564, 0.023598001684032144, 0.007776638000993239, 0.01701654990263764, 0.03348533544809588, 0.054163067421365174, 0.03222662617542571, 0.09000214672977887, 0.028525096169042013, 0.02961368795724646, 0.04244638464203285, 0.013016765587963166, 0.07161285728216171, 0.0022540995222140826, 0.018175796064878666, 0.028244097033635746, 0.06448794847294208, 0.025330187767864238, 0.002705204650767208, 0.21449850541689705, 0.07636607279099765, 0.16105019036800633, 0.09697356216248967, 0.1880134209509819, 0.19755329936742785, 0.09881827124064008, 0.18978990223859588, 0.23848337001137196, 0.1389618990041556, 0.1354538904683244, 0.1224636592932286, 0.09999667534664755, 0.2012269054689715, 0.12377689487390942, 0.07748200242678005, 0.15809943418829672, 0.19122233343941553, 0.12239780637525743, 0.21914056922879913, 0.13876931982174998, 0.171983000491896, 0.1096868372311996, 0.16480837257639055, 0.1184379591816856, 0.18434120912946042, 0.15096196153711888, 0.14375207825533806, 0.18425513149028827, 0.13297823137573658, 0.07883165782738118, 0.12074723163799894, 0.14144014747392747, 0.09337494074697457, 0.2471063484347636, 0.09365882994907518, 0.1173423768411721, 0.1370288293448187, 0.1949166698801902, 0.08786964140111402, 0.10045416773326936, 0.2034638822078705, 0.17716244433916387, 0.1878954434106427, 0.12130274497453244, 0.17589706627111282, 0.15056272247625938, 0.10020721929087754, 0.18999283892973778, 0.20875522085735876, 0.13306182689003407, 0.17101906270029085, 0.14885129737517527, 0.15684979156621043, 0.13116902281199733, 0.11437703434738422, 0.18690031051876085, 0.11099964380264284, 0.19413260953320613, 0.07635167033802118, 0.11913087804831805, 0.11012110949283647, 0.24063862049050871, 0.0983684090897441, 0.11309297905573923, 0.12195279356092216, 0.17028017089732234, 0.13205855814439635, 0.15421991897446496, 0.1646549098433987, 0.14202600555314174, 0.14060799212705705, 0.10576187002082026, 0.13685114291166106, 0.11336923802211402, 0.11645743803631876, 0.14196923843795253, 0.19058124042086064, 0.1285878887339946, 0.16221200867045313, 0.07959745463825042, 0.201072538752229, 0.2331234511709021, 0.13246312917720887, 0.1928956686489044, 0.06376753854114683, 0.12295764044768388, 0.2688511719386424, 0.22332486486242664, 0.11162095643099278, 0.16927423616570814, 0.1917742997888596, 0.15598766685974214, 0.18136838961753154, 0.10423084330414573, 0.10616620356637625, 0.30411266691742406, 0.22944379297475662, 0.08842408987543277, 0.12857990609782358, 0.15665659951346536, 0.15211233448597694, 0.10896181161966055, 0.19518837062341554, 0.14640546974635896, 0.12752442079926693, 0.09667284966957185, 0.10381897145341482, 0.17848379279096283, 0.12541469126459093, 0.11847707563109937, 0.15018499516431363, 0.11000285616084454, 0.09874986724988108, 0.11609680980684296, 0.16439192718075168, 0.2127485001279462, 0.10649207438672743, 0.16899570191819824, 0.10955772077244137, 0.06810805865473325, 0.1473980439045737, 0.15630959232728328, 0.1298457284968707, 0.0747207151125035, 0.18843604101529046, 0.13643563214328983, 0.1375625474799064, 0.2344203920614335, 0.15569902025163174, 0.1299286651755533, 0.09806466288864614, 0.17995299621214791, 0.157875552653305, 0.11007778722071841, 0.1287017906865766, 0.29356617961199055, 0.14545348292637258, 0.13491995782861788, 0.21572311228561789, 0.13239873182629386, 0.19544782928161084, 0.10473361148709252, 0.16160117612490732, 0.16457739706722, 0.1620930811810878, 0.17279598831890092, 0.13342190353620437, 0.15470937254928774, 0.11440718756808389, 0.2848033288553838, 0.1694162995103867, 0.10352858582571631, 0.15966488889628844, 0.08356003676571193, 0.10400821049247058, 0.06624798185282177, 0.12909430349546094, 0.17449717848531662, 0.13470055024710395, 0.12120241809996868, 0.14687970881500553, 0.10623261572853213, 0.12335543926324576, 0.15856982749556342, 0.07082524228720896, 0.15577841760410419, 0.12020061258226634, 0.12820480646745813, 0.23598385494082208, 0.08230655604312498, 0.08955197048283393, 0.17905261307474107, 0.17565489055648928, 0.13743427371786487, 0.15949196753001985], [0.12156574295893793, 0.05018694085940238, 0.08969527488994984, 0.03566393628716469, 0.05070052620384002, 0.030180437888409344, 0.021195082639854763, 0.02294425863862759, 0.03739312696721285, 0.04191060189998919, 0.05685622270609583, 0.04186503882069261, 0.049128034978263804, 0.012762578572296809, 0.0802067626688269, 0.018826549452158715, 0.022498428025433136, 0.0026600586105844067, 0.07508409359762747, 0.031896444195280635, 0.04441356436619836, 0.052465757490285946, 0.006477852274979195, 0.07955425494020024, 0.0819140891995161, 0.08403254447564965, 0.06181910115804884, 0.11101316525450639, 0.0028954398435270118, 0.06097548513583118, 0.015187043839344576, 0.05682893082379334, 0.08073125710530628, 0.060811339306735226, 0.024111926022376266, 0.03836837987745962, 0.014108195731927071, 0.0413733444386913, 0.013686200986886698, 0.03126093404247396, 0.03859743633637986, 0.07674237517940422, 0.021535664263571945, 0.013013348835820874, 0.033918799486972635, 0.018491343850450172, 0.013659066152608684, 0.08302775887592186, 0.007541155500803144, 0.1052400492311966, 0.08317236563250904, 0.05622266799271588, 0.07427255367679943, 0.027667529685723207, 0.041744502546686324, 0.03535813697042965, 0.06630681740540652, 0.039022193785997174, 0.0663011789982838, 0.03727296607628946, 0.013882887358176372, 0.0564848845674386, 0.050637607402618856, 0.0393885025574315, 0.026410310454065763, 0.03567073148705306, 0.06998090614234248, 0.02594544064073313, 0.1332527972877987, 0.038811749433197325, 0.026756760311282934, 0.10850486315546498, 0.05774994470900106, 0.0444813478257387, 0.04727512109844435, 0.029608277461281227, 0.050910445786411726, 0.03879727803230767, 0.041510761460109104, 0.031491695047025724, 0.04715712057546743, 0.026322082023046194, 0.013144612255986902, 0.047808789437816995, 0.009783305727215785, 0.04420654059598043, 0.018726144053582704, 0.06517721310017571, 0.01678801629872572, 0.047914930919726054, 0.10486336379882791, 0.07872096578320188, 0.034451288050941886, 0.03013017102925768, 0.036492349294525, 0.03912861872043821, 0.017535520845182964, 0.0871558236559072, 0.02503409095469021, 0.037074001551034956, 0.0397900092385469, 0.04970324060489094, 0.04143838530346271, 0.05340060692340617, 0.02763484071399416, 0.023905216348207286, 0.018651626681187944, 0.06726566837319443, 0.06034154737848909, 0.0543720408853504, 0.031223742388969952, 0.0526947986274477, 0.016660767179282925, 0.06387922266918807, 0.03409292744172197, 0.03886327267654481, 0.014911814303618046, 0.039602708401939565, 0.026378134761245984, 0.015760112080662962, 0.024697431701145346, 0.017542381162544893, 0.049816974018129616, 0.03622286254540086, 0.06614375559072341, 0.01737503883158488, 0.012653476160560406, 0.04201051125663423, 0.052813944451871424, 0.053978271692270235, 0.013328111381269993, 0.05948251766723491, 0.10785047851142385, 0.047115690540522344, 0.027294529136270288, 0.05528675752782053, 0.02518816272758188, 0.06283395315310167, 0.06905706539269417, 0.006237498892005534, 0.03709372831508517, 0.06938695817464782, 0.05082963883215862, 0.03011525721259175, 0.04294849781980438, 0.04279471332988432, 0.05184762795726138, 0.012690223483068329, 0.03016097925513262, 0.0337347008978888, 0.030982765601947907, 0.08188924496813167, 0.011033571753350478, 0.09631232103152622, 0.03521472148056473, 0.034968834069948045, 0.04800450575027255, 0.06786916945730487, 0.009558516378033786, 0.029923765875038602, 0.007849439815242566, 0.020527477233460354, 0.022294740568125443, 0.056458975473839434, 0.04914424539874158, 0.04758200442959224, 0.02772913273093441, 0.0388283007628014, 0.053670557155724496, 0.019758100876764908, 0.033365607396849704, 0.02367048317776813, 0.06369446141404972, 0.0341405934323707, 0.046694407299641645, 0.09386388870376734, 0.07774202799003932, 0.021620226963873834, 0.07916538104895623, 0.03389837558291132, 0.06887995352547976, 0.03395056915319255, 0.026196252081483126, 0.018293105193503925, 0.03645920067004139, 0.015954263658533176, 0.004968543672153066, 0.101277053416256, 0.00823171912587338, 0.006512435399101026, 0.058575178451475605, 0.04291041941952802, 0.04596688041102983, 0.03665117847342645, 0.055376539202106584, 0.015112404850491834, 0.024704202003176176, 0.005467010750209974, 0.03908888557024541, 0.023554738783728213, 0.01671360426342055, 0.018632514702696956, 0.02504793607870177, 0.03800166507942542, 0.05366329464220232, 0.04445403296079847, 0.0427268800746289, 0.04915054264147917, 0.03251590097563402, 0.04669874335729307, 0.02485455250397565, 0.029931164369167342, 0.0710800354699454, 0.04892389169864116, 0.01866926202520488, 0.05210704831106048, 0.018211196987859665, 0.09722603409881554, 0.014796536265602036, 0.014599426630734196, 0.034128075555687955, 0.02904359022185447, 0.025384790684667327, 0.009432125277066184, 0.06492258079590336, 0.07902893312876264, 0.02239890745840967, 0.038058715647146586, 0.024293115392567653, 0.023060610157347495, 0.028939942356138944, 0.023738950370780887, 0.07153189711032376, 0.025818396449810075, 0.04789344598388961, 0.005625622072857955, 0.01991661404439759, 0.0512117060321954, 0.026047140727901173, 0.03791336578527286, 0.06100567666092708, 0.03883528748467084, 0.04489568264914617, 0.03360093428543018, 0.025923314106260097, 0.022366664732896516, 0.11195612755874473, 0.02787315917591895, 0.05330030686191974, 0.029812491604036866, 0.0072155992553058655, 0.11300874768846458, 0.029361945719668464, 0.039824655564922484, 0.07238028586030969, 0.021105931072886434, 0.05552042966648456, 0.008831798669791991, 0.014343711269658901, 0.033069395670487035, 0.024950945517048243, 0.0647065133577393, 0.06379830846262556, 0.06332605356170286, 0.10003051345026302, 0.06723337776718602, 0.03712583889043139, 0.016686992284150857, 0.03533575954216142, 0.014923960627657513, 0.027974037633788203, 0.019283534305530693, 0.05543878384595437, 0.029008890269324187, 0.05693623292890768, 0.08911161548307828, 0.05621827064803051, 0.07045501497604194, 0.03736467063126545, 0.010863534708116806, 0.03742117727656038, 0.044554509222507484, 0.054566657861634615, 0.1370114697924545, 0.026887330421877485, 0.018445683094943245, 0.03635738375446489, 0.1109321821000307, 0.02909560184625368, 0.0722594661337714, 0.022296663448815385, 0.024816874384639726, 0.019370483369716716, 0.009564669021675664, 0.06051662145182491, 0.04527898325074104, 0.05540665794884967, 0.02857353973893389, 0.055708228460242676, 0.055462896463371096, 0.03788208258488486, 0.01428590802055213, 0.048993847017446836, 0.02875308585052769, 0.04332774198584018, 0.03335402031699496, 0.019369776653606566, 0.03741036394550916, 0.0471540370715722, 0.1790760093999486, 0.09583327093071516, 0.014237358155960759, 0.03803449960786008, 0.04689437923051658, 0.024832747726430817, 0.0342896779728753, 0.02406320666083165, 0.07434844234657866, 0.027552740986368833, 0.04165027373199982, 0.050738849752252145, 0.06283306832154913, 0.008694680422664651, 0.05258733947430888, 0.08089885416050112, 0.036158415398770766, 0.03926299437279663, 0.031214815549432274, 0.04082358059202952, 0.0664044093460806, 0.0446222352254535, 0.015159123764944174, 0.006285224254468397, 0.043958688169837966, 0.030406267201948552, 0.029694439370125055, 0.035523462574929, 0.01567862522337706, 0.03413200558673951, 0.06400661543011665, 0.008458728214815981, 0.024492710025139877, 0.038852195045159715, 0.034885096829384565, 0.046608237729918574, 0.0629007330374612, 0.04708623829027338, 0.06993179224551686, 0.038179922248086626, 0.033046589232981205, 0.09896292396250272, 0.10800287638220096, 0.1550375646160495, 0.12688608569723944, 0.18223770022872957, 0.14316608228029745, 0.1873057242482901, 0.13972322186154706, 0.11966188423215382, 0.09837657558701693, 0.11753107195780163, 0.10490658647951581, 0.15351226823704858, 0.3560735303307734, 0.10952988113727301, 0.13854952919627392, 0.1625394193275321, 0.15422852980273385, 0.13530903856360144, 0.10579367033055714, 0.13942892152455547, 0.10524531225523642, 0.14208347746922126, 0.1102335635392416, 0.13923379893024124, 0.14852977027335476, 0.10997395932434068, 0.13144685225861688, 0.2573374526635293, 0.2006996837594817, 0.09998477800118347, 0.18517678122847311, 0.1393451115056392, 0.14576480573704167, 0.1780224852864781, 0.13622278227440773, 0.1929641109440596, 0.14275936620129695, 0.12660955860009118, 0.11954636583405158, 0.08629826483346763, 0.11709892175971501, 0.10985020548105241, 0.19636984674199937, 0.0916607117640876, 0.07489860838940067, 0.20362571062099552, 0.09098983324703672, 0.13177046311959145, 0.17550654529083162, 0.10142721431029421, 0.14875686937762847, 0.26397664640699664, 0.14691439727621694, 0.13145158668198895, 0.20437148189352405, 0.11346161290402375, 0.2242622040813008, 0.28118031520035963, 0.16559954221931197, 0.13158890028153697, 0.1303683843223318, 0.11952724427946153, 0.12317262004099547, 0.1219804340132302, 0.15504399975461347, 0.15435622133795293, 0.1063261244205698, 0.1764348753157162, 0.11125973831381529, 0.17156054896693076, 0.17155431301122712, 0.21564023689396922, 0.1643620191081878, 0.12034841392549778, 0.24322798235281823, 0.06622882199383552, 0.15849363239061448, 0.16257901075145892, 0.1857582572847605, 0.20052326903227838, 0.10334133861526366, 0.1767765198864283, 0.163702187579005, 0.07844667566279251, 0.18940858963516452, 0.1996664916195216, 0.1343221028125094, 0.13568828272963726, 0.14673615925975386, 0.1481736772843907, 0.19149162866655858, 0.14783413179459112, 0.1721891241088029, 0.08440445718025008, 0.05509764489327228, 0.2143289395157368, 0.16255042035012476, 0.1649780457298602, 0.17388326626631523, 0.07823011792835691, 0.1826453356132392, 0.1513990453414379, 0.2445794533817999, 0.15141337118562193, 0.1128562119218611, 0.16600743807371587, 0.16067715151415718, 0.12191666485441309, 0.27505326655603224, 0.09640750745611806, 0.1187805843449408, 0.11815606180818812, 0.14588399369630123, 0.2958702350095395, 0.18070454378762554, 0.15014623111534506, 0.07298122054987377, 0.10192041405506673, 0.13972365087078464, 0.21474477204103626, 0.10590298341647272, 0.1261510549774093, 0.1520359095546507, 0.19877793687966563, 0.1456509497497351, 0.19695639430034548, 0.08076118816050791, 0.07866938508326009, 0.12466900426173404, 0.10483417584891282, 0.1346015870090454, 0.10431427793997912, 0.15430343787997, 0.1789844312494801, 0.2888924610470572, 0.15771131872409777, 0.14394692505799955, 0.08768100757151844, 0.17161224458006122, 0.1876930429810478, 0.17606641766765427, 0.10639315711394434, 0.17030226487305858, 0.13976292053778328, 0.12996430358579084, 0.08818286410983532, 0.2407509749454837, 0.15305664510496203, 0.12051743590423178, 0.1479158274108364, 0.15947543535261385, 0.09693669035069405, 0.14818265583486329, 0.14798474468050465, 0.18218821094882104, 0.17716002350132312, 0.08774781809939493, 0.21261558387308352, 0.14827735962406283, 0.13989015242024777, 0.12068144000706174, 0.15052843238076857, 0.16061394926040404, 0.2182923566790358, 0.17282300057911104, 0.071757088655666, 0.18812375293383676, 0.12777215065134148, 0.07088761716600388, 0.14037897780297265, 0.14051570917569822, 0.22466024804499843, 0.09706600599231259, 0.13488173004119627, 0.16227490448903653, 0.17903136179572154, 0.18699824719900088], [0.05647586005169058, 0.02328809613602296, 0.00786614053199188, 0.03694026175165369, 0.013687129868494888, 0.05188014455920747, 0.02143713386519061, 0.0228683048513748, 0.048284223603625456, 0.011654306942927501, 0.05075093478925767, 0.04999792398584466, 0.0267074299946187, 0.03521186014216754, 0.006046503117578405, 0.019187440066748572, 0.01952473134283097, 0.023153494487726883, 0.05563128641956756, 0.03893093739245688, 0.00663011416514975, 0.06415613281029849, 0.028281353804613316, 0.04730812033578273, 0.029463770296124202, 0.07567924432336323, 0.08382877274867027, 0.06490379632000001, 0.04940994384308015, 0.019064969420733473, 0.016329888059126756, 0.017832081141551177, 0.06370640472478925, 0.019669297879802126, 0.026118674187830863, 0.016136948815396717, 0.07105813301619023, 0.056182099806685606, 0.03982739049881216, 0.043374745310434414, 0.1962872931072789, 0.01214218046140647, 0.0375626775466146, 0.03341072231471058, 0.11743947082469541, 0.09624944053470127, 0.13942274685588577, 0.05977672607367558, 0.041310977220775626, 0.11537064272429674, 0.041324808938248504, 0.1269451740588392, 0.029091564562892722, 0.023700098221701, 0.026188957009224162, 0.05766804990989547, 0.07511673660408105, 0.0051357414040173735, 0.03912356637057759, 0.025936557851251096, 0.05667545276904299, 0.0647067125405996, 0.016266298930971854, 0.027498808396499486, 0.03680964759100349, 0.046872461455002914, 0.047633294016122825, 0.03972085065118248, 0.028845772913266576, 0.03311723020047911, 0.02406110183425969, 0.05427807254055816, 0.02716124324398416, 0.04413179339720838, 0.07613406306312931, 0.02110453296242462, 0.02848608122627822, 0.044742208424835436, 0.01962080259897536, 0.10474351700395347, 0.01411085501463423, 0.015467508628423658, 0.09233168221168941, 0.06547018044417904, 0.04198669358306835, 0.03128658458139868, 0.08527500885388545, 0.04802576085973171, 0.02332684869367269, 0.08075183422695245, 0.034405724971645305, 0.08154469692418653, 0.0011814917994460333, 0.016092743626945925, 0.0515738932505971, 0.009010440797635145, 0.02806827027891432, 0.05134561437092001, 0.0324358256353486, 0.03139673270315173, 0.03466488868598977, 0.017420509980330547, 0.034921570275459564, 0.0686408881278288, 0.05683880569713731, 0.0309657258912921, 0.10087515603029922, 0.07282225730558557, 0.012062671068575115, 0.05513632084212958, 0.05420540527050054, 0.07046051548733827, 0.02372069641076509, 0.0006676440100437181, 0.046337391174728834, 0.08903856133861889, 0.04511586780990324, 0.04263914002466106, 0.024422136090335347, 0.04612597772070477, 0.0324588772209902, 0.04846729563489076, 0.05487911448243165, 0.006735229568045226, 0.04125720167893075, 0.040396191630392306, 0.026807864121491873, 0.0997252733777127, 0.02971253819733618, 0.04979385731501445, 0.013013695490606611, 0.054444876694751364, 0.04903772470331, 0.010609803514765396, 0.01419237538826682, 0.042493315188274275, 0.026028825480851437, 0.011108906924604409, 0.022060212326206027, 0.021008111221054872, 0.009280687889024135, 0.01777114650805391, 0.023756643171392144, 0.015320001271433167, 0.0458564488367448, 0.05881187280700092, 0.03376427189176602, 0.017147958879509283, 0.03725765963956233, 0.05456821685056052, 0.019034381445136764, 0.026876861830392194, 0.03626352649242167, 0.016342405935809497, 0.04212197321917742, 0.021412310701224114, 0.05310485101935845, 0.05355361383408309, 0.02435128636387808, 0.023260451853275303, 0.04724985168826196, 0.07022064569736682, 0.052816870907742175, 0.009621259936642264, 0.02347798060415493, 0.020681142979752154, 0.01241357668468188, 0.030464767591066422, 0.009376742865800137, 0.03247663513907502, 0.016818159943326347, 0.02086790563959268, 0.015436883306040641, 0.06583715954254712, 0.03884438094833205, 0.01809878699151018, 0.03056345312225242, 0.011336278947701138, 0.02712262475172118, 0.019535617452234994, 0.011436443986190904, 0.03446065730625584, 0.06868052551703108, 0.021525720442314784, 0.04219692726168902, 0.060854592630940105, 0.03044294174610367, 0.03996863029897213, 0.08787907194346191, 0.025936136502892743, 0.09387305877622097, 0.020844689345047362, 0.06650029291068354, 0.027304633835991545, 0.05695035575979179, 0.022402638306600914, 0.050649822674571514, 0.037838381099244284, 0.07142531129741861, 0.008335907083575525, 0.003604549499634173, 0.05690604523425141, 0.022712808154943972, 0.06327695498663573, 0.057047710213209354, 0.05623320936255398, 0.0054127348571895596, 0.04776532160899332, 0.07433754857629538, 0.052603637994897944, 0.0606900982318386, 0.02575738137708076, 0.026977876268868006, 0.08028634388240115, 0.024414812289779226, 0.10152545742570393, 0.04663055387115286, 0.023561509085759044, 0.06682997118801841, 0.07946233971104508, 0.09599742825112997, 0.02771531250478039, 0.026482744067306482, 0.014050896185630513, 0.04173821296482798, 0.08057949508750632, 0.03358462810396187, 0.03999069363119141, 0.03406278188190153, 0.003733311882129901, 0.043192198049397244, 0.06053520674486795, 0.07125438175975315, 0.01858054138269396, 0.06530981525898942, 0.015144683007571488, 0.039769455099538456, 0.05420922804924269, 0.041708274248747096, 0.02070301095955074, 0.03226117291037114, 0.09098946552483306, 0.06923982332791052, 0.011137897606878992, 0.02512881198086806, 0.049252669822665, 0.024448296077729716, 0.04067671004562609, 0.07215258154657579, 0.016408383343068343, 0.04012845156173553, 0.00921633363055486, 0.0355723581366962, 0.03093617979527241, 0.06972143982326792, 0.03125875643754919, 0.02063669647360521, 0.05509053176689533, 0.005113467397618919, 0.032974416089634744, 0.0308792824451361, 0.03525941888050687, 0.01887777775165535, 0.09747711941599847, 0.025429028431854905, 0.07215707082181208, 0.027153681956171512, 0.05810581553246706, 0.04650002398017434, 0.03274232592253435, 0.04655862587594217, 0.03494142727445691, 0.037984018244089625, 0.008896291781697542, 0.025901064997719183, 0.007517640910772307, 0.045539759580166116, 0.0291678381918539, 0.03711998980912951, 0.02661442309017143, 0.0270462783444072, 0.026919255220902064, 0.06384576377909511, 0.11869300517343706, 0.05325020088123218, 0.06189040862204087, 0.03892091696240729, 0.026556255949300625, 0.08006710484023057, 0.0353053841559637, 0.050224015684497934, 0.018400476246531454, 0.07808818481862545, 0.04834982371258159, 0.10259624916098772, 0.02967793017535681, 0.047546595845732, 0.015128757954845506, 0.05424385905385979, 0.06935269872267401, 0.015508695430452786, 0.052570493200853954, 0.019835249761179573, 0.015574041772784005, 0.04938919818209064, 0.02988518377195203, 0.03450433197881907, 0.01983912233563681, 0.01866202823997986, 0.04460193772589968, 0.09081924844893718, 0.030014152758784836, 0.031959305539907466, 0.03178560084873631, 0.02275279219893198, 0.10000959158905091, 0.0759987566139429, 0.02724343298694059, 0.0777137287021164, 0.02732578743880074, 0.06124776810587895, 0.034336045444492376, 0.01982948111910974, 0.05921483888561207, 0.029517471144396453, 0.06724364334537138, 0.15460467897355556, 0.02068334739775427, 0.025570237588497902, 0.009165977713682, 0.017883535436985475, 0.03112830698580271, 0.03784498477715158, 0.016673851961029634, 0.06399119408020089, 0.042783156893546545, 0.061446165726069486, 0.06346814371945877, 0.020288478868502765, 0.03465580671364742, 0.02734927569455918, 0.012934806628993923, 0.03434483247298387, 0.0717651402397502, 0.0455504426762702, 0.08348949538964419, 0.035020119826039, 0.026641883511817264, 0.028107995768227888, 0.021758390921017817, 0.03261143597023141, 0.0580096063804963, 0.20186706386025877, 0.14408760944441443, 0.11744219809770585, 0.20565710000453458, 0.05083239674868603, 0.09656871533802441, 0.21800378667971781, 0.05707847630424846, 0.12504268662943957, 0.09027556350995457, 0.10814576710183775, 0.12492575862955664, 0.1653384441329587, 0.10193394316780953, 0.2410356838616633, 0.12053073519059729, 0.11021757528426186, 0.12674883338472537, 0.10624056006030691, 0.15951931686891666, 0.10442890001520996, 0.19047101569031516, 0.16749403169078214, 0.1549478250765993, 0.10242060052170869, 0.1621563294001164, 0.09409921559234781, 0.1111313266559474, 0.15825562419429903, 0.19163756841613402, 0.1734222651970002, 0.18205534065923384, 0.11586890631024876, 0.09383467777121453, 0.11534762944305137, 0.11116807589367514, 0.1624502160496289, 0.2035914511690217, 0.11484359721502951, 0.11108998855155323, 0.26723016053438187, 0.12927200525037705, 0.10979748331010343, 0.20191721197578216, 0.1977023034687004, 0.12872454349792775, 0.3495634990113397, 0.09712531651941039, 0.20201979114884333, 0.23780548945069316, 0.14884683874345597, 0.14435122029915934, 0.1269023420829927, 0.06692888079992225, 0.133271643050736, 0.20311142047566755, 0.17717267927383223, 0.06792844168000645, 0.14456123564272158, 0.09913854961914402, 0.15086492884062952, 0.18022043750651423, 0.09737133799541382, 0.07900837132887495, 0.20745382133510806, 0.16513023675689775, 0.0834324065175268, 0.13438375756865548, 0.14432586278886567, 0.16466379646332036, 0.08694618369542784, 0.12323818950643464, 0.22905843542708507, 0.10211352949901935, 0.1296160553371714, 0.1478202043161277, 0.06674941704278031, 0.12015326834854581, 0.13235167870598455, 0.17579364440133496, 0.0800954424325497, 0.12654150700977734, 0.10620050132274629, 0.21180993516839322, 0.12399771205720403, 0.15702522570087066, 0.21344616107882994, 0.2013540760644021, 0.16084729964213987, 0.2373720062596183, 0.15787945970171885, 0.23476203663214562, 0.11263026194947381, 0.16154232525056408, 0.1453834012030594, 0.07875436721670051, 0.10210514849712772, 0.11343041014286781, 0.19496055139649301, 0.10429722482278463, 0.163413648223204, 0.11538013455367858, 0.1926721701578748, 0.15889472538425078, 0.10064631024555815, 0.12605008458898914, 0.15241959703064736, 0.165694828235334, 0.21312726931946896, 0.1729059985448276, 0.1477389530308785, 0.09057408499140894, 0.18290738364861858, 0.12385093727179113, 0.2601217226155343, 0.17101114135115378, 0.14401752772110124, 0.09804288300895884, 0.19999051616797525, 0.12025596243479561, 0.1630707166247791, 0.2593869523655984, 0.10578341241325102, 0.1750501101055453, 0.16555258102955359, 0.21339483318790314, 0.12071275768140632, 0.14667436660778138, 0.08734303256196362, 0.1425486154133274, 0.049183093717381846, 0.10959440106225592, 0.1490334271182937, 0.10374931107846, 0.2815559740749098, 0.1442844021104036, 0.13507715907068024, 0.14765566395175073, 0.11004502164019693, 0.12660502335957943, 0.14064795127318752, 0.09045762430515983, 0.15092508206444402, 0.0973992542393746, 0.12266556942655195, 0.1746318873859221, 0.11632933281362058, 0.14349367679847827, 0.12424563343125967, 0.13568969233141792, 0.19334770648950533, 0.15211777371023932, 0.1745317137289432, 0.08224071844691232, 0.13207973281462349, 0.10683322866116801, 0.15139193604550055, 0.11276739934879927, 0.17588767403316113, 0.1993354497056815, 0.11615808151902692, 0.27861536089931765, 0.09407437902184264, 0.14168357957274685, 0.11948630454078799, 0.09087217746362572, 0.0814002433851842, 0.12767884114216413, 0.14767973443433163, 0.23914264995724926, 0.09721204533331818, 0.13972781838909273, 0.11178632417032797, 0.17495323062664078, 0.20002419339312663, 0.08703459024188981], [0.09685650392765961, 0.04851354819331919, 0.027777482455055562, 0.017138216156332244, 0.042961594092869954, 0.026939410994189884, 0.041942371566209107, 0.03796718346195356, 0.016342892401641416, 0.03556170568410908, 0.03748532947933963, 0.10819396935403348, 0.04432646399964729, 0.002487289743693245, 0.02932005794718862, 0.047097572561113105, 0.029263126123095715, 0.1264080238498507, 0.02374390504443117, 0.05278884358103237, 0.04097962504132621, 0.016477497880377116, 0.016420487532271974, 0.03200592582053956, 0.034055511707500104, 0.018180790958144975, 0.06692372502819185, 0.013055378334566712, 0.010907806929260975, 0.02105509347823118, 0.022353664220821474, 0.09968369778606201, 0.06042610816357117, 0.08396594845239194, 0.02535406289802444, 0.022568023282914393, 0.04901978675456298, 0.09304327064103658, 0.01396961521447426, 0.0339857287584774, 0.03494213590578687, 0.03685026557274884, 0.043298289735591224, 0.03163834725837073, 0.07908634375780821, 0.05695102608672554, 0.09835918539113576, 0.03162137649562811, 0.037893910982435754, 0.03515947888034486, 0.19226761444682078, 0.012275954734744325, 0.08120866777795939, 0.03507914307016519, 0.022245670721355467, 0.029554155264650623, 0.06695103606269245, 0.0396004599338818, 0.04064717735614508, 0.03158449510773344, 0.041780324818025676, 0.03222851841259868, 0.14507030106840596, 0.08492398736698013, 0.07966957415544218, 0.02739936826870807, 0.010864020216338819, 0.025431485658872034, 0.025916315893071796, 0.03879000402746662, 0.09644742063697308, 0.014818622580459042, 0.038400884988086845, 0.07766409386550227, 0.02929629198455763, 0.012063213075781542, 0.06276896591448496, 0.028120191887982433, 0.10094668565978927, 0.029410983007701657, 0.036342648053241354, 0.06709512187949113, 0.023565584673516216, 0.08030456145324054, 0.07349611590466193, 0.04337032115267169, 0.042697634668119495, 0.031383760919373845, 0.02684464400273658, 0.03335936378026682, 0.04566592276997624, 0.03314497024421731, 0.03977770969692258, 0.03707119000835284, 0.08126744970438943, 0.07288081706651757, 0.048573337525369666, 0.11124365812828464, 0.04291387830650614, 0.05106405407610921, 0.05555143707521981, 0.06314330328736575, 0.02196074730055707, 0.024104981435342662, 0.03711138281130022, 0.016186462993162776, 0.12628475264195474, 0.012266134445164955, 0.05268041532666934, 0.01603155618443364, 0.04658256612357594, 0.03746540736286871, 0.06322531299965997, 0.0056130534428502285, 0.09296056378873126, 0.0370048544549894, 0.06475988670342392, 0.03905495936651865, 0.062075740612682805, 0.061059341120022925, 0.09915170334880391, 0.054514797539600444, 0.006111595693284707, 0.06473544849863937, 0.031648923102165424, 0.07282201215744981, 0.03163787802951711, 0.017077938443230047, 0.037082662175018946, 0.033438653880429846, 0.07229697379854418, 0.03941862896505383, 0.06226291504478263, 0.05251675979384492, 0.03460820584047226, 0.05662569152792135, 0.04693945967442086, 0.03416064961422836, 0.04481292600112577, 0.03044187688388892, 0.048835251495362296, 0.04922415219968365, 0.03144141286611557, 0.03418287765535136, 0.04894577883063786, 0.03436758145389538, 0.14772274261040075, 0.09748357753720015, 0.02568025930574344, 0.042277814655174176, 0.041369755316766045, 0.041710587834278424, 0.04428352094105175, 0.08737215922484476, 0.041843040605946895, 0.024460252795007922, 0.03693632789016251, 0.02223988675752715, 0.10287922671845845, 0.10639259786975962, 0.050251299905921185, 0.08321083856806641, 0.07860150969316883, 0.010113014648067615, 0.02399592881932134, 0.0470422150477046, 0.013974691504582524, 0.06385334804954548, 0.13266916086356487, 0.059690449251643116, 0.08440127791536432, 0.06252008310008435, 0.031079832772393862, 0.024712749629191334, 0.04015793828594108, 0.024562820476750215, 0.03234039023218136, 0.024444383283656453, 0.04946916627006666, 0.01780305598532, 0.04798306294927194, 0.013564833507482565, 0.03584952874770088, 0.02995200196070777, 0.016306372990290967, 0.011670262639170453, 0.0026744354474959116, 0.06905915681272745, 0.015983778153425984, 0.018908844532204733, 0.11767534163570213, 0.04774349193359095, 0.029256700560630813, 0.07377393769040223, 0.05557699376837381, 0.05386657990334977, 0.030143778666012713, 0.012116981914357073, 0.08189211779784772, 0.019293190843816248, 0.041373386573527134, 0.03916217720196132, 0.047975513152778156, 0.005092572828289121, 0.015180962058835694, 0.023337112356638236, 0.02276677521876991, 0.03900631661376646, 0.007866429251378343, 0.08001268195408968, 0.018393738503237406, 0.011159188147904653, 0.07934015634800158, 0.037197364689481836, 0.01117893885220251, 0.03244450924197032, 0.029443378950799667, 0.04605139906127607, 0.04562647307231542, 0.020320926522535664, 0.02894968124887636, 0.03407967029019229, 0.028773590193821058, 0.016374782726709402, 0.02916071357415809, 0.03384302573038205, 0.05442946683615447, 0.029648855223410556, 0.0817916913318538, 0.06199597553800672, 0.07634574081748724, 0.025595949414456566, 0.046582979811055046, 0.028817642164686998, 0.04283775597991001, 0.06377798414999439, 0.04651218945641191, 0.006667613690238327, 0.07953539385550445, 0.034233822502316005, 0.061953771754258105, 0.03354155097997958, 0.02300330869583113, 0.037820431659178394, 0.03291510173209733, 0.027123708766134038, 0.013507946691055213, 0.07827486512401412, 0.012294285303552546, 0.048719396018573356, 0.03875847567894286, 0.03880853952479459, 0.01467651614333473, 0.007715679906053289, 0.02303349064482797, 0.010819818858327645, 0.049029730575820135, 0.03533927588573387, 0.024542783447090658, 0.022736660302466443, 0.030077469925726616, 0.04671020786307993, 0.010543771523741946, 0.02662266619623669, 0.03379325682838117, 0.009982715541076277, 0.06400638177329976, 0.03719082995948773, 0.02571045657649877, 0.016708816213893796, 0.11579893950012424, 0.04816982752433227, 0.09601451201184143, 0.03668875508611241, 0.02066428138453874, 0.04150536054024293, 0.062421062405431466, 0.028491204439271844, 0.02933008795333726, 0.04646422086103309, 0.03477808966812107, 0.017059395285022837, 0.06167069460535723, 0.032793163517189604, 0.00989940443692068, 0.008767502825526942, 0.07763772511914854, 0.07206949165030833, 0.015439533012648745, 0.030352307799001856, 0.049022437418780984, 0.04880836180922005, 0.05357500683936862, 0.05608877880618938, 0.029493653470830574, 0.08111882864707902, 0.031561703991986094, 0.012887512190988468, 0.021214815149564418, 0.015508128525388819, 0.013581120536752768, 0.0031372739308168215, 0.019667551199334766, 0.01855738254474296, 0.06368784624482356, 0.07439734173878547, 0.0598799066257573, 0.015616480170959427, 0.07360546729497372, 0.026084071911510923, 0.035836984057940786, 0.017376484822541956, 0.04780645670008756, 0.030301966246277578, 0.05451438768256096, 0.035051364722030784, 0.033007580035876845, 0.018167196727928617, 0.04953716423422579, 0.016853668118616747, 0.05137521983875383, 0.021203025056409742, 0.03433298875367449, 0.08217107339371597, 0.04882276426219652, 0.03809494777552543, 0.08597671474900939, 0.021412536697161776, 0.042426504660397775, 0.0358852744102478, 0.017987872781832854, 0.05197580212787275, 0.03878549176959261, 0.017483352172759273, 0.0350817401082285, 0.025544347647096843, 0.05331313500421182, 0.0671523716300726, 0.017985001867336613, 0.05209155035235229, 0.03268204246377272, 0.014278179151006045, 0.02214002528137738, 0.0862119956723144, 0.03724588103772652, 0.0234028963266962, 0.04346161968104782, 0.006427663461034817, 0.01234265705270152, 0.021466595691538626, 0.04546055758011438, 0.01845779877546574, 0.1448068740747629, 0.1475216598520356, 0.11748692231072534, 0.08850324974064866, 0.10039380000483605, 0.10725033289242177, 0.13850423807819046, 0.09937900163593794, 0.13398260328798525, 0.15903600731924658, 0.12384516096884206, 0.11299238405040196, 0.1281420715273388, 0.07879509245075526, 0.29923749787192194, 0.1445637790546302, 0.09866591167425919, 0.23165346634003425, 0.1628795010788787, 0.08462369622242066, 0.12019900379762535, 0.07127184856442675, 0.3260462238423286, 0.06260175190325226, 0.14684457602279802, 0.11223969500391714, 0.2096902005254261, 0.12738681608630767, 0.08489914313559571, 0.11034207989371593, 0.1377143861064988, 0.18650778238811802, 0.13461966668405842, 0.1993879573720117, 0.16856851596986094, 0.09848510726324974, 0.2123834132667511, 0.1718192568589603, 0.11030125506823102, 0.1284564357070673, 0.12284805157011557, 0.10758656888238846, 0.13890372228718575, 0.18166442131323202, 0.1175400505082742, 0.1002471937587665, 0.21782266817265944, 0.13427414570844945, 0.13672305301072138, 0.0940793279498335, 0.28149701594825716, 0.11342893159317394, 0.14194049481903354, 0.16293032335177546, 0.23686223603304357, 0.12726589676833924, 0.20801729432517485, 0.1951198363977094, 0.22126915984817092, 0.22147873086073708, 0.24928979094951387, 0.13231892078634233, 0.26717279587061177, 0.17506955341706354, 0.16980507381020055, 0.1362105861546532, 0.1725576124003818, 0.13034478881426398, 0.10433140766596603, 0.10970419678356379, 0.09972593221332758, 0.15955107887425732, 0.14905319218674015, 0.1344497637042115, 0.16241811696560154, 0.13753493767111533, 0.23035249582702116, 0.10980541232011973, 0.25019906070684234, 0.09708037014089285, 0.1690988939615988, 0.22569676500654992, 0.13612948808698885, 0.12218802851895172, 0.16725922574199018, 0.15146492890292598, 0.11502323717239404, 0.09393464458445389, 0.14823838107047543, 0.23096414042576668, 0.10018940774663802, 0.08972974118566321, 0.07212866428157977, 0.18746548422401954, 0.24214193014608276, 0.11916598785788783, 0.23782116360962394, 0.19639954030994447, 0.1314332005718062, 0.1412732015934683, 0.1384180378649504, 0.14378764005678316, 0.11769864603035873, 0.14196091872309485, 0.129372684525386, 0.09604869485502282, 0.14582996917588098, 0.15321534787935598, 0.11241477673813222, 0.0929503518367006, 0.20053819242504337, 0.07651125411352805, 0.15408931630513362, 0.17765318494169943, 0.13821441169467666, 0.15704289168840455, 0.18538077512095053, 0.2076420184945868, 0.17980632101816518, 0.1745632305861481, 0.2087944905243574, 0.13921692967414856, 0.14542486188152146, 0.1446590650706522, 0.11642405192457861, 0.1741476585307429, 0.13512704671630937, 0.15773569564184836, 0.1607286785879443, 0.12753072570288373, 0.1679482605428465, 0.1116221591890339, 0.12711531452594266, 0.10076568206591953, 0.12689884872205798, 0.14811072017877333, 0.14555975464322876, 0.12925317480919823, 0.14931372336802945, 0.07761608313528762, 0.19327236940303158, 0.10516956148128356, 0.15307555215493326, 0.07441713745074888, 0.12868099906031163, 0.10905984789133073, 0.17808371103338658, 0.17416814372183817, 0.0966419839871026, 0.08355496526365319, 0.21117115573536968, 0.10448183669077774, 0.2084778050982183, 0.15336807516794052, 0.17368123355892398, 0.1528851486622326, 0.20711868851175233, 0.07623615960079817, 0.3905467514789874, 0.14480198643380596, 0.10618971480477242, 0.11532844660142738, 0.21708207565449902, 0.1547396789875723, 0.15381615999485218, 0.1419750453844186, 0.09806751273572446, 0.1663795269785389, 0.2138415390565511, 0.10952110176966076, 0.18243967164908687, 0.13771164351172988, 0.13365500876980443, 0.07816630280426434, 0.11588733072482771, 0.2001491116900598], [0.07327032681073874, 0.03360076957652646, 0.03739048013343446, 0.022780139622608983, 0.09250284923661141, 0.05322295879464477, 0.01950117222393953, 0.02535633434871993, 0.0293072221440173, 0.01818142681112213, 0.021597558422194376, 0.04029974499116502, 0.1782545792840181, 0.059797916065661184, 0.031751013894174854, 0.028392572534240546, 0.04502550773923436, 0.007840646562286684, 0.07627359065677851, 0.016405290263074062, 0.016232520199170517, 0.041621656517588326, 0.08813823948824599, 0.040748427366657604, 0.042733824661662506, 0.02791789488025731, 0.07950103481210048, 0.0386247358795616, 0.013435483391907428, 0.030703497825250513, 0.08572807325230491, 0.03993502202173395, 0.02828712627712277, 0.00486133253997973, 0.05123215674933407, 0.023547206224212726, 0.04319327823337048, 0.042063815654405666, 0.05274358310646588, 0.027250605485131665, 0.045487493231532075, 0.02074174244978255, 0.042458553948710044, 0.05689240886919922, 0.04706430519300123, 0.022863704493389498, 0.045556896967032266, 0.006304877282555906, 0.02257369041833426, 0.02407527637607869, 0.08232384664757599, 0.06841332937080054, 0.0700300736653228, 0.08993464672277052, 0.030267078602205844, 0.035680276942589594, 0.0234567484773335, 0.04056550472253754, 0.02824410469451499, 0.11764882733264279, 0.049069440743375214, 0.037703001871705055, 0.07301821493573728, 0.03300473018879852, 0.010322074296944326, 0.029738087229610934, 0.026634071330209414, 0.017334058873295304, 0.026049664987611677, 0.03649957733409059, 0.06939985909529271, 0.0380487488432517, 0.022188597170996572, 0.038076270551931475, 0.010568154187151983, 0.025535148846346046, 0.029510164580818628, 0.013907556346948109, 0.026885790585149682, 0.030550056159676566, 0.023224378688140743, 0.03175070745900514, 0.004465628017280852, 0.02330109090243857, 0.028285343207479007, 0.06253674934287706, 0.029384641074425275, 0.04735449546827905, 0.0845744674124064, 0.04209381182708087, 0.037995670441417925, 0.08170549111861376, 0.01476249993673616, 0.007583419135170839, 0.03252353121135985, 0.11945368451697212, 0.055783331889899514, 0.013989395604679182, 0.04269365867179248, 0.050855639856308706, 0.02443716290497011, 0.036100365086308414, 0.04283659535670473, 0.022734496104080352, 0.0499127388391043, 0.07470404503927117, 0.08740720008650134, 0.02673585568704913, 0.04780949423870733, 0.06786239724005423, 0.0159793243097562, 0.06326276320783843, 0.02550309189715453, 0.03780599473224532, 0.05728415175971966, 0.025714007394027807, 0.016538482309589465, 0.03797780910146333, 0.05808151905394851, 0.016831286859908895, 0.02729197040260319, 0.0470778304753044, 0.01333577992139204, 0.008474727961114578, 0.030687733650988633, 0.02608775296398709, 0.09518605686964528, 0.04485334480001081, 0.03325562398400038, 0.011590428616581185, 0.02311028138313803, 0.05441205365763557, 0.020025884995477337, 0.02381292573596922, 0.036596196343100844, 0.05886368333332001, 0.020161178038125078, 0.0210295214633187, 0.0059116855282486695, 0.07675582768335458, 0.06117617335891532, 0.06343155152975552, 0.09941410378462846, 0.04190300230778033, 0.04376134009010369, 0.04444281743358701, 0.030140310202935533, 0.0730316061526537, 0.038384318336724274, 0.014328542728758147, 0.03735366194779354, 0.037796518224621975, 0.04673936516947804, 0.015374214441004782, 0.08296965876774443, 0.017551127971420367, 0.04939576355560173, 0.06381454569618068, 0.053564492282607866, 0.007020308121648287, 0.053622443003640066, 0.030313108995136236, 0.03248097885760569, 0.013688279000381309, 0.025829414709381042, 0.04190941063326694, 0.056372913156425765, 0.01694291161613599, 0.04049083413255792, 0.04779659714850207, 0.02794938875482448, 0.04320845060471085, 0.06397789096339576, 0.006433292770863421, 0.027349179933568644, 0.052487740383273175, 0.012183032099968724, 0.06313480354184586, 0.026806228523773533, 0.05442843261745669, 0.02564865626364706, 0.03598015439966994, 0.03257834480234212, 0.060557519055662624, 0.015387942736607887, 0.02578574003681781, 0.04733017983756239, 0.02643693583987413, 0.12177923634167641, 0.0895045726229587, 0.06611469787575545, 0.016261441933531916, 0.0859014772539658, 0.04023396485154668, 0.06219934123838621, 0.029466802089084542, 0.06346042921406127, 0.012105066374304795, 0.10386858330739122, 0.027086526688729084, 0.02276527560165813, 0.03533368344388662, 0.03695923391909849, 0.023850801122945645, 0.004400699671673319, 0.036931562823273485, 0.0493593743791984, 0.015467566085017979, 0.0573844364994476, 0.02977192150278678, 0.05494553047502714, 0.021976191633110567, 0.055201216150195374, 0.05700062644938308, 0.014290025743145137, 0.024840950612880053, 0.023068190597358252, 0.02609878654531654, 0.016445908244819413, 0.03637139550259998, 0.0750391242364722, 0.01727513139015965, 0.009921927421894527, 0.029698053389907848, 0.04084398151345311, 0.036698852124954426, 0.036080523409069545, 0.04720040454318927, 0.046719653727186304, 0.06648308657590421, 0.056162258129446745, 0.04782945849001408, 0.025161079604238756, 0.03266166452498686, 0.037793208724789085, 0.016925222645964355, 0.017902413758659558, 0.009089555655185495, 0.04521509534829567, 0.01982055044913244, 0.04640703622792517, 0.015794835015830976, 0.03672775662233753, 0.02077044584908553, 0.03692676328242787, 0.03619866948875208, 0.0296116731460056, 0.09217566074503046, 0.003782497360295947, 0.028583117753207207, 0.02122003412354858, 0.05780751621651073, 0.08459218702609501, 0.01341416986824404, 0.05350556096903259, 0.03136777457961392, 0.053416859478719776, 0.01619726100245551, 0.035618005485664454, 0.05645868436042821, 0.04637436257795461, 0.04450446452885386, 0.10198753867899218, 0.06621293333028594, 0.02470585675309262, 0.030632111837246248, 0.031818772455857645, 0.11710946312955312, 0.01651252725071484, 0.06295219116333513, 0.029347135324872313, 0.03688168283852358, 0.020820061533501553, 0.02478484424852556, 0.021920736443491715, 0.02411639231497482, 0.04596849685655006, 0.03675941520580842, 0.04880701732491294, 0.01793225479853009, 0.03944627324780149, 0.032000480850617734, 0.03415659700910892, 0.023784672413321755, 0.08243601724144914, 0.043869542348529064, 0.1385959541244853, 0.05212730750621808, 0.04597077213768517, 0.025107091472994898, 0.05970035476850406, 0.05935303731671265, 0.032127925322481224, 0.028105664945718263, 0.05182603959955516, 0.030266394868733424, 0.006085411286837752, 0.01709431165739173, 0.13977378366454957, 0.11623232309976894, 0.012606068724586118, 0.059429236252101204, 0.07177102379500866, 0.025036115342030124, 0.023478560915757573, 0.02668682031423575, 0.06555406707188775, 0.042696700040851875, 0.05051964901447777, 0.04470191220001829, 0.01686470553038582, 0.052735520031062834, 0.04507624191201983, 0.04459016295450349, 0.02232756552046105, 0.021057267252716328, 0.06699012186858924, 0.023849761158588435, 0.060672183265729304, 0.04903018256769546, 0.0694516696216118, 0.02126011201330731, 0.04848002035531306, 0.008696442424890496, 0.014132870466358239, 0.03489202609465968, 0.015538122782844211, 0.050839919732102466, 0.06795903157082296, 0.021800175271627885, 0.08043381580782515, 0.06475819364911126, 0.04520685224223041, 0.04099967739274425, 0.023754049963768453, 0.031169993660202434, 0.02435532747767866, 0.05917997039373844, 0.02902539563365281, 0.03152817615397996, 0.01485696528106928, 0.052322223256792755, 0.009510662695843606, 0.09780220116578764, 0.008181160195700584, 0.03441714734259633, 0.036041809155816035, 0.01680043649919812, 0.04231829091065353, 0.04779185506425077, 0.02301809993842917, 0.0633441025931989, 0.14545711418313367, 0.11209416894182084, 0.11537912331761853, 0.1262015401716194, 0.12280615422153666, 0.16286335194543486, 0.16987803602410903, 0.13254514655038235, 0.17746943109218152, 0.10351364711119283, 0.14552002532347558, 0.10529198233158359, 0.2898805918953111, 0.25000816691787014, 0.12576975769573642, 0.08837951887999812, 0.17715121349019392, 0.1455607965228058, 0.1405581351249449, 0.16707036974689654, 0.1524100668968693, 0.07187299775860964, 0.2611515286468691, 0.12120457080703591, 0.12092711674349925, 0.15663524098213644, 0.20532035839653787, 0.07926606798484441, 0.14859556190429196, 0.1578525700155766, 0.1863559744050426, 0.2041355114910872, 0.11881582438945772, 0.13817365581710495, 0.09480678972097174, 0.11862449393036867, 0.07298363372683525, 0.1215550330497565, 0.17402232654633062, 0.11160136756276894, 0.12193519652130143, 0.1038357028136811, 0.09309724919618138, 0.15418968914497286, 0.25530692129846544, 0.11161812190567294, 0.13982523412954423, 0.1594610328996374, 0.06686437619669784, 0.13835120435443618, 0.12240890698928027, 0.10169234201912919, 0.1559805728855633, 0.10823919152420376, 0.1889458725288991, 0.12061464480094372, 0.12053561517067495, 0.12907193372807196, 0.10453462014876067, 0.2459297139918612, 0.20743774881045665, 0.10580017441703428, 0.22437321022152903, 0.15766743720779497, 0.13301895660979132, 0.13076823625353076, 0.13800251177482067, 0.07304721902455054, 0.11121089254776317, 0.13635343090901453, 0.12150405755927488, 0.16532008866629294, 0.10832104801891312, 0.13422496286371063, 0.10795642847135183, 0.165714516694988, 0.1483461696414217, 0.12465211202300365, 0.15396651241087145, 0.22403021733607018, 0.10728057038279311, 0.13088803708312974, 0.11683412346868746, 0.08410661751704832, 0.10655464844838267, 0.14171580123084207, 0.17954827196175055, 0.10631136190626891, 0.1854527720640744, 0.09438668242505482, 0.14861811553278279, 0.26090662565923506, 0.09401997911833948, 0.17717745966247975, 0.1524459657770011, 0.2987683456270926, 0.171552857444171, 0.11376686829833255, 0.13448374736453259, 0.10752365774204654, 0.05768428714345059, 0.1255626764689242, 0.09904042141692293, 0.12583696658933355, 0.14336125083988713, 0.10238559796444832, 0.09955451237939059, 0.1018799263082685, 0.15908371927517076, 0.17771750568382202, 0.19070082674584082, 0.1429903417104675, 0.1563446178671814, 0.1546532029826795, 0.15795953121156464, 0.20726815226577944, 0.11180600496910273, 0.10396263592185513, 0.20318560843025485, 0.15890486838836826, 0.18035444160622938, 0.15890600219849618, 0.2455166087395722, 0.19112831912934783, 0.13491960542817272, 0.15278042444298345, 0.1845759691129769, 0.15388198226930636, 0.14246008629279752, 0.10929478407506982, 0.15624513368933432, 0.09071123005161363, 0.23589816034561206, 0.14713970373474783, 0.07990192862287646, 0.1963710878044367, 0.18171139782474888, 0.15278462260480852, 0.0932574688246654, 0.1951833910519077, 0.14581028071622695, 0.13055750078731967, 0.36764611580198814, 0.2761333585987168, 0.25812612485981756, 0.1523705827252519, 0.15497502119791123, 0.11974082193187169, 0.1720171833350774, 0.1365740642312073, 0.1297541656681607, 0.1249607765085755, 0.13942466207569645, 0.14455742052485868, 0.1552437035547149, 0.19037631190111562, 0.09532516311493613, 0.1416609340137051, 0.12875062113087024, 0.11085169690270578, 0.14048448343190456, 0.08869489429578667, 0.13396018755532083, 0.12967095319782534, 0.09850134066636525, 0.2164440010223658, 0.08335487841958962, 0.17956549361828836, 0.23965393703791404, 0.1200544200236759, 0.12440937706419539, 0.08255330530265648, 0.18766377842234028, 0.11211607905645525, 0.12998667335317982, 0.16415013451009028], [0.06095082093510897, 0.029741210953122186, 0.06013273862340759, 0.08221064183500507, 0.02148501819089776, 0.029463611332879915, 0.060593046383151127, 0.04093531451578583, 0.027222497719189814, 0.037704082055678295, 0.03737388666899454, 0.03539260326614303, 0.0441522173012697, 0.08349851990539221, 0.03250930495860596, 0.03513545819347905, 0.07229304376749263, 0.014327115889999175, 0.052423032766748826, 0.051547535995562235, 0.08000856040105706, 0.09221958056572946, 0.04937816268554138, 0.047639422719517065, 0.027859492167349786, 0.07596148643642664, 0.050258704145709356, 0.028472416132928866, 0.07021048737149085, 0.027814992035048145, 0.01257424926265113, 0.007017244248756118, 0.05109042282246294, 0.03621237480171746, 0.09059719020320524, 0.011672907557729031, 0.042638550136959365, 0.038625061466929414, 0.06902790808629605, 0.06921029829930875, 0.03289943140360617, 0.030356147814722314, 0.06179343721258545, 0.05161062716656635, 0.048919360288569046, 0.0466853253272993, 0.044230802600542386, 0.019747308613131606, 0.020986105345429915, 0.038216016480639096, 0.036209272145624125, 0.05999349831272999, 0.03552594469980367, 0.019230063283635725, 0.017027903325675477, 0.014131584396255354, 0.04368068252299582, 0.023439530651235295, 0.029638394292804505, 0.026006541898353927, 0.05744028813956727, 0.026286851554628343, 0.04276874294925121, 0.10328687742472657, 0.0343469507060945, 0.007616875631239026, 0.05643608859710156, 0.055585037691578756, 0.014045682957305784, 0.04705032408838311, 0.03160072659562913, 0.06846079617858895, 0.09866193567793216, 0.0260366759668555, 0.07206124088336384, 0.030515120635109565, 0.06223194211000397, 0.062095229889476494, 0.09022265747790376, 0.06749260659900404, 0.025485385690004598, 0.07353409854394775, 0.020261382338620966, 0.04978519286059084, 0.05263477563858033, 0.02904181672830976, 0.019585916870123437, 0.04079722333699465, 0.06385836592544952, 0.05282255911057996, 0.035276154071212776, 0.010740822744405559, 0.023599043563609163, 0.030493018998494072, 0.0709878980752922, 0.06884279826115217, 0.01739960152565712, 0.047685391825413516, 0.12179941509760196, 0.026388306493660616, 0.08163889509535606, 0.02564572597733669, 0.02627668173743352, 0.017885611535260276, 0.07120550535018406, 0.019480750235098026, 0.04991068572346723, 0.0387232432953052, 0.027827291576672467, 0.046882106501969605, 0.007576701980489757, 0.006444378541932712, 0.026946874605792186, 0.027759437253999136, 0.027132591555616068, 0.03467351483601717, 0.0029016125969769015, 0.030284118312861652, 0.007514312258741308, 0.02333438316840799, 0.073780051072038, 0.03815997714897798, 0.032292666784938306, 0.05049433363901992, 0.06048167635115886, 0.04385733473745566, 0.018812179557919022, 0.052618224308976246, 0.04896841672880035, 0.015931368163306148, 0.04655801300560275, 0.0777437057225935, 0.02019794451283111, 0.044168592430651195, 0.024517611713118614, 0.07146505593893028, 0.031056334940536372, 0.04442664148706583, 0.03067940244481208, 0.02546267309826949, 0.04202569128885385, 0.028500633066399928, 0.04666298620342728, 0.038590365344838756, 0.051508220363288164, 0.027980647057354934, 0.05568686609847411, 0.03623742587684143, 0.02142393991591469, 0.0600490894829554, 0.06730004273835691, 0.02806836795512467, 0.027973388374272375, 0.022223107516765598, 0.0024288530356340833, 0.009430821969985001, 0.01870614149787974, 0.05500354248309328, 0.0447003034153773, 0.06714446560269402, 0.02835246208574503, 0.012813032165380015, 0.05834231453557169, 0.04526801287166534, 0.01722200510783061, 0.07602932352212168, 0.06905759399336192, 0.045861095160005555, 0.05497507848626664, 0.02437630488026527, 0.00940998054800495, 0.022138922114766414, 0.013138809139960477, 0.06751060200434539, 0.04401009266955718, 0.07737341712439254, 0.0978663380468084, 0.040072423721393274, 0.017257329422019182, 0.05015153610598176, 0.03573145161593153, 0.009384731247630573, 0.012701863231467865, 0.009853902644658042, 0.08042731938222725, 0.10514222746414524, 0.03959105237417164, 0.03431248441038113, 0.0348044928884314, 0.033801453969170975, 0.014885950217684431, 0.08380441881355741, 0.034444079163574406, 0.004796863847126764, 0.03916558629322437, 0.062263918619963436, 0.06136804390999098, 0.0681883906344733, 0.030446036741317763, 0.057084356029067314, 0.02882942459696243, 0.07029938421422435, 0.044238294940441854, 0.10883691630536511, 0.009296839895297684, 0.026222004127057812, 0.007070394950137744, 0.008642131579108536, 0.030438768482136152, 0.03889739806313188, 0.0077204665191651835, 0.010801005654127128, 0.05383618153451432, 0.031122067199659445, 0.04660390933314639, 0.050629525175017696, 0.029264832583947048, 0.014718108971963727, 0.04453626100815112, 0.06794707293832494, 0.03424412255445796, 0.021256735480781046, 0.06017951212162453, 0.014630948275988622, 0.06160853423118111, 0.01886720765352009, 0.04367227470802684, 0.05096622847861821, 0.045324703378062096, 0.04674723672290002, 0.07618721424331588, 0.08484535610243198, 0.05945491168888346, 0.0501753997448231, 0.025219698736984885, 0.022471547915389942, 0.022805033649708477, 0.010267450312723317, 0.05201280800505512, 0.042659207697837584, 0.0645222615510706, 0.02808379696591968, 0.09306149587275521, 0.06846583703713072, 0.02778700109751475, 0.058594652406510815, 0.039218503816594044, 0.03856440262508489, 0.044603113670863455, 0.020458341628733664, 0.03125823166732106, 0.03483786367841306, 0.04611514140701583, 0.005175961020042099, 0.03490763130567728, 0.004338356394005279, 0.08657083125604738, 0.058209501702578804, 0.03990782206998237, 0.017118521951018803, 0.030407230557513334, 0.008596585736790252, 0.023611308631276893, 0.042139865202648986, 0.011199950728745712, 0.014534148278706258, 0.01442265950308572, 0.024907544720917944, 0.047408175249133384, 0.028201328260042978, 0.04954258430629008, 0.027594831772148613, 0.020582313807080352, 0.028151691508209033, 0.05163613789444489, 0.03922163711620435, 0.018123432040034283, 0.06364529772150902, 0.01725287079029987, 0.03111562823065587, 0.09423284430898006, 0.07302667254642134, 0.01279512677536977, 0.03529778456375484, 0.05056820366711867, 0.030963705334391807, 0.02183071919716895, 0.01892435206701198, 0.08947665637899792, 0.009368570622867875, 0.06414794716082754, 0.017636703823002118, 0.03388334110739731, 0.0331004758575751, 0.0537150323901686, 0.0576869186554705, 0.0684863988370184, 0.020347297184109207, 0.011860895958248407, 0.13151177054932042, 0.013450183661564464, 0.07392435905433471, 0.02209828881126258, 0.017640773665099856, 0.0641433238202045, 0.021603041696512414, 0.021013357008116382, 0.038360362767332026, 0.040589808861935334, 0.09668007387869781, 0.03992516630058808, 0.02059719698022931, 0.056622255623580954, 0.061235437920737656, 0.06408096809360771, 0.011247299750515772, 0.019156825278074514, 0.017269567676609563, 0.03019722479005014, 0.030374572229301258, 0.0672535258795946, 0.020457468288499984, 0.0568037610050411, 0.013086035258076606, 0.02197155105550924, 0.09815675431802388, 0.014995889580478112, 0.08168151256658378, 0.06068943939622372, 0.06400532074152462, 0.05239846815745677, 0.0536366960694713, 0.016922843942959464, 0.030164673714147463, 0.025223517685287425, 0.04298782494339732, 0.04484481058053432, 0.06002961169748057, 0.03345271925471964, 0.011217271019103787, 0.024425334507419218, 0.06389510750229802, 0.015989779494702816, 0.04370924611125262, 0.055260817790704395, 0.008083438977689273, 0.03878599738762264, 0.03205654124969677, 0.04202517034906534, 0.08518527697531447, 0.05660818258841192, 0.042040492107550946, 0.19328900883274694, 0.15622140028544013, 0.08839115575556794, 0.21106522109720016, 0.07756120059639215, 0.17743774569563328, 0.12830170892900036, 0.17807871614012027, 0.1760571173602535, 0.2066114923406032, 0.13383304760340722, 0.09454356957106821, 0.10688499322221165, 0.22457067704489156, 0.10012825094764272, 0.16506272908901015, 0.17744620330631736, 0.08314425786656719, 0.09822304390611188, 0.2296302587755265, 0.20274280961002075, 0.2339685380819344, 0.20270383105643336, 0.1966437538184466, 0.16623413881226895, 0.10607502378162839, 0.13133995234966278, 0.16233409244206645, 0.12063813305670217, 0.0852069189591754, 0.12170134052153557, 0.1047947989296048, 0.13108614742034866, 0.1590971871008796, 0.14226245093009166, 0.07053340109245432, 0.1164613833891288, 0.1354108976140138, 0.1464188303197584, 0.1434302600401063, 0.10648256723558712, 0.06979616403940224, 0.11743849023215233, 0.16265584937026425, 0.1077430883061982, 0.16254161033899556, 0.14842631776005993, 0.08133737821011774, 0.16281652865150284, 0.11313286159307727, 0.2626727647598713, 0.13143862447431012, 0.10507434441317474, 0.1856792276544917, 0.1405561892616172, 0.16735659551716622, 0.14148784410809317, 0.18539813467331473, 0.07391970890063433, 0.1825842477621571, 0.12193287527489087, 0.1237562181608331, 0.17312329172367052, 0.17807382849916337, 0.14432621518931082, 0.0876144958179324, 0.16548191707941795, 0.16335343371235556, 0.11614171788096429, 0.14487418255979015, 0.1376168631137379, 0.18564064746662495, 0.2945376097434952, 0.13592218469467857, 0.11646519850699172, 0.11147042781475092, 0.10819960010027695, 0.1000322831133681, 0.1339702079853704, 0.16164637531243986, 0.16979712181754653, 0.14596328379646425, 0.16540749929845333, 0.13430734795908775, 0.14547257383744563, 0.10770512098867087, 0.09624173369018302, 0.11855805878557506, 0.17384595778440276, 0.11374934786750425, 0.12406536528179724, 0.10309118026446912, 0.1393674659512697, 0.07336490802587041, 0.16266832128167152, 0.18014534556817624, 0.08743403614648888, 0.1365118885352727, 0.3133104717539203, 0.16350102821184745, 0.15865622689166378, 0.1505155314601237, 0.07473229070103939, 0.17155196878217882, 0.19608994885798425, 0.2202556714896233, 0.08426838464313939, 0.1780416374845851, 0.11466237911654097, 0.1969732941999551, 0.07426906031586471, 0.12332316397899583, 0.13732187329761444, 0.14636477515582116, 0.20564550143336097, 0.12261264041186341, 0.08545045831030415, 0.12774599640960657, 0.12290402961474274, 0.1279280878483288, 0.16613303052802242, 0.09062276987899696, 0.09742234412941242, 0.20235092499323432, 0.14572072503787858, 0.14653291613344224, 0.11996779080119827, 0.14122248657288092, 0.17524704066736085, 0.12341062057643168, 0.1632226625036809, 0.2337713623719831, 0.05199256796209563, 0.3231399926927782, 0.17798586628369747, 0.12436448431183254, 0.21749271410367182, 0.11591351561007962, 0.3109815338205907, 0.09998647105549613, 0.21831924636517802, 0.1491123494962531, 0.15877973558681627, 0.14100750697956932, 0.12165084766644625, 0.11440528767003168, 0.18437013660948123, 0.12810936723385127, 0.15709391314416163, 0.2689732863537727, 0.11903068906958066, 0.1787553096730863, 0.13863454963411057, 0.11492305585453588, 0.09921055422314715, 0.11802434065048734, 0.13361178608911653, 0.15088532210117386, 0.20195292699481213, 0.14968002064814492, 0.08657172757891879, 0.12022491289122451, 0.13045666829472588, 0.0956661182065164, 0.17160174917549859, 0.12467821263858389, 0.12818082791542815, 0.16499034910192414, 0.13418114263444178, 0.13222259289074328, 0.10965934233559717, 0.16444012943294742, 0.09138021633149156, 0.15953007274337355, 0.17885629538326495, 0.23909476946198174], [0.0420100937387155, 0.03668441136758174, 0.03482209375849174, 0.07606786540559224, 0.05833232474903907, 0.051055286199815815, 0.05149089528488056, 0.04803296974709919, 0.02767576704612903, 0.008320614053387075, 0.040348927835903825, 0.02511659287847579, 0.060779971836675564, 0.02452943244979026, 0.02547417590845256, 0.0252503058647797, 0.033733168722040234, 0.028351814741449013, 0.058886413162033406, 0.02044505957934645, 0.03455663280140969, 0.07562675963967078, 0.05584369961833281, 0.06392192441008746, 0.03907309266768637, 0.030866649655264713, 0.03810743500869121, 0.045299870637996544, 0.024846098723731218, 0.023330885977033648, 0.009489053270719465, 0.0294970051054993, 0.01621523917081856, 0.06408237769538838, 0.05735991019455176, 0.060646867890271454, 0.0640910613020101, 0.03971640351078203, 0.02112604854177804, 0.009304693254131463, 0.012564477811176932, 0.08058596853046648, 0.039897613948391336, 0.011443729482350812, 0.048390292307181705, 0.028642148658212636, 0.08284094833558606, 0.06002552078796491, 0.0649507575097584, 0.0078099905963866945, 0.032911010822581674, 0.03116302034487167, 0.02920990599499595, 0.014726412407453022, 0.02101988024679163, 0.01834234166439743, 0.04931097677458198, 0.025990421493207256, 0.03586377415265288, 0.035627723310983954, 0.001549934484853199, 0.021297481782253713, 0.018718232280544696, 0.0726826454422647, 0.06351304413270085, 0.031531845715137265, 0.04800196999924318, 0.07750054941542688, 0.029025880184264916, 0.05257998886067541, 0.04988920844851002, 0.05223397375835527, 0.0840340766514982, 0.07690413464461604, 0.03702447396673022, 0.035905001174298026, 0.013226303084182644, 0.05691653297793481, 0.02213562410625239, 0.04655362332179662, 0.04507709226961579, 0.05575022156981211, 0.025676394392165448, 0.0019500960831552927, 0.013252487011824646, 0.10083827655762435, 0.05175706487329257, 0.007940525754219703, 0.037900664047488285, 0.04084796134021975, 0.015047465492370389, 0.05360208421705231, 0.02947331766688055, 0.03356663269862052, 0.08292120370653369, 0.06835201935422036, 0.0546958202856683, 0.04925839632989899, 0.04690935241899664, 0.044604147889561234, 0.04410603369075445, 0.050101855304092176, 0.03824123992554603, 0.033716180722319314, 0.04410797955408212, 0.060591755524998715, 0.07733770976624182, 0.009424563031643629, 0.0730894687735746, 0.03792504096523889, 0.09120613051157805, 0.009231866063219647, 0.003627606591532728, 0.05473130164788135, 0.023911490608307145, 0.027242624764180472, 0.01148581643769097, 0.03344110536178754, 0.036474740763585416, 0.026949004330221685, 0.068803321750414, 0.04364582169200144, 0.037790266947159847, 0.04220989713024709, 0.02033219759112164, 0.08969082391910976, 0.04659666980226194, 0.027587795254564094, 0.026133137927841277, 0.05095390212391654, 0.07050939189690737, 0.03743560271217458, 0.019154350814079086, 0.09424566862083252, 0.10105647372021791, 0.05545847230560838, 0.006734981547079741, 0.01789234161767508, 0.09543350326918787, 0.020507830908642184, 0.04272300750017167, 0.035525029224734155, 0.0033540399454068397, 0.027699092508203564, 0.04723207078753941, 0.027816600819689133, 0.02197420746538668, 0.021613062126562003, 0.04529762216993878, 0.05772691610599718, 0.10080853702440377, 0.013608197914436461, 0.02918486066553141, 0.06622760391403591, 0.038434114051802505, 0.05188982024969113, 0.02819944559896906, 0.01847074566138608, 0.024612037795445612, 0.050227800158843885, 0.06471742244978106, 0.02239517086455899, 0.027103574060264136, 0.0757128142962052, 0.02765931913839473, 0.015287630226192696, 0.04702118210374348, 0.04441582432557498, 0.059304287311651056, 0.05845535463923889, 0.10706238088107879, 0.020082585077973145, 0.03848684388363073, 0.05559149964322006, 0.07867381307146243, 0.041101605391069766, 0.042130442321180336, 0.04865031404000136, 0.028683195649195584, 0.0236489656831949, 0.03603225986983988, 0.03529508027338213, 0.057959937069925575, 0.046843273505087824, 0.047379768708901066, 0.025608296836576155, 0.07588172136175056, 0.008913512480625463, 0.02470587782051054, 0.03549801696452402, 0.04327492022346105, 0.035976672530054085, 0.07083857987797068, 0.04255449113946769, 0.024957120185717944, 0.020015071664426117, 0.03349219576545781, 0.04076300601985666, 0.009366026253349358, 0.04918793539306329, 0.029118756853765058, 0.009158856926425811, 0.02928889923608832, 0.019486099444029313, 0.03874904130615535, 0.04531460633922008, 0.056616226511616866, 0.06671133481206433, 0.010537768267245303, 0.020251419365165696, 0.03460293898599283, 0.031545700415247874, 0.04454175002812859, 0.02372339304025856, 0.03347032012477998, 0.03829856245448032, 0.02026909684401847, 0.10363668849271152, 0.05128976273080034, 0.03127046609147182, 0.08381788663926625, 0.03594638907440728, 0.04557061760175613, 0.010057189821025297, 0.042464590721553376, 0.012980457808401798, 0.07559737250689538, 0.06176619895643765, 0.02641794835067084, 0.03175765204603874, 0.021374511923040115, 0.008506905569154169, 0.0999542493974009, 0.0489627706607984, 0.02834781576248427, 0.023364174412563447, 0.06193979064963999, 0.060661481017427105, 0.013839624457872443, 0.03907447928682931, 0.05174016497368294, 0.022206165482320135, 0.02677685096709719, 0.03423549640443056, 0.025606569308306903, 0.015098131674852584, 0.05812966767998953, 0.06156783197976409, 0.03639361588284373, 0.03076016534900954, 0.05593207552127781, 0.018610956988507704, 0.018505828657878504, 0.036029681983974673, 0.06961363593056318, 0.01400134178824843, 0.05699498038138113, 0.055809509114272175, 0.03098225423825845, 0.03165088045681196, 0.040667268011959336, 0.04619348538859237, 0.04226070408138537, 0.03449253422478515, 0.033674095682198965, 0.03354830404503211, 0.015658744284132078, 0.07800190799659298, 0.043582148294174866, 0.019474054626639814, 0.0649571466830469, 0.045930870448149023, 0.012934893771495311, 0.06763627106744437, 0.10397645614800916, 0.03157291760397775, 0.08602451863548449, 0.04575306527136315, 0.015380765450367284, 0.062022712006564104, 0.06884913380828596, 0.021042887782377583, 0.047222050357489824, 0.04468460244336917, 0.02837726418229361, 0.05489615227786764, 0.03865060666876455, 0.0579326834920193, 0.005734395545591871, 0.006119240771964073, 0.006159624139282612, 0.04161144073511805, 0.00969639209459626, 0.0625902146191126, 0.020003160912423365, 0.04077700627667289, 0.0737680234916268, 0.02853530237541324, 0.018756596048572854, 0.0474375470601503, 0.06282855989411473, 0.06307614035904408, 0.051274701442208984, 0.03958841320127249, 0.05378103086484536, 0.08483145926748553, 0.09993794704637221, 0.09017597974067734, 0.017876240364726514, 0.03014693303304094, 0.053096083143065055, 0.005876726542238988, 0.028535043820738796, 0.06112578392569577, 0.018214334117909594, 0.027786014759312236, 0.03748299291117057, 0.048541970055309996, 0.045010419637565656, 0.039413090149361285, 0.016943223796965137, 0.01438049881178285, 0.05409906077529154, 0.043098520818016225, 0.07282739009467826, 0.08572720757295048, 0.022815115366792007, 0.04664638507810812, 0.017174691517627048, 0.03645859546058121, 0.07443538566510524, 0.05253632567943104, 0.029148304865004557, 0.03244833202071248, 0.029627293678781683, 0.022537046517696113, 0.030646050807028532, 0.007779148854165068, 0.011210802364193145, 0.07823332783675964, 0.046773138155619946, 0.031513702837870486, 0.08619783070659445, 0.04382843407051217, 0.07971759254653608, 0.04662851224683466, 0.09259818121790887, 0.04801903460775653, 0.10816772318174762, 0.0257410311455568, 0.028692245062801148, 0.05459702941739271, 0.16525762185694712, 0.12231014293408203, 0.06520790258242239, 0.2636400273730678, 0.19545507647337454, 0.16548000185960726, 0.1370653257735314, 0.12012198897859744, 0.12089257383899343, 0.06615604364102887, 0.17656756174420157, 0.23112313431357187, 0.09222665155727057, 0.18708335956738842, 0.09687272200901663, 0.10647316733675619, 0.11438555324510222, 0.12284451224390538, 0.13563623471606162, 0.09031394451496103, 0.1742789506792061, 0.19297468295741468, 0.09760346263647081, 0.10657390023791984, 0.1946362357346281, 0.09853656538912366, 0.13635799679304325, 0.1348871386219417, 0.17684546779961358, 0.0749343004257929, 0.1371673227197701, 0.1485881768167019, 0.18319555528221593, 0.21668727990360032, 0.14537906514540797, 0.12174124604151135, 0.14998219636899812, 0.17593325626465584, 0.1160760718067327, 0.06018785098868032, 0.14846620029739796, 0.226154487219549, 0.1869163523998953, 0.16180210566568762, 0.16538525210513225, 0.14500605693507582, 0.1155497847245105, 0.1346143653556224, 0.1335942426756505, 0.04407435595508545, 0.19062187372436448, 0.13299220481947546, 0.09204291302951113, 0.08657121430000952, 0.10038474484557107, 0.08177769490547719, 0.10363609860500983, 0.11300526964928835, 0.08679539460929171, 0.0955955308651732, 0.14917883060632214, 0.20010340688449724, 0.08746256526078909, 0.17088213214470496, 0.2370673790574074, 0.23607327272334408, 0.1323367399914611, 0.1806634967966426, 0.16372759105457416, 0.1020342164162186, 0.15216568484902382, 0.12957660180907096, 0.14104073987372462, 0.1766364483703529, 0.07967715076501332, 0.09261024710271629, 0.15260377988940285, 0.12830076664085352, 0.13405009563411438, 0.11332169460553317, 0.2343079763194246, 0.12580417802617436, 0.17512051358578667, 0.0747163484113351, 0.1561333614611818, 0.1586108591647879, 0.21924077352929502, 0.11768340088066556, 0.12365183102027064, 0.17016498191702753, 0.07886089174257171, 0.13719254233423742, 0.1193267360870396, 0.08412208483223954, 0.11507847211173466, 0.11912342401281481, 0.13563867087566084, 0.11121047119940482, 0.17761445153624783, 0.16732474158127464, 0.0943173821114244, 0.13367057567642582, 0.11377615328397482, 0.2278628326471775, 0.15964222801548822, 0.16214938864352244, 0.1437893101284581, 0.15214742131290898, 0.16545449113172872, 0.09431787240769594, 0.16755542597703396, 0.09329448619316663, 0.041359830647706985, 0.11537651095779673, 0.08538282040746943, 0.11881095973113853, 0.22381410393263065, 0.09562760696656282, 0.14801509708406466, 0.11705923840523728, 0.25740302978984775, 0.1454033194890907, 0.0657741028454996, 0.12188970622035766, 0.09519479027198208, 0.15346863186888157, 0.08846959549813502, 0.15672634415809186, 0.130078557938818, 0.14503818666262014, 0.1875561430689789, 0.14325476461841216, 0.10716348916532532, 0.16389461354382578, 0.1891173230063531, 0.10689264644057521, 0.09833580438768673, 0.12293357762598223, 0.16110444471480387, 0.20549602235757536, 0.20821914317146425, 0.11462108697742225, 0.11830564047540389, 0.13995609726876984, 0.1474297752663974, 0.11006290979322889, 0.16034137517694505, 0.11625529041573887, 0.16556217245036559, 0.1443722264300431, 0.1442256278448528, 0.17499723471701148, 0.06752639107646481, 0.16289094643246743, 0.18076330273141786, 0.16387696287805037, 0.13330780240076204, 0.14956783473251328, 0.1088264285616817, 0.16125033849910383, 0.11539948593464591, 0.12061554112381513, 0.056272800786480795, 0.17507909887260006, 0.1487564250466324, 0.12823770994380598, 0.19677697650847897, 0.17901135157913933, 0.17531804169618315, 0.0939043841114448, 0.24442890178292032, 0.18662450354426138, 0.19379956046900443, 0.14384367172756504, 0.25313861668109894, 0.15225340191635395], [0.04625287252448259, 0.026679829761926687, 0.029463015699518785, 0.013649558043858458, 0.0432161919231857, 0.005472968520236112, 0.032597355274183136, 0.02913014475075949, 0.00890255550808844, 0.01409598429041404, 0.05057943834652824, 0.03968698190405004, 0.033757821431443576, 0.05861612585102839, 0.05990690356420894, 0.049994193137653416, 0.022732268703440507, 0.04743398092086277, 0.018815387551101948, 0.028458143914899522, 0.036405111032147566, 0.035244108613340125, 0.08156147424972827, 0.03570718578092995, 0.04522019366343175, 0.02105470085816999, 0.05871703878285424, 0.07452757668591316, 0.03576513267152252, 0.03269852867590324, 0.03412793382942196, 0.048057825469802466, 0.043070324951963085, 0.03215148827181228, 0.05539144344267346, 0.05945406516172713, 0.023313455561536457, 0.005895153829647649, 0.06277190386167457, 0.018587148891040878, 0.01761650016921903, 0.024380669666213856, 0.027208037809619022, 0.045962494557663325, 0.030448547594489592, 0.03985129244204971, 0.056082860776974316, 0.08853937078627849, 0.03362029332727675, 0.08871561697413845, 0.01270750355381038, 0.0137396605174628, 0.03367072872577175, 0.008959040128355546, 0.04811557317753473, 0.06076843838297552, 0.051606865674858136, 0.02625629996820804, 0.00844473083082947, 0.020059422409582525, 0.004910135692391064, 0.041937556703605, 0.049116053363128055, 0.0439722785696147, 0.03417249333353774, 0.05277986503055981, 0.0198885886329076, 0.017087627540252382, 0.06906890911200354, 0.050740412571617675, 0.0521765286553531, 0.04824873841097278, 0.02958170761684737, 0.04008972581716315, 0.019937821273361484, 0.07346943306225924, 0.012815017290713807, 0.045983998645697875, 0.014155019983468999, 0.043684329101515394, 0.07691072300076485, 0.04748101871941359, 0.046144095700114005, 0.0422939446364199, 0.005859649484796871, 0.03223897551276511, 0.030120786452185244, 0.03703265195532191, 0.05463625311911587, 0.05000180039074152, 0.019040067732754736, 0.020056442327557072, 0.03843857651396144, 0.02136144820871132, 0.027019118612271645, 0.05505809177374167, 0.045087258256370985, 0.0717382045883325, 0.06377835570263767, 0.011758971790362512, 0.03445023084960638, 0.06685224902485648, 0.06798342381033205, 0.012968974150416833, 0.06509866610529923, 0.017504793058540073, 0.02983825897137004, 0.033796076031942526, 0.0424717000174907, 0.04136743023991585, 0.0829710683695251, 0.10025176730367447, 0.04586658801042265, 0.04433220199820015, 0.018229441371776404, 0.025404582566191113, 0.03358421824692238, 0.05042677234497763, 0.0603743014676917, 0.03998728070948874, 0.07893567724573998, 0.015665044399699377, 0.07034099811027128, 0.08898911802398582, 0.04646204900176776, 0.03804748862861626, 0.038052525656718406, 0.0504531832261672, 0.05572885537760393, 0.03934537563773413, 0.006050394365428797, 0.03464885063529496, 0.043216249379780025, 0.048714684577839035, 0.029876078816971956, 0.024971650958421732, 0.026884237341883204, 0.04403186871880486, 0.05420750818185268, 0.020462608738471905, 0.07251923888801567, 0.055605093873436415, 0.07169198650386065, 0.01313298974456566, 0.006145802476713735, 0.025677405628225496, 0.022413679548809608, 0.01971973136307732, 0.05910409704571771, 0.015066117818106808, 0.034884579720035676, 0.02887265302330977, 0.015275495393472093, 0.01330573395300176, 0.07799274558501859, 0.02802843370685174, 0.043960116923816746, 0.0156205021325619, 0.13897395722808378, 0.012599029334171886, 0.02812977181747556, 0.055517687071715636, 0.029368855832745473, 0.012919985700488813, 0.0362915768017692, 0.023609401072345437, 0.04879188325796877, 0.009153724137333133, 0.061330972915335055, 0.08545526934246864, 0.03723411392720957, 0.058616183307622714, 0.11363215173684782, 0.04534922585251831, 0.030935836970926296, 0.00366300416287906, 0.04158266264224245, 0.03564519394609717, 0.07979836885727222, 0.024447277180790424, 0.04117253364153928, 0.04988284225785925, 0.04577167737748354, 0.0287308405724264, 0.02390694004603692, 0.05050095646912533, 0.07672880010138597, 0.020482984762037956, 0.035800686812088374, 0.031511979140040856, 0.11055955693366067, 0.05471512953179979, 0.022113913174478278, 0.03422018230682419, 0.04274134764507894, 0.02031471737990937, 0.026772932427364494, 0.008887418568314565, 0.05905074668267082, 0.0822291351974972, 0.012281249359911008, 0.020529605042670044, 0.03268361677445712, 0.03149595832632434, 0.03543276925601306, 0.018426270426941976, 0.03439256741154579, 0.011328057866663703, 0.04790449297175773, 0.02159830918836017, 0.09861196376263134, 0.03625766975024054, 0.003645501687236491, 0.03891008447915797, 0.0647048662687021, 0.014544412899281711, 0.0195381244749672, 0.04665400382251509, 0.047059321791053786, 0.08416894643056778, 0.05199003604150588, 0.02041618955591994, 0.07670931848547152, 0.07745630017692044, 0.04803166739762791, 0.029580541247982654, 0.05016753585228036, 0.039139156259836695, 0.04542450165195812, 0.03621214114490055, 0.046338371767271916, 0.06398484321130861, 0.03840691793049055, 0.011880271279463365, 0.06410957381670034, 0.027031513914886503, 0.05893407532224252, 0.047248537847471815, 0.0911914982322243, 0.14089297683488938, 0.04992557081183599, 0.05696891040931787, 0.011510250812035897, 0.020517801542976694, 0.047319098375737674, 0.0075415059860285015, 0.04878775021361728, 0.03232588435733511, 0.011225752570035477, 0.03226076688377127, 0.05581882857387105, 0.02307872430631711, 0.06051930275955989, 0.03203124311121722, 0.031360265002736164, 0.012647063047024272, 0.12476745422088331, 0.018963614073131355, 0.11315169203425608, 0.022104528597405842, 0.020752844979025183, 0.06083090136188173, 0.10528714065590214, 0.011224034617865279, 0.07571250020015625, 0.035263839207829974, 0.04189902631145331, 0.009220225357210204, 0.0317858689795098, 0.09053191951205654, 0.08655804524859113, 0.010119466065999963, 0.05855834366933954, 0.01068689111214612, 0.05425772141484965, 0.03281587802414452, 0.0328145488615959, 0.02460293475568535, 0.04584889904025101, 0.007126832168714534, 0.03097026496224346, 0.06345610847816834, 0.08334082836705832, 0.04193130925658249, 0.05917170813547508, 0.04483323499199845, 0.07738466329512096, 0.014379805502211376, 0.0498975090111696, 0.018871379002267798, 0.0352792720490646, 0.017416664218950658, 0.046879926981825026, 0.013632253075258867, 0.0639771478581092, 0.03130910565115271, 0.08230069547050423, 0.029021503906997464, 0.05604238835193458, 0.0729563839793686, 0.035386780997918504, 0.048325324220763105, 0.024754436303591056, 0.0069853342926850725, 0.06882337793227165, 0.04944814098698478, 0.025095603984570312, 0.019533278968846126, 0.021012853305306167, 0.04383031481636628, 0.03558745006880453, 0.0286214164037618, 0.07327210413472307, 0.04004346942829509, 0.044113545182852015, 0.03414926554767355, 0.030932424049223625, 0.07537138423011189, 0.04436556129686294, 0.03919414222060193, 0.02398998589224873, 0.052930244259656443, 0.025164073092802882, 0.05404137435459322, 0.0585192846765201, 0.030528854676372105, 0.025652479042389223, 0.014793811865421313, 0.03685051072088461, 0.013410276226368884, 0.05821451957848284, 0.04205336238467886, 0.044492187969867265, 0.028523274795002038, 0.07058908802367027, 0.019129385923846595, 0.013901151851901125, 0.017472646094017455, 0.06692859734739028, 0.09984944090848008, 0.04846290212064501, 0.038679446048674085, 0.029729426605626944, 0.03538447890370604, 0.03457780364119718, 0.045994543845975594, 0.09063020859274173, 0.05787166841928998, 0.04195596196598584, 0.05901335010064706, 0.04146470425410136, 0.024293975326262658, 0.11724036457317492, 0.1352194369199776, 0.20374629286027726, 0.14137898301405294, 0.11864965225780204, 0.08921941937578302, 0.1402356121088228, 0.1937913020411807, 0.10525574637276512, 0.17675617259115944, 0.12181781652954318, 0.1789022453369633, 0.05733837929343986, 0.09713949680688883, 0.3549135506393448, 0.13163639773284236, 0.06390068079194715, 0.13295092800211522, 0.09537647568410444, 0.10853583609024364, 0.1360619497755843, 0.11468556093712969, 0.20266690561848305, 0.1628848177290732, 0.10295332274249486, 0.10493481681952554, 0.1366285943696576, 0.12253330434642493, 0.19420302833520597, 0.14556857997611647, 0.14225774715023656, 0.15869543527162847, 0.17111178998264576, 0.11524416160799804, 0.204036149887308, 0.12168882264485284, 0.11884043879446485, 0.09125470814685668, 0.13227525377465835, 0.12862093776704805, 0.09811897852247763, 0.17885267944826236, 0.09624767087159619, 0.18200084116430054, 0.08020544499759713, 0.23174640812700797, 0.1792138745828021, 0.2102334334725334, 0.10740572616698281, 0.21161629878465207, 0.12825173701369955, 0.19726817676376915, 0.08591277705084893, 0.12512644302220116, 0.16334208028931774, 0.2551685658193404, 0.19805188471030807, 0.1272066705109131, 0.13805448317960387, 0.1250959527228148, 0.13873498376098373, 0.12463246186774586, 0.20460918365466982, 0.25857747322128666, 0.1274711393841332, 0.1159114012074086, 0.12800789888828032, 0.09441755576840333, 0.2338635687145495, 0.1585241839770348, 0.18581769038592616, 0.10068904262997451, 0.1800128276790342, 0.1467671092118948, 0.12276257147952435, 0.17129960409816236, 0.20348747771593834, 0.1370621235260079, 0.0875525346266166, 0.14361419775072606, 0.21248936322667908, 0.14203637838363647, 0.2591429380399566, 0.11617770103076774, 0.04717437670596185, 0.2067405168688105, 0.11656472865011423, 0.11821755568587011, 0.29588384073107477, 0.13529912538586125, 0.1540694133408608, 0.07668315658285733, 0.17774103990485593, 0.16005324950862318, 0.1409355560017209, 0.13726977931876339, 0.121063664255123, 0.13642604072247783, 0.1850980427116156, 0.10112051100980851, 0.17239000768430773, 0.14059769590535473, 0.21410256053411195, 0.09834419305045759, 0.12150978023606925, 0.15102805960322582, 0.18943111262013837, 0.15173889726640719, 0.16295741222077803, 0.13916436072078445, 0.2544324012893823, 0.1593202565826716, 0.1380807599954067, 0.14584913669574648, 0.08128870864428821, 0.09426672071699174, 0.29465123590442444, 0.20070172155336027, 0.180124324115534, 0.1315971740311192, 0.2616514776262545, 0.1302214486584548, 0.1856670008912202, 0.14586841146792137, 0.12983707170332634, 0.11764567871127399, 0.16829341379625185, 0.13155099425104358, 0.16667358216739472, 0.1418376704978366, 0.16540342371069616, 0.12223449941243857, 0.06964724420780136, 0.18776127077158422, 0.11218750909451516, 0.12450151445884859, 0.20091359082969928, 0.12276287025381481, 0.11414287191244865, 0.0544409275115017, 0.2817637677634916, 0.09785019657424382, 0.14648549529092927, 0.09915038567757416, 0.13784932483348156, 0.17443655028698907, 0.1277800260352031, 0.1592637039721012, 0.14995181332192115, 0.10957468195908493, 0.13072573369549167, 0.16160776448105613, 0.17334565640457217, 0.07425257410373419, 0.18842036685635968, 0.10684449015365494, 0.14259510162857272, 0.07880355006143933, 0.1711300688405191, 0.1398935232071146, 0.07176052072956678, 0.21227154910804766, 0.22235980858245205, 0.17152380739008227, 0.16799485401040123, 0.14545999467372894, 0.20467439305878457, 0.14907191537560957, 0.22508671387068688, 0.12717233445014686, 0.09997211456779512, 0.1440751681765241, 0.1598860584800282, 0.14203536714757645, 0.11469541282783594, 0.1350200089115289], [0.031356708439547694, 0.04124112149340011, 0.016867699018949946, 0.016803445309520732, 0.03403648208346098, 0.07500611350781496, 0.07750284001832047, 0.02224149745738795, 0.03983914228757063, 0.010608570113207304, 0.05398603599338282, 0.04772353151272382, 0.014826451041435283, 0.04724715122832887, 0.02129910971909281, 0.027542260903564673, 0.08558010336973014, 0.1133225602848876, 0.06992743320522771, 0.03088785879944842, 0.04411463685814412, 0.06748748913166985, 0.046717347802534226, 0.04029987905655177, 0.04118223997553991, 0.03059786387659129, 0.050252763133856564, 0.02122560166753829, 0.02387017931699032, 0.029290301176989754, 0.02301877218058273, 0.05547559820115567, 0.05426368540934017, 0.05645087409404017, 0.010796110352290975, 0.012515842719303985, 0.06317077903077006, 0.032959144126864216, 0.05545408645224187, 0.08799341056616077, 0.034837721952147065, 0.04651178342981204, 0.03305665945874588, 0.02652318393360944, 0.041694603409738316, 0.05416719663527705, 0.020240491120925835, 0.03164260479200992, 0.020476731569356015, 0.029605349090190667, 0.0500613407442166, 0.02971141587852711, 0.03834182343956444, 0.019722234555369905, 0.028492767258637378, 0.059419713779202396, 0.04819878181743045, 0.007511928288881938, 0.012434944792109872, 0.06567403644083009, 0.03821454559182448, 0.027574683659740036, 0.03363166207207307, 0.06135913813787122, 0.051247390407708385, 0.008033866385718989, 0.0065452593938267285, 0.009878842637032993, 0.046690151681222265, 0.028554762923909772, 0.014678632461225555, 0.04023405295165797, 0.02797558513139525, 0.029126467528722944, 0.02545528801067943, 0.0365837857187275, 0.03013178747477791, 0.04142952549661841, 0.029741580590545654, 0.02258917305528397, 0.017984028935672778, 0.044728886155832204, 0.0444757477230122, 0.07465725238885611, 0.0635489008779968, 0.05486254783106908, 0.09847939224733461, 0.024549875506049684, 0.072000635667674, 0.1047790864662778, 0.03906090037837144, 0.046217598006009095, 0.024278971494265625, 0.04234398933007352, 0.060152354304708784, 0.058008135491681684, 0.0539288858342315, 0.05119723846174536, 0.026292051376414396, 0.04714752532421582, 0.036490054861191785, 0.054404300847841855, 0.042834258788535674, 0.05899659575774305, 0.029589205702406265, 0.023162683712378628, 0.04100419348105788, 0.012282610123586512, 0.02868392534794346, 0.06805237938439654, 0.007553299909622799, 0.02146993200444887, 0.037344062866102305, 0.052640812411423654, 0.06999295670539141, 0.03657636232674122, 0.016613244830119996, 0.02754366859012554, 0.03885506787487576, 0.012214016526066249, 0.012453048407370526, 0.027569966473346277, 0.06028658440036159, 0.03747709786459323, 0.013806008519755017, 0.04312017812363563, 0.042338182383607474, 0.036667273980715585, 0.049806271769827416, 0.008423662455301852, 0.06679102327794799, 0.07074304871381291, 0.037758872664022836, 0.02990750565884575, 0.06261354199640694, 0.07122526275775126, 0.06437274417088878, 0.018465013408492652, 0.030958312075404875, 0.023010435228746746, 0.020652380208635045, 0.03644630357983612, 0.03876620167565923, 0.02321805654754562, 0.034141091389521476, 0.06745640128370255, 0.06430034120116504, 0.019963144309698574, 0.058589795409070874, 0.04868730842586487, 0.02058257619219442, 0.052671245254215696, 0.08037791437199039, 0.03421029594216136, 0.04715369999288552, 0.009635670050497978, 0.02138973600531538, 0.025279218023042047, 0.013105260234536424, 0.00650285211797323, 0.040423843574019215, 0.02873419795275456, 0.02313906522167306, 0.06260191661215599, 0.08496229176319416, 0.04439508249502509, 0.08813818586209128, 0.03631560131907463, 0.032935579262313344, 0.029330915328295484, 0.00929128767306646, 0.09167077049853341, 0.018978338283036026, 0.06216656033610625, 0.023205500366466663, 0.03411244736203263, 0.04835178489766775, 0.0106948699178775, 0.07492238775857034, 0.05157886133078606, 0.04171156076594226, 0.005323087727095211, 0.0731812078025072, 0.034082240515178254, 0.030111890256164536, 0.04307879788440563, 0.03522334763059213, 0.02821018423644766, 0.03676287409278654, 0.04595732729461405, 0.018794620822694515, 0.023533883955209486, 0.11200275933069569, 0.05364043840898141, 0.10041398642164084, 0.03453467289106019, 0.06409767647123625, 0.058598850568335865, 0.056552281152577176, 0.03184581535958475, 0.028053444562359687, 0.08045892816998305, 0.032736928833107796, 0.02173047467705704, 0.03734045459197895, 0.034801037831892895, 0.05344831887933035, 0.07015211913253992, 0.061261791345332904, 0.02696480680887978, 0.02413400659157384, 0.03188875075730105, 0.07422059759377472, 0.05222921635234549, 0.03567002668616272, 0.10262822567094719, 0.08536384440958501, 0.054854553703579216, 0.04303909537772979, 0.04675330413926033, 0.030948680434976856, 0.003976791143237103, 0.029612387522994995, 0.03796986476968854, 0.041704470622203046, 0.0369921833607218, 0.06685965709508428, 0.03440456434844002, 0.07054633265661617, 0.03855427877316552, 0.01994182025232623, 0.04749611831240116, 0.03271360528625308, 0.015559099227820915, 0.018347439979533517, 0.03238824774481116, 0.06548243019008829, 0.05582546672573494, 0.013891129506631725, 0.03660253572067426, 0.04855076857512036, 0.02896301500919846, 0.034233083227469076, 0.03544470873631297, 0.04573893094916017, 0.018282740023888407, 0.10543529439957873, 0.010564868627566724, 0.033500752967572024, 0.010542645374493254, 0.06392210827118928, 0.05027512140992669, 0.03451838203135037, 0.07197948398008462, 0.055713568093074914, 0.025052205103659825, 0.03383617307389936, 0.02478252683255461, 0.02525833829666578, 0.057045185953498855, 0.0426949150559883, 0.06233484303999332, 0.060492003216378154, 0.023480958770960573, 0.10075675714160166, 0.006806976574983809, 0.040497100731778535, 0.04050070900590189, 0.03665329670653709, 0.04887678878261678, 0.07455715534066962, 0.03587400525688164, 0.020353753390091083, 0.038246771080359336, 0.008774675323718019, 0.058905852643112024, 0.053218358436659466, 0.04754106086047907, 0.015596471869597032, 0.04097331247683014, 0.03573811275043315, 0.07553241591179564, 0.030537927072615396, 0.011219942750739715, 0.033592204713533004, 0.14150662858399654, 0.020211270612273968, 0.005712452393415715, 0.040044756456007885, 0.0724046091519056, 0.010097706296120681, 0.05421333811095646, 0.039690678278284694, 0.0401842687278986, 0.017194642362395124, 0.04379222875521068, 0.03851911533744105, 0.10639514894254747, 0.030352552947137627, 0.04014007694598648, 0.03344435357458649, 0.0298133036572366, 0.01854648494402007, 0.06627952169266439, 0.022211135477728905, 0.07205661371230118, 0.011565390947995888, 0.02929293268900966, 0.01997812707427769, 0.06146135724960797, 0.06998857468246453, 0.05122939500236704, 0.06440789228485477, 0.058864269390582084, 0.02005586201595443, 0.047958636235806255, 0.05682896146731031, 0.02799495183412106, 0.0239837518517649, 0.04009338388700159, 0.03118866896857658, 0.04084799964461596, 0.07789769705625312, 0.06518813751397595, 0.03159040547606926, 0.02617165874389391, 0.04536391941890602, 0.017378310027021556, 0.0399785204940746, 0.01709758285282841, 0.024617431054432547, 0.04166764860612251, 0.03590593580156565, 0.011707906284549785, 0.07538542662176394, 0.029595723195422082, 0.02610366652539421, 0.049877916312506126, 0.025771984928137353, 0.06673274696954797, 0.030545444310372396, 0.03720658455765055, 0.07080399100818942, 0.019981765991918022, 0.062364548099257296, 0.04938590400401623, 0.0365014580799447, 0.010474741256104843, 0.02161966771968911, 0.020193014737038363, 0.03901897621671519, 0.029305471633110317, 0.13104179092953283, 0.09230227975715553, 0.21384970555382393, 0.11154373476822531, 0.09987584795923003, 0.13649190896220748, 0.20458293748238396, 0.19680968846284574, 0.14195607704741342, 0.07533741589154928, 0.09331824257969858, 0.12908874169713067, 0.1283003223098574, 0.2622877596126449, 0.17456497726661546, 0.19739510221106393, 0.18428864017609628, 0.17028282156154034, 0.2054597863987569, 0.13092122401200956, 0.12361315124097372, 0.1327799831426913, 0.09247112553566696, 0.14787182332046572, 0.14064683278481807, 0.13014914528016122, 0.13995065804450743, 0.10597796810250129, 0.1267900948803271, 0.12575401458889246, 0.09291131199607927, 0.17335172382093247, 0.1582204147932991, 0.10234594525348756, 0.12042277808030767, 0.11723965211140534, 0.2195658399573257, 0.10392754143404384, 0.15171038347386545, 0.2716575358663836, 0.1556573603903094, 0.16444222851385995, 0.11262736613712004, 0.11386822939159409, 0.0952243612658593, 0.11412347456620586, 0.1782676640657648, 0.13057554981881572, 0.12879457925596546, 0.14257326812273072, 0.1846125268287236, 0.12734235234318242, 0.1481508018989717, 0.10838592034434119, 0.09688892476861516, 0.1375970674017745, 0.11393563746805153, 0.10583054214235275, 0.11763266287744047, 0.15028207382607847, 0.18230405876473074, 0.09666534966879314, 0.1789361064232165, 0.21543014494161453, 0.14144287474693792, 0.13866327793127106, 0.15409567483490513, 0.17352760228658878, 0.12483262532060185, 0.1070790279716734, 0.19230541322500477, 0.11582160038092446, 0.16947472137549233, 0.12689286557536933, 0.13425942149854478, 0.1629003846356946, 0.12244868993518815, 0.14863743627023313, 0.2089099093310295, 0.11219575220058042, 0.10773112201282095, 0.0819059303631225, 0.12368399905221117, 0.23964534153140363, 0.20732455165876498, 0.21079309134473725, 0.12286499743500065, 0.14824241069295716, 0.20628530742420306, 0.2098062628459546, 0.10605692878485688, 0.12599866476751145, 0.13037716368994406, 0.18577483542744191, 0.18395479438045334, 0.2232897933572531, 0.14992855489253998, 0.11382588771201911, 0.12563914736552587, 0.20838092561931382, 0.1091377666941093, 0.1086980322255723, 0.1712255693611599, 0.20782488368211255, 0.13112291964071413, 0.14072097477412995, 0.22588545246230018, 0.16639618173001275, 0.10877691629913547, 0.18948709832564478, 0.09642214739635106, 0.16362462883755086, 0.20579939317559043, 0.18170888505635724, 0.166865992810457, 0.18278554502514102, 0.11518125046765613, 0.08165773319741411, 0.12257968330936087, 0.11049853803049173, 0.15751981206478613, 0.19215201177904684, 0.18543057083602876, 0.12629888696415772, 0.139830274988086, 0.08201163517491472, 0.21808543633068764, 0.08742098966913839, 0.1537005113618028, 0.12456735205506125, 0.14526868719727765, 0.0985086338234044, 0.16952600330114367, 0.11488937862938452, 0.16129057343688705, 0.1793078888928698, 0.14581251769296585, 0.08016108850678129, 0.07718125162946601, 0.11332421503480404, 0.10480501088163546, 0.12330048011555789, 0.23581390599569968, 0.15005655286292877, 0.13799371708544994, 0.11424884485501437, 0.11472721313757282, 0.19996964793291785, 0.16422023155516194, 0.12627683895369693, 0.13601085171103477, 0.07132838585323865, 0.21945653453228936, 0.12265963224513877, 0.1689598490033419, 0.14757514811090885, 0.06191789202632443, 0.1282959326260513, 0.13986870195836792, 0.1894492689039438, 0.11724116896549541, 0.15800891323916375, 0.12627118522481573, 0.16933129439430852, 0.13955828313144947, 0.16772702967207279, 0.2510191271862676, 0.151932334467288, 0.1610336122253249, 0.12711586610924813, 0.15399948483513248, 0.15976970504608848, 0.12302364658323989, 0.21076091565191749, 0.11414786680571495, 0.12807755926323514], [0.05600483855232597, 0.04638202345719741, 0.02743621326742634, 0.032672627243183316, 0.029729014833367644, 0.06152524898249296, 0.0312845123135635, 0.01916733025873621, 0.03696566905766245, 0.044341529118678266, 0.06323085947623176, 0.014736057454419714, 0.06138111720041883, 0.033231913562743895, 0.05192975641318387, 0.10130552124352225, 0.009472779647987938, 0.03672946499840867, 0.031048457641454957, 0.014914914086881666, 0.0667471953877999, 0.04487239357624804, 0.031421184314474944, 0.014800963296194472, 0.014527516830111704, 0.05612058677680551, 0.11159833385458878, 0.06277462730424539, 0.027483421520540313, 0.042406662983158906, 0.053518262706817164, 0.04393526503155309, 0.10527720449552422, 0.025016582015180783, 0.06293196644213411, 0.05955776665359736, 0.01354052458003524, 0.036806774761287436, 0.02638094438870828, 0.035806279253935626, 0.027310881283014055, 0.022023602899524476, 0.03764239665601523, 0.023127081691317504, 0.007081289678030918, 0.07366260213236656, 0.03712171350695914, 0.07915073344784399, 0.02676439437744839, 0.04632067513622103, 0.06377244533430185, 0.05256528763340847, 0.05447852710682539, 0.02558142438741221, 0.07604217081661187, 0.026536096345573187, 0.04403962918947782, 0.028154625624959028, 0.01853813650086522, 0.01347921743628479, 0.01826342886253711, 0.07175177966635074, 0.019215559324009285, 0.036768282673531966, 0.09939574065708345, 0.03842636890288803, 0.040459642862720836, 0.04640885185630572, 0.020030969904074748, 0.017908331787874623, 0.04798554890458623, 0.05340377852741269, 0.10038381787918269, 0.042039779645781365, 0.012995520054603056, 0.044522318207929214, 0.042091287567370364, 0.0326637291319428, 0.00587451302694277, 0.03620507781423869, 0.025060651223025015, 0.05394496218932252, 0.05565114341856492, 0.023540857270540252, 0.021139343997703928, 0.08419558330769501, 0.13613578532972645, 0.019254269746823177, 0.10948103537122089, 0.027441355632618073, 0.03604481605091884, 0.05964072248447807, 0.03901881533825109, 0.04637315598947387, 0.07841173439256607, 0.0422559849797718, 0.04772757645696402, 0.04436263484099219, 0.04250464562867438, 0.029522619255247618, 0.022954786601927013, 0.014936625018655775, 0.03690399131887863, 0.01990527019745881, 0.036139014222088366, 0.031496236033196894, 0.028291039071196032, 0.056126596736571485, 0.04023772251281527, 0.03682304263835953, 0.0344506100631289, 0.037090277088986295, 0.06557844398963837, 0.0347836974317268, 0.012123424713800271, 0.05406255668569958, 0.14862303381725667, 0.04293153280272119, 0.06464970027727467, 0.06874840856800157, 0.06572441438273077, 0.015345776299645585, 0.034803611887318474, 0.0719678471045148, 0.07377926966235523, 0.0837170618075517, 0.056203481320652275, 0.07420657052388115, 0.028388918294841727, 0.013747750405943202, 0.057479213066999955, 0.05058396975660036, 0.019958197296927535, 0.024922743905335668, 0.03272591631919627, 0.05119654132173427, 0.03480641576912134, 0.04645587050265843, 0.038556638323972305, 0.005160309843749049, 0.007031643828902875, 0.016128274784874053, 0.04282658641797401, 0.015047717343775496, 0.04328895878467349, 0.06201656415097176, 0.03216526636313046, 0.049722362159480976, 0.05326733826809833, 0.07915617267210638, 0.03946261007278677, 0.029744129748113697, 0.051885254365662416, 0.09807294429910761, 0.03564882903329788, 0.03793559382639585, 0.04171983068508487, 0.05128762917593122, 0.03881487890236801, 0.03230378655115924, 0.026967865414917472, 0.021036414339417414, 0.027040457991402478, 0.054885530468797496, 0.03842640720728425, 0.027572521376573754, 0.03796109689339515, 0.02601236225135865, 0.047510808048349236, 0.011494488552993825, 0.02241059796013419, 0.06791226190304564, 0.03517313056715554, 0.03717645048914898, 0.050332861456779704, 0.01867115426237785, 0.05666433300282206, 0.012521125853151805, 0.09537777803357571, 0.04620255203917623, 0.03604986073990022, 0.01921644415556183, 0.056821112896526055, 0.05303610611947314, 0.05232751692434954, 0.03995614306580636, 0.07014787500543941, 0.03285742680271787, 0.0638246963611774, 0.017697226684240085, 0.034501022478986176, 0.019710630238536867, 0.03041027384179254, 0.029568253197677197, 0.04332663881922922, 0.03503209378029551, 0.058227964421553965, 0.002418652574922289, 0.030570162137249307, 0.08443759814385446, 0.05055003589199436, 0.039163663412534425, 0.015638113536331204, 0.08600210290282004, 0.048138636254495194, 0.05005985070320387, 0.057327129292271795, 0.004470589394200473, 0.0520991767576385, 0.034021911091141166, 0.08065534545288933, 0.045803213386886546, 0.029055857204742012, 0.007148038440068523, 0.020208179447499496, 0.049222669819550174, 0.027841780214540424, 0.027554830491182306, 0.07680718621779835, 0.02458365232263121, 0.05305404406822017, 0.07605687970475805, 0.028914328206390626, 0.03942575741318926, 0.06110910619158418, 0.03041838096725124, 0.08041312377299033, 0.024313552703167644, 0.04353943506195661, 0.01169148997794236, 0.0400347015520017, 0.0178295798644784, 0.03762014180181488, 0.039331620529053674, 0.03926079187001433, 0.021918796325823473, 0.01830609612947991, 0.05176939888887348, 0.00734054436531639, 0.03440623442011495, 0.018040008895519762, 0.036497574014168595, 0.04845093965770737, 0.03589023482955752, 0.0512738625759319, 0.04681102120347562, 0.10570834345755079, 0.00891037439296563, 0.06900504802263553, 0.009819182582319745, 0.012146143051194809, 0.0761749568365274, 0.022766566459810542, 0.03378702853355677, 0.02053322097767265, 0.018836633084462057, 0.0399021530193427, 0.07018247919697916, 0.0506122192488082, 0.03655056431589108, 0.07206599062849438, 0.016517943492339506, 0.018858395727171053, 0.05127604975695572, 0.04831034720184342, 0.028863415918162758, 0.006270844784129652, 0.06983727231741914, 0.02119777543890861, 0.0359407544977242, 0.08458859407373014, 0.029043931130980773, 0.004792968290031798, 0.03071323863320774, 0.010025145320762551, 0.07746058260841716, 0.04485651640401733, 0.0569798692970747, 0.028831464306060827, 0.061082886832375685, 0.01182599682285781, 0.0213874664698397, 0.0668252827299218, 0.004533189311323147, 0.022659492265853672, 0.02369460537128391, 0.020303128384834817, 0.021347191312440464, 0.03378219451875456, 0.0221785441822102, 0.0819057158585037, 0.027560512948360656, 0.02557591238479701, 0.017216418411642793, 0.03371324660556932, 0.0334379299273414, 0.03448770020998294, 0.0930103058776548, 0.027643085735279228, 0.09566893741007775, 0.07212717807100666, 0.03685958886278733, 0.03610231861051533, 0.052530518732965, 0.03317307801015916, 0.08614767493019182, 0.04604871775354109, 0.01779754015226518, 0.007478655653915579, 0.033565460584096374, 0.022074289191814683, 0.046275092904726346, 0.10826722268135318, 0.013947023281587229, 0.02482745405887404, 0.03192348709900773, 0.054793132604250026, 0.013651950153402023, 0.04709610550273811, 0.009908631965968638, 0.009543017461715687, 0.045758385751997276, 0.050611836204846064, 0.03587331960818941, 0.04694957203502136, 0.019507105574913083, 0.010784083729489677, 0.026769963836657907, 0.06888491011434986, 0.09823776045513731, 0.025054700635073167, 0.02446212013432336, 0.02379886802255867, 0.048320283362221335, 0.06813564548088659, 0.0651188678438625, 0.031958826734954794, 0.06628215703512393, 0.12849749801980873, 0.06512984588381744, 0.035123097364820784, 0.05460701537348571, 0.08309993968014756, 0.05071769423422314, 0.041258538502358624, 0.039697140229926, 0.03416547979859095, 0.05521921921641596, 0.04281455500712318, 0.07477947405629581, 0.055434210301046415, 0.024616553883759246, 0.1463649436951645, 0.13061848138609242, 0.09564577091124751, 0.10873463590659442, 0.06551671262469984, 0.14880520952565057, 0.17712826149598246, 0.09280328593787648, 0.12178214747578868, 0.08183823883413308, 0.12332397603219557, 0.10083888176708453, 0.22949530472678525, 0.06350035771667477, 0.0853413827116451, 0.22801998792396438, 0.14027644459518696, 0.130890948217242, 0.09774904998560106, 0.09890670843061902, 0.2203855540363058, 0.07462499242636465, 0.1154042816450519, 0.2194082709930597, 0.06755043091552873, 0.13422113242408923, 0.21503482825092732, 0.16382667686670058, 0.12406553382114058, 0.14497309983257325, 0.23226193933477327, 0.1880263065498683, 0.14930266105840284, 0.13746096422114681, 0.1480023647027631, 0.09052897773442731, 0.16781774980406608, 0.10726539418101312, 0.16984895532650335, 0.1199733296168908, 0.1122370366788199, 0.17912130051803205, 0.1639131069063179, 0.09477299758263173, 0.11721667713455616, 0.16996437413317544, 0.14387685865644487, 0.16702992030449454, 0.11967729026031111, 0.1389442330166217, 0.24972197179111744, 0.09134234860539438, 0.16218703420412156, 0.13041139249840092, 0.14584178225167338, 0.1234686823802129, 0.11048208246187818, 0.151648054560346, 0.08052391540859977, 0.09126832919015039, 0.14455028058540437, 0.1590670645236969, 0.07024816357560697, 0.13798498368311313, 0.20446177301627977, 0.13662042787238476, 0.105408389391678, 0.15909309619136397, 0.32438436462994547, 0.1397865160458511, 0.17887278159539546, 0.18717812464362193, 0.26477337784824834, 0.17020196864201179, 0.1002372959027848, 0.11318343871783827, 0.14224539781289716, 0.11147968215687622, 0.13590683229267597, 0.09979720903380264, 0.1329489361735121, 0.146952165410884, 0.18324452362233595, 0.10037754361908283, 0.2402744069695473, 0.18801060174742054, 0.1823875776702358, 0.14572876896108353, 0.1848793246092335, 0.13580330317058872, 0.1644839036969408, 0.099949078303912, 0.14130283387437945, 0.14730052091181278, 0.16460620197317294, 0.11232001932277796, 0.11487800222370895, 0.07752928537346664, 0.07600811054749836, 0.15255770736163662, 0.2367506170224759, 0.09628165453191727, 0.06839646777558712, 0.11962144245063105, 0.11051857122971166, 0.09038590315368869, 0.19097191461872673, 0.1458032173855651, 0.1547825952330905, 0.1226342057869319, 0.1163318762255292, 0.13555282306286598, 0.15842149755166424, 0.14540518874362593, 0.19971498498512855, 0.17094193296807428, 0.1702970248316565, 0.10932281523221925, 0.20386001095175746, 0.15033766116586425, 0.17686348618759265, 0.33637201653853543, 0.15927335667994716, 0.17261925183476942, 0.16952603394466062, 0.15102416787657047, 0.17016295944490742, 0.2112539545182259, 0.10984039955562162, 0.20286452565943042, 0.13062814941569684, 0.14580571483219826, 0.18322203128087908, 0.18070567759775347, 0.07038913141455382, 0.15786272834145254, 0.1973475281509661, 0.14773064863777932, 0.08991030810941612, 0.08807652344506595, 0.09768083751682313, 0.060292173011769215, 0.1500921912731663, 0.14353150622017924, 0.12724895856433338, 0.20424637973548906, 0.17555897634836937, 0.14854097047880774, 0.09162630675540817, 0.16834779071711725, 0.06833932527731504, 0.0707378929420825, 0.2918786717759025, 0.27676268450675473, 0.16431372492544113, 0.18493466680088352, 0.15648527161007927, 0.13445373203965927, 0.12246273232684021, 0.14426846748157857, 0.21397019586255475, 0.12365605982561266, 0.21397286184853126, 0.11250749635960787, 0.14436695574512406, 0.21066754485570618, 0.16359871974395168, 0.09008788729026433, 0.24063194020380899, 0.16894210640701557, 0.1460661081176612, 0.1526494234079315, 0.18542007543146613, 0.12945238831302813, 0.1481523953618542, 0.09937411399498101], [0.0745292850619843, 0.014711883549969045, 0.0322881200531077, 0.021422321555174647, 0.04562289927214865, 0.0969203420343899, 0.019199856436781345, 0.04990291759191502, 0.08434654093317448, 0.028399164720828977, 0.045389043272382794, 0.02234381616055485, 0.018906889092778007, 0.02851528832839141, 0.030555545179654035, 0.06713740227203216, 0.05973038924557548, 0.02344279801623235, 0.05018635480214031, 0.04038970286567365, 0.008887366857379675, 0.039531347311792836, 0.03502331441268325, 0.007466474855919519, 0.03443584371838839, 0.015460652141501347, 0.0710581636597072, 0.0384695494487401, 0.06462090303220096, 0.0989629392842612, 0.049213346529511676, 0.1077903559311263, 0.060720320400451465, 0.008312612265017966, 0.03209745800573259, 0.09959579685763006, 0.03603461175976742, 0.10899567270591375, 0.0045767485918927825, 0.017370158851507212, 0.04705378680580086, 0.06562149047010368, 0.01909058165526198, 0.0069226524999154914, 0.04751669543404733, 0.04962810653171713, 0.02693437588130755, 0.012508528494846918, 0.04528091762274985, 0.022972366404569438, 0.038016695724499804, 0.034279829912608674, 0.033779739206957246, 0.04882606610115017, 0.08304966132967703, 0.07212034456672207, 0.040342653575803966, 0.06069170318603997, 0.04754027945079631, 0.08217628279160108, 0.018678158221225587, 0.024392815990253322, 0.03303260812836309, 0.04479388488576778, 0.026835343695335814, 0.030702352523803714, 0.06506675088237371, 0.10327987538109865, 0.012911182392628924, 0.061385323023123134, 0.06263675446051263, 0.0782036112861768, 0.03824174937401568, 0.02478170520325582, 0.021256701006824454, 0.02914692016108142, 0.02939416546254389, 0.08136307279909812, 0.036986847558329185, 0.08071673973914116, 0.057062078192229235, 0.0545334019848416, 0.021293819881975654, 0.10031937456299221, 0.023392490937464663, 0.04187020991418151, 0.047678972008608045, 0.0676587021218673, 0.015689732540669223, 0.024400442395539537, 0.04022221306278821, 0.0012961545730978553, 0.03873409876119226, 0.03757970768117136, 0.024926894186665455, 0.01950173721378369, 0.011287717591790904, 0.039033056912763466, 0.023321543534797047, 0.024736998227214622, 0.05020085301610732, 0.015934192154917027, 0.016387984336864565, 0.07081511460484997, 0.033911824256422064, 0.05529451799849349, 0.0174021391919063, 0.034026231827034105, 0.014485089923255147, 0.02638421749936477, 0.03640771573109012, 0.07706845284349496, 0.06761477464028905, 0.06276163828348921, 0.030215321702041456, 0.05286245313923686, 0.008091914782961531, 0.041029727191574154, 0.01605549164401788, 0.07205848296683642, 0.03692747574419745, 0.06406181589550068, 0.03882972951678019, 0.05879081688040207, 0.03712707995286873, 0.019332791843842116, 0.02952052591999452, 0.007470012266909885, 0.07836682631844476, 0.01811445540478153, 0.04188737028368539, 0.017103016331431367, 0.03949538331418749, 0.02057245042505524, 0.011140754157226655, 0.013057260038030725, 0.022178440760340423, 0.0128618530335746, 0.03904039220463845, 0.007983305540326382, 0.03441994739395957, 0.01768683470154722, 0.04014961091020415, 0.04654919533359428, 0.036694290071365335, 0.049973183176330024, 0.009382975948674065, 0.009187784406446643, 0.030225037612141143, 0.029443315748545914, 0.05111825096631243, 0.022510151085894436, 0.016668136945114504, 0.030384784181331916, 0.028874709969386462, 0.01687868663500394, 0.07305472668620848, 0.07858768946701482, 0.01913952892796407, 0.08048662990932504, 0.030497052451415412, 0.0183835361273058, 0.010725368835753011, 0.03708880620017167, 0.03567529737108177, 0.05773168883376545, 0.049304710175361366, 0.040795085951685905, 0.030997863279715664, 0.06346817436297575, 0.03943795736338343, 0.03679972292194444, 0.11676663112255836, 0.06521859716984534, 0.005889493876302074, 0.042949524377622915, 0.05321556604617546, 0.038727889618565964, 0.022837661334403583, 0.05324304178957978, 0.04274274192510113, 0.030248110265200658, 0.01804680601062794, 0.032765251103668444, 0.009296522926419012, 0.05778210124962273, 0.029788465171511617, 0.02927419800882138, 0.009000948968253309, 0.05898848671706454, 0.06994792605720221, 0.08691275927929148, 0.06961167474547703, 0.020199890376158783, 0.05619794250495973, 0.012871420514138957, 0.03474836928709861, 0.028492403366873344, 0.010099131219659843, 0.006684265568882468, 0.028997872009753223, 0.013125620936343988, 0.11180372202708838, 0.015257566063214215, 0.05362567589468053, 0.06598994811816562, 0.08305227368949883, 0.05417788739226038, 0.08035589700504657, 0.03966240580343912, 0.08382976100209259, 0.11022272339511303, 0.030295134657212806, 0.037795250349107294, 0.042143029145776265, 0.04963796608330262, 0.023729448965299996, 0.08440598935609864, 0.06120971268824032, 0.04433189173259082, 0.024782124636394363, 0.03964803782441924, 0.058929149376889395, 0.08425791988209372, 0.019059049476298596, 0.02905855957989491, 0.05476173066023377, 0.02179535849380397, 0.03136151372605274, 0.0035783100306176615, 0.0331733538018119, 0.06955270895794516, 0.044995094048640424, 0.014308559325253292, 0.0263243745411596, 0.016877575807513732, 0.02878394961777714, 0.04042476287952835, 0.019316590999463396, 0.0429523857160201, 0.029819679423986428, 0.03593576343489751, 0.03875119401322257, 0.02802418191887198, 0.08591899002391486, 0.03168060658349386, 0.07964109100641743, 0.043557373010703636, 0.04978173780405233, 0.06571892919319292, 0.06795825782201945, 0.03864564241901521, 0.05071572921869736, 0.0640796274397402, 0.030574011729068817, 0.028638984715085358, 0.03155514053369482, 0.04184443488596909, 0.042871850722980116, 0.10276560821840841, 0.043083846403826634, 0.09726770162101715, 0.0081977536601405, 0.008165149915693028, 0.016311618777352477, 0.012854649891866552, 0.05350766388038474, 0.01883595892708869, 0.01856746426182649, 0.04554370876341578, 0.05598947848944415, 0.055991979766516924, 0.04039901466439328, 0.017743312618544987, 0.02133313742946954, 0.03455191369979613, 0.0628690706235507, 0.03363643479984134, 0.08220630577735363, 0.02677322354077572, 0.061940016645577654, 0.008928294147124455, 0.02858763575674065, 0.022818926654215303, 0.03523720999158198, 0.02990974455080446, 0.021869042745581078, 0.046729049795577605, 0.08374311645785648, 0.04274926133333676, 0.024194931648972056, 0.03031011167613249, 0.033539735351599036, 0.045484639554014134, 0.019396356074139476, 0.03199543807685616, 0.024422693419300263, 0.05506447328615093, 0.08640755493674548, 0.030257975562445583, 0.035862682477360776, 0.0529959554513616, 0.05134265727153228, 0.029047698368348425, 0.03750972171884872, 0.0372205886449064, 0.04005953812250688, 0.014583339741934213, 0.03924662307385476, 0.019973252839859457, 0.006273804277542138, 0.052304836891351215, 0.013470978160659152, 0.04869691516843535, 0.014774865553443952, 0.03992425848639781, 0.05655141547322274, 0.06737637573913222, 0.021722815713034044, 0.021975919671897447, 0.017726052657610947, 0.029956362916216738, 0.03708650410595921, 0.05778625727661195, 0.01742166868831602, 0.029428375118802634, 0.02422092118180327, 0.04181942211524133, 0.011384376820417182, 0.028522974105491757, 0.016007190758001902, 0.009240585101407864, 0.030578713593704086, 0.042122214536873565, 0.05131928775940211, 0.0697289704675636, 0.05165967594591841, 0.02864740019093358, 0.06778424861089838, 0.032038183867811196, 0.09586079646983454, 0.03264244720940629, 0.0670658573207836, 0.025113980518653992, 0.05024579173374561, 0.024384488614516395, 0.06579160795456941, 0.02989993862537367, 0.08283592279880278, 0.04643821217600377, 0.016862912884643002, 0.031992335420762824, 0.1921796215878379, 0.1309523884687693, 0.19125043354447813, 0.10619000591818364, 0.11682280835004584, 0.14032204214844013, 0.11667398044899588, 0.20948275923728946, 0.21886830158050985, 0.16334899040239473, 0.17647250555455687, 0.13557166882580327, 0.11536341085429154, 0.184267649366971, 0.12396235709949849, 0.1359948404734173, 0.29719173667892335, 0.08608836440309402, 0.11818275231147006, 0.10567607583418008, 0.09675038542838828, 0.16045307079630514, 0.19061789006715824, 0.10418813390236709, 0.06370244405022071, 0.09574720861330148, 0.20583490901176008, 0.12508078418191404, 0.14219860516248212, 0.18434127041649434, 0.15735841266089873, 0.2399855305350596, 0.18428853292378689, 0.09423361039690434, 0.2005572220490825, 0.23338971268986505, 0.11170747840116102, 0.18836853334740286, 0.0640264532769159, 0.12861160681613032, 0.14603710402884792, 0.1791677867332774, 0.20941886750440444, 0.21453641144739044, 0.11069333120699852, 0.16781393468620318, 0.1138296415428481, 0.2049575544773571, 0.20679032790564722, 0.09685400648102646, 0.11242881146890503, 0.0986800000311867, 0.09623411111533643, 0.20545034819552976, 0.12901475292540368, 0.16320729477991983, 0.34880142538778247, 0.17970769485879332, 0.17828678562035485, 0.13000049357933383, 0.11691955759400323, 0.11036205180590192, 0.18716793567422899, 0.11294336208412725, 0.1751465912187292, 0.11237463373089991, 0.1927726655717819, 0.14391369216384428, 0.16457442464607377, 0.29132249194287485, 0.16163958777343074, 0.17105100856673333, 0.13718282833935755, 0.12554488024644314, 0.13608508563089755, 0.14627521947747277, 0.10657695692873771, 0.1359479252489344, 0.09964465028456143, 0.1398077060378367, 0.09626439457098324, 0.15890431680506276, 0.08760675066901792, 0.1940889884867976, 0.15816459762713603, 0.20146063889466947, 0.11943565080723456, 0.09900184122905617, 0.1281056287247808, 0.0745247038561971, 0.21207392906710026, 0.0781346174077161, 0.15971961821759903, 0.20032175726467566, 0.17676464552360197, 0.14888010228112822, 0.21114999638690105, 0.22681221966781925, 0.07553608547295294, 0.24202030602722402, 0.07095301809209971, 0.08411710526073173, 0.15107851415391893, 0.13106616784728345, 0.11983190212518939, 0.16169848461304942, 0.038969766558899034, 0.16003878576861275, 0.16438786691475302, 0.192496812632007, 0.17279312315006412, 0.23139615272802694, 0.12517793179159203, 0.1966267313447691, 0.07923226052474591, 0.23442950850773245, 0.12562106769051284, 0.1513262057015973, 0.09139437363633225, 0.1292430011615638, 0.13938104102928794, 0.13542785880065736, 0.15647647692070854, 0.13390319061375436, 0.11590730263701371, 0.14212869197851227, 0.13855809405926736, 0.10225638957513918, 0.18099729662701008, 0.057101516398571195, 0.11785655973419068, 0.1582127692358148, 0.12482816668888255, 0.13632975879215425, 0.13511249104574805, 0.1428169913349613, 0.085260575757392, 0.09739370010192357, 0.09786744121341936, 0.1404884824108693, 0.28280754723856527, 0.116386643851236, 0.189154141191994, 0.18056709229225115, 0.1247081207111478, 0.12479340927975795, 0.09576642209844244, 0.07834260261827901, 0.07970664515009812, 0.16008085931741423, 0.15290921914481348, 0.1368125627237943, 0.07389789071655081, 0.06411541523712297, 0.12359910884932165, 0.1377104330928095, 0.23245105579976114, 0.1351173327214295, 0.10057223720415946, 0.17446308757268614, 0.13936294603251642, 0.12434406040777123, 0.20172080235375514, 0.1279863105305741, 0.13850512674018262, 0.13702671494214766, 0.2003408481757487, 0.12512114935464438, 0.12044544662198714, 0.16073442424737638, 0.12620628991674993, 0.13948372745465848, 0.2140341182389567, 0.08329015931174641, 0.10263238552837603, 0.1241324209578095], [0.0474910238277047, 0.026811097012532335, 0.04954259579760894, 0.0277126292818256, 0.022175299799850872, 0.0684896930150928, 0.013530728230703504, 0.024382628936080203, 0.03222522423452428, 0.03671790473163128, 0.045394949810278994, 0.058501568893271114, 0.08015039391935834, 0.030942088248388424, 0.030640511991335984, 0.05297186964702222, 0.0493757495085799, 0.007939967467644884, 0.023136627146854036, 0.017036012366353985, 0.06480860989540815, 0.04906544176441047, 0.025456264772782886, 0.015423674035006234, 0.04058866739092816, 0.04084376700883431, 0.05936883788015093, 0.007008451953410141, 0.060882459079185804, 0.03193846220270761, 0.0232060442888929, 0.012240351756073296, 0.020692745381365382, 0.043122851770491376, 0.027413351288546, 0.03208359181430311, 0.0389325691597356, 0.06706387315305971, 0.022654449492092096, 0.036630482608152014, 0.09350460112815903, 0.03841942048541481, 0.03268437137106254, 0.045782532843370596, 0.06863537995565323, 0.012140494110363146, 0.027638343651027932, 0.0555413591885759, 0.06349623233320252, 0.0303606198529803, 0.0820737878882116, 0.05722034046606672, 0.03521342296153307, 0.0273567067474247, 0.04969767880656066, 0.05619129669221659, 0.011186797956695721, 0.020872092310098872, 0.029621921487212665, 0.036999924679196654, 0.026905197507491516, 0.04166143180261697, 0.038784438398696726, 0.08361553217494681, 0.023788167689476284, 0.009600361058067892, 0.04763731214728567, 0.0400427914404821, 0.06122941646965281, 0.02438013531988667, 0.03279388747027805, 0.030954278622483535, 0.04872587329197315, 0.09742578386419243, 0.024624726126691508, 0.11104350233630789, 0.042077471171655965, 0.036814194322834094, 0.06000033181701457, 0.023580862381946177, 0.07116240524356404, 0.04555467531205185, 0.023064490392683976, 0.04748515559420471, 0.04477069923473943, 0.017985260422011057, 0.06088647337990904, 0.013884578497269222, 0.012959358789357207, 0.04686090501866514, 0.057967747336313616, 0.018663321013352083, 0.004388405396903475, 0.0364640538370417, 0.04748198015975857, 0.07176213717508702, 0.057605073652079994, 0.06054227390596944, 0.0047740042622711875, 0.0907510819454347, 0.04063460202286801, 0.02010311623434386, 0.05056632292126456, 0.059712003135392745, 0.020843229947551604, 0.04379772160562777, 0.0038398759094096964, 0.07135171323053299, 0.04231353350464375, 0.07335684112002773, 0.022660015120861993, 0.061843386145248536, 0.013757108169938288, 0.03921855361230912, 0.022013438827989083, 0.05995106470260409, 0.07614561566902746, 0.0432896597551242, 0.09398246379268747, 0.02828473033713958, 0.05238788465278284, 0.012533750024534041, 0.025117791806077285, 0.016850892965111042, 0.10700841764769248, 0.048565144215019486, 0.024357399745513836, 0.056645062061086784, 0.047921166875429695, 0.02387509185580477, 0.05279449730991356, 0.042651144622434536, 0.02240651088105815, 0.044143828638498826, 0.057205635408360156, 0.049028217552169684, 0.024920771228930643, 0.0053496355465012455, 0.034812563624713695, 0.017434385747859077, 0.025132833942470532, 0.04463602480809054, 0.08337409190473058, 0.03794152334692978, 0.10102469639311876, 0.041999809008332036, 0.061267104165087787, 0.10552530206980244, 0.06275162168387925, 0.03673941648054508, 0.04787444700336745, 0.028156360814107523, 0.08250992174350447, 0.05414842365069255, 0.0863528639198311, 0.04190731921323365, 0.058697250731770075, 0.037418438512231075, 0.017056244748434233, 0.0393246989246578, 0.039356464760438095, 0.008823952971837454, 0.06156706206140019, 0.01959914720857576, 0.042337332026011525, 0.05209297144545182, 0.019475345484792225, 0.032259736495513114, 0.034847118020538366, 0.03423445835529316, 0.02526489409407781, 0.022161289966935595, 0.07969337650724957, 0.050858815290754845, 0.08848086465150119, 0.0433974904609063, 0.022644565042649067, 0.08660452380295723, 0.08328770016950947, 0.04137398029166845, 0.03773236985228235, 0.0207185567987542, 0.024090310851592692, 0.0314686396309445, 0.04223044360837629, 0.028665882062106848, 0.03808847816300489, 0.028847875824618726, 0.020395516673283234, 0.031123737271334377, 0.018685336465076096, 0.13278514657530094, 0.058997423132701274, 0.04244370716473749, 0.049853141029034896, 0.05140166902433961, 0.05040618373201259, 0.026051030539336707, 0.038204046356822216, 0.05061535637885813, 0.014318152661285093, 0.05536558797522899, 0.0671742051359146, 0.022938105037375804, 0.0896327161500531, 0.036718927459010196, 0.03552560379067737, 0.010095089148249357, 0.03256597248236499, 0.05130998745200135, 0.021207453044612082, 0.022896157893081828, 0.05924469333202128, 0.048294186577080726, 0.06259361221905678, 0.018378552725358356, 0.024340840755030516, 0.13532541752342256, 0.061595323044926896, 0.045457634954683246, 0.08445173246605743, 0.03923726530985967, 0.036659525001361486, 0.05086370293171175, 0.06171828781765315, 0.06571580355446185, 0.03295188161334203, 0.0414939190170938, 0.006222383019649574, 0.007164544762007051, 0.03930841955626684, 0.030924828287454385, 0.0466918217528972, 0.03295557798757669, 0.041041080614611994, 0.022154159603580352, 0.01179457285381373, 0.048145596163287285, 0.027672616509540428, 0.07577648386359215, 0.027644932007176742, 0.04251680727447233, 0.03256911727329416, 0.02007752123679365, 0.0352251326154557, 0.01854705567952366, 0.002096897322541824, 0.04044022636427995, 0.050541961325272444, 0.0635868069084902, 0.03927281945042553, 0.047434536334607875, 0.08814000915135108, 0.0037303174359558694, 0.053215225137049155, 0.0755998622926493, 0.09895209147925339, 0.05339023026247179, 0.050705314253366766, 0.08309652292800528, 0.05869004567484221, 0.02895831314456319, 0.026622871124756434, 0.02449415984653658, 0.04661083859842151, 0.061967178292933016, 0.026869411625328566, 0.024623132663809007, 0.03854393275574811, 0.08827916136191738, 0.019996562980175502, 0.03346318784620493, 0.01931794505986956, 0.055196014413189505, 0.052581762354220116, 0.05234897121666901, 0.03538208870938228, 0.026765009163007624, 0.03477529727763707, 0.030234431765312632, 0.053759373559225956, 0.05337967740131482, 0.02358103666694895, 0.044126239259757345, 0.04685596758199315, 0.029690038195000063, 0.04837795829160079, 0.012693766639718126, 0.0158416765043512, 0.04750138899732021, 0.02539501412801685, 0.05056747971403022, 0.06588087251950657, 0.02014755507961156, 0.025234166307434924, 0.0546096085811094, 0.009266776689929108, 0.04468647935878366, 0.09197758871220774, 0.026589308812793706, 0.03256846609855852, 0.0028230667991128063, 0.04181024055146883, 0.058593779066277135, 0.014959420922452645, 0.035303721745168014, 0.10348124159199577, 0.09241469549916445, 0.06994873811040195, 0.06853080895398894, 0.020308389493654815, 0.006771739403296623, 0.014719305984345416, 0.011617489714896487, 0.022127126275952307, 0.036083189395046046, 0.0072871063809631575, 0.05739462163840091, 0.053960199678136464, 0.04816137757452746, 0.12477116208643683, 0.031103571921947504, 0.0385635637588078, 0.08248151520327215, 0.023284981988610762, 0.013356758281588556, 0.036116774689646504, 0.013771450293490724, 0.061848591712694016, 0.041318802808922146, 0.06739568881570332, 0.05116413963297683, 0.017780937111726212, 0.047069549064842925, 0.03455006359745899, 0.07410638154514375, 0.005921509169462708, 0.016652252112004547, 0.0077925132580041415, 0.03884441925272827, 0.055211634945965586, 0.03990237135440111, 0.017488929292848034, 0.043828154448419816, 0.08425799649088614, 0.04236733202912635, 0.04517620489481957, 0.06478305320225416, 0.09274104129402869, 0.019433038279173837, 0.059466364703351454, 0.011337717277778974, 0.09957408592585595, 0.20519795286799633, 0.17796623911107742, 0.09979117992183856, 0.09395830904043491, 0.11949818656449357, 0.152690393790122, 0.08966023402829325, 0.10453449757469278, 0.1505765120588964, 0.1484303933478171, 0.18085140284271012, 0.15835343830047116, 0.1103365793824196, 0.10884062417091862, 0.18551071895466698, 0.1579565741121769, 0.046023858200398185, 0.08963763443452698, 0.19664436668878604, 0.19297218551078152, 0.11804220582088155, 0.22393295481320352, 0.1352500957587073, 0.09007795879076566, 0.1657843226266484, 0.16744949133886447, 0.11141211320195468, 0.16925188172007763, 0.14150321183185424, 0.11681395237364116, 0.16278321914855512, 0.11033966671675445, 0.11504856403917076, 0.1802337521146382, 0.12219975732507245, 0.14894802363649493, 0.1321211168842931, 0.14951868253129144, 0.11445682240469802, 0.18187465116141305, 0.18258107615815056, 0.1139256093771227, 0.18869723103219466, 0.2618503540513977, 0.17303209661716418, 0.13172250601553148, 0.18855965696275237, 0.17330474730941559, 0.12044159319972801, 0.0729217874487081, 0.21254231522400535, 0.16985989506206206, 0.11543933782846698, 0.10527957170721024, 0.12586233942138572, 0.2192070350171097, 0.09809529874473812, 0.09991993631927237, 0.10531935465311813, 0.12908544751905626, 0.14046709323602338, 0.07474428763793362, 0.23437390584618817, 0.15415762070446246, 0.12245286511437548, 0.12910844547854317, 0.08614695480754299, 0.09884127686100622, 0.11085201099875475, 0.14220462661356698, 0.11137249879539014, 0.11922408796606526, 0.1758450335792957, 0.10807766954624846, 0.31981425179589185, 0.19446481590069112, 0.16557505804925196, 0.10847831054800942, 0.2633036841307917, 0.23518562196723877, 0.1725852988179653, 0.13166719446739844, 0.19575605709706584, 0.24779745167301548, 0.07647762285365213, 0.14593824804309877, 0.08451858129833015, 0.13104408919330568, 0.255406895772584, 0.07992137193439469, 0.10390625185062809, 0.10110385625833467, 0.1676345015725782, 0.12367637647736458, 0.1749592061124502, 0.15540364739154616, 0.20376483218804484, 0.12677340182445704, 0.1793777407898057, 0.11659356419958415, 0.15973389809650762, 0.08808146471217757, 0.20659229417722072, 0.13131945183680904, 0.14580542371878702, 0.08901046889443552, 0.1554947658892601, 0.19246175644859193, 0.2159772542936187, 0.13395163801408586, 0.1167827266298475, 0.16999774492315708, 0.133358977074104, 0.1547911754178424, 0.08859452911682668, 0.18108406374531408, 0.1366761684297554, 0.19125458574102772, 0.11308596935123207, 0.08603353549035327, 0.10320914248304983, 0.1839638801832353, 0.18846797155997447, 0.19339682804721017, 0.1308288797736168, 0.13934299710296816, 0.18294853789191093, 0.17775378760791596, 0.10367061852687791, 0.21272697305727392, 0.1699417438958922, 0.16672506327590636, 0.15521538894503348, 0.1572178968138272, 0.08841213124293475, 0.08620637258695019, 0.2733279446200017, 0.09163349266013793, 0.12534136898935805, 0.11219957497932258, 0.1403168480723135, 0.1653415391281728, 0.21982211168975602, 0.11948540821791657, 0.1494614557633477, 0.15250515373003098, 0.2123745726121049, 0.21591665673880808, 0.180007740855217, 0.11508725914022616, 0.11287504236303991, 0.19855454564094546, 0.19980706875362705, 0.22708128506858505, 0.1957739988762525, 0.16564374549254296, 0.13389767478069953, 0.12791958427236927, 0.20660176302396482, 0.1430525174064021, 0.0469689617203849, 0.12891695414099003, 0.11030343841881522, 0.14242650099819706, 0.10109867750396652, 0.07024154457594119, 0.12209071236993037, 0.16289672273541653, 0.16996512489934124, 0.09087633732105456, 0.14427626625664774, 0.18677762919856658, 0.19312385559803058, 0.16489535419931337, 0.16273604345417794]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.017401367358322588, 0.043404132443209814, 0.0261206851686321, 0.03702118744953506, 0.01946475623445886, 0.04500169006566848, 0.01885862746876815, 0.07991707418113947, 0.027826326305887876, 0.007691794242184129, 0.034147698897868395, 0.10432467375311161, 0.053006305299218626, 0.025115949364619392, 0.04395485389977694, 0.010920675291169074, 0.0813543547185198, 0.02451222419979111, 0.04559588701193852, 0.0244578683463436, 0.05896175024850715, 0.020581880967403134, 0.06341607655368506, 0.00858498429278693, 0.0786719821213234, 0.043515475662124735, 0.01923515010745295, 0.06902402402051995, 0.02305485300659653, 0.014451761268109325, 0.028076825565808726, 0.085276004768187, 0.008706203342655735, 0.0245081237141764, 0.012227011292481856, 0.031181557757419445, 0.029931553158788916, 0.003715770623286165, 0.013494391722844975, 0.018030834992626504, 0.011132260157366194, 0.08790331096538613, 0.09417633000280588, 0.037505286069767135, 0.05828856197636455, 0.04543108234722768, 0.04181301762019435, 0.045899855378534526, 0.09752534465083192, 0.07202128939811261, 0.07573707630076716, 0.05188729215954101, 0.05522830118875831, 0.015651264393161383, 0.10189903254110007, 0.036448781874271176, 0.030327582311245705, 0.04986020819013638, 0.03393349305336033, 0.05789884155796421, 0.044266709141553416, 0.08546515187669186, 0.039937473503091646, 0.04006037315834434, 0.028526381281534993, 0.026788778956078237, 0.05952081823300931, 0.048942840883448246, 0.07789159899637585, 0.024314290062794765, 0.018781352179845976, 0.04223816194421342, 0.05127645961399521, 0.017610472972474752, 0.030557176946932753, 0.0319532438692066, 0.02922695145131119, 0.08622261365094493, 0.04276175239694215, 0.024889857665966117, 0.040842250154744235, 0.03728688972431325, 0.02743512350735405, 0.03188811107388428, 0.04407707939765627, 0.014310595203912067, 0.052578659698126785, 0.04608163655164742, 0.040900951641942226, 0.031034578043486805, 0.06443985347305575, 0.06906769869308318, 0.06694267804343855, 0.17548673425710973, 0.055174839742962396, 0.040959890616396745, 0.0633071082073354, 0.02350895353893359, 0.060044627020796465, 0.03840816665380713, 0.03466578500886117, 0.03523130345368578, 0.036231990483018665, 0.011468272066615041, 0.03610464751780514, 0.030978253344073895, 0.02626703286002721, 0.07262075319886208, 0.07840394327837615, 0.046895850119331194, 0.04945762132504775, 0.059257161412988944, 0.04891761743854131, 0.059656546030554085, 0.09910218342537842, 0.04728894515503799, 0.03238460882717083, 0.02623620165151454, 0.053958131240740906, 0.02424582861544144, 0.014728698222297094, 0.06249243115645744, 0.042408953586052504, 0.04146797927997766, 0.030298325413417433, 0.06049183467703481, 0.038586925610058734, 0.011317166969210151, 0.03324888624070633, 0.01814395936596538, 0.029608968855632894, 0.10793391314725723, 0.0863044701456543, 0.13981918203494242, 0.024726629227159486, 0.006398056556786141, 0.047491751611232765, 0.05492689921670864, 0.0356529850602871, 0.030766728807300813, 0.029257441750697555, 0.02345590961105641, 0.0685018967957266, 0.05349664370559397, 0.03447700179212036, 0.04120750172484306, 0.01066746216477646, 0.029378025905199112, 0.0385257649806238, 0.0794079015031457, 0.025819702629720973, 0.03719600871385586, 0.08076646650630621, 0.01230874521312334, 0.03355303846840416, 0.015693810043646204, 0.05140912305984286, 0.038255381908628254, 0.02262771876919414, 0.013318202033969424, 0.02101466893368671, 0.016526629014181036, 0.05972478914284899, 0.019752682719920433, 0.021757567376499216, 0.016090751798342795, 0.05036452387069022, 0.011058353740091046, 0.08635395942556282, 0.009419587290575428, 0.02025863016775299, 0.05199804549075423, 0.07256960150815787, 0.04037121333362114, 0.04428403805040064, 0.04295558413310398, 0.028398908081374345, 0.07984250318259001, 0.01736586492869162, 0.046985172140862674, 0.02200039809629802, 0.043972761205007, 0.040846233811950496, 0.039266223433397474, 0.02475528666118701, 0.022798830252741615, 0.021365380154982693, 0.02247787771686431, 0.1013867112417375, 0.03184314171272901, 0.03269593929871917, 0.05474459710380724, 0.010108735089400604, 0.026650819927453998, 0.03273169262214534, 0.02030567562718305, 0.07082022441130492, 0.06461653633103256, 0.06547712886165227, 0.010986649825598204, 0.04356005814887824, 0.0499910751598016, 0.015057068404501245, 0.016289132181555033, 0.07176566884041795, 0.008966968180761944, 0.012962458572620827, 0.06390744534831855, 0.0231318237755688, 0.041310103880541946, 0.034962877736336766, 0.02923099448033158, 0.07326133293850769, 0.05666095072463636, 0.029373561527820367, 0.017895137838598703, 0.012801557125884199, 0.06908860523253679, 0.017104324426562074, 0.05929144001716088, 0.030550983126064947, 0.020828446365832802, 0.048644108727814696, 0.050298831831183166, 0.023486461197476716, 0.036139335979016564, 0.04215312235417866, 0.02796072877132364, 0.07348644021417826, 0.09310554592840134, 0.040998528260857835, 0.03798086579228121, 0.021326932117282864, 0.030799435016008157, 0.06714464946379585, 0.029657397103766282, 0.024532046724831866, 0.08242893858902878, 0.005708903012301533, 0.024538828518181562, 0.07646011008370308, 0.044617458667245605, 0.03591759949021282, 0.0249035821311296, 0.05037701493429561, 0.08539900784530947, 0.04239869566874639, 0.035321372410943436, 0.023527042790045662, 0.12271793153617652, 0.06157640833407641, 0.01524253350292002, 0.011279229337589876, 0.04592808188810464, 0.01554459239536476, 0.02072816545654449, 0.03626744886259398, 0.06838309188042918, 0.04015728711120544, 0.013892896296907098, 0.019282592017383828, 0.014886539147776223, 0.05329762555418476, 0.039920435707655647, 0.03662338863397318, 0.02466078971572701, 0.06088181173488979, 0.044515538329799334, 0.01758929830224764, 0.03417761080087193, 0.022900980416565173, 0.07696955089247035, 0.05831643225504987, 0.04373513605265368, 0.08189530472361273, 0.018980201791911837, 0.11631706774595285, 0.03286660836649037, 0.013154608745788856, 0.02029648831775112, 0.05434011034066639, 0.025906532950278734, 0.010904848872263347, 0.07132824795741229, 0.08121518718619501, 0.010081833911939495, 0.015355442414030194, 0.13328440607555453, 0.036625288532025395, 0.14092760400906687, 0.0026996225032264428, 0.03787503457598148, 0.004648286361067046, 0.05282717479032375, 0.06032765437398226, 0.011842033915942716, 0.0913883675070059, 0.035407610928579684, 0.040396919413920374, 0.05902397574015683, 0.044675225527175975, 0.035388209751897284, 0.038135944970793305, 0.049388780664171905, 0.06866272929455004, 0.020559034310281277, 0.05106373231918101, 0.11843670279748979, 0.07703057745651853, 0.08842289477827088, 0.03485712695926909, 0.025491983622252464, 0.0175490403818267, 0.05574187887231669, 0.04288702309432049, 0.02226108824083161, 0.05927079777804114, 0.0661843429289518, 0.02261966718510995, 0.03607479307139593, 0.01200546345282947, 0.015856716725524637, 0.039167869235238725, 0.0294822751499352, 0.046487544407887806, 0.07383217569440603, 0.031193278902660937, 0.033556527998899265, 0.047833292760075106, 0.028622305065753962, 0.07455527076437589, 0.06973393471731294, 0.02210124208021068, 0.006663355677794185, 0.06917003271800858, 0.006595035956706853, 0.040448940614418644, 0.03623340391523896, 0.05280784639199415, 0.01563943024995106, 0.027893113851126645, 0.06500980756696194, 0.022415962490823962, 0.03608082218336002, 0.1052344644502286, 0.05124224229685722, 0.05375081635711174, 0.04279442987735233, 0.06414281437173486, 0.04397765650684315, 0.08465299142464515, 0.03822164722688256, 0.1630893632048561, 0.16721951174399546, 0.09862572270175142, 0.18869413603698054, 0.11387687086337998, 0.15302777891197514, 0.10348955364597422, 0.16167801474371266, 0.09916403736438482, 0.1491607815748261, 0.10489653540594925, 0.1893044782862548, 0.29948469912332876, 0.1157936534934467, 0.16671349534824972, 0.11627641145981128, 0.17779203071709604, 0.11245084415760734, 0.12866397658663412, 0.16157587990164757, 0.1690088326652204, 0.10238074096700839, 0.24573793154089685, 0.0748587028694249, 0.2422814654006112, 0.11327314761377151, 0.1257106923167744, 0.13222967154316365, 0.13258037127314076, 0.1586742912449183, 0.18759043316446966, 0.16542527253829664, 0.12894142298929154, 0.14501693538360058, 0.15330033767367565, 0.11192674042596934, 0.1764496608126548, 0.11417353075117835, 0.16009860191374056, 0.1230250791676583, 0.06761539517150772, 0.1865511429646323, 0.12300087078925102, 0.14544220611212716, 0.115675944083881, 0.15052078682328426, 0.13464678619657794, 0.20974934251318056, 0.16746913383324302, 0.12566579190353233, 0.1653079844770893, 0.16685925123672332, 0.13619665867618977, 0.14784360064133523, 0.21606480282160545, 0.14999515857667695, 0.09673138644786612, 0.16367136020093195, 0.11381291784346105, 0.14572757386392163, 0.19937220660428848, 0.1587080450788621, 0.16757972628599213, 0.08482992709163698, 0.1925025429696806, 0.15610150752529023, 0.13653140845558337, 0.10488393325959483, 0.14865352411664304, 0.13599458000352307, 0.12602818979611322, 0.22478925725144727, 0.08599431178863011, 0.24587922879765112, 0.1489775486650967, 0.14854283973334298, 0.14335112315752815, 0.2656983830515416, 0.16873601343362563, 0.09069737918194264, 0.13466943175561968, 0.1774345434481098, 0.12911527898282776, 0.08975290768449345, 0.14620101620112697, 0.1457107812166214, 0.1693783781581348, 0.14239224154622326, 0.2035545870181053, 0.08484369369163629, 0.18859023919268963, 0.12886420132652407, 0.17842996745340287, 0.15611506728155, 0.11832951177512446, 0.10180996715902321, 0.151532007561576, 0.11580227198259485, 0.16934673872686204, 0.06809832933809488, 0.2101682700336941, 0.1369655504822731, 0.09390408533715433, 0.22438870051935797, 0.08568003187857329, 0.1058066401991152, 0.16162694732268013, 0.21958068674129827, 0.18645551986992362, 0.10378844284963223, 0.105755488508411, 0.2483402096456097, 0.14717269148076736, 0.15327730907067177, 0.182080744134803, 0.17777776615994592, 0.091080300570015, 0.17224322523801558, 0.09081421525127466, 0.14906181833676754, 0.15794319821701897, 0.16850773455394855, 0.11978565339720058, 0.12635317961535147, 0.12301102145424775, 0.15541313156004877, 0.0826133359524031, 0.16408981274693243, 0.17960182150765774, 0.067583947262216, 0.0872528640132758, 0.2683178828127923, 0.16084737625093232, 0.31466424104667484, 0.09626098547972019, 0.056670220388520154, 0.11395807618335371, 0.14951727292951078, 0.11006229692288946, 0.10776902804331434, 0.12342275540915229, 0.14847795208615644, 0.18894778774870982, 0.12077647321406873, 0.0930446879036965, 0.18235258277385466, 0.12338972935873656, 0.10107759476429033, 0.10270930841685304, 0.14798518901150073, 0.17212253574642444, 0.14035139863769855, 0.15307262569906252, 0.15977060902983914, 0.18238253681169403, 0.2448435851763333, 0.1618981424478754, 0.1148190057926601, 0.12006833218038084, 0.1260956438378461, 0.19408980053999733, 0.12303889939381231, 0.14890267123137751, 0.10719112195675412, 0.05322027748690979, 0.12351740557219713, 0.14468892717794066, 0.12359313336351227, 0.23758206756845598, 0.20901172241616636, 0.08561187303595005, 0.17592599375113366, 0.12762978853237245, 0.08909483049665728, 0.16531731542800704, 0.07224735428368853], [0.04155924333439719, 0.0537037555759232, 0.01370438312615959, 0.03902309010886858, 0.02819680068041048, 0.07099592667673865, 0.07916366501200585, 0.036912743873413534, 0.017431901707764597, 0.012436437705952316, 0.06490559662662207, 0.037930212058727784, 0.03334699529072931, 0.07378200459624491, 0.04055764466043442, 0.03319406498884482, 0.02621320369202764, 0.04700511723997132, 0.027072047626960184, 0.07894532229270666, 0.07390040348494246, 0.09974408083625379, 0.038761432778330586, 0.022710850800297434, 0.0509172065123435, 0.013758893154801862, 0.028211858138562213, 0.014970870106481017, 0.12397649142170146, 0.05276288852215775, 0.02512293608648883, 0.04265905448025273, 0.0985182099224579, 0.03971268032347003, 0.02610534234272857, 0.04485273192967138, 0.02487069014610062, 0.014438849813755483, 0.11722347233444454, 0.04793459256630271, 0.02822247803241255, 0.11329307356068205, 0.030844199448643677, 0.05265565153451697, 0.02931009497373335, 0.07749116483835444, 0.03866268404489083, 0.026600095330767577, 0.05208128860460655, 0.015046009925314257, 0.05308793196755071, 0.05787249196380858, 0.03393394504523566, 0.04871250505769446, 0.05773212933432191, 0.04697931922912117, 0.031710715754137885, 0.0523693185119379, 0.033379691923337604, 0.05256655167848353, 0.06048339621854886, 0.06083640570361769, 0.03972002327622425, 0.03622835539581795, 0.016119541382537256, 0.008648739087455457, 0.013844651909875534, 0.01562446280713043, 0.04925918923090062, 0.11050783833789249, 0.1144526472255107, 0.05739802306878471, 0.028967986919827042, 0.037798793505757086, 0.03824855223478329, 0.051545682062785474, 0.029232421319090554, 0.05507145234714112, 0.019229389126262358, 0.03530922608690397, 0.038697108205768375, 0.0488762371993113, 0.027990837941967675, 0.022833568509668115, 0.013103937775257134, 0.017599274682241584, 0.0571344122140398, 0.05683869844482792, 0.020391617285748644, 0.03477266193517754, 0.036951381517874624, 0.007620154966359899, 0.03369456938197536, 0.06433294590322242, 0.1320526592673794, 0.04344930864810463, 0.038260805811132156, 0.06181242087134912, 0.04090572053927087, 0.06799183545574065, 0.04902842439590924, 0.036640947369197686, 0.0187826985793729, 0.041878518137720325, 0.05148460953346184, 0.045544865556181445, 0.04298379915135522, 0.05516211885297972, 0.06762098761335497, 0.06451724367516656, 0.013772502706776706, 0.03412015803699051, 0.01984136697325495, 0.039633846045621944, 0.005776595020095908, 0.04908259447303511, 0.025977359694098274, 0.0319565725212376, 0.03218896146262846, 0.034213525002762195, 0.005194707191549242, 0.030159140644114346, 0.011034960287713237, 0.02864852059452284, 0.042175438495412956, 0.02388205751025629, 0.022448728071345438, 0.003524809801620582, 0.08171685220253083, 0.027878422199958758, 0.015137871528314728, 0.050620201884979205, 0.02871816756293899, 0.041341953985993905, 0.023468875649174856, 0.005347350210462127, 0.02205519253508218, 0.0584092169939991, 0.06479700366335531, 0.004742678448242406, 0.07753966586484064, 0.0529936112223133, 0.0612601251040976, 0.02829748187063923, 0.07269456577036651, 0.00726492669914038, 0.010412371165359454, 0.03982634861923514, 0.0765777888497518, 0.04340182651855773, 0.04733145537395631, 0.03006630610945004, 0.05023040485778644, 0.05612447850346085, 0.08072164270185656, 0.050235920690841256, 0.07610492873936892, 0.06840949127029988, 0.010710880197885056, 0.006296764411437776, 0.05738854656116136, 0.010633489995774244, 0.05610723003384568, 0.06946585756996948, 0.07964436986273335, 0.048991927967196515, 0.04831781272866553, 0.06871234114852644, 0.04925778345955957, 0.0023766094302353, 0.011064938265800236, 0.05004736730047772, 0.04527504555881024, 0.03583762374135756, 0.03743213616431721, 0.04905281663541833, 0.09179287725278447, 0.0017238034061231322, 0.026413943626046665, 0.05214830214578298, 0.05458690556547335, 0.0869985611268109, 0.02577158273197711, 0.01776288041935092, 0.10611479906665702, 0.02029403683639342, 0.060992147548184286, 0.03165658781184785, 0.022400493260412928, 0.0937161563084491, 0.07119262741217691, 0.03925116980568536, 0.042184654533142046, 0.04765077231211528, 0.056173243830280925, 0.014675285614606355, 0.030822641734454422, 0.1354428281586978, 0.04236909020091257, 0.07276149887231088, 0.09826329416565358, 0.046276019871114724, 0.011516647646203639, 0.03484406516016011, 0.013664911403470944, 0.04836071365242524, 0.04557250600848948, 0.036898287794282364, 0.030327111167172273, 0.02305956253211104, 0.009867329293140962, 0.06336429667088293, 0.014285899402062981, 0.010895086039278296, 0.051512035481151075, 0.03548768243842548, 0.011199184640821432, 0.11227276701960834, 0.03335500857041728, 0.05281019445148207, 0.09580438941596978, 0.0592544149877804, 0.03933453549360556, 0.01655278325591597, 0.029304726612603957, 0.05476945665695014, 0.030581496408089038, 0.0436966248127001, 0.017921395502203417, 0.02557836769659433, 0.06287725627302163, 0.025953072791678772, 0.014069545638537215, 0.03098805160862544, 0.037142673672567454, 0.01866558097272871, 0.048746879422856916, 0.062007677531050104, 0.06087666745447825, 0.1097173351914652, 0.09708531140800446, 0.03329279840052609, 0.03847827135975804, 0.07455755370639025, 0.03402596369626061, 0.038587538480398156, 0.048879171316061294, 0.02219749528223709, 0.03851186048479811, 0.03304069418640387, 0.03313599169374474, 0.01855738829040239, 0.0203367002728966, 0.007884646822217732, 0.016558201412760442, 0.018005919898109093, 0.004790855802580594, 0.018297782160281655, 0.07657908353834383, 0.02308342425573257, 0.027675311223814086, 0.05141971805583566, 0.1667194708340591, 0.03357152800045667, 0.024001189928141334, 0.03900614424398349, 0.08046730151099545, 0.00580397452370474, 0.05025151058010036, 0.0324119505051884, 0.05237808638823129, 0.07617497981916513, 0.03785251159100764, 0.06781992532553212, 0.03675764937314295, 0.05440394844739668, 0.0513282165141596, 0.031350300114061085, 0.03074005745621699, 0.06961348271297832, 0.08763219244898328, 0.04820840771219904, 0.04981396712302681, 0.05700980801315558, 0.04129805331749301, 0.04669531128339229, 0.05273279658849201, 0.10506348894728769, 0.019562853793162974, 0.06336239677283072, 0.0518729203500815, 0.014115300239814867, 0.09315783142923348, 0.004725144610875437, 0.029138267197976672, 0.0017663764681914943, 0.05177089276032583, 0.03738692931590542, 0.05000450468111423, 0.040627780009902296, 0.01970481563119158, 0.06775271643193499, 0.03951242877050273, 0.043925313549416686, 0.050904945275115396, 0.0279886411848448, 0.005885898529912436, 0.008774169705687992, 0.03943071400205936, 0.067372077985877, 0.07942251846074097, 0.012087127467947862, 0.009688209317955039, 0.0511787029644174, 0.018994280572740302, 0.008120287806847164, 0.02466296349021216, 0.042347406082215815, 0.024694911271874464, 0.060959021906338395, 0.05864485031774929, 0.1702704262589255, 0.032817383386915734, 0.03786113391059541, 0.06613706764314445, 0.08842599743436422, 0.012846102265851393, 0.07314501780896418, 0.048808974679559476, 0.053934968572350285, 0.034884100915083004, 0.07455375391028582, 0.07600261769708126, 0.13274742440590936, 0.07962419876768705, 0.11291979721957639, 0.031032936700109034, 0.039469998990816456, 0.04811673380074002, 0.05798900244577278, 0.056240410589042215, 0.018487999876660687, 0.019865519810287703, 0.04401128393627944, 0.009733955300743542, 0.023465569979781588, 0.07194287263818326, 0.0015260516938137552, 0.044159184870941025, 0.019108046544715762, 0.07876048059833628, 0.06076768761680973, 0.1607805120969011, 0.1370069958389767, 0.09975246949902467, 0.08552281531475245, 0.1179233396185502, 0.23590010620893972, 0.15327766147111693, 0.11242594630006822, 0.20673647192457031, 0.12980376220037862, 0.13846657719583283, 0.20476675261893582, 0.09499890158974356, 0.1747967341854688, 0.1739426840457224, 0.12423973455424271, 0.15037313103675842, 0.17602152491529144, 0.13014456407437403, 0.09987779382255771, 0.3423200764002339, 0.21073324455609246, 0.12403924934445851, 0.18747771098729105, 0.17917765394574214, 0.1845494931143138, 0.1324774703431514, 0.08024901241785096, 0.20592521545627426, 0.12930588165838874, 0.1262814891073973, 0.16100355093517613, 0.15617204890135797, 0.10308287587136993, 0.09920743624529532, 0.1591283055923639, 0.127465232846237, 0.10211882316657614, 0.29134709868700276, 0.10560009523384994, 0.16730031869824857, 0.3894247697486032, 0.20825099710735584, 0.20080217100199194, 0.11311261388923853, 0.18055060608012063, 0.10661273323480161, 0.1957996474999574, 0.3000301843689334, 0.10021743890378745, 0.12177136861869406, 0.12890161706074593, 0.17253922629019908, 0.12098760704600042, 0.19806443323050776, 0.07757362654252399, 0.15410112938092602, 0.1193482478359534, 0.11347578553062294, 0.11300911541066824, 0.13391861962454935, 0.1678715138545921, 0.16162107908918014, 0.35932410268052933, 0.23171861445711506, 0.2007071301341057, 0.19092208826013152, 0.1632916410603831, 0.21072857141975435, 0.16140979203966357, 0.16428231532054563, 0.1792046202406768, 0.08446130090423169, 0.1031803758814931, 0.14849528099500364, 0.11948096490795575, 0.1786681135455447, 0.1891119910344001, 0.1160402418745141, 0.17585637168057505, 0.14234177167377166, 0.14244758373787328, 0.16140832115084897, 0.05895210137110084, 0.15582101209269417, 0.0757523827374943, 0.3877084263630452, 0.1343591661462861, 0.18698408989416015, 0.12941423713439895, 0.20155662971158184, 0.10366367777028393, 0.10895385962700653, 0.18039574906710656, 0.30018285037048403, 0.1855354023075873, 0.14484010696891816, 0.1970418437474197, 0.1826028790204756, 0.14126099015195526, 0.1857579508495908, 0.14447512736003246, 0.12995268969285872, 0.11981659568846227, 0.1419060515059579, 0.12831403528370205, 0.16213818843806946, 0.1830837983758219, 0.12482003849600593, 0.12030264017202201, 0.14608155245021467, 0.14562036751979782, 0.06369417413107811, 0.10518292205468302, 0.1337287217498787, 0.11542370963481166, 0.18624260871400758, 0.11000604308660954, 0.09075616110837267, 0.2227627708306236, 0.12302435904500947, 0.09858043158366796, 0.1284839995505829, 0.12967294502642848, 0.12703420879739907, 0.3085089390797, 0.20668244740415007, 0.10090737768839445, 0.15138081244884, 0.08715009331823358, 0.12754202549976687, 0.1390299429335902, 0.07188805138632175, 0.16281574724182007, 0.13666296107394083, 0.10832642595614157, 0.10103425717041378, 0.14509631741431453, 0.13881107161362327, 0.06281002056634714, 0.17150712199509147, 0.3576607725793316, 0.1213654492711348, 0.11452790770319202, 0.13256454389662514, 0.19015745590290717, 0.0655843735101723, 0.1714737358833513, 0.23217581573032567, 0.1597769062725767, 0.11666501722028179, 0.12276243358369797, 0.12486648640685505, 0.21936236700463682, 0.18854376829920277, 0.09795040853561894, 0.19982262033848994, 0.1698779594153166, 0.15010702273538037, 0.18914505538921203, 0.15916913807872804, 0.08208665050446026, 0.17374129485218756, 0.15372010789090587, 0.14977631790022697, 0.12431484181433917, 0.10892175288209993, 0.1547428659133373, 0.13507003445298443, 0.07893979879877261, 0.15546082819421447, 0.23344261872191585, 0.11366366093317348, 0.16585949117377882, 0.14905561302458087, 0.2167590470203469], [0.08805511128758231, 0.034774845285761746, 0.048512973627375985, 0.031438970960856925, 0.02156334876593563, 0.051061621746949615, 0.03722716550973635, 0.005327274876406356, 0.10847701585941738, 0.02372637312228401, 0.046547686140383446, 0.018617378720532984, 0.03279540432436812, 0.029624275292360017, 0.04910155131872143, 0.009523476473987103, 0.0414863309162038, 0.004246944388855369, 0.027696313524258234, 0.04734823269949806, 0.05567025731227571, 0.06502879888660486, 0.024122373546443643, 0.04432449515368189, 0.041735336304672306, 0.04430613202613689, 0.007325373909195826, 0.08791712353066092, 0.025164595947811202, 0.04168162204986138, 0.0527578323418575, 0.06383385111187255, 0.008825050392788986, 0.013322705673354288, 0.026180694750960798, 0.07064682040964404, 0.026848958992970087, 0.040280703875807025, 0.04128173564470584, 0.07091875097924663, 0.006635930687714849, 0.026788227372772755, 0.06163404495905965, 0.014865220836063307, 0.052897620405400955, 0.040419687547029994, 0.04808307189734713, 0.03636865673827068, 0.019365666591892802, 0.032133485205591686, 0.03679500765077049, 0.06813566846352431, 0.039804262304378134, 0.026590117035553824, 0.042219798816668416, 0.05105923155262586, 0.010000707115978003, 0.056865963514053056, 0.04151615471909604, 0.026516101450749466, 0.07536627442365693, 0.030194093405659643, 0.025462751622281732, 0.062428351732031, 0.007778865880438037, 0.010183644124246653, 0.016961489248299794, 0.052460663005589485, 0.018328525268683032, 0.04790286503491863, 0.03630504462747805, 0.015946271446263118, 0.07294683852383206, 0.04697832331481961, 0.08072117538822275, 0.07501323812551076, 0.016889226089622227, 0.06729533129762258, 0.013177108748124973, 0.034360797745325876, 0.04367872516834929, 0.1424655408388184, 0.038368988917359424, 0.021012410889529896, 0.07784619296510374, 0.07879613433033228, 0.03560281396212597, 0.04135300863474127, 0.01883962657302618, 0.10072609064199271, 0.015246027821464645, 0.011125920779792773, 0.05417781078346795, 0.06989256088291446, 0.0476232850773921, 0.06243196383659398, 0.03477027940173303, 0.019284032262681473, 0.03996097708060857, 0.07538575603957139, 0.028134642221454172, 0.050102816744437145, 0.020402279314434817, 0.02268431734503998, 0.031231813125252247, 0.04857511867979362, 0.06954042856851894, 0.05205941679436834, 0.05484358715494314, 0.015950566326688616, 0.057664154352800506, 0.06581233063292119, 0.08094176274514006, 0.08400200821098783, 0.012095112976948581, 0.013386961298003314, 0.03256781109338326, 0.032534176003067725, 0.008510959131883518, 0.0014299495547499149, 0.12842562365075275, 0.0373689032670471, 0.03295819034739848, 0.0111962620153903, 0.0638884310460379, 0.05566847232741214, 0.017088098684325814, 0.024143883380137628, 0.039988131067084695, 0.04308193501445555, 0.04191776865252084, 0.02322791801435092, 0.040884480751570196, 0.04054489312693477, 0.0400703706057562, 0.029817572682194655, 0.053155673292255214, 0.04096593888055894, 0.07005043628235018, 0.028388071767685395, 0.02678212739767567, 0.021454491502334996, 0.008692023055177302, 0.037166510498331445, 0.011771865050128151, 0.006254800987775408, 0.061002053065045234, 0.07466502818128756, 0.03823375907696543, 0.011434314261761405, 0.0756317928373333, 0.005367978564238237, 0.023829961616185405, 0.0901624582888138, 0.02511618110621649, 0.046686508933142315, 0.01731222153701369, 0.01025864892008324, 0.05665563407444185, 0.06010494878395431, 0.03228518210591809, 0.036192333941618283, 0.0474646091160755, 0.028200313193543304, 0.029698917154042475, 0.015642598981127864, 0.037050570751870834, 0.10992143633625201, 0.034266503813165816, 0.02003481949589426, 0.03357736176000007, 0.026043752704056043, 0.06008494239781172, 0.04467858099228433, 0.036677853654949896, 0.03701562182076516, 0.07790870573972503, 0.023993161326694875, 0.009374194665842, 0.04419509524239167, 0.07116611310911757, 0.04262822327174006, 0.039780628491914084, 0.014536237783519732, 0.03984822042947335, 0.005381841404033044, 0.03479750616656196, 0.02315553419682528, 0.01997531361637577, 0.019098547054454684, 0.062167797568103964, 0.029281328372176618, 0.023017280224350192, 0.041845917266102574, 0.008506547423049567, 0.032358408620160435, 0.06684542318145115, 0.028301568949715267, 0.006503689547835459, 0.04010581366357304, 0.0429437595659927, 0.07701266632084885, 0.007572908887654664, 0.048515398295656334, 0.09494952722302369, 0.04129323845488891, 0.01435364743003682, 0.03760235324021309, 0.15474810595473937, 0.008238444420238657, 0.04264351055626908, 0.08310312660591257, 0.07165391193402391, 0.024488465898039363, 0.034733047528613004, 0.0338150060645515, 0.030266038637848634, 0.009088857557564493, 0.029432038934300506, 0.03930420224224368, 0.02250518300570548, 0.014611423567628429, 0.11420349244989696, 0.06745583437863859, 0.003806071322140915, 0.04484046686200365, 0.07222646306599341, 0.08247465871634983, 0.04376417461542353, 0.033316746309039094, 0.06635249156745211, 0.02742504179027052, 0.06970641683907279, 0.03868691540593582, 0.01800029106708544, 0.025198119955377716, 0.06805891411439066, 0.04396489348202463, 0.03169996371012061, 0.01704077743324301, 0.014507622484328046, 0.02495689610500009, 0.05661778550054278, 0.033777946561214425, 0.012793805273700387, 0.03600173509649692, 0.04461303450948289, 0.05291848864045836, 0.023921430599124684, 0.037457102969769514, 0.03555773734866131, 0.030593751899657712, 0.05560894729569555, 0.039870934936428265, 0.047115985484373187, 0.04370683293429114, 0.020429071324366718, 0.09787672619906165, 0.04137936205933652, 0.013047117033913251, 0.07253996156636747, 0.052469312138254606, 0.008961128675559116, 0.03450323647308735, 0.04018803405004644, 0.09073305589657638, 0.01877376407895598, 0.043862689692046375, 0.017522805700859716, 0.0414188577222728, 0.0017106093371459736, 0.04747846381618612, 0.028017748695527835, 0.0314092026993392, 0.04080220290850248, 0.04239492651615893, 0.02552992029626283, 0.02720734641526736, 0.013471327688274606, 0.02468457100011649, 0.047353518706175594, 0.10477998278914921, 0.02652485400528437, 0.060523849491390495, 0.06394466956055934, 0.023725179940341942, 0.06572205483192398, 0.038198722045748465, 0.08470715384089178, 0.050592373741129716, 0.04964683738146579, 0.035880654900064396, 0.0189298142739121, 0.01031471219199199, 0.040514284083920146, 0.11299205463259451, 0.06353166773014012, 0.006585198430149186, 0.015726245248750333, 0.020290346207818197, 0.030164957166679447, 0.0416670931923774, 0.013574461317470959, 0.0106185024431456, 0.05385760901375644, 0.031299361012755864, 0.09705624603215726, 0.024521470881037177, 0.02844092608880132, 0.04184612410984213, 0.04865912022069097, 0.04419128395496838, 0.059131216558237235, 0.06984987446377355, 0.016057302484348897, 0.047283655317920836, 0.0036788461429457515, 0.03226888358532902, 0.0685438477704602, 0.03689282941782186, 0.007708528954085084, 0.02979770419187844, 0.04577451956368262, 0.1061928634261412, 0.032502237797504475, 0.01476000344771291, 0.03422574027471485, 0.04721748064302149, 0.025753899507464904, 0.06064663806389417, 0.03271971100700959, 0.06312524659499046, 0.053979033949754895, 0.03241447093445928, 0.04953571249760928, 0.07878768438052747, 0.07228541353176679, 0.023592324972513224, 0.09507800782880477, 0.04397152397300928, 0.04555398966335962, 0.022697670257560188, 0.027135611857257547, 0.04363778542967574, 0.030596542374921903, 0.03531851490298587, 0.034026856188692396, 0.09352422063989986, 0.057149477333070776, 0.027788085111927603, 0.04200811723187085, 0.05875231713176735, 0.19770777333647976, 0.11167019290188629, 0.13937410027269395, 0.24343740014779955, 0.16384939903453474, 0.207955363777376, 0.1621937144908213, 0.09370794384590081, 0.14514507124981574, 0.17441312331826458, 0.1029639790255216, 0.11831887081385621, 0.15344681368479807, 0.16201768280758014, 0.16484379648200928, 0.12022942514909853, 0.09804720374485178, 0.1420202905372266, 0.12797463535060807, 0.08320906124408207, 0.18114427825616253, 0.14698806429101577, 0.1849093552558653, 0.19083901368562253, 0.11432235865222831, 0.12348237237141979, 0.17736568746547546, 0.23771628617278992, 0.151651777747658, 0.11421044852824942, 0.18296830296035738, 0.15661262606661167, 0.2121358442931406, 0.06945593673135005, 0.08990607164319485, 0.24633445356401706, 0.23083001375198367, 0.12886211756737004, 0.1587319163785827, 0.14949102675722492, 0.14979700227418255, 0.1211649640613506, 0.13933360486501647, 0.1594059971431571, 0.12888677027677337, 0.16901794911151932, 0.23299041234197157, 0.16871796440212958, 0.14605360556273692, 0.09957023250359683, 0.23731192964459621, 0.16167603823686802, 0.15642401521965382, 0.12444011251171752, 0.1365798405341564, 0.22594514603336013, 0.27047193819476717, 0.12872956903471103, 0.13185413524268136, 0.10464557266283421, 0.20800460790914876, 0.11060215142225066, 0.09814971396999975, 0.11434004762239995, 0.13591319082244752, 0.10713592532180971, 0.15094337624407586, 0.14568341655596612, 0.11076961824249838, 0.12315157560571549, 0.15647027160852187, 0.0724212026163455, 0.22926901767571128, 0.16851429226658038, 0.16943814833798718, 0.16485233070148578, 0.1570424167138915, 0.1572096843512789, 0.16813903175775083, 0.15020178781161386, 0.10957742455385386, 0.1715802374265848, 0.13890703178701863, 0.07922136675446265, 0.1676564270089711, 0.18217469715783674, 0.11162839514473755, 0.14446126116860297, 0.12520656815820164, 0.1955646730118221, 0.0924655330938197, 0.09603867442497323, 0.09777980841576092, 0.14397490258899429, 0.15360700266976512, 0.1574866098141478, 0.13628547891013085, 0.15830008793742428, 0.15978518002215894, 0.15833362726674927, 0.1768621531946044, 0.11405716965635938, 0.07920442855045681, 0.12425530912174333, 0.09000693477930562, 0.2604634897603143, 0.20646141571623666, 0.15195741618592895, 0.1585494035915021, 0.07749233695287859, 0.12327289328940454, 0.16427013452254957, 0.23006786351963399, 0.15412719169211003, 0.22592806227264867, 0.08671060399783236, 0.13354499854387777, 0.08440154604613782, 0.08222366532971782, 0.14446179743014997, 0.17301303634960807, 0.1685955129083126, 0.15101184918274804, 0.11609216731402183, 0.15714084369040307, 0.18556480476212117, 0.08989291791353496, 0.16549635017591138, 0.09821884574428683, 0.12085246147527812, 0.17573320006410922, 0.12665079711305519, 0.14717642998983785, 0.18063939567054474, 0.1695377857334191, 0.11680043092177761, 0.14078497375932433, 0.15087663466411252, 0.14757919305514905, 0.14503552067664363, 0.14826251284009026, 0.14012270607054234, 0.17411779642345446, 0.14782751279492534, 0.1253482178154011, 0.08198815458003553, 0.1713464120703359, 0.2270324852678084, 0.14553367701028624, 0.09517314062724191, 0.1581047814820082, 0.14522984653951662, 0.15380598634721773, 0.1686205333399196, 0.17864494704671446, 0.1705234804220738, 0.13114587163492558, 0.10314808527548468, 0.19411264528189937, 0.3308723326171598, 0.14773334526727278, 0.11676799475906358, 0.20495282005398505, 0.12330230340481767, 0.08828649282335274, 0.09715731601200758, 0.13124423732440318, 0.19564523481793944, 0.2361247844753727, 0.1057019772669, 0.1305968930283862, 0.184169176425184, 0.15598446461221865, 0.14461974943837813, 0.10186235225128551, 0.13836317064781345], [0.0016254585446609606, 0.06256566533157903, 0.05106591183932559, 0.02552082491738181, 0.010731940912533431, 0.06290771209845139, 0.044081277559481324, 0.011600180915857275, 0.02903170628292907, 0.020030255527085355, 0.021735134406856472, 0.10515237812914195, 0.04884164449909041, 0.016893665569143432, 0.014498061707033025, 0.015090484202148454, 0.07071140928254013, 0.04319416306492302, 0.03313427948723397, 0.10553856305177174, 0.05374882835894824, 0.04610635054808471, 0.03836439238981374, 0.05117648513987661, 0.02279291413874636, 0.03828079304507664, 0.04424607456331292, 0.011797879480816906, 0.01667455101626054, 0.05296073072860318, 0.06678058916041929, 0.050288141074199835, 0.030216516799203334, 0.06590404667921605, 0.04502457311196674, 0.01196448253692999, 0.03385680382170024, 0.08541809875638255, 0.0676094503292153, 0.01509196370945222, 0.08829647494900612, 0.03346588064525877, 0.027846641042419983, 0.07146461926881345, 0.03353977748643487, 0.05701067752294964, 0.0336767501768566, 0.04152989450601801, 0.017928271141323834, 0.03001886036907954, 0.023852632073084676, 0.03684010341643326, 0.022572506812491247, 0.01812989207645578, 0.07511246183346357, 0.041608813053537766, 0.038393836979183464, 0.07896613690160936, 0.011287278048844348, 0.06939867931988931, 0.01531274258835061, 0.06691114586447516, 0.020564764647954897, 0.05573082039312971, 0.049013186907095295, 0.026220012298454682, 0.033762751207236326, 0.03746629602486088, 0.04585960894943245, 0.06305750143984634, 0.04200698342174292, 0.04487274597669321, 0.06939743825745198, 0.02475274707971802, 0.03056596972108368, 0.06886860010244193, 0.06785742532942565, 0.03529714871077769, 0.048582024962431004, 0.0371750217351702, 0.055714050728467204, 0.07046821467097729, 0.016999351228737546, 0.04700577990602582, 0.07875375434636109, 0.056869579449055664, 0.04099089419469237, 0.0816634941786047, 0.04995302740304221, 0.062220791700266065, 0.05812795164303915, 0.02505729767313648, 0.02754498243091568, 0.075580480268165, 0.020989897480655103, 0.011763539589611034, 0.027651074117109663, 0.03765151693275379, 0.07823844530409382, 0.03561694062344971, 0.019513722659359058, 0.004630527964177272, 0.061678543176141486, 0.03649151808912716, 0.011993485668133344, 0.04991777203676682, 0.017753572451070915, 0.03416554108562489, 0.06940869208905967, 0.08664019285671173, 0.04701835140886326, 0.03535627920721327, 0.06975726209460728, 0.041485809976415294, 0.030039753501994476, 0.047179919352094014, 0.03739642497572688, 0.05250190534899312, 0.08315395653968857, 0.061129817378617106, 0.04635178596682606, 0.020111397644805334, 0.030298649085565444, 0.031951642745444854, 0.04682917748728106, 0.060272994000584855, 0.03752940251762348, 0.04581565082433724, 0.030869687193884488, 0.07867272522660994, 0.05028180169662641, 0.014462748884163318, 0.05247657465177679, 0.038518536941058217, 0.04986778863014714, 0.0517338753918246, 0.0386708045768882, 0.026591729650634433, 0.0277459541065318, 0.06014499219975645, 0.037664337414166624, 0.06531816561736407, 0.08767816538531935, 0.033331853562905904, 0.04817954151921215, 0.040959017276163065, 0.06882649591012348, 0.09605866931979695, 0.03691755873601764, 0.03326909180970923, 0.017544928404893127, 0.029897226674121716, 0.0350333271818536, 0.018646610720503717, 0.020263533130468383, 0.032835554992479664, 0.03737433099999063, 0.05654809065163136, 0.017073598555138996, 0.02840411173360002, 0.05717663898042614, 0.09118140119338229, 0.015880376393456134, 0.037572157884677576, 0.010097889199612603, 0.08527364521738022, 0.014398810228392964, 0.02651338566905789, 0.0417909964228109, 0.040021681887728554, 0.025626037517682682, 0.07784768683655609, 0.04042739056110863, 0.009695717937222893, 0.021669231693170244, 0.022766430479203983, 0.020617228264229435, 0.0657211814916903, 0.04453360268305387, 0.029034347371048028, 0.02400663298284335, 0.01336648089495758, 0.011598477327835657, 0.07159324543130013, 0.07072706811971242, 0.05648472751941412, 0.02024916706666831, 0.10423682645083436, 0.02288390240151315, 0.0205079592283695, 0.031928133422268495, 0.01967039530075366, 0.037105166007794683, 0.13778845148701824, 0.01710471513140346, 0.10183039106308453, 0.02077023134446673, 0.014501356842717337, 0.1053296585356997, 0.01835490742157544, 0.031233933273582693, 0.024178123679913344, 0.016650953592972893, 0.019799720518471255, 0.011028277128183795, 0.036227083689863646, 0.012429140718473543, 0.020145840957880985, 0.027314397626586502, 0.06024310124977943, 0.05539944140060295, 0.04403793230472554, 0.018013333713996316, 0.06982934330740283, 0.029954179565632538, 0.016751703731114828, 0.038412180954530355, 0.022130512384577625, 0.018680661413518172, 0.04134278519139175, 0.10733435741595684, 0.07363665473437117, 0.05447759247955777, 0.03257521916361105, 0.06327549175870034, 0.006596926278660015, 0.04745392218953179, 0.03969403374339304, 0.026167924065263044, 0.022957054222182884, 0.025582330286382668, 0.07460515841000503, 0.05140158475466794, 0.05859230051658327, 0.022402609578303756, 0.004700083002042507, 0.035597865034135125, 0.03780758053424858, 0.02100193655238517, 0.03309984766547719, 0.08321279209227332, 0.02204781510837136, 0.03230891167937267, 0.013707105611120502, 0.021957997044908906, 0.05084733163276988, 0.03645345118016966, 0.07858032736206248, 0.05231363158072195, 0.0459677345990654, 0.036546029075379335, 0.024913018419136925, 0.04786553740080807, 0.07916858329647973, 0.014666870138758134, 0.03356786226973899, 0.026900300290435556, 0.026138289869132064, 0.05742244595181077, 0.06421062081391293, 0.10485025603444346, 0.1913361894267221, 0.06398488151570482, 0.03628487353243175, 0.010132047144936459, 0.0917405840910731, 0.024797798795325142, 0.04073340055202285, 0.04252834838905162, 0.04403748031285021, 0.005247774580869103, 0.053335091084121704, 0.05072527850467352, 0.033422638812372764, 0.034566791127285654, 0.02755861305030844, 0.030427876627072695, 0.05640777015698053, 0.017968699516307925, 0.04977792651662904, 0.053497402132639, 0.022459886141962582, 0.04411810340600149, 0.022214037035742117, 0.028130108896162243, 0.014280549235521786, 0.06563245318830013, 0.049063281396464, 0.03700832100284677, 0.017218029111503594, 0.03021036511317136, 0.09245101572765459, 0.05700822604159194, 0.07214224702047725, 0.018229851228815895, 0.05102733931233806, 0.03429886336708742, 0.04038681088375949, 0.015457795591153687, 0.017601682113543633, 0.06294891613745882, 0.08776900043050129, 0.007403676713546439, 0.08577316518752806, 0.0027981454801310097, 0.02991823855066492, 0.03425711923609338, 0.03761549547855412, 0.11116410755822737, 0.02809664234519005, 0.029777207509464318, 0.006645690647870183, 0.021469367014604713, 0.04663985417855363, 0.00790173489217376, 0.03989091833993312, 0.06392160265315926, 0.004922579833111096, 0.04430450408929779, 0.004005768897777965, 0.029386228791648344, 0.058596843417974255, 0.020562803462868737, 0.03335019370781318, 0.0035054572236408754, 0.012187817276665762, 0.02122826190785535, 0.029707694606434916, 0.032600048073236985, 0.10085763559947092, 0.030661772846454577, 0.04252101309717663, 0.029620967707746935, 0.0728321398398088, 0.07147039557176252, 0.012569518669718697, 0.051633196116815654, 0.028027682940685944, 0.007629849809041668, 0.028806572194181146, 0.01334050093822542, 0.05228249393703957, 0.06135797368422632, 0.02373929127990719, 0.04939746044035401, 0.028789358198522564, 0.069951610940118, 0.035884397239574505, 0.021314257192575646, 0.04738872044629628, 0.051293436122397264, 0.030813418035846085, 0.09803826349877542, 0.149882206573121, 0.1619892915891063, 0.13013687255161424, 0.06561458801790591, 0.12062533172748743, 0.1575462420981738, 0.20223066451088076, 0.09889935398654592, 0.09973735458427861, 0.049084141970642155, 0.2629933572344242, 0.13859203175431298, 0.07339798004156159, 0.115138272935104, 0.12419326366075586, 0.14183603106967865, 0.19250897810824458, 0.1402349839167249, 0.2488835651667849, 0.15633732471014225, 0.12431976009881306, 0.1332463161839593, 0.13725070372944878, 0.09267142688434932, 0.17951519228518012, 0.10792624460713518, 0.12495836333161402, 0.09355053576009889, 0.08952555577120475, 0.2523675185417937, 0.1432880434778429, 0.1419290341436863, 0.13616408461764937, 0.20442998036742213, 0.13111536601378074, 0.19929356001798185, 0.2086659562924216, 0.17319260735905942, 0.07523048533907822, 0.12908846590547793, 0.10477621363656175, 0.1645253184101274, 0.1755084605106423, 0.18688298160991362, 0.17266933866325887, 0.20177403014273415, 0.16696685594656777, 0.14498000994565027, 0.07803904793916211, 0.11951988217450919, 0.16873927696818308, 0.11897772941137515, 0.10577126991965118, 0.2391987122715481, 0.19874082758061348, 0.10921884177913589, 0.1352390334490807, 0.16676764244273787, 0.11588821172594063, 0.08991934794692263, 0.1690802780250388, 0.26247211101074375, 0.2737752786807476, 0.15733064963452278, 0.12397044698797888, 0.1282788948306153, 0.12457924940052534, 0.19088306374126868, 0.0934866440272139, 0.11087536901956606, 0.15647191103667984, 0.21971007899170925, 0.11607758866082277, 0.10456403792505303, 0.09171255293392366, 0.20834170191759066, 0.17579857800756732, 0.09997291129923637, 0.08864351277870518, 0.16508375054165242, 0.267622887847885, 0.19377309979209978, 0.11778484624359878, 0.1930597187170098, 0.32736983991438345, 0.15962428623630157, 0.21016027207576463, 0.17374068198184814, 0.29209642460749996, 0.213766033430734, 0.14078955496511153, 0.08698623477210922, 0.12814061596028267, 0.10541027396797173, 0.14680674660109705, 0.12615988797117628, 0.10314083808372099, 0.1274087491835798, 0.15276257459434772, 0.1508292751086335, 0.18703402350506476, 0.10933867325225186, 0.10517339192090497, 0.3134306556274814, 0.11701641409027001, 0.24012613831268204, 0.1279772017451544, 0.13988866620967466, 0.1170212634268307, 0.16475485367400033, 0.14282037744358664, 0.13837398780930427, 0.11090889302713257, 0.09635326077019978, 0.15606251364994436, 0.12901049347654467, 0.15468042974750842, 0.10286306992413537, 0.11233617611710103, 0.1627182855360931, 0.1061427689367725, 0.18386974329909972, 0.10717429866593693, 0.15364461758684728, 0.12990862431545414, 0.12488189243501234, 0.16450740727445773, 0.07978921410657706, 0.17994148957152523, 0.24190749191949446, 0.20117795245061, 0.11075191395056826, 0.11401121970266105, 0.15197742640251113, 0.1306174088629984, 0.11135283331837385, 0.11984162378094851, 0.1245703474588452, 0.12321080952402085, 0.12160681293255861, 0.22682352712558163, 0.17912686231636232, 0.10923952615309147, 0.09412116401137845, 0.15311909659254938, 0.18243510576505817, 0.23471326747488594, 0.13661984564556232, 0.11870220588940768, 0.177633419873253, 0.15669020012982432, 0.11243510871164261, 0.22871646909944474, 0.21778537501250544, 0.16239778499209112, 0.11806974668175944, 0.1712533630310528, 0.1374257241766299, 0.10644679859040246, 0.1423936817915209, 0.10237315669655801, 0.08077952064453595, 0.10903114257680793, 0.06591278774243209, 0.14335267065513518, 0.16962354161566304, 0.08202077460385139, 0.14321664408329995, 0.12753466339481453, 0.135845591224009, 0.27461632064753966, 0.0945269761066283, 0.07039195827899442, 0.1741458352414831, 0.11455495060691911], [0.041547920554876334, 0.029932018557202913, 0.014942215545283211, 0.011465190477939624, 0.03832917532793457, 0.02313695464944167, 0.027076469869503093, 0.051218221609991406, 0.010904218764945624, 0.09208010659823496, 0.05386885518448488, 0.013276326710418349, 0.021590071827954343, 0.024234145774596164, 0.052317607577048966, 0.10838838714745738, 0.10356125181480762, 0.06321625784039497, 0.011175736604679016, 0.019610822388541796, 0.060374879864074533, 0.07673594004084026, 0.043943017841346806, 0.03753184250766232, 0.054048870524932305, 0.052166887438826026, 0.034760837368066275, 0.03448282789078451, 0.01559707995188693, 0.08110137716416391, 0.06778670775313532, 0.013760135174849102, 0.025327567747163198, 0.017468465169170694, 0.03502388897862646, 0.0752264557165965, 0.03490805265403563, 0.011206290106319133, 0.03949008198575147, 0.029206144503287734, 0.03322035712640613, 0.029785690018005913, 0.0729063967423093, 0.036200216986359134, 0.04993195615468487, 0.04250000313585324, 0.011826512016986888, 0.027781485264459928, 0.020291631320311178, 0.011690708568259593, 0.02966618221703797, 0.01784031275629757, 0.07080894759705952, 0.009024037900681217, 0.08537251652488786, 0.033712871222486424, 0.026598118823922934, 0.014780820929445328, 0.021798346236708666, 0.12737067461374307, 0.05343219272852425, 0.0624779635860074, 0.0111410309064893, 0.024973820902467258, 0.03905485977508849, 0.0067586910107263155, 0.04496720078731737, 0.02660368062225321, 0.024980225397514242, 0.029297795432109027, 0.06135251913820544, 0.019257207694012794, 0.12375076361481221, 0.057236991387100956, 0.04681656001916817, 0.029220841900115053, 0.011291017515524741, 0.04469798599940635, 0.1336917809901699, 0.027965254435736327, 0.040167924242034074, 0.04590887223340331, 0.03285943395307949, 0.050095741922456416, 0.10034090163366449, 0.10071061566592225, 0.02976449044992126, 0.016718467006519917, 0.06434884222765123, 0.0496997970396713, 0.02955912142961977, 0.011672558987723484, 0.05464826154732897, 0.023440480600261403, 0.09443693779288762, 0.03328526775623041, 0.051775768909963875, 0.02980945406541709, 0.05413028651908521, 0.04844062428380694, 0.025664393624831593, 0.032060007797554135, 0.05973634174874714, 0.06235368114205138, 0.038207838492047404, 0.03523228787666848, 0.04176709064913373, 0.020583303975722483, 0.03651532044093456, 0.09366577836654841, 0.028718290137006875, 0.06824112046630153, 0.016634909796618646, 0.0471895452468626, 0.0786200643426949, 0.025956707878879486, 0.07015739747833821, 0.02082854595726296, 0.012170370581800179, 0.05127586972629351, 0.036637270147161144, 0.061035600055249474, 0.03319464338522765, 0.0700650455790662, 0.05139929798221396, 0.08019945419002926, 0.04120742894649025, 0.011576017545115565, 0.04675153064571562, 0.027179811300048907, 0.025038769836687756, 0.03273875595280721, 0.09156801512524967, 0.020683828117926756, 0.042212620572817904, 0.026059352169414202, 0.08243371131679705, 0.04700190733156858, 0.06180202505821663, 0.025314496371955163, 0.032343351162008704, 0.027406050470627608, 0.07851478854014028, 0.024218262856706016, 0.015513301534097523, 0.04353649328432737, 0.03911707760585893, 0.03579275014119283, 0.04339915670214161, 0.022008643117583087, 0.007797358285320262, 0.06473942449496639, 0.05186531692743302, 0.018103961915438695, 0.03787878457637083, 0.044913643580530925, 0.048963732101143374, 0.02176545233645987, 0.020437969435607235, 0.010332013330151959, 0.06620085212372004, 0.02365229816566552, 0.05340253746497536, 0.01543893067601828, 0.005447549244103533, 0.05658674361785093, 0.045381206192917405, 0.03666472290792773, 0.049638318483747786, 0.07296242075221193, 0.018138458854669047, 0.04461301535728478, 0.0690686869465055, 0.03695426966934916, 0.04555367939775029, 0.030875233670456276, 0.03245764381943211, 0.08571564730617308, 0.026184375803436966, 0.02528102790576316, 0.05329461482864234, 0.039346478804345095, 0.04459496632578873, 0.017105280121247617, 0.018250830546622316, 0.023558680306098635, 0.0195863037445252, 0.05725162366645471, 0.011639473565493622, 0.04397984368786697, 0.023626557611409697, 0.018220803730430144, 0.01641819884459819, 0.042366914511207616, 0.01617743656219494, 0.018376583879392956, 0.030501675792038444, 0.053104988915184816, 0.03609974072465012, 0.017745224007916068, 0.1011513077443646, 0.017004821096516905, 0.03873098078334043, 0.017332371564642075, 0.0389173393318009, 0.09927141990873123, 0.09585572496777582, 0.012198610497908968, 0.010699191611380348, 0.008119769739888368, 0.020290210227211638, 0.05773491023348705, 0.08481311146169902, 0.025104643822076823, 0.03716875896638921, 0.015047260563850645, 0.024082745733340422, 0.06382826250046492, 0.054590452552562764, 0.04810537654726256, 0.07128687154862189, 0.05782382239797904, 0.025024214166126428, 0.040361721504239306, 0.016890915313495264, 0.031924270423910314, 0.030234443256631497, 0.05197999645925818, 0.07325387890300444, 0.03798802105349399, 0.029695856632784973, 0.04749842806749287, 0.03458250742105227, 0.04313152388579423, 0.04598873689950955, 0.058487591619092616, 0.05090923536749137, 0.044261250765092915, 0.03342461531921741, 0.01909271904057072, 0.046981724745203415, 0.03420719328606802, 0.025180122634816556, 0.008531268122756194, 0.05789491535735227, 0.0387313140315875, 0.07609576632779452, 0.024740991460519935, 0.06749544112432389, 0.060995234882519136, 0.068689925415862, 0.05258226414181052, 0.044828676768848975, 0.04932535624492073, 0.025680843447785706, 0.022576819887504946, 0.024192562522066217, 0.04470273574453689, 0.03313870747543631, 0.026566642186334057, 0.05562897283403624, 0.06195200209115302, 0.013000659546965073, 0.07828864704577193, 0.05396918588948827, 0.03465802453818821, 0.053200562214178425, 0.021477077689562595, 0.12533085060215768, 0.05785545033793296, 0.04120149176507708, 0.04725554372153936, 0.031184413350157203, 0.021069495931207653, 0.03290551797216458, 0.02658609890439097, 0.04810256117414083, 0.011417075368245284, 0.05495337904581139, 0.017136467560645074, 0.11978323255935985, 0.037491707161309264, 0.03403986436164668, 0.0683279718542772, 0.0327325085057847, 0.03431819176541702, 0.11170960812559051, 0.08670360195420443, 0.02947577297867787, 0.0270448649121869, 0.04454052811788936, 0.053232508080620924, 0.04586415185082344, 0.011012839498899637, 0.020101969017677253, 0.028236733013463598, 0.0711433909412834, 0.009861268580049999, 0.014116310518265012, 0.016463118410038374, 0.029745466571541566, 0.11102631898416628, 0.08751963881114799, 0.061674842971467206, 0.06712807898199366, 0.046850899910374035, 0.011212789404746747, 0.05050445366049967, 0.04625603646760987, 0.02590933108642217, 0.05297132572459598, 0.05442022781578764, 0.010334225409033318, 0.0760236008453273, 0.009537911485700358, 0.030127853613286733, 0.03210167531975575, 0.004189923507041268, 0.041429445057386355, 0.08566080307167384, 0.014988453739563064, 0.10382647911507277, 0.02896792946323272, 0.07115491290366457, 0.04425489989620063, 0.032942922215067574, 0.08183742678093334, 0.038037066002406424, 0.02272026027522741, 0.04997102663882318, 0.03648857631149792, 0.04600162249839595, 0.030441566618279587, 0.02604065770884195, 0.05075101522848972, 0.023435719363812, 0.04955057843377994, 0.03660799792757438, 0.024420111702995437, 0.04530671563359999, 0.034731300848145644, 0.07323540086227079, 0.04035609458843547, 0.0260542327868602, 0.009192977524963359, 0.04817439340836099, 0.023265787655667915, 0.026233554817736152, 0.013116218164683351, 0.0524176241860034, 0.055609655927025506, 0.08941168446213969, 0.11646503762852763, 0.22106073796749118, 0.1780887978572038, 0.17976326687682062, 0.09952110328501272, 0.1747173981200303, 0.1097887805512836, 0.22565413987444294, 0.10180565408400952, 0.15344217119197692, 0.1362313318156427, 0.10865146940153454, 0.21550638601183894, 0.10536830001060041, 0.15546893340445336, 0.2321672661890907, 0.18159550404356373, 0.13790063740264985, 0.11371829066305392, 0.12701441308543568, 0.15462144097733885, 0.2959905414571685, 0.13764268027678614, 0.0939681685920204, 0.16133232522876034, 0.18094572358794753, 0.19526094979336187, 0.10679365255899968, 0.14206961127779177, 0.2634278516615591, 0.14978014833984837, 0.12473890212394538, 0.14957500531548454, 0.0599737064312062, 0.2955656690943626, 0.18439673518221225, 0.20656473033370512, 0.15688935234662027, 0.1739553704617485, 0.09628808967048123, 0.16467752475892344, 0.09808909343255144, 0.17139812300522483, 0.14381554097898547, 0.16168748359045676, 0.24412211421276295, 0.16632816844409512, 0.11873009148985149, 0.21653927171662932, 0.1435082324690396, 0.1269922961270617, 0.07717945132284396, 0.13832719515888922, 0.10993889548004636, 0.16726287232050974, 0.1316711934463632, 0.07737207647052503, 0.20358248794030762, 0.16143701880449252, 0.20606715622688496, 0.25323943385193426, 0.18291145923637575, 0.1598477540838142, 0.12396484688525239, 0.11797127373997243, 0.09581540576032094, 0.2123567993722616, 0.15070880012166116, 0.23850736388516044, 0.14523707840952182, 0.11563822957536868, 0.1391119143414882, 0.176016652596093, 0.1691441544361653, 0.17916910440450717, 0.12999153035061975, 0.10863799391494644, 0.18307031522835457, 0.21211103836615242, 0.14566855445023508, 0.12269419813228231, 0.09379503272113301, 0.13752289476894564, 0.18648237891254887, 0.1802286806125795, 0.3781861986123747, 0.0859227208721061, 0.13684740440259058, 0.13241416083708887, 0.154175685057717, 0.20301460228379697, 0.15850034332083118, 0.1971123544799705, 0.10781323131654533, 0.261838311149228, 0.254153254171533, 0.19554303868884043, 0.13669219498913135, 0.09639551818010308, 0.09296109238939901, 0.1952166086243045, 0.12433982394154995, 0.16483849515357327, 0.1426649841690256, 0.1554486780397354, 0.12140083487235731, 0.16739459347821053, 0.17765863948772032, 0.24620340656368966, 0.287831184123793, 0.1848640794595403, 0.16529485373006714, 0.1495537693582235, 0.062003751330438166, 0.19514988236609968, 0.13700511126268294, 0.1609464927065757, 0.14609946358588435, 0.11909097252834229, 0.18634475887783114, 0.1954275585951344, 0.16910940468791993, 0.12333879217265115, 0.1324614131402585, 0.08515479433680735, 0.15169026600497384, 0.2135325451531718, 0.17372045726064714, 0.10379898421947034, 0.0961679211186786, 0.18862089803141935, 0.08644427353095624, 0.12141463211587361, 0.15809612468846385, 0.2106632547633302, 0.1668347977101803, 0.14865307978564693, 0.1540224521511024, 0.1220255719137288, 0.22163795457491953, 0.13310413026521284, 0.10816986822793562, 0.17622795496736804, 0.1683737304542334, 0.1526808176910685, 0.16474166163994422, 0.17040611575207404, 0.22935624444676986, 0.09300505817537347, 0.12029749972205009, 0.13603484558482326, 0.15499052681749867, 0.14079836497624076, 0.09441662880201494, 0.1793758102482365, 0.12494125658826483, 0.26753062021828466, 0.1457071652816188, 0.1630547360306786, 0.16493444000521015, 0.15745187538766092, 0.11990847261322123, 0.2342549323915474, 0.18817554047751814, 0.1573233105122082, 0.18519584149602922, 0.1414452496195032, 0.17379539598140026, 0.14174082166244908, 0.12563150180804153, 0.14018356409524718, 0.1962613380484043, 0.18947284909025316, 0.10950066254384096, 0.17192088608299533, 0.23982524961954166], [0.02039436179573738, 0.03572765948070634, 0.037461504144894506, 0.05614193381681558, 0.08683390584924529, 0.01895226448053314, 0.06708372249117783, 0.09110515246227865, 0.053043552494097146, 0.036350986920297146, 0.07839426758789247, 0.039014000475646994, 0.04428520633448516, 0.09386597246292139, 0.061222843435262485, 0.06601937355533724, 0.03113148242024885, 0.03563941381270847, 0.05382344532277315, 0.00664542874156107, 0.045044560345911214, 0.1250496197251543, 0.0753378295790284, 0.004120787423509624, 0.0290765090199608, 0.028852073986443783, 0.050766735352695956, 0.03740827252547588, 0.04162135774329786, 0.05111731633904481, 0.013481367270522302, 0.0628247945719669, 0.06430227174273422, 0.014902077326100441, 0.09861126662262025, 0.020409597369331508, 0.06905763995863738, 0.09548640164035944, 0.028034114248810277, 0.04556331678383774, 0.11637922812012896, 0.03628953134701137, 0.06375007173647323, 0.03713875513283476, 0.0074743358756325425, 0.06697815557521197, 0.013166725383921257, 0.08115691853867424, 0.06061813576267131, 0.07621848595238502, 0.03325193527064497, 0.03417231713331515, 0.014659131693112996, 0.039506828667776245, 0.055340310904167356, 0.028918557011732654, 0.03113434184342623, 0.04606136586517096, 0.034552461452661984, 0.021408654546605486, 0.031938749485679215, 0.02830870505872994, 0.026838787260555455, 0.03568855835305106, 0.026765194939329263, 0.10994106350887208, 0.0400369385287406, 0.02647407961288287, 0.06263111222295031, 0.028458569093697497, 0.020127876196056604, 0.04616337430272852, 0.0583046076879386, 0.07146857994338197, 0.0871521387729914, 0.030339818650616274, 0.03778048017392716, 0.05094332244968222, 0.0692762584695893, 0.06086686535948708, 0.07044969066496819, 0.09145894718746986, 0.00136072070275869, 0.009982229075244358, 0.019230821710680763, 0.0155568593782523, 0.009568361565470695, 0.057849156925635, 0.052483017451219985, 0.023537068965754682, 0.05787686632585622, 0.015214743663466748, 0.010071459166224926, 0.020812971389762337, 0.07700525058974182, 0.06265604455444602, 0.009702227769359466, 0.02770876053780798, 0.05173107917090097, 0.020089625425997282, 0.06080977265693008, 0.056139869209859646, 0.056405035223090844, 0.036157729750078534, 0.07626194612032945, 0.11684717760691721, 0.04908082864036964, 0.04711896556639864, 0.023419156542889053, 0.04653561259469679, 0.0854919879366794, 0.0144104317822043, 0.011119843787333418, 0.04491680369321858, 0.08230863214139977, 0.032276651716881224, 0.11727455507723555, 0.05586659798638956, 0.028359299420469233, 0.013097200031963088, 0.035112211255416755, 0.05080567177144751, 0.04055427387356758, 0.05979279476788737, 0.056958518426625006, 0.032633338423986594, 0.013113053263946167, 0.038166071378415635, 0.048422644200224074, 0.059262795989672025, 0.039082890932237914, 0.0916700886802808, 0.020964463361568993, 0.029923064904587886, 0.047350576928546356, 0.035922127069845315, 0.0674630509268853, 0.032399976550931894, 0.04301677540605588, 0.06769959589526539, 0.014872114669771926, 0.041851007920359416, 0.07221982874456914, 0.017097138521832325, 0.046363775242841056, 0.024557634061502836, 0.03032111269872516, 0.030114144469881733, 0.10653714333931286, 0.02164938810071157, 0.023412280903768637, 0.03928833656133183, 0.08311703110173826, 0.09956865436247281, 0.010041089525686638, 0.06177790477992066, 0.08357704391763096, 0.0561622504685675, 0.04345455251994633, 0.029087171048646974, 0.018814891509170976, 0.045944943483318054, 0.005478953103339601, 0.07811050095985975, 0.043059844869158925, 0.14884420340099644, 0.023265900653636745, 0.057897849474102266, 0.1266189584989221, 0.04007356519240045, 0.03840095393600003, 0.05078455455781472, 0.05167122855181656, 0.054502348610830885, 0.018733826000243425, 0.018496783074712562, 0.029292379190484365, 0.03240422450847203, 0.059911718426813046, 0.0565875250275337, 0.054329952014790434, 0.03337987961487905, 0.033847128131216576, 0.08404347655032912, 0.024969913854053425, 0.04339233851961551, 0.025967519294710893, 0.0451150902306601, 0.028054404087484847, 0.05459019208266851, 0.05063903998703726, 0.054668627994795965, 0.08702512905602494, 0.04351905712317075, 0.042242720167362885, 0.05244961601772136, 0.03201083261369458, 0.09040625810983682, 0.046780936930689125, 0.03579003818994088, 0.09422850059044939, 0.06360132810509493, 0.00787614516147803, 0.06272808746284535, 0.04987274138857761, 0.03748878836631775, 0.07197272708459247, 0.0015463111283738288, 0.05522248658141302, 0.02099838956529575, 0.08731392122084096, 0.04635122289220172, 0.024756238525432926, 0.011958790503652587, 0.08535126524586832, 0.05068767124847059, 0.06545220036059618, 0.1031120101951303, 0.05689382230141952, 0.05212022119291848, 0.021191830596616192, 0.05483802918705249, 0.048567273939448985, 0.050163586669030695, 0.040849324976724964, 0.09357713433282991, 0.038706864335484086, 0.033636120703792384, 0.01042126544616035, 0.04574433569946597, 0.04782289694694262, 0.014362403815011344, 0.006179854127338097, 0.09707330681023099, 0.03381641949677179, 0.021100198819993005, 0.024499070470131213, 0.08729461580514909, 0.04373723130312659, 0.031680279080906225, 0.03292816736164593, 0.030155151241248658, 0.021606425889917923, 0.0341646830671497, 0.00813120455976816, 0.03127751984603463, 0.018460110445777257, 0.040515800938010216, 0.08515965899512654, 0.019099341870676127, 0.07182399111409342, 0.02435115612893095, 0.008517581961988922, 0.050734666912185575, 0.009766298575296758, 0.03744278095602509, 0.02289386729018823, 0.08861565016089909, 0.01496209935735791, 0.034625580714594935, 0.0256429182650942, 0.005865132280309955, 0.017796046280812834, 0.013326477698771464, 0.013524652195854053, 0.025268441081167232, 0.09020950374824387, 0.034406441263854504, 0.017527630139562874, 0.038497821923585675, 0.049942968668596405, 0.07273531398705899, 0.05076123101096, 0.052270098634424715, 0.05480214179823956, 0.04671130719925127, 0.02972184999605581, 0.017835907750732957, 0.04715828885955196, 0.027174029251440402, 0.06983020898675726, 0.05614695552315924, 0.034247512493522904, 0.04477125464848453, 0.04548782647977914, 0.04075481270950648, 0.011934088956144069, 0.027010913810602603, 0.02992430788224503, 0.014153882342901443, 0.07791815926471064, 0.007384353103266368, 0.06847906737558304, 0.12186186658518931, 0.022387441037403002, 0.036855758423165935, 0.045749208018664396, 0.07405102403173525, 0.0383947026585379, 0.03683343079061278, 0.0584912037236556, 0.026356804958214203, 0.039159258406969814, 0.07613418563719719, 0.018811421130873987, 0.03186248734803691, 0.02054821714879044, 0.034160281892024705, 0.06365661667059026, 0.023195975978348046, 0.011412387867758592, 0.0030305404065837788, 0.03683346526456937, 0.06376496448572125, 0.08053518456196593, 0.029685684900370338, 0.02545348578883756, 0.07044182294198582, 0.061770328170349525, 0.07433192549093116, 0.07671533227567712, 0.10088715296719344, 0.025154031595335375, 0.057996065776434645, 0.05205031950026751, 0.05043356371442637, 0.007700591325579632, 0.03440629953758852, 0.06465762928729096, 0.04161293077613077, 0.03352005072238465, 0.04553538904855809, 0.03743326997444515, 0.09992323049734678, 0.08635171478794468, 0.02667996765775306, 0.029021542211393678, 0.06219442295391233, 0.017115158825031212, 0.05416466854512692, 0.05401370708920783, 0.04945718465493091, 0.030055561726312005, 0.02545895948705654, 0.04861724968518942, 0.04560256729863825, 0.013577427992957735, 0.04086481527455392, 0.024505706706775293, 0.08374589735702162, 0.019519418523076083, 0.058820085269549204, 0.09642459121682952, 0.07923420638807359, 0.1651138884405936, 0.13242309342228598, 0.18754301232195672, 0.07234820209804081, 0.12048937410356537, 0.1831956012474914, 0.08498713599457856, 0.1362749988273267, 0.1612626265494093, 0.07603444098945587, 0.13760889579932536, 0.16432132451765, 0.13552924287655663, 0.13250895655683934, 0.22216008946059213, 0.1152049608889126, 0.11335376304604354, 0.09643519387370157, 0.12915592760809008, 0.2149343328370202, 0.18980784401778253, 0.04895912408227882, 0.2135371416807175, 0.14439617433855612, 0.10188944878116732, 0.14966696650991518, 0.12920345570291245, 0.17394564114511016, 0.19128915162817126, 0.14963920348353926, 0.2111566460300838, 0.10512662991400688, 0.21097505254851234, 0.07460988517249785, 0.21780890923353935, 0.1789651717990637, 0.19357701192700094, 0.13782648009157952, 0.2959212871088136, 0.20828452111492235, 0.13595851258404795, 0.10613899978418505, 0.12442983927265291, 0.1437855716193876, 0.15623428588432653, 0.1041046609621375, 0.1763563972687529, 0.16863541076740912, 0.097777318630007, 0.09441782389917681, 0.12589254626824012, 0.1142819781577395, 0.14768989276020758, 0.10202768934710373, 0.12817872117363638, 0.1688470042520954, 0.09063390113653676, 0.0857825497646005, 0.1692055793659341, 0.19994645079057063, 0.10718173737968169, 0.1100831191926714, 0.07285668529690274, 0.19133792078543096, 0.11644759380649175, 0.16469214171651872, 0.17428006916757555, 0.23907400847923374, 0.20883029747393825, 0.0869536377309311, 0.18030187265286524, 0.09510050017026164, 0.17119071236060512, 0.09366754802965349, 0.1160915008175277, 0.09236912858942825, 0.0991682738306061, 0.11541560442457277, 0.17632293454822034, 0.15743258529372756, 0.149731042103902, 0.1106749987229705, 0.15191036306561964, 0.16190670731086887, 0.09748580685305981, 0.06902931002719749, 0.08377274873876765, 0.1103504149303321, 0.25670326975805147, 0.11219437324231672, 0.08771327519488913, 0.10012599098826609, 0.22209832745213665, 0.16588337779525789, 0.16465441954712715, 0.09954223198996437, 0.12795213534827196, 0.15032521989797393, 0.10695283030790668, 0.13863435045125025, 0.14578910604599984, 0.12161330935815651, 0.21978875622153285, 0.17037487468652188, 0.14989291648230246, 0.11885579119646743, 0.1486658121669485, 0.1344470057876841, 0.1126596260996115, 0.08999784897652366, 0.10979825705890695, 0.10492652008730559, 0.13852348220684838, 0.1287819694487318, 0.2516030087586372, 0.32198427245020866, 0.24149153682012714, 0.08568632912131087, 0.18742518799920238, 0.1346911426873938, 0.18102588702834424, 0.15101025571986554, 0.14566976486915542, 0.09137071684123048, 0.14689311535368044, 0.24194355933896958, 0.1320159330122894, 0.1838668934520214, 0.12964073869009174, 0.2638662071718324, 0.1614836582373227, 0.0962687382895139, 0.11560023161432437, 0.16103106881341628, 0.13415448277467681, 0.10790773592288457, 0.21106823948362183, 0.17313728048916788, 0.12695904791114793, 0.14514056665282096, 0.16559761167774278, 0.15812632387443898, 0.23952551005828768, 0.13201089215374764, 0.12201171338317857, 0.18080746003937337, 0.14102888083265674, 0.1523281874195222, 0.076237132532462, 0.14711627676602335, 0.11378207514362951, 0.16256637030070828, 0.13412275141285313, 0.11238143659166752, 0.26837530876359633, 0.2396488808576138, 0.2105040923361817, 0.09010671007056391, 0.09849325077788484, 0.2084091329766858, 0.09553289551648403, 0.23257425805974394, 0.1247302070260048, 0.22196375644735752, 0.12159160608726165, 0.12237008931415698, 0.19507452995786745, 0.11876049751956617, 0.1271792675458616, 0.13304371657150407, 0.2104486275704638, 0.1310962138156737, 0.1310992168803369, 0.14101006571323643], [0.03374593940773799, 0.08419526921164605, 0.0425302253044661, 0.014446702214979358, 0.007216071356989204, 0.07240657033699174, 0.01625926624382696, 0.02673639577903575, 0.0409807856645315, 0.0332572021251244, 0.06295432471820424, 0.09615117443665382, 0.014187300055768463, 0.010070462294313456, 0.03660691391316153, 0.04302611784829248, 0.03101246491555245, 0.014283625078537773, 0.015395849721596367, 0.04547664542652426, 0.05277115461086074, 0.045247477884855, 0.084602850970001, 0.0383727427481884, 0.033796213927768895, 0.024208523963968602, 0.021684003783570185, 0.047461058298546466, 0.07670407078319019, 0.12035322495766225, 0.0554428517728323, 0.03143350109307757, 0.04197041804511701, 0.028663091586842656, 0.03789726261710448, 0.05081488397873698, 0.025225551648726387, 0.014726990803835854, 0.04204225410977679, 0.04059011146666543, 0.06428327276221206, 0.015163800731721907, 0.044886286580754865, 0.007047916015219545, 0.034563064109534025, 0.05660393463087179, 0.00760326368523942, 0.07728396869835354, 0.016467054186749364, 0.069889580800889, 0.029260201582444773, 0.06238547762134864, 0.01695290331788842, 0.05272108310412976, 0.060123212320069154, 0.024522095242695465, 0.004528008641735201, 0.10328995709818217, 0.11347874263001066, 0.015536926728072427, 0.023166412645350062, 0.02461096910279124, 0.05339767663709579, 0.04649784446002976, 0.04781218320732156, 0.07081047211202883, 0.07152099567916125, 0.023173033560235656, 0.028378652716656367, 0.047696320069653374, 0.015541232142206884, 0.054705986272423505, 0.034258402433366544, 0.03980435040448943, 0.11478235614636254, 0.035599121418330944, 0.03536630346770248, 0.030765623725470037, 0.02318361706490959, 0.024334811643066428, 0.04753083741712955, 0.04496571074630465, 0.03333688676056843, 0.004596414068909062, 0.028953969426032518, 0.007540618281646242, 0.014167700653835652, 0.018712739430127606, 0.10195019955356276, 0.05198562720550164, 0.025434498299634265, 0.024650278989405885, 0.02379929894701608, 0.04578981067865126, 0.04814435893128957, 0.011946328168344355, 0.05313650960282934, 0.025788208755153804, 0.03443049259423729, 0.03650402830493066, 0.020929456973868995, 0.05095033598462901, 0.09336870479127092, 0.010471647218500656, 0.056278301297777125, 0.05177252835804417, 0.016333503994129358, 0.05556516920126254, 0.039683442577839866, 0.01938451043961029, 0.037168100130774324, 0.03921180820813583, 0.08094065191764986, 0.06786454994712146, 0.020140662203512846, 0.054770755175981796, 0.02558751287119043, 0.028612309533561912, 0.010276443227344464, 0.014592242641224256, 0.06913813281684153, 0.04652026402313383, 0.02887388834008767, 0.011320160457774276, 0.03177405207327778, 0.01059055555566785, 0.0216445789837669, 0.04898175048912245, 0.05569908903130601, 0.03614146953388568, 0.021527327311735962, 0.05112367486881633, 0.03793210046546113, 0.01900331466458738, 0.06844185848510073, 0.020818914316834945, 0.050211490146935954, 0.04212407996096919, 0.04606606581458642, 0.08946875801249858, 0.009971434896391247, 0.03897615190174791, 0.01845361976583879, 0.052388585623233556, 0.04240822197208482, 0.01384939207890702, 0.040004900731747194, 0.03417765676614738, 0.09880661904331177, 0.03126561675491112, 0.06013942657098655, 0.07652111366511354, 0.029505395683489984, 0.022212784481985916, 0.05883658297299858, 0.030496947114325823, 0.010286709763139728, 0.025496432677872723, 0.0478437805037585, 0.01773099583994237, 0.028268952756339026, 0.050040878535759066, 0.003800835829385887, 0.09618615401127646, 0.07421554907435372, 0.0299397656213372, 0.0826193344208502, 0.05737818905242509, 0.007923280636239196, 0.020782099961633646, 0.062184820041781476, 0.03763523373392321, 0.060240197776546406, 0.04538630450805349, 0.037558885411389416, 0.14181399838097636, 0.06618056611548509, 0.0869026852230872, 0.08622591548989858, 0.04526228253399173, 0.027231154512734185, 0.06242207364149152, 0.01502651873330075, 0.026433645492239345, 0.05791306398027848, 0.036234430473057494, 0.015015746579475462, 0.03770487878711955, 0.00916036707724655, 0.08972767274826766, 0.06782566332408498, 0.029760140985731157, 0.0160847571603353, 0.025545424000630458, 0.033719574491823875, 0.056742516105934504, 0.03225465350213551, 0.047608273584515824, 0.06063861712332695, 0.041635606978689475, 0.03969169334478436, 0.025091832916763042, 0.05618157503645747, 0.015674327470121846, 0.04867830306231495, 0.02304723809262918, 0.03415336411806845, 0.02193438046942315, 0.05738518343517377, 0.022884409934762987, 0.027843944412926515, 0.06998364873711141, 0.05596552675049152, 0.015510541702350302, 0.07444943571763654, 0.02804788467924922, 0.026148028761869477, 0.04490922325320783, 0.008720445874778014, 0.012490254425023113, 0.030801093596364224, 0.02825491994078602, 0.03102328016182348, 0.01624446734034967, 0.07778907344946939, 0.058584938411630934, 0.08783182730117152, 0.051042308670378504, 0.06252977794276611, 0.0450466517659445, 0.02190893294379836, 0.040599955696492426, 0.015199464039816974, 0.07224534713332692, 0.03512816886687952, 0.05436403526654167, 0.06922452455206264, 0.020264502231692596, 0.02074706101519687, 0.043166193194807544, 0.057918223582448504, 0.057250574125998446, 0.030728600611309373, 0.07313932577568678, 0.04171701148152352, 0.09153436854361527, 0.046068670513528975, 0.01945012012466548, 0.030714405002072457, 0.008655229767393923, 0.06736469289828693, 0.06511398786378485, 0.004370435368224618, 0.01778314152972833, 0.031135866358395548, 0.0029096208492128722, 0.03622699175931273, 0.01864530454059282, 0.04166861004646748, 0.04005440916385382, 0.05159548926918257, 0.12873836372408176, 0.07307982372660791, 0.03918039860324033, 0.04501834864758196, 0.021221679297365972, 0.015751358568518153, 0.02187964923289274, 0.019936168438664848, 0.010379506951017727, 0.026865157922129, 0.03221982714509772, 0.037461396892585104, 0.05352352956129659, 0.007042390127260719, 0.04048833285548514, 0.0199070226235856, 0.11120711573429647, 0.0433652917854488, 0.010195289618305622, 0.0836943319788383, 0.14566584249898312, 0.036410688152236324, 0.06605724128143442, 0.041772786512850754, 0.03591660740635088, 0.033696829341351986, 0.017597001316326282, 0.045527299160077694, 0.07456339129637327, 0.00927291592703231, 0.06287671235059539, 0.06662292826560236, 0.02672992425129539, 0.04725945076995319, 0.05724135425782973, 0.09771365672349931, 0.05886399359892934, 0.04479277405827757, 0.0389757382142688, 0.007162475367001589, 0.005839115455596438, 0.0034315510457682036, 0.059163419064134366, 0.01782174278501301, 0.016045447273720658, 0.04621049637095102, 0.021703753530258135, 0.07543743633094334, 0.009910429399760981, 0.008573877933104674, 0.03066533515530248, 0.02300599574922554, 0.01936116007967822, 0.04555514645612529, 0.05760682416298698, 0.0735993615742172, 0.027768563276397127, 0.0743430107831955, 0.024951577539585774, 0.0122509659042642, 0.01360512494425019, 0.056296767847191904, 0.05069702135158643, 0.03513685247350124, 0.022613946423535387, 0.0506372933065699, 0.013317988486960532, 0.06461139588106064, 0.03964639073538204, 0.03196241011122062, 0.0733669304979905, 0.034545865435633934, 0.008883635051578524, 0.05370068356334683, 0.031137796899964734, 0.05268449091442651, 0.04339516155361649, 0.09080142158293918, 0.041629650645078196, 0.046437721879732226, 0.08082853494993142, 0.030936886511382558, 0.019753349216414556, 0.016357088010878335, 0.03087961760860297, 0.016913405739732327, 0.03340406884108821, 0.017256867854044806, 0.07513930555433035, 0.024833209294405197, 0.025260937249948903, 0.12626501055614603, 0.20687901024376193, 0.1729027962973041, 0.17563247482382482, 0.1220985034841203, 0.2764528785501757, 0.12403676721958384, 0.0931683574773131, 0.15246311082474648, 0.17893981428877, 0.09529950683035197, 0.25567044534029504, 0.09915891989705064, 0.21988427206393213, 0.10919952870256479, 0.12314669562563782, 0.13966012686010332, 0.1287574699569133, 0.20573707958382947, 0.19395624077127827, 0.29045463689873297, 0.12721656836689482, 0.23278214367887667, 0.11917580910507711, 0.08072530460213462, 0.12060588075508996, 0.14516315092482876, 0.19657609293297415, 0.26962035485813696, 0.1830676339206196, 0.10605836903015453, 0.1441757861644991, 0.2504040045483459, 0.14482990267776674, 0.09761133035945316, 0.1809340484079815, 0.1467636924597525, 0.08512504714270754, 0.18299025904026725, 0.18821045876510684, 0.23108044789443094, 0.08735472306368813, 0.12008962176379659, 0.08690280779715508, 0.18817241483878708, 0.19201690451272074, 0.06049307573947215, 0.14340513235618993, 0.1778048550289485, 0.1657153440699462, 0.18698557610473326, 0.10854949543793356, 0.2024934939559429, 0.13718100505009775, 0.11367931210946654, 0.1007044333363733, 0.16681697850506153, 0.1403775222359165, 0.1727273468408854, 0.15799123192987136, 0.13979221574000775, 0.1508097092230474, 0.19829390720734674, 0.16784848525158821, 0.15787717675970447, 0.21436136035669237, 0.17373809260466408, 0.18186743461316635, 0.17778508996050205, 0.26979005865512357, 0.1880337529244923, 0.14334525492402816, 0.1684173668224004, 0.07419037542516187, 0.2666908959227224, 0.12218631248200133, 0.18913865089416507, 0.11192537678946411, 0.11327037437548561, 0.15509914276340317, 0.12199884310605065, 0.11496047158875775, 0.1461572419371336, 0.17681474767384991, 0.08817506533476614, 0.23607935546146286, 0.17515003861438844, 0.15592601210359605, 0.14865608285031012, 0.16628087017565005, 0.11030331584474734, 0.15924980713715478, 0.10970775143153245, 0.19161774206065363, 0.18626733803220336, 0.12009375097770845, 0.20090243658952175, 0.07892937234212315, 0.1256664277565095, 0.08484782290554817, 0.08442112725348243, 0.25802089502253844, 0.20709984274881504, 0.06446036930766798, 0.2604558288810715, 0.18561136758615895, 0.11933966765120146, 0.30208657886232104, 0.165165645340758, 0.13276643870819, 0.1764707588740895, 0.10426221460464502, 0.2545218343936628, 0.17663608064814923, 0.07793230124779287, 0.12916602464693208, 0.2191940574876724, 0.14576822248918397, 0.1721372905998461, 0.1656222950306631, 0.2016783457609915, 0.19267022429454714, 0.14395313037018623, 0.1437835797907845, 0.14754177732092721, 0.0851919572620142, 0.13214046826526044, 0.13259814451298407, 0.19033068370434547, 0.11564090322222441, 0.13852905932693713, 0.08353762869392672, 0.2727728373100681, 0.08689153098290966, 0.11386643674585128, 0.10625155342202033, 0.0857378791777357, 0.1533848065282068, 0.11072732252819885, 0.18172351733571102, 0.19392547468023916, 0.11857101333237464, 0.1904529666588191, 0.08763817559567191, 0.12661273786497693, 0.18769265993708567, 0.2591326111747373, 0.11586300743323182, 0.18258222529003698, 0.08103661975192447, 0.1639768913868935, 0.13822769565928367, 0.1438902498733613, 0.07484823044749998, 0.1172652394480763, 0.16658183547758287, 0.08144137464583882, 0.1169898538219352, 0.2355269447810227, 0.12333418032334698, 0.1303339103657392, 0.1240504495499115, 0.15478337664277325, 0.143673355060239, 0.14018644458584248, 0.18223164813412776, 0.18162709750956108, 0.1901007807182689, 0.12305927733259818, 0.11823252504391056, 0.19735863642586818, 0.1115011019752391, 0.10301778904132305, 0.16911000223650088, 0.12446942303570048, 0.25519225325795913], [0.02401234991397829, 0.04881296599764497, 0.04877736972224328, 0.0013947679244372393, 0.019715018007123185, 0.049299370542529135, 0.042053320249843026, 0.05581894348705969, 0.04467888359701441, 0.03179312766259236, 0.08117535061413243, 0.03581195596545454, 0.01980418872628962, 0.025761232884120078, 0.04538700547850421, 0.012554086786093972, 0.020017500163146087, 0.016917605816777197, 0.03943701507523656, 0.023373786900793354, 0.048592899580516165, 0.02256095995225253, 0.022506322561492844, 0.019566377797614665, 0.06010541609758812, 0.04800077107164168, 0.007894082152615152, 0.014339032387661358, 0.05918959628850703, 0.06482019314482328, 0.03135596533426114, 0.035786904890330574, 0.019236092395599813, 0.02244619232031607, 0.05863069684334821, 0.051079705252402255, 0.011095823100467604, 0.024581798389854453, 0.025908400289594166, 0.03042545961967159, 0.048143887787216136, 0.013576627431076863, 0.02590985777187011, 0.04671919407443174, 0.03604955430473051, 0.03352701063117674, 0.046288012977569334, 0.0471415804819234, 0.004820718867478952, 0.03346294269806916, 0.02202468499871752, 0.08145318006075199, 0.009628682371018635, 0.06330910386637816, 0.006199125069073372, 0.03498563437812752, 0.020230836497860092, 0.033747123013581, 0.0902211789282099, 0.035968172784534194, 0.0769674135071616, 0.04187890501212209, 0.021369873260658596, 0.041300550764126163, 0.07023704763982566, 0.07801556734428292, 0.009296206915150247, 0.013540617468196058, 0.02288968828056128, 0.06424284247200816, 0.03769540227949619, 0.062212046806610403, 0.07743262039918093, 0.1170617818171459, 0.0814705089695992, 0.030537768109371106, 0.05540607955246683, 0.05528171283883914, 0.014129176964953303, 0.048790056138269366, 0.0447747556702985, 0.06545829842047346, 0.046598650139546206, 0.034287433335257154, 0.023420828529783798, 0.014534166473294459, 0.049161850099241546, 0.023312302599210414, 0.06611090574053026, 0.09748902442234178, 0.04504538772086944, 0.03343222640274513, 0.059970764653576966, 0.04961637389515677, 0.025923992094073086, 0.03247464331047189, 0.06169043669116594, 0.07112276785436177, 0.011164159100923327, 0.07382212462083948, 0.06688548957989102, 0.033567536682371175, 0.06946776512890093, 0.030965532454091216, 0.01583019571919595, 0.05140808118026584, 0.05963658944012658, 0.069575768204466, 0.04602765033562337, 0.003989751435696118, 0.048917379951284784, 0.026998725351727298, 0.03091741447156716, 0.0032864480078475733, 0.028369710555360205, 0.08276870624432642, 0.047139569501122164, 0.04998953532307379, 0.025878210679718086, 0.0266372007993801, 0.02858438371350208, 0.07774913728597664, 0.018930995964535305, 0.034573164978815664, 0.07843236514036694, 0.010618678643368186, 0.06650687360595312, 0.012858826986273691, 0.03208172255976787, 0.03741764944166907, 0.026507846853365342, 0.022708008614098354, 0.044973026885981524, 0.026574038765242985, 0.04912556817514762, 0.04762138134890026, 0.013082785130057846, 0.027654827947938637, 0.06558798178429566, 0.03190037422633219, 0.00554063419375809, 0.06043495264865699, 0.02367793721327138, 0.07865988559299901, 0.011197390079858803, 0.02820163277999288, 0.03729029498513668, 0.03632588987989772, 0.05990045693432612, 0.05711285449985055, 0.030974047521369594, 0.038402535907563665, 0.07302334006395071, 0.032683823618196675, 0.022551029537534042, 0.04691023342010956, 0.03657072391961852, 0.017227836952154196, 0.011216649530275215, 0.05464883228283256, 0.04308208440160079, 0.055994389113038785, 0.02152051679008911, 0.0378839863133767, 0.007107517655728566, 0.0870737296739413, 0.017272026818846504, 0.04022349626006138, 0.04932245660212733, 0.01705159267951404, 0.02930263710779048, 0.017247795457801512, 0.028492543177919525, 0.026075744535773996, 0.03953056590211007, 0.04205916167026566, 0.037993356855886604, 0.024226318271229827, 0.08935625800081799, 0.06485960070764826, 0.009798040470829415, 0.15903259056710428, 0.05625423081519623, 0.07220801566877673, 0.034308382009546605, 0.012586166717923217, 0.10614087669959954, 0.008565160810136268, 0.016380742890760303, 0.03310725190526536, 0.07057400375244118, 0.01652050414122641, 0.0037213999331147684, 0.02518343979552869, 0.007414332517768227, 0.042954948280126824, 0.02139924698689532, 0.019016577561776486, 0.011406598158270843, 0.07663804166499646, 0.06780818885853214, 0.05590169247420085, 0.10007663960418395, 0.07895488307000169, 0.06511520594358444, 0.08980930707747899, 0.03467574798231644, 0.023288360436356837, 0.025055752090749242, 0.04120868150024645, 0.01913551462724084, 0.04789539184721728, 0.05664008632001858, 0.021650493182542346, 0.028306736212764538, 0.03470764788348348, 0.04517848400639431, 0.014681740862978323, 0.07675193595669924, 0.04840369118497737, 0.009813911897400695, 0.04722547860095098, 0.03750357386325637, 0.011887224484986116, 0.05059087986967737, 0.019739496431523756, 0.059060246172931895, 0.0450245846032856, 0.03755061166180718, 0.02940014669401271, 0.04986238771028096, 0.016854005197303432, 0.04892604823614802, 0.007929459614153471, 0.04245915149729099, 0.006371559011900137, 0.08876542801097517, 0.04762479810104255, 0.015601429416077032, 0.04913183094392862, 0.03030762380559839, 0.029935814522867723, 0.07277567915978932, 0.03684277323284938, 0.004470588436590568, 0.1053963081851121, 0.064941058836637, 0.004871347224369886, 0.11472790261670468, 0.07962498783824906, 0.07259853664905795, 0.03834254739265289, 0.05341874788545313, 0.01587789139575175, 0.04239928938688771, 0.0228211272417778, 0.07905528655335789, 0.03392528059081205, 0.039386541372345346, 0.04035668447613716, 0.04389336385253457, 0.053764284182820594, 0.028577877711805127, 0.03750784480343423, 0.060956512968386375, 0.05637905718157849, 0.04750123194929573, 0.04002229092762836, 0.06799830123782158, 0.016316121459127437, 0.04071039110121708, 0.041999648129867936, 0.01844711950980127, 0.0627682036570003, 0.024345619228458213, 0.04275840076227342, 0.04452435983224742, 0.05125063095962809, 0.10021007679883512, 0.038830817361632665, 0.054172011497881145, 0.011653496804947575, 0.020424260292202234, 0.05094775426832419, 0.025098756436378728, 0.058242864831681215, 0.03132624112279906, 0.026063680566186388, 0.07114779594684802, 0.0042698221682991476, 0.019293248300410567, 0.051251473656344804, 0.11224421492267041, 0.02290722020270844, 0.037160546503840916, 0.06183567930073027, 0.04133247364793093, 0.05244035018427719, 0.0375282610466163, 0.034082573763425314, 0.06448850005624757, 0.02497880238919489, 0.008937890355985974, 0.023257203640476353, 0.02008500783103368, 0.051769705324043194, 0.0147606278093712, 0.008162236866360952, 0.01240471208978805, 0.016123632292052912, 0.073284154697772, 0.022376901582784714, 0.022479337114360065, 0.03808165231959955, 0.047642421953740625, 0.055134528196386756, 0.022630568616272464, 0.020434525870387594, 0.03597918912888535, 0.011668864528708642, 0.01030804914227056, 0.02814544597640634, 0.05230975517582509, 0.03560630349262107, 0.07727413979028502, 0.032069800316446254, 0.03909885620457992, 0.028640308131974553, 0.09947376671217142, 0.03582195724330602, 0.02640273001405501, 0.01421357304113166, 0.020653311005463044, 0.05585010028294018, 0.04623623692520684, 0.042637247787488085, 0.11827287489488242, 0.0257278046375441, 0.013145071908741469, 0.047283253121760585, 0.009627771683998648, 0.018401435771656614, 0.021166674184402632, 0.030536427455503615, 0.05566564929341117, 0.04752044926487631, 0.02183998694583293, 0.058695971364936525, 0.03480841525860372, 0.014301363844424488, 0.043592410041920604, 0.0191112028269638, 0.11166548912203121, 0.09559743076322541, 0.14453240009325166, 0.16938787764839588, 0.11710046925732207, 0.21842505842927964, 0.11018762890730174, 0.18186227118055667, 0.16362698838835762, 0.11617824495319398, 0.1701291290021712, 0.1011188256163751, 0.13881983565947703, 0.14713362099662905, 0.12160295951029948, 0.07987973505571004, 0.1114766178051791, 0.1140614291052184, 0.09679388390072892, 0.12042415703857139, 0.17414292410737084, 0.08273599428995963, 0.21366187611654883, 0.12765035033226013, 0.16478163610783317, 0.17954813406592418, 0.13823066808042989, 0.1557918241427791, 0.1468703778640878, 0.2358490234661487, 0.1485848519951105, 0.12336228042840959, 0.12624802638686475, 0.11447004508227111, 0.146168488107862, 0.18656142386457614, 0.11712895240634681, 0.11439169727025494, 0.10957343323576836, 0.10949056550499894, 0.1698655947562187, 0.12210618734600083, 0.16670949636928498, 0.15692163529174943, 0.09971737501121337, 0.07951769722445358, 0.09719256371740373, 0.08862328039662493, 0.17286055420915927, 0.1563098068319021, 0.1415061536094835, 0.2026013438139231, 0.08508979177643215, 0.10455851443111898, 0.10580690066900947, 0.08019293478179364, 0.15204620577635306, 0.1484793616879371, 0.16264359196347578, 0.07272643502801657, 0.20012085836741234, 0.259939945272861, 0.13816936572472896, 0.14548104676988818, 0.18178898720972, 0.1159105585106919, 0.12536060545713673, 0.07939955114477104, 0.08451011602676685, 0.23976040793763054, 0.10618361674489514, 0.1480725383566272, 0.24106467262871806, 0.14615845235605396, 0.2399941720068455, 0.13471790979946816, 0.2169304515325254, 0.16189290240647333, 0.10621807537972928, 0.18330561147341806, 0.15151991869413084, 0.1436986053182233, 0.1549594236477729, 0.107045917651586, 0.16336418958681245, 0.15014134347438812, 0.1075237573334767, 0.16182485847703873, 0.2282789256423712, 0.13599202126985596, 0.10676649474208394, 0.20448769743163742, 0.18812165385292423, 0.19006679705794782, 0.13623028993606567, 0.13059384399844756, 0.12003180510815113, 0.18458719996194686, 0.0849840639820022, 0.12263149383567995, 0.15385942864081553, 0.17383163194021872, 0.1726521629719965, 0.16697057913387978, 0.16872801547569616, 0.10823991164685258, 0.11778522162668167, 0.0938872390636994, 0.10098506666479573, 0.17520777100036222, 0.199160858267738, 0.1044162902079763, 0.12766864451189197, 0.09440643217174277, 0.11960787503349206, 0.15019610343921572, 0.20804082854620873, 0.15947969480147287, 0.13315674518385243, 0.13708910514270106, 0.10746142841995725, 0.1922172211831616, 0.11713418478686964, 0.12146520157975536, 0.13892943219792458, 0.08582943434556646, 0.23735098480697603, 0.15691461792636305, 0.07516185918282117, 0.10511427291578825, 0.08814943969369897, 0.1255839966958569, 0.10559521525377229, 0.16266534886052533, 0.2750384350938182, 0.14342492806815332, 0.06793345955591049, 0.14643611326333017, 0.16124702899927096, 0.12128790585143913, 0.10272603211624008, 0.10196945900397916, 0.15399295776601762, 0.13243850711132252, 0.10129470408203141, 0.13397439082543697, 0.22283481373902292, 0.2931709088865788, 0.16234189121713563, 0.1500579011776755, 0.10013627188820994, 0.11996883268077528, 0.17761291936039927, 0.11939391433711975, 0.1682946242151722, 0.09940112625519115, 0.15113525062559113, 0.1663157578197218, 0.13778402349881588, 0.12491935413450965, 0.2461581154456062, 0.1454154543218113, 0.10064288583253661, 0.11696177669951033, 0.11927839593901751, 0.338256991197986, 0.14973399920328972, 0.17567811834235347, 0.2163041133673922, 0.12588088641003256, 0.14389489236618244, 0.08761639571598462, 0.2868618377514424, 0.12907484486218423, 0.1596110329152115, 0.09985768401454534], [0.029150538011303836, 0.024817278496019786, 0.08529511100101857, 0.0231225177225086, 0.038216188850422064, 0.026415146384087783, 0.02705652477039445, 0.03271075926961438, 0.05359483319484899, 0.061818430831115094, 0.02621947986734731, 0.06441592854718048, 0.04331490235222925, 0.031166854614932692, 0.01577876249117957, 0.09163623525490684, 0.05039058235143462, 0.05400724513756652, 0.06135104058851158, 0.026626674751300487, 0.003667654555981919, 0.01991197155157645, 0.03829462859298914, 0.02197155680116867, 0.01094121506602894, 0.03248539535448917, 0.1066183869636828, 0.09711564082892672, 0.05591613323157353, 0.0589120771074968, 0.021224621074995207, 0.03125009389834539, 0.01319380276160495, 0.032167966823063554, 0.01038002501797652, 0.008814392194542433, 0.017533622862350558, 0.06364267003992874, 0.013767230106637844, 0.019490793647785342, 0.10015837352482543, 0.052844032555097536, 0.04582034694331308, 0.038498511402717525, 0.02922725405604128, 0.006263241361481168, 0.03563901161654823, 0.038926926922173276, 0.028003955282451167, 0.0992856997876398, 0.040978698074937835, 0.012122133855647858, 0.05736642577234776, 0.04777733386764604, 0.03163259010761976, 0.009519131797846527, 0.05383119047168763, 0.07627457891020083, 0.03457707968810874, 0.03092011684672006, 0.04198248392992443, 0.014634856282012358, 0.013590794312016619, 0.03324771412618218, 0.02238255339644609, 0.02605289787865214, 0.026429901237509427, 0.030462969199664174, 0.056727018147226305, 0.028024649232505795, 0.04638013122002444, 0.05547986914133353, 0.022598777882634632, 0.013257711731468239, 0.045087553200221835, 0.033629708547866156, 0.09332208068019922, 0.045838361500852534, 0.018233354165849668, 0.028383331598653912, 0.05714128019228097, 0.04282478228091233, 0.07112695069442834, 0.05368815419534522, 0.03237249697708795, 0.007117373376874434, 0.025734400654572154, 0.027063643642430826, 0.054079219098052675, 0.016451136794902625, 0.06680363308518164, 0.048744910576891516, 0.022365157454905492, 0.09375871249264288, 0.05202168696409753, 0.02090153306902897, 0.007421273274362208, 0.022229896970994534, 0.0023214968255600866, 0.05465258994410115, 0.052516575932743094, 0.03790479326140016, 0.03081768706080414, 0.04843584006471981, 0.030148763983179967, 0.01808269914510029, 0.05994126260761292, 0.007613235277183835, 0.09305061742423043, 0.05821174634019694, 0.049335671618821166, 0.1157434517517686, 0.03901305818750013, 0.015827427268959582, 0.04810513522956641, 0.059929407396984685, 0.023593230871483687, 0.047218039887206215, 0.07291932064559191, 0.07585244148128456, 0.04848741693422199, 0.058291771884767286, 0.031464839834840067, 0.057921015972932505, 0.024964804047598474, 0.02280679373671451, 0.02308681419479751, 0.05447621352129406, 0.035630082861790736, 0.03848853310750377, 0.06175406029327743, 0.015951422429944, 0.05561193503860024, 0.08209611169032513, 0.06755049986344192, 0.0706531482958986, 0.015362705885162278, 0.09494905224851063, 0.019800873480797298, 0.02970111965682478, 0.019525342297950582, 0.05572132090286863, 0.011466043708365292, 0.018481219998530803, 0.017306305423018434, 0.026926006370734785, 0.02621669705296236, 0.031448612177384, 0.03861781810560534, 0.01895622515510167, 0.0318438733266967, 0.04008965303881034, 0.046935506660731575, 0.04587608750068373, 0.050397971269464305, 0.02036642256913887, 0.036233446050074794, 0.04992538695073417, 0.09270371749035775, 0.0501785138922353, 0.010554103177010773, 0.01921737495238983, 0.030777599594946352, 0.020189088536426425, 0.09807437688352601, 0.09927546485297142, 0.060880329354756305, 0.02855707842466091, 0.03670876530269462, 0.06579045882268299, 0.044264767108665365, 0.06026105835072457, 0.03806404761909958, 0.024766791386589892, 0.012078282982862044, 0.03764200212073423, 0.019254434455726898, 0.022838142054576068, 0.07232140434244949, 0.048967619997359095, 0.03809376800012204, 0.011764207043715063, 0.004691110676034324, 0.06750741507858038, 0.025960720264382904, 0.0642585625962144, 0.09013941436405144, 0.11716721849816462, 0.011262351463008071, 0.03669543920325176, 0.013674655084257886, 0.04895543153848379, 0.0266737470238079, 0.04009275569490368, 0.046922912175256404, 0.028674724631972855, 0.03674278726741191, 0.04630402038474718, 0.024780956352309837, 0.04619243201769648, 0.039524126933106495, 0.05425587131251251, 0.015530023318264755, 0.06927879422061867, 0.03588303743350891, 0.024993978590974887, 0.08072515904542901, 0.04100071544188165, 0.021257626057993022, 0.024196404453006484, 0.08368091011840491, 0.04085382957371973, 0.018867280431872895, 0.02523765583793002, 0.02827169535110795, 0.03561348173647158, 0.014818377432323273, 0.06693625056575384, 0.061726779902293805, 0.010573907507463329, 0.028376674294591914, 0.03421796831272302, 0.0213096319367328, 0.02561011629539632, 0.02677693523676886, 0.13215278695908286, 0.07495773505539664, 0.03765867602440619, 0.029959030817413045, 0.01297496208515499, 0.008957310684866483, 0.06102985822625699, 0.013355392729863526, 0.05147213379161493, 0.057016105255893165, 0.0498358351028254, 0.027131434762850407, 0.034010657259533485, 0.07151607739468736, 0.055320063200328624, 0.07775778641864177, 0.04026565024809491, 0.053520917201474796, 0.007975240070898568, 0.04543158413481809, 0.09200175878621879, 0.04161142924379918, 0.08320241926177856, 0.04156428802337858, 0.06579451908868167, 0.08030744194383584, 0.04452067111889201, 0.09825993103966599, 0.040274525376697706, 0.02231022128985534, 0.03787187446329383, 0.022160144665488796, 0.08532490416039383, 0.07175331950307855, 0.04527406496626716, 0.033496547144867724, 0.025742163040464925, 0.03483709759048877, 0.0239141489334044, 0.01506238122425613, 0.03418251759402695, 0.01124109635354891, 0.07917588411439812, 0.05451048829502637, 0.09754904741120916, 0.07067377904369947, 0.044188495394924, 0.014817412161538679, 0.06327230100249571, 0.0631051904131328, 0.07717867757404044, 0.04227077430715004, 0.024864806590842146, 0.0451707695009968, 0.08398441883224635, 0.030799164970014847, 0.06249070745862781, 0.06157599847703692, 0.01046037806513449, 0.09631223676185455, 0.025812622062080813, 0.05243527102133921, 0.07730699730135741, 0.04587531758231982, 0.029105764002569263, 0.007400067960618125, 0.03425672087037275, 0.027579165274097074, 0.010877519643174545, 0.0447667921863256, 0.06358402217888544, 0.026636507489808628, 0.054951823887325106, 0.022348663581895734, 0.03710952504808384, 0.009622469397952721, 0.03795216047775842, 0.01733964748470293, 0.05159743513251024, 0.07207333741168823, 0.05216746583520886, 0.08376480440699285, 0.02670528494843072, 0.03176622073947182, 0.04138036946495695, 0.01863206079560182, 0.04332305735818321, 0.03845346543276983, 0.038497948328093175, 0.021613586896790132, 0.012104244745006005, 0.020789996412913167, 0.0708481559770242, 0.11844843160361053, 0.01894524711514673, 0.006918321230313591, 0.0598354313913132, 0.039276764803235574, 0.06501969010118516, 0.07201286243094553, 0.0052660644512563465, 0.059628633617032925, 0.06404436441258558, 0.0578091211707121, 0.04896295452190023, 0.01538397344355021, 0.029697971035455985, 0.022890111544139446, 0.03805879225593902, 0.034840698203732895, 0.03286550519987941, 0.01679032413859762, 0.053805373308639375, 0.041308801531070666, 0.028177169677350792, 0.05937314712472501, 0.039130250487716935, 0.043896654200169354, 0.010324157098488463, 0.08504754202740808, 0.02926442847256699, 0.04109362658533839, 0.04627692385486538, 0.04059359333628128, 0.034560689236968756, 0.05743128277601735, 0.06709436345244608, 0.1698411259079172, 0.10304061080058736, 0.15351038366075487, 0.13417401801674597, 0.09690944826410663, 0.13423495265024324, 0.13253938556919176, 0.1738658301051586, 0.13021582557309058, 0.14475661870693007, 0.1460503420281795, 0.1825462191575958, 0.14742991316222376, 0.20075104229392546, 0.1390064087125563, 0.28683367635934587, 0.12665870314043376, 0.16791253020205807, 0.15469656355919378, 0.09974732904905274, 0.053473496358961835, 0.19282917221707685, 0.13571929396881213, 0.13410113241162994, 0.10753500350420514, 0.15840700316813686, 0.21077746315108192, 0.22641425231291404, 0.1501950309161217, 0.18589721031246648, 0.15895265695308486, 0.1566541327103492, 0.08306886715393874, 0.07230598299253373, 0.1205921984247623, 0.2075144801769526, 0.23958439157614786, 0.13528873723360801, 0.12368813592700229, 0.1773909070799428, 0.1790636600626092, 0.18666524410007462, 0.16107704941063158, 0.07815124151567299, 0.1835823071099097, 0.17221923136422712, 0.19858336586865688, 0.1728952426703707, 0.1586087294403584, 0.19603563322415277, 0.13691777723931498, 0.11535749665551609, 0.1603560227780573, 0.1120868604630232, 0.14244291060153516, 0.1626477135165084, 0.10202559792707044, 0.14025874796413607, 0.2257011470294768, 0.11131290481576037, 0.15967585927536412, 0.13511409983038902, 0.1887139777142194, 0.2562941634847272, 0.1755950437678445, 0.11669016022595669, 0.1326546358365205, 0.11690255810296345, 0.17454663712170818, 0.1753451458869442, 0.2115668707917775, 0.1761285473983134, 0.11328961850414354, 0.1199449613810547, 0.20385043485270393, 0.1610684385823627, 0.1870210919409029, 0.14035089301966852, 0.09909634583539541, 0.11715934311430301, 0.15565357591596343, 0.16841474680169938, 0.1973076149701111, 0.18890669479245142, 0.21942181542756098, 0.123872640542686, 0.08553783063806834, 0.18744449341489425, 0.12398447405787245, 0.10635034812073554, 0.1172071086963819, 0.27479518685610066, 0.11570625818304478, 0.1668169018962691, 0.17930157632837374, 0.12420854711484526, 0.0947366773541416, 0.14152116893279937, 0.19459348802845325, 0.15598101721655938, 0.16182536409506876, 0.13706721034982514, 0.1115657291525314, 0.15119696666877117, 0.10874768238394492, 0.2156330969545149, 0.17860907881009966, 0.06362047647276232, 0.2678399971656261, 0.1027074927884725, 0.15672360156332293, 0.32793732720517343, 0.13079402277306204, 0.09953074067110017, 0.07984013597090399, 0.15476269226881767, 0.08626497831315764, 0.11175230986648992, 0.1408833700923189, 0.1804318318083402, 0.1445240650566355, 0.13768910520499753, 0.1091379811987281, 0.17171952753297745, 0.10735844322029622, 0.1057619849340089, 0.0917211867448303, 0.12178752541301713, 0.14731354440652555, 0.1332662038264736, 0.11619679960272006, 0.08330992438019284, 0.1352818424422895, 0.16325862267084662, 0.14795155775162483, 0.1322015101510671, 0.2667840522143149, 0.17289377178155607, 0.12567590426413283, 0.12675652490748515, 0.12927552925482874, 0.13705504487358755, 0.1335739260238986, 0.11787220324960448, 0.10009338628620872, 0.1950779007447343, 0.12254772978203914, 0.1121622971409271, 0.2614283621791871, 0.14658805914223194, 0.25006957652588047, 0.17191582990269508, 0.20487935222204656, 0.18117720471514812, 0.08079082810229833, 0.13550144920666374, 0.08883732536266889, 0.1451689578712948, 0.18183988609140922, 0.13847071407062395, 0.08097635927580057, 0.07369028088907081, 0.2300003711735049, 0.11406044851267531, 0.1760069692447301, 0.16609489467115174, 0.1516868032875561, 0.16475151353065046, 0.1277202098900753, 0.12446973713174944, 0.15458086896086895, 0.16426271879144255, 0.15370095569279887, 0.2220982814868612, 0.13336429372429848, 0.13493327243674186], [0.026629160706614776, 0.05904278319869792, 0.08367298876926785, 0.11556054059896739, 0.06199084274891404, 0.005681235268111191, 0.03896523514882692, 0.015266411505909938, 0.029140548224771218, 0.05433554445663768, 0.06737919494269357, 0.054021387120648745, 0.05040429915571886, 0.03822944217151211, 0.02607087413179538, 0.037754149731969645, 0.08576692923182443, 0.07631728831197947, 0.011779556572887928, 0.01792028658993302, 0.02636702648634392, 0.05365350020809039, 0.07816886919881068, 0.05035078791420787, 0.043253557861692486, 0.03167256840594834, 0.09976357777392673, 0.04140824357408189, 0.032034590915446325, 0.05808775884009177, 0.020657899872129484, 0.03435360034927726, 0.07218504069192756, 0.03090525665620883, 0.07333198156688484, 0.004401690797925357, 0.043000082350185806, 0.05459284657732614, 0.0386116894022111, 0.042942292507617705, 0.03720147092075598, 0.009137540529932707, 0.09110847728387003, 0.037465641019685615, 0.03594366180139684, 0.009103744561153074, 0.013296925857092344, 0.0143321136560952, 0.043644703203631986, 0.05594964574782118, 0.05833545038777013, 0.023947106035906943, 0.04398765778469463, 0.03189327259127411, 0.014973559075095242, 0.030105141021551627, 0.05616277140835601, 0.053605259651498455, 0.059977027422357956, 0.016678841108636513, 0.04658769891266862, 0.029258374462745367, 0.015253902247716344, 0.0788679933776298, 0.028912968400325027, 0.016806373680611292, 0.03923636132610902, 0.043093514433431054, 0.01639432754487761, 0.021074159491446712, 0.040558694200890685, 0.019935314250629277, 0.008825028367761162, 0.06474978200370266, 0.0069474660877829365, 0.014483042553277507, 0.021680981566708897, 0.03726910116271146, 0.019684631129606597, 0.03769205447526709, 0.06238663058367468, 0.018703425716188167, 0.11105673267476021, 0.10049869276342854, 0.0408506732914717, 0.015610429991577423, 0.06804333954689003, 0.03812820365231845, 0.1511035805508014, 0.04413132991401419, 0.05794722001038252, 0.021588225556056828, 0.03694075587836485, 0.06608976171382012, 0.021719783920073704, 0.05118803774577476, 0.04364419375516234, 0.014013222854344115, 0.065673844918849, 0.015555047580311376, 0.033921775738558466, 0.05173734960056121, 0.020333992152084267, 0.04707390044425284, 0.07641938484964833, 0.02693801288372807, 0.04631227881257092, 0.08253669651645808, 0.017270686164979013, 0.02488142112269998, 0.05653383758580012, 0.024517456580313946, 0.05184008582164684, 0.040991296390852625, 0.03110637197331075, 0.05299516638079959, 0.06234974345012058, 0.029047102734987295, 0.05327566947427489, 0.037223875162101565, 0.00995138350258311, 0.049827025091696175, 0.051449974698405114, 0.05501721332210207, 0.04747441121106667, 0.04229188385990359, 0.04699985038549189, 0.03992134352184592, 0.025681688059722225, 0.057302254417370406, 0.11051615039187093, 0.025818520939097773, 0.035940750667284575, 0.031879452365120096, 0.01373665170714019, 0.050496336958941915, 0.11586653909856275, 0.02670477166952145, 0.028332457614822254, 0.01114803965338656, 0.01832300368996878, 0.02600125206123677, 0.04157531202860898, 0.020016540638020924, 0.01208015223739729, 0.15639812144781315, 0.00854723531031801, 0.10625088692552621, 0.045112772814689145, 0.06543574479198264, 0.03365140415788178, 0.01527034536740112, 0.05543572715513649, 0.055424136244842125, 0.04925060138526944, 0.013116062074268778, 0.09463035967200996, 0.026520657758679123, 0.03208643208528238, 0.024845194739980564, 0.015545799941455406, 0.02013365441422549, 0.05008783972551746, 0.03436645147420707, 0.019832905532131274, 0.06268744649846228, 0.07440650415035986, 0.015679841387956854, 0.02665921050544468, 0.06398149157663988, 0.011526543586965532, 0.03694552860613312, 0.04919604060330218, 0.03696257789288798, 0.04698634425538683, 0.05754677819148187, 0.02263785602765218, 0.025950131014049537, 0.022612220810485945, 0.05043788828075894, 0.020180485369036757, 0.007714536998631253, 0.0322193943054205, 0.05795624069569092, 0.03197548723208808, 0.039498922640397664, 0.043691978489439336, 0.015996856231903358, 0.02478697971861449, 0.0278003616709142, 0.07958036321665972, 0.009867725743641777, 0.04634068152236362, 0.04985743878229011, 0.026197834053046765, 0.035228250593307524, 0.024279417740481517, 0.03571377796751838, 0.0396722806767831, 0.043956340110350045, 0.016470907609008493, 0.029029716369545752, 0.02963095749427955, 0.046377859769328955, 0.030698129464121118, 0.00918870562717559, 0.03103959017373141, 0.03771525544805392, 0.08208527154619656, 0.0683346291583392, 0.011257152598831924, 0.029742735468091506, 0.10854501382357652, 0.050495819849593025, 0.021173463638631568, 0.06610650073496566, 0.04570551802434268, 0.039323768127829804, 0.02979043210225721, 0.022546593888452458, 0.05961574801814653, 0.04047116865554164, 0.04455481182723757, 0.059874544010287335, 0.06982201184596747, 0.05860061257056171, 0.04274933411168956, 0.029916964929490805, 0.03197445492861012, 0.0396451841469013, 0.041178788749441024, 0.010240321224104735, 0.012415156741025708, 0.06917847500693414, 0.057442011837396896, 0.049164029619386124, 0.027328039737298127, 0.04554359385022714, 0.013244796446674775, 0.08658970766250165, 0.06296726394324534, 0.020903053753558668, 0.08121240628702987, 0.044371153738710194, 0.05937055391710132, 0.04057287448836912, 0.021648903550099463, 0.05091376294712386, 0.03489283814785942, 0.0940036614455523, 0.05014255755550919, 0.030221605538240368, 0.06148526302328514, 0.08174443136780493, 0.0382076584613852, 0.0048912975903330075, 0.05174255133756707, 0.05212811189853857, 0.036476081417452906, 0.05698133252501007, 0.04579214724682031, 0.032156257169140924, 0.07162044921349134, 0.038171828529166604, 0.0288928643379721, 0.00915807072869352, 0.09619484910921705, 0.026566923723646232, 0.01829527705276926, 0.051810373101503625, 0.051800628463106776, 0.01842537601929038, 0.02452000573788199, 0.07621420352088829, 0.10316693869930121, 0.014651045635072215, 0.039666603965264176, 0.03792837727814913, 0.02733941422775388, 0.031612104916524504, 0.05772433822013198, 0.03195590027908404, 0.03138252368737613, 0.026652949651883497, 0.012734878748174638, 0.017232810778002587, 0.060394660254279454, 0.03695669050718989, 0.029495997699878873, 0.02359411953347585, 0.02032645576212916, 0.016877506859600544, 0.06643242518147154, 0.091241056460046, 0.05079683111680131, 0.018059716507371877, 0.057324149210246346, 0.020452258890614878, 0.046885982906866464, 0.01877253833827713, 0.03437932941221422, 0.04801464875439002, 0.03975634733515401, 0.07035903182000884, 0.04275050239577409, 0.06656722601262793, 0.0034736274673994034, 0.04169190678024485, 0.044814281976751746, 0.04065507189220479, 0.03421523720927296, 0.0347869188314484, 0.019278790306059584, 0.04496645002115158, 0.0037540996779552513, 0.04254613312021379, 0.033052212318345424, 0.009780200198292732, 0.0618203460509258, 0.0243558714001049, 0.05850831046700478, 0.06523923557852546, 0.04748297607406013, 0.044186296722581314, 0.020587435104854165, 0.042763817003898086, 0.024170001232696157, 0.04269584202237668, 0.05877541851312403, 0.06347487380187358, 0.07087185873740143, 0.040893252458303206, 0.03870159748100466, 0.019740480854506456, 0.02782669594331134, 0.04439874822574277, 0.03359983877969846, 0.014706085221992146, 0.04234053427353502, 0.03248458330128943, 0.002385461815602837, 0.0639830160916092, 0.009719879392744794, 0.03653588224082224, 0.07237961170293632, 0.1015466244350518, 0.026153908486688332, 0.04322293349691937, 0.0162928668601859, 0.04095141002307496, 0.06543779790761971, 0.09438344953401435, 0.11949316102771029, 0.1519058278251079, 0.15696125735919322, 0.16410917944965825, 0.13969830868224944, 0.10761473027448501, 0.13936398791209345, 0.07733978586451662, 0.10121680060101133, 0.13621574958726285, 0.1440989322239353, 0.10799284063039288, 0.18834381935096559, 0.13547397729369903, 0.1966542951882847, 0.14032339046318687, 0.16506913358405714, 0.16607445544533192, 0.12875676515602297, 0.1476425944917625, 0.0811544593964373, 0.11790975687965272, 0.13412052975787273, 0.16514728987409225, 0.1560145565458844, 0.09645720357976614, 0.20171830490712198, 0.11126712340140536, 0.10462403027040344, 0.1888686815096486, 0.10126940019789243, 0.11602878119916686, 0.15009991343944304, 0.21449519591706417, 0.20173662973027076, 0.09817469609721054, 0.27786330770581, 0.14262160827075282, 0.09163269592869668, 0.13290877784452132, 0.09639624596363115, 0.12515426733561102, 0.18353888524636147, 0.1275805444005997, 0.12866707158184823, 0.2559644545638754, 0.09828054646570837, 0.10348654292043179, 0.1492140093638051, 0.12704359337447152, 0.24515797233869954, 0.1515925744728696, 0.15468372392558283, 0.19209443261065792, 0.1561119722863359, 0.10544456406346253, 0.11371465174541359, 0.2927627065970052, 0.12749709444300783, 0.17500432869119031, 0.12096276281461601, 0.13006354261550213, 0.10079837103764858, 0.19718209912459697, 0.23404758303396164, 0.12113916222006084, 0.175283613704866, 0.1834444266052977, 0.15667003669565724, 0.14951342716813087, 0.10945748582842851, 0.1273897578639369, 0.1645528975754015, 0.1367097077590804, 0.17531378224732416, 0.10642188541110485, 0.1389633852147287, 0.13264119865432863, 0.15417554716189064, 0.14151681755338946, 0.14618934102116093, 0.07958541173608073, 0.12808141268549428, 0.1904622669662199, 0.11664823989474005, 0.11106544309445929, 0.15930730969675128, 0.10443600165026803, 0.1708894406235026, 0.08774586457518802, 0.3468740401008437, 0.14190713935081037, 0.1821196767231149, 0.14239588812474283, 0.10460456397624747, 0.18476834911252224, 0.09828495147127299, 0.09868422117564948, 0.203652324515485, 0.06325980993889033, 0.11979241795357197, 0.1871752594747851, 0.12017730052673048, 0.1296887724029441, 0.2312738544517948, 0.11659243038945621, 0.15999796860400708, 0.15601435736302408, 0.07610831484799424, 0.0898296773553856, 0.1285302636003302, 0.10941910482342206, 0.17464845020684505, 0.10867018492952471, 0.09825881255129654, 0.13514045325498428, 0.2123202723000319, 0.11224952391198567, 0.21090285642252815, 0.11775279312484688, 0.12226579410414543, 0.07303673894174638, 0.17597416535981242, 0.13892765487394027, 0.15165844271259923, 0.12104088846113413, 0.18177219456241978, 0.1776218213020794, 0.08984357419033205, 0.20134252345850392, 0.1310522556905785, 0.11975001498696305, 0.13170836403244926, 0.12297739019437183, 0.11016061664709162, 0.15570683434845942, 0.15500866777954564, 0.14597699677030887, 0.2377637836240953, 0.095617831684649, 0.07991054711202461, 0.12157816124419052, 0.19940954572971792, 0.08252444677054882, 0.15878656909110087, 0.21961764282276555, 0.10664857082789946, 0.12559368770809906, 0.08323416594536075, 0.1450267106655144, 0.1013276152192585, 0.08826915625362627, 0.1370413625432599, 0.1819638084740408, 0.24656590404770068, 0.1196801707509064, 0.18112648969456074, 0.1648167229347652, 0.13677061174906072, 0.09059336742446308, 0.14774857509520747, 0.07695859583515315, 0.1492779164184486, 0.10484676267350874, 0.19765393267716133, 0.14802456593080876, 0.1781097733445706, 0.13276680643039365, 0.18638637277387804, 0.13261836923418507, 0.1404761330735299, 0.1197540675920825, 0.10501915543910958, 0.09045455229258345, 0.24559977524463208, 0.16999009936567278], [0.08173709990636957, 0.05630205768430906, 0.04041308769956231, 0.03448815220185826, 0.0711257249537495, 0.08469645925346883, 0.06955317627157896, 0.0438911690106315, 0.02809103649680413, 0.015349086757088381, 0.006821284224579652, 0.03031186601747909, 0.03603662657100828, 0.03478789559355186, 0.014036348175948427, 0.08553062941158011, 0.050667067313747066, 0.030881009973405354, 0.010724147883123689, 0.06877757353527893, 0.1357217607719283, 0.038976098275593216, 0.0406911546334384, 0.029310207971702182, 0.048814241534038905, 0.03252427814708602, 0.03637133804600566, 0.03364709108286808, 0.015730331370216465, 0.046025627863503275, 0.056845194870425816, 0.052443196200915886, 0.03992048933381035, 0.02496371428752619, 0.02978803807749383, 0.03153507860617773, 0.0446794007063633, 0.03627211433805285, 0.05101512787082503, 0.027577635013468327, 0.011928481192538335, 0.036998951747532816, 0.018598527211936253, 0.1187613785206791, 0.0870596259952553, 0.034071304610059146, 0.037511843782398975, 0.043811220074853593, 0.05233333919257407, 0.046788318187839566, 0.01801089180873767, 0.05845277292293407, 0.02420311346800337, 0.03502417626159807, 0.014563939522861715, 0.059352324854943066, 0.019602104307963483, 0.01799938708333479, 0.03238445560958597, 0.02332990729971038, 0.0675186765710673, 0.11737883496548861, 0.015201104425584838, 0.03867811688612546, 0.05286711478425611, 0.033905278035109086, 0.0505574707752995, 0.06252588238567114, 0.052928669948972044, 0.06225730728117689, 0.011516001259517527, 0.1290480317848344, 0.0018945769730752576, 0.03337817506924753, 0.06146034601354792, 0.03771243241405295, 0.0985932175911242, 0.04120633344075853, 0.019591076472293467, 0.04311511811289576, 0.025293492156291203, 0.04171860494440602, 0.018624478440371253, 0.046172142179021915, 0.02572384396297557, 0.04239686471860736, 0.025210249042438886, 0.059516983962948286, 0.05495002358070305, 0.07351509190254635, 0.006377086336273821, 0.025842750384922952, 0.08320122416461669, 0.05878173490805973, 0.005525375158721281, 0.04120815673001832, 0.07065720856189728, 0.06827947082779101, 0.04255510017936749, 0.07064134288098543, 0.052886941139736486, 0.031008107790483103, 0.02232789493826849, 0.016210899282727512, 0.0473412957733437, 0.060222091288456035, 0.0629494677207643, 0.03106386750005186, 0.012819600411720816, 0.016703796422769947, 0.06186031668837513, 0.025954748609013138, 0.021817140288711078, 0.05744588058141451, 0.015693189512427538, 0.014700553109568935, 0.03750375772435819, 0.028601187852121172, 0.08383621146241504, 0.05676163383008492, 0.08689331596777325, 0.035835126294724406, 0.07816419606247256, 0.010498876856159299, 0.01123445628646521, 0.021247057875077573, 0.05915075563074601, 0.013365148859579238, 0.07604253853881553, 0.030451399356787725, 0.057800939351680784, 0.12055530363032896, 0.09320247903346054, 0.061185508140272675, 0.08253077465680339, 0.03985884989942274, 0.007755587820053822, 0.06324924175597488, 0.02839867059411782, 0.051515639924834815, 0.06734595438765903, 0.03736701102987413, 0.05229241094521938, 0.04608029589777993, 0.0368039938621223, 0.04230103861059874, 0.0045154625155602495, 0.05195494538413421, 0.05694009018160644, 0.0664685538879806, 0.02281812992277405, 0.034707582766009916, 0.024127761059771144, 0.03877312711049472, 0.05332242765073335, 0.0023761595929822615, 0.1016921275145104, 0.08672880624691326, 0.06221427229203044, 0.01997473521999294, 0.008105086707209629, 0.043012558092032714, 0.006192746908298784, 0.034430301072256225, 0.02858064903487121, 0.044396568705598195, 0.01401154320657013, 0.03706492723957185, 0.03629857884539712, 0.01531594770870382, 0.03214601840403292, 0.008441352383083394, 0.020137980895777865, 0.035396525636315346, 0.011566425166693668, 0.08641046607085774, 0.056757684646835255, 0.06079503312526692, 0.04791402310553578, 0.035405331817004955, 0.013495891339956753, 0.08413724571226106, 0.07985518193773686, 0.007023292034113359, 0.03378847260929404, 0.03105327633449868, 0.025013002469354582, 0.017690747495620482, 0.011077151622533078, 0.03242037747235548, 0.05430654419826404, 0.056058211898010586, 0.011780416506582932, 0.025804084012164705, 0.04390527268931751, 0.11337252453930917, 0.036658774235195694, 0.02196934472228731, 0.022367555310108492, 0.006172223891612263, 0.01446046211170934, 0.027342164483402046, 0.08545811918954696, 0.04180559422820807, 0.04828420445142735, 0.00978771647843983, 0.0673073818606715, 0.015108235416963938, 0.06323377444078365, 0.04712687925465646, 0.05382624154369678, 0.03125573230546809, 0.04355056631949641, 0.0028097435724996635, 0.02778083792016391, 0.05308273406098447, 0.04603773588314653, 0.01699876708669528, 0.052438373677432544, 0.06426661034985896, 0.07247983898606992, 0.08750789468326876, 0.03267884021624923, 0.017670668331125093, 0.01812505423121395, 0.039839628753402544, 0.012860372568660927, 0.012741120449537712, 0.06311006273233122, 0.04303231933003953, 0.04034954070624325, 0.048644468789139104, 0.031278766654131394, 0.007976916845842836, 0.10145437212720995, 0.040048893330799, 0.020118116235901273, 0.11295080079787201, 0.0268685229633364, 0.037498640257024, 0.04240325006145624, 0.052384050382721814, 0.07256710406152472, 0.02891964294136532, 0.044987345069286325, 0.011966483941632173, 0.05292547919276742, 0.04149241748476221, 0.09263480788156872, 0.060871442734834656, 0.04471318135338445, 0.015168414496245886, 0.08501804764232329, 0.021062892253300356, 0.01435715898555974, 0.005797185548280757, 0.011322800588283327, 0.0830907849294524, 0.02738282076954361, 0.041511523717593764, 0.04763217935819299, 0.04786204020943373, 0.020587211024136316, 0.03200803447755114, 0.029591706979479042, 0.051361794147880814, 0.022418404396082607, 0.04589373433601953, 0.07000281625697691, 0.10167802383582439, 0.034310251264081854, 0.03733678120038202, 0.039878990350952076, 0.033785523170785564, 0.02591867735909839, 0.06258755629401534, 0.056691157571490736, 0.04257956902766901, 0.03985572426069168, 0.02713210700500396, 0.06921591372379372, 0.11548790014198712, 0.01738072320398304, 0.03132062186787446, 0.09957619266764772, 0.03789246690669849, 0.027254236741892757, 0.010742145203684848, 0.019559080810135892, 0.0294599034673264, 0.010739624774413965, 0.024663225875326225, 0.0726810519793822, 0.012619369926171438, 0.03236066474909744, 0.007904608679499717, 0.013698622144969001, 0.0249087359876402, 0.08827921498807208, 0.02798339156734367, 0.05147675330179834, 0.0573786563660589, 0.07416408328760056, 0.038890392189064336, 0.05181098597184305, 0.02154559084785081, 0.07818282732079107, 0.029688235973158193, 0.06550028003872403, 0.11299742490894372, 0.018834468886075963, 0.02621262721086462, 0.03830205581541504, 0.039159403963675427, 0.0695195373508238, 0.024813505512992703, 0.04179815934490293, 0.018069238980270682, 0.04462999952656608, 0.06595417947298096, 0.04685033683574969, 0.01829946180805564, 0.03911625789177995, 0.03295184330894582, 0.03360684848420563, 0.022379391368538625, 0.026480817356176918, 0.0283874454908073, 0.008064024394468195, 0.03548788162128579, 0.024841569228878906, 0.0094218731054195, 0.01313595354722272, 0.07708958920932586, 0.02434861654746196, 0.05570689546725443, 0.011898580780853669, 0.06098014295041081, 0.015870633670279098, 0.06452659760872204, 0.052083732425085, 0.02074768920729478, 0.02670687266565379, 0.05485293725805898, 0.016240207891490673, 0.06001806292202204, 0.025217563266895955, 0.017295166504599394, 0.01073715414085816, 0.06625934293673885, 0.05934985422138726, 0.05940600846623702, 0.21463064026207695, 0.13229219963954342, 0.12146419034369531, 0.1648479333568004, 0.17260860321262192, 0.21594130944821144, 0.13671899274472268, 0.08574517999565409, 0.13809029012918472, 0.098772045495289, 0.07613605489173243, 0.09615837566314206, 0.1034903580382947, 0.13309859911039953, 0.14486118970859438, 0.15720491928438987, 0.16337157467440253, 0.15564793750884073, 0.1660039906780566, 0.2016750669046756, 0.28001111181032273, 0.2566464873211038, 0.11311482788333971, 0.09579066878124591, 0.12147689208147988, 0.12263596012827852, 0.1231828090103884, 0.16319765739383238, 0.09829108017466723, 0.08829102806386449, 0.16831487957989016, 0.13693475374771705, 0.07935530956714384, 0.1968222063395285, 0.13922955480314073, 0.15685343814473, 0.19076458058289944, 0.11673799475594876, 0.12496883575353893, 0.20277492401580657, 0.19331168503530566, 0.09458152922771632, 0.17929826682854086, 0.19853237505641677, 0.2162023156040138, 0.2135988883674145, 0.14668201216526572, 0.1124026036010154, 0.18099559591181819, 0.20432824389107768, 0.09452149091709046, 0.17299881775773343, 0.0929516771688096, 0.11067787155268655, 0.1313016019881733, 0.19829720138542115, 0.10651815201966994, 0.07613728829329053, 0.243372481857096, 0.1548258179137784, 0.142594258931856, 0.23345550432080225, 0.1207151708583678, 0.15353495976136577, 0.11067996297271983, 0.09518371264059698, 0.13838105113996615, 0.142831148639802, 0.14620968831642983, 0.22467809789363416, 0.18451353294714806, 0.24986584310329732, 0.18396472287995203, 0.17602068221857473, 0.10345253627747299, 0.1313270514290179, 0.34671993385399547, 0.26406238696748213, 0.0976851276091991, 0.08583691902458669, 0.087832126075462, 0.1551096381679658, 0.125987165787768, 0.08527765951810345, 0.11084730721889965, 0.1817631240813963, 0.10897748577859133, 0.11657663365645755, 0.14743962715710365, 0.10991257269896808, 0.1402733189564559, 0.10064036540326574, 0.2336771029137796, 0.17955548850999725, 0.14407708339633482, 0.10363413741992367, 0.1422437583847392, 0.16659921035170558, 0.14228452958406942, 0.14458971879174634, 0.1705581995268022, 0.0884535536170006, 0.1527554499766519, 0.13391563188164465, 0.15196362149811563, 0.23241471258863328, 0.1668317180367247, 0.1332133131161813, 0.1677317028084109, 0.07499913444682475, 0.1822876031961172, 0.17212938457246751, 0.12851727841001365, 0.10313914502940832, 0.08843322930436942, 0.1298692473961461, 0.21166005772688698, 0.13435230199848452, 0.14463793636570055, 0.1106747842183517, 0.1134236609082549, 0.1437498259568407, 0.24255109770644098, 0.12295063074317672, 0.16790275492014425, 0.14499645019250532, 0.1882579715381707, 0.1661830867129949, 0.15283688512300292, 0.17985659170775645, 0.20964596660867815, 0.25832135470644124, 0.28934929459806413, 0.10538146906201878, 0.17209204544703807, 0.1057183868702381, 0.12314381513504252, 0.09480832189682031, 0.15753116548782395, 0.1352957852425114, 0.18047617297739754, 0.06191002047290245, 0.1992286723707953, 0.1236070455202172, 0.10894690354865406, 0.11813215986495057, 0.10899699037714351, 0.2449715831467221, 0.1293890634852071, 0.11208492226057476, 0.07906031209014117, 0.09808696370812194, 0.08732197280492514, 0.12453503080553587, 0.1251378730540314, 0.09993137401198188, 0.1491747396968065, 0.1494216191912851, 0.16408307117319879, 0.13854088772448803, 0.07301593965460217, 0.14486177193541683, 0.16725787742724343, 0.1782112340292623, 0.12530063609442404, 0.10452364976968496, 0.10159013822915093, 0.12878636679341718, 0.09124267290556624, 0.09712655758184773, 0.09604086543643668, 0.07279676189946552, 0.11456612016885512, 0.12083763001306404, 0.14418951446010222, 0.1890892841883244], [0.017213706460390842, 0.06450627329609086, 0.03758613898929569, 0.06903798980337959, 0.07025955530304102, 0.01929903992511813, 0.02358187936366566, 0.026266481276721727, 0.06230547505941603, 0.033694465960105585, 0.06587128875957382, 0.012528458272197075, 0.014261259141588404, 0.051973067193983064, 0.03101719359326507, 0.029739134854847388, 0.06086154487885295, 0.031836231599652, 0.005792578008221162, 0.05931623062239059, 0.039496080454198584, 0.04557257878684229, 0.05280406957852745, 0.02354469920148052, 0.04659678471545058, 0.021933984018922336, 0.042813662514691396, 0.06735035939322365, 0.02703084933361219, 0.07407799798754916, 0.03806605093902157, 0.04237813003841908, 0.10577094816272298, 0.019422334115651828, 0.03137023563707068, 0.04178303676927763, 0.058677309463101054, 0.07999873149298853, 0.03841540618469158, 0.09976098839674266, 0.007406798043032929, 0.06874728241875287, 0.03330941101716411, 0.11827819920595616, 0.025779329796111392, 0.03246568774263705, 0.026618333969024882, 0.025564187409115896, 0.05393844661152652, 0.07117342158791519, 0.010941436273917075, 0.013236945003060805, 0.02695005004023833, 0.060865494062102614, 0.0409664674812267, 0.08070697977898583, 0.0349338008691707, 0.02791243841901662, 0.06505855374158391, 0.008033811801954383, 0.06866557148074912, 0.023821842999407844, 0.056098757101403135, 0.0234127214043251, 0.06075283700239755, 0.04756986959687164, 0.03806702387068541, 0.0465770656122796, 0.04302132213788648, 0.015419517050407108, 0.09027617638029399, 0.018890927650875623, 0.04866993738218181, 0.0568331481378165, 0.049898895630312544, 0.04948247704775103, 0.026360047425353722, 0.03016163617552769, 0.026852940734956535, 0.05158320121887711, 0.05579396902072815, 0.0360713878105725, 0.0853024731059709, 0.056239893479693326, 0.020565521159780123, 0.08519460792623221, 0.044160142480846376, 0.06198183738536412, 0.04563997537198086, 0.02258226485742677, 0.05155115576100446, 0.024533004334737218, 0.08926291784812367, 0.07220335019331786, 0.04851323792770986, 0.059924784056361646, 0.006081662244058305, 0.028372286526005597, 0.02550150609515127, 0.021644556001129172, 0.08363625485329859, 0.00814685765128102, 0.01969331856666794, 0.03373673103088814, 0.02282700505137684, 0.03848551855152173, 0.025952885100137324, 0.01350336452765811, 0.04665285086018905, 0.007992249138037404, 0.014617832850724941, 0.07198990277585483, 0.09780485183000566, 0.02948457532892785, 0.09351537232437442, 0.05540317990967343, 0.03615740033227109, 0.04531547584901414, 0.025120522909527345, 0.04400721217896189, 0.06909812004455636, 0.037910098420275797, 0.026574944664213448, 0.012907848952548399, 0.028275453012376547, 0.022593057121060068, 0.09653873065666807, 0.032385198714872526, 0.054010305658824025, 0.028134711169367357, 0.054021647590542995, 0.024056271649897102, 0.039771182627807704, 0.08478085149920757, 0.057438656372288545, 0.0712372060684908, 0.03860683623521078, 0.015077147568996637, 0.016168841055684512, 0.03199297893461922, 0.060837221587257045, 0.07630877707514071, 0.07397315885511137, 0.0466405819620817, 0.021473009762684667, 0.08277344066769847, 0.04231820664098186, 0.06384793946880006, 0.05814517329957697, 0.024974301622639743, 0.028636697942631382, 0.00846201568962105, 0.02449143640396576, 0.02190173746296956, 0.05653403676866044, 0.059772746246908946, 0.013830046443599127, 0.10321969151376717, 0.046423966771051775, 0.008710963621495232, 0.05115915623102939, 0.09668884558543082, 0.07364098313114337, 0.07699168317260281, 0.08252055504389348, 0.03814480860807723, 0.010040260235508604, 0.027510989194495544, 0.03359194807407837, 0.04444631845540097, 0.045239862970887654, 0.021910647065528942, 0.022076171852888602, 0.0735359141723283, 0.02505096787166211, 0.0260247920279301, 0.06800874301622953, 0.07476528610793814, 0.031727753549573884, 0.03834392252047697, 0.02967607241214043, 0.04156689655276076, 0.07626499515026808, 0.05307306220094043, 0.00901071563167798, 0.03499820588096496, 0.004759838338941336, 0.05172179801569832, 0.01811907491496494, 0.02095883836098496, 0.031223445529899294, 0.03276033281919456, 0.026596163384496208, 0.03935839147156766, 0.012905371615723258, 0.020671202988934614, 0.06080273613934556, 0.03746595511573457, 0.03354091129656281, 0.09769888654831918, 0.045948789244697946, 0.06488655168082445, 0.020676824159079024, 0.0705840471651285, 0.03314919138868009, 0.04989974981834812, 0.02436402449083905, 0.06010352769085477, 0.0704588224330256, 0.04526033284022443, 0.021288440029527393, 0.06370518281455002, 0.06623875815421343, 0.031995079930751555, 0.050543612244749264, 0.06095583115013377, 0.020911407942372947, 0.06526269319076693, 0.04951885856327511, 0.04026184662155086, 0.01733044485351251, 0.028260700074174715, 0.014956702267931355, 0.08648711316768201, 0.024005723253433264, 0.050935075513177344, 0.028857873272030588, 0.027894690077030854, 0.0034099454510836836, 0.0529399199501401, 0.014851601707989411, 0.12062445838725376, 0.022816388987966126, 0.05884332837717188, 0.03662674409908153, 0.027770505309285178, 0.05456757716714375, 0.05777262474199938, 0.026896540713947148, 0.07844478342561953, 0.05296945647006074, 0.07492762779997242, 0.025986897488755566, 0.04177020862698556, 0.039002191230294206, 0.052026406065711094, 0.030203414780478326, 0.05460162594493839, 0.04081963523921948, 0.04355585232617394, 0.059189450731801416, 0.020214861649419033, 0.05033668040508225, 0.03570230580085228, 0.01110473174541708, 0.02503880814108397, 0.07788891768864087, 0.027533502603370338, 0.06557007064862598, 0.03506269899287051, 0.025617606720075976, 0.04263110376233536, 0.016080200852405642, 0.059019279621180996, 0.12418966304751174, 0.012854377930653433, 0.03961724492030279, 0.04804611964631946, 0.0680727726449409, 0.030440879054367546, 0.02575670147404796, 0.036663646554394115, 0.03366074276967876, 0.01605527522417927, 0.06540741486054275, 0.03958781948313117, 0.04016972837909576, 0.034802516381586754, 0.01876884387926229, 0.011114781861373735, 0.028636240205096624, 0.03719498981691657, 0.008996397448373179, 0.02684830781823445, 0.02799626184447158, 0.04187584066042497, 0.051658668540297985, 0.03434447241165946, 0.08580958500744836, 0.03847863908196169, 0.0273117488775883, 0.016222289094941753, 0.01951668550440621, 0.021361113045244448, 0.05174088509633176, 0.037352413224476966, 0.02462910623439858, 0.07841295247236568, 0.01835143704327845, 0.03595205046416771, 0.013037258439937667, 0.01103876391425729, 0.035179584857917605, 0.00547793468520526, 0.029351921459179253, 0.06647177911814182, 0.023370236083264315, 0.061943414245521834, 0.032732734501722364, 0.02493927991318126, 0.078200998926355, 0.041411583717431755, 0.046941501298739065, 0.07684713004217034, 0.049566551367001194, 0.006942002923272911, 0.02872152877370677, 0.0352822253180127, 0.0655057345847449, 0.040632089254476374, 0.0357762792508208, 0.05618249051152699, 0.04738736830110993, 0.05646869712959855, 0.023668127457400965, 0.05869205282520383, 0.02021692817159478, 0.0913284670922064, 0.020096286560498902, 0.026957651547667, 0.01751906910700904, 0.08513544295584002, 0.04416706408524225, 0.0287941615698078, 0.02528455765587428, 0.020613466772521218, 0.032111464008208246, 0.11246748358732271, 0.0594689310978978, 0.03398371394723654, 0.023386923393474954, 0.03220860395700701, 0.0632572818487402, 0.01416870614423627, 0.04602547847635804, 0.03469985676929355, 0.0717179109192183, 0.02154933318736092, 0.020624992565342018, 0.0342475661196776, 0.010775829132105555, 0.06423952914173565, 0.11797841367942673, 0.26929204021730735, 0.06894278805702925, 0.17454136643678914, 0.21787068656375333, 0.08308523845288061, 0.19008518316813056, 0.14716843203190835, 0.12029005334742608, 0.15074437724486475, 0.1124345877718541, 0.08290749839356831, 0.09474202464785307, 0.16948875610626515, 0.15665595599960896, 0.11898889131243191, 0.11360228962955937, 0.09088271117258458, 0.16194078290174085, 0.24969718118588774, 0.11002445217943001, 0.1405949533105858, 0.10140391757651683, 0.19189777784049514, 0.16221594636238393, 0.22233131011166882, 0.08391803731360743, 0.19916134856400952, 0.16919283166287408, 0.17493283736609644, 0.10209865207152982, 0.12082763256565218, 0.22669061087071898, 0.10774784571220798, 0.16058442423180228, 0.13005721472924756, 0.1968212410687439, 0.12313967059937217, 0.1933333500018043, 0.1581036323501218, 0.14612492834848745, 0.13840084685192955, 0.14793940759714574, 0.18197611184610477, 0.12377697914358109, 0.08780324456071661, 0.1775560296711422, 0.2125050986726438, 0.09340636567362855, 0.11301791010003899, 0.10234576139238574, 0.07709729605384412, 0.09517789037237245, 0.11668975419935682, 0.15108877973210427, 0.2662567079307572, 0.07486033463670362, 0.16834835762218123, 0.1354645390904719, 0.18057781752319108, 0.2151188527744624, 0.18530315509246242, 0.12296675689398281, 0.3566085967806078, 0.07878396885409471, 0.1712707072616585, 0.11465772896284059, 0.13906691433681598, 0.09025573715447419, 0.13113981954032375, 0.22334204055368903, 0.15029454573748574, 0.1357499987728173, 0.09633879703018935, 0.13816663845171853, 0.11860352610388111, 0.09544910081932623, 0.09766136356178792, 0.07894714558196646, 0.1312561423307465, 0.1823848197537084, 0.21478099267809622, 0.2864393862264772, 0.1879410103203789, 0.08458039693294034, 0.24337216010016782, 0.10012052112048674, 0.14625799782093496, 0.18117862963868728, 0.08281344577910439, 0.1573667323757564, 0.11244922005120786, 0.18619462096643064, 0.13000967131266672, 0.19877839653242022, 0.19273923349476632, 0.13698274149529396, 0.1579397661431182, 0.08429398730156884, 0.21936489509478693, 0.1780121430995003, 0.16881446083707197, 0.10755672975773774, 0.12269655002220986, 0.1467867670280318, 0.14341008128418078, 0.10015487250301147, 0.0927535898142284, 0.15230571039982382, 0.260405236434552, 0.10586311620089317, 0.1690913709781824, 0.23046560104816194, 0.09809920579315194, 0.1487353269851977, 0.09046517793209323, 0.148493304488159, 0.13939031069317173, 0.06296233416745259, 0.10423861909657718, 0.12714212760329247, 0.35167140525675594, 0.11126447273718734, 0.12168627157206498, 0.1587681063721257, 0.05432291932764554, 0.12486654003300976, 0.1525214560810597, 0.08046577699602613, 0.2612088013800883, 0.09920460938085472, 0.12887019213409195, 0.1325687114149332, 0.14904406041868273, 0.15384588420631426, 0.13468050938700477, 0.2944527272014849, 0.20833158955699016, 0.1304808307078577, 0.1774301920686999, 0.12117216528783883, 0.12327894538400636, 0.24456512753761586, 0.10374545765620086, 0.1330113263740655, 0.18109291972171876, 0.14639969344340986, 0.15324389231541466, 0.1325241097759816, 0.14892427491084223, 0.09275594936503519, 0.16256943465240542, 0.07742242376890875, 0.11457488421470889, 0.12944799096834275, 0.17300850110909632, 0.13895779277288145, 0.24855664480597744, 0.1593931115442707, 0.080602454742597, 0.18210813943897525, 0.207075389222272, 0.20585729410090756, 0.18522853812863752, 0.09428809457007917, 0.16060968981154505, 0.19351103643496192, 0.1696882300799893, 0.182133435662235, 0.14468508141656078, 0.19502245130077486, 0.09541153186751951, 0.09834842185579962, 0.12868725033777376, 0.12247325837491982, 0.08849682226296395], [0.03085800435303921, 0.044251988762088364, 0.051016472355132146, 0.03547197763597773, 0.04727585271241204, 0.03378460386527642, 0.05599169248354532, 0.06042782037008194, 0.031050752074788177, 0.02323570146766161, 0.04527409944022375, 0.024627560652011347, 0.0709652601771297, 0.05043910253011892, 0.06310482652136876, 0.008511232050706544, 0.04210277505579495, 0.028319121939280344, 0.015515555747814718, 0.048933915959130374, 0.04925232125265945, 0.023146963588172392, 0.02173889589856469, 0.033150378824962724, 0.02751124583395018, 0.020160999922682683, 0.05239047786040653, 0.019719560908514167, 0.062473554750003164, 0.038626842621353366, 0.05996390433621503, 0.04993292908634871, 0.04476700286050478, 0.09773984160875121, 0.0470231892541051, 0.06313465798514024, 0.07075449406740165, 0.03487439075064275, 0.025767193048170982, 0.04422162869764913, 0.05212371838429282, 0.04397067744585295, 0.013820698255703095, 0.014923128464649764, 0.043592111267630136, 0.011538032033000023, 0.07893640502926805, 0.039660364179120916, 0.04690429623869639, 0.04997525161372558, 0.05055754355365231, 0.07295947131370345, 0.05382657479194384, 0.03439540959774487, 0.0037207298455834994, 0.010789554554878945, 0.04544284562730501, 0.005750820949493397, 0.040107851457451625, 0.015107665639070254, 0.08208398451848377, 0.04880197646637117, 0.057473256733388677, 0.1016808890046612, 0.030602849193758545, 0.028617620438096986, 0.016996346248854554, 0.046898343735524727, 0.04497340226906442, 0.013010398439702489, 0.025375492292486375, 0.061289872298197406, 0.028553207765423486, 0.04560030733926162, 0.011966582575452425, 0.03846107268585794, 0.05745058053082997, 0.03598976880311966, 0.04979786778529806, 0.06835447083557807, 0.05045185789405819, 0.06471209047782807, 0.03152254349251669, 0.047015899927505565, 0.05693683813836786, 0.028609316044997786, 0.03389649100661759, 0.07467005371807084, 0.04211621223798683, 0.010661868765319308, 0.07648422653155942, 0.0477952603250742, 0.012686172793168696, 0.025037703059253194, 0.018339978283151023, 0.04827699556405987, 0.139256383202249, 0.03300188800259944, 0.06221351003454578, 0.03143063783946057, 0.04078885765686151, 0.008684389946621754, 0.03639325965195894, 0.05513278917679864, 0.034094873305049636, 0.03493930521090666, 0.039767930584569136, 0.01701845937678891, 0.03702784475359706, 0.10792931661971154, 0.01323818989593776, 0.04168336873032874, 0.04649650380616227, 0.12213087069892115, 0.06511728204185925, 0.013934431668941774, 0.03835271720984771, 0.050040250343661156, 0.06008578126408881, 0.053149617367213776, 0.017674010389694766, 0.03835735970266885, 0.042039890728530385, 0.021335383982307488, 0.05659567237260842, 0.06709869184921827, 0.034771267655155355, 0.04515306520906668, 0.0591545477659712, 0.10278221700460681, 0.037916177327954964, 0.05057265080751912, 0.008192787495171352, 0.02716113599167476, 0.031849957980035294, 0.06742676900279138, 0.11387702408096484, 0.04108694246819904, 0.027464690670791655, 0.029037794766707287, 0.026472804076488943, 0.056964991869585174, 0.02588051277393055, 0.05059032445593227, 0.07964153533741351, 0.04867740290900392, 0.07515552363568738, 0.04258109354263833, 0.04011791019189743, 0.06450812722886763, 0.061547557462848006, 0.03037635338372521, 0.010446559754200281, 0.046713728037092, 0.07612408859835518, 0.04777412012880368, 0.04987310144990202, 0.06459343111923625, 0.04306018194784561, 0.03879954182212392, 0.051430362847543536, 0.028594348602177157, 0.054657163489009106, 0.0626810458338549, 0.007281640822428369, 0.06198102916260401, 0.054762427800244866, 0.06913432535985786, 0.017606071797349764, 0.03048707415620166, 0.0241894809333908, 0.049477780928775195, 0.022488244801699635, 0.055448777462926604, 0.04253577944191714, 0.11947970852375993, 0.053841046192833496, 0.03300062012708476, 0.09306426145016186, 0.012881807708782295, 0.020144312612472043, 0.00948188077252839, 0.03729571122676134, 0.040004176778658744, 0.0033332861447331287, 0.04601805508437176, 0.011358045420849757, 0.04052405553539434, 0.020968795588780797, 0.049381667537794965, 0.07793650707049717, 0.05183057100962728, 0.05554294116013954, 0.0065121687047423864, 0.007859050388252664, 0.020039632443278547, 0.07876538356105167, 0.04913317159779611, 0.10648757745061191, 0.039989115490067395, 0.03517247556198028, 0.04051396232699195, 0.099509627287907, 0.060109801950954625, 0.023507764187431144, 0.037493737294308604, 0.05233790124616316, 0.04432797702329774, 0.04684942902155942, 0.03972864942625165, 0.02857837183851629, 0.08546388017073756, 0.037091793943076365, 0.03202467007682689, 0.012601709684296962, 0.05366715955578032, 0.03499431798474924, 0.041295479262067426, 0.03352245623846689, 0.07968754657814581, 0.04516881214635027, 0.017078396180764805, 0.046782120536532135, 0.039064830409423004, 0.061474265831132094, 0.025747247949062337, 0.0347781126507588, 0.07091052319493986, 0.017987516550948063, 0.02672739616114526, 0.04066068348625014, 0.024348354162347895, 0.06466745053448024, 0.011610322004754939, 0.0181101193471301, 0.03720895176933658, 0.05842098793495567, 0.026345198726161357, 0.0776580494317797, 0.10004568199116377, 0.04441352223136252, 0.04661690218434219, 0.03775518778110704, 0.014628522650098369, 0.05324211099275178, 0.02982906400105886, 0.03433438303369669, 0.027187364926982312, 0.016435476042510524, 0.032641593021370714, 0.014147504660931808, 0.05955709632666362, 0.021786990898451018, 0.05800798227409682, 0.05444342878857448, 0.07304118991258644, 0.07574505127605892, 0.039828248517287355, 0.02389440301715607, 0.06270589006523933, 0.0287020797165291, 0.06526869165921403, 0.024934765740087437, 0.020912237232550982, 0.03639223309414041, 0.08756177364698342, 0.057985451628243735, 0.0864734384982336, 0.08808778493755287, 0.01731378244115941, 0.008303677764601045, 0.01646402047856921, 0.013383960148559944, 0.028183622052893046, 0.03383949789549074, 0.006194615684029076, 0.05963770792849603, 0.007383892971706847, 0.03125522477221826, 0.012297569905527899, 0.0029599750902683988, 0.030559588208674427, 0.04347309184771392, 0.020524391814345316, 0.0044939478938167375, 0.030576024625089862, 0.04616306786755881, 0.028555427505184087, 0.07733035532216873, 0.09281876091394695, 0.08810405664506459, 0.035068142047572526, 0.01443862381781782, 0.04880213734483527, 0.06361998234605117, 0.011393787252957062, 0.06115879848479264, 0.041469733621324265, 0.05727740252510675, 0.021615904312761083, 0.011600500757565663, 0.0375255759084417, 0.03806346156183751, 0.07790155047851224, 0.048828647817454995, 0.03409266314138809, 0.02254555583931506, 0.059590191324992534, 0.034116833215399135, 0.022269748864815603, 0.01575152231981197, 0.051095796929251765, 0.09032496085931217, 0.030375958848444205, 0.008031198963327634, 0.04344895241721984, 0.08511079790731592, 0.017873484363418915, 0.027743291950994925, 0.04131765750747535, 0.01845029111380779, 0.04017086985010294, 0.04675392850091861, 0.04572552058004564, 0.023211462445737376, 0.031353239976470514, 0.03560862473903164, 0.04400367285275171, 0.06629258349177337, 0.040899465431369124, 0.06584994555000337, 0.020009408359445875, 0.06754601824908488, 0.049927359627139185, 0.043599791299071045, 0.042701733238514394, 0.030972683884864374, 0.01361027209749145, 0.054633334324124365, 0.01711649564845908, 0.04186485495959078, 0.17621419602824798, 0.024429019390335007, 0.009512575042824592, 0.020281235507178693, 0.03175892949765248, 0.058322185575361216, 0.04530989872892538, 0.030139716484794216, 0.050181781257232355, 0.02636173090356733, 0.07021809462457895, 0.09411575543063302, 0.17829656090226867, 0.1650727954843352, 0.08599117082814056, 0.18819875294162383, 0.14051716474275436, 0.14022407482468313, 0.1856032470541616, 0.1942050354855676, 0.23557928390800956, 0.13795697550860145, 0.19099069909463007, 0.15505414275873095, 0.08146987311662206, 0.11739299993120855, 0.13125995744860944, 0.10483998279537886, 0.1690130921140794, 0.09493040566843364, 0.12995330256319818, 0.1555611857122952, 0.1257408302157156, 0.14909508187443982, 0.14969316671692556, 0.1198808168391547, 0.17072145286346638, 0.384685903066589, 0.2506787543215098, 0.1737166574645427, 0.14037905441176507, 0.1527051026782682, 0.19326751240559165, 0.20493250340223315, 0.18445797625087923, 0.2827245952381242, 0.1878636047965096, 0.1653827393367406, 0.13235029974772086, 0.192240234464407, 0.17793971714713883, 0.14810635347760495, 0.16096621180974668, 0.1584194137925102, 0.22728817477341623, 0.14437472387667627, 0.15244299335585487, 0.3031626259607654, 0.10240430583155925, 0.11660792834816441, 0.17482576891779902, 0.1268435371739249, 0.17867978872551074, 0.2227517698080309, 0.13848168444969963, 0.19844456605853575, 0.0327708626977138, 0.29331239000443493, 0.13588686804136924, 0.07751076136745753, 0.09946972176793123, 0.1315504426677381, 0.10168776081334199, 0.15755618591943096, 0.1946343205148174, 0.1793658204617039, 0.2192620860953485, 0.14159004023719218, 0.12679698967164563, 0.12605353198464841, 0.0873463420617965, 0.1059075799440184, 0.113472253865292, 0.08965842606079194, 0.1988629419957438, 0.11836535702910154, 0.15662511329977744, 0.1435814704746008, 0.19431270148244598, 0.11624513208986291, 0.15461120604267045, 0.16265618644895094, 0.11838481566237828, 0.07222418012397905, 0.17070657543597684, 0.13501856866623127, 0.1636885818574698, 0.16213167669071307, 0.17012600336344014, 0.12522473210288634, 0.12741762814262222, 0.1875489724860076, 0.1572544085642984, 0.22836701043190497, 0.13674222053058688, 0.1324397941390353, 0.17453194355532048, 0.14561854423053805, 0.16271805570971581, 0.13912472333158218, 0.08308926807536234, 0.13162953358504081, 0.12443194601444468, 0.14965366722354967, 0.11267945245509187, 0.15574532260577525, 0.17030465506738232, 0.2299359278573144, 0.10339146374814934, 0.10931565231012721, 0.16082462343958118, 0.14109459585480152, 0.12179422868235458, 0.2299656214252595, 0.3106473049809856, 0.17069398095050167, 0.10003753847652867, 0.10712954380940046, 0.19555762500291873, 0.1481614505211192, 0.1278177711872324, 0.1076601133231194, 0.17351614161124154, 0.2057777128873333, 0.08214494979549801, 0.1789156518756382, 0.11198281806202666, 0.06825311740319576, 0.16856765795138576, 0.15201308013450715, 0.1067935299849318, 0.20818554255510532, 0.1403973485913969, 0.10335240092489029, 0.0977781919702407, 0.15908833112447493, 0.18127200043489858, 0.18356830302265384, 0.23863422804542128, 0.11175792529097489, 0.22357722954644313, 0.20932113000702476, 0.21593855153168404, 0.10795353265899806, 0.20770031778562456, 0.2627633469960382, 0.17262636113070673, 0.12183377414100593, 0.09440566608381849, 0.12828467113356437, 0.15022118515785665, 0.15472317745368327, 0.16157811687838647, 0.06869921040150427, 0.1157132602266727, 0.15014761007360874, 0.1442168025119651, 0.1083029147177454, 0.10106076381259388, 0.12116140941338194, 0.09428542858410267, 0.17592101417962583, 0.1487756691752903, 0.23623906947191686, 0.19087262962373996, 0.08409472017158424, 0.18878580611799994, 0.15160605762033694, 0.21353380153736762, 0.15623678333095967, 0.1188887712816077, 0.18711496835514424, 0.18741574979597525, 0.17697858323733653, 0.11766368177749457, 0.1313870207917306, 0.27347454320519204], [0.06464249138990719, 0.06506160277152254, 0.05008514309602399, 0.04248381186757357, 0.11665540281683208, 0.045860306089443546, 0.0561175607295046, 0.06050162528070712, 0.06761186350617679, 0.016143134975385283, 0.044992918358935464, 0.03947587488519569, 0.06034373455951291, 0.028330023370442853, 0.011261097951641968, 0.017860914775801283, 0.11045852525820656, 0.05945008150452088, 0.024972361504971504, 0.01880157498582717, 0.02393103542647535, 0.04957689355397898, 0.08426659199739657, 0.027465506554431016, 0.02362514992484883, 0.04101272003965513, 0.030978822164357673, 0.0484359473170292, 0.054345967082847516, 0.012395612880467408, 0.08265919397555052, 0.03261647682877318, 0.03757984174655811, 0.03822218348842956, 0.021197687338797316, 0.022045501522840034, 0.03299175265936121, 0.05128259980870832, 0.041668970107791886, 0.03380276397952149, 0.02930824104095659, 0.060991818130376844, 0.05159378472355105, 0.041675600598776535, 0.03277607209559891, 0.05891833221539856, 0.029114371000398553, 0.03594627799165826, 0.031031299187170885, 0.07243300803125867, 0.050964213667377356, 0.029087716886293025, 0.0304810144007206, 0.0260590648864426, 0.08173260297025405, 0.005180936282305348, 0.049202950716379194, 0.14448324789202985, 0.04678179494916432, 0.04143494939912231, 0.06505840052399905, 0.012556869600478922, 0.026592641295264327, 0.030548968314824086, 0.031721688048433394, 0.03996167805105929, 0.010908894774113453, 0.02193896359043016, 0.05781350702407861, 0.03833641868925864, 0.02067493192190605, 0.045067439561769854, 0.018820355631290905, 0.07734781446596307, 0.03447363866613277, 0.041471135562225696, 0.04835712070006037, 0.04889477269663926, 0.0023131641829686783, 0.022738516150463014, 0.0883957829266306, 0.009321839259486766, 0.05695081541254636, 0.08528018760825358, 0.08156201051127526, 0.05752317119209517, 0.020490906111175017, 0.06001726236014117, 0.056548791622082074, 0.026722784311841094, 0.062474500868589654, 0.05295294727529249, 0.09811282683644565, 0.031938205563252976, 0.03716725743405762, 0.012578760562915237, 0.008977192581721373, 0.11637905958078562, 0.06296393146077472, 0.009255644474779407, 0.03667952372662483, 0.03498214867807204, 0.0027130491517093638, 0.05857640802259407, 0.08039516667204519, 0.026972082728940635, 0.07393658581760622, 0.015474719431010947, 0.020787401290069667, 0.018509193699085907, 0.02351099707847161, 0.01312226547123564, 0.02703362831755752, 0.01398175483524439, 0.05070172130100189, 0.010202598097103258, 0.020364108983607545, 0.021959000620089715, 0.037285150704725135, 0.03983120561667508, 0.07624067951955142, 0.031240680592975793, 0.007177562032255435, 0.05598022797775846, 0.00799074138124143, 0.030126823225028576, 0.01202987867497629, 0.11297348466130996, 0.03673857378382837, 0.04312729891089182, 0.04428199642608243, 0.08485151544934319, 0.04572152926196014, 0.03110276944484682, 0.05562992278306235, 0.026641586652746605, 0.04632483499364988, 0.05179804291636233, 0.07605683373948259, 0.04003963898867369, 0.0770442980912424, 0.04399456789777164, 0.02829725587470157, 0.06150354954203772, 0.05644828854729572, 0.025415809584721446, 0.04614025759961336, 0.06194969233606131, 0.005807607216880687, 0.015348800431726681, 0.06060506247224347, 0.03417792872736051, 0.038001201596231236, 0.01627639596981387, 0.03353806911036372, 0.05264798682483454, 0.0514993145911684, 0.04665781894037801, 0.008196694543585181, 0.02223876060827846, 0.04038432875888483, 0.06049774887581026, 0.01234450236698913, 0.054259671108616944, 0.018566910763301196, 0.007111502749349683, 0.05260618523724618, 0.0041181238315578916, 0.02249860231043591, 0.032823558055585435, 0.021863021294496233, 0.045761561186443415, 0.03387823513138198, 0.08100403037162558, 0.04680873443102164, 0.03615596008697345, 0.021739786475776665, 0.06714736907592705, 0.06559101549247581, 0.057937509845942266, 0.0694420935225583, 0.043226545601482355, 0.08605182200910584, 0.06400970659489114, 0.06187744641436204, 0.04231798447548382, 0.04740519516710793, 0.04273189412009332, 0.051731228558046204, 0.007050133360955384, 0.03968831106659867, 0.0780284529431693, 0.06585837251717044, 0.05534420646126232, 0.07393382024019957, 0.031069394824425542, 0.039058828110536264, 0.04552703485974381, 0.17631740339340704, 0.06687503247972458, 0.053456485376603184, 0.03586620648181246, 0.036338572465484185, 0.0374621131847943, 0.03461397448254209, 0.02141846813291552, 0.07705172914410792, 0.018983386802457033, 0.03668523108166072, 0.09588069177322811, 0.03142652394730718, 0.006456329034746535, 0.11045026683038282, 0.08332655614902897, 0.030791910117371913, 0.0835099192937055, 0.07304795446895784, 0.008362925089445085, 0.04502108358147164, 0.04850897847885086, 0.07802148154305835, 0.04501069925965802, 0.04577509796006545, 0.06025713981099187, 0.0204145711951799, 0.05185464915308741, 0.0749228474113249, 0.02893857105875448, 0.06761573991107364, 0.06556340568368474, 0.06851925634809079, 0.029706028365199606, 0.02738289737833604, 0.04800855069451275, 0.08294763373992137, 0.03120502303054016, 0.05967997299927858, 0.02416105332574056, 0.04483878146857024, 0.1388155149235841, 0.030705269403575413, 0.07359335544489085, 0.08834636259463527, 0.015658187912777066, 0.03708415987691091, 0.05081249378441323, 0.036112358192763025, 0.04533683054990346, 0.03748482003086998, 0.014970808819447075, 0.022348512279530688, 0.01883237938126249, 0.04111439522896563, 0.045547500898640965, 0.02122228450682615, 0.015281318619306532, 0.04096334184249563, 0.03350262605254689, 0.028916078717297608, 0.07716610607120299, 0.09503670036792757, 0.037529954100928964, 0.02451390959322453, 0.09621347270665631, 0.08296880074926923, 0.00850069738413778, 0.03892944352100453, 0.011509709762439374, 0.10160560554434216, 0.035013378252305334, 0.05352068737509751, 0.022897213179197524, 0.06072993097346156, 0.04829684490217798, 0.03143664971444636, 0.06169390323902331, 0.03489142471563912, 0.027945878156911463, 0.01768595944609373, 0.034244141706656066, 0.05693080902640378, 0.0013299965071529452, 0.04374148309110634, 0.002970154722964752, 0.05243019951928047, 0.029600668292973312, 0.05505626082360264, 0.05243227561755527, 0.06857583960217815, 0.01130394429163707, 0.00753055619556577, 0.03950684781997435, 0.02689419648489885, 0.04446716370782064, 0.04140502983523954, 0.03299327717433053, 0.04203239072775168, 0.006111259572207929, 0.006029566828792374, 0.0998157253789325, 0.08841295861789296, 0.025605150130427173, 0.0177706619574418, 0.07460564104539734, 0.13884304812358272, 0.050701797909794316, 0.007110435971915121, 0.04221809810147651, 0.04219110882390411, 0.05656324004033401, 0.027674683031716177, 0.05183450487111846, 0.06438240453961395, 0.04151012560713195, 0.02721977619183881, 0.04558205912490526, 0.022303782320851763, 0.08326668637774645, 0.0729652246340148, 0.06204485577801543, 0.030711995655550595, 0.03588646567697006, 0.025533155102523106, 0.05183479981496931, 0.049506356008350856, 0.04482121890290611, 0.031974401302455414, 0.04085945648952358, 0.016772008891547882, 0.006505452028866257, 0.04500855038303041, 0.03754172121144591, 0.034226847271765434, 0.05889974309191589, 0.05918599184482329, 0.03934385495320444, 0.03512278709921145, 0.03592397717218246, 0.015378302477690724, 0.027325588255940426, 0.06688203452335251, 0.03891299561327023, 0.004717708769960389, 0.02044779642845594, 0.015194650134822775, 0.038203322403733773, 0.014964785453142419, 0.08296252648916938, 0.0509644549850735, 0.10179261526753826, 0.07393012769640454, 0.05444764993303726, 0.0957368664263237, 0.11701118170974717, 0.14108745591534724, 0.1382430940265617, 0.27149429785147794, 0.1558425085198495, 0.2103806755715801, 0.13852858435242407, 0.15910656401707282, 0.09455130705910345, 0.2382010819330331, 0.12018959623791518, 0.1005167264731661, 0.1337172304310145, 0.1219439069410005, 0.16775690710111973, 0.21453598243815286, 0.17614917048523504, 0.1376725577058331, 0.09454121768114068, 0.11734194017105526, 0.13557145432118448, 0.3159424434265783, 0.23507150551003797, 0.22189260220095036, 0.08778891871653258, 0.11600650336232879, 0.11725357958986876, 0.13463420703286125, 0.0572513708574397, 0.24046888605000513, 0.16007678372965706, 0.18945542825085504, 0.18795162829900944, 0.15893459259983034, 0.29744620044385234, 0.24324593945376335, 0.22867140780773856, 0.15820440355568163, 0.2705192211414537, 0.16632289775917608, 0.1468441623353189, 0.1255744895447166, 0.14758005107362426, 0.12244105203858308, 0.10460056499728274, 0.15508844817598022, 0.10624047579063524, 0.17064164182351482, 0.22862614733317208, 0.17061528839891957, 0.19102589317387153, 0.10533648437910503, 0.12748052396120566, 0.14944110846807881, 0.09150848243265383, 0.13550207739876163, 0.20811376011660024, 0.184457715780985, 0.14706217563681065, 0.11900739999668253, 0.13588130624303896, 0.2204336950014676, 0.16603386810710355, 0.12913780196780159, 0.2185676733572637, 0.08490924017443773, 0.10671322864870872, 0.38912191987037664, 0.13494758295916742, 0.08869441932127362, 0.10390953070694402, 0.23329251145403232, 0.15618507239607074, 0.10282957656008583, 0.21632456791497048, 0.14154488701493512, 0.09662767346467703, 0.15143529662201483, 0.08402303732450932, 0.17903594300150874, 0.10557998542583759, 0.1310629962432769, 0.19776722175940392, 0.17321044188593665, 0.14654243094546182, 0.12369830957463673, 0.1554175595482511, 0.19213065324771791, 0.13984574996415647, 0.20463713054214755, 0.1705249819544054, 0.1842097177981369, 0.09492682803782726, 0.19459457587330573, 0.11798373799050048, 0.14472182299340927, 0.18212254189195173, 0.2218385776805301, 0.09765285998582841, 0.11597447322621462, 0.17333781166422754, 0.07354598822853259, 0.15945660491143504, 0.20830946493773692, 0.09670285733356591, 0.09108813764948039, 0.11873088056041349, 0.203317498127299, 0.19966391756409602, 0.21303294857423152, 0.21972549268074576, 0.20543006218729482, 0.11005927087558855, 0.07294424148576875, 0.10936513392915649, 0.11322466956992304, 0.1120318630109391, 0.08835007046018878, 0.11049921984874433, 0.22169668287519487, 0.14552364125847816, 0.1400818582624197, 0.16197668178187263, 0.14331297197889897, 0.12426248736559384, 0.21230885758996013, 0.25985742228165754, 0.32281085067699034, 0.12538121322229986, 0.12524221422931842, 0.18977703196146797, 0.17473530925569997, 0.21333359211923617, 0.13123099932507162, 0.10871370638450308, 0.15776543517506894, 0.11365746328186606, 0.1148147080394049, 0.16907471622670853, 0.20398074640862404, 0.17645580483780754, 0.33436768538048195, 0.20204818236731714, 0.1420935285427878, 0.171315937092708, 0.13489433984842994, 0.18844394704266904, 0.15054819744921502, 0.1041489408441609, 0.13020476326346397, 0.14642549528469964, 0.07416851893668214, 0.12837652507568562, 0.0837564540486182, 0.1405103159167113, 0.12432959666776082, 0.1470340295664726, 0.23395058098098925, 0.08422914561965773, 0.10189910914989249, 0.15641489877335488, 0.1559344850360386, 0.16457401095859467, 0.12144837828893816, 0.11498495575881774, 0.09641777303430343, 0.10595683939754964, 0.12643351925597077, 0.10264715570355616, 0.1057285528569933, 0.21975777562587495, 0.18471858404096098, 0.20434146656865076, 0.17887468149344768, 0.11756016031628656], [0.018141076960150274, 0.04473762338860862, 0.046347020899937044, 0.03532349830493331, 0.032441115472465754, 0.04026596051370425, 0.04396055359393359, 0.01425516970020028, 0.05660229520271382, 0.010946518309684771, 0.020324837401389115, 0.04693527683435429, 0.009911886882036924, 0.05597154437113674, 0.05520509255509223, 0.020195201918062185, 0.0492844203366868, 0.02321843767628795, 0.00545304496735034, 0.034946674976738236, 0.02883264216624441, 0.05500794748865789, 0.013994943038860877, 0.018031384660712173, 0.03572540335176933, 0.027192168298267552, 0.04706728527502668, 0.03199858861344476, 0.035906414606518326, 0.026874824036513607, 0.03329649094432112, 0.02828420939735107, 0.0483070147193728, 0.1354344931220816, 0.04481916195682941, 0.06697868417587972, 0.017429829439929417, 0.026167439514650937, 0.01688855193224886, 0.027271035134852416, 0.007492203918856479, 0.05262887293112375, 0.06366577525172504, 0.060264950077379906, 0.06140703778533686, 0.026598861929209485, 0.06804137836180388, 0.018231099952132474, 0.0768774594630926, 0.047278208432779203, 0.07043796185884746, 0.028612338261859074, 0.05822218811860489, 0.0947470578455156, 0.028507554670795802, 0.052519747536749616, 0.030313831033004873, 0.024200464719005173, 0.03045307325890228, 0.060442314753609325, 0.06200495408847929, 0.02787621203629721, 0.025351576942710147, 0.05839055509216363, 0.02861469972788567, 0.07931890506898204, 0.06586873002590672, 0.047316673707457325, 0.0346534586541595, 0.0636805339355863, 0.06400653116044498, 0.06003450699931672, 0.04868259315469092, 0.09565917744992242, 0.04939958250390426, 0.052451190328405756, 0.06682507588618225, 0.01102700925266911, 0.04101455482023378, 0.043661518833569946, 0.04091655685295982, 0.0238163233359134, 0.054262095776897286, 0.06101676195319142, 0.0563134647335016, 0.08725241968227972, 0.028472010106328997, 0.005320601771780921, 0.09615752530554611, 0.040056665292790825, 0.055342708759370356, 0.09730054381033106, 0.04358227852912199, 0.10181613416681368, 0.059295925461957534, 0.03487985295754287, 0.09846216292991754, 0.0460290867504814, 0.0377003780205644, 0.07446962979532058, 0.05880103649331197, 0.03225462668905816, 0.019121769094659437, 0.030735817159556096, 0.02306454593405849, 0.020811127033084634, 0.022275193834737427, 0.033285118369085175, 0.05136210824392977, 0.05435452811540135, 0.031628081680185376, 0.02193175470306268, 0.04742241299320613, 0.08437787392927755, 0.002135835177708237, 0.07651650181580937, 0.03302228892402303, 0.046022540529168425, 0.027661431625845934, 0.024128937004734913, 0.05118627574354891, 0.03360188040401667, 0.029739050585175716, 0.012472570242901004, 0.021471617397882288, 0.07943528914643873, 0.02563343792703123, 0.02000795087716993, 0.02644526896127049, 0.037267557495544036, 0.05214007819191583, 0.04869976118507405, 0.05197580978875199, 0.08269520776887095, 0.04966442676020726, 0.08841796117203851, 0.012319294243840682, 0.03481971888592647, 0.023525031809244427, 0.062057879272728204, 0.059428562094727834, 0.011501830548138149, 0.042876512367999366, 0.046685884571484024, 0.042471370599683256, 0.02761244987918725, 0.012510530857159006, 0.08130969179253425, 0.05369667692350284, 0.041903722430429155, 0.010511875453014529, 0.03740858279108521, 0.047220142798558365, 0.01686681227217759, 0.025730392099508358, 0.01087220299298004, 0.02378017930764585, 0.006485516505856668, 0.027910954123663328, 0.11100288435456254, 0.07336947390989912, 0.04601436254057673, 0.03900962994403897, 0.008370166535549348, 0.07433813080311784, 0.0972672266465041, 0.03385535591552335, 0.07480904505017304, 0.029934311075316324, 0.028766390882552634, 0.03498738105859488, 0.01299959947279985, 0.03785191787286632, 0.016874607216807145, 0.06260809128082569, 0.036026433771175724, 0.060605794086211154, 0.0706495706652922, 0.0226328841170236, 0.026776563684125582, 0.015193367895159512, 0.030276650870819728, 0.06246893140938013, 0.02480522410253123, 0.0124999703351228, 0.043365318598526145, 0.026139795231903275, 0.02303030180384315, 0.020522114617990393, 0.016552547683879253, 0.03766765457487876, 0.018811338776422125, 0.03494086803027219, 0.07115168767350336, 0.035874801988322894, 0.025304698107403614, 0.033980247399379174, 0.015851141520655684, 0.04597434593785194, 0.015897103923282797, 0.04947219231736757, 0.04200403781367406, 0.08715465920226229, 0.018842171900154605, 0.017938350943187555, 0.005540271738408915, 0.08216319034897512, 0.03480538538086318, 0.03438667619540807, 0.03826093221563966, 0.09342256843322709, 0.03392654080544749, 0.01992506207898259, 0.04800553996897033, 0.03770693956363586, 0.05516504530885047, 0.027685749171782407, 0.05751779325486672, 0.007078206652940642, 0.03719832229938719, 0.01884790415304803, 0.042285245708039695, 0.07816191312045821, 0.06338118124873408, 0.03969254370238032, 0.0756854496355499, 0.0664820140528102, 0.05565834081461353, 0.06850133755154188, 0.047034791655718326, 0.019095948101171566, 0.05134792029557209, 0.03875609314549835, 0.08063274585912306, 0.012873131763039818, 0.03707889302243148, 0.04129480893513368, 0.07420097808203391, 0.043904698123374296, 0.048434292567112756, 0.014044956131387624, 0.022120595376397816, 0.021248597711805376, 0.013852469837142816, 0.015116821347375312, 0.05850460260145127, 0.041785024767441135, 0.01306437316440767, 0.03161017437495532, 0.023905427022386464, 0.03707931054035022, 0.016933823898134213, 0.015011804099495133, 0.02124016499897886, 0.029857614182776986, 0.03423959114438584, 0.06467186320092409, 0.022034418145795504, 0.02792344901770834, 0.09331421295721685, 0.03832028870801291, 0.09262428949436835, 0.07963725290591679, 0.10296697442930552, 0.015985315117324074, 0.05273448198192543, 0.0415982065662261, 0.0963958246152728, 0.04570463702322976, 0.04525829121590622, 0.0433649700285206, 0.026147632311368664, 0.05249395335633909, 0.07112491290054976, 0.03758830318768178, 0.03367778056511476, 0.0111772371794007, 0.05877230053527221, 0.05403500050306321, 0.05472125057431479, 0.05048265079817465, 0.07956891020219173, 0.025979928003864425, 0.01813997953919874, 0.0601755705992541, 0.06563592356659713, 0.045913916922384695, 0.04506612572097971, 0.04057981141452347, 0.03772624880976735, 0.030858921743328535, 0.02610656999862723, 0.024879864048993876, 0.022224497966348164, 0.01597969873522919, 0.03032524382785684, 0.034535607518327814, 0.026531204874176654, 0.02602261442300533, 0.08286068276051553, 0.016742091242884918, 0.07347011488051185, 0.0053243172982136815, 0.07431455827768772, 0.012352972426601957, 0.01338239349875479, 0.03485516960462255, 0.02383978286337468, 0.02481098316850201, 0.008413593187147092, 0.05081841181362829, 0.023328195093199614, 0.027242917792811513, 0.03145941976277578, 0.027576378629272504, 0.07503268909790824, 0.03462077351287007, 0.017214499361392473, 0.002537660503519639, 0.029667017252875433, 0.0034930738911498342, 0.03463349823329238, 0.006321129837869517, 0.028211097796297366, 0.033151654361356656, 0.036479846739600745, 0.04406528164362235, 0.02757713322587792, 0.030904023254650737, 0.048145328032513784, 0.0174348377397344, 0.050013544518620744, 0.051297641945101564, 0.03890522748171803, 0.06106532809715118, 0.03579735432961776, 0.03258361931770079, 0.03654248974916916, 0.02070981190509854, 0.04332098125990841, 0.03998883969841465, 0.06263056063964483, 0.011700965527955805, 0.04511758384685363, 0.0604226952418685, 0.05082105098652744, 0.027754490241228093, 0.02146491221332502, 0.0785700771056356, 0.008840842337738122, 0.05001132286364033, 0.040609167903781905, 0.115678878200631, 0.1823775725619447, 0.21127848465356136, 0.0885709259478796, 0.09750563320854018, 0.10727081042263778, 0.09170777254527615, 0.12852487034134327, 0.17523136650843008, 0.129403542546976, 0.09911385860534445, 0.13233077982741018, 0.11373062467863483, 0.11686075268493545, 0.13724613784542009, 0.06636843385715639, 0.12755904031256515, 0.13198980941407143, 0.10987090517676647, 0.1559864564408218, 0.14814818187827064, 0.21440487415079149, 0.18042827716037152, 0.14092493802309036, 0.16862629432111018, 0.11025243994569588, 0.18710943720033094, 0.16605087525902257, 0.21268212627018654, 0.153073713543915, 0.14218529055435813, 0.1568101848205251, 0.11479853592332333, 0.24445599065192286, 0.30222824384127894, 0.21284168706305567, 0.1760868262499571, 0.12557781436630797, 0.10329875178755292, 0.22976492171085652, 0.11140884966739725, 0.118710104255907, 0.12454289086763898, 0.13586938591493716, 0.13929998892689907, 0.06959074522338568, 0.24178739997648427, 0.18149563682175454, 0.14077728223656455, 0.232334089495482, 0.2021543927971394, 0.1506180493461509, 0.2700944407091987, 0.14261422318316277, 0.08280925527815858, 0.13225866031021843, 0.06565509108646263, 0.11692125064831589, 0.0751790272132043, 0.13591771074120076, 0.1266146071195122, 0.2693110391978295, 0.07735702284281293, 0.17311351644175668, 0.18821246591546845, 0.15067388183407246, 0.172618102702883, 0.06411315527774634, 0.11913529837564116, 0.07964761041465306, 0.24393353400932205, 0.11646134508473259, 0.092960839580384, 0.1831248913320803, 0.1545703735563063, 0.07562820754584766, 0.1794889001476188, 0.04864144657227782, 0.13594809378827774, 0.15636689570401946, 0.27059396067934655, 0.15047885117030915, 0.09879321250463687, 0.21193770331240472, 0.09047953441979424, 0.22804419630237166, 0.21577224916508123, 0.1780478274750133, 0.13164919140117784, 0.13457022336942537, 0.1632683366657265, 0.2780779961857104, 0.13238311895439703, 0.15804033816581772, 0.08277542483542236, 0.09277523179808933, 0.1821129045058643, 0.2230454113094076, 0.1731922089933388, 0.12823441576573158, 0.15681449023465957, 0.11536970809702912, 0.24083202704787257, 0.1226594943493124, 0.10162656570995048, 0.18054918115658147, 0.17686995196967356, 0.08532807576440035, 0.2782195998776344, 0.1627846287503358, 0.09886648115371505, 0.13270636209316794, 0.13142200036635324, 0.1766256771741375, 0.1377380122580836, 0.09557873055699373, 0.15379484742879868, 0.24768837607435643, 0.19815303895983005, 0.2097220544613177, 0.10559621882895309, 0.1397499889736214, 0.11695459845565981, 0.11787974921565865, 0.06848944020607779, 0.19876468355857557, 0.08833374512652237, 0.141528508055114, 0.10236009489744903, 0.10977887503442266, 0.147955097077835, 0.13367504962990362, 0.1298921534250821, 0.20854093074317903, 0.17821265895280147, 0.13117201055490202, 0.18498650030984035, 0.17900804207930643, 0.17360427236605078, 0.2612963192645581, 0.12293377680884254, 0.09436985147335837, 0.11801405208966426, 0.08359244228490899, 0.13380434994976367, 0.07434899392988413, 0.10051357019091807, 0.30705557835678904, 0.1393588091577253, 0.14506409575621929, 0.09534786230013256, 0.17009638640428745, 0.16758835243601955, 0.1305537776000077, 0.15216429056900163, 0.2121320291752777, 0.21778422588061905, 0.2321033591344472, 0.1923085541854943, 0.21580948103820125, 0.1389550808216295, 0.09653549010474836, 0.12579915248939108, 0.09162244567226979, 0.23461234305174122, 0.18983842624771982, 0.11344933251459753, 0.17415755638672462, 0.10023944860985202, 0.11885098016430294, 0.08842264196925587, 0.07335926195786846, 0.10264003874673959, 0.09317129925494233, 0.13250446728160306, 0.11112325975010473], [0.015742880848026084, 0.02845805964522785, 0.015117038724823825, 0.03630478415758379, 0.03318107596808865, 0.04196331641005893, 0.004723293550928394, 0.017921113964891242, 0.08287771289507229, 0.03174112178385258, 0.03303530475785656, 0.01913518712465321, 0.02764361050550736, 0.04605478900034101, 0.02745494794761462, 0.023765845802582564, 0.04453610012968702, 0.040447316508019165, 0.02759627010222645, 0.07432755112888352, 0.035518004198468504, 0.022658377607923844, 0.01669413413882496, 0.036106317589480075, 0.017853889749535633, 0.02342159653292789, 0.07179893237809021, 0.07884079725631783, 0.08259557037343902, 0.05790104023030689, 0.026344329216367295, 0.07856296780969828, 0.016317870054814606, 0.014384466189620717, 0.03217774976585661, 0.06763017300756709, 0.04732467549582643, 0.005432337610757039, 0.04134283881754645, 0.05113461077393544, 0.06544750424162035, 0.024121561493243904, 0.03439006230403339, 0.03630673002091147, 0.023493181703792467, 0.04364934952689275, 0.02606474925884076, 0.029593796484292518, 0.018343933212060123, 0.02482149772526276, 0.021685300387382027, 0.025310183296941464, 0.05411458171663746, 0.04004387928533458, 0.04054428408703497, 0.05977919670723139, 0.007285707312891441, 0.017418246190514297, 0.023504977542606574, 0.034407509956508875, 0.030448589729325428, 0.025222125320485043, 0.05306639723599919, 0.09055358447855519, 0.025150913617483554, 0.06260359817514978, 0.039207257645865606, 0.10981405379190562, 0.032396161433068976, 0.025647168137854146, 0.009038518877669929, 0.030647650015570467, 0.027696614213768515, 0.006065839655592197, 0.05146099870363551, 0.06846810465738659, 0.047708175280281616, 0.03784550188650047, 0.030401488728520852, 0.008375962948306434, 0.016600037474305402, 0.012177009691273975, 0.07961007210636332, 0.06334059774094532, 0.025190742528666894, 0.040765511127369064, 0.09458725190451069, 0.061015647295261585, 0.06198587466872508, 0.031577968038618565, 0.020301040795241154, 0.11676868423819543, 0.03250146021826133, 0.03809277974669972, 0.1117859181437281, 0.053057096928598425, 0.06406720915448762, 0.033766110502784295, 0.02240743401700691, 0.017360935152898875, 0.09657189460291017, 0.08968975139601577, 0.0485769955952081, 0.009002250360114681, 0.008164502571397012, 0.06922663895473366, 0.0372742799170796, 0.080235130904663, 0.0312607808248891, 0.07142994612936052, 0.07246506881088981, 0.012740077612350785, 0.034687235470741026, 0.05904855567120737, 0.004035015261897277, 0.006057048796661079, 0.04691481079545714, 0.05225113412785915, 0.022190025924975355, 0.027682409028432546, 0.03422990013214369, 0.01863902645005334, 0.03250126869628026, 0.02141226665116847, 0.04756154222113471, 0.041916910634045644, 0.042424095313875906, 0.05734868700646105, 0.047591051927977995, 0.04903322776719447, 0.039063501246874376, 0.02933223682996487, 0.05482779808282372, 0.023625209296662963, 0.06505274679511786, 0.049454139455431895, 0.04419068257594782, 0.04261648680474009, 0.05335294476319706, 0.01285143519541429, 0.07694922657983919, 0.0933058625988422, 0.024415873321554354, 0.009848186671133003, 0.028384928891976035, 0.04386151374708261, 0.014142178434638247, 0.01723582724920444, 0.03101235766324305, 0.05070116205681717, 0.04527363595702956, 0.031306983587602456, 0.04072968119515046, 0.06187023369655494, 0.012642734650252088, 0.0685134953669002, 0.0317837028659039, 0.07765341459983781, 0.005272590562761311, 0.06173911774831434, 0.011450915387080563, 0.036366867922967484, 0.08149891550983153, 0.030642400398069335, 0.032734381590759566, 0.06608803035511125, 0.14611870771454227, 0.029826214153980537, 0.05428692468652322, 0.08049563910331457, 0.02612620674734635, 0.06635275969822561, 0.01556520303335762, 0.043293773647277586, 0.033985165683853055, 0.05997968957789483, 0.016836379429385546, 0.05768828995285496, 0.017126389674001166, 0.04818528717864425, 0.03231117929962855, 0.03025854438272936, 0.0544901984563518, 0.043636559688996886, 0.043844334225380616, 0.04132283243140386, 0.05027785634381637, 0.060133554507046945, 0.07557416770366893, 0.03129554206445333, 0.06821200146429962, 0.012420397740037692, 0.04386471982504572, 0.03316562397465591, 0.0238484128438417, 0.05870098541040094, 0.03350237324353188, 0.023976851314786943, 0.04635211155419389, 0.020267807901085868, 0.03412054491139228, 0.05694649850709304, 0.11831264251903181, 0.056985840952444466, 0.058129958793400764, 0.03236621505610886, 0.03717144410456381, 0.04113558522095123, 0.044687050094287244, 0.04959590019538038, 0.03379084748185931, 0.010249835078514392, 0.02761203810692795, 0.008042319208353518, 0.03927650816378094, 0.026641856698739915, 0.013881939324370075, 0.02986352838155243, 0.024028119833899603, 0.06411022116099635, 0.008837151709162902, 0.019796690640730724, 0.03803560660491067, 0.05042340921899004, 0.08474990154706663, 0.016238013049587607, 0.03828121439343499, 0.039304811282143484, 0.0026497525733805475, 0.0728154774274557, 0.01204434720303623, 0.056071718028115655, 0.02006804089873068, 0.07425586062092936, 0.02616166129648205, 0.05233233178695364, 0.056681723198703224, 0.023474525547616427, 0.006951439211280236, 0.05911108759802677, 0.02509958572655676, 0.05692690197798995, 0.003636913841605307, 0.11819983607218151, 0.04608218047407366, 0.0397999070945286, 0.03740027839798601, 0.029917156451471874, 0.005393262338569208, 0.02029750912991022, 0.12099950439146451, 0.01991934897828727, 0.08073017692133304, 0.06162521579573232, 0.048646705765878005, 0.048386205228105675, 0.05459325260392601, 0.03396686001290237, 0.024121862182754184, 0.031192200633907513, 0.02470421157927523, 0.029154247792077162, 0.07164425156529873, 0.07728309535811986, 0.014872892249015071, 0.03560603919228719, 0.07942075645851512, 0.029129202462612625, 0.01711099896760237, 0.027659790282468164, 0.011405907721529085, 0.07196713464274522, 0.0709584419946036, 0.018365105967067422, 0.00683474630462907, 0.026092290119718642, 0.04591040440925187, 0.07266905504248797, 0.06819428951149026, 0.047400916566050826, 0.04481586394831539, 0.01016713875991803, 0.034963210984583826, 0.026674649092338742, 0.058103827534303557, 0.029819016757931922, 0.036282330120523135, 0.029610732773078546, 0.061967561336895155, 0.013700170600185952, 0.030683269273609887, 0.036655231078545895, 0.05198549697055452, 0.058325223113980994, 0.020816426446300842, 0.0252091420453883, 0.014730872954392146, 0.013949827163390095, 0.0566086077672099, 0.03800428893056609, 0.01437462674784324, 0.06348222441550705, 0.03191335367098932, 0.041457357470907515, 0.04455891805851171, 0.00820779228477829, 0.027877382235601548, 0.009470881665155534, 0.0441787239434498, 0.02109105747583653, 0.021308955864139625, 0.02048436563552147, 0.04392811360077993, 0.09008245572688119, 0.042278002346715624, 0.0390457165157122, 0.019156781228018865, 0.025202563265338544, 0.07368774513804144, 0.07475952512674755, 0.024785317307818803, 0.02583290615509595, 0.012515930819415278, 0.061309235170483596, 0.03716230850606676, 0.019263571969443755, 0.028344035118577943, 0.01767121225355133, 0.03367023076862097, 0.03048322839482177, 0.027997728902846578, 0.01272749653341429, 0.04260980268760074, 0.00698047298600056, 0.020244074497191657, 0.039900544234701706, 0.04732469847846416, 0.024259447743515336, 0.0800810706230902, 0.014331171367948335, 0.06359598464182308, 0.03664389680770617, 0.02478561033644984, 0.04311279303604557, 0.02427494378700372, 0.04893709139357652, 0.06000410480004165, 0.05457658253069367, 0.058733934852024244, 0.007059078395081264, 0.047524758509450385, 0.04604998945949539, 0.07397629981560093, 0.1527563233168856, 0.1567662573389469, 0.13263660212678294, 0.22419912440161552, 0.09545584239305989, 0.13709506530675197, 0.12044562282220972, 0.2699075765427082, 0.11423412830598893, 0.16825832696931978, 0.10955902312191264, 0.09856598316541604, 0.19951574083778167, 0.22245733157521297, 0.08232971488107597, 0.16919873053989104, 0.10939997560795277, 0.13874658233215734, 0.18068488597148852, 0.10322881562094535, 0.08943717986825975, 0.15378910176936658, 0.1045239408830962, 0.16938406253053298, 0.11763512201967741, 0.1770886241067802, 0.24013772156209717, 0.20119495960252903, 0.20217794233993178, 0.11342883966262303, 0.0985437666156119, 0.15326895871229712, 0.11249927623618035, 0.10592638740255948, 0.08353880080845087, 0.15089385632065036, 0.13321728145162906, 0.1501617367349325, 0.11662594673614349, 0.14152547434693383, 0.09173233332412858, 0.14026193488990107, 0.13872493268741717, 0.12157986195938242, 0.1104730809287679, 0.13087312901212325, 0.16153368377877822, 0.16910804105141472, 0.08905131670255816, 0.14108676643621537, 0.08984566561036533, 0.1261452556918225, 0.15961225865589035, 0.21438999672330197, 0.14015269075189868, 0.12594923677463687, 0.0989750894387403, 0.08694686551368044, 0.14407723661391966, 0.15597432160810118, 0.1374364953728453, 0.10119840682994935, 0.16689613070939818, 0.16746061493552503, 0.15131353460732969, 0.12495392768253243, 0.22941014639312224, 0.11133886753551422, 0.17287517116675455, 0.16433862278298025, 0.17270526818690762, 0.147454688445695, 0.0859344420173476, 0.17455750024847447, 0.11965802314901546, 0.18149972773127018, 0.16916655484707127, 0.11058132915246872, 0.14038689915210972, 0.11112479958683254, 0.058493092130388946, 0.17706302144835073, 0.09061487151249763, 0.1787861676946763, 0.22934861421104402, 0.11985047209647395, 0.1207096933297092, 0.16549616631480957, 0.13737183755203602, 0.2052108537886412, 0.21559079357933617, 0.18211760828571935, 0.10648607591828031, 0.27407043703621436, 0.24461581191468626, 0.265034644473945, 0.19078607701005476, 0.17512270459725013, 0.20302934181546012, 0.13271169406512093, 0.19176905974745753, 0.1573452053050841, 0.12071022193037695, 0.14887974988068306, 0.12583519692622847, 0.18815004507139807, 0.3634955127152705, 0.22174497705794152, 0.14254918231839134, 0.19015598501409256, 0.1392512657349148, 0.17770406850163015, 0.1448213224930148, 0.15148693094811133, 0.09603210139058291, 0.19319510177498866, 0.14812893774961272, 0.12385092195003264, 0.1497394537493106, 0.16830567120304032, 0.10403385145529624, 0.1371048405886658, 0.20157814146049563, 0.11749867409948381, 0.20147764604658852, 0.2857078335458233, 0.2767776385430367, 0.10987111202050602, 0.11613980266115359, 0.15100765102092298, 0.1390412350695941, 0.14472160848879045, 0.1151884057288689, 0.1251169128884231, 0.13925272130197094, 0.26787483884442237, 0.17293445105033536, 0.09988183110591867, 0.07976482952794722, 0.17844614723036367, 0.1817341659578585, 0.19909615448165327, 0.17843955887421487, 0.07429689995103306, 0.18080214338917888, 0.08351841520878577, 0.14912129740320867, 0.1478219050313196, 0.08898297399883309, 0.07610070759490614, 0.16435031328470479, 0.19084888089808727, 0.17743724007760325, 0.12467310283212893, 0.2046005728264009, 0.11529073209291506, 0.18283406903426494, 0.07783470164623954, 0.206506829408388, 0.17825223505496982, 0.11748818635580041, 0.15550038897462432, 0.08407189841231993, 0.14312647553461214, 0.16804596739670924, 0.22306237249605118, 0.12330842444733267, 0.09977748993063167, 0.13839661804658754, 0.1363236454105185, 0.11483300987991596, 0.08037475042886312, 0.10781913019356229, 0.13531179648012887, 0.1991393465188242], [0.07215924651151703, 0.0746652503467856, 0.04106276090286913, 0.04940363510902371, 0.04472586393897091, 0.054916518725334644, 0.050978413107053894, 0.03247250975560277, 0.03407721497839497, 0.01206593651835236, 0.04915875510402745, 0.013301716779448814, 0.030115188264678565, 0.01791820857643841, 0.05836027929739607, 0.06775550499197937, 0.039706831242168145, 0.05413476430300263, 0.021938955929550915, 0.045703595143652735, 0.022068367332159992, 0.0645908264202937, 0.01989927172901169, 0.03949039991224005, 0.04576187528249237, 0.06244875648389421, 0.04783230833709241, 0.013441598688762997, 0.07102868459638088, 0.010957044357764385, 0.07526121312572111, 0.0167026243082458, 0.06453412825301771, 0.039350895301228574, 0.06342093738156461, 0.04734949674457312, 0.03569335023301744, 0.0181880802847445, 0.025187268319930282, 0.004912531632374251, 0.023140367571144335, 0.029124401006547194, 0.034740516885874734, 0.021847772314363433, 0.027616684430188713, 0.0633008262863563, 0.014105508678532658, 0.01472628504533561, 0.04627223156632916, 0.07750623378782504, 0.015095966518856587, 0.106526073368807, 0.054425732157523596, 0.06210070358769548, 0.03336828487414507, 0.014842850111064412, 0.07900546019476268, 0.13248854797453652, 0.05506350801536634, 0.027390012419932795, 0.04635902166727089, 0.023366878702936154, 0.046356531881516984, 0.09037998895491324, 0.03510675287895626, 0.04660697368484351, 0.05680935727732797, 0.07438657820344934, 0.044933389496779254, 0.031219381433460983, 0.041349856182932854, 0.05086231631256881, 0.023347263021634954, 0.05423643949231314, 0.04515289666972334, 0.022253714644560413, 0.028842128249966813, 0.0008378430709032522, 0.031012070380271445, 0.044833388209583304, 0.01967581154237832, 0.09041827802936878, 0.03134331530741146, 0.0044238024894448546, 0.04350486151393383, 0.0184480196631123, 0.05106073308495745, 0.04917193181632508, 0.06543828054301201, 0.04095976038144962, 0.03939896348803755, 0.02071218869288362, 0.0468157786094854, 0.011423800662610561, 0.024917766249047655, 0.09497986430482519, 0.054783403287611665, 0.030780995279670726, 0.06342044325485345, 0.05431200640516416, 0.026598423343872832, 0.009495432867908911, 0.009080714042929393, 0.04347333316541007, 0.02932822635968126, 0.0299157832388676, 0.04094318989964743, 0.050007002127747384, 0.07978202054096807, 0.0661069910312372, 0.08123435470606051, 0.031597712039647084, 0.06528792812699272, 0.05966527560245126, 0.04120546393096447, 0.10460537602944721, 0.03505374342503567, 0.01139447768969882, 0.06620349512705881, 0.012318026368325997, 0.045318306543894356, 0.06453566808974551, 0.06743438391675873, 0.021087359186382066, 0.032297734456557425, 0.01056862437361551, 0.04949262771274775, 0.0729210366825423, 0.055044666082868655, 0.01473572037573303, 0.014269901570984194, 0.049311122331287593, 0.03323976596396777, 0.031994329164585764, 0.11399455729030794, 0.0038216705480966, 0.11025916619767105, 0.03452478269595773, 0.028290801583939505, 0.10218323583924964, 0.01619472525142614, 0.017580679813099485, 0.025848821631722876, 0.01393510199587552, 0.014678326026055843, 0.01292992186086673, 0.02234717354088301, 0.043318610217782764, 0.04811849963340548, 0.035238826437102216, 0.013349665265019624, 0.01705232812392135, 0.051018958310446436, 0.046989106002353856, 0.015960173069259093, 0.05165461976561816, 0.06179590784614125, 0.043932537758542646, 0.03713927224218365, 0.02185213901553183, 0.013076998293399813, 0.035774122713313955, 0.013623537867510272, 0.0416855980461884, 0.026263922543054628, 0.037024883823769714, 0.022521203819421992, 0.05530650727450848, 0.015813887622507832, 0.018533773630136446, 0.06747127871119207, 0.056084278039634235, 0.03403814832469629, 0.0281242847127179, 0.038919005573036215, 0.06856751222644122, 0.07190488999889744, 0.11401912573003962, 0.09032181989882263, 0.022311136764924855, 0.08131645634890565, 0.02528534672643629, 0.019668478165723143, 0.026032219250356, 0.08125174490194167, 0.06697482309274136, 0.004028483883537833, 0.034284897584227786, 0.04138296650302026, 0.03942840041652803, 0.09259332422046893, 0.05433431488551921, 0.027908755451320644, 0.02099027477895781, 0.038246771080359336, 0.03193401123186754, 0.04451796299807968, 0.07781487529075916, 0.01708980131473753, 0.058386720822102604, 0.01956554084655739, 0.048266055828501145, 0.03869543430365382, 0.027631523553282026, 0.061296763259076306, 0.03908551478337857, 0.07630801098721643, 0.01859082036741799, 0.06496087753123815, 0.05978119619671376, 0.03662840650987722, 0.06890797702174994, 0.06131632914466243, 0.03191337856884686, 0.016017521453660824, 0.02565556063106464, 0.044841681111363635, 0.0038346361074100945, 0.053706145770246946, 0.026983016718839927, 0.07630848596172948, 0.08371146936570445, 0.04584237580157576, 0.05234052892774344, 0.05447481158039263, 0.04877952242931051, 0.041649568931109486, 0.0754403627868141, 0.12108951206168822, 0.0054135780327112205, 0.02642658407679729, 0.04539905604155314, 0.012703472016108854, 0.043362625799472296, 0.01105102898192502, 0.011012864396757176, 0.04883119122936361, 0.030342272047193784, 0.035938781821319175, 0.07459711448680009, 0.013618306444597342, 0.04380498411914995, 0.02525491388364425, 0.033692807379749515, 0.04522621894495622, 0.03502991809059055, 0.05489999037836829, 0.056718085562029195, 0.008735313726168488, 0.05380033245009761, 0.05385883475443529, 0.0404071964834246, 0.05582458572462202, 0.04651870886464754, 0.04472710500140825, 0.034024646025030844, 0.035114792971721584, 0.06418579956516623, 0.0465557492157865, 0.029886748506537372, 0.03796558233819181, 0.023133763893237038, 0.09321490497959238, 0.08181923985361092, 0.06467224624488624, 0.041998629232928644, 0.016966911235583887, 0.025309099282528606, 0.11041347928825887, 0.07710095029324293, 0.03563787397598067, 0.08625103551293574, 0.040195526389945904, 0.01625412579385504, 0.021936004575822624, 0.03529714871077769, 0.03371015544079485, 0.03873507935373533, 0.03617513143727857, 0.012793973813043728, 0.03941790884240501, 0.042196168834643985, 0.03960764966905117, 0.037267929048187314, 0.016559875314874996, 0.034048976977505994, 0.06382147113101617, 0.016127730862447814, 0.08229607596032082, 0.08571598438485976, 0.03239039662143877, 0.0597543026801319, 0.07252813316881657, 0.03364535206327996, 0.016826858871706554, 0.03906085441309599, 0.02271660412060878, 0.041676389669338544, 0.06986718805086228, 0.06970903685977382, 0.02187388633648234, 0.040165016938361435, 0.04213528399686179, 0.04277646128508834, 0.03302639132485755, 0.018945319893499537, 0.034416756637754946, 0.05495250570557772, 0.010619428451924075, 0.029501908068214695, 0.08853003217448151, 0.048397573972901994, 0.02147165761749831, 0.03746697784311349, 0.03664874231382724, 0.0790210347622633, 0.03425470222869227, 0.025711312679754152, 0.020157405055097995, 0.023835803036608046, 0.03689322395310287, 0.07182199162461105, 0.034527977282601985, 0.09660730318677041, 0.051755153483921484, 0.03405100328006572, 0.03056331522642605, 0.0562765239737928, 0.044701908369578665, 0.10754824150353672, 0.023608828421622038, 0.038225401057711536, 0.012760591531743207, 0.027064570608819206, 0.016267285269174366, 0.03314700803809589, 0.010459468335724406, 0.013229040890902042, 0.04688553474543076, 0.052399153806149006, 0.013190290248472125, 0.030251931128723007, 0.04307899706726594, 0.07341806686693624, 0.0403703285020686, 0.011717107000520394, 0.04732047350356176, 0.06873715473639389, 0.05231838515629211, 0.01736196745637684, 0.04366587021297986, 0.049872729897258744, 0.29798273778250145, 0.15504888739557038, 0.22096231099097963, 0.07031944805696126, 0.13133964591449307, 0.09805939220372709, 0.11882150110097663, 0.1163041208600325, 0.13725790495593704, 0.14059297680374117, 0.14722397340641868, 0.12050520914096026, 0.1260115427055186, 0.12601604730251337, 0.08662215148609492, 0.15347039387110742, 0.09821686157656294, 0.12237445601532537, 0.15037285524510569, 0.06683493543776774, 0.1340961681618806, 0.1508193925744103, 0.09720127413710279, 0.12258587329978905, 0.13696574966513342, 0.12855664766844244, 0.19463318670468946, 0.1179343636237806, 0.21853192769471677, 0.14942725759840783, 0.16768141679706114, 0.11960554612620224, 0.15039142521639026, 0.09631117956051904, 0.07530717074029869, 0.11779753265962487, 0.12135729809562046, 0.11098973062490264, 0.11535916672719103, 0.11860102099636871, 0.11599169488275245, 0.13823406951081368, 0.1603974221694854, 0.14004482557216, 0.09457379940056032, 0.14167689928604713, 0.07996126979349122, 0.16310177382922944, 0.10545132861983393, 0.126989844645704, 0.12108254066157727, 0.1990650206684105, 0.26593390912298237, 0.14868744648993015, 0.11762433550170354, 0.08540734288192565, 0.16832850062318389, 0.2984265784823126, 0.12710134108220378, 0.09408832182206454, 0.13560044308823926, 0.11204150039702655, 0.11953384029648959, 0.17270718340671834, 0.14085127100829156, 0.1393642637037462, 0.2655429897769805, 0.1062145360535191, 0.19953556719326204, 0.1179434187830456, 0.19115189931565718, 0.12326690248183667, 0.043944764521814166, 0.15617324399851984, 0.12738851680149957, 0.05400263328826236, 0.1577047763332244, 0.182765887209004, 0.13222941107326938, 0.2041422070995454, 0.1858036250116364, 0.17572350139098783, 0.1493332432883401, 0.12468608802244549, 0.17154459901634725, 0.12045037256734026, 0.15301884632677804, 0.1386394066315505, 0.2653688426700331, 0.22757164262715848, 0.09660152688382134, 0.13687988653058006, 0.2064729836438933, 0.12177012755625671, 0.13588643903213163, 0.2216753703091414, 0.12228297745628704, 0.13502227653178478, 0.12934890515621633, 0.15989886747012216, 0.17381476268412607, 0.21292249401730878, 0.0694469964852737, 0.12139937930530119, 0.13987386539097757, 0.11932916458575957, 0.18330116816345723, 0.09223157750262369, 0.17182792897426313, 0.09818982633371508, 0.1787852330674087, 0.08289097387704157, 0.16964807175099852, 0.2543137649134282, 0.12554199975584784, 0.21069015977123093, 0.14574785987215658, 0.20901403600169768, 0.12199014034723082, 0.14230250200677302, 0.1353660355051679, 0.11462759106389939, 0.17530992116418578, 0.13576335934621675, 0.06491072941571474, 0.11179441405880837, 0.13694907959190109, 0.10836116804350769, 0.2512447400799682, 0.09496536226041856, 0.10488554204423582, 0.11112485321298723, 0.12737240597245195, 0.10136106261803259, 0.30465055257081985, 0.10317438507392522, 0.16437410797563293, 0.10321710213658311, 0.1533138054993845, 0.2583089134385509, 0.08423926564113748, 0.09618633787237829, 0.1455889732366608, 0.13018125968594707, 0.10676030475165575, 0.18952854368234837, 0.10104410906112003, 0.12401777589994094, 0.11646933538178283, 0.07224075060578124, 0.11144333128486911, 0.11068336440310364, 0.13044560598509927, 0.11837509400661915, 0.15698229413359396, 0.1617409105622961, 0.098542854970982, 0.17856793988856579, 0.0724985545140601, 0.11101406923825703, 0.12346566399379123, 0.08749581347670286, 0.10908621663768446, 0.1868815260428575, 0.1804962138374967, 0.09746246415400699, 0.1640570854708072, 0.11068906409726029, 0.1993967827048994, 0.10580374438676143, 0.19125181250274184, 0.09754523229334625, 0.18486705188068653, 0.17822225037361347, 0.15465104261473303, 0.1325075163115417], [0.021603403673056635, 0.08569638785575667, 0.05361513452484243, 0.03206232904396471, 0.013217773652755687, 0.03768098833520086, 0.018050475571785244, 0.03129413820833209, 0.0808476488436422, 0.029357663288171736, 0.08727066023575683, 0.10049174434595531, 0.06101234162586832, 0.008872371643871791, 0.02498150859478741, 0.02241046772518706, 0.07357158322608279, 0.11093271070069845, 0.04860681556766072, 0.03947186441491208, 0.06806547948790174, 0.038262801470174905, 0.03723738895308587, 0.0860978638933551, 0.059002636361026, 0.03566939083318557, 0.02775750671242995, 0.09146512951701881, 0.02113899351247857, 0.08740211326268413, 0.007330608204938472, 0.037220787827766715, 0.0448482962805898, 0.02752061317404432, 0.07842079721271031, 0.11151859942342966, 0.07465368241912897, 0.07560396852392344, 0.07785382320082958, 0.06228450723292847, 0.060703895475354895, 0.033442626046317245, 0.03567507903602335, 0.016532171660313205, 0.09200719801048118, 0.016903371903144063, 0.01965874310342535, 0.04782913290264626, 0.1115147383402913, 0.032673933423094215, 0.04444698878233472, 0.028215114012240406, 0.034141654464145826, 0.039445112624596206, 0.08253487322719828, 0.04770820592379859, 0.03288437011501482, 0.08857638815477972, 0.013135237255013518, 0.07924180598028245, 0.03954373878396807, 0.028113095998583783, 0.03727142240912203, 0.04333439162902294, 0.01681136091299836, 0.03829773124908248, 0.04295851441941435, 0.03944679035715038, 0.05070297385475809, 0.031393021007158586, 0.07447545972442435, 0.014440987199064226, 0.050038292989014625, 0.01894767369864689, 0.05157482787786473, 0.00905758489088546, 0.021821635309606794, 0.031336213672353376, 0.023800411689726096, 0.03133495154249812, 0.05378482300007055, 0.0263120788299749, 0.0485232506968802, 0.026850450949202624, 0.013630751542927278, 0.048860191487737244, 0.04183439913416102, 0.0759399823483921, 0.029071918238074552, 0.03763248347827504, 0.005315056252819036, 0.026673559332266453, 0.06643578064657989, 0.03309379557087537, 0.0575020041827473, 0.04642177192914871, 0.05441632842825306, 0.021355281200920864, 0.042644211526719794, 0.07601455334694156, 0.012647169341723765, 0.018366548127584884, 0.05872763760928666, 0.023733616483608083, 0.06215076360310759, 0.027398092732314142, 0.0375473749403271, 0.06875077577968759, 0.022948161856601798, 0.041715866180076715, 0.02985331642952177, 0.027261899536355372, 0.05311780939659765, 0.010871243467854877, 0.028657234844661532, 0.008004402644151162, 0.028971007221468517, 0.030084876080734596, 0.07037243069780451, 0.09314358219384186, 0.041083043080664454, 0.0675990162116866, 0.01952812511233553, 0.02339218450229495, 0.034741964792051626, 0.04430924617354909, 0.032348139211535454, 0.055340249617133415, 0.021715089716317675, 0.050404502169018796, 0.04874276553070353, 0.015416807014374964, 0.027401183897088614, 0.05367751706451659, 0.07890409910150113, 0.07984228867797122, 0.035161968666098775, 0.027848075542058197, 0.09836006639224869, 0.09834826097733552, 0.008561437622824264, 0.017391699328718167, 0.10776201833880718, 0.06718357439122855, 0.03146012456366613, 0.05822588449283954, 0.05317204842163671, 0.029080128785403028, 0.10103548291109263, 0.037806937020392194, 0.06154454673730558, 0.04463501740247012, 0.05132065139590733, 0.06646013458169277, 0.062401550146000045, 0.01361680108182613, 0.05649887333293596, 0.018907534521854213, 0.07541967841285853, 0.03697284347107334, 0.03343811761888285, 0.01380047161928228, 0.01788575709196589, 0.07642614940601973, 0.031339622763616425, 0.057300308554042736, 0.06676712133471044, 0.02087989874604729, 0.05825203107369523, 0.019814479202332518, 0.02054150238813412, 0.013803998496563686, 0.05654015781117543, 0.030885736735898162, 0.04000873500180822, 0.003844700587515329, 0.030977954569783424, 0.027490865979944507, 0.06550074735235784, 0.026641387469886292, 0.011445510636774764, 0.0053323956953752185, 0.009532836153202, 0.05353789754031647, 0.09178264997899534, 0.05675160573915609, 0.03679681178783217, 0.08485266458122961, 0.03151960746054688, 0.024293892971810796, 0.03833790873027137, 0.00945350104537342, 0.035285806779058716, 0.041551992312193885, 0.036379060212282405, 0.0201080804840932, 0.03299525751161479, 0.06128308092874866, 0.025563877143506563, 0.08837217209680427, 0.034461672372755506, 0.09276139625017682, 0.0793456185549017, 0.10265893047495235, 0.014761572012737876, 0.038458766761205854, 0.08824543051061132, 0.03698770557680438, 0.06691227201372385, 0.006057238403422338, 0.03474254701887408, 0.10692220211269395, 0.007454701520938187, 0.05687053705896101, 0.09915657566800233, 0.053503672562299244, 0.059631276620371695, 0.05390527500440517, 0.018486214891797113, 0.03154003519504782, 0.0590053751253553, 0.03773132414226571, 0.02744853579168839, 0.08542162276083425, 0.0468247456686391, 0.028145541737396872, 0.06269542913463327, 0.041743418532273466, 0.06652496860272462, 0.020158785928581512, 0.07495299297114534, 0.05354995959468427, 0.02407495461915049, 0.053811436894560055, 0.03855296493237538, 0.019247455394736702, 0.06907945814272089, 0.035911386517146905, 0.04382043611258269, 0.0806515456567849, 0.05391098618988068, 0.028186847283054265, 0.05263386782439006, 0.01873811800783921, 0.09539441746329108, 0.01585089924534963, 0.04370256199411327, 0.027233770702995604, 0.041661726746467814, 0.013889396232703041, 0.06688955750676893, 0.04599896417329869, 0.040593558862324686, 0.01507364558957277, 0.05055339901798195, 0.031220415652158762, 0.05543696055669458, 0.018939216087962833, 0.10316570529774313, 0.07806102700170972, 0.056075031358388164, 0.021325018812691974, 0.048291842348032424, 0.03037039321967431, 0.042471887709032145, 0.077828879378015, 0.030193559059332457, 0.03025261677741524, 0.0059593189601606185, 0.07213688440500729, 0.03627482245886519, 0.0423667153283473, 0.05690892955528633, 0.0038847377788530845, 0.07616780157531462, 0.05411170888692141, 0.06751162090128468, 0.035319564443442135, 0.11115328273585728, 0.018263884684852055, 0.0555171431492894, 0.05890147828106439, 0.058667840616356944, 0.06148503319690786, 0.04503167474702482, 0.053536507090733904, 0.07347353163265413, 0.02274459697336199, 0.03646322263164386, 0.002241675251899588, 0.04182765372998772, 0.0508447039511896, 0.07793738807161009, 0.056996508726790074, 0.04190717748696766, 0.02049564053454707, 0.05160819100696714, 0.04247621227536471, 0.019787671870642135, 0.02750489113461827, 0.023525376548810352, 0.06607838530814455, 0.07612151454292959, 0.04042435302248886, 0.07966766659651073, 0.05014215152890933, 0.0416106440036768, 0.025534133779846376, 0.04854642868702931, 0.0722757148586454, 0.01887873727678051, 0.04676896680687224, 0.03390641184523702, 0.0040144675867556925, 0.05323913474116595, 0.06732143957408206, 0.034755892270515044, 0.054394977557803356, 0.05458440428840057, 0.059531892033954786, 0.03871853185457088, 0.06275454047887076, 0.029929195523201942, 0.06764637576716562, 0.04686825946273823, 0.034457290349828626, 0.025043171011812748, 0.03947451890956971, 0.043527235111762444, 0.07707936959641595, 0.040358745252653476, 0.004889856387425455, 0.05661722242591843, 0.012912877362161394, 0.061797455343748295, 0.01608614569469806, 0.032003158327913096, 0.023581366084756392, 0.02097101724376121, 0.0913896392129602, 0.02212721820650322, 0.02827175089248246, 0.10150523270450293, 0.04684129316780356, 0.004332801777749293, 0.09312714960786606, 0.016830149219341336, 0.0694600812670204, 0.013371085083382505, 0.05368167309150581, 0.038144149772462346, 0.03323904967175857, 0.13211212301206204, 0.1919821394427169, 0.10536275353402862, 0.09098302272538986, 0.04614170933622987, 0.12359812059589934, 0.14040764481309922, 0.15665299890022125, 0.12194574555201877, 0.12257538555610566, 0.23043307295489698, 0.24472600600171476, 0.18632767511711967, 0.11954428973577677, 0.18093620877592795, 0.06558402110972712, 0.1770598651661027, 0.2392613322984788, 0.12158487983528646, 0.13739777728915215, 0.1330992732677729, 0.17219407303679377, 0.16373960331322687, 0.234308083571734, 0.14480760951917018, 0.2086041023534152, 0.20637912255141044, 0.2560328968590306, 0.07228054121256837, 0.20998243242502215, 0.17426344505961866, 0.09015394705197505, 0.17748626970475723, 0.08526236840313481, 0.15199284009154768, 0.2954600408913628, 0.1647416922834612, 0.15040725259290588, 0.27843664790834155, 0.15955074179557063, 0.1277668569837847, 0.1188823821083192, 0.195331598421739, 0.10758699023074682, 0.29034291063585593, 0.1455822010194102, 0.14784652709720597, 0.17163876654399982, 0.22307223970851592, 0.10432225291527088, 0.10109371325421719, 0.27299166266475955, 0.16486916931406145, 0.11954013753922717, 0.15300818238287203, 0.12326163179691761, 0.0581427256486589, 0.11041311156605521, 0.08987190412177194, 0.12795394331577326, 0.12748343509531793, 0.2398082424676226, 0.26230740210702347, 0.25581561900194616, 0.1755220968756945, 0.09111103601753713, 0.18970338026842765, 0.12274724972103873, 0.18059378279553306, 0.1189419607661905, 0.20153966852493826, 0.12557810547971918, 0.19983901462006956, 0.12995029949853498, 0.1241486160565288, 0.10780674255182666, 0.15509469945344234, 0.11046471524863474, 0.1225648518471468, 0.13188958979181706, 0.13055648955125965, 0.14219561741957742, 0.22526403258164085, 0.14872182851597188, 0.0831329121044086, 0.09684749473367008, 0.13718195499912386, 0.15138966842524468, 0.0816245845729305, 0.14989814120194606, 0.1579691226323766, 0.14187350809093446, 0.2878330533783282, 0.1750013562700441, 0.16925440981022774, 0.1952852960675955, 0.1967648263539999, 0.14282534169333597, 0.18088379304014868, 0.18731899289113862, 0.22244363392312683, 0.0857348531304348, 0.19533250240548966, 0.1430826553053433, 0.15621504175566858, 0.13766526454879394, 0.16324870949310644, 0.19973799826637392, 0.1869893912225962, 0.13623235837346123, 0.20420445940427243, 0.11311901838428552, 0.1540490813673504, 0.0724639043572449, 0.09612126636408991, 0.15030539354249356, 0.11933556908080656, 0.17719472728429303, 0.1622274836465236, 0.17816166814056136, 0.14766743106226768, 0.16611640642006553, 0.07239563060143302, 0.12271858271091216, 0.12669356780186777, 0.15599404071127215, 0.2520660016565554, 0.13448348689463832, 0.15004901455775385, 0.11647079094883897, 0.1352426340623248, 0.09258446824406424, 0.13748774665497965, 0.10397762060165407, 0.1328661986776898, 0.1190672238026896, 0.10844821861434369, 0.15687798360182395, 0.16133690643454754, 0.22354460952262725, 0.10563347368471085, 0.213064925084191, 0.14710241057459386, 0.24295868712567517, 0.13858245565525948, 0.18739731772051704, 0.10799071856684263, 0.1867156220419753, 0.21635067619142995, 0.13821911547453175, 0.10908728149989921, 0.16113265207217586, 0.24723053128728945, 0.1392390389716433, 0.21849396037718943, 0.09331311745148513, 0.13244944684688123, 0.13982961615247114, 0.13520285877729618, 0.15085860095437498, 0.1154769987108246, 0.11071890322191101, 0.11178324449687235, 0.1887740543292415, 0.2448874973361531, 0.1295825160078464, 0.20191070022842578, 0.13146658668354635, 0.08654859938448475, 0.15220834062464778, 0.07397608531098213, 0.1539088566336901, 0.09309364858293727, 0.1464538558596565, 0.12728124150946257, 0.10724791205458103], [0.09872485447915332, 0.06645202171057463, 0.007497589038159218, 0.042934616306616415, 0.09247889366721915, 0.015476887459836662, 0.030936252573625218, 0.022117132658980066, 0.026386644082864927, 0.06496423299634649, 0.03414277295251528, 0.010950123710978416, 0.07422513283428646, 0.06447489433471235, 0.04719176690184301, 0.03009592115338291, 0.014405543183637484, 0.027276233041418657, 0.0726074232689796, 0.018957927785513383, 0.045475534599034056, 0.06912623547137746, 0.0442699650152316, 0.03589206577969655, 0.06839695807185865, 0.017389008444884134, 0.014127795133859882, 0.05240780293881413, 0.026969185001367045, 0.040871032078059456, 0.08482929889953907, 0.0568637341981934, 0.02146780228001937, 0.02963212386314427, 0.043204329051678224, 0.0347754811387389, 0.03931561695231546, 0.05495863440897196, 0.032794071331379876, 0.02421171472017323, 0.02299927141247017, 0.05561556629536133, 0.0853911018179309, 0.04127068099595847, 0.03250819796155537, 0.016014054905803456, 0.024998398918297984, 0.006417059367747918, 0.04397423209382161, 0.042787339733613115, 0.008270529140117428, 0.0032661564933556706, 0.016701337280533007, 0.02483963677208991, 0.06632882711147109, 0.03267105676293854, 0.0755989506480194, 0.029514818564958634, 0.01890072400020736, 0.04050001952677004, 0.00999634328763932, 0.08740986607247785, 0.03903319480858984, 0.05977784839248466, 0.029943073205950282, 0.00827222794008952, 0.04701569691420563, 0.04300466738641263, 0.0422427584717591, 0.04534036604567401, 0.03535214233242216, 0.09422146790330449, 0.057377097377132986, 0.037133924948472175, 0.05152396347013213, 0.04021236883296121, 0.04241497120669773, 0.08033169628751856, 0.10319452552545456, 0.03911918817809032, 0.012743165904295542, 0.005216127009912124, 0.041508371265785354, 0.09963647612640936, 0.07921706134032819, 0.057115489842310074, 0.09483270647545015, 0.014960626553323482, 0.037653290426298495, 0.02113959489149913, 0.04374789524703257, 0.04100955992696747, 0.03623904615280129, 0.03360790185510151, 0.03694783070034558, 0.03646035363236743, 0.03295660454539522, 0.014344239870326654, 0.05422433147266988, 0.005277309664374879, 0.034773730627831914, 0.0058197961545609425, 0.05221970920120517, 0.04169570657634928, 0.01939939361275925, 0.005685171523627135, 0.07488432851049208, 0.03774429401082378, 0.06558730762692229, 0.049434083273574236, 0.03629474840577572, 0.012988196254046935, 0.04341268964532403, 0.033613547923103455, 0.03535028456920578, 0.048517083689089746, 0.029967520986833883, 0.04690348035505703, 0.0641651918000031, 0.042154895847723375, 0.013728474676158401, 0.05227567575451347, 0.024180310860937162, 0.04190253882458614, 0.05970243852765811, 0.043086282563425844, 0.014060031784127557, 0.07671068978285597, 0.03545168013642392, 0.05051385738977021, 0.09396257615017314, 0.026035754746126554, 0.03300040179202634, 0.06907188153314976, 0.05177024924646943, 0.08348549641067944, 0.07508117480263596, 0.02579297382204283, 0.06802157498896122, 0.0536414573059207, 0.02033574266299125, 0.07295868990402068, 0.07233089617183132, 0.044081855955864155, 0.07934974010793433, 0.0406474493173582, 0.0130211207978127, 0.0462838186461839, 0.02071565332552118, 0.019199550001611634, 0.008735491841610883, 0.07043305123525281, 0.04921121680508218, 0.05076927876460457, 0.01586405584783924, 0.04328563396308211, 0.018406174025468288, 0.023552666515893033, 0.03611170318758777, 0.026688660840473832, 0.07424433865854818, 0.036711324036361716, 0.06486618906379708, 0.03457689199656729, 0.048021735067689614, 0.036751612600299625, 0.03527170310037271, 0.014490008207729027, 0.030435037633944905, 0.05519768448486444, 0.04586861431298237, 0.04937963740479562, 0.02522853173075184, 0.05814945190063408, 0.03796193575967224, 0.043867374319703355, 0.05922664430052523, 0.03243757614625558, 0.021034797893897183, 0.06345687839653223, 0.047928532810821656, 0.03308598147404771, 0.025074664886379917, 0.030989373110294826, 0.03904103571849485, 0.051070872258635304, 0.030547120127706762, 0.04415449258240481, 0.029347192781466632, 0.05943878936851698, 0.055542427881230275, 0.005772050203485114, 0.023526803387569326, 0.03138088234399836, 0.05731370360139878, 0.0553512544701657, 0.015661990581711215, 0.02889573908290796, 0.04919957226863311, 0.04413983732041332, 0.035749102281706954, 0.04443357458278056, 0.029239013505678986, 0.006689745491565836, 0.07631732661637568, 0.03629688579108446, 0.08021151241395744, 0.0586905627841911, 0.04813105198404482, 0.056898085580718134, 0.0192490297054211, 0.02535456277039503, 0.007843281904746207, 0.018276234022191456, 0.07336901425714455, 0.05545680989481269, 0.03641692027750035, 0.03241587287536071, 0.06559984082536352, 0.0839312370085428, 0.028052737846249537, 0.092783298703932, 0.05453509120871464, 0.08303456939756872, 0.055048163274243, 0.05258231010708598, 0.051520006626003215, 0.021208345537043868, 0.011764864921720039, 0.0065001923564611186, 0.008992029789594874, 0.0864592811933929, 0.03584047358843588, 0.09406861037977281, 0.021179414226583416, 0.02218476673137517, 0.030567295053192688, 0.05246049063580652, 0.04051158362398705, 0.0217007945156506, 0.06801530072886137, 0.06424421376939263, 0.09213767810574464, 0.016998610038670803, 0.07815559289508289, 0.017719113816236778, 0.09200838544676382, 0.022110329798212456, 0.03915731254364214, 0.02605076623900283, 0.03679085545422089, 0.02048556839356259, 0.01191225257747236, 0.03874822925295561, 0.03639097287950497, 0.0712934752265292, 0.03293359892502908, 0.0473352819831381, 0.02260715696930645, 0.07789434925202401, 0.046707472929190245, 0.02377496416410131, 0.08509845623085577, 0.025523341516213074, 0.0170610347131808, 0.025845192290181597, 0.06703574240448014, 0.024393587823837035, 0.055988264240084164, 0.11987596750259401, 0.03095445482270612, 0.045854828560784947, 0.11962495879420351, 0.06326789982737073, 0.05440828067460849, 0.02215081371457106, 0.03397407656114909, 0.06170916754091459, 0.1047388515284946, 0.044265100356912425, 0.023714010378405936, 0.043386271103255214, 0.05006733155178447, 0.05879970733076335, 0.02483849338586292, 0.06033318169835595, 0.0437305586773061, 0.010992713411518884, 0.016649679971798774, 0.05583158393781032, 0.060537788461172776, 0.03763884583848619, 0.04345206273419242, 0.05936843568399068, 0.01040513642252453, 0.029888893552725355, 0.09592283426994279, 0.025860650029273766, 0.019735317421896804, 0.03737798140894982, 0.06724504528627281, 0.06547827033265945, 0.04747694696209604, 0.09475969063538699, 0.03255902023445214, 0.015403503897569835, 0.07773004637490358, 0.02820111567064399, 0.04054091330016813, 0.03454683070641852, 0.04157626197763509, 0.03132837659288799, 0.01953664592527334, 0.05802393988555959, 0.04361255049344994, 0.05003534738094576, 0.01529737773741926, 0.01885666245324237, 0.02051241786008881, 0.04653707582263216, 0.06433468492281053, 0.04849199430956956, 0.02318243345906658, 0.05285063623300484, 0.040907716198313626, 0.07710131035456735, 0.04911382787770802, 0.0197203901986922, 0.008217958271533491, 0.11343011902945657, 0.0544589497299204, 0.09996946390357711, 0.11485470548993158, 0.02085848658856365, 0.030556370639392448, 0.03912359318365494, 0.09057814525740762, 0.021144126301571246, 0.04809766587230468, 0.03910287816618239, 0.07578689499848312, 0.05040343730680404, 0.00218782453767715, 0.03450597906785627, 0.030773767240105138, 0.09903777075270492, 0.055332807072949027, 0.02563628202845012, 0.03983691297171097, 0.027531641009714336, 0.038211933232002684, 0.02627570306011025, 0.17490377199024926, 0.1953510110897403, 0.16066708511883215, 0.2183095783355736, 0.2028290098232608, 0.11640676898100685, 0.16937632504249775, 0.1363584564457978, 0.07761674963178174, 0.10776081558076606, 0.11897744595884316, 0.08475125752269261, 0.1652995881534392, 0.193887859763157, 0.1237572753621686, 0.08401953630269536, 0.08209271025994132, 0.09851746681717136, 0.1457228241187911, 0.09484745366799255, 0.10436671665839611, 0.2505810015023716, 0.19112487173368856, 0.1301627969669719, 0.08799373232308896, 0.16368127337867217, 0.1920428289280784, 0.1280452993007437, 0.1520359248764092, 0.18564067811014193, 0.21779839850721822, 0.16173680433102194, 0.1447768281063726, 0.08365490909425483, 0.09529222899507131, 0.21470605395734313, 0.3227749364751001, 0.11029072902015141, 0.15254361134382988, 0.07052313551426896, 0.17491348598512912, 0.1654731377118057, 0.1584400828447073, 0.13380030500552348, 0.1305245590065756, 0.18498040224996307, 0.0987907840059169, 0.14138535686558293, 0.11131431441754104, 0.11022490674569724, 0.16387615082485063, 0.07377640449351842, 0.057542664299328486, 0.08078312125778006, 0.11735223639275759, 0.1640678260235056, 0.20707658431943388, 0.22795407371895932, 0.09642613871443657, 0.13677191409853198, 0.10744773842875036, 0.16272300463770667, 0.17026985935386152, 0.21949817907185326, 0.12925548839472956, 0.2524749393905363, 0.18358466666071646, 0.08270757242796883, 0.14517622038481698, 0.17331672892455133, 0.1811085479153741, 0.2139243378394073, 0.1767233074192078, 0.0873695545259022, 0.20326938780565418, 0.13135437012439774, 0.18172008526181022, 0.20930259067925716, 0.1622224734314988, 0.2205664733605039, 0.18737156184450274, 0.1440637841099693, 0.133161464285466, 0.18495786394323074, 0.1936682989640582, 0.13097857335402122, 0.137862149145334, 0.13193498816220992, 0.1017540887058262, 0.08553974585787905, 0.1527816501836623, 0.1054476360760389, 0.17200252041220668, 0.2264842267839178, 0.14732475993373703, 0.1639793581900097, 0.12738935949821628, 0.1440263070887135, 0.1534965021475669, 0.1330625623344414, 0.12577586341649294, 0.11518960082603079, 0.13220967664833994, 0.17005371530690502, 0.17656941567697834, 0.17004475207819095, 0.170639343559742, 0.14024186338628494, 0.15607143091338296, 0.22291108545276428, 0.13435294551234092, 0.07045647054309807, 0.13767045862492056, 0.13524246552298147, 0.17797897149237896, 0.06501149296039535, 0.08218122405871268, 0.15537289662226555, 0.11601794871591753, 0.20147068996823606, 0.17130184107490126, 0.15784431158775286, 0.06876803574062164, 0.08279206426513773, 0.18267637749593105, 0.21732630448475962, 0.1406760973435256, 0.264773745570452, 0.16983268361899162, 0.14258215474265237, 0.20373961257357753, 0.10007184389377795, 0.12744532222108496, 0.3355444270756937, 0.08135951815112945, 0.183358394931401, 0.28223751653586665, 0.15020189506392326, 0.22515126443918676, 0.25238555225153125, 0.13522044815603765, 0.13026824130886985, 0.16674606940679013, 0.21026864287353333, 0.15133999528423434, 0.1656143123944921, 0.059866350699937156, 0.1289571277917393, 0.10064870810076114, 0.14386722127035742, 0.10882876512985076, 0.15040112388951166, 0.12989049867516564, 0.2637542051173026, 0.12428151698963297, 0.1969352962389108, 0.2441732582425879, 0.1407039676222109, 0.1733260445537106, 0.10344652248726738, 0.24243249197400388, 0.14946402981877327, 0.13020316980058147, 0.12966778159381884, 0.18515804271784522, 0.08222958718937251, 0.07494810533018843, 0.10694897688564756, 0.11299038456091959, 0.20084280430549578, 0.15167315160074543, 0.13252653061382233, 0.12364929526924126, 0.11897534687793064, 0.13404608133339113, 0.11534766008656834], [0.08412799903101499, 0.01940207492049423, 0.030801635603570653, 0.017664072314097036, 0.04681320838449944, 0.019231817624982328, 0.07015641688579513, 0.04117989957693123, 0.0531237427475712, 0.027527042566948844, 0.06480320131466275, 0.04328150474917024, 0.07595112892769038, 0.05504501848331383, 0.011608693110305938, 0.010682599104550338, 0.034187627400481896, 0.033766911064665166, 0.051744117987372225, 0.0476144444227459, 0.021172209169655558, 0.02507593467711441, 0.015813143559611373, 0.04912995785895375, 0.012785386925022449, 0.06733882976996322, 0.06006655245718937, 0.02490089890817481, 0.03956608173827972, 0.05765730169631782, 0.044613900188837326, 0.03262400364262923, 0.00760215046372445, 0.025164052025384964, 0.04634251630294227, 0.018476887771319, 0.022842185083596457, 0.013263407595185264, 0.04254337520368638, 0.05221279142724891, 0.13877178662486617, 0.07169511214259171, 0.024815039604061076, 0.032244384093510534, 0.08945903635673946, 0.07740707136690617, 0.04585921824459107, 0.046696081201756195, 0.018192764912401477, 0.0991517186705624, 0.029780880901061242, 0.016252068847778346, 0.0556218252337027, 0.0550931402962775, 0.024430076591670517, 0.0958532888081766, 0.03751606875730138, 0.04072313880427711, 0.026958019269870657, 0.035785985584821434, 0.022319933369515405, 0.041066361516113245, 0.0297650343723475, 0.0168376051700644, 0.020070467482230837, 0.008369425345482606, 0.05510348248325529, 0.01015894544956785, 0.04819908059172092, 0.0038172834977177124, 0.05723654705610487, 0.032469885904462106, 0.05390243664864571, 0.0635733467436606, 0.01292616515720804, 0.08145992163448565, 0.04703001509751043, 0.031462083833532474, 0.030057913616239548, 0.023460019672770175, 0.07848451274537271, 0.051081842637711, 0.02740827595604764, 0.02753932295637506, 0.019344625987052437, 0.0524068491593484, 0.018766541785049825, 0.04561830274460297, 0.031783007641112616, 0.05514271767629732, 0.009764617012302962, 0.04847912020200203, 0.02962974707535919, 0.01923316402450925, 0.06793630174210957, 0.035064798073783036, 0.04117985361165578, 0.05327438627700171, 0.03713706973940134, 0.008035146710162443, 0.07702595794633513, 0.044840436218486684, 0.07965431368399052, 0.04038244035215147, 0.026383305854734876, 0.041340613332126415, 0.037912274109980756, 0.07349718076687667, 0.06618251197881277, 0.025592858249682094, 0.042920711810790727, 0.05306749657217053, 0.04785316125039132, 0.06324561049921379, 0.08196224548643635, 0.037536105786960934, 0.04402304338591714, 0.0269341518005897, 0.03731109044184128, 0.0673729206825937, 0.025455466126121824, 0.026797211668904752, 0.05119041261834003, 0.05412161823422198, 0.07158988230531255, 0.10407367270560035, 0.05489874931593096, 0.011276571012492622, 0.03279564181162465, 0.03737828018324029, 0.05626892055114431, 0.039015502007978584, 0.01578058386521955, 0.045348126516346975, 0.02572103050507365, 0.018269561396370974, 0.032778596355309414, 0.04680934730136106, 0.022451861370955745, 0.04273738697051041, 0.03407158040171189, 0.015921603415101286, 0.07366322266358523, 0.06367733934894204, 0.055653598730362235, 0.03392207834328856, 0.05207086597839671, 0.03458352631799156, 0.05405855004585559, 0.015007750536765785, 0.03143411779385661, 0.057467051421202, 0.05561418733709762, 0.023820674715323314, 0.03328801418143896, 0.037825058830241044, 0.053015249375734604, 0.0682995882966826, 0.02100537245672557, 0.030343321587650046, 0.0266319033013837, 0.06009844086703755, 0.03337309590630955, 0.04220372629201701, 0.04829398739422041, 0.004380444306955343, 0.08646972297180085, 0.0231757972224225, 0.07742351927464047, 0.05873862714056046, 0.018605665236170736, 0.044482175200696916, 0.05901194432930601, 0.05725030599522495, 0.06701858203497625, 0.07063997158360097, 0.023195813184664137, 0.021141399028560808, 0.021057282574474815, 0.014718695029225803, 0.10473812374496654, 0.05711285066941092, 0.0494356346016209, 0.04259140125565952, 0.06367088122774037, 0.05160237256918223, 0.02710749834565626, 0.05431049721195333, 0.10877293264192921, 0.04066564007512024, 0.027693203207285657, 0.03340297333535648, 0.018965718899703315, 0.041599256106682365, 0.042677264390212875, 0.04670540449179469, 0.058438064034787886, 0.037998558592892466, 0.00999645053994872, 0.08572792003472006, 0.07015775753966264, 0.03572101366796321, 0.07387404239946797, 0.051781637143463864, 0.04954167266166018, 0.008744151507984967, 0.05966453249716471, 0.03216039787437166, 0.028231881761683092, 0.0397095431934201, 0.020125007196780176, 0.027211680557698976, 0.030455381098774173, 0.05509487165498638, 0.04404383884262174, 0.011585311149246992, 0.10126625157652364, 0.06723991249718013, 0.09637807435806721, 0.04458862311777569, 0.057526488352807305, 0.017857999811249397, 0.04943882152738591, 0.025577833350267143, 0.08158610397649389, 0.030564701845568996, 0.014013479493798749, 0.03476048879806073, 0.03281679732965366, 0.04555698123670394, 0.08393937286229865, 0.008015214059982569, 0.05118310030910277, 0.022581100403781862, 0.012355839510658577, 0.026671906497569817, 0.036862159087773294, 0.010486925884540524, 0.06323470523761165, 0.0175842976633219, 0.033821222868057034, 0.055053560363669554, 0.09466881728580884, 0.06739814029706102, 0.056598246428034, 0.022732538749433817, 0.04349809695756243, 0.017621292049185406, 0.03620505100116134, 0.040263727367404974, 0.029284978781135815, 0.04206425615496213, 0.061738049055659966, 0.016794669772348097, 0.02427445349073218, 0.03987595664277192, 0.06783025219075142, 0.03903411028365936, 0.020275853739510623, 0.029558466424444513, 0.031130871465129238, 0.014856174295287461, 0.03921876811692792, 0.0396001918031083, 0.01208719833108086, 0.10140450746421853, 0.06578763195824239, 0.0350708578292641, 0.03256004296183106, 0.06194627558391902, 0.0703836692076537, 0.05922210522957387, 0.08258052440660615, 0.048402622492323, 0.10557418614025078, 0.02356218515835222, 0.05209170356993714, 0.07530831221130586, 0.019226345841983156, 0.017148280636437477, 0.02373626140216666, 0.04215756566413949, 0.016352278893933665, 0.05458221710737675, 0.008426177138913303, 0.017560539361570152, 0.05362472594565442, 0.0276915465421494, 0.028593544209856662, 0.014166034412600342, 0.053401495585398334, 0.035469472528465336, 0.028890776748378432, 0.03139207105813248, 0.03238467011420477, 0.024021751728029023, 0.013137024155096903, 0.004881393988691872, 0.045220262611344944, 0.01458034146532056, 0.0542404767756741, 0.07084712175832641, 0.03080544689099395, 0.004038426268380135, 0.00973506995867337, 0.04162478598675901, 0.05136097443380183, 0.03818643399544301, 0.025849419180303815, 0.04884742846291873, 0.03252131338681906, 0.030784929141161904, 0.01753887822551112, 0.006704387347018647, 0.06012373325985767, 0.013425750244829445, 0.04947726764986592, 0.03248369846973689, 0.027352782462032574, 0.008496875563005527, 0.10485364214306879, 0.07485080450292557, 0.02619984120340838, 0.0257576571687335, 0.044213358778506524, 0.05898863227377015, 0.005604106493504538, 0.04345968913947863, 0.07051362836312863, 0.04547036350554517, 0.03272349165091592, 0.01966778677137148, 0.04890227652785759, 0.04535363468852255, 0.02501736534008336, 0.040577359933165774, 0.07248936911984798, 0.055951323480375355, 0.0784517778083682, 0.0389828436797665, 0.03462539685349311, 0.06832357450959183, 0.023892449492949153, 0.009321803827920269, 0.06506587754214002, 0.10977302978356039, 0.03131472107563769, 0.02268586867308665, 0.09397286471099624, 0.01641766832871062, 0.022169559886078202, 0.028753480385808695, 0.14177952442438374, 0.09115915400006118, 0.13847690406105212, 0.178171121665547, 0.2074639183739501, 0.1418677317879854, 0.14606540331677084, 0.16452389348658825, 0.14476024996369116, 0.14500060238905493, 0.10931390562965985, 0.1220780642583005, 0.2617694245230767, 0.10792454389194328, 0.16374868911600884, 0.0867805018600437, 0.13853319620172824, 0.11773327320453622, 0.1701899104180836, 0.16854501239234404, 0.14364059714059677, 0.11954868708046214, 0.12014026783647076, 0.16046862238116805, 0.24110685342982893, 0.11075211313342857, 0.1326101567716368, 0.1788863719951722, 0.13789896733097493, 0.17906784290267577, 0.17671940037079398, 0.10890886728321353, 0.10556627245199297, 0.17494377710165518, 0.13417604048886608, 0.12397589387312052, 0.09071527499585383, 0.09827340652625408, 0.1349584920512092, 0.1266591015061544, 0.19843626166543654, 0.21247716710692455, 0.16549556876622862, 0.06870499436533259, 0.22585932886408222, 0.10325947445967507, 0.15585795285240298, 0.13876150572492232, 0.1255521887252408, 0.1916147083524735, 0.09703962192420038, 0.14046982050903384, 0.16453765242570834, 0.10242845292293257, 0.12869540151328812, 0.1168972720962859, 0.15940101757164926, 0.08195401004125034, 0.1304855191659543, 0.14928136381410784, 0.11657013723085966, 0.11081201354822806, 0.13582573422501165, 0.06152651302756802, 0.07469331980833123, 0.24515499991755335, 0.20942784605487702, 0.15669121136588438, 0.19394090369103417, 0.07759098609488818, 0.18988129652796254, 0.08848247343614217, 0.10111027607514013, 0.15560342780044004, 0.16350430706816335, 0.1818801363509509, 0.13274655106567568, 0.19269682286727816, 0.1323023426436609, 0.12862236269058722, 0.20839215646828377, 0.19464100080151714, 0.23419939101703707, 0.11373489944925232, 0.14274574515800323, 0.2511013590640599, 0.19542613367159523, 0.10998680661883085, 0.17594600396771587, 0.16466840831262453, 0.15525874952154775, 0.14403242047034925, 0.14427019884028744, 0.22274262271821502, 0.13508504977630031, 0.15468914782808674, 0.29755853957706885, 0.1675266670363565, 0.17054116173136621, 0.12387676209571863, 0.13311804242191777, 0.28915296158482956, 0.21163303014491835, 0.2148105023849395, 0.14661822768469013, 0.16557282107251306, 0.10809106076316488, 0.20486197734792388, 0.09194728993480245, 0.06315774021429882, 0.18419146958378055, 0.16266852046453184, 0.09205991252055092, 0.1373944371458023, 0.12735975019994283, 0.1414049074294106, 0.1632920547478622, 0.07999475549666152, 0.23198801693656754, 0.19853260488279406, 0.1824140843124159, 0.1500184936148505, 0.194414361349998, 0.1586814311843726, 0.13524896194857938, 0.17854964570893397, 0.190341301682976, 0.21311617636632538, 0.10427228099997006, 0.14585788541984174, 0.12063480823511079, 0.17984991142105672, 0.1259480263557165, 0.14842611857719962, 0.18842520853204114, 0.10450671922655837, 0.1168296724978474, 0.12529463762597692, 0.1542851590220967, 0.15206597084479948, 0.13246475328360835, 0.10034606506627414, 0.14943064370703313, 0.21733949651881573, 0.2133558086690403, 0.1661288936532313, 0.13918832395105593, 0.09408259914527017, 0.14863434127501904, 0.18565930936846042, 0.13144564183969654, 0.1905737327592027, 0.1992915835111372, 0.14233357453298184, 0.11987970601166449, 0.13413934487729304, 0.16111873991547093, 0.14523882508998917, 0.21033049681253974, 0.13104830267688922, 0.13101410451194934, 0.20572089980686867, 0.13673040745479448, 0.13184198508820227, 0.116113816958762, 0.19014746611637456, 0.20641880590588818, 0.144875438943986, 0.1872692891066113, 0.1845679098680135, 0.12875066709614572, 0.12243952752361376, 0.20000188491277157, 0.15425814676188654, 0.13357798628989728, 0.14749544432326672], [0.008486813955730008, 0.03989250797237601, 0.016039783968740416, 0.017990939048749786, 0.061094611808056795, 0.05323978208546197, 0.017036090890366225, 0.07560232909576547, 0.05494742654263974, 0.01587234013113043, 0.008065427292979533, 0.01882244513610438, 0.03987957640821415, 0.03551752922395545, 0.0661599660112012, 0.008500975091010332, 0.09474332699732435, 0.031449795783227014, 0.030286832179333416, 0.04672920301316246, 0.02607042788557949, 0.05708103120747594, 0.04203446299558686, 0.10259075631057063, 0.022428535908881216, 0.03345102236996735, 0.010715316804576545, 0.05518687498425284, 0.045659774914383895, 0.03399130970900578, 0.03521672480048672, 0.11844329881451784, 0.049061691764021115, 0.05582511049485015, 0.08349961541112393, 0.08799019299687878, 0.029007727730899092, 0.03157674229793972, 0.06896249183844175, 0.03361623689171768, 0.051876371576180386, 0.029182068275047407, 0.013808629498065961, 0.013640234753819964, 0.02552261564790482, 0.02662788900066047, 0.0314109742776641, 0.007122426205540017, 0.021146817185405283, 0.10536302166480212, 0.07785761533605476, 0.004101999117166646, 0.04042443346172091, 0.03566779353986344, 0.011900711462893074, 0.06846530843646297, 0.06666171529720868, 0.06102766721479355, 0.03026974650340215, 0.019503148730784174, 0.046644228540601275, 0.021784677312919692, 0.00486751439072372, 0.004916786771988677, 0.007866001199750651, 0.04276137701385925, 0.028668232036814578, 0.019500396559916196, 0.027546905311605627, 0.017540201642400315, 0.03500550286844373, 0.031215370963177377, 0.023123256997355533, 0.017158268507750287, 0.05992015305485937, 0.03940058759443703, 0.08451090509732885, 0.04189741752681233, 0.06766154430806637, 0.008628567034799245, 0.0884007241937422, 0.023587707377549623, 0.1133700041100383, 0.03309199909469293, 0.01294071029406041, 0.07295597795276873, 0.06755633745342493, 0.09835420581962794, 0.018329954022661816, 0.015137517212649748, 0.008951236565236845, 0.028257825329238852, 0.06148111848761478, 0.07803828951211707, 0.04607989370161968, 0.025793720757769003, 0.023176909965132515, 0.03712236468169478, 0.04653471627182538, 0.04674866547687881, 0.06171436544748084, 0.09179894466914477, 0.03094019409599564, 0.056000345446650064, 0.037545329485569275, 0.03502571992876549, 0.057191026111644123, 0.006807263857955414, 0.05988827996676969, 0.06411212105904857, 0.03277681903132508, 0.04560869600203249, 0.04208115605457176, 0.05760109765575298, 0.028841446431714202, 0.005437815139415644, 0.029229176936731226, 0.04215318364121261, 0.043056018259977145, 0.03710073801959234, 0.004270991409993581, 0.03650802345345578, 0.07119451198847064, 0.1371043043271188, 0.039193556163339846, 0.027037181050306367, 0.020502071842671405, 0.021460279296602935, 0.006021101078424122, 0.03798713622194144, 0.03487790326377557, 0.07031188676914862, 0.04013114053034975, 0.030663073280706044, 0.035703638793840524, 0.028946775860423525, 0.06931759657398348, 0.0176295236639318, 0.032124405148469155, 0.029144325038237922, 0.031861531653351365, 0.04302244062625593, 0.051518642989497994, 0.0942229004877229, 0.04880758422997691, 0.028881767554388895, 0.07213385835770639, 0.002161082802265282, 0.030531884554112633, 0.0688084775221444, 0.020281224015859828, 0.016120912679921717, 0.04662919789552689, 0.08754135740380134, 0.06303466052838391, 0.08510521312634792, 0.10622623421612287, 0.046961921372360764, 0.009884726192291466, 0.036008384739679676, 0.0523712873579033, 0.015112311962331015, 0.05137820758165852, 0.06006007518378958, 0.04575606833602633, 0.007113822559345394, 0.032169207885500886, 0.03885691031633366, 0.026743432296620264, 0.035232962034041845, 0.026258852956215703, 0.0389444894878374, 0.07921765122802989, 0.05570984873620253, 0.042249549841207844, 0.051487210401964766, 0.06622837766283943, 0.012872208627091061, 0.04874509060755373, 0.016530392421109062, 0.0572491338807008, 0.075988789810048, 0.052563100452384645, 0.12453789597437268, 0.029510405898514776, 0.031417330892215815, 0.09674163670429299, 0.020562908799958327, 0.0739177170720312, 0.05310434540132842, 0.012436728819363542, 0.08143100181534406, 0.07241783182947867, 0.021097119146537398, 0.06239602282162636, 0.06872938660484168, 0.02078902731168895, 0.044660796261122154, 0.06871149079093049, 0.031592039158567786, 0.050805733058481455, 0.03593844091219287, 0.01888687313053637, 0.03405925787744984, 0.038277686558543675, 0.04039316941353102, 0.01859029942762948, 0.018435007659718394, 0.06528891638041505, 0.04001273781121258, 0.010348281207224055, 0.04614421444374227, 0.04465708456512901, 0.02203252782384234, 0.0646615210139463, 0.02919826528898651, 0.006277953601262022, 0.05886562536620806, 0.030783864278947155, 0.005502092789092492, 0.04486392830468474, 0.012402874436379682, 0.030097510785825794, 0.04016345794943552, 0.01763747757180564, 0.1207412638130688, 0.05389995452377105, 0.029637499885152907, 0.08478851237845036, 0.10114367750863876, 0.02466170902123615, 0.04876147339781446, 0.040594504980911175, 0.04172892414874608, 0.004852029838554201, 0.02910010835846826, 0.07128006102697504, 0.06486252716351902, 0.03683095632661735, 0.025444294648966, 0.005844428275351323, 0.037812161740035787, 0.0894807166449966, 0.03850647488669042, 0.013735529388331119, 0.006240409068507894, 0.050660708783975536, 0.003329480124164313, 0.04596125732566561, 0.06907388102263212, 0.06014671206714646, 0.07666176740801142, 0.05264158616022718, 0.03711315630484493, 0.042304095301416614, 0.012373056379146876, 0.06950895001571025, 0.00548716604469284, 0.07498846284203953, 0.04118931862796026, 0.006518216490099628, 0.04469613206662959, 0.009363473265341694, 0.01938217961710067, 0.029719216568816095, 0.0729505310676271, 0.00756604809148778, 0.005754232913586161, 0.042609163004183964, 0.0842304096647328, 0.06217457744623385, 0.03365646416862165, 0.1031074443111016, 0.09174042321260899, 0.04798398225478107, 0.020636819047673095, 0.04686747422261585, 0.12654870823626557, 0.044534001048774495, 0.02958304252505543, 0.023645861111881755, 0.015361394917201853, 0.024301839218805396, 0.03343535970235544, 0.0510674708282515, 0.040407116044192545, 0.08678846151357697, 0.030351262088985215, 0.026439055988204577, 0.010277858574784571, 0.042071323316063614, 0.03646992590098131, 0.031171748001549034, 0.018423698286736206, 0.024334602884107062, 0.01469158892324495, 0.05240524037470741, 0.030030382331460718, 0.03561278076602086, 0.030051980265265996, 0.05508618038748542, 0.04130512813947374, 0.021368207019423286, 0.01641087887448169, 0.0354245797761025, 0.027528952041100112, 0.08450082338024532, 0.07887222984385106, 0.0745301813848557, 0.08113107839298826, 0.008974026723374284, 0.011621211944598586, 0.024351437666243123, 0.03448731333558117, 0.06442633968207144, 0.022585319633024837, 0.019934617110618183, 0.025452258132938898, 0.044761781971300804, 0.0447743802872156, 0.05066686430044713, 0.00459295422432103, 0.018966998266536864, 0.0356471321485456, 0.05219764969942551, 0.0947358193356664, 0.016976648213101492, 0.019736386114551176, 0.02624259274002285, 0.08573949562325593, 0.05623490624730626, 0.06729228992856319, 0.06351784750398609, 0.05022319597041896, 0.020647684089659203, 0.0370650613049586, 0.06799719041033138, 0.050555099733173854, 0.025577772063233202, 0.026616181261957656, 0.06390703932171868, 0.019670178880915046, 0.024765100247497042, 0.03568748199951745, 0.10236748764591833, 0.037045269423434814, 0.02560140013003782, 0.028357391861537774, 0.04769232492112825, 0.03436245249524232, 0.05151829058905283, 0.007063306242813387, 0.1115753588777396, 0.15000386133549676, 0.1261987133071788, 0.055356720507505446, 0.14822685910809427, 0.13792884476002187, 0.15530583328537403, 0.2386667714604447, 0.16044401563704014, 0.13752510110216756, 0.20495381596828663, 0.09873132026123424, 0.14375636834771405, 0.1312659482561773, 0.15465209981606853, 0.17191046728722512, 0.22180701485804974, 0.20233382591076438, 0.23762850781842587, 0.2180766263195584, 0.08936850774672725, 0.10929231727195364, 0.11645773681060922, 0.21163888305665987, 0.18286051438941112, 0.08398510831137819, 0.16449041544429718, 0.09456276773445069, 0.12704583801208966, 0.1460426505054197, 0.07629487257931503, 0.27115528862322535, 0.13529244509916152, 0.09989676982044213, 0.21187955723895183, 0.16026485831506793, 0.19407049512430546, 0.11756402906030418, 0.18042794008168483, 0.1316580780210995, 0.13167471745081488, 0.11635531085513293, 0.16853188164532187, 0.08259843554227583, 0.08281840236797448, 0.09807338096922445, 0.1987217673130574, 0.09014000425175314, 0.12097269131411469, 0.20774789184572237, 0.17666214295933325, 0.10552743179423195, 0.19018941709110815, 0.24761873868203935, 0.09433329375761171, 0.1834686962707389, 0.15952901554203805, 0.1454193766919836, 0.17631472208567206, 0.07725230628444303, 0.14198031606933764, 0.08240430886226316, 0.12292621552102989, 0.11906302564086453, 0.04485621762972686, 0.15188065417591604, 0.2557221103099085, 0.1823670465138651, 0.12140002281915759, 0.11581834450724626, 0.2244597781569727, 0.1293904424434708, 0.12782147139190667, 0.2324647381300888, 0.1509725948375079, 0.14235068893721028, 0.21264235098515788, 0.20563612451716778, 0.14774656794484586, 0.09126521121229857, 0.2930051581032815, 0.13183023329944382, 0.23823737917888552, 0.12842762314023512, 0.10922384433328144, 0.1904773588983282, 0.20986937316915683, 0.171863766567361, 0.2204523415815446, 0.1728069740197351, 0.15439903033116173, 0.10430321563035251, 0.22095435899832558, 0.1555250110405107, 0.21696866399818854, 0.11165585173594375, 0.22633483963868312, 0.1494975385045813, 0.12161534715203509, 0.10506086892658666, 0.14462367180855046, 0.21981310249576647, 0.15898847922442422, 0.20825600732238064, 0.1787781084497129, 0.11723435844384855, 0.20465917855260835, 0.1199567208306924, 0.09590808707740038, 0.19639347289358416, 0.22643145864769337, 0.14151560713446912, 0.11874297708873788, 0.16571745847261724, 0.1561041888330252, 0.06880209600973515, 0.16096043550679762, 0.07918684683259457, 0.1153472770426062, 0.10169505397038114, 0.10612013103861002, 0.11490751193055224, 0.15396407625127226, 0.1794110656145119, 0.1398871340338261, 0.1423468278540719, 0.10377307512587118, 0.09311430997425511, 0.25209471463195743, 0.08028314163487765, 0.2209489044523047, 0.1623005224692245, 0.18375968710789758, 0.3249999315988633, 0.0925009493385592, 0.12991459980126352, 0.15791050158441067, 0.13585458509624004, 0.10211522255333201, 0.1036330878794674, 0.10679461782978428, 0.17703743411167977, 0.1290829807159401, 0.18837702160160388, 0.24044106173659527, 0.11889315330453458, 0.14142041304899802, 0.09715669548078891, 0.11790357455010377, 0.21793060996119054, 0.10463271004658554, 0.11644018573626397, 0.0981698390997706, 0.30311252381051745, 0.19348394756595935, 0.22527072819009905, 0.17781164256795762, 0.1311999421206213, 0.07100384802587571, 0.17302785249006364, 0.1267696173501111, 0.12366919823351408, 0.16763468543368001, 0.14203234876115478, 0.23862439147647352, 0.13310762362614756, 0.17540133077531092, 0.11119163309734677, 0.14858060786801, 0.15194525070969137, 0.16175480739724252, 0.1214513200665674, 0.1593628510712616, 0.18672354339111238, 0.12749339423833356, 0.12063370506849982], [0.019433687538689664, 0.04364203721765549, 0.014112951222717041, 0.03434166086897735, 0.018105835000413562, 0.026880201973742055, 0.06193666501090892, 0.02792638504967815, 0.029524869638525193, 0.04946658455376183, 0.031827860173859426, 0.027973041719486638, 0.05684188537059292, 0.03403082452414017, 0.034203975716786045, 0.03827879738603388, 0.02960835407007366, 0.02719180823694314, 0.056600877940053904, 0.05729568904385932, 0.05293633465865447, 0.06976260938831876, 0.040372534835290526, 0.023010383517811858, 0.0020647810015361756, 0.012252149510107214, 0.02322665779971548, 0.017348672000450954, 0.08287228133168914, 0.032646243175071095, 0.027620424854479013, 0.02406269529714219, 0.04756299778819085, 0.0682997108707505, 0.031900835794306574, 0.13296667876983845, 0.09668716019199741, 0.044402915744050864, 0.034937478091207244, 0.015604753280058505, 0.08801195755480759, 0.06523882955192559, 0.04809674273635592, 0.0483091444438023, 0.05650294892069313, 0.024163387978689808, 0.05448766270532243, 0.03574756244497915, 0.029334889409402688, 0.05992113364740245, 0.06891665679793205, 0.04258413491169772, 0.05719343162772637, 0.04982543162881367, 0.02592446706858614, 0.05133980359401434, 0.05094683496281505, 0.008175932603227276, 0.02339960789428123, 0.028668710841767253, 0.04308493424867911, 0.06110956201389913, 0.01502545004064638, 0.07030160586920477, 0.020973863260399912, 0.05592306249684865, 0.009266420459044317, 0.049429080719428684, 0.04594310104186016, 0.04156609982131951, 0.05774742427973017, 0.028025204646250898, 0.13573568825039173, 0.007197227988076667, 0.11092408455067104, 0.026868923244276838, 0.09671963465910766, 0.0035804019294559, 0.04292137830728485, 0.056746564880614324, 0.036466846227525704, 0.04952000769516153, 0.015043144756477448, 0.07328861332949131, 0.027080350104839574, 0.04225891143564255, 0.03903636641259636, 0.025534737074086745, 0.016558094160451044, 0.051586434109917575, 0.032302928532684044, 0.01756741883113019, 0.049827837144895915, 0.02772839537130729, 0.024421559609172326, 0.05945313053445951, 0.048146806582207644, 0.017068130602579445, 0.018386560259386897, 0.042607600184818434, 0.04170420632186917, 0.018464090272543893, 0.0853419189731921, 0.0374720799886892, 0.03672288047269948, 0.04713770790746616, 0.009549122224862297, 0.028770931868723808, 0.052900045073681304, 0.046902426984161145, 0.038324061691039996, 0.06062904485471307, 0.024228101340873588, 0.06236028481995868, 0.03181590728702084, 0.04432583197710976, 0.04306628000772288, 0.02925939719012428, 0.03308159179024158, 0.043924087808737834, 0.004503819894330997, 0.04621808064140139, 0.04439940323091803, 0.02077323823956953, 0.01185483141471782, 0.0983146297174596, 0.020008291786296234, 0.09003473611007776, 0.028820605009734154, 0.05601960489706648, 0.08435656136322407, 0.010371639228035367, 0.04967620153160346, 0.056281043892546054, 0.007457462789100265, 0.024913344006504745, 0.04522410454228521, 0.031508962668839006, 0.05262391634225365, 0.08213137471747976, 0.014448589664102804, 0.050249158690172824, 0.019384772824724356, 0.011139363707644085, 0.03168299869303742, 0.0227370816508248, 0.01534796443827931, 0.04804197894108873, 0.018728988155001597, 0.07900733711017717, 0.0605079761495994, 0.041652127664776585, 0.04766997430593737, 0.03070785686553967, 0.02228599184403016, 0.05485361141543235, 0.014606012114053293, 0.026355791806934342, 0.040628929141788714, 0.026353361392994563, 0.030358727615807327, 0.051453690224837874, 0.06234180294878541, 0.12819602709984587, 0.0243690979081176, 0.03737799290026869, 0.04950614150373205, 0.08191182157926022, 0.014487791340798141, 0.05177062462955233, 0.029982823593121384, 0.04531233488852459, 0.01654819438924953, 0.02838936837149724, 0.07781289112303527, 0.021966627025375926, 0.035534773863131, 0.013396945338876498, 0.03187720964272176, 0.013713083969759605, 0.028084808201979727, 0.008105019674516253, 0.06245971920209066, 0.023191624598938133, 0.0059190787555229284, 0.04628497926938919, 0.06516832648025406, 0.05973521942993807, 0.012429004737866983, 0.037439682130371375, 0.01362309162129438, 0.059934306529260455, 0.049176758170248046, 0.033780382720813636, 0.06079823154235079, 0.0657212887439997, 0.03489783304112573, 0.028880953585969347, 0.09552216262466486, 0.030443635055675145, 0.04781036374850139, 0.021324911560382576, 0.014178642304614188, 0.048221178397896795, 0.0936512456786248, 0.022604535033385602, 0.02271927585224471, 0.05499561347307698, 0.06035082853369175, 0.02579903932318332, 0.030181213552432678, 0.07427208636316561, 0.024408767856056654, 0.03958857407973659, 0.09995662426996617, 0.019637798259575522, 0.08180360399907635, 0.024797404260044138, 0.049271224472191066, 0.015304254334149583, 0.060878632470004024, 0.04184334321067699, 0.019860808369553378, 0.0570061959085926, 0.027895132492807125, 0.04420355285307573, 0.01780846456606542, 0.0518986570738977, 0.03489630852615641, 0.04356788373702476, 0.028338279883046786, 0.05494759125154346, 0.014297627250573808, 0.01257460549353592, 0.05541360636632289, 0.08002572077056093, 0.04173663099326434, 0.04915127425544685, 0.03770115176936792, 0.024787833906650066, 0.0689070194118446, 0.04883252805279148, 0.027251923156361428, 0.0028436800705329067, 0.09488412629692786, 0.07204296968636975, 0.09093327297558708, 0.045188695958424965, 0.07011607469570252, 0.04773815996163795, 0.03317364874566275, 0.0191649668774898, 0.06371785390881762, 0.012419825089314293, 0.036623457581886364, 0.052744843321101326, 0.034722678528557864, 0.06311509209955413, 0.007806059607725231, 0.04757660734016569, 0.05562158391600656, 0.073826085295408, 0.07532641486895662, 0.018818388700545318, 0.037619594048949025, 0.044281755108386285, 0.03178868818307116, 0.023036715874989188, 0.05639240626365908, 0.05145302755878337, 0.0748016829452207, 0.05212374136693055, 0.02362871797935617, 0.02855068542093279, 0.03813836197819441, 0.07043768606719471, 0.023918755037049134, 0.03378694043344548, 0.031823054887354374, 0.04441035445779563, 0.047181960976412224, 0.051202463181388956, 0.00175750493062585, 0.0606795568620005, 0.04415116776081343, 0.04024809534331003, 0.07732976543446703, 0.04638835134345197, 0.06643733580506618, 0.05173233938553641, 0.03302362957789052, 0.040911190407050234, 0.02969524567766536, 0.0355921883226162, 0.02589731499732983, 0.003999972245618401, 0.04298068883438264, 0.06689737926447584, 0.05251354222456294, 0.027267426860729055, 0.03772238006574973, 0.028910252618633454, 0.028889878510287213, 0.06728343395215851, 0.019202156615774, 0.04229867522935233, 0.04252215073774419, 0.06301229076099492, 0.009796781213803878, 0.060771200129942554, 0.020425836518106442, 0.07475434637237942, 0.08486004966881969, 0.02027129168592153, 0.02180573515473835, 0.14411621516750706, 0.01951581216417253, 0.014042677019812889, 0.005523580597758654, 0.04574269627130801, 0.027676682521198547, 0.029075405853349837, 0.024085919252566756, 0.015021394562697219, 0.05318664239659425, 0.06816633496313326, 0.04747896560377652, 0.03941723851547126, 0.08118003141134977, 0.06108855971345498, 0.010652127957362081, 0.05312225270655848, 0.07258862347131775, 0.04686100077965567, 0.03742650158763413, 0.026619730164266886, 0.020463376741615996, 0.0723393384607569, 0.02753658802248538, 0.046485315092028155, 0.05931187541254106, 0.0489360686661976, 0.02857881616951237, 0.03685361720741757, 0.022181332742254582, 0.02903345870905586, 0.035737476897455996, 0.008043809249366244, 0.08446536117023037, 0.044404244906599485, 0.051317805379268625, 0.018717946912792903, 0.11371603836455654, 0.17614970674678204, 0.1036096072845882, 0.1489280134199127, 0.0855467708841447, 0.08974235865377611, 0.19018471331125308, 0.1052125390138357, 0.15227595554484477, 0.10995379589017361, 0.2029611140249237, 0.15941750378377978, 0.11514772646008961, 0.18648207247737916, 0.12518678776799672, 0.12979680612202615, 0.13384741941286674, 0.21304977186504873, 0.14283226712817146, 0.11452236122662023, 0.07364787792246189, 0.14935889191204502, 0.2539552817301404, 0.13310016192976507, 0.24692527589298066, 0.1190485925443711, 0.13799728705517708, 0.1081225622986113, 0.17589285278752928, 0.11012182195460606, 0.1133290030843308, 0.13664704176687426, 0.1573147916144902, 0.15868895416778905, 0.09891217063751914, 0.22517809283829507, 0.21693944540475646, 0.17419806711616057, 0.10623637722024035, 0.1187443943513978, 0.1497314404696226, 0.10886402049612616, 0.1378275526146735, 0.11419175598289698, 0.14466882503080755, 0.13129083079195794, 0.1639419730993048, 0.1358114390243446, 0.10730885434895755, 0.22891985012158272, 0.16654578337986625, 0.16881550271664897, 0.12428438981934903, 0.15203065419149014, 0.08880430697313241, 0.12204614137449574, 0.1358230222737597, 0.1296051156016127, 0.16219345402092705, 0.17244766346148907, 0.08555440111987053, 0.20348032245472555, 0.13251839476006647, 0.2765520103275776, 0.10986636993625473, 0.1721306716001803, 0.09896350618932517, 0.12608679552232066, 0.1444946779238601, 0.1597525599983431, 0.11906005321971833, 0.0946379745859773, 0.15111130271707812, 0.1473100050803154, 0.15357887192118555, 0.13030003395772752, 0.17822320032263958, 0.10106130773502012, 0.17540225008082005, 0.13727428391575813, 0.11603664892214922, 0.20482663005109758, 0.10489519475208176, 0.09484514774334046, 0.19340312528994777, 0.20832660998548233, 0.1031544974314109, 0.15458099153493682, 0.22977848146711627, 0.1444126145854112, 0.18270099956181743, 0.11401456750689015, 0.14693831454121298, 0.15621974553552367, 0.1959674513988918, 0.1014831770331629, 0.17881209211003396, 0.14275401890758546, 0.13226350198589987, 0.19420240014310808, 0.14582149624343843, 0.17112246924831023, 0.129712842885525, 0.0934041363577689, 0.19592427468347937, 0.16762593670958476, 0.1887430737335836, 0.27939811889683047, 0.20619254949833118, 0.1470215576550653, 0.22509930835616207, 0.179630825596471, 0.18081878281889424, 0.1592255987587475, 0.10218074605349572, 0.06893261440939481, 0.17310642246757785, 0.20251549600112825, 0.15642217660863555, 0.09346169254352009, 0.10113957893824387, 0.4367597184834942, 0.20632863735720036, 0.10419795514955636, 0.15664258010445103, 0.18148359391958485, 0.09017388832064406, 0.17647066694353858, 0.15565892320967492, 0.17715227069152942, 0.24609938714533086, 0.1907623742496775, 0.1489401635743918, 0.1656717077017792, 0.05677112565946676, 0.210402064746426, 0.14838749242405738, 0.20211118543821, 0.12739963273728086, 0.21766275497934512, 0.08574295067979444, 0.12113282667292703, 0.09487170801167527, 0.11047144150060993, 0.15823208997326513, 0.13716002956273096, 0.1431269505091252, 0.11721570420289233, 0.14787592955173987, 0.15647776394842133, 0.08387971759563492, 0.15154044985050155, 0.13695856376040366, 0.1613430044944248, 0.08178334863435838, 0.1418666439431329, 0.14843877434970873, 0.18927581127612822, 0.2257970612375967, 0.11939154712543373, 0.15513249823162634, 0.17623636661277664, 0.12760653776387054, 0.21903273469257742, 0.15765680390740597, 0.1397241258452977, 0.12691825372918, 0.1284749980174726, 0.12582385116406988, 0.15829248834521542, 0.09542913656801948, 0.12919119829612394, 0.1578359459076197, 0.1356387168409363, 0.14621954020713607, 0.12400010991240702], [0.10411462010515314, 0.01341458355572315, 0.02699823122501614, 0.042584985269293676, 0.021746612319182006, 0.07940440048133174, 0.044757710213983254, 0.031167461739612684, 0.05473587136234968, 0.014980235531355345, 0.010610095585786529, 0.1446904593537892, 0.009731355389850515, 0.046534624341274464, 0.021901588075824326, 0.046747179266305706, 0.020712767089266452, 0.02637044515370602, 0.03966808251495804, 0.07207631749371368, 0.06626490473506913, 0.029325102636170004, 0.006992685385123497, 0.06972281112065239, 0.03580582343162068, 0.014794758941617706, 0.04023873374887532, 0.044213197900042425, 0.022402958148309303, 0.06307785256555484, 0.019953010881680156, 0.013665086646083624, 0.03398904974962916, 0.04128410668683149, 0.02088770901243533, 0.049470426484702096, 0.02696515537888533, 0.028717391898915656, 0.034389093202809175, 0.01686124089774826, 0.027649597482635613, 0.049538884101615804, 0.04013183383992122, 0.01949433680443514, 0.0778361801959334, 0.07424348064007298, 0.05527014491118251, 0.021526999809148333, 0.0029598209150736372, 0.019896483168967312, 0.04109117510398069, 0.008515157293708575, 0.04254256315048664, 0.03845724607667616, 0.05211597706581797, 0.03811448684803421, 0.019607110692548658, 0.009327455641581647, 0.04702793516879601, 0.05710019489690181, 0.049988531747892986, 0.012486446968039439, 0.03162704363104797, 0.057130436217712785, 0.05676745992874908, 0.009844353358681885, 0.02283683012900574, 0.031970794943551865, 0.012468700541273482, 0.010023685923266796, 0.05568515772240297, 0.036278541815737565, 0.0139403602318658, 0.03591735051163743, 0.057888204427135576, 0.040275375734293656, 0.03643596139285834, 0.0539046008470318, 0.01628137171088207, 0.015647544078679097, 0.08370943157182587, 0.07844053929851902, 0.05228389970838063, 0.08334976861313467, 0.041132677917278586, 0.05204119539308933, 0.02604211327589808, 0.05253594646590853, 0.0328491990184111, 0.03697581589221954, 0.0044928155201036605, 0.04630942513505298, 0.09072123515990474, 0.020540563930426876, 0.06232753839163531, 0.08414950311904953, 0.030894481629553824, 0.0501305491272961, 0.0423915021031374, 0.08840339784059795, 0.03692403217897781, 0.024482187807499885, 0.08154161725073092, 0.025158292959414186, 0.025822575459437027, 0.03600938831486049, 0.039067622799907005, 0.06424499134863577, 0.09646461931087318, 0.03142304590813095, 0.04387132733339264, 0.05002491326341706, 0.05290019829126616, 0.024075760926690795, 0.08319252140579686, 0.04878640189887055, 0.0934168074520365, 0.06536471311964336, 0.050099495753285386, 0.022959224166228406, 0.02577139695565547, 0.0459497123806467, 0.05690727480536988, 0.02291399816561851, 0.0482097790095835, 0.04017132184197826, 0.02111340809102741, 0.05151066035332699, 0.03548587064048456, 0.020152789375354207, 0.025245148177829482, 0.058593545409460226, 0.04775849193514836, 0.1289914025654716, 0.03645495271250125, 0.01591110896814855, 0.04020920488983393, 0.0397506897758332, 0.06780233594679064, 0.05169327273183773, 0.04234817600057971, 0.027596614841792374, 0.055549169454963944, 0.02000863461064235, 0.013763298160366476, 0.04545807162480009, 0.05442061852062902, 0.02880541157097586, 0.035319047334093245, 0.017559430449299755, 0.04362888731843522, 0.05739909942231833, 0.05902283426914966, 0.07185630470273957, 0.02394124929372582, 0.054962798096840425, 0.026325171272600853, 0.04403862178385739, 0.028737176119560198, 0.002134161036191208, 0.04043427003066867, 0.022206492984907764, 0.016624276496229634, 0.046501379955800316, 0.03455218183056962, 0.017217847165621577, 0.005833766246665149, 0.04496220206361144, 0.016814247149253086, 0.03732806311980371, 0.0341421868952532, 0.03219659935923354, 0.004156661405783868, 0.00923933542048138, 0.017160668278173093, 0.05983970233149106, 0.04019673680886626, 0.04923957354959942, 0.024538644657079733, 0.03440750229562964, 0.032096247586812225, 0.03697837462588664, 0.04403725814735217, 0.024770851652588577, 0.040620709018361185, 0.020354222618944703, 0.010773567257509118, 0.05003541249841933, 0.08641214380341192, 0.0342805500352575, 0.027390839794891018, 0.05842722389065932, 0.023520295470652562, 0.03652842820531899, 0.032950276659140666, 0.042819507765553655, 0.031484769612190225, 0.01664245767789262, 0.12897563647598992, 0.030146525091221257, 0.05877213199592887, 0.010158686894893406, 0.03363391054013083, 0.04195316957550184, 0.020825881886506276, 0.04783030118673079, 0.12170794419944288, 0.0700968841931993, 0.01484234162020467, 0.03301513749324987, 0.038576579592641325, 0.0615498289135435, 0.06858551529266181, 0.03911525048615952, 0.032936609650571505, 0.006922049684480074, 0.018411237866647782, 0.008804211843638651, 0.037875961542369864, 0.006544898853697364, 0.06143742849329307, 0.036205690684578115, 0.0474828994652677, 0.016762208711776524, 0.07295479817736535, 0.02685227615368222, 0.12010858243992252, 0.015616970467230967, 0.11690668731687531, 0.051700362875576944, 0.001995299939036129, 0.031999442801480336, 0.08753948048838685, 0.06606540777870724, 0.031563917986087264, 0.02380063385522414, 0.046232394994266575, 0.00464318996115077, 0.026610544770054763, 0.02397801193799223, 0.013045628908120338, 0.021166758454074303, 0.08876096937925586, 0.012239690047628697, 0.054010822768172914, 0.03871376295724223, 0.028547366345000845, 0.09299816338405495, 0.028754999155118584, 0.03595613371280413, 0.016819033283560027, 0.0364351493396586, 0.02674238084094419, 0.044096089869497285, 0.05709313156623995, 0.06196222936494216, 0.03762239793075189, 0.04444108224443851, 0.03322859640203176, 0.03347047717280446, 0.052586891312873175, 0.07555430304379233, 0.06443043825246635, 0.011893241148021434, 0.011616943877250438, 0.055614417163474913, 0.07552390467495688, 0.0700295527255343, 0.05255168957275249, 0.038314627318252484, 0.05784969701762161, 0.06521301238887733, 0.03996919337359648, 0.03158567871357645, 0.06670644717110742, 0.09214344674781447, 0.05211825234695308, 0.042441565948989124, 0.046322824012848644, 0.021676750846147057, 0.07847607045644715, 0.021899845225796587, 0.010855015810398806, 0.024363463331434517, 0.034677345275638566, 0.043224469503207553, 0.04326307267371205, 0.03144974981795155, 0.017031639919526154, 0.03845126676042715, 0.019009510400674997, 0.08035689291934814, 0.028823098625927687, 0.11733655457294757, 0.060253359167085546, 0.008162591182025931, 0.029286970609738946, 0.011003239459598498, 0.04829917380946779, 0.03041248400545409, 0.06484656955205625, 0.07945822581889168, 0.035414459754622755, 0.049963833073214184, 0.01707018754865614, 0.07606266366858637, 0.03346646287208123, 0.06626993793273164, 0.025371897424901688, 0.021861678725408933, 0.017869031477359035, 0.06686950132491128, 0.028756485365691687, 0.05406582405069663, 0.013844348347535538, 0.04502608996605681, 0.006847445648388878, 0.12288657047094838, 0.027170746564684857, 0.030657896441557718, 0.015636787246612292, 0.03353303974314082, 0.05488685197046688, 0.012541528689795205, 0.05414353984017527, 0.0693034622517805, 0.05217939382418991, 0.010981977646869999, 0.03957901330244157, 0.037703047836980516, 0.08833546882435199, 0.051503842170800895, 0.013206563871203652, 0.05931793899846174, 0.08011244192358949, 0.07630180567502975, 0.024260437912157467, 0.012721857168681681, 0.02898973232555774, 0.0658620344174485, 0.009929004159095067, 0.043813790299839554, 0.03191587793069982, 0.03945524030695519, 0.037996283311757355, 0.05950530495254263, 0.02838753742135821, 0.06759483337162003, 0.06595641644971986, 0.05306350908452465, 0.08263253411578556, 0.019396484393866795, 0.20596054743134207, 0.10979497820259103, 0.0866958108400145, 0.08256024605925046, 0.14796252813070052, 0.12685977823791966, 0.1939316187053919, 0.09224966483851595, 0.19810802363339933, 0.12936870086817973, 0.2232502785421187, 0.20852101245714774, 0.17970342008817583, 0.09632625617086889, 0.09869621045166448, 0.17394705074689082, 0.10622807282714114, 0.1648975605325353, 0.1312644314020872, 0.181822020921015, 0.10926304505236688, 0.0952375686216739, 0.14052303297625435, 0.20963082871129438, 0.09965597306408229, 0.09846078397165384, 0.16600126340504617, 0.13713212864052865, 0.24363880466309287, 0.18364166360228293, 0.18821291024646453, 0.10482367278347093, 0.1942230079082712, 0.10850041984550415, 0.1892539164832523, 0.2208882302887017, 0.17493070764166696, 0.16045593596514196, 0.14009466725251368, 0.20622599689710527, 0.17213882277569464, 0.11430960328828906, 0.09821564349676333, 0.12520823822987656, 0.1536867524226827, 0.22676004908017575, 0.14234315063203537, 0.1662524023483838, 0.15017134347750297, 0.20209419360804945, 0.17490037055986543, 0.08479175293037007, 0.1932800149605159, 0.12351186675650459, 0.1638821416324185, 0.13972244045186427, 0.2008008380090037, 0.13931748637508962, 0.07006991023738539, 0.12653270465952735, 0.11149785376244015, 0.07632568463562958, 0.11884437648639565, 0.11020912533445705, 0.13371805780597273, 0.1490314199679321, 0.18350595878737588, 0.12345169055005237, 0.10923362727607451, 0.15076357540824722, 0.1280057998073678, 0.15476099155362577, 0.07016241535424225, 0.20225102712790813, 0.18163881865480255, 0.14325795154417717, 0.1293419184343469, 0.20656610929196884, 0.2549103635453409, 0.14504669023857963, 0.1683448642612465, 0.08234977872381288, 0.140572369038578, 0.1225825178346807, 0.13639165869643613, 0.1995706386984356, 0.14231981559386178, 0.1769163309326095, 0.08854453421888814, 0.3118453439204924, 0.12984246496231328, 0.18924182761580716, 0.17143834262124955, 0.1358167403527806, 0.24645572528243068, 0.3870936254820516, 0.2822736758858927, 0.14729759445594204, 0.2489637286071816, 0.20420016931189647, 0.11783035186630104, 0.16134390847817545, 0.13814816041098488, 0.09054609213865573, 0.1536468392418277, 0.09262447335547017, 0.1608004150611739, 0.12135375876941028, 0.24412741554119896, 0.13460845115684694, 0.13318536622870353, 0.10575837665988554, 0.10835320838997442, 0.14289027530579798, 0.16415764217174825, 0.16460931229014553, 0.206543586306995, 0.18496072911206754, 0.18058051415268453, 0.11385611754151122, 0.14438895779030939, 0.08409469718894652, 0.2469079776276504, 0.12243841669612354, 0.1294337723764681, 0.09049676373721131, 0.16921279591418084, 0.1410487378316541, 0.12758658117344304, 0.15169248765995427, 0.15178392791459638, 0.1708587817847729, 0.14887519931841284, 0.23642170483306532, 0.13822487645572232, 0.2064794494259742, 0.1265887133476715, 0.14317043365970736, 0.18870743532334605, 0.15337432644540264, 0.08306655356840742, 0.2289172301008817, 0.13647864031935894, 0.10610575156827128, 0.09881465530563747, 0.1720854264473723, 0.16028090019620236, 0.07984290920918988, 0.13285231716450185, 0.21281458287229463, 0.18390581071857484, 0.11843645764935402, 0.1275849647279228, 0.13370069825360853, 0.1857690131592174, 0.28700144961476326, 0.16584017043632848, 0.17844509002902817, 0.14729851376145117, 0.2829709691145728, 0.1591829123396066, 0.12183185892119525, 0.18982443748222244, 0.23531925834475026, 0.08848231255767808, 0.08134787361468039, 0.08671606620473248, 0.1066991556135397, 0.17726798061161272, 0.17722029929920552, 0.11411489438145392, 0.1568177690909755, 0.09306050761933289, 0.15705180895184317, 0.1462441009859885, 0.14357544902351596], [0.043557189149601806, 0.08775323434101959, 0.007539063601964905, 0.018783535530430176, 0.07433780138531039, 0.06698255291989735, 0.04027025443651984, 0.02654836524368054, 0.011612394272590117, 0.10015607526105258, 0.0900676012820294, 0.05075782191969695, 0.027482224508158626, 0.016268407587983435, 0.02612350628741326, 0.05072089265130701, 0.0428316502591535, 0.06132091418088925, 0.030714297749763055, 0.021582022159089966, 0.07506055937659356, 0.03502710654790844, 0.034845670114361474, 0.050574807345025966, 0.008251978321030976, 0.09658888643307072, 0.05993581955291091, 0.04486190966300426, 0.045090835886977376, 0.05779267709341742, 0.07374641981216208, 0.021831910463891203, 0.05171452401085727, 0.037357791161705414, 0.019241313284803784, 0.030584355831266414, 0.0659552060307995, 0.02197398913032826, 0.023110287128797462, 0.05626720834463354, 0.01819648426927386, 0.042878948527598576, 0.02925084956410912, 0.03201554022398928, 0.05720941605226648, 0.08291627010030132, 0.028080020152452975, 0.07061120498204423, 0.05892573645518673, 0.02191862587126032, 0.045972334957050706, 0.03450002273424499, 0.016427918585137497, 0.05934153067608995, 0.03638959775168089, 0.026051534242146922, 0.056227050015642766, 0.03918556203584998, 0.03996736242345745, 0.023259473175952033, 0.03096188587557164, 0.06423053143906497, 0.011861638105925054, 0.021929881618087812, 0.11462547666122837, 0.09972153486864221, 0.05679379803158584, 0.024390741807198333, 0.049736940812680035, 0.018976721837515795, 0.0414466705443638, 0.020660328370849454, 0.05121935542011934, 0.11591154676411422, 0.09189072966335282, 0.0862482546137706, 0.03276132107261689, 0.06288394422060059, 0.056140681263059385, 0.05219153631778975, 0.033175088990960395, 0.05224004117471557, 0.08575802729014428, 0.026179310047037663, 0.027648618805312344, 0.05307191306905401, 0.05649703472191769, 0.05675921299224419, 0.018497394029832175, 0.04723993851052177, 0.09837909601628782, 0.02960931359519882, 0.06583918201466722, 0.024549433090273413, 0.059464836357942516, 0.03838241843867206, 0.06189226638525725, 0.00890092661363944, 0.05365364576479601, 0.023795079717773105, 0.005206231547955183, 0.03895245680224992, 0.038318204948858875, 0.024904974495931983, 0.06241778737955517, 0.023157899493291494, 0.0731635264932148, 0.05344030559964238, 0.035749312955886126, 0.03717325590250473, 0.03818509334157552, 0.04371809059633844, 0.011395992628569085, 0.08830461080276197, 0.01136610179298347, 0.03462740783429435, 0.05227095665289991, 0.09283334722802525, 0.024664455446444696, 0.024416396176562678, 0.05548959845797189, 0.03061256127341861, 0.02681678521537012, 0.02669313670917144, 0.03721705314913585, 0.050383825455942464, 0.04761087445301875, 0.07023745366642553, 0.07417683099066058, 0.022609104747853936, 0.05801158288734094, 0.04442274976041048, 0.02146955279092635, 0.03440481332701541, 0.04885863632925096, 0.0357187383868281, 0.04833763525370629, 0.0866689671191477, 0.05541179456838197, 0.05715332309445066, 0.023210280755114172, 0.04029886782049172, 0.02515213744294259, 0.06601717488299455, 0.017151986586771185, 0.031068797275844603, 0.10992595625500526, 0.03709465145103393, 0.041251379410706224, 0.02651265213987039, 0.03193529442914071, 0.03795322150953355, 0.09856999746613926, 0.05313849377055323, 0.06622477704959531, 0.006169027389748203, 0.031089207773367246, 0.05067784234040207, 0.06294480607574506, 0.047293783000279824, 0.05349808012045199, 0.03165139182050142, 0.025874937569061597, 0.10896508281509723, 0.037392027631041505, 0.05050659104580841, 0.003977514617520595, 0.043645243295618606, 0.0547923397032484, 0.04156578189483093, 0.06643303805181096, 0.03457314199617794, 0.04361450018721723, 0.022110073158757824, 0.05368089934270229, 0.008018593944143504, 0.017727596324778373, 0.03299785071923848, 0.009223973442379747, 0.024029397285513343, 0.07145986186280366, 0.05710726971888254, 0.05797510178038671, 0.042501408907194296, 0.03341806909790443, 0.06532643170606706, 0.07371422879758381, 0.06085669171185263, 0.06759825778464157, 0.049686938253862244, 0.07394242340758925, 0.05734688669983899, 0.022999506984506885, 0.06882813533828144, 0.08005929840428215, 0.07502822280530969, 0.015881325384872337, 0.046850566662126975, 0.03459938433802417, 0.021724650493612694, 0.032839159436163404, 0.07314730841185778, 0.042679650754097014, 0.03331941612545521, 0.038321686818474726, 0.029430100731852076, 0.01863031794557408, 0.012093785729619765, 0.05074085307217414, 0.03782618497948974, 0.04024045361626533, 0.03062864145894926, 0.03650854822368391, 0.03414058960193107, 0.016026493300864055, 0.05557179969224719, 0.028021155871571075, 0.05923111442356341, 0.03812742224263568, 0.023195920436973536, 0.0451817398800725, 0.028694077928159988, 0.05094760488117895, 0.07767255913706557, 0.05805328105305953, 0.04042389336973429, 0.10846889532742002, 0.03661477780570427, 0.0057051740793300975, 0.04083609463827264, 0.07080654974185652, 0.02647924496071233, 0.05413806614195628, 0.01462618895475903, 0.07193511982838954, 0.022704350544259917, 0.03499203121229526, 0.05972150645609345, 0.04907969866068133, 0.055663328047000596, 0.03213099350461797, 0.06242567042429602, 0.09652457335182736, 0.05981296203249405, 0.056743243889462565, 0.0198258230492713, 0.025443769878737872, 0.06038067914966134, 0.057092411443591125, 0.14637242071330547, 0.040180970719384576, 0.06753884766611361, 0.07745848352750463, 0.04867632272503069, 0.07561279385681115, 0.03936363151296973, 0.03814756652460464, 0.029152905222989862, 0.0741776736873773, 0.015282919743068278, 0.03374665953038681, 0.1264507792169048, 0.012964627559056446, 0.06134658961767151, 0.0802423627746682, 0.06521056090751964, 0.037247972457759806, 0.04623332579109458, 0.05001950468267164, 0.0740931282240537, 0.08507086940470242, 0.029473327242979602, 0.08554362992365515, 0.04054244930645631, 0.009128279484538062, 0.02955323595914149, 0.029863986119087187, 0.06733208819622956, 0.0617068960902191, 0.07436705828313867, 0.08580455947066508, 0.015009587232564247, 0.04421720453988641, 0.10754067255484481, 0.10405969160098223, 0.04406648440166347, 0.0662391105546586, 0.02861066819018414, 0.04026216837847906, 0.04225135780870915, 0.0032507387344770495, 0.09453338826255453, 0.04134346700964436, 0.06617904160051577, 0.005474627100592179, 0.0501493948902334, 0.01197088798958688, 0.03675453139529113, 0.017951309320426757, 0.012893333501603096, 0.01819484675633571, 0.023185840635109815, 0.043769740244193424, 0.022557794093905438, 0.031095411170334108, 0.02139629371794722, 0.043576107690891916, 0.009795871484393795, 0.01844892173164314, 0.04144838275087457, 0.04786072636864359, 0.08659297885793833, 0.05281461477880517, 0.05381104618971867, 0.016233606128803185, 0.017265289075552456, 0.04966210168335707, 0.04125254769479075, 0.02258349442854524, 0.028747797928630348, 0.03749620792786441, 0.09241212910461812, 0.05779309844177577, 0.027897241149818706, 0.019647085160437613, 0.06137916750665154, 0.010412103992195861, 0.05284488674313311, 0.029903037451027386, 0.040564773108569846, 0.046155020113914244, 0.016825525878718304, 0.05910982738339132, 0.014618874730301962, 0.0988805388671256, 0.0386426163717143, 0.0075102735389654925, 0.02452907813412528, 0.00530422568478952, 0.08767727672332719, 0.06134327245695938, 0.04580825424542831, 0.032091497841681686, 0.05159406434564341, 0.05518265767022968, 0.01656187480435737, 0.03230679727670166, 0.017124960920022383, 0.09806580435965331, 0.016094448172577446, 0.04400999307812702, 0.026109676485160188, 0.15224679823844664, 0.12406907314735076, 0.12775261540927235, 0.09094824999450676, 0.22036871542373013, 0.1984507866924809, 0.17380923152931277, 0.167835952053147, 0.15468957683732434, 0.23137886978445515, 0.2122868402230163, 0.1058837239660563, 0.1679297365368374, 0.0760555467117698, 0.1831844163637969, 0.17683710211948042, 0.11446266765556029, 0.2140420089445768, 0.29932498511287475, 0.11175204173571641, 0.18142416081841917, 0.1118391612544656, 0.1922769453977385, 0.0744038611470211, 0.17462681588386336, 0.17898744963590177, 0.1058036141518143, 0.12870281724439514, 0.20395543486360582, 0.14195295140868233, 0.19269688415431208, 0.08759462349717656, 0.11269404643004942, 0.07857112664609187, 0.17743959962841005, 0.11896240765288954, 0.10057482658134353, 0.1510624722727845, 0.09420510426524187, 0.23944896255289358, 0.15402399964870947, 0.1428885439470891, 0.0888439826667309, 0.14049511673229356, 0.12341574570464513, 0.16582540026114834, 0.07780086354262407, 0.17618134617805484, 0.16000259577506976, 0.1782600185082805, 0.2200887409309226, 0.10134940275982504, 0.13226610668484243, 0.15895717687183814, 0.19554642479746573, 0.18657449332456436, 0.20017859075338612, 0.13560035115768834, 0.06931231056730594, 0.13146506982945627, 0.16804189180895207, 0.11433827029841562, 0.1421755305942028, 0.18480498343706134, 0.13865819110745384, 0.16245153372085866, 0.12889539642680076, 0.1911380178024692, 0.14649591408669949, 0.1225861337696833, 0.17478547269298186, 0.20972052228546914, 0.17426097825650247, 0.24502997436831075, 0.1618500014827136, 0.21666271912474788, 0.16046764178862497, 0.1801313721244374, 0.2728768720501854, 0.16471386797005133, 0.2057971868423685, 0.13792432484126863, 0.13958350274591677, 0.1556010222843578, 0.07539421365025543, 0.2207312895165336, 0.1455592030599233, 0.16960089605662132, 0.17609935944839833, 0.2825556881725788, 0.21845121267101458, 0.11462214417875775, 0.15283948982194548, 0.24829065907866726, 0.17218595250479637, 0.10941647714184177, 0.2095769420867005, 0.18516852280064938, 0.14485106202623538, 0.11444017531410342, 0.21574197337031367, 0.2414128136250281, 0.1724713815436248, 0.1681338530033827, 0.1756388027100794, 0.11604164381541553, 0.15327672684384933, 0.17937685212781354, 0.13728309392688737, 0.13323148472174523, 0.11707442992877577, 0.13311776663026503, 0.1267571454387038, 0.380000141599486, 0.052279609616004655, 0.17129304638553053, 0.17759097860224787, 0.22676366501517836, 0.12415369521946677, 0.17567347584953233, 0.15360113443626514, 0.10389813897950996, 0.15050097578956237, 0.15444246751646842, 0.15588930117026453, 0.13012121371444196, 0.11498809671930729, 0.17036030369420208, 0.20012013824476352, 0.1632955787523139, 0.15888315745659415, 0.13393271564235612, 0.10653252382912945, 0.15126010763549036, 0.1256453143733163, 0.19116945805088167, 0.15396554714008687, 0.12661814644572236, 0.12916510534142295, 0.12891703074978245, 0.15462251350043282, 0.1654759109500916, 0.14393062270697088, 0.1543553020324438, 0.15098903508436295, 0.2205869125863237, 0.14909013294644896, 0.15186986765794216, 0.11198593603987848, 0.16523044105739365, 0.1290538080877835, 0.1275463385747806, 0.18450426328326427, 0.17981261826090275, 0.3022617372053285, 0.13455295574761209, 0.11182071385724891, 0.11283558117406023, 0.15281629267959826, 0.1022505060198807, 0.1593060992778309, 0.1491406641059345, 0.13941747617096673, 0.30368405604554766, 0.11711999683851197, 0.1437454286121553, 0.07097518867662839, 0.17963467135785088, 0.12257631252249404, 0.14614614898399, 0.14325382999114453, 0.13421379330177463, 0.13084222502525777, 0.08493830555028493, 0.1214793282410791, 0.15681813681317916], [0.10567901761180933, 0.010915259049544412, 0.06466181978823678, 0.014098014423413383, 0.021490216097464005, 0.050117973794019034, 0.03514884941039547, 0.045029514379078345, 0.0391566958428631, 0.02487500705155394, 0.02010332882374285, 0.056738015339379354, 0.04386982197062143, 0.03297443524183285, 0.05733524216338993, 0.04292918474323327, 0.020845512889565963, 0.02237516830885603, 0.030889511634145054, 0.003069195048620684, 0.013051477989422218, 0.009386769041509159, 0.04827958494124394, 0.06282975882171624, 0.03581406270724631, 0.006987264834254259, 0.008104208578926422, 0.02248268491858917, 0.05518854122548815, 0.040578194969003244, 0.11424070134037927, 0.03134581275404461, 0.017494665376181086, 0.06888903932826174, 0.08339636974156865, 0.04896118102835552, 0.02135520650734825, 0.004200330332687666, 0.049019323271368785, 0.023726495696351897, 0.038352835953475974, 0.06384346934576189, 0.00512136193367863, 0.05511079862293217, 0.025010585461953477, 0.0723722725806217, 0.035370210516116316, 0.05141303776913593, 0.060187743736370924, 0.09078401606529952, 0.06719553302372656, 0.005685411883713377, 0.01586244610558835, 0.07156994869752277, 0.03588664953807189, 0.05350509365539878, 0.01040805904795566, 0.034058805885574514, 0.07412122066823706, 0.03231656489773624, 0.043214774660525784, 0.0701777600953656, 0.06609954465661319, 0.05483711754242259, 0.014592409265347788, 0.03904355614776573, 0.029973205359232043, 0.049496753096219995, 0.06875960877345455, 0.04604674124669644, 0.022127972803108638, 0.058777628676785584, 0.04444342647348681, 0.03673130743986657, 0.0323968279295631, 0.037249366737781994, 0.060335242474872264, 0.02609616077895607, 0.032359527108529886, 0.04850631249287436, 0.03001760398488372, 0.07234312293510284, 0.02590204559026226, 0.09394674111277827, 0.03999664230392345, 0.0358932378942207, 0.05195690273878075, 0.06141458375139102, 0.10268558267383807, 0.05685112439095975, 0.09139199876376698, 0.024245767328407497, 0.07553907321585764, 0.06132689732757788, 0.036058414111574816, 0.02008484312212996, 0.07900327684417849, 0.13650556064901814, 0.019411476734544963, 0.0330003596571905, 0.0206867526585777, 0.012249867525702764, 0.09816831458480128, 0.015798117702586517, 0.07545756912159343, 0.01333305073316179, 0.018328121157302972, 0.04761524498462678, 0.04356871111198299, 0.0396758966117857, 0.09654701972800879, 0.05735652791636606, 0.0545628427437717, 0.04815703385599679, 0.08622506513230263, 0.06358572672451697, 0.06256966431054377, 0.07881020736550132, 0.05956134045376413, 0.042342043466745846, 0.02871082269496495, 0.03169012522595304, 0.03603794424223804, 0.019395260568407756, 0.0205842730769467, 0.06506472074937436, 0.08095186744486133, 0.0390784323005186, 0.0565473283941467, 0.05013888033347265, 0.059218175198522315, 0.018096400627626047, 0.011258841822704962, 0.014052163103535293, 0.08000721208631031, 0.036277128383517265, 0.004275552984777718, 0.08303608625165879, 0.037889283811373096, 0.04512686117161666, 0.05078578795937281, 0.080151550712124, 0.03524852894066322, 0.03643448284316448, 0.02777911613755409, 0.024255065720588453, 0.017206991699734525, 0.022608371218666438, 0.06037303742261664, 0.07560228313049001, 0.02245880787320916, 0.022343277983788042, 0.03964144946827043, 0.014358964080231325, 0.013894906320098429, 0.06316540492398125, 0.02326283055628019, 0.05901449157165424, 0.0691049995141164, 0.007591902122517387, 0.011358092343735119, 0.05528238699621251, 0.011319169331522239, 0.036812715773140235, 0.035128720450185, 0.01711181868168135, 0.0034616137723318275, 0.04692758148115489, 0.021918985932584734, 0.027903862064704302, 0.011276310542598368, 0.06886610265580878, 0.07201909838664917, 0.005215027194935829, 0.07224123324117354, 0.003198323238100256, 0.026070546629207752, 0.022842146779200243, 0.05319415388869182, 0.025296340088149714, 0.08211427563500982, 0.006920521817876087, 0.019832442048937082, 0.02291520858453887, 0.0356361081433152, 0.05515975547173331, 0.06571162837527453, 0.03847696901028676, 0.004747684354022627, 0.03583230709116306, 0.007509835911238747, 0.0531839304453423, 0.08656855597491227, 0.017557076644152403, 0.029653585816342986, 0.01777713156996235, 0.048042902077037486, 0.025251862938485803, 0.09370821963755355, 0.0297736432853966, 0.014995387792887708, 0.04604972515916152, 0.03145040673834663, 0.09062253239174044, 0.0675349252959413, 0.05411200000033264, 0.06062175169767392, 0.025108481922577468, 0.0377407010584589, 0.0671606760231718, 0.0770164507951948, 0.015978371487900375, 0.006428977780629911, 0.029189644884618542, 0.03424300023564889, 0.053845229032900066, 0.03422791213398019, 0.05125274919273873, 0.024541576858609918, 0.06906488715040107, 0.006427475290688416, 0.06292003462271345, 0.05341567204243714, 0.058858818675000826, 0.05343681606914728, 0.06951808178376767, 0.03619963092909705, 0.02859963077841507, 0.04906065371488372, 0.05685667086753154, 0.01849327439201936, 0.044815254908415585, 0.022842005052934253, 0.04158334063005544, 0.04209648547393661, 0.10195419087164825, 0.0038289170216528642, 0.05005930295033802, 0.05000208767371313, 0.04669761720804438, 0.05363715189178625, 0.0905292611869593, 0.024803186308652646, 0.05304575882731907, 0.0896882881680804, 0.02684161795543567, 0.028013002780836918, 0.049890832554909496, 0.03242129677786462, 0.016497921784438433, 0.12215523229491328, 0.030699901042446017, 0.028321860703609647, 0.026920547994274287, 0.03724585422464917, 0.006070199653491259, 0.04377172441191731, 0.06786028283738321, 0.03235058686245353, 0.14478836539051226, 0.011751028416197629, 0.0414206656897741, 0.03674866699223076, 0.12322258429541705, 0.015115671257878986, 0.03837871057311854, 0.0769073139095018, 0.07503998991582664, 0.15822674267955367, 0.07628079954414599, 0.11314510367810728, 0.021208904781228593, 0.07423232639989547, 0.08171379551171296, 0.06177510855899704, 0.07839479618856023, 0.013988675482030359, 0.012476871826595837, 0.09708033183649664, 0.01797559622284626, 0.01382180525275368, 0.02606505569401047, 0.018039330907706774, 0.06317306580322404, 0.020540042990638364, 0.035446532025572755, 0.03582887118682265, 0.026632709608924006, 0.05166658605899542, 0.027394953687044404, 0.13766383962525477, 0.05192019563588885, 0.02580766930365034, 0.05412400076766649, 0.012037701390293098, 0.0425171596749175, 0.04609021290595974, 0.019760236346853838, 0.0322424458910621, 0.02411450390824147, 0.008873114749158343, 0.10571343794224725, 0.08586854313410099, 0.024245683058735826, 0.03952539097818156, 0.07712277613820569, 0.12045411873728999, 0.04017025314932389, 0.04736321737929698, 0.03519677587093846, 0.0908772566265637, 0.01949204045588211, 0.012051054302813306, 0.032950238354744456, 0.039824632582284754, 0.0820293854321203, 0.007686175944869437, 0.08842874769001238, 0.019857879998462818, 0.05627231432064887, 0.05061409233378307, 0.02688586719394211, 0.024687292527467496, 0.027238800070218505, 0.02155614562422758, 0.11247237122827962, 0.03889333013625395, 0.020301255299859954, 0.05173980874279815, 0.060929240238281994, 0.056799007429470943, 0.004365593213738213, 0.018731228962180116, 0.04647703368156668, 0.019261028557535143, 0.05265192834720497, 0.04839541743539515, 0.04304264236481921, 0.07336267104913151, 0.033105696746779066, 0.01084225757362982, 0.1185330613366058, 0.03457753934086331, 0.008341883526994817, 0.03867561560905269, 0.03869638042224031, 0.0010796199410012172, 0.02871066373172066, 0.05714860016239747, 0.040573667389370745, 0.01536638406480873, 0.01454576217163835, 0.2434398822726742, 0.1830015971415466, 0.14695902955868553, 0.12549695378590014, 0.22948903812756463, 0.14614165970875373, 0.17222368999594645, 0.10166516888045496, 0.12664275318985024, 0.11200436045445743, 0.1289423116512837, 0.19804776315727543, 0.10232480122677742, 0.11740433037160866, 0.20853835668775345, 0.1584400675229488, 0.17987339967681518, 0.10353405569349566, 0.1960182583500301, 0.11816312513885, 0.15076650186411797, 0.17210569713384877, 0.20742135452887706, 0.16643103873056753, 0.09627063818756612, 0.156593642407848, 0.061820552894665357, 0.1446895094047631, 0.13461016719379734, 0.15326230906911437, 0.1931264602969731, 0.13391956957357545, 0.12206098815846829, 0.1205314553132461, 0.254509914065561, 0.19043505552314943, 0.157544985713978, 0.11196621693670751, 0.0987121450804895, 0.08430628301275354, 0.19717964764323928, 0.2244884451670993, 0.10821428600578539, 0.12516400431312863, 0.13034809831409686, 0.19789324322294807, 0.10938703638291168, 0.13261818537308326, 0.21095832118824606, 0.19405797724762272, 0.23853362537920478, 0.11540517796792331, 0.22707936984877433, 0.26897966020530273, 0.10160116223438133, 0.14175363065254304, 0.07957224268466234, 0.1357605248208969, 0.17958691343665126, 0.2117529995138607, 0.14490687919239845, 0.2516664255170092, 0.16776027788798656, 0.15413119067107478, 0.2277712698184675, 0.14385260431276214, 0.19508772199192356, 0.14731325329311434, 0.12017274230358102, 0.10876134173163485, 0.0894244474869582, 0.18810599501575195, 0.09836935137789096, 0.09927566403583174, 0.18825201137411982, 0.1425994989732581, 0.14178044372989287, 0.191114820660122, 0.1152578439383257, 0.11006084901671256, 0.21993385327439155, 0.1386933698649368, 0.29018181766713824, 0.26181909766408706, 0.19618430024673864, 0.17118832216628138, 0.16966287256969562, 0.10932086170801233, 0.22416193849377095, 0.17709410929631803, 0.22243781165490228, 0.30177082806344957, 0.28704793583000865, 0.20201324875796997, 0.2712257687122591, 0.13488412023552004, 0.20175611900706447, 0.28320876280626944, 0.205236655629931, 0.10706000600851352, 0.13815497859351097, 0.17390418046664807, 0.22377809780018948, 0.1308886039881937, 0.10910921459717136, 0.14591350340314452, 0.10026549559927757, 0.15984202374614057, 0.11033218969861347, 0.17307101388371762, 0.2796780474243626, 0.1188814168375346, 0.14535407535731792, 0.1886396978290812, 0.27789401250981516, 0.1251865656024987, 0.24500365158723247, 0.16038479704049327, 0.2032013132327026, 0.1367682828417709, 0.09791108524246563, 0.12483183625003985, 0.16758153425349345, 0.15027079701183305, 0.0959076427464043, 0.19687088356623728, 0.20494116019577752, 0.13937771620769657, 0.15613147688488807, 0.15402835102811938, 0.22716996740669976, 0.06837882477069093, 0.1863064851251341, 0.12088168006871017, 0.1629586992484908, 0.2250101510435343, 0.16783550772215092, 0.2415611129254103, 0.17118918018475657, 0.12861952816526737, 0.08593292516325751, 0.21664653934778708, 0.12352664459256396, 0.19740303888195948, 0.13982256814356775, 0.10166931341612533, 0.12682838395478266, 0.09318461386306633, 0.20124872365305502, 0.2633154818848256, 0.18634773129897733, 0.09984073814966025, 0.18997233841688405, 0.23224467171295998, 0.16177320882918375, 0.1592567019284733, 0.13666662297421886, 0.16143611482074186, 0.20059856015347666, 0.15547460245509304, 0.1341823990186376, 0.17680469660028336, 0.1548192908446635, 0.10258028388864572, 0.10136712237351364, 0.17289968598033154, 0.0989422319276679, 0.15619602745338795, 0.13932321671276324, 0.09607833479681323, 0.09039401602480682, 0.11785907250258232, 0.15245932635040055, 0.13822401843724713, 0.17906562124769534, 0.0874907726181611], [0.01870043797328347, 0.03558743091660642, 0.08680564486571858, 0.10650321330514648, 0.04325445035412427, 0.013312686200914605, 0.024175076565194516, 0.02172291913490382, 0.04421471858457212, 0.05829303976028197, 0.05504207287524497, 0.09492190975335338, 0.028076097782280658, 0.00694434188546673, 0.040975537962250175, 0.004429678383824086, 0.011606770229615994, 0.060321096661350423, 0.033882314549578775, 0.04370834978838121, 0.03356091385226577, 0.033697668207629074, 0.0546237658859501, 0.029155124962750464, 0.04495487060217608, 0.03195780592279569, 0.08804653110283037, 0.026453473762939536, 0.08195832311626404, 0.03769711065556734, 0.02393396379756591, 0.04297094802642542, 0.057697394907835035, 0.0124039871790897, 0.04286459587033718, 0.026786095733123443, 0.019140283524569486, 0.05177202274001414, 0.03329990003558417, 0.02629659427780538, 0.023438061677640485, 0.0078095754724927255, 0.05346041540765474, 0.043098731492195404, 0.03724939355085935, 0.060306157946826956, 0.02693393538075109, 0.05648452833655381, 0.03144328403587063, 0.048404710081916665, 0.123247918823073, 0.03287043497567216, 0.04585736048137469, 0.08371485547432977, 0.03472779216545244, 0.05653409422525475, 0.042276412714272744, 0.06585866363058168, 0.03305907646614698, 0.054991265924106685, 0.056800765601257165, 0.08903690658870245, 0.08182058050747841, 0.040849321146285346, 0.05987989130399882, 0.03803482136478828, 0.04813165336306538, 0.047860469729188955, 0.08443133920551309, 0.03275413133744751, 0.058967220116286516, 0.01565423489908778, 0.08825191927532997, 0.032259698191116896, 0.019844519425063364, 0.03644102523403783, 0.040064870094459866, 0.015338191071585303, 0.03690577247330258, 0.08209835632794327, 0.08265345597699766, 0.09736418273420104, 0.04538769495763606, 0.061336385326520096, 0.06008351747427256, 0.05758311757217011, 0.060102704146336165, 0.03131539714823087, 0.12205007906642654, 0.06593245321944838, 0.11811232584859095, 0.05784499323776653, 0.19849713501189986, 0.20176463790478247, 0.06525634232187463, 0.03613393888959, 0.07010308184450673, 0.059945453108558734, 0.04644838965407783, 0.03268313796950444, 0.047520598652021545, 0.056802090933366176, 0.057012818738698005, 0.058449566844970956, 0.08899967471558241, 0.03639718585257088, 0.04548206932902817, 0.020793675550169522, 0.030068558407947425, 0.058727932553137505, 0.06766767301146062, 0.03123920778894136, 0.027664572586335485, 0.06410857790239877, 0.06321602035313845, 0.02996866437306087, 0.0313034844810083, 0.004721021142622997, 0.06068049531970775, 0.12233755356001279, 0.020948212721475193, 0.021288989697613066, 0.012450148764577125, 0.054725988828126466, 0.047434831278458725, 0.006616770349923642, 0.03430731714733186, 0.023509351904654217, 0.05771336401061666, 0.04125809034092292, 0.03585111838014376, 0.07845501836028793, 0.049982004678778114, 0.07464897097839464, 0.0210986225940888, 0.06018687805701649, 0.029296269001919898, 0.008204289347744517, 0.03183412677308004, 0.009099419994820512, 0.1027608278297609, 0.02636848396861986, 0.0358132736366843, 0.022007266074539195, 0.02229662514441917, 0.0651825450721287, 0.07798880023220855, 0.018656192565216653, 0.01507778150675398, 0.012495389129335602, 0.047054809533179774, 0.035754418931901455, 0.10631647171272386, 0.021159256538075787, 0.019719823293628234, 0.02700692632295672, 0.03767893138912417, 0.021277222587096117, 0.05643541060928857, 0.03359379434597588, 0.04483303963957776, 0.0470938493738011, 0.02280416988557385, 0.06581626832485199, 0.03583350218832493, 0.027719932014963804, 0.054548095551229296, 0.011894001490286282, 0.017677718255248283, 0.04469290683646837, 0.06482590049985917, 0.0484920364444054, 0.03841597692019517, 0.06438346940182871, 0.05229768546057805, 0.04322869064767034, 0.055382212083185875, 0.10632407896581197, 0.05857041338458658, 0.06457483816531397, 0.037026630504237074, 0.0374712755963687, 0.024092371628109007, 0.008160527532679901, 0.02782066108568782, 0.07847172673791647, 0.09583416725358657, 0.06117290216347864, 0.0314602279855359, 0.024988522129734198, 0.0162154249471402, 0.045225985288139314, 0.05403358707084291, 0.040948632954349445, 0.01508203425234364, 0.03651260465924298, 0.059072978554233435, 0.04102008980548671, 0.1573842911109809, 0.022173878706751332, 0.05109380893108826, 0.0816064206282458, 0.02393119822015926, 0.03467694307947832, 0.10946330809665304, 0.05353744554844114, 0.06859072469054692, 0.025134718518764265, 0.015975603995273913, 0.04185350536699257, 0.02144800273761634, 0.04265581775877265, 0.046256840859930363, 0.08211949269377417, 0.009985191920291512, 0.025146476053182158, 0.041539849818594037, 0.03973548676097586, 0.011331104023772623, 0.00366117321274003, 0.033087145927692616, 0.040295994990775665, 0.025378183176320408, 0.022574854871979164, 0.036002727180358865, 0.019588669040991415, 0.04399930615158331, 0.042011150940051006, 0.04027546000396533, 0.019561754456991633, 0.1165746724713714, 0.05017877436212955, 0.013855835835960124, 0.052703030242194096, 0.024736448559128953, 0.020732405753205382, 0.04026290765332599, 0.05296136275114072, 0.029514494892810623, 0.019192557534082763, 0.03163210938744728, 0.05066520188965144, 0.014138115295809845, 0.03034584201692093, 0.05400603854908578, 0.03449616165110662, 0.04586021798933226, 0.051660024515923955, 0.08910996839404108, 0.08438601744391265, 0.06931989483775632, 0.055370019793870955, 0.035210289661922765, 0.05191881667762514, 0.06741451925688213, 0.09007142406077155, 0.14534085267974486, 0.021263839031058936, 0.02202954008093765, 0.08101303190473588, 0.009565388186714582, 0.1270812312741914, 0.09041513706887923, 0.04072406577066549, 0.058025112000083735, 0.03894117615756489, 0.05479574879451145, 0.02777499841496108, 0.06607369685004796, 0.1827974040662089, 0.08990951137797487, 0.05309214162069464, 0.10029986996444003, 0.16364627848229102, 0.02786914295997591, 0.02748130903308911, 0.08754779254236529, 0.03694721399956653, 0.006515700370073319, 0.02143600771594192, 0.053123317568773226, 0.06193368875932309, 0.05501142935827375, 0.02458424987121215, 0.10419206393341865, 0.019642886998612556, 0.00837138940339848, 0.015731933451588118, 0.045611185787786404, 0.09480963956805007, 0.04785493091349641, 0.025065649946730946, 0.0453315407127863, 0.03909283475349507, 0.07140876379825416, 0.039009867431295496, 0.05858553212977225, 0.05299965565603587, 0.03792235582706429, 0.024212352488370194, 0.04758898732102206, 0.05191779011980661, 0.031164366744398594, 0.027702712273645787, 0.049889530205438216, 0.09057648284661193, 0.034464966550829916, 0.03247273575154043, 0.06445878350566472, 0.02732007242288561, 0.0420799111616948, 0.023559105484896613, 0.03774258180431301, 0.050881399562762636, 0.03214607586062724, 0.02802095477349095, 0.09162642166859682, 0.06414888178809516, 0.04087957012797556, 0.028894785303442232, 0.004148707976714979, 0.008177146852587261, 0.05663733223393079, 0.10580990373367265, 0.06525055069716708, 0.01818448924759944, 0.017804875444140167, 0.01932106303772138, 0.052229614718066114, 0.03977952915574274, 0.06803085231372426, 0.05497212904775816, 0.028669777619201812, 0.04246431109946101, 0.024309176425900192, 0.04585012478092986, 0.014668399441776978, 0.034136207579004194, 0.04570564442885019, 0.024209134919088215, 0.047940751913213925, 0.02620140593799372, 0.05923658429134277, 0.02465785942941664, 0.015334245718775258, 0.07407127173557397, 0.07887487284718983, 0.04338579229830254, 0.010437953713980895, 0.01866921031426999, 0.08932363797700213, 0.013558773752001506, 0.12584616730530418, 0.182320284506967, 0.16126766740795107, 0.31297949112711415, 0.12496585567151347, 0.10426209203057712, 0.09820052858201728, 0.125911284778868, 0.07676951767456147, 0.20864472033516054, 0.1992784987293905, 0.16871649351331497, 0.253796058015958, 0.13051207177340984, 0.2482782790978109, 0.15002112895731004, 0.12805825384754327, 0.19378482093734128, 0.10978264418701011, 0.15423570038570514, 0.1881983698976617, 0.1293054832926681, 0.23805932502352425, 0.11520953443382057, 0.21913508403926127, 0.20112256429368452, 0.21774820442641937, 0.0793351308112183, 0.19577370776284128, 0.16932594710059706, 0.12523453802831713, 0.13068240376249438, 0.2572826314116678, 0.1754681029987912, 0.11396910784946335, 0.1128817149888604, 0.21430260141290006, 0.3241332103648494, 0.0861443271259627, 0.11310278498117002, 0.15655596620373188, 0.10349641779377576, 0.10564900994781526, 0.11993786740687587, 0.08113988840411748, 0.1404885743414202, 0.1884122616461208, 0.12791811338355466, 0.1489922115879674, 0.12375968087825084, 0.19532507135262414, 0.22860092771870477, 0.10912353278047617, 0.09056784903570529, 0.1895645038495141, 0.1838474348187447, 0.18543262395166582, 0.10937026671824918, 0.07848900968148824, 0.20902834652412325, 0.13682967712802274, 0.28795697576095985, 0.13772416138841262, 0.17420960440030023, 0.1807468778063213, 0.167860941841237, 0.19195180236091539, 0.14735593971225525, 0.1339797994061824, 0.14121965204756107, 0.2796876082016576, 0.1786419133385343, 0.25163569006948705, 0.18636040239324494, 0.20807066000998023, 0.18134073384346502, 0.20614378034107148, 0.09904807463528649, 0.2936139834984657, 0.18686232787947502, 0.24733640463842502, 0.29315433074389735, 0.13985457529704418, 0.2128649454924368, 0.1632778208342291, 0.17902733217323982, 0.14470659316547457, 0.14497480054776515, 0.27502964040444744, 0.15976887767113027, 0.3593945214825292, 0.17253501280661554, 0.3162363147543323, 0.4125892767502416, 0.3187424947898234, 0.14322678708741743, 0.3389602292689585, 0.3691321731575074, 0.14132102080170186, 0.17176544684315884, 0.23318988631569573, 0.15922696239525275, 0.11655696817944128, 0.2018606287216948, 0.10780252140736389, 0.16917600837205687, 0.2179405537824477, 0.12851863438563962, 0.1484836211367961, 0.16784955777468222, 0.22760345059777462, 0.19277439693049078, 0.10632872911951236, 0.14471855945885181, 0.13006299103219665, 0.11868153683721058, 0.17998883380524575, 0.1442253060879246, 0.20031198198276184, 0.11971587810905711, 0.1054893572243952, 0.10573368564608598, 0.24216408540885298, 0.11464256808281907, 0.2036414767104772, 0.1247052938467072, 0.14909983161957036, 0.1508494078992836, 0.22729025853257026, 0.15321747760378546, 0.14330284429654, 0.12378033460868944, 0.14481977499540777, 0.1407460411710124, 0.09754202238494351, 0.16059041503937016, 0.12305216037578161, 0.2330932366631685, 0.1410652240437846, 0.1062194926423892, 0.25052415777839, 0.16414766770697412, 0.08803098717884672, 0.09320503776712764, 0.07227620515491694, 0.08753502185666755, 0.19817199197507676, 0.15534073625120426, 0.14173147538977285, 0.0886430684477091, 0.09251480020823018, 0.1193775277164194, 0.2157737660191713, 0.15333835095647844, 0.17167984417849974, 0.2668087508889937, 0.14469626630025526, 0.1134950373201601, 0.06666093388752592, 0.190859820633646, 0.13285181154647183, 0.1647827852397196, 0.11408562216186717, 0.14527078627819015, 0.09394500209319015, 0.19251967269566753, 0.15136406576681524, 0.14830227280336042, 0.09120282101174516, 0.1699367183591089, 0.2077805578348137, 0.16532212646017153, 0.11547118410347931, 0.11335278245350046, 0.17046407796442511, 0.12312158326347991], [0.019289176543093017, 0.04131135260385852, 0.026367576154429587, 0.03415485415908118, 0.04305458567555874, 0.038683774445446274, 0.026915432442159905, 0.04631304107005558, 0.03798967197297081, 0.031129990464016318, 0.020972666248018225, 0.022239057467349117, 0.05682149977092782, 0.021458387059429963, 0.040287874458778294, 0.06220192295469104, 0.0417612147547545, 0.06390564504169649, 0.008003507278889658, 0.02086642900511863, 0.07389665731499273, 0.04471004422333452, 0.025985941794070027, 0.044341938975717754, 0.11941465233723003, 0.010631061497054273, 0.03421167106998544, 0.07306427980262427, 0.06573078057338154, 0.027411317325107036, 0.1132384438308016, 0.050200849185667695, 0.023858502221804474, 0.1026432792986593, 0.019659484293492093, 0.020564756987075654, 0.020250515381415046, 0.03200261632070667, 0.017457661414218527, 0.06876551531135075, 0.02722467149367496, 0.007617821749825512, 0.06426336213706002, 0.019545151416452664, 0.00873980108618496, 0.04836874608431132, 0.030059001461092024, 0.010121867751642581, 0.037757754175653385, 0.029020358605550665, 0.05631660569399115, 0.08217174755108934, 0.0381153984926641, 0.05098075350566257, 0.11844961137901391, 0.0462987803433451, 0.033473173802297924, 0.026136581493060917, 0.027042432583027312, 0.06884865117289367, 0.00753319058041539, 0.08662945230401332, 0.015721760761563577, 0.069822785594771, 0.06314824455447736, 0.030472920681800575, 0.09124701662409691, 0.04975174546181675, 0.09382599799503243, 0.041429801288271145, 0.0581657963864986, 0.056418843957926, 0.13052048341881844, 0.08334249077785401, 0.08099051658064127, 0.05881933450338341, 0.013604628902319218, 0.1158913909908264, 0.20833652316322251, 0.20833296851525385, 0.4109749456326808, 0.18549925827931973, 0.20258108844920514, 0.1336977411542208, 0.06497225393691371, 0.2146171724363681, 0.37567327700314984, 0.11631001207617023, 0.1426527114404786, 0.22813313911038063, 0.24561814603305634, 0.06803636814677907, 0.5980303583125914, 0.4114930049305962, 0.41438247407636336, 0.1695792004466057, 0.4197215246817758, 0.191128671529793, 0.10521924228317316, 0.006269188118993395, 0.06931339075127918, 0.10790612713824357, 0.06643774183166605, 0.08571551707122596, 0.03803779378593449, 0.06005762370243188, 0.02675082504508957, 0.09661759940847274, 0.12244945602311243, 0.01754191001847146, 0.012344812632598465, 0.052710154859889904, 0.05163324974297036, 0.06424143287022749, 0.04987178377867226, 0.0537630852552191, 0.064380228849909, 0.0018279677826813574, 0.02522186485059079, 0.03715318439888858, 0.047192475533172976, 0.06229961448679529, 0.08546088476695361, 0.019096174097109227, 0.026611211266548886, 0.0177760130815929, 0.06857164910123234, 0.036005776210297505, 0.04070092225447297, 0.06105939857661725, 0.009958194024229964, 0.030484477118138346, 0.031835810251293645, 0.09192819136285013, 0.06389619151671087, 0.07388505874381912, 0.03867431325958141, 0.03134163374441766, 0.010228485165674601, 0.05033448556317918, 0.01912977471346817, 0.0142611509316691, 0.032032034096999035, 0.04198688893548904, 0.016070649651209676, 0.0328176821612062, 0.016637610256551735, 0.006022295696781047, 0.02644461204087542, 0.026853953886236397, 0.05791254304048996, 0.06663660293505078, 0.037938773091281616, 0.04235643442840346, 0.05839623563412217, 0.01947475368187072, 0.016092368243863026, 0.01968447791202174, 0.04863306940082581, 0.04223624289396309, 0.0454217437354307, 0.04437316471951143, 0.05415109346710867, 0.030701444709613442, 0.015244425740092995, 0.023630374644492424, 0.06882906230466981, 0.08548375249149338, 0.031898374736849824, 0.03049732632784834, 0.03159024459760516, 0.057681847153411764, 0.07821963784555275, 0.04092207651645426, 0.03608809235776144, 0.05426269332547823, 0.014463932490006331, 0.02881182181168228, 0.055230553487255696, 0.05852981455503933, 0.026558805106868668, 0.03224825666796777, 0.022576540265412583, 0.07017676418106403, 0.05916394766480212, 0.028360961831264922, 0.030008928039141243, 0.034867246980748834, 0.046155583188538594, 0.09522083726140762, 0.08808176348646803, 0.028727557885670857, 0.0237117848929859, 0.02008861418993723, 0.03699565756945841, 0.010704981320868097, 0.044633106013099035, 0.05485975544058508, 0.06130792516013307, 0.03261475696138317, 0.027506478851841345, 0.007407470285186485, 0.04441217008617617, 0.016283995562022733, 0.03323481703597692, 0.053537970318669276, 0.016761670535009716, 0.01882752046860274, 0.03377618455898858, 0.08948301490876945, 0.047236096579581506, 0.02124568849291292, 0.035880942183036, 0.05971676820228177, 0.027366533740273407, 0.02659442436490809, 0.017305514437236616, 0.011641450072338265, 0.06780007598741401, 0.055624257562862295, 0.05464793595996115, 0.045179778694986336, 0.01792501143720602, 0.033851299479964285, 0.08013630556243082, 0.0362420377261456, 0.06219888541607126, 0.022457522760716178, 0.04737508791168371, 0.00407094095510641, 0.05717603377096596, 0.07526960178849197, 0.018112505711014235, 0.06036886607386893, 0.03611315492420428, 0.06430254753438697, 0.035971689128106644, 0.04882348438484534, 0.06306797769221087, 0.0629774414213194, 0.06187028349227002, 0.02807984778267001, 0.11884270641472071, 0.06941348779946566, 0.051636022981256254, 0.057032465063516176, 0.03635877803448708, 0.12180593450583758, 0.13139770005739507, 0.09288696572184564, 0.004934055830216817, 0.05436318873938534, 0.03497236190483936, 0.12750275583276827, 0.26803758656305654, 0.15000231383788973, 0.21089634467517177, 0.029105191351845864, 0.05784839466815034, 0.09430814309105759, 0.05372386921437518, 0.04155508730740797, 0.04865516337656206, 0.04325559565557107, 0.1509852659317755, 0.14665332983338064, 0.10408715585306769, 0.09147527252113627, 0.19692935139661838, 0.16341018550578626, 0.21345063503230774, 0.13629321639816608, 0.3626107118062435, 0.20169383605882046, 0.2587872893819886, 0.0399952020586258, 0.0663462249682315, 0.11561297165650515, 0.02005605162271569, 0.05365474127052773, 0.04802469599751696, 0.03446223161694023, 0.08853632941721909, 0.032784548858481075, 0.1283043442714599, 0.015172146302047036, 0.02911963402443836, 0.0813627663639284, 0.09363682024301061, 0.13243548872490085, 0.0369048263547161, 0.0664316131282718, 0.02885009747959914, 0.04730014536049097, 0.02881456249123139, 0.07089431277446209, 0.03561525523001629, 0.02196041022187039, 0.16763453221609517, 0.04201032356509278, 0.07341480333237879, 0.03993095409485602, 0.0035524473810989053, 0.0969499436717841, 0.018989636164699352, 0.0588343843006559, 0.04895140957688132, 0.02850135127382894, 0.09768918787519779, 0.01736291740540295, 0.06457705982029438, 0.05382519583368013, 0.01717354813140006, 0.02940373198549834, 0.06807217509635995, 0.060746597216254285, 0.0799841221962725, 0.03287741786710197, 0.06551139597450534, 0.01558841741268313, 0.015887902249702286, 0.08275740644744328, 0.061093121767044074, 0.038975113852610516, 0.06358141747994289, 0.05994391710227055, 0.013442855072958816, 0.018028180497968872, 0.057745076220242254, 0.05618948872471529, 0.012639646358307333, 0.019287663519442565, 0.033709818362108165, 0.080568379151725, 0.024444475214207367, 0.037714133129244855, 0.06515010124853542, 0.05232067958962533, 0.021667036851267182, 0.024354408172169523, 0.07563081990566946, 0.0101475891537003, 0.022426511521541306, 0.047783880088959015, 0.034172765294750856, 0.03751152202547078, 0.019753676719002185, 0.06647593897557066, 0.059080926716447844, 0.015348278534328266, 0.06401107023139635, 0.04677847395801256, 0.1776893136482085, 0.18190897190042082, 0.1515505315675851, 0.19034966736310915, 0.16630412860503122, 0.11726230533132631, 0.09068643178550467, 0.23142275130075796, 0.1961138661229803, 0.1068325085385192, 0.13180722001819842, 0.18418138786669702, 0.18086608108733931, 0.21046918937035147, 0.14327201691846694, 0.1522861445142377, 0.09803735185414554, 0.24908385119370877, 0.11953975449526504, 0.1944827270363608, 0.12848868034780025, 0.14429183316326913, 0.20736458741368788, 0.18714242494635044, 0.1509810064829165, 0.11784801019295571, 0.09866909093914494, 0.1581854965057104, 0.191267057652435, 0.09229277260601522, 0.2350263216442639, 0.1434537023305893, 0.08290824149885485, 0.27116573806251254, 0.11646536704633506, 0.07826728851444299, 0.12106145026102183, 0.14833950467648047, 0.061487044177709095, 0.10345382330518577, 0.08347017465219383, 0.15308086880512778, 0.1395058673956702, 0.1398677673311003, 0.14241888608422973, 0.15295861649417108, 0.0894743810978628, 0.15875218706505914, 0.2463507252715288, 0.09323108475655319, 0.11165507032626099, 0.14343024471834784, 0.19678221654988107, 0.28576430954760124, 0.24686565893071316, 0.18213423239367624, 0.11835592648675365, 0.1598540972918272, 0.11933208338075108, 0.1780804015335537, 0.11047859676182271, 0.14548424901741167, 0.20617790189721893, 0.17509425209174234, 0.20275227845676486, 0.14883847306332282, 0.19153837535169818, 0.1609587654351227, 0.17216480847808624, 0.13512120912632636, 0.11137998347441036, 0.1713802731565891, 0.349676052649175, 0.18791015229878888, 0.16018369896036966, 0.20250732950385542, 0.130547066669791, 0.23965504020452502, 0.47828321615534447, 0.387892839048178, 0.6130713608957107, 0.3078713087785629, 0.3712837464146076, 0.34119840110501937, 0.15622870876423775, 0.2685622342171208, 0.4734564025796229, 0.2701610903586111, 0.22015966535095247, 0.38578033627521613, 0.1967341521935117, 0.29865113417467765, 0.6261384306896118, 0.5542324375241034, 0.5369293918052028, 0.3413260313532045, 0.7065137403626597, 0.5067488983754189, 0.2926411131216634, 0.15340103227044308, 0.24961655809273645, 0.19152670017173215, 0.2111613344881804, 0.2367789469539158, 0.12486692307697189, 0.12943596338793156, 0.24282082194282165, 0.22697225543520144, 0.2640978415166178, 0.1324056112958539, 0.25306914782812523, 0.2605709565743323, 0.19227093926841216, 0.22597419608744884, 0.20905837717075504, 0.10479679841908718, 0.16999849568932288, 0.17920276630790005, 0.0774356924117573, 0.1243591446790003, 0.11174360710767009, 0.14226620476092064, 0.3057978764897393, 0.1728825868978616, 0.13455459517577004, 0.09871828910564223, 0.10018604462065044, 0.27496341976427263, 0.08484143373225966, 0.1502782893517325, 0.18652158729251356, 0.16819714718768675, 0.1863419243525113, 0.18539105602089437, 0.15877858645492987, 0.16173799942818382, 0.13374582083234865, 0.16560890381374668, 0.21495579862065856, 0.14325346226894087, 0.15510842774904546, 0.15498073621382638, 0.19456880467553295, 0.1353416892309343, 0.08810566542970558, 0.18348190362655348, 0.1368461020531193, 0.11200118118957167, 0.24695167528285136, 0.13041176022060458, 0.15747942390941805, 0.13660273124133387, 0.15978950075805187, 0.253983443122237, 0.10145382054390446, 0.150480613172535, 0.16545465967107206, 0.15864732494998365, 0.18846374275463243, 0.12275125636088273, 0.15010268667772894, 0.21760929736398885, 0.11014806046601265, 0.1010687847531611, 0.22925731185222828, 0.08542004461971023, 0.18106086660296689, 0.22839864986317776, 0.11385032591680366, 0.12451532702412337, 0.10264730892114102, 0.12599063616606498, 0.17780574369094065, 0.1736525665487974, 0.2049760938051247, 0.15962459267147128], [0.01716928868254106, 0.01696287586744274, 0.11062859677739682, 0.04128017282534031, 0.034674246449984854, 0.035473410220396136, 0.0024704724379379546, 0.04051467861920115, 0.04896001274427099, 0.03720714380183528, 0.013736278239277103, 0.015310495077902752, 0.04206125309029895, 0.04626146803099302, 0.0421316527401007, 0.0336291263210437, 0.03439626761622006, 0.031997613766561114, 0.110672868998541, 0.01574157562572509, 0.16605881192991812, 0.033332872459845196, 0.0635948967969706, 0.04257530957881001, 0.029139937269651604, 0.0082469173526812, 0.008872669460552355, 0.03842143912709529, 0.03204598647331999, 0.07155776023864746, 0.04189955874256069, 0.06139748466892108, 0.05674973265418122, 0.06009045440042692, 0.08475905629776179, 0.03995116349429854, 0.04288244954941254, 0.07319693558759267, 0.014840207107725644, 0.026544789528293956, 0.020548238216208357, 0.14974878470022834, 0.06574964931895656, 0.016816214079998674, 0.07806216081183764, 0.022913324008245143, 0.03458792366267693, 0.038785334721568136, 0.01429474580236861, 0.06175283072215896, 0.03350501241643102, 0.023374495532123313, 0.09009774684184983, 0.07971839693885657, 0.0024146389924064884, 0.05432091217728392, 0.04749411116203955, 0.028222075836252303, 0.04811957215649947, 0.03237715479166758, 0.05021064361977962, 0.09062629388344866, 0.05704600566757783, 0.036223613311566656, 0.008554444197685489, 0.031016988664745327, 0.06120774767271454, 0.07318771954986357, 0.04569328743063154, 0.07652872857908088, 0.09071920502690539, 0.08620931436457942, 0.3734056873907966, 0.053468616378884164, 0.16579962906337556, 0.3098964775281568, 0.4332776956500546, 5.576957310399702, 9.51022284646188, 8.84961530085533, 16.409097352335532, 21.298581823225945, 27.076452739777107, 34.30960339884604, 39.143967782297445, 34.855750299269154, 22.58122628734958, 24.761975849828413, 37.52367981018559, 41.57722973054455, 40.98991755516299, 34.692261988116854, 24.862572877637803, 26.76099611866859, 15.809542479053622, 8.611823570343757, 15.497800342498289, 3.7485782850173215, 0.9135278578727477, 0.32676199511174236, 0.1641985665886633, 0.14056011163178952, 0.08803942180689305, 0.032411609596062096, 0.07317589115231268, 0.029563551333041924, 0.05178161799126575, 0.03112442675046623, 0.11043135211953234, 0.13614770565782824, 0.06545859719476392, 0.03033843394669314, 0.05801516434838695, 0.02369458047342637, 0.0520004548372761, 0.025203032494192163, 0.04012050339952111, 0.010592850946610975, 0.10876756236558, 0.03545289821622353, 0.04216853604321519, 0.07694643035891556, 0.03573727005371644, 0.022963213569094098, 0.04352972872795598, 0.060043152301542224, 0.03905451886596219, 0.029070889765036204, 0.03842001037311651, 0.03233097118115233, 0.0678359595457873, 0.048346043068675265, 0.0850691457068728, 0.02915947825738019, 0.017726790017238068, 0.015545667791288468, 0.00757177172589206, 0.018746757564405282, 0.02683910518704403, 0.019533334510220636, 0.050688510114747676, 0.03712468209766573, 0.017144724073249008, 0.06082006504819278, 0.036142902118304086, 0.035357761587346756, 0.019048171027773814, 0.03320142326335753, 0.026782746013674526, 0.06263382417420227, 0.057421013367392366, 0.04620590367384496, 0.06412836595348294, 0.023927679961367, 0.03330175779880055, 0.046760271708931656, 0.0319904699966672, 0.06195377941513735, 0.05922753679295702, 0.06213243494951918, 0.025718490923604658, 0.09023208035937241, 0.014388917160460786, 0.04442664914794507, 0.06519261146745374, 0.0460489169364014, 0.0582682223419749, 0.033729763461216804, 0.02293776987390893, 0.029874793704478975, 0.11621071942030423, 0.06189852915403824, 0.05993549396554309, 0.005036712569680306, 0.026579288382744117, 0.02662580907194605, 0.026913875368453806, 0.0220006987858083, 0.08926874777722744, 0.07507594242211311, 0.01448773196898401, 0.04781318678250236, 0.037826361179712324, 0.058368660299287695, 0.02247571351847822, 0.09467746641847397, 0.03214467391972581, 0.019117542204537222, 0.09419470845210938, 0.026656027410119295, 0.016885315210768775, 0.034964294998996684, 0.05163691930412766, 0.05251160785255413, 0.03938796629588451, 0.03165051464982812, 0.06360936819786026, 0.03538910990520831, 0.020170156588597644, 0.08053611918923356, 0.06938427686691284, 0.008407812096148489, 0.053306527495864904, 0.023591813608823765, 0.036151750433829524, 0.0723025049533575, 0.043497767539755, 0.03513188439331228, 0.02857217610242867, 0.11582095686706806, 0.021006831854221322, 0.03726915478886616, 0.06229682209631128, 0.04335223764721905, 0.04295714695246951, 0.036848526553160725, 0.038189088490100644, 0.03613593837907238, 0.05180025308002388, 0.03423456177716294, 0.012647975649264072, 0.04287258616738743, 0.0340012994955384, 0.04838348178553486, 0.10023296750601261, 0.08233041202108707, 0.048394927139123606, 0.020385245349438443, 0.04646649997260782, 0.0895783622118254, 0.0832037139503706, 0.03428213583726076, 0.005333860838530405, 0.06405572166606303, 0.05023284484782527, 0.05269814643167681, 0.0052902397921218754, 0.0682569555036964, 0.036088716719419725, 0.054602828702979514, 0.04288297815008029, 0.04664085009285519, 0.052391604009655215, 0.050549626034954866, 0.023973440308304086, 0.059711179590874144, 0.15384223762779467, 0.22534548304975036, 0.12550212487938905, 0.06171898878810387, 0.08661236088242262, 0.8576008653448475, 2.031690793172006, 13.726530536528557, 19.140909525655932, 18.387420254368937, 30.170384991553526, 38.77440206466183, 48.72745952298565, 57.16612908147997, 65.32140347265428, 57.62258314317273, 41.75697626606111, 43.86987863048431, 62.69214460926672, 69.32171114029424, 66.45197960638231, 60.17420261136947, 48.2825372295995, 51.38993301699239, 36.40150147099649, 22.189071639891594, 32.71627387692852, 12.643555306619215, 4.805797271190151, 0.6044262118877903, 0.03840091563160381, 0.22993107085987446, 0.18677974360123759, 0.04305172050672193, 0.07853087638655017, 0.04278473503467056, 0.043114589512228005, 0.04185665015792174, 0.09122048699927908, 0.05273586860106838, 0.02858313307496569, 0.06388358170947721, 0.07106459879827115, 0.08504895162918875, 0.021911367188177763, 0.03298465102430313, 0.015304165276428385, 0.02753725643419931, 0.0650758060416387, 0.04850711688519486, 0.02820092223344311, 0.09169678684444198, 0.037095934648307106, 0.058554425129606846, 0.038058003185377005, 0.016945813174149203, 0.010366551446608238, 0.02484872832053131, 0.03595971517385014, 0.060505926864401954, 0.034440390450218995, 0.05463686981989492, 0.00594431417055368, 0.011721932396833456, 0.04276398937368105, 0.05545441203960969, 0.032904024100712234, 0.016994471248659878, 0.06079540084747057, 0.04333154944282386, 0.06506767784876209, 0.04978691272798085, 0.04050227565570705, 0.033368039726009296, 0.034560899911147934, 0.025118412337295955, 0.04021377843474189, 0.011182576812232935, 0.043736989985430436, 0.04702410855961423, 0.030357218422596494, 0.03369757244663854, 0.04525405858012457, 0.025375348651000572, 0.024587618742859172, 0.059006168026356935, 0.07552051090545232, 0.07228240280622436, 0.019510878557940165, 0.014156773367205696, 0.021681709350236965, 0.028660766509992462, 0.013249734840956668, 0.015607645261972664, 0.03347984642811841, 0.01614935752455025, 0.038482569113013246, 0.032400394068850626, 0.10024617486182721, 0.05508998784446909, 0.041791701223701246, 0.08458132389932872, 0.05932813179829429, 0.06474934533358583, 0.019955113793032307, 0.02990551191502281, 0.18406331839580692, 0.17570018167457274, 0.22479713263530887, 0.1334900393961899, 0.13069116780834814, 0.13210846111178398, 0.17272092702407993, 0.099830097188392, 0.13324070842035357, 0.20376431124825634, 0.15247493922229738, 0.0904430686345985, 0.17044995130310137, 0.10577717645754738, 0.14496540830981347, 0.0823963875131261, 0.256313024569423, 0.0970122802461828, 0.2068948069767606, 0.19035515255264698, 0.19417377909825695, 0.10650821585929203, 0.14698849330025335, 0.20388446447830047, 0.1717247062873456, 0.13382809867541637, 0.1562436628005197, 0.14692608777794147, 0.13041156103774426, 0.14586704783141613, 0.15199496981597718, 0.11420383718946289, 0.08699812445669405, 0.22983671947112008, 0.17130410869515714, 0.1534925491338776, 0.11628238694562067, 0.18876771112122845, 0.11958338320255281, 0.11484708291508498, 0.06080020421875581, 0.1959085698810316, 0.17334504353423275, 0.09480882751485033, 0.13963251705131224, 0.17504319999246828, 0.10939091278780853, 0.19746809506848936, 0.17053587572468867, 0.2694308553491869, 0.18348133672148953, 0.16205767259722756, 0.17810131573388654, 0.17575402233389117, 0.12569147117075422, 0.14158613318877836, 0.1082602819247592, 0.10252021493450289, 0.22296271977886079, 0.14840449957597643, 0.1158292152948918, 0.10594763102069979, 0.11348722322333245, 0.18254911496994958, 0.1119784590217375, 0.2030570435548021, 0.17593918578518977, 0.11598813257390454, 0.15884761097690753, 0.3136637608610815, 0.2748834095414608, 0.3490465428800352, 0.4741904680286685, 0.15174072055566698, 0.24280822745734648, 0.6981375188596788, 1.6274898114704317, 12.0103867015531, 17.65093445777893, 16.220192082466617, 27.418485379988148, 36.58122839466218, 47.08406094581851, 56.77942260619133, 65.053321238487, 57.499922783144065, 41.25444219958398, 45.67495730615432, 66.80689134905415, 72.42909908294678, 68.85068155104115, 59.697544420919115, 47.81173121544623, 49.69113488351145, 35.71031708871165, 20.09542811301447, 28.130954504013065, 11.386677872750068, 4.453615988454511, 0.5116524126741194, 0.26604511444607093, 0.44339787034738454, 0.28417118374378453, 0.12495942053294952, 0.1441398106755749, 0.12929497256634698, 0.15534263614925647, 0.14083544363177594, 0.20671491421038107, 0.23082981456912335, 0.15512315195895013, 0.26777383781248526, 0.1501910779024324, 0.18024437009326874, 0.13762593359476136, 0.10255222208797933, 0.21167199337674727, 0.10795656636717821, 0.14738138915309984, 0.10386912722981746, 0.1509935856466332, 0.20748553737517328, 0.1206780692201949, 0.09963700472707711, 0.1392031707350285, 0.09621140426926075, 0.15499864734949606, 0.07794378490577783, 0.14614798759500827, 0.14442203746687982, 0.20362499049834668, 0.15429698741964756, 0.2329107391978464, 0.15764692137318273, 0.10560054722572527, 0.09439938416283938, 0.13303020278051977, 0.13505593843517766, 0.17767521763040175, 0.12558237258945742, 0.22510929814269467, 0.17767512569985083, 0.09846457610687903, 0.20987565509013592, 0.15744619101526278, 0.1676949612315624, 0.1789864383998417, 0.19725965786605112, 0.07638422907480309, 0.1383589418424714, 0.10531468917765927, 0.08330279976249703, 0.1598653894278311, 0.07387210419701953, 0.15143155811294434, 0.15023301355540752, 0.18412596906625456, 0.19872437201199994, 0.12570185932300745, 0.18939982558931076, 0.237551715164896, 0.10584628524919672, 0.04948548394285383, 0.07710150187654842, 0.11593473624558219, 0.15448909162754013, 0.2920331457449544, 0.19574963728026037, 0.2491919002345493, 0.135229671854646, 0.18402377293715555, 0.14807954040025512, 0.23773715440784735, 0.13523845122225825, 0.12059339352192418, 0.09466975191307646], [0.027123402330964327, 0.07609123874816202, 0.033011713080228336, 0.014451711472394246, 0.03172848516354158, 0.06058382651498241, 0.03791504734826665, 0.0026548446640522493, 0.048061947022835096, 0.03280379681757862, 0.040136610398129116, 0.023780548945069317, 0.01252526081272311, 0.028738997493600173, 0.0034653872341638614, 0.04638308448897255, 0.02070558501497632, 0.020445377505835027, 0.05581110257715468, 0.02902321419828842, 0.07423660117051295, 0.005912053250452323, 0.08530037402505837, 0.06094170448881003, 0.05584936100809325, 0.04690490910903581, 0.020446902020804344, 0.01801208690589955, 0.02843689072066017, 0.036651982865746946, 0.01653445460232756, 0.020395275355587085, 0.0772423318196689, 0.0792763565456675, 0.07927128504360877, 0.025675243345059218, 0.031115099629988114, 0.01576363225467503, 0.029529050563371954, 0.012586910780819674, 0.06950155726724094, 0.007128939868116211, 0.018608888551112146, 0.021362091722567717, 0.02956288675176761, 0.015811419861781743, 0.02291624280323665, 0.06388272752144164, 0.05705472374815614, 0.09115543081274918, 0.024115532381279815, 0.03780975239351392, 0.054679969926514936, 0.08046834339057246, 0.05307821031179159, 0.04529042860432979, 0.06969860274224512, 0.1031468901783228, 0.03305735659875697, 0.09407791068717357, 0.05742796944574483, 0.03057136489529043, 0.1128601496137919, 0.06358045603959792, 0.03399379566432007, 0.11011665086111716, 0.11690563777641905, 0.1369788650903971, 0.3489380954734741, 1.6196204337381548, 3.21289332643632, 10.888863398182778, 21.275737939342378, 17.085822897572672, 30.979440519886634, 49.84763745338687, 71.24132694736605, 108.24772065685643, 114.2311159256966, 109.6038487649733, 120.0990209271831, 124.2236912635065, 127.88030516716742, 123.76050641459804, 129.8535946876772, 123.69171588651596, 125.43506037804389, 127.04589936041064, 125.55791685658117, 123.60397246576126, 126.79419302171277, 135.79571877756428, 130.5604293269496, 125.1778313421434, 114.57028327449676, 110.22490901331749, 116.61360279206308, 94.67498625478437, 67.10515622169741, 42.77039512511223, 26.041705992914018, 13.154538158447513, 3.131816218937597, 0.4652295069348428, 0.14073876333573174, 0.15848059357414324, 0.16813962930633178, 0.02866695650042065, 0.07571231633905443, 0.12666129251761785, 0.03425160340303856, 0.026612101843760862, 0.05184107407506916, 0.08638733021554448, 0.09460530859688598, 0.04649874078290117, 0.03155425187170265, 0.03348793248615919, 0.0554515507012125, 0.07043585511705569, 0.033987272425644824, 0.06093904999415241, 0.04545387729341465, 0.05781551417444022, 0.03347111302578161, 0.015213322570367206, 0.023523926727413654, 0.03621926193215674, 0.05016841685339328, 0.023619693463608146, 0.03549212574838631, 0.014926908150946182, 0.012914742786257018, 0.015530457115551878, 0.04818284718860542, 0.042129457898197636, 0.041786955309010325, 0.059978873694255475, 0.011893325417693104, 0.09455709102293176, 0.04579056144481705, 0.0260587967556691, 0.020918398494682005, 0.01893281733857528, 0.09108132712783353, 0.04064717735614508, 0.03412836666909918, 0.06689324238968473, 0.029574605981789293, 0.06772776494824118, 0.04623734775269705, 0.0440152331195291, 0.03069611465288026, 0.030522218439728025, 0.03018428556500904, 0.02656145385586687, 0.038180060143912994, 0.04573497027459164, 0.05929907791376595, 0.02324054505856287, 0.05073614929231906, 0.004645008941165983, 0.018578833006622813, 0.023139930901027495, 0.05749348145458968, 0.032509350923881415, 0.06987354658063381, 0.03276506724256662, 0.03994190915217323, 0.0301043845097264, 0.042253594785448045, 0.034207434603764166, 0.0464065037968178, 0.037889490655112656, 0.023448311934067358, 0.06476612265912757, 0.07355388659503191, 0.023494171872434598, 0.03766496943670415, 0.04355210232578459, 0.03287621127862123, 0.08732725881160268, 0.06701374802017404, 0.020882011233498494, 0.04101755405445734, 0.1211923287220059, 0.03584954023901974, 0.021439602583526604, 0.015235620517013295, 0.01310567104918582, 0.048291348221321265, 0.08471527437288916, 0.03174489668209947, 0.09410042601126818, 0.02807052832307114, 0.02363269014524356, 0.052743207723382986, 0.022197435910422957, 0.024456079531040405, 0.0935284341234834, 0.03256404960167504, 0.06687763717866714, 0.007854147904342221, 0.045474868102539936, 0.04545639772268553, 0.011299864873440276, 0.0184330215767747, 0.047195566697947444, 0.007369422528427095, 0.0463511118094527, 0.02742127646812268, 0.043930630199611194, 0.052081514600544214, 0.021367823975461147, 0.12049308962999813, 0.01798343521753146, 0.03130132028262221, 0.035462497297914765, 0.03794943320474798, 0.07559466055564343, 0.043273020325408834, 0.01879258685925555, 0.06517212627635849, 0.04231793851020836, 0.030847727283534986, 0.0759493439428268, 0.01424436690285802, 0.058911468067597, 0.024979357802939993, 0.04016553787814994, 0.04462262593029488, 0.03319180502946819, 0.02986115350898716, 0.09104621731826375, 0.0331705077851732, 0.06880204238358044, 0.034638546752713384, 0.059216934136084975, 0.1389367713202392, 0.05468333688294215, 0.04435500460526636, 0.10339844280913954, 0.12317945354528005, 0.11549911566919858, 0.7669183635903943, 4.723133810104863, 8.970077172402414, 22.751355171203617, 37.4954975804975, 31.26907225578062, 49.541476849586736, 78.99722560759514, 100.68084885997158, 133.59470428959017, 137.7039989348381, 135.1438836128481, 144.3390803183279, 144.4043642474759, 143.6156697427073, 139.19385633160994, 147.39565787776826, 140.19837533274006, 144.5639890240085, 148.7527822679089, 143.1915517007151, 144.07984302889918, 145.7431790136522, 151.3147960170623, 151.80766536343484, 146.4965408079086, 138.9894223982288, 137.1518861093829, 142.60997403052548, 128.96819022393996, 104.27633654686713, 74.53659642127253, 50.63790482859458, 28.983622866292155, 10.297478821969802, 1.5606218576431277, 0.368978220128244, 0.06633561465048021, 0.06888458835742167, 0.022658182255503152, 0.045920880661616405, 0.052688505215149735, 0.04325699759647251, 0.07202448398475686, 0.0012730354759579285, 0.021241415637515245, 0.02546286078981094, 0.06936491782506628, 0.005843221686870581, 0.023973402003907872, 0.019857234569386612, 0.0969639400981607, 0.023539658342938752, 0.03185692938014625, 0.132063215958976, 0.08630406411905443, 0.02311142668458483, 0.024101794509577657, 0.029005745478395014, 0.01799014806296797, 0.03599360690362031, 0.015256885202571511, 0.019982034122691523, 0.01866503321986285, 0.01689051886299445, 0.03946653244295909, 0.019298348530766465, 0.05059601648920967, 0.044265016087240754, 0.05307644447912613, 0.04371506454903753, 0.031785926436104124, 0.03811631779817324, 0.033558335966400565, 0.039455224985196706, 0.014319105483140918, 0.049177275279596935, 0.0474326977235896, 0.055222498072731885, 0.04684976226980648, 0.047160874406296405, 0.07356871805724598, 0.08025272794428372, 0.03473772449539073, 0.0397578488674856, 0.0867886453746788, 0.0379270825895571, 0.016932678596687414, 0.025233164647473924, 0.0704304005710348, 0.06504820389372688, 0.06810366897092712, 0.045628951366750464, 0.06597124791193394, 0.05708473141215021, 0.04613670678208432, 0.03791222048382606, 0.023138494486169472, 0.05261298043713455, 0.04276893064079266, 0.03553558591633074, 0.022840758244837486, 0.08780297642994313, 0.03770380243358593, 0.017071646946151892, 0.06182282817580047, 0.05103240315351756, 0.02560672444111157, 0.217692188077396, 0.1906001474708319, 0.11183670211222865, 0.1375712962040017, 0.13859187853672814, 0.14719524510925816, 0.1802166377104098, 0.12098378426725827, 0.12495942053294952, 0.17102842429472556, 0.14487669532818181, 0.10598362183138248, 0.11945504815347734, 0.11182848198880112, 0.14283140910969627, 0.13710061178332375, 0.1166212582780469, 0.21614202448437292, 0.10775182936941424, 0.08970261401226444, 0.14259551531605183, 0.16027641092096606, 0.20072591461000905, 0.3340464187485557, 0.19804210942839423, 0.1687152830943946, 0.14554455545881104, 0.10251283750779207, 0.10127785014769725, 0.10309121090798609, 0.06785212400098962, 0.19549604685556507, 0.11091522091338712, 0.14596340637053215, 0.2197679339517509, 0.11573562233318245, 0.10531313401917297, 0.16731096732039608, 0.1893827571503578, 0.12341040607181289, 0.1288799367724888, 0.12274279875019867, 0.13429109157333452, 0.13727740955448922, 0.22153729062166908, 0.13296258786032278, 0.21791056910109138, 0.12472287556456944, 0.14037788995812017, 0.19323087808105255, 0.09368430237255751, 0.17545213772644921, 0.17239305671424637, 0.129955600826971, 0.17099784206478827, 0.26452890386985195, 0.11178694470154663, 0.20497191096505812, 0.11541375815267525, 0.25315268205538877, 0.1609062577687925, 0.14172563779978983, 0.31502068643608405, 0.13933509107558958, 0.18431123976986255, 0.1831240486353636, 0.28077177583209934, 0.3021080293242009, 0.599308499405461, 3.9210380373462557, 8.072851665558355, 21.80594236620011, 35.06929982093073, 30.494007987360803, 51.22824507374918, 82.47615614245015, 106.27546664207213, 145.89795574065178, 152.7858574159684, 146.70313988962482, 157.69101665865992, 163.2975898250457, 167.97197249627885, 162.43051067475352, 165.6500078016712, 160.4788334138932, 164.9137632308468, 168.59624124342398, 164.2854779766452, 161.5595248437697, 167.16901625356368, 174.56188386486423, 171.56716992778163, 167.16879660083404, 161.5586305433704, 155.65604394482028, 161.54035229836742, 143.14595806983212, 116.27113280757781, 77.85531382406913, 49.60158325010731, 27.357294444114935, 8.227223407837654, 1.1425389950313876, 0.19743412672992677, 0.12424576366620681, 0.34237639918442697, 0.09450806905665705, 0.1789211064216591, 0.24084004032756054, 0.13579513667331589, 0.1739509118300292, 0.2038110732551544, 0.17407267384471434, 0.13218338451077863, 0.15861352515076438, 0.11157880627339888, 0.19520933078902383, 0.19072092889297396, 0.1385382523820285, 0.2281656365601286, 0.16976591139551134, 0.24246194039381322, 0.18944004520533547, 0.13537976380077102, 0.09458051799165626, 0.07791814394295216, 0.23141699031956736, 0.06691125311678456, 0.21602139627981573, 0.08982779277909188, 0.09250833442614925, 0.09884460934347684, 0.12810322320869855, 0.1181784468973356, 0.1105466406912573, 0.13490668918576934, 0.10947218705569545, 0.1530701895394633, 0.20414533273827648, 0.12418851391562533, 0.1206455487878092, 0.1774110245488344, 0.10918907160239835, 0.1922028493737021, 0.12362763030274261, 0.14292937643345327, 0.2171868764825406, 0.1205109624612716, 0.11895164411755339, 0.10578655337374057, 0.17384339905073568, 0.14041288485450132, 0.11468027493045216, 0.18158222007895672, 0.10925932952593412, 0.24729641484877757, 0.10582715603372744, 0.16132978181685173, 0.14246600049157299, 0.16476049208112303, 0.15324029170217054, 0.12716955355098172, 0.13252237841727274, 0.19187833452897687, 0.16680128902437227, 0.2699749922800449, 0.1500311953526351, 0.1490438765575809, 0.14494172087119472, 0.15647328999494353, 0.11670867657108654, 0.12274794686104983, 0.13758271091407345, 0.23462564233810673, 0.15277896887592732], [0.07426631006021654, 0.05046502311503695, 0.04072144191952483, 0.048475477453922076, 0.0748233019464439, 0.09771796979851301, 0.04460016423235497, 0.08043121876976184, 0.02022252444388165, 0.07441719107690357, 0.031779899239359845, 0.05064646337902354, 0.04098738551199917, 0.040034866260905425, 0.06259956472222844, 0.07211842934691137, 0.01656950120964358, 0.06724424089395231, 0.061037492292422446, 0.02133363347140051, 0.06040812424954869, 0.07373322777810597, 0.044399889696749954, 0.03021183025632655, 0.0258256666242115, 0.02380028336999878, 0.04127036689990952, 0.04259346203217584, 0.03442481971315799, 0.015749346630107013, 0.049365307730171955, 0.017031593954250697, 0.05026693193001613, 0.04846645676861367, 0.027151858666911725, 0.04397187637345445, 0.0292896653240126, 0.06045791996462692, 0.04206083557238022, 0.032709476072341204, 0.07359922367839083, 0.03256132998954385, 0.008381473993311727, 0.09302713682935124, 0.007917241948176055, 0.014292905276130526, 0.03697925179655995, 0.06734723375449259, 0.06459724623709917, 0.03890828417253591, 0.028993254414789622, 0.038833686360909093, 0.05929998572795622, 0.14381498939567997, 0.06460427892424407, 0.03643585031010932, 0.08049150988940271, 0.030138883364176562, 0.02648421112568148, 0.0634744294708775, 0.017142345370244116, 0.03984465429018583, 0.2769935527636159, 0.13691812963976016, 0.2392011790746643, 2.83108736238172, 6.769886382164494, 20.182136028043686, 50.322601179922785, 79.05556694153817, 87.55606482105871, 110.11376473211475, 107.94928319992559, 113.92757938754175, 103.56077855633151, 102.86507560360818, 104.28490300332348, 88.58293348743071, 101.52892020440872, 97.75210134444698, 94.76020366914811, 92.3280752858808, 89.24937555866858, 98.87979061372819, 83.77451558266917, 97.2735486492034, 100.35438214578937, 94.13116531987345, 95.76790763485818, 93.30538872749575, 91.75147118106966, 96.57765742271178, 102.80339241027833, 94.84700572106146, 103.60423057310044, 99.85569984682145, 96.545180197685, 103.69479025563886, 118.04228690362747, 125.93397801922215, 128.00861374024424, 116.16279694341846, 95.66594169985865, 68.72570699261081, 52.1068089239059, 24.709153290717836, 6.279838200538389, 0.3200107993137452, 0.18074143858205888, 0.35155710493845327, 0.09433327077497398, 0.1146495165002923, 0.03099750130317144, 0.004869952465542743, 0.06412041013038929, 0.016018993300085348, 0.04479353631576223, 0.02196355118235994, 0.11808221093228749, 0.017540883460652926, 0.006138458566349601, 0.029866200113188357, 0.056469455556643594, 0.0337149971164763, 0.022579568227933302, 0.006499955826814497, 0.027026026810128844, 0.011204194855846224, 0.06777949120488859, 0.0421985513680885, 0.022116054390226642, 0.019383868840973706, 0.08734451111165747, 0.02068979402763709, 0.02341654801350688, 0.027828050003717505, 0.04781553484199028, 0.016658093532427184, 0.006491063461233412, 0.018055997150499496, 0.055691228969202894, 0.02416735248369796, 0.027854932028980508, 0.022503574221064488, 0.05459118033609083, 0.01621083416525395, 0.02164149356465186, 0.037894351482992215, 0.012215603285679414, 0.028444704817487832, 0.07255431805406848, 0.05889885442992372, 0.0412018709785996, 0.07853565677519768, 0.03053775087239281, 0.035766350751322125, 0.03920680182355066, 0.029126178330531525, 0.03153335299312828, 0.05598801526150877, 0.04453917597270301, 0.06263272483803092, 0.04653306152190893, 0.053585824000859456, 0.028984279694756674, 0.013748649601644326, 0.053237809409056945, 0.06185506515565419, 0.009292501922426446, 0.04863582731735322, 0.05043474732026939, 0.06385627833585586, 0.06402359193851871, 0.0659071340135509, 0.038319055306454824, 0.0494623365962217, 0.11430211094838959, 0.02372612988936805, 0.0319949094761884, 0.00849308725821996, 0.03533621919491599, 0.016611436862618695, 0.058628965484639334, 0.04330138473080532, 0.01892216297076835, 0.06239823681572753, 0.012534148390254667, 0.014330782578326763, 0.008967242057194874, 0.02021038003506199, 0.04969968595692227, 0.05260057747364045, 0.04800178613814135, 0.037905141831405705, 0.017983919768143567, 0.018882075504910563, 0.03490814458458655, 0.06599623003914472, 0.015201673245868616, 0.03379883011803031, 0.025281171547248963, 0.07550150426405092, 0.011179960621971519, 0.08894936572159491, 0.049036560249665094, 0.0113334444223813, 0.02425563071043261, 0.0490272905857813, 0.03898116977765195, 0.02360179573447714, 0.03519465763782782, 0.06080794936767029, 0.07700403250994221, 0.030547217803917108, 0.026320798825773022, 0.06253859561477458, 0.11924881728426104, 0.009373578922672859, 0.01868480786440834, 0.01332529217770864, 0.03764863261171887, 0.05261759228643872, 0.07712222455490021, 0.09374659298168075, 0.038728686350007216, 0.030629298379344326, 0.05845528186088609, 0.018407112483175534, 0.035829001421769785, 0.06616348235477364, 0.10022998742398717, 0.045818236371081685, 0.09858726508795254, 0.049797549858809485, 0.04545898326942998, 0.17319643779868082, 0.04167382327479221, 0.030984897241597215, 0.28426035637817076, 0.10580831793166938, 1.1905914617161597, 7.259467801740093, 15.288783119570825, 32.940256903248454, 73.24040997412898, 104.05327919990786, 114.02403831481935, 132.16079558095626, 129.58009566030196, 139.78346701591246, 124.61138617607855, 121.6749272807952, 115.27744739286362, 104.13855152745401, 116.60184352628647, 111.33777172334733, 116.89060841837238, 110.42346723618047, 106.24771195073282, 118.62534722974225, 100.8487419928274, 120.41186917212703, 112.90049891318046, 108.03007618073495, 116.22348385472452, 112.98387281356321, 110.00387560936713, 108.59608988608085, 114.47398908676641, 106.8924476254371, 116.82977245699976, 111.07178795722224, 111.20602715399959, 116.08732269656275, 131.03674627119497, 140.5342871142972, 147.53843215204054, 141.1273337948707, 122.97114510690014, 97.9844468639743, 81.4687345873925, 47.042989807744185, 15.79426778901008, 2.7392801209803554, 0.24350924387333855, 0.23155729166202008, 0.06832572721665905, 0.30667621161668535, 0.05718564434397606, 0.04701249466668214, 0.04846289829020539, 0.011693056627747514, 0.06646926634975019, 0.02533349726769713, 0.08395932945272616, 0.007988545102923508, 0.08943393931634004, 0.04078261404027862, 0.06928170535473094, 0.06304322922181699, 0.030627023098209215, 0.022376275305906614, 0.003019742157888569, 0.06374405794626763, 0.0211325200695184, 0.08365028192319217, 0.030721719226529522, 0.02760875733539222, 0.019525244621740236, 0.02005511699544807, 0.08208089718414892, 0.037688645384004044, 0.035704190377146006, 0.04024596561888053, 0.04004573704855096, 0.017040103275869644, 0.05807955786886235, 0.0323357439089206, 0.011518097467600338, 0.07332716287384111, 0.045537273624851826, 0.04839568556616864, 0.04220728093998567, 0.10509033266815448, 0.04808355836317905, 0.0295264994905841, 0.0738715602745933, 0.02053718739790061, 0.024194276643796794, 0.02161598666721294, 0.0338422289989408, 0.04278491889577239, 0.03439517211048834, 0.04506776514913767, 0.02178719008131133, 0.06689050745579504, 0.027612423066109903, 0.053960509943745794, 0.008064433293897779, 0.0803366452155094, 0.00599897598036595, 0.04587277033997159, 0.02099490961089971, 0.10840626763961009, 0.05185611621146241, 0.0032433577167290837, 0.07066120754086203, 0.023164704269278916, 0.04006656314877253, 0.05978285477706983, 0.01591885315945312, 0.0819154145316251, 0.27023702499366575, 0.13103390022391273, 0.15075960707279945, 0.2019171813322652, 0.14791936673704656, 0.1996034425833533, 0.10470602466093917, 0.12565770201505194, 0.12427099094155336, 0.24201590868253864, 0.14218867666298343, 0.24049464192601944, 0.13747086207712853, 0.08159056260821321, 0.2363878743903291, 0.11392746330989946, 0.15392224785060654, 0.22824877242167152, 0.13582875261143332, 0.06781112297528213, 0.11510167691496112, 0.20035561835092885, 0.11050636744907788, 0.08225841507796319, 0.13018489094270816, 0.08040785308807127, 0.294163054035556, 0.19164879926510398, 0.1876242482854474, 0.0979283681860374, 0.1681512125557469, 0.11408572941417656, 0.09660762494369861, 0.12690871593452271, 0.14049467240129748, 0.22342388938751914, 0.15118198198897226, 0.23816450889552795, 0.12555673928751102, 0.10343389735827524, 0.2345219906419516, 0.19462855953362682, 0.17509734708695643, 0.15728260059991192, 0.112261934536359, 0.0765490299090743, 0.11409641634072028, 0.22675004397188464, 0.12784453829930675, 0.21282847970724109, 0.12847928044896934, 0.11953662885653397, 0.10885783050569797, 0.3744064740115597, 0.22285074836784796, 0.1271725029894902, 0.1587282698000631, 0.12310992340527235, 0.10274244938045742, 0.2988414917021029, 0.19864279896982256, 0.10163465559843088, 0.6296043350331245, 0.13254643357809515, 0.8127249056293119, 6.352468238722894, 14.454552838879248, 32.310647849113714, 77.21529283831197, 110.17393389055806, 126.03358268737794, 146.06608421571795, 146.84705949598745, 150.3588830271075, 138.91960420916158, 137.37320192398565, 135.71648690008348, 115.89261624120898, 126.72501025661346, 123.81920076185658, 120.65832737953433, 117.889447827493, 112.8033967171946, 124.40060584775864, 110.6961190315985, 126.24106038001277, 126.28044882128317, 119.80785554455174, 126.9279536893291, 122.25328860744354, 121.92402916569864, 124.71394831134428, 127.72174727532172, 123.18930733588435, 131.0784410661267, 127.66461403139176, 125.8438733316237, 134.1600747262278, 148.98122110674458, 163.34150468149494, 169.91034507751465, 157.10948605691235, 135.2944241800616, 106.16593053264003, 83.46767640882923, 44.447126004003714, 13.306615314176007, 1.839039659788532, 0.2270391655545081, 0.3861182729803747, 0.2747931030969466, 0.4805869957612407, 0.12162612600912973, 0.1297472402333252, 0.1366791408509016, 0.10833289939910175, 0.23185450313312395, 0.13378838467742168, 0.22309024277473652, 0.18248516195003064, 0.17205574820118566, 0.1686255129114274, 0.23118727119459262, 0.1498136570256564, 0.12470874890324571, 0.0921866924111401, 0.11653769340726639, 0.16551361779772467, 0.21036009844993392, 0.13896474885123392, 0.18325866560541815, 0.11940915948681294, 0.23839470299501575, 0.14001248133999689, 0.15971856101626353, 0.10440630808232293, 0.13926010638956102, 0.19382467283116234, 0.10735530225980668, 0.16811015024300546, 0.2743407434994175, 0.11044570860723335, 0.13042648443050925, 0.21604321446389924, 0.16798175390689604, 0.19623826348012496, 0.13262022316696184, 0.22093836308246662, 0.1162542945014373, 0.12352372579757245, 0.274792674087709, 0.16448601809961183, 0.14167355914269725, 0.2514815531791218, 0.11968125093487963, 0.0688761996946508, 0.13892903383220398, 0.204996012091156, 0.1329805602830264, 0.13630722048542193, 0.1747360140565903, 0.1614349963323724, 0.14168829867436042, 0.12935462017213145, 0.10621110397961833, 0.1346991100018063, 0.21369463403619107, 0.11910804096729526, 0.11451001955016006, 0.1389065261689886, 0.1976164862994225, 0.11691620212889488, 0.1357183593415445, 0.12315205824110778, 0.1257602275619584, 0.2125276829446516], [0.02229003295783074, 0.07500556958538872, 0.03873354334744715, 0.03865318455462975, 0.04366198231676414, 0.05768551671456906, 0.04530148325307716, 0.061200810746560176, 0.012962776499109404, 0.02520269350028567, 0.026368173703010526, 0.06494313493491181, 0.033705796400505694, 0.07182747681414889, 0.021737233487769, 0.03518131238618686, 0.007394436256764758, 0.03203699260108894, 0.023935013338022178, 0.029561616961033117, 0.013266045810474504, 0.031712424130209034, 0.020637135058941863, 0.015739056154064113, 0.01450555979259192, 0.07511761760519398, 0.04952141346650259, 0.030185766029922716, 0.04328592124605372, 0.038226745542018645, 0.04595158929606119, 0.051646786516592394, 0.01825935710521956, 0.06505214158565768, 0.08753010357219367, 0.03241431005599518, 0.046837501032578374, 0.0954030819177147, 0.02750072936196962, 0.055784350786838806, 0.02472005427754935, 0.059035482380779526, 0.02611425003006814, 0.048863792100981365, 0.06584518048311434, 0.02723889966164866, 0.052074095038997556, 0.05549879151306326, 0.02728328871120128, 0.08240616279503993, 0.013099570116478831, 0.0737828089885654, 0.02682511833676648, 0.09959077898172602, 0.05831926294993009, 0.012965162862993538, 0.027344974110864347, 0.03436403063636634, 0.024401855827759833, 0.1166748614501088, 0.02427144851084919, 1.4280142442833994, 8.530001947956702, 27.39610629697, 52.486384530221265, 72.86029308072983, 90.45979545962426, 96.02870602761546, 97.84261395854335, 94.94961492476925, 87.22071786080637, 87.54100291959702, 81.80761952554026, 51.830085708249, 85.60792553809382, 71.19457229491204, 81.38725911417316, 73.80752978786346, 92.8004933941749, 87.1090950504426, 74.6308352870326, 89.21026952805059, 77.61202489176105, 69.31388993417063, 85.80003538439351, 60.588024431659335, 82.67796993255615, 72.44315685764437, 68.93345140641736, 79.90497973657425, 79.0537783407396, 86.49116485349595, 74.87172372879522, 75.33029587038102, 87.49947286421254, 95.26792310899305, 90.78492072320755, 92.88016457711497, 85.07421647348713, 97.07451189717939, 88.12137249977359, 102.15130621387114, 99.70158992275115, 109.24083340552546, 110.84303532877277, 124.59654392734652, 108.77374187592538, 74.46143596403061, 39.602736042391875, 17.725614424674742, 5.222621665846917, 1.8903081022923993, 0.22143135598349958, 0.09635489253747849, 0.0025461856257020226, 0.07655462235092156, 0.035851440137071956, 0.028273865295153473, 0.010383472413635783, 0.054195702766939524, 0.020757002921234217, 0.032486594282090664, 0.11003585922862254, 0.04045046512938796, 0.05475512698232647, 0.05245433511933493, 0.1161678491400615, 0.07293959133206837, 0.05865818407807139, 0.07609628726758304, 0.03346755837781295, 0.04977339510655692, 0.04623943917273034, 0.10349903015359756, 0.028527482532926147, 0.03724932077250654, 0.05476645359228696, 0.036720256621558825, 0.023554315520150047, 0.039787025326081825, 0.008717822023637353, 0.009401817881171743, 0.03342716256156564, 0.04858231607584223, 0.043812828859494585, 0.046412207321414066, 0.0647842942646915, 0.08639174288198834, 0.02661668496476787, 0.045921393940525676, 0.04264405447869532, 0.03261774470428786, 0.0371582520705077, 0.03286586909164344, 0.02833147893749899, 0.056045862560671185, 0.08894103068497874, 0.038906338309208234, 0.05435054828863471, 0.022132100101800698, 0.017395278874544368, 0.039842038099924405, 0.011672855846794143, 0.021505706395292958, 0.017746309937548735, 0.04353401882033195, 0.013780864556470226, 0.01946336195443667, 0.029123816864504933, 0.0032253599173629717, 0.039696891251350605, 0.03758602024566743, 0.05006141735300903, 0.16007534348435942, 0.05510041813155817, 0.02372531017528907, 0.032714394356815085, 0.04341608341482859, 0.05024153611532623, 0.01641823331855478, 0.05923595609924486, 0.03731665607061117, 0.0351588775013243, 0.0357934434507643, 0.10192537830481607, 0.05951912900913627, 0.02183826516322311, 0.03939998621541647, 0.0453981175838459, 0.03863248102847607, 0.015494339900361675, 0.019286064310900627, 0.06842975429589711, 0.057588146939393015, 0.04687002912584332, 0.01623564583790158, 0.0344845975538896, 0.031119807240282817, 0.04585287503657803, 0.041792911642621604, 0.02269218506802234, 0.02951768181857563, 0.03284305116281875, 0.045095918880354975, 0.014466786167524276, 0.044701613425727815, 0.04296546283688757, 0.0742303115886546, 0.06026288930086359, 0.009233351316182845, 0.08046763858968213, 0.0530877864108451, 0.02870579907340148, 0.0651138729505962, 0.02413583179605344, 0.029670234822157412, 0.013964838656266371, 0.03054581203257605, 0.0701144046240276, 0.06778494575090947, 0.04738805778024178, 0.020002664870492393, 0.0181850370004653, 0.08493974579558258, 0.01618690732415886, 0.01180687718348758, 0.024507346134933255, 0.06940288514259361, 0.011992214919788944, 0.03936782967479479, 0.03875585565824182, 0.05196837490544685, 0.07834642539702116, 0.0774362133515458, 0.04617419912509861, 0.1086750495878439, 0.0368823838089743, 4.492530803526602, 17.533716386364354, 43.763127403874556, 74.96291099056121, 100.04088278739684, 112.60919232522289, 117.41315441746866, 114.97271845417639, 109.86451379714474, 99.08873527280747, 107.51520233769571, 97.21865115627166, 72.94248242532053, 105.87474161578764, 98.16344814915811, 111.51856160932972, 103.16895731033819, 131.0400567516204, 109.69576558759137, 114.152707745952, 122.59307569073094, 109.96478526822983, 102.07775392839986, 113.23539872323315, 81.33722536025509, 113.53356945899226, 100.72514026395737, 106.83809141958915, 116.80164906286426, 118.04098467673026, 110.14897192678144, 103.31967046183925, 97.77483540196573, 114.05737846128403, 123.41807565381451, 119.2584962229575, 112.07353776501073, 103.48491991719892, 110.25230284660094, 104.46988982539024, 112.6352603973881, 107.11128450209095, 119.79729652404787, 124.75385450547742, 139.3476289318454, 137.3271219192013, 106.09359418192219, 66.71982257596909, 34.35285537473617, 15.107910863814817, 6.5769273427224935, 1.4081936497842114, 0.04371156735766319, 0.06448541272191272, 0.058376742526888854, 0.020954827890701352, 0.006063695567014117, 0.03980162313147899, 0.03851514700199327, 0.04693264532233438, 0.02564158335688614, 0.05547561352291415, 0.05087860717227863, 0.0647633724034794, 0.03282648068101656, 0.01699960978341199, 0.026674612703162338, 0.020566314060781753, 0.03406527166765544, 0.035386194940656424, 0.03530785861995912, 0.029353746663658854, 0.104082559325522, 0.02057738977694704, 0.03162759521435345, 0.025180444391744754, 0.06346692563965917, 0.026810800153461677, 0.04845534466327198, 0.0434569618664682, 0.04038070516300298, 0.01584775445442046, 0.052755989900399605, 0.0285084854676238, 0.04288337651580092, 0.11327633453953652, 0.06671978476186914, 0.013887369930143318, 0.0563332412932669, 0.04400674486532808, 0.04741043520851001, 0.04803624477297549, 0.04142967105332402, 0.05206333916454066, 0.03953170737311725, 0.020883514681049896, 0.022100497059704318, 0.04366216617786596, 0.04218440172412703, 0.0176334613558626, 0.038030726624833006, 0.022902589201206164, 0.029235956814861106, 0.08449683972303906, 0.036844370526171503, 0.013243844582428856, 0.054765342764796755, 0.027678256831882943, 0.009470706422542854, 0.05123657324621755, 0.04066477056532618, 0.06103533958535522, 0.030193582041970188, 0.061280725208381494, 0.053190641375559, 0.11492126320879306, 0.13660118374372685, 0.09955494138862818, 0.12813897653212472, 0.13563292521622874, 0.15435652777312264, 0.29593014308521826, 0.15715161488661844, 0.13446716922185115, 0.10926388008820434, 0.0677986434029956, 0.18692074974458064, 0.26331814787080216, 0.17860086634755137, 0.0853714133582769, 0.12089887874261027, 0.13479629591588052, 0.15367820288144773, 0.06198836828491861, 0.08592321116837763, 0.16262447040888572, 0.12941362426405953, 0.1092548172680601, 0.10519730152502176, 0.25023750299888275, 0.2094240615805311, 0.10552741647247346, 0.19613566898530532, 0.1343813826960902, 0.1528262824661309, 0.18345522844503004, 0.18024922709070867, 0.12283069967863061, 0.17377026829748385, 0.14784536264356107, 0.21980787777612287, 0.11868495358935288, 0.17605825117038143, 0.1888111023412597, 0.15403794244893138, 0.14481563812061665, 0.14812288565501092, 0.20094703822847337, 0.21380942465076525, 0.15774340248636662, 0.08834111489235394, 0.15870585406739868, 0.2405839064909566, 0.10682296308298266, 0.15063819745855947, 0.07359843460782882, 0.11734551014078241, 0.13355439078182946, 0.23267861455678943, 0.14688381504627968, 0.13756631663249386, 0.15648527161007927, 0.1428782324036283, 0.1033312492373009, 0.35282936247606433, 0.09685930780946247, 3.6533884896386057, 16.303839568168886, 43.32908184297624, 78.24316563144808, 107.44534492492677, 124.84112724181145, 131.63777105269895, 127.55485042448967, 119.3966107214651, 110.1932554860269, 111.05853034603982, 105.0517185272709, 74.0960201140373, 113.23426908062352, 96.98905129586497, 107.79418483857187, 101.70511307254915, 122.34821781035393, 111.57582036910519, 99.86858091046734, 116.10065091040828, 105.96738799925774, 94.3405806633734, 113.62240329865487, 89.36830182229319, 115.39012924317392, 104.13071463184973, 99.19280359821936, 107.85829990140854, 109.35335836102887, 117.31658566382625, 106.92384227629631, 104.56303042750206, 122.68282736501386, 126.3810968399048, 125.02168963032385, 122.32572693978588, 115.98185800736951, 125.13219848755868, 114.60037569845878, 124.98591761435233, 125.67287368159141, 136.91180567587577, 145.01385350381176, 158.96734022325086, 152.94943594163465, 113.08981603191747, 66.13741336330291, 30.3854505092867, 13.336987207012793, 6.437865591818287, 0.7897878654541508, 0.1917870781354366, 0.17966589710164457, 0.1715366623454517, 0.21652060981479385, 0.13230249586124576, 0.19092339060960278, 0.12999951298679077, 0.16651198358064698, 0.15003337104234005, 0.1939184266713358, 0.12828455622037574, 0.14886136377050033, 0.17194002295934385, 0.17696856280728696, 0.20283451033455713, 0.10410798578372887, 0.22225353686559587, 0.19367462685031278, 0.15544806516939597, 0.14498063813774817, 0.24561753316271692, 0.11422910276920566, 0.1407010258445817, 0.19651351887131893, 0.10403844032196269, 0.12426101647677923, 0.13176811889054316, 0.12445602415790483, 0.19914542925694298, 0.07913774825752744, 0.13316972271328972, 0.13191346109153765, 0.10477791435175365, 0.20063497997339697, 0.20927681948148438, 0.09871449697041705, 0.1996521044883036, 0.1403877418488264, 0.1689090420522036, 0.12429378971817995, 0.13148541712472517, 0.1318310147091266, 0.14984482148241612, 0.1291868622384725, 0.21249196792562164, 0.13537106104195118, 0.1669634085509085, 0.07278782165338916, 0.17710999795986762, 0.11555618155867824, 0.09418561498844817, 0.2634852776123632, 0.16398020088672638, 0.11661962651076818, 0.15688225837244144, 0.0991907891547007, 0.07924450260977592, 0.20466650235316447, 0.08053349150765328, 0.19607687939799603, 0.1529354040300654, 0.16792060476877999, 0.10384564663493827], [0.010572485456753884, 0.004350076102831912, 0.05697122016440957, 0.04201537974539303, 0.04988716299375219, 0.08562841287423527, 0.04256337775938934, 0.041662891200112726, 0.032633755941905325, 0.027520323975852905, 0.05945976485588378, 0.014643046719532822, 0.031266256438327894, 0.031020098981717904, 0.03872890468506563, 0.01612717736392252, 0.015424573230707358, 0.046896853694512, 0.05619931380234419, 0.10111360855761076, 0.033838038497994986, 0.051441605187832355, 0.03327664926708226, 0.07004075293098727, 0.038908525490232056, 0.11452086735516788, 0.04455480033591871, 0.04015079068560754, 0.003246766329187179, 0.03929697037223847, 0.03391255587038975, 0.03456097651994036, 0.043882726721705935, 0.024313050915577242, 0.008268167674090833, 0.060587488415260474, 0.06527882700245227, 0.02208004442734584, 0.03767932592440517, 0.07080981327641396, 0.04454868695428295, 0.09252102084217534, 0.024209732467669155, 0.06752792325231337, 0.03910185160836385, 0.047223674463889295, 0.035209661469824856, 0.07680316425619588, 0.06478708282473587, 0.0750926201562247, 0.042784003420702876, 0.037484904300541654, 0.029754012282336914, 0.028845761421947714, 0.1155118250678624, 0.018352685766595028, 0.10093544714994009, 0.2542789691999074, 0.24324475967835998, 4.94423536523696, 25.44338176327367, 65.29351542072912, 84.81656382160803, 96.10170133652227, 96.72100436302924, 92.37619492315477, 88.18089838950866, 75.524688536121, 79.2085393782585, 83.28586670660204, 71.60817054010207, 86.68210583348429, 84.87012770868118, 78.32916751984628, 77.44194307634908, 61.901226120610396, 55.50788825558078, 46.27392676568801, 41.216375597061656, 38.481204894281205, 46.63860521008892, 44.26324921269571, 55.506291850920654, 35.215110009716405, 36.61745540557369, 52.699161344958895, 29.808779724182624, 39.33150414497622, 28.405230160682436, 43.53988962788736, 32.34655714804126, 43.7642962701859, 26.95528680278409, 34.57046454952609, 40.045748141504106, 39.03310591174711, 53.63229713132305, 73.91377110635081, 55.11636903209072, 83.49830227513468, 80.90467422239243, 80.2038957226661, 101.87572048556422, 110.99623526296308, 85.84143992393248, 87.05171861956197, 91.88309807931223, 96.22964905154322, 105.21757987237747, 107.36890577500867, 94.72861289978029, 74.40598933927475, 55.2095135565727, 8.72006823939662, 0.042247420116778345, 0.18070452846586707, 0.1501100564435605, 0.07395232126357094, 0.08291748818010092, 0.035494213337979974, 0.09447552564163363, 0.04367373027508298, 0.07278296465594923, 0.054997930889047926, 0.08905139331135059, 0.01632028706221571, 0.08348371142581587, 0.04936840272538605, 0.024734604202451247, 0.04799564977386787, 0.044717283754218976, 0.06287672001147462, 0.0150021513916492, 0.005955646526173599, 0.04632463964122919, 0.025024639344924403, 0.051517654736075676, 0.04792574425077727, 0.04500732464235156, 0.05221043187644213, 0.039930548068256154, 0.016327430832109625, 0.02467758044780743, 0.019640722800226464, 0.06209101640589296, 0.06295681067351853, 0.026801296832760977, 0.014950970015037927, 0.08428028198860346, 0.05947659963801984, 0.0551779002642199, 0.03874725632129177, 0.044745330233126886, 0.04672299004009655, 0.06647150332648909, 0.0254809481257032, 0.04906454544153906, 0.07334934111924903, 0.04629301936215451, 0.045791158993397994, 0.009974671617871331, 0.05239105625678936, 0.050936688128257954, 0.06391099999628722, 0.04285490868853466, 0.020733076080139128, 0.0554578862483463, 0.02000346734759308, 0.004756529317913397, 0.026843964099703778, 0.04515670795714663, 0.04688824669668271, 0.04339470190086192, 0.028633645082253124, 0.042649263876580426, 0.11095856616814291, 0.09295002241889316, 0.06415717085943588, 0.0399911571143856, 0.08631105084092387, 0.01867355403280066, 0.06600289500408596, 0.054497993400981354, 0.08557552216394294, 0.018033273067445527, 0.02670125341072919, 0.06093772083160378, 0.02579182852059603, 0.061841371334007675, 0.06044180147470005, 0.03616097030199824, 0.020008877843558308, 0.09441478253011742, 0.0035287000918610687, 0.09287764243180714, 0.04192888458830215, 0.02700659115948985, 0.00847216348178805, 0.048685481306165464, 0.019127305995132175, 0.02200881548736605, 0.06217303760950604, 0.02773229667406169, 0.07109573261151392, 0.02443544686801972, 0.06250792911516563, 0.05316772385530415, 0.0159527468044431, 0.028090963718451323, 0.023368813074944962, 0.08008954355553274, 0.02372661635519997, 0.03335819166574267, 0.04342151114777212, 0.000858782647898601, 0.025602754190443985, 0.015577409686821123, 0.079174681356357, 0.06333561433899788, 0.1071855524975446, 0.04242882590680834, 0.009839085546592552, 0.010805298619332814, 0.09607330159915071, 0.025347250461157773, 0.022114554773114865, 0.060758912079637094, 0.05418834449242681, 0.020739758282058665, 0.060941206531659256, 0.20963865812988053, 0.06204243494017471, 0.021745375087184292, 0.29529110318230045, 0.5415336415171623, 10.509835943098992, 42.43706426312847, 87.91547944468837, 104.7022275001772, 112.24781651650707, 107.17000238357052, 108.19902835353729, 100.64845792708859, 93.18472877625497, 96.20831920254616, 111.1973116474767, 98.26777535100138, 123.31785909591184, 126.42621978636711, 96.91568728416198, 106.39748373339253, 82.35111098135673, 75.2655218493554, 67.59098099124047, 68.68260014441707, 64.2994926821801, 63.65379994915378, 64.63874632312407, 74.11250191350138, 62.04655385786488, 57.35740346293296, 66.28928753637499, 45.556784137602776, 55.8777520733495, 49.11093788762247, 69.9834228331043, 55.063213071515484, 73.69378889760664, 60.281573572466456, 62.87752759072089, 73.93583836094027, 70.8002015083067, 81.77329878653251, 109.11199923484557, 93.42747642147927, 123.07887692605297, 120.10342967125678, 107.43786888737833, 132.16884428454983, 140.36921808796546, 105.7442129811933, 101.36999360976681, 98.59329285160189, 110.8215093612671, 117.67482357640421, 131.01314144749796, 120.27151892262121, 103.32877036063903, 79.78178593420213, 20.942969937478345, 1.8183519763331262, 0.05526591610584048, 0.18581928384880866, 0.04399491263733756, 0.02073598146859196, 0.022424136648976037, 0.07303603414085603, 0.0491610188938437, 0.06121411386336531, 0.03898609189256545, 0.025683961425637527, 0.09372197857667362, 0.005010914558830161, 0.027668458567331397, 0.010197587882078463, 0.053420651613944964, 0.037670929600755056, 0.007193421488702899, 0.032610750321539185, 0.021349213784560565, 0.03987145587621678, 0.045678440646658984, 0.08703417655441069, 0.03479943287769153, 0.051123437381559805, 0.1379088805087151, 0.03949418821702561, 0.05869948387806935, 0.037488298070046215, 0.07360552858200765, 0.016675502880506458, 0.04725234530445549, 0.06953560221459597, 0.048915376631362785, 0.05495080882082543, 0.010781357414089145, 0.03392211281724515, 0.04156562867724607, 0.030632475729010282, 0.04945739915954971, 0.02171136078334624, 0.00956104925623344, 0.02164050914166916, 0.09470940462403721, 0.02729123687341569, 0.026282233959664742, 0.050099216131193024, 0.012667421833612027, 0.06634080872660683, 0.018855940415373734, 0.04475227482016048, 0.043868852869397214, 0.024720387525796413, 0.037455589946119056, 0.023993896771102183, 0.035965663846582174, 0.010821320390659235, 0.0635619282031492, 0.08715959280849465, 0.02784699152764534, 0.07959673451560159, 0.01252138249260644, 0.18946817595391505, 0.08213040178581592, 0.1518388717405258, 0.13559756259764397, 0.16126478691735577, 0.22702954349017915, 0.2309992578962157, 0.21999383795886274, 0.08916367115753313, 0.14055876331704278, 0.15707571089508074, 0.0909876115920563, 0.13451440620326227, 0.1159289752643916, 0.17059632006191439, 0.1187961895559584, 0.23964020874231096, 0.10977673764911391, 0.29492359548326463, 0.15458310593760785, 0.12585814125956069, 0.1320361577334904, 0.11115169693385402, 0.1736268106727831, 0.11621766017689822, 0.18460275154680977, 0.11870619720749317, 0.16220269304129387, 0.1768841858833067, 0.156613330867502, 0.16665760157329423, 0.08040838168873903, 0.16574604887395136, 0.18207279214214894, 0.1484633810938366, 0.11266220015503707, 0.14030561722334356, 0.12614773781669716, 0.12637816174256225, 0.08756867609918119, 0.2366311839150806, 0.1358022766127702, 0.178249369886133, 0.18790405423891163, 0.1641832141866607, 0.1700133884385709, 0.07519276316968665, 0.2065027997859063, 0.20684579267136513, 0.22014745390943943, 0.11370166655509703, 0.15344902001802, 0.08885933506873347, 0.20364121624058296, 0.2367455148769002, 0.1857995800673962, 0.17228724465014475, 0.4736174036177897, 0.42796089223796324, 10.147226548963978, 44.665735383187574, 94.87248543770083, 116.5614038898099, 126.22824207428964, 124.15591270692887, 116.26956385950889, 107.77328645029377, 95.77193198665496, 102.47301117066415, 103.06248849438083, 94.82477372692478, 108.9449925576487, 109.99672120617284, 96.28851598308933, 100.01737994532432, 82.48949220103603, 79.88585425961404, 67.15334646163448, 56.00618223990164, 55.52047906383392, 64.04339721125942, 64.61254096800282, 76.01098399008475, 54.3417715257214, 55.113874404661125, 75.6629442399548, 47.77127981185914, 61.95354269396875, 43.990189490779755, 63.014343784701445, 47.17345176204559, 66.61249868331417, 45.285081555766446, 54.475473357785134, 63.38685520233647, 60.77442722935831, 76.48129186322613, 96.27085747257357, 77.7098488038586, 117.04462420555853, 113.29688579805436, 109.58193840519075, 130.55594213547246, 139.5005229211623, 108.77414195768296, 109.70080975563296, 110.4610513871716, 122.60769044199299, 134.91497408959174, 147.49693347561745, 132.99384424763343, 113.71565372713151, 81.76281036869173, 19.4644207339133, 1.2217705047899678, 0.18675083144297525, 0.22290768402238048, 0.23820186334271587, 0.22083521700434147, 0.09653640174937826, 0.28625056087490053, 0.08990173558554343, 0.15737659958822114, 0.11373728964357607, 0.12421816151829497, 0.22186142242243215, 0.15951920961660726, 0.08027987043944099, 0.1560429784078752, 0.12398442809259701, 0.1483392595283447, 0.1258575590327382, 0.10196231140364563, 0.08434608128041991, 0.10951117327016209, 0.18712840553733612, 0.15272359604076033, 0.15740917364676155, 0.11767541824449455, 0.31777658049137364, 0.09906407055114547, 0.23765089290757335, 0.29651871311568445, 0.09589658043677769, 0.1209433961118902, 0.1894601473524686, 0.19489498959193308, 0.0947790420163543, 0.20176836109209448, 0.10244908367073345, 0.15706470987248808, 0.1874622053677036, 0.11576405951693175, 0.2089730043324732, 0.12403307467578881, 0.10280982681339788, 0.20438945431622768, 0.1787507591108161, 0.12446560791783756, 0.17765724520769813, 0.1310811065618069, 0.132109502991361, 0.16149384720671564, 0.20131030180040868, 0.23805845168329057, 0.07213009686599817, 0.15980347420179075, 0.12138652434993176, 0.089306469946619, 0.10874634939095668, 0.05962338974519123, 0.1532507717849747, 0.2542433307896699, 0.08681139818602994, 0.1441319199699548, 0.14926634849079196], [0.06416686187167803, 0.019961665760004715, 0.010539282248505663, 0.007375488029567586, 0.07987905323745743, 0.028847142295431227, 0.04157335467396244, 0.04367875964230588, 0.0676263808723419, 0.0776822654710662, 0.12803876457074959, 0.02567071385020691, 0.014909946006692707, 0.019741164587978876, 0.05744237955960055, 0.06442361240906101, 0.024182310350419536, 0.022936570946307435, 0.04410904824673649, 0.04111460973358443, 0.09390687389719872, 0.060645366357939864, 0.014927634976864343, 0.06498541532745285, 0.07301246161542593, 0.010224501508468343, 0.04962584274190088, 0.07124400126837915, 0.08156842266720149, 0.01737575512379408, 0.033116448790796345, 0.046400041845176494, 0.04351760921699386, 0.08772554792343609, 0.03936441675309212, 0.05998621281657008, 0.07296637376590122, 0.09816305922164072, 0.03826046873244547, 0.005127109987135496, 0.08573177345697919, 0.036769834001578634, 0.019651484420342792, 0.02112460255082096, 0.03104202058767119, 0.11786975176824678, 0.03644849842173919, 0.05813276650564325, 0.028190633672620022, 0.07512789850513782, 0.025046032350209933, 0.012538189504055247, 0.034189151915451216, 0.06194917905715205, 0.179587189228304, 0.16199085440847183, 0.19043548453238704, 5.371562886622645, 29.763144908412812, 71.80434396190029, 86.2381249089395, 87.19176292419435, 85.482142971408, 90.27001550120693, 91.1315562648158, 94.11905304078134, 84.6676157366845, 55.424231944545625, 57.054988722647394, 55.20137856083532, 41.62792636502174, 36.9779839823323, 14.647957067335806, 54.05792528583158, 83.46340102534141, 31.30711924645209, 38.93878467621342, 42.83424346677719, 44.48194488402336, 31.137963110400786, 51.22161234578779, 48.73974438636534, 43.50483932802754, 58.70529459368799, 46.112305502737726, 34.60824481902584, 50.67029576147757, 47.00433092732584, 48.6569784533593, 45.63827922267299, 43.562866872356786, 39.33455574897028, 40.250382115764005, 30.94170928001404, 27.669975988326538, 32.79577051439593, 28.757784558880715, 20.08201752939532, 18.07999272500315, 21.95454332136339, 35.26330809439383, 39.312084490253085, 49.576495770485174, 45.25271023473432, 83.4360150367983, 79.39871157369306, 91.03951392635223, 76.9233351369058, 77.58641965927617, 84.68977712815808, 83.91595625108289, 94.35764297362297, 102.67879439938454, 93.85908619050058, 56.983295640637806, 10.6603382672033, 3.072007183105715, 0.1844783541896651, 0.21012034357315112, 0.02462283963517797, 0.07010200932141274, 0.09425886065488863, 0.051946602686638796, 0.03905982019439821, 0.14043444256869056, 0.11054452628858628, 0.049835107319297335, 0.11926036222927994, 0.007173598006052236, 0.014456080088782457, 0.07964512062889915, 0.08158712287343318, 0.055807295120171005, 0.03577525269300227, 0.03777488773207992, 0.06986847507857508, 0.06850020374141394, 0.015576457822575204, 0.09286356173575887, 0.07814653007493866, 0.05140202908566402, 0.07953779171070746, 0.04796375753358007, 0.05905795557003829, 0.013328500170891565, 0.03891901706435508, 0.02328025331089814, 0.04914328012795699, 0.017820794751206716, 0.037225077920142687, 0.06696421277499007, 0.035545840003197236, 0.03552437038911927, 0.046313435605336586, 0.03578368732104859, 0.029192569425269484, 0.06426523139159526, 0.022284107267736428, 0.0374337985751129, 0.06687504014060383, 0.05786674630437648, 0.11869938668584633, 0.02718736109654269, 0.00860015762173721, 0.008596579033520915, 0.0530649493298223, 0.020501755831402638, 0.05211177124311367, 0.022225505371968594, 0.056542122826701215, 0.07897152249971706, 0.04804416612211255, 0.02513878261520257, 0.05249877971026206, 0.06323882679064428, 0.039623844767770464, 0.042296442083053054, 0.026419191328327984, 0.033114112222627286, 0.007637012252328738, 0.0604553574005202, 0.040011764879548745, 0.07252299271884464, 0.027829469181597236, 0.015779418453964737, 0.10611144360154869, 0.05647504799849084, 0.012652212115485343, 0.020782873710437168, 0.10998670702740071, 0.04809285484014019, 0.04333573994376967, 0.026359840581614166, 0.06071819833690121, 0.010382227520758828, 0.01725483963626527, 0.14777891217700898, 0.035446643108321775, 0.07364896576731436, 0.03243144744286134, 0.04535017580154442, 0.05829041590914131, 0.03638019785284996, 0.031545367167000814, 0.044666269959341136, 0.04834506630657181, 0.036682959630965226, 0.08788261893055133, 0.06047364008883315, 0.08141584093532256, 0.0517019831515368, 0.014766372511193398, 0.037141528371120655, 0.05211640990549519, 0.03903296115177293, 0.0493711683027927, 0.0716965753705271, 0.05797817379296307, 0.01949562957780736, 0.023736675089645772, 0.04391671421246664, 0.014452270716578971, 0.046240477221867735, 0.04906688967058736, 0.08628980722278358, 0.14484059726518972, 0.048197559907191226, 0.04093046134878551, 0.01561042233069818, 0.08679370155497905, 0.26902436909656374, 0.06704591605211459, 0.42139076898174904, 13.508118256445854, 46.86680086197392, 95.80182044736802, 102.37825455204134, 103.0931692738687, 94.06365348446755, 109.20713240100493, 109.10868875442013, 117.90334086264335, 119.5319874055924, 85.20852627292757, 90.01378274733021, 78.59331561673072, 62.08847222789642, 54.838449493531265, 30.157480393686605, 58.2003600366654, 93.61920187550207, 42.334309931724306, 41.94201407894012, 34.83056083802254, 46.026605636842795, 40.10390904641921, 37.742924613337365, 47.23093801929105, 39.04549275675128, 43.380770837107015, 38.13167464348578, 41.037692023861794, 49.19567677282518, 47.49396431830622, 42.201012103788315, 44.87803759113435, 41.822683811187744, 43.9355783308706, 43.792870736891224, 37.44535792258478, 37.135537747413885, 42.22956695864278, 39.62897277647449, 34.507012367248535, 26.669304832335442, 43.599109572748986, 69.19050785803026, 62.47682217628726, 80.64281678968861, 75.4136933049848, 121.10560309502387, 110.55813789367677, 137.7526677039362, 106.34148797681256, 96.40939558705976, 102.16303410068636, 97.39246706808768, 106.28644143381428, 115.46747838297199, 118.14137381892051, 85.0956718383297, 29.637768307039817, 9.911500926940672, 1.1069791547713743, 0.16172243252156243, 0.024091249309299935, 0.0927144120777807, 0.02621839202249483, 0.08313207706857113, 0.0479158693774333, 0.020540780350265485, 0.030405939699360923, 0.04666937154627616, 0.08334615267813207, 0.07110014527795777, 0.0586269545038381, 0.05953689458810034, 0.027136490943150657, 0.05063230224374322, 0.004212950673630281, 0.03206383632195573, 0.031483896271956545, 0.096972152560709, 0.0054709340779921945, 0.02110953360135036, 0.0689759060379959, 0.056818699719564575, 0.06406035266756531, 0.05335516641817747, 0.037558912224466764, 0.048462143693599975, 0.03682920964614999, 0.010754722452181722, 0.027627945922675635, 0.03107608851766394, 0.024166791324293422, 0.012076611953577208, 0.02101233811117709, 0.0355677041525562, 0.051234949139818076, 0.06053565107586403, 0.03670050687487087, 0.08627622448388608, 0.008223912689924963, 0.062184153545287356, 0.024615046605768225, 0.020024902487714446, 0.032577046283310464, 0.1352701979058404, 0.018565265589483806, 0.01886638985466092, 0.046475034192084305, 0.024152038386091593, 0.052929275158432224, 0.03665312433675413, 0.06263189363263308, 0.07081234902744332, 0.024667791759354935, 0.031008912182803598, 0.056251840620872476, 0.03762402969803061, 0.009128244052971564, 0.1122706679386958, 0.18716275691986087, 0.1039952942500672, 0.14055882460407673, 0.32683851197361946, 0.08424197759238944, 0.10834655108591242, 0.11505973360110676, 0.142582553108373, 0.17795058027390512, 0.17888687761320224, 0.13761560672954207, 0.20223939791321757, 0.11610938897055965, 0.19492388642843694, 0.17931913506359826, 0.16199007299878906, 0.18906737407369, 0.10125442317897275, 0.17278491068751584, 0.19061402898401986, 0.17397168813453567, 0.1346805706740387, 0.102781213429426, 0.18616711840994898, 0.14442266565897774, 0.1570474422506748, 0.20714596124185672, 0.13409000881496938, 0.16704044635257415, 0.10654525621043098, 0.18035149982860013, 0.09278275478150576, 0.22127170326007953, 0.15683221750922743, 0.1337436451426437, 0.12741156072626192, 0.1227842900721777, 0.19751404502218772, 0.15879565489388284, 0.1549218240524492, 0.10153981391340496, 0.1465735341151876, 0.10755818532479387, 0.19012532617536285, 0.2362013473025253, 0.1628199607254036, 0.17767195409584433, 0.13955710335604607, 0.21278701902877903, 0.12925401750591495, 0.1474427374740762, 0.10472023559193458, 0.1639109925036469, 0.3070930247345279, 0.301044208989028, 0.4542146334725042, 10.989716360645911, 49.24775408160303, 103.39606254331528, 116.3288151833319, 111.40855481547695, 108.35913950397124, 109.84663563389933, 112.36053759051909, 116.42540747119536, 108.09640346034881, 76.47773819585001, 79.02053233115905, 72.60580185920962, 57.61091016953992, 51.2174036425929, 24.961638219894905, 67.01819727497717, 102.82696585501395, 50.28147905103622, 63.311361343629905, 62.32670522505238, 66.05063484561059, 45.963906549638324, 74.47836491369432, 69.4158794033912, 61.96707487106324, 79.31274106425624, 69.14794229692029, 55.1592013143724, 73.56460171361124, 76.6245525113998, 71.46713779818627, 67.4495481675671, 67.54621105809366, 56.003589553217736, 60.48010433873823, 46.79026757517169, 44.843783532419515, 49.21544944086383, 45.37200912352532, 31.08395403431308, 30.71718300542524, 39.343906679461085, 50.74890005973078, 62.51356301769134, 71.53866614064863, 65.67589944408786, 110.78598053224626, 109.21296888782133, 121.38690763904204, 104.20043868403282, 102.2940726434031, 105.47808016500166, 103.42030279098019, 115.3662576983052, 129.44109470613543, 132.37707507225775, 91.26690156998174, 29.4915815707176, 8.843375790503718, 0.6924039329732619, 0.3447406690928244, 0.1997514507703243, 0.22337993126242395, 0.1544965839674396, 0.22236769928807215, 0.10640873168144496, 0.24310272697719837, 0.21373200380513746, 0.2018778810217496, 0.17754435449117617, 0.16460494558897712, 0.1966254443170563, 0.1447101784569602, 0.19520790586548467, 0.08945904401761871, 0.13869960582064045, 0.1160842153213678, 0.16760229523624146, 0.18430558604098138, 0.06792239724628388, 0.22696871610899128, 0.14187997387301537, 0.2356681347854676, 0.1313263159846106, 0.12125852637954297, 0.20271348376427928, 0.1114422357791374, 0.19285034688730396, 0.1642608342151488, 0.11637906724166487, 0.08299127010808838, 0.1352386197616016, 0.2841001214279283, 0.10641602483848411, 0.2186302780624359, 0.1698446499123689, 0.2006792445336619, 0.11531297162535692, 0.24784701756171643, 0.1223121424235644, 0.18563116329812235, 0.22071979819766938, 0.19845412683583077, 0.22678742906258953, 0.1506424262639015, 0.10916526925059096, 0.0945322927568228, 0.11326332636658223, 0.13219323640148486, 0.12792575128015973, 0.07885229623606128, 0.09676124855515458, 0.24409009173752802, 0.16533807641075504, 0.15070906059155542, 0.18875704717732247, 0.10017020958325557, 0.20463045025544785], [0.0364914529716536, 0.0009795171471552984, 0.014380973786295903, 0.05832546826211676, 0.03229367419055874, 0.046206968536059705, 0.025163211243888064, 0.01657428159829109, 0.03882859570665225, 0.054752897666466814, 0.0355614758577318, 0.026675664158838413, 0.013559355021214053, 0.03501918519877138, 0.03733514560266368, 0.04874845756398094, 0.04600581299934176, 0.0303034198981139, 0.055326322138669996, 0.024332438685720967, 0.055081978395220735, 0.02714229405917708, 0.05207638181145153, 0.16623786199958096, 0.06268910507881834, 0.012065230759852117, 0.02962048890279426, 0.0324229745104188, 0.07832002600715046, 0.04138516517536294, 0.04463726587052788, 0.013958641962568848, 0.054048020167336355, 0.030694626527087345, 0.041576510956210476, 0.057137905574974515, 0.02105989876473623, 0.026607064815658717, 0.04083983314734313, 0.03154006200812517, 0.10480787605047227, 0.029855804300055872, 0.06048212834303418, 0.024436023349182743, 0.012331249045899079, 0.034583239035019954, 0.1026620714354419, 0.12926846592416688, 0.03446243079980055, 0.15951609929963467, 0.10634177559686285, 0.04882813836898535, 0.03197683937727444, 0.08345512868536097, 3.8995282496175463, 16.84763304648861, 40.93880907181771, 78.13730086049726, 103.9748945543843, 86.75519527927523, 82.79486440843152, 73.87701849783622, 85.29881923429429, 63.08736262782928, 54.884160795519435, 62.954813972596206, 38.22607432642291, 33.89500887163224, 26.221815347671512, 36.103322890497026, 36.81114988942301, 48.64034368145851, 72.80861977607974, 36.975085350774954, 44.38811002239105, 49.20599652874855, 40.4474223813703, 51.66573055328862, 61.48625112348988, 76.15685693679318, 102.17691929109635, 69.9898555201869, 57.974262852822584, 91.80262673285701, 59.67478682917934, 37.4596941855646, 45.71631477725121, 41.562885622824396, 71.83551896002986, 71.69641602423884, 68.6704957100653, 70.68062413123347, 92.75381718912433, 55.99854538517614, 73.21949589637019, 81.34274805745771, 59.23933705975933, 54.313126456352975, 94.26647140133767, 57.561484382998565, 35.44224662165488, 47.813821838748076, 33.84541834554365, 43.3044768148853, 34.10017628823557, 23.98290291909249, 24.436654467736524, 35.28359459292504, 61.48516070458197, 65.3123624094071, 64.53144988706036, 59.15872058560772, 78.86905823984455, 80.38033177775722, 95.61880265512775, 96.93322027883222, 70.42768616830149, 41.08456434742097, 6.909890972798871, 0.07579001297633495, 0.45917774941171374, 0.11040453904218252, 0.11363661802944638, 0.03649429132741305, 0.11357264202688971, 0.03241855801353532, 0.034736602176581664, 0.02083848786330031, 0.038191371432115, 0.13275056536639893, 0.05424791931985848, 0.11650797685668354, 0.03164667654932747, 0.034421973696519295, 0.03052714821552077, 0.06364379235873781, 0.04076395596888277, 0.08114819279721669, 0.05776473786681891, 0.06884354902731796, 0.018283486959614584, 0.02535377369983302, 0.0204205849853855, 0.020917557713185108, 0.0226556311827153, 0.03840556578530419, 0.04844037530523154, 0.00739555522393916, 0.06647703448130239, 0.009618354548189429, 0.03798307978638238, 0.04178134754540459, 0.03247317625209689, 0.051953911165436434, 0.0439115890842532, 0.04816764800418769, 0.027965020778919422, 0.03233203604336708, 0.08414554244448101, 0.02381418403538485, 0.040214839466517015, 0.050778483311014797, 0.09655080420235473, 0.07329925429075956, 0.028819927021921165, 0.019994994415150538, 0.05242333537147892, 0.02044363465580729, 0.0546606874934608, 0.07770002338915102, 0.02068159114118786, 0.03568861197920577, 0.028782873264243527, 0.04722157921341639, 0.06914878909986827, 0.031061887162767594, 0.06171428883868841, 0.012029000546693081, 0.06276009461632179, 0.04863959263950106, 0.01782012442427297, 0.0599001121947602, 0.020668259296085567, 0.021962396304814086, 0.06660526227806846, 0.03416517336342124, 0.016351652617055564, 0.03791179530502808, 0.01601684442345774, 0.029945137812906218, 0.04524696460594574, 0.09683773477351475, 0.07264626392674062, 0.047296659660435496, 0.013948927010079066, 0.04501734507240115, 0.022220533461340015, 0.0426615902312821, 0.042668703357659044, 0.0720402041089631, 0.058611326310182774, 0.06949377381393025, 0.08022162477455794, 0.05009311807131575, 0.01547112264820645, 0.049277743880426696, 0.022616639222589233, 0.02461101698328651, 0.02600632739373513, 0.014415276330715467, 0.03394429872353231, 0.09655195333424116, 0.049248107769075906, 0.03415964986948717, 0.03585145545883044, 0.04802952618187955, 0.027171309639309204, 0.08031109618323465, 0.0549828389569396, 0.005596945007827374, 0.040601863255423885, 0.022785613320827968, 0.04320399963387078, 0.055304687815688314, 0.09380409554127725, 0.09664099573368028, 0.12624249523205142, 0.07555369017345291, 0.11865023448462449, 0.16326898017958288, 9.14657892719392, 30.264933724557203, 61.63370870774793, 100.38565912554341, 119.37881100562312, 102.71627656875118, 97.67181827176003, 93.32472601244527, 107.35342025756837, 94.98772467336347, 94.57787621405818, 85.18465472805886, 57.43545078462171, 32.879199327961096, 27.20120176192253, 25.609062679352302, 26.21985024021518, 23.18905638110253, 25.418935591174712, 17.197067199214814, 30.250842609713157, 23.451202108014016, 24.749641956821566, 36.609391012499415, 18.675832133139334, 33.93371482049265, 58.00155078211139, 39.2957595855959, 29.71420745695791, 40.43114454515519, 27.953845762437393, 16.170476040532513, 27.27722121823219, 23.944293068301295, 28.769312404817153, 22.517699580038748, 23.940713905519058, 34.51015810812674, 36.174102060256466, 23.205681347077896, 27.171123066256126, 42.44201429428593, 24.994856772884248, 18.089002409288963, 52.59707381648403, 34.82206498422931, 14.122936052660789, 34.150574822579664, 25.556151866912845, 29.271191435475505, 34.9888559310667, 34.04774596614222, 38.352304043308386, 58.913858782860544, 87.7301945224885, 103.78393788491528, 98.98218016470634, 83.57473358031243, 100.21917804594963, 91.70345352542017, 104.1608541242538, 116.52719297716695, 95.50852914010325, 66.07229417370212, 17.20279189848131, 0.2833058414680343, 0.2704592517787411, 0.059982493459697694, 0.07305515569544609, 0.04206084706369908, 0.1151990160466202, 0.10672792221509642, 0.08319580792299203, 0.04271472608971019, 0.025338704750362425, 0.01565255237848408, 0.05750056393744965, 0.0498424579329308, 0.08222270771981248, 0.00853217497933656, 0.013020942682370305, 0.05046394676150334, 0.00773164805122501, 0.04092036047950387, 0.12912404302868152, 0.015096377333505981, 0.01093487951889514, 0.04365329487970279, 0.037700944925628366, 0.044780160420604294, 0.03705324056828695, 0.060929458573340416, 0.006213776021820283, 0.038513369678008946, 0.06906848776364519, 0.06022178868372595, 0.02298498961834177, 0.026502685335975502, 0.05924089736635647, 0.0180360961014465, 0.03305557544433302, 0.061736378983985034, 0.04431937002546845, 0.06749580884652753, 0.03712573929900124, 0.09251761175091229, 0.0023298687301576138, 0.017559719647491173, 0.05478729501426701, 0.10225688753228995, 0.04220682894811035, 0.035148857071274714, 0.1683274127783314, 0.02332893245282673, 0.04305333312180254, 0.02240483889416341, 0.05299106781040469, 0.05250676617687268, 0.04225556746185307, 0.021052530914124463, 0.1361006065722435, 0.03283124957834521, 0.14936099099295755, 0.07596131789708331, 0.1415635029514951, 0.14318117421240578, 0.15471096601217024, 0.1797328378644682, 0.07769656067173328, 0.1489335905400015, 0.08166023064404726, 0.12772564911433767, 0.12305782176554204, 0.10157955089403738, 0.1151309874389441, 0.12203909336559235, 0.11600248140072632, 0.17188117208500064, 0.14779303883833272, 0.14701343712306794, 0.07859877475927915, 0.22292855225743788, 0.13391950828654153, 0.07181966271732124, 0.16690242795213578, 0.23259667379240836, 0.1790199011203743, 0.17933284803744287, 0.16498662591461213, 0.13135067758060273, 0.1324952589047532, 0.09510187146764609, 0.10013621826205524, 0.07169128936384955, 0.10437577181766111, 0.20947474595760146, 0.17567100904641614, 0.20092100656080633, 0.13238547850520382, 0.12323847295896662, 0.17057494620882696, 0.09128297679126264, 0.1875919040532843, 0.16315253481509226, 0.1523510015179073, 0.14829565380369464, 0.14535139404958294, 0.19316531627649264, 0.1576526057455809, 0.1660905586135003, 0.2588054303440356, 0.3449437130362757, 0.20203600156932108, 0.18543409484048046, 0.23159217930609183, 0.2212847267547923, 7.36531247054377, 28.107792908145537, 64.43664227762531, 109.91060164666946, 131.24288251323085, 109.9025058746338, 102.20921608709521, 93.96670818328859, 110.39244128811745, 83.77355852434712, 75.29365308823125, 81.44174083586663, 51.2501044427195, 45.85832418933992, 37.312177765753965, 50.44908585086946, 50.980068868206395, 66.07341597157141, 100.01929406196841, 55.54424470470798, 64.13743995851087, 66.56344552193919, 63.94967217599193, 81.49988605130105, 88.42054736229682, 105.0946214122157, 133.72946123923026, 98.37663681276383, 80.1075230875323, 128.2613398951869, 84.87980811826645, 59.969654929253366, 68.9320707321167, 60.81514143174695, 103.33745448820054, 99.44426674996653, 98.36154353234076, 100.15041889682894, 126.41139322711577, 78.52915348545199, 102.26513339627175, 113.99333400111045, 79.62906452917284, 73.49119063346618, 132.11407230746363, 81.907177125254, 51.40148439714986, 73.50433841828378, 51.187389666034335, 58.65301724403136, 48.906209776478434, 34.78257456133443, 35.96911507268106, 49.11719406804731, 85.81008449677499, 92.52669626666655, 90.18305655448668, 86.1631448807255, 102.5686699344266, 99.22628495001025, 119.44622085940455, 132.6944261981595, 106.16168652811359, 69.51009473493023, 14.957121226095385, 0.33933821705079853, 0.4973317778879597, 0.21393434294769842, 0.2172194352193225, 0.09595724693950146, 0.23411489151898893, 0.14803319208083615, 0.27694366511798674, 0.12886938008089222, 0.12902880297793498, 0.26826903704674016, 0.24042805356364097, 0.2138302469205472, 0.11316052502802304, 0.18583057598481256, 0.1507567878692381, 0.1647147566320435, 0.10315548568483322, 0.17539555447236185, 0.18311868601989362, 0.14541474952092096, 0.14133356932190158, 0.14401558185777358, 0.21171936825398477, 0.13386761349055076, 0.14081930982009058, 0.17275199955028875, 0.1923665930066378, 0.09457557672454465, 0.14397058185310135, 0.14359051031210732, 0.16299093622834454, 0.0782979320314142, 0.1491061748275834, 0.14928029129101386, 0.26636160068934966, 0.12823357306901487, 0.1169457194966174, 0.18045453865441585, 0.14886271208524704, 0.2545398221381249, 0.16318235095710526, 0.1417186510779204, 0.195411991688513, 0.15114023019709896, 0.15245571041539793, 0.13056497780546067, 0.23536015211814837, 0.1069501106957755, 0.1620977849609429, 0.1997673241121154, 0.12326414456530926, 0.09814203776899846, 0.09780630739706178, 0.10385686982302897, 0.19757819722496694, 0.14367242043297138], [0.021000268395930048, 0.04568203742946348, 0.02141519693747884, 0.05925760957442465, 0.042144258716894735, 0.015653049378024957, 0.03608576728091125, 0.06270897739957418, 0.041740714241900755, 0.06904611033537696, 0.01694211679991455, 0.06308513806171476, 0.02029309071780693, 0.012445805046046454, 0.021559144858451142, 0.026363960219426986, 0.06283333645232263, 0.012179463087851483, 0.02479031411630492, 0.10014709671058002, 0.11896566352656773, 0.022373300969540592, 0.0698516900921541, 0.02356358135359422, 0.039895943876716404, 0.09901178505031333, 0.14127965205379073, 0.008119714198513858, 0.03026367717182204, 0.05366179310987073, 0.04460409043296691, 0.044515032711769306, 0.024630368364253835, 0.04289215205297355, 0.044129353407169544, 0.05472719158616759, 0.0948897340605336, 0.022417766627885645, 0.0037296246051893482, 0.04915395939362146, 0.02411277829519203, 0.015873101431005184, 0.037887008530237985, 0.05679608480403981, 0.0462530525551448, 0.03894513683213342, 0.037473428303435925, 0.04679134806558009, 0.06722361014615144, 0.06578220805573849, 0.12999048847104275, 0.11292186565697195, 3.082273987031752, 36.00873493379162, 69.30966946386522, 97.68372658760318, 91.11203855083835, 81.35728436131632, 54.44314910519508, 63.96482429196758, 69.77915363927042, 61.96776913058374, 48.41134394368818, 35.065212711211174, 13.015242045925511, 35.92874603886759, 42.7918073438829, 59.07239706285539, 68.07693127662905, 70.18301656169277, 57.227019956035, 74.74841225531794, 86.07189486103674, 74.22528574543615, 61.91739020809051, 88.04271328833796, 53.25727539677774, 49.54264571589809, 96.42674815270209, 106.90576014980194, 76.38880237456291, 71.97847366333008, 65.22342266574984, 61.3318980124689, 71.77948397974815, 78.56414887212938, 69.09485693900817, 73.26591322498938, 81.83823754710536, 91.76494060024139, 91.948193734692, 80.57241808983588, 82.60478634988108, 84.37849783128308, 88.69270493907314, 83.98258163082986, 92.68128471989786, 92.26375625979517, 98.37418925377631, 126.28103717680901, 113.50530485953055, 69.2166857565603, 83.8209564455094, 92.85577527938351, 79.55545733051916, 53.51771293147918, 61.8086071937315, 42.07737899595692, 28.913892930553807, 23.84763017777474, 26.74458492186762, 38.50198561145414, 65.03547053183279, 63.31680951579925, 80.62589568476524, 70.34155091931744, 84.73497067728351, 90.58631543190249, 81.30823904468168, 35.63341509911322, 11.651427072863425, 0.09202294877820438, 0.6058911558601164, 0.21340347465968904, 0.1171550989872025, 0.019294359127900774, 0.0876915259587188, 0.022406261902482762, 0.11238016488571322, 0.028364581596707145, 0.04049876314257422, 0.04096807626586768, 0.09190537726446506, 0.07692725517817083, 0.0724207199809532, 0.07658564125097568, 0.02691429671681216, 0.03528071612480187, 0.08130180108691416, 0.04963634197690314, 0.05804629050075047, 0.03775532950737304, 0.045165862707841786, 0.05496101694241647, 0.038311712353700594, 0.018483326740322575, 0.02368909336866871, 0.023264341664710836, 0.040832225894255024, 0.037422537082625974, 0.01773839433407111, 0.033152753697527994, 0.051770279889986406, 0.019934082764290997, 0.07043276012184159, 0.07423725234524858, 0.0076479596487667055, 0.08399032537014255, 0.023798335591451298, 0.05970261472788069, 0.05987670437823381, 0.04414713047745247, 0.07742042427942639, 0.08384101483370028, 0.09066490471483239, 0.05635016034507463, 0.03962821146893886, 0.03398700812531095, 0.008072955064445494, 0.020669841267649206, 0.04581656629940675, 0.02566984242519304, 0.046369153180069504, 0.03814377821981907, 0.016284334555929227, 0.029599371689161467, 0.026683539542700016, 0.047661869095698486, 0.01665701143323414, 0.01828728101005958, 0.023439758562392766, 0.02315914055572883, 0.07310037020473711, 0.010855055072404926, 0.0752861416267772, 0.021791190975495887, 0.07486687702757698, 0.03285241658769308, 0.012312845698738051, 0.008312076961080874, 0.051220584991237814, 0.016139342840160095, 0.0762621146596728, 0.019140825531775915, 0.05122636512462651, 0.03715410753483734, 0.035399268231084274, 0.029888445391289653, 0.019253752637474288, 0.03047484356249052, 0.061946463275460474, 0.050406386745312524, 0.05136658219740756, 0.01649127022603587, 0.011731258559701665, 0.019770388927070365, 0.09505274990994124, 0.021596326935856093, 0.020358899585722436, 0.10218957904726268, 0.00788132822509074, 0.07666130775525686, 0.050347654614597566, 0.08955496588661786, 0.01791147083314436, 0.02781107541053526, 0.046519467291692575, 0.06297443452621661, 0.007661234994884581, 0.06836659034654018, 0.12990415036197633, 0.10492088168018288, 0.006969264640863384, 0.0674346290648945, 0.03464932944024763, 0.029294951330690138, 0.13263801172856363, 0.07099323004724518, 9.0140930298836, 53.08116097604075, 90.35449550997826, 113.38062055649297, 110.61495734799294, 93.31454353947794, 77.77994155883789, 94.66979303667623, 89.44692965476744, 86.86489612825456, 78.66940175333332, 31.83443484767791, 15.37051550803646, 27.272557520097305, 26.939675769498272, 32.620750434937015, 35.52798963362171, 39.12601901638893, 27.861768122642275, 40.74100002165764, 58.375231066057765, 61.98542371872933, 43.89596239213021, 56.17756235984064, 47.88314973154376, 42.79644358542658, 69.59416681720366, 81.41819877009239, 67.71246464021745, 54.49686596470495, 54.695788967993956, 51.14519673009073, 57.33535582019437, 65.56926588858327, 53.86826692088958, 63.561702697507805, 66.29691262398997, 68.17603388140279, 71.50281567727366, 65.96442899396344, 64.73859810060071, 64.8009402521195, 73.33494694002214, 63.86540397520989, 67.22443549863755, 62.69471768409976, 88.31261157989503, 94.3334968628422, 59.082457942347375, 51.52650994639243, 55.65169019083823, 63.16610028666835, 44.13781965932539, 30.950897432142693, 23.65579685857219, 36.511692616247366, 39.75012694635699, 33.25485452528923, 39.1317613663212, 67.46752046769666, 96.66252182376002, 95.07287932980446, 101.12275092832505, 80.70515109646706, 93.86049039902227, 101.09822827000772, 102.55422776745212, 58.91784391095562, 25.299440583875104, 1.1440331729189044, 0.25051547034132865, 0.22188598320128458, 0.1150646442247014, 0.06145104187570753, 0.07180536751665416, 0.08351858374812911, 0.08850914861766562, 0.021479504273062753, 0.035200131336046804, 0.021988862727378166, 0.04801815743708322, 0.06375932224815892, 0.013927939073783497, 0.07136834499936912, 0.012680969140943021, 0.09832226761406469, 0.09083350534520804, 0.02758737390620574, 0.06318719246454778, 0.04385034801558622, 0.05445376331467302, 0.05704104524826812, 0.02538752753377682, 0.058965699431756814, 0.021532251341869275, 0.019369006735242663, 0.06187298012176349, 0.007888557701071185, 0.0176776493073351, 0.04302552796059078, 0.02585678128525615, 0.03838206220778727, 0.05207454703087288, 0.01827733527358261, 0.06462012162251819, 0.021352226425322796, 0.026998200581499168, 0.025220242659411123, 0.061277526791297623, 0.026181045236186157, 0.0511085101583552, 0.08364285087032665, 0.10739082575685556, 0.0573622084583246, 0.14363860531199363, 0.005391223587080716, 0.018097273967859727, 0.05206614304634352, 0.05918509169151226, 0.0239439842276155, 0.022622672164992943, 0.05553698099608864, 0.05309587246888588, 0.019851927495291157, 0.16815904197433304, 0.12146035224319467, 0.0906351268772156, 0.1918231608766702, 0.09683670055481697, 0.11269700352943714, 0.11090552224026573, 0.16179726399000616, 0.10652749829234616, 0.2200004876020455, 0.22931433943731172, 0.1581398070219063, 0.15131070008200986, 0.1313372863636863, 0.1237765501343435, 0.07662491857885353, 0.21929729549634844, 0.08502232241294078, 0.14091626590778752, 0.21325961866926765, 0.1778878989599405, 0.2147428108559501, 0.174252444037026, 0.19336151139390087, 0.20617727370512104, 0.19207957050492688, 0.22145220889679848, 0.10284394070866609, 0.1357802132805509, 0.14895026061323383, 0.24845025051505337, 0.08960931982484557, 0.09657001768749568, 0.21491058411136751, 0.08152496249925706, 0.205031160205122, 0.17239189226060145, 0.23141283812301777, 0.2428489833349182, 0.1183756915552001, 0.14278948877847966, 0.13475066771911037, 0.17624522258918132, 0.19590936661247285, 0.17384525298351244, 0.2897762813635411, 0.13552455441846004, 0.24817133322358134, 0.17949504417277154, 0.14232082682992184, 0.36077400068602256, 0.31292329091698895, 7.208461300019295, 54.12329942949357, 96.71699570071314, 126.48887572749969, 118.81440547204788, 100.70066467408212, 74.39989397602697, 84.58436735214727, 92.62072332443731, 84.03412941963443, 68.81676873853131, 48.53909946257069, 21.492297880111202, 53.035900746622396, 67.24329425442603, 88.12109793386152, 98.28137028601863, 100.00330648114605, 76.9420369978874, 103.8712106212493, 125.74790077824747, 104.76386362506499, 84.29173500307145, 118.05967084823118, 83.24980443523776, 66.82168652934413, 131.0502549140684, 147.2370058490384, 108.07847822866133, 100.1408326241278, 92.96741377922797, 84.22258361693352, 97.28904201138405, 109.64082102621757, 95.68083101703276, 101.94008658009191, 112.6201984959264, 124.27479974685178, 127.6267239355272, 115.22663700965144, 118.32978094777754, 120.93011625351446, 125.05519451633577, 119.6359694388605, 129.99852626554429, 127.54040041277487, 131.03071366586994, 158.07798201037994, 149.63566072525518, 95.71421823193951, 114.27607413261168, 126.60822560710292, 108.48717351113598, 73.25329103777486, 92.01417584573069, 58.54646605830039, 43.50325469047793, 33.596422364634854, 39.98155070889381, 55.14300192556074, 86.48620697759813, 92.20990996206962, 105.0454584244759, 90.54141998291017, 106.78875584756176, 117.17847116531865, 114.5745429685039, 61.073966872307565, 22.386966982195457, 0.5106738119596436, 1.002022289941388, 0.27035169303417206, 0.31455931764456535, 0.1124720801148684, 0.19087049989931046, 0.13850420743467348, 0.23190933970674393, 0.14160127108616216, 0.16790182029287662, 0.2037539077742446, 0.23880322704151755, 0.24500881501984215, 0.19048744061541176, 0.17946798594728594, 0.11172984050767076, 0.27926022307046, 0.2788137163846724, 0.20639455156220546, 0.18640777727048244, 0.12938681118670972, 0.13500456457897542, 0.16325211092349023, 0.17667161180607735, 0.11601342879716428, 0.18563753714965237, 0.111750356342283, 0.14809061803164023, 0.10835412003460432, 0.12348945102384015, 0.12551407585100782, 0.09274860258184134, 0.10192794469936241, 0.13597657693730247, 0.19471570969589297, 0.1630957217346276, 0.19173622521902287, 0.11960016052809455, 0.0963143051992501, 0.2175970706007173, 0.11040569583494818, 0.23488346156814408, 0.21285046643066793, 0.2814888341292259, 0.16093305552438383, 0.19024520361375427, 0.12324907561583866, 0.11085634705640617, 0.11485604614379907, 0.22687252610921863, 0.10302762561027082, 0.12387065637496211, 0.1303776693079741, 0.10656764129957846, 0.15001880005002022], [0.04780476747621452, 0.05165504494441613, 0.013044576494834356, 0.10394156850393742, 0.00783218224833329, 0.06394267390151659, 0.047776142600923784, 0.04257911703579369, 0.059804718926428795, 0.011923800395320983, 0.016217767260968685, 0.05381348234931788, 0.05599668737681163, 0.08435735809466532, 0.06632934039038035, 0.036678554625400615, 0.00962410691089087, 0.030575672224644693, 0.032555936730556914, 0.03274603761852749, 0.061401698152504625, 0.09737042635078393, 0.033051469213058876, 0.07330015061363097, 0.031106925471836043, 0.048886897312777663, 0.12814175743128986, 0.01619027811102569, 0.041085440935867454, 0.03411901273554371, 0.034546125905528184, 0.02921042310434484, 0.016731996119262713, 0.01750255225136155, 0.020318582293487365, 0.05472108969585069, 0.0034621986325815203, 0.021795753029084975, 0.018911152372076627, 0.023045060487704414, 0.01148316768869277, 0.030905840798251094, 0.030519979547769315, 0.10259300094818878, 0.02725112834013999, 0.021964135324402202, 0.13786694485574, 0.24969430069529244, 0.012508277601051717, 0.05086823434178388, 1.486888162551388, 29.544170748802927, 72.17383123213246, 92.02912792082756, 89.07699523433563, 73.42463585638231, 63.9113074733365, 64.937140633983, 55.406628347212276, 42.06277993417556, 55.51634096330213, 24.057516205695368, 24.140615540166056, 64.18575963666363, 117.87797881710915, 62.45278981424148, 66.75695957676058, 52.253937029069476, 52.46150101384809, 58.146874596995694, 77.2308018899733, 61.88627404551353, 52.210135921355224, 47.27924200796312, 64.38700468309464, 56.90495806355631, 54.135148909784135, 58.56564644844302, 44.13925524680845, 45.37958714269823, 40.17745740952031, 46.37117408937024, 37.65828378738896, 33.56341561963482, 34.158470553736535, 33.9604575403275, 39.69657090402419, 39.60435205890287, 42.43066687737742, 41.02032769110895, 42.93660556116412, 43.12106286325763, 46.16635184134207, 42.407975965930575, 34.71760442180019, 45.449068007930634, 52.291772211751635, 64.85764595770067, 56.03366236532889, 43.19618409679782, 65.77550018987348, 60.933247920005556, 60.300812798161665, 52.28684179244503, 64.27357366008144, 79.15784666615149, 83.26507814468877, 76.10468156876104, 46.496595798000214, 60.0859728167134, 52.63916869317332, 26.722248984921364, 22.301812325754476, 22.73898989923539, 57.49935796183925, 79.99335858129686, 77.11042434938493, 73.04793926977342, 73.66241778096845, 89.37238893201275, 82.24472845754316, 43.75809892531365, 11.209259263930782, 0.6084389804351715, 0.3294450495271914, 0.06338744784795469, 0.08640790733719066, 0.047668982222075426, 0.082495519290528, 0.01929136372411684, 0.049799139491252364, 0.03890974740047128, 0.00807724611443137, 0.034716649416593776, 0.09353748162186916, 0.059853729401384635, 0.04738836038497187, 0.05862883524969221, 0.2000099288359765, 0.03529473170337658, 0.02583596859157326, 0.07071848027408123, 0.07954036576613303, 0.04802334002189098, 0.06949548985088064, 0.06877390397412163, 0.09656552075138015, 0.03176837727697867, 0.01976753907999204, 0.06649966471858564, 0.09295831915111312, 0.018183365013570558, 0.0815185426824516, 0.032641098894659555, 0.026162107542697943, 0.015542665684235193, 0.04207838664672548, 0.02939656331774689, 0.03492753043951046, 0.01941700980457808, 0.047125680327054956, 0.05413147012492823, 0.04638081686871667, 0.08968477182450796, 0.02380864138925268, 0.07273160612150546, 0.023807488426926638, 0.010984880162493117, 0.023908081517044096, 0.03168378776359943, 0.051917633071782134, 0.0538572259697943, 0.012486532195321014, 0.06667012694261729, 0.013445346773932538, 0.04829660741492145, 0.04785468193492101, 0.018768692576897242, 0.0459570668247198, 0.04011518291888699, 0.041461245367123235, 0.10289716083676585, 0.058822383533322045, 0.03787973069495732, 0.008990675729188708, 0.02705965998522457, 0.039315057708130735, 0.07879675486155095, 0.018703588509872075, 0.03533228916386443, 0.030562351870861267, 0.04665601863375595, 0.02236573010562889, 0.012808944128694074, 0.01779996865098515, 0.04183723365948085, 0.09432771663752296, 0.10605484502570284, 0.04934317545003949, 0.050102889522789955, 0.0599527845699941, 0.011073382469945619, 0.07882930593745363, 0.03854629996743414, 0.056111305621602846, 0.023645018415165045, 0.029948780560986172, 0.07676768672442244, 0.0870487092423343, 0.035292146156632134, 0.028566371071182435, 0.03587142737101644, 0.04639409700288408, 0.018523251412496455, 0.08696451617945587, 0.06630713150145547, 0.014051657485505267, 0.0278436015885804, 0.05908587564443869, 0.08175204628177228, 0.03779715024715951, 0.07071844196968502, 0.06414196018369929, 0.33906435593962675, 0.072870513183936, 0.024414270282572797, 4.88840336761167, 49.2522059717486, 95.369261464765, 104.52517955533921, 104.017499339196, 93.71316617535007, 86.86684162386003, 92.64790534973146, 78.22564048151817, 59.96037460142567, 77.65473950293757, 28.3793209445092, 27.301035888733406, 48.20638833507415, 68.17108385024532, 48.363302753817656, 47.075494489362164, 49.57764502494566, 49.5679489258797, 62.422214938748276, 79.28074236839049, 67.76722092782298, 56.15760141803373, 51.097465407463815, 70.2716072144047, 64.08399766491306, 56.57473371874902, 59.593374113882746, 51.100673906264774, 50.334470272064216, 41.7809929386262, 44.167970918839984, 33.6426043510437, 30.24704967775653, 29.49657867031713, 28.519906536225353, 36.96104718792823, 37.976599816353094, 40.714837812608295, 44.56930783487136, 43.505937591675796, 45.42509055906727, 49.380455709272816, 43.036029800291985, 37.657813102968284, 48.74700861592447, 51.525093970760224, 65.5540039462428, 53.5967839917829, 44.52363183421474, 65.50365640271094, 65.59902883345082, 64.94421266740369, 61.54306665543587, 71.62955530228155, 74.0967732091104, 71.47845775850358, 46.69636995561662, 29.65307535663728, 35.250870258577415, 29.48812988496596, 19.198295762462003, 22.655957245057632, 34.562706101325254, 75.0131957761703, 106.16316918403872, 101.6836969314083, 93.15024329769997, 87.89438493790166, 98.52880124122866, 101.94379714227493, 65.96074196600145, 25.17751762943883, 3.022876309771692, 0.17683313378403265, 0.11125832105115538, 0.03928305821553354, 0.05096257423921939, 0.027329621708861766, 0.03694088228287236, 0.022058500119695262, 0.03436233375161406, 0.024172144363664334, 0.04622562660745556, 0.03733151051546297, 0.03521102510633008, 0.03220261697987876, 0.01419189754092405, 0.05391390498487219, 0.07843627984966002, 0.07755470417079426, 0.06843790547141144, 0.05705300771120576, 0.026393412469675945, 0.1067660044458124, 0.03521050799698119, 0.039060011716379274, 0.029193795165948333, 0.11305102042012638, 0.04327896899814087, 0.07099929746360549, 0.06592352063425126, 0.09864162668705949, 0.01354771910325414, 0.04343956784014741, 0.05272684025488073, 0.047348722995769595, 0.014693212072034518, 0.05809669142528888, 0.037813506224342895, 0.01488054163693901, 0.01454543658427053, 0.057473628286031954, 0.03810872586684362, 0.026556803702166485, 0.0732212818618263, 0.05636501862036605, 0.03491107487089692, 0.03710787795904664, 0.04195794230327011, 0.012793153141354843, 0.03101008429732775, 0.03169718472617528, 0.01765755290586141, 0.021104776195340583, 0.03099160051093467, 0.10939507264523737, 0.16547958817212813, 0.18075181141255364, 0.17611978335245965, 0.12777707659669463, 0.13973768560155747, 0.15713730436419288, 0.11815962411703602, 0.1430842334464673, 0.1976371400298611, 0.11854682027572587, 0.19618832986922036, 0.08569598949003605, 0.13827571405037759, 0.27013354183685395, 0.14352159304243906, 0.1374882216294927, 0.10627947732686036, 0.10485540414529462, 0.09897343468882384, 0.1754810039194361, 0.18659749128405126, 0.1744322601946131, 0.18352630608264478, 0.11233672003952727, 0.12834440300902053, 0.30487446474932856, 0.09371134527628461, 0.17529869031521583, 0.11660861782729627, 0.0997982202698627, 0.09065217233353084, 0.28444553515122784, 0.1377541920350444, 0.2035424521853847, 0.18886216976229223, 0.11402485606771325, 0.10937377540094238, 0.24825019431450676, 0.14466413657271093, 0.0917150120761606, 0.1385891359419592, 0.09889077380179398, 0.19297992299881675, 0.24042103619825458, 0.11981851856915221, 0.21105714653047825, 0.4723985270867425, 0.11847084733627497, 0.1396485282889297, 3.714834624721158, 51.49053004480178, 103.48190753690659, 118.27576991050475, 110.71709586728005, 93.16213592406243, 83.59785987484841, 86.66362362523233, 72.75993531750095, 56.84303952801613, 73.42327087156235, 35.795750233434866, 37.0636877705974, 91.30068886664607, 149.12830998820644, 87.19656390528526, 95.92451218635806, 74.11836193453881, 71.72178591451338, 85.15308749291205, 110.22864310972153, 90.64169145399525, 76.40083620625158, 72.1490732316048, 98.4434740005001, 84.83402621361518, 78.71358333095428, 85.25687340767153, 70.25558040988061, 70.3525649347613, 60.948333355688284, 69.05833967270391, 56.841333296991166, 51.75068124648064, 50.47208270718975, 47.773103713989265, 56.670396404881636, 58.728189468383796, 61.94872210102697, 63.73483611691383, 64.26207327073621, 65.31608081633046, 71.03911307550246, 66.12716813241282, 55.53363861576204, 70.7583184396067, 78.48072005856422, 92.57425892737605, 78.65963505160424, 68.15566893546813, 95.29478349993306, 90.25278060666977, 87.9287370558708, 79.56507498218168, 93.89903945307579, 109.3278080417264, 117.196757255062, 108.79008247006325, 67.1243287670997, 81.04254553394934, 75.11702875937186, 39.34573842633156, 33.5289458305605, 33.9804498610958, 79.00656084860526, 108.00518481962143, 101.61593406431138, 94.51021532858573, 93.60358299747591, 113.84374264747866, 114.77882785181846, 69.03263245859455, 20.98045014565991, 1.7754867216271741, 0.6406311594670819, 0.18778315024270167, 0.19508974446404367, 0.17784783256150064, 0.19348747157041105, 0.13012568766791976, 0.13902621974627818, 0.18404067283676517, 0.14708733396424403, 0.13667434514049562, 0.17272131006804206, 0.15358968908267637, 0.14909810026086148, 0.14459619989558575, 0.29147760942578316, 0.1500180952491299, 0.22549647897962602, 0.16828296435696466, 0.1103040589500339, 0.11847060984901844, 0.23400498854537166, 0.15760944435192695, 0.26180402105373723, 0.15432384646227285, 0.15540406107902527, 0.1981656640888222, 0.2228297269152057, 0.14376477999312265, 0.18050988084606587, 0.12219352136936881, 0.15256762053937684, 0.17610219397371815, 0.14859429019833767, 0.1582680041751554, 0.20040838648715328, 0.1794058408948683, 0.1407715978641664, 0.14857947405788208, 0.2392813271933025, 0.19721099596110084, 0.09463618194023449, 0.2644901398208834, 0.20044954073044563, 0.07171553604665303, 0.12781450765267496, 0.1207035722871942, 0.19137568892009799, 0.19298248173248386, 0.1407201780426887, 0.1372220367193222, 0.07042759668923194, 0.16687202958330033], [0.021676385039163214, 0.05234846559863898, 0.036104118917137384, 0.011903406177166731, 0.0403714929557135, 0.017269153989130454, 0.05341573332947108, 0.05705674622027625, 0.019106456912272883, 0.012105878427504532, 0.03688349463646451, 0.034176913660860835, 0.04514796306349097, 0.03377131223979016, 0.011221864673819755, 0.02140748817774077, 0.02378943939543059, 0.03179503905196344, 0.03566488240575118, 0.013091119209064112, 0.008736795148692064, 0.03026053621133249, 0.07336739015074507, 0.05756354402570475, 0.05743999319571642, 0.050546906422823674, 0.027845294642893058, 0.048152203671634204, 0.03982554805735427, 0.06780711633543815, 0.01534252521401692, 0.018365324302125844, 0.024486721132791812, 0.08058119580269822, 0.0364006792135056, 0.04692819435149432, 0.028040691113640225, 0.03420875610543355, 0.10486574633227241, 0.055679580602314205, 0.011844231630675496, 0.04227187364332138, 0.22554863424551105, 0.014624768819269395, 0.0776123216435794, 0.08257405862452523, 0.04336081400153138, 0.38176575976033367, 0.25770220244603775, 13.175111970593854, 59.584564470475726, 91.83487646041378, 82.52449543245378, 74.73650393947479, 65.27247190475464, 57.13192601357737, 52.9871613748612, 42.83289024906774, 38.63975494138656, 42.86748947635774, 30.054276950897712, 52.320028966473, 55.22606203632971, 45.11994584914177, 104.65952857848137, 92.93079453129923, 63.19747924804688, 53.287348208888886, 54.36680016979095, 42.1768150021953, 26.241131059585083, 18.54429937178089, 9.356246282977443, 8.07722903067066, 6.0940703365110584, 8.470106374832893, 9.80682267296699, 12.154279831917057, 20.3368245017144, 10.979044571999582, 4.955510218297282, 3.42942581061394, 1.0853795202509051, 0.5910267212217855, 0.46388756603963915, 0.5819479051616885, 0.7304993404015419, 1.6064421279776482, 1.3324509657198385, 3.0068816196533943, 3.504261201427829, 6.048270290897739, 6.2664741950650376, 4.480269964664213, 6.11972705010445, 3.8852000765262114, 3.1964833553760283, 7.406288491141412, 15.292769228258441, 11.408870643185033, 12.303035720702141, 17.517711154876217, 23.421845128459317, 30.922142536409442, 37.35007570635888, 46.448244740886075, 49.71183715328094, 72.5611888208697, 78.94610143476918, 79.22048691780337, 71.01342939561414, 126.68392735142862, 83.35041323015767, 48.424103413858724, 24.055768789783603, 22.87850860626467, 60.64889569436351, 56.81541819726267, 68.54191257107642, 75.10286900304979, 74.1211546621015, 85.65909677936186, 79.80824624338459, 55.832903692799235, 17.138971013407556, 0.9340043462091877, 0.6158409219595694, 0.12782840448762142, 0.07713849626241193, 0.0842979173326204, 0.08753684514592733, 0.045272927325699604, 0.05701835372395093, 0.07592269940482033, 0.01618081309472121, 0.025856313971622337, 0.09036770856548702, 0.07837763581905635, 0.0075097277013194425, 0.01871742214256477, 0.0625505733994707, 0.041611609274461385, 0.05734787112282169, 0.029152759666284247, 0.09819236974562369, 0.09318423847998343, 0.10626633891895895, 0.045316054245396975, 0.06576956760498785, 0.11410840561673527, 0.05119359571366541, 0.03995240072629625, 0.022270576239773826, 0.010323976110216352, 0.0613892377324162, 0.00958234171247891, 0.02847941626133698, 0.018792636654970628, 0.02117999645340587, 0.05466357947537496, 0.057658558080513636, 0.02272473805914483, 0.08781230738086086, 0.017955042083837816, 0.04660990397115389, 0.03507507514328726, 0.050965201920799674, 0.022127679774477597, 0.024167712545022372, 0.007155662451329972, 0.029267688176684806, 0.012662846373484261, 0.04779996027448966, 0.08487166356175177, 0.003240162172474929, 0.055620446275438995, 0.038830572213496894, 0.07557607526260038, 0.008725127629605273, 0.02168325301740439, 0.0016388614922987238, 0.021151746961198026, 0.04887246421628422, 0.03956239302492431, 0.03715707995598355, 0.0642276164745131, 0.04400030972676412, 0.05058695366906543, 0.07019786224249872, 0.01950906484477943, 0.0651928336329518, 0.014900704113496168, 0.016710583961779074, 0.020748911117534005, 0.05548014110254665, 0.09348992288352982, 0.02123390989107711, 0.009356431959707652, 0.029974086360344966, 0.05641315575508822, 0.06768586759966227, 0.08005172179471101, 0.026171365715262872, 0.02717345468549719, 0.04653548235974966, 0.009677487917454734, 0.0018213951073947454, 0.050891293588304715, 0.014414347449107277, 0.06765181499142801, 0.02452981166331278, 0.031500577836507754, 0.03634749738980205, 0.02172879311406324, 0.0622079290840174, 0.04325454994555443, 0.018324599068071094, 0.1286627202024383, 0.19347833980235363, 0.056319585776016604, 0.12198555148056439, 0.18940955490594913, 0.026249052776444345, 0.4247186549248234, 1.2365034174534584, 23.999824024015858, 81.76852918440296, 105.73542687200732, 97.61315530346286, 89.75531424245527, 86.01577358861124, 89.8429713710662, 80.36848621983683, 62.46123467722247, 55.167575574690304, 27.077474517206994, 31.314273649646392, 35.1757647145179, 25.827315122850482, 44.57596409705378, 93.45273648538898, 92.22747433570125, 63.92779711754092, 57.99638894296462, 55.89796796921761, 42.57066411356772, 26.40075191374748, 17.063983140453217, 7.658898445867724, 6.9573246855889606, 4.870866450571246, 6.25179325380633, 7.326417757618812, 10.260384967250209, 18.722855467950147, 10.277963069177444, 3.002173794854072, 2.022724745254363, 0.6615884445848004, 0.4243563259801557, 0.07946425493085578, 0.4298876340110456, 0.16830939439035233, 0.8943527997020753, 1.0036995934863244, 2.841829998839286, 1.985723801678227, 4.414103011931143, 3.9794955715056393, 3.401964806741284, 4.227871817927207, 1.8424408450242014, 1.5816588771920053, 3.7633418411977835, 11.110462604030486, 10.103046932528096, 10.278814223504837, 15.031371693457327, 17.791074860480524, 25.583777120036466, 34.00767111009167, 47.93085751994964, 55.320383271863385, 69.86377485336797, 67.67710055074384, 60.15835623587332, 54.21984464891496, 83.2809009859639, 54.68331583084599, 31.800490656206687, 28.68612873938776, 43.219565345395, 91.11319172766902, 87.34803799659976, 89.18173820741715, 94.1405946977677, 88.76680635636853, 97.61874075858825, 97.60053311624836, 78.16361211961316, 31.390842237780173, 3.360761778969919, 0.3847015619037613, 0.07210295437084091, 0.032599174733003305, 0.050106804232083024, 0.10262932117667892, 0.06486324728616784, 0.002779606631168375, 0.06161519919612235, 0.020195657740377133, 0.07996419624936196, 0.06451913591233954, 0.060390607649160016, 0.054332939757695126, 0.025711483134317304, 0.07829550353269424, 0.03200109180573735, 0.03780455448694768, 0.042563496503017606, 0.016966909320364078, 0.014726832798201472, 0.04923106997363991, 0.025437428585944638, 0.059637121871233954, 0.09561492821141597, 0.03310056012724677, 0.033421650558950446, 0.03264906237863245, 0.04208366499252377, 0.08551938324085168, 0.0711450380303206, 0.07336096267306036, 0.04392049102593334, 0.0329654413696018, 0.04259195666940462, 0.023353257659642447, 0.01569932491909112, 0.04797934742283918, 0.03700899132978051, 0.06037453129406899, 0.030583913415490143, 0.0562641746364534, 0.05486132592082985, 0.057607620894428224, 0.07008746131173066, 0.028175957343210618, 0.025091283248677373, 0.010631215672249035, 0.06838237175778036, 0.00791479764889265, 0.09273606172252087, 0.19092089316296965, 0.17265458380983723, 0.11546597470559421, 0.06619909012149419, 0.0934463937676722, 0.0698000404442991, 0.15759717162337997, 0.15927570090899545, 0.12821574620301687, 0.19152263990573345, 0.08030335869519942, 0.13774559652853396, 0.1563451388069699, 0.1805613925980945, 0.22939084097743037, 0.09424816606746567, 0.09417390150408592, 0.10435344035466833, 0.13018896653046533, 0.20275558795659773, 0.09855406283731423, 0.08752221286657356, 0.23610396220559077, 0.17167581455601802, 0.1591495875149004, 0.1714213661128475, 0.10331352196273305, 0.15175426499016825, 0.1683137610915207, 0.11261643406244055, 0.15581010300065243, 0.10138918570573292, 0.09121065043033132, 0.2571735098477333, 0.1799068164320723, 0.13621124499026807, 0.11438192964922037, 0.1958709702857079, 0.22815845065539886, 0.06785304330649876, 0.07997943373817591, 0.21192837236148698, 0.28643583157850855, 0.26284347979291794, 0.16864956807224982, 0.2317631854525497, 0.17569144827223596, 0.6356837636520786, 0.9283827930208176, 23.829500982838294, 87.69160624473326, 117.67788302513861, 101.39086061908354, 92.81208007566391, 84.49509420702535, 79.95411134535267, 71.47209567408409, 55.74692926099224, 54.548598104907626, 59.62323904037476, 45.63707897740026, 79.1478838459138, 75.22589022113432, 61.97312316586895, 127.96829177487282, 117.42724357112762, 88.17066884809925, 80.77728348393595, 81.67410204487463, 63.66845392411756, 42.16962137529927, 30.51093105346926, 16.863330371918217, 15.202517451778537, 12.723001933866932, 16.495468924122473, 19.065115605631185, 21.37776270989449, 32.392580278458134, 18.862078036031416, 10.147410900362077, 5.796357537469556, 2.6042052142081724, 1.543017524865366, 0.8830025023029697, 1.6408771060166822, 1.3847391018944404, 3.77800194486495, 3.0829177460362835, 5.544317797307046, 7.313640146486222, 10.033424861969488, 10.846660656313743, 9.709529261435232, 11.555153477576471, 7.203335742796622, 5.3508552235941735, 10.960815356623742, 20.936827505788496, 19.451196462877338, 22.25667565099655, 30.86373059980331, 36.91870127954791, 48.65450343778057, 56.86193358513617, 70.79569862734887, 73.59237993917158, 107.96154452908425, 110.34414122181555, 111.1934441904868, 94.16317970521989, 150.18126241622434, 111.40040413025888, 70.83422414718136, 40.950081963692945, 37.574733380348455, 80.46077958999142, 77.68502020066785, 88.95514288256246, 96.1576343351795, 92.15242370482414, 110.15156853583552, 112.57366349620204, 84.27468053756222, 29.088716891504106, 2.4910926386233303, 0.7220663058180964, 0.2760103861651113, 0.24308915189918012, 0.17758811343341105, 0.23727114312350753, 0.15648231451069156, 0.21546789775452307, 0.13206133138268225, 0.0669366565923537, 0.1836345696281041, 0.17077075828227306, 0.19401938173799746, 0.15857609409478404, 0.17938969176142447, 0.1507870023769717, 0.12793726558166166, 0.12251370015644258, 0.15384920902790564, 0.17732353730788156, 0.21124370426179903, 0.2454379315097486, 0.15835778967988107, 0.1550771866834933, 0.2344676596863616, 0.21888451200098763, 0.20095134364260783, 0.10682059587129664, 0.13848055063957168, 0.15632506730335374, 0.16812678967272082, 0.1527970945162158, 0.11582212132071296, 0.19145225174725058, 0.09146987926214935, 0.1825697533786297, 0.10976846389953168, 0.16648455763295775, 0.17142746417272478, 0.13874892656120563, 0.2416933550228996, 0.22946579501994196, 0.22659350156543717, 0.12873090202769927, 0.1256654318422079, 0.10022318456321956, 0.18803625037112545, 0.15853702361064573, 0.21897245889469502, 0.06879094943043686, 0.16899732602459772], [0.05049686172917005, 0.07437316400389518, 0.0289565070922817, 0.038954900622728376, 0.049368667025719924, 0.03136858471759385, 0.05979536499287333, 0.032203049819555976, 0.05857738095425791, 0.026367733202454065, 0.03212450090945969, 0.1229022676125169, 0.03530457593320358, 0.09900656033066974, 0.027799174234631564, 0.07514885100986689, 0.024712502565835754, 0.06382590294965813, 0.01991847180761397, 0.014915815197802601, 0.015096240395289517, 0.05439326535129259, 0.017477263688981053, 0.0058056321464509016, 0.02421414896455263, 0.011698065885162402, 0.039570639961429184, 0.01748733582996553, 0.005688932057725447, 0.01038700312135681, 0.05603609110919699, 0.03189495606948772, 0.0830717399836548, 0.020696690734175426, 0.05650019483460535, 0.0572992819962242, 0.06918941474249286, 0.019208124440704143, 0.030436318915998264, 0.02514659479681042, 0.05785862960281873, 0.0828901924673588, 0.0790570791991007, 0.016370944626208757, 0.0660515109437608, 0.25337755950468205, 0.12833854243639978, 8.158499069752233, 42.96778840403403, 83.4093350748862, 81.7438574760191, 76.01926803588867, 74.82875024118732, 58.327417373657234, 49.42741824734596, 24.87723077497175, 28.56753783841287, 30.169400476640273, 39.776704926644605, 70.42912175578456, 52.75156813283121, 61.53319797208233, 81.6466611431491, 60.88069992680704, 41.77991428682881, 38.50088342543572, 23.346788614026963, 17.188218332106068, 6.65023644124308, 1.960657159647634, 1.2566188025859095, 0.25147157871434767, 0.0313421604298656, 0.16595776493270553, 0.022403622729583614, 0.19746532183020346, 0.18024927305598415, 0.8860801532864572, 0.3570445620965573, 0.23773980507206535, 0.07373383298756615, 0.09558655231470063, 0.05622887330490255, 0.11060073415959075, 0.08937118139358298, 0.07703479860098132, 0.0687906506561464, 0.0741258095349035, 0.12789153779346135, 0.0188873979007645, 0.08854536159384636, 0.05133764705650749, 0.09036642919865348, 0.14411753283873682, 0.08868616089344987, 0.26004404130001224, 0.07969686220730506, 0.04834657549978264, 0.06830963170936993, 0.39989645622910996, 0.6375240907073021, 0.5189606463236194, 0.3016680803510451, 0.5759632875842433, 0.9898083356599655, 7.716599943176393, 15.829904483210658, 34.71046963045674, 51.80248398934641, 61.70987329175396, 56.2608931141515, 68.06981609713647, 83.98562539008357, 62.62261275322207, 49.23338251729166, 38.45177535087832, 21.999485838797785, 18.491839631911247, 38.82409065000473, 58.616590192241055, 62.88614896035964, 63.16688868307299, 69.74003976391208, 78.58842834349602, 79.86557560582315, 47.35645386480516, 14.090353904231904, 0.5516383412384218, 0.267836902170412, 0.03728574825330608, 0.05945824034091446, 0.12744829464223117, 0.09535592920597523, 0.040219650498681495, 0.037119089655818484, 0.07986804455398552, 0.04078795750355048, 0.06601291543413555, 0.03100454931207482, 0.04471645254882113, 0.025221171541019313, 0.04414756714756932, 0.05043827898560032, 0.044913264367008404, 0.04891389042078968, 0.02526983919162904, 0.052911049926713596, 0.019865113783687837, 0.05934520023724726, 0.05032669444898925, 0.05221757564633604, 0.06249923018678542, 0.03871460948439856, 0.03830885867618265, 0.10902960274008014, 0.06720306366802224, 0.04790805911104526, 0.008602950012221212, 0.04416837792603239, 0.07682882820165927, 0.02113665311386989, 0.014535905492882577, 0.07638302631676197, 0.02932437868308156, 0.053706318140029914, 0.04995738261289174, 0.028083193671679305, 0.029881791917667277, 0.0377930325245665, 0.009692065613043886, 0.02651980357064355, 0.04080501828162421, 0.06196791373734033, 0.09173271636809073, 0.011113733278527375, 0.006165417679209984, 0.015860627604378088, 0.0666155431780123, 0.0950560900532911, 0.07045509158483437, 0.035999930959435246, 0.02453135150004058, 0.018341431934987346, 0.024342918768525127, 0.02945523416142791, 0.014477424255962816, 0.1056937954478687, 0.06916401892780297, 0.005081064272446619, 0.05621489220028443, 0.02143723345662077, 0.10623090735246098, 0.01675813503923916, 0.05036531677169185, 0.010878121022195106, 0.1095045006443416, 0.04402123924885546, 0.03838174045085907, 0.01361561268793359, 0.023885742393172076, 0.073941090414601, 0.05350612787409656, 0.04561052695217152, 0.033776582924709204, 0.013369509815088203, 0.018247415709699837, 0.05435123776776656, 0.039413289332221595, 0.10522966107894337, 0.039749444882956245, 0.036475552816785155, 0.01934389054264513, 0.11737243813132087, 0.03441880592295239, 0.026512763222619414, 0.017847665285150853, 0.0686607374659469, 0.06395657456690265, 0.08378367315256789, 0.07890145609816236, 0.05447586878172813, 0.3985585602781465, 0.3500831517721376, 16.80341028398083, 60.16766402029223, 104.25910949707033, 89.9840590261644, 97.61008016524777, 95.9450497165803, 91.48530698591664, 73.58144437113117, 32.14357056925374, 34.359460646106356, 21.892830710257254, 16.980701415769516, 41.376694633114724, 27.965626601249944, 44.68662592672533, 76.83115943785637, 60.39513795606552, 44.65445072420182, 34.66650378319525, 21.791723774325465, 12.690549223653733, 5.161169892357242, 0.6623634804160364, 0.21394546654435898, 0.1631405838434735, 0.06745350547134876, 0.21723097250346216, 0.07585816415807894, 0.16310025697513936, 0.0820870488701809, 0.45207890291367814, 0.20876905640527127, 0.313329991674231, 0.10490289393572078, 0.10926725087507118, 0.17590515615959323, 0.29506437180023043, 0.293039723990425, 0.2063200878159654, 0.23369976379457982, 0.1536826155478916, 0.12286336566772192, 0.1656519119898158, 0.16762561495265654, 0.15690695704712024, 0.12412649143727557, 0.15854797866796294, 0.09673686397652473, 0.25398966375618215, 0.06981787497117635, 0.026027613146711263, 0.08561254719332342, 0.09014232549816371, 0.3236889406558006, 0.22702205115027968, 0.3204431793382091, 0.4515565841669037, 0.10079856255962964, 4.532577222393406, 12.657067871862843, 29.318542288195705, 47.039624414136334, 58.16521952229162, 56.14077052762432, 69.88759148505427, 81.53264568698022, 57.61547580842049, 46.74207341286444, 26.823008791092906, 23.747607777195594, 26.765169520531934, 59.97145921953263, 92.30546674420758, 92.40409081982028, 86.39429799972042, 89.29126647210892, 90.79238891601564, 96.80351534197408, 70.89857455222838, 26.641218700716575, 1.3266302909581893, 0.2782037265358433, 0.027820875590306618, 0.09723342684728485, 0.08896513947195585, 0.036916654752266985, 0.018799033489138372, 0.05630407632598954, 0.040683765715408715, 0.043874537241795374, 0.05303976035887196, 0.09936148120510964, 0.07022356449235832, 0.029755822165058027, 0.08017585868196142, 0.024631410243830854, 0.02996257397406284, 0.09423790815015955, 0.02986336750308833, 0.013354920628180188, 0.0022686010878157593, 0.038161616577135946, 0.057149799089998975, 0.04060368654468367, 0.05699948880881552, 0.07444563592153211, 0.07715469902201046, 0.052206846584956494, 0.06237452639447105, 0.11052656152676191, 0.05947141322277247, 0.04109175733080314, 0.0580647302370879, 0.02526024968603686, 0.08027360384022036, 0.04144539117753025, 0.08242393603488322, 0.02910196229124502, 0.0865535100080794, 0.023006087679776455, 0.06332260999648322, 0.020503799370940656, 0.04996741070382057, 0.02633095523642917, 0.053034340286807674, 0.024166414025990714, 0.04112043200180896, 0.01887226191860053, 0.034785141507464076, 0.20312502619720277, 0.17387077903314946, 0.14580425926514212, 0.13952255279066103, 0.16676290801936583, 0.08020716103454752, 0.1317922353383995, 0.11077758555691089, 0.18820238419838492, 0.08485913036331054, 0.24639675183401955, 0.20589307040697147, 0.14664772206977492, 0.16218908731975865, 0.1012200871182065, 0.15544113973456045, 0.12388436934880673, 0.1528984479485981, 0.1356580835436621, 0.15688933702486177, 0.15162885639696352, 0.12868409405552572, 0.09201570924731994, 0.20558308058929062, 0.2124390006065369, 0.12331160371221843, 0.17434394557870206, 0.10645802943937241, 0.1113490641657864, 0.12615280931875592, 0.12740024560762028, 0.10828833606454635, 0.3143930765649965, 0.12368078914380844, 0.25716921975535734, 0.14348744084277462, 0.20702346378276426, 0.1731988126712461, 0.14579909583253248, 0.07218860300077547, 0.13645202642486942, 0.278816290440098, 0.24979435177820347, 0.1405134109119254, 0.13918924325656507, 0.6569663603459636, 0.3384661944883485, 14.985889850124238, 63.92974653551656, 113.00364940397202, 102.75026782866448, 97.47924558577999, 97.33423556050947, 79.72238556031259, 67.9833278348369, 35.09146513477449, 42.250630086468114, 47.07997775846913, 54.56381297880604, 92.82688310069423, 72.68544950792867, 90.07526197741109, 116.34773669704315, 90.80720763052665, 63.313408820859856, 59.20804046815442, 37.02709205688969, 25.708326101303104, 10.470845622401084, 3.4796610762996063, 2.410973079742924, 0.7877358529836901, 0.21846426680924433, 0.3060214515895613, 0.20371621624837, 0.5345298818522884, 0.5494931111893346, 1.6580029096334212, 0.8226368576288224, 0.6979724728772718, 0.1595709971602886, 0.368363878900005, 0.30838284100736346, 0.7099767642155771, 0.5840126040481752, 0.36776865922635604, 0.2816429403760741, 0.2624726319505323, 0.39814928546547895, 0.29054975437541164, 0.36641829136398535, 0.3549531727067886, 0.31618204508577624, 0.2557916864151916, 0.14420068402203823, 0.30575445462619105, 0.2873555967403997, 0.18606219500783952, 0.20409363712514603, 0.6991205015970815, 1.3035112282922192, 1.2955456299166526, 1.465841704799283, 2.274731758140749, 2.8746006661845795, 12.73506812510952, 28.323744881537657, 53.334467641768924, 75.79200590810468, 93.39821553999379, 81.27102359648674, 92.35069951703473, 104.96561465724822, 92.5340703225905, 72.99862723196708, 56.584147407162575, 34.801958914726015, 28.481702650746993, 55.55023024159094, 79.65703102850145, 84.79062126528832, 82.53727451447519, 89.62349122570407, 99.06550699664702, 108.75520475449102, 77.18024253845215, 26.07223576115024, 0.8283448255350514, 0.5157302680515474, 0.15902146697044373, 0.2620428259814939, 0.2051985044513018, 0.11779082172940816, 0.11516348488869206, 0.13371416607931738, 0.2819730016973711, 0.19689061799116675, 0.17883964063179109, 0.18701894689471493, 0.14499098032472596, 0.17550467603629635, 0.14471670552607507, 0.11557005541098696, 0.13430183212603294, 0.20042842734725247, 0.19681195608310162, 0.18642941159346413, 0.18453962590184905, 0.15364510788311883, 0.10382566706187303, 0.20090865722346693, 0.1046868418193152, 0.15735347905466635, 0.17584569241491058, 0.23666211854546304, 0.14273788509590013, 0.22227811296620678, 0.11380377075364513, 0.21568974149563622, 0.1578161348738978, 0.16014053756671567, 0.2181899307235595, 0.17946148952168806, 0.16473413865652778, 0.09726947128412225, 0.14881469369415315, 0.13262665830552578, 0.16334794852281773, 0.12792720684721587, 0.159573755076816, 0.1654979436387939, 0.1140726905977053, 0.16962280617125575, 0.17461599872237252, 0.1622787655721749, 0.15166129255967756], [0.05696813666051435, 0.026192977055606824, 0.004177137020780075, 0.040637478683023684, 0.07861968895961201, 0.03423259676163716, 0.061816753098560925, 0.10106810293490849, 0.016463286949381713, 0.04580036737024785, 0.01940215152928666, 0.01817020170781161, 0.09051243789614209, 0.021265516763613112, 0.0217431572626435, 0.05173470276678282, 0.014883830069353985, 0.023783852699242776, 0.03003520293972425, 0.029525911518102212, 0.09401094694171222, 0.02812095414546709, 0.0523829204030335, 0.02850612974725664, 0.05423724005419401, 0.0361138750468531, 0.04677830541866922, 0.035017756444792596, 0.04743840124818587, 0.08368464096659615, 0.032782706417023175, 0.03488810755492699, 0.024245617941262263, 0.017979953347915606, 0.0553492128458475, 0.031440704234785614, 0.087450698558842, 0.03508696099743247, 0.03189525484377819, 0.04877537406320053, 0.09496559208679585, 0.05739310478431083, 0.2690527449932791, 0.12676176494888722, 0.7165272449774127, 8.552903686800311, 40.91738900830669, 75.21000462193643, 82.28507395713561, 76.77779951403218, 84.51986005229335, 59.404127597808845, 60.046780493951616, 28.82958942844022, 23.50235373743119, 63.25155304324243, 50.32496244676652, 66.60816054190359, 98.32253948334726, 55.117192729826904, 66.89276772160684, 64.36938147391042, 29.766006277453517, 17.848986694889685, 8.021057257729193, 1.884690165039032, 0.32784319032103787, 0.017368672640934106, 0.08612428626586353, 0.030331437648724646, 0.034928273544797016, 0.13290448775214533, 0.04358571060302277, 0.24906070001663702, 0.10304281713380929, 0.052830315750813296, 0.16900419017239926, 0.09767478542222131, 0.15251420888929598, 0.055508968991137324, 0.1392497948461002, 0.18874927904577027, 0.1907576091827885, 0.1168482501300112, 0.020676450691215938, 0.1283896251791908, 0.08762917406256161, 0.18076629047432255, 0.48267164357727577, 0.6554482805152094, 0.16018858660132657, 0.04207415018050421, 0.11155497327807451, 0.08828316034088213, 0.04165346065776483, 0.09990761762544995, 0.05458132078450534, 0.09611819435151354, 0.08400151025383704, 0.07251812039964622, 0.06118974460649395, 0.04576901905238629, 0.07626003856139799, 0.1559079630721, 0.04002381544259768, 0.03382564319538013, 0.08576069327612078, 0.2869313066044162, 2.7695728309692877, 6.877062205345401, 18.593570224700436, 35.93289198413972, 47.20938459519417, 42.96739224464663, 42.58855012155349, 62.57160625150127, 69.23730173418599, 56.79956789939635, 27.288441158110096, 18.49045503524042, 29.449945611338464, 49.70892675461308, 42.97897500376548, 63.107943304123424, 68.69345726505404, 83.26196378277194, 72.12895147262081, 35.59434044745661, 8.458298079429134, 0.19549045441371782, 0.2238686647145979, 0.043813702199728265, 0.041557826071737275, 0.01599484812393184, 0.09592025255363795, 0.017034648729848768, 0.08535550937296883, 0.034881369811632944, 0.07579576629664629, 0.06914266805735327, 0.03715071376533278, 0.050986529808611646, 0.01093744399822167, 0.023101358374039975, 0.04590095471470587, 0.03663495273119019, 0.020891575841233138, 0.05494912342739202, 0.029695448690965295, 0.04203180084004999, 0.04668830157888513, 0.06727457031487458, 0.03040268382568273, 0.04972980470366536, 0.04193711620304854, 0.04648266442781014, 0.03538356725907615, 0.04504912622993992, 0.08059911459924714, 0.05358494299974653, 0.031598265538172375, 0.08106133374836176, 0.029995496602608796, 0.024794964270005306, 0.012844385271291099, 0.019461360549734488, 0.0825149013150123, 0.014204550440603448, 0.07747385891214495, 0.0347868460530956, 0.009848527580259309, 0.028293498213432973, 0.05985897327322633, 0.05769474424361702, 0.023294634696456696, 0.06735435071130914, 0.03948218744969176, 0.038000109920939135, 0.020395913123784047, 0.025774943942744887, 0.03766035375696036, 0.0740398314871615, 0.11038319583261207, 0.055622376817008184, 0.023662368391430186, 0.03857455712052123, 0.017834425370599476, 0.028317574441673297, 0.03839928003388547, 0.02141759862312146, 0.006939301505729917, 0.026968558724488945, 0.028864455882519967, 0.05329299838312211, 0.013642993627957279, 0.021475811729267723, 0.02913960210618473, 0.07629396093468513, 0.032428195399622765, 0.056247496902341806, 0.037608485774046956, 0.05475747504181439, 0.053553077572536086, 0.05756753534379025, 0.08688830575274845, 0.09262143964729003, 0.05878839604256134, 0.047720624209051175, 0.04528710378273841, 0.026011854718108813, 0.03624196111735317, 0.07976627743412411, 0.06511493781281096, 0.05104276066225383, 0.11059607634501112, 0.005949161591894564, 0.05211233431773801, 0.05426114199743156, 0.28525973339715316, 0.20085668581868374, 1.6390411916279024, 16.008993041130804, 61.09772466844129, 94.40899464391893, 96.40513589305263, 91.00694256444132, 107.64926110544513, 79.24892410155266, 88.72721395184918, 45.02064712585942, 32.82107176319246, 41.66325515316379, 24.24888864640267, 42.04727088251422, 63.846968835400006, 52.04576899928432, 61.61090404756608, 65.81632814099713, 27.29721942255574, 14.709589269853408, 4.884607493877411, 0.8470582084790353, 0.19099111278210917, 0.07618760494815727, 0.1439754388505413, 0.12596092727636138, 0.10708445187417731, 0.11097523624137526, 0.08478056038579634, 0.2856620827749852, 0.20830120650991318, 0.11110735576479666, 0.0894071951869034, 0.05740316734919625, 0.0851133336583453, 0.0833542655492502, 0.20691296326056605, 0.18030135171307674, 0.12932086633818765, 0.12658654531884578, 0.0643628846193033, 0.2735973624212127, 0.09474315845798101, 0.17040899624266934, 0.37430139739186535, 0.42291415014093925, 0.11214968733369343, 0.17812080501068026, 0.1333620414258011, 0.11720353106577551, 0.1826153202883659, 0.05428419741351278, 0.08073855026234543, 0.18623015212435878, 0.04416614094929349, 0.20613754438536785, 0.02576978625579467, 0.15606688035111274, 0.1071624089813521, 0.08953914617098148, 0.08073587661548969, 0.09897107513801706, 0.39497758952840684, 0.33411414092106206, 0.5455422425462354, 3.885873498455171, 14.672749388602472, 33.76184440428211, 46.1868776044538, 45.780363159794966, 42.8052532288336, 56.027786654810754, 44.07653262538295, 37.93146510278025, 31.210744650133197, 34.70978713804676, 47.389676340164684, 75.34594612736856, 70.83603628220098, 88.38033522329023, 85.78599329917662, 94.37648603993078, 92.86757376886185, 55.709407867923865, 18.724426377204157, 0.657248035553963, 0.11666695542273023, 0.03086600805662813, 0.021988776542486686, 0.07570956608340626, 0.13287422727913628, 0.022408788077413075, 0.045860267785047336, 0.07249301569836755, 0.02102015220800475, 0.09793871037301519, 0.06564556095268458, 0.025952228179742253, 0.05104806199068985, 0.0182829353763091, 0.04363002112856315, 0.10068847572491055, 0.023914334709726037, 0.014715436282717894, 0.041150343904812495, 0.055954571693174304, 0.06461355624900711, 0.014015809358698467, 0.0397743848753312, 0.06790853105485439, 0.0532709465422217, 0.08915143673338237, 0.07443775287679127, 0.029768008708713517, 0.07537880762209816, 0.055746387299751086, 0.017603673942146764, 0.05470119822289675, 0.026156522761729938, 0.0702155052473949, 0.012904604570189071, 0.037929671966741164, 0.03810411401753945, 0.01766443429064126, 0.04828028208125503, 0.04055539619237666, 0.037986297355664354, 0.03390354667640021, 0.09596052579581739, 0.039652335577674454, 0.041235015772643595, 0.07020970596180809, 0.15106622610361348, 0.1126539723707303, 0.0768956080860188, 0.10936806038502725, 0.1459013838921824, 0.17325204046022508, 0.15657770777902297, 0.22050541615293873, 0.14179953464096592, 0.14607485684175647, 0.12540599616665032, 0.17235985446360805, 0.17777329220646815, 0.08793945499365369, 0.12354516859857306, 0.10861383916269388, 0.08252589467672572, 0.051706978044803106, 0.24355735419498337, 0.07366279365434762, 0.1351773633711761, 0.17229672881864733, 0.1431024663390652, 0.14920751293820722, 0.15267585344131918, 0.2611680148589996, 0.11111025157715045, 0.1645163858249303, 0.18494084146955322, 0.17449377705493282, 0.12121181033792035, 0.17590147893755667, 0.10603920917116827, 0.07263694063670213, 0.19568675678343544, 0.18249175030617945, 0.19654284471706038, 0.17801217374301728, 0.2615698432970432, 0.18797479479783968, 0.2145117434162286, 0.1126259258918224, 0.4491142039337466, 0.25498905609692296, 1.1207921490553887, 14.250856311090532, 63.3314948697244, 104.22587917697047, 108.08550711601012, 95.98774863827614, 107.81322402338829, 78.22367145169166, 77.1846434377855, 39.77992911492625, 35.68386070189938, 91.78294427933233, 68.0089879805042, 91.49783503624701, 133.24598989179057, 78.85827956661102, 97.16966075281944, 96.44076670369795, 46.17066252616144, 28.73920625255954, 11.488594778122442, 3.371982699440372, 1.0277151628848047, 0.2495782843400394, 0.21646044126922087, 0.24047576551956518, 0.2164764831503553, 0.2956529418306966, 0.4268842016256625, 0.7147635880016512, 0.6167429445251342, 0.2583883107910233, 0.24019816589932289, 0.27931179610952256, 0.2610991895198822, 0.38851554595655013, 0.8519642968331614, 0.5754369545367457, 0.550573417736638, 0.6804515517527058, 0.2551673094351446, 0.5352339472982192, 0.6442072578976232, 0.7213454477248654, 1.177139570636134, 2.666946221743861, 0.4603089854842233, 0.7749376494076945, 0.5820013474552863, 0.5688536852117508, 0.4794238597875642, 0.2570074219857493, 0.23308765954307972, 0.47532829245732683, 0.4084462732557328, 0.3230789814504885, 0.09008900577863378, 0.2941974973486316, 0.32011492598441343, 0.23683588260844832, 0.2211291649408879, 0.16239714147823472, 0.5636679441217454, 1.1246395038981591, 3.988146604068818, 11.462764989945198, 31.1106869482225, 55.86373352235364, 70.69282270246937, 62.85370703666442, 64.28001811427455, 93.22623529741841, 100.65155659952472, 78.00867849780668, 41.04754109536448, 29.039528408358176, 39.50676348901565, 67.40539012416717, 62.95109556567285, 83.1603116373862, 88.58772662378128, 103.4171413606213, 105.27971021590695, 60.63754435508483, 16.22012638276623, 0.4742528275857049, 0.38263906935049646, 0.1340408106484721, 0.1378969908241303, 0.17966312386335867, 0.32780684710991, 0.1641846237884414, 0.21929210142022182, 0.2254423012416209, 0.16557706519961357, 0.14528560241864574, 0.19213569410625966, 0.1282481440613347, 0.1016751280234706, 0.1764050744954617, 0.17303457874203884, 0.39195423885699243, 0.1649939037498928, 0.09835756894561554, 0.23297745013429275, 0.16070868369312058, 0.15334173706510376, 0.1508972117857587, 0.11049833118675217, 0.11468478718832617, 0.13618489156567282, 0.19606941770161354, 0.2284411830647338, 0.09738167252151236, 0.16355106907506145, 0.170071320007405, 0.14109965203510177, 0.20222426001583377, 0.17670751068620913, 0.15516995993112365, 0.08884505518982488, 0.15126499527644727, 0.17632538602957804, 0.11561577553830801, 0.14428869220277957, 0.188149064478855, 0.23863945276506487, 0.13768263942291661, 0.21853804107635252, 0.1396781452480824, 0.17922129031390915, 0.13907589288728853], [0.04467085116512833, 0.011349522692692137, 0.04493504807713532, 0.019216522679574067, 0.01207066136562536, 0.055557558117734815, 0.043096329806552786, 0.06846474919227824, 0.04273820285414977, 0.01377492162939762, 0.013572826677362525, 0.023639816678159183, 0.014686218646895743, 0.21699121762667933, 0.05430468643504766, 0.033898639883245194, 0.008927767461676513, 0.021944814586951848, 0.008188655408429764, 0.06687397527838908, 0.0024858889998041938, 0.031282886291944215, 0.04547186503787676, 0.017806204606688792, 0.027145364156533635, 0.037661801663137255, 0.07524528615777532, 0.027413581114923282, 0.037032192302567345, 0.079390273820008, 0.03943048034524245, 0.065094651804576, 0.056873995945939136, 0.09093128114698396, 0.05008726515957425, 0.05655771271596032, 0.03884054284783141, 0.010985436533848125, 0.08715647483064283, 0.061518243108425415, 0.08386651023982034, 0.01904103108831952, 0.532179462813562, 2.709221527461083, 42.5405599224952, 82.59396845294584, 84.75662216063469, 81.11902390756916, 66.02605727411085, 69.02212835127308, 46.03308539236746, 61.99147985827539, 26.21547679747305, 52.85669942055979, 50.44903486005722, 41.88653215285271, 58.81456005957819, 64.9264011844512, 44.97905431255218, 39.26730278999575, 28.395092794972083, 7.17258632183075, 2.1408401814199265, 0.0812694491938718, 0.05048495289238711, 0.0595636617001747, 0.10331816445555418, 0.0765411698469712, 0.19071411071044786, 0.05977047479621345, 0.04941052223946299, 0.02748474876786913, 0.08273359643475664, 0.10190189770993688, 0.07697698194533587, 0.02219228013869255, 0.09526189191326981, 0.2753341143890735, 0.19109899328360636, 0.12670206371694803, 0.11022715904419461, 0.15125897382536244, 0.02695251109769508, 0.08090511309884249, 0.08935883971712283, 0.11156503201252031, 0.13881087243076295, 0.21425236136682574, 0.20890948032179188, 0.1172499176895907, 0.030769331591023557, 0.09369168746014757, 0.13440199046125337, 0.14305000463801046, 0.05538372127639671, 0.37349550353903926, 0.16749942494976908, 0.08170647171115683, 0.11129019030880545, 0.07947989078539033, 0.11984307934800464, 0.09562920042944532, 0.3417654287430548, 0.16336677896399654, 0.08485651800348874, 0.07126869228217872, 0.15194733446884542, 0.04216986137532419, 0.15727901530842628, 0.15551707436961515, 0.0239149188517683, 1.8851686942000545, 11.356578584640257, 24.03628637713771, 52.370949176050004, 44.268218855704035, 52.62020403339017, 54.96763667752666, 62.72377460233627, 49.42533546878446, 35.33633478226201, 27.462127631710423, 29.03947545636085, 31.088190194099184, 52.219835942791356, 62.60391481461064, 69.58917756234446, 81.2667089892972, 77.90857176626884, 42.382927710010165, 5.989761275629844, 0.21059110460262145, 0.02976390822309881, 0.10841841779408917, 0.02601435599518159, 0.03822620545003203, 0.033102352772989584, 0.013153086146039349, 0.07302214496678884, 0.020256521510741404, 0.04110829333864874, 0.021230811065423395, 0.039919060579831564, 0.07475002563648647, 0.043208684261527755, 0.027002203390903534, 0.04531079505179678, 0.013780288075307205, 0.017804270234679984, 0.07867190551253096, 0.06852848004669913, 0.06320452137339501, 0.014543241742367466, 0.04571753794387464, 0.10294324868629057, 0.040241074147484, 0.03738008432030197, 0.06870124819538287, 0.04169061209165281, 0.04696795431476447, 0.03509279858741549, 0.014979470401040971, 0.028337165225116957, 0.09087187102845601, 0.09373281105992295, 0.032962484270214074, 0.012630032912467518, 0.0284729772923334, 0.028664185177354563, 0.03809901187196374, 0.021125129236268903, 0.028048453499533, 0.057924838751674666, 0.0378786888153803, 0.09469431269192889, 0.06271963751304054, 0.05025876160230368, 0.05354859595817905, 0.04598117178125728, 0.016892455150223067, 0.06028751519718959, 0.03776001413503001, 0.020126727064170187, 0.033973172577398444, 0.02597780785553398, 0.04237930598338285, 0.03998957131238234, 0.017654934800380183, 0.015156117827451278, 0.05175858555782226, 0.02297617003111349, 0.07921912211684451, 0.06403863790535158, 0.02071242618014015, 0.0421343723522319, 0.06228423910215498, 0.020009358563730796, 0.020014499013702718, 0.04129538733151652, 0.07315185131324876, 0.028864180090867227, 0.010024301666435937, 0.048975752020675334, 0.025071738430509166, 0.028428383314261035, 0.03195071194861685, 0.027111918672979362, 0.0036897511651454076, 0.09769707091993864, 0.006268007864785051, 0.018500941016921596, 0.02708385687231297, 0.01300568987179788, 0.05431446171696148, 0.08399136724971956, 0.090242353598437, 0.07635639710051399, 0.07686029909358871, 0.09542265546418006, 7.528947380281265, 62.98969561053861, 101.95938464133971, 103.48197029482935, 106.89196909627607, 91.95207688116258, 97.12454565109746, 78.94301845181373, 83.35310397609588, 29.615053861371933, 35.3060580069019, 25.291570348124353, 30.349470607696045, 41.992173348703695, 58.83121836570002, 50.61654360063615, 42.644859667747255, 27.364770481663367, 5.907081144471323, 0.8063740980240607, 0.1231361159514035, 0.1601452873118462, 0.08780614803394965, 0.07341047493560661, 0.13655348710956114, 0.14409681782126427, 0.09028032091596434, 0.051044388599092924, 0.08118437512988046, 0.06771186096293312, 0.04252422683601899, 0.09030965442258505, 0.1433492385812344, 0.025211484359216788, 0.4307292888481771, 0.16605868935585025, 0.38645084707006333, 0.1677847467362881, 0.11823165936455612, 0.190800724611167, 0.2809926849459448, 0.19441886594699276, 0.12493456097980662, 0.2791826030419719, 0.2005046071304429, 0.2904249433307879, 0.4061738113241811, 0.2870214904748625, 0.12268666748798664, 0.28167107112465367, 0.07919828452530407, 0.038866528550223, 0.28347088745044124, 0.37752160201630286, 0.12956244450423027, 0.12594333023674067, 0.05675904062246123, 0.158476043011873, 0.1400234210755556, 0.07434746941491481, 0.15835601235589675, 0.08175401512773768, 0.08142799108980164, 0.2786857184142836, 0.1695291442616332, 0.3109220853976665, 0.15578059329380914, 0.4024098987781233, 0.7153253449547676, 7.829640690357455, 18.89721070566485, 44.04920547239242, 43.22807688866892, 56.249455482729026, 43.95926944671139, 31.941052713701804, 21.719836534992343, 27.361383515019572, 41.18874249919769, 42.105863248148275, 52.88908250870244, 78.81414505743211, 88.35782081850114, 86.55291080474855, 93.571011635565, 98.15951793424546, 63.95841121673585, 13.717589493720764, 0.057147539130622343, 0.090089296892045, 0.09214415920958405, 0.014103252549595652, 0.028316917521278226, 0.0162046154465286, 0.07084494606862146, 0.039120149618435296, 0.04571504432768111, 0.04629028059782521, 0.04265069263055921, 0.07625305183952855, 0.05325277110621814, 0.056945579201583905, 0.07436407054023397, 0.019682210291765874, 0.035462267471537474, 0.0321478953194474, 0.03797001415683377, 0.006548051305505778, 0.03695583248871469, 0.021666006463009025, 0.019450750231983203, 0.0499133134050475, 0.015068985859773334, 0.0633570762921966, 0.03055995401565827, 0.038057252419211214, 0.04549575548979544, 0.007043864367710006, 0.03399980179364643, 0.05803155479952694, 0.08271330276564245, 0.06600039755745281, 0.05389444635159547, 0.030300972247195822, 0.03749336957210495, 0.050579829051369624, 0.01700971831357287, 0.05823508520881015, 0.02289690291358819, 0.019543960149730408, 0.03615881376449139, 0.03826283211369188, 0.0915828925527392, 0.12491123360251227, 0.1222595428266833, 0.08835857403614829, 0.1621083110090225, 0.23849838533468787, 0.18965954471740032, 0.1278492190965241, 0.16460914375080218, 0.10236977824881192, 0.11008593839623275, 0.11332437591326815, 0.12059469587139546, 0.1209931688443307, 0.2584394854643653, 0.12228507653719957, 0.17760993161749455, 0.21864863352910166, 0.20684675794214974, 0.1330258207575929, 0.2525074061967673, 0.11944631475114054, 0.11890598527726629, 0.14086852330834637, 0.13858345156956103, 0.19284438672325305, 0.14219964704205915, 0.09730241306486631, 0.15314390251953758, 0.09915777842604345, 0.18752176104293716, 0.13332206695791216, 0.13570576485606933, 0.27385706622754374, 0.17509903248038985, 0.11383419210511832, 0.13332663284194085, 0.10711737067228365, 0.16131184003766508, 0.17122457344685832, 0.15579067501089267, 0.22069938961536656, 0.16288305572684736, 0.42572854267012694, 5.9663682599221515, 65.99022250021657, 113.77232413138114, 111.09059179982832, 104.37346227707403, 86.63957165133569, 93.59569903342955, 64.29744912732032, 83.42788004106092, 39.09535392638176, 75.12415962834513, 71.258420636577, 64.80661984412902, 84.4231814722861, 83.96536242577338, 66.20041447301065, 61.91555846122004, 46.49924339786653, 11.872211406307837, 4.069057255983353, 0.29783181846141815, 0.3849161890966277, 0.15632854534253, 0.2698223262784943, 0.4283002691884195, 0.6093712175084699, 0.3345977262623849, 0.368499108740399, 0.19051020874852137, 0.264969649574449, 0.1728850077357023, 0.420720043682283, 0.2908545347952074, 0.33295897226179805, 0.8013801240632612, 0.521915661952188, 0.46734191777725376, 0.44840416300200653, 0.2619359413942983, 0.37940915073117903, 0.4455791678159468, 0.3904322672995829, 0.47218959958803275, 0.8495373915760749, 0.49202119510981346, 0.6155289709568024, 0.5820625119151608, 0.4856499176352255, 0.2746483431227746, 0.35222176282155904, 0.1989966703038062, 0.19053728229576544, 0.6440085040465479, 0.6435514253474052, 0.39134596504511376, 0.44235335542790355, 0.22255565129941512, 0.6424952658914751, 0.4598991590882502, 0.6907706335186959, 0.3455440808207758, 0.3466605467181052, 0.24965360610475465, 0.511778510746456, 0.1711302527016209, 0.6489334075200943, 0.63148744043804, 0.6379681765552491, 2.980608848794814, 18.206581338759392, 37.8526254623167, 75.26885586400186, 63.956261757881414, 79.37412615745299, 86.28257320773217, 88.33722053035613, 67.03507131145847, 51.178709460842995, 40.80461302111226, 39.95035609891338, 44.03184506200975, 71.42568619020524, 85.79471665043985, 89.87164389702582, 106.63677969286519, 107.85974333363195, 69.33152491046538, 12.74001423389681, 0.3088019523889788, 0.16635259132712119, 0.24014018836521336, 0.21161920991876434, 0.15044499008405596, 0.20588350962967644, 0.17805297558586444, 0.18880857425110956, 0.23201075442616018, 0.13740615829104377, 0.10718677823822345, 0.20595421954508752, 0.2569980757130731, 0.1488376303666061, 0.20449019487827055, 0.08542610437519128, 0.10007729077891958, 0.17386940007488574, 0.1842916125972425, 0.15794494489748634, 0.19771342706536094, 0.10926013391825462, 0.10874128554977718, 0.1890910155470333, 0.14871070491931132, 0.14972282964135372, 0.12184783951529574, 0.12957601958224851, 0.15986920454569403, 0.13597858408766408, 0.07625829954180988, 0.20695399492979052, 0.26021068074530174, 0.2148695064768676, 0.18717861493989346, 0.10542188020002459, 0.12311705568384741, 0.14966214015599222, 0.10347024823028235, 0.16465771372520155, 0.17852536072173428, 0.07809832782274292, 0.1652562582204419, 0.15594505704939365, 0.2296161934012367], [0.08553092818587057, 0.02152606518188071, 0.0342705640791645, 0.014456836600607682, 0.04803026162628685, 0.08597247062190887, 0.029681256912167997, 0.04537232723387499, 0.09062388070648716, 0.04127973615522346, 0.008696633946871566, 0.06303923024285225, 0.04842511100334026, 0.029161186633451335, 0.0067898166842848785, 0.042470435972415635, 0.020330743939285318, 0.030460686257649815, 0.012189784207411352, 0.016346521743182695, 0.036015482544298136, 0.099354961796874, 0.022155423648655418, 0.047393830252751235, 0.06107215011011689, 0.10172162956047444, 0.07763506679405129, 0.008904871008839578, 0.06442725898758059, 0.05910078371544519, 0.03774882925133552, 0.028736297033667087, 0.0069518433226602935, 0.032931373439609044, 0.017743435192612872, 0.04290543984802019, 0.07258848557549138, 0.03426001887888678, 0.03724080570522816, 0.13855504502932872, 0.04697275002517047, 1.9563678027160707, 22.079235469141317, 68.53617022114416, 99.49797968710624, 82.21008608418127, 79.96135988543111, 46.12484532017862, 53.420559744681086, 43.33811506148308, 24.59800704833, 26.00395121882039, 56.35267657618369, 59.41172130646245, 62.15178712721794, 60.3837787720465, 66.44313858401391, 56.57269016388924, 32.25381466650194, 10.142179439144751, 0.6648318157080682, 0.1538614970782111, 0.046328753533382575, 0.044284796477445675, 0.25066136412562867, 0.13030190321226276, 0.060849413876571966, 0.05772583209158433, 0.1259522858045755, 0.09314019608521655, 0.020889469099441366, 0.0837674780538486, 0.07241420057271758, 0.13726161282149055, 0.12191069702948294, 0.05808838703218968, 0.08732147484777436, 0.10426205372618091, 0.06278586198365496, 0.13047742927747388, 0.04482550899528208, 0.2821944623945221, 0.17680765369967108, 0.11305032328011529, 0.08788750657150823, 0.17642088655021884, 0.0833980091697266, 0.16352318347461764, 0.2232794511702753, 0.07370407047170786, 0.1060479119299881, 0.07724967860286275, 0.11991704513709392, 0.10090720148817187, 0.25220411198754467, 0.05489758486228605, 0.08296341515116154, 0.06542110485174964, 0.013668767698559792, 0.09174614588940337, 0.013127255576452421, 0.08256840489564404, 0.11257782323105682, 0.1435108678114991, 0.07322707348653386, 0.0336554529325616, 0.09570840625993668, 0.027075246044044054, 0.06750740741770114, 0.04109060053803748, 0.06669755289030653, 0.16080240688977704, 0.3679144610801051, 0.07609913711466136, 4.845297009714188, 29.14241413916311, 50.21919965744019, 66.84701719591695, 67.48271572974421, 80.16240489098334, 69.85317660916236, 42.58739302235265, 37.64837980270386, 32.167183237691084, 36.35686882080571, 35.8032968736464, 55.65866024263444, 58.08077481485183, 66.37506977204355, 75.04379810825472, 67.2222311266007, 23.64775992208912, 0.5828304997374935, 0.16691957299988117, 0.09297643713052235, 0.02693803395114599, 0.09506644756202737, 0.058393707543972044, 0.07172979294292389, 0.006175334687389795, 0.08575231227422915, 0.14072086752182053, 0.037927369872528705, 0.03045296217615326, 0.00956337241786382, 0.020275953330940778, 0.01859679202278776, 0.03675101505171868, 0.05822965747586662, 0.03877397746809068, 0.15227650712815025, 0.014249464260384202, 0.026393657617811716, 0.07893455109649128, 0.024074238326941288, 0.03267673347445746, 0.06750885532387803, 0.08602573671528409, 0.12629230626888815, 0.0503123494526071, 0.06243497073169678, 0.006505534383318117, 0.04369569018543248, 0.011850014636893908, 0.023763426879961646, 0.037212081238507264, 0.05324814776559511, 0.043975074790538325, 0.023960608335572387, 0.06769855401568836, 0.03412387356342327, 0.03555085404866165, 0.06448044847216337, 0.036775947383214394, 0.025843087463609637, 0.023448139564284397, 0.008689610835825725, 0.020624745501986435, 0.10138920868837065, 0.08083533014981978, 0.023749597077708573, 0.0285260422876285, 0.013115749893439634, 0.030021353985273072, 0.04062376570917907, 0.009146254780071398, 0.026842703885068337, 0.0739986312785937, 0.02629408725507317, 0.05086150425936907, 0.05347274559279604, 0.038455629631155924, 0.035323651522518165, 0.04436500588311784, 0.09295428186775216, 0.02744009541798263, 0.02643933944073656, 0.02281310438599077, 0.014491782658883642, 0.062310810861808646, 0.0936437993040008, 0.04575013498505277, 0.026550217261237484, 0.06613824741854783, 0.047627119347453124, 0.05685709221588989, 0.026595529446738864, 0.03583411505866436, 0.020279515639788682, 0.01791615929124096, 0.11021246547780691, 0.12381947404074094, 0.034703250538798115, 0.05619253009377469, 0.07922219412942087, 0.09946928509781439, 0.07322854437534848, 5.800605464366175, 39.7798506675228, 92.70680366023895, 114.93642868534212, 96.27721171225272, 94.47976989130821, 58.20738892401419, 72.79548768074282, 66.32005460800664, 31.933537452451645, 21.345091327544182, 24.117779501022834, 32.07672749796222, 46.97617223185878, 55.84498851530014, 68.4734985905309, 58.057585762393096, 29.341248889123243, 7.5287723445123245, 0.379406055735965, 0.32836930886391674, 0.10657453609089698, 0.12381700723762475, 0.3105579484854975, 0.17868020241298985, 0.08324139015448671, 0.03464166473056521, 0.1313593190523886, 0.05855389269849947, 0.14810008687838433, 0.1471120632824398, 0.06255521589229185, 0.3599156144886248, 0.35931123240340146, 0.45835291786539945, 0.2643913144786512, 0.20486274343584815, 0.044224110822523796, 0.5730488439721446, 0.5403800969642978, 0.5070126777695072, 0.4041302871079214, 0.31865307700730144, 0.3301610046577069, 0.4051543321580656, 0.7257994829166321, 0.3215706462581312, 1.0000101140429898, 0.6990047303899642, 0.7411773803253329, 0.5687358915325135, 0.7754604890942575, 0.402032186787936, 1.267019457394077, 0.37662117291362057, 0.17553213262750259, 0.16502859221110422, 0.24677961193505796, 0.18493131133577517, 0.04207433787204566, 0.13559627556993117, 0.05000905907382408, 0.302378366430921, 0.10131046251063386, 0.09005152875737799, 0.052911494257709676, 0.06668651356331765, 0.04146040267040653, 0.03732747323210201, 0.09962117735056147, 0.2732096912880098, 0.7215429758352618, 0.27370985477201404, 2.3527050450924905, 21.945139438875263, 43.96247402314217, 67.57125146927373, 63.16783005191434, 50.715230434171616, 38.76545121592861, 18.80068705927941, 21.109268626859112, 41.967799740452925, 58.64002243165047, 61.19043380983415, 87.9342205293717, 78.72644870511948, 82.30988687084567, 85.56980010001891, 88.0947474510439, 41.903567006511075, 1.736173295686322, 0.3763278225256551, 0.01113087258061334, 0.04552929481912044, 0.013879480182133136, 0.04113403006246494, 0.05296140105553693, 0.0862160559383131, 0.10727667099525852, 0.03861605993381912, 0.0667658802722731, 0.06779553308602303, 0.021967898731330232, 0.04034627334124619, 0.04551611044594357, 0.031193730894536264, 0.019811299937446753, 0.051174179215224526, 0.035916986619873394, 0.04001470665717798, 0.03707338485025591, 0.053121827527760505, 0.013138607084270448, 0.04219998012206728, 0.049025390687729084, 0.042831121658485745, 0.08871472065126704, 0.0011698142254552354, 0.06966596739667077, 0.02567513800796963, 0.04561479406190976, 0.03215994205205672, 0.009899750134096512, 0.011295783540023672, 0.07391502810341698, 0.019636377166475982, 0.013929341972294836, 0.026480560716722282, 0.03258184582415608, 0.031555994721730395, 0.034912181867947506, 0.04018672787013554, 0.031560891938786355, 0.07368818180815828, 0.17598636147956695, 0.15945361716853035, 0.18635539217822014, 0.13923107165723078, 0.10334120838031655, 0.1791512851993884, 0.09795659086516789, 0.13871141889643285, 0.1660406250025957, 0.15612484256346382, 0.1355544931345409, 0.1773734402752692, 0.18097753155856364, 0.07935411446998197, 0.11409939642274573, 0.17589714287990527, 0.12760564144099915, 0.157224485169976, 0.17506731644032464, 0.057252638732954386, 0.1594124782469965, 0.1691510645492423, 0.12571859834415297, 0.12577587873825144, 0.1456358424958683, 0.11720134005431207, 0.2394155151541195, 0.14905997972574928, 0.12571123623920064, 0.18917116366567152, 0.10852737847955958, 0.23370264428517512, 0.10394443367277423, 0.10691002897557714, 0.19732987748519068, 0.18997137314609944, 0.11012106352756101, 0.17329583004597696, 0.2609465541618486, 0.3586108441795073, 0.09605011977856198, 5.034951942582285, 40.77537959621799, 103.4423465113486, 128.2425203631001, 103.42758271002002, 101.14355517971902, 66.01870675240794, 71.25641238304877, 56.60889364057972, 39.261329020223315, 37.6348437032392, 77.02655623036047, 82.69875064972909, 89.23966377012192, 80.20936350668632, 87.25577600540655, 77.66622420280211, 47.02358584250174, 18.28687813974196, 1.7822568551186593, 0.6686317343865672, 0.26732622796008665, 0.36217085476363864, 0.546543550106787, 0.39565144046660394, 0.35271343805136224, 0.30478109395311725, 0.27471217356862565, 0.24530354436607132, 0.2841143400198029, 0.35430536875801705, 0.29495233910218366, 0.44043896299216057, 0.2587057469833282, 0.492819152291744, 0.383623308472095, 0.20805233518683142, 0.3263858459409206, 0.567873950687147, 0.5208374391640387, 0.867647955254201, 0.7306667765782726, 0.5505248171187217, 0.37579223513603216, 0.6884593768946586, 0.45036191601426373, 0.4428978907244821, 0.8381402708830372, 0.5430194230810289, 0.35229748295199487, 0.29783047014667147, 0.24628111852272866, 0.4352612811471186, 0.9464715385148603, 0.39518835563813487, 0.28988920272358004, 0.36193339815062864, 0.25401606314605285, 0.27804867033996894, 0.09195691966001066, 0.1841140180946358, 0.29469511742072724, 0.49217998981475836, 0.19766540867426705, 0.27164886375108077, 0.18376760845703466, 0.2774115916221373, 0.242047977123049, 0.38246403358155684, 0.27107693315032994, 0.44241629721176245, 0.8853536567861034, 0.35284045542920794, 6.801609041229372, 41.84251923714915, 68.08974173761183, 94.57541296558996, 98.81606778790875, 122.2667109581732, 100.66301776516823, 59.978715604351414, 55.34144247731855, 45.05268112305672, 47.29070317360663, 50.37203088883431, 75.69606473368984, 76.34054153196274, 84.29610452344342, 96.6384933840844, 99.0615140238116, 43.19276379000756, 1.1759292742898388, 0.3879627062668724, 0.1389275016563554, 0.16436716721903893, 0.13758914605263742, 0.11072911517394167, 0.24312393229094245, 0.11870717780003626, 0.28363519798844095, 0.2446622981299316, 0.174039471594076, 0.26697661607496204, 0.1723427553811381, 0.15272269205700967, 0.1789333485066891, 0.17212520173240095, 0.11543320146419349, 0.17262266858691172, 0.22053072769795695, 0.12335268900759759, 0.10250916028575552, 0.15626097638760844, 0.09628776791355304, 0.1297424598446777, 0.2592768502091208, 0.16434545628726482, 0.23391224594125826, 0.12235495141677319, 0.17795289385943644, 0.09975596285995939, 0.17802568753400158, 0.16993901662288174, 0.07298495139806502, 0.11624303300895038, 0.15913451090455055, 0.10201707902935245, 0.11236964649851285, 0.13010815957621222, 0.11175843856988416, 0.09062707529313142, 0.17371445113132078, 0.1379847998220113, 0.16438645731297233, 0.16832148325779747], [0.03298097763270621, 0.04054449093077452, 0.022200155522554152, 0.04021244544175364, 0.05986722020973122, 0.04165081382398644, 0.05837593430412873, 0.028223424150999037, 0.04773675035985728, 0.03134186931645438, 0.03694009321231035, 0.1026125132076202, 0.0028039986312749887, 0.046389006348627235, 0.05666266293114713, 0.0169685602398409, 0.048726321453408855, 0.022277026700096268, 0.031286733968543916, 0.04393876605336705, 0.07931343520120268, 0.055398866834659735, 0.012245797683605024, 0.04647016953376513, 0.05772261835274197, 0.0255819778859375, 0.05129894812501246, 0.0050409882979076965, 0.06342260362279993, 0.08574563964840867, 0.01160501014260996, 0.030379266433057286, 0.01079668587584409, 0.08329674000701598, 0.012553170353414552, 0.04168063762687868, 0.04954397475587265, 0.025511252648767926, 0.20741957720489274, 0.48529255294030715, 13.882085854007354, 59.4877133061809, 82.27983367058539, 80.68116188049316, 71.83146322927168, 73.41520647848807, 73.550551783654, 109.16510812697872, 63.95888974589687, 31.49219039947756, 61.22627642846877, 66.56206484763854, 70.92966325821416, 59.86794002594487, 70.29676529668993, 63.314071701418975, 33.38990957506242, 9.60029125213623, 0.8163703196952421, 0.018206797727954485, 0.07046459107509545, 0.09373367673927739, 0.10840494230750108, 0.023719353841677792, 0.11892095463530672, 0.05011592450882158, 0.06068124608587354, 0.10135841961469381, 0.09022976677384108, 0.040336390807022976, 0.03256360527067896, 0.05667993438340003, 0.06520388062081992, 0.030280540682255264, 0.085516112045415, 0.03198707431194282, 0.037287215311681075, 0.2978966907868463, 0.25059554185117444, 0.7232536808136971, 0.4644581176821263, 0.22102791876081498, 0.1724128371044513, 0.20423288126626324, 0.059043997448057904, 0.20082195139219686, 0.22331485975413556, 0.4933365374322861, 0.27095518645740324, 0.3070259154323609, 0.41463390413311224, 0.20607970474708467, 1.4108541199276525, 0.36165883223856654, 0.14324259914217458, 0.09034842613243288, 0.2603155735038942, 0.1384213626865418, 0.253299341927613, 0.23758580607752647, 0.3643411818531252, 0.06304913192927357, 0.3049821460679654, 0.3053517375261553, 0.09694576849259677, 0.06808705252384947, 0.03904594251164987, 0.046000235879253, 0.14570289051100133, 0.10778863989417592, 0.017284883689435742, 0.15707816237643843, 0.19330295163296884, 0.04153442208565051, 0.10791345859967894, 0.45511058862170867, 1.3229496368477422, 17.169624336304203, 44.34185351094892, 49.13186373249177, 60.04274829741448, 76.57146715348767, 111.32691460271036, 48.846381864240094, 26.992982741325136, 24.34822855457183, 27.42883259250272, 45.39728095454555, 57.99796181340372, 57.22019503193518, 74.45638395124867, 68.55792368611982, 47.6342204309279, 5.260598053855281, 0.1266561673894044, 0.056253637097054915, 0.11576792060007011, 0.030292296301453348, 0.04234346455984539, 0.024903651079042785, 0.06184413691141433, 0.024637199953318607, 0.013630711323311253, 0.01025376127912633, 0.026460016153812892, 0.05112120423526053, 0.07395332483875175, 0.029711182221710205, 0.013335591272240686, 0.05725505574035549, 0.08678882157490139, 0.04923449055622182, 0.02328779544651268, 0.0597093103363389, 0.04144485491598326, 0.06480515483886966, 0.04204990732814035, 0.02635912045896534, 0.027113981364715486, 0.03853142253994461, 0.043385324984668724, 0.06365831355534254, 0.04418807021612602, 0.008242122599885108, 0.06286451240040122, 0.043870327588651455, 0.06522484078642822, 0.031120533108591076, 0.045695807859902425, 0.017387847821678848, 0.034851794987316095, 0.024930628865296324, 0.04936032049778489, 0.07271001010292, 0.0221859177784814, 0.03990484198795692, 0.027051123850528273, 0.046539458356076674, 0.03249337799066017, 0.04416022675051805, 0.08718698045178767, 0.044921407881643505, 0.09507145777705217, 0.05069892508007827, 0.050810555581964796, 0.0702799562244646, 0.028618606776299498, 0.05343164880609801, 0.0575492526554773, 0.05014218983330554, 0.06307225629326797, 0.02331789121061804, 0.0572803826071322, 0.0449230358184826, 0.020679620380002647, 0.07604521984655051, 0.03562607239150713, 0.05195504880600399, 0.15897836686382372, 0.04085720419102619, 0.10351881820468173, 0.05346886535745956, 0.06855569148976957, 0.040276176296174526, 0.049365100886432395, 0.035044412474117936, 0.03855037938563093, 0.02809418320295311, 0.01638851868319175, 0.07367269151032933, 0.054909505190387856, 0.030069542830930125, 0.09147326537077466, 0.08345676045263968, 0.16683349536070902, 1.7988448037255196, 29.342560921945882, 85.48929737460229, 99.54929213370048, 92.11498075915922, 89.4390849144228, 100.78266574490456, 109.49008434049546, 112.39369730795585, 56.84699327714982, 21.288634692468953, 24.181729824312274, 34.33280421841529, 56.63798978251796, 54.41209962291103, 69.35279984628, 62.20198169831307, 27.044540336055142, 6.101921941003492, 0.10499381325057439, 0.06989190970817882, 0.08465412523477309, 0.05439536826264474, 0.05764551160316314, 0.11289690651239888, 0.14493341647809552, 0.11698825269817345, 0.13964143431475087, 0.07974257467374687, 0.22138658580520462, 0.32814092273193024, 0.4353660513316432, 0.1898402495369796, 0.6616073209912546, 0.6748599066368995, 0.7785280890041782, 0.9147211777106409, 0.5907075383490132, 1.0042690113186836, 1.2940181118826712, 1.6617355351486516, 1.644617576272257, 0.8710468728696147, 1.452748833164092, 1.7951045786180806, 1.9681952196744181, 2.932974114533394, 1.1553217542748297, 2.4774690212741977, 2.1979378788701953, 2.468887365633442, 2.302972087937017, 2.353226475177273, 4.289759955098552, 2.3009807496301593, 1.1051589298632838, 1.6110934461316757, 1.6970181128671094, 0.9457327233206843, 0.5711014484686237, 0.6985390715060696, 1.3101223832176578, 0.9249825270906572, 1.71276459049794, 1.7629415109272928, 0.3494607206554182, 0.527673640078114, 0.251572395885183, 0.2110763600156192, 0.44447106759875055, 0.04588241538693828, 0.057257599152264096, 0.13958984595392981, 0.22182832742410324, 0.26914985429856086, 0.13309892086732772, 0.5924708276025711, 0.23257827236046716, 12.159950598593682, 38.62238276389338, 50.47650714074412, 59.88169970050935, 54.838214151320926, 69.09368807269682, 21.9527566817499, 17.70862860064353, 30.959697269624282, 42.32020508858466, 72.990249049279, 77.87001486747496, 77.68065068029588, 88.21545447072675, 81.6547961388865, 70.9046071575534, 14.968644169069107, 0.04742685247272734, 0.043684237170964486, 0.15472503138646004, 0.025958044702307354, 0.11726810461691312, 0.07095691747963428, 0.09178678685378644, 0.05462458176958946, 0.04819788549455905, 0.12412249245831083, 0.07338257401340431, 0.021801722769234932, 0.02157321023274093, 0.04076558773616149, 0.009162495844066143, 0.031013617877878492, 0.029589638542083484, 0.014801704486261212, 0.12687559795355605, 0.011132971661525869, 0.07723976542512256, 0.04521034560316513, 0.03448870761560337, 0.08800011383549822, 0.03748656671133734, 0.030708174792028246, 0.07338879464734947, 0.07455075084562264, 0.010366490159574296, 0.011701137897738767, 0.06083366310884876, 0.047455634396042556, 0.04937990553556912, 0.0547335118115429, 0.09095907481687684, 0.030034940554610187, 0.03179997840385524, 0.020741838210773085, 0.023751617634608865, 0.041973352161867004, 0.06714601310030108, 0.1094936375175753, 0.07815861894238381, 0.12192181296526425, 0.10235461736879042, 0.0994449311627015, 0.1980571400734686, 0.11168635735708861, 0.17569322559622028, 0.18881404411888894, 0.13485888529929424, 0.16401911815327985, 0.11286935032976252, 0.2285824803214881, 0.16730512973041306, 0.12556507432412717, 0.1590549603344933, 0.19834183366788974, 0.09255851318518962, 0.05639007735636927, 0.1531497401095206, 0.22527466588202985, 0.1543035451322794, 0.30197779437707317, 0.1767489560429127, 0.15238011285902994, 0.14580690992936013, 0.14805490301261026, 0.14194334466611186, 0.19847288066821717, 0.1472528089558886, 0.2084244853786884, 0.19050329863544435, 0.06969798221102647, 0.13394377795198273, 0.19973726282196663, 0.11910552819890362, 0.18329969727464263, 0.20970748346899787, 0.15385302414576854, 0.2969750257269029, 1.4322397401255946, 30.84828626724982, 96.86435130334671, 114.61258995917537, 101.35586523240613, 95.10646266321983, 99.0043572456606, 95.80276966094972, 128.96798626069102, 78.67731709634104, 45.9773838135504, 83.55276046260711, 89.55776799109675, 99.8638113083378, 79.81214507933586, 88.75565113559847, 84.60117078596546, 43.584047671287294, 14.625154368339048, 1.5014410139091554, 0.2894173844927742, 0.12984813401295295, 0.12046572496934284, 0.2819799271322066, 0.3750927968611641, 0.24439974447652218, 0.37382335852711435, 0.33418943204226037, 0.2588907112517665, 0.24664835043011174, 0.2898770372473425, 0.26654429733753204, 0.1991575487679051, 0.4304598404034492, 0.2360118171500583, 0.4032253534082444, 0.5063610740246312, 0.3437513737909256, 0.9546097824650427, 0.71693045237372, 1.5763780186253211, 1.673308610916138, 0.3948151788884594, 0.9416269823428124, 1.1216567865302487, 1.2432912016107192, 1.8538789667429465, 0.6648179648383972, 1.4688848511826609, 1.7357558084111062, 1.2822554140321671, 1.3173010560774034, 1.3680399786080084, 3.364466702745807, 1.1068363559822882, 0.5555490668742888, 0.5734769951912665, 1.167023777961731, 0.7213350902161291, 0.6082152214742477, 0.5622035517327247, 0.7214492066733299, 0.3747757283910629, 0.7334080843194839, 0.5692644309132331, 0.2630737351794397, 0.26012120167574576, 0.2510113437329569, 0.2773148806825761, 0.598456732207729, 0.27344589151682397, 0.34681514326122503, 0.36721195845353993, 0.5874383653844557, 0.43585742012627665, 0.31612317888967456, 0.8040637607055326, 2.582385314087714, 22.87223477517405, 58.13721772163146, 68.23264152772965, 90.4684482082244, 113.20318037463774, 143.12992342056768, 64.39298237523725, 39.08148442545245, 34.86338323162448, 36.31079666076168, 60.35097599029542, 76.14275209365353, 75.43880431882798, 92.65398502349855, 94.46491979783582, 74.58563389316683, 12.771594216746669, 0.2679831943204326, 0.16659072209750453, 0.2090267990265162, 0.1367332419801143, 0.19660359548945583, 0.21625946576316513, 0.19236631721498507, 0.2161237303047411, 0.17022245383310705, 0.11998764013931637, 0.18465043285921698, 0.17815679582136293, 0.13137548350759093, 0.1781672759041671, 0.07710420616692112, 0.1507369768355162, 0.25124584324657917, 0.14767308479114888, 0.15867832086740002, 0.17193629977203187, 0.17828836376147886, 0.12516244915464234, 0.12412304404161631, 0.1128648916980432, 0.11556067849479376, 0.228528808201513, 0.1695136079985288, 0.21459474138194518, 0.11150968215999105, 0.13013705641271608, 0.20602466899060434, 0.1323914386692547, 0.19186045403682417, 0.17565516634814202, 0.2350160254225616, 0.12814682893334858, 0.1391007447795522, 0.08742708006813642, 0.11163545847539941, 0.16473242261957738, 0.17780597351731794, 0.1567685709244782], [0.023894832026393666, 0.025712358389770793, 0.0408248829415008, 0.01887507346128264, 0.022799230533682054, 0.053577174868194334, 0.02089988597999177, 0.057824458250956196, 0.04956270177518168, 0.027342049570213404, 0.011310665755562726, 0.023259503819469004, 0.03308215486486593, 0.046174923078187054, 0.021137185544977267, 0.06526267020812919, 0.014923630252240166, 0.06513839542505241, 0.03120344488941614, 0.029108092909859076, 0.02300219020746168, 0.10350899695749245, 0.057507753672619025, 0.15374102209123874, 0.09685808972966287, 0.04982070103588124, 0.07539357013639904, 0.09665356723651772, 0.11852523191801964, 0.07884667315069707, 0.009723371796069608, 0.04912689733769625, 0.10478385919404608, 0.1431431456078445, 0.10337079469595226, 0.03310805629758585, 0.14739957608042226, 0.21479856673507922, 8.293486948936216, 45.65190553665162, 81.09306566176876, 90.98359661717569, 77.17341761435233, 77.2799805671938, 73.1169729848062, 52.664683711144235, 20.177105588297692, 51.13859145872055, 124.5473260264243, 97.85915851593019, 67.99135300420946, 63.30578373324487, 58.5887295969071, 57.07675003236341, 28.54894776498118, 4.954388910724271, 0.26494780074684854, 0.1318999932658288, 0.198141394423381, 0.05935855698020709, 0.06128033450354011, 0.11752935592085124, 0.07491437447888237, 0.0722749640924796, 0.170761228148495, 0.1002746120455765, 0.03128020115376961, 0.06143852782946441, 0.11605197834151408, 0.12442125142702173, 0.028163514160100492, 0.7997174681194368, 0.1586719623376285, 1.2360507514207595, 1.1530743587401606, 0.580126638374021, 0.9129524339110622, 0.6174342622680049, 0.5190230978112067, 0.8357017210895016, 3.1672114422244415, 7.919871384097685, 13.421532915484521, 4.7609415361958165, 2.797786439618757, 2.353134789774495, 1.7965750997104954, 1.0806484063786845, 1.6889371722936632, 2.596891464725618, 4.467829677366442, 3.564145007441121, 6.568797249947825, 1.2491797824059765, 2.1378270656831804, 1.10986883842176, 0.399442840247385, 0.321724108991123, 0.15372795263125053, 0.1663397976587857, 0.16787103888007904, 0.13820497349144953, 0.12242730076034224, 0.31441103366594164, 0.18363789444969547, 0.11498477955859517, 0.12432326878150626, 1.1763193049738485, 0.30134966356619713, 0.07997812372782538, 0.1536078606882403, 0.1564295616962256, 0.07092288019315851, 0.05536145110043788, 0.22638730133973786, 0.2978354037529038, 0.06343212992613835, 0.23954086246029024, 0.8354054595674238, 11.257719166817205, 35.565644387275945, 60.89700914198353, 41.02398334010955, 70.1410158218876, 81.02127059813469, 54.501502206248624, 44.628810190385394, 23.928662423164617, 39.62113980324038, 47.904926730740456, 62.63038296853343, 74.33366867803758, 78.48151237733903, 72.82242651908629, 22.04438521016029, 0.27826139763478314, 0.2857827569448179, 0.09904255880223167, 0.0398915580233499, 0.10210663470770083, 0.03301742426570385, 0.028230412788088285, 0.05506785939477625, 0.03438388763536369, 0.027025021319728226, 0.03814137653417645, 0.03240668365070897, 0.04623776527061578, 0.06830193252573091, 0.020399257097573533, 0.06849449638637804, 0.0366404302598488, 0.026408410556013548, 0.030126059052324107, 0.01786915788186654, 0.05167505133055872, 0.031039638054226677, 0.1148066564553207, 0.0370008631369039, 0.029379755348688173, 0.051009562242055134, 0.06192081082131594, 0.02654823883917303, 0.024006818759164984, 0.045220906125201334, 0.07210352893678412, 0.05240696024209742, 0.024468639542558984, 0.045831619927118865, 0.06929125847114671, 0.02257292624562979, 0.03264018341959004, 0.023578646472625198, 0.022219173655274416, 0.05024952258193686, 0.03521078761907355, 0.04818080173384759, 0.05166580081887303, 0.08185868572083213, 0.045890528258056416, 0.01559374938463612, 0.011696277069859208, 0.05249944237631656, 0.04641969583087391, 0.011706164392131952, 0.0735083350070542, 0.02565592069238905, 0.030546426818135287, 0.06036918016991789, 0.026053234957338824, 0.07526286021475831, 0.03114586955146684, 0.028728210975626306, 0.0951521804616336, 0.02890593379796032, 0.01859638599618789, 0.01953536655843979, 0.014911660128423284, 0.02681640025618817, 0.04077280045396859, 0.058241792308587226, 0.003978710432889902, 0.10823992696861107, 0.015754705415137352, 0.0735584831225776, 0.07789529154017087, 0.031849687934041984, 0.0256355619058013, 0.08020672436443069, 0.055953116126118176, 0.030540819054529555, 0.031864446617903254, 0.25477268222358923, 0.4380171752024082, 17.912030950669322, 70.08662823707827, 101.45044926674136, 101.87758753376623, 98.70296232161984, 109.81799448690107, 106.00627437714608, 78.07787695238667, 23.290243725622854, 61.410561146274695, 104.2622866169099, 59.94046072806082, 53.79205134607131, 65.88177680969238, 67.54212394837411, 54.10069481019051, 22.73061760010258, 1.5251996680613489, 0.3589394039684727, 0.14555860551134234, 0.10795127269962143, 0.08785150043906705, 0.0726918078538391, 0.3559938265431312, 0.18760181723102448, 0.08173923729167831, 0.4136648641959314, 0.43907658287113716, 0.2895338605007818, 0.23706416148812542, 0.803424598228547, 0.8905316757098322, 3.6638264069634103, 3.86077081964862, 2.555316056936018, 4.706478445760665, 3.6122536130489844, 4.4164652593674205, 3.795662661713939, 3.1451260466729445, 4.033007242025868, 4.719417854662865, 9.41161249914477, 24.397746516812234, 24.967929701651297, 9.236384534066724, 7.59594734637968, 5.836833455870229, 3.64109970388874, 4.521112624675998, 5.731113322319524, 6.763928301872746, 4.482932273418673, 6.148176000964257, 8.89593751199784, 4.245118969871152, 5.691977383628969, 1.9990970002066706, 2.090365160857478, 0.9059535772089036, 1.0875593774741696, 1.4353581469866539, 1.3180643247981227, 1.8103179816276798, 0.7118009114938398, 0.8367215986213378, 0.9063185414960309, 0.7549474736855877, 0.6430951433797037, 0.9511007933366684, 0.5488882081643228, 0.4055661197391249, 0.5004068854595385, 0.30038031719384656, 0.1876157447094879, 0.07739225522645059, 0.18204705158789314, 0.2989994590320895, 0.06516138572366008, 0.6093877037206005, 0.20335534287075843, 7.078842165008669, 37.317865202503825, 64.72755270619547, 51.5903151419855, 45.82368181597802, 31.992016069350708, 23.05838457999691, 25.309966264232514, 32.34437631022546, 57.05891109281971, 76.1178058193576, 86.83521163079047, 88.56187820434572, 89.13021395283361, 92.50370333271643, 38.523150720903956, 2.2667867522085867, 0.29197219578969863, 0.008166414918377995, 0.195945939649978, 0.17273024265323916, 0.15432927036477675, 0.06342870551311681, 0.00877901233897935, 0.0508337871982686, 0.07208485171319017, 0.008633318695149595, 0.06023626774549485, 0.078086813521241, 0.0036442029288023593, 0.04034741864269299, 0.04616291081953434, 0.013876660020961879, 0.043843866911746805, 0.03341777415405358, 0.06897960624267017, 0.05201618645280119, 0.15943883167159173, 0.020809407165694623, 0.04241217881621372, 0.05360934290013487, 0.04815104304842892, 0.06059783060223826, 0.04462591627792967, 0.007591913135031299, 0.020770566507933602, 0.06621609727341322, 0.015209569697148137, 0.006542196478544465, 0.009353230669794065, 0.03860944476459296, 0.04911724079941069, 0.02479366192053403, 0.01644022387242125, 0.03622367076816098, 0.03125132729990348, 0.05282466968281135, 0.23799276730466276, 0.20212669105779743, 0.27378603455520445, 0.1379986506916823, 0.0714131381603018, 0.20033877973835315, 0.13206784313003864, 0.13136146409857657, 0.18592696516744553, 0.14670072003237664, 0.16181494529929855, 0.15517933684731686, 0.17567411936338873, 0.2731524798418245, 0.15178728337970473, 0.159113290269048, 0.1987649899937453, 0.19301091891623315, 0.20860641593894652, 0.10337879265388174, 0.07454911907834393, 0.12586056975828064, 0.24761072540235138, 0.19230214969044734, 0.16303789741810293, 0.25522219197404, 0.2107645162651616, 0.1937784011205358, 0.21715744338448972, 0.15834174779874666, 0.10693778434107382, 0.19260740508475613, 0.23229964618240637, 0.18101476343168368, 0.21162486364764554, 0.17493508966459384, 0.24623565886530185, 0.35714654372103755, 16.357197530807987, 77.22657357492756, 118.23634224553263, 112.60013949486518, 98.77246672107329, 103.98880327901533, 97.34509268114644, 70.89078472506615, 29.058671535984164, 68.25317121321156, 141.54608603446715, 121.62169287281652, 90.91732425074424, 89.03901100158693, 81.9205367180609, 76.15178923453055, 40.220948649990945, 7.124794202466165, 1.1983617996015858, 0.21902983888022362, 0.38534547412587755, 0.39965124680630626, 0.2603348482760691, 0.5077240363724771, 0.27163777079793716, 0.18153907400706124, 0.5110505433572877, 0.45920796391944735, 0.27896632109918906, 0.238715969626942, 0.321628348000588, 0.24055330893926083, 1.4603110402822497, 2.7343992215971795, 1.370507394594531, 3.3382167306638535, 2.219837206986643, 3.0068612723581256, 2.597313609815413, 1.3962114217781252, 4.490180323200842, 4.402046626613987, 9.774235621575388, 21.55338095080468, 25.04237432633677, 12.20071775297965, 8.044309068110682, 10.418979141020007, 5.365078228135263, 4.722654300351297, 5.559539045056989, 9.28203700050231, 13.593260165183777, 11.871200415395922, 17.042800380337624, 9.274200104898023, 9.477394569304682, 2.7121873296076253, 2.247035166909618, 1.0517492409675353, 2.8329639713610373, 1.6071188594064407, 1.3045895123674025, 0.7636935011513772, 0.4708726638026776, 0.8707720005223829, 0.5330175630027248, 1.0721918988612391, 0.6582804156407234, 2.4344072803374264, 0.5702172604299361, 0.3475888920647483, 0.528349697349533, 0.4004504603724326, 0.2571634894176837, 0.22747588163662344, 0.3580347154169314, 0.6073434134164165, 0.14842965790340978, 0.6394049284919616, 1.3107753352772806, 16.45215811267976, 50.47908413794733, 82.94050201292961, 65.81283723154377, 106.5120953898276, 116.18316973409345, 73.35874788222775, 62.76312774227512, 33.11568883157546, 51.81359606404459, 63.10930044420304, 82.89592035355108, 93.31816780951716, 100.60002450020083, 103.30045084799491, 39.06608912252611, 1.951717955450858, 0.4339558979676616, 0.19679586823669173, 0.4034726772337191, 0.3331534973075313, 0.2376590594048462, 0.09418089588683459, 0.16124220264534797, 0.09253510153822361, 0.11454990974837735, 0.13644307851791382, 0.10380751843894682, 0.17426965037180533, 0.1265949033380997, 0.13107457949269202, 0.09035866106710128, 0.12015101605004842, 0.12382991581914887, 0.09386438666091812, 0.09168169491233365, 0.13682410000793396, 0.318895222078408, 0.24620429522568182, 0.12170534716137957, 0.14914648637415903, 0.2120778361155141, 0.20390401504212813, 0.11888340866613774, 0.06570822694489072, 0.1406464037755805, 0.1253301381403881, 0.12895744954866747, 0.1843413317035283, 0.1674669275000211, 0.16731960879218194, 0.1333356420359304, 0.24156518851316747, 0.176254614827133, 0.11442443220725945, 0.12229212454610294, 0.1484542493257792], [0.01379762081459405, 0.033188721525572965, 0.11580129139005177, 0.05775895007255097, 0.09155535169186131, 0.009194083564404038, 0.026461852849611354, 0.0349284497450196, 0.05045426724058005, 0.014082183216458127, 0.023822777626675465, 0.050224617063518495, 0.0685625326549334, 0.03338757496807845, 0.016743221222573233, 0.021795902416230212, 0.04924078396851978, 0.03576687169111064, 0.02329194381262266, 0.016195288326050487, 0.043113520819573634, 0.005342027335803235, 0.014767390450522786, 0.08542146188237014, 0.028181879202865308, 0.04614417613934606, 0.025075618665845647, 0.05495454732989592, 0.03300768728818625, 0.05939134937380591, 0.057949591052508166, 0.042017452013228214, 0.051274157519782745, 0.03113813972431085, 0.09350085495820931, 0.07912448727555814, 1.8358491793755563, 32.696981699235984, 81.92714983417143, 101.86024281286426, 88.98538435659101, 66.73037375173261, 62.74814821058705, 45.11026936192667, 34.348627059690415, 32.78733545734037, 52.4366488764363, 32.10649436519992, 41.86947376497331, 69.27964764256632, 64.32238363450574, 57.657986456348056, 30.650896910698187, 3.7996563699937638, 0.32645399712266465, 0.08891349748498009, 0.006736758392259118, 0.19867793176203005, 0.1614823712096099, 0.04073016383054276, 0.10037015087061352, 0.030737318691887686, 0.04381263350707389, 0.10699264389733154, 0.34735235475724746, 0.6990499602210137, 0.08598094355435142, 0.22264954303541493, 0.6217610655773071, 0.32242658097417126, 1.6246801686863748, 1.1930417173331784, 2.032521845352265, 6.37577643317561, 2.0129446829518964, 3.706004143722596, 1.5514611621056835, 2.2621002552970766, 2.8585258126258855, 3.2137827238728924, 3.7912946122307933, 17.384960497579268, 31.601451942997596, 5.722101186552356, 9.884042374549374, 6.350404091419713, 2.446234206999502, 6.276848864170813, 1.9021867552111227, 6.106132115087202, 6.632421526216692, 5.16690194606781, 10.284937043343822, 7.858774094812333, 5.764894735428595, 6.683088742917584, 4.268305080552255, 0.9425699446470508, 1.3948623715869843, 2.5246722948166633, 5.409520153076419, 4.9603391462756745, 9.671747030750398, 11.990183553388043, 4.155942903411004, 4.167724722816098, 0.15591369340977362, 0.8125414122496882, 1.050763745461741, 0.1958577935734103, 0.06860262203601099, 0.10186416787966605, 0.23307210795821684, 0.08380028959964553, 0.023389313587798707, 0.055712729226797826, 0.2612629178310594, 0.10984844347882657, 0.023792628236415408, 0.24914173679726742, 2.713357911955926, 12.987452053254652, 34.41290686207433, 82.80282681988132, 57.57748373093144, 74.01042615213703, 67.73995261038503, 53.38155961805775, 29.78559067172389, 28.841389879103634, 46.52776687375961, 42.41485188084264, 63.57503483372351, 65.71381699654364, 84.33556356737691, 41.23945482315556, 8.806374111483175, 0.08963517529229004, 0.04289023300272323, 0.08200488594030181, 0.08845724616079562, 0.04018565917748117, 0.01413513808661411, 0.023116877400166085, 0.017818063647756656, 0.05089892765447017, 0.08894983303522871, 0.1144051650959638, 0.014445873882411229, 0.06008337957844619, 0.059204546494349364, 0.03977524672424601, 0.05238122351828122, 0.02509914139556068, 0.01525001435150062, 0.029951080739978823, 0.06205392625903892, 0.1140041946763954, 0.011731045970302677, 0.015374924987554552, 0.034391334009987694, 0.012530048862249862, 0.05172459806706156, 0.06765884001769366, 0.011278513045380674, 0.06147647216435402, 0.024107882993355877, 0.10904909201687384, 0.036695714994904496, 0.023838089809062022, 0.031187676884714636, 0.033498577277867064, 0.08101428062805245, 0.03396395653966935, 0.011664471014462894, 0.0040537767551629056, 0.03993783356441606, 0.06430293823922835, 0.05662162360104342, 0.026232775323273196, 0.03423679492346222, 0.03208507036399697, 0.04733768366878072, 0.12371130242583253, 0.052679017216207526, 0.029298065478102337, 0.026682110788721233, 0.048989269642099265, 0.047444648695208376, 0.050282544801912965, 0.017677802524919954, 0.033914394481408025, 0.03564070467086088, 0.07238073019130577, 0.015512988395658473, 0.04213387822552074, 0.05214717216609467, 0.08257504687794755, 0.01251022921003882, 0.07483359816814623, 0.006375840964591912, 0.035811986608971516, 0.03792426721643537, 0.020068142405380646, 0.1032123753740903, 0.03096714698439164, 0.09675562546979036, 0.025695288035598014, 0.058105846175984036, 0.038285975629884395, 0.052516392071641264, 0.0484455578900393, 7.163390815258027, 56.842866943728545, 108.30406942675191, 120.91863939839025, 105.92545001737534, 92.1084382457118, 88.89993160001694, 74.16949395210513, 48.77771685200353, 26.278524975622854, 37.25274993527321, 21.290578226889334, 39.62024942521126, 68.20441615196967, 72.88050897659795, 56.93356390922301, 24.305239377483247, 1.0790716135694136, 0.39917133868702, 0.0717151376809324, 0.06716826029362218, 0.040815578803660414, 0.2550279427199595, 0.05205154141050674, 0.23284995778193399, 0.1690897468717829, 0.42166950241211926, 0.25232559821057704, 0.42029722443511414, 1.1805600000004615, 0.5813890899862013, 0.9908347096173995, 1.5119315155090824, 4.6579469596186, 5.11616510729636, 7.335530894417917, 6.653896012613851, 10.796044430425091, 9.90575465463823, 6.876812154246915, 7.62786465306436, 6.070722428060347, 8.139593245521668, 9.940374474371634, 11.118641726432308, 28.284791823356386, 41.40290783297631, 10.522855270293451, 12.629711301096025, 11.959266451097305, 9.024115666266411, 10.315199109815783, 8.158741766406644, 12.87420145926937, 7.382301236352614, 4.0293319811744075, 5.350182537109622, 2.3134107407062285, 2.756632931770817, 0.13218263374461284, 1.963673462310145, 1.5723550151432715, 0.6662726125890209, 0.22052181043451835, 1.4734859139688554, 1.599437510294299, 2.837562950388078, 2.8215491387151905, 3.2910578289339623, 1.1391352357402926, 0.8900785193808618, 1.907167184737421, 2.6276198029518127, 0.6815303261241605, 0.13234389525267387, 0.11326420736769516, 0.17221160112850128, 0.5348197695228362, 0.13606368113429318, 0.0730535852152013, 0.21597832681671267, 0.15861271309756464, 0.08049611407782763, 0.5346292281343091, 1.1613874545981808, 9.299369954293775, 35.067919146630075, 92.84407092678933, 62.35348324621878, 55.95270072260211, 41.534448439075106, 22.950613537142356, 26.5017274502785, 44.14176948608891, 69.82255858759727, 71.21953425868865, 84.41400312608289, 81.92421590128254, 99.95069965239495, 62.70292720487041, 19.009602300582394, 0.07131761465702327, 0.27805302171937885, 0.156909316597927, 0.15868832597569113, 0.08045908138756791, 0.049389148386375564, 0.06569647515613226, 0.03593673253612172, 0.045321987596370523, 0.006738809113871427, 0.04098565798372992, 0.052057034260923826, 0.010422105270047343, 0.04436486415685185, 0.044926697718760664, 0.03230567878833221, 0.02754924379499449, 0.05188313230211216, 0.03197765143047417, 0.05815321339234229, 0.06821342638783878, 0.05183188485041742, 0.03619288169448415, 0.024425757770997383, 0.06731413875616367, 0.028068986571123524, 0.0302984269200674, 0.0409290632383237, 0.061301781134980346, 0.025210118807491758, 0.13569713870604194, 0.044599175978932655, 0.019674700714888114, 0.004770941825793876, 0.018948615986793753, 0.027828567113066395, 0.024134052556849295, 0.06727712138766243, 0.022354843996224866, 0.12613892014468872, 0.1708697215203316, 0.16227775433611485, 0.13482713861571205, 0.16391787197320692, 0.21355911308238584, 0.15361904557193481, 0.16546497121453285, 0.13487911002049524, 0.1862161633588614, 0.07159216524732691, 0.23411433993568345, 0.11903337037731564, 0.09787678748609559, 0.1794848552033786, 0.12036607225215244, 0.08192800135622103, 0.1706649921834469, 0.17040116682408318, 0.10746735027961193, 0.1069739513519791, 0.17310014054659875, 0.06511783362516473, 0.15456714066526583, 0.1335663570752067, 0.1262938920708914, 0.11865737442407878, 0.13301417622114384, 0.2352511684500402, 0.17791448221091302, 0.10727427314005553, 0.11344734834687364, 0.25131210985202945, 0.21588690188382903, 0.2851731961052264, 0.19951692061318507, 6.121044476186076, 61.97309570927774, 122.0709611523536, 132.29610166242045, 111.62881943487353, 91.45231200802712, 86.46129208226358, 60.35526706326393, 47.50121285838466, 44.255294645986254, 79.92535252724925, 49.19280952022922, 61.4292904638475, 93.88481693883097, 84.7708054511778, 75.55977805968254, 39.86581725458945, 5.936067460044738, 0.640545909202868, 0.32162347568138955, 0.1527662058511088, 0.6943194592191327, 0.3886888350450224, 0.1752564329053125, 0.3608857882359336, 0.15841884688744623, 0.4765664437605489, 0.29008127628795566, 1.1968082958652129, 1.7700619611047932, 1.4762996016971528, 2.08925758158007, 2.6304076275517865, 4.559300330377394, 8.005954661676961, 8.541744543660073, 10.359232617962746, 17.649477297259917, 9.111478617114406, 12.689396046823072, 10.828612850558374, 8.491865723363816, 9.523723644594993, 11.771780098638228, 10.31203571827181, 34.28950909645327, 49.848335635277536, 18.72041967607314, 24.208507845478675, 20.393961668014526, 13.255779435557704, 20.059918895844493, 12.872152020854335, 19.470129743699108, 25.41577219963074, 20.35368088752993, 25.050073938985026, 19.443922427392778, 15.376378470851531, 19.118181351692446, 13.286277824832549, 6.75433712620889, 6.492776813045626, 6.8030122691585175, 12.215602167191046, 14.058985729371349, 15.798022477857529, 21.99737168127491, 9.394440362530371, 7.87463665008545, 1.0140748754624398, 2.6689537398276793, 3.8638324747162485, 0.4969518289210335, 0.3557207315198837, 0.29344832464571924, 0.6590848692482518, 0.5407689019076286, 0.2672946651376063, 0.135422894550908, 0.45070248806188185, 0.26013624764257864, 0.15955777448271552, 0.6984102461607226, 2.891723773171825, 21.328566382008216, 49.19573560837777, 104.69803056409283, 81.92802844509002, 112.54050377876528, 94.83821176713514, 71.93848117705315, 42.13161360832953, 37.87768548534763, 57.62551707606162, 59.936993352828495, 82.15053666022517, 84.4331286030431, 112.91156784180673, 69.8966835391137, 17.464712089107884, 0.16870944550441158, 0.3043273553973244, 0.2613576982290514, 0.2082588112041835, 0.1905353977194717, 0.19521944314962436, 0.15330366249526703, 0.19000797682712156, 0.14194316080501004, 0.17450217337858293, 0.2747300693825368, 0.1627788677691452, 0.1960032277049557, 0.1300101309654213, 0.16615437373759287, 0.11627039766960567, 0.12758459700571914, 0.14061064279127505, 0.08884517776389277, 0.21442643186498075, 0.21770455273649386, 0.10544392821048537, 0.22355974742001106, 0.11556471577815472, 0.0869786581625381, 0.11630495589586998, 0.2299820463503561, 0.15529185984163515, 0.1071823119456249, 0.14093059175197156, 0.3175795733207657, 0.17471955848797677, 0.05985472914612582, 0.08846304544638242, 0.09750150399462831, 0.1745132663317265, 0.10567495734581064, 0.12372204297853094, 0.13722145449249976], [0.09011187350317355, 0.07408357510763793, 0.04845775017935423, 0.049215621810646794, 0.03372905482988685, 0.02804264655306695, 0.020944437823228298, 0.029054585498787706, 0.022662717496014895, 0.05828495753268081, 0.059723961767890764, 0.04983621814678754, 0.04852732628463738, 0.03723359681786068, 0.009996263806017177, 0.020952837977318034, 0.08957637038322226, 0.040069937766078985, 0.043516199615213184, 0.05718333841932397, 0.03007914574306098, 0.08638481744715283, 0.10459249043056082, 0.05788185355824329, 0.09852829930042067, 0.08618382661933861, 0.10362907357874418, 0.0361421705043364, 0.043345254755789236, 0.11976674634722934, 0.008921886779247754, 0.04059806728975908, 0.10643385170448212, 0.057283860646308436, 0.20314811608724057, 9.066653770785178, 74.73737470565304, 93.71915955697337, 88.3153493942753, 75.15425989704748, 70.754592187943, 52.50120716710245, 68.88916000243157, 40.2197091810165, 45.99814099650229, 64.4126844406128, 51.299655745106364, 73.57411738364928, 75.76527887775053, 74.54713190755537, 38.17039235945671, 4.797865258109185, 0.14644231857551684, 0.12933661710591088, 0.194398396077656, 0.06016301058773553, 0.05614829234658711, 0.03717665733288854, 0.05535941713699891, 0.05589408905155236, 0.049846878260253906, 0.09346701685459384, 0.23559811434918837, 0.5131250788127223, 0.23336768000116273, 1.0047196548792625, 0.8364025383226333, 2.3446791402755247, 3.3430706637520946, 7.7485986390421475, 10.1698007698982, 2.0829950273036957, 5.196017209560641, 4.020145790230844, 7.972687569356735, 4.864073886025337, 3.5597259671457353, 7.554476126547783, 3.577084661491456, 3.131364901219645, 9.881793875848095, 14.408053140486441, 13.238281742219003, 6.473106616927732, 5.815756109453017, 11.549215009135585, 6.9418548576293455, 6.510189194833079, 9.382979196886863, 7.721079289913178, 1.2378297914420406, 4.007759435522941, 7.63766763671752, 0.9419163184300546, 3.157144924325328, 2.8753079185562753, 3.5664057635491897, 1.7085305144709928, 1.4458446036423407, 1.7700805923631115, 2.152494033498149, 11.336854946228767, 3.5717656823896595, 2.347698629863801, 2.449187016294849, 0.41643742832445335, 0.3361876344969196, 0.4650403138610625, 1.3335347656280765, 0.6012490307611804, 0.537033457188837, 0.4429528039068945, 0.033265200083053885, 0.041482082958663666, 0.19751635860771904, 0.2624010180513705, 0.10929246282865925, 0.1516931005302937, 0.21163918949182958, 0.12859083051162382, 0.12162146053367084, 0.18193397701026934, 2.7535269048906144, 28.354490380133356, 59.63808913384715, 59.35100693856517, 53.101486698273696, 75.56814055288993, 56.59178818425825, 42.92183391509518, 24.84292768662976, 23.111781766337735, 42.0162880805231, 54.0222042606723, 54.72346913429999, 77.30500528889318, 77.81066156202748, 32.911552998327444, 0.8861931665770469, 0.2316302232324116, 0.2388300094753504, 0.03988164101517008, 0.10326054698276906, 0.022501059537453037, 0.04714508533417698, 0.01441768950767695, 0.04680264020158399, 0.03658293153069193, 0.09589998186716149, 0.02911878558206222, 0.032757869846518003, 0.025170261168011257, 0.03419146933142216, 0.059263757430017, 0.049508252075963446, 0.062190048591864694, 0.03959704701217913, 0.023291869119050044, 0.02891548116871667, 0.0884743682259033, 0.020331722616608587, 0.047144782729446895, 0.09466634282181341, 0.03513049011329009, 0.030583944059007113, 0.10407431621945674, 0.037884955414600914, 0.04520936884106167, 0.0401269615207228, 0.055064235798894405, 0.0066330904167355795, 0.04708007511292254, 0.06388926608187538, 0.04009489691065204, 0.04626815980901161, 0.050569222564057964, 0.028010346370959477, 0.09540390929267292, 0.01873157370174604, 0.031118922408730276, 0.05587484875333406, 0.01116577554644356, 0.050220924519723466, 0.009717998646890685, 0.0573497173947192, 0.06288217455749551, 0.02544609687080787, 0.08332479414680312, 0.031694045680905544, 0.05587657628160331, 0.019440768106329828, 0.06117935262380108, 0.025409284430826386, 0.027809447473696167, 0.037914576204193216, 0.011700568119845083, 0.045956986385487744, 0.012713691629018756, 0.10754216642629717, 0.06383539477903998, 0.03380324278447417, 0.04105099379235218, 0.0349412817177513, 0.009818733463274136, 0.059556720943580714, 0.052735742196560874, 0.031714230182490526, 0.04859228671017674, 0.08958663596140762, 0.054127969103114265, 0.09191925111677378, 21.515106462663223, 107.13120229782598, 109.36873405210434, 103.33572080058437, 99.76790935762467, 105.4042297793973, 86.73263380604406, 97.63818002516224, 35.71234103172056, 25.98640645703962, 45.96682479304653, 42.885128375022646, 73.27928066253662, 88.20433847365841, 82.09306609246039, 35.00640853758782, 1.7697659447308511, 0.24925936193716144, 0.050117629054453106, 0.2263248498521505, 0.0726487843560115, 0.14226384521011384, 0.05781333082385602, 0.4592718862958493, 0.1650304308221225, 0.2496008532902887, 1.13240028100629, 0.4425405873165977, 0.06995829888769696, 0.4477240301428303, 0.6767563726152144, 0.7604131739466422, 2.773138510604059, 1.8123782065606888, 2.5077443257454903, 4.768682824027154, 3.3589060075821418, 9.14184658758102, 9.213611252846258, 8.483820942140396, 12.311155026958836, 13.814307297429732, 18.309482759045018, 12.637563886181002, 10.438015384058799, 15.357929602746042, 14.445666709253866, 17.175331384904926, 12.353879444060787, 9.422341162158597, 17.868941753141343, 11.087770711991096, 6.676163798378361, 4.750497735315754, 3.667517847591831, 1.605100922526852, 0.41399826566057824, 0.31021602812313265, 0.9708651263386974, 1.6305976769616528, 1.6053150594234469, 2.4183716504804553, 2.4789090214237093, 1.144089802138267, 1.7151629972842433, 2.1050902287806235, 2.957604147734181, 1.1531860237160036, 1.0288288708656066, 0.322367224481798, 0.23487739415178377, 0.3544397405799358, 0.2685189962146744, 0.23231912013744158, 0.6831147185256404, 0.43352872734108283, 0.6812632985172734, 0.28398435022081103, 0.19150635287646325, 0.2122786430822265, 0.3377571341491515, 0.2445164349891486, 0.16472128370115835, 0.09719034206242332, 0.17873580507453413, 0.08850388559362582, 0.23445730217762534, 0.9358250001265157, 21.43479789457014, 62.16773548433858, 73.19454177733391, 52.9647607188071, 59.07877875912575, 31.581577293334473, 16.137905659214145, 29.63768005371094, 40.20889912882159, 66.36953138536023, 89.79533810769358, 73.81339765364125, 86.6589246257659, 95.32824131750291, 52.98691818791052, 2.4634075693545805, 0.364331804936932, 0.15113405552842926, 0.042385959457005226, 0.10200782468722713, 0.020678668515756726, 0.06289137144302649, 0.055640215174325054, 0.024706961834923397, 0.03594586430417915, 0.0966975560051299, 0.0439741401632707, 0.025825404239097433, 0.08251608109041568, 0.06326303516905155, 0.02111299823398792, 0.047627318530313434, 0.03453473800853376, 0.06709380420826136, 0.06057815363390311, 0.043739698106242765, 0.047247170380526976, 0.02017764892849711, 0.08517705685188694, 0.017289455319123886, 0.08291040952768057, 0.06857054593462138, 0.04527710250488693, 0.04739768367501036, 0.039812589680115064, 0.04293349015736773, 0.028854506315603375, 0.04562979023302755, 0.04280692860183697, 0.008602834141422665, 0.04689642085483478, 0.025140720817651, 0.017863071313308134, 0.15989614019711174, 0.1567519621382798, 0.07072408037680773, 0.13701169961883178, 0.08279656886213249, 0.16112330579949966, 0.12473491846673912, 0.1366036658686015, 0.16057826488489108, 0.20140310569155603, 0.1611890514651614, 0.17464739300550955, 0.12872325647021496, 0.1477707916450116, 0.10026389447551581, 0.1174412404878005, 0.10745003669252319, 0.16059505753219128, 0.12695974505115903, 0.23014212808301374, 0.14151099528516495, 0.14615823785143514, 0.13982213913433014, 0.2663141338815612, 0.15407535818315324, 0.26071954698812577, 0.20412978115341357, 0.16961946602790587, 0.14878829430428245, 0.22599635135021903, 0.09030706504540098, 0.23883613817874463, 0.19715346275798737, 0.19878120041422306, 0.24967694114292824, 20.587224691144883, 118.50428719674389, 123.52124183408677, 110.45247708597492, 94.80946079377206, 94.22472953796388, 68.58949876600697, 86.05219671803137, 56.4764508893413, 63.80373254899056, 91.92855834960939, 69.77135596736785, 101.17833875840711, 100.04682125583773, 93.99814205784952, 53.83750377162811, 7.48646762101881, 0.43027346653323023, 0.2706021118548609, 0.47665135694607613, 0.24027316590710995, 0.40159419899986637, 0.08431650262566344, 0.2506582538086561, 0.16032225362235503, 0.26179029275813415, 0.8217553049325944, 1.054856371014349, 1.4305843773388094, 0.8732986810707277, 2.500971127902308, 2.8657866101111136, 9.107760210191051, 10.812440918337915, 17.7860914891766, 23.969898300786173, 12.000008110077152, 22.28465391743568, 23.48033159009872, 24.397668069408788, 19.79956373091667, 22.292404520896174, 23.56863787097316, 12.906783607698257, 15.950001574331715, 22.35534679505133, 28.739127805156095, 25.32292381409676, 17.053600626607096, 16.398752101006046, 23.08375447027145, 18.233588818580873, 18.507501656009307, 19.279906557452296, 15.966440227723892, 7.095879960444666, 12.743094275074622, 15.784875673632468, 11.490342194034207, 12.233742148645463, 11.141756253857768, 9.685334121027301, 8.811262365310423, 4.428388774394989, 10.448702862185817, 13.408537122511095, 18.917330503463745, 12.596010296575486, 10.028463063701507, 3.8780400349247843, 1.4878146999305295, 1.097313944370516, 1.2919531065610148, 4.087066818629542, 2.302683548581216, 2.3337376886798493, 1.6148654179226969, 0.2645902828343453, 0.28637724117405955, 0.5127436896004985, 0.6599400072328506, 0.3827551469927834, 0.2726484552746819, 0.4438891472114671, 0.26745603389797673, 0.2676285568985247, 0.39521906044214006, 4.333109499946717, 37.09984417884581, 73.5150464888542, 78.58132100874379, 73.94398904615834, 112.33760741449173, 82.89137824889153, 59.58404671761298, 34.79680492031959, 30.29755803846544, 54.72535971672305, 72.61734147225657, 69.58363133092081, 98.48700446467247, 106.82570457458498, 53.76121367177656, 2.0142711795145467, 0.6379266239462361, 0.46791323550766517, 0.27203843478233586, 0.17941679595218551, 0.13203718429130892, 0.18291798630549064, 0.15336116505486352, 0.12321718337555086, 0.15831003175868144, 0.28514206229198363, 0.2385007908507701, 0.11066511618874728, 0.1417702854040169, 0.2608478207501673, 0.11533508858373089, 0.1782603249434502, 0.12553579444366117, 0.2042404961802306, 0.10733405098078713, 0.1205409394817487, 0.2184509981663958, 0.05837968430451809, 0.24381811520264995, 0.13838563234575335, 0.15136561326442227, 0.11201085688005533, 0.13590556058672168, 0.2453217772586692, 0.09665645538799225, 0.17771696942227502, 0.11386416146471617, 0.13070342521513664, 0.18866790518645318, 0.11022070092299294, 0.09640327865077604, 0.14298762975921556, 0.13123610147064732], [0.07459665483404553, 0.057555557559094125, 0.061711710952823205, 0.02662348782553548, 0.03146831212835687, 0.021771521668039986, 0.026344806106100162, 0.025856358021677985, 0.05795215744705451, 0.01540434755189645, 0.014100060835781117, 0.0998727453031367, 0.04067768297728993, 0.0316711109236724, 0.027304993897315957, 0.004298216738407651, 0.023566111358964158, 0.12756652499158538, 0.01806286129830105, 0.05210118007756049, 0.10377321302169755, 0.07778609336744394, 0.03178108092998305, 0.07988839184925442, 0.01541645174110008, 0.048199467466122685, 0.09966410891783815, 0.03944938739521369, 0.049550643551253507, 0.05507066710701874, 0.027756108601968137, 0.014068049851865059, 0.14135433030464958, 0.1795569593988119, 18.2748717646445, 100.40247040410196, 90.94802071971279, 73.36700839381065, 78.67573245879143, 89.04804814246394, 45.444749478370916, 32.87702437370054, 31.320739676875455, 66.0679481875512, 68.97061978617023, 57.75358638455791, 72.87519024264428, 72.08368732083228, 59.355133271986446, 16.90440543236271, 0.38949892705967354, 0.1300250390364278, 0.1525928554756026, 0.11910292349996106, 0.058770519380848256, 0.057867834149228956, 0.028090592165808045, 0.034781341711359645, 0.3332627720890507, 0.0850340512190615, 0.9357120481229598, 1.2693336557957435, 0.7133096144084008, 0.7325374407152976, 1.7581890691672604, 3.8064835004268156, 4.222008855112137, 2.2947157438724273, 2.744484861050883, 5.266182038091845, 6.756291937443518, 7.586611615073297, 5.782894982445625, 9.540821256176118, 11.671361538671679, 5.834848736563037, 8.263501409561403, 8.70000139359505, 9.914323072279654, 8.092390462275475, 11.186005492364208, 10.576049473977859, 18.45494777925553, 9.532972593461315, 11.773100956793755, 9.040913216529354, 10.461788869673207, 8.575104301975621, 5.8653196692466745, 8.712997186568476, 2.1047931092400707, 1.0155586345541863, 1.230414795779413, 0.36779277567421237, 3.042724483436154, 1.9705259655752492, 2.6852744769665504, 1.9525615101860416, 1.8823474068795483, 0.9429908639961674, 0.6791705914562749, 0.6276003103102408, 0.4502745513473788, 1.0867479371447717, 4.252289062546146, 4.102179220607204, 4.069652230508866, 4.997231979523936, 4.648790186451328, 1.8919936182998844, 0.3249645996237955, 0.5541398328158164, 0.20281250828937178, 0.9202668575509902, 0.09215448607480334, 0.21324726933192825, 0.2833013981580734, 0.039408761752589096, 0.015085108180139816, 0.1270730647769186, 0.13870699090823052, 0.10167694365185115, 0.21577267817431883, 0.4663715295253262, 7.49510468013825, 46.91882717993952, 87.44557165330457, 67.3064914826424, 61.138968390803186, 79.49021262507286, 58.76608348661854, 39.18470159653695, 27.657189061564786, 20.84486165354329, 46.98271866767637, 62.10802916557559, 61.518045856106674, 82.27543277125206, 49.925763222479056, 5.943314529234364, 0.8253508926399293, 0.011945791906797358, 0.09233637833066526, 0.01162792766286481, 0.06580201908946037, 0.040025822592959295, 0.019265355039087516, 0.046351977488807136, 0.018175275125090155, 0.04105861636719877, 0.02494553502108301, 0.026921739260996544, 0.04766284202736232, 0.014128272981202651, 0.017382728439124844, 0.06686469029274679, 0.04848436790428335, 0.03156300442623756, 0.05276103075894137, 0.04651281764850982, 0.010712661352309008, 0.08038701549653085, 0.0562071547122492, 0.046615848813446305, 0.04031786297057425, 0.014891386569117107, 0.023016251751311848, 0.05366593764554109, 0.19104377366602424, 0.07494590665784574, 0.023122716905368913, 0.04248593776156345, 0.048899445832977374, 0.029887470544406006, 0.01380924141079548, 0.02485613256031948, 0.05082406554250948, 0.03433182813046921, 0.01553078653335932, 0.05597450147052446, 0.05006034866035466, 0.026914894265393098, 0.01517084586779557, 0.021053002058197896, 0.050664301736340414, 0.057243108599176334, 0.04019595922962312, 0.028092172222151875, 0.04252702688738223, 0.01849106422835781, 0.026067578038501165, 0.049290165996118906, 0.036313452442447026, 0.03431852118322446, 0.017901775990462592, 0.046080062240963025, 0.025818338993215756, 0.08041053439580625, 0.010512656862697294, 0.0815299803751611, 0.07295938704403178, 0.08989901597341222, 0.03250577712371465, 0.051299204764467095, 0.03303977488089473, 0.07349279108307055, 0.04419689554901374, 0.023169965378098914, 0.12950526370156196, 0.05216667676464685, 38.531321017972886, 125.98002664504514, 98.33360056723319, 95.5730599741782, 109.13318003377607, 112.45054029649305, 74.43627788174537, 47.4032751975521, 26.041517719145745, 43.44109296798707, 57.69065979988345, 57.93514897746425, 78.44846248626709, 80.91070682771745, 52.254768571546, 10.817090888177196, 0.3637401399112517, 0.1549601590921802, 0.17258667777622902, 0.06767056882381439, 0.18773281826607643, 0.38664834453694286, 0.2724474644468677, 0.5625066161155701, 1.3040016471378266, 0.8742464237636136, 0.8171260501107862, 0.4163766622302994, 0.5539375243167723, 1.625529484402749, 3.177724620026927, 6.292230438801551, 7.996254640240823, 6.5638011309408375, 4.8355935562041505, 3.8234627054583643, 2.1212621610010824, 1.5502251252051324, 1.881023361798256, 0.9950301135259291, 1.060974165316551, 5.4206199703678015, 7.737485583751433, 10.500137882847941, 15.930090642744496, 13.089191471376727, 17.6328033016574, 17.971558801589474, 14.907337523275807, 9.898384521084449, 15.033761397484811, 10.093989199207677, 12.662400334112107, 9.816970825195312, 4.18898347885378, 0.7985837805655696, 0.2943552195304825, 0.5828240033118957, 1.8055689719415482, 1.7400380560467321, 4.198127504317991, 4.191874755967048, 5.176696594684355, 3.7057192815888316, 3.7054780558232343, 2.0888204824539924, 1.5546945434424186, 1.3645938086894251, 0.847158719214701, 1.3682663729113917, 4.263782587743575, 5.351141066320482, 5.414173064693328, 4.852330800025694, 3.615564338622555, 1.749782449295444, 0.13825916655121312, 0.155070046744039, 0.3970063742130034, 0.7909927685414592, 0.3591459106293417, 0.3850455966687972, 0.6699370869225072, 0.3962861902771458, 0.12834034274302183, 0.02437658067191801, 0.1214000074973991, 0.023942555473636717, 0.145576547290529, 0.8974438725459961, 2.9279348494545108, 39.341325759887695, 92.96574284953456, 76.31832522730674, 57.30805220142488, 45.83917517815867, 24.98228361529689, 27.22903882303546, 31.94459265278232, 38.908260791532456, 74.15213354172246, 83.87375154802876, 76.52237476841097, 94.95690268854942, 69.48227728566816, 11.832006131449054, 0.8668283024622548, 0.07405695355226917, 0.09561017846628543, 0.044570328938143874, 0.05409955107156308, 0.030011808529736537, 0.03000302341646485, 0.032012092828330015, 0.05391497367752656, 0.0600103599079434, 0.010115651905746951, 0.03806121692421936, 0.10267007705425063, 0.031206953572109345, 0.027508386410772804, 0.049595792943070975, 0.03959786289581849, 0.09626932051633635, 0.03127629219013597, 0.07868594024330378, 0.01994324517586539, 0.0275716346298014, 0.04457204880553388, 0.035554726623118885, 0.009834960163120302, 0.042352485245153795, 0.05588548971460231, 0.0765412081513674, 0.05347146239552287, 0.07685662187155216, 0.0678640902943669, 0.08318984775894112, 0.05827667612221934, 0.02414547684302013, 0.024275202341678164, 0.0695949740287277, 0.16126543043121216, 0.11891755320492292, 0.16356056856532253, 0.10124408099199496, 0.15853114005538727, 0.10882875746897153, 0.1499577121989381, 0.1049800696332128, 0.15256345302106875, 0.1297696100007142, 0.0906803337256274, 0.2646227956058518, 0.12796657610564463, 0.1424634111143889, 0.12812331003407318, 0.13906977950565277, 0.0887290847998473, 0.25405009277164936, 0.1343150701253645, 0.14168206271865677, 0.20037932111130607, 0.11810064300774567, 0.11977645268122997, 0.16524649826028656, 0.18644959034938968, 0.21155023136206214, 0.1679201604377839, 0.17390082500153975, 0.1519077430449186, 0.15913423511289781, 0.16147199837911516, 0.17729893056375368, 0.24882368773462313, 0.1746829088416792, 39.598637165561804, 145.7019470584008, 111.486586447685, 93.66674100199054, 100.66281380191927, 106.75271711041852, 55.62315102546446, 41.66245106727847, 42.73858862538492, 92.23164773756459, 98.86652515780543, 84.41608982701456, 99.61879653315391, 89.8048145540299, 74.46673900850358, 23.384700282927483, 1.2447470138149879, 0.5016735352335439, 0.38507863038009216, 0.4802398353574738, 0.2608477594631334, 0.3157927804896909, 0.14534918771636102, 0.42860523346931706, 0.8407193518454029, 0.9163375619438388, 2.8530962717148567, 3.4676272446109406, 2.24992914065238, 1.9111814854606506, 2.9538072934073787, 6.078695626028123, 7.360937556912822, 6.636028145590137, 7.215294559155741, 8.639642000198364, 11.874978638464405, 14.480496375791489, 13.600950952499145, 20.622833928754254, 30.144595407670547, 22.540637600806452, 22.147015986904023, 19.97590368793857, 24.779100918000747, 25.949559711640884, 24.68525036688774, 29.770162028651086, 36.30710571042953, 19.834400261602095, 24.955066288671187, 17.28794655492229, 25.703970309226747, 22.018895687595492, 15.648609592068581, 16.478081057148596, 5.19388638196453, 3.0632853027312987, 4.108409905625928, 2.2187031517105718, 4.03264785485883, 2.3234689235687256, 3.055780092554708, 1.8228348777178796, 2.0844808701545965, 1.138008412334227, 0.9052284903103306, 0.9328519661099681, 0.4775083948287272, 0.8981397868164125, 5.529214710958543, 5.815494781540287, 6.696805271410174, 9.008194765736981, 7.1457931014799305, 5.569836737648134, 1.2917053843698194, 2.815637636569239, 1.2559963714691902, 2.616386870222707, 0.35509869876888495, 0.3883716440008533, 0.5565743989521458, 0.3583732956359464, 0.2441176862245606, 0.21747777538914836, 0.49971930622573824, 0.27904283796106616, 0.44239264041666065, 0.9603186083897468, 10.68455792242481, 59.89555743432815, 104.6887816152265, 84.15759778791859, 87.24374217371788, 113.35831795969318, 75.10119807335639, 52.950165579395915, 35.20537860931889, 26.72811096714389, 61.911659625268754, 81.31962176292174, 76.07340458900698, 107.46156000321912, 76.91766338963663, 10.441215057526867, 1.2294313840327726, 0.13786810930938492, 0.3604337044300572, 0.1802336755058458, 0.1267946760861143, 0.17783457924041057, 0.09796605205103275, 0.1479208223041027, 0.2050718088303843, 0.1209055973337062, 0.10106336851153644, 0.13833419720251716, 0.30496498569846153, 0.20742389794078567, 0.13173359896867506, 0.2563382595056488, 0.07751891254297189, 0.17358968605197247, 0.21598368943218263, 0.1923026093432019, 0.08539647975515935, 0.13266480948415496, 0.12967478363744675, 0.1399621953286471, 0.1416569043912234, 0.10113562592455458, 0.09873007919879691, 0.19376399866755933, 0.26629899598417744, 0.203590577828788, 0.18791425853006302, 0.11959443785130017, 0.1224488048483768, 0.07960382848978043, 0.16091410250913712, 0.13675078539358032], [0.04156330360039588, 0.06996853382236536, 0.06828093405572638, 0.03563009818354922, 0.010120022437354971, 0.06958539026879496, 0.09703345491640991, 0.044474548795410705, 0.019203344052056634, 0.0032109960081851893, 0.046809967832579735, 0.05451647527215462, 0.03492226358503103, 0.03867472694706052, 0.05203876306392974, 0.03661411130921014, 0.04182215704913101, 0.11854806899904244, 0.050570869653095166, 0.10587925767345775, 0.013253364182497947, 0.04096822565301292, 0.015115199156195648, 0.019082865234644666, 0.07081076322544007, 0.06511053280724634, 0.08581715395614024, 0.02834735994016932, 0.05899717032368626, 0.020367284418053685, 0.017285550185929865, 0.0536194973955712, 0.19047689924557365, 19.206205221914477, 105.41613809524044, 77.79171651409519, 92.75183246981715, 68.8594284365254, 59.41008960047076, 56.60000554976925, 36.317154822811005, 62.13384620604977, 82.79873186542143, 56.64272408331595, 47.67654280508719, 88.99882239680137, 90.78641906861337, 33.579073721362704, 1.4124159587006415, 0.3485093620275298, 0.09051537967377132, 0.22120122317104574, 0.052936897733278816, 0.05596736919194941, 0.06441446531924509, 0.056042242795228965, 0.15786334121179196, 0.21948884812093553, 2.8528413176536564, 1.7669235746706686, 0.522647183989325, 1.9986692167097524, 5.206485525254281, 8.188264466101124, 14.27411106324965, 19.395118336523733, 19.918187972038023, 15.99327806503542, 9.464025170572343, 7.468658099251409, 4.846776723861694, 2.7724829844890104, 5.621146732761014, 5.506438487960446, 4.051210716847451, 8.808675562181781, 8.286929726600647, 16.333150459874062, 15.007909055679077, 8.986625652159415, 14.37676537421442, 9.65958179966096, 18.0219945984502, 14.880833087428925, 7.550448832973358, 4.372999024006629, 11.24446940037512, 5.021498703187512, 2.217969178192077, 1.9895347520228357, 2.124843284968407, 2.6178805578139523, 8.884341024583387, 25.952066106180993, 45.565123096589126, 68.09568805079307, 71.10831937482281, 73.70819184087938, 71.6170507861722, 59.36108350753785, 36.22415934839557, 25.363792950107207, 24.999120389261556, 21.706884868683357, 15.698994398117067, 13.28571790649045, 11.906402707099916, 10.131298784286747, 7.97547931632688, 4.809916740463627, 2.761066680954349, 1.825528197711514, 1.5152456731565538, 0.46299951691781327, 0.15233226300727937, 0.5361576654737996, 0.10400126207499735, 0.07647286544764235, 0.08190971483746845, 0.00678951982521422, 0.09391397553225679, 0.037929499596958204, 0.31952038046813785, 0.028508853189827457, 0.847562294333212, 0.37627508503294765, 14.914466431063993, 83.50869655609131, 85.83876486747496, 55.84835783127816, 66.97811849655645, 69.66975089042418, 49.63764944384175, 41.09608434861706, 26.33980024245478, 50.25543059072187, 53.56806047501103, 52.632932124599336, 91.27994737317486, 61.38394786465553, 17.146633363539173, 0.10505475554495089, 0.045675644425735365, 0.02416028532259647, 0.02040173347678877, 0.03445474310748039, 0.02829699540480731, 0.13557882408701605, 0.041261380688557704, 0.11091235574455031, 0.09957944088044668, 0.02772725006986049, 0.12432614161122231, 0.032059270437927015, 0.03129964446528785, 0.04175923058703061, 0.07541541896399952, 0.025882043034559297, 0.011089992213753924, 0.05385453700118008, 0.04225035040308872, 0.055299198795710845, 0.04658081944310858, 0.1401994221152798, 0.061824088390435905, 0.033937105157923315, 0.037639868565865105, 0.06319604078007322, 0.04058605886154598, 0.010047952715878286, 0.029785812592073798, 0.04621304744373887, 0.04821754714113571, 0.025334904954257994, 0.067497716405459, 0.06768061223650171, 0.058897027310224316, 0.049451921630891106, 0.020765347533949444, 0.02089363661774945, 0.04087776599091388, 0.07080231327563524, 0.09771466029868012, 0.021650529571718747, 0.033581954457106135, 0.02436060199303733, 0.06855902397224019, 0.06702394465044623, 0.055243672742958994, 0.02556814999890424, 0.05006032184727731, 0.05938833481782387, 0.0076195698667077295, 0.021132246193085468, 0.06774406729926986, 0.0553495537549738, 0.09678197889438561, 0.040896117627140016, 0.0742729597033993, 0.0513374517040868, 0.024804749128018177, 0.0665138143625471, 0.06463921253359126, 0.0626373366873351, 0.02363934936452537, 0.035971394184255795, 0.07251459639519453, 0.07477801848923968, 0.09173552791077284, 41.70762500455303, 125.5932495670934, 91.44284340643114, 117.91895974066951, 98.88764319881317, 89.60012174421742, 77.35349362896335, 37.449668607404156, 30.7378323231974, 47.3978623267143, 46.52855134779408, 49.964359344974646, 93.35915657781786, 94.40969282580961, 27.456495108142978, 0.2220681589096785, 0.4911449437420215, 0.11718545905164174, 0.01970531358834236, 0.2137735870576674, 0.3692877502931703, 0.48329925344836333, 0.3597728156995389, 0.9694911323247418, 0.541652293214875, 0.5101735871886054, 1.4576580471569494, 2.047718946010836, 5.496725718821249, 8.131543561335533, 12.585771929833198, 19.481663473190803, 25.240232406123994, 25.025286520681075, 20.648509763902236, 13.631930812712639, 10.05657567131904, 5.799596924935618, 4.1362187747032415, 2.8016634573859553, 0.7228561118245126, 0.4214361520303834, 0.9408015685696757, 2.079619827770418, 3.715881162112759, 4.101141998844763, 7.586338029753778, 8.933172572043635, 7.326382456287262, 17.061747389454997, 25.23924789121074, 5.552072323137715, 5.205076413769876, 11.276457309722902, 4.550588255928409, 1.5769940758905105, 2.2204074215504432, 3.2645727597898055, 4.445543750639885, 11.719324281138759, 32.811154050211755, 57.764635701333326, 83.34947970605667, 86.15206810735887, 89.97192321285125, 87.98889052483344, 75.2691068956929, 53.360374896757065, 43.51961097409649, 44.15980062177105, 44.555218681212395, 38.91131631789669, 34.58348289612801, 27.799225930244695, 22.997995768823934, 17.85046542844465, 8.957360848303765, 3.681463589591365, 2.767105414982765, 2.1097701066924683, 0.3780690484469937, 0.029793100003453515, 0.8976424425359696, 0.517103158898892, 0.3626222644121416, 0.42123093239722714, 0.44441348843036166, 0.15829363747710185, 0.027837423089471076, 0.16267195253843264, 0.05695375335973598, 0.5628199154330839, 0.9738691715944199, 7.884946109787111, 80.025161158654, 97.2446878494755, 62.59961589690178, 49.615197796975416, 40.23661067408901, 24.207966558394897, 21.319956779479984, 34.97810079205421, 79.75866748440652, 80.93715144741921, 74.23204791161322, 104.31159865471625, 79.72877902369346, 31.787117335104178, 0.35150062893667533, 0.007456381168712172, 0.04921526941020162, 0.026845952097867287, 0.12953891028319636, 0.011698747703415013, 0.0858766177008229, 0.04371600683718439, 0.06327772107456, 0.047871627799806096, 0.03685710673791267, 0.0847516329057755, 0.027012043790290916, 0.07193773218821134, 0.026613806389392387, 0.04209240988617943, 0.06151466930825865, 0.02376348433655597, 0.0695485491005163, 0.056137310476192546, 0.03462545431008743, 0.06738379147023925, 0.1019272092549551, 0.055224600984084035, 0.055008031758329565, 0.0328924561730556, 0.09860215783720055, 0.016361108057260994, 0.07601708143709168, 0.020242120972984744, 0.0950422928097748, 0.061283663155571114, 0.038321981762325576, 0.06654124031023634, 0.010284661435552183, 0.18903786436684672, 0.14163078079300542, 0.11820883760529181, 0.14547068926115192, 0.19891761003002045, 0.217214118569128, 0.22776304203416073, 0.13112504936514363, 0.12731667307596053, 0.11590127352504961, 0.18354682191725702, 0.1639166155890111, 0.130885110627259, 0.1473010418516013, 0.21035372459840393, 0.10786704899322604, 0.12479432092438783, 0.16464640626743918, 0.26304517542162253, 0.2048704656021249, 0.23871379393723705, 0.12990680102619434, 0.17156273997839422, 0.13434531527661508, 0.1600317990467433, 0.1381310919720319, 0.18874322695116844, 0.09263456273343294, 0.20876174792647365, 0.0687685490195309, 0.22689167830732562, 0.2778744619459875, 0.16744996631337752, 46.952155559293686, 147.69805692857312, 98.27390993795088, 119.63676960237565, 92.88214929642217, 73.89985453697943, 65.67473057777651, 49.45857363362467, 84.6456112400178, 108.74910154650289, 80.89548803144886, 68.26769967232981, 109.54147523449315, 105.88236670340262, 46.524279886676425, 3.5540958950596475, 0.9285948461582585, 0.23359284856386725, 0.5645181791436288, 0.21731374064280143, 0.29099380957984156, 0.3486264815493938, 0.18232938563150747, 0.5500158895888637, 0.9445132339192975, 5.288970028200458, 5.179911957633111, 3.334563042848341, 5.59792188867446, 7.755658905352316, 10.32928434110457, 18.465310681250788, 24.457811732445997, 26.017000944383685, 19.89615797996521, 12.470508179356976, 10.819593360347133, 7.869736138851413, 7.414821607451286, 11.625752218307989, 14.520734990796736, 12.647484540939333, 26.444919763072846, 27.211745092945716, 38.437541069522986, 34.299970057702836, 24.706474311890144, 29.58954864932645, 26.178828131768014, 34.75873831779727, 32.82925578855699, 15.611826585185145, 13.595755773205912, 23.717199602434714, 12.551313907869401, 7.267257138606041, 5.806981277081275, 4.185198881933767, 4.201189404533756, 11.525272861603769, 36.10513894788681, 66.25463731827276, 99.05241412501182, 99.70209983087356, 100.22444186672088, 95.820326189841, 81.83203235749276, 59.037134955006266, 50.12566289594097, 53.86319921862695, 52.977955572066776, 46.173012025894664, 39.395689810476, 32.21964689993089, 25.73427454117806, 19.61521037163273, 9.20894951589646, 4.272769228104623, 2.9250911310795815, 3.499459730040643, 1.4572531850107255, 1.0350319767190566, 2.307653436737676, 0.46133980275161807, 0.2437890038615273, 0.31458380181462536, 0.38015636224900523, 0.30636125754925514, 0.32001747960044497, 0.46121597229953737, 0.16472877604105782, 1.3462993839094717, 0.8230541610429365, 18.68235307355081, 100.18492790960498, 99.75803282953079, 73.23156110702023, 103.31521464932351, 96.44072747999623, 72.66024435720136, 52.11790530912338, 30.65665691129623, 65.46810403946908, 69.69672895246937, 69.03706473688926, 113.83315224801342, 88.88868224236273, 32.4760796946864, 0.31968922624664925, 0.18349132650802213, 0.13643293551379634, 0.1543925645490808, 0.18627316030042787, 0.22703591734170916, 0.2147262020697517, 0.09418858740959438, 0.2730432357038221, 0.1081675929468005, 0.15582649728223202, 0.11632474394695413, 0.19608984160567486, 0.16266732536736997, 0.1103725548713438, 0.2347988854613035, 0.12206740797527375, 0.16630751471365654, 0.17178629975645773, 0.183255095635691, 0.1745120252692892, 0.19429017849747213, 0.40878243263690706, 0.15463582810855683, 0.14867699705064297, 0.12202662145418507, 0.251068769683761, 0.11512877344484292, 0.12909162218772596, 0.1405690748605036, 0.08892717981530775, 0.28564268542874244, 0.19536873836430813, 0.20447776893213873, 0.13580498856402215], [0.061607787295454935, 0.008791013106313205, 0.056917371844211896, 0.14561705801996494, 0.13181114238837074, 0.07880325128714885, 0.037031943323991956, 0.132503456045543, 0.16161766233703784, 0.013013665804699545, 0.06670968006214788, 0.06107899510572034, 0.0792686803446662, 0.021444744948718338, 0.049178186924226826, 0.02796211539046659, 0.027637504784750844, 0.03694869637970002, 0.048162465419379935, 0.03676941265322028, 0.04497581161558629, 0.00656854942433476, 0.051078908520961, 0.1300790175915726, 0.07830833550542593, 0.1889642126738064, 0.025687330297284552, 0.08907862007617952, 0.04456440324804956, 0.16448128367623976, 0.17974808301416137, 0.06523298430106332, 32.968388142124304, 105.37897756022792, 82.5270998862482, 101.08552763538977, 64.58888907586375, 41.229248815967196, 34.5205916127851, 36.29722525996547, 74.92334212026289, 105.27682335146012, 74.7142562558574, 69.43957051923199, 123.74754690354871, 73.08366421730288, 9.946077600602182, 0.49989161472166743, 0.11346304548844216, 0.1116840284497988, 0.09295906991727891, 0.15970555284330923, 0.09318095962366751, 0.05992567654879344, 0.2195156152330099, 0.2741444411296999, 1.5821847199432313, 1.2763386412012963, 4.993696943406136, 5.954956614202069, 8.721386155774518, 15.564138408630127, 21.97671255757732, 30.208918356126357, 36.428793322655466, 35.598470703248054, 31.300357080275017, 29.06161919716866, 25.755078792572025, 21.380745672410537, 18.317390257312407, 11.010687312772198, 5.266186450758289, 2.7580699901426993, 1.000984148873437, 1.5212374613169701, 3.886059811038356, 5.248159237446324, 12.05850535823453, 7.316210769837903, 14.519338627015392, 12.636541128158571, 8.212344877181515, 14.66448103227923, 5.175719434215177, 2.485749144707957, 2.8026325279666535, 1.543391253198347, 2.2074599227597638, 4.272397093234524, 10.239806252141154, 18.05175362094756, 41.856573089476555, 55.96384417626166, 60.57134259131647, 57.29072709237376, 59.799788844200876, 60.70145937704272, 67.60681167725595, 68.14234856636294, 64.076439257591, 52.7412130755763, 45.77990816485497, 47.495329303126184, 54.93978784930322, 60.9645680458315, 67.98857596612746, 70.62495000900762, 67.56725849643831, 48.88927690444454, 26.53135899574526, 3.9197573834849946, 2.8122567986288383, 2.351664636404284, 1.7206631408583735, 0.4204714328290955, 0.45715656431932605, 1.4491134088846946, 0.05222059020231809, 0.007278192947964154, 0.18408571880671287, 0.12492434136689672, 0.10646450288233258, 0.03282311755502897, 0.45582556315968115, 0.028156196105203805, 0.8196644977696481, 2.9377750956243087, 63.612940619068766, 90.54235350701117, 52.578446480535696, 45.935132042054214, 68.82625302960797, 87.80366051581599, 42.77911455400529, 17.239946549938573, 27.565444823234316, 36.26289667621736, 49.5766761995131, 71.90834952938941, 76.63338568902786, 39.52987409407093, 0.6067914623887308, 0.11764339576925963, 0.04993194466336601, 0.11283516748658112, 0.03855482269559176, 0.03616136483727925, 0.06530973098931775, 0.05044790871080853, 0.06768314032665185, 0.05579809823464002, 0.06840008371058973, 0.06690649571077478, 0.18312101492718344, 0.03895619148088079, 0.07979014873384468, 0.06794485894422378, 0.038090221013032624, 0.03944282968258185, 0.0387325321113871, 0.032074754990096536, 0.02179936513364796, 0.1550437239629607, 0.052227412215283806, 0.009898551206495012, 0.07600633322351402, 0.13268238354113795, 0.11761790802401882, 0.06655368157812665, 0.010117079702115828, 0.0410736010469977, 0.010187029275262069, 0.041406194288884444, 0.017945274462803237, 0.08776529256494776, 0.019622978288680315, 0.008657480150671496, 0.044247461182455865, 0.14016562231606053, 0.0806922632299604, 0.07529216307786203, 0.03987094259730751, 0.00531849694520896, 0.08694351770945134, 0.0186135157221748, 0.013865623566802713, 0.0906782576273526, 0.09738010204126758, 0.0503478231539409, 0.04436328601572783, 0.02285423564664539, 0.011827721478297346, 0.012865290853134807, 0.03437195964638264, 0.05064360587106598, 0.03523726361773668, 0.013225740009558298, 0.03308406625423701, 0.13970999918397398, 0.03943938994780183, 0.09171006314816976, 0.005684444218904021, 0.1548646738932979, 0.10466270238882112, 0.2491575182085076, 0.12707570778025737, 0.10927740920094714, 56.892586908032825, 122.47946031631963, 95.65408045245756, 128.88181963274556, 97.26506848489085, 66.36929604314989, 52.477967123831476, 23.65764625610844, 30.25012677715671, 74.58862273923813, 68.60462342539142, 78.21581102186634, 135.51983494912426, 68.0836542191044, 4.516117486261553, 0.6271983899416462, 0.2207344764422986, 0.14149780325110883, 0.2508224877378633, 0.3762437367150861, 0.1928570271740037, 0.2813884766111451, 1.5494666368730607, 0.9238318630283879, 0.6690981900019031, 1.6407649507445674, 4.710481714817786, 7.833313990023829, 14.294446591408024, 20.75399406494633, 28.91463818088655, 36.48755042783676, 40.30463633998748, 40.81919247104276, 37.023024559020996, 35.1363213600651, 30.737793099495676, 28.87896030179916, 22.8080451873041, 15.168977264435062, 8.335662234214045, 4.238843177595447, 0.7952344441606153, 0.5632851453077409, 0.3671321627353469, 0.6561029486117825, 1.2307354495409997, 2.666225241076562, 3.501074030514687, 5.470105082758012, 8.87471454758798, 15.314428556349972, 7.611738318397154, 4.463331209075067, 3.894970700625451, 0.6770829099320597, 1.414765458433859, 6.376484420991714, 13.409348072544223, 25.5342964203127, 53.53046063453921, 71.69287020160307, 74.58409632405927, 68.61660234389767, 72.44248220997473, 72.78474038647067, 79.81788742926814, 83.69103970066195, 79.72869273154967, 67.40536658994614, 55.65761296979843, 53.64823372133317, 61.01787305647328, 72.06340866704141, 82.6805430073892, 87.66527929613667, 85.26695389901438, 70.85403211655156, 46.03858455534905, 20.3464166579708, 5.276958750140283, 3.672123690766673, 1.4990716571769407, 1.032621925396304, 1.138036972092044, 0.5929296836256981, 0.3470679522762376, 0.22059869501859913, 1.0094004520966162, 0.19474597016890205, 0.325938266732039, 0.15944286129407345, 0.1989578909330791, 0.06395689632383085, 0.800731891105252, 0.3067721871118392, 51.776537510656546, 102.17749195714151, 61.31923267918249, 41.91172161409932, 63.63783982492263, 50.73154749408845, 9.54065945840651, 17.126284107085198, 42.51351125778691, 66.2771438783215, 75.35589325812556, 85.43353696023264, 92.02083603028329, 57.17032601756435, 1.7100259180991881, 0.28890413622702327, 0.042184838394243876, 0.20227042447415092, 0.038630140629867395, 0.02517406862499493, 0.0956487586541522, 0.08763946262338469, 0.07563185412436724, 0.04590493837191213, 0.14316246634529484, 0.04456000207292457, 0.11985991796058033, 0.0685639652393518, 0.06500007825032358, 0.026336953704876286, 0.06932963181527392, 0.04135698080062866, 0.11473554817418899, 0.08290774354170408, 0.02922159458150066, 0.10362657613211101, 0.009422948501343209, 0.047611537119073254, 0.06376024155366807, 0.12414838623015151, 0.07381601890008296, 0.1220101965290885, 0.11776859751872479, 0.03786486092834704, 0.028012529721543677, 0.020200273420120922, 0.029635789593861952, 0.036528512474990664, 0.21557323484411164, 0.09968111606975717, 0.20363214575955946, 0.185217353244943, 0.16033414330693985, 0.30606260583285366, 0.222245937273387, 0.17075608003764384, 0.300448008722836, 0.10341269204453116, 0.16125905657968215, 0.10692130578982253, 0.1888617867183301, 0.08027938014316945, 0.14864198683250338, 0.18752997350548545, 0.1492778091661392, 0.14346517832769504, 0.16500536442524003, 0.2074596282815741, 0.15154565924838667, 0.10569732711319962, 0.13029355285388808, 0.22785170905051694, 0.1942708577600218, 0.21959893495565463, 0.0646724377668673, 0.3411576758709646, 0.3240713717476014, 0.2683110799520247, 0.4497943367929228, 0.20363398437057773, 60.88734442187894, 141.72133753376625, 103.91721217863022, 127.14802219021706, 80.79843290390508, 51.12928367430165, 46.66768566254647, 46.47909025992117, 99.06125514738022, 142.05549209348618, 103.85803145747032, 92.92349107803838, 145.83926139339326, 89.11984320609801, 13.401522944050452, 1.0382040710218492, 0.2800174243748188, 0.5957482743167108, 0.30028495456903215, 0.2762335935427297, 0.26484535946961374, 0.20811205940140834, 0.8666216425838009, 2.510928064584732, 4.198002478768749, 3.8131498136828026, 9.261962309960397, 8.57939439435159, 11.666739025423604, 18.535301454605598, 27.64264295178075, 36.27301639126193, 41.75064948297317, 42.627212924342004, 39.048261950092936, 36.807356957466375, 31.020497929665353, 27.676049778538367, 23.566209923836496, 15.123431682586672, 8.687674364736004, 5.964126625368673, 3.8653082664935825, 6.178739109346944, 11.766543734458185, 14.106967103096748, 28.724675832256196, 22.26024893022353, 29.09340608504511, 28.719588518142704, 18.65564565504751, 25.499410860000122, 13.1296036512621, 7.666829968652419, 7.681144168300014, 3.294978483069328, 4.2731761740100005, 6.911216733917114, 13.472648262977602, 26.705512231396092, 60.98492514702582, 80.0261260617164, 79.58540854915496, 72.7305018517279, 76.64481547570999, 76.37842378308697, 82.97132399774368, 84.6505298922139, 77.92612045041977, 67.48233918220767, 57.5055278501203, 59.09743747403545, 73.24395579676475, 81.73428689279865, 92.59966019661196, 97.54567484701835, 96.03589180977114, 80.00153280073597, 55.88278055191041, 27.502192681835545, 6.3858647692588075, 3.7866152246152205, 4.871389596692977, 3.5462320331604253, 5.270675113124232, 2.9137086579876565, 0.6002944852075269, 0.19528077614884223, 0.7753498047109574, 0.29764020454979717, 0.7644678628252399, 0.32781459991970374, 0.7508834691778307, 0.16190928136629446, 1.4243259905807435, 4.210494247175032, 75.63162803649902, 104.63309964826031, 63.85364863180346, 68.97808797897832, 99.86180305480958, 131.21647711723082, 60.405747967381636, 23.017117323413974, 34.05771270875008, 50.23051177301715, 65.75096968681582, 90.66564929100775, 102.73216216794907, 64.92684441228067, 1.6481341037058062, 0.396140112631744, 0.18941641905375067, 0.34190222140281434, 0.17411378212273124, 0.19185470837739207, 0.29178683315553977, 0.1678420041477488, 0.18708149031285318, 0.21567593659124068, 0.188572803031533, 0.14030989199396104, 0.23646586214102086, 0.09421705523686064, 0.1667045934065696, 0.11128341043067556, 0.1318467654768498, 0.13134373682400874, 0.20946936802037303, 0.14738931050223691, 0.1536865685615809, 0.3353259694432059, 0.14340539282608417, 0.09200572712166656, 0.2095519982638859, 0.2937006127209433, 0.24752772743663481, 0.25693424526722203, 0.23911698601178585, 0.24873059273006456, 0.15322300875859876, 0.16928201961901881, 0.17639870064393168, 0.22473380780748783], [0.0342852576455522, 0.0614789925936249, 0.06480119416430112, 0.12151613110496153, 0.0033615030782041893, 0.028727925607874513, 0.03383553339048259, 0.01270690025957001, 0.09706320211050973, 0.023516874888070652, 0.023028449786286202, 0.020439388613486965, 0.04915165729940899, 0.0122391355914935, 0.03533829529319079, 0.058028222317056316, 0.048351685306237596, 0.08968523913814176, 0.08480569573059198, 0.0735957992653693, 0.024516521953046325, 0.018485697782448223, 0.026871229168928923, 0.08967303535750798, 0.0553420729063932, 0.06277107648671636, 0.040268706938912796, 0.06638772395108977, 0.25091028141398586, 0.0822316786094058, 0.5973949343446763, 43.539673897527884, 94.71278221376481, 91.26563856678625, 87.47702906208654, 59.84981867574877, 32.84375875226913, 36.65304307014712, 57.890022108631754, 82.66465740819132, 88.91492289881553, 68.92553606340962, 91.33400547888972, 121.2083064356158, 52.93885346381895, 1.36300218441794, 0.20881125252814065, 0.20036594521614814, 0.08514074428427605, 0.40619302480932207, 0.07522406552227275, 0.14354374830520925, 0.2882405508670115, 0.45620450089054726, 0.7973960378477651, 2.330151171453538, 4.054843321923287, 4.6467078981861, 8.176231615005001, 16.1037378926431, 25.47608844695553, 38.16824290060228, 45.60238169085595, 46.87791293667209, 53.16523698068435, 61.168723490930375, 63.025114613194624, 60.814392259044034, 59.796313624228205, 54.168234102187625, 40.256583383006436, 38.20382664280553, 28.826916333167787, 16.247078949405303, 7.964810959754452, 4.509729906435936, 0.6435359197278178, 1.095845752185391, 0.8490260125648591, 3.1394707243288718, 4.988520395371222, 3.267487571124108, 2.2697790303537926, 7.614453088852668, 2.534081570563778, 0.871914268261002, 2.122143223401039, 2.52805975175673, 4.030370183529393, 15.594030791713347, 33.32752427747173, 56.422730107461255, 63.843889774814734, 76.54672484244071, 87.51885721760412, 94.63976337063698, 90.0729948474515, 95.82339348331575, 98.26392358349216, 100.08692356847949, 101.13491812059956, 93.68283840917772, 75.81600296881892, 59.20202747468026, 44.04577732086182, 45.593132741989635, 47.35247265908026, 55.13882460132722, 58.107505767576164, 59.581461875669426, 56.33441794303156, 41.86208401956866, 28.31011268400377, 5.455924733992546, 4.224566240464488, 1.8170405563808258, 2.0769660992007104, 2.8402970875463183, 0.6853651784120068, 0.7125527808262456, 0.2901638299226761, 0.09775434365315784, 0.3459579215174721, 0.03642079285195759, 0.3513350007274459, 0.11075609679063482, 0.42805086160379074, 0.2406918789230047, 0.8110939350820358, 39.55705611936508, 100.3262665963942, 76.78919792175293, 55.87710095990089, 95.00015074206938, 132.6670951227988, 84.80324345250284, 43.45645296958185, 22.348202197782456, 41.32272674191383, 49.496640236146995, 57.35362622045702, 74.0868966810165, 52.40391669734832, 1.9079651419193515, 0.2289272198874143, 0.2207626837996706, 0.16007943439387506, 0.014688827176277917, 0.09394940709875477, 0.03861286534717487, 0.0774321147811509, 0.07510149145438787, 0.11668773938811595, 0.07795406580572167, 0.07074307935732989, 0.06529922792387587, 0.12698636660652776, 0.09385880187995012, 0.03100170712587574, 0.0650183188038007, 0.06969682541826079, 0.01855575077746424, 0.07467281163459824, 0.06962652919032881, 0.07655459170740458, 0.03944253090829138, 0.0497430733465139, 0.020166234218425328, 0.05577354511666683, 0.018533082235784783, 0.024619409476497003, 0.06801278029959049, 0.12927506960207416, 0.1911603875698582, 0.06876837281930832, 0.1390643249596319, 0.0939365444825061, 0.04993907694194106, 0.07776557753283171, 0.09436060479211231, 0.07092575302287456, 0.0808543214694627, 0.10220947435065623, 0.08678138286115662, 0.03532594212541177, 0.011473164495621479, 0.058766742567381555, 0.060561295869129325, 0.052550697488890546, 0.09587411107795854, 0.05260382185599977, 0.055827826276541724, 0.01711877859047344, 0.05683600947621369, 0.054856143336022095, 0.09036733318240413, 0.02449622062305289, 0.030126654685685234, 0.03193110009775527, 0.14132863571566923, 0.050655273390152765, 0.04989007795830408, 0.05943213206445498, 0.06316630124685264, 0.24343226735870688, 0.1255259731964719, 1.9911360596456837, 70.65874515041229, 111.536345635691, 108.61560760005828, 108.99552837494882, 89.52842081746748, 61.87094542288012, 40.29343012840518, 22.866006051340413, 40.922005637999504, 67.56454421627906, 73.5699753607473, 103.711774118485, 129.57983678387058, 44.52632258015294, 0.18698802758609095, 0.09798767105225595, 0.3042066812274918, 0.1680264168328816, 0.5105706658815184, 0.2119956502029973, 0.7387631614842723, 0.477584237533231, 1.7022765403793705, 1.042531425914457, 1.6324237854250017, 2.2499659128727454, 5.51884445451921, 12.452456451231434, 21.448277119667303, 30.239359871033702, 43.58655406582741, 50.37552179828767, 56.484644720631266, 63.53418727074901, 68.88327644717309, 73.18421025430003, 66.61221627266177, 66.8240713304089, 59.64431785768079, 52.817310979289395, 49.32147110662153, 37.562899589538574, 24.388719181860647, 15.121298893805474, 8.81881881144739, 2.6714672436637263, 1.3476315188792445, 1.5180024865173525, 0.8822150252038433, 2.490790370971926, 1.2117294822969746, 2.91301072124512, 4.930980205535889, 4.080627267399143, 1.4758175178881616, 4.5152766281558625, 3.4046545720869497, 5.491742347517322, 22.042482860626716, 39.17615867430164, 73.33055388542914, 84.48194642220774, 90.91129949015956, 100.81155007885349, 107.96032859433083, 102.38726031395697, 108.80274388097949, 109.12615899116763, 109.87282922191005, 112.53282377796789, 103.84368342737999, 89.39942190724035, 75.41861980192124, 58.638516241504306, 53.67561970987628, 56.103268746406805, 61.576344043977805, 66.45569801330566, 69.60085838071763, 68.54280687147572, 57.98808136293965, 49.057499516394834, 20.89816862537015, 7.753582010346075, 4.319223328944176, 1.7065557236632996, 1.5556049010445996, 0.8423650312808253, 0.1866294065069768, 0.469151723889574, 0.5603076373377155, 0.5204278579162014, 0.22824226067431513, 0.3813191611439951, 0.25904809635493065, 0.4005644236120486, 0.039253123329892274, 0.5007264666980313, 28.291581446124663, 105.55848875353414, 83.3093067907518, 54.91952488499304, 98.83779771866338, 115.14916235400786, 41.91849162501674, 15.946379265477582, 27.293810882876, 67.2760852690666, 81.14320924205165, 76.35223019507625, 83.04275035858154, 71.33248283017066, 3.667250636123842, 0.6209852330146298, 0.23580169455418665, 0.12796214045656304, 0.050949217496259566, 0.18673744022605882, 0.05290135508403183, 0.04882845629547392, 0.0473922674333857, 0.07562453032381113, 0.1980292544730248, 0.13652834410388626, 0.11244194987680643, 0.11209188599980648, 0.13843058638515013, 0.04770991813030936, 0.06482082133692119, 0.06653613816466063, 0.02448988890635871, 0.020502022046956326, 0.030154220444420655, 0.06053008927753376, 0.033530707005411386, 0.009109650141439371, 0.0387658569360933, 0.08577787662826239, 0.008775589841177628, 0.060798522655762015, 0.06355306456586526, 0.12312837080248903, 0.21885613610427226, 0.04418537741707218, 0.07336192028296572, 0.16025802481078333, 0.23925779297226862, 0.13750188863806187, 0.19862525555635654, 0.11140946253773668, 0.10853179114600343, 0.2654897619880015, 0.2717164020624853, 0.16078210555978362, 0.2530191988954621, 0.17959314939235488, 0.09752458622378689, 0.09934375393054179, 0.20932719742338504, 0.1328487471947747, 0.15222445911457463, 0.15328331519999813, 0.20569528182668073, 0.13863240458792256, 0.2923344940908494, 0.11518751706687674, 0.17798592757073142, 0.22553309798240664, 0.32744145381354517, 0.12687329202890396, 0.12309821758178935, 0.21297146235742878, 0.23030588703770793, 0.41087627350803346, 0.1910377215714224, 1.6137763473295397, 73.6171300949589, 132.2649266642909, 114.11407239975469, 113.5806300563197, 74.39499885805192, 43.82012336484848, 54.40031682291339, 76.18792210855793, 113.76172588717554, 123.94702296103202, 90.78413624917307, 107.92610983694755, 138.31364508598082, 66.19690002933626, 2.2316602112785464, 0.41579648852348333, 0.5349786868018489, 0.5894819202442324, 0.6569425809767939, 0.2891464038721977, 0.555407187390712, 0.4553927541259797, 3.2905849381800625, 2.828137985160274, 5.657000628209883, 9.38701335460909, 6.83031588792801, 11.348787776885494, 20.598505427760465, 30.472533010667373, 45.61805155969436, 53.35109849129954, 62.07577159327846, 67.75350047696021, 73.88007010183027, 77.34360141138878, 69.64011346140217, 69.07892427136822, 65.00194211159983, 54.93993297699959, 46.36784007472377, 34.21150492083642, 21.498687421121907, 11.430117141815925, 6.248866185065239, 1.6405374532745731, 2.254809549739284, 5.878374297772685, 12.417490482330324, 13.100656559390407, 8.993140709015632, 7.648947392740558, 17.71278827421127, 7.955278619643181, 3.711258403716549, 7.78046005195187, 6.3289526489473165, 6.137833691412403, 23.489386381641513, 44.00216056454567, 83.32260362563595, 93.32211371391051, 95.7989884961036, 102.06344512201126, 107.45784944103612, 102.43409341381442, 111.36060776249056, 113.10799229529597, 113.49382015966602, 116.21308957376789, 106.93901400412284, 87.83652213311966, 74.06562174520185, 57.35868215560914, 55.063852417853575, 58.18191705211517, 68.03660931125765, 74.44568372541859, 76.52151184697306, 77.92299039902227, 67.50759924611738, 61.706939358865064, 30.410279112477458, 8.52685816826359, 5.415040889093953, 6.741776716324591, 7.372027077982503, 5.278830211008749, 3.456847835933009, 1.1070052630478338, 0.4128307170204578, 0.6595225199576348, 0.33499425337199246, 0.6807384363585903, 0.3538088212090154, 0.6034348328267375, 0.30346777410276476, 1.8108602493040025, 50.751402531900716, 117.70362161820935, 89.87315793191233, 68.43662831091112, 119.0529561811878, 172.3683689486596, 117.94166241922687, 55.73457379494944, 29.10323162232676, 52.71618050913657, 66.9980598265125, 74.74134414426743, 97.20022386120212, 80.63095554228752, 3.3190807123338026, 0.7667889253747079, 0.3659167489217174, 0.20895480208339232, 0.17256712721240136, 0.21975967552392717, 0.12843519974980624, 0.1550579119113184, 0.1779705138816949, 0.24287495371555132, 0.22842262841520772, 0.15635915821598423, 0.1540645410216624, 0.19421096500610152, 0.1669607578866905, 0.1865288651277942, 0.22000339873615773, 0.15629708977235904, 0.236107976506314, 0.19104717509640803, 0.12944884898681797, 0.1980076354718016, 0.13902234334138133, 0.09254621747400492, 0.15289699238154197, 0.13978106149983022, 0.27068135598974846, 0.20464459223853004, 0.19255483613139202, 0.33106768503785133, 0.4725716016705959, 0.2614055634025605, 0.19925234448765555], [0.0800485884951007, 0.10593335880267044, 0.025869069335561608, 0.05949956312355015, 0.19973347834762067, 0.10430662472161556, 0.06347860465006483, 0.06077758164235181, 0.14594661372323192, 0.06500136527803636, 0.1410057143338265, 0.10747378541817589, 0.012430541701765071, 0.07814552649975785, 0.032426042692555536, 0.012613057361675367, 0.06370285007682058, 0.10087097319023264, 0.10533389500192097, 0.048842931526803204, 0.10583794255170131, 0.05317464929013964, 0.028012202218956048, 0.08729165104488212, 0.04645405487427789, 0.04100330864950534, 0.04906741827125511, 0.04660320836269567, 0.07401223700012892, 0.9428130090236665, 60.10375684307468, 107.39735080349831, 93.20014369103217, 92.40369858280306, 55.723634304538855, 44.82289298888176, 45.82934571850685, 63.488373987136356, 93.11347499970468, 74.0428327745007, 85.57145534023162, 117.35339318552326, 105.92057058888098, 26.54756819048236, 0.6005592451941583, 0.18973200131327878, 0.5212198702558395, 0.3217482254389794, 0.1645193582460765, 0.10279265878301475, 0.6219588388358394, 1.0798479977153963, 1.1450292097945367, 0.5076338218585138, 3.241634003577694, 0.7719011833110164, 2.90786579731972, 11.747666347411371, 22.144744934574252, 35.03447701854091, 46.32436844610399, 64.28576046420683, 67.77556773154967, 83.43670537394863, 77.81296007094845, 80.60011002325243, 81.05580314513176, 80.09956852082284, 78.96304607391357, 81.78532477348082, 88.72442122428649, 90.9110955269106, 82.43442212381672, 84.81769346421765, 78.46182992381435, 66.99562795700567, 42.06658071087253, 23.76273439776513, 9.396723181970659, 2.2758616458985115, 1.3718875785989146, 0.26645776004560534, 0.7789958929342609, 1.6129006781885702, 2.3006110662414185, 4.406939783403951, 1.1210610765603282, 4.693987167650654, 9.40035431615768, 37.96729987667453, 52.82179424839636, 68.2082365405175, 77.61526476952338, 104.7464326120192, 113.11716279675885, 115.31681229991298, 106.62906046836608, 101.27693929979878, 94.50429254962553, 90.58451114162322, 96.7728659414476, 98.26174274567636, 100.13493337938863, 98.22392325247489, 85.81443832766625, 63.507256277145885, 50.09384462910314, 45.348121889175914, 49.06850568709835, 49.665223706153135, 51.79133269094652, 50.70286712338848, 40.196982968238096, 30.355840536855883, 8.921844766985986, 6.0195090213129605, 3.1048197707822247, 2.2941435681235407, 1.965645311340209, 0.7976286221415767, 0.8952471613883973, 0.1830194776336993, 0.21455272912017762, 0.048858885307826345, 0.1287251104029917, 0.0923804666907076, 0.24638656286462662, 0.04331013728534022, 0.127376856943292, 0.24297908038621951, 14.480742504519803, 96.90887804954284, 108.49827381872363, 81.52521671787386, 78.54334462073543, 97.06825179438438, 97.39792700736754, 59.390975890621064, 24.703799255432624, 34.226821776359316, 45.97853306801089, 58.83925922455327, 76.24507104196857, 48.057357880377005, 2.7594911138857565, 0.2967930338796108, 0.09087665141710351, 0.06066962836250182, 0.08548110182727538, 0.038693308409663944, 0.0758446810106116, 0.07276987221332328, 0.05953770281086045, 0.10031333012926964, 0.044148222152744575, 0.052260614465922124, 0.11101829804359906, 0.02914697378723612, 0.025698561146254503, 0.07247325829080037, 0.05266779019767719, 0.0660093454644084, 0.04122375811059629, 0.11615087263165944, 0.149961527316801, 0.06871011183266679, 0.11500151857974068, 0.11047899512754333, 0.05410524310484048, 0.049914466367373546, 0.07286037784069777, 0.1050472938485684, 0.03431937154082041, 0.18755376819641362, 0.17706781715875675, 0.07939597351416465, 0.05287576391692123, 0.09214720057864344, 0.012688427964495796, 0.025022467485659068, 0.16483711619530955, 0.1100672458508803, 0.11488495064118218, 0.013696522106446568, 0.10863427838851368, 0.09307791313697254, 0.08366751890148848, 0.11339671759595794, 0.03078275153623714, 0.07203436651898008, 0.06888694790822845, 0.06187771454513554, 0.029414095239894047, 0.060803417957598166, 0.023363057839413805, 0.06407888816489328, 0.07780265618836688, 0.06094791363143633, 0.060349277205645084, 0.22786513091095034, 0.011226128910728281, 0.02788422148554556, 0.08117196450550711, 0.1258763511695208, 0.2585614466619107, 4.222432961387019, 88.5847063987486, 121.83149260859336, 110.3876873754686, 119.87639504094278, 95.21422586133404, 61.80326884792697, 29.649525611631333, 25.52915027064662, 53.167778676556004, 75.82637371555452, 96.91950767270981, 130.18617245458788, 104.53285171139626, 18.669911315364224, 0.3403250608713396, 0.30856636503050405, 0.4247462647336145, 0.23628000921059042, 0.24560542897351328, 0.33794372252398924, 1.5799310731311, 2.819162376465336, 0.7259361530023237, 1.1138902484409272, 1.1813977937544546, 1.1140785222091982, 5.024029122244928, 15.239797619081314, 26.088576355288108, 41.19947410398915, 57.855595465629335, 74.6654619709138, 81.17973435309626, 90.25472610227524, 83.06888118866952, 85.47605545290055, 84.69160495265838, 84.85039034197408, 88.21770591120567, 90.61870636478548, 91.56368378669985, 93.49901260868197, 90.4922805293914, 95.78254592034125, 90.33176929719987, 79.61800344528692, 55.328400596495605, 35.505365402467795, 15.64029416730327, 4.363066602137781, 2.329325022235994, 0.6342915673890422, 0.7713045540355867, 1.5409598739877826, 3.1525172629664024, 5.684380242901464, 2.2081992895372453, 6.669728659814404, 14.121406328293586, 47.64436368019351, 65.91747822300081, 85.12992197467436, 89.57632864675215, 110.52067141379081, 115.7946119000835, 118.3657883059594, 111.41745859576811, 103.49068580135223, 98.28400611877443, 94.5017194747925, 99.31259278328189, 104.73246897420576, 106.11257060881584, 106.63038622948432, 99.05719941662204, 83.91984724229383, 67.56555618778353, 61.20538196256084, 60.44928235392417, 62.20955579511581, 63.691101689492505, 65.0181571898922, 56.93447389910298, 45.861536610511045, 27.64681439245901, 14.382973505604653, 7.470001511035427, 5.683097137558845, 2.8380385377714714, 1.827459597299176, 0.6744699372399239, 0.22673055469509096, 0.4317444779219166, 0.34448341676785105, 0.14489430002868176, 0.07618569738922581, 0.13170433440996757, 0.12564347576229803, 0.04379025224836604, 0.5151603599229168, 6.854694399141497, 89.93079323922434, 115.97231880311044, 82.72779972322526, 88.57292359875095, 103.96342554400044, 67.4598483116396, 14.790268501927777, 23.661078330009218, 57.642422491504306, 65.0176041356979, 76.54803491407826, 82.92530675088206, 67.68170541332614, 4.875022692065086, 0.5073781017093889, 0.044642590181601625, 0.0351745554906947, 0.039026093173531756, 0.0287356190458541, 0.07922277635624332, 0.11862766553437519, 0.053013920213185975, 0.06278314237152377, 0.07213335273967636, 0.0763781080322881, 0.12455528617025384, 0.06256268524955358, 0.01516553209043078, 0.07051099302066911, 0.06855062764859007, 0.013128461207323259, 0.07987477846683995, 0.054120538050248745, 0.13435565746359288, 0.06571140620977649, 0.125197934347295, 0.06416410395515061, 0.0515160842558309, 0.060268209781497724, 0.0569940802280701, 0.133619278429016, 0.09945938724183268, 0.1134767814449245, 0.047601409436714266, 0.039802645858857906, 0.14349784431678636, 0.16244166650839392, 0.08235318015419668, 0.15677088451000953, 0.30209632350071786, 0.17101648864486527, 0.25197273811265347, 0.17509239815896557, 0.24255175654205585, 0.16767945561197498, 0.20498763108926438, 0.22870641802587818, 0.13711774150931066, 0.31896830686638433, 0.18550278228377143, 0.1281166757126489, 0.22674244437967578, 0.1362684870799703, 0.2505724059958612, 0.26888736193218543, 0.39672105242648437, 0.21657156998351698, 0.17804801133611511, 0.29800731388311236, 0.19132800760769075, 0.15453709469687554, 0.2521740506973959, 0.3294874907981965, 0.31164159517615075, 3.980230525616677, 97.47125964010917, 140.84154990411574, 117.21945208887901, 118.24456353341381, 73.77208725098642, 61.539156052374075, 66.8348107799407, 89.01066010998142, 136.74683078642815, 104.86256614808114, 105.00849400797199, 138.6585626294536, 129.6737853942379, 35.90825949945758, 1.2522470758807276, 0.2838559845282186, 0.9582363814115525, 0.45928086484632186, 0.2815141456742441, 0.2985949646080694, 1.450881417239866, 4.642855640380613, 4.432764178322208, 5.533058143431141, 10.338308734278526, 3.3674329951886213, 5.629302811238074, 16.205528301577417, 28.365123925670503, 44.08277703869728, 59.51098080604308, 78.77117941456457, 84.53613788850846, 95.54019051213419, 93.8548892544162, 99.95007207316738, 99.12766087439753, 101.37088006542575, 102.96356631863503, 100.23185514634656, 101.57228592903384, 106.01259723786386, 99.83738237811674, 104.24359260066863, 97.34295891177271, 83.88489107931815, 54.546746746186294, 32.14708109055796, 13.276188508156809, 4.009708853498582, 3.0372005604928543, 3.1860098915715374, 2.8774539453368035, 4.739876937481665, 6.115980205997345, 9.354706752684809, 4.5393756704945725, 7.415678155037665, 13.742625982530656, 49.02857988111435, 75.06646156311035, 90.88226610614409, 95.80560161221413, 114.72578171760806, 117.5357049511325, 117.2028055498677, 108.24173511997347, 104.93055651264807, 101.6247280182377, 97.1266088178081, 102.77148785129671, 109.69575774285101, 111.17387156332694, 108.96417294779133, 97.06502760610273, 82.0846643755513, 69.03147143702354, 63.88372536628478, 66.57354954750308, 68.7146302192442, 68.1519740627658, 70.56815408891248, 61.08221169440978, 55.50220081883093, 41.62363529205322, 21.965988797526208, 7.338002477922748, 6.671780549710797, 7.901311709034828, 6.559713040628742, 5.311084351231975, 1.8139276653528216, 0.5887544431513356, 0.27367308255164857, 0.4752306622122565, 0.3229939456908934, 0.5738001617212449, 0.3267717703936562, 0.2731678322438271, 0.6245130985494584, 18.564358372842115, 116.94934983407299, 120.94060467135523, 87.56005779389413, 86.54685466520249, 123.7184036931684, 140.97470652672553, 80.46478825230753, 31.373997619075162, 42.88616780311831, 60.09755165346208, 78.07427621656849, 95.6451766721664, 79.41598569193195, 4.515227108232437, 0.8539626831489225, 0.1967945352437035, 0.17184875124404508, 0.09549881992561203, 0.22939519235684028, 0.20526854020933952, 0.17158167767188243, 0.143783533825509, 0.21185021607145188, 0.11260936307089944, 0.16825098784700518, 0.13378553483034336, 0.19188274719542076, 0.13081957946621603, 0.20628556789409733, 0.2372799837781537, 0.27000925173201873, 0.1166623512343053, 0.13452444195507035, 0.18221045814214215, 0.1329050699789678, 0.31764030877140265, 0.15186101168153748, 0.184550856750819, 0.11185177106169925, 0.11220827007726317, 0.2592907010787918, 0.1527633560040305, 0.30482920427476207, 0.3681106715192718, 0.14399422332644463], [0.0549516438566629, 0.11168923018680466, 0.048958442264026215, 0.05699640147448067, 0.03393212941685512, 0.08628108148132602, 0.10557968665154711, 0.12315038816943286, 0.03611326217651367, 0.10843614506865702, 0.10052212739303228, 0.07724334305572896, 0.13594636242956887, 0.06362502703503256, 0.03161957618900605, 0.05406791930116954, 0.04449240630492569, 0.009219332864778417, 0.11696023686278252, 0.07462844748290316, 0.12179046719064637, 0.09929639437506277, 0.15923309109864697, 0.1878135792550541, 0.06607947315299703, 0.1932232938106022, 0.19626582732364056, 0.34402241569853603, 2.1856517897498224, 65.11590657695648, 99.6259823153096, 92.96258926391603, 72.58239315402123, 57.91994587067635, 34.95320550857052, 35.27786008773312, 81.07135142049482, 66.73076598874985, 77.40621028407928, 96.09064025263633, 118.12695518616708, 56.94585269497287, 3.3678713200553774, 0.24016214444512324, 0.026046625533772093, 0.19323855428205383, 0.12815806744319777, 0.06868786463934569, 0.20422033274606352, 1.1570287207441947, 2.3356079238076366, 1.0503821723884152, 1.4648766791628254, 2.0650793563935066, 2.6096232331568197, 6.5734300594176025, 15.594930975667893, 29.754619636843284, 45.36945566054314, 68.40056603954685, 89.96940505120062, 98.24388027191164, 96.80363301307925, 83.73071839732509, 78.30431538243448, 83.47789026075795, 88.06935402654833, 83.35344129993071, 82.64405712004631, 82.89524570588144, 76.50444953672348, 80.16362082573676, 79.49044012254285, 71.80690134725263, 70.16849594731485, 74.46024356349822, 77.31876496345767, 80.61946299768265, 68.15522963000883, 40.39296419389787, 20.19385018656331, 4.521950541004058, 1.174762001441371, 0.6446828452810165, 1.0837458530741355, 6.584360724495304, 6.583539968536747, 14.228341906301438, 33.39403198611352, 66.06846594041394, 74.15947621868503, 86.97139632317328, 103.22174456811722, 114.07281691028227, 113.72131762966033, 111.60304161810107, 110.77389178737518, 112.35311646615307, 103.82616612219043, 92.20066885794364, 91.097439489057, 90.57373246838971, 95.59929278589065, 93.5376165759179, 93.9951845907396, 95.35218346503474, 81.81165956681775, 66.2707268807196, 56.41339486645114, 50.646451673200055, 49.946661610757154, 53.33797424070297, 50.84657099939162, 40.25019776436591, 28.08843405016007, 12.136333027193624, 7.704130238102329, 11.128920297468863, 8.561649591692033, 4.209916678167159, 2.621337146528306, 0.3476267674517247, 0.6374451530075843, 0.27125745410880736, 0.35501105831034724, 0.08351370376805145, 0.16529433279027864, 0.019613802470567248, 0.05055010100946792, 0.20307768196348222, 0.40176482210236214, 2.860972881317139, 53.41698254308393, 101.54003620147706, 87.26300101126395, 66.1652151230843, 88.162855486716, 135.74737948756066, 81.2304505994243, 32.8183594442183, 35.453578349082704, 49.87763574046474, 64.27418162745815, 77.3373648428148, 60.57104449118338, 8.954980950201712, 0.16281907206341145, 0.11370987901764532, 0.04657630718523457, 0.129431244286318, 0.0619595327354487, 0.09793835031169076, 0.03166421038669444, 0.039314088606906515, 0.04998690381105389, 0.12686154790102475, 0.023129592544489333, 0.08521924531387706, 0.05271901849717383, 0.026429299858488867, 0.014950651130939444, 0.23623565271977456, 0.09758820982589837, 0.12093892981929165, 0.019270424625926444, 0.09787715520829925, 0.019363494732627468, 0.07376548007971818, 0.017040844465936386, 0.07382091420191912, 0.16389337248138844, 0.13832005521943494, 0.20300724783972388, 0.22995213827779218, 0.09023343633499839, 0.038395710064158324, 0.02151091196273844, 0.017097584768048218, 0.06725932516518139, 0.02905773220493669, 0.01080551791200114, 0.03462584501492881, 0.09276200912051624, 0.10161521228691263, 0.09460409051708638, 0.17352769421713968, 0.03832297384618752, 0.0767064686383932, 0.10735876497722442, 0.13025016163385686, 0.12695691052583918, 0.061536265326844114, 0.0397086315487902, 0.052029539365321405, 0.012675726226711226, 0.03491924136816975, 0.05656360393209804, 0.05292932878458693, 0.1638405890234055, 0.30663315747534076, 0.20574447999317802, 0.21445255546319872, 0.2355631654180827, 0.27072897601512175, 9.351296251819981, 92.85361797578874, 114.52246173735588, 116.7410013752599, 110.19163162477555, 93.11998613419073, 58.81696055012365, 32.436557892830145, 25.976092584671516, 44.166433349732436, 84.4028792842742, 109.36036371415662, 126.83248319933493, 52.36343391479985, 0.7873298876708554, 0.12111948908216531, 0.036938810015037175, 0.1910687174888388, 0.23823603086413878, 0.3677243180572987, 0.43964259927311256, 1.7266849596654217, 4.721270193976741, 2.4605667927572807, 1.544337647576486, 2.8144900981457006, 4.50451462499557, 10.301528669172718, 22.186023958267707, 39.677115947969504, 61.804029787740404, 83.135632084262, 94.36047492488738, 101.07600412061139, 97.07521792381041, 92.83296277446132, 91.85785370488321, 91.12465289331253, 94.31616783142091, 86.42879132301577, 84.03811454772949, 86.32044761411606, 81.41601008753624, 84.51890299397131, 82.60488833150556, 78.27328158963111, 75.6318712234497, 80.49918743871874, 84.12188068512948, 87.1304484336607, 79.27442735241306, 51.60580458179597, 28.551542412850168, 7.915112078189851, 2.706219198242311, 0.8821219301992848, 1.633981088957479, 10.11193992630128, 9.238726189059596, 16.787930650095788, 47.741658072317804, 77.31495241965018, 86.3139521691107, 99.71316875949984, 110.42405559170632, 117.08620132938509, 115.74342496933477, 111.4901714940225, 113.73040968371977, 113.1018106399044, 107.35036080883397, 98.70157380257884, 97.07007961888468, 93.50503736926665, 100.09761594956922, 94.76114503798946, 95.91401592377694, 99.75323184843987, 95.50898413504325, 82.8023482907203, 73.8789326144803, 67.54143361122378, 66.16945128287038, 65.84464765364125, 63.98282012631817, 57.251966230330936, 49.6502951652773, 33.48971036172683, 23.22253773289342, 17.8727170344322, 15.889393110429088, 8.999178217303369, 4.732690174733439, 1.3048023009492506, 0.7177868773860316, 0.3486854090325294, 0.2340095237858834, 0.12109434607649043, 0.264124317515281, 0.03127137390566209, 0.10670022047575443, 0.32308832772316476, 0.26731859772436084, 0.47201857811981635, 43.54702834160098, 106.65503440364715, 90.41359778373473, 70.06614562003844, 95.70105475764122, 117.35653108166112, 35.774251722520404, 26.37781781534995, 56.6316080862476, 77.67666555220082, 84.56017417292442, 90.6883833485265, 81.11157140424176, 18.997364505644768, 0.0892147462394449, 0.1505550309534996, 0.06765317096705399, 0.06306665619054148, 0.028833628504446922, 0.15640153819995542, 0.039438800060100136, 0.015337096523463488, 0.02252269769087434, 0.05115731378957149, 0.038462283104778304, 0.0801727407041096, 0.0631615859756787, 0.06882941470511499, 0.08569595118563983, 0.14109790535463443, 0.15584785581356095, 0.12914255171293212, 0.13758580590928757, 0.12082205544556342, 0.05210122604283595, 0.08758545342472293, 0.06244655015067228, 0.06400487641052854, 0.1853168221010316, 0.12011319428922669, 0.13446917637221276, 0.20022732926712883, 0.1159162505439693, 0.05247141504960676, 0.12393885352198156, 0.15805743724828766, 0.20051038343339198, 0.1526029831579616, 0.10529471726547326, 0.24287961153013093, 0.194921174477185, 0.2022836318299655, 0.1665214371056326, 0.3443806690554465, 0.14879037806343648, 0.17791779171074593, 0.21835606455081896, 0.2890996725088166, 0.21350329591622277, 0.17966672447660278, 0.15923771826970964, 0.12956460487217675, 0.3954635957075704, 0.12693749785783792, 0.2883489369865387, 0.26635032387510427, 0.354556737527732, 0.44212956582346274, 0.36029902617296866, 0.2744555034704747, 0.247964596736335, 0.3757852484141627, 10.253111912358193, 109.73199259850287, 125.43478581213184, 119.37326477419947, 97.48484673038607, 75.48928522294568, 43.17030037603071, 53.47040914720105, 117.25406308327953, 101.52597058203914, 102.83623833810131, 119.55767108548073, 141.97749968497985, 70.73191304360667, 4.92552811099637, 0.6762886299721657, 0.17584455860478265, 0.5297410968811281, 0.47424577957680153, 0.3601739393366922, 0.603679184231066, 2.61235271250048, 8.359318048723283, 6.323085273465803, 6.042119033875005, 5.116067538338323, 5.916326170967472, 9.805374337780862, 21.98200579612486, 37.033046214811264, 61.774914033951305, 86.50524616241456, 102.38937054910969, 106.93576628162016, 107.77228232352965, 104.89619654993858, 101.13025834483486, 98.69182279033046, 101.1442219826483, 93.39800373200448, 92.62432406025549, 94.13591138778195, 93.7680087550994, 93.08073889824652, 92.41683852288031, 88.59956433696132, 85.63842588855375, 88.49588824856667, 95.11323267413725, 95.38761815717145, 83.44706827594389, 49.47588697556527, 24.395848089648833, 6.9811888760136025, 3.4774809739282055, 1.7025895945487486, 3.5089496595244256, 14.633544318137632, 10.832015506682858, 16.391831078836997, 45.58022422175254, 80.37387555645358, 88.62329467650383, 104.02433210803618, 113.22349825213033, 116.05071913811469, 113.07759392646052, 112.81314772944297, 115.15967430606966, 115.83678522417623, 110.99496441502725, 100.56313068636003, 100.10269934131254, 98.9207793820289, 106.69050831948559, 101.90321630047214, 101.39694813759097, 103.25284111884334, 96.66001935159007, 83.11795788426554, 74.56026400289228, 71.96217229289394, 71.67954983249788, 68.58522338251915, 72.60555867225894, 63.5551994077621, 53.189061457110995, 41.87557305059126, 34.84685828608852, 23.65117826769429, 16.385508218119224, 9.660933056185323, 8.260054626772481, 4.984212652329476, 2.299447593189055, 1.2123601258762422, 0.38905499442931146, 0.17257265836721467, 0.264817412582136, 0.15386238574020325, 0.21037022613229292, 0.35036795261886816, 0.6275501162294419, 3.789058370936302, 64.74244202336958, 117.98359255636893, 94.34615827375843, 72.90909521041378, 101.35500231096822, 167.04078612789033, 102.46180103671168, 42.908325272221724, 45.81224810692572, 67.70086226924774, 84.02014224759995, 97.39802898899202, 91.71919007455149, 17.68096608500327, 0.25974735076869687, 0.3018229833293346, 0.2383309644797156, 0.260843898379995, 0.12025793128076101, 0.16647326549695385, 0.1812312905226023, 0.10877663284660348, 0.2161473717780844, 0.1550256442879477, 0.11500867384095347, 0.18972299211928922, 0.23329772085191744, 0.11033031278319898, 0.20950280009738861, 0.3499580342923442, 0.22727242400569303, 0.22205603939871635, 0.1203683398724083, 0.1822118983874398, 0.12432242608478955, 0.22457720411400642, 0.17688669865169834, 0.11217126036964117, 0.27246051858509746, 0.3455445711170474, 0.1790536549543181, 0.313126580008576, 0.19416046449013297, 0.13816289994264805], [0.15836499090636932, 0.013635964771252007, 0.10684331803913079, 0.08344803471118213, 0.14800069463108817, 0.09755600348956163, 0.14351976975317926, 0.06269408081988655, 0.2437924206136696, 0.09871979063797383, 0.1748567801569739, 0.09295664907943818, 0.06192274136288513, 0.02628216309653175, 0.07596818204488485, 0.07982440052493926, 0.10221171132739514, 0.0134488477957465, 0.01591276276045509, 0.03958857407973659, 0.06668911826226019, 0.08246663011490338, 0.12739607808931222, 0.07096286998280595, 0.10341779419010687, 0.49588613933132547, 0.2494054702260802, 9.205213458307329, 80.4800933407199, 105.88417099368189, 81.51910566514539, 78.46777623699558, 35.528974148534964, 30.434909635974517, 49.54658377555109, 63.89650444830618, 62.12519345744964, 82.58993625640869, 105.93214942562966, 111.42050235502182, 38.33209991455078, 0.3444635597688537, 0.16620922563297136, 0.21161017008125785, 0.09535039039028269, 0.08480926570031913, 0.21924206055700782, 0.489823104993951, 0.6874422572793499, 2.076791798876178, 2.0930784604241772, 2.083207815885544, 3.782044682771929, 10.790090272503516, 20.828044491429484, 42.32302135036838, 66.60086493338308, 84.59221993723224, 96.71884705943447, 97.84009579689273, 98.86177908989691, 92.81733605169481, 77.9796451137912, 82.79968892374347, 87.13973660622874, 88.53109544323337, 88.01296603295111, 84.6301414120582, 77.78271075217955, 76.52073521767893, 73.59163468883884, 68.57601365735455, 60.803923453054125, 56.62224931101645, 65.91220655748921, 66.95720441879766, 74.45343432887908, 77.85853016761043, 76.85098309670725, 83.97215597091183, 77.99908438036519, 55.37023267438335, 31.024681137454127, 14.47657596680426, 10.399819343320786, 14.455842318073397, 24.763256503689675, 35.53048033868113, 81.9410664035428, 79.25519989382836, 80.03659094533613, 93.92778258169852, 120.79550835394092, 122.72317286460631, 110.49765494561966, 97.33537304785945, 86.2815063230453, 86.19351187059956, 86.35690996723791, 83.56658289509436, 84.3671464920044, 79.11005650797199, 81.42033253946613, 83.14996442487164, 78.63725400740101, 75.39481885971563, 75.56241389243834, 73.98853148183515, 72.29391851732808, 66.32098813210764, 59.601418895106164, 58.57105931928081, 49.56828232734434, 55.0084646286503, 49.817811750596576, 37.872496189609656, 21.854960226243545, 10.823348049194584, 13.350555666031378, 14.512007717163334, 10.96222250692306, 4.402349139413526, 1.135028269021742, 0.844833366572857, 0.5788006321076424, 0.1889978592554408, 0.22632000817646905, 0.23980681754408345, 0.07368936158356167, 0.051590578645587935, 0.26041157964256506, 0.06068748204157718, 0.07825006685790517, 19.19445772324839, 87.45792711934736, 95.64189757070234, 73.77251871170537, 54.551626174680656, 57.60828610389464, 77.31604283855808, 28.850515273309526, 34.36179053398871, 44.30126090203562, 61.41747236251832, 61.61664639749835, 71.80998433020808, 29.526967233227147, 1.3828933815802298, 0.08799898768624953, 0.12278186157345773, 0.15859996539450463, 0.09298790546674883, 0.05669417212747278, 0.06084091030061246, 0.04562468808745185, 0.0509681590201874, 0.06107341798563158, 0.14403574529194063, 0.10765052956318664, 0.13946724124252796, 0.1275730060954248, 0.2519343417858885, 0.1300638643724303, 0.19325019881850292, 0.03711855339427148, 0.02999739267022139, 0.059661514110743046, 0.09165718775963591, 0.09962955069157386, 0.04065371591657881, 0.061479429263741746, 0.08241208465469461, 0.1517788257690207, 0.2159083523457089, 0.0811442397835274, 0.07243277820488138, 0.21299651343255274, 0.04243693494748685, 0.08050753644877866, 0.037461691836435954, 0.09595568412013593, 0.06457548934004961, 0.0751616676608401, 0.08705909739458755, 0.08031457422241088, 0.051849776833888986, 0.09184516275361662, 0.1068031750318985, 0.10813988354657927, 0.0307570263037398, 0.05302721183867224, 0.037371458170274575, 0.047545534813956875, 0.023433897989772023, 0.033695427400450555, 0.021081130891557665, 0.07781057753750394, 0.04150429184758856, 0.18326412015143903, 0.0794284633030334, 0.077791616861378, 0.38161615811048016, 0.4236603810662224, 19.931308300264423, 105.53903379747945, 117.25467497302641, 100.83237001972815, 105.57155024620795, 63.69542806379257, 43.19359925485427, 14.251356413287503, 28.8342393982795, 62.357880223181944, 93.35892123560753, 119.37590060695526, 121.11150233976304, 33.450321920456425, 0.3474490963403256, 0.12717123128353588, 0.28909109232406466, 0.196829131774364, 0.14163994320457982, 0.5109332399743219, 1.9945233940116822, 1.6922671419958917, 2.9752883988042034, 2.603025806526984, 2.8539611543378527, 6.459964225369116, 16.10287791298282, 29.81705004169095, 54.65379215055897, 78.84425317087482, 91.64509650199645, 100.05808630297261, 101.91259076518398, 98.56579703669395, 91.85247221300679, 88.33744802782613, 90.96172548109486, 93.4819346089517, 91.95705829128143, 90.70691262522053, 89.50404720921671, 83.7552018319407, 83.25466817425144, 81.31638972989975, 76.6310401116648, 71.05335127922797, 69.23970222473145, 75.25707306400423, 76.68031292576944, 82.44687957148399, 84.2193280496905, 84.42425620171332, 92.26375625979517, 86.80453085130262, 65.30973049902147, 39.460683484231275, 23.211592358927575, 12.777062000766879, 21.064896814284786, 36.049107889975275, 45.93486139851232, 91.2396175630631, 88.8649989712623, 92.24679593117007, 97.93440526531589, 119.97278336555728, 119.64961928706016, 109.12290342392461, 98.36374005963727, 90.37324443940194, 90.14896331294891, 88.97515481518161, 87.72167513447424, 87.1976778584142, 85.044963436742, 84.05237628567605, 90.018262094067, 86.83070874983265, 83.55983641839798, 82.94349085900092, 82.594768616461, 82.56037727479013, 78.03550750978532, 75.83339475816297, 73.76807074392997, 65.69126336805283, 70.66342846039804, 65.20445016122633, 57.64952590388637, 45.020070537444084, 28.18506556172525, 24.18875086692072, 23.6876465043714, 20.226201895744573, 7.931559556914915, 3.146702839482215, 0.6234256827062177, 0.7272872869526187, 0.04871110311679302, 0.4879483652691688, 0.23866704725209745, 0.030028022780653932, 0.04369250325966747, 0.23899191449726784, 0.056893998501642104, 0.5149668154697264, 13.251496207329536, 86.6534568417457, 100.0947996877855, 73.70284172796434, 59.030325720387125, 65.17752308999339, 30.849849331763487, 28.128763860271825, 55.28318351314914, 66.61914317838608, 86.70753848168158, 72.03516760180074, 87.92560700447329, 46.59426673766106, 2.1625411846945366, 0.14636690488025067, 0.0610634703339348, 0.09393478248028025, 0.20811840260942138, 0.1292127406885547, 0.037863340243817344, 0.06283391484870546, 0.08730286657209359, 0.0696020067158726, 0.02911772071984747, 0.05222767651561768, 0.07442901181357522, 0.07675870817394988, 0.1655262429267168, 0.10255477316076718, 0.16041588488846056, 0.059846731188196334, 0.05100047643927317, 0.12363656288793973, 0.01587615429138344, 0.05590027904198055, 0.05070961200662198, 0.12004832196379862, 0.09526219834843952, 0.18299870132919283, 0.10549523311877444, 0.07080664933328668, 0.09910461958497764, 0.3185387460454818, 0.0840934944309054, 0.18403114270298712, 0.308536671462559, 0.21574753516864395, 0.17891084084347372, 0.3447146833904328, 0.12313716549185977, 0.57771940625483, 0.21394614070173235, 0.33223501917335296, 0.12537636388573917, 0.13930365082717713, 0.2044493777136649, 0.26627929220276497, 0.17838643833754525, 0.19687952503802317, 0.07374854953659159, 0.07504107776067911, 0.0706654440070833, 0.25195160940770184, 0.20930611468370885, 0.32907594836527304, 0.18301924780732204, 0.1690452218416237, 0.5027871206402779, 0.7588952166899559, 21.223452744945405, 120.42233405574676, 126.89038522781865, 104.60497625412481, 103.06282581821566, 45.63482361455118, 40.13417797703897, 65.83172736629363, 89.80492438039472, 92.02645286437004, 112.68141100483557, 128.11128570187478, 128.96356182713663, 51.29702383472074, 1.256855860833199, 0.2641435310004219, 0.4180282558644972, 0.49774497507079957, 0.2643219069127114, 0.5095467127619252, 1.1632938490759943, 1.6669081608133933, 6.062343755076009, 5.791364360240198, 3.369504987232147, 4.598370569367563, 12.816673036544556, 24.443198942369033, 48.38908841533046, 75.97470991073116, 95.14556084909748, 108.83768435447448, 111.73666108039119, 105.54255608589419, 103.36509935317501, 98.71885576555806, 97.85836619715538, 99.69508663300546, 97.45552309097783, 102.70194422814154, 101.9083232264365, 93.0432959525816, 92.38617343287315, 91.02826456869803, 85.5228179500949, 78.86392777965915, 77.35062245399722, 83.52141288018997, 80.51502596947455, 91.72621896190029, 90.0552422000516, 96.17338657379152, 102.61758189047538, 92.83747350015949, 66.26993456194478, 37.393080572928156, 21.53519488150074, 11.980849292970474, 24.862627790820216, 37.058749506550456, 42.25648618513539, 87.26420910127702, 89.26190360899895, 88.5389558730587, 95.32664099047261, 115.46107707485076, 118.84595701771399, 110.40066257599862, 105.10107763351934, 94.44354288039669, 94.18109709216704, 96.28674307177144, 94.09321246608611, 95.31555637236565, 90.71640476103752, 90.54617389555901, 95.91038380899738, 94.06971746875395, 93.70994983180877, 90.9629100368869, 90.11144976462089, 92.29091475086828, 86.24277683996385, 79.09522994872063, 76.6710247532014, 70.50644736136161, 76.04381422842704, 70.19523866714971, 61.04054435606926, 52.58463990303778, 38.6547540849255, 37.252024296791326, 33.7014320588881, 24.539430372176636, 8.336978189406857, 4.8962201610688245, 4.667669044386956, 1.7144263271362552, 0.2645046954914447, 0.5194334145034514, 0.39724278894643633, 0.08380828755757502, 0.1459240600947411, 0.46193180485598506, 0.1562567629040249, 0.6267733030742215, 26.674092085130756, 106.94201069493448, 108.22048371837987, 81.76477939851823, 61.71885551944856, 84.87078666687012, 99.92740077357139, 35.938806918359575, 42.00515639397406, 59.56342681761711, 80.04466318315076, 79.14307502008255, 102.48585301060831, 54.11721975572648, 3.5035049194289796, 0.27403924193593765, 0.376533409881015, 0.2990515223674236, 0.3773456162983372, 0.24639207869768145, 0.1570677589024267, 0.23031748560888154, 0.16738979776780452, 0.1809781291071446, 0.23608723084532449, 0.1302783077041949, 0.3033531673492924, 0.2588579839756412, 0.5463191782755237, 0.19903094507753852, 0.2651849202811718, 0.16242148775246837, 0.13326085653276215, 0.22770624427545458, 0.11290675840310513, 0.12356740047013569, 0.24261374837688862, 0.27852125465869904, 0.17749898676430026, 0.5601943176119559, 0.25289886180431614, 0.31102253484629816, 0.1722475766174255], [0.04750782796632379, 0.17937570299592712, 0.3098554765024493, 0.14099759380182914, 0.028002279465116804, 0.07150038025311886, 0.12247141976390155, 0.20137414756801822, 0.11869183305891291, 0.095022389845502, 0.20856196751757977, 0.2538759916299774, 0.04599452469377749, 0.030978389324680455, 0.020779719343408946, 0.06050867712005012, 0.06908705773492975, 0.03459902810713938, 0.045069381594657905, 0.05865014015486645, 0.15000726276588056, 0.06024977387559991, 0.05279037958732056, 0.46664753568268597, 0.18736950872886568, 0.2612566665535973, 12.483399048928293, 89.33906447502875, 109.70516358652424, 81.1474532465781, 75.67942603941887, 51.79314482596613, 37.75458581985966, 57.177911881477606, 105.31188934080063, 73.60341748883648, 77.89944833324802, 108.06272599004932, 118.36290144151258, 41.3302263136833, 0.5151997061987077, 0.31663158547974407, 0.36581427700096564, 0.2642762480724243, 0.2594318757614782, 0.10321901735639381, 0.38507639340335326, 2.038762826592692, 4.54578286217105, 1.8871679998213247, 4.822417334202798, 13.947457055891714, 27.92018202043349, 52.42523477923486, 86.84087553331929, 102.49834183723696, 103.26176058861518, 103.57806051931074, 103.6254035272906, 104.95144705618583, 95.1846041217927, 81.7696431375319, 87.3978207188268, 90.16724940269225, 86.68698526197865, 85.2165985107422, 79.89617009316721, 78.41699723274478, 74.56758314563383, 69.84906596522178, 61.869674574944284, 63.55142216528616, 60.67767020194762, 60.6315117497598, 61.062395880299235, 73.88256472925987, 81.23272557412425, 83.50292282719766, 85.74991533833166, 76.29014691998883, 68.79022213720506, 72.01332784468129, 90.35853555125576, 84.59681695507419, 49.51552644852669, 47.05663573357367, 69.34548070353847, 84.58400649409141, 85.23141722525321, 83.2603556110013, 119.86778936078473, 146.10204450545774, 132.04999646832866, 111.17243597584387, 87.1326449609572, 79.0408266744306, 78.04258346557617, 82.391566307314, 84.5755341745192, 81.68212721424719, 85.51763257672711, 88.47855137240502, 83.093749015562, 76.99936636032598, 77.96437924908054, 80.43837501156716, 74.86490664943572, 65.39006456252068, 60.96479946567167, 61.204875976808616, 64.84230164558657, 60.26323649191088, 64.82112084665607, 67.56668583039315, 52.77870308968329, 49.0892275687187, 42.98374068352484, 33.97585284325385, 22.171997562531505, 14.576872933295466, 18.15870684962119, 14.843146954813312, 10.418373134828384, 3.7024271872735794, 1.4282722626962971, 0.2774592729345445, 0.16259678399130223, 0.38576142922524487, 0.01802312623288843, 0.3374771749781024, 0.23445941658029634, 0.0674195064892692, 0.12109720358444799, 0.9258124148172717, 4.2089846249549625, 53.27732655309862, 89.55088815381451, 69.76893978734171, 36.211093933351584, 64.95597585555046, 82.21330242772257, 28.45620724462694, 32.43575969050008, 40.282898564492505, 43.66953180682275, 53.80787026497626, 70.94746297405612, 58.07380084068545, 6.526852403917621, 0.3100875704999893, 0.37789698509920033, 0.13512122444808483, 0.1118920672865164, 0.014329375849375802, 0.1494244077513295, 0.03143790609864218, 0.04745746151574197, 0.12854374674779753, 0.4448814455780291, 0.43988428469146457, 0.19508059737422775, 0.2529992959311893, 0.16565620208219176, 0.23989300243556502, 0.18354910485927137, 0.12075343695018562, 0.18561095389867985, 0.25553774359005116, 0.22959642833279026, 0.009198020298724935, 0.2139999507175338, 0.1719346756656324, 0.16624020622862926, 0.020307853232107816, 0.0679947772333699, 0.01875838869431567, 0.07293281145393848, 0.08857123238304931, 0.12442595520687681, 0.009741409336246792, 0.037616073874936956, 0.05276676875749423, 0.0841542375424216, 0.05507594545281703, 0.10356506693267054, 0.08944575239213244, 0.10813981459866609, 0.011154631839974994, 0.059608125443299936, 0.0074200451396585956, 0.0324070820164296, 0.04093810307583021, 0.0289938232350734, 0.0865301366655096, 0.1244961441824994, 0.08336508271074103, 0.07927724520765966, 0.09420372530697815, 0.045283395917184895, 0.5024588979299992, 0.06307756528258324, 0.16682166696315812, 24.34313339571799, 112.048960193511, 119.79820651392784, 105.4195740915114, 98.39201250383931, 79.55665757579189, 35.01913662879698, 12.707800788264121, 58.88230331482426, 64.55693744844007, 89.65091643794891, 115.12244316839404, 125.56361998281173, 36.036254282920595, 0.43376137292192835, 0.30412973535637705, 0.15477052168740382, 0.18214534066857832, 0.27977383905841463, 0.30468922468923754, 2.279941156025856, 4.891682469075726, 4.309148721156582, 2.51715507238142, 6.19179520876177, 18.462741528787923, 35.38404257066789, 61.708167060729004, 94.22101113104051, 106.27221891956945, 102.80099976447322, 103.31062547622189, 104.28330267629316, 108.97761883274202, 96.20616974369173, 93.99479235372236, 93.75905790636617, 92.588803075975, 92.32700840119394, 90.01113122509372, 87.69545016750213, 84.71193067489132, 85.46851665742936, 79.08968371729698, 72.30113567844515, 74.30678475287654, 70.15128458699873, 70.12898199019894, 70.94623134982201, 80.22711615408622, 89.46090113732123, 90.17902435794954, 92.33792827975367, 82.4066831219581, 77.67333153755435, 82.03246547329812, 101.0180393342049, 94.14486223651518, 63.81911608480639, 57.19113419132849, 81.194364793839, 92.478404045105, 85.06208850491433, 92.42473033166702, 125.26134644785236, 140.92558276268744, 125.65361484404534, 107.77301972912205, 88.92141834382089, 83.22260672046293, 80.30930549867692, 84.50858716041812, 87.10831057640814, 85.84155759503766, 90.16338194570234, 87.80377818692116, 85.94747727917087, 81.48268253572526, 80.065200713373, 84.51199962246804, 83.16282195429649, 73.74107699240409, 70.52187012087914, 70.55969745882096, 73.94951174336096, 70.81131750537504, 76.4016285250264, 80.14626826009443, 71.90976158265146, 67.93981306014523, 63.325532867062485, 59.12722787549419, 45.180715130221465, 35.20905779254052, 34.625781736066266, 31.881701369439405, 21.761421503559237, 8.441816279965064, 2.0603497134101008, 0.525863588817658, 0.25016187479899776, 0.309437376356894, 0.6113306252706436, 0.18595589264746637, 0.050223460270752834, 0.11807084984837041, 0.029897466076598055, 0.6448732028084417, 1.1728180992987849, 48.25643385610273, 98.79446337299963, 75.27814403656991, 31.720221311815326, 64.18116654119184, 29.990497250710767, 29.128756446223107, 57.034164859402566, 66.50777924445369, 71.71884413688414, 70.90348535968413, 84.10399467714372, 78.3362356308968, 10.35351086047388, 0.598577161229426, 0.3175172750507632, 0.20703052711342612, 0.11122273626707255, 0.023274808340976318, 0.1375216690282668, 0.0827230474040393, 0.11839155723611194, 0.08974321667225131, 0.35181595072630917, 0.2749096710355051, 0.2648554411866973, 0.13691344118166354, 0.07119121014951699, 0.15106014336549467, 0.08948662318289281, 0.11384069619159545, 0.07279500755811892, 0.0014342080459990088, 0.12607119031130307, 0.06886771910132901, 0.13374936015855882, 0.1788423066177676, 0.04561191357131447, 0.006068671308082319, 0.047533874955749324, 0.05481534532361454, 0.1701859880479113, 0.30371362703942484, 0.5294291458783612, 0.32229273009204096, 0.2638090263691641, 0.2800469647251791, 0.27375793445014185, 0.29630482136722536, 0.2791656571770868, 0.15447973003310544, 0.39848817211966364, 0.3021357617070598, 0.28899747637971757, 0.13093910450416227, 0.2223264224707119, 0.11939395264151598, 0.1776162748255076, 0.1327812395268871, 0.29690929538299965, 0.33867263986218366, 0.20932005748393076, 0.24636995407842824, 0.17749648931766712, 0.5179595839112036, 0.27113279628176845, 0.5204280417773032, 28.826157354539443, 128.2584608754804, 130.61349899538104, 102.87356361266106, 96.8151020234631, 63.129567330883404, 49.725447777778875, 76.79171608340356, 141.433043326101, 109.61025791783487, 102.53944043190249, 130.09151781758956, 136.44123108156268, 56.740783337623846, 0.6992471818962406, 0.4388063989820019, 0.6745830118175477, 0.6187124033608745, 0.5057120443351808, 0.42079006411856223, 1.1294441622111107, 4.6427002164625355, 8.498883824194632, 5.292734032677067, 6.445406838770836, 18.42612816441444, 34.3769661841854, 61.858119272416644, 97.44965522520005, 114.5404261927451, 113.08634865668513, 111.30408640830748, 115.32541798007105, 115.92015912455898, 106.77109733704599, 101.45488938977643, 97.53546099508964, 101.66052356843026, 98.48164650701709, 99.58500139174923, 98.56954682257869, 96.14189778604816, 94.23615147990566, 90.67894612589191, 84.71879482269287, 84.57481245840751, 80.0673266380064, 81.01032718535393, 80.80142174997638, 88.06842050244732, 94.46035415895524, 95.41960900829685, 98.65313253095074, 91.97827046917331, 88.5597130560106, 90.49310422712757, 110.3054117387341, 102.26787121065202, 65.48421321376678, 54.31035726301132, 77.84333490556287, 89.8056225622854, 94.4655866007651, 87.52412888311571, 114.08590978191747, 128.2101058959961, 123.19034284160985, 111.8540576196486, 93.79814824750348, 86.620116695281, 85.78570304378387, 90.86124220202046, 93.22812587984147, 90.52555791793331, 94.83511309469901, 96.52588998117756, 93.33595968061879, 88.04629048993512, 87.29547039155038, 90.40398797681256, 89.05217447588521, 81.34326581032046, 78.05955163894161, 81.77667986962103, 84.79064479950937, 79.76528060051703, 85.2081811043524, 86.27190436086347, 76.23320979456749, 73.39955622150053, 70.69033591978013, 67.25147631860548, 53.20977157162082, 43.071060488300944, 46.276291954901914, 40.80871189794233, 25.78624398477616, 8.75404380982922, 4.89504688209103, 2.5236184029809894, 0.60643250423093, 0.6975424217600977, 0.7157681437750018, 0.3322684818938855, 0.20578183444036593, 0.268155288311743, 0.2774908664005418, 1.082159867209773, 6.946654858127718, 68.85312911002868, 109.2528986161755, 92.1766874867101, 46.41070765833701, 93.69047134153305, 105.07083615949078, 38.9590633300043, 41.868124469634026, 51.64697770149478, 61.59064892799624, 71.18909666615149, 94.06205315743723, 93.30795395758845, 12.864446524650822, 0.7703159941780953, 0.49994183944598325, 0.3366384312750832, 0.16890303592287725, 0.19030822200640557, 0.25565503165125847, 0.11827271401641831, 0.21576906223931622, 0.20774940869981245, 0.5918804496046036, 0.6685353298821758, 0.7525221006043497, 0.5606414678115998, 0.3076418807669994, 0.42657252641454824, 0.3598261354190688, 0.3045281930075538, 0.273844042732831, 0.4308897689465554, 0.3872697644176022, 0.262084317303473, 0.3062277131022946, 0.2907482017913173, 0.36493888365164884, 0.2862212043856421, 0.2506214969100491, 0.1770975720137358], [0.05955161879800501, 0.14872259460389614, 0.06309945624501956, 0.15842460786863682, 0.06562637045018135, 0.09153623013727127, 0.10518763349541735, 0.046024149313809416, 0.01773913743935766, 0.0167966750074899, 0.3016220844320713, 0.10931590511914223, 0.024523661892500617, 0.07162728271777592, 0.02670269940168627, 0.10768920934248356, 0.05458770995779384, 0.0823021050722849, 0.04915442670725527, 0.08387990145673675, 0.07961641531437635, 0.04818811021264523, 0.03440204391916914, 0.3373060922228521, 2.6760478365805844, 34.05200566014936, 91.26050810660087, 89.28459844281598, 73.17180771981516, 62.93890091680712, 43.34466934204102, 31.520676612854007, 62.378041205867646, 125.6546974182129, 68.07715877409905, 64.1576676214895, 120.89706636244252, 102.79271571866929, 22.445335772729692, 0.1890128439352397, 0.06712499164765881, 0.34986380547765766, 0.34667936183752557, 0.14680237989992867, 0.18319170952083605, 0.16532201920786213, 0.9283555815777472, 15.707706962862323, 4.55739749054755, 1.9015673884461004, 12.30129614953072, 36.05235953484812, 70.36241792863416, 98.33232187455701, 103.10263787546467, 96.93300847084292, 96.60475315586214, 101.2362329421505, 97.34495147582024, 90.26615588895737, 87.1977327715966, 97.47671957938903, 92.46198500356367, 81.54562088751024, 80.22149931999945, 77.61267600520965, 79.47140093772643, 81.94801684348815, 76.6204418674592, 71.62560155314785, 71.60132992652156, 67.17272297028573, 61.77443158242011, 68.6253256951609, 68.66270588290307, 71.27258039289906, 75.27508458783551, 75.06366099080732, 68.48944694765153, 70.47355436509656, 62.526334254972404, 76.19415083239156, 95.59662557417347, 103.18510178596743, 87.43223559471869, 99.16635897851761, 100.6178242160428, 96.30270711837277, 73.11649445564517, 81.9360928381643, 109.37311926195699, 102.37827808626237, 81.26711691579511, 69.96510536439958, 68.29303818364298, 70.96099515115061, 66.61100033790835, 68.68233342324534, 69.0548958316926, 67.8753371392527, 74.01965941152265, 63.58159695902179, 67.55965694304436, 66.08157450152983, 67.43480790045955, 68.98649754062777, 71.26796768557641, 60.668268280644575, 57.61774293838009, 49.96719129623906, 51.41221207957114, 58.812520427088586, 59.53497394438713, 56.53786343912925, 49.54715251922608, 52.58662462234498, 47.358011045763575, 50.336113745166415, 49.64998922040386, 45.63327820070329, 31.393338826394853, 23.352491740257513, 19.787984894167995, 14.903959381964901, 7.280994749838307, 1.2864370283580597, 1.0333670531549761, 0.2864432779531325, 0.7889038612765651, 0.22027151418789742, 0.04090868912997746, 0.040769571393367746, 0.11596721837357168, 0.268560947189408, 0.3965273241121923, 0.3819731550831949, 23.98949642335215, 103.91093638635452, 122.82771187443888, 55.93850958731867, 76.0232453192434, 73.24273986201133, 27.401709402761153, 25.98564551722619, 22.437702840374364, 47.02793967339301, 60.1499427518537, 77.19520245828937, 55.47218291990219, 5.345597286378184, 0.417384282355347, 0.13621466174241037, 0.06418794844179385, 0.11297526964617353, 0.2405221751260181, 0.07866677272343829, 0.13482206711365333, 0.13972096956304966, 0.3152865802328433, 0.0872017506269678, 0.1180013733345174, 0.06984016812977291, 0.009290201743433793, 0.03790808360903494, 0.09106441956734465, 0.06342108676870985, 0.06722735631610118, 0.2918710721836936, 0.06737946307346707, 0.132060534651241, 0.24285431530687118, 0.23531499889589128, 0.017909701170039274, 0.10826121655202682, 0.11609824239126137, 0.11593481285437462, 0.03923343870067789, 0.054514019960357304, 0.08283579256385565, 0.035454748318560665, 0.08600162026742775, 0.13045185726256142, 0.056971365721115184, 0.01185786129245835, 0.09648253044654286, 0.027173085048073725, 0.354261763033367, 0.086038606992412, 0.021400675740874103, 0.10019538323244742, 0.04656676172969803, 0.06284876546311764, 0.016759588691075484, 0.0896662401576196, 0.02389052661225921, 0.12077676432747995, 0.09157468009019092, 0.04542340614622639, 0.014692871162908213, 0.46866774018253055, 6.9497094038994085, 53.992272653887355, 116.36516771008893, 103.06925066055791, 105.67751699878325, 94.52829745508011, 70.90016703451835, 31.45150169249504, 18.699415383800385, 103.04739521395777, 75.07415725338844, 74.34519260160386, 130.32948801594398, 108.37754326481974, 19.266168455923758, 0.4790824603649878, 0.020255456648526654, 0.22453320002363575, 0.4390233550821582, 0.48371147003866016, 0.7039891435734688, 0.4712311929512409, 0.7980942810254713, 8.725385992757737, 1.9049346206649658, 2.8216616617095087, 15.851880542693602, 41.18451026178176, 79.1829498352543, 104.60315627436485, 104.0090270196238, 99.50581658271052, 101.85245298570203, 103.35336362161945, 99.79251046334544, 92.74724329671552, 94.70600435810705, 102.75249573492236, 94.46195448598554, 88.10723627767256, 85.70298810159007, 86.11672755210631, 85.50115862200337, 91.14344889117827, 83.24744316839403, 80.67913009274392, 82.76615265877017, 77.68099584887105, 72.41807722276258, 76.56880778651085, 77.34507622257357, 80.13556018952401, 83.39266500165387, 82.26991007404943, 75.73116994673207, 75.89775300795033, 72.694243461855, 90.54356944176459, 100.54602915240874, 105.50773328350436, 95.56958475420552, 101.58662611438383, 104.44308434763263, 100.12053043611589, 81.59876900334513, 87.27706663070187, 102.82794644755703, 94.32912734247024, 77.98083751432358, 71.37466399900376, 70.47018112674837, 72.99687001012987, 68.75017473774572, 72.19418048858643, 73.85383729011782, 71.48952668712985, 75.58771318004978, 67.85701182580763, 71.06958989174136, 70.26433514010522, 73.32618436505719, 75.28881288343861, 77.17406088306059, 67.93931099676317, 68.0500316619873, 59.77211260026502, 61.67102613756734, 69.65554406566005, 70.82757180736911, 70.35989192224318, 65.71979468868625, 67.15767675830473, 63.68549662251627, 66.27006007779029, 66.3083267211914, 64.6230411529541, 53.7366125660558, 45.0286683728618, 37.34839300955496, 27.822767996018936, 14.799542946200217, 4.1701472766937755, 0.3912927372561347, 0.08602365295613006, 0.302892564645698, 0.5149463456003897, 0.25029797797962544, 0.10832367570049341, 0.20627107351056992, 0.1776604627769801, 0.19341532140970233, 0.6990527794245751, 20.453375770199685, 108.58698998728107, 115.7872143099385, 56.17259663920249, 63.95604994989211, 30.09350065262087, 23.993103042725597, 36.67454942580193, 41.35658856361143, 77.45501241376324, 77.89546320515295, 81.8965082783853, 69.42494007848924, 8.879324313132994, 0.7249290844605816, 0.13072672960979323, 0.08865852044114182, 0.12401060531696967, 0.23429506007702122, 0.0663363271122498, 0.09292725428578355, 0.1059665150880333, 0.30626307572087935, 0.04825233519377728, 0.04726243085197864, 0.0397947704749963, 0.03666825457325867, 0.047022074596175266, 0.06713063771566076, 0.094791337727539, 0.07952462265928907, 0.2607638268701492, 0.04420276378251372, 0.05148639834876503, 0.2257351306897979, 0.2300799830305961, 0.02273523537892728, 0.049993541962917776, 0.09363031615653346, 0.03646506890354138, 0.17057261730153717, 0.3950113893276261, 0.1839163061231375, 0.27609971201708244, 0.24854930568366285, 0.22018228026647724, 0.2038572990005055, 0.15183730892116024, 0.14834367219478856, 0.2265412084037258, 0.6418466652112623, 0.20417488841039522, 0.11431087499424336, 0.19238284939239103, 0.16988312284792625, 0.16630089571399076, 0.17836891024583773, 0.2381235844786129, 0.22683385399080094, 0.2519799546609002, 0.17339039593935016, 0.1939910211630406, 0.1531271711592713, 0.40468162526526763, 7.638136850249383, 62.933743000030525, 134.96475681181877, 107.8824067884876, 95.89143876106509, 80.7948164786062, 53.96299216055102, 42.833372700598936, 85.15503298851752, 154.33196160101122, 92.98480556857203, 86.2109193494243, 140.12281479374056, 123.43495753503616, 31.08370300262205, 0.5336417101563946, 0.2513654295715594, 0.781507496872256, 0.57180373659057, 0.5056380095981783, 0.4921651277090273, 0.5455258789081727, 4.469840872672297, 24.45121822818633, 8.058052562898206, 3.1248101303654336, 14.272295005859869, 40.815783931363015, 85.77825054045647, 115.13138617238691, 111.18789795906314, 106.6612631274808, 102.92453089068013, 110.68737214611424, 108.15612546859249, 99.78456374137633, 101.4005567181495, 104.83785521599555, 103.71176627374466, 93.99818128155124, 93.13993530888712, 93.78422383339175, 91.75554260130852, 95.86826539808705, 89.43305230909779, 88.57704208743188, 90.19607097871842, 85.72634189359604, 80.8635050250638, 86.41134462048932, 85.40773560923915, 89.95836750153573, 91.03549741929578, 85.69224080731793, 80.18174217593285, 81.56961010348412, 76.47967584671514, 97.39138449392011, 112.76025064529912, 117.72037013884514, 103.99262366756317, 106.40057456108832, 106.11018580775108, 107.99235082441761, 89.92167765094389, 86.57238929502427, 103.20985194175475, 98.75458071308752, 89.33619330006262, 83.98559401112219, 77.10375632009199, 82.31167547164425, 75.43482703547325, 81.92551812817975, 81.01509678748347, 79.79396881595736, 85.77610108160204, 77.58187755461663, 81.03170410279306, 77.67602228349256, 78.99626070453276, 86.20532604955858, 91.00275347309729, 80.37045524966332, 81.79386769571613, 76.04594015306043, 73.1711644511069, 79.90836866440313, 79.63653272198093, 79.39738581257483, 73.24021385562035, 73.35149934214931, 69.73682342037078, 72.52086685549828, 75.55980943864392, 74.02504874813941, 61.22533505962741, 53.4514170308267, 46.580440382803644, 37.84926399107903, 16.836824955478793, 3.924615238943408, 2.7254748488626173, 0.7665315811191836, 1.3145311272913411, 0.42169334306832285, 0.22287632038276042, 0.4410115983938018, 0.2880757500327403, 0.4173955285260755, 0.5318135792209256, 1.289994863252486, 35.151410718117994, 120.46427988236951, 144.6804520391649, 69.66367906139743, 110.87848571039017, 93.08777563033566, 34.91010258274694, 31.47404355387534, 29.62400078773499, 65.15724051383235, 78.42977631476619, 93.91594486851847, 79.97684540287142, 10.092746788455594, 1.0591350640020063, 0.34214356974247967, 0.15100264080589818, 0.22216110069665218, 0.42566033020134897, 0.302055720840731, 0.23264483007932865, 0.49569896872966523, 0.41656263773479774, 0.19806886121871012, 0.23367607635596108, 0.20729318801914492, 0.09733383799152029, 0.08209677052594001, 0.16768710116945929, 0.2355238651075671, 0.16047044567042784, 0.4806700396922327, 0.13934236891087026, 0.3469969206038983, 0.4502033971009716, 0.4161770197172319, 0.21519077310879386, 0.28903008108177497, 0.17122072768547844, 0.16213158476016215], [0.07864047292499773, 0.009366871822895783, 0.06333988527917574, 0.019453496657191746, 0.1331961527466774, 0.03883826373625667, 0.13147721998393536, 0.10131403248036101, 0.11499072440088758, 0.25830067033248566, 0.1723685572224279, 0.15167973995689424, 0.07204332208681492, 0.09649491042739923, 0.07560016106693976, 0.16826155986036026, 0.04938008556623132, 0.07374056690042058, 0.05586620345110855, 0.052615320835743225, 0.030738331843167547, 0.05636923976482884, 1.0701078945590605, 26.97837583480343, 78.55209150621968, 118.73252207233061, 96.64516925811769, 84.90695876459922, 56.92264010829311, 49.02073906313989, 29.256623752655525, 65.63437331107356, 93.80056442752962, 40.239862318961855, 88.44335986721902, 129.04269172299294, 86.7068559892716, 8.403240749912879, 0.6561842765058241, 0.0649062478013577, 0.1558940202718781, 0.09968735968634006, 0.5117468866369417, 0.2691084242636158, 0.6522862985730171, 0.921375539995009, 5.076242243089984, 1.2134498093397388, 0.37516965080172787, 9.310013305756355, 35.54412234214045, 74.34443166179042, 100.70686201895438, 101.89268865892964, 101.71069852767452, 95.86454699116369, 91.05433264086324, 88.44379917267831, 85.0111290716356, 78.21467353451636, 85.45689859697896, 83.17462828851517, 77.13847714085733, 80.93472742265271, 80.68822214680334, 81.19760467160134, 82.59100314109557, 77.74528349599531, 73.97354018303656, 70.87212208778628, 62.41873579640543, 61.694866303474676, 67.43474514253678, 60.07198172230875, 58.52909780317738, 55.02702920667587, 56.947519702296105, 75.65838644581457, 67.15501739132789, 60.783009375295336, 67.82054947268578, 76.16561951175814, 82.60045605321085, 93.19174197412308, 103.76727565642327, 88.8730162958945, 93.21191864628946, 92.64130007836127, 78.12204284052696, 68.42752841211134, 51.42952542151175, 48.51011314699727, 55.9782902656063, 64.9303392441042, 63.842371817558046, 64.70272802537488, 58.234939652104536, 61.87872348293182, 60.70052977531188, 60.5963320116843, 61.124636050193544, 63.9636318914352, 66.77983483960553, 69.34379408436438, 72.94452205781015, 75.75035818161504, 57.12664258095526, 52.3163027148093, 51.10818916751493, 40.967289401638894, 47.71864552651682, 51.26428773326259, 53.68762216260357, 54.173423397925596, 48.38104363410704, 50.38537479216053, 51.59911694065217, 50.79764335386215, 50.47828005206201, 50.40334709229008, 50.037990077849365, 48.85280670658235, 32.20507137237057, 19.58069351411635, 13.148335910612538, 13.677486200486461, 3.4566142097596204, 1.4214331200045924, 0.7992591636796152, 0.5619700481334041, 0.5829275783992584, 0.14600313569028534, 0.07194786753144956, 0.11692374809494904, 0.3188222598644995, 0.029773210445719383, 0.5249336806516494, 13.548866779573503, 73.90569102379584, 108.45153485575031, 64.53149695550242, 70.93323261507096, 91.48975495369204, 49.87780048001198, 34.90562323601016, 40.92575150151407, 55.81251913501371, 66.57328282633136, 75.41014748234903, 58.66601990115259, 10.608300182127184, 0.5760922967906922, 0.06768139364618449, 0.1629786328562806, 0.09618470610509958, 0.11990639651494643, 0.151552232282777, 0.04421423977961944, 0.06351575991439243, 0.06322348204952094, 0.09362987182553738, 0.03582790208559844, 0.058440699377247406, 0.16755980799996084, 0.08231102999660277, 0.04943158582694108, 0.04645653699915256, 0.05578050885589854, 0.022949161601342985, 0.08708588748929963, 0.1995791729179121, 0.14897203283204188, 0.02284129450638448, 0.00714920480893324, 0.07084323769255031, 0.03611068429064847, 0.026222806604158495, 0.0556417971458887, 0.012659305132054275, 0.0384065502082869, 0.10304894583720355, 0.0883564979378735, 0.05723585757697302, 0.17669650966361647, 0.039184589104186145, 0.2538952357586353, 0.13741873745476046, 0.09441203227446926, 0.05112726016030197, 0.13157068271069758, 0.060575173551877665, 0.0769852556949181, 0.05424871988173935, 0.06663376840973093, 0.13923235868494357, 0.019512623323187716, 0.042713174761663524, 0.02525453467012173, 2.3377946451787026, 43.554449465967, 101.86101944215837, 134.28783416748047, 115.78448434029858, 119.67371832939887, 96.6059612458752, 67.63067537738432, 20.495882495757073, 28.033909182394705, 85.89861239156416, 53.28475944457516, 94.87792968750001, 133.70446789649228, 91.41794420057728, 5.655194376745532, 0.9760550962340448, 0.03705853423584373, 0.061657904767461365, 0.1808240535038133, 0.49473541398202225, 1.1891204503274735, 1.0944772127174562, 2.9060806285950447, 3.394687829479095, 1.283410674621982, 0.15831937803135765, 12.693417456842239, 43.16666826125115, 85.362730333882, 105.43417315329276, 102.7234858851279, 105.72585628878687, 97.08962086708316, 94.8995654813705, 94.17308761227517, 90.04319267888224, 86.75156316449566, 91.77069863965436, 84.98574349188036, 86.66121528994653, 87.95013750753095, 89.69079125312068, 86.7768624521071, 87.70125527535716, 83.45938451828496, 84.57148628850138, 81.32626625799364, 72.45650076097058, 71.89187557466569, 76.35751755006852, 70.83325139937863, 68.9197309555546, 66.05454152630222, 64.95476384316721, 78.67669736185383, 75.84180431981241, 70.60110199835994, 75.10678352848177, 83.6368953028033, 92.74023794358777, 97.559779690158, 105.54416425766485, 93.96020489354288, 94.15856699789725, 95.76791547959851, 84.63242423149848, 72.62720231086978, 56.21238908460064, 53.132991175497736, 59.907293165883715, 69.43514608567762, 68.16302730191138, 69.47137309658912, 65.0855827331543, 70.675901597546, 68.64399617718112, 68.28908443450928, 70.67455230220672, 74.33293911718553, 74.37835231904062, 75.73044823062035, 76.93767532225579, 82.79018109844577, 66.07879746344783, 58.69614762644614, 60.812423229217536, 55.19400450491137, 60.98193237858435, 62.638168873325476, 64.13194079552927, 66.55837781967656, 63.65049339109852, 64.67711494814965, 65.37457120034003, 64.12096600378713, 61.415409195807676, 64.41482605472689, 64.4554853439331, 67.57784105116322, 53.41933204281715, 41.106360958468535, 29.930375160709506, 23.454765581315566, 7.929150731332841, 2.0558313881197283, 0.48049037675223044, 0.25119943364012626, 0.855189772142518, 0.30899761124484004, 0.10560285315037736, 0.24361933070805766, 0.14393667480157268, 0.053283510384179895, 0.4465479319614749, 9.971826980190894, 76.54743086907172, 107.41185572839554, 70.3958914356847, 56.42686820799305, 29.654685489593017, 24.909417744605776, 50.63922274497248, 57.19638624498921, 75.2940139462871, 92.07098745530652, 85.53065484569919, 75.34345149993896, 16.0407877737476, 0.5534171361115672, 0.05742260299983525, 0.24358266574000162, 0.07456103940644572, 0.0892049020096179, 0.0925088094006623, 0.04210309298228353, 0.06431124263232754, 0.07210990278831414, 0.05028851262684311, 0.023934113184711146, 0.11454940413034732, 0.09171194772446349, 0.08530085666045066, 0.051235420283891504, 0.08559568559811001, 0.026447075013551983, 0.045789446786887227, 0.12129063312444957, 0.057637931163152384, 0.055354544817800486, 0.05960822886516971, 0.04535548862129931, 0.06046836174303486, 0.05109531046341985, 0.1740767494324715, 0.1100730604582256, 0.2542130243513854, 0.14605268625722778, 0.1582395823131646, 0.20503724294324077, 0.36631030361017874, 0.32815048350922527, 0.24760159363429396, 0.36087350018562814, 0.20935339763039545, 0.28513354339426566, 0.10365306745253264, 0.29075004040233554, 0.1134003411918398, 0.1763866730635205, 0.1029754167182311, 0.17977607586691458, 0.16059772351816778, 0.12996176017388222, 0.11870187647160023, 0.09801840649977808, 3.4499863847609493, 49.939899444580085, 124.99389571528282, 152.95718654509514, 116.10415750934233, 114.52301086918001, 74.5321798324585, 60.768300487149155, 42.442543814259196, 75.96146798902943, 120.0079591812626, 59.61502167486376, 114.56953802416402, 146.92272986135177, 106.113143274861, 11.53924826652773, 0.955009741648551, 0.2721302734026986, 0.47200684165281637, 0.3114519118060989, 0.7492876773880375, 0.5929274160054423, 1.0693201110247643, 3.081912638679628, 12.524747694692305, 4.932385884946393, 0.9547886180300867, 10.943880523404768, 44.182660195135306, 100.35353491383215, 119.1362359446864, 110.87861907097601, 112.81201808683335, 106.32065234645721, 102.48518620767902, 95.33859637475784, 94.95976601877521, 91.51603483384656, 93.39305370084702, 91.43624597980131, 90.38765522741502, 89.8420927601476, 92.25096933303341, 91.62581413022934, 91.09671777294528, 87.93046289874663, 91.72472061649447, 87.00336364007767, 79.81223137147965, 79.92090455947384, 87.55349174622567, 80.87879442399549, 78.74402092349145, 75.0665556999945, 76.64052440274146, 89.26572399754679, 83.85541054510301, 76.51759732154109, 81.07750169692501, 89.34001368861045, 98.12371453931256, 103.5932557813583, 113.98417918912827, 104.22556538735668, 104.18633384089317, 104.46879940648233, 94.41786704524871, 74.72339537835892, 62.77221587396438, 59.82244445431618, 69.94348526000977, 75.54617527992495, 75.47322703946021, 78.00773712896532, 69.20766430516397, 76.74905638540946, 73.66463784248599, 70.6911596175163, 74.1976644146827, 76.02382583002891, 78.7842958204208, 82.69723661484258, 82.21069012918781, 86.69531637622465, 72.98436549402052, 69.30008319116408, 71.1743877780053, 64.46199647841915, 69.08787512010144, 72.10488380924349, 73.05813743222144, 75.38586016624205, 71.94282716320407, 72.15956164944556, 73.12140526310091, 72.84773365143808, 69.01161639921128, 70.2669160596786, 71.69512164208197, 74.2088431696738, 61.00836523117558, 50.16468655678534, 41.9544283805355, 31.808670759201053, 7.47011035680771, 4.391827381426289, 1.4004186540842058, 1.5675286612203045, 0.9853234730901258, 0.5676105390152624, 0.3058079582068228, 0.26939221387428625, 0.4377596164422651, 0.12328584017532489, 0.5900697854738082, 20.98907151529866, 83.8147355664161, 123.48410483329528, 75.72186608468333, 102.74307420176845, 116.88481899999805, 62.57458333046206, 45.291855489054036, 49.72310220041583, 71.91466454536685, 87.74524857920986, 92.95941998881679, 89.57623450986802, 21.690852180604015, 0.7845906636887982, 0.198596021641166, 0.47222217364657315, 0.16999739252271193, 0.3082594702080373, 0.29245590370508934, 0.10786369352811769, 0.2461537487444378, 0.139905872544454, 0.2660285975904234, 0.11255234314669525, 0.28185456450427737, 0.15863923506150324, 0.19959565913004262, 0.11485006299711044, 0.1131489187959702, 0.10093491088839308, 0.09818403470900752, 0.22840565190680567, 0.26098703424776754, 0.24805324843093274, 0.28741513709387473, 0.1853562143420981, 0.1308430370784575, 0.1896431657575792], [0.03192810660919115, 0.035783783082039125, 0.0075655467827023285, 0.1513583660726586, 0.1267443824138853, 0.03327207189173468, 0.04213120840910462, 0.05259582772850991, 0.03366528184063012, 0.0673334211892178, 0.1807005448086608, 0.06336540749837315, 0.14696572516714373, 0.1811437726381325, 0.11953544908113058, 0.04498724547785617, 0.11746223895780503, 0.08231093040517262, 0.11847738972714833, 0.10762702598566971, 0.056429377666884856, 12.500481951621271, 52.44332082809941, 96.64471426317769, 101.44649551760767, 80.92789465381254, 60.306841481116514, 49.92846573552778, 40.7163949935667, 66.10948608767602, 102.38295355150777, 105.17343751845821, 51.93000024364841, 90.3876866063764, 116.24825754473287, 79.24901039369645, 3.9900901384892005, 0.6597677293804385, 0.14962873872249358, 0.06961971866868197, 0.050724654143015226, 0.13523449820856895, 0.20768331063370551, 1.727134071050152, 1.7379469424486162, 1.7811185097502125, 1.8688676914861126, 1.5082142117523378, 5.291600467697267, 34.86497179154427, 69.10463933021792, 87.02903163048529, 88.12620485982588, 94.94504928588869, 91.82818489689981, 89.41111057035386, 90.18884597286102, 92.27139703689083, 81.1235660122287, 82.45357897973831, 88.35392198254986, 83.27506449914749, 89.90049685201338, 84.14988640815982, 85.78425961156046, 78.81896172800373, 72.02423987850067, 68.66212537211757, 74.27390744609218, 79.53365679710143, 83.83560257573282, 79.92472494802168, 76.98399066925049, 78.49026710756364, 75.21411526587703, 74.25642151986399, 63.769564782419515, 66.89231272666686, 83.29644926132696, 79.29841656838694, 62.30916046327161, 70.74362524094121, 73.7619440017208, 77.4392209514495, 82.59465879009616, 102.07155658352761, 89.68276608374812, 66.7367358361521, 83.73258544552712, 69.52496836262365, 50.56984778373472, 46.548739787070986, 51.72819429828275, 58.86986940137802, 57.54383763959331, 54.84992634865546, 55.80594132023474, 61.832502272821245, 61.64753898497551, 68.48797998120709, 73.3196496963501, 71.57468134357084, 73.21363587533274, 69.33092871019917, 69.20569527533748, 65.00706864941505, 73.69666007257277, 61.042874243951616, 62.35657015154439, 59.70641289987872, 60.28319351134762, 57.4851825160365, 55.2876667822561, 54.178522479149606, 54.9655774331862, 51.10408244594451, 44.55235927335678, 45.83548422782652, 46.4626084604571, 53.23847155417166, 54.96052149803408, 51.67852924716089, 57.42510357210713, 43.7775578037385, 27.95676792821577, 12.751419505765362, 13.081406547177224, 7.466510601582066, 1.051359945727933, 1.3852126055186795, 0.2873502034814127, 0.361195165183275, 0.1851770263766089, 0.1538561497844996, 0.10960015438256726, 0.11346658481465233, 0.15552301921190756, 0.2119514316080078, 8.725171242990802, 73.88392186933949, 106.01307576702487, 77.29315188623245, 84.48370364404495, 68.48208858120826, 43.73645136433263, 39.4626485916876, 39.519675931622906, 46.94006289205244, 75.42386008847144, 73.57808682226366, 80.41562526456772, 20.88424421125843, 0.6770095493524306, 0.04787383413302803, 0.1616427134121618, 0.19618898870483523, 0.06105522722786954, 0.008969570006874782, 0.053365068104598797, 0.01604703307572392, 0.12945375194953335, 0.05461298319841585, 0.07725086603914538, 0.04748911243833361, 0.07492709153842542, 0.06587368661477681, 0.10677253151492727, 0.03534135964488791, 0.04427405975518688, 0.09775863374553381, 0.03846831987762163, 0.20891845887226446, 0.05207849238368292, 0.1135415158745262, 0.04528246895079652, 0.0716659548361936, 0.05795222639496769, 0.033488955213538105, 0.04913668028048931, 0.022385895455015764, 0.01996451943752266, 0.0271039973238423, 0.02565728624411408, 0.09176358205055998, 0.14008259370682702, 0.011379830088586578, 0.18107911481732325, 0.022316173793027, 0.1416091005047483, 0.05837047592766824, 0.11777836513975937, 0.08435516708320187, 0.08476768244778918, 0.028743297162075198, 0.014523946860384558, 0.08689695488541357, 0.3032773859318226, 19.11591814410302, 72.7598725595782, 110.38636161435036, 112.60477573640885, 100.84722795794087, 98.33900559333064, 84.34137651997229, 39.27645760197794, 38.768793075315415, 54.77099257130777, 96.34921073913576, 61.956370722862985, 93.2756571615896, 126.29380841409008, 83.01336396125056, 3.3830923226571854, 0.9332350713591423, 0.3069892964295803, 0.13618915101453183, 0.13842939128798826, 0.19446297728967285, 0.521561055173797, 2.8522267312772813, 2.5967453564366987, 3.207808954100455, 1.145212212877889, 1.248505134736338, 9.29608496927446, 46.801771886887096, 83.72783937761861, 96.00680351257326, 95.33233627196282, 100.88747932064919, 96.06654121029763, 96.2288567327684, 96.58253685120614, 95.57142826818651, 86.56573695521202, 92.42029020863195, 92.03255607235818, 91.10776316735053, 93.96534319846862, 90.63068528329173, 87.73520731156873, 84.22341515941005, 77.37510588861282, 77.6521272044028, 76.36393454767044, 83.58138592012467, 85.75147644166024, 86.44432390889814, 81.57841974689116, 88.57566141313123, 83.97788263136341, 85.2867304894232, 76.12012786249961, 77.86903427493188, 85.63211871731667, 87.75041826309698, 72.12149896929341, 79.31536905227169, 85.61715095273911, 88.38767790025281, 90.22919147245346, 108.36579184378348, 94.21004418403872, 73.95961576892485, 88.4343776395244, 77.18754599171301, 58.9563419741969, 55.125716040211344, 64.22687392080984, 70.77614168966971, 69.17262185004451, 66.38208296991164, 68.2077423218758, 72.1929802433137, 73.7346129263601, 79.25744348956694, 80.24702610508089, 75.96245642631285, 77.4667481453188, 75.48152677474484, 74.88371049204181, 71.51419839551373, 79.75723974166378, 71.68187972038024, 69.58367055462253, 72.52978632527014, 73.95917646346554, 69.61737155914307, 65.47642730897473, 65.79520225524902, 69.27274427106305, 66.00509612791001, 57.66343855088758, 59.684992836367705, 57.964809940707305, 67.28236890608265, 65.94263630528604, 62.334342079777876, 73.29905725294545, 65.12472014273366, 52.67912980048887, 35.12393059269075, 26.901254192475353, 13.664492368698122, 2.475529654372123, 0.6549383111057744, 0.16307667678883, 0.546994867824739, 0.5053492557377585, 0.07696221943103498, 0.12729452547406958, 0.07029507113921066, 0.16046787161500226, 0.3794707748438082, 7.796200523453375, 75.7264474130446, 110.07166985542544, 81.04485188761066, 75.988249932566, 33.57722628501154, 20.693624865624216, 47.66853332519532, 58.188106552247085, 68.37822421904534, 92.89045687644713, 82.91460652505198, 95.30662121311312, 31.532371159522768, 0.5333925170763847, 0.08394500360854211, 0.1699204313298387, 0.13516262383951297, 0.03159611474632496, 0.06681032869363986, 0.12223678235445293, 0.015522982970240618, 0.0458800022099768, 0.11068573927566891, 0.04495901896828606, 0.02622150616990703, 0.1496361697753591, 0.030032000692200758, 0.09462984639310068, 0.03644852140437692, 0.08102931127312683, 0.05370374791504395, 0.01745045444207086, 0.09569585773973696, 0.030142357572913173, 0.1149734950834705, 0.043087895178506454, 0.04515506852898867, 0.1259381821258895, 0.1361192225088035, 0.17752823600124928, 0.27143291888698456, 0.22176869514007724, 0.10904872429467018, 0.1618483314110387, 0.26226716716924026, 0.26191010890949157, 0.328492495802141, 0.32837375217387754, 0.2522219924796974, 0.3434248364740803, 0.2307903457192644, 0.2397135233566646, 0.2003768543081899, 0.17718508989820558, 0.20446459221984112, 0.19469179243089693, 0.2889944426715374, 0.5745628788586586, 26.67407443446498, 93.3239572278915, 133.56307429652063, 119.76909468250891, 102.00563723041166, 85.62227356818416, 62.524804530605195, 51.94609372846542, 81.04471068228446, 108.24266079933413, 125.4219831958894, 72.67646728023406, 114.2943916013164, 134.1330417510002, 96.85010525488086, 6.60835043076546, 1.0496526115363645, 0.3083610534667969, 0.29487398362928824, 0.19493960655264317, 0.48837532139112877, 0.3035195922899631, 2.948786659586814, 5.927678000542426, 7.557842010451902, 3.997436492673813, 1.9740429833050699, 8.92554062028085, 54.42143878629131, 103.06638733033212, 111.45382681200581, 105.36551598579653, 108.42374094070928, 101.48270683903849, 98.63898846410937, 97.29994620046308, 100.17767936952653, 93.39302232188564, 93.95520779394334, 95.58965944474744, 89.69857323554255, 95.72972728360085, 94.53784450407952, 94.43205818053215, 91.99535631364392, 87.55837117472004, 86.37445080664851, 86.65072687210576, 93.07352173712947, 93.79283735829016, 93.23462132484683, 86.58867497597971, 93.76345880569951, 90.72260210590979, 88.00902797329812, 78.92136696846255, 86.86328011174356, 93.34383579992479, 94.91810260280486, 82.67691089260964, 86.8356901599515, 84.91940836752616, 92.73872390870126, 95.07804116895123, 111.65070626043506, 99.38764341415899, 89.9660945707752, 94.75017809098767, 78.86822669736802, 63.22673620716218, 62.34126506313201, 69.00022583623087, 74.84788356288787, 72.42640833700858, 69.85386694631269, 70.80096244812012, 73.35175037384033, 75.20907894257577, 81.52448715702181, 80.57749363683885, 80.88448186074534, 86.34520561464372, 80.7056688493298, 82.21382802532565, 79.49055779364802, 82.71962550378616, 76.69178193615329, 77.43009751842868, 79.4989202868554, 78.60771071526312, 76.87310526447912, 74.68581122736778, 73.35279372430617, 75.80947614485218, 74.31242512118432, 68.05534255120062, 67.32120037078857, 64.87787362067931, 71.79511070251465, 68.60769856360652, 65.81264111303514, 79.30128774335309, 73.52368354797363, 60.35919727817659, 44.00416097333355, 37.47952568915583, 15.39907624644618, 2.8073011290642524, 3.5112709672220292, 2.369579571870066, 0.7138974796379767, 0.8222875828223845, 0.30030931616502426, 0.25555789170245974, 0.2862439418752348, 0.2874492433282637, 0.8863435036713078, 14.08086274900744, 90.24448087138515, 123.8570280997984, 92.6103682671824, 118.49495195573377, 97.24977124121882, 56.091023106728834, 53.26876401901246, 47.227780511302335, 62.21507849231843, 93.3857031791441, 92.25958285793182, 112.32562849598547, 41.34982639743436, 0.6512735303371184, 0.2921696626130612, 0.2519495256485478, 0.21408466472020074, 0.19713976510590125, 0.1183849458973254, 0.17205924156212038, 0.05264936961353787, 0.21604338300324258, 0.19242927432060244, 0.20966185527222775, 0.22416864942398765, 0.2496362159088735, 0.1605431014491666, 0.252042421470246, 0.10764800913391576, 0.18842431987004896, 0.13344373704204637, 0.22201431825036005, 0.2956863126206783, 0.1078799652356294, 0.2374039368043023, 0.11650934049318876, 0.2705187614886992], [0.03424423363720698, 0.044883494190270865, 0.007781932626159923, 0.04107615978066479, 0.08178942371159792, 0.06748886808993355, 0.07755714033039347, 0.06472475391121642, 0.06939032130063542, 0.13681194985345488, 0.06597717743246787, 0.11793205003824928, 0.03164830065572695, 0.06939660322161452, 0.11669652641660745, 0.1376819193002678, 0.07546454052170438, 0.06552143938719265, 0.09904829680078453, 0.31207728470044754, 36.79972794748122, 104.7903553132088, 99.66678280984202, 91.34102652149816, 60.60006218571817, 54.974230181786325, 37.78889479175691, 53.060984303874356, 120.843471096408, 87.82413528811547, 138.04320550734, 72.51499114498016, 107.79304735122189, 112.61310685065486, 96.72519345437327, 7.197942483809687, 0.4859077828305383, 0.3190637920652667, 0.08438785605493092, 0.07287282676946732, 0.17119103411753334, 0.05276553918637576, 0.4806173634865592, 2.6114900362107063, 2.5658307056273184, 3.3791996154092976, 0.717453292060283, 13.191713402348181, 56.13828374493507, 80.04254510325771, 78.97049857724097, 83.19142387759301, 84.11911149178782, 89.66777478494953, 93.81523409197408, 93.97566687676215, 90.06179255823936, 84.32068209494315, 84.5566048160676, 92.05650606463033, 88.23431322651525, 88.42005314365511, 85.54927825927736, 81.76821539478918, 72.27050196739935, 74.2112671944403, 67.55451863811862, 70.8259165671564, 66.44809645991172, 69.69626611278903, 77.42592411656534, 83.53686701866889, 92.49559187120008, 91.3716523878036, 87.7186627541819, 93.91053199768068, 90.10057695450323, 79.38662282882198, 75.85967463831749, 86.98990991038661, 79.27423123390444, 75.03972668801585, 93.2259685762467, 82.83193865130025, 87.61457089454898, 86.71520279299828, 129.5088654179727, 78.75942014878797, 60.71074362724059, 80.26944637298584, 47.508610448529645, 61.877193758564616, 69.23801560555735, 73.51638793945312, 77.06632906390776, 83.72026920318604, 81.34263038635254, 87.08480773433563, 86.16158377739691, 79.3055788163216, 76.08429308860534, 61.65174768817041, 54.64959913684476, 66.15283612282046, 64.31648831213674, 61.464297617635424, 71.60259292971703, 77.7284251489947, 67.41504699953141, 68.2200114957748, 73.7143107383482, 69.61472003690659, 64.75488378155616, 64.44283570012739, 68.76045919233754, 54.472441365641934, 43.90593697947841, 46.81004024321034, 38.86034119513727, 46.62006416628438, 48.25038163892685, 46.13166632190828, 52.06111723376859, 55.616698726531006, 51.99857896374118, 37.65391818938717, 18.433884651430194, 11.133506528792843, 10.280561639416604, 1.421292282400593, 1.0221236403430662, 0.11454466204609602, 0.11222580582984995, 0.16769673855554673, 0.11175480731312307, 0.2338703715753171, 0.06306092585286786, 0.09345896527050965, 0.6130670708033347, 5.690541796145901, 66.9428171650056, 108.77717787219633, 75.03795377669796, 62.804187113238925, 85.49684401481383, 47.695268200289824, 34.06150956307688, 38.7435330114057, 52.141247334018836, 62.03942691126178, 65.42050607742803, 71.52235692547214, 31.232507921034294, 0.7838025124322984, 0.2724116115320114, 0.0610885635438946, 0.04852846775564456, 0.018277923246064497, 0.0551351985233205, 0.020633722137239192, 0.042064259985401746, 0.05712845971086814, 0.036839548002688155, 0.05588239471938822, 0.01740849963689764, 0.0969299870813566, 0.05746327843817492, 0.05906164045295408, 0.07573068712747867, 0.04427434703815849, 0.026259055969515638, 0.03664116187381648, 0.052158992902766314, 0.05745818778391808, 0.09435591633401572, 0.02793469327321697, 0.03931657839266043, 0.07388143514793727, 0.01663502279458748, 0.04097165389647407, 0.03591469218654018, 0.04238623907909759, 0.08171439306029389, 0.10750477367471303, 0.016020999492837057, 0.030728554646033916, 0.03790004734670924, 0.0638398189368027, 0.06230341428289972, 0.06764406984251353, 0.04979043673243254, 0.13209389011946418, 0.08257154585613359, 0.08524621160881174, 0.11571722856212048, 0.6058495419640696, 52.75564739781042, 124.29769854391776, 116.55783453295308, 114.20074109108218, 95.7219845248807, 92.97187743648406, 60.406387313719726, 45.88950310983966, 58.97161176127773, 64.28279907472673, 141.05158498210292, 81.07343812142649, 116.53255877956268, 119.62171554565431, 102.84099225075015, 5.707662451651789, 0.48047857899819657, 0.21750152411480106, 0.05631855921819807, 0.07404269665599832, 0.03963979471835398, 0.03543316762173369, 1.6878069168136967, 4.772453692651564, 1.7194160722917127, 0.6197335679204233, 0.6099952420880718, 21.523149282701556, 77.28402845321163, 97.86342605467766, 93.99597690951441, 95.61050291984313, 92.86340821173884, 94.7664951509045, 98.81708760415354, 95.25705029887538, 92.01341490591727, 92.25415429761334, 93.44823360443117, 98.65817669899234, 94.72509061136554, 91.69719342262515, 87.8671479994251, 86.61606096452283, 80.46226224591656, 81.85619415775423, 78.17463397979736, 81.48974280203544, 76.6888480032644, 77.98821941498788, 81.31662507211009, 85.24648697145524, 92.29936353621945, 89.4521071833949, 91.05788630823936, 92.83071917872276, 93.8006664091541, 86.25823097844278, 81.16015388119607, 90.10442087727209, 87.36800286077684, 81.16355849850564, 92.81611227220105, 84.31437492370605, 90.95158223182925, 90.58347563589774, 128.11736537564187, 89.70305258227934, 67.36195379687895, 82.10148349885019, 58.563532290920136, 73.58287211387389, 76.67276628555791, 79.4796222256076, 86.09518589511995, 89.86157909516366, 86.83545481774115, 91.06786481795773, 91.21065478171073, 84.72368209592759, 81.36412497489684, 64.78269730844806, 60.339197112667954, 73.86374519717309, 74.53061088438957, 72.88849492226878, 72.20794016315092, 77.6994074544599, 73.2375152649418, 71.09652873008483, 75.31902297850579, 76.91727899735974, 74.56726935602005, 75.4299162280175, 77.6603328028033, 68.05367162150722, 56.91568182360742, 60.71068871405817, 53.92027754937449, 57.74949927483836, 57.42433870992353, 58.48477894260038, 61.726688492682676, 67.45777730018862, 72.44688310930806, 58.29838398964175, 41.67604600229571, 27.444720152885687, 16.74841865416496, 4.898996218558281, 0.55358880109364, 0.3426285953291001, 0.3182197470338114, 0.1545203326930923, 0.08147588690682765, 0.1342294521389469, 0.07970490613051, 0.08757965413913613, 0.7492684332593795, 4.4798144794279535, 71.43684925571566, 110.8353082595333, 82.4999806188768, 61.572064738119806, 34.25005789726011, 22.50321818936256, 42.374498536509854, 61.045619903072236, 73.52180865503126, 83.29875561498827, 75.55620870282574, 86.32085554061398, 44.887514037470666, 0.9749223279856867, 0.1616031066664765, 0.003241712542911691, 0.12530147879114076, 0.0646646696353151, 0.03212517889727268, 0.03586873074152297, 0.03637303876119756, 0.06556394960611098, 0.016039322400766037, 0.04746480829893582, 0.03792460812556167, 0.042588566730339686, 0.027048591929938526, 0.04178775970133082, 0.0750492365970727, 0.01581793352435794, 0.07325105969944308, 0.010216904789089196, 0.052772755734622485, 0.09272758112919909, 0.06724263210931132, 0.09653260195327383, 0.1389390082969781, 0.11008262889639986, 0.08798585693922736, 0.10544590471733002, 0.18709347192798892, 0.18692649540401277, 0.2720217953526205, 0.22959687266378637, 0.23403126536117447, 0.2648819171853604, 0.1534864970392758, 0.2439451938675296, 0.1651281683195022, 0.2695599564861867, 0.33773442730307585, 0.2770621023110805, 0.15241598109564475, 0.1746784195664429, 0.2202071168369824, 1.0432864821726278, 63.35449564841486, 146.0268134455527, 127.4424509848318, 116.90492506950133, 87.73482291929184, 81.5850014840403, 48.91883588606312, 68.15373912934335, 139.86406387821322, 109.78283436067643, 157.42912784699473, 93.53246258151148, 134.71960867604903, 125.75631818463727, 118.57949472242787, 10.63908882679478, 0.9232405044378774, 0.42846601997171685, 0.2198048593897012, 0.21406132968202715, 0.6995137804938901, 0.2430561488314021, 1.1695329917054023, 9.170489695764358, 5.0595025477870825, 6.740643151344792, 1.2482903849694038, 21.19016947284822, 84.45903193566107, 106.03202081495716, 100.37555509997954, 100.32738054952314, 98.80772098418205, 100.63242327782416, 101.79028341847082, 101.65903306776478, 100.9592822290236, 96.42259044031944, 95.46568116834088, 99.09568571275281, 96.64701277209868, 97.56239198869275, 94.77769744011664, 95.6367749552573, 89.56047442651565, 89.85913938091647, 81.36727856051537, 86.45456913978823, 80.80209639764603, 84.76386285597279, 88.74260533240535, 92.14035064943376, 102.95339169040804, 98.14729582878851, 95.69564188680341, 95.64046198321928, 97.10531819251277, 90.15923992280038, 90.47416702393564, 95.03666800837364, 88.41953539079236, 89.29545556345295, 100.51381080381333, 89.8276113694714, 102.45728246627316, 101.53261507711103, 128.71870394675963, 96.09024017087876, 79.68170273688533, 90.56948061912291, 63.37942231085993, 75.59438120934271, 80.94700444129207, 83.43147293213876, 92.20176712159189, 94.57760949288645, 89.65052420093168, 96.35803607202347, 97.36541055863904, 91.12528831728044, 88.46320706029093, 79.41069833693966, 70.61141783191313, 82.9702021998744, 80.32817209920576, 78.77226983347248, 78.08832614652573, 83.31587283842026, 80.6325323350968, 82.13007757740637, 86.66012487103863, 85.22657702046057, 84.58244539076283, 84.03594155465403, 81.16341729317942, 75.87771754111014, 65.29504514509632, 66.98412756766042, 60.108216577960604, 63.553642226803696, 63.93177832326582, 61.68535063343664, 67.2023525545674, 70.34326107271256, 78.34930496831095, 65.95593314017019, 49.61417405836044, 37.51898081071916, 22.02474786389259, 3.9898945102768564, 4.39901904713723, 1.3393212422247858, 0.6155771425654811, 0.5530593424074112, 0.16753192239951703, 0.6280581244537908, 0.14279783913685432, 0.20195160932358236, 1.0935273862654165, 9.18726175062118, 83.23422478091332, 127.59871821249686, 89.51161738364928, 87.90395552112211, 122.11005933823125, 58.21343329644973, 43.547463724690104, 48.43238745966266, 68.03269478582567, 83.0016125402143, 83.09085430637484, 100.60111491910874, 59.36211901326334, 1.9577383033690916, 0.6042723814325949, 0.09836834014183092, 0.312490941536042, 0.1856281295899422, 0.19411034701812654, 0.14109790535463443, 0.2059027231148174, 0.14921479077348787, 0.1320349932798455, 0.2342918578294977, 0.11126226640396542, 0.1534416808957054, 0.15027687974995182, 0.13478776169640405, 0.15259726814204647, 0.21374450636006173, 0.10667045795989614, 0.2213292211414345, 0.18787429938393255, 0.13882729735585952, 0.16688730537651048, 0.1457510161544046], [0.045637351520840204, 0.03912739297975937, 0.08731640334571562, 0.007285052307716181, 0.04612088323600831, 0.015231912651459779, 0.1385500807795794, 0.09441953227524796, 0.0361331153450714, 0.2234173316748873, 0.1816345132406681, 0.18392637251846253, 0.07869490347201787, 0.08717136757989084, 0.17167723947955718, 0.16913796444573712, 0.0790366935994356, 0.10913051184146635, 0.04539394623509819, 32.3308539390564, 103.56296723888767, 81.48587534504553, 85.98608909114715, 69.54994601588096, 71.3569897990073, 43.50274085998536, 65.45300683667584, 200.19942099048248, 161.50346632926696, 104.55971210233628, 64.0543798477419, 99.5200861653974, 110.34591413313343, 98.30454364899667, 10.594851355398855, 1.0590403142475313, 0.11283897494356479, 0.2413807298627592, 0.30619369879845654, 0.3835952083670324, 0.07644386901970833, 0.12545733171845638, 1.11704322118913, 3.74479589443053, 1.4591168011388471, 1.1879302561283112, 16.46883995302262, 82.61595726013184, 92.47053577053933, 97.09639087800058, 90.71362772295552, 87.42224924025997, 84.00056177569975, 82.42952700584166, 84.16323815622638, 77.47177662387972, 75.7040742135817, 82.98531116977816, 86.29059053236439, 87.97254208595523, 82.01989035452567, 76.27914859402564, 76.68116015772667, 75.12188465364518, 76.92648872252434, 82.01132389806932, 85.1806225315217, 84.82632267859675, 83.65816239387759, 80.35349492103823, 74.53441558345672, 73.74648986324188, 78.45185141409598, 79.90850202498898, 83.49700004823747, 79.90013168704125, 83.00937883315548, 84.25051089256041, 81.77566005337624, 75.41141048554452, 83.53052062373008, 85.60370506778841, 93.84911552552255, 74.92718604303177, 74.61220402871409, 70.58411029077345, 105.04699599358344, 111.5322663707118, 72.60286008158039, 69.49584084172403, 72.22434351521154, 75.73102089666551, 67.92296255788496, 79.15680331568565, 89.93997158542757, 92.28396431092294, 92.38604007228729, 91.46007045622795, 94.25239793715939, 84.62386561978249, 75.4976555608934, 51.58107403785952, 58.33053173557405, 69.72449148854902, 65.73976347523352, 64.21649140696373, 60.460072794268214, 62.35906085660381, 60.91379296395087, 57.47338402655817, 59.8086416336798, 60.36362563410113, 59.70573825220908, 59.018040857007435, 65.36175681698707, 63.831997148452274, 44.94498068286527, 48.56985868946199, 44.46476882503879, 34.2309324202999, 34.40199090588477, 40.92282541336552, 46.12826170459871, 61.33805221126926, 51.477401871835035, 44.67029317732781, 35.17869472503662, 22.426196567473873, 8.801876133488072, 14.387254772647736, 2.582452729825051, 0.47417122390001054, 0.23301396188476395, 0.12681409641499483, 0.3057619316443321, 0.0910561228351247, 0.11584532612393941, 0.08366649234366995, 0.3455123341371936, 0.15872597153629028, 3.8814309239387517, 62.33675433743385, 107.81942136826055, 94.85855317884877, 78.12667908207064, 71.62266762025895, 50.61143275230162, 29.315567170420003, 35.21312136803904, 32.7968942734503, 67.33248110740416, 67.86715507507324, 74.42469120025635, 48.982190009086366, 2.2427786598282475, 0.05016598069379407, 0.13941350783551895, 0.15185123639962367, 0.057599094335830985, 0.0594480283888838, 0.03794800828120882, 0.012259467565003904, 0.07381790347637669, 0.02614004804091829, 0.03010732820257545, 0.04992648245646589, 0.05238570513263826, 0.12463714266496322, 0.04227586496140688, 0.12424846795657951, 0.11693776750396337, 0.07501906039373529, 0.032040055037566254, 0.07028141945239998, 0.06297571006261053, 0.05471570792818262, 0.04534291711846187, 0.052972697021980444, 0.0567398309677599, 0.05237807489691242, 0.038442085196654645, 0.028458952137659636, 0.16802350569876934, 0.07202947121714393, 0.007788199704185489, 0.05042117607269076, 0.09855949440069738, 0.14158380428148856, 0.055503035640163775, 0.06478619416274371, 0.053674755317549554, 0.11145488389076726, 0.04003377841605295, 0.06677770866982399, 0.039450195617973804, 46.67299262938961, 120.72288174783031, 88.05307619033321, 103.52488102451449, 90.61324642550562, 86.51065903325235, 57.53463183679889, 37.784180102809785, 131.11906897637152, 151.18935861895162, 106.87369085127308, 78.36182517390098, 106.0836313616845, 118.0380585885817, 103.2309699827625, 10.144763300495764, 1.2726609288684785, 0.12727579462432093, 0.26553756587447663, 0.16615190693447668, 0.41096955237369387, 0.03923464145871901, 0.4282522814408426, 3.132106719478484, 1.7659250863136786, 1.1712277007679786, 1.4635777617654493, 25.887233249602783, 102.94619021877166, 101.36042302654636, 106.79658489842569, 99.5692648426179, 92.64177076278195, 89.485729740512, 87.96745084947156, 87.32041666584631, 86.25118640161331, 85.21748496640114, 90.33918257682555, 93.09946429344916, 92.35084072236093, 85.13768826761554, 84.78567907887121, 87.47128671215427, 82.63669875360306, 84.65704887144028, 86.80513489630916, 89.32272388089089, 88.84264930602043, 88.40375177321896, 86.6015717291063, 83.79153866921702, 81.91201733004662, 83.9504260401572, 85.28122348170128, 87.54625889562791, 84.01339577090356, 86.43565547081732, 90.52136882658928, 87.28543696864959, 77.6253217266452, 85.52608920681863, 92.78646699843868, 98.70329180071431, 82.81126776049214, 83.4179642892653, 80.09071965371409, 105.47081593544253, 112.8261778431554, 83.98096561431885, 78.35703988229075, 80.31392605073991, 79.93493879995039, 72.40818500518799, 83.34940125865322, 94.19482538777014, 95.54916489508845, 96.00513258287984, 96.61969738621866, 98.32925458108225, 89.63319516951039, 79.14084711382466, 62.0728337380194, 71.4818702205535, 76.16255221828338, 71.6365449659286, 74.32381568416473, 71.79915074379214, 69.03996729081678, 66.84377731815462, 66.12399101257324, 63.62683365421911, 65.37651277357533, 67.98655986785889, 66.09069793455063, 68.72496958701842, 68.93644025248867, 58.36090657018847, 61.641757411341516, 60.55610418319703, 51.082556478438846, 49.248938637395064, 56.48938294379943, 56.47872586404124, 70.2696381845782, 69.34150342018374, 64.91252383878155, 56.96935553704539, 42.26188728886266, 22.52867044941072, 19.17482233816578, 5.6770571777897505, 0.12081508404545246, 0.30551129831902446, 0.30341849932747506, 0.35619742206988797, 0.05007575085807232, 0.05106734059330437, 0.10303745451833933, 0.33222545839605794, 0.1802846663180859, 3.126167025296919, 68.74793114200716, 110.24779996564313, 100.91280214248165, 77.91201560728013, 36.165578749872026, 14.225183417720181, 27.997329158167688, 60.37461611532397, 56.641927842170965, 89.21669437039284, 79.37553036597468, 83.58015429589057, 63.41884605346188, 1.598091769602991, 0.013682932664279737, 0.09754641206874963, 0.008267119091244475, 0.19525658309219346, 0.0742549719589372, 0.01614258147685999, 0.00927130139673189, 0.039870662975215146, 0.02777012801098247, 0.02976855263113976, 0.03865254487121298, 0.04233167063625109, 0.10931885455765071, 0.04171328446377189, 0.05239630395907068, 0.034915652246244495, 0.030911885231973666, 0.1073190126748335, 0.039460265843738476, 0.064796268218948, 0.08559924790695791, 0.18714723597851493, 0.16736030338271973, 0.18395617333871706, 0.17958784806391886, 0.12971367026048322, 0.12080638128663264, 0.33462355874719163, 0.15689640035552366, 0.13411136734629833, 0.2943682736687122, 0.367906095399972, 0.24972183389529107, 0.20725088464396618, 0.18585144421986996, 0.3809149731551448, 0.3103546287503935, 0.18267148985497414, 0.33707896247506147, 0.14387204762428038, 57.6322360961668, 139.2169826261459, 101.81726148051601, 106.91664864940029, 93.3716610939272, 87.91656201885593, 57.035161141426336, 84.18714108005648, 212.5520472372732, 165.67464028635334, 119.9395138217557, 86.54890998717278, 122.20443156457718, 125.84352816304855, 121.17217356158842, 16.609876617308586, 1.6654633802752343, 0.5488670028505788, 0.5460275745680255, 0.6041470494481825, 0.7958598783419979, 0.2012401281465446, 0.4076264978897187, 4.752456468920554, 11.231598142654667, 5.535121800438051, 2.161506414413452, 27.470898051415723, 116.98606321888586, 107.57270428442187, 111.10191176014563, 99.63989888468097, 97.927305775304, 96.2571370217108, 97.05634347854122, 97.1583878609442, 92.09255264651392, 89.86813729809177, 96.1190382126839, 99.30437934014105, 99.22113095560383, 93.90646842218216, 91.51191634516563, 91.89744610940257, 86.79463863372804, 86.30137705033826, 91.19880137904998, 92.83561429669781, 94.84414239083567, 92.74749432840656, 89.09065292727563, 88.35697358654392, 86.62662782976705, 89.51074661747103, 88.48103815509428, 93.27754774401265, 88.414428464828, 91.64221748228996, 95.23092731352776, 88.39379679772162, 86.57787276852517, 87.7745565291374, 92.27250314527943, 104.41939323179184, 93.1094035794658, 92.45964727094098, 90.18155036434051, 117.61886704352595, 119.11109355188186, 89.89044773963191, 88.20485622652116, 82.29766476538875, 83.1734751116845, 76.66062262750442, 86.9354203439528, 98.82821144596224, 100.0649190718128, 99.45906193025651, 99.98321610112345, 102.7817487716675, 91.726485683072, 87.5772769989506, 67.96486916080599, 68.22853088378906, 81.52169442945912, 78.24946495794481, 79.97497835466939, 77.56392094396776, 78.27807472598168, 73.45454000657605, 74.29750442504883, 75.30112128103934, 76.83267347274288, 78.43764458933185, 78.46479523566462, 80.1614478326613, 76.48656352873772, 66.29193905861148, 70.95708062571865, 66.1213630245578, 55.00477760068832, 55.05720792278167, 59.313242358546105, 58.975828309212964, 71.47363324319163, 70.79549466409992, 66.80914278953307, 63.94246678198538, 52.02973435001989, 31.022967061688824, 30.313343617223925, 4.838379909915309, 4.087252150620184, 1.236567768839098, 0.4372706684854723, 1.1041870400790246, 0.21015425062467977, 0.18504950338073317, 0.24154309453743122, 0.7589077805319141, 0.8896891015671915, 7.154779251544707, 81.67844018628521, 127.073928617662, 111.24670997742685, 102.35079011609479, 100.02057275464459, 63.724579118913226, 40.37217563198459, 45.17871079906341, 48.137617418842936, 87.97692729580788, 83.74022622262278, 98.54792671818888, 81.74709735378143, 4.00942153988346, 0.22467091198890443, 0.32170887916318835, 0.25668986321937654, 0.2704065142860336, 0.21067073178147117, 0.119174322894504, 0.12513385109242894, 0.19209558174254435, 0.08496472792279336, 0.14492489758037752, 0.14327811497834422, 0.09777852904892738, 0.20990708001678993, 0.13380700061398168, 0.1630999045746942, 0.28760261413070465, 0.15668088450066506, 0.2190762791301935, 0.1494023444191102, 0.19866287047343872, 0.22165303118526938], [0.06884253013037867, 0.004810281877120536, 0.02178499906984789, 0.06319803643911596, 0.11798291061554225, 0.06289131398643218, 0.11805725944859367, 0.03728728425959426, 0.07341741569220059, 0.04797404609440316, 0.15457659419025147, 0.10711316484957935, 0.06569819119308265, 0.09377682281117286, 0.0931719734123157, 0.0681054922601869, 0.031127090821222916, 0.06688964943731986, 6.78992381018977, 92.3311347346152, 92.55743195933681, 91.44139997420773, 62.709607001273866, 59.20311004884782, 60.664918576517415, 67.29765830501434, 105.8093870839765, 174.1682347943706, 107.78614397971862, 65.31127983523955, 110.18392808975713, 111.29883043227657, 97.36878379698723, 9.605661957494675, 0.8095585723077098, 0.2302814488329234, 0.20411288125380395, 0.11740577061690631, 0.28994249179959297, 0.09207332672010507, 0.11144258817958255, 0.7796941361119671, 2.3465961986972443, 2.3068961741462832, 1.3836689077077375, 16.65151846024298, 84.12222585370465, 93.66057503607966, 99.91338222257554, 93.77181345416655, 87.66170993927987, 81.00971529560705, 77.45060366968956, 71.21091288904991, 69.98813752205142, 75.59491465168615, 76.84286379045056, 81.11321095497378, 84.78650277660739, 79.8239278793335, 76.52115883365755, 76.63529980567195, 80.4613208770752, 84.83845064716955, 86.49921355708953, 82.57634916613179, 87.20924885042253, 88.67344610152706, 83.80496101994669, 85.09123956003498, 87.58113661120015, 90.60576254321684, 90.58458958902668, 81.74128440118606, 78.6751127243042, 84.63668392550561, 81.18292716241653, 86.31779609187957, 84.85660337632703, 76.47744009571691, 77.67945043502316, 78.97605265340498, 83.01594488082394, 71.75278048361503, 71.41677456517374, 89.35327129979288, 96.02910610937305, 94.74871112454323, 106.52877330780031, 83.37091938141855, 79.26418996626332, 76.3089507625949, 73.69924099214616, 92.23641733969413, 94.19091870707851, 92.75053024291994, 92.19242403584143, 92.50904560089113, 91.5224204524871, 94.12048862826441, 70.36313180000552, 75.56986639576574, 88.91911199015956, 81.29378903296687, 81.53878027392973, 77.38022850405785, 72.7399782980642, 71.5742341933712, 67.52719540749827, 67.86267572833647, 61.86284965084445, 57.62971793451617, 56.89723883905719, 60.75590579740463, 42.94009254824731, 57.624846350762155, 59.21455552501064, 46.65258061501288, 41.825358867645264, 26.252584380488244, 26.45706145994125, 32.1616978030051, 36.90652624253304, 45.02212585941438, 60.254124826000584, 61.42662325213033, 42.07921858756773, 32.29943967634632, 20.858380102342178, 7.1221735688947865, 10.634553586283038, 2.779977898443899, 0.4829135128567296, 0.6603210287228708, 0.028397818321302056, 0.2835335227991304, 0.19525849831200418, 0.10459219931714958, 0.19844073561891434, 0.172000007643815, 0.33749078069963767, 1.850083828453095, 50.530675072823804, 87.3438959736978, 94.49782848358156, 71.73603196297923, 67.39598428049396, 70.69345028169694, 25.621928053517497, 38.26477243054298, 39.07508311733123, 47.36383184309929, 64.33396639362459, 73.12472358826669, 45.901827196921076, 2.6779965191118182, 0.018243368850239826, 0.1430672262945483, 0.1370056015589545, 0.04584645138933294, 0.03607631758636525, 0.09453292860979996, 0.01759929191921988, 0.049063143500637625, 0.09746852390948804, 0.037944691120496685, 0.019119258241487608, 0.03103112107172849, 0.02224578563454411, 0.09893809505287679, 0.029944800734219533, 0.013746034368992814, 0.028117495258488966, 0.04854246035158154, 0.021531793604334517, 0.061901241105290196, 0.07954806494977205, 0.07543205073283565, 0.03448413024025579, 0.1328722967375671, 0.06647646757623842, 0.008884628093050373, 0.029331438183303804, 0.04884169429480549, 0.050460683226945906, 0.05915177835812492, 0.05767129812269442, 0.047309847864051985, 0.04425190449241669, 0.08161577456180127, 0.050788990206896305, 0.18536801209613202, 0.049775482696150584, 0.3402956430950473, 13.853490794858626, 111.0045506877284, 102.00318967142414, 122.37426234829812, 94.85854533410843, 95.55516612145209, 91.10527638466128, 60.60044265562489, 83.10612801582583, 175.0558828538464, 114.76479361134191, 74.31228391585812, 107.73445498558783, 119.60138982342137, 103.99571449525895, 10.168177889239404, 1.0739578234572564, 0.05980553097962853, 0.15917564982608443, 0.10883451078928287, 0.4335281144707434, 0.2407967716815972, 0.7004822994912825, 2.2731368243694305, 5.732933302079478, 0.3359032320159097, 1.3444862682973187, 23.03757836741786, 105.78929670395391, 102.50007552485313, 109.87601418648998, 99.76829374990156, 95.83615687585647, 90.3226693984001, 87.97305199407762, 82.49419120050247, 82.0628716868739, 85.5979391836351, 84.62879996145926, 89.57151197618055, 92.56886174601894, 85.40877895970499, 86.40378229079708, 88.66385198408558, 89.2716153975456, 88.33827957030266, 89.79272580915882, 85.63862200706237, 92.44997470609604, 94.93495310506513, 89.75562018732872, 89.01014235711868, 94.46672408811509, 90.95145671598374, 93.64021009014499, 88.20330296793293, 85.60222241186327, 88.89826851506388, 87.41340037315123, 91.5342503209268, 84.78622821069534, 81.06028249186855, 81.42358026196881, 76.28479680707379, 85.70920113594302, 76.41348977242747, 72.69606344161495, 95.94941923695227, 100.82614914063485, 96.7076212360013, 105.97832356729816, 86.66407862017232, 82.90205494050058, 79.84055088412377, 78.47511891395816, 95.43088974491243, 97.00461526070872, 94.8582786129367, 94.47534545775383, 92.7175352650304, 89.93025195214057, 94.73593204252182, 80.60508358863093, 85.63465256844798, 90.32466980718797, 85.55013333597492, 86.65434329740464, 83.46995922826952, 78.49589178639074, 79.11614402647942, 72.14275821562737, 71.83682118692707, 68.14909504305932, 64.92717389137515, 63.748505576964355, 65.43613280019453, 51.40968215081, 62.90780828845117, 64.6331020324461, 60.94885110855103, 57.3155164718628, 44.0035294717358, 44.162479600598736, 46.552324833408484, 49.99931550795033, 54.89908933639527, 68.71810543921687, 76.07471466064453, 71.33987257557531, 58.27115489590553, 42.935828931870006, 21.389545509892127, 16.53207444375561, 5.676477157300519, 0.5188411978944656, 1.208400738335425, 0.3798950343362747, 0.2183427039774195, 0.11338180186407221, 0.011759032119786548, 0.20506802435603835, 0.2744613563822162, 0.22067600861191752, 1.4174617202051225, 56.89357926768642, 95.00235511410622, 101.9572038035239, 68.9187660524922, 41.77462693183653, 25.853363583164832, 25.47217784389373, 57.416595951203384, 65.494780079011, 76.7595212690292, 80.44514502248457, 82.18583799177601, 58.61380138704854, 2.4414062596136525, 0.07760030172404743, 0.1531933764776876, 0.08827156176970852, 0.07942171406842048, 0.13667845137176976, 0.04238492906874707, 0.017023854550995657, 0.03908110977781396, 0.11670634000291748, 0.03746462595318595, 0.06900639633738226, 0.03793757799411974, 0.04926345634063886, 0.04628385695058011, 0.0012967020865612394, 0.0828970642760396, 0.03744014178312594, 0.021043412552605716, 0.029823666911632307, 0.017611463141116886, 0.11874116146035733, 0.15461673719748376, 0.1278275464691462, 0.19382436639599263, 0.2304430780631881, 0.2368769142776728, 0.24981552644843058, 0.14166606680279778, 0.156145389041593, 0.2955776507094983, 0.39560547519114714, 0.16335199346705792, 0.18779160785338572, 0.2076644955142852, 0.3048880704708638, 0.4271716378148525, 0.2351792174721918, 0.5407318232520935, 21.1730424434908, 129.95784344211702, 114.51276563828992, 122.28556186922135, 84.42906502754458, 79.5524763291882, 76.39745512316304, 87.90535188490345, 122.9899803284676, 181.2905686901462, 114.12222308497276, 87.34935591297766, 131.4368829419536, 126.88477623847224, 120.55494154653242, 15.578202066882966, 1.4550132664941973, 0.30508572115532817, 0.3098067533104651, 0.3241245382495465, 0.7548127034979483, 0.3710745124807281, 0.3900987126173512, 2.0106958165284126, 9.21546555334522, 8.859432993396636, 2.7798359576732885, 24.313392023886404, 114.51327554641233, 109.41985038018997, 111.44131445115613, 104.3843743108934, 102.26809086338167, 98.00215244293214, 96.82582578351422, 88.29691425446542, 86.10766687700826, 90.7860189868558, 93.36088242069368, 95.75300262820338, 99.35775495344593, 92.88032931666221, 90.50028216454291, 88.44226944831111, 90.15938897286692, 93.75349598546183, 95.32333051004719, 90.21278812039284, 97.67109655564832, 97.99776723307949, 94.2327311731154, 93.67914353647541, 96.31246597536149, 98.56836226678665, 100.35147959186186, 94.66593342442667, 89.16289514110935, 91.6945654346097, 91.63436489720499, 93.51483544995709, 86.84997543211907, 81.80595644058721, 82.91071553384104, 82.11923614625009, 87.93171021246141, 80.80915666395619, 78.66216890273556, 104.43354514337356, 105.24407940526163, 107.67691381515996, 111.98307221935643, 94.30223557256883, 89.08555384605162, 80.77315715051468, 79.64650338695895, 97.68806472901376, 101.27260900312855, 97.59543403502434, 100.45571265682098, 97.521834681111, 95.2745048461422, 102.39202207134616, 87.22999034389373, 81.36412497489684, 95.07768031089537, 90.79433441162111, 91.77031424737747, 88.4164837867983, 82.25646418909874, 83.72499958161386, 78.5035639424478, 79.21254019583426, 75.47499995077811, 72.69875418755316, 74.12701468313895, 78.68997850725728, 65.25888873684791, 77.81020656708749, 75.01256819694274, 70.89023559324204, 65.90718592366865, 47.74979306805519, 50.84492360391925, 52.17179475292083, 54.66292342832012, 60.14846401829874, 66.32689522158715, 70.57621063724642, 68.3643860970774, 62.04815026252501, 52.16277722389468, 28.468123405210434, 24.89748589454159, 5.564535164063977, 3.2885938450213406, 1.4970526171307412, 0.2769181390683497, 0.5917015527525257, 0.8639492827557749, 0.1375363319511375, 0.4425720275650102, 0.5273691660934879, 0.7052159261318945, 3.757681125594724, 70.4548054356729, 108.28175114047144, 112.04497506541591, 92.41519897214829, 99.20562190394249, 99.4858281843124, 37.26002200957268, 49.45485522670131, 54.01506554695868, 70.15415576196486, 86.6521389253678, 89.48745558338781, 81.11774521489298, 6.942676594180446, 0.3339028538715455, 0.21912688689847148, 0.19248746635933078, 0.20999711066965135, 0.20174877988474987, 0.17939920657344405, 0.18021410962025966, 0.12717177520596212, 0.28388816022103835, 0.1586310685642304, 0.21552647283721357, 0.13038474796039443, 0.22052170318220893, 0.18544314999974545, 0.13400085150234162, 0.1566707108530306, 0.1937289118406273, 0.12468491590792134, 0.15548051665386847, 0.08272287886469595], [0.08065646394125878, 0.05862706941702674, 0.06019086171422274, 0.07725396869523872, 0.06536809922826868, 0.0338461666908716, 0.014111496613270814, 0.005051335272935009, 0.07017051290360189, 0.02173638504539286, 0.08168719693898194, 0.20230629271076572, 0.038453917424645156, 0.06925318390130997, 0.11506776986343246, 0.11323741727298307, 0.052537673994177775, 0.4515908436188775, 51.41864868902391, 96.79345054011192, 74.82122713519682, 54.0515749685226, 43.28008751715384, 41.159187439949285, 38.59834255710725, 27.354837079201978, 24.661133673883256, 75.97216037011917, 83.85052327186831, 100.99929040478122, 114.82923030853273, 87.92814870034495, 4.477615010353827, 0.5423259602919702, 0.11677406983630312, 0.2622413346844335, 0.1840346973509558, 0.3874725019258838, 0.010995004014412483, 0.06098049535085598, 0.6874930029434543, 0.8981511862047258, 2.3180349699912535, 0.7730607952802413, 6.56163304082809, 79.42128089166458, 91.25955104827882, 103.06103721741708, 92.73250302960797, 89.73622014445644, 86.02816043361541, 81.655376649672, 79.56721659629576, 84.23744155514626, 77.57251093464514, 68.77553678327992, 66.0925022248299, 79.95213447078582, 77.43293731443345, 80.11410482468145, 83.63006253396311, 82.22298283730784, 85.46380196848224, 78.63719124947825, 81.88839681686895, 85.38255399273288, 87.31432914733888, 90.8722875964257, 86.92299427524691, 82.51187324523926, 82.94263578230336, 82.40020336643343, 82.81258567687004, 81.6054605668591, 84.0161963432066, 89.66508403901132, 90.69517689366495, 93.57366315780148, 81.94054080593972, 78.9576881162582, 81.45921107261412, 80.80881149538102, 77.32356594454858, 76.66656894068565, 68.28005513837262, 65.07418432543355, 62.61115158757856, 66.8869233900501, 72.1288259567753, 74.6962918004682, 81.67145836737849, 77.34521742789977, 84.30311772131151, 89.6624089825538, 89.48298408139138, 86.35185795445597, 88.71234032415575, 87.77300327054917, 89.51895221587151, 89.06566742927798, 84.36163163954213, 94.87579591812627, 81.24365329742432, 84.7399599321427, 81.88153266906738, 84.97175631984588, 78.34895979973578, 76.08470101510325, 73.09529012249362, 74.68926291311942, 67.41489010472452, 68.83041858673096, 60.182663163831165, 55.16224115125595, 50.94545002906553, 43.68202847819175, 52.969083170736994, 50.566592216491706, 44.857190193668494, 27.391499473202614, 21.802682876586918, 19.220468921046105, 23.827888888697473, 35.164083896144746, 54.26174732946581, 68.11912029020249, 66.08734038568312, 44.10999044295281, 32.03204777932937, 19.084348947771137, 7.810765754791999, 9.169766018467566, 1.857623849664965, 0.41159103354138715, 0.4503119364380837, 0.16981420557825797, 0.7205746406989714, 0.3044677639920866, 0.16248999133465752, 0.1299777407679827, 0.039996841486783764, 0.05433675870599766, 1.8674404390396613, 42.79707116465415, 85.29737580207087, 98.57792500526675, 61.47298958993728, 66.8846405706098, 74.9803263141263, 36.249121312172186, 26.143530722587343, 38.593133649518414, 51.38605771526214, 66.53016813339727, 67.54458719684233, 52.173646111642164, 2.1753386528261247, 0.16776706542699568, 0.13344459506052156, 0.038937115891566204, 0.030685421980677113, 0.075642226954862, 0.05078731630478175, 0.07416548522850198, 0.02357540400548568, 0.12012238734431806, 0.03216301406463308, 0.05760500470416681, 0.034875608830442356, 0.04264757465270739, 0.023654470024930856, 0.02256407601488454, 0.0410523574288574, 0.056451961938892646, 0.025117786060417854, 0.046213353878908583, 0.024374678858645984, 0.06068389675009155, 0.02173255843621108, 0.0396330684663788, 0.0741985266006762, 0.04977139178663493, 0.036369993561698545, 0.089527677834755, 0.0958745860524716, 0.02300885708762273, 0.09548873054764925, 0.053838782403017246, 0.019688898239344842, 0.08211158666639559, 0.020268405449666807, 0.07572140980271563, 0.06415479598687061, 0.420651923144056, 68.97637782558319, 107.38979631854643, 96.65255900352233, 72.30720750747189, 42.441457317721465, 46.356571105218705, 43.827454274700536, 32.954055801514656, 31.765697271593158, 78.58648284789055, 91.16422960835119, 103.2365240589265, 120.275770771888, 94.51100764736053, 4.309559589432133, 0.79421799870268, 0.03517079399898648, 0.15639756986450765, 0.2148876014736391, 0.5230709225420029, 0.05990478533109831, 0.5403826097326895, 0.9597198953551631, 3.50331076210545, 3.662826692865741, 1.093905649838909, 8.475813423433612, 96.01647607741818, 98.93421742223926, 107.41002005915489, 98.55734825134279, 95.09770793299522, 94.28953493795088, 92.03529388673844, 90.17734558351579, 93.60949008695542, 85.34070230299427, 77.79259512501379, 80.3756327782908, 88.57450039156022, 86.07834323760002, 85.61017697857272, 89.85504442645659, 89.51109963078653, 88.8294073843187, 85.48181349231352, 88.7948513031006, 91.40672622188445, 91.35739064985707, 93.21130675654258, 90.0564189111033, 88.83565179763302, 89.25235655999954, 87.06610587335403, 90.4331547214139, 87.3572555665047, 93.03043842315675, 92.09239575170702, 96.22107475034653, 93.44733930403187, 86.77796071575534, 79.83796211981004, 82.08769244532432, 82.13174850709977, 79.64400091478902, 76.49898175270327, 74.30545899175829, 67.65815550281157, 70.6520849658597, 73.04802556191721, 75.85933731448266, 76.51546355216735, 81.07440302448889, 78.81931474131923, 85.8408437236663, 91.02315764273368, 92.4436047769362, 90.1188708889869, 92.21169071812784, 92.47006508611864, 92.58921884721326, 91.38302726130333, 93.35459878367763, 93.9785380517283, 82.82457244011664, 85.22452169849028, 83.14532033858761, 85.41715714239305, 83.15546358785322, 80.27653017351705, 78.28735505380939, 78.65619121059295, 70.28615136300364, 75.06110360545497, 66.91803563025691, 60.17121376529817, 58.64997348477764, 51.951165353098226, 56.78506297449912, 57.01652203836749, 61.75648281651159, 50.163733420833466, 44.56238485151722, 43.78784618070049, 42.95771575743153, 49.25388474618235, 62.38883556858186, 70.63603462711458, 83.84027019623788, 71.67891440852996, 58.65424494589529, 40.552765477088194, 20.561956782494825, 16.32811119479518, 3.9819492591965586, 0.6713753710350683, 0.6470105268301503, 0.22186300056355618, 0.6639720199088897, 0.17415680562055882, 0.07609408859524035, 0.21248737139807594, 0.18386297108184907, 0.15671698256365715, 0.9818764451530673, 50.82763379619968, 96.21160614875056, 105.16180376852714, 65.95531340568297, 62.045310466520256, 21.68141103559925, 24.326328000714703, 43.3426453990321, 53.51920735451483, 76.04850538315313, 83.04982631437241, 77.39980897595807, 67.35467387783912, 3.5566054765255224, 0.3093350576537271, 0.18211008530230294, 0.144270152875012, 0.06558077289692818, 0.07303539062699965, 0.06851117412048964, 0.0811254476467448, 0.07027902159719698, 0.05097113910221285, 0.030501417237364, 0.0338191046349464, 0.026304167056936893, 0.024166555752256708, 0.040739590542451035, 0.059733530206065026, 0.04694249338260101, 0.031763633277507565, 0.03201240692437897, 0.06552059669047594, 0.19477489764892286, 0.2609142252514439, 0.08413745255600061, 0.18372043276265745, 0.3034645258899658, 0.14290172065938675, 0.10498424481240012, 0.15549145638942719, 0.17403092205284104, 0.12302382278346247, 0.32788091249042944, 0.34286746154389075, 0.16667641669271455, 0.2520058331109824, 0.15845451594120072, 0.35083747258590114, 0.2769929092497595, 1.2436969217754181, 89.17742360022761, 125.55811297508978, 99.54455391053231, 72.7057752301616, 62.42467034247614, 52.94480369937036, 51.77982837923112, 33.80767337737545, 32.755356373325476, 88.04357620977586, 106.44163393205213, 126.89399380837719, 133.26498985290527, 108.8392533025434, 12.290129161650135, 0.9664231034055834, 0.3846440440224063, 0.385046853052993, 0.3163693689050213, 1.18998006226555, 0.1276500055926942, 0.43877284433091845, 1.2211097079900004, 3.5882813122964676, 7.653190906970733, 3.1134063293856964, 8.59741964647847, 102.59418103002734, 101.70963164298766, 110.22855681757774, 104.32036122968121, 101.84267059449228, 100.28047684700259, 97.7804365465718, 94.48336278238605, 97.8272774911696, 92.44862541075676, 88.31873832210418, 82.60057372431602, 93.00069901251024, 89.97863046584591, 93.68431322036251, 94.04503007088938, 94.90267984328732, 96.03278529259467, 88.04717694559406, 90.13007317819904, 92.72887875956874, 94.99578906643777, 100.04970027554421, 95.06977281262799, 93.62746238708498, 93.36968421936037, 93.21441327371906, 92.58415114495062, 94.93846754873954, 95.8063154835855, 101.15533797971665, 98.72870091469058, 96.90777194115424, 87.44262987567534, 82.43352782341742, 83.42217691483037, 81.6548510520689, 80.07684230804443, 82.230498098558, 82.22577556487053, 78.983928772711, 78.8271124132218, 83.57953456140335, 83.03491346297726, 84.93011643809658, 88.1898178592805, 79.80183709052302, 88.79237236515169, 94.55443612990841, 94.80374197806083, 93.86597387252316, 95.47085085222798, 98.14743703411472, 95.74941758186587, 99.18261328051167, 92.93049643116613, 97.65150039426743, 89.40103007901101, 92.73247949538693, 91.62772824687343, 91.16967385815036, 87.90032340634255, 85.64397996471774, 82.31292278535905, 82.54004370781684, 77.66309415140461, 81.90024237478934, 74.38342786604359, 71.5170774152202, 67.33143775693833, 65.40284364454209, 71.59685842452511, 68.29306956260436, 67.00111143050655, 53.58073365303778, 51.12086234554168, 48.146250555592204, 49.12789037150722, 56.62983517492972, 67.61022413930586, 72.39572755752071, 74.5018599110265, 68.78983774492818, 60.528729961764434, 47.38629917944632, 27.84249359561551, 20.143408506147324, 4.618623237456045, 2.897446020956963, 0.9441692910848126, 0.5108089192259697, 2.1483392628931233, 1.606452914495622, 0.27556155057203385, 0.41714704024695587, 0.6437779422248564, 0.28242355332739894, 4.302052663218591, 67.898926273469, 107.0734336299281, 120.05131706114739, 80.88568995075842, 95.22189801739108, 99.75827601648147, 50.72053347864459, 34.230179325226814, 50.339588965139086, 76.6959318037956, 91.60559823436122, 85.47932670962426, 87.81907543059319, 6.959886483607754, 0.7500698225152108, 0.26612484887723004, 0.1932943867699754, 0.18314675548143927, 0.21662507356414873, 0.18839444244100204, 0.17185468076457902, 0.13057279190228832, 0.17816246487200263, 0.15151927518027444, 0.16458352577061425, 0.11540924589480124, 0.24987699734347485, 0.10523007476642247, 0.11415610991178021, 0.15283391270185673, 0.1353124706375022, 0.16096106369889554, 0.14012927910493267], [0.06947164919467703, 0.1272466296570436, 0.06574590314900683, 0.045321715635157404, 0.1016890325192963, 0.09583919279036984, 0.03719074185937643, 0.0576149715080617, 0.09943288059965258, 0.08553960030117343, 0.019636930665001273, 0.07222675417940463, 0.059390472203132615, 0.07110515549298256, 0.10754844068639702, 0.09757334772016733, 0.30042876459417805, 11.530606304445575, 85.89379572099256, 79.65188487883538, 75.32240406159433, 95.70330619812013, 105.59404111677601, 125.013225155492, 115.81554166732298, 62.91288775782432, 59.608157527062204, 65.99991859928255, 97.57109180573495, 113.11206371553483, 80.55477526880081, 2.6361208048559006, 0.7158997883239101, 0.07660031949560489, 0.07455324829225579, 0.13616967705949662, 0.07357437178612718, 0.14356023451733974, 0.2834628588489948, 0.739888881723727, 0.6670453808000011, 4.249577724164532, 4.013962909098595, 0.3359257243573666, 41.411207568260934, 99.15415256254136, 99.34178306210427, 103.60778424047656, 91.5596672796434, 89.0575324335406, 88.53149552499094, 89.98187034360825, 91.58962634301956, 88.90442663623442, 79.65438735100531, 71.70412740399762, 80.99895231185421, 82.47759957467356, 90.15586668445219, 80.09066474053168, 80.89605285275368, 85.9688385071293, 79.0276082869499, 83.2720599635955, 85.79776825443392, 85.8699006419028, 86.86120910029258, 85.90012642645067, 86.9921927298269, 85.82098084111368, 84.07528292748236, 84.57856224429223, 88.89613474569013, 84.21046349310106, 89.88563891380065, 86.6611054635817, 90.01162544373544, 90.25744822717483, 89.93223667144777, 80.30161765313919, 78.32061675287063, 81.3909226079141, 81.55873729336648, 66.51861283086961, 46.39728922997752, 30.0019407656885, 59.24999806188769, 60.90690528192828, 48.80176098115983, 56.472681491605705, 68.10186970618464, 74.11086236276935, 82.71444013041835, 89.14220856082055, 85.47282341987857, 84.22201095088836, 85.87115580035795, 88.05262904013358, 84.83586972759616, 85.51414951201409, 89.82923523072274, 82.57338385428153, 80.26237041719499, 82.75130256529778, 77.67731666564941, 76.79850962854202, 82.06255005251977, 83.63465170706473, 78.49052598399501, 75.90859443910661, 70.36277094194966, 64.46638168827181, 64.51133597281672, 57.91504683033113, 55.525354569958104, 52.18677036223873, 46.77251492777179, 53.425890245745265, 55.06775517617503, 39.742227292829945, 27.334523124079553, 28.5071764838311, 19.366551714558756, 27.98283992275115, 40.82371104148127, 53.39736284748201, 72.06228686917213, 60.32617484369586, 42.237093987003455, 33.223616769236905, 13.435399474636203, 11.417387089421673, 8.995358809348076, 1.5366983413696291, 2.0039022713899612, 0.27015919046055886, 0.10297107299970043, 0.24908357540205603, 0.6499524883204891, 0.1798854119354679, 0.24484035228529286, 0.09319746881843576, 0.20542983236091755, 1.56082165337378, 40.77049232298329, 83.88696209076913, 98.64258919992756, 55.41632444627824, 65.94014167785645, 70.71975369607249, 42.84391603162212, 43.974802032593765, 36.02965293392059, 47.58809335770146, 65.86876238546064, 59.1635254890688, 47.39202191752773, 3.182673180295575, 0.14545545943321722, 0.1519208278266653, 0.025858809503035683, 0.01624192584366087, 0.04170117261368902, 0.04811109539361731, 0.043854753021150834, 0.06101595756087092, 0.06886349795686622, 0.05651077067840004, 0.02002633698735266, 0.10472832548041498, 0.06006654479631013, 0.019455429113980745, 0.04968226894796376, 0.02469793348873575, 0.04682662258405359, 0.07575693329976452, 0.05024696001783014, 0.1134220521236139, 0.09055921522479865, 0.03553436783653113, 0.03314261069341052, 0.03316910584427176, 0.037132017389540715, 0.023958124295477907, 0.015494111031594296, 0.12558421886135496, 0.048233271095781564, 0.13747935033132955, 0.04530500725752885, 0.052675546837910536, 0.1250382356585995, 0.18192414044132157, 0.38309400300345114, 18.256801405260642, 103.76074883245654, 91.50720165621851, 92.87494782478579, 100.89287650200629, 108.55851357983006, 109.57818077456568, 78.0681965428014, 19.723312854766846, 40.72553019369803, 67.61983394622803, 103.9208992065922, 120.75819876886185, 90.6879440430672, 3.433379559747635, 0.8146948547613236, 0.026731063807082754, 0.07098353137412379, 0.039049443533463825, 0.027434533619652354, 0.011255267064928288, 0.4777784255002776, 3.033569426305833, 3.4212511008785618, 5.771518147760823, 1.7542956264749652, 0.25895144670240344, 49.76010584062146, 105.41722851414835, 103.42342499763735, 109.48069418630293, 92.27080083662464, 95.98062561404322, 95.66670263967207, 98.04540049645209, 95.96681887103666, 95.66486697043143, 89.19233645162275, 87.79768282367338, 89.89790024295931, 88.67250473268571, 94.810347249431, 88.95358962397422, 88.25460756978681, 92.35663798547561, 83.12224895723405, 89.45047547740322, 87.5448860660676, 89.132794872407, 89.95113465093797, 93.84162379849343, 92.33646131330921, 90.02137645598381, 90.11306578113188, 89.68647664593112, 92.20246530348255, 87.69773298694243, 92.99380348574732, 88.2747999314339, 91.41193512947329, 94.53679330887334, 93.32700883188556, 87.78666096348917, 78.56007745189052, 80.19320334157636, 83.77730046549152, 71.30259436945762, 48.07656180474066, 33.287920105841856, 66.04651635692966, 65.30156020195254, 49.782604555929865, 62.55193948745728, 69.66418112477949, 74.55336847612935, 85.08252405351209, 91.21425551752891, 88.38635998387491, 89.4974890062886, 87.69471276190974, 91.33973998408165, 85.56022951679846, 92.58566517983714, 92.54593156999158, 84.45663928985596, 86.054714879682, 84.5166358640117, 84.18338344943139, 81.37524881670552, 81.69966805365779, 84.66413267197149, 84.48175814843948, 80.04179200818463, 76.30701311172979, 70.93043204276793, 67.16891042647823, 65.065931658591, 60.942591005756015, 61.55811286741688, 56.51083830864199, 59.48944307142689, 61.62906854383407, 59.35546667345109, 49.68423543437835, 55.56488813892488, 43.64045527673537, 40.115778138560636, 53.20859093819895, 62.43895169227355, 78.77535281642791, 86.4390443986462, 70.69516827983242, 56.62310831008419, 35.90106587256155, 21.91626883322193, 14.215025459566425, 3.4274070157158762, 0.5312165822232924, 0.43619272148897575, 0.4891198669229785, 0.197463161462257, 0.30804233024677924, 0.1330260046186947, 0.17034944056743578, 0.1104501212736772, 0.1192371957304497, 1.5711796524063235, 54.02608740714289, 94.75771688645887, 106.0557197755383, 60.79549427955382, 61.919425918209946, 27.445088855681885, 34.569409431949744, 62.732607779964326, 56.55657706722137, 70.6182506007533, 77.36428014693722, 68.99185549828314, 62.29052920495311, 3.282429349999274, 0.15610673224493382, 0.14745216035554487, 0.08498722026425024, 0.04916257405232999, 0.07425645050863106, 0.04061449221485565, 0.011462265937288683, 0.021399283376071724, 0.0793426461337555, 0.10568886950251558, 0.06025902821772522, 0.1158677112130869, 0.06820867664270824, 0.02066777474547346, 0.04080538600382786, 0.03967936699008269, 0.02871178222009011, 0.06742450138253551, 0.13359939078650168, 0.2448087894628125, 0.20111134876647305, 0.10529994964599611, 0.32217208656572527, 0.18018115251775713, 0.15954786130497534, 0.12927839442366554, 0.12776445912858173, 0.22044512503329786, 0.11801426659428305, 0.2792609585148673, 0.300148805423129, 0.24866958148777488, 0.22428054422620805, 0.3201379392656588, 0.5922191830412035, 25.99401193280374, 122.81079861425586, 103.0623237548336, 105.17470836639406, 123.31800814597838, 129.69293440541915, 142.87991154578427, 135.5297036324778, 80.11945493759649, 80.00598861325173, 94.06168445464104, 118.91852871064218, 133.30314666994158, 102.35108821622788, 5.887831132258139, 1.2436198226867186, 0.20543741663136791, 0.15651116538191998, 1.0263932015626662, 0.26556309192411365, 0.561695420934308, 0.6081803491519344, 2.9330045129022295, 2.965482718521549, 12.495088692634338, 9.007026880018174, 0.4706541755266728, 55.10817912317092, 109.97292810870756, 107.36491280217325, 110.56054622896256, 94.40867300956481, 100.95517942982336, 102.84534608164142, 105.99921411083591, 102.39134742367654, 101.13127816107966, 96.68571872095909, 86.93225106885357, 92.47902377959221, 93.83344173431398, 98.41633904364802, 94.7671070406514, 95.78498563458844, 96.09653165263515, 86.97316138975083, 92.51413683737479, 90.68819507475823, 92.45486197933074, 94.64115973441832, 96.92423020639728, 97.03690421196723, 94.48334709290536, 93.26028147051412, 91.84250154802876, 97.0030463126398, 92.67740941816761, 97.92060636704969, 93.8759288480205, 96.50718027545561, 96.18477713677191, 94.29927026071857, 86.90117805234848, 79.94182648197298, 80.53500652313232, 82.86669869576731, 77.49930381774902, 60.98467019296462, 45.400093293959095, 67.83612912701022, 71.5709472471668, 66.59323200102776, 71.29652254043087, 78.28218536992227, 75.62597197871055, 88.70076148740708, 96.1041488955098, 91.23571088237148, 93.54837171493038, 92.31506870638941, 95.356537295926, 90.10424829298451, 97.7072843428581, 97.53066001399871, 91.28753323708811, 89.23232109315934, 90.04507541656496, 86.86238581134428, 85.47702820070329, 88.9301730740455, 90.4634589533652, 88.03809273627498, 84.8595137749949, 79.98022648595995, 76.72441605598696, 74.37301789560627, 72.36528212024321, 74.1370245718187, 71.27173316094184, 69.57417057406518, 76.08005692881923, 72.22668124783424, 62.609696388244636, 51.84243725192163, 58.30508732026624, 44.36023765994657, 54.72297099328811, 66.8455659189532, 71.85819025962584, 79.32816382377379, 77.66868745127033, 66.45748661410424, 58.73095081698511, 40.9056415096406, 28.362021330864202, 16.83692889828836, 5.572465215959857, 5.917553872831407, 1.4275235802896562, 0.5483329476368043, 1.2125235171087327, 1.7694282531738283, 0.32422872620724863, 0.3755360246906358, 0.3784204989431366, 0.6128151810938313, 4.511948006768381, 76.10522285584481, 105.20947625560146, 123.48385380160425, 74.36988784420875, 100.30942393887429, 98.76640273678689, 58.50731688161051, 59.69299054914906, 51.54839677195395, 68.89096429271083, 89.70408808800482, 79.26122465441304, 85.52043314903014, 7.306140084420481, 0.39752964290880394, 0.3479146326501524, 0.305978121656564, 0.1240772626272613, 0.16624339315439426, 0.10657593037091917, 0.08122798851540974, 0.11807628141175355, 0.17716561594317037, 0.20893762639212995, 0.1780383433065107, 0.2771889664713414, 0.12331535754304741, 0.12942264877980755, 0.08608094867198698, 0.1142191589479485, 0.1155153337505556, 0.15971200330363167], [0.025209835354959773, 0.06729504784509059, 0.10965699044566964, 0.05914853014532597, 0.040224400243812033, 0.12032837306539859, 0.02990103221588558, 0.01999945879252928, 0.028437804280509873, 0.10195946155656731, 0.038432267779904994, 0.03565819828861183, 0.028718885770368, 0.07630762028237505, 0.01479671055060481, 0.0993988279914183, 0.059685603745522044, 33.78861458070817, 92.02928481563445, 75.63869614754954, 75.22763175349083, 60.604286578393754, 29.303311724816602, 32.91495369326684, 78.14915426315801, 107.87074165959513, 95.32497006077921, 113.32575444252261, 119.91252791497016, 77.14538835710096, 2.7393384662366684, 0.13970362533244396, 0.13964846700189576, 0.1823615766460857, 0.10511323869709047, 0.1013314456588799, 0.11675793602461777, 0.1151321365708305, 0.2428499486057028, 0.6310339163868659, 2.067850756068384, 3.4997281672493106, 0.5186265094145652, 4.397126993825359, 88.6323396621212, 91.41252348499914, 102.98004027335875, 102.87121019055768, 99.998638860641, 94.27324925699543, 96.05333851229761, 91.29063190952425, 91.67735407429358, 86.83813771893902, 83.7438661821427, 85.98677942829748, 87.20822118943738, 84.11493808992448, 82.18523394676947, 86.66074460552585, 77.04288897975799, 83.66244562210576, 86.18347060295844, 82.91484186726233, 83.70737245005947, 88.04891063321023, 86.43169387694329, 86.30151825566446, 84.73415482428767, 87.99107920738959, 89.27356873789142, 85.05888785085371, 83.04269544539913, 82.10715524611935, 86.12886336541946, 85.71711647895076, 93.22536453124016, 91.9189642321679, 96.11965010243078, 86.1925861912389, 80.49620643738778, 77.54401883771344, 79.40309678354572, 67.24660473485147, 40.118202163327126, 30.92086384373327, 81.49379068805327, 55.69615025674143, 21.19550585746765, 30.533541556327577, 52.81059195918422, 76.5153694152832, 83.56450403890302, 86.78774310696511, 82.40491021064021, 83.2519382046115, 86.52335966787031, 86.40139748973232, 88.21817659562635, 86.34783360265916, 78.71450901031494, 81.22328835148966, 81.34734507529967, 81.0703472937307, 84.14935296581638, 79.90630549769249, 73.298523810602, 74.87448507739653, 79.51817127966112, 82.16624967513546, 78.80384491335961, 70.52459224577873, 63.01112351878997, 62.77285914267264, 57.670718469927394, 63.16580218653526, 60.04426233230099, 53.477292906853464, 58.77839580658944, 56.5661084267401, 39.68146193412043, 36.127214047216604, 32.78056544642295, 21.894260414185066, 33.075480614939046, 45.36949096187469, 62.84434041669292, 76.21903434876474, 59.9136709397839, 41.354356734983384, 34.04443548571679, 12.506262544662723, 11.896388896049993, 7.082507619934698, 0.67532145928952, 1.9953933021714612, 0.6754290180340891, 0.3509694848570132, 0.09045180969781454, 0.1330833999259818, 0.015431057207376487, 0.09125681488864845, 0.11815603116467116, 0.2919722570767326, 3.1135754815993772, 52.679926041633856, 82.8837453165362, 94.37062601889335, 49.60545462946738, 55.005032554749526, 78.22834691693707, 32.22106483674819, 37.512226489282426, 45.60869278446321, 54.3206887860452, 63.10956324300459, 62.97799910268476, 41.719043024124645, 3.299308534591429, 0.15626860662333428, 0.07854468895182495, 0.05941609401376017, 0.05339137939435821, 0.08909256287640141, 0.024029004665452148, 0.043497870961624774, 0.06793373534756322, 0.037178013308514515, 0.04019907337703532, 0.02175454515963793, 0.02085392070453494, 0.039563247212959875, 0.015093083155431576, 0.05563704357031853, 0.016159310921906464, 0.05630206151474869, 0.06593312737682173, 0.027862839971578894, 0.07563273512548016, 0.05229986115028301, 0.029480629976117806, 0.04080950755686049, 0.04996169951834506, 0.0386421145841239, 0.015724239055998623, 0.06337360846960256, 0.08077558295260515, 0.07332527063666813, 0.048680145503772844, 0.02481344614117857, 0.03085207483250528, 0.15332065432542755, 0.20316006705885936, 46.646226375333725, 99.9490208779612, 94.5275600494877, 98.404752362159, 83.67675442849436, 63.67449045181275, 52.20102425544493, 56.41972164953909, 84.61361254415205, 101.41278666834678, 121.62874529438635, 127.4680797515377, 87.18176872499528, 3.800045174937095, 0.36929204038554625, 0.22072286254936652, 0.7427153171550843, 0.2250863921137587, 0.23378285369084728, 0.06218118878502039, 0.3596837962827375, 0.8413116297414227, 3.3837414749207038, 4.488184817375676, 1.471293063894395, 0.5817442483478977, 5.4883200795419755, 98.4553901610836, 99.56023554648124, 108.98933887481691, 105.9631989079137, 104.14088141533637, 99.71600071076425, 103.5559069725775, 100.68907014785275, 99.96683628328385, 95.58084980134042, 93.41621921908472, 92.96846497443416, 90.26337885087537, 88.89021981147029, 87.6630670793595, 91.47532063145792, 83.12035053007065, 86.43076819758262, 91.52999062691966, 86.71601080125379, 89.639172861653, 92.08495109311997, 90.24832479415402, 86.80655479431154, 91.41354330124395, 92.17268666913434, 95.90956795600154, 89.91747287011917, 86.42896390730336, 86.2697627467494, 89.38342648167765, 88.94245009268485, 95.72639326895438, 91.20117049063407, 96.16469460148966, 87.32735141631096, 80.92725138510428, 79.96452916053035, 82.59795358104091, 69.82844214285575, 52.20490347954535, 42.046780586242676, 87.3665358943324, 59.369308717789195, 28.204604848738644, 30.116173913401944, 53.83168297429239, 76.8242560663531, 85.96533190819525, 87.10331347680862, 86.0264345907396, 86.08938078726493, 88.04889494372954, 87.40681079126175, 90.24201762291693, 90.41944996003183, 87.29998896198889, 85.80058451621764, 86.65649275625907, 85.0761462796119, 86.32585264021351, 85.41175996103595, 81.48560077913346, 78.87203139643516, 83.5150900194722, 84.14126503852107, 81.6357804882911, 78.16074094464703, 70.15930975637129, 68.11722970777943, 63.408490996206964, 65.56016598978351, 64.99756082411736, 61.59507728392079, 60.26544870868806, 61.81258055471606, 60.01339720141504, 57.00830467285649, 60.43733089200912, 45.58190691855646, 50.81227379460489, 55.080377363389545, 63.11169701237833, 78.40955257415771, 87.87123510914465, 67.83794126202984, 57.51045042468656, 34.01866943605485, 23.445147929653047, 11.423235343348596, 2.2582075480491888, 2.328615563531076, 2.832298884468694, 0.4376595347158371, 0.05926541217993345, 0.26815170302025737, 0.018521464512413068, 0.10201019189891317, 0.06285748737413557, 0.3711556565136679, 2.4748246083336496, 62.61867861593924, 92.57745958143666, 101.29735915891587, 60.58930312433551, 57.57186297447451, 33.504803642149895, 35.39266786267681, 58.51439283740137, 64.21256511442124, 77.19295101781046, 75.62493647298506, 73.13713396749189, 56.11128607103902, 2.9387625523151892, 0.22395134092338626, 0.10439630297403182, 0.025352879292181423, 0.08632982765594799, 0.05508471332911042, 0.044737519966738845, 0.09829841929698184, 0.11105016730124913, 0.02013479971567229, 0.043025918665432164, 0.08561263912387433, 0.02097942505873019, 0.06920521913637077, 0.027759079107894536, 0.06745774193757004, 0.08424229168843839, 0.025959417914911628, 0.19330704254248451, 0.15202927523322646, 0.3290479095472444, 0.10233996210679894, 0.19550674144298802, 0.1968926864285623, 0.146723763957139, 0.23420757283606838, 0.10545241646468641, 0.23068510056022676, 0.2197547112741778, 0.18182660212680218, 0.12077902428685658, 0.19078232317922578, 0.1648396289637012, 0.29568658841233103, 0.30812846917298536, 61.49259359605851, 121.07789547212663, 101.96725291590538, 95.74267894990983, 75.54998782373245, 38.31799899378131, 44.72985436839443, 93.7062628038468, 137.9746581662086, 119.54967729506956, 131.08001785893595, 140.65487646287488, 101.79641800542032, 5.852163549392454, 0.5708665965545563, 0.3651742871490217, 0.9190253048173843, 0.4919075383053672, 0.3913729619835654, 0.5056764059249432, 0.6815343097813669, 1.2440816817745086, 4.001761641233198, 6.03135654041844, 10.506232265503177, 1.4986991545846386, 6.583321786695912, 105.31782780924152, 99.61896127270114, 110.55227002789898, 106.20666042450937, 109.61199945019139, 102.53459238236951, 111.14981174468996, 105.17637145134711, 101.96126737902242, 96.16406702226209, 95.62043436111944, 95.13216987732919, 98.09075094038441, 92.16171972213253, 95.48016255901706, 94.45452551687919, 86.46304930410078, 92.88389082877868, 94.55104720207953, 90.6655159304219, 94.20228573583788, 92.9745211139802, 95.45274519151258, 91.48333011134979, 96.16461615408622, 96.68536570764358, 100.37141307707756, 93.13965289823471, 92.19641700867685, 88.40868611489573, 94.56745055414017, 93.20320313976657, 102.49671797598563, 95.18862062884916, 103.28061149966334, 91.23388305787118, 85.08985104099398, 78.87452602386475, 82.68038611258231, 70.60946449156731, 52.938343555696555, 40.691197687579745, 89.71498443234353, 68.61197394709434, 32.90187651111234, 46.33238969310638, 59.71603839628158, 77.82186385123961, 86.6788738004623, 92.48940237106817, 91.0796711521764, 88.15871346381404, 90.4136448521768, 91.85412745321952, 95.47926041387743, 97.44918454077937, 89.95451573402651, 89.88536434788858, 89.73403930664064, 86.94741495193975, 90.17247399976178, 89.09358686016452, 85.37055938474595, 85.53817010694935, 89.82408123631632, 87.91029407132058, 84.1224298169536, 80.80426939072149, 74.15559307221444, 71.84775675496748, 70.28019720508208, 74.37431227776312, 73.98577013323384, 70.72817110246228, 76.69706929114558, 71.31034497291812, 59.26687994310933, 59.734626508528194, 57.177770676151404, 48.74073674601894, 61.74705343861734, 67.1627679947884, 76.00310787077873, 77.20154885322818, 79.14631489784487, 64.23396948845156, 61.54136434678109, 39.90081264126686, 31.169379334295954, 12.967208700795329, 5.097175932699635, 6.276418874340673, 5.51940143108368, 0.9792569760353336, 0.2944759549873491, 0.6615017234317718, 0.12114849317097857, 0.2864792840855737, 0.2658775863387893, 1.2057910138560881, 10.649779246699426, 88.11740306115921, 93.3813258140318, 118.21258052702873, 68.30730776632986, 88.61548915986093, 107.54458873502671, 44.069739080244496, 50.51832352915118, 65.22291275762743, 76.58794895295175, 90.0551009947254, 83.12475142940399, 75.1822263963761, 4.192172856100144, 0.4663646040904907, 0.2472346375185636, 0.25401456161372127, 0.21624019099099023, 0.18267758791485142, 0.18316569317492748, 0.2137100477252276, 0.25020066949148334, 0.16517316832417445, 0.1512221862832385, 0.16568430218725436, 0.13743566799788706, 0.11737315059309045, 0.140454713255167, 0.177901734507853, 0.14464647058517704, 0.19163442745564446], [0.053038829562043956, 0.013663666510593989, 0.05838003670496326, 0.016255535395635713, 0.06640840832504534, 0.06515757060579716, 0.01212556688715854, 0.04166171525514895, 0.016139593733955297, 0.1508522730681204, 0.07935464307064972, 0.09361237437734682, 0.06263909868956094, 0.08091673465265382, 0.13151557034542485, 0.10171656571929494, 0.8176198397432605, 57.95483927572928, 87.01240078095468, 62.34415584994901, 73.3117735770441, 51.04380346113636, 39.59190637834611, 53.02914642518567, 54.289682449833045, 57.744733595079, 108.97861511476579, 103.54359073023643, 87.76319734511837, 7.451353582643694, 0.3381772567668269, 0.18199313431978228, 0.18557879352761855, 0.2112652466542298, 0.19529566889809025, 0.14684508164082805, 0.0951469021158353, 0.17718602452547322, 0.20411576174439924, 2.549307966424573, 7.777444239585631, 1.871127712149774, 0.15629621643212535, 33.58606730737994, 97.86402225494386, 94.25901889801027, 100.27780179054507, 102.55677730806413, 95.17150340541717, 97.18547574935421, 99.53912535021382, 100.81487624875962, 95.8263901741274, 91.51397166713592, 88.34547319719869, 83.82802455655991, 89.56671883982997, 82.04566817129813, 82.77232646942139, 84.33601071757656, 83.54282117659046, 80.26539064222767, 86.62602378476052, 84.93039100400864, 84.40864516842751, 81.42155631895989, 80.65774533056444, 83.3437922693068, 86.6709270784932, 86.18171338112124, 87.98168120845672, 82.55174806041103, 81.16734750809209, 86.87063847818683, 88.98987154806815, 88.28036185233825, 88.72944970284739, 85.94222130313997, 83.96260107717207, 79.4927150972428, 74.71110267023887, 74.41277503967285, 75.3880488487982, 73.72669758335238, 75.62395588044198, 79.23386220009097, 81.10608793074086, 52.358079879514634, 60.7347289208443, 19.40116467014436, 47.00575474769839, 76.05005864174136, 84.73039719366258, 82.69722092536189, 83.07778496896067, 86.78779802014752, 85.26907982364779, 83.23369918331024, 81.96572242244598, 81.82197540037095, 89.28321776851531, 85.05660503141343, 86.83207373465262, 84.59801720034692, 81.43249188700031, 83.615855709199, 84.46814752394154, 80.82222600137034, 70.88372445875599, 71.13292832528391, 79.18819796654486, 75.32565962883734, 72.28433224462694, 70.4244698247602, 65.82196066456457, 60.536594313959924, 64.13907950924289, 67.41804369034307, 56.68237140101772, 55.72688202704153, 56.56626924391716, 48.79916437210576, 44.10142790886664, 35.49377872097877, 33.985074335528964, 34.671755836855986, 43.35080392899052, 61.52273701083276, 79.27624733217301, 59.378812620716715, 43.06882081493255, 31.666612317485196, 13.27397923315725, 14.833191979315975, 3.793415143605202, 0.3172325354910666, 0.7309817306457028, 0.22566507961000168, 0.061459920834749944, 0.040253875476698724, 0.34182821730932883, 0.02571648951890248, 0.1274512517416189, 0.07190144260323818, 1.1376086982988542, 8.526811099821522, 64.51441503340199, 73.75992005871188, 95.21841495267807, 60.539426265224336, 70.24961056247835, 71.91886148145123, 32.28440523147583, 29.654965939060336, 28.373194202300045, 48.708687059340946, 62.96678504636211, 51.85409845844392, 43.77556131732079, 1.7613224300646015, 0.16334269315965716, 0.025646329271577062, 0.04044801364803026, 0.057092855774587205, 0.07845644328382709, 0.0505612475887662, 0.0403876344282781, 0.08335815727590554, 0.04650822878184338, 0.062369370622740644, 0.025331731435031663, 0.15309573091085882, 0.11130864536690135, 0.09670476489249738, 0.04297609230683696, 0.024328464604613763, 0.04323137578584495, 0.029043463817346963, 0.030590526669496493, 0.03303244724989899, 0.055418612750908064, 0.03369213322237615, 0.03893510874120459, 0.06134443691060428, 0.032477171400622014, 0.026162687854300586, 0.09685336296717006, 0.06031684487337067, 0.06509041533835473, 0.0687810592353344, 0.016236637921763525, 0.09833889172202158, 1.4544523675595562, 73.47974515730336, 97.25179518422773, 78.00623093881916, 74.07790660858154, 64.87636350816297, 55.58995600669615, 17.416349264883227, 37.32365069850799, 74.7573709487915, 118.79942986272998, 111.21614686904415, 97.98229740511988, 9.919547669349178, 0.3338000142285901, 0.2421684061447459, 0.08804619402414368, 0.3177374487202014, 0.41369452712035953, 0.05736554094079522, 0.42246258727485136, 0.1757287567541484, 1.5428815902240816, 2.079836783870574, 5.368885868980039, 1.3021012587893395, 0.21685652404783234, 41.00749761827531, 102.18607410307854, 93.74587089784684, 103.49200371773013, 102.44218134110974, 99.63718460452174, 100.93432026524698, 104.22190973835608, 102.61431847849201, 98.6434050529234, 99.45022090788811, 95.54360297418411, 91.35973622722011, 93.57928783662858, 86.39292517016011, 89.20574311287173, 87.07050677268737, 91.00406354473483, 86.11330724531605, 91.28882761924498, 90.45810099570983, 88.88919999522548, 87.21169640941005, 85.92202109675254, 89.5226235543528, 90.36589391769903, 90.29887630093484, 92.74130482827464, 91.499906047698, 89.0515390519173, 91.67102336883546, 93.85939998011436, 89.72839893833284, 92.03217168008128, 85.72613008560674, 82.98993956658148, 78.3188359968124, 77.00594809747513, 76.37170084061162, 76.03986832403368, 74.61579691979193, 77.15921863432854, 82.54417788597846, 86.0590922447943, 62.6186982277901, 69.87735409890452, 32.0457015498992, 50.23937240723641, 77.393752836412, 85.73965441796088, 87.63253534993818, 84.62914513003442, 91.39997190044772, 88.95619407776864, 86.96077454474666, 83.13273737507483, 86.44686560476981, 90.43298213712632, 86.73275147714924, 85.20938919436547, 86.5066582156766, 83.0852217828074, 84.38741730105492, 84.29140552397698, 84.76541611456102, 78.97833547284527, 75.88051026867282, 78.789763604441, 77.61966566885673, 76.85010448578866, 74.80388241429483, 70.35549102290985, 66.34289849189021, 66.60987854003906, 70.1174109981906, 61.8990570499051, 60.00520729249524, 61.93341701261459, 64.75477787756151, 61.067514573374105, 60.43900182170253, 53.22031098027384, 49.869465443395804, 54.18771651483352, 60.33651421147009, 76.81110043679514, 86.98174353568785, 67.02865431385656, 54.43798726604831, 37.589552094859464, 25.677937538393085, 7.032765102001929, 0.40452687550456295, 0.34336223176890807, 0.1543972376854189, 0.4033225240005601, 0.037742968678714774, 0.5118129847030486, 0.018360902059582934, 0.150628054454442, 0.09085969023045995, 1.1153784201991175, 11.938057214983049, 74.6023981032833, 83.76688265031385, 100.77466410975303, 75.59140020801176, 58.12409739340506, 31.38725719144268, 37.83323326418477, 49.22089761303317, 47.519428345464895, 74.34461209081834, 73.06639794380435, 64.14548081736412, 57.30820909623177, 1.4056475412461067, 0.09830843972703142, 0.04375163375610306, 0.15890336685603665, 0.06701630675384114, 0.03161506393113204, 0.051627546218374086, 0.03713265707295749, 0.06102020551841106, 0.017306922123797478, 0.06791293606041901, 0.046332442246737986, 0.02027786472031186, 0.05915656257721205, 0.06322704818880846, 0.04673054366702995, 0.04786177590909985, 0.12745122875898116, 0.09500994091673244, 0.1721152425893853, 0.1671586996845661, 0.1589036579694479, 0.12363864664709377, 0.2610940414090311, 0.1255846402097133, 0.1021792215385264, 0.15101299831463447, 0.16035081338017218, 0.29826202279617714, 0.26803170300779805, 0.2002816908662358, 0.2502223497797405, 0.2117385051303333, 2.6366147783494767, 91.57960860959946, 112.05398082733156, 84.58489294975035, 93.44213824118339, 67.92329203697943, 60.659191916065836, 70.37436546817904, 79.70386412835892, 80.21973425342192, 129.87651701896422, 121.12365384255688, 112.4661591745192, 14.044799497050624, 0.6455322835714586, 0.5578269220648274, 0.6512817427996667, 0.6316138755890631, 0.5608112328956204, 0.22852036591258743, 0.500920562734527, 0.34068640922346427, 2.1201258993917897, 8.766421829500507, 17.18995398090732, 7.151948771169109, 0.8707428891812602, 49.723412067659446, 111.85396348276447, 100.71937437980407, 112.19984592929964, 107.21093623868882, 102.05198395636775, 103.06658344884073, 107.15877656013735, 110.75112635089506, 107.60121207083426, 100.97070417096539, 101.28221096531038, 96.25675262943392, 98.94564720892139, 93.34004679033833, 91.16387659503569, 93.21711186439761, 94.48582603085427, 90.88257205101752, 94.79402234477382, 93.12224541940998, 96.15612030029298, 95.42278612813642, 87.76342484258836, 92.25394248962404, 94.80733486913866, 94.58220651072841, 96.82730059469901, 92.26931033595916, 90.02859361710088, 94.35194769213277, 97.18734279755624, 93.28673393495622, 97.1675818966281, 90.12563305516397, 85.49763633358864, 81.53287318445022, 79.89144755947976, 74.40270239307036, 76.55497750928326, 74.6400293227165, 76.03936626065162, 81.12409160983178, 92.0731290694206, 64.98418161945959, 65.0036601097353, 29.606532512172578, 52.96679250655636, 75.64109663809501, 88.57374729648714, 89.1425694188764, 87.78518615230438, 96.32005183927475, 92.46757830342939, 90.7399860505135, 91.76271269398352, 90.51120988784298, 94.73564178712907, 94.13065541175105, 91.26839207064722, 91.93448897330993, 87.51346788098736, 89.36832535651423, 87.48620740828976, 88.80385706501623, 83.28363880034416, 84.30587906991282, 85.59054159349012, 85.27085273496567, 80.25753021240234, 77.5040263514365, 73.78383867202267, 74.48259322874009, 75.22418791247954, 78.20436554570352, 68.34551949654856, 73.23171015708678, 72.93504561147383, 66.65087515308012, 59.728350716252486, 58.47520051463958, 57.71533935300766, 59.51583277794623, 62.23684764677479, 72.13427805131482, 75.86803713152486, 73.82455287441131, 64.2161266265377, 55.92691898345948, 42.288924186460434, 32.160052368717814, 6.590320765972138, 1.355177791368577, 1.4836102868280103, 0.5428870430877132, 1.0396239690242275, 0.12514024026571743, 1.930352559974117, 0.2451361081893406, 0.22171214252950686, 0.1897559185782748, 2.7413849628740743, 23.829091095155288, 95.58647448016752, 88.90771358243882, 120.73795149403234, 82.46528333233249, 112.87425825672766, 97.95673924107706, 43.40917664189493, 43.3957346793144, 46.06675109555645, 73.27145161167269, 87.072797436868, 73.65633026246103, 75.87980424204181, 3.631548977667286, 0.39973441331136617, 0.09649147069261921, 0.18239563691519922, 0.14069020868309084, 0.14774405517645423, 0.23290526933006703, 0.19882434648611855, 0.24324120503039132, 0.16482655950371297, 0.1750095534108339, 0.14208006071707896, 0.28721356403923803, 0.1724125919563155, 0.18837867635152034, 0.2030525696013243, 0.12026692515299206], [0.037108904516865174, 0.04303460993293313, 0.05865241926644118, 0.041057283374210524, 0.07301694322978297, 0.05244073322823933, 0.07106606968708577, 0.06271011504014173, 0.11786933808076767, 0.083753481627472, 0.0060486654007446865, 0.09760749225895252, 0.10876439076157347, 0.12240627164682075, 0.08628426840709102, 0.12451633826018342, 8.65327419773225, 69.78156981929656, 75.02273498042938, 78.87610281667402, 94.56683081965294, 61.33000350767567, 63.40999718635314, 76.98053898349886, 57.86793131982127, 102.23667267830142, 106.31364699332946, 101.75426037080827, 19.40685602926439, 0.26599798471696917, 0.1219611592410553, 0.18233793517274244, 0.30018349388434046, 0.8647862797783268, 1.0711306525814919, 0.09390049238478947, 0.1595427744811581, 0.35581324429761985, 0.8966372126052458, 4.434237028321912, 3.687162058007333, 1.0436399857844076, 2.9073907002325985, 67.79789386257049, 81.65677301345333, 87.12218007733746, 81.4913195948447, 79.4988339947116, 94.65784549713136, 96.7969100706039, 98.33910757495512, 88.7507873965848, 90.96402399001583, 87.89913100581016, 87.90328087345247, 80.46461566801995, 87.18438886827039, 82.14731247194352, 80.90331708231281, 82.99815300972232, 88.46195974657613, 78.26207930041899, 81.69525146484375, 86.38497060345065, 81.79711541821881, 80.9020854580787, 85.20989125774753, 86.3777534423336, 86.19504159496677, 88.89508355048396, 87.39108208687075, 84.43300308719759, 83.33122499527471, 80.8951428628737, 86.94517135620119, 86.00111176890712, 82.56324060501592, 83.10615939478721, 78.69936081670946, 84.61793499608194, 83.45883538646083, 79.82038205669772, 82.37148377203172, 78.58824006972775, 75.08444170798026, 63.89558269131569, 58.03676582151844, 67.56970605542584, 83.89021765801215, 73.20971350516044, 62.403199288152884, 72.96696585993614, 83.24334821393414, 86.49660125855478, 84.71003224772792, 80.57978430101949, 81.05282998854115, 84.68189316411173, 80.21232881853658, 80.60901380354359, 81.48381217833489, 83.31966969274706, 77.35687471205189, 79.57655183730587, 79.37318478861164, 78.72760188195014, 78.52702756081858, 85.38164400285291, 83.92203592484998, 70.91917484037339, 70.99460201878702, 78.73616049366613, 72.25729926939934, 75.07553008294876, 66.43647055472097, 65.29701809729299, 60.30560201214206, 64.18713246622394, 65.07602783941454, 59.063858062990256, 56.47146555685229, 60.06034012763732, 52.038987221256384, 47.285407973874, 38.63149835217384, 32.19697167796473, 36.893680480218705, 41.7992280375573, 51.7200122341033, 87.00222615272769, 63.80870219199889, 46.401529312133796, 29.71726102213706, 20.29092296477287, 16.480887513006888, 1.2508447059700567, 0.04883586819614134, 0.3390302803487547, 0.1936000864952803, 0.14728247188031673, 0.15962132913691385, 0.225671683287909, 0.1417849942921631, 0.10346180594135677, 0.1474496782306702, 3.3965565937180675, 13.849844951783458, 61.71762389521446, 67.57327541228264, 84.39688590265091, 62.392981513854004, 61.52656132175077, 72.51686603792253, 32.38050526188266, 37.45158272404825, 36.160052130299235, 58.18656506076936, 69.54212480975737, 67.27657948770832, 46.21369092695175, 4.146749848319638, 0.1182097492499217, 0.04660985034499918, 0.025091204724665132, 0.09723285994222088, 0.0395482893462383, 0.05480578837675914, 0.04042563621976203, 0.060571469516763767, 0.025638691374971986, 0.031847743985934124, 0.06740748656973725, 0.017819427284261873, 0.041207547690118515, 0.11070527451773805, 0.015385524771596878, 0.040329970990217505, 0.05553997256943295, 0.057135320028230074, 0.02771795742333897, 0.05430851687466907, 0.07585455588395558, 0.06824973895544968, 0.08322532529071455, 0.05702982589061703, 0.04864598564322918, 0.06030696616958707, 0.016045731683862547, 0.03998861753291661, 0.10019119273150161, 0.1230558835630936, 0.22268349605221904, 11.110819539716168, 83.76798091396209, 84.82110592626756, 84.66466611431491, 100.3782223116967, 69.51850429657968, 28.964369912301343, 63.83324838453724, 65.73359358695247, 112.57125516091625, 115.31617687594508, 114.66719719671435, 21.865289788092337, 0.8583390063816502, 0.08940030039558489, 0.31499445558555667, 0.2426562509349277, 1.3999791034767706, 0.4622256148967051, 0.1727123008740525, 0.18730299697527963, 1.152991988966542, 0.4618996291631653, 4.056901830819346, 2.807550689866466, 1.2751665879641811, 4.440773167917806, 85.1330598708122, 90.1312812682121, 95.55144771452873, 88.9009435715214, 88.8429238719325, 98.33709932142689, 97.35326690058555, 101.00851581942652, 93.53147414422806, 95.9932791802191, 92.58351572098272, 92.93162607377576, 86.58902014455488, 91.02367539559641, 88.95073413848878, 86.68904058394894, 86.10649801069691, 90.61279927530597, 85.51935841960292, 85.7657068006454, 91.1679558600149, 87.49731556061776, 89.71839689439344, 91.56331508390366, 90.35597032116306, 89.86958073031518, 92.63122743175876, 94.86191072771626, 87.96178694694274, 86.31115944154801, 86.343777871901, 87.91509505241149, 87.33449797476493, 84.12392816235943, 84.31795212530321, 80.36357541238108, 85.18438800688713, 87.79951849291402, 84.62437552790489, 85.54565398923813, 79.91289507958197, 73.70950191251694, 66.3570111797702, 62.04511042564147, 69.81928733087355, 77.79891798573156, 77.11121666815974, 65.73712372010755, 71.41659413614582, 82.914151530112, 88.20332650215396, 87.08365455750497, 82.54864154323455, 84.1942797937701, 86.83516456234841, 86.0575625204271, 83.88976266307216, 85.43702002494567, 87.84828139889626, 80.92092852438651, 82.48891953499087, 82.5969337647961, 83.5947847366333, 82.92010568803357, 84.28680066139468, 85.76744833300191, 80.02367850272887, 74.11877770577708, 80.17212452427034, 76.01519661564981, 79.23531347705473, 73.78532132794781, 69.0610461081228, 64.9332457204019, 66.72269375093522, 67.74345136457875, 65.6074893859125, 63.87617872607324, 65.71735497443908, 63.74676404460784, 62.42478016884097, 63.65169363637125, 54.08668018156483, 49.303577253895426, 55.508198122824396, 51.3971423333691, 76.02408470646029, 92.05962042654716, 71.77523213048136, 56.7108242742477, 41.38055424536429, 24.126528347692183, 3.7226215101057485, 0.021574345958088676, 0.19813653742594106, 0.07689520972029817, 0.3214475206069408, 0.19826338626444343, 0.1599911657432395, 0.2892532884593933, 0.03231179983084721, 0.5526733566676417, 3.5233084761327316, 15.036386443722634, 75.6219554716541, 79.36199034413984, 93.74208973300074, 76.39724331517374, 41.76654292691139, 33.91986493141421, 41.300208414754565, 51.30300152686335, 55.48626422882081, 78.67809372563516, 79.20701749863164, 76.84867674304594, 62.01870110727126, 3.406600803136826, 0.09860555926758437, 0.05007146459613597, 0.041157231035251776, 0.07083787507708035, 0.025196574372990478, 0.025324558936840585, 0.043903384282584154, 0.08357914299854348, 0.041208137577820214, 0.07046279842935263, 0.054887254166627125, 0.05940321607575302, 0.02172045807744707, 0.05570116129914119, 0.04039706114018637, 0.16567088032682098, 0.12700702033696637, 0.07442517371307458, 0.28562249135105844, 0.14620979556873923, 0.14173046415371282, 0.1664359570150414, 0.23064691873808063, 0.22903012081740365, 0.20140102193240197, 0.14388548480647226, 0.27492030433589415, 0.1903891055694511, 0.2678945426258349, 0.28041686261853865, 0.430041617683826, 15.51677873057704, 105.21143744068762, 99.93335493149297, 102.71690414797877, 118.97893321129584, 78.79515294105776, 90.71712647714924, 115.12003483310824, 78.82651621295561, 126.87038113993984, 123.74250273550712, 127.8277454068584, 33.44744682312012, 1.1527465956826364, 0.373507515797692, 0.7646776483424249, 0.5739755039253543, 3.210427626486748, 2.3795286638121453, 0.422089257307591, 0.709289062407709, 2.7316246349965376, 2.8469584978395894, 12.375441693490552, 14.552675831702448, 4.326311542141823, 5.220009857608426, 92.11687134158228, 97.51851635594522, 104.69162141123127, 95.63636702875938, 94.86074186140492, 99.63494885352351, 101.75298952287244, 105.55899866165655, 99.51424183384066, 101.4557993796564, 98.0638042573006, 98.58658559860723, 90.06921368260538, 96.3006753306235, 91.74306161942022, 89.87304810554751, 90.33403642715948, 94.61633113122757, 90.18424895501907, 93.86764480221657, 95.61921058162567, 92.06784955916866, 92.71741759392523, 96.91680908203126, 94.84694296313872, 94.51870333763861, 97.02281505830827, 97.89103954069077, 93.49408611174553, 90.41593551635744, 87.58731042185138, 90.92697328136813, 90.6098339634557, 84.5905960759809, 85.87175984536448, 79.94739624761766, 87.53949672945085, 87.58025015554121, 85.82761749144524, 88.23419555541008, 79.75098748360911, 73.97274786426176, 70.80299423586938, 67.24411010742188, 71.83006686549034, 88.45795108426003, 77.73776823474516, 65.17278878919541, 72.04726419141217, 85.23510425321518, 93.41101031149589, 93.29062492616715, 88.63003330845987, 88.80417869937035, 90.3315810234316, 88.75241910257648, 86.87828710002285, 89.16715483511649, 91.08536643366661, 82.47804672487321, 85.66421155006655, 86.05211827062791, 85.16221092593285, 88.29983249787362, 89.21252881326984, 89.10687585030833, 82.28899632730793, 81.85100093964608, 86.33856896431216, 81.54427159217097, 85.3525713951357, 78.19142172413488, 73.02909620346563, 72.71205886717766, 74.62353967851209, 73.83854004644579, 70.20145170150265, 69.13026025218349, 73.49517576156124, 65.79204866963049, 60.850933059569336, 60.982308926120886, 54.15533734906105, 59.23471258532617, 64.84332538420155, 63.526118955304554, 77.15038545670049, 78.36313524553853, 68.90077021814162, 60.19812122468026, 49.347547023527085, 31.986024648912494, 3.126872316483529, 0.0852517887289005, 0.8390352454396987, 0.3422814349253332, 0.5405984626662347, 0.3497925899442165, 0.4688725308064492, 0.350540628837001, 0.1681704720061633, 1.2196699529886246, 7.6270934170292275, 27.53303231731538, 94.26480047164425, 87.6183363699144, 108.85706870786606, 84.25092666379868, 99.02245506163567, 93.69706092342254, 45.88657309932094, 52.30810888351933, 56.99788685767882, 80.45395466589159, 93.74374497321345, 84.21116167499174, 83.79819100902927, 5.954578595776712, 0.18867846187804976, 0.160505409923292, 0.12063679240283467, 0.15049982665767594, 0.1315544722902198, 0.17783393572655418, 0.2219753090532557, 0.21074634465959766, 0.13757060672486984, 0.1569525546003734, 0.185053410429147, 0.1307836192990503, 0.15537855035114675, 0.2651672696153964, 0.1111520876386954], [0.033969874568884416, 0.08594323670671833, 0.005917189391179672, 0.043720136051096266, 0.02112968937463818, 0.04948366831447329, 0.03640582349391715, 0.06498935301938365, 0.020802328513274272, 0.11059065244250721, 0.01919492283054898, 0.026864100720793493, 0.09495279841846037, 0.09916373092921511, 0.02725315847313933, 0.3032943011531907, 21.23855975366408, 81.55198297192975, 72.35200097483974, 70.05661426051971, 44.81459325359714, 52.97937939243933, 82.52470724044308, 41.956016940455285, 82.77960638846122, 99.40045387514176, 101.52917123609974, 31.55088278555101, 0.47541574905476264, 0.04059093501118403, 0.05937752531721227, 0.04565848022579186, 0.08695133180627901, 0.19672463738149215, 0.8059257833707718, 0.137156781349932, 0.15719332071321626, 0.480715545314935, 1.1851640045642853, 1.3079447323276152, 0.6596860950512271, 1.2328869921545829, 28.121868333508893, 99.24290795480051, 80.88732950149044, 88.19968654263405, 87.6605018492668, 88.98223077097248, 94.85529761160575, 90.1452684402466, 90.97643436924105, 89.1114571786696, 87.39835416117023, 83.19547176361084, 83.77129139438753, 81.26397117491692, 85.23734784895375, 84.75876377474877, 84.35835253807807, 84.11413792640933, 86.61253083136775, 83.81471203219506, 74.25133812812068, 81.55238305368732, 82.25813511879214, 85.70098769280219, 81.80030038279872, 82.46916647880309, 84.61854688582882, 87.21351638917001, 86.17596318644863, 81.03082549187445, 81.70234311011531, 81.30099834934359, 84.29085639215286, 87.57926956299814, 86.85935774157124, 81.68834809334048, 85.75830921050041, 89.38976503187611, 86.30784896112259, 87.28568015560028, 83.5763103731217, 79.56414930282101, 81.87322508904242, 69.14553396163448, 57.19084785830591, 70.37481261837867, 74.18941959258049, 60.716976273444395, 74.04931253002536, 68.50302619318809, 77.7973255034416, 79.64675441864999, 80.9841492868239, 78.47346367374544, 78.07568042509018, 78.41152160398423, 82.61773801619007, 80.68486459793584, 84.133114353303, 85.57071793463923, 86.62914599141767, 86.0764212762156, 85.41330537488385, 83.50553512573242, 80.84721934410834, 78.60018760927262, 79.66466396085679, 82.87206449816304, 71.64947309801656, 72.1243073863368, 78.96545440919938, 76.7801215571742, 75.32846804588073, 62.995838042228456, 63.833013042326904, 58.10154376491424, 63.23245110050325, 67.0052848323699, 62.41730020892236, 60.76403687077185, 61.94185010848507, 58.86740223053963, 56.25158925210276, 47.189211845397956, 34.89233424586635, 41.14087389361474, 40.89993838341006, 50.73424608476701, 88.60340825973019, 66.53279612141272, 47.9574433449776, 34.48688668589438, 22.08122018844851, 13.059907055670216, 0.5601786894183005, 0.04738580548174439, 0.34323499988644357, 0.3185424845545523, 0.15522681897686375, 0.06687619693336949, 0.2082072688086379, 0.06559210333732829, 0.16704387842647492, 0.7891803883737134, 1.466871326969516, 13.648823480452261, 72.6598285859631, 70.15951371962025, 77.66543972876765, 53.20233083540394, 74.23577416327693, 45.48271802163894, 29.2863239396003, 34.638619653640255, 24.122072535176432, 44.32891753412063, 64.181397961032, 63.095732965777, 59.32929269729122, 1.6981709219755667, 0.2546211500321665, 0.08992906960268175, 0.03414336284021697, 0.0416733214872018, 0.04481136318176024, 0.03202508950996543, 0.018626675197494127, 0.034486079934023084, 0.028387334408058275, 0.07174064840881095, 0.037438896890248985, 0.07759025831136011, 0.021526293093038183, 0.06921507102707702, 0.08523854306868969, 0.13316045304940594, 0.03095972550762517, 0.03850212733772013, 0.016788073755320043, 0.06764231550116694, 0.07297653975265642, 0.05122099867871693, 0.03835173278686501, 0.04534023581072689, 0.02110786161445562, 0.03357741155571515, 0.028187534846966306, 0.1248531794596103, 0.3010530649654327, 0.23511679662812143, 27.60562558327952, 92.40855447707638, 82.7393550257529, 91.90146261645903, 69.31321528650099, 63.76521879626859, 61.78339027589368, 47.02703752825337, 91.93765040366881, 108.75995866713986, 113.54138282037552, 38.79429632617582, 0.8567544301190685, 0.06458480496920886, 0.14441871264528844, 0.021827549508382237, 0.10684892580273653, 0.13017071831610896, 0.891638151820629, 0.2531383408894462, 0.02327926697269563, 0.5110605025003033, 1.254403766605162, 1.2048270913862413, 0.5711506006698455, 1.183482165778837, 34.64003955164264, 107.3333534117668, 86.79840410909345, 95.96616775758805, 95.5320712058775, 96.37753025177987, 99.90480792137885, 95.99660535012522, 92.53603150767665, 92.51540768531062, 91.92663638822495, 88.70105174279983, 86.93345915886664, 87.59732031053113, 91.33047534573464, 89.00560809719948, 89.62036117430657, 89.5327668036184, 88.32047200972035, 89.4340564358619, 78.45382044392248, 84.92908093237108, 86.3095042013353, 91.36327420511554, 87.39023485491353, 90.28397913902037, 89.84874509995984, 89.45076573279597, 87.21912537851642, 83.5441626271894, 85.09920981622513, 85.1980927682692, 87.21814478597334, 88.46540358758743, 87.92850171366047, 86.5154835485643, 88.91585642291655, 87.61830499095302, 84.64113189328103, 90.21424724209695, 86.87822434210008, 83.51873782373245, 81.36272076637515, 71.54182757100752, 63.43474341977028, 76.28370638816588, 79.16981773991739, 62.3774253937506, 76.4681048547068, 68.61194256813296, 78.14705971748599, 81.15538427906652, 82.16679096221924, 82.45135107348042, 81.22552410248788, 82.4977840915803, 87.55105987671884, 83.28532541951826, 86.78185955170663, 86.54090835202126, 87.77372498666087, 89.09858395976406, 85.37635664786063, 84.98943836458268, 82.67625193442069, 82.2108627134754, 81.47322962360998, 83.75238557015696, 78.42299061436808, 76.33900396285519, 79.22073794949439, 80.44255625817084, 78.87331793385168, 68.82575881096625, 69.49403655144476, 63.17153276935701, 66.17957884265532, 70.89026697220342, 67.07318106005269, 63.693258993087284, 62.44180717775899, 64.68521072018531, 64.74559168661794, 67.96581837438768, 56.92026315196868, 52.217623726014175, 54.65091705322266, 51.05777494369015, 78.61226066466301, 90.79833522919687, 73.18909752753474, 60.883567179403, 43.10790723369968, 20.956715883747226, 1.528750148511702, 0.2566844393168726, 0.5964392856244118, 0.20662103779613974, 0.4987529322745339, 0.16688083959442956, 0.25803649257267675, 0.026224281323412736, 0.08447380345915595, 0.5374010568184238, 1.6539053811180977, 18.40385106302077, 85.88413884562831, 80.0240707397461, 87.16047809969994, 62.646817699555434, 43.093163044221946, 32.63072502228522, 41.78593904741349, 49.9786328500317, 44.083714485168464, 65.34918954295497, 77.86238193511963, 74.36647538215884, 71.12258895750969, 1.2042753855066917, 0.0881939570629789, 0.06525774426277607, 0.0970929416437303, 0.03105425692704176, 0.02731748113048173, 0.03712190885937983, 0.08845512409724536, 0.04960952889955333, 0.02893482488880475, 0.030182102214424845, 0.0646162222349836, 0.04520882491863543, 0.028350102534938245, 0.057815184756632776, 0.2013597144715248, 0.20908529750041424, 0.11024318560357056, 0.17100000243273475, 0.17244098317478934, 0.2414767819667055, 0.24106096476316455, 0.11600384503723153, 0.14145274195940266, 0.12168718321669487, 0.11456358441782576, 0.09857379726224369, 0.172059103666294, 0.24115677171897507, 0.48471348240010204, 0.5850037992481263, 37.43479497971074, 109.90664789753576, 95.54276358696723, 93.78600458944999, 61.05923837231052, 77.9837400682511, 120.12648536312966, 60.995021327849365, 107.86394026971634, 121.83920398835214, 118.55498775359123, 63.55400700722972, 1.0304708730789924, 0.15194295244591852, 0.27871672965345845, 0.39338360570611497, 0.40234683442019653, 0.6915098777221096, 2.106176480170219, 0.9357999337296333, 0.8277322616307967, 1.045003499715559, 4.290260057295523, 2.936194625593001, 4.247339521684955, 3.60246705432092, 41.26354602075393, 110.65625990590742, 92.2149698195919, 104.7566072402462, 101.14048004150392, 99.14703738304877, 103.25477876970845, 99.93004445106753, 96.30591561717372, 98.83368707472279, 96.50000233804026, 95.14621196254608, 92.97016728308894, 92.90405181146438, 93.92370331671931, 93.9348820717104, 94.46939129983225, 92.70585444665726, 92.63757382669758, 92.78919696807863, 84.6268544658538, 90.32125734513806, 91.77851200103761, 94.94759882650068, 91.77986914111723, 94.87912208803239, 92.10195064544679, 93.56945837697675, 91.82070101461103, 84.15773114850445, 86.93953883263373, 86.39603168733659, 88.59044874868086, 88.92673707777455, 90.7851246864565, 89.24783798956102, 94.56104924601894, 93.63219276551278, 91.01725839799451, 93.81562632899131, 91.74550917840774, 85.77926251196092, 80.75604777182303, 70.23920843678137, 61.82477520358179, 82.22602659656157, 87.07541758014311, 67.72364339520855, 75.32503989435013, 68.70658936039095, 77.92679509808941, 82.1047547555739, 85.92093852258499, 83.7956650026383, 82.56119312778597, 84.45616076069494, 88.83842099097468, 86.70043114692935, 88.55511603816863, 92.17630309443321, 92.03512130245086, 96.02582700790899, 89.40561140737226, 87.42694823972641, 84.86252615528723, 85.69391173701133, 84.34218452822778, 90.24026824582009, 83.79493544178625, 84.89657232838293, 84.06615164972122, 84.56738348930114, 86.60687477357926, 75.10392019825598, 70.88597589923491, 70.16014129884782, 75.83852521834835, 76.32814684221822, 72.2502076241278, 71.4678281353366, 71.66001642903974, 73.11481568121141, 67.50912897048458, 67.86156961994787, 57.967261422065, 61.80722651943084, 63.26013911154963, 62.29198832665721, 78.43249843966576, 78.96430907710906, 72.67976991591915, 67.07384001824164, 51.8820414235515, 26.337895931736117, 1.1418204658454465, 0.4283144264932602, 1.0883820946178129, 0.4728517140592299, 0.598637712818961, 0.8501673609979692, 0.47567955909236787, 0.12367004093023078, 0.509194465534341, 2.3000293297152368, 2.44214587153927, 32.01009819584508, 98.21391336379513, 90.9289344664543, 98.38321070517264, 80.30570476285874, 112.14312845660795, 61.72544510133805, 41.76594280427502, 47.86837024073447, 41.91203932608328, 68.4354123761577, 90.02727570072298, 82.40356876004128, 88.46248534417923, 1.9078651214799576, 0.3717059221479201, 0.4153802576324632, 0.19839962734089744, 0.1400922923799484, 0.09490479534912495, 0.12143517859400281, 0.11731191718530272, 0.19586994372788938, 0.10452150472349699, 0.16695078342191635, 0.2419231047913913, 0.17880389496924418, 0.14378114363118527, 0.1242322881796187], [0.03472916729327652, 0.06955771917296995, 0.01977264122556775, 0.01931095642278031, 0.06671696555830779, 0.04348747131805267, 0.1138761584016104, 0.030300292344163024, 0.029823306850307894, 0.06316651958191107, 0.0267409693239437, 0.04882822646909664, 0.04447861289184901, 0.07551371570556395, 0.12149683335014891, 0.16724552808990403, 29.609709632012155, 69.43001562549223, 63.176039572685, 54.121455915512584, 45.915998720353656, 40.24363171669745, 18.507901737766883, 66.15071019818707, 89.0890839792067, 97.09184877334103, 65.15453015604328, 1.1006364370546033, 0.6464320998038016, 0.1655849252617167, 0.1745778169002264, 0.1923585950487083, 0.1278792650649144, 0.2690553803357386, 0.7357488200068475, 0.1281308636610066, 0.11793405718861089, 1.403064170191365, 0.6137788584155421, 0.4730092830234959, 1.8684227476196906, 1.6419808854979854, 56.39594424155451, 73.94813891380065, 87.58327822531425, 76.43072466696464, 89.12491090836065, 90.81227533278927, 93.4467823274674, 85.2112562425675, 89.6220713277017, 81.50211395755892, 82.86864419137278, 83.99663940552743, 83.81905017360565, 81.73421629013555, 82.44447908093854, 84.41065342195573, 84.38817039612802, 85.52181382333079, 89.66222070878553, 88.78556313053255, 75.05900905978295, 75.85115525030321, 81.99064516252088, 81.14707669904156, 83.4395294804727, 81.7012526912074, 77.10340330677649, 79.30095041951826, 79.95816707611084, 87.25615255294308, 86.72990383640413, 84.0058961991341, 82.7992182393228, 81.75219643500544, 83.25083994096326, 83.00654688189107, 79.28670437105241, 77.600187178581, 79.79016411689021, 84.29437083582725, 83.95092025879892, 83.19622485868393, 84.43668227041923, 83.9454681642594, 79.4235009531821, 70.1275150237545, 50.864986527350645, 68.2653933186685, 79.49478610869377, 72.17504716688588, 78.11331948926373, 82.55907504789292, 81.34785498342207, 84.4418990227484, 80.35849202063777, 81.09721552941107, 80.51722249677105, 83.64369669268208, 84.71347608873921, 79.53112294597011, 76.86046738778391, 78.09343307249009, 79.3087951598629, 81.09255575364637, 78.3649395358178, 79.97740237943589, 78.07603343840569, 77.5522558150753, 79.97213071392429, 68.86401760962703, 73.0241540170485, 79.25236794256395, 73.15703607374623, 73.56861822066769, 66.02227610926475, 65.6425279186618, 58.74806804041709, 61.58495756887621, 59.61553158298616, 54.797621542407626, 54.32419146260908, 54.28313993638562, 50.277266425471154, 54.16293105771465, 49.25091158959174, 37.6169067044412, 46.56775936003655, 41.51185166451239, 50.18824431204027, 93.52474335701235, 70.45642929692423, 48.3310491038907, 37.36334116228166, 24.63319855351602, 7.824407267955042, 0.0927996929855116, 0.11308081357950166, 0.37819009033903, 0.5258439769667964, 0.09027171774857468, 0.012115065736936466, 0.040973113293969826, 0.2897235745143506, 0.19426382507287687, 0.2966172320227469, 0.337208308760197, 25.272866525957664, 60.21672110403738, 71.67174431585497, 68.46057045844294, 46.975991802830855, 72.9369754175986, 45.080753526379986, 30.957361498186668, 31.34063393838944, 49.72575764502249, 50.84973635212068, 62.36968263503044, 68.61296238437777, 34.66351493712395, 0.4317698813974858, 0.08534082346746037, 0.04738536498118793, 0.04154802397674611, 0.057476420676515955, 0.048875187658855034, 0.049889384648732604, 0.04464546301131768, 0.0892482855687699, 0.035655980464071035, 0.07799191054918113, 0.04403795911780289, 0.10548901248482928, 0.031040702916441426, 0.004545444324086871, 0.04168382838308331, 0.03667619890503345, 0.03789809765294194, 0.0214960670939857, 0.02546545016699501, 0.05892119355379574, 0.023155195202918786, 0.018823820263928464, 0.06335492741556899, 0.051673323802289464, 0.042504967385602575, 0.0445571254127689, 0.026052336719247605, 0.06783471848334997, 0.09338057915409727, 38.83936435945573, 81.13339547188052, 77.66590256844798, 69.1981251009049, 55.55231694252261, 52.30953662626205, 26.88500185166636, 72.93001713291292, 102.07900908685501, 108.5187642805038, 77.29340291792347, 1.1345839380256593, 0.42527697980403906, 0.0493766803054079, 0.02274522133502028, 0.1415730177635147, 0.09124723878959495, 0.22978939055915804, 0.18342106092360713, 0.16786877125982316, 0.2045423348223971, 3.1435776910474225, 1.177758324530817, 0.612004108486637, 1.929661242231246, 2.1549347283378726, 66.34903307883971, 79.38611292069959, 92.36532995777746, 83.32176423841908, 96.65878772735597, 91.81171094217609, 99.47894050228982, 91.307584393409, 92.67085905997985, 84.0527214542512, 86.47552244124874, 87.31063427463656, 88.44156342168009, 84.99955807962726, 89.61928644487935, 92.1096149567635, 88.25041847844278, 89.22835165454497, 89.5098287828507, 91.05900810610865, 82.73510317648612, 81.88301532499253, 86.09587623227029, 87.73865115258002, 85.65780239720499, 86.02616002482753, 82.02045517583048, 83.09390591036889, 85.77428110184209, 89.63728227922994, 90.53989025854295, 87.76189511822116, 86.770076751709, 84.01059519860053, 85.11185553766067, 84.13829188193046, 82.30141455127348, 78.74760596982895, 81.56038468883884, 87.53041252013176, 85.8381372882474, 86.90951701133483, 88.15559125715687, 87.98921215918757, 80.00942460952267, 79.1152105023784, 65.68351276459234, 76.42346828214585, 84.297893124242, 74.73966536983367, 79.31838143256404, 82.70653263215097, 80.37317737456291, 86.30267143249513, 82.86363140229257, 85.3409533346853, 82.98032975965931, 86.20159979789489, 85.44943040417087, 82.45506948040378, 79.82731680716239, 79.05270361131238, 82.84674952107092, 84.17440122173679, 79.65100626791678, 80.24755954742432, 81.47408470030754, 80.51417089277699, 82.9579173364947, 75.29050734735306, 74.03265030153337, 78.98643908962127, 77.26951568357407, 79.49529601681617, 69.86644206508514, 71.49667324558382, 64.11290161071285, 67.34573871858659, 64.6096815601472, 62.93405286727413, 61.77838140918363, 59.36580604122531, 56.73295036438973, 60.08062662616853, 63.84622750743743, 60.97952404329854, 55.006017069662775, 55.290714463879986, 52.204091548919685, 82.29021226206135, 97.4575391892464, 74.86146280842443, 59.76126332436839, 40.47561637816891, 13.76044629081603, 0.3416145094219716, 0.33899310976266867, 0.21060186047707835, 0.19891912688411054, 0.38304911025108834, 0.05548764110332536, 0.002280657157121647, 0.3006945971039034, 0.5576751753687859, 0.24223032137078626, 0.28182272589014423, 30.707018183123683, 76.6413402557373, 81.48294141215663, 80.62224003576463, 52.76629271045808, 26.228087217577045, 28.70092195849265, 38.85046858941355, 49.59713135996173, 62.41732374314339, 70.32637919149091, 72.19221930350028, 80.80986269058721, 42.11810496545608, 0.4948951279924762, 0.13079348651151504, 0.13753222571986337, 0.10339157866133798, 0.07369774258545331, 0.015291063257703378, 0.08115849667979826, 0.04978825721228796, 0.08772918684107643, 0.028059094460801254, 0.05967170691057559, 0.027930384028642893, 0.11865961140081768, 0.0246399195654498, 0.17787720437251753, 0.172587750299323, 0.14699986204504967, 0.12864805727956757, 0.1436332273747652, 0.12266384572872233, 0.19695288561765226, 0.09889410628426461, 0.15520978118142775, 0.16547594159360857, 0.0985578702942979, 0.13727265980935868, 0.1549948628751501, 0.21132883195194507, 0.23685138822803575, 0.31797248449537063, 52.71956159222511, 97.5576380760439, 84.08592824013003, 74.0066606767716, 63.017105133302756, 56.74353684148481, 30.758440456082745, 93.29558280206497, 118.26768982794978, 118.06494251374276, 94.81324980335852, 6.371445155912831, 1.771045863147705, 0.3244801256204805, 0.32449207659209933, 0.5282363163367395, 0.31487356691110524, 0.4767549320334389, 1.4421318351261079, 0.8055063349104697, 0.6310084822677797, 4.876641160057438, 1.5851399807199356, 2.1198373600359885, 6.3357084412728595, 2.512475684765847, 79.3367067460091, 90.88112077405377, 101.1101758095526, 91.58231504501836, 101.39406911788448, 95.45010935875678, 105.77927112579347, 96.98245386923514, 97.71516830690446, 88.394055674153, 88.22023191759664, 90.20346072412308, 97.07357052833804, 88.81171749484155, 93.89887471352854, 95.3604361318773, 92.67346351377427, 90.40760440211143, 95.47876619523572, 92.7965239555605, 88.16185920469223, 86.02548537715789, 90.25256879868047, 92.91540315074306, 91.6862343203637, 90.61456434188351, 84.63867648955315, 82.90756979296285, 84.89637620987432, 93.99902851350846, 96.47829594150667, 90.10930815050679, 90.97119408269083, 87.41693835104667, 88.02667863907354, 87.02717242702361, 87.15889346215033, 83.588085328379, 84.07183124173073, 89.7777109761392, 89.02144662795529, 90.83675092266452, 91.15817346880513, 88.59754039395241, 80.43405255963727, 77.64636916498985, 66.44517821650352, 71.47642597075432, 86.12208550976169, 76.09194171044135, 80.10855074851744, 86.64895396078788, 83.85075861407866, 92.47804318704914, 89.66799443767917, 87.83120339916599, 85.47811077487084, 88.53675150102185, 88.58308253749725, 85.47257238818754, 82.81256998738935, 81.41801049632411, 85.75358667681294, 85.99629509833552, 82.27739395633822, 87.02860801450669, 85.66057943528699, 81.8231991798647, 84.63709969674387, 82.36760062556114, 82.54744129796183, 89.00010108947755, 83.41698369672223, 85.08914501436296, 75.44498597421955, 74.82158014851233, 74.1791743616904, 78.62937004335465, 73.37289979380947, 69.77839269945699, 69.67861544701361, 70.63887442311933, 65.85050767467868, 67.1789046256773, 63.04967649521367, 59.199925084267896, 61.00343088949881, 64.02510327677574, 59.53427968486663, 79.85200420502694, 87.82164066068589, 76.97174502957252, 66.72088161591562, 52.10749533868606, 16.365569829940796, 0.4918467722112133, 0.7613231638266195, 0.7437225082708944, 0.7344781559321188, 0.7218850800587285, 0.1411862965793379, 0.19085143963175435, 0.3795353100905496, 1.6374409871716655, 0.5643256152829816, 0.5199599314120509, 41.722577079649895, 88.70193035371842, 94.93431768109723, 87.58167789828393, 73.65164695247528, 103.60150844820085, 60.885112593250895, 46.3593206867095, 47.63002741721369, 65.91041795669064, 72.84612547966742, 85.40007914266279, 91.68373184819376, 54.835452802719615, 0.6009699908956405, 0.16683110516638527, 0.3078876417731085, 0.1967061593407585, 0.18091399222612384, 0.12178959385041269, 0.15847354556523985, 0.14923421876324763, 0.239433043245827, 0.10663351720018734, 0.13164537628331494, 0.20923074695371816, 0.2269138335700958, 0.12565908097331563], [0.028968166950489246, 0.06834450403168317, 0.05211544463471059, 0.0204768541434239, 0.08340676555470114, 0.013268506867931256, 0.03127044119361428, 0.07996786581051928, 0.04375343023228549, 0.09087845172372558, 0.03892140725867883, 0.07328934111301938, 0.002227621847733615, 0.06542108186911191, 0.10484326931257403, 1.779884188886612, 50.24873510483773, 74.19084733532321, 64.38463164914039, 69.19947439624418, 59.03045515860281, 55.153082416903594, 40.75741121845861, 55.64052712532782, 86.72533035278322, 62.34616802584741, 7.12885287500197, 1.6361806806056731, 0.6505970440564618, 0.11405861756253628, 0.28944946825504303, 0.047644394630145644, 0.36162674847629767, 0.2154148385048874, 0.21056233034018548, 0.08864316803913924, 0.3050052819232787, 3.52970929395768, 0.19430799770259088, 0.8363864198327066, 0.6546196798163076, 25.33469092461371, 67.69040523036834, 73.69702877536898, 69.45099246117377, 68.31646257831206, 85.40025172695037, 90.49675987612818, 86.41612991209954, 85.69639067496024, 84.22175207445699, 82.26998067671254, 84.50075026481383, 83.8441925664102, 84.7684363395937, 86.3600557081161, 85.14638808465774, 87.02686648215018, 85.40646476130333, 85.80671910316714, 82.92757388084166, 86.45682058026715, 75.36310257450228, 78.23948644822644, 83.414747945724, 75.95906749848398, 81.64586097963395, 81.89897937159385, 79.2762787111344, 80.95088758776265, 83.74061061489968, 83.45213597820651, 80.21965580601847, 76.5534399401757, 77.44226471070321, 78.53960267959103, 83.7310557211599, 81.9211878315095, 83.46785683785716, 80.54474969064036, 83.18114726774155, 81.52300450109666, 81.65219168509208, 85.30815447530439, 79.0099968448762, 81.07857642635223, 79.54296065915017, 84.57630295907298, 82.58337805348059, 80.97049943862423, 75.70618444873442, 71.44339961390342, 72.2500507293209, 71.57339480615431, 80.21101874689903, 81.12171465350737, 79.84179819783857, 81.64899887577181, 82.00980986318281, 82.52463663777998, 81.1366275049025, 82.33148344101446, 81.76627774392405, 80.95257420693675, 78.26897482718192, 77.99151420593262, 77.46152354824927, 74.15173345996489, 71.9106480383104, 76.76244735717773, 79.60999396539505, 77.25102563058176, 67.72449847190612, 71.99846990646856, 75.50675545969318, 71.22449213458647, 65.40989214374174, 64.56040482367239, 66.69511948862385, 57.87018668267035, 53.89865352261452, 56.456478180423865, 56.86602069485573, 51.702749882974935, 51.76130302490727, 46.855578960910925, 44.18892814267067, 47.166093395602324, 41.50787438115766, 45.933457189990634, 41.60454119405439, 57.10617957576629, 98.13549733931019, 71.82894506762105, 49.979566374132716, 37.42962529582363, 19.24945131424935, 2.7050152757475456, 0.3268842014574236, 0.26641838312629734, 0.24275392714527347, 0.18525694466886983, 0.0837141430125602, 0.062136476063319755, 0.36266197841013637, 0.11135197529989867, 0.4585807524140804, 0.11895447098199399, 1.5300435500760234, 24.500828366125784, 46.26816872627505, 76.80669953746181, 62.996320493759654, 62.04740893456244, 75.24744756760137, 45.52085522682437, 38.00324447693364, 58.378651372848026, 45.28105720396965, 58.26945258725075, 62.59537581474551, 70.61972541193809, 11.153444916971269, 0.6077646392007029, 0.1871221389381155, 0.18511108152808683, 0.06331017255903253, 0.048227280288213686, 0.01659270984330966, 0.05509937625198115, 0.07906842496125929, 0.06023669675473244, 0.09229435840801847, 0.054944886961170745, 0.04777884689129649, 0.030416902417557377, 0.048689212154356704, 0.06533774682470868, 0.05622786589928212, 0.02613696645224287, 0.051313067125456954, 0.026772357861421285, 0.040340083350818005, 0.020470032130458185, 0.029110504171600746, 0.029614833258693258, 0.04611927828180694, 0.0536248293675242, 0.04979140966409638, 0.027756516543787815, 0.021979118088981318, 1.850900294319276, 60.70491498516452, 82.22314757685508, 80.03572802389823, 76.73821495425317, 62.64010260182043, 45.46980557903167, 25.18479362610848, 65.30705544256395, 97.63466558148785, 78.96868644222137, 6.038016724971033, 1.845985687067432, 1.4223111180528518, 0.04650359394990149, 0.36765095747766957, 0.040871675591915846, 0.362018158118571, 0.13726317564085608, 0.14801901945423696, 0.12686063625639485, 0.459747105957039, 7.463682572687826, 0.8294486663033886, 0.43122317041120223, 0.39162203248950744, 29.617666159906697, 80.380645567371, 79.40789776463663, 80.53727365309193, 77.44273539512389, 92.00305984866236, 94.83367750721594, 93.77612806135609, 88.6303706322947, 90.1209811241396, 85.53136087233021, 86.97529515912457, 85.77189630077731, 89.27970332484092, 89.33881344333773, 92.64440659553775, 89.9527898911507, 91.29908853961577, 87.34748886477563, 86.82619802413448, 89.49926976234683, 79.27445873137444, 83.51571759869977, 88.63872528076173, 80.08529893813595, 83.52520973451676, 84.49305457453575, 87.03123600252214, 88.65785075772195, 88.62304364481281, 83.2074506821171, 81.89451571433776, 81.26272386120212, 82.01465791271579, 81.72545371517059, 88.54271350368377, 85.15273447959655, 87.76496241169592, 86.901076070724, 85.19839871314265, 81.53616797539496, 82.73598178740471, 84.23667277059248, 84.4761570038334, 86.23928593051049, 83.14361018519249, 84.80247466794907, 84.46278956628616, 80.37484045951598, 75.57736596753521, 70.3391347392913, 75.56692461813651, 71.79167470624371, 79.7821311027773, 81.19805966654133, 85.4397343051049, 83.82840110409646, 85.88049104136806, 83.92572295281195, 85.30176885666387, 81.85535477053735, 86.35059495126048, 83.50105577899565, 78.79553733333465, 77.3626249067245, 77.18407861648068, 74.98395842890586, 72.09597218421199, 75.53861295023273, 79.44512890231225, 80.46129734285417, 74.69618981884372, 73.9560934805101, 76.69356269221153, 74.23861395928168, 75.67779433342719, 71.02340006059217, 71.13366573087632, 66.00689257344892, 63.41609254960091, 64.69824083389776, 68.37604338122954, 61.267045544039824, 59.65265681666713, 56.58295892900037, 51.262518744314875, 55.42410250632994, 63.33453470660795, 57.86877462940832, 57.79184910558886, 55.26936500303207, 85.25628505214569, 95.20704792391871, 79.47410737314533, 55.773660213716575, 33.8762560198384, 5.484118240494882, 0.21703914408722233, 0.08907073703143867, 0.1424153007927441, 0.06324510488118376, 0.2827538597968317, 0.05705137594392704, 0.30385703869885017, 0.4393207810578808, 0.4013959967320965, 0.08993250167658252, 1.2343915888378698, 31.715863558553885, 61.690139847417036, 89.03291563833915, 74.06696319580078, 62.44374482862411, 29.71433493398851, 30.56868403188644, 52.49366444926108, 87.02055146617275, 61.16456185617755, 76.06874481324228, 71.0196267404864, 83.98570383748701, 14.058598395316833, 0.8853587436099207, 0.23959945286473922, 0.1269926178839899, 0.07657493900267348, 0.06115330946481517, 0.03422066494221649, 0.031607920161238125, 0.0393340222146963, 0.059393708924612695, 0.07950341734554499, 0.034001858739723126, 0.028113660988427942, 0.10870752405495414, 0.1503669870116057, 0.22228520694038562, 0.17839851188323191, 0.12992072850465775, 0.21115679924766864, 0.10088626430520128, 0.129961438416954, 0.20847181429065045, 0.15080210963083854, 0.09125394971981164, 0.18552884459495547, 0.14496436643023647, 0.13712725632133024, 0.13747666902359457, 0.15278993925500303, 3.2382264444904947, 75.36491470952188, 98.02892654172837, 89.13495217600178, 90.47762655442762, 79.29050907011955, 77.45072918553507, 57.01192109815536, 85.0377227414039, 112.11716236606722, 95.12875741527927, 13.370299896886273, 3.4852046110937676, 2.086815906147803, 0.15856458745416135, 0.6092754258744179, 0.23097770018202646, 0.7398081054129909, 0.7613440627051938, 0.3173775712568914, 0.41579333224123527, 0.8074433729052545, 15.893470414223211, 1.6292689740657809, 1.2835837492058355, 2.0577543300967065, 35.60541722082323, 88.52580024350075, 80.10213375091553, 91.61586699947235, 86.18442766128048, 98.39601332141508, 100.52931985547467, 97.94324628768429, 94.34433829399848, 96.15965043344806, 88.8938440815095, 91.36042656437044, 89.15354421061855, 95.1375670586863, 96.38382173353627, 97.18289482978084, 93.85303005095452, 94.96113100359517, 90.42944415923088, 90.25829545913204, 94.96450424194337, 84.03874212695708, 90.97704625898793, 92.56527669968145, 83.77080502048616, 86.57944956133443, 87.22085122139224, 90.89908522944297, 91.4892372008293, 92.72330899392405, 87.24345191832512, 85.96475139740976, 82.76482689765193, 82.31646076325448, 84.92738646845665, 89.73053270770659, 86.10000256569155, 90.53200629449661, 89.06851507002308, 86.83160305023195, 85.30146291179042, 89.27852661378923, 91.39997190044772, 86.19152715129238, 88.02463116184359, 85.45145434717979, 90.22950526206725, 85.10508552674325, 85.94439429621544, 77.79197539052656, 73.09652174672773, 78.6178461197884, 74.7838391027143, 83.44616613080426, 84.09676967128631, 88.14727583239156, 85.63348370213663, 90.49749728172057, 90.57284601273076, 88.66883339420443, 85.69226434153896, 88.1790784097487, 86.33812965885286, 80.61655259901478, 81.3050776143228, 78.9899221543343, 77.25043727505592, 76.0518393977996, 80.25130148856871, 84.11128244092389, 84.61173765120968, 81.15607461621686, 79.00680403555594, 82.11406646236297, 80.55246891513949, 80.52965641021729, 79.11969769385554, 77.07660567375922, 73.69235331012358, 71.05217456817627, 68.93215702426049, 74.46866881462836, 64.59330566467779, 67.2649771167386, 63.612171834514996, 59.03323611905498, 59.65885416153939, 61.169684471622595, 59.5069682213568, 65.05783588655534, 62.73559270366546, 86.31316769507625, 89.30656371578094, 83.63269836671891, 64.34242694608628, 44.080741328577844, 5.267452886027675, 0.5859114602208138, 0.6298652952236514, 0.6181738741936222, 0.18477591806121413, 0.35535083362652414, 0.2268596711538492, 0.8714557799600786, 1.1550914376012742, 1.2960323715402235, 0.30518197244213474, 2.0402332251110384, 45.8687969177, 75.84298103086411, 105.72404415376725, 83.4384939747472, 100.40532588958742, 112.46841845973846, 64.28930236447242, 53.61936507686492, 76.76738954359486, 63.84256401369649, 80.37982186963482, 83.04291509812879, 95.77468549051594, 16.20753949688327, 1.4977114527456223, 0.28236474841833115, 0.29514983656906313, 0.33022422223321857, 0.10961092557878264, 0.14019461108311532, 0.13828225644125094, 0.11888935350843015, 0.2522697350791385, 0.2031440558212419, 0.16225697803160838, 0.1530714612454176, 0.22505853715683186], [0.08488662525891297, 0.02047709737633986, 0.06408438867618961, 0.030760651814841458, 0.06930527788016104, 0.07903605008557921, 0.05019135352584624, 0.009486038714737422, 0.037426677787856716, 0.04666623441622623, 0.09729109028534544, 0.1483342493133199, 0.1240073724259292, 0.05432492264756753, 0.1977652146090423, 6.9850769254469105, 70.40612882183444, 70.23177162293466, 65.77479416324248, 60.14533004453106, 52.595630384260616, 52.397778188028646, 50.9893491960341, 87.26222438196983, 71.92011663990637, 13.34822871992665, 1.0564135519727584, 0.20011446919412385, 0.7008566406946029, 0.0816571586314709, 0.03220360140286146, 0.21424938894567952, 0.07838711232667969, 0.07128306409163822, 0.25599132892825915, 0.8198383077979089, 0.12409720389593033, 2.9445083343213607, 0.016491231921639656, 0.34701846299632905, 2.3503604483219886, 60.19614827248358, 90.18541782133042, 73.29155768117597, 54.21273339179255, 71.8771666865195, 81.94533394229028, 85.20781240155621, 80.0155278175108, 84.11975476049608, 82.39429627695392, 83.09166231463033, 80.73565929166733, 86.59826909342121, 84.56272371353643, 86.05849604452811, 82.95008044089042, 85.39257172615298, 84.69086754706599, 85.1879495190036, 82.39383343727359, 82.88458470375308, 72.5078602760069, 74.09352548660772, 79.20233418864589, 74.87898795835434, 84.71277790684854, 78.89498510668355, 83.00859435912102, 80.45305252075195, 81.32791365346601, 81.03019006790655, 81.64423711838262, 81.49772874770626, 85.31566973655455, 84.05052492695471, 81.55317537246212, 81.57153206486856, 84.24762402811359, 80.4305067370015, 79.85384771900793, 76.02865034534086, 80.80977639844342, 80.35013737217074, 77.656661464322, 79.39642875425278, 78.3691050929408, 76.03314538155833, 77.07717049506404, 74.38474578242149, 68.93057238671088, 70.25471748844271, 69.2435775264617, 65.92736259583505, 69.94146131700086, 76.08634841057562, 79.1074049857355, 77.2913162169918, 78.83718505982431, 77.33461133895382, 76.55892341367661, 78.42863098267587, 78.0708323755572, 79.19654477027156, 78.31175219628119, 77.97500887224751, 78.14545939045568, 80.82850179364605, 75.34791515719506, 70.6091820809149, 72.6541333044729, 74.3330018751083, 66.71741424068328, 72.97335932331701, 72.28645816926034, 73.20038610889067, 72.16422926995062, 64.17116449725243, 65.15553036043721, 69.2253149709394, 65.31537478969943, 69.0500242479386, 71.1729992589643, 66.78245498288062, 64.97409328337639, 60.3135173551498, 48.40914741639168, 40.78287916798746, 42.81931884827153, 44.74891316506171, 55.54817884199081, 54.947134448635964, 58.93996607872748, 87.19728562139696, 71.38974158994614, 47.92640562980406, 30.851267268580777, 11.519514822190809, 0.724386755497225, 2.3805519121308483, 0.32005802097339786, 0.10992680661260121, 0.28939645497068284, 0.09648675159100564, 0.0815885937622478, 0.40855033863936707, 0.43340550975934156, 0.18015395639644516, 0.062185475046956734, 3.6040570851295226, 13.641248403056977, 46.017694011811294, 66.98925018310547, 50.36133850774458, 50.721576829110425, 59.31107328784082, 36.14956371245846, 20.506667052545858, 28.42472630162393, 42.683455790242846, 49.38287188929897, 65.96828076147264, 39.56534016516901, 0.2247364278281889, 0.0849964133193416, 0.04820173891681818, 0.01850636108898588, 0.05542053563159801, 0.06607651605360931, 0.04907992465661899, 0.030959106891626315, 0.07200702484096251, 0.09011603336060241, 0.08390085396146582, 0.023019254815975027, 0.041656115152422464, 0.024421902433518442, 0.034925190040901784, 0.03946588509866307, 0.024753884720285575, 0.012321557076047025, 0.0653154306834744, 0.04999690508890537, 0.08996439391687032, 0.030041055851465756, 0.04683471630297361, 0.04478085756061539, 0.08630082356713473, 0.04412363456081479, 0.11895880703964543, 0.12814807765666517, 9.573839768286675, 84.75648095530849, 79.37072154014342, 82.42944071369787, 71.41260900805074, 66.52764212700629, 38.20316768461658, 48.54291985111852, 106.08742037127095, 88.40197101716073, 16.9902249305479, 1.5938698284087645, 0.7858750560591299, 1.375985352262374, 0.16475715193777316, 0.17201336821721447, 0.19579888141203314, 0.04285963162058785, 0.09755505354053552, 0.4143740471091963, 1.518627981985769, 0.7561160335617682, 3.8636993592785256, 0.13437997309430955, 0.6195405750505386, 3.3677926275037953, 72.04362423189225, 95.14241510821928, 80.45025194844892, 65.83560266802388, 85.289593819649, 87.85577312592538, 87.40856801309894, 84.90520938750237, 88.33766768055578, 86.2226237020185, 90.89490398283928, 85.63786106724893, 91.54261281413417, 88.20718611440351, 88.57146447704685, 88.19671338604343, 89.44415261668544, 87.35844796703708, 89.71753397295552, 85.93324692018571, 87.01218112822502, 78.98469755726477, 79.59402991879372, 80.5843734741211, 83.14204123712356, 87.40994084265925, 84.33239429227768, 86.973506558326, 86.94569695380427, 86.16340375715687, 87.31054013775241, 82.80073227420931, 84.97076788256246, 89.392698964765, 87.65204521917528, 84.81675994011664, 85.54561476553641, 83.93189676346319, 84.27342537910708, 83.87717185481903, 80.05758347049837, 82.99452873968309, 83.05658848054948, 82.87968174103769, 80.48168582300987, 83.69478948654668, 78.62465535440754, 78.52418776481383, 79.14685618492865, 69.43461264333418, 70.11754435877647, 71.0685073175738, 69.70960217137491, 69.34293900766681, 73.24872539889428, 78.76655886250158, 77.68829145739156, 80.80528136222594, 78.61560252404983, 79.08170561636649, 83.17791523471956, 79.85977834270847, 82.86767144357005, 80.78463400563886, 82.51659577892673, 80.80819176089379, 80.0955520137664, 77.30634673949211, 71.51502993799025, 70.88724674717074, 72.95536348896643, 70.15144932654597, 76.49371008719169, 76.86697852226996, 74.441345584008, 74.7404969123102, 73.1326703102358, 66.63137312858336, 71.04542809147989, 73.49583471975019, 74.00328743842341, 75.56730116567304, 73.31584499728295, 70.47791604072818, 64.28484655195668, 59.259325458157456, 50.5627247595018, 49.91074446708926, 60.507882564298576, 64.39091528615644, 74.60838364016625, 62.410757695474935, 78.32472739681121, 91.3815289158975, 74.40423211743756, 46.227905596456225, 20.368909489723947, 1.443569016072058, 2.9329125823513156, 0.35799864799745623, 0.1234315271158853, 0.10155868265897998, 0.10874975848221972, 0.5962177942837439, 0.19429407022412748, 0.6074207576532519, 0.22111695349937488, 0.22285810281192103, 3.139250091006679, 24.02025172787328, 63.02089022051904, 79.78056999944872, 61.620349114941014, 51.864771227682795, 33.36207643631966, 26.275263524824574, 29.884795258122107, 34.08740112858434, 55.35296247851465, 73.8458199654856, 77.41571026463663, 51.24034950810095, 0.1469172164797783, 0.017779897147369002, 0.17692822061719435, 0.028579766118538477, 0.013399787525075578, 0.03188752310140239, 0.0366315359790479, 0.02365491818636656, 0.11495304053589223, 0.06505401850107216, 0.07012445569759415, 0.0645927569618629, 0.03720659604896942, 0.21214923551005704, 0.14649802848937052, 0.14853235965053882, 0.10747200043331231, 0.17575009996371885, 0.23654165888024917, 0.2023548780069236, 0.22873658656833634, 0.12796535036496579, 0.11501291796805398, 0.1568659100561373, 0.2550559968597466, 0.3699369944872395, 0.2562775240550118, 0.339993559304745, 13.833213121660295, 99.62456241730722, 89.89505260221421, 85.81326161661457, 79.88276343191825, 71.15232836815619, 73.42873081084221, 76.69310769727154, 122.2579562279486, 104.54310478702669, 24.387179651568015, 2.2914648344439845, 1.640809077409006, 2.0215732844606524, 0.5008490407659162, 0.545585266044063, 0.5346498818647477, 0.3043537088219197, 0.20586942893362817, 0.7992162014688216, 3.3295257389545445, 3.645301788083969, 9.584625305668, 0.5718117039049826, 1.2524321627232338, 4.560704538899084, 83.79444906788488, 97.351501834008, 90.92818921612155, 78.88407307286417, 93.55487500467609, 93.87406179981848, 97.3820649423907, 91.34752981124386, 91.73447162874284, 89.46452540736045, 95.42575928472704, 87.35150537183209, 95.85336823617259, 91.21409862272202, 96.30047136737456, 92.62842685945573, 94.66350155491983, 92.83104081307688, 92.56599841579315, 89.20008705508324, 92.10224090083953, 84.28373336791992, 85.46580237727012, 83.95526624494984, 84.90710781466576, 90.50079207266532, 92.3426272792201, 91.54129489775627, 88.4445365782707, 88.7588753238801, 90.0253458945982, 84.869076513475, 88.75547070657053, 91.80231294324322, 92.44647595190233, 87.7310888228878, 92.14617144676947, 89.19515271340647, 90.18917545195549, 89.20516260208623, 83.54340953211631, 86.68649104333694, 87.92803102923979, 85.49758926514657, 84.86143573637932, 85.06375943460773, 81.25227466706308, 81.85992040941792, 80.17185780309862, 70.6355639426939, 71.60716641333796, 71.92526278957244, 70.92117524916127, 72.53615625442998, 79.12243550823581, 84.78364729112195, 83.04658643661007, 84.23977928776895, 82.99810594128024, 83.30589432870188, 83.81845397333946, 82.52495042739376, 87.70870777868456, 84.68381512549617, 84.7132799702306, 85.05579702315792, 83.75864567295199, 79.234340729252, 73.38114461591168, 74.88327903132286, 78.12974637554538, 77.80218924245527, 82.14559447380805, 79.87278492219987, 78.8763616931054, 79.53488842133554, 78.2637502301124, 72.19597693412535, 78.57408031340569, 80.81555012733706, 82.86723213811075, 79.92081042258971, 77.69717954820203, 76.90109529802876, 71.1460368863998, 63.8478905923905, 59.34886140208091, 55.87744220610588, 63.14590400265109, 65.35767362963769, 74.18664255449849, 69.48300684652021, 80.7259004346786, 90.30982755845594, 80.8558407137471, 57.04262541186426, 26.441515145763276, 1.5971647419275778, 4.273632149542532, 0.6501608642358935, 0.6334896265499054, 0.3065426365262078, 0.23191398219956508, 0.8779453414101756, 1.3653682316503217, 1.4218888503889886, 0.365327320872776, 0.24382327863525963, 4.382124418212522, 40.07904121952672, 75.61343608363983, 95.11207949730658, 69.22179268252465, 80.94167001785772, 89.10303977227981, 56.77491972523352, 33.17611686645016, 46.39544179362636, 62.61509356960174, 71.61061025434925, 90.17756523624544, 58.50435941450058, 0.27146454299649886, 0.20209299851088755, 0.21738017578759503, 0.1222068896036475, 0.16637229510853369, 0.12877850673131405, 0.0751654444743068, 0.07387542901861091, 0.18017706160824146, 0.22374868002389708, 0.26734997668573934, 0.21960069695788048, 0.18504550440176842], [0.16082485326595847, 0.0688013529044486, 0.07784632320005087, 0.08147166576236486, 0.02959765756743089, 0.09051521879530723, 0.08616946247075835, 0.03917340422049165, 0.02542680677687449, 0.0479927922659103, 0.040549075967001344, 0.013202519884573357, 0.1526804040035894, 0.07805026346637357, 0.14445490263883146, 14.768166926599319, 70.45344045085292, 67.84716667667513, 66.47293290784283, 67.95094474669426, 49.89474119678621, 54.078258852804865, 61.244605664284, 74.93734498177805, 18.80387398504442, 0.9441351542069066, 0.19548936656886534, 0.36407409295920407, 0.43707632730084084, 0.23360087716531372, 0.09254851573777777, 0.0691476476288611, 0.05531790666282178, 0.09927610836682782, 0.3237990428122782, 0.8522345726528476, 0.3276421382061897, 0.573784165805386, 0.05728341631531235, 0.04031651848626714, 28.530155689485614, 60.87138822001796, 58.194939321087254, 55.242147676406375, 66.59765643458213, 76.1724522805983, 86.64865586065477, 81.87783779636507, 78.16431030150383, 75.39465412016838, 77.30477779142319, 81.04330647376277, 79.5475027638097, 85.55521672771823, 84.28706738256639, 86.42519843193793, 85.93513750260877, 79.9541348795737, 87.04434456363802, 81.6791069892145, 79.30634760087537, 79.6977295414094, 67.87129709797522, 77.09657053793632, 79.73638842182775, 86.2634006623299, 79.17798411461615, 78.20888411614203, 80.00380777543592, 85.49938571068549, 82.65605172803326, 83.23171446400305, 79.88364988757719, 82.25576600720807, 76.46546902195101, 80.51335503978115, 77.13298582261609, 75.7652396540488, 75.35758772204, 79.8324708015688, 79.06516105897965, 80.10813497727918, 80.8470702940418, 84.10200211309618, 78.7841546150946, 75.584394854884, 74.19738984877064, 76.1060308641003, 78.57389203963741, 71.24169565016224, 69.30424874828708, 67.36372670819684, 65.65359684728807, 68.40930508029076, 68.22509488751813, 71.43345248314643, 71.47368815637404, 77.42805788593908, 73.71634252609746, 73.64303342757687, 73.38373338022541, 78.10808704745385, 80.15601142760246, 78.81961284145233, 75.68009284234817, 78.30489589321998, 76.52618731221845, 75.4481787835398, 80.7039979196364, 78.6594153988746, 71.28112331513437, 68.87042676248859, 63.89346461142264, 65.1392250676309, 71.78170404126568, 68.27472071493825, 72.19537288911881, 68.87251346342026, 64.83704566955566, 65.06456275140086, 67.84860226415819, 64.74696059380808, 71.8650544074274, 70.70444076291977, 73.55890643212103, 70.50747502234675, 64.94583652865502, 48.315438070604884, 38.2213008019232, 31.737762151225922, 42.23996908433976, 93.44427985529747, 60.903775230530776, 64.93404980628722, 78.74561340578141, 68.69364553882231, 38.187791993541104, 21.169174986500895, 3.09464612314778, 0.9053563963501685, 1.8588624606209418, 0.3658079337929526, 0.25056312101021894, 0.14520082712894486, 0.1981290450860416, 0.29535288051251446, 0.22801939037538346, 0.10063180054027228, 0.27756661717449466, 0.030342794902202104, 4.376766950853409, 8.403514335232398, 56.90005117847074, 69.33304679009223, 49.94515934298116, 42.38072726034349, 82.95629347524336, 60.078441865982555, 122.06601112119614, 60.886199089788626, 36.038305682520715, 55.96496205176077, 57.976039686510646, 2.8698739649788028, 0.3229859170894469, 0.12252285490713774, 0.0595747048576032, 0.12393588876171459, 0.0008626643795005588, 0.0583685185730217, 0.10764636204487855, 0.04946174670852, 0.05785077720159485, 0.06814907500219923, 0.015032769053152975, 0.1707641086390903, 0.057420312396941654, 0.04794895671488297, 0.05426948469492698, 0.0817774114529452, 0.035499131622453856, 0.09897041630240218, 0.04133938759144756, 0.0595429007174267, 0.01880309758557668, 0.11444037449696373, 0.0117835249083357, 0.04065109206543815, 0.06602532605850889, 0.09043710847054759, 0.24254602620438223, 22.82796690540929, 82.05316774306759, 81.14132650436895, 79.60895845966955, 75.72460389906361, 51.223240129409305, 30.077491498762566, 69.3854731898154, 93.70384662382065, 25.995055283269576, 0.8466282186488953, 0.22845621370980818, 0.5975447811426655, 1.0223186556850712, 0.33470105620161184, 0.17343064619889184, 0.098580400940151, 0.10743114496431044, 0.1518948574460322, 1.5118754991600591, 2.308000566497926, 1.2711019092990508, 2.640786219027735, 0.05135285390180446, 0.5250527613585996, 38.70246187333138, 74.08015020432012, 69.96829817371984, 68.56106942699802, 79.59934080800703, 86.021162925228, 92.88873887831166, 89.48172892293623, 82.64288825373497, 81.44918549445369, 81.24453975308327, 84.49440386987503, 81.7427670571112, 86.45874254165157, 85.73404542861446, 88.30971687070786, 89.8292116965017, 83.89188074296521, 91.26698786212553, 87.37780878620764, 86.13488028126379, 84.39947466696464, 72.11894158394107, 81.71095663501372, 82.47948231235628, 89.97000909620716, 85.21581403670773, 83.84193328119095, 86.25350060001497, 89.35136502788913, 88.11521437860306, 86.51178083112164, 83.76537646016767, 84.87457567645659, 79.4604104565036, 84.75105239499001, 81.78836853273454, 82.58387227212229, 78.2437853659353, 78.98736476898193, 80.00183090086907, 82.24732506659724, 83.9122143099385, 84.77237439924671, 80.43667270291238, 79.46160285703598, 78.6822828169792, 77.33986731498473, 79.419719788336, 71.31677766000071, 69.6849932209138, 70.74728873468214, 67.52195512094806, 69.21835668625371, 73.30992221832275, 74.53971078318935, 72.97550878217145, 75.76931107428767, 77.6798975852228, 75.50581409085181, 75.80327879997992, 79.32942682696928, 80.80859968739172, 80.28361397404825, 76.56995311860116, 80.23145429549679, 77.50164939511207, 77.73800357695549, 77.81803561795142, 81.02051750306161, 76.88256602133475, 72.09686648461127, 65.95935344696045, 67.54777216142224, 75.3958700549218, 72.64264075986802, 75.38380484427176, 72.73958606104698, 69.64843673090782, 67.25151554230722, 70.01210320380427, 70.27221910415157, 72.72508898089009, 73.31993995174285, 77.59747289842176, 73.29123604682185, 70.51979126468783, 57.9066490357922, 52.01883016094085, 41.94221019744873, 56.29207595702141, 94.31227684020998, 73.58060498391428, 73.03286167883104, 76.52952132686492, 90.26734828948976, 62.31410264968873, 34.404014848893695, 6.395593227878694, 0.3393840291086705, 1.385598713832517, 0.13700829818844795, 0.3009396839526392, 0.5050118399723884, 0.925956010337799, 0.2832372919205697, 0.08000723506894805, 0.12239173895889714, 0.132617924903189, 0.15411652774820406, 4.1201360764042025, 24.805378836970178, 72.98536962078464, 78.66686005746165, 61.853145707038145, 43.43710391752182, 33.285821637799664, 43.37284372698876, 112.6071213137719, 71.26193508025139, 48.893979826281154, 63.58040063611923, 72.59201865042411, 3.408537228261271, 0.3188203293229303, 0.13388699551503505, 0.1385848918148587, 0.03729050565931586, 0.008742361735071867, 0.03541221128656499, 0.05103545984433544, 0.011790466622539587, 0.06028868348127412, 0.04837046595170133, 0.024805120680661454, 0.06698407743486666, 0.3155442615670543, 0.11753036715691129, 0.1651096443134931, 0.1819464642434351, 0.10223489314798387, 0.24877513308198224, 0.15879853538447813, 0.11931690717897109, 0.22014883286770315, 0.19267062266026774, 0.19329558186713727, 0.2373079766309069, 0.2506303528864538, 0.17602978334311517, 0.3629387506554204, 31.41112089157105, 97.81514167785646, 89.26422565214096, 91.61642397603681, 83.82140359570904, 72.29165923210883, 80.49830882780014, 89.36382247555642, 108.83682927777691, 33.61491241762715, 1.3418227338021802, 0.37816205152100135, 0.8459392911003483, 2.2020982878823436, 1.629666972064203, 1.2662984767267782, 0.2774414384076672, 0.27414569751389567, 0.5559904560927422, 4.0337811746904935, 4.669902343903819, 3.0640513906555795, 7.479697610101393, 0.3631146444428352, 0.7348700865141807, 49.03172954436272, 81.73144709679389, 78.35554938162528, 76.12098293919718, 84.70454092948668, 89.39185957754813, 98.71044620390862, 98.42196372247513, 88.9146012644614, 86.78742931735131, 84.93749833876088, 90.69857366623418, 89.07959968813005, 95.47489089350547, 90.55765075068321, 94.4419268638857, 96.26160852370724, 90.9718059724377, 95.54001008310627, 91.82226996267997, 89.45724548832064, 86.42998372354816, 78.53912415043001, 86.68739318847658, 84.57826414415914, 95.98496375545379, 87.09344479345506, 84.3712963596467, 87.70703684899115, 92.0677475775442, 91.25576203869235, 91.88392962178877, 86.0242380634431, 91.57294842504686, 83.36338058594735, 89.94347033962127, 85.70312146217593, 84.77482980297458, 82.51803921115014, 85.15220888199346, 86.08972595584008, 86.21219804210048, 89.46992258871757, 89.51710085715018, 83.91394015281432, 84.09424366489534, 81.23216075281944, 80.97936399521367, 78.72964935918009, 73.24613663458055, 72.12261292242235, 71.33082758995795, 70.01048718729328, 72.70911708954843, 72.37202859693959, 73.48162005024572, 75.2856279188587, 78.88218249044111, 79.48979685383459, 76.42069908880418, 79.49040089884113, 82.81654727074408, 83.82430614963656, 83.54042068604501, 80.06107437995173, 80.63960044614731, 80.0413134790236, 81.60692753330355, 84.89599181759743, 84.91674115580898, 79.35715013934721, 75.84436170516476, 67.84852381675475, 73.88684795748803, 83.2165741151379, 75.18567808212774, 80.34113161025509, 79.0922724816107, 73.6664499775056, 74.33070336618732, 76.69062091458228, 77.10403088600405, 78.57176611500402, 77.73524222835418, 80.23643570561563, 77.88502185575425, 76.3375997543335, 66.02093465866582, 56.92851974118141, 51.02319532825101, 55.691208070324315, 86.93532620706867, 74.54145231554585, 73.0495709757651, 79.44155954545545, 93.76492577214395, 71.22246034683721, 43.81471049401068, 8.366614637836333, 2.190691790273113, 3.2656671010678817, 0.8306135489575325, 0.7172842624206698, 2.3273162784114962, 3.257794168687636, 0.7926781006878423, 0.7501240615402499, 0.28239064219017185, 0.37788028438245097, 0.2871147386970059, 6.778514615951046, 45.25385948919481, 88.1757208608812, 95.36104017688383, 72.15359964678365, 71.40872586158015, 115.03398587626796, 90.32786261650824, 144.45968535638625, 77.01471851718041, 53.5479740173586, 76.27397106539819, 85.83749401953914, 4.037171083111917, 0.9331084523470172, 0.3179782454765612, 0.2163739499425696, 0.2923841059448258, 0.18579452388709594, 0.23654709810451155, 0.24693040868207333, 0.13680813473559197, 0.16208874512343638, 0.14107977971434593, 0.18805167938192047, 0.3596170240592572], [0.0191868903986629, 0.047046210196229725, 0.05468467753680964, 0.031204910032571326, 0.11276641109537695, 0.0462232364131318, 0.05267130271081002, 0.04966634581045759, 0.05526325011986399, 0.07229367195959054, 0.03898865062623255, 0.106505059577044, 0.027842379678341172, 0.08638107127720311, 0.12335068185723598, 23.758362916208085, 79.62393406898745, 54.87464904785157, 84.35311225152786, 75.55085074517035, 52.609452816747854, 59.49841353201098, 80.89176177978516, 58.40782596218971, 1.7509645536061258, 0.11527811462480216, 0.12943951803590023, 0.2744704268632397, 0.13858326770845922, 0.351220945557279, 0.14994720147261698, 0.09471749451251761, 0.0252314773388207, 0.23014179100432705, 1.6755019512868699, 1.4131292172016636, 1.1141013209858248, 0.38738909027268814, 0.1464847138812465, 11.401950601608524, 66.43063406790456, 60.46946294846074, 62.32013133264358, 78.6371284915555, 79.33922490765973, 87.39480049379411, 86.37164238960513, 81.67685554873559, 77.65944634714435, 78.41897410731163, 76.85799629457536, 73.56689237779187, 70.75739276024603, 74.4840366609635, 78.34295857337214, 81.184872658022, 80.68741413854784, 80.35935494207567, 83.4723440293343, 78.4933187115577, 77.13579423965948, 67.84049080264184, 66.47432142688383, 79.65616810706355, 82.03812937582694, 82.38718894220169, 85.24916202791276, 89.73279983766618, 85.7185128427321, 84.6703064826227, 78.26611934169647, 77.71697182809153, 78.16779336621686, 77.35396431338403, 78.77364266303279, 78.51955936801049, 79.28824194015996, 73.71158861344861, 74.31445690893358, 78.77624711682721, 74.30439995181176, 77.13602173712947, 78.04832581550845, 80.85671932466569, 77.846206080529, 74.81155457035189, 67.6940530346286, 71.2299285396453, 69.19563831821566, 65.36844838050105, 65.43286154347082, 65.73553908255793, 63.028303500144716, 73.19407109291323, 78.46481876988565, 80.19093621161677, 77.02925482103902, 80.6915718509305, 80.92935377551665, 80.00524336291899, 70.44157920345184, 71.86323442766744, 73.64750492957332, 76.22454135648667, 76.32456964062106, 75.5181303331929, 74.13042714518886, 74.0909916354764, 71.8884317336544, 69.91676607439595, 74.01898476385301, 75.44200497288858, 78.59048366546631, 63.31702524615873, 61.55269607420891, 70.28414310947542, 71.27110558171427, 69.37914248435729, 66.85817241668701, 72.6974598053963, 69.99222463177097, 67.50759924611738, 64.00513449022847, 66.05203120939194, 68.85933429964128, 69.18948804178547, 68.14166607395296, 53.95437863565261, 39.86675862343081, 41.54054380232289, 35.29703655550557, 65.546269032263, 76.87300328285464, 71.07674429493566, 76.97127434515184, 78.13401391429286, 59.865574836730964, 30.160594755603423, 10.448511646639917, 0.412390798690819, 0.5663860240770925, 0.17747218900870892, 0.6285828640384059, 1.0648033791972746, 0.14615811527736727, 0.20850175300673132, 0.10146883586722036, 0.08773438091720305, 0.01458035582946914, 0.23604017772501518, 0.06483618139980302, 1.8052583692535278, 23.477121130112682, 61.32937985081827, 59.766840934753425, 32.09889085062089, 53.367411628846206, 37.573717486473825, 58.2170928678205, 46.46707996245354, 56.98073433291528, 55.899509460695334, 71.34412442484211, 10.379724060335468, 0.5936097858413574, 0.14902231884339165, 0.15132957648846412, 0.08028016155285221, 0.04855087199699014, 0.07519938983023167, 0.07684897631406784, 0.014039992839248191, 0.11750706276225469, 0.1693830666162314, 0.05444403399803466, 0.03569292888465909, 0.08163347885373139, 0.10395950262224483, 0.06028070084510311, 0.008628817928594448, 0.0031047053785333715, 0.03028299407883277, 0.02477432394610538, 0.038089213607412194, 0.08458913799615637, 0.050661831102784605, 0.026398104758212165, 0.03742436420232539, 0.04537990767388575, 0.02929269903219275, 0.05377208678832939, 31.472462838695897, 89.24807333177137, 72.56727633937713, 78.65640301858225, 90.08963354172246, 37.60365693799911, 52.25692979751095, 102.38156503246677, 72.55075531621134, 2.143447331843838, 0.12301916496888285, 0.1586143831692396, 0.0649857830496565, 1.330934234203831, 0.9684572813491669, 0.11962521926409776, 0.5742806520673537, 0.06440327277467137, 0.7544058801666383, 2.4826382148650388, 3.3715443745736158, 1.687636171137133, 1.3830523601462765, 0.365781978734078, 18.352132651113696, 80.72321753348075, 69.00050040214293, 72.91577892918741, 87.41631077181908, 85.1629404867849, 92.58242530207481, 88.50214050662133, 85.60575254501836, 82.98998663502356, 86.46373964125111, 85.81881569277856, 82.08414662268855, 79.79676154352005, 81.02935852543001, 80.58542466932728, 80.8891494812504, 82.73252225691273, 86.41096022821243, 86.0500237249559, 82.67754631657755, 80.24678291813021, 71.42952226823377, 72.1857395479756, 85.71251161636846, 84.86982960854807, 85.1267997680172, 88.10911117061492, 90.85887309043639, 86.59442517065233, 88.49282879983225, 83.15540867467081, 80.93200529775312, 80.50066224990353, 80.80136683679397, 82.59485490860479, 82.47734854298254, 82.24446173637145, 78.54405849210679, 80.65303848635766, 80.23584735008978, 77.78209886243268, 82.53552513737833, 80.01950510086553, 80.35890779187604, 78.23608183091687, 78.54152464097547, 71.81306731316351, 76.2228939610143, 69.62393760681152, 67.62569396726548, 68.43664400039181, 68.73250838248961, 66.93721602039953, 78.58090523750552, 78.97163606459095, 82.20926238644509, 78.20296133718183, 83.23408357558712, 81.20696344683248, 80.90896529536094, 71.083694734881, 75.45641576090168, 75.46170311589395, 77.15167983885735, 77.04359500638901, 78.59678299196305, 74.41844678694203, 75.01430972929924, 73.65622043609619, 73.25857839276715, 75.93173642312327, 78.62936219861432, 80.07582249179964, 70.68668811551987, 65.01908286925286, 70.75489813281645, 74.36710296138641, 75.19462893086096, 68.56289725149833, 74.15669133586269, 69.80898718680106, 71.46709857448455, 68.69643042164465, 70.731214861716, 70.30622605354556, 70.08086235292497, 69.41501648195329, 60.94619958631454, 47.051242474586736, 59.1241527372791, 46.33475488232028, 60.577288904497706, 74.77660625211655, 77.15406463992211, 79.99037757996591, 81.88809871673584, 81.87059710102697, 49.58926700776624, 19.23803133349265, 0.989181737024938, 0.46603203000080207, 0.2597999656873365, 0.2896416950370035, 3.1384437987881326, 0.5471169515963524, 0.3338534565221879, 0.037131615193380464, 0.06292561174280221, 0.014666031272481046, 0.1463761132571005, 0.11664133744254229, 1.3222447133833364, 41.01416564756825, 73.93502250794442, 72.31212615966797, 40.3367958530303, 49.584889642653934, 28.192300373508086, 81.0516611222298, 48.4810640735011, 56.18869796875985, 65.94855908424624, 82.15623194171538, 13.192039939665026, 0.6855871600489463, 0.12156508412332305, 0.08522574173947496, 0.09366786978658169, 0.03818731882699555, 0.0556135016884054, 0.033405869147710265, 0.02693729850673868, 0.06592354361688899, 0.08907174060661947, 0.010812309281449887, 0.07364801581828825, 0.1816880781083338, 0.23009271541189766, 0.1167701091617346, 0.09078255283736414, 0.26242884236478037, 0.10336635138599143, 0.13328701077449706, 0.1556633971631527, 0.16289612518683558, 0.09970530146552671, 0.12728250555453763, 0.17450747470701897, 0.2535247403166948, 0.23747193476846143, 0.2115952926537683, 39.91019102834886, 102.18911001759191, 75.23632372579267, 101.07292898239629, 94.88565675673946, 78.48090048759215, 86.58543509821739, 108.20457458496095, 88.43479341076267, 3.1294024903928084, 0.21640873033433192, 0.6734455857546099, 0.36196670765357636, 3.4489927993666742, 1.3702363833304376, 0.6376933654950512, 0.5407807303051795, 0.16676980281068435, 1.762505760115962, 4.8351915132614876, 5.850666184579173, 4.534939469829682, 3.3809242325444377, 0.5791195698322789, 24.62309648913722, 93.67730002249442, 78.31038721146123, 77.03861359627017, 90.91200551679059, 90.03496354626071, 99.7777388172765, 96.87562419522195, 92.58909333136775, 89.77624400969475, 92.0951335660873, 89.80624229677262, 86.09706863280266, 83.69704092702558, 86.43038380530574, 84.61827231991677, 86.6210815983434, 89.18071054643201, 92.39513212634672, 94.11723306102138, 90.65250150619015, 85.01698124793269, 75.33152749461513, 76.98721485753214, 90.15661193478493, 87.40237066822668, 88.38017832848334, 93.40574649072464, 96.1543473889751, 93.09619303672545, 92.59431792843728, 86.48091177786551, 85.16074395948841, 84.21791599642846, 84.13018826515444, 85.91972258783157, 86.23479089429303, 86.74873905797159, 82.10564905597319, 83.7287336780179, 85.96049954814296, 81.57397177911575, 86.44684991528912, 82.34355649640484, 84.77406101842081, 83.51492527992495, 84.66648609407487, 71.3534204421505, 76.86513500828897, 70.4303063115766, 68.6744337697183, 70.45791979758971, 70.59623825934626, 67.68633381012948, 79.61097455793812, 84.22537634449621, 87.7959805150186, 80.79062738726216, 85.71308428241362, 86.51739766520839, 85.97331785386609, 74.00725687703779, 79.91236163723855, 78.39595763914048, 79.76357829186225, 80.37804111357659, 81.57802750987392, 74.99112067684051, 77.10067333713656, 75.3828477859497, 75.34894281818022, 80.13334012800648, 83.32132493295978, 84.64224584640996, 73.61896576419954, 70.94278750881072, 79.91517005428192, 78.98536436019405, 77.54120257592972, 75.28995037078857, 80.41509966696464, 76.7199053302888, 79.08587117348948, 77.46376714398785, 76.66916554973972, 76.09451478527438, 75.746169090271, 75.03055618655297, 66.38413829188194, 54.44750293608635, 64.92011754743515, 49.40588835747012, 76.16214429178547, 80.7367104868735, 78.22271439336961, 81.40150516263901, 82.61131317384782, 83.96787274268367, 58.91879704690749, 24.073178229793427, 0.9853335854507262, 1.4606142885261968, 0.8685931851786952, 0.8909861803535493, 5.355627767501339, 1.564086903968165, 0.8429059506424013, 0.36258999678877096, 0.24529775274136376, 0.11625729756610048, 0.3432730897780388, 0.23323431941530398, 4.926860245966143, 59.23311618066604, 88.43587598493023, 86.18361180828464, 48.19786502468971, 78.647656133098, 57.60292422386908, 74.67177698689123, 62.83693105943742, 82.66645385373025, 76.19014217007545, 96.88074681066699, 15.142317894966373, 0.8507969626976598, 0.26941816893316084, 0.3383287889582496, 0.20739126259521132, 0.20051615973634107, 0.23292529486840774, 0.16471549207645078, 0.16497225410515265, 0.2611255123009605, 0.3206978882512739, 0.07149406768862279, 0.16109307597000755], [0.15551474546232533, 0.026653016684576872, 0.030669284338552146, 0.010324223173571932, 0.14398628665554908, 0.0625785471000258, 0.026647282516463634, 0.03684110316117445, 0.052275867276494546, 0.11437557878032809, 0.09431575800502494, 0.016760797194776036, 0.10728631604222522, 0.04436674107226633, 0.1316381750568267, 20.893781454332416, 70.70591557410457, 63.188579390125895, 73.97878831432712, 40.56021013567525, 37.230737593866166, 51.25725492354363, 88.20207918843916, 14.402794222677908, 0.2133064113196827, 0.09465282136994986, 0.24192232338170855, 0.10053043178613148, 0.497572053704531, 0.3333239671924422, 0.38352524921778713, 0.6214508306114905, 0.1855138905586735, 1.0910841173702672, 1.679409122274768, 0.37047157064080244, 0.6718801310466183, 0.15691397441250665, 2.8863719442198357, 57.16487392302483, 53.57873716662007, 65.61691484143658, 77.15520212727209, 83.4983414988364, 77.37090110778809, 83.17853496920678, 79.66191830173616, 79.17816454364409, 78.68942153069281, 80.08702478101178, 83.78092473553073, 81.82789817933114, 78.67997646331787, 71.75034861410819, 73.3275571946175, 76.45234477135443, 78.56203863697668, 82.67643236344861, 78.105176648786, 76.30076869841545, 71.67585495979556, 68.72183953562092, 72.95513599149643, 81.10814325271114, 82.90899753570557, 85.08690926336473, 83.87150010754986, 83.24559965441304, 82.2234692112092, 82.29924155819802, 77.76260468267625, 78.29519194941368, 78.54693751181327, 78.17216288658881, 74.80250958473452, 76.35514843848445, 76.18469792027628, 70.45577033873528, 76.3868647236978, 71.8076858212871, 77.01730728149414, 79.70287569107549, 74.7120911075223, 77.64210162624236, 75.80531058772918, 70.5465732082244, 70.01253466452323, 67.55939806661299, 66.50418635337584, 66.26720459230485, 70.59543025109076, 71.21936167440107, 74.79138574292584, 73.70596393462151, 69.66079219695061, 70.77069743987053, 73.30485451606013, 79.25773374495968, 78.36183301864132, 77.02377919227847, 73.51143006355532, 72.27856636047363, 78.19784656647714, 75.91553703431161, 76.1633994502406, 76.01984070193383, 75.45718454545545, 76.64534107331308, 77.29272827025383, 76.57121612179664, 70.36612064607682, 73.01298310679775, 73.35990105905842, 73.7770765058456, 63.137894522759225, 61.732344550471154, 62.712850801406375, 73.80737289305657, 66.46562160984163, 66.62393631473665, 67.95906405295095, 68.02516383509483, 62.88853768379458, 62.24665357220558, 61.490573575419766, 64.54469965350243, 64.74125746757754, 64.50802157002111, 40.9012209984564, 39.69719848325176, 38.8762346390755, 34.723821378523304, 55.416814742549775, 63.91555147786295, 75.91615676879883, 75.10941936123756, 76.8119712029734, 41.952631934996575, 23.917524853060325, 2.920838056072112, 0.24528315110552698, 0.24468008669153338, 0.16286666144526776, 3.1257382612074576, 0.5217340684706165, 0.5682401407149531, 0.033356536915826226, 0.09988839647942975, 0.04518976082063971, 0.07376948671956217, 0.14988910136443956, 0.3376060309669664, 1.0435296691233114, 45.11674127271099, 67.25776780036189, 26.181669888957856, 17.96003487802321, 46.32957735369283, 18.278080263445457, 60.78722984560075, 66.54799922820061, 47.76469807470999, 71.30584993670064, 10.47966311054845, 0.5062773559362658, 0.0324070820164296, 0.028248630358927676, 0.03523264793799289, 0.026031083525008252, 0.0617413125902174, 0.012143733704672947, 0.010980858200890644, 0.08214067502488052, 0.07358105973370614, 0.03401466006893785, 0.09143553554050385, 0.058885796461254365, 0.03555953765528337, 0.050083074658628435, 0.030999661671117913, 0.06749915665075665, 0.023484852412835728, 0.014592249344493595, 0.09380104651133861, 0.06604800226106759, 0.04449324900164239, 0.06426027480272517, 0.02092695569679622, 0.0069920428288770065, 0.01399542663186308, 0.04308332546403812, 24.751791415675996, 83.58183307032432, 69.273403229252, 96.02258713014665, 59.65462584649364, 30.835685653071252, 57.83071194925616, 101.65217676470357, 19.591976211917018, 0.27387919084679696, 0.1013524747724014, 0.08774781809939493, 0.09184303302918712, 1.3105281033823568, 0.5987793471544021, 0.5787026954274024, 1.0831076099026589, 1.0028443942146918, 3.648414924260109, 4.517845290322458, 1.3797068235374268, 0.7186873677757479, 0.20248606290307739, 5.363300413854661, 71.77411817735242, 66.37902352117723, 77.31343838476366, 85.49374534237771, 87.59510809375395, 83.5332662828507, 88.41005894445604, 84.47896542087679, 84.262725153277, 84.45243450903124, 86.0783903060421, 86.74854293946298, 86.69825030911355, 85.126203567751, 80.59253984881987, 77.28498551153368, 78.92585415993968, 80.7469400282829, 84.95074810520296, 81.71395332582536, 81.65630232903266, 72.84324645996094, 75.1879216778663, 80.64683329674506, 89.42716090909897, 86.15865768924837, 86.92663423476681, 86.9544203050675, 85.71574364939045, 83.44142006289574, 86.03755058780794, 82.46710331209245, 84.58603828184067, 85.08090019226076, 82.32825140799247, 79.71849456910165, 81.69432578548309, 79.49861434198196, 76.71148792389901, 78.98896509601225, 74.48912789744716, 80.14349122201243, 84.80181570976012, 79.69008091957339, 79.14114521395776, 77.84505290369835, 69.28853573337679, 70.68895524547946, 71.95896379409298, 69.88271990130025, 67.82042395684027, 73.52769221028974, 73.55248158977878, 80.60890397717877, 76.43143069359564, 75.71373893368629, 73.75860214233398, 76.3846681964013, 79.23036344589727, 79.8293250606906, 77.61290350267964, 78.2214984586162, 74.78182300444573, 80.43766114019579, 78.4712593017086, 77.51552674078172, 78.91322412798482, 77.38244072083505, 79.3046139132592, 78.3721802311559, 76.8271193965789, 71.53958397526895, 74.14380242747646, 75.4518501220211, 75.12165715617519, 71.92377228890696, 67.41032446584394, 65.98288766799435, 76.28505568350516, 74.81688114904588, 72.70027606718003, 69.99754336572462, 69.98681176093318, 70.22366800615865, 69.92680734203708, 65.72648232983005, 67.87938502527052, 64.32729836433165, 69.81749088533464, 53.0468951502154, 48.17398563508065, 49.37516835428054, 41.855714090408824, 59.430764413649044, 67.04258657270863, 75.27491984828826, 77.63328413809501, 82.62474336931783, 67.8686220415177, 34.99014639085339, 6.654478484584439, 0.15438102726494113, 0.21836302062917143, 0.7120429339908785, 3.1626776726015153, 0.642585909414676, 0.9531819784352857, 0.08872527734286363, 0.15460492412169136, 0.035248302944725564, 0.016311473220646862, 0.10014491335999581, 0.80977761216702, 3.1121347460054585, 61.34139407065607, 80.66191088768744, 32.97718994079098, 26.4296813549534, 33.37896223991148, 23.747452843573786, 66.20129308392926, 64.28605856433992, 58.25475938858525, 78.82354305636498, 13.890496396249342, 0.6457586778748421, 0.1763602277083743, 0.12554998239201884, 0.07268608517704472, 0.04842971136132556, 0.05985652562230826, 0.07719019187554237, 0.01578170809924843, 0.023551084544329394, 0.07035602109446641, 0.08719552233214341, 0.09916485707846381, 0.2862236865105168, 0.1678230664542606, 0.15665545038157896, 0.06312565645202994, 0.2657307119619462, 0.21784620239369332, 0.07867533758643173, 0.24169831927264893, 0.3607845420558607, 0.247299678383335, 0.1798515508492147, 0.2324817606037663, 0.18928871219677312, 0.1697195324325754, 0.23625986109818184, 29.42538372931942, 95.21398267438336, 80.53728934257262, 95.32157328820999, 54.31287150229178, 57.26501203352406, 70.86226909391343, 117.14984570780109, 23.48095132458595, 0.5347823231450973, 0.35081985256364273, 0.4492864817861588, 0.4017551081074823, 3.1659241693635143, 1.150389864079414, 0.9324476555470498, 3.156956895705193, 2.615089055991942, 6.525751198491743, 7.855592072010041, 3.187727889707012, 3.208573571135921, 0.3291614744211397, 7.453445676834353, 85.35375595092775, 78.01728417796474, 83.08916768720074, 89.96665939208, 94.1402965976346, 88.41831945603894, 95.39303887274959, 90.6879597325479, 90.83748048351657, 87.86016618051838, 90.07985115051271, 90.945157389487, 92.11797744997087, 89.35107477249639, 86.06125739312942, 83.64962731638263, 83.04151873434745, 85.49456119537355, 92.46926492260349, 86.126462874874, 87.76028694645052, 80.75305108101138, 77.94451636652794, 83.15533022726737, 94.45162296295167, 89.23811835627403, 91.24887435666977, 91.85056594110306, 89.87562118038055, 86.59549205533921, 90.38012427668419, 86.76991985690209, 90.04538136143839, 86.58515268756499, 88.8427826666063, 82.72079437009751, 85.01295689613589, 85.64600390772667, 78.39092916057956, 84.54927782858573, 80.83942167220577, 80.40601545764555, 85.4355687479819, 81.96495363789221, 86.62576490832915, 79.83013306894611, 71.70932062210576, 73.25654660501789, 72.55230857479957, 70.14064711909141, 69.94619169542867, 74.53640814750426, 76.3111629793721, 81.97500275027367, 81.80227725736557, 78.84058183239353, 79.08875803793632, 80.59434413909912, 85.49380810030046, 82.57623149502663, 84.93128530440792, 81.95190783469909, 78.30243264475178, 85.2840946566674, 82.32049295979162, 81.7068773700345, 80.31136866538756, 81.1634486721408, 82.88626347818683, 82.35271915312737, 79.50452143146147, 75.31459854495141, 78.78612364492109, 81.49844261907762, 83.19293791247954, 76.82324409484863, 71.28110762565368, 68.50697994232178, 81.17229753924956, 76.89559613504719, 76.9966834591281, 75.6509574767082, 75.56293164530109, 76.90377035448628, 77.21912107160016, 74.30422736752418, 76.99427512384231, 75.3870996352165, 75.5226645931121, 58.50372399053266, 56.35925831333284, 55.848557872156945, 52.025882582510675, 67.16902025284307, 74.13578510284424, 79.2898658014113, 77.23298272778912, 86.3833781211607, 70.57364540715372, 44.44884007976901, 7.065785575297571, 0.31001439378146206, 0.937608146379071, 0.8566354719861862, 8.61484085359881, 0.888252227056411, 1.9041486757416881, 0.22952594824375647, 0.4879408576075108, 0.11194938598501106, 0.15417937760151204, 0.2942284166572556, 1.444842315489246, 7.5837845667716, 81.79645646002986, 88.46861208638838, 48.00415485135971, 35.7665442651318, 64.26707821507608, 29.079016870067967, 75.08696771437123, 82.45523421995102, 64.15994259618944, 95.78735474617251, 16.05023480230762, 0.9480898839331443, 0.23726031064025818, 0.32785866529710833, 0.10410947199430197, 0.1237588305206549, 0.29028428958789, 0.19680714505093713, 0.12228757398383272, 0.10500472234261614, 0.2033156901597977, 0.25957556321255626, 0.26338317341381506], [0.03367540569254949, 0.04793085405723222, 0.04481997401002915, 0.0341949665227965, 0.05419409398229853, 0.04683162513819914, 0.08554801194658203, 0.0455466467106054, 0.05016534484081692, 0.02128241666322274, 0.1079307951694054, 0.02260701141260084, 0.047192870068453976, 0.074129264591442, 0.12518054415141383, 10.21108469655437, 68.38337036871141, 68.66330208316927, 32.76043584269862, 38.51344285472747, 44.715933876652876, 75.01216027044481, 72.01908588409424, 2.401390729411956, 0.1802889104451864, 0.07368765320749053, 0.15466241135952935, 0.060306456721117424, 0.6711218265756485, 0.4663186694585508, 0.08755911532188616, 0.055903063771585305, 0.3102372947239107, 0.194069943541, 2.7982360412997584, 0.8182567958870243, 0.4756276796181356, 1.2331405979010368, 35.53108438368767, 56.26181487114199, 68.95368299176617, 79.47083611642161, 85.34087488728186, 83.47989851428618, 86.35666678028723, 79.6885198162448, 84.42510343367054, 77.6261297349007, 79.96643543243408, 78.5726055022209, 86.30722922663536, 82.49554834058209, 79.66706445140224, 74.73520171257758, 69.52251295889579, 76.19111491787818, 80.44863593193793, 82.76503086090088, 74.70819227157101, 70.26617080934587, 65.8081146978563, 75.95387428037583, 76.8679512700727, 81.07338320824408, 83.50016147859635, 83.94192234162362, 83.0540781636392, 80.80484990150698, 84.87849804662889, 80.84280275529431, 78.77556462441721, 79.7264648252918, 75.4125165939331, 73.41445338341498, 76.08440291497016, 76.89082653291764, 73.63775391732493, 74.47368160370858, 69.72397373568627, 74.60110372112644, 79.25495670687768, 79.3269714232414, 73.96777429888326, 77.50559529950543, 73.2597472590785, 69.24385993711411, 72.62747687678184, 68.04963158022973, 64.94875084969306, 66.10971358514601, 68.63681039502545, 71.69345071238857, 74.70092019727154, 69.3700739645189, 70.59320234483289, 69.18762099358344, 70.13008025384718, 70.11667359259822, 77.50004906808176, 76.18347414078252, 74.17589526022635, 69.33514918050459, 70.92931024489864, 73.88877776361281, 72.57882379716443, 73.18927011182232, 69.99662553110431, 71.22762218598398, 73.23272212859123, 72.12862199352634, 76.82206738379695, 72.77941380777668, 70.7735921490577, 71.96301952485116, 73.5919092547509, 65.62311218630883, 63.546283860360425, 63.4449415822183, 70.97990882012152, 71.01324112184587, 69.11225657309257, 70.02887525866109, 67.84861795363888, 58.70873843469928, 57.60296736994098, 54.99787422918505, 59.37069331446002, 60.87309837341309, 61.56033292893441, 43.17326568788098, 38.83726589141354, 36.895445546796246, 42.94834129271969, 50.134209740546446, 59.391599547478464, 75.88678606094854, 76.6404773342994, 61.91464847134006, 26.081437641574492, 13.903315682565013, 0.08568115036694274, 0.25826950587572595, 0.7044730659934783, 1.5182293711170074, 0.3719289150209196, 1.1656663927339739, 0.22281890975371485, 0.019894318970581217, 0.0827339641569603, 0.06192357639872259, 0.10940762882631634, 0.034255533434090116, 0.1881982473235938, 11.982958547530636, 64.12816355305334, 49.348453091036895, 52.66112612139795, 26.15778853816371, 35.818394076439645, 31.19802244247929, 58.08308901325349, 51.516958975022845, 55.12562974806755, 2.09982150504666, 0.21795189188372707, 0.04245451283490947, 0.07479093473164306, 0.12706385640006873, 0.045815761907086264, 0.01822533131006264, 0.05784077592374337, 0.01834094738437524, 0.10806175023918191, 0.01798228608564504, 0.05512736527429474, 0.047643161228587555, 0.022263171999985655, 0.03075658580318334, 0.033550843626501105, 0.043103504219963666, 0.07527713243278765, 0.045649834923566356, 0.09832610571456533, 0.036527857469815406, 0.03401847518680077, 0.038253428384421334, 0.094344693145925, 0.006409842340696243, 0.0446316849199995, 0.04827819066122175, 0.11486661049627489, 13.65384509486537, 80.67050872310516, 75.63804503410094, 57.49104253707394, 41.13392737603957, 35.500964503134455, 91.81004001248269, 84.73551980910763, 2.7781907685341376, 0.04397061998925863, 0.2565190102905035, 0.22865280719293704, 0.09093407736790758, 0.5890978956895491, 1.5369671463005006, 0.6699442575054785, 0.05125637278862057, 0.4412691571539449, 1.7362633876262175, 4.011890426758797, 3.079394231880865, 0.2581404047387262, 1.670047282691925, 46.88980556303456, 71.1886416712115, 81.98909974867298, 87.76795910250756, 91.17149383791032, 89.7199893766834, 92.72439156809162, 87.51649595076039, 89.24510017518075, 83.16777983019429, 86.2196897691296, 83.20683879237022, 88.29639650160267, 87.97106727477043, 86.94247276552262, 84.43896508985951, 77.50334385902651, 77.85467055536087, 82.26975317924254, 83.60003286792387, 77.27466183324015, 72.15764753280148, 72.22244508804815, 81.78745854285457, 85.28636178662701, 86.65624956930839, 89.15224198372134, 85.8927837494881, 86.47104309451196, 83.96015351818454, 89.35769573334726, 84.53581625415434, 82.54566838664394, 83.38816996543639, 78.36959146684217, 76.40065577722366, 80.10896651975571, 78.32595902104532, 78.86486914850052, 78.79010092827582, 77.09953584978658, 79.43714295664142, 80.5737595404348, 79.20875903098815, 77.56887881986557, 80.42181476469963, 72.43233111596876, 70.48575293633246, 73.22718374190792, 69.24396976347893, 68.76872754866078, 68.59852806214364, 72.49934873273297, 73.39517101164788, 77.21778746574157, 72.01069201192549, 72.65894213030415, 72.77214957821754, 72.75641302908622, 71.78244929159843, 76.6105967183267, 78.52559981807586, 78.43836630544355, 72.57751372552687, 72.68272738302909, 76.42176597349106, 76.6159938996838, 76.62561155134632, 73.16897576855075, 73.45656394958496, 75.00440182224398, 74.92201635914465, 77.24209831606957, 75.61021974009853, 75.05699296151438, 73.28670963164299, 77.74700149413079, 73.68011551518595, 67.71815992170765, 64.43159418721353, 75.83465776135846, 77.53942966461182, 73.12986973793276, 70.85455771415465, 73.69308287097563, 64.98456993410664, 65.269475213943, 60.85719708473452, 66.45050479519752, 63.37372702936973, 66.83244951309698, 54.77866472736482, 46.81572767996019, 47.24450942008726, 50.53253819865566, 58.836086027083866, 66.5849950236659, 72.01981544494629, 78.80830072587537, 77.15666124897619, 48.00271534150647, 20.231704981096332, 1.016651321082346, 0.07895554956649581, 1.918500015331853, 2.860781175474967, 0.3587791077311962, 1.2138039258218583, 0.023863167697263342, 0.14146446310464414, 0.19207862055590078, 0.11034333627791175, 0.04121157731260023, 0.06712676897164314, 0.309751441762332, 18.66564181543166, 79.29018743576543, 56.89596799112136, 59.35776518237207, 30.690252011822118, 39.22611398081626, 40.434384422917525, 61.64689571626725, 56.21680567341467, 64.27475821587348, 3.6622501044504108, 0.11436100012712902, 0.052853283066783226, 0.0472450444865371, 0.052873618870733254, 0.06668203960983984, 0.03517932055758373, 0.047717598161750266, 0.021509521513155872, 0.027599652380412145, 0.047323415281190995, 0.05642519865725791, 0.03500565608602858, 0.14809714510075508, 0.1755240274172637, 0.14158316076763217, 0.12567261008605843, 0.11736894477038615, 0.14990710443066013, 0.3715956361303407, 0.12248366184893156, 0.10984169424421365, 0.21480060452895783, 0.19840929537050186, 0.07349691263610318, 0.1687730920891608, 0.15365862167410313, 0.3235398293022187, 17.594744543875418, 91.24749368236911, 87.0067290336855, 48.787154074638124, 53.07412032158145, 66.34423994248914, 101.7705931202058, 96.32817114553144, 3.1381189775082374, 0.23830802780726265, 0.38251450345400845, 1.0026442307618357, 0.2326803459154983, 2.458654392150141, 3.717307433966668, 1.1544743997435416, 0.2355859335511923, 0.8755164136809688, 4.580610077227316, 7.167001847297915, 4.578259596901556, 0.9779407756943858, 2.690242158789789, 55.60635935875678, 82.5775807903659, 85.76555775057885, 96.82428821440666, 96.31157951970255, 94.80496575755458, 96.23463046166205, 90.77848803612494, 94.73858356475831, 86.57667252325243, 91.57511357338198, 88.08822847181752, 92.33614752369543, 91.94021563376151, 89.26635942151471, 85.61866498762562, 78.81853026728477, 85.91008924668836, 87.93265158130278, 90.46415713525589, 83.56903829882222, 80.21560792000064, 75.25604540301909, 84.56219811593333, 90.52824866387152, 91.59365069481635, 94.1772061009561, 89.56187863503733, 91.05521909652218, 87.16345125629057, 93.40466391655707, 87.59662212864046, 87.54090878271288, 89.69370949652888, 83.53496074676514, 82.2868468684535, 84.71116189033755, 83.93838436372819, 80.11423034052696, 81.32468162044403, 79.99029913256246, 80.58605224855485, 84.66052409141295, 84.73348802135837, 82.24845470920687, 84.29038570773217, 74.72341106783959, 74.80702815517303, 76.81958844584804, 72.84127743013444, 68.72438123149257, 69.96694887838056, 75.27015809089907, 78.58951876240393, 82.60583754508727, 77.33666666092412, 76.67008338436004, 76.95653407804429, 76.928096894295, 74.2578649520874, 81.90304294709237, 83.87460662472634, 83.0217735229, 75.9838725674537, 75.27335874495968, 79.17165340915804, 77.88587693245181, 79.42129658114526, 75.85324195123489, 77.3212831251083, 77.9547929763794, 78.19771320589128, 79.96565095839962, 77.57786104756018, 76.69433932150565, 77.03829196191604, 83.66110417150682, 78.5277492769303, 68.55589974311091, 65.82507502648139, 79.23042620382002, 80.4205596062445, 75.52683015023509, 76.12103000763925, 81.06300461676814, 70.96830644915181, 73.11911459892028, 69.52456043612573, 74.42742901463663, 73.59119538337954, 75.03332537989463, 57.71939508376583, 54.64631219064036, 53.430612779432735, 58.167212086339156, 62.35940602517898, 72.31279296259727, 76.88795535795151, 82.64981515945928, 81.39852416130805, 53.58530321428853, 25.783009990569084, 0.8407829677866352, 0.20290866764562748, 3.422836473872585, 5.041905324305258, 3.3731765708615704, 2.486135253021794, 0.5779447586786363, 0.3296629862198907, 0.6006695618552547, 0.3586097410128963, 0.21775503793070394, 0.2028164153377856, 1.2278887893884414, 27.97728780777224, 92.89078635554161, 76.0216293027324, 78.7661038675616, 45.24631677135345, 51.60642823865337, 44.16010264427432, 77.4756048571679, 68.2804395306495, 80.25261940494661, 5.392051877514009, 0.33355934004629817, 0.20144663480741365, 0.16135487885725114, 0.23284693939551232, 0.18556578535466425, 0.2736856770371237, 0.14542910600862197, 0.1062729502577455, 0.2246431489625285, 0.09759544169590359, 0.27618367525358356, 0.15719952602540294], [0.0532325387241379, 0.04499669517240217, 0.04293955757372803, 0.0459846115160373, 0.04556505963386548, 0.015945361716853037, 0.05758524729659962, 0.07103353393294158, 0.04725947758303054, 0.07272168528288603, 0.05987755856626938, 0.06725492015961679, 0.10155597836860727, 0.09170541299446937, 0.3809740232123483, 13.156636626489702, 63.2767346597487, 57.79165298708024, 52.88677615504111, 49.63083628685244, 46.892417861569314, 65.91226147067162, 24.921096601793845, 0.17615073330460057, 0.0715577832212852, 0.14805239024421862, 0.1343743806524623, 0.17708824106281806, 0.06324356504445595, 0.8449324064197079, 0.46755960932181734, 0.1629597870933433, 0.2173582809947191, 0.4381539678621677, 2.961627518938434, 1.1516179336655525, 1.0457335508638814, 11.004966535875875, 48.532047041000865, 62.01338629568777, 73.13030119865172, 80.50929930902298, 84.75026792095554, 89.81309075509348, 84.98718692410378, 85.91812226080125, 83.72976133900305, 84.48029902673538, 79.44866688020768, 80.48745955190351, 80.44574122275077, 83.17225917693108, 80.70595125998221, 80.67491746717884, 75.53731856807586, 70.21299131454961, 75.10456346696424, 79.78250765031385, 72.26439875941124, 65.95323454949164, 74.44012964925459, 81.33555443056169, 76.40736303021832, 82.30160282504174, 81.1297005991782, 78.91730339296403, 78.84170363026281, 79.32597514121764, 80.49139761155652, 80.58900187092443, 80.208218174596, 76.22836958977484, 72.19433738339332, 74.58370408704205, 72.42618868427893, 72.39749262409826, 77.92383763097948, 74.11201553960001, 78.82457856209048, 75.70563531691029, 74.58816774429815, 73.11599239226311, 76.26804828643799, 73.11585903167725, 72.06782525585544, 77.90745781313989, 74.4837385608304, 72.87621005888909, 68.4274499647079, 65.68641139614967, 66.09486349167364, 68.90506913585048, 71.91225621008104, 68.29918061533283, 68.44629303101571, 68.05781364440918, 66.27668103864117, 69.21176710436421, 73.18969372780093, 76.83315200190391, 73.59805168644075, 73.29264810008388, 72.10096143907117, 74.84285508432697, 72.63051279129522, 74.89549329203945, 72.62699834762081, 68.82635501123244, 71.66120882957213, 70.42524645405432, 71.59923538084954, 75.03715361318281, 72.61570976626489, 75.58713266926428, 75.87778029903289, 68.94788572865149, 67.16836913939446, 71.66765720613542, 65.44065137063303, 70.72022438049316, 69.6167282904348, 73.7932994288783, 73.18298647480627, 65.4032241144488, 56.83049971057523, 57.66654114569388, 54.406757354736335, 53.99108809809531, 52.86589737861387, 53.84555639759187, 39.09577754236037, 37.10886170787197, 46.6461596950408, 61.1718378528472, 55.06739431811918, 58.853579798052394, 73.1294539666945, 68.38684558868408, 40.89505503254552, 18.233465263920447, 4.527288886808581, 0.20515915817551075, 1.539368617438501, 1.3342069618163572, 0.6461433152998648, 1.1841427174306687, 0.21747759152804652, 0.07682912697594974, 0.09309492028889157, 0.1086367145481129, 0.20326578719241006, 0.12848953836627547, 0.05762030348001469, 0.5065043631099886, 46.200256809111565, 59.214759488259595, 79.21030444483604, 41.74189475274856, 27.801240067328177, 46.63778935709308, 46.00570724856469, 65.5286144441174, 27.779969053883708, 0.15099916276672196, 0.03207094753311286, 0.03649413427938858, 0.09386194284043967, 0.02400032807922652, 0.0875763216566655, 0.04721495638331098, 0.06571914369781172, 0.0657196416549625, 0.08892937082677119, 0.04873966670504982, 0.1058536550150283, 0.053692160835189205, 0.06563704971584582, 0.09308196574209199, 0.045632467710322915, 0.07871908120690815, 0.07761022256266686, 0.0727507966240087, 0.044057057689755194, 0.04023493778321051, 0.029203082066810424, 0.02889715251512826, 0.01975997396173977, 0.039296962711359226, 0.13060084604207547, 0.060611685302348874, 0.3319210763419828, 17.29667971211095, 74.37195885565974, 68.36893604647729, 68.76817057209631, 29.36775822793284, 47.8098092540618, 86.62232106731784, 29.808752267591416, 0.19985720154739198, 0.08316465112711154, 0.041048006049447486, 0.03741671098396182, 0.2966639327426111, 0.10846335651172746, 0.3046432900572977, 0.8076937917259432, 0.13517691904018003, 1.3513195274337646, 1.8862205022765746, 5.944625091168189, 0.5203252634213817, 1.4256952654930855, 18.835047021988903, 64.59414505189466, 72.73826029992873, 81.84192457506734, 88.11960743319604, 90.20530423810406, 93.84347515721475, 89.43188344278644, 93.17879815255442, 89.75743232234832, 90.33729199440249, 84.5073006230016, 85.12435220902967, 83.36118405865085, 87.19684631593766, 85.44304478553035, 84.91172052198841, 80.08922915304862, 78.79184246063232, 77.35577644840365, 79.26236998650336, 74.64144922071888, 73.89922695775186, 80.69145417982533, 87.8157727949081, 82.24333993850216, 88.21938468563943, 85.43570210856777, 83.9545209946171, 81.32265767743512, 83.04839857162969, 83.62906625193935, 82.75634673333938, 81.2846028420233, 78.15805804344916, 78.79749851842081, 80.54330625841695, 75.76465129852295, 76.77770537714805, 79.99251919407999, 78.78862611709103, 81.31154168036677, 81.98080001338836, 77.5389511354508, 75.52515137580134, 77.757340861905, 75.39838821657243, 72.68777155107068, 80.792125732668, 77.55326778657975, 77.81962810024139, 71.35117684641193, 70.00829850473713, 67.1302358565792, 71.76075858454551, 75.02831259081441, 74.54604148864746, 72.10009851763326, 71.51863067380845, 70.79744015970539, 72.91938750974595, 72.89917945861816, 77.08514075125419, 76.4461160475208, 75.61117679842057, 75.58873299629458, 78.08084226423695, 74.56934821221137, 75.36612279953496, 76.50531245816138, 75.3729320341541, 73.10938712089293, 73.55981642200102, 70.18725272147887, 73.99882378116732, 74.36245103036204, 78.36744200798773, 77.18854227373677, 73.0419223539291, 74.14111168153825, 75.86007472007506, 67.3828992535991, 70.26326041067801, 74.76829082735124, 73.93209641979587, 75.3778349968695, 70.50458031315958, 66.14879608154297, 66.69266408489597, 61.83882513353902, 59.97194951580417, 57.409265041351325, 58.99095296859742, 46.513709099062034, 44.26945047993814, 57.52914051855765, 66.45019100558373, 65.49216385810607, 68.06177523828322, 68.18813047101422, 75.20590966747653, 62.862626506436264, 30.035557439250333, 8.927991121046006, 0.1403689114076476, 0.69593443385055, 1.1704825730093065, 0.9434994238038218, 0.9038536382778999, 0.3235387567791247, 0.03991583151923072, 0.02225354227477745, 0.06542017788536127, 0.4190126788471976, 0.01962698109808468, 0.0702504618393798, 0.6953027483917052, 56.26214042786629, 75.155773931934, 90.98693847656251, 49.25365724871236, 28.48012781912281, 39.29917204764582, 51.07885768336635, 67.70572600826141, 34.250159878884595, 0.2129643224179745, 0.005008476484011138, 0.0501239990755435, 0.024004495597534606, 0.03258915430295371, 0.07806361637889378, 0.024923875800243793, 0.013092179283229335, 0.021976984534112197, 0.03475681923690342, 0.034090924121799974, 0.03663282300676069, 0.031500771273708636, 0.17649156582211295, 0.2607106603682041, 0.17751191832846214, 0.1410836407974843, 0.16653133496161432, 0.2360649530084864, 0.12947344040918735, 0.14299659298792963, 0.2578164414773064, 0.16071167143602527, 0.4970369259676626, 0.1764248855291836, 0.2791274447114237, 0.4072816970367586, 0.6126555283704113, 22.201938975241877, 85.79984711062524, 74.55926772086852, 66.78349048860612, 72.21966804996615, 76.1623796339958, 95.39334481762302, 38.41212803317655, 0.5574661252960083, 0.29503593461648114, 0.213033530801054, 0.803441636023983, 0.7593803648506442, 0.32118110587039306, 1.699270288790426, 1.6028374697892898, 0.9719990590407003, 1.8535527971483048, 5.5351458249553565, 8.328400946432545, 2.8059829675382186, 1.3742835339038604, 27.090028062943492, 75.58281021733438, 78.61232342258577, 90.07546594066005, 93.835081285046, 98.21594515154439, 98.60003148355793, 95.63311146151636, 95.55689196432792, 95.82809248278218, 94.00330389699629, 88.70775899579449, 89.06918187295237, 86.30962187244047, 91.03010808267902, 90.10935521894886, 88.01835536956789, 82.44810335097775, 83.47949058778825, 87.61804611452165, 89.04675376030707, 77.64288610027683, 80.89326012519099, 85.57366755700882, 91.53232835954236, 86.35654126444172, 92.92285565407046, 90.81066716101863, 89.47830077140563, 83.36800113801034, 85.0009544434086, 88.83334544397171, 86.85363892586001, 88.81258041627946, 86.87294483184816, 81.38343872562533, 84.22368188058176, 80.58867239182996, 80.21723962599232, 83.74077535444691, 81.37746887822306, 84.29244102970247, 85.59345199215798, 80.6346425702495, 77.73787021636963, 83.76473319145941, 77.24744058424427, 75.0820255279541, 85.77666590290686, 79.87291828278573, 80.91007924848988, 72.4649573910621, 69.38811686731154, 68.5432618664157, 72.45401397828134, 76.7956070746145, 74.97476439322196, 75.39496790978217, 75.64906689428514, 74.27098135794364, 74.79135436396446, 76.43980103154337, 83.29033036385813, 81.29662882897162, 78.83967184251355, 79.35842098728304, 83.08365283473846, 78.83099555969238, 78.4642461038405, 81.38229339353501, 76.18509015729352, 78.5204928921115, 77.511549457427, 74.65781334907778, 79.4936643108245, 77.50809777167537, 81.09809414032968, 82.53261473871048, 76.90246028284874, 77.91371791593491, 77.20903273551696, 68.26001967153242, 75.22798476680633, 78.09149542162496, 77.08119484686083, 79.8244377874559, 75.56002124663323, 70.50043044551727, 73.42468292482438, 73.55858479776691, 67.48797170577511, 67.25397094603508, 68.4755225335398, 54.34729030055385, 54.54811565337643, 64.73219287010932, 69.19910569344798, 65.40533827197167, 73.61107395541283, 74.23609579763105, 80.30410443582844, 66.69193452404392, 37.97611344245173, 10.083868503570557, 0.2873199583301621, 3.092660668396181, 5.759424009630758, 1.1748937685643475, 2.420232815127219, 0.29581176717915847, 0.27191411403398363, 0.17869405328266083, 0.2376567151757979, 0.8147025769276004, 0.2536710324667154, 0.272035063995469, 1.4206155509718004, 68.67104484188941, 83.99255229580788, 99.39642952334498, 59.25955295562745, 40.381024499093336, 62.41818274221113, 62.41634315060031, 82.99841973089403, 44.86673332029774, 0.5069424734721261, 0.11123173780018285, 0.2083133260208753, 0.12233399125116488, 0.16148915874861902, 0.10561570810574679, 0.14030816063525217, 0.0870733006647037, 0.23945473885584265, 0.17837365999096827, 0.13282026404574995, 0.25875860705010356, 0.1175999892274699], [0.04540929863710077, 0.045251407915906566, 0.02957438573151106, 0.022157978551882892, 0.07012573506442771, 0.013232419338648119, 0.03461767468721636, 0.09916317934590964, 0.05636386182760039, 0.024101419126494758, 0.05249725902573236, 0.058843148346509666, 0.06298872206600444, 0.03797032825288273, 0.10418479375901724, 30.383195146437618, 77.8546940895819, 44.34694082506242, 50.751959508465184, 52.459249573369185, 63.09725092303369, 31.677032093847956, 8.460453421838823, 0.0422253797671968, 0.12257266594397447, 0.11775100047910407, 0.1990951279238347, 0.30536647705781844, 0.06271814364158819, 0.07908683405407975, 0.6678620305272841, 0.030295567496890025, 0.07142247677209877, 1.316675438034919, 1.7619224301268979, 0.5805367099181299, 2.8899866534817606, 33.56747527276316, 49.717940361269065, 60.09090715839017, 78.33749078935193, 81.33380505346483, 82.9617141908215, 81.25920941752773, 82.78454857487833, 85.05768760558098, 79.71200696883663, 76.09467168008128, 80.1268760619625, 79.54117205835159, 80.620176869054, 80.00819298528856, 79.502348438386, 79.96400356292725, 79.04914209919592, 80.89884558031636, 69.84124475909819, 69.75685104247063, 76.20834981241535, 72.6991464245704, 79.61623837870937, 84.02906956211214, 79.19177516814202, 76.95747544688564, 76.31399493063651, 80.1298805975145, 80.46751822194746, 80.90072831799908, 78.43947241383215, 78.57676321460356, 71.89907704630207, 74.78132094106367, 77.92922696759625, 71.35710747011247, 73.75677431783369, 75.01243483635687, 75.27746154415992, 77.89427080462056, 75.80141959651824, 76.4186986800163, 71.1554584195537, 70.93094979563068, 76.52888590289702, 78.39834244020524, 71.81727993872859, 74.75966945771249, 80.60751545813777, 76.3192665961481, 67.08926277775919, 75.01490592956543, 71.1132223375382, 71.44489795930924, 72.41377046031337, 73.99412478170088, 69.31865953630017, 65.59406703518283, 66.55419657307287, 66.63232234216505, 69.12073673740511, 72.59214416626962, 69.66500482251568, 68.60623159716206, 69.68213773542836, 71.87476619597405, 70.17422260776644, 70.88415591947495, 72.0250008183141, 70.37079611132222, 70.2683202682003, 68.33892991465908, 70.90686644277265, 68.95746415661228, 72.05848217010498, 71.56029408977878, 75.0231429069273, 75.63163588123938, 71.3936561153781, 71.7140039320915, 73.3307735381588, 63.92796185708816, 65.4468487155053, 71.12047087761664, 73.41451614133774, 73.4603137354697, 66.13762517129221, 63.229226912221606, 54.44250583648682, 57.232962346846065, 56.15243173414662, 47.51549420818206, 39.34372625043316, 30.26729891377111, 39.971207418749415, 61.42537201604536, 69.91057657426404, 60.02803548689812, 56.55484730197538, 71.36841958568942, 48.90824940896804, 22.317344911636848, 11.850973733009832, 0.22603367515388997, 0.21016034868455705, 0.2774832974518499, 0.29837172658693406, 1.5328468190085505, 1.2217274812921401, 0.2310868830329949, 0.05546204227533552, 0.11554543334510058, 0.5615496190805589, 0.5715403862057195, 0.15676846367216882, 0.7465555014148836, 10.839583719930342, 69.19566969717704, 87.99500157756191, 57.33349269436252, 41.48173962869952, 57.94094624057893, 54.3551036619371, 55.212039562963675, 8.19766491651535, 0.05954610296495019, 0.03755287928206306, 0.0023347386553312743, 0.044072283687250274, 0.05087935410800481, 0.0731193385417423, 0.10386077687144281, 0.07722347839585236, 0.05818096492739935, 0.1111997842728611, 0.031048754500525615, 0.07082200173528926, 0.07884707917729694, 0.021566673587527008, 0.019038941583506042, 0.009096934997116127, 0.03493511470996084, 0.021121769940720934, 0.10765927828728192, 0.11860047707394247, 0.04414840218340678, 0.010818046322392841, 0.004154834286084459, 0.008968982992002801, 0.02730898138496184, 0.023296523103190046, 0.08371847140933238, 0.06603820399651605, 37.103425302813136, 85.28614997863771, 61.98460002099315, 53.3842582087363, 28.56297023834721, 80.23981678870418, 52.2873281663464, 9.062821615126825, 0.07031808442045605, 0.12186844728045887, 0.1643795625216538, 0.2336211325300317, 0.31700102372034905, 0.21891762232107503, 0.1830553611920726, 0.7970719520122775, 0.07654919078753841, 0.04152057887685876, 2.7966891565630516, 2.0795259360344183, 0.4407958373908074, 6.2501012413732475, 49.4789150453383, 63.655870960604766, 74.46517006043466, 87.60016795127623, 90.18972458377962, 89.87221656307098, 91.32733744959678, 86.68336099193942, 88.67937672522761, 87.33095215212914, 80.44310538999497, 84.48089522700157, 84.06230772695234, 86.15879104983422, 84.95810647164622, 83.53798881653817, 85.1569627946423, 83.29993232603996, 85.47563183692195, 78.14211753106888, 72.2640771250571, 75.73448042715751, 78.21121400402438, 86.47112154191541, 87.99435830885365, 83.82034455576252, 83.53856148258333, 81.27504010354319, 84.07130564412763, 82.92013706699495, 83.24840807145642, 82.67946827796199, 82.49617591980966, 76.31814479827881, 80.5451419276576, 81.32987483855217, 74.9949489101287, 79.1979960472353, 78.17339451082292, 79.76794781223421, 80.81864879977319, 77.8257469977102, 80.08806813147761, 75.89570553072038, 72.80341871323125, 79.78741845776959, 80.50184680569558, 75.50944620563139, 76.47245868559807, 79.98174836558681, 77.33008492377498, 71.65590578509916, 81.19701631607549, 75.4508852189587, 75.82034895496984, 74.82744801429011, 76.11052590031778, 72.63017546746039, 70.10123514359998, 72.03321426145493, 72.75655423441242, 71.66567248682823, 72.94970743117794, 72.66184468423167, 71.33100801898588, 71.71070129640641, 72.43965810345065, 73.43936827874953, 72.43464531437044, 73.32844365027644, 74.96958686459449, 72.74436350791686, 72.20586130695959, 72.4200148736277, 71.005231641954, 74.93726653437461, 75.23377418518066, 73.65691861798688, 77.7007959735009, 75.88823733791229, 74.93601137591948, 76.52108823099445, 66.25459024983068, 66.95494513357839, 74.80523955437445, 73.81073044192406, 75.86180056295088, 72.48730705630395, 71.38520733002694, 63.73869572916339, 62.91068338578748, 60.04203442604312, 57.627411580854854, 49.39248169622114, 40.432478151013775, 43.3965426875699, 64.53487411622079, 75.15242422780683, 72.78737621922647, 62.71764001538677, 71.35489525333529, 63.92251760728898, 44.7667246480142, 15.002834489268643, 1.012249870165702, 0.2681345426507535, 0.5132810236705888, 0.3952522780145369, 2.238780538881979, 1.05405890412869, 0.14513171067641628, 0.13264821601971505, 0.3456395660196582, 0.9137592164258804, 0.14018413100031116, 0.30654095113277435, 0.8731370671622215, 14.518104061003655, 79.53348421281385, 99.53714847564699, 69.3498266896894, 36.16572779993857, 56.52240145590998, 53.85199692941482, 66.11241217582457, 10.304321396735407, 0.17796449243061005, 0.029539086315180027, 0.02555447149901621, 0.07772414749788661, 0.03114029243137808, 0.056112630953711856, 0.025303876478104823, 0.0922779334829219, 0.06071712581380721, 0.04662702603626155, 0.002840410311511087, 0.09923425698352438, 0.07232234663059635, 0.17335837346411523, 0.1455364042832967, 0.1116149273190287, 0.15142953564082423, 0.13031708707492198, 0.21051870929377697, 0.2515946277567456, 0.12482905535087471, 0.10060026070042964, 0.08895364815309163, 0.17188445094131655, 0.12424818450404752, 0.22617344023479571, 0.10190840945729326, 0.17084105451020504, 44.17530575106221, 100.09335625556209, 60.51763357654695, 65.7956454830785, 82.35712789720105, 93.37759171762775, 70.55445717227074, 10.467176245104882, 0.172770875956743, 0.35106411203742033, 0.8402737951086414, 1.0778102038368103, 0.9294577675961679, 0.39731804942411764, 0.5840271290752196, 2.1789303181632875, 0.17114768886277754, 0.1664639651895531, 5.601159805251706, 5.2196210526650955, 0.7759694166241154, 11.214654484102804, 64.59420388744724, 72.4015248206354, 87.13895997693463, 92.98231878588277, 97.92076326185658, 94.34655051077567, 94.0944911587623, 90.97164123289048, 92.04198545025241, 91.69454190038866, 83.35037400645595, 90.77594634025328, 87.4732243630194, 90.05724260883947, 89.77305904511483, 87.82699077360093, 87.05763355378183, 85.43049320097893, 90.25816994328653, 80.3823321865451, 79.62511078003915, 83.45373630523682, 87.24621326692643, 90.82204203451835, 91.90560463936099, 89.42581161375969, 89.17287365082773, 85.0070890303581, 86.41389416110131, 86.83572938365322, 88.24036936606132, 84.79968194038638, 87.04047710664811, 79.16445193752166, 82.99840404141335, 88.53182500408542, 79.04117184300577, 83.51989884530344, 81.74279843607258, 82.97710557137766, 83.21824504483132, 82.6145608963505, 82.9864800360895, 78.52701971607824, 75.72911462476178, 81.87218958331694, 83.59722445088049, 79.41353028820407, 82.6841280537267, 86.03974711510443, 82.5909403831728, 73.05885130359282, 81.35376207290157, 79.00909469973656, 77.97122770740141, 78.69970598528462, 81.56230665022328, 76.29539505127939, 71.42585092975249, 75.0247589234383, 74.54038543085899, 76.93584749775549, 77.78654683020808, 77.64309006352579, 75.75564553660732, 76.36922190266272, 78.13451597767492, 74.93210469522785, 76.43094431969428, 77.19896008891445, 78.56035986254292, 76.65266806079497, 75.38695058514996, 75.32314146718672, 73.46916260257845, 80.60907656146635, 78.55999900448707, 79.45100461283039, 82.89146454103532, 79.07346863900462, 80.53695986347815, 78.69390872216995, 68.03459321298908, 69.32737504282306, 78.00332838489165, 76.50927405203544, 81.89627293617495, 75.08387688667544, 75.04943063182216, 70.41206729027533, 74.99436839934319, 66.73380190326323, 63.67677719362321, 55.00347145142094, 50.5334678003865, 59.40941495280112, 74.15839364451747, 73.32400352724137, 72.49537144937824, 65.42731923441734, 77.65833239401542, 67.26240404190557, 51.01508386673466, 20.649470744594453, 0.8534551652208452, 0.3707061161197001, 1.86651328879018, 1.1269100659316587, 2.8368012751302416, 1.9623370372479962, 0.4822202032852558, 0.22458121841472967, 0.5352685744723966, 1.719681812870887, 1.038457799342371, 0.9980437195589467, 0.8830249946444266, 17.194519619787894, 92.06494700524115, 99.98947620391847, 78.10250943706882, 60.53540583579772, 75.60439109802246, 65.94058098331575, 81.38386234160393, 15.024129036934147, 0.19835551599821738, 0.09588410086449116, 0.11086766217504779, 0.22555604997661807, 0.185208298085678, 0.137673691515961, 0.18462479955727057, 0.2719326533617512, 0.2077077181949731, 0.2122043325535713, 0.12216108520665478, 0.24121310982492664, 0.22211620794428935], [0.022868785571547288, 0.048282235605461944, 0.05841094835270798, 0.07051725961988972, 0.09166937621851122, 0.07904492904462161, 0.05082272871908161, 0.06759611273845358, 0.09205601313301633, 0.01579630111659607, 0.11215426087860139, 0.034340661124236165, 0.05582106938104957, 0.0070997614943001785, 0.11250717460267967, 44.8041283699774, 65.73942222902852, 48.37417556393532, 60.02224606852378, 44.83677817929176, 64.71340079461375, 2.7880753865165095, 1.6112710559560408, 0.10126900949305105, 0.18617249634717742, 0.2210127808634312, 0.3065986528752312, 0.08439620641330559, 0.2436278036405002, 0.26770360287158723, 0.3662622852190849, 0.06675380672658644, 0.2717443183064461, 0.929784550061149, 0.22406561059817193, 1.497130451663848, 23.67379857647804, 49.13737858495405, 59.573624980065134, 65.90758600542623, 78.22625237126505, 78.07982244799214, 81.4462515615648, 78.5416030883789, 83.17505974923411, 83.42314966263311, 81.8198416309972, 77.71414772156747, 76.91872242958316, 76.24925228857225, 79.75868317388719, 83.97729427583756, 81.12220887214907, 82.3378376806936, 81.7570052608367, 75.73863813954016, 73.11933425164992, 68.18623204385081, 71.75296875738329, 72.81000045038039, 83.07922840118408, 82.91382989575787, 81.05646994806106, 80.58679749888759, 80.12103173040575, 80.14637024171891, 75.96214263669907, 75.92499779116723, 75.61025896380025, 72.01108424894272, 78.14727152547529, 81.25737374828708, 72.93300597898423, 74.38799350492417, 74.59281183058216, 76.60730192738195, 83.05727097295946, 77.92810516972696, 78.6711197514688, 73.86781661741196, 69.71375203901722, 71.69319968069755, 78.46272422421363, 71.54604019657259, 70.36380644767516, 72.10336192961663, 74.09692225917694, 64.78447414213612, 70.79626344865369, 70.16538943013838, 70.97342121985652, 73.65858170293993, 72.409346026759, 68.41962875858431, 64.92301225662231, 65.6705257969518, 66.85275954584922, 67.46067985411614, 64.31437807698404, 69.17339847933862, 70.38048436564785, 71.10867238813832, 66.93848686833536, 66.95424695168772, 68.81170103626867, 71.17797282434279, 70.92299522892122, 68.68141558862501, 68.79912591749623, 71.0240041055987, 69.06882024580433, 68.30939446726154, 67.93537293711017, 71.34130816305839, 71.64263248443604, 73.61596907338789, 72.39124821078393, 69.77181880704819, 69.96166152338829, 72.26587357059603, 67.45824013986896, 68.57074199184295, 71.2144979353874, 71.10575414473011, 67.94602609449818, 61.57457505503009, 59.36806924881474, 53.248948204901914, 51.16724045045915, 53.48324706477504, 50.57931246296052, 37.774762492026056, 27.06780391354715, 38.187023208987334, 57.85705066496327, 68.6367162581413, 54.67760093750493, 57.74813429001839, 58.26688343478788, 26.162114912463775, 18.987203605713386, 3.645827630835195, 0.20458805494971816, 0.7488387498644091, 1.2502307324640214, 1.1351566040708174, 0.26916520670056343, 0.3150518815363607, 0.4452535191610937, 0.402449551489084, 0.31582608999263856, 0.14025485623748074, 0.3892987023197836, 0.14735532684191582, 0.1304445334620053, 46.06099697851366, 93.86067867279054, 42.153924049869666, 37.228368482282086, 50.70391831859466, 45.1585929624496, 44.250387760900686, 1.9146907810241947, 0.021544725168496374, 0.03772351770631729, 0.03131207615707911, 0.05399520606583646, 0.09331773696166855, 0.060374830068359454, 0.1301352331234563, 0.04103488296330456, 0.02019529576383291, 0.03892403494025912, 0.04043754505654497, 0.041862694591644316, 0.06506276722516745, 0.05643692363293902, 0.02168079770560707, 0.07810235744522465, 0.030762300819098472, 0.034116733623968984, 0.012316193502967157, 0.06715257847381216, 0.04631071216276577, 0.046613696106379075, 0.051162075026020895, 0.05926086161766322, 0.12459340670536603, 0.03677360698460572, 0.017121511609143308, 0.17839386939041077, 54.42215265766267, 73.93202581713277, 65.68807055873256, 46.16523396584296, 44.095964047216604, 85.898039725519, 8.571001502775378, 2.1455833075507997, 0.12046117440707262, 0.3314393296116783, 0.11067275408535235, 0.24071078597297593, 0.14876069981724988, 0.3955381513843614, 0.09892522477574887, 0.5330455711772365, 0.02716269498060067, 0.9096659167158989, 2.82143906720223, 0.15092088390261899, 2.5038714754966, 36.152352517650975, 64.39166053648918, 69.52801996661772, 77.10266590118408, 87.17975262672671, 83.40574218380837, 88.56955820514311, 86.29756450653078, 90.99895661877048, 87.7539562409924, 85.77837605630198, 80.65764334893997, 80.27723620014807, 80.77329051110053, 84.62956874601304, 87.02868646191013, 86.49753478265579, 85.54832904569565, 86.88947369975429, 79.71533313874276, 78.00111616811445, 75.59148650015555, 75.45817298273887, 80.77496144079393, 87.73301862901258, 85.0349457033219, 84.24914590774044, 84.85497167033535, 84.76674972041961, 84.08354343906527, 80.94471377711143, 80.2926197359639, 77.63102485287574, 77.34094988915228, 80.01611617303665, 80.84468549297702, 76.89186203864314, 81.12791984311997, 79.47286790417087, 80.46514911036338, 85.24784411153486, 81.54085913012105, 79.19673304403983, 76.74224715079032, 75.39132010552191, 77.52428931574669, 78.93025505927302, 73.60031097166001, 73.82299177108273, 75.999358084894, 73.21794263778195, 67.97687945827361, 71.81749174671789, 70.56828744949834, 72.18806159111762, 75.67417006338798, 75.44749629112982, 71.81920974485337, 67.39993802962765, 66.9848257495511, 71.63451317817935, 71.18825727893461, 70.02882034547868, 71.77914665591332, 70.67185371152817, 73.13833421276462, 69.18675022740518, 68.33306989362164, 71.67456057763869, 72.84938889165079, 73.4091817179034, 72.25461636820148, 71.68196601252403, 73.27494252112605, 72.45719109812092, 70.09783837103075, 68.60375265921317, 74.19808018592097, 75.61238488843365, 73.77279327761742, 74.49026538479713, 74.03606276358329, 71.70306836405109, 75.21399759477185, 70.02245826105919, 70.89036110908755, 72.9697193637971, 71.75466322129773, 70.99398228429979, 67.52313183199975, 65.12219805871287, 62.81731136383549, 58.52745433007517, 58.45663201424384, 58.72699706785141, 49.23404539785078, 39.94568063366798, 45.025397116138095, 64.75837076863935, 76.51196479797363, 66.81635995065012, 60.13578299553164, 63.24759929410873, 48.753080444951216, 28.472059503678356, 7.223160872536321, 0.28040920173929584, 0.830697205758864, 3.3766772862403625, 3.8479826671461907, 0.3454676558894496, 0.5805823074713831, 0.7262743348556181, 1.3481408141313063, 0.7907259860827077, 0.2973808991091867, 0.05772805374656474, 0.1281995357825391, 0.22561186714278114, 53.007287056215354, 101.37640276262837, 53.55158259791713, 38.83310817903088, 55.22643858386625, 48.96335086514873, 52.8743657758159, 2.2589015624215527, 0.06894631972236019, 0.06438126306860678, 0.045225920170665755, 0.05693668109034339, 0.07393516089406706, 0.020024492630674955, 0.02050878085766829, 0.05253847455605865, 0.039252767099007484, 0.03081329929221782, 0.028448284363314032, 0.04578926675622502, 0.0882902619759402, 0.15756073648170119, 0.27131104961999003, 0.13249148975216574, 0.12620657336928193, 0.19336589341682775, 0.15771773854090324, 0.14887231882781754, 0.16665986919355008, 0.15958097162506274, 0.14344158281962718, 0.20689137490285983, 0.19191412615679926, 0.10681780731125225, 0.18178469711734405, 0.4754902434445197, 65.09555732050251, 83.61751094941171, 65.42012560752131, 78.40882301330566, 67.60056726394161, 99.06249461635467, 20.08547313751713, 2.91995037467249, 0.2240523419553234, 0.9468157877845149, 0.390330990475993, 0.6253554888309971, 0.38985886581001744, 1.670996986569897, 0.41650404733034874, 2.43150252007669, 0.2465195863717987, 1.310437398572122, 5.092392111978223, 0.6306354893792061, 3.201203927878411, 50.66815414736348, 73.97682712924096, 82.17563982932799, 88.36195499666276, 92.585798540423, 91.68699526017713, 95.40467262268068, 92.7635132881903, 94.24174477977138, 91.57922421732258, 87.48867065675798, 85.69906573141776, 83.28087745174285, 86.9838773050616, 88.95545667217624, 92.21984924808626, 89.5341553226594, 90.19120723970475, 90.23605562025502, 83.58334710521083, 79.92905524469192, 80.14258123213246, 84.22121863211356, 87.56099916273548, 94.38215778719996, 91.228893803012, 88.11918381721743, 88.04876158314367, 88.87503239416307, 90.00785212362968, 84.31529275832638, 82.78498788033762, 81.74720718014626, 81.7889411987797, 83.03292089892973, 85.86003195854926, 81.58294616207, 84.39209276630034, 81.77479713193833, 82.99481899507585, 88.87639737898304, 83.88142370408582, 83.90218088703772, 82.10779067008727, 75.79027222048852, 78.30091076512491, 82.69006652216758, 77.51936281881025, 79.69292856031849, 77.45861314958142, 76.70099950605824, 71.16622924804688, 74.87839175808814, 73.96425985520887, 75.45925555690643, 79.65081799414851, 77.27596406013735, 76.14555266595657, 70.29416084289551, 71.61591329882222, 73.4789606832689, 73.20692862233808, 72.60511936679964, 74.01012020726358, 75.81992533899124, 77.57127146567069, 72.98181595340853, 72.42530222861998, 76.15830821375694, 75.60973336619716, 74.55653775122859, 73.91104113671088, 75.64610158243488, 76.38855918761223, 77.33826698795443, 74.31495897231564, 72.88275257233651, 78.2052755355835, 78.09841448260893, 79.37818973295151, 79.5022778357229, 76.17283667287519, 74.91878432612266, 79.3228764687815, 72.4872442983812, 74.69289502789898, 77.78989653433524, 76.5919497705275, 78.82366072747016, 73.95102577824747, 68.60190914523217, 68.74109837316698, 66.99550244116014, 70.07681446690714, 66.65204401939147, 54.83464871683429, 49.15209139547041, 58.13924950938071, 70.33394936592349, 73.09965179812524, 67.01181165633663, 67.51534984957787, 70.10477312149541, 51.733752296816924, 33.57002481337517, 7.699685212104552, 0.4374656225404432, 1.5772132383238886, 5.484819854459455, 6.742746522349696, 1.1310251225386898, 1.2953047718732589, 0.930767287650416, 3.0271431130747644, 1.750493869185448, 0.4858624610689379, 0.6454754704909941, 0.45810819873886727, 0.6800825425213384, 64.92250627087009, 104.3883280600271, 57.154538477620775, 54.41319004181893, 63.00362786939068, 58.558915661227324, 65.42831943881127, 3.926634769285879, 0.11852984376732381, 0.3172367949399256, 0.1540734736068595, 0.1872593759288711, 0.2846196516146583, 0.18534349728255503, 0.24095962665254073, 0.1148368479804166, 0.12501675455320266, 0.11969353898518509, 0.10241008213450832, 0.20488774854569666, 0.1701210237919323], [0.027282020835686597, 0.017733822704382965, 0.014202781735108265, 0.03669783705845475, 0.06784343656392829, 0.008790406939243118, 0.05437946427733668, 0.019100238193547534, 0.027965269757494814, 0.09471308950695301, 0.048481977709959594, 0.026825461161112594, 0.055821479238089056, 0.05245684405728694, 2.2549941462855188, 62.41569988189205, 56.33949349003454, 53.37564076146772, 40.7468992663968, 59.88680662647371, 49.52529707262593, 0.554927064766807, 0.6315669910080972, 0.11528382197983804, 0.7583136640248761, 0.2628693122777247, 0.3056546486914158, 0.3687416215337092, 0.4477555623217937, 0.23070037635343693, 0.7428527226851833, 0.2976976305006012, 0.498361032335989, 1.0664111832457206, 0.4147780205934279, 9.724354840094044, 39.66854556914299, 52.464081933421475, 64.12666520764752, 79.57035449243362, 74.00329528316375, 85.01416498614897, 78.93314192371984, 77.15984621355611, 81.22112320315453, 82.6324547490766, 78.5586497091478, 75.63124364422214, 79.03251909440564, 81.17889496587938, 81.9131705068773, 78.70284388142248, 78.86015445955339, 80.65906324694234, 75.09288264859107, 73.44571467368834, 77.21393569823235, 76.59500921926191, 73.92977437665387, 71.64343264795119, 78.8747456765944, 84.0748514667634, 84.09283945637365, 82.34703171637751, 81.37992428195092, 73.37740267476728, 74.82536131335844, 76.62971435054656, 72.88214852732997, 78.91444790747859, 78.50701562819943, 72.387129722103, 81.19417652007073, 79.27558837398406, 80.29178034874701, 77.98765459368306, 78.37578096697408, 78.46675642075078, 71.51127230736518, 74.88007837726225, 78.45694265057965, 68.79651361896147, 67.48131152122252, 66.83984710324195, 71.03076627177578, 68.15626513573432, 65.55947957500335, 68.80970847222113, 70.76148771470594, 72.93075453850531, 66.01220346266224, 64.88471031188965, 70.42545041730328, 68.0765547290925, 67.6078236487604, 68.0113806263093, 65.62745425008958, 65.48392295837402, 66.70094028595956, 64.53506631235923, 66.27926195821455, 66.58133152992495, 66.76352562442904, 66.28562404263404, 64.41437105978689, 65.3912648077934, 71.41380925332346, 70.93331106247442, 67.83873358080464, 66.3604393313008, 67.34122014814808, 69.40282575545773, 68.73388905679026, 68.03659362177696, 72.86241116062288, 74.40624821570613, 74.73999484892815, 69.29833381406723, 66.29259017206007, 70.7907485961914, 68.98675641705914, 61.75180735126619, 67.79769774406188, 71.26828931993055, 71.94765167851602, 63.174921697185894, 64.94764081893429, 60.64498116893154, 52.98108562346428, 45.919709282536665, 43.79165087976764, 41.84964226138207, 40.6536998287324, 36.32986330216931, 41.82712393422281, 61.02903612198369, 57.38125147358064, 50.866606466231815, 54.1616484426683, 42.81699680512951, 10.025558548588908, 12.634848625429216, 0.6786712859907459, 1.1526656967978324, 2.4783103696761595, 1.172276076770598, 0.4485448780319383, 0.46809522735495723, 1.6408670549431157, 0.46978043692727245, 0.3006059147657887, 0.1135869219057983, 0.20445953603954087, 0.23594843103520333, 0.29675895828873883, 11.918100195546305, 75.3739518503989, 29.876789700600412, 41.74240858324113, 36.05298319170552, 49.86566074432866, 47.114016086824485, 1.519672435618216, 0.071242829153855, 0.08515981221271139, 0.0273608589439743, 0.04552543373598207, 0.025653114895366376, 0.0629466217041256, 0.05022508820759193, 0.08831013429669604, 0.04090013192786325, 0.023783519450995712, 0.016662429590078614, 0.009975197345709369, 0.039920853225574385, 0.03574331065699939, 0.043726743559443185, 0.046829257926513115, 0.08567249357339837, 0.04740212698497119, 0.16493345941266707, 0.03960632050650255, 0.06394499897836678, 0.05806019882701578, 0.019850573434884992, 0.0776616653667823, 0.09389265530532408, 0.05032779761560021, 0.1185470577629824, 3.073463853328459, 71.94684367026053, 67.4570006708945, 63.151018773355794, 34.783398259070616, 67.820235683072, 65.50258951802408, 0.568201836318739, 0.276753951104418, 0.1828420057051605, 0.5573379741080347, 0.6453824367734694, 0.12081674645624815, 0.16443948591909102, 0.6071558750925526, 0.025043033115986376, 1.0327767364440426, 0.8912806032646088, 0.9378268185161776, 0.8594428471499874, 0.7263926801181609, 15.694668023817002, 59.48233573667465, 65.64212391453405, 73.52682144411149, 84.64557201631608, 79.68385219573975, 89.92003810021185, 84.11923700763334, 85.61337763263334, 86.69396708088537, 88.56348637611636, 82.56808080980855, 83.37858369273525, 82.02503650419175, 84.37565019053798, 83.78298005750104, 83.83353940902218, 81.14243261275753, 85.09937455577236, 77.79204599318966, 79.1400626397902, 83.77921458213561, 83.82639285056823, 78.3723920391452, 76.42717099958851, 78.98116742410969, 86.88717519083332, 85.61909644834458, 84.70245422855501, 84.55230589835875, 79.05541789147162, 80.4215794224893, 79.78121326815698, 77.11574308333859, 80.2873323809716, 81.02533417363321, 79.31358829621347, 85.61992014608076, 81.60154604142713, 82.95504616152856, 81.09404625431185, 80.40290894046908, 79.42597204639067, 73.88632235988494, 78.69949417729532, 80.02405505026542, 73.08160105059224, 72.10930039805751, 72.40237989733296, 76.37019465046545, 69.7224126323577, 70.8220334206858, 72.21949546567856, 75.64545046898627, 77.08838062901651, 68.63034632898146, 68.22966837113904, 71.1145559433968, 71.68917532890075, 69.40876422389861, 71.4178414498606, 71.26022492685627, 70.46738839918568, 69.58429028910976, 68.1899739849952, 65.38359657410653, 68.44599493088262, 66.03377649860998, 71.69709851664882, 65.72499967390492, 67.1067879276891, 70.6328731967557, 74.20549346554664, 71.88033596161874, 68.64733803656794, 69.89999401953914, 71.89891230675482, 71.86765101648146, 72.79481303307318, 73.23439305828464, 76.34295771198889, 73.44165894293016, 72.38066565605902, 70.54922473046088, 72.71239619101249, 70.04314484134798, 67.25721866853776, 69.45575421856296, 72.4919903662897, 73.03807058641988, 70.39323206870787, 70.46203044153029, 67.16851818946101, 61.46956143840667, 54.611748264681914, 51.30934007706181, 55.03776081146733, 50.145725819372366, 46.57925190464143, 49.42679851285873, 65.66008444755309, 71.29982517611596, 61.591958999633796, 55.63313737992318, 54.637922240841775, 29.021765955032844, 19.383321808230495, 2.1114135797946685, 0.696911839467864, 2.7399358922435395, 0.7422304754295658, 1.364293747371243, 0.6621176581228934, 5.083885471667013, 0.8101186132238758, 0.04484577968175854, 0.2169196190492761, 0.9359341523339673, 0.18239156132744205, 0.3492918748769068, 13.925215255829597, 81.68997979933216, 36.36672965941891, 39.30107439717939, 45.356409857350016, 54.75403616505285, 55.69202784569033, 2.1801227186956713, 0.07800167050933646, 0.04993207872875276, 0.13568541756080044, 0.058819541347122965, 0.010910216275782836, 0.10315522521493897, 0.03547192784026265, 0.05157218870496558, 0.044536276329909606, 0.032882642586745565, 0.025554157402967254, 0.03050666302442551, 0.09366918745781146, 0.1282708968726858, 0.18317102514688047, 0.1616519983978041, 0.17401376168333715, 0.12866256698485345, 0.3411137637111449, 0.15630465872105093, 0.1748583736198564, 0.2591809360010009, 0.1959367772384036, 0.1815486041408393, 0.2458881000958143, 0.14839222684742945, 0.24545126143963109, 4.708164574638491, 87.24252623896446, 70.56529860342704, 68.39949131011963, 60.04248157624276, 80.0069142926124, 78.46925104818037, 1.7839889492719405, 0.8161379192625323, 0.28264755743645853, 1.580913749433333, 2.1093678186016698, 1.0525574943711682, 0.9971377746232095, 1.4824329629059763, 0.36361958831548696, 2.550567537546158, 1.2622690993931986, 2.197417429377956, 3.44205976493897, 1.2730889575135325, 24.477121560804306, 67.02644209707937, 73.666959885628, 88.66091020645635, 93.43816095782866, 89.31088616771083, 98.79478500735377, 93.84966465734666, 90.37070274353029, 92.53019502086025, 93.03974228520548, 87.71081016909692, 86.00614809220838, 86.85483917113274, 89.19061845348728, 89.79257675909227, 87.54781215421616, 84.35837607229911, 89.8746092088761, 81.57522693757089, 80.57833302405574, 86.5082428532262, 86.13725723758822, 85.6754687524611, 82.70473618661204, 85.55300451094105, 94.44660232913111, 92.31024419107746, 91.08363274605044, 88.9145855749807, 82.58798291606288, 83.04112649733021, 83.23812361686461, 79.86671309317313, 83.56510023916923, 84.19607623930901, 83.28105788077079, 89.7890309364565, 85.36840992589151, 83.97203045506632, 82.41382183567171, 82.80192467474168, 84.7567633659609, 77.29623486918788, 81.82988289863833, 83.06317021769863, 77.03803308548467, 75.0315289343557, 72.92041517073109, 78.01545635346444, 74.42642488787251, 75.17296960276943, 73.94611497079173, 79.63137088283416, 80.76042513693534, 73.07870634140508, 72.49385741449171, 76.68410978009625, 74.05420764800041, 72.37135394926995, 75.19635477373677, 73.6676816017397, 72.3685847559283, 74.84802476821407, 71.59368130468553, 69.34526105080882, 73.03967091345018, 71.96094066865983, 74.1162673888668, 67.3682923470774, 72.46606349945068, 76.29015476472917, 77.73047262622465, 74.70946311950684, 72.62588439449188, 74.51055188332835, 74.98049889841388, 75.39898441683862, 76.56485403737715, 77.9600489524103, 81.36556056237991, 78.96912574768066, 77.3390200830275, 73.49431284012334, 75.15982966269218, 72.63185424189415, 69.61363746273902, 71.73898158534881, 77.2783802401635, 80.31626378336261, 75.62153185567549, 74.65251814934516, 72.07593671737179, 67.30953524189611, 61.47343281776675, 61.260040190912065, 63.28744273031912, 56.40343204621346, 55.819336214373195, 57.636770356086, 69.93583663817375, 69.42679928195092, 64.16835215783888, 61.14491470398442, 59.4405468048588, 31.29591891842504, 25.272831224626113, 2.340133848690218, 3.0418147387043124, 6.986877293356004, 4.007343173988404, 1.861226914390441, 1.163902061600839, 6.583819437411524, 1.4884110227707894, 0.4975739536025832, 0.9062552932770023, 1.6093400240905824, 0.6702400287312846, 0.4426849182815321, 19.477797977385983, 92.48896306560886, 46.080644130706794, 57.418788556129705, 49.930795623410134, 65.15043912395355, 67.00980340280842, 3.2060139794503493, 0.5515466558356439, 0.20175349898636344, 0.2118397819539232, 0.18911405947179566, 0.14547311009899264, 0.1568467272145133, 0.10584604776194019, 0.21959636090022905, 0.21725306647919843, 0.12348886113613845, 0.16755680493529768, 0.1205981049626585, 0.2931976913204116], [0.05604327318348712, 0.03649953519925475, 0.021457052151221904, 0.06117773234784123, 0.033986954499156244, 0.021289995188013684, 0.03379871903528129, 0.1199443331889568, 0.019934391114680518, 0.06199073932704426, 0.10329618539300658, 0.06319670344612772, 0.11016031787280114, 0.398942400971728, 14.408850362223966, 73.92823680754631, 51.67956475288638, 69.08799279120662, 46.53908683407692, 86.93690299987794, 17.33347938906762, 0.6495889336351426, 0.09059083933431296, 0.5653287001675176, 0.061669997465346134, 0.06483117118477821, 0.1752368670197264, 0.4015466096180101, 0.3298273580449243, 1.0113738945895627, 0.7319361536252884, 0.6207617804888756, 0.43949397821580216, 0.5620831839980618, 1.401763291608903, 47.01792978471326, 50.659713206752656, 65.11542804779546, 70.19683114943966, 78.9541893620645, 74.96968884621897, 76.36585650905486, 76.70101519553893, 80.66471930473082, 81.74534013194423, 82.7083683013916, 81.71466719719672, 78.67188853602256, 77.16726733792213, 78.88466142839002, 80.9213835193265, 82.14177408526021, 80.97539455659928, 74.24499173318186, 73.12276240318053, 73.36191715732699, 75.09498503900345, 75.94158941699614, 75.22332499104162, 69.56512558844783, 73.05595659440564, 81.61861619641705, 86.34599793341853, 80.99922687776628, 74.44638190730926, 73.9021687353811, 74.41144143381428, 73.72842342622819, 79.14182770636775, 78.5684399450979, 76.37420331278156, 78.06729439766177, 79.395432472229, 76.09027078074794, 81.56202423957087, 77.05218499706638, 73.10249943887034, 70.26160517046529, 77.60284654555782, 76.45857349518808, 64.36858131039527, 64.2180250537011, 73.4985411551691, 74.38877797895863, 74.28925175820628, 61.141619913039676, 72.34806291518673, 70.40367341810658, 74.56191924310501, 74.09086611963089, 72.90882064450172, 62.31283964649324, 58.532510265227295, 59.26395777733096, 65.98335835241502, 61.41440114667339, 70.33176068336734, 67.78694260504939, 66.64478763457268, 65.09941693275206, 67.69600637497442, 69.08761624367007, 67.54676018991779, 64.64395915308307, 68.37058344194966, 68.00004497651132, 64.270604425861, 65.43082191098121, 69.26622529183665, 71.89729629024383, 66.88106336901265, 64.92573045915174, 68.66865219608431, 70.2567022077499, 69.85230584298411, 70.00316019981139, 73.3536958694458, 71.63347767245385, 69.6774701149233, 67.45973064053443, 68.42035047469601, 73.42768746037638, 60.98668236886302, 65.65804873743366, 72.28352423637145, 70.24563327912362, 67.8930034945088, 64.43661874340427, 59.058566785627804, 53.25795788918772, 45.603793744117986, 44.291360839720696, 39.30409462221208, 36.666908648706254, 40.41763590228173, 59.291065277591834, 60.63086455868137, 50.911607819218794, 47.521820991270005, 49.57464441176384, 15.812026319965241, 10.029238712403084, 6.728194038714133, 0.7871542390315764, 1.2535873007389808, 0.1195403750264837, 1.133798360824585, 0.9884532180524642, 0.1624090005193026, 0.8601830106589102, 0.2716334500620442, 0.02590822217415177, 0.5190595023093686, 0.04174395479382046, 0.04321280964500001, 0.1934546217202179, 63.12558220278833, 42.04032828730922, 35.05524204623315, 39.250079662569114, 37.6065634142968, 52.876001404177764, 4.38109528633856, 0.3306424143093248, 0.035778481753603104, 0.07120838584077936, 0.026255604743416754, 0.026255108701485782, 0.09395142190999563, 0.09463196845665094, 0.036513539286510605, 0.02340132967689105, 0.07177553605288267, 0.04228274826140654, 0.04396737943733892, 0.07026795928757038, 0.033291132159290776, 0.019534880092607874, 0.02956561785521767, 0.00695102648141103, 0.04563408798628277, 0.023193409583801707, 0.04831065746745275, 0.05413459193321967, 0.04245642039384093, 0.012351174035199709, 0.11492561458820298, 0.17897194401631433, 0.16026948548613057, 0.49337465796739827, 18.8632567082682, 82.95282610001104, 59.722220051673155, 66.79028403374457, 35.794255810399214, 101.0494496745448, 23.23435583422261, 0.6863162306047256, 0.10378193110227586, 0.22541850655069276, 0.331163875037624, 0.16687169250461364, 0.44696419349601196, 0.3170636590690382, 0.31178056352561523, 1.1208903308837646, 0.8740040335443713, 2.307171965799024, 1.214605805373961, 0.6262741814697943, 1.7591835125800104, 61.614551851826334, 61.128075968834665, 75.61779775927144, 76.73149985651817, 84.33829353701684, 79.48705119471397, 84.04580239326724, 83.65481268975043, 86.53060820794876, 87.97251070699384, 90.52635808144846, 86.80227156608336, 85.83033961634483, 82.68284936105051, 82.89963091573408, 84.77046812734297, 85.3888140955279, 83.49514084477579, 77.71140206244685, 76.67089139261554, 75.93939288969963, 78.51082032726657, 80.34127281558129, 79.3498545308267, 79.65503846445392, 78.30045577018493, 85.02180576324464, 87.02775293780913, 81.35577817117014, 78.25548971852949, 80.33539710506317, 78.27174402052357, 81.12212258000528, 82.80288173306374, 80.99198618242818, 80.17072816048899, 81.36654115492298, 80.25663591200306, 79.33600856411842, 83.98794743322557, 80.07998020418229, 76.02629692323747, 74.49615678479596, 79.65000214115267, 75.3162302509431, 66.08284534946566, 71.3568485936811, 78.02719208502, 80.50133689757317, 74.21417759310815, 66.0972482927384, 76.64707476092924, 71.11744280784362, 74.2098629859186, 74.86082738445651, 76.73366500485328, 68.33354842278266, 61.56949558565694, 61.13428900318762, 66.50985025590467, 65.76884392769107, 73.02678200506395, 69.48376778633364, 72.95761492944533, 71.15225776549309, 71.93601792858493, 71.99295505400627, 70.53686926441809, 68.46100976390224, 68.99992773609777, 70.02899292976626, 67.22094458918419, 66.54003681675081, 71.55622266953992, 72.95544978111022, 69.48212823560162, 68.14036384705575, 71.09751716736825, 72.54638579583937, 73.22886251634168, 72.00700498396351, 72.27168652319139, 73.98763718143587, 72.98838200107699, 72.37520571677916, 69.80045995404645, 76.28966054608746, 65.33550439342376, 67.15381714605516, 72.37237376551475, 75.49165433452976, 71.44077947062831, 70.78528865691155, 65.90398526960804, 62.21236028978902, 56.84277280684441, 56.715374223647586, 49.66402738325058, 45.037003409477975, 49.02071160654868, 64.17732654079315, 67.89321530249812, 68.9636536567442, 54.877885003243726, 58.75030771378548, 34.01776336854504, 27.185859410993515, 11.941804059090154, 1.7012499825608347, 1.4662482829824572, 0.43364884992761, 0.4580825194716454, 1.940502305665324, 1.1320021604338, 0.42407544750359755, 0.22330244912976221, 0.016383129254644437, 1.6299112621814975, 0.18000841501259035, 0.08824005257338287, 0.4606465238236612, 69.46732521057129, 42.90649744772142, 31.221346816708966, 43.974178375736365, 40.986305052234286, 62.695219747481815, 5.171894633000897, 0.4121071010106995, 0.052967112241012436, 0.03714383812621236, 0.012404805935558774, 0.09231197076939768, 0.09910890967735361, 0.12369503837920005, 0.034208085778499805, 0.010596569345873452, 0.05655216240894891, 0.045602563468198624, 0.021494879657703064, 0.045635838497189746, 0.25263275350293807, 0.07086835771558747, 0.11877969568294865, 0.2182226120344093, 0.20682523087147744, 0.12673823838873258, 0.1927249842593747, 0.23864705235727374, 0.19370119477952683, 0.15302191067847515, 0.28975679208674743, 0.323971780317445, 0.37887583096181193, 0.7067978670520167, 23.503801092024773, 97.07666135603382, 62.76153525998516, 84.26828707418134, 60.786916055986964, 114.11799476992701, 25.910512516575476, 0.9402486369494469, 0.26518580894316396, 1.4160414544805404, 0.518710901660304, 1.3977527906817775, 1.0223119141113375, 0.7911811648837982, 2.025303581068593, 2.7825512184250742, 1.3661723175356466, 4.242186998167346, 4.316697812849476, 1.1529369532100617, 3.6932547246256187, 74.4238910367412, 66.24044618298932, 84.39474428853681, 81.76955684538811, 91.21129020567864, 87.94732909048759, 95.53222810068439, 91.55451328523698, 92.7995990937756, 91.22985870607438, 94.51400433817219, 89.67405057722523, 86.68802861244448, 87.07318182914489, 89.85152998278218, 89.7465124437886, 91.5377490751205, 90.1483984916441, 81.48476139191659, 80.70903424293765, 82.38602007589033, 83.69269494087466, 86.17645740509035, 83.6414138732418, 85.03568310891428, 84.6080663127284, 92.44059239664386, 91.51994935927853, 88.23092429868638, 80.81973137394075, 83.56218984050136, 80.59545809222807, 81.48534190270209, 85.39297180791056, 83.73031831556752, 83.35457094254033, 84.442322638727, 84.51124652739495, 81.14175012034755, 87.62052505247055, 81.74454781316942, 79.86898022313272, 76.35979252476847, 83.4469819838001, 82.25654263650218, 71.35033745919505, 70.28274674569407, 81.05233576989944, 80.01179372110676, 79.27249754628828, 68.45703248054751, 76.83639972440659, 74.52782600156723, 78.22796252466019, 80.17845522972846, 77.86676714497229, 67.99498511898902, 62.136952723226244, 66.57252973125827, 71.34535604907622, 68.24754653438445, 77.02865862077283, 72.11806297302246, 74.76399975438272, 72.3447524347613, 72.58598604509908, 76.73729711963286, 73.74131233461442, 75.94910467824629, 72.8791126128166, 73.73857452023414, 71.4776340607674, 70.27573354782598, 75.70717288601783, 78.65317098556027, 72.93518681680003, 69.9647758853051, 73.95961576892485, 75.18275199397918, 78.2443109635384, 76.06523821430822, 78.19482634144445, 78.8868736451672, 77.78169093593475, 75.12358696229997, 72.60615487252512, 79.13527734817998, 67.57993559683523, 71.82672500610352, 78.08576876117338, 81.28421844974642, 79.02809466085127, 73.78666277854674, 73.27931988623835, 68.73878417476531, 61.829125112102886, 60.876216657700084, 56.08588087943293, 58.51486352182204, 59.09369553289106, 70.55895220848822, 67.98782287105438, 65.59935439017512, 57.75714005193403, 65.29909303111415, 36.883164605786725, 32.29671951263182, 16.14462369872678, 2.425942805505568, 3.59625990352323, 0.7503172995582704, 2.578860329043481, 4.2224118786473435, 4.307970048919801, 1.631079883344712, 1.061739885518628, 0.1330896818469609, 4.184389893085727, 0.2554096230455945, 0.19542742069930802, 1.5139023839466035, 77.00069212144422, 59.352371923385135, 53.89404081529187, 50.55395041742633, 49.844448566436775, 74.26523116327103, 6.559269322502998, 0.498835853631458, 0.22774929841679914, 0.11435677898266625, 0.10490790415074557, 0.12876654043793678, 0.14754617466561257, 0.21773439952202384, 0.15684170167773, 0.11305255259597495, 0.13920707778344232, 0.19185326813209444, 0.17667142794497553, 0.15299531210574413], [0.0681864217885079, 0.05930258659645916, 0.07041175399095782, 0.02635572094380135, 0.08489018756776087, 0.02455706907165868, 0.03230976203696863, 0.05881888634194771, 0.026086992621722243, 0.018853603847204678, 0.049908452577167944, 0.08242548353249028, 0.05979501642286778, 0.004715771046316913, 38.00637845070132, 66.08128424613707, 47.63227493532243, 43.58999398446853, 49.170671662976666, 76.5164049210087, 2.359403472754263, 0.12347367727347922, 0.14731259445749945, 0.042253138963133104, 0.4450590554023943, 0.24643496429968267, 0.42853616298206393, 0.2348993042664182, 0.170988557079146, 1.2660979455517185, 1.8587446669417045, 0.7073479181816502, 0.04725474699009811, 0.3643538989126683, 31.56924536151271, 63.29027468158353, 76.19453522466844, 77.14048539438556, 82.52856685269265, 78.05795915665166, 79.79261952061808, 78.43828785804011, 79.00063806964506, 76.35147710000315, 84.61321246239447, 82.22634823091569, 80.11807426329582, 78.5535192489624, 79.22428377213018, 81.33915516637987, 80.62904927038377, 72.65532570500528, 68.7452325513286, 69.80805366270005, 66.69003609688052, 68.22062338552168, 65.56175062733313, 63.19901681715443, 71.11162985524824, 75.65693516885081, 78.98808648509365, 75.43108509432885, 80.1178938342679, 79.6524340106595, 78.44170032009002, 80.22794769656274, 76.81586219418433, 81.12563702367967, 78.39550264420049, 80.32866631784748, 81.96792679448282, 77.15005597760602, 78.385908526759, 80.95620632171631, 77.98591306132656, 74.47558003087198, 69.22842933285621, 81.31746445932697, 67.47305885437997, 64.65183919475925, 75.19705295562744, 77.72778972502678, 73.5677239202684, 73.4495036832748, 58.01988394029679, 67.10272435219058, 70.22071053904872, 68.68321203416394, 69.51884162041449, 71.25392560035952, 75.59919787991431, 75.5821277249244, 68.81734140457647, 57.97200748997351, 55.67550290015436, 59.05955130054105, 65.73786504807012, 66.93707481507333, 71.8754957568261, 69.43511470671623, 66.39472869134718, 69.28373475228587, 69.76786505791449, 68.74997077449676, 64.45423410784814, 66.20412503519367, 64.95302623318088, 63.11836504167127, 60.89274944797639, 64.02496207144954, 66.36775847404235, 66.1923030114943, 64.24326158338978, 70.69984374507781, 71.84954535576605, 71.58377339763027, 68.2641460049537, 69.90099814630324, 69.62083108963506, 68.34602155993062, 68.1906407879245, 69.04385828202771, 65.12973293181389, 63.682256744753936, 64.91936445236206, 74.22391291587584, 69.7425030123803, 69.70307534740817, 65.7695617214326, 58.72493782351094, 52.34281009243381, 50.57300136935327, 47.56053086250059, 30.497559693551835, 34.05595156454271, 52.26789282214258, 60.23108090123823, 53.97229994496992, 44.71325882019536, 42.068330087969386, 29.624218479279552, 5.0322852211613815, 11.61833501631214, 3.871332781930124, 0.09868615171721867, 0.763410477628631, 0.17225445608698553, 0.2834678843857781, 0.7088996445940388, 0.3507446227294784, 0.579395238910952, 0.7779418785245188, 0.22133608528923607, 0.08880049185526949, 0.4475047144918673, 0.4835345343716683, 26.69375884917475, 59.31998491287232, 22.03910177753818, 52.53107209359446, 36.51668187110655, 54.56425620663551, 5.436158930101703, 0.4767933590037208, 0.13516604059165524, 0.038311612762270436, 0.08100370861469738, 0.06725468267236026, 0.0375174860199613, 0.01986084092829016, 0.039299793406239444, 0.06501268039667799, 0.0288953349715279, 0.02073422904246517, 0.05243294211404939, 0.05697573625272321, 0.01640179881735915, 0.07739728842411311, 0.0652271084066841, 0.034035053329482194, 0.03423858756920503, 0.012812479624464627, 0.030303460117729924, 0.03390417486849812, 0.04795850600085912, 0.045746415628180395, 0.0963523184820529, 0.028137809995021072, 0.10679835633885477, 0.029883779915830785, 47.835430176027366, 72.51643457720357, 63.554305107362815, 45.3593163336477, 46.36540036047659, 92.59056029781219, 3.229055452731348, 0.18179759803798892, 0.08398011341811189, 0.014097312495352761, 0.06820411841955877, 0.0406440134130178, 0.14827812571198712, 0.18761078045973856, 0.3001504601730455, 4.658216132271675, 3.2444510008058245, 0.6683214994207506, 0.20534717147388767, 0.3609913857954164, 39.021519230258086, 75.00696705233666, 84.8409217403781, 87.60286654195478, 88.60050570580268, 83.34986409833355, 84.48194642220774, 82.8158804678148, 88.05048742601949, 81.01922312090474, 89.38661929099791, 88.51018136547458, 85.9849202248358, 81.36550564919749, 83.2208965670678, 86.14085012866606, 85.08692495284542, 76.53521660835513, 74.91266542865385, 71.75833455977902, 72.34216367044758, 71.68282108922159, 71.10793498254591, 68.04896477730044, 74.67688391285559, 78.48875307267713, 83.45787832813879, 79.94796891366282, 81.4971560816611, 80.99914058562248, 80.12531495863392, 82.3464668950727, 81.66243691598216, 85.16745121248307, 81.00097625486313, 81.83827677080708, 84.51236832526423, 78.58292133577409, 81.24627344069943, 80.94061097791119, 80.398923812374, 71.6735407613939, 76.45914616123324, 83.17869970875402, 68.59970477319533, 70.15623461815619, 79.66744099893879, 79.18923347227036, 79.32268819501324, 74.09421582375803, 61.90888258718676, 72.07949038474791, 74.07994624107116, 73.11248579332906, 71.56616980029692, 73.89437890821888, 76.31695239774643, 78.53870837919175, 73.522781402834, 63.79029450878021, 56.43812148801742, 61.15798796376875, 68.43533392875426, 69.77152855165544, 74.7737507666311, 72.4288558959961, 67.32441671432989, 71.4129541766259, 71.71420789534046, 71.80150416589552, 68.99352642797655, 69.8699329745385, 68.03260064894154, 66.96098558364376, 63.76878423075523, 67.46697133587253, 68.54228127387263, 70.59734436773485, 67.82095739918371, 72.13846714265885, 72.36825527683382, 74.42678574592837, 72.14699437541347, 69.48562698979532, 70.00039885121008, 71.60281258244669, 73.23845663378316, 72.60891622112644, 68.79421511004048, 65.20990225576585, 69.50044570430633, 73.55616077300041, 75.64315980480563, 72.995803125443, 69.01076916725405, 66.5016838812059, 61.633838145963615, 57.32478503257998, 55.404278847479056, 43.38079437132805, 41.25273596855902, 54.374315431041104, 64.5696969186106, 67.63525670574558, 62.74444157077421, 56.56443749704669, 51.31482747293288, 26.360082818615822, 29.26769856483706, 7.789646242895435, 0.26762319428305475, 1.8450915092422118, 0.06261053893174376, 0.3573495570209719, 0.9185411372492391, 0.49985845843630455, 0.6962120641143091, 1.2297847650704847, 0.2467389020227617, 0.42728011586493064, 0.16195823438465595, 0.2701076174214963, 29.37080590955673, 67.01088597697597, 19.989090696457897, 49.16579615685248, 44.42431349908152, 63.47732467036094, 7.998203567920193, 0.34367804385481343, 0.09589940730121829, 0.0756415834410056, 0.05919756360291954, 0.09065324485662485, 0.0671050503789898, 0.022048458622227755, 0.0590635403510063, 0.01700082211755216, 0.019291185608674443, 0.026818055006104614, 0.036109787967777064, 0.07233605194356173, 0.1346804787434878, 0.14683883036336592, 0.09697639668780951, 0.1391584312002505, 0.16635182523919692, 0.147898146101544, 0.15852392350714054, 0.17571073836616932, 0.15780802966365892, 0.17138157550606037, 0.13742376299154374, 0.19029904427307268, 0.23156862976329945, 0.09291642946341346, 54.36338770774103, 86.63460593069755, 59.54749414997717, 57.848425372954345, 68.041716237222, 95.43771466901227, 4.6760080033733, 0.8454261960521822, 0.2199274181358276, 0.1597349706196016, 1.3282445914322332, 0.664594573599677, 0.9738219805782842, 0.39672540380589427, 0.6427497296564041, 6.949262743996036, 5.069876726596586, 1.5083544364859982, 2.608541149285532, 0.7058519016831153, 52.23216002987277, 80.82161411162346, 88.70258931190737, 91.29072604640838, 95.25743469115227, 88.64598951032086, 90.61313659914079, 90.68006792376119, 93.55680481080087, 85.93259580673711, 90.62351519061674, 93.84630710847917, 91.83369190462174, 85.44404891229446, 86.57186369742118, 91.78723535230084, 92.00580550778298, 83.40280040617913, 77.13664931635704, 78.49859822180964, 78.86969366381246, 80.45809668879356, 76.77649728713497, 75.75795189026864, 81.59922399828511, 81.85325238012499, 85.88483702751898, 85.21093460821336, 89.14602110462805, 86.66823633255498, 81.5475114699333, 85.75738353113975, 84.73224070764358, 88.70662150844451, 83.67194560266311, 85.66592170346169, 90.35575851317375, 82.14325674118535, 85.12969447720437, 87.06475657801475, 83.18211217080393, 78.70635832509687, 79.10401605790662, 87.51397778910976, 71.9823803440217, 73.11886356722924, 80.91701399895453, 84.0548630683653, 80.08305534239739, 79.16489908772131, 65.20315185669931, 70.9464039341096, 76.42830064219814, 73.78775319745465, 74.92020422412504, 75.76683213633876, 80.51480631674491, 82.32843183702039, 75.25116597452472, 65.08527678828086, 59.45101953321888, 64.2856937839139, 71.73414138055617, 71.85669191422002, 78.70294586304696, 73.35204847397344, 71.19951448132916, 74.36238827243929, 75.47400366875434, 74.43320274353027, 73.71618563129057, 71.4630271542457, 72.69433759873914, 69.51321694158739, 65.19316550224059, 71.70552376777896, 71.55626973798199, 72.70837968395603, 72.7663758493239, 76.4176082611084, 77.33813362736856, 78.4249439547139, 75.91863570674774, 73.61678492638373, 74.76171693494244, 76.29324559242495, 74.87422620096515, 75.99341177171277, 71.59227709616385, 68.70144321072486, 74.32449033183437, 79.33920137343868, 79.66396577896612, 77.77201837108981, 75.35835650659378, 74.08741443387925, 63.249552634454545, 63.094622935018236, 63.30707811540174, 51.314666655755815, 50.156445657053304, 67.15480558333859, 71.6590593707177, 64.17967604052636, 60.31879294303156, 55.824043058579974, 54.480317484947946, 29.218298273701823, 39.067748285109, 10.25862676482047, 0.4114420754053901, 3.150046414905979, 0.4458474824505468, 1.664015535385378, 1.3957288476728624, 1.528318074922408, 1.1485438986170677, 1.5512435931351878, 0.7744540334228547, 0.8551812532448, 1.2157252743359537, 0.5592248793090544, 39.64704705822853, 79.82082136215703, 35.815758243683845, 68.3155761226531, 47.13590291238601, 79.04912640971523, 9.944020317446801, 0.6998085098401193, 0.18689212869972954, 0.2115741179835412, 0.14294908021486577, 0.16432872492699854, 0.16188165623574488, 0.3256127100077368, 0.14755762001920134, 0.12826533507435553, 0.17887074380151688, 0.08475206957589235, 0.16390083417777093, 0.13753245554624066], [0.09357193259582405, 0.0409406962834539, 0.020119466465867816, 0.02113356577953504, 0.06842167206829594, 0.09243632982214613, 0.11931537500312252, 0.031932425429864277, 0.04793202234131675, 0.04988203403509913, 0.049031837317611904, 0.08737811938889566, 0.05219945766692681, 0.23365834908139324, 54.16990110951086, 53.098419404798946, 38.220222150125814, 32.4249594442306, 53.29537730063162, 56.17176901909613, 0.26811094714268563, 0.2705525919314354, 0.29111117424984134, 0.30006358580243203, 0.13343638259797327, 0.8064190214199405, 1.183382022765375, 0.7986454966087496, 2.0356116924555074, 1.0193923223883876, 1.0122792879419944, 0.2673373822002642, 0.9463649603628344, 17.514620327180435, 67.19817915270406, 76.73886606770178, 87.36459824346727, 85.76008996655865, 82.51413253045853, 81.59265795061665, 78.55321330408897, 82.03975323707827, 84.81071949005127, 82.56060477226012, 81.91778321419993, 82.60302912804389, 74.39011942955756, 74.21954339550388, 73.29301680288008, 75.89271668464907, 74.20443442560013, 71.10642879239975, 71.18002030157274, 65.88078052766862, 60.55294667520831, 66.96148764702582, 63.65020705807594, 64.42180395126343, 66.251342527328, 64.22051183639034, 70.72650017276888, 76.13660181722334, 75.66978485353532, 84.57283558384066, 85.16096361221807, 82.62697127557571, 80.61540726692446, 76.71792061098161, 77.82141670103996, 77.61957937671293, 76.17779454877301, 75.17035730423467, 76.27506932904645, 74.436246502784, 72.29094536073747, 71.4895345318702, 86.0094742621145, 64.79684137528943, 67.13873955511278, 81.73234924193352, 80.12678976981871, 70.48630206815659, 81.84425446294969, 58.262270727465236, 69.00294796113046, 76.52235123418993, 69.40072336504537, 76.79236719685217, 69.30986558237385, 70.69188133362802, 67.12552116763207, 68.5268271353937, 63.743124085087935, 67.3528068296371, 59.987411499023445, 55.76667839480985, 59.826511952184866, 66.88071820043749, 64.4241181496651, 71.25648298571187, 68.06230868062666, 72.09754113228091, 69.17055868333387, 72.28523438976657, 70.26963033983785, 69.0610461081228, 68.82190704345703, 67.88224835549632, 69.28395440501552, 62.248253899235884, 61.112135456454375, 68.54723914977043, 66.16495624665292, 65.73093421997564, 67.10885109439974, 73.00657395393618, 68.4146708826865, 67.32177303683373, 67.0699647165114, 68.85405478938934, 67.82956307934177, 66.58343392033731, 67.90761824577086, 64.22815653585619, 65.55583569311327, 71.39341292842742, 66.88393454397878, 68.70261207703622, 65.64600313863447, 66.29510048897036, 56.78214865346109, 47.0863006191869, 45.84974204340289, 49.48413964240782, 32.79417803210597, 33.06181899962887, 53.91028335017543, 53.71270179748536, 48.72631419089533, 39.52234706571026, 29.777575308276763, 14.497580259077012, 5.599970346496952, 11.899380683898928, 1.8039723221332797, 0.07007529583549307, 0.09557388122043303, 0.09847564607738488, 0.42839777685942193, 0.8303385540362328, 0.2385491156770337, 0.13529086695803752, 0.2483152045357612, 0.04911267491538198, 0.15499762079167753, 0.04524791072453222, 5.314063391377849, 60.28972033531436, 30.63148706190048, 39.25747333034393, 28.654810574746904, 57.89614885084091, 8.628049435154084, 0.2948244024188288, 0.07711015100921355, 0.08788401321057351, 0.031941788939518795, 0.026213016000486193, 0.01147035486815918, 0.029851360990095045, 0.0609836133287078, 0.00496893820743407, 0.03937442952226247, 0.01125678870706789, 0.04118913476685843, 0.043972075556314764, 0.06374514962155974, 0.018032644875347614, 0.017977534425294688, 0.05214683125696836, 0.029149660840630535, 0.006669151132941367, 0.0783599085444885, 0.023255985560676744, 0.07785841206749601, 0.060481458016100435, 0.033055763135874466, 0.03732560780800639, 0.05456293850476223, 0.630694141070689, 66.222866119877, 62.52108612368184, 62.25777741401427, 25.817334651947025, 55.46966475825156, 64.60318219277167, 0.19760959150810398, 0.07200901666956563, 0.38921513744900305, 0.2779833383617863, 0.2942553216651563, 1.5724889885994697, 0.21173588510963226, 2.1753930757122655, 3.2043876667176527, 0.8676000900806919, 1.3753399997949602, 0.1631489801671236, 1.2506820501819735, 24.457070404483428, 81.63757693383002, 86.52246536747103, 93.13307116108557, 87.70633866710048, 89.58260443902786, 88.12652649418001, 80.75203126476657, 85.0457400660361, 91.68889368734052, 85.99125093029392, 85.53719735914662, 85.15420929078134, 78.85184687952842, 77.77270086349981, 75.91352093604304, 78.29767088736259, 78.5373826180735, 75.66324234008789, 72.93357080028903, 71.80672876296505, 70.17713300643429, 75.45105780324629, 73.04660566391485, 75.72807127429594, 77.76669179239582, 70.74190724280574, 75.28607506905833, 79.71153628441596, 79.78597502554618, 86.35232863887664, 87.12107396894886, 84.67405626850744, 83.84675779650289, 81.42641221323322, 81.04785642316266, 79.99146799887382, 79.40914507835143, 76.71831284799885, 79.40860379126765, 74.98182465953212, 70.88608572559973, 74.44899420584403, 83.6684468484694, 67.75867016084733, 73.99839232044836, 84.04326069739558, 80.70444506983604, 75.20922799264231, 83.44371072707638, 59.34565682565013, 76.57989240461781, 76.887374847166, 73.12528056483116, 77.72453415778376, 71.1043264019874, 73.67427902836954, 72.00268253203362, 70.79394140551167, 65.66024134235998, 70.11563808687272, 66.40078483089324, 59.752940054862734, 60.90727790709465, 69.62583603397493, 66.4852491501839, 71.6661431712489, 71.90055185748686, 75.90842185481903, 73.23518537705945, 72.43911681636688, 73.30639208516767, 72.67674969088647, 71.37785680832403, 70.62117668890184, 71.29987224455803, 66.23156593691918, 65.36594590833111, 68.89886394623788, 69.11580239572834, 68.03567578715663, 69.98865527491417, 72.8837017859182, 70.97793979029503, 71.90600395202637, 71.1310612770819, 71.61553675128569, 73.04404043382215, 71.1640719444521, 69.89433796175065, 67.04413198655652, 69.57465694796655, 70.91222440042804, 69.8089950315414, 72.37954385818975, 69.76995175884616, 69.279890829517, 64.53197940703362, 57.927869058424434, 54.44921701185165, 56.38687964408629, 37.95213599358836, 43.121957163656916, 59.626231808816236, 66.43760019733061, 70.6069855536184, 63.60144807446388, 52.402732141556285, 40.85506646863876, 21.605450414842178, 23.018909846582723, 2.6764523310046044, 0.17924949767128115, 0.3199180107443564, 0.019636419301311818, 1.026554202600833, 1.1391988516815248, 0.033401012150270325, 0.7210879808952733, 0.21922240274087076, 0.27420949731622973, 0.031142521747237736, 0.15662204894808032, 5.437507735144708, 71.10016868960473, 27.579665376294045, 42.31929509870468, 36.22988993121732, 65.74303473195722, 13.049272529540524, 0.25410070053992734, 0.12824083558253704, 0.08630693694877048, 0.008966815920786993, 0.046139736659824855, 0.04546290947004192, 0.01871745087086193, 0.02988988755180711, 0.06204049290728666, 0.12302064351857671, 0.06605692718538546, 0.09939210940032236, 0.012881465842046086, 0.2506972476840019, 0.1710788482019017, 0.08777796365921536, 0.2928528904674515, 0.1939059547599285, 0.12298692032814988, 0.2987544641139046, 0.13540602529481535, 0.23970270619517375, 0.14807399392368334, 0.12413361605497138, 0.14409523968014026, 0.20216053682229213, 1.1142529451077985, 76.83064952973398, 68.69041350580031, 48.958036053565245, 47.491634430423865, 72.18541791362148, 71.19388980250206, 0.3189003395457422, 0.492627538380123, 0.5219482666542453, 0.45442824942931054, 0.5396424462237667, 3.1261133378551853, 3.452253024424276, 3.699613867267486, 5.026439909012088, 2.739834400915331, 2.5690789184262677, 0.6399574923899867, 1.919674397476258, 31.618563282874327, 90.03384174839144, 88.79373734997165, 96.62093685519312, 91.37726137715002, 93.91514470500331, 93.19849629555979, 86.65737136717766, 91.05093586829402, 96.30202462596279, 87.9129691277781, 89.11956079544561, 90.05565012654951, 84.0043507852862, 83.76849866682484, 81.48921720443234, 84.42315009332474, 84.62871366931547, 81.71722458254906, 84.12567753945628, 81.95510848875969, 77.58590975115376, 85.91423911433067, 80.24638283637263, 80.64929654521328, 86.16199170389484, 82.45113142075078, 84.04361371071109, 84.71434685491747, 84.54161351726901, 89.97723410206457, 88.8842813430294, 87.68201997203212, 88.41397346988802, 81.80109270157354, 84.52413543578118, 83.74387402688303, 84.79781489218436, 79.81129784737864, 86.2498841747161, 80.10679352668025, 79.8310822825278, 76.54901550662133, 91.44148626635152, 74.32287431532338, 74.91664271200858, 89.8436224845148, 88.19733312053066, 77.57316204809374, 88.43183594365274, 63.68850508043843, 76.2093774734005, 80.5423648895756, 75.22161483764648, 83.93324605880245, 73.6996332291634, 77.60879285873906, 73.26974145827755, 73.98582504641625, 67.716324252467, 69.7364390280939, 64.66526939022926, 61.43989655279345, 65.39863101897701, 73.15883251928514, 70.25767495555263, 75.57512237179664, 72.45774807468538, 76.95751467058736, 73.90391026773761, 78.77547048753308, 74.7898324843376, 74.4253501584453, 73.45690127341979, 74.26742769056752, 72.93315502905077, 68.13637871896067, 69.29119510035362, 73.51336771442045, 70.60664038504325, 71.30871326692643, 74.03846325412874, 79.6139947829708, 73.46916260257845, 74.74969094799411, 74.7967044768795, 74.84041537007978, 76.30955480760144, 75.01982458176153, 73.83994425496748, 69.38755204600673, 71.53353568046325, 75.71223274354013, 73.57734157193092, 79.71453297522761, 74.09703208554176, 76.8051855025753, 69.40706191524383, 59.08155579720775, 62.81181612322408, 65.11340410478654, 53.11279881385065, 56.93192435849098, 67.8008827086418, 66.7550297706358, 63.412856594208755, 58.34092993890086, 50.75084555533625, 44.99230407899426, 25.961813196059197, 32.53755304121202, 2.4881135984774563, 0.6651052171664854, 0.7118348645106439, 0.46258941473018744, 2.3851013712344633, 2.9982286259051296, 0.9086092669636974, 1.5149451215421001, 0.9592628779430544, 0.42637766429012824, 0.7847843920030902, 0.34005545920902686, 9.82275043764422, 80.98510634514594, 47.87274368347661, 55.951120007422666, 37.30722381222633, 81.91360196759625, 14.823252693299326, 0.47633015160118386, 0.2040898220072831, 0.20475953607068909, 0.1334905603359784, 0.11439661555472883, 0.06573576014488935, 0.13039156614292052, 0.12776308783119725, 0.24984601674781692, 0.37569481939558064, 0.15737209499122637, 0.20633453623421733, 0.10760605815918216], [0.0495658542269901, 0.11057221270616978, 0.06864143205025504, 0.0440263643770689, 0.030431214855202747, 0.06651032866249162, 0.026628070946542487, 0.016394806349830284, 0.030919781683253187, 0.058708581172170184, 0.02886340059640427, 0.10372474263872832, 0.16240766752631436, 8.450975014317422, 73.41839144306799, 38.37198257446289, 44.34188881228047, 31.03758965769122, 81.81431893379458, 26.872665997474428, 0.3120231069624424, 0.25122632332626854, 0.26592125335047323, 0.09808648873360888, 0.14342115891556587, 0.9008202978199529, 0.9461440818925059, 1.9777040255646554, 2.6282571881048145, 0.46375291842606764, 0.4227773574811797, 1.1083290629809903, 16.437659071337794, 64.30846314276418, 78.57294282605572, 86.5128477158085, 88.77737322161275, 88.78576709378152, 90.15515281308083, 82.95707010453748, 82.50793518558626, 85.63185199614495, 88.01328766730525, 83.72987901010822, 84.83273967619866, 83.14869357693581, 76.96500639761649, 73.09165016297372, 69.22580134484076, 68.2334416912448, 70.3711805035991, 68.38642981744582, 60.03631168796171, 57.23276230596728, 63.058042910791215, 59.076872487222, 57.92270329690749, 67.3539129380257, 71.58959419496598, 72.24598715382238, 65.89443037586828, 72.81135759046002, 76.00685765666347, 78.75464270191809, 81.56430705901116, 84.37801145738172, 80.37539743608045, 85.95620063043411, 79.2883203875634, 75.95191309528967, 75.98355093309956, 79.4468782794091, 73.12942258773312, 69.23299497173679, 77.36036562150525, 80.7701918386644, 66.45587059759325, 69.69458733835529, 79.4129183984572, 72.36907112982966, 73.52744902333906, 83.05818880757978, 60.334258848621005, 59.07417389654345, 77.69259821984076, 63.622322928520944, 70.79431795304822, 66.61124352485903, 69.7109357772335, 69.52621567633845, 73.01862347510554, 67.96674405374836, 68.96844679309477, 70.48296020876977, 72.818982678075, 64.50499742261826, 57.64995344223515, 58.807633153853885, 64.65875825574322, 60.96087317312918, 65.81629676203575, 64.53520359531527, 72.3541033652521, 68.07410717010498, 73.62134272052397, 67.3947448115195, 71.28939167145761, 71.06493011597665, 68.49926071782266, 66.35592860560264, 64.04449939727783, 62.90401927886471, 64.34264267644575, 66.55160780875914, 67.57122793505269, 69.5772300227996, 71.59740755634924, 66.34449881892051, 70.40019035339355, 67.81137112648257, 67.01256475140973, 66.31984280001733, 65.80580049945463, 67.65752007884365, 67.39112838622063, 65.40698566744405, 68.4872817993164, 66.57235714697069, 70.8124706822057, 68.35087745420395, 60.66583641113774, 53.4002967803709, 53.700267884039114, 46.11250946598668, 32.904579024161066, 30.494598304071737, 53.43127958236202, 48.28937784318001, 50.07392683336812, 43.057257667664565, 33.524042867845104, 16.227949550074918, 4.581407789261111, 5.344772608049455, 8.354216025721643, 0.536591638961146, 0.6196629039702878, 0.05570029945022637, 0.4439046834745715, 1.3218442639035564, 0.39105742568931273, 0.15468199256687395, 0.5410150306359415, 0.24360175665107467, 0.011628773232411233, 0.22038458876552122, 0.07555812582253449, 44.83293817889306, 32.48970796985011, 47.38830351060437, 37.70548951241278, 52.735941410064704, 17.533961534500122, 0.48504385015656876, 0.12006546701154402, 0.061435375377656, 0.17292142755562262, 0.12150496920390476, 0.05132128724888448, 0.14394465743774368, 0.01540340622135949, 0.008465437229812868, 0.10416430856792197, 0.03976093620182045, 0.02164878672169101, 0.03956950232086163, 0.00645256610662346, 0.044856933921936064, 0.029954229361347617, 0.049753614716352, 0.03318545799101553, 0.047426124689199274, 0.12944521773005688, 0.09049429693409512, 0.05840187021080525, 0.10779443151888349, 0.1163589038074978, 0.04755514155652735, 0.2819383132361597, 10.519897803183525, 79.8985392047513, 51.426713082098196, 52.6345952095524, 28.030488875604448, 94.78150998392414, 31.231762670701553, 0.29909142022652013, 0.16979791854898776, 0.2449563533187874, 0.17943299105090482, 0.4283302998350513, 0.537416868873181, 2.5057618127715204, 2.6571966803842977, 4.045897131004642, 0.6186435167347232, 0.36208456261984767, 1.3681078846416166, 20.953244586144727, 78.28250700427641, 90.51892126760175, 94.19003225141957, 94.52839159196424, 93.08819924631428, 90.6469552747665, 86.30134567137688, 85.51637741827196, 88.32803433941257, 90.45971701222082, 86.96553630213585, 89.24712411818966, 86.47049396268784, 80.335051936488, 75.58349270974436, 74.46309904898368, 73.46069812774658, 75.93098332805019, 74.03505863681917, 67.64577650254773, 66.97887159162953, 67.53316525490054, 67.92230359969601, 67.65856342930948, 73.25413042499174, 79.23889852339222, 85.84067113937871, 78.60674581220074, 81.01215500985423, 81.02336514380671, 82.77126742947488, 83.57940120081749, 83.36225094333773, 82.01101010845554, 87.66893494513728, 80.66515076544978, 79.27227789355864, 80.11839589764996, 80.3493764323573, 71.02117999907463, 71.990444737096, 80.31349459002095, 77.64978947178011, 66.6277410138038, 73.7431558485954, 81.21668308011948, 73.02296946125647, 78.6762188326928, 83.25524868503695, 60.31194840708087, 66.44385245538527, 77.49218863825645, 67.91853027959024, 72.16343695117583, 70.77021106596916, 76.81765863972326, 74.6059125469577, 75.35091969274706, 69.07255434220838, 72.30964722171908, 73.10046765112108, 74.60617142338907, 70.43971215524982, 63.56600161521666, 60.394498609727435, 67.01738142198133, 63.96156872472456, 69.8952950200727, 67.32470696972263, 73.14235071982108, 69.35034444255214, 73.18001331821566, 70.68002008622693, 72.34406994235131, 73.56637462492913, 73.57664339004025, 69.50577228300034, 67.61138516087686, 65.76851837096676, 67.9606016220585, 69.39038399727114, 72.04302803162606, 68.58885549729871, 73.0852488548525, 70.27726327219318, 73.58313099030526, 70.65539544628513, 71.2883718552128, 71.12269093913417, 69.6119116198632, 67.51713845037645, 69.5727663655435, 65.8149710009175, 72.92638501813336, 69.05445652623331, 73.92710716493669, 71.27964065920922, 64.39913265166744, 61.85789177494665, 62.48514544579291, 55.48574255358789, 43.96403120410058, 41.128220327438854, 59.10635302143713, 58.44932071624264, 68.77715279979091, 67.44695940325337, 62.56622868199503, 51.59875216022615, 33.78920293623401, 23.919056538612615, 14.94403619920054, 0.7401376457944994, 1.068989406189611, 0.13253981457842937, 0.5481764818391492, 2.878122954599319, 0.05549632470994707, 0.19869660898562402, 0.8283522412661584, 0.18365540721964452, 0.322632352190633, 0.1592103689308128, 0.08504447001483172, 50.8145252350838, 37.09485100161645, 40.184364703393754, 42.96787469617782, 59.39187019102035, 22.760910064943378, 0.5179469587822114, 0.1523242650493499, 0.118280497469729, 0.16178918942328424, 0.08924397249375621, 0.04675050025745746, 0.06320220778786367, 0.010895212443785803, 0.07217921076282378, 0.04989758178952241, 0.14702554131227155, 0.034134694555353735, 0.040512430151143385, 0.13854387546739272, 0.18435277705711706, 0.183881142687413, 0.15465531738535052, 0.17271714254973397, 0.16838402667593572, 0.2074539898744514, 0.2298545999632728, 0.22014512500214964, 0.24647290097369304, 0.27138342960707607, 0.3374152137867866, 0.5263893702818502, 12.171406861274475, 96.37327840251308, 49.449293305796964, 56.06687307357789, 47.342482382251376, 101.46452273091963, 37.30938896056145, 0.4623455842656474, 1.0838670788272735, 0.5325544168872218, 0.25065466851717044, 0.6337225172788866, 1.5700017156139499, 4.416602542323451, 8.374691778613675, 7.237199525679312, 1.1617648601531982, 0.7168330059897515, 2.6735894910750853, 25.80921534569033, 90.4151902660247, 95.97946459247221, 97.41295752986785, 97.59839150213428, 96.79678455475839, 95.45809530442762, 92.61196074947235, 91.94049804441391, 93.7102871556436, 94.89903988376741, 91.71467150411299, 93.84353791513752, 94.14549766048309, 85.23163687798285, 81.79941392713978, 82.49277130250009, 81.54784879376813, 86.17283313505112, 83.96912005639847, 75.25198182752057, 71.2161845545615, 74.8637613173454, 72.02394962310791, 69.24669188837852, 77.34172651844641, 80.68312306557932, 86.12241498885616, 81.6764162432763, 85.32969613229075, 87.95234972430815, 89.73678496576126, 89.93536672284527, 87.34290753641437, 86.4677796825286, 90.93336674474901, 86.69507318927397, 81.13844748466246, 82.94876252451252, 85.90258967491889, 77.31961219541489, 74.87506558818203, 85.6341112813642, 84.33084103368944, 73.26230464443084, 76.33245360466742, 86.43214102714293, 75.77405714219617, 81.28278286226335, 89.01178975259104, 66.79217461616763, 66.83543835916828, 83.78693380663472, 70.31838540107974, 72.78699967168993, 71.73785978747954, 76.54596390262728, 73.8369946325979, 78.00096711804791, 73.36959715812438, 73.15306663513184, 74.87795245262885, 76.39246586830386, 72.52132185043828, 64.30347781027517, 65.79460605498284, 69.46842347421955, 64.7902439486596, 73.7737895596412, 71.55994892120361, 78.37040731983801, 71.63223035873906, 75.57687959363385, 72.85691199764129, 77.98659555373654, 76.58011205734746, 74.44689966017201, 71.43860647755285, 69.69046884967436, 68.4187501476657, 70.57833656187981, 71.84745865483438, 75.66848262663811, 75.6576882639239, 77.29107303004112, 74.10142514013475, 78.55171495868315, 73.312181503542, 75.5035940293343, 74.87784262626403, 73.38048565772273, 70.8053162790114, 72.04583644866943, 70.31847169322353, 77.40169171364077, 74.68010810113724, 78.20303193984493, 78.09688475824173, 71.42731789619693, 69.86325710050522, 69.1937477357926, 65.30739276639878, 53.54620110604071, 54.190662214832926, 67.87388586228894, 63.12963401117633, 68.28610343317833, 59.97030996507215, 55.436728615914625, 47.77203290693222, 36.58035762848393, 31.68680467913228, 22.625148988539173, 1.4106181648469742, 2.127947105515388, 0.5740379554129417, 0.9079777653659544, 4.20818446143981, 0.9824109906631132, 1.1953360587358475, 1.1310294126310656, 1.5851963647911627, 0.5692784656440059, 0.40057211513480834, 0.18954910548223605, 62.876268509895574, 46.4682762853561, 64.79915165132093, 49.57703705756895, 70.62467544309555, 27.91687350119314, 0.8958401134417904, 0.2589820595758577, 0.16842127387081424, 0.2204908604823774, 0.19256654195487502, 0.08835586208489635, 0.20220904550965757, 0.13882228714083472, 0.17190744890080345, 0.1460452398826038, 0.27582686214197066, 0.09737868477860767, 0.13001373157866541], [0.030753410368737195, 0.05064798789399286, 0.023615541267058542, 0.019649852653064077, 0.0890707983184726, 0.02724173610218831, 0.020658200561639764, 0.01988668107397614, 0.007796082270121383, 0.014978275303879093, 0.03318357724516142, 0.018550593090514024, 0.3924268231757226, 15.089992496275134, 68.05733511524816, 35.47206055733466, 56.331413407479566, 27.538298099271714, 80.51347271088632, 10.081903396114226, 0.17510583534115748, 0.062396053465143334, 0.36877330693025745, 0.06598882962979617, 0.6536622537720589, 0.3218451202396424, 0.4496627841745654, 0.22219156035252158, 0.224573404317902, 1.3926245368296102, 0.19750938720760808, 12.955398444206486, 63.510037237598056, 79.62707980986565, 86.36437031530565, 91.04815883021202, 87.40904654225996, 86.64110922044324, 82.33677864074707, 79.00878091012278, 77.53570341294812, 80.5737595404348, 81.51259453065934, 79.06694965977823, 80.5613648506903, 81.38734540631695, 77.52287726248466, 71.18402896388885, 68.91596548018917, 72.0381642926124, 70.7675281647713, 64.20967824997442, 66.40634675179759, 73.19826802899762, 71.66516257870582, 74.64454004841467, 70.12687959978658, 74.6220491778466, 75.73284872116582, 79.59819547591671, 80.30058999215403, 73.25921381673506, 78.6395368268413, 76.34072980573102, 76.95669097285118, 76.10173194639145, 77.86357433565202, 79.14607171089419, 76.55868807146626, 73.82423124005719, 72.71327480193108, 69.77843976789906, 70.05591607862904, 77.84193069704118, 76.89759654383506, 63.69990348815919, 74.5836962423017, 75.76352950065368, 73.82401943206787, 76.12580745450913, 80.26861483050932, 59.302043991704146, 59.190887943390884, 79.77081898720034, 67.52907030044064, 74.55971487106817, 73.44464778900146, 72.59980063284598, 72.34272849175238, 73.05133604234265, 70.4084587097168, 65.93558388371622, 66.64704691979193, 68.36351533089915, 68.56029279770391, 70.86037851149037, 74.17310253266366, 62.11219472269859, 60.572174133793006, 64.83740260524135, 64.19853871868503, 61.342959096354825, 62.007498818059126, 66.01442352417978, 73.17013679012176, 67.47098784292898, 67.02755605020832, 70.02744751591837, 72.74394773667859, 71.00742032451015, 69.06813775339435, 69.16704423965948, 63.838076822219364, 63.27077657945695, 66.20419563785677, 65.59326294929751, 67.80226338294246, 65.08896381624284, 64.36392153463056, 67.61567623384538, 67.20134058306294, 63.54823327833607, 67.02661468136695, 62.45276628002044, 64.65627931779431, 57.85975317801199, 63.51439891322967, 67.44044826876733, 67.22663987067439, 67.83515637920749, 69.34293900766681, 62.276706772465865, 58.8839977787387, 51.15749336058094, 47.95801208865258, 31.388443708419803, 41.85623968801191, 47.056929911336596, 42.13356302630517, 49.568239181272446, 43.406152494492076, 26.263996516504598, 10.04030469925173, 4.221410203364588, 2.890829717920673, 3.445954433371944, 0.07975299346951709, 0.29454027572947167, 0.2115293018399708, 0.6166603908904138, 0.43966901398474173, 0.8463933054477939, 0.9741779356714219, 0.04296067478736082, 0.4405467055978314, 0.4359514037928274, 0.27975655611484285, 16.989265911040768, 51.02937306127241, 41.34650022752824, 29.962114980143888, 48.60324198199857, 18.162405644693685, 0.31169770345572506, 0.20084334056704276, 0.08519034081649396, 0.16716977731595117, 0.028028948900980816, 0.06993744597439805, 0.046471418257081704, 0.0748587181911834, 0.05186137157462297, 0.02681835378039508, 0.0599434421277575, 0.02259994425149935, 0.0640187579237165, 0.02408033064115913, 0.003620614602808811, 0.02503392241534687, 0.008895411738194525, 0.041667077870618914, 0.0805741401329156, 0.029332481978100636, 0.017537273271309755, 0.10446049348120728, 0.03823537552248567, 0.033669997111804066, 0.08428888515599313, 0.45858363290467574, 18.990163034008397, 77.16218394617881, 43.8200919858871, 49.50121371976791, 27.52151623848946, 92.00838642735636, 11.610537344409574, 0.29757343232631683, 0.15324476565564835, 0.9132676331266281, 0.19038524448631272, 0.18987447834543644, 1.0987690211303773, 2.464647038329032, 0.05000750774577741, 0.653240476404467, 2.4685755372047424, 0.31111124782792987, 14.70788303882845, 73.46021959858557, 87.0606694682952, 91.7279448047761, 94.87197552957844, 91.42028977794033, 90.56619367291852, 86.55373450248473, 83.46665659258443, 84.35373198601508, 84.35745039293843, 84.74102681682956, 82.45282588466522, 86.76428733333465, 84.82280823492235, 81.81340109917426, 75.97427060527187, 74.06449994733258, 77.01178458429153, 75.94504894748812, 70.94483498604068, 74.09643588527557, 78.60223508650257, 77.04572877576275, 77.9914592927502, 75.40058474386893, 80.75569475850752, 79.80901502793836, 78.20392624024423, 84.22360343317833, 83.21204769995906, 84.80757374917307, 81.0141005054597, 81.36737269739952, 79.35773849487305, 80.5538260552191, 79.99121696718278, 80.20715128990912, 77.13387227827504, 75.285839726848, 73.52670377300632, 74.72632146650746, 81.1107869302073, 75.24338399210285, 66.828307490195, 78.68029809767201, 76.53084708798316, 76.39096752289804, 80.28788151279574, 78.63872097384545, 60.80211524040469, 66.65698620580858, 81.57432479243126, 70.70532721857872, 78.6243337200534, 74.30491770467451, 75.4427972916634, 73.14730859571888, 73.54270704330938, 73.59376845821258, 66.8161246084398, 70.35721686578566, 67.79856851024013, 70.07754402775919, 73.2171267847861, 75.7628470082437, 67.86755515683082, 62.43854376577563, 66.25849693052231, 69.59885797192975, 65.59353751520958, 63.95005264589864, 64.57687877839612, 74.50052630516791, 70.78699096556633, 70.64881370913598, 69.84840700703283, 74.01682746025824, 73.96083170367827, 73.71933137216877, 72.30800767098704, 68.18336871362501, 65.68629372504451, 67.02761880813107, 68.7152813326928, 69.32437835201141, 69.36746951072448, 68.58381917399745, 71.68770836245629, 71.39684892469838, 69.6700176115959, 72.58138902725713, 68.12914586836293, 68.54229696335332, 61.567232378067516, 64.09921253881147, 71.34659551805066, 69.64753458576818, 71.07124513195407, 69.35772634321644, 66.2384222399804, 63.19519250623642, 58.93875014397406, 55.858505002913944, 41.106698282303356, 48.495874943271765, 54.802689244670255, 59.48978431763188, 71.60730761866417, 69.27278349476477, 60.587616505161414, 48.203940776086625, 28.50279715753371, 21.76360038018996, 5.689946086175981, 0.1853826137319688, 0.5518803637354606, 0.17691777117790716, 1.0006812070646594, 1.1711108876812844, 1.688387917895471, 1.1367454091387412, 0.14378624577676097, 0.9073017693815694, 0.4216961009848503, 0.4423574616591777, 18.989413861305483, 53.26566142420615, 38.365859754623905, 38.37670118578019, 54.02105892858198, 23.103303563210275, 0.43509727704428863, 0.16960457327865786, 0.11941755581046305, 0.07684007437238771, 0.06824915672862722, 0.017082805016769037, 0.013414508862150534, 0.03382738221496825, 0.033334224605031555, 0.050255823655114065, 0.12020607478916646, 0.04149619046778929, 0.06227794568985701, 0.18680724615771926, 0.13123481444293453, 0.13097160195391025, 0.10804516443562125, 0.16068006264826945, 0.12691024811037127, 0.11473167176929214, 0.11571706002277714, 0.20594108879806536, 0.16688024204584861, 0.1935256533925572, 0.17531699981660614, 0.613558654102587, 21.973798236539288, 91.39757925464262, 46.54764936816308, 68.9642890807121, 42.47444445087064, 99.05730924298688, 14.7271732553359, 0.4132832604790888, 0.638097001900596, 1.6120923022108695, 0.5008669059363104, 2.4746701650081144, 2.528536564880802, 4.714162859224505, 1.284173085324226, 1.1054620555331631, 4.429230613093223, 0.8272341819059464, 19.17975275747238, 90.92718508935745, 93.58055083982407, 95.60702769987046, 98.03675559259231, 94.33997661836686, 96.65226874812957, 92.66459895718484, 88.60260809621504, 87.6542809701735, 90.67265464413552, 89.62957089947116, 84.86349105834961, 86.21624592811831, 88.79921297873221, 85.25284905587473, 82.84242706914102, 79.88262222659203, 83.50100871055358, 82.71659743401312, 74.62372010754001, 79.39845269726169, 81.786375968687, 80.88883569163661, 82.93644628217145, 78.83578085130262, 86.0271563068513, 82.73277328860375, 81.70158217030188, 85.26238041539347, 84.17921004756805, 86.6077612292382, 86.4642652388542, 89.55801902278778, 84.59884089808311, 84.89505829349642, 85.726090861905, 82.88723622598957, 81.37759439406857, 80.6345719675864, 75.47720432281494, 76.25439843823834, 82.92411435034968, 82.25155338164299, 70.29527479602446, 82.17016420056744, 80.59186520115023, 78.90414776340609, 82.352460276696, 85.98542228821786, 67.00809324941328, 66.61678191154235, 85.28313759834536, 72.04367130033432, 81.38312493601154, 78.97937882331111, 78.7910109181558, 79.52974227166946, 77.77819218174105, 75.82530683086765, 71.39097321418025, 73.71397341451338, 74.11658117848059, 74.83091538952243, 77.28719772831087, 79.13763077028337, 67.37528201072448, 67.40880258621709, 69.22177699304396, 70.70334249927153, 65.96466433617377, 66.58941161247992, 68.1331859096404, 81.48411027846798, 74.15749149937784, 72.0822988017913, 74.0641861577188, 80.16541727127569, 75.48248383306688, 75.64389721039804, 73.36241137596869, 70.49194243646437, 69.57097776474492, 71.5748147041567, 72.83434267966979, 76.21619455275997, 72.08174182522681, 71.74473178002143, 75.81077052700904, 75.81444186549034, 70.41746447163244, 75.81193154858005, 69.9201314680038, 70.26637477259483, 65.13953101250434, 68.61494710368495, 78.92090412878221, 74.20086506874331, 74.65241616772067, 75.92030663644114, 70.87115718472388, 69.88894862513389, 66.06788542962843, 63.124680057648696, 53.26876009664228, 63.836025422619244, 63.054351960459066, 62.61385017825712, 68.98726632518154, 62.51368853353686, 53.011887996427475, 45.038607658878455, 32.57598638534546, 35.78834872091971, 7.479769683653309, 0.42281131049798387, 1.167283634985647, 0.8270418631934351, 2.594750095759669, 1.5031045891584889, 2.6427836860379865, 2.6474760665047556, 0.2804902844852017, 0.9537963809505586, 0.89607484278179, 0.6239900137147596, 25.01448823559669, 65.7814347359442, 60.70199674175632, 40.44548473050518, 65.12481035724764, 28.952179185805786, 0.9210793397599651, 0.3075516662530361, 0.26873720869902645, 0.29642607776388047, 0.1232456282201794, 0.18834493783933504, 0.15493392824165284, 0.17310518140514053, 0.1996088664858572, 0.09954367223526202, 0.1857777159180372, 0.10765872670397644, 0.21064545087996991], [0.05234601028684167, 0.02347554827499534, 0.03174872137606144, 0.05940903068309831, 0.06745599525710268, 0.020453220330959847, 0.04444747907860626, 0.07112165702687157, 0.042006060285794164, 0.07012801800644206, 0.06932854397042144, 0.06232891734989901, 0.21024754481209865, 32.590599175422426, 57.68126180095058, 41.55655099499611, 49.98166876454508, 41.86689676777009, 74.89125713225334, 1.5994112794437718, 0.05390587255298611, 0.0778925566062812, 0.37866996781479934, 0.9299005664164021, 0.24836166010748958, 0.8655880367563618, 1.274981501121675, 0.2884475171806351, 0.39204644519955884, 0.7308806683267317, 6.283111908743459, 53.6574669807188, 82.64422185959356, 81.9868169292327, 91.32844355798538, 89.8822735201928, 88.20746852505593, 85.3107746185795, 78.40374746630269, 80.75940532069053, 81.3865452428018, 85.51400046194755, 83.53776916380852, 80.57335945867723, 79.5033682546308, 80.93603749429026, 73.6856460571289, 70.4951274010443, 69.5093337951168, 73.88093302326818, 73.18179407427388, 75.29958371193179, 72.82569777581, 73.6437237647272, 76.93880496486541, 73.43410445797828, 75.66139098136657, 79.17605430849137, 76.94140941865983, 73.39869330006262, 79.76739868041008, 81.35801392216837, 80.62048281392744, 75.69725713422223, 75.52552792333788, 77.38896754480179, 78.60425902951148, 75.78068594778739, 74.81193896262877, 69.6746773873606, 71.05837975778888, 74.14188831083237, 78.59727721060477, 73.694502768978, 63.82034770904049, 77.01084321545017, 78.2680569925616, 74.71828060765421, 78.56792219223516, 75.93336028437461, 57.81010381637081, 61.825226276151604, 76.12040242841168, 74.86733067420222, 73.67205112211167, 67.28033711833339, 63.196051505304155, 64.89733249910417, 67.05489497030935, 63.2090384729447, 65.26531357919016, 63.19165845071117, 67.86379752620574, 66.3623534479449, 64.91602259297525, 68.44870921104186, 69.66882521106352, 71.53520661015665, 65.02261300240794, 59.90267261382073, 65.66026095421084, 68.2817574470274, 62.62559375455303, 60.6470835593439, 57.87363444605182, 67.11118882702243, 68.11606084146808, 66.73405293495425, 65.51830645530455, 69.49222441642516, 68.95441255261822, 69.45839005131876, 71.8442266218124, 63.289199952156316, 61.94785917958906, 65.41554427916004, 64.630481889171, 66.45669429532944, 64.93282602679345, 66.55877005669379, 65.56492382480253, 65.15487532461843, 63.63822813956969, 64.83333510737266, 64.53864743632656, 63.67967582518055, 54.25123929977418, 64.20617165104036, 66.52407277014949, 66.69021652590844, 66.98215069309359, 67.52728954438241, 65.06649255752563, 57.538471837197584, 51.64500867166827, 46.95832936994491, 33.969400544320386, 46.32223075436008, 42.16564801431472, 48.470097126499304, 44.07696800847208, 40.58113598054455, 20.38136693739122, 11.1463846506611, 4.143542330111227, 6.389952369274632, 0.7780137069282994, 0.076039619743824, 0.14153161837208655, 0.286119069543577, 0.7405285957840182, 0.1694676274013135, 0.027529946040181864, 0.053295836738881566, 0.36824755610958226, 0.10284992385535471, 0.1877436047840503, 4.091480710814077, 54.78657614800238, 35.30851733299994, 27.08605862432911, 47.703363972325484, 25.299281727883127, 0.2648350632479114, 0.208108167674753, 0.11818070685671223, 0.1186005536827349, 0.02883266706410195, 0.07515964518872, 0.09933443830138254, 0.01931475238844512, 0.11953167992854312, 0.02009521978306434, 0.05635092260255929, 0.05409318488091231, 0.02261923051499311, 0.09395754295251063, 0.03764077254961576, 0.04632696471807938, 0.05803546567838039, 0.027691590592205047, 0.04688443540925941, 0.05472907233202169, 0.019560969216869246, 0.02511170715273869, 0.016844833209629984, 0.054662319260739514, 0.07281801317848506, 0.19966992369342237, 39.85774501677483, 66.4935645749492, 53.33033738597747, 39.359243146834835, 43.60397331176266, 83.54384883757561, 2.036103704763997, 0.019516151158079025, 0.17992175514659575, 0.36336328593953965, 0.4472310678853143, 0.12624298552832297, 1.8573166790508457, 2.1896776124354336, 0.32824618321272636, 0.39449522992776287, 0.682824585706957, 7.855162572476172, 64.86139966595557, 93.72145806589435, 89.04500438321023, 95.57134982078307, 92.08152294158937, 90.32166527163598, 87.93764083616196, 81.42830279565628, 85.68671811011531, 85.8007335662842, 89.62489543422576, 88.15322999031314, 82.6624216571931, 83.77333102687713, 83.00689205046623, 80.22607280362038, 75.4188237651702, 75.2311775761266, 77.02077465672647, 76.98740313130041, 80.95284877284881, 78.13916006395894, 77.89639672925396, 77.56793745102422, 78.83910702120873, 79.43117310923915, 82.5277509996968, 80.41450346669843, 78.19444194916757, 81.02029785033196, 82.71490297009869, 84.51751447493031, 80.73551808634113, 81.48872298579063, 81.89448433537638, 81.84765908025926, 77.94308862378521, 74.86942521987423, 73.29395032698109, 73.68895653755435, 79.11707755058043, 79.68147523941533, 72.53272025815903, 69.24586819064233, 79.92529761406684, 75.54138214357438, 76.95072112544891, 80.58888419981926, 74.24617628897391, 59.66074474396245, 69.41656189580118, 78.50852966308594, 77.1980030305924, 73.48030997860816, 67.81014734698881, 66.4829114175612, 68.34003602304767, 69.56416068538543, 68.94248070255404, 69.32444110993417, 67.14500750264814, 70.29219965780936, 68.96639147112447, 68.05272240792551, 72.73415750072849, 71.5487309425108, 73.2460189634754, 69.93796256280714, 63.304963957878854, 65.25563316960489, 70.49046762527959, 66.27679870974633, 65.38155694161692, 60.04341510034377, 67.29646590448195, 70.35208640560028, 72.44233315990817, 69.58199962492913, 71.69665136644917, 72.2411547937701, 72.1817465751402, 73.85420599291402, 68.49611497694447, 64.85344509924612, 68.31848652132096, 67.33106905414213, 68.29566617165843, 68.84924596355808, 70.22784140802199, 68.34548027284684, 67.13598605125182, 68.93508311240905, 69.4961154076361, 67.65241315287929, 67.19115811009561, 56.51312897282263, 66.19204413506293, 68.16895008087158, 69.1441297531128, 65.88437341874646, 69.24448751634168, 66.00368407464796, 61.6481783313136, 58.574585530065725, 56.915571997242594, 43.072594135038315, 55.22067662208311, 56.48500557868712, 67.44247221177625, 64.24370088884908, 70.22408377739691, 54.51457154366278, 45.05701141972696, 23.959188269030665, 10.953873742011286, 1.4527640323485098, 0.11647349523921167, 0.08666004219482984, 1.1729742586612701, 2.4259001497299444, 0.22321373614813053, 0.4151527908059859, 0.052802541233118505, 0.08105407123483958, 0.13642941150934468, 0.20395178828508626, 4.06287927781382, 62.46678090864613, 30.598517579417077, 28.11906776120586, 56.66817242099393, 31.33788435689865, 0.20733659456093467, 0.10440938775577854, 0.03706286263261591, 0.029583029118516756, 0.030995980618641745, 0.03481348293022283, 0.1152916897028204, 0.0419019412760052, 0.04031857543234383, 0.04142626579250059, 0.046754587336533496, 0.06892604903588373, 0.06614902627564247, 0.13272016699756348, 0.13772367109214106, 0.18833816562208439, 0.19223634273775164, 0.1502794691271359, 0.1956806280800412, 0.17997269999356041, 0.27101144795456245, 0.1044180598710814, 0.2229191753412447, 0.18383205177322512, 0.15332941837128133, 0.3977025642750725, 46.77710802324357, 75.63867261332851, 55.56249941548994, 69.55047161348405, 61.010910849417414, 92.06575501349666, 2.76556711043081, 0.16254628347533365, 0.29816543443068383, 1.804499268051117, 2.085015783386846, 0.6912361085414888, 3.8081161870110423, 4.492911763729588, 1.444318433923106, 1.1882001642257938, 1.5785663334592697, 10.421738528436231, 81.51184143558626, 103.15217741074102, 96.38753229571928, 101.95710182189943, 95.44334719257971, 93.22225801406368, 93.3001405962052, 86.47760129744007, 88.04285449366417, 87.84088380875127, 92.74891422640894, 91.57018707644556, 86.37266220584993, 87.24454233723303, 89.1651544263286, 84.79521828313028, 79.09209989732312, 79.59060176726311, 79.70194216697448, 80.64200093669277, 84.99018361491542, 83.30174446105957, 83.65719749081521, 86.766844718687, 84.24640024861982, 83.70546617815572, 87.71731345884263, 83.81932473951771, 80.51937980036583, 85.51833860335812, 85.69436673195132, 88.66753901204756, 82.71286333760908, 83.1533847316619, 87.1881151199341, 85.58645448377057, 84.641814385691, 79.19048078598516, 76.09755069978776, 76.44872834605556, 80.87984561920166, 82.60962655467372, 79.4880239425167, 71.86002592886649, 83.47624286528557, 81.44262729152557, 79.91595452831638, 84.40203205231698, 80.89079687672277, 63.207602885461625, 69.1330216007848, 84.02469219699984, 82.04689195079189, 79.54865594064036, 72.03695620259931, 70.89473847419985, 72.17499225370346, 72.46457299878521, 69.68234169867732, 71.29021536919379, 70.24213452492991, 73.74613684992637, 71.4304950160365, 71.40965154094081, 75.86058462819746, 76.1271567498484, 77.47192567394626, 71.47408039339128, 66.02608865307224, 69.45933926490046, 71.97280976080125, 66.48502165271391, 66.65202832991078, 62.002274220989605, 73.28776082684918, 72.65695741099697, 74.67932362710276, 70.23135585169639, 74.75355056024368, 74.29752795926987, 73.45325346915953, 77.17399812513783, 69.39307474320935, 69.21246528625488, 70.19250869750977, 70.56399637652983, 73.13339202634751, 72.06591113921135, 73.40565942948865, 72.94130571426885, 72.04939011604556, 71.57209257925712, 73.98575444375315, 69.8061473907963, 70.00840833110195, 60.78307997795844, 72.79621724159487, 71.793730028214, 75.86790377093901, 71.78802690198346, 75.67931621305405, 73.30508985827046, 70.6262836148662, 65.50830833373531, 64.54426034804314, 54.68033482951503, 67.83179098559965, 62.1114416276255, 70.22165190789008, 62.382104781366166, 62.55172767946797, 46.398379648885424, 41.75406586739325, 29.57719122209857, 22.97922330517923, 1.4463654208567835, 0.5827378337421726, 0.7336377881227002, 2.255433451744818, 4.83498853060507, 0.7178230980230916, 1.2231376959431557, 0.24190488722055192, 0.860884931058653, 0.4686102835882095, 0.6062298280096824, 7.1091262948128495, 73.87442188878214, 47.90887655750398, 36.80836500660066, 63.220848729533536, 36.607131727280155, 0.6030943833531872, 0.4104176932765592, 0.3345621491391813, 0.255677922358436, 0.15999586952309455, 0.2169581532718674, 0.17794541684129547, 0.13248272570631198, 0.2073963034537531, 0.14732092949411563, 0.15278534272745734, 0.20503192629304626, 0.1869134565875415], [0.02747330341428038, 0.04894580564371521, 0.01812989782211521, 0.03170271396576878, 0.009838255298804614, 0.07556517383143788, 0.043077821122302164, 0.03217701049100968, 0.07421956337507694, 0.011185654570468733, 0.028865371357589483, 0.007451889020646172, 0.3156251604518583, 53.95162120942147, 48.47450979294316, 32.070902778256325, 33.28637076962379, 50.27753706901304, 47.72432511852634, 0.0908437172972387, 0.21040767251003176, 0.07630631793290377, 0.2900198973234623, 0.36265333693835045, 0.30987781562632133, 1.625124867404661, 0.42415613188378276, 0.10799667873089352, 0.22349801605507252, 1.2000860490145222, 25.913264059251357, 77.23118628225019, 79.08170561636649, 90.8599478198636, 86.6239292390885, 87.04376405285251, 82.21615006846767, 79.16638958838679, 76.29471255886939, 81.48109789817565, 84.83949399763539, 81.14560973259711, 80.45973623952558, 72.65160729808193, 81.1338504668205, 78.95885698256954, 74.21354216914024, 77.25861149449503, 73.94827227438651, 73.55482716714182, 79.09592028587096, 73.90184710102697, 70.96359960494503, 69.56546291228264, 73.34232884068643, 73.56121278578236, 76.9553416775119, 74.07246235878237, 75.54759517792733, 81.62678257111581, 77.07351484606343, 76.54145317692911, 76.46226836789039, 77.11928106123402, 78.19662278698337, 77.1675968170166, 72.69744411591562, 67.49406706902289, 71.41711188900855, 72.46738141582858, 75.49328604052144, 77.03533449480611, 67.38960650659376, 64.19055669538437, 78.70528359566966, 78.99862981611683, 75.93070876213812, 78.68457348115983, 73.2934404188587, 57.75097408602315, 68.1203362249559, 78.38191555392358, 71.03367667044364, 70.03111885439965, 61.84931747374996, 62.509934825281945, 69.00410113796111, 70.02823983469318, 72.8616423760691, 72.44582406936154, 67.74889561437791, 67.70555342397383, 65.12211568893926, 66.73723789953416, 69.62826790348177, 69.27740404682775, 70.5502131677443, 66.05935035213348, 73.02336954301404, 66.01728685440557, 53.82898830598401, 68.08321491364511, 70.35851124794253, 66.43352877709174, 64.75124774440643, 59.70756215433921, 62.34142588030908, 67.47821284878638, 69.5812935982981, 67.05244741132184, 66.80231786543324, 66.4566707611084, 66.85325376449093, 69.96696456786125, 67.39499584321054, 62.941517137712054, 63.83925745564123, 67.2971248626709, 64.0133479333693, 65.9663038869058, 65.6322003179981, 67.06062163076093, 64.89600281561574, 63.441168262112534, 61.40630537463773, 65.27575492858887, 56.150902009779415, 57.460718693271765, 64.73591127703267, 63.69296089295418, 66.82303582468342, 64.3485144645937, 61.5918452508988, 61.13484205738191, 55.03292845141504, 55.37774009089316, 41.9598687079645, 42.47114965992589, 47.309338354295306, 50.79259526345038, 50.01461667399253, 44.83382463455201, 33.67910200549711, 22.188581343620054, 11.880289527677721, 1.7177849791703688, 2.428042744436572, 0.1683976630409879, 0.09166859480882845, 0.29559753835201263, 0.2372510409763744, 0.15692563427071418, 0.33552401849339086, 0.24184807414008727, 0.02536548526897546, 0.0937575556998772, 0.08878800462210372, 0.08508783059134599, 39.24497665897493, 51.26350325922812, 35.66823397913287, 41.855145346733835, 35.83074562011227, 0.06529190412331974, 0.040567259063884135, 0.07846711488861231, 0.04313257725669011, 0.04670650382796603, 0.05161059269260976, 0.06077300043656461, 0.03531316377883477, 0.0287975438479935, 0.011141565252816486, 0.030722247827197277, 0.013384099959606125, 0.01936784802725719, 0.01149659242195588, 0.07732158361543572, 0.04997312955017533, 0.04569281628655811, 0.020070329586404468, 0.03558610941493704, 0.06551848994868417, 0.022553582525541706, 0.0660663653886126, 0.03971836086542856, 0.028489561180674264, 0.04838735819043172, 0.49711396376932826, 64.12761049885904, 55.542358044655096, 47.693393307347456, 35.84397577470349, 55.40413371978268, 56.047021958135794, 0.058977087328751246, 0.061788377201845573, 0.13980324740611738, 0.18561421743323728, 0.4133944658021773, 0.5533746029100111, 1.7501217343153495, 0.5488832439145734, 0.5750509075099423, 0.18570093858626582, 2.009492261755851, 30.116407294427198, 87.03381692209553, 85.64878094580867, 96.97472679999568, 90.82633310748686, 89.22329964176302, 84.6480195753036, 82.70608548195132, 82.1269553707492, 87.04075167256018, 89.54647940974083, 85.6574886075912, 82.04507981577228, 73.2084426572246, 83.44962566129624, 82.72549336956394, 80.10855074851744, 79.4669137462493, 75.68713741917765, 77.06741948281565, 79.86818005961757, 76.24462389176892, 74.7636781200286, 75.45488603653448, 76.72762455478792, 75.76458069585985, 80.45156202008648, 79.19036311487999, 80.048993479821, 81.88795751140964, 78.336376836223, 80.63974165147351, 81.2171459197998, 81.43341756636097, 82.56001641673427, 80.93035790228075, 75.60865079202961, 72.6507051529423, 75.56242958191903, 79.35903287702992, 78.73318733707552, 80.15488178499284, 68.51523260916433, 68.783232473558, 81.71181955645162, 77.34705309714042, 77.25515196400305, 80.79018808180287, 73.51814516129033, 59.46384960605253, 73.21935469104399, 79.59323760001891, 74.12471617421797, 68.64655356253348, 64.01731344961351, 68.8681439430483, 72.21100745662567, 74.38509095099666, 73.480419804973, 73.93531276333717, 72.39434688322007, 72.40419987709292, 68.00906642790764, 69.54046956954464, 74.04649626824164, 68.80275018753545, 73.03589759334442, 68.42066426430979, 73.46088640151486, 70.74353894879742, 57.71810070160897, 67.3280958975515, 73.91680702086418, 69.56354879563855, 68.56374448345554, 61.778891317306034, 63.5599886217425, 68.99881378296884, 72.51206505683162, 70.04000694521012, 70.98172879988148, 70.90728221401092, 68.53995923073062, 71.94389404789095, 72.47623812767768, 65.89188867999663, 64.16293144226074, 70.16960205570345, 66.57296903671758, 69.63568902784779, 69.51384452081496, 71.42092443281605, 69.59160158711096, 67.07497750559162, 65.19657404192033, 69.62243141666536, 61.27874597426384, 60.14113310844668, 68.07553491284771, 67.02336695886427, 67.71644192357218, 68.21171176049018, 63.79402468281408, 64.65636953230828, 60.485850611040675, 61.65385007858277, 52.515119814103656, 50.737336912462794, 53.86894549092939, 66.25794779869818, 66.81913698873213, 67.7147945280998, 62.14726071203909, 57.50224482628607, 36.25969994452692, 18.642233110243275, 3.58438860504858, 0.2620797514194443, 0.08010871107539824, 0.8965966405887759, 0.3168570604776183, 0.819583660171878, 0.3648485159201007, 0.2526892754699915, 0.10295724511266717, 0.13843132182955742, 0.11909001491843693, 0.13468147465778937, 44.898783006975734, 46.711208281978486, 33.70096137446742, 50.68694230048887, 42.56132887255761, 0.17582154532353725, 0.05879005845335703, 0.057545288150469144, 0.041601025769787456, 0.05989660351206699, 0.02575905144875569, 0.03457024235338454, 0.027495962379860784, 0.05636172827273127, 0.02758546060161485, 0.07318077879326959, 0.040432408437012665, 0.07280697385149618, 0.1901376295474268, 0.13351507514955538, 0.19004890124403662, 0.09155769592090961, 0.10674073886606963, 0.130026402672933, 0.11857836777644774, 0.08668757539482848, 0.21888694816058685, 0.2244654165640954, 0.1651231734262359, 0.2376557192614963, 0.682634963623939, 72.46163906589632, 64.71175732151156, 40.07107488570675, 46.91689737381474, 68.09682553814304, 59.89177234711186, 0.30253614989980576, 0.41448607980724306, 0.24987613932499964, 1.041144010040068, 2.3988997792043993, 1.2222156938045257, 3.5257084763819173, 1.3828155470471228, 0.9462931932460878, 0.17118524249282577, 3.9361146476960953, 38.04344092645953, 100.77005140243038, 91.13702404883601, 103.55293381598689, 91.01509324965939, 94.58954134295064, 87.20590699103572, 90.07311251855667, 86.72888402015933, 92.33616321317612, 94.25549660959553, 89.06346305724114, 87.07845349465647, 75.82951945643272, 87.05646468747048, 88.02128145771643, 84.12857224864345, 85.80975501768052, 83.1318195404545, 81.53590125422325, 87.9146400574715, 82.48615818638956, 80.76257459578976, 79.0849768730902, 82.66820323082709, 78.99790025526478, 84.33684226005309, 82.60107578769808, 84.10206487101894, 83.74244628414031, 81.68703017696258, 83.19460099743259, 82.18160183198991, 85.43884784944596, 87.86649688597649, 84.74372540750812, 80.1607261165496, 76.25338646673387, 80.73849908767208, 79.46262267328079, 78.53684133098972, 80.5416274839832, 73.2850073229882, 70.1178503036499, 82.81244447154384, 83.74917707135602, 80.8013197683519, 84.54638311939856, 78.02269704880254, 63.53699961016255, 72.11847874426073, 83.26717269036078, 75.29118983976304, 74.76887918287709, 68.91618513291883, 69.75783163501372, 75.26308997984856, 75.65875514861077, 77.69492026298278, 77.26475392618488, 76.61634691299932, 76.54532847865936, 70.41320477762531, 71.06617742969145, 75.21767677799349, 74.48678232008412, 77.13220134858163, 70.34330814115464, 79.63135519335347, 70.66207132031842, 60.60680081767421, 71.88199120183145, 75.0990564592423, 73.12320955338018, 68.78308342349145, 66.20398382986745, 68.81948301869055, 72.87402922107329, 75.99074455999559, 72.59665489196777, 72.60317387119417, 72.14066366995536, 73.77786097988006, 74.9911363663212, 75.9764200641263, 69.53556660682925, 70.30932472598168, 72.80023374865132, 69.2681315637404, 75.30513778809579, 72.35837090399959, 73.2104273765318, 72.51191600676506, 70.72475864041236, 69.39386706198417, 72.91216250388854, 61.200349561629764, 63.147378813835886, 72.961545144358, 73.4184463562504, 74.10574759206465, 71.999936872913, 72.21609869310933, 72.01391620020713, 69.40539098555043, 70.88530125156527, 60.02448966426235, 64.24699567979383, 64.16899542654714, 72.3186529836347, 67.21216632473853, 64.77762176144508, 54.628469328726496, 50.140701263181626, 36.41686147259128, 29.568344316174908, 4.29457466448507, 0.814844701559313, 0.37096673923154033, 2.6767798489139927, 1.5700465777227957, 1.4114510556382518, 0.6816980074490271, 1.4190535896247434, 0.326145937846553, 0.2811680577935711, 0.3331121285596202, 0.6781029713249976, 52.59555978159751, 68.74682503361856, 51.726476300147276, 57.13329884313769, 52.72102463629938, 0.26795622802549796, 0.17510434913058437, 0.2130895011848019, 0.12932717890268372, 0.22990395134735495, 0.08126412488279805, 0.13823206236045207, 0.15019519945546506, 0.24911244159504292, 0.17128642738586472, 0.12887901746697966, 0.1084501721385506, 0.15619228894431747], [0.055130670943688, 0.023310944708364627, 0.021372073848221092, 0.04621699662698854, 0.013884456880811243, 0.029805284631889195, 0.02454200012218808, 0.01577973063479388, 0.05006465024404949, 0.014470419339505176, 0.057766618612673015, 0.05645584983510837, 1.775299305877378, 58.00740688077865, 45.625974747442434, 43.32808948332264, 34.0972541224572, 64.9362345664732, 21.28289234253668, 0.22536710205097354, 0.30274391294487063, 0.05935559221994012, 0.25668932695782953, 0.3117539649528842, 0.3836325015271864, 0.2271845996860535, 0.6360502601150544, 0.14410265541124728, 0.7300132116483105, 6.801978724618112, 51.91778598293182, 76.5728086040866, 85.24059557145642, 85.88666485201928, 84.65848445892334, 80.64516236705165, 84.94016555047806, 76.49987605310257, 79.46510945597004, 80.17722360549435, 83.1234884262085, 82.30044964821109, 70.08442386504143, 77.6476792366274, 75.14250063127088, 76.15640978659354, 77.2934970548076, 74.1132079401324, 70.62470682205694, 72.51048041928199, 74.53026571581441, 74.68564648782053, 72.91018562932169, 70.65791360793575, 74.62704627744614, 72.80735677288425, 74.18225734464585, 75.93535284842216, 79.8715768321868, 76.24905617006364, 75.59183951347106, 79.16495400090372, 81.38448207609116, 78.78270333813083, 75.69347596937611, 71.96596914722075, 70.94131269762593, 72.50892716069376, 76.56278302592617, 79.6348225685858, 75.94685323776739, 67.57607598458567, 65.16050784818589, 80.79338089112314, 74.8582229306621, 74.91113570428665, 75.97266243350121, 74.85972127606793, 58.32309492172734, 66.29947785408267, 78.95517779934791, 73.91138630528604, 70.87840572480233, 63.92307066148328, 73.23828404949558, 72.7516120479953, 71.32506170580464, 69.17094307561075, 65.03896536365633, 65.98077743284165, 69.61921507312407, 67.88250723192769, 67.66236812837663, 64.93399097073463, 69.5378415815292, 68.36219741452125, 69.80167588879986, 69.92449314363542, 65.0809072679089, 68.25715634130663, 67.21520223925191, 55.35891271406605, 67.98903096106746, 69.16193731369512, 67.8734936252717, 64.92796621014996, 62.04700100806452, 58.60627828105804, 61.122686632217906, 66.31927013397217, 66.7395991663779, 70.38064910519508, 67.35947485893004, 65.64827026859408, 70.70440153921805, 67.83070841143208, 62.29659318923951, 63.86281913326633, 64.34378016379573, 62.35524831279632, 65.51768279844715, 66.16858836143248, 65.0425974784359, 63.11568998521375, 63.7176404460784, 63.86515294351886, 65.83451224911597, 58.656488541633856, 62.72860304001839, 62.31254546873031, 61.82784249705654, 59.53049852002052, 60.26416217127154, 58.783691006322066, 58.13780999952748, 59.63712423078476, 59.066517429967085, 43.03881860548451, 52.83901345345282, 48.36236530734647, 57.00655529575964, 52.263229124007694, 47.42839013376544, 31.97705811069858, 21.108164479655606, 10.585410210394091, 4.013140437103087, 0.3939141369154377, 0.15217282478847813, 0.1658540979147919, 0.1611624375706719, 0.8552115290395675, 0.6357213938909193, 0.4573484540225998, 0.039708060813286615, 0.11490420243071933, 0.07871755669193883, 0.06859964195398555, 18.27650543182127, 52.28779100602674, 33.784598073651715, 37.70629359829811, 41.235226508109804, 0.30086117526215894, 0.06601101553608334, 0.029128384663753455, 0.05376319633796812, 0.0660132295301845, 0.06911785446948583, 0.05318166665552605, 0.026856539432980844, 0.05854604795815484, 0.060395384207367904, 0.025729214239324776, 0.10270921648630213, 0.04696187540708531, 0.033119930660412196, 0.008344476734618507, 0.026567525102666793, 0.028541681972602685, 0.061907848613637115, 0.03243140913846512, 0.047199167311191566, 0.04971967702130637, 0.024004853743639205, 0.057228407371909394, 0.029949498768415184, 0.09402757871054834, 2.447289079427719, 69.77058718281408, 51.534644942129816, 45.63905192959694, 29.866860220509192, 70.90966701507568, 27.510313949277325, 0.19875863146397377, 0.12938881833707133, 0.08921607923243316, 0.17540722965232788, 0.33336959538921235, 0.40312882632978503, 0.7367753778253833, 0.7337205869055564, 0.40589397472719996, 1.0375052762608374, 6.615765671576224, 63.46482799899194, 89.11377137707126, 91.65698912835892, 92.80564738858132, 87.89486346706268, 82.6109209368306, 89.1503200223369, 83.47448564344838, 83.26113224029541, 83.00391889387562, 88.2722503908219, 86.6866087144421, 77.71938016337734, 77.34262081884569, 76.37796878814697, 80.85448357366747, 79.72635499892696, 78.31140702770603, 75.25922252285865, 73.84255655350225, 76.65062058356501, 77.44622630457725, 77.22953888677782, 75.15918639398392, 78.0731701081799, 76.74397299366613, 78.21370078671363, 81.07427750864338, 82.14604946874803, 79.20112609863281, 77.94014684615597, 79.7119991240963, 82.74334015384798, 82.03791756783762, 78.41834652808406, 73.97842745627128, 75.16190067414315, 76.88045578618204, 78.7645584537137, 80.2273593410369, 76.81960413532873, 68.14370570644256, 69.28406423138034, 84.3171754960091, 74.77586100178381, 74.60354343537362, 77.7542814131706, 72.70113898861793, 59.633774526657604, 73.14836763566541, 79.28884598516649, 75.03083859720539, 67.6933313185169, 67.0607393018661, 75.82569122314453, 73.4002544033912, 73.36268594188076, 71.78394763700425, 67.53922923918694, 66.90807281001922, 70.91854726114582, 68.57145586321431, 70.32823055021225, 69.71594856631371, 71.89429959943219, 67.98190793683453, 70.74272309580158, 72.83662549911007, 68.41662422303231, 67.50163724345546, 70.1249497936618, 59.510741541462565, 64.41785804687008, 72.8719425201416, 71.21829478971421, 71.12839406536472, 65.04349570120534, 62.6300613341793, 63.30612105707969, 71.02642028562485, 70.60438894456433, 70.69401510300176, 68.63903045654297, 66.34011360906786, 73.27345202046057, 71.3175307550738, 66.87756461481895, 65.20584652500769, 67.90739859304121, 68.61155033111572, 69.82515519665134, 68.6170102703956, 69.49911209844774, 68.46446144965388, 67.11191054313414, 66.52444931768602, 67.26274921048072, 61.262727014480106, 64.95515215781428, 66.59939796693864, 66.53497695922852, 63.95874854057067, 63.29825278251403, 62.47281743634132, 62.91166397833056, 65.31399803776895, 66.15789598034274, 53.142408786281464, 59.15635931876398, 59.59245627926242, 67.9416173504245, 65.84114889944753, 72.0892963101787, 61.21106155457036, 50.19462600831063, 30.235160973764238, 5.195671550689205, 1.4138899118669572, 0.07631731895549644, 0.4019291939273958, 0.8126718310579177, 1.5321823449865466, 0.8209754887127108, 0.9869068236120286, 0.06916001228795898, 0.25529117053074224, 0.0778835550731709, 0.34910786055749465, 22.484932099619222, 54.85305640005297, 33.48586251658778, 48.26861673785795, 47.47616852483442, 0.378593604170507, 0.07682703555591645, 0.046385501496373646, 0.06634879136277784, 0.007593576503436893, 0.04799870646468574, 0.02759225963194284, 0.049068651672813206, 0.036837996674641486, 0.053458427409491235, 0.07204095487512889, 0.048285506800898624, 0.04800318807904278, 0.10535650225656648, 0.09165056875997013, 0.15836764157058733, 0.1335892477823842, 0.1715013303703839, 0.11209521848227709, 0.24082660314536866, 0.15539951051675505, 0.1977638509725371, 0.16034554269525314, 0.26020200862999887, 0.38736567862572213, 3.737072502413104, 79.52287027912756, 61.05986202916792, 54.15762016850134, 48.193773992599986, 85.38140081590223, 34.59619922022666, 0.30239396398105933, 0.6431998216336774, 0.30402763115782894, 0.5805500092044954, 0.7904585907536169, 0.8580083015464968, 1.0812323492380882, 1.7056581137641784, 1.0253132014505326, 1.897378174527999, 8.334222724360805, 78.9995554954775, 100.67052518167804, 99.30196316011491, 97.66482076337262, 91.26078267251292, 88.27296426219326, 92.6795510322817, 86.170667986716, 89.04618109426191, 87.29026932870188, 93.77908552846601, 89.16742940102854, 81.80958855536677, 79.84100587906377, 81.87048727466215, 87.35398430978098, 84.07089771762972, 83.27909669568463, 78.14902874731249, 79.78728509718373, 83.38701678860573, 82.84070907100555, 83.12826587307839, 80.54828766853579, 82.37187600904896, 82.94882528243527, 82.27868049375473, 84.39963940651187, 83.8657969813193, 82.8133152377221, 83.31289968182965, 85.03941720531833, 90.57269696266421, 87.00180253674908, 82.46594229052144, 77.680038790549, 77.28413043483611, 79.09963084805396, 84.7677303129627, 82.88676554156889, 83.23128300328409, 74.73878675891508, 70.26711217818722, 86.8169726094892, 79.61809758217105, 77.31684300207323, 81.57627028803672, 80.56059606613653, 64.0301513671875, 71.42650988794142, 83.33244093002813, 77.3385964670489, 76.12604279671946, 69.48656051389634, 79.42155545757663, 79.45326389804964, 76.69369605279739, 74.53896553285661, 72.24934470268988, 71.27815800328409, 74.18303397393997, 72.1841235314646, 70.61781914003434, 72.11180287022745, 79.07171141716742, 72.06449124120897, 75.98701046359155, 73.76123797508978, 69.47830784705378, 71.0313154035999, 70.87967657273816, 62.61198705242526, 71.48528268260341, 73.81877914551767, 74.26349747565486, 72.77222802562099, 67.96726965135144, 65.80070141823062, 66.41285788628363, 72.25340043344806, 71.27361589862456, 74.0642567603819, 71.72095437203684, 71.26351187306066, 78.14316872627505, 72.71717363788237, 69.11982674752512, 68.7176896679786, 71.77309836110761, 70.31483957844397, 74.34723223409345, 74.06036576917096, 72.5151558845274, 70.51006378666048, 71.68726121225666, 70.67979258875694, 72.42083857136389, 65.69375407311225, 68.76589559739637, 70.33962111319266, 72.89047964157598, 69.48622319006151, 70.22392688259002, 67.96677543270972, 69.20130222074448, 72.93205676540252, 73.22635219943139, 59.86238987215104, 70.17868626502253, 66.19031044744676, 74.91254775754868, 68.9846932503485, 69.66444000121086, 55.417811024573545, 46.47231632663358, 40.2937243061681, 9.800941078893601, 2.453963237424051, 0.3902051988388262, 0.918566816516461, 1.4443603542543229, 3.3661972034362058, 1.9937072958677047, 1.9463547271105552, 0.16149793811623128, 0.38281333903151177, 0.20595429615387995, 0.5797826342525021, 29.870921834822628, 70.1240005800801, 46.22327327728272, 50.821895368637584, 56.42422060812674, 0.4996849548432135, 0.2199214732935352, 0.2382418837758803, 0.09039274431885251, 0.22629328702967014, 0.1787448755555576, 0.17906033524101783, 0.20774352514455396, 0.16018377556916208, 0.12123027305689552, 0.15860007264681403, 0.20041299833645745, 0.17278350108573515], [0.043448676625567104, 0.032472433146810344, 0.029833227688927325, 0.03933398007986046, 0.03370682678876385, 0.04624625735525643, 0.0355450279499975, 0.04230021123564051, 0.0765117290880411, 0.0451224829791294, 0.057217938780424096, 0.2102165029294068, 4.6097763315323865, 63.226073326603064, 43.04084254849342, 58.47657726657007, 38.4391963097357, 57.19033010544316, 6.126929012037093, 0.12188537016270623, 0.17942474794483956, 0.17183103929123572, 0.09425237189016997, 0.07482895567532509, 1.0231730582252627, 0.6899139633582485, 0.12479670345783235, 0.13031078983218441, 0.11012449560146179, 18.698232789193433, 65.70419934488112, 72.43065234153502, 87.23872938463765, 82.02534244906518, 85.31254752989739, 90.11577221655077, 89.25056795920096, 81.96038015427129, 75.62375191719302, 82.67978991231611, 84.42154976629442, 83.93612507850894, 80.7083046820856, 84.21195399376654, 79.61786223996071, 76.68148963682114, 78.9469486667264, 76.09154162868377, 74.05797312336584, 71.28299036333638, 74.23073783997567, 72.41005989813036, 71.45732402801514, 73.85825387893185, 76.49239217081379, 73.06088309134208, 75.94202087771508, 76.67958336491739, 77.41679283880418, 77.48037445929744, 75.86459329051357, 79.70348758082237, 75.51062291668308, 71.28835616573211, 71.50405514624812, 71.3935305995326, 76.52695609677222, 76.0735850180349, 78.33531779627647, 73.18876020369991, 65.71282071451988, 66.80849167608446, 80.834714827999, 72.80092408580165, 75.23054999689903, 73.76219503341183, 72.24684223051995, 57.46801430179227, 67.4749808157644, 76.81545426768642, 74.4230830284857, 69.28410345508208, 61.109785956721154, 73.68494787523824, 71.09366539985903, 69.17485760104272, 68.64681243896484, 71.65621957471295, 69.46235948993315, 67.89162282020816, 70.33846009162166, 69.61941119163268, 68.4307369109123, 68.2772937897713, 64.89133911748087, 61.54472189564859, 65.3477539554719, 68.29729787765011, 71.14148693699991, 64.4052319372854, 70.40675640106201, 67.98803467904368, 52.489200792004986, 63.44414141870315, 70.14616981629403, 68.21212753172844, 68.20884843026438, 64.57390954417568, 62.20015779618294, 61.54946796355709, 65.58943079363915, 67.68789491345807, 69.20892730835946, 64.6903568698514, 69.19647770543253, 66.87506214264901, 68.51605630690052, 63.453217783281886, 61.925278094507036, 65.20252427747174, 60.55086389664681, 64.27292254663283, 65.19121608426495, 64.67490273137247, 64.27118101427632, 63.045738435560665, 62.39267164661039, 59.71019014235466, 60.0454939565351, 59.94661100449101, 58.161081421759825, 59.01482451346613, 58.27672073918005, 59.93483212686355, 61.80569287269347, 61.25856537972728, 63.408130138151115, 58.700595594221554, 53.10301250027072, 60.960241671531435, 54.34663526473507, 58.91475308325983, 54.201684075017134, 46.39248040414626, 35.72957984862789, 21.009044224216094, 2.5119449390519053, 1.1707445137923764, 0.26363150847534983, 0.2865997131072706, 0.8404068492593304, 0.6107221675976631, 0.1080075188750221, 0.3555250420205055, 0.011271928519671483, 0.06071760844919951, 0.11000297107403317, 0.1267600948772123, 7.80216742907801, 51.65411641520839, 32.34479404264881, 35.198259507456136, 49.42995602084745, 0.6244543855709415, 0.07075667741798586, 0.07384441777943604, 0.01974158593633723, 0.0809183587590533, 0.04017107669384249, 0.089504518996804, 0.057544878293429656, 0.06441787441050814, 0.03726219104963445, 0.0496339709347775, 0.004409120414376019, 0.07950097352506653, 0.06002425291245023, 0.06098755485107822, 0.01794484353834583, 0.0670423920476629, 0.009510840811286001, 0.049947546043943976, 0.07076798487574824, 0.054489528129418055, 0.06887079877478462, 0.014083825517445804, 0.04989303122725218, 0.16768311751225304, 6.585176087194874, 75.19011036042245, 51.33112492099885, 53.7838065239691, 31.47653033656459, 69.12331765697849, 8.382422770223311, 0.14803716041628392, 0.08151995228423227, 0.3274604221505504, 0.06794207804505864, 0.33744971838689625, 2.877133046427081, 1.2810785804064044, 0.24756767126100682, 0.017826938776359443, 0.13107980421233562, 21.117633081251576, 76.9714939978815, 84.33316307683145, 92.19619735594719, 85.25957984309044, 88.06843619192801, 91.417277397648, 93.16155541327693, 86.83954977220105, 79.17584250050207, 85.71891292448967, 88.81259610576015, 86.8646058728618, 85.77828191941785, 87.19459487545876, 85.09254178693219, 81.70266474446943, 84.76730669698408, 81.03410459333851, 77.80582135723483, 74.04768866877403, 73.60940302571943, 76.38193038202103, 75.71084422449913, 76.71189585039693, 78.44251617308586, 75.39190846104776, 81.88257601953323, 79.15559522567257, 77.53942966461182, 79.72277779732981, 78.475707269484, 82.78648622574346, 79.696058611716, 73.94076485787669, 74.50845733765634, 77.00248856698313, 79.87246328784575, 80.28795996019917, 80.90616472305791, 75.27161721260318, 70.05356265652564, 73.70814477243732, 80.45469991622433, 75.1934757540303, 77.98930983389579, 75.62975314355667, 71.88887888385405, 58.211158321749785, 73.41399054373466, 78.02785104320895, 74.1286934575727, 69.00100246552499, 65.19531496109502, 74.60471230168497, 72.62428406746157, 72.48963694418632, 70.9046777602165, 72.73928011617353, 72.64466470287692, 74.5020874084965, 72.37489977190572, 75.28223114628946, 70.57376307825889, 70.21348553319132, 68.0568330518661, 64.31307192771666, 66.53770692886846, 69.58898144383585, 71.63621548683413, 68.90801091347971, 68.70025865493282, 72.97519499255766, 57.40567215027348, 64.01353620713758, 71.96534941273352, 69.23844706627631, 71.87808452113983, 69.1214741429975, 66.44524881916662, 61.90536814351236, 67.85628226495558, 70.05582194174491, 69.41604414293843, 68.84260146848618, 69.89993126161637, 68.0110276129938, 70.32801874222295, 67.97319243031164, 64.00658576719223, 67.79248099173269, 66.93077548857659, 67.27948988637617, 68.1485616007159, 67.28989201207315, 69.59932081161007, 65.79319007935064, 65.5455316266706, 65.87621488878804, 62.983235466864805, 64.41588117230323, 64.2372368228051, 62.24123285662744, 62.41215013688611, 63.39853209833946, 65.29640228517594, 65.52742596595519, 68.6162571753225, 64.70748193802373, 60.044195652008064, 64.55010860197007, 64.2717223013601, 65.89283004883798, 70.1701198085662, 69.01716263063493, 62.43770437855875, 46.84129761111352, 11.430698633193972, 2.1016319240293195, 0.16022011878028994, 0.4426504443249395, 1.850364768216687, 0.9627208762591886, 0.2685645937679276, 0.21930996659061602, 0.07616920351621605, 0.05662286466348076, 0.03262764639070919, 0.3255415864048466, 9.883212793257929, 59.88447673859135, 30.671183409229403, 39.433050386367306, 57.235445207165135, 1.3504898235682519, 0.08002735253783964, 0.09576219329310041, 0.007735263507422661, 0.07775254637723969, 0.0622149809233604, 0.07085201706016256, 0.06258587856146117, 0.03265414537201005, 0.016479485878540624, 0.0130645397885312, 0.020266831138982408, 0.019999079579006762, 0.24672797760896145, 0.12114958867671029, 0.12561375155083596, 0.17754820025255605, 0.11485593889148966, 0.1447878138072068, 0.13003266927215362, 0.14214929974367543, 0.19537598555607183, 0.15239361132825577, 0.1358609283042531, 0.29141825293340995, 7.491395098547782, 91.1235232507029, 54.6526115171371, 78.0561548663724, 54.97033526820522, 81.06896661943006, 12.62138508981274, 0.35881529772473925, 0.5238169696061842, 0.6758810711964485, 0.3674630820751191, 1.002866457546911, 4.7932412739722965, 2.2388430516566, 0.680398048172074, 0.4117829232446609, 0.6022603893952986, 27.21434758555505, 91.90681272937407, 90.5168188771894, 101.10371958824896, 91.1787659122098, 92.1767580893732, 94.33524623993905, 97.50716501666655, 90.22166836646296, 82.12517461469098, 91.51445804103729, 96.21833693596625, 89.97920313189107, 88.20548380574873, 92.336547605453, 88.79237236515169, 86.25437921093356, 86.44510053819226, 85.68053645472374, 83.12654003020256, 77.85689061687839, 83.21295768983903, 83.03450553647934, 78.75049283427578, 81.61413684968026, 86.12262679684548, 79.22366403764295, 84.5142432182066, 85.03442795045915, 83.7413558652324, 83.84515746947258, 81.65716525047057, 87.83714971234723, 83.28943606345885, 79.11233932741227, 77.89906394097113, 78.86136254956646, 82.46564419038835, 82.51688603431948, 86.19355893904164, 80.85198894623788, 72.76690144692698, 73.32832597917127, 86.83023022067162, 80.11481085131246, 79.59726195181571, 80.98053286152502, 78.65011153682586, 61.91116932899722, 74.41268874752906, 83.01545066218223, 78.40785026550293, 75.61385969961844, 66.69618637331071, 78.38788540132585, 77.76698204778856, 73.72252418148902, 72.36205793196156, 77.01704056032243, 76.20354883132443, 77.0946878002536, 78.07927331616803, 74.58512398504442, 75.74884414672852, 74.86036454477619, 70.96274452824747, 67.80494628414031, 70.8600333429152, 73.47153171416252, 75.41141833028486, 69.5405480169481, 75.55507906021612, 75.51810679897186, 57.0699211858934, 68.99516597870858, 75.10887022941344, 73.36489815865794, 74.75170704626268, 70.4262113571167, 68.09545270858273, 68.01569523349886, 72.37587251970845, 73.95867440008348, 72.65510605227563, 70.3116467691237, 75.26512961233817, 71.18840632900115, 74.7868279487856, 69.35285475946242, 69.38529276078748, 72.58006326613888, 70.02497642270981, 71.12879414712229, 71.02390996871456, 71.39844140698834, 73.31338174881475, 68.97393811133601, 70.50763191715365, 67.2177831588253, 69.13791671875985, 69.42577946570613, 70.65302633470105, 68.14992658553585, 68.59348389410204, 68.64056018091017, 74.30050896060082, 69.71395600226619, 75.9649432090021, 68.82367995477492, 68.14881263240692, 73.09460763008364, 69.7937370115711, 70.32022107032039, 72.03770929767241, 66.60313206334268, 57.16308532222625, 50.86054248194541, 21.59754291657479, 3.0975469610383435, 1.0258228031377639, 0.9426193419964084, 4.139655261270462, 2.5162399343905912, 1.0675628891875668, 0.9923118497094802, 0.19730343213004453, 0.39264739521088143, 0.24556735440367655, 0.9173683485677167, 15.297501567871342, 70.21239511428341, 45.05232026500087, 47.91219488266976, 66.63418154562673, 1.8242373702026184, 0.26618187646231345, 0.22119340907421806, 0.15056060807358834, 0.13096270001223012, 0.1418367205488105, 0.18222193413924787, 0.1861630734657088, 0.1438764909342412, 0.18225867571609636, 0.11731211636816302, 0.10439097866295807, 0.15645815209755976], [0.05599978237202572, 0.0701253060551901, 0.07514952516724026, 0.12057306154841378, 0.007528228724690816, 0.012027022124628627, 0.021650073749403802, 0.06318408597801482, 0.056757473972656076, 0.03613249098341312, 0.15138432113153322, 0.36345726960609037, 14.517145041496525, 56.422357482294885, 43.413844262399984, 40.408304583641794, 31.21711850166321, 47.40002747504942, 1.0933057723506805, 0.06287436812154709, 0.028789549720503634, 0.09864584017064303, 0.20398235519326505, 0.2677837663119839, 0.5621697212899885, 0.8894499595607481, 0.4993486422444544, 0.0721223363953252, 1.1345514558976697, 25.407088072069232, 67.90921857280117, 76.56821158624466, 82.54100861087923, 83.55558456913118, 89.04172528174617, 87.02874921983289, 87.32637082376789, 85.35268906624087, 81.75213367708268, 83.57771458164339, 84.80059193026635, 86.99140825579244, 83.87631677812146, 81.30510899328416, 80.83195347939768, 81.27755042045348, 80.60567978889712, 80.45609628000568, 79.06819697349303, 75.4628719822053, 71.3494510035361, 73.97512482058617, 72.60248353404384, 74.77941466915992, 71.94233294456237, 77.3865984332177, 74.82269410164126, 74.31914021891933, 76.48199788985714, 74.46600160291119, 78.39516532036566, 72.49821124538299, 73.50647218765752, 70.13387710817399, 77.47570683879238, 78.45504422341624, 76.98412402983635, 78.05802975931476, 70.02845948742282, 69.34664172510948, 75.44715112255466, 79.31675757131269, 67.53565988233014, 72.71231774360903, 76.55690731540804, 67.44255850392004, 60.78522943681287, 66.1051244120444, 75.62540715740573, 67.96171557518744, 71.849043292384, 60.460339515439934, 67.86683344071912, 67.2511625289917, 69.53844562653573, 70.26005191187706, 71.54420452733194, 68.94542248018327, 69.93513845628308, 67.84025546043151, 69.6553244129304, 70.03075015160346, 66.22651392413725, 66.50100138879591, 65.53784378113286, 59.23757199318179, 61.07529655579598, 64.72250461578369, 67.17194634099161, 70.49942631875315, 66.3732890159853, 67.42468818541496, 70.85034508858958, 53.02128599536035, 58.39882412264424, 67.1184059881395, 65.78989528840589, 66.66772565534039, 68.84519807754025, 63.940674258816635, 61.30703803031676, 61.891294679334095, 67.97401612804782, 68.28703695727934, 63.92283924164311, 63.78386966643795, 62.08546769234442, 66.16362264079433, 63.78259097376178, 62.94482369576732, 65.05252107497185, 64.62923065308603, 67.20745163579141, 66.00828893723028, 63.2364676075597, 61.62668374276931, 61.502466201782234, 62.22487265063871, 58.9140784355902, 57.737414452337454, 57.10189634753812, 59.539174802841686, 56.57477294245074, 60.35228998430314, 60.67572862871232, 64.49362254911854, 63.392570095677534, 68.51524045390468, 54.87345272494901, 61.11045275965045, 61.05468450054046, 59.58933799497543, 65.13174510771229, 56.23940637034755, 51.385084967459406, 32.44700512578411, 9.810385165675994, 1.6829336170227298, 0.44914092508054554, 0.11537906969146383, 0.23552219503589217, 0.29025695557075165, 0.31963560009194963, 0.23039947233853802, 0.06173165605193185, 0.02933418460851235, 0.008085256521289629, 0.25752492970035923, 5.022433698177338, 42.708759000224454, 45.8863377571106, 19.304919512041156, 51.14614594367243, 2.981723047071888, 0.0924069886546462, 0.06633341597813754, 0.03707555670952124, 0.07426367471775702, 0.023803786307032553, 0.040988500169929, 0.007988799348353379, 0.03034364909023768, 0.02739332766542512, 0.017760517038104516, 0.09148234351267738, 0.07068081173084437, 0.08008453334050794, 0.023285573791532267, 0.021657121758307182, 0.06990904709504497, 0.013977352702509493, 0.03809178766283778, 0.05868820323338432, 0.07641489557441204, 0.05608111409650696, 0.05841806913996416, 0.23699918191038796, 0.5853869657843345, 20.600923568971698, 61.11708156524166, 53.71575732384959, 42.027992433117284, 26.552698650667747, 59.540833965424575, 1.3424254304939702, 0.020753871536843722, 0.03262378530757081, 0.029416194320806575, 0.15566898960499995, 0.7650377096668367, 1.3699771391768611, 1.422768687048266, 0.26760787252456913, 0.04448486033887152, 1.4461316721093271, 32.36642395296405, 81.38014393468058, 86.82918687020579, 88.01397800445558, 86.79732937966624, 90.78598760789441, 88.73392120484384, 87.12338816735053, 89.82512458678215, 84.69799841603925, 88.89172600161645, 86.68113308568155, 91.87850890621063, 88.69712152788716, 85.25225285560855, 84.83161787832938, 85.2825100191178, 81.76923521103399, 82.03784696517452, 80.83109840270012, 79.93726868783274, 75.62326554329165, 75.97605136133011, 75.34193746505245, 78.11808124665292, 75.72502751504221, 80.04404344866353, 77.09577037442115, 78.9085800417008, 78.90566964303294, 77.92923481233659, 79.15483428585914, 75.08781494632845, 75.76016410704582, 75.80789150730257, 79.08268620890956, 81.84758847759616, 81.45342165423979, 80.3995200126402, 70.5393325128863, 72.26323773784023, 79.04768297749182, 81.70357473434942, 70.51389201994866, 77.41512190911078, 77.59503318417457, 68.65074265387751, 63.878791024608, 74.95104974316013, 75.84046286921348, 70.35577343356225, 71.4229013073829, 64.49373629785353, 69.39103511071974, 67.86417407374229, 74.1849559353244, 72.36186965819329, 74.17675033692392, 71.37835887170607, 73.58853601640271, 68.97602481226768, 72.56471895402478, 72.18007564544678, 68.92005258990874, 69.9465839324459, 69.17029196216215, 60.85715393866263, 64.92127072426581, 66.50207611822313, 67.87327397254207, 71.70260552437075, 67.99431831605973, 69.00715274195518, 72.44194876763129, 58.9968208343752, 59.05814316964919, 69.30580200687533, 67.1803637473814, 68.49593454791655, 70.39771141544466, 68.2347752971034, 64.61361569743003, 64.4968585045107, 68.39343517057358, 71.10662491090837, 67.08773305339199, 67.57365980455953, 62.37562894821168, 68.78698225944274, 66.94167183291528, 66.13984523280975, 68.7888728418658, 67.20653380117109, 69.19153551901542, 67.82964937148556, 66.53180768412929, 66.58975678105509, 65.48396610444593, 66.07619300965341, 63.07778027749831, 62.24267628885085, 60.54567460090884, 61.67834135793871, 60.220015894982126, 61.316487020061864, 64.08488019820183, 67.30192584376182, 69.08094821437713, 70.15873709032613, 64.07324644827074, 61.7949769573827, 68.83890659578385, 63.75525205366073, 72.97140598297119, 69.69002954421505, 73.26170844416465, 58.4096694761707, 24.091189753624704, 3.0671963960893693, 0.5162497982382774, 0.25494699786988, 0.15082964283083716, 1.0088300536717139, 0.6769679967434176, 0.3960191320267416, 0.05405971449950049, 0.18623217459647887, 0.05001120028957244, 0.33412786921666515, 7.082768947847429, 51.01406012811969, 42.413400603878884, 23.462680924323298, 58.733947507796756, 4.505420692505376, 0.2451963686654645, 0.14712925429546064, 0.05455136291622635, 0.05041125140363171, 0.032318813365794, 0.043336594131805246, 0.10802850968414739, 0.009205076926117464, 0.05609831277040705, 0.010882630407239401, 0.08388356335701481, 0.039339848313360445, 0.12033947367942142, 0.15736956690107623, 0.14704985694298822, 0.21548632982998125, 0.1675332400707468, 0.1419015928742386, 0.11265912814246071, 0.12600624137708258, 0.16786674878770308, 0.17381681579976313, 0.24370478015513192, 0.6740886706017679, 23.442676836444488, 76.48259409012334, 56.78866371031731, 55.072552234895774, 42.670582571337306, 69.27275211580339, 2.8904541509766735, 0.10840265936548672, 0.25795292770189626, 0.29922248254860606, 0.5206340887854176, 1.6072615356214586, 3.3410285797811325, 2.6820699005357684, 1.0408544900917238, 0.2951587538325018, 2.1943888693086566, 38.63338108985655, 96.3014990283597, 95.76276932993244, 95.29973353109052, 92.06257004891673, 96.01591125611337, 93.80042322220342, 94.90895563556303, 94.42866140796293, 91.28360302217546, 91.65389830066313, 92.99338771450905, 95.42430016302293, 93.46909276900753, 90.47141352007466, 89.0576030362037, 88.32350007949337, 86.93203141612392, 86.11806900270524, 84.95314075100808, 84.44761783845964, 78.08907139685847, 80.83243200855871, 79.32761469194966, 82.63097993789181, 78.8499798313264, 84.64297540726201, 83.7733937847999, 82.44651871342813, 82.54182446387507, 80.14381285636657, 84.57148628850138, 80.45359380783574, 80.91387610281669, 78.43176103407338, 82.48608758372646, 85.36422867928782, 82.58657086280085, 85.95953464508058, 76.34240858016476, 76.04658342176869, 81.63481558522871, 86.32025934034779, 73.21584809210994, 79.440092579011, 82.43312774165985, 72.68493175506592, 69.82099748426869, 74.42727211982974, 82.31364450147076, 72.86645120190036, 79.02894973754883, 67.09338911118047, 73.05295205885365, 72.77435395025438, 75.97119546705677, 75.28292932818013, 77.98854889408236, 74.60532419143185, 77.08076338614188, 73.91533220967939, 75.9020362361785, 77.5258739532963, 70.01919484907582, 72.51904687573834, 74.01012805200392, 66.85761544012254, 66.75606527636128, 70.49888503166937, 72.6534665015436, 76.71390410392516, 68.22470265050089, 72.34166945180586, 75.57628339336765, 58.05225133895875, 63.73799362490254, 72.70551635373023, 68.38420191118794, 72.55967478598319, 73.88818156334662, 70.53985811048939, 67.9679286095404, 69.61400616553523, 71.68505684021981, 73.31167159541961, 68.89641638725035, 69.84205276735368, 64.37783810400194, 70.83999787607502, 71.48226245757073, 68.48876445524155, 75.5442690080212, 71.16140473273494, 71.76602240531676, 72.29988051999, 69.73858848694833, 70.4853371650942, 69.35477672084686, 71.00603180546915, 68.61659449915733, 67.83856884125741, 67.2299660405805, 68.46079011117259, 64.99696854622134, 67.86683344071912, 70.39134933102515, 72.06486778874552, 74.65218082551034, 77.74573064619496, 68.78406401603453, 68.96261030627836, 75.08823071756672, 68.06959644440683, 77.29435213150518, 71.92631398477863, 70.21470146794474, 59.065787869115034, 36.401626986842004, 3.690991026739921, 1.328899504676942, 0.3894330128546684, 0.9713883950344979, 2.3168651230873603, 1.2400409050526158, 0.8132677248889401, 0.20532129302380547, 0.24765875911520374, 0.40331713074157316, 0.6428091167922944, 11.86056588926623, 60.409815465250325, 60.08821641245196, 31.576717476690973, 67.76863298108502, 5.544100596058754, 0.3819287526271036, 0.28837887570261955, 0.17160207093242677, 0.17102226494781433, 0.10657566224014568, 0.22363830207576677, 0.21536018579236924, 0.10467183415687854, 0.18116162248676826, 0.15956548132723378, 0.22475383334582855, 0.14225757861089322], [0.050225180138142846, 0.0421463999326431, 0.048973304369757255, 0.018859564011255582, 0.07348354440182447, 0.08202513364414055, 0.03964063358463107, 0.10721837936510002, 0.057038038353165316, 0.020489105804552956, 0.05517677794541082, 0.15229343767127684, 26.04353185622923, 59.32264427984915, 33.10594174169725, 43.77704005087576, 38.40950396753127, 37.43959988317182, 0.02941238303338328, 0.13774426353554572, 0.11505468508168576, 0.15295996480891783, 0.19564385585967572, 0.3550512626046135, 1.356983429962589, 0.19542544419246335, 0.13887169981195083, 0.14199605151530237, 2.167295832787791, 29.65269292554548, 61.92751776787543, 75.89267746094735, 78.28765315394249, 87.08863596762382, 86.83388586967223, 91.14348027013963, 83.69311855685326, 87.46874501628261, 81.18924217839395, 84.71181300378616, 83.60585366525959, 85.82712327280353, 79.09194300251623, 77.36788088275541, 77.76586809465962, 80.80868597953551, 82.92928403423679, 82.94447929628434, 79.01260914341097, 76.203948913082, 73.71367531438028, 72.79587207301971, 75.88691157679405, 73.25872744283369, 73.70686607976114, 76.79563845357588, 75.96620621219759, 77.16911869664347, 74.06175428821196, 76.00281761538598, 70.62434596400108, 69.24179677040347, 73.64683812664401, 75.87200657013925, 75.40813138408046, 75.46764158433484, 73.11803986949306, 64.54760612980013, 64.9001762174791, 74.27814360587828, 75.77995638693534, 74.22947483678018, 76.06443805079307, 72.43016596763366, 60.654681190367675, 59.40829707730202, 73.02747234221428, 75.4279628876717, 68.54246954764089, 68.44888964006978, 63.66422168670162, 60.26202447952763, 53.172105050856075, 60.14023096330705, 72.25368284410047, 66.81896440444454, 64.93859191094676, 66.19897104078724, 67.67930492278069, 65.90971193005963, 65.30276044722527, 65.32181924389255, 68.61550408024942, 65.8799332957114, 52.88251646103398, 52.78613598115983, 57.438682817643695, 63.418081191278276, 66.87753323585757, 63.50020385557606, 69.2753722590785, 69.69493250693046, 65.88665623818675, 70.79016808540591, 54.204786669823434, 59.639210931716434, 68.29142216713198, 68.27230453491211, 63.4217054613175, 67.4999584690217, 67.16101861769154, 60.095684605260054, 58.94642230003112, 65.91931389224145, 65.952332404352, 65.56135054557555, 63.73279256205406, 63.21785596109206, 66.6920365056684, 63.269768530322665, 61.730057808660696, 63.97598343510782, 62.494743485604566, 65.54218584491362, 64.56406831741333, 62.75941325772194, 63.21501224271713, 60.450015837146395, 58.27503019763578, 56.04718277531286, 56.602704140447806, 54.84451740018783, 56.54130728014054, 57.9892933753229, 61.822763027683386, 66.88273429870605, 66.28969546287291, 64.96711146446967, 64.24456773265716, 56.186834842928, 67.86916332860147, 65.19029824964463, 68.86527276808216, 61.89873541555097, 63.66004828483828, 40.53213380998181, 16.219834166188395, 2.531861754194383, 0.20701698267892485, 0.13432300679626005, 0.23482493245072905, 0.7866252706416192, 0.303568713847668, 0.10120868006901396, 0.13032344560469353, 0.05890207582964532, 0.16614950141839444, 0.41021639601357524, 2.921797565875515, 30.214156681491485, 60.77223462443198, 29.370039086188044, 51.88681102568104, 8.604565224339886, 0.7417633456568564, 0.17384934389302809, 0.06867644226839466, 0.08375843821634209, 0.09275586509536352, 0.11348722322333245, 0.022326684519348126, 0.08266582063609555, 0.07281068937792894, 0.012060974183822832, 0.026494465212547974, 0.07270705300353228, 0.034228999978832664, 0.10360662720256275, 0.07883432381335767, 0.049137925173366265, 0.040825924821077816, 0.020614552702153885, 0.006450764842391495, 0.08979893424698422, 0.13239480945612156, 0.1753835575354676, 0.15055087875695, 0.2309415714755174, 33.14197655647032, 64.27510338444864, 54.14749653108659, 47.13260419907109, 37.69396951121669, 46.609556136592744, 0.3480191576865412, 0.07535927238002901, 0.15873079789021324, 0.25519960770203226, 0.4604208343211682, 0.2570206293415639, 2.0281893423488064, 0.24663719618993424, 0.2682495784134634, 0.13760904901691023, 2.661326445879475, 39.37998071793587, 79.24097737958355, 84.58581862911102, 84.14077081987935, 90.92203109495102, 89.44697672320952, 92.43743096628498, 88.20263616500363, 88.37514984992244, 83.58979548177412, 89.0489738218246, 87.06115584219657, 87.06878877455189, 82.48083160769555, 83.38167452043103, 81.32148096638342, 84.34452226085048, 84.74985214971727, 84.74158379339403, 80.71883232362809, 79.74398213048136, 76.06970187156432, 75.96066782551428, 78.30615889641547, 77.49198467500749, 77.82446046029368, 80.79319261735486, 79.08915027495354, 79.23098318038448, 76.13737844651746, 77.26344385454732, 74.66693678209859, 72.13459968566895, 78.82013059431507, 77.3118459024737, 77.97256131325999, 78.52554490489345, 76.11249493014428, 67.98817588436988, 71.5802824881769, 78.43547944099673, 79.14120012714018, 76.47372168879356, 77.81732959132042, 71.99821103003718, 63.29630728690856, 63.87320164711245, 77.6255335346345, 73.97049642378285, 70.9760021394299, 70.94222268750592, 63.1771025350017, 61.12358877735754, 54.086421305133456, 61.181757527012984, 72.00778945799797, 70.77275276184082, 69.75387004113966, 69.15333163353705, 70.68292264015444, 67.63548420321557, 68.59880262805571, 67.94772055841261, 71.40649795532227, 67.06299074234502, 54.2603313538336, 53.786375676431966, 59.67701865780739, 64.07553711245137, 69.7211653186429, 66.13152980804443, 69.35207028542796, 71.31258856865668, 66.3944855043965, 71.67509401998213, 60.83398842042493, 60.97693527898481, 68.54693320489699, 73.12619839945148, 64.93872527153262, 69.93852738411196, 69.2904733842419, 64.94909209589805, 61.98601207425518, 67.08978053062194, 67.6589007531443, 68.55968875269737, 68.47375746696227, 64.37875986099243, 70.11215502215971, 68.68462408742597, 64.99335604329264, 67.78862922422348, 66.34116480427404, 69.80116598067745, 67.3010080091415, 66.24944410016461, 65.52293092973771, 63.438528506986565, 62.76071156224897, 60.4091251281, 61.157062284408084, 58.923268548903934, 61.04475698163433, 62.82470895398048, 65.45905905385172, 68.77323827435895, 71.13342254392563, 69.76297778467979, 68.69838376199046, 63.43540237795923, 69.30169920767509, 68.09335816291072, 70.1185877092423, 71.83806065590151, 76.69079349886987, 60.46805481756888, 37.542554255454775, 4.405378680075369, 0.4771230526028141, 0.14177652135972055, 0.5952588973506805, 1.9485350746300913, 0.5402822828581256, 0.05040220773568557, 0.09941004351862978, 0.07287071236679632, 0.09575460136177079, 0.6735581700359622, 2.5222436122355925, 40.64920087014475, 58.14020656770276, 35.481925318318034, 63.0378270149231, 10.497950180884331, 0.5071093887090683, 0.3116020343957409, 0.1657517638898665, 0.046222995095435655, 0.06146604187726494, 0.10340487028682425, 0.0743350817731792, 0.09116683786194171, 0.062310791709610534, 0.03481332205175873, 0.03566848301899529, 0.044516338891680204, 0.16526630929400846, 0.16560884252671274, 0.19166736923638852, 0.15939580817376414, 0.212290364227468, 0.16993929241453448, 0.1196434291740579, 0.2014485806707413, 0.31151577289546695, 0.25474824401880464, 0.2513372835012213, 0.31538212671875954, 37.94794297987415, 77.61424495327857, 45.216177278949374, 63.272070961613814, 56.20748219951507, 53.89561760810114, 0.6080601039913394, 0.22972773580301195, 0.26935188700595214, 0.30458540445373905, 0.7839663939610605, 0.7513031627862685, 3.8747339671657937, 0.41063768308489557, 0.45600467451637794, 0.4739869950759796, 4.121677077585652, 48.40767260520689, 92.65050980352586, 91.66988588148548, 91.36883612601989, 93.39419118819698, 94.16195592572613, 96.86719109935146, 95.63423325938564, 92.9738856900123, 89.43655106329149, 90.72030359698881, 92.52655506134035, 91.4284247736777, 87.12945215163693, 86.84722977299845, 84.31273537297403, 87.70150630704819, 87.04982803713891, 90.5250087861092, 85.05402411184004, 84.41772937774658, 78.75238341669883, 81.21833047559186, 82.47817224071872, 82.8890875847109, 81.2536318071427, 87.32576677876135, 82.64462978609147, 84.60502255347468, 80.69972253614857, 81.98180414015248, 76.60951414415914, 76.07041574293568, 80.84002571721231, 81.73354164246591, 80.30895248536142, 82.48695834990471, 79.88956482179704, 72.99515985673474, 72.95008397871449, 82.991226103998, 80.21549024889546, 81.19682019756686, 80.62151047491258, 78.66625601245512, 67.41683560032999, 65.00147534954932, 77.5393904409101, 79.83864461222004, 74.39537540558847, 73.93533629755821, 70.27024222958472, 66.59256519809847, 57.7499189684468, 66.76778531843617, 76.72089376757222, 72.12758648780085, 71.36172802217546, 71.69446268389302, 71.70892838508853, 68.59291907279723, 69.07563732516381, 69.75768258494716, 73.82138359931209, 73.09463900904503, 58.59193809570805, 58.78702109859836, 63.054030326104936, 69.68705638762444, 73.30687845906904, 66.22455273905109, 75.3081972368302, 76.02045259168072, 70.59982330568376, 73.22506566201487, 60.3295127807125, 66.15725271163448, 73.7106393998669, 75.71864189640169, 68.54289316361951, 74.3774893976027, 71.68765344927388, 65.91637211461222, 64.97913352904781, 71.67182276325842, 71.62021221653109, 71.56278871720838, 69.4159500060543, 67.95997404283094, 73.8728686301939, 71.44781620271745, 68.36731218522596, 72.62621387358635, 69.85768733486053, 73.55153237619709, 72.68493175506592, 68.91052123039, 70.43845699679467, 67.94279406147619, 67.19667296255788, 63.976226622058505, 66.25511584743377, 64.79905751443678, 69.31125410141485, 66.72675732643374, 71.56213760375977, 75.26762423976776, 76.56666617239676, 72.06508744147517, 72.96791507351783, 68.21090375223469, 75.62281054835167, 72.51147670130577, 76.57520909463206, 73.01518747883459, 76.76015669299711, 62.497277336735884, 51.67309676447223, 5.894764902130251, 1.1149740483491652, 0.5338147234532141, 1.3208424660467333, 3.54175097038669, 1.2036683987225256, 0.42531430360771, 0.40485629331200357, 0.23360522854472363, 0.5149768052562591, 0.8671377406966302, 5.404580418140658, 48.225509889664195, 77.87642402033653, 42.20588760991251, 69.19810156668387, 12.624109175897415, 0.98863658885802, 0.511799807990751, 0.3886313478071844, 0.24360403959308904, 0.18554802743657944, 0.19109527009629435, 0.11944043119588207, 0.20812623202800754, 0.18790868140997427, 0.0947874536617629, 0.143788865797462, 0.10509474533459834], [0.02490966486924839, 0.013963523857866325, 0.01980074516106998, 0.02060069225638384, 0.043597255548041676, 0.04582970470730816, 0.03738965658891586, 0.04529229785886504, 0.03626954028262727, 0.06808929716146762, 0.15669162505336348, 0.07580030153715804, 36.547480321699574, 51.96940829676967, 34.53544170625749, 27.964273383540494, 44.93712025303995, 24.721612699570198, 0.08492230963442596, 0.14601494876607773, 0.12060670046916894, 0.12447614162679642, 0.8566063606450636, 0.36675353143965045, 0.4775110914582207, 0.19203587284972592, 0.07040574786163147, 0.3908585186206526, 6.52266723494376, 38.200339655722345, 61.51999135171214, 78.40523012222783, 75.91831407239361, 85.33082577490038, 87.22960595161685, 87.78411926761751, 84.8143280706098, 84.40570339079827, 84.41460717108943, 83.40892714838829, 86.07234985597673, 81.47359832640618, 78.8968050864435, 78.0724327025875, 78.48300287800451, 81.2023115158081, 78.61399435227918, 81.36672942869126, 75.27271547625142, 77.59018513464159, 73.11009314752394, 73.3783361988683, 73.8703190895819, 77.44093894958496, 73.19961732433688, 75.35208855905842, 75.67803752037787, 74.14298657448062, 73.2421358170048, 73.66128813835883, 71.02200369681083, 75.00550008589222, 73.95088457292127, 71.63688228976342, 72.33302454794608, 76.7969093015117, 63.40924409128005, 69.5403911221412, 76.83722342214277, 74.29715925647368, 73.26942766866377, 76.73936028634348, 69.01964156858384, 61.64897457245858, 62.787195405652454, 75.63650746499339, 72.61789844882104, 68.88760674384334, 69.92522270448747, 57.14663097935339, 54.12517040006576, 53.9734217428392, 53.39494666745586, 48.13264777583461, 55.002981155149406, 75.40674286503946, 70.11119011909732, 71.12011001956078, 69.22242810649257, 69.1513547589702, 69.41784058847736, 70.95417022705078, 65.56553179217924, 50.454212388684674, 49.12330904314595, 52.069436580904075, 50.87218015424667, 52.45937116684453, 56.93882380762408, 64.95180245368712, 64.60170738158688, 65.77411951557283, 65.34358447597873, 65.83139788719916, 68.38197400493007, 58.54644252407936, 55.633623753824544, 64.58799869783464, 65.29449209090203, 66.39610936564785, 64.40448668695265, 68.02947844228437, 61.698506262994584, 58.25493197287283, 62.91428804397584, 67.86786110170426, 66.36239267164662, 61.78781078707788, 63.028538842355054, 66.85258696156164, 57.92627657613447, 64.90155296940958, 61.58283948898316, 64.54080473992133, 61.295835741104625, 61.81797381370299, 62.56670328878588, 61.878193962958555, 61.3708040022081, 58.07824488609069, 57.709691139959524, 54.565750629671165, 56.004056315268244, 58.679167685970185, 60.65201790102067, 63.855190123281176, 66.39883933528778, 66.96223289735856, 65.86703654258483, 61.220067316485995, 63.90030914737333, 70.68404443802373, 68.21689713385798, 67.52932133213167, 67.78228282928467, 50.62413730928975, 23.94730740977872, 9.034587414033952, 0.3921925534884776, 0.18513288439041187, 0.429384681966997, 0.2261219284827671, 0.12362963745310424, 0.09255803054979733, 0.08700095132113465, 0.1587011656093021, 0.2066446179824491, 0.3067065180549699, 2.387394241748318, 12.464379475962732, 57.98255474336686, 29.004699722413097, 42.94113589871315, 17.141671565271196, 0.4842975273007347, 0.2198813149645444, 0.1156119604204451, 0.09228957801937096, 0.0361794330209734, 0.07719011526674995, 0.09304249689223305, 0.057404799116474975, 0.02905728021306136, 0.01202015701921717, 0.06584619171917439, 0.08345780999309595, 0.06825718533007369, 0.038620924592138305, 0.034056197356192336, 0.10248512810757084, 0.06405830721280749, 0.02689930437613399, 0.04993587469441756, 0.05887494099536731, 0.07888770481992154, 0.018974071173297784, 0.03485491679560754, 0.054885312133739074, 45.539631612839244, 58.208106717755726, 47.73955175953527, 29.07521413218591, 49.19133470904443, 29.37143937233956, 0.08825036411684367, 0.10285913989308382, 0.09567949410167434, 0.08103572342905306, 0.4098989598212704, 0.3828086505734152, 0.8228441916646496, 0.2926257607196608, 0.09511030609569243, 0.2244675922538004, 7.8438401606775106, 49.278101459626235, 75.30161549968105, 87.54556071373725, 83.3564458354827, 88.90252820907101, 92.37899549545781, 90.54204756213774, 87.83600438025691, 90.20756352332332, 86.34708050758609, 89.32584608754804, 87.70000011690202, 86.76338518819502, 82.64499848888767, 81.64857525979319, 80.46048933459868, 83.91694468836631, 82.33911637336978, 83.29959500220515, 81.35875132776077, 81.87639436414166, 74.83470439910889, 75.13281237694525, 75.3725633313579, 78.62712644761609, 76.34531113409227, 77.89573777106501, 80.74726950737738, 76.09600528593987, 76.57669959529754, 76.18447042280629, 75.7480832069151, 78.4156322479248, 78.24995917658653, 75.11728763580322, 77.99656621871456, 75.82819369531448, 67.052565082427, 73.5233776031002, 78.2213415638093, 76.06958420045915, 74.40791130065918, 78.98903569867535, 67.9546082404352, 63.618039700292776, 68.42082115911668, 79.33320799181539, 72.7592606698313, 71.5359361710087, 68.86343709884152, 58.127333348797215, 55.99019465907928, 57.73727324701125, 55.74236362211166, 51.375922310736875, 57.47509025758313, 76.19207982094058, 72.92029749962592, 71.08590695165819, 72.68610846611762, 71.09595606403967, 71.3771664711737, 71.74582219892933, 67.31456372045702, 51.397299228175996, 51.29970281354843, 53.944066724469586, 53.93327628412555, 55.46998247023552, 57.17840217774915, 65.80402366576656, 68.07970831471106, 66.15582496889176, 68.02105319115424, 69.00461889082386, 69.8707566722747, 63.65501196153703, 58.66985597918111, 66.58368495202834, 68.04669764734084, 69.52287381695163, 66.45325045431814, 71.10533052875151, 65.12288447349303, 61.193736445519235, 65.91396377932641, 67.60459946047875, 69.72865704567202, 64.27332655076059, 65.05266620266822, 69.68380082038142, 62.46813412635558, 67.56838813904794, 64.75940235199468, 67.08734081637475, 65.90921771141791, 62.758777833754024, 64.8235958622348, 66.27504933264949, 65.16526176083472, 60.818420533211004, 60.945069943704915, 60.77125403188891, 60.443438022367424, 60.87048607487833, 64.61714975295529, 67.31936470154794, 70.20251074144917, 70.79160367288898, 69.57699468058925, 65.40458125452842, 68.45164314393075, 71.74519461970176, 70.84601479191934, 73.18595963139688, 74.2681650961599, 68.9839558447561, 47.414120551078554, 11.4007140744117, 0.8642491602128552, 0.07137308708362042, 0.7506324987738364, 1.0918440765911535, 0.1969478447591105, 0.29077780342871146, 0.12645998759375465, 0.16096232008309136, 0.14251590345896062, 0.7365427322445378, 2.761690092663611, 14.422395287021516, 65.5339841688833, 27.085227081852576, 50.89856986076602, 21.627068558046897, 0.6211976538742743, 0.19124533139890243, 0.23848838022639676, 0.03611056937745983, 0.05647391035792328, 0.03712021197462755, 0.164015211104866, 0.04502485656449872, 0.03877337608907012, 0.07179902430864112, 0.05360850403385778, 0.03183011630279643, 0.10873131108500304, 0.09168344925368026, 0.1914984315273262, 0.18442526429651246, 0.17372174428835993, 0.14768394791791517, 0.0992859832401718, 0.17918595833884132, 0.2716713560925376, 0.14401221107090675, 0.24140489227589101, 0.22115836821256146, 50.908234580870605, 67.6184062034853, 44.41126377351823, 40.25948201456378, 63.87531188226516, 36.3418226088247, 0.21542064545135345, 0.4479278095306889, 0.35676978167987644, 0.3455846834807627, 2.016902477029831, 1.1694694983382379, 1.4790499186323536, 0.7532628156965779, 0.25795464373884663, 0.797197038848554, 11.180169986140344, 61.06951890453216, 94.12050431774509, 95.58626267217821, 89.29443574720814, 94.30837800425869, 96.37494933220648, 93.7308168411255, 92.18361439243441, 94.51326693257978, 90.44136031981438, 92.26952214394846, 90.40493719039425, 88.8044846442438, 87.06490562808129, 86.88959137085946, 84.28514542118197, 88.7332308676935, 85.58169272638138, 87.41839747275077, 81.64473133702433, 86.91786381506151, 80.20179333225374, 80.09445375011813, 77.92471624189808, 84.15667210855793, 79.64556986285795, 83.44153773400092, 84.99743215499386, 80.92851438829976, 77.6549748451479, 82.66843857303743, 77.68141162010932, 82.21148244796261, 81.1090140188894, 78.65015860526793, 79.17328511514972, 82.76178313839821, 68.33354842278266, 74.50453496748402, 81.71590666617118, 80.16645277700117, 77.17876772726737, 82.33677864074707, 74.5239899235387, 68.43782855618385, 68.39068166671261, 80.59043745840751, 75.4130578810169, 73.26564650381766, 74.06618656650667, 62.13241846330705, 61.15930195777648, 60.690551265593506, 57.349095882907996, 52.6677353151383, 61.2630957172763, 81.97130787757136, 73.86093678012972, 73.24506190515334, 75.07284718175089, 75.63745667857509, 74.81371187394666, 74.35658316458426, 71.52365915236935, 56.98646883810721, 54.24486937061433, 58.22319999817879, 56.96036938698062, 60.68438137731245, 64.33914392225205, 69.84364524964364, 69.69808609254899, 69.85654200277021, 68.74753890498992, 72.00039186785298, 72.77946872095909, 63.90060332513625, 61.646087708011756, 70.67375213869157, 69.95258515880954, 72.61343479156494, 70.39986871903943, 73.93815255934193, 66.72193281112179, 64.61816956920009, 69.44503045851185, 72.77816649406188, 71.50594572867118, 67.40349954174411, 69.30708854429184, 71.11020211250552, 64.95761932865267, 70.84341818286528, 66.64046518264279, 70.53479040822675, 69.47199283107635, 67.95672632032826, 69.42400655438824, 67.24709895349318, 67.74676184500417, 67.82473856402983, 69.64462418710032, 67.09217317642705, 67.1246111777521, 65.54437844983994, 68.20973488592333, 70.26817121813374, 75.10866626616448, 75.43609003866874, 75.18958476281936, 69.46670547608407, 72.22246077752882, 77.31380708755987, 75.16113973432972, 75.47282695770264, 79.8442300673454, 70.56885227080315, 63.43020915985108, 15.772313302563084, 1.832131630470676, 0.31898341412025116, 1.8186687077245407, 2.61260423448778, 0.591365761093555, 0.5137750890947158, 0.2561966251702078, 0.29919073586502387, 0.4408543052211885, 0.9267009542353692, 7.084097650743301, 21.582224099866806, 75.57600098271524, 40.00955250955398, 58.25045654850622, 24.888284014117335, 0.8586901810861404, 0.332500116238671, 0.3368261534600489, 0.24205166966684405, 0.15021386135730053, 0.12031221627107552, 0.3565542045379839, 0.1434651017189026, 0.112402749157721, 0.15760475589383036, 0.20453832052167387, 0.1919663886749937], [0.05002213619469155, 0.018221075691643263, 0.047086314899065805, 0.018110607728181828, 0.019538656906074574, 0.0634784744151177, 0.0571754323919454, 0.028785412845712517, 0.12955015645392481, 0.08744021081515858, 0.19264112827518295, 1.0772637686421795, 52.65343043111986, 45.624319507229714, 47.10142920094152, 44.0110525777263, 45.026271804686516, 14.077679745612608, 0.15726232991343544, 0.23978838546862527, 0.12643237012408434, 0.12074565349687492, 0.07706017909391273, 0.5247556418180466, 0.21556932779569782, 0.2680344609243255, 0.036330896264482895, 0.22990160711830665, 15.59561444867042, 48.520354455517186, 60.266241027462875, 76.32316543209937, 77.88180551221295, 85.41544698899793, 82.99862369414299, 88.88298696087253, 85.61960635646697, 84.21287182838687, 82.13105816994944, 80.0557948696998, 82.41484949665686, 77.1952259925104, 76.35244200306555, 71.04132529227965, 75.24818497319376, 76.14326200177594, 80.03874040419056, 77.61978333996188, 79.63668961678782, 77.53618978684949, 72.33906499801144, 74.73097339753183, 72.39245630079701, 74.92893542012861, 73.19252567906534, 74.419356776822, 71.33216904055688, 73.82020688826039, 71.64762173929523, 74.55486682153519, 73.08429179653045, 75.37527761151715, 70.59218252858808, 72.95776397951188, 72.93630076992896, 63.02973124288744, 71.1877473708122, 74.8621609903151, 66.30045844662574, 74.83578697327646, 75.75402952009632, 65.03272487271217, 58.78172589886574, 67.40371919447377, 76.51349452234085, 70.46719228067707, 71.28430827971428, 68.90840315049695, 53.34899217851701, 57.13912356284357, 56.90495021881596, 59.957762302890906, 54.96558135555637, 54.21982111469392, 47.27732396894886, 59.37074038290209, 67.55490303039551, 68.74167103921214, 70.19479151695006, 67.02919560094034, 67.01758538523029, 66.68329746492448, 52.64821760116085, 51.478433455190356, 50.969282350232525, 54.235271330802675, 56.131721619636785, 54.45522608295564, 50.62713007773123, 51.51894761670021, 61.42219489620578, 64.1671166112346, 65.26550185295844, 69.64376126566242, 64.51715677015244, 68.96102566872874, 62.3536793647274, 59.232586660692775, 60.26607236554546, 68.68570666159354, 65.63295341307118, 64.04313833482804, 64.76560361923711, 62.322292558608524, 58.897384828136815, 62.706131781301195, 63.74459497390255, 62.11839598994102, 62.093806651330766, 63.23329833246047, 62.53290030264086, 62.43479790226106, 65.27500183351579, 61.02028531412925, 60.99845732412031, 61.17329305218112, 61.30610058384558, 63.840932307704804, 62.2931375811177, 56.800987797398726, 54.38306231652537, 53.72322551665768, 56.51763969852079, 60.882049222146314, 60.555543284262384, 63.269819521134906, 66.2134132077617, 63.375076324709006, 68.10357985957977, 65.7423169382157, 62.68587273936119, 67.4890229009813, 68.45226287841797, 71.57111983145438, 70.25285828498103, 62.09877237196892, 33.51793573748681, 13.473239560281078, 2.7293351965565837, 0.055864529548994, 0.2719279342601376, 0.09881876919779087, 0.11265020321814284, 0.056623990812729445, 0.04744769389470739, 0.14893067940588922, 0.03453040578132195, 0.17714822574728922, 0.8284330175768945, 3.015852325385617, 46.16317472150249, 40.02584995761995, 36.75302820820963, 31.11971624435917, 0.5715140940681581, 0.21005516481255332, 0.005163080209205228, 0.07868001838364909, 0.024622717061110085, 0.11618303300272073, 0.05057711326967805, 0.14444235411863174, 0.07230521690460943, 0.04931808990095893, 0.02330390052990087, 0.029306285601529865, 0.045964440420990994, 0.03893565649407045, 0.010133676996995366, 0.040966988421015205, 0.03471612464636564, 0.009962213113002721, 0.035280727616120736, 0.016331136782443332, 0.07431622834936266, 0.050565001419595176, 0.12584828936885442, 1.484953330889825, 59.58518420496295, 56.86389084785216, 50.09430746878348, 26.240715288346816, 59.1689815059785, 15.801882090107089, 0.24865798291660127, 0.1401492586779979, 0.023385613383124434, 0.17665753111002908, 0.46950737254754193, 0.4633445629189092, 0.3868464242306448, 0.4663843998024541, 0.026556884141398535, 0.09626112337554656, 18.219311391153646, 59.06693320120535, 76.89520389802995, 84.87297534942627, 81.61596467418056, 88.73430559712072, 88.24928883583316, 89.59011185553767, 86.83681980256112, 89.10172185590191, 86.41816954458915, 86.05779786263743, 84.48710826135452, 83.322399662387, 81.26612847851169, 76.29585789095971, 77.47623243639546, 79.23924369196739, 84.54140955402006, 82.62875987637429, 80.58521286133798, 78.44862722581433, 76.74052130791449, 75.76197624206543, 76.56703487519296, 76.51764438998315, 77.96476364135742, 78.64662847211285, 76.91524720961048, 77.07949253820604, 74.01028494681083, 77.71182567842546, 78.28591162158598, 76.02843069261121, 73.19530271714734, 77.83584317853375, 74.63318870913598, 68.28383630321872, 74.65445580021029, 78.49318535097184, 71.16265989119007, 77.860318768409, 76.9092224490258, 68.34403684062343, 62.361582940624615, 72.85415064903998, 77.38395475572156, 73.01938441491896, 74.78920490511003, 67.59089469909668, 55.43081368169477, 61.73477249760782, 60.44071981983801, 60.646483436707534, 56.05667491112986, 55.361548546821844, 51.24460920210808, 61.06222721838183, 68.9998100649926, 70.16527960377356, 73.05540746258151, 69.67076286192864, 69.23207713711646, 65.22159484124953, 53.37944546053487, 56.3558066275812, 53.15364637682515, 56.83146853600779, 59.20877395137664, 61.34348077158774, 55.75438176431964, 55.35094638024607, 61.57035850709485, 67.54917636994394, 65.60612440109253, 69.47968852135443, 69.13326478773548, 69.43320059007215, 64.60583371500816, 62.481925179881436, 60.302346444899044, 69.93641714895926, 68.22886036288354, 65.75537058614916, 68.23639915835473, 65.03703947990172, 61.71935758283062, 65.36063894148796, 65.8725513950471, 66.0713057364187, 68.5851449351157, 67.49780116542694, 68.97109831533125, 65.2944803237915, 68.45824841530093, 66.01984423975792, 64.16690872561547, 64.2922951329139, 64.35332721279514, 66.10926643494638, 63.69997801319246, 62.24614366408318, 58.80262036477366, 57.61816263198853, 59.179120832873934, 62.15017111070695, 65.0996248183712, 67.43886363121771, 69.67332809202134, 68.46434377854871, 70.92936515808105, 70.7242016638479, 66.63218113683885, 70.804123878479, 68.32754719641902, 74.71276575519194, 74.56408439144012, 71.08798580784952, 54.107386373704486, 18.358120149181737, 3.2298185988779995, 0.04156009752243277, 0.4096995011693047, 0.27079409348868555, 0.6008954045753325, 0.14695366694321557, 0.022248281165957454, 0.10214085585527843, 0.027756206278178482, 0.9064118816487251, 1.689506038542717, 2.3692192041104843, 54.14903017782397, 36.93908583733344, 43.34747383671422, 38.2605048917955, 0.4258401770024531, 0.20669839735473358, 0.05888745121117081, 0.021834153186289534, 0.03385837813238463, 0.18158004438925177, 0.03480943798598263, 0.07825194377331965, 0.07142678984711248, 0.04997008052023669, 0.06625796397847515, 0.020037761273523493, 0.1114776750065146, 0.13613970769989875, 0.11250606377518947, 0.1601146591166335, 0.08238775370221946, 0.12384893778230875, 0.11460850015282632, 0.08773778234758685, 0.14774318183622054, 0.16890455277696734, 0.1941864195490076, 1.3180037732085874, 76.1990616398473, 58.234798446778335, 62.16384057075747, 62.10138074813351, 66.68359556505757, 20.939875187412387, 0.3475438767383176, 0.4832827672362328, 0.2600148073848217, 0.6201862339531222, 0.8799763937150279, 1.8790186629179988, 0.3970341372393793, 1.3825186726547058, 0.2555675290885472, 0.5016929019362696, 21.089105682988322, 74.02802190473004, 92.94542497204196, 91.50851172785606, 88.33052896684217, 94.00313915744906, 92.18628944889193, 92.10834410882767, 89.98202723841514, 92.40948015643706, 89.60268697431012, 89.63666254474272, 89.78212756495323, 89.09710130383893, 84.21533507685508, 78.10854204239385, 79.3977152916693, 84.03232512935516, 86.24834660560855, 84.75673983173986, 83.6846697715021, 85.4266728124311, 77.865417849633, 80.97621825433548, 78.59234286892799, 81.5244322438394, 80.4129502081102, 81.78500313912669, 80.41786101556595, 82.14834797766902, 78.04769823628088, 79.5475733664728, 79.4669843489124, 79.94466627797773, 76.6583162738431, 82.40942093633836, 81.71549089493291, 69.8214054107666, 76.70628686105051, 83.90400086679767, 73.21954296481225, 81.58286771466656, 81.9521039532077, 73.38272925346129, 65.31959526000485, 73.91741891061106, 83.94781374162244, 75.986861413525, 76.56585031940092, 73.694502768978, 58.90330368472684, 62.91703370309646, 62.97924641639956, 63.852318948315045, 60.49010638267764, 59.437628561450595, 53.132614627961196, 67.09709967336347, 73.32019882817423, 73.86017584031629, 75.89747844203826, 73.58561777299451, 71.76344148574337, 70.37756612223964, 58.75713656025549, 59.91620479091522, 58.647796569332, 60.80317035798104, 60.6881429303077, 63.528684185397246, 56.742658230566214, 59.675171221456225, 67.64102258989888, 68.81317584745346, 71.97003272271925, 73.70435576285087, 72.2122626150808, 71.7614253874748, 65.88004312207623, 64.7903694645051, 66.30170576034054, 75.04823823128977, 69.2160346431117, 67.42315846104776, 69.91375369410362, 67.5847993358489, 64.78792975025793, 67.44934420431814, 68.99635837924096, 69.4631596534483, 70.60463213151502, 70.19036708339569, 71.36512479474469, 69.10611414140271, 72.57780398091963, 68.00048428197061, 69.15500256323045, 68.5434893638857, 67.85375625856462, 71.50703614757907, 69.05993999973421, 66.69972435120614, 67.72588699094712, 64.31276206047305, 65.8026155348747, 70.23617252226799, 70.3525100215789, 71.46947553080898, 73.20219824391027, 74.49881615177279, 75.10850152661725, 73.31662947131743, 69.04552136698078, 77.94746598889752, 72.54907654177758, 77.9206605111399, 77.68711474633987, 73.66017418522989, 68.33432505207678, 26.074498968739665, 4.6535338028784725, 0.35881208015545724, 0.9035868558191484, 0.7309136407509927, 1.5223836514257616, 0.3891391415269144, 0.28112540201794717, 0.3274351412490491, 0.20913530772011127, 2.4734772741794586, 4.336610705621781, 5.790063604231804, 64.71627196957989, 52.157223147730676, 52.14343993894516, 43.06575744382797, 0.7267462450169748, 0.37877329775402624, 0.2811118575834459, 0.13354116810425637, 0.08847966955433931, 0.3336980326041099, 0.12373956340935924, 0.37447802662368745, 0.18026453352743582, 0.1643019271714072, 0.11343997858104207, 0.06918652659101833], [0.040157156876258315, 0.06784570418418416, 0.05489676897864669, 0.05796943272974703, 0.060844591353088624, 0.11197278997109783, 0.03764616580860269, 0.07215749217017044, 0.017706130541140036, 0.05105080075501915, 0.08249348915752866, 4.724973401715679, 58.13871214466711, 31.626572762766195, 47.54945801150414, 40.62028123486427, 38.39128848045103, 7.024205509693393, 0.10107437719500835, 0.21447392931628614, 0.07385190245845626, 0.09840053115640918, 0.06677430723944018, 0.1200167284978013, 0.058782769126757506, 0.28070126509954857, 0.07367546474861522, 1.5170168684374903, 30.866542939216863, 54.26652085396552, 64.12823415571644, 73.31948495680287, 74.1365852663594, 82.26414418989613, 85.24519258929838, 83.89149635068833, 80.51712051514657, 79.77498454432335, 81.0618200609761, 78.89558130694975, 75.995192527771, 74.57502780422088, 71.43582159473051, 67.74121561358052, 71.74430816404282, 75.34363977370724, 79.61287298510152, 80.31012135167276, 79.77963647534771, 79.0980697447254, 74.68756060446464, 71.59749384849303, 72.50004691462364, 74.90464810402163, 76.85252066581481, 71.43427618088262, 69.60077993331417, 71.84617211741786, 74.90878228218325, 74.22406981068274, 71.67103828922396, 72.58769619849421, 71.62904539415914, 69.60882079216742, 64.54683342287618, 72.25121959563225, 76.12320300071471, 71.24878729543379, 72.92227437419277, 74.42188278321298, 64.06753155492967, 62.9688560578131, 70.24997926527455, 77.65263711252521, 70.49478223246913, 75.01510204807406, 63.287113251224646, 51.71681942478303, 60.337914497621604, 63.030872652607584, 58.08275953415902, 54.32638014516523, 51.16877017482635, 50.6237058485708, 50.1555395895435, 49.1773122356784, 58.85435642734651, 58.9084106106912, 64.98482881053802, 64.43163341091525, 59.72210630293816, 56.57130164484824, 49.7609216936173, 49.742400261663626, 49.603238490320024, 51.20064335484659, 54.54257726669312, 59.344868429245494, 61.74275844327865, 58.27160204610517, 51.204400985471665, 58.531423768689564, 67.07399691304853, 63.82540756656278, 66.42193425086238, 65.10922678055303, 66.8101155373358, 63.462364750523726, 58.95870324104064, 61.763754890811065, 62.960144473660385, 66.37099050706433, 65.78324294859364, 65.42696229873165, 62.20370754118889, 58.73137051059354, 66.33181387378325, 65.30166218357702, 64.99517994542276, 60.30363690468573, 66.75066025026383, 63.59821996381206, 61.50002648753505, 63.623695758081254, 58.90812035529845, 57.84014132715041, 60.56967558399324, 60.41516950053554, 56.79055037037019, 57.23058146815146, 51.91169061968404, 54.580369303303385, 58.43123858974826, 60.721612514988074, 61.48039894719278, 63.71316894408196, 64.94696224889448, 67.27359064163701, 68.09090275918284, 65.79314693327873, 65.5692619662131, 66.30265497392224, 73.93205719609415, 71.95133086173766, 69.70344405020438, 68.14710247901179, 38.36698547486336, 19.591150552995746, 4.104470375084108, 0.17724772524689475, 0.13662085688162234, 0.10370166807044899, 0.07407941525020907, 0.051192373803426186, 0.09015508852298222, 0.024093467133840727, 0.06579608956892645, 0.19335052569306668, 0.17052896561161165, 0.2963365067637736, 32.40662236367503, 45.694380883247625, 29.022858335125832, 43.40069647758238, 0.12679747996791718, 0.045416193428419294, 0.00902479537011635, 0.05969548244930564, 0.05477906722996024, 0.007731802705224724, 0.02372798573736462, 0.06185349467540942, 0.030558002406671166, 0.023289509568243258, 0.11443548685600681, 0.029098920922185627, 0.10589169894134808, 0.053165525182961464, 0.06386528369940578, 0.037559069272491245, 0.028403357136994604, 0.04479910960541137, 0.02723032522255615, 0.025694491304156762, 0.09339079110612793, 0.0591650891358093, 0.15508251865544628, 8.402641607869057, 68.90666161814045, 36.03212794949932, 37.5607854320157, 42.90889793826688, 50.19837971656553, 8.57405604854707, 0.12444056450359284, 0.18544832875411357, 0.09502396032574678, 0.07830422161327255, 0.2228978627751912, 0.1698105589997384, 0.4355553669794914, 0.45907843377321, 0.03372381095804515, 1.81524325282343, 34.93641384186284, 65.50631969205796, 79.41588371030747, 84.49344681155297, 82.88160370242211, 85.73051529545938, 88.03010679060414, 84.38276537003057, 80.65729033562445, 85.09169455497496, 84.3759875143728, 82.6311368326987, 80.19591762173562, 79.86012351128363, 72.54791552020659, 71.02260774181735, 73.6793153516708, 78.72862954293528, 81.33105154960387, 82.98810389734085, 82.64943861192273, 80.80563437554144, 78.31227779388428, 74.60196664256435, 75.9971772470782, 77.5406220651442, 79.49728073612337, 75.2440429502918, 75.91183431686895, 73.68500278842065, 79.04598066883703, 76.58439528557562, 71.43815148261287, 74.52355061807941, 73.99515244268602, 73.27553872139224, 70.42911391104423, 74.77612772295552, 77.60809467684838, 72.48427898653092, 78.20625612812658, 74.00073005307105, 67.12420325125417, 65.52105603679534, 74.7687772012526, 76.90519025248867, 74.27683353424072, 77.56472110748291, 63.46553794799313, 55.109512729029504, 65.1202957091793, 64.66874461020193, 58.859373138796904, 56.2049561931241, 53.420649959195046, 52.87921382534889, 53.150249604255926, 52.959724395505845, 58.6126168312565, 60.622662882651056, 65.02817100094211, 63.857135618886645, 60.570107044712195, 56.619554642708074, 51.17670120731477, 51.012565705084036, 53.380947728310865, 54.42046211611841, 57.79522626630722, 61.22669219970704, 66.60598754882812, 63.04658958988806, 55.77286397257159, 56.50451544792422, 69.66304363742952, 65.55621616301998, 67.88522151208693, 67.27068808770949, 68.98183776486304, 67.03205108642578, 62.281519520667295, 62.44272501237931, 65.09444728974374, 69.20686414164882, 65.88201999664307, 68.26257705688477, 64.650968428581, 61.73710630786035, 68.31933375327819, 67.71371195393225, 68.85613364558067, 66.07923676890712, 69.0898519946683, 67.4972520336028, 65.17398118972778, 66.27571613557878, 62.39906903236144, 63.27785645761798, 63.890063916483236, 63.845282216225904, 62.820484561304895, 60.93929621481127, 57.89025352847192, 59.51562881469727, 60.56253294790945, 64.31529983397454, 64.05658421977874, 68.49815460943407, 69.53842209231469, 71.66217373263451, 72.75867231430547, 67.52425362986904, 67.94830106919812, 70.15177880564045, 74.99861240386963, 75.19651951328402, 70.10050558274793, 78.06217962695708, 58.15169518993747, 26.152232500814623, 4.994544665659628, 0.07987909154185364, 0.25963703410760053, 0.048993490786562045, 0.3730988844988808, 0.0337630155075702, 0.08888514457090248, 0.20231231416185058, 0.06239067169747526, 0.3446573800136966, 0.7534775041764783, 0.16117723838936898, 37.98049080756403, 48.04199003404187, 32.35795947813219, 53.263170719146736, 0.27326776075267023, 0.028845684813155286, 0.022944572734676545, 0.02915177715852136, 0.018464480977385275, 0.045129232213742314, 0.026051865575174173, 0.07647220661202747, 0.01772501460847355, 0.05459555086769885, 0.06612064271804786, 0.027903055757163998, 0.2097652618202471, 0.1936862254214864, 0.17838300626364448, 0.15842543524359504, 0.17515154014672005, 0.1594122484206192, 0.21760802565803453, 0.15623433184960198, 0.27198775040526546, 0.1675398284268956, 0.43109057591326777, 10.003051007947615, 86.15572375635948, 38.34568700482769, 66.31306494435957, 57.394360034696525, 57.812861242601954, 14.021614366962066, 0.4858309595334915, 0.6121533424142869, 0.20559487834332452, 0.36950170332866333, 0.4019515024077508, 0.8407589432693298, 1.1180554378417231, 1.3791062106047909, 0.12945773560673962, 2.491001933813095, 40.46301380280526, 77.05191043115433, 90.75156488726216, 90.49730116321196, 88.04987553627261, 93.60865854447889, 91.75304012913858, 87.84455514723255, 82.45047246256183, 89.88964757611676, 87.2053421697309, 88.22577030427995, 82.51785878212222, 84.9582084532707, 77.27969031180106, 74.782011278214, 78.05882207808956, 81.550076700026, 86.72977047581827, 86.54687819942352, 86.50329282206874, 83.5494186032203, 82.40683217202464, 77.96841144561768, 77.24364372991747, 81.27951160553964, 83.42020004026352, 78.05719037209788, 78.47060034351965, 78.19386143838206, 82.6333490494759, 81.12782570623583, 74.17927634331488, 77.11231493180799, 79.77641228706607, 78.2085075686055, 73.47718777195101, 77.21085271527691, 81.86927133990874, 74.49475257627427, 77.98948241818336, 79.1957446067564, 72.83532327221286, 70.53364507613644, 77.2130649320541, 83.36399247569423, 78.2448051821801, 80.63982009887695, 69.94812150155344, 58.32940993770477, 65.38990766771379, 68.62758498038016, 61.695776293354655, 61.33710299768756, 56.638534991971916, 55.48208690458729, 56.21395018792922, 53.87642152847783, 64.21120405197144, 65.58882674863263, 72.04433810326361, 71.29296102831441, 65.26471737892398, 63.245379232591205, 55.062106963126894, 55.452257279426824, 56.9540661381137, 57.01123076100504, 61.24030674657514, 66.32515368923065, 67.50465746848815, 64.51569372607817, 56.80167421217888, 62.45660628041914, 71.41062428874355, 68.25881158151935, 70.2851080125378, 70.06563571191603, 73.26142603351225, 68.71846629727271, 64.5913327124811, 68.4397348280876, 71.25002676440825, 72.7800335422639, 69.36615943908691, 69.7380393551242, 65.91230069437336, 62.77317293228642, 71.82628570064422, 71.20559415509625, 72.5551248365833, 68.81906724745228, 73.04631540852209, 71.51987014278289, 68.64128189702188, 70.88401471414875, 65.96395830954275, 66.52799514032179, 68.36802605659732, 67.9667518984887, 64.9549364274548, 67.92810870755103, 63.61037931134624, 68.4532356262207, 68.3282139993483, 70.042234851468, 69.43322412429318, 73.1518114766767, 71.68147963862266, 77.13402917308193, 75.65959453582764, 73.91062536547261, 71.72266452543198, 74.26814940667923, 79.08549462595295, 78.67757597277242, 74.56345681221255, 81.0906102580409, 72.11452499512704, 37.02065936980709, 5.7830705085108365, 0.3164018816765278, 0.58778089861716, 0.4224835474404597, 0.9562621421871648, 0.35744157950243644, 0.4670365857741525, 0.3101083468044958, 0.3034840151667595, 2.2321063808856474, 2.4979288395374053, 0.7435723550377354, 46.41987423742972, 61.18722138866302, 42.693332318336736, 60.47072202928605, 0.3955602453600976, 0.11395144186192945, 0.12194386097572504, 0.16183166133780635, 0.208165654912591, 0.15639311123278835, 0.10570930106745613, 0.1466066597570335, 0.10115584298487633, 0.15760231973423114, 0.13624794060184112, 0.07821570781450118], [0.04802333236101174, 0.05094563603521355, 0.03317870109552338, 0.06902363331567857, 0.049873733472439556, 0.012069854100475149, 0.015353438136498294, 0.04572634412456424, 0.06292656552226794, 0.045003620607237664, 0.1918151629187407, 22.74059218745078, 53.50087419632943, 35.192725043143, 44.628829802236254, 37.013359838916415, 41.78191077324652, 4.2540977654918555, 0.14684027060866356, 0.14538300283733877, 0.10221820775299303, 0.0693340138382008, 0.10329295250196611, 0.0888249070774163, 0.1996060932475713, 0.48672388097451585, 0.07422917777852667, 5.639051862301366, 46.41081356233167, 64.39481412210773, 66.91616073731454, 69.73047702543198, 74.13262367248535, 82.76001022708031, 87.65412407536661, 81.92959739315896, 78.24189478351225, 81.91102104802286, 78.19004889457457, 75.35759556678035, 76.74473393347957, 70.45180874486124, 68.82994005756994, 65.92329902033653, 69.49255389551963, 74.74349360312186, 75.46357800883632, 77.04630144180791, 78.86449260096397, 76.08854493787213, 74.19074535369873, 73.58349184836112, 71.05250404727074, 70.2963887491534, 72.46356102728075, 72.79864126636137, 72.17105419405046, 73.80327793859666, 73.43482617408999, 70.77463549952354, 71.45413906343522, 69.32016572644635, 65.46671159805791, 69.58007766354469, 71.38778824960032, 74.06077369566887, 71.13818430131482, 72.45978770717498, 68.36175026432161, 58.73094689461493, 64.47384203633955, 70.92822767073109, 72.56744892366471, 69.3566123900875, 74.35232347057712, 61.54182326409125, 51.581552567020545, 63.623997780584524, 62.83151426622945, 60.33997766433224, 55.60011494544245, 54.7488860930166, 49.30965300529234, 50.493412556186804, 52.60006266255533, 49.560304226413855, 48.42534680520335, 50.892333292192035, 54.53255953327302, 51.70247531706288, 48.48556695445892, 48.52918371077507, 48.20152459606048, 50.56664712967412, 48.344926449560354, 51.27569790809385, 52.1565406553207, 53.76917216085619, 54.458336522502286, 62.12256546943419, 65.21589563738915, 51.32804586041359, 55.59634554770685, 68.3359646028088, 62.79089027835477, 68.79320313853603, 65.17446364125898, 65.78714178454491, 65.21743712886688, 59.32029085774576, 57.31730507266138, 61.96575695468534, 65.91429325842088, 64.08321711324876, 66.9656296699278, 60.357683243290076, 61.3744165051368, 64.38790290586411, 63.32456404162992, 62.308223016800426, 60.068992876237445, 64.4614512689652, 62.403375794810636, 60.27045757539811, 61.14484017895114, 58.448308744738185, 59.43072911231749, 59.98733305162, 56.697107745755105, 54.48025080465502, 52.64172607852567, 52.543470705709154, 58.47840901344054, 60.722075354668405, 61.1886412866654, 60.23365789844144, 62.95053466673821, 68.4002757841541, 69.3471202542705, 66.52459052301222, 66.61836654909196, 67.79309288147958, 70.4186019589824, 74.94891597378638, 75.14029625923403, 70.85306721348917, 42.9023632695598, 22.485651854545843, 8.099515447693488, 0.11137468214597433, 0.2831509078462278, 0.04707789559277797, 0.08522578770475042, 0.18303392605195123, 0.08957355884054015, 0.06240964769535969, 0.09689644009115235, 0.2095603179787436, 0.22573632578695976, 0.04755583869653845, 15.760305946873082, 51.22311853593396, 26.462584157143873, 46.53334448414464, 3.2192723260771845, 0.2338879609540586, 0.06641590066494481, 0.030251494458606167, 0.08513080046301888, 0.07252168270849413, 0.10289899178690488, 0.03412382759814782, 0.0527404727894933, 0.041820080950856216, 0.14818429526302124, 0.07920518697750184, 0.014518071923615232, 0.039898713284562674, 0.012471067752959508, 0.023456545464033564, 0.11572892672472423, 0.026790962306662437, 0.009318630308693936, 0.04717968569527711, 0.052424423216331395, 0.024299054489200635, 0.15857488367586367, 36.87793216397686, 63.46813847941738, 50.58345448586249, 47.04442147285708, 40.92020919246059, 45.91885812820927, 6.911666335598116, 1.2330100565187394, 0.2173476170508131, 0.11990189957883089, 0.03713093337512786, 0.0833176312247111, 0.22902132612803291, 0.38360912052373736, 0.5369870629041427, 0.060392875269415884, 6.7379617210357425, 48.47061880173222, 74.52493129238006, 79.95446435866818, 81.83505258252545, 81.25315327798167, 87.72396579865487, 89.25147794908094, 83.72565069506246, 79.209347386514, 84.75301358007616, 81.86469001154747, 80.0999293788787, 79.759475492662, 73.745650476025, 72.09485823108305, 71.34798403709166, 72.94409059709119, 77.47584804411858, 77.16779293552523, 78.69344588248961, 81.90272131273824, 79.0307540278281, 75.33923102963355, 77.48581086435627, 75.84524031608336, 75.22366231487644, 76.81440307248023, 74.33970912810295, 76.13027111176523, 76.00731265160346, 77.35045771444999, 73.88381204297467, 74.53106587932956, 73.4673269333378, 72.0168109093943, 73.38582008115708, 75.56399852998796, 77.84119329144879, 72.20313133731966, 73.52289122919883, 70.38810945326283, 64.21158844424833, 69.81913043606666, 73.63014451919064, 73.15232922953945, 74.8114525887274, 75.21094599077779, 59.88248417454382, 55.816912189606704, 67.05222775859218, 65.335555384236, 62.785665681285245, 57.34445179662397, 54.329976958613244, 52.510879731947384, 52.274517705363614, 53.52301205358198, 52.379790198418405, 51.193222230480565, 53.58676233599263, 58.59293437773182, 54.89546898872622, 50.52958073154573, 49.606443066750806, 51.38741093297159, 53.30713264403805, 50.848053655316754, 52.591339311292096, 54.580420294115626, 56.47178326883624, 57.64869828378001, 63.40010104640838, 68.64742432871174, 55.38988374894666, 54.3982183548712, 67.8500456963816, 65.07995805432721, 70.2670729544855, 67.94171933204898, 65.53166604811146, 70.29174466286936, 63.447102808183246, 60.58116812859813, 61.59976059390653, 67.39236001045474, 65.08224871850783, 68.5887299814532, 62.16235007009199, 65.0685243452749, 67.60222250415434, 66.1977158823321, 65.43029631337812, 64.67213353803082, 66.0468223018031, 64.26081811228107, 61.8728046263418, 63.5765802475714, 60.351462364196784, 61.63531687951858, 62.19046561948715, 60.76551560432681, 59.91416908079579, 58.51842111156833, 57.631635973530436, 61.68638613916213, 62.6327952261894, 64.20630108925604, 64.55995767347275, 66.57029398026006, 71.94084244389688, 71.5375521875197, 69.94681927465624, 68.75163385944983, 71.21077952846404, 72.00892694534795, 76.52978804803665, 75.51033266129033, 76.5487095617479, 58.35820405713974, 28.79221316306822, 8.705153426816388, 0.012105365148595264, 0.2818577514300423, 0.04966888539192658, 0.08831882173375738, 0.28868978482580954, 0.10431400214832637, 0.11815440705827168, 0.05519144469872118, 0.33009622426282975, 0.6308854179036233, 0.21402846451007554, 17.926904578362745, 55.494920899791104, 30.464496074184297, 59.53258914332236, 5.668212723347449, 0.317934823613013, 0.07797871085424578, 0.028727935183973565, 0.05511000572193054, 0.0726400662754332, 0.1335628483925135, 0.051561302595561555, 0.036186461877678676, 0.01708382008326871, 0.048613063014683225, 0.024162238846803387, 0.10987037657609872, 0.09640110296107109, 0.22003437933181563, 0.0957741289429607, 0.20585038398783054, 0.15345717119353433, 0.12363498474681571, 0.1687897161971177, 0.194628375672525, 0.25713820851618246, 0.39879629268280925, 44.499999553926536, 74.14077435770344, 50.6679109604128, 63.05628568895402, 48.44234635753017, 61.16334984379431, 11.164300076423153, 2.8400048709684804, 0.5195152326937645, 0.2767990277178826, 0.30490716138193685, 0.5073809821999843, 0.7339908627252425, 0.9711236963349005, 1.4244483195004927, 0.29136530093608365, 10.056781595753087, 54.03037063537106, 88.28300552983438, 91.6117798897528, 89.05295110517933, 88.77052476329189, 91.4074008695541, 92.35357069200086, 83.48809626794632, 81.11969071049845, 88.35121554713096, 84.56401025095295, 84.29482583076724, 85.4721252379879, 76.96458278163787, 75.1523300909227, 73.22639926787346, 76.57790768531062, 80.57438711966239, 80.77636564931562, 83.87390844283566, 87.0920798086351, 81.30940006625268, 80.1615733485068, 81.3244462782337, 80.81351049484746, 78.4090740449967, 83.96823360073952, 78.89782490268831, 79.3966248727614, 78.81356454664662, 82.59379586865826, 77.00044893449353, 80.49872459903841, 77.73148459772911, 73.15494937281456, 76.83697239045175, 79.61666983942833, 80.6180666339013, 76.08161803214782, 77.52147305396296, 73.81632374178979, 65.85202955430555, 71.79599715817359, 77.0553699616463, 77.20660086601012, 77.92765801952731, 80.34040989414339, 68.2070755189465, 57.17298538454118, 68.03646810593145, 70.0919234368109, 65.19821751502253, 61.722836725173465, 56.66985119542768, 55.45257106904061, 56.916603580597915, 57.317595328054125, 54.439273803464836, 54.33053001280754, 56.94574679097822, 61.28771251247775, 57.073545455932624, 54.25679337593817, 51.98163824696695, 54.84844369273032, 57.64014751680436, 56.32107796207551, 55.429629125902736, 57.359274433505156, 59.68682850560835, 59.96958824896044, 68.98547772438296, 71.05877983954646, 56.056004185830396, 60.52287778546734, 72.49456344112274, 68.07736273734801, 74.18696418885263, 71.22709658838087, 69.56054426008656, 71.3224886309716, 62.653018966797866, 64.21414582960068, 66.53370611129269, 70.48856135337584, 65.99973817025462, 71.76152736909928, 65.78102680944627, 69.9901222413586, 70.84733270829724, 69.55767308512043, 68.83205029272264, 67.41469398621591, 71.14024746802546, 67.81952181170064, 67.56332828152564, 67.06468520625945, 64.5061819784103, 66.27564553291568, 66.58351236774077, 65.20548174458166, 66.15834313054239, 65.49126955770677, 65.24917694830125, 69.8526039431172, 68.8782322791315, 66.85230455090924, 69.2645622068836, 70.74138164520264, 78.18574213212537, 75.4969338447817, 75.13263194791733, 71.38687041498, 75.63695461519303, 75.13136894472184, 80.76789332974343, 78.53276991075086, 78.93751928883215, 71.44823197395571, 42.198921480486476, 10.486279168436605, 0.39614176738166046, 0.5820987938392548, 0.14428178208970255, 0.3433449794688533, 0.3998163847192642, 0.291544841302018, 0.18335905376701586, 0.34764984202000404, 0.7410828757189936, 1.2265940395093735, 0.44088464230299, 23.38185852573764, 71.0293463737734, 39.144054074441236, 71.80945873260498, 7.170544237859788, 0.7184874494710277, 0.22518771490262401, 0.10335830746278649, 0.18558132161776866, 0.27154623861274413, 0.3059357723161098, 0.17644674967854254, 0.1528918595924493, 0.12284635085492365, 0.18739627584094004, 0.10358457919210197], [0.047868640056901404, 0.022219167909614986, 0.02539927166165604, 0.011256326181483606, 0.013348208740353586, 0.11313925076636577, 0.17852686225406586, 0.3342655198948999, 0.16190540496139758, 0.03745669311273002, 11.449691730160868, 53.78062548175935, 30.285463410039103, 24.921278992006858, 29.97916356209786, 62.535285103705625, 13.497801442300121, 2.1837737098816903, 0.14483600073764402, 0.4524746945788784, 0.27642839438011574, 0.10507976831567865, 0.17887325656990852, 0.08213389514675064, 1.2871228302678754, 0.13918725142796196, 0.7526001189985584, 19.038059096182547, 63.14886539213119, 76.42934399266397, 65.97260321340254, 74.79614750031503, 80.40714510025518, 87.39076829725697, 83.28391336625623, 80.27745585287772, 80.0221723125827, 83.18878804483722, 79.82457899278211, 79.22625280195668, 77.78504848480225, 79.97588834454938, 70.71994196984076, 64.96413046313872, 66.52807358772525, 72.49525377827307, 74.12771286502962, 75.59855461120605, 76.94527687564974, 77.97547171192785, 72.52169055323448, 74.69356967556861, 73.6494896488805, 75.26126215534826, 72.1540467969833, 70.85168653918852, 74.04400164081206, 72.09175171390658, 71.71384703728461, 71.51706957047986, 70.45518982794978, 68.57288360595703, 68.38139349414458, 72.80658014359014, 72.65252513270225, 70.74413514906361, 71.01577497297718, 69.25341483085387, 62.20657479378485, 67.03765223103186, 71.84082984924316, 71.60485221493629, 71.63022210521083, 73.48696231842041, 58.749750737221014, 53.65761603078535, 68.53468756521902, 67.34329900433941, 57.06212351399084, 63.44602415638586, 55.13041503967778, 50.840973777155725, 49.34826089489845, 46.992893295903365, 48.51903653913929, 50.426092916919345, 58.68860883097495, 61.49748086929322, 64.3746413723115, 59.86217806416174, 56.40654640813028, 51.878585815429695, 48.568364266426336, 46.67081571394398, 47.706392042098514, 47.62788188072943, 48.293202154098026, 54.68057801646572, 57.948194780657374, 57.561519684330115, 58.433372359122004, 64.3559120547387, 50.282667529198434, 53.12342451464746, 65.24292469024658, 64.36604745926397, 66.3522651118617, 61.52194469205795, 66.57713459384057, 63.29201229156987, 61.0170336692564, 57.45903207409767, 59.920770429795795, 64.22351244957217, 66.09182757716026, 66.09101956890476, 56.10848942110616, 63.226822499305975, 61.48208556636688, 61.13218661277526, 61.4622893641072, 59.335474352682795, 61.22624112713722, 61.2091709721473, 59.747303608925115, 58.394627186559866, 59.47027837076495, 57.29938768571424, 54.54835884032711, 53.417064912857555, 51.765590175505615, 52.46418391504596, 57.11423612410023, 58.0209743592047, 58.88604133359848, 63.63591394116802, 64.47295165831044, 66.9820644009498, 64.61762043737596, 66.84697797221523, 65.9435776741274, 69.75575277882238, 68.04144167130994, 71.95406867611793, 68.95878991773053, 72.54309884963497, 46.079487031505955, 27.795621272056337, 10.188546757544241, 0.019556276928333026, 0.25600367826559856, 0.11874248679246634, 0.0708953699757976, 0.09277998154321987, 0.12482506403278922, 0.07031309718806898, 0.08890001433751277, 0.35224407130191404, 0.18919223108358924, 0.19810385611509124, 11.16660152712176, 49.601187090719904, 31.88271922449912, 29.230377212647472, 22.32614867148861, 0.5753529300132106, 0.014742586438754394, 0.02661884724793415, 0.05692032128272038, 0.058935163167094996, 0.07358322776253186, 0.07505586325761772, 0.024647095894080498, 0.04690211671855181, 0.4087969883074684, 0.14084328837212057, 0.042230010768699075, 0.03962762924211641, 0.06357630384304831, 0.026286799843693455, 0.09247648815113692, 0.04580453871899555, 0.0802575389764482, 0.10822260572064309, 0.12731159391302255, 0.12719642791536548, 18.010209837267478, 69.19437531502017, 41.79292871106056, 37.30933796974921, 23.015885699179865, 59.17208802315497, 18.558384603069676, 4.550506376451062, 2.0537503255951792, 0.8540690774398466, 0.28491502447474387, 0.11165305551502014, 0.2908995501216381, 0.09262017560221496, 2.0401727960955713, 0.4778999883321024, 0.7558155432343484, 20.689070993854155, 68.64386281659527, 85.80489127866684, 83.60677934462025, 84.63908441605108, 85.24942090434413, 90.14712764370827, 84.53112509942825, 82.02163973162251, 78.91519315781133, 83.15875053405762, 81.6809348137148, 80.67172465785858, 81.48569491601761, 81.98960181205504, 75.4571767007151, 69.34316650513681, 69.8967541417768, 74.84538109071794, 76.70166630898753, 79.47269531988329, 79.55245279496717, 80.95708493263491, 76.27271590694305, 78.0737663084461, 76.04148434054467, 79.32444541685044, 75.68585088176113, 75.45332493320589, 74.55931478931059, 75.00207977910196, 74.58273133923932, 73.32651384415166, 74.08468446423932, 73.61271350614487, 71.1106727969262, 75.35673264534243, 76.76120004346295, 75.65532699708017, 72.77414998700543, 69.37423167690154, 65.48366408194265, 71.73916985911708, 74.67197310539984, 72.03081377090948, 72.2923574139995, 74.96527225740495, 58.60749813818163, 60.283679885248986, 71.23041491354667, 68.51026688852619, 60.95999848458075, 65.29468428704047, 57.674283904414025, 52.100972437089496, 51.577842004837535, 49.23784225217758, 51.36017399449503, 54.28676812879501, 62.789729256783765, 65.00012605421006, 68.97054918350713, 64.1959499543713, 61.93016929011192, 56.75184834387995, 50.64251753591722, 49.36488389968873, 50.218983927080714, 50.22631483693277, 52.69896914882045, 58.59232248798494, 63.58192251574609, 61.07177034501107, 60.465513121697214, 66.14281838940036, 54.549904254175004, 51.97933973804597, 64.86367464065552, 66.18916511535645, 68.73778789274155, 63.54164369644658, 68.52026108772525, 67.82479347721224, 64.73873930592691, 62.092951574633204, 60.29682767006659, 65.99004207118865, 67.96063300101989, 67.54007647114416, 61.12315731663858, 64.88636162973219, 66.42795901144704, 65.49532136609479, 64.63790693590718, 61.69992616099697, 64.31985370574459, 64.16392380191435, 63.3526913581356, 63.43767735265917, 62.97160171693372, 60.503003135804214, 60.05764153695876, 57.40931603216357, 56.624987125396736, 59.3938470655872, 60.06513718635806, 61.263107484386815, 62.925007881656775, 66.59145124496953, 67.89024999064785, 70.94376810135381, 69.40487323268768, 67.79554828520745, 68.7842679792835, 71.65556846126434, 69.89421244590514, 75.4950197281376, 70.54258808012932, 78.12879716196369, 59.6932533479506, 33.782581975383145, 10.690722907743147, 0.1877303054976848, 0.5210651204951349, 0.04772013774321926, 0.10065906560949742, 0.30296335116990153, 0.08985955478443254, 0.15645599172961328, 0.06214885987461575, 0.3730447986914266, 0.1817330168259721, 0.2732757893541167, 11.896602665224384, 56.40959408975417, 36.22957614160354, 40.24080368780321, 34.19557617556664, 0.6719647071534588, 0.08056806505567606, 0.0743687819809683, 0.008850066993956365, 0.014229067169400233, 0.041982847821688464, 0.04642010951835302, 0.043580451409422585, 0.027584598752700036, 0.11127333637447127, 0.03981163590064934, 0.1522925030440092, 0.06183496300852107, 0.1907670780295326, 0.10298374409396803, 0.11191387014884142, 0.24459620006382468, 0.5528449603626805, 0.5727745844952522, 0.3040511960223798, 0.1751394359575164, 19.063870253101474, 86.71567347741897, 44.920975777410696, 36.38793399257045, 39.63701363532774, 77.8425661210091, 22.15825161626262, 10.412426821647152, 4.850958951057927, 1.3258697188669637, 0.31364865360721467, 0.3813231448012014, 0.7839605104058021, 0.2186239961414568, 3.3010554602069244, 1.2970909211904773, 1.3155622203503887, 27.73538543332008, 80.79222771429247, 93.94389567836639, 92.80444714330858, 93.40169075996646, 89.91462522937407, 93.56568505687099, 86.49080399544009, 84.40643295165032, 83.36172534573464, 88.67782346663937, 87.93937452377813, 86.10791006395894, 86.72407519432807, 87.97067503775321, 78.73794909446471, 71.78989395018547, 75.8536655672135, 78.65494389687815, 81.38655308754214, 82.92536166406448, 85.13225970729705, 82.77224017727761, 79.93172245640909, 82.54757465854769, 82.09590588846515, 84.81326903066328, 79.66176925166961, 77.9936871990081, 78.91433808111375, 77.89413744403471, 77.65874816525367, 78.64172550939745, 77.96478717557846, 73.95496383790048, 75.40786466290875, 80.75957790497812, 78.81523547634002, 77.32762167530676, 78.48956892567297, 74.76156004013555, 67.19701813113305, 73.82284272101619, 77.85433323152604, 77.7418710339454, 77.68636165126678, 80.606291678644, 64.75587221883958, 59.31938086786578, 74.72266581750686, 74.7179981970018, 62.75566739420738, 67.93902858611077, 59.67164893304149, 54.55608198719641, 55.41552036039291, 51.812391896401685, 56.324600250490256, 55.496003473958666, 63.59983990269323, 64.05740399514475, 70.6438087647961, 64.6428765789155, 62.39196954234954, 60.01586044988325, 55.08401340053928, 53.80332816031672, 53.85134973833638, 52.84489308634112, 55.59305467913228, 61.16865681063745, 65.08520226324758, 62.034406277441214, 65.96231091407039, 70.15785847940754, 56.59715006428381, 57.67009873544016, 67.12945138254474, 67.32840968716529, 72.83529973799183, 65.44058861271029, 71.46576496862596, 70.78273911629954, 65.90381268532046, 64.2935855927006, 65.83686567121937, 68.2958544454267, 71.11548162275746, 71.51454356408888, 63.3894714232414, 68.08169303401824, 70.76125237249559, 70.42479145911433, 66.09694234786495, 65.21855892673616, 69.15850131742417, 69.62638516579905, 67.62414070867723, 66.57962137652983, 65.91570531168293, 65.70257156125962, 65.68097499109084, 66.6493611181936, 65.16077064698743, 64.52686463632892, 66.83194744971492, 66.03962083016673, 66.14075522268972, 71.19711399078369, 70.95128336260396, 74.9190039788523, 73.05823941384593, 72.87323690229847, 72.9246513305172, 74.78271730484502, 73.78687458653604, 77.94299448690107, 73.27334219409575, 79.45000833080661, 70.91985733278337, 47.163453640476355, 12.28089099930179, 0.44449306964393587, 0.7771057395204422, 0.3743620102684344, 0.4902002347573158, 0.5709980572423627, 0.3075105426532607, 0.31600529327988625, 0.45431529742575466, 0.7255470416238232, 0.5292937628203823, 0.4792998761178986, 14.749827884858655, 70.09596347808838, 45.80032410160188, 50.36162091839699, 41.28666839291973, 0.7503421208070171, 0.22150741319262215, 0.15144116485551481, 0.1328514131807512, 0.18115215364002413, 0.28647018296103327, 0.12533342465758324, 0.11555379136435448, 0.10567651250429692, 0.27975643354077495, 0.17137478796705125], [3.4529664054993665, 0.3981791935380428, 0.10124254115526715, 0.1348677719192159, 0.1189504796639085, 0.3053582339517532, 1.8845140261034814, 3.3163507426938708, 0.35509517476443325, 4.690594317451601, 59.339643832175966, 49.9496308449776, 27.928069906850016, 28.764485928320116, 57.432175605527824, 48.35662687978437, 0.8810552906605505, 0.5565888626921562, 0.5735057388101855, 0.8005510943551218, 0.08769704179177362, 0.07265670570514857, 0.12526050840895023, 0.11388296892325725, 2.3858230873461697, 5.990660478991847, 5.344820657084066, 48.05551828876619, 85.1383472258045, 68.57748846853934, 73.32347008489793, 82.82933419750583, 84.7965048205468, 84.36835458201747, 83.68608182476413, 83.90953925348099, 81.7575857716222, 82.79116169098886, 80.41668430451425, 79.4210377047139, 79.79583586415937, 76.91862044795867, 73.32933795067572, 66.44391521330803, 63.39008723535846, 62.00025420035086, 67.23602218012657, 74.69527982896375, 74.29428808150753, 76.9836925691174, 81.5044673796623, 75.27470804029896, 73.04865314114478, 72.28113159056633, 72.37633535938879, 74.7592850654356, 68.93300425621771, 72.88913819097704, 70.45478190145185, 69.11473551104146, 67.11646833727437, 67.46769305198424, 71.80086874192762, 71.1317123905305, 75.38053358754804, 73.01951777550482, 63.7293016526007, 62.464419641802394, 68.52114754338419, 71.64412298510152, 71.76099392675584, 68.68495356652045, 71.49028762694329, 56.855791153446326, 54.826615702721384, 70.46495652967884, 65.86110591888428, 61.17704283806586, 61.578450356760335, 55.83692804459603, 51.38043695880521, 49.54434017981253, 47.44642911418792, 48.53930734818982, 50.9849561414411, 56.434469761387, 62.738973786753995, 67.8424362982473, 67.68207411612234, 68.10427804147044, 66.214307508161, 53.61134775223271, 49.846182254052934, 46.52149108148391, 46.09014018889397, 49.38042433031144, 47.6335261714074, 49.41746327184862, 54.3654038060096, 62.49965429306031, 62.61321083191903, 59.908579703300234, 66.49685936589395, 51.57876376182803, 51.02118315235261, 61.883222441519464, 63.00193340547624, 63.621020701623735, 61.87489917201381, 62.938951907619355, 64.24202211441533, 62.985498674454234, 60.006788007674686, 63.08471895033314, 61.84495187574818, 63.81674305085213, 63.01100192531463, 56.89374400723366, 64.82728681256695, 58.9195893656823, 61.37911942697341, 62.64700989569388, 58.01734224442513, 62.32121390681114, 58.86900255756994, 59.933929981723914, 58.20801650324176, 56.44235372543336, 52.24521760017642, 51.87999002395138, 52.77438456012357, 54.34622341586698, 55.42130977876725, 59.49334582974834, 56.445601447936035, 60.11783030725295, 61.68176950946931, 62.41946927962765, 65.56979933092671, 66.54890137334024, 67.07835074393981, 69.22282818825015, 65.25626859357281, 73.66117831199401, 72.4843103654923, 72.51917239158385, 49.3056639548271, 31.397135680721654, 11.763135194778444, 0.01717538291197871, 0.2737477608025074, 0.08385937796124528, 0.087405959024064, 0.10680405603301142, 0.1742349619105939, 0.12192270162725642, 0.2607721619067654, 0.19744540354417217, 0.5250305754523124, 0.5728302331220719, 10.204534338366601, 35.73966033997075, 40.782996839092625, 23.10768877306292, 34.99292342893539, 23.27561720725029, 1.1660601006400202, 0.36093202930304313, 0.10820126251107264, 0.13109688797304708, 0.03287186372965094, 0.09258751727400288, 1.0095520149315558, 4.857462240803627, 5.749020903341233, 6.469178363200157, 1.7645168328477492, 0.01098800388600437, 0.08053844043564412, 0.048796173350344745, 0.11311269049803097, 0.24674153736522123, 0.9386552353539775, 0.764880937434012, 0.6380010876924761, 7.876279632891379, 74.63929191712411, 59.72331439295123, 41.099732152877316, 27.39903238511855, 45.72375159109793, 55.40803647810414, 1.5070512289962463, 0.5705479652650896, 1.6286185960615835, 1.3060031590923187, 0.05335718889029757, 0.032988266959305734, 0.15180603721209113, 0.03257070307529742, 3.113755665479168, 7.408568368804071, 7.457980917346093, 50.402150769387525, 87.992295142143, 83.06296625444966, 81.73588721982895, 88.85020379097232, 88.06085032801475, 89.84674469117196, 83.96849247717088, 84.81653244264665, 84.697355147331, 84.66603894387522, 82.34000282902872, 81.47813258632537, 81.08590341383412, 79.70668039014264, 77.84981466108754, 71.62279313610446, 65.92031801900556, 64.88250201748264, 70.08250190365699, 77.79564672900786, 79.21304225921631, 80.16038879271477, 82.28465818589734, 78.19605012093821, 76.24142323770832, 72.9272714737923, 77.09341695231777, 76.0202407836914, 71.55302986021965, 75.25174648531022, 74.59256864363148, 71.96967970940375, 69.27004568038448, 72.37432710586056, 74.48805316801995, 73.84097976069297, 76.62586258303735, 73.92783672578874, 69.37221557863298, 66.56060572593444, 72.20211152107485, 74.5157451014365, 74.66197890620079, 72.48164315377512, 73.02316557976508, 58.059872504203554, 61.430918247469016, 74.51059110703008, 65.66398720587453, 64.27831580561977, 64.54689618079894, 56.59413768399147, 53.91793589438162, 52.10261198782152, 51.90788984298707, 51.77680030945809, 53.15612531477406, 59.68010164076283, 65.13666375990837, 68.08494075652092, 72.3354721069336, 68.62804782006049, 68.67945440353887, 60.46551704406739, 51.86300223873508, 50.50228103514641, 49.497428632551625, 52.84840753001552, 50.035495450419766, 51.53343292974657, 55.886746068154615, 64.96930014702582, 65.93476803072038, 64.47445784845661, 69.77530971650155, 56.599515253497714, 53.579105869416274, 65.00197741293138, 65.15301612115675, 67.34320486745527, 66.98603383956417, 64.72273603562387, 66.34565199575117, 67.07840565712222, 63.42830288794733, 63.99539524509061, 63.61736897499331, 64.84415692667808, 66.9469670326479, 61.03603755274127, 67.3518419265747, 62.55656003952027, 64.36336063569593, 66.41589380079701, 61.05885398003363, 64.46773882835143, 62.29325917459304, 62.90992636834422, 61.60585987952448, 60.69714084748299, 59.81368580172139, 56.960322318538545, 58.96524575448806, 59.27053559210993, 61.193681532336825, 62.297456110677416, 60.25967497979442, 63.55243805916079, 66.96926178470736, 65.98724149888562, 69.11344897362494, 68.5196727321994, 67.60005735581922, 70.3089403337048, 67.0189582147906, 74.34487881199007, 76.4038799655053, 74.0746275071175, 60.794097915772475, 34.97688093493062, 12.76583911911134, 0.06463633204299597, 0.060096134942385464, 0.024990184540529887, 0.2840103052796856, 0.08869841830023835, 0.16272694232963747, 0.19226808942133383, 0.31399225936301295, 0.17055922608462074, 0.382870642408248, 0.6568952060995564, 11.38270745354314, 43.47467237903226, 42.740169340564364, 27.78739606180499, 49.1292671234377, 30.417498234779607, 0.8347678292662868, 0.3077045774027225, 0.1420046623435713, 0.1687897161971177, 0.054744455377541246, 0.095882675940952, 0.5024426262224875, 1.8994016272406427, 3.540832400321961, 3.5476315838675347, 5.1253086424643, 0.5310433237783371, 0.225659410559362, 0.19098637835873714, 0.5229820563427864, 1.3417958900813134, 2.423621988104236, 4.9958571887785395, 1.1436975651210355, 8.281791421674914, 88.60194129328575, 73.67491445233746, 42.919394200848, 39.983794304632376, 78.860805573002, 65.68254786152994, 3.0683848742515814, 1.234239106697421, 4.532290399074554, 2.232803091887505, 0.2120341691038301, 0.3392015163215899, 0.27305874132340957, 0.16768233610257027, 4.198914429833812, 8.885875651913306, 11.975858076926201, 61.35200800434236, 94.12383048765122, 89.41483682201755, 87.82195445029967, 91.97991001990535, 92.08494324837962, 91.58097359441942, 88.23333263397218, 88.96812592783283, 89.15769407826086, 86.80696272080945, 85.69048358548073, 84.62803902164583, 87.31839272283739, 84.10238650537308, 83.30219945599957, 75.76727928653841, 69.5567709399808, 67.14175978014546, 73.7594650637719, 82.09410159818589, 82.12002846502489, 86.00627360805389, 85.38482112269249, 82.02464426717451, 80.17762368725192, 78.68444796531432, 80.64553106984785, 78.8128428305349, 74.20794102453416, 80.88150870415473, 78.91695037964853, 77.18219587879797, 75.08741486457087, 75.78034862395256, 76.86461725542623, 76.54242592473184, 80.2062334552888, 79.78672812061926, 72.09264601430586, 70.78205662388956, 74.7519031647713, 78.370634817308, 78.1839535313268, 73.14269588839623, 78.31848298349689, 65.05601590679538, 61.885877886126124, 77.60028916020548, 71.27060351833221, 65.89346547280589, 65.94003969623198, 62.4331073607168, 55.85213115138393, 54.27917049777124, 53.940269870142785, 55.16640278600878, 55.99468577292658, 61.96284655601748, 66.77354335784912, 74.06235048847815, 74.62588525587513, 71.60740960028865, 71.3966606509301, 60.76324455199703, 57.3660405220524, 52.10115286611742, 52.03304483044533, 55.47445004986179, 53.94984829810358, 53.184656635407485, 60.57032277507167, 69.17605784631544, 65.68151627817463, 65.90444026454803, 74.49420344445014, 57.53730297088624, 57.72168967031664, 70.13017439073133, 68.75916481018066, 69.49752746089813, 68.3456136334327, 68.36186009068643, 69.31250141512963, 70.10170582802066, 66.16807060856974, 68.91259224184098, 67.76729937522643, 68.77887079792639, 69.51651957727248, 62.70153084108907, 73.16728914937666, 65.69861388975575, 68.21187650003742, 69.09255058534684, 65.76213275232624, 68.2680134619436, 67.54879982240739, 68.64034052818053, 66.48218185670915, 64.5915445204704, 64.66019776559645, 64.9944935306426, 65.94626057532527, 65.94950829782795, 67.77291620931318, 67.98666969422372, 65.20352448186567, 68.47385944858675, 70.91861786380892, 68.73996873055735, 75.55413769137475, 72.72951341444447, 70.4818227214198, 73.53182638845136, 70.1718064277403, 78.88277869070731, 78.87858175462293, 76.23756362545875, 70.79650663560437, 44.28217072640696, 13.987638796529463, 0.29463389167381876, 0.6387353063591066, 0.11537825763826409, 0.7076306965562605, 0.12129481596451615, 0.3721469130006529, 0.3740736241302183, 0.646679699420929, 0.3275244977445372, 0.6554457064597838, 0.9468485150606403, 12.997135404617557, 54.55920419385357, 53.86427394805416, 36.90886397515574, 61.342955173984656, 36.693651368541104, 1.1239622821730952, 0.42963546850988943, 0.3095303181438677, 0.31248079853192456, 0.11279710057762363, 0.18548893141410044, 2.2660481208755128, 5.264348820332558, 8.316499494737196, 7.346600313340464], [18.111403065343058, 12.958427494572057, 1.7414828365848911, 0.34418706331522236, 2.5232671057024314, 2.0873851401190606, 2.5548032070359876, 8.258693564322687, 1.8001127098837209, 29.19678603449176, 63.41634750366212, 39.64166948872228, 23.439146703289403, 31.195855332959084, 66.8534420382592, 16.07547623495902, 0.17577671385820837, 0.05081539725764625, 0.844803519787327, 0.17908114218904128, 0.15392992405160782, 0.06050529484186442, 0.2796043191225298, 0.12768657096932012, 1.163642327150991, 3.9533022286430484, 22.92160172616282, 71.54539692786433, 73.71267903235652, 71.60911975368377, 86.12805535716396, 79.76561792435186, 83.40906835371449, 84.593443716726, 81.13352098772603, 83.41909393187493, 80.97633592544064, 79.31385501738518, 80.03345304919829, 78.72703706064533, 77.4322626667638, 76.49862089464742, 74.47502305430751, 68.98313999176025, 65.44259294386833, 61.32096244442848, 65.26124608132147, 68.77886295318604, 72.76144150764712, 72.82305409831386, 76.74288257475823, 72.9658675962879, 75.78855422235306, 71.25102304643201, 69.55190720096712, 74.53615711581323, 71.81451074538693, 68.12198362042828, 70.60002726893272, 64.87369629644579, 67.99129809102705, 71.35972761338758, 70.05177405572707, 70.3438102045367, 71.46031287408644, 65.50664524878225, 62.834942417760054, 69.96365408743583, 72.70961130819013, 70.47727277201992, 69.70313810533094, 71.63936122771233, 58.57915509131647, 54.77345189740581, 72.80305001043504, 65.31874410567745, 66.39705857922955, 67.21142891914614, 56.02130689928609, 50.99951990189091, 48.00173867133356, 48.9453903321297, 46.05650978703653, 48.92606089192052, 53.49676355238884, 58.021327372520204, 61.41390300566151, 65.3948930002028, 63.13588234686083, 63.505275480208866, 61.354883101678666, 58.99278471546789, 50.1199911486718, 47.85488120971188, 45.76321847977177, 50.15598281737297, 47.57734606342931, 49.16449785232545, 51.864555497323316, 56.77360965359596, 60.314878417599594, 64.23592675116755, 62.637455001954116, 60.57833225496354, 48.65707651261361, 54.86933423626808, 55.582813370612364, 60.450623804523104, 63.76562672276651, 61.04363126139487, 64.23444017287224, 63.12162060891429, 65.0531094304977, 57.45890655825215, 61.51502170870381, 63.24344550409625, 66.30587131746354, 59.65820304809078, 59.945249942041215, 58.13506041803668, 61.791533116371404, 64.826172859438, 56.07931875413465, 59.37370177238219, 56.88880574318671, 59.910682093712595, 58.51479291915894, 56.0022912486907, 55.357535962135564, 51.017327462473226, 52.97326049497051, 59.071993058727635, 56.048249659999726, 54.94736586847613, 57.78502025911885, 58.597205838849476, 62.84300681083434, 63.12456238654352, 64.55361912327429, 63.109975091872684, 66.00314278756419, 67.77585014220207, 71.90637265482258, 67.93901289663008, 69.538633900304, 69.69829005579795, 53.5959053808643, 39.233409589336766, 11.59601673003166, 0.36534037501100575, 0.3902115114033223, 0.40932310685034723, 0.12479525555165545, 0.1468621654015395, 0.2984441065740201, 0.0718935365758596, 0.35426629827387873, 0.20687977633168622, 0.6611957172712972, 0.7436735399307743, 10.86621759399291, 46.66543029969739, 45.9153829082366, 42.70044357545915, 19.599954312847508, 50.59715924724456, 11.479354654589008, 0.4594786381048541, 0.1212889553918954, 0.20035040895304373, 0.16982391957313786, 7.615056643562933, 12.435494161421254, 13.016668808075691, 9.072619695817272, 13.09068589441238, 19.640635175089685, 8.595721260193857, 0.6917617061445791, 0.10025175964279522, 0.3784652384779146, 0.739938891943424, 3.2101890973506437, 6.2461901480151765, 0.8350446627986047, 43.11579904248638, 73.32917321112849, 55.83763407122705, 38.789310993686804, 27.051745730061686, 68.52597205869614, 21.193691761262958, 0.030284773318036914, 0.053280139597313064, 1.0881098576130406, 0.19696460676289376, 0.04972838744100544, 0.142961613413307, 0.39491774273976205, 0.12391099090417548, 1.1250270831008111, 15.648634106882158, 26.600326030485093, 73.03651732783165, 86.35813374673167, 77.84602565150108, 91.85123274403234, 85.53476548963978, 86.62762411179082, 86.32506816617905, 84.15002761348602, 85.19373109263759, 81.631771825975, 82.02384410365936, 79.67610159227925, 81.37956342389508, 82.29973577683973, 80.67811027649911, 77.9776760839647, 72.46244707415181, 69.39930346704298, 65.88757407280707, 65.85579502967097, 71.40383858834544, 75.93021454349642, 76.7651459478563, 76.41887910904424, 77.98970207091301, 75.65153798749371, 74.55823221514302, 74.60784235308248, 76.90044418458017, 74.71071827796199, 73.17493777121268, 71.21711023392217, 70.73488620019728, 71.75939359972554, 76.1214614683582, 70.46340327109061, 72.03483812270626, 75.94904192032354, 67.02966628536102, 67.11052202409314, 75.01754176232123, 74.16987049964168, 72.97014297977572, 71.95742622498544, 75.54514761893981, 59.31127332871961, 61.06869520679597, 74.48108703859391, 68.11453896184122, 71.53706581361833, 68.07623309473838, 57.24969517800116, 54.708964209402765, 51.69989047511932, 52.51360185684697, 50.36350365607969, 50.579967498779304, 57.301301802358324, 62.235804296308956, 64.80381142708563, 67.725110361653, 66.45687472435736, 67.92602200661936, 65.48901811722787, 59.69816415540634, 51.66551482292914, 51.153245433684326, 48.643850280392556, 52.92089293079992, 49.58845899951074, 51.97403277120283, 55.129187337813846, 58.94490042040425, 61.188280428609545, 67.4502149704964, 65.34591828623127, 65.78734182542371, 51.68510706193986, 56.66684665987569, 58.76822117836245, 60.944387451294936, 67.2141824230071, 65.63023913291194, 65.0116382106658, 64.74314020526025, 68.45016048800561, 61.99212704935382, 63.61734151840211, 66.29879536167269, 66.95914991440313, 65.72722758016279, 61.741518974304206, 61.68525257418233, 65.2869729072817, 65.93021808132049, 60.0902521225714, 61.97988140967585, 59.50755265451247, 63.2567148823892, 62.04158029248638, 61.74264469454366, 59.05673503875733, 57.23641011022753, 57.87633695910054, 63.542553686326556, 59.74895492676766, 58.156731513238725, 61.81613814446234, 61.73360363129647, 66.33110784715223, 67.78370272728705, 69.87107830662882, 66.36420480666622, 67.47403944692304, 68.66528680247646, 73.30801594641902, 71.67291318216633, 70.3460459555349, 75.18314423099642, 61.729598891350534, 40.454392433166504, 12.3597365233206, 0.48007610704629655, 0.6844287125333663, 0.10460434947162868, 0.24517001524086923, 0.1025946710198637, 0.34377463222030674, 0.14182072463295153, 0.34951958685151996, 0.21286299962910915, 0.5198775616384322, 0.8247896872701184, 10.883623111632563, 55.01537192252375, 46.08963812551191, 51.41962535919682, 29.45915141413289, 65.54945399684291, 12.782127741844425, 0.3099263243136868, 0.0856582903032822, 0.10362854497807641, 0.11363238922410435, 4.272800607066001, 12.567716279337484, 17.891626781032933, 19.51761003463499, 20.109723191107474, 32.63005037461558, 16.250580645376637, 2.8764159881299545, 0.745142222412171, 4.744898551894773, 4.595017433166504, 5.433475538607567, 13.680978090532365, 3.8694956418006656, 50.256246443717714, 87.62773436884727, 63.667018336634484, 34.081580331248624, 43.8961898896002, 85.97200778222854, 26.572310501529326, 0.559695931451936, 0.13234611690765427, 2.7730855586067324, 1.0771106736313913, 0.6505674424190676, 0.19763052103019532, 0.9913546688133671, 0.26658581930302805, 1.495520563856248, 26.51987429588072, 33.28648451835879, 77.98593659554759, 89.62830005153533, 84.44279332314768, 95.08491316149312, 92.37476718041205, 90.09357944611581, 89.42403085770147, 86.57442892751386, 87.62444742264287, 88.37149420092183, 84.53019942006758, 83.51432123491841, 82.3957867776194, 82.75743715224728, 83.01406998788157, 82.30605079281716, 77.19004846388295, 73.9522809367026, 68.07752747689524, 71.1990281074278, 76.32196518682665, 79.50816139098137, 80.58805265734273, 82.53171259357084, 80.12537771655668, 79.97133839514949, 78.03153022643059, 76.83647032706969, 80.3544206003989, 75.58968220987629, 77.46168828779652, 74.41063342555877, 73.19680106255316, 75.18801581475043, 78.3934159432688, 76.24119574023833, 77.82696293246362, 80.27452976472917, 70.07809315958332, 70.71576856797742, 77.1906368194088, 78.53975957439792, 75.41163013827416, 74.99195221931704, 80.00932262789819, 64.25484042013845, 61.80302566097629, 77.42149183827063, 72.97139813823085, 72.59044185761483, 72.11953778420725, 61.220012403303585, 56.766435638550796, 54.286222919341064, 56.16070401284003, 52.56451422168363, 56.04388798436811, 58.80895107023178, 66.57194137573242, 66.45431733900502, 72.13159515011695, 68.94051167272752, 70.62851936586442, 68.16947567847468, 64.95199464982556, 56.273083840647054, 55.05149695181078, 51.345880877587106, 56.796175049197295, 54.35099694036669, 55.03555251706032, 59.41753033668765, 63.732929845010084, 67.75200997629474, 70.05119354494157, 67.35788237664008, 67.21934426215388, 52.54272545537641, 59.60567466674313, 62.55187672953453, 66.21061263545867, 70.11243743281211, 66.26170542932326, 70.45278933740431, 67.90415871527888, 71.63796486393099, 62.569715669078214, 66.26027768658054, 66.4552116394043, 70.60495376586914, 68.14577671789354, 66.82379676449683, 63.76698386284613, 70.69239908649077, 72.90922072625929, 62.9617565678012, 67.03354158709126, 65.08357447962608, 66.4373883893413, 67.67882639361967, 66.39314405379757, 67.08022563688218, 63.62864578923872, 68.15458636130056, 68.70014098382765, 65.69606434914374, 61.98240349369665, 67.28509103098224, 66.6349817091419, 70.03569233802058, 71.52109392227666, 72.87901063119212, 69.27173229955858, 70.55604180982037, 73.1919922367219, 78.41272184925695, 74.77415084838867, 72.93371200561523, 77.56462697059878, 70.63962751819243, 46.95909815449869, 13.324911209844775, 1.0183396562933922, 1.3956799406197764, 0.9358384832739831, 0.9081996244288261, 0.3046780091620261, 0.6770987832738508, 0.32374599888440103, 0.5671461671590805, 0.2427987279670854, 0.7677983841107738, 1.157665002730585, 11.92245206525249, 66.05232930952504, 57.11401254900041, 60.77763572815926, 35.66190719604492, 78.99405633249592, 17.49665391060614, 0.34057829889558977, 0.1346007289905702, 0.32501905315345336, 0.5043499400058101, 8.611416624438379, 24.446291731249904, 26.557964432624082, 35.949503221819484, 33.10647910641086], [17.10081223518618, 24.921031882686002, 11.735330493219438, 5.273627186975172, 6.621313864184964, 2.1585040851946804, 4.881768678465198, 5.486894788280611, 4.664610576245093, 44.12842558276269, 52.44492899987006, 27.723359446371756, 17.37029867787515, 50.82195812656034, 60.78075401244625, 5.197632735775364, 0.08760733289584037, 0.10458643067507975, 0.08105504416650341, 1.0724491818297295, 0.28695324736256755, 0.12678985739307058, 0.05897552067894609, 0.24868548547308295, 0.12862224011651932, 0.553411988000716, 27.648991307904645, 74.76783583241125, 61.043764621980735, 89.20940660661267, 79.69106935685681, 82.49576799331173, 77.34342098236084, 85.61098498682823, 83.0784047034479, 82.90022711600028, 76.21726143744685, 78.3172199803014, 76.42255044752552, 80.09965481296663, 79.81863267960088, 77.59485275514665, 73.76160667788598, 70.17268503865888, 63.79773916736726, 58.65786529356434, 63.46700883680775, 65.9073349737352, 66.38108668788787, 70.31918556459489, 71.55434777659755, 72.39637082622897, 70.20836291774627, 69.86088798892114, 71.4836980450538, 69.44819973361108, 70.92929455541795, 69.34724577011602, 67.89801628358903, 64.58591591927313, 69.3288420092675, 68.22915846301665, 70.37569907403761, 71.05077035965459, 66.05725580646147, 62.62750394882695, 70.49619428573116, 68.50639158679594, 71.58066688045379, 68.87628678352603, 69.61979558390956, 59.90994076575003, 54.561330118486964, 71.5405253441103, 65.98548427704843, 66.84533057674285, 66.49195640317856, 58.150294903785955, 55.60703400642642, 50.64700864976453, 48.64499561248287, 49.646506155690844, 47.32025823285503, 50.22198061789236, 54.48682861943399, 56.48818269852669, 57.403832558662664, 60.9211003395819, 64.34407826392882, 61.53483360044418, 57.0593229416878, 54.096909722974225, 50.34819464529715, 49.82518580652053, 49.186059121162664, 49.702411697756865, 47.22472106256793, 46.52742562755462, 48.35768199736073, 54.050551229907626, 54.71887211645804, 58.75927817436957, 63.714024020779526, 67.79280262608683, 57.59454604118102, 53.401520559864665, 58.90021285703106, 53.945510156693004, 60.327826161538404, 62.33556585927164, 62.18082051123343, 62.238393060622684, 62.14763333720546, 63.46746775411791, 59.800110478555005, 62.85291864025978, 62.05628133589222, 60.61217446481029, 59.026634770054976, 60.52415255577334, 59.987360508211204, 62.28097431121334, 59.5508477764745, 57.76190180932322, 55.754299394546024, 58.79125333601429, 55.394727876109464, 56.166183563970755, 52.85245541603335, 52.20592329579016, 49.83359929054014, 57.32949187678676, 57.08993311851256, 55.7213750193196, 54.563326604904674, 57.05762063303302, 60.41154523049632, 62.10120816384593, 63.092500932755016, 58.73526150180448, 62.237165358758745, 63.801614469097515, 68.95362023384341, 68.94751702585529, 73.78521150158298, 65.44840589646371, 57.30802866720385, 34.095249791299146, 10.407398343086243, 0.6473612112383689, 0.20858623718302097, 0.11201513165067281, 0.057985141362634406, 0.022462239947109934, 0.09286808165451212, 0.022452596815363057, 0.13058302683695672, 0.09855693566703028, 0.2752162287792852, 0.4237383994604311, 7.223483487482994, 58.74220409700948, 39.472823219914595, 50.58045779505084, 16.886133070914976, 55.66075871067663, 45.323607075598936, 0.23144938051700595, 0.02166826259194603, 0.13150706676946533, 2.637656657926498, 25.111647305950044, 27.663870819153328, 20.490287234706265, 23.407430418076057, 13.518434089999046, 34.92869461736372, 31.422756602687222, 10.881558964329383, 3.8414178452184125, 5.698420366933269, 2.4987052236833884, 4.792852469028966, 12.095617844212441, 6.074246677660174, 63.1119558888097, 64.45050001144409, 43.38521880488242, 19.329197022222704, 34.9950336640881, 74.68726250433153, 6.34040302807285, 0.08294659952122359, 0.10468725550679431, 0.1763902583550061, 1.5171422617089365, 0.09436527026757117, 0.11195008312502217, 0.039087403190111926, 0.18664072928649766, 0.26589952709694065, 2.664544995753996, 30.082412112143736, 81.57071621187272, 70.69283839195006, 90.92644768376505, 86.08258724212648, 85.81992180116715, 83.31549629088371, 87.94180639328496, 83.2934525705153, 83.44789197368007, 78.23946291400541, 81.78086111622473, 77.42143692508822, 83.07127383447464, 80.97762246285716, 82.18834046394595, 77.1776145504367, 75.47148550710371, 66.26767527672553, 63.88040311874882, 67.44704569539716, 70.1695785214824, 68.97378906126946, 71.681487483363, 75.01848313116258, 75.39321853268531, 73.04323242556664, 71.56277302772769, 76.00369622630458, 73.52288338445848, 74.03488605253159, 73.7566880256899, 66.99765974475493, 67.29795640514743, 72.3976573636455, 73.5303908009683, 73.72857247629474, 74.75220910964474, 67.18294466695478, 68.22511842173915, 74.51812990250127, 72.05774476451259, 72.69580456518358, 70.07049160618936, 72.88689459523847, 60.14598508034984, 58.16365057422269, 75.11359276310091, 68.92148033265146, 72.01922708942045, 68.3389691383608, 60.64713455015614, 58.88863402028238, 52.75279583469514, 50.73968641219601, 51.51133429619574, 52.037222154678844, 52.956311933455936, 57.170710409841234, 57.4066762770376, 59.728656661125925, 62.764657466642326, 66.73348026890909, 66.45097547961821, 58.80207515531971, 55.846898709574056, 52.850003934675655, 52.0555906141958, 51.58888739924277, 50.73661519635109, 49.427610443484404, 47.37752483737084, 49.30890383258943, 55.307541431919226, 59.328327794228834, 60.65045679769209, 64.79301314200124, 67.95413755601453, 62.65747477931362, 55.04070651146674, 61.77920902928999, 58.790841487146196, 60.655218555081284, 65.35577912484446, 65.22419929504395, 64.51170467561292, 63.836154860834924, 65.52229550576979, 63.267309204224624, 65.03637267697242, 62.75914261418005, 66.44532726657006, 65.78334493021812, 64.07096755120062, 63.97572455867645, 64.57685132180491, 62.955316035978264, 60.053342619249904, 59.92500266721172, 61.03988147551014, 59.23369669145154, 61.101650960983775, 57.375520890758885, 56.540287463895744, 57.63608001893567, 61.51626117767827, 61.985694362271225, 59.94017831740841, 59.01859391120173, 60.162055030945815, 62.845426913230654, 65.11555356364097, 66.86307537940242, 62.85243226635841, 66.78167050884616, 66.532301902771, 69.21098263032975, 72.94160381440194, 76.36566823528659, 69.29717279249623, 64.18224127061906, 35.49022113123248, 10.597857852135936, 1.1980318302108397, 1.1413779734603822, 0.15639853513529225, 0.07906188257038593, 0.061540892497906764, 0.03436759294521424, 0.10134480623227936, 0.0797702304478134, 0.12673146617148193, 0.19401150635413586, 0.5212030163215053, 7.495911217504933, 68.60855364030408, 43.28776751795123, 58.104603213648645, 28.233032226562504, 66.92056163664788, 51.61337083385837, 0.14616418269372758, 0.13087271532464412, 0.18937054570884476, 2.321608494366369, 27.030282520478774, 36.225124251457956, 31.249480016769905, 29.329128765290786, 33.696862497637355, 50.04215563497236, 42.566345584008005, 23.69830946768484, 9.403332375711011, 17.216718273778117, 8.820180854489728, 12.982290214107884, 13.658292082048233, 8.69848539752345, 75.26410979609336, 83.74663537548435, 47.060052117993756, 24.52728475293806, 65.32734586346534, 85.32537368036087, 9.886914530108053, 0.20745374472631564, 0.2659291900213688, 0.9528699661454848, 2.9072828350528597, 0.5986845361128931, 0.45452989397510407, 0.16058494517159078, 0.5034278152931122, 0.45142736045583604, 2.4381578016665677, 34.583957502918864, 86.39897346496583, 77.46867010670324, 95.60033613635649, 92.20540708111179, 91.48318106128325, 83.20224177452826, 90.97004090586017, 86.97895080812516, 88.94944760107225, 81.88506280222248, 85.60806674342003, 81.01909760505923, 87.19045285255679, 84.83754065728958, 86.56388559649068, 79.30278608875891, 79.14350648080149, 67.9456966154037, 65.86758567440894, 69.39148226091939, 74.135847860767, 72.41745748827535, 77.2204468327184, 78.00538370686193, 79.50326627300632, 76.28091366060319, 75.54411211321431, 76.39856907629198, 77.03137290093207, 77.20861696427869, 78.92351642731698, 71.68635122237667, 70.9850549697876, 75.77577514033165, 78.89340831387427, 78.51352676268547, 77.74126698893886, 72.7192917177754, 71.47155438700031, 77.17971694084906, 75.21821806507727, 77.65431588695895, 75.1597982837308, 76.70688306131672, 68.33587046592467, 60.254371935321444, 77.48522250883042, 73.77871605657762, 73.70857623315626, 70.71118723961615, 64.42447116298061, 61.121086305187596, 57.64911405501827, 54.491104002921816, 56.016694191963445, 53.75979769614435, 57.123571365110344, 58.811308414705344, 60.711304526175226, 62.83491496116885, 66.48363313367291, 71.17581552074802, 67.67446471798804, 63.46036041936567, 60.633931852156124, 56.17355369752454, 57.01135235448038, 55.06604894515007, 54.790827997269176, 51.42884292910176, 50.09746497677219, 52.25328591562087, 57.54537128633069, 60.04587834881198, 63.54278510616672, 69.2978003717238, 71.17353270130774, 63.15059907974736, 59.26530315030006, 64.19772286568919, 60.50534479079708, 65.1691331401948, 66.39400697523548, 67.90550801061815, 66.13817430311634, 66.65994367291852, 69.37381590566328, 65.4592316381393, 68.07222443242227, 64.5145836953194, 66.27960712678971, 67.13962601077172, 66.73688488621866, 67.59743721254411, 66.89422684331095, 68.61490787998324, 64.67894669502013, 63.554108988854196, 66.83485784838277, 65.18098262048537, 66.46108734992244, 65.14874466003911, 63.09483474300754, 63.35491141965313, 68.79252849086639, 67.5514199656825, 66.07669507303547, 63.889848186123764, 64.72539148023053, 69.24999452406361, 70.15519911243071, 72.23769526327811, 64.5367999999754, 68.21810522387105, 70.3112231531451, 73.41535552855461, 75.13376159052696, 76.43176017269012, 71.72297831504576, 65.73638631451514, 38.82238441897977, 13.343315951285824, 2.25817616908781, 1.9250343163167278, 0.18048957951607245, 0.2310458973290459, 0.13597467703925026, 0.3401919147900997, 0.32827887984533466, 0.4354728133447709, 0.25081907098572104, 0.4807113471531099, 0.5561121108551179, 8.612215807360988, 76.43667098014586, 54.52999430318033, 59.738493965518096, 31.81949846206173, 78.42648152382144, 63.5426046771388, 0.5770858821849669, 0.28713937608465073, 0.26856725975390405, 5.5711884844687685, 36.874711898065385, 50.99206739856351, 46.50723326590754, 47.37748953603929, 47.9243738420548], [8.74480760866596, 8.5758299404575, 12.743548289422067, 11.318810082251026, 8.021275929866299, 8.038645165581858, 7.14545528734884, 9.848369398424703, 4.015169283074718, 28.84707731585349, 36.311306568884085, 26.99188643886197, 43.621274886592744, 63.26068824337375, 38.840195901932255, 1.304917030276791, 0.09855960931388602, 0.1270004013373006, 0.08421439842711534, 0.6026949757529844, 0.05655557150021196, 0.2168382605117175, 0.10349258735415437, 0.06749716482215351, 0.15417838168721046, 0.6022746692742071, 39.225172611974905, 63.431844788212935, 82.99488175299861, 79.79857367853965, 80.81383997394194, 75.36868802962765, 80.73609859712663, 81.65002653675695, 83.50672752626481, 79.57795604582756, 74.53725537946148, 71.51159394171931, 74.73815133494716, 76.34494243129608, 73.93812118038055, 77.19354721807665, 75.49629842081379, 70.31020333690029, 64.39402964807326, 60.429960758455344, 60.673402663200136, 65.58111929124402, 66.13338116676577, 66.79783067395611, 67.58646242080196, 69.43986077462473, 70.08121536624047, 70.11542627888342, 69.55655913199149, 65.19480505297261, 70.23532529031077, 65.10923462529337, 64.91113139737037, 65.18990993499756, 67.72997410066667, 70.20797852546939, 70.52311743459394, 65.09507486897131, 65.01429365527245, 72.7591900671682, 68.64443548264043, 65.43559151311075, 69.71496797377064, 68.64163491033739, 60.05567250713226, 51.82701841477425, 67.20325469970703, 66.90054185928838, 68.28240071573566, 69.29716494775587, 59.04509736645607, 59.44278647822719, 53.53175893906624, 49.58021417740853, 49.69917181999453, 49.07866462584465, 51.31272508252052, 49.73655985247705, 48.97111715808992, 51.36546134948731, 56.588210982661096, 60.00316373763546, 61.657105645825794, 59.33798466959308, 58.3298296313132, 53.47890107862411, 49.643576145172126, 49.642991712016446, 48.836160167571045, 47.641304231459095, 45.56550748886601, 47.557063487268266, 49.381683411136756, 50.939452725072066, 57.93113639277797, 58.38253844168879, 59.216312746847834, 61.06775383795462, 66.33341420081355, 59.940076335783935, 53.248269634862105, 62.03097812591061, 54.15761232376099, 55.25320091555196, 59.57813962813347, 61.34706581792524, 61.802743250323886, 57.91498407240837, 61.0609132243741, 60.35713018909578, 58.6172216938388, 61.4766413165677, 60.52319941982147, 57.96312332153321, 62.624283682915475, 60.06096378449471, 57.94284074537216, 57.824538138604936, 57.88990835989676, 54.383478087763635, 52.20360517501832, 55.371993818590724, 52.26366842946699, 50.934620365019775, 52.44089680333292, 55.148999229554214, 58.343389264998905, 54.51000982715238, 54.348000249555035, 53.81540906044745, 54.44919740000079, 54.37287592118787, 52.0076867072813, 56.496105886274776, 64.9781725483556, 64.02194576878702, 73.18181760849492, 66.21440948978548, 68.24457337779384, 64.9142575263977, 40.46408068749213, 16.09625106857669, 7.348348219548503, 0.260291303838453, 0.8810571292715689, 0.12431095008768382, 0.05199912184428784, 0.0518760344974937, 0.07368219100059041, 0.041872266860258196, 0.0834007824080125, 0.029761931716254162, 0.014165260663796819, 0.16590207034061033, 4.51515160260662, 72.50054113326534, 29.09768342971802, 34.14425588423206, 19.82002281373547, 38.017282639780355, 65.59579680042883, 2.9943550402118317, 0.20455997016641403, 0.37327346061506583, 15.204864990326667, 30.638062915494366, 46.58255061795635, 52.63650932619649, 43.87229873288063, 22.59141464387217, 32.525852610988004, 31.78157110368052, 28.32279762914104, 7.142378187948658, 12.457134858254465, 4.20511422618743, 8.41783686991661, 16.80398883358125, 7.823465899113686, 35.88111669786515, 53.49199395025931, 41.9747462580281, 31.295587478145478, 63.12126759559878, 51.618171814949285, 2.3400352991396383, 0.040490864776074886, 0.3214879394058259, 0.09522355687353881, 1.0455471157066285, 0.04914210418299322, 0.14481165446341038, 0.1948846320831968, 0.18404401298011505, 0.11434941687771391, 0.9575882097405772, 43.46662367543867, 73.67742476924774, 87.94878036745133, 87.20091773617654, 86.11238156595539, 83.51130100988573, 82.85819499723374, 83.0946276264806, 84.82012533372449, 81.16537063352524, 75.83104133605957, 73.86707921181956, 76.73990157342728, 77.56930243584418, 78.56847916879963, 79.00092048029747, 80.01744193415489, 74.04901442989227, 68.9489604580787, 64.16169589565646, 63.81139686030727, 68.44753249999016, 68.73646997636365, 70.57359833871165, 68.16048560603973, 71.84438351661929, 72.61041456653227, 73.13955014751804, 71.8677608428463, 71.8266700929211, 71.04363164594098, 68.62676912738432, 68.9058614546253, 69.09926568308185, 70.17664663253292, 73.7531735820155, 73.32461541698825, 67.81505815444454, 68.35061857777258, 75.89867868731099, 69.72497786245039, 70.19920810576409, 72.04612670406219, 70.22762960003269, 62.456429773761386, 57.20538808453468, 71.29016045601138, 70.44306970411732, 73.22260241354667, 68.99116516113281, 61.936025388779186, 61.071648751535726, 56.43363821891047, 53.20098154006466, 51.92660347107918, 52.1814477059149, 55.140048380820986, 54.68048780195175, 52.0536490409605, 54.93001330283381, 61.67200673011042, 64.35753199361986, 65.4299158434714, 64.83275067421698, 62.161000774752715, 58.73481827397501, 54.038893945755504, 53.500697689671675, 53.653670126392, 50.754414912193056, 48.83075514147359, 48.38868441120271, 50.172095914040845, 51.05129518816548, 58.19047174146099, 64.84916187101796, 64.07836514134561, 64.28267355888121, 66.8468838353311, 63.49554800218152, 54.76402251951156, 65.42054137875958, 57.44136571884156, 58.0540281726468, 62.36059450334119, 64.68299850340813, 66.1736011505127, 60.33815376220211, 60.89512248193065, 61.549264000308135, 59.02931767125284, 63.84824752807618, 64.25256152306834, 60.86545759631742, 63.65106605714368, 64.01033163070679, 60.226593709761104, 60.67040597238849, 61.04021487697479, 58.62581560688635, 56.686478122588134, 58.32778607645343, 56.57330205363613, 58.49661273341025, 58.39867899494787, 59.47900172202819, 61.73194054634341, 58.629302593969534, 58.25086839737431, 56.69509556985671, 58.76323976824361, 56.79384908368511, 57.042217485366336, 58.58266953499087, 67.83564275310886, 64.6578404211229, 74.27388391187115, 70.41083566604122, 67.75384564553538, 70.53729288039669, 45.10628031146142, 21.883417021843698, 12.223194895252107, 1.1584700692084529, 0.6579224380754656, 0.16996199926061017, 0.07666348344496182, 0.21426086494278526, 0.0610983886215235, 0.10928811144924934, 0.04867892742397324, 0.1583609459621291, 0.08386957459151746, 0.2630081886966383, 5.8230178875307885, 78.49476998852145, 36.85355463335591, 39.04745394183744, 26.302119993394424, 45.84983618028703, 76.18592954451039, 3.4380702241774532, 0.09424526259423265, 0.2745345943877774, 15.310525798028516, 41.78155775993101, 55.621174150897616, 54.9323667249372, 55.834060792000066, 40.59950051769134, 48.32253756061677, 35.908694882546705, 52.887552784335234, 35.40909867132864, 16.904075953268237, 15.580143640118262, 19.736474367880053, 27.549386639748853, 7.35541093734003, 62.414389810254505, 71.22746529117708, 42.95939453186528, 58.73118223682527, 84.52849711141279, 56.619299688646876, 4.685709985994524, 0.1757126689077385, 0.9994641691446305, 0.24815852423348736, 2.038750569185903, 0.5327173178234409, 0.4740085374684104, 0.36944268391497675, 0.3948542187290807, 0.23568618381696366, 1.5388435101316822, 49.50841519140428, 80.63799227437666, 94.8253228587489, 92.19441659988897, 92.6096857747724, 88.00723152775919, 89.28516326412078, 88.33922093914401, 88.74688856063351, 86.29208887777021, 80.21964796127813, 76.96590069801577, 81.91795579848751, 81.72237857695549, 82.08984190417875, 82.69256899433752, 85.3424124563894, 77.7955839710851, 73.04641739014657, 66.13225936889648, 66.9258019231981, 70.62800945774202, 72.07960805585309, 73.17353356269099, 73.23198472299885, 76.2047569213375, 76.65479398542836, 77.90981123524328, 77.05430307695943, 73.52011419111683, 76.1210770760813, 69.82877162195021, 72.09502297063028, 72.50221206295875, 75.1759506041004, 78.24301658138153, 78.07585300937777, 72.21018375888949, 72.02786414853989, 76.89262297845657, 72.62625309728807, 69.34394313443092, 74.97929865314116, 74.03028118994929, 66.5654145517657, 58.39360737031507, 74.68268117597027, 72.97567352171868, 76.28283562198763, 74.10161341390302, 65.39998815905663, 64.89812481787898, 58.65996376160653, 53.947883190647254, 54.24387701096074, 53.67677288670694, 58.696743826712336, 56.12180586784117, 55.766207710389175, 55.689564597222116, 62.99654799122965, 65.03572156352382, 67.94718711606919, 66.39619565779164, 64.02340096812095, 59.28476202872492, 56.61502822752922, 57.335171468796275, 57.54483784398725, 54.738276081700484, 49.4161335883602, 51.37775405760735, 53.358288195825395, 55.43689727783204, 62.71002669488231, 63.40971477570073, 62.945596402691265, 67.82887274219145, 69.81499625790504, 65.84740900224256, 57.569168306166134, 68.25285742359777, 59.787256871500325, 60.16061944346274, 66.01595324854698, 66.97208589123142, 70.06982480326008, 64.7428656393482, 64.78643140485211, 64.71620136691679, 61.400437508859945, 67.67240939601776, 66.93305830801687, 64.05488583349413, 69.35290967264484, 68.1269964095085, 64.07250512030818, 63.645727711339156, 64.48976685923915, 64.47552473314347, 60.11127602669501, 65.74505867496615, 61.862841806104115, 62.3037201358426, 62.913523181792236, 69.23359117200299, 69.42006064999488, 64.03965134774485, 62.89836714344641, 60.95139280442269, 60.95669192652549, 60.856106665826616, 61.314023771593654, 62.4327661145118, 70.96121480388027, 69.61125266167426, 78.86055454131096, 75.68227368016397, 72.56318922965758, 74.04182080299624, 51.821801662445075, 30.690597180397283, 14.459755862912825, 1.2791756180024918, 1.146881671682481, 0.26305421525912903, 0.29274428984330547, 0.3515951335430146, 0.2668391799013461, 0.3782449422344085, 0.28893913112340436, 0.21675039022680254, 0.2368450603417812, 0.5516104556379781, 6.5503400468057205, 89.13335184897147, 42.97221675995858, 44.99590481481245, 34.16534254627843, 53.6374472033593, 89.80808581075361, 5.267589678687434, 0.4783047891912922, 0.6355413938722303, 24.120862483978275, 55.62289607140326, 75.50382937154463, 85.14695290596255, 96.22869983796151, 62.06315725080429], [9.282235080196012, 5.596121520765367, 36.124327182769775, 22.747587734653106, 34.38032765542307, 38.061570121395974, 39.07416528271091, 16.93975971591088, 2.5936077054469817, 20.15244564702434, 22.63999712082648, 20.712277696978663, 46.889040700850956, 71.77080769692698, 40.5085015296936, 0.46361425651177285, 0.09893346788181413, 0.03709510344290926, 0.07537869270890951, 0.08920661804656829, 0.3456602503936137, 0.04194414889019343, 0.10773934979712772, 0.0853382494120348, 0.16207182990206828, 3.325432010235325, 55.409648572244954, 74.87800736581126, 76.36550349573936, 75.61180437764814, 79.62471854302191, 79.20389529197448, 77.86016187360211, 81.70326094473563, 81.40947541882916, 76.43739269625756, 70.97517059695336, 67.46329999739125, 73.23327126041536, 77.53681736607706, 76.29266508163946, 76.4374162304786, 75.09954283314367, 72.48225504352202, 64.9533204109438, 58.13720203215077, 60.822146784874704, 63.89870489797285, 68.69960754148423, 70.6364268641318, 68.86737515849453, 67.82249496829125, 68.24026661534464, 70.29292921866141, 67.50557530310847, 68.34721396046301, 66.14886668420607, 65.1490584496529, 70.65064937837663, 63.523549802841686, 69.00334019814768, 66.82400857248615, 68.52283416255828, 62.67709839728571, 70.28908529589253, 67.36615857770367, 64.03987884521484, 71.28883469489314, 64.66159805174797, 62.97026026633478, 55.87464555617302, 61.23618825789421, 66.94472343690934, 66.55003101594987, 68.58452520062848, 59.83968327122351, 62.63693724909137, 57.87872568253548, 50.82778284626623, 49.588972830003314, 50.007921188108384, 51.37830711180165, 52.53680659878639, 53.78559904713785, 53.74172341439032, 60.66663265228272, 63.72981156072309, 65.49844357275194, 64.92597364610242, 64.83670442335068, 65.49299932295277, 60.96341486900084, 58.09740174201227, 54.80562317755915, 50.70186691899454, 48.37176330627934, 44.343489139310776, 47.18703100758214, 46.33207198112242, 48.89472115424372, 51.56616118646438, 57.904479965086914, 63.82810223487116, 64.21297304091915, 60.11050724214124, 66.87011211149155, 54.939360310954434, 59.12654146071404, 62.09824677436583, 55.42533020819388, 56.4428714782961, 59.16652217988045, 61.05800282570624, 54.37884576859013, 53.38644689129245, 55.29207944869996, 54.02722881686304, 54.98336145954748, 60.17734835224768, 60.4923499784162, 58.59844530782392, 58.72538497371059, 58.520531346721036, 53.98334533937516, 56.415583549007295, 51.73024962025305, 50.96488145089919, 50.625094367611794, 49.192189785741995, 50.32746491893646, 54.519235241797666, 50.60381550942698, 57.996345796892726, 56.688619736702215, 56.044029189694314, 50.963394872603885, 52.19489751323577, 50.93229832187776, 56.13108619566887, 60.47721747429141, 62.349482428643014, 65.48054579765567, 61.34881127265192, 71.80649342075472, 64.27360503904282, 39.99905232460269, 14.12496195685479, 8.385080176015055, 4.318990438215194, 0.1348929915336832, 0.05405614452977335, 0.03635977777922827, 0.07991089185159053, 0.07120443282709008, 0.21344893431711584, 0.03535786500921653, 0.05749220208775613, 0.04649409829008003, 0.15757481717774946, 0.09529206045572797, 4.720510234755855, 73.98551910154282, 37.989559327402425, 34.057226334848714, 61.63791741094282, 46.70102188664098, 54.020439194094756, 10.42008819118623, 0.7207417091534984, 3.387012731644415, 25.604730421496978, 33.62089403213994, 41.460625510061945, 44.6603617360515, 36.69759335056428, 16.788044398830785, 30.842489004135135, 22.948872004785848, 35.78475582984186, 24.47271085554554, 16.740444475604644, 13.03272306919098, 17.40542350276824, 26.280556763372115, 6.944819188887074, 23.208852583362212, 42.15076654188095, 31.930831017032748, 43.70264053344727, 79.74760640052058, 44.43863015021048, 0.7502735406160356, 0.08144247015157054, 0.02977617712120616, 0.03322454762735194, 0.17114681552254385, 0.7465884125521107, 0.02024815008494883, 0.10541711513313556, 0.10402957668467876, 0.12392063595114217, 3.9831365116180915, 58.791021916174124, 82.0446248208323, 87.11762228319722, 83.27848480593774, 86.5115454889113, 82.79670007767217, 83.46321275157314, 84.0806330403974, 83.10684188719719, 77.7396588171682, 71.36754881951117, 70.05878725359517, 75.94067158237581, 80.99769715339907, 77.4410487759498, 77.72290245179208, 78.23832542665544, 74.65396158156857, 68.16785181722334, 61.3306506987541, 64.76212447689426, 65.2017201915864, 72.32432473090388, 73.63983277351626, 73.15994647241408, 72.28077073251048, 70.35469870413505, 71.26047595854729, 71.35254967597224, 72.28550895567864, 69.21189262020972, 71.01082494181972, 70.96195220947266, 66.13567183094641, 68.08294034773304, 69.40433979034424, 72.89164066314697, 68.73887831164946, 73.00498931638657, 68.9591899994881, 67.93734981167701, 75.51736939337947, 66.14195546796246, 63.782987133149184, 58.39545480666622, 65.28794565508443, 69.03019274434736, 70.87165924810594, 69.83200365497221, 62.49807357788087, 65.16661497854417, 60.460414040473204, 53.50600465651482, 51.66989611041162, 54.094481775837565, 54.12055377037295, 54.58899067294214, 55.7694907342234, 58.010646758540986, 63.488071964633086, 66.01097183842813, 68.5540719186106, 70.3415273850964, 68.82098136409637, 67.68976196166008, 66.36094139468285, 62.57404988811862, 58.61566843525056, 55.165790896261896, 53.5656560620954, 48.98077403345416, 50.78668817397087, 48.93576091335666, 51.41562846399123, 51.41935079328476, 58.08225354840679, 63.463666977420935, 66.76048186517531, 62.15956126489947, 67.14288157801475, 58.88493522520989, 57.916403970410755, 64.63735388171288, 61.17019830211517, 57.930673553097634, 61.014311544356815, 62.86630176728772, 56.92355009817309, 55.14670856537358, 57.99531813590758, 54.3836820510126, 55.84846373527281, 60.40563029627646, 62.705468900742076, 60.2823188227992, 62.41016933994909, 62.40801988109466, 58.333834371259144, 60.15236285425002, 55.484310888474994, 54.94348272200554, 55.83210352928408, 55.275256403030895, 60.09493151018697, 61.59674821361419, 59.45329450791883, 59.532094924680656, 61.548534439456084, 58.085254161588615, 57.87898063659669, 54.596525546043154, 55.802042484283454, 57.44209527969361, 64.87481024957472, 65.04082848948818, 67.51498899152203, 65.7346369374183, 68.37202687417307, 75.3489585076609, 43.72907338603851, 20.84273769009498, 15.247823769046416, 7.9862584798566765, 0.2624982805742372, 0.10199585839384988, 0.06447104857333245, 0.01412012946656755, 0.03519064716754421, 0.06034908568366401, 0.03567223684982427, 0.052959558614079034, 0.04639399741145392, 0.2586164517748741, 0.18053600444428383, 6.5875545144081125, 81.37405641617315, 44.519505500793464, 33.78310365061606, 62.24515914916993, 52.104220159592174, 68.55993193964805, 12.757656074339344, 0.7566394861186705, 1.5897021875266106, 35.21520414660054, 44.022243099827925, 69.6350928275816, 80.8110237121582, 75.56406128791072, 48.87036715784381, 54.78474440113191, 46.92850366715462, 86.29302240187123, 111.96673162521856, 63.784344273228804, 64.88577719657653, 56.96685698724563, 44.327301517609634, 3.2192885058541454, 59.04395595673592, 54.40546297257947, 36.004079080397084, 61.75148179454189, 88.5762889923588, 58.48226078094975, 1.708779339828799, 0.32208401709795, 0.2257750438706529, 0.17819071819465007, 0.4370811383330053, 1.7500056566730624, 0.15875283057891554, 0.36340894477982677, 0.5683877198926864, 0.279640294611454, 5.679162019683469, 66.59815065322384, 94.66103830645162, 93.94448403389224, 92.41149625470563, 93.19813543750395, 89.31415742443454, 88.45540938838836, 90.76177873919087, 88.76034229032456, 80.81104724637925, 75.99349021911621, 74.89847429337041, 81.20375494803153, 84.71032250312068, 79.40174748820644, 83.2786887691867, 83.24203029755624, 79.64216524554838, 73.22290051367976, 63.46106644599669, 66.84846062814036, 70.54289402500277, 75.2257490158081, 76.36357368961458, 76.83661153239589, 75.10546561210387, 74.75003611656928, 75.94176984602406, 75.73538257229713, 75.79032713367094, 76.01711857703425, 72.28543835301554, 76.41134031357305, 73.1307718830724, 72.37973213195801, 71.35950796065792, 76.12117905770579, 69.54226601508357, 76.69982279500654, 72.99529321732061, 69.63452016153644, 77.72857419906124, 70.51852826149234, 70.0683186131139, 60.01280492351901, 68.8247468394618, 72.9073222990959, 73.69978227922994, 73.92920171060871, 65.8128607657648, 65.78376462382656, 64.97665851346909, 56.674036364401545, 53.74453575380387, 55.92932731874528, 57.503044989801225, 59.1145743093183, 59.02362631213281, 61.461889282349624, 66.64671744069746, 69.36837165586411, 70.39479317203646, 71.45948133160992, 70.51319383805799, 72.97202571745842, 69.71430901558169, 64.82673375837265, 61.732289637288744, 56.07443540327011, 55.11354884793682, 49.887826058172415, 54.830514538672666, 49.91131713313442, 52.50497264246787, 55.101538550469186, 62.04706768835745, 68.23430461268272, 70.22064778112596, 63.31933944456039, 71.12728011223578, 59.09033406165339, 64.98785688031104, 65.58144092559814, 61.67857670014905, 63.57531724437591, 65.05110509933965, 64.70742702484131, 58.58487390702771, 56.99362716367168, 60.594782675466234, 58.47714208787488, 59.700662705206106, 63.975532362538004, 65.45768230192124, 64.70301828076764, 64.86378838939052, 65.8174499388664, 63.11139498987506, 63.924953399165986, 60.93363623465262, 61.5745162194775, 62.97839133970199, 60.98034774103473, 63.59638821694159, 64.98992004702168, 64.53392882500926, 66.44227566257601, 65.97348966906148, 64.94101985808342, 60.9042537596918, 59.552028409896366, 58.31414015062394, 61.48195612815119, 68.62250943337718, 70.0961752860777, 71.52112530123803, 70.73317604680216, 71.1629815255442, 76.79278296809044, 51.78476664327806, 37.66929388046265, 19.44140426574215, 9.661289991871003, 0.304328887573173, 0.2756144106388092, 0.15069179296974214, 0.1230150740593672, 0.2464678447933928, 0.3540661961080567, 0.10355011289638859, 0.2186790318979371, 0.1319646051213626, 0.5648456357659832, 0.45437204921918534, 9.612927167646347, 90.94871890160346, 55.43101372257356, 45.60014201748756, 78.10987564825243, 62.537673827140566, 79.92698423324093, 17.45999740016076, 1.1230695752366897, 4.0458000523428765, 47.460490811255674, 55.02412273037819, 84.76721256009995, 95.5822696993428, 89.7866382906514, 64.36986000307145], [14.613727523434548, 38.682736273734804, 43.847007290009536, 45.431593848812966, 45.103640556335456, 42.43047468123898, 17.73599301615069, 10.653794773163336, 2.2804336586306175, 10.672781005982431, 19.903900738685362, 27.997529199046475, 62.334683325982866, 75.17021609890845, 36.220684128422896, 0.47013682102964777, 0.18673878854080556, 0.07841180334047926, 0.052114850916569276, 0.05342621724271486, 0.2758226946236626, 0.17793991632999914, 0.08836533093164045, 0.20046965819933724, 0.12965270498346898, 8.367375577649764, 79.63936467324534, 75.19353851195305, 70.34725404554798, 69.18388689717939, 71.83806065590151, 79.27658465600784, 77.74653865445045, 78.83964830829252, 79.41628379206504, 79.43665658274006, 70.4792574913271, 67.05258861664804, 69.4726517892653, 74.61622053577055, 72.49486154125583, 73.54835525635751, 73.72550518281999, 71.66244829854658, 71.95656330354753, 59.72327909161968, 59.662031281378965, 63.370942146547385, 67.53143156728437, 69.36744597650343, 70.54905999091365, 69.46828226889335, 69.02507797364267, 67.97678532138949, 69.93507569836032, 66.25992467326503, 66.47849482874717, 66.73822633681759, 57.714092039292865, 63.20537890157392, 65.52218960177514, 63.08080442490117, 65.55960509084886, 70.29861665541127, 67.75706983381703, 65.94900623444589, 67.41459200459143, 65.36283939115464, 61.253140741778964, 62.77966053255143, 60.75701190579323, 66.21706885676231, 66.87834908885341, 70.40437159999725, 65.34045442458122, 66.3214195928266, 61.931071435251546, 52.96440378312142, 48.913787795651345, 50.471235475232525, 54.546068176146484, 52.87125533626926, 54.44250583648682, 55.8083967239626, 59.527290021219564, 60.04995761379119, 60.82108774492818, 64.58221712420064, 62.4228346732355, 64.34307021479454, 61.149613703450854, 61.16685644272835, 55.581189509361025, 53.73559274981099, 57.604057788848884, 60.32715151386877, 51.50381511257541, 47.60301797620712, 48.69274654696065, 49.03657367152553, 48.132145712452555, 52.62184750649237, 59.417710765715576, 62.51298642927601, 64.4918849391322, 61.25406249876946, 63.71784833169753, 53.04716579375729, 58.6884323243172, 64.32789456459784, 57.84843714006486, 57.30363169024068, 56.32612605248728, 62.8470076284101, 54.343289482978086, 56.03435662484939, 55.468264472100046, 52.31747158112065, 47.167466225162634, 57.886401760962706, 58.18588649072955, 55.66853284835816, 57.76192926591443, 55.51045348567348, 51.39554592870897, 50.43401610466742, 48.25741837101598, 48.570878505706794, 50.157567454922585, 54.43442575393185, 52.47537443714758, 57.48924609153502, 55.475093318570046, 57.51612217195573, 51.109695357661096, 54.700813524184696, 51.81867945578791, 54.161138534545906, 55.21568736722393, 59.944551760150546, 63.44927187888854, 62.16635481003792, 58.68902067984305, 49.28435764005108, 30.29848764019628, 12.355047329779595, 10.310140232886038, 3.6843460413717457, 1.857692123420777, 0.20947771837874768, 0.11700525985009248, 0.08766597692644404, 0.07477452512830496, 0.054245425703664946, 0.10836640808490977, 0.07905767674768165, 0.3692577196465385, 0.10409925238139207, 0.32861182165722697, 0.24506530634337859, 9.901291977974678, 71.04586739693919, 44.314283171007716, 34.85464419088056, 117.63689425683792, 62.10664849127493, 53.605970182726466, 20.62710342868682, 1.457280519027864, 5.018099479136929, 10.751745181698954, 19.897266049538892, 18.204580929971513, 13.99236721377219, 14.450585361449951, 10.091294530899296, 22.135990204349643, 41.4332865899609, 59.41262345160208, 79.84451247799782, 52.65677229050667, 49.519138951455396, 44.19290934839557, 23.41695393285444, 4.96306078087899, 20.98512561090531, 32.86342355512804, 29.372723948570993, 61.59449285076511, 87.58460398643248, 41.99769212353615, 0.8393122015460845, 0.25550264144136065, 0.07684634097160832, 0.019584137630919297, 0.050716093110461394, 0.4917679570855633, 0.25027347848780696, 0.3389945193644493, 0.17981241907804243, 0.12981724534784594, 7.797466958722762, 82.91435549336096, 85.02936024819651, 80.60491884908369, 79.01471937856367, 80.14089461295836, 83.75255815444454, 84.20155186806956, 83.36028191351122, 80.45968132634317, 80.49672419025053, 71.21556482007428, 67.92693199649935, 71.03384140999087, 77.37980488807925, 74.21661730735534, 78.24440510042253, 78.37603984340545, 76.40333867842152, 73.93543827918269, 62.77906433228524, 61.18135352288524, 67.66073642238494, 69.92551295988022, 71.58447157952094, 76.10031204838907, 72.99518339095577, 72.52468724404612, 69.91478135508876, 72.40660036763838, 68.61687690980973, 72.26410065927814, 66.82433020684027, 60.991440203882036, 65.71356988722279, 66.9765652379682, 68.07273434054467, 68.13830068034511, 74.16918016249134, 70.35684816298946, 69.10151712356075, 70.7943650214903, 67.57258507513231, 64.09802406064927, 64.63643212472239, 64.36196819428476, 69.3107363485521, 71.31414182724492, 71.71385488202496, 67.13689604113179, 69.1261339187622, 61.65417563530707, 55.43253560220042, 52.329583860212765, 54.85615899485927, 55.91054701036023, 57.108544764980195, 59.17114273194344, 58.814697342534224, 61.54867956715246, 59.80993993820683, 63.64607287991432, 65.65306732731482, 64.08995182283464, 65.6353303693956, 64.86385899205362, 61.96569027439241, 58.15990078833796, 56.19686826582878, 63.61427422492736, 63.95348471979942, 57.58431649977162, 53.83284791823357, 50.55790024418985, 52.28748113878312, 53.18956352049305, 53.009715003352014, 61.68781780427503, 63.14033815937658, 68.46788960118448, 65.45069263827416, 66.77230388887467, 56.85241399272796, 61.10661668162192, 66.32513015500962, 61.47748462615475, 59.558735662891024, 57.11400470426006, 65.27374275269048, 57.89948286548738, 59.37765159914571, 60.09907745545911, 52.145581553059245, 49.70489455807594, 61.81598124965545, 61.56574579977221, 59.43660090046545, 61.39794680380053, 61.77001499360608, 55.06018500174246, 55.89072727387952, 54.11527818249118, 54.48118432875603, 57.031666309602805, 60.36118199748378, 58.80662902708977, 62.56709552580311, 58.72604000952936, 58.568274436458466, 54.11801991924163, 58.999523347423924, 54.165009913905976, 59.71657576099519, 59.33845535401375, 64.88999374451177, 64.7431598171111, 66.74334895226264, 61.26578646321451, 55.054297524113814, 31.95555763859903, 15.53470298167198, 14.770225190347242, 7.902900759250888, 2.158399652088842, 0.18154737840016044, 0.05977571483761553, 0.060926164395266005, 0.08021643835931055, 0.04777233514394011, 0.1999685294445484, 0.044719325378537185, 0.38792814037972884, 0.07851431356562723, 0.4344121186483291, 0.37902298113030775, 12.049172078409503, 77.86839100622362, 51.96187342366865, 35.01359039737333, 122.52958820712183, 66.80370638447424, 69.0689536063902, 22.273222169568463, 0.7725641251571718, 6.850046880783574, 36.51351651837749, 34.461618777244325, 43.70507632532428, 48.075043847483975, 47.06823418217321, 27.455740051884806, 43.322472649235884, 100.00697781962734, 87.8333842369818, 148.91863576827512, 89.36863914612802, 71.47393918806507, 47.120025157928474, 25.9695206534478, 3.2879834261632737, 63.65898924489176, 37.29302483220255, 48.610596426071666, 76.77451256782778, 96.7901949728689, 51.21288114978422, 1.0876764357089996, 0.3611201804972464, 0.4391999536704633, 0.22729825649049976, 0.17690015115564872, 1.259913593530655, 0.7158115962820669, 0.6468205983119627, 0.7291869398566985, 0.3096212681022383, 12.418038633561904, 91.09824749731249, 93.50952456074377, 89.56012141320014, 85.54999997538906, 86.60075587611045, 90.78404211228894, 92.63675012896138, 87.2883395225771, 86.23921532784739, 86.71609709339758, 75.15697417720672, 72.5219415849255, 78.43362808227539, 82.17975831800892, 79.62638947271532, 82.02564054919829, 80.95909318616314, 80.32080588802215, 78.80852037860502, 65.48247168141027, 64.07116759207942, 71.31616577025383, 75.3979959795552, 75.60113553077944, 78.58624750568022, 75.58941548870456, 76.13966126595774, 73.6440924675234, 76.77015089219617, 73.26465022179389, 72.77720159099948, 72.74774459100539, 65.60886613784298, 68.14901659565588, 70.17525811349192, 70.09253532655778, 73.95085319395989, 78.88763458498063, 74.39885847030148, 71.62094962212348, 73.1677362995763, 72.4989329614947, 66.22550195263278, 68.77515239100303, 67.01118407710906, 71.35279286292293, 73.80925563073927, 77.2056124287267, 70.8404685604957, 71.72592793741535, 65.91128087812855, 58.30057659456807, 55.56167964012393, 57.205956828209665, 58.6389555469636, 59.907634412088704, 60.57261343925231, 60.67676021206764, 65.0366040968126, 64.31930849629065, 65.90785272659795, 68.95287498351067, 68.45429466616723, 70.48589414165866, 66.2428702077558, 65.55145048326062, 60.550832517685436, 61.90394432313981, 66.03999737770327, 65.76972253860967, 57.84308702714982, 55.74791377590549, 53.13424633395288, 54.22256285144437, 52.569852567488155, 58.06020198329803, 62.9671262925671, 67.72127428362447, 69.25230087772493, 68.18861684491559, 69.7933526192942, 58.654405763072354, 67.0795274549915, 68.98408136060162, 63.0845267541947, 62.35273015114569, 60.16276105757683, 69.74054182729414, 59.779306227161044, 63.0936501872155, 61.53599069964502, 55.994387672793486, 51.24000826189595, 63.93444553498299, 64.5516618605583, 62.544694869749016, 65.29220927146174, 64.04248722137945, 59.37351349861392, 61.05040911705264, 61.837189505177165, 61.25618450103268, 63.99053150607694, 64.92213364570372, 60.48089273514287, 66.66709023137247, 64.09769850392496, 64.42339643355339, 58.16394475198562, 64.58664155775502, 60.007666618593284, 62.9107226094892, 63.47590084998839, 69.46122200258317, 70.44311677255939, 71.74637133075346, 68.59330346507411, 66.18218329644972, 47.317343911817, 33.28224835857269, 21.01737533846209, 9.807119792507542, 3.8218388442070257, 0.3348735179151258, 0.21273854098493056, 0.29816191042623214, 0.1580644239701571, 0.11416489694027171, 0.404433106342631, 0.13475636741326702, 0.8020772640743564, 0.1856455197858234, 0.890515986229143, 0.4355274200920136, 14.413229688521355, 88.10889936262562, 64.10686508301767, 48.714131309140114, 121.20436053122245, 71.64585667271768, 82.05141836597075, 26.469003115930867, 1.056428996305312, 13.038905705175093, 47.94467603006671, 46.35201723344865, 58.36684503862935, 40.303145839322, 37.058070936510646, 25.218624068844704], [19.362960784666, 53.529064270757864, 53.1115161988043, 42.645981465616536, 27.85861061465356, 39.40751183417536, 14.442652367776441, 13.405785579835216, 5.7138857822264395, 11.368394724784359, 29.329562187194828, 42.663722345905924, 85.175962755757, 64.26454828631493, 42.55442157868416, 1.577332993188212, 0.23745155682967556, 0.06839822211693372, 0.056626059250125, 0.16988833224581135, 0.048049348706920306, 0.3000187543371032, 0.18559336451993835, 0.08589187817227456, 0.31437459852426286, 15.986337431015508, 89.55582249549128, 73.13564346682641, 74.15906829218711, 66.52360993046915, 70.1865545395882, 69.42959985425396, 73.06168325485723, 74.1772916240077, 75.45008505544355, 75.95558443377095, 68.69817195400115, 65.69699395087459, 65.34800106479277, 73.69062746724775, 71.68209152836954, 72.42046202382734, 73.42813461057602, 71.9607053264495, 66.77821882309453, 66.72157195306593, 55.98602125721594, 60.19510099964758, 62.24380593146048, 64.72785472869873, 65.4350463036568, 67.6052741081484, 68.23788181427987, 69.51637052720594, 69.81273697268578, 67.53861734944006, 68.300459308009, 59.723522278570364, 56.85356716955862, 62.835620987799864, 64.27697827739101, 66.75635553175404, 69.00277537684288, 64.53877687454224, 67.15183242674797, 63.54257722054759, 64.44234540385585, 62.323806593495036, 63.609163376592825, 58.97722859536449, 63.195369012894176, 66.83079427288425, 66.13975109592562, 66.70962441352107, 65.94275397639122, 61.09983098122382, 55.95482272486533, 48.985347517075084, 48.27839520669753, 55.18601463687036, 59.29347753524781, 63.919050232056655, 62.03117032204906, 57.580256846643266, 54.04146702058854, 52.65265772419592, 61.03981479521721, 63.67689878709855, 64.26277537499705, 64.30667454196562, 62.742343102732015, 59.33363868344215, 52.634948222867905, 54.2142278148282, 58.3689631185224, 64.03921204228556, 64.92379673065679, 59.51941390191356, 47.954952639918176, 47.24545471129879, 53.0281932892338, 53.023902216265284, 58.84661366862636, 62.2819588261266, 61.63138274223574, 64.01350875054636, 61.584137793510195, 60.22206337221208, 53.827591942202666, 60.09687308342227, 63.70646561345747, 58.162666059309444, 57.13365577882337, 58.437537916245006, 61.77442373767976, 57.88824527494369, 58.513008240730535, 53.01606924303117, 52.54779315763905, 56.53781244831701, 53.4561905553264, 57.68853779762023, 54.538313650315814, 55.538969116826216, 50.46283375832343, 47.27791624684488, 44.20263290405274, 48.336332536512806, 53.99749332858671, 57.836999508642386, 56.26763959084788, 56.87154731442852, 51.949043350835005, 56.22478769671533, 49.733527860333844, 50.051330058805405, 49.26959383872248, 58.80022771896855, 58.80374216264295, 61.82853675657704, 56.5973069590907, 53.60023959990471, 29.336830339124127, 28.15541244322254, 22.55463653995145, 15.978295591569717, 5.383314797955175, 2.179202677742128, 0.3388928441751388, 0.36112257069157017, 0.13700290492946102, 0.24518797234181436, 0.021885574922987053, 0.0931861307171564, 0.01067408212205215, 0.07631132048704932, 0.1255370661496155, 0.038570535158918756, 0.3563583618210208, 0.27120732131504244, 11.348792679848211, 66.6431402391003, 49.6584419281252, 27.82730813949339, 42.513001349664506, 43.21753355764574, 60.26897884184315, 12.3531126206921, 0.5837480279226458, 2.133163367548297, 8.132982090596231, 11.00334071343945, 0.3920915218130235, 2.984664334404853, 5.7061371399510294, 2.9032320072574, 17.253849391014345, 63.2131608839958, 72.85414280429964, 94.88535081186603, 54.802281318172334, 51.445967997274096, 33.47457393523186, 10.97771292732608, 8.572995047415457, 33.28869673513597, 39.12411274448518, 39.45336041911956, 92.02745699113416, 70.87354198578866, 50.54507801609655, 1.4011184294377605, 0.18222315987992674, 0.08644196760630415, 0.09195860505344407, 0.08697385479125284, 0.0555185221075531, 0.3583522741833041, 0.5842367920183367, 0.10991955942083752, 0.3255247324705124, 16.896231212923606, 91.88472194056358, 80.95946973369968, 82.1124896695537, 74.61207066812824, 76.84759416887837, 78.24671929882419, 78.6136648731847, 78.52845530356132, 77.41085437036331, 76.22250172399706, 71.49075831136396, 67.09006294127434, 66.35357518349925, 76.49565558279716, 75.37401460832166, 73.9784509904923, 75.60465781919419, 75.50147594944124, 71.56392620455834, 69.7526462616459, 60.3090968439656, 63.317817564933534, 64.61109361340924, 68.69287675426853, 68.86688093985282, 70.74801045079386, 71.6302691736529, 74.30059525274461, 72.6518661745133, 70.46206182049167, 70.10690689086914, 63.76923138095487, 61.717831780833585, 66.39240664820518, 69.04640782263972, 71.04920925632601, 72.26433600148847, 67.00911306565808, 68.13895963853406, 66.3329827400946, 67.63110683810326, 67.30901748903337, 68.02500694028794, 62.493547162702015, 66.27076610442131, 69.00847850307342, 67.9084497882474, 69.35224286971554, 67.46016210125339, 63.44452188860986, 60.37347078323365, 52.585847993050855, 51.890529432604396, 58.66109732658633, 62.78340639606599, 67.36978284774288, 66.11057650658393, 63.22195091555196, 56.73916732111285, 58.056891502872595, 63.76826647789248, 67.7957679379371, 68.14403518553704, 66.55433777839907, 64.35475495553786, 62.06973114321309, 55.49750574173466, 57.03179574781849, 60.773489782887125, 66.10870945838191, 66.14957271083709, 63.41730848435433, 52.130464738415135, 47.68772548244846, 55.623068655690844, 56.16070401284003, 60.128004935479936, 64.9298450254625, 63.75341638442009, 66.0878973622476, 64.21787992600473, 64.07596072842999, 57.12444997602894, 61.420508277031686, 65.47947106822845, 63.815825216231815, 59.00416743370795, 58.79596018022107, 63.40304674640779, 60.781977791940015, 61.48319167475547, 57.937835801032286, 54.99876852958433, 60.054138860394886, 58.236920449041556, 60.78308782269878, 58.22598880337131, 58.08175540739491, 55.48150247143161, 51.87387112648257, 48.98562600535732, 54.423572555665054, 59.33572538437382, 60.25226954490908, 60.70970027677475, 61.03938725686843, 57.48657887981784, 58.2556026981723, 56.90130241455571, 55.75564084514495, 53.80740350292575, 60.104188303793634, 61.77445903901131, 66.41678025645595, 59.14955400651502, 59.30091827146469, 32.492512464523315, 29.222546200598444, 21.54517731358928, 15.964698695367384, 10.165535192335806, 4.123791725404801, 1.214385417199904, 0.43679584719000325, 0.1976839939673101, 0.08807047901134338, 0.04596141054325047, 0.06784633237628207, 0.15577101719475564, 0.013257861118613472, 0.21378124793691022, 0.035179718923304355, 0.254877774165042, 0.2954234525320992, 13.620332364113102, 75.2343782301872, 56.340152448223485, 33.98474093406431, 55.00980215687906, 47.06437064755348, 73.34878506199007, 16.745376856096332, 0.6983563748578872, 10.458513690579323, 16.975417983147405, 18.408789327067716, 14.447259191543827, 11.621145394540603, 17.415043115615845, 9.86315869515942, 30.204160521107337, 105.55155400306948, 101.20899600367393, 161.9133383227933, 73.15061907614432, 64.5539564471091, 37.141601731700284, 24.52257790873128, 11.752154519481044, 65.93121436334425, 53.88696485950101, 61.58532234930224, 98.84057475674538, 82.54591941833496, 60.03972807238179, 2.4214261962521464, 0.39471197152330034, 0.3009543928407854, 0.3198352426050171, 0.4340739061515178, 0.33858968786174254, 0.9617347065960208, 0.7466799140937868, 0.6910931871783349, 0.33380415110338124, 19.328473344925914, 100.1072100670107, 88.69880030232092, 88.99512752409905, 83.52495870282574, 85.86486431860155, 84.20376408484675, 85.1655763195407, 81.23202739223358, 82.88513383557721, 81.36350524040961, 74.89674845049458, 70.98098354954874, 70.35695014461395, 79.44103394785236, 78.65248064840995, 78.3862772295552, 79.30273902031684, 79.61574416006766, 73.36162690193423, 74.6074422713249, 62.058685748807854, 66.97471387924688, 67.61963782771942, 71.06905644939792, 72.17379200843074, 74.64905077411284, 75.95902827478226, 77.70447515672254, 76.19256619484194, 73.41047610006025, 76.02041336797899, 69.46991397488502, 62.349768761665594, 69.43743674985825, 70.29430204822172, 75.95682390274541, 77.45227459938296, 68.32754719641902, 72.18382543133151, 72.24048799084079, 71.62840212545088, 69.26008286014681, 70.40275558348625, 66.56295914803782, 67.46597505384877, 73.59581593544253, 71.40204214280652, 72.59404259343302, 71.56241216967183, 65.60004864969562, 62.70617100500292, 55.80602369000835, 53.825830797995295, 60.00213607665032, 64.12024428767543, 71.46862829885175, 67.32706039182602, 64.05294818262901, 58.38958694088844, 57.22540786189418, 66.07968391910677, 70.80956028353783, 72.39928122489684, 70.71387014081402, 69.3660496127221, 65.19318511409145, 58.407535706796956, 60.440853180423865, 64.33817509681948, 72.57421108984178, 67.73829737017232, 67.38449958062941, 52.55735197374898, 51.567392810698486, 57.852900797320956, 59.6480990225269, 63.21917387746996, 68.40688105552428, 67.72707154673915, 70.6012196694651, 66.02103664029029, 66.00137772098665, 60.85580464332335, 65.91637211461222, 67.54173171135687, 65.4932346651631, 61.390451154401234, 63.50518134332473, 66.72958143295781, 64.19265124105638, 63.317762651751124, 59.28411483764649, 55.207579828077755, 66.38317338881954, 58.515753899851155, 65.5321406549023, 60.03459761219641, 63.306281874256754, 58.97955848324684, 59.30458176520563, 55.55942819964502, 59.97631119143579, 65.54320958352858, 65.46363253747263, 64.81380954865487, 65.91447368744882, 65.56391969803842, 66.90712359643751, 60.09458241924163, 60.83753816543087, 56.750961888221006, 66.75219781937139, 66.3320884396953, 71.0531630054597, 65.71962602676885, 67.23711259903448, 47.64011183092671, 49.807260574833045, 32.496921208597, 23.204365391885084, 15.072539910193413, 6.648216420604337, 1.8243404549937097, 0.8564458499031683, 0.3713494461149939, 0.8075886844627319, 0.10828983759687794, 0.5832759339001872, 0.2994241781773106, 0.28556953935373214, 0.6639807226677096, 0.17404596801967392, 0.6476091172906661, 0.44818552150841684, 17.81556025628121, 83.12530056122812, 66.88486022333946, 41.84579049387286, 59.33316799902148, 54.50347123607513, 88.39518531676262, 22.189042222115305, 0.6329289727634, 20.701249953239195, 34.14038450487199, 39.510352457723315, 17.019640745655185, 7.1091037411843585, 8.386964874882853, 5.768684235311324], [31.840649843215946, 58.30413810668453, 65.3122212040809, 23.20110982464206, 17.695767148848503, 37.65813865969258, 17.611128284085183, 10.31907735332366, 7.5100851924188685, 27.339533951974687, 26.716359546107633, 35.767583693227465, 98.46383894643476, 64.24883919377481, 41.139199041551166, 3.7929785347753957, 0.530857195056254, 0.2695463201211345, 0.10488138984768622, 0.16526702941665727, 0.09560996396166664, 0.27710337912844074, 0.02083840742406826, 0.12094649876798354, 0.046379744345622684, 16.968216511511034, 70.09627726770216, 73.83908133352958, 73.90518896041378, 65.73937908295663, 64.98615064928609, 68.3477944712485, 70.48648249718451, 71.27827567438926, 71.8976963720014, 71.68899489987281, 68.76507189966017, 66.53989561142461, 59.31485445268693, 70.02590210207048, 72.66870098729288, 74.224485581921, 72.64287610207835, 73.30190489369055, 69.13396296962615, 69.91536186587426, 64.189956572748, 54.91779511974704, 57.256622083725475, 62.28081349403628, 63.308670597691695, 66.14704670444613, 66.52021315789992, 69.35586713975476, 67.34217720647013, 67.67003243969333, 61.143836052187034, 55.9981962942308, 57.11410276351437, 63.49723462135562, 62.61970627692438, 66.57569900635751, 67.59143598618047, 65.23118895869102, 66.16676838167253, 62.24312343905049, 65.55502376248761, 68.25596394077425, 60.60118790595763, 59.815870561907374, 67.18299173539685, 63.49268467195573, 66.32443197311895, 67.4479478405368, 62.232474204032656, 63.69915431545627, 56.26177564744027, 48.47308205020044, 52.64708011381088, 60.36004843250398, 65.08764589986494, 66.85327729871197, 63.35893184907975, 55.56038133559689, 55.48319693534605, 52.945780369543264, 59.212668864957756, 59.92610485323014, 62.19798480310748, 62.008196999949796, 60.55645327414236, 56.32790680854552, 52.746155261993415, 53.05889368057252, 54.687159753614864, 62.183891727078354, 61.28868526028049, 62.75633811950684, 58.75077447583599, 47.27162084271831, 47.03672970494917, 56.10683418089344, 53.78631684087939, 59.610330520137666, 64.11657294919415, 59.91446325855871, 61.21246968546222, 59.33731394429361, 56.546151407303356, 55.13029344620244, 62.38485828522713, 59.0620655398215, 60.812340859443914, 54.27674647300474, 58.213617647847826, 57.48249961483864, 60.312991757546705, 54.09579184747512, 55.789530123433764, 56.03811425547446, 55.62120160748882, 54.79205177676294, 54.482510089874275, 53.226822114759884, 46.55766710158318, 42.361750833449825, 42.51985373035554, 49.82964161903628, 51.69668197631837, 57.34777012178975, 56.66399117439025, 55.33694744110108, 52.36116678484025, 57.374395170519435, 51.143353216109745, 52.9902639696675, 55.46387141750705, 61.5285264292071, 55.284689703295314, 60.35623196632632, 50.80287971804219, 28.324974544586677, 28.256276192203647, 22.233843534223496, 13.782081104093983, 18.46608142698965, 8.628898628296392, 3.835302624971636, 1.2414885047943363, 0.3652884648932565, 0.15338590969481777, 0.258259791880846, 0.39530066412783443, 0.12029494098838299, 0.044017493078905734, 0.17381274021200596, 0.0688475097018865, 0.030623181167268948, 0.18168389526826723, 0.24685402971602258, 14.209517471251951, 66.73533947237077, 58.09956296797722, 33.717309813345636, 33.158701542885076, 45.06654670161586, 48.457153304930664, 7.390047917442938, 0.24738471414293015, 6.175171223378951, 5.132520410322375, 5.700984616433421, 0.9477586275146854, 0.3391966133588745, 1.0266143864681645, 0.24461475471335076, 31.40998144303599, 67.81766260823896, 82.04136140884893, 95.76734281355336, 41.111550254206506, 57.25219372780093, 27.012369055901807, 13.77205748711863, 6.899639368057252, 49.20979338307535, 40.53915485259026, 42.363017759015484, 106.4958175536125, 70.88832932133829, 51.81376864833217, 3.979493610320553, 0.5309650602359925, 0.21376652372700555, 0.05946880469339029, 0.09864360319390413, 0.052888170710854956, 0.14590320718144217, 0.24844603703146984, 0.07157406258967615, 0.05056476010189903, 19.260553583022087, 86.43504358107045, 81.54937067339498, 81.93506517717915, 74.41529320132348, 72.32852166698825, 75.66966718243015, 76.37436805232879, 75.70182277310279, 75.38239279100972, 74.25763745461741, 68.00062548729682, 67.6414462058775, 60.27014378578433, 69.1624079981158, 73.43843475464853, 76.23917964196976, 74.16685811934933, 75.30416504029306, 74.13220005650675, 75.82185514511602, 67.28271407465782, 57.10198656205208, 59.11133443155597, 63.87859490609939, 65.57057596022084, 68.30456995194959, 70.73937339167442, 72.67192517557453, 72.40080310452369, 70.76369208674278, 67.03882894208355, 58.90258589098531, 62.034116022048465, 67.41145410845357, 66.45750230358493, 67.8849861698766, 69.81196034339168, 70.11037426610147, 67.94485722818683, 65.71424061252226, 69.65395942811044, 69.33739277624315, 61.80834047255978, 63.30846663444274, 70.45831203460693, 65.57502392799624, 68.58006938811272, 69.01342853423088, 66.06411995426302, 66.47522357202345, 57.88578594884565, 52.09322967836934, 55.03822757351784, 66.20633725197085, 67.6788499278407, 70.45898668227657, 65.36511828822475, 58.34844520015102, 57.29047213831256, 55.66167654529695, 61.594226129593395, 63.58533890016618, 67.64420755447881, 62.98207836766397, 62.68193075733801, 58.795426737877634, 54.02767596706268, 55.42732277224141, 56.15852709739439, 66.04235079980666, 63.86239551728772, 63.63361543224704, 63.46916221803235, 52.12486751617924, 46.89392012934531, 59.27232811527868, 57.74407463689005, 62.35973942664362, 65.43194763122067, 62.86149294145646, 61.9183551111529, 63.25596178731611, 60.246311464617335, 59.39483550287063, 64.44827210518622, 60.79316046930129, 62.339103837167066, 58.183117297387895, 59.30837077479209, 60.1163358842173, 61.62037264916205, 57.13042374580138, 57.88946120969711, 58.494039658577215, 56.8646635547761, 58.48202936110958, 56.54160145790347, 56.9540661381137, 49.95909944657357, 48.429520207066695, 53.300366555490804, 57.5318391092362, 57.2467141766702, 60.650743130714666, 61.14251029106879, 58.04444189994567, 57.142685074960035, 57.87268915484029, 56.5202598417959, 55.51127718340967, 58.10712922003962, 62.44629829160629, 62.274635761014885, 60.81550621217298, 57.01758107831402, 32.0218986465085, 24.114047365803874, 27.554621042743808, 20.2310009156504, 22.800506391832908, 13.296802524597416, 4.058069226241881, 1.1224367253242002, 0.08015157369476172, 0.2552081419215087, 0.1315501362325684, 0.2170033984246754, 0.30261190067375865, 0.01943099282441601, 0.19383383524273673, 0.10706585125937577, 0.05472380930798189, 0.3614173613248333, 0.3453486364695334, 17.451719237912087, 74.37592044953378, 64.51234402195101, 39.486139666649606, 35.500019211922925, 51.1935007187628, 60.071722845877375, 9.22268859801754, 0.4136877242595919, 12.330514865536845, 16.563302393882505, 8.599197460759072, 1.769933013185378, 1.2193211071914243, 2.373501696894246, 1.2326819257390116, 49.62584703199325, 100.3625955889302, 143.15681519046908, 143.8682076238817, 56.61558128172352, 72.13849067687988, 43.059720916132775, 21.2812037621775, 20.565441808392926, 80.7391502011207, 48.54084491729737, 58.18976963720014, 109.99606224798389, 80.90656480481549, 59.4258536061933, 6.0793830214008215, 1.0198714031327156, 0.8326572263913771, 0.3493276665047292, 0.4040970082484907, 0.2963055874551496, 0.5517387906870534, 0.3017186421540476, 0.2765273422964158, 0.1460914043409209, 25.255439435282064, 92.4029141087686, 87.47844896008893, 90.02323565944549, 80.90985959576022, 78.31178357524257, 82.52407966121551, 82.02003155985187, 82.8203284355902, 80.9818115542012, 77.22422015282416, 73.52199692879954, 73.57817311440745, 62.67820842804448, 75.32204320353847, 75.94231113310784, 83.92216928543584, 76.09721337595295, 79.25352896413496, 76.06121386251142, 80.5732653217931, 70.0611642099196, 61.05061700267177, 61.187158630740264, 69.21112383565595, 69.94947864163306, 74.11511421203613, 72.79854712947723, 75.3468482725082, 75.62692119229224, 75.13933920091199, 68.46730909039898, 60.76652365346109, 62.79200030911354, 69.6640242299726, 68.75882748634585, 73.38072884467341, 73.55407407206874, 72.40823207363006, 70.74886552749142, 67.16032828054121, 70.50448617627545, 72.6733450735769, 66.39276750626104, 65.74256796990672, 73.22093148385325, 69.50739614425167, 72.03110402630222, 73.34029705293717, 67.86531156109226, 69.16629898932673, 61.83034889159664, 53.63183429164272, 58.29012347805885, 67.18201898759412, 70.09390815611809, 74.52417035256663, 68.58794550741874, 60.690621868256606, 61.28826948904223, 57.28962490635534, 64.57381932966172, 65.83692058440178, 72.35727264035133, 66.39972579094672, 65.47982015917378, 64.51965531995221, 56.56764599584765, 58.829245413503344, 60.60366292153636, 71.17445053592806, 67.781357149924, 67.3534579430857, 64.4486015842807, 54.03289664176203, 49.319180442440896, 62.747493174768266, 58.01643617691533, 65.51960868220176, 69.29997336479926, 65.42422840672155, 65.02431531106272, 64.55896923618933, 61.79286279985982, 61.390596282097604, 67.7014192458122, 63.34242651539465, 64.69968034375098, 60.761632457856216, 63.83473888520272, 62.51679112834316, 64.4580662635065, 61.495480460505334, 61.615548133850105, 60.792725086212165, 60.47550732089628, 62.86722352427822, 60.213151747180575, 63.24841906947475, 58.920307159423835, 56.75637083668863, 56.701849891293435, 63.6558238921627, 59.78830414433634, 65.86274546961631, 64.13347444226666, 63.27915476214502, 59.95724455002816, 65.34338051272978, 61.0808192529986, 60.43321632569837, 63.15474894738967, 67.82800982075354, 66.40928852942683, 68.64336859795355, 64.33551572984265, 47.99687100994972, 35.50478881405246, 31.985534352640954, 26.551521939616052, 27.466073536103774, 21.48875205747543, 8.500601822330106, 2.1749643116228046, 2.6248979232003613, 0.3602371262686868, 0.7407232434038193, 0.611165211566033, 1.2216704843505737, 0.1379749019660296, 0.4234136394675701, 0.2141973562538624, 0.23085094327407502, 0.6991752309183921, 0.69515498535287, 23.345245161364158, 83.7108398252918, 75.23717880249023, 48.49809892715947, 50.768606047476496, 56.89718784824495, 80.43817889305853, 11.741402322246183, 0.47224215321963836, 28.333331154238795, 38.223014877688506, 20.579307386952063, 2.3772647207783115, 0.5661741548007535, 1.0941554557892585, 0.7936575900643104], [40.866751209382095, 69.34752818076842, 32.35422538172814, 38.096687101548724, 18.26851164141009, 29.034996109624064, 17.07366158885341, 10.658087807316935, 7.980834332204635, 33.77337225021855, 27.55634688561963, 48.59855082727248, 95.28151019926995, 53.28110379557456, 40.40975586060555, 7.614010351319467, 0.6887365168621463, 0.4562634590171999, 0.1325315714723641, 0.12123640176028976, 0.12346090658778146, 0.038705155959412936, 0.06748799474969988, 0.103900506191196, 0.05996209636871373, 16.646990083879043, 50.2525790276066, 74.28511758004466, 72.26290041400541, 66.27137014942785, 65.71546046964585, 62.679695006339784, 65.90982175642445, 66.66137926040157, 69.53920656634916, 68.24155315276116, 66.82624432348436, 65.42991192110124, 57.24257999850858, 64.87745000470069, 71.40390919100854, 73.02697812357258, 70.74154638474988, 70.44481908121418, 68.81481539818549, 71.62173409615794, 68.34084403130316, 60.174555624684984, 55.487790030817834, 58.1670787257533, 57.06927399481497, 62.28592826474098, 69.23119852619787, 67.518676019484, 68.41272538708103, 65.17550306935465, 55.04921021000032, 56.55207026389338, 63.30111611273981, 64.94115321866929, 64.99970243823144, 63.11466624659877, 68.56481136814241, 63.03967052890409, 67.57803716967183, 68.16766354345506, 69.52223839298372, 58.607070599832845, 59.668840515998106, 65.32936980647426, 66.42107132942446, 64.10366442895705, 64.20498317287814, 63.55153983639133, 68.60814571380615, 54.99377927472515, 53.30468508505052, 47.90967279864896, 59.34364464975173, 63.94227850821711, 64.01763116159748, 64.49721151782622, 56.30530218924246, 52.07202142284763, 51.5326209991209, 52.898535420817716, 57.55091359538417, 57.513203928547526, 58.98450459203413, 58.90193869990688, 58.98619905594857, 56.01327780754336, 50.408850177641845, 48.331323669802764, 51.39639708303636, 59.461711914308616, 63.230176125803304, 59.419515055994836, 61.28116999903033, 54.40221917244696, 46.8387794494629, 50.31854152679444, 57.150812225957075, 56.33905418457524, 55.56223269431822, 64.07599995213171, 58.927406649435724, 59.672853100684385, 62.06528709780786, 57.11404000559161, 57.01493740081788, 58.7837851432062, 58.47705971810126, 59.48855661576795, 57.75856779467676, 56.692345988365915, 56.278786966877604, 53.516583288869555, 56.209043302843654, 56.11190580552625, 55.05440735047864, 53.093037912922526, 52.37860172025619, 47.826483249664314, 42.965101580466, 43.757879272584, 48.24927160816808, 54.4912334411375, 55.856367311170025, 53.165115387209006, 54.37892029362341, 53.50936612775249, 54.09807858928558, 58.28369471334643, 56.0073354167323, 56.4584001418083, 55.9035808809342, 58.447273239012695, 59.75785086231848, 63.579016039448405, 30.95334302994513, 31.92203510192133, 32.271710480413134, 14.774562351165281, 2.5191606292801523, 20.973519317565426, 18.78547022419591, 4.617538211807128, 1.168058670816883, 0.6256625981580827, 0.12887803687443658, 0.08800368380522536, 0.3274357541193885, 0.16677312763227573, 0.05859718815754018, 0.08764454178632268, 0.04283957543873018, 0.06582752215645968, 0.0894545317597447, 0.14270675128265736, 18.773748220935946, 63.53195544212096, 60.587702797305205, 35.546891535482104, 43.38055118437737, 48.60361460716494, 33.73970654702956, 6.510705967103282, 0.12156481599254955, 10.898065278607032, 6.219287591595804, 1.8402120807478506, 0.4183775919579691, 0.3598616206117215, 0.4397868383074961, 3.427302092313767, 48.964809986852835, 65.98162466479887, 94.43205818053215, 81.36789045026227, 32.482947764858125, 50.44564593222834, 22.139430122990763, 13.654266749658893, 7.2557116420038295, 57.64566236926664, 37.6094542011138, 58.33694873317596, 109.8764221129879, 60.82610837874874, 52.066514415125695, 8.01052765500161, 0.2935206433457713, 0.28521667925580857, 0.1311227204578538, 0.11401660530076874, 0.009555374459934332, 0.05299958670812269, 0.08750449325288497, 0.052873247318089976, 0.04580815465399816, 22.64267021609891, 68.70807201631608, 83.4582156519736, 79.92087318051247, 73.8999878975653, 74.22117510149556, 71.08144329440209, 73.68753663955196, 75.28504740807318, 72.75306332495906, 71.98039562471452, 69.20076877840104, 68.62006187438965, 57.232091580667806, 66.28234494117, 73.63416102624709, 73.7342442235639, 72.55014342646446, 72.87834382826283, 73.1298775826731, 73.66900736285795, 71.90131279730028, 63.434590447333555, 58.66087767385668, 59.63440210588517, 60.68422056013539, 64.9140888644803, 70.34638327936973, 72.08115346970098, 70.72691594400715, 68.39489429227768, 58.49319242662, 61.54991511375674, 68.47731897907873, 68.75437951857045, 70.31262736166678, 66.91054390322778, 70.24579017393052, 64.86614965623426, 71.16530356868621, 68.99503261812272, 69.73594480945219, 63.26090005136306, 64.51765491116431, 68.83235623759609, 68.32574290613975, 65.7769161655057, 66.06351590925648, 67.1038696842809, 68.0579391602547, 55.502816630947976, 56.77939514960013, 50.55424459518925, 63.670077785368896, 67.29921940834292, 65.92451495508995, 65.88300058918615, 58.0021862060793, 55.31204431287704, 53.704453053012976, 54.141224661181056, 58.350555435303725, 60.28093814849854, 62.249089364082586, 61.195713320086085, 60.890207752104736, 59.12156397296537, 52.47568822676136, 50.244491100311286, 51.77367810280093, 61.8719966180863, 65.34468666199716, 63.04158464554818, 63.34725887544694, 57.583198624272505, 51.903100629006666, 52.25479995050738, 58.34100838630431, 58.78530702283306, 56.15864476849956, 66.07720498115786, 60.86462997621106, 62.34858028350338, 63.550261143715154, 60.11348039873185, 57.86957871529364, 61.51446865450952, 62.74563397130659, 62.24783420562745, 60.92183774517429, 61.37174144867928, 59.6712645407646, 58.94373939883325, 58.36483286273096, 57.98762244562949, 56.92984550229965, 57.458686905522505, 55.57650619937528, 50.73503055880147, 48.3017921447754, 51.689166715068204, 55.99040646706858, 58.56120240303778, 60.60231362619708, 57.23445676988172, 55.752734368847264, 56.33834031320388, 56.99270540668119, 61.5558575045678, 60.15404162868377, 59.43445144161102, 60.5013322061108, 61.60206302519768, 62.725116052935206, 64.3619603495444, 37.213961616639175, 33.02006144677439, 36.17206242776687, 21.276118409249094, 10.55184550823704, 24.559538402865012, 21.227280978233587, 5.918758040474308, 0.46490897574732387, 1.463571755636123, 0.08307016950341002, 0.09316792846807549, 0.47863552466996256, 0.2483837694049843, 0.08712641354049407, 0.14308331414095818, 0.04315676648289927, 0.07761257445259441, 0.20853938324557197, 0.1308389921342173, 23.421060654424853, 72.54276152580016, 66.48588457415181, 42.4596728048017, 44.59716058546498, 53.376793938298384, 44.63952218332599, 8.491275406652882, 0.15669150247929559, 15.265855885321095, 16.006262090898332, 6.744909219203457, 0.5052917378564035, 0.0914457091881383, 0.1908593916244084, 1.4900229943375436, 70.40644261144823, 99.5055498615388, 157.3676407721735, 105.62037591011294, 39.03196450202696, 58.26793462999406, 45.58783361988683, 21.041666576939246, 35.96192536815521, 84.93887116832119, 45.73958619948357, 67.53083536701818, 111.37468907140918, 71.17468587813839, 61.53909721682149, 9.87771559146143, 0.8608874438270446, 1.0065799615075512, 0.22431933891869363, 0.7496279430004859, 0.2039261856266568, 0.16817603380449359, 0.20005836091454954, 0.1473863380810907, 0.086956127516685, 24.624192791600382, 77.42045633254513, 88.89807239655526, 80.3373190664476, 79.81048983912315, 77.88802639130624, 76.72281572895666, 76.61196170314666, 79.27897730181294, 79.17752127493583, 79.21316777506183, 73.3246938643917, 72.4561163686937, 60.873631815756525, 71.31467526958835, 79.15841933219664, 79.22236181074574, 76.0898785437307, 77.77256750291394, 75.43135966024091, 78.2391648138723, 73.44543226303594, 65.73051844873737, 61.272179926595385, 63.28471668304936, 63.00272572425104, 67.64600400001773, 73.76836099932271, 73.1621116207492, 73.52350311894571, 72.24215107579386, 58.878930076476074, 64.0501436879558, 69.79275641902801, 70.05226042962843, 71.75246669400123, 70.07231158594932, 73.92353780807989, 71.96525527584937, 74.14249235583891, 73.1426723541752, 74.06932446264452, 65.40394190819033, 65.89435192846483, 70.7884971557125, 69.51965747341033, 69.74038493248725, 70.76552775598341, 69.10630241517099, 74.73877106943439, 61.17513656616212, 61.541595766621256, 52.15863912336288, 64.39263328429192, 70.52274088705741, 69.77707478307909, 70.26200525222286, 61.78647718121929, 58.14828272788756, 57.801043141272764, 56.61893883059102, 61.693065935565585, 61.20677048160184, 64.54379358599263, 63.91744990502635, 64.11209752482753, 62.730038627501465, 56.52020885098366, 53.1891595163653, 53.7792016613868, 66.36029028123426, 68.39685547736384, 65.36129005493657, 66.36622090493479, 60.425289215580115, 51.76611969547888, 54.18401771976102, 61.195999653108665, 61.315784915801025, 61.21094780583536, 70.5543787248673, 63.30594847279211, 64.4858641009177, 65.54492365929389, 64.40118797363775, 60.078496779164965, 62.47573175737935, 65.37161765560028, 64.41921910931988, 63.593293466875636, 63.962317897427475, 62.846823277012, 61.89098481209048, 60.27231285648962, 63.87151110556818, 61.027169073781664, 59.759961097471184, 60.1302916772904, 61.669064952481186, 54.80146154280632, 57.19214616283294, 58.87925563320037, 63.19650257787397, 65.57780881081858, 62.99361798071093, 61.35474581872264, 62.28082918351697, 63.19341959491853, 67.59818246287685, 64.43838380998181, 65.57906004690355, 65.57683606301585, 68.06952584174373, 66.76096039433634, 72.03125307636877, 46.58267221143169, 45.506224786081624, 44.093041881438225, 24.885716822839555, 15.748718284791517, 29.928062923492927, 32.94089624958654, 16.394156063756636, 4.937231482998018, 3.6762164388933494, 0.2766254934812746, 0.5717219184002569, 0.9714546463181897, 0.4307940385995373, 0.16298779526785498, 0.2271028581045328, 0.16224957762225983, 0.22627012053083992, 0.40202814184369584, 0.3959251790037079, 29.442049880181592, 82.7710085530435, 76.27105282198998, 51.78220141318537, 65.27431934110581, 62.456716106783965, 60.45609158854331, 9.487219125993791, 0.2991481720199508, 30.198798641081783, 39.06708932692005, 12.350485613269191, 1.882881216945187, 0.5494081060732565, 0.535032925826888, 4.471173988234613], [51.78863410026797, 65.03798477111324, 14.600682700833968, 41.57136578713694, 20.329211181209935, 18.16628682997919, 6.690602533278927, 5.353135101256832, 13.456069384851764, 28.36632024857306, 30.42216781646975, 39.05787175701511, 84.34325141291465, 52.48293284446963, 39.49975029114754, 14.948385127129095, 0.59325989816458, 0.455858719445044, 0.11200144165946592, 0.08880495814786804, 0.135201970115304, 0.10799662510473883, 0.04002603709757809, 0.259547034098256, 0.011825613778895669, 10.083414489223111, 50.33060281507431, 71.84321465030794, 72.2710354097428, 67.7990548841415, 66.46141682901691, 60.807955649591264, 63.063479315850046, 61.90449737733411, 66.13029033906999, 65.4560858972611, 68.59124814310383, 64.76114388435118, 62.91320939217845, 60.881103930934785, 67.57054544264271, 71.50211749538299, 69.95629572099256, 70.40728984340545, 68.00694050327425, 72.42638480278754, 65.78945206057641, 63.98049416080598, 53.7921101816239, 54.8417599739567, 55.84764003753663, 63.34495644415579, 68.6818862730457, 69.41700120126048, 69.67587763263334, 64.93872134916245, 56.904695264754764, 60.30782991839994, 60.852270587798095, 60.16907607355426, 67.36200086532101, 66.24467449803507, 65.71518590373378, 65.0306381717805, 67.06480287736463, 67.97087038716963, 60.957550925593225, 57.53968384958083, 64.05530160473239, 66.83258287368282, 64.44980575192359, 63.93430040728662, 66.71845759114912, 66.01602385121008, 56.0929411457431, 53.57488932148103, 54.99359884569722, 52.92933387141074, 60.56524330569852, 59.92621467959497, 62.081894413117446, 60.33784781732867, 50.60909109730875, 47.93306581435665, 49.0749462189213, 48.40310696632632, 54.063730393686605, 57.252221184392134, 58.45174081863896, 58.8040598746269, 58.59399734004852, 50.15750469699983, 45.41548467451527, 46.99359540016421, 47.276217860560266, 53.30501064177483, 58.715253491555494, 59.34303668237502, 62.60010227080315, 59.65785003477528, 50.719917666527536, 52.747265292752175, 48.83710545878257, 59.198340446718284, 55.92287501981182, 57.43503893575361, 61.867285851509344, 57.83528151050691, 58.373697419320386, 56.93235581920993, 53.00520427765385, 57.64604676154352, 58.70165855653825, 58.4350589782961, 60.56896955736222, 54.0678684942184, 55.088986965917776, 52.19773338687036, 57.213350495984486, 53.2230370275436, 55.790279296136674, 49.948116810091086, 48.381851642362534, 46.33741424929711, 42.03951243431338, 49.085897476442405, 53.51327280844412, 54.7155341794414, 51.547753503245694, 52.63301449437296, 51.84002107189548, 52.51219764832528, 52.635854290377715, 61.211940165488954, 58.594785736453154, 57.686776653412856, 61.878586199975786, 61.41102006358486, 60.40821121584985, 40.43125829389019, 30.93299573467624, 39.06048405554987, 22.137500316865985, 7.241830373964003, 8.871712953813615, 23.70935682327517, 28.701992765549694, 18.770498537248184, 7.972225710268944, 1.561444329638635, 0.7544607320620168, 0.11271473080400499, 0.16703030334845667, 0.13556923266620408, 0.10107563357920417, 0.08923451130789134, 0.059937370880957574, 0.054450446153960885, 0.4575352569020564, 0.2443262613228252, 23.66469475530809, 57.46973622229792, 67.33590925893476, 36.78508181725779, 43.487576976899184, 53.80645428934405, 37.612709768356815, 5.214320459673482, 0.2002767572600034, 12.536140218857797, 3.510215114201269, 2.6634116759223323, 1.4267492799028274, 0.06189328911263616, 0.2802138186750874, 6.194809059942923, 57.39429727677376, 70.52980115336757, 82.2048693318521, 61.22328366002729, 31.268499589735466, 36.24082942162791, 23.03943757087954, 13.274716638749647, 18.579839967912246, 49.485908631355535, 36.97493630070841, 49.54127680870795, 99.65182289000481, 58.46352754100677, 53.847525427418375, 18.29414629167126, 0.726985632171554, 0.44639863674679114, 0.07663322297195274, 0.07690239562502793, 0.17948355285390732, 0.12341481873825674, 0.015169334759364928, 0.02512118557558185, 0.026845450310276884, 15.64215042898732, 65.6497529245192, 81.82999272500315, 82.16413943998276, 72.01812098103186, 74.92498951573526, 67.21515517080984, 71.97745384708529, 70.56375318957915, 71.43089509779408, 69.17278658959174, 72.07106513361778, 67.24964064936485, 63.398277144278254, 62.58745262699743, 66.92915162732525, 73.55012032293504, 71.47186033187374, 72.51667776415425, 71.49612411375969, 75.48886160696708, 68.21223735809326, 67.97010160261586, 57.69902229309083, 58.11487197875977, 58.08287720526419, 65.1215704794853, 68.58044593564927, 69.30478219063052, 72.17637292800411, 65.6546401977539, 59.3662335795741, 65.29341736147481, 60.039257387961115, 63.19136427294824, 69.457166271825, 68.93702860801451, 66.84657789045765, 66.84511876875355, 68.02538348782447, 69.61083689043599, 64.79249538913851, 63.847667017290675, 67.80682902182302, 71.73670661064887, 65.29951272472259, 66.86943746382191, 68.98070812225342, 65.56955222160586, 55.701402310402166, 57.52891694345782, 55.53635681829145, 56.12710498994397, 63.71090181412236, 61.714740953137806, 63.70717948482883, 62.429651752594985, 52.708645636035556, 47.55138781762893, 50.24432243839387, 50.120395152799546, 53.85808837029242, 59.068764948075824, 59.90157435017248, 61.75158769853654, 59.75952963675223, 55.16620666750016, 45.38214452805058, 51.02217158963604, 47.24750218852874, 56.21345989165768, 60.93880591853973, 63.781990851125414, 62.29612250481883, 60.82781853214387, 51.87878585630848, 56.09223511911208, 51.269594700105735, 60.48325792435677, 59.75239484540878, 59.62694960255777, 62.48578871450117, 61.66296174449306, 60.81930698886995, 60.87098421589021, 54.03304961419875, 58.82283233827161, 61.337452088632894, 61.992201574387096, 62.9596463326485, 59.15732422182637, 58.87134029019264, 55.93569724790512, 58.341804627449285, 57.72352926192745, 58.07378515120476, 53.61427776275143, 52.341864801222286, 50.3637586101409, 49.81235181131671, 56.32445512279388, 58.95561633571502, 58.59369923991542, 54.252902384727236, 54.239319216820505, 55.78104603675104, 56.93761179524084, 57.503005766099506, 61.87577386056224, 63.07019049121488, 59.36354283363589, 63.43630452309886, 62.211046295781294, 62.57236326894453, 42.87157266370712, 30.898839735215713, 46.41348077404884, 30.59589155258671, 10.896995452142532, 13.872628038929356, 28.778137737704863, 33.55050709939773, 17.562306542550367, 5.265248513990834, 0.3187609728305571, 0.5159298186340641, 0.12138885325722157, 0.15311007207680136, 0.17984257229874212, 0.05305072307706841, 0.059696011049973394, 0.12010996905906547, 0.15416997004180186, 0.321175835185474, 0.2753954320665329, 29.15287902278285, 66.14368915557861, 74.97109305474066, 42.39015271586757, 54.056830944553504, 60.79405476970058, 50.046160374918294, 6.3618936942469695, 0.18708801738196806, 22.17833415154488, 17.720329030867546, 7.3828675285462415, 3.4913220376737657, 0.14338149088284663, 0.09079690932506516, 6.065185512265852, 81.73169028374457, 106.87103932903659, 152.16805273486725, 79.09377867175688, 40.6148369850651, 37.71731545848232, 36.01360259517547, 11.740307980968106, 49.25766198865829, 73.47035500311083, 51.26191862167851, 54.42161921531924, 98.13762326394358, 65.50621771043348, 64.64544965374854, 22.2701136912069, 1.0659923476557578, 0.9215591559487005, 0.32612494703742767, 0.27562957917971, 0.23150305263698104, 0.31237379137066107, 0.07572060541039513, 0.4207760600313064, 0.08013976061896932, 20.169221624251335, 71.11075908906999, 83.358979686614, 83.08180932075747, 76.4914115782707, 78.86057807553199, 72.1445389716856, 76.53171000942108, 76.62849841579315, 76.03035265399565, 74.28376828470539, 77.50310851681617, 71.07708946351083, 67.5454265840592, 65.71114978482647, 72.29566789442494, 77.34008696771438, 76.4214051154352, 76.67951276225429, 74.60031924709197, 79.9340444995511, 71.75136058561264, 70.94662358683925, 59.06665079055294, 60.31572172718664, 62.10401265851913, 68.9239671153407, 73.34645517410772, 73.97069254229146, 75.89432485641973, 68.0113257131269, 60.66984899582402, 66.89424253279164, 63.06444814128261, 67.42865762402936, 71.24787730555381, 72.59959666959702, 72.96301211080244, 69.25436404443556, 73.33864181272446, 73.3611483727732, 68.98211233077511, 65.08440602210261, 70.70028305053711, 75.14971779238793, 68.55924944723807, 69.90371242646249, 71.63525842851209, 72.71051345332977, 60.40308860040481, 59.51600928460399, 59.017044574983665, 59.32835132844987, 65.41009218462052, 67.26613029356926, 66.42902589613392, 65.26224236334524, 54.54569555098011, 51.13315113129155, 51.555555097518436, 53.152316693336736, 57.03011305101457, 60.546164897180375, 64.33579814049506, 64.97809802332233, 63.10539768588159, 56.95017906927294, 50.21162948300762, 54.195000356243504, 51.163427906651656, 58.78426759473739, 64.4910651637662, 69.07075789666945, 66.592008221534, 65.587583357288, 54.58500162247689, 57.849425577348285, 52.65552889916205, 66.47951464499197, 59.53570742760936, 64.49681535843881, 65.27407615415513, 62.187190440393266, 63.747293564581106, 64.72654465706118, 57.46091873415055, 62.19876927714195, 63.619412529853086, 66.93677671494024, 66.78789138793945, 60.799075403521144, 63.68111141266362, 59.77164976058468, 62.86432881509105, 60.54760832940379, 62.638368914204264, 57.1512907551181, 58.724537741753366, 58.93106229843632, 53.4671143562563, 63.055599274173865, 62.205088215489546, 64.65838170820668, 59.26353023898218, 59.6608781045483, 59.50194366516606, 60.431619921038234, 62.07793674161358, 69.09392341490715, 67.06947834261003, 64.36904022770544, 68.24642473651518, 71.27531036253899, 66.20971833505939, 52.17790188327913, 39.522170559052505, 54.48746404340191, 37.629768156236224, 16.257892923970378, 32.8907173679721, 38.609082006639056, 47.279226318482436, 34.32192356355729, 14.754817139717842, 7.03215076077369, 0.8608671578188097, 0.15237240601451169, 0.2103510739341859, 0.21547751981885205, 0.15109276338931055, 0.14736608271637272, 0.17394446136970676, 0.2803222967251655, 0.7071079181567316, 0.2715890476059529, 36.51727807137274, 77.12626288014074, 83.98025174294749, 52.33225499430011, 61.99637889862061, 68.9375542056176, 66.31661076699534, 7.923354939106972, 0.4912102757202041, 34.94876146316528, 48.11561292217624, 15.118745430823296, 3.9308689678868944, 0.2751233789228624, 0.6357649689720524, 10.804597158585826], [63.315856379847375, 36.98046684265137, 36.53045723515172, 25.975978835936516, 22.6697051525116, 14.856349652813329, 2.799472813644717, 2.557651092929225, 18.003910510770737, 25.210022311056814, 23.9456953156379, 27.575807725229573, 70.06752629433909, 46.75698234188942, 34.9590459177571, 20.478996692165254, 0.41110796913985287, 0.2595706602498408, 0.13627887523222354, 0.0762072780860528, 0.10858657409346874, 0.03821022868637116, 0.1217891648411751, 0.044079641961762984, 0.14005423313187015, 3.0895757242556545, 30.934176368098107, 65.41525794613746, 71.70701426844444, 69.88953698065974, 65.2221949638859, 62.767779673299486, 60.535056744852376, 60.464532529154134, 62.46834593434488, 62.26929741521036, 65.62427713025001, 65.92140843791347, 68.16625149019303, 62.71745566398867, 60.51884166656002, 68.18517300390428, 70.24069893744685, 69.75081059240526, 69.67239456792032, 68.66395319661787, 67.47226653560516, 67.2517587292579, 58.2797880326548, 53.61790203279065, 56.75802999927152, 60.16638140524588, 65.97269735028668, 67.49927597661173, 70.65635250460717, 68.98315568124094, 63.88112483486053, 64.16460237195416, 60.606173238446644, 59.88829320476901, 60.61783836733911, 64.65846800035047, 64.354735343687, 65.32467865174817, 63.550221920013435, 60.6979763123297, 61.24955961781164, 62.94746345089328, 63.8545782335343, 63.25297686361498, 63.22437494031845, 65.82734215644099, 59.54564279125583, 58.350449531309074, 61.370235258533114, 56.54906180597121, 49.10367758043351, 54.53170445657546, 59.54237545690229, 60.90239455623012, 62.012240963597456, 56.56373931515602, 48.27354715716455, 41.805370469247144, 42.115280858932, 46.18408879926128, 45.64244477979599, 50.87837749911893, 52.294768902563284, 51.696274049820445, 50.881978234937115, 48.56716009878343, 43.30199395456622, 41.121250275642645, 43.05652026207217, 47.35579098424604, 58.56391668319703, 59.47769165039063, 55.81020101424187, 59.201207699314246, 48.47803600372807, 50.23474008806291, 59.426143861586056, 54.68474357358871, 59.60561975356072, 57.74826372823408, 57.03695758696526, 60.34630444742019, 54.6469436922381, 59.32287177731914, 58.16756117728449, 54.67969156080677, 58.80737427742251, 60.530134170286125, 60.26271873904813, 55.52505254745484, 56.194028469824026, 51.86649314818844, 55.65782085541756, 54.7614965131206, 51.895185285998934, 49.52620706250591, 47.29119739224834, 41.06015936020882, 45.85924594633041, 54.75640135426676, 53.37661743164063, 51.51155394892539, 48.977702817609234, 50.18545942921793, 52.403434245817124, 52.5221408567121, 54.215855598449714, 65.6371581938959, 61.741895521840746, 60.657426849488296, 58.88419389724732, 52.70721789329283, 46.08328780820293, 43.87848431064237, 46.904290876080914, 39.583198716563565, 18.275487576761556, 10.919414739454947, 22.50068629941633, 39.885613456849136, 38.971748275141564, 26.53509505333439, 19.781358049761867, 10.402950375310837, 4.108845533863191, 0.08820803775902718, 0.03798275802945418, 0.0349217732887595, 0.013693861866129503, 0.05007694212479457, 0.13645757290144123, 0.08485461810543653, 0.18086001367097904, 0.12355425440135503, 27.427083215405865, 60.92434021734423, 65.39501459367814, 40.60281884285712, 30.26293919932458, 35.17356426485124, 64.09503129220778, 3.3774850493477238, 0.3110710741771806, 13.551300610265425, 5.2505592376955095, 4.586727503807315, 2.701933273384648, 0.18652639832467804, 0.44425760485952903, 11.001584472194796, 68.78334229992282, 71.07809359027495, 66.27212324450093, 39.971262331931825, 30.821869104139267, 26.86441136944679, 14.292305957886482, 6.725455243741313, 22.313952061437792, 45.04229076447026, 33.491322455867646, 37.86721667935772, 73.76774910957583, 54.286976014414144, 45.7520632590017, 29.315916261365338, 0.45826631928643874, 0.25636536369640983, 0.1903722822786339, 0.08756466945933719, 0.02861834056074581, 0.1680398233715565, 0.18966213409458438, 0.12738297798580703, 0.31763463972076295, 3.7506492964683043, 43.436229228973396, 82.65345511897918, 78.86049962812855, 74.63205906652635, 71.94655341486778, 68.84128355210828, 67.56699177526659, 68.51063559132238, 69.84379429971018, 66.01778107304727, 67.72005050413071, 66.35449301811957, 66.11434198194935, 63.704488738890625, 57.41616449048443, 70.39696616511192, 71.74568099360313, 73.88105069437336, 73.207564046306, 72.6330780213879, 71.22460196095129, 73.03974936085363, 63.49620696037047, 56.95905539297289, 59.23858004231607, 62.00086609009774, 67.74269042476531, 68.76213012203094, 72.55905505149596, 69.22127492966192, 68.19708131974744, 68.5105336096979, 66.66501137518114, 64.55116764191659, 63.591920637315326, 68.05265180526241, 68.27775662945163, 67.5234926900556, 65.98183647278817, 62.52299631795576, 64.75385612057102, 65.64831733703613, 68.215053619877, 66.50282136855587, 66.37573657497283, 66.48990892594861, 63.601267645435954, 63.6627233412958, 63.87065995124079, 57.06684997004848, 52.317071499363074, 58.481613589871316, 63.8424071188896, 63.14938706736412, 65.5628018225393, 57.23404099864345, 52.138325168240456, 43.79988001238915, 43.439245531635905, 47.90218499399001, 45.67731465062788, 52.21178331682759, 54.88718102055212, 54.41288409694549, 52.437978559924716, 51.1597094997283, 45.975959993177845, 43.54307067009711, 45.27632290317167, 46.93599931655392, 61.80125667202858, 62.3244773187945, 56.68078284109793, 61.34736391805834, 53.87649997588127, 51.68863719509494, 63.658173391895915, 58.886100169151064, 58.901997535459465, 62.28836797898816, 58.39568230413622, 61.94575286680653, 56.135443948930316, 61.91893954430858, 59.83751812288838, 58.21061311229583, 61.82515959585867, 62.55306520769673, 60.31363894862514, 59.14920099319951, 58.850889052114184, 56.18015112415437, 56.69381687718054, 56.7834508803583, 55.0758078021388, 53.999529038706136, 51.659356701758604, 49.542386839466715, 50.75055922231367, 59.15905398707236, 58.26808760243078, 53.67390955648115, 53.35888831846176, 53.62332667073896, 55.96151036600913, 57.86545630424254, 58.77585803308795, 65.26822005548786, 63.178079205174605, 62.29621664170296, 61.1236789918715, 52.13503429966589, 45.73628356379848, 44.03433968943935, 48.37620735168458, 47.76854591984903, 25.443962274059174, 13.044488218522842, 32.874863147735596, 43.90267356749504, 48.42612735686764, 32.955871858904445, 17.369535776876635, 8.836126269832734, 2.530468087042532, 0.08572655639821485, 0.03373180508553501, 0.08676625262465208, 0.004690949797570225, 0.02229347269261076, 0.11283193459554065, 0.2506119054892371, 0.03217483480130473, 0.1242006793918629, 32.74021994683051, 68.97975106393137, 73.136977072685, 47.870911936606134, 37.86906411570888, 46.77085184281873, 73.91319059556531, 4.830984280955407, 0.16926464474489614, 17.343548113299956, 17.85367588843069, 12.685146158741368, 7.6667284773242095, 0.0568914933941297, 0.48000286904073536, 10.616198855061686, 94.06939583439981, 107.45666488524407, 116.78241375953921, 51.36946216706307, 48.14385398741692, 32.76089672119387, 24.073509670072987, 6.1221589196112856, 56.41992169041788, 64.70909010979437, 43.94544701422415, 41.322295281194876, 81.3679688976657, 62.57945491421608, 59.18604381622807, 38.4568783544725, 0.6970847914776495, 0.42809814455047734, 0.24511815108839544, 0.1941401018731056, 0.31958488507136223, 0.27647212267883364, 0.20870809112825703, 0.3221912387638323, 0.4548908439615081, 7.774737313870461, 55.29100864164291, 77.49095701402234, 79.72229142342844, 78.08731417502128, 76.55093746800577, 72.49485369651549, 73.50382851016137, 72.04743677569975, 76.03066644360943, 69.87207458865258, 74.171494360893, 69.64725217511578, 72.45002100544592, 68.7931090016519, 64.26843143278553, 74.44386374565863, 75.538801224001, 77.45032125903715, 76.37898075965144, 76.38193822676136, 73.51881980895996, 77.29768614615165, 63.80246954579508, 60.869795737728, 63.93757950875067, 67.96364538131222, 72.0114843307003, 74.12830122055547, 77.0845994641704, 74.98949681558918, 67.50526935823503, 71.24397846960252, 68.6693033095329, 67.90389983884751, 68.43937397003174, 71.33150223762759, 71.05390825579244, 73.39592410672095, 69.20234557121032, 68.7368465239002, 66.11766815185547, 69.47652709099555, 69.44311634186776, 69.8944164091541, 66.99905610853627, 71.74690477309689, 66.21073815130418, 63.499184039331254, 66.84576203746181, 63.50469889179353, 53.363136245358376, 60.07408411272111, 65.04509210586548, 67.03960557137766, 67.63123235394879, 60.65570492898265, 55.7166995540742, 46.17560471257856, 45.2425120722863, 50.061186975048436, 48.34978234383368, 53.46930696118263, 55.69135712039087, 56.63845654456847, 54.84711008687174, 53.8778414264802, 46.55736507907991, 46.56536279186126, 46.74220285108013, 50.34871239815989, 62.24810092679916, 65.75237781770768, 62.73134477676884, 66.16017879978304, 53.98834636134487, 55.72692517311343, 64.31987331759545, 61.481234412039484, 62.38750588509345, 61.748991089482466, 61.375793257067286, 65.80814607681768, 56.98344469070435, 65.74790631571125, 64.24043355449554, 61.163287085871545, 63.933990540043006, 64.7969590463946, 64.8520605025753, 62.75463188848188, 63.9472246170044, 60.42196696804416, 59.821291277485514, 61.59356324903427, 60.92220644797049, 59.01683668936453, 58.47432974846133, 54.462098075497536, 56.204850289129446, 63.225108423540675, 62.78501456783664, 59.165623957110995, 58.789468657585886, 58.11586041604319, 59.537037111097774, 64.33227192971015, 65.61653829390004, 71.07524594952984, 70.22060855742424, 68.93740515555106, 68.69288459900888, 57.689761577113984, 52.282342833857385, 52.47710028002339, 57.824342020096324, 62.616050627923784, 44.40989486632809, 45.46219618089738, 45.91133894458894, 54.089578813122166, 54.95906237632998, 42.80746152324062, 36.141958236694336, 17.630979399527273, 6.234579932305121, 0.1512216500216915, 0.16238928141613163, 0.31560689691574345, 0.06606399817692657, 0.11294337740588574, 0.344057533168985, 0.31312878634179797, 0.3756717448273013, 0.3085459564482012, 39.30166275270524, 81.74799949892106, 80.23680440841183, 60.17332792282105, 46.02983374749461, 51.652296435448434, 85.08797614805161, 6.15559418355265, 0.5859803468469651, 23.652639350583478, 45.65493360642464, 20.823204286636848, 10.494519087576098, 0.23528306835120727, 0.5803776087780154, 17.430301135586156], [68.60320352738904, 29.528747989285378, 38.85302205239573, 9.600838422775269, 18.410444567280432, 11.441675386121197, 4.887771375717656, 5.054328451233526, 21.635313380149103, 27.736495464078843, 18.634631556849328, 22.85457822584337, 66.75642613441714, 44.892526826550885, 28.588479372762865, 24.84138031159678, 0.137508139915524, 0.07266624349980585, 0.04339608085912563, 0.02453997765006798, 0.08327544276272097, 0.007397062023125229, 0.04135652880875334, 0.06894404444122507, 0.27793991649823807, 0.5217170919622145, 7.51976756318923, 51.000873119600364, 78.56100313125118, 69.69965504061791, 72.65190539821502, 62.1568234505192, 60.43759369081067, 58.05924100260581, 58.274057449833045, 60.4653170031886, 64.11996972176337, 69.18402025776525, 70.71914965106596, 68.73494809673679, 60.15408477475567, 58.65738676440332, 71.91119717013451, 70.523846995446, 69.75339935671899, 72.62065979742235, 67.2930455976917, 67.16009293833088, 62.80561877835182, 54.51913718254336, 51.70584071067072, 54.95575974064489, 61.88548957147906, 69.37397280047017, 68.13141299832252, 67.80384802049207, 67.28990770155384, 65.97716885228311, 63.82902791423183, 63.62235038511215, 61.59056655822262, 60.071012896876184, 63.8563629119627, 63.13728263301235, 62.59728208664925, 64.57753773658507, 62.30606571320565, 62.30031944090321, 65.6682861235834, 65.27573923910818, 63.20101722594231, 60.017095996487534, 64.91260228618499, 63.27824477226504, 53.76881914754068, 57.76897384274391, 50.94013521748205, 56.991038399357954, 61.82384952422112, 57.65782563917099, 61.79126639519969, 49.48197841644288, 45.54593486170615, 43.424787675180745, 45.25925667055192, 43.36321430821573, 44.19283482336229, 46.15065059354229, 45.80222645113545, 45.40033255853961, 44.31545988205941, 43.52403148528069, 45.39981480567686, 40.15297397490471, 41.37356065934704, 44.391302831711315, 52.40948254062284, 60.31221120588241, 59.03991199308827, 57.43261491098712, 55.18689324778896, 48.65366012819352, 56.14176288727791, 60.92122193305724, 51.590444580201186, 62.08775835652506, 58.84777861256754, 57.50961103746968, 59.835196079746375, 53.4320915129877, 58.777881976096864, 55.12357050372709, 55.768078680961366, 57.644724922795454, 58.729903544149096, 55.312362024861, 52.001544275591456, 50.298600196838386, 52.17700366050967, 52.074484671315844, 49.112357785624845, 46.3857300050797, 40.095397503145286, 44.632395236722886, 53.5864838477104, 54.12479777489939, 51.77802408895185, 49.147549290810865, 47.119829039419855, 48.60098661914949, 52.96208173997941, 55.45121785133116, 56.051242428441206, 61.6092997981656, 63.19179965603737, 54.87499029405656, 57.57791126928022, 62.00861277118806, 59.82515088973507, 56.560915208631954, 58.13448382962135, 53.919583289853996, 50.619724642845895, 36.87890491177959, 41.72902153384301, 51.95251072606733, 39.34754271661082, 35.9680756445854, 27.559533811384632, 21.71180352087944, 6.798006834522371, 0.5272558463677284, 0.020556427696118915, 0.18153464601885888, 0.03138410757415958, 0.08713518524722708, 0.12438405019741867, 0.3219684910389685, 0.09538595219172778, 0.035681690374809893, 37.00342055289976, 62.93289969044348, 65.74004980825609, 40.704086595965975, 35.898888957115915, 40.071243547624164, 75.90589584842806, 2.737352276040662, 0.1768144565604387, 11.884369773249473, 7.911281393420312, 8.470551563847451, 6.850491579501861, 0.22471617246347092, 0.6730340433216865, 20.66807846869192, 82.18219018751576, 76.44649259505734, 62.66215808929936, 20.633394910443215, 30.47710845547338, 20.713889791119485, 4.862279401671502, 7.565235187930446, 21.306812917032552, 43.360037188376154, 28.677381853903498, 28.10165636001095, 87.38108004293134, 50.8620604392021, 42.10911097065095, 38.66230856987738, 0.06813156989312942, 0.10390745460866921, 0.08328198515359433, 0.028938820037329872, 0.01120344600490024, 0.03781512266986313, 0.05158770198543226, 0.07254592173041836, 0.10698636197635245, 0.7539812223084512, 13.179560918961803, 70.47099697974421, 81.29830760340538, 77.88217421500914, 74.54945395069738, 67.77275146976595, 68.86482561788252, 64.39643798335906, 66.31162935687651, 68.6074867556172, 68.2390820595526, 72.55063764510616, 70.33034078536495, 70.09316290578535, 60.32328797924904, 61.006058877514256, 72.77393817901611, 71.45439009512626, 73.2660779645366, 73.6611940014747, 71.43251895904541, 68.73555214174333, 67.64583926047048, 57.73868137790311, 56.306863292571045, 58.591114397971864, 66.93518423265027, 70.39477748255577, 69.41808377542804, 70.39227501038583, 69.68663277164583, 68.28921779509514, 67.28560878384498, 69.15576350304389, 65.71312665939331, 64.48927656296762, 68.07264804840088, 66.81866630431145, 65.40219253109348, 68.97327130840671, 63.73990381917646, 65.99795741419639, 65.71968486232143, 67.7381875438075, 65.0198987222487, 65.04968912370744, 68.42937977083268, 63.18402944072601, 55.823148758180686, 61.33052518290859, 55.771871612918, 59.32105964229953, 65.35360220939883, 60.89855847820159, 62.151555707377774, 51.72280103929582, 46.617789191584436, 45.69387097512522, 48.1350443440099, 44.464827660591375, 45.21333748294462, 46.97822755382907, 46.89320625797395, 43.71577262878419, 45.0923558973497, 44.517956164575395, 47.677707749028365, 43.28349213446341, 44.54306717841856, 46.292746297774784, 55.341736655081476, 64.08684922802833, 61.87117684272028, 60.972416708546305, 59.232657263355875, 52.0566810331037, 58.282521924664906, 64.06570765279955, 56.86002731323243, 62.59967473245437, 62.41814744087958, 62.137270435210205, 61.29379218624484, 55.40243141112789, 62.80435577515633, 60.00200271606446, 56.87505391336257, 60.968153092169, 59.11318186790713, 57.13621708654589, 55.15462783075149, 53.11106512623449, 54.24675995303739, 54.39187980467274, 50.3630643506204, 48.984563043040616, 45.1330191089261, 50.88283723400485, 57.8850563879936, 57.441840325632405, 55.546621661032404, 49.70148209602603, 51.59330791042697, 53.67487445954354, 56.099919042279645, 59.059084538490545, 58.93099169577322, 60.90023333026517, 63.04278881319108, 57.83166508520804, 56.01292479422785, 60.44731332409767, 62.030354469053215, 58.00654003697058, 63.88755359957295, 61.00804359682145, 59.43958190179641, 42.52893793967463, 44.21763204759167, 57.657617753551854, 47.48311112003942, 42.307461307894805, 34.05646147266511, 22.73416538392344, 7.913335244501791, 0.06730391148237452, 0.17855402773186085, 0.03564781396679821, 0.06113518765496631, 0.019727369259682395, 0.10642584608567339, 0.23812744556175125, 0.19460933072672737, 0.021085729334323157, 43.27508257281396, 72.23506727526265, 72.02517340260168, 49.61648825676211, 41.62226638486309, 47.620123432528594, 85.20196022525911, 3.83602213475012, 0.09296239473887029, 16.103758485086505, 15.586370402766814, 17.716424311361006, 14.185276242994494, 0.24587438712196968, 0.19940068975331324, 15.83224613820353, 108.11134769070534, 101.69231045630671, 80.3644226443383, 34.32226088739211, 41.81177569973854, 27.901280118573098, 13.44722051774302, 15.566584006432565, 54.13457624373898, 61.55825407274308, 36.70806607892437, 35.74817972798502, 78.40355919253442, 65.60213142825712, 53.16866513221495, 57.69018911546277, 0.2158317895185563, 0.3089858134908061, 0.19629506123883111, 0.11684347740224293, 0.12460973203903246, 0.24824092465062297, 0.19693572524814837, 0.2828118986179752, 0.31442218790611914, 0.41552802067129846, 27.58419571384307, 76.94490032811319, 80.85999842612975, 79.07046410345262, 77.59333087551978, 74.90768401853501, 71.38689394920104, 70.94196381107454, 70.2341172002977, 75.78801293526926, 76.24670274796026, 81.17705929663875, 76.11851184598862, 75.58524993158157, 65.04492344394808, 62.210779574609575, 77.64817345526912, 78.17271201841294, 79.9778103059338, 80.37621328907629, 75.49421171988212, 72.18387249977359, 69.72491510452764, 62.07490474947038, 57.884315060031035, 61.41793520219865, 70.25422326980099, 76.71799121364471, 73.96283995720648, 73.42301983987132, 72.43255861343877, 71.8838974737352, 70.05405687516736, 72.28053539030014, 68.16363919165828, 67.18923614871117, 70.46403869505852, 70.03722990712812, 69.06190902956071, 73.85718699424498, 69.82619854711717, 68.1633097125638, 68.87270958192887, 70.10001136410621, 68.26965301267563, 67.2097344552317, 69.58915402812343, 66.85539537860502, 58.19694365224531, 63.37540580380348, 55.167791305049775, 62.37951209468227, 67.53214543865573, 62.76144896784137, 65.81188017322172, 58.08626613309307, 49.871658048322125, 49.469846525499904, 50.99837849217077, 45.3809521275182, 46.221865146390854, 49.060119659669944, 47.893089017560406, 48.17861010951381, 48.11056875413465, 47.67561320335635, 48.56642269319104, 45.83486057096913, 45.73134529975153, 49.204415813569106, 58.723055085828236, 68.82020473480225, 64.06821012496948, 64.15638500644316, 60.324805936505726, 54.44884438668528, 62.664162420457416, 68.03057670593262, 57.9279161268665, 65.46044757289272, 61.479641929749526, 63.48576953334194, 62.623283478521536, 58.42676316538165, 63.77376564087407, 61.735337318912634, 61.10253741664272, 63.86206996056342, 61.622357368469245, 62.23458443918536, 56.66571309489589, 59.231515853635734, 59.61534723158806, 60.76474681977303, 58.9705958674031, 57.68556464102961, 53.7231666811051, 55.28459556641118, 62.00028950168241, 63.184551115958925, 59.96934506200976, 55.93865471501505, 54.93168815489739, 58.44792043009112, 61.596308908154896, 65.1329335858745, 65.58516717726185, 66.89428175649336, 69.99225601073235, 64.09612563348585, 62.9268043271957, 66.80466344279628, 70.50888707560878, 68.86855186954622, 74.96121652664678, 69.68970006512058, 72.84331706262404, 59.811289233546105, 61.73101094461257, 63.40625132283857, 56.30207015622047, 51.915173684397054, 41.53920627409413, 33.76954793930054, 11.711786466260111, 0.9704472100542438, 0.2824927770322369, 0.20731024113633942, 0.1398548970539724, 0.17045448654361312, 0.20215423957955456, 0.3332698200979541, 0.19585764035582545, 0.2118519014648853, 48.3590038361088, 82.55545862259405, 80.16360513625607, 61.77150157190139, 49.79534441424955, 53.544216386733524, 96.80338982612857, 5.858539852403826, 0.841232508180603, 23.792589518331713, 40.52165715925155, 28.348196937191872, 18.55145965853045, 0.36511719827690436, 0.5731302944402541, 24.147520872854418], [76.362012586286, 31.8860944240324, 9.172837234312489, 10.1379148421749, 16.66039674512802, 5.483937811466956, 1.4552093850028132, 3.801970078099159, 14.439243828096698, 28.06539797013806, 35.45014235281175, 36.250101904715265, 28.006142723944883, 43.24009110850673, 28.557700534020704, 21.700528667819118, 0.8552653390553691, 0.15083891249472095, 0.062151001090364116, 0.0931503007849378, 0.1234955644054759, 0.021139177373580394, 0.021697034939162193, 0.04121394835472588, 0.10057967591790423, 0.684755985294619, 5.172448177491465, 25.971997630211618, 72.29910389069589, 73.19132543379261, 72.64217792018768, 64.37484533556047, 54.579659354302194, 53.908694790255645, 55.48437756876792, 58.50449277508644, 64.30589399030133, 65.56701444810437, 69.8565576922509, 66.82425960417717, 65.0016361667264, 57.149408017435384, 64.85392362840714, 72.15186595916748, 68.39364697856288, 70.69457207956623, 64.32063817977905, 66.84832726755451, 66.8248950281451, 58.834360184208045, 53.59830979377993, 53.663005367402114, 60.8574834177571, 66.32168631399831, 68.1424113242857, 67.10326563927435, 69.5517110824585, 62.99218239322786, 63.29432256760136, 62.59130439450664, 65.04611584448045, 67.51377305676861, 59.735838520911436, 60.43198077909408, 66.18050452201598, 64.45483815285468, 60.776768884351185, 65.64945090201594, 61.38199452430972, 65.52811238073534, 61.64281252891787, 65.21032194937429, 65.34583983882781, 53.66495870774793, 57.97583180089151, 60.12792256570632, 56.15888795545025, 61.19621146109797, 61.49457831536571, 59.64143491560414, 55.61268221947455, 47.07624758443525, 44.55713672022666, 48.01560032752253, 48.331123628923976, 42.419280236767186, 41.44425745933287, 40.27991364079137, 39.98569273179577, 39.438506403277, 41.16580055605981, 39.23830862968199, 43.079705392160726, 44.795679584626235, 43.15013939334501, 40.82831982643374, 51.87174520184917, 56.00680589675904, 60.65697969928865, 60.21082970403857, 59.69050768882998, 53.319990173462905, 50.88692434372441, 56.49860835844471, 59.97652692179526, 52.830521522029755, 60.08404693295879, 62.121529963708696, 58.17435864479312, 55.74573293808968, 57.50262921856296, 56.99450185222011, 55.42916236385223, 58.530443176146484, 53.87493495018252, 52.0304129200597, 50.893721811233036, 49.18549037748768, 47.62754063452444, 44.040521344830914, 37.49203020526517, 36.35046359031431, 38.45133212304885, 51.11557106817923, 55.2445089432501, 52.64360097146804, 50.18300010311989, 45.45943090992589, 49.30881754044564, 53.133634444205995, 52.197156798455026, 54.19323921203614, 53.65676879882813, 60.06365453043292, 55.831315132879446, 55.641413580986764, 65.49186968034314, 61.522501668622425, 59.883653040855165, 57.18396017628332, 59.32668824349681, 63.313463734042266, 57.62192026261361, 55.67356524928924, 60.40639908083024, 64.25889222852646, 47.63502059444305, 38.377568029588275, 29.061274028593495, 17.862318831105387, 4.663754518954985, 0.5927229011731764, 0.648332120430085, 0.09643865659111932, 0.07934668341711645, 0.19185950408779806, 0.15091241097017644, 0.1511131413280964, 0.26579782126411317, 0.25025889217372865, 28.323060427942586, 62.7660067619816, 60.900303932928274, 46.386734131843816, 40.70613015082575, 40.25395539499099, 70.78490426463466, 2.0965012186957948, 0.17401846546319225, 3.0765907178002023, 9.908132591555196, 10.0438299294441, 8.16326573010414, 0.24954757953603424, 0.2521311191301192, 28.483306900147472, 94.09984911641767, 62.71301554095361, 34.823226005800315, 12.782920060619233, 28.780332303816273, 16.718875362027077, 0.995987294422042, 12.701034699716876, 22.000284041127852, 42.354278718271566, 33.57935613201511, 37.33200926934519, 51.138077628227975, 51.692371291498986, 40.53847236018027, 43.51297432376493, 0.8817600302638546, 0.05664476328679631, 0.1570325188579098, 0.009964851328291962, 0.08871021605427228, 0.05899484524683607, 0.06244047890387236, 0.027670444650275093, 0.18755735348789923, 0.5500785249375528, 0.7232611578318381, 42.42146499695317, 82.9146614382344, 76.4005224166378, 78.04121848075621, 69.20611104657574, 63.86049709012432, 59.2739402094195, 63.27875075801727, 64.4662679395368, 70.51257410357076, 71.65425054488644, 74.62460656319895, 72.18325276528635, 66.51107403539842, 60.040700820184526, 65.22783925456386, 75.23514701474097, 71.94933829769012, 70.74391549633395, 70.4561782652332, 71.5140179664858, 70.76575525345342, 64.0166348795737, 57.06296290120771, 55.92810353925152, 64.37576709255096, 71.4318835350775, 69.56405870376095, 70.2936666242538, 68.20806395622992, 65.6093603564847, 66.03939333269673, 67.12228913461009, 67.36098104907622, 71.62479354489234, 64.43590879440308, 64.00529922977572, 68.12465083214545, 67.00462587418096, 62.13441102735458, 67.3810165159164, 62.77934674293765, 67.55313796381797, 65.90113762886294, 67.08308112236762, 65.61449081667008, 58.813806964505105, 61.290167916205625, 61.30782642672139, 58.82832365651285, 67.21313122780093, 65.3498249669229, 64.08367210818876, 55.26396389930479, 50.097916049342004, 45.39721819662279, 50.310728165411184, 50.82368789180633, 45.608378994849424, 42.17493618688276, 40.12339930380545, 40.098790353344334, 39.30110577614077, 41.697579814541726, 40.7752501580023, 44.450907168849824, 48.96721047739829, 45.059898284173784, 42.079865778646166, 53.5191406742219, 58.29542652253182, 60.31001860095609, 63.12990465471822, 62.047718801806056, 57.59655821707941, 54.55046515310965, 59.49627191789689, 61.84335154871788, 57.92506064138105, 61.67521522891138, 63.21554176269039, 60.739584815117624, 58.704804297416445, 60.47939046736687, 58.45632999174057, 56.77777913308913, 58.48780309000323, 56.80597705225791, 55.5637231949837, 51.35056418757285, 52.44323453595562, 50.20071744918824, 48.52886992116129, 46.22447744492562, 43.83343981158349, 45.4915786558582, 54.477697341672844, 58.960636969535585, 56.408056520646625, 53.438924281827866, 47.81138996924124, 51.50399554160334, 55.009692330514234, 54.48799356337517, 59.001535523322325, 56.265074360755186, 59.21762674085556, 56.88233383240239, 57.05009752704252, 63.7215079030683, 66.26243499017531, 66.93136384410244, 66.40119275739117, 63.822050017695275, 70.2103868607552, 67.23297842087285, 63.11512124153876, 67.46648496197116, 71.96466692032354, 54.76613275466427, 43.80822289374567, 35.15370138229863, 27.09874160828129, 7.585714863192651, 0.7372839989200716, 0.2547034585187512, 0.07509573047319729, 0.0763818848457548, 0.09493384540321366, 0.29995118538218163, 1.3738833295722164, 0.2947281204885052, 0.20493973527223835, 38.97172081855036, 71.22884596547773, 68.70828382430538, 56.09087797903246, 45.96498520143571, 48.78455354321388, 84.76938555317541, 4.0264372719872386, 0.2799653610394847, 6.5288072151522485, 14.532566820421527, 18.645378851121475, 15.889047941853924, 0.35831442943984465, 0.18673782327002098, 21.37110644771207, 117.50054482490786, 86.80973975889145, 37.610583843723425, 27.534693441083355, 40.38149126114384, 20.73651990582866, 6.012918949127198, 19.348228362298784, 53.843446162439164, 57.91459968013149, 53.225912124879905, 53.72452382118472, 35.21761248188634, 65.20559941568683, 53.27492998492334, 66.53828743965396, 1.82957632887748, 0.3300183284426889, 0.17351240310217106, 0.2701140219165433, 0.3719873215642668, 0.2035456391111497, 0.18694204698887565, 0.10805326964586012, 0.42067582508729356, 2.0569620113218985, 13.661478027220696, 58.157406160908366, 81.55824307472476, 80.38426199266988, 81.14135003858998, 72.31349114448794, 66.62930211713238, 63.53011585051014, 67.00975633436634, 71.83331458799302, 78.6225764982162, 80.24884608484085, 79.97020090779951, 78.88200990615353, 68.35688652530794, 64.05783545586371, 73.22798390542307, 80.69520396571006, 75.3179874727803, 76.11986114132789, 72.1196162316107, 71.44983230098602, 77.72909979666434, 67.1882555561681, 59.9444733127471, 59.432976630426225, 68.1500050329393, 73.46276913919758, 74.21825685808736, 71.53166078752088, 71.37008267064249, 70.36831717337333, 68.96064127645185, 71.08983716657086, 70.40476383701449, 74.22877665488951, 68.61987360062139, 68.43393756497291, 69.70442464274745, 71.09881939426546, 65.29772020155384, 71.73074460798695, 63.41443338701802, 70.71338376691266, 67.61119688710859, 71.41973203228366, 70.52856952913346, 62.210050013757524, 63.7829989002597, 66.47554520637759, 63.55957285050423, 67.69941883702433, 68.51692707307878, 65.47482305957426, 60.58638880329748, 53.37521714548911, 48.64289714444069, 51.42951365440123, 52.17498363987092, 47.014603614807136, 41.12736917311146, 40.963253282731586, 41.789802582033225, 40.636912084394886, 40.45215275979812, 41.330744066546046, 44.19842420085784, 47.787079118913226, 45.99806647146902, 44.18828487396241, 55.04839043463431, 58.44277820279522, 65.94814331300798, 67.29859182911535, 64.46548738787251, 58.79157889273859, 55.802042484283454, 62.14828445065407, 63.548205821744865, 59.71907038842479, 64.4065223970721, 65.72124596565001, 63.27221608931019, 60.37707936379218, 62.456394472429835, 62.992288297222515, 57.04644187804192, 62.5317039797383, 60.22283607913602, 61.07153500280073, 57.380172821783255, 55.10135419907109, 53.388717943622225, 58.52694442195278, 52.41382852677376, 49.07604448256954, 48.23541387434929, 56.58861890915902, 63.738613359389774, 59.72529126751808, 58.504253510505926, 51.54323101043702, 56.85830539272678, 62.48740865338234, 61.00014786566458, 64.17052907328453, 62.28664605848251, 65.3637650705153, 66.14016686716388, 65.16585403873076, 72.11095563827023, 74.78460004252773, 77.83923995110297, 75.29753623470184, 69.37561235120221, 74.58660664096956, 65.67678982211699, 64.36024627377911, 67.69261744714552, 71.22191121501308, 60.28344062066848, 55.47418725106024, 41.3022009788021, 34.003529087189705, 11.545655458204209, 2.1651716241913457, 0.918298440594827, 0.17806530960144537, 0.27494126450150247, 0.39877168593868134, 0.25764842307375324, 0.7901711545644269, 0.6715880983298825, 0.39629945891999435, 54.630234395304036, 79.72422122955322, 80.80475576462285, 63.96532635534964, 60.493001091864805, 54.89146817115046, 99.9738573258923, 6.61734099349668, 0.8320764091707046, 14.188368051282822, 36.30201055157569, 28.547980900733705, 23.335625548516553, 0.32201264834692406, 0.2005117623916557, 31.606229389867476], [64.78179516330843, 40.4713527617916, 5.842019809830574, 16.695807903043686, 19.630005551922707, 2.067728917444906, 0.20725710527791133, 1.4486799869806537, 9.728539028475362, 30.984433697115993, 48.14097889008061, 44.99741492732879, 28.835776967387048, 28.587326195932206, 34.60031770890759, 22.897714491813417, 1.1760127472300683, 0.1591116968061655, 0.11680469037063661, 0.15734984779790526, 0.09141664381229109, 0.10806070069872564, 0.1524399902911917, 0.19726817676376915, 0.21276291790268115, 0.6925533507620135, 4.914677364210929, 22.76218483524938, 73.34171695093956, 76.95411005327779, 75.30560847251647, 69.23996110116282, 59.51903343200684, 53.44949899181243, 52.231583441457445, 55.66907413544194, 61.22258940050679, 59.93531457839474, 63.205622088524606, 66.54295506015902, 67.23127611221807, 58.58304216015724, 58.011144899552875, 67.00930133942636, 67.2221056107552, 68.07536232856013, 65.11699307349421, 67.46739495185115, 67.17499794498568, 62.201295283532914, 53.998513144831506, 50.75030819062264, 59.175747594525745, 65.2067800491087, 66.1880668517082, 68.96114333983391, 69.32378215174522, 66.06087223176034, 62.78062543561382, 60.25092809431015, 62.131296665437766, 64.02864517704134, 64.40730687110656, 57.77095463968093, 58.28516167979087, 58.18623165930472, 62.451601336079264, 62.88835725476665, 62.121314233349224, 64.40439255006852, 65.62360248258038, 59.89876201075893, 57.53086636143347, 57.38055329168997, 60.884473246912805, 55.21959012554538, 58.154695803119296, 62.48407071636569, 59.40381380819506, 59.90361398266208, 51.63486934477284, 40.74380059396067, 42.18524809806578, 50.600183394647416, 50.87153688553841, 39.314955665219216, 41.68104702426542, 36.93763456036968, 39.335975646972656, 38.197025252926736, 41.728276283510276, 37.83645353009624, 44.26228038726315, 49.337313559747514, 44.41030279282601, 37.68051970389582, 53.925611972808845, 59.15074248467723, 54.738986030701675, 57.94709651700912, 55.55202668712985, 54.58258936482092, 51.38393179062874, 54.598251388918975, 58.47043091251005, 58.905778700305575, 52.15872541550667, 60.83621240431263, 59.749641341547814, 56.21603688886089, 56.50373489625993, 56.744101662789625, 54.055669922982496, 53.28251192646643, 49.9539101508356, 52.38333209868401, 48.32891533451696, 48.500938723164225, 42.13678721458682, 39.54150784400202, 46.879736838802216, 51.95591142100673, 55.448205471038825, 52.739381328705825, 55.85177813806842, 52.88565827954201, 49.31188091155022, 47.69254607539023, 49.259191713025494, 52.77673013748662, 57.843239999586544, 58.784636297533595, 56.34010930215159, 58.55031782580961, 57.73260170413602, 61.106738275097264, 53.771466747407, 42.451373069517075, 50.41299612291398, 58.50383773926766, 67.51022723413283, 64.3404971399615, 63.44407866078039, 55.53268547981016, 59.38877151858423, 62.36126130627048, 62.574826517412745, 49.69562991972893, 40.10802753510014, 18.77139872120273, 6.274230191784521, 1.5409783826720331, 0.24380889150404164, 0.3590660536241147, 0.0686022313311696, 0.07306308470546238, 0.4702945432114986, 2.1293052261875522, 0.42623915559341835, 3.8541243633916302, 53.749615223177024, 58.19380967847763, 71.7093441563268, 44.863160041070756, 49.463445217378684, 43.291682043383204, 61.21952210703204, 2.534538281540717, 0.39753472973262116, 1.6778477737980506, 8.547006403246234, 12.080499068383249, 8.984587980854897, 0.20772492452975244, 0.330757174280382, 24.816494834038522, 93.56438282997378, 61.480979457978286, 2.5601008582499722, 18.88626729288409, 26.607590260044223, 10.499902540637601, 1.1964905838812552, 5.103567925191695, 16.783878841707786, 46.49876486870551, 54.66680265242054, 37.90830350691272, 17.598180540146366, 34.459626213196785, 47.30767919171242, 47.39939597345168, 2.3051200759026313, 0.16403451652055787, 0.09753291359952382, 0.08218720720540132, 0.02805623503762388, 0.027301358810115247, 0.09596234142419793, 0.15129108823114826, 0.14127782876453093, 1.5919461509873791, 4.631733759757012, 35.510844953598514, 83.23724500594601, 81.12571547108313, 83.78254859678208, 71.934676477986, 68.5302552869243, 57.189125937800256, 60.34291551959131, 62.832992999784416, 69.5330092214769, 69.24784506520918, 70.79557311150336, 72.02859370939194, 69.39566350752308, 61.800589869099284, 59.216489253505586, 68.63279388796899, 69.47682519112864, 71.21561973325669, 68.24545198871245, 70.19996904557752, 72.43440212741976, 64.84083467914213, 57.0829277653848, 54.19386286889353, 62.278718948364265, 68.2997375918973, 70.39671513342088, 70.9419402768535, 70.89680948565083, 69.28557042152651, 61.23037922766901, 65.34833838862758, 65.31917164402624, 66.39382654620756, 69.76322097163047, 64.52558202128257, 61.297012452156316, 60.889411510959754, 64.94593066553917, 62.832679210170625, 65.09205072156846, 65.72907893888413, 67.34260866718908, 62.736239894743896, 60.1487817302827, 60.83180758260912, 62.865372165556884, 57.84708392235541, 60.21043746702133, 65.31149164322885, 60.82530821523359, 61.82586170011952, 53.2326429120956, 44.20358604000461, 45.04184361427061, 55.07772976352323, 55.66719924249957, 41.41415326826034, 42.28884573905699, 38.54013066137991, 40.781533795018355, 39.78907215979792, 41.12611009228615, 39.751440940364716, 47.104265074576105, 53.059132945153024, 47.87971373527281, 42.69284986680554, 57.75764211531609, 56.724148565723056, 55.937925154163, 58.73549292164465, 57.686760963932166, 58.31992172425794, 54.67496118237896, 59.042387008667, 59.79589000824959, 62.09943133015787, 55.212463178942286, 61.43508772696219, 61.587879734654585, 58.43179164394256, 59.0537775716474, 59.46455955505372, 55.618444181257686, 55.53143816609537, 54.96462429723432, 54.85839474585749, 51.23081422621205, 50.31540363065658, 47.35053500821514, 47.90613089838336, 53.98306292872275, 55.048272763529134, 58.10845498115786, 54.769831549736764, 58.114762152394945, 54.472723776294345, 54.14152276131415, 49.62787097500217, 52.437907957261615, 54.55537988293556, 58.29330844263877, 60.62241969570037, 56.89149648912492, 59.810163513306655, 57.946645444439305, 64.05456419914, 59.4165026757025, 54.05112781832295, 60.55772412207819, 66.11597368794104, 73.16568097760602, 69.11603773793867, 68.87991105356525, 60.62416907279723, 65.1193896416695, 65.87600308079874, 63.859351758034, 56.897336898311494, 41.287354807699884, 21.55198850939351, 8.821776278557317, 1.8751415225767323, 0.5176030772347604, 0.24301311001181605, 0.02223964352461119, 0.07914134887077155, 0.3806338188869338, 4.507991315857057, 0.33028134174885293, 5.3290154664747185, 65.52011074558382, 68.43443962835497, 78.55230331420898, 53.93726533459079, 53.70823814022926, 45.55785102228965, 77.30995532005065, 3.822800070047379, 0.11225597437230811, 4.744031217790419, 12.105231573504787, 18.564374062322802, 15.070935660792937, 0.10001640977157701, 0.09744294423369632, 26.136505757608724, 109.4032822885821, 80.03776765638783, 17.838925815397694, 31.512333731497492, 47.01052042745775, 13.348258137702944, 2.2423913257737316, 6.2344588291260505, 49.138810250066946, 62.71260761445569, 63.64031484050136, 61.67685085727323, 41.660301608424035, 48.449806705597915, 60.123882524428836, 70.22373076408141, 5.223818969342017, 0.2980313077569008, 0.22771330760611644, 0.3108073560701263, 0.11517332145763982, 0.1249498061294998, 0.2818109587796273, 0.418873833071801, 0.5893559141024467, 5.19995036625093, 14.632408791972747, 50.40235473263649, 89.11092373632616, 79.68979850892099, 88.18407550934823, 76.33512866112494, 74.99691009521484, 63.84418003020748, 64.16970537554833, 68.49816245417442, 76.72389830312422, 75.95520788623442, 77.46035468193793, 80.15616832240936, 74.70150855279739, 66.38850781225389, 62.530754766156605, 75.77530445591097, 74.62877212032195, 77.16298410969397, 68.82853584904825, 72.88625917127057, 74.41170031024565, 70.1999298218758, 61.25604721807665, 56.76630227796493, 65.09182322409846, 72.5389176030313, 72.88920879364014, 72.8741390474381, 75.37416365838821, 70.8349693975141, 67.39169320752545, 67.70515334221625, 67.40684140113093, 71.22167587280273, 71.65425054488644, 66.1505925270819, 65.3765598420174, 63.426620191143414, 68.54286178465813, 65.0514659573955, 66.73599058581938, 69.97417388423797, 69.34071110140893, 64.64603408690422, 62.56748776282034, 63.111112579222656, 66.25684953504994, 61.83973904578917, 61.760389497203214, 68.71408108742007, 64.2293450140184, 63.03632082477693, 56.220096541989236, 46.165900768772254, 46.80636890472905, 58.36065553849744, 55.68433607778242, 41.68552244863203, 43.06698122332173, 38.18199080805625, 41.338502514746885, 39.883871924492624, 42.32415883771835, 36.31005141042894, 47.200198404250614, 53.00533763823971, 49.658465462346236, 44.50013683688256, 61.85812711715699, 58.864134896186094, 59.99611131606564, 63.52947258180188, 59.134225383881606, 60.150927266766956, 56.390088142887244, 62.19561961389358, 63.12723744300104, 63.59059487619708, 57.39313625520276, 66.37379107936736, 65.71933184900593, 62.38106143090033, 61.33941719608923, 61.82579894219676, 59.407838159991854, 58.983924081248624, 57.819011519032145, 57.861408418224705, 51.28672761301841, 52.594230098109094, 53.30157464550388, 51.18664833807176, 56.24640387873496, 59.36545302790981, 62.024223804473884, 57.812202284413004, 63.354723145884854, 59.07693916751493, 59.570996992049686, 54.68865025428034, 59.24636202473795, 59.942021831389404, 64.29243241586994, 64.20154325423702, 63.35918680314095, 68.75525812948905, 66.93488613251718, 70.70139700366606, 67.64162663490542, 65.14910944046514, 69.92026482858967, 73.42711479433122, 75.27796360754198, 73.84942854604414, 74.8047924041748, 66.48501380797356, 64.79916734080162, 69.37161153362644, 65.72293650719428, 65.77833606350806, 50.69676391540035, 36.02337714164488, 18.266605369506344, 7.012763465604475, 0.7089027089457358, 1.2582631337065853, 0.2975455160823561, 0.27761825150059116, 1.2494556966327852, 7.6221007300961405, 0.4493649904766391, 6.289040080962643, 80.55599120355423, 74.6787666505383, 90.45569266042402, 60.97068302093014, 67.4741178943265, 57.27634768332205, 94.35252820291828, 7.940627096160767, 0.9496076573287288, 15.860644098251099, 29.79756566785997, 32.48251434295408, 24.51853982863888, 0.24819243128501603, 0.268305410901385, 31.581159560911118], [63.892311434591974, 45.36332107359364, 8.491994180986959, 22.051929889186738, 27.550226026965728, 1.0178713007800042, 0.08033054715563213, 0.4220625668043091, 6.652558484385091, 34.23237585252331, 24.52169341425742, 60.56774577786846, 99.46467876434328, 26.02647935190509, 38.31270379404868, 20.45946328870712, 1.4542940018638488, 0.19851591948780323, 0.11720414393611493, 0.015264974133442006, 0.072049351198779, 0.06371544839273538, 0.07087862329377283, 0.05475064153752981, 0.06332522235630501, 0.8885321862274601, 3.2115553079112886, 37.1346709036058, 80.85581717952606, 78.39652246044528, 76.81975318539527, 72.17113264145391, 63.97218658078102, 52.795490834020804, 52.46161084021292, 53.47728506211312, 61.34299832005655, 57.57084315822971, 59.17065635804207, 60.233426478601274, 64.62387269543063, 62.277432410947746, 56.16529318594164, 64.80180317355742, 68.07059272643059, 68.54841586082213, 66.01931864215483, 64.48867251796108, 64.72153186798096, 65.13274531210622, 53.12786463768252, 50.470843238215295, 56.16048436011038, 63.434429630156494, 64.52862578053629, 68.47361626163607, 66.26477272279801, 66.4754589142338, 62.51864640943466, 62.38801971558602, 64.00147884122788, 62.80704652109454, 62.27529079683366, 63.488876050518414, 60.79155229753064, 56.10858355799029, 62.04820125333725, 63.092214599732436, 64.63968769196542, 64.4266402336859, 62.350804267391084, 59.86197802328295, 56.051870007668775, 56.710157471318404, 59.07207542850126, 56.997384794296764, 61.234011342448575, 62.23517671708138, 64.60341753498201, 58.64251705908007, 47.95385437626993, 40.92327648593534, 47.036643412805375, 53.89262876202984, 61.649810037305286, 52.158501840406856, 40.54937262688914, 39.70873025155837, 40.6551589504365, 40.51399677030502, 39.373983413942405, 43.86158281756986, 55.66593623930409, 55.18723841636412, 45.942066792518865, 40.952145130403586, 42.96648617713682, 43.35968809743082, 56.04926163150419, 58.32646816007553, 58.89516868898946, 56.32459240574991, 53.20875567774619, 53.14188318867838, 53.81816648667859, 58.03590290008053, 56.95439169483801, 53.98246280608639, 57.74520820186984, 56.78477664147654, 54.90247826422415, 53.21814975430889, 51.38019377185453, 54.435516172839755, 54.55326572541268, 52.691069495293405, 49.02429665288618, 42.830258338682114, 46.85182525265602, 55.95173581953972, 56.824039566901426, 53.59422660643055, 51.734160223314845, 53.673666369530466, 53.862128411569905, 53.09043345912811, 48.87965140804168, 46.94966485423427, 49.33277537745815, 53.63235204450546, 58.04382216545844, 64.84422360697101, 59.84878709239345, 55.97523866161224, 63.01387310028077, 53.38214405121342, 37.619734733335434, 35.30709351262739, 52.992131017869525, 57.01795370348039, 64.0939800970016, 62.304214354484316, 60.6591683818448, 56.288055527594786, 55.65616169283467, 58.52892129651962, 67.25011133378553, 59.60424692400041, 53.35030225015456, 39.45462734468522, 17.374028851909024, 4.889055951949089, 1.7429007734021835, 0.7500807316072526, 0.3220763255751902, 0.0942138070240617, 0.3056709203989275, 4.297130578948606, 0.18912323720512852, 2.8577972323663774, 42.647801445376494, 64.85989739817958, 69.8877719140822, 47.47424656344999, 48.02058173764137, 43.04755372385825, 65.18552864751508, 6.600589531083261, 0.2669205690824217, 0.717635314551092, 4.497765206521557, 9.40424922973879, 5.482383081989904, 0.11686737934548048, 0.2671514373392828, 13.944118138282532, 91.0005569458008, 58.03947225693734, 8.868133791031378, 24.887628978298558, 29.450180953548802, 7.45652424712335, 0.2962907253494186, 0.6102605536580086, 13.45465046744193, 48.24896566329464, 36.169520731895204, 56.98785735714821, 78.9060305010888, 31.225649656787997, 53.042957090562396, 46.9551718619562, 3.5955884427793565, 0.32590587653460046, 0.0848600879732159, 0.026389005548891523, 0.06482070642373254, 0.0543332921581403, 0.11216433493480568, 0.03905058117403139, 0.22092465010862197, 2.788152853327413, 9.085176183331399, 47.56500628686721, 86.17669274730068, 78.64978990247174, 82.98580538841986, 78.0965474344069, 73.23557761407667, 61.47396233774001, 59.24756619238085, 59.24386347493818, 68.53950423579063, 66.90409552666449, 65.53211319831111, 68.44764232635498, 68.61056189383231, 64.88403566422002, 57.634240427324855, 65.61771500495173, 70.29008942265665, 71.47226041363132, 68.96060989749047, 66.6453524558775, 69.43541280684933, 68.34885351119503, 57.54919951961887, 54.35750807485273, 59.530635802976555, 67.27007619796261, 67.37834930419922, 71.66792392730713, 68.91118803331929, 68.02091983056837, 63.724261406929266, 64.62015036613711, 63.449781787010934, 64.33606878403695, 64.02581322577693, 69.11158977016326, 64.84046989871611, 60.16472224266299, 64.92061568844703, 64.88900922959851, 65.60289236807054, 65.31926970328054, 63.48019976769725, 62.839359006574085, 58.530086240460804, 61.80856797002978, 63.53690155090825, 58.69719489928215, 63.58399352719707, 64.37349996259137, 65.60212750588694, 58.29455575635357, 48.561515808105476, 45.32810603418658, 48.13725263841691, 56.90259679671257, 62.55759946761593, 54.12097738635156, 44.22339008700463, 41.11951658802648, 41.08636471533006, 40.86966553042012, 42.10801662937288, 48.09047837411204, 59.61155429963143, 58.99817012971448, 50.42561831012849, 42.78471177624118, 44.175388120835834, 44.16969283934563, 54.60972039930282, 61.54849129338419, 61.36781123376662, 58.71552413509738, 56.17467549539382, 59.40307248023249, 55.68521076633085, 60.01694694642098, 59.384821691820704, 58.79457950592042, 58.331535862338164, 59.771959627828295, 58.074044027636134, 57.62051605409192, 54.888549927742254, 57.748965832494925, 57.20509782914193, 56.48808463927239, 47.86135704286637, 49.67516299216978, 54.06097688982564, 57.94916752846011, 58.45664770372453, 58.21177021149666, 53.88777679012668, 54.15555307942053, 55.217526958834746, 56.24620776022635, 51.36690478171072, 50.125455010321836, 52.68543697172596, 56.28665524144327, 58.675602251483554, 65.13495360651325, 58.53181208333662, 57.02470410254694, 63.09627817523096, 58.55423627361175, 46.433359346082135, 49.62305822680074, 62.07530483122795, 64.3914604956104, 69.79845170051821, 66.72168177943077, 66.61179265668316, 63.46015253374654, 61.78923460745043, 65.58677142666232, 68.79030058460852, 63.91689292846188, 57.16051616976338, 43.84222199839931, 17.11792553624799, 3.779028380109418, 1.2334021709619032, 1.2935693682201448, 0.4019381111908344, 0.11533136539641889, 0.4941288868506109, 0.8448376566652329, 0.2741871581923577, 5.002731142505523, 58.65791236200641, 73.98902570047687, 80.60317731672718, 56.670113994229226, 55.68385362625123, 49.66199951787149, 77.89721258224981, 7.997382321665365, 0.23427956977919226, 3.0482246270102844, 10.737330471315692, 15.870901096251705, 10.687046666299144, 0.179116029833113, 0.2175821778514693, 23.052365702967492, 108.7573463686051, 79.15556384671119, 19.722165561491444, 42.51101663035732, 62.066640315517304, 16.858745121186782, 0.9739127466755529, 0.5466880036457893, 39.38739399756155, 66.30784819203039, 38.877395660646506, 80.85032586128482, 103.60692916377899, 46.00080036347913, 63.499842997520204, 73.54782965875441, 10.395252723847667, 0.584724023938179, 0.4312069599907245, 0.17382233163281796, 0.24416126130569368, 0.1785108663382069, 0.18663067821293108, 0.12326419053058471, 0.31228458809275783, 5.644223997669836, 17.166633529047814, 60.456860373097086, 88.44173600596767, 84.33476340386176, 86.87410585341915, 84.94067545860045, 78.74636650085449, 67.25625376547536, 62.54704044711206, 65.66321057658043, 78.03738240272769, 74.2571432359757, 73.4051573661066, 78.5714287911692, 72.80312061309814, 69.60130553091727, 62.85242834398824, 69.55905375942108, 75.99931101645194, 75.17932384244858, 70.57078207692793, 72.83105573346539, 71.72500225805467, 72.54914714444068, 59.77831778987762, 55.967880295168975, 63.439638537745324, 70.80108796396564, 72.38200710665795, 72.98956655686902, 71.45533930870795, 71.78795629932036, 68.70003115746283, 68.78300497608801, 67.83153210916828, 68.36069906911543, 67.95408264283212, 70.8558677857922, 68.59995580488636, 60.90270050110356, 67.57148681148406, 68.63595531832787, 68.74315369513728, 67.20845576255553, 65.66141805341168, 65.22035537227508, 62.92913421507805, 61.91541333352367, 66.00762213430097, 63.337158772253225, 65.66123762438374, 68.86470794677734, 69.31524707425025, 64.30385828018188, 51.876605018492675, 47.62997642640145, 52.11390449154762, 59.22879765110632, 66.89521528059437, 54.3484160207933, 41.13948145220357, 40.53275746683921, 41.32469969411051, 41.55074196477091, 40.89083456224011, 47.26998913672663, 60.29996948857462, 60.0878280978049, 51.74338563796013, 45.347321725660755, 46.07374075920352, 48.98599863052369, 57.38490320021107, 64.97925120015299, 63.62200521653699, 60.42605015539355, 58.614021039778194, 62.729218852135446, 59.16962477468676, 62.77896627303093, 61.60668357726067, 61.46817684173585, 62.58716237160468, 61.28787332965482, 61.76217809800179, 59.83610214725618, 56.63897429743121, 60.55065208865751, 58.16974593747047, 57.67908880787512, 55.19072932581748, 55.23687601089478, 55.556976718287316, 62.45305261304302, 64.20819951641944, 64.02608386931881, 59.50363420671033, 59.43750696797525, 60.05738266052739, 59.88327257094845, 57.65751577192738, 54.491425637275945, 57.354375393159934, 60.20282414651687, 64.52278144897954, 70.59859168144965, 65.6006173933706, 67.90130322979343, 69.83045039638397, 68.16127008007419, 57.55541255397182, 62.31971163903514, 69.28074590621456, 67.9177850292575, 71.36725856411842, 70.25981656966671, 66.66374837198566, 64.73625644560784, 64.0697516164472, 68.3356115894933, 71.2866303228563, 71.78666976190382, 64.76618020765244, 52.10420839248165, 38.79371189302014, 18.30882772322624, 5.876562653049346, 1.9370758701716702, 0.6210229245405043, 0.41353456796176974, 2.599381434340631, 7.929391466802167, 0.5601819989181335, 7.275784861656928, 74.23670768737793, 77.9810885460146, 89.84659564110541, 62.42338380505962, 69.54370160256663, 63.15548243061189, 90.52513430195471, 10.384928064961588, 0.3193770300957465, 12.089368527935399, 22.97066273227815, 24.946323325557096, 18.268911723167665, 0.27548184678439175, 0.5599802420023949, 21.294002456049768], [59.90473578053137, 56.481828458847545, 8.882890728212173, 30.370000293177945, 29.80045057112171, 2.934480549827699, 2.133086391033665, 1.1608733789574717, 6.048271761786554, 47.12137445326775, 49.320039441508634, 37.5424091277584, 51.83734601543796, 34.18072608209426, 38.89366957449144, 22.579776971570908, 3.9661832922889344, 0.09937750010360634, 0.019557835917258938, 0.05530548071668995, 0.08987525192600104, 0.07436358024396243, 0.07314529360061692, 0.03385352496538432, 0.07371330949207468, 1.5645944831832763, 9.988965776658828, 63.65047377924766, 87.96981996105563, 78.37341185539, 76.62226184721916, 69.38917590725806, 67.51134903200212, 53.85391889079925, 51.21982374498921, 54.43142514075003, 59.462621904188595, 59.72505984767791, 59.22085877387755, 61.632508462475194, 61.654144256345695, 64.58527657293504, 54.42653394514515, 57.35074720075054, 64.3274474143982, 67.94407275415236, 67.89530984817013, 64.25534640589069, 62.21025397700649, 68.12955379486084, 53.96769900475779, 54.50683662968298, 54.753534101670795, 62.767618856122425, 64.2542677540933, 65.2430658955728, 63.44324711830386, 59.51670354412448, 56.406507184428555, 59.82031852968278, 62.98722451733005, 62.5325825906569, 59.61511581174789, 59.70611087737545, 64.08364465159755, 58.97841315115652, 60.458931384548066, 63.7102585454141, 59.796082204388036, 63.056293533694365, 57.84320077588482, 60.084058700069306, 58.620547863744925, 60.16773070058515, 56.91334801335489, 56.35715200055031, 62.65451338983352, 63.06634264607584, 55.24294391755135, 47.903393084003085, 45.81813166218419, 39.69283288524997, 49.70799715288224, 55.110540390014656, 58.91442752653553, 60.99637062318864, 56.21307157701062, 49.98762292246665, 38.56624972435736, 43.6672999781947, 51.58293716369137, 57.454297773299686, 59.425665332425034, 55.88751485270839, 50.748903982100956, 40.344318959020804, 45.04177693397769, 47.24619211689119, 44.61456414191954, 55.79738270851874, 59.28187908664827, 58.02682261313162, 54.06825288649529, 53.40037522777435, 51.90492453113679, 56.14497923081922, 58.078841086356874, 58.78669554187406, 55.43842700219924, 57.43192065146662, 53.220907180540024, 51.00519949390043, 54.16258196676932, 56.53591402115361, 54.777872408590014, 49.35077905654908, 42.808257764385594, 48.704643095693285, 57.49823616396997, 51.34401775175526, 53.31627176653955, 52.26419402707008, 52.70719043670162, 49.09384419841152, 52.08860128156601, 52.39311841226394, 46.50889242849043, 46.891629465164684, 50.65003671953755, 58.14024971377466, 62.69879694907897, 66.50868923433366, 62.564236117947495, 50.576045128606985, 54.29921380935177, 41.04370109496578, 26.724831865679835, 33.58268230192123, 45.1054330795042, 53.099050906396684, 60.60013278838127, 64.66513995201358, 59.38269184481714, 55.103554648737756, 53.92667493512554, 56.535615921020515, 62.98951518151068, 68.89764016674411, 64.99822370467648, 51.589146275674146, 44.64131470649473, 21.907149322571296, 8.297813323236282, 0.2591901903431262, 0.29417261481285095, 0.48089851775477016, 0.1504988920304083, 1.1657676389140468, 0.11137413056266886, 2.426331855597035, 56.79503756184732, 65.24614887852823, 71.72681439307429, 50.28027096102315, 47.65475796115014, 31.956571571288574, 49.22209001356556, 4.811597476082464, 0.8136105645568141, 5.769524603120743, 3.018950262377339, 7.647511805257491, 5.402297108404098, 0.32581697969186696, 0.4030287139598401, 10.301804215677324, 82.12558254118889, 68.30481313890027, 12.098558641249134, 32.97916681535783, 38.66602697680074, 2.4281040314705145, 2.5082625689045077, 1.1491703746780273, 13.90964932980076, 50.59354674431586, 45.6849632724639, 44.77225911232733, 61.375475545083326, 39.31013507227744, 51.08921666299143, 46.49337553208875, 4.457029921393241, 0.14362230296096495, 0.039518994144013816, 0.048910477499087016, 0.058521705514360825, 0.05820991155961829, 0.014990070185083297, 0.03584022844030011, 0.09186392424688225, 3.1315605294319893, 16.85015513050941, 65.77893618614443, 87.88300221966159, 83.71564080638271, 80.55286115215671, 78.36700270252844, 73.42576549899194, 62.102918317241055, 55.26758032460367, 62.24613581934283, 68.02437936106037, 69.03657051824754, 68.25159442040228, 68.75885102056688, 67.55336546128797, 68.34254633995795, 57.669098531046224, 57.8711005949205, 65.54199364877516, 71.39709211164906, 72.01914079727666, 69.55128746647989, 66.97762427791473, 71.9752259408274, 57.48115424186953, 56.857344412034564, 56.881392463561035, 68.35080685154085, 68.5139617612285, 67.12690184193274, 63.26498323871244, 61.03894795140913, 60.412667028365604, 61.97187192978398, 63.30737621553483, 64.6227587423017, 63.90055233432401, 64.11931468594459, 64.0904813428079, 62.684488142690356, 63.63662781253938, 66.07500060912102, 62.218926337457475, 67.00202926512688, 59.16500422262377, 63.4656556190983, 62.52183529638476, 62.177188396453865, 59.19934849585257, 59.23801914338143, 63.983910545226074, 64.6907098831669, 55.5732584768726, 50.638249997169744, 50.06349332870976, 43.84790551277899, 51.79308991278372, 57.77202936910815, 60.726511555333296, 63.78618386483962, 60.03662939994567, 52.81599698528167, 43.30350798945273, 47.49660407343219, 56.25422900722873, 61.492926997523156, 61.22868868612475, 55.48318909060571, 53.368462824052386, 42.30937542453889, 46.14229986744542, 49.9749772010311, 43.55353555371685, 55.801454128757605, 60.43427536564489, 62.16560563733501, 56.309632485912694, 58.342432206676854, 54.88385092827582, 58.83425428021339, 60.035586049479825, 62.05701481911444, 58.624340795701556, 60.850525133071415, 57.9121050527019, 55.35097775920745, 58.22053278646162, 59.61206028538366, 56.21948465224236, 51.92765858865554, 48.93048924784507, 53.685664899887584, 57.99168994349819, 54.55825498027187, 55.188736761769945, 56.87407332081949, 54.29238496288177, 52.39116114954795, 53.60396192919824, 56.12554388661539, 47.98722590169599, 49.298909633390366, 52.014994082912324, 58.740050715784875, 62.9317347465023, 63.256459928328, 62.442776003191554, 56.74120303123229, 61.99893236160279, 49.73910939308905, 40.396549240235366, 46.95849018712198, 56.048324185033, 62.811231690068404, 68.1381045618365, 68.20322375143728, 66.02808906186011, 60.123709940141254, 59.863652875346524, 63.28738781713671, 67.86010265350342, 72.84885544930735, 66.3936225829586, 57.68776509069628, 47.19578966017693, 16.606734798800563, 2.903067267710163, 1.3991915650906102, 0.532421056301363, 0.16757736673518536, 0.5519567273797528, 1.8865209313169604, 0.20782549655245197, 3.6375024001444545, 66.01505894814768, 72.3380922502087, 81.83346010023548, 59.072648094546416, 56.4042910452812, 40.562889114502944, 62.28645386234407, 5.38714450213217, 0.5985901540806217, 9.244353809664327, 5.172091732102056, 13.047195634534283, 7.748931550210523, 0.47429483984747245, 0.4036217273002671, 16.87090054635079, 99.82364623777329, 87.49738616328086, 36.65827551195699, 48.68541955947877, 76.03414950832244, 30.744382681385165, 5.386520845274772, 4.32550500477514, 35.42645908171131, 73.06644501224642, 65.51879282920592, 53.790529466444454, 62.022725459068056, 54.509378325554636, 62.305034129850334, 76.49596937241094, 14.491951657879738, 0.43339478452840163, 0.10915580040384686, 0.1757927557393428, 0.21033239671059195, 0.3189881332218647, 0.11365546379238368, 0.1565403992971105, 0.18522711320509835, 5.284679935824487, 24.207558631896976, 76.25757555807792, 92.41169237321424, 88.68037300725138, 85.65751998655259, 83.7264665480583, 81.09606235258042, 65.67592690067907, 63.02633447031822, 68.6642199177896, 74.05435669806697, 75.44971635264736, 75.77128010411417, 78.70518945878553, 75.54119386980611, 75.73547670918127, 61.41868045253139, 62.13511313161543, 69.32692789262342, 74.86733067420222, 76.82467183759137, 70.74793200339042, 68.82222867781117, 75.57986843970515, 60.85161947434949, 60.82100537515456, 59.60684745542465, 70.88526202786353, 70.16737414944556, 71.25329802113195, 68.73089236597862, 65.37486930047312, 61.73828694128222, 65.84469472208332, 71.10625620811217, 69.27256384203511, 66.3592783097298, 66.8802632054975, 68.53745675856068, 65.41941565852012, 68.24245529790079, 67.30074128796979, 63.1536820627028, 70.587491373862, 62.22214268099878, 64.9964782499498, 64.65663233110982, 66.65866498024234, 62.68610023683118, 61.81826799146591, 67.38563706797939, 67.91979328278573, 58.57545237387381, 53.649920340507265, 51.35045436120803, 47.65970406993743, 56.17009024466238, 58.16442720351681, 64.65726383270757, 69.91140027200022, 60.08335267343829, 51.56752617128434, 40.657308409290934, 47.221343901849565, 53.73200378110332, 62.48420015458138, 64.9196860867162, 59.73217502717049, 54.23256881775395, 45.93402201129545, 51.1423098656439, 49.65583747433078, 46.62275098985242, 57.34440472818191, 63.892954703300234, 64.43370834473642, 57.62308912892496, 60.510989081475046, 56.58345707001225, 60.30040879403392, 62.51923084259034, 64.60552777013471, 62.345540446619836, 63.75480490346109, 60.37138800467215, 59.43039178848267, 60.22110631389003, 61.44644298861104, 59.073915020112075, 60.940504304824344, 52.87948839126095, 56.83291589060138, 64.00072574615479, 59.158116540601185, 57.88686067827287, 60.245656428798554, 58.76066669341057, 55.62635167952507, 59.100049772570216, 61.28791647572672, 55.24834894364881, 54.39158170453964, 58.6361510522904, 62.827882151449884, 67.2033880602929, 67.82057300690683, 68.43738140598421, 67.07314183635097, 72.31235365713798, 59.26415389583957, 55.44108636917607, 58.02892500354398, 62.78175115585328, 65.33633201353013, 72.77924906822943, 70.70385240739392, 69.95744105308287, 60.5485849995767, 63.66615541519658, 65.4588903919343, 71.66913986206055, 72.0125041469451, 77.7063657391456, 62.50704011609478, 70.61082947638728, 56.23540163040162, 17.464761118735037, 3.513930824495131, 3.573059819398388, 1.0556131433094702, 0.3832056679792943, 2.9866676849703637, 0.722395662338503, 4.95385350719575, 78.11170347275274, 77.54277936873898, 90.02616959233438, 67.55680145755892, 65.15900165803971, 51.285499911154474, 74.71266377356746, 6.194194718714684, 0.7622864734261268, 25.24375665572382, 17.47598105861295, 22.393603632527014, 12.61991027862795, 0.7473089642101719, 0.7051429332744691, 16.98068572628883], [63.206426174409934, 72.34243823635963, 19.9267779627154, 41.78726480853173, 48.52153508893905, 11.913652227770898, 6.153904622600925, 1.5776155264146867, 5.5748372693215655, 58.0375934416248, 50.14436475692257, 38.27630419884959, 43.43849243656282, 38.39610515102264, 38.72491352019772, 25.997520492922877, 3.851001176141924, 0.04619976347913185, 0.01821868741253932, 0.030606476620080012, 0.017064221638945803, 0.09921644543928486, 0.017874681375800602, 0.044964511818703146, 0.3413321294130818, 3.2249823164555336, 21.016498688728582, 77.58205798364456, 78.87306690216064, 78.51053007187383, 74.85843473865141, 71.51938376888153, 63.83461336935721, 55.179197557510875, 48.13615045239849, 52.30339811694238, 57.90493103765673, 60.31683960268575, 58.33237524955504, 61.27119148931196, 61.26078151887464, 61.378648742552734, 56.55928350264027, 53.6257585402458, 59.64487875661543, 65.17546384565293, 65.846326428075, 68.99128283223799, 62.879849633862904, 65.1602921178264, 53.81826062356272, 47.00298163198656, 53.62031429044662, 59.998982491031775, 62.991382229712706, 60.4433556525938, 57.468241799262266, 58.25033887740105, 52.99898339856056, 56.287557386582904, 59.52692524079354, 60.81623185065485, 62.10176906278057, 60.91303594650761, 59.411615402467795, 61.723209350339836, 58.64128935721613, 57.638911970200084, 64.0614793377538, 60.64092936054353, 60.815015915901434, 61.33902103670182, 60.6346849472292, 56.027174765063876, 56.459192460583104, 55.262740119811035, 57.72843222464285, 53.33100026653659, 48.35547370295371, 50.773187375837765, 48.990019059950306, 42.44343026991814, 49.72711870747228, 55.484844330818426, 52.91289521801857, 55.59103858086371, 54.907483208564024, 57.88031816482545, 49.912321259898526, 57.03201147817797, 55.91948609198294, 55.392782380503995, 54.437210636754195, 51.5417169755505, 50.45579310386412, 41.994577761619325, 43.45311111019504, 47.93265788785873, 44.14830807716616, 46.87309626610049, 56.728176839890025, 55.911221658029866, 57.623493133052705, 52.90776868020335, 53.83227525218841, 56.30405095315749, 57.74673792623705, 57.76120362743255, 58.42382531012259, 55.23887641968266, 53.65759249656431, 49.33206542845696, 56.17750744665823, 53.830820052854484, 50.323993621333955, 46.26739994172127, 52.55478674365629, 54.85669635957288, 51.77465085060366, 53.13286173728205, 53.21074824179373, 48.35905874929121, 48.27268031335647, 46.27786090297084, 44.96996225849275, 46.022969599693056, 44.39509184129777, 43.56900145930629, 51.88999206789079, 60.33816552931263, 65.03259543449649, 67.22810683711883, 59.688487668191236, 39.25040521929341, 32.02129656268705, 26.66501964292219, 21.89542143575607, 28.956227071823616, 42.242683364499, 48.61535033872051, 51.3923688088694, 54.55966311116373, 52.49040495964789, 53.65402313970751, 52.62241625016736, 56.400623629170084, 57.96703392459501, 68.4406840416693, 68.95009010068833, 70.41740955845003, 61.45649994573286, 40.120590886762066, 21.774122138177198, 6.261711947379574, 3.152407926897849, 2.9558724213031033, 1.5103816889947461, 1.0564714069328, 0.31243443489074707, 9.460892177397206, 76.42555498307752, 63.114164183216715, 72.53609349650722, 47.40296925267866, 49.64449790216262, 41.54054380232289, 25.288246139403313, 3.4830495138322157, 0.8481341636469288, 4.892546371106179, 4.333918488794758, 3.910125513230601, 1.282057579486601, 0.2576735507576697, 0.23498205708399897, 6.443848186923612, 79.414165712172, 69.47536606942454, 20.486041268994732, 42.386638272193174, 53.56644445850004, 10.904557781834757, 11.150140320101093, 0.670112980709922, 17.019762339130526, 62.73020728941887, 55.61184675462785, 36.658138229000954, 40.906151417763006, 48.11266329980666, 48.703183973989184, 50.916475480602635, 6.4246236701165484, 0.24234341127016854, 0.06976947353612031, 0.10472188268097178, 0.05579324123720008, 0.11142322147685675, 0.016855330529412436, 0.12294890704534708, 0.18252907410985042, 4.705463042182307, 24.834194529441096, 79.05745752396123, 82.42190191822668, 82.98658986245432, 81.7575308584398, 76.8169447683519, 74.88163163585048, 64.30386220255207, 56.11141943162488, 61.39824098156345, 67.53027054571336, 71.86794127187422, 68.02335170007521, 70.87536981028896, 67.15968501183295, 66.9059076616841, 59.38752420486943, 58.43560026537988, 61.584047578996234, 68.15385680044851, 69.26606055228942, 70.01090295853155, 68.668667885565, 69.34129161219444, 57.44320923282255, 50.03176135401572, 55.62286077007171, 62.03959557317919, 67.041684427569, 64.4959955830728, 60.991922655413234, 57.56945856155888, 54.36704335674163, 57.33906246000721, 62.22502562307543, 61.91984561181838, 62.89631574384628, 63.423901988614, 63.52396949645012, 63.540823921080566, 61.19914147161669, 60.708507876242365, 63.7012331716476, 61.7166393803012, 62.267218559019035, 63.699017032500244, 62.56629536228796, 61.230516510625044, 59.114174227560724, 59.28834315269225, 59.886339864423206, 55.95776450249457, 51.1642437596475, 50.94568537127588, 51.88368097428353, 44.17395645572294, 51.39853869715045, 57.17118501663209, 53.52572241137105, 58.14663533241519, 57.19136168879848, 58.03637750687138, 53.14507207562847, 57.01410193597117, 56.12678335558984, 58.14541547529159, 55.285827190645286, 53.40844746558897, 53.068958482434674, 43.27682410517047, 45.11891818815663, 48.788205269844305, 43.91517416123421, 47.48089105852189, 58.0733262338946, 59.99721350208406, 60.98337973317793, 57.62850592213293, 56.8479032670298, 59.06397573409542, 59.71460280879852, 62.09397531324818, 60.1907903148282, 58.14618818221554, 55.75416995633034, 52.43519367710237, 59.53319711069907, 54.7808220309596, 54.78241059087939, 51.624090671539314, 55.9373014973056, 57.82545989559543, 54.785462194873446, 55.316813915006584, 53.47644567489625, 50.709342956542976, 50.28338924531014, 48.55090579678936, 49.17383309333555, 48.02555922539004, 48.95334097646898, 47.24924372088525, 53.76645395832678, 60.15659509166595, 64.0364153923527, 67.18772211382466, 60.38159793423068, 53.05700702051963, 50.19291193254533, 42.855589005254934, 32.59511970704602, 43.65456404224519, 52.856177745326875, 54.94339642986175, 56.98499794929259, 60.25284613332441, 56.41715249707622, 58.81203405318722, 57.016090577648534, 62.387635323309134, 63.787054631017874, 75.12962741236534, 72.13917316928988, 71.12679373833441, 71.19881629943848, 47.619892012688425, 17.032800297583304, 3.864158031440551, 3.04792064332193, 3.6882613022481245, 3.93419734412624, 1.185415771699721, 0.5514892298848398, 10.81608578082054, 85.32848019753733, 69.38563008462229, 81.90400000541442, 54.3336953655366, 56.54439418546615, 51.28782195429648, 38.08573192165744, 6.8809728084072, 5.063439626847544, 5.236142566127162, 6.717916448270121, 5.827512923748263, 1.3119171127196283, 0.3722902020860103, 0.5396379109832549, 10.917908549308779, 93.57954671305995, 98.7866892353181, 64.18165683746338, 60.95973176340903, 96.72091022614511, 52.04422358543643, 17.8122458534856, 5.404398027927646, 37.865118211315526, 83.6043082514117, 68.78011811164119, 54.274169475801536, 55.69971569122807, 61.06823236711564, 62.34561889402328, 70.01139717717325, 17.79461087719087, 0.34866429564933626, 0.13935974378499294, 0.18836853334740286, 0.21395965449271664, 0.22285598840925003, 0.08058756965422824, 0.1975311747481746, 0.9165973576807207, 7.738938331604005, 32.33688654438142, 85.87062235801451, 84.66046133349019, 88.18790374263641, 84.87966691294025, 84.54635958517753, 77.6961911109186, 70.81655779192525, 60.6088286830533, 67.56190053878292, 71.38436009806972, 78.73303044226863, 75.01654548029747, 78.76007910697692, 76.16502331149194, 72.41450002116542, 65.22780787560248, 60.21464224784606, 64.48217315058555, 69.96534070660992, 73.03310486578172, 74.6744441986084, 74.17071773159888, 74.19396954198038, 61.28652795668572, 51.662816232250584, 59.14775363860592, 66.45063815578338, 69.5892873887093, 66.60567375921434, 64.90537335795742, 64.19933888220018, 57.52508478779947, 61.95110297972157, 67.40801811218262, 67.24079962699645, 67.72982505060011, 66.24610224077779, 67.76408303168513, 65.36909164920931, 64.66699523310508, 61.98973048117853, 66.90932012373402, 68.31546629628828, 66.27859515528526, 67.61347970654889, 68.28658196233934, 62.150900671559, 62.039073897946274, 61.89642513951948, 64.37340974807739, 59.380024633099964, 49.9868227589515, 54.10927695612754, 53.769042722640506, 46.46847240386471, 54.66516310168851, 61.58389068418934, 57.04328829242338, 62.40429362943096, 62.35070620813678, 62.207747582466375, 52.25500391375635, 59.683690609470496, 60.182274849184104, 60.486544870561175, 58.557240809163744, 54.86925186649446, 52.00163056773525, 47.07610245673887, 47.69094182598976, 51.82809706657164, 46.6937223557503, 50.31419161827334, 58.619190723665305, 60.80278596570415, 65.47373656303652, 60.687895820986846, 60.33357243384085, 59.670056450751524, 62.879547611359634, 65.52952443399738, 64.84081898966144, 60.642878778519176, 59.615641409350985, 56.69655469156081, 60.97193817938528, 59.09623330639255, 61.697133433434274, 57.12386162050309, 60.3670733974826, 63.75999419919906, 59.47218856503887, 58.92912856994137, 59.618693013345045, 54.571528280934984, 55.49738807062949, 53.07438704275316, 52.34675599682716, 55.3664711213881, 52.9902365130763, 51.76936349561138, 57.71861060973137, 64.97276359988798, 67.43379592895508, 71.93795557945006, 68.43573401051184, 63.11288549054054, 60.12282740685248, 51.486921464243245, 47.972995542710834, 57.056020306002715, 61.36181000740298, 58.550286446848226, 60.74208336491739, 62.02150560194447, 59.52484638460221, 61.525568962097175, 60.27800813797982, 63.71390634967435, 66.49529826256537, 76.77754063760081, 72.92199196354036, 74.14355139578544, 73.72998452955677, 61.03646116871988, 44.01435129104122, 16.133352768036627, 7.104922004284398, 6.119684884625097, 4.410223787830723, 2.939787271522707, 0.9228736402526979, 13.563395238691761, 91.20532820301672, 76.35546222809823, 86.23104895314863, 65.73638631451514, 64.34359581239762, 67.10667810132428, 53.536909011102495, 12.193322124019748, 15.57833738865391, 18.4973721350393, 13.48578820305486, 9.672356959312193, 3.0887017711516354, 0.7690485170291317, 0.4834363218997756, 10.929580542349047], [62.53144118093676, 72.62118539502545, 36.26275154852098, 40.17482157676451, 64.93027256381127, 40.07280072858257, 16.84298307664933, 1.7521877202295488, 7.755163706118061, 49.6636704475649, 47.13864464913645, 53.65479584663145, 74.23368746234526, 45.91270000703874, 36.94678152761152, 37.790899122914965, 3.6926055723621003, 0.1297077254181908, 0.05401855642576853, 0.15752574158532007, 0.060658416665729985, 0.10710987833238418, 0.07936825645306418, 0.36362731048176367, 3.462627203233781, 9.68382400851096, 36.95103729924848, 78.71607011364353, 73.12455100397911, 78.38763436963482, 71.62396984715616, 69.32106002684563, 60.24001606049077, 54.51869787708406, 47.29683383818596, 51.62902109084591, 55.97225766028128, 62.57859591514834, 60.39964083702334, 63.00398480507636, 60.8564204554404, 60.64016449835993, 59.92074297320459, 55.004573637439364, 58.08075912537114, 64.41845816950645, 64.71829199021863, 63.86456458799301, 62.59537189237533, 62.081255066779356, 50.29973376181818, 47.42120435160976, 52.578320964690185, 57.32211782086281, 61.16044336749662, 59.865594448581824, 55.376120152012, 52.091758789554724, 53.372106705942464, 53.35779397718368, 54.51416361716486, 58.696657534568544, 60.256795960087935, 58.22152122374504, 62.369004064990634, 56.318524499093336, 54.996995618266446, 57.17771184059882, 58.045963779572524, 57.992956869063846, 62.00463941020351, 59.383825409796934, 57.73554740413543, 59.077213733426994, 57.097436612652196, 55.24919617560602, 60.91325559923726, 56.58244509850779, 58.23058582121327, 48.0347454163336, 47.540769961572465, 44.80705838049612, 47.517129836543916, 50.306307654226984, 51.07733580373949, 52.09601063882151, 49.03238065781132, 47.3668481457618, 54.961678597234915, 51.14898181730702, 46.339544096300685, 51.74585280879852, 48.97881677073818, 48.41929066565729, 48.72977372138731, 43.336075428993475, 43.71316033024942, 47.15718569294099, 42.848528738944765, 45.30892956641413, 49.515393087940836, 56.85111568820093, 54.92401207647016, 58.0784410045993, 52.94446637553554, 52.35039595634707, 59.5537660198827, 57.390955417386955, 57.62950612652687, 53.24353533406412, 50.58737293366463, 50.962041654894435, 46.877151996858665, 45.853444760845555, 46.65460848039197, 53.09753687151017, 53.516171440001465, 49.83021428508144, 54.18466883320963, 48.10683858010077, 47.3707587488236, 47.21136146976102, 46.068986846554665, 44.51322186377741, 44.94028168339884, 43.526247624428045, 43.17114368561776, 44.41084015753962, 50.49835866497409, 59.62345869310441, 62.071021602999785, 57.121041436349195, 46.30534495076826, 23.61647705877981, 15.422599680962103, 17.521015751746393, 19.90476562130836, 26.88240916498246, 39.510403448535556, 45.89964243673509, 50.00612474256947, 49.2440592089007, 50.71668171113538, 51.66082366820305, 56.1064850899481, 58.13955937662433, 62.28837190135833, 66.49251337974303, 68.99831956432712, 68.00076669262302, 72.94871114915418, 50.340871580185436, 32.284418959771436, 31.1889245048646, 14.100472638683936, 13.343026676485616, 9.352951492032698, 1.812969994160437, 0.516333332465541, 19.628919055384976, 77.55648413012105, 63.39632380393244, 75.64047690360778, 46.58796741116432, 55.465856136814246, 44.82325776930779, 46.87450439699235, 2.9453138910955, 9.265172769946437, 1.6853507776414196, 5.4683155013668925, 1.518165877749843, 0.24107504545921282, 0.09316599792650632, 0.1266591015061544, 1.5078643853625946, 74.94937096872638, 74.82027792161512, 30.433079850289133, 51.4807790325534, 68.71708562297206, 32.07502715049252, 15.394355673943798, 1.205595263069676, 11.464126052394992, 60.10236440166351, 49.51762099419871, 58.23270782347649, 78.18295724930303, 57.66145383158038, 48.43399955380348, 59.17574367215557, 12.117687059986977, 0.2603234795312728, 0.051176247652620084, 0.07664590938797883, 0.10248128234619096, 0.08979802260235434, 0.09426691989985206, 0.14790861086258966, 4.786740435707954, 12.98205683308263, 42.61345324977752, 81.33729596291819, 80.19996550775345, 83.2758411284416, 80.48116022540678, 76.44630432128906, 71.11346552448889, 63.09023380279542, 54.30383436141476, 58.496055756845784, 66.67883380766838, 69.83686739398588, 66.94965777858611, 67.89050102233887, 68.24444786194833, 66.71326437304097, 63.044400907331905, 58.574228594380045, 59.854768706906235, 67.66335656566005, 68.12006950378418, 68.99454624422135, 67.71950921704693, 66.44837887056413, 54.59485069397957, 51.25898076641945, 55.63026228258687, 61.36202966013263, 63.607143355954086, 60.61362966414421, 59.48341438847204, 54.97040194849814, 56.59444755123508, 56.60262177067419, 60.63795228158275, 62.38060251359017, 66.06954066984116, 63.53244181602233, 66.22996560988888, 60.11348432110202, 57.56539890843054, 59.24953522220735, 59.908289447907485, 62.55466945709721, 64.5576552421816, 60.00081423790225, 60.808183147061264, 61.23744733871953, 60.922783036385816, 60.79396847755679, 63.98637771606446, 57.77726965565836, 59.210676300910215, 48.877345054380356, 49.714237643826394, 48.26722429644678, 51.15735999999508, 52.73805556758758, 52.91469950829783, 55.55293275463966, 54.522859511836884, 47.98596289850051, 57.75295488296017, 53.48660853601272, 49.04602658364081, 54.73817802244618, 50.39377650906963, 49.92178201675416, 53.043278724916526, 45.98937449916717, 45.347372716473, 49.03957036233718, 46.08370750181137, 44.8819403494558, 50.51251842129616, 58.990031211606926, 57.5182794755505, 59.97886465441797, 55.43341421311902, 55.685053871523955, 63.43579461497646, 61.48350938673943, 59.004783245825, 55.786886445937625, 53.58769193772347, 53.658961403754454, 51.054429161933164, 49.860549895994126, 54.159377390338534, 56.64978434962612, 56.03929096652616, 53.09038639068604, 54.46283155871976, 52.08286285400391, 51.03401322518626, 50.85852246130667, 49.822110668305434, 48.06499865747268, 46.54718652848275, 46.81301339980095, 44.963125567282404, 49.44413538902037, 53.58021590017504, 60.15156269073487, 65.06898326258506, 63.74818002024005, 56.80130158701251, 42.86231979247063, 35.92123862235777, 32.798194539162424, 32.46307703756517, 41.17533191557854, 51.8337413572496, 52.29090144557338, 56.57572607840262, 52.64451096134802, 56.412943793881325, 56.1846814617034, 60.92248493625272, 65.44465611057898, 67.2496877178069, 69.77217966510405, 74.58926600794639, 72.92035241280833, 82.01269672762963, 58.76895466158467, 40.66267813405683, 29.75863026034448, 15.078073393914009, 17.02837586402893, 6.214475823986915, 1.5574737878576403, 0.2212570250154503, 21.597333069770567, 85.73316681769587, 66.7628509767594, 84.73197398647186, 51.22742137601299, 63.16799479146158, 50.71554030141523, 64.50823337801042, 11.60050097973116, 21.96518667282597, 7.2049473466411715, 9.124137086253013, 3.5498678251620266, 0.11961065593265718, 0.2120066971908654, 0.12498120807351605, 6.130719982808636, 82.77057709232454, 96.0996852382537, 84.30839723156345, 66.22799658006238, 96.5936920719762, 69.13512399119716, 28.836504567054014, 7.37304836511612, 24.010536016956454, 82.15343136941233, 65.31977568903278, 76.87705116887247, 87.58417252571353, 66.4891166071738, 62.452687832616995, 77.05989637682515, 31.816678277907837, 0.5546487603456743, 0.1007403705209013, 0.35510433717600765, 0.27806500333451456, 0.13603562699450603, 0.16806636065725358, 0.7455927433986819, 8.775558010224374, 21.480601372257357, 55.406243954935384, 82.85894809230682, 81.22672434776061, 87.0385943689654, 83.92896283057429, 83.00245192743118, 74.19966482347058, 68.08763934719947, 59.21740708812591, 63.10211073967719, 70.76784979912543, 78.98083794501521, 72.35094193489321, 73.61730267924648, 74.42969614459624, 73.20824653871598, 69.17520276961788, 61.703248408532914, 65.08533562383344, 69.35203890646659, 72.53991388505506, 70.42016306231099, 70.72160505479383, 69.47795483373827, 58.708118700212054, 53.29837399144327, 58.66414500821022, 64.74063773309031, 65.2857530501581, 63.72514394021804, 61.424183537883145, 57.754668958725475, 61.63065710375386, 60.375530027574115, 63.00453001453031, 64.24874897926085, 67.42224847116779, 65.65813895194762, 70.84599125769832, 63.98981763470558, 61.563651254100186, 62.482693964435214, 65.87347707440777, 63.48864070830807, 69.5271570451798, 64.07284244414299, 65.46158506024268, 65.19662503273257, 62.59496004350724, 59.90734023432578, 65.44855886890043, 57.51058770764259, 62.25947580029888, 54.44822072982789, 50.681070512340916, 52.08636553056779, 55.16113112049719, 55.04617429548695, 56.03752589994862, 59.573083692981356, 54.827611984745154, 51.63208838432066, 59.74472661172191, 57.56612846928259, 51.973044333919404, 57.7723470810921, 54.57847479851016, 51.89952342740951, 53.13389332063737, 48.01263501567226, 46.45983926711544, 51.36925820381411, 45.5899360102992, 48.14388144400812, 56.14410061990061, 59.05201250506986, 60.51758258573471, 64.18489279285555, 57.97820091247559, 57.31948983284735, 66.61114154323455, 63.9063770540299, 64.06852391458327, 57.864758122351866, 55.16357867948471, 56.072533053736535, 55.422553170111875, 55.73599369295182, 55.81756330305531, 59.93862898119035, 60.658768300087225, 56.94674307300199, 59.878267626608576, 56.12349248701527, 54.62376640688989, 55.65318853624406, 53.73474944022394, 52.0878795654543, 51.348555934044626, 55.27925722060665, 50.82079318261916, 52.77282345679499, 55.72123773636357, 63.04937055034023, 70.17634068765949, 71.02770682304137, 63.958415139106016, 52.39652302957351, 46.1418919409475, 44.744661315794914, 48.94875572573755, 55.01068076779766, 60.16462810577885, 57.78835035139515, 59.909878007827274, 54.86525497128887, 59.763899157124186, 58.908896984592566, 63.39158165839411, 67.30336927598523, 70.5427606644169, 71.6112692125382, 78.09205239818942, 75.29892475374284, 79.46839640217443, 67.70665953236242, 56.94632730176372, 55.684665556876894, 21.292943416103242, 17.135540900691865, 13.250237126504222, 5.393046688648963, 1.152721590572788, 24.773125187043224, 92.0103789914039, 74.5719212870444, 94.3218631129111, 58.85934175983552, 75.0116817412838, 58.950121095103604, 82.32322292943155, 23.46247107751908, 44.75644803816273, 30.188910345877375, 21.676243312897224, 5.61116430067247, 0.2724359424844865, 0.32100723455509833, 0.7269096362494654, 5.975483848202614], [40.760286315794914, 65.66955304914906, 60.09749674027967, 40.0871487586729, 55.01296750960812, 41.895078997458185, 16.01484423683536, 0.7399844894966772, 6.1804644619264915, 44.90128547914567, 48.17664500205748, 49.28425958079677, 70.01699047703897, 38.88844497742192, 37.77830831466183, 44.80624644987045, 8.0786719725978, 2.334800650996547, 0.020598501244920398, 0.04023689513785705, 0.0559942129128162, 0.07108065600116407, 0.11462562987881322, 0.6061290108388471, 4.171546582252749, 21.952462503986975, 67.38735506611486, 80.54468693271761, 77.62079531146635, 76.54799569037654, 69.94215165415119, 70.22041243891563, 59.3128187425675, 52.72639436106528, 49.71743437551683, 51.32702996653896, 56.47120668042091, 62.44715336830386, 61.595293014280266, 61.26657093724897, 62.43618642130206, 61.66901003929877, 60.747515847606046, 54.34574096433578, 54.40825962251233, 60.57129944524458, 63.561561492181596, 65.1983783321996, 60.569106840318256, 59.46887023987309, 47.20484641290481, 47.85122556071128, 49.835395736079064, 54.16009910645024, 54.37093434795257, 55.69909987911102, 53.33786049196797, 52.28996792147237, 52.83900168634231, 52.02924013137818, 56.539612816226104, 59.06392866565336, 60.64809160847818, 59.53598983826176, 63.20625751249252, 56.84492618806901, 55.01267333184519, 57.34363202125796, 56.93641547233828, 59.95180030022899, 61.11756401677286, 57.403722732297844, 59.572966021876184, 59.04943158549648, 63.89082877866684, 68.12574125105336, 59.097896391345614, 56.79333133082236, 48.7155786637337, 46.24634465863628, 52.1316885179089, 48.505021910513605, 45.44534567863711, 47.75694747124949, 50.020233508079286, 50.026528912205855, 53.43122466917961, 47.03991859189926, 53.407600233631754, 52.08560459075436, 50.152021223498934, 49.72437304835166, 48.26314110909739, 49.10053968429566, 45.58722565251012, 42.73784337505218, 46.3803328237226, 45.384490105413626, 44.56060409545899, 44.02851104736329, 44.25853060137841, 63.56018081788094, 58.11560153961182, 55.90824065669891, 53.74182147364463, 54.048735172517844, 54.31497389270414, 57.498353835075136, 56.7480867908847, 50.24362817887337, 50.36948134822231, 45.947099193449944, 41.557806153451246, 49.45976211178688, 54.98992750721594, 53.34723103430964, 52.40902754568285, 51.8736397066424, 47.60770913093321, 46.194479157847745, 45.6638373867158, 45.31524066002139, 46.84114856104697, 48.16524267196656, 49.41069718330137, 47.06280169948455, 47.88950004885274, 47.055255059273016, 50.72979027225126, 61.09101349307645, 59.85818901369649, 43.780581951141365, 32.11949898350623, 22.397488740182695, 12.949079505858883, 14.630688832652185, 17.768848749899096, 25.337862160898027, 36.19969160326066, 46.89392405171549, 48.30354152187225, 50.480025506788685, 52.05889324988089, 52.09369644041985, 55.56973226608769, 57.94122865123134, 59.5564293092297, 62.05083316372287, 66.08045270366054, 67.53041175103957, 61.257773060952466, 58.943378540777395, 35.68219761694632, 40.90733205118487, 30.222436804925245, 19.05221885250461, 8.515846114004813, 1.5075199522318379, 0.2143333368604222, 33.638011255571925, 77.69798755645752, 61.64837837219239, 67.74156078215569, 49.59930043066702, 49.01270997139716, 57.37442262711064, 49.87883598573747, 10.367760831309903, 23.458695796228227, 10.323956781818021, 7.299827029628139, 0.8330456636125042, 1.201567356624911, 0.348895654202469, 0.8176963872486546, 1.022102496316356, 59.12441945845082, 81.54251437033378, 47.405452112997736, 53.417723871046505, 74.38205503648328, 48.76196461339151, 20.096885273533484, 3.879731066765324, 7.677045291469944, 56.528434061235004, 54.579070998776345, 56.86609129751883, 78.46632496003183, 47.04896749988679, 46.9652170519675, 59.09234231518161, 24.929957236013106, 3.409954429634156, 0.15892156910511757, 0.14612100597831512, 0.041682020415582006, 0.028048284960189657, 0.0395483965985477, 1.060711243940938, 7.5648934514291835, 33.29421943233859, 70.51081688173356, 82.82099523851949, 82.45180606842041, 84.10337494265649, 78.66686005746165, 76.28444379375827, 70.3134589041433, 59.94869770542268, 58.78997072096794, 57.96937557958788, 65.69742933396371, 71.34407735640004, 69.7885202592419, 69.09332721464096, 68.35895753675892, 68.19766967527329, 62.41692758375599, 57.980515110877256, 55.844086370160504, 62.82348517448672, 67.14740014845326, 67.88829665030202, 65.6819438165234, 61.892294883728034, 50.60157975842876, 51.6522297551555, 55.08103239920832, 58.113263806989124, 58.3638483478177, 59.28583283578197, 57.36507954136018, 54.195086648387296, 56.37786603743031, 56.3412703237226, 59.72569134927566, 60.30593933597688, 65.28298385681646, 63.60268362106816, 64.90293364371023, 60.115296456121634, 56.06483344108828, 60.413592707726266, 62.348125288563395, 63.48423196423439, 60.38553599388369, 61.261589527130134, 63.15099131676459, 61.39861360672982, 65.52077362614294, 68.9134394737982, 59.563819054634344, 55.173086504782404, 53.98432593191824, 50.850442378751694, 52.890922100313254, 50.31266189390614, 47.31753218558527, 50.95242400323191, 53.690763981111594, 55.82287419226862, 54.60273073565576, 53.0238433807127, 55.845792601185465, 55.91474002407443, 53.515571317365094, 52.93726490389917, 50.6163945505696, 50.90173913586525, 47.93527803113384, 43.806842219445016, 50.157281121900006, 47.66457565369145, 48.49801263501568, 43.1770037066552, 45.502855470103604, 66.6027476710658, 61.97957154243224, 63.3102983813132, 58.33372454489432, 57.858215608904445, 57.193456234470496, 59.84734366017004, 58.45133681451121, 53.72938756019839, 54.08918265373477, 48.66065371421076, 47.88815859825381, 54.47710114140665, 56.92569171228717, 55.39211557757471, 55.065311539557676, 53.281233233790246, 50.428552243017386, 50.27818426009148, 47.24012028786444, 48.770876238423014, 50.00306137146489, 52.447058846873624, 54.902595935329316, 54.06181235467234, 50.116916010456706, 50.556668619955744, 51.20127093407416, 62.19725524225543, 63.982302373455425, 53.07199831931822, 44.775447999277425, 36.64193491781912, 27.894896461117654, 27.195143661191388, 29.948282741731216, 38.19137311750843, 48.07288262151903, 51.1282834699077, 55.368820621121316, 54.86574918993058, 55.71728398722988, 56.63629924097369, 61.07719890532955, 64.3520014516769, 67.72923669507428, 68.32133416206607, 73.31245606945407, 72.10782558687272, 73.02191826605028, 70.53637504577637, 47.57103104745188, 53.29357693272253, 36.95610500151111, 20.561276251269927, 10.211465166461084, 1.4021462129969753, 0.2491609196388914, 37.49377958236202, 85.11921390410393, 68.68143912284606, 78.51763740662606, 54.197922522021884, 61.650708260074744, 55.83430397895075, 72.00499673043528, 16.049907284398234, 40.079782547489295, 27.52376179541311, 3.2634921468073324, 1.4020305030768918, 0.6257633540418841, 0.11926252259722642, 0.5155342721169995, 1.7111534769496612, 53.162997307315955, 87.00090039160945, 88.31415699374291, 72.25707961666969, 81.01569298774966, 61.04320764541627, 33.39562446840348, 17.47760884223446, 17.321125884209913, 76.99802490972704, 71.64380919548773, 63.381175610326956, 84.02051095039614, 55.883055117822465, 62.19223853080504, 73.38385889607092, 57.199908533403956, 5.589677556868523, 0.3334022613783037, 0.315134680319217, 0.18388774636532032, 0.3198696552745758, 0.17732627990265049, 1.5030732101971105, 10.918233125440537, 45.630877710157826, 75.41504260032409, 86.6229643360261, 85.18433309370472, 87.27901212630734, 80.9870518407514, 82.22865458457701, 74.43146905591412, 67.03899368163079, 62.88118323972149, 62.45212693368236, 69.51451132374426, 76.14574878446518, 73.3477181773032, 74.28722781519737, 72.5843386496267, 72.99327711905204, 69.55102074530818, 63.17105816256616, 61.03187984035861, 67.6046073052191, 72.74694442749023, 73.41648517116424, 68.93130194756293, 65.11749513687627, 52.70920653497019, 54.66013070075743, 58.02302575880482, 62.875946875541445, 60.97311881280715, 64.0152189039415, 60.21364596582229, 57.41829041511782, 60.08233677956366, 59.13431559839557, 63.03499898602886, 64.25215359657042, 68.8879519124185, 67.63985372358754, 70.35609506791639, 63.096529206921986, 57.87633303673037, 63.645017762337964, 63.44800495332288, 65.28132469423356, 64.83285265584146, 64.57678856388216, 66.3184307467553, 67.24428269170946, 65.5878383113492, 72.8357861118932, 65.85884663366502, 61.622408359281486, 55.47465401311075, 51.885685305441584, 55.84154467428885, 54.66936003777289, 50.24678568686209, 53.68604536979429, 53.97591244789862, 57.33361821020804, 58.66917348677113, 54.03695629489038, 58.77913321218183, 57.46795938860986, 54.757683969313106, 54.03510493616904, 54.58083606535389, 55.1984485503166, 50.8745571105711, 46.908711387265114, 52.533609867095954, 50.697477786771714, 50.2719476915175, 43.852839854455766, 48.79382210393106, 66.8451109240132, 63.2938636502912, 66.94174243557838, 60.64403587772001, 61.13985092409196, 61.024423414661044, 63.98487937065863, 61.57984279817151, 57.83126500345046, 55.836610332612075, 52.958473159420876, 48.486374962714414, 57.0815392463438, 62.84612509512133, 58.57272632660405, 57.82746814912366, 59.998358834174375, 53.0507626072053, 54.31204388218542, 52.55591638626591, 52.51864602488857, 52.5678482363301, 55.91334758266326, 57.83890185817596, 58.06501080912929, 54.181036718430065, 55.383227486764234, 56.67851571113833, 64.27651936008085, 72.10738628141343, 63.89386861555038, 55.45912534959855, 49.18817327868555, 39.94121305404171, 41.44023702990624, 44.77561273882466, 52.256498336792, 56.43304986338462, 55.59663188072943, 58.3298296313132, 56.839854563436205, 56.51658850331461, 58.54667002154935, 63.23369841421805, 66.07647542030581, 68.71241015772667, 69.4349656566497, 74.62783859622094, 73.70721909307665, 71.8912793743995, 73.41353554879466, 52.43253038775537, 59.43927203455279, 43.230924529414025, 19.855184901145197, 15.15834273830537, 2.960693749689287, 0.3510035298043682, 40.023374942041215, 94.21390379628828, 74.47437194085892, 88.47937507014122, 59.072632405065725, 76.27020559003277, 63.76364592582949, 89.92854964348578, 35.814350112791985, 64.94610324982675, 70.617811295294, 23.95857245691361, 4.397290262483782, 1.9977388795345061, 0.7195160297616836, 2.1017089005439513, 7.2943528717564], [19.00655265777342, 54.488354421431026, 55.39520248290032, 43.08055262411795, 41.287354807699884, 33.47391105467273, 10.351735987970907, 4.5064184454179586, 4.342499654139242, 32.149793409532116, 50.12336046464982, 25.576465822035267, 51.074856865790586, 45.89516308999831, 44.04134112019693, 47.83153918481643, 14.272615659621454, 7.368958803915209, 0.1384792789336174, 0.11219405914626776, 0.07110893230644927, 0.03213090348928686, 0.124095426571946, 0.4897667515662409, 2.5018553772280296, 16.465949166205622, 72.56380111940446, 77.89412175455402, 76.64909870393815, 73.85822249997047, 70.03438226638302, 62.86099480044458, 57.6960648259809, 54.224006283667784, 55.07558422703897, 53.44689846038819, 57.57748373093144, 59.434525966644294, 65.1471168764176, 62.99217062611734, 63.32508571686284, 60.497354922756074, 62.91040097513507, 57.50289593973468, 53.723978611730764, 57.2185476364628, 61.554716094847656, 61.16500116163685, 57.45342308475126, 54.60374662953039, 45.6627744243991, 46.43026459601618, 48.93532945263771, 53.962250832588445, 52.18362854373071, 53.4363982754369, 50.34626483917237, 50.65205281780612, 55.24261051608671, 55.11781246431413, 55.95584254111014, 58.01001525694325, 63.059737374705655, 59.654739595228634, 59.79841993701074, 56.4760821865451, 51.080140298412694, 58.14168530125772, 57.20405840104627, 55.308204312478345, 62.333200670057735, 58.68220752285373, 59.66056431493452, 57.92950468678629, 59.93397705016598, 53.33927646760018, 46.34174062359718, 51.763040634893606, 53.4839609361464, 50.667938417004, 46.54929676363545, 49.58727052134853, 47.015019386045395, 44.88630594745759, 45.82985954899942, 53.85375022888184, 50.91856218153431, 51.20907645071707, 58.49272958693966, 55.80481952236545, 52.38668180281117, 50.51405206803353, 51.23640360370759, 46.85772841976535, 43.54842862775249, 45.63600817034322, 47.538130206446496, 44.47207227829964, 52.38339485660676, 47.72751400547643, 43.44582726878505, 48.787848334158625, 54.852766144660215, 56.461130111448234, 57.281368317142615, 60.37411405194191, 53.88335627894248, 53.75636562224358, 51.61425336714714, 50.56568222661173, 44.15024572803129, 44.98108217793126, 51.84402973421159, 56.54578662687733, 53.16324441663681, 51.47152223894673, 49.49798953148627, 47.21142422768378, 48.60741538386191, 45.5209925097804, 42.9942447908463, 45.57439950204665, 50.0177663372409, 51.31688671727335, 53.69739278670281, 58.08345379367952, 57.232950579735544, 57.74520820186984, 52.98089734969601, 56.360384033572295, 54.887655627342966, 39.23644942622031, 30.644215153109645, 22.530504157466275, 9.782907001433834, 17.075540404165945, 21.17797482398249, 29.61063531137282, 36.35287977034046, 45.08507205593971, 48.236421923483576, 51.778836019577525, 51.00230478471326, 57.46834378088675, 58.50009579812327, 66.65437390727382, 64.66851711273193, 65.83902297481414, 66.46727685005435, 70.18613092360958, 63.96213746839955, 61.33984865680818, 44.16651571950605, 47.10994466658562, 40.91145446223598, 24.31209960291463, 12.017434220160208, 0.801038510136066, 0.09343619713740003, 43.089170071386526, 75.10377114818942, 56.46921411637337, 63.357041266656694, 48.82323988022343, 43.11370841918453, 70.25471748844271, 39.82841353262625, 23.593607679490123, 34.37167098445278, 29.012744503636515, 21.64039088833717, 10.808072378558498, 0.7644870456668639, 1.5024813000232944, 2.9488263735848093, 2.923784736664065, 34.7794327428264, 72.03590500739314, 61.283801909415956, 54.05825084255588, 60.91289474118141, 46.22407344079787, 17.296381611977857, 7.340979556883536, 4.318279018325191, 41.41881304402506, 59.70569902850736, 40.39490184476299, 61.674203257406916, 52.62734274710379, 53.84900416097334, 62.5342966664222, 35.25262748041461, 18.01139439305952, 0.15238512307405472, 0.08939079324444456, 0.1129954330803406, 0.06874890652515235, 0.060125644649228746, 0.49865885667743226, 4.145567253712685, 29.630154986535352, 80.02167024920064, 81.76388509811895, 82.8087809778029, 80.71002268022107, 79.15536772820258, 72.14845349711757, 64.25645643664946, 60.642200208479366, 60.42824668269004, 60.502073534073375, 65.5705955720717, 68.99015318962836, 71.10812325631419, 68.00697188223562, 69.82757922141784, 66.90826892852783, 67.7208585123862, 60.84768925943683, 55.0097825450282, 62.24988560522757, 63.06271837603662, 63.032119966322384, 61.9497811409735, 56.05540406319403, 48.03591820501512, 49.87533723154376, 52.66248718384774, 57.1586726557824, 55.38562013256935, 55.90009389385101, 56.02870841180125, 55.015662177916504, 54.83267184226744, 59.64281951227496, 59.951168798631244, 60.634967357881614, 66.26221533744567, 64.85789306702154, 65.06135817497008, 57.8473820224885, 52.848725241999475, 60.94014344676849, 59.696634431039136, 60.268472856090916, 61.09063694553991, 59.80834745591687, 61.30046413790796, 59.71611292131486, 61.89139666095857, 54.59610193006454, 47.846593241537775, 54.04467551938949, 57.32755814829181, 53.94988752180531, 47.286341497975016, 49.749786084698094, 50.14159948595109, 48.95787523638818, 50.07597823296824, 57.60447748245732, 54.65227419330228, 55.44290634893603, 60.792477976891306, 58.86502919658538, 55.42201580539827, 54.11599597623272, 53.78098633981521, 48.71293498623756, 46.527229509046, 48.89951821296446, 48.71966577345326, 48.0793623770437, 55.19124315631006, 49.35302657465781, 44.988632740512976, 50.081744117121545, 54.159145970498365, 60.74897496931015, 60.37369828070364, 62.85449543306905, 57.965170798763154, 56.868272135334635, 53.021890040366884, 53.11795673062725, 47.768828330501435, 51.199297981877486, 55.53110084226055, 57.986845816335375, 56.3816079785747, 55.23092969771355, 51.157261940740774, 50.748641183299405, 49.783514545809844, 48.15226747143654, 45.37094616120862, 50.5830426369944, 53.03927790734076, 55.910809809161776, 58.99158054782499, 60.04518408929149, 57.37913339368759, 59.69020566632671, 53.53152751922608, 56.28387035862092, 60.78231903814501, 48.528701259243874, 41.3634370219323, 36.30623494425128, 26.70124469264861, 28.553736978961577, 33.164051655800115, 41.25912158719955, 47.035643208411436, 50.38226827498406, 53.40783557584209, 54.0714535405559, 57.82841736270536, 62.152944226418775, 63.802810792000066, 70.84069605796569, 71.71673390173143, 71.61428159283054, 73.64934059881395, 77.16465503938737, 76.36291473142563, 72.84006149538102, 57.71018535860124, 59.67022903503911, 50.333811313875266, 26.208463599604947, 13.432397880861837, 2.1413446962833405, 0.24703988264645302, 50.40012682637861, 82.07383078913536, 64.3637607174535, 70.2566316050868, 57.298320801027366, 59.04188494528494, 64.44292199227118, 55.24138673659294, 38.55036412515948, 59.29346184576712, 49.956875462685865, 14.312468901757272, 2.9741148746782735, 0.5922403883549475, 0.22686245971389357, 1.5593717247247698, 4.537653749988926, 26.449909017932033, 68.94386922159504, 72.4577872983871, 74.81611236449211, 64.23779772173974, 52.064266897016964, 30.900720511713338, 17.19264276566044, 11.935013455729331, 58.157104138405096, 80.37599363634664, 41.55762180205315, 68.43582030265563, 63.16626502621559, 66.52665368972286, 75.11018814579134, 62.25029745409566, 32.924512509376775, 0.3558904353168703, 0.2862620521937647, 0.2125857064440366, 0.14877314108514017, 0.3832319601168556, 2.000520085134814, 8.126991650750561, 44.90523138353902, 87.80412335549632, 83.53156397419592, 84.79219021335726, 82.57209731686501, 81.16042844710812, 73.76302657588836, 69.86535164617723, 65.09625158002301, 63.89272720583024, 62.58300465922203, 67.87466249158307, 71.63939260667371, 77.21736384976295, 72.0456873986029, 75.0590169045233, 70.07016997183524, 72.41183280944824, 65.3906293838255, 59.714496904803866, 65.50815536129859, 67.11962192289292, 65.32272138903218, 65.42723294227355, 61.25803193738384, 50.936722755432136, 52.777820556394516, 54.90303524078862, 60.98226970241916, 59.02027660800565, 60.67252405228154, 57.40877474507978, 57.50344899392898, 60.50427790611022, 64.80088926130726, 62.59423440502536, 65.39164527770012, 71.97091133363786, 67.53341628659156, 66.73259381325015, 59.73895288282826, 54.143813425494784, 63.20057399811284, 61.562066616550574, 60.733983670511556, 65.72275215579619, 63.48989586676321, 64.74107703854962, 64.26903155542189, 64.71378126452046, 56.31595534663047, 51.64956254343833, 55.63414150668729, 58.2827494221349, 57.16840013380974, 52.75805965546639, 53.71760083783058, 53.188457412104455, 51.09941482543946, 52.26104436382171, 63.568837488851244, 57.38856277158184, 59.3317049549472, 64.11227403148528, 61.74004808548958, 58.15096562908542, 56.85976059206071, 56.506504089601584, 53.52737372921359, 47.90766062275056, 50.878730512434444, 50.572334566423976, 52.61436362420359, 58.66467845055365, 50.64725968145555, 46.131505504731216, 52.773870729631, 59.07945340679538, 64.63618501540154, 63.19364709238853, 66.64386979995236, 58.10914139593802, 59.54501521202826, 56.141080394867934, 59.99585243963427, 52.57176668413224, 51.52335243840372, 58.62607056094755, 62.14200865837836, 60.3321486134683, 58.08459128102949, 55.198825097853145, 54.90751066515523, 54.72196686652399, 53.86085756363408, 50.627549771339666, 53.396476391823064, 57.74369024461316, 58.821416362639404, 62.1810519310736, 65.00827281705796, 64.3406658018789, 65.402545544409, 55.90078030863116, 60.536876724612334, 66.25217406980454, 59.15295077908424, 55.338532078650694, 51.04135590214884, 40.20562394972771, 45.852087620765936, 49.085646444751376, 55.48526402442686, 53.57945496036161, 53.43938319913803, 55.327133670929946, 56.63909981327673, 57.997063590634255, 63.54507969271753, 63.72507725992511, 71.86433269131568, 73.0506221709713, 72.89502174623551, 75.64016311399399, 78.84755580655991, 76.76735031989314, 74.26978895741125, 67.19641408612652, 65.1387700726909, 55.286843084519916, 26.559160755526637, 19.136467441435784, 3.156645557572765, 0.2924017566106012, 54.34540364050097, 90.13467019604099, 71.68378599228399, 79.85702483884751, 63.51890179418749, 69.75773749812957, 72.1494968475834, 61.49900274892008, 70.15371645650556, 84.15921380442958, 77.63014624195715, 37.07496850721298, 16.734209868215746, 3.8840586668060677, 1.4044790426569602, 9.779734784556974, 17.66428032229024], [3.5851439064548867, 30.57950585119186, 42.87793867049679, 40.60848666775612, 40.60821602421422, 28.104957034510953, 6.169462213593145, 5.610451409893652, 3.7721254989024136, 21.6979379423203, 48.0307367540175, 22.047185782463323, 44.539293858312796, 46.42357695487238, 52.91018878259967, 55.344788259075536, 21.576309165646954, 0.6409924465321726, 0.06415704828536799, 0.15351134893153945, 0.11586427147830687, 0.020318858085140105, 0.4846909900586452, 0.8642764329429596, 4.528996588722352, 35.29362801582583, 81.39739451869842, 79.2576317633352, 79.39934699766098, 72.86206599204772, 67.75328866897091, 65.02458987697479, 59.68588713676699, 56.108618859321844, 54.509876466566524, 52.611468915016424, 57.24921664884014, 60.80145628221574, 63.45130758900797, 64.50542496096703, 66.4825584042457, 63.80818443913614, 63.07361472037531, 60.550781526873195, 55.00557776420347, 51.61408078285956, 55.388412860132036, 56.22985932134814, 52.24153057221444, 50.3261273907077, 46.56605705138176, 47.399980406607355, 48.20366621017457, 47.991069824464866, 49.52517940152077, 53.551437470220755, 49.71413173983174, 51.36679887771607, 50.7311160333695, 53.82674863261562, 53.576128790455485, 58.23954843705701, 60.39791499414752, 61.339530944824226, 63.317958770259736, 57.66110081826487, 52.22893191922096, 56.275543166745095, 55.0347327416943, 56.1025470302951, 55.05181074142457, 56.908280311092255, 59.082277513319454, 55.14030725725236, 47.55243901283511, 44.82387750379501, 51.30004013738325, 50.10934583602413, 54.33515056487053, 49.50909768381427, 43.9781125130192, 47.981283510884936, 45.8382651882787, 48.55505566443167, 43.691320573129964, 46.162582443606475, 49.491988305122625, 49.48121355425928, 56.10819132097306, 54.692807966663, 49.968038528196274, 47.69165569736112, 49.26347886362384, 45.92409057001914, 45.48884868621827, 43.51594355798537, 45.01362608325097, 44.347803746500325, 48.01287428025277, 50.75157119381813, 40.37922020881407, 33.68695459058208, 45.60556665543587, 48.04569275148454, 52.31003868964411, 55.15145071091191, 58.04240618982623, 56.761626812719534, 52.19997698260892, 51.02011626766574, 46.98468377513271, 50.2482722651574, 57.642548007349816, 50.8349568613114, 53.92853806095739, 52.56397685697002, 49.9170712501772, 46.908048506705995, 46.33979905036188, 45.65438839697069, 44.066510969592684, 46.41924665820214, 50.885292637732725, 56.94779426820817, 55.853547127016135, 58.86733162787653, 59.46350443747736, 59.798310110645915, 60.02612137025403, 57.88309912527762, 53.626864648634395, 42.951734142918745, 39.248193002516224, 29.20365606584857, 20.323645337935417, 25.466372736038704, 27.784872016599103, 36.5134027696425, 42.26548802468085, 47.73873590653943, 49.26296111076109, 52.81862105092695, 57.352767221389286, 58.50957224445959, 63.25890356494535, 66.52828539571455, 67.03315719481438, 68.30068680547899, 68.34907316392469, 67.45493750418386, 64.83614744678621, 68.09289532323038, 55.74637228442777, 53.092398566584436, 55.87059767015519, 30.14739597997358, 13.637901640707447, 1.3767027782817043, 0.6712887724561076, 54.25027047434161, 74.08750072602304, 57.33273567691926, 64.88423178272863, 45.8020224878865, 37.56627282788677, 62.610072935781176, 26.309262629478212, 24.390431296440866, 15.931874340580357, 33.014350475803504, 24.279057556583037, 4.8706482687304105, 2.931749599595224, 0.36861552346137266, 2.903519566020658, 2.055585872261755, 9.03068857808267, 50.60699655163673, 59.044854179505386, 50.639924849233324, 49.521476684078095, 39.03718517672631, 14.229337207732664, 8.279063413220069, 2.5717434335139493, 29.249381096132343, 56.518024090797674, 31.318603946316628, 54.25023125063989, 53.00278809762771, 60.59579072460052, 68.38223288136145, 41.65088007527013, 12.074073245448451, 0.2138226013630629, 0.04493678709672344, 0.14424176165653815, 0.10884226359907659, 0.11155076745537021, 0.6418071963614034, 3.920401142489526, 47.98475873085761, 84.66973381657755, 81.92655363390523, 84.73540998274281, 77.56238337486022, 77.22549884550034, 69.65454778363629, 66.36077665513562, 60.68330272551506, 61.101258723966545, 56.994799952353205, 62.6690379265816, 68.54008474657613, 71.16021233220255, 70.21568206048781, 70.48286607188564, 69.56851451627671, 66.96293107924923, 63.681578174714126, 58.22084265370523, 56.686482044958304, 57.19639016735939, 60.17256698300762, 56.0618838187187, 53.17507036270634, 50.34653156034408, 49.52106091283983, 50.868963810705374, 51.697078135705766, 53.222185873216205, 55.66787781253938, 52.54488668134136, 54.40697700746598, 53.633658193772845, 56.7585281402834, 57.484127398460146, 61.80574778587588, 63.418418515113096, 64.48152595950712, 68.3794479985391, 62.078046567978404, 55.69442833623579, 57.360949285568736, 57.605552211884536, 57.828476198257945, 57.166701747525124, 61.79167039932744, 63.735671581760535, 58.1585907167004, 49.949368046176055, 49.49374160458965, 54.2552597292008, 51.49376992256411, 58.47057211783625, 51.40484979075771, 45.13331720905919, 48.698814453617224, 47.60479480989518, 49.78812333076231, 46.78816518475933, 48.71740256586383, 51.74424071465769, 52.64783320888397, 61.74384886218656, 56.6627085593439, 50.85624356423655, 50.51322444792717, 50.12478820739254, 48.02635154416485, 47.01114408431515, 46.15558885758924, 46.16618317942466, 47.06497861493019, 50.9730125242664, 55.287380449233524, 42.188029058517955, 36.59660016336749, 46.78187370300294, 50.18906408740629, 54.45544181331512, 56.860835321487926, 58.7702686555924, 60.10414123535157, 55.119420636084776, 53.09040992490707, 52.4039480763097, 51.01636648178101, 57.96058162566155, 54.46513006764074, 56.311750565805745, 55.78230119520619, 52.41422076379099, 49.937208698641875, 48.24535316036594, 47.620299939186346, 45.746222849815126, 49.99365945016184, 53.643146407219675, 57.95326248292, 58.4421859248992, 59.12541574047458, 62.12795088368078, 62.566342430730025, 62.5389446750764, 61.279879539243645, 59.778058913446245, 52.51463344020229, 50.55109100957071, 41.459342895015595, 35.86654117030483, 36.1208245062059, 38.78488656013243, 45.743677231573294, 51.05992832491475, 52.404799230637096, 51.283840748571585, 56.948821929193315, 59.43519669194376, 64.83287226769232, 66.21207960190313, 71.14224787681334, 73.65675387843963, 74.0642567603819, 76.41720817935082, 75.57047828551262, 75.04867753674908, 75.56653238111927, 68.6079417505572, 60.90519905090333, 66.80223941802979, 34.945474516960886, 14.733849129369183, 1.9216414661176744, 0.6869544737762021, 65.6874272900243, 78.16356505117109, 68.54701949704078, 68.3188081556751, 57.86118484312489, 47.18708984313473, 65.45725868594262, 46.25554261669036, 50.32821801400954, 47.23305217681393, 46.46306737776726, 26.052963195308564, 11.798528702028337, 1.5347420592461865, 0.33849503003781845, 3.565980431533629, 4.038144076062787, 5.087166534316156, 40.52975293128721, 53.72368051159767, 57.84591113367389, 52.388937165660245, 43.670069171536355, 21.74473770203129, 13.711196030339888, 10.034453503547176, 50.98730171880415, 81.21638497998639, 36.68456323685185, 61.44860029220582, 65.24510945043257, 73.04254208841633, 80.05217059966057, 61.32663811406782, 31.327295918618482, 0.5214023830429201, 0.3034811040326473, 0.23453296102102728, 0.28194459515713877, 0.510981135791348, 3.0870193194958473, 18.08251088665378, 65.50283662734493, 89.25007374055924, 83.74596072781472, 86.33474073102398, 78.44737991209954, 77.73992553833993, 71.94610626466813, 68.80999872761389, 64.73072982603504, 63.962337509278335, 60.08214458342522, 64.23892736434937, 71.50667528952323, 73.62170357857981, 74.3620901723062, 74.10477484426191, 73.05705485805389, 71.70039330759357, 67.92388039250528, 60.5167196642968, 58.465316141805346, 58.70376094695061, 63.21489849398213, 61.45114983281782, 57.79596759426979, 54.86982845490979, 51.77005775513188, 54.49191985591766, 56.80969545918127, 56.36220009096208, 59.220713646181174, 55.2905144230012, 59.72755839747768, 55.389448365857525, 60.528031779873764, 60.198674278874556, 64.79381722788658, 66.86007868859076, 67.53049804318336, 72.01714823322912, 63.88249374205067, 56.45108492143693, 62.82344595078499, 59.736356273774184, 61.622663313342684, 61.76547288894654, 63.6850102486149, 66.43703537602579, 62.5501234300675, 53.91918713046659, 50.56941632301577, 54.69216469795474, 54.21887582348239, 61.36416342950637, 54.1940668321425, 47.55978561216786, 52.28067190416398, 50.53246759599256, 52.68148714496244, 48.169765164775235, 50.996201576725134, 54.898795158632346, 53.97289222286594, 66.11742496490479, 59.6381675812506, 53.46310961631037, 54.746458145879934, 53.08539321345668, 51.01783737059563, 49.10452089002056, 48.83155530498874, 48.7135664878353, 50.37418427005891, 53.47086806451121, 58.02951728144, 42.49909262503348, 40.44986209561748, 46.630540817014634, 53.27596156827865, 57.511242743461366, 61.49203269712387, 61.486223666898674, 63.23736583032916, 58.43290167470133, 57.23194253060126, 52.779016879297075, 57.532086218557055, 61.2355096878544, 56.185901318826986, 59.439966294073294, 60.727209737223966, 56.862941634270456, 52.553700247118556, 54.34902791054019, 54.05272030061292, 51.06646299362183, 54.16976382655483, 59.70163153063867, 62.487130165100105, 60.63969381393925, 62.45266037602579, 67.32573463070777, 66.79933686410227, 65.57254106767716, 63.99120615374658, 63.38287791898174, 60.785347107918035, 63.52325562507876, 54.235232107100956, 49.40792406758955, 52.59547348945372, 56.80614963654549, 55.78951835632325, 56.84585971217002, 54.73445569315265, 53.513017854382916, 58.62501544337119, 60.763417136284616, 65.74305434380808, 69.46071209446077, 70.19097897314256, 75.03643974181145, 75.14232020224296, 77.17056997360723, 75.8146458287393, 76.46834804165748, 74.02217757317328, 73.73642506137972, 69.00059453902706, 70.59511646147698, 35.44029328130907, 23.075882273335612, 3.3659795118916422, 0.7205884302816083, 70.79093686995968, 85.26252946546002, 74.66961183855611, 78.75070464226508, 66.19220887461017, 59.321243993697635, 74.552427107288, 51.97147930822065, 69.74368756817233, 56.089505149472146, 45.631375851169715, 31.35448382746789, 26.497836459067564, 5.919071830088093, 3.0807271022950453, 11.049869829608548, 19.747811978863133], [0.06765645748424916, 5.793157373705219, 21.507942253543487, 27.74482853950993, 22.049362697908958, 13.131495214277699, 2.615453591269832, 3.3010022630614624, 3.623720907395886, 22.121736311143447, 38.96217769192111, 31.076579978389127, 38.573164862971154, 41.8946240025182, 51.70280871852752, 63.22189207999938, 30.95001489885392, 9.731348426111284, 0.10328087129540021, 0.28426378845207156, 0.03811734818643139, 0.049795512064930894, 0.9111364990953477, 3.4632905740891737, 8.708346236136652, 59.97106306014523, 79.61099809215915, 76.7296249635758, 76.0957307200278, 74.33449237577378, 71.77953104819022, 68.47674631303357, 64.1941378193517, 57.64325403398084, 53.34765857265842, 52.59375549131825, 54.69488682285432, 58.36646849109281, 64.0967022219012, 64.29586448977071, 65.65650724595594, 65.68557985367315, 63.92010927200318, 60.64136082126249, 59.177889208639826, 56.90804104651175, 50.56293656749111, 53.92692988918674, 49.08037085686961, 47.13817788708595, 47.16017846138247, 46.121789793814386, 45.732141540896514, 46.89390443986463, 48.552819913433446, 49.21578284232847, 50.9382995482414, 52.474884140876036, 54.855315685272224, 55.84501989426152, 57.413403141883116, 60.6295701765245, 57.61746052772769, 59.95891155735139, 62.923721344240256, 59.35964399768461, 53.68615127378895, 56.72624311139507, 53.83190262702204, 53.94377254670667, 55.61992291481265, 58.76223956384967, 58.348182401349476, 55.97393643471503, 49.59638218725882, 43.290846578536495, 49.55067873001099, 50.253088935729004, 50.60654547906692, 48.85099064919257, 44.956477149840325, 45.678052056220274, 43.97447647586946, 46.850589706051736, 44.228944163168634, 45.40392152724728, 44.524275102923, 51.29152859410932, 55.385918232702444, 53.951319186918205, 47.767169167918546, 46.76685494761313, 42.77096386878721, 45.1976127009238, 45.29928838053058, 42.34288423292099, 44.170022318440104, 43.230995132077126, 50.5657136055731, 47.5083907958, 47.59812678060224, 46.58228389678463, 42.36678715675108, 47.736307959402765, 50.09797096252442, 54.68770104069864, 54.33460143304641, 53.422842564121375, 49.7691822052002, 46.18221782868909, 52.634128447501894, 48.54462608214348, 49.28708368732084, 58.54669747814056, 50.21111565251505, 52.847226896593654, 50.6509506317877, 46.58736336615778, 46.31271900669221, 44.70906188411098, 41.84538256737494, 46.06403289302703, 50.21373579579015, 55.02283619296167, 59.57277382573774, 58.89965980283676, 61.278526321534194, 62.45588456430743, 64.10808886251142, 61.16002367388818, 56.462506863378714, 51.12111729960288, 51.957370542710834, 43.09037031665925, 30.96499639172708, 40.501472642344815, 44.29267091135825, 45.318798249767674, 46.149426814048525, 49.126796030229144, 51.40859957664244, 51.6411647488994, 56.985009716403106, 62.67754946985553, 67.55683283652029, 65.3859107725082, 67.06428512450188, 65.83943874605241, 68.13558640018587, 67.71859922716695, 68.71442625599524, 65.66394405980265, 71.65232073876166, 61.14119237469089, 67.3172152426935, 50.70707974895355, 14.558482900742563, 0.5031833413147158, 2.9219502931640995, 61.57765411561536, 66.19573900776525, 53.08221217124693, 57.369723627644206, 46.29854748325963, 27.564401472768477, 47.891716188000096, 29.36722674677449, 29.321442880938132, 42.037151167469645, 47.17582087362967, 20.061056383194465, 5.029447876637982, 5.997937946550309, 1.5685835336485219, 7.842806616137105, 2.6017826603304957, 0.7114938021667543, 18.478474155549083, 36.30300291122929, 41.36718288544686, 34.16519741858206, 26.705841710490567, 8.567057559567115, 5.5375561214262445, 3.286448063388948, 27.347829764889134, 54.05141415134553, 33.79549441799041, 44.940532715089866, 48.10801529115247, 63.465357518965206, 73.51947092240857, 50.36324085727815, 20.55492593396095, 0.08693039462330841, 0.13381522839828847, 0.1174459825720518, 0.036718758919666854, 0.9889087645757584, 3.2734576636745087, 10.150276191772955, 68.86405683332875, 82.23744853850334, 82.62747333895776, 84.29029941558838, 79.90245373018327, 75.38324786770728, 75.37581105386057, 70.94448197272517, 64.7087606306999, 58.144823197395574, 57.22057942421206, 59.90916413645591, 64.46533833780597, 67.9520430103425, 68.87781650789323, 69.82874808772918, 68.45932314472815, 68.1248861743558, 63.94977807998658, 62.83138875038394, 58.69124074136057, 52.86398718433996, 56.254503573140795, 52.45810424127887, 51.82086813834406, 50.5366409978559, 51.325209986779, 50.71156694043068, 52.31594970149379, 51.90248873925979, 52.67247746067663, 55.08313086725051, 56.790915150796216, 56.833684675155155, 60.69383036705756, 58.132659927491225, 62.49801866469845, 64.49960416363132, 64.04771181844896, 64.24907453598516, 62.949412868868926, 58.3604201962871, 58.942256742908114, 56.98945768417851, 55.71942167897379, 58.36855911439466, 61.55355115090648, 60.46579945471979, 58.366778358336425, 52.72539807904152, 46.59825971049648, 52.2117676273469, 53.61295200163319, 52.65652910355599, 52.03609251206922, 47.04765742824924, 48.80145895865656, 46.7055247675988, 49.67008352279664, 47.12259823276151, 48.47322717789681, 47.683057861943404, 53.17970660425002, 58.291037390309, 56.75333884454543, 48.94056581681775, 48.31084889750327, 46.428868232234834, 46.68460676746984, 47.12119010186965, 45.23373380784066, 47.57243917834374, 46.518561070965184, 49.35093595135597, 49.7907042503357, 48.77923480926022, 48.454140924638324, 43.5634316936616, 49.8219733853494, 51.82667716856926, 55.522369646256976, 56.73528417464226, 54.65431774816206, 54.0186192143348, 48.43074006419028, 52.594175184926684, 53.44481175945651, 51.41123148702806, 59.96082175162531, 54.38145414475472, 57.0620019205155, 52.16664468088458, 49.78623667070943, 48.66324247852449, 47.55722038207516, 44.244151192326704, 50.05517790394445, 53.452974211785104, 56.97123435235793, 59.98120630941084, 61.53091123027187, 64.93633654809767, 62.55131190822971, 65.30724763870239, 62.52138422381494, 62.21717303799045, 58.709205196749785, 61.93991637999012, 53.17498407056255, 43.54427876011018, 51.484815151460715, 52.649084444968935, 53.861771475884225, 55.39120558769473, 54.40935004142023, 56.095404394211315, 55.610336642111506, 62.34185734102803, 65.91352447386711, 72.5316063050301, 70.70614307157456, 73.14784988280266, 71.40282661684098, 74.69837065665953, 74.26575676087411, 76.2163906712686, 75.65596242104807, 78.90088435142272, 71.43455859153502, 76.37495640785464, 57.43454079474173, 18.487299488436793, 1.1843650667898118, 3.481606571905075, 73.3492479016704, 72.74281809406897, 63.52015695264263, 63.876778848709606, 54.19650654638968, 36.4965836463436, 56.41106497856879, 37.44804474615282, 40.543638121697214, 39.759179776714696, 47.40263192884384, 23.870362274108395, 5.835866101326482, 7.558289650947818, 6.183084114905327, 3.6469580088892295, 4.379853856179023, 0.27988813937671725, 8.351513512672918, 28.1345768128672, 35.328497886657715, 32.73714873098558, 22.535995475707516, 16.595903173569713, 9.044999345656365, 9.69681195674404, 42.880260713638805, 76.62152444162678, 47.7331151500825, 56.16967447342412, 59.82013417828468, 72.37497037456882, 83.45084944079, 67.79062178827101, 36.73006273085071, 0.34687103703618055, 0.4881300813248081, 0.26459579866740013, 0.09061747621144019, 1.231235429163902, 4.805938476516355, 37.17343176564863, 74.82813050670009, 88.18357344596618, 82.32849459494315, 87.28626066638579, 80.7927611566359, 78.66007435706355, 76.14324631229525, 72.93815997339064, 64.81627671949326, 59.29567406254431, 59.90107620916059, 62.93804191773938, 64.8695307393228, 72.89880291108163, 73.07156762769146, 73.52489948272705, 72.08822158075148, 70.42473654593192, 66.76689886277723, 68.1825214816678, 62.14126340804562, 54.98114532040012, 60.69843915201003, 56.01099891047324, 55.71131413982761, 54.035956090496434, 52.256686610560266, 53.67822024130053, 55.10860273914953, 54.6293753962363, 55.536529402579035, 56.727039352540054, 58.97731488750827, 58.266228398969105, 64.55373679437946, 61.36716012031802, 67.48253530071628, 65.44959437462592, 68.79407390471428, 68.40169568215647, 65.91991009250765, 60.04475262857253, 63.4682483057822, 61.16578955804149, 58.74439277956563, 62.674058560402166, 67.30025491406842, 64.54857887760286, 61.93532328451834, 55.13949532662669, 51.41568729954382, 55.72070821639031, 55.77248742503505, 54.87588067208567, 54.15731814599807, 50.168620694068174, 51.660815823462706, 50.41410615367275, 52.326606781251975, 50.89674988100606, 52.13528925372709, 50.589949930867846, 55.5879516755381, 60.58109360356485, 60.36597905620452, 52.711410907007036, 52.14322420858568, 46.558004425418, 51.220317963630926, 50.42629295779813, 47.14315929720479, 49.6874164765881, 48.4454018838944, 53.00556905807988, 53.35394613204464, 51.42851345000729, 50.01692695002402, 45.30630550076885, 52.97376648072274, 54.91921894011959, 60.476115288272986, 59.53047106342932, 58.09020811511625, 59.09882599307645, 50.945552010690015, 56.13401228381742, 56.308663660480136, 56.06418232763968, 63.57329722373717, 56.70769814522036, 63.42215653388732, 57.280799573467625, 53.09675239747571, 52.34708155355146, 51.51515860711375, 47.6345734442434, 54.66699092618881, 58.10139079247752, 60.47545240771387, 62.851522276478434, 63.89885787040957, 68.40319402756231, 65.60834838498023, 69.57794389417096, 64.45642671277447, 65.95375230235439, 61.25458809637255, 68.55702938572054, 59.18305104778659, 51.80644166085028, 61.06702819947274, 61.029000820652136, 58.845236916695875, 57.697014039562596, 56.851798180610906, 57.491117062107215, 57.18243437428629, 61.46760025332051, 65.75866145472374, 72.67140742271178, 68.83631783147013, 73.3143937203192, 72.60842200248473, 76.23432374769642, 72.93549276167347, 77.1904799246019, 74.67315766119188, 77.62556491359588, 71.76335519359958, 78.6852010603874, 60.43065109560567, 25.442159944964995, 1.9360018761888629, 3.473526244201968, 78.33285454780825, 78.50369730303365, 69.96396003230926, 75.76816574219735, 62.149233664235766, 44.467518406529585, 61.50752998167469, 52.872702690862845, 64.68400263017224, 70.55624577306932, 74.02493107703425, 45.76554052291378, 20.531462315590154, 18.524463945819488, 18.524842454541115, 24.270334205319806, 15.234073900407362], [0.09300056123925794, 0.3262739971039757, 6.255056175493426, 11.269920679830737, 10.68664070098631, 3.9960857264457212, 1.574190194087644, 1.4141519752240952, 2.446171694224881, 17.619222094935758, 40.47549870706374, 28.93444418907166, 48.1238655890188, 49.935980996777936, 52.74497855094172, 74.21669575475877, 44.15567428834977, 29.579423050726618, 0.2045670488188344, 0.12157621538086284, 0.07446990558697332, 0.15063812084976705, 0.89877275930297, 10.589745410027044, 30.47068165194604, 77.32483679248442, 78.56440774856075, 77.9229433305802, 74.80709091309579, 75.31648912737447, 70.8900708536948, 71.29136854602446, 70.91304809816423, 64.28297558138448, 55.437760199269945, 54.511665067365094, 53.31898604669879, 56.83002118141421, 62.17405834505635, 64.99464258070915, 66.44903782875308, 65.37561455080586, 62.237608586588216, 63.70608514355075, 61.51717901229859, 58.716390978905466, 53.313110336180664, 51.48336387449696, 52.03418624016547, 48.42944568203342, 49.53822128234371, 47.725537130909586, 47.8876918362033, 48.6215712178138, 48.69567655747937, 51.13295501278293, 51.58130938006986, 52.521791765766764, 55.796123627693426, 55.95998848638227, 57.93162276667934, 57.11450284527194, 60.99029094942155, 60.36200569521997, 60.33669464049801, 60.540995213293264, 55.031994927314024, 55.10113454634144, 52.73757311605638, 52.47799458042268, 54.9784271178707, 56.17243189965525, 58.03259634202527, 52.37065499828708, 47.730232208005845, 48.84817046503867, 48.73419031020134, 50.48898027789209, 45.51423426597349, 45.6520349748673, 46.94088266741845, 47.70918084729103, 44.3190174718057, 45.161087589879195, 40.649271472807854, 44.869098509511645, 45.33895138771304, 49.94453176375359, 49.000699673929525, 50.04189283617082, 47.40671119382305, 44.30495577473795, 45.159055802129934, 43.44364250859907, 43.52575340578633, 43.245331395056944, 44.08720147225165, 44.79385568249611, 45.29982182287401, 45.66846970588931, 45.67542406820482, 46.162511840943374, 43.213634721694454, 44.93407257141606, 47.80892672077302, 51.74265999947825, 50.178136364106216, 46.39638708483788, 50.001174711412006, 49.61167943093085, 46.58655928027245, 52.84819179965604, 51.31867139570175, 53.67627866806523, 53.892899405571725, 52.03037369635798, 52.316604737312566, 50.2327004555733, 47.88775459412606, 46.51188519693191, 47.72434865274737, 46.19605202828684, 47.61761311561831, 51.631076412816206, 56.57889143113167, 59.80362884459957, 59.43913475159676, 61.80074284153601, 64.81160517661803, 62.32559519429361, 62.0671933697116, 58.622171724996264, 57.654617140370036, 42.58613786389751, 44.306175631861535, 51.039308424918886, 54.179467770361136, 53.646178399362874, 49.85235998707433, 49.72323948337186, 50.06736470806984, 52.28919521454842, 56.80903650099232, 63.59447802266767, 65.26092052459717, 65.95928284429735, 65.4254561085855, 66.28171736194243, 63.7409471696423, 65.59152926168134, 62.53415153872583, 67.74368670678908, 67.30952739715576, 67.01724021665513, 68.71509305892452, 74.4067345896075, 31.90463939020711, 0.5807510306758266, 6.640795786534587, 69.20702103645571, 64.58002451927432, 50.47373794740247, 49.55307529818628, 49.995416671999045, 33.31304680916571, 31.18091306378765, 35.48933467557354, 37.27113408427085, 47.62095105263495, 29.884971764779863, 6.102353892018718, 2.2899434451133978, 5.203314779266234, 6.226647919224155, 13.367413032439448, 0.40172777409034394, 0.1878165669979588, 2.3105307404072057, 15.312398729785798, 22.187555643819994, 22.14383690587936, 13.599711483524693, 6.2470491470829135, 2.8430959438124015, 1.797407990501773, 25.59919203481367, 51.86418679452712, 24.91476001278047, 51.834890611710094, 58.67127587718349, 63.59737273185485, 83.07454509119835, 59.42993287117251, 44.39106748950097, 0.15382811096647095, 0.22399085573852065, 0.7736975675629032, 0.03947805440534027, 1.3761059651451728, 10.888859475812605, 38.582649154047814, 83.52698264583465, 82.10127953560122, 82.60120130354359, 80.98012493502709, 82.12641408366542, 78.30688061252718, 77.95109025893673, 75.70104614380868, 70.55347657972767, 57.86702917468164, 59.10785136684295, 57.83472061157227, 63.99944705347862, 66.02542969488329, 69.28556257678618, 70.55462191181799, 69.62190581906226, 67.02826992157968, 68.6530254733178, 66.07480449061241, 61.4371116699711, 57.320219393699404, 52.529275648055545, 54.52335765284877, 51.86161371969408, 52.33219223637735, 48.92810836915047, 49.611863782328946, 52.58687565403601, 53.01703414609356, 54.17036787156136, 54.69307076546454, 55.49421487316009, 57.54768940710253, 59.097841478163204, 59.39890300073932, 61.70628432304629, 63.33358941539642, 66.57762096774194, 63.849663503708385, 64.13101511616861, 58.66033246440273, 58.534938212363954, 54.601636394377685, 54.9823808670044, 57.01747125194919, 58.90455099844164, 60.92273596794375, 53.97597128345121, 49.87991855990503, 51.21542284565588, 51.00763920814761, 50.037476247356786, 47.008582776592625, 49.62390938112813, 49.70493770414784, 49.941150680665054, 47.182814459646906, 48.83246529486872, 45.79027498922041, 45.86667491543678, 47.87400276430192, 52.73761626212828, 50.23749751429404, 51.795011874168154, 49.589419980202955, 48.87700380817537, 46.71635835401474, 43.61946667394331, 48.782804166117025, 46.000541487047755, 46.339191082985174, 48.273327504434896, 48.03372952245897, 48.38448355274816, 49.508995702189786, 47.429821798878336, 45.282179001838934, 43.82524598029352, 48.792841511387984, 53.23556900024415, 52.55930531409479, 48.973619630259854, 53.764586910124756, 55.64245300908243, 50.01827232299313, 54.44289415113388, 56.15538920125654, 53.44214454773934, 56.963993657019834, 54.67989944642591, 54.664198198626124, 52.26670042161019, 50.92677170230497, 49.40527646772323, 52.151319980621345, 48.22052847954535, 50.676850042035504, 53.17406623594223, 56.093125497141195, 62.26448466700893, 61.227237409160985, 62.88695696861514, 65.04011461811682, 65.46043188341203, 65.77932842316167, 63.45167629180416, 63.90827155882313, 50.87838926622945, 56.29100907233454, 62.54659721928259, 61.37409879315285, 60.44910976963659, 56.02332299755466, 54.17573759632727, 55.06671574807937, 57.69824958616688, 61.71552542717227, 69.10930695072298, 71.78642657495314, 72.48528311329504, 70.82392400310886, 71.93673179995629, 72.38373294953378, 73.7255444065217, 70.63793305427798, 74.80643195490684, 75.64833733343309, 75.78270204605596, 74.87585006221649, 78.79854186888664, 39.2326682613742, 0.6836513477948405, 7.260562633314441, 78.78866534079276, 70.05153871351673, 61.4903853016515, 58.84506433240829, 57.45662766118204, 46.26333244385258, 37.874174964043405, 39.19032627536405, 45.78035139268445, 58.50627353114467, 48.874524870226466, 19.43541676767411, 9.46097945013354, 6.437302731698559, 8.886710136167466, 8.741311796249883, 1.5278987490361737, 0.43776255821989435, 0.6656268923994034, 8.67801650877922, 15.320451355749562, 15.915128761722197, 9.265604230665392, 5.189250140420852, 4.0804537025190175, 5.030323545778952, 40.58279514312744, 72.85691199764129, 42.13661070792906, 66.13236135052097, 70.02538434920773, 71.2055863103559, 94.1400847896453, 70.41026299999606, 63.38710231165733, 0.5787204686672457, 0.5169474285456442, 0.43092154627365453, 0.23694374778818703, 2.565119285737315, 13.407010339921522, 58.29728964836367, 86.15015399071478, 81.84801209357478, 84.23259350561327, 81.58656258736887, 82.57175999303018, 77.74773889972319, 78.03244021631058, 79.38546180725098, 73.3802895392141, 62.125256215372396, 60.73395229155018, 60.319067508943625, 63.626402193500155, 67.9011228007655, 71.91394282925513, 76.04251200152983, 70.10323555238786, 71.01214285819762, 71.47921869831701, 69.68494615247174, 62.85004746529364, 59.40884620912614, 55.58449998978646, 59.725357947811005, 53.83575047216108, 54.598392594245176, 52.2392124514426, 54.342238287771906, 57.155075842334384, 56.21543284385436, 56.17551880498087, 56.5905487152838, 56.59966038119409, 61.97608455534905, 64.01811361312866, 64.13370978447699, 64.17674603000765, 64.16388850058279, 69.55962642546623, 69.42265725904896, 66.28432181573683, 60.307990735577, 63.87291531408987, 58.41918514620874, 55.968131326860004, 62.699032291289306, 65.30280359329717, 63.36920845893122, 57.96969721394201, 53.04392983836513, 54.5178702569777, 53.028001093095355, 52.76391575413366, 50.38866566073511, 50.94630902813327, 53.083930169382405, 55.21225137095298, 50.05320887411795, 52.37247497804704, 45.92393367521225, 47.964884081194484, 51.855910593463534, 55.58444507660405, 52.176085825889345, 56.238974909628595, 50.86702615984025, 50.10419576398788, 50.26006683226555, 46.52904948880596, 50.725922815261356, 49.51684828727476, 49.199944311572665, 52.474260484018636, 49.44673592044462, 51.869815395724395, 52.509040140336566, 50.35311721986341, 46.90283175437681, 45.466040103666245, 50.65197829277285, 58.26714231121925, 56.462216607985965, 52.67166553005096, 58.77641108728225, 57.82821732182657, 52.74158177837249, 56.55300771036456, 61.218639573743275, 60.180654910302934, 60.507957089331846, 58.12026523774671, 58.648643801289225, 57.04228416565926, 55.688831113999896, 53.12458945858864, 55.377092899814734, 51.860456620493245, 54.48749542236329, 57.727126075375466, 61.25706703432145, 64.67908397797616, 64.58824188478532, 65.19567581915086, 66.6520518641318, 66.46191889239897, 68.93270615608462, 64.8951163599568, 65.90184365549396, 51.29018322114022, 60.306264892701186, 64.25659371960548, 63.9416979974316, 63.39140515173636, 57.27856382246941, 55.785537150598344, 56.6456070253926, 59.7068404382275, 61.50410183014409, 70.17095919578307, 72.08459731071227, 71.62516224768855, 70.06125050206339, 70.2605696647398, 73.26396772938391, 75.13595811782345, 71.00203098789339, 75.22588237639397, 76.22200750535535, 78.15126449831071, 77.17057781834757, 79.36889371564313, 47.056255263666955, 1.2175033337646917, 7.803620667226854, 82.79885738126694, 74.54710052859399, 70.9726445905624, 65.12510845738073, 67.49999769272344, 49.4928276923395, 46.09586292697538, 55.92618550023725, 67.42308001364431, 73.38604757862707, 51.53422524852138, 31.03924882027411, 30.273462918496904, 24.44073569390082, 32.587580911574825, 55.13979734912996, 1.8942451813528616], [0.10634231951928909, 0.05055523762900022, 0.2803237676139801, 1.746186003569634, 2.400018390147917, 0.40166982719975136, 0.7898212056006155, 1.1787448006291543, 3.00642637956527, 18.57959285859139, 35.10014533996582, 35.920242340334006, 43.052895992032944, 43.2714347685537, 43.50274478235553, 77.8929058198006, 54.43100152477142, 59.86046006602626, 4.217033818844826, 0.03507615915770012, 1.3383591583659573, 0.14386293117798146, 2.9384154225549395, 18.43920534656894, 65.89725448239234, 73.12631607055664, 72.88702795582434, 76.14173227740874, 76.96963479441982, 72.64446858436831, 74.94929252132293, 72.93053488577567, 72.88039915023312, 69.5376140840592, 60.27739232586276, 51.27080279011881, 52.679533804616625, 53.10949225579539, 59.937354210884344, 61.20424447521087, 62.51591643979473, 61.2475670537641, 62.74284908848425, 61.924776031124985, 65.69705670879733, 63.22928574777419, 61.929004346170736, 54.57059475683398, 50.566721654707386, 50.63422564537295, 46.08739845214352, 44.463062594013834, 43.591531553576075, 46.550379337803015, 48.65442891274729, 49.21481009452574, 53.71685166512766, 53.04447112544891, 56.267588600035644, 56.745137168515114, 59.24184345429944, 59.62366265635337, 58.75287686624835, 60.06623937237648, 59.8851788428522, 59.44708539593605, 59.16871870717695, 56.91121032161098, 54.27549915928995, 56.47776096097885, 52.31032110029652, 49.55303607448455, 52.633516557755016, 51.05432325793851, 49.200462064435406, 47.9042834620322, 46.72255177651682, 45.538380376754276, 45.678836530254735, 44.24716749498921, 43.342574796369, 43.651971355561294, 46.34379986793765, 43.430118176244925, 41.94838008572979, 45.45320610846243, 46.144433636819166, 46.15158804001347, 47.54314691789689, 48.09341230700093, 47.52950883680775, 45.68783444743003, 44.377613759809925, 43.63954136448522, 43.38735257425616, 44.76026842671056, 44.436500303206905, 43.19896113487982, 42.98919670043453, 45.37968520195254, 47.32675760023056, 47.72351711027084, 43.1612906917449, 40.88761821869881, 41.78533500240695, 43.64778618658743, 49.48923480126166, 46.91467731229721, 46.26663507953767, 54.12315822416737, 57.55811114465037, 55.32594519276773, 54.528884272421564, 54.52537767348751, 54.73822509088824, 52.04443147105556, 54.51183372928251, 53.698573420124674, 51.988639677724535, 50.680897928053334, 49.78853517963041, 47.38068234535956, 46.04675093004781, 49.10604669201759, 53.21247800703972, 57.111839555924945, 62.50325110650832, 61.87731535203996, 61.52263502920828, 60.252426439715975, 62.371804637293664, 59.56969476515248, 53.78573633009388, 49.4055078875634, 51.35537693577429, 57.36043937744633, 57.393151944683446, 58.35545839801912, 51.46649376038582, 50.20123520205098, 51.168813320898245, 53.43615508848622, 57.37956877677672, 62.231152365284586, 69.05810433049356, 68.61694751247283, 71.21213666854366, 71.670834325975, 70.57122138238722, 74.1801941779352, 73.32852994242023, 70.81400825131324, 73.5490220592868, 68.95169042771863, 66.52816772460938, 65.83385329092702, 19.423779095372847, 0.5252970514758941, 11.467512038446243, 66.99520434102705, 65.85066456948557, 48.00177789503529, 46.88787967927995, 51.106608452335486, 29.27014808500967, 25.90837678601665, 44.38462695767803, 48.78875440166843, 39.57112173880301, 13.730411721814065, 0.4656261259750013, 2.387457735115482, 9.085140881999846, 9.846339571860529, 3.0984829366207127, 0.04737206569482242, 0.0805186600454392, 0.23826823720047552, 1.719302813852987, 6.238859238163118, 8.790948410188, 3.866153782413852, 3.0593984790386695, 0.9472907010105349, 1.0609066270051464, 26.495932148348903, 45.054814892430464, 31.287672135137747, 50.16289011124642, 53.45376260818974, 54.09604287916615, 87.60026993290072, 63.40632977024202, 76.52131572846444, 6.945956185940774, 0.005445203578640377, 2.6664657313977522, 0.2653507629950201, 3.1667044758796696, 22.48346709435986, 74.01749426318754, 77.1346410628288, 80.93853212171986, 83.80924424817486, 81.60753157831009, 78.12162706928869, 80.3919969066497, 78.13948169831308, 77.16603571368803, 74.06922248102005, 64.71269084561256, 55.52730006556357, 57.51676151829382, 59.06026909428259, 65.56279005542879, 66.33768958430137, 67.68276445327267, 63.962176692101266, 67.44436279419931, 65.44128287223079, 68.55924944723807, 66.26704769749796, 65.81945034765428, 57.98006403830744, 53.6076371900497, 53.179934101720015, 48.92409578446419, 46.73409531193395, 48.78220796585084, 51.982481556554, 52.37283975847306, 53.5890765343943, 56.31821070947955, 56.34458080414803, 59.80215403341479, 59.37495300846716, 60.36559858629781, 64.00234176266578, 60.158795541332616, 62.9485656369117, 63.113807247531035, 62.95592400335497, 62.96712237019693, 61.75349789281046, 56.16099034586261, 58.674017613933934, 55.61186244410854, 51.41850748369771, 55.57285839511503, 53.84727439572735, 52.584918391320016, 52.004897902088786, 49.24129393792922, 48.379176585905014, 47.82194898974511, 47.847679738075506, 46.97818048538701, 45.74972160400883, 47.49298372576314, 48.5797469846664, 47.94181662221109, 45.972143527000185, 49.09979443396292, 48.42299338309996, 49.68120344223515, 50.70035288410802, 49.61824940096948, 47.27490386655254, 45.69811890202184, 44.34876080482237, 46.20819176397016, 46.065578306874926, 47.004483899762555, 44.440469741821296, 45.707607115468676, 47.26945177201302, 49.38796312578263, 47.3347435459014, 45.40388230354556, 42.371058617868734, 42.08272518650178, 44.93366072254796, 51.67392830694876, 50.79613324134581, 50.499150983748905, 55.774087752065356, 58.45527487416422, 58.136747037210775, 55.7104512183897, 57.47069720299014, 59.449074037613414, 54.64969719609907, 57.01268596033896, 56.146183398462114, 53.51852093973468, 52.617670182258856, 51.61755992520241, 49.81684684753419, 47.94199705123902, 51.20763694086383, 54.802653943338704, 59.31182246054373, 63.076670246739546, 63.40424306931035, 64.65634992045742, 62.27835416793824, 65.92245963311964, 65.4531951104441, 57.36105911193356, 53.47672416317848, 62.11712906437536, 63.938391439376346, 65.4189645859503, 62.33622873983076, 57.91301504258187, 53.66329954516504, 53.73704794914492, 55.10540600745909, 62.39224410826161, 67.20847929677656, 74.813492221217, 75.42920235664614, 77.1071138689595, 74.98246008350004, 75.84265155176963, 78.78525287874284, 78.63483782737487, 76.00536715599799, 79.76728885404526, 75.5257946445096, 72.92889533504363, 70.09993291670277, 22.617057138873687, 0.6498223146603954, 12.946609393242868, 73.22089226015153, 72.51970583392729, 56.994211596827355, 51.39998212937386, 60.133927714440134, 35.054794896033506, 21.58912943255517, 48.800329316046934, 55.21730338373492, 56.45010432889385, 31.80987100447378, 8.697872527184026, 11.892038987528894, 10.318608630088068, 15.012977738534252, 11.936309799071282, 0.1271654703023453, 0.1400921085188466, 0.2195601862284445, 0.4040398274458224, 2.4240144702696034, 5.222457416595952, 1.807899840416447, 3.4513371509890405, 2.127208964478585, 6.82629055553867, 47.447346948808246, 65.02397014248756, 58.35074763144217, 64.93217883571502, 62.11180640805153, 58.51480076389929, 94.29480660346248, 70.50324670730099, 90.30961575046663, 8.027933662937533, 0.08610783835812923, 3.573694753070032, 0.40956056346335723, 4.098754501150501, 35.19740835312874, 77.00600301065754, 78.0016339209772, 81.47741087021367, 83.59164684049546, 81.70095459107431, 78.9107608795166, 82.46904880769792, 80.56767986666772, 76.54504606800695, 74.96729620041387, 66.87556420603107, 56.836787269961455, 59.80566847708918, 60.74965746172013, 66.65501717598208, 67.66801634142476, 69.4060891674411, 66.81567745824015, 71.32834865200904, 67.27592052951937, 75.16254394285141, 69.0614305003997, 69.25994165482061, 60.18898994691911, 56.449100202129735, 55.868522736334036, 54.81809239233694, 50.20456529432728, 50.758678528570364, 54.92065060523249, 55.757884440883515, 55.94422840302991, 60.29394472798994, 58.27804257792812, 64.1563928511835, 60.79108161310996, 62.663758416329664, 66.92034198391822, 63.9585171207305, 64.98378938244235, 64.03013175533664, 65.96553510235202, 62.2255825996399, 64.08388783854824, 58.740246834293494, 61.61951365009431, 60.24049066728162, 56.89071593746063, 59.39348228516118, 55.37758319608627, 55.37954438117243, 54.63356448758034, 53.22526493380147, 53.47246054680117, 49.795458162984545, 49.716591065929784, 51.3645552819775, 50.195418327085434, 52.058975619654504, 50.30316975808913, 48.42095375061036, 50.434043561258626, 51.63934476913945, 51.23369324591852, 52.205232958639826, 55.09338394288094, 53.170540025157315, 51.52169327582083, 49.10752150320238, 47.82007801917292, 49.415149073446955, 48.23344876689296, 50.62257620596117, 50.13194261058685, 49.40800643736317, 50.765021001139, 52.20959071190127, 51.39190596918906, 47.28747506295481, 43.83038820758943, 44.346077903624504, 47.5033740843496, 54.82816111656928, 54.06602498023741, 55.88720106309461, 59.06304613236458, 61.08210579041512, 61.71590981944915, 58.16989890990719, 60.41027046019032, 63.927502939777995, 60.09328019234442, 60.8405387786127, 59.956899381453, 57.382475253074404, 56.19181233067667, 55.58458235956008, 51.38455936985632, 50.694496785440755, 56.12766196650844, 59.675834102015344, 61.64290666580201, 67.02408083023565, 64.19356515330654, 64.17783644891554, 63.32235574722291, 66.98397851759388, 66.42020056324621, 57.388590228173044, 54.16585322349302, 63.65272521972657, 65.44246742802282, 65.46627621496877, 62.76484574041059, 59.992616484242106, 54.44449055579401, 54.53680746016964, 55.82190144446589, 64.4963485963883, 66.65084377411874, 74.0621857489309, 73.74812941397391, 76.89553337712442, 74.86146280842443, 76.05824070592081, 74.88292601800735, 78.28049875074818, 75.92119309210008, 78.07220520511751, 76.19632382546702, 75.62055910787275, 74.82222341722058, 29.917425455585605, 0.713549062850014, 13.750220671776804, 78.29328567750993, 79.01160501664685, 64.73049840619488, 62.591708398634395, 69.90361828957835, 40.10503476665866, 37.14921897457492, 63.336652786501, 68.10414468088459, 71.23311350422522, 41.205079170965384, 26.238897269771947, 35.69832640309488, 33.81292150866601, 68.16217222521382, 10.61578602560105, 0.31326325009426764], [0.03279060861396213, 0.10981416104421501, 0.029720580205321315, 0.06200740173939736, 0.5467391170320973, 0.2543555779923355, 0.3497734990331435, 1.8969644870488875, 2.547420325779146, 14.908999627636327, 29.244795845400905, 23.13992084995393, 32.78248348543721, 44.134560169712195, 41.81498027616932, 80.45016565630513, 56.46158902875839, 71.16285600969869, 24.27507046730288, 0.07460485197483532, 3.140505494609956, 0.29619769163189397, 4.0862107613394345, 40.31758016155612, 76.38110668428483, 74.77597082814863, 74.57384324842884, 72.87409982373639, 76.72986815052649, 76.39433291650589, 70.69407786092451, 71.31079212311776, 73.9606983430924, 68.2216118228051, 65.34175272910826, 54.134756672766905, 52.805704685949514, 54.4038430336983, 56.03905954668599, 59.56087727700511, 64.01480313270324, 59.986772152685354, 57.72975406339092, 59.767907819440296, 62.737612724304206, 64.51616441049885, 65.42131016331335, 60.26236180336245, 54.7891806017968, 51.256439070547785, 47.183045879487075, 49.75262195833268, 49.4142783072687, 46.270192669283965, 50.698897684774096, 52.51650441077448, 56.88999422134892, 57.02650054808586, 57.477584885012725, 56.06460986598846, 58.98191190535023, 58.56163778612691, 57.776014497203214, 61.01226014475669, 62.97028380055582, 58.62541944749894, 62.361692766989435, 57.67515074822211, 57.91377990476547, 51.621882377132295, 49.19647301397016, 46.83440992909093, 51.466183893142215, 49.08954528070266, 46.54908887801632, 47.123217967248735, 47.57985638033959, 46.3141663612858, 47.998106556554, 45.414943387431485, 44.535587218499955, 41.13423724328318, 43.62218487647272, 46.081428604741255, 45.7646305330338, 44.34786258205291, 46.82369793615034, 44.770596027374275, 45.45908181898056, 45.10076153662897, 45.55281469898839, 45.64718300296415, 43.06483176446731, 44.965886915883715, 42.652312171074655, 44.61664299811087, 43.33915056720857, 44.14268339833906, 47.826091012647076, 46.04402880514822, 47.072446807738274, 46.67911152685843, 44.3331576162769, 42.49435047949515, 40.14272089927427, 36.03940002379879, 46.177573742405066, 45.54055336982974, 49.54398716649702, 53.34154359755978, 53.00550237778695, 55.318010237909135, 52.47086371144941, 55.97959641487368, 55.77422895739156, 55.790008652594786, 56.67282827438847, 58.79474032309748, 56.00397002312445, 55.76763937550207, 56.57040342207878, 51.14625577003726, 48.365232559942434, 45.51805465452133, 47.75132671479256, 53.39869253097042, 57.48637883893905, 58.856376447985255, 61.28076599490259, 56.74652960992629, 52.72981859022572, 51.16465168614542, 53.28799539996732, 53.82681531290854, 58.70757741312827, 60.241569319079005, 61.17906678107477, 58.508211182009795, 49.37235209249681, 48.95946771867814, 50.52141043447679, 52.06225864348873, 55.13009732769382, 60.518265078144694, 64.3398852502146, 68.94816813930389, 69.93903729223436, 70.60541660554948, 69.78274653034826, 69.74538987682712, 69.90718764643516, 72.95408479629025, 74.67086699701126, 74.31411958509877, 66.90255795755695, 45.66919142200101, 7.85516502395753, 0.6880282838979076, 11.985534564141306, 69.83940908985754, 63.195671035397446, 45.278288010627996, 48.092925933099565, 43.364744032582934, 25.22506852303782, 32.90877596024544, 45.495061720571215, 42.031695150559955, 32.22457339686732, 12.470883746300975, 4.428680500676555, 2.442062521173108, 14.04717351159742, 5.858250087307346, 0.06330324712419702, 0.12312005108763134, 0.09999365696022589, 0.0952344200003051, 0.062376652288460926, 0.3825172307270189, 2.621689424399407, 0.809326233162034, 0.9867830238034649, 3.390858615598371, 1.1591023062506032, 21.50971712604646, 40.86498222043438, 22.65157791876024, 40.984116369678134, 50.90354342614451, 50.70850749169627, 88.15708960256269, 66.45047341623615, 83.62189615926435, 31.56640164313778, 0.04211891652835954, 4.598071978938195, 0.5180641395911094, 6.205711287836875, 51.64524009150844, 83.61370625034456, 81.55157504543182, 80.2774009396953, 78.3294185515373, 80.37627604699905, 81.15041071368803, 76.319195993485, 73.66420638176703, 79.52262709217688, 75.38887254653439, 68.16229774105933, 56.223697277807425, 55.13412560186079, 56.994160606015114, 60.63980756267425, 64.47750553008049, 69.13984652488463, 64.1480185908656, 65.75535881903865, 64.88272167021229, 66.13742120804326, 65.76675330438923, 67.33343032098585, 62.528103243920114, 59.31366989689489, 54.28345372599941, 49.4661634199081, 52.81584401284495, 51.64289059177522, 51.38313947185394, 53.131210419439505, 56.09746363855178, 59.838671299719046, 60.57414708598968, 60.96748236686953, 58.09539348848405, 59.5951234909796, 61.503572310170824, 59.91292176708099, 63.641005177651685, 63.08214979787027, 60.563474316750806, 61.595936282988525, 59.54706268925821, 61.53348038273474, 53.6463588283908, 52.246504137592936, 50.21655205757388, 54.515371707177934, 52.9097730113614, 48.99858551640665, 49.734826164860884, 48.606521083462624, 49.02917608138054, 49.04111969855524, 47.9686495565599, 47.49753367516303, 46.81414696478075, 47.26978909584784, 48.45567849374587, 48.222230788200136, 48.292794227600105, 50.4919965805546, 48.09184728130218, 47.375002753350046, 47.3873072285806, 47.42491883616294, 47.486017596337106, 45.82094792396792, 48.43543514128655, 45.30918452047533, 49.18200339040449, 47.415167823914565, 45.4279617340334, 49.190177609843595, 50.728370374248875, 48.56806616629324, 49.56527779179235, 50.04737238730154, 44.733713980643984, 43.09307282970798, 38.01063814470845, 46.92827224731446, 51.98663142419631, 50.88819519166024, 56.75069908941946, 53.97621447040189, 58.08804296678113, 55.14729692089943, 58.241003636390936, 59.9256577030305, 60.18263570723995, 58.59976322420182, 60.81475703947006, 58.26332976741176, 57.173114822756865, 58.90758691295501, 53.357825356145064, 51.086569063125125, 49.44026008729012, 50.08438779461769, 54.16477064932547, 59.85636511156636, 59.25513636681342, 64.74414825439453, 58.708405033234634, 54.75305949487994, 52.74320563962383, 58.35643114582185, 61.48120695544828, 64.62883841606879, 65.29934798517536, 65.43486587462887, 61.800052504385675, 57.07144306552026, 51.96098304563954, 53.83573870505057, 54.791510489679155, 59.028042900946836, 61.79426308601134, 70.67175172990369, 71.23475305495724, 74.61363177145682, 74.19556202427034, 75.65333443303263, 73.34800843269595, 77.50361842493858, 74.96917109335624, 80.44363883233841, 77.2331553120767, 77.22314542339694, 53.408882848678104, 8.799319728728264, 0.9066968050695235, 14.823475287806604, 75.99919334534677, 73.43288067848452, 51.25530158319781, 52.45901423115885, 50.08627445467057, 22.299233367366178, 27.80488394921826, 49.378294483307876, 50.785723270908484, 45.09634494781495, 18.38084440077505, 6.486509846102807, 10.402511069851538, 18.253777257857784, 14.555820591988104, 0.40541323923295547, 0.01963172892799541, 0.13935548433613393, 0.22057300042961875, 0.14773550563521926, 0.23155577480793002, 1.1945948533473478, 0.49306371820069134, 1.6448521830381888, 8.04531809783751, 6.937073978685564, 40.71793256267425, 58.81894134706067, 34.574967430483916, 53.30914481993645, 60.46036304966096, 59.60596884450605, 92.44342434790828, 72.79265572947841, 92.11335689790788, 34.21140686158211, 0.1700640881373998, 12.522061851716812, 0.6205148550291216, 8.331450589241522, 58.88505681868523, 80.91659822771626, 83.91561108250772, 80.35792719933295, 77.91069769090223, 79.90721548757246, 79.59832099176224, 74.84260405263593, 73.9995062735773, 79.89970022632231, 75.5794212895055, 71.21358010076708, 57.437702225100615, 56.87062163506785, 59.979064695296756, 62.344720671253825, 65.25948885948428, 70.91292258231871, 66.27460218244984, 67.26567529862928, 68.79570561070597, 70.06089748874788, 67.91786347666095, 71.85881783885341, 64.2391352499685, 61.31671843990203, 56.99483917605493, 53.50297658674179, 54.773447975035644, 53.81991586377544, 51.56415293293615, 56.961157783385254, 57.61553464397308, 65.60585767992082, 64.5318695806688, 62.46410192981843, 60.2275429233428, 63.53456774065572, 64.36343908309937, 61.78839914260372, 67.11390310718168, 68.305785886703, 62.07629326851138, 66.3227375092045, 61.04471383556243, 64.30331699309811, 58.2850440086857, 55.09427824328023, 55.97683506627237, 59.488078086606926, 56.592435375336684, 52.52532582129202, 54.10395429980371, 50.569251583468535, 51.75767875486805, 54.53146126962478, 51.17231207509195, 50.03017279409593, 48.275967259560865, 52.36072355701078, 51.24924936602193, 51.898287880805235, 51.21465013873193, 53.28162154843731, 50.37457650707614, 52.029604911804206, 49.85411720891153, 51.59553581668485, 52.33152151107789, 48.224086069291644, 48.60918437280963, 45.93173526948499, 52.644428591574396, 49.07001972198487, 47.760002997613725, 54.005644013804776, 52.056955599015765, 54.01089606746551, 53.15468580492082, 49.78176909108316, 48.20501942788401, 43.83444786071778, 39.955663065756525, 51.776109972307765, 57.04948563729563, 53.55727395703716, 60.465211099193944, 60.122160603923184, 61.5017484080407, 57.005033416132775, 60.947042895901596, 63.54214183745846, 63.53586604518276, 64.02642903789398, 65.16269653074204, 63.0456482210467, 61.01259746859151, 63.47267666170674, 53.78206499161259, 55.468531193271765, 52.15938437369562, 53.15403469147221, 56.4453229596538, 61.57635188871815, 60.418872217978205, 65.90851952952724, 59.71982348349787, 55.07906729175199, 49.83565069014027, 57.26187805975638, 61.80453969586281, 64.64441022565289, 64.88460833026518, 64.51438757681078, 63.42844801564371, 56.01290518237699, 54.59134017267535, 55.337174938571074, 54.6344470208691, 59.488944930415, 64.3628821065349, 69.42811719832882, 73.80027340304467, 75.05714201158094, 72.97763470680484, 75.16007284964286, 74.19345178911763, 74.8618079769996, 75.00609628615841, 80.5833536578763, 79.28601403390208, 78.55424096507411, 60.67270055893929, 10.85540165824275, 0.9065646702243436, 15.041338436065184, 83.61492218509798, 76.4055508951987, 61.564902490185155, 63.720138995878166, 58.43780071504655, 33.2383805705655, 51.88468902341781, 61.89726060436618, 63.53975311402352, 64.87995639924081, 34.790211416059925, 21.846219224314538, 36.69477708878056, 52.34009581227457, 16.008593939965774, 0.24546780893879555, 0.26041001682319953], [0.029708240444080967, 0.04212041806069113, 0.07197403709494299, 0.03309141303743086, 0.16329775444201886, 0.08500553742651978, 0.08882613281809515, 4.82906133897843, 2.9224849612482133, 13.060176718619562, 26.032347217682872, 25.44844554316613, 39.20741211983466, 62.704743262260195, 39.358513585982784, 72.6121247199274, 67.53517350842877, 71.35738988076487, 44.11713307903659, 0.1094491967570878, 1.7332723352216906, 2.825643357730681, 6.447808800205109, 57.06222157324515, 79.9250622718565, 73.2511729578818, 77.20169790329473, 73.82313297640893, 73.10209935711276, 72.01422214508057, 76.18775736901068, 72.45657136363369, 70.966353108806, 72.79963754838514, 66.89915334024738, 55.90420846016177, 52.70650402192147, 51.61550460323211, 51.836118313574026, 56.06340962071573, 59.25443426255257, 64.20167661482289, 64.06580178968369, 60.472769506516, 60.120944669169766, 66.07680489940029, 63.339567107539025, 64.1496189178959, 61.990083494494044, 56.21951603120374, 51.69782730840868, 49.62545087260585, 48.16458371377761, 51.203349790265484, 52.81444372669343, 56.57280391262424, 57.41555260073755, 55.33804178237916, 57.31341800382061, 59.01735444222728, 57.74567888629053, 59.68291398017638, 60.191778752111624, 58.87049305823542, 61.009467417194, 58.62280714896418, 56.59142340383222, 56.36317283876481, 56.98138544636389, 52.18340104626071, 46.80453323548841, 41.79576850706532, 43.21083807176159, 43.661561550632605, 44.92086595104587, 47.45052014627765, 44.38599978723834, 45.70273160934449, 45.896641823553274, 46.19084312069801, 45.56193420963903, 46.802776013651204, 41.91696190064953, 42.91030999152891, 45.647261450367594, 44.98226281135313, 44.79865666358702, 47.858125009844386, 44.47337450519685, 46.98887678884691, 47.63764466008833, 47.330272043904955, 46.56568834858556, 46.371691842232984, 44.49739510013212, 42.074786309273016, 43.8516592210339, 45.63367436009069, 44.79743680646343, 45.71609904689174, 42.70075736507293, 48.62417567160822, 50.139579465312345, 43.080940938765, 39.6431835236088, 35.748187572725364, 41.477832948007894, 50.58821232088151, 51.568875466623616, 52.3427551792514, 53.43960677423785, 55.670878425721206, 57.32400055854552, 54.3751234392966, 53.232384035664225, 58.103654000066946, 55.62577116873957, 58.769770514580514, 60.80678286090974, 55.40954659062048, 57.54200981509302, 54.670242571061664, 54.000525320729906, 49.77788986698274, 46.80571386891027, 48.733652945487734, 54.86105411283432, 60.65037835028864, 59.04031599721601, 62.06330630087084, 54.20852076622748, 52.85176115651285, 61.36767002844042, 64.96548760321834, 61.575716464750236, 60.82000909313079, 60.96461511427357, 55.02223214795513, 53.80931369719967, 47.77407253942182, 50.832944685413, 51.72876696432791, 56.83499866916288, 58.64201891806818, 67.22137604990314, 65.90087090769123, 70.81731873173868, 71.04150572130757, 73.71587968641713, 66.71888120712774, 73.2137692359186, 72.29118070294781, 77.57537426487093, 67.68343910094231, 75.60707399922033, 28.79148752458634, 3.4375544324997938, 0.16644559440112885, 14.743553073175493, 71.56842908551617, 57.61026690083166, 42.91494231070242, 45.95175112447431, 36.95291611456102, 33.61887401150119, 46.23980606755903, 43.51628872656053, 35.687767382591005, 30.932917287272794, 15.228475697578924, 12.938679341346988, 11.31650863155242, 6.740597553791539, 0.21401991496884057, 0.10943311657155715, 0.03004929512709139, 0.08883690401431053, 0.1729006972163916, 0.04119198078349714, 0.05020677487576201, 0.3381447746388374, 0.33020739894240136, 0.045505699311052604, 8.027765001020125, 4.41748752709358, 19.18872517924155, 35.65386633719168, 26.312863365296398, 51.410670588093424, 72.88010105010002, 49.496047958250976, 82.1154079129619, 72.62532741792741, 81.38788669340073, 51.14542814993089, 0.16929200940555142, 0.962199752609576, 1.146947493956935, 9.28634278235897, 66.09532633135396, 84.68822386956985, 79.78210756855627, 81.59405431439801, 81.24175487026092, 77.47072542867353, 78.2177016042894, 79.98871449501284, 76.06111188088694, 74.95053983503773, 74.12040941176876, 68.42839917828961, 59.68847982345089, 56.899862904702466, 53.63336401600992, 56.37720315687118, 58.90699855742916, 63.47093120698006, 66.74856570459181, 67.95709502312445, 65.20059839371713, 62.99622635687552, 70.09003285438784, 68.39871468082552, 66.55644016881143, 63.95944672246134, 57.30562425428822, 53.71097203223936, 51.94581131781302, 49.392493463331654, 53.293875032855624, 54.00428295135499, 60.254156204961966, 59.08799240666052, 58.05434196226059, 60.208997957168094, 61.869349018219985, 62.09624244320778, 62.71293709355017, 61.66985727125599, 61.37165515653549, 60.62979375162433, 58.324601111873505, 57.44631574999902, 58.98316706380537, 59.43974271897347, 58.10853342856131, 50.51930412169426, 47.18563856617097, 43.22676681703137, 45.933402276808216, 48.025178755483324, 53.093751784293886, 45.703704357147224, 46.79745335732737, 49.35211266240766, 48.704356762670706, 48.635005335653986, 48.33033523251934, 44.88382700950869, 43.19931022582516, 47.89047671902565, 47.17135721637357, 46.42203154102449, 49.928242160427956, 47.60364163306452, 49.37362294043265, 49.98901144150765, 50.22318086316509, 48.016227906750096, 46.72235958037838, 47.4207022882277, 45.80925926085442, 48.10958423922139, 47.04693963450771, 46.97085349790512, 47.99092077439832, 43.59894091083158, 49.868982991864605, 50.29253229018181, 44.54390656563544, 41.818937947673184, 40.36748839962868, 43.87509930518366, 52.04467073563607, 54.43436299600909, 56.893873445449344, 57.41758046611663, 57.30396116933515, 55.77991247177125, 58.698049975979714, 56.21131435517342, 59.74636616245393, 58.363840503077355, 60.982006903617616, 63.09498771544426, 59.376549413127286, 59.00270438963368, 57.963209613677, 58.27176678565241, 52.862186816430864, 48.809401758255504, 50.45371817004297, 58.083689135889855, 62.43075393861341, 62.96261948923912, 66.1894553707492, 57.884177777075, 55.406565589289514, 66.9159097056235, 68.58254048132127, 65.90625239956763, 64.79062834093648, 64.4316137990644, 59.65337461040866, 57.91687465483143, 52.00971849503056, 55.015481748888575, 56.11967994320778, 61.54181934172108, 62.98281577325637, 71.86193220077023, 69.20866843192809, 75.26428238038095, 72.880077515879, 80.4605834714828, 71.15112027814313, 79.60433006286621, 75.28002677425262, 83.77071872834237, 72.81466807088545, 82.67719330326204, 34.01209554364605, 4.4981417540581, 0.31917674406882257, 17.09310281661249, 76.68556890180035, 64.76245003361856, 47.97138737094018, 50.81488217076948, 45.33926909969699, 27.045040438252112, 46.554085977615856, 43.672187251429406, 42.53087559053975, 42.561262192264685, 23.456852282247237, 14.270351471439486, 14.241013123143105, 13.483953514406759, 0.43403676620894865, 0.04220342368728692, 0.019197914403893294, 0.13344609659285317, 0.3531921510734866, 0.2143426831330984, 0.19956942827951527, 0.1714312486470707, 0.2604538983395023, 0.3056720848525724, 16.728145883929347, 9.469911667608446, 40.193080209916644, 57.64806285981209, 38.0777616654673, 61.855695247650154, 79.86556776108281, 60.08079136571577, 86.11437413000291, 81.20865006600657, 84.327758050734, 56.403012352605025, 0.17094610048638237, 6.718837714964344, 5.001659354855938, 10.1206152285299, 69.54155998845255, 79.70879847003569, 77.81719623073455, 81.64359384967436, 80.6408634493428, 78.88666968191825, 79.33124680672923, 78.98311291971515, 75.74481195019138, 74.20635638698455, 77.68898179454189, 71.62109082744968, 60.98118320588143, 59.47030190498599, 55.90443203526159, 58.27454774610458, 60.8102463137719, 64.51183019145843, 69.02681166125883, 71.14355010371055, 69.41319650219333, 66.79434760924309, 72.27023524622764, 70.41191039546844, 68.40778320066391, 67.64666295820668, 61.04671424435031, 57.24045799624536, 55.96081218411846, 52.950240104429184, 57.05945630227366, 57.12564237656132, 61.69969081878663, 62.28290411733813, 60.3066885086798, 63.48562440564556, 64.46647582515594, 65.26820436600717, 63.41865777969361, 63.66744587498327, 64.41261383794969, 63.27385956241239, 63.59943589856548, 59.64832651999689, 60.8115642301498, 62.15074769912228, 62.75422788435414, 54.38927927324849, 52.467698358720355, 50.60547467200987, 49.509207510179095, 50.640395533654, 53.49730091710245, 48.57420467561292, 51.75681191105997, 52.98686719709828, 50.95529910056822, 50.900480055039935, 52.67883170035578, 46.711475003150206, 49.9028605030429, 52.40863138629545, 50.06144192910964, 47.150549042609434, 52.95682576394851, 49.48595569979761, 53.83341273953838, 51.978923966807706, 53.67341533783944, 52.6777805051496, 50.90008389565253, 52.500681569499356, 46.49558382649576, 49.25936429731308, 50.436608791351325, 48.96656328631986, 52.097838463321814, 47.788726514385594, 53.750274181365974, 53.68765746393512, 48.66801992539437, 45.69594590894638, 42.311258162221606, 47.69515445155483, 54.441662526899776, 58.32642109163346, 59.407234114985314, 59.3008319793209, 62.364257997082134, 60.34336266979095, 60.77867515625493, 60.94878835062827, 63.686822383634514, 60.58626328745196, 63.127645369498964, 68.52469336601996, 61.22134600916217, 63.43060924160866, 59.240019552169315, 58.60147729996712, 55.9481546955724, 50.825802049329205, 53.028075618128625, 60.3334233837743, 63.826148894525346, 63.27909200422226, 65.99281126453032, 56.549614860165505, 56.442287045140425, 67.90513930782195, 69.87733840942383, 64.29842187512305, 63.41720258035968, 65.25405245442545, 59.66111736912882, 58.879428217487956, 52.29441981161795, 55.46706814919749, 56.15319267396004, 61.82630885031916, 62.388827723841516, 72.26009984170237, 70.96852610188147, 74.812331199646, 75.76972684552594, 78.12984051242952, 68.43313740145776, 79.54177610335812, 75.45811806955646, 83.61466330866661, 75.84703676162228, 83.13640086881577, 40.91033266436669, 5.92808053378136, 0.37916642343325, 18.16459628843492, 84.25174251679452, 67.99706397518035, 60.699003973314845, 61.547871558896965, 55.48100040804956, 43.58366327901041, 65.6617828338377, 61.33392195547781, 54.583095350573146, 74.66186123509561, 26.35738422793727, 33.87550684713548, 34.69301900556011, 11.105156617779887, 0.19857778874856813, 0.17157219350337985, 0.12439654509146368], [0.054983700805854414, 0.05158031306740257, 0.03878929539613667, 0.024274217918695464, 0.03850571645964538, 0.0802701564445611, 0.10347458428793377, 10.301355104292593, 3.4412926964221464, 7.440239546760437, 29.62869586483125, 25.585675547199866, 37.69925686620897, 52.670975192900634, 38.458439457801084, 64.00010993403774, 68.59987735748291, 70.51855179571336, 51.794545112117646, 1.433122150840298, 0.29872192069888115, 3.6382101428124214, 16.916062716514833, 70.69573310113722, 76.90009117126465, 72.8359273172194, 73.22281422153597, 68.02871750247094, 76.80604057927286, 70.397719260185, 75.58011947139617, 69.65898790667134, 67.80449128920033, 67.37434848662346, 68.87490610922538, 61.36607362378029, 50.40096621359549, 53.31578147026801, 50.52746265165268, 53.88095971076719, 57.68880059642177, 58.23275881428873, 60.095649303928504, 63.167720225549516, 59.89286668838994, 61.11590877656014, 66.1476036810106, 61.80832870544926, 59.52497974518807, 58.18952252787929, 50.499531453655614, 48.439914488023334, 48.83169258794477, 52.784417983024355, 58.0414334420235, 61.686645015593506, 56.50971651077271, 60.097626178495354, 60.38641068243212, 56.301179778191354, 60.741612680496715, 58.37033987045289, 57.48650827715474, 59.271272997702326, 55.335802109010764, 53.06620497857371, 51.747355076574514, 54.304924780322665, 57.53361986529443, 54.49325346177625, 46.77823374348302, 41.06610175101988, 37.659974328933224, 42.24122032042473, 43.79880136059177, 47.15923317017094, 41.608149774612926, 45.24793278786444, 43.986980991978804, 47.52170332016484, 46.86895816556869, 46.706736779982045, 42.34548084197506, 42.39146278750512, 40.07911574456, 45.60765727873772, 44.88963211736372, 43.80176667244204, 42.74243647052396, 44.887694466498594, 48.07062725866995, 43.7534156153279, 43.447039281168294, 43.980967998504646, 42.16910362243652, 43.40620348530431, 44.92897741256222, 42.9584845419853, 44.69881273085072, 44.309172322673184, 41.43644802031979, 44.90506664399178, 49.35406600275348, 44.191646345200084, 36.79889640500469, 35.338927468945904, 40.63966951062603, 52.561011545119754, 52.06982097318096, 57.58570894118279, 54.66773225415138, 55.691404188832934, 55.09758480133549, 58.73889361658404, 55.4783449634429, 52.77441986145512, 58.33344997898225, 60.96341879137101, 55.375057189695305, 60.922049553163596, 60.1824592005822, 58.71823449288645, 56.134416287945164, 54.83260516197451, 50.37596894848732, 47.819905434885335, 46.216107106977894, 56.63027055801884, 60.242251811488984, 61.59154322839553, 58.725804667319025, 58.43234469813686, 63.486648144260535, 58.653370257346864, 62.03343352963848, 58.4376242083888, 57.970034537776826, 51.286354987852036, 50.80296601018598, 46.59520810650241, 52.840178397394, 51.97039281168292, 61.211347887592936, 62.53611272381198, 68.9602098157329, 64.73222032670053, 69.73809426830661, 67.1668472597676, 71.50690278699322, 64.76769032016878, 74.15487135610273, 69.63931329788701, 80.43753562435028, 70.04625135852446, 75.10338675591254, 19.339165726015647, 2.3037063066036474, 0.15414977596411783, 17.81157708937122, 73.73195355938327, 61.16398526776222, 42.364531793902, 43.17493661757439, 37.74749809695829, 35.40250908943915, 50.52876880092006, 32.88114090119639, 32.98986704118791, 36.25078831949542, 3.3286633078129064, 7.207452760588739, 0.31635024735043127, 0.07400576355716876, 0.06561500170538503, 0.043271583910550804, 0.007724518645479675, 0.07607656050353281, 0.060235831075378006, 0.09140162848897519, 0.009380028425385396, 0.09119396503534048, 0.14224740496325877, 0.091349657084192, 13.021473711536778, 7.362582010607566, 15.825535943431241, 39.913411294260335, 27.37752014590848, 48.375360119727354, 61.04433728802589, 45.31332654337729, 71.64583313849666, 75.08644996150848, 77.63853226938556, 60.26284817726382, 1.835182008724059, 1.2253734469413757, 2.8111884430531533, 19.547898577105617, 77.46415153626474, 81.86181883658134, 81.45231554585119, 76.54187679290771, 72.44252143367645, 79.07401777082875, 75.27778317851406, 78.27720395980343, 75.27707715188303, 73.02934723515665, 70.58817386627197, 70.63594833497079, 65.30718095840948, 54.04892344628611, 56.92049849417902, 54.40683972450995, 58.52710131675967, 60.75292871844385, 63.276311043770086, 64.9285271090846, 67.81804700051585, 64.41478683102515, 66.14952564239502, 65.75003224034464, 63.97546960461525, 62.927769230258086, 60.443226214378114, 52.74313503696073, 51.37193326027163, 50.96339095023371, 56.44263613608576, 61.33388665414626, 63.53793705663374, 60.494966199321134, 63.05727020386727, 60.829595365831935, 59.355831453877116, 63.636584666467485, 61.22788852260959, 61.119964507318315, 60.94682716554212, 57.46306427063481, 55.27720189863636, 54.58886123472645, 54.232188347847234, 59.94581084097586, 57.31101359090498, 51.23729398173671, 43.72695922851563, 41.487030906061975, 46.14342558768488, 47.51334474932763, 50.741494624845444, 44.22986199778896, 44.985624282590805, 46.90107061016945, 48.33423406847062, 50.513236215037686, 47.723117028513265, 44.295957857562655, 44.87454668168099, 43.241087390530495, 48.219469439598825, 46.88973103800128, 46.46380086098948, 44.6250407926498, 46.96614273132817, 47.57573789165866, 45.31558582859655, 44.78224938915622, 48.03734202538767, 45.508735102991906, 45.59720416222849, 46.29076157846759, 43.76266064182405, 46.85093879699708, 46.668936898631436, 46.081750239095385, 48.56169231476323, 52.469286918640144, 46.237833115362356, 38.913587370226466, 39.01544740123134, 42.44462267045052, 54.294836444239465, 57.67615095261605, 60.48882376763129, 56.01517623470676, 57.06954856072703, 57.04808927351429, 59.9117725126205, 59.7624518025306, 56.69187922631541, 59.24491074777419, 62.418543600266986, 57.10930178242346, 62.45478237828901, 61.80208821450511, 59.94131972712856, 59.871744725012014, 56.58736375070388, 51.28142064617526, 49.3977298275117, 49.795866089482466, 60.366116339160556, 62.200632402973795, 63.67789899149249, 62.36570927404589, 60.20312224664996, 64.98023963743641, 63.034975451807824, 64.8425526772776, 62.08138842736522, 61.335432067994155, 55.56324074345251, 52.71674925281156, 51.242997107967255, 55.03988281373055, 58.1425678345465, 65.14512038999989, 67.41598836837277, 72.10160470777943, 68.3581103048017, 74.3250394636585, 71.21171305256506, 75.21607645096319, 69.44602674053561, 76.30027447977375, 73.25314198770832, 85.18602755761917, 73.93827807518744, 82.6688543442757, 25.527559749541748, 3.009444643412867, 0.18197439580915437, 21.259220838546756, 81.05274369639736, 68.22598134317707, 50.237815226278, 49.37645881406723, 45.95079014378209, 35.52930362762944, 54.74142182257868, 34.339817416283395, 38.63207886295934, 59.197332397584, 7.04058385664417, 13.119534927029765, 1.4665244423574018, 0.12995108090821775, 0.072393263389747, 0.03765188082451782, 0.006831375038957284, 0.19357751754503097, 0.21573976703709175, 0.12068978270455716, 0.1498687081038952, 0.19707567419015593, 0.14678661381044697, 0.2813039617913385, 22.917547956589733, 9.992755766837828, 35.63577636595696, 64.9173758106847, 38.48474679454681, 59.52475617008825, 69.0406733174478, 57.35351247172202, 76.39318758441557, 83.48553888259396, 82.84036390243038, 65.54184067633845, 1.7159387685598868, 3.5987751233962277, 5.44878896205656, 21.416800099034464, 77.18323138452347, 80.49058175856068, 78.88965852798955, 77.64425892983714, 70.44506226816486, 79.75644742288898, 75.2308951654742, 75.85191619011664, 74.3863304199711, 71.93846548757246, 71.15351292394823, 74.5361884947746, 66.68128136665591, 54.54959046456122, 60.5868673324585, 56.53386654392366, 61.386262063057195, 63.508644796186886, 65.82501226855864, 65.43441480205905, 72.28779177511893, 65.69686059028872, 70.84816425077378, 68.21306105582946, 66.16367755397674, 64.99992601333126, 63.61576472559283, 54.67757740328389, 53.949201107025154, 53.93677896068942, 59.25177489557574, 64.31634318444037, 68.14419208034393, 63.66723406699396, 66.12044518993747, 63.06551502596948, 61.73421159867318, 66.74249387556507, 64.82728681256695, 63.31777441886164, 66.53664788892193, 60.82702621336907, 58.83155568953484, 58.66142288331063, 59.92443000116656, 61.732034683227546, 60.88385743479575, 53.88925552368165, 51.074343035298014, 48.26966008832378, 50.470572594673406, 50.557272664962284, 52.462046223302046, 46.31936742413429, 49.72424753250615, 49.45572207050939, 52.577967951374674, 54.18530033480737, 51.530903000985425, 47.690545666602354, 48.75868551192745, 45.3561431361783, 53.307497424464074, 51.35199585268575, 49.57913552561114, 45.33275012047061, 50.88191155464419, 53.741288031301195, 48.73852060687158, 48.163505061980224, 49.83260300851638, 48.33541077952231, 48.85059056743499, 50.67493200302125, 46.85203706064532, 48.32068620189544, 52.171951647727724, 48.45491363156227, 50.94501464597641, 55.37621036652596, 47.79802645406416, 42.789587282365375, 42.556680863903416, 48.00717899876256, 61.0838943912137, 60.04232860380604, 62.931715134651434, 58.543030062029445, 61.888219541119, 59.26321252699822, 63.925526065211145, 62.96488269682854, 58.488924887872514, 64.44589907123198, 65.66511684848417, 59.82315832568754, 63.84188544365668, 64.42042327696278, 63.97288084030152, 63.244971306093284, 58.63409180794993, 54.40653770200668, 52.19690184439383, 51.24207142860659, 61.79234504699708, 63.23605968106178, 63.771592647798606, 65.11205873181744, 63.55775679311445, 65.01732956978583, 64.14270377928212, 66.25600230309271, 63.87932054458126, 62.69052074801538, 57.124089117973085, 53.75859352850146, 52.36916057525143, 56.1463559827497, 58.80843331736904, 65.52284463759392, 68.56015943711805, 72.56683703391784, 69.85361591462167, 74.07325467755719, 71.35702117796868, 76.08627780791252, 67.54538736035748, 76.59994356093868, 75.08724228028329, 83.0510893175679, 75.85469322819864, 86.9205859399611, 32.16136440154045, 3.6535953946651953, 0.371974298069554, 22.48617352977876, 88.27592957404353, 71.26839130155503, 62.0312487694525, 58.836038958641794, 55.30559201394358, 52.88528173200546, 68.68867981818416, 50.42169593995618, 55.85107603380757, 88.38326915617913, 11.130699092342008, 18.109353626928023, 0.37928020281176417, 0.09693440740867969, 0.09682653456806176, 0.17258972680616766, 0.09917750519009368], [0.0776942394253227, 0.022150174031154286, 0.06356717590543051, 0.05713764893551988, 0.07035421312696512, 0.13803356897927102, 0.5011442297648999, 4.648974047553155, 0.9456805067677653, 6.790868611105028, 22.35985359837932, 27.732779018340576, 39.125030579105506, 62.7545730529293, 32.91344750312067, 54.72716008463214, 69.34937953948975, 71.44368986929618, 57.99792258970199, 5.042260789102124, 0.39516381018104096, 2.7141411602497105, 33.84845033768685, 74.27420554622528, 76.26097233064714, 74.76351338048136, 76.87630591853973, 74.80673789978027, 71.4912917537074, 69.7362115306239, 71.25034839876237, 72.15044606116511, 72.12935939911874, 70.82330426862164, 67.28569507598877, 62.73036810659594, 52.05102497531522, 51.104913988421046, 49.77288492264287, 49.293669346840154, 49.81866290492397, 56.3086401262591, 57.40653114934122, 59.748123384291134, 62.2315759812632, 61.53062097487911, 59.14115228960591, 65.44990424186953, 59.97759772885231, 57.96067184017551, 53.10367538082985, 48.19517820112167, 47.466480270508804, 57.242681980133064, 60.294380111079064, 58.948030471801765, 61.63337530628328, 57.24090906881518, 56.97629813225039, 58.388798544483805, 57.746345689219815, 59.37056779861451, 57.72292521692092, 54.42651041092412, 51.68967270082044, 47.904001051379794, 50.02403036240609, 51.90112767680999, 55.364541315263324, 57.188733700783025, 49.59091832560878, 38.1776055982036, 34.169810125904704, 41.09392312265212, 45.51215540978217, 47.28703575749552, 48.31905057353359, 42.21237128780734, 44.04474181513633, 45.692811935178696, 47.16449699094219, 44.142726544410955, 42.1121508075345, 42.6232042620259, 42.65342612420359, 42.41455378070955, 43.06386686140492, 43.40667024735482, 43.42450918689851, 40.935569194055375, 43.933228831137384, 41.010200131324034, 42.19656413601291, 45.42057198862876, 45.20858749266594, 44.0447457375065, 42.965948812423214, 44.2607428181556, 43.92939275310886, 41.934287009700654, 43.39555425028647, 44.02735002579228, 51.43527169381419, 51.415146012460035, 35.87882211131435, 37.6169067044412, 42.44846267084922, 54.654678606217914, 54.490354830218905, 53.01444145940965, 51.41550687051589, 52.14920974546864, 51.61210390829271, 56.968359255021625, 57.94037357453377, 58.86862993240357, 53.79453028402021, 59.22602453539449, 61.94436434776553, 57.130239394403276, 59.17428455045147, 57.20715315111222, 56.7448704473434, 60.01601342231997, 51.1330452272969, 49.27899183765535, 45.94195304378387, 52.704938996222715, 58.71839531006352, 59.580826451701505, 57.19020066722747, 58.3149677707303, 62.36314796632337, 60.47558969066989, 55.359332407674486, 50.57263266655707, 50.9162401383923, 49.80640942050565, 49.96243738359021, 48.178696401657604, 52.991115123994895, 58.053824209397845, 66.18337569698211, 66.2723821209323, 70.79114083320864, 66.99227040813815, 71.07430458068848, 68.82693552201795, 71.09942343927199, 64.63394926440331, 68.40897560119629, 67.48285693507042, 76.88069897313272, 66.64592512192266, 72.9940615930865, 15.491103876021603, 2.427907177517491, 0.18400091287349502, 21.47732815434856, 76.33545029547908, 58.56559545763078, 41.639979808561264, 39.854132513846125, 36.33508397686866, 32.72963150855034, 45.137165054198235, 28.848697254734656, 31.085893646363292, 56.09062302497126, 8.480284925430052, 0.7117439145522734, 0.11637109992725235, 0.05151341060897516, 0.024322213327151634, 0.05285654277090104, 0.0920570090473179, 0.02956851366757145, 0.08183600185739417, 0.0662714854303387, 0.025783784597391085, 0.03062717631579407, 0.0570065904438736, 0.2950608784392957, 10.185697155614054, 4.147404884138416, 16.580586318046816, 37.036391996568256, 33.784613763132405, 50.18056823361305, 71.62851979655605, 39.90274636976181, 64.73690363668626, 74.97805133942636, 76.83352854944046, 63.23194119238085, 6.0753777911586155, 0.5588161560796923, 3.2480358019951856, 37.19231405565816, 82.15417661974507, 80.59203778543781, 80.47134645523565, 79.75290944499355, 79.78675949958064, 75.85691328971618, 74.39080976670789, 75.04281751571163, 77.96499898356777, 74.6111842124693, 73.66077823023643, 70.59116271234328, 65.90226727147257, 55.94143175309705, 53.57034329445132, 54.07767834201936, 53.736812606934585, 54.766815247074256, 60.863096329473684, 60.53438994192309, 63.0929284711038, 66.74283119939989, 64.60496687120008, 61.25869481794296, 68.65189583070817, 60.77092455279443, 60.69215159262381, 55.96033365495744, 50.08423482218097, 49.55846463480304, 59.26989232340167, 62.52690692101756, 61.16402449146394, 63.56702143146146, 60.91820563039472, 59.875878903173636, 61.556426248242786, 62.463815596795854, 60.70524054188883, 59.00583836340136, 56.257249232261415, 52.476810024630645, 51.3396482313833, 51.6318138184086, 54.634886326328406, 56.842172684208045, 58.928030306293124, 54.67916596320368, 42.53681798135081, 37.71991206753639, 43.85701717868928, 49.240772262696304, 50.056707628311656, 51.40599120047785, 45.91415520637266, 45.65300772267003, 46.39758340774044, 49.55129061975787, 46.13102305320002, 42.006027160152314, 44.51559097536149, 45.65097985729095, 44.596250595585, 44.95154673053373, 46.59187409185594, 45.08007495634018, 42.9918796016324, 44.81014920819191, 45.87659851197274, 44.61636058745846, 48.39938463703279, 47.599601591787035, 45.688497327989154, 43.68209123611451, 45.80082616498394, 45.633144840117424, 44.69356852193033, 47.111486158063336, 46.77898291618594, 53.610018068744296, 54.56738625803302, 39.92885758799892, 39.9083867380696, 47.98648065136325, 57.425476197273504, 57.42235006824617, 57.14117496244369, 53.99980752698837, 55.583523319613555, 54.39143657684327, 59.84118946136967, 59.09886521677817, 61.11124115605509, 58.607984512083, 60.396742205466, 62.43381730971798, 59.414576791947894, 60.445916960316325, 63.36846320859848, 59.217485535529356, 60.9867412044156, 56.021934478513664, 51.14267072369976, 49.0952484069332, 53.98436123324979, 62.11512081084713, 63.280217724461714, 61.0946769868174, 62.42654131304834, 65.56646531628024, 63.284975559480735, 61.19506220663748, 55.53060270124867, 54.9257496864565, 54.16488047569029, 52.32836792545935, 51.020696778451246, 56.82581247821931, 63.076952657391956, 70.67686650060838, 70.19825889218238, 74.69485621298514, 73.51052791841569, 73.66811306245866, 73.57627468724405, 74.76112857941659, 68.08035942815965, 71.30351220407795, 71.14369915377709, 79.6751602234379, 72.84370929964128, 80.9659573339647, 22.40433719850356, 3.391282476725117, 0.2410865520998355, 24.093250959150254, 85.39023399353029, 62.71294493829051, 51.59179387554046, 48.620084639518495, 43.49648075719034, 38.36150200136247, 56.456890029291955, 27.641168140595962, 42.00278728238998, 74.96128712930988, 11.166013171595912, 2.3447190994216554, 0.21866908807667995, 0.09884328401136784, 0.12926086633195802, 0.04210515758923946, 0.027539522139235374, 0.22244896589507981, 0.12172155758185733, 0.13927933519646046, 0.13677931450788053, 0.11418932748417701, 0.20768585404561413, 0.9316932121592184, 10.835050440603688, 6.107618203086238, 40.53285552609352, 57.80602062902143, 41.212904299459154, 61.098356170039025, 80.04696953681209, 52.60685620769378, 69.49517403879474, 82.2844934463501, 82.64194688489361, 71.63169691639563, 7.002169143769049, 0.9040870193031527, 3.476194436511686, 38.40682891107375, 78.20715042852586, 80.3156989620578, 81.43525323560162, 79.06516890372001, 79.2946667825022, 78.50800406548285, 73.45247683986541, 73.43268455997591, 76.05802889793151, 74.24518000695014, 74.67792726332142, 71.15478377188407, 68.69451630500056, 58.05912725387081, 56.05398808756183, 56.105641780361054, 52.638548958686094, 56.50304848147977, 63.067825302000976, 62.61206157745854, 66.12496376037598, 69.31121487771311, 64.64981132938017, 67.69428053209859, 69.0251564210461, 64.32782003956457, 63.07006497536937, 59.05236944075554, 53.52853867315478, 52.42531322663831, 61.38499905986171, 65.32723603710052, 63.87092667241251, 68.89460425223075, 62.97256269762593, 62.25350595289662, 63.159396956043864, 62.9123660825914, 65.71288347244263, 61.522607572617076, 60.84637134305893, 57.30864055695073, 54.99217502532467, 55.64970939390121, 58.60351301008656, 58.87244247621106, 64.93909005195864, 56.78039535399407, 49.39292100168044, 45.60316224252024, 46.445820716119584, 52.74710055320494, 53.816985853256725, 55.07812592291064, 49.16862810811689, 48.67661383844192, 49.1351899023979, 53.12970030692316, 51.08474908336517, 45.49733277290098, 46.74943570167788, 49.29425377999583, 48.6254818208756, 49.13229519321073, 48.5013819509937, 48.03552596799789, 46.960816152634166, 50.39043072731265, 48.521546856049575, 47.64657197460052, 51.842488242733864, 50.08219518969136, 48.398678610401774, 47.68428948617751, 48.64134388585245, 49.200995506778845, 46.64744231008714, 49.762172929702274, 49.17200526883526, 54.87158567674699, 53.18527244752454, 44.07463812058972, 43.91030649985037, 52.76497479408018, 64.60668879170572, 58.91303116275419, 56.66441086799868, 56.48561354606383, 60.66726415388046, 56.50513910478162, 64.21341626874863, 61.64290274343183, 63.91239396987423, 61.4820541874055, 64.07509388462191, 65.07880487749654, 62.34762714755151, 61.154442141132975, 64.32704733264062, 62.55438704644481, 63.74794467802971, 57.486782843066806, 52.89780978233584, 50.294199297505045, 54.76657598249374, 63.01765426512688, 63.10132234327255, 60.135602566503714, 64.77721383494716, 68.73210045599168, 63.1279944604443, 62.43030286604359, 56.53536096695931, 54.80139094014322, 55.13604364087505, 55.28457595456032, 52.59113927041331, 56.57505535310315, 64.0951018948709, 71.81379687401557, 71.31762489195793, 75.95268187984344, 73.66035461425781, 73.85201731035787, 73.57301127526068, 74.46771960104667, 67.59272252359699, 69.53562936475201, 70.17641129032259, 80.31753463129844, 75.63689970201062, 85.10523457680979, 28.607938251187726, 3.8739845493147453, 0.39861304445132134, 28.366790932993737, 92.63020761551397, 69.46122200258317, 60.037205988360995, 55.51374827661822, 53.634603484984375, 52.28365290549494, 65.75983816577543, 49.891838642858694, 56.171494453184074, 94.34395390172159, 24.157985756474158, 1.819763907021092, 0.3657549205085924, 0.4586990670331063, 0.18018931901502996, 0.18715128092275513, 0.10908426311347755], [0.01647045753235298, 0.052048316180345514, 0.05039481498721627, 0.062185769990807584, 0.04091146236826335, 0.08833857148044533, 0.30523936774942184, 0.9190676541578386, 0.4345337121236709, 6.991925383767774, 23.67554403120472, 29.782903848155854, 32.42301787099531, 63.81776286709694, 35.750843017332016, 57.67014188151206, 66.63181243404266, 74.78992662122174, 62.50394144365865, 8.526277657478087, 0.08085426018242875, 6.047141138584384, 39.80463612464167, 72.24142935968214, 72.6518661745133, 73.82198764431861, 71.96694973976382, 72.27509898524131, 69.3640648934149, 69.36327257464009, 72.06218488754766, 69.91982552313036, 68.26510306327575, 69.28219718317833, 68.89929540695684, 66.76468664600004, 54.81503686597271, 47.70701569895591, 51.87084305670954, 50.1395010179089, 49.74119217165055, 49.621830524936804, 52.38679162917599, 56.85986257368519, 59.09410345938898, 61.968133911009765, 57.564677192318825, 57.81623448095014, 60.792101429354766, 56.432124184023955, 51.02001036367109, 46.1084694247092, 49.75258665700113, 59.08820421464982, 62.05162940486785, 58.96311982985466, 55.54624119112569, 56.59266679517685, 57.42658622803227, 57.56645402600689, 58.04109219581851, 54.97914098924207, 51.62851902746385, 49.371791193562174, 47.434461962792184, 46.187991557582734, 46.092305337229085, 47.64761924743653, 52.8049280566554, 57.68809456979075, 53.893840774413086, 36.32980446661673, 32.836498445080174, 42.20192601603847, 41.62491006235923, 47.290695328866285, 46.990590864612216, 45.120404766451934, 40.56337941077448, 43.43743339661629, 42.59880319718392, 44.14489561511625, 45.03531679030388, 42.895608948123076, 44.95461402400848, 42.90122185983966, 42.201082706451416, 43.03881468311433, 39.97453751102571, 42.9051834537137, 41.41085455494542, 45.46002318782192, 42.72680190301711, 47.166415029956454, 44.62437006735033, 43.39062383097988, 43.08463581146733, 43.09095474981493, 41.716316976854884, 43.46615691338816, 42.68676627066828, 43.22321707202543, 46.98425623678392, 54.88725554558539, 36.71895457852271, 36.27203972108903, 46.81738292017291, 53.39728440007856, 55.60193100283223, 52.91251474811185, 48.96192312240601, 46.91969794611777, 49.78409113422517, 54.498556506249216, 57.06576347351075, 57.05843256365869, 59.46664233361522, 55.56043232640913, 54.89862649671493, 57.439392766644886, 53.91801434178507, 61.07354717869913, 57.322486523659, 60.318926303617424, 55.33176599010345, 49.61161667300809, 45.71855837298978, 49.30442448585264, 59.18073684938493, 60.16014091430172, 62.05165686145906, 61.50412144199495, 60.206715137727805, 55.79829662076889, 50.49120818414996, 49.63089512240503, 50.56705897854221, 47.66001393718105, 49.03264737898304, 49.59106345330515, 57.644528804286836, 64.8359356387969, 64.68394379461965, 67.71381393555673, 68.67295111379316, 66.74879320206182, 68.44751681050947, 69.20691905483123, 71.61625062265705, 70.60329852565643, 72.05383808382096, 67.91077967612975, 76.34365589387956, 68.15941087661251, 61.762060426896625, 15.515593194192457, 2.3426787314876436, 0.06263003586941669, 28.048794577198645, 76.28503999402447, 57.28900124949794, 37.0321636815225, 34.700926503827496, 42.79870287064583, 41.99946111248386, 34.01073840356643, 26.61541146616782, 43.08147438110844, 68.39895002303585, 13.360762653812287, 0.48372029537154787, 0.14437584236504572, 0.06221895308924779, 0.07349639169631467, 0.13272681664074623, 0.06907531360705053, 0.04236389995522557, 0.019761477409291173, 0.12119269644420956, 0.11005097414336859, 0.10064290881517435, 0.07656790631552858, 0.30754222804980896, 3.9442535658036513, 0.8623109577644257, 12.730729003106395, 40.138472972377656, 26.493649328908614, 32.26720171590006, 78.3534626806936, 41.62793813213226, 66.29324913024902, 73.03232039174726, 80.90759246580063, 66.55667551102178, 10.742892392220037, 0.07228366685129943, 7.791544179762564, 44.70608872752036, 78.51529967400336, 76.93476492358793, 77.25737202552058, 76.48894048506214, 76.50905439930578, 73.41704999246906, 73.46338887368479, 74.29118940907141, 73.5515166867164, 72.90552585355698, 73.84394507254325, 71.02854621025824, 69.67095113569691, 59.14039134979249, 52.463650472702525, 54.80519171684019, 53.76427704288114, 54.31117703837734, 53.56057267035208, 56.12278646038425, 60.30064805861443, 62.58122390316379, 65.75668458015689, 60.79487454506659, 61.246135388651204, 62.36781166445825, 59.47058823800857, 55.7606928579269, 49.001448846632435, 53.58779391934795, 61.58021150096771, 62.26500634224185, 60.57390782140917, 56.694448378778276, 59.8328544247535, 59.25042560023647, 58.64994210581626, 60.894345852636526, 57.05653021412512, 54.567802029271284, 52.579678104769805, 49.29255147134104, 47.8971290588379, 47.558652047188055, 51.603890465151885, 56.48539781570435, 60.12924832682456, 56.34221169256396, 42.027737479056086, 36.724151719001036, 46.71016493151265, 44.16283261391425, 49.20460800970755, 50.31469760402557, 48.47006574753792, 44.247661713630926, 45.174851186813854, 44.03325319290162, 44.68404892952212, 46.97723519417548, 45.633603757427586, 47.25073422155073, 47.78982085566367, 44.395746877116544, 46.70565420581449, 41.70331039736348, 46.16666170858568, 43.65476016075381, 47.57469061882266, 45.50379291657479, 48.28426307247531, 46.57440385510845, 43.97114246122299, 43.92771005630494, 44.829592397136075, 44.07124919276084, 45.1339683225078, 45.05568173623855, 46.34153666034822, 51.56838909272225, 54.50717787588797, 39.78915452957153, 40.19579841244606, 50.54754518693494, 57.57762101388747, 57.622387024664114, 55.51544274053266, 50.48259858162173, 47.88553453260853, 51.90218279438635, 55.660276259145434, 57.802894499994096, 59.90602231794789, 61.78043673115393, 60.827987194061286, 58.060331421513716, 60.215077630935184, 55.2631127449774, 62.00451781672817, 60.46368529719692, 61.5782856172131, 57.00864199669131, 51.40825440806728, 49.20191334139917, 53.13159481171639, 62.09831345465876, 63.48838575424687, 64.60586509396954, 63.90971106867637, 64.70251621738558, 61.1938266600332, 52.66686847133022, 52.53338629199613, 53.30555977359895, 51.66491077792261, 52.08556536705264, 53.571418023878536, 61.580980285521484, 67.70206251452046, 69.45533060258435, 70.83140788539764, 70.72511165372788, 69.73024952796199, 72.71734622216994, 74.60093113683885, 74.2636465257214, 75.10350442701771, 76.69651231458111, 71.75025447722405, 78.00927469807287, 74.87198260522659, 69.44754862016248, 19.087986946105957, 3.0928104539071364, 0.07829769454415768, 31.90436874666522, 87.236187688766, 63.86974996136081, 47.57782459259034, 42.05001261926467, 45.02667580881427, 49.615892056495916, 39.97722041222357, 28.008539292120165, 49.90155827614569, 81.92408254069667, 15.404774469714011, 0.46250039531338605, 0.2570070849070626, 0.06895788765001683, 0.05503970566355894, 0.07111785723076713, 0.039190874855604865, 0.1470013176121058, 0.15928579794783748, 0.1716170556122257, 0.20454792726424434, 0.33604462120321493, 0.21686559452885584, 0.4038617886122196, 2.966389766623897, 1.036050199500976, 34.563114027823175, 60.945477870202836, 44.3111531196102, 51.04569796592959, 83.40170998727122, 54.45759911690989, 71.90353285881781, 80.11876460044616, 84.52112305548884, 75.05511806857201, 12.058669117189224, 0.19749665482630654, 8.725573285933464, 46.041141940701394, 80.29215689628356, 77.1755906074278, 79.19991800861975, 77.00666981358683, 75.8360384356591, 72.83860237367692, 75.36362817210536, 74.04825349007884, 73.45080591017201, 74.05571383814659, 74.76347415677964, 73.40831095172514, 73.05011226284888, 60.59239787440146, 53.507808946794086, 58.08008840007167, 55.40721278036795, 57.50849316197058, 56.33893651347007, 58.683886297287486, 63.21791087427447, 64.84158385184504, 67.69488457710513, 63.82861606536373, 65.37642648143154, 65.24963194324125, 61.62562862519295, 57.31797972033101, 50.94703074424498, 55.918623170545025, 65.46298142402404, 65.89479123392414, 64.18593222095122, 60.84606539818549, 63.556697753167924, 62.65106954882222, 62.2366201493048, 64.35713191186228, 59.75174765433035, 57.46898312722483, 55.63655768671344, 53.09477944527903, 52.672736337108, 50.64835010036346, 54.571210568951024, 58.90758299058484, 66.26993456194478, 63.24883091834284, 45.794966143946496, 42.84140963708201, 50.1195086971406, 48.28893069298037, 54.315213157284646, 53.87718639066143, 49.186749458312995, 46.165277111914854, 49.085599376309304, 46.42255713862758, 47.21393062222389, 50.87009737568518, 47.312660601831254, 50.22101963720014, 49.93960526681716, 47.9590868180798, 49.59099677301223, 44.092343699547556, 50.062469590094786, 47.238708234602406, 52.53184087814824, 47.84801313954015, 53.55436748073947, 48.6404731196742, 47.338026569735625, 47.931100706900324, 45.09060652025285, 47.508786955187404, 48.32691100335891, 49.32182411993704, 48.691416863472234, 57.21962236589002, 58.75648152443671, 43.51397060578869, 47.60929376848283, 53.040285956475046, 59.588577055162006, 61.873804830735736, 58.074436264653365, 53.582298678736535, 51.79910290625788, 56.36295710840533, 60.32405284143264, 60.316466977519376, 61.864571571350105, 63.61937330615137, 63.00437311972342, 60.825955406312026, 62.48043860158613, 57.18136748959942, 64.9953015388981, 63.405455081693596, 63.897394826335294, 58.95842867512857, 54.188508833608324, 51.392804191958525, 56.82350220218782, 63.86440377081595, 63.43457868022304, 66.19038889485022, 65.27707284496677, 64.00350278423679, 62.696576887561434, 53.704955116395034, 55.104892176966516, 57.114051772702126, 52.08228626558858, 53.50594582096223, 54.874464696453465, 62.33303985288067, 70.76373915518485, 68.93200797419395, 72.11032805904266, 71.64892396619244, 72.31661335114511, 72.56709591034921, 75.28351768370598, 73.2527889743928, 75.52071125276628, 75.76887176882836, 68.91863269190635, 77.91706762006207, 75.52201347966349, 73.56373094743299, 22.42876571993674, 3.4720416270917465, 0.19888325864749573, 34.849968725635165, 90.3004530937441, 70.08334913561421, 53.291592213415335, 48.368888208943034, 64.0163524689213, 66.29792459549444, 50.01120028957244, 48.60176324844361, 69.96115946000623, 92.74372885304113, 21.033060896781183, 0.7984442299892827, 0.3726092317411977, 0.22145052350336508, 0.1502120840333162, 0.1679276221341664, 0.11826698367874469], [0.048909270910606276, 0.007160394959482215, 0.06541498380923463, 0.022727049729456345, 0.02785633780032156, 0.03780736602962979, 0.0655507805546926, 0.12239892486362688, 0.3209827810285553, 6.5065384487951965, 35.528883934020996, 54.85560594066497, 39.299662343917355, 69.62752265314903, 38.44209886366321, 47.060946418393044, 67.94135062925278, 69.68965299667852, 64.47403031010782, 8.08465603859194, 0.016951254313631405, 10.081852405301987, 44.69184660142468, 65.9534542022213, 73.08870054060414, 71.601408373925, 72.9533395459575, 69.97752358836513, 70.90076323478453, 69.1411252175608, 69.21627783006238, 69.9850231601346, 70.92744319669663, 67.41789464027651, 67.30313393377489, 65.31727321686284, 58.017812928845814, 48.86628004812425, 49.58479158339962, 49.1347505969386, 50.61336648079657, 49.10204195207166, 47.17231035232545, 50.45467915073518, 54.76905099807247, 58.150969551455596, 59.013353624651515, 55.01659177964734, 57.712703520251864, 55.76904750639393, 53.26838747147591, 47.96685311102098, 53.527420797655665, 59.195128025547156, 61.95473509450113, 59.794905493336344, 55.36082290833997, 51.77244255619665, 53.25856585656443, 57.715182458200765, 55.97377561753797, 52.85525598833638, 52.70817887398505, 45.024777381650864, 45.927608936063706, 44.76204918276879, 43.374620560676824, 46.835684699396936, 51.36356292232391, 55.62120552985899, 52.44412099161456, 38.033858576128566, 33.25399160385132, 46.732016455742624, 42.54887926963068, 47.0191849431684, 46.16246085013113, 45.720374430379565, 43.41971997291812, 43.82551270146524, 41.239376375752116, 43.166707484952866, 42.674583388913064, 42.513628928892075, 46.517702071897446, 46.339940255688084, 44.001011310085175, 43.19135173674553, 39.05654991826704, 40.44547688576483, 42.890141164102864, 43.31009364897206, 42.859436850393976, 42.24295008567072, 42.87641286849976, 43.02503539669899, 42.860405675826534, 41.866786941405266, 41.91321995950515, 42.71677632485667, 42.92905107621224, 43.435538891823064, 43.160447382157855, 49.49142740618799, 38.51039125073341, 37.019117878329375, 51.60913467407227, 53.45378614241078, 53.81927651743735, 50.45989982543453, 50.02288503031577, 46.47898827829669, 47.69724507485667, 49.44136227330854, 51.17178647748886, 56.29088355648903, 56.235601671280406, 61.255525542843735, 57.918471059491566, 54.731533527374275, 52.98321547046785, 51.757925864188906, 61.25267790209863, 60.06074020939489, 59.43123509806972, 49.55236927155526, 46.57598457028789, 47.74432136166481, 58.39930657417544, 57.85460310597574, 60.30725332998461, 60.52926732647804, 60.59306075496059, 57.13779387935516, 47.29769675962387, 46.745246610333844, 49.37433288943384, 48.2242900325406, 49.11242054354761, 52.91144786342498, 61.366610988493896, 64.10870467462848, 66.08969380778652, 65.9237697047572, 67.52406535610076, 65.69338144794588, 68.7556032980642, 66.23886154543969, 69.55958720176451, 70.17478742907124, 72.83151857314571, 75.36830363735076, 73.42181959459859, 69.08269759147399, 59.07681757403959, 20.73282111075617, 2.3447382209762453, 0.028135061654592716, 28.630701726482762, 75.28830297531621, 60.48918070331697, 31.32742339564908, 39.936035525414255, 49.996471789575395, 51.580626887659875, 30.125544455743608, 37.694149940244614, 56.01877304815478, 48.89136360537622, 1.5292818748181867, 0.13698266488650154, 0.01860920073194129, 0.056394329144349026, 0.032306667041754535, 0.007144562316112101, 0.015795894132386294, 0.0521134949409433, 0.0412865428464307, 0.042226900451726494, 0.026894749983424143, 0.01684763134577342, 0.06411051227440757, 0.08682012392748749, 1.1822379164157377, 0.611809399579802, 15.16080794795867, 49.514235988740005, 60.895185239853404, 42.542368135144635, 80.49870890955772, 43.161176943009906, 55.61584364983344, 76.2542180092104, 78.5849609682637, 69.65858782491377, 9.013123223858496, 0.00609917932325193, 13.641010119069009, 51.55985009285712, 72.33665666272564, 78.63612436479139, 77.99422848609187, 77.05216146284535, 75.66392483249788, 76.71035828128939, 72.25086658231675, 74.01297569274902, 73.83590421369, 74.3445493328956, 73.83161314072149, 71.31502828290387, 69.27775706014326, 63.57304619204614, 54.01923110408168, 54.9682407225332, 52.29928355063162, 55.53125381469727, 52.86814881909279, 51.55189160377749, 51.69619168004682, 56.46237350279286, 62.78508517049975, 64.0560939235072, 58.35493280041603, 61.0169630665933, 57.26946392366963, 55.980718212742964, 50.001512035246826, 54.21157237022154, 62.49112313793552, 63.185210074147875, 59.82559803993472, 59.331673575985825, 54.863748781142704, 58.226384962758715, 58.034910540426935, 57.01408232412031, 57.0119014863045, 52.02580413510723, 47.45532897210891, 49.65127575782038, 47.864832262839045, 46.02302843524564, 49.95317666761337, 53.64038898098854, 60.57839109051613, 56.87663070617184, 41.571318718694876, 35.82727824487994, 49.13274234341037, 47.02404868218207, 48.83770950378911, 48.83253589753182, 47.19166332675565, 47.28611400050502, 47.28819285669635, 45.159699070838194, 46.06288363856655, 44.862414790738015, 46.09374092471215, 48.748624632435465, 49.34177721700361, 46.6320195505696, 44.40546651040354, 43.46449775080527, 42.13073107504076, 45.82075572782948, 46.01802349090577, 45.78064557044737, 43.85382829173919, 45.34260311434346, 45.67698909390358, 43.47689244054979, 43.95094225483556, 43.863269436743956, 44.083110440161924, 44.394691759540194, 46.55228168733659, 47.336316416340495, 50.403857000412486, 41.761349708803245, 42.47189883262881, 57.40200081179219, 58.46810102462769, 57.28024259690316, 53.44724362896335, 51.21700748320549, 48.03595742871685, 49.41264660127702, 52.6756977265881, 53.816723054455174, 58.38191086246122, 59.72095704847767, 64.54334251342281, 61.00077544489215, 55.907460105034616, 53.651948205886356, 55.36117984402565, 63.66538663064281, 61.56329039604434, 60.4590961240953, 51.84503778334587, 48.3700688423649, 50.58071274911204, 59.53931208579772, 62.910832435854026, 64.18302574465352, 63.07770183009487, 65.976164725519, 60.03151070687079, 51.74622543396489, 51.15345331930345, 51.98480359969601, 51.63264143851496, 52.76874026944561, 56.86793873386999, 67.68686725247291, 69.51625285610076, 69.7300063410113, 71.14037298387098, 70.69934952643611, 69.81034432688068, 72.14668843054002, 72.66833228449669, 72.79458553560319, 74.5395617331228, 77.75880782834946, 79.60555384235998, 76.2307700803203, 73.09612950971051, 68.69381027836954, 23.02596422933763, 2.866265629568408, 0.05632772546021208, 31.8223794429533, 82.05891009299987, 68.32812770720452, 41.717136752220895, 42.30688471947947, 56.822953070363695, 58.27207273052585, 31.75162772978506, 42.42906262797695, 64.97798035221716, 58.633452461611846, 2.0635827270246323, 0.04305456269292101, 0.02566831982544353, 0.022136771322918997, 0.07002575292942986, 0.03522267347321876, 0.03161075660177777, 0.14744065371492218, 0.10244560563155722, 0.14101944262942961, 0.07974419878014634, 0.1357389058196737, 0.14519065348131044, 0.16703554338985876, 1.2046643130240904, 0.49699344281708047, 35.15710207723802, 70.19071225197085, 72.0722104657081, 54.38117173410232, 86.35494093741141, 55.945256064015055, 60.51235798866519, 82.9801336411507, 82.56640203537481, 76.08587772615495, 11.129912657122459, 0.15218958679226138, 13.740794235660186, 51.455738621373335, 73.17161160130655, 80.70382533534881, 78.81391755996212, 76.82602113293063, 75.3318020605272, 76.42073046776557, 72.91570048178397, 74.78354884732154, 74.08135044959285, 76.0786448755572, 76.05872707982218, 73.58266030588459, 72.03307305612873, 63.641664135840635, 55.61239980882215, 55.793695680556766, 53.26483772646997, 57.66192059363089, 54.379661621585974, 53.324838222995886, 54.37468021146713, 59.89995833366149, 63.73188649454425, 67.486967579011, 59.247832913552564, 63.77600531424246, 62.028644315658084, 57.93443902846306, 52.67034369130289, 58.49772276416902, 64.71715842523884, 67.67735158243488, 64.7500474991337, 62.258055902296505, 56.877046477410104, 59.77070054700298, 59.80853180731497, 61.42021409926876, 61.24476648146107, 57.08790917550364, 49.945018137654955, 52.37885275194722, 52.31494557472968, 49.56426582028789, 52.859939298322125, 57.44234631138464, 62.97511223823794, 60.84561432561567, 47.66572883052211, 44.2399581786125, 49.7354615888288, 46.106602376507176, 53.70340970254714, 50.13751629860171, 50.87117602748256, 48.61182805030577, 48.31139410695722, 47.80195666897682, 50.16053276677286, 47.247690462297015, 47.662963559550626, 50.773650215518096, 51.14458091797368, 49.663388036912494, 46.43170410586942, 46.13975817157377, 46.4032002418272, 48.38291068230906, 50.17730089925951, 47.66404613371819, 48.003229171999045, 48.54526935085174, 47.19398929226784, 45.28395191315682, 48.18900831284062, 48.37386961906187, 46.560240176416215, 48.0191030040864, 48.97070530922183, 50.7126691264491, 56.85654817088958, 47.45381101485222, 47.223732625284505, 59.386194521381015, 61.251481579196074, 61.65572497152514, 55.2328634262085, 55.718448931171054, 51.196211076551876, 53.490574052256925, 57.36289085880403, 56.714236736297615, 61.50181508833363, 62.380928070314475, 66.07416122190415, 62.68258579315678, 59.71635610826554, 53.42637661964663, 59.40366868049868, 66.81667374026391, 63.73695027443671, 61.63772129243421, 54.20801478047525, 50.69420260767783, 51.3574008787832, 60.78692390072731, 64.30619601280459, 67.09521693568077, 65.5798327538275, 66.34785636778801, 61.18493464685256, 51.65595992918938, 52.32269225582, 54.80451706917056, 52.096183223109094, 54.35547628710347, 57.87261070743684, 68.17634767101657, 70.81110569738573, 69.66571869388704, 72.50929586348995, 71.44883601896225, 71.4855258695541, 73.8616192725397, 74.2265958170737, 73.24830178291568, 78.0428501867479, 79.16049034364762, 78.8940437378422, 75.770934935539, 74.97476439322196, 72.57244602326425, 23.87957984401334, 4.025386076781058, 0.4606586892998988, 34.194003305127545, 88.28876356924735, 74.05379187676215, 44.14332274467715, 52.53080929479292, 75.57025863278297, 71.1335402150308, 49.54537176316785, 59.96426559263661, 80.22445678710938, 65.5530547326611, 2.075209857956056, 0.2576381574955679, 0.10365476816772454, 0.09338408783679047, 0.14229261947254981, 0.1663191592501056, 0.08278146160826569], [0.05828778056668178, 0.030268691217286453, 0.05491957924659214, 0.031592517963520465, 0.010457837526055594, 0.09272490748234334, 0.1004752045076701, 0.05218944489775647, 0.7153284705934987, 6.503937427074679, 38.51778491850823, 36.3461725173458, 48.89498787541544, 53.005914226655044, 47.1300664255696, 30.17766294940826, 65.38135690073814, 68.05814312350365, 72.07526206970215, 9.399348228208481, 0.058166520339587045, 14.581155180931093, 46.843262718569854, 68.61792026027557, 71.16655872714135, 68.38923038974886, 70.4571274788149, 70.28810470334946, 68.46726986669725, 67.5560091387841, 68.73989028315391, 66.97381957884758, 68.89548286314934, 65.80069749586045, 66.94806529629615, 65.95764329356533, 63.440042541873076, 50.48985496644051, 50.69990573390838, 49.01882102412563, 48.648572814080026, 47.727019786834724, 48.075989138695505, 46.813582143475934, 49.57144375770323, 55.92196502993184, 59.98206923084875, 58.23670864105225, 58.45646335232643, 53.51674018367645, 50.872870491397, 46.90659722974224, 49.9119564794725, 56.1210645398786, 56.26752584211288, 62.57543840715962, 57.54095861988684, 51.053519172053186, 59.39600829155215, 58.411709108660304, 53.998638660677024, 52.96449007526521, 47.92835112540953, 50.22432619525541, 47.77181717657274, 46.50524462423017, 44.465839632095836, 45.77152998216691, 50.53140855604603, 54.853425102849165, 56.019047614066835, 41.40573978424072, 32.5755137397397, 54.87423719898347, 48.65259324350665, 44.016822384249785, 44.638773010623076, 43.321527358024355, 42.87442030445222, 43.53690078181606, 41.81944393342541, 41.05223225009057, 41.92398294325798, 40.851599093406435, 44.0180814650751, 46.21360463480796, 44.0515745839765, 43.32129201581402, 42.63133925776328, 44.085126538430494, 42.865818546664336, 44.16871224680255, 44.77387512883833, 41.13599054275021, 39.53826404386951, 43.70740229083646, 41.30066340969455, 41.14593375113703, 41.29230483885735, 41.427505016326904, 41.89431021290441, 44.313985070874615, 46.23110625051683, 41.02785471946963, 32.39750677539457, 38.35227658671718, 56.783352821103996, 56.443271560053674, 50.99453064703172, 49.40920276026572, 46.834190276361284, 45.08099671333067, 45.41279785094723, 47.720100725850756, 49.167800488010535, 52.564918225811375, 57.43681969181184, 58.30319281547301, 58.53458519904845, 58.21994443093577, 52.09867000579835, 64.02948848662838, 63.446463461845156, 58.16818091177172, 56.78323514999882, 48.04258231193789, 45.11103814648044, 47.92643700876544, 54.69887979568974, 59.68501637058874, 60.70034934628395, 60.621097856952304, 61.13732099533082, 54.98652288990637, 47.33834035934941, 47.89654070331205, 47.880537433008996, 47.78143875060543, 49.8000551808265, 53.14117716204736, 66.11359673161661, 65.46206751177388, 66.33037044155982, 66.67481730061193, 67.2746261473625, 65.86246305896391, 66.74598478501844, 64.49246937228789, 69.8055668800108, 66.54408470276864, 73.59599636447045, 71.23451771274691, 78.92999618284165, 69.78141292448967, 66.9543489333122, 26.92362346956807, 2.5487262298983913, 0.1599287295774106, 26.165309682969127, 75.32696185573455, 51.350164105815274, 28.76688445768049, 52.24885363732615, 36.474649752340014, 52.93140096049155, 33.83894251238915, 36.94423983173986, 52.39475404062579, 20.461136179585612, 0.33261876793638356, 0.021058885613456372, 0.06812499685873909, 0.044032734398159294, 0.10958696234851115, 0.06172622831898832, 0.02485979063015792, 0.014354566735545955, 0.0310391228600976, 0.01170897401959425, 0.04172872879632539, 0.06265664210302696, 0.05199004753282474, 0.09508333213987852, 0.05706378273786076, 1.242441885894345, 12.171784389403559, 53.59710170376686, 46.0658371833063, 60.90517159431212, 65.92609174789922, 50.66650675189111, 38.02208362087127, 73.65947600333922, 76.68476089354485, 78.39531437043222, 12.198084862001481, 0.11140235324179935, 17.604717170038533, 53.888118036331676, 76.2805292683263, 76.576778042701, 75.62900789322393, 72.499144769484, 74.32001882983793, 74.2139579403785, 73.81969698013799, 72.96278461333245, 73.90275709090695, 72.02952723349296, 70.9904678406254, 70.802029332807, 72.48508699478643, 68.91794235475602, 56.080926925905295, 54.28022561534759, 54.84849860591274, 53.14380122769264, 50.35564322625437, 51.52062246876379, 51.095111985360425, 53.59805483971873, 59.50851755757486, 62.60132212792674, 63.40022263988372, 60.13810503867365, 57.78163917603032, 53.23533365803381, 51.163694627823375, 53.03524571080362, 59.04509344408589, 60.48057894552908, 63.37043616079516, 60.1729945213564, 59.17811670610982, 63.15485485138432, 57.9432329823894, 56.6867801450914, 56.12692063854587, 51.49792371257659, 52.1300450448067, 51.46829412829492, 47.76418424421742, 46.13383539261357, 47.31328818105882, 51.84592031663465, 56.540644399581424, 59.45164319007628, 45.193996275624926, 36.575823368564734, 52.82794452482655, 51.15664220625355, 46.8299658836857, 47.32918162499705, 46.54445263647264, 44.415515622785016, 46.33469212439753, 45.823493542209754, 43.76080928310272, 44.68428819410263, 42.63768173033192, 45.610155828537486, 48.74873838117046, 46.071928624183904, 46.57469018813103, 44.44509813862462, 45.30591326375162, 45.361779582115915, 47.13528317789878, 48.08634419595042, 43.41990040194604, 43.838538892807506, 46.08562161845546, 41.50406183735017, 43.68457017406341, 42.89269854945522, 44.327854571803925, 43.5166338951357, 46.38517695088541, 48.77452796505344, 43.594312514028246, 38.95546259418611, 43.09023303370322, 56.67391869329638, 60.287566954089755, 54.11932999087919, 53.70810085727323, 48.32653445582236, 46.81271922203803, 47.820368274565666, 49.591824393118586, 52.000767646297334, 54.90800488379694, 58.88938319298529, 59.09733549241097, 59.1938179539096, 62.109605958384854, 55.74346580813008, 66.19783355343726, 63.99190041326708, 60.46838429666335, 59.969176400092344, 52.27098757220853, 46.39342961772796, 50.92527335689914, 59.34308375081709, 61.257969179461085, 65.07131707283759, 63.14697873207831, 63.56674294317923, 60.21899607873733, 51.08470985966345, 49.89883222887593, 51.00434049483269, 51.259094515154445, 52.4427128607227, 57.77728142276887, 68.80310320085096, 67.41467829673522, 70.92743535195628, 70.2538545670048, 70.9800814044091, 69.20291039251512, 71.17961237507483, 69.88562245522776, 74.33705760586646, 71.64333851106706, 75.2318286895752, 75.57291015501946, 84.00466457489999, 74.34911497177617, 74.63505575733801, 31.81266373203647, 3.1552717474199112, 0.11761370220131452, 29.594467301522535, 84.0673440502536, 58.105171957323634, 32.68516555909188, 48.18990653561008, 44.7228019468246, 63.38245038063296, 27.340463553705526, 46.4226669649924, 59.86700650184386, 23.025160143452307, 0.27572797551270456, 0.06805041819931039, 0.07539370803222542, 0.0815280115291957, 0.09906541120501296, 0.09170637826525396, 0.05863906635392097, 0.08884978195231769, 0.06930695561271522, 0.3000473447384373, 0.16719170275234407, 0.21274725906550887, 0.23280889546919256, 0.14734492336790408, 0.11300705463415193, 2.329166901688422, 34.712501418206, 67.22798916601366, 50.41591828869235, 64.39982691118794, 69.1730611555038, 65.07359204753753, 42.74591953523698, 81.64088741425546, 78.99262074501284, 83.45438741868543, 13.363214135169985, 0.23102858374195717, 19.872611991820797, 55.62095057579779, 79.38219055052727, 76.76677765384798, 75.97712609075731, 76.46917958413401, 76.78462443813201, 74.79717516130017, 72.47410435830393, 74.77674745744275, 74.57750674216979, 74.41086092302876, 71.41796696570613, 72.86451355103524, 73.03420312942998, 69.76349553754254, 58.00492402045958, 55.78513706884077, 56.19828424146099, 55.96202419650171, 52.692760036837676, 54.872075973018525, 52.162820369966575, 54.57672149904313, 61.86284965084445, 65.15178841929283, 66.61901766254057, 62.46904803860573, 58.56758409930814, 56.83002510378438, 52.99415496087844, 55.962102643905155, 60.196516975279785, 63.735655892279844, 68.66834625121086, 64.61126227532664, 59.535538765691946, 63.63787904862435, 63.25888787546466, 59.08855722796533, 60.66919003763507, 54.36991453170777, 57.32766012991629, 56.16380268527616, 50.9997630888416, 50.634790466677764, 51.18921749053463, 55.31231103404876, 61.07147616724814, 61.34506540913736, 49.90486091183078, 43.253423244722434, 54.19583582109021, 54.57927103965513, 50.512757685876664, 51.32738690222464, 47.95209715443273, 46.726329018992764, 50.110267593014626, 47.58680682028494, 44.22410788074617, 47.35213925761562, 48.486139620504076, 49.246887237794944, 53.075732415722264, 49.9020250381962, 50.72313793243901, 48.45012441758187, 48.969179507224794, 47.65143179124402, 48.97110931334957, 51.400150791291274, 45.92554576935307, 45.49287303801506, 48.88175772082422, 44.99078612173758, 47.4229694181873, 45.854460654720185, 46.62601047946561, 46.844470808582926, 50.17196255345499, 50.57619417867353, 49.92971304924258, 43.24353494951802, 47.577891272883264, 62.16569585184898, 63.93449652579523, 57.964201973330596, 54.79975531178137, 51.15908976524107, 51.16671877522623, 50.429854469914595, 50.94728962067635, 54.189520805112785, 57.15195755804739, 61.37647967184744, 61.92027315016716, 60.82149174905593, 62.71915405027328, 56.881808234799294, 67.4659279854067, 64.7973983518539, 61.78561033741121, 60.3180084689971, 54.74997258955433, 49.33425803338328, 50.21686976955783, 60.48760783287787, 64.04605657823625, 65.53203082853749, 64.71761734254899, 65.21932771128994, 61.12316123900875, 51.711241814398, 51.82108779107371, 52.02375273550711, 53.52528702828192, 53.49063288780951, 57.99570252818447, 69.69938047470586, 71.1921404254052, 70.88432850376253, 73.4484681775493, 71.5628279409101, 73.217283679593, 73.08864562742173, 71.21591783338978, 75.38086306664252, 73.17690680103918, 77.66392569388114, 75.23852025308918, 82.52771962073543, 73.89669310662055, 77.46733650084465, 33.355118151633974, 3.6414041778733655, 0.4671406818013038, 34.169598317915394, 89.11880770037251, 64.47152391556772, 44.04080767785349, 66.47003819865566, 57.190588981874534, 71.02001113276329, 50.002837796365064, 61.515425712831565, 83.00045936338364, 28.35428837806948, 0.32901843048391805, 0.1943516493925164, 0.19837367228202282, 0.15329195667178402, 0.15075311064720154, 0.1778439255130868, 0.0989413356047965], [0.03358589597947655, 0.06443351792592196, 0.035003143317636945, 0.016203811054208105, 0.03133880496475726, 0.048576501468496944, 0.07214587827723834, 0.08123158146777461, 0.5603982195738824, 1.7902815341949465, 46.180319401525686, 38.13091370367235, 19.634326042667514, 49.81232043235533, 52.672351944831114, 25.637290016297374, 56.44253415446128, 69.24389131607549, 67.42607670445597, 13.826035184244956, 0.1276037951691016, 20.651969294394217, 51.614053326268355, 73.2232613717356, 69.65165307444911, 67.25757952659362, 66.71326437304097, 67.97319243031164, 66.62166918477705, 68.80150287382065, 70.35206287137925, 67.19049915190666, 68.3424835820352, 65.16467732767906, 67.50308067567887, 65.9683435193954, 64.19534198699459, 53.912546557764855, 48.96628479803763, 48.44527244567872, 49.47281575972035, 49.07003933383573, 48.401032032505164, 47.48750417463241, 48.993196179789884, 51.97921422220046, 56.30696135182535, 56.24028890363632, 55.62115061667658, 52.95771614197762, 47.35883082112959, 47.04519025741085, 48.900965567558046, 57.150137578287435, 58.37815323183614, 59.52241059272521, 51.871862872954345, 60.02483875520768, 60.453334162312174, 56.39250040054322, 53.47419031204716, 50.20329836876162, 48.556742283605764, 52.16072582429456, 48.533404181080485, 45.17596513994279, 42.716313485176336, 44.926541620685214, 52.165973955585116, 54.21427488327027, 55.78445849880096, 39.18729428322085, 34.39681729962749, 41.13494719228437, 41.74920212837958, 47.37688156866258, 43.29328629278368, 43.78116246192686, 42.39753853890204, 42.01810806028305, 41.21706985658215, 41.62051308539606, 41.6570342740705, 41.61096211402647, 41.78728834275277, 40.745879450152, 40.833630715647054, 42.21980810165405, 41.57238560338175, 43.59841923559866, 44.44618463516236, 42.64175315057078, 43.1461307310289, 44.32577963798277, 40.85542340432444, 42.69721154243716, 42.10404719075849, 41.47868802470546, 40.42061298124252, 40.55211828600976, 41.655418257559504, 45.20182924885904, 45.898779515297186, 37.080714779515425, 27.794983886903335, 43.925972446318596, 54.32210083930723, 52.42652523902155, 48.81832907276769, 46.81000101950861, 47.20132804686024, 45.411197523916925, 44.09390872524631, 48.568238750580825, 49.64361929124402, 49.40409975667154, 51.9847055404417, 56.65562868118287, 54.78886681218302, 60.03304043123799, 57.00547272159208, 60.80661027662216, 58.37815715420631, 58.93773817246961, 56.75173459514495, 46.54726497588619, 42.71611344429755, 49.41361150433941, 58.779286184618556, 60.44421857403171, 61.01250725407755, 58.82063581097511, 57.70297604222452, 51.492593211512414, 43.94963218319801, 49.4398521607922, 46.48544057723015, 47.80951507629887, 49.402648479707786, 55.8535235927951, 64.34944798869472, 63.800743702919256, 65.9050521542949, 64.74947091071837, 65.43625831604004, 64.64404936759703, 62.70052671432496, 61.24994401008853, 65.27383688957461, 66.18071633000528, 71.85740578559138, 71.42345043920702, 74.62412018929759, 70.33674993822652, 74.11977398780085, 46.806961182625066, 3.9006865745590584, 0.2149290315085842, 23.551785407527802, 72.26771708457701, 47.12971733462426, 44.800158931363015, 52.04311355467766, 33.86830929786929, 37.96732341089557, 28.074517480788696, 39.90205995498165, 22.328196148718558, 2.458898069397096, 0.24791863146087817, 0.14322451946716155, 0.05185358046043304, 0.0702528213901866, 0.06035398098550016, 0.0222640932207146, 0.018664925967553453, 0.026385680727300145, 0.03931513431692316, 0.02935004837420439, 0.021916760447164698, 0.04132149177753637, 0.1261547934864798, 0.02754205597504493, 0.10878461548277449, 0.4651827449279447, 15.732746393449846, 64.20681491974862, 36.70208838678176, 28.439007651421335, 64.04011418742519, 55.82794189453126, 30.869170927232314, 63.73289846604871, 76.12087311283236, 73.70696021664527, 16.128377241473046, 0.2992569565051987, 24.647766236336004, 59.981347514737045, 79.30079352471137, 72.93433174010246, 72.63216018676758, 71.19181879105108, 72.79836670044931, 71.39419740246188, 72.86762791295206, 72.08934337862077, 72.824309256769, 72.91552789749639, 68.25186898631435, 71.28967408211001, 69.73952201104933, 69.00232822664323, 59.51555821203417, 53.58658582933488, 53.45983051484632, 52.31425915994952, 54.27245540003623, 52.65866287292973, 49.79190449560843, 50.036762375985425, 55.24899221235707, 59.3196907351094, 58.74869169727449, 59.87943649291993, 56.86512639445644, 50.216328482474054, 51.739973175910215, 50.592256284529164, 61.137289616369436, 63.160181430078325, 60.947650863278305, 57.217527820217995, 63.298539115536606, 60.50461522994503, 59.612432910550034, 57.04169188776324, 53.49291178487963, 50.76671546505344, 53.55328882894209, 50.245106912428334, 48.34803296673683, 47.72600781533026, 49.67691629163681, 53.0592780728494, 59.5545740281382, 58.91754188845235, 45.40866367278561, 37.69814683545021, 44.057544431378766, 44.630241855498284, 49.307197601564475, 47.31354313512003, 45.582989492724025, 43.23401927947999, 43.834510618640536, 44.73290597238849, 43.41523670381115, 44.95521414664484, 43.280911214890025, 43.639992437055035, 42.71815699915732, 43.27802042807303, 43.75077193783176, 43.403802994758856, 46.22304577981272, 48.07992327597834, 45.55650172695037, 45.55842761070498, 47.92237343326692, 43.717788727052756, 45.061569213867195, 44.577517355642016, 44.273957283266135, 41.8644452864124, 41.134496119714555, 43.36836830262215, 48.30121555636006, 47.607822879668205, 40.851548102594194, 33.30769669625067, 47.48629608461934, 57.59832328365695, 57.99708712485529, 51.490643793536776, 47.20498761823101, 48.99611442319809, 48.910826406171246, 49.34063188491329, 51.17881144246748, 50.912694315756525, 53.31664831407609, 54.76559931232084, 59.621313156620154, 56.83166465451641, 58.133691510846546, 62.72375499048541, 60.674563684771144, 59.25640721474925, 63.14674338986797, 58.45046212596279, 49.789021553531775, 47.34937790901431, 50.95643266554802, 60.28720217366373, 64.68939981152936, 62.28497905115928, 61.00495669149584, 61.204664168819306, 57.507481190466116, 47.51842421870078, 50.653453103957645, 51.010408401489265, 51.90567762620988, 53.66664924929219, 59.17369227255545, 68.63066011859526, 67.86407209211781, 68.86451967300908, 67.65144040507656, 69.32907735147785, 68.54724699451079, 67.5013469880627, 64.8958106194773, 69.41666387742566, 71.21510982513428, 75.16026112341112, 75.80472223220333, 76.00026023003363, 76.68878524534165, 76.36006709068053, 55.072964083763864, 5.666266737445708, 0.24312806916573357, 26.808780393292828, 79.3295366533341, 57.427558975835005, 46.297343315616736, 49.98648935748685, 46.331197292574, 47.2334522585715, 30.38604670955289, 55.36743994682066, 30.507400920314176, 2.696856010344721, 0.11805342900897227, 0.17438035007686387, 0.12349913437520305, 0.19220588308188225, 0.06135557965946294, 0.030513308837168643, 0.03734704294812776, 0.27483278645142434, 0.24704270185001437, 0.12696273279406373, 0.12515619787718021, 0.11493829334334982, 0.24934121077099156, 0.1300211779532894, 0.2661193330441752, 0.5601288017726714, 37.82809495925903, 77.77262241609635, 55.71167892025363, 32.24514230605095, 65.65903717471708, 71.2546943849133, 36.542800934084006, 71.90849073471563, 79.52614153585127, 79.30095041951826, 17.290352929023005, 0.6230748144368972, 27.103262139904885, 63.228050201169914, 80.17931030642602, 75.68432115739392, 75.59194933983588, 72.11946718154415, 74.57236059250371, 73.22778778691446, 74.62463009742, 74.26427410494897, 75.25564532126151, 75.4091041318832, 71.54902119790354, 75.37199066531274, 71.2561378171367, 70.47147550890523, 59.26114936028758, 54.99769772252729, 55.35472362272201, 54.46572234553676, 55.71112586605934, 53.98904846560571, 51.246417414757516, 55.28480345203031, 56.20625449765114, 62.02341187384821, 62.61683902432842, 62.03160962750835, 58.569827695046705, 51.93977871248799, 53.6998168114693, 53.51184898807157, 62.79895074905888, 63.76417152343258, 64.7689337115134, 57.530752612698464, 61.239306542181204, 64.31757088630431, 62.23228985263456, 58.8715717100328, 55.2524870441806, 53.70066796579669, 57.75687333076232, 55.02255378230926, 51.436750427369155, 50.36841446353544, 50.6615214194021, 57.02770471572877, 62.38288141066029, 60.97952012092837, 48.97167805702456, 43.66031815928798, 47.890645380943056, 47.52421755944529, 50.56390931529384, 52.06557696865451, 48.056106644292036, 48.513772718368045, 47.76901660426971, 48.223693832274414, 47.08152709468719, 47.59538504385179, 45.572810942126864, 47.805353441546046, 47.73469194289177, 46.77992820739747, 48.36030214063583, 47.17788796271048, 48.92475866502332, 49.336631067337535, 48.25850094518354, 49.090282686295055, 51.93468747600433, 45.786658563921534, 47.53246630391767, 47.79879131624776, 45.38973823670418, 45.24250814991613, 42.96459951708394, 45.60938704398371, 52.07338248529742, 51.32742220355619, 46.24201828433622, 39.067520787639005, 50.057817659070416, 59.862738963096376, 60.23033172853532, 53.93931281182074, 50.801428441078436, 51.74219323742775, 50.56243450410905, 50.970172728261645, 53.4523230983365, 54.13031262736167, 54.58799831328854, 56.411425836624645, 61.249143846573375, 61.37381246013027, 60.96255194756293, 64.09454099593624, 64.39652035313269, 61.4437993111149, 64.46807222981607, 63.9706019432314, 52.64653490435693, 47.393277075982866, 54.83995568367743, 62.25656540163102, 67.26008984350389, 64.71262024294946, 61.46428977289508, 63.64146017259168, 56.666246537239324, 47.58539868939308, 54.636816132453184, 53.49737151976555, 52.81496932429653, 56.086453545478086, 61.13370064766177, 69.77039106430547, 68.10456829686319, 69.83198796549152, 69.68782517217821, 70.49975579784763, 70.46160682555168, 69.25474059197211, 67.83110064844932, 72.71868767276888, 73.23567175096082, 78.28660980347665, 77.34185203429192, 80.55189624909433, 77.28708790194604, 79.30092688529723, 55.92103150583083, 6.360924378518136, 0.4474052149922617, 29.663899137127785, 84.6468585537326, 62.9042193197435, 63.82170484912012, 70.56954260795348, 51.55661413746496, 53.17454084273308, 52.42841974381478, 75.84673081674885, 52.80633226517708, 3.4509498169345245, 0.47284662723541265, 0.33668255793952173, 0.22903994206459294, 0.2725878117545959, 0.25526732987453865, 0.11050275151407528, 0.11689460611030941], [0.06321048536788552, 0.007781334119969078, 0.010680345848443048, 0.026232055200624372, 0.05839317128242505, 0.06451085450187807, 0.07983228356968011, 0.11656696562685313, 0.027353630904408715, 3.5351035335371574, 49.20685160544611, 59.18307065963746, 23.393653092845796, 37.65580877181023, 59.2524613103559, 26.396662842842844, 42.35728325382356, 64.69010583816036, 69.90388501075007, 11.003482899358197, 0.40627652839306866, 26.85904556705106, 58.14288946890063, 73.94959803550475, 71.14564464938256, 68.37425478043096, 64.75011417942663, 66.5138118497787, 66.23237394517469, 64.22745835396552, 65.46046718474358, 65.37568907583913, 65.10284900665283, 65.73313859201247, 65.20802736282349, 62.82731733014507, 64.33545689429006, 59.11132266444545, 49.86701788440828, 49.681481930517386, 49.27913304298155, 47.34044274976177, 46.73802552684661, 46.72278319635699, 47.41224173576602, 49.628914325468, 53.301394216475956, 54.576074307964696, 54.26245335609683, 50.312814866342855, 46.8804624772841, 47.34085459862986, 50.45077639241373, 53.89784551435902, 59.14371751969861, 56.460294646601525, 57.19493104565529, 59.77481903568391, 56.28662386248189, 58.41942833315942, 51.388811219123106, 50.83527065092518, 49.77779965246878, 52.29939337699644, 47.23905340317757, 46.190647002189394, 46.18366910565285, 49.226310483870975, 50.449552612919966, 54.93246086182133, 58.033753441226104, 56.11807961617747, 30.936039493929957, 40.8653195442692, 46.11529042643886, 48.20943993906821, 46.18552046437418, 42.84823848355202, 41.621627038525, 40.12834933496291, 42.25432103680026, 41.452517970915764, 42.39040766992877, 43.445686063458844, 44.927306482868815, 44.69174854217037, 47.7029364339767, 46.24810188047348, 40.58141839119696, 43.55205682016189, 43.936347115424375, 43.730861986837084, 39.30956240623228, 40.70118796440863, 41.58785935371153, 43.821857052464644, 40.45511414927822, 43.280326781734345, 41.93409089119204, 40.79621130420316, 41.68705217299923, 45.87553554965604, 45.00039200628958, 37.415387092098115, 25.192526578903202, 49.99751121767106, 62.35538559575235, 54.90996214651293, 50.53591143700385, 45.30668597067557, 45.24196294046218, 45.384419502750525, 43.878409785609094, 47.04256619176557, 49.27677962087816, 47.93377968572801, 50.2134886864693, 51.51816706503592, 54.56586830077633, 54.51799185045304, 57.91734141688193, 52.057900890227295, 54.073834419250495, 58.21380984398627, 52.60663263259396, 47.29566104950444, 43.201632268967174, 49.57293425836871, 53.552469053576075, 58.89119140563473, 57.9569887345837, 58.732582522976784, 55.88962116549092, 48.96403335755872, 45.14777506551435, 47.20232825125418, 46.30255222320557, 49.536307165699625, 48.39510140880462, 57.10783873834918, 61.971969989038286, 62.437747524630645, 65.96608423417615, 65.30960498317596, 62.72173496984667, 61.26292313298872, 58.489030791867165, 60.71723514987577, 63.417312406724506, 66.60190043910858, 64.50305977175313, 68.3410244603311, 69.80978735031621, 77.20053688172372, 68.83048918939406, 66.16869034305697, 10.61936911075346, 0.5217378069796871, 29.071076031654115, 72.94798943304247, 42.45480906578803, 48.662371712346236, 45.134827321575536, 26.654127220953665, 56.51942437694919, 32.50372063729071, 41.96587777906849, 5.314719407789169, 0.2925516034085905, 0.1487300103350032, 0.051064463933148695, 0.010241676242120806, 0.021730003532983606, 0.08022211507082948, 0.06256671104159567, 0.06351096420398643, 0.04860264421891301, 0.054519826906823346, 0.09469533158886818, 0.030400071465860934, 0.007501036912623433, 0.04489088310830055, 0.10236294474452735, 0.017572746972643563, 0.03174990306668465, 15.363452299948662, 66.59589921274494, 58.11252640139673, 21.57013143262556, 51.88389670464301, 65.4609182573134, 28.81234080560746, 52.65537592672533, 69.39379645932105, 76.35219881611486, 12.640554693437393, 0.5983231264737345, 31.318396060697495, 63.77897062609273, 78.16928386688232, 78.54990282366353, 72.83305614225327, 68.33843569601736, 70.36308473156345, 67.81346567215459, 71.41653137822306, 68.30648406859368, 69.76078125738329, 69.04851805779242, 70.51871653526061, 67.34414623629662, 68.10884368035101, 68.77258716091033, 62.456755330485684, 53.877335440727975, 52.8200880173714, 51.73295213330177, 51.00422674609769, 50.56882796748992, 50.562799284535075, 50.217822905509706, 51.938186230198035, 54.52930004365983, 56.532285828744214, 56.43705068096038, 52.464042709719756, 50.348916361408854, 49.29519907120736, 51.74207948869275, 56.5481282818702, 60.812376160775464, 58.98767386713336, 61.24595103725311, 59.6185008172066, 61.421257449734604, 59.99323621872933, 54.291090580724905, 53.69940496260121, 54.6066923295298, 55.850981896923436, 51.333686228721376, 48.42728445606847, 49.813701106655984, 50.22643250803794, 53.956653610352554, 56.69376196399812, 62.03721469448459, 60.19647775157806, 35.181232498538115, 43.625715009627804, 46.21328300045383, 50.87631825477847, 48.76192146731962, 44.668939959618356, 42.36966225408739, 43.44196373416532, 44.795824712322606, 45.635529641182195, 44.30662278206118, 46.736044729909594, 46.86407873707433, 45.85284071583902, 49.00275499589982, 47.0607542222546, 41.97727618678924, 44.15719616797663, 45.9250319388605, 45.850981512377345, 43.246468882406916, 43.98378426028837, 42.962661866218816, 45.679938716273156, 42.29172868113364, 44.006930166675204, 43.08324729242633, 44.65416046880907, 42.07998344975133, 48.181618567435976, 46.98129092493365, 40.578649197855306, 32.48419115620275, 54.06981398982387, 63.849628202376834, 56.652835953620176, 51.24129872168265, 47.316084830991684, 49.764742082165135, 45.83600198068927, 46.73543284016271, 47.49183447130265, 49.737356093622026, 52.66574667346094, 54.54853534698487, 54.71740907238376, 58.095703355727665, 57.63038081507529, 58.93705568005962, 59.600736402696185, 59.40848927344046, 60.91887243332402, 55.92655812540362, 49.56892951842278, 45.209136624490064, 51.08508640719999, 55.582150490053245, 61.015135242093, 61.92084973858249, 62.52099590916788, 60.43706417083741, 50.6618469761264, 49.02010363917197, 52.17763123973724, 50.54669011023737, 51.5651805939213, 51.66619339296895, 60.42011560932283, 67.31864298543623, 67.80176916430074, 68.8111597491849, 71.2964048693257, 68.22540083239156, 64.6778876550736, 63.83089888480402, 64.47761535644531, 67.2151473260695, 71.29105475641066, 69.29490566253662, 73.7518556656376, 75.19131060569518, 78.72946893015217, 73.8798661385813, 72.52345561981201, 14.407707971911277, 0.6313494833246355, 33.71218719790059, 77.071137889739, 54.62644146334741, 57.80637364233694, 46.635922308891054, 43.028879319467855, 57.24248978399462, 35.02447105223133, 60.35669088363648, 8.312381986648806, 0.2887151576578617, 0.0814188746435027, 0.06743030832900156, 0.08700709534628738, 0.07036000475167267, 0.1090044673952845, 0.06347698437410497, 0.026418226057543393, 0.37773788395908575, 0.14615977002728373, 0.16555215202031598, 0.07529551088209115, 0.10187597329457922, 0.12687215821877604, 0.1770634964228638, 0.10540442105623023, 0.21347704974393691, 41.736285763402144, 76.86154211721113, 79.51883023785007, 39.25943059305991, 51.29563923804991, 77.89503958917435, 37.66184922187559, 57.397819565188506, 74.97863969495221, 82.7726794827369, 14.07104015350342, 0.6582631326971516, 33.34696354404573, 70.19540340669694, 79.75112868893532, 77.47853879005679, 75.65000041838616, 71.1566900437878, 71.52223925436698, 69.07249942902597, 72.02451444441273, 68.46039787415536, 71.15173216789, 69.63359448217577, 71.95453151579827, 72.96646379655408, 69.17514785643547, 70.72452329820203, 65.54543748978647, 55.85653597308744, 55.04689208922848, 54.79292254294119, 53.628990573267785, 52.55551238213816, 52.44271678309287, 53.18023220185311, 54.90326273825861, 57.06348065407046, 60.58352155070151, 59.00466557471984, 55.960443481322265, 51.220196370155584, 50.44781500293363, 55.8313072881391, 59.50830967195573, 65.32202712951168, 61.99426081872756, 59.54098301549112, 63.765748316241854, 63.93366498331871, 60.97574287845243, 56.605218379728264, 56.22546626675514, 56.65471869130289, 59.09171865832422, 54.9729867904417, 51.36597125760971, 52.35495767285747, 53.95389226175124, 57.34294168410763, 60.042913036961714, 65.01798852797478, 61.07120944607643, 39.13740957936933, 44.40420742957823, 50.6952420357735, 54.40731825367097, 50.733932295153224, 47.351276336177705, 46.39825021066974, 45.49837220099665, 48.82716617276592, 48.74786761499221, 47.59283550323979, 50.42708527657294, 51.05044795620827, 51.759581104401626, 54.1916859534479, 51.30600998478552, 44.984549553163596, 48.615895548174464, 49.926100546313876, 47.892983113565755, 45.35125586294359, 45.88643581636491, 47.74396442597913, 50.29858058498752, 43.924882027410696, 47.446676223508774, 46.52425243008522, 45.5581138210912, 46.37191933970298, 52.165173792069965, 50.35525098923714, 44.43814377630911, 37.40533405734647, 53.45924608169064, 67.56532869031354, 60.56362336681735, 54.65834209995886, 51.464524730559326, 52.15805861257738, 48.520303464704945, 48.856325072626916, 48.85086121097688, 52.089793682098396, 53.05502230121244, 56.96972031747141, 55.57152871162661, 58.368174722117764, 60.23262239271595, 61.27170531980453, 61.162785022489494, 59.79495256177841, 61.83032143500544, 57.48729667355938, 52.531613380678245, 45.86163466976535, 52.489059586678785, 55.397524526042325, 62.38816876565257, 62.55527350210375, 64.60206431727256, 61.763186147136075, 53.11146913036224, 50.21345338513775, 53.62643711028561, 52.82543028554609, 55.0112416667323, 52.45158918442265, 63.05175927377517, 68.61288393697431, 70.371337398406, 72.54137300675916, 71.09431651330763, 69.07322114513767, 66.05138794068368, 65.74660016644386, 66.45441147588915, 70.40435591051656, 73.1676107837308, 71.09747009892618, 77.02015492223924, 78.05266395691903, 82.30878076245709, 75.8575330242034, 72.93576732758554, 14.658615127686533, 0.5760750138471203, 36.39637493318127, 85.40446435251545, 60.49858654699018, 70.48783963726413, 62.20052257660897, 40.56637610158613, 75.97547869528495, 52.02665136706445, 83.22127311460434, 14.72071115047701, 0.46591491047893807, 0.1847041815879845, 0.14024606154810998, 0.1536708944026501, 0.16153351523943488, 0.3728976791664478, 0.23446045845987337, 0.15868705426973684], [0.026806799259277123, 0.04047136400796233, 0.027740945806726817, 0.08531951856228613, 0.002989577206467549, 0.01767074302469771, 0.06168605083779943, 0.12649196410371413, 0.2159399764552232, 3.1544603070905133, 54.853460404180716, 53.116234810121604, 47.455850647341826, 20.062756730664162, 57.09416143355831, 29.68816488019882, 33.332011468948856, 64.2795709640749, 70.14294562801238, 14.693566387699498, 0.8020773253613903, 35.00832657660208, 53.40305812897221, 71.09393212103075, 68.5933191545548, 70.31466699415638, 65.03109316672048, 65.38111371378746, 65.02759049015661, 65.54450396568545, 64.6232411938329, 68.1108990023213, 65.28615313191568, 66.13603268900226, 64.36763601918375, 63.49728953453803, 62.54798966069376, 64.08751210858746, 51.77436059521091, 49.22614574432374, 45.33327964044387, 50.37069336060555, 47.53359202415713, 49.03281996327062, 45.09194012611143, 48.3481074917701, 50.606282680265366, 52.981972079123224, 51.31350171181464, 47.931312514889626, 46.46255354727469, 47.07423933090703, 49.98688943924443, 58.62749045894992, 55.97580348291705, 57.831402286406494, 58.598276645906516, 59.74421278122933, 59.239823433660696, 54.22492411828811, 50.79917307822935, 50.53617031343522, 52.50237211104363, 54.10477799753989, 51.29042248572073, 51.03730017139066, 51.63618726115073, 48.19866911057503, 53.63377586487801, 53.5344575297448, 57.105795183489406, 64.04179688422911, 30.315832361098263, 41.04794509949223, 45.61624726941509, 47.82914261664114, 45.70168433650848, 40.69678706507529, 40.93806382148497, 39.95551401568998, 40.47087423263058, 39.83471678149316, 39.762549092692716, 40.04755635415354, 41.99547990675896, 42.887874034143266, 44.0087579911755, 43.559532857710316, 44.34274781134821, 40.4797976247726, 41.09404471612746, 41.17746960732245, 38.81288443842242, 42.15617549034857, 41.95324774711363, 40.668506776132894, 40.895278607645345, 41.135794424241595, 40.83898082856209, 45.347200132185414, 43.38703093990203, 42.232775457443736, 43.62821748179775, 36.37543732120145, 29.965725521887506, 56.55215655603717, 57.19408773606824, 54.52422057428668, 47.717715924785985, 45.990131516610425, 46.400195706275206, 45.433504043086884, 46.386632150219334, 48.83766635771721, 51.2905401568259, 52.94614122759912, 50.91570277367869, 54.55347361103181, 54.043640013664, 55.316868828188994, 52.03883817118984, 57.28574960462509, 55.76512513622161, 53.220585546185895, 49.40155413842971, 47.0485556510187, 47.1168754946801, 49.299356783590014, 54.421662361391135, 57.012344714133974, 58.08000995266823, 55.621052557422274, 53.07864281439012, 47.557585162501184, 45.33044376680928, 47.224693605976725, 47.15036076884116, 48.58163364471928, 48.5581543368678, 54.21929159472066, 61.60773085009668, 62.8614733296056, 62.254584604694, 64.34062657817718, 60.42116288215884, 59.10576858828145, 58.52807798693257, 60.49996329892067, 62.57425385136759, 64.7985319168337, 63.00643628643405, 69.94964338118031, 71.18028702274447, 73.54458978099208, 71.54421237207228, 73.20877213631907, 18.750011997838175, 0.41052984854867386, 36.26750153879966, 66.59809574004143, 32.73538366440804, 34.762025264001664, 30.18060080466732, 25.9730625537134, 42.831309533888295, 42.54251326284101, 32.02210653212763, 0.5073572947613655, 0.06296904509766929, 0.07441358280278022, 0.1108605758617482, 0.017283253837376833, 0.04297199373644206, 0.0825399217466193, 0.0658821672080986, 0.05804838192078376, 0.05587305227715162, 0.01743355262724142, 0.05001479324193732, 0.04566614110503466, 0.010510166119333478, 0.019214417853002107, 0.11143092066049577, 0.07518140208576957, 0.3200221067715076, 4.563645335935778, 71.0735514856154, 60.863025726810584, 32.92150797382478, 29.26874976004324, 73.41785015598421, 29.349623149441136, 46.688760557482325, 69.44275548381191, 78.26137327378797, 15.800588688542767, 1.1051486336415814, 41.094899792825025, 61.326610657476614, 76.35943166671261, 75.52830496141988, 73.84406274364841, 69.84050735350579, 69.09156214806342, 69.57562969576928, 69.89647957586473, 68.94095882292717, 69.61757552239203, 67.54341048579063, 72.46640082328551, 69.04711384927073, 66.75724983215332, 65.66686230321085, 68.45313364459624, 54.18994049872122, 51.590483803902906, 50.80255808368806, 53.24705370010869, 49.47392186810894, 51.39099990167926, 47.893963706108835, 51.098018461658114, 53.861053682142696, 53.01259010068832, 52.56496529425345, 51.47812751031692, 48.98830498418501, 49.37843961100425, 51.84115463687528, 60.740239850936405, 60.25371689950267, 61.94317194723315, 59.17479838094404, 62.376895873777336, 60.803550827887754, 57.10168846191899, 53.846081995194965, 54.349906521458784, 55.23955498972247, 56.80862465212422, 53.85978675657704, 52.47161288415232, 52.4749312093181, 51.83178409453362, 55.81966961583784, 55.811899400526485, 59.66012893184539, 63.84118726176601, 32.57749257549163, 41.88688908853839, 48.14101811378233, 49.03786020894205, 48.32084701907251, 44.53301414366692, 43.8318943977356, 44.22834404053227, 43.73974615527738, 43.003721237182624, 42.43760162784208, 41.93382417002032, 44.19746322016562, 43.74657892411755, 46.15759711111746, 45.563879705244496, 46.18340238448113, 43.406548653879476, 42.70783332086379, 43.19787463834209, 43.307367601702296, 43.37642877332626, 45.21468677828389, 44.9040154487856, 41.76622129255726, 43.39556209502682, 41.99066715855753, 47.106332163656916, 44.07306132778045, 45.48884084147792, 46.77469968795777, 39.097024856075166, 36.948503448117165, 64.01526989475374, 58.39219531705303, 56.11150964613884, 49.99998623324979, 49.61626075929212, 48.81507742789484, 48.614271686923125, 47.821513606655984, 51.524109455846975, 53.12112992809665, 55.32194437519197, 53.28801108944801, 55.23660928972306, 54.378053449815326, 54.52614645804129, 54.68142524842293, 62.541651110495295, 58.82464839566139, 57.67739826633085, 53.41818278835666, 50.22863688007478, 50.20424365997315, 52.487290597731075, 57.33506164243145, 60.226295609628, 59.78167926111529, 58.746361809392134, 56.23240493958997, 51.21806652315202, 48.57306326589277, 52.562529502376435, 50.17572410645024, 52.05683400554042, 51.98989483617967, 58.72121941658759, 65.2261055669477, 67.07067074314241, 65.96140876893075, 68.08835321857084, 63.73576571864467, 63.21589869837608, 62.03094282457906, 64.69026665533742, 66.44206385458669, 69.61351979163386, 70.36646581465199, 75.24598844589727, 76.68613372310516, 77.40481392029794, 74.90512663318266, 79.98129337064682, 22.676696777343754, 0.2019252558989871, 41.28265973060362, 74.89697594796458, 38.654781541516705, 39.965806315022135, 37.727572456482925, 41.161168236886304, 37.43549708397158, 55.001525955815474, 40.46875223036736, 0.5274461426081196, 0.045453279744833715, 0.055767090825904767, 0.07714479350514951, 0.037206703301278815, 0.07108143741084684, 0.03392044657600984, 0.06208091170617169, 0.04948747960189658, 0.12795253371399257, 0.08328546319277057, 0.15126312602191203, 0.17022488999270624, 0.08784610718008011, 0.19200130696258239, 0.2894996623358419, 0.1842023939975808, 0.7174568467082516, 13.471584320068361, 92.91257119947865, 65.92052982699487, 70.56200381248229, 29.989808874745524, 75.61758595128214, 41.64923267979776, 49.763639896146714, 74.06103257210025, 80.27055248137444, 17.96848954692964, 1.2782331459945249, 42.264570190060525, 66.52635558958977, 81.37984583454748, 75.14326157108431, 77.74115716257404, 73.42784435518327, 69.56254466887444, 70.46743546762775, 69.60751856527021, 72.4782620706866, 73.84065812633884, 70.37443607084214, 73.74153198734408, 71.72624172702913, 69.30126774695613, 66.82850360870361, 72.37901041584631, 57.85346561862577, 55.24827049624536, 50.826692427358324, 56.52118159878639, 51.81167018028998, 54.73918607158046, 49.973435709553385, 53.87094982208745, 57.14479138774257, 56.57051324844361, 54.90427470976307, 53.78440664660547, 51.760887253669004, 51.53761809872043, 56.20698798087336, 64.98875118071034, 62.18735910231068, 63.231631325137236, 59.94610894110895, 66.39751357416954, 63.36817295320573, 60.316482667000066, 56.22635664478425, 57.14167702582575, 59.551730309763265, 60.01777064415717, 57.186219461502574, 57.03457670827066, 56.46040839533652, 52.542239081475046, 61.48917721163843, 58.12211267409786, 66.22728270869102, 64.98573095567765, 36.39823021427278, 47.356995151888945, 50.895526101512296, 54.6854966686618, 53.162212833281494, 46.067594405143495, 45.42259985400785, 45.469374118312714, 46.87833263028053, 46.26134772454539, 45.79923760506415, 44.19338003281624, 48.58374387987199, 47.553784385804214, 49.11652334274785, 50.50652111730268, 49.55167108966459, 47.913202931804044, 46.71334205135223, 45.994430434319284, 44.18996757076633, 49.000464331719186, 49.44744979181598, 48.106156087690785, 45.33813161234702, 46.11967955866168, 45.43493178582961, 50.74544445160897, 48.1123455878227, 48.44323281318911, 48.217167008307676, 42.768300579440215, 39.419055369592485, 57.81236702396024, 59.57202073066466, 57.5826887161501, 52.70882998743365, 52.34037822292697, 52.34694034822526, 50.9707179377156, 50.62426282513527, 53.43814373016358, 56.19847643759943, 56.41628173089797, 54.71762480274324, 58.545728652708, 59.54701562081615, 58.018385594890965, 56.67357744709138, 62.845764237065474, 61.21985550849669, 59.70715030547112, 54.790780928827104, 51.521524613903416, 53.81285951983545, 55.235730678804465, 59.21250804778069, 61.26281722899407, 61.147009249656435, 60.23256355716337, 60.22581315809681, 52.47888888082197, 50.122626981427594, 54.86598453214092, 52.47052638761459, 55.84516109958772, 54.31844519030664, 60.10387451417985, 67.72119583622103, 68.0328909043343, 68.99781750094506, 70.1633027292067, 67.32778995267807, 65.84547135137743, 65.06762612250544, 67.29688167572021, 68.41420804300617, 72.69444742510396, 73.647520619054, 78.33331738748859, 79.16437349011822, 80.08615401483353, 77.92850525148454, 81.48943685716199, 24.689327670681863, 0.35501108895386424, 43.3880703679977, 78.79825945823424, 48.23898715357627, 49.05146691106981, 46.94118076755155, 38.09130953204247, 58.159763505381925, 66.47128551237046, 62.484600236338956, 0.8966606855392457, 0.12598020204853627, 0.17426624894142154, 0.16995804624692087, 0.11459287962005024, 0.11332855875333471, 0.1333251159878508, 0.1493747652538361, 0.1323546204836138], [0.07666681592743244, 0.13851724625114473, 0.010335937615544086, 0.08442090508798439, 0.06552228208390937, 0.06924880187838309, 0.021620010544035225, 0.04163129390367577, 0.03339078104604156, 0.3096347818932226, 40.793567626707016, 63.18667311822215, 60.876326484064904, 25.89845515066578, 30.96485910877105, 45.52764484959264, 25.072562848368, 58.10464635972054, 74.76563930511475, 18.783818906353368, 1.2083990222984746, 48.15626436664213, 52.550605497052594, 68.44028395991172, 65.20647018186509, 70.0348529508037, 61.54500038393083, 65.51191299192368, 63.28919602978615, 67.87583135789441, 62.09829776517807, 64.7582648646447, 63.949377998229004, 62.55731705696353, 64.1473517879363, 63.67846773516748, 63.601726562746116, 64.16024069632253, 51.44558752736738, 46.35583369962631, 47.74596875713718, 49.98175113431869, 47.84634613221692, 47.22946320810626, 47.212228313569106, 44.56655825338056, 47.604971316552934, 50.44122149867397, 48.47034423582016, 47.629748928931456, 45.6468496014995, 47.42487569009104, 48.126191554530976, 56.67350684442828, 57.33968611686461, 59.793799384947754, 59.18189002621559, 60.57796355216735, 57.18029668254238, 54.93061734784035, 48.723325344824026, 54.02580107412031, 51.778106458725475, 54.83422117848551, 53.7911884246334, 54.748136920313684, 48.24813019844794, 53.01799512678578, 51.26798260596491, 56.85642265504407, 55.31516651953421, 55.78675700772194, 32.21014103581829, 37.20825456803845, 45.71586762705157, 45.532524278087, 47.22415231889295, 42.66708773951377, 41.83981672410042, 40.40469208071309, 40.07940207758258, 39.39811383524249, 38.07263512765208, 41.767233264061716, 40.66130922686669, 39.52505350112915, 43.125044068982525, 45.61707881189162, 44.25347074385613, 43.588181849448915, 43.043337175923014, 39.90438199812367, 40.56657222009475, 41.5734407209581, 41.65204109684114, 40.20417659513412, 38.98906946182251, 39.341984718076645, 41.08146567498484, 43.12003127990231, 46.24893734532018, 42.673026207954656, 46.276005621879335, 32.76982991926132, 32.055283900230165, 63.07845884753812, 57.11160029134443, 53.37569175227996, 49.52191991190757, 44.908031955842056, 44.31708374331075, 46.79262099727508, 45.78750187350858, 50.928575992584236, 51.84138997908562, 53.09346545127131, 52.89565640111124, 53.37941015920332, 51.8098109768283, 51.84914450491629, 50.80409173042544, 53.537995507640225, 52.97246425382553, 52.13947834507112, 47.51138356424148, 45.372550410609094, 44.312145479263805, 49.10389723316316, 56.40433811372327, 56.68944735680857, 54.47335527789209, 54.16530801403908, 50.89098399685275, 47.17328310012818, 47.533191942399554, 48.053792445890366, 48.30476922373618, 49.63115007646623, 46.825878773966146, 54.490335218368045, 62.796377674225845, 62.37462089907739, 61.711069614656516, 63.46249811110958, 57.38090630500548, 58.07506384388093, 54.5960940853242, 58.92910895809051, 62.12287141430763, 65.00519767884286, 64.73127111311882, 67.89005387213923, 67.3144538940922, 71.68056180400234, 71.10165134552987, 77.38480198767878, 27.717603368143884, 0.153307385682579, 40.53603656830327, 63.81091440877607, 35.917983055114746, 39.76860523223877, 29.323370725877826, 41.797309998543035, 42.68796259357084, 54.9834006832492, 16.770974243840865, 0.3586516613441129, 0.20522050649648715, 0.14687128184783846, 0.046830246179935434, 0.05245915381237865, 0.05021013034087035, 0.0749373417948523, 0.0673005789999039, 0.04781946487304184, 0.04250135528103959, 0.024175530472289652, 0.05329257320432414, 0.05685063026424858, 0.048994965505816286, 0.06777828844684748, 0.09490150883192978, 0.014254463941700036, 0.05956443927941784, 0.2829179251866956, 42.51429573182137, 73.3217050183204, 52.45209124780471, 26.303202567561982, 49.5355030798143, 45.227744348587535, 34.05541812219928, 67.04571662410613, 82.00222399926956, 20.501381658738662, 1.8652804388153938, 52.135865842142415, 61.45558211111254, 73.34895764627765, 70.54353729371103, 74.73502912829, 65.20212419571416, 71.43401730445125, 66.75129567423176, 73.71604442596436, 66.87459930296868, 69.59998761453937, 68.4347769521898, 66.91510954210835, 67.25417490928405, 68.47092551569786, 65.01377590240972, 66.39648591318439, 53.84309707149383, 50.86883045011952, 53.82579941903391, 54.279001835853826, 49.54364199792185, 50.463673145540305, 49.216920329678445, 48.54748156762893, 49.68767535301947, 54.209870061566754, 52.009906768798835, 50.383837223052986, 48.30583610842305, 48.80878202376827, 49.698046099755075, 58.810684757847945, 60.19336338966124, 62.49259402675014, 60.036582331503595, 62.041925461061545, 57.43789442123906, 55.877559877211056, 52.51222510491648, 58.17255043214368, 54.352275633042865, 57.85711342288602, 56.3820747406252, 56.80852267049975, 53.238055782933394, 54.84915364173151, 54.04569925800447, 60.55924207933488, 58.15834360737955, 58.07293399687737, 37.454053817256806, 38.747824084374216, 47.90698205271075, 47.77685742224417, 48.53993492741739, 44.00800489610241, 44.275369336528165, 43.38387735428349, 44.22417848340927, 41.62469040962958, 42.016523422733435, 44.699679574658795, 41.79006930320494, 42.15282578622141, 45.84765926484139, 46.90290627941009, 47.272511220747425, 44.710501393964215, 46.139267875302224, 44.006561463879, 43.76607702624413, 45.3420304482983, 44.51176274207331, 42.89788392282302, 41.23111978653939, 43.27885589291973, 43.56636170418032, 43.70967334316623, 46.679652813942205, 44.26775993839387, 48.21785342308783, 37.0744703662011, 41.12223479055589, 75.88893551980296, 58.62459967213293, 56.989575355283684, 51.22455412341703, 49.04490478577153, 47.805996710254306, 50.05982591259865, 48.45415661411901, 53.489915094067975, 55.76507806777955, 56.903161618017386, 55.500443596993726, 57.202924836066465, 53.315408845101636, 54.022419991031775, 55.505774098057906, 55.86564763899773, 55.49300286077685, 55.17760507522091, 49.223031382406916, 49.85591757682062, 47.19218892435874, 51.95402868332402, 56.70527804282404, 59.028866598683024, 58.58092015789401, 58.128133512312374, 54.20869335051506, 50.59969702074605, 50.50043752116542, 51.01365612399194, 50.61894801355178, 52.839970511774865, 50.023567522725756, 58.976146021196925, 65.81445324805476, 65.50482134665212, 64.77732366131198, 66.19104785303917, 63.02768768802766, 62.47916383128013, 58.571839870945105, 64.52850810943112, 65.56163295622795, 70.89032188538583, 70.35459672251056, 72.59081056041103, 71.09016664566533, 78.91289464889034, 73.79639810131442, 82.29958672677317, 31.55321659580354, 0.022938591503207723, 44.90095207768102, 73.12994818533622, 42.2020201529226, 48.9935060470335, 33.15465365686725, 51.672563322128795, 46.93531290177376, 69.55337416741156, 16.21309357304727, 0.7430717012574597, 0.36723662648470173, 0.08749163829751554, 0.258432314881394, 0.07760584820061922, 0.06355979081784045, 0.037222484712518995, 0.11541610238172355, 0.073089859478416, 0.1484361390072492, 0.1937011181707344, 0.1956404850728089, 0.12742247747918292, 0.21025912806151376, 0.20535527668412656, 0.19724881006104333, 0.1265460422502891, 0.19593297744229918, 0.4000660680955456, 67.83242640956756, 76.35608196258545, 82.28214002424671, 32.52681751405039, 45.167649715177475, 60.61442198291902, 37.99687847014397, 70.1805768474456, 86.44226858692785, 23.247478123634096, 2.2612162511194907, 55.735099392552534, 65.29087958797332, 79.62415372171711, 71.37500916757892, 75.54277066261538, 65.97057927039363, 72.3264035870952, 67.77467343115038, 74.11936606130293, 66.89422684331095, 70.1367796621015, 70.11027228447699, 70.23043017233573, 69.96041420967349, 69.63379844542473, 68.55910824191186, 71.61454046926191, 57.26636525123351, 53.10031783196234, 54.63882046361124, 58.204047064627375, 52.17527781763385, 53.62833553744901, 49.502759133615804, 51.678023261408654, 52.07708128036992, 56.77807331085206, 55.307329623929924, 54.662648862408055, 50.38031493463824, 51.847583401587706, 52.58066261968305, 59.68012125261369, 64.08623341591128, 63.972500370394805, 63.38765144348145, 66.34659336459252, 60.24491510083599, 60.620933117405066, 55.508825702051965, 60.44388909493724, 56.84978992708268, 59.785276074563306, 62.30630497778616, 60.974197464604536, 55.33218960608206, 57.6138597919095, 57.193173823818086, 62.95521797672395, 60.34799498896445, 59.71605408576227, 41.68926831214659, 41.605474718155406, 49.86788472821636, 50.19584978780439, 50.869387426683986, 48.131812310987904, 48.719406897021884, 46.29551549111643, 44.9633805213436, 46.915591224547356, 45.90286662501674, 49.11176158535866, 46.614902327137614, 44.573504770955736, 48.99719307499547, 52.57788558160105, 51.06759655860163, 48.45270925952543, 50.6588149839832, 46.902129650115974, 47.89654462568222, 48.74025429448774, 48.19902212389054, 48.688667281981445, 43.03127196527297, 46.48562100625808, 46.07989495800388, 47.06349988137522, 49.74631870946577, 50.249131264225134, 50.42076633822534, 40.93611440350933, 40.604019088129846, 68.26395773118543, 62.72810097663634, 59.84224457894603, 55.44971950592534, 48.340643221332186, 48.999468049695416, 52.27967169977004, 49.58421891735446, 54.9990430954964, 59.34733952245405, 59.15293116723338, 57.7497777631206, 58.8353015530494, 55.64781881147816, 55.62177427353398, 56.58497894963911, 57.28374919583721, 57.775167265246, 57.74498462677003, 49.65146403158865, 52.80995261284613, 50.65237837453043, 54.857010149186664, 62.09188861231651, 59.61237407499745, 62.16558602548415, 59.78631942502914, 56.9484414592866, 52.8205979254938, 53.84509355791154, 53.397311856669766, 53.25813439584548, 55.312514997297725, 50.80758656224897, 61.53482967807401, 67.37290505440005, 69.5457883034983, 68.0007980715844, 68.58335633431712, 64.09940081257974, 65.90542085709112, 61.36761903762818, 67.92166033098775, 68.02507754295104, 73.18055460529943, 70.89209479670372, 75.244411653088, 73.28703911073747, 80.00540025772588, 78.21198278857817, 86.36320929373466, 32.83763985480032, 0.2064150673968177, 46.61320001848283, 78.39192544260334, 52.09529284507998, 60.63973303764098, 40.407069037037516, 58.46996022808937, 56.18744281030471, 82.00725247783046, 27.016336533331103, 1.1822900103945886, 0.38489869164843715, 0.36339457297036726, 0.3739827967459156, 0.19640582223092357, 0.27602046788219486, 0.2356883595066686, 0.2374551421211612, 0.19121150095616618], [0.024177859379579465, 0.06632712639627919, 0.02635442050954988, 0.057442839212355115, 0.09475268093087981, 0.009487532586189769, 0.10091548289863334, 0.07877774822014956, 0.23301503440785795, 0.558942100934444, 9.179284630283233, 57.19058113713419, 56.59608317959694, 31.922947052986395, 23.487334982041393, 51.82062495139338, 26.717981446173887, 53.10937458469022, 78.30232281838694, 24.537067144147812, 2.029633387442558, 46.962855785123764, 52.02640818011377, 65.89683086641374, 64.68043327331543, 71.1789220379245, 63.48101169832292, 66.68413685214135, 66.43152836830386, 68.03456967876804, 63.70703435713246, 70.98647486778998, 63.85659433180287, 65.77876752422702, 60.206875954904866, 62.8277527132342, 62.972841185908166, 61.62677395728327, 49.98198647652903, 47.93951026854977, 48.14253214866885, 48.62255181035688, 46.617130233395486, 48.468386973104174, 46.28031238432854, 45.77813525353709, 46.311499149568625, 46.51772560611848, 45.78452871691796, 44.29811123878726, 45.71339653384301, 47.880090282809356, 50.67751292259463, 59.51615441230036, 57.17487596696424, 60.3121994387719, 58.8053777910048, 60.135386836144235, 55.039302302945046, 53.39666466559134, 52.087459871845866, 54.57831398133309, 56.9012043553014, 55.968307833517756, 53.90683166442379, 53.84689392582063, 51.25747849864345, 51.884751781340576, 49.96046050902336, 57.660967457679014, 55.44780538928125, 60.5828155240705, 40.04242197159798, 37.5621739510567, 44.7526119601342, 45.96909976774647, 47.63148261654762, 45.46533407703523, 43.15497959813764, 40.47691468269595, 41.28755484857867, 38.44844133623185, 38.42990813716766, 38.13017629807995, 39.46223674281951, 42.57091906762893, 44.387294169395204, 42.95770006795084, 44.53699142702165, 46.386259525052964, 42.268688678741455, 38.766757365195986, 40.005351651099424, 39.95062674245527, 40.73770130834272, 38.68129284151139, 40.26718554958221, 41.917844433938306, 43.05861088537401, 40.65234661102295, 45.53190846596995, 42.83053290459418, 45.59598038273473, 31.003539562225345, 37.452579006072014, 53.984980967737016, 53.40825526945053, 54.34288547885034, 48.45081867710237, 46.99480349017728, 47.175452170833466, 50.19350421044135, 48.893175740395826, 53.28076254936957, 53.113344023304606, 55.95212413418678, 53.05151570227839, 56.08208010273596, 54.010707793697236, 50.58516856162779, 50.55009472754694, 51.279490840050485, 50.23610507288287, 49.464904339082786, 44.64486837387086, 45.45860721218971, 45.27414206535586, 48.22211703946514, 52.86927453933224, 54.82321108541181, 51.78747700106714, 50.718744877846014, 47.969304592378684, 43.948812407831994, 45.01628152785763, 46.625884963620095, 48.3696295369056, 46.66869763405093, 49.516287388340125, 53.28912112020677, 59.700254778708185, 60.590444534055656, 59.62365481161303, 58.117166565310576, 56.859140857573486, 54.49820741530388, 55.60269978738601, 58.936177069141024, 61.86575612714214, 64.04240092923565, 64.75158114587107, 65.55278408911921, 68.55130272526895, 69.17990961382466, 70.14986468899635, 77.89662422672396, 34.156670185827444, 0.2762227150942049, 47.3993645944903, 50.11161296598373, 37.254577759773504, 32.44146477791571, 36.7847405710528, 48.5960836564341, 44.78474401658581, 62.19978909338675, 4.997451632253585, 0.4099768862849282, 0.16058060911393937, 0.06399837615449103, 0.1159162505439693, 0.05384540523312265, 0.11587522653562408, 0.09563994098214373, 0.03783162037331251, 0.15215191058814526, 0.021974105958736712, 0.10583386696394413, 0.026149078302325744, 0.05295898404813582, 0.09055357681767595, 0.0664174558234311, 0.07269555402378883, 0.21824606964665078, 0.15850117069578942, 0.633196184231389, 7.0082556816839405, 66.87685074344759, 60.16027035251741, 20.104928093571818, 33.14993504554995, 57.317826747894294, 29.741277694702152, 65.94861399742865, 83.12555159291914, 30.890753769105483, 2.778168705201918, 51.42841539075298, 59.11573925325948, 73.58818300308721, 67.58286168498378, 75.1647404701479, 67.54095508206275, 71.58399305035992, 69.10397252728863, 72.82299918513145, 67.46471205065328, 73.72614060678791, 66.92200506887129, 69.5570533506332, 63.68166446685792, 68.0228574814335, 67.3968001334898, 65.20293612633982, 53.5092092329456, 53.09506185593144, 51.30799078172254, 52.108440629897586, 50.33168146687169, 50.60232108639133, 48.498212675894464, 48.35032363091746, 47.534317662639005, 49.986006905955655, 46.84830296424128, 47.45899638822002, 49.86053812888361, 49.47256080565914, 55.48651133814166, 62.42552934154388, 59.766448697736195, 60.54647476442399, 60.61900723365046, 63.17155630357804, 57.16921206443541, 54.956583438381074, 54.35216188430787, 58.629333972930915, 57.90541348918792, 59.35826332338395, 56.848613216030984, 56.0293948265814, 54.687234278648134, 54.57139492034913, 53.44736522243869, 58.966963752623535, 58.931595740779755, 61.93929272313272, 43.06869529908703, 39.62590940536992, 44.88079109499532, 49.40790445573869, 48.143661791278475, 47.670074816673036, 44.88968703054613, 44.78852125906175, 43.73671808550435, 42.25654894305814, 40.96843473372921, 39.87019854207193, 41.44049590633762, 43.98057576148741, 46.27562122960245, 45.279519634862105, 44.65680806867538, 49.63854766661122, 44.80918822749969, 42.7123518913023, 44.58102003220589, 43.02632193411551, 43.2459746637652, 42.15887015865695, 44.18739841830346, 43.11353975726713, 45.25214149105934, 43.086016485767985, 46.392813805610906, 44.973892473405414, 48.50896781490695, 35.64236987021662, 50.71115509156258, 65.55307434451196, 56.38863294355331, 56.54603765856836, 49.493733759849306, 52.52824014233005, 49.62162263931767, 50.74742917091616, 51.88838781849031, 57.44612747623075, 54.10873174667359, 59.393788230034616, 56.30895783824306, 56.47221865192537, 54.68923860980619, 55.019137397889175, 53.266849902368364, 54.45227253821589, 53.10226332756781, 51.70731944422568, 47.59433384864561, 47.63694255582748, 48.41546635473929, 50.32781793225197, 54.02688757065804, 58.607996279193515, 54.342469707612075, 53.08844089508057, 50.35560008018248, 48.7593444701164, 50.28990822453653, 49.6313383502345, 51.122799996406805, 51.13006422596594, 53.509221000056115, 56.082338979167325, 60.82064059472854, 62.62804131354056, 61.74023243688769, 64.26673696887109, 59.8362551196929, 58.11020828062489, 56.619338912348596, 62.98331783663843, 64.51574863926058, 67.31266529329362, 69.05075380879065, 69.1070790444651, 71.32428507651053, 73.70208078815092, 74.93790980308287, 82.45550878586309, 39.17029473089403, 0.22774169882459028, 51.87487133087651, 55.134306030888716, 43.33210599037909, 38.58299824499315, 38.918600159306685, 45.92668325670304, 48.80036853974866, 68.87919718219389, 2.480715763184332, 0.07995048327551735, 0.0917726218880665, 0.029928027239117413, 0.10518782501739841, 0.08162636189691483, 0.08507252415461887, 0.09232262705242442, 0.016843933056318955, 0.09177765508572902, 0.13805969257748898, 0.2562611757387077, 0.16352701391423904, 0.15418709976778877, 0.26590669767991193, 0.16084872456567903, 0.3798662907173557, 0.5978345462391453, 0.3875463834453014, 1.0671668523742308, 18.018495844256496, 82.90364742279053, 73.40330600738525, 44.300809829465805, 32.308763150245916, 73.29862579222649, 35.951691904375636, 67.74694227403211, 88.95344841864802, 32.31617839105668, 3.3752090940552377, 54.311753626792665, 65.52835556768602, 79.77037968174105, 70.47103620344593, 76.90878314356651, 68.80640583653604, 72.76692498114802, 70.409760936614, 74.42224364126884, 68.15356654505577, 77.86441372286889, 67.9657163927632, 71.88152836215112, 65.11775793567782, 70.32901502424671, 68.83637274465254, 67.42134632602816, 55.16554378694104, 56.20017482388405, 52.37537753197455, 55.428311209524836, 51.54223080604307, 55.071324533031834, 51.11564167084233, 53.845728981879454, 51.57355877660936, 53.59517582001225, 49.248636614891794, 51.53597070324806, 52.904136565423784, 53.08994708522674, 57.528344277412664, 64.150030766764, 62.358484268188484, 60.81347442442372, 63.151799325020086, 65.31534341073805, 59.34705711180165, 56.83510457315753, 57.50080139406266, 61.96410171447262, 60.99763362638412, 59.76991607296852, 59.864311833535474, 58.853277775549124, 56.09793040060229, 55.8730334620322, 55.22043343513243, 62.7844262123108, 64.22889786381876, 65.4900065545113, 47.758594866721864, 42.95574280523485, 47.813739468974454, 51.02208921986242, 51.3630255576103, 51.457401706326394, 47.320219009153305, 46.54156184965565, 47.24682361848893, 47.714095577116936, 42.62547531435567, 41.79216384887695, 44.30810543798631, 48.39521515753962, 49.84130282555857, 48.34236514183783, 49.6160214947116, 54.678797260407485, 48.450249933427386, 45.16149159400694, 47.066716224916526, 47.24068118679909, 47.073368564728774, 45.50549522522957, 46.20762694266535, 47.18451284593152, 48.36424020028884, 46.78315631804928, 49.82308341610817, 47.76212107750678, 48.8735991908658, 40.314367740384995, 46.75407194322156, 61.46857300112325, 61.81050954326507, 58.21804600377237, 54.15183859486734, 51.30282109783542, 53.02472983637164, 52.5366497039795, 53.83479341383904, 61.40500314774052, 57.094047684823316, 62.36150841559134, 58.17333490617814, 60.221337733730195, 57.902644295846265, 56.39582264807917, 55.52759816569667, 55.49674872429141, 54.54591912607993, 56.520330444459, 49.87769457601732, 50.49471086071384, 50.96091593465498, 52.69353274376162, 57.760783933824115, 61.6197136909731, 57.47953822535854, 56.89732513120098, 53.29479286747595, 49.0492154705909, 50.83674938448014, 53.60778624011625, 54.15678078128446, 54.015363647091775, 56.47729419892835, 59.899785749373905, 64.63769120554771, 69.65670508723106, 65.03609026632002, 66.79633232855028, 62.4052232311618, 60.97908866020941, 60.62106647799092, 68.87366664025092, 66.8177955381332, 72.29123561613022, 73.87870511701031, 73.47671708753033, 76.21245261161559, 77.32846890726398, 77.58413683983588, 86.8627780483615, 41.21004881397371, 0.5862957912106669, 53.213058517825225, 64.21541275516634, 48.695162726986794, 44.8642308481278, 53.76177064834103, 67.88240525030321, 57.588725243845296, 83.474454264487, 5.629459215748695, 0.5478171559591447, 0.20196150717956407, 0.21118574204944798, 0.25319794252995526, 0.176576693512259, 0.17828583567132875, 0.21414463408291343, 0.18721311954000305, 0.29342426948489686], [0.0024992000168910433, 0.03692615424252806, 0.04624039295219606, 0.051579447388048136, 0.03021921151347699, 0.08929700876075415, 0.04731764280868154, 0.059974545297483285, 0.055808857939536535, 0.03588466153990838, 0.0678537481073891, 32.536207668242916, 62.6691791319078, 45.34816895761798, 32.792214885834724, 50.3289044287897, 34.08115671527001, 34.862790953728464, 80.50543185203307, 31.92344911636845, 2.843718129780985, 42.467219445013235, 54.961266748366825, 64.01571704495338, 69.13845800584363, 67.39222664986887, 68.61503339582875, 65.61824060255482, 72.15008520310926, 69.56762021587741, 67.4666497015184, 66.79386123534172, 68.70001546798214, 66.17471510364165, 64.50341278506865, 63.274898990508056, 63.1756434132976, 56.64398708651143, 48.066826481972974, 46.18594800272296, 48.66250507293209, 47.29552768891858, 47.51888705838112, 45.09329726619106, 47.525080480883204, 47.07875005660519, 42.760816697151434, 42.25743147634691, 45.54739398341025, 44.39822581506545, 45.555783933208836, 49.14035958628501, 52.02576883377568, 55.485162042802386, 58.21416677967195, 57.649019918134144, 56.808722711378536, 59.63271548671108, 52.70639027318647, 51.70658988337363, 53.03316685461229, 55.6909844952245, 55.45246124267579, 55.95026100835493, 53.40673731219385, 59.40507681139054, 55.45572073228898, 53.6279825241335, 53.48526316304361, 57.848197875484345, 56.16435573947046, 60.93661331361341, 44.96542799857355, 35.94106620357883, 46.49106133368708, 41.17579475525887, 48.268871691919145, 41.897914871092766, 43.30497495589718, 40.487085388552764, 41.87695764726208, 39.84736642529888, 41.59120513546852, 39.90002032249205, 41.90794437162338, 43.67733732346566, 47.1993354828127, 43.949828301706624, 47.09247442983812, 46.03412482046312, 43.89192627322289, 40.413007505478404, 40.51269454340781, 40.50652857749693, 40.37476439629832, 37.402513873192575, 40.72443585241995, 38.476125424908055, 42.582929365096554, 41.52082604746665, 45.48391434454149, 41.850709146068944, 48.61315381142401, 31.350026053767053, 34.9291496123037, 43.59487341296288, 51.973648378925944, 54.28286929284373, 50.09781014534735, 48.558813295056744, 49.00814041014641, 50.169475770765736, 52.76701050419962, 52.31115656514322, 52.73964412750737, 54.10675094973657, 54.997493759278335, 52.319942674329205, 52.16309101350846, 52.74365671219365, 51.61585761654762, 48.32837012506301, 48.85558374466435, 46.34105028644685, 45.74816050068025, 45.30291657293997, 43.88057493394421, 46.125112041350334, 49.81594078002438, 49.85358376656809, 50.328072886313166, 50.46651294154506, 45.41976005800309, 47.10856006991479, 46.772769881832986, 48.21112655824231, 48.58402629052439, 46.913786934268096, 47.08490817777572, 53.42505478089856, 55.844333479481364, 55.05913380653628, 59.66861694089828, 53.6905364836416, 54.92084672374111, 52.8539929851409, 52.12940177609844, 53.989919231783965, 60.56765948572467, 60.73492111698274, 64.56320147360525, 65.23322074644028, 65.05236025779479, 73.14646136376166, 70.87057667393839, 81.174925527265, 31.417033864605813, 0.6254493192799631, 52.09430440779656, 47.85275136270831, 42.78012652550974, 28.117604717131588, 71.07883884060767, 69.49384043293615, 47.85570882981824, 52.03087183736986, 0.5810819806591158, 0.09967265079819387, 0.05273442069489149, 0.024975858696345842, 0.14708707349434977, 0.03429081944388247, 0.030484802705506166, 0.05124901068366824, 0.10946664057912366, 0.022150603040391882, 0.025238810715475873, 0.03505094337367243, 0.03381455024223655, 0.05279125292755423, 0.05816624071749468, 0.04157897775932666, 0.04819073789422551, 0.053923753045138814, 0.021582445422668132, 0.09180942475194893, 0.17051004323988192, 32.75249304309968, 70.82135092827582, 36.10548803883214, 35.0675896675356, 59.00962345061764, 33.33228211249075, 43.807073639285186, 82.30026137444281, 38.86329473987703, 4.242301727494886, 43.85580516630604, 64.78830629779448, 71.9850161767775, 71.99066438982564, 70.91415420655282, 71.64767665247764, 70.94555670215239, 74.26182654596145, 72.56738616574195, 71.51502993799025, 69.27655681487053, 69.54383496315249, 70.22882984530541, 66.24777317047119, 68.59037737692557, 64.86465915556877, 59.92450452619984, 49.810312178827104, 51.57874022760699, 51.885449963231245, 50.104133006065126, 49.183827292534616, 49.4955341277584, 50.65410421740625, 49.51002728554511, 44.96533778405959, 46.84869127888834, 47.135302789749645, 47.33348054270591, 48.98701844676849, 50.30202050362864, 56.456262450064386, 59.85413720530849, 59.720541277239406, 59.84665332301971, 60.3565182993489, 60.43330261784216, 56.28913417939217, 55.5758511635565, 54.835080177553245, 57.23755151994767, 57.27708508891445, 57.873846254041126, 56.450127863114886, 59.82963023647186, 57.890771281334665, 55.73170654235348, 56.25458594291442, 58.34790783543741, 59.16652217988045, 62.475755291600386, 49.10264991944837, 38.79631634681456, 47.726184321988015, 44.72543385721023, 51.425540293416674, 46.05612539475965, 44.67458817266649, 43.421437971053585, 43.412165487966234, 42.94136731855331, 42.95844531828358, 42.301063922143754, 43.73167391746275, 45.37791621300482, 51.198286010373025, 48.048261903947406, 49.75538330693399, 46.30014781028994, 46.64869746854229, 42.261879444122314, 41.40759114296206, 42.652653417279645, 43.197760889607096, 42.00962397360033, 43.26707309292209, 41.82771621211883, 43.401343668660815, 43.65241066102059, 49.29882726361675, 43.68218145062847, 50.1101303100586, 36.74250841140747, 53.47122107782672, 53.99820719995807, 54.038607612732925, 56.664179448158514, 54.18486495171824, 51.85946426083965, 51.88075488613498, 51.98903583711194, 54.19622413573727, 58.04217869235624, 56.737398332165135, 56.162508303119296, 56.323819698825965, 55.17872295072002, 56.42473443861931, 57.15034546390657, 54.43305292437154, 52.58262380476921, 52.554363127677675, 49.828013835414765, 49.267601274674945, 48.74677327371413, 46.87599097528766, 50.392289930774325, 52.897445001909816, 54.64942655255718, 52.40867453236734, 52.1159755029986, 47.349472045898445, 49.59655869391657, 50.23015875970164, 51.44536002989739, 51.74042032610986, 52.74428036905105, 50.038064602882635, 56.44980230639058, 58.539947079074004, 59.70623247085079, 62.99859154608942, 56.68470521127024, 57.441322572769664, 55.547064888861875, 54.32889438444569, 58.37579980973275, 61.904579747107725, 64.30871417445522, 65.58095455169678, 69.9048734480335, 68.40655942117014, 76.46865398653092, 72.65279185387396, 84.5467596669351, 32.20701686797604, 0.785108293977476, 57.52239404186126, 54.0611533964834, 51.25485835536834, 31.661464206634033, 78.4260892868042, 68.59397811274376, 49.363499303017896, 62.47095431050947, 0.45298834121035, 0.10236515107774928, 0.04803219216785604, 0.05804220725211406, 0.15250469407727643, 0.015516124568098496, 0.029238103776268905, 0.032755923983190334, 0.06433683762987776, 0.05926022959512569, 0.0843237268347894, 0.1416186612820433, 0.09381717266214472, 0.1250039991892634, 0.23512176087787076, 0.22342998744739642, 0.10188081497026068, 0.21115234061594934, 0.1479164556029343, 0.16258327020031793, 0.2598261352508299, 57.11144339653754, 76.19363307952881, 63.789368829419544, 45.55619185970676, 66.79299046916347, 47.59098806688863, 47.085563213594504, 91.02196524220129, 40.89408620711296, 6.805882953828381, 46.69882928171466, 70.94390930668001, 73.52092219937232, 76.19700631787701, 71.94860873683807, 73.6071123615388, 71.1328184989191, 75.59208270042174, 73.32230121858659, 72.90496887699251, 68.98354007351783, 73.701445364183, 72.82897687727406, 70.09755596037834, 71.60776261360415, 66.64764312005812, 63.00772282385058, 52.38204163889731, 52.50891070212088, 56.17629935664516, 51.62781300083284, 52.52112496283747, 52.34330038870535, 52.53490424925282, 53.14249115605509, 47.001291090442294, 49.289939172806285, 50.82256609393705, 49.027493384576616, 50.623470506360455, 54.719464394354056, 58.2174184245448, 60.45866074100618, 65.15880946190127, 62.54241989504907, 61.926972558421475, 65.19741735150738, 58.55100424058976, 58.43956578162409, 57.46927338261759, 59.997327250819055, 59.89578100942797, 60.293019048629276, 60.280153674464074, 64.73291458622103, 62.10233780645556, 57.41341098662346, 60.96941217299431, 63.37390745839765, 63.08761365952031, 65.78753402156215, 54.577305932198804, 41.941574773480816, 49.43880096558602, 47.941118440320416, 53.51373564812445, 46.507739251659764, 49.122822669244584, 45.706908933578006, 46.93867437301144, 46.18820728794221, 47.44502490566623, 44.0014898392462, 45.834546781355336, 49.93711456175774, 54.186277004980276, 51.92779979398174, 53.535889194857695, 50.28526413825251, 50.744271662927446, 44.64759442114061, 45.097815836629565, 46.03007301207512, 45.413284224848596, 45.361257906883, 47.674087401359316, 45.50308688994377, 46.120648384094245, 46.208619302318944, 53.47076216051656, 48.317077621336914, 50.01156899236864, 42.041536377322295, 46.82708686397922, 52.201808729479396, 58.32976687339045, 58.97190201667048, 57.93353296095326, 53.59860004917268, 53.35310282245759, 51.21365777907833, 57.732974329302394, 58.48706960678101, 58.613326780257694, 58.654421452553045, 60.35285872797812, 56.70370517238494, 57.266498611819365, 59.55418963586131, 58.22463166329169, 53.98831890475366, 55.41311202510711, 50.65804619942942, 51.77132075832736, 50.95076484064902, 49.84986143727457, 54.30416776287941, 56.561358436461425, 57.25712414710753, 55.44281613442206, 56.35415530973866, 50.49691131038051, 53.29721689224244, 51.47968861364549, 54.13628639713411, 55.220884507702245, 54.846741384075536, 50.86517480111892, 61.001085312135764, 64.02138486985238, 62.18475857088643, 65.57154086328322, 58.81869816010999, 60.411509929164765, 58.90553943572506, 57.60934906621134, 61.961983634579575, 66.19031044744676, 66.6611909866333, 72.59805910048946, 73.13773801249843, 70.7763848766204, 79.76893624951764, 76.99779741225704, 86.88790475168537, 37.78461548589891, 1.1287747852263914, 58.95751084050825, 62.54183546189339, 58.399569372976984, 39.508104939614576, 92.35961114206623, 90.899791256074, 59.092671794276086, 74.10111919526132, 0.8228450496831249, 0.1851356116634223, 0.18484498854846726, 0.14368866149696613, 0.2657240010317295, 0.15916458751645782, 0.10412079477382284, 0.10304307760370356, 0.20900416878923295, 0.17613997743014367], [0.041819299541173444, 0.05692887465439497, 0.09330184063723973, 0.06100610567016467, 0.012801309104918713, 0.05318633596142454, 0.05766010557812068, 0.09909430804151682, 0.08280359388839814, 0.1270929141150367, 0.622762005415655, 8.4077504950185, 64.86044260763353, 49.853740661374985, 40.591126257373446, 46.86791873747303, 37.87782276830366, 27.92677748587824, 73.02268705060406, 49.32036892060311, 3.6765299833589986, 33.9142127959959, 53.636639195103804, 67.51856619311918, 74.02809250739314, 70.43351481037756, 70.29415299815517, 70.39425188495268, 67.83407380503994, 71.79156487987888, 67.1557391074396, 68.55286382859754, 67.0456930898851, 64.1313132163017, 64.81071087621874, 63.12731589040449, 58.68129753297376, 50.49168671331098, 45.671772341574396, 45.98329874777025, 45.35854362672376, 47.563590311235004, 46.429899815590154, 44.98984083052605, 47.40180038636731, 45.37761419050155, 42.48053589174825, 43.754572714528734, 45.25585205324235, 44.3243165939085, 44.20497455904561, 46.61751462567238, 54.26823885210099, 60.6150770187378, 61.6494531016196, 55.97016703697943, 58.46104468068769, 58.11015336744247, 54.451366470706084, 51.848901317965606, 53.86932203846594, 54.65329008717691, 57.7991251022585, 55.98877868344707, 55.962926341641335, 58.60199505282987, 56.34301185607911, 56.36260801746, 54.8455568282835, 53.12205952982749, 54.83512724599531, 61.67743921279908, 49.47353355346188, 37.085782481778054, 45.629520570078206, 41.8909683535176, 45.47128431258663, 45.793542323573945, 41.5833447056432, 39.537326597398334, 39.500919157458895, 39.36441283072195, 39.9383105001142, 39.24791059186382, 45.78516806325605, 49.77679944807484, 44.726673326184674, 43.842214153658965, 44.9785130254684, 46.946326917217625, 42.25900826915618, 45.73432237871232, 44.6205496788025, 42.76235426625898, 40.76379291472897, 41.13155041971515, 42.01296975535732, 45.12818282650363, 44.49006811265023, 42.610719357767415, 41.878946288939446, 47.63325160549533, 47.64676024836879, 28.235432717107958, 32.43877207079242, 38.79944639821207, 53.0292837081417, 50.372309377116544, 51.37371009395969, 47.98694349104359, 51.41745628849153, 52.00428993471208, 54.10748443295879, 53.72169971466065, 53.27931519477598, 52.978940086980025, 55.162350977620775, 53.205288302513864, 53.53440261656239, 53.40945943709343, 53.15578799093924, 50.23728178393457, 50.60333698026596, 48.66447018038843, 45.94298070476901, 44.65807891661122, 45.0469466178648, 46.57281529518866, 50.19896807209138, 49.87785931556456, 46.57073251662716, 45.67078782666115, 46.103805726574315, 44.819821773036836, 46.13003461591659, 44.751184217391476, 44.43484506299419, 49.43072480540122, 48.132447734955825, 51.489773027358524, 52.272160360890055, 53.56163955503895, 53.834546304518184, 56.57950332087856, 53.76110384541174, 53.49190373574534, 51.31317223272016, 55.02965327232115, 53.83649180012365, 61.138058400923214, 59.0531970608619, 63.97905857332292, 63.7413864751016, 74.06430382882395, 68.00689343483218, 87.92467348037228, 22.809639630779145, 1.968633054244903, 59.12513332982218, 48.7991722168461, 34.38461480602142, 32.00125128992143, 84.47888697347334, 53.70391568829937, 50.902566755971606, 53.06749936073057, 0.13680761379580345, 0.0831416838111416, 0.04652311387021215, 0.06278949324041605, 0.062260647424526756, 0.1097896232480003, 0.041183017554783055, 0.019455111187492168, 0.017852859361277475, 0.05280883081497685, 0.025096358581175728, 0.0643629765498542, 0.023662653759181983, 0.063375010410504, 0.07980478867407768, 0.10483113447985343, 0.060653597972686255, 0.023219678738725283, 0.07468821766275553, 0.05358361766763753, 0.4448629368937785, 6.773918088405364, 72.60504876413654, 47.25500568266838, 46.15603208541871, 58.66980891073904, 36.13961658170147, 32.59744175018803, 78.75854938260971, 54.63798499876454, 6.636021771738607, 34.812423798345755, 60.05702964721188, 72.30585036739227, 77.72705231943439, 70.51515502314415, 74.16343781255907, 71.76166072968515, 72.1194044236214, 74.66162589288528, 69.4003781964702, 72.75369874892696, 69.81991491010113, 68.12587461163922, 67.71080155526438, 64.45655615099015, 63.90950318305724, 54.760276655997004, 49.38135393204228, 49.26446730090726, 49.79421869401009, 51.80634360159598, 51.53584518740254, 47.54969727608466, 50.73007660527384, 48.151384938147764, 46.3086122851218, 45.306850710222804, 46.40571448110765, 48.52179396537043, 48.01325475015948, 48.28171353186331, 57.52822268393732, 61.58796602679838, 62.85852762960619, 57.3193133261896, 59.8434526689591, 61.410867091148134, 56.00276585548155, 56.507594508509484, 56.783929409519324, 57.49295665371803, 58.33628977498701, 58.10170065972113, 57.22533725923108, 59.9280385817251, 59.854199963231245, 54.23351803133565, 57.01347043437343, 55.137569442872085, 58.91942070376489, 62.87568015436973, 53.23952667174801, 41.20998605605095, 47.31518660822223, 43.00707878605012, 47.7869261464765, 48.72747129009616, 45.33531142819313, 42.05289948371149, 41.42732066492881, 42.602905996384166, 41.529051257717995, 41.07323261999315, 48.437698348875976, 50.56810625137822, 45.660507294439505, 44.93946190803282, 47.137177682692005, 48.265176819216826, 45.0611848215903, 45.91213910810409, 47.89020999785393, 47.08928554288803, 44.319311649568625, 44.119741455201186, 45.16246826417985, 49.72277664369153, 45.81269133475519, 44.95904630230319, 44.77813090047529, 48.73930508090604, 47.26341132194766, 36.4304603299787, 49.86875157202444, 44.37933568031558, 54.82172058474634, 51.77351336325369, 54.324481718001834, 50.66729514829574, 55.22531678599697, 54.13658841963738, 60.146565591135335, 56.93841588112616, 59.01610712851248, 56.776100358655384, 58.57930021901285, 56.76380765053534, 57.961868163078066, 56.288090828926336, 55.373229365195, 53.52636175770914, 52.282735070874615, 51.19748584685787, 48.12008834654286, 48.60737223779002, 48.2144997965905, 50.21895647048951, 52.76248408902077, 54.108692522971864, 50.92944283639231, 50.33527828031971, 48.705372656545336, 48.51194097149757, 47.717143258740826, 50.413184396682254, 47.81948966364707, 51.02038298883746, 50.7596081303012, 55.31706102432744, 57.620531743572606, 57.97244287306263, 56.13542433707945, 58.28827604170769, 54.94010163891701, 55.245505225273874, 54.17692607448947, 60.124549327358125, 57.39481502963651, 65.09381578814599, 61.40464621205484, 68.85354488126694, 66.84988052614274, 78.27335219229423, 70.91549565715175, 92.67817820272138, 22.180154131304835, 2.5167711704008044, 65.26664718504875, 57.17700189159763, 39.88005545831496, 31.850240038287257, 90.29114138695502, 59.09543706524757, 61.56327470656365, 55.691510092827585, 0.09911498475459316, 0.07621834805655865, 0.047508211010285926, 0.06827697338115785, 0.025668873323968826, 0.06106533575803042, 0.09293113835155965, 0.0429712314789574, 0.02899037392419433, 0.040816662818073265, 0.13637048402620902, 0.13041094816740484, 0.16709188149581033, 0.11441955222718178, 0.2706077809055006, 0.13577996813241514, 0.1518923140341236, 0.1936561641313376, 0.18308324679251642, 0.3518909660558547, 1.1264287175670749, 14.859331634736831, 84.38085125338647, 63.92025047732938, 57.32858580927695, 62.685860972250666, 51.27154411808137, 38.11400436585949, 85.98115474947038, 57.80582843288299, 10.335212023027482, 39.21526862728981, 65.72452898948424, 76.20040309044623, 82.05569374945857, 75.40354221097886, 77.01476558562248, 72.6744511819655, 74.45868246016964, 73.3858436153781, 71.50790691375732, 75.24094427785566, 71.66619808443131, 69.32708478743031, 71.54288661095404, 66.72648276052168, 65.29207198850571, 57.186611698519805, 51.00942388657601, 49.583893360630164, 51.21914909731958, 53.39779038583079, 52.141659182886926, 49.707832413335005, 53.56501671575732, 50.776631216849054, 48.306487221871656, 47.98972837386593, 51.59294705237112, 49.7333356641954, 48.758720813259, 51.913534133665024, 60.71345006265948, 64.65343559941938, 66.98342938576975, 60.567396686923125, 62.11790569366948, 63.03276323503064, 59.6416231893724, 57.870174915559836, 59.18112516403199, 59.86426476509341, 60.7566471253672, 58.27390055502615, 61.8750992128926, 64.30544291773151, 62.19636486422632, 58.81741162269347, 61.211563617952415, 57.19333071862498, 63.180197285067656, 67.16067344911637, 58.62722373777821, 45.26427338200231, 48.42726876658779, 45.53113183667583, 50.86413537302325, 53.17599996443718, 47.13820142130698, 43.44730207996984, 44.56867241090344, 45.26432045044438, 42.307284801237046, 44.95375502494074, 55.33429199649442, 57.434780059322236, 50.987823394037065, 47.83483789813134, 52.01815159090104, 52.30652424596971, 47.29058550250146, 50.04317545121717, 50.06434840540732, 50.445579251935406, 45.38972646959367, 45.82264631025253, 49.50413980791646, 53.627135292176284, 51.03204027298958, 48.49738505578811, 47.56875607275194, 50.41958962717364, 46.983248187649636, 40.26176875637424, 42.873380876356556, 45.16296640519173, 58.92959925436205, 52.62839001993979, 58.5554051399231, 53.235164996116396, 57.6004845096219, 55.97256360515472, 61.117465957518554, 59.151715232479965, 58.66907150514665, 56.918494163020966, 62.021886071851185, 58.501096002517215, 59.15999927828389, 61.1139593585845, 57.01506291666339, 55.50142026716664, 56.56170752740676, 52.546942003311656, 51.09566896192489, 51.56113663027364, 50.55083997787968, 52.697863040431855, 58.48059769599669, 58.42412733262586, 53.42540779421407, 52.878390127612704, 51.54252890617617, 51.27817684604276, 50.78275011431787, 51.44461870193482, 50.11606093375914, 54.60588824364447, 52.23953016342656, 57.91223841328775, 60.38359442064839, 62.171728457174, 60.61534373990951, 62.36092006006549, 58.6406853122096, 59.39772236731745, 57.71455095660303, 63.64024816020843, 59.979123530849336, 68.84999905863117, 65.14302976669805, 71.52531439258208, 69.6604548731158, 80.61260669462143, 73.93327313084757, 96.83669074889153, 27.727126882922267, 2.640122603024206, 68.45614602488857, 65.47540749272993, 46.39128800361387, 43.771348691755726, 98.16072602425852, 66.22758865356445, 69.87648333272627, 68.30570743929955, 0.34386107758168255, 0.16363935304745553, 0.1475704443310538, 0.22283265337107644, 0.1233720557103234, 0.20582868837781493, 0.09746051829067931, 0.19383011205542475, 0.07614180821204379, 0.13505575457407584], [0.07575196905001517, 0.07320214498547778, 0.11766617156324849, 0.02571204812416146, 0.0640997602303903, 0.013244979350166696, 0.16301594133819305, 0.04887910236814811, 0.09661603658910721, 0.04766857619547556, 0.014523117570206525, 1.5237762154110017, 55.050622263262355, 43.49670433229016, 35.60979458593553, 42.39193739429597, 40.1924487083189, 31.645768842389508, 61.51309582494921, 62.666927691428896, 6.304870276681839, 23.963757830281413, 52.941732483525435, 68.42249993355044, 75.43783941576558, 70.07566129007648, 72.79951203253962, 70.96674534582323, 69.21476379517587, 70.04410189967003, 66.15311853347286, 63.457230367968165, 67.10823920465285, 62.30187662186162, 63.66747725394465, 61.353353377311464, 55.380230795952585, 48.19258551443777, 47.01349358404837, 45.139961704131096, 44.19991077915315, 46.3647610141385, 44.974159194577126, 44.429636155405355, 46.39378655341364, 46.58925787095101, 42.22152609978953, 41.9003898866715, 43.2976479684153, 45.453488519114835, 47.26144229212115, 47.53505114586123, 58.22416490124118, 56.77882248355497, 63.00536155700684, 60.343692148885424, 53.34414412898403, 62.432773959252145, 50.83039122243082, 51.11426491891184, 52.36553630521221, 55.472900713643725, 54.95958797393307, 54.785838742409986, 57.75348832530361, 58.53235729279057, 52.78706166052049, 54.86910673879809, 51.20603269146335, 54.688246250152595, 54.23469082001717, 57.16479547562138, 50.27353232906711, 38.7265452261894, 44.5593136356723, 44.69474523298202, 42.65388504151375, 39.74177622026013, 41.77802762677593, 43.289132502771196, 40.06984718384282, 40.59087130331224, 41.809077109059984, 41.76501320254418, 41.086411783772135, 39.93042653606784, 37.20236316803963, 40.5629518724257, 38.56835995951007, 37.61279213813044, 42.981457864084554, 39.03866391028128, 39.997557901567035, 43.320974303830056, 42.24034170950613, 39.33973327759774, 37.87471232875701, 44.26999176702192, 38.771158264529326, 42.145471342148326, 41.65877972879718, 47.34980152499291, 44.5584350247537, 27.780859431912823, 26.200110912323, 41.77856891385971, 56.88100807128414, 49.80956300612419, 51.62431424663913, 50.2573956981782, 51.39208247584682, 54.00028213377922, 52.561388092656294, 49.17852817043182, 52.8854033254808, 55.27381689317765, 53.73944059495003, 54.977273941040046, 56.57536129797659, 55.43494001511605, 53.37724893323837, 51.25386207334457, 52.16827246450609, 46.97476802333709, 44.57352830517677, 45.10977122091478, 44.20912442668792, 45.33652344057637, 47.342109757085005, 47.11405923289638, 44.254651377277995, 44.885682290600194, 45.11201089428317, 45.44282751698648, 45.45228435147194, 45.903396144990005, 46.378516766332815, 46.4314373846977, 47.740979502277995, 50.452160989084554, 52.181432016434215, 50.80038116824243, 52.49726518507927, 53.45203284294375, 52.39962954674998, 53.173819126621375, 49.9215349074333, 52.56433771502588, 54.484969415972316, 59.61811642492972, 58.63218161367602, 65.30262316426924, 66.67626073283535, 74.50531944151848, 71.23978153351815, 82.92223945740731, 12.846908627017854, 4.620876148823769, 67.09527184886318, 46.192572885944, 32.46193170547485, 27.119092825920355, 70.47615097415063, 44.57737222794564, 48.104453779036, 41.68554990522323, 0.09290815571383124, 0.19155988710061198, 0.04552412755607117, 0.06386448313752491, 0.06626700381598165, 0.1091352079604422, 0.07693627969391885, 0.018269729935714317, 0.08634360191682655, 0.09809624103288497, 0.04030274039494895, 0.03934467849772304, 0.05285684537563113, 0.12815930084475588, 0.0966006612044669, 0.030246708324299227, 0.077173805254842, 0.05065454177618508, 0.04888136615796436, 0.03671230462890479, 0.11330073443992485, 1.3060849159955978, 65.4345913087168, 45.93783063273276, 36.40310964276714, 56.31157405914799, 45.10597436658798, 34.465772567256806, 68.48791722328433, 69.93982176626884, 10.50376803644242, 24.074419659952966, 56.88054915397399, 72.46910725870441, 77.58541553251206, 72.3359271018736, 74.53095605296474, 72.15982052587694, 72.5286723721412, 74.54971282712876, 69.82309202994071, 68.7798200115081, 69.2891005546816, 67.91875777706024, 68.29237922545403, 64.4845030384679, 58.252504025736165, 50.451623624370946, 50.96311638432165, 48.35529327392579, 48.145803405392556, 49.873615311038115, 48.79170794640818, 46.753036437496064, 49.248581701709384, 49.3327675327178, 45.76314787710867, 45.82110874114498, 45.264971563892985, 47.437454731233665, 47.138679950468, 50.11303286398611, 59.51570333973054, 60.3063904085467, 63.04520107084706, 65.29633952725318, 57.77985057523174, 60.74436618435768, 54.179985523223884, 55.4400900871523, 55.56553140763314, 58.74101954121744, 57.46657871430921, 58.69246452085434, 61.770242491076075, 60.43187095272926, 57.47693377156412, 57.82595019186697, 56.26111276688115, 56.56020918200093, 55.32170903298163, 59.232657263355875, 52.143012400596376, 43.735121680844216, 46.310216534522276, 45.45037807956819, 45.96008223872031, 43.563686647722804, 44.35293420668572, 44.62731576734974, 43.76655555540516, 43.821962956459295, 43.3315097901129, 44.803132087953635, 42.510647927561116, 40.45623202477732, 40.01409461421352, 42.87615006969821, 42.18968429873067, 40.261152944257184, 44.01321380369125, 41.90004079572616, 41.5065368529289, 43.79619298442718, 45.14511177616735, 42.66025104830342, 41.20438098907471, 47.24904368000646, 39.52481815891881, 47.00304438990932, 43.863681285612046, 45.77953161731843, 44.91072270178026, 39.21712390838131, 41.07326007658436, 45.62197392986667, 61.09146064327609, 52.85985692854851, 53.638725896035474, 51.812964562446844, 56.289318530790275, 53.434986222174864, 55.39389633363294, 51.15932118508124, 55.31544500781644, 56.849711479679236, 56.65293793524466, 57.0792015137211, 59.86809692075176, 58.280937287115286, 58.0716827607924, 53.2496306973119, 54.02229839755643, 47.31159371714438, 47.80902478002733, 46.412390355140936, 48.29599095929054, 48.9061430961855, 50.540586902249245, 49.786381798405806, 47.433477447878936, 49.110981033694365, 48.105332389954604, 49.84238539972613, 47.22849830504387, 50.16889133761006, 49.58834525077574, 50.30892387513192, 50.438628811990064, 54.11135188994869, 54.79507984653596, 54.807839316706506, 55.71265559042654, 55.31362895042666, 54.931260616548606, 55.06205597231465, 54.493065188007975, 58.01137239702287, 57.78025065698932, 63.83031052927818, 64.291545960211, 70.09159395771643, 70.42738022342806, 78.80146011229485, 73.65310607417938, 85.0394642737604, 12.743503182165085, 6.591299887626402, 75.86969237173759, 52.42898848748977, 36.68635968239077, 32.51366972923279, 71.51910920296946, 49.32654665362451, 56.01977325254872, 47.775159035959554, 0.10212034768154545, 0.08309122159956925, 0.026868858126803275, 0.03774659227459662, 0.022283228181843317, 0.03085355146697933, 0.0190400255979189, 0.024042089447198857, 0.019759677102669113, 0.0931387558399189, 0.148129734481054, 0.24823127194277703, 0.22415116729755558, 0.20604849432504949, 0.2555184228526008, 0.13669291511178017, 0.16942040574166084, 0.1347101876331914, 0.21028978690024347, 0.1566972481387277, 0.186775055143141, 3.419040600138326, 77.08576833048176, 55.305548867871686, 45.127268914253484, 55.66143728071644, 56.191463239731334, 42.055068554416785, 74.51984790063675, 74.78074043027817, 13.126925653026952, 27.5671471318891, 61.643345971261304, 76.97809142451133, 81.21724005668395, 74.0855787646386, 76.68565519394414, 74.41831342635616, 75.37374788714995, 74.28408207431917, 71.27733430554791, 69.46687806037166, 70.9664943141322, 70.66256553896012, 70.76963055518367, 65.59050552306637, 60.8774051358623, 52.713760406740256, 51.74981832504273, 48.89525067421698, 48.40197732371669, 52.54596141076858, 50.67766981740152, 48.90886914345526, 51.28657856295186, 53.06084702091833, 48.597621225541644, 51.080477622247514, 49.97027035682432, 49.79319103302495, 49.29604630316458, 53.579282376074026, 62.29293754023891, 62.416853058722715, 65.82263531223421, 67.48989366715955, 60.58917760849, 65.65641310907179, 56.86787205357706, 56.27501364677184, 58.48573207855225, 59.259968726865715, 60.534895927675315, 60.143070759311804, 65.12200194020426, 66.34653845141011, 60.97670385914465, 60.69068070380919, 58.50061747335619, 59.57940263132895, 58.63506847812284, 63.472064771959865, 55.395096578905665, 47.968469127531975, 47.593129681002715, 47.83183336257935, 47.74134428270402, 46.06263652924569, 48.34405960575227, 48.3173208082876, 46.37912081133935, 46.250298407769975, 46.30813767833095, 47.827695262047556, 47.99328596361222, 45.711992325321326, 44.068327026982466, 47.20823534073369, 48.855544520962624, 45.2687801853303, 48.602861512091856, 45.99310075083087, 46.386628227849165, 49.32523265961678, 49.25559097720731, 45.62491962986608, 44.79617380326794, 51.24979457547588, 42.70229101181031, 49.575334748914166, 46.65583225988573, 49.32895498891031, 49.13329539760467, 41.76083980068084, 35.06439685821533, 47.010132112810695, 61.944089781853464, 55.5207222507846, 59.22427515829764, 54.951158800432765, 58.91207410443214, 57.53329430857013, 56.061283696082334, 54.852126798322125, 58.697100762398016, 59.046497652607584, 57.08316310759514, 59.270060985319084, 60.31221512825259, 60.524434966425744, 59.35757298623363, 57.02976396006923, 58.85223442508329, 50.32943787113313, 49.78030996937906, 50.70893110767488, 50.842040661842596, 52.73702398423226, 54.77580924187937, 53.70687707777947, 50.10384275067238, 51.99660601154451, 50.16789897795647, 51.48277551897111, 48.88441708780105, 51.45557780419627, 50.73288109994704, 53.24325292341171, 53.05512428283692, 58.62798859996181, 59.24429101328696, 56.522601496788766, 59.71827022490963, 60.2525362660808, 58.914764850370354, 61.0645963299659, 58.26297283172608, 62.57551685456307, 61.89098481209048, 66.4176510226342, 68.15934811868976, 72.40889103181901, 74.62055083244078, 83.22280283897155, 75.23778284749677, 91.15858139530306, 16.09846720772405, 6.492557160315975, 78.30954782424435, 60.68722901805755, 44.575791512766195, 42.492146107458304, 88.88514426446731, 55.15083882116503, 64.01083761645903, 54.9356536711416, 0.17937930360917123, 0.2495285652337536, 0.12743574612203146, 0.20508146153823023, 0.11532971830738169, 0.2803086297165963, 0.14740781918648752, 0.09830557455819461, 0.13448359414694772, 0.27748020245663585], [0.04072332266537894, 0.04832199939917173, 0.08719211324088036, 0.021327531581083616, 0.048740417471215616, 0.07808832271445183, 0.03608175681062764, 0.09131417955241858, 0.0035018956330004, 0.031213651095787366, 0.10414864206987043, 0.04516826822392402, 40.14976547610375, 56.536616125414454, 39.65702164557673, 34.47260533609698, 38.00657849158011, 26.829823909267304, 44.471103452867084, 75.38146711164906, 13.746838608095723, 13.296520113945009, 46.6605822501644, 67.07809971224877, 77.65501406884964, 70.69789040473201, 71.80515981489613, 68.59220520142587, 66.74693399860014, 64.46680922662058, 68.63479429675688, 63.07818428162606, 64.57921651101881, 62.45626111184398, 62.241083806560894, 56.17664060285015, 49.99802504816363, 46.31000472653297, 45.849608682817035, 45.515995410180864, 46.31883398179085, 44.574881522886216, 45.740445198551306, 46.70517959902364, 45.74292021413004, 43.652398893910075, 40.5781824358048, 39.028257862214126, 43.75618088629938, 44.65166976374965, 45.195337726223855, 47.17900976057976, 57.19695891103437, 59.24370658013129, 59.63168390335576, 66.49692212381672, 57.77844636671005, 55.18927804885372, 56.577302871211884, 53.78467336777718, 54.665551416335575, 53.20717496256675, 56.18870581350019, 59.40502189820813, 56.73174619674683, 56.35907003956457, 53.08243574634675, 52.19151643014724, 57.612255542509025, 54.91204100270426, 56.5525056469825, 54.05307331392842, 54.69799726240097, 41.27308130264282, 46.859309134944795, 44.21390971829815, 41.836353271238266, 42.65854481727847, 39.69320943278652, 41.41680086812666, 40.416435657009, 38.34085464477539, 37.87766587349677, 37.2060227394104, 36.90472979699412, 38.42186727831441, 38.69311878758092, 39.444782195552705, 37.83734783049553, 39.140990703336655, 40.83846307569935, 50.22183941256616, 48.565904940328295, 40.549109828087595, 41.349677347367816, 41.33170112486809, 41.246067939266084, 43.80453978815387, 47.85173154646351, 45.13559610612931, 40.23970542415496, 38.403534120129, 36.17165450126895, 25.507300707601733, 27.20166656278795, 46.58167200703775, 55.74915716725012, 51.63851714903309, 52.09636365213702, 49.35582714696085, 55.59554930656187, 51.61441810669438, 48.54545762462001, 51.51119701323971, 50.94262592254147, 53.164601556716434, 54.10358167463734, 55.122750728361076, 56.2248622217486, 56.282281798701135, 56.9671590097489, 53.52370631310248, 51.99458206853559, 47.30948740436185, 47.89606217415103, 47.16196313981087, 43.925223273615686, 45.38527065707792, 45.160479622502486, 44.788517336691584, 42.33283904290969, 46.20326134466356, 44.587699828609345, 45.78989844168387, 46.167022566641535, 47.837877735014885, 46.40734226472917, 47.76321541878485, 47.6141575074965, 48.9235858763418, 47.03975385235202, 51.154320163111535, 51.06993429122433, 50.928007248909246, 51.58211738832536, 50.561834381472686, 49.47340019287602, 54.6066217268667, 51.36614776426747, 58.91465110163535, 59.96698379516602, 67.97438483084402, 64.93363011267878, 76.14211666968562, 72.79408347222113, 73.76597619825795, 4.163410115626551, 12.103256660123026, 71.81912345270958, 38.89368918634231, 34.737796783447266, 32.84451576971239, 44.4557983644547, 39.594483375549316, 63.012296307471495, 40.182776143473966, 0.04689646682011024, 0.07779679561574614, 0.06351497850470966, 0.006685825515418284, 0.03679998722227831, 0.03496287390589714, 0.11933746131797952, 0.10161693598474227, 0.015754777235880254, 0.05371119428966796, 0.08666575721074497, 0.08971108694470699, 0.0610340295750047, 0.043854002254985036, 0.08390002658650761, 0.054120262258596, 0.038918733611823096, 0.013308728399175792, 0.025006778004969803, 0.016648881325137713, 0.07272749989023132, 0.06629735621954165, 43.95730433925506, 61.734435173773, 38.09460824535739, 44.48998966524678, 43.00944397526403, 31.574113022896555, 48.641602762283824, 84.69686877342963, 17.131585190373084, 13.546891866191743, 48.12439903136223, 71.98708718822849, 76.75659518088065, 73.67213741425546, 75.7583833509876, 72.14887711309618, 68.83906349059075, 71.55239443625175, 73.7270898203696, 66.98656728190761, 67.72383951371717, 66.76801281590616, 65.38396135453256, 58.13721772163146, 53.82434421969999, 50.57257383100448, 50.245440313892985, 49.40837906252954, 48.77923873163039, 49.70161937898206, 49.93529065962761, 50.765793708062944, 48.06369643057547, 46.24701538393575, 43.501215057988325, 43.47893991777974, 44.92349786143149, 47.51865956091112, 49.365138853749926, 51.64777002026958, 58.332638048356586, 64.03357167397776, 63.05005304275021, 67.95568296986242, 62.116823119501916, 57.94473132779522, 57.90937508306196, 55.42584011631628, 54.92813056515109, 54.342293200954316, 59.93472230049872, 61.883112615154644, 60.22412261655254, 59.020806127978915, 58.45803230039535, 56.09762053335867, 61.80966623367802, 57.82201997695431, 59.13677100212344, 57.790182098265625, 57.493490096061464, 48.305667446505645, 49.684855168865575, 44.87415052229359, 42.60071339145784, 47.42341264601677, 41.00474411441434, 41.96854499078567, 42.78588848729288, 41.713284984711684, 42.2794085164224, 40.648840012088904, 42.44865486698766, 40.76551091286444, 41.32915158425608, 42.11119767158262, 40.371595121199086, 40.927151787665586, 42.66223968998079, 52.2403460164224, 52.5900213949142, 44.89940274146296, 45.7889021596601, 44.42097948443505, 43.530648523761386, 45.174282443138864, 49.377455096091, 47.93219112580823, 41.908485658707164, 40.23501819179904, 39.41993790288126, 36.299845403240575, 34.58380060811197, 50.79814541724421, 57.164752329549486, 54.70116261513003, 53.25599670410157, 51.000692690572436, 56.821631231615626, 54.25245131215742, 54.807443157319106, 53.33800561966435, 54.54486793087375, 57.232268087325565, 57.37162989954795, 57.705729546085486, 59.56297182267713, 61.017790686699655, 59.10246203022619, 58.644529234978464, 54.24925458046698, 49.47789915146367, 51.352517527918664, 49.03804456034015, 48.1618929678394, 49.25422599238735, 49.35835707572199, 46.86435722535657, 48.71000497571884, 48.8891553109692, 48.035431831113755, 47.230722288931574, 48.142912618575565, 50.38231534342612, 50.502861545931914, 52.08743241525466, 51.06900468949349, 51.18893507988223, 50.59991275110553, 54.339225907479566, 54.80250097090199, 54.416265180034024, 53.56536972907282, 55.001737763804776, 55.29550367786039, 59.04674476192844, 55.855312193593676, 61.961434502755445, 62.570445229930264, 70.41934720931515, 68.71099025972428, 79.98137181805026, 75.8346656060988, 75.16274006136003, 3.690988575258563, 16.199684950613207, 78.44912928919639, 44.87278161510345, 38.933560079143895, 37.79889291332614, 53.62637042999268, 37.77047141905754, 68.02887439727783, 40.876666961177705, 0.05897677323270229, 0.08224343805904351, 0.019783218984582254, 0.05993587700950523, 0.04325659540031226, 0.017566390358091846, 0.1082593166539746, 0.081010228022933, 0.05897276659285831, 0.020189519460883834, 0.1317798706793016, 0.13148806778894317, 0.18722900820355262, 0.1803412189286563, 0.15825779988400399, 0.24893512288408898, 0.1384751267370678, 0.22643391012905106, 0.18512517754589358, 0.10853975846041596, 0.13545939097962073, 0.20185440808774965, 54.240315498844275, 75.02632002676688, 50.76107117437547, 50.27401478059831, 51.05446838563489, 38.03989510382376, 55.83441380531558, 88.92669785407283, 18.057182181266047, 16.02609947804482, 55.17943682209138, 77.79796877214986, 82.94344379055886, 78.3425114231725, 77.82640595589915, 73.45581085451188, 73.08107545298915, 70.42012383860927, 73.2921931051439, 67.12043777588876, 70.96553725581016, 69.75180687442904, 68.35908305260443, 61.93799834097586, 54.90984055303759, 53.463827410051906, 52.87483646023659, 50.94231997766803, 51.9061993014428, 51.363711972390455, 53.17293267096243, 53.52926038926648, 50.715869780509706, 48.96077386794552, 44.84861981484198, 45.16146805978591, 47.8356380616465, 49.00142139004123, 50.81286215013074, 53.96618496987128, 63.62986564636231, 67.21253502753474, 66.13176515025478, 70.02569029408117, 62.782253219235336, 59.58327008831886, 62.06881723096294, 58.727102971846065, 58.74139608875398, 55.74108492943549, 62.29973108537736, 64.5435582437823, 63.62238568644371, 62.198369195384366, 61.738812538885306, 56.877721125079745, 64.56504498758625, 61.60562453731414, 64.78653338647658, 58.13452305332307, 58.698297085300574, 51.210033509039114, 51.901531680937744, 44.79085506931428, 47.84824455938032, 50.069157231238584, 45.037250518798835, 46.85172327103154, 47.2259722986529, 46.91650513679751, 45.73489504475748, 44.95093484078684, 45.57244616170084, 45.3662314722615, 45.51195929127355, 45.226712765232215, 44.35497383917532, 43.941928648179584, 44.89429189312843, 53.19996564619003, 53.57453630816553, 49.47997408528482, 49.19477070531538, 49.48577919313985, 47.6084896825975, 49.41085800047844, 52.84035882642193, 50.545309435936716, 43.09746588430097, 43.207425609711684, 43.78919939840994, 34.90677641284081, 32.59617286343729, 52.93044390216951, 61.638866624524525, 57.68909085181452, 56.43634073195919, 54.881862286598455, 60.25500343691919, 58.84971626343266, 55.54031448979532, 57.20696487734395, 56.65702112259404, 59.52412466849051, 61.063768709859545, 60.63643432432606, 62.26282942679621, 62.62371493924049, 60.97183227539063, 58.765742240413545, 56.180872840266076, 51.45913539394256, 54.214302339861476, 52.662738215538766, 51.1408507439398, 51.37975446639523, 54.39294668935961, 49.87854180797454, 51.41618936292587, 52.16618576357442, 50.3670024102734, 49.901001299581225, 51.58020327168127, 53.52748355557842, 52.67654495854532, 54.66120935255482, 55.05371701332831, 56.19672706050258, 52.868046837468306, 58.55303995070919, 59.18915033340455, 57.814998934345866, 57.34092166346889, 58.091624090748454, 55.912292465086914, 61.86276728107084, 58.2957834582175, 65.60627345115908, 66.22040287140878, 74.68203790726201, 71.41973987702401, 84.05978172056138, 78.20447537206834, 83.24786678437265, 5.08870949668269, 15.062731042984995, 84.77951311296033, 51.08772616232596, 44.07124527039067, 50.195739961439564, 60.27804343931137, 50.64092897599744, 78.6868876795615, 50.287084118012466, 0.13658935534617594, 0.18287821102046198, 0.17913142820039105, 0.31525492547981204, 0.14610033692611804, 0.1454544941624326, 0.2011537900374782, 0.16218980744240746, 0.13984876835057813, 0.0915715084861844], [0.10612683430794748, 0.0007749844195542768, 0.053792008904800306, 0.021669750717738946, 0.07491515588856514, 0.007092170041775512, 0.14718471906117855, 0.08282357346146338, 0.09517717024972362, 0.08929856391924043, 0.04795048889073153, 0.021910767724377014, 27.657267508968232, 61.23129313991916, 34.268006663168634, 35.77367513410507, 33.51288764707504, 33.375157540844334, 43.82179821691206, 77.65913255753057, 25.42362870708589, 5.0319390719936745, 37.35106806601248, 60.666593428580995, 74.66206519834458, 71.49621040590348, 71.9417759679979, 68.02839586811682, 67.92908145535377, 65.75013422196912, 68.6533078839702, 60.942073252893266, 64.42042719933295, 63.37342500686646, 61.81400829745878, 52.59218262087915, 48.38878639282719, 45.69027416167721, 46.89816805624193, 47.119452491883315, 46.42946051013085, 46.9183055047066, 47.04638265794324, 44.165652798068145, 47.030136200689505, 45.74499122558102, 43.698894669932706, 41.29352861835111, 43.00776520083028, 46.52208335937993, 44.434609720783854, 46.817014217376716, 55.52740596955823, 56.955615474331765, 57.89904748239825, 57.63208312373008, 61.911961647772024, 54.861752294724994, 56.75765737410515, 54.18512775051979, 55.65811111081032, 56.2939194710024, 57.48326055465206, 59.7911713969323, 55.11854202516618, 55.58565316661712, 53.77620497057515, 50.71906651220014, 54.74636008662563, 54.150069605919626, 55.61835004437355, 56.2715894176114, 56.11863267037177, 43.52818527529317, 51.55202104199318, 49.74595785140992, 44.945812225341804, 40.32417758818596, 38.056251387442316, 38.860054862114694, 37.16096647324101, 35.36615656268212, 38.91712927049206, 40.31648189790788, 38.712330556684925, 45.076187887499415, 43.90279123860021, 52.989173550759595, 61.67701951919064, 56.787353638679754, 64.91787395169659, 57.30338065854965, 57.90801794298234, 49.16750238787744, 45.05851368750296, 42.961183132663855, 39.67201294437532, 42.979920294977006, 43.985729755893836, 38.7739666815727, 39.85968659001012, 40.726479407279726, 39.951603412628174, 24.944848514372303, 35.26758740025182, 50.50998064779466, 50.17567703800817, 52.005807891968765, 52.64171038904498, 48.07273357145248, 52.168864742402114, 52.91002012068226, 53.71101910068143, 51.19725442701771, 51.44847831418438, 53.0655538651251, 53.18976356137184, 53.8961902741463, 53.46910299793367, 54.81034571124662, 56.741658026172274, 55.6285011383795, 51.0597086721851, 45.454892727636526, 48.97396872120519, 47.06364108670143, 47.09961706592191, 44.70522580608245, 41.572354224420366, 41.439232903142134, 45.03377529882616, 47.66952176247874, 45.83081660732147, 46.73412276852516, 46.90588728074105, 47.11338458522674, 47.36042722578972, 46.03094377825337, 47.43628194255214, 47.90096121449625, 49.27463800676408, 48.92001651948499, 49.64647477672946, 50.2520965760754, 50.757627333364184, 50.00020196360927, 50.92899568619267, 52.7669987370891, 55.794087917574, 61.06985622836698, 64.97564654196462, 65.56100929937055, 69.16088611848893, 76.75261789752592, 77.02168464660645, 52.08553006572109, 1.8827663650435789, 24.448872650823287, 68.98514040054815, 37.25680958840155, 48.162167533751465, 36.899438519631666, 45.750537457004675, 45.51091594080771, 64.43033510638823, 23.74382661234948, 0.23945452435122383, 0.11506629897461784, 0.10510994451901606, 0.03012003951645907, 0.15048917803552844, 0.051299867430521603, 0.08705881394205556, 0.043956991285085685, 0.013646765653374455, 0.01975560151491194, 0.06515573199477888, 0.010776947620475005, 0.0518350679457428, 0.007471161877601258, 0.024114297064501914, 0.027669841356034723, 0.17985911979790659, 0.07508430810224626, 0.09257453208368632, 0.09606120507082633, 0.04585683954158618, 0.02512252239900972, 29.5825707527899, 69.99439762484643, 36.100294820723995, 45.13540390999087, 39.591667113765595, 37.425279309672696, 50.27047680270288, 84.52456689650013, 28.915638385280488, 5.691998466368645, 39.30644804431547, 67.01976622304609, 76.73711669060492, 76.05986456717216, 72.79162806849327, 71.93724955281904, 70.3105406607351, 68.39295664141255, 72.58413468637775, 63.627724032248224, 68.01939010620117, 65.81883061316707, 66.51440020530455, 55.78730613954606, 52.2752001977736, 48.25299001509144, 51.66825655967959, 50.2690569047005, 49.270401846977975, 51.15068020359163, 50.569663432336625, 48.810864802329775, 50.6763126773219, 49.61820233252741, 47.70472895714545, 43.52467475398895, 45.42156827065253, 48.19002812908542, 48.157197890743134, 48.696782665867964, 58.66312911433559, 58.955573189643125, 59.917918866680516, 58.17444885930708, 61.17885497308547, 59.70789947817403, 58.04718363669611, 58.4820136716289, 57.03256453237226, 58.94952489483742, 61.389133238023334, 62.396507724638916, 58.734951634560865, 58.49613812661941, 57.166411492132376, 55.60945803119291, 57.43896130592593, 57.229910742852, 56.08451981698313, 58.56477568226477, 61.10082334087741, 48.668063071466264, 53.892973930605, 52.23814556675573, 46.10462550194033, 42.87533421670237, 40.91472179658952, 42.087639916327696, 38.896352475689305, 39.51182726890811, 40.834379888349964, 43.47505677130915, 41.4590173382913, 47.95338761421942, 45.557670593261726, 52.45577827576668, 58.981013682580766, 55.03635660294564, 61.60564022679483, 58.77067265972015, 54.86713770897158, 48.13137692789878, 45.49563830898654, 45.523408689806544, 40.567152730880245, 41.12708284008888, 45.073089215063284, 37.9284409553774, 41.41887187957764, 43.93411528679633, 44.25661648473432, 31.930413284609397, 38.99456470243393, 54.48918596390755, 53.25649484511345, 55.041800852744814, 54.791777210850874, 52.16229869473366, 53.58917067127844, 56.55556117334674, 56.22218324292091, 53.729720961663034, 54.89706147101618, 56.75651596438501, 54.96613833212084, 57.52830113134077, 55.98032205335556, 58.49916227402226, 60.181917913498424, 58.23290394198511, 55.44164334574054, 47.206705616366484, 51.16521650745023, 50.729703980107466, 49.8664059946614, 48.19171867062969, 46.469441229297274, 45.013202467272365, 46.98419740123134, 49.78287519947175, 49.969654544707275, 49.883707569491484, 50.42893663529427, 49.9008914732164, 51.40338282431326, 50.517641036741196, 50.38275857125559, 49.682678253419944, 52.1433497244312, 51.52361523720526, 53.140318162979625, 54.780994615247174, 55.8978424533721, 53.32450874390141, 55.736291793084916, 55.33194641913138, 61.43961414214104, 64.8842357050988, 68.91448282426404, 69.06487434141098, 73.56060089603548, 78.45053349771808, 80.19609805076354, 50.53477787202405, 2.3646854344875585, 30.263900180016797, 75.87807839916599, 41.445363567721465, 50.799322128295906, 45.33602922193466, 57.853779408239554, 48.49831465751895, 64.0540974370895, 25.671122420218687, 0.3070336682421546, 0.15590079248912875, 0.042982098436163324, 0.02733230684703637, 0.10654845079707523, 0.08026771262408265, 0.03066522598777327, 0.06172118746044655, 0.01064998195356419, 0.01192647404217672, 0.20673241165857162, 0.11012835668460016, 0.1380152441561222, 0.11904326823329735, 0.1231720531359315, 0.16953580922657446, 0.19834157319799547, 0.18886730255138492, 0.28359122454158725, 0.2855757599876773, 0.14194838552465364, 0.08691504222130583, 40.000323172538515, 80.15219103905463, 44.09939612111738, 50.04281459316131, 45.58334250603953, 46.814594114980395, 57.46689642629316, 90.87547256100564, 30.227484895337014, 8.63307987490008, 43.976998559890255, 75.86131418904951, 80.00096013469081, 79.76278597308745, 77.11662169425719, 73.28266959036551, 73.2539656854445, 70.41764490066036, 74.22472092413133, 67.08123760838663, 70.50090112993794, 67.3080918096727, 67.39250906052129, 57.82579721943025, 55.36112493084323, 51.44273988662228, 55.2414063484438, 52.431208549007295, 52.15481089007471, 54.07067691126178, 53.63775314823274, 50.71859582777947, 52.51355871077507, 52.853643894195564, 49.33830199703094, 47.33680279024186, 47.948641546310924, 51.64580099044308, 49.57027489139188, 51.65679931640626, 61.374173318186116, 62.79620901230843, 62.501250697720444, 59.58913403172647, 64.98064756393433, 59.14076397495886, 63.270537314876435, 59.33471341286937, 61.89131036881478, 61.03349193449944, 63.54535033625942, 67.43348998408165, 62.25298035529352, 61.51789680604012, 61.36264939461986, 58.20024236556023, 59.59389578911566, 59.81993021503572, 60.64883293644075, 62.1654526648983, 64.96448739882439, 52.47705321158133, 58.507909159506525, 51.44019819075062, 42.86806606477307, 43.43307172098468, 44.376240930249615, 47.066704457806004, 45.47744243375717, 42.68358522845853, 45.37935180048789, 48.61755863312752, 43.87331854912543, 49.209483515831735, 49.802608643808675, 53.431754189152876, 57.84428335005238, 53.21867142954181, 61.700216416389715, 59.9991354634685, 59.76075341624599, 49.006798959547474, 48.8081975906126, 46.5489790516515, 43.69244629336942, 45.07964349562123, 47.32406685429235, 38.03581976121472, 42.09188784322431, 43.574916393526145, 43.62378128113286, 32.204426142477224, 37.54071858621413, 57.580150942648615, 56.76346640433035, 58.13418572948825, 57.6817128735204, 53.39411120260916, 60.07764954720775, 60.45102780865085, 56.61239239477343, 55.23086301742062, 57.00397437618625, 58.78790363188713, 58.13989277808898, 60.765256727895434, 58.31465790348669, 59.33931043071132, 61.318640401286466, 62.218424274075424, 57.97451780688379, 49.96007611674648, 54.78355200059953, 54.72429283203618, 54.03814869542276, 51.35788725268457, 49.53466369259743, 47.260638206235825, 51.998465215006185, 52.2422012975139, 51.84860714020268, 53.203268281875125, 54.452131332889685, 52.69019480674498, 54.69449458583709, 52.49367229400143, 54.60719047054168, 53.727402840891195, 56.62210418332008, 56.524864704378196, 56.46256962130147, 58.88941849431684, 58.78068647077007, 56.92174580789382, 58.17544514133085, 61.25346629850326, 62.56306725163614, 66.96999919029975, 72.8319735680857, 71.25859322086458, 74.68808620206772, 82.23438908976894, 83.88564417439123, 59.38916767797163, 3.0852334153267646, 30.223488000131425, 85.49816977593207, 48.338364324262066, 60.24347559098275, 58.3117945732609, 51.302436705558534, 59.22638539345034, 83.50927706687682, 33.75540387245917, 0.5636298848736672, 0.18160367054083656, 0.16717331664216134, 0.08619164837704552, 0.28890033643091884, 0.11787066341287668, 0.2366865261067306, 0.20645707965858523, 0.20544005197382745, 0.09747724965094559], [0.09174963158945884, 0.022088697390450586, 0.05401909651775515, 0.026967714112552426, 0.01899831211044183, 0.12988784801094763, 0.18663029516896895, 0.04885863249881133, 0.3171585620410981, 0.11601988691836597, 0.06770835228023991, 0.3869587327203443, 19.69928441509124, 65.46636250711256, 43.56291786316903, 41.96625432660503, 32.939437127882435, 31.160744236361598, 36.19037989647158, 73.06868076324463, 36.89075831444033, 2.757182553891213, 25.91399165891832, 64.61073275535338, 72.66242519501718, 72.6435193707866, 70.6018001802506, 73.22685426281345, 67.05687968961655, 64.66069198423817, 65.34470235147785, 63.05281046898135, 64.51453270450716, 63.96513023684102, 56.504880228350245, 51.01400913730745, 46.92167482068462, 47.816873442742136, 47.34663224989369, 44.48238418948266, 46.17129402775919, 45.97072755136798, 46.9732932121523, 48.92636683679397, 46.321701234386815, 45.50327124134187, 45.45552422923427, 40.47849932024556, 42.75602748317104, 46.27377379325129, 46.19011355984596, 46.03198320634904, 53.22237414698447, 56.727447279037975, 53.31243961088119, 58.98589311107513, 57.069854505600475, 55.84859709585867, 52.885858320420795, 52.05480614016133, 54.55988276389338, 59.077249034758545, 58.47846392662295, 56.96074985688733, 55.78461931597803, 51.191527766566125, 55.081875708795366, 58.123818905122825, 57.84323607721637, 57.10492049494098, 52.77797352883124, 53.51427301283806, 58.57811958559098, 46.97710183358962, 51.028651345160704, 52.75500805147233, 51.683443976986794, 52.65608587572652, 43.5530178008541, 43.667962858753825, 39.24687508613833, 35.80936870267315, 35.1763177687122, 42.19165332855717, 40.92557107248614, 44.7301838474889, 27.542345985289547, 48.8533244594451, 85.53019200601886, 73.69098048056327, 56.81755981137676, 48.02021695721535, 47.72494877538374, 44.380539847958474, 39.61727234625047, 42.44615239481772, 38.41781546992641, 37.83091122104276, 37.487750899407175, 43.02832234290339, 39.68145801175026, 50.26566013213127, 43.749846258471095, 31.193160664650705, 50.762420469714755, 53.465898421502885, 50.02955305960871, 48.214742983541186, 52.51272716829854, 47.063280228645574, 51.142804084285615, 50.33942814796202, 52.02533737305672, 53.01302940614762, 54.824081851590066, 53.85999464219617, 56.41179453942084, 55.191070572022475, 55.934759801433934, 58.29368106780514, 57.85780376003635, 57.57869574331469, 52.467772883753625, 44.2665518483808, 46.601123040722264, 46.79277789208197, 47.70334828284479, 46.35547676394063, 44.56506775271508, 41.23336338227795, 43.762166423182336, 47.076451547684215, 45.665335732121626, 44.536497208379934, 46.4396547502087, 47.01982428950649, 48.62392856228737, 47.35453190342073, 46.90144323533582, 49.102802891885084, 47.39883507451704, 45.93513988679456, 50.333156278056485, 52.20059279472598, 50.98195160588911, 51.02157538936984, 49.563018506573094, 54.3918288138605, 62.99962705181491, 62.939897198830884, 67.34595837131624, 68.65988177637901, 71.33443617051648, 77.28346363190683, 69.89850351887365, 31.04157086341612, 1.033084274780366, 37.97135168506254, 66.31908970494425, 31.99909986988191, 40.42685347218668, 30.098795852353497, 31.356680354764386, 30.380614226864232, 57.23648071289063, 21.471505395827755, 0.10566325918320688, 0.13565049927321174, 0.105959375148579, 0.12258958116534258, 0.0952422034536158, 0.14855042400379337, 0.1908923027616355, 0.041319013483101324, 0.025301145374654763, 0.05049839390501861, 0.018765040252718235, 0.08023095572547567, 0.14156143451409955, 0.05160384728843647, 0.06400566931153018, 0.08805462099131077, 0.14776886110344242, 0.053808265290553534, 0.2631484747173325, 0.10119878221303226, 0.05727762852104441, 0.7900938103275915, 23.53588019647906, 80.17753739510813, 39.9071394243548, 43.746123929177564, 44.08291824402348, 33.893577206519346, 42.21698007275982, 76.1670394097605, 39.42627253070955, 3.859347489572341, 25.32460847208577, 76.25826589522823, 76.43596495351484, 75.2781754155313, 72.41329193115234, 75.74687511690202, 71.40880430898359, 68.11659428381151, 70.80455533919796, 66.55273745136877, 68.04947468542284, 67.3577647055349, 60.5441644883925, 53.37018474455803, 50.78367579367853, 51.110268023706254, 51.52860841443462, 46.34566691613967, 47.6532909947057, 48.22103054292741, 51.2027810465905, 50.21266106636294, 50.26579349271713, 48.343628145033314, 48.987720551029334, 44.567429019558816, 44.96859335130261, 49.01640876646965, 49.37393673004643, 50.10625108595818, 54.79071424853418, 59.83073242249028, 55.40894646798411, 60.39773848748977, 59.50666619885353, 55.95392842446604, 51.78715536671301, 52.65770189223751, 55.60067584437709, 60.612449030722345, 62.16627244026431, 62.368341184431515, 62.94652208205193, 57.34491855867448, 58.00689697265626, 61.497402421889774, 59.54682734704787, 59.05775093263196, 55.24030024005521, 56.83731286756454, 60.33141905261625, 50.78162831644858, 54.71509095161192, 55.81613948268276, 53.459728533221835, 51.19877630664457, 47.62328878525765, 46.09953426545667, 43.66118108072589, 38.41614061786283, 35.39623721953362, 40.92252339086225, 42.230802505247055, 47.08515528709658, 27.942839591733872, 42.01334238052368, 77.42701453547325, 71.67618443889003, 59.06249700054046, 49.945178954832016, 46.46064727537094, 44.42853396938693, 41.10725918123799, 41.30649989651096, 37.584543228149414, 36.675745748704486, 37.19855062423214, 42.44435202690863, 40.33041807913011, 51.28404471182054, 46.908585871419604, 35.67780456235332, 55.00145535315237, 55.82902446869881, 55.20029598666776, 53.20146006922568, 52.83783674240113, 49.54991386782739, 53.18949291782995, 52.811764747865745, 52.99230752452728, 56.41419895233647, 59.12890664992794, 56.821584163173554, 60.57843815895819, 58.37595278216947, 57.525378965562396, 62.02414535707044, 62.73309807623587, 61.68039275753883, 56.14130789233793, 45.568084486069225, 49.386680510736284, 52.041391634172015, 51.27421917453889, 49.536240485406694, 47.30487469703921, 44.21226232282577, 46.5915681469825, 49.33719196627217, 49.137437420506636, 47.91304603699715, 49.68801267685429, 51.789626459921564, 52.243746711361794, 50.50781157708938, 50.92116663532873, 51.935118936723285, 52.41708801638696, 49.58259505610312, 53.27914261048841, 56.09817750992314, 55.6494426727295, 54.47109599267283, 53.59798031468546, 57.98323723577685, 65.8249181316745, 67.50967025756836, 72.89179755795386, 73.2793277309787, 72.49276699558382, 76.5302038192749, 71.97615162018808, 30.47344888410261, 1.2762149639668003, 43.483925250268754, 71.18998312181043, 36.3010887945852, 45.639608906161406, 41.30299721994708, 36.880344421632834, 35.27835038400466, 66.43693339440131, 28.324894135998143, 0.21379902117675353, 0.06960153940223879, 0.13790871196937177, 0.2293401106350845, 0.10440234740775439, 0.2745269947955685, 0.15040359069262782, 0.1853910406991359, 0.05415349515275129, 0.03995191043002471, 0.3133976219161865, 0.20023446920658314, 0.24292592920603293, 0.13307569308146355, 0.25785563453551263, 0.19317126111878505, 0.21464767805751295, 0.13350274113397445, 0.3617215595178066, 0.19466962184636824, 0.23265656654632863, 1.1595770356155213, 30.50539266678595, 86.07381682242118, 55.50689981829736, 51.83920129652947, 45.96825253578925, 42.86733650392102, 51.434969671310924, 82.81661002866684, 40.20555726943478, 5.320964801696039, 30.226370942208078, 80.72222909619732, 77.48349666595459, 77.72403993914205, 73.22642280209449, 77.814725137526, 73.9609101510817, 68.49798986988684, 74.7980223932574, 70.05939914334205, 69.50707450989755, 70.1316805808775, 61.89413839770902, 57.37547774468699, 52.85229459885628, 55.54358182414886, 54.95922319350704, 49.52230430418446, 50.94427331801384, 52.19019851376934, 53.41961053109939, 55.736130975907855, 51.77037938948601, 52.501199322362105, 50.8709289181617, 48.00886954030683, 50.324993825727894, 55.423102301936, 51.28004781661495, 54.577984502238614, 58.143893595664736, 63.58071834810319, 59.48482644173407, 63.58730792999268, 62.96673797792005, 61.97309570927774, 54.53495217907814, 54.67907182631954, 60.71901198356383, 62.53970169251966, 62.846458496585974, 65.04529214674427, 64.32955372718074, 56.920973100969874, 60.70017676199637, 65.28620412272792, 64.7283136460089, 62.96710275834607, 58.19037368220668, 58.5357109192879, 62.90606283372449, 57.640998671131754, 60.64274541793331, 60.095896413249356, 56.59881314923687, 47.50127169393724, 45.675180881254136, 46.884306400052964, 46.13422370726063, 40.672032986917806, 37.40797381247244, 45.54470323747205, 44.42541568509994, 53.42709049101799, 30.837946899475593, 45.846419795866936, 79.6691668418146, 72.94955053637105, 61.70986936938379, 51.87388681596326, 48.538789595327074, 46.36879321067564, 41.64503182134321, 43.837617135817005, 40.07927656173706, 35.66643361122378, 38.509124325167754, 44.24699098833146, 41.86662220185803, 50.70482830847464, 51.35610649662634, 35.96849533819383, 56.451877240211736, 58.6263176702684, 57.14278313421435, 57.10902721651139, 56.28043828472015, 52.21825914998209, 57.165073963903616, 55.69156500601, 56.95964767086891, 59.80011832329535, 62.150908516299346, 59.12388209373721, 63.25911537293465, 61.583545515614176, 62.28879551733694, 62.40507025872508, 64.7280586919477, 65.05348597803425, 59.93232965469361, 48.73537486599338, 51.67226914436587, 56.40528340493479, 56.19320084971767, 53.41957130739766, 50.191939184742594, 48.43361123915642, 49.969246618209354, 51.120532866447206, 51.71361484835225, 50.44420250000493, 50.393058715328095, 52.91631552480882, 55.1262612496653, 54.00660107212683, 54.270074521341634, 54.927750095244384, 56.72085769714848, 52.655089593702755, 55.029410085370465, 60.06161882031349, 57.920738189451164, 55.52501724612329, 58.31949026353898, 60.75707466371598, 68.73661118168985, 69.52084202920237, 73.96221237797891, 76.79861161016649, 74.885922708819, 81.38917323081725, 81.14255812860306, 35.710050367539935, 1.850121948988207, 42.847654050396336, 82.52257347106934, 40.68596916814005, 54.02875854123024, 48.48062084567163, 33.02430545130084, 42.88619525970952, 78.54685906440982, 30.34463824764375, 0.37515598379315873, 0.19066131193070643, 0.18527951361911912, 0.2633931325568307, 0.19251089332805527, 0.38178206211136234, 0.23790515748964203, 0.29288420814179605, 0.14473631737693665, 0.1493431871095973], [0.2257337364097757, 0.06572754002146183, 0.2311920822267571, 0.06604097723480194, 0.18715998368157497, 0.13143932927520047, 0.11275510363761457, 0.05108340545707653, 0.21063541512816183, 0.19593714496060727, 0.03960941167127702, 0.13342490660086756, 18.26211033328887, 61.70241686605639, 50.99636631627237, 39.74643207365467, 29.5348943433454, 38.233197350655836, 34.11777596319876, 56.40119237284507, 52.383767481773134, 4.169806030488783, 16.930736303329468, 72.47411220304429, 70.98200336579355, 72.77099640138688, 65.53847136036043, 70.58361607213175, 66.15283612282046, 67.77324568840766, 59.362860341225904, 66.49619256296467, 61.601682555290964, 61.99542576266874, 49.26614215297084, 50.909697624944876, 49.11013380173714, 50.96374396354922, 44.49156253568588, 44.78384971618653, 43.49873219766925, 47.4244285398914, 45.697467788573235, 47.42082388170304, 46.88297279419438, 48.063861170122706, 43.76319408416749, 43.84013529746763, 39.96448055390389, 45.52067872016661, 45.25399284978067, 47.084335511730565, 51.56934615104429, 56.49797685684697, 55.10465683475618, 59.756379973503854, 56.05504712750835, 53.99222558544528, 54.120796957323634, 50.27639173692273, 55.24378330476823, 57.19526836949011, 58.450446436482096, 59.41497687370547, 62.98622431293611, 59.43603607916064, 54.56620170224098, 55.7086665399613, 58.531639499049035, 52.87925697142079, 50.68349845947758, 49.889504832606164, 53.80369294074274, 47.66190059723393, 45.189520851258315, 51.385673322985255, 41.23086483247819, 46.13582011192076, 47.41028447305003, 51.355545597691695, 46.94918240270307, 40.66915004484115, 38.35405734277541, 47.31364903911468, 44.322594673402854, 68.83896150896626, 45.31989651341593, 43.895738817030384, 57.99951899436213, 37.35294688132502, 40.15138933735509, 38.13181584881198, 42.54604731836627, 41.55877890125398, 40.95331791908511, 39.50287249780471, 38.064343237107806, 35.13082611945368, 41.23878017548592, 42.4911262912135, 46.89721884266023, 55.84809895484678, 40.847162892741544, 43.88679581303751, 56.99919692931637, 52.413734389889626, 54.6736511107414, 51.213222395989206, 52.33319636314146, 47.944307327270515, 55.65580475714899, 51.42474797464187, 53.050519420254616, 54.12781799993208, 53.07294361052975, 54.08487981365573, 58.12376399194041, 51.54287407475134, 52.8178208874118, 55.76452501358525, 61.50249758074361, 56.55809502447806, 46.6540083577556, 43.0215484096158, 48.82931955399052, 49.607604088321814, 48.6749860548204, 46.88078018926805, 42.350124928259085, 41.696242286312966, 46.31773571814261, 47.13892705978886, 46.598055747247514, 46.51056335818383, 47.22497601662913, 46.39049960720924, 49.625344968611195, 48.02745373018327, 50.203565089933335, 53.03441416832709, 51.75786702863632, 47.49904771004954, 50.73195934295655, 53.04159210574243, 51.62205103904971, 51.73152831292922, 52.80084879167619, 56.88422441482545, 67.18212881395894, 66.46119717628726, 71.48420010843586, 69.13537502288818, 73.82088153593003, 69.44303789446431, 52.644075578258885, 17.6064077115828, 2.4062912406459933, 57.41117131325507, 56.43880790279758, 32.858167579097135, 28.754660391038467, 23.63776376170497, 33.72566446181267, 32.91789154852591, 56.10297456864388, 29.672946083930235, 0.17790957924819764, 0.1674093023663567, 0.22109890446787883, 0.21056228437491004, 0.0660826524178828, 0.3317790742843382, 0.5171091037411844, 0.09702446870505811, 0.0810743878865915, 0.07193786242315847, 0.12872101949347606, 0.05415991879999638, 0.23876096963161425, 0.09056887559352383, 0.15012919331990904, 0.13160757750513094, 0.041263150351662795, 0.13517373211441502, 0.1298781799813432, 0.1561706392995773, 0.08796929411830441, 0.468412755477813, 21.84677031732375, 71.42071262482675, 51.271897131396884, 43.073927740896906, 33.62329844505557, 45.3967357450916, 41.28000036362679, 56.797206632552616, 59.38976387823782, 4.798687484956557, 18.31819434319773, 79.57012699496362, 70.59207270222326, 74.34227435819565, 67.01287854102351, 72.97126477764499, 69.66394578256916, 70.81811889525383, 65.56323720562843, 67.87272484071794, 62.34022955740652, 65.5270690302695, 53.05753654049289, 54.574521049376465, 53.158631709314164, 52.879421710968025, 48.19490363520961, 48.2922843194777, 47.02718265594975, 49.93880118093183, 47.6137456586284, 51.82104072263164, 49.4998408902076, 51.556288580740656, 49.73439078177176, 46.41304146858954, 41.207197250858435, 48.21779850990542, 50.06848650593912, 49.76068242903679, 51.685028614536414, 58.26845630522698, 56.24992224477953, 59.87918938359907, 57.39938066851709, 57.182120584672504, 54.61539214657199, 52.853785099521765, 56.193604853845414, 61.40793315825924, 60.190762858236994, 62.16455444212883, 65.65933135248, 62.162303001649924, 57.262721369343424, 61.03018537644417, 61.4122320759681, 56.800634784083215, 52.10294538928617, 53.642091289643325, 56.33200960774576, 51.64347502493089, 50.365276567397586, 54.00065868131576, 44.19363106450727, 50.55242853779947, 48.703646813669515, 50.964414688848684, 48.806212871305405, 42.824657194076046, 37.7675727875002, 47.71806501573133, 46.147395026299264, 68.31052410987117, 52.15338314733198, 52.47018906377977, 59.674845664731926, 41.38406868903868, 40.76984905427502, 36.058521578388834, 40.56601916590045, 40.39574515435004, 39.254272676283314, 37.93215936230075, 37.8910646900054, 35.43632776506486, 39.92074612648257, 43.31260004351216, 47.967770945641306, 56.74868691352106, 43.218725958178126, 45.92497702567808, 58.95322368990991, 55.03858058683334, 59.2923871163399, 56.74557647397442, 57.060421205336056, 51.26666468958701, 58.85362294412429, 53.81528354460194, 55.8162610761581, 55.401819521381015, 58.53458519904845, 57.19876320131364, 59.636014200026, 54.114768274368785, 55.410233005400634, 59.1823136421942, 64.28752945315453, 58.6324954032898, 49.65977945635396, 44.925023663428526, 53.71423544422273, 53.45317817503407, 52.052319357472086, 50.01500498863959, 45.35388385095904, 44.72384529729044, 49.36496626946234, 50.875537703114176, 48.471077719042384, 49.679128508413996, 48.35149249722881, 49.16825156058035, 55.68853693623697, 54.465326186149355, 56.45914146977087, 57.783337562314934, 55.44455766677857, 50.08252074641567, 52.761421126704064, 55.8710644322057, 54.466432294537945, 54.51375961303712, 56.67584065468081, 60.444151893738784, 69.02712545087262, 69.12383540984123, 74.9023417503603, 72.92624381280714, 74.79362149392405, 73.27146730115338, 54.51588946004068, 15.41106693206295, 4.146109031092736, 64.6960090052697, 60.186303123351074, 39.37317148331673, 37.47204965160739, 32.777868816929484, 36.94627946422946, 40.524685229024584, 67.62756101546749, 30.08793284816127, 0.31656015544168414, 0.1078522405136497, 0.17817106037851305, 0.2140046391756304, 0.05271934791498127, 0.4931773443616206, 0.3391272977234856, 0.24302981072856536, 0.10327499540102097, 0.09420633000592071, 0.27639554452992254, 0.36538284692552786, 0.4141136997890088, 0.15262903014738716, 0.4491400364185534, 0.27207027339646894, 0.2411609852025586, 0.24934027614372395, 0.33250419182642815, 0.3348202594826299, 0.2530269057399804, 1.1661237165812524, 26.926086718036284, 78.4163853429979, 64.83347631269886, 53.39008292844219, 42.800413024040964, 48.74339219062559, 48.01973058331398, 66.42471913368472, 59.748354804131296, 5.587831591406177, 21.91875953828135, 81.81020828985399, 71.5973134194651, 78.95182809522076, 65.87829374497937, 74.75185609632923, 67.96748145934075, 72.4863656874626, 72.11503490324944, 69.36299800872803, 64.74338339221093, 69.7761255694974, 56.73210705480268, 58.81901587209394, 56.739481110726636, 57.33582258224488, 50.65809719024166, 51.44047275666268, 50.936118710425596, 53.88911431835544, 50.32524485741892, 55.02499349655644, 51.318232090242454, 54.072998954403786, 52.60492247919883, 51.44950597516952, 45.2312627146321, 53.82561114526565, 52.05447666106686, 54.8646705381332, 56.167230836806766, 66.34256116805538, 58.06996476265692, 62.87775901056106, 57.68902024915142, 59.58252483798612, 60.368097136097575, 55.67602457538728, 58.02561844548872, 62.18789646702429, 62.316177583509884, 63.983271198887984, 68.08072028621551, 63.46623220751363, 61.270591366675596, 65.45160655052432, 67.0923065370129, 60.82632410910822, 54.92706368046423, 57.04343734248992, 58.98468109869189, 57.170333862304695, 53.44378802084154, 56.105265232824514, 48.6715579032898, 57.32578131460375, 50.71595215028333, 53.53586173826649, 50.07194211406093, 41.521175138411984, 40.61684916096349, 51.35006996893114, 48.09169038649529, 67.71310006418537, 59.49226325558078, 59.82482533301077, 69.14172926256734, 48.94818698206256, 46.72344999928629, 39.177790380293324, 42.94377957620929, 40.96171179125386, 41.292167555901315, 40.46279022770543, 40.34006710975401, 38.61255722661173, 42.86980367475941, 45.44047409488309, 49.97459280875422, 61.50104630377985, 47.591188107767415, 48.87514460471369, 62.10426761258034, 61.32715978930074, 62.85621343120452, 59.15220160638133, 58.534279254175004, 55.645406553822184, 61.87561304338517, 54.62438221900694, 57.493490096061464, 58.72022313456382, 60.53542544764858, 61.43665275266094, 64.75480533415272, 57.06365323835804, 59.98535617705315, 61.941928555888516, 68.46528514739006, 65.13101946923041, 53.58804495103898, 47.02564900921237, 54.794946485950106, 56.919419842381636, 55.91287297587241, 55.495685761974705, 47.62301814171576, 46.301038188319055, 51.46126131857596, 53.13419926551081, 49.296681727132494, 50.5664078650936, 50.26627202187815, 50.65959553564749, 58.72056045839864, 56.5653004184846, 58.65399783657443, 61.62125910482099, 58.91034826155632, 51.0310322238553, 55.27885713884908, 59.334383933774895, 56.808675642936464, 55.74343050679853, 57.8125278411373, 60.89641686408751, 71.99458675999796, 69.24931987639397, 78.08667875105336, 76.347899898406, 80.31420061665197, 78.65665405027329, 62.47574744686004, 16.10837413418678, 4.277044611592447, 64.51880024325463, 69.72288331677838, 40.983939863020375, 38.37606576181228, 36.483663358996, 43.997088939912864, 47.58695194798131, 76.84881794837214, 42.53369185232347, 0.6049040668914395, 0.2762138591178002, 0.39095691495364715, 0.30509356589567277, 0.17294865432045153, 0.47382464572306604, 0.5638298644654213, 0.5655423467678409, 0.1832298760212237, 0.17491866473949727], [0.13027597879690508, 0.03213223648227511, 0.0169080316329435, 0.13112673475857706, 0.08406562415222008, 0.05727123168687667, 0.037238821537504276, 0.12108879193903939, 0.304509898827922, 0.17110106475170583, 0.16815378661117247, 0.2849375781032347, 13.100756579829802, 69.55473130749118, 35.975053541121945, 43.34906239663401, 61.29974242179625, 27.306258524617842, 46.04519767145957, 51.34426093870594, 72.13962816422986, 11.42370798895436, 11.688365013368669, 67.63925752332135, 68.32335026033464, 72.64490004508727, 69.03046731025943, 75.91066545055759, 68.17082497381395, 64.37650057577318, 63.960913688905784, 63.93537121434366, 61.22387201555314, 53.22330374871531, 46.393708106010195, 47.34931907346172, 45.82833374700239, 48.6486904851852, 46.56267596829323, 47.294433347640506, 44.42854181412728, 49.391203003544966, 50.00189642752371, 48.64437980036582, 46.625614320078206, 46.85257442535893, 41.75321079069569, 42.421935681373846, 40.17142480419528, 44.52935849466632, 48.40166353410291, 49.97934672140306, 47.17710348867601, 49.087360520516675, 55.192588529279156, 61.006945333173206, 54.72578725507183, 52.61508926268547, 55.57725929444837, 52.44041435180172, 57.06311195127426, 59.20735013100409, 59.05529552890409, 57.50315481616605, 61.525302240925456, 61.87249475909818, 56.255927393513346, 55.31156578371602, 58.13076150032782, 54.051622036964666, 52.49552365272276, 50.16996606703728, 57.189769206508515, 49.50502234120523, 46.705328649090184, 50.247797658366544, 52.52716933527301, 48.49834211411015, 39.7881817817688, 39.82423620839273, 45.264402820217995, 42.72956717398859, 42.18731126477642, 48.11194158369496, 44.20419400738132, 61.286425975061235, 69.55239357486849, 41.312740387455115, 43.534343396463704, 35.95979552115164, 44.53534795391945, 36.24863886064099, 37.64433976142637, 40.676347594107355, 43.89481313766972, 40.20220756530762, 38.74414882352276, 41.95768394777852, 38.86676603747953, 43.809819298405806, 48.27581036475397, 49.386641287034564, 45.41449231486167, 49.1639800994627, 51.4044536313703, 47.78079548189717, 50.26643283905522, 52.20594290764102, 55.14461794207173, 51.65930571094636, 52.879174601647165, 56.04728867930751, 55.36036399102981, 50.70955476453228, 54.59325428931944, 54.0070011538844, 54.16653179353284, 54.38865169402092, 47.43635646758541, 46.215091213103264, 45.26894492487754, 44.06887223643642, 39.573106458110196, 43.47266412550404, 49.88642969439107, 46.356210247162856, 46.82632592416579, 46.00836269317135, 42.5840001721536, 43.15548950626005, 47.72741594622212, 43.62306348739132, 49.83441906590616, 47.82030551664291, 49.616374508027114, 47.8557284416691, 49.23224110757151, 50.76058872284428, 55.59696135982391, 56.192992964098536, 53.802527996801565, 53.1603693193005, 53.43517449594314, 49.77062563742361, 50.23593248859529, 49.1581279231656, 59.32398180807791, 64.22006860856088, 68.23789750376056, 71.07354364087506, 73.60238198311099, 71.59590921094342, 76.31321830134239, 63.968417183045425, 41.26202806349724, 8.931698741451386, 9.757399828203264, 65.4455151096467, 49.38348377904585, 33.32766548279793, 22.919128671769176, 31.04339868791642, 47.21169487122567, 47.48572341857418, 57.362596681041104, 21.853724679639264, 0.10066399921572979, 0.07029016817649526, 0.11206653615039204, 0.09578636336711147, 0.1505489482153808, 0.41722202493298444, 0.10076520709140648, 0.06276186044898725, 0.3010585807984875, 0.09731441766263978, 0.03246482206328261, 0.10676785071770992, 0.05792234513548113, 0.19719959657278754, 0.08741450090441974, 0.05239348858594895, 0.0868225600870867, 0.055545676094029224, 0.2785608154391089, 0.15035590938022061, 0.1621580454370668, 0.37363977321693975, 17.68155247934403, 76.35355595619448, 42.81645944041591, 50.021072895296165, 57.56569700856363, 37.535764632686494, 50.73196326532672, 59.41385115346601, 79.1488330594955, 16.03731059258984, 10.49219214147137, 70.30583381652832, 69.70006296711584, 77.23251204336844, 70.15629737607895, 76.66163459900888, 69.78698269013437, 68.73991381737494, 66.52260580370503, 66.20238350283715, 62.641828444696245, 55.21526767361549, 49.84985751490439, 52.51969329772457, 50.40743420200963, 54.104785842280236, 50.54829435963785, 50.23830552254954, 48.6089333411186, 50.92949774957473, 52.65430904203846, 50.68988800048829, 46.760218297281575, 49.06843116206508, 48.25950114957748, 45.90740088493594, 42.28477039644795, 48.50901096097885, 51.52767096796344, 53.133548152062204, 50.39619661146595, 50.921378443318034, 57.545614473281375, 65.83742264778384, 57.15594268614247, 56.81556332495905, 53.87570765710647, 57.31265314163701, 60.448929340608665, 62.59669373112341, 60.78170714839813, 61.13924687908542, 64.41651267390098, 64.5878771043593, 61.167707597055745, 57.78746781810638, 60.48222241863128, 57.120060843806115, 55.61130546754407, 54.004482992233775, 59.656736081646336, 52.68777470434866, 50.22503222188642, 54.181891795127626, 54.43067989041729, 53.7689015173143, 42.58340789425758, 40.24866411762853, 45.08551920613935, 43.836224694405836, 43.32379448798395, 46.61863642354166, 42.48780012130737, 59.96602673684398, 70.86654447740125, 44.99702269031156, 44.717381231246456, 35.50253345120338, 41.827618152864524, 35.510809652266964, 35.58221247888381, 40.34061231920796, 40.71040945668375, 40.146815853734175, 38.07141919289866, 43.184840602259484, 39.78622844142299, 43.90800799092939, 51.361997896625155, 54.45683425472629, 47.65678582652923, 51.81300770851874, 54.801794944270966, 48.759819076907256, 51.855659561772505, 53.60143592280727, 57.94264070449337, 53.932852668146936, 57.87796474272206, 59.64554163717455, 57.72087773969097, 54.78404621924124, 58.160791166367076, 58.418592868312714, 58.79146906637377, 55.66530866007651, 50.0571547785113, 49.60638423119822, 46.32393698538504, 43.75417263277116, 40.07156125960812, 46.09785549102291, 53.58244772880308, 50.480237314777995, 51.684259829982636, 49.8169292173078, 48.50050726244527, 47.68973765834686, 52.018053531646736, 48.23411164745208, 52.662314599560155, 50.456899212252715, 54.64328019849716, 51.04712178630214, 53.33641705974456, 54.53334792967766, 60.21549732454362, 60.97890038644115, 62.22702995423348, 55.94807624816895, 58.00045644083331, 56.60890540769024, 54.61339566015429, 53.65495274143835, 62.36093182717601, 68.33958102810767, 73.18181760849492, 73.9202194829141, 77.78780198866322, 72.23232946088238, 78.44256324152794, 69.06880455632364, 43.65220669777163, 7.19412160496558, 13.070865177339124, 70.73372517862629, 50.89472986036732, 41.7866607635252, 30.220257928294522, 35.75121172012822, 46.69132186520485, 51.11992097670033, 65.03359171652025, 29.346371504568285, 0.33261101512658986, 0.07946450007899154, 0.08870553525705492, 0.15538267190417937, 0.06964303838509707, 0.38730114337898075, 0.1432404387742281, 0.043570388844537164, 0.21537126342375434, 0.033657057886762966, 0.15288712516907724, 0.12686054432584395, 0.13851382949900243, 0.3469987898584335, 0.16335283616377463, 0.14968613402978068, 0.21654103371885516, 0.21150993513724498, 0.6486603737838808, 0.3039560172586672, 0.3982465479883456, 0.6251791660343448, 22.03548142986913, 91.27950806771555, 45.007071802693034, 57.92144421608218, 80.81307118938815, 34.18623701218636, 60.42306523169241, 62.67473320807181, 84.5027663630824, 14.451612041842553, 14.10184350705916, 75.32554195773217, 69.97284027837938, 75.71726906684138, 69.37999756105485, 76.64585882617583, 71.06638923768075, 68.84517454331922, 69.72568388908141, 69.09857534593152, 65.54637885862782, 61.12137656058035, 53.635744894704516, 56.1348516710343, 53.61086922307169, 58.36660577404884, 51.85120767162692, 52.46608626457953, 51.748476874443796, 57.01282716566517, 55.25057292753651, 54.402423135695926, 51.00229301760274, 53.278844510355306, 50.29504260709209, 49.16374475725236, 45.46817779541016, 53.78807798508675, 53.888118036331676, 57.69812799269154, 55.49471693654215, 55.52509177115656, 58.84674310684205, 68.0120631187193, 60.2236754663529, 58.07968047357375, 58.224459079004106, 58.02144504362538, 60.66159240661129, 63.402874162120206, 62.78017828541418, 64.6130665656059, 66.471434562437, 66.32946829642019, 62.893844650637725, 64.52811587241389, 67.3489236831665, 60.95577016953499, 57.905993999973425, 56.43813717749811, 63.98060398717081, 59.222125699443204, 52.59309261075912, 55.39119774295438, 56.073211623776345, 55.45796432802754, 45.511033611912886, 46.54348773341025, 50.20936627541819, 44.854640653056485, 43.98682409717191, 48.775371274640484, 42.1551086056617, 64.8967755225397, 60.04492129048994, 43.47433113282727, 50.533969863768554, 37.134984693219586, 43.319923108623875, 36.46611467484505, 37.36043468598397, 41.24047856177054, 42.7984949850267, 42.70225571047875, 38.67540144151257, 46.653588664147165, 41.58434883240731, 46.220562919493645, 55.525617368759654, 56.68570933803436, 52.681565592365885, 55.64525750375564, 59.96370469370196, 53.97448862752607, 57.88914349771316, 56.66577977518882, 60.87948399205362, 56.06584149022257, 59.581556012553555, 61.02988335394091, 59.085109464583866, 56.08220954095164, 61.523682302044286, 62.39454261718258, 63.99525403976441, 57.49806750205256, 52.90906698473039, 51.4817988487982, 52.955370564614576, 47.397560304211034, 40.45097604874642, 46.66517142326602, 56.38327106352776, 55.01754099322904, 55.745191651005904, 52.07242542697538, 49.79111217683362, 48.41510941905361, 55.8299187690981, 49.779215628100985, 55.34497653284381, 51.92038259198589, 55.686085454879276, 52.22745318566599, 57.544206342389515, 55.58844197180964, 63.45361786503946, 64.14987779432728, 62.65812589276222, 57.180869348587535, 60.93125535595802, 60.23283812307543, 56.45942388042327, 56.58766185083697, 68.06383840499386, 67.97141951899376, 75.95860465880364, 78.09049913960119, 79.18861373778313, 73.97383828316966, 78.50438764018398, 71.30319056972381, 51.08756534514889, 7.762098946878988, 13.930093703731416, 74.80726349738337, 59.074683804665845, 41.831826856059415, 28.556268868907807, 44.97571637553554, 65.0595970307627, 64.43705804886358, 75.83126098878923, 37.19523622143654, 0.4363494017912496, 0.27471652494803556, 0.262929649362641, 0.2857668529595098, 0.2200779850564657, 0.6178339763033776, 0.3533989641695254, 0.19278627129331713, 0.4025801235148984, 0.24022251217355653], [0.05227733050442992, 0.08047286330932572, 0.10949579788552177, 0.054246214774226954, 0.03498663029242908, 0.08858663841120659, 0.20425338177911698, 0.031021060422062877, 0.029358285734610214, 0.08177911982901635, 0.11213651062139582, 0.058766635315072153, 11.237421881768013, 71.10778593247937, 44.40980465181413, 34.51932076484927, 52.04674566945722, 23.434424169601936, 34.370090269273334, 46.8129780984694, 74.21539352786156, 29.085261283382295, 1.50773715348013, 60.306253125590665, 75.16693699744441, 75.26614158384263, 68.97793892891177, 67.19521384085378, 64.76187344520324, 68.2392389543595, 66.83048832801082, 62.81189457062752, 53.25423948226437, 46.81672396198396, 50.61913236494988, 49.38782192045643, 47.325478907554384, 44.530543050458355, 49.04523034249583, 51.25985545496787, 47.95777674644224, 49.53717008713753, 46.73346381033621, 43.97854397373815, 44.55057851729855, 44.06488318597117, 44.78406152417583, 46.72818430008427, 43.86898433008502, 41.90195099000008, 48.38848437032392, 47.81630077669698, 46.7396140867664, 51.207429055244695, 57.07091746791717, 58.1964494336036, 60.59475521887503, 57.80433400984734, 51.42524219328358, 52.11156675892492, 58.43836945872153, 57.886652792653734, 56.4114885945474, 58.49713440864318, 55.93849389783798, 59.48423416383805, 55.398469817253854, 56.492293342467285, 56.00192646826468, 54.23932706156085, 54.0260011149991, 51.11997981225291, 51.22966497175155, 48.07425152870917, 46.993069802561116, 52.83891147182834, 51.85204313647363, 57.69367218017579, 43.87130245085686, 38.051548465605705, 39.39052404895906, 39.14346964128556, 37.01668993119271, 38.19457769393921, 38.87595222842309, 31.975595066624305, 45.937006934996575, 42.90722700857347, 45.528135145864184, 49.36372680048789, 49.27605790476645, 44.62712357121129, 40.50096273422241, 38.826930446009484, 40.69147617586198, 39.46819482311126, 41.25924318067489, 40.21976017182873, 41.91127446389968, 49.661034614809104, 48.24666715437367, 55.5460411502469, 40.177626071437714, 47.37160205841065, 49.87981657828055, 46.032073420863, 48.511815455652055, 50.04199874016547, 52.71488612697971, 55.98047110342211, 55.42200796065792, 53.19586284698979, 54.45317860572569, 51.862790430745775, 51.066015843422186, 52.76030717357513, 53.41921829408216, 51.65885856074672, 51.44175537170903, 48.5637790156949, 38.96160894824613, 39.67683745968727, 43.57649318633541, 51.10197613316198, 51.15477123568135, 46.167983547333755, 47.43806662098054, 44.66531568957914, 45.96336134018437, 45.78966309947353, 47.097918679637296, 47.05735352731521, 45.96419680503107, 47.54020906263783, 48.56424185537523, 48.85871771843203, 52.23801220616987, 56.26426635249969, 60.23457181069159, 58.6794775532138, 62.62646844310146, 59.861546562563994, 59.628546007217906, 53.933511626335886, 53.29445554364113, 51.45398532190631, 55.21657774525305, 63.70690491891677, 71.24332735615393, 69.0825406966671, 77.33319144095145, 72.40092077562886, 80.76397880431145, 58.46887765392181, 31.122252056675574, 3.4254647070361726, 19.309059573758034, 67.83014359012728, 45.40830673709993, 29.305853420688262, 26.346334911161854, 37.92741329439225, 37.4983177646514, 34.71452536121492, 61.15767025178479, 27.138153583772723, 0.12052247676277354, 0.09483207828335224, 0.15956230972322727, 0.08716647993893394, 0.03287894238207129, 0.15709222775072823, 0.06398044969706286, 0.26336304062316496, 0.14096327306282136, 0.12592564892744826, 0.013397209639210376, 0.045326277688746495, 0.06065936278431647, 0.07258860814955927, 0.06149285495461476, 0.17026311778012784, 0.18724984579509307, 0.04728654346939537, 0.06715022658388461, 0.0304685041849171, 0.10363275846165997, 0.09849987743842988, 17.654374376420055, 78.38857573847618, 49.54639157941265, 44.51430836031514, 57.342306260139715, 30.764235758012344, 43.67772171574254, 51.01237350894559, 79.36908198941138, 36.3469373795294, 1.2541366777112408, 62.29001929683071, 78.82444520150462, 75.75431977548908, 71.01903838496055, 68.71494400885798, 67.42520593827771, 71.53921527247276, 69.48852954372283, 66.33423789854973, 54.32506222878733, 49.77628561758226, 52.44559972516952, 50.710343160936915, 49.00407291227772, 49.55442851589572, 55.02913551945841, 54.836237276754076, 51.61712454211328, 51.50249327382734, 51.35934637438867, 48.257673325077185, 49.35231662565663, 48.79996453562091, 47.6579664599511, 48.665729261213734, 46.58335470384168, 44.579141216893355, 50.069474943222545, 49.32242032020323, 49.29408904044859, 53.329941226590066, 58.05420467930456, 62.05212754587974, 61.00457229921895, 58.170797132676654, 54.36520768750099, 55.727988135430124, 58.34394624156337, 61.12844467163087, 60.39543997856879, 62.36676831399242, 60.51112244206091, 62.70493938076881, 61.160874828215576, 59.650797613205455, 57.58499114744125, 59.299243419401115, 55.25789991501839, 54.81168716184555, 53.986267505153535, 52.39493054728354, 52.43910820253434, 53.965780965743534, 54.82836507981824, 60.57059341861356, 45.323928709953066, 40.03904088850945, 40.81566626025785, 39.7060904964324, 37.54541366331039, 37.68703868312221, 35.45539048410232, 31.188787221908573, 42.61141753965809, 41.99339712819746, 41.35095996241416, 44.27940937780565, 46.43623444341844, 43.12940574461415, 38.729016319397964, 37.0747527768535, 38.117385448948035, 39.74593785501296, 41.594233205241544, 41.39212523737262, 43.4536406301683, 49.657037719603515, 49.451038760523645, 57.080409603734175, 42.79529825333626, 48.99094866168115, 53.10305564634262, 48.67935557519236, 51.34847356427101, 52.096218524440644, 56.68916886852634, 59.467615081417954, 57.4849550185665, 57.07010945966167, 57.952599602360884, 54.308400000295336, 54.25339660336895, 54.75196907597204, 56.0766044739754, 53.82029633368216, 53.95038174044702, 49.91964432501024, 39.02200560415945, 41.04985921613632, 44.98370232120637, 52.43201655726279, 54.672646983977295, 51.68364794023576, 50.17420614919355, 47.18113176284298, 48.02862651886479, 47.61095685343589, 49.2877975586922, 49.34147519450034, 48.85109263081705, 51.33418436973326, 51.29130109663933, 49.71444160707536, 56.10683025852327, 60.04701975853213, 62.64027126373784, 61.30352358664236, 64.53673331968247, 66.2986384668658, 64.45907431264078, 59.49199653440907, 61.06150942464029, 54.463686635417325, 58.3219535120072, 66.73401371125253, 75.00476268029983, 71.80763090810468, 78.31911056272446, 74.34617319414693, 82.442486516891, 63.709372089755156, 29.095271172062045, 2.484622689024095, 23.96688788167892, 70.59504585881388, 49.529823487804784, 36.68162538159278, 28.671855234330703, 42.97154603465911, 44.406298052880075, 40.4830414249051, 67.79303796829717, 42.16152560326361, 0.14352922327816486, 0.07384018131321476, 0.12187848303226695, 0.14612100597831512, 0.03539865919118447, 0.17001747934808656, 0.03155329617701712, 0.41268301526865653, 0.1447611692692003, 0.08223104275642865, 0.1276263641193509, 0.1662724278867245, 0.19052519342832028, 0.13100872657472087, 0.21418655441413004, 0.308329000348045, 0.36034067071253256, 0.1291996405850495, 0.18140897695575992, 0.17469512028319223, 0.22788629025941898, 0.20578800910903564, 20.793629615537583, 89.9579752645185, 55.541648095653905, 45.88410200611238, 68.27156712931972, 31.8312910679848, 46.63376500529628, 58.648663413140085, 85.22979336400186, 36.918285508309644, 2.3972004123272437, 66.12927836756553, 77.63022468936059, 79.37527148954331, 72.83555076968285, 71.7517214436685, 69.03160479760939, 73.80615695830315, 71.78418297921458, 69.19424979917466, 57.988199034044825, 51.471216294073294, 55.39225678290091, 55.977737211412006, 52.63987864217451, 52.358931033842026, 57.62986306221255, 57.88360903340002, 54.38058337857647, 57.08592445619645, 55.50038476144114, 50.567631644587365, 53.48179186544111, 51.88086863486998, 49.85346217309275, 50.025638534176736, 48.5606058182255, 48.67978311354115, 53.050091881905836, 53.436837580896196, 52.58610294711206, 58.06306531352382, 61.57825816062189, 66.36049424448322, 64.8409366607666, 61.432400903394154, 57.21892026162917, 53.71537685394288, 58.021735299018125, 62.21156797101421, 61.11884663181921, 66.65721370327857, 62.77562049127395, 65.6985785884242, 64.69009407104986, 62.143691355182284, 64.26569754077543, 64.8918294137524, 59.021123839962875, 59.103940763781154, 56.65404012126308, 55.88088604711718, 55.3753121437565, 58.444978652461884, 59.94379866507746, 64.08654720552506, 46.949323608029275, 40.05757800994381, 43.27651816029703, 41.14851074834024, 38.95854165477138, 39.73717528004801, 39.253625485204886, 33.88949009679979, 45.27529916455669, 41.261043548583984, 41.60290556569254, 47.493634839211744, 49.759235074443204, 46.878328707910356, 39.45130901951944, 37.44151792218609, 39.71433139616443, 40.84481339300833, 44.99233938032582, 42.766292325911984, 47.08597898483277, 52.671473333912516, 51.453977477165964, 61.43865316144882, 49.6047015343943, 51.08790266898371, 55.82734569426506, 51.179564537540564, 52.64008260542347, 56.60274336414953, 58.67825769609021, 63.14411147948235, 61.28008742486278, 59.330692983442745, 59.8521799425925, 56.62608931141516, 57.59619735902356, 58.99563235621299, 59.40917176585044, 56.14808967036586, 54.88675348220333, 51.47755876664193, 39.74431791613179, 41.42699903057468, 47.45097906358781, 55.46406753601567, 56.925397534524244, 54.50116488241381, 53.09339092623804, 50.59180913432952, 51.926634850040564, 50.118661465183386, 50.18820116596837, 53.49264898607808, 51.68854698058098, 53.57407346848519, 54.69865622058992, 52.372212179245494, 60.83989158753426, 63.43197030405845, 65.93625068664551, 64.87557118938815, 66.13249471110683, 65.73688053315686, 66.87085736182429, 61.7047389091984, 63.601322558618364, 59.308390386642955, 62.92059913758309, 70.9157153098814, 78.79560793599775, 74.77142087874874, 81.71774233541181, 75.23492736201133, 86.47838577147454, 68.141234613234, 34.94785539565548, 3.1023023445760054, 24.9133950279605, 80.51285297639909, 54.095623185557706, 35.924407897457, 34.630347374946844, 51.92449323592648, 51.77426645832678, 48.07270219249111, 74.09845982828449, 49.44921093602335, 0.32475046272720065, 0.18044733742792762, 0.21871182046109633, 0.30918000145785274, 0.23173251129206152, 0.1646030456909249, 0.1288672503564627, 0.487819294775686, 0.3148764474017005, 0.18298279734388476], [0.1715268870635379, 0.12074483378279595, 0.08700674294584221, 0.06854511181553526, 0.1261305621254348, 0.06462412060148294, 0.09402547962963582, 0.05007583129730436, 0.0964998976597863, 0.03577925933284625, 0.27697498279233135, 0.16706676913365243, 21.05794245196927, 69.3237429280435, 40.262592454110425, 36.546480117305634, 29.341115528537383, 30.480968067722937, 23.092503316940803, 42.419566569789765, 56.58182536402057, 52.94065383172805, 1.3342453274996051, 49.977679714079834, 77.25958424229776, 67.50452410790228, 68.49041185071393, 64.41780313368767, 70.75071688621276, 66.60919604762908, 64.99740392931047, 54.370216554211034, 50.56099107188564, 51.634465340645086, 47.47380333562052, 46.61236063126595, 45.36465467945222, 49.36874743430845, 47.83870535512125, 47.970500915281235, 47.1272187848245, 47.77528455180507, 46.58285264045962, 44.592708695319395, 45.70582243704027, 46.533587671095326, 45.62915578965218, 46.85751661177605, 46.74248526173253, 43.453809292085715, 47.583668924147084, 48.71220542538551, 50.3944040882972, 49.03633832931519, 51.342401735244266, 55.039427818790564, 55.67374175594699, 52.761703537356475, 54.63010495708835, 58.679842333639826, 61.48981655797651, 60.027666784101925, 59.92395147200554, 56.506900248988984, 50.32665298831079, 57.393332373711374, 55.073583818251095, 53.44131692763298, 50.71265735933858, 49.464959252265196, 52.28750467300416, 54.096427271443034, 55.78329747722995, 49.17458618840864, 44.40442708230788, 53.80835271650746, 50.684012289970156, 50.42768147683913, 38.88475010471959, 41.1901427853492, 41.52452876490932, 45.15437641451436, 41.27547787081811, 39.05206664916008, 39.16590167630104, 42.865434154387444, 42.900637426683986, 49.39876533323719, 64.62831674083587, 59.484053734810125, 52.21040656489711, 46.28263442747055, 39.870143628889515, 44.02849143551242, 41.62265469951015, 38.28110910231067, 37.27553890597436, 42.71175961340628, 38.62008817734257, 49.98401434190812, 51.13421801597842, 55.094015444478686, 40.02794450329196, 49.08711341119582, 52.37054909429243, 49.88812023593534, 50.65340603551557, 52.17146919619653, 51.60464356022497, 54.63691026933732, 53.33468729449857, 52.22618626010034, 51.874130002913944, 53.588378352503625, 53.21837725177888, 53.250391637125325, 53.2670146419156, 53.4532017092551, 51.10367451944659, 43.871149478420136, 40.29275155836537, 41.50112790446128, 45.84453313581405, 54.06660549102291, 47.96009878958426, 47.6975667092108, 47.3139863629495, 44.42104616472798, 42.50697658907983, 46.10311538942399, 45.57997319006151, 45.91446507361628, 46.88500850431381, 46.708395942564934, 49.15633147762668, 51.00556819669662, 56.3309270335782, 56.65457748597669, 58.58814516375142, 61.639474591901234, 60.529781156970614, 63.55712529151671, 61.47847698580835, 57.13738203048707, 55.37342940607379, 51.38019377185453, 53.974712202625895, 62.371820326774355, 68.98818415980186, 72.1217264667634, 72.6746473004741, 74.43932948573944, 76.93208202239006, 54.55331671622492, 16.140118856583875, 0.45689094631421956, 33.28209930850614, 65.83321002221876, 41.90229615857525, 25.303941503647838, 37.38416502552648, 34.1382860368298, 39.99384733938402, 46.50029067070254, 58.90962262307444, 39.15492296218872, 0.100645138131034, 0.16110449068007932, 0.05414210725575686, 0.13906662322340474, 0.2666969020520487, 0.3514916810297197, 0.1812996715307236, 0.14997525561240413, 0.1679574229544209, 0.03437200178121848, 0.14802168544021346, 0.14548910601485163, 0.08184171687330931, 0.04816211684937439, 0.0469777487488764, 0.058041770581997214, 0.04853413297584461, 0.03653274511077231, 0.10505471724055468, 0.034577788319438696, 0.1739854930389312, 0.08881043567652665, 24.049179207894113, 81.95886611938477, 44.07197483124272, 45.376382566267445, 39.87477202569285, 32.637255768622126, 40.01450646308161, 47.989041959085775, 63.79011015738211, 58.407963245145744, 2.152781347113271, 48.3556305977606, 80.77802873426869, 66.73162891018775, 70.56602816427909, 65.32041503537086, 70.59797979170277, 68.29056709043442, 66.35350458083614, 53.6277001134811, 53.980093694502315, 52.49855172249579, 49.5740835128292, 48.59858220623386, 46.36952277152769, 51.00464251733596, 52.89867270377375, 49.494000481021025, 51.150860632619555, 51.69441092398859, 51.71889043623402, 48.716943648553666, 48.82346345532326, 49.874952839266875, 49.09771165540142, 48.61254976641748, 49.41096390447309, 45.3411243807885, 50.40701843077137, 52.513711683211795, 53.62719412772886, 53.6297397459707, 54.88096798619917, 57.61749582905924, 55.59287032773418, 55.73561714541528, 56.81855609340053, 61.57827777247275, 64.85786953280049, 66.63191441566714, 65.93886298518028, 61.6342225382405, 54.86441950644217, 60.05153440660047, 60.37776185620216, 56.90886082187776, 53.88831023247012, 55.190074289998705, 56.55004239851429, 58.19089927980977, 56.89000991082961, 53.30089607546407, 49.91816559145528, 57.593326184057425, 56.18666618101059, 54.79041222603091, 45.29224772607127, 44.33825669750091, 44.41658250747189, 46.68628946427376, 40.96416327261156, 37.04284037313154, 37.55682776051183, 39.7440904186618, 43.21763161690005, 46.90815441070065, 59.82448800917595, 54.29271836434641, 47.83598323022166, 42.50828273834721, 37.601064251315215, 39.015871017209946, 37.956862449645996, 37.96480132687477, 36.601691399851155, 42.45439329454976, 41.27094361089891, 52.4572923106532, 53.33351842818722, 57.19142052435107, 43.393589142830145, 51.89009404951527, 53.656690351424686, 53.20796728134156, 54.3370254578129, 54.49581869186894, 54.05537966758975, 58.247957998706454, 58.218681427740286, 54.46619695232761, 54.9577130809907, 55.61364712253694, 52.23556464718234, 52.36377516100484, 52.20474266236829, 54.7689764730392, 54.160911037075905, 43.64243607367239, 39.36062774350567, 42.88657572961623, 47.7345742717866, 53.840339645262695, 49.15133830039732, 48.95879699337868, 51.6153790873866, 46.82373323748189, 45.73918611772599, 45.99151611328126, 48.018012585178504, 47.89883528986285, 49.4469791073953, 50.32296596034881, 52.38714072012132, 55.995332964005016, 60.16325135384837, 63.81165965910881, 63.124185839006984, 67.43636900378813, 68.66400810980028, 69.86888962407266, 66.73008349633986, 61.9638075367097, 61.66862172465171, 54.27061580842542, 56.9497162295926, 66.95885965901037, 73.68104903928696, 77.85154050396335, 80.33395367283975, 78.30841818163472, 82.18561049430602, 57.57422816368842, 14.626828239810083, 0.6368336922699406, 43.03022469243696, 69.38435923668646, 46.64559095136581, 27.04083565742739, 34.38472071001607, 40.93911109432098, 46.57671020876977, 57.10519506085304, 66.81510479219499, 50.57493509784822, 0.1902890391647816, 0.041108553808542996, 0.006694956804670755, 0.04662004314483174, 0.1797819134568976, 0.2816535736764631, 0.19614469350105335, 0.26849328630393554, 0.21025021079807513, 0.032055700468199874, 0.1865215260054796, 0.15881086940005903, 0.14083795640016758, 0.06926530341227209, 0.15662598664001112, 0.24209636323634656, 0.252331527731111, 0.13522574948447366, 0.22375549820642318, 0.1884822974041585, 0.5171409729988344, 0.33601615337594865, 31.993900768218506, 89.15779605988534, 56.22497204811343, 49.55544833214053, 45.744316577911384, 43.956633613955596, 34.77110555095058, 57.99054853377804, 71.17499966775218, 60.87041154984505, 1.9958272143717737, 53.2355336989126, 79.43598193507042, 71.46813408021005, 72.48773067228257, 66.57461643218994, 72.3869885167768, 71.24798713191863, 67.49649109378939, 57.590933538252315, 57.56368483266523, 56.862051256241344, 50.94425370616298, 50.79046933881698, 47.017031561943796, 54.40303894781298, 55.47826259366928, 51.809371671369, 55.77459373781758, 54.98897829363423, 54.62961073844664, 49.83931810625138, 51.08715741865097, 53.6133324715399, 51.008788462608095, 48.627592056028305, 48.87737251097157, 47.324639520337506, 51.73641558616392, 56.23060457168087, 57.32821318411059, 57.57047837780368, 56.35685390041721, 60.05498216998193, 58.937671492176676, 55.99001030768118, 57.800705817437944, 65.36159599981, 66.12019415824645, 68.59736704057264, 67.23861878918063, 66.88890026461694, 59.8705287902586, 65.3901037862224, 63.59392889084355, 59.91893868292532, 56.56186834458382, 61.91991621448148, 59.247954507027906, 61.11770522209906, 60.996519673255186, 58.62542336986911, 56.74057152963454, 65.46000042269307, 59.22672271728516, 59.07990840173537, 48.41565855087773, 46.9751641827245, 47.35401022818781, 47.45773338502454, 42.20883330991192, 37.592976324019894, 37.83548470466368, 41.58060296889275, 44.87627644692698, 48.259528606168686, 66.64310101539859, 59.19119388826432, 52.195678064900065, 43.48239160353138, 38.74460774083292, 39.88901022941836, 40.32022776142244, 40.56145352701987, 37.52322089287543, 45.60448408126832, 45.80214015899166, 58.63544502565938, 58.6346919305863, 63.622605339173354, 51.22074550197971, 56.27162471894295, 56.870519653443374, 56.70479951366302, 57.76569866365003, 54.88384700590565, 56.88970396595617, 61.90820401714694, 61.844371364962676, 57.862063454043486, 58.8819581462491, 59.264393160420084, 53.83506013501076, 53.46121511151714, 53.73600459867909, 54.91590061495381, 55.41187255613266, 46.157644179559526, 40.222925524557795, 42.96265794384865, 50.67358663005214, 58.00864634975311, 52.29896976101784, 51.36854433244275, 54.97652476833713, 49.74620496073077, 44.53062934260215, 47.56973666529502, 49.50250025718443, 51.43660137730261, 52.23783962188229, 51.509565307248025, 53.89972040730139, 57.66759626327023, 64.6466459766511, 66.46134622635381, 63.62824962985132, 68.08755305505568, 68.63895200913953, 74.87339465848862, 67.9803389887656, 62.360194421583614, 64.9769958373039, 59.04770574262066, 60.97124391986478, 71.7032644825597, 77.71624226723948, 80.15073191735053, 81.59927891146752, 79.061936870698, 82.93418699695219, 63.25427909051219, 18.501237630844116, 1.4283464200073674, 42.91005895983788, 75.7321426945348, 51.342923410477184, 31.010456662024225, 50.83190917968751, 49.219560084804414, 51.482214620036466, 60.97323256154215, 75.59388699070101, 63.208544254302986, 0.584465331367908, 0.2684655232775596, 0.10177987522535747, 0.18588746567406964, 0.34358979052593636, 0.4491715685975167, 0.25279003135379285, 0.30733100228732635, 0.3497636624641957, 0.11337774159807353], [0.027177486223198717, 0.054454640485346324, 0.1021717751639024, 0.1836656421543129, 0.03400744352069113, 0.038543768046844396, 0.08139675002424948, 0.039645210959978645, 0.12777627986525336, 0.06764535687022633, 0.2302517246214613, 0.17484001815319064, 15.870080340293148, 58.69577500127978, 55.43042536704771, 31.343777718082553, 30.711066069141513, 40.31477174451275, 15.831953921625692, 43.116469767785844, 44.346073981254335, 79.3798214389432, 5.40712897816012, 34.41881002918367, 83.77855562394666, 64.89344935263357, 70.0993759401383, 67.21102099264822, 66.37148472570604, 64.96109062625517, 60.24122022813367, 50.32748845315749, 50.83108940432149, 48.166301711913086, 50.90719907514511, 55.14832850425474, 53.47261351923789, 54.439313027166556, 56.46715487203291, 53.69230939495949, 53.36015524402742, 53.6487671636766, 50.96821938791583, 50.54226959905317, 49.649322417474565, 46.84495718248429, 47.66193982093565, 46.29200889218239, 46.21566387914842, 46.772930699010054, 44.81000408049553, 48.15282052563083, 49.2576894452495, 49.01755409855997, 52.20638613547049, 53.66937137419178, 54.10827282936343, 53.9815685056871, 53.48834614599905, 51.451604443211714, 53.74430825633388, 55.23174947307956, 52.6307277525625, 52.425411285892615, 49.90053453753072, 53.4687578293585, 54.164633366369436, 52.96938911561043, 52.91958285916237, 52.24630017434397, 54.500215668832105, 52.665256377189394, 49.235582966958326, 49.83340317203153, 44.48424731531451, 49.93572604271674, 49.16598443062075, 50.245118679538855, 39.51153701351535, 38.74368206147225, 40.65014616135628, 45.88484725644512, 41.67603031281502, 39.493537256794596, 44.08495787651309, 40.161469828697946, 50.83707494120444, 54.03654444602228, 51.38495552924372, 56.527790792526744, 57.20496839092624, 43.264511785199566, 40.11714704575078, 38.89999635757939, 36.819143679834184, 36.63741634738061, 36.99078267620456, 40.01245506348149, 41.04709786753501, 46.37257829789193, 49.49442409699964, 50.26934716009325, 40.58730194645543, 49.59796290243826, 51.69654077099216, 51.09089935979536, 51.03945747498543, 48.94802224251532, 51.78806927896316, 56.41397929960682, 50.703694743494836, 52.0300442172635, 52.00526268251481, 52.19059075078657, 47.93308150383734, 52.77246652110931, 54.63209752113589, 53.462991945205204, 46.210023510840635, 42.6034394387276, 42.240890841330256, 46.05041834615892, 50.674473085711085, 49.01532226993192, 47.99042263338643, 47.2903109365894, 44.58576217774422, 45.31948466454783, 45.73018427818052, 44.77422814215384, 45.96363590609643, 45.983408574135076, 45.35626472965364, 47.25087934924711, 48.70791043004682, 50.65708129636703, 58.186129677680235, 61.812196162439164, 61.16906865950554, 68.21009574397918, 77.4713530079011, 59.07633120013822, 63.24676382926203, 60.32186415887649, 59.367323998482, 53.70522183756675, 51.618724869143584, 59.65624970774497, 68.80824150577669, 70.20626052733391, 73.91907415082379, 74.29438221839168, 80.35938632103705, 39.73715566819714, 7.02549449859127, 1.8699282023214527, 46.761230268786036, 62.62010635868196, 32.08370931686894, 26.217475245075843, 36.70908589516917, 30.880741919240645, 41.812842584425404, 38.83280223415744, 54.915555446378654, 45.985695315945534, 0.18199069816018307, 0.05141807096679846, 0.0434672351055328, 0.04449434450737411, 0.032328393295287125, 0.23402426331754655, 0.1879604076666217, 0.05704752252166791, 0.12928466102288616, 0.07463223961812836, 0.057715428617572596, 0.06067175808693133, 0.14248267056480532, 0.08739395442629054, 0.099224274857871, 0.08450391071458017, 0.07623727042828837, 0.13719359953557292, 0.12973225555352627, 0.051296374069586884, 0.3090709105374352, 0.1521437900561479, 19.042630618618382, 68.67870130846578, 56.35240201027163, 30.41311106374187, 35.871804991076075, 36.757582079979684, 21.91610997722995, 50.02428531646729, 46.257731299246515, 86.24538913849862, 7.472232359070932, 35.04637748964372, 86.15474316381639, 64.31295425661149, 72.0783293631769, 66.9189142411755, 66.86338132427585, 66.09474582056846, 60.162325674487704, 50.3803345464891, 51.05599811000209, 50.03622893364199, 54.667320405283284, 57.615291457022394, 56.20284203560122, 58.751103954930464, 60.19403411496071, 58.999790068595644, 58.08505412070983, 57.58981174038303, 54.04054526359805, 53.90184240956461, 52.41032192783972, 49.367723695693485, 50.176430133081254, 49.15100097656251, 49.08508554581673, 48.615538612488784, 49.166392357118674, 52.63354793671639, 53.7204170996143, 54.51063348400978, 55.81902634712958, 55.183386648854906, 56.67766847918111, 57.24809877334103, 55.34171704323062, 53.79545596338088, 57.70989510320849, 62.72493562390728, 58.54016280943348, 57.13914317469443, 55.878971930473085, 56.577655884527395, 57.51562010857367, 56.51954597042453, 57.53265103986187, 57.393383364523615, 56.40002742890389, 53.01426887512208, 51.005030831983014, 51.467984261051306, 47.45264214854087, 55.784858580558534, 56.220826102841286, 54.07340688090171, 45.374291942965606, 43.10049787644417, 41.5119497237667, 45.25842120570522, 39.35353217586395, 37.46629161219443, 41.311748027801514, 39.05301586274178, 46.37918749163228, 51.20252217015913, 50.7314141335026, 54.330702597095126, 54.39525304302093, 41.543599328687115, 37.576388620561175, 36.774930723251835, 35.541184486881384, 36.46046646179692, 36.063087217269405, 39.10657974981493, 42.147491362787065, 49.01800124875961, 51.32029525695309, 51.64611478005686, 42.13306096292312, 51.81191728961084, 52.94156382160803, 55.20989794884959, 54.67965233710505, 56.16430867102839, 56.72626272324593, 58.70993083523166, 55.0810637781697, 53.60450321628202, 52.74834786691974, 51.6386426648786, 50.002837796365064, 52.804331856389204, 54.78606623987998, 54.8470865526507, 47.17651905552034, 39.184987929559526, 41.18449457230107, 46.56549223007695, 52.46793762330086, 50.881570308439194, 48.58274367547805, 51.16665993967364, 47.06447655154813, 48.38707231706189, 48.58161011049825, 48.84888433641004, 50.73065711605934, 50.59185620277159, 47.797834257925714, 50.34045973131734, 53.83966891996322, 56.88411458846062, 62.659031960272024, 66.09170206131475, 64.71644063149729, 70.36727382290748, 81.2783427392283, 64.87984265050581, 69.88848578545355, 67.00652430134436, 63.656067079113384, 57.69562944289177, 54.526228827814904, 65.1581818826737, 72.06306349846625, 72.82434848047072, 77.56010055541992, 77.40373919087072, 85.30441253416001, 43.57647357448455, 6.601364199192294, 3.4988475951456257, 55.82536489732804, 68.69650886904809, 35.23724002222861, 25.03294102607235, 37.23768411144134, 34.780319198485344, 41.253018379211426, 40.12735305293914, 64.00867639049407, 52.89375012920749, 0.590335158330779, 0.031349363571573655, 0.059645464568729364, 0.034379237481663306, 0.08484370135251554, 0.4082329330905792, 0.24341239503795103, 0.06883034167150337, 0.06793249428512589, 0.039687269187021645, 0.19933115961330555, 0.17465813355820795, 0.2432114961406877, 0.3838630633488778, 0.2665116007049238, 0.14901212987399873, 0.21071784618881442, 0.28512002960328137, 0.23956543856090118, 0.31532463948092154, 0.4402419251780357, 0.24238062782153008, 24.85349455187398, 78.62618507877474, 71.49457085517146, 46.74223815241168, 43.60471463972523, 57.4432445341541, 21.96330393514326, 60.02564676346318, 55.445604939614576, 87.29841216917961, 6.556007381408445, 39.05007408511254, 85.14297562260782, 64.99096339748752, 72.84729434597877, 69.81243102781235, 68.99031008443525, 69.59995623557799, 62.12162410059283, 50.39595342451527, 52.814526096467056, 51.35639675201909, 54.48145497229792, 57.4486417155112, 56.2475178318639, 60.91866062533472, 62.32072753290977, 58.906206238654356, 58.02825427824452, 63.01476740068006, 55.03426205727362, 55.995787958945, 55.61138391494752, 52.021301254149414, 53.29007425615865, 51.85605572115991, 50.054197311401374, 49.88260930584323, 50.78748049274568, 55.08637858975319, 55.685340204546534, 58.388065061261585, 58.93260378991404, 59.7636559701735, 57.97017182073286, 58.37981239441903, 56.772503545207364, 56.47395233954153, 63.3295532964891, 66.9346272560858, 61.85803298027285, 61.472189426422126, 61.70492718296667, 61.32863460048553, 62.80714458034885, 59.4647321393413, 60.78184835372433, 57.884989707700676, 60.468631405984205, 58.028791642958126, 53.83875893008325, 56.18617588473905, 54.46395727895922, 60.04247765387259, 63.471048878085234, 60.95699787139893, 48.74844812577771, 45.26040592501241, 42.77340750540457, 46.00024730928483, 40.11176947624453, 38.33326093612179, 45.57499962468302, 39.3808554064843, 49.75979597337785, 53.08132571558799, 50.370277589367284, 58.82392275717951, 58.575919135924316, 41.486066002999586, 38.04453134536743, 41.48643470579579, 37.760398772455034, 38.1202095554721, 38.483860338887865, 41.72058843797253, 48.575675564427534, 54.50510294206681, 56.11159201591246, 55.2190488384616, 48.281352673807454, 53.97953279556767, 54.63871848198676, 57.78627149520382, 58.44513946963895, 62.1013532915423, 59.94889774630147, 62.41055373222598, 60.913977315348966, 57.53347081522788, 57.69934392744496, 56.60557923778411, 51.378240431508715, 52.814851653191354, 58.877357206036976, 57.348954677581794, 45.93614401355867, 39.575193159041866, 40.393823192965606, 46.59864802514353, 55.34026576626686, 53.74327275060839, 51.73254812917402, 51.368414894227065, 49.30843707053892, 50.84753590245401, 50.17805791670277, 51.08363513023623, 54.12302094121134, 51.14621654633553, 49.71878759322628, 51.170080246463904, 53.00752239842569, 56.94615079510597, 66.43668236271029, 68.26413031547301, 64.20683453159948, 72.81236956196447, 81.28741910380703, 67.10055135911512, 71.75528295578496, 68.47975084858557, 66.66086150753883, 63.55946694650958, 60.41112553688788, 71.15191259691792, 74.91274387605729, 74.85739138818558, 77.40241342975249, 79.05531590984714, 83.78435288706135, 52.80949369553597, 6.53790956543338, 3.3696790424085434, 54.230725303772964, 71.64147930760538, 43.17992587243357, 31.743871242769305, 49.18460784419891, 43.83568732969223, 52.44915339254564, 47.4882572697055, 68.17565733386625, 64.92447922306677, 0.7604647776292217, 0.096996100469222, 0.11766306124627592, 0.1215253624644491, 0.1091144316559357, 0.6344575939639923, 0.3235660295092291, 0.1893488960641046, 0.24538165469083095, 0.14180888091364216], [0.03514085145246598, 0.07835310568372089, 0.07158324798388828, 0.07650376177362858, 0.09461729021202173, 0.15518670661314843, 0.029063975821519573, 0.09448571461102656, 0.03433144891694669, 0.0348374423300547, 0.09833137639948437, 0.2628081478178501, 19.82470416253613, 60.46540329533239, 44.35284006980158, 63.97574417052731, 47.90479729252477, 38.17887252376926, 28.040677232127038, 33.7420952704645, 37.451006135632916, 82.64182921378844, 20.828609312734297, 17.444492270869596, 84.30825602623725, 62.71096021898332, 72.95574788124331, 61.89096912260979, 66.9317796153407, 56.20910213839624, 55.91880359957295, 51.90552073140299, 53.060541076044885, 53.160785090538766, 60.74948879980273, 60.08174450166764, 62.02976219115719, 60.37111736113026, 62.48120346376973, 58.64685127812048, 59.22343184871059, 58.24114876408731, 56.1098583282963, 54.04955887025403, 52.68147145548175, 48.091961030037176, 46.526970632614635, 46.58365280397477, 46.9026787819401, 45.98762904444049, 44.87774341337143, 42.721946008743785, 47.60665401335686, 47.889452980410674, 50.1531312542577, 51.4849445896764, 55.54156180351011, 54.19048963054534, 52.572174610630164, 48.860372958644746, 55.56508033506332, 56.70405034096011, 54.18689281709733, 55.576780765287346, 55.78463108308854, 52.91826102041429, 53.83645257642193, 51.72825313383534, 52.77884037263932, 51.61628907726657, 51.16817789693033, 47.49307394027711, 47.98529217320104, 54.36889863783314, 44.03270013870732, 53.977316656420314, 52.992185931051935, 47.63218864317864, 40.06665437452255, 40.39541959762573, 40.77965497970581, 45.82592541171659, 45.885266950053555, 47.38737390887353, 45.903254939663796, 44.83783329686811, 42.03580971687071, 40.89999329659247, 40.522704432087565, 44.169382972102014, 41.36054231274513, 41.895863471492646, 41.74242427272182, 34.79236087491436, 32.10454690840937, 29.767116308212284, 31.020988225936893, 40.00825812739711, 41.60765947834138, 46.56078146349999, 51.672618235311205, 54.22532812241585, 41.063038379915305, 52.360770625452844, 48.77510847583894, 48.937749555034024, 51.235560294120546, 50.231959127610736, 50.61167201688213, 51.61454754491007, 52.12476945692494, 52.97645722666095, 51.12591435832363, 47.81018580159834, 49.16554120279128, 51.47190270885345, 52.123580978762725, 51.03842589163011, 50.19766584519417, 47.01331707739061, 50.003547745366255, 52.43431506618377, 48.835571812045195, 46.80877724001485, 44.17380740565639, 45.95498707986648, 44.3404689142781, 45.58098908393614, 45.55923561896048, 45.32820409344089, 46.39488873943206, 49.394133014063684, 47.60688543319703, 48.3178150269293, 48.27020137540756, 55.896512769883685, 59.59916353225709, 60.905077457427986, 61.64648778976933, 59.098037596671816, 70.46084588573825, 63.13756504366475, 60.8674148590334, 61.69683533330118, 61.57164504451137, 55.65687948657621, 51.69933349855485, 60.07497449075023, 67.91587875735375, 69.32776727984029, 71.28338260035362, 72.16178955570345, 78.73177528381348, 31.19868140066824, 2.8374097328032217, 10.86736979023103, 49.33122604124008, 54.0520142739819, 31.151748280371393, 29.093970906349924, 30.092382777121763, 40.772386827776515, 51.53836727142335, 44.48328633462229, 49.86937915125201, 46.841689848130756, 0.632476490591803, 0.04947270559627683, 0.08997147256929068, 0.03941489428642296, 0.09443928202193591, 0.07639753602204785, 0.08747390336206845, 0.1697457173178273, 0.06085146699220904, 0.07032751496280394, 0.08991901852911519, 0.009467281051911414, 0.17528418060992995, 0.1017212311947538, 0.05386967872900348, 0.08632010600018887, 0.04050917044702557, 0.055006580021713054, 0.03473625360657612, 0.03732443569348224, 0.09792254591781287, 0.1851655350577447, 26.05259253132728, 72.4464673380698, 53.931138592381636, 69.31040686945762, 50.526748780281316, 41.14274486418694, 23.03518964398292, 44.71827945401592, 39.46570411805184, 89.16532701061618, 26.286254006047404, 18.868275380903675, 86.90523378310665, 67.41044213694911, 76.28394957511657, 65.03577647670623, 68.6481225106024, 56.616538340045565, 56.982534700824374, 52.94602355649395, 53.86599979092998, 56.381921768188484, 63.72056261185677, 65.55538069817328, 65.22440718066308, 64.9275622060222, 65.08145639973303, 62.95422561707036, 62.20761029951034, 60.71608197304511, 58.33996503583847, 55.12739873701527, 54.93886609231272, 50.500633639674035, 49.76123940560126, 49.65493925156132, 48.57631098839545, 50.85094051976358, 47.68406198870751, 46.1631590320218, 52.31121147832563, 51.919021529536096, 54.5616360633604, 53.05283361865629, 55.25256941395422, 55.860646617028024, 54.14067552935693, 49.75546175433744, 58.622116811813854, 60.77258763774749, 58.0485603886266, 59.90319821142382, 61.49337022535263, 57.82245928241361, 55.88596551649032, 55.60530031881025, 53.8425636291504, 54.84549407036074, 52.893040180206306, 53.461783855192124, 53.9999173533532, 58.32461287898403, 48.506500644068566, 58.06584627397599, 58.13030258301766, 50.58138739678168, 43.31882484497563, 43.330282088248964, 43.64118091521725, 45.283614589322, 46.08105990194505, 44.481925272172504, 43.41558187238632, 42.11313140007758, 42.02223439370432, 41.58799271429739, 42.670853214879195, 47.54320575344948, 44.15973786384829, 42.6987922576166, 39.579276346391254, 34.98843231508809, 31.8404576470775, 32.590512883278635, 33.50139118009998, 43.01016569137574, 43.29067007187874, 46.58211915723739, 51.933424472808845, 54.13034008395288, 41.62663982760522, 52.575916551774554, 52.123349558922556, 53.57704662507581, 54.31128686474216, 55.54493111948813, 53.75906029055196, 52.617368159755586, 54.735742230569166, 55.68083340121854, 51.49477404932822, 50.451874656061975, 52.616262051366995, 55.307419838443884, 51.73181856832197, 53.725276916257805, 51.9788259075534, 49.37194416599889, 52.12394575918875, 54.92730294504474, 54.61238761102, 52.103259178899954, 51.17546566071049, 49.37395241952712, 47.968425981460086, 47.85844272182834, 48.809597876764116, 46.54213451570081, 48.98963466767342, 52.51703393074774, 50.83798100871425, 50.243016289126494, 52.02621206160515, 60.76890453215569, 66.16945128287038, 66.80099994905534, 68.10004188168433, 65.69424044701361, 70.87147881907802, 65.05622771478468, 63.41532376504714, 65.41719951937276, 64.8719665311998, 59.51899028593495, 52.86996095411239, 61.09593606764271, 69.07107168628325, 72.0635655618483, 74.24825514516523, 73.83952848372921, 80.64270696332379, 35.000725023208126, 2.508602099072549, 12.907809307498317, 57.43288555452901, 54.7202096446868, 32.62930708546793, 26.462240949753795, 31.702252934055945, 36.05238699143933, 40.55756645817911, 47.60095088712631, 58.65196997119535, 56.646669987709295, 1.3794624108460642, 0.0775865121414104, 0.014683341029130164, 0.10222646618081678, 0.06294574836389193, 0.15505881589506904, 0.07849330743474346, 0.17655139728899927, 0.0267258275961203, 0.08976501187369709, 0.16207173797151736, 0.14779161391479356, 0.3448682380539756, 0.255249955000416, 0.2966346068968696, 0.21688922068044064, 0.1745294920739628, 0.1888937325847726, 0.20675375486814207, 0.15532500080523953, 0.20506376490717937, 0.3179260289236423, 31.33372860570108, 86.4989782148792, 58.159084935342115, 80.58711913324173, 65.7338720752347, 52.49694355072514, 37.354810007156864, 51.58754202627367, 48.311621604427216, 95.52243001999395, 25.331756991724816, 20.94863384000717, 92.73597040484029, 66.48558647401872, 78.63581841991794, 66.7514290348176, 70.38828988229075, 58.782553518972094, 60.00603883497177, 55.44137662456882, 54.78376380858883, 56.15731900738132, 64.85717527327999, 67.26600477772375, 68.12367808434271, 65.89625035562824, 68.55319330769201, 65.29951664709276, 64.92924098045596, 64.93200232905727, 61.53127993306806, 59.08429361158802, 58.85075569152833, 53.45347235279699, 52.29279987273678, 51.335219875458755, 50.5638583244816, 51.93848040796096, 50.76000036731843, 49.20492964406168, 53.70075033557031, 54.753926338688025, 59.779372907453975, 55.11352923608596, 59.317266710342906, 58.30133361201133, 53.91802610889558, 49.44992088502454, 61.18103581090128, 66.92675113677979, 63.261672758287006, 64.42868771091585, 64.58005982060587, 58.45807152409708, 62.41010265965616, 61.946529496100645, 58.88360946409164, 59.20447895603796, 59.456330422432195, 56.36540858976303, 55.80061081917056, 62.22337430523288, 52.984345113077474, 62.86336391202865, 62.9804584287828, 55.83616318241243, 48.07816605414114, 47.11190977404195, 45.36645896973149, 48.46028727869834, 47.91233608799596, 47.40660921219857, 43.82891731877481, 45.86513342395906, 44.02076044390279, 44.186759071965376, 45.32241859743672, 47.02919875421832, 45.47831319993543, 45.91891696376186, 42.49862194061279, 36.16412747290827, 31.773453758608913, 34.348611370209724, 35.289878229941095, 46.32800448325373, 46.65227859250961, 51.22319698333741, 53.74734417084725, 57.81180220265543, 46.114929568383005, 57.898113958297245, 54.422642953934215, 56.272154238916215, 58.80365194812898, 57.9880460616081, 57.48472752109651, 56.996812128251605, 57.26302731421686, 58.638892789040845, 57.02119358124272, 54.54668398826353, 53.560902149446555, 56.263615239051084, 55.9217022311303, 56.28576094104398, 53.467643876229566, 49.62916143478886, 53.754788829434304, 59.14552965471822, 55.738806032365375, 55.63945631827078, 53.12604465792256, 52.28450405982233, 48.098256434163744, 51.09120922703897, 52.69957711619716, 49.10077894887617, 50.86134264546057, 57.83206516696561, 54.829396663173554, 53.43327999114991, 52.52614559665803, 61.9532798951672, 65.5684265013664, 69.83023074365431, 72.01025270646619, 71.64432694835048, 76.98589694115424, 67.35095547091576, 67.89138747799781, 65.58229600229572, 67.33520323230375, 62.93302128391882, 58.619994809550626, 68.31676852318549, 72.77927260245048, 72.89780662905785, 75.81606572674167, 76.48319029038953, 81.45350794638358, 41.228076027285674, 3.0127641943193253, 11.255943313721689, 55.875175076146284, 62.65049688277706, 40.472301975373306, 32.48014327018492, 38.867593657585886, 52.173642189271995, 64.65119200368082, 58.11482883268788, 61.51009913413756, 68.00689343483218, 1.915644284698271, 0.16530801512060628, 0.20503525111463763, 0.3193695530776055, 0.2557792145037844, 0.40143368825797116, 0.15127360610471619, 0.33965844180314775, 0.17558442578921396, 0.21106014959514144], [0.022694538873169693, 0.06602282861187574, 0.04309332291144998, 0.046266731055032824, 0.03408279975936298, 0.0560996112894387, 0.05131978954699251, 0.04531828739169625, 0.06058670317513808, 0.04899314987743574, 0.018473055416477785, 0.08688816785692208, 18.72986866581825, 62.19267391389417, 42.7471629265816, 18.82646683723696, 46.5864259196866, 29.708100326599617, 23.523375680369718, 24.772134788574714, 30.703095812951368, 75.7222661664409, 39.01423146647792, 11.027030848687696, 71.00360778070265, 65.86717774791103, 71.3059832972865, 64.23907641441592, 62.76599107250091, 53.57016678779356, 53.411769713124926, 51.93535820130379, 55.336315939503336, 60.10135635252922, 62.657392409539995, 64.19605978073614, 63.86600017547608, 59.971898524991936, 60.58418443126064, 61.828364172289454, 61.207182330469934, 59.55493096382388, 59.01487550427837, 58.84337379086403, 52.81296891550864, 45.72883106047108, 44.88895354732391, 47.64359489563973, 45.18740669373543, 46.10762611512215, 45.725540191896506, 44.59794505949944, 45.554018866631296, 46.695789444831114, 48.48509627003824, 52.64117302433137, 50.79163036038799, 51.928133195446385, 53.91137376908333, 57.65548398417812, 59.481308075689505, 57.1689727998549, 56.30492564170592, 56.58114679398076, 53.27277660369874, 55.409252412857555, 51.10773809494511, 49.12333649973716, 50.91561255916473, 47.24183044125957, 47.20567795538133, 47.02080095967939, 49.25256682980446, 51.75091658869098, 44.29200410842896, 52.09779923962009, 52.02870276666457, 45.22167644193096, 42.907113259838475, 42.483230560056626, 38.778559777044485, 38.824184786888864, 41.40105647425498, 41.69906639283703, 38.78694580447289, 31.027328737320442, 21.936369019169963, 18.047744958631455, 13.306681994468937, 15.18300856313398, 14.654387793233319, 18.577798374237556, 19.674712727146765, 15.632451388143725, 11.532540032940528, 10.221633911132812, 15.877287695484778, 30.620551493860063, 40.95301197421166, 45.2197858595079, 52.66189490595172, 55.83811260038807, 42.51611178921115, 56.680116038168634, 47.41070808902864, 46.475163967378684, 46.48469532689741, 50.529870986938484, 48.939032170080374, 49.41563936971849, 52.42072797590687, 53.05503406832295, 52.7987777802252, 53.088495808262984, 52.36959988071073, 53.64166767366471, 52.837256231615626, 53.91666504644579, 54.031602259605165, 54.092073440551765, 51.63069594290949, 46.34208579217234, 47.99394492180117, 46.4090524181243, 45.90026217122232, 43.73122284489293, 46.69437346919891, 45.39539429449266, 44.4771360581921, 46.50653900638704, 45.59368187381376, 46.67396145482218, 47.980216626198064, 48.69660615921021, 51.33337243910759, 58.956165467539144, 63.17763597734513, 61.40016294294789, 59.817725842998875, 58.96925441680416, 54.36363089469172, 64.31882996712962, 59.29139083431613, 64.51204199944773, 63.0463424805672, 60.55437441795104, 48.948014397774976, 53.14142034899805, 64.6643005647967, 70.86675628539055, 72.37226393914992, 68.73063348954724, 71.41649215452134, 23.559710556460967, 0.8367003933075936, 23.06986535749128, 54.27384391907723, 48.92657864478327, 23.491290692360174, 33.15725418829149, 29.964276206108835, 56.504825315167835, 59.63821857206283, 49.14085380492672, 52.540846640063876, 46.48936686977264, 2.4184594135130606, 0.040577283324373346, 0.0517960510877592, 0.04087189775741389, 0.1923858677788127, 0.007991613285060251, 0.054117737998885494, 0.04947841678175235, 0.03669549665984608, 0.05722547708559902, 0.11431244547448813, 0.01477490098501045, 0.1230150204332125, 0.10538906865422765, 0.017635328695178032, 0.06823388859629631, 0.052812121162611636, 0.024436841148041913, 0.07298024761820994, 0.0503330568092004, 0.049111315109316385, 0.0774727940499302, 26.98798171935543, 68.6762615942186, 51.5184102519866, 25.110705937108687, 53.70652798683413, 32.85229186857901, 30.070217463278002, 42.81092497610277, 33.762985814002256, 78.83993071894493, 45.10674315114176, 12.81811058521271, 72.12578219752159, 72.90703988844349, 72.37887705526045, 69.34905006039527, 63.379355630567005, 56.62767394896477, 55.735526930901315, 55.375794595287694, 58.923233247572384, 65.42600131803944, 66.24225831800892, 69.06738465832126, 64.80330151896324, 65.05707886911208, 65.62970176819833, 66.48171901702881, 64.64882681446691, 62.434397820503484, 61.43137716477918, 60.809555976621574, 56.26151284863872, 48.399694504276404, 46.891147013633486, 48.741121138295824, 46.99830224437099, 51.57952470164145, 48.05110954469251, 47.9297867128926, 47.7996071692436, 50.514146204917665, 49.62408981015606, 54.0746973406884, 51.19353209772418, 52.75307040060721, 56.506323660573656, 60.09086008994811, 65.10475527855658, 61.46580380778159, 61.09187249214419, 59.14015600758215, 55.354162723787375, 56.90936680762999, 54.329282699092744, 52.973197737047755, 53.51688138900265, 51.621576432258856, 53.444847060788064, 51.33280761780278, 53.485459281552224, 53.37480529662102, 48.17263633974137, 57.165344607445505, 53.6246681213379, 50.048655002347886, 44.15890239900158, 43.120552955135224, 38.560377936209406, 39.5431120934025, 42.21191237049718, 40.6122717549724, 41.536856774360906, 36.228940717635616, 28.22627006038543, 24.90343220772282, 19.641301978018976, 21.99246087381917, 21.257357712714903, 23.600856219568563, 23.90059982576678, 18.899930869379354, 16.820335311274377, 14.219568544818511, 20.15073157125904, 32.35921267540225, 43.73896168124291, 45.9659775610893, 53.07343390680129, 58.1724759071104, 44.90705920803932, 57.66521930694581, 50.44708544208158, 51.44513645479756, 51.63699526940623, 52.31630663717947, 50.99553477379584, 52.128911479826904, 54.43286857297344, 55.643872907084805, 57.392830310329316, 56.93167332679995, 54.37266019082839, 56.22641940270701, 55.61982877792851, 57.98944634775962, 57.08069985912692, 57.013058585505334, 53.78469297962805, 50.84410382855324, 51.37502408796742, 51.16960563967305, 50.22744055717222, 45.76841562025009, 47.92003962301439, 50.555331091726984, 48.13343617223924, 48.46474309121409, 47.65559342599685, 50.1843297866083, 53.361547685438595, 51.47962193335257, 55.80748673408262, 64.46971570291828, 66.68866326732021, 64.53534480064147, 65.87586972021288, 62.452291673229595, 61.51340569219282, 67.069454808389, 60.82775185185095, 68.38583361717963, 66.10500674093923, 65.15433011516448, 53.59439134597779, 56.53769477721184, 67.43032855372276, 73.67838967231013, 75.16514055190548, 71.65087730653825, 69.92754474762948, 26.688916683197025, 0.5774801416743187, 28.599475737540956, 58.11147520619055, 48.494823748065585, 30.851418279832412, 35.41320147052888, 34.63013948932771, 64.33181693477016, 59.38674757557531, 47.30441185735887, 60.77407029367263, 60.594410050299864, 5.440435294182071, 0.14995329953249426, 0.047592775625807625, 0.03630582220672119, 0.19218844692072562, 0.050634926094883875, 0.048401806608683644, 0.09842735189463823, 0.04017057107581247, 0.01742800998110925, 0.2643850325576721, 0.08708658462931072, 0.17514873626491717, 0.1263430749156302, 0.11580926636534354, 0.1677107119992856, 0.16213083399399636, 0.21175647755303692, 0.19301677182797464, 0.19522676695018046, 0.22195758177868782, 0.2668676170850954, 33.04790635262766, 80.85675070362707, 55.54166770750477, 27.74660929556816, 61.65063765741164, 39.23972852768437, 31.613613251716863, 39.050564381384085, 41.00135910895563, 84.22005761054255, 44.35143586127989, 13.922854969578406, 77.92545364749047, 74.21401285356092, 76.1256270254812, 71.44467046183925, 67.05502833089521, 57.21215417308193, 57.104441965779955, 58.0007270843752, 61.12929190358808, 68.51226729731407, 68.78143602801909, 71.08078433621314, 69.74349929440406, 69.37929937916418, 70.37984109693959, 67.74953103834584, 67.96864248091175, 65.75528429400536, 66.68983997837191, 66.23606881787701, 57.36515406639346, 49.8368077893411, 49.56396379778462, 50.09717472137944, 50.042057575718054, 53.776377554862734, 49.51858197489093, 51.25388168519544, 51.01016913690875, 51.044909569524954, 52.93715899990451, 57.68656092305338, 53.999011285843395, 54.893645086596095, 57.44999885559083, 62.470499315569484, 68.96900376965924, 65.09107797376572, 66.16236748233919, 63.226159618746856, 60.99591170587848, 60.57849307214061, 56.60653629610616, 56.399748940621656, 57.892038206900324, 52.78121340659357, 54.9063535659544, 55.06700992584229, 55.26435613632203, 56.300732627991714, 52.978265439310384, 61.72542156711702, 57.09200020759337, 54.60726107320478, 46.15893856171639, 44.59674873659688, 40.348488438513975, 42.510526334085775, 44.137678453999186, 42.011338049365634, 42.7539211703885, 34.770870208740234, 26.709879790582967, 26.436272898027976, 15.642213186910077, 19.494307233441262, 17.979829119097804, 21.37777251581992, 22.66905600024808, 18.649413008843702, 14.570270603702916, 13.028307460969495, 18.936516777161632, 34.72566097013412, 48.4265862741778, 47.96524886162051, 55.46970005958311, 62.45406850691765, 49.703894353681996, 61.51058158566875, 52.88869811642555, 57.34873502485214, 52.57510462114888, 57.779199461783136, 56.0488772392273, 56.52439009758734, 57.52572413413756, 58.321710325056515, 60.72382473176526, 60.4240732808267, 58.70607906772245, 60.70806857078307, 57.78228636710875, 61.112774802792465, 59.97475008810721, 60.278149343306026, 57.55398481122909, 55.54905353053924, 53.26577125057098, 55.86330598400485, 53.49329225478634, 49.412634834166504, 51.60341193599086, 53.41456244068762, 50.842664318699995, 51.618132591247566, 49.75782694355134, 53.90069707747429, 55.39225678290091, 55.64406510322325, 56.31131518271662, 67.77238276696974, 68.50374006455945, 68.49825659105855, 68.96700336087135, 65.87774461315524, 62.70386857371177, 68.61499417212703, 64.31219331679806, 71.60252232705393, 67.90599438451952, 66.7493187996649, 54.0940934611905, 61.27586303218719, 68.60730632658928, 75.65833153263216, 73.86500820036858, 73.85995618758663, 69.30901050567627, 35.200903184952274, 1.0840025231722863, 25.601306192336548, 64.8893936218754, 57.7382577619245, 34.25708286223873, 40.11189499209004, 40.87281911603866, 81.55467371786796, 86.96973323822023, 61.637211384311804, 65.70787068336242, 68.64645942564934, 5.339537224461956, 0.24513918786279618, 0.33936582685958955, 0.21056406169889436, 0.2628394042051608, 0.17264627941673802, 0.14965346804068935, 0.14751360060707217, 0.19720787032236978, 0.10564000075382572], [0.039195754835682536, 0.05517234612676886, 0.017699417695703528, 0.03055889106866333, 0.025865242726379828, 0.05238960452017285, 0.05255912062561801, 0.08023438779937644, 0.03492557308486393, 0.2868080890226749, 0.20323785562669078, 0.1393503975123167, 27.798970976183494, 58.511207872821444, 56.01098322099256, 47.17797817722444, 42.856549985947154, 34.851969134423044, 17.271772661516746, 10.235910357967501, 25.043917778999578, 61.90587020689442, 61.62121203637893, 9.213708331508021, 48.88318154119676, 74.33181731931626, 64.7721775116459, 68.61914403976934, 60.2067582837997, 56.91539549058484, 51.8693329441932, 54.127535589279674, 60.50640383074361, 63.89781059757356, 63.95093910155758, 62.071358926834606, 58.021072418459006, 63.229050405563854, 62.564596976003344, 59.51483257355229, 61.19190862101894, 59.50871367608348, 55.731996797746234, 60.94789405022899, 55.29159307479859, 48.618680430996804, 46.224144043460974, 47.2776024572311, 45.71560482825003, 45.667406743572606, 43.63157110829508, 47.15757400758805, 43.96636109198294, 45.86836153461088, 46.739535639362956, 47.64574435449416, 49.46778728115944, 50.9906945690032, 55.032096908938506, 56.267517997372536, 56.26194823172785, 56.54859112155054, 57.33076272472259, 57.122394654058645, 57.651840102288034, 52.70147162099039, 51.50779239593014, 52.63878430089643, 53.203950774285104, 51.90353993446597, 50.76280486199164, 49.57029058087257, 50.0555819080722, 54.04778595893614, 41.372713427389826, 48.301941194841945, 49.77088451385499, 40.81490532044442, 44.87537037941718, 38.08977980767527, 21.658682861635764, 20.402518318545436, 24.039155590918757, 21.115079618269398, 17.681162203511885, 10.06701505953266, 12.723600095318211, 18.43440044310785, 6.204302176352471, 4.671383038643868, 4.877483489051943, 5.24641917597863, 6.571158516791559, 6.237230473949063, 4.782256676304725, 6.1953483858416165, 8.204724692529249, 20.60331033122155, 42.56842051782916, 44.45431963089974, 50.82752396983486, 49.66837336940151, 40.00028394883679, 53.48107799406975, 49.517252291402514, 49.141791251397905, 47.584684818021714, 47.6616221089517, 49.846213633014315, 50.53766473647087, 51.67751727565643, 52.99504926127773, 52.24668064425069, 51.89347121023363, 53.000281703087595, 52.028361520459576, 52.75889904268327, 54.17579250950968, 50.87250571097098, 52.54735777454992, 47.240296794522195, 45.19987198614305, 46.01758418544647, 45.38788295561268, 46.13952282936343, 43.694474158748505, 46.38585552092522, 45.64250361534857, 44.454715790287146, 45.44312561711958, 46.66797591793922, 46.263399124145515, 48.41279914302211, 47.82090956164945, 54.77591514587403, 60.28924965089368, 59.533491288461995, 63.47093120698006, 61.06324703462663, 64.02893935480427, 59.75043366032263, 63.39680625546364, 60.37687540054322, 63.243006198636955, 65.57260382559993, 60.74279331391858, 56.97097939829673, 52.21976926249843, 63.780563108382694, 68.31597620441069, 70.51251919038835, 65.65558941133561, 70.89251841268232, 13.166595524357213, 0.22576398156102628, 42.08274872072282, 58.76307895106655, 42.114649357334265, 21.065732279131492, 30.41320323944092, 24.209090317449263, 46.068539696355025, 66.79802679246473, 46.174882996466856, 43.403159726050596, 59.272222211284024, 11.755530699606865, 0.3578176673862242, 0.2051105882011114, 0.025316670146440307, 0.07363218844177262, 0.0722005999376697, 0.05732716376622839, 0.05241747479885817, 0.0576741939350482, 0.02640863080629178, 0.0409833635503967, 0.06273062321387472, 0.03010891783501833, 0.16223584932665672, 0.07010230043482396, 0.08764317814981745, 0.030726365549790285, 0.06445394182998328, 0.06737374805755193, 0.11203954687281964, 0.1045621533487593, 0.1745744001480841, 36.8120010437504, 66.62039833684122, 60.29799261400777, 43.53091132256293, 49.98717969463718, 35.44907546812488, 19.43363993398605, 17.52411638536761, 30.64110275237791, 65.35708135174167, 69.37497692723429, 11.7515798922508, 48.05984466306625, 81.40745147582024, 67.01163122730871, 72.25265518311532, 63.294475540038086, 61.49921063453921, 54.03395960407873, 59.753669615714784, 63.81703330624489, 66.85639166062879, 67.88604520982312, 63.97828586639897, 63.27538928677959, 69.11888537868377, 63.06044340133668, 60.31673762106127, 62.064161377568404, 63.897889044977006, 59.982332029650294, 61.2729565558895, 57.48668086144232, 51.77833003382529, 48.792857200868674, 49.863919211972146, 48.44553524448026, 48.44168347697104, 45.589108390192834, 50.314136705090924, 44.69371757199688, 48.11791535346739, 48.40449940773749, 51.3733963043459, 51.73062616778959, 54.35834353969943, 57.65366400441816, 58.820451459577015, 58.27996061694238, 59.69157065114668, 57.06419060307165, 59.62921673251737, 58.511509895324714, 56.10588104494157, 57.849127477215184, 57.76004652823172, 57.899612303703066, 54.17497273414366, 56.03009300847208, 55.24135143526139, 52.97921857526226, 59.425061287418494, 47.221324289998705, 52.75175640659948, 50.31055950349378, 43.397778234174176, 47.22320310531124, 37.45062174335603, 24.23294225046712, 25.960475667830437, 29.19926105007049, 25.370443328734368, 23.90305522949465, 17.247173516981064, 15.372943455173125, 26.866207814985707, 9.88701847291762, 9.62661918132536, 10.887448403143114, 11.384148924581467, 11.644289339742354, 10.572721342886648, 6.78174517808422, 6.514885742818156, 9.806502019205402, 23.038913934461533, 44.073410418725786, 45.566927386868386, 50.68915451726606, 50.076378314725815, 42.97582534051711, 55.58337034717683, 50.889591555441584, 51.3125721100838, 49.69471992984895, 53.29404369477303, 51.853910184675655, 55.50258913347798, 53.93307624324676, 54.91233518046718, 55.22901558106946, 55.689086068061094, 55.35620235627698, 56.52086780917261, 52.634642277994466, 56.091642841216064, 54.592814983860144, 54.967436636647875, 48.653989607288, 49.50095092096637, 48.06786983243881, 48.335904998164025, 48.610314015419256, 45.446287047478464, 49.8023497673773, 48.075330180506555, 48.64038290516023, 46.308129833590606, 49.086999662460826, 49.28517741541709, 51.07929306645548, 52.887729290992986, 60.61588110462312, 64.04784517903482, 65.24762368971302, 65.52591585343885, 63.778676448329804, 65.20135541116038, 63.54980222640499, 68.19745786728399, 62.99475939043107, 65.92770776441021, 68.29836476233699, 63.513422243056766, 58.50364946549939, 55.39665375986407, 68.55360907893028, 70.90656834263956, 74.18600713053058, 69.2467232673399, 71.48561216169789, 12.873301275314825, 0.40312873439923413, 48.84110235398816, 58.133036475027765, 45.75259670134514, 28.19520684980577, 28.83929337224653, 16.26759784836923, 53.99936037678873, 74.33230369321763, 49.41585510007797, 52.742734955203154, 70.97501370214647, 23.468833161938576, 0.34653561309941355, 0.15617419394754595, 0.033969422577009085, 0.08883626050045414, 0.0947029235201978, 0.16905784697061585, 0.04720409708698431, 0.04804415080035406, 0.07757813113951877, 0.08719759076953897, 0.12606919848269996, 0.10156934660288597, 0.23754072946406182, 0.13858237904646706, 0.16886709107747003, 0.2697099871452778, 0.20293264619765744, 0.1800225263521556, 0.3696102120222584, 0.34901271243729903, 0.2697442772407686, 41.82406056311823, 77.8652060416437, 72.32110054262223, 57.792641424363666, 56.469688723164225, 46.4421062315664, 24.30096007162525, 14.552247312761123, 38.957643432001916, 74.92759396952968, 72.58837084616385, 13.648683255718602, 57.465088213643725, 82.73202019353067, 71.15439153486683, 74.53752994537354, 67.89392917386948, 62.64548801606702, 57.266859469875214, 61.579395647971864, 67.5422965326617, 68.46351223607218, 71.25643591726981, 67.45029341789984, 67.76043522742488, 69.48874135171214, 67.07358114181027, 64.1916157353309, 64.86626340496925, 66.12416359686083, 63.76607779533633, 63.4154845822242, 61.526890800845244, 54.18005220351681, 50.79027322030837, 53.57166121082922, 51.60038386621783, 50.86012671070715, 49.07472656619165, 53.15030843980851, 47.964334949370354, 50.52588978121358, 54.1011929512024, 53.329137140704745, 55.40237649794548, 56.21060440617224, 61.99963054349346, 61.812086336074344, 61.44182635891823, 63.02049013876147, 61.71064992104808, 62.9496717453003, 61.73389780905939, 58.75617950193344, 60.12523574213828, 61.648088116799634, 60.145867409244666, 59.44416715252785, 61.334792721656065, 59.73016677364227, 57.97885594829437, 61.07464936471755, 53.288207207956624, 55.98872377026466, 53.314840101426654, 45.33384446174868, 49.59466418912334, 40.80079263256442, 25.14633086419875, 23.489192224317982, 28.638568039863344, 26.169971419918923, 22.38477045489896, 14.939721592010992, 21.571000237618726, 39.44331522910826, 20.05596906908097, 9.29450229290993, 10.400748945051625, 12.202895649017828, 11.797633421036506, 8.805569045005306, 6.8850045146480685, 7.916356940423289, 10.644629174663175, 26.198353690485803, 48.07267865827007, 48.20564700711159, 54.375241110401774, 52.68507219129994, 49.16139133514897, 57.27640259650446, 56.01595286400088, 53.283767084921564, 52.669088532847745, 56.08153881565217, 54.95353967912736, 57.73242519747827, 58.45144271850587, 58.262290339316095, 58.69748907704508, 58.585317134857185, 57.49535714426349, 58.791112130688084, 55.47606606637278, 60.582874359623084, 56.485413505185036, 58.59823349983462, 52.95388790868944, 51.96306974657121, 50.81120298754785, 51.569287315491714, 52.39098856526037, 48.483680294406035, 52.34874071613435, 52.01785349076795, 51.376816611136164, 49.510905896463704, 52.16236929739676, 52.202063683540594, 53.26910918758762, 55.142919555787124, 62.092614250798384, 67.43778105705016, 68.08322275838545, 69.53413101934618, 66.85403823852539, 70.56693030941871, 65.89128463499009, 67.96387287878221, 64.4592272850775, 69.46778805025163, 71.6163133805798, 67.50729330124395, 61.2993384176685, 59.485567769696644, 70.20552312174152, 73.75778628933814, 74.189545108426, 70.74381351470947, 70.49129132301577, 21.028538403972505, 0.39887740607223204, 47.13521257523568, 68.04450112004434, 53.98775800581902, 30.25415309013859, 36.22763064599807, 33.9031046436679, 61.39322034774288, 84.34130591730919, 58.85841608047486, 53.657604263674834, 81.23700095761208, 24.714083710024436, 0.731383957449467, 0.2837673328336208, 0.18020177560467876, 0.36077222336203824, 0.1645160640680021, 0.22976957952543614, 0.271601734021979, 0.23874357943573307, 0.26432794368555473], [0.16169811689084576, 0.1438957657064161, 0.05324819756131019, 0.06251966941260523, 0.030176626600986047, 0.0493905158533204, 0.1837014337821353, 0.09628628936385918, 0.13023922189829812, 0.10787635696150603, 0.1729572038616865, 0.15631152286885247, 29.6186859761515, 59.620901307752064, 51.38696770514212, 36.216177325094904, 47.08336276392783, 31.082702798228112, 33.00653711442025, 29.673420690721084, 20.06522390150255, 46.26490531429168, 65.80842848747008, 11.500770795729853, 19.18055488217262, 82.14158581149194, 60.67989026346515, 75.8352461168843, 57.19796303779849, 60.75472908635294, 48.25060913639684, 63.93040157133534, 62.38057897936914, 67.00348054209064, 60.05199332391063, 59.65301375235281, 63.34196759808449, 64.47897641889512, 59.71807802877119, 60.93016885942029, 55.040298584968816, 61.37708763922415, 55.257162509425996, 60.63743845109017, 54.297880203493186, 49.26643240836359, 44.13221459234915, 46.577125980008034, 45.67340404756608, 47.356924549225845, 46.36884812385806, 48.25379802334694, 46.95537190283499, 45.886157328082675, 45.86598065591628, 46.51474068241735, 47.83950944100657, 50.444441764585434, 53.141102637014086, 56.89378323093538, 57.22839670796549, 57.11368306990593, 54.377021866460005, 55.17365917082756, 54.04268687771213, 54.96783671840545, 51.08136800027663, 52.95242878698534, 52.591198105965894, 53.69099147858159, 51.37102327039165, 52.849690145061864, 50.80600192469936, 53.20164049825361, 41.78740993622811, 45.90664778986285, 46.06937123883156, 40.06058646786598, 46.01189282632644, 24.536941628302298, 8.926374123942468, 7.766704790053829, 8.125869362585007, 10.854263190300236, 8.778921442647135, 12.406998142119377, 19.44116303997655, 12.358239158507317, 6.553272508805798, 1.7470309066195644, 3.641675066563391, 3.546622063844435, 5.008081255420562, 5.0980383638412725, 5.31307936676087, 7.864684126069469, 11.181266288603506, 23.9254343125128, 40.948799348646595, 40.1269765054026, 47.56700277328492, 44.463458753401234, 39.22234066071049, 54.935932159423835, 50.61273105682866, 49.65123261174848, 49.90293502807618, 51.78790846178609, 51.73153615766957, 49.781604351535925, 51.91644060996271, 52.42457974341608, 52.447839398537916, 52.31358451227988, 51.4046379827684, 50.73319488956083, 50.97752324996456, 53.551206050380586, 51.731861714393865, 50.651746872932684, 45.68109189310382, 44.51642644020819, 44.80013147477181, 45.09541926845428, 46.04080461686658, 45.76318317844022, 45.77234191279258, 47.087414572315836, 45.851962104920425, 43.6704457190729, 45.342842378923976, 44.96466705876012, 46.87903473454137, 51.85676174779093, 60.40652851904593, 59.718474188158595, 61.16168675884124, 59.939048674798784, 63.11568606284357, 61.01635509921659, 58.65455089076873, 58.4437862519295, 67.0503685551305, 59.7505081853559, 67.4358904746271, 61.539854234264745, 59.781357626761164, 48.234645089795514, 65.2040736136898, 65.05378800053751, 74.3526372601909, 62.91037744091403, 64.94462843864196, 2.1305868606413565, 3.36515556900732, 52.81218444147418, 52.18122413081508, 29.995580642454087, 15.1941490750159, 37.64013498060165, 42.7553802920926, 25.190518325374974, 58.67678680727559, 34.04095242100377, 29.71826711008626, 66.49336061170025, 32.963732288729766, 0.10321245198288273, 0.04297364465591889, 0.08297299891109429, 0.02400797746715046, 0.05990788415675202, 0.03509336549247946, 0.07705930575367904, 0.09554416466985019, 0.07598010237298666, 0.06339600888050853, 0.04969110194173071, 0.08745382419757305, 0.020242749165082653, 0.0364456907094967, 0.06092494248502678, 0.1919916236112195, 0.06723521637820429, 0.09597962436776969, 0.11481474634380111, 0.2223207687418307, 0.2247797424394277, 35.52116863189205, 65.03780434208532, 60.650586235907774, 42.8724826535871, 53.66484495901293, 37.92305161876064, 26.311455234404534, 29.660867144984586, 27.792210771191506, 50.31570565315985, 72.11851796796246, 15.559425680868088, 18.51728993077432, 86.71769742042788, 65.49943985477572, 79.85109421514696, 60.09611998834918, 63.043655656999164, 53.41982233908869, 67.95669494136688, 64.17948384438792, 69.71815293835056, 62.041658739889826, 66.07374545066588, 67.2317938650808, 64.6162123064841, 61.89494640596452, 62.39684112610356, 60.1458634868745, 63.481600053848766, 60.2542228852549, 62.883062055034024, 58.033518099015765, 51.00516419256888, 46.69249465388637, 48.95053648179578, 48.235339349316014, 50.37689462784798, 49.124603425302816, 51.123811967911266, 49.1594458395435, 48.673605380519746, 48.5042295917388, 48.78012126491916, 47.729906651281546, 52.81400442123414, 57.050619202275435, 61.59477133904735, 59.25971377280451, 60.39699323715703, 58.32893925328409, 60.53010671369491, 57.101319759122795, 57.42677842417071, 55.25691147773497, 56.226388023745635, 55.973065668536776, 57.00206810428251, 54.05136316053329, 54.938626827732215, 55.682147395226266, 54.986530734646706, 46.39360220201554, 49.353391355083836, 48.57051764765094, 39.54860341164374, 47.260638206235825, 24.10324319716423, 8.817059628425106, 9.772383282261512, 11.975775707152582, 15.812428362907903, 11.443633629429726, 12.904848898610762, 31.7697863424978, 29.375922641446515, 17.035902892389608, 7.066895115760065, 5.055482118360458, 4.707156525504205, 5.064969351214748, 6.418569491755578, 6.438141138322893, 7.801124568908446, 7.670802349044432, 24.807251768727458, 42.102635137496456, 41.32239726281936, 47.475129096738755, 46.9343872224131, 44.59415604991298, 59.34611966533046, 52.75141123802432, 53.843175518897276, 52.60999802620181, 57.17410718241046, 54.62254262739613, 54.555356348714525, 52.98958539962769, 56.63876641181208, 53.93360184084985, 55.25520916908018, 55.01794891972696, 53.954406092243815, 54.26890565503029, 55.03838446832473, 54.65718500075802, 51.64243167446506, 47.328452064145, 48.04852470274895, 47.527986957180886, 46.80059125346523, 49.96624208265736, 47.67446787126603, 49.44092296784925, 47.745294109467544, 48.769326902204945, 46.59241145656955, 48.2079965068448, 46.876759759841434, 50.372662390432055, 54.05708197624453, 61.28524534163937, 63.751361062449796, 63.74764657789662, 62.351121979375044, 64.44018025552073, 65.89831352233887, 64.12906962056314, 60.837032179678644, 68.53115743206394, 61.49341337142452, 70.45717454725697, 62.69723192338021, 65.26512138305172, 51.501430311510646, 68.29702331173804, 66.90286390243038, 79.32701849168348, 66.32383577285275, 67.95682830195274, 2.414995470354634, 5.221888182624694, 60.27215203931255, 57.01156416246968, 36.543028431554, 21.177992474648264, 28.14277848889751, 25.50475705054499, 27.24644041830494, 63.82228928227579, 38.40273395661385, 40.949721105637096, 75.52218606395107, 50.41623207830614, 1.1710211634635925, 0.19884647110537176, 0.12706557243701913, 0.04586833469089001, 0.042548477349262086, 0.06080609160445391, 0.03259695307802289, 0.0340116799869124, 0.019176666955313375, 0.2804923988878727, 0.15981692670574113, 0.2738404574413454, 0.2120273662430625, 0.26040367361518646, 0.15913471008741087, 0.385022368882933, 0.14600469850965087, 0.2723629189835441, 0.18327732750725362, 0.3018009506406323, 0.26827501253254954, 46.21285153973488, 78.2827501912271, 67.48015834439185, 46.19669137462493, 64.06496632483699, 44.46634169547789, 45.35614705854847, 37.66895655662783, 32.20620885972054, 58.99019202878399, 76.4197498752225, 16.433741604128194, 25.70053823532597, 90.0764229989821, 66.00059324695219, 82.64285687477359, 62.19044208526612, 66.39840002982848, 53.473331312979425, 71.26471996307373, 65.80666342089253, 73.46955483959567, 65.49902800590762, 70.66518568223523, 66.29300594329834, 66.31365329988542, 64.91861920202932, 65.78488249932566, 62.36751748669533, 65.457290064904, 60.871011672481416, 66.55298063831945, 62.440583398265225, 54.38787114235663, 49.266891325673754, 51.21630537894465, 49.71268438523816, 52.26938724517823, 52.34996841799829, 52.608758557227354, 52.77543575532975, 50.34316616673624, 52.434970102002545, 50.822409199130156, 52.60163553299443, 54.646347491971916, 59.85017561143445, 62.92679648245535, 64.09599619527017, 63.705665449942316, 61.56165084531231, 63.58941816514539, 61.3782565055355, 59.64165849070395, 59.211319569618475, 59.280380741242446, 60.279129935849106, 60.73371694933984, 59.45209034027592, 58.525559825281945, 59.22884864191855, 58.48484562289331, 50.012377000624134, 51.75408586379021, 52.388913631439216, 41.4692468797007, 49.80664868508616, 29.368272058425415, 11.287919455958951, 11.44150084064853, 11.36094516323459, 16.04295978623052, 11.953956542476533, 19.889429153934604, 45.84817701770414, 43.36539122366136, 31.972339499381285, 16.67471927981223, 6.8003234844053955, 5.864551865285443, 7.625735296357063, 7.5117360199651415, 7.892870768424004, 12.31029308611347, 15.611761866077302, 27.566543086882564, 47.263379942986276, 41.37825965881348, 51.870941115963845, 50.34089903677664, 48.85836470511652, 59.58807891415012, 55.603080257292724, 57.45068919274115, 54.64323705242526, 59.81037532129596, 57.72752223476287, 56.708247277044485, 56.891629849710775, 60.29147363478138, 57.476996529486875, 58.478259963373986, 56.81899932123, 57.38364019701558, 57.37215549715104, 62.480658254315784, 56.668721552818056, 57.01421568470617, 50.19371601843065, 51.51331509313276, 51.89766814631801, 50.69965470221735, 53.812228018237704, 49.8843429934594, 50.38682999149446, 50.4607549021321, 52.86039429326212, 47.45499164827409, 52.32886214410105, 49.525610862239716, 51.00066523398123, 56.63930769889586, 64.36744774541548, 65.7761513033221, 66.55426717573597, 63.23678924191383, 69.82030714711836, 68.71788578648722, 67.57775475901943, 63.460587916835664, 68.85683967221168, 65.42273790605607, 72.42465111517137, 66.09845638275146, 67.24997012845932, 53.210097128345126, 72.22824235116282, 68.74838613694715, 81.8910954075475, 65.41682297183623, 75.7149705579204, 7.253767126990903, 3.398621721613792, 63.949589806218306, 62.744637689282825, 44.12748813629151, 22.21166841445431, 45.328584563347604, 57.965951350427446, 33.68858629657377, 66.80223941802979, 48.635295591046734, 40.215990774093136, 84.47381927121071, 56.3625648713881, 1.083167058325583, 0.2874424404674961, 0.16051127815679198, 0.1395910563728502, 0.15431577189555093, 0.07866505668648789, 0.14925953030826586, 0.13497341544397418, 0.17525441043319243], [0.08636781795611305, 0.03968801995318744, 0.0055944734166616635, 0.01302278895426782, 0.06986914923594845, 0.07486469367699278, 0.01774154487065971, 0.052624287894896926, 0.03751596150499198, 0.09583928472092075, 0.05882854288023326, 0.2197049002373411, 31.05762512453141, 60.76883392949259, 38.529167636748284, 27.446149856813495, 39.92583344059606, 32.336007933462824, 16.887046983165128, 29.47928886259756, 15.826620478783886, 34.15487766265869, 66.02683390340498, 28.700394399704475, 3.3324368730668104, 68.68474960327148, 65.5817311809909, 72.53203776574904, 63.383187786225356, 58.14498401457264, 54.31267146141299, 65.40215330739176, 63.07266158442344, 67.7960503485895, 55.03383451892484, 65.36024670447073, 65.30074827132687, 62.610429871466856, 60.77732193854548, 63.05442256312217, 56.806502649861, 60.243067664484826, 57.5601900008417, 58.20320375504033, 52.3528003692627, 47.011238221199285, 46.63052512753395, 45.83409178641535, 45.880218859641786, 48.29745792573499, 46.54366816243818, 47.89136709705476, 48.63163994204614, 49.84364055818128, 46.201539424157914, 47.89068852701495, 45.25656200224354, 49.73754828976047, 50.876773249718454, 56.94484856820876, 55.33565305894422, 55.67178841560118, 56.00008295428369, 53.22344495404152, 54.38849479921403, 53.93939910396453, 55.27200475815804, 53.44838111631332, 48.905888142124304, 53.74813648962206, 51.03233052838234, 52.069456192754934, 48.5438572975897, 53.73645174887873, 41.79441136698569, 44.58556605923561, 44.74210785281274, 39.70707501134565, 42.22513075797789, 22.054922657628214, 6.503636385163953, 8.505759739106702, 11.9445389316928, 6.355150649624487, 10.365586857641897, 22.563246142479684, 31.058333112347512, 24.738759340778476, 21.23490410466348, 16.384349157733304, 11.534500237434141, 12.223263536730121, 11.407117343718006, 10.932045752002347, 5.987351469455227, 5.783691223590605, 9.763087264953121, 18.55451714607977, 34.95991276156518, 40.60854158093853, 42.835816337216286, 41.33298766228461, 38.49997735792591, 52.39523649215699, 50.05600944642098, 51.79017951411586, 47.82389056298041, 51.74046347218176, 49.14810626737533, 49.69981901107296, 52.51700647415654, 51.49165184267106, 51.35523180807791, 52.073198133899325, 54.228799420018355, 50.38947759136077, 50.31094781814083, 50.608118349506015, 52.47502142383207, 48.91991061549033, 48.04411595867526, 46.5197770057186, 47.881216003048806, 45.15381159320955, 45.70642648204681, 45.72426934396067, 46.7197355147331, 44.9143861955212, 47.2378453131645, 43.661173235985544, 47.23953977707894, 46.15307854067895, 47.544547204048406, 52.728955668787805, 59.54512503839309, 60.05514690952917, 61.41798619301089, 59.65374331320486, 63.14511952861663, 59.58199924038303, 65.70994561718356, 53.23463547614313, 65.51068529005974, 62.40922012636739, 66.2188260785995, 62.433378004258685, 62.1763607763475, 51.97417005415886, 64.97860400907456, 68.78705286210584, 69.56797322919293, 65.64653265860774, 50.266389692983324, 0.2542969875878865, 17.106546740378104, 56.4581451877471, 53.56225144478583, 19.9976904930607, 37.813201719714755, 141.12232885053083, 88.49023219077819, 27.715912826599617, 33.9017161246269, 45.16451966377997, 32.63986218360163, 55.42084693908692, 63.55331667007939, 6.912778817838238, 0.48453130669170813, 0.06825117153986808, 0.01996968287013231, 0.08802412303104516, 0.08662373728809819, 0.060254676838315306, 0.013903264339352328, 0.04267236142749748, 0.07311991310768551, 0.04888318561678452, 0.11902210122394948, 0.007832854011681894, 0.04699593950663844, 0.062323474295197, 0.08650805801153184, 0.06842500455076657, 0.032766748805560415, 0.0387710471817803, 0.03525299140282216, 0.38289224608771266, 41.41076434043146, 70.03369977397304, 45.07781567112092, 30.674913583263276, 45.27054132953767, 40.894152887405895, 17.040986284132927, 24.34547112834069, 18.96095314333516, 36.11283463816489, 72.30745853916292, 37.98430335137152, 3.872063078226582, 67.1748802738805, 70.26957542665544, 72.1953179759364, 69.91696219290458, 60.412792544211115, 57.61175740149714, 68.50412445683634, 66.29710089775824, 68.75916481018066, 58.675798369992165, 69.2766744859757, 64.5814718738679, 65.69136927204748, 64.04977106278943, 64.85427664172265, 60.99448396313576, 64.44775435232347, 61.36637564628356, 62.72218604241649, 53.41953600606611, 49.26454182594053, 49.874525300918094, 49.56865495251071, 47.515772696464296, 49.88329572062339, 49.96618716947494, 50.78437397556921, 51.09114254674604, 52.731611113394464, 46.89131175318072, 50.19556345478181, 47.1157419297003, 51.83723226670296, 54.607272840315304, 59.91287077626875, 57.39686642923663, 60.140556520031346, 58.14787872375981, 55.60287629404376, 57.049050254206506, 55.912076734727435, 58.010968392895116, 55.55296413360104, 52.97688084263956, 56.10814817490117, 53.60566031548285, 54.616968939381266, 54.500141143798835, 57.5268380872665, 47.26414088279971, 46.6580758556243, 47.63171795875796, 37.23206727735458, 42.497190275499904, 21.52817972244755, 6.153654081206168, 6.88637440243075, 11.182466533876235, 8.351855739470452, 8.236242898048895, 24.234026785819765, 38.24987526862852, 32.40607715422107, 26.275549857847153, 19.403720094311623, 5.9100758740978865, 8.829274869734242, 8.424499996246832, 7.38552003137527, 5.267974070964321, 6.975222460685238, 12.0414577568731, 20.361237333666896, 39.476216070113644, 41.12477648642756, 44.80425388582292, 43.692034444501324, 44.56926076642929, 54.947538452763716, 52.35486745834351, 54.27740935356387, 52.04938934695337, 54.9090600013733, 52.896131007902085, 55.42100775626398, 54.27494218272548, 53.464451066909305, 54.17862053840391, 54.26223370336718, 55.85671640211537, 53.456053272370376, 53.107888006394916, 54.096137016050285, 53.60729986621488, 50.07175384029266, 52.63142985682334, 49.8530738584457, 49.33527000488774, 48.1551347240325, 48.78012126491916, 47.94576252660444, 48.92212283226752, 47.42369897903935, 48.615338571609996, 47.59942116275911, 50.82655122203212, 48.45493324341313, 50.08249328982446, 57.094600739017615, 63.91965427706319, 65.16455573420372, 64.01750172338178, 62.878406201639486, 66.4638251643027, 64.31976349123063, 67.2861030024867, 59.141968142601755, 67.14918874925183, 63.545891623343195, 67.78029810997748, 64.16946611096783, 65.45480328221475, 55.44053723735195, 65.27740624643141, 71.16284816495835, 72.080243479821, 68.49982553912749, 53.84836873700542, 0.43219524405656323, 23.435847989974484, 64.61649471713652, 55.78585094021213, 24.090464115142826, 47.59176469618275, 144.28259818784653, 102.07506318246166, 38.701418522865545, 42.90676024652297, 49.766577751405784, 34.775926143892356, 68.99581709215718, 71.03581043981737, 16.525728048816806, 0.2582402719605354, 0.22460433894828444, 0.1180030357453131, 0.20140943357781058, 0.09982536276501995, 0.08387549645117215, 0.0598225113184702, 0.036667817903141824, 0.1815846715603144, 0.09913150161024063, 0.35679349976201213, 0.11588219027485579, 0.20068233952887599, 0.13938850272567044, 0.20062839161724816, 0.22791279690159907, 0.14831459149718285, 0.21846426680924433, 0.12739404029543364, 0.7296095139557316, 48.84365973934051, 78.91034510827835, 51.12958177443474, 33.37727169836722, 54.52272222888086, 45.35959482192994, 26.556605331359375, 38.26336037728095, 26.719085593377393, 47.36447903417772, 79.09305695564517, 37.54440561417611, 5.732216488930487, 80.3482703239687, 72.1463667961859, 77.91568694576141, 69.44695241989629, 62.90577650070191, 58.462146866706114, 71.81779769159132, 70.8141416118991, 71.97792453150596, 61.2179688484438, 69.72587216284968, 66.08185691218223, 68.07595068408598, 66.88422479937154, 68.52347743126654, 62.653787751351636, 68.50097871595814, 63.21804031249016, 64.23159253212714, 56.14995279619771, 52.80039771910637, 52.03687698610368, 52.392965439827215, 49.74915066073018, 53.636764710949315, 51.83459643394717, 54.52533844978579, 55.37000517691336, 56.07152500460225, 48.76745593163275, 54.242260994449744, 48.76119975120791, 54.291729927062995, 56.50927720531341, 61.16323609505931, 60.26598999577185, 62.29844454796084, 62.82883920977193, 58.87332108712966, 61.92055948318974, 59.675512467661214, 63.52758984411917, 59.938476008753625, 55.782022706923954, 63.21673416322278, 58.64857712099629, 56.97776509869484, 58.964880974062034, 61.11299837789228, 53.18271898454236, 50.33405842319612, 49.28708760969101, 39.332017975468794, 44.85522116384199, 25.172222429706206, 9.641218243106719, 12.814306866738105, 18.354976369488625, 10.208147821887847, 16.30712063081803, 37.57465885531518, 48.37525029336253, 41.77106934209024, 38.79839912537606, 30.642565796452185, 23.152021361935525, 21.393110944378762, 18.023212494388705, 13.698171800182713, 10.158520033282619, 10.58883640073961, 16.29581047642616, 25.064117985387004, 44.17026942776096, 42.07999129449168, 45.305693611021965, 47.440949563057195, 47.69202832252749, 57.29093497799289, 54.71451044082642, 57.116868034485854, 53.856986184274, 59.2768309962365, 55.007068264868956, 58.504967381877286, 58.041060816857126, 56.75279363509148, 57.13433827123335, 58.4663712593817, 60.17510475650911, 57.47742014546549, 55.0443386262463, 58.17162867515319, 57.224442958831794, 53.550743210700254, 54.74796041365593, 52.280593456760535, 51.500787042802386, 51.330124716604914, 51.03879067205614, 50.27267332999937, 51.611503785656346, 50.97629554810063, 52.09946624694332, 50.40370402797576, 55.15057209999331, 51.409670383699485, 53.69175241839502, 59.894153225806456, 66.36537367297758, 66.78058008993825, 67.94824615601571, 65.121017425291, 68.49522852128553, 67.7282404130505, 71.44820059499433, 61.37048236785397, 68.7388155537267, 66.68146179568383, 71.62785299362676, 68.25182976261263, 69.58353719403668, 58.518821193325905, 71.83360484338576, 73.22430472220145, 77.63803805074384, 70.46003003274241, 64.30158330548194, 0.9063936181126103, 19.353235267823745, 68.66676161366125, 63.94628717053322, 33.490985132032826, 45.17450994060886, 137.57487450876545, 99.596172302, 42.373529711077296, 41.75831379428987, 63.03708176459036, 45.19651835964572, 71.62825307538434, 85.25005632831206, 15.590321210122879, 0.8278241308946764, 0.3656333883202845, 0.23221030500867676, 0.28304742468941596, 0.2117635255619403, 0.24394770663592125, 0.11858716246581848, 0.14323421814028295], [0.03890976655266939, 0.009933708896560055, 0.08516225603318985, 0.015253637947382466, 0.01095488494742782, 0.043398976671479406, 0.09142170765347059, 0.09715455809548017, 0.0896004485266824, 0.061613839390056754, 0.022730523938192956, 0.17433208653763418, 44.46856567936559, 55.39663414801321, 49.5899377330657, 37.23184762462493, 36.090771305945616, 40.84633527263519, 17.438116458154497, 34.08335324256651, 10.46532488638355, 34.6236518890627, 51.65679539403608, 60.977908026787546, 3.9244737884690686, 26.45389218484202, 80.71935792123118, 60.14985253733974, 68.55094971195345, 58.71208029408609, 62.65189324655841, 63.10306387562906, 67.25812865841773, 58.99522835208524, 61.9602656364441, 67.69634369880923, 62.10242802096952, 62.88761984917426, 58.6109027554912, 58.30624834183724, 57.79782287536129, 59.26404799184492, 56.32698505155502, 57.79796015831732, 49.818780576029134, 47.533835211107814, 46.81502557569935, 48.01506296280892, 46.30887508392335, 49.50990961443994, 48.0540003315095, 47.91240276828889, 49.16536469613352, 47.6555149785934, 49.14352493901407, 49.784224494811035, 47.20799607615317, 47.9209456905242, 52.15949420006045, 54.626472842308786, 53.69873815967191, 54.12037334134502, 54.7875802747665, 52.53787348347326, 51.181309992267245, 51.713269679777085, 51.4338674852925, 51.24624875284011, 50.020253119930146, 52.896468331736905, 50.52518767695273, 51.63887408471877, 49.985489153092914, 53.38188125241188, 41.593621315494666, 42.90778398513795, 39.39858844203334, 38.56906990851126, 37.84159183502197, 19.85703233749636, 5.549084947955224, 8.639158568074627, 10.422973094447967, 17.457836174195815, 36.40908733490975, 42.496868641145774, 36.428475610671505, 31.155558862993797, 23.440448930186612, 23.386402591582268, 23.28016911783526, 27.145156975715395, 25.23333884054615, 24.494840868057747, 17.765348034520304, 10.276394121108517, 8.84048794546435, 17.03802489465283, 31.583238417102447, 34.8836697301557, 41.325845026200824, 37.56176602455878, 40.224937700456195, 52.00305046573762, 48.505735781884965, 52.536998794924834, 49.12675680652742, 51.96546631474649, 50.582038510230284, 49.41836933935843, 48.89863960204586, 49.45438061991046, 51.566984884200565, 51.56012073639901, 51.20318897308842, 52.1478408382785, 48.09097259275375, 47.378587799687544, 47.358030657614435, 49.92719880996212, 48.74267831925423, 48.44897908549155, 50.28829613039571, 47.92586434272028, 46.73628007211993, 45.94662066428892, 44.919908892723825, 45.53268901763424, 45.48136088155931, 45.29848429464525, 45.1197144293016, 45.690670321064616, 47.13296505712694, 58.53760150171096, 61.2318971849257, 59.85771832927581, 59.24391446575042, 61.08052115286551, 61.88980810103878, 61.600058694039625, 61.85831931329543, 61.68286385074739, 56.78762820459182, 62.97811285141976, 60.724158133229906, 64.12293895598381, 61.2060958339322, 57.79956833008797, 54.4150217886894, 71.40468582030266, 65.09109366324641, 77.6308758028092, 34.92134017329062, 0.28122055013814284, 39.46206023616176, 53.1137833287639, 42.52501556950231, 12.32341439493241, 43.465058649739916, 72.9189403595463, 19.737631467080888, 21.7863775837806, 28.885238055259954, 40.03773866161224, 48.5283011774863, 35.69766744490593, 63.95523801926644, 34.235647109247026, 0.34455417264853755, 0.06498731522550506, 0.0029049508251069536, 0.015890952237250826, 0.10590591753322272, 0.014792978744803658, 0.07019238471384011, 0.007982331172247689, 0.054174014817803144, 0.0435377151945666, 0.05326528898290089, 0.06073094603996124, 0.0811706008690019, 0.017214863253156507, 0.07468312317805906, 0.031046726282746084, 0.049225190248821056, 0.05991030116415313, 0.0009117247100220994, 0.43947513245286485, 53.17284637881864, 62.035437860796534, 52.81776205185921, 34.60716224485828, 39.79637953542894, 46.57688279305735, 20.04179362327822, 26.360373074008574, 11.385354072816911, 42.902402493261526, 56.91821959710891, 69.30697087318667, 7.185090347643822, 20.958514290471232, 84.64996507090908, 64.1401699281508, 72.49471249118929, 63.31973168157763, 67.66777315447408, 66.02087190074306, 71.37888446930917, 62.87743345383675, 65.91641133831394, 68.90717937100318, 65.22609772220736, 63.70264522490963, 62.21849095436835, 61.7788246370131, 61.37537356345885, 62.277722666340495, 59.53188311669135, 61.879853125541445, 53.85014164832331, 50.629510956425825, 49.588043228272475, 49.71955245540988, 48.44181291518673, 50.93644818952007, 49.75918408363096, 49.81832558108915, 52.47364467190158, 51.505231088207616, 50.533385430612874, 51.78686511132025, 49.08705065327306, 53.18824952648532, 55.94977071208339, 56.83195098753899, 56.52864979159448, 57.18911417068974, 57.28158796987226, 56.487876753653254, 56.25178144824121, 54.37937136619322, 54.670956442433024, 53.99845430927893, 54.4536022217043, 56.16520689379785, 50.45195310346542, 55.70113951160062, 54.67593000781152, 54.25782888166366, 45.86498045152234, 45.81830032410161, 43.817789554595954, 40.39545882132746, 39.98658310982489, 22.73331815196622, 6.177104461577631, 8.024950210125215, 7.251478423995357, 10.461474099466878, 28.683945940386867, 43.50916177995744, 42.992005117477916, 38.63610321475614, 31.89541005319165, 32.70658954497307, 32.051226208286906, 30.901197079689275, 29.071540832519535, 21.304186890202185, 14.900867573676573, 10.604664144977447, 10.948291228663537, 18.91600278116042, 34.52735770133234, 37.148089331965295, 41.56055573494204, 40.2876877784729, 42.077429986769154, 55.02083970654396, 54.592885586523245, 54.672595993165054, 50.907932558367335, 53.6108103875191, 55.06837098829208, 55.72211634728217, 52.226198027210856, 54.07681934295162, 54.867243612966234, 55.402227447878936, 53.52665201310189, 54.25027047434161, 51.983489605688284, 52.26515108539213, 50.62045028132778, 55.87018974365727, 51.89412624605241, 50.646773307554184, 52.6492884082179, 52.11039397024339, 49.150471456589244, 49.16472927216561, 49.08182213383336, 48.47411755592593, 48.0952165972802, 48.456961108792214, 49.31217508931314, 47.57143112920946, 48.198810315901234, 62.16253442149009, 63.59350135249477, 64.03744305333784, 63.73123930346582, 63.28202985948133, 62.62687636959938, 63.14124030451622, 64.62975232831894, 65.508892766891, 63.40603167010892, 67.4052567635813, 64.13905597502186, 69.82018163127285, 62.81813506157168, 61.34816015920332, 55.917603354300226, 74.90679756287606, 67.60938475208899, 83.3225408677132, 33.53274660725748, 0.36918717827047076, 48.38039644302861, 55.34750253923478, 43.50308602856052, 13.005578306413467, 45.672737244636785, 89.50164671867125, 33.593049126286665, 35.776444327446725, 31.851416749338952, 48.576118792257006, 44.32322617500059, 48.36823709549443, 71.21079521794474, 50.515503344997285, 1.3717377930879595, 0.059863064182741996, 0.07578714780749814, 0.10753661994972538, 0.10865456439674863, 0.07118303599136491, 0.05663128780020822, 0.0540946864132439, 0.21416795379932851, 0.23416096404675515, 0.274611693476477, 0.17137507908046248, 0.23169341016440625, 0.1430036563185915, 0.17039644772246962, 0.21592886818032112, 0.18215955926045296, 0.10402551641868008, 0.12839720178876193, 0.4896374972116563, 63.60394270189347, 70.47978308893019, 65.33546124735187, 50.25408521775277, 51.860350716498594, 57.85435207428471, 25.010008888859904, 44.87067530232091, 16.749954262087424, 48.681238312875074, 62.75847188888058, 75.72774179520147, 5.9953109391274, 32.32603334611462, 85.43538831895398, 65.48152246782857, 71.04341199321132, 67.39942812150525, 67.5930755369125, 69.30149524442612, 72.08379714719712, 65.4985769333378, 67.5051752213509, 71.03594380040323, 68.57126758944604, 67.15984190663984, 65.18251234485258, 65.72299534274687, 64.27338538631317, 65.89445391008931, 63.08058084980134, 64.55456049211564, 56.7538958211099, 55.24433243659235, 52.40793320440477, 52.9751040089515, 50.67184902006581, 56.11195287396831, 51.67243780628328, 52.75184269874327, 55.69578547631541, 52.099478014053844, 54.22352383213659, 53.262213660824685, 51.608295286855395, 55.51789422189036, 58.25695199351157, 60.56379987347511, 59.34875942045643, 59.70044697484663, 62.448588955786924, 58.94730483331988, 59.71204542344617, 56.75868895746047, 60.94634471401092, 57.13131020146032, 59.56138718512751, 60.9215945582236, 55.956132796502885, 59.56728642986667, 59.88548478772564, 58.54838409731465, 51.94288915203464, 51.457629203796394, 45.4805411061933, 41.41729900913854, 43.469745882095836, 26.813049893225394, 9.354269408410596, 12.672438659975606, 13.547656728375344, 23.035748581732474, 41.0986299668589, 45.46125481205602, 45.81735895526025, 45.74801537298387, 37.01496016594672, 39.64068497380903, 40.92094267568281, 41.41420818144276, 39.306400975873395, 31.85159129481162, 21.179735968189856, 12.457569260751049, 12.437599493611245, 20.614534193469634, 39.68684734836702, 37.68399492386849, 41.04492879682972, 43.23818875897316, 46.015521018735825, 56.123931792474565, 54.652984142303474, 59.65605358923636, 53.25047792926912, 56.28112862187048, 57.671095017463934, 58.241038937722486, 53.43697094148206, 56.9709127180038, 58.082994876369355, 58.95149784703409, 58.24419252334103, 56.421855418912834, 52.789548443209746, 54.314448295101045, 52.429529774573545, 58.172436683408684, 54.52332235151722, 53.11343816018874, 57.79781110825078, 54.76511686078964, 53.24211151369157, 52.022175942697835, 50.14816161124937, 50.73887448157034, 50.862954739601385, 49.582712727208296, 52.42358346139231, 50.033785297024636, 51.320691416340495, 63.710105572977376, 67.22554160702613, 65.28930279516405, 65.81165267575172, 65.92181636441138, 66.93512931946786, 67.58770188977643, 68.30449150454614, 66.93869867632466, 65.97221882112565, 68.20862877753474, 65.67682120107835, 70.3527767427506, 68.39501196338286, 63.18782629505281, 57.810558811310806, 76.23824611786874, 71.52467112387382, 84.33258256604596, 42.11079366745488, 0.43594113821464203, 45.42007384761688, 63.54196925317088, 52.8888040204202, 22.144446834441155, 50.71161793124292, 75.4553488762148, 24.298898866099698, 31.324646357567083, 36.42656541639759, 54.56500537933842, 64.48187505045246, 50.10254444614534, 80.273478569523, 54.82941627502442, 1.3042691037539513, 0.15587200290493428, 0.14104869186637864, 0.17300038057709896, 0.2065519519871281, 0.17221495659360964, 0.20249121101392856, 0.14288751738927058], [0.06713805344676779, 0.03493205801914296, 0.19946511774774522, 0.056196827847029895, 0.17626892534955857, 0.12372577382672219, 0.08324345093100302, 0.0016294047353796722, 0.022405444103623592, 0.08104799615760004, 0.0428661740114612, 0.8994884079983159, 48.24250944199101, 52.41488756672029, 39.81173953702373, 56.474411256851695, 53.34178678451046, 44.07029997917914, 20.184477683036558, 30.63068101483007, 21.428484839777795, 37.46099641246181, 62.055065401138805, 63.166010072154386, 31.558125442074193, 1.9578189571057598, 66.71491176851335, 66.06705388715191, 73.40467883694556, 59.579755644644464, 67.73854840186335, 59.514197149584376, 69.49715875810193, 58.05654633429743, 67.28721695561563, 65.06216618322557, 61.76082488029235, 62.37101231851886, 57.80903300931377, 58.7270402139233, 57.577118950505415, 57.69910466286444, 59.065803558595725, 58.16940076889531, 52.25098348432972, 45.16350769227551, 46.003342059350786, 48.09467531019642, 47.31773222646406, 48.94839486768169, 49.22720870664043, 50.82081279447002, 51.808720557920395, 48.41585859175652, 51.12167035379718, 52.06999355746854, 50.111675723906494, 49.969105412883145, 53.52750316742928, 53.543612341726984, 51.90994124258719, 53.232278131669574, 53.69665930348059, 53.438135885423236, 52.62759770116499, 51.11484542969735, 47.87769763700424, 50.581928683865456, 49.24370227321502, 48.16490534813174, 47.98131488984632, 49.84749624806066, 48.0209465180674, 51.81023851517708, 36.323073679401034, 36.58851223607218, 36.11163831526233, 39.62762348113522, 34.347109102433734, 18.756301518409483, 9.34761412682072, 7.7489109577671185, 13.847598414267264, 46.105727687958755, 50.118861506062174, 39.80360454128635, 36.24465373254592, 34.459249665660245, 28.474257992159938, 24.65963140610726, 20.93825524853122, 23.299539742931245, 25.00116982767659, 32.84377248056474, 36.36230522586454, 26.24861494187386, 19.84336679981601, 12.971541939243195, 29.678584491052938, 36.931798073553274, 39.3147320901194, 35.03592045076432, 37.69080023611746, 50.187855997393214, 49.07839790467293, 50.38233887764716, 51.06098344249111, 48.64892582739554, 48.89261484146119, 49.23259804325719, 48.48996393142208, 51.366367416997115, 51.51650005771268, 49.33176340595369, 48.79517139927034, 49.00894841840191, 48.325938255556174, 47.223054055244695, 47.34028977732505, 49.04440272238947, 47.36391029050274, 48.03991117785054, 49.80425996165122, 48.45933806511664, 45.67156445595526, 46.34285065435594, 44.914845112831365, 47.521781767568285, 46.81686908968034, 47.120970449139996, 45.32350901634463, 45.007177706687685, 46.01279497146607, 55.84147014925557, 60.95052988298478, 63.497917113765595, 55.86256073367212, 61.45533107942151, 59.742969389884706, 63.53837243972286, 58.32031788364534, 66.17597810683712, 63.672454741693315, 65.42796642549577, 60.47132999666276, 66.31972512891217, 57.875881964160556, 61.49206799845542, 53.455347245739354, 73.23335755255916, 58.55238883726059, 86.84060881214758, 17.301608170232466, 2.750847435766651, 52.28693592932917, 51.97231477306735, 35.44579244429065, 10.377604999849874, 29.8157399700534, 13.396513096747862, 14.218051568154367, 30.825575743952108, 39.82843314447711, 30.01308814171822, 38.750852154147246, 37.977046966552734, 59.66995054675687, 59.44396318927888, 4.4908319269457175, 0.3710614583424984, 0.07699491606364328, 0.12731656582365114, 0.06884838304212017, 0.11365838258737519, 0.1516561291270679, 0.09019926881357547, 0.06751914388470112, 0.10036047518012986, 0.046025359732729774, 0.10496716871256791, 0.13052921682115526, 0.22668299595675162, 0.031154352060008435, 0.08750603308961277, 0.02170731966954566, 0.07310269911202692, 0.018184483501940005, 1.6703271192889062, 62.48791856150474, 60.527035497849994, 45.940925382798724, 60.78076970192694, 62.261519355158654, 49.10999259641094, 31.258238669364687, 31.37943990768925, 28.15580664142486, 42.22140058394402, 68.36412722064604, 67.68072482078307, 41.674065205358694, 2.3294833879317007, 63.77392253568096, 72.00633033629387, 74.10247633534094, 66.63007090168615, 69.0606068026635, 65.55355287367298, 70.70369551258703, 61.923152169873646, 66.95179154795986, 65.35175477304767, 64.53967901968187, 65.43628185026108, 60.94632510216006, 62.459693185744754, 60.10028554547218, 61.46858869060394, 59.6828394551431, 60.696348528708185, 54.204806281674294, 49.73479870826968, 49.67211138817572, 50.67328852991904, 50.357384758610884, 51.835741766037486, 51.93939432021111, 54.37348388856458, 53.19520781117102, 51.40710123123662, 52.78677532749792, 53.860775193860455, 53.66018126087805, 54.61846728478709, 55.098741900536325, 55.47812531071325, 56.219951414292865, 56.484323086277136, 57.32309449103571, 58.14820035811394, 56.23373070070821, 54.572575553770996, 54.61173649757139, 53.20311923180857, 52.69800816812823, 51.85819341290382, 50.300027939581106, 54.23408285264046, 50.5707577736147, 55.54575481722432, 42.45195358030258, 39.46085606851886, 38.827357984358265, 40.01437702486592, 35.34155153459118, 22.48653046546444, 12.4691020096502, 8.685527847659204, 12.925438400237793, 42.79655733416158, 50.03638190607871, 44.599094313959924, 41.727962493896484, 38.27175032707953, 34.03647699663716, 30.34149839032081, 27.56558995093069, 30.583306627888835, 34.98584355077436, 36.55719995498657, 34.46931446752241, 22.78974536926516, 19.796667060544415, 14.947840898267685, 31.11756874668983, 37.13776957604193, 38.739053664668916, 38.97558827554026, 42.09208396173293, 51.478613884218284, 51.1679700113112, 53.130551461250555, 51.71268524662141, 53.0014427246586, 51.06604330001339, 52.31982500322404, 52.96511373212261, 53.56960588885892, 51.94673307480351, 51.49778642962056, 51.49485641910184, 52.557857959501206, 52.14744467889109, 51.097128083628995, 52.91282461535547, 53.83612309732745, 49.85884366496917, 50.74299297025127, 53.2120700805418, 50.46676397323609, 47.375963734042266, 47.82715789733395, 47.728141584704005, 49.40348002218431, 50.20268255664457, 51.29791813512003, 49.79502670226559, 48.4823388438071, 47.864102701986994, 56.81159388634467, 63.063000786689024, 64.36411765313917, 59.99501697478756, 65.51661983613046, 62.37227924408452, 66.51818137015066, 60.09194658648584, 67.50111949059271, 64.02106715786842, 68.07424053069084, 63.47590084998839, 69.21734471474925, 58.766130555060606, 65.42101598555043, 56.129117165842366, 76.57583667385963, 60.45542478561402, 88.2688771524737, 14.805956021431955, 4.0034311000377905, 60.10639659820065, 53.91735146122595, 36.540647552859404, 11.673337432645983, 28.708790233058316, 17.243288409325388, 20.584210349667458, 45.810741916779556, 39.72253699456492, 35.26439066856138, 42.11426888742755, 43.573331755976525, 67.2595799353815, 69.80345664485809, 13.311489839707653, 0.5931468235869563, 0.224614926283398, 0.10031856250979247, 0.08540875248370633, 0.13952649048259183, 0.0831835428553243, 0.13256198516295803, 0.15688800403187353, 0.22350694864026963, 0.3346720061475231, 0.23979924859539156, 0.3271496356014283, 0.3026309915848317, 0.1432855919964852, 0.19213184834487979, 0.12078504573794142, 0.20327396901144137, 0.17669693867285408, 1.6121191459317363, 72.66934425600114, 67.31843117744693, 57.394360034696525, 67.65753576832434, 74.6086895850397, 60.48055933367822, 28.07878305835109, 43.9531466268724, 31.92763428534231, 53.89208747494606, 71.33252989861273, 76.89917333664434, 37.05768654423375, 3.9146014278934853, 74.63811520607241, 70.88268110829016, 78.88126465582079, 65.80430999878915, 74.15250224451866, 66.08908191803964, 73.07505853714483, 62.704707960928644, 68.95767596460158, 67.95638115175309, 68.16411772081929, 68.77463463814028, 64.93188073558193, 67.67095027431365, 62.733180446009484, 63.817966830345895, 62.73920912896434, 63.330314236302534, 58.10011602217152, 51.79175630692513, 53.89274251076483, 52.82109606650568, 52.51262518667406, 53.66188356953283, 54.13726698967719, 58.23655566861553, 57.12912936364451, 55.61990722533196, 55.11764380239672, 57.657166680982044, 56.254589865284586, 56.64434402219711, 57.928884952299065, 57.35297118463824, 58.89918519604591, 56.584857356163766, 61.07681451305267, 58.97693441760156, 59.49563649392898, 56.82713039459721, 55.84625151849563, 58.29266517393051, 58.38086358962521, 55.554329118421, 53.73871103409798, 57.70448223237069, 57.17835118693691, 58.19595913733206, 49.49763651817076, 43.95770049864247, 39.58939213906565, 40.12241871126237, 36.521698582556944, 26.589498327624415, 14.353420407541337, 10.961137971570416, 18.243449657194077, 48.93623944251768, 49.77587769108434, 43.46929480952602, 41.17003279347574, 41.73374798990066, 39.35511289104339, 39.47322722404234, 31.27364770058663, 34.3694430781949, 38.29011094185614, 40.809366933761105, 39.131702530768614, 28.72487195076481, 23.80495086792977, 21.0353397938513, 36.05947863671088, 40.22992695531538, 38.47912996046005, 43.64539746315249, 46.50460527789208, 53.703382245955936, 53.979846585181456, 55.561538434797725, 54.052888962530325, 55.62462583664925, 53.74917199534755, 52.57104496802054, 51.24856687361195, 55.47953344160511, 54.648292987577385, 54.08258130473476, 56.913304867282996, 54.342763885375, 55.395794760796335, 54.066813376642045, 54.6876500498864, 57.05609875340616, 53.63306199350665, 52.58270225217266, 56.437540977231926, 53.2670146419156, 51.365316221790934, 50.24211414398686, 48.69067945787984, 53.10365184660881, 54.12922613082394, 54.61844375056606, 51.2966472871842, 49.0749030728494, 50.5671727272772, 58.867127664627574, 66.7898682625063, 68.64009734122985, 62.71259976971535, 64.51003374591951, 64.80171688141363, 69.04449370599562, 61.84084123180759, 71.98033286679176, 67.24504363152289, 69.94832546480241, 67.17368787334811, 73.15221155843427, 63.59735312000398, 67.7809335339454, 58.46097800039477, 77.21636756773918, 64.23708777273855, 91.12885767413725, 20.152631959607525, 2.7951601676402555, 62.79449101417296, 63.08712728561894, 45.667634241042606, 18.067315624606227, 35.71529849883049, 17.531853260532504, 19.112450768870694, 40.908504839866396, 52.51912455404959, 43.12748378322971, 53.43668460845948, 51.51868089552849, 75.92703742365684, 84.16001396794474, 15.434529569841201, 0.8135261110240414, 0.32754509018794187, 0.17713780695151898, 0.18770042806863788, 0.3521638465744834, 0.3362495344012015, 0.3357399020704531], [0.02441826351587811, 0.11033226630740589, 0.04475063922244214, 0.04264735248720935, 0.06935511956051474, 0.03416839859358246, 0.09895301078476253, 0.08331983755793303, 0.07664899672231368, 0.07502310533797549, 0.0689776603793425, 3.1740057228073, 64.4726025673651, 51.32998351127871, 44.21293697049541, 36.21609887769146, 40.10583885254399, 42.13552421139133, 20.776816375793953, 18.83527255827381, 22.915361235218665, 25.023486152771984, 59.99264394083331, 57.48907742961761, 70.71424668835056, 9.685216449922132, 13.573587517584524, 86.40177403726886, 58.00139780967467, 75.1953035785306, 60.952110598164225, 70.5936259608115, 63.76081789693525, 64.02134172378048, 69.31261124149447, 62.68964213709678, 57.95221128771382, 61.17055523780085, 54.93965448871736, 56.64963922192974, 56.44549162157121, 56.00074583484281, 57.20248945297734, 58.762655335087935, 51.73311687284901, 47.86817019985568, 45.993037992908114, 47.72372891826015, 47.58937597274781, 51.9729737312563, 52.51679074379706, 50.77259509794174, 51.270343872808645, 51.310834500097464, 49.32376961554251, 50.29656448671895, 51.74770024514968, 50.868802993528305, 52.544196344191036, 50.2439929592994, 51.239663093320786, 53.567923192055, 54.2757462686108, 50.64907573884534, 50.45655404367755, 50.429266114388746, 47.4871237047257, 48.25769685929822, 48.558879975349676, 48.61458155416673, 47.224089560970185, 48.26405109897737, 47.12757179814, 51.35823242125973, 36.86616505345991, 31.89944224972879, 38.80321187357749, 41.07143225208406, 34.33192952986687, 23.735244466412453, 16.961660269768007, 24.472238209939775, 37.7868983053392, 45.64283701681322, 44.46460016312138, 45.99561499011132, 40.55831955325219, 38.35546939603744, 35.54175715292654, 33.94382276842671, 30.963366646920484, 28.084450883250085, 29.519703003668017, 31.103803188570087, 38.39173563065068, 38.702485407552416, 30.416535292902303, 31.062804614343953, 32.369122543642604, 33.63330048899497, 36.124433086764434, 30.59190642449164, 36.157008371045514, 49.45354907743393, 49.838427728222264, 48.048603150152395, 51.2039146115703, 48.77614398156443, 48.9365493097613, 49.75424581958402, 48.94057366155809, 48.61012966402116, 52.25404293306413, 49.12843950333134, 50.16252925319057, 47.794766964450965, 48.50813627243043, 50.024195101953325, 47.41264966226394, 48.711275823654674, 49.879306670158144, 49.22359228134156, 46.58402542914114, 46.47749385526104, 45.03809382838588, 48.88186362481887, 45.797853008393325, 47.841564762976866, 47.68010431720365, 48.3275778062882, 45.54924926450176, 46.34473731440883, 43.06254502265684, 56.32109757392638, 58.71532801658877, 64.97499542851602, 59.28584852526265, 59.92381026667934, 60.97941813930389, 63.35460155240951, 59.18121537854595, 64.79706495038926, 61.506761197120916, 65.68707035433862, 59.535060236530924, 62.73946408302554, 57.08940752090947, 59.428854219375125, 55.275021060820556, 73.4011173248291, 59.831148193728545, 83.12620270636775, 5.911632564760024, 15.31236440904679, 53.83560926683488, 52.318746351426654, 32.440982326384514, 8.576794843519888, 24.007351052376535, 38.108650330574285, 33.02116755516299, 39.89287768640826, 42.54404690957839, 32.67729140097095, 32.1405876067377, 33.36451615056684, 50.926583428536695, 60.881692286460634, 27.67850518226624, 0.26137341835325767, 0.09922697914824372, 0.023002151903065465, 0.07522200474575644, 0.04426535316592744, 0.015340395489587419, 0.09277502495434978, 0.018759465047849283, 0.08710670209820233, 0.03514823654005605, 0.09339924105593274, 0.010461041688798897, 0.04041572687246146, 0.07710086602357126, 0.06222042397806241, 0.044239018893530296, 0.13857557618569943, 0.21605758627335872, 3.9799978800358313, 77.3158545647898, 57.801145122897246, 49.97299640409408, 42.8524628762276, 48.87200670857584, 44.440901202540246, 33.69213604157971, 28.65378683613193, 24.083117515810077, 29.4862255742473, 63.600800883385446, 62.58510312726421, 77.23480270754906, 17.121388989110148, 8.860056650254036, 85.50897982812698, 61.81734231210525, 74.12382971855902, 65.63462826513475, 75.1017785841419, 66.80070184892224, 67.41495286264728, 68.99368332278344, 65.71147926392095, 63.60945755435575, 63.02444781026533, 58.67080911513298, 61.05153091492192, 58.92820289058071, 60.2148344439845, 58.78127874866609, 60.738867021376095, 52.15434020565402, 49.586674321082334, 48.839729524427845, 51.15706974460233, 51.285142975468794, 54.59776501501761, 53.95637512207032, 55.686140368061686, 54.849396828682195, 53.919285189720895, 52.28553956554782, 54.94600088365617, 53.57312425490349, 54.342026479782604, 53.207265177080714, 55.23661321209323, 55.26888647387105, 58.43079143954862, 55.1954165581734, 57.421714644278254, 55.01230070667883, 55.06973205074188, 51.50372882043162, 52.26536289338143, 52.13384582150368, 53.67476855554889, 51.48284612163421, 50.83877332748906, 51.18567559026903, 55.41493200486707, 42.400260663801625, 35.49535943615821, 41.30936714910692, 41.97390687081122, 36.608398652845814, 25.300317233608617, 15.460708448963782, 21.884970280431933, 38.54869711783625, 47.04692786739719, 45.421768311531316, 45.48237285306377, 42.754129056007635, 44.60954350809897, 41.42049181845881, 38.83791308249197, 35.708783441974276, 31.508532954800515, 33.13741091758975, 33.41826831140826, 40.83844738621866, 38.81147630753056, 28.36213900196937, 26.712599954297467, 31.833346389955093, 35.67276431668189, 37.65031353119881, 36.085138782378166, 40.57603297695037, 54.0507395036759, 52.32226863984139, 50.24772705570344, 51.64673059217392, 52.47837112795923, 50.48616401610836, 55.01878830694384, 50.98522286261282, 52.380574672452866, 54.34134006500245, 50.855808181147424, 53.72224100174443, 50.460394044076246, 52.76235465080508, 51.71188116073609, 51.709810149285104, 53.282374643510394, 52.89105546089911, 51.68847637791788, 49.32209084110875, 50.889622934402965, 47.01816120455342, 51.68731535634687, 49.37114400248374, 51.521257892731704, 50.824272324962, 53.0511744560734, 48.9050958233495, 49.53413809499433, 45.97299468132758, 57.590953150103175, 60.85756578753072, 66.11845262588994, 63.19627115803381, 61.65813330681094, 63.72689331731489, 65.58228031281503, 61.000171399885616, 67.01722452717443, 65.04801819401403, 70.27338012572258, 63.71422013928814, 69.24800980475642, 59.22742482154601, 62.19393691708965, 57.48021679539835, 75.90801392832111, 64.6709176032774, 86.13403304930657, 4.811762705925973, 21.571151248870358, 65.98433894495811, 57.27226449597267, 36.155094254401426, 11.678182540401338, 19.173971183838386, 34.906843093133745, 34.98325086409046, 46.48982970945297, 45.9203133275432, 34.06889538611136, 34.07661461061047, 32.99146736821821, 61.79408265698341, 67.12283042169386, 45.35738260515275, 0.2734377709848266, 0.20540756984583794, 0.02539507158461117, 0.08546905126422645, 0.01673909200866136, 0.11983738731472723, 0.03596821108893041, 0.12437877951249962, 0.1804769543870803, 0.16452481279209738, 0.2726922448604338, 0.11099579038038371, 0.17419820501198693, 0.2048212980791446, 0.18008425771709413, 0.162326033197103, 0.2302550341212942, 0.2793256163356766, 4.439187549775647, 88.07302536502962, 66.23968524317588, 58.206576993388516, 45.90237240637503, 56.296182678591826, 60.269951589645885, 29.366705071541574, 27.874115743944724, 35.88465075339041, 37.3683500289917, 73.04862960692375, 66.52043281062957, 83.67132586817588, 12.212209316991991, 16.650312331414995, 92.02353462096184, 62.31055682705295, 82.56822201513475, 65.48900635011735, 78.95109853436871, 67.17862221502489, 69.7053110984064, 72.29005106033819, 70.96894971786007, 63.48203543693789, 66.87958071308752, 61.73539615446522, 64.6683523731847, 64.18343367115145, 62.729803285291126, 65.04861439428022, 66.15924527568203, 56.25737082573676, 51.83684395205591, 52.10392990419942, 52.118301468510786, 54.29432261374689, 55.44225523548742, 57.978699053487475, 57.86428351556101, 58.625858752958244, 57.64159094902777, 55.08916347257553, 55.37690854841664, 56.30748694942844, 56.59911517174014, 56.656848538306456, 56.17121988727201, 57.38506009501796, 61.310756437240116, 60.98871807898245, 60.14574973813949, 59.442853158520116, 61.17056700491137, 55.44124718635313, 55.38640852897398, 58.14418777342766, 56.66397156253938, 55.85979938507081, 55.007911574456, 56.404722506000155, 60.04663144388507, 49.00241374969483, 39.41403473577192, 43.973233084524836, 42.55462161956295, 36.485185238622854, 29.480589128309685, 18.844078279310658, 25.99079558926244, 41.84270358854725, 44.555516781345496, 43.5826434627656, 45.719633102417, 41.33872216747653, 43.25396845417638, 41.41483576067033, 41.372893856417754, 39.86402080905053, 35.07250439736151, 36.34379948339155, 35.15978497843589, 41.07949664515834, 40.22359624985726, 28.50142236678831, 34.61011971196821, 35.23891879666236, 39.060601726655044, 39.01522774850169, 40.34117714051278, 41.762436205340975, 55.9362385349889, 51.720377014529326, 54.35498206846176, 53.884984062563994, 55.60469627380372, 53.618576680460286, 57.9521720640121, 53.43652379128241, 55.158201109978464, 60.303201521596606, 54.050696357604004, 55.587837926803104, 53.40274433935843, 54.80206558781286, 56.930437780195675, 57.19572728680026, 55.358979394358975, 55.403816007798724, 56.02056557132352, 53.7528354890885, 53.22790468892744, 50.18643217702066, 53.40205007983793, 50.02032372259325, 52.56097232141803, 51.42869780140539, 54.869985349716686, 50.98137501747378, 50.80151473322223, 47.303207689715975, 60.923783240779755, 64.04309911112632, 69.73421112183603, 64.90064690189978, 64.69369088449787, 64.2405669150814, 67.8386551334012, 65.69172228536299, 70.81879354292347, 67.99254540474185, 72.5486215468376, 66.844969718687, 70.93356209416544, 64.00887250900269, 64.08286409993326, 60.01452292165449, 80.11145330244496, 66.20034387034755, 89.63731365819132, 7.363872470394258, 17.499891827183387, 69.4396411218951, 62.04614593136696, 44.918943989661436, 16.524690581906228, 31.251543183480543, 49.935859403302594, 44.363277496830115, 50.90866996395973, 57.94814378984513, 45.63409013132895, 43.429082670519435, 44.191771861045595, 69.50031234372047, 75.977369277708, 52.56881313939249, 0.2928898159054018, 0.2406209545029748, 0.15843053738917076, 0.1915821342939331, 0.13025976837642733, 0.21680731055957658, 0.13817417675689345], [0.07467443574099772, 0.07794018429253372, 0.10756084364989113, 0.05482045896050911, 0.23167750617909819, 0.0801490992307663, 0.1533705419710567, 0.13571645944349228, 0.06994754301324006, 0.15310071048236665, 0.14114411577822703, 2.5806079901033834, 56.975760767536784, 50.38058165580996, 40.03616971354331, 23.604717793003207, 34.689014265614176, 52.83052544439993, 31.25259241750164, 30.531337184290734, 14.64847678138364, 18.4565814464323, 46.12595927330756, 62.27083498431791, 57.3577525538783, 59.82696302475468, 3.2993028961843063, 32.8640236777644, 82.0011963382844, 59.98048851566931, 71.37596622590097, 65.73609213675222, 68.19144879618, 63.54239286914949, 67.99103921459567, 58.473411913841005, 61.00202668097712, 56.43029243715348, 60.36496708470007, 57.73386078496134, 61.10542035871937, 54.99470887645599, 57.22372516509026, 52.56674605031168, 50.061991060933764, 47.02541758937221, 50.563477854574884, 46.69637387798679, 49.42919900340419, 51.44446180712793, 55.0831897028031, 51.529636075419766, 52.663879625258915, 51.80884215139574, 49.453694205130304, 49.614774180996804, 52.17030032988518, 52.849721524023245, 55.57450971295757, 55.022793046889774, 55.310126273862785, 53.436053106861735, 52.57008790969849, 51.79469808455437, 48.218116221889375, 44.4616505407518, 48.48642203115648, 48.625666172273704, 49.70023085994106, 45.72374766872775, 43.642275256495324, 44.48701258628599, 45.892668462568714, 44.74265306226669, 30.52278837850017, 26.323559668756303, 34.312133327607185, 33.34350793592392, 32.20560089234383, 38.5211463897459, 56.204461974482385, 62.458104625824966, 44.91872825930196, 41.57857902588383, 44.9779599712741, 47.12324542383994, 42.86225703454787, 42.81619271924419, 44.29434184105166, 41.405571122323316, 37.29751594604985, 31.19189766145522, 33.35253723206059, 35.26487704246275, 36.739699994364095, 38.183673504860174, 38.651714248041955, 33.39425163884317, 37.303246528871604, 34.98185450030912, 34.9670357857981, 42.54124633727535, 35.675541354763894, 42.06105409129974, 48.29345318578905, 48.016459326590265, 48.88078889539165, 47.87981179452712, 49.18137973354709, 48.52952103460989, 47.10984268496114, 47.87391647215813, 46.51653712795627, 49.218575569891165, 47.13082344301286, 50.61275459104969, 49.126992148737756, 48.13334203535511, 48.60628966362246, 51.35483957106068, 50.23210425530711, 48.521248755916474, 48.476910283488614, 48.07345920993436, 47.7987011017338, 46.02376191846786, 49.09059255353866, 51.93400106122417, 52.04465112378521, 50.06738039755052, 49.20649074739026, 48.224729337999904, 43.98387055243216, 47.173600812112134, 58.10181048608596, 61.367167965058364, 62.91737887167162, 56.54847737281554, 58.4495678255635, 62.424913529426824, 58.82478960098759, 60.106180867841175, 63.7233788736405, 66.31326106286818, 61.769512930224025, 62.07794458635392, 56.2972495632787, 59.944536070669855, 60.65638349902246, 69.42622661590576, 65.25875145389189, 63.58661367047218, 2.237204971813387, 39.22176014992499, 44.817754683956025, 61.54752246795162, 26.009391546249393, 6.9391101791012675, 30.863816891947103, 28.558700738414643, 34.12983725147863, 47.07351761479532, 42.42374389402328, 32.19965065679243, 52.1801729356089, 44.68094633471581, 56.91643099631033, 64.23123559644146, 49.71813255740751, 1.7284975849813031, 0.18140971240016723, 0.2729397831905273, 0.23506461071871945, 0.14935397362757116, 0.07550492867707245, 0.027064735317722927, 0.06059855072488708, 0.10641667601321975, 0.05479888592456138, 0.07479582237259996, 0.12705035026996367, 0.18700558632131548, 0.12149520158287018, 0.030733162664898464, 0.052364365753507426, 0.14539824798703194, 0.1679884188718373, 2.737787904277925, 69.45339295171922, 60.11870499580138, 51.14689119400517, 32.69084318991631, 36.65251747254403, 55.83305666523596, 27.764911074792188, 45.09898470294091, 22.48160004615784, 20.301232914770804, 51.647730796567856, 69.44133558580953, 62.81846061829598, 73.7820343817434, 7.888217856807094, 22.966069636806367, 90.22894044076243, 65.02854754847866, 73.8550453801309, 66.343918308135, 71.62531914249544, 69.01023572491061, 69.23366177466609, 61.48674926450176, 65.07367833968132, 57.45625503601567, 62.6679906537456, 58.56170838879001, 64.07956538661834, 61.162573214500185, 61.62081587699152, 55.89460257560977, 53.42214045986053, 47.421949601942494, 50.59735928812335, 49.99662083964194, 55.50428359739242, 54.410256108930035, 56.54086797468124, 56.040722631639056, 57.73322143862325, 54.23312187194825, 53.41599018343034, 53.04555762198664, 54.5729285670865, 54.16038936184299, 58.14277572016562, 55.72951393742716, 57.11915477629631, 57.29966617399647, 57.071050828503026, 58.41292896578389, 54.358339617329264, 50.20633036090482, 54.168559658911924, 52.711124573984456, 54.517685905579604, 52.57718347734021, 50.632260537916615, 48.698920357611875, 48.79382994867141, 51.532491560905214, 37.87380626124721, 32.44680900727549, 38.78209383256974, 34.16296951232418, 33.995288187457675, 38.64471281728437, 47.60197854811146, 47.133929960189334, 40.78170245693576, 41.41753827371905, 44.9704094086924, 47.763011455535896, 43.29905609930716, 42.28532345064225, 48.38485617791453, 44.7518196413594, 38.07266258424328, 33.462747989162324, 35.43864196346652, 38.42416970960556, 36.336084181262606, 37.66245326688213, 39.778469993222146, 35.7162320229315, 40.293041813758116, 38.09862475241385, 34.378684182320875, 43.16581318455358, 40.62285823206748, 45.2465364240831, 53.415499887158795, 53.14586047203311, 52.17655258793985, 51.59650464211741, 52.68779431619952, 50.6767088367093, 50.679984015803186, 51.92584253126576, 51.29775731794296, 51.768586866317264, 48.63305591767835, 52.466078419839185, 51.94463068439115, 51.98062235309232, 51.85996240185153, 52.87527576569588, 51.0042816592801, 50.927971947577696, 51.82702233714443, 50.23086870870283, 51.841111490803385, 48.2281574895305, 49.8526620095776, 53.86054377402029, 51.57209181016492, 51.97316200502458, 53.04281196286602, 51.33950310368692, 48.846734877555605, 50.146690722434755, 58.656437550821614, 62.271909713745124, 63.73578140812536, 59.68851904715262, 59.43667150312855, 65.15210613127678, 63.27005878571541, 65.12128022409254, 64.3085612020185, 67.62567043304443, 65.51080296116491, 69.47662907262003, 62.08722099181145, 62.5487349110265, 63.0277818249118, 70.47442513127481, 68.35536464568108, 57.92003216282014, 2.178689337545826, 47.143398561785304, 49.90976779691635, 69.71310092556861, 27.835592185297322, 8.706162456543215, 21.535173308464792, 29.456168451616843, 34.348611370209724, 51.13350022223688, 52.25426650816395, 34.91415439113494, 60.91589535436323, 49.76458518735824, 70.25110106314384, 66.3667465025379, 66.53922880849531, 2.1722902357578278, 0.23127183197967469, 0.22677851179915093, 0.1635694092199687, 0.14253360009001148, 0.06581315034700018, 0.09209914388315332, 0.13615896715031517, 0.20111563885884903, 0.17240798010701136, 0.11989568660576498, 0.25081467364103566, 0.23515442686696209, 0.13060057025042274, 0.27290359319698426, 0.3089222588366078, 0.41453759155927167, 0.40625440377381544, 5.285395768380934, 82.62593576985022, 67.56909416567895, 56.13940946517452, 35.879186891740375, 46.89778758633522, 70.7749963575794, 45.481121616978804, 38.69453084084296, 26.155666535900487, 31.235728186945764, 58.63822598611155, 72.7866074346727, 68.09941430245676, 72.83029479365196, 6.5213826587123265, 38.12710115986486, 91.87988958051129, 64.93676800881663, 74.09907171803137, 69.76907314792757, 74.55937754723334, 68.98706236193257, 71.39580557423254, 63.13064598268079, 69.48359520204606, 61.175140488532286, 67.49941718193793, 61.14981374432964, 66.24028144344207, 64.39784219188076, 64.12219370565107, 57.54882297208233, 55.719162802542414, 51.10841274261475, 55.68284165474677, 50.6062787578952, 57.528379578744214, 57.14318713834209, 59.2616710355205, 56.94467598392118, 60.60356093991188, 57.69699050534157, 56.522993733806, 55.55946350097657, 57.66689415900939, 58.08365775692848, 61.53724978047033, 57.96905002286358, 60.9624146646069, 59.606172807755016, 62.227124091117616, 60.29318771054668, 56.6851366719892, 52.147632952659364, 60.877267852906265, 57.290107357886534, 59.37823603230139, 58.302671140240086, 53.79118450226323, 53.12496208375501, 54.40042272690804, 57.22981660596786, 46.08901839102469, 36.51945890918855, 40.02739144909767, 38.16752902923092, 36.32826689750918, 40.586046788000296, 47.572235215094786, 45.71203547139322, 40.83480742669875, 41.63811276035924, 44.22413925970755, 45.588496500445956, 42.8562165844825, 43.434487696616884, 55.11684756125174, 46.09146987238238, 40.18959322283345, 34.826473728302986, 35.360335765346406, 40.327754789783114, 36.852605419774214, 37.514277888882546, 39.73725764982162, 36.326552821743874, 40.281133497914965, 39.48286840992589, 37.13438457058322, 48.98806964197467, 44.38514471054078, 49.637076777796594, 58.46115058468234, 56.157177802055116, 57.244129334726644, 53.46281936091762, 53.98665189743043, 54.83023605039043, 54.01827012338946, 55.31886139223653, 55.91120989091935, 56.4310259203757, 50.805472404726096, 54.68774418677054, 56.107920677431174, 55.21218469066005, 53.76282968828755, 56.65356159210206, 55.76778058082827, 52.857068123355994, 54.81506824493409, 53.07796816672049, 54.64801842166532, 50.65565747599448, 53.88729826096566, 57.01012857498662, 56.521448319958104, 56.12038989220896, 55.139656143803755, 53.165727276955884, 50.96850964330858, 53.52495362681728, 63.05491285939371, 66.24302710256269, 66.1790140213505, 61.083055003996826, 62.067099232827466, 68.35013220387121, 66.63382853231123, 67.12166940012287, 68.57541745708835, 72.83239718406432, 70.57486134190714, 72.21133693572014, 65.1022175050551, 66.37419116112494, 64.63476903976934, 73.72357537669521, 67.98299835574242, 69.01273819708055, 2.9746993078339488, 42.925065948117165, 59.47274161923317, 72.06988057782574, 35.50613810939174, 13.647936044200776, 37.7126988287895, 37.359865942308986, 45.771145589890025, 66.21050280909385, 57.85925895937028, 44.603173578939135, 70.19214783945392, 56.985939318133944, 74.62584603217341, 76.75284539499592, 76.90190330628427, 3.793159454099594, 0.3787637369767312, 0.4391391875763094, 0.20953345893611833, 0.1776637569550545, 0.25370143083555086, 0.13792089276736783], [0.08917802764523415, 0.11622781084189493, 0.11629499675285433, 0.09838828907137918, 0.05194232025514207, 0.06892732074183804, 0.15293505162962023, 0.06333589396109024, 0.03911931841303745, 0.07430337339399323, 0.243894218377048, 3.9071499051586276, 60.482163583078695, 53.2700466340588, 39.23965400265109, 33.76228370974141, 39.74365895794284, 45.4580423908849, 46.86760102548907, 29.824547652275335, 16.050308346748352, 8.203434723038828, 32.415971332980746, 66.32707565061509, 58.9774247138731, 61.94737280568769, 42.51710414886475, 1.4659381705907084, 38.23359743241341, 74.73991640152471, 66.58461847612935, 68.96499510734313, 71.04011720226657, 67.57220068285542, 62.92581588991227, 63.429114818573005, 56.65751534123575, 55.80587071757163, 56.27351922373618, 57.08338276032479, 59.68469865860478, 59.38982663616058, 57.049250295085294, 53.31063532060193, 49.220321024617846, 44.88292486436906, 47.75710828842656, 50.85243102042906, 51.348861878918065, 53.21338407454952, 54.73728764441706, 54.850287206711315, 52.692069699687345, 53.30729346121512, 51.652649448763945, 49.194739326354004, 50.17360210418702, 54.11474474014775, 53.71152116406349, 52.044870776514855, 54.09910625027072, 53.04176076765984, 52.75882844002017, 50.003583046697806, 51.75854167630596, 50.64279994656963, 45.53639565744708, 46.16090366917272, 48.902965976345925, 46.15390616078531, 44.84931407436248, 40.647612310224964, 38.62623453140259, 39.50117411152009, 27.35848096109206, 29.713175873602594, 32.8837747727671, 30.201528610721713, 34.65178312793855, 47.89146515630907, 72.28532068191036, 97.60632253462269, 80.4634468017086, 44.57077480131581, 42.467627371511156, 43.545341722426876, 43.077030335703206, 46.1397817057948, 49.092957742752574, 41.89092128507553, 38.98238574304889, 39.98874825816001, 37.84426296910932, 37.5926076212237, 37.69358904130998, 39.12934518629505, 49.45671443016299, 51.6374384972357, 33.96760802115164, 21.353047855438728, 15.780686582288435, 23.778484675192065, 36.41831667192521, 37.92167094445998, 43.51587687769244, 41.15974833888393, 45.819269149534165, 45.33894354297269, 48.25357052587694, 47.31185259357576, 44.92244274385514, 46.323717332655384, 48.37545817898166, 46.623939468014626, 50.684655558678415, 48.37590532918131, 50.18532999100224, 48.417305946350105, 49.63216597034086, 47.08901097697597, 48.325797050229966, 48.99831879523493, 48.975027761151715, 48.26203107833863, 50.91523208925801, 46.26597219897855, 49.51540093268118, 49.24692646149666, 51.587436122279016, 51.8382756171688, 52.27289776648245, 46.21395764812347, 45.414209904209265, 44.36655659829417, 54.81990060498638, 58.8011416312187, 63.52309088553152, 61.49927731483214, 56.42389112903226, 59.41199587237451, 60.61179399490357, 61.10186276897308, 63.313432355080884, 65.30674949769052, 65.21211055017287, 59.26459712366904, 64.01004529768421, 54.83801411044214, 71.67959690093994, 58.07556982963317, 81.26468504628828, 27.711774726067823, 4.634646119609957, 47.37392410155266, 43.62858226222377, 71.91754356507333, 15.70879149821497, 7.710073119209659, 29.52907942956494, 24.402086619407903, 39.088058317861254, 38.62409291728851, 45.15290160332957, 32.04570743345445, 34.49330368349629, 24.37443979324833, 35.65202674558086, 67.43049329326999, 63.0649305928138, 4.066711433472173, 0.49179988763024735, 0.04209486902841637, 0.19483137365070083, 0.07763983952181955, 0.11792191469501104, 0.20803581833118395, 0.10002525808710246, 0.013645917210998315, 0.12741074867306218, 0.10171765356414741, 0.13479050429117295, 0.17724665272380077, 0.15259109347337677, 0.013093834990755686, 0.054431033485959616, 0.11390324727061296, 0.19462875871648713, 6.845349352205954, 76.35867072689918, 59.486583663571274, 49.98410455642208, 30.80852520081305, 44.66235037772886, 45.70035857539023, 40.81989065293343, 36.4669579844321, 36.73611887039677, 16.162249849688624, 31.238316951259492, 70.91682926301034, 67.58490916221373, 65.37488106758364, 57.075279143548784, 1.905299646239127, 23.25369311917213, 72.31955512877434, 63.70863076179259, 72.47935248959449, 70.38388113821708, 71.30177067172143, 64.53238733353155, 65.25705698997744, 59.5820463088251, 58.77900769633632, 56.71997516385971, 58.229754278736735, 60.614033668271965, 61.99739479249524, 61.99663777505199, 59.918777865748254, 51.24667236881872, 45.68294325182515, 47.32302350382651, 52.75707906292331, 58.34960229935185, 60.30546080681586, 55.7387315073321, 57.98250375255462, 58.41426257164248, 57.41573302976547, 56.71215395773611, 54.7143574683897, 52.812619824563306, 53.97765005788496, 56.24094786182527, 52.80480646318006, 51.45842544494137, 55.4196741504054, 56.26207766994354, 54.1824762282833, 58.10689387782928, 57.88389928879277, 53.435194107794, 53.56151796156361, 53.196902275085456, 50.46147269587363, 51.34519838517713, 47.49547835319273, 45.51078258022186, 40.612114860165505, 34.05945816347676, 38.77516300447526, 39.76851501772481, 33.904387258714245, 38.362753237447436, 50.7980473579899, 71.58210246793686, 86.55477000821023, 53.715792625181145, 41.10579613716372, 42.38404558550927, 42.301793482995805, 45.04159258257958, 47.03449787632112, 52.509295094397764, 46.72961988756734, 41.68287877113589, 43.43044373296922, 36.41509248364356, 39.31819554298155, 38.7310794861086, 40.09235766626174, 37.16266093715545, 42.19695637303014, 38.47804346392232, 26.00086823586495, 15.080517030531361, 22.275481454787716, 39.852457661782545, 42.649315480263006, 51.42064125307145, 50.49590326124623, 52.1156930923462, 50.71661503084245, 52.015150977719216, 50.16554947822325, 51.54005781296761, 50.94383009018437, 51.89565989278978, 49.7195367659292, 50.88622616183374, 48.689063441368845, 52.07734800154164, 51.80232317216935, 52.42493667910176, 51.09078953343054, 51.02737265248453, 51.165695036611254, 53.91779076668524, 51.62333757646623, 55.531591138532086, 49.744063346616684, 50.3204164197368, 53.49142128421415, 54.865317729211625, 53.43764558915169, 50.4286777588629, 49.3339717003607, 50.10209337357552, 47.35281782765543, 56.64375174430109, 61.26972844523769, 65.65732702132195, 61.47058517702165, 58.37141067750993, 58.994993009874904, 62.94944032546013, 65.22222242047711, 67.99072542498189, 64.69863307091498, 68.12027346703314, 61.706347080969046, 70.76813220977783, 58.9574323931048, 73.17077221408968, 59.21634020343904, 83.55079143278061, 20.50201904389166, 7.1783634827983, 54.46540855592298, 42.54164641903293, 76.11610351070281, 16.357950625881074, 10.807739957686394, 30.279301366498395, 27.59289945325544, 39.25871672168855, 46.74270883683236, 57.81065687056511, 42.400951000951956, 47.14875259707051, 28.26467790911275, 44.99291989111131, 66.04520628529211, 79.921477225519, 9.108706481995123, 0.5303296975551114, 0.26857795434132703, 0.025366732077072227, 0.6361407197771535, 0.06533197052175961, 0.18462697524697552, 0.2173399714933288, 0.21668913383637706, 0.1361164339487591, 0.2488164711863764, 0.32613821568027623, 0.20568749837337003, 0.2557519877389554, 0.12673722715267252, 0.19581545955471455, 0.19848523000555657, 0.3197380413691844, 6.630967797771578, 84.37197100731635, 69.30351134269469, 55.69675822411814, 43.59812898020591, 55.535297778344926, 59.26790760409448, 67.24778144590317, 39.09013325168241, 26.143718996355613, 19.267302020903557, 45.053853911738244, 77.16356462047946, 74.23040051614085, 73.06548010918402, 54.0192703277834, 1.9428699463605883, 43.072307802015736, 81.79220461076306, 67.29795640514743, 71.03727740626182, 74.60927794056555, 72.51696801954701, 68.52794108852264, 69.97992407891059, 64.03844718010195, 63.011868769122714, 63.348619937896736, 62.86076338060441, 67.31377924642256, 66.17698223360124, 64.72146126531786, 62.69683184162263, 55.3249292988931, 47.752781914126494, 50.4189581255759, 54.2758168712739, 58.3590316772461, 62.68756720327563, 58.995789251019886, 60.6268794305863, 61.19679589425365, 60.51182454632175, 59.563246388589185, 55.051744061131636, 55.07492919122019, 60.720898643616714, 60.89911153239589, 55.939529403563476, 56.22263431549073, 59.710005790956565, 60.47278519599669, 59.47150999499906, 62.9011441815284, 59.056072158198205, 54.411236701473115, 56.84272181603217, 58.10638004733671, 54.55098290597239, 52.58773073073357, 50.26399704717821, 50.50929031064434, 48.921146162094615, 42.04039496760215, 43.031589677256925, 39.900506696393414, 35.477928423112445, 40.144462431630785, 54.02369868370795, 70.6090565650694, 75.55438872306578, 48.47918133581839, 40.04616391274237, 42.832698052929295, 40.516926780823745, 45.38024610088718, 45.37938317944927, 48.24056786875571, 46.42666778256817, 38.834433940149125, 43.25685924099338, 38.391782699092744, 38.62463812674246, 36.8675692619816, 40.38378584769465, 40.12205785320651, 42.2518224870005, 37.91252005484797, 28.319285146651733, 19.086604310620217, 28.204483255263302, 44.51295906497587, 45.52740558501213, 51.419229199809415, 53.391981355605594, 55.0379490852356, 53.11651722077401, 56.6630615726594, 54.308403922665505, 53.38605073190505, 55.35231528743621, 54.35789638949979, 52.98780464356946, 56.641712111811486, 52.150378611779985, 55.95217904736919, 55.951724052429206, 52.81896229713194, 53.610057292446015, 55.34490200781054, 53.69083066140452, 57.200928349648755, 54.82138326091152, 58.7272677113933, 53.246292760295255, 53.66257390668316, 56.79286849114203, 57.060052502539854, 55.82116403887349, 54.77540523775163, 51.81824799506895, 52.227735596318404, 50.81127359021095, 63.194619840191265, 63.70018589881159, 70.36146871505245, 63.42804401151596, 59.592236626532774, 62.97536719229914, 66.39072002903109, 68.07853944839971, 70.97735927950951, 68.60814571380615, 70.28004031027518, 65.45346967635616, 73.14245270144555, 60.646875673724765, 76.3536657825593, 63.32779999702208, 85.96244504374843, 30.587491796862697, 6.289936342547017, 59.59340549284413, 50.361558160474225, 82.16098585436421, 25.212156080430557, 14.929191989283408, 35.60675082668182, 33.44259092884679, 48.53803257788382, 57.27879524230958, 64.30503891360375, 44.37902581307196, 51.84675970385152, 35.33024726375457, 52.2612012586286, 80.03543776850547, 90.52848400608187, 12.307724914243146, 0.8349480744331115, 0.34367770677612675, 0.3357053974703435, 0.5982151387199279, 0.2418566849683562, 0.32813693907472397], [0.03771975238416945, 0.19247415175120677, 0.13779753728980018, 0.06530406959955731, 0.11288365319130883, 0.17735782740337236, 0.09653363617197161, 0.1077647609335761, 0.18118682677947706, 0.11162561424557241, 0.12945696951881533, 7.09088089966005, 71.33342419901203, 50.59709256695163, 46.47684274181243, 32.89229416078137, 37.11028160587434, 43.81873484580748, 29.865444244876986, 28.82583179781514, 17.8140736779859, 5.9733966569746695, 7.312975795038286, 38.75252308384065, 67.28703652658771, 53.86270892235541, 69.40574399886593, 18.19505741519313, 0.05406549463288919, 16.66498395704454, 49.06692497191891, 72.36962026165378, 64.84432951096566, 66.77713624892696, 63.47232364839124, 60.65452821793095, 57.617068290710456, 56.44351082463419, 55.691843494292236, 57.55945651761947, 58.50510074246315, 60.09490797596594, 57.99617321260514, 50.96936079763597, 44.86030455558531, 45.0767566311744, 44.777173842153246, 50.38386860201436, 54.49226502449282, 54.66231938331358, 51.01799034303235, 53.28693243765062, 57.01570226300148, 54.168661640536406, 54.21949555796962, 53.336640634844386, 49.77029223595896, 49.983457365343654, 51.428333020979366, 47.523460542002034, 49.41980884921167, 50.91143915730139, 51.46607406677739, 50.80079693948069, 51.23984744471889, 48.51305492462651, 50.04555632991176, 49.23674006615916, 46.3181475670107, 42.558893080680605, 44.92628274425384, 35.385921385980424, 31.575007323295843, 19.691074894320582, 14.198909421120922, 15.611946217475401, 14.8572959246174, 15.873405529606728, 24.398838896905225, 43.66549176554526, 51.303809535118845, 58.67951677691553, 99.39865742960285, 63.121244061377745, 41.913925986136164, 42.853588596467056, 39.5268460242979, 40.79021792257986, 42.4590060018724, 38.1172207094008, 35.9636551334012, 36.79646061312768, 37.33830467347176, 40.75670126945742, 37.82250558176349, 51.54553344172817, 73.65684017058342, 56.27993622133809, 38.30545133160007, 20.322535307176654, 12.834705152819234, 5.460049596525008, 10.37088107678198, 19.329210750518307, 36.936842241594874, 41.41896601646177, 41.68413000722086, 41.518300041075676, 48.12077868369318, 45.880897429681596, 46.32456848698278, 47.70046534076814, 51.06774168629801, 48.05619293643583, 47.52211124666276, 45.28864306788291, 48.950230536922334, 44.744571101280954, 44.859186680086204, 47.215370132077126, 47.246090135266705, 47.741999318522794, 48.90035367781117, 49.08182213383336, 48.84665643015216, 48.825820799796816, 53.57878031269197, 53.16180490678357, 53.3830971871653, 52.18101232282577, 50.11025974827428, 50.47304368788197, 47.42131025560441, 43.553735594595636, 44.20250738820722, 51.552899652911776, 62.16035358367428, 58.81137509499827, 62.17935746715915, 52.4179038693828, 61.619023353822776, 58.65745736706642, 67.64247386686264, 64.67810338543308, 68.95792699629261, 58.28736212945754, 69.68043542677357, 61.866638660430915, 69.33205050806846, 59.74068657044442, 74.73523309153896, 2.7969115059221945, 16.61763506550943, 54.13367409859934, 59.733465486957186, 55.55359563519878, 6.594128406816914, 8.511925705017584, 17.093769619541785, 31.082181122995195, 33.59001321177329, 41.25035116749425, 46.05949471073766, 32.92122948554255, 28.84546522171267, 31.097831379982736, 38.32191744158345, 60.14989176104146, 66.47133258081251, 11.105061500303208, 0.4859708165449481, 0.3709962489383836, 0.04713728655910781, 0.11485433776772792, 0.07936915277593559, 0.20110453058394695, 0.25749447004448983, 0.03368522310929914, 0.08472612217789696, 0.1033338615971227, 0.04045939005370583, 0.20337057269869313, 0.2104695724143136, 0.06833145755433268, 0.2913636461861672, 0.17993818007169232, 0.2655224279770928, 8.282192484025034, 83.7429718817434, 55.38328239994665, 50.04939240794028, 30.206947365114768, 45.36834562978437, 47.472175551999, 19.706101494450724, 9.118123112186309, 18.489880408010176, 17.564348136225057, 9.595727574440742, 36.20861107303251, 73.61722423184302, 61.6097116470337, 77.59607653464042, 24.985229315296298, 0.08799468227211507, 8.157459151360298, 45.400391394092196, 72.47688139638593, 66.57726795442643, 68.77699590498402, 66.42368362795922, 61.508381136002086, 59.25898421195246, 59.332281543362534, 58.196610250780665, 58.1612265494562, 61.405140430696555, 58.70386685094526, 60.72167135054066, 56.52910870890464, 49.77636014261554, 48.270099393783084, 49.16866733181862, 50.32580575635357, 57.738214615852606, 61.351764817391675, 57.25171519863991, 57.73405298109978, 59.53569173812867, 58.306522907749304, 56.82875033347838, 56.49002229013751, 56.15746021270753, 57.436403920573575, 55.14062889160649, 50.54346199958555, 49.87354078600484, 54.20292746636176, 57.79357887083485, 60.09082086624638, 57.7136762680546, 56.4125790134553, 56.02387212937879, 52.62657396255001, 50.62470997533491, 50.07185974428731, 48.76461221325783, 39.7643651500825, 35.24895221956315, 18.434822097901378, 16.669055377283406, 17.41557655795928, 16.7579480524986, 19.5933392355519, 33.14591461612333, 52.0917901685161, 61.638615592833496, 70.00105780939903, 95.15067561980217, 48.311068550232925, 44.37394242132864, 42.507423739279474, 40.326613380062966, 40.291935705369525, 41.89322371636668, 39.70115223238545, 37.95013950717065, 39.77164899149249, 39.81853700453236, 41.71996870348531, 38.27799474039386, 42.029859481319306, 58.656453240302305, 54.87473533999536, 42.987976843310946, 23.6089833705656, 9.845434484943267, 6.516700819615395, 11.88131130510761, 22.663988297985448, 39.347727068008915, 48.148478461850075, 48.220124475417606, 49.06294376619401, 51.242228323413485, 51.802958596137266, 51.576861412294456, 52.02084625920942, 51.28023216801306, 49.15311121171521, 47.60426528992192, 48.011022921531435, 49.98528518984395, 49.0428690756521, 48.84699375398698, 50.38452363783314, 49.565764165693714, 50.31860036234702, 52.87897456076838, 52.15880386291012, 51.21103371343305, 53.60689586208713, 54.126751115245206, 55.56345647381198, 58.16206593667307, 54.692792277182306, 49.58648604731406, 51.971008623799975, 49.98137850915232, 47.73111866366479, 49.077413389759684, 54.71138038942891, 61.26508828132384, 58.85082237182125, 62.04982119221842, 57.41831002696868, 64.25169467926025, 61.49600605810843, 68.89917773585167, 64.86759701082784, 67.59472293238487, 63.772361432352376, 71.4277885806176, 66.39723900825747, 72.76039031244093, 66.26802829004103, 66.24866747087049, 1.170639590390267, 25.46896738390769, 57.76238426085442, 56.2706127474385, 56.54252713726413, 5.785797536373139, 15.456721359683623, 21.721987955031857, 25.552690375235777, 24.684267813159575, 45.28880388505998, 53.22377443313599, 39.42786893536968, 37.95895699531802, 28.056655007023966, 45.2915495441806, 58.47509461064493, 74.97918098203598, 16.191415613697423, 0.7573123564643245, 0.2541746586681374, 0.15587083845128938, 0.5290878383863358, 0.20603464345537847, 0.15489928574571687, 0.32481315936292376, 0.21402149310996457, 0.19818123099544357, 0.12274017106861838, 0.2657897926626667, 0.5284345798915433, 0.25827756512068933, 0.3152778161869895, 0.2977601432752225, 0.2584556958848431, 0.4300452642623456, 10.251877346346456, 96.74208318033527, 63.29186324150332, 65.70523877297678, 43.601910145052024, 50.83110509380218, 61.37974700620098, 39.94763005164362, 41.890944819296564, 24.35720293752609, 12.116757458256139, 17.566946706464215, 50.61013837014475, 79.05422549093925, 64.98806084356, 84.1816968302573, 22.253702494405932, 0.3249522502864561, 23.02698012321226, 51.44403034640897, 74.89539131041496, 69.69530120972665, 70.80355121243385, 67.15160492927798, 64.72836463682114, 63.25052538225728, 62.551064798908854, 61.646358351553644, 61.47926145984281, 63.91866583977977, 64.90366320456228, 64.15860899033086, 57.8194429797511, 51.45967668102634, 51.87411431343325, 49.698654067131784, 56.25201679045155, 61.27689461554251, 61.008000450749556, 59.15124847042946, 62.10263590658865, 60.786755238809896, 62.930157953693026, 59.88084854618196, 59.201141019021314, 57.84125528027935, 58.40622955752958, 55.7880945359507, 52.48175613341793, 52.72951264535227, 59.280737676928126, 61.26848113152289, 62.10078847023749, 60.64978215002245, 56.43121027177381, 59.39183881205898, 57.11115314114479, 55.358606769192605, 55.803489838877034, 54.28707407366846, 46.04196563843758, 42.68012962033672, 34.281911465429495, 29.28054040478122, 31.35144202939926, 25.89201658002792, 24.934132599061538, 36.64864609318395, 54.44542015752485, 66.13277712175923, 75.34306710766208, 86.66823633255498, 44.16846121511152, 46.65516937932661, 43.82951744141118, 41.32457417826499, 39.91441934339462, 41.096927658204116, 37.37759505548785, 36.34695306901009, 38.09423169782085, 36.06759794296757, 39.469865752804665, 39.11664062930692, 37.73868845355126, 58.10127704374252, 55.38106626079929, 43.865536566703554, 25.111115824791696, 14.655340929185192, 11.957475889113642, 19.90403017690105, 34.06188611061343, 44.608660974810206, 50.24812713746102, 51.03296202998008, 52.50075217216246, 56.601280320075254, 54.51430482249106, 54.99262217552432, 55.624064937714614, 56.895532608032234, 54.68942688357446, 51.33308218371484, 51.63396327726303, 57.88500147481119, 52.89145162028652, 50.84636703614266, 55.16000540025773, 54.29866467752765, 56.08865399514475, 56.28548245276175, 54.24348477394351, 54.518466457243896, 56.429060812919374, 59.23464590503324, 57.838470397457, 59.688683786699855, 56.371598089894945, 52.287991046905525, 55.70378711146694, 53.95814018864786, 50.146565206589244, 53.30923111208024, 57.405774131897964, 64.97858831959387, 62.14244796383766, 65.29598259156751, 57.45151289047734, 67.22545531488234, 64.7170917449459, 72.4029133396764, 66.0841711105839, 72.12237758021202, 64.91988220522481, 78.23230066607076, 65.87010383605957, 76.61253436919182, 63.83072237814627, 81.29188276106312, 4.470601812485726, 20.092755017742036, 62.64501340927617, 66.12376351510325, 67.85615674911007, 13.680529959740179, 14.932705452365262, 22.38714937240847, 42.90423816250217, 39.147709723441835, 62.548887883463216, 62.45635524872811, 43.36368891500658, 40.30435392933507, 42.67100618731591, 53.967491119138664, 72.7563424264231, 90.7946325117542, 27.1558532791753, 1.000871258156915, 0.7511402005630156, 0.2836354737800937, 0.6027235355108016, 0.23997322716299566, 0.24069788505233106], [0.06569867382847494, 0.13475960030430748, 0.22570617256626008, 0.0210546319102568, 0.13555415605585422, 0.13389721512794495, 0.03204004929190682, 0.07608825866613658, 0.17518059020080876, 0.07997231678135934, 0.13275647956517436, 5.321992952977458, 69.72012196817707, 49.65897537046864, 50.45601275659377, 30.916184456117694, 34.07848950355284, 42.4035083863043, 38.52348804473877, 81.47858758126536, 68.30515046273509, 12.170024225788733, 3.558818428747116, 7.826897973014463, 60.985623328916496, 58.75062934813961, 64.17360813386979, 45.16930103302003, 1.379518059472884, 0.3038133410436492, 20.403426347240327, 75.01514911651611, 66.47425082422072, 68.44141360252135, 63.85490771262877, 61.420810299534956, 55.29701379037673, 58.33684675155148, 57.804122201858036, 57.24030110143847, 60.259431792843735, 58.2649536286631, 58.865986254907426, 52.53957971449822, 44.84194001843853, 47.00420148911015, 50.0933543328316, 51.261538151771795, 56.826447902187226, 57.77036628415508, 58.89777706515405, 57.205525367490715, 55.37299402298466, 58.45890698894378, 55.85124077335481, 53.15741577456075, 51.78109530479678, 55.2760918678776, 51.212406542993364, 51.09727713369554, 53.14380122769264, 53.85559374286283, 55.28539572992633, 53.16717463154947, 49.898628265626975, 53.14758631490892, 48.872638210173584, 48.16318342762609, 40.590632038731734, 39.72303513557681, 34.1926069413462, 25.858829405999955, 11.184113929348609, 1.776680225326169, 1.9590326855259559, 0.7613553395194392, 1.3210720472758817, 2.1759998173482957, 11.817956201491818, 32.16839132770416, 23.410648722802442, 31.59588021616782, 48.633597204762125, 63.86390170743389, 35.785606984169256, 36.816735344548384, 33.064019449295536, 33.84327673142956, 30.075371457684426, 29.58287669766334, 31.791190716528128, 32.12409796253328, 37.59086216649702, 38.01698846201743, 41.428607202345326, 66.43319145325692, 42.40575590441304, 33.70437775888751, 33.84540265606296, 18.01599141090147, 2.421231548632345, 0.8911955368614967, 0.7491843474488105, 4.011511182592762, 12.76782972197379, 28.859454354932232, 35.758491639168035, 40.38198155741538, 47.011948170200476, 49.17025589173841, 46.369781647959066, 45.71776605421498, 47.35853664336666, 49.616519635723485, 51.17283767269504, 48.49440405445714, 49.993353505288404, 47.297786974137836, 50.46714052077263, 50.597920187057994, 49.510529348927165, 48.17421313255064, 48.39133985580937, 49.573871704839895, 48.19344843587568, 49.20059150265109, 50.961457221738755, 54.744747992484804, 54.08700573828913, 52.921430295513524, 50.78549969580866, 50.57211099132415, 48.9315757443828, 47.28816932247531, 44.14459359261298, 46.668081821933875, 58.34550342252178, 60.24630754224716, 61.74627680932323, 62.483564730613466, 58.01719319435858, 60.4779980259557, 59.46493218022009, 65.32945609861805, 60.68403620873729, 66.26724381600657, 61.206590052573915, 67.76104711717176, 59.47418897382675, 72.13566657035582, 29.74036966600726, 0.4421475229244079, 46.29005947420674, 57.41221858609108, 66.8696806507726, 33.0234189956419, 2.304856541656679, 10.755576356764763, 25.75645946687268, 58.00226073111258, 62.559850908094845, 44.955425954634144, 42.80956783602315, 32.93582070258356, 40.03036068331811, 36.473543643951416, 32.86029154254545, 50.58646686615483, 62.562706393580285, 8.900244274447042, 0.16373701393604279, 0.24461253305837033, 0.06354080715907678, 0.09058162329658385, 0.17988222500970288, 0.1847806218410692, 0.044333634582618554, 0.05888750483732551, 0.3026269772841085, 0.09329907505983308, 0.13461248077932866, 0.10169204324483873, 0.02085026071947669, 0.13203013628240556, 0.2684739196012097, 0.12073345737712038, 0.30831456725155154, 8.079638346549004, 79.32642229141729, 52.745841472379624, 54.27939799524123, 38.01956153685047, 42.88408894692698, 52.28519047460249, 39.94212696629186, 73.92418892152848, 62.76778359566966, 6.8155609119323, 6.2065609712754535, 8.864835077716458, 62.84468950763826, 68.74022760698873, 68.67093501552459, 51.95764903099307, 2.5198896998359315, 0.39461774270861383, 17.44171131041742, 73.59436465847877, 65.9807538986206, 71.28471620621221, 64.27001214796498, 63.99750940261349, 58.034945841758486, 58.08763504028321, 55.615435723335516, 61.13292794073782, 61.35439280540713, 57.74438842650383, 60.88088427820514, 56.48984578347976, 48.632243987052675, 49.721635233971384, 50.452529691880756, 55.25424034364762, 58.98549695168773, 59.88624964990924, 62.09067659993326, 58.848994547320956, 55.52859837009061, 59.233869275739124, 58.945500543040616, 58.101963458522675, 60.79621207329535, 63.23955451288531, 53.98960936454035, 53.95999154736919, 55.02658205647623, 58.32706828271189, 59.07655869760821, 60.98308947778518, 56.38319261612431, 59.868124377342966, 54.847702364767756, 53.644142689243445, 49.1513696793587, 48.109537170779326, 38.64574832300986, 32.32269933146815, 11.196123246223697, 2.1060651829165797, 1.2489782706383736, 1.3747091110675567, 1.3386088417422388, 4.042149796601265, 17.733363066950155, 41.37275657346172, 33.8817669499305, 39.648823891916585, 63.223394347775375, 64.66665790927026, 38.76598073590187, 36.24780731816446, 36.53061805232879, 38.053843052156516, 36.80353264654837, 35.20472749587029, 37.49023375972625, 35.00973862986411, 38.969375241187315, 39.199908625695016, 43.609433251042525, 61.566204717082364, 49.87701600597751, 35.64616280217325, 43.238373110371256, 23.738425508622203, 3.035932899482789, 1.524258054071857, 0.1992992597121385, 1.5996412283951238, 10.047745435468613, 28.73140858065698, 43.00476066527828, 48.404130704941295, 51.16537732462729, 52.816240172232355, 53.87154602235364, 50.734108801810976, 50.248382091522224, 51.20915489812052, 51.6455146574205, 53.30872120395784, 51.9071759716157, 51.1118487388857, 53.251070207165135, 54.80829823401667, 49.59167534305204, 51.392184457471295, 50.75510524934339, 51.708076461668945, 51.12567117137294, 52.13695626105032, 51.56755755024572, 58.07561689807523, 58.11185567609726, 53.98868368517969, 53.760950872975016, 50.61438629704137, 49.43169755320395, 49.61060862387381, 50.638657923667665, 51.41959005786527, 56.53501579838415, 61.88102591422297, 64.23622485130065, 65.73240510879025, 58.97736980069069, 64.85436685623662, 60.64272972845263, 65.56743414171281, 60.00738813031105, 71.11545024379608, 62.74714800619311, 72.4382068264869, 63.140902980681396, 74.05823199979721, 18.158402865932835, 0.8373071962306577, 56.907884151704856, 58.74688740699523, 69.89254936095207, 30.763523847826068, 3.937352400633597, 15.718121836262366, 21.038220774742868, 53.37709203843148, 44.6516344624181, 31.141130424314934, 54.85735139539165, 33.131911754608154, 48.48994824194139, 32.239762775359615, 30.98801482108332, 54.90606723293182, 73.06268738162133, 14.042108751112416, 0.440679146878181, 0.045155704381965825, 0.17135370522737506, 0.32817135174428264, 0.6558851344931511, 0.41911441532354204, 0.11496460080266961, 0.2623929281628901, 0.2974701636741239, 0.14170400347680817, 0.2906314499916569, 0.20935258557719572, 0.14844738517797765, 0.23266503947877118, 0.3998888259933841, 0.18258361957005917, 0.6319401677577727, 9.231751234300676, 94.16277962346231, 62.33369488869945, 67.02979180120653, 44.80155529514436, 47.81064079653832, 59.14550219812701, 46.91463416622531, 90.99275142915788, 85.66105796444802, 15.377914078773992, 9.497835020865164, 16.991678168696744, 73.44285134346255, 71.67504695154005, 78.11313121549546, 54.14708860458867, 1.674620030868438, 0.39572461718513124, 26.75819946873573, 76.46178983872937, 71.1238205817438, 74.00788445626536, 66.94079322199669, 67.0536555013349, 60.89519308459375, 63.56358543519051, 62.85374233799597, 64.29989668630785, 67.1024654757592, 64.54179317720475, 68.16349014159172, 60.61532805042883, 53.32651307505947, 53.35238895108623, 56.39886248496271, 57.70145416259766, 64.70539523709205, 60.60922092007053, 61.61497154543477, 60.73379147437311, 57.412979525904504, 59.86134259931503, 63.54979045929448, 61.33642050527758, 63.93122134670135, 66.72868713255852, 55.27874339011408, 54.234643751575106, 57.408912028035815, 63.36680012364542, 63.28748587639102, 64.27356581534109, 59.80270316523891, 62.813993038669715, 58.1966337850017, 57.81332015991212, 53.903364289191465, 53.26202930942659, 45.6663320141454, 41.106419794021114, 27.047837088184973, 18.259419587350664, 10.9128898766733, 3.6597704310570998, 4.187031119100509, 10.775340199470522, 26.29361237249067, 46.23538555637483, 38.99087767447195, 48.65890825948408, 67.63993217099097, 61.75591799520678, 36.0289429849194, 36.887604728821785, 35.48808736185874, 37.884408427822976, 38.340058403630415, 32.653443390323275, 38.01934188412082, 34.54725980758667, 37.674855801366995, 37.84951110039988, 42.34569264996437, 56.21063578513361, 43.77679686392508, 36.49243377870129, 41.58945968074184, 25.003009419287405, 6.411685241806892, 2.490810227970923, 1.988558204423997, 10.724098355539384, 30.832508533231675, 43.95673951795025, 44.7943381340273, 52.13001366584532, 54.12656676384711, 58.05365946985061, 55.73943361159294, 52.63799982686197, 52.57457117880545, 54.955328279925936, 55.40685584468227, 59.64649477312642, 58.81457967142905, 56.30569442625969, 57.535635963563, 59.32675884615991, 54.84574510205177, 55.54586464358915, 54.937540331194484, 53.66825349869267, 55.38846385094428, 55.512426437870154, 53.83525625351937, 63.217267605566214, 59.82834762142551, 55.81419398707729, 55.10487648748583, 51.82759108081941, 54.142550422299294, 53.338370400090376, 54.19829906955842, 53.24105639611521, 60.484144380015714, 65.42814685452369, 68.99995911505916, 68.26726821161085, 60.71749402630714, 63.5484843100271, 62.40940840013566, 68.46340240970736, 60.75392107809744, 73.04992398908063, 65.7926134909353, 74.73950847502678, 62.88922017620456, 74.97010461745724, 34.70707285788752, 0.7969443524076093, 53.64781010535456, 64.60547677932247, 76.17896341508435, 43.714011484576815, 8.512484642767138, 16.706053133933775, 32.16384530067444, 69.4060734779604, 78.54661587745913, 62.498148102914136, 61.08659298189225, 41.78953193849133, 59.35986757278443, 49.151542263646284, 47.542535028150006, 65.22912971435055, 90.34890221011254, 26.31683868746604, 0.5076683877456574, 0.4640306406203778, 0.23331477396911193, 0.2739136648033896, 0.6349163887000854, 0.44953371368108264], [0.10680316737101925, 0.05715420026512397, 0.07198464741269428, 0.13566577506642188, 0.033224176074708664, 0.05637889630311439, 0.004346508527129528, 0.0857780758111227, 0.0620313726305481, 0.16187448565277363, 0.06528579074168397, 7.699653833143174, 71.17344640916394, 51.67504618244787, 42.878946719631074, 20.066533973140103, 36.85759075226323, 38.97583538486112, 17.17833592045692, 57.01041098563903, 75.70150113874867, 18.766470263081214, 6.6206568671811015, 5.818538540794004, 33.61741488979709, 67.61403668311335, 53.669920506015906, 58.91781253199424, 10.851618532211551, 0.026699012603550672, 1.6978641190836508, 60.295482297097486, 71.42017918248331, 67.87987924391224, 65.43748601790398, 56.88941763293359, 57.60075123079362, 57.88783734844577, 58.17958324186264, 61.582106005760934, 59.07176163888747, 57.764596477631606, 59.32957118557346, 50.95440480016893, 46.744940665460405, 48.78452608662267, 51.68195739869149, 52.58060770650064, 56.05296042657668, 55.556564869419226, 58.13324043827673, 61.12841721503966, 57.9641588272587, 56.48984578347976, 57.44329944733651, 56.57889927587202, 54.647657563609464, 56.25147942573794, 54.94461236461517, 55.29109885615688, 54.999329428518976, 57.320964644032145, 56.38027045034594, 55.55236793333485, 52.36839571306783, 51.05650017338415, 49.319823711149155, 45.048680305480964, 41.08109304981847, 34.18072608209426, 24.898433146938203, 7.956511224469832, 1.099987529939221, 1.4357692604103398, 0.258405716308663, 0.7061223613639033, 0.604458571441712, 0.49783705883929813, 3.1772970816781445, 13.6598551465619, 12.286157761850665, 25.681703013758508, 28.116537832444717, 36.1709523970081, 25.963943043062766, 25.91202262909182, 20.446629293503303, 14.81414298857412, 11.584680099641124, 11.804872155189516, 14.377321370186346, 20.83954291958963, 28.837559684630367, 29.372435654363326, 39.59863324319163, 30.252762609912505, 26.885345059056437, 30.524227888353412, 19.3925021156188, 8.619921303564503, 1.2336117726179863, 0.026771827345533718, 0.1787237928158814, 0.7017648532505959, 1.920677298499692, 7.966139662650324, 25.269595269233953, 35.152728634495894, 38.032199413545676, 45.08528778629918, 47.702685402285674, 45.80085754394532, 47.320823054159845, 51.95762549677203, 50.38725752984324, 52.65630552845617, 49.65903420602122, 54.39557075500489, 52.531311358174975, 54.14247981963619, 52.23282683280207, 51.877307122753514, 50.06542313483454, 49.48089584227532, 49.26807980383597, 50.92097836156046, 53.1191961996017, 55.69032945940572, 55.56458219405144, 54.7046809811746, 58.77590902390019, 62.45124832276375, 54.727399349212654, 46.66632460009667, 42.81013657969814, 44.04680105947679, 53.10927652543592, 60.88420652574109, 63.52272218273532, 65.15242776563092, 60.031789195153024, 62.11050810352449, 64.32093235754198, 58.370167286165305, 63.42429030326105, 65.08273117003903, 63.93110759796635, 64.1623862328068, 63.03539122304609, 59.308194268134336, 0.094959034374164, 5.294882510938953, 58.56799202580606, 48.18689023294757, 65.12219021397253, 13.9466941548932, 2.384499042264877, 15.105067145439888, 35.70420211361301, 45.70492421427081, 84.60043338037308, 59.82561765178558, 34.48165424408452, 36.344807532525834, 33.470961432303156, 27.528145044080674, 37.87997614952826, 50.5431442876016, 62.210744273278024, 6.090534810096988, 0.27260773004062716, 0.36325545140331794, 0.10053581738423917, 0.20578754945628105, 0.039683185938385226, 0.043101228938828555, 0.09609668260259975, 0.24118157764596326, 0.26221213141275995, 0.1053207795766573, 0.1274274187462945, 0.13328151026320073, 0.13221028951867936, 0.17220599336489556, 0.12453263295033287, 0.06491091327681657, 0.2632965441913374, 8.212833212267968, 79.37218066184752, 56.84274142788303, 46.35975606979863, 23.606029825825846, 44.50624788961103, 45.93881122527584, 31.033635908557525, 79.50859285170033, 78.7757372087048, 14.493293108478671, 6.320530829891083, 11.070052385330202, 35.09980409376083, 76.89645905648509, 60.60281568957914, 64.1866696265436, 17.363456103109545, 0.11592345943133678, 0.5501667782664299, 52.31431799550211, 71.23304290156211, 70.6080053698632, 66.36997853555988, 57.941185505159446, 58.59231856561477, 57.700226460733724, 58.20366659472066, 64.6835397904919, 61.64096117019654, 61.50618068633541, 62.50213715337939, 54.51207691623319, 49.3402631821171, 49.60449757114534, 52.61582274590769, 55.0665549309023, 55.89628919478386, 59.43318451604536, 61.7543843484694, 66.50076604658558, 60.03689219874721, 60.27791007872551, 60.59031901821014, 60.94113188405191, 58.66276041153939, 61.077728425302816, 56.42623278402514, 59.72029809028872, 57.50561806463427, 59.91432989797285, 61.57574784371161, 58.87956157807381, 56.19569155477709, 57.28556133085682, 52.37606786912488, 47.337634332718395, 48.245157041857325, 42.594351307038345, 30.728028358951693, 12.919473455798242, 1.4419618248939516, 1.8541054836203976, 0.7272907190265194, 0.8696831750773615, 0.700921482376514, 0.9221711682696497, 1.5168643862970415, 23.665995021020215, 18.539461128173336, 33.37906422153596, 39.944413708102324, 46.833527395802165, 33.23551724033971, 33.65750543532833, 29.19650362383935, 24.09687719037456, 21.86430919554926, 21.199047757733254, 21.883677859460157, 30.518244312655543, 34.77925623616865, 37.087065096824404, 42.059826389435806, 37.414583006212794, 33.17737986964564, 39.07349455741144, 32.187981605529785, 14.768339510886902, 0.7878821451337107, 0.3333184207158704, 0.31561679477172516, 1.0977316767938676, 2.148486351774585, 6.302849275450553, 27.069312064878403, 41.28699002727386, 44.952570469148704, 48.126654394211315, 51.620474246240434, 49.132573681492964, 51.03060076313635, 53.25822461035944, 51.61992511441631, 56.51468223141086, 53.17026153687508, 56.238476768616714, 57.13973937496063, 57.225352948711766, 51.74549587311284, 55.975046465473795, 54.702904147486535, 52.567220657102524, 53.31295736374394, 51.60694991388629, 55.400179970648985, 55.94904507360151, 58.63378586307649, 57.51763228447207, 61.73661601158881, 67.4496187702302, 53.78246899574034, 49.84665293847361, 48.87405026343561, 48.0833004366967, 53.77562053741948, 63.49573627594979, 67.41247392469838, 66.87036314318257, 63.93039764896516, 62.95787734370079, 64.6638887159286, 62.52477315164382, 65.97705118117794, 67.03894661318871, 68.92149602213215, 67.25089580781999, 70.97231511146792, 46.35659856180991, 0.6272469905595626, 11.773595175435467, 64.59146215069678, 51.71680373530234, 72.61771017505278, 14.69923617378358, 7.912889565190962, 9.396709453675056, 28.38337471408229, 46.09836147677514, 77.76950020943919, 44.945243481666814, 41.57928113014468, 39.31414373459355, 40.20578476690477, 31.329939596114624, 38.71535078171761, 59.293257882518155, 71.36757235373221, 10.12212141867607, 0.9024241794982265, 0.23672427891963915, 0.18711976406555023, 0.29658324836242583, 0.1884762453095567, 0.18996198090814775, 0.20113785540865314, 0.5057005530163166, 0.2729180262934777, 0.29734388174068543, 0.20480363209161068, 0.2987395713646566, 0.19798331984108497, 0.6584574738817831, 0.27893604530442145, 0.25278575658317537, 0.3969872833019303, 11.644272669669121, 92.51088911487211, 65.63828783650553, 56.64756821047876, 30.267861773890836, 48.19494678128151, 53.711838876047445, 22.156635599751628, 62.95271942692419, 80.83487172280589, 26.447057454816758, 12.074759660228608, 14.592591831761023, 43.449906533764256, 76.99678544075259, 64.43560677189981, 69.35207028542796, 15.418687116715217, 0.5253353558721081, 2.9559219412265287, 66.6684316819714, 77.41295676077567, 75.85635631315171, 68.73528542057161, 62.05453588116554, 62.272800091774236, 63.51626596143169, 61.07622223515665, 68.57939474044308, 65.67142009735107, 64.9987296904287, 65.18189653273552, 57.911273510225364, 51.526035339601584, 53.2089674857355, 57.96485700914937, 59.06987497883459, 60.133264833881015, 61.34367689009636, 63.840183135001894, 69.3648572121897, 59.77223419374036, 63.02958219282089, 63.79163595937914, 64.67577741992089, 62.28163326940229, 62.70777917677357, 59.29561914936189, 61.37986467730615, 59.58933799497543, 65.73675893968152, 66.2498128029608, 61.16382445058515, 58.327538967132575, 63.005502762333045, 52.94008116568289, 56.3144923025562, 53.54017242308586, 51.15056645485663, 40.518107414245605, 29.663138197314357, 11.650992670366842, 2.9037264710472477, 1.7550157491237888, 1.4591154528241006, 2.0839135973684253, 1.2944847513591091, 12.045351689861668, 36.36674142652942, 19.931969219638457, 42.97468785316714, 48.17777856703728, 54.30234386074928, 33.46185761113321, 36.32957304677656, 33.04585495302754, 25.252646707719375, 24.89219657836422, 23.788461223725353, 25.323055213497533, 30.492164473379816, 37.19600108362014, 34.424234667131984, 44.2730276815353, 35.617435363031205, 40.044391001424486, 34.69380740196475, 27.69656377453958, 29.71588230902149, 2.066878988858192, 0.4909624003114239, 0.35543418399268584, 1.2310510777658032, 5.074272232670938, 26.14299531905882, 41.89774228680519, 45.611195256633145, 48.883997394192605, 50.97571111494496, 56.8809296238807, 51.12984849560646, 53.64354648897725, 56.731604991420625, 55.81372722502678, 61.164691294393236, 59.73424996099165, 63.47093905172041, 57.82609531956335, 60.99649613903415, 56.34244311240412, 59.74829204620854, 58.20694961855489, 52.39530709482009, 56.92522102786649, 56.263662307493156, 59.336556926850356, 61.31371390435004, 60.87635001828594, 62.488985446191606, 60.02789820394209, 64.79013804466494, 60.93956685835316, 52.10778951644898, 51.302809330724905, 49.913482281469534, 59.43374541498, 68.41212134207449, 73.55320330589049, 71.90552542286535, 63.09194787856072, 65.7228188360891, 63.07941198349, 63.12818665658275, 65.62979198271229, 73.31341312777612, 69.25866296214443, 71.50542013106808, 66.28334122319376, 66.53424739837646, 0.48121705711368595, 7.40435133057256, 68.55105953831827, 58.43372145006734, 79.2884066797072, 21.078303475533765, 10.623325801664784, 19.924906992143203, 44.818072395939986, 54.5588590252784, 93.64621916124898, 72.26654037352532, 47.20385013088104, 48.689989120729514, 51.76578629401423, 39.89783948467624, 55.64942698324881, 64.75619385319372, 91.46041562480312, 21.231328864251417, 0.8989680197931106, 0.5255698400639719, 0.28862972353254596, 0.38739601570752363, 0.25562196729644654, 0.360077228397131], [0.005043186970250381, 0.10922726108542374, 0.12466396340319227, 0.1467619917445606, 0.11527084445040073, 0.027653408770058906, 0.06955739741604175, 0.03323295927276054, 0.13192838448430264, 0.03786970643446811, 0.18063790945997163, 3.7519343629960096, 60.36826579801498, 57.36325956160023, 34.39611127299648, 47.42657407637566, 40.20916584999331, 53.944031423138036, 27.962982923753803, 15.750444127667336, 38.05096403245003, 9.79037029127921, 3.8637054879819197, 15.653739071661427, 44.04157646240727, 55.11557671331591, 64.028182337361, 61.170433644325506, 46.37563774662633, 2.3697043522711727, 0.14230916697171428, 14.488852985443609, 72.98014502371512, 66.28367854702857, 67.85813362367692, 54.040019665994954, 61.28723790568691, 55.00165539403116, 61.91449942127351, 57.73561016205819, 61.05841467457434, 56.37280225753785, 55.521573405111994, 49.464335595407796, 49.60196372001402, 48.65874351993684, 51.38390433403754, 53.9915862391072, 54.949801660353145, 57.38737037104946, 59.7957331134427, 57.95747510848507, 61.517155478077555, 59.85577675604052, 55.6169968266641, 59.051612423312285, 54.97644239856351, 53.48766757595924, 53.88112445031443, 54.93562621455039, 55.25345586961316, 53.52396911190402, 54.1519013527901, 50.20298850151801, 45.93530070397162, 42.557806584142874, 34.805222326709384, 24.951316502786455, 32.64065842474661, 24.497459050147768, 11.170621956548384, 1.8141501372860325, 0.8735203562724976, 0.46985793438169265, 0.12378418803094857, 0.058319956259501565, 0.2940747394196449, 0.5677486799897686, 0.6481899345113386, 5.272146492235122, 11.01451652665292, 18.92652846151783, 18.78481322719205, 15.065153106566399, 17.6833704979189, 14.87537314814906, 9.722848649947874, 4.003604910066051, 5.874667657959846, 5.918713913809869, 6.1266657229392765, 9.060386803842361, 10.349025630181837, 21.552108141683764, 23.809496894959484, 13.817908033247917, 24.82672437544792, 18.343936858638642, 16.379618779305492, 2.8899216892257815, 0.11495481785987655, 0.06209627559949314, 0.21969869492515443, 0.09206992528972127, 0.024656283203512434, 2.5372572195145393, 10.232394933700562, 25.06126249990156, 37.72605449922624, 43.36811727093112, 46.59674175323979, 47.47862392856229, 50.97913534410539, 50.23761910776938, 51.92078659611364, 48.598119366553526, 52.172928317900634, 51.84170769106958, 59.158257745927386, 54.725865702475275, 51.31755744257281, 53.740825191620864, 51.738937670184725, 49.67280564769622, 52.11555188701999, 51.35908357558712, 52.78437091458229, 54.93195095369893, 57.6163818759303, 55.51727840977331, 81.43948155064737, 67.34562104748142, 49.67670056127733, 51.94590153232698, 44.30118637700235, 44.11712915666642, 48.445445029966294, 56.13417702336466, 63.848486792656686, 60.772524879824736, 65.15738171915855, 58.28576964716758, 61.86945099984447, 62.450318721032914, 65.70801188868862, 63.516830782736506, 65.80915020358178, 61.70869265833209, 62.77123920379147, 4.499466534583799, 0.2559256292278728, 27.056905608023367, 49.34575057798817, 56.76437639421033, 51.24588789478425, 17.776379700629942, 6.945315368713872, 9.36332518054593, 22.138879029981553, 40.06305756107454, 73.59940882652037, 65.44618191257601, 36.01166494431035, 28.971836143924346, 43.529973876091745, 27.873666632559996, 45.8146878211729, 60.63645785854709, 61.9238385846538, 5.473909781825158, 0.36499048733422834, 0.22903733736565038, 0.08352424513788954, 0.08929782081395389, 0.17314101899823836, 0.07118737204901635, 0.004478672100606585, 0.08377836416325263, 0.06207367983616649, 0.07380681818411236, 0.13435110690132265, 0.10033256659704833, 0.19517799779292078, 0.1569314718606972, 0.06558687095680545, 0.08991405427936586, 0.2963410726478023, 4.268828226673988, 72.5150852818643, 62.88654119737687, 43.28552784458284, 42.69459139916205, 44.35395794530069, 56.46322857949042, 29.071607512812463, 18.448487635581724, 35.47778329541607, 15.254198601168973, 5.918889930171352, 19.83732242738047, 49.68819310588222, 59.61351156234742, 69.69247710320258, 64.25590730482533, 52.43745296232162, 4.450966427403112, 0.4670486593198392, 11.079839679502673, 73.24645042419434, 71.1851115380564, 69.79128945258357, 58.885131343718506, 62.893809349306174, 56.98555884822723, 62.89570777646957, 61.920641852963364, 63.403125193811235, 60.14851500911098, 59.67595961786086, 49.3165446096851, 52.40007277457945, 49.89820857201853, 54.302822389910304, 53.89746896682247, 57.971972188641956, 60.55193470370386, 62.52309437721007, 59.369041996617476, 64.02848828223445, 65.28776522605651, 59.74890001358525, 62.32330060774281, 58.80657019153718, 57.96000895961639, 55.66120978324644, 58.90626507420694, 58.463590298929525, 58.19540608313776, 55.77111851784491, 51.06735729402112, 48.419286743287124, 47.24054782621322, 34.476417879904474, 23.605606209847238, 36.353397523203206, 30.40413275841744, 16.22638452437616, 2.518604878456362, 1.5959660901177315, 0.9325125585159949, 0.5245567653929034, 0.1104778076912607, 0.4081068963052765, 0.44843808537529367, 1.082668794739631, 6.973587322619654, 17.711897896182155, 18.79952996007858, 23.559373232626147, 27.455077171325687, 24.63429681716427, 20.74806736361596, 16.731307314288234, 10.543629123318581, 3.782181230283553, 5.6844106412703, 7.27870261476886, 11.067970587361245, 24.386571684191306, 32.1350884437561, 35.157847327570764, 19.71013761335804, 21.098087910682928, 29.46364448916528, 26.482111677046746, 1.8828266714849782, 0.1545184021515231, 0.15873963854485945, 0.3314798709846312, 0.10883417371059619, 0.21925796454231586, 1.7202471244719721, 7.730945521785368, 30.913177959380615, 44.410593048218765, 48.659022008219075, 51.51613135491648, 48.60868230942757, 54.635102056687884, 53.599486504831624, 55.29511536321333, 51.77051667244204, 52.883630414162916, 54.67358835281865, 57.24941276734876, 56.60603031035393, 53.41983802856938, 55.671415790434814, 54.18977183680381, 50.70195321113833, 54.49329268547797, 52.604993081861934, 56.986100135311005, 56.79983462056806, 60.21173184917819, 59.4326824526633, 89.64919843981343, 70.01138933243291, 52.0304560661316, 52.08668324255174, 50.79222263828401, 47.416901511530725, 47.68538382745559, 57.74145449361494, 64.40105853542205, 62.95567689403411, 66.4964122156943, 63.38259943069951, 63.007871873917125, 62.46316448334725, 67.96416313417497, 67.49696177821006, 69.94787046986242, 62.56283583179597, 53.50826786410425, 0.15174364701153772, 0.5724056365509187, 34.9776065734125, 56.09521219807287, 61.56427098858742, 61.431169279160045, 25.007225967222645, 12.709772759868255, 8.253380713924285, 22.304324603849842, 43.60709159604965, 70.7936119264172, 56.818501180218114, 42.34223311947238, 30.75546141593687, 47.81464161411409, 28.890019424500007, 48.623795201701505, 65.90500508585285, 69.9266190682688, 7.049216503097165, 0.6620192311463818, 0.2085076365619898, 0.04863379335391426, 0.1980606793996788, 0.06571390365640964, 0.1881287325053446, 0.19686775792750622, 0.30332852996164755, 0.26566069152566696, 0.2697943181039826, 0.2771572197877592, 0.3355193606788113, 0.20248186474125232, 0.2601322026983384, 0.40365604803927485, 0.5391443052118825, 0.7568145218876101, 8.210691107857613, 84.75717913719916, 74.27327202212426, 50.31023394676947, 61.667068466063476, 53.27689901474984, 74.98948112610849, 42.147008911255874, 20.61090207869007, 45.63274083598968, 15.443699090711533, 10.811448558684319, 25.71616888046265, 54.5594826821358, 64.95183775501867, 73.50769596715128, 71.79772300104942, 52.845763852519376, 2.78394169865116, 0.49459335063734366, 19.843058893757483, 84.4215811452558, 72.50738174684587, 76.16200308645926, 58.665937531378965, 67.81774105564241, 58.9745339270561, 67.08599936577582, 64.53011628120177, 68.25626204090734, 61.07259796511743, 62.009055999017534, 56.488319981482725, 57.9003300974446, 54.4626275954708, 58.93151337100614, 58.92657118458902, 62.65009680101949, 63.6756161720522, 63.77270660092754, 63.55798821295462, 67.19919112420851, 66.93277589736446, 62.22919118019843, 67.06156299960229, 63.03467735167473, 59.09129504234561, 60.14543202615554, 63.62371536993212, 66.6608379733178, 60.89627958113148, 61.205272136196015, 57.39767443749213, 56.04116193709835, 49.14936142583048, 38.77321750886979, 33.44334794629005, 47.68630558444608, 40.18061491750902, 29.047253516412553, 11.907954985095609, 3.656011819839478, 1.9248112315131773, 0.691449816428846, 0.10989515185956994, 0.6573220702909655, 1.3610318062766906, 1.266542521695937, 22.501358985900882, 24.078242009685887, 27.813713204476144, 33.44168486133699, 43.21174021690123, 30.404881931120354, 27.32010449132612, 24.601399898529056, 19.29460171730288, 12.7407879214133, 11.446779370307924, 15.137032501159178, 20.95053226717057, 29.63850179026204, 34.16047488489459, 35.95669684871551, 24.425479635115593, 29.009259477738414, 29.05235063645148, 30.837129085294663, 14.617735205158112, 0.19376170040378649, 0.3119475094060744, 0.4083826879580175, 0.3299241609150364, 0.3122419629606509, 4.801082582243027, 27.555034852796986, 41.37248592991983, 46.27289518233269, 53.37973571592762, 54.97916060109293, 56.423997033026914, 58.57868048452563, 57.35105314562398, 59.3015262388414, 57.84958247215518, 57.20492916722452, 59.69558715820313, 60.63021344523276, 63.31695072112545, 55.05904359202231, 59.814568335010165, 60.18318483906408, 55.21051768333682, 55.76781588215982, 57.18621161676223, 61.924423017809474, 60.14203133121614, 65.23107520995602, 56.4123240593941, 79.33272946265437, 82.23398116327103, 56.14066854599984, 57.8419142384683, 52.913918956633545, 49.158622141807314, 52.646323096367624, 63.44228613761164, 69.85089378972208, 66.75823042469641, 70.96022636659684, 64.09414091417867, 65.17505984152517, 60.91380473106139, 67.33768217025265, 69.50212447874009, 73.47841939618512, 64.92914684357183, 67.87874960130262, 5.702783513453699, 0.5957580189551077, 34.57171186324089, 59.481092345330026, 68.24956263265302, 63.89215846215526, 25.873746179765273, 14.240473797244412, 15.201575102344638, 28.18190609255145, 50.055021009137555, 80.32140993302869, 69.52197951655235, 51.00698024995866, 38.281497416957734, 62.398559124239036, 37.56348794506442, 64.9722654588761, 75.64706648549726, 92.15300421560966, 15.408464439453619, 0.7763014697740156, 0.30356583335707266, 0.3088865897828533, 0.5433170329178534, 0.32665673463094624, 0.36528969063393535], [0.07535450731313999, 0.10215973992261196, 0.15969295835783406, 0.03278596995158061, 0.07975768958849293, 0.07594473209352263, 0.06594061205584197, 0.08113819534980482, 0.09450226211019101, 0.06401097830084544, 0.0738494586379778, 2.3903536700433303, 66.32695013476958, 54.975959947032315, 37.322344549240604, 35.120369080574285, 41.16807945312993, 41.268131271485366, 55.7867060169097, 43.64832747367121, 39.79744249774564, 12.411538285593833, 1.5049053247897857, 11.600218569078754, 52.235847057834754, 54.244449677005896, 55.33821828903691, 56.97919284143756, 60.357722466991795, 15.494970352418962, 0.09024834440600488, 0.611835998152533, 38.96870843825802, 75.49904407993441, 61.83608731915874, 61.090138804528024, 54.353020883375606, 56.95851018351894, 57.13169459373721, 64.6395347195287, 61.1350420982607, 60.338647980843824, 54.26177478605702, 50.15935213335099, 50.09269537464265, 51.01978678857127, 49.616821658226755, 54.29152988618421, 55.020545528781035, 59.53542109458678, 58.9757106381078, 58.28654235409152, 54.99496775288736, 57.387994027906856, 60.606961634851274, 60.56698091568486, 58.628749539775235, 54.246756030667214, 51.72427585048061, 53.94594553978213, 52.33672649629655, 51.03429563583867, 39.528250232819595, 43.34410059836603, 43.108052361396055, 45.81061640093404, 33.44690161366617, 11.759023570245313, 23.858659882699293, 14.800342129122827, 3.2022891986754636, 0.8163377762802186, 0.2912321548548437, 0.0953789578089791, 0.09678037777062386, 0.1640960180591191, 0.14743175177324205, 0.08789810156750102, 0.19192816088757209, 3.8389330237142505, 3.437225933997862, 11.077024398311492, 11.070830975809406, 10.296053040412165, 6.988947814510715, 9.204009290664427, 7.775812043297676, 4.25239545683707, 0.4284486450975941, 0.6875420938576422, 1.3945118097528335, 3.5392536463276034, 10.02285505494764, 13.396985742353625, 8.176363994998317, 9.440416424505173, 14.14139472669171, 8.163365260247263, 4.475986246139773, 2.8747254465856864, 0.0980146526689491, 0.0730721245429689, 0.11082058607210075, 0.06506268295549578, 0.07313926448865284, 0.3640199458647159, 2.529825798926815, 10.98273846410936, 29.182294837890137, 36.90904832655384, 37.33567668545631, 44.872197181947776, 47.88944513567033, 51.796435694540705, 50.05461700500981, 51.352941143897276, 46.71116121353642, 54.174604031347464, 56.04312312218451, 51.47035337263539, 50.64709886427849, 51.586702639056796, 50.41852274248677, 50.204204436271425, 50.244424420018355, 53.12058864101287, 54.48973901810185, 58.204415767423576, 51.020626175788145, 73.37163679061398, 60.957872559947354, 49.575852501776914, 53.65609415115849, 50.633951079460886, 45.93238246056342, 45.19496902342766, 45.639844248371745, 48.804232074368386, 59.12651400412283, 61.64036104756018, 59.736073863121774, 65.39174333695443, 61.85238868959489, 59.43375325972035, 62.26789320668867, 64.89402986341908, 62.278824852358916, 60.47697036497055, 7.565242542374519, 0.5781758720836332, 2.0090308929643323, 44.02585168038645, 54.74221806372366, 63.77955898161858, 59.210315442854366, 46.292550179266165, 12.999151502886127, 5.969214429778438, 15.796497656453042, 35.02809924464072, 67.86653534058603, 34.03366465722361, 42.010459438447036, 26.30691509093008, 41.40788139835481, 26.40048715376085, 43.59361433213757, 60.83671446769469, 51.52948702535322, 2.446204298926938, 0.35898356127642816, 0.1350334154502038, 0.06375818843803098, 0.08109894866544394, 0.03588099963963032, 0.06615600533663266, 0.11786264247230946, 0.06306132038814888, 0.09445298733490129, 0.019251553965131604, 0.03259504168865181, 0.05869068918869861, 0.17835355784383514, 0.0362100190813503, 0.09099752476979649, 0.20737707464685365, 0.007071989849435106, 3.1249260854336525, 77.4654459184216, 60.82776754133163, 38.143786922577895, 35.01503775196691, 45.63485891588273, 52.65677229050667, 49.27932916149017, 27.51257911805184, 37.57549039779171, 19.842201855874833, 5.849240893317807, 11.92095862280938, 58.03473795613935, 57.41427390806137, 61.48282689432944, 60.994738917196955, 66.38876668868527, 17.764306645239554, 0.05623573362226448, 0.36062752467490017, 37.28883181848834, 78.99089490213703, 64.21735040603146, 64.86300391535606, 55.873963063763036, 60.05802592923565, 58.894301845181374, 67.36044760673278, 62.94020314370433, 61.60131385249477, 54.41421770280408, 52.03815960115003, 51.770140124905495, 52.02501573870259, 53.52309834572577, 55.590301175271314, 55.114035221838186, 63.693490412927446, 62.159608333341545, 61.27874205189367, 56.602939482658144, 61.54539654331823, 65.53444700856363, 61.55980733133132, 61.933048309818396, 58.133197292204834, 55.78727476058468, 59.75446193448959, 57.981942853619984, 55.67732680228449, 44.460367925705455, 48.87227342974756, 47.71096944808961, 48.52781088121476, 39.409253366531864, 17.95305305911649, 31.81054172977325, 21.837364473650535, 8.26407015323639, 2.154914381042604, 0.3390965316324465, 0.2924581100383113, 0.1714813967625941, 0.11348025948410073, 0.057551068283857844, 0.2214754213609042, 0.6502329377878098, 1.9263654706939575, 9.621948619042675, 15.274057561351409, 18.95877230551935, 14.76639009291126, 15.277309206224258, 13.072608670880719, 7.516046704784517, 4.077736970878417, 1.6938974996728284, 1.836839700418134, 3.7445938923666557, 5.531782882828867, 9.147790939577165, 16.20746889422017, 18.357702416758386, 14.635705544102578, 21.68807122015184, 17.281982591075284, 8.587427408464494, 0.8987118399912312, 0.16750052811638003, 0.017308958002456257, 0.21012909229724638, 0.0921366362261676, 0.050824689904167775, 0.17867093274910606, 1.9071027107777137, 10.481327176094055, 33.50797291724913, 40.59963780064737, 41.18781289746685, 47.229047436867994, 52.93833963332638, 53.83635451716762, 53.059882117855935, 53.984302397697206, 48.721438684771144, 55.91195906362226, 58.670318818861446, 54.96899773997646, 55.96805680182673, 53.89134222461332, 53.70544933503675, 54.60645698731946, 53.146841064576186, 55.48608772216305, 55.960090468006754, 60.30866930561682, 53.07270826831941, 83.24733334202921, 69.56493731467955, 51.24815502474385, 58.08774094427786, 50.67402593551144, 53.06700514208887, 46.37323333371071, 50.19008782602126, 50.098237683696134, 61.50295649805377, 62.8777668553014, 62.70961876838439, 63.92957787359915, 63.42461585998536, 62.93593952732702, 66.32232958270659, 66.38091410360029, 64.30648234582716, 52.35895064569289, 3.483694498577426, 0.72365946226543, 3.201551302786797, 50.508050841669885, 58.09186727769914, 69.613158933578, 65.82727939851823, 56.12762666517689, 18.43472796101724, 6.532844804948376, 17.993482889667636, 37.01196347513507, 65.35654398702806, 38.39872137192757, 45.67394533464986, 27.720804022204494, 48.47665140705724, 26.937255667101955, 44.87572339273269, 68.28496594582835, 58.97510267073109, 3.6560664878737543, 0.17966833326124376, 0.061918255918088465, 0.03492784836599904, 0.10844981973810543, 0.02009849289372083, 0.07166521939178629, 0.17438448695165498, 0.26820790323038257, 0.27094651434210043, 0.13151580017180214, 0.18475446759933428, 0.3303157237748946, 0.24360607738696763, 0.2758344617341795, 0.12118807693402614, 0.5577784440209789, 0.26945481857945847, 4.970144091113921, 91.99784309633317, 69.36164086864841, 53.80098650532385, 46.63033685376568, 56.674267784241714, 58.71990542257986, 80.51210772606635, 51.18465577402423, 50.48454015485702, 20.287179062443396, 8.859505557244825, 20.986884793927594, 64.35137387244933, 63.89584156774706, 70.83492232907203, 69.82040912874284, 72.2535651729953, 18.574533001069103, 0.23661664356627773, 1.4337739997333097, 46.029366985444106, 80.20005964463758, 66.11370655798143, 68.16075232721144, 58.90188770909464, 61.97473918237994, 62.47247226776616, 73.1614605073006, 65.9622952245897, 64.15035240111813, 59.675155531975534, 54.08780982417446, 56.8897981028403, 57.375771922449914, 57.18427004352693, 61.916970514482074, 58.69000911712647, 67.33520323230375, 64.22998043798631, 62.98764813330866, 58.94433167672927, 63.9374343810543, 68.21139797087639, 66.04853245519823, 66.76579275438863, 60.4540244994625, 61.33519672578382, 64.39266858562347, 61.305692657347656, 58.220932868219194, 48.37813323543918, 51.48183415012976, 50.62766744244484, 51.42683467557354, 43.980936619543264, 36.97523832321167, 44.92108952614569, 30.102559366533836, 18.46214140615156, 6.702688336372376, 2.0364409060247484, 0.36373254031904284, 0.3492931619046196, 0.2489743772293291, 0.25229570545977165, 0.11996411357916172, 1.3557807332085026, 10.666791546729304, 22.246793239347397, 23.804036955679617, 37.41564596852949, 29.53852841931005, 22.86576286438973, 24.48361308343949, 13.923771823606184, 4.804725973836837, 0.8498869728176826, 1.2604048703947377, 2.7197327440784824, 4.883733785921528, 11.620391318874976, 25.216974712187245, 25.773914014139486, 23.159075744690437, 25.357525002571847, 23.69822709791122, 20.064814013819543, 7.066329313862709, 0.2919593561560877, 0.1317385785401829, 0.3403723438180262, 0.16947306662557587, 0.07202916478197421, 0.42367276104707874, 5.18546260172321, 28.76072241413978, 41.711625822128795, 47.6386683987033, 45.8689812690981, 51.45857841737809, 57.545653696983095, 58.3267270365069, 57.01013641972696, 57.84146316589848, 55.04112620507517, 57.97524736773584, 58.72948777291083, 60.065376450938565, 57.308075735645915, 57.65691172692084, 56.68011996053881, 56.734829179702274, 57.125960088545284, 60.77490183614916, 61.52006587674541, 61.94121860688733, 57.328668179050574, 71.13649768214073, 77.12039501436296, 61.23001836961316, 59.02281045913697, 57.7644552723054, 52.30664583944505, 49.021017551422126, 53.13431693661598, 54.24266499857749, 64.79568819845876, 68.4276774621779, 65.35180576385991, 71.358166510059, 65.74630598868093, 65.7359823103874, 64.38457281358781, 69.26599779436665, 64.86018765357234, 68.31416406939107, 9.683470995195451, 1.1239606887102127, 2.7731603287881423, 53.07893306978288, 63.999988340562396, 74.57059552592617, 67.69271942877, 58.80436189713017, 21.163473821455433, 12.91981372141069, 20.30766756303849, 42.08682406333185, 76.94649281040316, 36.584401592131584, 56.86113342162102, 31.540918004128244, 62.272976598431995, 36.32240295410156, 59.13457055245677, 75.58949393610801, 86.62211710406889, 9.220793112631767, 0.7768499274407664, 0.2513137952454629, 0.20754398988379588, 0.23043120370036174, 0.12535729595730383, 0.1469932124018669], [0.05497816965104111, 0.11665069137609775, 0.04710331439010559, 0.0980245122205346, 0.10518749559959097, 0.05948125745259947, 0.006829507220836898, 0.10761099176541453, 0.04189747881384627, 0.045625860201975996, 0.1611662833320518, 0.9584851454823249, 58.707177331370694, 51.435487424173665, 43.79735400599819, 34.04359217612974, 43.08081934528966, 34.497171140486195, 29.016904177204257, 45.20404146563622, 30.399586731387725, 23.547843425504624, 2.78582860385218, 4.3623370412857305, 40.85066164693525, 64.37694380360266, 62.41769244593959, 45.60230716582268, 54.971464910814845, 27.08068105482286, 0.27393165254785173, 0.09718816637271836, 13.385765802475715, 70.21250494064824, 60.48465428813812, 60.362370475645996, 56.227564734797326, 57.76605167696553, 58.455812238877826, 62.690265793954175, 61.55550841362246, 58.503092488934925, 48.59147487148162, 52.920257506832, 50.03211044496106, 50.08259527144894, 48.165952620967744, 53.925984597975216, 54.527864456176765, 56.52390764605615, 57.97071703018681, 60.18763280683949, 56.99545106580181, 56.46725293128722, 57.13574640212521, 57.745004238620886, 57.35119827332036, 57.04639873197002, 53.4664906993989, 55.58622583266228, 54.6827902332429, 51.2361761062376, 47.080805378575484, 47.20918847668556, 38.35825427885979, 40.981566829066125, 42.7909287329643, 38.366036261281664, 27.95024698780429, 9.014541160675789, 1.2425324681305117, 0.7336270628917603, 0.1929739168694904, 0.08268904842195973, 0.07918608074467029, 0.10184546767343437, 0.07282103922578596, 0.05549389238078749, 0.6438141628619164, 0.883338722971178, 1.5038278987330775, 6.886705352414039, 11.608944862119614, 4.978565910170156, 6.410634536896983, 5.094315544251473, 2.799059003591538, 0.6470583920036593, 0.625658062917571, 0.017396523767421325, 0.8709745541695626, 1.8178576351173463, 3.7049247564808017, 7.186428366168854, 7.821421853957638, 10.262576591583992, 6.706631298988097, 3.377280595802492, 0.7023733722106104, 0.4038421154743241, 0.1742603194208876, 0.052623219202242555, 0.052313141284450415, 0.03738830827416913, 0.0641744269899303, 0.048098546873417594, 0.03161778162804342, 1.835360966863171, 14.296205774430307, 25.706298235924017, 32.31548805390635, 42.968333613487985, 47.717786527449086, 46.52172250132407, 52.3687957948254, 46.56311527375252, 48.89841210457587, 55.251329944979766, 50.992957776592625, 50.94908998858545, 55.78404664993287, 51.026490119195756, 52.606452203566036, 50.25876068299817, 54.34563113797096, 52.435927160324596, 56.754229222574544, 53.35194572325676, 62.849490488729174, 57.83766631157168, 37.58034236969487, 59.05813532490885, 56.98976362905195, 52.34523019483013, 49.761957199342795, 46.226462164232814, 47.93774520197223, 48.77382978316277, 52.84954893973566, 53.69772618816745, 60.68737022338375, 58.88118151695498, 64.77648427409511, 61.66237338896721, 67.77064907935359, 58.06588942004789, 63.32770193776777, 8.917511528538121, 0.10564034549339164, 0.31958552858521866, 11.204254319590907, 72.15101088246992, 52.06685958370086, 67.52385354811146, 54.590924401437086, 65.72703538402435, 16.59090607397018, 4.693795461808482, 18.23019596838182, 43.9103300340714, 56.44795094766925, 21.943801910646503, 35.75489874809019, 27.571922617573893, 40.15338974614298, 30.552612120105376, 45.88818127109159, 61.931961813280665, 34.133798845352665, 0.7913685193465603, 0.05687587286135363, 0.07179800541170182, 0.033484098216098164, 0.036262760404497385, 0.03186691150579962, 0.10513883369464068, 0.0709581202376754, 0.017043271049436544, 0.04928253959083269, 0.11548095938539314, 0.0062457798236620525, 0.05349058778055253, 0.01153877418067667, 0.031690462304639726, 0.17878037606996877, 0.08094802934436068, 0.061915597592991214, 1.344718055859689, 63.58152243398852, 58.994773357145256, 44.83499742323353, 35.79267901758994, 51.05223263463667, 43.253544838197776, 36.600977528479795, 43.99408832673104, 35.05109610096101, 25.889418009788763, 9.059276773083596, 5.2013521232912625, 44.67563936787267, 68.19152724358344, 69.43755442096342, 48.698281011273785, 58.23700281881518, 33.591927328417384, 0.5082306043515282, 0.01730527694998009, 12.589172624772596, 71.06247471224877, 62.32365362105831, 66.83991770590505, 59.23525387240995, 61.82626962661744, 60.870011468087476, 64.25322832599764, 62.05129208103303, 62.25581622892811, 50.21890155730709, 56.76347032670052, 54.38204250028057, 51.364763167596635, 51.65750926540744, 56.73423690180625, 57.99557308996878, 60.715854475575114, 61.87332237920454, 64.59011677772769, 60.3157413390375, 59.16454922768378, 58.96579880868236, 62.721676134294086, 61.43658607236801, 59.65442580561484, 55.52868073986423, 61.3383306995515, 62.25934636208319, 55.83358618520922, 49.76472639268445, 49.924319790255645, 42.384641785775464, 42.98610587273875, 45.2167970134366, 54.84503123068041, 35.69335283771638, 15.139353563708646, 3.482673456591945, 1.1061217491665194, 0.4570600985279007, 0.19688444332249705, 0.1616557062633576, 0.16941276018417653, 0.14157382981671443, 0.02852116230755083, 0.6925759656775383, 1.5473638787384958, 3.8361773135200625, 7.398274108286827, 8.497007950659722, 11.099811407827563, 11.129665547801602, 10.226783002576521, 5.2907468618885165, 2.805151915357959, 1.051772039744162, 0.04492821840329036, 1.1991652726165711, 3.780866991127691, 7.732313448382963, 12.635996899297162, 12.288906362748916, 8.248351254770833, 8.954769142212408, 5.875253562004336, 1.7498930111046762, 1.4681578643860356, 0.3974424621030208, 0.034181230566314155, 0.12004004055333715, 0.1553086371671769, 0.10213591458816683, 0.05055522613768136, 0.0391666473249995, 1.206483189617434, 17.30465977422653, 31.904098103123328, 39.38514255708264, 47.13185894873835, 52.62354589277699, 49.35229701380576, 57.31948198810701, 50.88720283200664, 53.45417445705783, 55.659672214138894, 52.33312183810819, 54.77411085559476, 58.01506334735502, 53.303433848965554, 58.1422697344134, 51.71798044635404, 56.02449186386601, 53.6201338614187, 61.35891529821581, 54.09841983549057, 68.59814366986676, 72.0485193498673, 43.74174656406526, 61.98556492405554, 58.69759105866956, 55.08136972304314, 52.685578177052165, 48.49951882516184, 51.1541122774924, 51.79305461145217, 53.813973472964385, 56.89660733745944, 63.60114605196061, 60.30496266580398, 64.64543788663804, 64.38594564314812, 69.68929213862266, 60.9423517411755, 62.95899521919989, 5.446108512340054, 0.3540934075511271, 0.2995357818661198, 15.393818309230191, 82.88832664489746, 54.21712644638554, 73.83089142460977, 60.709880705802675, 74.39150794859856, 18.369324399578957, 7.0812446167392125, 24.66518940464143, 41.2028238081163, 57.181175293460974, 27.368785027534734, 41.36003240462273, 28.658897684466456, 47.68821577872, 33.47751179049092, 49.11279316871397, 68.65395899741881, 48.55803274339246, 1.3528202017468791, 0.26850554371072405, 0.02000565835905652, 0.017117081705721158, 0.17097358772110555, 0.03271420666527364, 0.2031755726784468, 0.16876869474447545, 0.15253556742062493, 0.21345278007849572, 0.24401023473230102, 0.14988219125136254, 0.15940973565222757, 0.1470685954536161, 0.3470668797531436, 0.4062684691481052, 0.20650568027650157, 0.18674888557964758, 2.139128311987846, 86.78768819378269, 64.9817144486212, 61.444419045602125, 46.47917655206496, 59.97380479689568, 49.83661559320266, 42.29641591348956, 50.42137822797222, 40.72556549502958, 35.51188830406436, 10.745658643784063, 10.839417999790562, 53.51577528061406, 74.71966912669521, 75.22641581873741, 55.99227743764078, 66.33203352651289, 32.96887451602567, 0.5039593883820119, 0.22102465522625755, 16.65227351650115, 78.21762315688595, 67.01511429202172, 69.29889863537204, 61.92988687945951, 63.944726067204634, 62.24666926168627, 68.30237342465308, 67.4720468828755, 68.1530801711544, 51.61377483798612, 59.936099052429206, 56.66106900861187, 54.878885207637666, 53.24785386362384, 61.648174408943426, 62.00107789808705, 63.81944164153069, 63.51144929086009, 66.2892718468943, 62.17564690497614, 66.78245498288062, 64.20327694185319, 64.84572195237683, 65.17612672621205, 62.47064836563603, 57.43996543269004, 65.05747502849948, 64.70939213229765, 56.74588634121803, 48.939408717616914, 51.899052742988836, 43.93564501116353, 45.29498161808137, 54.286666147170536, 64.81793588207614, 41.61786156315958, 26.290566652051865, 12.057886604339847, 3.443165137883156, 0.9871859860516364, 0.4498517321002099, 0.2998178860833568, 0.2911330230774418, 0.2847505607191594, 0.16979028831326193, 1.9922956103278746, 3.0356818677917605, 18.074466105430357, 19.04956929145321, 21.381339911491644, 20.168446956142304, 18.0089880189588, 13.568689457831846, 5.141078531742096, 2.8168623966555444, 1.137024387717247, 0.16210892387936193, 1.3380931726386471, 4.658634354991298, 9.046215280409783, 15.545520878607228, 19.82786363170993, 18.04858042347816, 16.08100579630944, 12.68440188900117, 6.9778308368498285, 2.5008419348347575, 0.4837943607520673, 0.2859484157975643, 0.19786140460881496, 0.35568855582706393, 0.3396394121791086, 0.1726785623618672, 0.1453619813846965, 9.481072771933771, 28.49550743256846, 33.78758691972302, 43.29837360689717, 50.786135119776574, 54.65099942299628, 53.32326143018661, 60.13928174972535, 56.53578066056775, 54.195584789399184, 57.522350895789366, 58.816740897394, 56.457403859784534, 60.53258957401399, 56.67005515867665, 61.35501646226453, 55.49503857089628, 59.83132077801613, 58.565513087857155, 62.82050809552593, 60.7731956051242, 65.94054960435437, 65.43809006291052, 49.802267397603686, 66.26205844263878, 63.52792716795399, 56.98272297459265, 56.335692713337565, 49.658842009882775, 54.22227259605162, 54.50994314685945, 61.06372556378765, 58.613754318606475, 68.18637324917701, 62.48615741729737, 72.8169979587678, 64.34554523037326, 74.30458822558003, 60.476719333279526, 68.44084878121653, 12.874249508303981, 0.2675421115371489, 0.38290526958242543, 13.260295064218584, 82.31917504341372, 60.512914965229655, 79.17546595296552, 65.91588574071085, 75.5488738706035, 25.45356227505592, 10.102521334925006, 23.992620591194402, 49.1575748689713, 68.73589731031849, 29.202618598937992, 48.781643144546024, 35.55801145492062, 57.790719462979226, 43.28555137880387, 64.31901039615755, 76.41412519639539, 74.75880653627458, 3.140604534456807, 0.513639644749703, 0.2339324400189423, 0.1469381000365942, 0.30784949059447936, 0.15734275382372642, 0.4762481189062519], [0.06861141672538174, 0.08940408486993083, 0.04410946576465522, 0.03494108636533061, 0.06465518546681251, 0.09886773753791087, 0.05152243512472318, 0.0487654532245811, 0.00932643770225226, 0.04900554134961098, 0.04378103238019732, 0.3011455164561349, 40.218626606848936, 59.24758972660188, 42.98725512719924, 33.40409678797568, 29.847095397210893, 51.51444081337222, 30.489246229971613, 14.571718938889044, 46.60422563552857, 27.586317716106294, 22.236104780627837, 0.3036670488936286, 20.698421924344956, 62.63242260102303, 65.72090471944502, 56.449076667908706, 57.261062206760535, 46.3243959026952, 2.4764173357717456, 0.06453426614884408, 3.8575186844794986, 58.29863894370295, 63.05666223649056, 57.616911395903564, 60.04785522337883, 60.3151176821801, 60.464187360578975, 62.315000872458185, 59.69481052890901, 52.90027303080405, 50.42223330466978, 52.773078410856186, 58.592855930328376, 53.56616989258797, 51.76289550719723, 51.008772773127404, 54.79406395266133, 53.607578354497115, 59.39062287730556, 60.160360567031375, 59.54818448712749, 58.80604067156392, 57.743635331430745, 57.94398999983265, 58.97061547925396, 56.622943570536954, 55.85746949718845, 57.10770930013349, 57.965504200227805, 48.481934839679354, 43.60780546742101, 41.964732446978175, 41.52741562935614, 36.228532791137695, 36.871377883418916, 58.389477114523615, 22.293398841734856, 4.060831310287599, 1.1679283745827214, 0.209212253591226, 0.0626131244784882, 0.16876095725644022, 0.042508154311367584, 0.13379377793640862, 0.08272550654627624, 0.1650866616757647, 0.3864227163214838, 0.6239010862285091, 2.543294482654141, 3.888450985954654, 5.4203684483805015, 1.5102310454653156, 2.8816584810133907, 1.6940081840561283, 0.19790041380591933, 0.2323322815279807, 0.03416866289391633, 0.060549559402129347, 0.31750921580579977, 0.8488528766939718, 1.1506844095645414, 2.6747475708684614, 4.132620490366413, 8.239532786030924, 6.001543095034938, 3.708770395286622, 1.1278237330336724, 0.215732581132362, 0.17115472154992242, 0.16132121695385826, 0.0942893892586712, 0.04835368862615959, 0.1258430952927278, 0.11840218287562171, 0.08158853247521386, 0.028824192216439597, 2.4154421302580067, 22.44481605868186, 35.478022559996575, 42.121709623644435, 50.18166257489113, 47.19054152888637, 51.858566038070194, 51.45757036824381, 46.261175140257805, 44.12895118036578, 47.84641673488002, 50.68971149383053, 49.943092253900346, 53.142408786281464, 51.59860703252977, 51.00923561280774, 55.53364646050238, 55.54399367301695, 55.97107702685941, 54.9310488085593, 60.81650249419674, 38.1409235923521, 47.98596289850051, 61.71856918642598, 54.739648911260794, 54.09929844640917, 46.24006102162023, 45.2034923338121, 48.09595008050242, 48.8022748116524, 45.46196476105721, 51.004669973927165, 54.21008971429641, 60.861492080073205, 59.771332048600726, 60.548800729936175, 61.996731911936116, 67.84670383699479, 39.182854160185784, 0.1554661295226505, 0.9677437164129751, 0.1921466185200599, 14.665503790301663, 37.28107729265767, 54.97200619789862, 58.82806870245165, 58.56407357800392, 58.32474623956988, 5.9629253995034, 8.220348473518126, 26.938634380217525, 51.502183406583725, 45.935324238192656, 32.009547102835874, 45.14075010053573, 23.737340973269557, 41.856157318238296, 37.95381869039228, 45.63563554517685, 59.71731708895776, 30.247169310046782, 0.5772523990561885, 0.03688450204208493, 0.014322694605066171, 0.051860662943293015, 0.06283212220296264, 0.1121226367690871, 0.08376522575535121, 0.041906147098709504, 0.21380026223919085, 0.03461295175516317, 0.07402009706223205, 0.0379720059854369, 0.03016761357655689, 0.018773815789890867, 0.13249872162217094, 0.033896337789032734, 0.05219787186492355, 0.07203067397518505, 0.502242891778869, 53.61598791614656, 70.14772307488226, 45.47224921564902, 31.88383709999823, 39.309534949641076, 54.41180936751827, 33.55084834560272, 23.809745965465424, 51.06773384155766, 29.026770899372718, 26.671805343320294, 2.3704307261974584, 18.784138579522413, 64.88748342760148, 70.7939806292134, 62.65693741460001, 63.452543135612245, 50.4960483889426, 3.5679850078398183, 0.09945927998952328, 3.6942213437249585, 58.75592847024241, 67.14295218067785, 62.88916134065198, 63.55572108299502, 62.44848697416244, 65.68867852610927, 64.07088125905683, 65.71458185872724, 54.88571405410767, 52.678839545096125, 56.03138346825877, 60.00548578077748, 56.024574233639626, 55.41937212790213, 53.116787864315896, 58.47475728681011, 56.75874387064288, 61.758122367243615, 61.77041115299348, 61.47917909006919, 60.40328079654325, 60.260169198436124, 62.488573597323516, 65.28851439875942, 59.051184884963504, 58.27490860416044, 59.854168584269864, 60.54239549944478, 52.99859900628367, 46.744297396752145, 43.50839299540366, 40.792304623511534, 39.48791650033767, 44.33953931254726, 61.699722197748, 26.303675213167747, 8.476709685017987, 2.374153055490986, 0.4861595499659739, 0.14473169020587398, 0.10339187743562846, 0.05073345266282559, 0.17598622358374058, 0.10368683660823493, 0.027209116078372446, 0.5334985436451051, 0.6333623946674409, 3.7768875014397407, 9.73840477005128, 12.57864792500773, 11.813273872098616, 8.243058016223292, 4.898188700599055, 0.9794066389722209, 0.9194364795281041, 0.07667281439587956, 0.2082195262154264, 1.0909046689348838, 2.1601921752575906, 2.779991136443231, 7.158069629823008, 13.86823106196619, 13.579106292416974, 8.09208010473559, 5.689683287374436, 1.628985460246763, 0.2277791605240876, 0.12805806998644145, 0.044184833494645935, 0.09154998141551211, 0.041214595699021896, 0.07653505646533544, 0.05816172845962067, 0.11287708781779775, 0.05508875061247138, 4.635668387336116, 27.893123549799768, 41.164623845008116, 46.901329486600815, 51.79701228295603, 51.42272403163295, 55.05021041439426, 49.475679089946134, 46.89211976143622, 47.50864967223137, 49.873666301850356, 53.31988819183842, 51.79245056644563, 54.222378500046275, 55.85675170344692, 55.72223401838734, 57.335065564801624, 57.90255015896213, 60.59083677107289, 57.5659284284038, 73.68981161425191, 52.0126602726598, 47.95814937160861, 63.77483252556094, 57.42036927130915, 56.73590390912948, 48.21109517928093, 49.08885494355233, 50.51901386630151, 52.445325159257465, 48.11052953043292, 53.52416523041264, 54.280660998436716, 63.96192566041024, 62.02655761472641, 62.87474270789855, 64.0338227056688, 70.95584900148454, 34.52022683235907, 0.143649407151726, 1.482880358253756, 0.3571121310514789, 18.171966421988703, 41.55562923800561, 59.485603071028194, 65.88107862780171, 64.5569452931804, 60.02856892924155, 4.627661358925605, 15.627146382485668, 29.76516296786647, 45.70865046593451, 53.62669990908716, 31.86151096897741, 46.02476996760215, 27.338435688326438, 45.16708489387266, 37.90671494699294, 50.80097736850862, 70.38969409081244, 43.991515251898, 0.8069565087076157, 0.04732313948953825, 0.04441755951472348, 0.01868524644974499, 0.17206268895777965, 0.09691909331107333, 0.03637038043610031, 0.2811697738305215, 0.2791166275499329, 0.1156258495945123, 0.16384789750220316, 0.2857088754254003, 0.16030829550037462, 0.10064483169586429, 0.34219646045277197, 0.15924475095685453, 0.23791335463043184, 0.11816072728364699, 1.220436163486973, 69.90078633831394, 75.85739966361754, 59.06144188296411, 44.408545570988814, 44.07614823310606, 71.09604235618346, 41.99968468758368, 19.171480478778964, 58.925421930128536, 38.52017364194317, 33.04398790482552, 4.520153605168866, 31.163809568651264, 72.28515594236313, 76.23337453411472, 64.89070369351295, 71.56223174064391, 52.67706663377824, 3.6562393173094723, 0.197366297305111, 6.595415434529705, 66.05817364108178, 69.66828392397973, 65.24816105442663, 67.90505301567816, 65.96988108850294, 66.92952033012145, 69.4982805559712, 68.33623916872087, 60.864735880205714, 53.29451437919371, 58.28661295675463, 64.3777008210459, 58.276783497102805, 56.07116806891657, 56.81603008700956, 63.17253297375095, 60.59901883525234, 65.26055966654133, 64.40163512383738, 66.37549338802215, 65.2024732866595, 62.98808743876796, 65.47862383627123, 63.01675604235742, 62.396899961656146, 62.93692404224027, 65.63991169775686, 61.09006820186492, 53.286332315014256, 49.34327556240944, 45.817802183089725, 48.26198008752639, 41.68231394983108, 47.673032283782966, 62.68216217717817, 34.77667139422509, 21.799927411540864, 7.130253161153487, 2.2211727740303164, 0.31912722414539707, 0.3830493553992241, 0.3308547125949014, 0.19638245654923303, 0.1618679892271757, 0.4069981525742239, 1.7261880443942164, 0.934797277854335, 10.812115361613612, 17.985128241200602, 21.068134730862035, 19.019831841991795, 11.587595401271699, 4.557519084022892, 0.8180357335555939, 1.0999228108313777, 0.13013209216296673, 0.5586250631078598, 1.7014011163865368, 4.071657297111327, 3.217416309541272, 7.060366820904517, 16.776016450697377, 20.187794047017253, 12.53588036183388, 13.58797771315421, 5.491584472117886, 0.22921805750698815, 0.24836409626708877, 0.3212863663511892, 0.27662172432868715, 0.13829834428766083, 0.2395726244656309, 0.2143354512630932, 0.17107227516751136, 0.14676223689269635, 19.9152873792956, 39.62577996715423, 45.46333759061752, 52.797628525764715, 57.38964926811957, 56.41677202716951, 57.20470166975453, 52.117163981160815, 47.82747168694773, 52.385920862997736, 50.487368183751265, 54.765516942547215, 54.83127940085627, 59.42088004081481, 57.05428269601638, 59.43544380126461, 61.18354220544139, 64.91915264437276, 60.74489570433094, 60.97400919083626, 66.7215641083256, 48.12812136065576, 53.99646958997173, 65.75611975885207, 59.389952152006096, 60.71015527171474, 49.83322666537378, 51.42216313269831, 55.0997656391513, 56.69171448676818, 51.22680164152577, 56.59935835869082, 56.74931449274863, 67.06130412317091, 65.25815133125552, 65.04251510866227, 66.7098597557314, 68.2049495943131, 43.896072218495036, 0.6324021494196308, 1.9415640422413427, 0.6072490313841451, 18.040068880204235, 51.048529917194, 65.67799006738971, 69.37554959327944, 67.29868596599948, 68.61347229250016, 12.910792270014364, 13.770879795474391, 34.924403544395204, 61.26904987519788, 59.82261311623358, 40.82258139887164, 57.46863795864967, 31.83815129341618, 59.94599127000379, 50.22006650124827, 61.60014106381325, 78.19648942639752, 60.926419073535556, 1.4826240558778088, 0.26950902696098056, 0.1556436014511893, 0.11274708269704735, 0.25312741647564596, 0.38800287991762167, 0.16669504795103304], [0.07808086867894858, 0.027589212517224015, 0.11310593360253882, 0.11848580137255693, 0.037801486304810936, 0.027626224140065814, 0.05422017544568066, 0.1223445556036407, 0.03042964054451835, 0.08493798379335674, 0.006996951537251834, 0.2441999027805944, 34.93408003161031, 64.41634401198357, 40.68731846347932, 36.8335230888859, 34.31447498260006, 39.106991598683024, 44.44522757684031, 18.473710436974805, 25.140021731776578, 24.16773480753745, 15.01604405141646, 5.579502438345264, 11.344126039935697, 46.70433236706642, 65.07755364141157, 49.78884504687402, 53.45921470272926, 50.59624925736458, 6.250142916556328, 0.03834011123305367, 0.49075632265979247, 38.67552303498791, 64.1770205959197, 59.590561774469194, 62.299130962740996, 58.805726881950136, 60.10696141950546, 59.90203718985281, 60.32950493597216, 46.277468665953606, 56.72097144588348, 63.61648644170454, 61.901794864285385, 58.92327639364428, 54.363183744492076, 50.518229392267045, 51.134406289746686, 53.12916686457973, 59.10900454367361, 61.28078560675345, 59.60166992679719, 56.576232064154844, 58.332355637704175, 58.97121167952015, 63.73555391065536, 62.25116429790374, 60.5754336234062, 61.70808861332556, 48.78973107184134, 50.16046608647993, 48.03267440488262, 41.33165405642602, 40.08176726679648, 36.19021123455417, 37.19869182955834, 48.98068774131037, 12.423188705598156, 3.8184903658205465, 0.28898852847276196, 0.4144625149426922, 0.04555952847905217, 0.061309813566866427, 0.13923186838867205, 0.06351674050693551, 0.04130868661788203, 0.5936442904414669, 0.6083730355866495, 2.0600920627194066, 3.4596246288668726, 1.7619835945867726, 1.6152934465677509, 1.4252595146817546, 1.1403800979737313, 0.47097887423249984, 0.17766539638321246, 0.19338942763786163, 0.06443745561785276, 0.04386073233739984, 0.07741077157158045, 0.13228110668639984, 0.38344002959709017, 0.6714779655298879, 0.26399540023938306, 1.825194796246867, 1.3460642868472685, 1.350883654048366, 1.5355586476864354, 1.7549179350176167, 0.3361939164178987, 0.10022715289866733, 0.06507525445833322, 0.09485214978696839, 0.01814735505068975, 0.03408916978045337, 0.03708840783445105, 0.03561225216535311, 1.3004061820045596, 9.474281187980406, 28.095961078520748, 40.48972514367873, 42.03194618225098, 48.41550557844101, 49.42861457024851, 38.700061382785925, 39.1004059391637, 45.69260404955956, 50.14682408302061, 55.235714989323775, 46.351828959680375, 50.01046288398005, 49.957820753897394, 56.54017763753092, 51.82333923155262, 60.32833214729064, 53.81758597589309, 60.21332825383833, 53.92132089984033, 30.379700314614084, 52.270540422008885, 56.90552288486112, 57.48893622429141, 53.720377875912575, 48.96503748432283, 49.868269120493245, 50.01893128118208, 48.74753421352756, 47.80350992756505, 52.28617498951574, 49.71194697964577, 55.41063700952838, 56.79224875665481, 60.422920103996034, 59.50365774093136, 60.34236638776718, 14.401806765987029, 0.019467916347146518, 0.15952808091477041, 0.8550367997057977, 16.470536378122148, 46.97307355942265, 65.37444176212435, 58.922644892046534, 64.64575167625182, 28.791838576716763, 1.8417033168577381, 21.341023829675493, 29.605451899190104, 47.10853261332358, 34.840825680763494, 32.885257428692235, 43.47453509607623, 23.173961139494374, 38.717249208881015, 26.409083027993482, 46.54246399479528, 64.91545384930026, 31.29187495477738, 0.312813587126232, 0.12973314421551843, 0.06570798179675495, 0.1079449141698499, 0.09172170002373958, 0.07461438210861338, 0.031631061762210824, 0.03543745771410965, 0.05555172435819142, 0.07801134619982013, 0.1261362848022292, 0.07188612850563181, 0.08256671184133138, 0.021772778052235806, 0.1163163246406663, 0.032799112189921646, 0.02717310420027183, 0.027000029616418387, 0.11363194489310827, 47.23312277947703, 73.7070151298277, 42.235011208441954, 32.22252788082246, 44.012452863877826, 41.76631935181157, 40.45382368949152, 24.47864736280134, 24.5050056903593, 27.80929465447703, 14.535099690960301, 9.572513026575889, 17.10288913019242, 49.6257136714074, 69.939711939904, 54.95386523585166, 60.48943565737817, 58.62776110249182, 7.6559174445367635, 0.044730893306193814, 0.45008664530131126, 37.913418277617424, 70.22801399230957, 62.79831924746114, 68.07905720126244, 60.25628212959536, 65.28194835109096, 62.54868784258443, 59.93176875575897, 48.35607774796025, 61.040018758466175, 66.55598517387145, 65.87836434764247, 62.400249665783306, 58.33461492292343, 53.1929563706921, 55.98072997985348, 55.91058231169178, 60.41263564940422, 61.94040667626166, 61.575689008159024, 61.513162505242136, 60.04760811405798, 63.87905774577972, 67.20984428159653, 63.99450878943167, 64.65793063563686, 62.78130008328346, 53.42344268675774, 53.254329696778335, 50.336254950492616, 42.97619012094314, 43.01990101414342, 39.68722389590356, 49.621116653565444, 50.200509563569106, 19.317033752318352, 4.071919115320329, 1.1748779565095901, 0.29047274721726296, 0.22649686723466844, 0.025536026017019348, 0.05413379903221804, 0.06699448856975763, 0.19054578587172494, 0.5307348661365048, 0.7592360338857098, 1.0215834564258977, 5.558556981625096, 13.572508865787139, 15.931146740913393, 12.031164476948401, 4.690771804701898, 2.6891041811435454, 0.22379262282723383, 0.6596448488773838, 0.1072510376933121, 0.05171346297908214, 0.2978672730105539, 0.9171743138182549, 1.0146493801186163, 2.3636462515400303, 6.808482504660084, 10.878741721953116, 10.799450028327204, 8.926929139321851, 3.576125396836189, 0.9672592424096601, 0.3170505130002576, 0.08308673998521221, 0.09614692264867407, 0.09068544353208235, 0.062297737571380796, 0.05531047560995626, 0.08702929657433303, 0.12763306738868838, 0.916692965453671, 13.057821335331088, 35.779546922253026, 45.42537689208985, 46.44632670187181, 51.19030006470219, 50.90188426356162, 42.318287049570394, 46.2901222321295, 47.027712175923014, 50.32000457086871, 59.008450661936116, 48.38153785274875, 50.79464274068033, 53.67270146646808, 56.815696685544914, 55.71167499788346, 61.874326505968654, 54.306015199230565, 61.643714674057506, 67.17021265337544, 35.75104698058098, 50.990710258483894, 57.983884426855276, 61.98791050141858, 57.48251530431933, 50.13130326424876, 51.481555661847516, 51.73026138736356, 51.76134617097917, 51.20230251742948, 54.81425239193825, 53.48990332695746, 60.551189453371116, 60.90858405636203, 64.141699652518, 63.07378730466289, 63.014685030906435, 13.938740568776286, 0.23522237886584577, 0.3998246278253294, 1.390011747998576, 20.791821402888147, 51.55217793680007, 67.78021181783369, 63.951876548028764, 69.58895790961482, 27.6371104486527, 3.7095127038417326, 24.871459007263187, 33.61322972082323, 47.61085487181141, 45.071159408938506, 36.339833967147335, 45.97467345576133, 25.07812869164252, 46.23191033640216, 27.997564500378026, 52.651720277724735, 76.1069957671627, 38.227207891402706, 0.3671966060515373, 0.2422752907319415, 0.1238821630155848, 0.10997582091799668, 0.15025374389463855, 0.06035631755366922, 0.0669613169626363, 0.17602265872541936, 0.23267708238094087, 0.2719731334476702, 0.21514549731246888, 0.2454433554122525, 0.14206535182893276, 0.14929118506129713, 0.287855668293853, 0.3831655862590959, 0.21939308713040045, 0.13357699037559573, 0.3461374618834065, 60.68788405387633, 84.14745453865298, 56.038800670254616, 54.20878356502902, 48.54648136323499, 57.635507352890514, 60.16302777874855, 26.337633132934574, 32.46063928450308, 33.92382652528825, 24.830076040760165, 13.110421299934389, 17.236638030698224, 55.099451849537516, 77.32191854907622, 61.026902352609945, 67.28789944802561, 62.604922863744925, 7.755827076973454, 0.2111895571673109, 1.9987343035397993, 48.530752658844, 72.65401563336773, 67.74871518535, 71.51216660776447, 63.032170957134625, 70.13863886556318, 64.92565593411847, 66.43808657123198, 50.69942328237718, 62.95133090788319, 70.48000274165985, 68.76503267595845, 63.71332191651868, 60.53449584591774, 54.64579051540744, 58.89548247860324, 60.438782168972885, 64.93156694596814, 65.98858294948455, 66.30000345168575, 61.44849438821117, 61.67264999881868, 64.39967393875122, 69.1510566588371, 68.23443797326857, 62.67272495454358, 65.72825916351812, 60.19989805836832, 55.12997181184831, 48.99808737539476, 47.813821838748076, 43.40870203510408, 45.27036874525009, 47.82409844859954, 49.136707859654585, 33.02236387806554, 15.066679889155974, 3.2964653065127716, 1.1445352363009607, 0.2955592952428326, 0.3202635163982069, 0.149427073737306, 0.2822670875297439, 0.3724893543028063, 1.534838402463544, 2.431842295392867, 3.9691993498033096, 12.941384796173343, 22.656920186934933, 22.666604518890384, 16.930953994874034, 5.7000015724089845, 2.1231299446475123, 0.2879737377647431, 0.6028260074315533, 0.2406040239598482, 0.12000967282801868, 0.34601381529242764, 1.5820918087997746, 1.1426672075063953, 2.226645951309512, 7.145968627545142, 12.987245148228062, 14.515999709406207, 12.112934127930673, 6.7841628289991815, 3.4066115896548, 1.4953827906039454, 0.29625193065693306, 0.16973373570269154, 0.1210154313594103, 0.16951448133876248, 0.1796232872912961, 0.17956618309742023, 0.279244227154601, 1.6715220938767157, 30.81280842904122, 42.30420574065178, 50.365225576585345, 50.919468249044115, 55.25205950583182, 53.94920502939532, 48.33471259763164, 49.03012137259207, 49.63708070016677, 53.20757112195415, 60.61529274909728, 53.24644965510215, 55.342450526452836, 58.40790048722298, 61.80266872529061, 58.28684437659479, 64.87173511135963, 57.10885070985364, 66.89388167473578, 57.02027966899257, 36.450507563929406, 54.41805770320278, 59.19597917987455, 64.55506647786787, 58.64754946001115, 50.830218638143236, 54.67320788291193, 53.65843188378119, 55.883070807303156, 52.02026574842392, 56.52974805524273, 53.51750504586005, 59.95527552020166, 61.03329189362065, 67.39680797823014, 65.86897419344994, 67.54703475582984, 18.574917393345988, 0.4074270085942361, 0.6717087724997152, 1.8729658328717755, 19.709004048378237, 55.02189090175014, 75.5734435973629, 72.58719413511216, 75.44163627009239, 37.876799029688684, 6.401512574764991, 30.21964799973273, 39.9786050088944, 56.90370682747134, 45.44062706731981, 43.6209414851281, 60.118042115242254, 31.685137671809045, 55.46782908901092, 38.79003270979851, 63.453841440139286, 81.26103724202802, 56.95912207326582, 0.44276918795320297, 0.43142535633617835, 0.2608237655893449, 0.17339551340668433, 0.2818713877950945, 0.26033641109543465, 0.13599514690858705], [0.03766514180648712, 0.0023223483801684194, 0.15604676288222114, 0.03733790351919109, 0.10368105264440661, 0.059516099131395744, 0.05226943213793059, 0.07837149179390362, 0.04470570050480385, 0.06179267495510079, 0.11296857403771532, 0.11295881407755999, 35.2155650046564, 61.16750755617696, 42.5231328318196, 37.80394492610809, 33.04918896767401, 43.76664576991912, 48.40420915234474, 26.456631960407382, 19.035115357368223, 27.02816640177081, 17.76871342812815, 3.666253128359395, 31.16244262264621, 58.52195516709359, 66.13102774466238, 44.534912570830315, 53.92877340316773, 57.77807374154368, 10.981680404755378, 0.05013349473536496, 0.2004755570763542, 17.715459408298617, 60.35550240547427, 56.03665121140019, 65.20013163166662, 59.344244772388095, 62.33196120108328, 58.06044909261889, 53.849078686006614, 50.74615832298033, 62.522949249513694, 64.06093412829985, 65.23383655855733, 61.9149975622854, 55.84447860717774, 50.288139235588815, 51.7090884331734, 54.49772496377268, 54.64683386587328, 57.84955501556397, 60.07799079341274, 60.591197629128736, 58.09620934147989, 58.15137747795352, 58.566493680400235, 53.67059515368555, 60.766625635085575, 65.70039856818416, 70.54183498505624, 46.7117025006202, 36.12408007344892, 42.29589816062681, 38.11766785960044, 26.684668756300404, 32.14176824015956, 33.038422061551, 2.2200482795315404, 2.0102675427352232, 0.34144195577790665, 0.2637902418932607, 0.16638444526301277, 0.037573697721405376, 0.13826497349767916, 0.25854866831533374, 0.6810061381228509, 0.9962567122232531, 5.79014205163525, 7.424053886244375, 4.483933948701428, 2.1259055118406973, 2.6627313898455713, 0.89603862214473, 0.519055886374366, 0.31169899048343785, 0.06919465478389494, 0.1262278476309392, 0.175318761818832, 0.03880697287498944, 0.1915395244835846, 0.07405055671810143, 0.006504701741505415, 0.14663659847311436, 0.2486774262281195, 0.5909990194824435, 2.105127736445396, 3.4420185800521605, 4.206943031280272, 3.497082038271812, 5.1968948398866965, 0.5508149499374052, 0.08934200110454714, 0.07728298810581047, 0.03311703484805842, 0.15364250318417627, 0.049049939975262656, 0.11766928188022106, 0.08021807012658927, 1.9154650814110235, 22.631942533677627, 38.925103449052386, 38.04822621806976, 48.092619988226126, 39.56112361723377, 46.19634620604977, 51.76149914341589, 45.24286116323164, 47.46221273176132, 55.66992136739916, 50.74473058023761, 43.01591980841852, 42.635712700505415, 50.928917238789225, 53.47488849393783, 57.21777100716868, 52.17121424213533, 67.24737351940524, 32.46177677185305, 32.63873057980692, 60.20467942760837, 54.2453557445157, 55.93114337613506, 52.3305566080155, 47.93487010463592, 49.925586715821304, 52.583012119416274, 48.85732919939103, 53.87991636030136, 54.974959742638376, 54.100934074771025, 60.49408366603237, 56.20457180084721, 61.21203038000292, 59.94390456907211, 49.203007682677246, 10.829718958946968, 0.07453099343805544, 0.4364097695196829, 2.4609685905518073, 56.655636525923214, 61.107424689877426, 54.95999197806082, 55.96646039716659, 60.545078400642645, 27.91661854713194, 2.801510730097371, 31.91226055545192, 37.77991256406231, 63.13124610531715, 34.67490157773418, 36.80811005253946, 34.35590305636006, 26.22888149753694, 41.7163562005566, 35.20789677096952, 44.03967019050352, 68.8808524224066, 21.978281505646247, 0.2795472915374464, 0.07270739008221896, 0.09997214521131209, 0.07381015832746222, 0.009734129585746315, 0.03790747839957476, 0.0075423218696678606, 0.023109417619003404, 0.08065252624932798, 0.05834183573061901, 0.030533441627818732, 0.013417939978441405, 0.029094544644918174, 0.027702620343094873, 0.06992037753544508, 0.011528318995730051, 0.04221408380075328, 0.05188965171034779, 0.06514319879633766, 42.98201484064902, 72.9566421816426, 45.281520043649984, 34.84810167743314, 41.089851702413256, 49.60146557900214, 39.18334445645733, 26.65623941729146, 21.70866954711176, 36.160781691151286, 26.339545288393577, 3.8502733313268234, 32.12327426479709, 68.82782197767689, 68.19818742813604, 50.945548088319846, 60.312991757546705, 62.737189108325595, 13.101177254030782, 0.03210037488550429, 0.36182933276699436, 20.57462211578123, 67.36852768928775, 60.06005379461474, 67.99208256506151, 64.41986630039831, 65.77300164007372, 61.22094592740459, 56.06512761885121, 53.47941490911669, 66.05236068848642, 65.26906728744507, 65.78397250944569, 64.98617026113695, 60.67952548303912, 52.79043882123886, 52.819629100061235, 56.25861029471121, 59.21455944738081, 60.8481599438575, 62.8142362256204, 64.3053448584772, 60.30600601626981, 58.39404275340419, 60.782189599929325, 54.09581538169615, 65.5079710099005, 71.00958547284527, 67.67131113236951, 50.13562963854883, 39.55434183920584, 45.912884358436834, 38.384702820931714, 39.12579151891893, 48.59137681222732, 36.95331227394843, 10.757399278302348, 4.1556041086873705, 0.4121639140911641, 0.47903324687673204, 0.26905492068298403, 0.11014226118042586, 0.04544276518807296, 0.1391053106635809, 0.2515934326595837, 1.2870400927720533, 3.3853346926550714, 8.093734364355765, 9.741739765290292, 10.453908827997024, 11.947269881925276, 7.904024518305256, 2.214580250363196, 0.7654624288120578, 0.11451065540313722, 0.24513849838366433, 0.2975689583728391, 0.055792988428185065, 0.29052634272844563, 0.2872036661832564, 0.2668519888914401, 0.5851313988527944, 2.9752150995116082, 8.665611032516725, 7.65970939590085, 8.082615915806063, 4.825790082254718, 3.626629099730523, 2.071627017951781, 0.07159395023219048, 0.04033518038810261, 0.042551442109529054, 0.032505018696669614, 0.08098399717240565, 0.054470839414505236, 0.04512926285725929, 0.05099237888991352, 4.079829800513483, 30.94595524572557, 45.8652550174344, 43.65589764810378, 50.222533672086655, 47.842812076691665, 53.71991895860242, 51.95192629291166, 44.440901202540246, 49.3047421978366, 56.78461974666965, 52.31920134636664, 46.76020653017106, 40.7349556492221, 53.989672122463105, 55.738609913856756, 60.605996731788885, 51.19820364059941, 72.55320287519886, 43.481713033491566, 34.801264655205514, 62.90265821641492, 58.498801415966405, 59.65163307805216, 53.99143718904065, 50.784844659989886, 49.54845474612329, 54.897657671282374, 51.76679042077834, 56.76939310566072, 57.948175168806515, 58.05875070633427, 65.271569759615, 62.78651683561264, 65.05587077909901, 63.69170181212887, 48.86822162135955, 9.630772971337842, 0.06897645762130138, 0.30760792775019524, 2.6385102637352484, 56.35047612651702, 59.29203018065422, 62.59736445642287, 61.00043419868716, 65.38039199767574, 29.125530296756377, 3.6660148443714267, 35.32064530157274, 44.04906818943639, 69.75899265658471, 43.251552274150235, 34.36627772546584, 38.21031032070037, 28.25231459832961, 44.747328527512096, 37.76778067311933, 51.20984915764102, 78.6419451621271, 26.340669047447946, 0.32574355782520387, 0.15720433705756742, 0.18502190889370057, 0.08580007019542879, 0.12041234396277897, 0.04959997195269793, 0.05122623488967938, 0.14250297189479874, 0.19156172571163024, 0.28179511608135316, 0.09300128902278601, 0.220196912545831, 0.12692538600775505, 0.15360611400777294, 0.17991806260280072, 0.09127995074396172, 0.1947896525023445, 0.25371290683265657, 0.2593900167172955, 54.87958338952834, 82.88597322279408, 55.596376926668235, 55.82969911636845, 44.61207343686012, 65.69002782144855, 63.89080524444581, 37.457709466257405, 28.278363058643958, 39.49004242497106, 28.803952816993963, 8.830756545066833, 40.01927998758132, 72.32550928669592, 76.7455654759561, 57.67730020707654, 65.54840280163673, 67.94431594110304, 13.8783811753796, 0.2379672718985427, 0.5273430578170285, 29.65124360976681, 72.55051212926065, 63.623495717202466, 72.6862104477421, 66.2533272466352, 69.53528419617685, 63.9098758082236, 58.3876375229128, 54.52560909332768, 69.89632268105784, 69.21118659357872, 68.18114080736714, 66.85390487793954, 63.823328710371456, 55.04882581772343, 57.27319017533333, 59.390042366520056, 60.11883443401706, 63.00440842105497, 66.91224621188256, 66.27268806580575, 62.101365058652824, 62.56076482034499, 60.344849248086255, 59.11655118388515, 70.07570835851854, 64.0126536738488, 56.84016443067982, 53.884109374015566, 40.93405123679869, 47.384130108741026, 43.66475828232304, 42.99624127726401, 40.986293285123764, 44.29105489484726, 22.900220886353527, 6.605972493848493, 2.8980147646319483, 1.6296192907517957, 0.6633460954312356, 0.27875717909586045, 0.21986657543288124, 0.5491046126811736, 1.819617798732173, 2.5014347030270487, 14.244789385026502, 17.200377679640248, 17.388329813557288, 14.418935756529532, 17.884572398278024, 10.632283514545811, 1.8146645806489454, 0.7070665494088204, 0.25150366247661654, 0.3829766383334514, 0.4790361273673273, 0.16241750409526212, 0.41501982858584774, 0.18807599501263714, 0.16353579328185128, 0.48757362570012774, 2.6477805404893817, 10.785423632591002, 12.404315240921514, 14.596597552299501, 8.241022306103861, 7.07413875287579, 7.943414430464468, 1.365663022283585, 0.10501914777823033, 0.15697633396954308, 0.06322006146693904, 0.2818497534721129, 0.22343285261623322, 0.17931320554306432, 0.15000494918034923, 13.960066495403169, 44.622267676937966, 46.19388687995173, 49.606054752103745, 53.65142653065344, 53.544235998584384, 56.77703388275639, 54.20994850897021, 46.477270280161214, 50.63677126361478, 58.771798379959606, 55.51201066663189, 49.577868600045484, 47.47494474534066, 56.07518065360285, 58.098143069974846, 63.30958450994184, 55.665712664204264, 66.76848350032684, 41.397549875320934, 38.43453653397099, 62.64814738304385, 60.110636680356926, 62.223954816018384, 56.20667419125957, 52.11401824028262, 53.105895442347375, 58.78271433614916, 55.22312025870047, 58.38770420320573, 59.91015257373933, 57.79274340598815, 65.21732338013189, 62.8651995812693, 69.75816111410819, 65.32562002058953, 55.69610318829937, 15.504101630180115, 0.11449246081493555, 2.023652018077912, 3.1751667443783056, 61.40174365812733, 70.95029492532053, 66.8016432177636, 68.03016093469435, 68.50486186242873, 36.202766741475756, 7.345282887258838, 42.00440722127115, 48.47493733129194, 76.53370257346862, 40.520139201994866, 47.97290925056704, 51.32738690222464, 37.74981621773013, 56.28059517952704, 46.72361081646335, 62.10500501817273, 89.17241865588774, 43.694760491771085, 0.6959022581577302, 0.2074477079534723, 0.31979166752388405, 0.4045351492541452, 0.3874601832320614, 0.11859385807427669, 0.1737707432719969], [0.01937058296114687, 0.08744842327770688, 0.05518083821140951, 0.09292580637960665, 0.05451699621194313, 0.01415431135213904, 0.06933907001850105, 0.15848211042823332, 0.13968399815982388, 0.07757128997435493, 0.05692887848483459, 0.3547561042491467, 26.78399689735905, 64.61957770009195, 39.6916953979, 38.94710010097873, 40.63753181888212, 34.0587168355142, 50.50374015685051, 27.68918383506037, 22.46323354782597, 21.634097445395685, 45.78696450879497, 3.6727794620298573, 7.194211819479543, 59.167514539534054, 66.1717733260124, 53.957524376530806, 46.83966590512184, 63.85241700756935, 11.249718512258223, 0.304481155209003, 0.3482687184887548, 4.21000934416248, 53.89396236788843, 61.42462284334245, 64.62443359436529, 62.08997841804259, 62.73746367423766, 56.299147990442094, 50.17766567968553, 55.013771595493445, 63.91287249903526, 61.53675948419879, 63.32066520567864, 60.91442446554861, 59.2015685573701, 55.21360066629226, 53.084483223576704, 50.62645543006159, 52.686880403949374, 59.04138680427306, 61.3380600560096, 58.18429793080976, 59.37721621605658, 49.76455380839687, 56.66122590341876, 62.16222455424648, 53.17020662369267, 47.84682073900777, 72.68036611618535, 96.98625072356194, 60.06270923922139, 34.68890443924935, 27.277962546194754, 33.3487952909162, 35.77110205927203, 21.77499878791071, 3.169211115567915, 0.4863112660184984, 1.044842682538494, 0.616427009865161, 0.5312281041856736, 0.023454080576137192, 0.041122098243044275, 0.5888283553142702, 0.8968425241689529, 4.883582284373622, 24.090069916940507, 17.65393703214584, 4.993818536881478, 1.4556902430711256, 1.8688710009859455, 1.5135198302807347, 0.23583783858245422, 0.06081278721291212, 0.10532053442852152, 0.3421743051900018, 0.04332433672501676, 0.04631946854774029, 0.009507674952938912, 0.03622693813315803, 0.13124235274810947, 0.10722197997834414, 0.3006701435773604, 1.9714170790487722, 3.3577383670114704, 4.489765042258847, 6.456123734674146, 13.60437616225212, 11.093582683993924, 2.802963968246214, 0.07596655793848538, 0.040276544018378185, 0.06781838548880431, 0.04529672201662775, 0.016100889056800835, 0.03008300108053992, 0.09524528312707141, 1.5155814035284905, 11.97915384846349, 32.05638608624859, 40.31914910962505, 41.40331968184441, 52.514660896793494, 51.08691815407046, 41.23931754019953, 43.235043018094956, 49.85551749506305, 53.80696027509628, 59.95247102552845, 55.81937936044509, 43.10412214648339, 44.30930568325905, 49.90215447641189, 53.15213626430881, 59.60769468738187, 48.78262765945927, 27.831730611862678, 52.52130146949522, 56.12337873828027, 55.99827474163425, 53.48354124253797, 50.43274525673159, 49.145623407056256, 49.23779126136534, 50.10307788848878, 54.20154286969093, 53.35690359915457, 59.86956388719621, 60.21290856022989, 61.903277520210516, 60.130554476091945, 60.83278033041186, 58.2917316498295, 39.770680166059925, 2.1454335220398444, 0.1035559504863716, 0.6162923009645555, 7.315287051662323, 56.246035175938765, 54.88661619924731, 61.53501010710194, 44.845513297665505, 63.868381054170676, 17.024647651180146, 4.804872572422028, 49.23584576575987, 27.11477625754572, 49.04726213024509, 29.620409857842233, 41.17866985259518, 35.34759198465655, 26.820549464994862, 35.26552031117101, 23.566358973903043, 47.78878534993818, 69.31754558317124, 14.67992046187001, 0.33691042313171976, 0.26895897583134715, 0.06491695771053915, 0.12678572051827947, 0.15477976070777064, 0.019895452780709155, 0.02927917374988958, 0.07654554420901884, 0.08003659155820647, 0.07052615390069063, 0.07668764585809362, 0.05280927131553331, 0.06569663603459636, 0.13627951874607994, 0.2599918860341272, 0.0807912341288982, 0.14920542917905316, 0.18843820138323694, 0.1660793737298058, 27.166355425311675, 71.46328603067707, 46.98963380629017, 30.83051204681397, 39.88174207748906, 43.64243607367239, 38.66274395296651, 25.994280615160545, 19.37727939698004, 25.260932714708392, 59.03551893849527, 9.300102456923454, 6.935641332980126, 61.39628764121764, 68.12767105717813, 60.677074001681426, 48.964472663018014, 72.5176191329956, 12.317428858049455, 0.24716739032057025, 0.45865622739638057, 5.347330973994348, 61.23181089278191, 66.30956619016587, 68.6900604924848, 64.32148541173628, 64.72314788449195, 59.76184383515389, 52.01012642152848, 57.657398100822206, 66.44398581597113, 67.40296609940069, 65.47324234439482, 62.74784226571361, 62.47311945884459, 58.60509764763617, 55.941172876665675, 52.2510423198823, 56.189627570490686, 61.021854262198175, 65.15895066722747, 62.52325519438713, 61.448568913244436, 50.49242804127355, 56.35819927338631, 64.53798455576744, 53.4228386417512, 55.93335951528242, 77.38732799406975, 89.8517417907715, 55.75956321531727, 36.006197160290135, 35.196780773901175, 48.40360118496803, 48.61682907227547, 31.039644979661514, 6.423384691438367, 2.8793866932392125, 1.8205298723713046, 1.1137294312638621, 0.2507192497291873, 0.049727824366381096, 0.28863536193966866, 0.2058487139161556, 1.700129778154435, 3.763738245733323, 25.27592009113681, 21.665880410901963, 12.832132077986195, 9.545436905276391, 9.064413116824243, 5.212333288884932, 0.9846531155128634, 0.19201328857771813, 0.005526557328149436, 0.43137041251024894, 0.06888209091078851, 0.05757831420088488, 0.027147135734858534, 0.1141311967324826, 0.16146813729597678, 0.2304740433370875, 0.9330517005535864, 4.044246793754639, 8.419851987592637, 11.001125554884634, 11.28268015000128, 12.312903423463146, 10.725783994120937, 2.4938905142968704, 0.04694862591643487, 0.011029947199858727, 0.06079874099082044, 0.038201587214585275, 0.11898193523407945, 0.04171362154245858, 0.09658412902706093, 0.7880910726324205, 19.988178745392833, 37.40985262778498, 44.18673946011452, 45.00772291614164, 59.49472258167883, 51.033550385505926, 41.57752783067765, 48.14313227130521, 49.92793229318435, 54.57541927214592, 58.92778711934244, 61.39924903069774, 50.06049663789811, 49.04062155754336, 51.32698682046706, 53.77626380612774, 62.033853223246915, 57.27113093099287, 34.48714556232576, 54.24116273080149, 57.21684532780802, 60.40117840613089, 58.246742063953036, 52.9999130002914, 49.94333544085103, 52.64544056307886, 52.61689355296474, 58.34762150241483, 56.25058904770882, 62.363457833566976, 60.95553874969483, 64.20456740163988, 64.73286359540879, 65.67073368257093, 63.70242557217998, 40.74256504735639, 3.5045002208602045, 0.3084913803444755, 0.5816265159556943, 9.340426383479949, 60.384425963124926, 58.80535817915394, 70.14456948926373, 48.958769536787464, 66.43493298561343, 15.53812328846224, 6.1140195112074585, 56.48711189146965, 34.40648594210225, 57.085830319312315, 35.499038619379846, 37.96162812940536, 39.30122344724594, 30.684639100105535, 40.320482715483635, 25.123620340901038, 53.800778619704715, 76.83854133852067, 18.636025959445586, 0.21751634025525665, 0.09667574548192563, 0.06016882902552044, 0.2309885020217588, 0.09318077576256568, 0.0287672259183901, 0.04029352052678024, 0.1934828443993484, 0.13385815996556513, 0.2645336536149825, 0.12727694375620735, 0.2016280903931587, 0.27607075389354463, 0.21327567587216056, 0.3131810948252678, 0.32928015676236927, 0.4278970005050783, 0.36458562518800464, 0.4220640989801576, 42.32903042147237, 90.24858367058539, 54.613603545773415, 53.164385826356956, 50.62467467400336, 54.73149038130238, 66.65239703270697, 36.939050536001886, 31.62024597967825, 32.00394595822981, 58.58368935123567, 11.208409090195934, 14.265928018477656, 69.08868312835693, 74.37595182849516, 68.09469961350965, 55.31653542672434, 78.41531061357068, 14.985452505850024, 0.7726156675527174, 1.0100087871955288, 10.768986940383913, 73.03532492729926, 71.39129484853437, 72.5301314938453, 66.41780007270076, 69.56071684437414, 62.11961584706461, 55.042867737431685, 60.178991825349875, 69.89004688878214, 68.72171401977539, 67.35678411299183, 66.1973471795359, 65.99378401233305, 60.82257824559366, 57.999287574521965, 57.41064571565198, 57.85670157401793, 62.76848177756033, 63.921921407022786, 64.57886742007348, 65.14910159572479, 57.02946193756596, 60.82699875677786, 64.32174821053782, 55.72362253742834, 63.74262594407605, 80.61143782831009, 80.5411175758608, 52.652795007151944, 41.80694726205642, 36.17835783189343, 43.87935899919079, 51.1307074946742, 45.478426948670425, 19.033915112095496, 4.927285823129839, 2.2800259772808324, 1.1909561195681173, 1.1281817718859644, 0.1405254538140951, 0.6161915450807541, 1.1168314131998247, 2.346636893287782, 16.89557029354957, 44.58494632474838, 40.55540130984399, 19.739816227266868, 12.685746281377732, 11.222913034500616, 4.971142824619047, 0.7580609162968974, 0.13377191378704964, 0.342697941608006, 0.587318794381234, 0.33778155703217755, 0.19994743138311372, 0.15013619536353698, 0.1666704105633882, 0.24272286994082315, 0.21571303056853436, 0.5101940264144252, 4.601033368418294, 10.403956463260036, 18.05079067907026, 26.66708477081791, 32.627128208837206, 21.427159078659553, 8.274167314652475, 0.2769680880010128, 0.165368490101349, 0.1309471637491257, 0.12329302608005463, 0.277570570188184, 0.1118114058889689, 0.2132520190770588, 4.2629618317850175, 36.245610790867964, 44.20099727569088, 50.31905535728701, 50.45783273635372, 62.899587000569994, 52.63070814071163, 46.14694395372945, 49.8707559031825, 53.27756581767913, 56.81513578661027, 62.310937296959665, 64.14307640444848, 55.63890718644666, 54.858614398587136, 54.76792527783302, 58.71201361379316, 60.52431729532058, 59.46097843108639, 38.37850155368928, 55.804129185215125, 60.886481500441036, 62.93908526820522, 59.61228386048348, 55.75558593196254, 53.837758725689305, 54.4808626944019, 56.59197645802652, 58.02401027371807, 57.27969738744921, 63.89330379424557, 65.35982701086229, 66.49953442235147, 67.53442825809603, 65.52085207354638, 66.75791663508262, 47.254468317954775, 5.881599466646872, 0.6226351412553942, 1.8052416991802955, 8.929140375506494, 66.74832251764113, 67.99543226918867, 70.63573652698149, 57.15424822222803, 74.4637736966533, 25.477535801549113, 8.597166653602354, 59.30577808810819, 40.30603270376883, 59.74108665220199, 33.446823166262725, 56.38117651785574, 52.03649259382679, 37.4473112629306, 49.0504627843057, 34.518991285754794, 65.23520938811764, 90.5059931355138, 29.881500467177364, 0.6515898940063293, 0.4053064159327938, 0.2224369536364271, 0.3759410400544444, 0.3303692579990433, 0.10927044546171542, 0.1124645647923312], [0.16288952150892827, 0.03485718824630303, 0.11181336707405506, 0.02321987983680541, 0.03257975823456242, 0.07475961705729847, 0.08224505450456374, 0.03143531863667792, 0.055328562945848515, 0.17012675412960593, 0.05045018399194364, 0.12463466820096779, 8.379741830210532, 60.18140800537602, 43.972307405164166, 37.1886387948067, 32.65227060164175, 32.96599549631919, 50.95556189936977, 20.57867196298415, 29.655518993254635, 28.973714959236887, 34.99825785236974, 14.031837044223664, 3.6027582903062148, 51.53348392055881, 67.5473956138857, 65.14298269825598, 50.98530523238644, 61.66105547258931, 15.853232779810506, 0.31237636542608666, 0.23628319613635543, 1.1399776873088654, 42.73014376240392, 60.1921082312061, 67.87086563725626, 62.909428227332334, 64.65476920527797, 57.05081139841388, 50.433851365120184, 58.89733383732458, 64.68225325307539, 63.20382956535586, 68.0156324755761, 65.08718698255478, 62.39200876605127, 56.409982404401234, 53.3218179979632, 52.33536543384675, 51.040877372987815, 58.336313309208045, 59.607141633187574, 59.29046907732564, 57.96419412859025, 52.12480083588631, 47.590886085264145, 53.75680885007305, 58.96831304796281, 46.1149021117918, 35.67665530789283, 41.979978699837964, 44.828505900598344, 39.666333352365804, 41.18101150758805, 41.92136279998287, 38.15108645346857, 19.93334597156894, 4.925895833200024, 1.5333274319287271, 0.8235695237113584, 0.15720994482117315, 0.1072285759953722, 0.3069777744671991, 0.4175427399816052, 0.9455761349489613, 2.0734599905629314, 24.10661643551242, 39.808150568316066, 27.69288851368812, 9.894647482902775, 3.076346795405111, 1.4167022512805079, 1.1217803411906766, 0.563133888907971, 0.1650973102979122, 0.3029695718038467, 0.5466734173317109, 0.2946532277330276, 0.07259600089802858, 0.07717607287509788, 0.029783322806319887, 0.1789765558656185, 0.42853784837549735, 0.2150347516421349, 0.9037701040506364, 3.2078513647279436, 8.86360933703761, 16.513635381575554, 28.44528344369704, 28.372733323804795, 9.527801928981658, 1.4828293674415158, 0.04792926059434972, 0.07405509195861316, 0.09401614101783884, 0.11365367114664086, 0.07895935702347949, 0.07951206647821012, 0.09122097729555062, 4.846600707500212, 30.900391032618863, 41.554134814969956, 41.646628226003344, 48.273790344115234, 49.13519774713824, 43.72544519362911, 46.41697560587237, 45.52257322495984, 53.24892074831071, 53.24842260729883, 61.79821291277486, 68.24954694317233, 60.72807265866188, 62.447996677890906, 58.22619276662027, 53.53985863347208, 41.434792780107074, 48.31446532280215, 56.06366065240676, 57.19115380317935, 57.084543781895796, 53.683668413469874, 47.23640972568143, 45.658471584320075, 51.260718376405784, 57.6662116665994, 57.506343703116144, 60.29747093877485, 54.97147275555519, 58.06960782697124, 59.55972802254462, 62.95400204197053, 64.55386623259514, 59.40700661751532, 23.36769876941558, 1.0705468322961562, 0.36089917945285, 0.3570288726158681, 19.509369134902954, 59.99265570794383, 39.77752077964045, 40.25388871469806, 46.89734435850575, 56.270695117212114, 3.9471056192151965, 11.361924775185125, 42.75552541978898, 26.234906258121615, 29.969079148384836, 18.886310438955984, 42.06864387758317, 36.04056496773997, 34.67731383539016, 35.5666132127085, 33.746405955283876, 50.021484744164255, 60.557661364155436, 8.871160880211862, 0.34514363134099596, 0.15947281533191282, 0.10457896131781802, 0.006147526174543366, 0.05084696391056623, 0.0734628600278689, 0.1152197234032135, 0.11742049482681098, 0.03562219215617065, 0.07273600346619084, 0.051061422564089305, 0.034756470666897875, 0.05311824606671449, 0.1455772674131778, 0.035845962608413356, 0.04539168244528194, 0.16409652367714914, 0.23004981448813794, 0.28523126556988687, 13.475786159115454, 76.27318659136373, 49.6442311809909, 33.657748622279016, 33.822143000941125, 45.499588135750066, 41.46588933083319, 24.885944320309548, 30.7844320420296, 25.975366946189638, 42.85199611417709, 25.18577225746647, 6.04724508139395, 54.12429963388751, 72.1084374766196, 70.12425161177113, 59.27819598105646, 66.02562581339191, 18.437936459818197, 0.4517595055362871, 0.5305137425180405, 1.0485255429821632, 50.789304394875806, 64.67823282364877, 69.86148418918734, 66.85890197753906, 66.70975777410692, 59.167887164700424, 54.475363531420314, 62.87790021588726, 67.86128720929547, 66.41884342316659, 68.78859827595373, 66.21017332999938, 64.31262085514685, 57.083759307861335, 55.970539662145804, 54.51076292222547, 56.46242057123492, 59.80550765991212, 63.218856165486, 60.707201726974986, 62.216980841852006, 53.767407094278646, 51.27992622313961, 51.56913042068482, 60.059759616851814, 44.97276283079579, 44.92559240710351, 50.47555792716242, 45.13152468589045, 43.192399009581536, 50.994879737977065, 48.123944036422245, 47.256158859499045, 29.77125833111425, 4.542684189734921, 2.6137990865015217, 1.0723702441300116, 0.9001453437151448, 0.5023840971050725, 0.047972218974703745, 0.2616273305348812, 0.7679682717688623, 3.358238959504712, 22.406665125200828, 38.19036506837414, 27.485699115260957, 14.483874517102397, 8.20643239444302, 5.830994517572465, 2.3550047797541467, 0.8037538321748857, 0.06265479583112944, 0.03250266680674207, 0.2348471336787747, 0.4254336601063129, 0.07056505584548559, 0.011035510913408812, 0.0699911104334939, 0.0785920714899417, 0.3377324661179897, 0.5188517392643037, 3.2580829531915727, 5.9727166160460445, 10.036286231010191, 11.685586994694127, 21.004251087865523, 24.398097568942656, 12.647632610413337, 1.4422149403441338, 0.05488130549389509, 0.12212284975835394, 0.010099160905566909, 0.036928069462338765, 0.1142940593643054, 0.018756115328400366, 0.25802040472626686, 7.889921146054422, 42.43145135141189, 44.293286723475305, 49.053400639564764, 50.03345974030034, 56.76389786504931, 47.72134019482521, 46.14316671125351, 47.64810954370807, 54.23072922614313, 51.985395877592026, 59.438326743341264, 68.14616111017042, 66.08832882296655, 65.88482841368645, 64.00299287611439, 60.05563328343054, 46.9570271430477, 52.05172707957607, 57.3144103634742, 61.35729143696447, 59.74401274035054, 54.83666873747303, 49.35835315335182, 48.97020716820994, 55.264756218079604, 60.58274099903723, 58.99376923038114, 60.66902922045801, 59.81126569932508, 60.954534622930716, 62.40246188256049, 64.21317700416812, 65.66954912677889, 61.06347453209662, 22.45992502858562, 1.4959374382611246, 0.43670400856964053, 0.8960065077389441, 27.486679707804036, 65.79546505405058, 48.15786469367243, 44.00696154563658, 51.734878017056374, 57.77174303608557, 4.411744196568766, 12.73142816558961, 52.29186634863577, 33.37315320968628, 34.17081033029864, 24.04309561175685, 36.0245499303264, 38.873653719502116, 40.155680410323605, 39.83182207230599, 35.8255837809655, 54.585452695046705, 67.82099662288543, 10.388911231871575, 0.2533359302868766, 0.10655457183959023, 0.07287138652416968, 0.06496271614225642, 0.16755473649790212, 0.125984767932565, 0.1771002073561953, 0.23700704197249106, 0.1324525878073708, 0.21040396464447822, 0.1196100124188008, 0.09474076826365725, 0.16325983308976696, 0.19918869790290633, 0.18535826745773518, 0.14792025539903872, 0.29810417804025835, 0.3188969994023923, 0.43840870741874943, 20.256374728295114, 89.8525341095463, 57.75673212543611, 53.7335805739126, 42.89155713973507, 51.68994334436233, 69.44972161323794, 30.34512854391529, 40.181328788880386, 40.089106021388886, 46.71671921207059, 20.101615651961296, 9.651388948963536, 61.828685806643584, 78.4644579118298, 75.64145749615085, 61.65636431786322, 76.06146489420246, 19.78507253431505, 0.8054253747386317, 0.8389851739329677, 2.457160214262624, 66.09694234786495, 67.96928574962001, 77.95784458037346, 69.67878018656086, 69.47531115624213, 60.695995515392674, 55.48822149153679, 64.90197658538818, 70.14085892708071, 66.74462764493882, 71.08869967922088, 73.28354035654377, 69.74325610745338, 60.99334255341561, 59.20104295976701, 59.42551628235848, 59.77064955619074, 63.4498445449337, 64.19536159884545, 64.11423913894161, 63.777331075360706, 57.08354357750186, 54.97197874130742, 62.787391524161066, 60.73752164840699, 44.99433194437335, 55.52149888007872, 68.3148544065414, 50.593621269349136, 39.140272909595126, 46.4042906607351, 56.287251441709465, 52.1809377977925, 42.51254635472452, 14.059961418951712, 5.574311671718474, 3.1807963261681222, 1.3787012258844993, 0.6064261303794, 0.314571421833769, 0.7667959120965774, 2.7500803672498275, 10.781501262418686, 41.18983684047576, 44.86555660924604, 36.00961354471023, 20.641669150321714, 12.006624167965306, 5.320262207138923, 2.0030295440266213, 0.7024199503564066, 0.3254643034550452, 0.5242122709751129, 0.7603506611720209, 0.5027698376967061, 0.1805152894268113, 0.1576124780601071, 0.27294618768557427, 0.17046355702463659, 0.5315681246499862, 1.185925557248054, 3.9849305056756545, 6.820988981954514, 15.150044964205835, 19.75861026394752, 33.4024925385752, 39.09615408989691, 23.312883646257465, 5.387206769758656, 0.10571040423406709, 0.2895165162701761, 0.1965325025300826, 0.21380933272021435, 0.39954022534431954, 0.18565800701898916, 1.1331787489114271, 18.677803124150923, 52.123706494608236, 49.447645910324596, 55.48661724213631, 49.67630440188993, 59.76434238495366, 53.102541815850046, 49.50795235172395, 49.27862313485915, 57.729706994948856, 55.83720653287826, 63.07601913329094, 68.49218476203181, 61.512789880075765, 65.16087655098208, 62.81926862655148, 64.29588802399175, 56.19714675411102, 55.13314108694754, 62.093359501131125, 63.54312243000154, 63.2873603605455, 58.582073334724676, 52.37576976899178, 50.42000932078208, 55.3945396023412, 64.25753901081701, 63.141671765235166, 64.91758369630384, 61.65711741293631, 63.34091248050813, 65.37806995453374, 67.4503012626402, 70.95821026832827, 64.82443917182185, 28.691598484593055, 3.3828890948526325, 0.9281510667454813, 1.3081730878160847, 25.984498223950787, 71.5289072836599, 51.61170774890531, 48.77525752590549, 57.168337375886985, 67.56759582027313, 8.681566253785165, 16.502984185372632, 58.67883820687571, 37.61859332361529, 44.51504576590754, 24.16511662544743, 57.60957264131116, 48.94930877993184, 47.70121843584123, 51.41153350953133, 46.983142283654985, 65.10814420638546, 83.56380585701235, 19.51387986060112, 0.5736664947002166, 0.4897710110150999, 0.34214930008015326, 0.15444956149064726, 0.23926467244182867, 0.20943110958943445, 0.197285337133273], [0.04899641341199318, 0.018585526699861212, 0.05111309519458202, 0.057110127226840106, 0.012953211891374761, 0.0439324573193106, 0.061959099895771474, 0.030210196573828018, 0.20890804007649424, 0.06635632200707352, 0.18329012117558913, 0.2244399058362169, 7.252596299494467, 68.19485341348957, 45.233541611702215, 31.208810921638246, 32.335737289920935, 19.671916077213904, 50.75763517810453, 20.650592542463734, 22.944055334214244, 32.48305759122295, 50.19382976716565, 21.11781547146459, 0.06235419442096065, 28.922812400325654, 67.80951976776123, 60.52989882807578, 55.48475019393429, 62.91986957673104, 27.514367718850416, 1.036548708235064, 0.5889696219275075, 0.14557720612614386, 28.78608249848889, 69.37329815280053, 62.29602052319435, 64.55766308692195, 64.79115393853957, 56.15554217369326, 54.95806609430621, 62.05861906851492, 65.38638145692887, 64.67106273097377, 66.9035699290614, 65.93439932792418, 62.755428129626864, 57.10494402916201, 55.10610026697959, 49.7227805660617, 53.76204521425309, 58.5551501858619, 60.89242781362226, 58.93101130762408, 60.846657676081506, 56.21035729685138, 53.60641733292611, 48.03365891979587, 48.523935579484515, 52.77599665426439, 56.43580336724558, 36.114807590361565, 33.20242812556605, 48.13827245466171, 48.72998552937662, 51.25427784458284, 46.82233687370054, 14.14498761776955, 3.951536671769235, 1.932076319090782, 0.23486152080999267, 0.5312047538257415, 0.21081463373716802, 0.343866991780458, 0.9447018141227385, 3.4245029908995477, 5.992579988894924, 31.099996528317853, 35.12419731386247, 30.932707440468576, 18.544575898878037, 8.063969458303145, 3.1372832675133986, 0.5581693940104977, 0.4070648328671533, 0.06530978461547245, 0.8621057687747864, 0.7617174233159711, 0.04660180642179424, 0.08844651326897646, 0.058184983058562206, 0.07509517122901256, 0.14294659808999108, 0.0871961275416036, 0.1699284292877682, 1.4165877671011033, 6.975268058238491, 12.854456247821933, 24.09002677086861, 33.30058936149844, 33.052734790309785, 16.333849622357278, 1.1654092323395515, 0.3760388848041335, 0.05916709628617091, 0.021396582916138635, 0.0869238598933143, 0.10634883892752471, 0.1396172259363436, 0.0951147034403778, 0.5508792400360107, 15.796050506253398, 42.94106921842022, 43.446431313791585, 46.45017846938103, 46.948237111491544, 49.27410456442064, 44.5471856670995, 48.04199003404187, 49.110071043814386, 53.92984813259494, 53.20715927308606, 58.68094451965825, 63.083997234221435, 64.27549562146588, 58.26975068738384, 52.90843548313264, 55.383988426577666, 56.565924075342, 52.401398535697695, 57.05298046911917, 54.34516829829062, 52.37792315021638, 47.91859226842081, 51.68835870681271, 58.72229022364463, 60.736960749472345, 59.57065182347452, 59.43750304560508, 59.59265632014121, 61.09019371771044, 61.367952439092825, 64.62308822139617, 63.25064697573262, 50.27208497447353, 9.197251046857527, 0.4633028264487944, 0.15583457184895394, 2.0627198055867226, 45.3250152064908, 57.04508081559212, 55.84791852581886, 45.47870543695266, 64.60945014030703, 38.10610471233245, 2.1258841839528855, 12.959354154525265, 40.68768324390535, 31.88507853015777, 44.18680614040744, 30.418235640372004, 44.05346908876973, 29.266235520762784, 35.76581078190958, 32.070249703622636, 28.68667394884171, 51.010051465803585, 47.427382084631155, 4.185061598977735, 0.371924287849857, 0.05544081014851409, 0.19762305933381283, 0.08309385694202878, 0.06452430700582844, 0.06876494840628679, 0.06830424611126223, 0.05343002853013816, 0.044498990830634876, 0.02301669225186831, 0.05398201786221997, 0.047773350210439776, 0.040556997316138405, 0.10052042667784038, 0.05453874161767383, 0.07891126202359315, 0.01957081344669625, 0.11576956002822808, 0.16412079334259033, 8.828442346665168, 79.93113410088324, 50.56294441223145, 34.50345869987242, 38.62210427561114, 29.08011905608639, 44.23234093573786, 25.536520404200402, 28.726407558687274, 30.95433342841364, 44.354130529588275, 22.106896023596487, 1.2605563719426434, 24.63815446822874, 75.55934659896359, 63.383509420579486, 58.13523300232426, 66.92762190295805, 33.107145909340154, 1.5196976858762004, 0.32119106501340866, 0.19770477027181657, 31.078056750759004, 70.3828142535302, 65.672055521319, 66.86440114052066, 65.59529473704677, 59.085023172440074, 58.18197981003792, 65.6221394385061, 67.52893693985479, 65.31223689356159, 68.42977200784992, 65.88289076282133, 63.99383021939186, 60.52503508906211, 59.09225210066765, 54.266399260490175, 57.352469121256185, 62.05150388902234, 65.15772688773372, 60.04813763403124, 64.54362100170505, 55.85816767907912, 55.719574651410504, 49.82411499946348, 52.2864495554278, 54.182550753316576, 58.30228282559303, 44.85074966184555, 47.243713178942286, 51.166208867103826, 55.18042133700464, 55.255413132329146, 56.53441959811796, 18.11852805076107, 4.676353171948464, 2.8489814602559616, 1.441784705365858, 0.15121573582291603, 0.2793801005088514, 0.11112360448967065, 1.1396537240474456, 2.8054112820856036, 5.714584454413384, 38.898596071427875, 40.94190382188366, 30.57982944673108, 15.108006961884039, 8.95367774271196, 4.252274843954271, 1.4764528192820088, 0.5536774834317546, 0.08304766184019466, 0.21465100287910432, 0.7901522168709386, 0.32108408849566217, 0.08169887977982722, 0.06247983667098227, 0.10485381068241213, 0.11689156474125002, 0.1372288702236068, 0.1546912315872408, 1.3094585220659933, 6.6931883558150265, 11.137115109351374, 18.48166500368426, 36.3440465927124, 41.2681116596345, 25.451828587439756, 3.9646371429966347, 0.4912267925758516, 0.12163523479454941, 0.14252413124326738, 0.07230939974467601, 0.06891422063833283, 0.10421006699963924, 0.2685088838540739, 1.9145783806039443, 22.063600901634466, 47.65589152612994, 47.136357907325994, 51.2362467089007, 50.304044446637555, 50.80563322190316, 49.605372259693766, 48.408182513329294, 49.1715738081163, 55.63483576620779, 53.56414594957906, 56.56936791635329, 60.02231274881671, 65.92718216680711, 63.06185153222854, 57.117311262315326, 59.33363083870181, 58.6103928473688, 56.78456483348724, 57.70638065953409, 56.7478749828954, 56.04720630953389, 50.81569802376532, 55.98992401553739, 62.491589899986025, 63.232882561222205, 61.48991853960099, 63.8389358212871, 61.38862725227111, 62.90692183279223, 64.17494566209855, 65.63728370974141, 63.927322510750066, 48.26327446968325, 7.113888542498312, 1.1167423018524725, 0.3173882352007974, 3.386632016589565, 55.03267741972401, 61.904901381461855, 62.57373217613467, 44.286367662491344, 67.86360140769713, 39.72245854716147, 2.278656089498151, 17.584112959523356, 51.47112607955933, 33.93820985671013, 42.812305650403424, 27.088545407018355, 36.775605370921475, 35.07436752319336, 43.10562049188922, 37.46974722031624, 28.764764416602354, 58.77717202709567, 55.7728914291628, 5.212719642346905, 0.3048717068328012, 0.14650345239187443, 0.039249859795334845, 0.08047925248261421, 0.05217044974767393, 0.05742816862860515, 0.01727193297307578, 0.3524631418047413, 0.1513832332866807, 0.2404085336433303, 0.2025541834413044, 0.10661975826106726, 0.22320789855814752, 0.23993892174574638, 0.11642297174060538, 0.32963724566563485, 0.16566965458614213, 0.5016299295088937, 0.5155958655861117, 15.463589429855348, 97.30975212589388, 60.957782345433394, 46.212749558110396, 46.198648637340916, 31.952358945723507, 71.36200258808752, 28.016154573809718, 31.716857879392563, 41.18631455206102, 59.5173389680924, 29.791066300484445, 2.328282407214565, 36.37175813797982, 79.89732326999788, 72.15450179192328, 65.32378827371906, 73.77322473833638, 36.33722951335292, 2.4173459506803945, 0.9608828781112548, 0.35708354065014475, 40.034479171999045, 77.96799567437942, 68.15292327634751, 70.48186978986188, 68.20742853226201, 62.24469630948959, 61.51589247488207, 68.06646639300932, 73.22974897200062, 67.64973809642177, 71.37380107756584, 69.74256577030306, 65.86880945390271, 63.656196517329064, 61.555645696578495, 54.73329467158164, 58.435239407324026, 64.67361227158578, 68.14872634026312, 64.99886697338474, 66.45112452968475, 59.134531328755045, 53.56611497940556, 50.91953100696687, 59.249896080263206, 57.508657901517815, 55.227332884265536, 44.31418903412358, 48.26946789218534, 52.20650772894583, 63.01193152704547, 58.314685360077895, 62.957524330385276, 31.4105462643408, 11.4360644355897, 8.102620984277419, 4.128111725853336, 2.0874469174492747, 0.29964864193912477, 1.487600072737663, 1.7943936490243482, 3.3811306472747558, 24.2972553929975, 47.23135379052932, 41.8203382338247, 38.89227713308027, 28.145777140894246, 16.746200553832516, 6.65411860712113, 1.7368638779847854, 1.0730892636122242, 0.2683790779161838, 1.115474640842407, 1.3902084793775313, 0.8552285668350036, 0.3489123549192183, 0.3724611929107097, 0.22828540674621062, 0.2136074991956834, 0.2084145875227067, 0.32625190312823943, 3.6860392795455073, 12.572936954036837, 22.393507534457793, 30.890320347201442, 40.12940445253926, 43.76350002904093, 36.80499569062264, 13.42593381481786, 0.6526169421211366, 0.23640137285955493, 0.1801187776389622, 0.15557391809359675, 0.22760717378508663, 0.30547048115441877, 0.2948686516573352, 7.300759573136607, 36.98680931522001, 53.01581821134014, 53.45298205652545, 58.099861068110314, 56.417132885225364, 56.135734204323064, 53.33891560954433, 50.340961794699396, 53.183107299189416, 59.12962836603965, 57.50916780964021, 58.6754257448258, 61.66416198976579, 64.35674359721523, 67.41288185119629, 59.81450557708741, 59.04202615061114, 62.39131058416059, 57.10684245632541, 62.43992444007628, 59.62247810056133, 58.52772497361707, 53.0596467756456, 57.655887988305864, 64.29307176220802, 64.60178190662016, 64.25173782533216, 64.5319519504424, 63.61452133424821, 67.55759377633372, 68.42879141530683, 69.71852164114676, 68.45196477828488, 57.12110811664213, 12.038052158970988, 1.478012329147708, 0.45146560356501614, 2.7129764614566683, 57.721544542620265, 67.20677698812177, 67.06675621771043, 52.74166022577594, 75.1421711521764, 45.922364727143325, 6.0255617287851155, 19.171751122320853, 56.03552941353091, 41.644412086855986, 59.0375271920235, 36.406510337706536, 55.52181659206268, 43.1371053572624, 51.504128902189194, 46.98669987340128, 40.874203712709495, 71.49941105996409, 74.75845352295907, 11.416859530633497, 0.6907692852039492, 0.37862277679866363, 0.28556521861783923, 0.2504543518467296, 0.24343720096493923, 0.14935035769256855, 0.14835485707848303], [0.05921009680136077, 0.03182651568955231, 0.04841052085882233, 0.04498347249482909, 0.045243019253135695, 0.0713019788024887, 0.05509545005136921, 0.02021321264516202, 0.07167927710519684, 0.03225361545299811, 0.05358602318371977, 0.10973667125067404, 1.8282765534616288, 51.02997318390877, 52.954637081392356, 26.182587723578177, 29.132918080975934, 25.634940516564157, 47.94057323086647, 33.80506500121086, 19.667887803046934, 31.70107622300425, 42.352890199230565, 65.03000274781259, 2.8290852375568885, 9.75843043096604, 52.204417105643984, 70.39704461251536, 57.48611211776734, 60.00109272618448, 32.11698082185561, 0.3173369073098706, 0.4721515403399545, 0.10063088889564238, 12.288553349433407, 63.85311126708985, 65.20399516628635, 64.8855104754048, 63.30455995375111, 60.26526827966014, 55.206336436733125, 67.30584821393414, 63.99946666532948, 66.75513175226027, 62.987263741031775, 67.18627083686091, 61.56549869045135, 58.59515443924935, 52.015041151354396, 55.13174864553637, 56.06930102071455, 61.03755158762778, 60.54287010623563, 64.14253903973487, 61.4004296641196, 56.92573878072924, 50.89025835837088, 58.2376931559655, 50.65597518797844, 48.55638142554991, 48.397215566327496, 60.837530320690526, 56.60030364990235, 55.50589569153325, 52.6053225609564, 53.51817577115951, 26.98131565124758, 5.047492250319451, 4.344919266239289, 3.6140284855519575, 2.423478576444811, 0.8231896053879493, 0.7155945176078428, 1.8897157018223119, 1.0500159210735753, 5.085134256270624, 7.205257704181056, 26.364048334860033, 39.27823835803617, 34.34404965369932, 17.03434963380137, 5.1963594363581755, 0.47306416556239134, 0.6971713287695762, 0.9882779984224228, 0.19064205248029004, 0.3790572712257985, 1.3550194256728696, 0.2880393455345785, 0.16892722897952603, 0.15230931101306794, 0.21364779542050055, 0.7009168245619344, 0.6527973711490631, 0.8878265886056809, 0.7272050397530679, 3.1951090549269034, 12.821727010511584, 22.190571946482507, 30.822851657867435, 30.019650267016505, 13.889847243985823, 0.8742930019094098, 1.7540996305404173, 0.17139046212598202, 0.084158320791058, 0.05475978096646648, 0.08761297130296308, 0.08089832555983337, 0.16859534436896925, 0.7575964218666478, 3.6979966250158127, 26.246249752659953, 41.91283556722826, 45.76195547657628, 44.20414693893925, 45.553218703116144, 47.71619012278896, 46.37353535621397, 48.20735323813654, 53.37191450980402, 54.16819095611573, 52.2643469995068, 49.68923253397788, 52.36658750041839, 54.164205828020656, 53.69996978390602, 54.053175295552904, 55.125767031023585, 57.19434269012944, 57.535761479408514, 52.664346387309415, 49.564850253443566, 47.88019226443383, 58.114067892874445, 59.111373655257694, 63.60924574636645, 63.41005209953555, 63.57847082999445, 60.08201514520953, 59.37050504069175, 64.55569405709544, 62.55866242993263, 60.959312069800596, 29.226713718906527, 0.7154156820427987, 1.0556874231946085, 0.44117278329307036, 11.930828286755471, 50.61750850369854, 56.06183282790646, 57.7677147619186, 55.75493481851394, 65.31398234828826, 29.616169775685957, 1.772555607941843, 24.96599401197126, 47.158389860583895, 48.34777409030546, 54.31996314756332, 36.84385853428995, 45.91528484898229, 27.018183969682266, 36.03744668345298, 29.311736975946737, 32.601242526885, 53.52846807049167, 35.57222612442509, 1.047216084214949, 0.09797493101007516, 0.0905510793710428, 0.10015743889755781, 0.04902676964599279, 0.05085478566827313, 0.022739579097457954, 0.052699946738298864, 0.06110816773387694, 0.026632659813208927, 0.15797067012998367, 0.02220848481351089, 0.02104266178643992, 0.05615604132594121, 0.07051305379718542, 0.017672033882850123, 0.13534067799487423, 0.04424098007861645, 0.07648565911597784, 0.02557181381440211, 1.9546564235802621, 63.37151873496271, 62.224629463688025, 28.668297644584413, 28.890350864779567, 40.175947297003965, 46.09306627704252, 30.68923023439223, 27.16577687571126, 35.516512778497514, 46.738810000881074, 53.11440306325113, 5.6126812773366135, 10.951297725400618, 56.841478424687544, 74.0618170461347, 67.56765857819589, 64.72541893682173, 39.281705733268495, 0.8123039862801953, 1.2119705854885041, 0.2879001933240122, 14.485727837008817, 64.62344123471168, 68.4547653505879, 69.85003871302452, 66.35352811505719, 62.05468100886192, 58.18483529552337, 69.79649836017241, 66.40736656804239, 65.98561763763428, 66.20018697554066, 69.11078960664811, 63.42052482789563, 58.48290404965801, 56.564712062958755, 58.29281422399706, 58.58247341648225, 62.01128390527541, 63.07885500692553, 65.47652929059922, 66.19089095823227, 58.26238447620023, 54.527793853513664, 57.541943134800086, 54.74498333469514, 49.28456944804038, 52.03720646519815, 61.00506651786066, 56.513701638867786, 55.21222783673195, 58.41681995699483, 54.62304469077818, 33.81844028349846, 11.92684708103057, 8.37860434286056, 4.632345159207621, 2.3133090042298843, 1.50050136110475, 0.6547209259963805, 1.0258658266355916, 0.9393722323640701, 4.839371288976362, 19.29603338241577, 39.973298042051255, 40.209467872496575, 35.071327686309814, 20.246582531159927, 9.648856078424762, 2.6276423565803038, 0.12731593763155322, 0.24441002537646603, 0.22148705057559476, 0.4472770331607711, 0.9796479260248523, 0.3425559089068444, 0.14041722091215272, 0.03159548463900724, 0.303149173456815, 0.37489529939428456, 0.2028174878608796, 0.3208292876520465, 0.8095314221516733, 4.549145314001269, 14.871692984334885, 24.240779146071404, 36.29019245024651, 40.538750848462506, 29.919349378155125, 6.479360345871219, 1.9183744994863388, 0.31779588590706553, 0.14719205818349315, 0.041996108803657756, 0.12041914682354658, 0.1282215148450867, 0.28007147953875605, 0.7065316361765708, 8.299670565512873, 34.76333141326904, 46.08834766572522, 49.00724610974712, 47.8983175370001, 49.71326097365349, 48.91140691695675, 48.3377367450345, 50.34468020162275, 55.246540730999364, 56.60178238345731, 56.408166347011445, 54.88378424798289, 55.60143678419052, 54.1842059935293, 56.646650375858435, 57.09427518229331, 55.8150137624433, 57.5889801979065, 59.859530464295425, 54.55929048599736, 50.379102922254994, 53.355985764534246, 59.30254213271603, 61.67599185820549, 64.31595486979332, 65.16989015763806, 65.49337587048932, 64.89117045556345, 62.42898494966569, 65.79135833248016, 60.661886584374216, 59.37054426439347, 26.688853925274266, 0.6106662738227076, 0.7593380767972239, 2.4254218657170576, 17.882013051740586, 56.20801956422868, 60.73019073855493, 62.20991665317167, 57.15470321716801, 70.08010925785189, 32.57447823401421, 2.7574254956937607, 31.44558087471993, 52.757031994481245, 44.99180593798238, 55.64291192639259, 30.226674925896432, 36.29099653613183, 36.01688954137987, 43.40044544589135, 32.03978269330917, 37.359281509153305, 66.41121049081126, 42.649597890915416, 1.7986479497724965, 0.15759732484096484, 0.02053000340839067, 0.07119734651379048, 0.15470042464233216, 0.038781400860076955, 0.00760291655164873, 0.07973458437669663, 0.2137444144295108, 0.11389766248964495, 0.29094242040188084, 0.10257243914830108, 0.09177951667938503, 0.21411127861469023, 0.17234866957991354, 0.16261391371728914, 0.25396989868773573, 0.17449296500173309, 0.2004093364361794, 0.2683240115161865, 5.016745771131208, 77.47658544971098, 73.45779557381907, 40.015902826862956, 41.26120436576105, 32.640568210232644, 68.56430146002, 45.0386155036188, 28.10509627865207, 42.858640609248994, 48.76239215174029, 69.45230253281133, 8.748424033964834, 14.253051857794485, 64.02824509528376, 80.11763495783653, 70.71064595253237, 71.36758804321289, 42.2560586467866, 1.3762814912103838, 1.240507054232782, 0.3094393988290141, 20.04430001781833, 71.82956480210828, 68.49048245337703, 72.77116114093413, 67.8367410167571, 65.98516264269429, 59.98383821979646, 72.17634939378308, 69.9126789646764, 69.75167351384317, 68.82381331536078, 72.31731153303578, 67.01487110507104, 62.099474476229766, 59.394713909395286, 60.67008826040453, 61.58437313572053, 65.89881558572093, 66.74199965692335, 67.95829526839718, 70.08735779793032, 60.839205172754106, 56.08911683482509, 61.101690184685495, 55.47415587209887, 53.67410567498977, 57.01547084316131, 62.632395144431825, 58.513580906775694, 60.39552627071258, 58.65088739702779, 59.1204970882785, 42.954413121746434, 22.090747625597064, 14.78758462013737, 9.990064040307077, 6.188822542467426, 3.06693212639901, 1.3510791596866425, 2.8575214407136365, 1.3663853512656305, 8.199484405979033, 32.849875688552856, 41.225581399856075, 41.64835014650899, 44.097176059599846, 30.187943481629897, 15.081139706796217, 4.242441461932275, 0.9579577092682162, 1.0692437473804721, 0.3972106438971335, 1.0055407172729893, 1.7710591011470365, 1.1022378672515194, 0.29456954028817917, 0.1880609950110797, 0.7021276724915351, 0.9339527425266082, 1.1428988724946976, 1.2119559991744258, 1.1197980733648425, 7.218410391961375, 21.471234752285866, 28.852148940486295, 36.570402652986594, 39.435635228310865, 35.81332245180684, 21.54418887630586, 2.8087384325842706, 1.1207573380201095, 0.176988189979907, 0.17511918059279843, 0.18187105054816893, 0.3619962480039366, 0.4273967450905231, 4.688643918883416, 16.716763165689287, 45.081659593889796, 53.60045140789401, 56.32350590921218, 52.56273738799557, 55.297331502360684, 52.891757565159956, 54.8276198294855, 52.22849261376166, 59.646392791501945, 59.721737600141964, 59.06321087191182, 54.80282260525612, 60.570499281729425, 58.07731528435984, 61.18541317601358, 60.485509364835686, 61.252885787717766, 60.03894359834733, 64.53337577081496, 57.98537492752076, 56.01502326227004, 54.129496774365826, 63.41517079261042, 63.41044433655278, 67.58258711907172, 68.37421555672923, 69.8998135905112, 66.23198170815745, 64.10637086437595, 68.54300298998433, 65.34429442497992, 64.00865285627305, 33.63481844625166, 1.5588733385647497, 2.8329681388793455, 2.4878927200071277, 15.595847829695671, 61.86648568799419, 65.59847577925652, 67.81194379252773, 65.49042232574956, 74.6797864667831, 38.93664698446951, 4.84525925690128, 31.387492533653017, 62.05694421645134, 52.46960070825393, 68.53341671728319, 43.13259070919406, 61.45608025212442, 42.36450825968097, 51.3386558717297, 39.9158117848058, 48.13435400685957, 74.86184720070132, 63.845313595187285, 4.640896906775813, 0.396731072856534, 0.21775572740983581, 0.14454048998173208, 0.2756613871503261, 0.15641068528977134, 0.1762640836738771, 0.18023678582281838], [0.0337037586066271, 0.1407641361677839, 0.08857261134131302, 0.16646770369862357, 0.04893891468283631, 0.06165245022144049, 0.05093266999709511, 0.003993732459475137, 0.08664068315298327, 0.014515972842702703, 0.05977826974084301, 0.15116586349904537, 0.2592011300786849, 54.046879891426336, 54.565213264957556, 38.966256956900324, 45.66860698884534, 15.483391515670286, 39.37199869463521, 46.030724125523726, 28.466581913732714, 32.24647983427971, 29.436942954217237, 69.67041769335347, 5.810139765662532, 14.448286852528973, 55.996694026454804, 58.70844425693635, 49.66929904876217, 66.55220400902533, 43.91299724578858, 5.793975187886146, 0.2283596253443149, 0.2826120416002889, 4.495803040842857, 57.581519849838756, 67.24374924936603, 66.965088382844, 62.74856790419548, 60.47354221343995, 59.68607541053527, 66.88671158206078, 66.79573612828409, 68.09172645691903, 65.6476701459577, 66.57691494111093, 60.13376689726307, 61.31793829702563, 52.814479028024984, 55.71758600973315, 56.90123181189261, 61.6612555134681, 59.698187689627375, 62.01088382351784, 61.36211202990625, 55.380909365992395, 57.11842129307409, 53.188810425419966, 55.21020389372303, 56.049426371051425, 49.95738537080827, 52.07297848116968, 54.384423378975164, 54.17270560418406, 51.23473659638436, 30.12092194249553, 12.35774003690289, 7.9320581882230705, 6.144724805508891, 4.103187514889625, 4.332446129091324, 2.952595771320405, 1.2772074461944642, 1.4762282635896438, 5.149222843108639, 6.431994293966602, 10.788872376565012, 21.015900527277303, 26.218857880561586, 22.897022193478, 14.601512282125412, 3.2032815583290595, 1.0299265216435156, 0.824635734240855, 0.21350085975662356, 0.3879896112747731, 0.8410598626059871, 1.5010034244868065, 2.092531534933275, 0.5790337066977256, 0.89888344368627, 0.7243127207602225, 1.821792385270519, 0.6284996362463121, 1.1473785869536863, 0.7745813265923531, 1.3724568125701722, 9.305717329825125, 19.83579074182818, 22.87675334561256, 22.89459816871151, 14.187211932674533, 2.2996907801397386, 2.8936560307779624, 0.22482408360848505, 0.23834544354148451, 0.050216768492734244, 0.1645098893993324, 0.1733705389403528, 0.2007155417795143, 1.2850624827607986, 2.9358715203500565, 13.08649484188326, 25.24704752429839, 40.31075915982647, 47.012022695233746, 46.0328382830466, 45.59141866622433, 44.72243716639858, 45.028554624126805, 49.43294486691875, 53.025898702682994, 56.731836411260794, 56.42680152770012, 52.30351578804755, 52.369643026782626, 51.447842890216464, 53.342971340302505, 54.009954698624156, 50.19927401696482, 51.90799574698172, 50.20462805225004, 47.99658467692714, 53.713976567791356, 57.878592321949625, 58.97975852412563, 61.67881204235939, 64.20674039471534, 62.41625685845653, 63.817982519826586, 64.4856091468565, 61.12612262848885, 61.16610727002544, 49.99653062512798, 7.298246804744967, 0.04382066976939959, 0.09638588079401562, 3.5242858817500458, 35.254918144595244, 54.823921034413004, 55.34916170181767, 53.898892787195024, 53.948687276532574, 65.71060457537251, 19.85108014075987, 2.766743331186233, 36.874354962379705, 53.70082878297376, 63.6410600908341, 53.364081536569905, 43.65253225449593, 33.636073604706795, 23.564621363916707, 37.37554365588773, 27.493035908668276, 45.01856042492775, 59.12891057229812, 28.445697253750218, 1.158577321517852, 0.15152376445551075, 0.13923995827715244, 0.03268727867473518, 0.06642805848030314, 0.07880941063406006, 0.026581596222616015, 0.09947333004205458, 0.027062810521813172, 0.016248632943437948, 0.02936564783956255, 0.021085549303660953, 0.029988423695847876, 0.04578743963652561, 0.05072536277434519, 0.06094739269164782, 0.03206723583711973, 0.033785756827602466, 0.042598039407523415, 0.14730655768465611, 0.9528479028132655, 59.52975719205795, 62.88515267833587, 38.42018850388066, 44.620820322344386, 15.218966891688687, 39.55500864213513, 39.45540789634951, 38.58575959359446, 32.62293911749317, 44.43194250906668, 68.97681713104248, 6.766755350174443, 14.1614370576797, 65.12264913128269, 63.87072663153372, 54.80950240165957, 71.8974296508297, 51.5010537639741, 8.392662117558142, 0.5667530108363398, 0.25168873399736424, 4.155549195504958, 59.24463618186213, 69.42681497143161, 69.73664299134286, 65.58748137566351, 64.64006031713178, 61.25416840276411, 69.17165694698211, 69.13106826043898, 69.14962891609439, 67.79342236057406, 68.84437437980407, 62.13275186477169, 62.27415330948369, 58.55966875630041, 58.4313601832236, 57.5543809706165, 63.29709176094302, 64.09315639926542, 63.268415312613214, 63.96693452712029, 55.733067604803274, 59.300267158016084, 55.09318782437233, 55.94408327533353, 59.3984519281695, 53.68864590121854, 53.749011178170484, 56.18243002122449, 58.03925260420769, 55.25762142673616, 32.85055818096284, 20.23655891418457, 15.921052521274937, 15.278144671070962, 7.838010538008906, 4.917251419636512, 3.8067337966734365, 1.6469016214532237, 2.1740994289998086, 4.9439828626571165, 5.634207735138555, 16.968540107050252, 29.051462219607448, 38.70935347772414, 38.435117044756495, 21.038573788058375, 6.96708256198514, 2.7198969933294483, 0.312624056973765, 0.5999166506432718, 0.28033458477547096, 0.9540999356296755, 1.5074629552902714, 0.4706428374253935, 0.272869793397765, 0.12955023306271723, 0.4688251252856947, 0.9749738703812323, 0.8010342200436901, 1.8533883027492033, 0.8665147579966054, 4.138589357176135, 13.920326021409805, 26.603913038007676, 35.07034709376674, 32.2277779732981, 25.413614896035966, 11.762489964885097, 1.099496620797342, 0.43648398811778716, 0.5120791849349776, 0.14095349778090754, 0.09417639895071907, 0.08743788956874803, 1.1280086973021108, 1.3610351157765235, 8.291913097904574, 18.53452482531148, 31.363566075601888, 46.430307742088075, 49.078088037429325, 47.83015851051577, 46.61008957893618, 48.65079679796773, 47.973175971738755, 49.28605602633569, 52.49830461317494, 58.991105941034135, 58.58853347839848, 56.42998256990987, 56.74580397144441, 53.17036744086973, 55.27178118305822, 54.36440752398584, 52.797612836284024, 54.42871086059078, 51.40430065893358, 50.35320743437737, 57.25932851914437, 61.48315637342392, 62.783935916039255, 64.54120089930873, 64.69791919954362, 63.04323596339073, 65.07980900426065, 64.126425943067, 62.26537504503804, 61.85101193766441, 46.5460608082433, 6.530786050904182, 0.22690485501962326, 0.024065920527303414, 6.3750032359553925, 41.806405974972634, 61.141643447260705, 58.047391522315245, 62.34036291799238, 58.86842596915461, 68.11386431417158, 19.628558197329124, 4.6354041176457565, 42.87624028421218, 54.94794245689146, 61.64495806540213, 59.0267877424917, 34.15827051285775, 28.3925824780618, 32.12980893350417, 37.9819538516383, 29.145705007737686, 48.30776199217766, 71.2548199007588, 37.13722436658798, 0.9701589158465787, 0.20031749781581665, 0.17202890448031888, 0.1333191251802829, 0.14644761990395286, 0.14531937157434804, 0.011859938348343056, 0.03616306172203153, 0.21378060442305383, 0.2673157172337655, 0.2155017281972593, 0.155139270448877, 0.11236182474080594, 0.17583504379276307, 0.16993368465092876, 0.11103682971048741, 0.26165101797349993, 0.1685287406848323, 0.2652034289654224, 0.4295532519538557, 2.8335623779604515, 77.47164326329386, 72.55290477506577, 51.891294294788, 62.08946458755001, 20.380604036392707, 60.918664547704886, 61.5298718021762, 36.65279988319644, 44.67544717173423, 40.32995523944978, 77.30041611579158, 9.877162537267132, 20.833378914863836, 66.16850991402903, 73.43110776716664, 60.04122249541744, 77.9870113249748, 53.418829979435095, 9.681936367865532, 0.5763245133623001, 0.3640436026598177, 7.886895527762752, 67.59228321813768, 68.83028522614511, 73.59179942838608, 68.2485741953696, 66.15710366156794, 63.45153508647796, 74.27529596513318, 72.62220521127024, 72.254514386577, 72.55011204750308, 73.09485081703433, 63.908334316745886, 67.09184369733258, 59.32654311580043, 61.33612240514448, 59.78127525698755, 66.75562597090199, 66.23209153452228, 66.54074284338182, 66.19306395130774, 59.96397141487368, 59.87560825963175, 58.91126609617665, 60.193096668489524, 61.91925725629253, 53.52773850963962, 57.20638044418828, 56.75759069381222, 61.00355640534432, 60.320997315068404, 40.39657669682657, 27.621297413303008, 24.296200275421146, 21.542535597278228, 12.189067332975327, 8.74089406382653, 4.912409743955059, 2.459623707878974, 3.0788965811652527, 5.171976022181973, 19.731367441915697, 28.749461289375063, 30.948398882342925, 39.96874809265137, 41.70038823158511, 23.567280730893536, 6.646480771803088, 2.965880103649632, 1.4147753869333577, 1.1199972562251554, 0.8995002976829006, 2.016712977520881, 3.08213155596487, 2.6417979453840568, 1.0416974319565682, 1.313659135372408, 1.8211969204487342, 4.622200439053198, 4.125172399705456, 5.370589648523639, 2.7136653277181813, 4.01216499267086, 14.932965309389177, 34.32711285929526, 41.231480644595244, 33.98459580636794, 30.215576579493863, 25.100650941171956, 5.513117303771358, 0.41237023689093133, 1.499957254817409, 0.26065890346803977, 0.23877391651753457, 0.5499181980567595, 0.9909386524269659, 4.0009234797570015, 12.9384224261007, 25.308209042395315, 38.45718037697577, 55.73000423369869, 53.224398089993386, 54.301559386714814, 52.63000603645079, 52.46356025818856, 49.291351226068315, 53.12799407589821, 54.85770833107733, 59.95809570435555, 60.75281496970885, 58.77619927929294, 60.010482880377005, 56.72515661485734, 56.79706934959658, 58.85344251509636, 55.168752285741995, 57.73606515699818, 56.23026332547588, 52.798981743474165, 59.45408290432346, 63.24883091834284, 63.3078194433643, 67.85163033393123, 67.31712110580938, 65.82872283074164, 67.17024403233683, 66.94840262013098, 63.3025634673334, 64.13171329805928, 52.75766349607899, 13.538663714162766, 0.47049584047448256, 0.2375549940212119, 6.68545344183522, 47.011665759548066, 64.95023350561819, 63.538635238524414, 65.73000854061496, 65.39501459367814, 75.8009724463186, 27.629106852316088, 5.897692951463885, 45.59370540803479, 60.89158842640539, 67.29065295188659, 63.87801439531388, 50.39788715301022, 46.54035375964257, 36.11937715161231, 48.225513812034364, 40.79458744295182, 62.686394414594105, 79.34852876970845, 54.77001982350504, 1.754822817540938, 0.3479771760682906, 0.35602051704641313, 0.2463490092345784, 0.2621196186350238, 0.2231661774097912, 0.08520952365811794, 0.17983155595439096], [0.017431671881387313, 0.1334110250876796, 0.14109533129920884, 0.06167561288983111, 0.025627056414621974, 0.07386923902818272, 0.017445635749027133, 0.07060873817892806, 0.07486673147087136, 0.03564748837943039, 0.07545945369788716, 0.07620393028182369, 0.14858687446723062, 26.014100351641257, 58.726036087159194, 35.754890903349846, 31.72678343711361, 62.80015099433161, 47.996259120202836, 46.83538659926384, 23.21593442270833, 54.68930921246929, 19.786849368003107, 61.58334939710556, 6.968195044225262, 2.644407792437461, 52.67303051487092, 59.36848894242318, 49.89148562954318, 50.81254443814678, 66.04709686771517, 17.356395836799376, 0.322832515643489, 1.108464875048207, 0.3100917380182974, 24.405049970073087, 60.98039873184697, 69.8447984264743, 64.96011003371208, 61.707237458998165, 61.59207667073896, 65.271569759615, 64.29074971906601, 63.45227249207036, 64.71429117264287, 65.80996605657762, 60.83672231243503, 57.03055627884404, 55.89823076801916, 56.18309290178361, 59.31362282845282, 61.69827876552459, 60.246884130662494, 66.32827589588781, 60.854996635067856, 59.34286409808744, 58.22226255170761, 60.49161649519398, 58.972086368068574, 60.40330040839411, 56.91454041388727, 60.449447093471406, 54.418367570446385, 45.76557974661551, 25.642893122088527, 16.712887863959036, 9.471585539079483, 11.710826466160437, 12.016745844194967, 11.378654664562596, 9.78826593968176, 5.1258415945114635, 3.5395176708698277, 4.523395444116285, 7.197632616566074, 8.43028647284354, 16.007521171723646, 20.924572060185096, 21.71807735197006, 15.142443410811888, 7.333976655237137, 2.5944353255533406, 1.177309826016426, 0.7936532386849005, 1.0098919128218005, 0.3178135672163579, 0.8111889912716804, 4.237384055891345, 6.982446485950101, 4.060489573786336, 4.272412292418942, 6.95596460373171, 7.602664895596043, 6.910084639826129, 6.693922329333521, 4.187157615538567, 3.513441753964271, 6.24668485695316, 10.934353086256213, 22.26566964580167, 24.107398948361798, 18.07022798445917, 9.630203247070312, 4.8578289824147385, 1.5322312520396326, 0.5255456929725986, 1.0618927353812804, 0.024042568252151533, 0.2742263818940809, 1.0174362241260468, 3.136536055995572, 2.5104762565705085, 11.64510323155311, 15.822864809343892, 18.17161144748811, 32.29837279165945, 44.64650792460288, 42.92051599871728, 42.67144941514538, 43.161557412916615, 45.716969813069994, 59.02292420787197, 53.9439804323258, 48.06458288623441, 54.030582443360366, 53.93993646867814, 54.630042199165594, 47.84214919613254, 50.23095107847645, 50.49614644819691, 52.48539609293784, 47.416183717789195, 50.66924064390121, 52.421434002537886, 57.1525655254241, 59.62122686447636, 61.524576602443574, 55.71558560094526, 65.89135523765319, 58.17802606090423, 59.73666221864762, 55.35632002738215, 60.7689594453381, 21.38783339531191, 0.7435547656589939, 0.34720183380188485, 12.56245049738115, 30.996147855635616, 48.68081077452629, 62.431754143007346, 51.95153013352425, 59.51232617901218, 55.70147291306527, 56.58103304524576, 6.918265233116766, 9.797481548401619, 46.02350304203649, 58.348649163399976, 64.92076866088375, 58.713892429105705, 41.084705552747174, 32.53214801511457, 23.920399950396632, 42.69844708904144, 29.942714937271614, 40.667345754561886, 55.52984960617558, 15.756814056827178, 0.3980969463384921, 0.06684785934105035, 0.02388796021771287, 0.056062429212033756, 0.11039640318842665, 0.05378531329634209, 0.009288151500626438, 0.053040580072950934, 0.09210779301581845, 0.0637321682616828, 0.10693600701708948, 0.009628515746895104, 0.028922448738388, 0.033989413641393185, 0.0321124043811353, 0.04045678152432365, 0.05183108428853655, 0.04974435271334745, 0.08743654891488054, 0.025430972379962766, 0.13000685210910537, 34.25521581403671, 72.15771029072424, 42.60445533260223, 36.720354864674235, 42.384606484443914, 44.12949246744956, 34.527906833156464, 32.88304717310014, 55.61311368019351, 36.160036440818544, 71.68594329587876, 8.431635768182817, 3.078177071386768, 50.142285900731245, 70.35618920480051, 56.42054534727528, 54.30113969310638, 69.82508459398824, 23.88378658602315, 0.740302017619533, 0.46493422600530815, 0.18074700038038916, 25.034925745379542, 63.760684536349395, 72.5947093963623, 67.77695625059067, 66.24062661201724, 63.75446757962627, 69.50319136342695, 67.00000532211797, 63.696749902540645, 67.55967263252505, 68.90892874810004, 63.86211310663531, 60.49650769079886, 57.24773007054483, 61.6761605201229, 62.61305785948231, 67.13209506004088, 61.70399758123583, 66.63425214828985, 61.365457811663234, 60.395887128768436, 60.51950454711915, 60.19308097900883, 60.30368005075763, 63.73667570852465, 58.22374128526258, 60.38466915007561, 58.00284124189808, 47.581950926011615, 30.3057106848686, 21.682728951977147, 19.081264003630608, 19.850658485966346, 17.707897078606393, 16.633416721897742, 10.689643275353218, 5.033382994513358, 3.285428492292281, 4.908090233802795, 7.738859884200558, 12.065944133266328, 17.467377339639974, 24.793501900088405, 33.80375100720313, 28.775160658744078, 13.455077025198168, 4.630619316331802, 1.0490421926782978, 1.4672745956528572, 1.7791956903473025, 0.5693550744364339, 1.42044578588778, 3.0521205211839373, 2.694036561635233, 0.9674899268054193, 1.483447998762131, 1.8473618261275755, 2.855707834805212, 1.3175324759175702, 2.8801532714597644, 4.198157902686827, 2.788867214995046, 9.185559441966396, 19.55782609601175, 30.477553644487937, 29.661663386129565, 22.8759257255062, 14.319999852488118, 2.36616367774625, 1.1582142571287772, 1.0683202743530273, 0.28116781264543533, 0.5610827957430194, 1.0971717584517695, 1.8024907693747552, 2.3847564478074355, 7.737738086331276, 17.324120613836474, 20.876528909129483, 24.703028509693763, 38.02788480635613, 47.4556976749051, 46.31472726022044, 45.698750403619584, 45.9016389231528, 45.456426374373905, 59.33635296360139, 56.99471366020941, 52.40181430693596, 56.229365102706424, 54.56025146668958, 56.174314637337964, 52.29538863705051, 53.6265940050925, 52.90119478779455, 53.017238109342514, 50.10820442630399, 54.325234813074914, 55.165700681747936, 59.68218441932433, 63.328529557874134, 62.29438097246232, 57.99039163897115, 64.97312445794383, 58.19139349845148, 56.845169375019694, 56.7115185337682, 58.053255465722856, 19.854604390359697, 0.6567606197730188, 1.2051190628159432, 22.109369077990134, 40.94083301482662, 54.38598055993357, 66.12575607915079, 57.07955060466644, 64.21736609551215, 60.375530027574115, 62.21923228233092, 7.065143287181855, 16.92929679347623, 53.66329170042469, 58.6566375917004, 63.250246893975046, 67.07357329706993, 39.1401630832303, 31.741798270133238, 32.640905534067464, 46.289502497642275, 32.32472719684724, 47.35301002379387, 67.46034253028132, 16.00943136599756, 0.49386044964194303, 0.04857314983382822, 0.05206252711134092, 0.09656999470485796, 0.17868299097303422, 0.03938908095381433, 0.07308434364536116, 0.012279701862303961, 0.1035035270897131, 0.22274174937798133, 0.2807964132197442, 0.16649741258832718, 0.12743873386493615, 0.1559610989305281, 0.16868669269306047, 0.20460964330742437, 0.27530316443693253, 0.19911818717035557, 0.2172464781230496, 0.12839547043005306, 0.919540973920976, 54.163617472494806, 79.72659818587765, 52.357181656745176, 47.69361688244728, 71.35673092257592, 65.53783201402234, 62.875946875541445, 29.515947334228027, 64.41639892516598, 32.80441934062589, 72.28316337831559, 10.939188388086135, 7.860054258377322, 60.35328626632691, 71.41348761896934, 63.80737250851047, 61.99670053297474, 76.61785310314548, 24.627622904316073, 1.7455920096366637, 2.455101950514701, 0.5782628383847975, 33.04368980469243, 69.1080988607099, 75.05118000891902, 70.99751241745489, 67.6696402026761, 67.08688582143476, 72.35502904461276, 69.2403611829204, 64.0525088771697, 69.23294005855438, 70.8064773005824, 67.00391984754994, 61.811266560708326, 62.50690675550892, 62.10604836863857, 67.75093524686753, 68.97876262664795, 66.88312653572329, 69.55014213438957, 66.24254072866133, 64.9831735703253, 65.08268802396714, 62.84091618753249, 63.80471314153364, 69.46407748806861, 64.29489174196797, 63.850683319953184, 61.974621511274776, 53.19375653420725, 32.85905207357099, 27.406743764877323, 26.776038408279422, 26.266391123494795, 24.435683681118874, 20.755170775998025, 11.734792147913288, 4.966204560572102, 5.056200892694536, 6.277488700805172, 13.640420782950617, 24.88616201185411, 27.673666938658688, 34.01677493126162, 39.50439045506139, 31.391218785316717, 12.353809821990229, 5.733726111150557, 3.6811211176456946, 1.971055117826308, 2.2797744552935324, 1.1910460889339447, 3.3020848372290215, 9.220014522152564, 10.314924543903722, 6.8406616295537646, 7.289264577050363, 10.221246577078297, 12.38165766962113, 11.415808335427316, 14.595729727898876, 10.996366739273073, 8.857865025920253, 8.687225253351274, 16.60272809766954, 35.99171576961395, 39.5211507428077, 31.836868678369832, 27.669077765557077, 17.08330277473696, 1.472234187587615, 2.025905052019704, 1.8180749589397063, 0.7737632059762556, 1.1728030226884352, 1.951541326219036, 4.379236573173154, 12.894342830104213, 23.278753142203055, 24.165255869588545, 29.70674122533491, 46.88183138447423, 53.123824596405036, 50.87953852068994, 47.32704393325314, 49.295328509423044, 46.608587311160186, 58.90786932360742, 60.8140000220268, 54.41456287137924, 61.71173641758581, 58.18649445810626, 60.91967651920935, 54.89477472920572, 54.39005198017244, 55.135933814510224, 55.76345028415803, 55.84864416430074, 57.862651809569336, 59.080355551935014, 61.04801254887735, 64.16811289325838, 66.44933592888617, 60.09482952856249, 67.17342899691674, 60.63470848145024, 59.305272102355964, 54.06395396878643, 58.36721766379572, 27.48636199582008, 1.956993420758555, 0.8419037237763406, 16.746681044178626, 37.37009548371838, 58.46007193288496, 71.65031248523344, 61.43115751204952, 70.78660657328945, 64.07885543761715, 66.64576038237541, 12.713403894055276, 13.597572811188238, 60.05810829900927, 66.30205877365606, 72.71822483308854, 65.76590999480217, 50.77859632430538, 45.19024256737002, 34.007251416483236, 55.67621677152572, 43.42896892178444, 55.29786494470412, 81.39813976903116, 37.20883115645378, 0.8456854402057586, 0.2875661483455089, 0.1783173065632582, 0.3225772857906357, 0.2537620743556369, 0.14237330385273503, 0.1521022680906519, 0.20522721742670383], [0.06567155431595541, 0.03742611854367199, 0.05189306080161084, 0.08136608352464053, 0.058999269404598785, 0.038912842395685376, 0.10254602443667189, 0.06658601814941054, 0.17038414435040566, 0.017306885734621077, 0.037946744236133756, 0.23856072956996582, 0.2414545041298674, 27.689226981132265, 71.2717253162015, 43.77718517857213, 33.479021903007265, 127.20004066344231, 70.4001432849515, 49.295685445108724, 27.168438203873176, 37.54677472576019, 29.642910534335723, 46.24847058326968, 37.97425816136022, 0.441754519819252, 19.65389866982737, 49.975020347103, 72.65231332471295, 58.96190781747142, 49.73463789109261, 51.42745833243094, 9.52206055964193, 0.8345066239276241, 0.5232148857847337, 8.0270849600915, 55.67203160255186, 66.24325460003269, 63.78389712302916, 64.32153640254852, 64.58288392712994, 63.96580096214049, 67.4125680615825, 64.42717759839951, 64.8068904876709, 62.265833962348204, 65.31051105068576, 62.54294549265216, 57.873124537929414, 55.18996054126371, 66.97712221453267, 63.992080842295, 65.65149053450554, 62.78781514013968, 57.7631098993363, 57.659449500422326, 62.373907027706025, 59.68259626819242, 60.27210497087049, 59.763224509454545, 52.73211317677652, 39.75497891826015, 31.61057341483332, 25.76408455448766, 23.76904549137239, 15.571659553435543, 14.70327131209835, 18.54476417264631, 18.174825829844323, 17.0250791118991, 10.530344055544946, 4.365776959926852, 3.809082070665975, 6.252808657384688, 10.621702921005989, 15.606899107656172, 17.88084222424415, 21.93475692502914, 17.92089942962893, 11.138577172833106, 4.304689476566931, 0.44913363192350636, 0.5877088863522776, 1.2374335094805688, 2.9420722972962166, 3.325773256440317, 2.181950543195971, 8.133497391977619, 9.492649647497363, 7.9966066729637895, 11.232342412394862, 16.938426110052294, 21.372261585727816, 21.423756422535067, 19.865479161662442, 10.725146608967936, 2.314235419034958, 4.570220208937123, 8.73917410450597, 12.811809297530884, 22.751559134452577, 20.825312560604466, 16.554133853604718, 10.58073768692632, 6.9674154731535145, 3.2824082672595982, 1.4864522891659893, 0.4603382193994138, 0.9576524998391829, 1.3342280445560333, 4.139643003863673, 3.791548585699451, 10.168837828020896, 16.08798565403108, 20.670086722220145, 17.54780161765314, 22.950327204119777, 33.01797474584272, 39.34065111221806, 36.89920317742133, 48.710738458941066, 44.32222204823648, 46.094674448813166, 55.65810326606997, 51.99729634869484, 53.22482955071234, 53.09304575766287, 53.585044337857155, 50.011412097561745, 49.61725311894571, 49.50720710139121, 46.427475790823664, 49.718693456342145, 57.60176320229807, 57.87971804218908, 60.925693435053674, 59.8564867050417, 60.71261852018295, 56.777241768375525, 62.583365517277876, 67.54435185463198, 59.242443576935806, 38.649702072143555, 3.4220924492805236, 0.020938085039116202, 14.847075208540886, 51.03544881266933, 54.68130365494759, 55.46221617729434, 53.7830416617855, 55.484542308315156, 52.7557768360261, 66.189314165423, 28.295521466962754, 1.1162835071163795, 13.22852288523028, 37.61982887021957, 59.98235556387133, 66.74906776797387, 39.550658733614036, 32.33302889331695, 23.49003161153486, 24.54514918788787, 32.26209871230587, 17.67690839306001, 50.243534041989236, 46.240955322019516, 1.6122842532011772, 0.2646136331942774, 0.028125717297136307, 0.09230829354736114, 0.0694585261085341, 0.08969137550241525, 0.03065539133404532, 0.039987947205982866, 0.04624871266705375, 0.0234417867801723, 0.03716004854669014, 0.038489115334326224, 0.033779409789149804, 0.082375465651914, 0.024729770187649037, 0.10011414726895672, 0.036839053875976996, 0.0907772821524451, 0.05486820539038989, 0.07868572573868499, 0.11537111003793056, 0.20343648690369823, 35.95439833979453, 82.5442014201995, 46.16224119740148, 38.31663793133151, 124.42457937425183, 80.1111630470522, 35.38257560422344, 31.02543031015704, 51.04757678124213, 38.90392265012188, 69.29125001353603, 42.59268429971511, 1.5083500238195544, 19.825233682509392, 51.23482288852815, 70.75587088061918, 63.6754043640629, 55.003859766068004, 59.13964217708957, 15.63707095961417, 1.8108144066026135, 0.2359942584148338, 7.739086891374281, 55.207634741260165, 70.91405222492834, 68.43720882169663, 66.91735313784692, 67.31705834788661, 66.63481696959465, 68.09844155465403, 68.69197460912889, 65.50200900723858, 65.75500972809331, 65.60098217379662, 64.80383888367685, 61.587738529328384, 57.95040699743456, 66.5225273563016, 66.04988175053751, 66.2039210719447, 64.56297005376508, 61.18717824259112, 61.37389090753371, 64.89190393878569, 62.36464238935902, 62.95290770069246, 59.29087700382356, 54.68401009036649, 43.66970439111033, 32.85147601558317, 28.69815472633608, 28.03903179783975, 22.313922643661503, 23.489470712600216, 24.226642923970378, 24.177223020984282, 20.937170713178574, 10.161537316537673, 5.404219560084805, 2.9769799209410146, 5.282185308394894, 13.222571669086335, 15.37223154498685, 19.275282083019135, 27.60840262136152, 27.66593594704905, 19.01438759219262, 7.8225024669401115, 3.065508306026459, 2.5867514023857736, 2.2835965598783186, 1.9877717692044474, 2.397433303056225, 4.03110979545501, 6.875607006011471, 9.177476417633796, 4.628835618495941, 3.7221125825758907, 5.01879717073133, 7.82591296780494, 5.929331769866328, 2.7999599229904915, 5.59082337925511, 7.058384553078683, 6.4383352956464215, 11.91881504751021, 21.64923583307574, 29.572929566906346, 28.731247763479914, 19.934473652993482, 13.671589897524926, 5.0505266939440085, 1.7631973230069684, 1.9460042878504724, 0.7760192429827106, 0.7471192195530861, 0.4469324468124298, 2.9975694225680445, 7.63097950527745, 15.348536506775888, 20.874332381832986, 26.75611080661897, 23.078065072336507, 30.1579059708503, 36.48918997856879, 42.388250366334, 37.16207650399978, 49.1075332703129, 48.06973688064083, 48.35532073051699, 57.19085962541642, 52.389807931838504, 56.102821596207164, 54.59533706788094, 57.196649043790764, 52.07012299568423, 50.8892071631647, 49.266659905833585, 49.42480987118137, 54.14233469193982, 61.095092758055664, 60.82472378207792, 63.94009374803113, 61.843535900115974, 60.68106305214667, 57.572718051172075, 63.895127696375695, 68.6798466405561, 58.563445998776345, 37.673843829862534, 2.1638017364086646, 0.2515845153961451, 24.614986988805956, 55.001686772992535, 57.960420808484486, 60.4223592050614, 60.03582923643051, 63.54102788432952, 59.29417571713848, 71.71199567856328, 24.776910274259507, 2.4967217301168754, 19.669645024884133, 35.86893381610994, 62.697537868253654, 67.17155410397437, 50.06736470806984, 29.657576276410012, 27.962027826616843, 30.68064024371486, 37.726595786310014, 22.072190892311838, 57.41814920979162, 59.40830492204236, 3.014113244510466, 0.48743199136468673, 0.09319058934887571, 0.04903973568411124, 0.10764538145233547, 0.13709871188527153, 0.05012548528611661, 0.027001795449083852, 0.03283719825107725, 0.23071729157480503, 0.16192653366634924, 0.16869833722950953, 0.17949072343687858, 0.21012189107075815, 0.09244358467478907, 0.27132309252215975, 0.2001550871758692, 0.19663169559451843, 0.12178249987623385, 0.28314530008262206, 0.39445196128179955, 0.2654710387991321, 49.17544910984655, 93.46282482147218, 61.00454876499792, 48.17806882243003, 144.54957039125506, 89.7561614744125, 69.42727781111195, 34.96361155663767, 45.73802901852516, 43.707845518665934, 64.91390843545237, 43.26594737268264, 3.7830130179082198, 26.72040939331055, 62.68203666133266, 79.46223828100389, 69.32583747371551, 61.29319206360848, 61.16051004778955, 14.174225945626537, 3.9320476401236752, 0.8688090993992744, 14.144608128455378, 64.60457855655302, 72.8846666889806, 71.28767367332213, 69.75387788588002, 70.67372075973019, 70.49749651262837, 72.61881628344136, 70.54789112460229, 68.48918022647982, 67.6369119459583, 68.13306823853524, 68.5876944757277, 66.2012852391889, 60.075766809525035, 72.60153432046214, 71.09302213115078, 71.76603809479745, 69.41901729952905, 65.17938621582525, 65.71469560746225, 68.22691486727807, 68.09226774400281, 67.20522372953354, 65.6160048515566, 57.6338089666059, 50.07375032671037, 40.511796320638354, 32.73022967000162, 35.330133515019575, 30.5921672621081, 29.481767800546464, 30.388223624998528, 28.151903883103405, 23.696365933264456, 12.720674987762207, 8.626734460553816, 5.212227875186551, 13.123172925364587, 23.501969345154304, 27.45062331999502, 27.163825496550533, 37.300394965756325, 31.404688204488448, 17.469377748427853, 6.791657007509663, 4.288809270628037, 4.30283272458661, 6.917392996049697, 10.267791382728085, 7.815019074947604, 8.817892151494181, 15.617700334518188, 15.786251444970409, 15.544236302375795, 17.742953262021466, 21.565548143079205, 25.127819238170503, 27.410091507819395, 28.92460100112423, 25.01604933892527, 20.166952533106652, 10.27324838023032, 11.693885749386205, 22.332544096054573, 38.04890478810957, 37.581844637470866, 30.347152486924205, 25.7619252897078, 14.795758839576477, 2.738781734820335, 1.9734558535199014, 0.6354669301259903, 0.9679749523920398, 1.5696153621519766, 4.270546715105734, 11.785124001964448, 19.996105855511082, 27.13126786293522, 31.89378619194031, 27.70297488858623, 37.58003250245125, 45.27354978745984, 48.270546543982725, 40.723270908478774, 51.638034697501894, 56.13832296863679, 52.543572687333636, 60.13391986969979, 56.06042077464443, 58.09706834054763, 56.789169696069536, 58.81989056064237, 56.68898059475807, 54.24508510097381, 54.56799422540973, 51.50627443867346, 56.65163570834745, 61.661632061004646, 65.2543583992989, 65.07903629733671, 64.55451734604375, 62.96569462745421, 60.17849368433799, 61.80128805098995, 65.97838478703653, 57.367531022717884, 47.333641359882975, 5.473870067827163, 0.17454721934853062, 19.528076879439816, 59.34334262724846, 65.32142700687533, 65.24361110502674, 61.86304576935307, 66.5052689275434, 60.91858217793127, 76.71118982376592, 36.36402322400001, 3.511815441231574, 19.38696765130566, 48.27067598219841, 64.52883758852559, 76.21490017060312, 44.69278404789586, 42.74885346812587, 35.105479763400176, 33.42272804629418, 42.98201091827885, 30.19576664893858, 69.17462225883239, 72.18193484890845, 10.370640831608927, 0.9629995484025249, 0.38777044884139494, 0.3327887475250229, 0.23850333426267872, 0.49424039860886915, 0.12731849636522033, 0.12221117203514423, 0.31171581377425506], [0.026077533351077188, 0.13019365498856192, 0.014567049839834293, 0.0676880203067295, 0.06435163078769561, 0.03545387114788737, 0.02702907584006748, 0.04176501072041931, 0.022900470968095527, 0.041918128713845246, 0.2148634390605073, 0.07317913936511164, 0.3303445593243645, 18.165816145558512, 61.93056152712915, 44.57554440344534, 25.66584290996675, 42.33526306767618, 37.63736970963017, 45.32040642153832, 44.704492322860226, 14.772963004727519, 32.23688767802331, 20.79391790974525, 48.376803551950765, 5.456447389818007, 8.845292848925437, 54.01052344229914, 53.766195081895404, 71.02110939641153, 67.20079929597917, 56.547779190924864, 42.49278545379639, 8.710234857374623, 1.1636928276669596, 0.03766837469752758, 14.123836236615336, 67.14720402994465, 67.53616979045253, 66.48160919066399, 65.50419768979474, 68.39822830692415, 61.95079311247795, 63.18764586602489, 61.473134717633656, 62.689606835765225, 63.88199560103878, 62.26282942679621, 58.04764255400627, 58.78893913761262, 61.22947316015921, 60.83129767448672, 62.2302855214765, 65.28096775854787, 60.644608543765166, 61.01357021639424, 63.07878048189225, 59.859224519421986, 58.35354428137503, 46.01481499210481, 26.782855487638905, 19.162953246024347, 23.118490980517482, 23.855237614723947, 21.936006199929025, 19.480114136972738, 24.619715406048684, 24.066421947171612, 23.678797637262655, 17.46936990368751, 10.566558318753398, 4.613012777220819, 1.8752877534397188, 7.941994042165819, 17.21345486179475, 18.641713396195446, 19.569089181961555, 15.962161902458439, 9.92555772104571, 4.707097199655348, 1.245475226352292, 2.176118714194144, 2.5400406314480692, 3.244657905832414, 8.373615088001374, 12.601692830362628, 7.219803323668819, 13.101971533990676, 11.530645528147298, 13.753342878433967, 16.194123029708862, 25.281383952786847, 29.456407716197354, 32.49128672384447, 28.979739719821563, 16.28639384623497, 4.14283630348021, 0.8002226571402242, 1.2111727508806414, 7.084075587411081, 11.847049401652429, 24.04942043365971, 24.524076254137103, 22.14638448530628, 14.507585244794047, 6.584093513027315, 4.275903201872303, 1.3454302111941001, 0.46921080459029446, 0.6324014139752234, 1.76929660862492, 5.388703644275666, 5.887964492843998, 18.071691028533444, 15.628597659449424, 21.178786754608154, 17.73741683652324, 17.52842118663173, 20.864593136695124, 27.21711285652653, 27.77833930907711, 37.67748771175262, 44.41174230267925, 51.94399133805306, 52.84418313733993, 53.929267621809444, 54.82440740831437, 53.2755301075597, 47.298555758691606, 50.94671695463119, 50.14072479740266, 51.08891856285834, 50.827225869701756, 52.01226803564256, 57.65588014356552, 58.73854452563871, 60.265691895638746, 55.62464544850012, 60.60205867213588, 61.84693659505537, 60.301381541836655, 48.62328137120893, 9.632105596603887, 0.44856786066966675, 19.094782452429495, 50.54199503314111, 48.85877655398462, 48.203815260241115, 54.46110963821412, 60.198301653708185, 55.580836496045514, 60.30239743571128, 38.3937164275877, 0.9065711666499415, 9.074201391589257, 37.65973114198254, 39.08095882784936, 66.28021117179625, 63.25328673085859, 35.37959852526265, 39.91113631956039, 19.54531961871732, 28.841636988424487, 31.37718454484017, 31.951266565630515, 48.98408843624977, 52.645660215808505, 2.2667933712082524, 0.1069033640106359, 0.20435134910287397, 0.07463193318295865, 0.10351904803105902, 0.07648068720534926, 0.02784210388668843, 0.08667731747752236, 0.05632433169070752, 0.0632114276560324, 0.07371670326157924, 0.03915717464781577, 0.04587740134147387, 0.013774369088482234, 0.07348089373760647, 0.10012428261219494, 0.10543009266257287, 0.03140362366403063, 0.056878584812605576, 0.20833817791313897, 0.10690262090534934, 0.2671002626659409, 17.454092271866337, 75.72652586044805, 49.04408501040552, 29.897131112314042, 54.82580769446589, 43.692442370999245, 40.46150761265909, 39.071176436639604, 27.05161236947583, 36.04478543804538, 36.03385379237514, 60.23241842946699, 9.562663955073203, 7.399055640543661, 58.81451299113613, 56.68479150341403, 70.69557620633033, 75.56588911241101, 60.56003832047986, 51.94065340103642, 15.216613469585297, 3.142835137344176, 0.04482951946556569, 12.69150726256832, 69.42964692269602, 69.88083716361754, 72.17094436768564, 67.29768183923537, 73.026805539285, 65.92042784537038, 62.49115059452673, 64.04770397370862, 66.09061164240684, 65.73403289241176, 64.1934435598312, 59.912498151102376, 63.30233596986341, 63.47395535438292, 63.82904360371252, 63.30891378464238, 67.22062295483005, 63.488020973820845, 63.60981449004143, 64.03105351232713, 62.95223305302282, 62.48096027681905, 52.312168536647675, 33.23047699466829, 23.461064907812304, 26.03937610503166, 29.3003228787453, 27.392444764414144, 25.425007420201457, 27.889734621970888, 25.36440876222426, 26.412220924131333, 17.895356955066806, 11.462185459752238, 5.156475795853523, 3.0701764168277865, 11.716360930473575, 18.289311970433882, 16.918610295941754, 23.78410935401917, 27.70255127260762, 19.76823772153547, 10.251541983696724, 4.605276392352197, 3.6602153749235216, 3.38102204665061, 3.249150980864802, 2.036429874358639, 2.0071957140199603, 6.460310864833094, 13.137816113810386, 11.922352044813096, 12.05371222188396, 12.808577264508894, 19.74072817833193, 22.879610792283092, 19.464867884112945, 23.412537344040413, 14.928913501001174, 10.815275811379957, 7.96948250262968, 6.9181132412725885, 12.352864530778701, 21.731964503565145, 32.41853067951818, 26.40080486574481, 20.134210548093243, 18.68082138799852, 8.904147032768496, 2.5476686608406807, 0.5849706429627635, 1.4235809853961392, 0.5422302299449521, 3.862317949533463, 10.366742976250189, 11.308370694037407, 20.322707891464233, 20.122668973861202, 27.211199883491766, 24.588342328225416, 22.564271842279744, 26.106334886243268, 31.97227085790327, 35.853675796139626, 41.93993130037862, 49.160673541407434, 54.387949589760076, 54.90208994957709, 55.66731299123457, 59.586776687252915, 57.93230133671915, 51.6639615643409, 51.24678219518354, 52.5650711982481, 53.21608266522808, 53.47750863721294, 54.22023296356202, 61.00265818257486, 60.036507806470325, 62.104149941475164, 56.636613030587476, 59.254532321806884, 62.47888142062772, 59.61530800788634, 44.46803615939233, 8.638327025598096, 1.4760974770592106, 29.49816526905183, 53.73596145260719, 58.776434621503284, 54.28503836354902, 60.90157870323428, 64.39055442810059, 61.88270468865672, 62.701483772647, 32.83303695340311, 1.3763891112419868, 19.130342660411713, 35.98877399198471, 46.26070053346696, 64.31484091666438, 68.92743449057303, 40.54250847908759, 35.754871291498986, 27.14157977411824, 32.110112751683886, 26.717644122339067, 34.435182002282914, 62.32903511293473, 62.2275516294664, 3.624779702194276, 0.7778334617614747, 0.1479342441645361, 0.13388805271637055, 0.11140440635743643, 0.04350076677397855, 0.044101103914961706, 0.0697807809938827, 0.0758867392376546, 0.3096010740245542, 0.32269161675245533, 0.13504665344953537, 0.15744229928860742, 0.21253868396724426, 0.3034416964698223, 0.20987297378240094, 0.2545050264246041, 0.18617240441662652, 0.1659081684004876, 0.5041654966771603, 0.23929268061634035, 0.6261729352897214, 32.34957345070378, 85.26427884255686, 62.39332668242916, 39.631549773677705, 58.81399131590321, 48.70581196200464, 67.00265684435445, 57.778987653793834, 21.799717564736646, 47.499141846933675, 35.70223700615668, 61.89450317813505, 11.390356075379158, 14.925428475103072, 63.0733754557948, 61.96356042738884, 72.247344293902, 75.33774052896808, 71.49199778033842, 57.23334673912295, 10.48672337685862, 2.1154531307758826, 0.12459987248744696, 22.289856941469257, 75.13530700437485, 72.32299112504529, 74.69611137144028, 70.13361823174262, 76.29289257910945, 66.98970517804547, 64.84074446462816, 66.663756216726, 69.87294535483085, 69.1729199501776, 69.08386645778533, 63.89080524444581, 66.8549717626264, 65.46540544879052, 67.89835360742384, 67.17438605523878, 72.67655357237786, 67.00500242171749, 67.827178278277, 70.1410864245507, 65.378371977037, 64.33240921266618, 60.36074661439466, 41.84092675485919, 29.79116435973875, 28.94713894013436, 33.459162942824825, 32.587606406980946, 32.01665443758811, 35.33273012407365, 31.984171329006074, 31.377563053561797, 22.89033062996403, 14.020805378114025, 8.967678643042042, 7.920802456717338, 20.924725032621815, 29.513778263522735, 24.563217586086644, 32.47333403556578, 37.19033325872114, 19.733385501369355, 9.6494669875791, 6.144379636933727, 8.97088812243554, 9.265459102969016, 12.001064208246047, 24.448547094098984, 26.484778888763923, 19.578116516913138, 23.476399414000973, 18.979694228018484, 20.827432601682602, 25.33635989312203, 33.96887886908747, 37.62837179245488, 34.13824681312808, 36.300021909898334, 30.18348570792906, 22.83837099229136, 11.555368227343406, 6.238387082853626, 12.347995888802314, 23.521534127573815, 39.89498007682062, 37.389036609280495, 31.413048736510742, 30.237300626693237, 18.763661846037834, 5.875937035006862, 0.9519892714677319, 0.7838421651432592, 0.965871949109339, 4.340329112545136, 14.411077287889297, 16.792735553556874, 26.563802880625573, 26.79502856346869, 35.13227347404727, 31.38971651754072, 29.672036094050256, 35.78932146872244, 38.05762029463245, 42.21107690565048, 47.71094591386857, 50.86081704785747, 59.60094821068549, 57.86899035976779, 59.843946887600815, 60.776753194870494, 61.09777173688335, 53.23952667174801, 55.2318710665549, 57.06938774354997, 58.58363836042343, 55.925338268280036, 56.88632288286763, 61.66382466593097, 64.31464872052594, 65.4359249145754, 58.10139471484769, 60.73165770499938, 60.50609004112982, 62.645821417531664, 52.528887333408484, 15.489120137306953, 0.8881344333771737, 25.237833876763624, 57.88437781795379, 60.77993031471007, 57.23108353153352, 64.36370188190092, 67.55225935289937, 68.43995448081725, 67.65164436832552, 49.95573797533589, 2.5385900899287197, 15.468541422197896, 46.41113127431562, 53.89776706695557, 69.91191018012263, 75.49694953426238, 37.16658330732776, 54.69808355454476, 28.33488049045686, 38.160351091815585, 40.04930180888022, 46.57887927947506, 66.70006167504096, 76.69339795266428, 7.509491933930305, 0.833545275513203, 0.7325971955733915, 0.19090111277276473, 0.29221979540682613, 0.3161223821582333, 0.1059199446031163, 0.2245897832777231, 0.1485093923345689], [0.05794412501516843, 0.03343012349139298, 0.015294528847950843, 0.03798402207452924, 0.046325198885413914, 0.04678629571571947, 0.11602845178135943, 0.03692147344531071, 0.10062881279736759, 0.09037112531762931, 0.3905906636388071, 0.1106466841132891, 0.525161913566051, 5.01116668985736, 63.738985984556145, 56.40335752118019, 37.22884701144311, 33.1374736755125, 54.93073894131569, 37.757076524919086, 52.00568629849342, 34.20342091591128, 31.960843032406224, 27.428754145099273, 30.024106079532256, 18.692612032736502, 1.850989650814764, 29.247782730287124, 73.55795721853934, 55.9752151273912, 54.29623673039099, 46.38822855487947, 68.84824183679396, 63.24603034603981, 37.72831770681566, 14.47791741740319, 0.9239284513938812, 22.620997159711777, 60.67037459342711, 68.13579820817517, 68.13731224306169, 65.79478648401076, 67.60852183065107, 60.038986744419226, 61.78239007149974, 59.60538441135038, 60.93412653092415, 63.106390045535186, 63.45426897848807, 60.108393084618356, 63.372942555335264, 63.20564170037547, 65.40677778182491, 60.36222927031979, 62.17803955078126, 57.39756461112731, 62.40375626471735, 58.68168584762081, 37.80046970613542, 22.642617264101585, 16.209486953673824, 14.084064383660595, 19.464734523527085, 26.83867277637605, 24.655681579343735, 32.0206376044981, 30.091253134512133, 22.62011658760809, 20.056312276471047, 14.306803038043363, 8.634578220305904, 2.24119818979694, 5.263422160379348, 10.927809592216246, 19.825798503814205, 19.11333918571472, 13.17859503530687, 8.703397185571733, 1.4014062333491542, 0.6946560476095446, 2.6272155536759287, 0.9648194668754455, 2.4199575137707496, 8.351572348225503, 15.291363058551667, 19.429552824266498, 12.352394826950567, 19.52586466266263, 18.731431730331916, 17.002468609040786, 25.915384100329494, 26.288417193197436, 31.911399595199097, 33.48249320060977, 33.14412993769492, 28.462226121656357, 7.894010216959062, 1.239068770120221, 1.6010098904371264, 1.1477487606386985, 5.413849469154112, 12.140886898963684, 18.25053934128054, 23.619514934478268, 24.447256634312293, 11.337554108711982, 5.049016581427667, 3.1473299284135146, 0.5352414243163601, 1.0282780230045319, 1.4842703481835704, 7.365759130447143, 6.670549415772961, 12.33413423261335, 21.5843931705721, 16.440911696803187, 19.217909574508667, 20.32285890271587, 19.904993118778354, 19.38919947993371, 24.665695390393658, 33.1297662181239, 40.178320330958215, 44.8668941374748, 50.18618899006998, 51.52015962908345, 50.89209402761152, 53.615721194974846, 50.52403842249225, 48.90608818300309, 48.30630287047356, 48.710456048288655, 53.07580301838537, 57.22691012967018, 57.89188131209343, 56.48155389293548, 59.796278322896654, 58.53178462674541, 55.12945013661539, 53.885215482404156, 48.33332407859064, 22.959460443066014, 1.8742062824387706, 15.581303681096724, 58.37459564208985, 42.51060478148922, 43.23348583713655, 57.35829384096208, 53.17448985192084, 47.50101673987604, 52.75740069727744, 39.9508071714832, 3.418542459126442, 7.789786467629095, 67.99600493523383, 43.67121450362667, 43.65386586035452, 71.53876027753277, 48.151788942275516, 31.183609693281113, 33.58439245531636, 14.01897853420627, 39.00484523465557, 34.03220553551951, 32.782685487501084, 57.543013941857126, 49.96137442127351, 0.33621395727799785, 0.11028736589416382, 0.13924803284387435, 0.05741297327462704, 0.04481820051648444, 0.05247253353797621, 0.06424052505603721, 0.08059940571265836, 0.11524816058696279, 0.05668018719241504, 0.08442444441419455, 0.05691863588928696, 0.03087964250646051, 0.08300090749417582, 0.08758507038076078, 0.0824316428794015, 0.06841941210891932, 0.09699737983605555, 0.1168902011047448, 0.2260403554405897, 0.07611547777008626, 0.4999486116632339, 6.367166340351106, 75.6581981720463, 65.07725554127848, 34.688912283989694, 39.478028205133256, 58.10749007809547, 44.25864827248358, 36.88969927449381, 39.50677917849633, 37.63915438805857, 34.85690739846999, 44.354185442770685, 26.152860080042196, 2.9212825096422628, 23.578390844406623, 77.8079237476472, 61.89357749877438, 55.9218708930477, 52.46355633581839, 70.11537921044135, 66.3811965142527, 46.428883921715524, 21.720709262355683, 2.001314119946572, 20.05102296029368, 61.7093712283719, 71.94194855228548, 73.66262174421742, 66.25431568391862, 67.32389896146714, 61.60394576288039, 64.18096650031306, 62.44714944593368, 63.076638867778165, 64.78991054719495, 61.54449047580842, 63.84928303380167, 64.72136712843373, 66.17686456249606, 66.56046452060824, 63.6529331053457, 62.754769171437914, 57.77991725552467, 64.04118499448224, 60.20491084744854, 45.218809189335, 25.876740909391835, 18.514199103078536, 18.563197351271107, 24.873890876770023, 31.531145418843916, 28.517111847477576, 37.67851929510794, 34.96721229245586, 23.51392080706935, 21.41323466454783, 13.681707651384416, 9.889045357704163, 6.106421880183682, 9.227754339095085, 16.059907367152555, 18.204139663327126, 23.32874571123431, 25.182183288758804, 19.916497430493756, 9.667519696297186, 3.308049781668571, 3.768738287110483, 2.80640535777615, 3.582423742740385, 3.9875741831717955, 5.477527187716577, 9.13916172519807, 10.495850732249599, 19.613309983284243, 16.727553606033325, 18.082838404563166, 26.67389596662214, 36.3688987301242, 38.23024380591608, 40.97584801335489, 34.48653759494905, 27.77022784756076, 9.461488377663398, 7.6484311107666265, 5.0888060850481835, 4.701159221510734, 11.18385014995452, 24.482173573586252, 32.40388454929475, 25.539617115451446, 25.572639549932173, 17.888845820580762, 10.210705207240197, 1.6039340174005878, 1.7217200970457447, 2.353479713201523, 4.387923642512291, 12.144486654189325, 13.134934152326277, 16.78615185522264, 28.06763960469154, 21.620500549193352, 23.36744969890964, 24.58382768015708, 23.755648636048843, 22.21740488083132, 30.066740282120247, 37.69233388285483, 45.864674506648896, 48.022825333379934, 54.19702429925242, 53.89547248040476, 55.85471207095731, 56.43269292769894, 55.67763274715793, 51.54586684319281, 51.586361392851806, 52.400790568320986, 56.70493679661905, 59.84668862435126, 58.951474312813055, 59.81339554632864, 62.05261784215128, 56.54260950703775, 55.810883506651855, 54.501266864038286, 46.71668391073904, 23.834147030307403, 2.419480210350406, 22.613883941404282, 63.44185859926286, 46.70711332751859, 48.492540928625296, 63.19475320077712, 57.9790638339135, 52.520615054715066, 60.74462113841888, 34.69457618651852, 3.0349523069397097, 14.095443179530484, 74.84651073332756, 46.74698029795001, 48.61802539517803, 69.41411433681365, 57.69044406952397, 30.987087180537564, 36.354970393642304, 19.106122024597664, 36.212003923231556, 35.94135645897158, 36.146625857199396, 69.17695214671474, 55.204998908504365, 1.090396599423501, 0.12850603223928522, 0.06797686609770022, 0.035165733988246614, 0.08496111198779076, 0.05818474174086606, 0.07108356713527633, 0.06618784395076575, 0.254189474808593, 0.10057781432424823, 0.08922344899826473, 0.14327005573338078, 0.17269894030065308, 0.244131644346541, 0.192095949464748, 0.2267068672564722, 0.29455002036786854, 0.32174261767537365, 0.3300277360023991, 0.4504680038700181, 0.3743886701281994, 0.8516832344955014, 10.503298332614284, 92.59803633536063, 75.14876073406589, 51.84405719080279, 44.295067479533536, 65.83631653939524, 55.51180670338293, 69.19392032008018, 43.15826262197187, 49.22116825657506, 42.59200965204547, 46.7687729866274, 26.777713260343, 4.556879737684804, 35.84075943116219, 83.71621347242787, 64.72731344161495, 62.37016900893181, 57.04064461492724, 78.78709639272383, 74.6059831496208, 47.02828484196817, 17.252529513451364, 2.3324285976348387, 31.793098949616958, 69.89079213911488, 75.46534307541387, 76.77985483600249, 70.75849102389428, 70.25739254490023, 63.62630021187567, 65.97265812658495, 64.96228694915771, 66.44763362023139, 68.48768188107398, 65.61942515834686, 65.62090781427199, 67.67994034674861, 69.95246748770438, 71.24901479290378, 67.15904958786504, 67.78313790598224, 62.92610222293485, 69.26062414723059, 65.83816005337623, 52.2469905114943, 34.53752840718916, 23.462775061207434, 23.909668345605176, 29.907141000993793, 35.9656673092996, 33.352282277999386, 43.041980035843395, 39.499636542412546, 26.65384873267143, 22.619512542601555, 17.11819225741971, 11.545731944422569, 8.068511072666414, 14.618908974432177, 24.071648505426225, 26.054587056559903, 31.351214531929266, 29.28643180478004, 18.542853978372392, 7.131047931409652, 2.0871265088358233, 6.045868819759739, 9.225353848549629, 14.195022352280157, 21.621549783214448, 29.973903663696785, 34.30038190657093, 24.634791035805982, 30.909194792470625, 27.66665570197567, 29.826936375710275, 39.17248341345018, 38.020742170272335, 43.946121661893784, 43.4185746408278, 43.78021324834516, 41.68054496088336, 30.006216149176325, 12.042771750880826, 5.706752461771812, 3.999447687979668, 10.785548167843974, 24.01337581296121, 37.87609300305767, 34.4289218994879, 32.57495676317523, 29.603653492466098, 15.800899536378923, 2.13020590043837, 1.4566247477646799, 3.974933364698964, 6.113339470278833, 13.95455752649615, 18.507436936901463, 23.354651005037372, 32.537117658122895, 28.86369443708851, 29.611231511639012, 31.010435088988277, 27.859320563654748, 27.25499510765076, 34.1401844639932, 42.87647170405234, 51.13960343022501, 50.882205732407115, 56.0965967947437, 56.67657021553286, 57.92140891475063, 57.68952231253348, 57.97044638664492, 57.41407386718258, 55.00416571094144, 54.293514605491396, 57.5483169863301, 63.27465580355737, 62.655627342962454, 61.83452229345999, 63.69977797231367, 59.195449659901286, 54.527562433673495, 57.705392222250666, 51.99377013790993, 31.610222362702896, 3.018376860887774, 19.66757989698841, 67.69040523036834, 51.411772774111846, 53.260550575871626, 65.5402325045678, 63.28035500741775, 57.418306104598514, 64.76557224027573, 47.359242669997684, 6.020266529052488, 12.145552558283653, 78.04227752070274, 53.24636728532853, 54.395264810131444, 75.59064711293867, 59.46815636850173, 35.359480688648844, 52.034990326050796, 18.321995119894705, 53.206802337400376, 45.32634096760904, 48.72340771459764, 74.52154236455118, 76.3989770027899, 3.337416567148701, 0.26298894456798033, 0.39449510735369503, 0.13941424327992624, 0.3425042439372309, 0.2862907345256498, 0.30300557793628785, 0.16347122739159292, 0.5137189501716245], [0.012646989311061561, 0.0457072570439308, 0.07461261244550829, 0.07092704005058735, 0.017638607551493955, 0.04875489270254489, 0.14694050555267643, 0.07522167532794899, 0.043239841057408246, 0.060805482564554106, 0.20112553671483072, 0.014769357381268375, 0.028878844928957766, 0.6911640349895724, 36.559329801990145, 54.65329400954708, 38.7567239422952, 30.3387370417195, 52.17134760272119, 33.51784552297285, 49.89824387335008, 42.86770520671722, 28.358251933128606, 20.911865542011878, 26.779052749756847, 37.96196153087001, 12.08396448243049, 0.4015843011438847, 19.26952600479126, 62.34235940441009, 65.10525734193864, 57.4499596318891, 49.98208453578334, 57.55315326875257, 62.20715530457036, 60.39340426844936, 24.545482589352517, 1.4905788677354015, 22.03199640397103, 48.6876670775875, 61.34475946426392, 61.265904134319676, 53.528581819226666, 55.305191932186005, 60.24849622480331, 60.44410090292654, 62.09874099300754, 58.92447663891701, 60.10952272722798, 60.20909209405223, 60.25736862613309, 61.235717573473536, 60.36159776872205, 63.3766217385569, 56.35546930374638, 54.54492284405617, 43.13500688922021, 29.073964857286025, 23.597471214109852, 20.004415396721136, 15.18725452884551, 17.227526364787934, 25.57630696604329, 27.54517793655396, 25.848221355868926, 33.3796682665425, 24.916817295935846, 22.86887134275129, 14.915799056330036, 9.92521059128546, 3.6987624677919575, 3.7353003265396243, 12.22704666276132, 20.688219839526763, 21.14051030528161, 12.278175738550003, 7.0435790765670045, 2.507996092880926, 0.760697668358203, 0.8780210308970944, 1.3780193463448556, 1.6171396571782328, 2.2090448054575154, 13.957565003825774, 15.517303347587587, 9.919642786825857, 20.414840444441765, 34.97473932081653, 21.79499306986409, 27.720617709621308, 32.65667934571543, 31.607761075419766, 39.44113439129245, 38.62613647214828, 41.199407423696215, 27.34676484138735, 6.331938062944721, 1.9934353040110682, 2.719387330355183, 0.8119738330283474, 0.9970294191471993, 3.822366893291474, 10.279293733258402, 18.224920380500055, 25.0511545519675, 23.92149429167471, 9.569765406270182, 4.677130291538854, 0.6830976194431705, 3.2313757798364087, 8.107529830548073, 6.706708275502728, 13.72959488822568, 9.499907993501234, 13.80800404856282, 24.609958510245047, 19.443230129057362, 18.411397703232304, 20.98548254659099, 23.86392370347054, 30.135050319856216, 34.93007529166437, 41.53555846983387, 45.86275254526446, 51.03155782145839, 55.06892012011621, 54.37307596206666, 51.4251402116591, 50.86194276809693, 49.7314097804408, 50.52750579772457, 52.59311614498016, 54.21914646702429, 52.15357534347042, 57.144787465372396, 58.751280461588216, 57.99173308957008, 50.008325192236136, 61.156740650053955, 44.323022211751635, 42.44284191439229, 18.945079311247795, 8.80686342716217, 53.02050152132588, 49.347225389172955, 56.82411016956453, 43.21253253567604, 37.828177329032656, 47.31291163352228, 54.72286508929346, 55.88624400477256, 7.718422374417705, 1.2388026618188428, 66.66158322365054, 60.45325571490873, 21.013607901911584, 50.56177946829027, 61.572955116148925, 41.1338803075975, 38.513580137683505, 21.942982135280488, 21.000611128345614, 47.49201490033058, 21.83941391206557, 38.867256333751065, 63.78230071836903, 26.95865611876211, 0.27803797575254596, 0.18581410509444055, 0.017237535625275587, 0.05148802628560413, 0.11899937905611531, 0.07103207836588545, 0.12072767341329206, 0.07333697646015114, 0.12802967110708838, 0.012163786056090989, 0.025248890517339594, 0.03618170830210851, 0.03753223704294332, 0.020430871630988775, 0.009746265376076825, 0.11533880411016366, 0.09743281655133733, 0.058220732551548755, 0.044957436996722416, 0.2177257120849625, 0.053428534658685814, 0.13620551465259445, 0.8107818002181669, 38.4386864016133, 69.63172743397375, 35.57048066969841, 33.48362676558956, 63.06626812104256, 38.290071718154415, 41.40151146919497, 36.71627952206519, 39.068109143164854, 31.066138628990423, 37.21673865472117, 51.45797829474173, 22.652738940331247, 0.5537027949767729, 15.473095293967956, 62.243225420674975, 67.91251336374592, 65.18453628786149, 57.67229526273666, 67.58737241068195, 65.73569205499464, 64.76166163721393, 32.19392203515576, 2.6605275081050013, 20.995282588466523, 48.68948313497728, 60.126526201924975, 63.53500704611502, 53.37274212991038, 54.44798146524737, 59.540849654905266, 64.5492103792006, 65.69910418602728, 63.36249728356639, 62.6289983718626, 61.39318896878151, 65.40622472763062, 62.061804033094845, 62.34569734142673, 62.83571904705417, 58.894603867684644, 58.39422318243212, 49.79739581384967, 34.4354957918967, 26.54449305226726, 23.311648099653183, 19.472845985043435, 21.94850287129802, 29.244933128356937, 30.356795633992842, 30.241444610780288, 35.505655657860544, 26.538289823839744, 24.78415293078269, 16.021967261068284, 11.761458381529778, 5.711789275369337, 6.815007367441732, 11.55854436659044, 17.73643624398016, 26.670155986662834, 24.113904199292584, 16.689386983071607, 9.609702979364704, 1.842255880755763, 1.7421682707725035, 3.4892696574811017, 3.2278998244193295, 1.0580716113890372, 10.318129120334502, 24.95577427648729, 23.446216775525002, 18.216871676906464, 30.73919338564719, 22.82162835521083, 25.518905039756532, 31.986395312893777, 36.633372383732954, 42.34600251720798, 41.3010674138223, 40.85663149433751, 35.81618185966246, 12.99803754975719, 2.579864210659458, 2.213746991849715, 1.1373240813132257, 2.7837973063991917, 10.017995238304138, 21.529111285363477, 27.8001457260501, 29.00162066182783, 23.924063444137577, 13.728391701175322, 5.0370999305479, 2.970216529023263, 6.773672940269594, 10.446281779196955, 10.629756527562296, 14.90056751235839, 16.165970217797064, 16.462997582650956, 29.14999019715094, 24.786298467266946, 21.546006894880726, 24.87479498309474, 26.383738633125063, 31.68361971455236, 37.988508132196245, 44.62375425523327, 50.348057362341116, 54.504651869496996, 57.69005575487691, 58.5334437893283, 55.47902353348271, 53.661110862608886, 52.76472376238916, 54.597113901569, 55.92585602114278, 55.161209567900634, 53.85075746044036, 59.524273718557055, 60.22941781628517, 60.67184155987155, 51.226311345254224, 61.28386466733871, 41.67715603305448, 47.38845648304109, 20.176566262399, 12.752144163654698, 58.70609475720314, 54.888495014559844, 62.11561895185902, 48.75352367278069, 43.7927334539352, 53.397759006869414, 59.890085727937766, 54.752679024973226, 5.747914304656367, 4.352409522379599, 70.574994702493, 71.71074836484848, 28.24223214580167, 48.53553795045423, 63.95175103218325, 49.490744913778, 34.58757785058791, 30.433079850289133, 25.43567822825524, 43.136685663653964, 24.447858718133745, 47.229863289863836, 75.5526158117479, 31.35579586029053, 0.402441063234883, 0.0762579471413647, 0.05005352281694932, 0.02412359928712249, 0.055055119352595466, 0.048666647034547025, 0.06821012454888514, 0.13890298684277844, 0.13879389592236088, 0.19716705315776412, 0.1064401489472197, 0.1580310991454509, 0.22890598393015324, 0.0973585213444406, 0.0926475479237495, 0.24795416261880632, 0.18246591782137273, 0.1814723630706149, 0.14676606733231776, 0.46443378672965113, 0.24945885123264408, 0.2502998319124022, 2.546748374739001, 63.639275412405695, 77.34146764201503, 54.975528486313365, 43.31877777653356, 67.48820704798545, 45.0724341792445, 72.23502805156093, 54.0931167910176, 45.97166892020933, 39.551035281150575, 41.09467229535503, 51.27349745842719, 21.010289576745805, 1.6512349824751578, 27.734524473067257, 71.43757881656771, 79.02231308721727, 67.66402336858934, 62.98250982838293, 70.7770909032514, 74.73550765745102, 69.76395053248253, 28.142790256008027, 3.1582601031949444, 33.16225521026119, 58.138402277423495, 64.80854180551344, 66.25138175102973, 56.45495630079701, 55.118263536883944, 63.73272588176113, 66.68601958982407, 68.95975482079291, 64.74862367876115, 66.42184795871859, 65.98482531885948, 68.2834440662015, 63.4689425653027, 65.43017864227295, 67.06631691225114, 62.27953087898993, 63.528080140390706, 56.4388902725712, 41.34098537506596, 30.672964165287635, 29.02376244145055, 26.089394169469035, 27.105672436375773, 33.430710069594845, 36.525620952729255, 36.37098935342605, 43.11276705034318, 29.578550323363277, 27.052914596373036, 18.011921951847693, 13.814999595765146, 6.495737712229452, 10.341137743765309, 18.048737318285053, 24.945664367368146, 36.787211664261356, 29.366291261488392, 17.73051150383488, 7.200550369678005, 1.1946943834904702, 5.6918401006729376, 10.058740819654158, 17.598992470772036, 25.130535479514833, 30.759779945496593, 40.87088146517354, 30.551596226230746, 29.305735749583093, 44.76007623057212, 31.03426741015527, 40.14347791671753, 49.8571531234249, 49.444959086756555, 51.8421156175675, 48.317591451829486, 48.66020264164094, 46.53848278907038, 24.16005676792514, 11.657204724127247, 7.515018553503099, 3.6019662166795428, 1.7079104122615631, 9.973040953759226, 25.31263739831986, 34.00986763738817, 33.619827147453066, 35.84637626524895, 19.51085179082809, 7.328069565757629, 5.903976588479935, 7.372215842047046, 13.262081703832074, 13.548170558867918, 19.996427489865212, 22.423674483453077, 25.575661736149943, 34.07746576493786, 29.79169191852693, 25.877609714385002, 30.042907960953254, 31.24726191643746, 35.82460711079259, 41.83041088042721, 47.434779674776145, 53.528295486204094, 58.84583703933224, 62.25826771028581, 59.49404793400919, 59.31025743484498, 58.4637354266259, 57.324690895695845, 58.228718773011245, 59.53437382175077, 57.60839200788929, 57.14674080571821, 61.23641183299404, 64.18333168952697, 60.95552698258431, 52.60685228532361, 64.25102787633097, 48.49610244074176, 50.452784645941954, 24.936595847529752, 10.258417898608792, 61.94426628851122, 56.20230859325778, 65.79426873114802, 50.329500629055886, 45.4406427568005, 56.91750964810772, 65.59874642279841, 63.59585477459816, 12.411890318316798, 3.783348135409817, 78.79847126622354, 69.31324666546237, 29.895405269438225, 54.99939218644173, 72.94667936140492, 47.368464162272794, 51.6170931631519, 33.087585049290816, 27.44404354403096, 62.78406535425494, 29.060713129658854, 55.159585706649295, 78.60683994908487, 51.69252818630588, 0.7490591993255, 0.29523668029615957, 0.19120984620624976, 0.13436842048841138, 0.2014788411437504, 0.23519309898537977, 0.21825840366223168, 0.24073764501560121, 0.2706546041994326], [0.06402811185727197, 0.03584988114814605, 0.04274100673595264, 0.023472688851817965, 0.08314457962349539, 0.07479952257727424, 0.007122939005644331, 0.16949041085618158, 0.09558358755443366, 0.06994604914178772, 0.1486217161460269, 0.1272566730697309, 0.1987822422938001, 0.3847264750830589, 6.536063599971033, 58.39406628762522, 48.0137764253924, 39.09179633663547, 39.768220839961884, 18.109934137713527, 41.07094195581252, 52.79370223322223, 27.146731807339577, 14.541066596584937, 17.102367454959502, 23.175506553342267, 50.231661027477635, 12.391939182435314, 0.5718989766413166, 20.061685923607122, 56.51178359985352, 57.646737098693855, 76.27825429362636, 62.76008790539157, 62.34244177418371, 58.752386569976814, 59.3011575360452, 15.769701984620864, 1.2327940810111262, 12.846998841531816, 37.930351149651315, 37.91157476363644, 54.722782719519834, 56.96472714024206, 52.96561187313449, 50.81906733974334, 61.567216688586825, 61.742272069377286, 63.91366089543989, 60.72677043176467, 61.55634780083934, 60.92305760229788, 60.797471154120664, 51.98716878890992, 43.897625477083274, 28.575472793271466, 21.71007767800362, 22.982068984739243, 25.80727965601029, 24.827314692158854, 21.739315025268063, 16.501646657143873, 18.22109606958205, 22.187443856270086, 26.434690221663445, 26.204503966915993, 19.134068912075413, 13.46066346091609, 5.622354822774088, 4.417549794720066, 1.7919381227224105, 10.856034140433035, 22.388877176469375, 22.497320905808483, 14.421457840550332, 6.56647079413937, 2.602954958715747, 0.1254375206847345, 1.2140800851968028, 3.0884833441626642, 1.8712456284030792, 1.3541807739004013, 2.6570687130574258, 8.826470375061035, 15.239288691551456, 19.33421765604327, 32.211913947136175, 34.81504786399103, 21.99431419372559, 35.71258029630108, 35.62076153293733, 28.867093170842818, 29.38603255056566, 35.225857303988555, 33.37122732593168, 18.610520747400102, 1.619505459262479, 1.871868917538274, 1.4358494238507364, 2.336702019937577, 1.2188043349212216, 1.5649009183529885, 7.202666978682242, 15.764677428430128, 20.65258510651127, 26.398800534586755, 16.88924547164671, 8.533865482576433, 7.415242771948538, 5.491838935882815, 9.957217131891559, 9.504787421995594, 16.380490526076287, 20.856114933567664, 5.761133672729616, 6.643962119856189, 22.498989874316802, 22.777368330186416, 24.3941810823256, 27.90758925099527, 32.78351310760745, 42.03833180089151, 47.97641584950109, 51.68249084103493, 50.17337068434685, 50.549247495589725, 51.383908256407715, 49.995063658683534, 50.635641621005156, 50.783852300336285, 49.64991861774076, 54.44614579600673, 55.36911087651407, 59.898165810492735, 58.20739284638436, 58.50392403141145, 56.40273386432279, 57.28116435389365, 46.07054794988325, 35.63100676382742, 41.90328851822884, 10.955310310086897, 33.062273994568855, 58.68740074096188, 46.55626681543166, 56.95954176687426, 49.12064183142878, 51.286178481194284, 59.4029430420168, 57.07230990932834, 23.761255664210168, 1.16126059043792, 22.31744100970607, 57.15618587309315, 19.531004928773452, 22.300137473690896, 62.11624653108659, 56.12005256837415, 29.996255290123727, 36.74121795162078, 14.948235096470004, 30.988642400310887, 33.85165099174746, 27.35115005124, 49.70599282172419, 63.7293291091919, 14.176242043895108, 0.31433139116533343, 0.1556100621218643, 0.1217237332715623, 0.049981242421293454, 0.0752851227298379, 0.06799273177861206, 0.08262597640315372, 0.05016269417659891, 0.05700688538772445, 0.11186055809019074, 0.029588052740080223, 0.05348949610526043, 0.007818266739993687, 0.009293962277532106, 0.05589777776490777, 0.06389092849267107, 0.06633577552894432, 0.10738841257989408, 0.0450551170375078, 0.029331802075067838, 0.07917304192819903, 0.11588631948876767, 0.24269979537254383, 7.99484258697879, 73.0446837025304, 52.28810479564052, 39.07720904196463, 46.791561957328554, 18.72935679651076, 37.29411525111045, 41.8199420744373, 35.018195259955625, 24.22600357763229, 21.993984714631114, 33.050714769671046, 66.38204374620992, 16.81969988730646, 0.27640813901539774, 20.162916414199337, 63.628759537973714, 63.18480607002013, 83.2621677460209, 65.12339045924526, 70.65780378157093, 62.86497600616948, 65.85956050503638, 23.64797173007842, 2.0271750419370593, 13.127174723532892, 41.17495929041217, 40.904366739334606, 57.070693892817346, 61.81116457908385, 54.58048697440855, 53.03319823357367, 61.30447280022406, 64.08399374254289, 67.4198793595837, 62.35841758789555, 65.42153766078334, 62.5725946887847, 63.877508409561656, 55.44773086424797, 50.628122437384825, 35.29004296948833, 26.719003223603774, 27.043345974337672, 28.97900623659934, 27.5649937506645, 24.40908216661023, 22.645659062170214, 20.804271005815078, 25.78958780534806, 33.028294501766084, 28.115472908942934, 22.548325446344194, 15.308992151291141, 9.235773624912385, 5.912146395252598, 6.268880569165753, 12.611654670007768, 18.4827926851088, 24.623251422759026, 26.009099329671553, 15.869814599713973, 6.72970268034166, 0.69415416808859, 0.17882393582934336, 0.6432977583139174, 1.2482684442112524, 2.1006547635601414, 9.095886215086907, 18.460882325326246, 30.617460666164277, 24.207315444946293, 28.161678429572817, 38.1967467646445, 26.672840849045787, 33.242855994932114, 36.77755478889712, 40.56330880811138, 46.29552333585678, 47.574000281672326, 46.62502988692253, 36.69772278877997, 14.30881521394176, 3.8027293018756376, 2.1877460902737034, 2.6068724259253475, 0.837733815273931, 2.268018376442694, 11.734806856801434, 25.14165932132352, 32.569583116039155, 25.296351717364406, 17.514628171920776, 11.548956132704213, 7.304547602130521, 8.059485698899916, 13.508258481179515, 21.86320504834575, 18.80537036926516, 27.66082705989961, 10.576564285062975, 8.651723880921642, 24.8325647846345, 27.401834918606667, 28.043695495974635, 30.74068584749776, 34.82285730300411, 45.45530849887479, 50.25816448273198, 53.95629667466687, 52.17307736796718, 54.28663869057932, 53.61963572040681, 52.58460067933606, 50.764813115519864, 54.197545974485344, 51.24758235869869, 57.83217891570061, 58.54432052181613, 62.29558121773505, 59.80262864020563, 61.487400377950365, 57.53935437048636, 56.01305423244354, 42.79203876372307, 40.56365005431637, 39.63677044837706, 13.663077373658458, 40.345993811084384, 64.13702026490243, 52.84860757089431, 62.192681758634514, 52.79563988408735, 51.62372589111329, 62.518920975346724, 60.67102570687572, 22.516042378640947, 2.0930787055723132, 29.158817491223736, 70.77158389552947, 30.37968266394831, 22.585558545204904, 59.075589872175655, 62.57699951048821, 35.02573405542682, 37.86606742489723, 23.871835124108102, 29.56108008661578, 37.201551237413966, 22.363491596714145, 59.29642323524722, 69.37687535439768, 19.973597334277247, 0.3203007789148439, 0.28578548421782834, 0.09184223629774586, 0.11626485119303388, 0.10880464868199442, 0.06856688403434331, 0.19424424386553227, 0.11750029054500404, 0.10367929064218076, 0.16639127876729737, 0.19020637827775172, 0.18753366604928048, 0.1444844736327087, 0.18307754709835977, 0.156663907992263, 0.14473835517081524, 0.4213703603994462, 0.2347302286615295, 0.2251378119352364, 0.2434567208852499, 0.3284215867038696, 0.36172854623967604, 0.8372886875464071, 23.852737103739095, 88.83064685329315, 65.99616096865746, 56.64596396107828, 52.91539376781833, 29.500144104803766, 57.7742886543274, 65.28866737119614, 42.294356669149096, 31.553016554924753, 27.40783614497031, 34.312384359298214, 65.33582210540771, 17.89205235819663, 1.825626256965822, 26.08726432246547, 69.71346178362447, 72.41187203314998, 84.99374512703189, 72.90114064370432, 71.7448494511266, 67.81970224072857, 69.75232462729178, 20.14389095767852, 2.2629570480315917, 22.032480816687308, 50.1408189342868, 49.06386944555467, 65.80806762941423, 69.07642179919829, 59.30588006973267, 56.82212545025734, 64.91715615795505, 68.6989172043339, 71.80086089718726, 66.4501674713627, 68.88127603838521, 67.67227603543189, 67.50281395450716, 61.830125316496826, 56.92957485875776, 43.92789048533286, 31.69287454697394, 29.988620396583315, 34.11929392045544, 35.10709970228134, 30.949028422755582, 29.883051764580514, 27.680229063956972, 31.847765022708526, 38.480083096411924, 32.09735720388351, 24.633167174554643, 18.65834620691115, 10.041380409271488, 6.140845091112199, 8.345390692833933, 19.400221340117916, 25.395158183190134, 32.26944531163862, 32.31224033140367, 16.302466738608576, 4.444762218383051, 0.49625484212752313, 5.327739715576173, 8.814039403392423, 14.16083497385825, 15.165694240600834, 30.854538525304488, 32.017140811489476, 41.30347967147827, 36.381748414808705, 45.549366935606926, 41.829402831292924, 30.547973917376613, 47.56929343746555, 49.79021003169399, 47.22013581183649, 51.775792260323804, 51.222545869888805, 55.659793807614236, 43.06484353157782, 23.494658047153106, 12.10725159414353, 9.146648549264478, 7.74235716750545, 3.438497272229964, 2.627893633419468, 14.141100548928785, 33.01743738112911, 38.49212085047076, 30.785720540631203, 24.442451730851207, 16.41352080529736, 13.022912240797474, 11.950880423668893, 18.00115896809486, 27.32358951722422, 25.096514801825247, 32.91709138501075, 13.916278135391975, 12.308558417904763, 35.272388381342736, 32.23673666677168, 29.53917168801831, 33.25507025564871, 39.049599478321696, 49.628659371406805, 54.602385567080596, 55.004287304416785, 55.87020543313796, 54.68537507518646, 58.654205722193566, 55.433610331627634, 56.62479492925829, 57.221148167887044, 57.04877176592427, 60.40183736431984, 61.51488442574779, 63.292220177189, 64.6035469731977, 62.25094072280392, 58.132267690473995, 57.66641562984836, 47.69458178550967, 46.09897728889219, 50.10138342457433, 15.415001069345783, 39.625364195915964, 69.0757942199707, 56.52043634845365, 65.66073163863152, 57.49164658208048, 58.789131333751065, 67.5070736485143, 65.32738900953724, 31.061824021800874, 3.762217836995279, 26.63914376689542, 71.20319366455078, 23.33315053293782, 30.407504035580544, 65.91696047013806, 68.37172092929964, 33.49511538782428, 53.48259987369661, 22.52481083716116, 41.9744050118231, 50.16885995864869, 35.422199387704175, 70.57018587666174, 81.72498303074991, 33.026309782458895, 0.5845668226961167, 0.40407963337436803, 0.2750473523572568, 0.2952002451544808, 0.33023090251991827, 0.19222095969223207, 0.44210783956993016, 0.14502222139027812, 0.24498978539580302], [0.053938327867898254, 0.0637359642273476, 0.07654119282960892, 0.028745739067333843, 0.01674510005320753, 0.05193667801757974, 0.008281597195403471, 0.14837293675349605, 0.03662997699012199, 0.11018605842705696, 0.11952603386054117, 0.07729540639106305, 0.038935514767804456, 0.07448863643672197, 0.35186133377494355, 24.436974140905566, 66.8560229578326, 37.695197213080625, 38.89703496809929, 32.0427401604191, 35.773290741828184, 50.66864052126485, 34.36583842000654, 18.90063101245511, 18.756693755426717, 20.207919728371408, 33.816043715323175, 43.88008856004284, 3.2343979660541784, 8.811041731988231, 50.77431701844739, 40.48677944367932, 43.66520543252268, 66.92618631547498, 56.79979931923651, 64.23607972360426, 45.73822513703377, 46.705395329383116, 18.64437864672753, 1.0113523215536149, 13.237219760494849, 39.603806849448915, 31.40740836820295, 52.40484237670899, 53.51947015331638, 57.21897125244141, 53.09763493076448, 57.478887111909934, 59.040092422116196, 60.43237693848149, 58.11524068155597, 54.90713019524851, 43.66074177526659, 34.87842944360549, 27.976983824083884, 26.096607408215924, 26.887290554661906, 24.55114256951117, 28.80484319502308, 25.4926839951546, 20.948292593802176, 11.607095464583367, 14.453272185017987, 17.776279680190548, 24.789967844563147, 19.192520072383267, 21.308711344195952, 12.19156784396018, 8.688057776420347, 5.123736752617744, 6.769476984777759, 20.484044782577023, 27.409044234983384, 19.775366629323653, 9.310475164844144, 3.5998272991949514, 0.4338417202234269, 0.8733823378720592, 1.517297072756675, 2.786087235135417, 1.6885612376274604, 2.6605625642884165, 4.8210052809407635, 11.177046798890638, 26.533639854000462, 38.06674765002343, 37.348389087184785, 30.182328608728227, 20.16261439169607, 36.961215849845644, 39.5748205338755, 21.63190680165445, 21.372518500974103, 24.153137706941177, 16.663456193862423, 8.570923055371932, 4.650075252979033, 7.569362501944266, 4.043040910074788, 2.732441468584922, 0.996126783711295, 1.6352654200407768, 4.550327908608222, 13.249845870079534, 22.389232150969967, 28.16057820473948, 23.575111742942568, 10.785561896139576, 9.712185686634434, 10.598767842015913, 15.577848072974914, 9.708238801648541, 13.735333315787779, 25.298271717563754, 23.689450794650664, 5.788841785923128, 2.948537098784601, 10.30742693331934, 25.8360541635944, 32.41650085295401, 32.78306203503763, 39.763121758737874, 45.58264432414886, 50.558555280008626, 51.60337663465931, 54.227744302442, 54.405298233032234, 50.57002429039248, 51.145334013046764, 53.44062659048265, 56.788149879824736, 58.784997155589444, 55.78609020479264, 53.80465784380513, 56.19359700910507, 59.2101114796054, 51.967619695971095, 49.661211121466856, 37.60433158566875, 23.450749074259114, 4.433482952656285, 23.1610643863678, 49.45023075226815, 42.68013746507707, 49.77104140866188, 55.84576906696443, 51.74502911106233, 64.5650214533652, 62.95928547459265, 45.80554085393106, 6.529640228517595, 4.370584805165568, 50.16743221590596, 18.913967071040986, 13.163845942866418, 35.76641090454594, 57.97978947239538, 48.95075613452543, 26.056022644042972, 29.152990810332764, 19.204959869384766, 45.96655807187481, 25.790117325321322, 44.19707882788874, 43.06588295967349, 57.94501373844763, 1.7862834132486776, 0.05038808490480146, 0.10228328692216067, 0.11480545369727958, 0.053245508592695966, 0.0994793821366564, 0.09040404411573565, 0.057843564483787746, 0.10110174185566365, 0.04978095256392995, 0.041608272961551146, 0.07172528834592912, 0.07012316100900212, 0.025955629610126058, 0.042695420674018325, 0.05260387548215447, 0.03554418525328079, 0.13732643918164317, 0.014951328161142528, 0.06856599537235114, 0.09627427710520645, 0.07195113872688624, 0.054332778879231027, 0.09058418203025095, 1.9464868619557352, 33.38200992153537, 79.69874151291387, 35.7321293892399, 41.4981076794286, 34.74013451606997, 34.17652130126953, 40.191777983019435, 33.48669798143449, 29.01559606675179, 26.266069489140666, 24.2410066435414, 49.60371309711088, 51.21739972022272, 6.4640302523489925, 6.843540649260245, 51.51950459326468, 49.0462266245196, 53.25593394617881, 71.65607836938673, 61.62853117912047, 67.6721897432881, 50.89093300604051, 51.569534424812566, 25.093841706552816, 1.538991702179755, 14.19720515128105, 49.58477981628911, 39.27266467002131, 55.520267255844615, 55.619820933188166, 59.81388584260018, 55.385879009000725, 60.192563226146085, 60.54762009651431, 67.16310531862321, 60.6777996401633, 59.083293407194084, 51.78108353768626, 43.358162295433786, 32.73180842399597, 28.229578579625777, 28.119891458942046, 29.41563467825613, 30.506518387025405, 31.268899671493042, 24.06345663532134, 17.00170374685718, 17.810404300689697, 23.85769105726673, 27.91870132569344, 24.004170010166785, 26.087560461413478, 15.415848301303003, 11.664525828053876, 7.045697156460055, 12.440219636886352, 20.194322832169075, 27.202531445410948, 33.05320547473046, 18.56196180466683, 7.773661113554432, 1.0934556804357038, 0.15410759516300696, 2.145388414782863, 1.5252567875769831, 2.6317738381124314, 6.480853298018056, 11.713073984269174, 24.396030479861846, 24.975852889399377, 29.359750709226056, 38.280301094055176, 36.97006471695439, 26.270042850125222, 41.0226026658089, 44.51270411091466, 40.11194990527245, 42.16388687010735, 41.098214195620635, 39.888237522494414, 30.876040958589126, 11.005155790236689, 6.45778387784958, 2.636323052067911, 5.689871561142707, 5.034001748408041, 3.393427032616831, 7.7841387448772315, 21.029907311162642, 35.01231954943749, 32.93454593227756, 23.796274585108605, 15.969180003289255, 11.132261176263134, 14.819582335410582, 19.29047146151143, 14.418378779965064, 18.93983117995724, 29.27991870910891, 24.720841953831336, 7.809911168390705, 3.262896191689276, 15.523781141927167, 28.46580920680877, 33.94447780424549, 34.58161584792599, 43.76152707684425, 47.958855398239635, 52.91549967181299, 54.152030791005785, 56.855775463965635, 56.59005841901226, 54.49986657788677, 52.708626024184696, 54.95512431667697, 58.72154497331189, 60.57494724950483, 58.45933844966274, 55.00697412798482, 60.80957166610226, 59.99587205148513, 51.441782828300234, 50.51011008601035, 37.73747644116802, 19.586535884488015, 4.91306281858875, 30.490283696882187, 51.88718757321758, 49.30897443525253, 55.1652378420676, 59.94044503858013, 57.314920271596606, 69.70642505153533, 67.63017331400226, 45.163209592142415, 3.357110542635764, 9.620901346206665, 55.419203465984715, 27.642707670888594, 18.01879394438959, 35.10431089708882, 58.28207085209509, 56.258837792181204, 31.535758126166563, 36.08329134602701, 24.030791136526293, 47.81257452503328, 33.40266904523296, 40.61274243939308, 56.94739026408042, 62.55709740423388, 4.3224058420427385, 0.12168898352331693, 0.23963104633073654, 0.07527625909255398, 0.020565053846146313, 0.048337317327217716, 0.09004189137129054, 0.08355703370104875, 0.10519744708172737, 0.07477365944895052, 0.13551818056693002, 0.12125222147592615, 0.3264741299133147, 0.10779146675861652, 0.13765764963482657, 0.22422572297434654, 0.08114199514590925, 0.3662343076880901, 0.18410925302774678, 0.18552939617826095, 0.22223588619982043, 0.23522846160396454, 0.2213739300326955, 0.270531693052861, 3.557333076192487, 60.72152230047411, 89.54862886859526, 52.94395646741314, 50.82457434746527, 44.62596254964029, 49.42628468236616, 67.91516488598239, 47.41506976466025, 38.28578456755608, 31.817376459798506, 27.477430758937714, 49.643937003227975, 52.22806507541288, 7.006371473112415, 14.282451002828537, 60.64139612259404, 51.87228648893295, 56.73831224441529, 76.76933503920033, 66.87794116235548, 73.91254732685705, 54.52267908280896, 55.89265315763412, 22.882732998940256, 1.9143628953926026, 22.11187155016007, 55.582829060093054, 39.935800183203916, 56.600550759223204, 58.24110169564524, 64.82674552548316, 58.95287459896457, 62.90072841029014, 63.822669752182506, 68.25466171387704, 66.88897086728004, 63.24088027400356, 57.23764173446163, 48.73952865600587, 37.487444954533736, 32.97236150310886, 33.24526433021792, 33.428266432977495, 36.987903656498084, 37.2052578772268, 31.980388202974876, 23.02307540370572, 24.82295301652724, 26.81646823883057, 33.316537718619074, 30.048991557090517, 32.33434092613959, 17.59175177543394, 16.52936016359637, 8.931533021311607, 14.622175328193174, 26.992053139594297, 34.08092921780002, 37.373437343105195, 24.225103393677745, 8.852047170362166, 0.7981040869509021, 1.2697892636060715, 6.490364555389651, 11.200279978013809, 17.10554849716925, 15.675516070858126, 20.77703798970869, 31.330608360229004, 41.32943399490849, 49.84065955685031, 41.94799177108273, 37.327847634592366, 30.522900166050082, 51.20877835058397, 50.60898127094392, 47.0414718504875, 44.89206398687055, 45.56602131935858, 46.27699798153293, 33.55675935745239, 27.34978310523495, 21.848998223581624, 24.815088664331746, 20.631525901056108, 18.938713304458126, 9.295989851797781, 11.47978807649305, 28.206605257526522, 42.18334967090238, 34.46289354755033, 28.30275823993068, 21.385681975272394, 16.260630738350653, 20.139042908145537, 23.307727690665956, 19.21096697930367, 21.266883188678374, 32.6984525880506, 26.43877144782774, 7.952794288435291, 8.12472059842079, 26.16983021459272, 35.53684242310063, 38.60487330344416, 36.979525473810014, 47.17141605192616, 50.999857225725734, 55.825557093466486, 57.430339936287176, 60.17702671789355, 59.63506890881447, 57.10832118988038, 57.52412380710725, 58.63931248264929, 62.42767880039831, 66.16566227328393, 61.73951464314615, 57.179300400518606, 61.78368053128643, 61.610037203758, 52.932514913620494, 49.74114902557866, 47.390872663067235, 28.05833182027263, 7.158565319353535, 27.269262729152558, 59.41322749660861, 51.81815778055499, 59.48299077249343, 62.42985963821412, 61.791278162310206, 72.08326370485368, 72.28396354183074, 54.31869622199766, 9.552765853943365, 7.638048106624235, 59.7169287743107, 27.72231609590592, 18.723269278003325, 45.220774296791326, 66.75069162922522, 60.09284873162547, 32.155863277373776, 44.1649075477354, 25.068344339247673, 64.98775489868657, 38.69824924776631, 57.809311497596006, 61.004505618926025, 77.22333369716522, 11.209363206740349, 0.3402617513652771, 0.5266383795007583, 0.30219919378719023, 0.4093282856047154, 0.14525088331391736, 0.26302075253859647, 0.25544993459217014, 0.48064457492962964, 0.1154181708191191], [0.059844873424979954, 0.03458426559283849, 0.04539607978996731, 0.07935148678840169, 0.06381028241688205, 0.03620420064356539, 0.15631230427853524, 0.042277780181217584, 0.03182315447878453, 0.22293679536350314, 0.06426818849098298, 0.22932167855962632, 0.31823960403280876, 0.12159701466800706, 0.5960590608658329, 16.40540934378101, 60.40380247177617, 52.05847747864262, 39.12199074222196, 41.298302142850815, 33.7125402112161, 52.67291676613593, 37.45208086506013, 19.432253376130138, 14.020121905111498, 30.78061949822211, 21.417007984653598, 59.247170032993445, 19.021675355972786, 0.6303775322533424, 6.847426737508466, 33.01853172240719, 65.10081721890357, 55.7630305905496, 63.61633739163799, 62.54657760743172, 58.79034726850448, 41.52172034786594, 36.260370669826386, 6.586976945400239, 0.8596268921129165, 32.65717552554223, 61.79173707962037, 43.34645402046942, 45.943796557764855, 47.79157807750087, 53.471672150396536, 51.918970538723855, 59.19952500251032, 50.68134507825298, 44.433021160864065, 37.955022858035186, 37.182868988283225, 31.51617765426636, 26.651713002112608, 23.756178156022106, 28.24537592549478, 31.243976931418146, 29.469914397885724, 20.351596147783344, 18.87686929395122, 11.619597038915082, 11.500245198126763, 15.687538135436276, 20.144495002685055, 12.97161352249884, 14.395891831767175, 9.280703394643723, 11.661609545830759, 11.744607879269509, 14.15163701580417, 20.067157629997503, 22.67674972934108, 17.369520087395948, 9.357243545593755, 1.936571477882324, 0.7318466132686985, 0.386648191319358, 1.422765622696569, 4.590644971016915, 10.803240018506205, 14.462122032719275, 16.768438431524462, 26.574234424098847, 39.4875713317625, 46.93121794731387, 44.764269244286325, 31.03762495902277, 25.56775227669747, 39.46459408729307, 43.13722302836757, 26.91195049593526, 14.184531973254296, 14.705426654508038, 9.768190268547306, 14.690683445622845, 19.23608191551701, 25.10280432239656, 19.94933747476147, 21.676706152577555, 13.724481098113523, 11.423698183028929, 11.642065355854651, 18.11243268751329, 29.95523710404673, 29.692554012421642, 22.227132358858665, 15.396266848810258, 16.817687711408063, 11.372748555675631, 16.906007720578103, 25.131268962737053, 10.69374607455346, 18.88241356418979, 26.923066493003603, 30.58998642429229, 14.712259423348213, 2.399496714914999, 7.952172592762978, 26.94347458501016, 39.527269640276515, 40.71697158198203, 46.14002489274549, 49.29002546495008, 47.491030385417325, 49.282525893180605, 49.221964497720045, 50.40482974821522, 53.704315770056944, 51.16937814220306, 53.760358595079, 53.62142039883522, 55.07019096805204, 65.84398085071196, 58.20433732002013, 52.08447887051491, 50.75452866092805, 44.33200443944624, 9.665050564273711, 0.09992915235700146, 9.133973410052638, 51.525768618429865, 49.17370365511987, 53.645766550494784, 52.875232619623986, 56.94710393105784, 29.721807049166774, 32.6190677381331, 38.57800899013397, 7.144625706057395, 0.6571762684372164, 24.83245691945476, 60.595210213815015, 19.89710327117674, 31.41638863471247, 45.54962973440848, 56.21318532574562, 36.17645155998969, 28.085711925260483, 21.257955874166182, 32.85337640393165, 32.501700616651966, 36.781186903676684, 38.38200030788299, 50.61241726721487, 43.116571749410326, 0.9423621203149519, 0.15288432128727436, 0.025244742151229613, 0.04735785476382702, 0.06487188875795373, 0.03966438614072339, 0.09108989199082698, 0.026531913505506613, 0.060444773895846265, 0.02760270141035078, 0.0051835357143934216, 0.03876399151199768, 0.031021679038061734, 0.032397578695728894, 0.0915932194179585, 0.018039307925069047, 0.11652489973893089, 0.025054601043643012, 0.19817165489639008, 0.07814614703097651, 0.02462183797521697, 0.11574936595054404, 0.1712702935741794, 0.17620311839686287, 0.2580478613174731, 23.77408181467364, 78.96021412264916, 51.87271010491156, 41.28246753446518, 50.372893810272224, 43.315875222606046, 44.545965809975904, 36.24337111749957, 26.753235709282663, 21.508526686699163, 33.84206864141649, 30.958899067294215, 73.18351207240936, 30.45807907658239, 3.7978108948276894, 3.3951134066427913, 32.338853613022835, 67.70079951132497, 66.0430960501394, 69.48118686676025, 69.71576813728579, 58.760372515647646, 47.027516057414395, 41.922394383338194, 10.746110696946422, 0.6474030702825516, 32.54101061051892, 62.947773318136896, 51.569644251177394, 52.635567957355136, 50.22209828899753, 52.010302928186235, 53.7842458294284, 60.462904745532626, 54.19434139805456, 45.436441898345954, 42.72184794948947, 41.299961305433705, 34.45466833729898, 29.311860530607163, 26.494237684434463, 30.30863481183206, 33.261750052052165, 32.28388747861309, 25.514562975975778, 20.963072084611465, 17.373660149112826, 16.44166675306136, 21.09032161774174, 21.859947519917643, 15.594346542512218, 18.66293145764259, 15.126206759483585, 12.638211077259434, 13.671336904648813, 17.26770712483314, 20.07646933678658, 26.975759613898497, 26.254402399063114, 14.368019469322698, 4.278735643432987, 0.7905773037383634, 1.1442755018511126, 2.9909195342371544, 3.0473862203859516, 2.1294116204784763, 6.756568464540667, 11.58772680067247, 19.92055512243702, 36.18033078409011, 45.31563681940879, 47.8996785994499, 37.33206810489778, 28.040422278065837, 40.97883293705602, 49.9301209757405, 35.371498830856815, 37.166238138752604, 34.45569207591396, 29.762807584577995, 23.228231053198538, 12.381723369321517, 12.561852335929872, 7.767366690020408, 5.2838523157181285, 5.450238768131503, 4.548025477317072, 7.986767897682806, 20.75483149097812, 35.8927700596471, 34.296228116558446, 24.712746181795676, 21.098099677793442, 17.04752291402509, 17.466938034180675, 21.17559982884315, 26.740717464877715, 15.398142722345169, 25.590225496599754, 31.353185522940855, 32.01160046362108, 20.519218637097268, 7.377897885537918, 14.237400620214402, 30.438892802884503, 43.23204632728331, 42.53424490651777, 49.20544347455425, 52.142549560916045, 51.41586380620157, 50.31866704263995, 49.360043694896085, 52.23265817088466, 56.071109233363984, 55.02253024808822, 56.56016995829921, 56.61875447919292, 59.052985252872595, 69.57822630482336, 60.70876675267374, 52.229175106171645, 53.8325027496584, 42.894510684474824, 6.219335150334143, 0.3388763273194913, 15.576955733760713, 55.52892392681491, 53.05292383317025, 56.41402636804889, 57.515969199519006, 62.78557938914146, 36.94032530630789, 39.53190588182019, 39.18282670359458, 3.710513398531945, 3.22287134585842, 36.81650784707839, 67.88876733472271, 30.177647259927568, 25.69309946029417, 46.18286109739735, 56.864973422019716, 48.73767729728453, 32.350912940117624, 31.747960313673946, 31.65224075317383, 33.317247667620265, 36.005055750569994, 43.259644123815725, 63.164245005576845, 50.23009992414906, 0.8162871531901822, 0.14372783923341384, 0.08105819278787221, 0.11143292781085738, 0.024313726988170418, 0.010999582347369963, 0.05135172775255577, 0.010001576625772063, 0.09255921798607997, 0.014163611659539804, 0.09404048729207247, 0.11046617847657013, 0.2258094412184531, 0.12432739799541813, 0.2454133554091377, 0.10455120595232134, 0.4136777651165763, 0.11190766483665475, 0.3312127820907101, 0.2950063636226039, 0.16295312212840204, 0.4911826659114131, 0.5104183982456885, 0.2296546510150356, 0.921908982338444, 39.17988492596535, 89.84046105415591, 67.76121970145934, 53.589068689653956, 51.90642287654262, 48.245498288062315, 72.93242546819872, 52.80423771950507, 37.407930666400546, 27.084619114475867, 40.02839557586178, 26.14937701532918, 71.48517285623859, 23.769394582317723, 2.6933047944499604, 10.881933550680838, 42.32185248405703, 78.07392320325299, 70.47924964658677, 72.74701503015334, 73.58052653651085, 69.48168108540197, 55.20713267787811, 43.6959489699333, 8.636580590278871, 1.4323646431007695, 44.94374905863116, 77.5892908342423, 59.22975863179853, 54.496379590803585, 51.64327890642228, 55.50501315824447, 56.879913730006066, 65.45466599925872, 58.22256065184071, 49.993373117139264, 48.94338600097164, 46.954399155032256, 39.728926535575624, 33.224507147266024, 31.643891988262055, 39.02820294903171, 37.394437713007775, 38.9479551776763, 32.99546034105363, 26.754610500028058, 21.868088399210286, 22.17378027977482, 23.991867496121316, 26.707338094711307, 17.869416359932192, 22.39656109963694, 19.672655443991385, 17.160779391565633, 18.956163929354762, 23.528257070049165, 24.411084536583196, 30.524598552334695, 35.345968123405214, 20.91880617603179, 5.285682591699786, 1.0816901633816383, 5.15783783889586, 9.727383890459615, 21.743557068609423, 29.127717018127445, 32.84922653628934, 28.494071845085394, 38.68297946068549, 47.96317392779935, 48.48595919147615, 53.2067003557759, 42.38590478897095, 41.48292418449156, 48.01001487239715, 54.55337162940733, 51.73134003916095, 41.971953530465406, 42.03737082019929, 35.16417018828854, 40.609384890525575, 40.18663183335335, 40.87075202695785, 37.827035919312515, 40.87198365119196, 40.035161664409024, 32.74992781300699, 26.282127672626128, 33.522807321240826, 47.27456654271772, 39.784514365657685, 26.270664545797533, 27.16370390307519, 21.405780200035345, 24.804870890032863, 24.539210719446984, 31.97153933586613, 16.9463453754302, 29.41065326813729, 36.08113796480241, 38.0556159634744, 23.666826563496745, 14.057037291988252, 21.261323228959117, 39.558201451455396, 47.99185429849933, 45.38567858357584, 53.32811340208977, 54.63386258771343, 52.82282583175167, 54.72031947105162, 53.13385409693564, 55.17767960025419, 60.58653000862368, 58.62048118345199, 58.72457696545509, 60.67783886386503, 60.29916932505947, 69.40240213947912, 63.69268240467195, 50.24873510483773, 52.222652204575084, 52.61537559570805, 13.576893095047245, 0.28491514704881177, 11.92367192237608, 57.38289102431267, 58.43578853914815, 60.76743756571124, 62.78688553840884, 64.47268493713872, 42.865857770366055, 43.64651926102177, 50.186667519231, 10.690538556345048, 2.963930440525855, 30.570456943204327, 73.03381089241275, 24.192418283031834, 43.63636032227547, 53.132210623833444, 63.48514979885471, 45.40871466359785, 37.98075752873575, 31.98619527201499, 43.380719846294774, 46.262418531602435, 46.71254973257742, 54.651144550692656, 65.55293313918575, 67.79656810145225, 1.6731236466476995, 0.3245163462575405, 0.2805296920480267, 0.29362167502122544, 0.15187412710680118, 0.08026847871200693, 0.147769826374227, 0.12505679796900482, 0.21383000177241143, 0.14764118488998185], [0.07269563063258126, 0.026832099312976487, 0.03674860570519682, 0.031165027495233283, 0.027769898184605186, 0.03224257995644885, 0.015770821989844405, 0.047137317202624776, 0.059941404333878914, 0.07388345762005738, 0.19995728327381998, 0.2021368340619149, 0.02336629264567408, 0.10294665777755362, 0.2764506415734368, 7.453783490965444, 60.215630685129476, 50.362448538503344, 31.267120876619895, 36.79239703762916, 24.869599803801506, 41.066752864468484, 45.44791483109998, 26.435376636443603, 18.158193019128618, 17.774294960883356, 22.465585008744274, 32.749663053020356, 83.83010341275124, 11.626629848634044, 1.8258308330851218, 7.911670688659915, 59.10141083502001, 57.038102919055575, 49.45384325519685, 53.79704844567084, 67.7202936910814, 53.328497794366655, 36.76810972152218, 26.50426914615016, 2.0180758785816932, 0.17243611085559093, 6.876167414649841, 13.695927223851605, 30.69571391228707, 38.202391055322465, 37.45652098809519, 41.460394090221776, 44.283814199509166, 41.10512541186425, 36.056364274794056, 37.797676978572724, 30.439579217664658, 24.787637956680793, 28.286296052317468, 28.95812942135719, 34.671026276003936, 29.382818168209447, 23.89479667909684, 16.20826611595769, 12.162537401722325, 12.360945593926216, 15.812380313873293, 18.49935881553158, 18.394898253102458, 11.872711508504807, 14.862687222419249, 10.579648248610958, 12.908476110427612, 13.662277210143305, 19.04038113932456, 28.766290218599384, 26.781492464004028, 15.937425474966727, 8.693880534941151, 3.2604478972573436, 0.792310010761984, 3.118761345263451, 6.647868310251544, 17.631808980818718, 29.15837230220918, 32.331779618417066, 32.78052818390631, 41.071271434907, 47.36741688943679, 49.609937898574344, 45.85014604753064, 51.43316145866148, 37.82287820692986, 40.85984391550864, 46.58874404045844, 31.449161998687256, 16.145846497627996, 16.333776077916546, 15.977342455617844, 25.53438859601175, 35.67114437780073, 39.55805632375902, 34.39985321414086, 42.27617648340041, 26.343793215290194, 29.19144964987232, 32.60319978960099, 34.25892245384955, 36.25726415264991, 29.295019834272324, 19.39776985876022, 19.900064660656838, 16.916439264051377, 14.070696946113342, 18.864917832036173, 20.507331894290065, 25.852559497279508, 18.366919986663326, 30.319741002974975, 37.21916267948766, 29.277904572025424, 17.62706095172513, 12.731398747813317, 7.333930567387612, 21.98923276316735, 36.498756639419064, 39.934427353643606, 49.99659730542091, 53.99756393124981, 55.23570714458343, 55.06730410360522, 53.38276770807082, 53.29755813844743, 56.79146036025017, 58.0732124851596, 57.425868434290734, 56.59618516122141, 49.496287222831484, 50.5528913774798, 52.82961545451995, 32.974503117222945, 8.080809664341713, 0.28583221558120947, 5.427994516588027, 34.43715103210942, 50.52144181343817, 53.424697845212876, 56.144182989674235, 53.34117097239341, 49.08782728256718, 27.755658203555694, 43.26917940570463, 8.223982549482777, 0.8432419261624737, 16.14600633421252, 62.064353573706846, 34.263852873156154, 14.099195907192847, 35.1463508605957, 46.94013349471554, 47.37789746253721, 21.0030076965209, 29.770095348358158, 21.65045569019933, 40.014675124999016, 33.23258330745082, 31.86057548369131, 39.5312390788909, 57.8691747111659, 19.06365256155691, 0.29977375941891826, 0.31970742849573014, 0.04796855707442568, 0.0815922633234051, 0.04096082141322475, 0.036340208063202525, 0.024110229137623986, 0.10790984266467633, 0.060727012178470055, 0.08445573144502218, 0.05309844652431146, 0.013327847080936116, 0.07737694878972347, 0.07842982938933758, 0.03068985571453889, 0.09196969800658765, 0.01754416997784809, 0.042641503405907465, 0.07486313085762725, 0.02906202804297209, 0.08054410182540456, 0.11705140898665113, 0.15414700272583193, 0.18142397695731732, 0.32099136121330724, 9.60256132387346, 73.00830764155235, 61.57821893692017, 29.505570703937163, 44.557944728482155, 34.58200416257305, 42.17732098794753, 35.136305670584406, 34.900531999526486, 25.46503128543977, 25.530458381099088, 24.57862073375333, 46.393060914931766, 82.7090507938016, 23.137412494228734, 3.711294685640643, 6.444537543481396, 61.59803475103071, 65.36209806319206, 56.1346947762274, 59.75686634740522, 71.17816894285141, 60.4802220098434, 41.91290224752119, 34.29762840270996, 4.1000057372354695, 1.2771370886794984, 6.317815569139296, 14.501628145094841, 31.693331503099014, 46.243167538796705, 45.11308170134022, 48.726612291028424, 47.999950070534986, 47.82831499653478, 41.34334271953952, 43.620666919216035, 33.870870605591804, 29.287488883541478, 32.91083520458591, 35.79041973237069, 38.556706597728116, 34.91767667954968, 27.273092923625825, 22.37818087300947, 17.38232466482347, 16.35273975710715, 19.02736279272264, 23.55849462170755, 21.389598461889452, 16.040846609300186, 16.33914678327499, 13.982065108514602, 14.03356190650694, 15.89702408159933, 23.24148278082571, 25.137884040032667, 28.173372976241577, 23.58425674899932, 14.473973474194928, 5.69016573890563, 2.694146142851922, 4.861538073708934, 3.501198320619522, 3.764353567554105, 14.265726016413781, 18.342252200649632, 24.248047298000706, 33.91162403168217, 49.49531055265858, 58.472894160978264, 50.76835893815564, 45.66139375009845, 35.17196393782093, 43.84926265285861, 54.45636357030561, 35.14534281146142, 26.63914768926559, 27.980865009369392, 21.572704507458596, 25.14272032245513, 26.886076581093576, 29.62035494465982, 28.2676177255569, 28.8904312733681, 21.770701831386937, 17.29227096803727, 23.688770263425766, 31.440370005946008, 37.87232752769224, 34.68364454084827, 23.027774403172156, 23.373717646444998, 18.3625033978493, 19.902557326901345, 24.163930108470304, 24.075780722402758, 27.152227047950994, 20.904456184756373, 35.547691698997255, 37.261402683873335, 34.548142340875444, 21.02646739252152, 20.548432450140677, 12.788553564779221, 28.140183841028524, 41.989192347372736, 42.64401243579003, 50.845288384345274, 55.551399107902284, 56.31253503984021, 60.10135635252922, 55.31373485442131, 56.10563001325054, 56.32173692026446, 61.97735932565505, 59.522383136133996, 58.51007038547147, 51.07327615061114, 55.89825037987002, 52.93040467846779, 29.458270842029204, 5.3327230868801, 0.6343863171435172, 9.867568419825647, 37.82623183342719, 53.57801937287854, 58.384448635962706, 59.85712212900962, 59.503610672489295, 53.86999668613557, 34.19778839234383, 41.07056933064615, 7.142204623068533, 2.4395622553363925, 29.940365437538397, 61.90330105443155, 46.25232235077889, 19.97959856064089, 26.612169627220403, 44.97888957300494, 56.00529186187252, 32.786160707473755, 29.514662757996593, 28.44247698783875, 32.42113121094243, 38.35221382879442, 29.496341366921705, 49.30399694750386, 66.89031231787898, 23.86568877004808, 0.3058390920200656, 0.23902701664595838, 0.045496387512332974, 0.09048624535001094, 0.07657333787891173, 0.05030856114782153, 0.025834267876381357, 0.059829593801330176, 0.01603759583010669, 0.1033792523066363, 0.2120739903541342, 0.27454032472545103, 0.1766832563425264, 0.215702228728802, 0.12328682076786796, 0.25096271247152363, 0.21495158513707502, 0.19010329348666055, 0.2509504703864936, 0.1804783486671025, 0.3319546003495494, 0.2731245329543468, 0.5115327497403468, 0.24393900387710143, 0.49297338111266015, 17.54697988110204, 89.82572078704835, 72.4756811511132, 43.184871981220866, 50.76540539341589, 33.053982104024584, 57.278446151364236, 61.06279988442699, 46.397453969524754, 33.78091496805991, 26.182054281234745, 27.08101445628751, 37.592650767295595, 95.5485059368995, 17.30109041736972, 3.876033497433509, 11.380451110101516, 68.79405037049325, 69.56580023611747, 63.83765320624075, 66.8910026550293, 80.46999715989637, 65.57017980083343, 48.811810093541304, 34.126095310334236, 3.295673478034235, 0.5029395721372097, 10.520504789967692, 23.281555675691177, 48.94200532667099, 54.77542092723232, 53.13476408681562, 53.1550701971977, 51.63995665888633, 50.2895591335912, 46.5168156162385, 46.06395444562359, 38.21268335465462, 34.06219990022721, 40.65774379238006, 40.552055528087, 47.12757572051018, 39.24670250185075, 36.55379141530683, 26.88630800093374, 24.926005448064497, 21.443174116073116, 26.88106183082827, 28.002139945184034, 27.063569714946134, 19.83385701333323, 21.069570318345104, 16.44397016494505, 19.454059793103127, 19.09157395362854, 29.407034881653328, 33.149519274311686, 31.517001352002545, 34.6537600025054, 22.127178599757535, 8.614669249903772, 6.7574740417542, 20.435872193305723, 23.292954083411928, 38.49754941078925, 44.301704129865094, 45.459477978367964, 42.52238758148686, 46.62013476894748, 54.15077563255064, 55.656083245431226, 55.1168240270307, 56.76430579154723, 48.76672244841053, 45.95986258599066, 58.52099810877154, 50.50233202595865, 40.877235704852694, 43.4307732120637, 41.315431133393325, 46.88288650205059, 49.42815957530853, 43.8742010824142, 40.51035288841494, 51.95222047067458, 50.4388366976092, 47.09001510374008, 48.31916039989841, 46.88730701323479, 43.559375962903424, 33.5622702875445, 25.031534856365575, 26.93471593241538, 23.876300742549283, 26.28076857136142, 30.40228532206628, 30.901907028690463, 32.00796050410117, 26.664162605039536, 39.71677895515196, 42.923763721219956, 35.82501503729051, 25.196592115586807, 27.051518232591693, 20.32927393913269, 36.26376744239561, 49.428057593684045, 44.9411367600964, 55.328067195030954, 60.38758739348381, 59.865719964427335, 62.776769745734434, 57.89201467267929, 58.60380718784948, 61.36047247917422, 63.845282216225904, 64.04293829394926, 60.57694765829272, 51.86789735671013, 51.9204100485771, 57.77436317936067, 41.68434573758034, 10.952628389481577, 0.34283191506420413, 7.492889031287163, 38.777081043489524, 58.84580173800069, 60.85684014904884, 65.17384782914193, 61.641937840369444, 61.72327603063276, 38.89513654093589, 51.95636249357655, 11.852170055912389, 2.46531825392477, 20.754845219273722, 70.72923798714915, 42.65009995429747, 17.405672573274185, 47.24454472141881, 53.25834620383478, 58.88195422387893, 27.95935865371458, 41.92590882701259, 30.96187810744009, 52.944474220275886, 49.004049378056685, 42.17499110006517, 55.50725283161287, 77.98209267277872, 40.31545031455256, 0.3451991573937478, 0.5842415111199503, 0.16978077350124238, 0.18077073378428338, 0.12812140247514173, 0.15216216084457215, 0.09370381463198893, 0.19678624617236276, 0.15596892834911424, 0.2516959352238525], [0.06035897587876647, 0.0747109245088312, 0.1418782425143065, 0.11897704759312254, 0.04427454239057918, 0.020386095707034393, 0.05672274337660882, 0.01226825076305578, 0.09431299242761829, 0.045407103795197704, 0.03037602396591777, 0.1098110277446047, 0.04534230424812244, 0.027532462639013128, 0.06820758879785577, 0.4751489972395282, 48.826389543471805, 65.47815707422072, 44.15308160166587, 31.720184049298688, 34.16604857290945, 28.61702834406207, 61.37652281791934, 23.4309293377784, 24.513997723979337, 14.352489825217956, 34.10613044615715, 12.356127942762068, 59.59271907806397, 69.20299668465891, 5.198425054550171, 3.1802339563446664, 28.40937806713966, 69.66385949042537, 64.26023367912539, 57.72166221372543, 55.1663008043843, 56.68645851073727, 48.89463486209993, 38.057663440704346, 13.853805565064954, 0.20896229442329178, 9.10697965852676, 14.563960490688203, 4.144942125966472, 8.558647997917669, 18.6320427925356, 25.926741323163434, 33.36830123778313, 33.0050701479758, 32.8237997716473, 33.17830554900631, 26.82927085507301, 16.511489845091297, 13.240960721046696, 15.023452428079421, 14.282396089646126, 17.018646424816502, 19.071091336588708, 14.524890741994305, 16.92299746697949, 24.48200098929867, 29.902514565375547, 23.51957686485783, 17.650887389336866, 14.178084577283553, 19.410244957093273, 16.441115660052148, 18.88143297164671, 18.893080449873402, 20.395893435324393, 22.738685915547034, 30.517989358594342, 24.795792564269036, 15.428291040082133, 9.464585088914442, 5.556316817960432, 12.78143250173138, 23.71530705882657, 32.40753431474009, 44.11118284348519, 43.94935369491578, 43.454417259462424, 41.84004814394059, 53.41226000939646, 52.59217085376863, 37.678672267544655, 49.1577317637782, 47.940282975473714, 44.260554544387325, 49.02111561067643, 36.322179379001746, 21.294306439738122, 25.34615601262739, 26.76819366793479, 40.93133695663945, 42.855247759049945, 40.967552200440444, 37.21195728548112, 19.379109182665427, 3.7300992636911334, 6.656088617540176, 20.600466612846624, 33.77444697964576, 35.60687242015716, 29.189886585358654, 17.46403940262333, 21.56247300486411, 18.93160008615063, 21.374569900574226, 14.54245609621848, 12.347774274887579, 25.917092292539536, 23.39785199011526, 20.081560573270245, 32.76109676207266, 39.267283178144886, 22.136141215601278, 20.21146555100718, 11.24520778656006, 3.4303370262345965, 19.52659422351468, 37.68403022520004, 41.11334669974543, 44.504298471635394, 46.68577955615136, 47.506876760913485, 51.609260189917784, 56.24581552320912, 52.79154100725728, 53.2704859395181, 53.96947191607568, 52.56602825657014, 62.397849175237845, 45.16570421957201, 21.504419965128747, 1.9620157706160701, 0.0419647604857962, 3.152395914639196, 30.948561660705078, 47.47112435679282, 55.65919368497787, 49.38331903949861, 53.043208122253425, 53.73301967497795, 44.8744878461284, 66.72384692776588, 51.45884906091998, 4.2301114912956, 8.442202633427035, 44.106766254671165, 65.79715167322468, 11.504420561175193, 28.299967473553075, 38.656974146443034, 43.855338404255534, 39.441020642557454, 22.314369793861143, 32.72384797373126, 28.62593016316814, 47.971457973603286, 23.521257600476666, 44.36740383025139, 40.153005353866085, 62.0768424003355, 3.696235480808443, 0.1217485391985505, 0.24549912661314013, 0.03637799151962803, 0.07006872280110275, 0.007702881449668278, 0.21870927704918772, 0.08862500409445456, 0.06702035935896059, 0.03451773851749397, 0.07982583310935767, 0.07042278565706746, 0.016313145207541607, 0.023518146594024958, 0.0557635706518927, 0.015946004273099525, 0.09729398609769922, 0.06501689388026154, 0.03726457741351859, 0.05787064186147144, 0.10761504437053397, 0.0373154264994927, 0.12668337883247485, 0.02229222205407437, 0.04419035315814038, 0.04720467165292752, 0.8246598200451943, 55.487946925624726, 79.79558483246835, 40.516714972834436, 33.398083794501524, 30.119098040365405, 32.17762654827487, 47.297198618611986, 28.216383726366107, 32.433892642298055, 23.093780048431892, 33.37243933831492, 18.48824477964832, 68.11412319060295, 65.43741149287071, 11.393189007236112, 2.58932055484864, 31.64276234565243, 72.29481281772738, 68.93867600348689, 64.70542661605343, 62.44282307163362, 61.58200010176628, 55.21706019678424, 43.39539735547958, 16.349013505443452, 1.3795559348598605, 17.04550877694161, 21.576430759122296, 8.41529223226732, 11.22466633396764, 23.25197119866648, 30.397892267473285, 38.65276936561831, 35.09932164222964, 38.334265062885905, 38.27621398433563, 29.45042806286966, 23.4652167366397, 18.45202365229207, 20.704925214090657, 18.381613185328824, 20.884883557596517, 20.78678115721672, 19.977870756579986, 20.603653538611628, 27.347053135595015, 33.55499429087485, 28.967223436601703, 24.832407889827607, 21.135695595895093, 23.093146585649063, 21.549458580632365, 21.50696558337058, 21.808123204015917, 25.020356101374475, 25.12515006526824, 34.39544839243735, 29.26963817688727, 16.27997292626289, 7.993729124146124, 2.741920856698867, 2.477147141771932, 11.123622155958607, 22.55470714261455, 35.50986828342561, 38.80878163922218, 39.75295105288106, 46.945260032530754, 58.67796351832729, 55.87699505590624, 45.3863493088753, 54.204194391927416, 50.23314760577295, 47.38032540967388, 54.98276525928129, 41.157759697206565, 27.901670394405244, 29.582839435146703, 27.604490057114635, 36.2407745084455, 44.982788408956225, 42.9755154732735, 46.294636880197835, 49.98811321873819, 28.45740552871458, 26.616905889203473, 36.977293645181966, 44.81792726824361, 40.33614081721152, 32.96198291163291, 21.497381271854525, 23.92732293375077, 22.78263411214275, 26.746055810682236, 22.02135697487862, 18.124442984980924, 27.159597181504775, 25.452095308611472, 23.166085020188365, 38.99216421188847, 40.112232315924864, 26.7536554028911, 23.22704257503633, 16.28731462263292, 7.9357898331457575, 25.363406596645234, 43.35272981274513, 46.30892215236541, 47.1132629917514, 48.16415225305865, 50.2050869695602, 52.49803004726287, 56.72292870859946, 55.363545033239554, 54.44454154660625, 53.6551998507592, 55.65301987432665, 63.77538950212541, 39.24518454459406, 16.43727271787582, 3.8605553344372785, 0.32696344559231116, 4.818521930325416, 34.61158275604248, 54.073536319117395, 58.10699978182393, 54.752247564254276, 57.40711558249689, 59.33938495574459, 49.92518663406373, 67.06784663661834, 50.60734172021189, 5.582051978957269, 12.21847922571244, 51.050989243292044, 62.37900610893004, 16.48967166100779, 21.38697635742926, 36.128053434433475, 44.275655669550744, 49.02703446726645, 26.002172423947243, 34.9798737033721, 29.75386065821494, 43.649370824137044, 25.813125948752127, 43.921336204774924, 52.00717287678873, 68.75007275612124, 5.903759387231642, 0.3108053029544892, 0.21865974180400374, 0.07177070969895971, 0.11599938640551222, 0.03798622457731155, 0.12663518424115836, 0.017779516018626672, 0.017177437942835595, 0.039261094474744414, 0.06511389593323393, 0.19847471927923543, 0.13812528502556587, 0.22808608599007132, 0.2185463761129687, 0.06567048179286142, 0.13119234252841244, 0.11521906456759862, 0.11561189913341116, 0.21780380708796365, 0.17584167811418736, 0.1107184205865187, 0.1606828818518308, 0.11177541507828621, 0.32359658109564937, 0.285558017391351, 2.3600918487195046, 67.4652768719581, 86.19860310708323, 57.754010000536525, 45.31021218146048, 42.739937920724195, 38.82633032337312, 87.63867778162803, 36.06473069037161, 47.28078742181101, 24.668286115892474, 43.72701806406821, 14.199114364962425, 67.73155089347594, 77.33462702843451, 10.957400933388742, 5.534129931080726, 37.668756515749045, 80.1077505850023, 77.21043694403865, 68.36579815033944, 68.79844342508625, 68.41171341557657, 61.576685290182795, 48.67375050821612, 20.876568132831206, 0.5086848332035927, 16.5517137512084, 25.526732129435388, 10.681795593230955, 18.30714894879249, 34.475154876708984, 44.02492600102579, 52.4179038693828, 47.79441787350563, 50.095131166519664, 49.960154564149924, 37.340967962818766, 30.941556307577322, 29.57599097682584, 26.33797634032465, 25.739810966676284, 25.460587240034535, 26.156564758669948, 23.543201300405688, 25.514451188425866, 33.14627547417918, 42.13916024854107, 33.96716871569234, 29.052621279993367, 24.79548858058068, 29.240895048264537, 24.250779228825724, 30.191461847674464, 26.68511002294479, 29.91099669087318, 29.05248203585225, 34.93331124705654, 37.047821783250384, 27.158457732969715, 23.513758028707198, 25.715521689384218, 40.017244277461884, 41.92985865377611, 46.9842876157453, 51.529118322557025, 51.13384931318222, 49.457534205529, 47.01915748657719, 61.360413643621634, 56.802933293004195, 47.484287831091116, 55.67501260388283, 57.59224360988986, 49.803212688815215, 58.15417412788638, 55.98353839689686, 45.068507886702015, 49.087058498013405, 47.252754242189475, 52.728649723914366, 52.344794811741004, 43.96450973326161, 53.00077984409948, 48.493239110515965, 22.9966405899294, 21.703240986793272, 35.47114272271433, 49.634825337317686, 41.76203220121322, 32.91517726836666, 25.64504454212804, 27.037317291382823, 27.760010073261878, 32.29559379239237, 26.941389845263576, 21.72782640303335, 32.938452612969186, 31.915535734545802, 27.821761908069735, 44.371067323992335, 45.3431365566869, 29.657207573613814, 27.801191037701024, 21.342851654175792, 12.648334714674181, 33.72199312333138, 50.6259298324585, 49.37461137771607, 50.528019628217145, 50.75034349195419, 53.61122615875737, 57.05935824301935, 60.312207283512244, 59.150487530616026, 60.57069147786787, 54.51508929652553, 51.81114458268689, 63.70999182424238, 49.811359451663115, 28.416665830919822, 4.182200229937031, 0.18781596944937784, 5.416062666523842, 34.25598459859049, 54.49216304286834, 63.96530674349878, 58.314759885111165, 62.92476469470609, 66.33608925727107, 56.73187563496252, 76.40735518547797, 62.04988787251135, 6.863361366333501, 12.907276845747425, 52.38120617405061, 77.21837582126741, 15.903079240552842, 38.583586600519, 49.77072369667792, 50.9294310692818, 49.18281924340033, 28.246815435348022, 47.17911174220424, 37.22627393661007, 67.21645739770705, 36.20927003122146, 60.87303953786051, 56.704807358403365, 85.19619434110581, 12.674656760308052, 0.5675824082666828, 0.6382188405240736, 0.312329143766434, 0.14644858517473744, 0.22582793458094522, 0.38055926321014283, 0.1019625029256267, 0.14321166451179212, 0.093927075635762, 0.1553963695562655], [0.09747851369602066, 0.014508232481837755, 0.0821717398902101, 0.026846459631117123, 0.020805339238816695, 0.028825477328932578, 0.1313647429548925, 0.0552413476661088, 0.11229717458087592, 0.21002141097860955, 0.03564145543702668, 0.14332314562653342, 0.13847858945448555, 0.08806372977673046, 0.2413524152530778, 0.4077298584724627, 17.174137023187455, 63.49778375317974, 58.89954997647194, 41.25212015644197, 52.41413839401738, 30.131139716794415, 42.04214826706917, 42.90075509778915, 24.268376942603822, 18.07320506341996, 24.108387385645223, 35.66324472427368, 20.555365239420247, 75.45000660804011, 29.769469730315674, 3.6311385996880072, 11.514659908510025, 53.430718683427386, 66.89949850882253, 61.45704907755698, 57.20683543912826, 65.27149131221157, 51.17283375032487, 53.9711977589515, 28.850664323376073, 8.64294659706854, 7.406949410515447, 32.85963062317141, 28.80993639269183, 3.753660451019964, 7.821535602692635, 2.9221616108571333, 2.5877212084108785, 1.9960202685286923, 2.2266307521250943, 5.075851967257838, 6.80620409788624, 3.133629579697886, 3.7015042045424065, 8.51942135441688, 7.913030770517166, 10.544634230675237, 10.998913338107448, 16.378747032534694, 27.176486907466767, 33.62099601376441, 27.954032075020578, 15.679263895557774, 8.26434079677828, 15.688649146787583, 27.180905457465883, 16.629419826692153, 25.405895671536847, 23.843680351011216, 22.064442250036425, 18.655014153449766, 23.03194976622059, 25.889998520574263, 22.409420590246878, 20.780336703023604, 15.365422310367709, 6.565953531572896, 13.050335491857222, 21.259609153193814, 32.646463532601636, 37.93115131316647, 49.96475942673222, 49.52915276250532, 54.09891405413228, 52.684593662138916, 46.975995725201024, 55.955007076263435, 45.53473257249402, 46.69561686054353, 52.1912104852738, 43.47892422829905, 33.96874550850161, 31.540059005060506, 37.669843012286776, 46.842011482484885, 48.260332692054014, 42.627907183862504, 23.617592973093835, 6.9953304913736165, 5.32513379089294, 3.6578722490418345, 15.740220469813194, 30.282827577283307, 36.067774449625325, 28.37303730749315, 17.30605809919296, 20.943169978357133, 16.869496337829098, 20.877268275906964, 19.343044950116067, 7.700432913918649, 16.01523941563022, 31.93197438793798, 21.759340686182824, 20.45180486094567, 35.70328820136286, 30.731329033451697, 21.96688702029567, 22.502541580507835, 3.6671023215017016, 2.4179176361330095, 9.127987873169685, 25.251344480822166, 46.046790153749534, 46.05746292298841, 47.08830102797478, 50.23370065996724, 47.67910803517988, 51.08896563130041, 47.46518196598176, 50.41281569388605, 40.69785394976216, 18.525313138961792, 4.088187390758145, 4.954653670710902, 2.3837285416741527, 3.387438063659976, 19.686111134867517, 43.39577390301613, 55.63306285488991, 52.00461941380655, 48.099970509929044, 42.10168592391476, 46.69101984270158, 57.623438219870295, 57.242109314087905, 38.276112002711145, 6.0260745786851455, 16.496510313403224, 82.11254458273612, 67.90106004284274, 42.39724043876895, 37.15636161065871, 45.42928357278147, 41.924869398916925, 35.043890706954464, 28.907168026893373, 21.454784331783173, 37.91000189319734, 31.015842076270815, 29.750297184913393, 46.135161153731815, 47.56765780910369, 42.6730771987669, 0.40724140081194143, 0.1073127843800091, 0.05691219692028338, 0.05768399986047899, 0.03545562931967359, 0.0659210385093766, 0.05695087669958031, 0.07193656773456643, 0.026748770014232686, 0.06960066606200511, 0.029505320989917365, 0.005157118608739468, 0.061974988559321056, 0.010737455787978346, 0.0064179590422539946, 0.06489641123240994, 0.03347733749016639, 0.09864173393936888, 0.056176135812195084, 0.02778519887567288, 0.0660311100223372, 0.06097817793488503, 0.15844854045539133, 0.13348285349146014, 0.04628257758374657, 0.145321011002506, 0.2755412952073159, 18.902256834891535, 77.87343517426523, 60.438091831822554, 40.08790969848633, 52.72455869182464, 31.84435256065861, 42.717953035908366, 33.353584504896595, 34.71915768038842, 22.23351405512902, 31.750843255750596, 28.636791206175282, 30.834820770448257, 65.86240030104115, 32.80799261985287, 3.9543198385546288, 12.290204667275953, 58.280046909086174, 69.22153380609328, 67.66011668789771, 61.116536355787716, 71.05845036045199, 57.32824848544214, 60.67584629981749, 31.535138391679336, 5.808612492776686, 9.47871248568258, 41.08216777924569, 36.34430154677361, 7.197481115018168, 15.805600497030444, 6.588541480802721, 3.2514281618979672, 3.7001139694644563, 5.243125855922699, 8.134193122386932, 9.790239872470979, 7.672009948761233, 6.161832223015447, 11.72734062517843, 12.282912000533074, 13.030519677746682, 12.990369316070312, 17.530205865060132, 33.045317588313935, 38.258214227614864, 35.877241396134906, 22.282114182749105, 10.043873075515995, 19.517741434035763, 30.876509681824718, 20.489332137569306, 31.051457197435443, 25.817360147353142, 28.50235785207441, 22.489717391229448, 27.134080202348773, 31.505106764454997, 24.577296933820172, 17.189787280174997, 10.887872999714268, 14.296887286247747, 30.183220947942427, 42.94381879991101, 50.300278971272135, 54.610461727265395, 51.69946293677054, 51.064948958735314, 58.007861875718646, 56.18207700790898, 48.55771895377867, 56.288749787115286, 53.6187453423777, 51.526051029082275, 57.26662805003505, 47.14064113555416, 36.49146495326873, 33.52489794454267, 37.655177270212484, 49.866147118230025, 54.70866610926967, 47.53430589552849, 43.41589958437028, 21.993612089464744, 10.024525984641045, 8.894097920387022, 22.812734380845104, 41.74506010547761, 43.85495793434882, 31.785556231775594, 21.459049909345566, 24.90545418954665, 21.08998037153675, 28.854990697676136, 22.574946572703702, 13.970688273829799, 21.137329263071862, 35.737224548093735, 23.96776649259752, 25.12894888078013, 37.98693526175715, 35.869435879491995, 22.789957177254465, 24.99590208453517, 6.285024064202463, 5.692221551172196, 12.56840563589527, 30.95485902601673, 51.14967215445734, 50.58018715150895, 53.32811732445994, 54.888851950245524, 51.6447772518281, 53.70070326712824, 48.01591019476614, 47.84986449826149, 34.97062867687595, 13.745443224906923, 4.991944134235382, 9.136726913913604, 9.742778212793413, 7.231160056206488, 22.94845819473267, 47.5950437976468, 58.6667965304467, 56.158734983013524, 55.23812724697975, 46.825894463446836, 55.99302661034369, 62.83129069112963, 59.69650107045328, 43.17619962076987, 7.026269656996574, 27.566468561849288, 84.99187807882987, 69.78608054499473, 48.90293851975472, 25.18521135853183, 46.37082892079508, 44.032135317402506, 44.30150016661614, 29.379005624401955, 26.831887075977942, 38.21306774693151, 36.359320302163404, 29.994111714824555, 48.727377153212025, 58.78764083308559, 47.466213549337084, 0.5381251631244537, 0.16424132961659663, 0.05157272113607295, 0.09595894765469337, 0.02708992620389308, 0.025007061457501787, 0.06991567375559, 0.07148389404098834, 0.11491141897896606, 0.06131796857282039, 0.008418108317850819, 0.26113522629584035, 0.17800881827790893, 0.18003570306445324, 0.12883040152730482, 0.17326484945031906, 0.0839494928837784, 0.15067559787102286, 0.24867892776045109, 0.1346148862954109, 0.3520699548384836, 0.19582007140401872, 0.18333361964792977, 0.2737721223984995, 0.2989301433967006, 0.32217184141758953, 0.37127774028528127, 30.017620440452333, 89.78943886295443, 73.93350847305791, 54.66851280581567, 69.43730338927239, 39.120311967788204, 60.45156125099429, 58.62545082646032, 42.23576430351504, 31.575797680885564, 34.87223209873323, 39.36366758038921, 32.01956679744105, 83.79051100823187, 35.14180875593616, 6.358551344563884, 17.551618083830803, 66.91456825502458, 76.88364075076196, 74.41706611264136, 67.79120229905652, 77.24501655947778, 62.166456791662405, 66.29896794596027, 34.39416185502083, 14.065680234662949, 10.27298362024369, 42.841684202994074, 39.70789086434149, 7.12420976931049, 19.823649044959776, 7.584843606718126, 5.41887745741875, 7.205897050519144, 7.833905777623577, 10.478986501693726, 12.188579978481417, 13.797407765542308, 11.519236333908575, 17.365079964360884, 16.510801469126058, 17.140294813340713, 16.72372733393023, 20.67785889871659, 39.76256085980324, 48.95523940363238, 43.626993702303984, 25.700191105565718, 15.791012221767058, 23.696932715754357, 35.429330256677446, 24.30909114499246, 35.2328077439339, 33.572374313108384, 31.429352068131973, 28.27000644899184, 28.439021379716937, 31.76539917146006, 34.49450000639885, 38.18827836744247, 34.51156231664842, 27.380183435255482, 36.36708267273442, 47.65491877832721, 52.0160884241904, 54.09190477863435, 54.56830801502351, 55.90574602926932, 59.684745727046845, 55.301355854157485, 55.22311241396012, 59.22395352394351, 55.39188023536436, 49.783671440616736, 57.80833874979327, 58.21580240803381, 51.32118563498221, 46.92374975450578, 47.39922731153427, 53.00587108058315, 56.216617399646395, 52.34434373917119, 46.028621735111365, 18.557031385360226, 13.420680780564586, 12.114568775699986, 27.251892512844456, 49.13817482609903, 48.689989120729514, 33.42929409396264, 23.979039384472756, 25.96236821143858, 25.8762643414159, 33.30816738067135, 30.95355679911952, 17.70438655730217, 25.947133725689305, 43.58996260550715, 29.54294500812408, 29.475913663064283, 43.03865386593727, 40.92901491349743, 28.569834386148763, 31.19186039893858, 9.303146216177172, 7.719787359237672, 20.002183568093088, 38.94882594385455, 57.23630812860305, 57.10932531664449, 55.80534511996854, 58.21858336848598, 57.290852608219275, 56.97407414836269, 51.51747672788559, 52.44661169667398, 45.28445789890905, 24.020245844318023, 7.35132824028692, 7.10064564020403, 6.138316142943598, 7.660117322398771, 25.129272476319347, 49.655845319071126, 62.638419905016505, 58.660465824988584, 57.02463742225402, 50.41135264981178, 58.944037498966345, 68.27512079669584, 66.31424165541127, 47.634149828264796, 9.313450282619847, 23.2168875586602, 89.60421669867732, 80.07264537196006, 47.383631967729144, 50.97040022573164, 54.844619381812315, 49.39609812152002, 44.226555439733694, 41.03905308631159, 33.196517113716375, 47.87691708533995, 49.16392126391011, 41.91547139998406, 63.55345787540559, 63.33058487984442, 66.21145202267554, 2.1391373824688698, 0.41734018633442543, 0.32618960485823695, 0.3565891075038141, 0.1268068798667481, 0.14321282896543705, 0.2820116738157888, 0.16862824018443787, 0.29123172584560614, 0.17525195895183474, 0.13905102567326638], [0.025496206681935057, 0.12700785537280385, 0.05546016919036066, 0.06475024931733647, 0.06827869707898748, 0.07940787085962873, 0.06350961971967932, 0.039045750989668795, 0.032362553155830795, 0.006364476529040164, 0.04173320658024281, 0.06353444862930525, 0.08019275092069181, 0.010743016628698717, 0.1214572266044636, 0.050276036884996204, 0.3765616019166285, 54.669081549490656, 62.760617425364835, 34.44829056339879, 31.009242688455892, 34.307049935863866, 28.724130622802246, 58.11576627915906, 24.02422312767275, 32.88664790891832, 17.159212404681792, 44.13179489874071, 35.02437299297702, 61.56898959990471, 65.6362638934966, 11.403117506734787, 5.468894050967309, 46.91080201056696, 64.84866765237624, 69.61269609389767, 61.105306609984375, 59.934796825532, 59.629475608948745, 40.5005116616526, 29.54627706158546, 27.23131968129066, 9.106560945510864, 2.0680287336149523, 8.34994750638162, 17.412472001967892, 13.60382212746528, 13.181750582110498, 7.642464695438263, 11.183517729082416, 16.880616257267615, 20.851366904474077, 17.723376712491437, 10.125557414947018, 20.333702295057236, 21.62384044739508, 11.836037347393653, 6.86810645364946, 10.34244389303269, 26.707706797507505, 30.369939496440274, 30.453888024053267, 8.968754353061799, 15.030708812898206, 21.91521763801575, 25.85758013110007, 31.14097745187821, 15.998470302551025, 23.026436874943396, 33.64002343147032, 20.276270950994185, 18.30729211530378, 18.579012347805886, 25.205289971443918, 31.848684818513934, 29.799764156341556, 17.8893361168523, 5.23421815326137, 9.700661763068169, 18.11522541507598, 30.729401188512004, 33.16163547577397, 45.75889210547171, 49.52775639872397, 53.94109356787897, 46.163739542807306, 43.84623458308559, 50.43038791225803, 44.51099003514936, 51.21269679838612, 53.74246474235289, 48.9910271090846, 45.016677687245036, 39.272970614894746, 46.10709267277872, 46.79964203988352, 56.342003806944824, 36.204727926561915, 13.122714988646969, 8.206399054296556, 5.3023502134507705, 2.938717690206343, 16.703835033601333, 34.614214666428104, 37.084084095493445, 30.273100099255963, 20.465133074791204, 18.23235719434677, 17.84822771626134, 22.973345633476015, 20.994072537268362, 15.726608864722715, 13.6120512600868, 28.71521899777074, 25.82499896326373, 11.936113680562666, 18.77329714836613, 33.06193667073404, 26.555220734688547, 24.915242464311664, 12.280416392510938, 3.157706068408105, 2.252809140951403, 1.2980510438642194, 7.354848567516574, 14.154473870031296, 19.41113925749256, 24.16933905693793, 35.263421843128825, 32.59683378281132, 23.223596772839947, 11.28656525765696, 8.57189384198958, 5.503185862495053, 33.59180965731221, 31.28531086829401, 3.3401347696781163, 10.819055995633526, 36.26069622655069, 54.31361283025434, 50.18334134932488, 52.76524543762208, 55.17329439040154, 61.38500690460206, 58.34194975514566, 53.84058283221338, 56.570089632465, 37.852299905592396, 3.2770152534207995, 12.008088192632123, 30.21962250432661, 36.32379931788291, 18.67886608646762, 31.732162967804943, 46.85271170831496, 40.7352106032833, 30.076495216738795, 27.403786297767397, 25.79334935834331, 35.10447171426589, 26.253504176293653, 30.121614240830947, 44.534841968167214, 58.399781180966286, 18.42887382353506, 0.44690125171215306, 0.16325621715476438, 0.18969248649814438, 0.08234839976554917, 0.12495753595665579, 0.2707152783630356, 0.0627745392041341, 0.032257645075479825, 0.05294398787701803, 0.04954732639054137, 0.054322555435881506, 0.02763919400862388, 0.10499198996131459, 0.018321812423246524, 0.01967040679207252, 0.04192370200349439, 0.09551473157179934, 0.02619788001832222, 0.018888259749679316, 0.042169374909492276, 0.13459915084944618, 0.022880682917011362, 0.04125956506017716, 0.04867949815947683, 0.1017128195493452, 0.14113028023031451, 0.1316577409424128, 1.2040743640353604, 64.97585442758376, 74.5685088249945, 34.61636412528254, 36.00738171608218, 29.3424589403214, 34.62287918213875, 45.282998777204945, 29.17500903529506, 36.00208651634955, 25.33454187454716, 45.78664679681101, 35.56662105744885, 61.00112845820766, 65.93902772472751, 17.605299642009122, 5.6730181171048075, 49.57008661762361, 70.95453892984699, 79.08755779266357, 64.89756784131451, 66.16912180377592, 64.21615016075873, 46.112254511925485, 34.8699688911438, 25.256743623364358, 5.864111088937329, 3.03931545346014, 6.656015073099445, 14.971334915007315, 19.213877377971528, 18.829302710871545, 15.799764990806581, 19.74126946541571, 23.551971720110988, 28.149989766459314, 25.079175964478527, 15.636549284381253, 27.086907817471413, 28.53267385113624, 16.320058568831413, 8.630117504827439, 13.876792615459813, 29.456223364799257, 36.535356275496945, 34.09939965894146, 17.329837468362626, 15.479487776756288, 19.951255513775735, 26.534983265784483, 34.80159021192981, 16.982954817433512, 26.14718048803268, 37.82811849348007, 24.430404170866936, 24.233703190280547, 21.20578246731912, 29.068854008951497, 35.19092467523391, 33.03953209230977, 24.620099798325572, 18.072400977534635, 29.72853195282721, 36.94336122082126, 40.83235202297088, 44.18782595665225, 52.3173225310541, 53.30691691367857, 58.26836216834284, 56.145324399394376, 52.740522738425966, 61.15076295791134, 57.119754898932676, 56.95428186847318, 62.23872646208733, 52.465756785485056, 44.14121643189461, 42.807936130031464, 48.10287698622673, 53.604899375669426, 53.01436693437638, 47.02489591413929, 32.529237616446714, 12.004548253551608, 8.7324894051398, 6.894017631007779, 21.13448162232676, 42.413522197354226, 44.19527845997965, 30.18875345107048, 24.236291954594275, 21.4872831298459, 22.068086131926506, 30.89888680365778, 26.60007303760898, 20.946776597730576, 19.671068845256684, 31.495985292619277, 27.78748627631895, 14.615143499066754, 23.214220346943026, 32.70354774690444, 26.494645610932384, 25.28160752788667, 14.733724594116213, 7.4049190936550024, 5.442433741784865, 2.7825468057586304, 8.326100476326483, 15.831223380181099, 20.852675014926543, 22.951588246130175, 35.10433835368003, 31.925233794796853, 21.00835780943594, 8.682987132380086, 10.183269208477391, 11.417415526605422, 47.3679111080785, 42.729739758276175, 7.160830978424319, 12.713986366025864, 38.159284207128714, 58.67999922844672, 53.94143873645414, 57.92770039650702, 58.672625172522764, 64.34427438243743, 63.920352458953865, 58.1037599040616, 60.85882486835603, 39.60062188486899, 5.112370704450916, 15.846854025317779, 33.218411784018244, 49.44687320340065, 20.433599179790868, 30.738824682850993, 47.06599450880482, 46.839324658916844, 39.808064276172274, 25.979389336801347, 30.55938997576314, 31.128096388232326, 31.08459730302134, 31.171720989288826, 51.13637531957319, 67.22703210769161, 22.671442762497936, 0.3838368018548335, 0.3822912347893561, 0.28118068292256326, 0.13720829310196062, 0.1556283716232546, 0.05478571304270337, 0.022087592308619813, 0.06638592364446771, 0.12572114941694085, 0.06628496091692679, 0.17080065103307848, 0.19850393787266749, 0.29916646619958265, 0.13015870605745625, 0.13666619396498128, 0.16810279579893236, 0.11948609003616918, 0.253944035559412, 0.2560887140251937, 0.09775804385783211, 0.2922300609850115, 0.2551928508065401, 0.2250579396082509, 0.29444650656753973, 0.1555787444475197, 0.410516947628029, 0.36978374625886645, 3.8263385382390793, 81.65944806991085, 84.1155029112293, 49.043845745825, 42.90683869392642, 42.23419927781628, 42.76458609488703, 76.04039392163678, 34.66695485576507, 53.07302598030337, 26.352108640055505, 55.53810227301813, 39.24633379905455, 71.40291290898477, 73.55838083451795, 17.851302854476437, 8.907121169951655, 57.701218820387325, 73.8598620507025, 81.44796171495992, 72.07017083321848, 75.29847760354319, 70.53202905962544, 51.32335862805767, 35.328344914221, 34.78984271326373, 13.27858703751718, 4.461824528632626, 13.256613919811866, 23.84398433469957, 24.98735720111478, 19.600899604059038, 23.342170023149063, 24.54791642004444, 30.345238370280114, 35.62593121682444, 26.647880846454253, 20.37208660956352, 28.411482418737105, 40.943770870085686, 20.62301043541201, 11.076406625009353, 17.64105792968504, 35.04655791867164, 44.848419773963194, 42.09297826213222, 19.080173584722704, 23.811809132176062, 29.088283469600064, 34.50630241824735, 45.01919192652549, 23.939439135213053, 31.910583742203254, 45.183943240873276, 30.1645367376266, 26.183787968850908, 26.429508770665816, 32.30859841069868, 41.23662679426132, 44.37494262572258, 37.873355188677394, 28.7233010415108, 38.560452461242676, 45.693204172195934, 49.30385574217766, 51.44483443229429, 56.025876460536836, 56.204771841726, 57.42983395053495, 50.44331996671615, 50.06929059182444, 54.93938384517547, 56.70879248649844, 52.99661820934665, 58.2649536286631, 59.427889316312736, 52.93507622134302, 48.70978140061902, 50.36406063264417, 53.55268870630572, 58.458436304523104, 52.026847485573064, 39.428822071321555, 24.35236861628871, 15.73558226708443, 16.297284307018405, 34.35628744863695, 54.59348570915961, 47.6243164462428, 34.23774949965939, 27.081936213278002, 23.23184355612724, 27.68002510070801, 35.81883730426912, 32.72839988431623, 27.280704282945205, 23.711655332196145, 37.195883412514966, 35.90152086750154, 21.501778248817693, 26.48100752984324, 39.4270295481528, 31.242457012976374, 32.40811678671068, 19.764809570004864, 8.558819601612708, 5.536240166233433, 5.8747029592913975, 14.877765793954174, 21.884266214986003, 28.173614202007172, 33.522615125102384, 44.821480935619725, 41.29516816908314, 28.48175560274432, 15.981951240570316, 12.311356048430167, 9.046759509271192, 42.70775095109017, 35.90148164379981, 8.001780279221075, 14.341873930346582, 37.03540355928483, 62.988605191630704, 56.40280446698589, 61.84614035391039, 63.60202074050904, 69.76602938867384, 65.75344470239455, 63.20181346708729, 65.88127474631032, 46.261904701109856, 5.640919891095931, 19.05029885230526, 40.503163183889086, 63.79526415178853, 22.097954980788693, 43.26058549265708, 53.58922558446085, 52.262715293515114, 35.25806388547344, 39.800843192685036, 35.9007324710969, 45.913382499448716, 39.639108180999756, 41.559257430415, 62.29690305648312, 74.31945400853311, 36.32285010430121, 0.5777221028843235, 0.5228535374326091, 0.30452923488713085, 0.2901719504546735, 0.2758177916609472, 0.396362615208472, 0.17124904229515986, 0.27636863952202184, 0.1596453230107023, 0.13383087191370227, 0.18343155632816976], [0.04942816141391954, 0.09206882212311031, 0.016184501808076616, 0.10889716145973052, 0.02754549379460514, 0.10668361168955603, 0.05115297390148044, 0.04862720116732582, 0.0690462788747203, 0.03633309110638596, 0.22585566696380416, 0.08048294502640925, 0.05308484463321586, 0.1110269854806604, 0.1261848241331116, 0.09199262701816137, 0.08823285134689463, 30.304471215894146, 74.68435210566368, 43.93349947467927, 33.696866420007524, 47.81679107296852, 25.963229171691406, 47.09980141732001, 44.16190693455358, 29.140596120588242, 24.09243510615441, 18.619365692138672, 53.444878439749445, 52.562886438062115, 72.58640181633734, 30.674960651705344, 3.9524866207953426, 19.927823274366318, 54.22767762214907, 46.73604080753942, 50.6802232803837, 58.93022683358962, 58.73811698728993, 42.02466626321116, 48.70782806027321, 24.524221381833478, 23.400579998570105, 12.421314793248332, 2.179963127259285, 2.9485035134900004, 6.650946390244269, 11.484962663342877, 49.74107450054538, 10.055244026645537, 29.88656620825491, 16.488096829383604, 7.882596119757622, 9.175344609445142, 11.152993844401452, 11.085257453303184, 2.933399201400819, 4.787536186556663, 14.574072360992433, 29.655899463161347, 33.25666273793867, 13.105302606859516, 4.690078035477669, 20.76575136953785, 14.060226178938343, 28.060571493641024, 24.623212199057303, 16.676780485337783, 23.60729871257659, 33.024921263417895, 20.435436810216597, 14.564028151573675, 22.786823203486783, 32.383123443972686, 38.68324618185721, 34.47395070906609, 19.94139467516253, 5.042123015849821, 11.093540518514573, 18.588671184355213, 32.005836540652865, 34.23606680285546, 43.85152586044804, 45.52220452216364, 50.607726112488784, 49.076770121051425, 39.71925004836052, 43.522843007118475, 39.5857717913966, 46.413139527843846, 53.06912714435209, 58.715747710197206, 49.26875837387578, 45.634905984324796, 47.999381326860004, 50.65463765974968, 54.96329069137574, 34.33176479031963, 19.547098413590465, 9.856506355347173, 9.116943459356985, 2.444190897287861, 20.824643796490086, 37.57224659765921, 42.39992726233698, 33.73923586260888, 24.67787042740853, 14.878743444719623, 18.015622708105273, 19.513005172052694, 21.783802547762473, 30.621443833074263, 20.123229872795847, 22.978938933341738, 25.052362641980572, 18.40820881628221, 10.440364883792016, 15.51897329668845, 21.948204771164928, 25.92139905498874, 20.67714502734523, 4.217438313268846, 3.905671661899936, 2.912946002137277, 2.85927424988439, 3.1068785248264192, 8.573128408001317, 5.26154040328918, 8.52478813740515, 11.217451134035665, 7.147521886133379, 15.490474335608946, 23.09949886414313, 27.248566342938332, 39.322141447374904, 12.541098094755604, 12.434913650635751, 21.890675367847567, 33.30215830956736, 54.299492297634, 52.809556453458725, 53.086926860194055, 54.21576538393575, 57.54751290044477, 52.6381802558899, 52.48879678787724, 55.379195290227095, 20.122827829853183, 1.8821721259624729, 21.78777590874703, 25.414483701029134, 14.536630395920048, 24.865899047543927, 38.33812859750564, 40.054040032048384, 37.34656518505466, 21.18294446699081, 32.09580394529527, 23.40761280828907, 47.191565267501346, 24.460926094362815, 39.38923751154254, 48.53938971796344, 49.96437111208516, 3.096289841398116, 0.06527285917752212, 0.12763317464099777, 0.07665092726388285, 0.1360348915500987, 0.03686854443062217, 0.11244809390195917, 0.048320490205960895, 0.05872930385052197, 0.0062648285998992866, 0.05155405157335824, 0.04031785147925539, 0.10245292943211333, 0.03179878905235279, 0.009118531015701592, 0.08794378339042587, 0.02834303920427638, 0.010072709804761314, 0.03589741690384765, 0.027268869021246513, 0.013501884062744439, 0.1315440381726911, 0.19104000451343675, 0.12783913737944058, 0.07377471143920576, 0.014754260661110524, 0.024805697161824476, 0.05345610999352029, 0.010344660484171923, 31.58395621084398, 89.13820774324479, 45.98855864617133, 38.56673609825873, 38.587854139266476, 29.389252816477132, 44.62862191661712, 40.178924375964755, 36.90843251443679, 28.93562286130844, 28.214306831359867, 46.379211025853316, 63.68993674555133, 79.33332566292056, 42.96256772933468, 6.663869619369508, 19.131703722861506, 57.85389315697455, 60.83147810351465, 55.374829692225305, 64.7329459651824, 61.225539022876376, 46.74512893922868, 54.338484579517, 31.436126001419563, 15.56275087018167, 6.0538778093553365, 1.780789030655738, 2.1263033872650516, 6.311392197685858, 19.242073335955222, 54.23816211761967, 15.23771385992727, 32.494257919249996, 19.668213359771237, 10.027868824620402, 11.311053595235272, 14.080150838821167, 12.66904777096164, 3.2085752871728714, 5.0174959244266635, 15.009585868927742, 34.41604475821219, 35.21626318654707, 21.62355019200233, 5.722408602314611, 18.216814802538966, 18.575511632427094, 28.775062599489768, 29.012077700707223, 20.438608046500914, 25.54044669674289, 38.3062122714135, 23.767366716938636, 19.04224426515641, 21.580659074168054, 31.54933148814786, 44.41379762464955, 44.212379993930945, 28.297431661236672, 13.219851505371834, 20.027059239725915, 29.399456862480413, 42.39564795647898, 45.61369772880308, 50.958119284722116, 54.08249109022079, 58.77916066877304, 52.52326265458138, 50.60277608133132, 55.78501155299526, 51.78179348668745, 52.81792679140645, 64.00421273323798, 60.782440631620354, 55.567441601907056, 47.51722789579823, 54.288364533455145, 54.12061260592554, 58.64799661021079, 45.53502282788677, 26.1657529107986, 14.925402979696951, 11.121021624534361, 10.058427030040372, 22.189742365191062, 45.42898155027821, 49.17983824206937, 32.30534480464074, 26.614870179084043, 18.132179860145815, 20.11111759370373, 28.653737806504775, 28.944691381146832, 35.97513591089557, 26.476355598818873, 27.77074363923842, 29.25176589719711, 20.97431359752532, 14.417718841183571, 20.879631503935784, 22.075352322670724, 26.962688315299253, 18.589379172171316, 7.149710568689532, 9.967113271836313, 8.348239314171577, 5.9144100931382955, 6.929021843018071, 15.97970372246158, 9.503908811076995, 10.705028772354128, 15.941647906457225, 13.281245423901467, 21.48434723577192, 28.548873239947905, 28.779134019728634, 43.74510019056259, 17.072318177069388, 15.033851611998776, 22.373495601838638, 38.71465259982694, 56.84329055970716, 56.57210573073357, 55.707838919854936, 59.552675600974794, 60.433989032622314, 58.52227680144772, 59.332226630180116, 62.26158995782176, 25.113551616668705, 4.622005301137125, 22.940791922230876, 31.177688875506004, 27.67106640723444, 18.65479842309029, 40.48237069960564, 39.851139745404645, 54.9423413122854, 28.372707828398678, 28.101138607148204, 27.525726902869444, 42.760832386632124, 31.894553015308997, 35.48899735173872, 57.9026678300673, 54.058615622981904, 4.258408940607502, 0.18220704138999988, 0.3063197968707931, 0.032843166076007395, 0.07424636113066828, 0.02488664392712376, 0.045830340560285315, 0.03534031776531089, 0.05204144437166472, 0.045978544099677, 0.03712560523361449, 0.12580783992645242, 0.16911602368758571, 0.1391315108705913, 0.18845609719714812, 0.21617983858431541, 0.21115054797020652, 0.19209184323347386, 0.2961275179780299, 0.1264042087319878, 0.2188462076047736, 0.1868042124495391, 0.29772156308735576, 0.23634598470262944, 0.10687415307808308, 0.20273432135581973, 0.31598016559596986, 0.21398390883639937, 0.16086775418971816, 45.99650929051061, 98.34196306044056, 61.14135319186796, 48.63815499890236, 62.4808112267525, 37.3831412869115, 66.77593600365424, 55.1789386810795, 48.093553512327134, 36.790400551211455, 27.11330144636093, 57.49439616357127, 65.26957719556748, 81.49220605050364, 39.57658167808287, 6.925597613857639, 25.561031295407204, 63.2399389051622, 59.69536750547348, 59.28410307053597, 71.07410846217986, 68.1908525959138, 52.86947065784086, 58.38932021971672, 31.098923760075724, 30.093320223592944, 17.570278759925596, 4.093474255454156, 4.651416213281693, 11.678208035807456, 30.256310393733365, 63.89890886122181, 23.495754349616266, 38.33211560403147, 22.64595323993314, 14.736732071445836, 18.347247339064076, 19.848901264129147, 19.554225360193563, 5.178693571398336, 7.582928999777764, 19.6792842495826, 41.42430828463647, 44.200863915105025, 24.4256914431049, 10.292676860286344, 31.91386284366731, 23.94773102575733, 38.677033147504254, 36.67665181621429, 23.64002108573914, 33.837671664453325, 43.938418126875355, 31.273771255247055, 22.144813576052268, 27.417569506552915, 36.5798516427317, 50.4781113901446, 55.81863411011235, 47.102503930368734, 35.79176510533979, 42.07900677957843, 46.44169046032814, 54.23748746995003, 55.56943024358442, 55.85115055884085, 55.718539145685014, 56.980145977389434, 51.47829617223432, 48.57411053872878, 49.93860506242322, 53.43985388355871, 49.91641229198825, 56.057592745750185, 63.697840321448545, 54.17360774932369, 52.10098420420001, 52.10493010859336, 56.978169102822584, 59.38513155906432, 49.34459347878733, 46.310518557025546, 35.66048337567237, 25.579336997001406, 31.85999889527598, 45.47354752017606, 56.705556531106275, 52.99857939443281, 36.83061661258821, 30.420216437309023, 20.17509537358438, 25.043904050703972, 34.8261599386892, 34.786857789562596, 40.64102272833548, 31.362418782326486, 32.196655927165864, 36.391177792702955, 26.883901626833026, 18.444959463611728, 22.76519133198646, 26.89063241404872, 31.117694262535345, 24.14165104589155, 10.152186386046871, 9.182743180182673, 7.534833877317368, 7.353715983129318, 10.014206228717681, 19.125486766138387, 14.238273347577742, 15.800971119634568, 22.856117756136005, 16.900079058062648, 22.180195316191643, 34.606471907707956, 40.256803035736084, 49.3483667988931, 14.63657238791066, 23.896922603730236, 26.014051322014105, 38.20813732762491, 61.765233624366026, 63.27973919530069, 58.645043065471036, 63.130218444332, 64.85637903213501, 62.359033400012606, 61.02004997191891, 66.23428021707844, 26.11265774696104, 4.813100234154732, 29.73434686660767, 36.9110369682312, 30.19174621951196, 34.38646616474275, 49.85162258148194, 46.12029144840856, 53.27047025003741, 27.65578877541327, 46.204104654250614, 30.448416317662886, 60.67052756586383, 35.920191349521765, 51.38051540620866, 62.375777998278224, 72.09306963028448, 9.436244003234371, 0.5430615885603813, 0.910124711451992, 0.27308199975279074, 0.28406031549938265, 0.18090190335867867, 0.27133645309555915, 0.164525211157818, 0.27952853770506, 0.1530580700285012, 0.16602138087393778, 0.15593578738550987], [0.09480183313210165, 0.05604575530836179, 0.11362347962154497, 0.033292679656897826, 0.06561704716014286, 0.05021645056624567, 0.13531620914657272, 0.07903325386465558, 0.08462859152425682, 0.0693521241567308, 0.19149944276338626, 0.06054145036145084, 0.1261614124861456, 0.05326251574461499, 0.2851133493165816, 0.137727486210004, 0.4251286958254153, 6.511668908980585, 65.09949145778533, 59.39041106931625, 35.942564548984656, 41.89093305218605, 39.82973537137432, 32.456924799949896, 56.11042314960111, 31.480299734300186, 43.56667157142393, 18.716520840121856, 44.92482362254974, 41.120516792420425, 37.2804497134301, 65.6709337234497, 19.35278419525393, 7.5404433569600515, 28.51419556525446, 61.389862798875384, 56.63938222392913, 70.21372087540166, 65.65674258816627, 60.886771755833784, 52.78242541897682, 46.606771253770404, 20.38958430290222, 7.901854467007422, 2.3189824675360033, 0.2470092238077233, 4.687954562325632, 14.418414081296614, 21.85155757011906, 11.256532649840079, 5.6971838397364465, 1.3425894345968001, 0.6915223802770338, 13.11665100436057, 23.54210303675744, 4.047957846233922, 5.340407010047667, 7.4284940092794365, 23.31297189958634, 32.82742011931635, 22.973706491531868, 3.176053200037249, 16.360435447385235, 20.04577875137329, 16.261697623037524, 30.665858791720485, 21.290009483214348, 19.86829738463125, 23.53106744827763, 24.388981980662194, 30.150324029307214, 14.558012216321885, 25.602671177156513, 40.66808316015428, 43.6557956664793, 32.70662484630462, 14.11478634803526, 6.984212042823915, 13.304569798131144, 16.73070719165187, 30.56757203994259, 38.737661223257746, 43.65244596235214, 50.29212828605406, 53.04660489482265, 46.88987616569766, 41.32720216628044, 41.718278161941036, 40.897220180880645, 43.73520797298801, 49.61433487553751, 52.60265534923923, 47.261595264557876, 42.971985340118415, 45.184727714907744, 55.50193802002938, 54.11974183974728, 45.001152946103005, 31.517609319379254, 18.694302574280773, 12.052829688595189, 7.0404210782820185, 12.538718196653551, 30.790176353146954, 44.43411942451231, 42.16243559314359, 29.085310313009447, 11.145100074429667, 13.45923081521065, 17.471756665937363, 25.727075030726773, 25.742721365344142, 29.148901739428123, 20.731001130996212, 21.739544483923144, 20.317226379148423, 20.51371359056042, 6.345344724193697, 12.49898752858562, 21.61242635019364, 23.95372440738063, 17.73736192334083, 5.636556254279229, 2.0533807647805062, 2.184581963285323, 5.045013312370547, 26.90869296750715, 27.933725964638498, 31.139526174914455, 41.245781606243504, 30.767267750155543, 20.60992148614699, 5.055609595391059, 1.7256662465872306, 5.342983026658335, 9.782536337452552, 16.777534407954064, 23.8576381052694, 44.73367083457209, 53.406686321381606, 50.10151286279002, 54.00016054030388, 52.49197390771682, 54.708611196087254, 55.505134751719815, 54.42238799987301, 54.067688065190474, 20.535567075975482, 6.029395355332283, 51.99763759489983, 53.82562291237616, 29.881753460053478, 44.02401601114581, 33.853165026633974, 44.271874504704634, 22.157708367993756, 32.556015637613115, 30.481285779706894, 37.9974550585593, 32.25188093800699, 27.26418914333467, 46.302069771674375, 54.893021429738695, 23.023999121881303, 0.5049269267868611, 0.2877897847323649, 0.12548394561294587, 0.14562533176954717, 0.06634586490690708, 0.11594353093495292, 0.03255450414613851, 0.10519685719402568, 0.039095117695509427, 0.09560279337869537, 0.0695373259124256, 0.033422278751048355, 0.0746122753668216, 0.038468791021695065, 0.08380632637248886, 0.0767809400455125, 0.06621554569010774, 0.024224891432470853, 0.20499072608447846, 0.0058746944940198335, 0.012685333926891609, 0.10721699274595707, 0.011424954582546509, 0.09097798186684809, 0.07114774232069332, 0.007890509310058288, 0.13267676045577373, 0.11917744087235582, 0.3798763417909223, 7.344997044532531, 77.6982307434082, 67.256222386514, 38.11858569422076, 43.81845243515507, 36.6044056800104, 38.37302200255856, 39.73043272572179, 36.60211501582977, 42.49365229760447, 24.706709654100482, 44.400787122787975, 47.67536217166532, 46.345090327724336, 71.90988709849697, 28.47154567318578, 9.833139815638143, 29.38969408312152, 64.105711906187, 60.170539117628536, 74.4110413520567, 67.53938613399383, 60.43629930865381, 57.13167890425652, 53.914523432331706, 24.332892087198076, 10.59856289817441, 4.488451538547393, 0.7387334985598442, 5.630573659173904, 17.216618253338723, 27.569908480490408, 11.762188922974373, 6.911605048564173, 1.8697124719619753, 1.7597816740312886, 16.077393293380737, 28.491587023581232, 4.747666764643885, 5.559917063482347, 8.849066169031206, 29.713905434454645, 38.35031932400119, 29.856869943680305, 9.058588397118355, 12.007343922891925, 22.663709809703214, 21.031754747513805, 32.41471029097034, 23.77521145728327, 25.33403196642476, 27.528005799939557, 29.078099035447647, 30.90455266737169, 18.139047930317542, 25.07222748571827, 39.91419969066497, 51.64593827339911, 43.95472341968168, 24.95487213134766, 15.60288848415498, 22.390765797707346, 31.8915347514614, 40.781321987029045, 43.82718755352882, 49.609353465418664, 54.02624037957961, 58.98687370361821, 53.42913796824794, 45.15338013249059, 49.075185483501805, 49.948834603832616, 52.57368080077633, 60.21447750829882, 60.51383672222015, 57.3026510976976, 50.79572139247772, 54.258338789786066, 56.317900842235936, 59.32466430048789, 46.19294943348054, 32.71959024090921, 20.69241677561114, 16.822372982578894, 12.374463062132559, 28.291699117229832, 45.05740757911436, 52.07572021792012, 40.56797642861643, 27.859500992682676, 12.310476456919025, 15.875154906703582, 22.000478198451383, 29.96646684985007, 29.155879635964673, 32.85272332929796, 26.53075691192381, 24.242938410851266, 26.655005831872266, 22.14812013410753, 14.851437864765046, 17.4526664903087, 23.341199236531413, 27.812940497552198, 15.55454723296627, 7.723501843790855, 6.795335700435023, 6.366441192165499, 9.63666731311429, 31.898087070834254, 34.85880582563339, 37.29958303513066, 47.22684306483115, 38.27243281948952, 23.891041009656846, 4.4842438159450415, 0.6131908706118984, 5.5064277014424725, 9.208179750750142, 15.534784370853057, 27.04278507540303, 43.59299067528018, 57.03205070187969, 55.986601768001435, 60.166887390998106, 57.48530803188201, 62.375613258730986, 60.07164439847393, 58.98770916846491, 61.47014979393252, 24.011322452176003, 8.768189837855678, 54.824846713773674, 46.351009184314364, 37.7859922378294, 41.579877330410866, 37.24404619586083, 48.49918934606737, 36.774161938698064, 27.783330525121382, 30.696221859224384, 35.31944113392984, 33.3183616207492, 29.993182113093717, 45.79992794221448, 67.51789154544954, 26.8734916563957, 0.37122451249630223, 0.12748367258257445, 0.007454870539086481, 0.17355124375993208, 0.045649700858179605, 0.14814812059123672, 0.03031199625242622, 0.0401857894124283, 0.015240383668682508, 0.011272797071855637, 0.032263195382491235, 0.053168478451909564, 0.19224539789701664, 0.1250212897937144, 0.21003250393175313, 0.1537884429337517, 0.1514332128628608, 0.13578660245383942, 0.28397132672609826, 0.15737751889373028, 0.19914378982878503, 0.23694730243615567, 0.27876658665557064, 0.28801786442918165, 0.2922506840719331, 0.17755534019201033, 0.5355671649017643, 0.4022958742514734, 0.7172552123665811, 15.051756251242855, 92.00571137089884, 75.941495280112, 54.59118327786846, 59.181615460303526, 51.28226003339214, 48.221877774884625, 68.5866589700022, 43.64814704464328, 61.096575413980794, 27.05263218572063, 51.02687058910247, 45.9490329219449, 46.794911661455714, 75.93226986546671, 26.58959834806381, 11.16893925974446, 36.548170658849905, 73.34525492883498, 69.61581830055484, 80.65374451298868, 76.50662252979895, 68.29182224888956, 62.04869547197896, 57.096993384822724, 26.160338078775716, 13.450943827629091, 8.695992731278944, 0.7974279683924491, 11.514777579615194, 23.22520886698077, 30.712572259287683, 13.798082413211947, 9.732794800112325, 3.6551361506985085, 2.461122298432935, 17.462888186977757, 34.050809337246804, 6.7959235656646, 9.316749976527307, 13.002240369396826, 37.20334376058271, 45.84491360572077, 34.85910784813666, 9.182903016767195, 22.477709054946903, 28.907464165841382, 28.249394393736317, 38.27218963253883, 30.226825937148067, 30.247534090472808, 33.16595400533369, 36.23973115797966, 37.82262325286865, 23.79648247072774, 29.74980296627168, 46.59216826961887, 59.799200488675034, 55.22445386455905, 38.41807434635778, 31.040066634455037, 37.98975936828121, 45.10960648136754, 51.81090924047655, 53.30022927253477, 53.58682117154522, 57.3493076908973, 57.81781127375942, 50.9988138752599, 46.062499246289654, 50.090459623644435, 52.119140855727665, 48.67274245908184, 52.80667743375225, 57.012038769260535, 52.8264775583821, 49.357223510742195, 53.234274618087284, 59.4031705394868, 57.58212389484529, 52.43281672077795, 51.88550879878383, 50.69097057465584, 42.99386824330976, 42.442532047148674, 42.682726229390795, 52.19909444932015, 58.94448072679582, 49.24525160943308, 33.74364068431239, 14.750059304698823, 17.96403373441389, 28.17452419188715, 37.476164217918154, 34.049985639510616, 39.79737581745271, 29.534323638485326, 29.941753956579394, 30.851887003068004, 33.11313144622311, 13.031767972054022, 17.13718241260898, 27.589732139341294, 29.316122185799387, 24.450082702021447, 10.029083778781276, 5.522859490686848, 7.1503170651774255, 13.26538630070225, 39.89907503128052, 42.55096204819218, 40.41365469655683, 51.430921785293094, 42.615743913958156, 32.09474098297858, 8.392308123650091, 3.730246842868867, 7.240774766091378, 15.191777021654191, 22.479442742563066, 27.141022797553774, 48.65810809596893, 60.64686390661425, 60.959633704154726, 62.826258290198545, 61.349682038830174, 64.97323036193848, 63.14742195990778, 61.73687881039035, 63.05737610786193, 26.128872825253396, 9.413169680103179, 59.75829801251812, 64.39145657324022, 36.3941470269234, 57.66072427072833, 40.400973673789736, 55.457799588480306, 32.510133712522446, 42.313948908159816, 43.56863275651009, 47.43425407717305, 44.76922319781396, 37.50926509980233, 61.971809171861224, 72.85112257926696, 43.48267009181362, 0.39242716025440927, 0.4791998250349876, 0.292322114109993, 0.4042911042849864, 0.1355427873110579, 0.1896538143797267, 0.0857535763193042, 0.16199422519533865, 0.14600653712066913, 0.22937161217053093, 0.15431335105771019, 0.15307746737474395], [0.025313054211437706, 0.029246879313441537, 0.03883476654488233, 0.06075351499021054, 0.012246109864434168, 0.016070398757414475, 0.06824373282612332, 0.05817499327202959, 0.17303125392044746, 0.06356133448500788, 0.06285996566857062, 0.22870243436867194, 0.04655195708056131, 0.024271159312657775, 0.029401495008759444, 0.09682806674391033, 0.06328943072848263, 0.20906570097131116, 47.671345664608864, 65.7878674230268, 38.53089740199428, 32.17079574061979, 44.590692597050825, 31.501335405534316, 55.91242974804294, 40.028493635116085, 35.88495277589367, 28.512956096280007, 17.351324212166574, 30.627176377081103, 56.996902342765566, 70.89929626834008, 58.3975415075979, 15.112100935751393, 18.83297012698266, 73.18934071448543, 63.22854441981163, 56.91965910696215, 60.98779632199196, 64.54538214591243, 63.24376713845038, 57.07414165619881, 48.839266684747514, 13.747058260825373, 1.1075083070224332, 0.2689066367043603, 4.965801537036896, 7.703878225818758, 8.456746782025984, 4.060699175442419, 0.2078293116703149, 4.084939668255468, 3.9290494784232113, 5.829009798265273, 8.959559336785349, 6.687182226488668, 4.916868007952168, 11.817808132017813, 35.79899403356737, 32.60271537688471, 9.282567501068115, 6.560926523900802, 21.757542279458818, 16.86888837045239, 21.819723613800544, 23.591558241075088, 23.259107951195013, 24.522589675841797, 25.205754772309337, 19.984079868562763, 23.461227686174457, 17.224482605534217, 25.663616964893958, 42.245028941862046, 47.790134645277455, 32.32275424465057, 11.358984958740974, 7.227626000681232, 10.862160882642193, 19.95885902835477, 31.89264282103508, 42.989938028397106, 46.57552957534791, 49.257136391055205, 54.58497416588568, 47.41610134801557, 44.77826033869098, 42.80938348462505, 41.81386240067021, 40.02103328704834, 41.80812005073794, 46.65453003298852, 43.12116484488211, 39.215401987875666, 45.206422344330825, 53.03166066446612, 52.81939768022107, 47.08664186539189, 37.65098033412811, 30.76321594176754, 17.543388951209284, 11.005142061941086, 8.785173700701806, 21.09701906481097, 40.5177544009301, 47.320038580125384, 29.789973920391454, 11.807015730488686, 6.857165002053784, 15.456605649763539, 22.286244438540553, 24.930059217637588, 27.129128210006225, 29.03702397500315, 24.10107216527385, 22.162528960935532, 18.481845432712188, 13.450427055358888, 2.8320718772949713, 11.536580074218012, 16.90596849687638, 17.287546473164713, 13.161267965070664, 2.035400987632813, 1.0315969610406508, 1.7613853105614263, 2.362656833664064, 0.6309402085119679, 6.526488113787867, 9.647069438811272, 10.05895164705092, 3.7155462897592977, 0.10616088691618174, 1.9364227955379796, 4.753102189110172, 12.969809232219575, 21.232125105396396, 39.16775695739254, 44.89803775664299, 54.45545358042563, 51.6977684728561, 53.8618891469894, 50.73766639155727, 55.71490703090545, 56.21982197607718, 61.458555267703154, 36.93992130218014, 4.882467350652141, 21.92677490172848, 57.920593061754786, 67.56865486021965, 40.78404411192864, 18.496089519992953, 44.7970445694462, 34.76789312977945, 17.004325851317375, 36.16231926025883, 31.226626326960904, 42.581905626481586, 39.746467374986224, 38.451053634766616, 45.950339071212284, 58.31661908857284, 6.999086160813609, 0.6484959406718132, 0.08670627560106017, 0.03654612100593025, 0.02233098035738353, 0.07547298281062996, 0.19681512768710815, 0.09002040260501447, 0.17402568201143898, 0.03758831850944027, 0.2186563863388954, 0.058044547650722735, 0.05472447963491563, 0.026791215115677447, 0.026665369852355895, 0.025261318378691233, 0.06327667919498298, 0.020795891459490505, 0.056447261989477186, 0.03179013991968767, 0.06393731128604663, 0.05264160531242529, 0.05114227931405749, 0.06778403410627958, 0.05609674995104152, 0.07368459651667265, 0.04026291914464485, 0.04245565813635627, 0.030398142839511557, 0.06924736163308544, 0.18895753238710666, 52.067710738028254, 79.66397362370645, 39.99442000542918, 40.28602077114967, 40.770213834701046, 36.3168724121586, 45.13023030373358, 37.44057263097456, 44.530770547928356, 28.817743870519823, 28.131670336569513, 30.44942632798226, 58.201764245187086, 71.3474113710465, 62.24197026221984, 17.562112385226836, 21.10799974010837, 72.32650556871968, 68.28101219669466, 63.539862940388346, 66.33596374142554, 66.57340834217688, 70.3556400729764, 61.504105752514256, 53.85042013660554, 20.227506083826867, 3.6805577672296956, 0.2657902523154213, 4.105320793967094, 10.431039448707335, 11.635530687147572, 5.606357926322568, 0.5257989922838827, 3.8298140033598873, 2.119269842101682, 7.254230456967508, 11.241489379636704, 6.931201700241336, 6.617403261123165, 15.44868540379309, 42.64481652167536, 33.3479166799976, 17.747656183858073, 6.1448630690574655, 21.188435785232052, 22.993324225948705, 26.745328211015273, 27.4168772082175, 28.80140719875213, 31.792987162067046, 30.88305219527214, 24.552840955795784, 27.513179240688203, 17.406543339452437, 28.111332847226052, 47.407774156139745, 52.451224403996626, 41.653798318678334, 22.926749837013986, 14.924750885655804, 19.438497789444465, 29.804247425448512, 43.00363102266866, 49.30965300529234, 52.20189109925301, 55.42676971804712, 60.63484576440627, 52.939630093113074, 49.61238937993204, 50.5968140786694, 48.15302841124996, 49.73431625673848, 51.87135688720211, 57.24602776189005, 51.81931095738565, 48.773974910859145, 52.68526438743838, 58.749429102866884, 57.583288838786466, 51.51541356117495, 44.77184726345924, 33.04755333931216, 23.6500858876013, 21.195692170050837, 23.82641407751268, 34.87442470365955, 49.018581759545114, 48.36848420481528, 31.32860795144112, 14.253496066216501, 7.494960042738146, 19.73071828965218, 27.131036443095056, 27.628893083141698, 30.230942464643913, 31.067780140907537, 26.25051533022235, 25.532829453868253, 20.343882806839485, 14.117793825364883, 10.374149391728064, 16.03076513736479, 19.348373489995158, 20.326424337202504, 11.267850648972297, 6.645597748218044, 5.82073800986813, 4.586495103374604, 5.673303959831115, 2.5890364281592833, 6.571210978492615, 10.17382316050991, 9.93532246158969, 3.0724710033785914, 0.602771952267616, 2.475790982284854, 1.805007092414364, 12.395931174678188, 16.356766070089034, 38.405436469662575, 46.37934830880935, 57.014533396690126, 54.91386098246421, 57.81111971024544, 57.400161220181374, 63.908248024602095, 58.392183549942516, 67.46658694359564, 42.71011614030407, 8.545070713566195, 27.621599435806278, 52.68899063910208, 69.99109498916134, 40.918687312833725, 25.937114031084125, 46.249937549714126, 42.61115474085654, 25.726855377997122, 29.818824914193925, 33.92715269519437, 34.17436007530459, 45.016748289908136, 33.518990855063166, 53.375440720588934, 68.48363399505615, 9.237754421849406, 0.47775283816360664, 0.3312823735177517, 0.042641143344583056, 0.09270289011539952, 0.06947655981827168, 0.08021063907372375, 0.07572360847505831, 0.1281741935940039, 0.029249501249362386, 0.09388142445635411, 0.08769960818631996, 0.012090468568907631, 0.0792807768729906, 0.13130255193719942, 0.11650258359769661, 0.1505569308515518, 0.2242941193042263, 0.22951243445277217, 0.1714914325144022, 0.20878529746926602, 0.15858567019383754, 0.16822124831378463, 0.16883778055348705, 0.23120366547617222, 0.16620815310987735, 0.12779208425913127, 0.1601696948731138, 0.1742293388252297, 0.24507417764154174, 0.8429937749620408, 71.59945503357919, 83.35064072762766, 56.80338436557401, 44.21203482535578, 59.62559246247815, 47.55081907395394, 73.5298652033652, 50.17408063334804, 53.40646666865195, 38.81064084268386, 24.691379070281986, 36.65022680836339, 67.36842570766326, 78.41392209452968, 66.11520490338727, 21.972721545926987, 24.417183822201146, 83.5461316570159, 74.88281619164252, 69.97133408823322, 72.2737967583441, 74.70510928861557, 72.64705734868204, 65.84507126961985, 53.490001386211766, 19.339104929277976, 3.082310514103982, 0.2642232041445471, 8.06285697606302, 16.780570322467437, 16.245147182095437, 7.80398593794915, 2.719052948297993, 8.937852940251751, 7.191989306480655, 11.301525177494174, 15.628024993404267, 10.316554288710318, 7.681471195913131, 21.08286911441434, 49.00108406620641, 41.55546449845837, 16.697574930806315, 12.018986498155902, 31.127776715063284, 25.23396641977372, 34.07872092339301, 33.661635691119784, 33.038182796970496, 37.10390775434433, 36.648332303570164, 27.789270954747355, 30.45900867831323, 22.9721434270182, 36.05054739982852, 51.965729113548036, 58.05019993935862, 55.33701804376418, 34.10105489915417, 24.2524972269612, 33.4721302986145, 47.82426318814678, 53.823532289074315, 53.62493484250961, 56.809758217104026, 55.348388994893725, 58.73315518902194, 53.306512909550825, 50.55895928413638, 52.1410825944716, 50.42134684901084, 49.159033990675404, 50.03363624695809, 56.19420497648178, 48.64752946361419, 50.78362480286629, 53.566609198047274, 59.89648311368881, 57.49611416170674, 53.62297365742346, 53.696541632375414, 53.82066503647835, 48.967449741978804, 45.97810160729193, 29.99238391076365, 40.44409621146418, 52.55446118693198, 52.95517052373579, 38.55021115272276, 18.099688906823438, 10.388411129674605, 22.328388344857004, 34.14609547584288, 32.70892139404051, 37.86555359440465, 37.34030508225964, 32.740510202223255, 32.62657319345782, 27.650548488863055, 21.489581638766875, 6.443526552569482, 16.588419291280932, 22.687063601709184, 22.27819181257679, 19.48749407645195, 5.4086650763788535, 5.189661989288946, 4.8017150644333135, 6.190112511957846, 4.482802344906715, 10.689815859640799, 16.62017087782583, 14.875915415825384, 5.61373443372788, 0.6558483622727856, 4.0380509197711945, 8.687081106247442, 24.785510070862312, 26.302767184472856, 41.800326301205544, 51.98465847199964, 61.68462499495476, 59.906010550837365, 60.22276939884309, 61.32610074935421, 65.0179571490134, 64.89674414357832, 68.15500213253883, 44.64038902713407, 7.661645575877159, 29.542564538217363, 63.40728290619389, 80.38448949013987, 47.77855580852878, 30.00170542347816, 52.896382039593114, 47.90196534126036, 22.54840389374764, 51.95327166588076, 45.65224286048643, 53.89570782261511, 53.21268197028868, 51.13877581011865, 61.83496944365963, 77.28744091526156, 14.93550798585338, 0.8095260901797203, 0.9423660426851242, 0.22543606528591728, 0.3854836763874177, 0.21490690688933098, 0.26736894502274455, 0.19486782411413808, 0.3173482760546669, 0.09768261484080747, 0.4374728237669315, 0.2420513785534328, 0.12600143800579733], [0.02892086485160455, 0.02382548957792742, 0.05578789011304898, 0.04472865632945492, 0.10776044019768316, 0.09864630748427684, 0.035216697987409375, 0.1061134890563065, 0.03245852865098465, 0.03241696838109243, 0.030698175429396575, 0.126250684711962, 0.06560517279731651, 0.018432188456157045, 0.11017038426812618, 0.08313870372911615, 0.012546289926244607, 0.30381723277030454, 21.19764551039665, 79.29367050047844, 38.52822626790693, 30.263400077819828, 62.650920498755674, 54.208956149316606, 39.28380420131069, 56.74835351205642, 30.360011977534143, 36.32998097327448, 14.132820425495026, 53.2728668182127, 82.56615100368377, 57.54519870204311, 40.80368341938142, 5.976590446887478, 26.172748458000925, 66.53095260743173, 64.5986440104823, 53.97830117133356, 60.02358359675254, 53.20211118267429, 42.862986595399924, 59.7722851845526, 35.7551105560795, 24.416460144904352, 8.79992965729006, 1.6960714733408344, 0.3731804268975412, 1.4554748804338518, 9.383343977312888, 3.680598216672098, 0.5420442237969368, 0.2750090479610428, 2.4707936375371875, 5.042986917880274, 7.085318488459434, 4.6138374555495485, 2.390936632310191, 24.61224525205551, 36.68165676055416, 26.947398916367565, 8.090568521330434, 13.601294159889223, 21.094730361815422, 19.111466253957442, 22.648136038934034, 25.182257813792077, 28.221659314247873, 29.43739010441688, 28.29399174259555, 20.219029841884492, 18.658089291664865, 23.53988297523991, 28.11525521739837, 44.86773744706185, 47.14134323981501, 27.5161406301683, 9.7404493055036, 8.351423298158954, 11.89659482048404, 16.442204117774963, 31.905561147197602, 46.4881823139806, 45.97575210755872, 55.1528549194336, 54.160338371030754, 48.82497749020977, 44.27694612933744, 46.51144981384278, 43.69938888857442, 42.045956888506495, 40.084187369192804, 40.635488264022335, 41.33874570169757, 38.36425550522343, 45.44932296199184, 53.25428655070644, 52.895523040525376, 52.447341257526034, 41.86592401996736, 28.775154775188817, 14.028562845722323, 11.291787893541398, 7.067607516242612, 17.07012753332815, 35.92943245364774, 42.57433545204901, 29.18911583961979, 13.596268623105942, 6.27647820018953, 8.493591566239635, 15.71973785277336, 25.23363497949416, 27.164113790758197, 24.097844054622037, 26.13548201899375, 24.0027795299407, 14.646801929320059, 13.53709182431621, 10.122087097937062, 2.538360386125503, 12.592216384026313, 11.642942005588163, 10.589839546911179, 6.1558074624307695, 3.5361375683738343, 1.7599757087807504, 7.467158773253042, 6.004074494684897, 4.014028363650845, 0.8701302027029376, 2.8925837528321052, 2.014259289829962, 1.2091106873366142, 1.3982430869533171, 1.766639938277583, 7.150536717907076, 11.173791231647616, 48.05970738011022, 54.31842557845577, 54.20058973373906, 51.679462771261896, 53.85100849213139, 54.42104654927408, 53.13748228934504, 58.330641561938876, 48.5778054114311, 17.15794155674596, 13.16841648470971, 49.45185069114932, 63.5470526449142, 41.60560023400092, 20.915278004061793, 24.43527771580604, 43.247394561767585, 24.893188938017815, 20.51587873889554, 36.355770557157456, 30.21257792749713, 64.8814586670168, 38.67754305562666, 40.934514076479026, 60.46483847402758, 40.21592409380021, 0.3246336802840233, 0.07471733666475742, 0.09421049752422879, 0.08399695203068756, 0.02396621609917812, 0.016120001035291823, 0.021824460258827578, 0.06896371757912059, 0.06261648377403617, 0.0328528149534137, 0.045388748328531944, 0.05155534243151065, 0.0750330031939572, 0.06530693476839412, 0.015963608015989585, 0.07953933154743525, 0.11135844874285883, 0.04446185088806576, 0.07471007415123525, 0.026996118737564936, 0.04191771502636614, 0.06025325574521577, 0.047081726032399365, 0.014028081129635534, 0.045385140054408586, 0.08564701348903679, 0.04914217696134602, 0.14914997973509375, 0.18562278229623072, 0.06976861551764511, 0.1464388405363406, 26.556262123969297, 91.09383875323881, 44.76203349328811, 36.06526805508521, 65.1446653950599, 47.08261359122492, 35.83974353728756, 43.19081829440209, 37.09623952065745, 37.87179408534881, 22.65087777568448, 53.43863010406495, 82.95066879641625, 62.796805212574625, 46.31721404290969, 8.520670629316761, 30.265282815502538, 74.34944445087065, 70.57490056560886, 62.14760588061426, 65.58588104863321, 59.368010413262155, 51.526125554115545, 67.9029506252658, 40.89460788234588, 27.120004776985418, 10.596835094113505, 2.1472351156896163, 0.5699244309817592, 4.165853752243904, 13.2169871945535, 4.965855959923037, 0.8865730849004562, 1.5877975090857477, 1.66659424862554, 4.845252392753478, 9.008903734145626, 8.318950976094893, 6.484980121735604, 32.358024197240034, 38.229792733346265, 32.292559839064076, 11.883895166458624, 9.33570384979248, 24.241991158454653, 22.388469249971454, 27.02091197813711, 28.854639645545717, 34.537673534885535, 33.01491529710832, 33.708825726662916, 23.66475751323085, 20.1417826837109, 25.569040775299076, 30.776195064667736, 47.26831036229288, 57.987665591701386, 39.6264781490449, 18.735954223140595, 11.594335994412823, 19.748698434522076, 28.720602450832246, 42.58255673993019, 51.745319366455085, 54.760704194345784, 58.80351074280278, 58.38764929002332, 54.255683345179406, 47.47706282523371, 52.58329060769851, 49.44772828009821, 48.48048748508577, 47.969712518876605, 52.27726728685441, 48.08471641232891, 45.96758181048978, 51.81476885272611, 59.49000397036153, 58.29389287579445, 53.592689037323005, 50.776293893014234, 42.981579457559896, 33.49411518343034, 19.936552509184807, 16.404510140419006, 29.050071739381362, 48.24962462148359, 49.310602218874045, 32.98799214824554, 20.69718441655559, 9.239541061462896, 13.436170220375063, 21.17062822464974, 31.44144081300305, 30.638621853243922, 26.97897203506962, 30.66306410297271, 24.507376763128466, 21.03373162208065, 11.866549464964098, 13.851012837502266, 10.861326398388034, 16.13572384080579, 14.349065596057525, 9.666809747295996, 7.188467018065914, 8.94289710829335, 8.522176819462931, 14.951996649465254, 10.696410344493005, 4.46794048432381, 0.9486702108575452, 3.011003295260091, 2.817841518309809, 0.14675892739286348, 0.6803287325366851, 1.1652139718494108, 7.196110736939215, 12.389283737828656, 45.20037404952511, 56.75826926385203, 57.517447933073974, 57.632616566073516, 58.30465978191745, 59.21681873260006, 59.228589765487186, 64.516623327809, 52.22284440071353, 17.780339333318896, 17.50583029562427, 50.29429343438918, 60.01015340128253, 52.01526472645422, 25.403314751963464, 26.548458568511474, 44.83880604467085, 40.56054745951007, 23.40657141900832, 31.259811539803785, 30.42976740867861, 52.830572512842, 46.32819667939217, 38.66676438239313, 72.96910747405022, 45.46317285107028, 0.3013409608073773, 0.06982146792354123, 0.10313508476340964, 0.0824390892540255, 0.03935728447451707, 0.07482681062913711, 0.00416656979547453, 0.020353701679156195, 0.03122524200608173, 0.05086323944851757, 0.030573193930209647, 0.012151692400596315, 0.03608204409359925, 0.10072916265456908, 0.12231652444649128, 0.12409801594913007, 0.15665076192348235, 0.19776392758132952, 0.22155275027598106, 0.09424114104120002, 0.20418003652124636, 0.1759537414557511, 0.16023455187678337, 0.1320513875614251, 0.14369557161004315, 0.20076847845508208, 0.17042349062619672, 0.2699541546885045, 0.27877964079380035, 0.18371341539727104, 0.340555775910616, 40.39666298897036, 102.80285112319454, 57.08854459947156, 42.36461416367562, 78.75457209925499, 71.23260359610282, 56.14046458275088, 68.55425234763854, 42.097732174781065, 50.42291579707977, 17.685017893391272, 59.73723488469278, 95.4912942455661, 66.78457306277367, 47.93590168799124, 10.343892228218818, 32.3799188675419, 78.04736091244605, 75.68458787856564, 67.10430898974019, 72.55846669597011, 61.65224582918229, 50.51549550025694, 72.25449869709631, 44.07065299249465, 30.687192563087713, 13.22342380400627, 2.64946642421907, 1.8224346733862355, 9.706516881142894, 18.86059145773611, 8.134263234753764, 2.1806691538903022, 2.6049195758758055, 6.7962564768329745, 8.921035778137947, 13.125685203459955, 9.404499280837275, 10.78101194673969, 37.14338641012869, 45.908193203710745, 39.03999751613986, 11.418055853536053, 19.43502256947179, 29.70900247173925, 26.676572984264745, 35.62224026649229, 33.99401733952184, 38.89807047382478, 40.60688241835564, 40.60585083500032, 28.02722546362108, 24.968606310506022, 29.25000083061957, 43.06762056965982, 51.56411370923443, 58.93263516887542, 50.0490080156634, 25.88984358695246, 22.47456919762396, 34.48782413236557, 47.459973058392926, 50.43510652357533, 58.56925895137172, 55.85378639159664, 60.58050917040918, 58.11541326584355, 54.682896137237556, 47.308593103962565, 55.647881569400916, 52.810211489277506, 50.53830800517913, 49.97544396308161, 54.36952621706071, 46.53541157322545, 48.31036644597208, 53.17646280411751, 61.37919002963651, 58.90329976235667, 57.17698620211694, 55.81337813408145, 57.77076636591266, 50.28638201375162, 31.14586472511292, 27.332312868487453, 37.50681361844463, 51.71783924102784, 50.3781811652645, 37.50739020685996, 27.849498948743268, 11.460780270638006, 12.615869256757922, 25.197864924707723, 33.69935320269677, 35.34654863419072, 33.47884539634951, 36.691117517409786, 33.2505791418014, 24.070477677929787, 21.80644835195234, 17.600228017376317, 6.771229303652241, 20.332647177480883, 15.390414672513163, 18.311514546794278, 11.624365660452074, 4.998938700845165, 6.498110255887432, 15.724373113724495, 10.969440648632666, 7.9468023777008066, 1.6822696332969975, 6.687764698459256, 6.337060188093494, 3.7560249047894634, 1.6718600305818743, 7.346121784179442, 15.572501882430046, 15.384790974278605, 50.928650517617505, 57.6352249422381, 60.18492244905042, 59.346704098486136, 63.461615577820815, 63.019780189760276, 62.45585318534606, 69.1888604625579, 57.387358603938935, 21.430557812413863, 18.440182016741847, 56.32079947379328, 71.63305405647525, 51.54373307381907, 26.375615404498195, 32.959598110568145, 52.23364268579791, 39.568670257445305, 29.452803058008996, 50.85867935611356, 41.793619048210886, 77.9035040640062, 53.42362311578567, 55.35673579862041, 77.76350682781589, 63.21440427534042, 0.8095764068345871, 0.37038956858938743, 0.23259262884816817, 0.18376033062175398, 0.14399646030318353, 0.1859540387146896, 0.06942492549217517, 0.20703457205766634, 0.20189335599782007, 0.17940781740171297, 0.22864084089955977, 0.20077895853788624, 0.16807187649030841], [0.19411319686520487, 0.012719149047869348, 0.04686809092339489, 0.1239627171608229, 0.07597687714282544, 0.01655206504848696, 0.032340141253605965, 0.035584764930629925, 0.03675839630886912, 0.01978624120144354, 0.02997067918430173, 0.1802626336293836, 0.05011757159785879, 0.08400711035656352, 0.11583271631670576, 0.08879706744224795, 0.13562656668645723, 0.2751897527806221, 3.953807724099006, 58.585744673205966, 50.84037365451936, 27.33232463559797, 53.364352180111794, 87.34646904853084, 54.069915971448346, 55.02169478324152, 41.936016774946644, 36.33930444717407, 24.385647966015725, 19.759988977063088, 51.746656894683845, 66.98353921213459, 49.98523419903171, 16.933221124833633, 27.102226634179395, 51.35236847785212, 60.84375904452417, 50.18844043054889, 55.28223429956744, 51.68724475368377, 23.186497034565097, 51.00215965701688, 55.619518910684896, 36.98447158259731, 13.521226817561736, 0.9171540890970539, 1.0295809853461482, 8.713993468592244, 3.1180418354849664, 3.2689126172373375, 1.006740043240209, 1.3540399362964015, 1.3790595098849268, 3.888084734639814, 7.558109221919891, 1.417165213534909, 5.921896917204704, 30.384730754360078, 30.437151270527995, 19.634292702521048, 13.024388032574809, 17.1803500575404, 16.925407763450377, 21.663558367759954, 24.131723526985418, 34.34453210523052, 28.863794457527902, 30.873446310720137, 29.73501366953696, 13.15950191790058, 8.820110251826625, 20.11707567399548, 28.28336015824349, 44.338852897767104, 46.56202093247445, 26.15642551452883, 7.871920899037392, 7.273388783777914, 10.695565073720871, 18.794703483581543, 32.95557768114152, 47.92674295363888, 50.18382380085607, 56.827875644929954, 53.786265850067146, 48.33343782732564, 45.93333559651529, 48.20585489273072, 45.888028298654866, 38.80340799208611, 40.411795493095156, 39.99666360116775, 38.415885663801625, 37.83843432703326, 45.20315500997728, 54.90683209511542, 56.498588746593846, 51.82914041703748, 41.75424629642118, 26.0786311857162, 9.151488754057116, 8.456597731959436, 7.232846185084313, 13.166228782746101, 33.095484702817856, 43.61541094318513, 32.29493091183324, 12.491392839339472, 8.540512919425964, 4.8815431421802895, 12.360858321189882, 22.952976765171176, 27.676361606967067, 24.450047400689897, 24.042546479932724, 23.243028194673602, 17.1846999660615, 6.470608557424238, 12.477114431319698, 9.078675835363327, 2.8062656233387613, 12.476804564076087, 8.754143830268614, 12.598771645176797, 12.304550736181199, 3.6764900242128684, 2.826139537557479, 3.830908834934235, 8.138776902229555, 1.9030206265949436, 0.3455159807157132, 0.30935568074064873, 0.3170964782757144, 1.61006455940585, 0.9164588489840109, 8.158879539658948, 15.423639109057767, 37.10468438363845, 55.25728410290134, 54.88535711842199, 49.1824976090462, 46.849110972496774, 52.53252337055822, 50.93266702467396, 56.61955856507825, 41.55813171017555, 17.78210243871135, 31.001686242318925, 78.85605950509348, 48.0667951030116, 15.666720155746708, 20.122700352822584, 34.837915282095636, 42.999100685119636, 15.411265011756653, 34.544875006521906, 30.923988011575517, 41.62606323918989, 70.48695318160519, 29.741291422997755, 45.584060299781065, 63.51552463346913, 16.248849899538104, 0.9113094511051333, 0.22227503329275117, 0.23279570343513645, 0.03208519102284505, 0.015099606394106823, 0.06724756571554369, 0.033152960541267554, 0.04611736306199624, 0.03360517075165145, 0.10267262812703849, 0.10191588647543423, 0.059629529939904335, 0.10453273557246694, 0.03666091928138368, 0.020672723673464313, 0.13437997309430955, 0.10644850696647361, 0.04909729570030205, 0.06613930461988335, 0.031203297417490717, 0.10172855499530993, 0.01219488635298706, 0.011812935023748828, 0.051745948937511256, 0.14849187956461984, 0.08582978674601163, 0.050178019765524134, 0.06607335211048204, 0.3150596956331884, 0.08596132404261059, 0.410740522727851, 5.012253676691364, 73.16637915949669, 60.724448388622655, 25.725174642378285, 53.59097103918753, 78.99920248216199, 48.611153402636134, 37.171427434490575, 41.88648116204047, 39.99744415283203, 29.64778211808974, 29.586330344600064, 53.59223796475319, 68.99477374169135, 49.05000778936571, 19.15512223397532, 31.143923151877623, 59.51518950923797, 66.62119850035637, 58.477440188007975, 66.66694902604627, 57.409323876903905, 29.87078259068151, 56.56770090903006, 59.03080032717798, 38.95629805903281, 17.52772496592614, 2.1994551006824743, 0.9827258834435094, 9.01484710554923, 3.938118978854149, 3.782422946345422, 1.6580877308883977, 1.6704151274696475, 1.478254167783645, 6.4487060423820255, 12.628361025164205, 5.3680425593929915, 12.129645386049825, 30.56027839260717, 29.45649204715606, 24.269639945799305, 11.182387105880245, 13.355857729911806, 22.18196430513936, 24.667417310899307, 29.10388077459028, 39.541821633615804, 33.29223079066123, 36.016038387052475, 34.21235607516381, 18.040447388925863, 12.384990703675056, 21.901338331161007, 33.34444930476527, 49.312065262948316, 57.48308012562414, 37.82613377417288, 14.937128905327091, 12.043373834702278, 18.175504399884133, 29.05201331261666, 43.619078359296246, 55.21665227028632, 55.28685485163043, 61.34100183363884, 58.75577157543552, 52.879205980608546, 49.469917128163004, 51.99410353937457, 51.80746147709509, 47.673377452358125, 47.336390941373764, 49.776850438887074, 48.4664846235706, 47.498125953059045, 53.59923939551077, 60.472961702654445, 59.049596325043716, 55.43720714507565, 54.15139928940804, 45.75622097138436, 25.393104822404926, 14.44199929314275, 14.877539277076723, 25.84718977251361, 43.287583166553134, 45.884929626218735, 36.31939057380923, 16.566820759927076, 9.13000887440097, 7.734213346435179, 16.78467312166768, 27.860813025505315, 33.57841084080358, 25.933195583281982, 30.75032703338131, 27.036626954232496, 21.331566995190038, 8.313305704824387, 12.417134527237186, 13.786912483553733, 10.698418598021231, 13.966867885281964, 13.76752224660689, 7.179787303170851, 14.86153502618113, 7.158129445968136, 7.935319639021351, 12.88200697591228, 16.130753217204926, 5.006081827225224, 1.0082584295061328, 0.05184713383055022, 0.32016652966699294, 0.9500478208065034, 2.745381122635257, 7.088101410096692, 14.762248070009294, 39.86075739706717, 56.59946818505564, 59.17697921875985, 49.38932026586225, 52.327320652623335, 58.55366360756659, 56.517502415564756, 62.35571115247665, 44.93293116169591, 18.158506808742402, 31.962737537199455, 72.38532543182373, 51.174857693333784, 22.57081239454208, 23.968794153582667, 32.61530814632293, 49.95341985456405, 31.83527815726496, 28.64055472035562, 32.234975522564305, 35.11312054049584, 68.13954799405991, 34.57669327335973, 48.426880451940725, 74.00266770393618, 19.761761888380974, 0.4734044311748397, 0.4388432324894013, 0.10243732422109574, 0.19663964758717245, 0.0034131998883470175, 0.09684533436572361, 0.048015211829014366, 0.14405108237218472, 0.00918586535619632, 0.03294055117294192, 0.06454261650721874, 0.10972354816453112, 0.04028759866712555, 0.22735586630240565, 0.051018824245059685, 0.16773156491258454, 0.1849715309517999, 0.17389048281456196, 0.14993244661919533, 0.1936974869139733, 0.12544999259614176, 0.2283697530266739, 0.18003625464775871, 0.17072381241427315, 0.25176793216697635, 0.17185382274610383, 0.14390138879178033, 0.13572085678817766, 0.41431564056584913, 0.20350865238616545, 0.7430985449783264, 8.752356210062581, 92.93896090599799, 69.21212796242007, 40.45597314834595, 67.60222250415434, 105.49876674529045, 75.9260097626717, 68.86561793665733, 51.422849547478464, 50.79141855239869, 30.5760149417385, 26.07613459710152, 62.35749975327523, 75.30990739022532, 55.12284094287504, 23.16128796146762, 34.75179572259226, 63.27040395429058, 71.50186646369197, 62.79025485438686, 68.93371812758907, 61.56317664730934, 29.13200612991087, 59.83245434299592, 65.56295479497602, 43.26254275537307, 19.127298901157996, 3.655528632863876, 1.6661670779989612, 13.974304699128675, 8.421136563824069, 6.499703718769935, 2.113212476814947, 3.5437712361735687, 4.116483859477505, 8.25080861968379, 15.769986356458357, 6.710431095092528, 12.574794196313428, 40.543920532349624, 37.28239520903557, 28.54889677416894, 17.13767270888052, 24.203720592683364, 26.889500810254006, 32.307943374879905, 36.31833937860305, 46.01258708584694, 40.610012469753144, 44.63070861754879, 41.78554681039626, 19.652841591065933, 13.541593724681487, 24.144235887835105, 40.02481445189446, 48.1289372136516, 61.251481579196074, 51.70511114981867, 23.731261299502467, 21.767830656420802, 35.509444667447, 47.61291803852205, 49.51968416090935, 62.32545398896741, 57.36641314721877, 62.5576896821299, 55.6881643110706, 53.10369891505088, 48.010732666138686, 56.585022095711004, 56.662877221261304, 49.9993194303205, 52.31904445155975, 53.34030412858533, 50.83092858714443, 47.87833306097215, 53.73150956246161, 63.01651285540674, 62.06311802710257, 59.293473612877634, 58.91669465649513, 55.712369257403964, 41.62766356622019, 26.364932829333892, 26.673301727541034, 35.74431227099511, 48.16394436743952, 48.56091960783928, 39.46245247317899, 21.633603226753976, 12.725515192554845, 9.472121923200547, 19.751797106958207, 32.180187855997396, 37.40972318956929, 32.99610753213206, 35.386937279855054, 31.401381646433187, 26.873595599205267, 12.016434015766269, 26.210083538486113, 15.37416821525943, 9.899084664160206, 19.68236134898278, 16.229845035460688, 21.60171239606796, 18.518784353809973, 4.0630959887658396, 4.362975407031275, 10.174406613073042, 16.246974026003194, 4.473641649369271, 2.9186809976254744, 1.6246619051502598, 0.8338240702306071, 3.872164079258519, 6.411398908784313, 14.579900022475952, 19.49103205434738, 44.88123432282479, 58.68731052644792, 63.77730754113967, 54.06392258982505, 56.36532621998941, 58.56830581541985, 62.838417637732725, 65.33537495520808, 50.055021009137555, 22.40227403179292, 39.753013810803814, 84.81228059337985, 58.18378017794702, 18.63872847249431, 30.737730341572917, 39.21479402049896, 56.214585611897135, 24.45860601240589, 45.70196282479071, 47.601225453038374, 56.348138393894324, 81.8758216980965, 45.51956476703767, 59.50912552495157, 84.37751723874001, 29.414810980519942, 0.7700386703495057, 0.6915172934532167, 0.307794516125033, 0.33854948356747633, 0.19431858503770447, 0.16538873014430847, 0.13021781740169372, 0.26393739206175654, 0.08977961350953387, 0.23859930975783258, 0.18110529970257513, 0.2507061955909575, 0.195949126575743], [0.11942977491285532, 0.04735946354846801, 0.025176320923492316, 0.17292769415484321, 0.0533585180528462, 0.03599197513634159, 0.011735805291532269, 0.04052172279766491, 0.07568185668318503, 0.0515732305845426, 0.03925282072516219, 0.01728799400640832, 0.058986582988572706, 0.039406804397942564, 0.06702862544766358, 0.010090805759142724, 0.08359522318407413, 0.05966868086327469, 0.4525078815077582, 40.7966584544028, 53.14207930718699, 72.21861685475996, 91.6358789320915, 61.264707811417125, 47.36005460062335, 50.55565664845128, 46.08992053616432, 34.00780054830736, 37.036431220269975, 14.096412985555588, 56.8366107633037, 53.06433400800152, 74.59665575335103, 41.021790735183224, 15.435389549501481, 34.71830652606103, 57.72105032397855, 70.0567005526635, 47.55002283280896, 54.19655361483174, 35.89217385938091, 36.688513063615375, 56.91758025077082, 35.80346161319364, 15.477734477289262, 2.8215670345291017, 2.6791940677550534, 0.9787265980435956, 1.498601953348806, 1.4059094820291766, 1.5382633670683832, 0.5997694391877421, 1.3265033042238605, 8.049595442510421, 3.931697813733932, 2.777054261776709, 16.188853325382357, 29.097983491036203, 21.376990002970544, 17.876468781502016, 14.528297320488962, 14.882348102907981, 18.035632679539344, 18.143078165669596, 30.30293953034186, 33.602145102716264, 30.292776669225386, 24.383298466282508, 20.582986570173695, 9.668459103953454, 8.636674727163008, 17.741913833925803, 24.32426287281898, 46.58946183419997, 48.98727732319986, 27.240172470769576, 9.067881472649114, 8.200275253865028, 10.370987961369178, 14.908986879933266, 35.89158158148489, 46.017337076125614, 51.701679075917895, 54.48271013075306, 57.98846183284637, 49.687914617599986, 46.08626488716372, 47.01292484037338, 44.30213559058405, 39.91585885324786, 41.66600081228441, 38.551466311177904, 39.52030743322065, 39.92217386922529, 43.565455636670514, 53.47615149713332, 54.0845307227104, 50.812246338013686, 40.00141751381659, 19.7661647488994, 10.67878713530879, 8.572297846117328, 7.620971087486514, 14.480540502455927, 35.57572880098897, 43.97388812034361, 28.14827569069401, 12.011701676153368, 15.120506575030667, 19.126763497629476, 8.139534409969084, 22.315340580478793, 24.998708540393462, 22.796750722392915, 18.796080235512026, 21.714792366950743, 13.572287251872401, 6.015215006566817, 9.571641279805092, 13.765067823471563, 4.134896935955171, 9.380304140429343, 7.524418513621054, 7.909105948863491, 22.18100332444714, 17.544801004471317, 13.415330667649547, 4.296647637121139, 0.8725719394222383, 1.876760113143152, 3.0436057909842464, 0.4708334094574375, 0.23494842582412306, 0.3601442151252301, 1.1772595706485933, 2.8017330794565143, 17.029931083802257, 41.52095156331217, 56.70850223110568, 55.868401142858694, 47.35709321114325, 48.1649955626457, 51.23535633087159, 51.24551919198806, 57.60362632812993, 45.53105338927239, 39.27959549811579, 62.73144283602315, 63.94902106254332, 44.54578145857781, 25.518163711793964, 21.315193060905706, 40.0048456653472, 35.48859726998114, 14.318542691969103, 38.93595664731918, 23.028776568751184, 58.714002255470525, 49.29961173765121, 34.62994337081909, 57.926853164549804, 53.82352444433398, 1.7426943586718653, 0.37028372588176883, 0.1645222387366718, 0.1008455697146635, 0.02609192814317442, 0.09758811023446823, 0.08157796812273803, 0.12095364636831707, 0.025124698088714675, 0.08148216116692751, 0.022099121931880232, 0.03005893634361846, 0.06232583001556416, 0.09960531166964963, 0.08487384691233597, 0.030532271428514394, 0.10620173472430437, 0.07914002353866255, 0.01024215696229329, 0.05289731780067087, 0.021476118164437435, 0.08369977886397993, 0.14862858029382844, 0.06373995554543312, 0.023918350925669078, 0.042563940834013686, 0.1198140063112782, 0.09313617412361408, 0.043265271346054734, 0.05536825779164511, 0.07975967375621681, 0.07779655046761036, 0.11537031330648931, 53.790564767776004, 65.36529871725267, 70.3001699139995, 93.5753183980142, 65.94264415002638, 54.017768060007405, 33.19955695059992, 42.24808446822628, 39.532674666373964, 35.008499160889656, 22.407067168143488, 65.70002986538795, 62.30037043171545, 66.7629764926049, 45.62959901748165, 19.01487788846416, 35.880026278957246, 64.31328373570597, 74.94216165234967, 57.6182371570218, 60.51307186003655, 36.807376569317235, 41.039131533715036, 61.17459527907833, 38.36012132706181, 17.333477427882535, 3.7989265639935774, 4.30117012992982, 1.4250915882087525, 2.285837704135526, 2.3650431056176466, 1.9737790813369138, 1.5047587262045954, 4.249558602609943, 11.447582475600704, 12.29894959157513, 7.182707017467869, 14.893184631101548, 27.173956978705625, 23.315323360504646, 20.56278440260118, 12.260637840917035, 15.126037116973633, 23.684257576542517, 23.00102383859696, 31.82076538762739, 38.367711113345244, 33.852945373904326, 32.97160056329543, 26.011599840656405, 13.558616811229339, 6.779207404582732, 20.707260985528272, 30.992374535529848, 48.70104628224527, 58.13040456464214, 35.888851611844956, 15.53309775167896, 11.56364050603682, 16.602226034287487, 30.380300437250447, 45.888616654180716, 55.73680562357749, 59.09814350066647, 59.5567274093628, 63.105660484683135, 53.63029672253517, 49.40987348556519, 53.85988481583134, 51.24717835457095, 48.416721513194425, 48.27392370470109, 46.24514049099338, 50.4719336571232, 43.341919760550226, 51.34689284909157, 60.54078732767413, 59.126027630221465, 57.74442765020556, 53.35280079995432, 40.38759446913197, 20.789503282116307, 13.951223511849681, 13.504493005814092, 27.386665151965236, 43.41160851140177, 48.10514411618633, 34.76837950368082, 13.374202655207727, 19.181433493091216, 20.505596245488814, 15.711195911130599, 27.08467402765828, 30.807693658336518, 26.990546949448127, 24.71239120729508, 29.37285730915685, 19.41427323126024, 7.83540363273313, 7.243264490558255, 14.428315124204083, 8.833945432016927, 10.937567468612425, 10.535684362534555, 7.880923719175401, 18.90300992996462, 19.553554634894095, 16.047083177874168, 7.937452427802548, 4.171746132835265, 6.6311614647988355, 8.932293961125037, 1.0884732897243192, 0.41612354678011715, 0.0952272953826093, 0.8221542222365257, 2.3974173684274, 17.962498126491425, 42.44489331399241, 58.683105745623195, 57.55349059258738, 50.941378608826675, 52.360927520259736, 57.75590058295958, 59.95871543884278, 61.61301036034862, 48.168439403657, 40.66996982020717, 58.549196027940326, 63.658546017062285, 52.035315882775095, 27.413288239509832, 24.967921856910955, 37.54635503215175, 49.75283768869216, 23.298955309775568, 30.253705939938946, 27.160975894620343, 47.57771868859568, 61.06409426658385, 36.526460339946134, 66.18519567674207, 62.046259680101954, 3.0692853033542637, 0.3397609443674165, 0.324171943770301, 0.18608289470355358, 0.0896583800955165, 0.06426041652899116, 0.03919089400780298, 0.12325386366536542, 0.04880118356536954, 0.11129931441598362, 0.03318382239329719, 0.014955196905160143, 0.00624877187581132, 0.06871582684858192, 0.20623284572314834, 0.13682170981361022, 0.268803705130854, 0.2533926974020658, 0.17197212204337123, 0.2082547815817018, 0.12544787819347075, 0.18415776171511222, 0.3544410276076486, 0.13385743984291631, 0.10434641532840268, 0.08961360991722153, 0.17456402731758935, 0.31181301501008774, 0.1328016940744654, 0.07757473737001419, 0.1975263024289762, 0.21450877099508242, 0.6915322474894986, 72.03172376078945, 77.9352125044792, 82.44196876402825, 102.28146614566927, 71.33176111405896, 64.10313883135396, 71.05120182037354, 56.75771620965774, 51.137022510651626, 47.07427463223858, 17.43645925675669, 65.71017703702374, 61.1975960577688, 80.42274828880065, 49.784581430496715, 23.04575650922714, 43.6571135828572, 70.70291103855257, 81.53907052932247, 57.72791839415028, 62.35167503356934, 42.09009139768539, 46.86757356889787, 65.64750932878064, 42.39474188896918, 23.678683888527658, 6.326837020535623, 4.497993194287823, 6.597956640105094, 4.782678821394521, 3.1605154660440262, 3.3861554486136285, 1.9335970955510295, 3.5397922367818895, 14.084473290751058, 10.749967367418352, 5.054895724019697, 25.08160391161519, 39.681642363148356, 29.30571221536206, 27.91121352103449, 19.569516720310336, 21.6226755034539, 26.816276042692124, 27.53491113262792, 39.25851275843959, 46.35847345475228, 42.59593202221779, 38.44085154994842, 30.059030863546557, 15.668361667663822, 12.870351652945242, 25.502638970651937, 35.71505531187981, 48.43657655100669, 66.30122723117952, 48.4752550432759, 26.390234078130415, 22.65967957435116, 30.246745694068174, 42.538014304253366, 55.009476600154755, 59.01759762917796, 61.847368055774325, 58.46279013541437, 62.309862567532456, 52.999407014539166, 48.2510405971158, 55.77958691504694, 56.474736813575994, 47.48172652336859, 52.38685438709875, 51.59443363066643, 52.244068345715924, 45.456532278368556, 49.10032787630635, 62.02962883057133, 60.592535157357496, 59.60987160282751, 63.22964268345987, 54.44290984061457, 34.45100484355804, 24.922724385415357, 26.121681159542455, 42.505211522502286, 49.424350953871205, 48.359384306015514, 37.784250705472886, 17.898198712256647, 21.845230787031113, 26.603122680417954, 12.317380809014844, 31.133448462332453, 31.465082899216686, 32.07815327951985, 33.092703742365686, 36.14900281352382, 20.58879756158398, 12.949736502862747, 17.9721648077811, 26.342226228406354, 8.042520957608378, 15.746599224305923, 14.08536857174289, 16.33480668067932, 33.24467597469207, 23.797255177651685, 17.27318471477878, 5.06386177193734, 2.256188508002989, 3.8074883626353357, 8.179862749192024, 1.8559472815644358, 1.2159939566927573, 0.7802909492484985, 2.9612355270693382, 5.516917099875789, 19.311087439137122, 49.5725812450532, 62.3261207918967, 64.52305209252143, 52.67822373297907, 57.068465986559474, 56.82108994453185, 59.9185739024993, 65.29536677945045, 55.25470710569813, 46.99776880202755, 72.11445439246394, 70.78490426463466, 55.61051314876926, 30.589415719432218, 32.7024200654799, 42.92386570284444, 50.63038172260408, 19.751681397038123, 53.3277407769234, 34.44182257498465, 69.8013307202247, 66.0842966264294, 47.84262380292339, 73.49228889711442, 75.12947836229878, 4.82282575099699, 1.1967118300737873, 0.6975025239010012, 0.4129534749494445, 0.18863415135250938, 0.21012719239919417, 0.22810297056792245, 0.17945948237132642, 0.12827299595359834, 0.24652695613763026, 0.13495907427803164, 0.12326113383976683, 0.12129806417731509, 0.23698344646442324], [0.029092604527249936, 0.048339807112971624, 0.06559227953755087, 0.029580885987548582, 0.04606338450685144, 0.13099069286498333, 0.05345055968650887, 0.14614336042394563, 0.0064526915535210606, 0.01677089231839824, 0.01665354680059658, 0.014417661736989695, 0.08698464897010597, 0.06260358668383091, 0.1834872968855404, 0.007778154855083315, 0.17558425724987062, 0.11661925112768529, 0.5223713923365839, 13.418959840651482, 61.08460041784472, 60.09795957996, 108.39809648452267, 47.05836157644949, 35.023525761019805, 51.19550897229103, 51.73438379841467, 37.178821102265395, 52.22688836436118, 19.634288780150875, 18.89908559860722, 31.073885310080748, 65.83783057428175, 56.469939754855254, 23.51891398429871, 28.25606438421434, 56.698335447619044, 57.46726512908936, 57.199606510900686, 57.880624109698886, 33.3119995363297, 49.37048112192462, 63.611446196033114, 42.338734365278675, 21.466472994896677, 7.102317060193709, 1.1877805931914238, 0.08801876807645445, 0.5969534838391889, 0.2998835244967092, 0.7679647171208936, 2.342326698764678, 3.813224829012348, 5.0666373391305255, 4.478253866395643, 10.581947738124478, 20.72138740170387, 17.367127441590835, 19.06596479877349, 16.946419900463475, 8.201036683974728, 14.228867503904528, 15.384928257234636, 22.15156005274865, 30.694048866148922, 27.250792288011123, 28.471724141028623, 25.781566558345673, 10.896112918853762, 7.184277926721881, 8.86598825454712, 11.787909865379335, 21.59300865665559, 40.79746254028813, 47.23288351489652, 30.67307006928229, 11.344526121693274, 5.8708423664492955, 10.064114466790231, 15.716025329405262, 31.08127505548539, 46.93967457740538, 50.64762053951141, 54.2653755218752, 56.41650138362762, 49.23242153659944, 45.727858312668346, 47.551909492861846, 44.44052073263353, 41.40069169382895, 38.74336042711812, 41.39488658597393, 40.835929224568034, 39.62099075317383, 46.64894457786314, 55.36594552378501, 56.468743431952696, 49.25404556335942, 25.383226333125947, 12.787267027362702, 9.232086596950408, 6.856957116434652, 7.395512759685517, 22.90870105066607, 45.95277486308929, 42.63990963658979, 33.89069034207252, 12.848374612869756, 3.8701867143954005, 8.295489318909185, 8.687288011274031, 16.890122121380223, 26.90135617409983, 20.95657467842102, 20.459680980251683, 23.325119480010002, 11.00418500361904, 5.20422084677604, 5.295472827649886, 12.32522947172965, 7.576780194236387, 3.8906158891416367, 9.582348369782972, 5.773378331815043, 17.36179497934157, 22.673156838263235, 20.63069239739449, 19.153608199088804, 11.469137860882668, 2.528044797720448, 2.229545318311261, 5.183815206250837, 0.32409294478354916, 0.5721345639997913, 0.9566314578537018, 2.5376352379398965, 15.566639900207521, 42.6535673295298, 55.15319616563859, 47.44041219834359, 52.82993708887408, 59.005885431843424, 51.042556147421564, 40.87008914639873, 61.99839499688918, 48.19771597462316, 60.58176432886432, 63.09639584633612, 57.47544719326881, 35.975390864956765, 29.96792793273926, 24.56990130486027, 43.28525720104095, 18.412741115016324, 25.33020961669184, 40.51800543262113, 26.93488459433279, 61.78604572050033, 34.776216399285104, 43.74667306100169, 60.611307621002204, 25.66513688333573, 0.3420944481847748, 0.23420256262104358, 0.1956577067293467, 0.13582990174331974, 0.04370302164686784, 0.019525844085540985, 0.03985495051188816, 0.13225490647938945, 0.0628539135739688, 0.09013293326021203, 0.032049269160075534, 0.06327722694784885, 0.04238626589217494, 0.04095778004416535, 0.05113923411455847, 0.045668634721228195, 0.046886672385998314, 0.01658793520032158, 0.049869255688522136, 0.08168734249568756, 0.10804108884786406, 0.05733512725020128, 0.05107624636542413, 0.00781590671038195, 0.01396924461944089, 0.03630294937700514, 0.054104844739119855, 0.03320448761505466, 0.12028842158014737, 0.10402796023915853, 0.16209654389850556, 0.07749326391926697, 0.4341601982953087, 22.286220904319517, 75.45381130710726, 65.41103747583205, 109.66124873007499, 50.892513721219956, 38.434583602413056, 41.83612577376827, 40.961613731999556, 45.05886670081846, 46.938839112558675, 26.997377757103216, 30.581019886078376, 34.42126543291154, 64.15496118607061, 57.83502655644571, 26.328286124813943, 28.695140384858657, 60.45653089400261, 66.23890076914142, 55.86409830277967, 65.27496653218424, 38.35912896740822, 54.00225116360573, 70.34934074647965, 46.256519286863266, 20.327673612102387, 7.818977727044014, 0.9398905368101214, 0.2511259504864293, 1.8310865639678895, 0.8183399011050502, 2.498785387123785, 6.854177136575022, 7.338722232849368, 14.995561434376626, 9.728860662829492, 10.835815302787289, 16.293873806153577, 22.44294116573949, 22.456853812740697, 18.612476048931, 8.23118402111915, 15.607295267043577, 18.79517024563205, 25.544059199671594, 37.950978894387525, 33.929290386938284, 34.73893427079724, 32.610089432808664, 14.775061472769707, 12.141434069602722, 11.88682713816243, 13.706507817391428, 27.573107173365933, 47.16224555046328, 57.50328033201156, 37.939784449915734, 16.231564994781248, 12.036580289563826, 16.193815123650335, 29.232426651062507, 45.41289983257171, 54.49277493261523, 59.401240733362016, 61.66938266446514, 61.42666639820222, 53.594865952768636, 50.2496607841984, 53.31358102060134, 51.10009339547927, 49.895247182538434, 45.61143452121366, 45.56828452694801, 48.98152320615707, 44.37538193118188, 52.19238327395532, 59.47051371297529, 62.39575462956583, 56.09742833722023, 50.477636783353745, 29.879890334221628, 16.434802605259804, 12.624551423134344, 15.416984808060432, 33.83179595393519, 49.01474960388676, 46.32448219483899, 36.69911130782097, 16.5335355266448, 7.758331020032206, 13.46265112200091, 13.219844641224032, 24.060760005827873, 32.14279197877453, 29.600139048791704, 24.887148487952448, 25.419202312346428, 13.35724134599009, 9.235732440025576, 5.357166807497702, 13.778645107823035, 12.71712818453389, 8.380344894624526, 11.613616404994843, 8.446670213053304, 12.35095335591224, 17.931187806590913, 19.94411680006212, 22.500664726380382, 17.597264666711133, 7.020848941418433, 9.583013211527179, 10.575921996947258, 1.099384833247431, 1.0586022345289108, 1.3466993430929801, 1.7861567942365524, 15.152834749990895, 46.827788968240064, 57.96508842898954, 52.64224775375859, 54.48191388960808, 57.06494762051491, 58.39916144647906, 47.50424485052786, 65.65889596939087, 51.22696245870283, 65.12421023461127, 65.16791720544138, 61.69761588496547, 42.767355288228686, 34.134422502210064, 26.37723534337936, 44.46230557657058, 34.56608326204362, 22.578298238015947, 37.30555288253292, 27.594356613774455, 60.00018665867468, 45.20998385644729, 43.72512748164516, 73.35093452084449, 29.517747702137118, 0.17704022267172415, 0.2831183031441704, 0.12351971915772847, 0.04671115398166641, 0.058387433283872185, 0.03257379424007189, 0.03898447927748484, 0.10454559052783637, 0.022632602579711426, 0.1193507529434658, 0.06512732545454657, 0.04605291974580577, 0.04277508232682463, 0.07531143018915769, 0.20024116481504134, 0.19172082685174482, 0.17348215795092045, 0.20858066006293222, 0.13760969253076663, 0.23992896260273075, 0.234854809879776, 0.18369711304624237, 0.10003316411448103, 0.2092975344989569, 0.09114823724714019, 0.15306409147958602, 0.23920401359998414, 0.18675096933880161, 0.28421534105174007, 0.1629501803507728, 0.2009153834754421, 0.18746140863626234, 0.4736808050544032, 38.48941441505186, 88.88627390707694, 78.16419263039866, 116.30752455803656, 60.250998696973255, 46.7190844012845, 71.65289340480682, 68.21209615276706, 53.78504599294355, 65.96912799342986, 24.211514342215754, 24.217590093612674, 36.45644211000012, 76.28368285394485, 65.05162285220239, 32.864302166046635, 35.73461617192915, 68.65419433962914, 71.2087869644165, 66.92150300548923, 68.19919939964049, 36.58018504419635, 58.711095779172844, 76.42321725045481, 49.94042504218317, 26.67554924564977, 13.074737537291742, 3.3159482094549366, 0.8181152841256512, 3.430650080403974, 2.8816011163496205, 2.3502167915144274, 5.528326294114513, 8.314688340310129, 11.399982552374563, 5.246680013595089, 17.40786321701542, 32.52278335632817, 27.44493784443025, 26.930742571430823, 24.996007988529822, 14.190505743026735, 22.51538538163708, 22.78045523551203, 28.997166810497163, 43.54708325478339, 39.05281582186299, 42.39078029509514, 41.06083400787846, 17.249709329297467, 13.747110232230156, 13.551005451909958, 17.707677425876742, 31.582095046197217, 46.96758224118141, 58.910626749838556, 52.03784188916607, 31.70549673418845, 20.514111711132912, 31.477524657403272, 39.46923032883675, 53.85284808374221, 55.08706500453334, 59.384288249477265, 56.891916182733354, 59.10591371597783, 53.68544132478776, 49.793320471240634, 56.79908937023532, 54.607774903697354, 53.3833089951546, 47.69932785341817, 51.12352171251851, 53.73694204515027, 47.515345158115515, 54.38632965087891, 59.45916629606678, 64.81065204066616, 59.407712644146336, 56.772515312317886, 41.40058186746413, 28.798279108539706, 23.18922112064977, 28.09384103744261, 43.99877555908696, 53.02824428004604, 43.479575341747655, 43.04045423384636, 18.831516888833818, 9.797580588248469, 11.877901784835323, 17.20955406465838, 25.95091881290559, 37.61061130031463, 34.13607382005261, 36.28306158127324, 31.414662791836648, 18.10533908105666, 13.824092630417118, 12.470584665575336, 23.509339478708085, 16.60567968122421, 10.99768465565097, 16.431365628396314, 13.32392865611661, 29.196217290816772, 28.261781238740493, 29.417027119667303, 25.582916159783643, 18.203435597881196, 4.570059391760058, 6.809480747868938, 7.475432032539, 0.952487535053684, 0.9811946269004577, 3.1595591431663883, 5.485394971985971, 18.24512843162783, 48.34184738897508, 62.79865657129596, 53.32689354496618, 59.06597222051313, 62.482423320893325, 58.350198499618045, 46.55227384259624, 71.11445396177231, 54.65352542938725, 71.12709968320786, 72.7914947079074, 66.0034958008797, 42.60856989891299, 41.556825560908166, 30.74562999509996, 52.10984483841927, 31.423215519997385, 35.53279845945297, 55.36504337864538, 39.62024942521126, 72.80377172654676, 50.50141026896816, 56.1405744091157, 82.41832471662953, 39.67439382306991, 0.6039215744503084, 0.41427791839645756, 0.28624434024095535, 0.28782879392946925, 0.1229521322755083, 0.13452272591811998, 0.1053005931598525, 0.20076595036493194, 0.15031293184766847, 0.3056432493031025, 0.14379946845433406, 0.16878064571609422, 0.14870223198686877, 0.23708882951928725], [0.050584808622877446, 0.03808577004219255, 0.060047419411280466, 0.06566535666464798, 0.10128526587880428, 0.05197778246515701, 0.023024385689847895, 0.1919622364784441, 0.1673775863262915, 0.07895074619521057, 0.09720488241122616, 0.07535079944758646, 0.11004786382639602, 0.04543529966125085, 0.03562081319790694, 0.06307108800918346, 0.15968106867324922, 0.26368583943093976, 0.1005512846994304, 2.348508354156248, 49.25825034418414, 56.4269466553965, 54.21608309591971, 48.05114092365388, 45.26264952075097, 36.87946188834406, 54.879461796053, 34.319385790055804, 48.031717346560576, 31.403897846898726, 18.76878446148288, 60.136096785145426, 63.91728124310894, 65.2329893266001, 46.86358059606245, 24.35729511322514, 39.37054741767145, 55.2780608977041, 63.47678338327716, 57.24255254191738, 14.864171839529469, 35.09175931253741, 56.03432132351784, 38.82670687090966, 13.842908240133717, 5.0757578303737025, 2.3854830668818567, 1.248457208275795, 0.806563352384875, 0.6250449474300108, 0.32693258757072113, 3.4479246889391257, 6.479959978211311, 9.832859366170823, 16.69293280570738, 15.86460961449531, 10.62655097053897, 11.086322376804969, 18.562901212323098, 18.237289574838456, 7.731015634152198, 11.037961513765397, 18.131332628188595, 27.421207504887736, 26.510238993552427, 32.68346717280726, 31.350828178467292, 17.518830991560414, 8.20364506013932, 4.397758985719373, 1.4163791460375634, 5.15302263921307, 12.779338936651907, 34.74535126839915, 45.11308954608056, 36.337978686055834, 18.36701020117729, 7.223884549833114, 8.423692968583877, 12.68872336033852, 29.805769305075373, 43.70806909376576, 51.92340281701858, 53.956406501031694, 56.87698764185752, 48.03780486506801, 47.30785962074034, 45.989382343907515, 46.93794873452956, 40.03058033604776, 42.9230773064398, 42.29214445237191, 43.03334689909413, 40.009878066278276, 45.80661950572845, 55.879936833535474, 55.721029850744436, 39.18953003421907, 20.148201642497895, 12.908624179901617, 9.536813574452555, 6.084689497947694, 8.85965362671883, 28.69576208053097, 49.87417228760258, 42.831003589014855, 30.14189681699199, 13.79161540539034, 7.726469116826212, 11.14033047230013, 16.5509488890248, 8.741868772814351, 23.239856958389286, 27.655888795852665, 18.76474638139048, 17.515957855409194, 14.194578143858141, 3.515370579496507, 2.582976611391191, 7.95377831305227, 12.826631934412065, 5.04150475225141, 8.567700828275374, 3.898180180018948, 11.04008351602862, 26.03246096641787, 24.829936796619048, 20.30259201603551, 14.651856883879631, 15.93835605729011, 4.921500327125673, 3.911310559318912, 3.4382114295036565, 0.25532238095277743, 0.17971072856697345, 0.7115613404781588, 12.121875170738468, 45.97098250542918, 44.70814012712048, 41.35377622419789, 50.887289124150435, 62.84652125450873, 39.504633642012074, 48.66543116108064, 58.82241264466317, 60.710786773312485, 62.241581947572776, 58.8883476872598, 60.27630975169521, 46.06369556919221, 22.195947554803666, 39.36186721248012, 44.42852220227642, 15.671285794627284, 38.96264445397162, 24.981575627480787, 42.216113228951734, 57.07364351518693, 31.337070465087894, 52.96406253691643, 60.73539572377359, 3.6930909656709243, 0.16219507812732653, 0.19010542321109003, 0.15881103793940238, 0.1489528346686594, 0.027318015476808916, 0.05843177062248992, 0.09363329623855891, 0.058725362328151544, 0.0389279343277937, 0.03895645578121466, 0.047244094537510994, 0.03771575340520471, 0.034481502558675506, 0.06403523264452815, 0.1104137167755154, 0.04267156086561661, 0.037617257480779966, 0.09542944300318919, 0.07080304105916331, 0.03088698162877512, 0.04584969194125264, 0.04200425614873248, 0.03552607110431118, 0.04929947013395929, 0.07426410372699462, 0.10390446686576452, 0.016541219158698956, 0.027686157113602086, 0.019233602609845902, 0.05136817566029007, 0.21562574251044184, 0.08916184786827334, 0.1499611289510804, 3.487698748227089, 69.52628627900155, 67.89849481275006, 65.50597452348279, 51.61227257021012, 51.131892050466234, 47.29652789331252, 37.10972462930987, 39.71131509350192, 46.06371518104307, 32.818210394151755, 26.916988780421597, 52.32132727100004, 68.46509687362179, 63.40404695080173, 47.04856741812922, 26.56706040905368, 42.70338143071821, 61.811850993864006, 69.05520177656605, 64.84274879578622, 20.524451078907138, 43.74726926126788, 59.68272178403793, 44.1219497496082, 13.837111957611578, 4.266503241754347, 2.5596147294967406, 1.8074085635523645, 0.8163656618806624, 2.44804413568589, 6.06187895421059, 7.116772465167507, 15.222069486494988, 17.70627910091031, 16.055646692552877, 8.324645276992552, 16.258513639050147, 17.945023967373757, 24.629999860640496, 20.649735504581084, 8.393315192191832, 15.35451812128867, 20.222544285558886, 32.60184853307663, 32.14092100820234, 39.79486157817226, 36.27161610511042, 24.061305215281827, 10.558587081970709, 9.133815534653204, 1.5315255931308194, 5.936130708263767, 21.046736240386963, 41.91926433194069, 55.008511697092366, 41.86123678761144, 20.9152485862855, 11.44575268991532, 13.676803708076479, 27.145831623385032, 44.48772645765736, 55.96331073391823, 59.04711346472464, 59.62426670135991, 62.4586380681684, 50.453918210921756, 49.87607071476598, 53.316122716473, 51.44934908036263, 46.50017299959737, 49.568384308968824, 47.630039184324204, 50.37560024569112, 43.24092265098326, 51.305037236982784, 60.23458750017228, 60.905438315483835, 55.77903778322282, 38.57411407655285, 21.238175361387192, 17.110078834718276, 12.344070576852369, 17.991982583076723, 39.20574903488159, 53.35635838970062, 43.09444173689812, 34.453813260601414, 18.552954081566103, 8.218284326214945, 9.955590328862591, 19.28040469846418, 16.99107216250512, 25.698988899107903, 30.14785097491357, 19.88841129887489, 18.50735652831293, 15.689175724983217, 5.003238108850295, 3.6098795985021903, 6.625196030063014, 11.428627621742988, 8.853217997858602, 9.790991006358977, 7.08494439240425, 6.488026332470679, 12.347009412703976, 12.08585310366846, 12.761690232061571, 15.350090745956669, 20.419970904627156, 10.761411862988627, 12.115524853429488, 10.506415636308732, 1.499161749116836, 0.7390954597823082, 0.8515002314121494, 11.365374499751676, 48.59597383006927, 49.41070110567155, 47.227298059771144, 54.07875699381675, 64.02366768929267, 39.86132614074215, 48.16038285532306, 63.00974284448932, 66.08610091670867, 67.10309305498677, 62.76798755891862, 65.68744690187516, 49.681089693500155, 28.95202425218398, 37.98373853006671, 56.101217346806685, 25.353702652838923, 29.37432819797147, 31.940611447057417, 33.255435036074736, 64.0005688513479, 36.07435618677447, 58.63540580195766, 71.49397465490526, 6.11714122756835, 0.6239762241321226, 0.218592892971731, 0.18893409009662368, 0.07164938435439142, 0.0938465751166786, 0.08943976158456457, 0.11322030286875465, 0.06646834704424105, 0.047838846897526134, 0.062375744474270654, 0.02933257582387136, 0.08828395707232338, 0.055092259295164585, 0.061883567456877044, 0.12913614721788516, 0.09763261228198968, 0.15806895921066885, 0.3228391346431548, 0.2845572307705879, 0.15848888264548394, 0.1543320895683381, 0.3065836988389492, 0.36129815804381527, 0.20929762642950783, 0.19564370264209088, 0.17273653989597676, 0.15103270209604694, 0.071514866975767, 0.06554430711173242, 0.09233276239566265, 0.6122425763357071, 0.2555676516626151, 0.4758482516532945, 8.045479895607118, 94.54434779382522, 76.10672120125064, 75.8712770092872, 62.30814849176715, 60.02399152325046, 55.459172418040616, 76.59169873883648, 45.60970475596767, 62.02306670527305, 35.11180654648812, 23.512500909066972, 67.01113700866699, 75.09625588693928, 75.77870122848019, 59.16924822715021, 32.564454617038855, 48.812186641077844, 68.6739238615959, 76.97350225140973, 67.62568612252512, 17.557309442950835, 43.97535900915823, 67.42286036091467, 47.449739594613355, 19.801369982381022, 9.38950405966851, 5.545116489933384, 2.7276755436774227, 2.2100146114826202, 3.0796930674583685, 4.928639531135559, 6.923228992569832, 11.770410210855546, 12.000306210210248, 24.461645849289436, 31.635231394921583, 24.163216237098943, 20.269171460982292, 28.997121703240182, 25.963701817297167, 15.317655686409244, 19.045937176673643, 24.58715581124829, 38.151239425905295, 37.742261732778246, 47.049265600019886, 44.22530028127855, 29.97677483866292, 14.447639661450541, 9.93685120536435, 4.1488654767313315, 8.887735835967526, 23.237644741612097, 44.30254743945214, 56.3609645443578, 54.23098025783416, 40.70852279663086, 23.918970246468824, 24.289363584210797, 39.789256511196015, 53.542290502978915, 60.71382661019603, 56.957180500030525, 54.39076977391397, 59.230590174275065, 50.185553566102065, 51.712269475383145, 55.02886879828669, 57.481613159179695, 47.088383397748395, 53.971966543505275, 54.4529785648469, 54.546480025014574, 47.599193665289114, 50.285056252633375, 59.99824116306921, 62.931495481921786, 57.32686388877131, 50.06682734335623, 38.16202202150899, 31.547080047668953, 21.593710760916434, 33.65668565996232, 45.61068142614057, 50.49501288321711, 45.44342763962285, 37.355802366810465, 22.66781064771837, 12.476746709116044, 16.64212046131011, 26.955029887537805, 16.101332499134926, 30.814291084966353, 34.21546259234029, 25.740979832987634, 22.20270383742548, 19.910990422771825, 9.119831304396353, 10.567914478240475, 17.90362335020496, 25.055894736320745, 13.116656887915827, 13.510375580480023, 10.966986225497338, 21.778350453222952, 41.99820987639889, 34.644660103705625, 28.570061883618756, 20.349895800313643, 21.530858701275243, 7.141725113314967, 8.61232171135564, 8.960284975267227, 1.484431655656907, 0.462393909091911, 2.376626355032767, 14.099596969542967, 52.569538777874364, 52.13323000938662, 48.632565621406805, 56.79772438541536, 68.35696497271138, 45.6637236379808, 53.40277179594963, 65.51814171575731, 70.09085655212402, 72.49155890557074, 68.11948899299868, 71.55388493691721, 52.08609880939607, 32.35219751634906, 40.553851973625925, 59.053718736094815, 21.751050756823634, 55.26241456308673, 38.84499688302317, 51.992793467737016, 69.21873323379025, 47.99911852805845, 66.39920019334363, 87.39407093294206, 8.545430591029506, 1.0075864784659878, 0.2920680793543016, 0.36523496131262473, 0.21341314268929346, 0.24127920789103358, 0.1670502829215219, 0.26592943516950457, 0.11424116865401307, 0.1390207805220158, 0.20365442359639754, 0.09615777811456112, 0.2996476307030647, 0.17354715285041641, 0.08967282085288918], [0.0879150091279899, 0.04859089626059417, 0.01893866067421773, 0.03754503837215804, 0.095146166671428, 0.028430438345117916, 0.07262123583425438, 0.051912848852695, 0.11352910525015286, 0.0396176241338253, 0.10271876194183865, 0.09221858465142789, 0.01864241830433809, 0.02463977400874419, 0.02565902717892201, 0.13579504474276496, 0.045785474620999835, 0.19070432010677554, 0.10526899969385517, 0.27149638161063194, 12.641693161379907, 67.03525958522674, 54.961784501229566, 65.27629621567266, 35.05964294556649, 22.16082076872549, 54.454449453661525, 45.90247831036968, 43.13812125113703, 43.69613724370157, 20.026702304040235, 55.13187023901171, 72.59144598437895, 63.57686658059398, 62.491891922489295, 50.72944118130592, 39.68647080083048, 58.833756139201505, 55.44811525652486, 45.65218794730402, 40.814999457328554, 34.83656990912653, 59.53774313772879, 36.18496310326361, 19.335884663366503, 0.9684065356850625, 0.6975146587337218, 0.35665361210703855, 0.14213227726999791, 0.9869804906268275, 4.9849902622161375, 11.41999154321609, 11.735211841521725, 21.9238390076545, 22.668965785734116, 8.449848313485424, 3.1984871962378105, 10.09805375529874, 21.030213256036085, 25.34830939385199, 10.252358817285108, 12.252500883994564, 19.35716744392149, 23.69020977327901, 30.003837231666814, 33.21472475605626, 26.511464734231275, 15.88552467284664, 5.226445976764926, 5.147514650898596, 4.864420035193044, 0.8617507942741918, 4.478917727547308, 11.47175604297269, 28.98842384738307, 33.97817880876603, 24.002246087597264, 9.093399432397659, 11.138840952227193, 12.433827154098019, 29.32977007281396, 44.73635765814012, 52.43371102117723, 57.28627912459835, 60.58882067280432, 47.98304465509231, 47.43481105373752, 48.19771205225299, 46.93831351495559, 40.5188879659099, 41.14108570160405, 44.83169086517827, 46.06571951220113, 42.79981682377477, 44.99475948272213, 56.71888474495181, 55.188862277615456, 34.60358112089096, 14.189763434471624, 10.49589878128421, 9.678095386874292, 4.303310763451361, 13.732412130601945, 33.72212256154707, 47.92498180943151, 44.15035947676628, 28.924740245265347, 13.17662012192511, 3.9606679495303867, 13.267778946507363, 15.79517581770497, 5.587168710847055, 8.567757702642872, 22.147657294427198, 20.90367563309208, 12.97985932519359, 11.07470529694711, 5.1183832076288045, 1.9167125176998878, 9.56202853110529, 13.72747092477737, 10.94966798059402, 9.736970163160755, 5.584306851510079, 4.262510759215202, 11.482795553822672, 28.373566827466412, 55.41559880779636, 37.08804568936748, 22.386580628733483, 15.424871713884416, 7.122018144976709, 3.2024519770376147, 4.657730248666579, 0.7489813647923932, 0.36789356220153074, 7.602685488039448, 43.54808345917733, 41.10929096898725, 45.66612020615609, 63.97560688757128, 45.775660237958355, 51.42905865946124, 62.4833764568452, 57.340627485705966, 56.43115143622122, 59.51255759885235, 55.207277805574485, 57.10060196538126, 39.790790157933394, 21.785812762475786, 63.23324341927806, 50.80826905465896, 34.358684016812234, 29.359319248507102, 30.014912043848348, 63.587625641976636, 48.45006558202928, 36.96992743399836, 60.61194304497012, 22.687375430137884, 0.39205049014379906, 0.16241989428958586, 0.024586992465981075, 0.21104075224889865, 0.11333631156312843, 0.1452227525653378, 0.0465315523286981, 0.057691097665097446, 0.06826659288978384, 0.07305974456211252, 0.03354037886545543, 0.00831590069743294, 0.02649270512554194, 0.06628938890512913, 0.08153633890493263, 0.07829486767971709, 0.02796452473698845, 0.01868753705263859, 0.01351318290201767, 0.0584693165916589, 0.04179265883360659, 0.09251488447790185, 0.08366754954500545, 0.04144617258721302, 0.04863650530516621, 0.04865879463332315, 0.10592034296883691, 0.10671139003769045, 0.05628129287112144, 0.07448222428079575, 0.07647907842070827, 0.09489982343849637, 0.20513884152375883, 0.09562090369722537, 0.21436728987722628, 28.31886741422838, 82.96192599881081, 64.55876527294036, 73.33948904468168, 36.973445800042924, 34.9884872282705, 40.31963940589659, 35.984945758696526, 43.585365587665194, 37.34370577719904, 26.616027278284875, 57.97167801087903, 74.14617938380088, 65.65014123916626, 63.88330959504651, 55.478321429221864, 44.99199421175065, 62.57490496481619, 65.00158909828433, 52.58300427467593, 41.141505395212484, 41.386069097826564, 65.18024129252281, 40.06922744935559, 21.109078391905754, 1.9222672067342268, 2.156836097278903, 0.4058508286553045, 1.9660397546906627, 6.562673449516297, 10.688816635839402, 21.08163356781006, 19.22942957570476, 18.16198987345542, 11.890199395918078, 10.756101954367853, 16.413147199538447, 18.89801283036509, 27.307348943525746, 30.149443457203528, 11.511718130880787, 15.531620979309084, 20.721654122875584, 26.468375536703295, 32.940362807243105, 39.128756830769206, 32.77017116546631, 21.22211717790173, 11.17674477638737, 8.46564369816934, 5.130556283458587, 0.5772567504355984, 9.512596861008676, 23.675020394786713, 42.12617328090053, 42.814317826301824, 27.448783728384203, 15.042528875412481, 14.77353959314285, 23.46823892285747, 42.473746268979966, 54.69749519901892, 58.69821471552695, 60.097449671837595, 61.57410044823924, 52.219906545454464, 49.78965305512952, 53.22497860077889, 50.79306202550089, 47.40957452404884, 47.90296162328413, 50.614241169345, 50.20497714319537, 45.91551234645229, 48.25379017860659, 60.556880812491144, 62.67714546572778, 48.751652702208496, 31.478636649347123, 16.22967343176565, 16.43878871394742, 12.903114230402055, 25.26120335825028, 44.74851308330413, 52.72233078556677, 44.38146552731914, 33.94151641476539, 15.799893448429724, 7.414521055836832, 16.67918489825341, 18.247897624969482, 13.995379594064529, 14.249545258860435, 25.9921899918587, 23.365990577205537, 15.037632776844887, 12.690958130744196, 7.768514963888354, 3.141652542737223, 8.693761883243438, 9.564305466990318, 15.231237046180235, 14.107262261452215, 8.566207385832264, 8.749465423245585, 17.91223099154811, 29.41672117479386, 42.616904935529156, 27.44863860068783, 19.088594913482666, 17.4971834305794, 11.38253192747793, 8.58210082977049, 11.275293346374266, 2.7228130304044296, 1.4341397607518782, 7.743340701826158, 44.752019682238185, 43.52811467263007, 47.13975467989522, 66.340435243422, 49.68158391214187, 56.75753970299998, 67.46308034466159, 60.363029433834946, 62.695964997814556, 64.2174013968437, 58.49441620611376, 62.16798259365944, 44.426247227576475, 27.670497663559456, 57.86498561982186, 70.12050967062675, 38.003432750701904, 25.07696767007151, 30.16485837198073, 55.322018900225245, 65.59088599297309, 38.29693978832614, 72.49872115350539, 30.00675939744519, 0.48854183826235037, 0.1895902597255284, 0.096464266910428, 0.08207361168798902, 0.04939545328999239, 0.07229426184729223, 0.049056497687894496, 0.08600639299519601, 0.08933447046025146, 0.06653999158691976, 0.08009545009342894, 0.03739463232998406, 0.011593721837045686, 0.03273875595280721, 0.05958019387758067, 0.16840593679057014, 0.10522584596108045, 0.09364730032581477, 0.13856353328352974, 0.16321745310579577, 0.17028214740416697, 0.21146174820680774, 0.1528165837930095, 0.23598347189685992, 0.11033356099599793, 0.1961672011642687, 0.16716354136024753, 0.3284646408452142, 0.15742386721314924, 0.21315820394985138, 0.1555377740653292, 0.1729269740321944, 0.34703933123138647, 0.26675543116946376, 0.2675967795714255, 47.88606797495196, 95.78465615549396, 71.69708282716813, 82.0068916197746, 46.28287761442123, 38.74258772019417, 78.7303004726287, 55.08522149055235, 53.98738930302282, 55.69134535328035, 23.75464450928473, 67.03056843050065, 85.25891304016115, 73.8321622725456, 71.29427109995197, 61.251144255361254, 50.55788455470916, 73.32132847078385, 69.63346112158992, 54.577035288656916, 46.89988997674758, 45.52301253041914, 70.27676905355146, 44.108927480636105, 25.356866044382897, 5.61195710974355, 3.2605827287320173, 1.055203500774599, 3.6254325316798304, 7.516113385077446, 9.160511186045985, 15.770517837616707, 15.406705256431335, 31.209230615246682, 37.26116341929282, 22.230154545076434, 13.459429875496896, 20.22579789161682, 30.893652400662823, 35.31571488226614, 18.502683024252615, 18.734877532528294, 26.558835198802335, 30.944947196591286, 41.758427543024865, 46.410986146619244, 42.382931632380334, 27.36860263732172, 10.64336617146769, 10.558551780639156, 8.86517926569908, 4.379861700919367, 12.057807176343857, 21.869665192019557, 34.737812472927956, 46.82143472856092, 50.50208491663779, 30.227843792207782, 27.42351778091923, 36.377002346900206, 53.00430213251422, 62.19832997168265, 57.5548634221477, 55.06274238709481, 61.51181713227303, 50.85406272642074, 53.94563959490869, 55.635224080854854, 57.10467730799029, 48.607211420612956, 50.64999357346566, 56.56658695590112, 54.781308404860965, 50.759427701273275, 49.906527919154016, 57.19772769558815, 64.0071702003479, 56.763638988617934, 45.34055955948369, 34.9817289844636, 31.432909657878263, 26.17951258536308, 40.533616465906945, 48.406578263928814, 46.511375288809504, 44.87071452602264, 38.692577500497144, 21.414927167277185, 6.79816274873672, 18.916665661719538, 22.45112322991894, 11.768651027833263, 14.471268019368573, 29.125383207874915, 27.027605502836167, 18.116227580655007, 15.43488258315671, 12.531498093758861, 9.262327090386423, 18.035873905304943, 24.087734145502893, 18.706322677673835, 16.191510731174102, 12.23315477371216, 10.923519499840276, 21.547722931831114, 39.51088590006675, 68.93206288737636, 49.55726831190048, 30.786685443693596, 19.25721564600545, 8.883331994856558, 4.1702193502456915, 7.5156745699144185, 2.23262952700738, 1.061180825195005, 9.371678848420421, 49.66209365475563, 44.687163291438935, 47.59745605530278, 71.00000704488447, 53.47950512363065, 54.9243180213436, 71.01945415619882, 64.25406771321451, 66.36463626738518, 67.16848681049963, 64.95036294383388, 65.17098449891614, 45.89328427468577, 27.58398586703885, 66.69872022444203, 59.56674122041272, 43.62297719524753, 41.51737043934484, 40.855231208186, 77.40140145824802, 68.60791821633616, 47.26024989158877, 80.27176057138752, 41.04120646753619, 0.829522823614459, 0.29257354416674186, 0.14515285470312642, 0.26613649341367906, 0.257777493567236, 0.1994248062011696, 0.12717544476711942, 0.11832674619771781, 0.11882723143865025, 0.14047977965204947, 0.2274461267816444, 0.17947215346559403, 0.1571465587063182, 0.19732777840427815, 0.15800840762113372], [0.04793039823491727, 0.10121087874135665, 0.08479058081584592, 0.04140656967196734, 0.08450066250178122, 0.06830988451838493, 0.10812424769204472, 0.11870836523631889, 0.041849004600437424, 0.020227247375934836, 0.12308932330098846, 0.11051493231207134, 0.03842241971963837, 0.12004671317915763, 0.05173677886505762, 0.057045714554166606, 0.12203490286464654, 0.13775337998184467, 0.1146755941332348, 0.5211409938431556, 2.390643925436082, 77.24472630408503, 60.3363573166632, 68.86640241069179, 62.312219912006015, 36.931190106176565, 40.342267559420684, 65.23696660995483, 38.11887202724334, 57.57728369005265, 28.92079826324217, 28.07266612206736, 71.24726541580694, 62.48104656896284, 63.96897808198006, 72.46381990371212, 53.63153619150962, 56.530265808105476, 70.64095327931066, 72.21937779457339, 83.59046228470342, 46.26731757194766, 49.017918878985995, 38.745364758276175, 12.847976492297265, 1.46027218430273, 0.12408273249504068, 0.6030283159305972, 1.698106570589927, 4.195966278353046, 6.978626587698537, 13.520306041163783, 37.55130506330921, 41.03527584383565, 17.591361499601796, 2.621914960684315, 5.1696662364467505, 8.667483964274007, 23.5292298178519, 33.7864141310415, 18.959248873495287, 12.204430276347745, 18.158194980313702, 24.05353499997047, 34.62894708879533, 29.20861198056129, 29.173202783830707, 7.04135460238303, 8.473039327129241, 11.562454969652238, 5.4285132500433155, 1.0941367019568722, 5.741411014910668, 16.54019767238248, 24.618085661242088, 38.01268954430857, 32.78667257678124, 13.429324703831828, 12.0620443167225, 11.92188528276259, 26.376968622207645, 41.05230285275368, 53.45524918648505, 57.69853984155963, 59.81236396297332, 51.30014211900773, 46.134823829896995, 46.16077423095704, 44.653948660819765, 39.18437996218282, 42.124937734296246, 43.28446880463631, 44.89033422162456, 41.29729409371653, 44.77871533363096, 59.18665178360478, 53.217482951379594, 37.616953772883264, 18.55179698236527, 12.287486464746538, 11.154627511578223, 4.284240689969832, 10.918279213290061, 33.50969483775477, 49.204572708376, 44.47242529161515, 30.051711720805017, 12.913171187523874, 9.597674050638753, 9.686694202884551, 17.342895038666263, 14.821014981116019, 4.753869502775131, 16.690065553111417, 24.544645163320727, 17.030458642590432, 10.802538894837904, 5.426260338675592, 1.12611664399024, 3.8652121684243603, 14.272025342910522, 17.1295710532896, 12.858587484205923, 4.029567078236611, 5.9922524709855365, 10.067970156669617, 9.508498964771148, 14.395282883797924, 39.18926331304735, 33.312489832601244, 27.6113522437311, 21.439026209615893, 9.106164786123461, 4.614433165519468, 4.28681964835813, 0.0664474328439082, 2.8152865844388164, 31.074554074195127, 43.28211146016275, 50.576708009166104, 62.76608520938505, 59.66219994329638, 57.47618459886121, 51.34622996853244, 60.62042320928266, 54.81482113561323, 62.247292918543664, 45.6353452897841, 64.28915723677605, 31.78241441326757, 24.652312263365715, 61.8189779404671, 54.49165313474594, 37.58120921350295, 25.29849333147849, 51.50115182322841, 64.29462894316643, 42.647464121541674, 38.08305294282975, 71.36098277184271, 10.11395602456985, 0.49539231905533426, 0.1275433738145136, 0.06740956266801204, 0.06730504529250246, 0.044501415498915224, 0.10769634928193786, 0.08111374948414103, 0.020300989084306265, 0.06189962465976996, 0.056412278584414915, 0.04678527681878017, 0.06940065582673396, 0.024895149418303085, 0.05397180974062893, 0.14746539835487643, 0.04114072567092315, 0.15768095099877927, 0.05514467120050423, 0.054548233447055665, 0.04312169880816533, 0.01619693349986788, 0.022251581089691292, 0.12259494378081254, 0.06889159806192884, 0.01782600414909182, 0.08201529707519278, 0.16783339331947988, 0.08556920959944687, 0.057067724260231184, 0.05503633104625249, 0.04372288247630481, 0.14065789509444468, 0.2631062785944631, 0.12644517911417832, 0.5675965655715235, 6.622457725386466, 88.20054946407195, 69.18697772487518, 74.29374679442375, 60.71434436305877, 36.42124276007376, 38.141778669049664, 38.025103845903956, 43.1366660518031, 42.45121617471018, 32.451906127314416, 39.70541977113293, 74.48373071609005, 68.10758852189588, 66.58922333871165, 75.13428718813005, 57.09631873715309, 62.8606378647589, 72.35928873861991, 72.92072896034487, 71.4356803894043, 49.17733184752926, 53.931409235923525, 39.31339456189064, 15.288896868305823, 2.5709150779631833, 1.1336934374224756, 2.6984237326729685, 7.031156439935008, 15.103818851132548, 17.239101279166437, 19.33827142561636, 22.62408406503739, 21.50831291752477, 17.329755098589008, 12.774055504029798, 11.558642425844747, 16.457906346167288, 27.101485306216826, 40.9930044604886, 21.160610491229644, 13.791028030457037, 19.01113006376451, 24.6415610467234, 36.14841445799797, 36.508644934623476, 31.06848224516838, 15.757349460355698, 16.530099530373853, 10.735835067687496, 5.746686112496161, 1.707040626675852, 8.833513971297972, 16.652077397992535, 25.798432750086633, 46.61731458479359, 35.48890321485458, 16.74771066634886, 18.691027395186886, 23.218274116516117, 40.20631820924821, 54.49745824260097, 62.76236680246169, 60.41500083861813, 62.11617200605331, 52.20264811669627, 47.17403619520126, 52.114131989017615, 51.921300426606216, 45.11754143622614, 44.22593570524647, 49.34975924030427, 50.93191785197104, 45.761410267122336, 47.93097519105481, 62.45852824180358, 63.38691011551888, 47.38188259063229, 27.25112568947577, 18.054183529269313, 16.732234954833984, 11.17020030175486, 24.5007695305732, 47.885871856443345, 51.71097509322628, 43.61259468140141, 33.4362563010185, 16.28058873837994, 8.619541814250331, 14.15548780272084, 18.162766502749538, 21.67204245444267, 10.968808166442379, 19.452896810347035, 25.562058956392352, 20.321950874020978, 11.867937003412555, 6.547543396872859, 2.9659742405337672, 7.554909058155553, 12.92452056561747, 21.37496017640637, 16.018909773518963, 10.669559759478416, 11.249963660393993, 13.68892873487165, 17.265137972370272, 24.34007786935376, 45.072822493891564, 31.469268068190548, 25.274207976556596, 20.505623702080022, 12.401875526674333, 9.48118357889114, 7.123153180845323, 0.9724765463221459, 3.3041234891260824, 29.78076223404177, 46.32363496288177, 50.732273132570334, 59.77405809587049, 63.178844067358206, 61.069487525570786, 56.19094156449842, 65.72648232983005, 58.51830736283333, 67.21801065629529, 51.52028906729914, 66.89942790615943, 36.92278054452712, 28.72559758924669, 57.98364516227477, 68.0147538646575, 35.39854749556511, 27.25487351417542, 42.91863718340474, 64.39881493968349, 49.16980874153876, 42.893118243063654, 80.98989948149651, 13.10420826558144, 0.9166132310225118, 0.059423969397621776, 0.12234490034320664, 0.09234949375592894, 0.018316131881287983, 0.07939362928511635, 0.09301869454042566, 0.019282950163488428, 0.10399562366787465, 0.07027980300687975, 0.028621098477273222, 0.027171248352275263, 0.024299110030575145, 0.05965035220968628, 0.11661080883875971, 0.1635176829633213, 0.20487936754380504, 0.15772901535514863, 0.11268122211819696, 0.19542671589841767, 0.2179932453098797, 0.1829270721082726, 0.32408506939968756, 0.16328954197947057, 0.21492161577747715, 0.17534502331287632, 0.3376797899123161, 0.32455419100099997, 0.14567361063053533, 0.15296256950786039, 0.19003408510358105, 0.2979547908950237, 0.5088928107532763, 0.3024133306837851, 0.8130423724651338, 11.035559062034855, 107.26507279180713, 79.23990265015634, 84.26199559242495, 77.62622387178483, 50.44485361345353, 58.313371366070164, 82.22860751613494, 44.5536458107733, 68.10714137169623, 34.61507366549584, 37.11221141199912, 81.12542521569037, 73.75098489945935, 73.21078823458764, 84.04190355731596, 63.747615198935236, 71.51262160270446, 77.47949584837883, 81.41165625664496, 92.81755570442446, 56.92324415329964, 57.99851486759802, 46.71391471739739, 16.45100787762673, 4.110751560618801, 1.2474796800844132, 3.8165973319161326, 7.682126722028179, 11.338660217100575, 11.684457352084499, 21.99817184479006, 50.44970166298651, 58.15404468967069, 28.378720821872836, 12.773803491746227, 8.460189642444734, 18.48628947811742, 33.00267750217069, 42.82801474294355, 28.606232020162768, 17.105621061017438, 23.290788935076808, 30.74684592985338, 44.54652278654037, 43.7427036223873, 43.061038832510675, 15.098084345940622, 16.355779593990697, 16.03000419755136, 7.7924232809774345, 3.4208488127877636, 11.165762139904885, 19.426487491976832, 29.262999565370624, 54.98154932452787, 58.15026352482458, 37.767223696554865, 31.162260232433198, 37.88673047096499, 51.387975754276404, 60.10328223628383, 61.54168990350539, 56.03620406120054, 59.62432161454232, 51.56752617128434, 50.59144827627367, 55.56224838379891, 56.65433037665583, 47.930135803837935, 49.721525407606556, 52.61785845602713, 52.92192843652541, 47.599319181134625, 47.06539046379828, 61.29493359596499, 61.71466642810453, 62.99201765368062, 48.68827112259404, 37.125802424646196, 35.7114153523599, 26.369398447775072, 35.23125448534566, 52.28814401934224, 49.11683320999146, 45.51437939366987, 38.89750565251997, 22.78813131393925, 11.968097667540274, 13.783575527129637, 26.441562214205344, 26.937624369898153, 9.023420426153368, 24.3939967309275, 28.02144781235726, 22.869949994548676, 13.856198210870067, 10.510772408977633, 9.098920168415193, 12.803204597965365, 22.27405567323008, 26.56737223748238, 18.804468224125525, 11.070930015656257, 10.855100616332024, 15.22571042660744, 12.876086158137168, 19.263867985817697, 51.868497479346495, 42.807241870510964, 37.05617250934724, 25.090023279190067, 14.181972626716862, 7.98511608954399, 6.829131332135971, 1.3509481280080735, 3.2025998013634838, 36.8971674673019, 48.859235471294774, 54.69999374881868, 65.27669237506005, 61.99936774469192, 60.6065184070218, 57.485963067700794, 69.08819675445557, 62.86951811082902, 73.17874247027983, 56.34664397085867, 73.42331794000441, 37.40572237199353, 29.460792926050004, 71.54136473132719, 60.63713250621673, 46.2338166083059, 34.53056620013329, 67.28231399290024, 71.18704918892153, 55.81113453834288, 49.70092511946156, 91.7164993286133, 17.571963417914606, 1.2494065444315634, 0.22141099336647221, 0.265474348298965, 0.17275291885579788, 0.1704548236222998, 0.20920633939245056, 0.29753521986065373, 0.12363093214169626, 0.18770556085773055, 0.15240701786693067, 0.11859748167015853, 0.177372045995247, 0.13382842043234458, 0.2887864344783368, 0.12236238246963871], [0.06228588619119218, 0.1315094569637891, 0.01862839889532376, 0.04271346970551437, 0.0467890766148846, 0.0595532812088007, 0.05195183506716163, 0.09608470098746401, 0.04161637434135041, 0.0313657827510108, 0.04694902045171588, 0.05821145522678572, 0.02958121540535602, 0.16697594174934974, 0.047415740367385655, 0.10372140249537845, 0.12823578706311603, 0.19306330400849545, 0.1299156723243575, 0.20682883148472156, 0.14921535767855185, 43.84575605392457, 73.13158773606824, 66.42257751957064, 66.26727519496795, 67.76752687269642, 27.831226587295536, 66.8292723932574, 41.33716106414795, 45.93916816096152, 38.87535995052707, 17.874199690357333, 60.37470240746776, 68.3149956118676, 56.684195303147845, 66.40188309454149, 75.1982924246019, 64.65934661126906, 67.13340513167843, 68.52671730902888, 72.15796132241526, 56.84661672961328, 37.73180469389885, 33.630950989261756, 5.064477584054393, 0.4080369984430652, 1.773832094284796, 2.4683406852906753, 5.87526434852231, 8.33163199886199, 23.53246577324406, 63.48230215810961, 70.72872023428641, 26.676194475543117, 8.331836942703493, 6.548093509289527, 15.809544440238708, 11.352355172557216, 25.090605751160656, 39.22776137628863, 26.737085350098152, 12.539602691127408, 15.487063834744117, 25.032858656298732, 31.34287165057275, 28.449368592231508, 17.84057124968498, 5.965815696024126, 20.365791205436956, 13.165362919530562, 14.429257473637982, 3.5462031056804046, 5.199860642033239, 22.2048827140562, 39.2194773304847, 45.657424311484064, 31.778419479247066, 16.023438149882903, 12.527886571422702, 13.033833099949746, 23.492973389164096, 41.90936819199593, 50.754328620049264, 59.68359255021619, 58.80924917036488, 49.50053122735793, 46.99136749390633, 47.85195512156333, 46.05979673324093, 40.085650413267075, 45.562789286336596, 47.473395409122595, 45.158738090145974, 43.46451344028596, 44.85295011151222, 58.97605580668296, 58.14803169619653, 46.86671456983013, 21.315508811704575, 11.395574788893423, 9.671229277887653, 3.6334572107561174, 6.493600510781811, 26.110957399491344, 46.25848831668977, 43.67574876354587, 25.12874491753117, 8.303854753894191, 10.322531980852927, 18.433102138580814, 20.05968551481924, 23.542732577170096, 8.633090661418054, 8.295789380227367, 21.379257132930142, 19.75185790369588, 12.31163747849003, 5.585585053889982, 1.9477971787414246, 3.4336850143248037, 17.63108334233684, 27.822001172650246, 22.127194289238226, 7.91605442762375, 11.49288094812824, 21.201952272845855, 22.52837823283288, 13.299913944736605, 11.494668568334273, 18.731488604699415, 21.48937571433283, 19.100887621602705, 18.931329442608742, 11.200953645090904, 8.809400220071117, 7.193082176869916, 0.2165861256540783, 10.114636555794748, 32.47208279948081, 42.862880691405266, 55.47722708794379, 35.76684236526489, 59.10991845592376, 60.73872189367972, 58.88861833080169, 56.083692196876775, 61.61363009483584, 44.09379105414114, 63.65424317698326, 26.103661790970836, 27.695791067615634, 50.5684631870639, 46.38083096473448, 48.74415705280919, 34.07826985082319, 64.35221718203637, 72.71736191165063, 43.36325353191745, 51.80708100718837, 50.82278966903687, 0.6374098516760335, 0.13006965599713788, 0.028734377983416763, 0.020183021120066126, 0.06210532309787889, 0.12701004638426727, 0.010095759475183104, 0.1119123456338721, 0.019169021397829056, 0.1264220355979858, 0.007297357594999936, 0.04200823597549912, 0.04490797069945163, 0.1010506208084764, 0.03738591041896613, 0.020988014819581183, 0.017677591850740776, 0.10732651267561222, 0.013530052158110326, 0.026027747212098013, 0.04050853842448804, 0.13988452933488355, 0.05135435543413605, 0.03865055687304947, 0.01054812481837167, 0.1247251048804291, 0.0569317972798261, 0.07469414718328946, 0.022911140657660943, 0.09478137092364412, 0.07517042404581463, 0.08645064738248626, 0.07399860829595598, 0.08171987824983175, 0.15607484766552526, 0.1442466033322196, 0.18555947279016818, 57.06524964301818, 87.46688581282093, 73.71900973781463, 71.5850991587485, 56.40948818575952, 32.503948134760705, 38.1478230414852, 38.26007735344672, 43.39822538437382, 30.451020771457305, 28.407746361147975, 64.35641019575058, 74.76579619992164, 62.83345191709457, 77.20614587107013, 79.278090846154, 72.76352036383845, 70.63386947877946, 71.61700371773013, 68.64241938437186, 57.492913507646136, 44.895966745192005, 36.81327189168623, 5.333303597665602, 0.9172674701098473, 1.851509364862596, 9.12737794460789, 17.361712609567952, 18.87012673962501, 24.947702038672663, 49.387978815263324, 62.66799849848594, 31.785381686302927, 17.915812115515433, 10.845073076986498, 17.067517195978475, 15.244775106829984, 28.59633391903293, 45.743732144755704, 31.199824771573468, 15.393943825075704, 17.48878759722556, 25.582327804257794, 37.90209831730012, 32.17588697710345, 26.833279517389116, 15.834342645060634, 25.20775321991213, 17.22042883596113, 13.848626075252412, 4.449706856281527, 9.624784492677259, 23.0463997779354, 38.242258025753884, 52.23859663932554, 41.36227600036129, 23.083523050431285, 17.569898290018884, 24.509588979905654, 40.90398626942789, 55.98307555721652, 60.115951491940415, 63.05190047910137, 60.0400536291061, 50.98075528298655, 47.635095119476325, 54.05818808463312, 49.047156226250436, 44.00651439543694, 48.639370933655776, 50.19328848008187, 51.34116618863998, 48.91823184105658, 49.25796793353174, 62.79720137196203, 63.85126383073869, 50.98276353651478, 31.287732931875418, 18.885329846412905, 15.482912986509263, 9.100216511757143, 18.73473240483192, 46.357210451556796, 52.60695426694809, 41.11487642411263, 31.048072191976736, 9.64325297263361, 10.373184488665673, 17.208846076842278, 19.342888055309174, 24.462457779915106, 15.982714141568831, 13.563207945516034, 23.972996973222305, 20.9205477083883, 12.290106608021645, 6.004235802158234, 3.030155738515239, 3.861590349866498, 19.06385064125061, 32.153158803139966, 23.671323560899307, 13.126459871568988, 15.746942431696, 18.806535313206336, 24.001065454175396, 14.868421727611175, 15.77392049374119, 20.86995501672068, 22.28491867742231, 21.957041871163156, 25.53980342803463, 17.010513390264205, 14.044346463295723, 9.466024598767682, 0.41871917524164726, 8.408644795417786, 33.75594123717278, 45.04567969229914, 56.46709603648032, 43.85181611584079, 65.06039719427785, 61.987177018196356, 63.90499637972925, 59.12552164446924, 65.27088334483486, 50.22351818699991, 66.71594727423884, 31.638255542324437, 25.295143627351333, 56.759610714450965, 52.245456864756925, 52.05300577225224, 34.84415577303979, 55.49464241150887, 86.47814258452385, 48.88840613826629, 57.97545525335497, 61.00615301439839, 0.9200907799024737, 0.12007421573563931, 0.10210222204125698, 0.07678765097572919, 0.10928895414596605, 0.028297137131073305, 0.05198861111796672, 0.05478619184765605, 0.00342505102913316, 0.050808107931046724, 0.059495307505130775, 0.0963488634255144, 0.03235314942656025, 0.02871011023319537, 0.029242661999418374, 0.07187729551186485, 0.13951015748804615, 0.26103918951365257, 0.11519857937650335, 0.18242513130028404, 0.12389402971753191, 0.17946510545669064, 0.17230681053573088, 0.14540347270667553, 0.17981307791365733, 0.290666475531555, 0.15906328004935097, 0.23471538187755694, 0.0762691320250592, 0.18782082644681777, 0.18496264433187826, 0.13718057604086015, 0.16133030275664023, 0.20778760584371708, 0.21904108505095207, 0.24454919290879082, 0.2906401527504767, 71.0401564259683, 102.79586145954748, 82.27045136113321, 86.0659642373362, 77.78525244805121, 47.6683803527586, 86.73665031310051, 51.173892790271395, 58.038173952410304, 47.52155819246846, 21.783188696830504, 72.31506009255686, 77.37801628728067, 68.0518751759683, 80.3611513876146, 87.8556711443009, 77.83248562966624, 78.41232961223972, 78.74035742975052, 81.77052959319084, 66.21245614943966, 50.09276597730575, 44.05573621872933, 8.193231657628091, 1.252208342475276, 4.616312961424551, 9.890077921652026, 16.11978038664787, 14.977523434546688, 33.607385389266476, 76.96537510041269, 78.14862082081457, 38.14375946598668, 14.989603354084878, 11.396432807368617, 26.668375230604603, 21.644691767231112, 34.87176141431255, 50.63797543125768, 39.5156398127156, 20.557055780964514, 20.76592395382543, 32.23510692196508, 41.731649521858465, 41.91275711982481, 31.398375149696108, 14.81336832046509, 33.3552279779988, 21.176754966858898, 20.231620650137625, 7.365179109957911, 14.560884371880563, 30.841524101072746, 50.75092792510987, 60.03481334255588, 58.53214548480127, 42.603180562296224, 31.890183494937038, 41.232245506778845, 53.0778387285048, 63.23270605456445, 58.96344930894914, 59.045799470716915, 57.54719518846082, 50.8442214996584, 52.71058328690068, 57.60511682879541, 55.40737359754501, 49.00761873491349, 53.399253429905066, 56.65979816067604, 57.01484718630391, 50.65224893631474, 49.77710931531845, 60.478860947393606, 62.89549596848027, 68.00091574268957, 55.20412814232611, 40.903637178482555, 35.38111648251934, 20.550062194947277, 28.265042689538774, 47.963691680662095, 49.51138050325456, 39.551074504852295, 34.2466728918014, 16.7132193042386, 13.915505428468029, 24.24993788042376, 27.199993671909457, 36.21941328048706, 16.115179446435747, 13.942576646804811, 26.90643564347298, 22.864276286094423, 14.903830924341756, 9.854630481812263, 10.026943145259734, 12.62973189353943, 26.931854563374674, 37.908099543663766, 26.98950948253755, 15.115864449931731, 18.856010129374845, 33.29458029039445, 35.12095351372996, 18.337211954978205, 16.02758017278487, 23.820581513066447, 30.26962684046838, 25.67234031615719, 25.010136365890506, 17.5962919189084, 13.467452103091826, 12.81991977845469, 0.38270381910185663, 11.391103286896984, 41.36857140448786, 47.9515205660174, 66.59465974377048, 42.7476453781128, 66.93876927898776, 65.18300264112412, 64.51450524791595, 62.07623443295879, 72.26612460228705, 52.747457488890625, 75.13179256070045, 30.190389079432336, 37.004977733858176, 60.839487583406516, 52.95211499737155, 56.76090117423766, 45.44691462670603, 75.97307820473948, 89.02168197016563, 58.35719208563528, 63.579835814814416, 73.69893504727271, 1.9965272348734642, 0.4964385193682486, 0.20774819828089208, 0.30080123654296326, 0.16845056907303874, 0.14998532200772918, 0.14502623569100134, 0.1691960032668806, 0.11590968517045822, 0.3109635460761286, 0.18854770599113357, 0.13021994712612323, 0.21664483863259518, 0.2191939349136045, 0.0692595960572362, 0.10162542423894329], [0.05488638848727269, 0.056355603399776646, 0.02884919349584849, 0.054415014587462916, 0.05405982558224952, 0.08521238882695475, 0.06302646721803373, 0.13979405435102601, 0.06697541298044306, 0.21526712143132765, 0.02386354116512643, 0.10492140261997139, 0.06951491017976115, 0.04823191128971596, 0.0660333623208346, 0.04413226071084219, 0.09984240056045594, 0.08028965338223404, 0.08489961811010877, 0.21547974147383245, 0.22024195851577869, 7.734354551761382, 78.2962509893602, 68.68277272870465, 71.30084499236077, 76.25521429123418, 51.60012106741629, 43.64895505289878, 60.19571288939446, 27.033253715884303, 61.152480956046816, 13.820302640238117, 46.3140526125508, 63.20730478532853, 65.01613324688327, 60.90681898978449, 57.48392735758136, 68.68000353536299, 69.61344918897076, 66.63128683643957, 53.77377702343849, 49.2467656443196, 44.67396059343892, 26.1150582375065, 1.4670746773481371, 1.0226390642985221, 2.623610160043163, 5.854616501638967, 10.064118389160404, 26.790460963403028, 46.365412127587106, 37.472951796747026, 17.282374828092514, 9.777429411488196, 11.56428965830034, 16.349282187800256, 16.778252201695597, 10.814815913477252, 20.79314128045113, 39.808456513189505, 29.620804056044552, 9.535660397621895, 14.737630294215295, 29.3884781483681, 29.27174056729963, 30.40339731401013, 11.668834551688164, 12.779357567910226, 25.088093473065285, 17.128849337177893, 10.022650111106135, 3.8692580932571046, 13.259484114185458, 28.684167554301602, 48.54343760398127, 46.37794410028766, 35.36477981075164, 18.39002863053353, 9.998049005385369, 14.951761307254916, 17.457932272265037, 36.654780680133456, 47.50777890605312, 58.11220084467242, 63.37107158476307, 50.81268956584316, 46.15644785665697, 47.27597075123941, 44.6727172020943, 45.26927048160184, 44.25733427847586, 45.73469500387869, 43.32415926840998, 41.27751750330771, 45.62862234730875, 54.58533894631171, 54.98154540215769, 49.53723284506029, 30.133279369723414, 7.97851425024771, 7.534203846608439, 2.714230639319266, 3.825932327778109, 19.960190673028272, 43.60331435357371, 37.35451582939395, 12.749387718016102, 8.937238108727241, 11.492983910345263, 18.44163917726086, 18.361534572416737, 27.241939498532204, 17.568811793481153, 4.571037532821778, 15.494193723124845, 21.61130455232436, 13.566406638391557, 4.800753593444824, 1.4071326486526, 6.383057332807972, 31.20017778488898, 31.60653925711109, 21.025671151376542, 10.13791778395253, 18.010201992527133, 21.323916412168934, 23.768627758949037, 27.469691922587735, 29.363463232594153, 28.085343222464285, 25.380898406428678, 21.58553065792207, 17.18895769888355, 14.117272150131965, 16.485084449091268, 11.60281615872537, 4.415230693355683, 0.6542526317700263, 19.689800124014578, 29.482762121385147, 36.98906860043926, 43.03532377366097, 54.01528127731816, 54.36944384728709, 55.385004320452296, 58.53558932581256, 58.24352572041174, 48.67432709663145, 56.59645580476331, 20.0528900084957, 31.712984538847405, 17.13310903118503, 43.301311462156235, 37.91657970797631, 48.6147855174157, 77.04635635499032, 45.46474964387956, 32.38290575242812, 62.61831775788338, 29.72576472067064, 0.05219688744194085, 0.10334166037219186, 0.1086856292620782, 0.09961551596080104, 0.06537155428480718, 0.039774848358525385, 0.11820576559271544, 0.030911371953064398, 0.03705519792293349, 0.04092472335023265, 0.09907381518954232, 0.06623089809211032, 0.05773841125530101, 0.08545801193723757, 0.06261287549991282, 0.009187579477926897, 0.01974606372025465, 0.06668352582041295, 0.04680745506418809, 0.008178956735308373, 0.05204237899893234, 0.07358458373815784, 0.04881797621266977, 0.013697780405862198, 0.07093343688475509, 0.0455650634643051, 0.01348597911982647, 0.10891000875422072, 0.051586028083317706, 0.041894188466211485, 0.07904626203760987, 0.12540473212157527, 0.14309953988319443, 0.10589673979988984, 0.11799650867619824, 0.33422537688766757, 0.5328284925030125, 15.05565606778668, 92.41312796069731, 76.90773979310067, 77.96096678703063, 78.71431289180633, 52.35522047165902, 32.93368301083965, 41.783169854071836, 36.564860343933105, 43.860613992137296, 22.385874602102465, 56.63027448038901, 68.95484401333717, 67.65486071186682, 63.58427986021965, 65.3415487658593, 75.56605385195824, 76.6966142962056, 73.14002867667907, 60.42971757150466, 56.70394835933563, 48.67198936400875, 28.234006935550322, 1.4256168180896391, 3.2604204406661377, 6.155528483852264, 14.00950110727741, 18.638546082281298, 30.314024148448823, 43.73991873956496, 46.03839628158077, 24.81139183044434, 14.587483925204124, 14.735919160227622, 15.92094171431757, 16.309073971163844, 13.544893418588947, 24.440241475259107, 44.525322375759, 37.00231444451117, 12.176622633011112, 16.22833590353689, 29.58718542129763, 34.57851325311969, 31.17379003955472, 21.255371032222627, 21.63142631130834, 30.84338526571951, 20.05882259338133, 13.51312614256336, 7.859332542265616, 16.534584760665894, 32.39151927732652, 48.16941215145973, 55.43171974920458, 45.01855650255757, 24.237464743275797, 15.728432766852842, 24.362258872678204, 36.98309875303699, 53.17732180318525, 58.34973173756754, 61.1587881272839, 61.93199319224205, 52.50990306177447, 50.61469224191482, 52.56811103513164, 51.15936825352331, 48.592416240322976, 48.38674676033759, 52.15250061404321, 50.53803343926707, 44.86137144027218, 49.22620850224649, 63.05232409507998, 61.13081378321494, 59.57141276328795, 36.11075185960339, 20.849086046218872, 13.733778096014454, 6.921222700226692, 12.365161161268912, 33.890447155121834, 48.628823680262414, 36.93004085171607, 16.732546783262684, 8.95714904031446, 10.530037130078963, 17.616174413311867, 20.003195539597545, 24.849825174577777, 21.42525084557072, 11.02121985727741, 17.84534869655486, 22.02101572867363, 13.681538008874464, 5.292370232843584, 3.1301656365394597, 5.624249817863588, 33.662706498176824, 35.01079374744047, 24.409776426130726, 16.69574122275076, 19.35928160144437, 20.89565830845987, 23.900244851266187, 24.30128758953464, 25.783582656614243, 26.4108088708693, 22.14446448510693, 19.52195405960083, 18.3326365101722, 19.115208195101832, 25.577487599465158, 19.33803608340602, 6.569288036515636, 0.7626955643776925, 18.17565344995068, 30.132620411534464, 40.198053775295136, 47.192820425956484, 57.496588768497595, 60.79571393228347, 59.69326903743129, 61.66854327724826, 62.27500446381108, 52.657301810479936, 59.44024085998536, 29.113786720460464, 24.734099565013764, 35.14503294421781, 57.516255532541585, 49.103171594681285, 40.341051624667266, 77.10654904765468, 59.00742692332114, 40.70150567639259, 68.25169640202677, 39.28503582554479, 0.2889432679981955, 0.1597767224114749, 0.05202835192903877, 0.058145445260790095, 0.15925428109063258, 0.0785628452356304, 0.08767385231030565, 0.05886619610171165, 0.07007408541657272, 0.03386079897022536, 0.06141551837865865, 0.05584284159985762, 0.060592728456662553, 0.04032771869172012, 0.019355435487664035, 0.05974871789916389, 0.28613748629727676, 0.13127930882957675, 0.08064134136563347, 0.10166155294545236, 0.13306613230416853, 0.22630678549889596, 0.200503442676798, 0.24395581184616014, 0.1381197232272356, 0.3015924827946771, 0.09856121809852701, 0.09082861004337188, 0.21518492019705235, 0.09744849837114734, 0.37654860906543275, 0.2401577011351624, 0.2610096798068093, 0.1603618756897988, 0.2432945707151967, 0.42794725587291105, 0.7186887773775286, 17.151989360009473, 110.0047306860647, 88.14628739510813, 94.00399423414662, 93.05517288946336, 69.65102549522155, 68.72126686957576, 78.55498621540686, 35.14113410826653, 76.8556820961737, 17.223390225441225, 58.048689826842285, 73.20520277946227, 77.26149835894185, 72.29358119349327, 73.58240927419355, 80.40524667309177, 84.05479246570219, 76.87277578538465, 65.47885133374122, 62.72819903589065, 56.614435949633204, 36.33256189284786, 3.34512010216713, 4.429889571282172, 8.49450449789724, 15.848814229811392, 16.163120615866877, 34.36944700056507, 60.87817784278624, 50.500810146331794, 25.68563715104134, 16.089935072006718, 16.123557629123813, 26.904299912914155, 28.467470330576745, 22.52832135846538, 30.713295936584476, 52.49663368348153, 43.67822770149478, 16.83954119682312, 18.873488210862686, 36.53035525352725, 38.636683725541644, 44.20349974786082, 21.977226388069894, 25.44604701380576, 38.84881334920084, 21.877594263322894, 13.13643543950973, 8.629219282057978, 26.245467239810576, 40.24769921456614, 55.343713529648326, 58.036216689694314, 63.783575488675034, 43.502195650531405, 28.970320147852746, 38.23932409286499, 46.95274783718971, 60.85280403014153, 58.171475702716464, 58.67703783896662, 59.570930311756754, 53.72988962358045, 53.014135514536214, 55.112450584288574, 56.472861920633626, 50.935691172076815, 55.53121066862538, 57.090803884690814, 53.690230538768155, 45.70602640028923, 48.446543293614546, 60.712128223911414, 58.00025639995452, 69.81078363233998, 61.477237516833895, 46.93283788619503, 33.792995868190644, 15.982482721728665, 19.15507712671834, 41.88067997655561, 50.41562411092943, 34.88099075132801, 21.177413925047844, 14.955609152393958, 14.60560723658531, 23.799792951153172, 26.32831358140515, 37.24678008787094, 25.190843882099276, 8.365895863502256, 21.503200108005156, 25.070593818541496, 17.783998904689668, 8.470776119539815, 7.959602542461888, 15.862410145421183, 42.46250475606611, 38.08743030794206, 27.893896256723714, 20.1088975321862, 28.465346367128436, 29.080605429987756, 36.14992064814414, 37.463738149212254, 38.002734568811235, 35.162036418914795, 32.00713092280973, 28.350446416485696, 22.088566787781257, 19.797706488640078, 23.433847581186605, 17.96572623714324, 10.254907377304571, 1.2307719766132295, 27.08211664230593, 36.2432809029856, 44.262445126810384, 48.069838862265314, 63.57279123798494, 61.76882651544387, 66.24218771534582, 64.52004755696943, 68.470792155112, 59.23981558892035, 64.07524685705862, 26.942211581814675, 42.37707161134289, 27.1735353239121, 51.34750866120862, 46.58408426469373, 60.71325786652104, 89.59572868962442, 56.9823464270561, 42.63794060676329, 79.43640555104902, 46.425581286030436, 0.27324603449913765, 0.29713544453824725, 0.2452664197452607, 0.247995991019472, 0.23185499342939547, 0.20893454671867434, 0.14095095436899893, 0.10563827705599609, 0.1924750710567159, 0.11614020868775346, 0.23058802189846195, 0.22099526809348216, 0.15253397395774243, 0.2139526830926057, 0.13810276204059202, 0.19176253267834265], [0.052221570794861165, 0.05494222480563387, 0.0967039451784184, 0.03990628606369419, 0.06714860247748514, 0.0484684485972168, 0.033964056131099506, 0.08983802005288102, 0.02700279327860523, 0.06038263267386825, 0.04403923465419681, 0.13986249664618125, 0.09104633223145239, 0.05426308403031961, 0.035685685523335016, 0.01955969751091494, 0.11520175098050987, 0.13128172966741747, 0.08868975384581475, 0.1303907387679623, 0.08493594599947815, 0.49473078681095956, 32.23503239693181, 69.77029692742133, 67.5535302008352, 60.74556250726024, 86.85294858870968, 37.66295533026419, 70.039912808326, 19.099340246569728, 41.40360209249681, 26.153707311999415, 31.071461285314253, 69.7678493684338, 71.48555724851548, 80.04261570592081, 62.97171154329854, 69.4424887626402, 69.2570234114124, 66.64274800208308, 61.65747827099216, 50.93612655516594, 68.32182053596743, 17.42195825422964, 0.33041470233471165, 1.763961204598027, 3.909706309918435, 11.172154622693217, 20.0513602841285, 37.792668111862675, 28.910713849529145, 22.087872528260757, 22.76861163877672, 16.28564271234697, 18.644866981813987, 15.744627252701791, 16.809497802488266, 9.112745542680065, 14.19012527312002, 35.62423675291, 34.0168337668142, 15.19205060697371, 14.642122541704486, 29.76292721686825, 32.20340632623242, 24.351360567154426, 9.937164994978136, 30.984657272215816, 28.516898078303186, 25.34156683952578, 15.580577062022304, 4.840146447381666, 19.360517148048647, 32.60676718527271, 46.62455135776151, 44.20216221963206, 34.97266438699538, 16.62784891743814, 8.839034707315507, 13.611769830026935, 15.676974211969684, 30.861432090882335, 40.54061005192418, 55.43152363069596, 62.489091350186264, 54.27585217260546, 47.73260916433027, 51.04452125487789, 45.50636206903766, 48.31407308578492, 49.35129288704165, 44.03864252951838, 41.095950988031205, 41.97092586948026, 51.43288689274942, 55.94904115123134, 58.473945356184444, 53.03954462851248, 26.725392764614476, 5.763142416554113, 8.515725501122015, 2.737959017676692, 3.9639438640686775, 16.158820717565476, 31.888292912513982, 27.185394610128096, 11.829709583713163, 7.427134417718457, 11.856042415865007, 19.997976826083278, 18.07980052886471, 29.387495594639933, 24.236393936218757, 10.12745976448059, 6.60121024616303, 19.476374157013435, 12.097427037454421, 6.4902434522105805, 1.916462098879199, 16.256663260921357, 41.14470212690292, 32.410911475458455, 20.38018434278427, 10.152859072531424, 25.643736431675574, 26.56336945872153, 23.203373032231486, 25.66111449272402, 26.677879133532127, 30.865993807392737, 27.15243297238504, 25.19684510846292, 23.835508092757195, 24.686152512027373, 10.876267686966928, 12.612234200200728, 12.7553810996394, 0.8858872829906402, 7.093353954053695, 20.629309761908747, 40.427661480442175, 74.729702549596, 52.91910040763117, 52.533358835404925, 50.0702319606658, 59.398887311258626, 53.94216437493601, 52.54258425005021, 36.78656055081275, 20.115806787244736, 27.194616102403213, 6.401689571719016, 22.62954596550234, 30.880404595405828, 70.51103653446322, 78.34396270013626, 57.07399652850244, 51.682443772592855, 55.88114884591872, 28.507998220382202, 0.7028180709288967, 0.18037131086232203, 0.12035132505961003, 0.05222688744505567, 0.13720196521570607, 0.04200066702680723, 0.0651943045217664, 0.06858310977657957, 0.03460277810752873, 0.04590633648237394, 0.03285914283966826, 0.03541024627103921, 0.09604664173938575, 0.06426245049243012, 0.07681756670917235, 0.06615532351838005, 0.08542747567257575, 0.10808625739187964, 0.08559210030662437, 0.05886782020811112, 0.02973359029349541, 0.0255578346250038, 0.05025676594326093, 0.024344937410205606, 0.025504836662402077, 0.010139389140080782, 0.0660826524178828, 0.09242941204818989, 0.10442353739974, 0.03005576857005156, 0.02583236223266971, 0.06054353412060488, 0.0540729410075132, 0.02691391558806983, 0.07319324304379764, 0.13814757818416243, 0.09217382213401218, 0.4996129732218481, 54.21552611935524, 86.26781725114392, 74.88079224863361, 70.29436480614447, 83.85781103564848, 41.77226958736297, 39.86505631477603, 27.748897998563706, 33.7406792948323, 29.072448861214426, 42.62059196349114, 69.31176400953724, 78.44729361995574, 90.74685019831504, 71.90939287985526, 73.75553484885924, 79.82359055549868, 72.38118340892177, 69.23292436907369, 55.49353630312028, 70.26134629403391, 18.25943527683135, 0.24888486751625616, 4.963495183375574, 5.911132952859325, 19.708454916554114, 27.26937451670247, 38.841462827497914, 28.50004561485783, 23.12583169629497, 19.032087287595196, 18.41504158512239, 21.350537538528446, 17.511427517860167, 13.604423230694188, 10.09628378575848, 19.480110214602565, 37.48384814108572, 41.31680004058346, 18.581352041613673, 14.99243236357166, 30.17022417437646, 33.88077459027691, 25.737206512881865, 21.73064462600216, 34.39196925009451, 28.540073402466316, 26.41602170082831, 15.239024912157367, 6.999237172065243, 23.34582174977949, 39.85394424007785, 48.880220151716664, 51.95883750915528, 51.26325614990727, 23.094058536714126, 13.326378176289221, 20.382190635127408, 29.56270787023729, 49.229342476014175, 56.147905318967766, 60.208425291122936, 62.53921139624811, 54.5979219098245, 51.453098866247366, 52.42073189827704, 51.31266232459776, 49.56292044731879, 53.1414831069208, 50.6530765564211, 48.08020568663075, 43.962626995578894, 56.2969083170737, 61.94805922046785, 61.015452954076956, 64.6394484273849, 43.08816594462241, 19.55295647344282, 9.245894320549505, 6.502867110313908, 8.328613735014393, 29.44831390534678, 44.63669807680192, 28.36943264930479, 13.812314733382195, 10.599759221076965, 10.667197512042138, 19.34516106882403, 17.8049777015563, 29.64174755157963, 24.01864943965789, 16.195941048283732, 13.804238573197397, 19.528247502542314, 13.394131237460723, 6.795505342944977, 3.0135871566111043, 15.387129687493848, 49.933164734994214, 34.61164943633541, 24.281014819299024, 15.869397847883164, 23.514809223913378, 24.760148025328114, 21.315010670692693, 22.602348250727502, 23.855798513658588, 26.428208504953695, 25.695103791452226, 22.999825554509318, 22.15162673304158, 26.097250676924183, 17.172073856476818, 20.630004021429247, 19.466868292900827, 1.3901847000083616, 3.583124376112415, 22.621181511109878, 46.049410297024636, 70.33044276698944, 55.93706615509526, 56.7405911414854, 54.75920192656979, 63.92869926268055, 59.14896172861899, 55.45450479753556, 47.22467007175569, 25.486992636034568, 24.228386417511974, 14.26156928462367, 37.45383416452716, 34.81675409501599, 59.27983160941832, 85.51581259696715, 53.768725010656546, 45.845690235014885, 69.95441298330985, 33.67051985956008, 0.5616441849739321, 0.19686360573095663, 0.03541253304349319, 0.1265167853524608, 0.15883564468353026, 0.10898661754664876, 0.1219279952948132, 0.021318922668034514, 0.2275374597839771, 0.06541221057094875, 0.08151689559341439, 0.03938645327223405, 0.09905287800657173, 0.03142687826297216, 0.038469342605000546, 0.06641873519026464, 0.25822516470666856, 0.1512071403164056, 0.23415396200312724, 0.14599044927425925, 0.14557282410321698, 0.11850148319236695, 0.22297726012766364, 0.10369580749782825, 0.1085493422203487, 0.17033370512147106, 0.18868532602585134, 0.21048858671659426, 0.12413842708713586, 0.15480795274338416, 0.14090048449654735, 0.11157369646694391, 0.2239275615542166, 0.14186572463762376, 0.1534504909068346, 0.4186220965798824, 0.3790809586644173, 0.6532870545502633, 72.77060416436964, 107.39134957713466, 82.7376684065788, 83.21388336919969, 97.5753358102614, 61.26002842380155, 88.01775132456135, 27.88331174081372, 48.69122074496362, 34.7679009745198, 39.26570638533562, 77.58138333597492, 84.70323870258947, 93.76925606881419, 79.01075778468963, 80.87463671161284, 83.8930731434976, 77.70089011038505, 73.19412600609564, 62.494566978946814, 78.30780629188784, 22.987821140596946, 0.6170210037981311, 5.812039173418476, 8.885100003211729, 19.549802887824274, 28.572793814443774, 52.969953936915246, 40.5275877829521, 30.15925526618958, 33.50817688049809, 26.69343721482062, 31.004422095514116, 26.723109945174187, 25.974372625350956, 20.24263858795166, 25.911347981422182, 48.48919906923848, 48.50102109293784, 27.815060538630334, 17.113199080190352, 37.0991224627341, 40.63640609864266, 34.43609983690324, 19.75761398192375, 47.38784851566438, 40.76838208783058, 32.86370596578045, 20.399980545043945, 8.802307594207026, 30.229312719837313, 45.03603066167524, 52.917382409495694, 55.78966348401962, 62.86623508699479, 39.08162955314883, 25.61500507016336, 31.600875354582268, 44.13685867863317, 60.037476631902884, 57.8088447355455, 56.4703006129111, 60.165338054780044, 54.44368646990869, 53.59910211255474, 56.49214037003056, 56.88539720350697, 53.705935708938114, 57.8965332431178, 56.24228146768386, 49.853383725689305, 47.46008680712792, 57.54694415676979, 60.5881421027645, 63.060109999872026, 73.99289315746677, 61.94682367386357, 44.53102942435972, 29.697407945509884, 15.351976425417009, 17.009483768093972, 40.32156921202137, 42.629562424075225, 22.706940212557395, 19.49009264669111, 13.978336895665816, 14.438885911818474, 25.338075930072417, 24.619791892267045, 40.317984165683875, 31.505510768582745, 14.335991355680651, 12.472925339975665, 22.673892282670547, 15.871361974746952, 12.883447466358064, 7.382720929961051, 26.043877024804395, 55.941208177997225, 38.3952461519549, 29.089615114273567, 17.52645019562014, 37.90523621343797, 36.698762216875636, 33.075374710944395, 35.64725322108115, 33.533166300865915, 37.295562605704035, 34.31705590217344, 31.523690954331432, 32.28756077827946, 32.39625161693942, 14.748710009359545, 18.601283565644298, 23.63091726456919, 2.1752643729409864, 10.378470863065413, 33.92430505444927, 47.26580396775277, 82.59614929076164, 62.23556110935827, 60.67022162099039, 57.31091945402084, 69.25397180741834, 64.0347562297698, 62.1761058222863, 43.93897510343983, 27.821989405539732, 35.11168887538295, 9.290784866579118, 30.873662041079616, 40.17542954414122, 83.50340920109903, 85.89806325974004, 71.78088818826984, 56.452398915444654, 79.84059795256584, 43.37660920235419, 0.9457219368027103, 0.3373678695530661, 0.310749072100847, 0.16899470600389666, 0.22012401161895645, 0.1430585848227624, 0.20683269256785994, 0.16285221302701583, 0.2380289113329303, 0.16359608440149218, 0.2944318896099445, 0.12892706650159053, 0.36312809694678555, 0.15499323876875062, 0.16709986413198133, 0.14201370218107778], [0.020306918604840195, 0.11512693483382465, 0.013081955839879813, 0.047475947217354854, 0.09771039318894187, 0.022642391268163923, 0.13453087709363432, 0.061503775537975376, 0.061768642776916106, 0.11080016216803944, 0.035642780769135685, 0.07653330212398883, 0.14083493801374591, 0.057835076229586724, 0.10468287348386743, 0.0721123849131888, 0.0396868325169048, 0.10381228350583585, 0.0717614553568344, 0.03572155375994983, 0.13062575922137307, 0.1938518536307158, 12.725940769718541, 59.29440321460847, 71.0532179186421, 74.0154310964769, 84.77014649298884, 59.31264223590974, 48.069175981706195, 40.08983558224094, 24.806867376450572, 45.53192023308047, 18.39048166428843, 64.37264880826397, 63.73618148988294, 67.9552044407014, 65.72675297337194, 67.33481884002686, 68.13338987288937, 69.76198934739637, 64.46591884859147, 59.84453524312666, 56.16749755797848, 7.138721558355517, 0.7237191558364899, 4.133816322972698, 12.702737008371662, 15.184774610304064, 27.584170218436952, 36.704575169471006, 36.490017598675145, 33.12158415394445, 21.21178565486785, 17.163150464334798, 19.63503795285379, 13.949861468807345, 17.310874769764563, 6.453211865117473, 6.33183608132024, 30.62784710238057, 33.58455327249343, 22.59909268348448, 17.42562174797058, 24.972399242462654, 30.373522581592685, 15.793285235281914, 14.117177032655286, 39.62231651429207, 52.00339171194261, 27.658477560166393, 16.769974039446925, 9.274552137620988, 19.480123942898167, 36.20180183841337, 48.31203737566548, 47.94869253712316, 30.154087543487552, 12.953532376597005, 5.506605678989041, 13.668662828783836, 13.884757968687243, 23.110101030718898, 35.12950428070561, 55.91015869571317, 64.36753795992944, 57.914411406363214, 50.363958651019686, 50.35661597405711, 44.00893842020343, 44.46969924434539, 46.57571000437583, 47.29022856681578, 38.28501186063213, 41.351391423133116, 52.70406038530412, 55.706611217991004, 57.30084288504816, 46.74304616066718, 21.077797489781535, 9.39530916752354, 7.754836188208673, 2.690721178247083, 5.373028872474547, 18.57528021258693, 33.23366195924821, 21.238342062119518, 13.942830620273469, 10.963776746103841, 15.985694162307249, 16.71098355324038, 20.300181719564623, 28.895447984818492, 21.806091416266657, 19.459717812076693, 4.398124256441671, 12.110871941812578, 10.65727097372855, 6.9442867271361814, 2.4476862194076663, 33.05604134836505, 40.4437667323697, 27.968219287933845, 10.88741212121902, 15.026951182273129, 33.44497965228173, 23.334778316559333, 24.496878539362264, 31.883099694405836, 28.995980293520038, 30.09883703724031, 21.50775201859013, 23.098104461546868, 23.187032438093617, 25.729022487517327, 24.856018597079863, 7.183062482264734, 7.996276703573043, 2.927932888269425, 0.12126825569618134, 13.416842741350974, 41.52381489353795, 65.41500691444644, 56.57028182860344, 48.20103037741877, 53.587648791651574, 59.36972448902746, 54.398681194551536, 52.389274489495065, 28.5290240856909, 26.87338379121596, 25.454350671460553, 24.017156977807325, 32.78530759196128, 48.91825145290744, 85.43727890137704, 82.29212637870543, 99.30895282376198, 67.44549243680893, 50.339177116270996, 14.026156471621606, 0.7655818159541776, 0.17413563095033172, 0.120273107482541, 0.13287903831130074, 0.20291943884184285, 0.04322297563175521, 0.11573298699072293, 0.057811902069877234, 0.021238797532034018, 0.07013711913098251, 0.047833614517003305, 0.04865875632892694, 0.0573985938042883, 0.04028235096484423, 0.09791309239282724, 0.061530661393678, 0.11871840864900621, 0.14000812996058695, 0.08890749901653298, 0.09425605677308575, 0.11411064259347417, 0.07151177964143215, 0.2247055391630819, 0.027853277279064063, 0.03531147455496173, 0.05173497089755632, 0.048801436374384555, 0.3690952477195571, 0.10769009800447572, 0.05178532202637965, 0.050405023108807304, 0.2007027634329373, 0.16317836729989899, 0.014206655267175409, 0.06462088004956323, 0.18789145975343644, 0.159311844937263, 0.28490350251236274, 26.523322059262185, 82.5609342513546, 83.78571002714096, 85.54013129203551, 91.13787912553357, 64.30711384742492, 38.094031656942065, 33.69889428538661, 30.94504917821577, 34.19343848382273, 31.83437797331041, 67.44506097608998, 76.58977677745204, 75.89872575575306, 76.62390924269154, 72.79043566796088, 78.47465607427782, 73.57925568857502, 69.76776307629001, 61.90333243339293, 61.6044125249309, 6.906439287047233, 2.627626421951479, 8.471680225864533, 26.28184133960355, 24.95423866856483, 31.98082554724909, 32.79666873716539, 32.14471197897388, 28.195577513787057, 21.18697666352795, 20.355736209500222, 21.12952374642895, 14.19048515058333, 14.356506332274407, 6.567980906655712, 10.937380175436697, 32.35638660769309, 42.68361660741991, 29.445232883576427, 19.149242601087018, 27.904078729691047, 30.140151362265314, 22.305277739801717, 23.787131540236935, 37.686340501231534, 41.856090637945364, 28.360662229599495, 19.411857051234094, 10.425803084527294, 22.91778329880007, 41.19863863914244, 49.44252329487955, 56.215817236131244, 41.43035265707201, 20.038314480935377, 12.093989079998387, 16.33345934652513, 25.761621306019446, 41.45577353815879, 52.832820030950735, 61.16136512448711, 64.66470849129462, 57.0531883547383, 53.85418953434114, 54.616007958689046, 47.35564977891984, 46.508480579622336, 52.36143742838214, 53.870828228612105, 44.10048654002529, 45.568406120423354, 57.74565535206949, 59.45079988048923, 61.49095012295631, 60.4044496628546, 37.18247675126599, 19.05950661628477, 5.3108740141314845, 5.666387350328508, 9.548925853544667, 25.535451558328447, 35.901226689738614, 22.53760168629308, 15.578954181363507, 13.402398613191421, 13.249535022243379, 15.768975365546444, 21.87566053482794, 29.023148590518584, 20.513915592624297, 22.20423944534794, 11.347823854415648, 15.26930364870256, 11.990563042702215, 8.513280883912119, 5.1442615351369305, 36.60141683393909, 44.7238649091413, 29.13607166659448, 17.0368952520432, 17.23676746891391, 30.641946061964962, 24.851309791688, 23.075513570539414, 29.926099777221683, 23.643253118761127, 26.72875423585215, 22.711954962822702, 21.753321809153405, 24.09966991793725, 25.869055025039184, 26.823614797284527, 11.585081161991244, 18.23933312969823, 6.02773815393448, 0.7698353812579186, 16.40787749521194, 49.09651925486904, 68.13520985264933, 59.19021329572124, 56.05729856798726, 59.37494908609698, 64.38023467217722, 59.598685003096065, 58.33349312505415, 38.163383083958784, 29.050920932523667, 25.593677182351392, 24.28166397156254, 31.369906586985437, 37.78024596552695, 88.24488009175947, 79.28608463656518, 95.46318654091128, 67.75033904660133, 62.07943116464923, 20.481779613802512, 0.5913139735498737, 0.2321355195055085, 0.1021123573844952, 0.07926718647321386, 0.139401204463455, 0.06435092598680528, 0.09622876382162494, 0.1452899078327802, 0.10266769452080612, 0.06200431057462289, 0.11437216202818579, 0.03436875739885915, 0.036350435336991664, 0.009023780303616679, 0.08151462797315852, 0.023330305665431005, 0.2772096508452969, 0.17693724513294237, 0.19795099093068033, 0.17347431321057583, 0.20062649171919594, 0.06642762947106554, 0.4580246032245698, 0.2164409366706687, 0.10472076419260233, 0.15355308540165424, 0.15931460285379043, 0.27700829229527907, 0.2064946026451165, 0.10220189008020586, 0.1655711969661136, 0.2501837695918737, 0.2709019280249073, 0.14964698693684994, 0.1522745306213056, 0.31857288292338776, 0.14191303822782733, 0.20866378060271665, 31.415190350624826, 105.79012040169009, 100.01955293839978, 93.50677890162315, 100.30196359080654, 72.35052616365495, 75.16216739531487, 48.847731159579375, 34.15821559967534, 54.28475203052644, 24.730418420607045, 75.10553621476697, 80.29532617138278, 80.9254784737864, 76.22695753651281, 84.40960222674956, 80.66926925413071, 82.23111783304523, 74.82412184438398, 67.91798114776611, 69.25390904949558, 12.17847889469516, 2.5080049182138135, 7.413596357068709, 22.42545327832622, 22.64083258567318, 38.04428031367641, 49.37730996839462, 46.00834308132049, 47.01956933544528, 34.423626699755275, 27.263622360844767, 31.71516145429304, 24.77280943624435, 28.550910911252423, 14.38928165743428, 15.100913355427405, 43.12296129042103, 48.018581328853486, 37.2835523082364, 23.616661410177908, 30.702856548370857, 34.42130073424309, 25.93653352029862, 24.823864967592304, 53.56562076076385, 66.65041231339978, 34.89239308141893, 23.54349155579844, 15.063260562958257, 29.427541032914196, 48.42190296419206, 53.81584052116641, 63.028158372448345, 51.358020613270426, 33.53747698568529, 21.19819268103569, 28.617195044794393, 40.23814039845621, 53.02172530081965, 56.314390320931714, 63.53832929365097, 61.111048959916644, 55.922098390517704, 53.62536630322857, 57.99043870741322, 52.8736009136323, 51.09367639787736, 55.50444833693966, 59.36229159755092, 48.181983347862, 48.81573638608379, 58.69878345920194, 63.40767514321112, 64.27794318045339, 72.62371140141641, 57.212283611297615, 38.88819394573089, 21.183593619254328, 9.352918151886234, 22.288572365237822, 34.90820415558354, 37.048108116272964, 19.783923279854562, 19.64919770917585, 17.66591791183718, 18.6544003025178, 22.881497452335974, 30.025561278866185, 38.39782707152828, 26.709267900836085, 27.050518028197754, 8.02378869825794, 17.68666136649347, 16.568644662057203, 13.896501544983158, 9.896895981604054, 45.04863715940907, 49.996805191040046, 35.659702824008086, 18.316641084609493, 24.30549433154445, 46.35559835741597, 31.369126035321145, 34.52761265539354, 42.708437365870324, 34.37637782865955, 36.564876033413796, 28.482900934834635, 31.428753906680694, 31.241731374494492, 34.864218696471184, 29.840519543617006, 12.314207611545442, 16.554932055934785, 6.670714155320199, 1.026869279242331, 27.250158825228294, 53.41627259408274, 74.62140590913835, 60.50808652754753, 59.0216023691239, 59.5700595455785, 72.10187142895114, 61.1608003031823, 62.83018850511121, 34.915699804982836, 36.75238101713119, 28.823725485032607, 30.27171550258514, 39.59518940218034, 57.86982974698467, 101.77602952526462, 87.73585842501733, 102.54632811392509, 75.5647986935031, 74.27390744609218, 24.18590126499053, 1.0280027216480625, 0.39639549570218213, 0.24187078098616294, 0.24491339110799376, 0.3633867588735396, 0.23979394726695555, 0.2728573521298747, 0.2166620449673745, 0.24483906525758006, 0.16706650866375816, 0.2357349070089479, 0.08027411711912963, 0.2144856811050446, 0.12647775317271873, 0.15303570026111218, 0.11631028786782296], [0.05535238444985402, 0.07461134073955399, 0.08393847653942724, 0.010625958393868661, 0.1438655511986825, 0.10458784027686042, 0.11100478425261476, 0.09749353668021579, 0.08296660973780579, 0.08776548408692883, 0.03325440207376115, 0.012610422019215842, 0.06397185036011281, 0.08192327459372821, 0.05454555980019993, 0.03383869733360987, 0.09635893748171868, 0.17420260235667231, 0.037992272841473745, 0.1825728330520853, 0.32074605985995264, 0.45667432729275, 5.751191444935338, 37.13271756325999, 67.3197961622669, 59.509851163433446, 63.265987365476555, 86.1999680919032, 37.22702703168316, 56.37609312611242, 18.039929636063114, 47.61928796768189, 18.782257803024788, 32.405561362543416, 62.23245066981163, 78.75372486729776, 74.25523696407195, 61.7484615695092, 65.56537489737234, 65.61243157232961, 65.6102664239945, 65.11470633168375, 34.8084072912893, 2.1360742565124267, 1.0133228835559662, 11.038867581275202, 14.304773211479189, 21.36335780543666, 31.153803602341686, 41.05717443650769, 34.68233839158089, 28.82888536299429, 16.119268517340384, 21.362777294651156, 21.08938809364073, 13.662495882280412, 12.159709372828084, 8.166493840755956, 1.0728003565342197, 17.989731142597815, 28.855522178834487, 36.720409777856645, 20.709182946912705, 19.41050579470973, 23.455873650889245, 8.623065083257615, 22.375966695047197, 38.316653620812204, 48.619123658826275, 33.252748212506695, 18.317462821160596, 11.1013646664158, 17.931323128361857, 33.69048864610734, 40.6758023846534, 42.12893462950184, 30.250877911044707, 10.883550547784376, 7.180760050973586, 12.941261241512915, 12.951745736983515, 17.46565345794924, 30.669232030068677, 50.92534003719207, 60.80708096104284, 59.46324163867582, 53.78534801544682, 53.54051366929085, 41.905618406111195, 39.143575545280214, 49.88482544499059, 47.747486714393865, 40.34047895862211, 47.41865088862758, 53.432130736689416, 59.5674943154858, 55.662664982580374, 30.662340425675918, 6.79857018493837, 6.497002186313753, 3.142753012718693, 3.1846346105298693, 11.749919749075367, 30.555534285883752, 26.782651524389944, 15.333624635973285, 15.838234616864113, 17.565324806397964, 15.289068472000862, 19.76314256268163, 21.56744068668735, 32.866822288882354, 25.37923336029053, 21.86172631479079, 10.908922399244002, 3.404913203370187, 8.11866642005982, 4.346739245999244, 19.01533288340415, 42.09280567784464, 31.114625007875507, 18.606888632620535, 4.666014784766782, 25.19383272817058, 28.72649777320124, 20.595210636815718, 28.634288734005345, 20.45292862000004, 31.960180151847105, 25.06984660702367, 28.525701838154948, 27.010888361161758, 21.769136805688184, 31.097044944763187, 30.228863608452585, 15.674811024819652, 4.860943344331557, 6.243378298897897, 0.2804411629274968, 5.248423997432956, 35.623424822284335, 59.37677298822711, 59.31428570901195, 57.281744864679155, 56.43039049640779, 55.99110072658908, 56.65325172485844, 62.88399557913504, 24.66288108979502, 33.36250005229827, 29.74003234217244, 35.99643830330142, 41.54098703015236, 70.78557106756395, 76.4745375417894, 79.20753525149438, 86.29826268842145, 51.619721151167354, 48.32427124823294, 4.41966591342803, 0.5219075107766736, 0.20412342262364205, 0.037226667552585566, 0.11832780339905333, 0.11067504468824595, 0.020407622777706674, 0.011284505768168357, 0.12915402771003787, 0.12936241894720063, 0.021345193738177903, 0.028564381157799114, 0.04787783694243239, 0.0480220721463763, 0.036366569148677017, 0.029676899787098653, 0.025906462087145737, 0.07844043970708886, 0.05564186609380188, 0.05169186313005705, 0.11180258821696044, 0.05322909515891826, 0.07278325576936046, 0.10220211990658315, 0.15050738028460933, 0.050663489683140675, 0.024329037255337162, 0.07173664176896696, 0.09320800252739461, 0.014600517348416392, 0.041843308736720396, 0.05551667583565559, 0.10401053939976039, 0.020286902642598557, 0.08592802986142137, 0.07366237996686852, 0.06322365824974353, 0.23848059677308608, 0.35121089448371245, 8.322865501526865, 66.67277766812232, 86.58468200314431, 68.32966527631207, 84.82564803092711, 81.77444411862282, 41.4356243225836, 38.321234949173466, 25.44104991420623, 41.716779816535215, 27.75689571134506, 45.658867743707475, 72.0645304649107, 85.94258216119583, 80.6758431465395, 69.76042824406778, 68.93287089563185, 77.40697122389271, 69.0608186106528, 71.43212672202819, 39.905617544727946, 2.8241935516557386, 2.4903978888065588, 21.95256252442637, 24.84280413196933, 25.259310814642138, 30.98671259418611, 40.05089036880001, 34.327979703103345, 29.233164056654903, 17.8264428723243, 20.892061495011855, 23.044664129134148, 15.910245410857664, 13.371345208537194, 5.9363724243256355, 4.8175913480020345, 21.986985245058616, 34.09080182352374, 43.987428142178445, 25.35899196901629, 22.23717558768488, 24.101944892637192, 18.46943505348698, 28.046080297039403, 34.0039840821297, 46.4209528892271, 32.334448791319325, 20.345822418889693, 10.970235909185103, 19.317424028150498, 39.2092477890753, 42.95475436795143, 50.13042465333016, 41.04191249416721, 18.179014921188354, 11.248172117817788, 15.319792397560613, 25.30695192275509, 32.224742058784734, 49.35683519609513, 57.08116662117743, 61.043125275642645, 59.238666334459865, 55.24000998466246, 54.852036583808164, 45.48679336424797, 43.430922262130245, 55.217173945519235, 51.93900208319388, 45.59576465237526, 49.54772518527124, 61.455629179554606, 59.033283187497055, 62.572186762286776, 52.829380112309615, 27.45961731480014, 9.512574307380184, 3.218540558891912, 9.539927936369374, 13.018557429313661, 32.633076483203524, 30.251542752788914, 19.241641875236265, 21.18244436479384, 17.9562674414727, 13.07143392101411, 17.962660904853575, 23.01049440137802, 29.476831497684604, 24.84322382557777, 24.44744686926565, 16.250246263319447, 9.208832825383833, 9.904552448180414, 6.226294415612375, 20.941765769835442, 48.177147065439534, 33.18819776658089, 22.87911461245629, 10.846205661373755, 22.339249387864147, 27.965161800384525, 19.635800853852306, 25.000910951245217, 20.082468601965136, 27.629554002515732, 26.293594721824896, 26.42405471494121, 29.562050873233428, 22.154019378846694, 30.805473596818988, 32.80836720620432, 19.498468868194088, 10.101273040617667, 14.523196278079865, 1.3414339288588495, 6.504650808149769, 48.55798567495039, 62.46025800704957, 64.95676032958492, 60.98725503490817, 64.735213095142, 60.83894629632274, 64.41737951770907, 63.523145798713934, 33.202024121438306, 33.41251811673565, 27.677920749110562, 30.281160569960075, 33.89198472422938, 62.49364914432649, 84.43445436416134, 89.08034493846279, 94.18309750095491, 56.355677189365515, 63.12289145685012, 7.357596187822281, 0.6289195137158518, 0.3134962940408338, 0.03702733913556703, 0.15018953040482538, 0.17189456330191705, 0.06688927405423696, 0.034017115380735166, 0.04192671655947643, 0.16277348983191675, 0.17081604940035652, 0.12346194846735847, 0.04211970559892155, 0.07896835855658978, 0.009970508887612773, 0.0159952349983336, 0.11543065805228488, 0.18447594867358286, 0.1547476463019848, 0.12077905493037355, 0.33965163894238015, 0.3013856084116044, 0.25008250809004234, 0.3340719447981927, 0.2491289890942074, 0.19829049045520447, 0.14445899354834713, 0.23029724556592204, 0.17679490599661105, 0.13989347724183915, 0.10118758200757927, 0.20262703840290347, 0.11352930443301318, 0.29384779353295604, 0.28893594419763935, 0.1926167207139154, 0.18930378880712295, 0.37731380832772105, 0.5652588942358571, 10.043020940596058, 90.3961746154293, 103.96122117196362, 80.13852550137429, 92.92026688975673, 91.34839273268177, 59.54614093226772, 68.89097998219152, 24.38027039650948, 55.06166373529742, 26.577646886148763, 42.435377643954375, 77.08442687988281, 93.05292144898446, 86.39422739705732, 74.12048785917221, 78.74733140391689, 79.20892377053538, 78.61656742711222, 74.90110228138586, 50.63435508358864, 4.328633094987562, 4.5788342241318, 18.272669353792747, 19.60171937942505, 30.38428164297535, 42.524360533683534, 53.02676946886125, 44.40071652012487, 39.76660874582107, 28.737099939777007, 32.79311310860419, 35.548636990208784, 25.101282442769698, 24.49672164455537, 15.327083103118406, 9.342447384711235, 29.041075783391154, 41.248813598386704, 53.465180627761356, 32.01100426335489, 26.093908817537372, 29.411149447964085, 15.57940427334078, 34.92737670098582, 49.69914044103315, 60.46658785112443, 45.20237053594282, 25.852637944682954, 15.69094079156076, 26.19188766325674, 42.2167133515881, 43.3791155968943, 53.29010171274985, 51.79284672583304, 32.98559950244042, 22.31941003953257, 30.5366127721725, 38.62473226362659, 46.64544974603961, 54.423678459659705, 54.7944797238996, 58.483876797460745, 58.55667598785893, 56.060671806335456, 60.27042619643673, 51.547800571687766, 50.29139480283184, 58.87940076089675, 59.997895994494044, 51.95668412793068, 54.10448381977697, 64.75879438461797, 63.165562921954745, 71.74990146390854, 61.014990114396625, 34.3531064064272, 22.217249947209513, 11.926221462988085, 16.224850877638787, 27.106431415004117, 43.276169069351695, 23.676193183468236, 20.113476899362382, 21.57275942064101, 20.86173765120968, 20.45020845628554, 26.543035891748247, 32.56167365658668, 39.7888054386262, 30.4938099076671, 31.199503137219338, 16.267552741112247, 8.845569376022585, 16.17472985098439, 9.807321794571417, 31.407890819734146, 54.21407876476165, 39.174613260453754, 26.824585583902177, 11.041579900249358, 34.42892582185807, 42.37773841427219, 30.987755944651944, 37.90142759200066, 29.471465695288877, 37.7775473748484, 32.177053882229714, 34.67403865629627, 35.713227487379505, 27.93379068374634, 42.4982806944078, 37.54235421457599, 27.81501739255844, 8.976205875796657, 12.592430153200704, 1.5676185080120641, 12.877040274681585, 51.73499176579138, 70.48766705297655, 70.40583072170135, 67.1154720552506, 67.20380383153116, 67.9702506526824, 66.26227025062808, 70.44674888733896, 31.49506549681387, 42.60988781529088, 32.43643826053989, 45.488644722969305, 51.63749341041812, 88.54066602645382, 93.08502997121504, 88.76868909405124, 99.1358821622787, 62.60425213844546, 81.6830764278289, 7.5009975510258835, 0.7188835475713976, 0.4899042183833738, 0.1356723787443292, 0.2540697505877864, 0.16373165132057282, 0.14600457593558297, 0.12599584556395008, 0.2742788742386526, 0.3673962792081218, 0.2655922032652363, 0.29326167498384753, 0.15540111930139605, 0.1596096539569478, 0.10180590689302453, 0.1275307716681592, 0.29008182787126113], [0.0418263781935938, 0.08413489382233351, 0.04756950570510761, 0.10641257744282485, 0.10684892580273653, 0.019160852985336416, 0.004921715111366564, 0.04722843953077832, 0.06406533606951276, 0.07827986767815967, 0.10036662686616184, 0.036630651147495356, 0.16175774917487176, 0.010463841740162143, 0.10644914281945075, 0.09343864095787849, 0.0676279207090697, 0.07153633275940534, 0.08881038971125119, 0.01499282522878099, 0.05399148670896407, 0.07252126902101502, 0.2101680402073168, 28.953142127683087, 74.57291756906818, 60.98556449336391, 53.56449896289457, 100.2966840805546, 50.91086649125623, 51.092311413057395, 38.01869469304239, 38.54787734247024, 27.424174777923096, 33.50577246758246, 61.97700631233954, 68.50912155643587, 80.82133170097106, 66.69751213442895, 82.16841482347058, 65.16156296576223, 76.34692715060326, 57.70768680880147, 24.436854508615312, 0.4197725461375329, 7.51038182166315, 12.68994321746211, 19.877697344749205, 28.425244054486676, 28.621127220892138, 34.313757188858524, 35.558121281285445, 27.37386645809297, 18.533967848747007, 18.87949728196667, 22.238856323303718, 15.211077044087073, 12.401444065955378, 8.645965841508682, 1.7499587108050625, 6.815626611632686, 25.42396406973562, 41.08432116047029, 28.77869667545442, 16.489657932712188, 10.85269522282385, 12.115957294740985, 29.993038946582427, 25.715025509557417, 24.7763160351784, 32.01985705283381, 23.90042135792394, 13.698098255741982, 18.926400984487227, 29.80727549522154, 33.710233857554776, 36.02369877599901, 32.52812562450286, 15.130401734382877, 6.354586808912217, 13.39777708053589, 12.568365431601002, 18.109536017141036, 27.02777808712375, 46.9775725180103, 62.872538335861705, 61.9532092925041, 54.85617468433996, 53.3503963870387, 42.276690313892985, 37.13400017830634, 51.05390748670025, 46.09257990314115, 41.01205933478571, 47.17150626644012, 59.04589752997122, 57.371971145752944, 42.43783304768224, 14.657735536175391, 6.0128370696498505, 7.277893135624548, 3.840870429431239, 12.330429553985597, 30.68613548432627, 32.67800919471249, 27.064507161417318, 16.526855730241348, 26.75521258384951, 22.894733490482455, 17.886843450607792, 20.164801113067135, 26.78934701027409, 36.05890597066572, 33.62844851709182, 20.169256925582886, 16.706310049180065, 4.0015314471337105, 2.9739138532069425, 10.837195977087944, 39.59551888127481, 32.137549731039236, 24.336051556371874, 6.3607836634882045, 11.317354882917098, 29.250781382283858, 15.133363123862976, 22.128886791967577, 17.720617325075214, 27.41649869949587, 29.096265492900727, 28.169691831834857, 31.372915044907604, 26.425707993968842, 25.722781996573172, 30.679820468348844, 33.079226478453606, 21.564036069377778, 11.817481594700968, 12.851145767396497, 1.9829190618568853, 1.229116736400512, 28.18092550000837, 42.517727805722146, 52.01220527771981, 53.35626425281648, 62.61119865602063, 50.977660532920595, 65.47840810591175, 64.06299729501048, 24.39476747666636, 32.85780279867111, 39.69797903491605, 41.96181420356997, 47.16793690958331, 77.12598831422868, 64.1490815531823, 27.534465943613363, 42.471498750871234, 58.33646235927459, 32.32245614451747, 0.8329445400064992, 0.17592970161668717, 0.09087131944515052, 0.1429589167838135, 0.11873972887593894, 0.10342706385399066, 0.027685500193207015, 0.05166776966483844, 0.09485745877628365, 0.06343343610604925, 0.01797876591163297, 0.06476106647882732, 0.08419219719906969, 0.05983367321952697, 0.08011422690845306, 0.046273863333607876, 0.008469459191415339, 0.10078368513214012, 0.09681343446455656, 0.06028226749490827, 0.12177239517651259, 0.03585087706244761, 0.13071658660567578, 0.0611530643166794, 0.013919117571335408, 0.03223640911821877, 0.05658806511952032, 0.05974422862392761, 0.12698068989500885, 0.07229563314467669, 0.006501895944482737, 0.11627657233827537, 0.05846311510991185, 0.04446268592390322, 0.10600630569482043, 0.12519450993427347, 0.06288934131002714, 0.2799011322279131, 0.11680956268983504, 0.9679425315510843, 48.656366563612416, 93.21122830913913, 71.58727999656432, 69.04937313448998, 97.25971837197581, 50.44180593182964, 41.08074788124331, 34.7592717601407, 32.39616924716581, 32.73824503344874, 44.043192478918264, 64.96008257712087, 78.4713299043717, 81.52815849550309, 75.94001262418686, 87.41230995424333, 72.21589472986037, 75.44471140830748, 64.12611215345322, 31.844252540219216, 1.2079150998784651, 7.818052047683348, 22.44162521054668, 21.4585066610767, 34.43939070547781, 28.266741075823386, 33.567016355453, 34.38980017938922, 29.581582315506477, 20.107238369603312, 19.472993073924897, 20.945246873363374, 15.7341908062658, 12.580955259261593, 8.003902771780568, 2.824473265678652, 10.511790264037348, 28.057374761950587, 49.223266724617254, 38.43006895434472, 17.9916746770182, 17.903754749605735, 21.07411438418973, 28.53486841724765, 27.420538740773356, 27.920988067503902, 30.467604552545858, 26.467375332309356, 14.440339149967318, 18.733361536456695, 34.89146740205827, 36.832695468779534, 45.50405963774651, 34.09646964842273, 19.277523717572613, 11.182889169262303, 13.460199640643213, 22.056699491316273, 31.287126925683793, 40.92739497461627, 55.512069502184474, 64.41399843462052, 61.15899209053286, 55.56588834331882, 57.24535703659058, 48.21120500564576, 44.8402573216346, 54.22536734611758, 52.824383012710086, 44.90779269126154, 54.66088771820069, 61.407886089817175, 65.27517834017354, 57.03277634036157, 32.68839955329895, 10.65026169823062, 5.316159898234952, 9.513112652686335, 13.3893665382939, 28.605861356181485, 34.63361078693021, 30.75310014909314, 21.599845347865937, 25.740444429459114, 24.111678254219797, 10.027118671324946, 22.44733618151757, 22.99196904705417, 30.863887494610204, 26.308484038999005, 23.2319769167131, 24.896934801532378, 12.753793520312156, 8.457324351033858, 15.968775999161506, 43.3897412976911, 36.0659780040864, 27.99313614445348, 12.904237989456425, 12.331327776755057, 24.498172921519128, 18.386753451439645, 18.782763788777014, 16.32654420791134, 23.828547846886423, 29.929355344464703, 25.3321276557061, 29.560807481888805, 25.101066712410223, 22.231107681028305, 33.477217612728, 34.748799031780614, 24.699264995513428, 11.091962745112758, 15.240539927636425, 5.0098987836991595, 0.48089952899083016, 34.099584010339555, 56.96531941813808, 62.1361368702304, 61.61179834796537, 66.37841163143035, 58.0491408994121, 68.6365750528151, 68.44505356204125, 33.9979200978433, 32.305876285799094, 30.534280923105058, 32.375823913082, 41.20281988574613, 68.5141892586985, 76.05147069500339, 40.930721144522394, 49.59573891855056, 70.36368093182965, 45.12996750493204, 0.64091436685093, 0.23905375311451577, 0.07196624598075306, 0.1108059001665923, 0.17955600944978578, 0.19803340666957442, 0.07560919324356703, 0.017788234099204984, 0.18521122454154879, 0.1605374323985269, 0.06815660564649491, 0.13641102539916194, 0.08998186072154392, 0.03895722186913894, 0.02624696518685068, 0.038807099279496944, 0.1337301313516594, 0.1099440206082598, 0.1966017262349206, 0.19243351844770296, 0.2706577604816806, 0.25346915297690903, 0.2705027349293232, 0.2596753078602976, 0.15902753438680403, 0.15308324367769305, 0.11756279565874608, 0.16022791755535912, 0.18114928847118733, 0.1460718384553348, 0.08229354020929144, 0.2422188760171975, 0.15656943402944073, 0.18119816488075643, 0.2479608888707815, 0.2682456866868081, 0.14209849279253714, 0.3102677543797801, 0.21813468046246037, 0.47637844578393046, 62.02725971898725, 111.3827613092238, 84.46420161954819, 78.84352361002277, 112.20276417270784, 68.8614288453133, 70.03028731192313, 48.54524973900088, 46.1410564761008, 36.81192651871712, 40.88280939286755, 77.97529128289993, 81.91889716732888, 94.1479059957689, 75.91781200901156, 91.78183032620339, 75.50556305916079, 84.1811006299911, 68.35574903795796, 45.449958385959754, 1.1899007568436286, 12.278147301366253, 17.960933100792673, 26.174034995417443, 41.03455412772394, 39.55441244186894, 43.630704264486994, 43.21162254579606, 39.733703982445505, 30.17135773935626, 31.353399292115245, 34.608076157108435, 27.180193547279607, 22.299515778018584, 17.78207890449032, 9.855053117198329, 15.824645565402125, 37.92973533753426, 57.68846327258695, 45.62264857753631, 25.815528400482673, 17.011899948120117, 18.16509246826172, 40.3885672169347, 34.1596943332303, 33.524391958790446, 44.987891412550404, 35.47275873922533, 19.877471808464296, 26.165407742223433, 37.285819438196, 38.48283660027289, 45.33723338957756, 51.35721260501493, 33.17071576272288, 22.03827807980199, 29.61096871283747, 38.071070101953325, 46.619483655498875, 47.62308482200869, 58.298125113210375, 61.181302532073, 59.496228771824995, 56.82356888248075, 61.11280618175384, 55.55735326582386, 47.93626254604709, 60.731594947076616, 57.32184717732092, 49.615503741848855, 55.56039310270741, 63.75110218601843, 71.24302141128048, 62.2500934908467, 37.74142234556137, 18.0474409749431, 16.42292566837803, 18.333250361104167, 29.592400212441724, 41.63750871535271, 32.486262167653734, 35.075728585643155, 24.455587748558294, 26.68133866402411, 26.15095184695336, 23.45697387572258, 30.534273078364713, 32.339139946045414, 41.632060543183364, 40.208785380086596, 28.94197710098759, 31.539825624035252, 11.284541314648045, 11.668413877487184, 22.309172653382827, 53.90647472873811, 44.248732520687966, 33.2749919737539, 14.059052409664279, 16.142643882382302, 38.93736085584087, 25.69272291275763, 32.63951897621155, 26.72591247866231, 36.65566321342222, 37.51236769460863, 34.77714992338611, 39.1719852724383, 35.94789505004883, 34.44080275873984, 41.19792084540091, 40.15976359767299, 30.847782242682676, 21.02478273453251, 18.798465036576797, 3.4831924351953694, 3.7045342355005206, 47.49902809819868, 57.89905140476843, 70.62964116373371, 63.795001352986986, 77.66226260892807, 57.324051549357755, 77.54342263744724, 71.73247829560312, 32.746821295830514, 37.16285313329389, 48.32896240295903, 50.18332173747402, 64.75102809167677, 90.39713167375135, 82.81785734238164, 47.487563010185, 55.622476377794825, 86.03801342748827, 49.249774102241766, 0.7813686204533424, 0.3257409224827444, 0.09406561497598888, 0.22657978859159256, 0.25784613504525156, 0.20569715108121597, 0.08715979199135497, 0.1012018848691256, 0.26538869966903045, 0.30114707927550044, 0.2435182530673281, 0.29681843735518, 0.16887230047535512, 0.15946233524910866, 0.12259636104347245, 0.2097123711099548, 0.30503589479673293], [0.038451665126147776, 0.005704043620836831, 0.05581728873714324, 0.06920787746146803, 0.06510416661659557, 0.07852516903151428, 0.04688681028182468, 0.08040169374116006, 0.04183410035987054, 0.012741757260124772, 0.11079028729469546, 0.020824930022260355, 0.18980701664282432, 0.11693520110941703, 0.08769513423284216, 0.06939926920759101, 0.08737633440403209, 0.05841166464491718, 0.11521594658974679, 0.04293870338569245, 0.05981476233911611, 0.24770181325654833, 0.442393283930517, 4.586948137129507, 68.24941358258648, 64.24822730402794, 54.77691927263814, 80.41763351809594, 86.02259066797073, 48.47027755552723, 48.745004284766416, 36.33472311881281, 36.05020615362352, 37.886640256451024, 76.13729215437367, 71.53330818299325, 79.53433928951141, 63.12369554273544, 66.90388371867519, 72.54887257852863, 73.29744908117479, 54.40687894821168, 12.17101658544233, 2.0060722001137274, 11.998004759511641, 17.900095178234963, 31.374093717144383, 21.378910003169892, 34.863873527896025, 34.71146199011034, 34.79770314308905, 31.026995335855794, 23.685926545050837, 20.04585719877674, 24.817034159937215, 17.280756850396436, 11.67356198833835, 6.713351789982089, 2.707708473167112, 1.9534301926051418, 12.80835270881653, 37.55294069167107, 39.63399341029506, 19.5100143647963, 4.955617593180749, 18.065978096377467, 26.45349406426953, 23.243373363248764, 23.824537223385228, 33.7867122311746, 26.073320296502885, 14.489667857846907, 16.29191654343759, 24.103492267670173, 18.496542553747854, 27.905063244604296, 39.069160338371034, 26.14945742391771, 9.364730369660164, 12.560608944585248, 15.387436612959831, 20.160586526316983, 29.426174086909143, 46.06794349608883, 58.8990871367916, 64.32536855820688, 58.49152149692659, 59.21688541289299, 39.396717471461145, 35.29748370570522, 53.99021733191706, 45.48986850246307, 45.439975953871205, 51.863057151917495, 64.72221828276112, 54.202417558239354, 26.912460404057658, 9.035031622455968, 8.347999068998522, 3.4947403832789394, 15.659238234643015, 31.948169854379472, 27.199419044679214, 14.639240580220378, 9.761604609027986, 9.560191881272102, 18.537272445617184, 21.953592146596602, 21.82919025421143, 19.733201149971254, 24.543705755664458, 43.94354858706075, 43.512911565842174, 20.847522981705207, 22.305083582478186, 14.141428066838174, 9.210741058472665, 30.35382247740223, 38.77988553816272, 26.693586264887166, 10.690079639034888, 5.6108554140214, 24.141296071390954, 17.901105188554336, 16.19666374498798, 17.54626600973068, 18.487477956279633, 24.064297983723304, 18.883027415121756, 25.452405175855084, 26.547978078165364, 33.74738262545678, 35.635729297514885, 39.08802693889987, 39.57531083014704, 24.076726013614287, 40.50625793395504, 34.100937228049006, 14.022603784838031, 0.7399227734534972, 12.489991572595413, 35.37124779916579, 34.31442006941765, 44.91638660430909, 59.6420350382405, 58.52227680144772, 63.823332632741625, 52.50882048760691, 25.825873651812156, 40.177284825232725, 44.67227005189465, 39.75619093064339, 64.97361475421538, 80.19152456714262, 50.71035100567726, 37.04491138458252, 61.51643376196585, 33.56537680472098, 0.8738082214709252, 0.06847376604714701, 0.11892656239891246, 0.037429500821857684, 0.08366689837026982, 0.08597705182769606, 0.0772734196676362, 0.013918621529404436, 0.04842299277022962, 0.08472984536520897, 0.08515844091532693, 0.04229487160280828, 0.06319212990121977, 0.06997925905330528, 0.08355537895113231, 0.060730172291157715, 0.08019758493549402, 0.12080930008162415, 0.014956330715288079, 0.05873662382063847, 0.10821984780411567, 0.04760546204183371, 0.0779474851104521, 0.03324768348266521, 0.19328648074259683, 0.05595182909840538, 0.007818704846525385, 0.09478897051585299, 0.023380072652212074, 0.04182400715146815, 0.08855668437336722, 0.15883690106772608, 0.04095449352697019, 0.0528682754074614, 0.03280534814562529, 0.07365867976219424, 0.10180797533042009, 0.06926080647615657, 0.02359132905821166, 0.12031236182778113, 0.29606739539773236, 10.31482550405687, 87.95598183908771, 77.78679001715876, 63.36638435240715, 96.85825594009893, 73.96429123417025, 41.24740546749484, 44.34426184623472, 35.26843070983887, 30.94850282515249, 48.78362001911287, 77.12980085803618, 82.35722203408518, 83.44582096222909, 73.92221989170199, 72.29496186779392, 79.43552694013043, 72.83281295530259, 62.65254436000701, 18.934661496070124, 2.1478894160639856, 19.623070801458052, 26.443270406415387, 31.6819703578949, 22.159628368193104, 33.72648815954886, 34.1100057478874, 34.92603132801671, 30.611484935206754, 24.055411854097922, 22.185288513860396, 24.932083160646503, 20.49174439522528, 13.176892726652085, 5.91696894937946, 3.5030832646354555, 3.4384627063428206, 18.928779901996737, 42.70414237053164, 50.95716222640007, 26.386866723337484, 15.56880504854264, 25.02155830783229, 24.502971941424956, 26.225237615646858, 22.544548203868253, 33.26155001117338, 24.710577111090384, 16.7700622927758, 13.683246201084508, 27.534479671908965, 21.811823960273497, 33.219859138611824, 43.36009602392874, 23.1534981343054, 13.360561632340955, 18.089414258157056, 22.551173087089293, 31.71059189304229, 43.606773884065696, 54.096137016050285, 62.74333154001544, 62.20680621362502, 57.01431766633065, 58.81047687222881, 47.8471423733619, 42.52548625392299, 59.857302558037546, 50.076040990891, 48.51699690664969, 56.010218358808956, 70.00861229435091, 65.58410813731533, 40.68801272299982, 18.05304604191934, 12.04103414089449, 13.916038870811464, 13.866200254809472, 32.63160363320382, 31.820926204804454, 19.737027422074352, 13.907566551239261, 15.24178724135122, 23.057902128465717, 22.860891280635713, 11.875127688530954, 17.1080490081541, 18.95062162030128, 39.52131155998477, 39.98672431515109, 26.548662531760435, 28.932924270629886, 21.752254924466534, 13.958584820070575, 31.178704769380634, 44.201165937608295, 29.012636638456776, 17.201774043421594, 7.996700809847924, 20.27131307509638, 18.36515688127087, 16.38909326445672, 14.285078010251446, 16.155900512972188, 23.446863966603434, 19.192386711797408, 24.513852596282963, 27.52883145886083, 30.082570968135713, 33.20889219161003, 35.62542915344238, 36.72766616267543, 25.98803031829096, 33.51640209074944, 33.096198574189216, 21.085249993108935, 1.173496301616392, 9.748034188824317, 52.70157360261487, 48.84023943255025, 57.64687045927971, 68.33886715673631, 63.97140602911673, 68.41525923821234, 58.736963810459265, 31.07512870142537, 35.330204117682676, 31.113293363202004, 35.7232883668715, 52.378185949017926, 85.98236283948346, 62.322045449287664, 38.28050897967431, 62.16816302268737, 52.94898102360388, 3.3896220884015484, 0.18771755779462476, 0.05776469190154345, 0.09165602330599101, 0.251872641064467, 0.04532697482875759, 0.13829531057948066, 0.050313027440420086, 0.09026335206844154, 0.014934984632887909, 0.1075230218890694, 0.10763394375962597, 0.050589274915476004, 0.05271066047791993, 0.06156830312383752, 0.08451383155319961, 0.001956186841257037, 0.07245958362135195, 0.23765316052782923, 0.17415280664159408, 0.24042665928361878, 0.24372402428378984, 0.18941738432453525, 0.23742327286351114, 0.30813876539468765, 0.2583767581851252, 0.13457285871188487, 0.14752469356021575, 0.2541403838944051, 0.07945508485840214, 0.16423449611231206, 0.22615601939539756, 0.19009307387375063, 0.20671972524254553, 0.1945832071285094, 0.2777805089229538, 0.15042326383052335, 0.18842995827717168, 0.1287749367615869, 0.2327278433668037, 0.4551733159009488, 10.400851907268649, 108.60370712895548, 91.41125263706331, 74.83467302014752, 103.08277499291205, 99.79078462046962, 67.38177745572983, 60.282809119070734, 47.8758188216917, 42.48838455446305, 48.36098463304582, 89.14984933791622, 87.30078912550404, 93.20989470328055, 75.89778438691171, 78.29126173450102, 89.34184151311075, 81.67635348535354, 72.06038844200873, 24.068290956558723, 3.2839017097027074, 16.936815977096558, 25.87711157337312, 43.28724976508848, 30.31134516962113, 45.84836921384258, 46.60314698373118, 45.902007625949004, 41.29041425643429, 33.16569905127249, 34.700393061484064, 39.224850977620775, 30.575216739408432, 22.43519252346408, 15.3641200834705, 11.358057318195222, 7.79395055386328, 26.183264332432902, 53.85292260877548, 57.034764982038936, 34.78368066972302, 12.273507137452404, 25.835471691623813, 33.574119767835064, 31.40620420056005, 32.44023707605178, 48.41015546552597, 37.53153239527057, 24.10201745648538, 21.393436501103064, 30.356160210024928, 19.55024415446866, 29.79583590261398, 55.007460501886186, 40.004869199568226, 27.26404597682338, 32.807669024313654, 44.40006148430609, 48.76351787197975, 51.53807701603059, 60.397299182030466, 58.92470805875717, 63.97703070794383, 55.34049326373685, 66.25440197606241, 53.80176705698813, 51.55483338140672, 64.3843178595266, 58.80361272442726, 53.65053615262432, 61.37265143855926, 71.18195795243787, 71.0286795708441, 48.23445681602725, 25.387715485788164, 15.639875454287376, 21.1343482617409, 36.20764224759994, 47.36773460142074, 29.892210498932872, 17.776599353359593, 15.141009784513905, 18.646169208711196, 22.122628650357647, 23.996574340328095, 28.161917694153328, 27.300292599585752, 27.847718192685036, 54.69311783390661, 52.2384750458502, 33.218266656321866, 40.225400540136526, 23.171352763329786, 15.709264143820732, 42.26908876049904, 53.86900040411181, 36.901384015237134, 19.693759756703532, 9.931332430531903, 33.00134781868228, 26.88862219933541, 24.552803693279145, 28.728117712082405, 28.259504302855465, 34.172979401003936, 28.55351732623193, 33.661012034262384, 36.082855962937884, 40.84306793828165, 45.8968222525812, 45.492425887815415, 47.8604039069145, 32.663943575274565, 54.553199045119754, 43.025855172065, 21.529570202673636, 1.1957226573459565, 20.52332143629751, 56.142096288742565, 51.10705560253513, 61.37544416612195, 74.95932594422372, 69.76293856097807, 78.25516023943501, 63.33723721965667, 31.89838517096735, 47.09969943569553, 53.29648340902021, 52.91871209298411, 78.41196090944352, 97.69777651756041, 68.37982454607564, 52.89369913839525, 79.60315335181453, 64.23039620922458, 2.368520777071676, 0.3836655045949644, 0.13680868631889745, 0.16722275995679442, 0.35650492976269416, 0.1329616072677797, 0.12870655575346562, 0.11813821195955239, 0.2852097538209731, 0.1570564820881813, 0.24757930047569737, 0.22746304200301248, 0.1948559803948287, 0.18979428426152278, 0.27807949771804197, 0.14041133735689426, 0.14682419808401218, 0.22266071259735093], [0.06062965389461287, 0.10447998275800098, 0.05133008576869484, 0.04939202121609161, 0.08459121409443118, 0.07884585343661808, 0.031844656651599274, 0.1352874808494122, 0.014821180356516233, 0.0888177824597205, 0.04619769121129667, 0.09116872243823544, 0.10728740388707769, 0.1592620339004263, 0.0857417632435118, 0.06453304040816522, 0.0369803358109728, 0.06097566516649339, 0.06382142516574071, 0.025654478531871593, 0.02900395474787201, 0.10265832526549216, 0.0285046550280024, 0.08267827722574435, 42.10322741539248, 93.39321844039425, 49.87446646536551, 65.6318865283843, 109.09466235868393, 69.63123321533203, 51.55494713014173, 35.88181095738565, 39.08321811306862, 30.038232495707852, 78.19241800615865, 73.20345340236541, 63.841893288397024, 68.69282184108611, 47.886169956576445, 55.45597568635018, 49.223231423285704, 41.28183603286743, 11.519759970326579, 1.9408686795542318, 18.375608036595008, 26.533985022575628, 30.138382373317597, 39.057354004152366, 28.86355519294739, 34.422469600554436, 34.75847159662555, 32.72625238664689, 25.32492030051447, 21.683299656837217, 20.94460948821037, 16.479183243167018, 11.367841670590064, 6.122140778649238, 3.140312563027105, 0.8867863024915419, 2.745126658870328, 28.13881689502347, 45.52361657542568, 35.16936732876685, 16.543849399012906, 22.631826823757542, 22.517448548347723, 26.398265131058235, 19.20858610060907, 29.011410897777928, 39.86723323022166, 20.854132175445557, 19.610030881820187, 18.965238332748413, 8.88865465118039, 18.248168268511375, 34.34957627327212, 37.52211086211666, 29.26998922901769, 12.92967357943135, 19.142731466600974, 23.075972487849576, 29.278077156313007, 38.43870209109399, 56.24215595183834, 62.04548305080783, 57.022452662068034, 63.23818560569518, 31.867484738749845, 41.611240602308705, 56.14327692216443, 46.77932416239093, 45.039270539437574, 54.77662901724539, 61.13794072981804, 44.69274090182397, 18.243941914650705, 10.484082641140109, 11.622959490745298, 17.612693309783936, 37.46324785294072, 32.97546017554499, 16.189670158970742, 5.1168824107416215, 1.9077137425061197, 2.318909413391544, 7.259299630118955, 18.856549455273537, 16.67150881982619, 18.34559602122153, 28.060663669340073, 34.92533314612604, 27.588072976758404, 24.67360681103122, 26.986755978676584, 24.13463784802345, 26.988548501845333, 45.49774462176908, 32.387643975596276, 15.649089101822147, 1.6947562535924299, 12.89816321865205, 17.103336280392064, 14.429070180462254, 18.88585348283091, 16.907355054732292, 20.791017317002822, 21.732184156294792, 29.81295704841614, 29.394616657687774, 29.565702599863855, 31.445816216930268, 26.75444576048082, 45.2569777734818, 44.15331302150604, 33.60922890324747, 34.84852137104158, 27.84428219641409, 27.26443821384061, 4.383887523604978, 3.045234064902029, 20.614796992271177, 45.67042304623512, 49.57206741456063, 51.209017615164484, 53.31589914137318, 66.13964126956078, 53.33201223804105, 29.123855444692797, 44.09514819422076, 40.10990242804251, 38.06495904922485, 81.68885800146288, 63.97435565148631, 40.34323638485324, 42.578273511702015, 39.46616695773217, 0.6564849506943458, 0.4720595485020069, 0.09539165188588443, 0.1252398163741154, 0.046973041138581695, 0.10812012613901209, 0.12147644008960455, 0.04957499365592676, 0.026822588331396544, 0.05155748364725902, 0.0769089073723843, 0.0798514127851494, 0.037366991877676024, 0.12474607270691665, 0.1557302766389424, 0.0654404102674415, 0.08170133892206416, 0.08610897982913641, 0.011936053014059943, 0.05543198098518676, 0.03502213080684024, 0.014931757487506877, 0.06335708012263622, 0.026440655196746512, 0.16638513474214464, 0.07022326571806785, 0.0776947910086282, 0.03916529517981314, 0.07766319754263086, 0.03483607486310986, 0.07287664188733024, 0.21330978210654952, 0.06015850982118038, 0.10297077422540996, 0.081724398168585, 0.024442253559226954, 0.10072902475874271, 0.012962189484237423, 0.0590991749308042, 0.03147776565334249, 0.10577294765220535, 0.007535321262454795, 0.09507254562190465, 59.27500709410637, 100.25369490346601, 56.726196042953006, 78.27493682984384, 110.88396918389105, 57.84818218600366, 39.886437154585316, 35.82629765233686, 36.25378108793689, 40.36759038125315, 84.07086633866834, 79.19092793618479, 76.69866961817588, 75.68017913449195, 59.33209719196443, 68.4521608967935, 64.56064016588273, 55.8302600153031, 12.320801115805104, 1.7223100460344747, 29.958671139132594, 25.640610302648238, 34.71079518718105, 31.1387122831037, 22.986212968826297, 33.360342748703495, 33.80875202917284, 32.08963209582914, 27.611120823890936, 22.058031135989776, 22.42839505595546, 16.766742006424938, 11.691377393661007, 5.704097017165154, 5.172483969119288, 2.6881564384506595, 7.80974054528821, 35.84995738921627, 52.01970877185945, 41.38683003763999, 22.38452922913336, 25.69934975716376, 22.80413850661247, 28.21905682163854, 19.62269817629168, 24.71990450736015, 33.802746880439024, 18.792024504753854, 12.679976474854255, 23.106453226458644, 11.875039435202076, 22.540929817384292, 44.562349550185665, 40.050811921396566, 24.532048471512336, 20.0937375714702, 26.37119293212891, 31.99324377121464, 41.48713288768646, 50.20194907342234, 61.241836470942346, 64.40841297949514, 57.21559409172305, 66.08608522722798, 39.33687779211229, 47.53225841829854, 62.72976013921923, 49.10503864288331, 48.60771348399501, 59.581661916548214, 66.46873597175845, 58.78185925945159, 30.126627029911166, 14.682205242495384, 17.908959734824396, 14.067674759895572, 34.860241413116455, 31.941770507443337, 23.143329389633674, 9.69157265078637, 4.6961312332460965, 6.328105907286368, 13.615230341111461, 24.506707999014086, 14.480763096963207, 10.490062294467803, 21.78305925861482, 38.729208515536406, 33.65332026635447, 30.30765618047407, 33.750689183512044, 28.318002531605384, 28.169199574378233, 47.80111728175994, 38.508767389482074, 18.059068841318933, 5.690938936125848, 12.552161139826621, 15.249418212521462, 12.959614011549181, 13.548430415891833, 12.734751393718104, 14.6286109570534, 19.193741890691943, 22.666288768091512, 26.955867313569595, 28.603076473359142, 33.07114639589864, 26.78969806240451, 39.51840900605725, 37.985209418881325, 35.66821828965218, 40.920899529610914, 34.23605111337478, 30.437839646493238, 5.5014016743629215, 0.44788380544031825, 23.191121508998258, 55.83196232395788, 60.42460280079996, 61.36455174415343, 58.09057681791244, 70.86432441588371, 58.85541938966321, 34.675646828066924, 31.35896121301959, 32.20235120865607, 37.92660136376658, 72.68784215373378, 79.82234324178388, 47.99084232699487, 45.4827376334898, 65.6868899253107, 5.201281520628161, 0.8663439510330078, 0.1605584232076522, 0.05643498926093021, 0.021561743811734264, 0.09554899102377315, 0.07204971892098266, 0.09943539336804422, 0.02842479610755559, 0.057609723805780375, 0.10010827903545673, 0.09508389904494248, 0.03022434238734986, 0.01979198303043602, 0.054494028895973205, 0.09911029629649655, 0.011014533510822202, 0.0462395579163586, 0.01920827574306919, 0.12450348330481399, 0.24749054152879024, 0.06737668217430193, 0.2152550325638825, 0.20623365777634806, 0.17718193361595755, 0.185476643363795, 0.17232749490968644, 0.10544778929362375, 0.2630447770559019, 0.1260083404579951, 0.11534861003559445, 0.2242648394237603, 0.17121706578520038, 0.20580446467764918, 0.14800656286458816, 0.1829707237981981, 0.23125652554294757, 0.1209531867155625, 0.3869966693943547, 0.15809480701723408, 0.1797429349033102, 0.10097504623474614, 0.31332297430884454, 70.69076738049908, 118.89275873861006, 65.89486183658724, 90.85390736979824, 122.24675393873646, 92.51569794070338, 67.9656457901001, 44.42607072091872, 47.69866105048887, 41.286801753505586, 89.54799344462734, 90.96196866804554, 79.49764943891957, 82.97687807390767, 62.04813457304432, 75.69183641864409, 68.55264417586788, 63.30984730874339, 19.640686165901926, 3.2286960655643098, 24.37178630982676, 35.191089414781146, 42.9906322879176, 50.85444319632746, 38.214907338542325, 42.764629240958925, 49.13371901358328, 45.46284337197581, 34.883807013111735, 30.980725096118068, 34.542623566043, 28.68277511289043, 22.563161811520978, 11.377443632771893, 13.545028740359893, 7.086783003422522, 13.658127342500995, 41.80639420786212, 61.78941503647835, 44.942603726540845, 24.747918075130833, 31.59273643647471, 31.284879407575055, 36.3333502892525, 27.141320897686867, 37.587998836271225, 51.11498271265338, 30.184544747875584, 27.156716200613207, 24.631066745327367, 14.41746388712237, 20.979738235473633, 51.38006825600901, 57.43774537117251, 41.844052883886526, 41.98686245949038, 46.565696193325905, 51.00321477459323, 50.35323489096857, 54.74221021898332, 61.27674948784613, 60.87611075370543, 57.71226421479256, 70.29746347858061, 43.76233116272957, 53.80401457509687, 72.05676417196952, 56.13880542016799, 53.723049009999926, 63.31486009782361, 69.37070154374646, 65.10358641224524, 39.00890881015409, 21.912970119907012, 32.188389532027706, 36.110296864663404, 51.77121093196254, 34.39523266207787, 22.097337207486554, 7.127268727748626, 3.4340495496026935, 8.878910503079815, 19.888521125239713, 28.454393148422245, 23.39710673978252, 19.70842157640765, 37.213232055787124, 42.36046429603331, 36.43739900281353, 39.44993618995913, 47.4312299297702, 41.4125725530809, 33.54897345266035, 55.378606934701246, 47.7514914543398, 25.92741793201816, 8.13161220281355, 20.624724511177313, 29.026431614352813, 21.41504679956744, 29.388246728527932, 25.115471616868053, 30.933801781746652, 32.50143193429516, 41.1607014748358, 39.747322451683786, 40.7164655962298, 40.091282936834524, 36.27360474678778, 50.466297211185584, 52.46951049373996, 41.88471217309275, 46.508664931020434, 36.30392074584961, 34.8866742657077, 5.051624467295985, 3.4620388477079334, 35.183570231160815, 63.8711973159544, 68.50235154551845, 66.08628919047695, 67.2493347044914, 77.06233609107234, 65.7238111957427, 36.6522938974442, 52.589644847377656, 49.67474722093152, 53.389686769054784, 96.99849636323991, 86.99202799027967, 58.65466463950373, 64.54564886708414, 84.99045033608714, 7.170993349244518, 0.910911514393745, 0.35055809564167456, 0.17204779620853164, 0.1377735740595287, 0.1959327476159219, 0.19692974976233898, 0.20526002131162152, 0.1021411163251727, 0.1369790949167744, 0.17978554471365868, 0.20958071123928795, 0.13519571883784187, 0.15551459224474046, 0.2172074076389113, 0.14464369734689114, 0.2159722440785939, 0.16110446003656234, 0.1053851922493308], [0.01560957771876166, 0.08491011351467141, 0.06449604602230173, 0.008938640164541862, 0.06284498098877168, 0.06469778761628174, 0.024734276699863618, 0.018625267510933262, 0.06271822408082024, 0.02160306276393033, 0.02509627048106444, 0.08261719703554146, 0.142671465272865, 0.09878283201326286, 0.09367344690667045, 0.05048380376050069, 0.04814449682711594, 0.05821532397080333, 0.014618602769088843, 0.01691021306830789, 0.12117111574738257, 0.08371479418729583, 0.19329591894582396, 0.2210423978225839, 13.142156216406054, 106.01189121123284, 68.31476811439761, 51.760153770446784, 82.01613272390058, 88.95282083942045, 60.94304207832583, 47.80038379853772, 39.586120882341945, 29.524425537355487, 61.71798083090014, 82.9490057114632, 57.84531493340769, 74.17729946874803, 63.28587770462037, 64.21101970057335, 47.1781821404734, 34.2654335883356, 2.6665610940225664, 4.915972726960336, 27.519466800074426, 38.46837874381773, 33.10212527551959, 39.33372420649375, 39.69045592892555, 31.686071195910056, 35.35674287426856, 33.94530542435185, 32.75749014269921, 27.02765061009315, 23.15679096406506, 22.51590117331474, 15.858876089895926, 8.407692640058457, 3.3373444935967846, 3.484628022678437, 1.9708004089132434, 9.671696039938158, 42.628883854035415, 48.250189442788404, 45.06721742691533, 23.143027367130404, 21.212819199408255, 28.016325196912213, 20.056582920012936, 24.741277502429103, 37.98592721262286, 26.072247528260757, 20.131290343499955, 10.710301418458263, 4.152517203361758, 2.3734661504145596, 15.427989998171407, 38.91599178314209, 45.190983895332586, 32.596708266965805, 20.716001987457275, 26.840916372114613, 25.756432010281472, 37.072211080981845, 54.29598569869996, 61.05614754461474, 65.66350475434335, 50.34557450202204, 25.924164325960223, 52.7645904018033, 52.984090159016276, 45.124950793481645, 46.94374992001442, 58.16032832668674, 57.83419501396918, 49.36839049862277, 23.339218439594394, 21.961564363971835, 25.88919835705911, 36.07291667692123, 44.57591702861171, 25.102163014873383, 6.366135737588329, 0.49020277816922436, 1.0086023110535838, 0.4670410903711473, 3.4693753959671145, 4.581420046667899, 3.8808379105983244, 12.764920303898474, 26.480717274450488, 19.967790265237134, 26.262686444867043, 32.99620951375654, 26.501882383900305, 38.921651763300744, 50.948152542114265, 36.516152351133286, 23.25549348708122, 5.61991265704555, 7.451905165949176, 15.200467032770957, 11.490780518900964, 15.005635061571676, 14.072894454002382, 16.517734258405625, 23.100093103224232, 24.516251125643333, 29.186935001803985, 25.829035082171043, 30.050942936251243, 24.851811855070054, 27.87303513096225, 37.85881496244861, 49.9410016305985, 42.057225858011556, 37.65172558446085, 38.48756305633053, 53.79570699507191, 13.214372934833651, 0.8710978023948208, 5.955916614301744, 35.20130326670986, 50.10334460966049, 57.56032728379773, 56.71118120993338, 72.016371603935, 42.22571126876339, 26.304198849585752, 51.57135832694269, 35.408937854151574, 55.64845815781624, 84.68644311351161, 53.55368891069966, 36.33382097367318, 45.679032648763354, 10.065414732502354, 0.4447571248296769, 0.08851608171338037, 0.1329049780484169, 0.039153007129507686, 0.0519428450253702, 0.017796804707857872, 0.20075170112954033, 0.052159349133651105, 0.10665508257525583, 0.04041637038631786, 0.07208579400133702, 0.011227459030886813, 0.06240953278217105, 0.10656094569112025, 0.06841902906495718, 0.08047955891778392, 0.10319644074526527, 0.029356449038811752, 0.04663615780431898, 0.02907645156336648, 0.06533046132854878, 0.021492801644208453, 0.09168136549452621, 0.06335210438156802, 0.15179707398337705, 0.011945247984371118, 0.10582586900601465, 0.07010439185485726, 0.05495783767753071, 0.1294540124194276, 0.04690333096791179, 0.04030535275477075, 0.08957745822807474, 0.05047466816200365, 0.045253587436051144, 0.048222633964952924, 0.016625607573998072, 0.034389426451056235, 0.08737373736596878, 0.06490510633035053, 0.11233283597375117, 0.31005190144623485, 0.6343614958947705, 21.724266852101973, 121.377164471534, 74.01044968635806, 66.01408620034495, 100.71082361282842, 80.02254886011924, 51.217285971487726, 39.530085902060236, 35.56074142456055, 38.39377918551045, 77.11736694458993, 86.40051887881371, 69.72047498149257, 79.16354194764169, 72.5167719010384, 74.50036941036102, 59.651491872725956, 38.53674957829137, 2.63426233683863, 7.72354498986275, 32.29432882801179, 31.439034438902336, 37.67256121481619, 42.48660772077499, 32.97072979711717, 26.33372449105786, 29.24932029939467, 29.53102492517041, 30.299179938531694, 26.34636825130832, 22.805342674255375, 19.74511731055475, 12.846600720959326, 6.9845415219183895, 4.552768603447945, 3.5282923377329305, 2.833660437214759, 18.623768552657097, 48.26869910763156, 57.84424020398048, 39.7359711124051, 25.838615471316924, 21.570764895408384, 26.54641893602187, 20.573396375102384, 19.831721282774403, 34.07539867585705, 23.801812971791914, 13.734418422945085, 12.934286286753993, 5.817490777661724, 2.8905892275994827, 23.203245555200887, 49.12357968668784, 48.23172292401714, 30.699569602166456, 27.684661342251687, 33.09589262931578, 42.79480403469455, 45.17286646750666, 56.24378373545986, 64.27421300641953, 62.19510186103083, 60.09059336877639, 30.24994242575861, 57.6024966855203, 61.22112635643252, 50.85854207315753, 51.06325841719105, 64.49092395843999, 63.66741449602189, 53.155136877490634, 28.071785549963675, 21.569137111786876, 26.20275458981914, 36.37013035435831, 46.338849836780184, 34.72648074550014, 17.712413687859815, 2.5311093945657057, 1.7502660039932498, 1.4752886107852383, 6.475377669257503, 8.716070363598487, 10.650941248862974, 10.684745215600538, 16.535553586098455, 24.02843967560799, 30.916686519499752, 39.33636396161972, 29.143710482505064, 29.4461291451608, 42.81114855120259, 45.721496228248846, 26.060419621006137, 7.0547524382991185, 4.271445918467737, 11.297786178127414, 9.872133078113679, 11.548118706672422, 9.0379596717896, 8.951441011121197, 16.84310467012467, 21.013315685333747, 24.51802795933139, 27.197628482695553, 28.847926508995798, 24.95798453207939, 25.625717063103956, 37.70836068737892, 40.80709195906117, 37.75309924156436, 41.58572950670796, 40.78843716652163, 60.73165770499938, 14.536186187498032, 0.7131127604553777, 2.6933940283713804, 39.83598762942899, 56.865812809236594, 64.43960758947557, 62.346089578443966, 75.49710642906928, 50.14116802523213, 29.736706172266317, 30.331129604770293, 36.110736170122706, 51.07105216672344, 87.47801749936997, 65.22257935616278, 43.63398728832122, 63.35068310460737, 21.306467748457386, 0.7069537812663663, 0.14080328326071465, 0.1971649234333346, 0.02089775050990284, 0.06059717176662338, 0.03662964757231455, 0.041538804108577396, 0.06331501040427436, 0.11307978702168311, 0.039532025299605825, 0.04127541924977014, 0.05654495735202105, 0.049048599321395166, 0.04373134774786811, 0.05866636589710271, 0.11416098223097863, 0.055459786146398515, 0.019923240704942616, 0.037729129300362645, 0.1613319115412812, 0.1418327828568797, 0.1256796197905656, 0.2189319328435006, 0.09640781389128777, 0.16348674833293886, 0.1730141854814945, 0.14614291609294955, 0.2180134087440468, 0.2782394875201487, 0.18262653581557736, 0.1635711252569191, 0.21223644695935712, 0.22947305753346414, 0.139773860273342, 0.16027049672219063, 0.27591870076233344, 0.20418265654194742, 0.14685542382780584, 0.3311661120143629, 0.23175144898554972, 0.18456965654848084, 0.45470594098010375, 0.8540386790710112, 22.942890390273064, 134.02759275128764, 85.21644946067565, 74.29891647831087, 102.49345456400226, 110.69356164624615, 79.2781614488171, 62.833973592327496, 48.11160425986014, 40.24238832535283, 77.54430124836584, 98.8841522893598, 71.25424723471366, 92.37269616896107, 78.010051327367, 82.42030943593672, 62.392840308527795, 54.24222177074802, 4.797265625769093, 6.568487873000484, 38.601602046720444, 48.90424074665193, 43.01133063531692, 50.32791991387644, 53.57465790164087, 43.83771911744149, 46.058114036437004, 45.25845258466659, 42.0614424059468, 35.23588288214899, 36.88773808940765, 34.577022752454205, 24.41972944044298, 12.373297137598838, 10.775902078997705, 12.001984004051456, 7.118911627800235, 24.939039484147106, 57.313602355218705, 58.851347969424346, 57.78750311943793, 34.48272112877139, 29.789391448420865, 37.281375392790764, 26.685976866752874, 35.925580686138524, 47.9595261235391, 33.301111036731356, 27.176718327306933, 19.88909379128487, 12.451772978228908, 3.1932167564668967, 22.305214981878958, 56.511532568162494, 60.90148064397997, 44.263100162629165, 41.23581094126548, 48.788115055330344, 51.850560480548495, 50.3281670231973, 57.60500308006041, 62.40892594860446, 63.15061476922805, 60.89815839644402, 35.9008736764231, 65.1047670456671, 68.45923685258435, 54.84047343654018, 55.799975395202644, 66.6538796886321, 67.09194567895705, 60.65222970900997, 42.14555763429211, 40.06266140168713, 43.47736312497047, 48.026888908878455, 48.218080920557824, 39.73637119416268, 14.803573181552274, 2.1866620452173295, 4.880004102183927, 2.376604291700548, 10.961688083987083, 7.624537502565692, 7.949877515915902, 20.65096320644502, 34.16472673416138, 24.429196080853863, 36.725367653754454, 52.57510069877871, 39.916388373221125, 49.440589566384595, 57.937337660020404, 46.88405536836194, 32.56870646630564, 15.06255453632724, 14.586166008826225, 25.950552071294478, 20.865577651608376, 25.651306606108143, 24.605298734480336, 26.331296543921194, 38.24620393014724, 37.75787276606406, 43.935335143919914, 40.41436856792819, 41.92628537454913, 32.529333714515936, 34.153422463324766, 47.8004857801622, 57.35679549555625, 47.33340601767264, 49.01666764290103, 45.290106111957186, 62.126177972362896, 15.370899900313347, 1.0304555513205067, 7.436022998825197, 49.2662049108936, 64.7336833707748, 73.16202532860541, 72.95252369296166, 82.05367765119, 52.59681101768248, 31.747966197229204, 61.28336652632683, 47.598962245448945, 70.80651652428412, 98.65273244919317, 75.59123546846452, 58.44551209480532, 83.99562743402298, 27.696557890984323, 1.0145582462991438, 0.42700778692960745, 0.3244032103928828, 0.11606886291936522, 0.25879608407135934, 0.14183272156984578, 0.3812839517429952, 0.1238158887492553, 0.3015488464265101, 0.16773184070423727, 0.19399799256315156, 0.18651745041772244, 0.13717964141359254, 0.18556452897046843, 0.17129727519087254, 0.1541654501230486, 0.14431061763917247, 0.18674412051275854, 0.1649818761694816], [0.07862099896996252, 0.039684181852686795, 0.03473903067530163, 0.010553130245346938, 0.03367693403795843, 0.1073548579288106, 0.045881404150878234, 0.08723430936374972, 0.11664244060915326, 0.041686253051363656, 0.0409559452635867, 0.07320899381152085, 0.05674601329730884, 0.07252113112518865, 0.1283197196561002, 0.05141411029222993, 0.04266814411347432, 0.12046955540896424, 0.07874397140356802, 0.06160765706050781, 0.08314140801948887, 0.1287909173556874, 0.07481615434611037, 0.04679923494076056, 0.22610576402756477, 64.64469655867546, 85.10375192088466, 51.612025460889264, 70.54531020502891, 102.81253153277983, 54.443682547538515, 49.77663863089777, 48.952544735324004, 27.02013731002808, 54.21172142028809, 84.35127658228721, 61.29935410714919, 62.14020436809909, 63.24600681181877, 65.98287197851366, 61.29321167545935, 8.981915866175006, 2.0280022943212144, 18.671641080610215, 39.42193046692879, 45.4308525208504, 33.374137724599535, 31.001290082931522, 28.883506328828876, 33.754089878451445, 31.14690415320858, 29.882679139414144, 30.08299066174415, 29.645222771552305, 25.964509825552664, 18.98864115438154, 11.660118064572735, 11.143292842372771, 5.265212232066739, 6.769309303452892, 0.686672553420067, 0.43321196530615136, 27.91017017056865, 46.509410181353175, 62.3108902285176, 38.564696465769124, 17.03786211629068, 22.795928985841815, 19.76103036634384, 17.92017379114705, 32.44576957917983, 23.504836597750266, 12.080833450440439, 11.265267768213826, 4.019358619566887, 0.6986557620186961, 5.776229894930317, 26.706104509292114, 50.361216914269235, 58.318144890569876, 31.627469024350567, 29.679902407430834, 31.066068026327322, 44.9217406395943, 51.96046529277679, 58.340678907209835, 64.15174876489948, 27.11893985348363, 15.715493848246915, 50.682251145762784, 53.66358980055779, 49.36938678064654, 52.17698012628863, 56.625434275596376, 56.96475459683327, 56.62898009823215, 45.631128741848855, 41.654155254364014, 42.88185319592876, 48.927280749044115, 46.782516971711196, 7.105023005316335, 2.1385872700522026, 4.070091045671894, 0.6732756368094875, 0.3634466363057014, 0.8636445023359791, 2.9301318670472796, 4.965570117196729, 10.747882627671766, 19.6730927882656, 28.34360972527535, 28.944922800987, 30.318770216357326, 26.955949683343214, 47.90434621995496, 55.18070767002722, 28.87664414221241, 16.594000824036137, 0.9251310868609337, 9.656364475527118, 11.947466981026436, 12.100667895809298, 8.486981391906738, 11.086424358429449, 22.560271024703983, 20.462630602621264, 25.8491744918208, 26.446926055415986, 25.161565349948024, 27.088953333516276, 26.72344138545375, 24.071491610619333, 26.939630662241292, 55.283316873735004, 52.15484619140626, 45.81784925153179, 44.85144392136605, 36.85231516438146, 30.794385056341852, 0.9367210778497881, 1.2278810672221647, 14.033708014795858, 38.09154487425281, 56.24038696289063, 57.926837475069114, 70.57093112699448, 33.6846286250699, 33.446199509405325, 47.57854238633187, 34.03160933525332, 74.73629997622582, 71.1307631769488, 38.456211551543205, 39.16235193129509, 29.34890143332943, 0.3955167315659985, 0.24673853430055806, 0.26585883250640285, 0.037038784489155784, 0.05835852878648908, 0.03180402717853506, 0.14752552093517396, 0.03131582232702884, 0.10784177575260402, 0.1010490273455939, 0.07458569977672831, 0.08073430613524492, 0.030384853129245104, 0.07985228612538307, 0.09620529854850424, 0.09365222627116788, 0.03591130607791486, 0.058418161070515076, 0.0933215597404107, 0.03092763216925725, 0.11316479979864053, 0.023985410432120966, 0.015564540367303117, 0.06682453962463526, 0.033740435066002036, 0.22861401250045146, 0.06203539842259019, 0.08753826240858725, 0.14735443817992366, 0.0485485201070626, 0.03306814694717046, 0.03876414856002216, 0.03798104965338304, 0.09574766826605606, 0.07870451787546759, 0.06431995305202662, 0.044203208113509806, 0.0729482940908882, 0.013816256860962078, 0.12669454839441086, 0.06358567692880189, 0.08519502161371131, 0.06016270032212619, 0.1425572262415963, 0.8677962085893078, 81.74745036709695, 96.40398271622198, 56.47161068454866, 88.7038758493239, 100.59600799314438, 49.729829065261356, 47.63300841854465, 35.9207522484564, 31.979317395917832, 72.409118529289, 87.35796943787606, 71.76626559226744, 74.04069900512695, 77.81146172554263, 76.33154361478745, 66.4245230151761, 6.56261069159354, 2.494898073134884, 25.266586811311786, 42.05648845241916, 38.76977759022867, 35.91665337162633, 32.85225264487728, 28.660578420085294, 31.41763790961235, 29.758865602554817, 27.329096524946152, 29.877858546472368, 28.887244347603094, 24.200390500407067, 15.02730223440355, 9.051654627246242, 8.837738363973557, 5.743725703608606, 6.294169560555489, 1.284371287591996, 6.382383665730877, 35.878276901860396, 53.458853844673406, 49.85972227588777, 34.28136625597554, 17.696559467623313, 23.535036886892012, 20.163263543959587, 19.063917321543542, 30.407256926259688, 19.594437499200147, 14.116280771070912, 12.97007595339129, 4.639660379578991, 1.3035866113439685, 5.2751882903037535, 35.836064354065925, 60.69009234828334, 56.66669760980914, 35.70501404423868, 35.0652950809848, 43.92931430570541, 51.93336955962643, 55.885000613427934, 60.52745126908826, 67.83601145590505, 36.831444232694565, 18.218893658730295, 58.56327341448877, 57.55909958193379, 55.43170798209406, 53.91799865230438, 64.51348150930097, 62.23896572666784, 65.27046757359659, 47.8735242351409, 41.567572855180316, 47.427350705669774, 53.41253457530853, 52.94969489497524, 25.383728396508005, 6.850593070830069, 4.550441657343219, 1.329544857144356, 0.521018113340101, 1.2530596193767365, 8.083571012943022, 9.600738402335875, 13.425518043579595, 18.001890490131995, 28.753222842370313, 32.46831732411539, 36.80781587477654, 27.465451840431463, 37.82617692024478, 49.763373174975, 36.07294805588261, 22.37778275243698, 1.9268002409127452, 4.776652589921029, 9.465240124733219, 9.679637858944556, 6.018462729069495, 7.228478625897439, 19.098693055491296, 19.606055559650546, 23.97817057947959, 27.177269420316144, 25.77582616959849, 26.702978380264778, 26.633238638600996, 24.983521123086255, 25.446878556282293, 46.78413298822219, 37.65951148925289, 49.756289374443796, 46.04310312578755, 41.813823176968484, 36.254898963436005, 1.3501388940118975, 0.6345687686435638, 13.824460352620772, 42.740561577581595, 60.058990832298036, 65.05971862423804, 75.00357812450778, 46.43028028549687, 26.54343205113565, 35.01996817127351, 34.74454326014365, 68.42442973967522, 85.39772572055941, 57.53259220430928, 54.13269350605627, 47.373237686772505, 1.2706165159902265, 0.28578726154181266, 0.07882519204530024, 0.12261139934942608, 0.02854480761133375, 0.06604768816501864, 0.10676658667263486, 0.04477172962299759, 0.1365754278677125, 0.05618063657875023, 0.01175926864943317, 0.057139525850934375, 0.022923461266703183, 0.06770734104417986, 0.04372586255833026, 0.11872174879235607, 0.027734629411791122, 0.003947645088755376, 0.04147540650240356, 0.023464005245196245, 0.22591050353742417, 0.10354948470429068, 0.13061607587001017, 0.16107634460974127, 0.13100943137561122, 0.3537700878035638, 0.1912818737928906, 0.18560848709556366, 0.28987461640950174, 0.16414130917720257, 0.16436906711709115, 0.15960715651031465, 0.15937366823275245, 0.3486100566242972, 0.19720724213027185, 0.15295619565633037, 0.1272515556023967, 0.13149350701320556, 0.11498183778096592, 0.2612706399973362, 0.15582197736347878, 0.1668661766715588, 0.12101801307571512, 0.2501670688751244, 0.7826430230371414, 88.64198084800475, 111.1261990762526, 72.64298592844318, 95.51626405408307, 123.42141751320132, 76.02195093708654, 67.13531924832252, 63.41569639021351, 35.59471307262298, 71.86046523432579, 98.04208217128631, 82.08006735770934, 82.93768575114589, 87.65423390173143, 80.71163085199173, 81.48315322014594, 15.121900977626925, 3.817159946887724, 27.13487840467884, 48.36391856593471, 58.91309784304712, 42.00376787493306, 39.176146907191125, 35.83852368016397, 45.122864092549975, 44.01568881926998, 41.4085207446929, 42.00012791541315, 39.649894698973625, 36.52211435379521, 34.159184425107895, 21.681024682137277, 20.422420424799768, 10.661820923128436, 16.04074070530553, 7.718747440845736, 12.74360614438211, 42.50189319733651, 55.530147706308675, 70.65614069661787, 54.19387855837422, 24.345853559432495, 36.06224390768236, 28.18906245693084, 30.508183433163552, 39.290052536995184, 36.03543058518441, 21.15921804981847, 22.54611126838192, 6.197742502535544, 2.262373350320324, 5.785728894895123, 40.80032194814375, 63.293424344831905, 69.21881952593404, 49.266232367484804, 52.27411370123587, 57.40300493855631, 57.4023538251077, 57.97974240395331, 59.27966294750091, 64.82530601562993, 38.38120406673801, 20.16667404482442, 62.71758902457453, 61.31866001313733, 59.27514829943257, 56.90069836954917, 66.80591075651108, 62.3705102551368, 62.66916344242712, 61.086000703996234, 54.2430886145561, 49.37031638237738, 55.805843260980424, 58.885401987260394, 23.840724845086378, 5.129601186321628, 8.900917941524137, 1.1151072863609561, 0.7195249776686392, 0.9825046985380113, 11.753062548175937, 11.992799774292978, 20.740973757159328, 32.75184585202125, 31.937004827683975, 40.79496399048836, 48.380616095758256, 41.2106881603118, 60.1195090816867, 61.17236737282046, 33.91630341929774, 28.3356257407896, 7.551599558322661, 19.7065721788714, 21.675343128942675, 21.901865889949185, 20.39154744917347, 22.080088584653794, 36.711066692106186, 35.16542926911385, 39.75043289123043, 39.821667055929865, 39.91807499239522, 38.73389182552215, 35.5031963317625, 34.47166396725562, 35.24839524299868, 61.675309365795506, 59.209601571483, 55.70624643756498, 52.414216841420824, 46.26022984904628, 35.316981807831795, 1.9525378533909399, 1.3333007717324843, 21.2085908843625, 51.06387030693793, 73.75279703447896, 72.27611880148612, 83.6152438194521, 41.81097945859356, 42.761330527644006, 57.76010144141413, 46.825023697268584, 90.8169900217364, 94.53182758823519, 66.30502408550632, 66.78997024413079, 61.99155046093849, 1.5873579584783124, 0.44917104765772825, 0.5274870210597592, 0.19526171588128616, 0.17325893525154362, 0.30574765176542346, 0.299092676610716, 0.14264308937614964, 0.19525649116164256, 0.29958698718297866, 0.22358144303002667, 0.24591456077271895, 0.1677681073065727, 0.17096681550385492, 0.16276766756369224, 0.20069612911151302, 0.17730196427193382, 0.1434784163270266, 0.17477686186471295, 0.1355227924162342], [0.04015662061471132, 0.022849380564425262, 0.048564738188419616, 0.14387924885076864, 0.07343750251757522, 0.029339528071784207, 0.030614668015210383, 0.03928845530496009, 0.01950086004311039, 0.07001876620756042, 0.0452580192546931, 0.04482741272377391, 0.05724621508570929, 0.051124739731031085, 0.1272414432417962, 0.2086298582294295, 0.09751334005305845, 0.02391934300953102, 0.06503224628226412, 0.032279765864293423, 0.208078887794287, 0.06887298212536881, 0.03853558239737346, 0.19431697625306346, 0.07803854998201132, 8.25570667943647, 82.58346434562438, 65.60706184756371, 51.93533074471259, 89.15560737732919, 84.97964028389224, 37.94043556336434, 55.46261233668174, 40.79066899514968, 47.72933006286622, 83.14561059398036, 55.10238970479658, 65.30688285827637, 65.24121845922163, 61.93043993365381, 27.887612619707664, 0.5439458378861027, 7.497224721216387, 45.289486377469956, 27.85332522084636, 51.34631233830606, 59.25110809264645, 52.92013199098649, 32.41360418258175, 17.545809053605605, 23.364390250175234, 23.761800873664118, 26.258201214575, 28.021108527337354, 20.862096548080444, 15.339224799986809, 9.640335709817949, 9.125188281459193, 7.96182946812722, 4.376748319595091, 3.7784650296934195, 2.5724310740347835, 17.84887294615469, 40.07219276120586, 64.85338234132337, 60.242553833992254, 23.912466956723122, 22.275789360846243, 20.83222377684809, 16.940065660784324, 29.867885920309252, 21.801969005215554, 3.628588078483459, 17.22575149228496, 11.240806887226721, 5.791213348988564, 7.191181788521429, 21.20009110819909, 40.7518453751841, 56.2976731792573, 51.61533201894453, 37.135553436894575, 37.34807921994118, 46.619036505299235, 57.274523781191924, 59.05789606032833, 71.32918803922593, 20.482879838635846, 7.56280969227514, 49.58683906062957, 55.29930053218719, 52.33904853943856, 49.135550760453754, 57.4337798549283, 51.26472703872189, 61.109072085349794, 60.0666472988744, 54.492974973494015, 55.30614114576771, 58.96758348711076, 38.00545669371082, 12.767110947639713, 5.435976049592418, 0.9767239216354586, 0.7875185291613302, 0.03452027043808372, 0.9303113121178843, 8.591029124875224, 16.288705102859005, 14.739674829667615, 14.888621933998602, 28.227605627429103, 29.141431585434947, 32.73302631993448, 31.706912709820656, 66.5948558622791, 59.555468328537486, 33.40250038331555, 3.478723139532151, 3.3502593876854068, 8.18616403687385, 9.074540676609162, 8.340528915005347, 8.16222728260102, 13.942407004294859, 18.383890121213852, 17.06067854358304, 27.49363014774938, 25.695919644448068, 29.227374638280562, 21.235321837086833, 23.510731920119255, 20.303605948725057, 28.32868902913986, 46.31783769976708, 68.27645440255442, 44.56772711969192, 44.312525949170514, 45.41049541965608, 26.271245056583037, 3.0445309800486413, 0.11333662565917739, 2.6325230108153437, 24.62355540644738, 49.57780584212273, 62.643483684908965, 62.112402608317716, 21.84409329968114, 46.61206253113286, 34.264727561704575, 46.56058926736155, 83.08785761556318, 57.957431962413175, 26.289992024821622, 37.641982416952814, 10.087554550939991, 0.3236457332968712, 0.12532427756776734, 0.07055357984837986, 0.06445347451634946, 0.0709586181948262, 0.04628111435581119, 0.04961845382387119, 0.05944964100396442, 0.06697759633102725, 0.03289449779737381, 0.03638463733237117, 0.025475765540895444, 0.049426805438293565, 0.06766095442036468, 0.04633578239008785, 0.0373014836992708, 0.0409726076759398, 0.007894196108193889, 0.05052575856567391, 0.04882552600916355, 0.015991306882501853, 0.005343996660573589, 0.04492790813768103, 0.10157451769637485, 0.05119924178166736, 0.07896762311218247, 0.019498556033678113, 0.09768594732327808, 0.0821757848344503, 0.037770846618279334, 0.08776689368870952, 0.04005072045049841, 0.059694727852700226, 0.05252879503513536, 0.13519224079866565, 0.2253195586343927, 0.07456412674078057, 0.060621586988770196, 0.10065982403654246, 0.08573777192542631, 0.17003090120851996, 0.010656212163608401, 0.08796639064507139, 0.10128224749238261, 0.5860787125364427, 18.426967551631314, 101.64138240198936, 74.76931848833638, 65.41480295119747, 101.72642723206552, 68.20563993146344, 41.88945431863108, 37.77114214435701, 38.060530693300315, 66.33738363942793, 92.78805163598831, 65.64386936926073, 76.68188187383836, 71.07028022889169, 75.56731685515373, 25.359011580867154, 0.2525911702504081, 9.912430528671512, 48.54520267055881, 30.26251558334597, 46.819779488348196, 52.33809540348669, 50.364852951418975, 25.0694171074898, 19.959035535012525, 27.111332416534427, 24.043170136790124, 23.86819516458819, 23.65696768606863, 18.890962369980354, 8.94271275689525, 5.634395028314283, 7.585588366754594, 8.512324806182615, 5.49971309400374, 2.606482885537609, 1.935715420592216, 22.611075524360906, 45.29459330343431, 61.94911041567403, 48.43237569255214, 25.532654908395585, 23.99023775131472, 22.966367736939464, 14.177858060406102, 27.024055757830222, 19.42252785928788, 11.694928119259497, 20.491334507542273, 15.666252413103658, 6.537339350869579, 7.75877473815795, 22.661028869690437, 52.0012971662706, 63.027142478573715, 53.89644915057767, 37.451900436032204, 48.99034069430444, 55.229509799711174, 60.6390073991591, 58.92573571974232, 74.70439541724421, 23.252394814645093, 9.871810463167007, 57.814214460311405, 58.58854132313883, 59.43874251457953, 56.42443633848622, 61.811156734343506, 55.75623312304097, 67.85651760716593, 66.15756650124827, 60.05763369221842, 60.777784778225815, 56.12135087290118, 47.47397984227827, 15.741079468880931, 7.482730582837136, 3.6497095515651092, 0.5715261676138448, 0.057284331790381865, 0.8845231561891495, 11.109564381261027, 16.216078496748402, 20.496821903413345, 17.086878015149026, 28.90682678068838, 30.696053197306973, 35.882666034083215, 27.360385271810717, 55.77731978508734, 56.784729573034475, 40.827351001001176, 10.500264379285998, 3.750058979757371, 6.715168827964414, 8.275902963453724, 9.878042128778274, 10.168152393833285, 15.696870434668758, 24.414585251961988, 19.651052990267356, 28.46522673483818, 27.8849434468054, 27.588037675426854, 20.628968515703757, 21.916127627895726, 20.798273701821607, 31.62997934126085, 48.877847117762414, 61.302593984911525, 41.90785415710942, 49.59398169671336, 47.58893666728851, 32.4012565612793, 3.5703249467957408, 0.11842963946682793, 2.330029577978196, 25.01779675483704, 51.56015211536039, 67.62669024928924, 69.93117686240905, 34.197266717110914, 28.1975406600583, 32.619750230543076, 42.56722811729678, 86.57457797758042, 74.55318020236108, 39.693146674863755, 56.456070253925944, 21.98424154712308, 0.9337732940912248, 0.05472251844982948, 0.030579366683659535, 0.057619487596375335, 0.13168011070980182, 0.06572442970448925, 0.024311509163629626, 0.06622001198270629, 0.06713710349774168, 0.048425769838955135, 0.03961232663582891, 0.0783567599231197, 0.09963280656525206, 0.027216765466296387, 0.005595981173457639, 0.09277045907032105, 0.028546414480754928, 0.0444789691227338, 0.045931153900681004, 0.016658036075832865, 0.1334367809636939, 0.22240111604332927, 0.09514045165551287, 0.17156470116348038, 0.19230106184559484, 0.14940038323402405, 0.09342860520607041, 0.189459182081684, 0.3045320234471752, 0.14279125078070548, 0.22512656576450796, 0.19693885088687946, 0.12628718114067472, 0.23541054538180753, 0.23944525468734004, 0.3255161216422435, 0.1276782435935832, 0.134632874039873, 0.17997040172978757, 0.2642290876998056, 0.2345977873811799, 0.14113127614461607, 0.29603984687597523, 0.28389674040579027, 1.065099027849013, 17.794118619734242, 122.38840641513949, 92.69119262695314, 78.19985482000536, 108.54858213855375, 109.12218955255325, 56.778473392609634, 69.2193058998354, 56.03461942365093, 61.26407238744921, 96.5905620205787, 73.64654002651092, 86.03905677795412, 81.72503794393232, 82.28481508070423, 36.18406095812398, 1.428500250462563, 11.618802758955187, 57.504790444527906, 38.99334484531034, 63.53056300070978, 65.87381439824259, 63.00767183303834, 40.59918280570738, 27.67629884904431, 34.666962700505415, 34.2221620005946, 34.01054620742798, 40.86916738940824, 33.3075084224824, 28.684650005832797, 21.848319653541814, 18.190234861066266, 15.658541033344886, 13.606425600667155, 14.68637276080347, 12.663237760143897, 31.526730791214977, 53.364399248553866, 77.67456316178846, 75.93490569822251, 33.488525805934785, 32.60654753254306, 31.598123811906387, 25.710797194511663, 39.62100644265452, 36.23982921723397, 14.346808272023356, 22.59208340798655, 17.383758291121453, 8.280878490017306, 6.253423488909199, 23.993326617825417, 55.37521016213202, 60.4074816549978, 59.000213684574256, 49.657684910681944, 60.403912298140995, 58.69870108942832, 63.18036594698506, 60.50730205351307, 75.99524744095342, 30.922064089005996, 13.526304325749798, 63.86186599731446, 64.68408107757568, 62.17320719072896, 58.518656453778675, 63.318374541498, 56.38889574235486, 67.22689090236541, 65.97541947518626, 58.74112936758227, 57.95030501581008, 61.68754716073314, 48.19833963148056, 17.5753503845584, 7.220836868209224, 6.247785081786494, 1.1617565251165822, 0.12440275040365036, 1.1501845525157068, 20.28205252462818, 22.14177962272398, 22.962910167632565, 24.867248342883205, 34.706257004891675, 40.595103540728175, 48.89793357541485, 42.445207103606194, 77.00670903728854, 62.09064129860171, 39.7639689906951, 9.60881946548339, 11.605578487919225, 19.272687435150146, 20.417607676598337, 20.857789785631244, 19.661115830944432, 25.781792094630582, 35.68354691228559, 30.272580385208133, 41.74549548856674, 40.34123597606536, 44.10196527358025, 33.23029264327019, 36.64230754298549, 31.174749059061853, 38.037839781853464, 55.44058430579401, 80.64684898622575, 50.935706861557506, 52.02518047824983, 54.123487703261844, 35.84482300666071, 4.760860637311013, 0.17811505935124813, 3.51097017045944, 31.64936173346735, 61.24423696148781, 72.80101822268578, 74.85204912001088, 26.64400946709418, 51.66631106407412, 48.154463998733036, 62.265151469938225, 102.18875700427641, 84.39078269466278, 44.43808101838635, 74.52820254910377, 28.1465204300419, 0.959338812578109, 0.10078705591900695, 0.17007266832215173, 0.17445086080941463, 0.2591745315059539, 0.1683217743712087, 0.13886903382597432, 0.271796565502882, 0.10535886946825251, 0.1452364655391824, 0.12607673678787487, 0.1440724102599967, 0.20092480635691076, 0.1178939141813786, 0.13104724547555371, 0.16798055880973417, 0.14732551069990282, 0.2174572901980531, 0.16521757078026572, 0.11790155207798367], [0.04337689801750164, 0.09005517533589756, 0.08027502110288029, 0.14134636299023706, 0.06082564982916079, 0.01842949948754282, 0.02838030172091338, 0.03622947005374778, 0.03970930187572395, 0.029142700931838447, 0.08320546063083796, 0.03145112111533602, 0.07615214273814233, 0.03367088194335661, 0.04684227759078626, 0.08755634974447951, 0.03262068265147748, 0.04742256238035137, 0.06162307457998396, 0.0738545224791573, 0.12150403457663714, 0.15266574108071868, 0.03403506099036144, 0.05474622121020671, 0.18939553549693477, 0.15180419860107286, 30.80180814189296, 68.9979822404923, 48.49530227722661, 69.25999656800302, 97.56630651412472, 60.92235942040721, 42.69229289024107, 46.04404449462891, 35.92580033886817, 80.25274492079213, 61.77905997922344, 63.30735660368397, 67.44129550072455, 39.35614839676888, 5.068554397552244, 0.12599109581881954, 21.72026603452621, 58.90072276515346, 47.762552538225734, 55.24946289677774, 63.79313822715514, 45.86757706057641, 34.51895990679341, 22.3999676781316, 21.87034768442954, 26.521354990620768, 22.881797513654156, 24.210204270578203, 17.521570767125777, 10.80232120329334, 8.891849421685743, 7.464710233672974, 10.623106148935134, 6.223745855592913, 0.9943112779048182, 2.8116142653649856, 11.101505871742003, 28.318983124148463, 46.42577348216888, 56.39317504821285, 31.206365323835808, 23.677769976277506, 19.565070713720015, 18.425245631125666, 22.494873346820956, 15.066066038224006, 6.772332470263205, 20.04731239811067, 6.243759259100884, 3.7708938746683063, 5.392309773352839, 21.691177737328317, 35.80193188882644, 49.10609376045966, 59.91420045975716, 55.751698863121774, 48.33874871653896, 51.60704012840025, 57.993972762938476, 59.84429990091632, 66.03525915453511, 47.59722071309244, 8.937082194512891, 35.74794438577468, 55.64029178311748, 57.812021855385076, 57.03294107990881, 50.85474129646055, 51.443222338153475, 52.537783268959295, 55.01806266846196, 58.69549259062737, 48.83878815558649, 52.15241432189942, 33.50658047583796, 9.611207208325787, 1.3310700462710474, 0.571270355534169, 1.4952608294064, 0.05293652618063554, 1.2095275617414907, 10.318308568769886, 19.806249410875385, 22.231056690216068, 18.57394660672834, 26.186994506466775, 25.8006763458252, 27.654070777277795, 33.19902350825648, 65.46687633760514, 56.31117005502024, 30.10146502525576, 4.971258044242859, 4.135816241464307, 2.8972393610785088, 3.429562358125564, 7.100074445047687, 9.129446014281243, 18.27197705545733, 21.999205389330466, 20.47618043038153, 26.482294067259758, 23.701727813290013, 25.332031557636878, 22.70036828133368, 22.305946503916097, 20.450863492104318, 17.8662843473496, 34.573935847128595, 56.55547880357312, 62.14425225411693, 48.64009264976748, 45.90119961769351, 23.56868297823014, 3.0861559077616665, 0.2158377803261242, 0.2606051853827892, 7.283032911439096, 37.77354263490246, 65.7916093641712, 52.05307245254517, 23.736984037583877, 43.9036855389995, 34.496186625572946, 58.50555965977331, 80.15215181535291, 42.58380405364498, 30.2042370073257, 31.396437498830984, 4.825491982121622, 0.38109117337772924, 0.3107994500427477, 0.13571403860565157, 0.03958631795079958, 0.09866946632222784, 0.038626781334319425, 0.059943262097095294, 0.00793431134473893, 0.07698050594978756, 0.20588324915978218, 0.15498648187325847, 0.04565062016368874, 0.03359744092449546, 0.03031705626316609, 0.0401750335379714, 0.07767805198748266, 0.0278349218123983, 0.07054851600720037, 0.036328598000710054, 0.008924934851576485, 0.03689926838682544, 0.15883532292660207, 0.08304737838766268, 0.07545458903956799, 0.1451675635912726, 0.06137471653581147, 0.054082306432387525, 0.13619604580585035, 0.053631463688948465, 0.020077862145919955, 0.028297880236359856, 0.03773690892323371, 0.06905006334906624, 0.03725882026276762, 0.049534578687481345, 0.11905031624220072, 0.036594127905705286, 0.02507242982486083, 0.036114978213464065, 0.08449117833327863, 0.12235330432773599, 0.04592536227597345, 0.04599161739010484, 0.15459384649030625, 0.19637675685507638, 0.4957281107143049, 57.67445256633144, 81.7797314736151, 54.93219806301979, 87.92665035493913, 89.85432271034487, 48.41588604834772, 36.87080129500359, 30.16830417417711, 55.328349605683364, 92.87810925514468, 70.51841843512751, 71.26651640861266, 72.97335147857666, 40.88690826969762, 3.8223634612175728, 0.38250108159357504, 24.84423775826731, 75.11269061796128, 43.479583186488, 51.81060329560311, 58.51670703580303, 42.944940597780295, 34.47330744035783, 19.363203971616684, 23.48112979242879, 26.461393717796575, 22.93067809074156, 20.059965964286558, 10.388510169521457, 10.146636232253044, 8.896933794021606, 7.867481756594874, 9.689240801718928, 5.866464020744448, 4.866801404183911, 2.5981895241045185, 15.17718678520572, 30.786144156609815, 48.80987244267618, 47.14180215712517, 32.97613482321463, 25.497477131505168, 23.539243628901822, 17.882366065056093, 20.389782382595925, 23.046907724872714, 14.450184299099831, 25.843026176575695, 8.645966822101224, 5.890671418559167, 6.230130983937172, 24.680555289791478, 43.76259003916095, 58.775152006456935, 70.53176233845373, 54.99730940788023, 51.06101482145248, 58.63048714976157, 63.10663715485604, 64.58740249756845, 74.31944616379278, 52.16915107542469, 11.416928172111513, 43.76497484022572, 59.779698464178274, 62.500768246189246, 60.904010572741115, 57.043166698948035, 58.55615823499618, 66.7634864007273, 64.19043117953886, 61.44515252882435, 56.047465185965265, 57.10319857443533, 42.059971517132176, 18.960770753122148, 4.5542757741866575, 0.7979079071552524, 1.5971968563333636, 0.07215468828836757, 1.0503297106873606, 16.277628329492387, 16.919712481960175, 23.829618653943463, 16.106814011450737, 25.23866345805507, 27.517939036892308, 30.205372533490582, 31.568364789409024, 60.06778478622437, 54.69358459595711, 32.6856735060292, 10.150540951759586, 5.719986538733206, 5.388636473686465, 5.46343558257626, 9.874872853679042, 13.719020178241115, 25.09131766134693, 30.820111882302072, 25.021422986061346, 29.510053973044123, 24.971142122822425, 23.062026500701908, 19.11505130029494, 21.173719052345525, 21.258195138746693, 22.504461580707183, 43.04689868803948, 61.107663954457934, 65.16277105577531, 57.477961432549264, 54.881199406039336, 28.406981498964374, 4.273154600974053, 0.07872902502816531, 0.32154211714383096, 6.628337358274768, 39.81268482823526, 67.73024866657873, 65.84642840969947, 28.502642223911902, 26.5156126406885, 33.726723501759196, 60.16801703360773, 93.36682088913457, 58.55050609957788, 39.87394048321632, 55.68313975487986, 7.159056596217617, 0.9489769524624272, 0.1944635595164953, 0.11024451859655882, 0.10916213595098066, 0.02508852150171034, 0.07222008155358416, 0.08722310915829674, 0.04032176235810884, 0.14401599554525268, 0.08704097941517831, 0.08375226354767239, 0.0816380600595186, 0.022067472924508398, 0.054620885395354805, 0.045086346611741095, 0.06532002721102008, 0.03988000541745175, 0.09323916698415434, 0.05033398377558878, 0.07874037079032391, 0.15924640570677098, 0.19267192500973904, 0.14570623065435118, 0.17844135151995769, 0.2189587305990919, 0.10527807017487865, 0.3021582234049997, 0.2252145892670078, 0.1668964371445679, 0.13726999382338217, 0.11990410591205282, 0.08741874503152025, 0.35789681959056086, 0.09094846449912557, 0.16118981755308567, 0.2232834961145155, 0.10739445701361665, 0.1487003933758505, 0.11541847725428882, 0.16159720778945955, 0.32370594780771966, 0.18311087192306597, 0.15382705376513545, 0.41320496629322734, 0.36666371529140784, 0.4289658463770344, 68.08071244147517, 103.02317065577354, 71.55106083039315, 97.46539961907172, 117.23560440924861, 85.71893645871071, 60.833709932142696, 60.617473586913086, 43.96043831302274, 95.33049275798183, 74.64090008889475, 82.38031694965979, 82.88225481587072, 49.72970354941584, 6.696228192698571, 0.4003833204267487, 29.735119573531616, 74.865094923204, 59.091244051533366, 66.06578303921607, 74.67874311631726, 55.188630857775294, 40.52697197083504, 32.29556829698625, 33.258737671759825, 42.26680201868857, 37.04169504104122, 38.27595903027443, 31.393772248298895, 25.13383811519992, 22.941394006052327, 19.558092817183464, 19.684724577011604, 16.824408692698327, 11.118867262717217, 14.715597360364853, 22.3200435023154, 38.82939761684787, 58.36089088070778, 70.60980181540214, 47.42277329967868, 34.48505886139409, 30.943523376218735, 23.77336794330228, 28.821050428575088, 28.348999061892112, 18.517415446619836, 30.065090925462787, 10.399106452541968, 5.654429024265659, 6.333519268420435, 23.024916956501624, 43.99688105429373, 60.14899746064217, 66.21604119577717, 61.719804733030266, 56.87156692627938, 65.27775925974693, 67.08301051970452, 65.42156903974472, 70.66356966572424, 61.14713476550195, 15.664103934841773, 45.248497609169256, 61.66210666779549, 64.13347444226666, 63.032155267653934, 58.63573135868196, 57.382934170384566, 66.95630227365803, 63.080863260453754, 57.090843108392534, 55.2800299275306, 59.538111840524984, 40.33074755822459, 14.260546526601239, 2.7580756285498222, 2.0717316962057546, 2.8327734912595446, 0.20934553756829233, 1.3603243087568593, 21.213254582497385, 28.210686483690818, 30.496177058066095, 25.927776828888927, 35.578854930016306, 38.72268169156967, 41.54704709206858, 47.27101679771177, 74.93916496153801, 59.36794373296923, 34.74686138091549, 10.91688677187889, 14.336072744861728, 14.93338990596033, 16.04489351472547, 21.338435065361764, 20.243846677964736, 32.65253928399856, 38.80980537783715, 33.878264273366625, 42.98273263439056, 36.56995550278695, 38.97710231042678, 34.476166848213445, 38.07119954016901, 32.20687370146475, 25.98389614012934, 46.89299837235482, 69.68239661185973, 69.58287039110738, 58.55125527228079, 51.77135605965891, 33.876197184285815, 4.373239269179683, 0.28306798648930365, 0.6265008209213134, 11.057441965226205, 46.556125610105454, 79.73416051556988, 64.57960874803605, 31.85437813881905, 52.375228481908, 52.59810932220952, 75.79287667428294, 107.44667068604501, 66.59400863032188, 51.822107607318515, 75.8849347022272, 7.639134603161966, 1.2151307901067119, 0.4742230114436919, 0.1534440251247537, 0.1478082686662674, 0.24028563781851725, 0.18630976398145, 0.20718147707802637, 0.209240491592115, 0.28337212339524304, 0.23163557052612307, 0.2545326209116367, 0.14769246681563317, 0.13912401853069184, 0.2510328554818707, 0.12109185629073652, 0.16547266273729264, 0.13769843615591526, 0.176812541340628, 0.1912679309926687, 0.08953425853002457], [0.05565879280648886, 0.04974759709570677, 0.05580567484421115, 0.03327048608973142, 0.11607225668886978, 0.04202996605947133, 0.029365601874287092, 0.04110390365484261, 0.06097458881295978, 0.1413129002697045, 0.05470368417821104, 0.09025363807356165, 0.07084570449566649, 0.04257619824080218, 0.04520171562269811, 0.10098864429540212, 0.05784271795663142, 0.042013525812616276, 0.0690651782638123, 0.0415776600880969, 0.14372365639334725, 0.10017833011525293, 0.08050853236308021, 0.04570150372361945, 0.05499298196105708, 0.4371600147456892, 4.705418425221597, 55.19655404552337, 60.23692131042481, 50.42329234461631, 94.2084046333067, 77.04656816297963, 41.11479013196884, 58.06861546731765, 41.654135642513154, 67.05172569521012, 64.1346001625061, 61.44046921883861, 43.71995387538787, 9.258906783596162, 0.25299031738071676, 0.10710695953739267, 17.69750475883484, 37.713757868736025, 62.071041214850645, 58.32307923224665, 52.80681471670828, 57.58737202613585, 26.957144045060684, 18.89181156312266, 20.61950775884813, 22.632081777818744, 21.858829644418535, 22.005479220421087, 15.521575789297781, 9.993594173462162, 12.357410557808416, 10.556578828442483, 9.881880167991886, 6.9335693409366, 1.6011708301882592, 5.809566119024831, 8.185037826338123, 13.408545947843983, 22.833377815062, 34.12408313443584, 40.783349852408136, 33.66722899098551, 30.34085119924238, 16.117516198465903, 15.826556740268586, 15.245697844413021, 17.93783622403299, 20.28571797955421, 2.705014050006867, 1.6975047319166123, 2.223805174712212, 8.233502141890988, 24.772272071530743, 36.40114453531081, 51.95699007280412, 59.08392098642165, 57.73026004914315, 54.57951814897599, 56.266694299636356, 62.0837849955405, 58.955090738111934, 75.10541069892146, 11.564361241555984, 18.28191634147398, 58.53808787561233, 51.20713487748177, 58.33134758856989, 48.18667450258809, 51.973095324731645, 46.79077356092392, 58.05923315786547, 57.2589127479061, 50.87788328047722, 43.31358455842541, 28.392115716011297, 9.861278899254339, 4.6720768078680965, 2.6585832382402113, 0.14264813023469142, 0.20139979619172313, 0.31784905240901057, 11.720553944187781, 23.917054168639645, 26.36487203259622, 20.583274864381362, 22.609763491538263, 27.627110365898382, 32.50685853342856, 36.576125391068, 45.31677430675876, 41.62051700776623, 19.555602112124046, 11.665639781182813, 4.589320680787487, 1.3009045681645794, 4.657457643939603, 9.878694222819421, 15.994973509542405, 20.25022445186492, 22.92899735512272, 22.430468028591527, 23.3585008113615, 25.830284357070926, 22.75149049297456, 19.236293723506314, 20.350782255972586, 23.594045023764334, 21.7430079367853, 30.839451128436675, 42.23770587675033, 34.41563683171427, 40.573710933808364, 32.46587172631295, 31.853668189817864, 3.2362250551100704, 0.15965250891543206, 0.10484514622798852, 1.6331426823331465, 24.47359142764922, 67.63378973930114, 44.58685259665213, 25.452589527253185, 39.91536463460615, 46.63681268692017, 64.09396440752091, 65.5086927260122, 32.11577077065745, 43.65370504317745, 24.70444448532597, 0.6095434953608821, 0.1444061028380548, 0.16296593111849603, 0.08949508845445611, 0.09011777238019052, 0.050880319378789396, 0.07738102437748064, 0.07338219096944218, 0.09035961101612738, 0.0780213283254735, 0.02459817734967557, 0.07965393064002838, 0.013544066779075131, 0.06539918707623597, 0.07530574581675953, 0.05598341490352347, 0.02893889473090249, 0.02002800322858797, 0.09724075064784098, 0.10125980877708043, 0.054543223232030875, 0.04897552219429805, 0.06542996848903357, 0.06250972176090845, 0.010058518025964018, 0.0965317362739194, 0.051696976766951626, 0.01448481125877269, 0.06188311929544134, 0.05387993664630959, 0.05571989980976909, 0.11102310907576354, 0.052047661175170255, 0.07710907848611956, 0.039266506885929454, 0.042133947173433925, 0.03480992445181455, 0.049765787853468815, 0.10355293209994994, 0.12311920839091464, 0.10595749823316451, 0.06271204558171092, 0.07096982606115841, 0.05310164494139533, 0.12899691839852642, 0.09595776021841074, 0.37088737252258486, 10.374875030209942, 82.86531802146666, 67.6284396263861, 68.9819868149296, 109.08512315442486, 70.61301031420308, 46.753420829772956, 31.39128350442456, 54.3866708970839, 83.33873241178452, 71.9618663480205, 67.03109402810374, 47.25868878826019, 8.905719903207595, 0.20945338742627254, 0.24789638426755709, 21.97317065731172, 50.19308451683291, 68.11596670458394, 65.66426961652695, 57.87430909372146, 48.82459702030305, 28.270441832080966, 19.592325302862353, 20.413016542311638, 25.033178329467777, 20.863685108000233, 19.157075574321134, 13.000985210941685, 15.693751169789223, 19.238515746208932, 14.518141323520293, 10.858251260172937, 9.862497775785386, 7.00498785703413, 8.21452130233088, 13.357288414432158, 18.02701915464094, 25.444707524391916, 32.88552218867887, 37.61658114771689, 31.278115280212898, 29.775490568530177, 17.231874312123946, 17.91062281977746, 20.121245153488655, 20.454530908215432, 22.725557742580293, 6.009704566770985, 3.034369834969121, 4.044903790758503, 12.01431397468813, 29.327959898979437, 42.65045688998315, 60.0024498662641, 66.87823926248859, 60.383002142752375, 58.6722368578757, 59.82346034819081, 71.83238890863234, 62.48158393367645, 81.96023894894509, 14.648235555618042, 21.540199825840613, 62.752521653329175, 58.420232419044744, 65.78703588055026, 56.83692455291749, 62.97109965355166, 57.82191015058949, 67.39221096038818, 59.340879378780244, 55.27303241914319, 51.11259398921844, 35.38232457253241, 11.624995200864731, 1.9561553818564263, 1.21118905323167, 0.18054173478195745, 0.42870718445028033, 0.16304653888988882, 15.734506557064673, 11.835882413771845, 19.707333118684833, 17.18232104855199, 23.056311607360843, 23.980210211969194, 31.502972995081258, 27.826635453008837, 42.995786282324026, 46.471257286687056, 24.082958659818097, 14.502327307578057, 8.182173025223518, 6.555545032024384, 8.236007555838555, 15.16685918454201, 21.98266279312872, 27.09841016800173, 28.32899889638347, 29.334798551374867, 27.388104661818478, 28.217952674435033, 25.241754285750854, 20.590419461650235, 18.134733323127993, 21.97986614319586, 25.79759336286976, 41.11888508642874, 55.82958144526328, 47.572525470487534, 48.97660455396099, 41.211978620098485, 33.3046882383285, 5.635523200035096, 0.07788671901629818, 0.0773203808573946, 1.4904433008163207, 27.277474211108302, 68.15320568699991, 63.296883875323886, 25.199863372310517, 31.34534274378131, 45.297880249638716, 69.42606972109887, 82.82793783372449, 47.72353279975153, 57.23455090676585, 39.09738571413102, 0.8235760201369563, 0.11979755840354389, 0.11723762963928523, 0.15495905592556924, 0.09395196583242187, 0.02893149623677375, 0.09276108981500711, 0.06643830107585078, 0.014910593350988724, 0.06082846903272214, 0.11989744860799083, 0.055032634672017834, 0.07761856526016228, 0.035402393869815335, 0.048706108223526716, 0.08418022324481318, 0.08343218435202876, 0.016972679877653718, 0.029048654063033964, 0.05876400380305225, 0.10160376693332389, 0.1755516985130887, 0.15073906059467024, 0.17723120839124729, 0.14806207359558152, 0.2932745759044924, 0.11331044843480473, 0.15408534796968584, 0.15638840745293325, 0.26545265268894935, 0.2522807207799727, 0.26072319356664536, 0.1433090189652097, 0.1353694522573102, 0.19382755332175763, 0.1323095898354246, 0.2067632083931277, 0.15764353526455743, 0.1960763584582075, 0.22122002296870757, 0.12704934669478288, 0.1944249027198361, 0.31544516043316934, 0.16870886327758913, 0.4053624629253342, 0.16900673358430787, 0.507111870833943, 11.481127565906895, 101.75328762300553, 88.094818053707, 77.80306000863352, 126.17169718588553, 96.83287036034369, 63.75910774354012, 70.93270701746788, 51.315074582253736, 80.82078256914693, 83.84286680529195, 73.63205863583472, 56.488622003985995, 11.56049672634371, 0.5387475942411731, 0.45126096615868233, 23.75061623511776, 51.000637777390025, 77.64516891971712, 68.86920298299482, 66.62990616213891, 69.54640803798553, 35.728097192702755, 29.66401484704787, 36.13493719408589, 34.98638483785814, 37.92300847268874, 38.552195872029955, 32.98587406835249, 25.463854574388076, 27.431805749093336, 26.074799030057846, 23.590379568838305, 23.291208628685247, 12.967578384184069, 20.654836546990182, 21.255520082289173, 25.40967683638296, 30.914191892070157, 43.167244849666474, 57.34520489169706, 45.13578045752741, 38.9346504980518, 19.994042688800445, 22.952582566968857, 23.728996130727953, 29.854296868847264, 32.62012873926471, 9.334500662742123, 2.789436694114439, 2.6544318997090866, 11.84343787931627, 27.65805590537287, 42.892478896725564, 59.44328461923907, 66.03226246372347, 60.23180653972011, 57.77177833741712, 61.6965490002786, 71.9298754968951, 63.132050191202474, 80.2972089090655, 19.73647632906514, 23.657487400116462, 65.78635731051045, 60.735270207928075, 63.73116870080272, 57.82664445138747, 67.62025756220665, 62.67100695640811, 68.80159701070478, 57.77694802130423, 56.79445312869165, 63.44061128554806, 36.41571221813079, 19.988671002849458, 9.702906339399277, 3.331756832138185, 0.3879878033072718, 0.7014537602663041, 0.304604648582397, 23.35200732754123, 31.228946408917828, 35.28380640091435, 28.808030120788086, 31.521064927501065, 41.30481719970703, 45.08033775514172, 45.42561615667036, 48.55654224272698, 46.54124021530152, 26.770376466935684, 21.174831044289377, 17.39971645416752, 14.104265570640566, 19.112986172399214, 25.19619203382923, 27.82503120360836, 32.216952231622514, 34.49233093569356, 35.64912811402352, 35.7293523511579, 39.75995640600882, 40.16299955306515, 34.6674882981085, 36.0306139146128, 34.20287570645733, 31.666331868017878, 43.89704496629777, 55.949233347369784, 43.46619221471971, 47.983193705158854, 42.485846780961566, 39.99311777853197, 5.171659290790558, 0.2119168503991058, 0.36565946595322707, 2.763756201151879, 31.191699581761515, 79.88021389130624, 58.51904476842573, 34.46890261865432, 52.63078658811508, 64.23849982600059, 83.02979869227256, 94.76822883852067, 58.37224614235663, 74.85345332853257, 50.98604656034901, 0.5674440834310748, 0.17581722458764432, 0.28772598493003076, 0.2545375085525936, 0.17984940580302672, 0.16453389859487935, 0.26143700365097294, 0.2591104559119671, 0.17472213254340235, 0.31714615141672475, 0.1924997084443608, 0.18310079020598244, 0.09006288984129507, 0.0849606370132777, 0.16829969571723094, 0.19666532685439433, 0.15187933650468627, 0.10822612206421553, 0.1575708641640602, 0.27100461445027785, 0.2645262991709094], [0.022137311414905617, 0.0827134713049858, 0.062149871110675804, 0.038840401121565414, 0.09231219293489572, 0.02572157825793951, 0.020545332827755523, 0.023974535814035806, 0.0469503840882211, 0.08512749862406524, 0.029984844150021676, 0.05287086478464546, 0.018038840611435233, 0.04092270470855217, 0.045613756012772365, 0.014816857705403481, 0.12474600375900347, 0.06500097457319498, 0.029696323946418784, 0.09878630239155986, 0.0607051327073526, 0.034366554896076845, 0.10151712238908776, 0.08657762645593575, 0.06136811285790417, 0.035481810374485875, 0.1277222706665916, 42.99458211468112, 70.39101200719034, 46.95767433412614, 79.09759906030472, 90.65235245612361, 33.881276653658965, 42.27302682015204, 51.931110274407175, 57.37212411818966, 71.16166360916631, 52.33554586287468, 22.353711166689475, 1.2883002767639777, 0.18062393601623275, 1.0608089354730423, 25.706137418746952, 43.070758465797674, 35.39795521766909, 47.39240630980461, 44.836225125097464, 59.07450729800809, 36.69123518851496, 18.73842335516407, 20.914346441145867, 13.071856556400178, 14.837899804115297, 14.447477863680932, 12.75258739148417, 15.265513658523561, 15.622168894737, 11.337964976987532, 12.974439590207993, 8.295864885853183, 4.770167931433647, 5.1485349574396695, 12.062471855071283, 10.821222124561187, 13.665197414736594, 17.439628531855924, 36.24717189419654, 32.77434064495948, 30.454654847421956, 23.726958459423436, 19.902865232959872, 16.729144127138202, 20.232105062853908, 18.000947160105554, 5.879318118095399, 0.5459570331919579, 0.22681532998479184, 5.987051898433316, 17.668604735405214, 27.457993453548802, 45.33127138691564, 54.836543221627515, 58.91867937580232, 56.74810640273556, 52.48911842223137, 60.171574623354026, 55.3016225753292, 77.8682811798588, 29.472518851680142, 5.93851698021735, 51.604408218014626, 48.462036655795195, 58.477102864173155, 50.95305942719983, 58.14672946929932, 48.66265020062847, 55.09160318682271, 51.76795928708969, 54.329655324259114, 53.376201660402366, 34.120549078910585, 22.739772412084765, 9.833255525558226, 4.624540132860984, 0.38402669972950415, 0.32286355752618084, 1.1312886567846423, 5.903126414745085, 22.282255388075306, 19.37919547480922, 16.583898759657338, 22.626053094863895, 24.45571326440381, 31.4782855972167, 30.877580488881758, 33.934777782809356, 24.893924382425126, 16.146448581449448, 17.721617529469153, 4.247463076345382, 4.139313034472927, 8.993250535380456, 14.811764071064612, 20.071395750968687, 25.295278949122277, 24.376006780132172, 25.81426931965736, 28.070228369005267, 29.30087201056942, 17.71041916262719, 17.675464960836596, 20.956609979752574, 23.907850327030307, 31.47122140853636, 31.088751093033824, 24.75042643085603, 25.613210585809526, 31.28952741622925, 44.077795628578436, 36.02923324031215, 4.252726897116631, 0.057410211527660016, 0.061399258162465796, 0.6702731237296136, 16.507810661869666, 54.30557197140109, 31.718391526129942, 30.781054881311235, 33.157705260861306, 45.24150010078184, 70.15543445464104, 52.511950539004424, 37.73617813664098, 46.59103862700924, 7.840948883564242, 0.2228513305946704, 0.21103500658946656, 0.04572142200965074, 0.015489209984098713, 0.03832349095553641, 0.08135292979498064, 0.0666535028346604, 0.033205759321008964, 0.06838351322878754, 0.036612445067974835, 0.01768415722425186, 0.05267401849250159, 0.046122457546692704, 0.056780111870818564, 0.03356823382238227, 0.07442056186377041, 0.010632830202549456, 0.023090728904090585, 0.04541570313214775, 0.12891906854366103, 0.02936799972949009, 0.033119785103706584, 0.02802218434460942, 0.03891992104810573, 0.03732285755235822, 0.03098042520333923, 0.030746488764341322, 0.08755115566835289, 0.04118345039446027, 0.09404693775239492, 0.1432310771797934, 0.06177001024386095, 0.06359611487677021, 0.038857523186673085, 0.035077653029152465, 0.05506305219305139, 0.031018515094934456, 0.07814113681595172, 0.09140310703866905, 0.010593377632058917, 0.04451258123041161, 0.02885067587598197, 0.06290340668431695, 0.12942171415253995, 0.07098519378491948, 0.18209111696529776, 0.03170691787325327, 0.7767614902507874, 64.16036228979787, 83.65670327217349, 55.64714024143835, 98.4381317323254, 85.9459161758423, 42.405622543827185, 30.337509339855565, 43.402520379712506, 77.21573998851161, 76.303467289094, 60.54876150623445, 22.027285637394076, 0.9998760180127237, 0.40456180911391015, 1.255517229437828, 26.07589533252101, 39.409943703682195, 47.558561832674094, 64.5308929104959, 48.002385862412, 58.6081257174092, 40.71688136746807, 20.743874349901755, 19.780226445967152, 15.89527862687265, 15.359867253611165, 18.285105228424072, 19.55649249015316, 23.818457549618138, 21.725037597840835, 16.613159641142815, 16.10749258149055, 13.979192952955923, 8.67478741753486, 7.415258461429228, 15.404425378768677, 14.795876510681646, 16.533141328442483, 21.183734824580533, 37.831425051535334, 34.352208183657744, 32.309788850045976, 24.565918137950284, 19.123352996764645, 18.82899284362793, 20.379562647111957, 16.09820833129268, 10.526471695592328, 0.5593256964798897, 0.8132543643155407, 6.52131695901194, 19.39207261608493, 31.416718113806944, 50.99451887992121, 65.134788866966, 67.93945220208937, 64.69542064974385, 58.04975278915898, 67.99545580340971, 62.58462459810319, 83.4426595318702, 30.215670716378, 7.137697819740542, 56.31763019869405, 55.47829397263066, 64.65073700874083, 56.22059076063095, 61.681530244888805, 57.090184150203584, 62.74539862909625, 56.48206380105788, 62.92344285595802, 55.907585620880134, 43.590554883403165, 28.675824672945087, 8.461915485320553, 5.423951533532912, 0.40545427090217995, 0.40731770316919974, 1.547456054437545, 14.170175117831077, 11.781019241579118, 6.894698652528948, 10.632763024299376, 17.004625912635557, 25.909104385683616, 33.49209908516177, 28.508792500342096, 36.856708218974454, 28.69110622713643, 21.080549032457416, 17.262486450133785, 10.314664686879805, 7.58680037913784, 13.500264690768335, 20.567771696275283, 27.43302756740201, 33.26195401530112, 30.258189209045906, 32.61455701243493, 33.56279588514759, 32.447275769326, 22.482739494692897, 21.166566610336304, 23.752051822600826, 23.12653183937073, 32.839244104200795, 39.651196925870835, 36.99304588379399, 37.21404398641279, 46.12544152044481, 52.30411983305409, 41.82122468948364, 4.792202336172904, 0.046974052374641743, 0.2865207447640358, 0.6240335887958927, 18.66996426736155, 61.63652889190182, 49.41268582497874, 21.072208112285985, 34.55176661091466, 50.89549864492109, 79.23478787945163, 70.62258874216388, 47.791629068313114, 64.54282868293025, 16.60747220439296, 1.251251161579163, 0.014745627807813787, 0.2037994900057393, 0.04525079887600676, 0.10398883612886553, 0.1084602844991511, 0.090776048750887, 0.06750279556839697, 0.008257300716884916, 0.04429998034010491, 0.037282258722810976, 0.032745283021922075, 0.023026756731973543, 0.025408426412351193, 0.052275514876049374, 0.09645515046412907, 0.03282161219225776, 0.023545068838903983, 0.06887837538435575, 0.048561834715186596, 0.017439164221286774, 0.12542402221550866, 0.2382127877565161, 0.16451727448692247, 0.10337508478832823, 0.19041666941296673, 0.17708379775285724, 0.1404885896631787, 0.13504061667669204, 0.272530171299173, 0.2875795089189084, 0.28319043798312066, 0.13740946779087668, 0.1798611269482682, 0.14062886036211444, 0.13867374269231675, 0.2029949751111769, 0.2928174665618328, 0.3070943424057576, 0.15059332002795514, 0.27165364413972826, 0.15325307004874753, 0.15540390786144043, 0.3281278073066666, 0.22295263806177726, 0.2298851362279346, 0.07301135844881497, 0.4429064096222001, 73.32999690886467, 105.91423203868251, 72.423458714639, 110.44918229503017, 113.5730363476661, 50.01407930927892, 55.47146904853083, 66.53787951315603, 67.7861032178325, 90.88826733250772, 61.05129949508175, 29.51170725207175, 1.933689148676011, 0.6365924052173092, 1.1165865102121908, 31.769015596758937, 57.143806872829316, 51.68230648963682, 65.1703098512465, 60.132660788874475, 71.12810380997198, 46.34859692665839, 29.6588530079011, 35.302767138327326, 28.99956337867245, 29.754839289572935, 31.501704108330514, 29.698159079397882, 28.348196937191872, 29.6039790491904, 25.58598149207331, 29.63854689751902, 22.37518810456799, 16.397825441052838, 16.100649026132402, 23.41893276860637, 21.0705058036312, 23.513758028707198, 25.716869023538408, 50.5897577347294, 44.06757393190938, 40.57534263980004, 32.049831805690644, 28.12447278730331, 24.382176668413226, 30.82685639781337, 31.483704351609756, 13.488768223793278, 1.3010053240483808, 0.6738467706787972, 6.968683869607988, 18.035024712162635, 31.979266405105594, 52.28280567353772, 70.52958934537827, 64.78415250778198, 63.55550535263554, 60.11544550618818, 69.19251611155849, 60.185483347985056, 81.996520873039, 36.26706615571053, 9.633529416976437, 58.475479002921816, 58.69254296825778, 65.45086130019158, 58.46716357815651, 66.92078913411787, 60.81202314745996, 62.7067122920867, 53.53253164599019, 62.12000416171167, 62.37933558802452, 48.80187472989483, 35.17712969933787, 17.818084301487094, 7.74534454268794, 0.4571865336789239, 0.6106900531918772, 3.9347678038381764, 24.22177134021636, 32.82247204934397, 31.629496889729655, 26.746638282652828, 31.309702127210556, 35.41690418797155, 43.96993044883975, 40.78714670673494, 40.76345951326432, 29.055323793042092, 21.98477891183669, 27.840193125509447, 18.765011141377112, 14.603006705161064, 22.16083645820618, 24.26346025159282, 30.542884642078032, 35.06662476447321, 31.912342925225538, 35.12647621093258, 38.73339368451027, 42.808540175038004, 31.559457086747695, 33.36888959330897, 40.213617740138886, 37.26667042701475, 44.348713736380304, 45.870663965902025, 38.15109822057909, 38.61114517334969, 44.873930869563935, 56.33615947538807, 46.69381649263444, 4.8342040565706075, 0.16280008840464777, 0.24277410590119902, 0.9434008129662084, 20.515082497750562, 68.34004386778801, 44.51877593994141, 37.744815195760424, 52.97645722666095, 65.46234600005612, 94.35290475045481, 86.20222737712245, 56.528237942726385, 88.19267334476595, 19.494887744226766, 1.0749142689089621, 0.2818561886106768, 0.21901790323036335, 0.22385133580575067, 0.21916707587097922, 0.2996440454115791, 0.1621420495212078, 0.2153632041787909, 0.16118376545848387, 0.09195836756618754, 0.1273611061755688, 0.23925148040777255, 0.12412696641178862, 0.2621037759367497, 0.1267394258250152, 0.1582165996754362, 0.1041234530989201, 0.10449901238204011, 0.15983456204975807, 0.19081952440882885, 0.23123588713426746], [0.07011094190660985, 0.040775757553356315, 0.03239010550802754, 0.09688681802682339, 0.030513659322394, 0.08567293790439445, 0.09295095704616078, 0.02487837017754153, 0.05285049450673884, 0.13898091330643625, 0.016725800383175095, 0.07995099655442661, 0.15708844327638227, 0.10539906610163952, 0.06823991004738116, 0.053466153406207605, 0.029952649305003787, 0.12402141481758126, 0.06267028995939801, 0.14579071483064085, 0.06487050979969002, 0.08349366290795227, 0.10281435439303037, 0.12661716585317928, 0.1858194677099105, 0.051441214482990966, 0.4522344187623071, 18.874207965789303, 71.44844378194502, 69.5991325378418, 66.78639304253363, 98.5597252076672, 58.51880550384522, 30.419051493367842, 58.74649516997799, 46.46538157616892, 60.28945753651281, 44.28226094092093, 8.401719850878562, 0.283411561601585, 0.3461196273565293, 1.6190591670813101, 24.50861034854766, 68.62414898410921, 54.87895973267094, 43.20816693767425, 64.23545606674688, 56.99994217964911, 31.456608618459395, 15.151088314671671, 15.652200521961337, 13.395578592054306, 12.603407886720474, 12.682335780512902, 18.364415553308305, 21.24641626111923, 20.803827777985607, 15.17570314868804, 13.412168256698118, 8.391134354376025, 7.586168877540096, 7.610396867798221, 13.009575201619057, 10.259011157097357, 8.26345237993425, 13.504337091599742, 30.096628742833293, 33.74973212519, 33.48162243443151, 23.128906834510065, 25.492762442558046, 18.35248762561429, 24.03016944085398, 13.145086226924775, 4.428983503772367, 1.104129307693051, 0.6854740241842886, 0.14123364081305845, 5.908492707437085, 20.122527768535, 33.58623596929735, 49.48672056198121, 58.75324949141472, 56.793872617906146, 59.289496329522905, 55.87527313540059, 53.09315558402769, 69.84673607733943, 34.89756668767622, 2.351349130753548, 42.909874608439786, 46.39351590987175, 55.85564559505832, 52.58101171062839, 57.57099220829626, 49.85427018134825, 55.16316683061662, 52.44147731411842, 58.51912713819935, 58.73606166531963, 51.81251348987703, 34.46594515154439, 13.864120418025603, 3.3389217767023274, 0.5395199334429157, 0.1455878394265329, 0.2445485800384514, 2.577604925440204, 10.98537233568007, 21.559564567381337, 22.337596108836514, 27.86669069720853, 22.852724905936952, 33.374761381456935, 26.627690445992258, 24.865612714521347, 17.854162262332057, 18.307984413639193, 21.330729569158247, 5.605405280666967, 8.092793976106952, 14.676585466630998, 21.792924019598193, 25.735331619939497, 25.76104275641903, 28.379187583923343, 27.47330834788661, 29.169992323844667, 29.17297136399054, 21.82261440061754, 19.3080299515878, 18.339906623286588, 25.280925035476688, 40.072706591698434, 54.32486218790854, 41.15895994247929, 26.11162812479081, 23.801787476385794, 33.92889422755088, 30.06131760535702, 4.000053939319426, 0.2277587059765093, 0.1657189906484658, 0.18461372192588546, 10.47485036234702, 34.2618485419981, 34.825438222577496, 37.900160666435, 31.131869708338094, 50.291418337052875, 71.2959655638664, 41.14385097257553, 42.16738170193088, 25.34729349997736, 0.85819443026858, 0.19811191536005468, 0.13190268989532225, 0.02919111385821335, 0.045959644710585, 0.11051143895113662, 0.1388646977683229, 0.09970401443781392, 0.1186165879029901, 0.03978711725663274, 0.042276945145380114, 0.06046927338766475, 0.010171483436058606, 0.04239512952945886, 0.12650559280788706, 0.12088560243888248, 0.01861168285681596, 0.040323440090663014, 0.058392646512196916, 0.0360259281531457, 0.024828323568668098, 0.05768937396726782, 0.009656774815202001, 0.038860020633306236, 0.013477510975433454, 0.04999716555879963, 0.015220447188063015, 0.06235272736258565, 0.04143816313796467, 0.04308387321690398, 0.09039998384973696, 0.1540563285591141, 0.03043907108686624, 0.02968918209174468, 0.08399557307242386, 0.14667686405441455, 0.06858757606917812, 0.05850184468492385, 0.061609250523390315, 0.11064891342914875, 0.04279736782454195, 0.17615171389714365, 0.07895100666510482, 0.042396439539809386, 0.06496723606100967, 0.18231388001192003, 0.34391433601417853, 0.14661635843015489, 0.15839165076613426, 29.378109362817582, 92.72592913719916, 71.6584082572691, 81.66869701877718, 101.12108784337198, 52.13337513708299, 33.73969870228922, 34.65641936948223, 65.46464058660692, 68.97873124768658, 49.017993404019265, 10.037038345490734, 0.5751128687012581, 0.3405403622215794, 3.1970957354191816, 27.56635677429938, 80.86679981600854, 62.89141670350106, 46.8292010215021, 59.30475827186339, 58.68491395827263, 41.92703846962222, 20.15599931440046, 17.29470479872919, 14.702654519388753, 15.033524094089387, 18.930962700997632, 29.173049811393987, 30.508965946012932, 29.1389585310413, 23.075084071005545, 19.549722479235744, 15.433482297005193, 12.280476208656067, 11.640781760215761, 13.415728788222037, 12.741863631433057, 12.480823032317623, 17.83499756167012, 32.39905218924246, 31.707461841644783, 33.63952529045844, 23.521867529038463, 23.5698224267652, 17.38449961908402, 22.25884864407201, 13.450817331191033, 8.398783956804584, 1.203554282265325, 0.8916171916550206, 1.7975148750889687, 8.126954878530196, 23.206946311458466, 41.911949111569314, 55.616651658088934, 63.257358151097456, 62.587558530992084, 65.50887315504013, 62.75934265505884, 60.334882505478404, 75.09579304725894, 39.31532436801542, 2.4109880337792062, 50.28586426088887, 56.017192332975334, 62.87971235090687, 61.74671611478252, 67.299972503416, 58.56661527387558, 63.57147724397721, 59.20571842501241, 64.40276084407684, 68.1033915858115, 52.34688543504285, 37.80094039055609, 16.39379030273807, 7.010677745265346, 1.238256226624212, 0.1994587438962152, 0.6727684866036139, 6.906641289111107, 2.9986348363661, 5.095239752723325, 11.198751234239149, 27.547817691679928, 29.629490144791145, 28.695522815950458, 28.072511188445556, 27.098372905485093, 21.16183230953832, 19.14127822845213, 18.428050125798872, 13.50442534492862, 13.036835674316654, 20.481279511605543, 28.654916478741555, 33.257737467365885, 32.86365693615329, 33.27991454832016, 33.36632436321628, 37.30059892900529, 37.47863531112671, 29.906501654655706, 26.752082532452, 25.970738549386304, 31.28744463766775, 42.931177000845636, 55.21313782661192, 45.00030571414579, 32.66230598572762, 38.30589455942954, 40.41209359322825, 34.26393524292977, 4.668720239593137, 0.33708631691913454, 0.15143076138150308, 0.48633768073012756, 11.058973650778494, 53.02319618963426, 38.0839668550799, 25.787024536440452, 42.79410977517405, 58.06684647836993, 85.6482945719073, 57.97893831806799, 55.22486571342715, 53.19923608533798, 1.6335379837020751, 0.316565609987705, 0.08854449591449193, 0.08220154837134384, 0.028895453715156165, 0.022049201727514307, 0.1678695833130229, 0.0655674965932004, 0.06559877596314877, 0.13141214847564697, 0.054007976751534216, 0.04762616556798739, 0.0829346485496048, 0.08131330772753685, 0.012466884912892938, 0.04351636815455653, 0.015435355918241606, 0.06614755538682784, 0.025367440708402186, 0.09256381451362565, 0.02281923883504445, 0.0358462039261095, 0.225048256256888, 0.13158657137424717, 0.12346981619034084, 0.17445415498748904, 0.13891349756909957, 0.261092018936911, 0.12775103726814832, 0.08192331289812442, 0.1184296164841902, 0.19742341682074532, 0.16015196759854594, 0.2269419336751584, 0.33656451911214863, 0.36672874083442075, 0.1355721897655918, 0.07741175216412352, 0.15725145146491068, 0.23680738413766508, 0.18422647980192017, 0.3167722392226419, 0.1964920224441636, 0.1396541820178109, 0.33934373288385333, 0.27852422707984525, 0.44194294680510804, 0.1796444466397647, 0.32593639747750375, 29.41788611873504, 116.39187120622205, 93.11621281408495, 94.99554587948708, 125.04860493444629, 79.60616573210686, 47.49196783188851, 77.68254126271894, 60.26309920895485, 74.69326373069518, 54.190881867562574, 10.193422263668431, 0.6806417254190291, 0.840383927908636, 4.419290836780302, 31.02692081082252, 85.37915722016366, 74.28131288097751, 55.27615854817053, 77.35083426198652, 68.14470983320668, 45.709391793897076, 28.664208573679772, 30.048607164813628, 25.42587426400954, 27.886100546006237, 27.813617106406923, 34.85375773522162, 37.683430102563676, 31.726899147033695, 31.31268312854152, 28.886350047203806, 23.70585806908146, 17.633940789007372, 20.237543429097823, 26.83522697417967, 18.19569480034613, 15.398688912391664, 20.016912068090132, 41.74856278204149, 43.594598847050825, 43.58398883573471, 30.36879808672013, 32.72857835215907, 26.093702893103323, 35.199475442209554, 27.714975380128433, 13.409606948975595, 1.6449338173674, 0.9332051632865783, 2.1555532370844195, 6.28615027473819, 22.429536465675604, 41.22462434153403, 56.20091615184661, 65.4207218077875, 63.648955821990974, 67.20696526189005, 63.06271837603662, 58.51729931369905, 76.28896236419678, 41.06503094396284, 4.952548828817183, 53.26802661342006, 60.463191078555205, 64.28195968750985, 61.41051407783263, 67.99300039968183, 61.17536014126193, 67.02657545766523, 58.40235425579933, 61.388917507663855, 62.907823977931855, 56.60079786854406, 40.07075325135262, 21.172050083837203, 7.073478814094298, 3.0285686494842654, 0.3796818473887059, 2.2039474402704546, 18.22045672324396, 26.33654271402667, 37.18246890652565, 33.39486352859005, 37.38244702739101, 31.73361816713887, 42.69491695588635, 36.23683644879249, 29.617377865699034, 23.323572104977025, 26.01405720556936, 33.737957169932706, 19.31956760344967, 18.695924474347024, 25.717231842779345, 30.27314912888312, 34.58248661410424, 35.62841407714352, 36.7996887237795, 36.276417086201334, 39.19125195472471, 40.92278226729363, 33.828952235560266, 36.62351938986009, 34.278581373153195, 40.586282130210634, 53.34011193244688, 68.31822764488959, 57.792990515309, 38.27062460684007, 40.20971105944726, 48.60634849917505, 38.96282880536972, 5.152077838297814, 0.3771331341516587, 0.2964133913478544, 0.40858426101265416, 12.124928735917615, 49.969391745905725, 45.861909235677416, 54.45719119041197, 64.13030516716742, 67.61057715262136, 105.68349469092585, 64.94464412812265, 68.75737620938209, 65.42899408648091, 1.1689269855137796, 0.4179716572886513, 0.36454646277331537, 0.23339889042319792, 0.10082228064176538, 0.2581276263921492, 0.2906566083190903, 0.2168433779790517, 0.2468291778237589, 0.23656746072153892, 0.18752413591550243, 0.1629640312204438, 0.121035709706766, 0.3002945766333611, 0.24760378464575739, 0.2861589061156396, 0.1678064423463037, 0.16827784688963046, 0.10023063093784357, 0.19135220066433956, 0.17257762261696402, 0.10824259295458756], [0.0015798401633923453, 0.050825256809231736, 0.03852538576710128, 0.05310344524801739, 0.0358280016770286, 0.10367626459487986, 0.053257823456078775, 0.08343396933689233, 0.045233289936497334, 0.027384305064896905, 0.03587328130379319, 0.0633216025908628, 0.1347024961104316, 0.051353279080602436, 0.11905489744798792, 0.06194729065041869, 0.1603934997993131, 0.017228463229032296, 0.05029831089139466, 0.03156570871661027, 0.046527572501931465, 0.1941942949328692, 0.03177531803357265, 0.05181378219276667, 0.24159353376636583, 0.17621955864371794, 0.7607621423179104, 2.5914043140026832, 71.7731140505883, 87.5726564468876, 73.49415594531645, 94.88182852345129, 81.22571237625615, 41.5430345073823, 40.826178212319654, 43.86782330851401, 44.703688236974905, 32.792754211733424, 1.7446291903334281, 0.770527066722993, 0.3664666774772829, 1.9835194296413854, 27.72617570815548, 48.7958852706417, 51.83130164300242, 71.85691156694966, 66.2095614402525, 59.97607584922545, 29.924419041602846, 19.104594261415546, 15.975773507548919, 10.758920177336663, 13.640391365174326, 24.18381456405886, 32.00169844012107, 36.488181929434504, 22.47503988204464, 20.960865751389537, 17.52636782584652, 15.08233799088386, 8.670683637742075, 5.838533803339928, 13.46268936511009, 14.258822644910506, 10.394499628774582, 15.905122795412618, 26.48631645787147, 36.86467063042426, 32.95779382028888, 26.159747762064782, 26.55859201185165, 22.830063412266394, 27.30326379499128, 8.5894739051019, 4.0390722069048115, 2.306104345667747, 0.22591873132173093, 1.2245248666694089, 1.385562554482491, 0.8778918378295437, 14.222171037427842, 36.69422795695644, 52.272807551968484, 61.985070705413825, 52.466717766177275, 55.904373199709006, 53.12049842649891, 69.22767623778313, 32.416377298293575, 1.3005358653683818, 44.735761457873934, 51.81059545086276, 59.777309740743334, 58.72285112257927, 60.88322593319801, 54.247799381133056, 59.997935218195764, 53.62313055223035, 57.642049866337935, 58.22427472760601, 53.303590743772446, 41.04578779589745, 22.328743319357596, 1.842880885927908, 1.326106777114253, 0.21180809655737495, 0.08599685520053872, 1.8237039278591833, 1.3891436784498155, 11.109048589583367, 31.98804270836615, 26.84564675054243, 23.461478717865486, 29.228384648599935, 17.63700023774178, 16.774082722202426, 14.735812275640427, 22.43775579237169, 19.202118112194924, 8.116498820243343, 10.802638915277297, 15.46030346424349, 24.902408469107844, 30.403112942172637, 30.770586075321322, 32.94488137768161, 33.42889401220506, 37.858575697868105, 36.091802889300936, 25.868468630698423, 18.038658788127286, 22.986059996389574, 27.141501326714796, 45.67996617286436, 65.03755723276447, 50.529549352584354, 33.20009431531353, 31.252751273493615, 30.164146461794456, 19.33557479612289, 2.233287504603786, 0.13395151544001796, 0.7724239617105454, 0.3675719584909178, 6.763920457132402, 18.143217409810713, 33.816349660196614, 25.20038308635835, 34.36794473278907, 54.97714842519453, 67.63535084262972, 32.80728659322185, 64.37494731718495, 20.290367949393488, 0.8288798613413688, 0.21948650389188723, 0.060506371195398034, 0.08066866006101332, 0.0713774154803926, 0.05125526962200961, 0.1089242886331293, 0.12028878164147178, 0.09540981583056912, 0.1254118414175126, 0.0856215104220375, 0.08198862955454858, 0.02749193467259888, 0.050691245048637354, 0.08881336979327664, 0.08820923285618906, 0.05512773682693801, 0.02917521753378453, 0.056953171132913524, 0.04756161499948752, 0.02368518248981526, 0.018866776729062684, 0.047522111675671996, 0.08308333089394916, 0.0970368869903107, 0.06719055345221873, 0.02963035036959956, 0.017465201634613257, 0.07691567958963495, 0.14697378441210718, 0.025051138326225263, 0.03884508957966201, 0.06711027509863339, 0.10786442131164575, 0.07456636371751947, 0.05116667155356658, 0.16760684579851168, 0.006447822107152353, 0.08260582829074514, 0.014095066900124714, 0.044200714497316274, 0.02319965320038459, 0.026605609248602585, 0.27840266424802046, 0.10701618577924468, 0.07019418502046217, 0.42141844007757406, 0.3954932279884816, 0.6373054798572295, 10.757894477536603, 95.25490084002095, 90.11801581228934, 87.95558175733014, 105.13108376533755, 73.92167075987786, 40.18342725692257, 33.802107534100934, 52.37720143410468, 61.89487188093124, 35.04246688658191, 3.0110447252950365, 0.6746283029356311, 1.2611020716928667, 2.5439443703620666, 30.030003363086333, 57.124908893339104, 53.815436517038655, 80.16817077513664, 74.79171522202031, 69.60375308990479, 37.762532541828776, 21.703570465887747, 17.650250004183864, 16.516883104078232, 20.756973105092204, 32.96370483213855, 42.932871464760076, 39.336509089316095, 29.940828277218728, 26.599470953787527, 25.869610040418564, 19.419646878396314, 15.278641831490303, 11.815306640440419, 15.49872111889624, 15.044235106437439, 14.935876688649579, 21.73350795622795, 29.026539479532552, 33.88119428388534, 32.95679361589494, 24.077808587781846, 22.615241081483905, 18.736599453033943, 21.734869018677745, 10.014564144995905, 6.6153744151515355, 2.230273408274497, 0.17473022243188274, 1.097437499030944, 0.8303041720101911, 4.168264539011063, 20.91366002636571, 44.04890344988915, 58.20766348992625, 67.38893185892414, 61.241801169610795, 65.9759529175297, 59.43860130925333, 75.75151920318604, 34.869031444672615, 1.9049705348668562, 50.351752235043435, 59.64292933863979, 67.16565485923522, 63.53754089724634, 66.65510346812587, 61.14785255924348, 69.28968106546711, 63.12718252981863, 65.67560134395477, 65.94265199476673, 62.12468747169741, 46.82153278781522, 25.279840500124042, 4.797798577816256, 1.2359251130011775, 0.10127474749160391, 0.11913516047981479, 1.0261662556759774, 8.325711181086879, 3.3102872487037414, 25.008016324812367, 31.374125096105764, 24.056445398638328, 26.756332420533706, 23.647261781077233, 19.888115159926876, 17.874403653606294, 23.650621291129823, 19.432529903227284, 13.598018980795338, 17.716696916087983, 19.792921197029855, 27.827266954606582, 36.01637963325747, 34.04863634417134, 36.17204673828618, 36.41986600814327, 44.147343174103774, 44.281197978604226, 32.65733242034912, 27.543248130429177, 30.765441886840332, 35.81500122624059, 52.74243685507005, 64.46990005431637, 54.32156347459363, 42.82697923721806, 42.01052611873996, 34.01783789357832, 23.00298502368312, 2.51821558321676, 0.3347096976733977, 0.16752599287898312, 0.7053054052014506, 7.1142126283338, 25.108838888906664, 21.942799745067475, 31.58198129746222, 49.68543567965108, 64.91125299084571, 86.23497132332095, 45.19184681677049, 68.30001215780935, 28.045962625934234, 1.1837901944114317, 0.2055914003041483, 0.054524354486455845, 0.11360850260262528, 0.0410510512489465, 0.30918484313353417, 0.07341854184144929, 0.23080246523022654, 0.09101403396456473, 0.12339937440570324, 0.03788159994949256, 0.12097009427605138, 0.0077366213982684486, 0.048086266483991384, 0.07404427479712233, 0.07295390185449394, 0.04505612444312823, 0.05171281563478613, 0.05455992777921981, 0.08156368824382944, 0.1423608932283617, 0.06543844908235535, 0.15019552121239324, 0.13166143348620785, 0.15729493461549282, 0.16572283640984567, 0.13077816475302945, 0.13617985070713107, 0.17961455388895928, 0.19594471390929916, 0.12131068164542799, 0.11117937569055827, 0.20571333085817678, 0.28039921195276324, 0.2525997964004355, 0.17321151440903065, 0.2645428160265569, 0.10954675039336567, 0.24655150159472422, 0.17259326613237783, 0.20592722260663587, 0.13269536107057525, 0.24239184334874156, 0.30498950051203855, 0.20596707450045695, 0.2539552510866235, 1.1393105166573678, 0.2872846876421283, 1.333232988272944, 8.875002841795645, 110.32501574485534, 112.13930022331976, 106.35057218613164, 121.53977024939753, 100.38427845124276, 58.95492207619452, 52.41173398110175, 59.029223534368704, 60.37234506299419, 42.38441428830547, 2.472095128989989, 0.8516179638043527, 1.551334052797287, 5.618662891849395, 35.89937925338745, 63.825419333673295, 65.8888449207429, 91.27968849674349, 76.57611123977169, 73.5401810369184, 43.073751234239154, 32.44099017112486, 31.46567125474253, 30.212532820240146, 27.328398343055483, 40.14605883629092, 46.07931836958855, 50.51609562289331, 34.83096876452046, 35.07080993344707, 30.720697449099635, 31.465532010601414, 23.55605882983054, 17.387719884995494, 28.841338888291393, 26.91063650192753, 17.96340027163106, 25.007300492255922, 37.61522400763727, 46.61504745483399, 43.25166994525541, 35.21020704700101, 32.70701119976659, 28.375347583524643, 35.03524188072451, 22.313300947989188, 11.368886982240985, 2.4526296315654634, 0.4397877882565222, 1.3255214859401028, 2.0004141811401617, 5.725080716994501, 23.55944971884451, 46.79557454201483, 61.19578000037902, 73.00496578216553, 61.7822684780244, 66.22700029803862, 59.15218591690064, 76.4475751692249, 35.911746486540764, 3.0503632993467393, 55.68199442278955, 63.97068823537519, 66.28494155022406, 64.81426062122469, 69.51273056768602, 62.23500805516397, 71.18799840250324, 61.6340381868424, 63.660295394159135, 62.56624044910554, 61.652100701485914, 41.97176917906731, 26.225392549268662, 5.198725115868354, 1.7159354590600537, 0.3125392663623056, 0.4413791980233885, 10.513999539036906, 19.65355350125221, 25.48198965287978, 45.103326766721665, 30.02181737653671, 29.904673830155406, 39.91418400118428, 27.099883018001435, 24.37249233645778, 19.767921970736598, 30.623204977281635, 32.669348601372015, 20.998349881941273, 20.81855627798265, 25.390070869076638, 32.28102807075747, 42.24314620417934, 40.15435072683519, 42.3922590286501, 40.46063684648083, 47.93167337294548, 45.733977210137155, 36.39956774250154, 31.43095631753245, 36.83580198595601, 41.569290853315785, 60.27394064011113, 78.80902244198707, 64.72300275679558, 50.517178197060865, 48.873779619893725, 39.77042128962856, 27.590822558249197, 2.955626782871062, 0.8169413922775177, 1.3647585482366624, 0.6829740647827426, 7.2914753229387355, 25.653463909702918, 40.04153551593904, 50.36845368723716, 64.6962914159221, 77.07170271104383, 100.11481162040465, 53.72566523090486, 89.66327190399171, 35.56551887143043, 1.0892783562021873, 0.4132232911163761, 0.11747766796860004, 0.16945305640899366, 0.1731861109334615, 0.35757628840304195, 0.2936825330459303, 0.3664230411091159, 0.15136029661422776, 0.35098345830075206, 0.10045943841818841, 0.1393230481734199, 0.16372619677455197, 0.1238112002911587, 0.27920500345287785, 0.24844459678617217, 0.17213096271359152, 0.13509461055359534, 0.11473646747969812, 0.16402707014593387, 0.23844338022172454, 0.11698051521013822], [0.055583183758801995, 0.04858824176593654, 0.08473090256654447, 0.03677083757675944, 0.02369892227673723, 0.05149518920769615, 0.09830111592647531, 0.03944300205236481, 0.025599166983738545, 0.07688024036225773, 0.09487105683693964, 0.060400451878987016, 0.05834373179823161, 0.31535454755348546, 0.06952867677976048, 0.16047211574210277, 0.03915838123629651, 0.09142429703065465, 0.03284733359431548, 0.026017188605281617, 0.031076486883384567, 0.04958670714028901, 0.02758338450334005, 0.05951577354402793, 0.12826197194836794, 0.05891691495273864, 0.1380157038088768, 0.29151851852093974, 51.492016623097086, 92.46197715882333, 69.6417373226535, 85.3466486161755, 92.01055942043182, 57.60133174157912, 29.806022297951486, 44.474292339817175, 33.72354638191962, 22.885570833759925, 1.0567512435297812, 0.4469695561114819, 0.2596646132728746, 0.4347578694503154, 27.529508067715554, 47.1651049583189, 57.16404630291847, 64.77854351843557, 63.2762522082175, 58.47112124966037, 39.64385424890826, 26.94542988654106, 14.113534131357747, 16.2256569247092, 16.354469522353142, 36.726614967469246, 40.690538729390795, 43.45472712670603, 31.151328586762954, 26.326319056172526, 19.683853810833348, 15.830222195194615, 13.145721650892689, 8.429771661758423, 7.800329308356009, 11.689300498654767, 12.109575598470627, 21.25850892836048, 29.94407992209158, 29.32290396382732, 29.434922933578495, 25.843281130636893, 32.79760422245149, 27.55216367783085, 31.263286759776456, 5.299998262236196, 4.515592869251005, 1.9116499635481068, 0.061669909365234844, 0.1375646618825774, 0.26589174364362994, 0.7944982643088987, 8.15156529988012, 19.83955425600852, 34.10250617611793, 55.07661188802412, 54.750984561058786, 49.02728942132766, 51.8091873199709, 70.99319781026533, 21.6268410605769, 1.7075205041516213, 52.977657471933675, 63.89292724670903, 58.63400159343597, 58.89650621721822, 64.1685639658282, 63.65833028670281, 57.93356433991463, 50.27221049031904, 55.09764363688808, 57.48531587662236, 53.43328391352008, 36.80921616092805, 15.304279423529103, 1.088544014961489, 2.092045161031908, 0.17038711677155188, 0.23362044305089982, 0.33279987112168347, 0.5717669030831707, 5.4398096761395855, 22.060837591848067, 23.064013181194184, 21.58029233255694, 30.624758235869873, 20.281948581818614, 12.556500261829747, 16.12189454417075, 20.8096799542827, 17.594603338549216, 11.206007619057933, 13.336217441866475, 19.324547052383423, 24.734976214747277, 28.08875764569929, 29.59211584060423, 32.16401200140677, 37.473579375974595, 39.2926295341984, 40.65320953246086, 34.58282393793906, 24.786845637905984, 27.200866399272797, 36.52291843968053, 49.88742989878501, 64.15802455717518, 52.30827754543674, 34.50286249960623, 35.14168324009065, 27.609079230216246, 13.749819609426684, 0.9342591776963204, 0.41925228050639557, 0.2878744834132733, 0.24402092931972397, 3.6244649319879474, 14.210925602143812, 19.35698897607865, 8.82901010974761, 35.15977321132537, 63.370192973844475, 52.953601575666866, 39.815053939819336, 62.17227758899812, 2.621425645005319, 0.42100171889028243, 0.1337702590371332, 0.09971851648222055, 0.07364600100704739, 0.16221274411486042, 0.10895742193585443, 0.11891399089607502, 0.08009188012370179, 0.01469688833646116, 0.27218978311265674, 0.0939353647071027, 0.0898495420152622, 0.0777372629231503, 0.0022079350638969414, 0.04240989204375975, 0.04780408565796191, 0.09050761154221912, 0.0431793392635882, 0.09717519650416029, 0.049297240818099636, 0.0252981269882331, 0.02276327994261538, 0.0929194784933521, 0.12361329679767932, 0.05002319722646668, 0.04001057361282649, 0.016326308513300556, 0.027607958688731157, 0.04196969026158895, 0.011741988578691118, 0.03911107913741181, 0.026241018429338455, 0.06185628706589342, 0.07050652672807056, 0.12219804128812206, 0.17220804648053262, 0.049672899692649805, 0.04376005689283052, 0.03860063475346373, 0.022943542346418388, 0.011783116008906115, 0.05949204780101296, 0.03962995048852698, 0.03827631526115922, 0.030030864966853015, 0.12232338859429284, 0.030335179988234758, 0.41812846016499305, 0.0241235111870112, 1.1257692690818542, 79.61491261759113, 109.91228826584356, 85.05293369293214, 94.81394014050885, 97.8060104000953, 52.129072297003965, 21.708328300906768, 40.644219460025916, 48.56496749385711, 26.46019151133876, 1.1948028615405484, 0.4134604412942164, 1.0996726371588246, 0.5762542171343681, 30.684511623074933, 56.45315593288791, 65.23798642619964, 74.97401914288922, 72.31724877511301, 68.0075288588001, 44.55921557641799, 31.70332766348316, 22.11150088617879, 22.81136743484005, 24.46053581853067, 48.21822997062437, 52.55954850104548, 49.98207276867282, 35.937720421821844, 32.486377877573815, 25.819340944290165, 21.152100909140803, 18.763032305625178, 13.306580993436999, 11.900543666655018, 13.096129163619011, 13.408324333929247, 23.163674723717477, 28.300479342860562, 28.510620324842392, 29.697062776934718, 23.948580218899636, 22.64545706010634, 13.899428613724249, 23.07478597087245, 6.911396182352497, 6.321619777910172, 1.4314104039822857, 0.022911640530031537, 0.044703961485215736, 0.24611501533898617, 1.273443073995652, 9.318740579389758, 23.934483220500333, 39.027849935716205, 61.06647122290827, 61.76131517656388, 58.03657754775017, 59.78792367442962, 74.40300833794379, 27.280245365635043, 2.17190706922162, 61.23380737919962, 69.95671149223082, 68.9552519398351, 66.49061495257963, 70.57224119863203, 71.9493696766515, 67.69220952064761, 57.37414021645823, 64.12688093800699, 64.3239761167957, 62.469302992666925, 40.36513105515511, 19.302156202254757, 2.6926904532217213, 1.915934049794751, 0.20215794744510807, 0.437848084275761, 1.7331234077292106, 6.766133654502131, 6.458527657293505, 25.194423044881514, 27.063695230791648, 19.443822406953384, 27.818557331638953, 24.064205808024255, 19.089122472270844, 19.294025128887547, 21.697730056701168, 19.96876301303987, 17.546111076108872, 20.009618420754713, 25.474809754279356, 29.37735038418924, 31.785326773120513, 33.95324822395079, 35.65702384518039, 42.37914654516405, 44.16161275679066, 45.917265645919315, 40.51544020252843, 35.10302043730213, 36.75535809609198, 45.99933339703468, 54.103966066914225, 69.09083258721137, 56.860874545189645, 43.31898566215269, 38.55985626097649, 28.846165364788426, 15.156576691135285, 1.1335451228003348, 0.24668910630768348, 0.41950849095179193, 0.5590787710201356, 3.8888584221563036, 9.435820387255761, 14.239586360992925, 33.14791110254104, 50.56284635297714, 76.02037414427727, 72.24322580522107, 47.074349157271854, 84.5471283697313, 8.208805428397271, 0.803944189702311, 0.05522665026928148, 0.03652260976753408, 0.05320335460466243, 0.0775319436985639, 0.12422945365429887, 0.14270505056746546, 0.08969548939456863, 0.1435172723065461, 0.14943870295199657, 0.10289388198044994, 0.03944079954958251, 0.0269633608179227, 0.05361031200135908, 0.026498335871785402, 0.03131951104038425, 0.03980662951606416, 0.013600448935082363, 0.05084001166265338, 0.023505057981838624, 0.04051454838425402, 0.06704049981048993, 0.17502942573158972, 0.18755959046463813, 0.16245617621367978, 0.11230401574603974, 0.07031794652462968, 0.17101141714280652, 0.13974454974935901, 0.10729193912758943, 0.1754014839928958, 0.2575988725068108, 0.1846815053854258, 0.15837717170436538, 0.13731715419600088, 0.3980928707507349, 0.21703149852973802, 0.2639878925777251, 0.16965933324348542, 0.14897517379253142, 0.15280090963407872, 0.10835933709336866, 0.10410945667254348, 0.16476154928245854, 0.17245630493327496, 0.19490235935776465, 0.22107192285118565, 0.5602984442826241, 0.22422690274974993, 0.6797632983615322, 83.22131233830606, 124.11307257990684, 97.14614222126623, 104.98931361782937, 120.64041783732753, 79.72722576510522, 45.094803456337225, 61.97408022419099, 47.31744589344148, 30.475663062064882, 1.3748731151703866, 0.8472604556910454, 1.7382867177647932, 1.7677476401290588, 34.638760858966464, 64.00307132351783, 75.59445965674617, 80.9495226029427, 72.97739936459449, 70.73575696637555, 50.86306456596621, 44.457963512789824, 28.296629536536436, 29.923069746263568, 32.474977508667976, 53.67073635901175, 56.49289346510365, 56.83253542069466, 44.33397346927274, 39.740838773788944, 31.710939022802542, 29.529454015916397, 27.307113601315407, 21.130410202087898, 21.4203086591536, 24.668137065825928, 20.211208635760894, 28.463053741762717, 38.25141283773607, 38.17540514853693, 37.47505418715939, 34.00430571648383, 38.49403104474468, 37.846718372837195, 40.83860035865538, 17.057683813956476, 15.067035844249112, 2.482565160720579, 0.21238027230626155, 0.16460298440389096, 0.711290758223303, 3.58717373301906, 11.36603836090334, 23.908668141211233, 38.94830034625146, 61.0214541804406, 65.4307669977988, 62.89476640762822, 63.577372566346206, 71.59603472678893, 28.132776444958104, 3.8757996261119847, 62.794412566769516, 69.98716477424868, 66.74684770645635, 64.72323417663574, 68.04886279567596, 70.97419784915063, 67.53336137340915, 56.490245865237334, 61.33946818690146, 61.534021669818515, 63.796272200922814, 36.68267265442879, 19.41576373192572, 5.072090414262587, 2.889851822007087, 0.7108684292724057, 0.4313167557120324, 3.4330422359128154, 8.694153139668128, 14.583125191350138, 40.264126100847804, 28.621725382343417, 29.030924689385202, 39.218786993334376, 26.869086834692187, 19.415318542911162, 23.555674437553655, 34.320531122146114, 31.110098592696655, 24.960718424089496, 25.22176000379747, 30.176760804268625, 33.46585842870897, 39.80331820826377, 37.86705586218065, 40.98553626768051, 46.6457909922446, 48.610545435259425, 49.5645482309403, 47.698461009610085, 38.59831117814587, 42.54559624579645, 49.179210662841804, 61.90786669331213, 76.77738374279392, 66.79357097994897, 49.891195374150435, 51.09043259774485, 37.04913969962828, 17.997750428415117, 0.7912063538547486, 1.9490542983816517, 0.8231197381692549, 0.8719667912490907, 4.575491384152444, 17.613948468239077, 25.78133906087568, 51.09075030972881, 64.11416461390834, 93.39939225104548, 79.29927164508452, 61.986780858808956, 98.88899249415245, 5.924441064557722, 0.9081824027722882, 0.16099860200718527, 0.21633595198152528, 0.1856056525702438, 0.36492163135159406, 0.19197665425317903, 0.15512184960947883, 0.3618062275551981, 0.1508593210770238, 0.23992220570723857, 0.14402932547513517, 0.163360420434225, 0.19089129152557544, 0.22312404257395577, 0.12026242821687654, 0.19048816073806057, 0.1330687216813526, 0.18565287422989646, 0.19698806437513522, 0.1473972165296155, 0.11577142928276332, 0.17463432354552133], [0.08168461522267711, 0.005119727293570196, 0.05583749813658576, 0.05919372933285852, 0.030704495654771888, 0.02729292609728873, 0.04383452063907058, 0.02391803491440031, 0.06908815324066148, 0.10581777145665501, 0.0655875068097826, 0.05665630823181522, 0.06406358555860578, 0.077801461091205, 0.0263861557018132, 0.06259439362873954, 0.10587342008347474, 0.15598219699196278, 0.06788018580165602, 0.029155266689016458, 0.11309919968968439, 0.1174352803237496, 0.1237074490035734, 0.11693844166133674, 0.03998487136296688, 0.3963894282858218, 0.08731268015840361, 0.7851477628273349, 13.99895287329151, 74.14423388819542, 69.88482229171261, 72.06410684893208, 85.212291748293, 65.6239947195976, 44.896610013900265, 43.66187141787621, 35.13907878629623, 9.133759640878248, 1.0900761908100498, 0.23090884419939212, 1.2775342286594453, 0.3918052194339614, 19.442626084050826, 56.44896684154388, 41.3115950553648, 69.22493842340285, 62.391020328767844, 63.03920376685358, 56.11912688901348, 31.22626546890505, 22.040494218949352, 20.054992398908063, 26.300388266963346, 42.38109596313969, 51.83985633234824, 43.03817141440607, 29.970216635734808, 28.953418654780236, 30.690799182461156, 20.61529121091289, 12.628246295836664, 14.191568705343432, 12.372751928144886, 11.122074780925628, 15.069983505433607, 26.119498360541563, 31.10624682518744, 34.49164844328357, 33.43379697492046, 21.39244414144947, 30.590902297727524, 44.612712783198205, 34.362782893642304, 7.119426438885351, 2.5324861464961885, 0.6070327494413622, 0.04802993220847942, 0.2897950658394445, 0.2156847312806114, 0.7082791133753715, 3.574856019789173, 11.154463752623528, 17.580329833492158, 33.072166212143436, 43.37104728144985, 39.03160364397111, 47.88806446136967, 74.85791698578866, 18.556715634561357, 6.343765970199339, 55.70743883809736, 55.46491869034306, 62.34104148803219, 55.30708643697924, 60.14419647955126, 57.451430520703724, 58.9297483044286, 55.741555613856164, 61.10984479227374, 62.74421799567438, 45.787411658994614, 26.19234265819673, 4.906156995604116, 0.8411182691493343, 0.5150693486775122, 0.13013356305178136, 0.2674756457488383, 0.13859048425670595, 0.6981999703472661, 1.454269487050272, 21.274396488743445, 23.27915518514572, 30.711703454294515, 30.599886486607215, 23.19585188742607, 13.947509027296498, 15.194236347752234, 26.20394895153661, 20.00303472242048, 11.091067464120927, 13.206327173017687, 13.091900848573255, 18.408810900103663, 25.646825298186272, 31.27190224585995, 35.30579520810035, 35.93145639665666, 40.45356481306015, 39.27287647801061, 36.40136418804046, 31.442970537370254, 29.629337172354425, 40.67225656201763, 50.741777035497854, 50.067266648815526, 52.27158377247473, 47.46284815572923, 35.71945621121314, 16.449828224797404, 3.912912847534303, 0.8813155766937041, 1.4341742040649539, 0.32971443668488537, 1.029258738121679, 0.9128883276735583, 4.182177186012268, 3.6809816283564416, 22.310831815965717, 42.282499344118186, 77.56412490721672, 41.09883785247803, 51.879797827812936, 15.199292282904349, 0.8130014940134941, 0.11217718989017511, 0.0645552109926939, 0.09573315089989094, 0.028418791893449043, 0.02368165273970414, 0.04992084404934318, 0.05305648022781938, 0.03592700321948336, 0.19433891701121486, 0.08428067269344484, 0.13820685806774324, 0.058613023194935054, 0.03413466774227639, 0.04038504888153365, 0.0671529998221705, 0.10558149461904842, 0.08151891806553449, 0.13026824130886985, 0.04278930091869928, 0.16470010903093124, 0.06269198556941363, 0.04187070021045305, 0.007288772143393516, 0.05725759149138486, 0.03219821197431415, 0.04178157354134225, 0.06305190133711984, 0.08391174007086985, 0.041731092177571795, 0.05587694017336734, 0.07431845766522231, 0.13230618840504077, 0.08633658455144014, 0.10177923937238033, 0.03613534083049144, 0.08835120427031672, 0.04554440590342687, 0.012541080528359502, 0.04677775766580336, 0.10127693084218811, 0.1226650408258842, 0.04954193313155444, 0.20122810056613338, 0.2053452102888015, 0.050329165082545056, 0.05334675094232925, 0.049341712222104116, 0.44167928998508765, 0.08531021825488537, 0.16964557430436536, 37.17770714913645, 105.87130561951669, 85.14896115949078, 94.79468914770311, 96.67202180431735, 75.58311616220783, 36.99793315702869, 30.360382641515425, 36.18022880246563, 10.954429737983212, 1.0814115525253358, 0.46905155023259504, 2.6147630089713685, 0.18265466656415694, 21.670710809769172, 56.276947375266786, 61.058991262989665, 74.82227048566266, 73.4802079969837, 72.31289494422175, 53.85009850225141, 39.46550015480288, 30.485902409399714, 30.34331248652551, 35.49639101951353, 53.52388281976023, 57.804483059913885, 47.32704001088297, 36.893001910178896, 33.17674444567773, 33.24735887588994, 23.96104355012217, 17.59516227629877, 18.264216646071404, 12.864134696222122, 12.429810647041569, 15.678619646256971, 31.433394070594545, 32.48586796945141, 30.538793609988307, 29.207960867112686, 21.430414645902573, 18.43094091261587, 31.18529239008504, 20.359132982069447, 7.685447008379045, 3.4999068802402866, 0.2816874654062333, 0.045267143361871286, 0.21344081378511845, 0.4920659652881084, 1.4522934705019, 5.296480876784171, 13.01555387435421, 23.76503682905628, 38.16665826305267, 50.111142281563055, 50.535468209174375, 53.48792253002044, 79.99811249394571, 20.997449697986728, 7.68043274841001, 68.01489506998371, 63.19138780716927, 72.32477188110352, 64.82172096929243, 70.27244660162157, 61.01379771386424, 67.08216328774729, 65.6782450214509, 67.80185545644453, 70.02632571804908, 50.33692175342191, 30.145156306605188, 7.6507404062055775, 2.0480779654556707, 0.8408413743299823, 0.23978028025838638, 0.18164252652035606, 0.137053512697739, 2.7878116071224217, 5.521537651938777, 27.859485303201986, 23.238695936818278, 26.35163599444974, 30.675078322810513, 26.243406034285023, 19.38679114464791, 16.117027863379448, 23.881368444811915, 23.938601709181263, 18.3106182852099, 21.981064427283503, 20.390813965951246, 25.34086081289476, 31.826837216654134, 35.05309258737872, 38.25479784319478, 40.594036656041304, 46.3349941469008, 44.157541336551795, 43.47136189860683, 40.777179964127086, 39.095867756874334, 45.57514475237939, 58.756607040282226, 59.06779220027309, 56.92656247846542, 52.48546669560095, 27.843332982832386, 14.867588223949557, 6.579822051909662, 0.5845853313803673, 0.6868359446525575, 0.6422168388962746, 0.786853319694919, 1.1792642695288504, 2.652847262159471, 7.682924924358246, 52.01253475681428, 53.75228635726437, 86.4743535749374, 55.261708536455714, 63.69774618456441, 35.86626660439276, 0.49272786525468676, 0.2838317455062943, 0.08013304202787339, 0.08506951342907645, 0.0710868000263168, 0.020516248299710212, 0.052949105344352224, 0.04063404277868329, 0.04234413871721875, 0.07000296947456176, 0.0965597827528273, 0.15324933153967704, 0.060464887534298246, 0.06791205505930609, 0.00967253515902426, 0.0415533559486991, 0.051879079696992715, 0.040628285627932324, 0.051410314326565114, 0.06573084186041547, 0.1508464354781374, 0.07343389424345187, 0.07213948910394985, 0.12116589868861823, 0.25666403073456984, 0.21366618153068329, 0.20324531732307327, 0.22213653991779975, 0.17927287867473019, 0.17572357799978028, 0.16266640606186084, 0.20067320776081857, 0.21313240210856163, 0.13639159740940218, 0.23944885530058416, 0.17400705075312048, 0.20540331039697896, 0.1657296239488548, 0.14733741570624614, 0.22737696436384033, 0.2028308024690036, 0.24481098047427594, 0.2235987566171154, 0.25398157386770176, 0.3747488540266791, 0.23197859405509888, 0.28607368649494264, 0.2178541084210719, 0.8004415131384327, 0.2499046071522659, 0.8794871393230654, 35.12311866206508, 117.31097667447983, 97.22383652963947, 108.48927590154834, 112.19985377403998, 95.28628764613983, 65.03685120613345, 58.53451851875552, 48.11035694614534, 13.799849440974574, 1.901361464012054, 0.6046716051716959, 3.7618010851644703, 0.5416532125203841, 24.308818540265484, 66.32225898004347, 59.18820504219302, 82.69491457170056, 74.22402274224066, 75.4441858107044, 67.16372505311044, 45.793863957928075, 38.28769083945982, 38.11350622484761, 44.188790859714636, 59.57447221202236, 64.25273018498575, 54.717428684234626, 42.43536979921403, 39.84117300279679, 44.33741338791386, 35.045632239310976, 25.70509210709603, 26.800992527315696, 23.063211056493945, 24.30604346336857, 25.30583404725598, 37.42452621459961, 41.75621532624768, 44.49647334314162, 44.22237419313, 32.333358372411425, 40.38920264090262, 54.31946500655144, 42.265888106438425, 18.111173606687977, 9.103496593813743, 1.1399436117179933, 0.5426057968889514, 0.41019231020923586, 0.5698636342440883, 1.159525064210738, 5.825762075762595, 12.000012032447323, 23.472582947823312, 39.879627919966175, 52.90628602427822, 57.42624498182728, 59.9161930238047, 76.70297638062509, 23.089249710882864, 11.555125040392722, 70.8343182840655, 62.4098986964072, 71.78304549186461, 63.52829979312036, 71.19496453192927, 63.32858839342671, 63.83895543313796, 62.6617697746523, 64.37321362956878, 66.78583606596916, 50.90603805357411, 28.192384704466793, 12.101680847906298, 2.2850777449146396, 0.7746967913643007, 0.5319048356144659, 0.26435748403591497, 0.19496084250990423, 3.5946463384935936, 18.617879113843365, 36.662503827002745, 30.989919131801976, 39.17225591598019, 37.11486293423561, 31.078872603754846, 17.463915847962905, 22.334191491526944, 41.562548298989576, 36.51451280040126, 26.226918351265695, 27.83877714987724, 23.08661976168233, 32.62797151842425, 39.57464794958792, 41.71948232958394, 43.756306402144894, 45.83843777256627, 51.57407260710194, 50.13663768768311, 50.90735204758183, 46.517647158715036, 45.36565096147599, 52.30781078338624, 62.827274184073175, 62.191469746251265, 61.228590626870435, 63.389447889020374, 50.97021979670371, 24.07972662679611, 5.939929033479383, 0.8937605218060556, 2.303581771350676, 0.5286181958452348, 0.9434689641479523, 1.8961438536643984, 4.04258763117175, 14.804951894667843, 71.1018866877402, 66.20215600536716, 109.651074101848, 62.17408187927739, 89.83329880622126, 37.27546045857091, 1.0868778656567297, 0.3855468633194124, 0.14225924868256817, 0.22271705070330253, 0.21763217274940785, 0.2285206110607232, 0.14301758379705493, 0.13645453919326106, 0.13826224622466873, 0.3559627233734054, 0.2004189278569914, 0.40058403546291016, 0.21246837241755379, 0.12380266607168222, 0.14292481054942455, 0.17942021270432781, 0.13599078020741864, 0.16078060402745203, 0.38243771080047856, 0.10405059047644177, 0.30746742722488224, 0.17864709209290244, 0.15435484237968922], [0.09665057949361303, 0.09446467017574657, 0.07064837556813033, 0.018894587635933872, 0.07001506600288615, 0.0763164149717458, 0.05480743163535672, 0.12526760238312906, 0.07780234975319716, 0.08317300148548619, 0.035859694734456084, 0.011393431022072272, 0.007153550442683721, 0.03184620223398651, 0.04772618983782107, 0.04889258934605507, 0.04215326791088428, 0.045045157894492156, 0.03564533184192354, 0.13720414090541103, 0.04877685261289439, 0.19500941248430362, 0.00758718493612363, 0.12976414013293483, 0.13083894616894184, 0.312160941501779, 0.16270728451350044, 0.4004858842780514, 2.297035825829352, 81.53754864969562, 92.78869490469657, 70.36244930759554, 79.56895028391193, 67.73593610332858, 39.20458801331059, 21.633299243065622, 19.337694837201028, 2.7526921754883182, 0.5848275377385078, 0.6891817671637381, 0.5419940910031719, 0.16513503246730374, 5.5693920389298475, 59.40131133602512, 59.26229469237789, 68.5007276842671, 64.27555837938863, 50.03757822898127, 55.841960445527114, 38.022648442176084, 35.15801598948818, 29.19425414454553, 34.10584803550474, 48.96657897580055, 50.75983170540103, 46.35798315848074, 34.444630992028024, 30.39783931547596, 23.997692215827204, 21.091784661816014, 16.216848261894718, 13.55969742421181, 16.184869177879825, 14.265636782492361, 14.179081839899863, 23.471245419594553, 34.04052880502517, 32.154084482500636, 34.19987901564568, 17.094442306026338, 35.36612126135057, 36.877473246666696, 16.772637328793927, 7.576967487412115, 3.437857435595605, 1.069325749431887, 0.3610907627209541, 0.02626471735927607, 0.06132985059652598, 0.2432944481411288, 0.7000903076221866, 4.629941726884534, 13.504622444029778, 29.10164502359206, 37.541840384083415, 34.76506117851504, 39.722474236642164, 64.06839055399742, 22.485808749352735, 16.487830108211888, 47.32400409636959, 67.63405646047285, 60.825975018162886, 59.19497897548061, 54.64811255854946, 57.973721565738806, 55.65519678977228, 52.89356577780939, 57.92315044710713, 53.5208704394679, 34.734992288774066, 9.03897556566423, 1.7986854574372693, 1.0360661341298012, 0.13255099946212384, 0.09700969086899873, 0.07101957581096119, 0.13684841563865063, 0.7209728225584954, 3.1051855318007933, 16.111673828094236, 19.534564479704827, 30.561904215043594, 28.683286982197917, 30.230461974297803, 20.978777254781416, 16.004865727116986, 22.702013715620964, 16.22138252181392, 9.116428648271869, 9.860364006411645, 12.024844558008256, 19.787392616271973, 22.990890395256784, 31.222099911782053, 34.77175666439918, 37.20477150332543, 33.09296654116723, 33.44308906985868, 32.972487018954375, 35.27482025084957, 31.810584875845144, 47.25353087148359, 45.12408002730339, 46.19621676783408, 45.65310185955417, 46.73200468863211, 32.365647323669926, 5.944759432346591, 0.4139805230642519, 0.8057853134889758, 0.5511424678467935, 0.39879938767802336, 0.5145250585290694, 0.8339277066050038, 2.3307976270875623, 34.95119333267212, 24.649019433606057, 69.09219757203134, 55.76368954873855, 35.58182024186657, 56.653424309146025, 3.934798202207012, 0.2325258566246879, 0.20108740085796004, 0.034167873823354324, 0.05914948009435208, 0.07747411172115996, 0.14681989266987772, 0.07607504364944274, 0.05452153145245487, 0.07523656041631777, 0.1245068311090431, 0.03245875847736194, 0.03628522593287691, 0.09685077358998599, 0.013700375528705698, 0.08006728104045314, 0.05764099934528913, 0.038837470835255045, 0.02011253911581251, 0.06807194526998267, 0.04344047565433768, 0.03295666966286879, 0.08961751696563537, 0.07654090171619769, 0.040080873671198086, 0.08411502916245692, 0.025680632773606528, 0.07939604246207783, 0.04084022768262414, 0.05542805478457482, 0.030330340227773114, 0.06562065543426622, 0.07067685105627583, 0.08613871170147773, 0.09558704261097217, 0.03491257640322851, 0.0237555974613755, 0.050343042765293396, 0.03656669812757642, 0.04120616490141519, 0.05246763440570044, 0.08686853302342278, 0.10760480177498634, 0.08231821590133252, 0.07329618993906245, 0.12781977067671477, 0.05756396920450273, 0.05850211281569735, 0.15236043972113442, 0.013347147708578457, 0.35979487903175816, 0.2591258696010036, 7.268870213339406, 101.53466255434098, 100.4889351321805, 86.02009604054113, 93.69025953354375, 76.98439075100806, 56.34924842465309, 18.773799211748187, 16.097590557990536, 4.613066219514416, 0.5303910458760878, 0.821284007641577, 1.221166582357499, 0.1771869897962578, 7.697006723573131, 63.047162255933216, 63.59605089310677, 83.7352212782829, 65.22735680303266, 65.15737779678838, 60.73974955466486, 45.06617407644949, 43.251211027945246, 37.05156372439477, 44.46041891651769, 57.86873932807677, 59.21528508586269, 55.54708842308291, 41.90760312541839, 34.760723037104455, 26.906729821235906, 25.594885272364465, 18.70275135963194, 17.13153616074593, 17.50323957012546, 14.259044258825242, 13.210711402277793, 22.77216334496775, 34.26298995171824, 30.11701722298899, 32.95276926409814, 20.442314686313754, 34.51691242956346, 41.562603212171986, 15.15719642562251, 7.518147134011792, 2.3747225346103793, 1.6554451565588675, 0.3772575161870449, 0.1040683483945266, 0.1078735224361862, 0.2397804794412467, 1.2946840567934899, 6.922984825026605, 17.130320225992513, 30.055163406556655, 41.52661938821116, 45.68815215941399, 48.73182512098744, 68.41147022862589, 33.19520311970865, 22.169924589895434, 56.79973656131376, 76.99675406179121, 72.29303206166914, 67.61041241307413, 61.05812834155176, 65.1996805590968, 63.51670134452082, 63.36370145120929, 67.93334899410125, 58.53682487241684, 41.87804022142964, 11.838665335409104, 0.9452936630095206, 1.4988187868748943, 0.2626469935620985, 0.20966533331140397, 0.0279306540746362, 0.2594435509414442, 2.9942763476602496, 5.462678565133003, 16.83500889808901, 20.611525735547467, 28.161980452076083, 26.254574983350693, 28.739214097299886, 23.640205437137237, 21.04119589251857, 25.876201583493142, 23.665824397917717, 20.343066953843643, 20.859309704073016, 23.68619522740764, 28.145108376779866, 27.025130487257435, 31.88540800925224, 37.8160140591283, 40.01619700462588, 38.07807937745125, 40.96483399791103, 43.411169205942464, 44.27419654784664, 43.66476612706339, 53.26814036215506, 50.11493129114951, 53.42014005107265, 53.93810864417784, 37.70294389417095, 19.589762033954745, 8.111675285523939, 0.9803643714516395, 0.5199229140435496, 0.40906159507651485, 0.2824338801926182, 0.8276344475246246, 0.27999811895912696, 2.5782155894464065, 49.70716561040571, 43.85780949746409, 69.97934356812509, 79.99735155413228, 50.31740011707429, 77.60301128510507, 7.009788838125045, 0.9545871675495179, 0.14218650097327848, 0.012765524180365667, 0.09279488961422637, 0.04726219719516174, 0.045167302953139435, 0.014935426091054275, 0.11802788763757675, 0.09050096189903636, 0.031487376226352594, 0.05760655220177385, 0.04815815617480586, 0.030945665878994815, 0.04354979257069288, 0.0403457370796992, 0.013121810606530598, 0.05008778226892314, 0.06554154919520502, 0.025125824237963366, 0.06124538557243444, 0.05489370845738919, 0.19327549504176264, 0.03903147494119983, 0.26839295942937175, 0.17107443553545784, 0.16976782661532203, 0.14596979554382064, 0.15456044505680763, 0.21697197349802141, 0.17039013515797355, 0.25537472007976425, 0.3079228205305915, 0.2648074227956034, 0.1735705798191409, 0.15190558267697213, 0.16585274960004515, 0.10360792955203403, 0.16626761685456, 0.1291051972657442, 0.2937187230394733, 0.15956935773213066, 0.11614583177311767, 0.23157264406402267, 0.23369198034126915, 0.42266226043143584, 0.11036948285876744, 0.20989983282502622, 0.2360106373746549, 0.4985865992644141, 0.4434082584996378, 0.46090929198168945, 6.204542421525525, 118.29121620424333, 122.82765696125647, 95.5515810751146, 114.40434348198676, 99.40365452920237, 80.78292385224374, 31.221792005723525, 29.785088608341834, 7.263945187291792, 1.020222210115002, 1.646134920658604, 2.5960241306212644, 0.9579445938429526, 7.163071632385255, 72.46015640997118, 75.63467179575275, 81.65139152157693, 74.73969674879505, 66.19014570789953, 70.94547825474893, 54.42983658083024, 53.12722921371461, 42.70184778398083, 52.62295753725114, 66.16742733986148, 68.90784617393248, 65.35642239355272, 47.19660943554294, 42.15217467277281, 36.22867007409373, 33.475064231503396, 27.029121498907767, 27.4559538210592, 29.323217753441106, 25.7633138087488, 25.19040261545489, 33.598061915366884, 41.03669574183803, 39.4323286702556, 45.5620518807442, 28.208484072839063, 49.897008326745805, 57.38065527331445, 30.3288899314019, 21.455774730251683, 7.616439279048675, 1.8087152031160172, 0.665218536892245, 0.12735389728820132, 0.3220747933993417, 0.5888272521476592, 1.8630799891487246, 8.815509311614498, 20.899223742946504, 31.88181119580423, 43.5889780905939, 53.22684564898091, 53.56447935104371, 70.48249736908944, 45.27018831622216, 22.26002339393862, 56.29390770389188, 72.18636712720318, 64.35047564967986, 60.7454409137849, 60.298749631451024, 62.925062794839185, 64.50570737161945, 62.31651882971487, 62.06553812949889, 57.36959026705835, 42.19670141896894, 12.78464198112488, 4.1673020874300315, 3.404246400440893, 1.2691312860096655, 0.2043472581933583, 0.19347780354080663, 0.48465988688891937, 4.134106088069178, 19.659064431344312, 30.50370800879694, 25.375003084059685, 36.4761677095967, 34.03919127679641, 37.11190154475551, 26.839310161529053, 28.71525626028738, 39.70015987273186, 32.36255257360397, 23.8175985505504, 26.718491354296287, 26.85771784474773, 34.470177388960316, 31.64869296935297, 39.168427682692005, 43.69178733518047, 48.601720102371715, 44.33693878112301, 46.95203788818852, 51.197160290133574, 53.639882995236306, 46.74598009355607, 61.014084046886815, 57.08023701944659, 56.254040733460464, 54.39376254235545, 57.894728952838534, 38.144524328170284, 10.778627145674921, 1.1640104170768493, 1.6292438463818644, 0.8721664644056751, 0.40189628279016865, 1.090941686303385, 0.6625725304888141, 8.366010592829797, 76.05669529207292, 51.22225561449605, 100.49762710448235, 86.83117158951299, 62.20270733679495, 98.75860506488432, 7.131565193976126, 1.00927941020458, 0.33199299667631427, 0.16025172756804576, 0.2484742750323588, 0.20080592483282092, 0.2013665939410848, 0.17624968122090065, 0.1643681937768575, 0.19185746629391948, 0.2021561088340898, 0.14496277296735396, 0.23234361962926006, 0.15469518460093007, 0.18886249151922044, 0.1451122213996226, 0.15057735475561312, 0.18300757262735598, 0.18713818081924993, 0.2946734218107116, 0.132006234339168, 0.1326773120390792, 0.3536590050545431, 0.2158969376356371], [0.09593950434317512, 0.06778186607745386, 0.010206485035709076, 0.04133009877536566, 0.03319627898294599, 0.07985405578848817, 0.06952911344987732, 0.03961527224389776, 0.05870196983338364, 0.06350876936208337, 0.04655701709130118, 0.03601760843828802, 0.04227737798505733, 0.04772229428072611, 0.029818308126601963, 0.023392523496201443, 0.066009774473646, 0.0734320939368298, 0.07187940225365662, 0.1815384917802388, 0.2565514158097006, 0.1555240457697261, 0.03506240021858004, 0.06741877870574113, 0.13443289444811884, 0.04588844449890237, 0.35180347881490187, 0.1462604952675681, 0.13873369673327093, 43.66064763838246, 112.33184937507876, 80.74292352122646, 85.56051192745086, 75.32514972071495, 50.24375761708906, 8.295703088083576, 5.571984235317477, 0.39207760965631855, 0.06879953727606805, 0.39584621066047304, 1.5915888475794948, 0.33524154655395016, 0.42135188235871257, 33.147989549944484, 81.28494016585812, 58.7979958903405, 66.17294219232375, 44.467894954066125, 49.813767786948915, 47.65888429457142, 45.07907475194624, 36.508719459656746, 43.495190297403646, 49.05125510308051, 51.36307262605237, 41.69089217339793, 33.45449532231977, 25.802749318461267, 28.997655145583618, 16.09732187563373, 14.079655639586912, 16.659657378350538, 16.812519988706036, 11.818209194367933, 17.24358650945848, 29.553556980625277, 32.26060036690005, 30.436825713803692, 30.782157067329656, 14.914225205298393, 13.371589376080422, 1.652522132762017, 4.334057242639603, 3.0796276129061178, 4.806878374468896, 1.5107035684970118, 0.08007175499393095, 0.28287370659170613, 0.1489723392672116, 0.6079656606720341, 0.6979277946295277, 0.42021470144391065, 12.709339337964213, 22.833983821253625, 26.956618447457593, 38.20403845079484, 36.39275458551223, 43.95495091715167, 16.796455921665316, 15.93505047982739, 42.70094171647103, 56.7324875247094, 59.008615401483354, 54.602083544577326, 51.115488698405606, 42.504125025964555, 35.49942301165673, 37.75690001826133, 46.23327532122212, 41.016370019605084, 12.611388929428594, 2.372024924524369, 1.981514853335196, 0.507433505188073, 0.1691401094919251, 0.19342623050174407, 0.16260259093776827, 0.7337477370615929, 2.278378091512188, 8.88565109622094, 14.511865531244586, 26.968430665231523, 27.301045694658836, 28.44910187105979, 26.62536251929499, 28.491216359599946, 15.23271676032774, 8.115563825253519, 13.58438580266891, 10.247717672778714, 10.710998619756392, 15.269456621139282, 16.35665428253912, 21.901222621240926, 24.99444296283107, 30.651857891390403, 27.624949139933435, 27.263781216836747, 24.607254036011238, 29.172386930834865, 41.22407913208008, 42.01047120555755, 53.78951749493999, 50.464779253928896, 40.470948757663855, 43.10609902105024, 46.80294859793879, 18.2739225510628, 2.5426213058733174, 0.5107983778561316, 0.13466391592256485, 0.136118670925498, 0.4559457470332423, 0.2748777711343381, 0.11344465937825943, 37.75502512531896, 24.89950591518033, 45.27667983885735, 77.2712258369692, 32.63747934372195, 51.96804331194971, 25.602200492735832, 0.45977257071964206, 0.06575547924806034, 0.1290627406729806, 0.052542370113153616, 0.03673649768555357, 0.11607918212370527, 0.0058103584301387595, 0.04840999991903382, 0.054480522765868136, 0.1261511775514772, 0.04135524561148017, 0.10808181408191882, 0.11149122710189513, 0.08805335694623571, 0.016045727853422925, 0.04919147088883385, 0.08459408692414723, 0.09564705793896029, 0.051883791137727044, 0.02824118781474329, 0.006389334645768207, 0.03938786670445435, 0.05885921704072145, 0.03331745110992943, 0.007739680004306138, 0.08143352224461495, 0.04901962204565925, 0.037977881879816135, 0.05422384500683797, 0.05734176157162555, 0.07299390696589986, 0.01601703977587843, 0.07486915996959133, 0.008166148702824309, 0.055191276159377835, 0.06572216974511262, 0.10417268190893436, 0.06237692808011367, 0.02140112773274943, 0.062434829005430785, 0.035209332052017414, 0.04510944033221853, 0.13208233751356602, 0.17445135110568616, 0.21317731018268296, 0.10166792679698237, 0.015174844846760314, 0.029241957198528033, 0.041954885612452225, 0.162677958667759, 0.18402864525635398, 0.22089955306822256, 0.16215478190250937, 77.60714546326669, 133.8094932802262, 89.04749116589947, 108.31621308480541, 87.86432389290103, 71.21845952926144, 23.274099249993604, 3.9953157161512687, 0.5635795069317664, 0.2144976933636973, 0.3248529040044354, 2.1676451688812626, 0.9494694550671886, 0.42900249602333196, 37.152121528502434, 83.85638329290575, 74.44445210118448, 77.77209681849327, 52.70846128463746, 59.84569234232749, 57.33588141779746, 55.2785276597546, 43.51235066690753, 54.27482058925014, 57.21686101728871, 55.54815530776978, 45.796217380031464, 44.54111776044292, 32.293846376480595, 32.84428631105731, 24.052683845643077, 23.701906281132853, 18.497240735638528, 19.81420005521467, 14.877317663161987, 13.760650254064991, 26.772637713340025, 32.02736054697345, 28.63065269685561, 27.113442651687134, 15.592923702732211, 17.24897388489016, 9.68739434596031, 8.417222038392099, 8.743293573779445, 1.955044125356982, 1.6898038935276771, 0.2723631947751968, 0.2294658409852174, 0.12981461000538644, 0.2032138923964193, 0.512028745706043, 5.695692358478423, 18.050584754636212, 26.293569226418775, 28.823741174513295, 40.34163213545277, 42.42581882784444, 48.274861151172274, 18.934151587947724, 16.655956622092955, 47.90325972341722, 64.65969962458458, 67.16227377614668, 64.34661603743031, 57.37912947131742, 51.19541875777706, 44.50525160758726, 45.89118972901375, 57.319858535643554, 42.87770725065663, 14.635529037444824, 0.35904726914821133, 1.5473463506467882, 0.7496871462752743, 0.22792764368557164, 0.04505534303344546, 0.19641872315156847, 0.7106254261828239, 2.51695454120636, 5.2243739847213995, 12.363614766828476, 22.392170006229033, 24.67533657627721, 27.327455013029038, 25.579462512846916, 30.63040448773292, 23.705212839188118, 18.313536528618105, 29.086353663475286, 23.673239638728482, 21.816552377516224, 26.091043526126494, 25.441834388240693, 30.078701549960723, 30.157770649079357, 33.8788487065223, 35.879975288145005, 33.561195558117284, 33.09215068817139, 39.79911734980922, 49.1189669793652, 50.03167506187193, 64.04043189940914, 61.466027382881414, 50.149044144538145, 44.85577029566611, 35.28692468520134, 14.382978408567368, 3.7880584116904967, 0.628998083693366, 0.1831828075791559, 0.12215133290737869, 0.41732560002034713, 0.0657303822076609, 1.5885665387876573, 44.52922905645063, 54.52498151410011, 44.95052299191875, 94.43004992700394, 50.18870322935043, 59.13076193101945, 48.47403126378214, 0.4104943327125042, 0.13365286372361646, 0.00812133926252324, 0.10496966615920106, 0.03852696773866492, 0.10112365197029807, 0.035048760023088224, 0.08428083357190894, 0.046160294629272916, 0.06240702001377941, 0.04811330172683924, 0.07215352383472266, 0.0576542564968188, 0.09818428751802254, 0.1054444338285154, 0.03737874366643448, 0.1129044984437285, 0.10820622676082196, 0.047657579003322514, 0.047864564469144236, 0.017284512136792465, 0.05282115716967852, 0.09065281584738724, 0.009033516323524378, 0.13401123965459485, 0.20901860188572638, 0.1251954981876958, 0.1710749105099709, 0.1657444094457934, 0.22328798538975178, 0.2815341252473093, 0.13445325706514621, 0.2901120117354778, 0.16906710131274116, 0.1739466677029287, 0.15312315685854805, 0.15597171690915862, 0.16425986894436423, 0.1965373901710395, 0.19500287009343026, 0.2684186693401106, 0.17455472701018857, 0.16432264218887976, 0.3099709106308799, 0.2561052462025996, 0.31800239256793456, 0.11998060745217147, 0.16400178924443262, 0.1997393925463961, 0.34961200769870515, 0.33757459071855395, 0.3336210867329952, 0.2212723774174529, 79.6647188740392, 156.00649987497638, 108.7541300250638, 126.03158227859007, 110.70128871548562, 94.04065270577708, 44.9868441397144, 6.6147105539998705, 1.9555661683121037, 0.7828012661587808, 1.7100820570222794, 4.2647077768079695, 1.0086023723406177, 0.621238409751846, 39.56474396490282, 93.97211320938604, 76.50055854551255, 76.83795298299482, 58.28702480562272, 64.02831177557668, 67.21757919557633, 61.618403619335545, 52.20062417368735, 62.36195556579098, 68.74008640166252, 65.068822445408, 53.38794523669828, 52.47402121943813, 39.29720694018949, 42.05866929023497, 30.0826435319839, 31.71520656155002, 27.782285213470463, 31.615888226416807, 25.71637676608178, 28.452294680380053, 40.13432702710552, 40.972188441984116, 36.78625852830949, 40.65392732620239, 25.176042818254043, 24.58121342043723, 13.034288094889734, 16.309956504452614, 19.68353217647922, 6.165656533933455, 2.418294919113959, 0.6119882351448459, 0.3504250108474686, 0.22084779616805816, 0.431744110199713, 2.0011948553785204, 7.842663939922088, 17.321072932212584, 29.757930117268717, 34.499167626903905, 49.40325252471432, 49.11251860280191, 50.36634345208445, 27.495648207203036, 22.429816915142922, 57.56858779538063, 65.8387170299407, 66.24993831880631, 67.0436534573955, 62.86973776355867, 55.89912114604827, 55.622444998833444, 56.27361336062032, 60.96042602292953, 46.194836093533425, 17.86226195673789, 4.352116325209218, 3.1519423905880224, 2.0062224759209544, 0.6885130643363923, 0.508043433749868, 0.202927268260429, 3.972141862876954, 6.012395803005465, 16.9424916467359, 23.418067885983376, 34.63256743646438, 32.4377679440283, 34.11548137664795, 33.66945297487321, 37.61345894105973, 25.517661648411906, 22.235794913384225, 28.722214544973067, 27.363672218015118, 27.943541695994718, 30.199681174370554, 29.471959913930586, 34.042105597834436, 35.09665050814229, 41.564850730280725, 40.765918839362364, 41.75591722611458, 40.90109548261089, 48.047869666930175, 58.553942095848825, 56.94144787326936, 69.77151286217475, 61.39207893802274, 53.04790712171986, 50.65849727199924, 56.821564551322695, 23.456112915469756, 3.9982342047076074, 1.9265872071827612, 0.2031424470366009, 0.294070357396718, 0.6857618280956823, 0.32655616260824666, 2.697232557881263, 79.39609143041795, 56.38794260640299, 75.38428337343278, 114.7076682121523, 59.58035184491066, 80.16848456475043, 56.717092221783055, 0.3546694443831521, 0.16000898494835825, 0.21886159065029315, 0.23801915137277496, 0.1735165093334452, 0.22028222409707887, 0.11594681745214809, 0.21563513474839352, 0.15127320773899555, 0.2229003142565489, 0.13571425311027036, 0.22885529955308284, 0.39079530104514093, 0.2214545378040883, 0.2890471495207279, 0.13751095911908534, 0.2136725553822133, 0.20604072619349728, 0.13643178638190995, 0.2032432948509532, 0.1137822513438521, 0.12101811266714528, 0.2122686532956939, 0.1925316389890448], [0.052638433708418766, 0.029387651799967694, 0.07142267595495909, 0.06038314978321714, 0.019825731118720387, 0.053675935092952945, 0.014136452885014156, 0.01586246430017655, 0.07808423180493616, 0.04885289066981885, 0.013727862763428881, 0.10620954882113204, 0.015569064116495994, 0.0497654277921444, 0.11504018303727913, 0.08037096595451718, 0.1830252539366484, 0.13486150531999527, 0.09992517636067445, 0.13521382915637187, 0.03660319072584953, 0.04439718923681686, 0.06046204917853879, 0.12899307263714652, 0.12632682619075622, 0.034506193572475065, 0.10802780488325704, 0.06295813217518792, 0.06539092864841223, 9.403420629039887, 95.71544201143327, 115.06141893325315, 74.13299237528156, 81.61785525660362, 58.224851316021336, 36.40643189030309, 3.941428233538905, 0.565864839140446, 0.22109344992185795, 0.5133804312396435, 0.15958659471042697, 1.0148564077192739, 0.1107371207927504, 7.9702032381488435, 40.98304164025092, 68.62924806533321, 44.07805842737998, 52.006964991169596, 53.47731251870432, 48.10637966279061, 48.822592689145, 45.53763120405136, 55.02104759216309, 45.11709820839667, 45.78342653089955, 40.11457789328791, 33.466509542157574, 19.424667512216878, 18.08959468718498, 14.87391108466733, 15.383888829138973, 17.134974118201963, 16.788344460148966, 12.813335099527913, 20.465535117733864, 26.671193453573412, 34.99484931269, 29.25132266936764, 30.78217079562526, 19.729143458027995, 6.601038642467992, 1.5066463668500225, 0.878269549819731, 4.7362286429251395, 3.7739084612938667, 1.1008613604691722, 0.8395489533582042, 0.22147031921532848, 0.470668853771302, 0.3589470342041985, 0.6857420323837189, 0.7846886003690382, 3.913008945603525, 11.212820776047247, 18.356880680207286, 34.408164716536, 37.791342350744436, 34.156509368650376, 12.041945111367012, 6.856607535193044, 24.925024855521418, 35.5361089398784, 38.2809365180231, 30.13475810327838, 30.453888024053267, 23.183786676776027, 14.950470847468223, 21.411614725666663, 26.2798507367411, 10.890244072483434, 3.0157596593902958, 3.564788031001245, 1.4369247661482905, 1.3980533422962313, 0.07233043651907675, 0.050308894396068594, 0.07009822484706679, 0.46832257160736673, 3.385187358625474, 6.83704226247726, 20.888396040085826, 26.26940154260205, 22.45372964489845, 26.04600294943779, 23.15205470208199, 16.817789693032545, 6.438211740985994, 7.428038524043176, 8.470877120571753, 10.122805872271138, 18.7316180429151, 16.551027336428245, 22.33030246150109, 22.788505900290705, 20.95162464726356, 22.131302971993726, 17.378114000443492, 20.192616601144117, 20.34330229605398, 34.0478204911755, 40.062594721394206, 42.48871403355753, 40.590577125549316, 48.2321543847361, 43.33973500036424, 41.97761351062406, 24.47907686233521, 7.030961302018936, 0.2388211841424627, 0.03397004693866738, 0.33367900298007075, 0.06186215529939341, 0.02136168952640747, 0.3578334794409814, 35.65063822653986, 28.808255657072994, 34.44285808071014, 80.43937913833126, 50.40440613223661, 33.82366488056798, 69.35710660872921, 4.6351697560279606, 0.6510272790347377, 0.16432541542716567, 0.016404158368165937, 0.03177037485124123, 0.0729358911273941, 0.020819605711186608, 0.0551959416348367, 0.30540897961585756, 0.11010770295416156, 0.053418939407434196, 0.07255928996469706, 0.042177683133031094, 0.09376717776420618, 0.07730191813841944, 0.042468666309310545, 0.045063421430607, 0.1381715873797094, 0.0634028577065516, 0.10827037130272198, 0.1084668728552999, 0.12114553607159084, 0.01745018439607755, 0.08762614035438146, 0.089020075637006, 0.08554379846299849, 0.02295007899163231, 0.008310430829653577, 0.021634024207390124, 0.004518049019914602, 0.03490277813867696, 0.014994411030784251, 0.019551894905406143, 0.09757235180586578, 0.022864434192137375, 0.07851527883641182, 0.022402552121709433, 0.09863526815728796, 0.01005886372313985, 0.08508327236819653, 0.017848869958411784, 0.04508018726482988, 0.03896556073619474, 0.07455386116259521, 0.0586027576167497, 0.09205938391988316, 0.08564465393823001, 0.09140426383143471, 0.033646033881532575, 0.13044585113323506, 0.0711745860415601, 0.14261423850492125, 0.1100344572877211, 0.5614044300971494, 28.449370553416593, 124.05608838604344, 114.75183410029258, 99.29579719420403, 101.54053826485912, 73.52529956448463, 59.91521243126162, 2.719670966748269, 0.1599795365285489, 0.050496566785319205, 0.14746535238960098, 0.4579696287551234, 1.0003467637204355, 0.2783387112281015, 11.804077875229622, 44.68462159556728, 72.00048600473713, 59.302381315538966, 66.19176172441053, 69.13587708627024, 57.5931457550295, 55.44950377556586, 57.82556187721991, 63.28694851167741, 53.16075371157739, 53.98945246973346, 51.927054543649, 40.74731503763507, 26.443097822127807, 25.57556563808072, 25.305992903247958, 25.438359168268022, 26.172273851210072, 26.54843895666061, 18.055330822544715, 23.149003098087928, 23.6470538954581, 33.03010271441552, 24.903908775698756, 30.225490370104392, 18.970845360909742, 8.999553784247368, 4.719562492062969, 9.635171909486095, 8.567643953907876, 2.2201887494133365, 0.6802919603163197, 0.7527372180934876, 0.20017753355205062, 0.23558951884267793, 0.21619255564385848, 0.7128645479679109, 2.3219771971625667, 6.5574694448901765, 11.872258474749904, 20.587091330559026, 36.61035983793197, 42.54409005565029, 41.99104370609407, 14.625560333651883, 11.577919894649137, 27.044220662886097, 38.44133400147961, 38.3276911704771, 35.14833950227307, 34.9868869012402, 25.69688258632537, 21.91443708635146, 30.976241827011112, 27.757960634846842, 8.549911898951377, 3.374501841683542, 2.025714817066347, 1.7890980815695179, 1.1420862064246209, 0.08653428120117995, 0.030778622322325266, 0.15697018994439035, 0.7336505971127941, 1.9387887201962934, 3.8789495345084903, 8.58860117773856, 13.723545612827426, 17.306909253520352, 20.61885468421444, 17.47411204922584, 18.087474646106845, 18.727307358095725, 20.06448845709524, 22.435441593970022, 22.17730452937465, 30.857346942347867, 29.75732607226218, 33.54559629194198, 31.04462442859527, 28.78798680920755, 31.395654985981604, 27.322701100380193, 28.937942943265362, 32.57996366870019, 42.87337695398639, 48.89703143027521, 51.31105023045694, 56.01385439595869, 60.12924440445439, 48.53697353793729, 37.411354895560976, 19.74165778006277, 7.204065303648672, 0.6875003573875273, 0.13241262866124032, 0.071888059047201, 0.18971130161756472, 0.05577332678160841, 0.8776416028699568, 41.41451020394602, 62.81487557195849, 38.564284616901034, 80.77638918353666, 72.49422611728792, 45.96852710170131, 83.33587692629906, 9.741911368985331, 1.2420443781921942, 0.18927976428981752, 0.09428830141381872, 0.13775305822491646, 0.05663830899603425, 0.07243391967588857, 0.09397440454772404, 0.1437564143129895, 0.06319678005492015, 0.03404689321835195, 0.06639212895665439, 0.02037333076699607, 0.028103460527716145, 0.10022774278636902, 0.04569847384587892, 0.09974165999841306, 0.05025791890558697, 0.04276153789232335, 0.08646789202166182, 0.07131134805780265, 0.04890890701884224, 0.024733853436285452, 0.0693823539862229, 0.07465106239842792, 0.15999856615258803, 0.09161663106492451, 0.1664512940952855, 0.24533083241793419, 0.1594508132867275, 0.11144698552426793, 0.06656993796387989, 0.13318357358296073, 0.19498926437189504, 0.17177296982657525, 0.17438555947474896, 0.21624348516906464, 0.3346058774378992, 0.18221580543585364, 0.26386197836649034, 0.16351504762086178, 0.24516187938711337, 0.285747547543818, 0.34322212960931564, 0.3151402880828227, 0.12445675194143288, 0.18941621987089036, 0.4237655189729506, 0.22041949173135145, 0.30647108391408, 0.18946880414601297, 0.42538705131699966, 0.27591474774864416, 0.7124718206544077, 27.983691077078543, 143.4451093981343, 140.4876736671694, 103.66965570757466, 119.22836457529377, 97.83872296733242, 84.6359778988746, 12.148487471765089, 2.03250419468649, 0.4422298314109926, 1.61305193458834, 1.2712556171801783, 1.4647522664839223, 0.40898290252493275, 12.904815558464298, 52.33064682252946, 78.01364421844482, 52.55384537481493, 70.95857897112447, 66.80607549605831, 63.182484026878114, 64.25626031814083, 61.82455555085213, 70.83638929551648, 63.64655925381569, 66.43626659147202, 59.174417911037324, 50.020057001421534, 33.477543169452304, 30.564226258185606, 30.567415145135698, 30.54614413169123, 36.29988854931247, 39.28080751049904, 27.176173117852983, 35.585809292331824, 34.881916430688676, 43.614214620282574, 32.71903326434474, 36.185351417910674, 27.545632931493945, 10.8077605501298, 6.655904266142077, 16.534757344953476, 13.640959128256767, 6.770045728452745, 0.787356976539858, 1.493534005938038, 0.7681762186750289, 1.079713288814791, 0.7814926041230079, 1.2141977563019724, 2.329649598367753, 5.846551127972142, 12.676800335607222, 24.88862329913724, 40.96269238379694, 47.941353782530754, 41.47888806558425, 18.562055941550963, 14.332286677052899, 33.960171207304924, 50.08867102284586, 51.359397365200905, 48.913407325744636, 51.62477708631947, 43.56503202069191, 39.58792909499138, 40.91570631150277, 39.042896147697206, 12.86701665770623, 8.068718467989276, 6.47585766930734, 2.6522768024475347, 2.842113635232372, 0.15037443338622972, 0.10919238876311049, 0.2765976998113817, 1.4478049307100236, 6.19659471896387, 12.908928163589971, 27.422699966738303, 33.005313334926484, 30.049513232323434, 33.4616889492158, 26.01816784950995, 23.953818544264763, 16.991931161572857, 19.500384946023267, 22.23117632250632, 22.890966053931947, 36.67720879277876, 32.25074148947193, 33.567447816171956, 32.026550577532866, 31.455598608140026, 34.95570405837029, 30.62070642748187, 35.600824125351444, 38.92256959792107, 50.70545981007238, 55.015772004281324, 57.62153194796655, 57.213993764692745, 59.11068331810736, 55.114486294408, 53.28463000635947, 30.53577534614071, 8.800560178295258, 0.9885966297118896, 0.19115275733413237, 0.6496234382352521, 0.24686256393549905, 0.22388896604459133, 1.6966408298861597, 75.2541155968943, 62.66988123616865, 61.43345994334067, 111.30850299712151, 82.21781315342074, 58.432070132224794, 105.7996125375071, 8.00295453879141, 1.2054889913528197, 0.4665788022741195, 0.23589488148929613, 0.24547058217708143, 0.1493272065154968, 0.142291363088354, 0.1976200103038742, 0.36616486947863336, 0.18944269586955348, 0.17150917511072852, 0.1672431225738218, 0.12737280433817258, 0.218718025773283, 0.1927147493247063, 0.1675806302697428, 0.22684552917076697, 0.3262284914812734, 0.13644442683266056, 0.2322515665042785, 0.15169175221554695, 0.21710001743368565, 0.17118346516884145, 0.16793241784457238, 0.1964177272372669], [0.05298552899471214, 0.14008153650549152, 0.07695575364895406, 0.036661011211934595, 0.02963562488495823, 0.04407087791590922, 0.08831104594132594, 0.02611738141445864, 0.032978936008388, 0.010289818164892495, 0.07454553378685828, 0.011534734024485994, 0.0461832542843636, 0.04515701822275597, 0.0757572167522965, 0.02022326180350877, 0.054968884665398836, 0.05533817734929824, 0.042061689760415785, 0.09242519856460633, 0.1199901146033118, 0.07840837126657849, 0.07640912693234221, 0.07882673188202804, 0.06883459345948312, 0.04888300558612232, 0.20212073089374652, 0.093601526572339, 0.09178523169530016, 1.3534532968075046, 83.97033599115188, 111.03018729917466, 76.11717824013003, 75.55367485169442, 83.6618729560606, 46.69041579769504, 43.39792336187055, 1.3852102766113898, 0.13316236826921665, 0.31127715182881205, 0.11143072147763546, 0.6667573930275056, 0.04584565082745207, 0.38092373720099854, 14.474460828688837, 35.6294221262778, 47.05669064675608, 56.350738925318566, 54.25074115876229, 58.007010721391254, 58.68262721646217, 48.90781402587891, 54.03499510980422, 45.217624633542954, 40.047748550291985, 32.81262690021146, 25.275533737674838, 22.613758425558768, 19.462288925724646, 18.099024065079227, 21.11584055808283, 12.806580778091186, 13.029908768592342, 8.055788374716236, 9.285136653530984, 18.37331541122929, 28.718619692710142, 32.43078612512158, 24.64748186449851, 15.501295174321822, 7.881497365813102, 3.5779287065229113, 2.3015225270102104, 2.8500517770167324, 5.607795965286994, 0.06382999768961342, 0.17514073830698768, 0.2946352093450485, 0.06608655180541739, 0.4938710216552981, 0.9509535818811387, 0.8094632096828953, 1.3025758655801898, 11.065449483932989, 8.142424216193538, 19.759481030125773, 20.99389014705535, 22.935045649928433, 11.191958669693241, 11.430869256296466, 22.01901924225592, 17.305752154319517, 10.104078515883415, 12.449752957590166, 11.087515757929895, 8.42754767787072, 8.43024822973436, 9.483150647532556, 4.322650009585965, 1.4258334064675917, 1.1465991384560064, 0.9025433214922106, 0.34574038319049344, 0.06937071711065308, 0.03614782040277797, 0.02970560127118182, 0.14390937142795132, 0.31257257586525333, 3.374037285966258, 4.141883657824609, 8.090322392602122, 17.169355653947402, 19.465158139505697, 18.506421043026833, 17.960140782017863, 12.44330850339705, 5.139665007591248, 5.838500463193463, 4.253020094287011, 8.479554383985459, 24.5686500687753, 29.88152792376857, 28.023312899374194, 22.74063337233759, 17.46054849316997, 13.163376239038284, 14.639297454587876, 16.717761408898138, 23.208299529167917, 35.50427890593006, 43.55815218340966, 40.44442961292882, 35.15478787883636, 40.32875891654722, 42.700659305818625, 29.11648334995393, 9.453585782358724, 0.8104395734206323, 0.12695867252806503, 0.15060554679122665, 0.10289830996865228, 0.011326568783260884, 0.7387265731250087, 34.40037096700361, 27.891784060385923, 30.367907708691014, 74.57857362685665, 66.83044910430908, 29.746235570599957, 52.06229786719046, 31.187902727434714, 0.40859801995177425, 0.12073898087105445, 0.05861724433939784, 0.14667986711907774, 0.03918183884853798, 0.049314711453212846, 0.036049657726600286, 0.10623864484049621, 0.15721803470965356, 0.148605122681587, 0.08040374685679713, 0.10353557254758575, 0.008692175315152253, 0.08018389494428713, 0.035322050398756424, 0.017999831414330873, 0.0904091386004321, 0.07360968843943651, 0.11058135213510645, 0.07367877424844811, 0.09378900360916892, 0.07939060323781545, 0.03098618809974963, 0.027936997282649242, 0.07869106537151722, 0.05865025506805509, 0.04419334856192431, 0.07572343227483573, 0.11205686812078762, 0.09750751012395467, 0.051358768100579905, 0.038887377633082296, 0.08391196989724714, 0.040748557601604736, 0.051771896335506634, 0.04325375321411318, 0.015067849176815681, 0.011707571121082913, 0.011189338495774616, 0.06581233829380044, 0.014496083284968571, 0.10101873622906786, 0.0812794543021629, 0.09953562831205708, 0.1357791714009739, 0.040987002468037034, 0.01184406213372225, 0.04205825768651501, 0.2052528966939257, 0.1476098978591542, 0.06354292539218742, 0.09547176170012645, 0.015366132213403622, 0.08383751381188632, 4.502835850561819, 104.28159252289804, 126.78292012983754, 90.24052712225145, 98.73856175330378, 92.50477806214364, 67.53252198619228, 45.31422476614676, 2.054073308264056, 0.583622083067894, 0.04869550556665467, 0.6081902776514331, 0.5398335391955992, 0.491656475970822, 1.119979482985312, 14.254194248107172, 35.29172958866243, 41.67543019017866, 57.19655098453645, 66.53270982926892, 73.69047057244086, 69.86877979770784, 60.180278362766394, 64.31713550321518, 55.424639871043546, 46.50566431783861, 42.20579347302837, 33.80125637977354, 32.17729510799531, 28.95228901217061, 28.585984745333274, 31.484359387428533, 22.875315796944406, 23.438897632783462, 20.79884832905185, 18.141597470929547, 25.23223469334264, 31.967591470287694, 29.980079435533096, 27.420130814275435, 21.82512471752782, 11.408281307066641, 6.324695406421539, 7.4958484595821755, 10.68231922964896, 0.5953290097175107, 0.11638386295207086, 0.2866193249581322, 0.25280847875100954, 0.13637278228998184, 0.39259903974110083, 1.7250136622498113, 1.0447131217487398, 3.0059294642940646, 13.338112927252247, 13.08214101099199, 24.860727402471728, 23.326107917293427, 26.203625355997396, 11.909403320281736, 14.789004518139748, 26.233631487815614, 21.08959597925986, 10.86739234385952, 11.258652690918217, 12.09819091904548, 13.976487498129568, 15.185831689065504, 9.162170348628875, 3.103959300825673, 1.1419502717833365, 0.3051421052265552, 0.9170554782594404, 0.1899624558826608, 0.0721585417106267, 0.14536227249810774, 0.058632677180632475, 0.13703333394181344, 0.32843117812468164, 1.2975050989658603, 1.2282486668517514, 2.422712733668666, 9.885670158170885, 12.823921576622995, 14.68035682555168, 22.34269322887544, 26.34242626928514, 19.442873193371682, 17.40888499444531, 20.00930266995584, 24.115533944099184, 35.63144606928672, 38.56699105231993, 38.37836427073325, 34.545537887081025, 29.68248332700422, 23.848673528240575, 26.209185315716653, 30.823077194152344, 35.44547080993652, 44.557909427150605, 53.61913757939493, 53.55139432414886, 47.32485917306716, 49.06876064115956, 43.64037290696175, 24.037780800173362, 10.638078816475408, 1.3730066798387037, 0.5116413810080098, 0.11449701137720578, 0.2353607496667293, 0.1846715155988932, 0.9609089863877144, 36.476179476707216, 56.960357619870095, 40.01400047732938, 69.17280227907243, 89.78399461315524, 49.25028793273434, 62.49522201476559, 53.83959831730012, 0.5670628167929188, 0.2914544735704699, 0.08163037619763806, 0.26305344917120477, 0.10981311916463798, 0.014612548759267216, 0.030747067160724156, 0.030376096744270577, 0.08399389533986969, 0.018126931146628434, 0.05547597741467818, 0.059228126680658716, 0.045778204446598414, 0.12648112395958555, 0.16319499140785587, 0.031946891085094506, 0.03458123571509796, 0.07113340881563003, 0.026003835692761407, 0.03819553511998346, 0.05145174819194982, 0.051311875858734694, 0.015945381826661047, 0.07359317924466825, 0.010560726964726083, 0.15779010320623077, 0.19522926439681362, 0.12650216839486553, 0.2114419984601198, 0.18386344605636212, 0.11553049463057712, 0.25980437835378034, 0.17416975250647915, 0.14872794189760763, 0.16169324457164735, 0.3611414164545075, 0.18824071923811592, 0.1759926127570291, 0.1129476828200202, 0.14196330891741862, 0.17178620782590684, 0.1899357653793789, 0.2712569025255019, 0.232221765684024, 0.25736095624104627, 0.2182366774086991, 0.25103614965994514, 0.17253415478814035, 0.2086101697697755, 0.22825237303491563, 0.28872738442113327, 0.30780046096732544, 0.17378436431529062, 0.15068901973145624, 3.5098797515515363, 117.69155640755932, 139.34667187352335, 102.07353345809445, 106.58056428355556, 122.70798544729911, 83.74545866443266, 83.66020202636719, 3.8560173972960445, 1.8478533481397938, 0.2504932231480076, 3.2649029743286873, 2.432245318928073, 0.4994752306130625, 1.4975885109555338, 18.750212038716963, 50.02099444789272, 62.008389196088245, 71.10358115165465, 69.82164859771729, 73.9300097188642, 75.33436729061988, 67.7643419081165, 68.5702948416433, 59.79548600412185, 54.07596426625406, 50.66963680328862, 42.0778771369688, 42.18423612656132, 33.63988222614412, 35.34435210689422, 37.511238051999, 29.35516153612445, 29.679657259295066, 24.719431861754387, 22.40254467533481, 33.00699210936023, 39.30100771688646, 37.385937936844364, 32.927579802851525, 25.514351167986472, 13.890955313559502, 7.171625831434804, 9.32954768980703, 13.167383920761848, 8.148981928825378, 0.2347965412322552, 0.5231268163169585, 0.5405400561228876, 0.2202882608699222, 1.8069067453184438, 3.480822833315019, 1.5782118492549466, 3.9792666031468302, 12.535376337266738, 15.81899441057636, 30.715896468008722, 29.165330586894868, 28.180790178237427, 12.991335199725244, 26.19245836811681, 37.75703730121736, 32.73307927193181, 30.683454544313495, 32.1488893032074, 29.8931557901444, 29.3482679705466, 25.45646679016852, 17.415062727466708, 6.271992479601215, 1.425719167436323, 2.418982069338522, 1.7512423064439528, 0.543425939977169, 0.22106185645586063, 0.282038027240384, 0.1083669673290945, 0.23993803308375422, 0.547517707511302, 5.123255281679092, 13.54530526745704, 22.343556150313347, 27.928011071297433, 30.803898765194802, 26.91588463321809, 28.345317917485392, 24.63336721543343, 14.651183216802536, 16.340852033707403, 17.83796875707565, 24.167691661465554, 38.10481425254576, 42.999422319473766, 40.688436338978434, 35.48749116159255, 29.42928452645579, 25.091109775727798, 31.561963481287805, 33.74880644582933, 42.381558802820024, 52.45071449587422, 57.79208837016937, 53.595062071277255, 49.32712324203984, 52.08514959581437, 57.68901240441107, 36.44785996406309, 14.315333212575606, 1.2992604821920395, 0.677487159207944, 0.4493952356278897, 0.2346230069956472, 0.23864473877174242, 1.3618923988073104, 70.1718770304034, 53.94016788851831, 55.49448551670198, 102.98884991676577, 100.13502751627277, 56.421372967381636, 84.7471849380001, 52.97560999470373, 0.5291116790425393, 0.3522304042933449, 0.19722256388875747, 0.4055111452696785, 0.1222649131030325, 0.2088945569290269, 0.16257596172152028, 0.19975819234405795, 0.2224566420960811, 0.24107948876917365, 0.15657177825848903, 0.1951413481466232, 0.21622778036661688, 0.27622020232581324, 0.1995743925292646, 0.10050121319269943, 0.12701271237024378, 0.11597994309399398, 0.18067748556213994, 0.1888303924351931, 0.228191836767139, 0.14096422301184747, 0.13637040741741657, 0.25833253959013575, 0.37071791387373404], [0.1033343289107565, 0.08220706420439867, 0.07945075646162995, 0.032359810561061866, 0.03834690260250242, 0.060434638552608035, 0.07431370025921254, 0.046444942258418574, 0.056223472385036374, 0.004350865652198874, 0.11532016519096591, 0.030634881245092522, 0.09364932279793486, 0.06676436341818302, 0.07380859550809668, 0.10431953330313969, 0.15843233003491358, 0.04692048367653643, 0.05787575166792639, 0.05122989295951782, 0.04421866393738216, 0.03092184437498931, 0.02861710524396791, 0.0069601831473259925, 0.0948616722598672, 0.11141539971914985, 0.08156576434210425, 0.04689206947542487, 0.10616300131885276, 0.19874651195301166, 14.110047144274558, 102.95075585765224, 97.1212822391141, 72.870130385122, 94.30473804473878, 67.01679306645548, 50.34045188657699, 44.942262480335856, 1.559852582793082, 0.1582101951803892, 0.20645055258947037, 0.49487306466025693, 0.29215394248885496, 0.11876773705045063, 1.4261011082318522, 19.900276468646144, 40.43963255420808, 60.616100757352775, 63.4969953567751, 57.58949402839907, 51.41367120127524, 62.436339393738784, 59.7965411216982, 41.12803205367058, 27.575368419770275, 28.288629862569994, 21.727139988253196, 19.672169070090018, 18.232518011523833, 24.453495164071363, 27.046893758158532, 19.60447092210093, 9.643976649930401, 4.426301583167046, 5.751440025145008, 20.112666929921797, 22.834642779442575, 23.409262164946526, 22.951782403453706, 17.2471401768346, 10.702743991728752, 3.154614014971641, 3.517397709431187, 4.8144117766811005, 3.4911107199807323, 0.2643629079384189, 0.12155433590974539, 0.09917827127801795, 0.028008944430058042, 0.37781489111723443, 1.2144981853423582, 0.10129204575693417, 2.7699106451003783, 3.582795387314212, 6.571939558752122, 8.355222113670843, 11.101741213952343, 13.477984647597037, 7.224295418108664, 2.16196263509412, 15.81401300045752, 8.32874317323008, 2.7995573897515578, 1.2231754487560642, 0.6888681001240208, 4.775903907514388, 4.882091293411871, 1.3861012675108448, 0.7477808743715287, 0.19498511217534545, 1.4662142073915851, 0.5568807115477901, 0.28274861975542964, 0.2236811723560095, 0.11015785106968497, 0.09924885861936117, 0.20200146632569455, 1.0242297692644982, 0.6731159840860675, 3.651055414830485, 3.7030383415760535, 3.3253091910193047, 11.31467100112669, 16.829099847424416, 9.257949725274118, 5.727526314796941, 1.697382770719067, 6.276703736474437, 3.110119383181295, 20.192581299812566, 45.22159407215734, 52.73697299342002, 43.072186208540394, 27.869520687287856, 18.21045075693438, 16.98209385718069, 20.517873264128163, 25.897025446737967, 34.55683823554747, 39.90175401010821, 45.13336035513109, 45.37066767292638, 39.159621961655155, 30.87878465652466, 28.801038495955932, 14.603230280260886, 2.5852206974260272, 0.1337718525000157, 0.3702534807305182, 0.370018444955349, 0.31663955279415656, 1.1027648131693564, 39.16693718202653, 30.21190720219766, 26.47864430181442, 67.94310785108998, 77.1551864377914, 32.46990588403518, 50.91888773825861, 55.64788941414126, 2.31661188506311, 0.12959353235219756, 0.03552201849919173, 0.17946721985936168, 0.08073050633914049, 0.12144019646990685, 0.04705477122878356, 0.018123905099327528, 0.06387320121810322, 0.12792821808327592, 0.05704026000814573, 0.06007870644210808, 0.07650127964875392, 0.04399773950177816, 0.12185925422536752, 0.08502800678533894, 0.045633980733973366, 0.08355488099398152, 0.028601785400702108, 0.03044832159855193, 0.018436503446390553, 0.05211537568679741, 0.05452635397593822, 0.036929076867959196, 0.08071791951454456, 0.05867055639804852, 0.04308779941751592, 0.05265814132027088, 0.02516426461478395, 0.06790300756092034, 0.031157330226814075, 0.01569202505878263, 0.07385208631955809, 0.04227470050776198, 0.04948688971419488, 0.055885187109872225, 0.07593533985557095, 0.08273435486180168, 0.023358760086158593, 0.017963829112329313, 0.039647942063428705, 0.055390922502884944, 0.0631629457817443, 0.07077906250713334, 0.04093449480170685, 0.08012957164957639, 0.07349726503654834, 0.07849642541259527, 0.0556586932150587, 0.01441580301616341, 0.20318640516169612, 0.12531417286804608, 0.0578662138732691, 0.0989642109902155, 0.026641305115434433, 0.3089730657877461, 46.44231803955571, 129.5068257854831, 100.98622891210742, 93.33901128461285, 108.36920430583339, 79.40674458780597, 75.67744132011168, 36.68805414630521, 2.197065151506855, 0.4646736948240188, 0.14052114839996063, 0.4776753713527034, 0.058013781559683626, 0.3354713116442004, 1.6220900560578995, 12.652293366770591, 24.795129683709916, 56.84909174519201, 68.59421345495409, 68.24109031308082, 68.85295652574109, 76.52690118358981, 71.91555884576613, 49.45860501258604, 39.00610431548088, 38.88236530365483, 28.35741254591173, 29.036778826867383, 28.462104528181015, 36.64441777813819, 40.19558268208658, 35.791918077776515, 19.680290337531797, 15.431217128230681, 17.610867446468724, 25.54725593136203, 24.503768182569935, 27.53857658755395, 22.551786938021262, 21.62456608587696, 14.293844507586572, 9.877958778412113, 12.37657427787781, 9.810669537513487, 1.0093064990735825, 0.09941791124161213, 0.1974191726936448, 0.07913870586743278, 0.10025323819248907, 0.5468464306285304, 0.7895319308004072, 0.044902558288266586, 2.8861017909742173, 5.244101545503063, 5.33975491600652, 10.373350208805455, 11.826752116603236, 14.75649493355905, 6.51259703982261, 0.5737339104375532, 12.266563561654861, 9.868311708973302, 4.208634063120812, 6.71949569256075, 7.728165051629467, 7.886078203878096, 3.288269759185853, 1.3672530530921876, 1.41137640803091, 0.24935947430710642, 1.3482234290530606, 0.6949829526485936, 0.24508513269885895, 0.271971233549618, 0.09919037546722159, 0.2540216709096586, 0.08440723807941522, 0.27363931339594627, 0.38688046917799984, 1.3421842047283727, 3.6763149884439286, 7.633596706774927, 14.855084688432756, 22.46455146420387, 23.434581064408828, 18.285124840274936, 13.396267948612092, 18.892947089287546, 17.89303098955462, 34.68241291661417, 59.83368204485986, 66.50348817148517, 57.5982605257342, 42.69100635282455, 30.834361853138095, 33.26470359679192, 34.6821108941109, 36.070826053619385, 43.59645412814233, 51.75857305526734, 56.79475907356509, 55.41668138196392, 41.12461174688032, 29.67305591029506, 22.054575527867964, 13.10127531328509, 1.6237656435658856, 0.22855575917468918, 0.4265085733946293, 0.40455157417924176, 0.30498447497525527, 1.0619372297679226, 32.569924362244144, 55.484742349193944, 35.3574175219382, 67.11209881690242, 96.27996521611368, 59.65262151533558, 53.3798376975521, 72.1598126811366, 6.365598863170994, 0.706102443077872, 0.07747644062844977, 0.07957228098905857, 0.10948477388029138, 0.19537878943787468, 0.03184964579920615, 0.03903055180525107, 0.0814280906812318, 0.08731505503096888, 0.057446899478353804, 0.173761596182181, 0.026263662073160374, 0.017885010156239715, 0.08944849498690137, 0.09778635080663428, 0.014410928781745175, 0.04138668202945302, 0.036285517046288136, 0.002086660472653626, 0.01624446159469024, 0.0023901208271948442, 0.051474006876589797, 0.08406515683858626, 0.05096458138958101, 0.08557138528915183, 0.24420433076879672, 0.21192481771351832, 0.13291021808981895, 0.1527783560055879, 0.1590656089566408, 0.14335487698835714, 0.12003205025628691, 0.14610311016440392, 0.09812308475375177, 0.09505736942012465, 0.3054678151684423, 0.2557427333968301, 0.09731127670215023, 0.15439988834963692, 0.17866222999028622, 0.1835767299898209, 0.2897142895287083, 0.1123930121802034, 0.27752123412586027, 0.1499390809406196, 0.1729648953844463, 0.14141272152623824, 0.17160384825641112, 0.17153244886186816, 0.3714896708486542, 0.2851002951783519, 0.11470756298231502, 0.16561429707273362, 0.30931679411761226, 0.48266318596659175, 28.82545917264877, 145.0503315464143, 120.82080764155235, 108.99022533047585, 124.22803724965743, 112.54147652656802, 88.18376956447479, 81.07670153340986, 4.866649412339734, 1.5876591229631056, 0.2642651244757637, 1.1780004083148896, 1.486180052161217, 0.30705959265751226, 2.892952700776439, 24.589158181221258, 54.022545506877286, 78.35233303808397, 72.86708662586828, 68.25867037619314, 67.76649136697093, 80.68279358648485, 71.15265784725067, 56.25254631042481, 45.48143932896276, 46.786568780099195, 38.08128787625221, 35.75778953490719, 35.95701848306964, 42.97133422666981, 46.47270071891047, 39.84385982636483, 27.083787571999338, 16.684568351314915, 19.44790167193259, 31.82689997457689, 29.018441746311805, 32.618875541994655, 28.060444016610425, 24.519659665323076, 14.259455127100791, 7.396648776146674, 11.116045117378237, 12.948925552829621, 5.969798862934113, 0.3336140080805748, 0.2901647185846683, 0.11464491997274662, 0.21763949654996398, 0.8816717769349776, 1.7510275566770186, 0.25791397979182584, 3.652280665213062, 4.967880883524495, 9.113646707227154, 13.765102144210571, 18.104921348633304, 18.877904799676713, 9.349520398724465, 3.2932933347840465, 31.74253763691072, 25.0390403116903, 11.82087444490002, 13.541310333436536, 15.289257726361676, 18.440072190377023, 10.097909608194906, 3.4577784182563907, 2.6334082407336084, 1.3976303391879605, 1.9508350544398831, 1.3508255539401886, 0.6307123433197699, 0.48406907988171427, 0.2913941977725875, 0.31329211628725456, 0.18276070845463585, 1.9573399376484657, 1.9570982215865969, 8.836656770398541, 9.877728339164488, 13.357170743326988, 24.429099982784642, 27.92815031543855, 19.29056167602539, 11.77575247903024, 10.89733865953261, 21.55626585406642, 15.82271379809226, 36.20701859074254, 61.9944961609379, 69.03110273422735, 58.09596223215903, 41.47715830033825, 30.50500435213889, 31.7517355949648, 36.18328825120003, 42.526396243802964, 46.742548019655295, 51.46799210579165, 53.41675896798411, 57.283470707554976, 48.55539298826649, 44.81127100606119, 36.512280971773215, 20.459382880118586, 3.282934110010824, 0.7170233635171768, 0.8793432373673686, 0.358814500993298, 0.5457291067127259, 1.9192413432944206, 68.2747285596786, 54.1578947344134, 46.68516374403431, 99.00580852262436, 111.64501882368519, 62.92738876035137, 75.23463710661858, 94.94066407603603, 3.4325791510843464, 0.5781685176395601, 0.2193634548494893, 0.3924438609711586, 0.16505646248978956, 0.2779266784989065, 0.16622980275461752, 0.1430778749166958, 0.19565471898644202, 0.22095776042870938, 0.2048517424132555, 0.46955784241999354, 0.21055716690757584, 0.07473113390827373, 0.3500947963085867, 0.178746591592508, 0.2396006479619011, 0.13509960544686164, 0.10362266908369719, 0.12979392563143086, 0.09283101832073543, 0.1796392219201211, 0.12698507191793573, 0.10629694413153395, 0.16121223328575013, 0.2949555873149826], [0.08044241897521481, 0.035562536889506925, 0.03579492200045817, 0.017914594556655616, 0.011899053840146912, 0.021933817394798803, 0.09541957579072445, 0.09719715258407016, 0.04555343808005414, 0.033583310432732105, 0.056945468118834885, 0.04975693570750375, 0.07409820738699167, 0.042507303953771634, 0.045453440623297814, 0.024731597307348446, 0.0104984832784882, 0.04055748378197032, 0.051055876087517514, 0.014127825777376852, 0.040296730435182976, 0.12292766342720679, 0.09985421363624836, 0.08317658677697183, 0.029015440321076783, 0.09023309159543245, 0.08165396404482665, 0.08524485563318576, 0.05023309382640066, 0.07193839868470546, 0.16483147778818685, 40.60397201968778, 114.03456595636185, 75.69664524447533, 81.10146737867787, 96.22100414768343, 49.84754331650273, 49.67099351267661, 51.067977028508345, 5.0552624656308085, 1.2955778668965063, 0.5692014891293742, 1.4938089395723035, 0.5265071639610875, 0.052860051453594244, 3.3020765021924054, 24.85066063942448, 39.518165819106564, 50.88725774518905, 58.34100838630431, 53.180863703450854, 54.80351686477662, 53.847862751253196, 50.965195240512976, 38.74699254189768, 28.17332394661442, 22.059727561089304, 24.46476217239134, 30.836240668450635, 29.9827564531757, 44.29393391455374, 33.43825670980638, 22.27152574446894, 11.42755191172323, 4.585444888760967, 18.805591983179895, 20.227107963254376, 26.013329605902396, 26.04060576808068, 20.063062675537605, 9.683739677552255, 3.3092198737206, 2.2382456256497294, 3.9349242083487974, 1.9077479406710596, 0.3711859016649185, 0.0929523743088207, 0.3378601576532087, 0.20954832104184937, 0.8709361884863147, 0.26139505267623936, 0.3653317948262538, 0.9673862291439888, 3.789622456796708, 4.5845000878457105, 7.946835717847271, 6.659392233817808, 5.5199280092793135, 2.011126786951096, 0.10725620112592175, 0.5876908679642986, 1.4635655043586608, 0.3395533651834534, 1.3056750283125909, 1.8200925280970914, 1.819920311531713, 0.9095751506186301, 0.35636347928835505, 0.4428247752929888, 0.20287204864284686, 0.09666371790151443, 0.19266495360962807, 0.02987800744332133, 0.12833000055604404, 0.031195240087747097, 0.20020051618977902, 0.06147187946724796, 1.7650342179882912, 1.39986265811228, 0.5705722962175647, 1.35249158067088, 2.312810863218, 3.26435286191202, 7.446365308377051, 4.680141200942378, 0.4860690290168409, 10.724878907203676, 7.565431796735333, 4.426459948862753, 32.50217522344282, 38.79395115760065, 44.12103583735805, 40.69450816800518, 35.85093405938918, 26.670507038793257, 31.77473245128509, 37.53441925971739, 33.801209311331476, 39.46880671285814, 49.7899393881521, 45.00923302865798, 49.29570897932976, 43.963019232596125, 35.594042347323516, 17.045116539924376, 2.280858990646178, 1.1101207281312635, 0.4068076724727308, 0.434139728425972, 0.83152556130963, 5.228291451931, 51.686205325588105, 32.332709220147905, 24.137369778848466, 63.1089670427384, 89.9862555534609, 42.395887221059496, 32.94711320630966, 66.75645751337852, 14.329288025056163, 0.6778689774294054, 0.07228703763816627, 0.016678304847089515, 0.02010436878810006, 0.06071885717251609, 0.047683534062197136, 0.05208616858468421, 0.13750214910795613, 0.06294317430846634, 0.05501920515070519, 0.029865043320422693, 0.01623113166480776, 0.017477646732943195, 0.016650903797257813, 0.03279360018730645, 0.022494109204760002, 0.05824892075672265, 0.020839546979855628, 0.07460001029915388, 0.07668307997406491, 0.08998250423540032, 0.09654714230207667, 0.0483095734530399, 0.04466315964236856, 0.046987160139026186, 0.02507134581044797, 0.14050939661120215, 0.048747814050124544, 0.040227410969354456, 0.04682695200186103, 0.04129665903747082, 0.06452491221528861, 0.03235134145905895, 0.04633189832431175, 0.03134754794319311, 0.02072289285640563, 0.07767399172148398, 0.04214964048456281, 0.07870863176762097, 0.06851701937135189, 0.028822244437892112, 0.02313324869910796, 0.021423560702392173, 0.05435458174155605, 0.13480979438510635, 0.06418803271146552, 0.07379947140091851, 0.03866077648595937, 0.02695105936107857, 0.09008951139666381, 0.03235911342105077, 0.13297637744295981, 0.030381578103368802, 0.08946896485623815, 0.06512475139912098, 0.13492306814559046, 0.839246808280868, 83.1983978517594, 121.53486728668214, 92.67579340165662, 112.83192019308768, 100.81999886420466, 69.905453958819, 77.22348274723177, 42.73418380368141, 1.9906755488726402, 1.041195000852308, 0.2146588016541735, 0.9299060209624229, 0.55404226385778, 0.03873866847566059, 4.856098236576204, 15.914275646209719, 25.043878555297855, 52.30904240762034, 69.19741122953354, 70.18813917713781, 68.71019009620913, 64.18721483599755, 63.294177439904985, 45.31220082313784, 37.758382674186464, 28.950004231545236, 31.5050636183831, 36.4996862411499, 41.372536920732074, 54.51006474033479, 45.92171361369472, 32.640021039593606, 17.39279935436864, 12.21674063513356, 22.952160912175334, 23.769404388243153, 38.25550779219597, 33.46239497584681, 22.372899401572443, 17.4382007891132, 11.591864901204264, 9.625672909521288, 16.6418811967296, 2.376219899423661, 0.43338301741788465, 0.2221710904831848, 0.32303914487842594, 0.10684255961208575, 1.4176372462703337, 1.0176748758362186, 0.7108230155802543, 1.629700925081007, 4.31362267463438, 6.886620531159063, 11.593578976969566, 8.03149615564654, 5.444452781831065, 1.1494617332373898, 0.1638444501065439, 0.8699659534519719, 0.9764760768701954, 2.197670667402206, 1.454655963086313, 1.205973158920965, 1.714569248499409, 1.4553901817529433, 1.1233040594285535, 0.24256743070098663, 0.07553407832259133, 0.14740991826740005, 0.2205283375036332, 0.061792039102123636, 0.06956826054280804, 0.07145506615239768, 0.05478474777191878, 0.6250929351775878, 1.8116714444852646, 3.8726759485660063, 0.9404847758912271, 2.691569635944982, 3.9958834792337115, 9.474645968406431, 12.368494195322837, 18.15325475508167, 16.108778138314527, 23.05159691841372, 26.828500109334147, 22.214145391218125, 53.25625165816277, 69.22750365349555, 70.5301227877217, 62.26668903904577, 51.788324233024355, 43.44517223296627, 43.367917230052335, 50.392631176979314, 46.11531396065989, 52.95218952240483, 62.08883700832244, 52.4925857974637, 47.599958527472715, 39.09070591772757, 25.67009475923354, 13.517456439233596, 2.4134684426169244, 0.7817370781014044, 1.0786836666445578, 0.19227947348788862, 1.0411474421139688, 1.579131399912219, 43.88891389293056, 61.52731049445368, 33.30092276296308, 59.77174781983899, 97.3722590169599, 70.98553349894863, 39.24378033607237, 81.55017083691013, 32.89791099486813, 0.9359200563161605, 0.026756787124360283, 0.058441672308911244, 0.11439315283731108, 0.11638269083754671, 0.023219713212681875, 0.009799612866294001, 0.11624122504144908, 0.08613465143547905, 0.10542546549151022, 0.021066575220996336, 0.01585838392436985, 0.04341717509012069, 0.011453015425602996, 0.01207628636620939, 0.10191184153119404, 0.1575298478165942, 0.04794545569306901, 0.06704221584744031, 0.026671167222722888, 0.11641364845056688, 0.037891685497015715, 0.03538910990520831, 0.09691829657963208, 0.044775387692836024, 0.05588072464771329, 0.2549670693734961, 0.22453388950276762, 0.17740970687760463, 0.12959503388452914, 0.08627553500475423, 0.15307100159266304, 0.1349574348498737, 0.20523017452609157, 0.1800916274829257, 0.13134199014354137, 0.19637254337149282, 0.1774676537681972, 0.21529064033060305, 0.16296881160909132, 0.12784347343709201, 0.11853601843599351, 0.1165260105664211, 0.19078863574372185, 0.25582076711279733, 0.21056810664313458, 0.16071518011871846, 0.22503432877842458, 0.19999105242952225, 0.17125337835281126, 0.13793183250292657, 0.2583030911703264, 0.1492838459389825, 0.21200092088791633, 0.16066377561899925, 0.14203509135592368, 0.27010896573624305, 77.34048704947196, 144.7397582761703, 107.12993144989015, 120.61732292175294, 126.7576208422261, 93.76284691595262, 84.77859527834, 89.69253278547718, 8.734160334833208, 3.183959962860231, 0.5303877363762548, 4.137226333541255, 1.7463490270799207, 0.2696761567025416, 5.836873169868223, 32.92729739219912, 54.02670321925994, 67.36101242803758, 68.35645506458899, 70.8194289668914, 72.26296317192816, 69.63714814955189, 65.1903570851972, 51.40993318250103, 41.35773389570175, 37.18951348335513, 37.06186386846727, 46.6023938886581, 48.23078547754596, 61.917488267344815, 49.36152242845105, 39.7240274952304, 25.954670559975412, 16.54329046126335, 34.58323970917733, 32.41742064875941, 33.56111711071384, 38.240594940800825, 29.785471039433634, 19.436173785117365, 7.856226515385413, 6.996321380138398, 18.875943614590554, 4.813369406807808, 1.2557105287428827, 0.5462662875652313, 0.4239057743501279, 0.3681895785754727, 2.625560313463211, 0.5425988101670819, 0.4935967621784057, 1.4554917956552198, 5.950433140800846, 10.205754195490192, 15.103282467011484, 12.591532911023787, 8.13412546150146, 3.0227564323333005, 0.3558967785248834, 1.4165414341034428, 6.222809389714272, 5.817256416043928, 6.162662294603163, 4.785231303784156, 4.197702907746838, 3.2337228280882684, 1.856855310259327, 1.2964189701503324, 0.4446864915230582, 0.3463455313636411, 0.5114408498329501, 0.1534431671062785, 0.21227804553364554, 0.21744060480306227, 0.3542490766173409, 1.0807829927052222, 1.9063545186673443, 4.957366970277602, 1.065928363992322, 2.3771541589690797, 2.934529579454853, 8.206573109472952, 10.786332641878436, 13.273861562052081, 16.008232101317375, 26.109967001022834, 25.453591692832212, 19.25010831125321, 54.271835665549006, 62.27991134889665, 66.37652889374765, 57.41385029208276, 51.591232976605816, 41.34890464044387, 45.02254947539299, 50.92721493013444, 44.66520978558449, 51.53520584106446, 57.0604996527395, 52.88011204811835, 59.50278305238294, 60.94274790056291, 43.117626866986676, 23.80691009183084, 4.792235676319369, 2.292920033777914, 1.592095446202063, 1.043521579234831, 1.6439859521004463, 9.64319609826611, 77.87046986241495, 58.82256561709989, 43.92870241595853, 90.26469676725327, 115.74129904470136, 77.16795767507246, 53.7600604949459, 108.9430784410046, 29.981226728808497, 1.3598892933899358, 0.252047278467686, 0.23384600997932498, 0.27642508488028283, 0.1868530888591082, 0.11934513751898082, 0.18113091768276307, 0.3711579241339238, 0.31218085978781024, 0.2098964620381594, 0.1233046706165037, 0.22816661715267167, 0.07079505076211307, 0.09542154463668985, 0.2120803948491812, 0.2809040026078301, 0.20411295786259637, 0.1505341627184422, 0.1591404404250845, 0.18014863974625067, 0.21630330131419245, 0.17413972185984736, 0.16052833127398647, 0.29659271720916996, 0.18242713845064565, 0.13313219972675847], [0.13157146412038034, 0.010638889958030515, 0.04461918619551486, 0.04361849150530273, 0.04653116928473596, 0.009229657814777907, 0.0372185661727863, 0.05212068467611267, 0.0913849124504674, 0.017228254470072927, 0.033069690614337885, 0.029121185352485028, 0.08736152592445574, 0.026052970657004945, 0.06547195010728414, 0.09863062566446681, 0.061349106216502775, 0.029654451495697422, 0.06034203767476063, 0.036806023995121645, 0.04936360701498005, 0.0656815211198503, 0.06746247636094209, 0.07860747751809898, 0.026725647565458092, 0.016344037703088215, 0.018416020170515104, 0.11644737164099371, 0.07886796273411283, 0.259784490711266, 0.11325548928711685, 5.246274048282254, 105.28436999167167, 95.82270314616542, 67.36801778116535, 90.42167002154936, 94.16489770335536, 46.01455219330327, 45.08950433423443, 65.37110774747788, 9.613236054297417, 1.7975578985867964, 0.2755995178895612, 1.014537715142773, 1.0347794741392136, 0.2980349849789374, 4.847009124294405, 26.912583958718088, 44.13342268236222, 43.629743283794774, 52.83607952056393, 62.82732517488542, 59.89692634151828, 57.6902557957557, 50.21490858447168, 40.87117956530663, 32.99578197540776, 32.85733799780569, 36.73630322179487, 51.9849604945029, 55.311467724461714, 63.182107479341575, 32.81801427564314, 19.092042676864132, 8.245091765157639, 15.81241169283467, 28.733610991508733, 25.11318095268742, 30.01883245283558, 29.059228512548632, 17.071829841982936, 6.361963316317528, 6.236529350280763, 4.660120933286605, 1.257245278646869, 0.8663923065027884, 0.11919768857619456, 0.16489037462780554, 0.09539934340864421, 0.24067563785900994, 0.14359676158956944, 0.3263005650331897, 0.09838834269753388, 0.7216132107761599, 1.0695070364782888, 3.894138667852648, 2.6292375354997577, 1.0644294057161579, 0.13449232754928453, 0.10087764581605312, 0.1904587276400097, 0.15304875439934193, 0.035294766177333174, 0.09051853595601936, 0.1238293642358434, 0.5262930883515267, 0.5778695594879889, 0.20652734524300023, 0.024031613194834323, 0.13879630143844313, 0.04048000547974821, 0.033005044284847476, 0.08516614009896595, 0.06110405384172356, 0.0306340538701343, 0.049146030383605155, 0.8422467473053163, 0.42760999332512584, 0.7164500846016792, 0.3319529762431499, 0.3074365385597752, 0.16823379683398432, 0.670861479255461, 3.1313261678141937, 3.705026002660875, 11.373195705875276, 22.704790753702966, 12.109138254196415, 4.210297638370145, 26.21384116911119, 18.920499778562977, 19.024187634068152, 27.563715057988322, 31.57056720026078, 27.794897594759544, 36.604280164164884, 36.092646198887984, 30.026031963286865, 34.60106688161051, 32.800387144088745, 39.16929452650009, 36.57858079479587, 33.24753146017752, 14.279418030092794, 3.598346849603038, 0.6639135520785087, 0.34880960720681375, 0.11686338036651574, 0.48495026485573867, 10.39734923070477, 44.617756951239805, 23.4145652094195, 27.47941940061508, 65.39678750499603, 99.0789685710784, 51.93675064271497, 43.31724020742601, 66.30678915208387, 13.170643410375042, 0.8225881344368382, 0.07649179548025131, 0.09021078311507741, 0.12218870267632509, 0.07028060739920025, 0.014340067563969043, 0.06256027590303172, 0.09876855979523352, 0.055610958276496786, 0.06979143727690944, 0.0794415480847801, 0.12483871571959988, 0.02791732222953391, 0.10215647638805452, 0.017493931846993587, 0.0026352850029305107, 0.038850314299305605, 0.04209961877354691, 0.043544567851049286, 0.06632806868442605, 0.0808163081866599, 0.030157612298705408, 0.04901955309774607, 0.048320750675855145, 0.07289498969311677, 0.02180016761074864, 0.05105472695563109, 0.029467572007448446, 0.016645504792611447, 0.04824607242499629, 0.035203708966653195, 0.11151007286483243, 0.024442671077145685, 0.027453105506156723, 0.04140495705688673, 0.13192896671112508, 0.025828089377272035, 0.06402733427802883, 0.05278997356072069, 0.012455730672715413, 0.04796140947409215, 0.032367858314706434, 0.08185675517926294, 0.07138480056798266, 0.04445481820092086, 0.1379227467001446, 0.045430201346114765, 0.06781681500855954, 0.05924111187097527, 0.019098353617253806, 0.06168096784442183, 0.055319975100217335, 0.2093520799591657, 0.18796999908743367, 0.1026693186272056, 0.09243957037406583, 0.1742203755965156, 0.23144947244755684, 18.766729139512588, 126.5289858848818, 93.13143161035354, 87.58293305673908, 109.51974530373852, 86.80181657114338, 63.8462039732164, 76.17229538579141, 52.34627746766614, 5.667836666107179, 0.7903616959529539, 0.23195732745432088, 0.35323321338622804, 0.7442719465301884, 0.17747995714026113, 5.56689594061144, 20.14925087651899, 26.854464238689793, 39.82764867044265, 63.049484299075225, 78.84608099537512, 77.79490147867511, 73.76193615698045, 66.53241957387617, 55.338206521926395, 44.272302043053415, 42.460249393217026, 47.921561502641254, 56.11750695013232, 66.15793520404448, 71.56282009616976, 45.11323075140677, 27.698813253833404, 16.027015351480056, 22.19390988349915, 24.38096465602998, 26.04004683033113, 28.40260217266698, 32.16129772124752, 24.201498569980746, 13.844521314867082, 12.631061577027845, 11.358230883075345, 1.281157885828326, 0.35632489910048826, 0.3929706536714108, 0.0399514431163909, 0.04481554219138719, 0.6160144868396944, 0.14282973903802135, 0.9093735775639935, 0.2023498677918988, 0.456326155652923, 0.7567281684567853, 1.853409875785151, 0.3958083965605305, 0.7873184882825421, 0.360548893410352, 0.18730075999854073, 0.3360907396962566, 0.4945051892390175, 0.029667019168095245, 0.08230569036377054, 0.12815280441915797, 1.0213986147315273, 0.5915928908413457, 0.13152074909979297, 0.18279234788590865, 0.061518419308648, 0.037429745969993454, 0.16309964410479993, 0.07221605193110243, 0.10621615249903933, 0.14318069923789273, 0.1712272547545933, 0.8058424330046101, 0.8513753284369746, 2.033003316290917, 0.32357871592525517, 1.6851978052046992, 1.7895508701762848, 3.996973407845344, 12.687078906643777, 15.440557272203508, 26.613454203451834, 36.103232675983065, 24.27134813800935, 22.06231632540303, 43.05632806593373, 33.03299350123252, 32.88711074859866, 43.1007920542071, 46.09692981166225, 41.8006871592614, 50.05249892511676, 51.668786079652854, 38.741320794628514, 46.53266983647501, 39.12392447071691, 36.43634780760735, 34.580070434078095, 28.500996789624615, 13.758197792114752, 3.429458660464133, 1.2010089091716276, 0.5399570938560271, 0.35836545089560173, 0.9503823867247951, 6.9012544039757024, 54.4281421169158, 55.75183614607781, 34.707563154159054, 55.752761825438476, 88.12789932374032, 80.82987462320636, 50.74275370567076, 69.96126144163071, 50.6775168449648, 1.9503864333514247, 0.21410459832799053, 0.1255480058851742, 0.0936216057368344, 0.0324610069454197, 0.07434661905731886, 0.024936541148851958, 0.056569790092086604, 0.09035343634745768, 0.0643303488651591, 0.08224392835531505, 0.0715260518594615, 0.03992062722963672, 0.011937562207270776, 0.011965329064086322, 0.0267174695768664, 0.027667937627542886, 0.05561278539619619, 0.08579344353488377, 0.0943907043866573, 0.0412701677170492, 0.026292650840215148, 0.0026946939244460798, 0.04736225976939163, 0.03941532329566056, 0.03688125765972561, 0.004850331517387061, 0.22919418620726756, 0.08920584429776476, 0.11305533349514009, 0.1160226831392896, 0.27708591232376717, 0.1920305561995314, 0.3070863138043112, 0.1753087107452654, 0.22688239332168336, 0.08725439618912437, 0.08006385662743161, 0.1877208366509407, 0.1736351150658823, 0.22396051865671912, 0.21779709615774695, 0.3069277336039851, 0.1611156908855323, 0.33264414076843574, 0.32955420173464284, 0.11979196596169665, 0.18836864059971226, 0.12278617464847143, 0.15443486792425956, 0.23783925860639543, 0.22770530964818694, 0.4243865711314063, 0.23886406974446392, 0.3769514487395364, 0.17644596826885978, 0.26749841388194795, 0.37017003843380564, 14.225749219617537, 145.52889208639823, 123.70010975868472, 101.76859271141791, 121.94236232388405, 129.5527881191623, 86.4368792503111, 75.09402013594105, 101.49338353064753, 17.88211307217998, 2.211735551395724, 0.36004425597287, 2.7770934854784324, 0.8739407853253427, 0.23336352780461314, 5.352103517901513, 33.87966063714797, 57.17105950078657, 58.89740443998768, 63.546621184195246, 73.1607937043713, 76.16944774504631, 73.37998359434067, 64.49461490877214, 59.24452635549731, 45.300845561488984, 45.55687042974657, 50.59073048253214, 68.7030670719762, 71.12541306403376, 76.98548116991597, 51.10905601132301, 36.58897507575251, 24.04278378332815, 34.05509648784515, 42.172912243873846, 34.82928214534637, 27.311006553711433, 34.515763175102975, 22.179187267057358, 9.502332998860268, 9.281089748105696, 16.175652588567427, 4.237738049799397, 1.7153479615526817, 0.5109990622487761, 0.2875998255706603, 0.22781061609425854, 0.5608009366739182, 0.1649947464466095, 2.2240331624784777, 0.7498510278040363, 2.8131143268077605, 2.3203567679851287, 5.500828518021492, 3.095938789267694, 1.5115560711391511, 0.43713644988113837, 0.3112082958461777, 0.3507151436661521, 0.5845904794912185, 0.17780834838988321, 0.2064903125527405, 0.19473561266016579, 1.4726567003996143, 1.1776336667037781, 0.5567816717009391, 0.3135536587046039, 0.28835549469917054, 0.24656510731625944, 0.31358512959653334, 0.18657378852367404, 0.27896077462261726, 0.2092270850534401, 0.326274701904866, 1.7476322549966075, 2.3298349303583947, 2.8190704459144227, 0.208855057435651, 0.7046577238267469, 0.5957814306020737, 1.4125191660658007, 9.196192987503546, 13.243340619148748, 32.6388031436551, 42.131911708462624, 26.98320427248555, 22.17059139282473, 47.1689724153088, 32.80926935134396, 36.20451219620244, 44.09457945054577, 49.62224629617507, 38.7725781625317, 48.81677189180928, 47.51573347276258, 37.926283651782626, 46.931990654237815, 45.03285746420584, 58.83284222695136, 54.30770181840467, 43.57291206236809, 21.490709320191417, 7.449910150420282, 1.5568773424433124, 0.7742033081669962, 1.1576344817876816, 0.8022255786964971, 21.01973072175057, 62.81986482681767, 38.14600306172525, 44.53083330585111, 87.32801821924026, 121.09373400288244, 79.84113139490928, 64.938074158084, 96.41475354471515, 48.13616614187918, 0.8359833350104671, 0.30033775334877355, 0.20345818251371386, 0.24007171542654115, 0.13337981466564441, 0.10099877963864035, 0.12479137148587935, 0.16451730513043944, 0.2562697712452181, 0.18987225669045604, 0.2865448918554091, 0.3822388037318184, 0.12935388472772416, 0.2080520287516617, 0.08451852767217545, 0.12966980406593892, 0.14289674108787892, 0.16940516059196767, 0.20142746728754815, 0.21830122797719895, 0.14279420788009323, 0.19205381462891258, 0.1783573269964226, 0.2348312756587421, 0.16636498662973606, 0.13792573444304929, 0.11674356421515827], [0.016732695174493616, 0.08914739945002141, 0.061664914471968535, 0.03476806157719224, 0.06096818814835241, 0.06753976697162276, 0.06525471821547517, 0.07116620503966847, 0.047662807553405726, 0.049578065668503125, 0.07874595557129191, 0.06210178760210834, 0.014552009618660856, 0.040656619389811834, 0.019745673015413266, 0.007859211745521715, 0.04316673328679416, 0.041178478483831694, 0.037406100666210536, 0.06231008307828058, 0.03194560980304115, 0.031861826597202214, 0.015212398476808544, 0.04633938683377159, 0.07801945141005902, 0.021762993194222934, 0.09299701425216853, 0.12830943875615636, 0.022396498111887805, 0.19008414128855353, 0.2550869161683706, 0.38767205250840037, 30.637098012431977, 112.53244723043134, 75.96009515946912, 53.380218167458814, 101.71701354365196, 95.8239112361785, 52.41351473715998, 39.782764988560835, 69.88626572393602, 19.35891485983326, 1.0738372105744578, 0.5446293721756628, 0.7249762754767173, 0.9830236771414358, 0.6651294255448926, 2.9097370130400506, 21.21402336705116, 43.797608960059385, 50.954016485521876, 40.239615209641, 33.27967136136947, 39.697563263677786, 47.01110093824325, 46.872107828817065, 44.488891401598536, 46.40737364369054, 52.82523808940765, 67.5538989036314, 61.8031943228937, 51.39605975920155, 40.89851848540768, 21.03437489078891, 6.752575001408977, 16.577452344279138, 29.253579993401807, 40.837090246139034, 59.43496134973342, 40.85590977822581, 15.727570826007476, 12.54143443799788, 11.793430601396869, 14.378399041391189, 4.678598238575844, 1.005188561975956, 0.21001756521722964, 0.15979429646845789, 0.4083392660944693, 0.9089405846691901, 0.6926285499526609, 0.3044543727751701, 0.4249335272658256, 0.4169524232706716, 0.6286162654719045, 0.9707885175462693, 0.3472327837540258, 0.26223220291637606, 0.23625515731832675, 0.28850037724741046, 0.6791934515199354, 0.3251731900438186, 0.41364335244701755, 0.10387136420655636, 0.21479070667297612, 0.19294330399603615, 0.039845998774492936, 0.021699111037436995, 0.17226361849855992, 0.0625612564955748, 0.022480022763052297, 0.10711160203021382, 0.02128799952897093, 0.04336983085640016, 0.1300216222842855, 0.15280642546713352, 0.40865851025427546, 0.9935639438129241, 1.130727757850001, 2.283974088007404, 0.25812155897578887, 0.6917184987856496, 5.707152053233116, 7.0537424279797465, 10.190914888535778, 18.498701818527714, 27.25627183914185, 8.316948606121926, 3.409786993457425, 10.922581072776548, 15.765573690014502, 24.84673434688199, 29.797726485037035, 31.091998815536503, 26.565940572369485, 32.88804623388475, 34.42297558630667, 39.32310635043729, 35.6735291788655, 36.60079709945187, 36.815950870513916, 27.972661372153993, 13.347117708575341, 3.2222516113711945, 0.4480654908524406, 0.686490347068156, 0.7136087564210738, 0.3724509886195583, 12.859040517960826, 29.061974171669256, 17.75576372300425, 38.95747084771433, 69.72644482889484, 97.93428759421073, 61.82413193487353, 51.59289606155888, 72.63908709249189, 41.46553239514751, 0.4873895500936816, 0.11382968750812354, 0.026786310237742243, 0.14652557701112764, 0.14196744579220974, 0.05104939881411772, 0.0656733239790605, 0.05685686621995223, 0.06647204724891533, 0.23213294545008292, 0.034908876198554234, 0.03446885061660602, 0.0994014403512401, 0.011376669018289015, 0.04263660044319207, 0.0317682393811523, 0.012516461335302842, 0.03285456929476031, 0.05227886268027848, 0.02371580302414875, 0.069493513344036, 0.044268976761809284, 0.04642688556604328, 0.02827021680141409, 0.02217981780338432, 0.05728571457908519, 0.09922753073154919, 0.07564890724156173, 0.010439023364245171, 0.15885580811769734, 0.007003495364540047, 0.05160811822861434, 0.09211625828738175, 0.016604044114149386, 0.008446927587952345, 0.03721557459944198, 0.037062786023823485, 0.05933907153385301, 0.07605926989908181, 0.07137011466247421, 0.025888428377408176, 0.018093089212573344, 0.004797472408221614, 0.0032351895436389193, 0.02698569994179472, 0.057397322098333994, 0.07992845824769429, 0.09361258122108637, 0.03032167002769007, 0.013740409368408785, 0.03512731850928357, 0.023292041488833005, 0.06733648554091493, 0.0831803942339555, 0.08244139517867759, 0.0523226063007549, 0.06515510380268097, 0.07461965279353243, 0.1969390194262228, 0.9041927394367034, 67.61771586633498, 118.88026991198142, 80.43646089492306, 85.14447396801364, 111.82129013922908, 78.36904233501804, 56.988469246895086, 78.07582947515672, 63.1129051023914, 8.45288226681371, 0.15068862136573563, 0.4262824855264156, 0.8095190421708169, 0.724882812749955, 0.563224409857104, 3.9029294348532155, 15.98645902449085, 28.311795380807695, 36.13428215826712, 47.7990266584581, 50.88052303560319, 59.17984647135581, 61.69811794834753, 63.49049598939958, 60.917574128796986, 58.5370994383289, 65.54637101388747, 72.11006133787095, 63.96785236174061, 59.61921076620779, 61.917358829129135, 34.51817543275895, 15.680336663799903, 22.871516981432517, 28.764238818999264, 31.14641385693704, 33.09757924848987, 32.044175747902166, 25.028799003170384, 20.292315406184045, 15.063934230035352, 25.467088568595152, 4.9164870477491815, 1.4555273421349064, 0.4786684051636727, 0.2532081621428651, 0.46169909798810566, 1.4502483221792406, 0.657530201058234, 0.19099414649028934, 0.4008390508111446, 0.16806617679615177, 0.2844953308663061, 0.31137701905062126, 0.1940085952200236, 0.26822408300734335, 0.5618720501661301, 0.243480040601665, 0.3840322768495929, 0.23980583695154037, 0.585274565364084, 0.048488443492040526, 0.1394030277527148, 0.14946746189267407, 0.06587940163069195, 0.08836797393497922, 0.06506419214870661, 0.11709129918486842, 0.052274331270206364, 0.059893205912122806, 0.05514203968848433, 0.09114081385515391, 0.16849506345968093, 0.17911439040495505, 0.3822977005714371, 1.4572297733637596, 4.7645172669041544, 5.460487921391764, 1.3434749096632006, 2.921041529024801, 15.095503426367237, 17.85204222125392, 29.301866331408103, 53.45531586677798, 42.860723387810495, 22.107352979721565, 20.283217468569358, 26.45593770088688, 29.192565564186346, 38.602402210235596, 46.632639285056825, 47.7031207853748, 40.10818050753686, 48.4542429062628, 41.40576331846176, 45.12244439894154, 33.698560883921964, 25.991197632205104, 25.91156763415183, 20.685007418355635, 12.522505079546283, 1.3398934179736723, 0.808854629435847, 0.46202869965664806, 1.4897382547778468, 2.0429590272326625, 13.030348074051643, 51.72078101865707, 43.11160602877217, 35.484525849742276, 56.2691810823256, 93.56601453596546, 95.01220810797908, 60.954154153024, 69.07699446524344, 75.82775438985517, 1.8110373688320962, 0.19242928964236092, 0.1061998578088899, 0.07572576118212554, 0.05289903766806087, 0.031891386099760576, 0.11173500394028042, 0.04878044939569889, 0.06840988963602052, 0.14713268636936142, 0.06503881931665444, 0.0793080342813365, 0.09283436612496454, 0.08742440642128069, 0.011540163672649333, 0.05248571791115308, 0.022568708931606625, 0.03868764318946389, 0.04337635026463578, 0.01042315002245408, 0.04247209072233208, 0.06796413371639867, 0.0580341250245129, 0.024824171372118498, 0.06124197648117139, 0.00861453804968586, 0.03002844987467172, 0.03144569146717268, 0.141555673532909, 0.20189559297455897, 0.1780235424878136, 0.22354407326108028, 0.17464632048241555, 0.17295502817198155, 0.2257846352914649, 0.16278853579874963, 0.17753523804487722, 0.13772017773120634, 0.11718997130951575, 0.17900353748231165, 0.17520381798667295, 0.08929051233515625, 0.32635342509996507, 0.13042859883318025, 0.09638898345010896, 0.17761717880925826, 0.18279783307544648, 0.15715588965723593, 0.15623437781487742, 0.12708739062110264, 0.17770746993201395, 0.20564449019730094, 0.17633335334399056, 0.09752463218906234, 0.2176648080949822, 0.3227155493392099, 0.11506371725831302, 0.23631840553735536, 0.30590595617409677, 0.49059486196887114, 55.80334863355083, 147.15098042641918, 110.72489353918262, 85.36576624839537, 124.97468394617881, 122.22990343647619, 85.5074187247984, 72.11709022521973, 104.18068562784504, 37.1203189511453, 1.0466450116326733, 0.5457318646292533, 1.384228213179496, 1.1832717061042786, 0.6553106911240086, 4.3551296860941, 24.355920322479744, 50.48011572130265, 62.87240889764602, 57.259638386387984, 51.599226767017, 55.67774257352276, 57.194134804510306, 60.710610266654726, 57.27868149357458, 54.69936616959111, 64.15663996050435, 77.16316453872189, 77.5695691570159, 62.47915206416961, 55.74913755539925, 39.667827775401456, 23.851240719518355, 33.51574313256049, 44.36137906966671, 56.69893557025541, 72.7228218509305, 49.80741746963994, 26.91514918881078, 19.506801943625174, 16.385137554137938, 28.716860509687855, 13.835684214868854, 2.4062272569825573, 0.815225723049333, 0.36109404157727, 0.7011225651348791, 1.7455541342496874, 1.3291217314620174, 0.8209254784930138, 0.8058477036895291, 1.3490291084012678, 1.4760912257817485, 2.5462007138036915, 1.2183462756295358, 0.8913403581227026, 0.7914063947335367, 0.4424137844433708, 1.8737716347940507, 0.3796949934574866, 0.8477088929184022, 0.2531490048333522, 0.48612093913459015, 0.26754824024054313, 0.19578588856083734, 0.24693905015385922, 0.20707621659723022, 0.169552264795188, 0.15740948008193126, 0.3616314675779112, 0.1171067588391804, 0.2619635512030894, 0.32142576370989123, 0.22188967574507962, 0.4762816429138184, 1.5616198557038463, 3.8106277296620035, 4.716105903348615, 0.5484218751230548, 0.7731182825180792, 9.353911492132372, 21.95774789779417, 31.921303579884192, 57.15217721077704, 50.13533153841573, 19.251120282757668, 17.95456317163283, 25.40596039064469, 31.576582154920025, 36.458458208268695, 40.90866173467329, 39.196504008385446, 36.843207420841345, 48.762207800342196, 48.53165480398363, 61.69975749907955, 50.65944648558094, 53.15152437456193, 46.006872192505874, 35.617451052511896, 23.15331574409239, 4.106731376340313, 0.6420436417383533, 0.8903540045984331, 4.600816657466273, 1.9286333360979635, 27.975114814696777, 42.540528543533824, 28.71949634244365, 55.191804055244695, 91.31515456784157, 118.92857782302366, 83.80747918159732, 78.73445818501135, 92.55894599422332, 80.62558189515146, 0.6107131584036736, 0.2605654713847945, 0.11573687105649903, 0.171626846215898, 0.23048816999841124, 0.2102223558411483, 0.1774022605029806, 0.1463327833241032, 0.11552845683669853, 0.3782021332411997, 0.1472523952684095, 0.14563633279213983, 0.30314708969766097, 0.17675358321397536, 0.09352707814785743, 0.14209058676515857, 0.13580520306864094, 0.17313380244999163, 0.12250852140207445, 0.12064369485503244, 0.21728686627841767, 0.13412068297545757, 0.10255272770600934, 0.11536735620710159, 0.13103008510604983, 0.1601182903733946, 0.1257440707676353, 0.17712870582697854], [0.06066200578765524, 0.07887226814824728, 0.01758571301076201, 0.007493482328080122, 0.08145269742535968, 0.035842090033956116, 0.08619365552740713, 0.09634861827737863, 0.05879235671712987, 0.04774046971672966, 0.03740909223955485, 0.08381099184794773, 0.03381811638152407, 0.05347023665484402, 0.08043782244766913, 0.025831582738206755, 0.09318638352617141, 0.07389196885689613, 0.07038419780832145, 0.03697267110129038, 0.058077665631689375, 0.03626341540967265, 0.07927704602479935, 0.05982116300372347, 0.09563067897913918, 0.12619043189671733, 0.008737999821952995, 0.09061281073598132, 0.15664478643767296, 0.0654099123071759, 0.02914022072218359, 0.18977640376937008, 0.3311736503195378, 63.2130471352608, 99.72396312221404, 64.6975112730457, 55.27042796534877, 92.45324596281975, 89.14804504763696, 52.37829577538275, 34.533374617176676, 63.07580732530164, 34.695952938449004, 0.27493804693222046, 0.33455972830134056, 0.24231380963277435, 0.4852930432365787, 0.10603360140756254, 1.84328121283362, 11.416836977005007, 33.48720004481654, 47.776582856332105, 45.15432542370212, 29.6857447778025, 40.063206611141084, 45.412786083836714, 46.09253283469908, 45.15525502543296, 35.35150651008853, 36.567621692534416, 40.849904629491995, 39.96559058466266, 18.59421153222361, 17.58079267317249, 9.797027534054173, 11.393089967389262, 41.1451728113236, 64.62292740421911, 102.27076591983919, 102.1119099278604, 38.24584699446155, 14.38668308719512, 15.570883904733966, 9.801360772502038, 1.2576388639788474, 0.481668466762189, 0.27339925208399374, 0.1709242516587819, 0.7662562797627142, 0.541826777400509, 0.628338941643315, 0.2211170147864088, 0.034016291836216565, 0.06794649837238174, 0.03515419670410695, 0.21727594186461743, 0.055667177638820106, 0.06472859201171706, 0.39256919295557086, 0.34044729786053785, 0.7682963412615561, 0.01932149013173917, 0.02133290760309225, 0.014671889929881981, 0.09314824766930073, 0.12047896296867441, 0.02168062725104392, 0.030421000987952276, 0.03917039732538885, 0.03697185521765101, 0.03551691635361603, 0.03833213625776191, 0.032823753408006126, 0.04948543031669913, 0.05915500358828615, 0.3116529332774301, 0.6041915438348248, 0.6927043007266137, 0.8784410922277359, 1.449793327239252, 1.2070637004029368, 3.7593233729562456, 13.353293480411654, 24.312325139199537, 15.030625462532045, 18.562661947742587, 17.818855047225952, 4.873123774605413, 4.948877000039624, 6.814272903626965, 11.149501954355548, 15.540125658435208, 24.66301052801071, 26.86719625226913, 34.74736344429755, 39.76155673303912, 28.064801769871867, 24.101489897697206, 26.687608572744555, 25.187129397546094, 15.131218567971262, 6.192840520412692, 1.4989337613505702, 0.3883107553326315, 1.6532188437638746, 0.8864403984719708, 2.068108161610942, 19.452071151425763, 19.298512320364676, 18.470890252820908, 53.449671576100016, 78.38336683088734, 100.67582038141067, 60.02252847917619, 41.77890231532436, 66.3957328181113, 73.83761436708512, 0.9298153774392222, 0.11776243051093434, 0.022844353112422174, 0.1416611638400824, 0.07771171389087554, 0.15803853019831643, 0.08232903306282337, 0.11007928875305, 0.21425832153087665, 0.06169115681381476, 0.07022036990571408, 0.05897420300771633, 0.01294193794995907, 0.07262055401600177, 0.03702384577463231, 0.051442750489279154, 0.066051832700689, 0.07636628729561645, 0.008674664460423013, 0.019067681371985425, 0.022955612061665426, 0.04413182787116497, 0.02586642824744265, 0.04540631855507532, 0.04286011808641976, 0.018129152801608848, 0.009139832090436211, 0.013705957436843986, 0.02561865817575205, 0.049103811278098056, 0.07755076647886346, 0.0010443499711747732, 0.017254793670989813, 0.012426011249302857, 0.04878582350248772, 0.06489149294793606, 0.034122747414174585, 0.024414787391921686, 0.05340779282813592, 0.03644133933008679, 0.0327441070769583, 0.0470836642348478, 0.08196458971548466, 0.030973007557012384, 0.052703463081871314, 0.06055964111921288, 0.022149331334437576, 0.006626921014920358, 0.04452309578717236, 0.04835526293684398, 0.031760545943172715, 0.033576036427891066, 0.04974745153900116, 0.10924966915720895, 0.16617933288216594, 0.030137481423275127, 0.10796526146511878, 0.042234844783501285, 0.16414244298733052, 0.09404346737409792, 0.3071915742851073, 5.745642762030325, 115.96998891522809, 104.7337398221416, 75.85107680289977, 92.7882242202759, 112.2038467468754, 78.93908039216073, 50.44368082477201, 68.7971725771504, 72.81731174838158, 9.519279599189758, 0.4058935150744454, 0.24585949437272167, 0.22277633058688334, 0.27463381809573023, 0.16488153397315936, 1.8556676901155904, 15.111250762016544, 22.466479309143562, 25.313357153246482, 28.70620539111476, 27.397522272602206, 49.88539811103575, 56.83326890391689, 56.80900119966077, 61.31162720341837, 47.0093515611464, 49.70424736699751, 51.74568414688111, 46.313483868875814, 31.412985978587983, 37.738519791633856, 23.097584747499038, 27.626131734540387, 57.9717250793211, 70.08113691883703, 92.87221785514586, 88.40867827015539, 49.85417212209394, 20.599756663845433, 19.28074594466917, 18.214065221048173, 8.431472989820666, 0.3626713859698465, 0.6301071951466223, 0.07763358058347818, 0.7338180332895249, 1.161029538319957, 0.8002779380448404, 0.11233157192867611, 0.11763811742346134, 0.16943692259730833, 0.17806310326822344, 0.047518840480235316, 0.07468709151350683, 0.11054903088558106, 0.2357680173290353, 0.0978974412165342, 0.6833873845396504, 0.19773780398311155, 0.09428374319066925, 0.02603402147219787, 0.09308365879640465, 0.06114929516409194, 0.043784709602233865, 0.11996075811405336, 0.04863468201590642, 0.077061228634369, 0.013766586592781448, 0.046925015086608554, 0.0327544684161342, 0.15848128305327508, 0.07696765865529738, 0.21360512432311812, 0.46237806639363693, 0.5203087772092512, 1.48163243166862, 4.797248465399589, 4.96172619442786, 8.266345127936333, 23.290539864570867, 34.183071659457305, 35.022917793643096, 34.70614717852685, 34.44608619136196, 23.362362384796146, 21.89953011851157, 21.341251327145486, 24.229841616845903, 26.887900483223703, 35.52704042004001, 39.27895222940753, 44.024239586245635, 40.39952239682598, 23.385321978599798, 13.623815428826118, 15.19525420281195, 18.662552948920958, 14.995564376154254, 6.172834471348794, 1.936484082571922, 0.7143019740619968, 2.2877037717450053, 2.951352870272052, 5.358565132464133, 25.900769349067446, 44.021992068136896, 38.35156663771599, 37.11962861399497, 61.560176034127515, 100.10099703265776, 90.75958221189438, 57.18685096310031, 69.92958438011908, 96.43074897027786, 13.320767225757724, 0.4377520168500562, 0.13305624976994532, 0.15244844790187576, 0.06339790494812113, 0.017296083894888722, 0.05614417079355448, 0.04053347458642337, 0.06762230528458472, 0.02250693734705208, 0.03169848707564656, 0.07206645028124894, 0.08159064687788486, 0.0580977333048659, 0.043373707261297016, 0.06202193059688134, 0.09261989981056222, 0.06955679986746081, 0.0538416016065786, 0.08813414857873032, 0.0566873922493429, 0.02961540399419685, 0.03297043243242848, 0.045308148218018394, 0.008663558100740756, 0.12962146391791682, 0.04742147453549889, 0.053043295854642514, 0.06648031333761831, 0.17041377663131685, 0.24315095987291108, 0.1362213267073516, 0.2335301672499026, 0.1293762085298377, 0.1192977779635018, 0.1865810816807132, 0.34235994361581346, 0.11915454250429908, 0.11934929737640966, 0.07078928212004323, 0.20363645117369392, 0.18311143882812994, 0.24455719086672031, 0.16447055844529984, 0.12605137927758117, 0.2612067176209342, 0.18086102490703906, 0.19082258876052596, 0.12196810765852853, 0.12246809494231017, 0.16668314294468972, 0.20612484264758327, 0.18685488150485102, 0.30421437275025154, 0.28632998887088995, 0.2227865808433102, 0.13446324685167882, 0.16873458851008646, 0.20444145636452785, 0.2011182129142746, 0.35814141614302514, 1.6622580684000448, 113.07098865509035, 127.10430345227643, 99.98414178048411, 81.82203031355336, 116.1997692046627, 108.98442022262081, 78.45030600024809, 59.12173655725295, 83.55690248550908, 52.33976241080992, 0.31638680506617795, 1.1282852243992592, 0.6250312191344077, 0.4254431902400909, 0.2761902329662154, 3.199730342434299, 23.7109532279353, 51.519692867032944, 58.655668766267844, 59.36242103576661, 47.28649054804156, 59.66068198603969, 62.237177125869266, 58.01504373550416, 57.331429527651885, 41.3184239018348, 42.686421102093114, 47.18666230478595, 51.470804445205204, 30.52580664234777, 31.224094437014674, 24.612823801655924, 26.364799468748032, 57.38604460993121, 82.65209797889956, 110.29469582342334, 112.48726937078662, 47.68672527805452, 21.43554706727305, 19.1156376946357, 17.87458016026405, 12.737967737259405, 0.7869439632181199, 2.4548036052334696, 0.501372064313581, 2.187273689816075, 2.335813848241683, 1.7272896175422978, 0.2287283128187541, 0.2885126959412329, 0.3325603613930364, 0.3761844108662298, 0.42637496766063476, 0.18540340535823377, 0.2718952989145633, 1.0887992141708251, 1.3776937896205534, 1.7489837566691062, 0.12979129028897132, 0.10571756715615911, 0.1632368198085216, 0.35342069042305796, 0.16180245806613278, 0.07907003374590028, 0.1539641222165477, 0.12338488002217586, 0.1305536703476983, 0.15155261532673914, 0.17412490571939176, 0.16740300512361914, 0.2262302992805358, 0.08113645633021671, 0.40777753978486986, 0.8751546363196067, 0.7960952205523368, 1.6585288749587153, 3.5668019229365937, 2.233713326915618, 5.555694631991848, 20.195246550344653, 56.326012303752286, 55.54873581855528, 49.918204815157004, 34.08714617452314, 17.64164040165563, 20.891224068980065, 17.138282637442313, 23.008225310233332, 26.552290724169826, 33.2799929957236, 36.81461726465533, 51.471714435085175, 54.18115046716506, 40.721294033911924, 32.3380083422507, 35.1268135347674, 36.375543225196104, 27.04329498352543, 12.672179783544234, 1.2706830737090882, 0.6845456481941286, 5.663253866857098, 4.253530983001956, 9.353756558510566, 40.11580559515184, 33.94744703846593, 31.771706342697147, 72.79303227701496, 94.3467152503229, 118.18823829773935, 78.66731505240165, 67.0903375071864, 81.39642961563604, 112.27400225977745, 7.447436115434093, 0.682299600974206, 0.1795498041375991, 0.1548707413096582, 0.25467906627924214, 0.26139232540322893, 0.25345655849143384, 0.15856066508398903, 0.3984306235947917, 0.21034785636490394, 0.18269952867300282, 0.2143886790520722, 0.1457034574160653, 0.14937387659184395, 0.19512837061718588, 0.10411501080999452, 0.20000714027593214, 0.14110159789842946, 0.2157984646938501, 0.1612626265494093, 0.1184580919723357, 0.1467899845973138, 0.14689310003192196, 0.12379099089171618, 0.14669742585430223, 0.2517276359421592, 0.1145780711404739, 0.11769326043225105, 0.1659034952641495], [0.05213502967249482, 0.011201968412816284, 0.03992002202017654, 0.02249492317317955, 0.028137034330997738, 0.05704646915077202, 0.0691652599902403, 0.1021417981434253, 0.08453414820495152, 0.04983939358123368, 0.05167738789872778, 0.03962169972158248, 0.017739428552768884, 0.11085678372652301, 0.03758698934689164, 0.10508411203420932, 0.11294689374945818, 0.08468627794495515, 0.016362385508874734, 0.11573457279272618, 0.019394107606081713, 0.057560675026428317, 0.01207798133574186, 0.04094329715195683, 0.047804005218729864, 0.021432979753421202, 0.023846430591337626, 0.16510936852184036, 0.18767326259084288, 0.34385691006337443, 0.16059442934009338, 0.04605885692721894, 0.11974352622224439, 1.9742786932376124, 79.5416662769933, 96.34985400784402, 56.884746090058364, 66.53391007454165, 107.46642374223279, 94.74736967394429, 66.76310985319077, 36.13714941086308, 47.72323077724826, 51.12662430732481, 10.430157896011107, 0.3165544251040105, 0.19670917772718016, 0.21351809673491987, 0.20577906120208003, 1.0805146780706223, 7.635100935736011, 18.172037024651807, 34.10991945574361, 45.10347581678822, 41.18242748322026, 38.259316413633286, 38.02463316148327, 34.132461317123905, 35.94478461050218, 31.13714333503477, 22.098711998231952, 16.143271461609874, 25.547740344078314, 16.05649588569518, 15.56701840892915, 16.295600629621937, 33.14419661798785, 73.7809596523162, 79.71098715259184, 46.36358430308681, 15.426663256460621, 13.26373694404479, 7.798130819874426, 5.992742276960804, 3.281846878028685, 1.1812790194826743, 0.39467513801590093, 0.542768084954831, 0.3361540798458361, 0.26034698310878973, 0.14206241005130354, 0.11069451098240192, 0.02156337557901298, 0.03184207302007464, 0.03013491885916841, 0.07708414232418423, 0.020036669598231395, 0.008829064693512216, 0.10137119030039157, 0.20683745763474898, 0.13049673469316575, 0.13467603543352696, 0.06544604101368497, 0.09771484415978195, 0.08672654628753663, 0.07644833531230688, 0.0525410256288465, 0.06650914888708823, 0.06996667988958859, 0.06819136305561951, 0.10488721211591076, 0.011936124834802844, 0.057877747326969146, 0.030155197206524112, 0.06358296880798955, 0.04013842602650966, 0.6403550613791712, 0.5740856367253488, 1.0961849146312284, 1.0231718324845838, 4.924403371349459, 8.204858053115107, 11.541372229976039, 13.4322331413146, 10.951101606892003, 17.188479169722527, 19.250912397138535, 7.220566224667334, 9.005577564239502, 8.031323081062686, 14.373705925480014, 20.820291926783902, 21.0648811248041, 29.11532036719784, 25.58330055206053, 17.478724756548484, 23.480335512468894, 29.54961892097227, 24.99654535324343, 9.236146250078756, 4.350977857266703, 1.0126144054435915, 0.47370896644649974, 1.648537985259487, 0.33164369122635934, 4.319588109370201, 11.294038353427764, 12.872087301746493, 25.31406710224767, 56.770518825900176, 79.75843998693651, 109.51488940946518, 61.615265723197695, 40.48601850386589, 70.9352251791185, 81.23463969076835, 7.871126128781227, 0.249488728661691, 0.004955384196833738, 0.05646765525002153, 0.08757421491487373, 0.0233526581958417, 0.13106452841912547, 0.0542243353031095, 0.058398108719097036, 0.06422420738325005, 0.027074891728379076, 0.041675979812299056, 0.04907260085606287, 0.05067915618119221, 0.031654714726872986, 0.0832505678878196, 0.05149044712344485, 0.028083222399976467, 0.06062162146272679, 0.020751431546804887, 0.08184599930480604, 0.1003112999962703, 0.02010737568320286, 0.038392174568387775, 0.02970412655192758, 0.014829097875213672, 0.03176552168424091, 0.0650729791771981, 0.06659366370689485, 0.029181026395470388, 0.08017143835463832, 0.03814449834246789, 0.039691306470382604, 0.03836784744635224, 0.04826581834124462, 0.07075583472126915, 0.0692815368153876, 0.02207097586154217, 0.08595223057894938, 0.018432460417370164, 0.03621633164584637, 0.045582729451839006, 0.016002791498096722, 0.08854170735444754, 0.11841292342832012, 0.11770344174076473, 0.04411253777723159, 0.08283278949919247, 0.035240588439328056, 0.1354249017012696, 0.037962525647373936, 0.08022468146537581, 0.03297242809147124, 0.07935181620620912, 0.03134178504678271, 0.017910187635871194, 0.040472670187873226, 0.11493867638731196, 0.15453665036587946, 0.20515397942114263, 0.1328391710957212, 0.17121009438508944, 0.2453662563235529, 20.309583640867665, 117.96051333027502, 97.26962627903109, 75.8489901019681, 93.72469794365668, 114.3083473943895, 83.35587316943754, 53.16480159759522, 59.430262350266986, 69.60296077112999, 25.297830450919367, 2.503704284468005, 0.3757642576050374, 0.37609290932455375, 0.33321840027647637, 0.6520725906856599, 1.2561439506469236, 5.940053078436083, 18.32454466050671, 25.633714775885306, 26.432285808747817, 23.167473539229363, 27.46341613031203, 35.3567664084896, 37.222735958714644, 41.75615256832492, 42.22212622242589, 30.606099520960164, 21.63287562708701, 25.873654004066225, 22.35957903246726, 28.888413213914443, 24.75179533804617, 42.75825146705874, 81.61827102784189, 82.51016309184413, 65.99378401233305, 30.04631453944791, 11.411627088823627, 8.838127659213159, 9.899249403707444, 6.3768330216407785, 0.9219166432176867, 1.1635917040609545, 0.2820898760710993, 1.1678942989918495, 0.5420081257339447, 0.010687065397148893, 0.1518373548864357, 0.004358516476537672, 0.027750445296987895, 0.07317511740350917, 0.07156599568383348, 0.017984940580302672, 0.02022797132902328, 0.1796839767766576, 0.32112533466950544, 1.5130650804888819, 1.3058841396724026, 0.010974590644060124, 0.09854164455206164, 0.04633362968302062, 0.10304107811422118, 0.005647292306211087, 0.07678246456048182, 0.05326651855401936, 0.08304706429161372, 0.11140635222076409, 0.05446520483782215, 0.08960852309340432, 0.0816066887590193, 0.09441350316328388, 0.1431601834032805, 1.187964576867319, 0.390916649372347, 1.2522793128605814, 2.5090347855321826, 6.5277589617236975, 9.477897613279282, 12.959370824598498, 24.60244913255015, 22.41132490096554, 31.034181118011478, 29.934878041667325, 16.78176664536999, 13.199565006840615, 8.12327814678992, 14.234664767019211, 22.2616982460022, 26.826254552410497, 29.0927843893728, 23.378661794047204, 11.05018558040742, 11.721612003541763, 18.228721157197032, 20.819454500752112, 12.235301290788959, 5.899902226463442, 2.85952577187169, 3.1541607360686026, 5.775248321794695, 6.323727071285249, 10.518219028749774, 26.60180280285497, 33.66584831668485, 33.04784359470491, 32.20464579520687, 60.75162649154664, 101.8789525185862, 86.8208557559598, 54.530931749651515, 64.15503178873371, 92.2930092965403, 30.005874902971332, 0.3273395641196159, 0.1608604763544375, 0.07435801078475292, 0.10891701079784863, 0.009718927528498875, 0.08294652291243115, 0.011567833810864438, 0.15088431086511384, 0.026064082762346636, 0.02203025254270723, 0.035212086138105204, 0.03478817521564422, 0.02861664176077372, 0.14511758401509256, 0.09261104383415754, 0.10317520478800421, 0.03991392396029927, 0.1146266104713563, 0.055785116874763084, 0.04404933552347845, 0.05238565150648356, 0.05384378112672318, 0.06390844509305973, 0.04248739332861958, 0.051139540549728184, 0.014739567094722824, 0.03193153102221268, 0.057119710986772855, 0.04670896297020297, 0.24934874907616647, 0.0793849035436588, 0.17384969629347327, 0.2075117222604252, 0.1511240963854136, 0.18567590283290034, 0.16390982805000198, 0.15537534810362325, 0.16935406252741816, 0.1197194021135088, 0.11525471829959463, 0.08167948243358443, 0.1346482264418756, 0.2016601435119106, 0.2721242059863383, 0.18885532093624915, 0.1616569932910704, 0.20078986762992798, 0.11123545332661561, 0.3615081274221021, 0.19557993348327377, 0.1464747087729554, 0.19147429975771135, 0.13052146401136153, 0.1460452245608453, 0.11787892950157966, 0.1642452060214935, 0.2473494128113793, 0.23454232261546198, 0.44013154722990533, 0.358433295642176, 0.2539767934790542, 0.43301498877906036, 8.289840125268507, 130.88897489732312, 123.66277663938462, 93.89195565254458, 90.72348071682839, 129.7881538637223, 109.24960382523076, 88.27792998283141, 55.82527468281408, 63.103981710249386, 78.24498561120804, 18.847779035568237, 0.42567528423763096, 1.5469628163883764, 0.8561582911399104, 0.4244355701150433, 0.7217875723877262, 13.190706333806439, 39.70156800362372, 60.20986480097617, 67.37302272550522, 54.34511338510821, 54.82950648953838, 59.09261295872351, 49.246706808767016, 45.5355994163021, 38.300748409763465, 30.022105670744377, 23.184988883233842, 33.78434311959052, 24.409845067608742, 27.269666733280307, 30.67316028379625, 45.22928191769508, 84.9300850591352, 82.31547232597106, 58.47320402822187, 30.103320306347264, 22.984371416030392, 14.600573855061686, 9.761584997177124, 11.666787074458215, 4.190674510694319, 4.0326750663019, 2.5692029633829674, 1.6326901388745156, 0.6859917157600004, 0.2827709895228186, 0.2343645902170289, 0.049999004169817896, 0.11928473914703054, 0.22625614708710104, 0.19323553589563217, 0.16819468038457056, 0.1410549278220823, 0.4530628968871409, 0.8617866471890481, 1.61861005569658, 0.8968259766697885, 0.16968276021220993, 0.27542454340765554, 0.21547048713170716, 0.23146651024299286, 0.17656045244826427, 0.17707523288986377, 0.1953391673704309, 0.08469491941674102, 0.22389233683145818, 0.15012649669041558, 0.2248433124153845, 0.18160187789509374, 0.4345268173323524, 0.17029982871345936, 1.8762153939854715, 1.0092321579014103, 0.9432762777132373, 1.9115731096075428, 7.853134216800814, 13.404350972944691, 18.52851575420749, 30.033172638185565, 30.534614324569706, 44.90581581669469, 37.53234824826641, 22.527697701607984, 17.709803350510136, 16.463268226192845, 30.445156828049694, 38.73961848597373, 31.44227235547958, 35.77958614595475, 34.24237789646272, 23.442780779254054, 31.8098258972168, 41.55371119899135, 43.89693513993294, 19.74759428731857, 6.677527312309512, 3.7302235537959687, 6.249689392505154, 6.122431524338261, 7.740061600362101, 18.466783531250492, 26.598211872962217, 24.41838210628879, 41.64962883918516, 75.32824839315107, 97.2447584521386, 129.5060020877469, 79.74592762608683, 66.04917572390649, 85.1861216945033, 114.47675043536772, 18.784842644968343, 0.4222444054340163, 0.23719404403480793, 0.16976290833084814, 0.14800676204744848, 0.30720683475655897, 0.15647773330490436, 0.09624947117821825, 0.26525941467092884, 0.18180116800771606, 0.11185032315552236, 0.21531610509320614, 0.22578512558773642, 0.15865657929210894, 0.1955282378701433, 0.3848352595683067, 0.2493427735903571, 0.1449161028910068, 0.15227180334829515, 0.21105225888952134, 0.1914372211021762, 0.15809949547533067, 0.13964483574513467, 0.21795107983052733, 0.1603319676172349, 0.0679884263644776, 0.10189755399140621, 0.15704404082029097, 0.1481745353028659, 0.2348151724905737], [0.10735259796943396, 0.04218692981427716, 0.07419898625343077, 0.04371647798125783, 0.13742422264429832, 0.04889956074616602, 0.11198164594750251, 0.0445477484965757, 0.131536147467071, 0.04748993598285222, 0.009142512440561287, 0.056550044175838275, 0.02759690403998379, 0.07870388202249043, 0.06582330101199689, 0.026542462536223957, 0.06886215730299873, 0.06202062058653082, 0.03229351331209464, 0.001485297851163083, 0.05261337114197593, 0.02121045036361583, 0.04074626316827151, 0.03119926396456938, 0.03650700455651649, 0.025779919683813088, 0.07061448383836016, 0.04813722665271452, 0.13062004420545795, 0.10672481955900308, 0.3191076429380525, 0.07663012797673864, 0.056231259668786684, 0.3159432095145026, 8.113189320410452, 102.7594618643484, 102.04731633586269, 49.451909526701904, 59.589259547571984, 104.2678250035932, 96.31352501530802, 88.87652289482855, 40.11692739302113, 29.6425594822053, 41.986470222473145, 25.77112520894697, 4.505321652658524, 0.35244392831960036, 0.25739181426263624, 1.1639102740633873, 1.3782860675165731, 2.3055633037321033, 8.820015134349946, 19.846775339495753, 34.07051140262235, 31.186773084825088, 33.1982704131834, 30.711897611618046, 30.64421319192456, 28.505776197679584, 34.19081834054763, 19.592644976031398, 26.39638435456061, 36.6238724031756, 35.52564405625866, 42.371195900824766, 59.12425471890358, 55.8859694388605, 16.203168995918766, 6.297740388301111, 11.428744312255613, 6.715187949519004, 2.3919910144421364, 2.6646531060818703, 1.9253405063383042, 0.36813169297191406, 0.5816308060480703, 1.7611085383161422, 0.3699164633308688, 0.1293750134326758, 0.019763226004978342, 0.07777111634852425, 0.024491532164956295, 0.07490001033030211, 0.08105952578086047, 0.10384268953555054, 0.0617351379215477, 0.09502805123526244, 0.038092595885597894, 0.14979596039460552, 0.4569108339567339, 1.0920747609869128, 0.005844858721003778, 0.07905792955669665, 0.11971979281835018, 0.08855529009334503, 0.05529024705831563, 0.05372827805037941, 0.04336667457415212, 0.02164324024511922, 0.04905760468494508, 0.04855114395820326, 0.08921418699526018, 0.047383488065773444, 0.12815480390864034, 0.06305280915131012, 0.10364994947468081, 0.7208248756585584, 0.0862273327525585, 1.4397950830959505, 4.120832297109788, 7.79521502794758, 11.178902079982143, 6.606895231431531, 3.2701403191012726, 12.480197414275139, 7.293168315964361, 5.137053689649028, 7.95760948811808, 3.7621212486297857, 4.561866050766361, 12.349667799088264, 5.7787083425829495, 16.3561757533781, 15.976424620997523, 34.43650776340116, 35.71758524064095, 13.29994728488307, 5.574329812680522, 1.986451033622988, 2.258464953591747, 0.6001494800852192, 1.3681537273430056, 3.091738175961279, 3.434587894908844, 9.463175977430037, 18.086464635787472, 35.07569720668178, 67.16957722940754, 91.05142224219539, 109.4792821330409, 46.871444948257945, 50.1340606904799, 74.393202412513, 76.2208543285247, 14.185300757808072, 0.12002182298249776, 0.0629784603182587, 0.015470893779439072, 0.10921842043077755, 0.0818435401625691, 0.0768826841827362, 0.09841400664299728, 0.04220039763998601, 0.06528576775904625, 0.04697796708393482, 0.060979012970722495, 0.049106002289561496, 0.03342450040602877, 0.048431684037730585, 0.052044596823473135, 0.06405797779500004, 0.02801437216300157, 0.06226389946776533, 0.04788730961961612, 0.060109863237988566, 0.04733450440389495, 0.04214598624516399, 0.06738506317619355, 0.059003057709384354, 0.05165980618086554, 0.013602073041481838, 0.06643743539649634, 0.036360103366596085, 0.07105867693861646, 0.020916308989868532, 0.06291085305894095, 0.03053905896752352, 0.0238166450928416, 0.033883233855087916, 0.014640897842905214, 0.017784108715732733, 0.08448966147918856, 0.020641708603849816, 0.03610696876421571, 0.024191934329968308, 0.06832727471426611, 0.0705272034411469, 0.10750510309252048, 0.10562220453134469, 0.0760125385357007, 0.20836520549510756, 0.040159508766185854, 0.01926852472787423, 0.07958223247119496, 0.06544926624384619, 0.10035937967439813, 0.05277099373239664, 0.0534058929300837, 0.06582740724327103, 0.04181653396376679, 0.0290387811049098, 0.07364676709497169, 0.08379757764839357, 0.05280814516628462, 0.10047166518145993, 0.1465258221592634, 0.05988527690210651, 0.25983836201410143, 0.7711945438096601, 38.82851116118893, 119.86470637782928, 90.28518722903344, 80.80113933932397, 98.23863214062106, 113.62141486137145, 86.62996184441351, 59.56883576608474, 52.1748738135061, 63.3664196537387, 49.18988343208067, 12.98690096024544, 4.855370636909239, 1.248849077570823, 1.7110241613080426, 1.9540171998162426, 1.8673613787658754, 3.1114694139649792, 6.661486779489826, 12.405951849875912, 20.25144430898851, 15.832776638769335, 14.19774643836483, 12.713253863396185, 18.423788470606652, 26.819247238097656, 33.47576633576424, 19.46674866061057, 21.7632120655429, 27.151925025447724, 35.253564926885794, 56.26113237873201, 65.92456986827236, 63.85153055191041, 44.72622617598503, 16.732440879268033, 10.857015713568657, 7.428793580301347, 7.080018385764092, 6.917287092055044, 3.7558260896513542, 0.2944922266948608, 0.34685948443028236, 0.48216240961224804, 1.203315630555153, 0.26050773899882074, 0.13380128559806656, 0.14237354900087082, 0.03925857787591316, 0.16357181473605095, 0.09120226942843969, 0.048498299213186394, 0.08174613208299683, 0.06786107956882446, 0.05874124333082188, 0.05745596995937729, 2.2004452540028483, 2.69695921770988, 0.08205426796790093, 0.14763925434841266, 0.039870540401147264, 0.07145814582585328, 0.05266844137241283, 0.12945326165326182, 0.13488071880513622, 0.03185466367511019, 0.02675065842096604, 0.04038998248776601, 0.09977612629412644, 0.04757689845357691, 0.045147066740619565, 0.09365012719025535, 0.6309622718441872, 0.5428496579970084, 0.29812982666396326, 1.8575473634466049, 5.243976029657549, 11.043650911700341, 13.330586879484116, 12.839361986806317, 14.463530163611136, 17.944829810050226, 17.30801732309403, 9.50577978164919, 5.889788885270396, 6.56910466571008, 11.108961316847033, 22.620269560044814, 17.043606427408037, 16.746108378133467, 13.830298800622264, 21.49749109821935, 24.370835135059973, 13.299092208185504, 6.140481291278717, 2.073067263249428, 4.92922249340242, 6.596068999459667, 8.25899068386324, 15.770355059254555, 19.91531091351663, 22.537680133696526, 25.924913498663134, 30.022366508360836, 43.44652545067572, 66.37835671824794, 101.80820080541797, 90.49417111181444, 60.08030891418458, 61.703601421848425, 93.67263240198936, 43.96528636255572, 0.43489018815659714, 0.05885143358741076, 0.05716985527185663, 0.06669687873293316, 0.134977322492388, 0.06011281267649705, 0.10911830039995332, 0.1549581212983016, 0.08195395641509565, 0.029274537002727873, 0.07339188198168432, 0.038264816281415766, 0.08490164058222886, 0.03981964534989769, 0.028810619053641157, 0.04903224334421177, 0.07705536806174824, 0.1304060758482064, 0.011403645846932646, 0.06961389640045744, 0.06044703385522289, 0.05327164751267242, 0.10067853190365339, 0.03395641440405481, 0.04639377141551626, 0.04315966229525305, 0.0594627028030734, 0.07738215052672932, 0.04225583942306619, 0.03198816024157549, 0.140702803168566, 0.11303012920243126, 0.10935725088441565, 0.11958996389782238, 0.36046450116461326, 0.1073454810126174, 0.2037659659981728, 0.17459316930222898, 0.19414279850259905, 0.10879718698561193, 0.09645321226168065, 0.20744150264128564, 0.1658171265115661, 0.18121155609767284, 0.20478565966890705, 0.26345739201191937, 0.22164244385015583, 0.10852380850983244, 0.18102245495444347, 0.11186680936765288, 0.18595529509888542, 0.19222707307386785, 0.1417953211573824, 0.22026357751700187, 0.1197612994620877, 0.12563375410653893, 0.2955177426338196, 0.14852192553301014, 0.2902613375936785, 0.2514449954633751, 0.541169964257748, 0.21398251455637718, 0.4160359676086134, 0.7041665082496982, 21.284994732949045, 143.57627345669655, 127.16285659420876, 84.42765297428255, 83.49423869963616, 127.29925309458088, 112.36158094098492, 106.82081730135026, 59.62692999070691, 46.18532042349539, 66.36781338722476, 49.05362421466459, 10.822228212510387, 1.910754314834072, 3.851896457133755, 4.058748531726099, 1.700173291948534, 2.3488723991378664, 12.428829073905947, 36.119734087298, 59.12957345285724, 47.10922687284408, 47.2570296256773, 45.67802067725889, 43.49323303468766, 37.88343960239042, 41.672672763947524, 29.645926836998235, 35.942105631674494, 48.78867987663516, 49.32653488651399, 59.22333771182645, 80.31393389548026, 78.1813726117534, 41.9379073573697, 21.566824874570294, 25.354069394450036, 19.595567141809774, 11.52914914392656, 6.6139461821125405, 3.687318217369818, 0.37092901706214876, 2.0265622941717027, 3.49971836132388, 2.0823439138550914, 0.39399092956896753, 0.24533607245933628, 0.34215411111231775, 0.11362351792594118, 0.19854060284072356, 0.28225596393308333, 0.17697380284868902, 0.21623999180812992, 0.3771761882930033, 0.17992589202138687, 0.2225308606941854, 1.5382694957717773, 2.309216256103208, 0.1468693053409938, 0.19515158308129157, 0.2955686108719918, 0.20129343254431603, 0.19308820186603456, 0.17137904741591023, 0.36331018072462856, 0.2426331457231314, 0.2432470579421328, 0.2023010067040882, 0.20574975067809706, 0.1452614859707894, 0.30514388255053954, 0.1573946486197172, 0.7662321326713409, 1.3675680684466518, 0.1854124298739818, 2.86257688556948, 7.135142395573278, 13.371533482305466, 26.54873705679371, 25.539976012322214, 28.74805708085337, 31.918049973826257, 30.615921135871645, 20.233264123239827, 11.242003210129278, 24.32382945091494, 31.001823525274958, 31.19677708994958, 18.67526927301961, 30.188486729898763, 29.569048381620842, 45.66111918418638, 47.195385656049176, 22.43409622100092, 8.652996690042558, 3.446790388514919, 5.642281443841997, 7.032171353217095, 9.177225385942767, 20.886048501537694, 21.884780045478575, 21.65223644625756, 36.06005130275604, 60.00692136826054, 89.47328013758506, 107.86081021831883, 125.54556139053838, 72.85321712493896, 77.78578589039465, 87.28564093189856, 111.10402199529834, 30.373797147504746, 0.3152374893186554, 0.14837148118643992, 0.20084418326375947, 0.22713610632044656, 0.15668368838246793, 0.18702437079721884, 0.21717409813596358, 0.20027286553334808, 0.21479579349679334, 0.1043236012300176, 0.1382697232428097, 0.16597144726303317, 0.20342989854754942, 0.19595496416572603, 0.12610829961035522, 0.12822349901281058, 0.16567563007195152, 0.4753479043081884, 0.11508723615758842, 0.22892728117444824, 0.17887864982889545, 0.1535451640525172, 0.14224729771094938, 0.23132205670399053, 0.1972631052617104, 0.1225855592037401, 0.14394545416918494, 0.256045276839887, 0.2861665669948824, 0.14860133820724103], [0.04467519488365901, 0.03985107027655167, 0.043911244344687274, 0.029156492429695306, 0.06682458558991071, 0.013940159133785676, 0.06896018591378966, 0.02203528382514994, 0.05693037235628694, 0.10060900942452493, 0.068996038828646, 0.03150753391486022, 0.036066856400500384, 0.0689637022573621, 0.1025503375116856, 0.04507150748864778, 0.08052256709385304, 0.03212328282966009, 0.032776148704391335, 0.08915181977734452, 0.08447246280528846, 0.06938225439479274, 0.08593373721645725, 0.023924636677087798, 0.029428210409898913, 0.03387855305787056, 0.08258968681818055, 0.06626559421420097, 0.0904320982555228, 0.15920779487538725, 0.12569394563474964, 0.08246707444589946, 0.04594221621030762, 0.06621273414742562, 0.7274386046394226, 21.394705387853808, 106.16856636539583, 91.58171100001182, 61.436248748533195, 67.02338264834496, 97.65962754526447, 98.08515764051869, 87.53647650441816, 51.9526715432444, 30.51410621212375, 25.965347251584454, 24.158099505209155, 15.376248052043302, 3.243446138597304, 0.2605932650546874, 0.3571362474993352, 0.438042946400181, 2.00759849240703, 5.261703671947603, 10.566043507668281, 24.54081693003255, 31.665690560494703, 35.520038989282426, 41.359075346300685, 39.11095319255706, 30.95208787148999, 21.106113080055486, 21.191155948946555, 24.529087082032238, 32.73518754589942, 10.200586472788165, 10.630567477595422, 6.4063763137786625, 3.5898745300308352, 1.2289886464995723, 6.389793022986382, 5.238359685867064, 3.670655498581548, 2.6348676075858455, 0.2623721825019006, 0.29464538299268295, 0.444577094167471, 0.3489645408286203, 0.14964121063390087, 0.10597559322993602, 0.04978181441284476, 0.062168950530430006, 0.03137411970284677, 0.10280870066414918, 0.07781977825347455, 0.015038334681922871, 0.03949690782915681, 0.0965446065510473, 0.037740252897023194, 0.0865099655704633, 1.2237935897804078, 1.9148838351811133, 0.3246722604718901, 0.15403703846518071, 0.03794415485894969, 0.06762282622437324, 0.04132209315655693, 0.0502665335642955, 0.030125720058417613, 0.012775589618080807, 0.041674665971508915, 0.06248795337254002, 0.1525434734480035, 0.11624723117077544, 0.06536395469259831, 0.016217219508102825, 0.47065491097108014, 0.23272631119095513, 0.07578759213849422, 1.2684864238385232, 6.260880895199315, 17.815199398225356, 5.20282301210588, 2.866612269032386, 2.020575776696205, 6.259958647912549, 5.62705627372188, 2.1077863679778193, 3.660743178859834, 0.7923052916603704, 5.777091345479412, 14.30178044303771, 13.589982044312263, 22.107560865340695, 21.696512160762666, 14.058920029670963, 4.544032994777926, 1.530301691062989, 0.09188556623074318, 2.5471006526101023, 1.5859842708995266, 2.345382715425184, 4.442085691036717, 2.701337318266592, 8.169962196580826, 23.853094039424775, 43.34783469477008, 69.16657355523878, 99.26334350339829, 92.63216880060013, 42.01027900941911, 49.4056216362984, 70.7958084537137, 75.29243715347783, 11.785932990812487, 0.14974176733484193, 0.042084408097810326, 0.07409667521114312, 0.06699673320737577, 0.0639126624070829, 0.035913332380474575, 0.09243010152732173, 0.05004930933336577, 0.04288995721107049, 0.03892288580837269, 0.007942080912705993, 0.02424893893241402, 0.05195158991902586, 0.07430137390451086, 0.037633950536650036, 0.06870739988141483, 0.018404080690215194, 0.021156117492806048, 0.12119725466735902, 0.023904666680121617, 0.038625934807163094, 0.059291581743426865, 0.04781481471934146, 0.03492876384106856, 0.05017575597570789, 0.15635869856322968, 0.013605320296670883, 0.06800537989024194, 0.0655909618663211, 0.06152673519306606, 0.08838075228155622, 0.03081233019099361, 0.05228519056653304, 0.031574296562241456, 0.12294358273427333, 0.033597502211529406, 0.08730427617387426, 0.04453230033358259, 0.0728175918301267, 0.02091690270800985, 0.008085497838985777, 0.0568259890461641, 0.053972108514919404, 0.12325766346146985, 0.03929321654140949, 0.047613368069212285, 0.1377158569953134, 0.1417442997016253, 0.02983354178497628, 0.027918869727140957, 0.03801342835950275, 0.03436267083030074, 0.12120149879445954, 0.04632927447317108, 0.04297292836370968, 0.01252280550092579, 0.07902720177005376, 0.04756669033198588, 0.1348522050125945, 0.06698118928339213, 0.16273737644716618, 0.05207365836888071, 0.054415964536489024, 0.03598080174396596, 0.23133535599035604, 2.411918370954452, 61.36753274548439, 128.58542180830435, 76.21356656474453, 81.60597831972184, 99.68561803140949, 108.82284210574244, 97.19568175654258, 58.351273229045255, 43.565914553980676, 53.54216106476323, 53.20788491156794, 38.406075816000666, 12.84803826962748, 5.255927491572596, 5.085590722099428, 5.056365632241772, 3.0055793927561854, 1.7194719660666682, 6.189858048192917, 12.545426430240756, 20.09944069770075, 19.80850281253938, 18.447920853091826, 19.045966594449936, 16.24003731435345, 17.99829956023924, 19.335878779811246, 18.798168897628784, 29.107803144762595, 45.70437508244669, 28.408477883185114, 40.595158453910585, 27.054881665014452, 15.075187510059727, 18.174217862467614, 14.814927462608585, 7.495295405387879, 2.921436707819662, 4.595245911229042, 0.583850990139669, 0.8611121220934776, 0.3203547727917472, 0.281622807585424, 0.48172920221282595, 0.17036183587005063, 0.02661135490803469, 0.12106846762640823, 0.04562155095740192, 0.09804499741162985, 0.07766051623489588, 0.05088141488452112, 0.04211768695724107, 0.025558857352382718, 0.38980422841925777, 0.17355720392398297, 2.4799332503349554, 2.181107478757059, 0.29430284975997867, 0.08090558807335554, 0.09565300278125272, 0.018055612191317544, 0.04031594008988431, 0.02006209031077883, 0.09382874058980135, 0.011441757763555695, 0.02174902549614349, 0.06089877675197298, 0.10839691370605462, 0.056690651953460715, 0.08144826943715734, 0.06187637006082843, 0.3275294619942865, 0.20788793271828085, 0.727174028513893, 2.670619521410235, 6.474463266711082, 12.959456136149745, 13.993071279218121, 9.285813262385707, 2.6983327827145978, 9.380814048551745, 7.17436658759271, 2.5429434305237186, 4.361955590786473, 6.162090118854277, 8.204003957010086, 15.922481244610204, 12.934028390915165, 17.253264957858672, 15.178025191830052, 13.430472977699774, 7.194910001370215, 2.653121582923397, 4.148438918975092, 9.999848392701919, 10.18753674722487, 12.895597007966812, 18.46133339789606, 20.025119627675704, 18.833707532575055, 29.71581562872856, 42.35827953584733, 52.415071918118386, 83.5211383142779, 107.6248404287523, 82.23961368683847, 48.8087506448069, 65.69526026325842, 98.20720611080047, 41.94816043300014, 0.8413962058482632, 0.049149313070360696, 0.14305706796867235, 0.09176529042663113, 0.07088814576667163, 0.05034502310257766, 0.03972086214250134, 0.06043573788877937, 0.040063640523341396, 0.03970286290672037, 0.03165254095238784, 0.056184857723213015, 0.0557818265271283, 0.07068481837068835, 0.011096292329321225, 0.03058741060686448, 0.03738895561846514, 0.10860037133698502, 0.07506119522957072, 0.010983747309975086, 0.046624547741826505, 0.08901361751580432, 0.08767739163651582, 0.02718034373115628, 0.06213486727867877, 0.12282133042331665, 0.029924049327570586, 0.0581654554773723, 0.042765751375906894, 0.013309187094320454, 0.01777573728994016, 0.10433051900397386, 0.17098180018365386, 0.1385023535018967, 0.2074422840509684, 0.2502808788971555, 0.14133162345857392, 0.17987255698009846, 0.17242492597189643, 0.08396574160865239, 0.23869697064641984, 0.16805183563020923, 0.18552619393073744, 0.15688351475663725, 0.12488233676600842, 0.14198534160612092, 0.16799280089476418, 0.20371491389889873, 0.21004243243125179, 0.0989479239609453, 0.15502909168360696, 0.19565392225500078, 0.23152848675606713, 0.20177904035775893, 0.1963527629812879, 0.19053254787239338, 0.19839614930172123, 0.18730673548435012, 0.286814401587171, 0.3828125729435875, 0.6571732040855193, 0.2964504393598726, 0.253180644264625, 0.11558802783369057, 0.26530433806680864, 1.1327521911551877, 41.18099189573719, 155.7760214036511, 110.55082659567557, 97.97727677129932, 89.24439414854973, 121.50214687470468, 117.60673907495315, 98.55417897624355, 71.61891783437422, 48.593981266021736, 48.566971825015166, 49.04312010734312, 34.171182955465014, 11.543968839030113, 9.594197850073538, 8.008407613923474, 4.399759394507255, 3.0939587277750817, 8.059534728527069, 19.630899852321996, 43.335400781323834, 51.62265116168607, 54.43440614208099, 55.01871770428073, 51.44123761884628, 37.76015166313418, 29.708978937518214, 31.37240121441503, 35.981219507032826, 46.099651936561834, 20.477382636839344, 24.824168951280658, 13.821471506549468, 8.782166223372183, 21.9802995650999, 20.635375707380234, 6.732478247534845, 5.282449087788982, 3.673491862512404, 0.3548898632007261, 1.4708461588428867, 1.1371282079527456, 1.8426753292160651, 0.8398729779066578, 0.24074806381137143, 0.14457139396859756, 0.23976734869422453, 0.14392650115393824, 0.21225441938206074, 0.24894931083244665, 0.15826181418472723, 0.16841116151021374, 0.14311074008864744, 0.45723770835226585, 0.39700891762491197, 4.390349138167597, 3.9982672997059363, 0.5074896747546812, 0.38385301227531127, 0.10473368809588494, 0.10419521255478745, 0.16848056907615355, 0.14844260478933013, 0.1462369916900512, 0.12663251825518188, 0.10785173489561967, 0.24302769632589435, 0.41671784714825694, 0.39879040912755076, 0.16856617174081265, 0.18105567252684027, 0.5544056959690586, 0.5924620635567174, 0.7081149254114397, 2.0253251541045407, 10.615701694642345, 22.601673603057865, 18.629320667636012, 22.13658444343075, 15.816415452188062, 14.255710244178774, 7.341538004336819, 2.9366984050120077, 11.843175080514724, 14.750085780697486, 24.131188123456894, 40.01526740289504, 32.603562608841926, 35.3188370889233, 38.446640968322754, 24.013771972348614, 7.200179705696722, 3.9789118737943716, 3.7419154038352356, 10.256688133362802, 9.20391123141012, 15.253170940183825, 22.190454275377338, 16.908514115118212, 21.491440842228553, 51.97835914550289, 73.77486428906842, 90.78670932400613, 116.62036495824015, 103.79986270781487, 65.27515088358234, 70.5048313448506, 81.82174790290095, 117.2827591434602, 31.653792050576982, 0.6384733655760366, 0.08513878309918989, 0.23399677608282338, 0.11522111002235644, 0.25809462332437116, 0.14425241027868566, 0.11316576506942512, 0.12140799779444934, 0.14739395299505803, 0.17749996735684334, 0.10960450576197718, 0.11055964120333234, 0.10798219966912463, 0.13847538720696204, 0.15427936739738912, 0.14732793153774354, 0.1292110552951213, 0.2189237050591938, 0.20374471471915323, 0.13272718436294986, 0.11692472868749212, 0.18888634749718253, 0.22256711197476234, 0.18978260908155672, 0.10993498077075328, 0.2668116926666229, 0.1404741106014098, 0.21004863774343846, 0.1374628794409575, 0.1353535023067267, 0.18976258354321604], [0.03223621376579808, 0.10295810313114237, 0.052060661687245297, 0.0139586869702344, 0.046335016302163565, 0.05431553040961585, 0.04508363083004952, 0.04623888375898523, 0.04269640126656141, 0.07607473721427303, 0.07735233438471634, 0.030295000591826056, 0.05095137786420603, 0.07337493611679924, 0.03583130734642187, 0.043966609518975026, 0.17639316948911837, 0.04056289236271574, 0.08813398003938698, 0.0631018081349471, 0.03986454193270014, 0.0265727881267066, 0.0887855148363498, 0.07616014835695106, 0.09060937866208055, 0.029514550434185133, 0.05620375711230501, 0.04554871514800095, 0.03643812559124443, 0.07445574062125337, 0.1571812624892881, 0.008627281922306265, 0.15109106267411865, 0.04527529453738563, 0.20521598657773388, 0.10658748297681732, 23.394882755894816, 106.11282164050688, 93.8105978504304, 79.1039768342049, 68.13472347874796, 92.02307962602185, 96.81781630362235, 77.5452975303896, 57.45204633282077, 41.512683206988925, 24.79848723257742, 20.186927203209173, 19.12408059643161, 7.917544437992958, 5.103798364439319, 2.2728507364949873, 1.5475257990821716, 2.5713997358276, 1.4985928828677824, 1.7954541598596883, 7.743356881603119, 21.003643120488814, 30.695470725336385, 44.794365590618504, 46.06534296466459, 32.634951376145885, 22.00544588027462, 13.20366584485577, 13.927736359257853, 17.216218171581147, 5.676144246132144, 2.891820606685454, 2.2487014387884448, 2.0811225858426865, 7.5308982691457205, 8.784753026500825, 3.520504471755797, 0.4896039425605728, 0.1783376385367686, 0.07307236203022542, 0.0788070357614948, 0.028665502848584327, 0.022629132201414437, 0.024333459497880072, 0.024062963427915692, 0.028924109233963876, 0.09711636095157555, 0.0996538433396528, 0.05159393411069628, 0.028332541884493925, 0.12718225528876628, 0.16966109524571127, 0.05444977582702714, 0.16613886811800543, 2.412497901147412, 2.3366824080867152, 0.2304872353711436, 0.03363067764909037, 0.03888766874649352, 0.0141747429170796, 0.060010145403324604, 0.1534100567861911, 0.01643363743149225, 0.0679253007195169, 0.14572588847048823, 0.03555544291532809, 0.03839428514061916, 0.02138058891549947, 0.06320441029064598, 0.05065853309427058, 0.48987412644970807, 0.11614164893305111, 0.7393392596033312, 0.23801769580571885, 4.8502980316838915, 5.655433151029772, 12.20952739638667, 7.6780028400882605, 4.406138148999983, 4.3858722429121695, 4.747304925995489, 6.252213437711039, 5.893543083821574, 12.453655715911621, 20.587493373501687, 16.803451468867642, 13.374593911632417, 6.253153825959852, 1.7110112910309148, 0.6482282389075525, 1.9054078791410693, 1.144245348630413, 2.0375894250408297, 2.9294704573769725, 1.8589867507257771, 5.753866501392857, 9.728461561664458, 18.634625673294067, 41.816459009724284, 56.60585380369618, 78.05896328341576, 103.91179146305208, 67.90918719383978, 29.647738972017844, 54.79011412589781, 79.53641814570274, 80.23667889256632, 12.038863109004113, 0.17073911885100027, 0.16448471575014054, 0.05924839736713518, 0.178516075736092, 0.008094077066127813, 0.0640498610934423, 0.09155112288651929, 0.06156156155010385, 0.063721037004143, 0.05193162566771911, 0.04594829128754716, 0.06182597296672964, 0.08049494196330348, 0.059936359644897526, 0.11599006311547373, 0.05247291275149873, 0.02709219573936876, 0.05119033217910798, 0.055505042790525386, 0.09937920081879824, 0.027700902390924674, 0.09111609219783738, 0.031006589021173217, 0.033512412825779575, 0.026974153081556002, 0.030801604960053682, 0.03564520543741603, 0.029775614046581814, 0.020763053100616224, 0.023975411069489295, 0.0024010562535089954, 0.05736737189093425, 0.026682516815321102, 0.15068921891431655, 0.06205794822064139, 0.08804342844673703, 0.04127197951499013, 0.030987249131524758, 0.03991914101906362, 0.07088633013829108, 0.018208981078538685, 0.013080129677790308, 0.003640088318441544, 0.055599742749285315, 0.02981711877509952, 0.03646730204984065, 0.09945676722113164, 0.0231749564409256, 0.06564124787767088, 0.07423922119121398, 0.029032736671187227, 0.04090499275574281, 0.017381650170371417, 0.011171752947472758, 0.08177588693797588, 0.03661715267826954, 0.02380768569456714, 0.05364654029929831, 0.016928957324595224, 0.05277471691970864, 0.09189270617019746, 0.06777657240989708, 0.14161680734926654, 0.007976136393769975, 0.09604683326136682, 0.06982121511452621, 0.48734514763759035, 1.153384838854113, 72.81495048153785, 123.72383225348689, 86.2186856423655, 86.88118180921002, 97.38753272641091, 109.1501089834398, 94.39329731848933, 62.365705351675714, 47.51918515851421, 49.88104428014448, 44.47242921398532, 43.0901663534103, 31.25177852569088, 18.179960212399884, 11.156094478022668, 6.076447127326843, 5.987670162031728, 10.597828434359643, 5.324194873532941, 2.851964422772008, 10.497908995997522, 18.789753452424083, 23.104242970866544, 29.12240416772904, 26.582628296267604, 23.521461563725627, 19.107255589577463, 18.95222783088684, 20.572109837685865, 23.005161939128755, 14.190646948352938, 7.174485239290423, 4.957423844645101, 7.373898048554698, 21.13289502359206, 10.264776060658118, 6.014014270997817, 1.1081258351764371, 0.1092428969399583, 0.12072576585436061, 0.056810816674823725, 0.11805480796723597, 0.11467679689127593, 0.18862315032991672, 0.07664443083828495, 0.06267876289184056, 0.11847959606037026, 0.07862351939923341, 0.024688596792158582, 0.10390034531273189, 0.10594148699554706, 0.07065620498671647, 0.07490119776658474, 0.15356253892663987, 2.3238270849950853, 0.7066122286262051, 0.11337519052528566, 0.03721066780628697, 0.050376283320327925, 0.1368884820370905, 0.01007154918155603, 0.09748810511683265, 0.025769970116896496, 0.04490743060746501, 0.08272023586135718, 0.06978410581547408, 0.07008504047388993, 0.02847887233891074, 0.07666226536516221, 0.11916452462995246, 0.45855776977635204, 0.18793379377213218, 0.5235754374054171, 0.8691893241578533, 7.657787434516415, 11.444716203597284, 12.80993244340343, 15.554657059331095, 6.716252873020788, 1.8390907731748398, 2.0365014576142837, 4.151968561833905, 3.7236393651654645, 3.7518865591095345, 10.652103251026524, 12.084917618382363, 7.370403707027436, 7.609155437638683, 8.275715670277997, 3.5333242483677405, 5.0884212024750255, 8.186201299390486, 12.450325623635324, 17.251323384623376, 18.495367803881248, 22.071488788050992, 25.200314444880334, 28.356479021810717, 43.680902757952296, 58.949815150230165, 68.85393711828416, 94.53869173603674, 96.49133389995944, 62.617474448296335, 52.593563295179806, 77.91110561740014, 92.41794463126891, 40.61552732221542, 0.7275364187455947, 0.12886915025451492, 0.029998781204584147, 0.07099283168152457, 0.06588450377626766, 0.04309009385084914, 0.03793758182455936, 0.03249006849082728, 0.09762574813418812, 0.02800068983267392, 0.05811619985428068, 0.12025301299628713, 0.007925905923794715, 0.05790081806480885, 0.035082674735496124, 0.029171950168787476, 0.02975894588856928, 0.03158898629818953, 0.08901437594284935, 0.0974737945944071, 0.019664161260269826, 0.10851675284004982, 0.01336626064467935, 0.04905725611493953, 0.04178389478775282, 0.04219181362479445, 0.034077157521800655, 0.039373946886870174, 0.029135875088433107, 0.013684205327843948, 0.026822421707273014, 0.06744811221236183, 0.1459858067814381, 0.34804762551380747, 0.17751562619401565, 0.1004394282016062, 0.1408075886748491, 0.16570039003366427, 0.11162204427584527, 0.1556677638643211, 0.13670668937265873, 0.1285386752457388, 0.1496013587400798, 0.13499929389405635, 0.1555967475137403, 0.18681427884486415, 0.18352667380484844, 0.15163791155622852, 0.2889968328658612, 0.4084436072697563, 0.19880615955879613, 0.13164882367897418, 0.18904647519511564, 0.1499811544894211, 0.2338402183546174, 0.1594291023549534, 0.15889857114563066, 0.09724091152630507, 0.11366589790991238, 0.19497127662743294, 0.2857479152660216, 0.3051097456726336, 0.33324965666378703, 0.16724644739541317, 0.24594886618996822, 0.11542292056424965, 0.3361720675902982, 0.21668827581790187, 51.99312294683149, 156.8232628606981, 113.19670061911307, 108.5284290006084, 95.07245571382585, 116.04358042440107, 118.15380773236676, 95.14210916334584, 83.79837928279754, 62.39956717337332, 38.91361482681767, 36.50874691624796, 45.345878293437345, 30.151385030438824, 18.20098803889367, 10.670657042534122, 10.147532493837419, 12.719624773148569, 6.890163412017207, 7.211306489283039, 17.53963524295438, 31.0887687436996, 46.121758414853005, 68.20528691814792, 65.65411460015082, 50.084395639358036, 33.25250110318584, 25.617768379949755, 21.249281552530107, 20.77154471028236, 6.990302503108979, 2.3224407722873073, 1.6106410252471126, 2.1658376916762325, 17.223947202005697, 10.442007376301675, 5.518060470781019, 0.45233204900737733, 0.22680987543877096, 0.16157705967705097, 0.2718371681628689, 0.4420331919625883, 0.10199870058004895, 0.16393005277120298, 0.16097044061508872, 0.20689198777319925, 0.16891080405442946, 0.2185971677423485, 0.10988153847715548, 0.15067604220201894, 0.2163460490203673, 0.25967840285551164, 0.32592959461673615, 0.4284277155755028, 5.353023313706921, 3.601937779495793, 0.3220438434472007, 0.1449926197528839, 0.23920995844227655, 0.2631428056666928, 0.13818266501109447, 0.3840032267955042, 0.16475738176415045, 0.155536410428824, 0.35725943443755953, 0.14003967746130883, 0.20814849454308712, 0.10280497747683719, 0.25483108876693633, 0.1687855486788096, 0.630613242185885, 0.8346162664313471, 2.0777667530121344, 0.7013574783359805, 8.663757712610307, 8.288415324303413, 18.538192241422593, 23.901735351931666, 12.935259034556728, 3.141355913492941, 5.1779610687686555, 20.666676221355317, 32.847300652534734, 33.1459891411566, 42.59635563819639, 40.482574662854596, 29.153530136231456, 19.201355211196407, 14.50459247635257, 4.4467229131729376, 5.460744836638051, 7.805069983005525, 12.451069893375522, 15.075278705166234, 17.412632819144957, 20.114734019002608, 21.284014140405965, 43.66543685236285, 74.51672569397958, 81.23481227505593, 97.83745996413693, 114.64760103533345, 85.58883144009499, 52.3434494387719, 74.54910093738188, 95.17864211913079, 107.98096810617756, 28.96018082095731, 0.5456995663623656, 0.26138782080623413, 0.26523673846837015, 0.1837025063052293, 0.2251249110145915, 0.17960577452134702, 0.19463372296623646, 0.1784755190413806, 0.17097029354303114, 0.1592801288971978, 0.15723709497720967, 0.2558149448445728, 0.19534341149753143, 0.0999961467459798, 0.234694023346228, 0.17455765346605934, 0.16956424641032375, 0.14876128204407232, 0.16278767778027445, 0.16877929740134748, 0.10329266138855489, 0.2528252254330343, 0.19931718616956667, 0.1644744348501967, 0.12666287065874185, 0.1273226792052869, 0.09729260713943551, 0.15034429548728853, 0.09271134006520433, 0.14700603671371937, 0.18005174494558768, 0.10573022292866822], [0.01191553334900809, 0.08512757523285766, 0.07300095497480324, 0.029943703313268004, 0.030366528306096315, 0.15462612943543544, 0.03397752012636873, 0.05044240819951219, 0.07890215323817346, 0.0024395011789766293, 0.0313588764683734, 0.0022083918438217933, 0.022687335731461648, 0.015345671920165902, 0.056986005661348184, 0.07335204540962174, 0.01723598238200911, 0.05677654573153104, 0.04654584752936517, 0.01890741003256652, 0.06699886293180528, 0.04473361291832501, 0.06634857685815904, 0.013202834938232218, 0.024057595066786296, 0.06912881718768228, 0.030059273422305143, 0.03929649922816504, 0.06327475248385342, 0.03965099109336734, 0.07376928753670185, 0.10302155053303128, 0.06263955834231551, 0.04739757259226134, 0.30120658898545855, 0.13053456411486672, 0.19276069927840464, 21.1938133547383, 107.65121444579094, 87.31176391724618, 79.65020610440163, 60.15297082162673, 78.74435040258592, 110.65218848566856, 78.61237833576818, 88.6369445247035, 76.91235250042331, 35.49204111099243, 18.157975327584055, 20.608627103990127, 19.21488150473564, 7.784344669311278, 0.8816061998086592, 2.500905428201922, 1.365261469637194, 1.0327677885370872, 3.9031863500995025, 5.462074029830195, 3.729544983756158, 6.308455323019336, 7.830112355370676, 12.07860750536765, 24.528096683563728, 23.847543885630948, 24.334219809501406, 39.27437090104626, 9.962948695305856, 7.13242958630285, 8.81351282519679, 7.186883851405113, 9.132134799034365, 10.051707029342651, 7.442018831929854, 1.5743074974706097, 0.3166702882416787, 0.025799920324296243, 0.18539405908555756, 0.04778735429769562, 0.006703593009602159, 0.03769022352512806, 0.04168457148836986, 0.08655229192827979, 0.04050681089621879, 0.028555733940353798, 0.04354464829028134, 0.07167601357063941, 0.009699475598491488, 0.05605260796484448, 0.244714055030096, 0.07939037341143816, 0.7605694558831954, 1.3611415100674475, 0.1833742376296751, 0.03685355592038363, 0.31588523198039303, 0.13343975338484013, 0.06930228247637711, 0.01876663371560074, 0.024716988010632417, 0.052101406073498155, 0.0707998005072436, 0.0601765358700387, 0.12016131227175075, 0.012552897434591526, 0.10569823875782952, 0.16046538949012756, 0.19090030071956499, 0.6129281330973871, 1.8320578408818093, 0.2004695969123033, 1.791677775402223, 5.836405427225175, 19.504138654278172, 11.501243441335617, 3.474258746831648, 7.607951269995782, 3.8636351304669536, 4.662696949897274, 8.844431888672615, 9.98633876923592, 9.4444505822274, 3.077259481914582, 2.355687027015994, 2.6357783329102302, 3.0102832951853356, 3.0648687145402356, 12.564265574178389, 18.725087296578195, 18.772508751961496, 13.990238347361165, 17.07267903512524, 25.552562898205174, 41.69297102958926, 61.171755483073575, 80.35468732157062, 108.04142752001363, 88.77706727673932, 47.58786193786129, 39.90054592009514, 71.17231676655432, 82.90970356233659, 80.59696428237423, 14.057782542320991, 0.05382986897001824, 0.05846470857279436, 0.1305431136561017, 0.04202318235090183, 0.026108962108170795, 0.07214733384429448, 0.07349432325891911, 0.11347017010613797, 0.09108033121353196, 0.0403122513765289, 0.0672357373179928, 0.06935554090887308, 0.054345093742613836, 0.03257385552710584, 0.10975346389797427, 0.05271367503390197, 0.03390725837239335, 0.03497968570539548, 0.012831487223475933, 0.06656760139571083, 0.03551031267570873, 0.057017039883160786, 0.06409609449967262, 0.07008287244506421, 0.08330509036539063, 0.06045176444815532, 0.028932825399322376, 0.07614527859034077, 0.03956983556910869, 0.08012091485603202, 0.014400478384848085, 0.020352910693374374, 0.04483364101859831, 0.060922054333552245, 0.13178912502142692, 0.009034665455410798, 0.06117074945641141, 0.0656636406276976, 0.015991778026575285, 0.013332137173312086, 0.1007879599027576, 0.018506244260577426, 0.03185754225048567, 0.06042425806123403, 0.034605444093505223, 0.049036410862519864, 0.0850968704288525, 0.06311331860600941, 0.052155924720629576, 0.02485296287153277, 0.11325912820475717, 0.08009194141073574, 0.05228253990231503, 0.06343842333843631, 0.037423873906053846, 0.09771312812283155, 0.025798709905375878, 0.06036046975021882, 0.08407823395945373, 0.003733517768259551, 0.04994630881194627, 0.04087777365179312, 0.04452447474543606, 0.15244245709430787, 0.15608295287576415, 0.06914199389997991, 0.027729582807589925, 0.17610323585329518, 0.12022629951036747, 2.859581175350374, 72.26759941347184, 120.60870155211418, 93.9822329244306, 84.20570958045222, 89.29314920979162, 100.6423076506584, 101.77739451008459, 70.57577917652746, 62.92854193718203, 59.14021484313473, 49.591400777139974, 44.67645914323869, 42.04551758304719, 34.447427641960886, 21.06121566987807, 20.292825314306445, 16.920038038684478, 10.541329633805061, 11.85625030148414, 12.47023851640763, 12.911652249674644, 12.432576898605594, 14.96848629366967, 15.188736204178104, 19.533201456069946, 32.98191247447845, 35.02916612932759, 30.318854547316032, 44.066922818460775, 24.40740731454665, 12.115430716545353, 9.304770077428511, 8.131451385636485, 15.817603930350273, 13.209766111066266, 6.281098752252518, 0.8696472608754713, 0.6283146106908399, 0.19836276318998108, 0.1683047518975312, 0.08087418612933929, 0.03339499836006472, 0.07640072294781286, 0.08103131842348846, 0.011408104478651959, 0.09614353654004874, 0.06201810398769956, 0.03650932963336668, 0.043031733272777456, 0.09236220315459276, 0.03880706863597997, 0.06615096447809089, 0.09311060976958083, 0.6273997791351811, 0.9166286753550653, 0.12169696615948794, 0.06635216981052391, 0.04568575295589624, 0.048583966995319056, 0.043999313812462554, 0.05275198326055562, 0.05545170391879736, 0.043597378122109565, 0.09682311781591947, 0.002748756031055124, 0.05066674555681887, 0.03316027285050481, 0.12758910160271392, 0.09970994395834785, 0.2618046645675936, 0.4732286599614928, 1.2537297318058631, 0.06552960588446548, 3.708375216491761, 5.652036378460546, 16.28532303917793, 11.72610507857415, 2.572976528636871, 2.812420557583532, 2.6112691577403777, 6.122793853282929, 10.30243375608998, 12.848179474953684, 11.208496362932268, 8.840399692135474, 7.884247927896439, 7.479826558020807, 8.412314172713987, 10.280156654696311, 19.071501224271714, 33.26229526150611, 36.08448766892956, 29.290630702049505, 31.63741223273739, 43.37615812978437, 43.86518747575822, 53.997603154951534, 69.40582244626938, 88.00778065958332, 101.9116101726409, 88.05032268647226, 59.99159274562713, 50.78093013455791, 80.69827910392516, 95.22753838569888, 36.404156915603146, 0.7987658030563786, 0.07910090708924879, 0.07289173381943857, 0.05699880316012329, 0.018146774739087112, 0.07898792444217591, 0.0451154119875883, 0.1419838707173063, 0.040312894890385295, 0.043879528304622065, 0.11482522642660527, 0.02004075476208762, 0.06457825491745627, 0.09189304324888414, 0.05977309481691449, 0.11935613088069424, 0.015645952531016402, 0.05395127475381859, 0.03814685023239544, 0.0620589173218656, 0.03668055794532261, 0.029406541612960642, 0.10636108101255472, 0.0855401672062374, 0.05768154454868167, 0.004307755011869896, 0.05365807375299835, 0.03749795843877139, 0.05413222089109402, 0.009729625946361451, 0.02809928534852882, 0.01518703905129505, 0.07712441556636365, 0.15673425018547044, 0.30446546572831373, 0.16972563049245268, 0.1650345676969136, 0.16010194205709044, 0.21816503286602038, 0.16811205014105768, 0.19769775290643016, 0.1804269135238663, 0.1303583792140407, 0.15182425478293052, 0.12756185185524727, 0.2492393823640962, 0.14122800240593572, 0.1609378972000653, 0.20078280429926612, 0.12765505411211522, 0.20671784066625182, 0.2099198736851254, 0.25543297340552656, 0.12108145281672479, 0.1530643519494803, 0.29268386082783826, 0.20262129274347138, 0.1568684381462874, 0.1403316642127691, 0.09220431243339855, 0.2123742508551767, 0.21468170768310949, 0.1851152643681534, 0.2004799237775226, 0.1884427059802317, 0.18438613252534022, 0.09650064076507285, 0.41218043094681156, 0.16103931191948154, 0.4936729726051131, 50.36571979522706, 151.7419421288275, 103.98146060205276, 105.3240800672962, 87.44310840483635, 96.7942742378481, 138.06719472331386, 105.11435093418245, 107.75162712220224, 100.65241952096262, 53.8583041006519, 33.96740013553251, 43.570637087668146, 45.657334096970104, 31.84501151884756, 23.385172928533247, 20.243750579895515, 13.661686893432373, 14.559412502473402, 13.420795509892127, 16.090773478631053, 16.90848469734192, 21.09030200589088, 21.696894591854466, 30.963923623484952, 46.57178763420352, 55.70454412891019, 37.52251094387424, 56.99653756233954, 24.08830288917788, 18.588006342611006, 19.712255693251088, 12.185304799387533, 22.609890968568866, 17.505853829845307, 9.806390231655492, 2.4426199880338486, 1.2742471598809766, 0.7598950533616928, 0.6390656434720563, 0.14655047486866676, 0.09314496115210558, 0.1625280199392188, 0.14329478505157656, 0.23613091317876694, 0.16058948041210253, 0.17503373114572418, 0.17347993629594005, 0.2194269022513782, 0.1824623172081286, 0.14660348815302696, 0.3270740380450603, 0.33283756264755804, 6.347446624309787, 3.068335844624427, 0.538051373535587, 0.18606141359815676, 0.22367458399986068, 0.14277361543668857, 0.23467632671517713, 0.14896320749915418, 0.13939084695471873, 0.13929542304287035, 0.2492270330267568, 0.1519938666493662, 0.1943137280402645, 0.12149548503540217, 0.19414813047455204, 0.20137609343134588, 0.7998709308524287, 1.50325461981758, 2.8359940023191514, 0.22362947674287906, 3.5198393848634537, 8.518478024390436, 26.198522352403213, 26.781700349623158, 13.993180124990403, 12.864539680942414, 29.654905142322665, 29.444619032644457, 31.665153195781095, 21.124508996163648, 13.972053258649765, 8.788446918610605, 6.066773581889368, 7.587768223977859, 9.176825304185192, 16.541982350810883, 28.677209269615915, 39.12061791266165, 39.12046494022493, 27.869134333825883, 29.87672498149257, 50.45514199041551, 69.65253953010806, 87.53893190814604, 93.13691508385443, 118.4140334590789, 102.33273152382144, 72.16554718632852, 60.49065943687194, 82.2095997102799, 97.66933148907077, 109.02274962394469, 21.971070228084443, 0.36497406240913177, 0.12907767938750406, 0.3072850676553865, 0.07978174474931533, 0.06882792849454188, 0.20922172243797013, 0.15567697224117097, 0.3898066186135815, 0.214491625947337, 0.13583861982389805, 0.1520098472434667, 0.1569965280472271, 0.15618193143558118, 0.1891623689763008, 0.1740542724127731, 0.23858542824464463, 0.25722744243760265, 0.13393812422310153, 0.11384097198324819, 0.2060805474438014, 0.17999434963830058, 0.14856288059344216, 0.28090795562151943, 0.23391685779056243, 0.1796722556314161, 0.15153504126975614, 0.16950665192017633, 0.15059187978265748, 0.14616157799478502, 0.12089944564767423, 0.09311732836067678, 0.0816788848850035, 0.2101938267268481], [0.010486110000901166, 0.04610946852593653, 0.07693722198206572, 0.06596181736958605, 0.04223453834833157, 0.06524332648804111, 0.029175694423517393, 0.016804360784590244, 0.0419717931729411, 0.015363276620665866, 0.012686235037812544, 0.05078780277061367, 0.04280916557857587, 0.08723545083475691, 0.04312117786837682, 0.0426662442154221, 0.04086730889074745, 0.03079572906567445, 0.06153579035233106, 0.06863843664647111, 0.02787061767923015, 0.015251885521255676, 0.06455535654939952, 0.11144297888442395, 0.10271562864222836, 0.04997885988784894, 0.0526985026625616, 0.11468792814881572, 0.03983920357460457, 0.1758940019194157, 0.05855282017540547, 0.05418812998780801, 0.03522384941818253, 0.09207433795616513, 0.1467553727448948, 0.1625748738766678, 0.16592428689041447, 0.22402057994998273, 9.841984760376716, 108.01663814052459, 100.44598517879363, 87.72782541090443, 65.7142053111907, 54.743834080234656, 104.72510276302215, 98.81854672585764, 82.6583423922139, 75.79516733846357, 34.39798224356867, 24.79300375907652, 38.096224261868386, 43.709006540236935, 25.359111601306548, 16.00623071193695, 15.038910488928519, 13.468571939776021, 11.631422004392071, 10.108372530629559, 3.500677135682875, 8.83536042705659, 7.127678615431632, 1.6893433827546336, 11.06295975946611, 13.562040059797226, 9.867912607808268, 19.409256519809848, 15.848531819158985, 13.878838131504676, 14.858547160702368, 7.795238562168614, 3.959386560224718, 4.366407971228323, 4.11451384905846, 1.1005016055799302, 0.2268951103812264, 0.9321298822760583, 0.14122038749196839, 0.21864428214969175, 0.1354288547149589, 0.1635751855229178, 0.11282744532030438, 0.039110052579593275, 0.051053489723633376, 0.033953959092257485, 0.032483591217427485, 0.06189858278019294, 0.02361249415233972, 0.11934402669149062, 0.010328974833922281, 0.09741492073742614, 1.192446007363258, 0.2170409980199991, 0.0403535588374061, 0.0770165580475042, 0.012955176906900541, 0.07653902480078321, 0.017131279230177883, 0.043836485654596365, 0.047897893124290054, 0.03292183181451213, 0.047989896453556516, 0.09788081710857731, 0.09782019657112899, 0.08643711826974347, 0.16736799490547952, 0.08214910965292685, 0.15143551112663362, 0.3657919991641276, 0.10797198771709397, 0.28991635287961653, 0.7365730080393054, 4.629954964883866, 6.555680844091601, 10.819969907883676, 8.405824611263892, 7.448943776469077, 4.402558986217746, 7.487486946967341, 8.643386883120384, 9.152189877725418, 11.551485080872814, 10.976609760715116, 10.342366426221787, 11.885285646684709, 23.623882493665143, 35.20672005991782, 40.048725220464895, 33.52283085546186, 31.84205993529289, 46.60742236721901, 60.72584867477418, 74.78689070670836, 84.60404980567195, 91.53452488683885, 88.99013826923986, 52.56443969665035, 45.227136381210826, 55.45923517596338, 74.8694016856532, 82.96526001345727, 54.80692148208619, 7.08243211430888, 0.08776677877552087, 0.06050568937714543, 0.07307204027329722, 0.08569757529203931, 0.037194104985364025, 0.11043311412175817, 0.059303245432074034, 0.08560053493467071, 0.043494684035859765, 0.14711134315979096, 0.021800556400370215, 0.05935697883908307, 0.04965255622782054, 0.06716490482851382, 0.03650343075634972, 0.03437810367153537, 0.039132970099848126, 0.11437786172234243, 0.12157392477796924, 0.036324671800098116, 0.038746440437652414, 0.0651892560023454, 0.08892371709789, 0.02668784495683447, 0.06636579085381762, 0.04074119932709202, 0.01476687046834418, 0.011894039794682496, 0.0765150232661155, 0.02836762488098635, 0.023593638813303366, 0.031628537502500324, 0.03662016723425158, 0.06021508158394887, 0.023819441313765222, 0.08848773646018199, 0.10243553923623216, 0.005916783364579803, 0.02880355572297929, 0.02271944247636824, 0.04321707675473825, 0.017401723589207378, 0.07772785536344014, 0.06588108702412536, 0.03882135234532818, 0.07531630250835612, 0.06282592455165521, 0.052191218391301177, 0.02132667164738861, 0.04760115662769926, 0.0626527120719754, 0.02312791289671535, 0.05203120177611709, 0.037076303645247416, 0.042382538874423316, 0.07346847545235388, 0.10013466310356894, 0.14484330921644165, 0.07024622537315854, 0.047568651517072034, 0.025525530612456705, 0.051886261771282846, 0.07705084048211575, 0.09079730769078578, 0.03175949831793626, 0.09837040091834723, 0.07588551349697575, 0.06021505477087152, 0.16028997067722583, 0.12021247928421344, 0.17503779141172288, 2.6279688938971493, 54.448456072038226, 113.17543352803877, 100.50183973004742, 79.6830520322246, 88.60176086425783, 99.24881504428004, 105.40872481561478, 98.41093401755057, 75.00667679694392, 51.908144797048266, 42.38425739349858, 50.54129292888027, 69.38901901245117, 60.83859328300723, 37.40244719289964, 34.163087183429354, 37.759806494559015, 32.86770089980095, 30.24522185325623, 30.747159719467167, 28.668203507700277, 31.151403111796228, 25.635868157109908, 18.921229339415028, 30.408988652690766, 36.053955939508256, 30.094161571994906, 37.483130347344186, 22.443951176058864, 16.427922767977563, 11.56176463250191, 10.026403819361041, 10.032184412402492, 8.741770713560044, 5.170403642039146, 1.5521874134579015, 0.9767888246044036, 0.36634269380761736, 0.22198722938135748, 0.4272911168875233, 0.1751450743646391, 0.09121218260617987, 0.026481771135642648, 0.06820257092195173, 0.019654276810826796, 0.04769447379775586, 0.010708164416193482, 0.0983299667977037, 0.012938692609989836, 0.044996557276575797, 0.0123564878125645, 0.2596058390073238, 0.775476914019354, 1.0645787009308416, 0.17869553949323394, 0.08551127036973354, 0.03677380233702641, 0.04262777894074398, 0.033236291755231163, 0.05110844887132126, 0.07957062623914211, 0.06701827559980654, 0.0578927549894058, 0.11126164587274676, 0.09355874056176794, 0.11478674583016865, 0.2091336989354703, 0.10358980391174556, 0.010346145737135123, 0.7888751176576462, 0.950985267277687, 0.6285764901868759, 1.4153427822935967, 6.858728066567452, 12.433116224504287, 11.928192453999674, 5.514927477605882, 7.5793978860301365, 6.06882203971186, 8.132623193725463, 12.088707608561363, 12.919245958328249, 13.582705067050073, 13.70755312904235, 13.771090622871155, 18.28676635219205, 28.75767081014572, 44.38282266739876, 50.06735686332949, 45.61539219271752, 46.57827523446853, 51.242620560430716, 57.154789509311804, 57.50322934119933, 68.52299105736518, 77.83938900116952, 90.65963237516343, 86.42919140477335, 67.25284130342546, 50.07033786466045, 61.816616673623365, 88.2829035482099, 81.67820484407487, 24.051195306162683, 0.635323518466565, 0.07214781647968678, 0.012653868780621599, 0.09977310790770477, 0.03684280387636635, 0.07899145610750684, 0.12319527326091645, 0.1807327051797221, 0.08951061705668127, 0.1569312573560784, 0.04403895503210445, 0.02760725963350025, 0.05089010232158246, 0.04083689136971389, 0.028228062813380556, 0.06371061437793317, 0.07255211172084655, 0.06365532198199822, 0.03237333201292542, 0.05473784020831508, 0.033553364055771986, 0.046996364685436415, 0.020082581247533524, 0.019278681138530374, 0.032811047839781934, 0.05308103334579257, 0.04313784411116954, 0.03159730984348684, 0.04710333737274332, 0.0389420188542816, 0.021443783508373365, 0.09706995900600188, 0.09545212686662713, 0.05313967354595662, 0.13263418128894222, 0.23471216430827496, 0.29564555674310655, 0.1537974980930167, 0.1260458711054056, 0.13095459480199123, 0.14520094970301275, 0.14935221162534532, 0.13323142343471128, 0.14442107219609523, 0.20171877988163503, 0.20286504659921895, 0.16766010423100766, 0.20015277359033787, 0.17358510484618528, 0.17936467132981748, 0.18745086726642426, 0.15051873370764718, 0.1328909279958856, 0.1321604171948087, 0.18309433974566, 0.13090057028157095, 0.19835726267868475, 0.3009474367624329, 0.19217222117848937, 0.16387653386881276, 0.09489157267155186, 0.24483632266281113, 0.29948105254480917, 0.4144799817473658, 0.2484096478550665, 0.22919133636018924, 0.1620686123327863, 0.1709929391020729, 0.2094836632210401, 0.2733589865026936, 0.2498063333933392, 0.5147483884807557, 28.72232633252298, 140.95030938425373, 119.22639554546727, 109.53908258868803, 92.75588820057531, 78.201917986716, 126.87637452156314, 130.3523083656065, 107.78715595122307, 105.19866620340656, 62.49065637588502, 48.185203613773474, 62.911883631060206, 68.614515642966, 47.156346305724114, 41.8342234242347, 47.26687477480981, 35.68266437899682, 31.286344412834417, 35.31803692540815, 32.18188624228201, 34.74896769369803, 32.33844372533983, 24.847932630969634, 37.81206815473495, 38.53241535925096, 23.04112222886855, 32.275497528814505, 24.54654359048413, 26.976657836667954, 23.163256991294123, 14.886198889824653, 10.882764112564827, 8.347423461175735, 6.627780381710299, 2.0705380699326916, 1.5518738689922518, 1.6357413751463739, 0.746649822160121, 0.892753882273551, 0.40300527166935707, 0.29267457584219597, 0.2059821357890483, 0.12449526318138647, 0.12478393277213459, 0.10352327683640104, 0.11554041546919655, 0.22329705587077528, 0.13267090754403224, 0.26638994594254806, 0.08400679626051458, 0.41941656040087827, 3.685525203904798, 1.7733311340693505, 0.27609487034140096, 0.1454494226603739, 0.24354246144573538, 0.2532472019834865, 0.08975460839968535, 0.24139136316314821, 0.16026968466899089, 0.1377491818200196, 0.173815360232707, 0.35583300936606627, 0.3685767287688871, 0.32549552919883884, 0.3558946334786954, 0.34208865656006726, 0.25025146112086316, 0.6863458935291537, 0.9007822385718747, 1.6915057118861907, 0.963350784394049, 7.457089068428163, 9.012200486275459, 13.827050097527044, 19.238578504131688, 14.676406018195616, 6.5969873243762605, 10.452006478463451, 14.065251715721624, 15.306950557616451, 21.747389224267778, 21.175633168989613, 22.05527763212881, 29.506188477239302, 47.11750699627785, 58.35524266765964, 59.05679387430991, 45.6556906238679, 44.60678608186784, 62.07914090925648, 85.80591109491165, 93.61036085313367, 97.14245519330426, 102.5876542060606, 102.16176325275053, 71.73549067589545, 66.35037452943864, 67.67108363489952, 89.27942091418852, 101.0906659403155, 82.45411242208174, 10.697069302681955, 0.483392195235337, 0.13486643892622766, 0.09506759669391379, 0.28141155117942446, 0.12314070481806995, 0.18691108171497622, 0.2372427365832752, 0.3527231214027251, 0.19334766052422986, 0.277096760128775, 0.10415220437871833, 0.10038685158736284, 0.1588770440749584, 0.1447647085954105, 0.17999183686990894, 0.13890272637288417, 0.12938742405704914, 0.23187206186834844, 0.2399005713842569, 0.20983762648557464, 0.13370143369801585, 0.26444049732339, 0.1253994767584147, 0.14700939217882772, 0.1485658070493129, 0.1531382334688979, 0.1182470117665587, 0.15153035281165955, 0.15699072110076107, 0.07737239822745323, 0.0867538343393995, 0.2164274075579259, 0.1881107447608825, 0.16168576755350636], [0.0444126412302496, 0.05602832680808441, 0.0784590403218904, 0.11814822472872273, 0.06024624221026898, 0.04442777529719376, 0.05267740077068729, 0.09935056445218864, 0.04223091858288935, 0.0557933523199491, 0.17036540583977777, 0.056529478545510964, 0.10344158122015577, 0.017830539389603564, 0.09997772999228009, 0.07497126416813943, 0.02068411348567855, 0.11826391166616833, 0.16062136499151108, 0.0705682810756468, 0.06252852921944953, 0.06256286144977616, 0.09853783709507796, 0.021100166261256225, 0.05017795081761095, 0.06747303305253868, 0.10253301626371761, 0.0875365004063614, 0.02557615753293278, 0.03863303644222118, 0.007015250026128225, 0.0663340748137524, 0.042583181132231994, 0.016222675969343514, 0.021861033296332728, 0.036602271420340386, 0.1638768096604655, 0.15974218716784833, 0.34004675645020704, 14.46588162452944, 102.30704784393312, 108.21794986724855, 86.33113215046545, 65.05116001252206, 53.02080354382915, 79.60160009322628, 98.8827794597995, 109.48569128590246, 108.3425086544406, 73.27433847611951, 47.7668789125258, 34.571617726356756, 35.36789025029829, 27.258927283748505, 36.934171107507524, 34.88981216184555, 24.045225458760417, 18.598690878960397, 14.9975912609408, 21.148559008875203, 21.49726556193444, 15.966523578090055, 22.087760740710845, 16.55012519128861, 13.44175567550044, 13.678512880879065, 20.06546904963832, 13.751976913021458, 17.001033021557717, 10.602975564618266, 6.51868946129276, 3.238339948077356, 0.27059454290616897, 0.6564688322044189, 0.2762200491082284, 0.28950183802554685, 0.452706114419045, 0.4193388790853562, 0.08282361942673884, 0.148894703916965, 0.04791873837670973, 0.06577765749346826, 0.05748668242426169, 0.015913063449965372, 0.0697000123440258, 0.08490312679280197, 0.05799112833976265, 0.0850918219094315, 0.02616616780869663, 0.08347771295736875, 0.43134552997446834, 0.3924417772120045, 0.17862027901555264, 0.08451079784501946, 0.07855864707380533, 0.09291605408033056, 0.023648594130551624, 0.07333943560238808, 0.11202807087571391, 0.0156836258623028, 0.11247423282193561, 0.13953510131086075, 0.29506752808247844, 0.07712051617882906, 0.4598496391648247, 0.518435110007563, 1.2716631759558956, 1.2433513854780507, 0.9046327803404102, 1.0093045378884962, 0.9927178150223148, 4.449501912440024, 5.242592413579264, 11.712377763563588, 10.447370236919774, 4.485226369673207, 6.473994053179219, 8.489976121533303, 6.531823027518488, 9.885595633137612, 12.803206559150452, 12.79135904004497, 15.604555491478214, 21.566422831627634, 42.6822437778596, 57.46696310658609, 59.325542911406494, 53.024671000819055, 68.56816107226958, 87.95808422950007, 90.15288568312123, 82.82621199084868, 67.62826704209851, 55.468582184084006, 39.14113583103303, 44.29281211668446, 66.19024768952401, 78.72932772482596, 77.7086014901438, 25.51330585633555, 0.7920754652830863, 0.5389719660724364, 0.018318324807971235, 0.1381063166885607, 0.06187103425843581, 0.02123396734767143, 0.12110533943820385, 0.05891755463615541, 0.12305481870087887, 0.061572554911817276, 0.02643687646806, 0.08626556820085934, 0.010717566230244214, 0.02105574465296682, 0.1060187393018315, 0.17760902763374392, 0.11114406669812818, 0.026175600266264334, 0.12526598593760885, 0.03976234580360113, 0.07314871801363845, 0.10227630786117047, 0.08175240634309669, 0.18362856349877774, 0.07384489275394909, 0.06573612020621378, 0.05492023808220702, 0.010389696878020563, 0.07190212442149078, 0.0797764434208793, 0.021182419206466407, 0.014006021627855879, 0.02555799358824809, 0.02438247954893497, 0.10020970907663146, 0.07451630753254698, 0.029247319813998, 0.03962109068168267, 0.03902217080335944, 0.09528096750258438, 0.029228730690515334, 0.026287816825412938, 0.033515071150876825, 0.03870759594945177, 0.006004800163810292, 0.01283926301590738, 0.06543340056293434, 0.025148714945140867, 0.02046546241598985, 0.05130304669540736, 0.07861903778487637, 0.02068468039074252, 0.041904978814624974, 0.043830012211636196, 0.2592310687947658, 0.10176070004461274, 0.02699799373775961, 0.05290625038586798, 0.05352647899980507, 0.05647078854963184, 0.02441429709565015, 0.030293192624324755, 0.07083843432126508, 0.06050302722160855, 0.06668529548351804, 0.07535401701686845, 0.12623247480200184, 0.03351289929161149, 0.08148189303615401, 0.044345160375439355, 0.10442996487742472, 0.12553531180826888, 0.12976507476020244, 0.21594132476996994, 3.0241326939675117, 54.0360188484192, 120.39184939476752, 107.54352969508018, 80.12547185344081, 72.61363091007357, 94.15925733504757, 103.32017252522131, 101.66239061663228, 87.58629845034692, 55.13560433541575, 45.807090190149125, 56.94656656634424, 66.64354032085788, 69.451612195661, 59.280012038446245, 62.18481348406885, 54.32471706021217, 44.39819835847424, 44.10943738875851, 37.08822611839541, 37.37442185801845, 38.05161514589864, 37.92253778826806, 45.15364685366231, 33.34785392207484, 32.4630868434906, 29.774219720594346, 18.39873433113098, 13.283360562016888, 15.365020267425047, 10.21533948759879, 7.832629046132488, 6.023828041168952, 4.487978892941629, 1.055056657041273, 0.11084254215201063, 0.5008710734546185, 1.0707858517285318, 0.0864146642326828, 0.1584433923445402, 0.12626640483616822, 0.1715132660202442, 0.07562780918012704, 0.02938075509342936, 0.055376144666825576, 0.04796661504153763, 0.02175954579856367, 0.04996210554494493, 0.05941726995872394, 0.05834215365710759, 0.34803919854664034, 0.38997344191997285, 0.3470449083514752, 0.342960924270653, 0.04866590392926047, 0.14123459076208456, 0.057344695688375545, 0.08427003173217659, 0.05247740202673501, 0.08428706186673335, 0.008369199349544942, 0.1460855667509379, 0.08287011330286342, 0.14051580110624914, 0.04127341592984815, 0.2445500662490245, 0.07136960904444418, 0.2911267717999797, 1.0589997422310615, 0.1634506962352222, 0.8726174756884576, 1.3530611823643408, 4.927436344085201, 7.33389477575979, 14.349009702282569, 11.924657417881875, 7.214175703064089, 7.2088971734046945, 13.61049407912839, 17.311135607381022, 20.31475136356969, 26.230105277030702, 29.329307233133626, 31.40001077805796, 39.396042823791504, 53.60641341055594, 57.858576466960294, 60.927030963282434, 53.89646876242853, 49.39910265707201, 62.9670988359759, 73.23734268065422, 80.73143097662157, 82.50311067027431, 83.17090203685146, 70.60595004789292, 47.94336988079933, 58.93315292173817, 77.53887268804735, 92.21023159642374, 57.19993598999516, 6.829603977741734, 0.5280248147826041, 0.05996507645073918, 0.045266112973613125, 0.0100686801822796, 0.0417501179711713, 0.045815260119495854, 0.048418327294770754, 0.15066098091342758, 0.05291876060167148, 0.1411159237426135, 0.0412034108153274, 0.05114861103075166, 0.049112299532299085, 0.06389694228287666, 0.11195454941762072, 0.09146173574751423, 0.06269753970686467, 0.09521476984504731, 0.06599701144882748, 0.06836403161287308, 0.046666410616448814, 0.09240845188258157, 0.130437362879034, 0.03593958621363967, 0.028813809809845783, 0.04508311372070063, 0.0645336073132292, 0.013585216234317951, 0.044506801097022916, 0.0370014721768037, 0.0055229471388062645, 0.030050882844314463, 0.05090170472319569, 0.065159079799008, 0.09847505618968318, 0.12569321785122156, 0.2416373386738762, 0.14860852411197079, 0.3109765082838074, 0.10212910406651998, 0.10691071079382974, 0.21554659030610518, 0.1874867048595221, 0.13563600488968436, 0.12101448907126343, 0.26580060982415754, 0.1139580915051122, 0.1352420978007778, 0.1303408051570577, 0.1373460969977802, 0.2031962110871269, 0.17269573805312957, 0.23426763412933196, 0.3423057965213253, 0.16341757059337633, 0.2203067695541728, 0.16616588037821556, 0.2427509240806103, 0.2747572195385733, 0.12657986503214608, 0.2082152667665674, 0.17935524844834883, 0.22543142279309614, 0.14418214469427063, 0.18781512675266113, 0.13425274121184505, 0.14217888605931114, 0.08889480493962766, 0.1406033649559944, 0.21473933281677388, 0.24785852420233914, 0.380037342829089, 0.24121487182715248, 1.1935139952167388, 29.191906605997396, 142.6327080880442, 129.4061306984194, 103.11767624270533, 88.96892609134798, 78.39893864047143, 99.94174880366172, 123.80995181299026, 131.8527953855453, 133.99477035768572, 100.198836634236, 71.20884972233927, 56.05931074388566, 61.589303555027136, 51.27561161595007, 59.043732381636104, 58.84540950098346, 47.64047268898257, 45.32814525788831, 33.57434334293489, 42.211135741203066, 45.39722996373331, 48.02339407705492, 57.31195103737616, 48.14441880872173, 35.492747137623454, 34.392639975393976, 31.551173040943763, 15.921278057559846, 17.190675697019024, 13.995125620595871, 12.335641403352062, 8.797298727496978, 3.9306525020830096, 1.1810643922898079, 0.3300397789045688, 1.1698385688566393, 1.4699335949074839, 0.9610175870118604, 0.1853818782875615, 0.2560746486509039, 0.3514693419058477, 0.19063457546214904, 0.17854140260286872, 0.12230343966474458, 0.19658448925662428, 0.21290603844869524, 0.17907732707117835, 0.238158610018511, 0.16723677936580875, 0.5345417102498393, 1.614982231009391, 1.6828847099696438, 0.3851988755406872, 0.15875986326606045, 0.22349390982379838, 0.300932421439117, 0.14413283927546394, 0.38455530039725766, 0.2752208253068309, 0.0770495611152822, 0.29858328942810336, 0.27430666790854547, 0.4962676817611341, 0.22919417088550909, 0.7858906229657512, 1.2221947336389174, 1.7423064117470097, 2.640068670434337, 1.2937505326924787, 2.2092936308153215, 2.0196364916140035, 7.091670276657228, 9.173867837075266, 18.90593013455791, 26.000360288927634, 16.927327763649725, 17.34363832781392, 23.491931999883345, 22.6527173672953, 29.761403376056304, 31.849520283360636, 35.293000436598255, 40.74874278037779, 38.745431438569106, 56.980338173527876, 70.89449528724917, 72.35062030053908, 71.33216904055688, 82.20215505169284, 98.21670609135782, 100.29564857482912, 104.7221923643543, 88.5892955718502, 76.35248122676727, 65.4264876919408, 63.574305272871456, 81.55393631227555, 96.41836997001403, 102.54457873682823, 45.56968089072935, 2.3074421190446426, 0.8087684598661239, 0.14099763976710458, 0.15202481660150713, 0.24936583283687794, 0.27837254167083775, 0.17494573828674134, 0.17481200997867893, 0.26739790314628237, 0.15209410159337908, 0.27073777070449245, 0.18691285903896057, 0.09651245384086525, 0.08468663800627955, 0.19975957130232166, 0.22471870055362103, 0.2235346810231286, 0.16161730993659268, 0.31519802046879647, 0.10879590761877837, 0.31355773429236106, 0.1388653259604208, 0.3156959776195788, 0.19633005613521223, 0.15015793693882806, 0.2442060774492641, 0.2025930394208239, 0.16995369486751097, 0.22996208209904934, 0.14156091357431105, 0.12377468087980825, 0.0627104827623454, 0.0856782622154682, 0.09983010484927124, 0.20058568987634876, 0.20979015967778622], [0.12701917049144545, 0.04502559583934565, 0.05499084074530871, 0.05125297901911601, 0.03342478385856075, 0.12126038797319898, 0.006900807981559586, 0.025522629054443493, 0.09380844692068716, 0.045560122197193485, 0.06367631662156313, 0.05211444872040903, 0.07210244875281088, 0.08720358157710684, 0.03164942105931621, 0.05432742392464031, 0.06011680782502217, 0.11314010878484096, 0.1557406801129541, 0.08027337401384309, 0.06882785188574946, 0.09495072232018556, 0.11376460067807667, 0.08332579772198394, 0.09694855705264116, 0.05110429284433204, 0.02451637065068128, 0.04487194541481234, 0.03476001765398729, 0.050858593125256805, 0.01088960468018007, 0.015428386433350464, 0.027689681118053776, 0.08211180883189363, 0.11519089551462282, 0.03643014295507343, 0.056732319475662325, 0.1707778522564519, 0.060716838530835614, 0.23625321145499908, 4.838892269519068, 70.00697274361887, 119.19165119048088, 110.71850007580174, 86.18885209483486, 50.146373010450795, 45.45736382084508, 70.4098472287578, 102.6323849155057, 120.39415574842884, 116.02633768512358, 91.84624348917316, 81.22574375521752, 53.24478657014909, 47.49593334813272, 47.33465333138743, 39.25985420903852, 37.561201203253965, 29.125122370258456, 29.983564461431197, 33.85921332143968, 33.23328148934149, 29.15059228097239, 15.511569822988204, 13.77151325825722, 20.068879550503148, 27.437701071462325, 13.316562444933, 9.700629403514247, 5.327221962713427, 3.017265114092058, 3.9983631526270225, 4.559864661385936, 5.129021656128669, 0.9872984477589208, 0.06939422068817001, 0.7024287756892943, 0.02291840125596331, 0.3424918026693406, 0.17433979338215244, 0.09491552824094411, 0.033401341568077766, 0.03992674827215172, 0.05712015531776894, 0.06999702463226934, 0.00932072651677675, 0.06019899373753898, 0.09875529881326423, 0.05090034491713009, 0.254744153109289, 0.37118844507682713, 1.0718040745104513, 0.10472967379516172, 0.05487022403207037, 0.07336961180572549, 0.04389615624301857, 0.045359430143669735, 0.0959405385618729, 0.058039870683945, 0.051771068960548415, 0.2652329693157827, 0.35043190563878707, 0.21136781050553247, 0.6002013289159345, 0.6740931445552457, 0.5179317595977937, 0.4207554982314187, 0.9167577458485481, 0.6272786759561109, 1.2588445025105632, 1.050887054974033, 8.393151433237138, 2.1483441658558387, 16.46652771580604, 29.879215686551987, 22.47859747179093, 22.037301409629084, 34.346544281128914, 44.72225281500047, 47.322176271869296, 52.93882208485758, 62.31404381413614, 72.30429710880404, 83.94507592724216, 77.52042185875678, 63.597788503093106, 74.86565974450882, 72.3508164190477, 77.03841747776156, 57.59337325249949, 50.333069985912694, 48.32885649896438, 41.02850191054806, 48.67984979383407, 53.41181285919682, 68.14954219325897, 81.61418391812234, 56.88740545703519, 8.626286329761628, 0.25311407122400503, 0.12741332272848777, 0.158708703914477, 0.04784541993191646, 0.24131011187789903, 0.012699012426779637, 0.17181282172039633, 0.2570568193351069, 0.2767760757236712, 0.1119432342989791, 0.12515328674306794, 0.08438301437924947, 0.10569259268982757, 0.09297656736546948, 0.034315295953063235, 0.08937469007627619, 0.04463497526763428, 0.02829739568574775, 0.010309399372237104, 0.08935746075885911, 0.09612983888796262, 0.17427833780886667, 0.32243773521434876, 0.08785532321780921, 0.12656814388690457, 0.1398417969504672, 0.04282305475264307, 0.12907079991794404, 0.12380768394758626, 0.057402056521706046, 0.05099239421167201, 0.015324092180948826, 0.010087193654579742, 0.056207775243467865, 0.07751505912071274, 0.07181292880446681, 0.05225465430187122, 0.10466175243979502, 0.07160004063118851, 0.047038350134126605, 0.07923694132196327, 0.032961338968767274, 0.07674361624184155, 0.048450889861992294, 0.057720818046119914, 0.10467545009188114, 0.041581406258046634, 0.0720740651952163, 0.009036547158874812, 0.044095488490476724, 0.06319572668402426, 0.1044015966415886, 0.08279925016986747, 0.04544961401411603, 0.14563244106548448, 0.06253043294794138, 0.042673659946529136, 0.08617243489190456, 0.03558221002740245, 0.04916214887353201, 0.05946467547947842, 0.05473446176056901, 0.04447135803920608, 0.04136133984091782, 0.03471813179672726, 0.04252472096273015, 0.10258397643244076, 0.049460413715531754, 0.03768419824360359, 0.023698031699525255, 0.037956672735632434, 0.1701349512703957, 0.05949953248003318, 0.10847200564439259, 0.2859667712642301, 0.1905050606376702, 2.3682236575311233, 33.78196616326609, 111.65214184791812, 118.59900459166496, 91.64398254886751, 70.9978497412897, 82.08262474306169, 93.09533011528754, 108.37464071089222, 117.18428411791402, 95.39239560404133, 75.3093582584012, 57.91256789238223, 61.612249420535186, 54.86025787168934, 60.9696828165362, 65.49029680990404, 58.019664287567146, 47.13789939880372, 39.30198438705937, 47.69245586087627, 54.914700369681086, 55.6820297241211, 50.29407378165953, 39.277979481604795, 36.33176565170288, 31.511176632296657, 30.775200743829053, 18.550977206999256, 18.15726145621269, 11.019453810107324, 7.282779918562982, 8.6848129956953, 6.304941859937483, 2.9738851708750573, 2.499484794755136, 1.1621716834845082, 0.2175501247327174, 0.033890618942677975, 0.21716150365048842, 0.0597992260760117, 0.09738946363570229, 0.04094173816303092, 0.045175802698659326, 0.030570625620443496, 0.05784155350298651, 0.007461525927928667, 0.0838284203482251, 0.06417921503945705, 0.06398098978904948, 0.09699256880389107, 0.7239799934529489, 2.234432101249695, 0.1845587474564391, 0.06795296415446267, 0.03422086029463718, 0.0541302137407324, 0.06089501142982514, 0.040681923273950815, 0.08766642125744013, 0.09348699642765908, 0.12534287818256887, 0.2034549189791564, 0.18342607113863194, 0.35494879068386176, 0.10900786882566829, 0.6236933844704783, 0.7095854465038546, 0.8468527130542264, 0.06628069380718855, 1.2325671964114713, 2.487203118301207, 8.070379101460981, 5.7431451928231025, 14.920654950603364, 22.204508127704745, 10.678980312039776, 17.36563890211044, 18.792353983848326, 18.230811780498875, 28.499725941688787, 33.595371169428674, 35.47912866838517, 45.678142270734234, 51.826316310513405, 63.05442648549234, 68.80490749113022, 76.13179299139208, 78.85375315143217, 82.54833559836112, 82.66501826624717, 78.08940087595295, 78.04648230152746, 62.52090569465392, 57.60756438778293, 50.71625025041642, 71.2798995356406, 90.56152605241346, 79.00634904061594, 29.97386051762489, 1.1109881848096848, 0.1677224637880441, 0.14945324330079943, 0.0940031941319185, 0.1291425823564491, 0.1545989026706065, 0.07739924960919926, 0.20530989363549218, 0.14679386100221067, 0.13707894681682511, 0.06611994557803677, 0.07198791094725171, 0.044298302607550744, 0.05743890535086394, 0.11744609748524044, 0.06600677140898283, 0.04449926662228761, 0.047837218960687045, 0.008863184334439857, 0.058467320932616154, 0.11063286388713507, 0.14912134336848415, 0.14483479031872365, 0.054862340987329526, 0.09237506577084142, 0.10245352698069427, 0.08211502640117561, 0.0279488907976737, 0.033099483773713155, 0.025437466890340852, 0.055329646960261374, 0.08267441614260597, 0.012296611338012643, 0.02977633799967026, 0.03553691890931899, 0.0027942896638471154, 0.04069462501173539, 0.2440202858058676, 0.1607291075971819, 0.15918617587416403, 0.13036558044052896, 0.1408047081842538, 0.1953664247787768, 0.1273321633737895, 0.23152899237409716, 0.22269347051699317, 0.09794680026149559, 0.15570654323504818, 0.1030914254126049, 0.11554128114855099, 0.13810211852673562, 0.14317516808307942, 0.24010214443889358, 0.22386224489779244, 0.259649322157906, 0.3401198105946664, 0.22565634620766487, 0.17297015074760685, 0.19503421841129182, 0.20636833603343657, 0.09927525800923187, 0.18194784320169882, 0.10507800631345281, 0.07930834837738546, 0.2216709116774221, 0.1100082724024692, 0.20158738048086244, 0.09284950402234832, 0.144898314329405, 0.17359232139443198, 0.26007204947452395, 0.2975099083156355, 0.30551785603165627, 0.23140137744767053, 0.5584803644207217, 0.18444712844587144, 0.6456760629530877, 12.430475488785776, 110.90019210692375, 152.23655300755655, 122.82802566405266, 104.18225457591396, 77.53597797886019, 73.60395877592026, 96.8386205550163, 134.37367131633144, 145.34590567311935, 136.62879882320283, 110.35994837360998, 98.74761458366149, 68.90011910469302, 72.3155935349003, 75.19145965576172, 63.847612104108265, 54.80754513894358, 46.79231897477181, 50.27545821282172, 66.47593744339483, 68.12245430484896, 61.40998455785937, 34.70726113165579, 31.984263504705122, 38.15873507530459, 51.613680701101984, 25.307816805378085, 20.115000740174327, 11.533761851249203, 7.969966915345962, 9.988199933882683, 9.50585626786755, 10.779984285754542, 3.902351130400935, 1.5290107409800253, 1.4695354743349938, 0.09312417718671984, 0.7225009534628161, 0.23047848664704831, 0.19401489246276118, 0.14282687386918452, 0.16651892433724097, 0.1447809803029222, 0.13487992207369498, 0.09148212134717934, 0.21471314793152196, 0.14889718604183969, 0.1408158624244313, 0.3066575803583668, 0.7505111504466303, 3.275247980510035, 0.2815331752982832, 0.12302939990355123, 0.24650959658526608, 0.1948388659906003, 0.2605137144846301, 0.13285889019889216, 0.1741426636374766, 0.25498599174522585, 0.4074029534334137, 0.2883133292198181, 0.26659669775155287, 0.6406755925666902, 1.0285136103630066, 1.7560528483121627, 1.3094883075644894, 1.4544951459092479, 1.6711092644160794, 2.6727376013032855, 3.843683013992925, 11.38498438942817, 5.040182913503339, 20.2523523376834, 42.811925180496715, 49.203796079081876, 45.927589324212846, 56.76172094960367, 76.39611367256411, 74.83023289711245, 81.83985356361636, 83.60895233769571, 87.84304111234604, 95.23212755880049, 95.59547239734282, 88.38843884006624, 102.14417534489786, 92.72351295717301, 96.07032237514373, 85.36041613548034, 81.60124009655368, 79.95888879222255, 62.6972476128609, 68.23457133385443, 73.11727108493929, 92.26029672930318, 107.84994525294151, 77.03280848841514, 16.535479061065182, 0.40828300459731015, 0.41252385284150805, 0.25118222730534695, 0.1934304439853276, 0.34329729815644605, 0.254051058042434, 0.259872897257728, 0.32732598904159765, 0.272656912885366, 0.19647354440342998, 0.2129934797243726, 0.16842939440281163, 0.15136927516470033, 0.1436661078684753, 0.2658410286230426, 0.15930775402774736, 0.1302319134195005, 0.13554870150983334, 0.09179722863219439, 0.25065404032507255, 0.25524111434576974, 0.2040773807393928, 0.2876091411998195, 0.19586049020290378, 0.31933605971355594, 0.25398005701361165, 0.24736140974827353, 0.16688201936983293, 0.19185236414834378, 0.12858874675246978, 0.10151785017261583, 0.22685109096909725, 0.11932744088792994, 0.14595393752378805, 0.1610175090571565, 0.15696654336587076, 0.1302292321117655], [0.049086271695071654, 0.0875850014328476, 0.08080982708282049, 0.018248643365598494, 0.01714945849662106, 0.07098487202799128, 0.037170091959377455, 0.08588709778362706, 0.05361218125589433, 0.085733029841175, 0.07799931095852967, 0.06311619143572546, 0.06170637515043059, 0.0869751877842411, 0.08839230488745436, 0.02865709694883516, 0.06491688110174672, 0.07853573338399011, 0.05869965624785232, 0.07674279652776257, 0.07355018639035764, 0.02023323435306309, 0.04275722864774927, 0.01988583071638019, 0.1291901717383054, 0.057179446692668626, 0.04202433148278825, 0.07036820189246247, 0.06278825217797872, 0.023211924013711756, 0.016981851865327167, 0.049586776088202195, 0.02695393027557481, 0.02271083739375876, 0.041522038274354515, 0.0819815815456452, 0.04700872551409468, 0.09932040357060971, 0.16055348960141982, 0.03820522996266523, 0.2227573469281197, 0.3120371416932152, 44.11008065746677, 127.84006949393981, 107.64933955284857, 92.23945325420749, 64.34798886699062, 36.62480984964679, 37.77753560773788, 72.84285422294371, 99.35515834439187, 97.60138034820558, 103.1965551068706, 100.96786437496063, 80.40894939053445, 77.16128964577952, 78.64519288462978, 75.47056767248338, 63.132061958312995, 58.626039181986165, 62.75250988621866, 59.929634986385224, 50.20120382308961, 40.58021422355406, 48.13554248502178, 53.76419075073735, 64.52953969278644, 64.24947069537255, 53.12261258402179, 40.901036647058305, 28.200970772773992, 25.48721621113439, 23.458062333445397, 15.563690277837939, 6.110258448508478, 1.9199496988327274, 1.2975657731294632, 0.1651007883370884, 0.8229719751304196, 0.10224784769478346, 0.08172593034443357, 0.12932589187497093, 0.005294610323729895, 0.06335798410638686, 0.22963156112499777, 0.015234889860655514, 0.08041511560159345, 0.04200062872241101, 0.17581537065486755, 0.16055529756892115, 0.5527992402353595, 0.667022030440069, 0.05117143279001598, 0.0499469599866819, 0.11499093890550638, 0.07454582490026951, 0.062424065470094645, 0.05864668126788832, 0.039573478317188646, 0.08750777210920088, 0.11703407241692466, 0.07316358778024874, 0.1293470359016811, 0.13114003404494257, 0.11343385753852707, 0.9266442637289725, 1.283917518392686, 2.2500870160518156, 2.8024057659410664, 4.259073292055438, 11.596558997707984, 12.161452866369679, 9.209119158406413, 31.692735302832823, 39.98835209877261, 52.441014474438084, 61.977441695428666, 70.18315776701897, 68.31553689895138, 75.57199232039913, 79.88929810062533, 77.41083083614227, 75.34313771032518, 62.78296316823652, 58.156978622559585, 61.73187386605048, 57.24101105043965, 44.134540557861335, 35.77921352078838, 39.842992982556744, 44.46448249201621, 49.10082601731824, 57.709243989759884, 66.7440471341533, 72.9485228753859, 55.24656034285023, 11.345469451719715, 0.0415234134021786, 0.25845977147260024, 0.1297659787439531, 0.09423436116307013, 0.0454070310168449, 0.039651975516350045, 0.0241945639267684, 0.2684387102002098, 0.11198528486514285, 0.11346434783791343, 0.2612300986243833, 0.04786536120058549, 0.10665195693652477, 0.1740441600521726, 0.1212193179995783, 0.10510743175062442, 0.16167101270008474, 0.07262386351583466, 0.050325610434576395, 0.07384946629885705, 0.10252781452671175, 0.08452237343355533, 0.06744925368336901, 0.06783897027132973, 0.08218899985114414, 0.0696900608618894, 0.03500585143844928, 0.04977978811028504, 0.07774631042153606, 0.053510425627351775, 0.05889816495079187, 0.104834244796826, 0.058402069393665566, 0.10277716082430656, 0.1241695379177409, 0.14920492356102313, 0.02104135369130921, 0.0342240318986437, 0.027628085733721816, 0.050672150307124665, 0.03883660132546098, 0.04337730021366189, 0.05277829838075465, 0.03224945942600889, 0.1312627460086538, 0.042722459747305805, 0.13235082068750936, 0.02478354189905428, 0.019366606964819857, 0.07557335565046919, 0.08231233234607405, 0.08932309405457589, 0.09297630689557522, 0.0442425812023782, 0.09909885860378705, 0.03719662541463491, 0.03878646087081682, 0.05170916522582693, 0.03740492855168639, 0.044083491553582495, 0.11590858200384725, 0.027817031744146542, 0.03309846487677386, 0.05756928202425761, 0.1488214659114038, 0.030400059974542072, 0.07814334314917365, 0.050362984033962416, 0.057304617798616814, 0.01657323588827445, 0.046410311253801476, 0.11412430960204333, 0.04139854107052088, 0.022317437838102062, 0.05904736440448512, 0.03845957115352635, 0.03742923652152381, 0.23002876239197872, 0.13787336467254546, 1.6254734680537255, 12.42828582563708, 88.46512117693501, 129.81809723761776, 104.46641460541757, 72.18436671841529, 59.50554047861407, 65.04696699880785, 81.8764728115451, 104.0717064949774, 113.89793411377939, 103.53971542850618, 95.23246488263531, 85.1135656910558, 76.41898109066871, 79.3995274266889, 78.28655489029424, 85.65125203901722, 84.92683733663252, 81.059905944332, 80.85890800722184, 80.92220721706268, 65.06255057550246, 50.68246295375209, 41.315882205963135, 34.67091252726894, 42.228021544794885, 25.144218667860954, 20.516622028043194, 7.880133851881951, 7.604767776304676, 12.709298153077404, 12.001398590303237, 9.036223042395807, 5.879890293844285, 0.6289696465096166, 1.2022586743677817, 0.2812322559616258, 0.8670450747013093, 0.19678456077892936, 0.08955411552902191, 0.10453463547051915, 0.03907722954247748, 0.056570230592643066, 0.08944586730532109, 0.028712427649166317, 0.09613369997110098, 0.10422624677660004, 0.11940315335748658, 0.15248894330955323, 0.17235974721129865, 1.3602549318344364, 0.1679135720816351, 0.11355094641687409, 0.035850643405630704, 0.0654686865727267, 0.023199614895988378, 0.039690873630705385, 0.07728715562411854, 0.1369524657005264, 0.13776925332363577, 0.11919036477563844, 0.09722686147377377, 0.3676774641198497, 0.06540648023327512, 1.5108542120264423, 2.4523097132482836, 2.3359746654187483, 2.730669047563307, 2.9649066204024903, 5.847411597928693, 10.453048848336744, 7.309821719123471, 27.61641602362356, 43.2904072730772, 31.162642663525, 26.961533177283506, 39.76258831639444, 49.31151613112419, 55.14863837149836, 66.99494546459567, 79.34943091484809, 87.09474702035227, 89.25069347504648, 79.61302203516807, 80.78115094092585, 80.38052789626583, 70.57468091287922, 68.21104495756089, 62.2115836604949, 63.35125577065253, 58.878753569818315, 56.81773631803451, 71.24981495641893, 83.94452679541804, 81.86632171753915, 39.66967913412279, 6.365061498457386, 0.6730509585430545, 0.5232708408467232, 0.03802021589851187, 0.06864811999783402, 0.07394174925021588, 0.11714629663695252, 0.018488453783755823, 0.13043613713835517, 0.0602638392498897, 0.19344619475305083, 0.18415981483074928, 0.08358362461290053, 0.11931155222438036, 0.1945871601421987, 0.11563600025950901, 0.04204011672446805, 0.024986277492116057, 0.13151071334798492, 0.015236957340441165, 0.1217527986474095, 0.10351540911341868, 0.049640053672896284, 0.10315280437709824, 0.037114722954650084, 0.08822489169336135, 0.039662961217184226, 0.16207091059655915, 0.13992412075881036, 0.11363516246239025, 0.030260222115283533, 0.050220556797519814, 0.029578110834042874, 0.07197468060879939, 0.038900002762074434, 0.1596687499794268, 0.04742674138997832, 0.027063258683248877, 0.06263910635044018, 0.2100544446899045, 0.26466545138147574, 0.23740974375076834, 0.18645544326113117, 0.19352281886723735, 0.23234276161078485, 0.23948092374109456, 0.26842366423337694, 0.11238447796072691, 0.12365377688359831, 0.2505498370456119, 0.18155294019849072, 0.22277896592934288, 0.31790273985074413, 0.23354835417722505, 0.19972667548685305, 0.10191551109235134, 0.29349597531460947, 0.27465217356239596, 0.12358726513001228, 0.22621980387597318, 0.17288995666369317, 0.11481623255437422, 0.11184120670922341, 0.238868742880802, 0.18651820118388823, 0.14314925898948025, 0.18382489651201234, 0.08958095158900946, 0.09186380167281435, 0.18400344096364515, 0.11686621489183557, 0.20635932683944705, 0.17966061109496703, 0.2781682106996736, 0.12441575091572539, 0.12410858796248514, 0.20218975541572418, 0.3926864044079858, 0.1355122357246376, 0.7015839339263978, 2.5304271473038584, 70.30617898510349, 153.51604584724674, 132.16316469254033, 106.53223283829229, 85.28203148995676, 60.41071368801979, 63.46760111470377, 96.78759836381482, 118.32764717840381, 123.99362071867913, 125.28452765557074, 121.92468027914725, 99.71635372407975, 101.84214499688919, 101.84907190261349, 107.45556662159582, 103.32276128953504, 94.51971530914308, 95.56344232251568, 99.97694815358808, 87.09259756149785, 74.8015054579704, 80.68611975639098, 83.83611248385522, 86.66134080579205, 74.50027527347689, 64.34041084781771, 57.37120236119917, 42.602643197582616, 37.17419662783223, 31.50969985992678, 26.075412880989816, 13.56229599445097, 3.323521080517, 1.5460894761546966, 0.4648373924916791, 1.4425048280146815, 0.23947197583413896, 0.1948867924511433, 0.3784716429729616, 0.23721468244348806, 0.15888124223678343, 0.3777373936628142, 0.10849495763860403, 0.23648250157073622, 0.22335340929848535, 0.24027083699982013, 0.18103986047208312, 0.9561306814993582, 2.301739973406638, 0.17775216350151649, 0.26783049767536504, 0.13952782347558007, 0.14170700654147134, 0.17863825143825623, 0.1882254128013888, 0.10128405545988392, 0.15419826932972477, 0.1813798196493618, 0.22031709641939212, 0.2123875654633007, 0.45753795353154986, 0.3090079074665424, 1.6126970826618134, 3.592792528290903, 7.312041290344731, 9.680542945861816, 7.216518338649505, 16.54543992011778, 16.585928586221513, 16.60273986478006, 43.467486596876576, 56.87424982747724, 63.001768665929, 78.81457651815107, 90.60162052031487, 91.57798474834811, 100.58397416145571, 103.31742686610069, 99.44482372653101, 93.03142686044016, 91.91177845001222, 86.24488707511657, 91.77438566761633, 88.1673740571545, 73.5973378150694, 72.2920593138664, 75.76949150331559, 72.75768387702205, 70.01842606452205, 77.99238497211088, 93.19212636639996, 100.45877210555538, 83.10745377694407, 25.255700272898522, 1.542393377711696, 0.4353442944345936, 0.5618828979711379, 0.17467164734919227, 0.13505773108092048, 0.15009631282619892, 0.25869609427548224, 0.21930731592639802, 0.13657052490499713, 0.2095447817156392, 0.24516232371810945, 0.22796240875557547, 0.20577006732984898, 0.2734344001979597, 0.2827346769552077, 0.1705495886985333, 0.24190120999851536, 0.07588201247516178, 0.1554495054146936, 0.1079821766864869, 0.3446380745980048, 0.1909097542445506, 0.11712640133355895, 0.20789134947042312, 0.12048490781096682, 0.21855045170072587, 0.12866550876248267, 0.2571060328233627, 0.1921622773572322, 0.1556798067664908, 0.13581353810525712, 0.1539853122085333, 0.1432790802491288, 0.19656271703781622, 0.14692470881967776, 0.22953560095160241, 0.10042940777155662, 0.152855439772529, 0.2389506530016661], [0.028507324844418515, 0.012518715549020037, 0.05822624072372433, 0.10060216825936111, 0.051513847279092, 0.09803537534730089, 0.09089987154208845, 0.03790275546752157, 0.11197175575240005, 0.03254709607591072, 0.07358523491289347, 0.032255408098740924, 0.020053713139326825, 0.05801128794349009, 0.026702193783656247, 0.0971503216292589, 0.01782269464925893, 0.09900042396639624, 0.05932078884554006, 0.07673549570984418, 0.021791032012251597, 0.061563155012986356, 0.0763187438790356, 0.06087938706660944, 0.0618816982023418, 0.13858090815765245, 0.041458498941914695, 0.09380278553092673, 0.02519223065445981, 0.02055406048443289, 0.06905944026525944, 0.044026276276957606, 0.06994126109226097, 0.042533297317042466, 0.04746397709353797, 0.02496240810761529, 0.04798485942545438, 0.042389502613655025, 0.08931393930388075, 0.31200315803289413, 0.10754038910231284, 0.21576720830653945, 0.18988629142122884, 12.428497633626385, 78.31088927484329, 105.61382555192517, 101.25566436398415, 81.05455583141696, 65.87157864724436, 53.571425868618874, 47.026892400556996, 74.17904100110455, 79.74375463301136, 78.54357211820542, 77.17360588812059, 68.3317284430227, 77.2877311706543, 87.03502501210859, 79.00962814208, 77.63542575220909, 80.10184349552279, 69.68122774554838, 52.1809103412013, 45.64211922307169, 43.49604145173104, 47.477337391145774, 56.28799276967203, 60.79527854919434, 54.88996198100429, 47.88168276509931, 37.626504744252856, 30.281184104181108, 26.746675545169463, 25.08326111301299, 18.911903904330348, 7.581462033333318, 1.809404191951598, 1.2490170040438253, 0.34388225225190966, 0.14296421811224955, 0.16242032329882347, 0.05463752482507018, 0.050289002923114653, 0.08553413043339407, 0.2122047309192919, 0.07887260522693396, 0.12484010999962208, 0.06512434537252111, 0.04824325705187456, 0.09687468319410279, 0.2919302141714481, 0.7172711469954061, 0.05010455576402526, 0.09579733374618715, 0.11232994016139738, 0.09204042324375722, 0.12597903759489137, 0.03416366800065002, 0.14151047434537642, 0.09044162838930085, 0.11833028552392799, 0.08952895720158854, 0.2632676167113166, 0.015354686859814871, 0.9961196131283238, 2.3533693965404265, 5.141018225300697, 11.55553492807573, 12.350913151617974, 16.369528482037207, 25.651849854377012, 27.45907210534619, 27.470421483439786, 16.546648010130852, 19.82990718656971, 34.10434969009892, 41.30589192913425, 43.237165020358184, 41.01138468711607, 30.66964387893677, 32.89563602016818, 35.98891127494074, 44.56241230810843, 48.490101214378114, 43.78430035806472, 32.46110604655358, 27.70083719684232, 33.5374181501327, 38.08739500661051, 47.58718729019166, 51.484207184084006, 68.36494307364187, 67.98433196160101, 57.72629845526911, 18.090035953829368, 1.6615949426927876, 0.173750426620245, 0.053904719590660066, 0.09607855696231128, 0.17384045727310643, 0.013924879510135902, 0.2090266917742068, 0.20501813671040922, 0.247013284073722, 0.11282007555447279, 0.2168595577560125, 0.1562138466585067, 0.12164875624641297, 0.08594719738128685, 0.05165525178815569, 0.06628950381831777, 0.06790403411873887, 0.020985532694706516, 0.05661184065825036, 0.07056297974721079, 0.061705157070630984, 0.052986854326821146, 0.07992675753250238, 0.09476117684596008, 0.16099552233372966, 0.15513652785410806, 0.08605828013030753, 0.0438180765617759, 0.03730583507868071, 0.07927330751572886, 0.017080826594704585, 0.018008164535727234, 0.10567380055304497, 0.06325925452514522, 0.07265936403024582, 0.07881250562927417, 0.059255031688559445, 0.055043643355489745, 0.024410135323001493, 0.01058771719990839, 0.02057400749876134, 0.02284080229489313, 0.011322253793027374, 0.08178334863435838, 0.09561781636289052, 0.01299234557776682, 0.062362295800759915, 0.06471831877265247, 0.02872087568375132, 0.11240251167046447, 0.023883989967045285, 0.07177231082272145, 0.0585737458670572, 0.019207329624482704, 0.0516539647604429, 0.12946159668987797, 0.06803733341756367, 0.0472695286565971, 0.04013185682255895, 0.07466305167444291, 0.1244187922847848, 0.04080852313387779, 0.08947213646024467, 0.06581350274744534, 0.08619938586508075, 0.07399837846957869, 0.07929534020443117, 0.029353400008873116, 0.06693304831823034, 0.058914869497980804, 0.036243826541448795, 0.05568223892741146, 0.07093924383122115, 0.05519417197173161, 0.04557708338383706, 0.03298594954333479, 0.05201993645319054, 0.11303429672073935, 0.08229767708408256, 0.07395620532934705, 0.1394097386829315, 0.1264727046532977, 0.4216225259006024, 2.7567189787664725, 48.52231956297352, 112.70442747300672, 116.10051754982241, 91.87247630088561, 62.44392133528187, 56.51183851303593, 74.20469330203149, 77.10810230624291, 93.67587227975169, 97.15400265109156, 96.56676892311343, 91.92440063722673, 89.14830392406833, 90.13956531401604, 103.13288719423356, 102.84157276153566, 100.3450547495196, 99.62589602316581, 95.05188680464222, 82.23975489216467, 75.74229378854075, 70.18148683732556, 68.23419478631789, 65.77108360105946, 62.674646915928015, 50.57195801888743, 43.868246924492624, 33.339358068281605, 30.56848006863748, 26.52482628822327, 20.12341030182377, 7.054859322886314, 4.808231101882074, 2.719356441690076, 1.0398659302342323, 0.9913008587975657, 0.06497420746112062, 0.1902221596889919, 0.05443087260749552, 0.08531278464943172, 0.007356099780618905, 0.11540828062401665, 0.04558665948289056, 0.04726341527496134, 0.08796801475147087, 0.06387674820519264, 0.04626848156593981, 0.27651128509352285, 1.3818592241694851, 0.1588276314038423, 0.12331639942262443, 0.12495961205493059, 0.06890335751156654, 0.12074998189364711, 0.020994413568968737, 0.1389184618188489, 0.01569463837621433, 0.0769532715240794, 0.06623863558014555, 0.2288855906696089, 0.3141150785790336, 0.043622141914261926, 0.4407904134883035, 1.0675951261674206, 4.7551908512269305, 5.652119728826708, 10.045183147153548, 19.89627957344055, 21.699377452173543, 17.386882458963704, 37.297323749911406, 41.028509755288404, 56.16250045837895, 58.55057670224098, 65.24781588585147, 72.32155553756222, 65.71786488256147, 73.8054117079704, 74.23906110948133, 71.49516705543765, 65.58663806607647, 66.78145085611652, 62.859955372348914, 57.58700724570983, 54.779437434288766, 52.56238045230989, 62.66774354442474, 64.52840612780663, 74.31117780746953, 83.27011446799003, 82.1485205619566, 47.697088180049775, 11.571942202506527, 0.7280951726340479, 0.08125707687389466, 0.10725927313849812, 0.09436456546668084, 0.03912104211086708, 0.12134887878933262, 0.13376819059973763, 0.17673424715476652, 0.166604052027387, 0.1509452454986111, 0.15368327438350649, 0.06903240502241158, 0.0910653924990085, 0.07816717614449802, 0.007614055948872721, 0.06778385024517775, 0.032798687011123664, 0.04485828989756204, 0.008321095731169468, 0.05330203055974938, 0.04113875682495775, 0.07243194316904392, 0.10004574327819771, 0.10356811596260918, 0.0304511082433765, 0.0755615272529183, 0.04453515401110054, 0.06283760356206088, 0.030399357088871544, 0.1021453757740317, 0.02735416333551609, 0.07604705845756878, 0.03263789281669644, 0.07696228071806893, 0.07521727798326362, 0.048217010879588705, 0.015836023733079914, 0.055626643926746426, 0.03693538560201565, 0.0703388913684795, 0.13355270538839603, 0.07251748454666908, 0.1967905822300142, 0.29961193100579325, 0.14762563330511894, 0.15027225257888918, 0.21291101802020304, 0.4369524355617262, 0.3581874733490329, 0.16929308192864542, 0.3286465101184384, 0.15063979092144197, 0.15626814697057972, 0.1811076745751404, 0.17587820518641703, 0.20379896906595077, 0.08586397725007228, 0.2722290068143799, 0.19856585309870783, 0.26755884289741516, 0.12316277581116847, 0.20670982738656385, 0.27531082531617534, 0.17309586577598127, 0.14400091893490286, 0.17754830750486544, 0.1492201840324748, 0.08749805811432101, 0.15633029202299734, 0.13335122426431026, 0.14397867174158174, 0.18656418178110354, 0.2689870452928928, 0.21597418994192155, 0.15270501074771728, 0.20858683473160192, 0.2729542162870207, 0.2572368806408298, 0.12750187483165534, 0.4878843509622159, 0.189541689751129, 0.4476158585279219, 0.3109871722277134, 22.046154199108003, 116.71437632653021, 140.22871878839308, 123.20866815505491, 99.93682230672529, 86.32846493874827, 77.0337341677758, 65.98098924083095, 96.32520583368118, 105.62378837216286, 107.77100363085347, 104.64085809646114, 91.74345385643744, 96.50144577026369, 110.23986108841436, 105.48372053330945, 107.06924453858407, 114.51159677197857, 110.48276562844555, 88.7001495976602, 84.64640355879261, 85.79917246295561, 91.23149041206607, 101.59378836231848, 100.08610771548365, 84.00412328781621, 68.98360283144059, 58.47969162848688, 48.767381406599476, 38.8119234577302, 38.63362035443706, 27.222674777430875, 11.982927168569258, 6.020284670014536, 3.1696016365481965, 0.9895235961002689, 0.16854838317921086, 0.3211390016780746, 0.1321512547832343, 0.16176147236218377, 0.1633148535244888, 0.35915280542066025, 0.20780223812307083, 0.2241006821033455, 0.21642955260411387, 0.2406176603249004, 0.26476142687662957, 0.6584467486508432, 2.7809614327646073, 0.14389299246813023, 0.3676339196822336, 0.30631155376472785, 0.27863031493559964, 0.3400256124234969, 0.1868159182730221, 0.28645369674890275, 0.1702200483170248, 0.13958544860924446, 0.24942431598901751, 0.3626724891364575, 0.7441881058677551, 1.5998836799014, 4.076633068823045, 6.985279417807057, 15.67495026896077, 19.940265032552905, 21.228628312387777, 33.399240893702355, 34.65534856242519, 45.16733592556369, 57.5501722674216, 58.45403932755994, 65.47844732961347, 74.01319534547868, 75.7062001382151, 75.83998434005245, 66.59129435016264, 73.85540623818675, 79.80579083965671, 79.97305639328496, 85.42582558047387, 83.30112472657235, 71.95941878903297, 60.70553471965175, 66.72106988968389, 70.25789460828229, 75.07679308614424, 78.48861186735093, 94.7455261599633, 97.12785613152289, 82.3126325299663, 34.89205575758411, 4.748097244770297, 0.33224899261709184, 0.2035986830390269, 0.3344974300313381, 0.22343689756047344, 0.13766045351662945, 0.29957586358631816, 0.22993597382258987, 0.4197749363318567, 0.17446501811425533, 0.22112187178384876, 0.3451182585089438, 0.23550007041663895, 0.1974132278513524, 0.15370325395657172, 0.21495210607686352, 0.2144962224748827, 0.09663050032911763, 0.1869431654772451, 0.08470967427016267, 0.10880503172595656, 0.15544564433155522, 0.22574024815713206, 0.25945737116759826, 0.2775623270821187, 0.3024215431463334, 0.2788489870727062, 0.27548512564070765, 0.200153692895847, 0.15847788162289128, 0.20568112452184, 0.0954245400404738, 0.17046093700393555, 0.13883500420037778, 0.27084149900944005, 0.20565634923836879, 0.21268434792516694, 0.17674884879060332, 0.11028442411653458, 0.2722763510481004, 0.1508616653060721], [0.034508752306142164, 0.1085850649002579, 0.10578918105532086, 0.09934674167344648, 0.13843263950078719, 0.04878995271639959, 0.06468059660326089, 0.09941188212964805, 0.10720474300004783, 0.09890856236339578, 0.06008449423637602, 0.02207933196557626, 0.0990055873990059, 0.029625411017707763, 0.14576220103809912, 0.11384519312771098, 0.05037658592505802, 0.10725077722341785, 0.08559337967345793, 0.09420506596084564, 0.030407228642293525, 0.06216380241957884, 0.02328601620730854, 0.024142431643521114, 0.03387675658168812, 0.01577450974558991, 0.06132935646981482, 0.057865030267426086, 0.007919162913646189, 0.11151029503033047, 0.08107906868380886, 0.05748415433411157, 0.05125051221599983, 0.012703025769892962, 0.10576393845821581, 0.013402396054457755, 0.011513614895633392, 0.07962659662289005, 0.08362528447422289, 0.05295403128970535, 0.05237483817543234, 0.09333000969021552, 0.08957805577665569, 0.42496116771813364, 0.7455763797606192, 24.097234126060243, 69.81159164059547, 101.20141798450102, 81.4216661453247, 74.61152153630411, 76.1233755850023, 52.028004584773896, 45.84100300265897, 47.673357840507265, 57.11060400932067, 61.70208346459174, 65.70816486112534, 63.01210411133305, 63.55627805955949, 64.70248091605403, 70.5549749251335, 62.337001446754705, 54.34396413064773, 43.48378796731272, 29.36482821741412, 23.940843343734745, 20.612682834748302, 23.172050945220455, 25.247408382354248, 30.293963186202514, 29.442389165201497, 24.99835748826304, 19.013044180408603, 24.163175052212132, 26.951686066965905, 15.646224791003814, 5.950085030448053, 2.141382449096249, 0.5044413802604522, 0.45377327489756775, 0.3583007624312755, 0.03660773745768013, 0.04824843197580307, 0.08628216932617849, 0.0445371343483848, 0.14112116378401557, 0.09550138632015837, 0.1548753071936869, 0.004950583219573263, 0.06120942540526871, 0.07804025835808247, 0.04365356684091591, 0.3397162354761555, 0.07801821034762167, 0.5765790384142631, 0.10689835379561109, 0.25245898943995276, 0.14263314555489248, 0.05272792426929359, 0.05572239342596262, 0.11290518792286036, 0.4694213868389207, 1.0534832963059027, 0.30799391348996474, 0.6072460283194819, 4.172275162512257, 10.80777329783286, 19.71449536661948, 31.68472190057078, 40.371508829055294, 46.15509856131769, 44.54144331716722, 27.343005249577185, 11.435617285390055, 8.800841608355123, 6.682479304652061, 7.851177444381099, 5.326796875846002, 8.511968851089478, 17.76377908645138, 31.22421995286019, 35.85870035233037, 30.737102762345348, 19.82586714529222, 22.935345711246615, 27.47367116712755, 34.79891907784247, 45.003451455023985, 46.97712536781065, 56.297932055688676, 62.54788375669911, 41.80673545406711, 12.977917751958294, 1.9917090934130455, 0.2577163903943954, 0.005956207206773182, 0.14756175689399242, 0.07957909917158466, 0.10779643100836586, 0.2867342075032573, 0.1682196701726606, 0.15187123129444738, 0.17943127501395442, 0.04143117641609523, 0.13569719999307586, 0.1902442996300036, 0.08550573921492023, 0.03437919151638785, 0.08332028954980836, 0.09123644461074183, 0.08122247268235491, 0.08356260316025826, 0.05161359192683332, 0.035586955942093365, 0.10220678538204202, 0.07779138703500071, 0.038775976957573045, 0.09479748175269175, 0.0185209512335038, 0.04421940704266872, 0.11120887007564308, 0.11322726660798635, 0.06159947524147649, 0.031124275448101184, 0.024066334214782523, 0.020203324365279367, 0.13378363493229115, 0.08331417616817259, 0.08205824396422795, 0.05823800783424128, 0.09226643450317845, 0.10341256180958402, 0.04579174505066007, 0.06255210940575888, 0.012675567263466938, 0.03672575330241554, 0.02076331931616991, 0.07469625392508122, 0.12588076383596467, 0.019111934440931486, 0.20403423466749732, 0.15486331025679267, 0.09873601638021008, 0.14286615885794163, 0.07838879005923387, 0.0699322825417884, 0.15286910678109816, 0.03776569084654893, 0.06817575784460192, 0.02932391328466756, 0.08138561110583045, 0.2051306903482445, 0.04290339822370199, 0.044720865215264985, 0.19226824263891867, 0.01735256947276573, 0.08298279717564583, 0.03878602420069999, 0.03128066080652418, 0.032110259334947315, 0.03618198026332163, 0.10587646911341338, 0.030304724162804986, 0.024898537442148216, 0.06572604615000949, 0.07299362351336787, 0.06285084156139244, 0.06109454286014361, 0.02942776990934245, 0.051825974482081594, 0.03462443924358776, 0.011332943592400802, 0.01859674797273211, 0.037065122591992544, 0.11612441961563404, 0.08482605068674011, 0.19781704811799913, 0.06356983040008815, 0.11101583124048288, 2.796409687688274, 12.083087832696977, 64.11948727023217, 106.59084873814737, 112.25449239054035, 91.25392636945172, 73.07450156058036, 69.12058768733856, 73.30908283110588, 74.51856920796057, 75.05762054074195, 79.68147523941533, 72.50716993885656, 83.26714915613975, 84.09733449259113, 79.18147502406951, 89.98888354147635, 100.22090388882546, 92.40944877747567, 87.46157492360761, 80.15898458419308, 68.55022799584174, 59.732418214121175, 59.11524895698794, 58.75063327050979, 56.75168360433271, 55.472618302991314, 47.217135198654674, 35.93945410943801, 30.025618153233683, 29.565594734684115, 22.626792461641376, 13.17830870228429, 4.3694718326291735, 2.3871983683878377, 0.21203171762247242, 0.19390077600556035, 0.24962788087225732, 0.06445975643732856, 0.032352636147650986, 0.012537977872266164, 0.10379984223794553, 0.14919562325362237, 0.06202387262976939, 0.12687988804593203, 0.038252773379246076, 0.026812987334485498, 0.021728168752404953, 1.7458264938285275, 0.4040169060951279, 0.07350592183009272, 0.24489149631511783, 0.14520769127674643, 0.12426777337227138, 0.054187398373840324, 0.12331053118912444, 0.17831862423448794, 0.21821809211565604, 0.08531806299523001, 0.8219597584778263, 0.2525273091610401, 1.6394573305883717, 4.516050315672352, 7.940425094096892, 17.67450201895929, 21.49633203783343, 26.55507952936234, 37.81292323143252, 35.73976232159522, 35.259397491332024, 27.466848204212805, 26.308658584471672, 39.496228002732806, 42.33362743931432, 44.60006313939249, 45.39938726732808, 43.9592537572307, 48.941138482862904, 53.33692304549679, 54.223806242788996, 59.45406721484277, 54.80786677329771, 50.11745729754048, 49.48014274720223, 60.47210270358671, 65.35956028969058, 72.06514235465758, 75.25067960062336, 68.78724898061445, 39.08994105554397, 12.261192856296418, 1.125168901297354, 0.03637404233637837, 0.10114475003173275, 0.05677613587449155, 0.04238387186741156, 0.11806993820374051, 0.22967833845365435, 0.22928994719780263, 0.308584536636068, 0.06320124251707908, 0.16422095167781078, 0.14451424380944622, 0.06985951951074024, 0.10182880526108128, 0.06985058692554313, 0.04953744002587853, 0.09283132475590514, 0.1511670279526903, 0.036173679700662056, 0.04843993480467508, 0.07467475749792592, 0.02243181668041695, 0.03035078519925235, 0.12433090667811134, 0.07137066624577969, 0.023818387942869338, 0.04459146147353515, 0.13615703660874598, 0.04525937139987946, 0.006559936680846037, 0.08610069841867493, 0.06621551504659076, 0.04639807682965071, 0.06046532420441509, 0.12162742069772176, 0.07676246200477885, 0.032459367517261736, 0.15935462328695482, 0.07413284988292763, 0.09220239721358785, 0.06403726660796712, 0.0638588830347984, 0.12511588633060455, 0.15857237090747203, 0.12142865918576719, 0.2485845916934552, 0.31602496641778177, 0.25309603751426746, 0.23900119948291013, 0.29757769177517585, 0.2616787197128419, 0.2859573943480369, 0.29897610867215746, 0.19311195059168726, 0.2754978427002507, 0.1579716047572513, 0.2758187109664563, 0.27304283733810153, 0.19786954046257083, 0.18803433515131476, 0.4000076002651646, 0.25301084853708744, 0.2029894592781221, 0.3279330983998314, 0.15932407170053453, 0.37408551381480315, 0.2692735008895397, 0.24141952455524476, 0.20180855006460222, 0.1050470946657081, 0.22083730076349553, 0.19130461128248324, 0.19339531119312012, 0.238539754082599, 0.19372707322960903, 0.11473335716272555, 0.28160518756316555, 0.26370005802281443, 0.37068733164379675, 0.2550415331197362, 0.44661145597215623, 0.18060761834344558, 0.5803250857899266, 0.19007744568009532, 0.24249376368618783, 1.0093315654704649, 2.2273257470900014, 41.97918245869298, 110.8699349434145, 139.72442750007878, 112.27493578387846, 97.49666090934508, 99.40199144424932, 76.00971314214891, 70.21471715742543, 71.88162249903526, 81.46191750803303, 86.72737783001315, 97.17024126360494, 88.57149585600823, 85.78880171622001, 94.28656178136026, 111.48759841918947, 107.87733124148463, 105.82067566533243, 96.24264778629427, 80.59213976706229, 72.0032787322998, 63.82619204059724, 53.58737422573952, 58.85868672401675, 58.09388337596771, 56.52113060797415, 43.83436549094416, 41.500135544807684, 41.487081896874216, 38.539789415174916, 20.578928878230435, 12.827609585177514, 5.068565184070218, 1.022959779347143, 0.6225879502392585, 0.5097594400567393, 0.15855551697313786, 0.19939183377690856, 0.24455116941563546, 0.25793855589243675, 0.36259149832110255, 0.18585668426127205, 0.17794546280657092, 0.146004545292066, 0.10778713836184434, 0.3452203320639749, 4.330037303509251, 0.5391646525071514, 0.4555751749825093, 0.8824028699628769, 0.7091659980435526, 0.6446999443634864, 0.500092299114312, 0.22303536023584106, 0.21121981764031997, 0.33732800233748655, 0.7250964593502783, 2.4996590950796684, 2.016834816144359, 2.623194143656762, 4.295646942430928, 9.772817684758095, 20.284239245999245, 35.37908861714025, 52.59335933193084, 58.505253714899865, 62.84900019245764, 65.64062556912823, 53.66267196593746, 41.99348734271142, 46.58732806482623, 50.40400212810886, 48.94504516355453, 54.96110985355993, 61.85492254072621, 72.78604261336788, 76.58880402964931, 72.06966876983643, 62.91510781934185, 64.42500460532405, 66.64976119995117, 67.1690280975834, 80.11040210723877, 81.23464753550869, 89.54691871520012, 86.7370896185598, 61.89795878625686, 27.038584216948482, 4.948577919313985, 0.4167591852526511, 0.21695030853152278, 0.3115228209043703, 0.18875815034393342, 0.1557362214812348, 0.40893117626828535, 0.3296804530245643, 0.26393184558518473, 0.38524796645487513, 0.20954813718074755, 0.2616216921277585, 0.30019452555045006, 0.25652561396841084, 0.17869363959518172, 0.14555535729854338, 0.1589644393853603, 0.3047624320512818, 0.24883384606049908, 0.10919739897813528, 0.18337832853919078, 0.1806365764669834, 0.1616896746019202, 0.18286328762769702, 0.2636243991794125, 0.17859544244504746, 0.11867031364911988, 0.21571767306135547, 0.22553521238507765, 0.10533521267315073, 0.07459117730538692, 0.1566301848018362, 0.15826155371483297, 0.3563110788743342, 0.12967748026694023, 0.1920727216788838, 0.17794367016082813, 0.17321726006846275, 0.17960162232479743, 0.20645309600137896, 0.18928875816204857, 0.1573227436071442, 0.13432458493738406], [0.040912174830032934, 0.060323862238757076, 0.11634273169141625, 0.062119560841951645, 0.07843939782751184, 0.030402555505955414, 0.07564626423822296, 0.1614646899003175, 0.06712038745923389, 0.10038180306794182, 0.05902376506597765, 0.12103094463987697, 0.10478530710022296, 0.04507393981780737, 0.05370816824236705, 0.08685983792548219, 0.06472384226658652, 0.04712936904041037, 0.053304263706048655, 0.013129149728845204, 0.03204637334772176, 0.10226833288587871, 0.14505802833985898, 0.11722648305998695, 0.15442679335753765, 0.11081292519285796, 0.035248988593417796, 0.036174959067495606, 0.01767765888343415, 0.08317657911609258, 0.00813728059461761, 0.05223536803837746, 0.10192031446363657, 0.04998427229903398, 0.08764186813946694, 0.19110976447982175, 0.14674617968980344, 0.12311460420248971, 0.045737188099132436, 0.05990184738390869, 0.04596808699951057, 0.05495632082344063, 0.12745677523555296, 0.011376270652568389, 0.2914821753098119, 0.33627809415901866, 0.847952937887561, 25.039369790784775, 73.90226287226524, 99.24075065120574, 97.09690863086333, 88.22399739296206, 73.79758265710646, 58.475604518767334, 55.56855555503599, 59.11248760838663, 62.94354500309114, 61.73634536804692, 43.016257132253344, 36.66166836215604, 39.41342284602504, 25.995520084134995, 21.49444930015072, 21.40507613458941, 13.007934670294485, 14.086721789452339, 9.458668193509503, 12.741111516952516, 9.30714899493802, 11.70171283906506, 10.8630169399323, 12.393139427708043, 9.043234279078822, 17.04559114671523, 22.039811726539366, 29.91169095039368, 17.940487746269472, 4.5910190670721, 0.14324888106315367, 0.6804965977226535, 0.8153338946642414, 0.20428517442797461, 0.11307733554032542, 0.0846269597569781, 0.041426553075472196, 0.02963125052291059, 0.01097128976271638, 0.15704970987093064, 0.20754337701345646, 0.2067389387276865, 0.09454076568926535, 0.10208021233519239, 0.30684812174689385, 0.1900611739725836, 0.3918314196409718, 0.4756130320170234, 0.6930572527550882, 0.42768693919624057, 0.23902202175269205, 0.37481329734286956, 0.6814680584976751, 1.0084119535261586, 1.597498878836632, 3.0233952883751165, 6.066252887248994, 14.55030377834074, 25.406990012814923, 35.956755684268096, 43.27323905883297, 43.18809616950251, 48.36904118137975, 35.114022685635476, 14.061171470149873, 4.663255887646829, 9.570168429805387, 6.7066548332091305, 2.2507462193889003, 5.206061909275671, 10.612654013018455, 18.063687432196833, 24.5164962737791, 14.015302292762266, 11.047588971353347, 21.348031143988333, 32.67433589504611, 37.55398796450707, 41.26543268080681, 40.08163390621063, 43.46546657623784, 36.906553699124245, 14.68488912428579, 0.4869956889700505, 0.49894592514441866, 0.24926973476765618, 0.21703004296268188, 0.008145920151183683, 0.050438256002962596, 0.2431377525170965, 0.17879948230280032, 0.06060146185899935, 0.12892418601099523, 0.04372687379439031, 0.09517384542813224, 0.09323856177469415, 0.06134598823865095, 0.042859336676737, 0.07531719117034828, 0.04064518935798157, 0.07230314846721388, 0.0738025127699779, 0.10903105064625702, 0.07590930818790391, 0.03568768884325701, 0.08294825427114003, 0.037165269435894106, 0.015274187298341384, 0.06583725147309803, 0.025658077229895902, 0.0536472910654641, 0.09203892171142564, 0.09190237419980188, 0.17226222421853774, 0.10346384373523536, 0.03264912749610601, 0.04652093435006757, 0.018052670413688306, 0.06895470838513106, 0.03514597658067942, 0.036404892697089145, 0.07998163241051859, 0.07811336612869656, 0.05711870358115243, 0.017817981293304794, 0.060752442467116544, 0.02824375420928963, 0.02590384972732394, 0.09250825781735683, 0.12577551101604778, 0.06194574698325127, 0.06848127370880497, 0.10505852469753836, 0.11650551005356735, 0.060796691705622984, 0.07991244701007683, 0.2800031751394272, 0.13196040695953754, 0.04901545835779079, 0.08979121208070748, 0.09877506388171066, 0.08742136505222128, 0.034881120833057555, 0.10788128290685917, 0.03505519899209181, 0.06751142171842438, 0.021157760751403628, 0.05066077773188872, 0.12181081448591526, 0.11884307413692437, 0.11646895233782069, 0.1524668186903, 0.1048439434699474, 0.10561911719700984, 0.051332897311376954, 0.035232406620296745, 0.051872659880187244, 0.022177278221915328, 0.042742761077299234, 0.18291055525262512, 0.0841644035291768, 0.016377054177404895, 0.15079801872132287, 0.07730187983402322, 0.16668884263884637, 0.17409565648244274, 0.11133997070212519, 0.03118161904445339, 0.13624224090768447, 0.1996135549439538, 0.11274740445397555, 0.053841390932399424, 0.34733835066999164, 3.920607557219844, 14.802848523662938, 64.53123415670088, 95.59286009880805, 100.3962730592297, 96.79505086714222, 83.35777159660094, 74.42509128201392, 67.41656103441792, 73.27453459462812, 83.17408700143137, 83.18251225256151, 80.15689788326141, 79.20072601687524, 71.16149886961907, 77.23777586413969, 75.19717847147297, 65.44198105412146, 64.05254025613108, 57.70821240640456, 45.22782279599098, 35.26077424326251, 32.367573207424535, 34.65273234152025, 37.45390476719026, 35.08020793237994, 32.960633616293634, 24.29134241996273, 34.91481334932389, 33.693873651566044, 23.083705440644298, 11.685401662703484, 5.233932800831334, 0.13657104584478563, 0.8356484626570057, 0.9950940971893649, 0.30764666115564687, 0.13922341077798797, 0.12209661890782657, 0.1413555713670869, 0.034018356443172505, 0.03701535368999166, 0.0574625046893714, 0.10036137916388051, 0.1874162094487298, 0.09676409074135366, 0.7667908252727601, 0.6436503426201883, 0.3368652852312211, 0.7958052103077212, 0.8470287294157091, 0.8048240263615886, 0.3981826256119436, 0.6428837643996362, 0.36001106904399016, 0.7048346594937387, 1.3584336037597349, 2.8599822377004935, 2.7700719525737147, 3.32154494139456, 7.7160478695746395, 19.375965402972316, 32.365431593310454, 40.05988044123496, 50.87974640630907, 57.763745323304214, 59.50759187821419, 38.595412546588534, 22.746597336184596, 18.56880634061752, 20.25786130659042, 21.66445659052941, 21.527505074777913, 25.639104112502068, 32.24446373601114, 43.94561567614156, 44.76201780380742, 44.708375469330825, 39.81105704461375, 46.78718851458642, 50.63577498159101, 56.91991013865317, 63.85558628266858, 62.907321914549804, 57.21867707467849, 34.581462875489265, 10.707885238432116, 1.3040879392816176, 0.40817029774189, 0.0658342024431594, 0.0893247947697678, 0.03848891232102629, 0.07394241574671, 0.11429704710721009, 0.12870321561011577, 0.21421352070906471, 0.31511675386178883, 0.09789156532215496, 0.08608794305473567, 0.11875114358601072, 0.10016265595632215, 0.04681841778238455, 0.022003247943376342, 0.07663083277762898, 0.1194589781845289, 0.05446255417360414, 0.11426076518311618, 0.05510816328047265, 0.038191930676299723, 0.015727102309615625, 0.021419780058485847, 0.059523859602068706, 0.03857939879620268, 0.07436806951919872, 0.004909859900738323, 0.025768165979834817, 0.1627607880941322, 0.04440290808317162, 0.119627088518633, 0.050030678075047276, 0.022693443367437973, 0.04996568700599094, 0.025677353917290608, 0.02804061642006761, 0.11543052781733776, 0.14696569452362676, 0.04672877400392487, 0.05946005979973463, 0.04446668490286797, 0.009315610964662366, 0.07417415734380484, 0.1693456815255265, 0.35773204939980663, 0.18180219456553462, 0.18176500865769002, 0.16796563541696918, 0.16835356702006635, 0.18993165914810475, 0.36336245856458144, 0.4347208214382972, 0.31775614126555385, 0.2687638685587914, 0.16820925137689038, 0.23171711292478347, 0.20308428564138953, 0.2027344439298876, 0.23797025964144738, 0.35844343864629347, 0.2550011756078851, 0.23457572404896063, 0.22046453770129915, 0.19504293649187013, 0.3417968077044333, 0.27649872125156466, 0.24400707845005298, 0.36273402131853566, 0.2814917452633381, 0.13181393094841512, 0.11552291802100598, 0.20704877532778249, 0.20640926045035163, 0.23332932963967326, 0.22026566127615593, 0.24285797720714924, 0.1982068489756315, 0.43905834997853926, 0.46365593169485375, 0.2824693960287879, 0.2607634591479456, 0.1421219657265371, 0.1527335398620175, 0.34065852362302046, 0.2341643195118635, 0.4039197355028122, 0.11527964680065071, 0.45471295834549014, 0.9406025695704645, 3.6539569881654557, 45.02235727925455, 105.24667601431571, 125.30209202920238, 120.92939453740274, 116.77540056167112, 102.7144879679526, 87.14536128505584, 85.64310135379915, 91.60305653848957, 96.97895511504143, 94.93078754794215, 85.37257548301451, 74.90861754263602, 81.9713157223117, 74.72334046517649, 70.39011770679106, 80.92786327485116, 76.99682466445431, 68.91266284450408, 55.34427442858296, 48.3502334164035, 44.44689850653372, 44.11756846212572, 38.617075797050234, 39.14781170506632, 46.94613864344936, 54.086299711658114, 46.88987224332748, 40.981672733060776, 27.64362942787909, 12.0391131601026, 0.2012736521541111, 1.3642340538001831, 1.9281518651593117, 0.5554076163999496, 0.29028655720814583, 0.3853399889363397, 0.3982213896609122, 0.36005534892601354, 0.22686906339180088, 0.28890223632897105, 0.2950396731255516, 0.5231080624845721, 0.17223780133551167, 3.369406927977839, 1.7923686028488222, 0.6021434537345364, 1.0697426238367636, 1.268615371757938, 1.2653470568118559, 0.569160059094429, 1.1529353597471792, 0.8695838287953408, 1.4364073810077485, 3.047171470619017, 5.349773630019158, 5.612621461191486, 9.244218487893383, 18.214584935096003, 28.780853979049194, 45.94018405483615, 56.57217633339667, 64.4159007841541, 76.83385018379458, 75.3679427792949, 59.480660884611076, 46.79509601285381, 38.46946131798529, 39.602594837065666, 44.869616262374386, 44.79151402750323, 53.86090070970597, 65.64068440468081, 61.9623484150056, 49.22149381329937, 48.612863556031265, 56.23335023080149, 66.80903296316824, 73.36743200978925, 74.72177936184791, 70.5255885278025, 66.2025325529037, 51.4717968048588, 21.425048843506847, 4.205894777851721, 0.500780092852731, 0.4231467344347508, 0.2750690173237555, 0.18709003985408815, 0.17136308214356824, 0.22998748557461848, 0.39099595479426846, 0.18805336477535387, 0.25050837636714984, 0.3961621453204463, 0.2880701422691345, 0.4377552344193382, 0.16331191174685955, 0.22259608542005863, 0.10677743447764267, 0.11251093609438789, 0.1699447929258308, 0.25113474517580003, 0.2707423059450042, 0.14764860062108887, 0.1624057063412282, 0.2163689244057863, 0.1455117056086179, 0.13606391096067044, 0.1690786845621563, 0.13068209732732466, 0.17480324593282517, 0.1409718685693318, 0.13310553986699353, 0.41275386307989403, 0.19082956016063693, 0.18550204683936414, 0.2016967778364497, 0.1497232586505913, 0.14401245621904252, 0.09751015312729344, 0.1734479291424636, 0.24464902948708306, 0.366444215779343, 0.1551812061018521, 0.1816480423534109, 0.1691264731268729, 0.13258570324509375, 0.07526774019483598], [0.06512172535182008, 0.10972602262852654, 0.03337096235144042, 0.05033566533858257, 0.012174221131229594, 0.07819341465590463, 0.06789071184973564, 0.016863272945967414, 0.048453054060378385, 0.05554352721740162, 0.08045034798523111, 0.1242359194363798, 0.1492788510457162, 0.05562865107710804, 0.1781108611894231, 0.0401036418043077, 0.04707161750223848, 0.015356192222586083, 0.16687233601847004, 0.07864972726712305, 0.1776465046549997, 0.06289646975816258, 0.057070122115434184, 0.06956455267725453, 0.15165733954598828, 0.06947053070630758, 0.10720245239715423, 0.15248436210376604, 0.08392791984783066, 0.04007118648939556, 0.0691747288369844, 0.03869911152569037, 0.10326482941426578, 0.06421669206071286, 0.07796158112825886, 0.10176340433498544, 0.018983281465367447, 0.14048394717035756, 0.08813686819086153, 0.0909033342595062, 0.011741692677230365, 0.11006801193880458, 0.09744870521488691, 0.1740465042812209, 0.05003964513420098, 0.12455627442367616, 0.1852492071808346, 0.9584740525291813, 0.7211666121598214, 12.061623642521521, 48.93231707234537, 73.55365045609014, 76.17121281162386, 78.5188219624181, 77.69551646324896, 75.27205651806247, 82.15041114437966, 69.07859479227375, 53.021297762470866, 38.91705866782896, 26.045644052567024, 14.404856408796004, 13.842402254381488, 19.190688325512795, 21.806640548090783, 17.06108254771079, 10.801366106156381, 2.3314989959039996, 5.684138526839595, 7.60989333352735, 6.759887770298989, 10.374106245656169, 17.587344992545344, 20.582508041012673, 37.65671876169021, 44.575022728212424, 30.081202060945575, 10.709811122186723, 2.0598241158070105, 2.239653511393455, 2.007818635432951, 0.7164633226010108, 0.35554073150119475, 0.1480638968848413, 0.22839900226362292, 0.07558146086070808, 0.016515520739278967, 0.051439517598238685, 0.030793294821295048, 0.09324071448176138, 0.03802153740018126, 0.4670196092657505, 0.08604670454177164, 0.17566397635927125, 0.38858237946706436, 0.4405368690288836, 0.24948305961105133, 1.9835183264747744, 1.3103897172597148, 0.667018904801338, 1.068369671702385, 0.7457218138921646, 2.0518833999672244, 6.901047008652841, 15.461445854556178, 23.74347948258923, 24.068995022004653, 27.9547655582428, 34.15288117624099, 35.79064330747051, 33.27842797002485, 22.34614491462708, 12.213838081206045, 7.98939980806843, 2.7705990210656197, 2.8215376167528095, 7.174973084080604, 10.605127965250324, 11.280341436786037, 5.502319018686972, 6.040877603715466, 14.270867263117145, 20.463707293233565, 35.921579868562766, 40.62117945763373, 36.74949807505454, 43.78415915273851, 28.055644996704597, 7.571798293821274, 1.9480028580273352, 0.0835899908035513, 0.04723180265676591, 0.06401008963885327, 0.09132585473238461, 0.1448814910385878, 0.25001720675537664, 0.17096134563607557, 0.01841955949672528, 0.08859395455088347, 0.052896662795495604, 0.03491309734301702, 0.016888563423567725, 0.08098719175904989, 0.06454475389252748, 0.027484409773962635, 0.043271679671541344, 0.008146883506748465, 0.004438258568576027, 0.045867909512092034, 0.13454820600248155, 0.051236381724236474, 0.08926036677533582, 0.023533790109438762, 0.03692482507997944, 0.04919832354531654, 0.03600873330968522, 0.04461992547036179, 0.04793371156518979, 0.047051044211031935, 0.055341145940004825, 0.022085761358480782, 0.0884241511624667, 0.004414916827133106, 0.043509473363238, 0.027962894884929545, 0.032846759028372266, 0.02795025634939873, 0.06745210353044734, 0.01530716738348166, 0.1028579371350427, 0.026808737461725553, 0.07504543680096827, 0.07896475028246641, 0.09508208341656194, 0.0802799087438372, 0.027886682543002313, 0.04790980962195224, 0.08612922753297514, 0.025895562571203037, 0.06850863836946026, 0.025886193315889088, 0.026141436575281046, 0.06921963691110573, 0.05445038869736656, 0.070490890873536, 0.1381473790013021, 0.07568159621329078, 0.15318626718175027, 0.28405149016649495, 0.07693353709914992, 0.06479225391822477, 0.08325684214791945, 0.1321027920611443, 0.09225337270406947, 0.1438257299483784, 0.15615632877715174, 0.10285602957611123, 0.08033210997499766, 0.08505970750364565, 0.13790056079385743, 0.14975949460940977, 0.1416095295139859, 0.12302265066893832, 0.06254926338912019, 0.09590440985536385, 0.056371105188924464, 0.09634964483519716, 0.05720252126094796, 0.05162022241781797, 0.13501902831898582, 0.09754929255934493, 0.16659666693979697, 0.09164156722685984, 0.06947767064576188, 0.18068200548089322, 0.015013465552680917, 0.032116863012854616, 0.06137391214349097, 0.13799106642123193, 0.07139796961940105, 0.13032965091688017, 0.23393098445188618, 0.7044411354487943, 4.739029215228173, 11.488978189806785, 48.20901240071943, 82.6115720502792, 95.70709520770659, 94.45787522100633, 90.9924219500634, 85.34305572509767, 81.3587748619818, 85.86928875215592, 86.65939531018658, 73.45700325504427, 66.6411868987545, 61.43295787995862, 43.588095557305124, 39.931360060168856, 45.2876389411188, 39.28063100384128, 34.18575063828499, 24.47453671886075, 22.44775587512601, 16.33868100181703, 19.18168648596733, 19.24735676857733, 24.35642630823197, 24.15244736979085, 35.611853830276, 42.53603350731635, 45.42243903683078, 33.086282822393606, 12.115078683822388, 3.619176841551258, 2.1340976270937153, 1.9818411455039058, 0.3357312912421842, 0.3062303178012371, 0.0904914470870168, 0.011358855558829683, 0.16389177901850593, 0.07886535803517027, 0.24471748710399677, 0.11094907433876108, 0.15237455106069966, 0.07768048814708188, 1.184679959570208, 1.2074012693858918, 0.20685641064999566, 0.7744787320975335, 0.8438138567632245, 0.6137868257299547, 1.701045161293399, 1.1001674686708758, 1.4848272021739715, 2.4527796622245543, 4.0137287926289344, 4.771130873310951, 7.948000661788448, 14.405328073809224, 24.487102031707767, 34.39786065009333, 40.573922741797666, 45.28079832753828, 49.41831442617601, 55.85140551290205, 49.8650880782835, 31.93906407202444, 23.265003273564, 19.596306508587254, 17.52511266739138, 14.486927101689002, 16.32723356446912, 27.723386902962964, 33.097516490567116, 36.508680235955026, 32.99877866621941, 31.140400863462883, 38.11495750181137, 52.44812965393067, 58.15950855132073, 64.12005601390716, 46.45349287217664, 25.424079779655706, 10.488545317803661, 1.615603313811364, 0.11032003954413439, 0.09600868208273765, 0.14904338626130936, 0.08313846624185962, 0.11282310926265295, 0.1280903299489329, 0.08478614516676435, 0.06763261682804554, 0.10511198231289465, 0.03830268400751295, 0.02844399618615787, 0.021984350469504154, 0.05141232147692673, 0.05298356397918636, 0.06428018542787721, 0.014637816254229797, 0.09828800050121161, 0.05615826298092162, 0.08817622978841105, 0.0927395397616971, 0.06930407512211992, 0.02366925935230909, 0.026770967411838716, 0.07359242081762322, 0.028691674327297557, 0.03565747816596301, 0.03720067035887511, 0.036604473923122695, 0.07636411926679074, 0.0691603187231287, 0.030866435150645917, 0.08079322595750132, 0.03992859837448886, 0.04190381436098007, 0.025117468133929278, 0.09455204250351076, 0.03863105610493691, 0.15181650197313679, 0.10963618349764617, 0.06130021065473557, 0.03728812312587135, 0.0273864520263047, 0.08482813444589415, 0.08532704154570257, 0.05968950313305663, 0.103683557751919, 0.20877916876587177, 0.23352140320404885, 0.23555043303678114, 0.0663308342618327, 0.1996709349294824, 0.17179582989023578, 0.15160287069457193, 0.2907805307017219, 0.2403864090240771, 0.3298802793987336, 0.25695404097918545, 0.35301402030933293, 0.27307366471617456, 0.29312341143527343, 0.23946837522089484, 0.316956406759639, 0.2893709289210458, 0.31648149353361904, 0.36174267290099976, 0.37752981447885114, 0.27638016148440303, 0.3161590930915648, 0.1777667344938363, 0.22835666824492717, 0.22492056472166894, 0.19120217000524845, 0.20558470469569007, 0.15707632376542016, 0.19113061739312065, 0.24080106177397315, 0.20255783001982397, 0.20858761614128468, 0.3615599456093004, 0.3416437739806791, 0.315313515884261, 0.2258767190599634, 0.2786099063532968, 0.21405248902738097, 0.19212207306296597, 0.09351002503066294, 0.2236013153507825, 0.37091700480349604, 0.48121825221084785, 0.23061463579295144, 0.24568615931897397, 0.7151515962135407, 1.2128369390003144, 2.138008720451786, 25.097083545500233, 74.77989319832095, 100.51105729995236, 104.53001976013185, 106.39392222127607, 108.10572301187824, 101.8555595028785, 105.31960072055941, 96.88987808842813, 85.35484636983564, 81.96889954228556, 73.1825863930487, 55.06063607431228, 59.3117126341789, 66.78590666863226, 68.13968919938611, 62.535481222214244, 62.07167663881856, 53.522784556111986, 44.938928465689386, 36.696448018473966, 31.05867631973759, 35.74848175048828, 61.72206009587934, 68.45096065152076, 86.87006581214168, 70.70728055892452, 55.24092389691261, 24.81295293377292, 3.4772355806443, 3.2584420952104756, 4.618819846260933, 1.7014361725699518, 0.802160675727552, 0.6888776609013159, 0.6603085874549804, 0.7063522490282214, 0.2974981412051186, 0.34363842178736964, 0.2432589016614422, 0.2055868037766026, 0.20851355076076525, 3.35487675282263, 2.8154559818006333, 0.5209430980105554, 2.53283376655271, 2.4444801720880696, 0.8997295111898453, 4.61699741501962, 2.860927283763886, 5.30206976398345, 5.894312848967891, 6.965529303396902, 8.080978816555392, 10.805976852293938, 21.62270688241528, 33.730841990440126, 41.42120568983017, 46.52772765005789, 55.973175494901604, 63.03011171279415, 69.23063370489305, 64.25174959244268, 55.290271236050515, 48.00237409530148, 48.126356294078214, 48.64525056654408, 54.08037693269792, 55.7212338139934, 55.069320201873786, 47.967327717811834, 45.20489654233379, 53.82291647695727, 55.57502354345014, 68.44597139666158, 75.47056767248338, 70.14147866156794, 71.40659993694675, 46.94326354611305, 16.270358216377996, 4.345485558432918, 0.41075725408811725, 0.21879091137839904, 0.2392959135073808, 0.1757083022065701, 0.1580559203941976, 0.3741585986027795, 0.25733634949691836, 0.1762276944974738, 0.11236436815271456, 0.2676743995999136, 0.1543261294042872, 0.12341389177186836, 0.17866278157359172, 0.1977641574077068, 0.2347241459234107, 0.19668778855233424, 0.1799165763922276, 0.16843988980737426, 0.21517129915375866, 0.16588489464934797, 0.09988775296557335, 0.3135058548181288, 0.1365071081466252, 0.18879755790675842, 0.22507601928326393, 0.2441815626356871, 0.20072626701045423, 0.13566775157326652, 0.16182792282873587, 0.1563645208314542, 0.12442020188656547, 0.14274779827364031, 0.19933859066617107, 0.12944636686194327, 0.15003056716053717, 0.1709093282660169, 0.18253979934079034, 0.18131097898848597, 0.2740932970998749, 0.23396850743841743, 0.25879222298822097, 0.2430246779394727, 0.16503922551149325, 0.17279583510131608, 0.1977331614902904, 0.1491435445965298], [0.08148468925707764, 0.013590138349231454, 0.04084847844956864, 0.1335734050841101, 0.06679070152101979, 0.12763309803220535, 0.05716556134904104, 0.06855242795521213, 0.037432990352352785, 0.04204723751172424, 0.10568497011498099, 0.006312958073742207, 0.041037709827745156, 0.04927543029489537, 0.1628760996484949, 0.01831150854066495, 0.1908546878445533, 0.11880881468495054, 0.10403428046453385, 0.06957677944052605, 0.04492809582922248, 0.12784618538834397, 0.09558479031247478, 0.049011378939593994, 0.10236090695064876, 0.04173575765303066, 0.12881351694945367, 0.09113978729733536, 0.08292211535116358, 0.09720324298306819, 0.05792372792418446, 0.055148256491989865, 0.07573811051946494, 0.15697221241651044, 0.07124820709108345, 0.09237570928469782, 0.04593874966245025, 0.06998498173009965, 0.01962934830977071, 0.02993082346004104, 0.05545636173337699, 0.06449292038357066, 0.14536213460228137, 0.0925309646634325, 0.07673079192998909, 0.09376672577233085, 0.07210407285921036, 0.017387265594856396, 0.27400669852091425, 0.7274695545915635, 0.3961661596211695, 1.312538195521601, 17.40382513692302, 44.60982199638121, 53.15265401717156, 58.49101943354453, 66.19806105090727, 62.011546704076956, 66.55902893312516, 56.36598910054853, 37.5680261273538, 22.04485001102571, 11.379623489995158, 3.7633045786811463, 6.470436463432928, 14.786824660916484, 19.07961856934332, 12.02529759176316, 6.92412035119149, 3.49831072072829, 3.6360616645505353, 10.174740995130232, 17.767293530125773, 20.501826847753218, 29.60758959093402, 52.457323689614576, 46.23418923347227, 19.457268291904082, 4.847922546248283, 4.27544379426587, 2.599368931785707, 1.0557867081895953, 0.3211738740003878, 0.17692535544835752, 0.10458358082800143, 0.1470454136330274, 0.1188279209177821, 0.11741583701223136, 0.09032783368902822, 0.1315927000776414, 0.020775210915974552, 0.8158621276097914, 0.42169634613298607, 0.19256510170957736, 0.6971635453162656, 1.1493246954294944, 0.702535537702422, 0.03454903320920083, 0.435182037012231, 0.4959465989903097, 0.854217698497157, 1.714212557961864, 5.229909429627081, 10.920716966352156, 21.024943551709576, 27.791112507543257, 32.5783045061173, 31.849939976969075, 25.755898567938036, 13.062183991555246, 15.141014687476622, 12.081316882564176, 7.7149603924443655, 1.0345609245761749, 7.1620375975485775, 7.607697296527125, 9.01332522592237, 5.329947519686915, 3.7023911504976215, 5.63069966531569, 16.859390351080126, 23.179044531237697, 22.347507938261955, 31.20316270859011, 37.1258298812374, 31.499911585161765, 16.650465303851714, 2.847218845159777, 0.3671501811233259, 0.03038223119332425, 0.09867053118444259, 0.03342960255160447, 0.12124760962662198, 0.03153391606775263, 0.3242924340790318, 0.07173225974604007, 0.193324095659679, 0.21991119239359136, 0.08927014971812887, 0.10609376995313553, 0.08811370169203128, 0.02603276700322186, 0.035971371201618065, 0.05373407350552659, 0.09734247180242693, 0.03316644751917451, 0.04021210453262733, 0.1184044734785153, 0.036339851832317735, 0.05117111103308778, 0.1078393932191595, 0.03882082374466043, 0.06410886135493075, 0.044261986209500226, 0.06274004226490375, 0.038990910585609176, 0.03351821211136637, 0.02642505764660816, 0.016363408236253648, 0.11411571409553291, 0.0489103855685361, 0.0631736825040031, 0.12038148594118896, 0.15988611976706213, 0.014398760432677885, 0.016876545419255574, 0.04118231275389272, 0.11466965695182163, 0.0943574868142605, 0.04452935089507411, 0.0608557915585416, 0.06492089540246995, 0.1373141358095792, 0.08362866292196898, 0.027844471098374457, 0.028396519802270398, 0.04110097336853224, 0.0769186060455057, 0.026863102891272115, 0.06123076095395993, 0.03500023218352468, 0.05373340317859285, 0.03292038773877486, 0.17332670338932546, 0.14928809006608304, 0.22114509956971293, 0.242444044579902, 0.06669719282898211, 0.14334027535252034, 0.10062140472713979, 0.14763960674885782, 0.16015167648513473, 0.14457375351940432, 0.24477564849920813, 0.23650278757897117, 0.14602535224008947, 0.16743001738382926, 0.14115646511556643, 0.05072382293761738, 0.11228046620324736, 0.0922838400208181, 0.17305031418800357, 0.13411303741797326, 0.087679605630617, 0.04979471533348964, 0.019519407031757217, 0.1015771377170759, 0.048813345211167494, 0.08194365253251407, 0.1680281175480735, 0.09749459388155131, 0.20715547605387627, 0.13527090270673076, 0.11632369440649787, 0.11220538958666787, 0.08721648249775173, 0.058993144531644164, 0.022846733730646874, 0.10947270799548396, 0.1151593939791764, 0.12286475994774412, 0.11643437878979791, 0.08153581796514411, 0.21503424602410487, 0.40898060426115995, 2.9670163652589245, 4.2136698961257935, 20.926370466909102, 48.05980543936453, 74.20427753079322, 86.57449168543663, 92.13603604224421, 98.00415285172002, 89.95058551911386, 83.27220901366204, 75.54695190921908, 59.85626312994189, 52.426446791618105, 46.84507485358946, 44.054402612870746, 42.66421264217746, 34.566553946464296, 24.933954131218698, 14.862960807738768, 15.631597292038704, 17.464725817403487, 18.931582435484856, 24.939884754919238, 33.37236873565182, 37.531501016309186, 50.08043012311382, 60.73473284321447, 54.12886919513826, 25.192108846479847, 7.784833984990274, 4.229578539248436, 3.1360415922057245, 1.1944169983748467, 0.2718605798098349, 0.5778101110650647, 0.6234230473637581, 0.1658729283559707, 0.19762621561606086, 0.07514188727063519, 0.08209020515242893, 0.7257498404191387, 0.047534453352132154, 0.4000833510391174, 0.43917206807001946, 0.4053160073536058, 0.34905049589372455, 1.4808163335246425, 1.211232812173905, 1.6455730411314196, 0.8043238628775844, 1.1140935988195482, 1.0191040281807224, 0.8326832120937686, 6.136419186669012, 13.889363811862085, 28.8484501454138, 41.6624314554276, 42.62306697906987, 42.442524202408336, 39.40404053657286, 34.17689784880608, 37.94906085537326, 32.97506009378741, 26.066450265146074, 17.867739546683527, 15.04910178722874, 16.3083149925355, 24.87090987543906, 29.807012696419996, 28.740643801227694, 23.87416305080537, 24.778502756549468, 29.704074013617735, 33.79819300866897, 49.14501151730938, 57.32584407252651, 49.23172727707894, 33.989035929403, 9.495186440406307, 1.5588148707343688, 0.25951556320632657, 0.10337629520724859, 0.12977858855118676, 0.09131512184056545, 0.10455989338938268, 0.2874513577309347, 0.20236315175650582, 0.2366426599121863, 0.12063415706037514, 0.17038146304267068, 0.023691265227934046, 0.018680504365493695, 0.036951232130729386, 0.021702876359584834, 0.011813072919575198, 0.11768609751015903, 0.027510058397667545, 0.02703227042671173, 0.06286451240040122, 0.03726087337840469, 0.06315452264501684, 0.0293853975862505, 0.05213838896804279, 0.06289610203595893, 0.031111280681685578, 0.06917677429174224, 0.12315724465635516, 0.06326671622152771, 0.177895360656323, 0.03699924286094405, 0.026719838703772234, 0.07811666030677096, 0.015636546886526048, 0.10617083073743891, 0.04282432645859738, 0.06999353127133462, 0.051811062580635475, 0.03656423132446024, 0.09467047203572528, 0.10273798308785885, 0.11829716754296135, 0.13866094902398127, 0.04783385966513907, 0.06047458620741964, 0.047155829717315016, 0.07577128212658629, 0.02251374403825931, 0.20860583371212407, 0.11099120151371726, 0.1944586718755384, 0.2366351982158038, 0.20552404585384554, 0.21404901098820472, 0.3244085117213188, 0.5147773772478104, 0.323291402310133, 0.3118930252328996, 0.45234452091878463, 0.13925912579701794, 0.3647899561591687, 0.23506945239440089, 0.28282388023311095, 0.195152732213178, 0.4255746509278975, 0.3688514478985341, 0.35433273341867233, 0.30221534292063407, 0.33791467246990053, 0.25881716681103556, 0.18725272628568834, 0.17238415477256622, 0.27986215367432565, 0.2725234910124733, 0.224420094802495, 0.3049653227771482, 0.16809268343833186, 0.34727133329837556, 0.32057252562334465, 0.17276206594561377, 0.2458333707745037, 0.3177374793637184, 0.20035462243662727, 0.24740849351209981, 0.28638735353466005, 0.2259155903612414, 0.19211185345005607, 0.2490715784651618, 0.1709639656567766, 0.2961020532154268, 0.3049436884541666, 0.36407994587094555, 0.16973310751059364, 0.2894845244384581, 0.11572998392605975, 0.17218258171792955, 0.4664255234022295, 0.9465038980687819, 0.5542611811430224, 6.775212960858499, 33.470161268788004, 68.27770956100957, 82.45215123699558, 91.90345518050655, 103.9669321429345, 97.05043638906172, 103.66735719865369, 97.84896819822251, 83.68462270306003, 75.23909291913434, 66.45871823833835, 51.98676478478217, 58.04525383057133, 57.995596624189815, 61.1073854661757, 55.95384605469243, 51.66585606913413, 49.585638815356845, 46.458956733826675, 39.63277355317147, 57.23346833259829, 63.38518035027289, 83.96490743083339, 85.2564105679912, 91.1454414552258, 50.19990944093274, 17.49433971220447, 11.048425416792593, 6.3363051318353225, 1.7129495547663782, 0.43014022852143935, 0.5901327885447011, 0.6160301763203837, 0.2698495990085987, 0.3828512450620052, 0.23561878340138545, 0.2886856173075015, 1.230251772269126, 0.17108848558798914, 3.04831410607984, 1.2926601137845748, 1.14427623729552, 4.187829321430576, 4.396973531092367, 3.405104664064223, 3.674123364110147, 1.7782045564343854, 4.281528370995676, 2.8225277700731835, 3.3479525437278137, 10.030086924952846, 20.7840492263917, 40.77237506066599, 59.313061929518184, 71.34545803070068, 70.31436104928294, 72.99805456592192, 52.2121088735519, 48.82565213787941, 45.41677121193179, 45.346164626459924, 47.046645456744784, 50.588435895981334, 48.62712137160763, 54.152301434547674, 47.222987374951764, 39.286075253640455, 41.270841629274436, 50.553832746321156, 60.931055315079234, 56.45501513634959, 61.868635146848625, 66.66978097731068, 53.1530305647081, 24.640113692129813, 4.04456205425724, 0.6530681985520548, 0.4340234362790662, 0.2060199345672323, 0.4109646494109785, 0.23604817568294464, 0.2743389048883992, 0.4769509586115038, 0.24292995882851465, 0.47942134701917255, 0.4451905773772348, 0.27341445126841146, 0.2362337068564469, 0.25931282569804504, 0.09894414714747861, 0.10265031964668345, 0.07980066712104505, 0.2822352182720938, 0.11247574201514644, 0.21592226450241384, 0.22047633545533304, 0.1991095303768112, 0.1577292758250429, 0.2592652669597057, 0.078757569464224, 0.17958161210821522, 0.1382127722665187, 0.1535028913208554, 0.20056580223383444, 0.1576424933849804, 0.23488021335534512, 0.13237455409140358, 0.22640242391536314, 0.18667543306946757, 0.1271086802045184, 0.22453747479425323, 0.22255336835740075, 0.13550406922736477, 0.08062109366179475, 0.15726125739034147, 0.3470477888420705, 0.3617715390939867, 0.3245521378853629, 0.4749057183582937, 0.2466355107965008, 0.24339114375893148, 0.2311199167442899, 0.37067338884357487, 0.15167626191771802], [0.04205090324244192, 0.020837216157346003, 0.07949187240052609, 0.09020370446265706, 0.022991143219593554, 0.03403444045914277, 0.07194947631609055, 0.024486914569992694, 0.0824046536018291, 0.03534588722452041, 0.05816094321949829, 0.11308870428512174, 0.0590292311033174, 0.1070532720956591, 0.1290416579333044, 0.03265660834468661, 0.12444270188890158, 0.11446256806413013, 0.05807457063647528, 0.0919739651163259, 0.049905120094697324, 0.014075014548706672, 0.06284882675015158, 0.07769161174374242, 0.09024979231218178, 0.05862702728219091, 0.06789780582391447, 0.04701277811921412, 0.07049775502133755, 0.0271410625728388, 0.07672380520811967, 0.08169391553007788, 0.07275348559262292, 0.03162491965227791, 0.19290167477823075, 0.15656951063823316, 0.05541632980889371, 0.03874301219419126, 0.06994440205275052, 0.07159874594259648, 0.014514086351189164, 0.10732828999959654, 0.047647072107441006, 0.08300427828104266, 0.04305368935268733, 0.04161062102103907, 0.13794300206486257, 0.07890611391274199, 0.007059925401042546, 0.058738278570554914, 0.2593019472495202, 0.28083410474561876, 0.22908644360159675, 0.12765691570577123, 3.4561283261545244, 18.761373143042288, 39.893658238072554, 51.33991495255501, 53.716557487364746, 45.60471550110848, 35.71978961267779, 28.24408938807826, 24.48120474815369, 18.053248043983213, 13.072361561559863, 1.5066037110743986, 3.9328992847473394, 8.764883279800415, 7.305128603212296, 9.186492966067407, 4.615207833628501, 9.470012668640384, 14.970051319368425, 24.773762572196222, 26.68069931768602, 31.918956041336063, 37.8418860127849, 16.699689088329194, 2.8733283473599345, 5.4610189122538415, 1.8512145742293329, 1.3723097236887103, 1.4547146760648297, 0.12037314324369354, 0.3723941448955767, 0.0869684232278697, 0.30296270765604516, 0.23808281327928268, 0.19866262532530293, 0.20003652740870753, 0.18175923235474095, 0.535409718511566, 0.19003632208031995, 0.08241138751468352, 0.4602628057041476, 0.22188930802287596, 0.694098887183974, 0.3733442777827863, 0.5637549717099436, 0.7282404841915254, 2.2703313491036816, 6.58161408478214, 12.666146197626668, 19.04340332554233, 20.589305508521296, 16.509020713067827, 16.992892142265074, 12.56035497111659, 8.379675149917603, 9.484641148198037, 8.285595140149518, 10.119477741179928, 1.8511342882148683, 8.519481170562006, 5.566685113214678, 9.403598116290185, 4.808978803696172, 8.547286852713555, 10.75245709188523, 20.702138370083226, 22.43139174676711, 30.23763598934297, 35.84967497856387, 29.709714381925522, 16.637517559912897, 4.109265472619764, 0.7241368269728077, 0.14222457554311524, 0.06186430800646063, 0.025983729715188666, 0.030751495148926496, 0.02250734145843214, 0.12978255688663454, 0.04295423581835724, 0.05172868131569797, 0.054013527058545625, 0.14579560247159776, 0.023720811323953733, 0.08864839275878283, 0.07062700937592215, 0.1243827478479474, 0.041496450937683546, 0.02519170779945149, 0.042939434999660145, 0.11159960556054309, 0.07084499969477616, 0.04285136170144524, 0.09897543417830622, 0.08287743710341954, 0.012648955284197246, 0.08938536168106141, 0.06487074728694654, 0.05775110150176672, 0.009077090447047546, 0.03430484268333643, 0.025832103677995266, 0.05117754617165174, 0.08031566206726336, 0.05106707629297049, 0.14117687369786924, 0.033896165419249766, 0.027148012905531836, 0.10334975792155152, 0.040323367312310204, 0.053498911325849836, 0.07584779132758418, 0.03754347555279251, 0.07172667496507207, 0.12509171625659352, 0.09442412880279365, 0.06928522935918263, 0.07332186154540508, 0.06604505282255911, 0.21450071175011898, 0.04931575333278987, 0.08064885668817066, 0.01919814997593001, 0.033870183547297796, 0.056950846056063334, 0.03835805301224032, 0.04620791082420657, 0.06154683350975956, 0.047875190108654, 0.07024044907020946, 0.11418627845423837, 0.046809588619057214, 0.12828099391152784, 0.09000922538219921, 0.04155170119878265, 0.10445681625917073, 0.09171461371043999, 0.17271251537867133, 0.16396893939423948, 0.19376514779944576, 0.15354095056893366, 0.13009525865556734, 0.06504998887859045, 0.03177029249678937, 0.058504116135619344, 0.04089665388868701, 0.06984010684273897, 0.041915738519521496, 0.09243100551107238, 0.0800781365063402, 0.05102879870983382, 0.01375445080245094, 0.08694966173460407, 0.06491612267470168, 0.08087788633401356, 0.1609229738073003, 0.2114702977480427, 0.27941491154413073, 0.08695593599470393, 0.06759163112409654, 0.06493175852923624, 0.06489472583897653, 0.11035442157017608, 0.11488852061090932, 0.0722797598028856, 0.0832817093619416, 0.02658704693819727, 0.024063511180781552, 0.1278889637380358, 0.03860119016720884, 0.04812622179968223, 0.5621021829785839, 0.42755284316597447, 1.1388609149763662, 1.8482946147841794, 6.882151970940252, 19.957676433747817, 45.24560682235226, 67.9825355160621, 81.44832257301577, 90.89943824275848, 79.7193104220975, 68.76008264480099, 52.632857599566066, 38.84701298129174, 31.40821441527336, 30.212621073569025, 32.796949186632716, 30.46656708563528, 24.364633867817542, 15.69123104695351, 15.971055876824165, 18.375464870083718, 27.296942895458592, 37.46634652537685, 50.11532745053692, 60.930004119873054, 58.76145901218538, 63.3575786313703, 40.242592288601784, 12.25351187490648, 0.1489950307915288, 5.99223776209739, 5.345604150525985, 2.0240837239450027, 0.04073009871306919, 0.2581566458027209, 0.6695644617561372, 0.9362773597240449, 1.3600645743070112, 0.30454743713621174, 0.1350237627423579, 0.1427911588501546, 0.34835252850767107, 0.10468408390278779, 0.11629341095085106, 0.31507995099790637, 0.2207028523327843, 0.8877026049360153, 0.674518783005976, 0.80351076779827, 0.9007864060901827, 3.1713625356074306, 9.191015458876088, 18.075748720476707, 31.847796401669903, 41.65663419231292, 45.058917691630704, 38.84775823162448, 32.659960408364576, 29.52383325945947, 20.387387775605728, 20.266255178759177, 20.161708324186264, 15.641209060145965, 13.158223225224404, 17.66334483700414, 22.45854043191479, 23.383199976336574, 21.983737522555938, 15.672433087902686, 19.28818471970097, 29.99907155190745, 43.877727293199115, 45.498913488080426, 43.75903637178483, 35.008479549038796, 14.846128936736816, 3.506074317039982, 0.459146554311437, 0.16547713669077044, 0.10659521280397331, 0.11230288959679105, 0.07879120072409992, 0.0892008570653777, 0.05535210099732203, 0.1484355108151513, 0.09111351048153254, 0.12253135082221801, 0.13075331286076577, 0.05025498478883698, 0.11637975672079671, 0.08952301235929613, 0.0441397262376643, 0.04367606684325203, 0.06361503724849994, 0.03449634551220844, 0.13988428418674778, 0.02949443871095296, 0.07236034459164066, 0.030665783316738186, 0.06888058937845692, 0.0688053825269303, 0.0826943957156712, 0.12864362929136525, 0.04722242574057272, 0.025785529362638632, 0.01957259077068058, 0.08213944162332243, 0.08700890331378869, 0.06342955587071276, 0.09107368923122845, 0.08360036363404605, 0.17304237751710802, 0.1773659785788867, 0.10114472704909502, 0.06489176873958881, 0.042495812634907426, 0.04680923621861204, 0.12079300539147471, 0.061491659857452884, 0.12399828662314724, 0.17199073797993122, 0.13829129627875744, 0.07611818972133821, 0.20082867764417203, 0.04895132530720965, 0.051219884020787095, 0.12407638162614838, 0.07869295760869019, 0.29180662886750314, 0.27819140784202084, 0.2485472219245088, 0.2564696282629044, 0.3474877378152263, 0.34709019946955866, 0.4371948564244855, 0.4366293916058156, 0.2976745252888049, 0.27074638153276137, 0.21454025720877035, 0.24465117453327104, 0.23489677617626809, 0.3169520553802291, 0.26189515487320963, 0.3656012739144987, 0.2338886657549489, 0.2333819905235883, 0.15007170608207104, 0.18359497820417728, 0.20126127217325473, 0.1439519812382998, 0.2711067799358599, 0.24614061799741563, 0.18996789510692322, 0.22025239263330737, 0.19603606223339037, 0.15991022089316, 0.19670033707253395, 0.26481906733205246, 0.20613135439493965, 0.24609512769647185, 0.5306289008548183, 0.3631366771315375, 0.35334622667681787, 0.16819020643109278, 0.2287105702224278, 0.1289124955092707, 0.2612551037342318, 0.20610480178748408, 0.14217963682547693, 0.18453870659633992, 0.27540940551027177, 0.12236792128533126, 0.19019914640774652, 0.18963619435746826, 0.14552273727472753, 0.46225684064049877, 0.4579488830941339, 0.7409958481307953, 0.34442096528026367, 1.2316395558657185, 7.879450378879425, 31.402905487245132, 61.91061235243275, 83.61785611798688, 94.41170107933783, 87.46253198192966, 83.4834364921816, 77.4172321442635, 68.16623580071234, 68.6837847002091, 65.16684639838435, 47.2762139381901, 39.47379204534715, 34.95874389525383, 40.721952992100874, 47.05246233171033, 51.77408602929885, 56.2705421447754, 70.7173453607867, 71.80836046895674, 91.77054174484746, 78.12094457687871, 84.17032195675759, 79.1402038451164, 39.045469222530244, 17.290323511246715, 15.311085716370615, 8.838913113840166, 2.3301310693064043, 0.13912696030832108, 0.9697646563572269, 0.9788067614839924, 0.847865726438261, 0.6979101439637523, 0.3343306680119807, 0.5989204911935715, 0.5152350075302586, 2.3173267370270145, 0.35276237574796526, 0.5823899072504813, 1.5982134856524008, 2.161850847544209, 3.1701399818543465, 3.002318677402312, 0.9294095959874892, 0.4981274980931513, 2.2467843803667256, 12.9413200770655, 29.24874567216443, 52.57970948373118, 74.00411898089995, 72.18490800549908, 61.62646409003966, 49.00865424063898, 42.53526472276257, 50.18789914346511, 41.13302915327011, 42.10404719075849, 35.55973337542626, 42.067977074653875, 40.41540407365368, 41.32951244231194, 34.22728853840982, 47.08985820893319, 49.07656223543229, 55.80875365964828, 56.41841157790154, 68.98018252465033, 62.34344197857765, 48.49831073514877, 28.442933943963823, 7.933642825772686, 1.1870750568566786, 0.31339461885152325, 0.2768623985109791, 0.40255260563665823, 0.28867832415046235, 0.22217394033026314, 0.23302035105805244, 0.10851830033765686, 0.1882412708214214, 0.3728721531168107, 0.32858264902907036, 0.16481186593732527, 0.17581544726366, 0.2191193026280211, 0.23841560187359012, 0.19077924350577016, 0.1929822212625896, 0.24256343172202188, 0.22208358792047347, 0.2570944802174645, 0.1247625282755302, 0.19455054113941808, 0.16546149317535663, 0.18589564749310095, 0.1783248448684331, 0.12421977796381521, 0.23256901801834184, 0.16793117678213507, 0.1402716029195055, 0.16330659509666506, 0.17870415032150286, 0.27145869008475737, 0.18026874701101936, 0.2733714890576178, 0.2221733121381652, 0.30118323862552643, 0.2060385811473093, 0.2455520632887079, 0.15991975102693806, 0.1934856023158758, 0.24064697084888337, 0.16162967459569055, 0.2778576692986873, 0.3851944322307264, 0.2462526660172209, 0.4092408902943135, 0.23968341610124036, 0.419411504220578, 0.13091825159086337, 0.20190239583532657], [0.08625221528833912, 0.04197987923098188, 0.04793740410898482, 0.05105162429953775, 0.07307976243957397, 0.060509213381597114, 0.07199279092732938, 0.09518372030147622, 0.03585969090401646, 0.17396960437538164, 0.17441805692449694, 0.04311450907299596, 0.01262758143110982, 0.035784434256774765, 0.07046015542601386, 0.0830224881910028, 0.09151812747962053, 0.05403586235197802, 0.016581908003577304, 0.04768916863888022, 0.13266002909550745, 0.056595055671829375, 0.09006542559232443, 0.06551235358441068, 0.01915711830670555, 0.06664063255753248, 0.06738209841592659, 0.09814459650266556, 0.07294372054598025, 0.05509007977502001, 0.08294214855038351, 0.06783882471462412, 0.08280141819869319, 0.038448639078846866, 0.053172806848681746, 0.056200087551147714, 0.1476367569017795, 0.06037682955784183, 0.04043340052087461, 0.020143000686901714, 0.03731112874623749, 0.06838008115488677, 0.0713092106724939, 0.037168211213523344, 0.06012370644678032, 0.03675654237609237, 0.04414751352141461, 0.04355147413368668, 0.022233346281873605, 0.0886970470028539, 0.050434483019935514, 0.05784346106191797, 0.11103111469457227, 0.10679966634920529, 0.12634036296437826, 0.1876007140644135, 0.9409695563297119, 9.694234959540829, 27.944090827818844, 39.39790202725319, 46.15237643641811, 29.818024750678774, 31.19779886737947, 30.213083913249356, 28.169844804271577, 11.653692241637938, 3.176097816997959, 6.167785890640752, 7.802915130892108, 7.356814655565447, 15.94389150219579, 18.630946490072436, 15.447184116609636, 20.82503014995206, 33.61960357235324, 24.971495136137932, 37.492524423906886, 31.59527224879111, 16.107962285318685, 0.16237533861590972, 3.256392166499169, 1.8164953469268739, 2.2230763493045687, 2.859526262167962, 1.028463232421106, 0.8073071318288004, 0.47191595298147976, 1.101008449350634, 0.6318742229092507, 0.41024621215558826, 0.5466761139612044, 0.3258606773470679, 0.39734602695511234, 0.4398026810057702, 0.12492396598381382, 0.24702302871211884, 0.6853980895492339, 1.2076910344823715, 3.402059679069827, 7.909328543370771, 10.05788476236405, 9.48163269027587, 10.996527556450138, 11.922523648508134, 13.286177804393153, 10.989574174727164, 15.07263404707755, 14.56126876415745, 9.071073301376837, 9.90726476715457, 9.370960074086344, 9.750805343351058, 6.530887542232391, 2.9896535892640395, 2.7888968779194743, 3.4597398484906847, 16.096834521139822, 30.919996999925186, 22.035469662758615, 27.850599173576605, 37.18638735432779, 37.059055451423895, 23.569849883356405, 8.388536764729409, 1.3199778285718735, 0.3690917237151054, 0.04027324600986416, 0.14665256374545638, 0.07871085342260138, 0.01900571251979038, 0.030284095330223925, 0.10926633156956204, 0.08478838214350325, 0.13715292026679363, 0.04279060709861018, 0.09356162871324247, 0.0380759526254429, 0.09276298205218009, 0.04378093661920678, 0.08908126307951827, 0.03709674287106722, 0.09206231037575392, 0.024099168743217186, 0.014709860120239037, 0.07917832793487657, 0.017841605529669794, 0.1260366933720727, 0.06997876875703374, 0.06914971606625665, 0.0512134412213439, 0.05951488871247538, 0.04680516829173412, 0.06777230530015885, 0.03800540741893553, 0.08114011823049477, 0.023520169066145055, 0.06213091043454986, 0.03640375888696121, 0.06902984628874449, 0.1426206583217267, 0.11930396029305075, 0.03906439756974578, 0.12251655766440016, 0.188445586470827, 0.1051132463579697, 0.0695577804600039, 0.06543109463828226, 0.00726503395144978, 0.13225861434494296, 0.06479971561460726, 0.019315807674560818, 0.12917509512795558, 0.033793877359599836, 0.16647234619144471, 0.08783571902782687, 0.07629467339645471, 0.11969650374545206, 0.04654101351456297, 0.04537084102330189, 0.09129569385080569, 0.059161431065970854, 0.0528367777024546, 0.04089799837299413, 0.011851909746896597, 0.03535818676614473, 0.03574366688788418, 0.1215878752390704, 0.06067693301085984, 0.05806125602835129, 0.044403800575603405, 0.13968641899766462, 0.13944292561181132, 0.1417478390278355, 0.0617218041612256, 0.07683606007166448, 0.04887570476820392, 0.045122762601221764, 0.030506437028487845, 0.09304980537103069, 0.06874410315386711, 0.0203733001234791, 0.0395434744836342, 0.08152074135479428, 0.064270839155201, 0.04768767476742787, 0.0445979502382538, 0.039907236012720296, 0.05941299518810646, 0.04832376140139757, 0.22042857753413342, 0.04254735120001339, 0.07659164738030204, 0.1393808724899446, 0.04038002334475037, 0.0058690757179001895, 0.10396353224472654, 0.07231987216660092, 0.011587731029477813, 0.08831186565540491, 0.0942850225575028, 0.1019594768783258, 0.10933915588764415, 0.07714015867320761, 0.08532319578432268, 0.12187451469681918, 0.08695687062197155, 0.10621387721790422, 0.1179921726185468, 0.16776138105459754, 0.2926227270114807, 1.2162202284220727, 2.017179984719523, 9.378502791927708, 29.093768904286048, 51.872208041529504, 65.03864765167236, 69.8609350573632, 61.04421961692072, 54.15356051537299, 44.708234264004616, 34.62749973420174, 19.247572498936808, 20.663271604045747, 22.652995855577533, 23.217783820244577, 20.092394159686183, 21.9518211964638, 29.69123217367357, 37.71141229137298, 43.57050372708229, 61.0672047061305, 55.15571432728922, 61.352439465061316, 58.127258823763945, 39.45210133829425, 17.57468358162911, 5.72708357726374, 2.824613245264177, 4.395677187750417, 2.9992825177408036, 1.6233631103269517, 0.8871113689195727, 0.4348976345312211, 0.8042840875925557, 1.0925819724798203, 0.8374180031880256, 1.0232573278969335, 0.6132815141350992, 0.8418570843435104, 1.0080626174326868, 0.19656717566953552, 0.23602465678366924, 0.4521064820789522, 1.217106684081016, 4.096952417204458, 10.417182695481086, 16.073368941583944, 21.120017882316343, 24.610317407115815, 29.333814036461618, 35.34665061581519, 30.551413836017733, 27.692137379800123, 22.51867428902657, 17.9950184975901, 20.910498596006825, 23.96384020005503, 20.953381869100756, 14.28199306611092, 13.767138834922546, 18.51829209635335, 18.010502053845315, 13.451865584619584, 21.17932608050685, 28.30089511409883, 39.2391009484568, 48.46324866817844, 50.2074247021829, 39.81265344927388, 20.774588469536077, 5.7921968833092725, 1.154265165809662, 0.19011424854397777, 0.19865450479330557, 0.09365984884601447, 0.003601418354646153, 0.015262703640356421, 0.01662434735936263, 0.04994446254004875, 0.05597412608744157, 0.06607692974108843, 0.12422353945552342, 0.08421229168532357, 0.12553719638456262, 0.15942902574616094, 0.13336328248823845, 0.15217005155019223, 0.04927585547369334, 0.021165260752182335, 0.0508945303097848, 0.04454196453274739, 0.02957591216170019, 0.031350325011918624, 0.14937176218917295, 0.08329030486845201, 0.06148172752751459, 0.0314595653194814, 0.13730377830084295, 0.12129385069373155, 0.09827903727249754, 0.08164378273631297, 0.053901643747644085, 0.08978185048627277, 0.20408445939181313, 0.18252774111686215, 0.06477224370164257, 0.062111011300716674, 0.09135599263132581, 0.16258118644116387, 0.25482232472108257, 0.1654053082869899, 0.06537438114924778, 0.044677761278205344, 0.10246399940261919, 0.18064460506842983, 0.1820987472010236, 0.2498845050051328, 0.12137320208092853, 0.08097711770284562, 0.14607381496217944, 0.10844209757182868, 0.014746557647031883, 0.21768713189709574, 0.12746868024189628, 0.17264384325713883, 0.2854180990928604, 0.22983218423060833, 0.23118428345168793, 0.16588495593638192, 0.24977936709840454, 0.16576297941707796, 0.28640877335302295, 0.3668261259313553, 0.16866602364086336, 0.12651907595535442, 0.18567843092305047, 0.21393849514424804, 0.21897454265384905, 0.23044788909535255, 0.22676539637388723, 0.14057917189934563, 0.20536540436648554, 0.12999176017699704, 0.15544852482215052, 0.20950630878008183, 0.19327359514371042, 0.14369112830008232, 0.1647877801329859, 0.23608332379691063, 0.23051389523090857, 0.20390430615553934, 0.2172836487091357, 0.11365405419060301, 0.1548606289490577, 0.13737883959566394, 0.2517726819121069, 0.3191643334444492, 0.2584571054866237, 0.33761249674904736, 0.4085624428285707, 0.21390769840969195, 0.19071898302964627, 0.2911803979546793, 0.1997804088938621, 0.2080141686864438, 0.17206878701765693, 0.2723127249027452, 0.27469605507869876, 0.1654908036993396, 0.20630160977523174, 0.19329260944599108, 0.30808621176308204, 0.17184508934376702, 0.21158236108960646, 0.1704146806150675, 0.20927409220847393, 0.3763482617514749, 0.3067410532985964, 1.9093195853694793, 14.5721003893883, 40.067748715800626, 67.42602179127356, 84.00442923268965, 72.57483082432901, 77.06546614246984, 74.15605591189477, 70.28378225141957, 52.73873413762739, 38.12169613376741, 33.82129576898391, 32.995491720015, 36.947840567558046, 43.454884021512925, 61.59823086953933, 63.57499168765161, 69.5230777802006, 90.70924251310288, 78.63457110620315, 85.4879088555613, 92.92951583862306, 77.23358677279565, 53.83013363807432, 34.01255838332638, 21.287918859912505, 13.706067531339585, 5.869610251918917, 1.8010497886327006, 1.3549235727517837, 1.5508180159714915, 1.1729642075877036, 1.4622451364994051, 1.5873601648115343, 1.651543501404024, 0.7194313310807752, 0.8371182483050131, 1.2243345091419837, 0.33381990187110444, 0.3892231966939665, 0.7177154779914887, 1.5381822230354434, 4.597568934963596, 15.078059665618406, 29.08651448065235, 41.56529003574003, 59.64433746953165, 67.61816301653462, 70.27542760295253, 58.1521737190985, 58.66412539635935, 54.45220978029313, 49.523167225622366, 53.29568324550506, 52.4566411972046, 50.92856814784389, 44.12389524521367, 33.07227996087844, 28.422702358615016, 27.942196323025613, 50.513648063905784, 61.809360288804584, 61.750363919042776, 63.14564120384955, 69.90004893272155, 58.77897631737494, 34.81701297144736, 12.298037640510067, 2.209157083303698, 0.8728051978734233, 0.3670177704864933, 0.2845386607993034, 0.13590577509134047, 0.04920580056345752, 0.13235624459001327, 0.21382014988170517, 0.17569946155192392, 0.4185073059653083, 0.1599528307035085, 0.2439973950986901, 0.30194816209616204, 0.2562494699152247, 0.3018549138740186, 0.32767967651447943, 0.31627412885427475, 0.14579387111288888, 0.293189907867101, 0.09582310494395996, 0.17872578464448455, 0.17076492069229005, 0.19675217058149078, 0.19116657756028638, 0.20179318234084115, 0.12930957420218375, 0.16104686554641495, 0.2443654390592729, 0.19122401883284892, 0.1847307801607155, 0.1753082970577863, 0.17733645355028493, 0.22119259702101832, 0.24100842645331738, 0.31021713128974365, 0.22035149376719232, 0.26910719852293696, 0.12036657020930322, 0.26606892445875757, 0.3542249908130015, 0.2181927958923963, 0.19524287011834884, 0.16723797446297062, 0.19473100081086162, 0.3648984648527638, 0.6064993070979273, 0.41537725456780006, 0.38209523885480823, 0.2746243798925031, 0.3324898813040026, 0.3391692793417362, 0.22352948694700198], [0.08732641611488597, 0.036603749970034245, 0.023707406700498635, 0.09012785409727404, 0.08896120944090428, 0.08563916874869217, 0.10583287104964258, 0.03922382046678855, 0.03619778465719954, 0.10083416266547096, 0.04590032269216834, 0.13173459488297665, 0.033107837962527434, 0.03333354661721857, 0.009703661311387776, 0.049465711213528156, 0.01583714509427908, 0.07785363933972775, 0.0682185668378107, 0.03225638103040476, 0.010874189075923735, 0.1234422293641875, 0.14209263988079565, 0.09433643471810127, 0.09292795908667388, 0.055444272865931836, 0.06302423024129483, 0.06803722616525427, 0.04380332936923351, 0.11749096725496555, 0.03127402265466029, 0.0343844622013069, 0.11312785137805248, 0.028158433081942703, 0.04968519540383451, 0.10440652258694173, 0.1744423725552136, 0.2117717227027301, 0.0784701562576717, 0.026717582574835228, 0.05300674963021471, 0.02768130203138196, 0.04803789186201269, 0.022479639719090155, 0.04542633643253677, 0.12279126147228865, 0.040767985591364485, 0.05654347880232719, 0.05779356575540959, 0.03974273395273955, 0.1173156020682185, 0.12290908579504299, 0.0100918035886641, 0.1026339713303793, 0.13410995774451764, 0.2325742733815024, 0.0885279713979652, 0.25057576146096955, 0.9032994196299584, 6.105276548093365, 20.65595442248929, 43.70373095235517, 54.26037842227567, 55.8571792417957, 39.85007286071777, 24.182127944884765, 21.927276965110533, 9.372756519625264, 3.9452461706053827, 2.738509865537767, 3.4583508391534132, 10.510093838937822, 17.39561953852254, 25.368729252969068, 35.863783744073686, 33.104863089899865, 38.548575524360906, 44.91481765624016, 34.71346632126839, 16.436090123268865, 10.403900569485081, 7.166632163909174, 3.676956786263374, 2.205474958304436, 0.8489556550498932, 1.8501563923012827, 2.0580330635270765, 0.5731790176322383, 1.6183444376914733, 1.9940813919228895, 3.4554649552991314, 5.321494811965573, 6.62567848159421, 8.459701307358282, 10.506954962207425, 8.166516394384447, 10.081091465488559, 14.831970161007298, 9.465327397469553, 7.4594101309776315, 6.6771953817336795, 8.003297746181488, 19.41338089204604, 25.352314133797925, 20.853137854606878, 19.441747473132228, 15.311451477389182, 15.458283443604747, 12.478375473330098, 6.084497792105521, 2.5147224674301767, 5.382375390298906, 5.207206751069715, 3.4569368247062933, 8.756917926572985, 11.160263957515841, 13.890198296116246, 20.52964625820037, 31.123813160004158, 39.545328232549856, 33.223667760049146, 10.392997360998585, 0.7756401213907427, 0.2867691104690875, 0.14561322758034353, 0.11888233614304375, 0.05077745675319626, 0.10161634609704057, 0.017747709963230357, 0.18121196978515197, 0.04350053311716165, 0.03040161704824817, 0.08312738861047453, 0.012996305294725443, 0.024807828801473784, 0.04884789194611292, 0.03639566133760157, 0.048781655984179634, 0.14142877872913115, 0.10066830462986424, 0.023306323282961405, 0.05020489029946828, 0.06335568967305365, 0.02757046060005744, 0.04510305881980927, 0.11132225874931582, 0.07698932362179603, 0.09196667962016598, 0.05423753882848448, 0.13595288949868373, 0.047749475080279574, 0.04962727532631928, 0.07131573008072954, 0.06653419230133295, 0.0648485996850556, 0.019887539092451334, 0.055215867581747236, 0.057636624983241486, 0.1885304536910788, 0.07647847321124808, 0.09676397582816501, 0.11498464166276878, 0.04990082617188173, 0.1216685213148594, 0.08117666828536219, 0.050093715619896693, 0.07248717810838454, 0.04912859039200891, 0.05862009801691579, 0.03757902586291875, 0.15117465818841613, 0.16660645754346926, 0.15904182958747112, 0.15141409130827074, 0.024671557081502773, 0.04534146155140573, 0.026652126107364896, 0.020056099503210956, 0.019682895940458103, 0.08555692154914142, 0.030963180564163677, 0.057322896656490145, 0.2113414570809372, 0.11885369977643413, 0.028858447837973797, 0.12178219344106414, 0.016750552684008595, 0.04093216589441703, 0.055373965146681, 0.09528290570503282, 0.0718306101137592, 0.09666836039433557, 0.05006535504493983, 0.13703166387013851, 0.0596525049167535, 0.0899031451873241, 0.03678537409512266, 0.09958756141244404, 0.1152025783554681, 0.14364891685545444, 0.10667314692851036, 0.020696246403179342, 0.018873524048455784, 0.0659590900965756, 0.09804080691068404, 0.02521621686736903, 0.123121744141944, 0.1157214190630663, 0.10086257686658252, 0.06327932219832175, 0.05330605635179147, 0.024157699775852026, 0.2144587454536269, 0.10727413524422916, 0.09018403898564079, 0.009840950970688175, 0.04343547310019213, 0.08575583627868084, 0.07327277829209644, 0.01646698523883618, 0.04747601233482842, 0.057316392570013, 0.047197941570512714, 0.06844572722911835, 0.019399537254245054, 0.138627685486309, 0.1840575880581333, 0.16709912868757404, 0.04214633481516954, 0.1209126836470058, 0.1398111074682205, 0.13622244519572105, 0.4302447535578282, 2.0862243636961906, 7.247175583916326, 21.02083683013916, 42.6093190716159, 54.443984570041785, 69.8775972858552, 64.89794831122121, 53.491484042136904, 32.96288897914271, 16.37356460094452, 11.098809242248537, 19.666363962234993, 23.529582831167406, 29.13543232025639, 31.600893005248043, 39.20743173168552, 49.04239054649107, 65.471289004049, 55.10563742729926, 70.90385406248032, 66.96642198870259, 64.45476755019158, 40.73244140994164, 14.894600606733754, 6.591109652673045, 9.74773903046885, 9.131255207523223, 10.512684564436636, 6.162592182236334, 5.305514095291015, 3.634019825727709, 5.8419624451668035, 7.342065563124995, 11.575010476573823, 18.434076847568637, 17.354299329942275, 15.420299210856038, 10.97052518398531, 9.16312740695092, 13.693964077580361, 16.198216022983676, 12.461857391941933, 14.277746119806844, 9.737829162228493, 7.902387909350857, 16.831204199021865, 29.915393667836344, 37.539094724962794, 39.02655555355934, 41.99116529956941, 36.01760341275123, 34.03109158239057, 28.28978500058574, 21.64944567987996, 25.73926575722233, 21.96130548754046, 19.175230264663696, 11.551768472117763, 11.183067637105143, 28.688319383129, 41.56656480604603, 45.77965713316395, 52.841284505782596, 47.23953193233859, 25.39931001201753, 5.954254019644953, 2.0160764503863553, 0.3725438384759811, 0.14391448889528552, 0.1368162859111063, 0.16553932770846352, 0.0866028154268861, 0.10416321306219024, 0.08221018218225049, 0.042617785323771744, 0.014016834958907098, 0.031183080357168953, 0.05582870727765465, 0.08652209274230466, 0.024067481431449135, 0.06249227793887258, 0.09631738487270572, 0.06081387888820422, 0.05484063771643466, 0.11595389610456845, 0.07680969132531075, 0.10980899761160536, 0.06342464524711813, 0.13744260875448105, 0.13516976377896725, 0.0735107711666534, 0.14689276295323528, 0.08752497078310098, 0.17299647352868514, 0.059436740083319534, 0.06791045393554435, 0.039095619483099836, 0.015047570829459978, 0.025709554507967927, 0.028092448013804616, 0.1742328475079229, 0.13270009549394732, 0.039974774324124863, 0.1271448012501482, 0.016993864123979886, 0.13145625981832706, 0.20297553179965866, 0.1765033482543884, 0.1923923642044106, 0.1018824850419356, 0.11570960598727388, 0.10356181105899234, 0.17954643335073225, 0.20970356109882557, 0.10651904834254135, 0.1287791962104459, 0.03926589784602966, 0.0823982108023859, 0.049984459990575436, 0.2378484516614868, 0.16271571148066752, 0.1286486854716655, 0.189519350627257, 0.17573375164741473, 0.1675799867558864, 0.4692266166450516, 0.3567543373473229, 0.2609039596732586, 0.2752001715763923, 0.22045675424798844, 0.25916371434446306, 0.1418637787742961, 0.1483514096828238, 0.1421116388613178, 0.1409298103422888, 0.16653914905844197, 0.19375335004541183, 0.1441681406070148, 0.12602619030663084, 0.17583463010528397, 0.17489513051846337, 0.1872576905354377, 0.2117209310733503, 0.2755530316743159, 0.12278293409655172, 0.07899848879465173, 0.14816903479156956, 0.18353591282521525, 0.23344839502486492, 0.28907108210748245, 0.11531374537416043, 0.20711798371086199, 0.16122358670878797, 0.1734137616210407, 0.37634256205731825, 0.5129781125053283, 0.3828877108472009, 0.1676414270074137, 0.16002092059821854, 0.12381100876917764, 0.1831361987898427, 0.11832621759705006, 0.14906711966520356, 0.13727523386478424, 0.26796195836317155, 0.2562454862580184, 0.17169406277037438, 0.12203895546976598, 0.25041741108702076, 0.4024147710973217, 0.40664789717524286, 0.2861885383965508, 0.19791185915950807, 0.1775579448909529, 0.24719143015963418, 0.2865308264811193, 0.5818728898321429, 1.6436386997661285, 9.607362304964374, 30.60316754925636, 66.31564586393296, 89.45727686728202, 92.86378475927538, 82.14455112334221, 67.54363798326062, 63.659330491096746, 49.86357012102681, 39.50091523508872, 33.7160821114817, 41.31517617933212, 43.12080790919643, 67.56824693372174, 68.22318861561438, 82.75491114585631, 87.71062189532866, 102.01111285917221, 103.50536331053704, 106.8531297868298, 81.14427612673852, 42.09619068330334, 26.573193034818097, 22.27585800232426, 21.61487783155134, 12.854087545025735, 6.058151231658075, 4.062423302281288, 1.4737300815120822, 2.5683147916870737, 3.638614392088306, 6.58842969325281, 16.364926561232537, 17.117409744570335, 20.05173683166504, 21.72811273605593, 17.93936594840019, 20.83199824056318, 30.24118377316383, 36.29245565783593, 42.653237850435325, 42.25632144558815, 46.56886546842514, 44.75505559675155, 58.756987510188935, 73.57696502439438, 76.3745798603181, 74.3444787302325, 64.9628556928327, 63.98824476426648, 50.86091510711178, 34.85704468142602, 39.795261659929835, 39.28924060636951, 39.304133845913796, 41.49522473735195, 47.971230476133286, 48.0855401100651, 51.729543593622026, 63.695467287494296, 64.65862881752753, 47.29941868012952, 16.70571973246913, 1.7577053918953867, 0.69315335082431, 0.47763737339165907, 0.2916671395782502, 0.19449270150113493, 0.2889925734170022, 0.139330402617493, 0.40037578212157376, 0.22228862369252791, 0.17980330263174352, 0.12454917278861809, 0.09686021945409237, 0.19659516852228873, 0.2921289373790064, 0.11946691485542445, 0.18420542770576093, 0.33434369150669346, 0.2588100268715813, 0.21215487391717974, 0.2734611826317926, 0.16921442002058032, 0.2367509541011626, 0.15877723814018313, 0.19642871293810107, 0.14524830925849178, 0.2212790730259111, 0.3296468370864469, 0.18280023859152872, 0.2655024484040276, 0.20029537319656343, 0.23698626566798459, 0.1428936767361818, 0.11806206281987891, 0.17305308742628944, 0.19541376901249732, 0.2557972788570389, 0.459020915891855, 0.16075042016323537, 0.42810494741124494, 0.22703599395050159, 0.4044557212581558, 0.33542543829929444, 0.2721797013955732, 0.2748832869673929, 0.1620148636040188, 0.25250590466443573, 0.33670943230390554, 0.38065888528381625, 0.4779439617789561, 0.5137035364825879, 0.3443667568987416, 0.23880785421258022, 0.25816565499671046, 0.19693039327619538], [0.09664966784898313, 0.07404293414325484, 0.06489215178355094, 0.09224694522638476, 0.05979375620823234, 0.07105250993082601, 0.0994591574154554, 0.15809699802869753, 0.0654182703264298, 0.16763788768120352, 0.042890144902611935, 0.18507283841890676, 0.07277405505338985, 0.10151368265430774, 0.057726513909836935, 0.043112938592751185, 0.06493043319712724, 0.050111772312271985, 0.009423972186332029, 0.026584057280072765, 0.044479470910324205, 0.13861357414674375, 0.11263115061146599, 0.03038495463589507, 0.04393740241686183, 0.10648573883959364, 0.1915017103836421, 0.13126654580475824, 0.09225633746433644, 0.02169405294191693, 0.04543423096859648, 0.11259356633790078, 0.05563060843175458, 0.032949391827588125, 0.1555179630316073, 0.08744632419679435, 0.1377900909151762, 0.06541903641435408, 0.046355053331823125, 0.061672529385935884, 0.07033044907955394, 0.08357993972998473, 0.06462748372747053, 0.05407889351068486, 0.0639549542909428, 0.06322226013928171, 0.06034454661271265, 0.040272866796341636, 0.08303485285010069, 0.03534042118718067, 0.08746340029662655, 0.16510224390414455, 0.009388788640799542, 0.04596298485393486, 0.04946307587106863, 0.107663729258122, 0.029258146551587892, 0.0133524174358876, 0.1216820351058437, 0.07549771212882574, 0.6005821052578189, 4.262833864458146, 15.647875128253816, 31.330233773877545, 59.19923866948774, 48.55557733966459, 31.188545996142974, 22.181452435831872, 15.683401996089568, 16.59342227443572, 16.54323947045111, 17.0801374220079, 14.396673364024009, 14.830401212938371, 18.364497923081924, 29.516863207663263, 24.471232121990575, 35.275616491994555, 32.56951447456114, 27.222670855060702, 18.38787721049401, 13.627319085982538, 14.55868294162135, 8.116472834540952, 7.604478011208196, 11.242339553371554, 18.341489299651116, 22.938871922031527, 22.40154447094087, 42.79214466771772, 40.26468699978244, 36.12021261645902, 19.929327503327404, 19.56055018209642, 32.93887230657762, 23.457099391568093, 16.441557907289077, 30.01126620077318, 25.73460598145762, 18.533463824179865, 19.28028310498884, 22.26274944120838, 12.95358140622416, 14.43000860752598, 23.177630516790575, 16.70058927228374, 9.74772039921053, 2.399684253238863, 8.128198269874819, 10.317182848530432, 11.027991829379912, 13.245171385426676, 15.72054978339903, 14.700962997251942, 9.758102913056652, 15.890086389357045, 25.769840632715535, 34.39240463318364, 31.48677948982485, 15.67515423220973, 1.953123267139158, 0.16688635542748437, 0.14302521403278076, 0.08452716914396133, 0.07835113683775549, 0.05308631169159086, 0.10299192591299934, 0.062137828208506114, 0.03574966152589168, 0.12992170909720083, 0.06745637064018557, 0.07227596000678117, 0.03127639561200575, 0.05420571170567025, 0.06119201222674982, 0.03287571332147045, 0.06939941476429663, 0.07920275081790264, 0.04062894063310758, 0.09672969339355346, 0.16829796435852207, 0.10127634095448641, 0.08889083660417989, 0.03765340150904752, 0.02462765449778207, 0.05721110527613952, 0.054338559012619726, 0.09674437163818268, 0.07849221958989099, 0.0087705020597505, 0.045020053193213484, 0.07773976036978346, 0.05215590939887109, 0.0843230450165368, 0.06467166401806378, 0.03053802091838612, 0.021525260789560217, 0.13063231693400493, 0.1321348605016547, 0.105015256051575, 0.16238160521513031, 0.036746150393399506, 0.19753063848662764, 0.18074833337337742, 0.023308562174920115, 0.04178222471607789, 0.04623876118491735, 0.011906810480380252, 0.019044738953873035, 0.05484064920775352, 0.0635386812650869, 0.024779592715804617, 0.1810327205326288, 0.16723337793542495, 0.2001292853345794, 0.061815561831838665, 0.1434958831317002, 0.11116646710903415, 0.08818847187344106, 0.07879264096939757, 0.030872722817284447, 0.06037076980236077, 0.068799062301555, 0.12009431788277243, 0.1246827785226126, 0.08449041224535435, 0.04540512345791344, 0.11908905730853159, 0.0227730379875509, 0.05631508500946145, 0.059494828700178096, 0.057878712597753734, 0.1637951446877372, 0.1464420427838641, 0.021484307644347993, 0.1386036456472451, 0.08226396155453498, 0.2879430329607379, 0.09935728304328457, 0.04798518118238257, 0.06185354064068487, 0.05309612527790089, 0.058013413837479974, 0.1017703221089417, 0.05656538891696161, 0.0909040313995173, 0.047803894135980844, 0.10741793760849584, 0.056269479795329036, 0.02882060309451434, 0.031219639988135428, 0.0527519258039613, 0.05261951516712866, 0.24856536288655576, 0.09270920267989559, 0.1942180283367634, 0.18836919218301776, 0.02376461431624428, 0.048207204954157916, 0.06072554128965544, 0.09559275762688729, 0.16247158990271632, 0.0329940049578586, 0.04064016382119829, 0.038993668502136584, 0.04663768998016754, 0.054848773570190516, 0.10594934705765018, 0.06913448623832195, 0.0685875913909366, 0.04217367649318711, 0.0009792676897749546, 0.040455486835731615, 0.12341317164921954, 0.4687530517337784, 1.1182775420527304, 5.597570836544038, 19.534954755536972, 40.137315873176824, 62.587750727130526, 73.38470612802814, 65.16335941130116, 52.59211594058622, 36.4680640928207, 21.49745971925797, 17.374752529205814, 21.950783729553226, 30.331288460762273, 42.86128820911531, 42.305194177935206, 47.15397719414004, 55.24470113938855, 59.733767509460456, 74.4859900013093, 71.65092437498032, 66.38684472730084, 58.857804190727975, 47.45830212869952, 49.89279570118074, 51.437123052535526, 63.15613746643067, 63.98329473310902, 61.94384267253261, 75.46337404558736, 67.01012503716254, 90.3415987568517, 80.4855062115577, 71.17919660383656, 51.048133757806596, 47.73419772425006, 63.04125908882388, 42.0797755641322, 38.24640004865585, 51.47717437436504, 51.98006929889802, 41.93156096243089, 37.93520704392464, 45.65491399457378, 37.1331411792386, 35.66952443891956, 48.923538807899725, 45.61690622760404, 40.510972622902166, 34.509648200004335, 37.87102922316521, 35.38982022193171, 18.93378484633661, 21.899006482093565, 20.103276775729274, 19.888891789220995, 25.679020112560643, 30.391494881722238, 38.54329601410897, 48.6731307737289, 47.568846287265906, 32.457838712200044, 10.366067347988006, 1.5675593047372758, 0.36536881219475503, 0.0883634080509505, 0.06072135844958886, 0.04636702728607962, 0.10353147397719084, 0.034372706582108815, 0.08332843306444346, 0.04283468396733365, 0.03903669966084342, 0.08865960828599431, 0.07962351694943444, 0.02425217182345448, 0.03044392999952599, 0.05208655162864635, 0.0733506434687203, 0.01714352706086732, 0.03386002905186146, 0.11567324745438753, 0.07707319492774625, 0.06621805845849937, 0.11972685614901206, 0.05585793353196594, 0.023021821210521366, 0.013785311696870674, 0.04115457271015452, 0.06881253778814309, 0.092514447807785, 0.18613934006181457, 0.055951101314877315, 0.13941551498588056, 0.21621130947624484, 0.09741468325016961, 0.06398387794052401, 0.05761423223321477, 0.030277813409244826, 0.06476733307804793, 0.15888167124602104, 0.05375684546907583, 0.13374090254787477, 0.13458343072523996, 0.12820439277997903, 0.2574838673876178, 0.2919906738304323, 0.18572188343011564, 0.07166406259902063, 0.08237384154551453, 0.04786310507164848, 0.028796325768193895, 0.1555964257568121, 0.08601709524349821, 0.07705284763247737, 0.10264424456944389, 0.038699142169207335, 0.0992136798618782, 0.34651728827626477, 0.3305995133855651, 0.22408157587051394, 0.1983504904614341, 0.14350414155952393, 0.18771317577169788, 0.30756033836833896, 0.3026798986379178, 0.39941648682278974, 0.32269841961322293, 0.17489894563632627, 0.28441188856959343, 0.10092462232757, 0.1632758749709014, 0.16282304039885923, 0.12806272014014183, 0.19164383501535465, 0.3195266317456, 0.09505216002223954, 0.15400303948310115, 0.13737784368136238, 0.344288585286948, 0.1923838299849341, 0.12669721438038734, 0.23327453903132872, 0.304005230746923, 0.24246160331512653, 0.23226901798719363, 0.2516727687250222, 0.17782238312065604, 0.12455874888767159, 0.23882017290640264, 0.1634953131959323, 0.24596236465919405, 0.29809952022567876, 0.15933331072090134, 0.3705352478690686, 0.3098358033645538, 0.15954626784209283, 0.3252235679857193, 0.3540782390102264, 0.18215372167046995, 0.20889060391533762, 0.1595163750912874, 0.2317881139536058, 0.4138414627842365, 0.11448721311265424, 0.16513046658327504, 0.2140925707475793, 0.1653166259488752, 0.22239098836097027, 0.29189619986761, 0.24777793175270482, 0.1523090198996567, 0.11694920519667289, 0.191170729756836, 0.21785308186325336, 0.10696148710145105, 0.2815638801022884, 0.33565158745454204, 1.3928321773006072, 7.471848457090317, 25.597707417703447, 51.29499596934165, 83.89181014030211, 89.51435519802956, 76.6382102043398, 71.45618654066517, 59.932572841644294, 58.09541310033491, 55.0046677743235, 56.09810690726004, 60.9525812825849, 59.35369768450337, 59.61037366620956, 77.52774884623867, 76.86586456914102, 86.10582336302727, 78.759216185539, 72.8039207766133, 70.39802520505845, 64.19454574584961, 69.70444817696848, 70.35341216671851, 88.05861457701653, 85.78290247148084, 82.46286715230634, 85.74348265124907, 75.13140032368322, 96.23484226965137, 96.63302560006419, 84.99747922343593, 63.63294862931775, 64.95517961440548, 93.28373724414458, 68.30820206672915, 64.792028627088, 79.32323732683736, 79.33932688928421, 73.76497991623418, 68.67273146106352, 68.67528100167551, 50.73231627864223, 41.395196453217544, 61.59679920442643, 61.368289762927645, 62.75406706717707, 50.65277061154766, 62.37010232863888, 57.877858838727406, 46.07905164841683, 46.457944762322214, 49.59697446515484, 55.57181896701936, 49.32527188331851, 45.881062169228834, 58.401048106531945, 60.15584199659286, 48.105367691286155, 21.726763440716653, 3.327781264820407, 0.5085208291007627, 0.284686025472418, 0.4369704539497053, 0.31763666219288306, 0.42622821585785964, 0.41411268855294875, 0.18512329296959987, 0.19557625626123723, 0.16441861768403362, 0.15194483702221226, 0.20142061846150508, 0.1659626985389379, 0.1438243203465977, 0.24228137347006032, 0.11430126825167287, 0.19914279391448345, 0.23761223611091417, 0.1647687198654298, 0.36537414416670805, 0.43808229267597204, 0.17233178500206242, 0.20834076729032303, 0.12680941561777748, 0.14790542393682465, 0.10987521059090093, 0.2579188214675073, 0.2999131874211373, 0.23290379844125242, 0.27483437991430687, 0.13067046811263408, 0.2790027868843848, 0.20784434231538929, 0.1688274077229923, 0.12479491847296878, 0.37261606524548224, 0.17330113137441297, 0.3147440980519018, 0.3017663234664548, 0.29778704828312325, 0.3885749024489234, 0.3239669692852805, 0.39036748690470574, 0.3291892680910326, 0.2391550452598641, 0.1348280425994627, 0.11111107129122942, 0.17914111155175394, 0.17596834309158788, 0.1723010495545403, 0.31883384311391466, 0.29561736470749306, 0.4226733533845794, 0.47413258242510986, 0.4632326221514133, 0.23038712300119862], [0.03232911341793595, 0.16859246387837395, 0.06578950887365688, 0.07997407112270594, 0.047008786801128626, 0.06961259405098616, 0.13239082579891528, 0.13679301215996667, 0.1455473593406139, 0.08583904108813695, 0.10091487768917315, 0.15850550675344083, 0.09966381014354768, 0.04093998765212394, 0.07500985967776469, 0.04308579609759393, 0.07419996684597385, 0.040533034085866906, 0.057233118812643716, 0.03388813681780331, 0.03190813661222497, 0.08069581021704982, 0.08166312645640104, 0.0872841663658619, 0.13101320052819868, 0.12371204553111909, 0.16259238664661685, 0.2861056476831436, 0.060534149543532444, 0.048593428181183916, 0.036008461348472104, 0.1404624200996853, 0.0746195225585853, 0.042974345626369606, 0.009329341175485282, 0.08866679419072405, 0.0605529876455905, 0.03662109037020034, 0.05201314125330218, 0.023330416748180025, 0.045152260816746184, 0.04172122496510706, 0.008950062535492884, 0.07999123149220982, 0.036205441706002726, 0.07657614942159384, 0.1100073607578393, 0.024255778182358034, 0.1032877584258395, 0.09991264316223322, 0.04926866190808435, 0.06884376353193676, 0.03170027780616957, 0.05298837501135084, 0.11311082890437496, 0.09056492257983455, 0.03287200545591693, 0.15956131380892571, 0.1115298455941581, 0.04945987745398476, 0.02391681108894127, 0.023224625751496326, 0.26485501217745966, 1.4204182067225057, 8.561245587564285, 33.085949420928955, 47.88917841449861, 45.84914976550687, 43.23769454033145, 41.36743391713789, 34.39581317286338, 25.230524539947513, 22.302292816100582, 31.076146556485085, 41.3686223953001, 37.56027944626347, 33.99020087334418, 40.41088942558535, 40.23706566902899, 25.65791383866341, 24.677293838993197, 23.77378567572563, 21.454333259213357, 15.056975945349663, 15.898981344315315, 28.10139552239449, 38.19063571191604, 43.575967588732325, 54.71628335214431, 68.55577422726539, 67.83168115923482, 62.963980551688906, 52.471157889212336, 58.60410528798258, 54.756617084626235, 40.05014511846727, 34.40330097752233, 13.650105114906067, 14.575493239587354, 25.471740499619518, 25.897551044341057, 16.90954177610336, 16.16950623450741, 17.35651154671946, 30.345081475473222, 31.315973997116092, 30.51291185040628, 26.432005359280495, 26.110068982647313, 23.380883816749822, 20.0398697007087, 23.827243658804125, 30.076775666206117, 33.375228143507435, 26.215308135555638, 23.859169790821692, 18.1571751640689, 9.548027630775206, 1.6638403770423706, 0.07322127420094705, 0.14048586239016828, 0.044854290918597294, 0.0603343538128801, 0.030652261864874634, 0.09137295381796938, 0.05330470037616549, 0.04456814558755967, 0.0491132877857214, 0.046572373323743387, 0.10207791407141956, 0.046913883829068755, 0.04527080526214935, 0.008874070443843883, 0.04711681285933141, 0.04277628508486575, 0.09453080654624971, 0.0467437778359219, 0.03249809709227374, 0.08017935970377538, 0.03159163504718773, 0.022970981700646303, 0.049340486481425264, 0.02213644190511156, 0.09281318379385818, 0.11632402382430532, 0.04418983987923111, 0.0075532855454742195, 0.05493768190424289, 0.07958017935555789, 0.0510954981549613, 0.02629797706650871, 0.04028808896339709, 0.07597778112657609, 0.06796762707733339, 0.08143286340900006, 0.11470863550540902, 0.039017838576147636, 0.08860083402044351, 0.13537506002091593, 0.08417950312216436, 0.2332963725371707, 0.11598073982543523, 0.04358845702823132, 0.07961779427264007, 0.10612926280666744, 0.05874784317828956, 0.028494025558053006, 0.01573669468803752, 0.11568247881387511, 0.08933137546503737, 0.04837304766800615, 0.10720863472670318, 0.21466652382045023, 0.31972851123540635, 0.11744529309291994, 0.1473884678055202, 0.12382810019076833, 0.08947224371255406, 0.03461729547369384, 0.05410739581190771, 0.012088258405246083, 0.05544541433693902, 0.1209531867155625, 0.07629380005622104, 0.06431675080450312, 0.06879812767428738, 0.02235496657029275, 0.0820052613233847, 0.03337004304593129, 0.032955815474833214, 0.15243196168974524, 0.0831434381524882, 0.08435388005548909, 0.04845764675748445, 0.09389964968807275, 0.0802232642027159, 0.06983386322615609, 0.051523634052324685, 0.05599088043034558, 0.10523678569663918, 0.10517940571111058, 0.09149748141006117, 0.07357851632179753, 0.1669962277575847, 0.05131749894409891, 0.08324162764174324, 0.03778500392312004, 0.008970159894576477, 0.02989390185253034, 0.08284573638511282, 0.039934654299530296, 0.015144514468228145, 0.05972954271841915, 0.038517812987969774, 0.02590324643308357, 0.11307327527432673, 0.06405911160512798, 0.04172426250372683, 0.047454010289643085, 0.0834387573864191, 0.12863512571540572, 0.01790808089407942, 0.05394840575454216, 0.05596089191854962, 0.0930463349927337, 0.03980058508234159, 0.013106653556948709, 0.032407196929618236, 0.022333701884734537, 0.044264364912505114, 0.06647780823010592, 0.06484693727425991, 0.057799748084958524, 0.0805410298128282, 0.021916563179524198, 0.057513989628322666, 0.19209139890247778, 1.2832163947243846, 3.144770827024214, 10.408966310562628, 32.53040844394315, 55.40343946026218, 67.8094256308771, 67.71397083036362, 55.32361530488538, 56.35213921147009, 43.77888356485675, 42.19737998900875, 38.7786421468181, 41.3549215562882, 49.03326711347027, 53.8537698407327, 53.0729083091982, 61.05537876006096, 65.54762224997243, 62.59537189237533, 61.46293263281546, 67.077558425165, 61.657890119860255, 65.74874570292812, 57.328970201553844, 73.07102634060767, 76.5397979367164, 72.82848265863234, 79.39867234999134, 103.90651195280014, 95.1466355785247, 104.99265547721618, 96.63437489540347, 99.85382495387908, 93.84240827252789, 83.15427118732084, 76.69501396917528, 53.960254346170736, 50.44042133515882, 60.20152584198983, 54.22037416888822, 43.80273157550443, 35.732411799892304, 42.551817124889745, 43.93007132314867, 44.73802466546336, 38.5667400206289, 32.80438207810925, 42.81518074773973, 41.30054181621921, 35.966063468687, 36.062106624726326, 44.835636769571614, 46.04872780461466, 39.94861456655687, 38.89053167835359, 39.511474255592596, 26.314655888465147, 10.827607743201717, 1.9709424722579219, 0.5860644326575342, 0.08079726324086228, 0.06941062263062886, 0.005856801074133405, 0.06820224150414429, 0.05356889345773286, 0.05616451425838375, 0.07882942851152151, 0.01726087257866898, 0.010880788923391413, 0.006097677312115388, 0.054767962785497795, 0.019842110078541503, 0.031615770647242185, 0.061153880200318755, 0.045686691413603486, 0.05015132543180258, 0.07981586630546278, 0.042124574087680354, 0.05670378270048288, 0.05059734948219792, 0.09153748652146709, 0.017558762037585822, 0.034278634815446796, 0.0895091002025912, 0.028792583428683783, 0.021552163882241137, 0.021291651853149938, 0.05444631694004901, 0.07029408288578834, 0.05675033403320178, 0.033329413572867075, 0.1472685750453703, 0.06771958312920986, 0.11540721576180189, 0.08489205682229611, 0.08480815487282892, 0.14708710413786674, 0.13440724582441393, 0.07606174436307724, 0.05323195649731544, 0.0574178341025066, 0.14851112369327776, 0.1860307241159101, 0.20635142081206848, 0.11832562004846912, 0.10954476622564178, 0.059238759981047724, 0.10683157391125157, 0.11800493564336531, 0.2125455634368043, 0.10700799629933412, 0.1290039664074298, 0.1836201058880937, 0.090813847529071, 0.09051157221678766, 0.36392620734630093, 0.3307724041083167, 0.14225076042836712, 0.25269879028201103, 0.32251826637694914, 0.30720855079350934, 0.30677758037082614, 0.2696108860113929, 0.2516824980416606, 0.2646650530157551, 0.2646802522001728, 0.28264501402454995, 0.10431018703046346, 0.10124247986823322, 0.22433902737834763, 0.19981785527160092, 0.10094994919434672, 0.2244001611947052, 0.08916324980917478, 0.09941000521423356, 0.20936959272911473, 0.15275474517576157, 0.31446113581618956, 0.3453631308530608, 0.3596593427561945, 0.3162126886027475, 0.18171116799837161, 0.45779735090271123, 0.0922420499245486, 0.15420118046383705, 0.20871287151690454, 0.18856872744377584, 0.12972821060928608, 0.24482271694127591, 0.12307033964222479, 0.1865096363208948, 0.11146994517935861, 0.1047706211947145, 0.2392542996113339, 0.30523434221263857, 0.2164818151223083, 0.12847145869126245, 0.13999853853977498, 0.2460212921423297, 0.32930329261768254, 0.18357628565882483, 0.25897400033089424, 0.166797305367166, 0.22653549338781068, 0.36282656473978875, 0.17708817977578412, 0.11927023710262392, 0.16614772409441012, 0.14043321682801171, 0.21210279526008716, 0.19070966740048703, 0.17498137669697886, 0.31292540531965995, 0.22255998735706653, 0.14286942239249908, 0.2431410313734124, 0.3630859927544671, 0.7157314941287042, 3.044806036256975, 15.075651330332603, 45.01419090455578, 73.54342875942108, 87.49635850229572, 87.75539182847547, 90.54951575494583, 81.34653706704417, 77.59446051812942, 67.50854845969909, 77.16765957493936, 88.69349725784795, 81.26415944868519, 85.5972017780427, 93.04941485005041, 93.33117438900857, 78.96588586991834, 70.63401852884601, 80.20221694823235, 79.12805234232258, 88.63440282883184, 71.51744611801641, 98.56767977437666, 100.46519694789764, 91.29064759900494, 97.82336296573763, 113.35276388352918, 97.29701226757419, 103.51689507884365, 95.34145186024328, 107.10571473644627, 111.97660815331244, 97.74930077214395, 80.23747121134113, 65.22226164417883, 65.56579851335096, 83.02372686324581, 84.09089396076818, 67.62083807299214, 66.0545729052636, 72.31751549628474, 69.51822188592726, 78.0236227281632, 73.79463303473689, 74.72893376504221, 75.78867189345821, 76.0756560294859, 58.587066511954035, 59.01102373676916, 68.53696253991896, 70.47861422261884, 58.77270444746941, 47.06614355887137, 34.969824590990626, 14.360479693258963, 3.5906469918066457, 0.456672212890079, 0.3978541883970461, 0.11871844695340242, 0.16605311223576147, 0.1441934674737915, 0.24303741032077422, 0.07977056752650008, 0.17169758677482608, 0.18727304293744026, 0.17027315353193592, 0.14179907498821137, 0.09727235943559678, 0.19380061767033993, 0.15494436235918155, 0.08834773389201972, 0.264699220537178, 0.2514213846335488, 0.13293036620222753, 0.19312587807015066, 0.23675184276315475, 0.12824743926044435, 0.11964535205474786, 0.2318908463442518, 0.2049761857356756, 0.18029655600267072, 0.24094392185009297, 0.11421764209385842, 0.13819178145739341, 0.09533925147186365, 0.19214882485328183, 0.2504072834046618, 0.14770093974807572, 0.23194562163083787, 0.1670699713811759, 0.15388176776468754, 0.2064944953928071, 0.20631296319826958, 0.16312517015443695, 0.28305012131890944, 0.24477782418891308, 0.16479666675290755, 0.28309964124233494, 0.219246641762795, 0.17885706147118924, 0.2644726730162098, 0.27797773059818054, 0.18222633148393325, 0.1242622115739411, 0.20002616989997127, 0.22807002878717839, 0.20141223745961345, 0.2988193977263666, 0.4200331998928901, 0.5037153740563701, 0.41565727502588307, 0.2022951537923467, 0.25520069554688474], [0.03900365062778996, 0.039595181588083506, 0.028380194468603983, 0.008499576022938616, 0.031964999488404686, 0.08385556284338237, 0.08275287120693153, 0.17052158052402158, 0.026082457381210504, 0.13363273093296638, 0.06042814978788938, 0.031987650793105844, 0.09901065890106464, 0.029217480689347274, 0.061971656076850436, 0.126748695488899, 0.05455571812607589, 0.032767721737224254, 0.01855691714632896, 0.11378671763645065, 0.0209251630510534, 0.054630530442321495, 0.0497749847389998, 0.05019878457871176, 0.06865855411536272, 0.08771363525621353, 0.17425013045149465, 0.14248478496747632, 0.09934529376726958, 0.02132490006906371, 0.0542031797850805, 0.14814006134627328, 0.05577542586252094, 0.1344529506299765, 0.0397568644445029, 0.05346234211878431, 0.018290868216765024, 0.0750442953299611, 0.0345437663547214, 0.08388553986385947, 0.1194114424288273, 0.07519638676556849, 0.11929053077173811, 0.11544791801321892, 0.13648109180071663, 0.16366305580783277, 0.1179706225652368, 0.06715483843318878, 0.06335197414662089, 0.035855427624717835, 0.023758477951970794, 0.06318361100350177, 0.052840500889766606, 0.02937201403021332, 0.014062611585212572, 0.03424552449535939, 0.040937080348451296, 0.08627512897815436, 0.13138623938204783, 0.060540419973192684, 0.07473196128323194, 0.045875007316710494, 0.008895471110008657, 0.06886532124612602, 0.013374129325271615, 0.5737584252511302, 6.608649021194828, 19.96846491290677, 37.97020243060204, 60.690923890759876, 67.53318094438123, 74.4601337371334, 52.792560823502086, 44.55141398214525, 46.79162079288114, 47.28958529810752, 46.644767253629624, 46.94078853053432, 50.66711471926782, 49.94848159051711, 58.096134816446614, 63.50167866676085, 53.90210128599598, 48.19841023414366, 50.042767524719245, 51.12275685033491, 58.30351444982714, 59.48930578847086, 62.3309806085402, 59.907026444711995, 60.72692732657156, 38.63077271369196, 29.09833650435171, 27.782447991832612, 69.48547793972877, 61.61211213757915, 28.89241207030512, 42.682016280389604, 40.03511851833713, 50.576794301309896, 59.381060138825454, 41.233673249521566, 36.691619580791844, 41.93613444605182, 39.19315822662846, 34.831058979034424, 37.01543477273757, 36.646826113424, 37.023189298568234, 42.46608195766326, 45.25806034764936, 36.27059236649544, 28.103468495030558, 19.050898974941624, 9.072933485431056, 2.311601057167976, 0.6238023528168279, 0.1086416558152245, 0.17053710146536752, 0.13855746586716947, 0.059943124201268926, 0.056298939706457246, 0.07809268175474099, 0.031231292185463735, 0.0175488431141862, 0.06284567429834316, 0.0493513381168727, 0.04927798136768322, 0.13124457440308987, 0.03214496886357665, 0.12525877705024135, 0.04512986423627985, 0.03528787521645427, 0.012720958930590462, 0.07573700735285398, 0.0705299996620705, 0.015341405768037565, 0.06112971778718695, 0.04851150273856136, 0.03350990771826717, 0.11941868195971174, 0.039351335801785035, 0.04335059055818185, 0.057872633690074574, 0.02513640199697787, 0.07959126464782224, 0.036087816566108696, 0.056318946092599825, 0.05516972993650744, 0.04279737165498157, 0.030705849715178053, 0.051454827865405436, 0.03273083460367015, 0.0714966111005314, 0.10038771726671727, 0.036701043136417866, 0.028143854428743644, 0.0981396092702785, 0.09433575289984865, 0.0806091656728137, 0.05872627780322106, 0.011572406398162488, 0.049771138977619915, 0.05384940804252702, 0.11950770903739238, 0.1372090438681264, 0.0340194825924212, 0.08989199094714657, 0.11688306882616975, 0.055182236321871324, 0.08735279252211894, 0.011890931392929727, 0.05756600699838131, 0.09749830174710482, 0.026863426563420126, 0.004709307179455796, 0.034999182643068415, 0.023376171349457676, 0.037893481973198154, 0.03481452864023947, 0.019292524347322124, 0.10077423926803375, 0.07388629980625645, 0.1054164409757622, 0.05935871785867119, 0.10695868321964819, 0.08965458029941206, 0.03491001383912179, 0.1035517446636673, 0.057792696245615525, 0.061857394062944, 0.07743758464893026, 0.09492450679141669, 0.059874521027649605, 0.032067450341738524, 0.09988267380263537, 0.05194349620010584, 0.09683563569260221, 0.023427784608136264, 0.07983081268086549, 0.07731458157180779, 0.0272629969573069, 0.0723735059821798, 0.10008773255732753, 0.20530342785341127, 0.09175418215172906, 0.02439687051059258, 0.07196540328403635, 0.06288625014525268, 0.12714971187374285, 0.047561465612342285, 0.0917406223954693, 0.011224425322706661, 0.04051829072376413, 0.039280426703513636, 0.07366146832223862, 0.04891998465022734, 0.013378324614266955, 0.017864603489156694, 0.03503444183978342, 0.08355419917572891, 0.03677641852728782, 0.06073248204624942, 0.04488295792872387, 0.04961657690845671, 0.06044355964648628, 0.019975756032152042, 0.07102258653650362, 0.07322356480384067, 0.032575245976688406, 0.06138162664888848, 0.029951850658342726, 0.08592913302803233, 0.06236791505568451, 0.029449178236386472, 0.027040932965915532, 0.01829842567413805, 0.035338448510775645, 0.11421492248172722, 0.30007881563036676, 0.3708296094930941, 5.904778222883902, 22.49975081413023, 42.126879307531546, 62.57242602686729, 81.54249083611273, 82.2007586879115, 74.20405003332323, 62.423234754993075, 61.54352949511621, 64.8971716819271, 60.97676269469723, 60.2030751782079, 65.5344940770057, 67.94584566547026, 63.535658159563624, 71.2724313428325, 77.72293383075346, 76.12248912934335, 69.495817307503, 64.81145220418131, 70.87553454983619, 84.36571090452134, 73.41094678448093, 72.9084833206669, 63.941321449895064, 67.59384432146626, 53.01415904875725, 43.58864468912925, 48.99337660881781, 94.82700163318266, 85.59280087870937, 46.134470816581484, 58.93622413758309, 49.782373136089696, 63.50584422388385, 76.29111966779156, 63.69506720573672, 61.263656616210945, 62.67387420900407, 60.85731083346952, 55.14235473448231, 56.49792586603473, 54.878708700979914, 56.717947298480624, 59.028580265660445, 58.77606984107726, 59.80855141916583, 51.90764273366621, 42.33847941121748, 25.03194082167841, 12.142332292372181, 3.832045831987935, 0.9975413497417205, 0.4878660567825841, 0.0459764680014022, 0.04513169518641887, 0.027242109570051395, 0.07720729861889156, 0.062106066203165444, 0.060371727412266124, 0.05503207925827273, 0.04811049784503637, 0.09468220084184602, 0.038335258066053354, 0.02529321827985827, 0.018832524937968102, 0.021946511471704132, 0.03829085944040168, 0.021869335774212115, 0.025116497117485252, 0.011957260243023836, 0.05148723721504212, 0.020864667002892783, 0.025646832974387274, 0.03910699971921502, 0.045907769066792344, 0.16267607409146526, 0.04260250186968235, 0.06413832126605896, 0.04164425228091498, 0.03914165753690947, 0.0495729060663331, 0.020451513870108514, 0.009347578856132684, 0.05770868321339931, 0.06488979223274416, 0.14415808953344822, 0.07240477003036969, 0.1037625567386708, 0.06908006335218107, 0.0909136611247255, 0.06186803885465188, 0.022309476269348975, 0.04834949429477415, 0.08173637978372075, 0.03706670456355618, 0.05444653910554705, 0.0694268100684689, 0.08050964319057043, 0.1315652281646767, 0.04852074175892819, 0.10942003945068968, 0.0828424422070384, 0.11761923335612783, 0.07895869052698536, 0.13343612212807904, 0.10363141780779248, 0.12161835021669827, 0.12571028629017453, 0.11935389390395534, 0.011471000297235386, 0.23681723602837135, 0.14548792623944823, 0.1000370251976194, 0.17491209170510694, 0.16979335266495907, 0.14650702236160157, 0.1622590771125209, 0.22430204065336337, 0.1569748017936945, 0.2520379475167682, 0.27547492134955626, 0.17571925726388732, 0.278378670374232, 0.18335516204036054, 0.14336253786759992, 0.3801977309969164, 0.09998202008465606, 0.2611758595993442, 0.09877407562828834, 0.22943222504709998, 0.19445591395901096, 0.08310556276551179, 0.13612634712649932, 0.0948602243536903, 0.25667144646567686, 0.17261125387683993, 0.14901648125340863, 0.23365097931556164, 0.2065006547397183, 0.29257385060191154, 0.13314628042280674, 0.20296001085831275, 0.13787921758428698, 0.21724303072739035, 0.1103364568083517, 0.22633655567563352, 0.04863460923755362, 0.1816387726895271, 0.12371051335527052, 0.20299612424306332, 0.11140566274163224, 0.15686839218101195, 0.1985304291930891, 0.24677081724568722, 0.1908629003071016, 0.27333833277225494, 0.18912951912610762, 0.17695760774996974, 0.2288543955693322, 0.36270803561614406, 0.1040225669801716, 0.19136732323996483, 0.24438261475053527, 0.13151396156078385, 0.1112190054188813, 0.20254699753657465, 0.19788427999423397, 0.2750574953613743, 0.25256486279108836, 0.1492973903734838, 0.08359351480800299, 0.18787696536990905, 0.11426160021895364, 0.12279272470022402, 0.0880442098564198, 1.1144006468595997, 9.292872548103333, 28.655132209101033, 56.32572597072971, 91.48927642453103, 110.20029221811603, 120.77104845354636, 110.2007785920174, 104.55454241844916, 104.34381700331166, 92.50381315908125, 89.02479633208245, 87.10438036149549, 88.65970996118362, 87.01887269173899, 97.97884571936824, 105.70013338519682, 96.6518529768913, 82.31034186578567, 79.96251306226178, 82.88688321267405, 95.78748810675837, 81.76890573193951, 85.29002528036796, 84.0685756744877, 90.33346376111432, 68.22875838125906, 57.00033833903652, 61.342551169856904, 114.9518043764176, 105.6739241077054, 71.08065882036763, 83.05696502808603, 75.17617025683003, 87.75269323779692, 103.25381386664607, 85.73513584752237, 88.41950401183098, 94.62159495199882, 89.4626897381198, 79.17302623871835, 80.43442126243346, 77.13829671182941, 85.90977545707457, 87.81072078212615, 86.21812082106068, 75.54664596434563, 51.57158974678286, 35.042564945836226, 17.53973330220869, 5.5128598982287995, 1.0402756953431715, 0.2977594691178491, 0.339512333514229, 0.2575179736220068, 0.12791935444599198, 0.11912616660758374, 0.1923197390691888, 0.1333342783994252, 0.17679236258470243, 0.12428081984962187, 0.21583900606680304, 0.09728323022324233, 0.17670533499650418, 0.14357788518311518, 0.18407730716130427, 0.2000141116760431, 0.1904149840195333, 0.12229056938761666, 0.13026603497564793, 0.0696013785237747, 0.13047649465020628, 0.08680546100461677, 0.2026531313576045, 0.1048223091469657, 0.15391339187420186, 0.2477333454355117, 0.2541908078015812, 0.18025258255581703, 0.10516475810999833, 0.1933033193551725, 0.13415891076287917, 0.20186674210333055, 0.10949884691546041, 0.1196333168134574, 0.15972447521503896, 0.1702753138998824, 0.18143548359794004, 0.1671906149074916, 0.21436019590304745, 0.14340012214116513, 0.2063325597273727, 0.16981319434219794, 0.17711934423254383, 0.19118364599923934, 0.11518363300110064, 0.15898687043978324, 0.1619051751350203, 0.1831117912285751, 0.28293278729242666, 0.2435074971928712, 0.14657117456438082, 0.1565141224813077, 0.1795686652222949, 0.22271849094860016, 0.27957683188780663, 0.20390588429666337, 0.24716360584622432, 0.29417384055352985, 0.22965126490641027, 0.07577544964489437], [0.05460663615996319, 0.0366580770951846, 0.04952024901285768, 0.04919364657853881, 0.09615747167939141, 0.06871178956522096, 0.15779713589337566, 0.03701887003356411, 0.10749378797387886, 0.0447046701165457, 0.04290070542464814, 0.13598471279105834, 0.05143709292995834, 0.054978384155659914, 0.11412234841695718, 0.02262556031646748, 0.13948342101948877, 0.035200537362646674, 0.015689161805165632, 0.042067224745668715, 0.051622896064673705, 0.06250968728695186, 0.11720818888035514, 0.05207957256765616, 0.001205495847839742, 0.0546771354011951, 0.06035794549050832, 0.07827640496074192, 0.053344253495696096, 0.03234443134598194, 0.039973161709044254, 0.08387719716636405, 0.04163964043161081, 0.06525556091219187, 0.02498212912600608, 0.044184389163649855, 0.07371092695863017, 0.0216330531909461, 0.04642326197016143, 0.030435470473622123, 0.05166753217758191, 0.037336026603776606, 0.0297878714533703, 0.02211410852689897, 0.04139792053930221, 0.017309666633786216, 0.03615933087384028, 0.030011504009786635, 0.07469614667277183, 0.036984694851261955, 0.043874621511467045, 0.00444331522768123, 0.03336849554832424, 0.03296036220666382, 0.025986897488755566, 0.0441250862974313, 0.03506135833900302, 0.04459208583519344, 0.042247481403812286, 0.06865342898714928, 0.06917461392379577, 0.0062176078978565434, 0.016752295534036333, 0.026778283551515594, 0.04841072770256189, 0.0748632840752121, 0.048915020400477995, 0.19713359043723155, 0.33133609160300226, 4.236607426597226, 11.185915277850244, 29.19900609600929, 46.31405653492097, 58.98643047578874, 69.93899806853264, 70.5464163134175, 88.50605503205331, 81.39091476317375, 80.66580972363873, 81.06258884552987, 72.80749013347011, 79.51701025809012, 71.64836698962797, 73.443863314967, 67.90987753099012, 71.71789492330244, 72.9130175805861, 81.77852338360202, 91.45335535849296, 79.39883708953857, 71.522490286058, 69.66137270773612, 87.25419136785692, 76.61942205121441, 62.80731324226626, 68.82023611376363, 61.44255591977028, 61.638137063672474, 75.01373706325408, 97.91201637637232, 85.39654900950771, 76.3427851277013, 64.9556738330472, 72.55225366161716, 66.09888784347042, 60.63399461007888, 53.517795301252804, 34.30097810683712, 21.307193386939264, 20.565122135223884, 10.834466007448013, 2.0499475877131186, 0.7361429569221313, 0.4261577357688258, 0.1432012916812974, 0.41323671297680953, 0.0641650845476937, 0.04497766937880267, 0.011659513467982894, 0.05448197067204503, 0.05260236245850402, 0.01140904963962854, 0.03206308555578993, 0.10562969687124414, 0.07115878930856144, 0.0415837811306119, 0.07565676730366484, 0.03764827638083408, 0.03981425592135038, 0.0470439157628965, 0.09496518606019598, 0.027482278134313323, 0.075658728488751, 0.015425407308934918, 0.045944732809138876, 0.013597892116635077, 0.02293185950557311, 0.025558784574029908, 0.016244126431223367, 0.0300768053444523, 0.06651657993995375, 0.04106256555044844, 0.03146013413976518, 0.0969957250861391, 0.04138815674870726, 0.03250349035126067, 0.05478660936557478, 0.08760472819689782, 0.034575107011703715, 0.012962282372398243, 0.11619922810144002, 0.03654326732841231, 0.04328345827337715, 0.026843676816732175, 0.052312823357961835, 0.02757617370075276, 0.021880290831529328, 0.042362796788614605, 0.016939967923286944, 0.04805321745093792, 0.013267352947995309, 0.13044681640401964, 0.08140223521378734, 0.06836184826228889, 0.05741380831046451, 0.05872269251173543, 0.08078885159545368, 0.07665569233077188, 0.06848217003167638, 0.08055402266402399, 0.04196079215034843, 0.04641039169303352, 0.051614557197617913, 0.06509890359255575, 0.11671277514148144, 0.07915922936292426, 0.04706714354876069, 0.013508160238064105, 0.04289165026538315, 0.07211040074546492, 0.07726316175033009, 0.02520709276019085, 0.10421420387443035, 0.019850309134551117, 0.04322720443709724, 0.08329153060913087, 0.16065858154287263, 0.068696046458377, 0.05474512570447499, 0.031207999282125986, 0.02326047675113284, 0.06268641611020412, 0.01633560882070132, 0.04489370997274115, 0.0069764361814445555, 0.09882321250775168, 0.03362054230585214, 0.1060358307234222, 0.044279039326694705, 0.045589647225795255, 0.046009045890382225, 0.09796825072337544, 0.14054623011860157, 0.08464896946304268, 0.08610557073787337, 0.03055418537358844, 0.01732547485810374, 0.09057081379597226, 0.05623045527646619, 0.04723176052193007, 0.02375622948391303, 0.07853366494659456, 0.11992778568979233, 0.04017808639834966, 0.05299145468480645, 0.04700146683101212, 0.052883298391656536, 0.04760908946815518, 0.048239311699064515, 0.04502624701408129, 0.04579850577659184, 0.029382342810652433, 0.028772787716720375, 0.04326853488061217, 0.008278557741563887, 0.04314222613409643, 0.1332816634807856, 0.029402940999716524, 0.056626327380898504, 0.0628098328748057, 0.06116676579920515, 0.017632197310787537, 0.055178654860825314, 0.053337515752402045, 0.05080739929971676, 0.0731181740880974, 0.04315227720766299, 0.029083352100344437, 0.03290292476454089, 0.027947280097812898, 0.058090175847492875, 0.2585397510518951, 0.15733824922673165, 2.162015096795175, 5.578230119520619, 19.234338421975416, 37.27099287894465, 63.64553159283054, 71.63437197285315, 83.43514427062004, 86.82174221161874, 88.43043173513105, 101.19584037411599, 92.03594500018706, 97.6986002152966, 97.9263565617223, 94.16137541494062, 101.17382803270894, 89.48060712506695, 94.13904143917946, 92.65546767942368, 102.88376177510908, 105.88112723442816, 111.2809052005891, 117.86364647649951, 99.51714438776817, 89.31776600499308, 77.74237309732746, 86.37852222688737, 78.87248639137515, 71.43972043068179, 80.99402581491779, 77.29854122284921, 85.76119607494724, 100.53128888530117, 118.6633393072313, 110.50702156559115, 94.696716185539, 93.15432256267917, 93.30775783907984, 84.71993231004285, 78.51060851927727, 78.97545645313879, 65.20663492141232, 48.87608205118487, 45.1851160295548, 32.541830385884936, 14.225315797713495, 6.151101108520262, 2.8701416667430633, 1.4441724482082552, 0.8052347107760368, 0.07033470086753368, 0.17617478846542298, 0.01771019080713872, 0.03262922070139358, 0.050577266487262906, 0.013142186630096649, 0.060083352765368844, 0.04780745644482875, 0.10831462820210766, 0.03608750247005974, 0.03518502791261962, 0.025154361013142813, 0.06249214770392545, 0.05814528055188637, 0.062222071067099614, 0.01596020658560578, 0.049307893270686756, 0.043990932810570926, 0.09337276505726962, 0.029945591720001354, 0.03848180302508897, 0.00523639482355887, 0.014586367704454931, 0.07056877903279758, 0.06714566836073514, 0.015019952402179761, 0.06496866864542808, 0.05226122350582192, 0.027890049499429526, 0.024147537619536443, 0.0661925783741378, 0.037794377008873614, 0.02398017039071889, 0.05961785859037792, 0.11149010095264643, 0.05341489829363362, 0.007096056022771424, 0.060870301263827475, 0.04668981077209596, 0.031906027955213384, 0.03730342190171923, 0.06570103337928172, 0.06078315110156133, 0.09293523692195454, 0.11816023698737545, 0.09440653942405217, 0.1283360909550421, 0.06045664442823299, 0.08900598728007848, 0.08021550373204293, 0.057410889515473004, 0.019512824421267838, 0.06133478037231873, 0.050939993797651226, 0.03266384787557106, 0.12664692836903757, 0.027087181693904346, 0.06549851037561893, 0.13240812406424554, 0.05462614458895499, 0.16991261723301104, 0.12060755082676489, 0.11042876274234827, 0.1834631344724086, 0.24153964714177195, 0.1631425756720766, 0.27133914972505263, 0.2022100873892346, 0.2475392340772575, 0.237777971572453, 0.19622815111952444, 0.2300394110141262, 0.1653425963295083, 0.11969366155925298, 0.16792111038681, 0.0888017635612238, 0.1529427584741385, 0.11184778740449298, 0.08991813752800228, 0.12993436486970994, 0.20868071114584325, 0.17903960490178678, 0.19790589899545719, 0.16625937374849475, 0.20221079219012492, 0.22671569258935992, 0.1547973500865121, 0.18672162817130167, 0.21031819344047578, 0.1657536791096772, 0.14746452501464277, 0.20547844830059236, 0.13835685808331738, 0.16696869455758603, 0.17510848600537549, 0.08265835127883381, 0.20833958751491963, 0.17117056424819654, 0.1468986924737692, 0.11977253031105765, 0.22957551413245741, 0.13364811397848592, 0.18893750684876598, 0.12382966301013386, 0.15462741646314823, 0.11917456038176052, 0.15387347869334683, 0.13501078521292056, 0.18380680151524084, 0.15871034334263495, 0.16515654421621756, 0.11888346229229244, 0.1263297373248685, 0.19233104652695118, 0.10256349124134549, 0.1786535119097079, 0.20426484245446422, 0.1358880784602896, 0.1956104544261771, 0.19272501490289168, 0.12592417803863365, 0.18683736873490198, 0.24199165433885592, 0.1411646622563562, 0.1712684856066781, 0.2979834732269087, 0.08303092281904914, 0.40095411721737156, 0.9917847812175752, 6.443926144030787, 19.933697023699363, 46.866404702586514, 72.05360274161063, 98.88712544595042, 111.96214245211695, 113.1536251498807, 136.26674836681735, 130.74638105207876, 131.89057565504507, 132.98615640209567, 121.74905223231163, 122.9757107457807, 111.18143389301916, 115.55418629800121, 115.95411116077055, 128.98815508811705, 137.71339693377095, 134.59694831602036, 131.46650468149494, 106.55820677357336, 95.82497027612503, 94.04448093906527, 108.02409064385199, 99.03832497135286, 87.46329292174309, 102.171812365132, 92.54470779049782, 95.8960985368298, 111.93589395092381, 138.60986248139415, 129.5746906342045, 118.512233918713, 114.688017137589, 119.3582420964395, 108.33787241289693, 102.60543038768154, 94.30134127216955, 72.96364753477036, 50.584886150975386, 40.049333187841604, 21.84940811126463, 6.649178872185369, 1.908363875362181, 0.6651146553697125, 0.3895340138866056, 0.6931336163993805, 0.3195683988592317, 0.2692085059900438, 0.12115466017876902, 0.25666058333891056, 0.1747543542014976, 0.14478678724938823, 0.2720551967861191, 0.12078014277522603, 0.2319895644341746, 0.09357127376020917, 0.15384931628021503, 0.10251237019415825, 0.1277836802746019, 0.23223057569515324, 0.15258945404521881, 0.13179067251903395, 0.13235964602039707, 0.10199451007910314, 0.20157493921297215, 0.10467823099104628, 0.16043974086642265, 0.07834331508004859, 0.17947247522252222, 0.12506788326126914, 0.12266199945682481, 0.08406249085260976, 0.23756645469655915, 0.19789068448928096, 0.14975163454730667, 0.1157835411328462, 0.17674933908687485, 0.17382135104027488, 0.13659746055641483, 0.16084608922321952, 0.17415237763235647, 0.1714407481373318, 0.07971232186161703, 0.0915958317777803, 0.2152056352145249, 0.16540474138192593, 0.12970303696009422, 0.20912563969050685, 0.1607431576497132, 0.19795384077775866, 0.25826840270911494, 0.23657789483906763, 0.23746588267385962, 0.15678205407194554, 0.13709181709395302, 0.2235862080969157, 0.24572397341891644, 0.17339399655259427, 0.13223105050142736, 0.1537014613108289, 0.1467220325984301, 0.20917623213702635, 0.12434232138818312, 0.21880148339175412, 0.29549620024138884, 0.17110294932799955], [0.03396258907272451, 0.007462148374367146, 0.07561712991446257, 0.03364378158303519, 0.10203158873463831, 0.029792196019702864, 0.026451261684058175, 0.045549714892742135, 0.017814740741385088, 0.027249670857864044, 0.08595605335769155, 0.03816746948887745, 0.054545747491741375, 0.0027828536469549424, 0.05394010136144296, 0.06860837535632235, 0.09481021413399328, 0.009136248714170389, 0.03647469096787034, 0.03338118579478995, 0.01421813126428113, 0.06897815067561404, 0.05369106149901787, 0.04200900589386302, 0.07067114370123995, 0.010404154872371545, 0.019595745778191957, 0.03088123022368358, 0.031243880925279473, 0.029901941945295663, 0.022703101820943337, 0.012156127092067995, 0.06211532437573038, 0.04726503938136082, 0.12642662446465225, 0.00241455256811253, 0.033139611459186966, 0.10394524572597397, 0.026185429174332853, 0.01053849796599318, 0.03952211212186564, 0.029796872986480597, 0.024689010479637695, 0.0786053707763072, 0.031651763373144695, 0.0030896100947903774, 0.06953927943663252, 0.015031823892176393, 0.016690016416231954, 0.03173511756974603, 0.054821684701187964, 0.07102542872270269, 0.07779994423711493, 0.09936996945931066, 0.04430727349714406, 0.04148613173334349, 0.007918706133721337, 0.02960839045925006, 0.01736873009752843, 0.06772613318096246, 0.05950960653623747, 0.033618945012530016, 0.02849583544077412, 0.014524355759814143, 0.026302588915812875, 0.0707675482056314, 0.03862706861729103, 0.11334374261599396, 0.07877782482894198, 0.0060168483328344605, 0.0937683115743341, 0.1277242241907985, 0.4002893674037149, 1.332977298767336, 5.093462919035266, 10.495176084579962, 20.217262814121863, 21.102192671068256, 30.831467143950928, 45.39726918743503, 58.522100294789965, 59.82617070597988, 66.64103784868794, 66.29838743517476, 64.67144712325066, 32.274109009773504, 10.593872724040862, 39.731044615468676, 67.28713850821218, 117.20988935039891, 136.17895003288024, 121.68587069357596, 123.26031792548396, 109.17293717784267, 113.24089788621473, 114.67923102840301, 104.94348464473602, 93.79075850209883, 69.2415222044914, 47.12942315686134, 15.389985172979294, 16.83224166593244, 15.316774133713016, 12.217959511664606, 8.26088224687884, 7.3758827678618895, 4.035219458803054, 1.6608249323983348, 1.3396144393951663, 0.1538865021880596, 0.3468359195657315, 0.06821141923747717, 0.13228375735061784, 0.022873429979588238, 0.045735506536138636, 0.1080528712801395, 0.02191703432359763, 0.07662652736349453, 0.058668909309011315, 0.03053837140361148, 0.06257172891749971, 0.06593882707097838, 0.047903255739760016, 0.04992160630682784, 0.044862986016537876, 0.011380316554418495, 0.05904944433319954, 0.024789096036505316, 0.024779391617724494, 0.07044272692573648, 0.027917232214202805, 0.014304052813038712, 0.0020565766786720847, 0.04575140669100708, 0.010587394485370287, 0.04814298380346549, 0.10951757010432983, 0.054741601700023304, 0.052478673732689315, 0.06693340837955475, 0.03678730463669185, 0.028018319431031426, 0.06050338345249334, 0.003031057037127715, 0.09672701974669773, 0.045058411215582204, 0.05248244288527677, 0.03280037623499671, 0.04787586809646699, 0.07281382267753925, 0.030701327881204988, 0.030419895906121503, 0.02816456753099638, 0.059367811322332396, 0.11870637340771577, 0.058609242551028735, 0.0046153038819020074, 0.04939556437274141, 0.02685647240028747, 0.04526115638474303, 0.02237558582677476, 0.07630903754503497, 0.03527772455145756, 0.09051767027666492, 0.06281922128231776, 0.028817433405727632, 0.04635450557895726, 0.028139399627463955, 0.07364444584856111, 0.02659744849698919, 0.04771451465785504, 0.05822100834320149, 0.08159567241466816, 0.06108034342046707, 0.023009412501367833, 0.0675433905675046, 0.07608872597977039, 0.061894844271122455, 0.02272233828872202, 0.03432396423792647, 0.02537728302300938, 0.07335408320350033, 0.08972159001014887, 0.03320923352974557, 0.026246306351235798, 0.018112095853974743, 0.06945590608783307, 0.041835326100549394, 0.043533654928567915, 0.12157852130551493, 0.0468405845364736, 0.048234155927334106, 0.06073192280206469, 0.09305376604559923, 0.015519277019906911, 0.020211374034143744, 0.04435372140799319, 0.02192370694941811, 0.04176060188441508, 0.05358165265211175, 0.04633701579164594, 0.055314984037390644, 0.04561385943464214, 0.03701160752004193, 0.09413046431877921, 0.03933670352243128, 0.044820717115315704, 0.029327812672202146, 0.013171304674488644, 0.017010880851997964, 0.0144138504495664, 0.04423708835196111, 0.06612323975611119, 0.016055062634780282, 0.042377655063906026, 0.026336980517953638, 0.07651780416528065, 0.026443097102005157, 0.004080112942779858, 0.03443029341137698, 0.06363800456446987, 0.051322624072312355, 0.05428416676999581, 0.12523158858980865, 0.013843625352056998, 0.04072249912086033, 0.04638865394818206, 0.0898025808255038, 0.019913873364848476, 0.008127185470995404, 0.023416124749928716, 0.03024846649608545, 0.05356175351827856, 0.05891518359402976, 0.018091411480019172, 0.018561586452227448, 0.02921167948854066, 0.06921902404076631, 0.09814936156955459, 0.07653757689460632, 0.0406686048353872, 0.01894369195666044, 0.025219941969900846, 0.14234049996781734, 0.012701784707455626, 0.26176813749536393, 0.3741738284307142, 0.986720020732572, 4.724455648852933, 8.994351740806334, 19.697991994119462, 26.201140534493234, 41.33666292313607, 44.250764308437226, 56.99528632625457, 76.11424430724114, 87.26948861152896, 87.44503036622079, 93.9997031611781, 90.45219390623032, 91.39262922348516, 53.37610752351823, 22.1246761275876, 60.52891823553271, 91.32252862376552, 143.30172323411512, 155.11836544159922, 145.7120197050033, 141.64791076414048, 132.3086061785298, 137.269525835591, 141.99489931906425, 127.26553640057965, 119.45553256619363, 91.39339800803893, 73.28035539196384, 31.641191436398415, 36.24949001496838, 33.229727821965376, 34.327712981931626, 28.483106859268684, 22.525644340822776, 13.939008270540546, 6.1996374976250435, 3.9112791803575333, 1.0285918126183173, 0.7330986460851086, 0.19408967796592944, 0.1688719327531515, 0.0383866855484103, 0.11687314798755032, 0.09673776029939614, 0.0166474832146759, 0.028326282946152553, 0.03519520156025406, 0.010382205495731005, 0.02705153179234795, 0.030296218671625665, 0.05651120351807726, 0.01725451213367764, 0.037646487565530885, 0.06781331398674557, 0.024713500395357132, 0.04075251444573364, 0.035026087650969144, 0.03212153423397291, 0.019955355110728455, 0.08810848463326694, 0.03580688063295619, 0.054470264848562024, 0.017890449380502105, 0.010397372121411947, 0.07200800543350559, 0.06272143398922297, 0.037115056202897144, 0.0751325486588382, 0.05140521984186865, 0.07809478849653276, 0.025075540141833406, 0.07648458659288383, 0.06428491219037002, 0.06128861591400159, 0.037425942343449405, 0.06197738258408443, 0.03682938201593296, 0.014382471488187871, 0.05322679306470579, 0.005211239368955215, 0.06085575325414539, 0.05853092155208992, 0.06792929969848165, 0.07990673199416169, 0.06943917472756679, 0.050990356417793425, 0.012301535368145955, 0.057715148995480234, 0.029273315092488646, 0.0059194043428907476, 0.07490567938094178, 0.05193421121446356, 0.11769047953308591, 0.019636308218562798, 0.025189809816619082, 0.03605967815664988, 0.047554911730150064, 0.0222056943382467, 0.0218946396583511, 0.05561785306781531, 0.09707108515525058, 0.06045142353902902, 0.02999406018775077, 0.04026892527397122, 0.3493607615030581, 0.14680372821467538, 0.12453165235778979, 0.19918911159038546, 0.22340153494188864, 0.15078960707591427, 0.1485206997923313, 0.1740901559711464, 0.14293473904892323, 0.08382505722223751, 0.3492968084831392, 0.1544906238033887, 0.19227107716423852, 0.1554081826320579, 0.19598888653901317, 0.12494051348297827, 0.31083306598086513, 0.11845698880572474, 0.14927920344616138, 0.14797962721317046, 0.16036973575190192, 0.14255238456591485, 0.2612734898444145, 0.17508102941416925, 0.10278445398134571, 0.16882566104252494, 0.10317918078433122, 0.06661196554740591, 0.2114835204256158, 0.1665410183129772, 0.14589451974438084, 0.14868877948291842, 0.15419790160752114, 0.12529822291746257, 0.1375196465561467, 0.14968040369210706, 0.12202408570315569, 0.08508913294081727, 0.09315654440152069, 0.1347066636287397, 0.3024232898268008, 0.13557320100165185, 0.09982244397002844, 0.1431757043446264, 0.11138394414897888, 0.14496375355989705, 0.1481636874978581, 0.24001957548241462, 0.08249353512280411, 0.14378284434637717, 0.15543167088781634, 0.1855907751427543, 0.21245341838127185, 0.1814215561194766, 0.08662287160874375, 0.12349011752033427, 0.1913260617443631, 0.15624266688621816, 0.1322166174049339, 0.11475628617429927, 0.12964965595353034, 0.2845165361800502, 0.1877400041708062, 0.25727003692619266, 0.18580120417379564, 0.15068443852566904, 0.13402486069788858, 0.3005132487704677, 0.16942665701912296, 0.19940098086672448, 0.17235429266527777, 0.2509278401492104, 0.9086091443896295, 2.557775873330332, 8.246576382267861, 14.011846684640455, 26.846572429903095, 31.923988442267145, 45.63601993745374, 64.63822464789114, 83.50008303119291, 85.51121557912519, 95.79193607453378, 93.6823755694974, 92.99658052382931, 56.612204121005156, 24.95292663574219, 65.72284629268032, 102.16278306899532, 169.4828224182129, 181.39975178626278, 172.44705169431626, 166.8349401412472, 154.3106709757159, 160.54565491214876, 167.31693667750207, 152.7929647507206, 138.60702268538938, 100.75982970576133, 72.76834487915039, 25.611449441602154, 26.760774504753854, 25.05226654391135, 24.55116218136203, 19.799887326455888, 13.394921595050445, 7.075891562046544, 2.7096179319966227, 1.9030751720551524, 0.26720193785525137, 0.2852259948849678, 0.20839961816466626, 0.3712766064751533, 0.08429224828198072, 0.12572671887615036, 0.26514134520003874, 0.1459037127994722, 0.17288030395584722, 0.22917333329396866, 0.20759924014489498, 0.16758314303813443, 0.1740334041777157, 0.11069588227978638, 0.1786398142576218, 0.08928835196720977, 0.10476135919170995, 0.15953378060892706, 0.14718015317714986, 0.13523618360200237, 0.1818101925234641, 0.14909557217071134, 0.13022619840358535, 0.12541879749586507, 0.15283922935205121, 0.15741309601693385, 0.154893831199696, 0.24541946879077345, 0.16029292777661355, 0.12400443064829997, 0.2855891512045937, 0.1432429055773443, 0.14815464766035158, 0.13597639307620066, 0.1750762030602463, 0.18071488597460333, 0.14754733911925746, 0.14731070988120573, 0.14320772681986133, 0.15391405070981673, 0.1896125069188495, 0.12542894049998254, 0.17636254129390563, 0.10795774614258159, 0.17945073364723116, 0.29065599544875087, 0.20490973526912354, 0.19278916710567093, 0.14363483615940617, 0.08174076180664763, 0.1937457351314445, 0.10777134928972491, 0.18905111768793678, 0.10782358116440235, 0.18776946791237403, 0.22013766330576715, 0.11708928437362756, 0.058235973870802316, 0.11536639859719623, 0.16071150289668193, 0.12163813826778244, 0.10373485499932882, 0.12885407364416507, 0.17789713798030732, 0.16314340304703484, 0.09607385318245619, 0.1813068880789703], [0.08117816981769378, 0.025535742564487363, 0.02007265849369428, 0.041995687455299406, 0.02004247079903801, 0.0216846511278662, 0.0560535425921121, 0.0665835973115698, 0.04362321443735592, 0.0774762491064687, 0.04389773438414259, 0.02938542822976747, 0.04451628143508588, 0.04833143377195924, 0.09848817927582611, 0.04359359364776362, 0.02600137846574428, 0.09860152198422341, 0.044716460209700375, 0.05792655861906468, 0.026137851283795414, 0.062309657899482604, 0.016782508126550147, 0.06890811491757631, 0.05101870933187105, 0.022044051701443333, 0.03095439545089199, 0.040098918872254516, 0.1049893239753381, 0.01119194702515679, 0.024920148782492168, 0.06394578038804954, 0.02672981508376618, 0.036740285990339135, 0.08205369340195771, 0.02697128216705976, 0.06665397780917345, 0.03551237345222504, 0.013198944169186778, 0.036825559237190796, 0.06230907950309977, 0.017727299465707714, 0.051304628666971004, 0.03112593402845725, 0.04885102141528361, 0.06532952670128116, 0.03750774521200407, 0.01943452640496675, 0.016739986416312958, 0.07856215575649854, 0.07597413454805652, 0.0336281955242157, 0.07634838382082601, 0.023871619562287966, 0.04559832317153773, 0.042662992172183535, 0.07590662688016891, 0.011303116916678848, 0.03204763547757701, 0.04853536254696308, 0.03672394150447461, 0.01599088744936331, 0.012416683171214837, 0.035737591810644634, 0.01663368788637942, 0.005294168865563529, 0.03791823427403166, 0.1306089206087974, 0.03328407648950815, 0.005038055138767607, 0.016876296440680182, 0.05643804212130847, 0.02495361724868417, 0.04585656374993344, 0.06261712345745295, 0.05836212173885396, 0.10958432700605163, 0.24709524015986153, 0.1121003742540075, 0.11690294114692558, 0.2756517037989632, 0.10237250552182237, 0.37177346045932463, 0.23187975339110822, 0.08630630875667257, 0.06645702426472018, 0.14006647521690016, 0.23258699044104547, 0.10476406348208267, 4.901087822452669, 15.98786323301254, 24.69992199251729, 35.85564482596613, 40.523845841807706, 37.05237565502044, 33.823515830501435, 18.34157951416508, 3.6966534583799304, 0.3333745902824787, 0.06746056880201064, 0.23957567349556955, 0.2524949496071185, 0.14279736416234126, 0.16377095163108843, 0.22997887474634957, 0.1533328504451821, 0.10725883646838127, 0.08598026173609881, 0.042750923744132446, 0.04623630204268041, 0.044366047762694864, 0.0534789853789393, 0.022346729209886926, 0.04044978331113535, 0.03975068211495396, 0.012817207344567344, 0.0534018479858435, 0.02148490136248931, 0.04820920444364029, 0.05058784616149722, 0.04660064962902858, 0.01141105583238025, 0.04211341218662359, 0.058276250943421364, 0.03372597515643124, 0.0578978379827834, 0.01458916296776865, 0.04954620024129268, 0.06015667504060173, 0.045868277234295686, 0.08678489920472907, 0.045079643342403636, 0.07539736227162423, 0.0698816517908727, 0.07533584541130452, 0.021433318747327696, 0.029102027408718586, 0.020569374582039255, 0.09318099026718447, 0.04937509450340464, 0.05836243966534253, 0.03122589701125699, 0.04426979264544864, 0.031136873764015978, 0.016471417057478142, 0.05891101224528206, 0.02747576255651732, 0.0450525583038407, 0.006684697929754734, 0.02058580908323488, 0.08097880309627903, 0.022680885271139206, 0.049797254914958636, 0.061933252089206255, 0.06129550687488049, 0.013988346064222917, 0.0366689938481056, 0.0481098045354649, 0.02448542835941959, 0.036938855980312636, 0.006666612509082282, 0.008409300221941404, 0.03801589516261893, 0.03190341368017178, 0.054504279152400074, 0.03450856078416109, 0.05635810467684942, 0.02777846304759864, 0.0332511347087641, 0.02682208845902595, 0.0403022654204359, 0.029705859825856266, 0.051770551851199526, 0.027767295400882443, 0.0726303676023118, 0.018203130082016992, 0.03696294944553125, 0.025567761209282665, 0.0748311237041508, 0.07591584291789802, 0.0030213308327215454, 0.0691781992152814, 0.05208338002463983, 0.055297268254141656, 0.030765256003266385, 0.0999868234559413, 0.011017574879881597, 0.03378483369165371, 0.006175888185915087, 0.055919534661957336, 0.05722763745354549, 0.08434477893094863, 0.03444321731465959, 0.07607050074805176, 0.0370818309696211, 0.0673491336525448, 0.018585674171786637, 0.03475136086044293, 0.00985021393130263, 0.028509071524885875, 0.013089632998491007, 0.04748304885241294, 0.014773424350536399, 0.030980176224763838, 0.04707691116979526, 0.04330192482279193, 0.021876659574768236, 0.06414686314641468, 0.053513290796188585, 0.035689401049767776, 0.11692338037274538, 0.006393214881104688, 0.028135063569812525, 0.030047337772444855, 0.007261786696260736, 0.00802918463089173, 0.05258031827848285, 0.04106667178172258, 0.041452634538854324, 0.060688830356323914, 0.023229871538557836, 0.028133682696329012, 0.02914446867972372, 0.02973185510434691, 0.012281493550436872, 0.08737798149306929, 0.049947350691523285, 0.029100635043916204, 0.07521330964781585, 0.052881739402730624, 0.009661122364172292, 0.03353192891565061, 0.026643823629485506, 0.0661503592686307, 0.029988440932826172, 0.03201354648016634, 0.07318819452437662, 0.025628452609863975, 0.029266956562717116, 0.06145146322406589, 0.019524779223326235, 0.06145157047637528, 0.015410980915710812, 0.21047484309923267, 0.028686614316557685, 0.06122906023876802, 0.06872450662476402, 0.028532205464979334, 0.0507804713091783, 0.050237337953501174, 0.05583127367220098, 0.19803365181771018, 0.3597846440970898, 0.5698603247442554, 0.306623320906393, 0.5739287419184562, 1.1848552404872834, 0.49273289079147004, 1.401025273146168, 0.9003906757120164, 0.6578189242751368, 0.07129547471601157, 0.18274561652252752, 0.18532503456357988, 0.17411681583091138, 7.750124441039178, 24.58698714933088, 37.73597417339202, 56.67544841766358, 62.52873866788803, 54.82618031963226, 51.03156958856891, 32.66282373859037, 9.196036092696652, 2.0461497527937738, 0.20380453086428105, 0.2407440495106482, 0.08243916586281792, 0.056808648645998015, 0.09086590320352586, 0.23124725587906378, 0.13239700046758499, 0.22549549838708294, 0.11387749139459864, 0.06939152405867655, 0.16144728438267786, 0.11306805055468314, 0.03283456290861772, 0.061399725476099606, 0.00843073153162315, 0.003689456460697036, 0.03874975759836455, 0.028741190420283426, 0.0231504550338873, 0.01846866764789147, 0.03532087445379265, 0.04529426670483044, 0.022813414651600104, 0.047605408415679014, 0.021997282033666007, 0.010168154784027609, 0.02728295546295422, 0.024920414998045853, 0.046417340110506744, 0.06543553794824308, 0.060337724599746935, 0.045136770518917235, 0.060873522663549076, 0.0593575036093112, 0.04448287234070801, 0.024164483484421528, 0.05356996215038723, 0.024426610043813145, 0.0992385930411758, 0.022297816411141428, 0.012314216038512607, 0.04280209841747438, 0.028224669043875994, 0.011357838577110202, 0.05782938419630932, 0.0579339015718189, 0.07137964479625225, 0.03295355934589621, 0.03716824185704032, 0.02369643249098332, 0.009192361781794217, 0.09138293594362275, 0.026834817009887872, 0.030600481982072516, 0.02099125537150089, 0.06505420236217399, 0.05012764565406307, 0.06822439676691448, 0.03988652482568737, 0.023505006270903735, 0.09027919476671566, 0.04759663287850638, 0.01912357323172112, 0.03152916440740228, 0.04250525849901381, 0.08519230966245936, 0.08157598395501414, 0.047606837169657794, 0.01650522643279645, 0.04054861248380715, 0.0093501586572177, 0.04090533749530873, 0.06268107647737188, 0.04092375041856881, 0.05734710120445779, 0.022869208835125453, 0.0796720639411961, 0.23488893143592343, 0.13344585144471738, 0.15687571598156808, 0.11407554044478363, 0.050384920961674184, 0.1476050255399558, 0.1698002168127606, 0.18217158684086415, 0.1392521390751485, 0.2588640820355185, 0.08230351467406558, 0.0959043485683299, 0.1444908474842387, 0.13134620362712493, 0.20753740152764708, 0.11551987665194659, 0.14003969278306733, 0.1595255375028618, 0.13693824710865177, 0.13200850195942387, 0.0646338499181213, 0.13088005444695874, 0.08857553779718377, 0.14369095976073898, 0.22558511535246528, 0.14240054593932244, 0.08597869891673328, 0.16802284686315447, 0.2526281876189094, 0.16639042074882215, 0.1088322967951817, 0.17607429305151587, 0.14942926474876944, 0.07502044701287824, 0.205383024388744, 0.22122826607477283, 0.2402445755057758, 0.07805097592814315, 0.12015434853251904, 0.06887897293293668, 0.17864090210247427, 0.1215550330497565, 0.12816837132577935, 0.14855871307513407, 0.1168146035483768, 0.16711656484873066, 0.0788717165649418, 0.1289682973536753, 0.07142989250320582, 0.190213012599176, 0.18397212328930057, 0.16410856657931883, 0.19460022960218692, 0.07514805427842564, 0.14994753855130366, 0.10536178826324402, 0.11158454427195173, 0.16921104923371347, 0.12528575100605527, 0.09268515517995243, 0.1745557688897656, 0.09347608733561732, 0.09271304844127548, 0.15813579272118308, 0.1993538971028982, 0.225113220512867, 0.14477290573620027, 0.2831247382827344, 0.21540386812581172, 0.13129803201844617, 0.14158925882750942, 0.1248857152137545, 0.2154010029569749, 0.15562780471819063, 0.1746386902466897, 0.1772467293325932, 0.17154479819920757, 0.4649254313159374, 0.1751895840730398, 0.2605676777180164, 0.42554918616529436, 0.1591529123364918, 0.6459677279476197, 0.505563760356557, 0.3143633523535344, 0.2897464039344942, 0.6287522614002228, 0.405884352662871, 0.17116037527880362, 6.732623375231221, 23.431794220401397, 39.814857821310724, 61.75081891398277, 68.16112887474799, 60.38428868016889, 52.25750246355611, 30.017834209626724, 6.312003597136467, 1.1279653060820796, 0.1491955926101054, 0.32831647944065834, 0.42826043261635693, 0.2735828986812023, 0.26972717815829866, 0.27581334835098636, 0.3853356069134128, 0.25730720751227876, 0.18965842622903087, 0.1897579563721534, 0.15517129292411191, 0.1736277606218092, 0.1712444304458557, 0.12972431888263072, 0.12860432898084964, 0.14634755349928333, 0.1051883612789454, 0.12038517848498399, 0.1964778804610814, 0.16231805056093201, 0.18355575450245412, 0.13966378876038138, 0.07906310831106479, 0.17775902764931803, 0.11736964957127649, 0.08512542252579043, 0.31747005339111056, 0.09840382533448358, 0.1912198053492654, 0.1849082980545298, 0.17741136162752108, 0.16976344459239515, 0.12580591704576247, 0.12297850102186204, 0.17033295435530527, 0.20833848434830868, 0.16631007344732363, 0.09435774728415475, 0.1593829685401532, 0.13255876759367605, 0.08724417657621446, 0.15419811611213993, 0.1271846914483655, 0.08766706477129653, 0.08560597415893309, 0.14327152662219542, 0.1696414833948497, 0.139100423022624, 0.1384129203976162, 0.08330960262326464, 0.09184686346880852, 0.17826999297305463, 0.11118637007330695, 0.05498365101013934, 0.12645415000377164, 0.2022344643069852, 0.09333914145827295, 0.11676712907970914, 0.2921230844672649, 0.054772501856449156, 0.24210426926372514, 0.15017739557210477, 0.09653491553880515, 0.11002527955438822, 0.11181597177299762, 0.3008076103944933, 0.19494634812637684, 0.1754442776643461, 0.14253428956914332, 0.09388459606036063, 0.16259718235702286, 0.14831587852489564, 0.1314478941381939, 0.18326329277648082, 0.16513607434688077, 0.16985215757402683, 0.21322693735841783], [0.06431806081485364, 0.09039470550393866, 0.019766838109541326, 0.09979733160787052, 0.03448416471421238, 0.034544203024838245, 0.05344475657048245, 0.018962093388601657, 0.011076165284330567, 0.044882532749925895, 0.02829863100252565, 0.028357263541810458, 0.04604998179861615, 0.03966973343443486, 0.03233992674898717, 0.03654320221093874, 0.08112561618608814, 0.057831150028974786, 0.008468788864481594, 0.014924959414788793, 0.07794678797044101, 0.10549367796028815, 0.03488960525681896, 0.06782265259854256, 0.02993591602951769, 0.07538200220874242, 0.010828690156490814, 0.027185353946181077, 0.014627101556998829, 0.14077933535220163, 0.027148752180378766, 0.02514374686495191, 0.011601274506369186, 0.02933789630450549, 0.015333290981699624, 0.023651003477073485, 0.08765953412700085, 0.051512085276866154, 0.01551958824312615, 0.04299289261501643, 0.03917675585516038, 0.02297838402521466, 0.02372217304523914, 0.04762664437294007, 0.11351193721976974, 0.1267856898747625, 0.0715076887319165, 0.041580103908575354, 0.08998228206990228, 0.032045825594855894, 0.01724193680040058, 0.012141828060961299, 0.027255470143450845, 0.10830244740411159, 0.08847848977893592, 0.012283943116574759, 0.050107849942099665, 0.05065673278764852, 0.06784637834155752, 0.06771965207712305, 0.04812395417942636, 0.057625298373281, 0.05726286217630391, 0.024586500254489725, 0.03233672450146368, 0.0439129680425169, 0.020334164521867232, 0.0676692281699469, 0.03802345261999196, 0.06952339077308294, 0.07510886888109869, 0.060820222096217263, 0.10567005438309525, 0.04373741133378879, 0.04545840487304715, 0.03180871946707128, 0.02018358802513009, 0.09484094958151541, 0.10527725046079968, 0.041469484642748876, 0.039393248472122416, 0.05125646471917149, 0.02266038858872508, 0.09173347479513577, 0.1619394345869941, 0.10964660995429563, 0.015555579053808846, 0.11220974862695703, 0.11810948366239188, 0.21569085998400567, 0.5344364191255262, 0.718093128694642, 0.5754831649603382, 0.5441396274874287, 0.1523157461516319, 0.29590663950770135, 0.5952011649647068, 0.14831646075171812, 0.07732747483157343, 0.21416927147055828, 0.06554266768357446, 0.07814370321049806, 0.01997069410619236, 0.020518197993477507, 0.0659507320773217, 0.03031232950067328, 0.02543756073611158, 0.06252184510231018, 0.06689137313514948, 0.08766078285031742, 0.047298839180580074, 0.09133413614284608, 0.06307948433283357, 0.050666956230998046, 0.11199912041305535, 0.007042995336720901, 0.06330436561256647, 0.01677437993367353, 0.020712776665365504, 0.05704358482973711, 0.04594998817229944, 0.006764026334313977, 0.042768149231109893, 0.03946696911307593, 0.0044465581736257, 0.027733122133800102, 0.04686939710330579, 0.04660420810743686, 0.0321388554819409, 0.03414899358646043, 0.05186414864334849, 0.08686039716966691, 0.06813343148678541, 0.03695802733061775, 0.04262790534525149, 0.012104082908932001, 0.04223183788839848, 0.0630376099668924, 0.07450971917639818, 0.03055285046538038, 0.033070736324354526, 0.031924739652763934, 0.019211661851694508, 0.007369160143313029, 0.04191152120549833, 0.05697222373959038, 0.06184915095687874, 0.092291661778525, 0.04232373396535555, 0.07664704319810675, 0.04465914151120571, 0.05447938129486096, 0.02957894012422091, 0.03782410122033569, 0.06118840778306608, 0.0423877444418688, 0.05545825397054996, 0.05424508479453864, 0.03314058056041118, 0.05444426382441194, 0.02771853965016142, 0.06703175108639464, 0.052362607581721204, 0.003843804504046397, 0.02295876834391346, 0.018388958114589897, 0.06382482659612453, 0.09446486935860689, 0.08271777671912024, 0.035839251678196654, 0.017430128214219888, 0.03741781798101241, 0.04125306480413964, 0.12810179062428015, 0.0395640209617634, 0.03803183362188359, 0.03386488604930139, 0.02545570552859816, 0.05247624523396935, 0.04640407912853745, 0.026015562583662333, 0.0878991894123535, 0.031296049597703164, 0.048948257125072905, 0.010925958425016894, 0.041689823021090804, 0.015527367865997217, 0.07336618739270395, 0.007814495193381465, 0.06413814889627599, 0.049878877752851096, 0.036873290345313094, 0.04487602866344875, 0.04074943860271766, 0.006550243753384078, 0.032188754618888905, 0.010862353975103508, 0.03237338563908012, 0.06883193513438587, 0.02124557549494409, 0.022081492333522728, 0.0512824542520027, 0.017939465601117383, 0.0356391686645727, 0.0254318552962955, 0.06860938659238239, 0.060754840322319544, 0.07672816424840882, 0.032427099893891045, 0.031834258923246976, 0.05272023274653381, 0.03951310675831572, 0.03185674360382461, 0.021329123128746307, 0.02878302073616895, 0.0459125571163191, 0.09157812748585017, 0.009386332371392319, 0.06942531619701656, 0.0193022919683567, 0.07259066126519635, 0.046416451448514584, 0.08415494234331193, 0.0527067534295061, 0.07817122874961746, 0.022670098753165335, 0.017354986480166836, 0.04290085481179338, 0.03536690867716267, 0.03766355983492348, 0.013977210018633595, 0.02797832006528493, 0.09683997941113288, 0.06278349860240856, 0.05311351164334244, 0.09090797675232734, 0.0435554692822118, 0.00857863246628474, 0.09376724671211936, 0.023601343742601817, 0.0077662785770371565, 0.05292794982632322, 0.07203409838820658, 0.04693477504676388, 0.07122269636320491, 0.05307092864607131, 0.044404478563416394, 0.0753213280451394, 0.09829208374984803, 0.04183891905291427, 0.05551910816481518, 0.06374760110291743, 0.026876093827248104, 0.07868398671909686, 0.07287724709679043, 0.07289428489222642, 0.06459570640037138, 0.021625162485326012, 0.07396338357319755, 0.1871345035972134, 0.08845650305550906, 0.10507734747783792, 0.1450450201669047, 0.2689298644902245, 0.1179401629093674, 0.07712196408500595, 0.46168012965110045, 0.5363417717237626, 0.29792417802156945, 0.3084013190480971, 0.15148144575857347, 0.14744440754575117, 0.5042096233415989, 0.18010330266289173, 0.03565624476440492, 0.033628885003347556, 0.11798240499751222, 0.015947949178817294, 0.055821356664021174, 0.05611342385471348, 0.04670688304148855, 0.07673349622036181, 0.03150530459900056, 0.05170544969939417, 0.0872762373558456, 0.05194888179821353, 0.04832987095259371, 0.0631121005262098, 0.03140022031842701, 0.03716076100845972, 0.06497874270163237, 0.0592810825084246, 0.028966471980956775, 0.051119744837764776, 0.03060608591523863, 0.020793838343853434, 0.03590039315543348, 0.027310038586297346, 0.03346793759133547, 0.02643078415384216, 0.09026987913755641, 0.02774767780436143, 0.07828898412445862, 0.07420830188259002, 0.012841604372125962, 0.04360573231092384, 0.027430279916452787, 0.02198696282932595, 0.059899085636941664, 0.005485515604020968, 0.033426082377592405, 0.020226236139874787, 0.058736922594928936, 0.015910092944038973, 0.04608354028013926, 0.04610243200835201, 0.012265014041575694, 0.0766294921237615, 0.03589999095927324, 0.05846802190306687, 0.035537072126903844, 0.055854030313991734, 0.013892851289241545, 0.10074039350353903, 0.031072545361014146, 0.06681569130910982, 0.015870563764756006, 0.02501933993170819, 0.01566521293904272, 0.07073750223724112, 0.11276245042080842, 0.04452003526591486, 0.014068048894255152, 0.13628302742877316, 0.025919811169226325, 0.023914390251100547, 0.03438112588839666, 0.04259836116445161, 0.04501931774880617, 0.05338171136475379, 0.08306076194369987, 0.06955869976551303, 0.03128712275816548, 0.02278715315755577, 0.031092894571502844, 0.08386875487743847, 0.009940481113810695, 0.022273096669044708, 0.01493606577447105, 0.002998290977801287, 0.03267011064435205, 0.09245866128513891, 0.16554587009933688, 0.2179211717579634, 0.14405725704085443, 0.15352294750271306, 0.16954610544827678, 0.17956526379191107, 0.19336031629673897, 0.13235488095350806, 0.056746833011387825, 0.23067360924136257, 0.13280544790529436, 0.1309743139051622, 0.07302579920618765, 0.25403521534415985, 0.14304565325860055, 0.17566484969950494, 0.18235877276428286, 0.17821558540867222, 0.1068530013904937, 0.13204332831646168, 0.10938026416566103, 0.1635066206536947, 0.12339429524276527, 0.13954403389605785, 0.1458148159567387, 0.18245781261113383, 0.05834254819238859, 0.13722051986523215, 0.13590369133218644, 0.31255988944922725, 0.15952900022027955, 0.15812445461990374, 0.08619753959318323, 0.13717573436517871, 0.18587453410990779, 0.20375599153339866, 0.1787410451159362, 0.224671877259689, 0.1407034313606639, 0.14841222174225316, 0.1946565983516555, 0.11745854641400999, 0.20182947958669356, 0.1738712846511795, 0.2311923120531344, 0.1761696403545718, 0.34499767626966205, 0.18080588189824937, 0.1964102655408844, 0.151238136233822, 0.08319998310217935, 0.1661298436022574, 0.1254228501009845, 0.2354205658118571, 0.1205101044427964, 0.11155812956032254, 0.3430942542129948, 0.18409832861394654, 0.1652594451462069, 0.15591079759741985, 0.09689582722081293, 0.09718840385997489, 0.21749108999727235, 0.1167368915893378, 0.09655445844175355, 0.1577482135185311, 0.10499764369019579, 0.17570134612821764, 0.13221240392135036, 0.10897504961899213, 0.24831592465841004, 0.1992003730828724, 0.25199861656273564, 0.14364709356619468, 0.213147463397153, 0.17860279688912054, 0.1678807681967174, 0.27471342995282144, 0.21795797462184585, 0.14454617435413022, 0.2002081923907803, 0.24733752312679447, 0.20368848386551106, 0.3860708674596202, 0.3789878023728248, 0.3337459590646529, 0.34043896282392166, 0.29990442337528356, 0.17762293979044885, 0.23462922762959237, 0.7416364202095617, 1.00960508950295, 0.5087367739648588, 0.6681862389368396, 0.2391189931621475, 0.4487608841830685, 0.8679627254605294, 0.22458674956954297, 0.21290130402532317, 0.3255300644424654, 0.3508475543029847, 0.17007371020172873, 0.19313265028740131, 0.19771077640114293, 0.1325224397043067, 0.15607521538772892, 0.08515273356029103, 0.15105850393733672, 0.23260540719474518, 0.11851739483855425, 0.18479232766455223, 0.1292168009545534, 0.1409627980883083, 0.14457499458184167, 0.17595228588869496, 0.09225839057997351, 0.1984886927229743, 0.07887686467579297, 0.15726254441805426, 0.1448583858267915, 0.12083248190221288, 0.20117727829323662, 0.10507799865257357, 0.12776377731032912, 0.15351032237372092, 0.1144314036073704, 0.1969383759123664, 0.19034625061096686, 0.14820022989184628, 0.12735588145592522, 0.10055181330009814, 0.1499155467195857, 0.17176296471828417, 0.11841601842353422, 0.15204851936188438, 0.08695248859904467, 0.12570384349073135, 0.23870582662282452, 0.1408106683483047, 0.166315007053556, 0.11582641141308893, 0.17009286239983576, 0.19312054609819768, 0.11648625060315095, 0.12055155746037922, 0.18389450326081247, 0.12892429326330462, 0.24328511719021106, 0.13812235856969513, 0.16772206542232346, 0.1718595990490529, 0.12403230092698529, 0.10865755980053257, 0.13424917124211788, 0.1556763900143485, 0.22051788806434602, 0.126163097879579, 0.2582834180324309, 0.20008859074404164, 0.08809046624528785, 0.20210539381350243, 0.07006945058463082, 0.12231892230169428, 0.160887090248927, 0.12724970166961994, 0.09934884075435901, 0.14359469315217388, 0.14439059721846736, 0.22285309259689626, 0.09141654422086093, 0.09869905263786355, 0.08889253731937179, 0.1241060215679388, 0.2288729042535828, 0.06721750442539492, 0.19535200700404184], [0.04504585886494287, 0.028396588750183586, 0.0370749936348969, 0.017134807065069195, 0.020575298356913754, 0.010047889513624533, 0.032021366322653434, 0.0944045246128113, 0.0765394155056246, 0.047651254947507576, 0.034970691833164425, 0.039614310803552794, 0.04720569821074606, 0.035258032261363925, 0.007449222555864723, 0.03216512080642485, 0.029008313788161166, 0.013462596201157619, 0.022409063869065816, 0.0816129170538437, 0.026387724266838164, 0.07813174457800004, 0.015172222910839465, 0.06582941439363264, 0.008338681279471325, 0.03462972908070491, 0.005615624146641142, 0.03304015026397763, 0.026541307658678102, 0.03267023704885956, 0.018428179901093245, 0.03444121782517722, 0.0736706996817262, 0.013967180012484953, 0.06481316811855763, 0.02053590803106706, 0.00591331250747786, 0.02077616086500066, 0.032317001567853075, 0.03778457874432206, 0.0383259769108507, 0.05768316865508115, 0.015990213291989942, 0.01876742661660237, 0.021851801936845147, 0.03830377951324467, 0.021015714643703356, 0.037771298610154665, 0.12798736007103037, 0.04381473258798642, 0.028937513857418974, 0.06567244297794758, 0.05935086545744731, 0.02487107702050238, 0.02792612457978389, 0.07713189258450463, 0.06796438652541369, 0.0965770733572783, 0.06663648036098288, 0.03819535508932125, 0.011334519818305008, 0.03876251296230382, 0.021078418940305713, 0.027910174629200372, 0.07126550535641371, 0.16443818356961976, 0.069383587387781, 0.06110212330015437, 0.039257436404905977, 0.03744387263131719, 0.08549243226767549, 0.045215623948963425, 0.008317069939127373, 0.015553184071435563, 0.08013226827906986, 0.05207372348635428, 0.03682805285338433, 0.03360153566445074, 0.03800083387402758, 0.09814796728953239, 0.03924836209344287, 0.09224678434792066, 0.1115027490642763, 0.038444161294929446, 0.018842252339386655, 0.030726287025778048, 0.0508542072718903, 0.12041462690479333, 0.07440526308792253, 0.04205279547961489, 0.15559861676827555, 0.2172635005967271, 0.25459111938553475, 0.2325595032063223, 0.1237859117287782, 0.2008842036969239, 0.13919098993703244, 0.02589439620233832, 0.0590737599639162, 0.0283051542412009, 0.05748469442609818, 0.042285736004311236, 0.042564147677753246, 0.04045897253578709, 0.11027484801748108, 0.059164920596465956, 0.08677058102142426, 0.08098956663161516, 0.026873123321321704, 0.034175595989631075, 0.13124147940787578, 0.03778438339190137, 0.06258227794821705, 0.06717370717876381, 0.0709674971538686, 0.07866975280546373, 0.07273757394643561, 0.056744029129584955, 0.058290496348373355, 0.04626766568230045, 0.06517715181314176, 0.028881083820916476, 0.08135949516849172, 0.010182338901945661, 0.048306183513974955, 0.034854683138790636, 0.04809704917152563, 0.0611664517031562, 0.10623970204183172, 0.00862557546145493, 0.045793901588166916, 0.026978447004371596, 0.03991623371539097, 0.018335605836323193, 0.029324089484890143, 0.023805295500243386, 0.06174880876055649, 0.06350325352902855, 0.0251757635945274, 0.018820535661953113, 0.02651829437743272, 0.05311255786387671, 0.06914966244010196, 0.05308117124161894, 0.031104588903666987, 0.07298815364558851, 0.050007243445443536, 0.06968233103473341, 0.008126480670105065, 0.06808584976580835, 0.02009049110535172, 0.033726488435340506, 0.019597900400478995, 0.04242644337336383, 0.044326398882173726, 0.030634302848709688, 0.037546731426470706, 0.05217343749057862, 0.06144315883096668, 0.011697835101175212, 0.028672715566391428, 0.028247527192316713, 0.01989249568132143, 0.032276690021277435, 0.024845786542902072, 0.035356964855905504, 0.0786727175657307, 0.07404429777976006, 0.029628915869961345, 0.0321390891387578, 0.018883146112784743, 0.05884075815218592, 0.03483203374930928, 0.045137053971449216, 0.08476412013894127, 0.04725206951280275, 0.012627548872373037, 0.05550199376058675, 0.08183297581009327, 0.03913181713752208, 0.037350704848405816, 0.04598158163829677, 0.08721259843197562, 0.05939441372550303, 0.032270159121722944, 0.030055582793729923, 0.06536855888102325, 0.017822736784094767, 0.05129576502968708, 0.028435615184266242, 0.025996481248688315, 0.0404472513905456, 0.07843500048282646, 0.012432755695866242, 0.006391764580903034, 0.016188682732923378, 0.009776900274558895, 0.06035454406012451, 0.04060643296989222, 0.05358787711649653, 0.015247179826180783, 0.03592530250429146, 0.04269118420779706, 0.03587259182466134, 0.03385967665141629, 0.06358508321066057, 0.10919110939627695, 0.031533814561102665, 0.055972027006529035, 0.04478118314798321, 0.005425043496107984, 0.020910770174175985, 0.03686783579929221, 0.0437988362635576, 0.0030403343618907517, 0.013039182278237516, 0.06151623212762418, 0.03599551063211214, 0.06445402609965493, 0.04559348149585628, 0.038012869115318024, 0.011076825077555353, 0.046621054380891785, 0.04478361930758242, 0.029446242204416665, 0.009178723501522214, 0.02569697725947105, 0.03313178587104044, 0.03187255565858176, 0.03342762604475983, 0.03639041746575986, 0.088671114926617, 0.015341470885511129, 0.023478834792190505, 0.047717559857354055, 0.009357328282579059, 0.04570814187548334, 0.08065145372623399, 0.03055424666062238, 0.020259036194352854, 0.07009071718540884, 0.09071017285027812, 0.03917821908309575, 0.018132167357590892, 0.010404061984210726, 0.009662737852082619, 0.039096849054218306, 0.010722463447300178, 0.01679548948642708, 0.043912290054703915, 0.06855787484035378, 0.04423852093637951, 0.06799005813175632, 0.11027164576995759, 0.07568282961484886, 0.06596847467364804, 0.05491856418009247, 0.06474600519023596, 0.07285850858616252, 0.13395131625715764, 0.07165000488561007, 0.08826654389380448, 0.012779231408550855, 0.18955443745418904, 0.06536117379343317, 0.08115121118363836, 0.11983714216659147, 0.1650444961964123, 0.23785370702464737, 0.09920853175102703, 0.14014242517371334, 0.09586268104612829, 0.17141235691885795, 0.004673260348593636, 0.07582949714795237, 0.08147368057360573, 0.026751866924666592, 0.06303381400122758, 0.038505524937664314, 0.08388475079329745, 0.05583723000581226, 0.0696315547271121, 0.06597775199841108, 0.08714267758712654, 0.025210023046501225, 0.03534638518167119, 0.07123526786604235, 0.061634493120495355, 0.03552895542534609, 0.011119525860844841, 0.04086077799119296, 0.025855725999140454, 0.03876568456631034, 0.026198795493391734, 0.009152760781768349, 0.06599501962022436, 0.04477745613023158, 0.04030528763729719, 0.022556681351195422, 0.04929515322850597, 0.03030626208431298, 0.008644492087525227, 0.07656739303661932, 0.04194643566264741, 0.05607298207319072, 0.044672651471750396, 0.047301064666000106, 0.0208452332674736, 0.025324943896022536, 0.059671208953424815, 0.05459129524927947, 0.0391957663270014, 0.05059952517190287, 0.06558674838273756, 0.032594344548640714, 0.03825262399210084, 0.07521457369289092, 0.020811523483585448, 0.0605092823295103, 0.0339250928992706, 0.042570755186100165, 0.03956880901129015, 0.05845536613055776, 0.02200573006825101, 0.06234851770944173, 0.0869478767497405, 0.046775965020060546, 0.04856132526671694, 0.022312749380005464, 0.0613194547833935, 0.06498484076150964, 0.09699000240934473, 0.03859546749041446, 0.03174792847505981, 0.008017554458591246, 0.003170293277963215, 0.031756514405471184, 0.059094126411383195, 0.03881520065929621, 0.008609709780543082, 0.04395684189794045, 0.09682501771397169, 0.014957693394183394, 0.04989445615079134, 0.05546482317450066, 0.07849483961059202, 0.02064548541731652, 0.01538641822163857, 0.030319852484089714, 0.0364522407612493, 0.05534510278413373, 0.041706539059598605, 0.07911206899030555, 0.1553311295086338, 0.15177363169289407, 0.14515446348776742, 0.10710167353071513, 0.06179956208554007, 0.16055943444371223, 0.14103654171189955, 0.3730676893986041, 0.15573764640477397, 0.13094501870293773, 0.08499849707849565, 0.1724739249555334, 0.16174576755973602, 0.058146517783884084, 0.1390786967690914, 0.11216503207481678, 0.11299993767733536, 0.10959207215496611, 0.24759839138677045, 0.09065271625595708, 0.22330555944673477, 0.21928673880475186, 0.1806229401019312, 0.09233240233433825, 0.2263512492420212, 0.10872138258550437, 0.14891882036482135, 0.264041181653738, 0.1575727487403539, 0.14129433029841992, 0.09811455053427527, 0.18510703658384664, 0.08385366294533016, 0.09762573281242963, 0.11813935343055956, 0.1360861121887161, 0.19654178751572488, 0.19580216026834904, 0.11093865554299086, 0.11030741441514223, 0.10843029215691552, 0.15635943400763697, 0.1554171611825305, 0.14086123015130722, 0.10590998546010065, 0.16695634522024663, 0.1483794944661279, 0.2280627662736562, 0.1099414618745927, 0.10929567273706199, 0.15161374914309672, 0.16517712133786372, 0.08292219195995601, 0.09684366429404867, 0.20890129850276057, 0.12390150673567288, 0.11720751472298177, 0.20388012842064906, 0.23461379861879736, 0.14052025973796844, 0.11855128656832442, 0.10419009508745325, 0.1411197541822349, 0.135369666761929, 0.16569893446660813, 0.0982374540199676, 0.11587504267452226, 0.11184268525891727, 0.16958257123347253, 0.2402322414901949, 0.12183131499876901, 0.17592887424172896, 0.1562151336862195, 0.26474610511814395, 0.14942443839484645, 0.1951893665377171, 0.18886501960937055, 0.2656455536282832, 0.22646395609744135, 0.23329822646994747, 0.18390135208685554, 0.3484730188164019, 0.35606853543750705, 0.1536109556834544, 0.197520112438548, 0.11292217209214166, 0.3699807534294744, 0.1575431624247182, 0.25890713617686306, 0.3725896198903361, 0.3521260937615749, 0.5495435504182693, 0.30665353541412665, 0.2661199765580316, 0.2086309307525235, 0.41993841949489813, 0.13592443699317594, 0.24937085837366121, 0.28067806795720135, 0.3354170726191613, 0.15133880018707246, 0.173062096620279, 0.26150509354568297, 0.26780438939890555, 0.15744897957530715, 0.21421583429459604, 0.14516048493885225, 0.11025761103918476, 0.13273303727469138, 0.15550524597206425, 0.08498346643342126, 0.1791260349414041, 0.22258497714515657, 0.12768637944733904, 0.11880570436797797, 0.15681557807951205, 0.16809364870911644, 0.21223597198484406, 0.2424131099495196, 0.08395299390559235, 0.20173263075130604, 0.13935137810485979, 0.15225404543021034, 0.14433542356616066, 0.13664129610744216, 0.23584885492680535, 0.247037798887299, 0.19401100073610583, 0.14245670018417222, 0.11789696321131722, 0.13346938566575128, 0.17167288810014728, 0.18938197574067503, 0.1480121706281939, 0.13014408909986097, 0.11590021632371411, 0.16423012941114365, 0.14619807442349775, 0.14223499433888545, 0.18003890531197672, 0.1404256632010783, 0.12545166266781668, 0.13249767974259394, 0.21359403136997454, 0.1175728926975881, 0.1922116593848313, 0.12727848359293517, 0.13207300656264828, 0.21642481818074183, 0.10186064387521437, 0.13654294573972303, 0.13847943215120223, 0.1666320908454157, 0.12168367453400167, 0.1988197039932974, 0.12827606796617472, 0.1917539678153492, 0.15868201341119506, 0.06447064254673258, 0.12756483193727272, 0.14311593416477406, 0.11861735399091437, 0.0502875090516623, 0.09883445867848012, 0.2115730607822057, 0.1653053338128713, 0.10995722030319514, 0.14365763493603276, 0.1339963009400714, 0.1317026030512587, 0.11071455950338034, 0.20030070516851642, 0.09249623023694561, 0.22998751621813546, 0.18641764448294718], [0.04670180770899019, 0.05944373063562859, 0.020509117936354973, 0.058586830648803906, 0.027210270955918298, 0.05310798048852913, 0.03471083863968811, 0.05673826431795474, 0.08034705635040038, 0.045231849691199685, 0.037197548550583666, 0.025239839188514218, 0.10430414259674088, 0.05837375861442378, 0.04070805453304802, 0.022293375016400413, 0.031952242209245606, 0.01518246263355738, 0.05183916268569808, 0.07926759249981373, 0.007694141822867096, 0.03712525666360894, 0.047348477847633824, 0.030662914317461754, 0.010412122186784063, 0.04660185621750932, 0.043210135998144265, 0.01068402594330931, 0.03941222063956722, 0.08991955479066219, 0.05295475141235417, 0.02791461219350177, 0.021336274559519464, 0.022332462737517014, 0.09127572959949894, 0.034898821294548056, 0.01836930412889248, 0.05514279045465012, 0.026637488082351706, 0.029158321464614525, 0.04891170323976586, 0.0246652081278303, 0.0249993143933675, 0.06532299963216628, 0.023701917680521167, 0.04684433070642333, 0.17216903728342828, 0.04761465509692508, 0.0556711498047075, 0.04557146412891246, 0.01854362360562288, 0.034228360295415886, 0.017872854256101193, 0.14293942750701982, 0.0237592842595111, 0.07927113948690315, 0.04794562040197273, 0.09039862021323174, 0.10396194644272329, 0.03893757554432077, 0.03443343820230615, 0.028743697443015637, 0.02431064348427519, 0.03092404879299143, 0.06326445243171146, 0.007431910405190843, 0.08635385217325342, 0.13075251612932454, 0.04293005808346695, 0.01711939146081286, 0.024750140465555653, 0.05883504313627078, 0.07498961963480519, 0.093736472960201, 0.043719029054045684, 0.03312516687137466, 0.03650488249296623, 0.015546660832760316, 0.07357851632179753, 0.03926599360702019, 0.0927934110645325, 0.01739806934980856, 0.08579563454634721, 0.07196347274246716, 0.07159183582951946, 0.07092641951936869, 0.024359010445374637, 0.11377561702242783, 0.02557908398880353, 0.12405477794668368, 0.1312644773673627, 0.10333992135260375, 0.13764606638541146, 0.09757943045828613, 0.058010805308097796, 0.11635295896520538, 0.19890005129479593, 0.054491090948783585, 0.049083697639646075, 0.03267739231007234, 0.02894148602330637, 0.060880168476292205, 0.07700842985462758, 0.10284729617377443, 0.04066562092292213, 0.06958351335338048, 0.05138268153513632, 0.03234871760791829, 0.13284749081057887, 0.009555588006943224, 0.029288548750862963, 0.020020539616985668, 0.13258711284687444, 0.05649320428229629, 0.036029348735727613, 0.042882851745572784, 0.03132061995265465, 0.03853329562491948, 0.04172619687573564, 0.03342145520652975, 0.019712976382804975, 0.028281271450161457, 0.11501802777450894, 0.03344842916234367, 0.037275383083690564, 0.02415263401945272, 0.053274432242277174, 0.04170365473856369, 0.04671765423770394, 0.07646923419088125, 0.027518876069676013, 0.05586395115261117, 0.020926396452611493, 0.0036536368227849205, 0.04714171837774977, 0.02678703993649012, 0.04141168330886191, 0.09397066603865355, 0.03032603289841885, 0.019395454005608638, 0.06817548971382842, 0.06789673330082048, 0.026599110907784877, 0.022545027238647306, 0.07255331447888767, 0.07105842412960145, 0.032347805963288394, 0.034468168798353405, 0.024599353294639338, 0.018395316644361424, 0.039237326596893614, 0.11489953695526046, 0.055919362292174375, 0.03912014578799567, 0.05585688016107006, 0.01954022930153916, 0.03632875121829491, 0.03142343278253271, 0.014918087606107997, 0.03658711054031888, 0.0601927692731542, 0.051843763043683384, 0.007789165932579988, 0.09155862288729799, 0.034069335764093746, 0.047145253873520324, 0.045035026381693544, 0.03855134082597591, 0.02579808554371759, 0.03213649210069449, 0.032002114533116265, 0.031449966237790165, 0.03458586288616061, 0.0283689042478199, 0.08779218225109, 0.03806673275727419, 0.024658252049477834, 0.05722324393929974, 0.0033805003829090107, 0.08062404310030323, 0.07758388445983011, 0.04850677980650817, 0.04755673118897023, 0.08836967465017112, 0.03972163972174449, 0.0144233719648553, 0.028471918175778085, 0.059540062361667236, 0.0534065364439401, 0.08986589799244558, 0.08742209283574935, 0.0402891997908873, 0.0798206849985065, 0.03858587223916285, 0.017269328274133227, 0.06942762212166864, 0.032460428549036864, 0.01337392631197168, 0.07445265328691852, 0.02510933228017342, 0.05040498097397147, 0.05228232156725661, 0.03896012534237197, 0.013315490082717471, 0.06405485215626898, 0.03838694984874418, 0.08394262873597684, 0.01572972328792657, 0.019163201044824336, 0.0407265019302647, 0.015881290910915745, 0.06589370449223826, 0.04164932761341334, 0.07693986498540448, 0.033784194008236935, 0.019956079063816898, 0.12221507142267882, 0.04992266350816335, 0.05367056098616412, 0.017050071994984345, 0.018978644718205737, 0.025258591105680794, 0.05222403759797735, 0.015924921533423328, 0.02965154610724459, 0.08964095925611835, 0.031146672028567524, 0.03181109242441674, 0.08804751169537345, 0.04113107296307722, 0.022977464719705527, 0.08485530758456838, 0.025500433572057276, 0.06460400313259133, 0.11358816296823564, 0.09750180276891879, 0.006531107834645457, 0.04955578017078581, 0.024401482359896746, 0.038401463384469675, 0.01696569124056447, 0.004630236371961092, 0.010676565204536723, 0.14528561774040424, 0.05453570407905406, 0.030893144806125955, 0.02630850119936851, 0.05876121524300787, 0.04774411629524924, 0.09185394978210812, 0.050458603298231486, 0.05939547092683854, 0.033139921724796295, 0.07667353451852837, 0.06469508332590904, 0.0199714352962591, 0.10844747550905713, 0.07729494673830849, 0.0845783514781825, 0.028352393137831843, 0.1298716069469529, 0.044246810007720225, 0.06965006341136272, 0.10519557016631288, 0.025057477703798684, 0.03730684248430114, 0.08557457221491684, 0.0883987553477768, 0.031287055725472114, 0.0662136228094178, 0.04328839187960952, 0.07401311800124184, 0.1719322241842747, 0.06014891073948914, 0.02080573951975713, 0.02669848974854235, 0.06310933877924277, 0.06947243826523905, 0.12643148146209218, 0.06289032190257023, 0.10266374916799607, 0.06964146790485229, 0.017358864800283508, 0.016313583792878256, 0.027039442924902807, 0.009012871211574925, 0.04505944926471961, 0.020939563588810065, 0.031729230184047934, 0.049333112885154067, 0.02763339663825689, 0.018286440228562684, 0.07621784243852862, 0.020283370977267623, 0.019367351985326218, 0.03853209286687836, 0.04027017782772741, 0.061105808183070154, 0.0436313004953967, 0.008676933995898693, 0.017743519462284543, 0.08915595665213563, 0.009634229805200331, 0.04335083570631762, 0.025758656913474686, 0.016355461989259048, 0.030628963215877453, 0.05283871207446341, 0.03891543560330907, 0.05275672151436729, 0.021263339158688343, 0.010789751822519447, 0.02819751697261968, 0.07760567966127589, 0.02883478146677296, 0.0207666460529811, 0.02491310460402841, 0.051061487681562864, 0.0490625114781001, 0.024605026175718636, 0.11758059954210637, 0.010222762488880226, 0.03196359180184382, 0.011289840612951066, 0.05479054705750558, 0.008231024858692001, 0.03668078777169989, 0.01458559108282169, 0.016707973517177087, 0.015327567347295344, 0.030355035072012298, 0.011145225237874735, 0.06321215927000008, 0.05054823941581192, 0.020859999612214106, 0.04001140098778471, 0.045237484267882766, 0.09709553102091437, 0.020467444668493925, 0.10340863177853246, 0.0038520969270217807, 0.03951319485842701, 0.036712323781102896, 0.017721956002435858, 0.033639246342523445, 0.019230969182606188, 0.01983032190060664, 0.00944533837854021, 0.01994301917992773, 0.022953943905210304, 0.023515022870513703, 0.05628749818330812, 0.10582288126310996, 0.18736413079163722, 0.14286890145271056, 0.18844498892224607, 0.25138148677445227, 0.19825730352632462, 0.11411815025513211, 0.12580594768927944, 0.11495318609259783, 0.16490886799029766, 0.15415041947797423, 0.11384349241251908, 0.2821447279664778, 0.1438927932852699, 0.16045394413653882, 0.10331028141081335, 0.14479403444115194, 0.14224659291005906, 0.06912242801439378, 0.19016597480062516, 0.15219551631279532, 0.0666879001824606, 0.15365400982479896, 0.17167333243114336, 0.066054483364907, 0.11929594701336277, 0.11476111252822223, 0.12647578432675333, 0.18349504969533414, 0.12060779597490065, 0.14304983609866712, 0.13167779712427047, 0.1407651014385685, 0.20800672231181977, 0.2488308429958359, 0.12487030918559722, 0.20112238043258268, 0.19722432589098332, 0.11119407691782522, 0.12627634865742537, 0.2887812250804517, 0.09175546151856262, 0.2701224488837104, 0.15010654776086732, 0.10017928006427904, 0.14751061286416747, 0.40811890856392924, 0.12133387112689596, 0.13170968170367903, 0.18359065746828435, 0.0682777701125991, 0.10319779672089124, 0.1763524595768221, 0.2325998453964149, 0.11059194713109925, 0.22052895037397263, 0.2582535712469009, 0.2062806802531404, 0.22344754618262092, 0.11819646528531468, 0.18485986597595677, 0.11005861970085291, 0.09783898104703236, 0.08620128576313296, 0.15610550650425498, 0.21243772890058257, 0.13384430909589415, 0.26948592174918423, 0.19341786482161094, 0.08188047326139866, 0.19693696631058571, 0.31578395515680313, 0.14932766616825136, 0.21967522199115447, 0.1591884434944199, 0.15170062351371014, 0.25487052697327833, 0.17380106503203993, 0.19498103658758825, 0.1327663314558806, 0.23459898247834177, 0.1570002665562976, 0.26630346993765525, 0.21884963967867438, 0.29305906004963383, 0.20615150250734823, 0.16066733026696792, 0.2274061523137554, 0.18178923235785577, 0.23929277254689127, 0.3438358579672152, 0.2538135248206316, 0.2851815311418426, 0.3190979902302066, 0.13769471296860328, 0.22805643838740167, 0.41171170771121984, 0.12322761749307956, 0.10935215639971918, 0.17948920658278852, 0.1797433639125478, 0.2808725010723837, 0.2916429311998429, 0.20508518472554224, 0.3083294600007996, 0.16933797468100825, 0.12103232359814069, 0.11381150824168038, 0.20558303462401514, 0.11314886516981548, 0.12300503064667988, 0.1555507515947665, 0.29382643500162714, 0.14160646516228878, 0.1306571535045101, 0.12767270477789064, 0.09064705486619666, 0.1850322204371614, 0.09224102336673007, 0.168698888812815, 0.18963555084361186, 0.09270293608067498, 0.1603727234948066, 0.12588970408204103, 0.09223835738075357, 0.1294027151720178, 0.10145080981836205, 0.13369634687419862, 0.1485956078695674, 0.20955633432153734, 0.16010845380444683, 0.1959879825552625, 0.12829003374903433, 0.08150060856414419, 0.16155887274972855, 0.11922154455415665, 0.18918869175737907, 0.2520522427174353, 0.10808543767780067, 0.05625049230612575, 0.19279275239715654, 0.16673880689326795, 0.10052926733248657, 0.0820820233333976, 0.16583355143666267, 0.1399257601869683, 0.12044038278080764, 0.11013031020880708, 0.09603279086971477, 0.13851070386027137, 0.20392197214307325, 0.2857442686875021, 0.14898188472274812, 0.09119676125626411, 0.13798602556269016, 0.11148020309666473, 0.29366028585260917, 0.10585986798809421, 0.12069145277623208, 0.15562074138752877, 0.17840081014700476, 0.18090780223569564, 0.12894974270414922, 0.19821509208169677, 0.094265908663792, 0.12115527304910845, 0.10638659174043326, 0.1153779358813359, 0.11372693213483981, 0.138465826429667, 0.0844387319539824, 0.06495491736718724, 0.11728791565063501, 0.11551876582445637, 0.18292802205729872, 0.16343307621296377], [0.025072019967821338, 0.04586697871526403, 0.04219646377849483, 0.013415633096179415, 0.044994216877967126, 0.03365357984758673, 0.03840775679676764, 0.004893602557375186, 0.017364623866254286, 0.0580215267085981, 0.03173682211537755, 0.037221661168000394, 0.11778512203525152, 0.015295559236209, 0.058740649612680565, 0.013593061932272488, 0.04716347910523896, 0.050556616587263924, 0.009367075793805623, 0.03460601482900881, 0.030599618217937892, 0.04129614575856155, 0.06438007563232415, 0.0748715884683113, 0.1206299972029463, 0.03105431438363608, 0.09934186935424806, 0.020086718122324636, 0.038425564510567535, 0.046835838621782686, 0.04571448125305676, 0.05219566936214125, 0.05005380243904168, 0.04108446417376399, 0.024339775892815763, 0.09049717742469042, 0.00969032659345577, 0.03816400294102008, 0.030206505945252798, 0.05860269249927613, 0.04491323372349144, 0.030752504469766736, 0.05586778542267219, 0.09999291385493933, 0.04371628262883714, 0.03620361841674294, 0.017395240570148154, 0.02400374483136881, 0.008082396140502346, 0.036251908769049955, 0.042575983736183376, 0.0354633093511145, 0.03139221661483809, 0.04541820057878091, 0.08328701069037761, 0.051595945091497515, 0.039483995417193066, 0.05609016542533233, 0.040121173726454865, 0.008550518954683457, 0.05367383984248004, 0.010073087103064022, 0.0376725307245168, 0.027205998100520625, 0.07277586302089115, 0.08412174009267362, 0.07511468348844398, 0.06238481878573376, 0.021725926030006622, 0.08145904063337273, 0.041398924114483024, 0.020824158188676643, 0.03498818928135499, 0.07010834486854654, 0.0027674423519431827, 0.034840131298668926, 0.022617441699689916, 0.06280500652088274, 0.06828854130881448, 0.011484141577966513, 0.04494653556555991, 0.06705056620581497, 0.029629810277612943, 0.07202856723339328, 0.04359756198321139, 0.10812794789671899, 0.04916286899618084, 0.06299345648937649, 0.0486768972909739, 0.031279306746118014, 0.042964516718301086, 0.063154622236447, 0.10314171142395466, 0.0053522986596480256, 0.049798021002882914, 0.048177607147203344, 0.018435689477971005, 0.11771660313130387, 0.02891576079080903, 0.09036664370327227, 0.024998709183907317, 0.019712463103895708, 0.0812470947482413, 0.10440631574320217, 0.04935789965994416, 0.02828769701262636, 0.09734782675701766, 0.02774896291685441, 0.08067946956162492, 0.020740641198391398, 0.014815066974880475, 0.06694316067883084, 0.010392849329828976, 0.025398984378684434, 0.03471520917129613, 0.011096778795153145, 0.029927762938783537, 0.02459085737955907, 0.05738652408904126, 0.01844799093481514, 0.027147924805420543, 0.041070433273430795, 0.06755876595214491, 0.01800228481090838, 0.0409071569541289, 0.04744164180010558, 0.02814307301906088, 0.04126718763502375, 0.05854015674201712, 0.03567871029278444, 0.04826265439811734, 0.03821004099482971, 0.04192199362742324, 0.06427449339459981, 0.033877285182355873, 0.04010540763697317, 0.04349087657887609, 0.0412730482076445, 0.04665326454766816, 0.04209583812964059, 0.04452761187548599, 0.03734448421446066, 0.014559048051465184, 0.05663421808651859, 0.04433557278506699, 0.08066512073480314, 0.030068121737830585, 0.022990691227718227, 0.03983809657755398, 0.046271760422255725, 0.00899017489920821, 0.03429158170136713, 0.09209535174792813, 0.027271113658864653, 0.021675241652936227, 0.03828731245331226, 0.10626523575234799, 0.06354979720086822, 0.020145733705571583, 0.05043988010936207, 0.05892662511717889, 0.0605699181887171, 0.017371802110104792, 0.04306212398073366, 0.03774870667726763, 0.012723096315899204, 0.04023154401370595, 0.07599615957587957, 0.011746537225741533, 0.05462913233185968, 0.024869546759873632, 0.025362870993933855, 0.0426358535074659, 0.03085699503219897, 0.04902223057504143, 0.04614383139978013, 0.015446477599682347, 0.0707864475947234, 0.057386681137065736, 0.06861392949377337, 0.02216283363410302, 0.04140874919211192, 0.05331498127610934, 0.06752881957518478, 0.06105389040444167, 0.014757681243692436, 0.034967845816525726, 0.05565167584967229, 0.03377181402738056, 0.04485992932572, 0.023225089234690514, 0.07045576574220773, 0.03365204001085893, 0.022088927216827873, 0.03264135170367456, 0.053756902925670154, 0.03345623942873171, 0.04572621005917749, 0.021387906970396157, 0.03066722356203583, 0.08116367543416639, 0.0497576060344375, 0.03354679485182128, 0.004548632207461783, 0.06609639603524439, 0.00649144985683022, 0.06255651824176311, 0.041708507905564005, 0.043906226468783234, 0.018954786825023832, 0.017468093616527416, 0.0349167630737347, 0.05493552153629642, 0.05852884545381512, 0.019385835771719297, 0.042514229388607126, 0.04110707525884913, 0.036370556636322895, 0.05527453842542826, 0.06809489726419411, 0.0715679492080404, 0.0460591710232679, 0.04541051288646075, 0.013593362621782769, 0.02136053847930124, 0.0452619569466239, 0.03970968491968609, 0.058859565610727, 0.06292587221269647, 0.02315056420141651, 0.023569907324628967, 0.013651511568065374, 0.03718509196093486, 0.022414882306850726, 0.015783579269003485, 0.04938355977496794, 0.05943727634486653, 0.02802497098943399, 0.052385207175487475, 0.018219522448376786, 0.05560486021661951, 0.04758717169264152, 0.09165781595173383, 0.016035839573540274, 0.06848771650824817, 0.059147614670256456, 0.1295630573745697, 0.0038129177541592193, 0.012421344816234085, 0.02947458362717542, 0.009727326724978705, 0.04981399393610416, 0.04952456974875062, 0.06370762280458886, 0.04725332972743819, 0.022842550890580304, 0.03506587059687703, 0.00424329350109122, 0.052896291242852334, 0.056449284461597284, 0.053981925931669054, 0.013889613610151556, 0.05966596125114349, 0.105110542067597, 0.04005898270876177, 0.044571301869807706, 0.037567975044611006, 0.042398898682046327, 0.04126696546952571, 0.11074504214188746, 0.03057088417511794, 0.01363839039714226, 0.12062751507807164, 0.0770359936981432, 0.04205246989224707, 0.060166657166255105, 0.08259391562352258, 0.02730013498465621, 0.004545779487553744, 0.026864320971071724, 0.04489229654052085, 0.012836823025868546, 0.029703862251593705, 0.019063690053899924, 0.04523116021206783, 0.016891461151141315, 0.011922263431422895, 0.02757193531931168, 0.02533645053664523, 0.01888604767079796, 0.07031444550281571, 0.04735839868625326, 0.054554101680555654, 0.049466094257490295, 0.06928992547815846, 0.057370011063833395, 0.0341722711680397, 0.0872915054881765, 0.03304446333899133, 0.022948027791215048, 0.05166658605899542, 0.02449873339144453, 0.0639942009753037, 0.05692750718745013, 0.04991198424249888, 0.03767400927421066, 0.018127863858676246, 0.02332256243173634, 0.04557952720431551, 0.10914994749210535, 0.05353879003274826, 0.00874515604077568, 0.00955151912245539, 0.028504367745030793, 0.06447924571412225, 0.03751003198445805, 0.06924636571878387, 0.034978563386586406, 0.01660090889931927, 0.022949604017119256, 0.05508003636233269, 0.03428585136369352, 0.03310470466291712, 0.03324551162339988, 0.026404229631166787, 0.05884288021573617, 0.05775963189080358, 0.03916621448532228, 0.1082711833559217, 0.044530817953449105, 0.026663590613151752, 0.04123255279996703, 0.048158872467015064, 0.024781281939677657, 0.037115929543130824, 0.009281007730732522, 0.07745240845026509, 0.06700118417821585, 0.0436133663770893, 0.06628008859772837, 0.03792188851343047, 0.03959176483594122, 0.03796942426913208, 0.010799471563058756, 0.04641297723977797, 0.045652887783944614, 0.07155250487548691, 0.02700738406049148, 0.033725343133893707, 0.009982239608953317, 0.02540399842414885, 0.0492190960193834, 0.09348927170879419, 0.1653347362674052, 0.09527885309991338, 0.12021722136846474, 0.12015569684726578, 0.16358797919125329, 0.20004798808405477, 0.17669718382098984, 0.1384446670811984, 0.12985970194060958, 0.15696989883097912, 0.10039578417255994, 0.23298871162677967, 0.1385562401264906, 0.08460608386104146, 0.09733727772630031, 0.07584806711923692, 0.1589867938309908, 0.08650297118771462, 0.09579927960951483, 0.08628322652751401, 0.21876363864829465, 0.19701074057769394, 0.21074036917378827, 0.1957834830447551, 0.14834837597464362, 0.21958123832460374, 0.06990961400010894, 0.13338606594310654, 0.10950987092069081, 0.17635078950514718, 0.16397117637097836, 0.19482244106550373, 0.16252780543460002, 0.15688873947628085, 0.29163861046394995, 0.11082686033220061, 0.17300465534771645, 0.13963306863461772, 0.18306139796491594, 0.12799873647670593, 0.18550125010792287, 0.2109183773638741, 0.18509554526498243, 0.19220327838293969, 0.16807728507105382, 0.14758945863333442, 0.14089202688586328, 0.1790106314564905, 0.1189428034629072, 0.17577334307134154, 0.19783653739479282, 0.17550014079578463, 0.0995870174900178, 0.1455804849824598, 0.12207493861956943, 0.1047877662424599, 0.1701668205280458, 0.11156662547540282, 0.1432088299864723, 0.12798034270564396, 0.05622867412204224, 0.1201041927561164, 0.13225329769474845, 0.21850310746700535, 0.14026040271405252, 0.2548178201240878, 0.18987981031738943, 0.18297889029547093, 0.19426600076258185, 0.2560798427270305, 0.11744553058017647, 0.09110362794730933, 0.11940873813845458, 0.09843392492902857, 0.19347460129328314, 0.11003602010708664, 0.1798158664737017, 0.28799270610174826, 0.10789180129405954, 0.13810283864938444, 0.17103386351898794, 0.10305164246669701, 0.15037331489786027, 0.1586194853148153, 0.16157367356842564, 0.19952576126783125, 0.2053318190718851, 0.2070076517280071, 0.1546450058418897, 0.1747532816784036, 0.20633855053494055, 0.33778560197641777, 0.32556220949176823, 0.13687141359813754, 0.14230748157828085, 0.2344261530426241, 0.23610298161304769, 0.15373375957771657, 0.2082862984389067, 0.17860429842145215, 0.2128758392627201, 0.1713451097208646, 0.2944135341432787, 0.11563891905450052, 0.11168018268841891, 0.1335784765861688, 0.08424417626473212, 0.3057202871047682, 0.1375680939564782, 0.10466523813985049, 0.11262406429816639, 0.09751285741766615, 0.19730870281496357, 0.15219036820194415, 0.13814209299462457, 0.1833293142337953, 0.18263232744028493, 0.17483179036888385, 0.15969059880702727, 0.10675897175866751, 0.14984923414885998, 0.13545585165341056, 0.1298133689429491, 0.1398462555821865, 0.24081022418554754, 0.16699658015802984, 0.15143276853186471, 0.13905692455028335, 0.19928418310178866, 0.12995201553548538, 0.1711988635361195, 0.10063190013170244, 0.15928739141072, 0.20615842794218373, 0.11641707286358842, 0.10991170701961364, 0.11648782874427496, 0.16976623315243952, 0.12449193835979509, 0.1015897015590341, 0.14088363056221317, 0.1227637972202032, 0.1369956730594558, 0.1935347085518222, 0.13650952898446592, 0.11681708567325147, 0.09525901908355375, 0.09350696833984506, 0.22671707154762363, 0.1871217252506364, 0.16381497104321757, 0.21794069167827407, 0.07220632261446408, 0.13146431906329048, 0.09632331439323964, 0.16830450674939543, 0.1394228387864367, 0.15124567453899693, 0.14109758359770622, 0.24632135346051187, 0.1279845561892275, 0.12302202247684041, 0.17502597833593048, 0.1320324192244199, 0.055296846905783306, 0.11976466258807529, 0.13214961535507633, 0.12277865932593424, 0.1553024624985072, 0.1657226985140193, 0.0826012394240787, 0.1027814279340448, 0.07202737979711064, 0.08603547369280169, 0.13785563739797763], [0.037027860075355544, 0.03690310265688646, 0.014134102910306427, 0.011422083668050267, 0.013212298039316893, 0.053833603648649114, 0.031434479770400835, 0.02228265936155954, 0.020221225924849994, 0.04207775079374833, 0.056786738531363595, 0.03193360520526767, 0.06076234032309825, 0.10013135360373605, 0.027457209822211056, 0.027243005892922802, 0.045878374273137706, 0.0013646500156028198, 0.01778423512024024, 0.05025187064142478, 0.047346938010906024, 0.01642658750736906, 0.034370921597245245, 0.012328827250448447, 0.03903107274503958, 0.03450191497141796, 0.01819784982099889, 0.03565930528566241, 0.0014156106631309096, 0.06524901852131852, 0.031643865006645365, 0.015466173720215599, 0.05084953413555219, 0.0438915980198691, 0.041982380508054654, 0.07607753343519665, 0.10369610627211871, 0.01974347051263096, 0.026700427950990778, 0.027989991414811344, 0.050725416400499886, 0.02084742044849742, 0.023495914722462336, 0.01989610012500517, 0.05144899410586204, 0.02615236864996053, 0.08752163830063037, 0.05467306747431717, 0.07677860347734344, 0.06003354555897175, 0.05886085646887941, 0.04027100137224601, 0.020070632191134558, 0.03694995276389584, 0.07124322751957564, 0.07144676175929847, 0.02333175740204752, 0.04921575970647316, 0.05702319156919276, 0.018349000883679238, 0.06826159033563829, 0.009320653738423942, 0.02432707032459157, 0.08841017771872783, 0.02978412528342057, 0.07829725787404083, 0.04972364918719377, 0.02196325623850909, 0.07572936179536967, 0.08329820323495135, 0.06161022345505415, 0.02972640630398547, 0.03253269362293425, 0.04688392213035015, 0.03216312897782172, 0.02978595431833979, 0.0279135798900238, 0.09892151691019536, 0.01862358977837909, 0.06294471031475453, 0.018673100125705524, 0.01749347410945883, 0.07931971712218178, 0.017568027871029995, 0.11048823414791016, 0.06652243285169525, 0.04542806779124564, 0.058837119234545585, 0.0437790597037923, 0.10296223234505424, 0.08946741735863109, 0.016709423338573788, 0.08687515968396779, 0.052450922197632255, 0.06154815501142895, 0.03888672262790703, 0.09785313835187305, 0.0424074482232813, 0.03011118928571382, 0.06338767767433198, 0.029224961537927873, 0.029435252673142863, 0.026213192200708776, 0.005011246370662365, 0.021829347899784485, 0.03440404723909113, 0.04705385575371404, 0.007980012798666834, 0.06166381513579719, 0.06075276805448437, 0.08888523650145339, 0.042297376710320675, 0.018461634960746574, 0.08605248850559996, 0.019488075950873956, 0.04307493680126725, 0.036706811778487704, 0.05759988723683262, 0.03871405407065346, 0.036113315802668376, 0.009114054189394078, 0.031954189987793084, 0.045261386211120316, 0.05906105056525238, 0.035610880867968646, 0.04767354427566452, 0.05094555176554188, 0.024125707944134073, 0.021368013582222407, 0.04954498216149308, 0.06706849266324313, 0.03867655789719955, 0.02172879311406324, 0.034085308697315, 0.07669664739120392, 0.06554108954245044, 0.031210038991224383, 0.02438493294551248, 0.041323908784937476, 0.07907606285786437, 0.030699341798261292, 0.04660994993642934, 0.05241134226502431, 0.07619988533758348, 0.023207250877373645, 0.052103302141110745, 0.056033179975084724, 0.09045882706320094, 0.07106210901251725, 0.0315554412232051, 0.05841740264347004, 0.012046896360604274, 0.05582062121961386, 0.04508400621313242, 0.01950684318979902, 0.03504696737734541, 0.015706680320774116, 0.009796786001853405, 0.048781606188464555, 0.07494076620787382, 0.023318454285242388, 0.045067290174624616, 0.03518496279514605, 0.01839830438726612, 0.028338553759479718, 0.06290645188381595, 0.04924155005644407, 0.032799200290032936, 0.07556892766226685, 0.043624095438468846, 0.014608782479509473, 0.047355709717639034, 0.04620214601257636, 0.03290234253771844, 0.02366253693077353, 0.03285269620978544, 0.0734082915850224, 0.07217174906644129, 0.051343228007035877, 0.03388251756287871, 0.029366454147102854, 0.03213444281549704, 0.042414228101411176, 0.01623342609814098, 0.09985174683313217, 0.002466877809755745, 0.05617265777301885, 0.010530271139296313, 0.029416031527122664, 0.06155148749389957, 0.013187658736452222, 0.011429442900172886, 0.05132603699401502, 0.030205843279198296, 0.01904510667607669, 0.018322475089301026, 0.024524780380870068, 0.03813176979160598, 0.013218585705955424, 0.039882843773211205, 0.011998681659479777, 0.04286320925119423, 0.045934720039968534, 0.01754488435483748, 0.04543874322647049, 0.039633991602327556, 0.043259525686622634, 0.09853959143642457, 0.0506683083761844, 0.016604687628005783, 0.04939854062432724, 0.03960164353972481, 0.01101868858020152, 0.03420158552246229, 0.10968127543286932, 0.02673716952783927, 0.047537713056249965, 0.03845128974306487, 0.020454792726424434, 0.06729340075605339, 0.022287175449873173, 0.030241518078612226, 0.0604011643407566, 0.019441137743753292, 0.037455149445562594, 0.05725492550540836, 0.042206530173819874, 0.0326694211652202, 0.010147615009167743, 0.0419788641644822, 0.04879194837544234, 0.05667762845874794, 0.044070713207005494, 0.03937995684663615, 0.06413753602593657, 0.010849894512624992, 0.03933450485008859, 0.014233871498295378, 0.02721123239626327, 0.06882012205859346, 0.046275131209122564, 0.0227440262378584, 0.045317456186298406, 0.018900162840802825, 0.038269784361604726, 0.03164137330567164, 0.027667215589674252, 0.04692199286974726, 0.0449846024745174, 0.03582897077825281, 0.024930366480182257, 0.033379274405418866, 0.01207672303632623, 0.014508438367967405, 0.029124841507103656, 0.08876145201464815, 0.016436284265270638, 0.07888735241947636, 0.050509080831562324, 0.06362289731060305, 0.06897346987839668, 0.1226235724865429, 0.04997136754794948, 0.057254366261223634, 0.09091242006228817, 0.0410916232654164, 0.028998837280537815, 0.03441669152028138, 0.1458489068693692, 0.024440981853272647, 0.027740101194790298, 0.054401696148899295, 0.040278857603909514, 0.09265859491161763, 0.03677010979323137, 0.10403360630716048, 0.04671858503453193, 0.020859532298580296, 0.01361842614583551, 0.008267881348729134, 0.017980437898527712, 0.024495249606608867, 0.05811685102901632, 0.050395753444923516, 0.07947619058071606, 0.020730747172849315, 0.0168214981714564, 0.024661883306238922, 0.06497873504075312, 0.09708735686276229, 0.0048511239395837395, 0.02556187190836476, 0.06566553286487056, 0.06842163376389973, 0.018698254622699275, 0.0228736559755259, 0.018021161217362653, 0.055266720498160976, 0.03835395444184542, 0.035834501933066115, 0.009123492392621214, 0.047089180067902615, 0.035721094107195255, 0.03651817794889212, 0.05077778234056408, 0.026876861830392194, 0.031316211116650415, 0.05245358052272951, 0.025261220702480887, 0.07452787546020362, 0.03958202019754437, 0.05474543597008433, 0.03501670307389671, 0.05515635787178913, 0.020681700308717067, 0.04540736426509196, 0.05189194997412063, 0.05549706398479401, 0.06480731520681612, 0.07110637357278217, 0.021613445170524142, 0.038587415906330275, 0.02528193188951381, 0.054607011543046084, 0.08316445960513047, 0.038473146231544596, 0.04720120510507015, 0.028026371015115615, 0.03508454782047099, 0.04404446703471965, 0.044910211506630146, 0.016379576521895586, 0.004955863480591366, 0.02118163396634402, 0.04334276880047495, 0.06239802231110873, 0.015862502604572764, 0.03929615831903873, 0.06414636135882427, 0.06385311439272857, 0.04025851796951987, 0.03326926034905257, 0.057926405401479815, 0.04158569251998298, 0.01991762719567745, 0.08049776116686483, 0.04931840016656826, 0.026030131660762335, 0.08030457677499903, 0.04048852054702659, 0.027372857796088345, 0.0270103047707028, 0.19471040836745696, 0.17149858777561497, 0.15941525148528238, 0.10041980102898614, 0.14570583228863057, 0.12121879705978979, 0.08812288708624341, 0.09189446051154407, 0.18412451349919845, 0.17776291937597338, 0.13790256794421904, 0.10429042962289627, 0.18088492685027663, 0.1784371840016496, 0.11291058118184728, 0.08463466660149636, 0.10878257768889589, 0.08407313181387802, 0.12457691283235628, 0.13482520807414286, 0.09710700701802008, 0.12366347555671969, 0.19869495423570757, 0.17156247950849995, 0.19906606254798753, 0.0738672471995796, 0.1389014240234129, 0.17427945629723612, 0.10781742947837038, 0.18346238370624282, 0.11910539030307725, 0.16445885262181684, 0.10731761839481131, 0.149604331161226, 0.13262062153268245, 0.19647310007243388, 0.17940129033259808, 0.19694652708788074, 0.1869133493352321, 0.14326101589587428, 0.087581385497845, 0.12227277316513563, 0.09561210900785462, 0.16335928662409707, 0.11332318847698551, 0.19074404942652873, 0.15654015414897474, 0.15731875994993796, 0.10447989848832931, 0.132104201662925, 0.1292128632626226, 0.1546113745820138, 0.12585815658131916, 0.1524651332968666, 0.23570404898735786, 0.19668165984894, 0.11427716712557501, 0.09591112844645978, 0.09050255536191887, 0.08649143390357496, 0.21334828568562386, 0.15011552631133987, 0.1736703704321577, 0.1321027920611443, 0.05913647575183742, 0.20422315194962487, 0.17012873063645056, 0.12136963977208062, 0.24647610322121652, 0.18381996290577998, 0.12970447720539185, 0.11597653400273093, 0.06963603634146914, 0.16405011407069622, 0.0617519956863215, 0.18675159753089954, 0.08826702652919678, 0.1810385887661288, 0.18640212354160127, 0.1944019047603492, 0.058490234622431386, 0.225555069384075, 0.10516609876386582, 0.2619249097281887, 0.2934754135147218, 0.2769607029134228, 0.1738932866963648, 0.32255837874066445, 0.1706772342684769, 0.13415661249910632, 0.20836782551580862, 0.14382378408505073, 0.20582021544537238, 0.21394443998654045, 0.20873107376598543, 0.18792708284191548, 0.24896886139627428, 0.2474923188527746, 0.12533777603699317, 0.14239696064783683, 0.19144649076606, 0.16806075289364786, 0.15730435749696148, 0.11089684246408363, 0.10838775129448022, 0.17511565658834674, 0.12098378426725827, 0.125329441000377, 0.1620207011940018, 0.12231201218861727, 0.15567283536637985, 0.1490799592988145, 0.20195510268451708, 0.19947999517523474, 0.06393537691403782, 0.11801401378526805, 0.16555808154084992, 0.20970037417306056, 0.11602147272036922, 0.18539266480553537, 0.09935478559665142, 0.0980531485871442, 0.20971335170249786, 0.10656603251493747, 0.11125295843568542, 0.13504984037530038, 0.08885417929700307, 0.21326781581005744, 0.19350038781281442, 0.12157562549316114, 0.14669718070616647, 0.12291552859448618, 0.10818305260111248, 0.13476226629028398, 0.18715894180199794, 0.14135318117276316, 0.19510325825502797, 0.12471048792283382, 0.2132939394082754, 0.19679402962567347, 0.17028544158224138, 0.19262834992860595, 0.23002905350538994, 0.22780568248802618, 0.13567144411706156, 0.15012738535240774, 0.1137781527734572, 0.2916135440670675, 0.13232085132791152, 0.11566222344915714, 0.17910734239605167, 0.06858795145226103, 0.12086587567483226, 0.13788263433642928, 0.12568281437720985, 0.1246437080384743, 0.14800820229274614, 0.14541174645625776, 0.09841845761383734, 0.14579376386057946, 0.08306506735783431, 0.23417058611108413, 0.16520531337347724, 0.10180691812908459, 0.08393306795868181, 0.09806955819048228, 0.1544061855923745, 0.1515120739537862, 0.20050094523016485, 0.1824538136321691, 0.10993524890152678, 0.18838848227695112, 0.27809218413406805, 0.09634733891054507, 0.19039019341430358, 0.09550785210223929], [0.03473262618025465, 0.0647328744432138, 0.03286316480127073, 0.001208887103618303, 0.07171283175628032, 0.0365241342825034, 0.09758241054031158, 0.040616710039396445, 0.04462413129306609, 0.023143916473453565, 0.0716660084623483, 0.07138362079257927, 0.043133707236378424, 0.02518617089897875, 0.06489631930185903, 0.034464058736639644, 0.018088262858650377, 0.04348144220608858, 0.01791176003133578, 0.019443573903352506, 0.022201735578897982, 0.11096965912128649, 0.005585525030901115, 0.05359804310325173, 0.05754317757823775, 0.01180570506896343, 0.06677043849542257, 0.11145057081575356, 0.048312212625939044, 0.012068619741307152, 0.017527030675762126, 0.0739588100282896, 0.011406668063793934, 0.009756666934868742, 0.04723037390278713, 0.03297901261718043, 0.017893776117313295, 0.0576443586408371, 0.04803573915494546, 0.006061715229729852, 0.0176535960617325, 0.011590924658512157, 0.04655300279057795, 0.06070992458731898, 0.038571963912897536, 0.0656335027287564, 0.0338034994239288, 0.05354779156585855, 0.046926489805862795, 0.035152078470996315, 0.02937494048608407, 0.023108900509654515, 0.03140017818359118, 0.012683029917459334, 0.046956677500519066, 0.025903365176711834, 0.03617752163160232, 0.06533441434223806, 0.053108187332268686, 0.04157911182471341, 0.012249572581851916, 0.04865583753393543, 0.1135964443786971, 0.04891492463948746, 0.05421320787600933, 0.05170101788075221, 0.026065503855446176, 0.09152399571312052, 0.0713850227334807, 0.018113656758120465, 0.04587695701047779, 0.03598019653450578, 0.053757971618324525, 0.04019754503162638, 0.0611239453146775, 0.04063064517873911, 0.08397102761532992, 0.03202105414182429, 0.03362848663762693, 0.10359667572042636, 0.03805331855772003, 0.060421772105919744, 0.0645436124215203, 0.04541542351005539, 0.03237371888732718, 0.09422526769940892, 0.039540360336222, 0.0479506612605145, 0.02729319997372166, 0.06485060683541721, 0.08966938111810915, 0.020582264011365273, 0.06474287189062565, 0.03972427123376439, 0.09856364659724698, 0.03388456684807616, 0.04983242218112273, 0.08437556800462546, 0.04371379667352285, 0.12177710661724692, 0.08774107652566127, 0.04485974546461817, 0.08894772629343695, 0.033759912851476864, 0.020606750096645088, 0.005077363110162439, 0.016471597088140347, 0.027595684044964375, 0.024867231259122494, 0.04134812099378436, 0.07746088904358688, 0.06056377033312475, 0.05675899082674615, 0.08270017967949952, 0.008747626674331484, 0.04685057815344584, 0.05153176990608054, 0.08459374218458131, 0.03729548140038406, 0.0650362529221081, 0.04601067765766094, 0.024203959995159702, 0.012550648966533764, 0.03677519278660898, 0.08033946441907076, 0.04443365119157299, 0.020409670147684314, 0.013870171256243222, 0.05450119564850485, 0.01868717890653399, 0.06471779017198472, 0.04469381465065864, 0.04175699361029171, 0.0579193688838953, 0.031910454028195916, 0.04629919786126383, 0.010693717913161363, 0.008395528833892558, 0.056869567957736795, 0.0509728130043274, 0.05901640679146494, 0.023992937245977022, 0.046986892008252686, 0.03633722798117707, 0.022419049825158813, 0.07503225242779141, 0.06705538489885869, 0.04204378245518573, 0.011579296401431485, 0.06579644963025086, 0.02711309461794313, 0.029520696374557676, 0.06358402217888544, 0.029808239816057108, 0.02376226625675636, 0.04387680103161162, 0.09414035451388168, 0.028095209760771647, 0.06327378721306882, 0.03849566538607882, 0.02331341534192043, 0.021545705761039452, 0.03821959794168511, 0.062398684977163235, 0.05390605258364832, 0.0051884334102543376, 0.028739633346577326, 0.04417546423933199, 0.02962177976094667, 0.06376515983814193, 0.048632831913569284, 0.018214881870775454, 0.02769528888165951, 0.027817640784046346, 0.0558889945668559, 0.03019161894166422, 0.025962899784527482, 0.017155579539136063, 0.04935223827018373, 0.005852310362482263, 0.05369335593235108, 0.07210490023416859, 0.0869742761396112, 0.0413944999567203, 0.06058325960991844, 0.03465650385365852, 0.0284222201369102, 0.030317621253010248, 0.05524141278358237, 0.05730714588876694, 0.039241459641245105, 0.03912305309166832, 0.0839742451846119, 0.09501875858874091, 0.05573694909652395, 0.03733978809548482, 0.018413683602346048, 0.049353215032287186, 0.08330586411419415, 0.05451082537371305, 0.046616254840046174, 0.03108919245160876, 0.030886286403983835, 0.05478119695438974, 0.06302307727896879, 0.03317355681511183, 0.03004841604119828, 0.020075100398952925, 0.02885651921162442, 0.051209300516113165, 0.07602547009986255, 0.0305342766636562, 0.010936791865876126, 0.028649246462831096, 0.03504079270867571, 0.01724750817482991, 0.04992572785986047, 0.004190066669722118, 0.029977817208536213, 0.07475557211305826, 0.04640001120165952, 0.03859506146381459, 0.030404593299834, 0.06053030761259218, 0.03074390896325631, 0.057484047081802166, 0.013433382395775089, 0.04601963322549578, 0.051056615362364444, 0.026852191884010553, 0.0576427843301527, 0.03342910459445369, 0.027551436721677744, 0.06315564113338629, 0.038103160238073724, 0.04792445722306448, 0.019575553615727735, 0.02681242425986115, 0.061924920883029706, 0.015368998339850337, 0.035004043470947974, 0.02899499918003717, 0.024318068791481278, 0.06300232395710004, 0.043332595152840506, 0.04430480286358826, 0.011502770921065202, 0.018310533693781304, 0.04221165147159369, 0.048297388824604215, 0.06193607512320723, 0.008444917564761014, 0.06532146745631773, 0.011281706674415018, 0.03641038554750624, 0.06795887069235887, 0.04690903832294768, 0.09241178436505218, 0.019176153676404108, 0.06997914414011663, 0.06186865172499131, 0.040314974819099715, 0.010321026671707872, 0.11370395715799063, 0.0333595936066441, 0.009048590061044502, 0.020734954910773425, 0.05546237935402221, 0.11306068078885156, 0.16378688625991344, 0.04744820717361666, 0.0621431601804591, 0.07992013087195736, 0.04181119433093456, 0.03385072874446069, 0.020863684495129896, 0.08688636755030002, 0.04707736316167059, 0.13079984504128658, 0.12151511986890148, 0.03998287953436375, 0.022274328155382987, 0.04000548678900927, 0.05526318500239042, 0.07822520730476226, 0.01358110138455466, 0.06332801091634939, 0.04986922887544479, 0.00828284783393986, 0.017196446499456803, 0.043776022165172526, 0.025216096208520958, 0.069877085906844, 0.08302020524898845, 0.01830569584853947, 0.059090966298695535, 0.034985109607899384, 0.07849668588248954, 0.07046344194320903, 0.019086391154316165, 0.04731873448397364, 0.01809303941685827, 0.007282565394791985, 0.04590370113991442, 0.0966620478298395, 0.044245959650124275, 0.04519989616387794, 0.05291928537189961, 0.02511413756667847, 0.013285007444210352, 0.0266727089746705, 0.047673165062141996, 0.038076381634680495, 0.03556740537826573, 0.03521044287950762, 0.021123062714093158, 0.09407550517109134, 0.06351954438873837, 0.01822426261740827, 0.02033203862787735, 0.01376340445506597, 0.05922423878444299, 0.003509705420583487, 0.03750001538484808, 0.04100833801672824, 0.021326658240849936, 0.034048766303326816, 0.04880085031712248, 0.025039700633515755, 0.012382551081358426, 0.01418549017304735, 0.05003503711533643, 0.1297765201137912, 0.026905005985510447, 0.039582092975897175, 0.03582939978749041, 0.014823865494690837, 0.007320514996536077, 0.045003927042407375, 0.061340843958239404, 0.026711371516989126, 0.03426029467053952, 0.05819920931131609, 0.06770436862303365, 0.06121230972630363, 0.06466344389463625, 0.038194133179082025, 0.03502495001040159, 0.03877086332067847, 0.03344290566840961, 0.013103548028025658, 0.08174899725183364, 0.09087695019139398, 0.18971808915657384, 0.22432019693716881, 0.11924802821369902, 0.1613056194037199, 0.21381559931943495, 0.17195015064170285, 0.14398205785020707, 0.1093779659018882, 0.09508966002613307, 0.16521030826674354, 0.24129846734144997, 0.3210144051380696, 0.12895237804660875, 0.16315422020852566, 0.13826007053496378, 0.18252225592732432, 0.18499531032096955, 0.11544506050526135, 0.11830167980083536, 0.08620304010447957, 0.12066973418357874, 0.1033546762060254, 0.14621745644798204, 0.14387679736941092, 0.2572571053620308, 0.104144053203204, 0.21651808172464374, 0.19144100557652213, 0.12097517343898936, 0.1897542178630829, 0.1420866184297108, 0.0794392038557318, 0.13504361974135523, 0.17345652464897404, 0.08184187009089416, 0.08413451843925061, 0.13505858909939567, 0.1156787173221669, 0.15345899448279413, 0.13139304224281542, 0.052252099398643746, 0.13037685725477435, 0.184012649340495, 0.11027659469794844, 0.13861902869276463, 0.10178525316258592, 0.20575532779818584, 0.1670125913956473, 0.18818857929398938, 0.07703713516915038, 0.13484526425600052, 0.13969676118464242, 0.08259868069041161, 0.20562189060353464, 0.12546825613225662, 0.11687605912166259, 0.11448563497153022, 0.15962289195627938, 0.1645770599885333, 0.08697390841740756, 0.11519072697527948, 0.15772725335292279, 0.13877497355063118, 0.11262236358297449, 0.11093551458250131, 0.1294029143548781, 0.16213181458653944, 0.1725649668444549, 0.08831052500153742, 0.08323438044997954, 0.24967266637231075, 0.15851687549823718, 0.13887732289731503, 0.15445771266616162, 0.09427233614147672, 0.14598729299201121, 0.09391820433759883, 0.12286966291045952, 0.22575915520710332, 0.13670287425479583, 0.2047877281063026, 0.15826250366385908, 0.18079953869023632, 0.10055897622219018, 0.27924355299722764, 0.11537235110036789, 0.22592182631694505, 0.1305754885317818, 0.1296655752605969, 0.17688155054084717, 0.13679209285445754, 0.21006740689758333, 0.3607637351078372, 0.2168961001500007, 0.12827593773122759, 0.2167551246501746, 0.2157238324082667, 0.15616778945249898, 0.18632471801773196, 0.17114114647190418, 0.12748048565680944, 0.239090770483017, 0.22460666785557426, 0.20876240676208851, 0.11248907960590818, 0.09518689190548274, 0.21798913907860556, 0.15645069040117726, 0.10331439530296672, 0.1244129240512848, 0.19068355912402754, 0.14282292085549525, 0.15246482686169688, 0.12270128444558191, 0.15895584387884987, 0.15797129832208157, 0.14095777255152503, 0.16300304041754815, 0.34637920858879245, 0.21187960320422727, 0.11005577751465383, 0.13348306799607892, 0.09850966804210218, 0.1154935155664721, 0.13543780262191452, 0.07815928543887793, 0.11489430457473764, 0.17857235255500964, 0.14262769100887163, 0.184267649366971, 0.14671058724484137, 0.12135167501025623, 0.12490997721831645, 0.17333431830329282, 0.12655777871728907, 0.09438473656172715, 0.07533586073306299, 0.15946777447337107, 0.14935218098182834, 0.20807081322756507, 0.14096776233805766, 0.1468619662186792, 0.09117783888453439, 0.15023810037922475, 0.17973535063285984, 0.0884019575953003, 0.14893106244985135, 0.0942622391026347, 0.15400489341587792, 0.10307924461460884, 0.1424279718870117, 0.11433876059468716, 0.14933535769101114, 0.08056713042840843, 0.09581653957044887, 0.25042035286465003, 0.13556273624060616, 0.14967965292594126, 0.1444228035548041, 0.10013379742421451, 0.06855144736266906, 0.13853927893984702, 0.13102081544216604, 0.14224130690338152, 0.11079214122747222, 0.11310112257037433, 0.1519850413164785, 0.15952274894281743, 0.10743558061339202, 0.1297140226609284, 0.16491354112663578, 0.16883182038943614, 0.11763389627899855, 0.11434940155595542, 0.15349994954322616], [0.060093377025858055, 0.02261111764387498, 0.03121340786287141, 0.11871229526737045, 0.026432080757654002, 0.07368173134783584, 0.04971251792965397, 0.018791880143145402, 0.040021126473983454, 0.03531972915234585, 0.013833498627307915, 0.008614618488917909, 0.04052074603556145, 0.04426088304288926, 0.030193576296310753, 0.07186815608292818, 0.06539123508358194, 0.026628877254082795, 0.04182878754011566, 0.020052339926722552, 0.034673020709306, 0.022814406735462048, 0.05261396486011725, 0.029968863555921182, 0.05969408816928345, 0.11205152848795538, 0.029237199792518254, 0.017046396688167608, 0.030270041447253, 0.07650385370417949, 0.05925761340486427, 0.019770522992457115, 0.036144587511737505, 0.032756280214075124, 0.04617195448748047, 0.08577081329760053, 0.020107998129641338, 0.06268221411793944, 0.0520063613751723, 0.008390621083127636, 0.0335873362247742, 0.031096983565798694, 0.09954508949792194, 0.09515359772429352, 0.03372896672977555, 0.032631300630108, 0.07008762219019475, 0.10834665067734257, 0.03965957127811928, 0.005364811269476289, 0.016771252379722653, 0.0917962633614098, 0.032274326640031034, 0.024503381629925103, 0.0390168656444838, 0.06993726211329622, 0.014037878436577177, 0.03702796732766494, 0.08555797108959767, 0.021691980674081755, 0.07024554355490593, 0.005545265674065318, 0.06872909549143046, 0.049233272476422216, 0.016258469512385708, 0.06234855218339832, 0.054903284556442694, 0.0782950132364227, 0.038007464365012227, 0.028210408317165512, 0.020962011880211292, 0.009773899125115526, 0.053310978466704975, 0.01758822960959327, 0.037816750606702226, 0.013777698698123137, 0.09871449697041705, 0.052658941882151755, 0.018760037698572683, 0.0513364672811041, 0.013941088973003772, 0.011804918871231139, 0.058168362781044945, 0.09939682850193593, 0.011671360060121986, 0.01414495837619348, 0.057067881308255665, 0.051692709657213384, 0.007113228841204077, 0.054100351633443955, 0.06786097231651507, 0.10028198947228732, 0.048555591098603704, 0.05739015534580235, 0.05788395646959544, 0.03757208510632477, 0.09588828370455774, 0.06848935593640612, 0.028540232151205984, 0.07256063061856455, 0.08448628303144248, 0.05807930889028696, 0.01173431812334926, 0.022953269747836937, 0.09957283720253937, 0.012950318951850698, 0.026109567317630977, 0.05112929795418055, 0.02307296140990671, 0.06782787731818615, 0.018540618625739892, 0.010795081879252629, 0.028832718775036837, 0.03235996760908635, 0.04264451030101027, 0.012990496433039588, 0.14053838537825694, 0.047175104489489916, 0.06802710614377452, 0.0285929428308361, 0.06271329430502749, 0.005052798979675337, 0.040037892308206334, 0.039447104453199336, 0.00911892267815288, 0.016072974728059866, 0.03412756610721831, 0.041281356431183316, 0.032867929868159756, 0.08460197762976732, 0.07367164196987307, 0.013573539139132106, 0.0514261148900034, 0.045753800715770454, 0.03886170219630003, 0.011867038068181325, 0.02396007590446501, 0.013759361426045578, 0.026560743309317097, 0.04946586826155263, 0.049951545022908724, 0.038229032314472625, 0.07018380452908816, 0.05203436954968399, 0.028491505128782124, 0.08414941884937786, 0.018217647448182106, 0.022866134907329277, 0.03352562018159417, 0.0831374396840411, 0.01914018201791952, 0.05821217917987417, 0.02011425706798271, 0.02368433404743912, 0.01672234915707621, 0.060088048884344686, 0.06276715411654403, 0.07748860610468734, 0.0654249812566465, 0.050609277471178965, 0.020199677786759792, 0.026926412397334655, 0.046669425172430855, 0.07353700967806001, 0.012291831906975038, 0.0163392209252643, 0.049867363451349164, 0.023963559689300678, 0.03451227248015423, 0.013929136086165184, 0.05230316681967628, 0.017793401362254255, 0.0642898304748439, 0.0886218095078103, 0.040755414088527044, 0.027944462809471354, 0.060603691174859003, 0.01920552548742102, 0.043450101549106265, 0.04236858458288255, 0.05422801252514605, 0.03813289211041505, 0.06961055625710758, 0.01317216843862327, 0.03268738592704458, 0.02076200547537977, 0.011619842562433935, 0.010059803138456998, 0.02767292485992995, 0.03141761242952799, 0.029140550139991027, 0.08286536355773289, 0.05504546281430991, 0.034353121544324586, 0.02825419024203814, 0.013365461040408382, 0.0637667264879471, 0.0366011988972464, 0.04814700959550758, 0.03336572614047797, 0.03434809983798093, 0.051888303395601056, 0.028006847264365326, 0.012581829702661885, 0.05152242363340432, 0.024299740137892867, 0.07275353921877761, 0.01865310140044218, 0.03345698636445788, 0.011026762189313529, 0.02455909920465802, 0.0411212440550087, 0.022321513425859234, 0.03976450234110798, 0.035796477158944455, 0.013674017316060922, 0.07485979837515662, 0.03490380086605588, 0.07253500497749737, 0.007827841881437288, 0.018871915263814792, 0.03313223403247614, 0.035261820566149495, 0.05775277923432089, 0.03714218720673554, 0.03203560406672618, 0.014549195203149031, 0.019311398838556582, 0.015206970743865017, 0.037604774078053814, 0.0496772472416201, 0.06817206530080688, 0.011689196502219045, 0.012705187095449337, 0.05449584835479337, 0.043837853121541204, 0.007587223240519844, 0.023086168765721303, 0.02628892190724371, 0.06288185280056731, 0.08391331055111463, 0.09782841669455652, 0.03364788781430933, 0.018191443410732092, 0.06358405665284203, 0.0535171595402062, 0.06267084920358273, 0.04259251591358935, 0.04531402028195801, 0.04785897968817623, 0.0587148477713908, 0.021891046705986225, 0.04827710664680889, 0.03499360169254003, 0.027324789609279365, 0.015845708042052726, 0.018569032826851455, 0.05842232858882316, 0.0484810469131316, 0.03983473345156639, 0.026294100661611846, 0.08799546368179784, 0.03890471037236914, 0.04047971053589736, 0.09408115123909327, 0.02913697250938464, 0.00785798839886763, 0.02871394067281677, 0.05994809994233712, 0.01802497825044538, 0.060643259616148096, 0.050922377605832396, 0.08000233210623264, 0.029980427653138197, 0.04223319003358484, 0.04306026621751728, 0.028777041419919942, 0.05627170145030945, 0.052743406906243295, 0.030664530762981985, 0.02312319379510178, 0.03998930318160884, 0.05265829453785574, 0.04805078512177833, 0.06138860187943905, 0.035037797304891774, 0.01630761213750849, 0.02626537427967114, 0.052607817004524896, 0.044037606717357715, 0.07801229614884624, 0.008702634330538493, 0.05550143451640203, 0.0347369852205438, 0.07488587600809914, 0.06541569627100421, 0.025847938715390144, 0.05635151249026099, 0.05718037748949663, 0.04614356709944625, 0.04244425108716373, 0.048503393697882854, 0.02957184615004207, 0.049092752798911066, 0.03500048116210007, 0.02202869546900113, 0.010456374298120219, 0.11114377558471696, 0.03218480926607886, 0.04463718543129583, 0.03921499513390084, 0.01728995519149448, 0.03507050542881893, 0.07831446420882018, 0.00547335826746759, 0.11017358651564968, 0.06966295667112836, 0.03274331034551705, 0.08447073910745882, 0.03980113666564707, 0.05744896025487012, 0.05843815979577842, 0.052983349474567565, 0.021708403683958516, 0.008708297635518737, 0.014483239820918009, 0.06251276696040746, 0.042339791168248465, 0.03900334419262025, 0.03376358624307379, 0.018363822769794255, 0.06575442204672484, 0.007513862182085793, 0.022004165333665667, 0.03977412823587656, 0.01233716994794386, 0.0037800341482169086, 0.00968836157792999, 0.016707105922602838, 0.012237682897267083, 0.033772350288927555, 0.0239617383152607, 0.07915706899497779, 0.018552150164220124, 0.055554853827362104, 0.01757728029793549, 0.032721001865162004, 0.0704740139565641, 0.035474421456456184, 0.040179335121666236, 0.028741621344740835, 0.06687203707594065, 0.15029753348039043, 0.09304567615711883, 0.18780260887597838, 0.19119768073001217, 0.14018391649569237, 0.15798240659698365, 0.20970716171206968, 0.12020463454386882, 0.15091901464808374, 0.20245872888593905, 0.1377062808962599, 0.05330061329708946, 0.14529977504524494, 0.14970171625816053, 0.11672027514226015, 0.15651945445326068, 0.2294871688730294, 0.1379629816379278, 0.10456493424792444, 0.19249728760652005, 0.10152854476003878, 0.085288530305749, 0.1621495112175903, 0.0955449001142575, 0.15924168660515742, 0.11480266513723521, 0.23267973304515888, 0.07939180599585657, 0.10911562675309759, 0.1759191602468491, 0.16661862301970684, 0.12972595831078867, 0.12782590704098826, 0.1647429333458985, 0.11009055790641617, 0.16753598266551573, 0.1762246148240182, 0.17774422683062094, 0.13922505020614595, 0.10077647624477264, 0.13688351778734115, 0.20484063413835343, 0.35350817766401077, 0.12002533932607021, 0.10219220672884297, 0.18139152547284482, 0.1430717002480261, 0.11645340841383704, 0.1118018297899154, 0.31843492580998334, 0.0731261414025099, 0.20615229923878947, 0.09357104393383188, 0.15332463798263382, 0.1284327559293278, 0.18530338491883971, 0.11646063262296301, 0.09934611348134857, 0.13883537192258144, 0.1323823222229558, 0.14094252740183186, 0.1550443674768171, 0.1493665834348048, 0.21134911796018002, 0.1467858324007642, 0.2665096701633546, 0.12852121610194445, 0.11824741013227932, 0.18228594844620075, 0.10787363734937484, 0.1538372120910114, 0.1140502825259201, 0.18085212296535894, 0.18527162291349905, 0.1542802407376228, 0.21834336281303438, 0.1518190607068039, 0.16826689183231325, 0.07763990846973273, 0.1870873432245947, 0.19355487198598925, 0.1046695358931057, 0.1369998405777639, 0.140803957418088, 0.141627517258448, 0.15706144633793062, 0.23683194491651752, 0.1406054793586654, 0.20616242692114847, 0.13954809416205655, 0.11372994286038222, 0.18024532004229485, 0.16557832158380942, 0.20100147643637276, 0.17613197947221418, 0.13696850758166085, 0.18031386958975948, 0.20596345856545434, 0.15173713526418134, 0.174019246872875, 0.1838994675105618, 0.15543658917229022, 0.2066564310582415, 0.07790807754762712, 0.18269606595558507, 0.11837065069665832, 0.09282962404071324, 0.13723378850808068, 0.15175564394843194, 0.09171296662140278, 0.07879234985598634, 0.11979287760632655, 0.11281385492052763, 0.18152677063499728, 0.21648513994389967, 0.09526444298605766, 0.23295192408465573, 0.18596101011480057, 0.18946788484050384, 0.1371201623471514, 0.1289185782473895, 0.150895296565948, 0.14741820733874075, 0.13805613792952032, 0.19175782889848758, 0.11559333682300584, 0.08505898738099683, 0.11913528305388267, 0.07257461938406191, 0.18317286375789874, 0.21335062991467216, 0.15657190083255693, 0.18575188343323049, 0.13750847699421068, 0.10657956162768026, 0.12162900649972501, 0.17422894045950907, 0.2627932857121191, 0.09955708643481617, 0.14886865692753948, 0.14818052611043378, 0.08802092078352168, 0.13200585129520587, 0.17132214240489468, 0.16833482850943843, 0.2759300695071297, 0.13236511588817643, 0.14321514255096837, 0.08091072086244822, 0.11661179709218203, 0.08832917158161441, 0.14332015788362873, 0.0874573405411455, 0.13739967718720436, 0.12357927483296204, 0.1567720949289299, 0.17976159680514567, 0.13742053010050329, 0.10645711013386328, 0.14931787556457907, 0.14525601610301003, 0.11771805869836001, 0.10382885398763804, 0.19332093937743097, 0.1260023802939442, 0.13563320100788148, 0.13635102539293228, 0.0823503915941523, 0.16719159550003468, 0.1441346778864822, 0.16352497612036046, 0.13095073371885285, 0.15086938747234885, 0.14875849348402795, 0.12185968323460511, 0.13724416133857545], [0.053074590546349366, 0.030480428343458526, 0.06850822468198116, 0.04099903770932748, 0.015340782363989182, 0.024586280004211494, 0.011686709589294849, 0.06262471538878257, 0.06530595417585104, 0.013389846576648134, 0.023553265979693785, 0.008671894094966834, 0.06146481996702571, 0.03582232496550968, 0.047295859098554625, 0.0023012776106160378, 0.03207559960203306, 0.028002229669401725, 0.01989173725427639, 0.058659019113908854, 0.02916601490259411, 0.042302210725122885, 0.00889077020298329, 0.060428869910538204, 0.04245933535839281, 0.05742168369432611, 0.04060402362337036, 0.03187288699160901, 0.025269184186453783, 0.04962849723655851, 0.02577041444789258, 0.02728536289425627, 0.038164929907408454, 0.06596270603157821, 0.05856269121830983, 0.03272434200851187, 0.03494028580344973, 0.008413744489512136, 0.03758638796787109, 0.01224982922130655, 0.02103370621860508, 0.0379403282497679, 0.046621261224631345, 0.021706379296618606, 0.06724362036273365, 0.04323946567432534, 0.024930990841840545, 0.03283821714801654, 0.03659803495411912, 0.04069612654406698, 0.042056890219570174, 0.03419284828968587, 0.062002732433498874, 0.039470539082803076, 0.06438650311000886, 0.05624727090640415, 0.07738709179384094, 0.027266559266154806, 0.08933464666047404, 0.042587291193945755, 0.03446179111638377, 0.07139112845423722, 0.05184357918258156, 0.0328400174546386, 0.037165970406344825, 0.05458304831277459, 0.02739576574024414, 0.06036582853524916, 0.06406923928748696, 0.01503952977908475, 0.055937089566742225, 0.004465395318073852, 0.031204153520746097, 0.0397906182784467, 0.05129096548884146, 0.02053558052847943, 0.01504941997418721, 0.11242164854681301, 0.06010695593431593, 0.09263188142569796, 0.044487181585282094, 0.07424806950673943, 0.014170749683774287, 0.033638556863391594, 0.05659992033014855, 0.034722739815591805, 0.055066993715421814, 0.0774605366431417, 0.027391724626443563, 0.08930588005891732, 0.022272905147063638, 0.023156311776068424, 0.0468687191154928, 0.0874786377854405, 0.0231396091440993, 0.028849898296738827, 0.03197814938762496, 0.041991397362923434, 0.03304521793559675, 0.01962304149093407, 0.017851639366258058, 0.00436006780458434, 0.06496941175071463, 0.049898378520963654, 0.023344953266543247, 0.03237112184926387, 0.043678916690330354, 0.04218832792473897, 0.07151569435072523, 0.02467545455381755, 0.06273495927152616, 0.017318626032060674, 0.03346262477158058, 0.028838496993205724, 0.04026839667330346, 0.013211385437077092, 0.02717752644281474, 0.015350032875674869, 0.04619453492904863, 0.02904774624884369, 0.004376311262603849, 0.11251354845420969, 0.07359283450510233, 0.021251652487403443, 0.07883341982960701, 0.06720757592589625, 0.03073083567282846, 0.022706922684465686, 0.049509286294661226, 0.029738970145943667, 0.029712473079862616, 0.051019425624080246, 0.03394700301390502, 0.02681121958660022, 0.02102821336818799, 0.02078492682607424, 0.01938620157870314, 0.020323960230715817, 0.035614979438363545, 0.07293774506017085, 0.06216387519793165, 0.015719703815486884, 0.09364686365569792, 0.03576630861648629, 0.04612987710823936, 0.02647547006246544, 0.01438644078124555, 0.038920039791733994, 0.055321342567162174, 0.013048741140312726, 0.0034941449778289686, 0.06370406815662019, 0.03379090110801401, 0.054918610145367926, 0.03247651256500714, 0.09228537219666666, 0.020743828124156403, 0.047566732466821714, 0.036284088292309356, 0.05015081215289332, 0.027486001321625327, 0.07594280921283268, 0.04533123810805621, 0.055818981791455904, 0.029676382677749764, 0.06223493368334829, 0.08252864493237388, 0.014944979207470052, 0.051106338299089865, 0.09590712946749504, 0.04729850210189339, 0.019811047128431743, 0.054403699468821294, 0.06277554277931491, 0.03076819586567581, 0.05186537821446696, 0.016876304101559426, 0.04233794872679057, 0.017293140202039675, 0.03405494863287576, 0.06903134016019684, 0.017239582995253227, 0.0173561432729325, 0.014002237153509933, 0.024883924314992565, 0.057263528672798034, 0.08424478913507155, 0.06147830694493267, 0.017342083644302144, 0.044389064874379866, 0.07318891464702545, 0.036837529361007676, 0.06224724088585185, 0.030403570572455085, 0.023095972775932283, 0.009590501506482402, 0.05426695660477685, 0.02152336280672781, 0.02106072039403502, 0.06533300474045739, 0.04971572783805671, 0.038152565248310566, 0.02595298086112786, 0.06488603840191519, 0.015409743683713098, 0.004622891025182101, 0.051109536716173735, 0.02108772882380553, 0.019669184881833293, 0.06390904264164067, 0.04138148412288677, 0.06510241227524896, 0.04957039329794146, 0.062087710736499685, 0.05577364470809699, 0.02357589621697703, 0.018175886080209768, 0.03440929111093283, 0.04276970438959618, 0.017782917449010477, 0.05534670007745585, 0.05329518173370631, 0.0686673564656127, 0.020897894151388638, 0.031104089031296394, 0.03427773466213577, 0.04308848123576853, 0.007249115601993136, 0.06181758813439839, 0.045548312951840704, 0.03482685116450152, 0.023182391324230743, 0.057411310863831354, 0.018280426438357082, 0.027418093372797294, 0.02555670847575511, 0.07638031436551003, 0.0712749895249163, 0.052532568018162445, 0.06162919562249895, 0.08666656926394471, 0.05958143877045763, 0.023576455461161754, 0.005102056996791714, 0.06650951660929189, 0.06708724649562951, 0.019952901714150945, 0.03545438825723625, 0.030828898757575985, 0.02397148486887736, 0.01972213879437937, 0.03304660455473969, 0.039918899701367465, 0.036901853933569886, 0.04841047106310726, 0.018992861394860575, 0.020411100816882907, 0.06235541250076025, 0.07808421648317769, 0.023808195143036788, 0.035314190336653305, 0.04123810693741806, 0.07401186927792526, 0.05806154331132289, 0.06308439112598858, 0.029359480831772092, 0.08450954146082364, 0.03843650424612626, 0.05412475153383228, 0.030419252392265107, 0.036304033391418, 0.03756168163231304, 0.0320669274867302, 0.00850005099745167, 0.04370752241342299, 0.043488693228291894, 0.08634290477681546, 0.016749859374437123, 0.0228348727743592, 0.028855230268691818, 0.07748853715677416, 0.04610345473573093, 0.02733083021256232, 0.01868420648538778, 0.07564480101028759, 0.01814937177715042, 0.06545040771485337, 0.021593021266462824, 0.06417801994229518, 0.011797066470007262, 0.01971613266505301, 0.03319668500954586, 0.019220259273424745, 0.008034832614113488, 0.05677268464839267, 0.09336699641519978, 0.050152099180606105, 0.06597123259017545, 0.10351886416995719, 0.0581245425517761, 0.12428246693865908, 0.09546233115777855, 0.03838576241246155, 0.02125781757997409, 0.009338299616149837, 0.026708692124473955, 0.08558529744585676, 0.01771960411250832, 0.05469285552540133, 0.03850071007506021, 0.024449336042086926, 0.029593200850931388, 0.056496927469608285, 0.04184056997239109, 0.0517665567026744, 0.031089018166605985, 0.026916905246194334, 0.017084963469495697, 0.07422031414124274, 0.043868213185980436, 0.02399139549402941, 0.05737499446578084, 0.05823544143969494, 0.029267529213440516, 0.026972965645273368, 0.018256327227479028, 0.024241230172675945, 0.023953587139746355, 0.023357423262730725, 0.06357673668272554, 0.023725587882161624, 0.02423299089705031, 0.03540379964115639, 0.043771728242356936, 0.05779319420276631, 0.07829983192946642, 0.062165012838499206, 0.09570786999838968, 0.07907919615747468, 0.07513356755577749, 0.01577000897903476, 0.007226020445100844, 0.03836942558747627, 0.014214302739879538, 0.05837468941125178, 0.05529028153227222, 0.0727670300271242, 0.020537461274333542, 0.05045382290958397, 0.01622651406984416, 0.0304434128901771, 0.013070482715603807, 0.08433966912449369, 0.12122428991020688, 0.09835968334828654, 0.15055276333324372, 0.13634244520818034, 0.12355184888527279, 0.12713956886962538, 0.1872001879758412, 0.10476705122498736, 0.16047671226964844, 0.19770120030208943, 0.17038022198023337, 0.12879638722346676, 0.11116473575032527, 0.18787474371492865, 0.1342865410110643, 0.17886987046128322, 0.10441112677536665, 0.06390340040407835, 0.18722609706944038, 0.12549391241684077, 0.12853887442859913, 0.07924252610293128, 0.15340048068713757, 0.2146830866413732, 0.1271047654952253, 0.16448430206266143, 0.2200561515506237, 0.1093945210619319, 0.1744543082050739, 0.13499650533401197, 0.09469330145586884, 0.10765854284287461, 0.31221226939270574, 0.16985244868743807, 0.15776853017028303, 0.234161684169404, 0.1293012391655676, 0.12671181601622414, 0.1182590010425737, 0.2322161272769013, 0.09974660126552468, 0.18517086702969768, 0.12331401688917992, 0.15264680338723047, 0.15310475542660684, 0.10154801105419475, 0.1634007626243176, 0.12387870795904629, 0.18134162250545718, 0.20954027711864442, 0.15927424534193932, 0.16464427654300967, 0.12231346775567341, 0.2801389565631267, 0.07440201487512359, 0.20045448965843649, 0.12491920857780403, 0.21900556921478243, 0.12736924202932468, 0.1788793546297858, 0.13977240470628585, 0.1990306386423688, 0.08386422729780597, 0.14759791624401847, 0.2036554195106991, 0.0870208619462867, 0.2676136028622427, 0.1593986273773255, 0.10493909159014303, 0.17622919602980539, 0.0872440233586296, 0.13393213341553367, 0.16027662542558488, 0.12283517363210841, 0.14710359034999726, 0.0869796081115642, 0.22041782165967652, 0.11807164657981166, 0.10108323317141303, 0.167651753872633, 0.1337743959119243, 0.13377179121298174, 0.1568191633709977, 0.15851212575310664, 0.10274447951345675, 0.21090907705647333, 0.23314192921163576, 0.07309080176656285, 0.22667346582297357, 0.20159283502688333, 0.16403591080058008, 0.281759079305395, 0.15799354551540268, 0.10933747049421073, 0.20154420376545001, 0.09388546940059432, 0.27611720946527296, 0.15179888195087834, 0.2005463436005577, 0.17426981891114868, 0.14315950924590712, 0.14408515796305674, 0.14110455499781718, 0.2152219222437951, 0.1774363514156111, 0.11764343407365585, 0.1260821300468618, 0.2348588395022577, 0.10767631608271792, 0.17572773019632987, 0.07071340111114326, 0.1398299532311578, 0.10994507014871606, 0.12691140490313693, 0.13023795019234383, 0.10923198018703731, 0.0876309437256667, 0.1664278824483195, 0.12090361316598232, 0.18905346191698508, 0.15677476091490639, 0.19360445319644867, 0.2609799862388642, 0.19364379947223972, 0.1943966953624641, 0.20676104802518122, 0.15186139472549962, 0.14369911093625332, 0.09999360333407119, 0.16788423091413515, 0.07144043387304391, 0.09087191699373146, 0.0818082464918975, 0.1469628906418239, 0.18088989110002596, 0.1389645496683736, 0.1279258891759861, 0.13930213397308705, 0.13598299675410794, 0.15555809071708113, 0.09315837535165972, 0.2561311552961988, 0.12363448678966492, 0.1353150600146863, 0.06343717078468011, 0.12998108091133256, 0.07720100903703321, 0.16085278483167773, 0.0948234444724456, 0.11343025692528295, 0.16626945546557828, 0.0859949553024865, 0.1188765291965777, 0.11655229504310316, 0.14898482650037737, 0.12078636340917119, 0.1407781708985567, 0.14254218027476342, 0.16357596693260057, 0.11129028223935636, 0.26672224424058394, 0.10547587407692786, 0.19872098590337461, 0.21198429677995945, 0.10379719923460677, 0.19853868762091284, 0.1267841883424309, 0.12842431364040222, 0.20870161002441762, 0.22827581532539862, 0.11113990684069934, 0.19132175633022863, 0.11972244348256819, 0.19473765045404437, 0.2133151140785025], [0.06424636647645986, 0.007644542417819462, 0.04474557538126265, 0.04381508498843159, 0.021606946829706434, 0.014479405550856986, 0.05546872256203525, 0.0715295605421547, 0.09438121255727545, 0.040347809347534375, 0.04100294092730169, 0.03466112719428155, 0.028770422420254158, 0.07065694043112379, 0.02326233642956903, 0.027674702183914282, 0.02606272678672066, 0.0518772870512499, 0.02922372430593016, 0.06940100822717914, 0.0629990604225426, 0.022586656456452706, 0.028593599751231172, 0.010394506952575138, 0.05416622370361321, 0.037785318019169, 0.012815427147753298, 0.0700876834772287, 0.055003304995836756, 0.007027489238328511, 0.0474600623842449, 0.026268325633399432, 0.02263667050658936, 0.023596588251811844, 0.0407407664874148, 0.0282541117180259, 0.09390563283476139, 0.03267837673305504, 0.08546201857708155, 0.015336106354821355, 0.017283253837376833, 0.025998593736139518, 0.05982022454601623, 0.06626321168075647, 0.02878489765158344, 0.07723244928544568, 0.04179822063193687, 0.06981432798408693, 0.023417877176055507, 0.027459531068621625, 0.03564914312934683, 0.047933814987059564, 0.026313398416424473, 0.017911302293801022, 0.010101618132584039, 0.06339739549965148, 0.09729753308478864, 0.08411478401432115, 0.03365627264664058, 0.04270243803940473, 0.02100736811576832, 0.02654514767439856, 0.01743868733155391, 0.025540959623251713, 0.10058057990165488, 0.011622912659790489, 0.0562884979280493, 0.04737130343733777, 0.03535379708233861, 0.07527481118637709, 0.05374034776562645, 0.0415822604460822, 0.03830644166878155, 0.0116573492695968, 0.02209884614022749, 0.07497568449546253, 0.016769206924964825, 0.018149153442092, 0.04362638221092282, 0.05469599265545126, 0.03648657299157593, 0.024241651521034302, 0.03305893090944136, 0.060747742517701084, 0.057937080836704666, 0.019008684940936587, 0.008469571231774265, 0.09198768575104976, 0.07403193312066217, 0.02695751556706044, 0.022254208771271572, 0.05269856778003516, 0.028161849834084995, 0.040626738130325274, 0.033289768522785555, 0.09230319906266467, 0.041789904747518807, 0.03642773360855157, 0.07638727810474173, 0.02835964990569459, 0.027794313406752005, 0.03476263767468833, 0.040938938111667676, 0.019018084839767507, 0.08327498310996641, 0.03912691034436707, 0.06381083400018754, 0.008677547823848024, 0.051009152385015646, 0.016119384334512776, 0.03987325235239921, 0.05361955102172591, 0.027643380679130077, 0.019281711016270905, 0.07767186965793371, 0.059131400419339064, 0.09522555636302119, 0.029003506586436304, 0.029068673855715224, 0.05518019852799274, 0.028262908322616454, 0.05910133912919029, 0.010518088426080444, 0.010193213520030822, 0.018714405671362917, 0.02359438574902954, 0.046169951167558475, 0.024731197026408008, 0.031004152861574007, 0.01977362756377026, 0.027210307345094702, 0.024071524460469524, 0.05324346313793814, 0.06880009652025278, 0.046836616201025826, 0.05921816753764307, 0.08738574962462149, 0.0318985317848743, 0.01759625821103973, 0.0627587539624543, 0.053662107205919685, 0.04566167481243611, 0.02466786453770774, 0.03633672236314705, 0.05308537706432324, 0.014364021218141482, 0.05598717639523168, 0.06548088269248124, 0.05267290000413215, 0.05948609146740168, 0.04569943145578427, 0.050000000084119464, 0.06288055045109603, 0.028069609017562003, 0.07322026296488701, 0.023160182435305852, 0.047472695174116286, 0.005096816476584683, 0.01573264304052798, 0.043637421537911704, 0.028516667286655115, 0.05812204127470332, 0.031587475189758886, 0.015698064704455676, 0.044915252365171916, 0.01180474745905808, 0.03565973812533963, 0.03075492147716784, 0.038672309939659415, 0.07346342693293288, 0.04108670115050289, 0.021390948339455554, 0.0854495543265535, 0.008840774347434842, 0.061265173623518604, 0.05730346483629077, 0.05427865476738061, 0.026733827469269597, 0.036996588366286415, 0.025040219658084457, 0.08483161248507039, 0.034439946119222915, 0.002850002689932984, 0.039907163234367486, 0.041120906976322015, 0.03449929878115654, 0.07306425681998653, 0.024127412489765597, 0.030049138079066912, 0.058488242793828256, 0.04541340103793529, 0.03666527449123321, 0.08277758520336882, 0.06586143686886757, 0.019778003841037714, 0.053827597519322756, 0.10628798856369912, 0.025497844194873207, 0.044637300344484473, 0.02499776306532083, 0.030437550402336547, 0.045262202094759674, 0.05159906306934934, 0.06286801342221518, 0.010120038716723363, 0.006402390220412805, 0.01854018387084286, 0.08476194444923632, 0.08144005697460906, 0.03833215924039964, 0.031257396631483594, 0.007331752548775366, 0.012330467636216313, 0.09462888878319534, 0.08677300952014425, 0.06231066530510303, 0.0232327826726701, 0.03353195955916759, 0.04867968202057866, 0.0367094969166623, 0.05930666601465595, 0.15634261071681976, 0.04131164754770937, 0.047434069020974065, 0.06320863526554839, 0.050142147698469704, 0.03165972494189778, 0.03861893659397479, 0.06196338615770783, 0.02294573527310164, 0.04149735875187382, 0.058142629887668364, 0.011378926104835926, 0.009951271462224184, 0.021029898761621407, 0.03711649644819479, 0.04127696291693757, 0.018756389204833298, 0.04180878881485232, 0.05543763854450757, 0.06010594469825587, 0.03531458870237393, 0.09994129485060131, 0.03903756534019786, 0.06587306608355815, 0.06914583966135979, 0.03138622963770984, 0.03119806503696788, 0.03333021796518757, 0.05792014646313845, 0.05291804430946227, 0.04095149429274663, 0.022741712652327075, 0.03013021507931333, 0.0539770842559876, 0.0320612354534528, 0.0455782363461631, 0.08686122454462514, 0.010374994693143715, 0.036818093710368684, 0.034524843982991674, 0.06268509460853473, 0.021312640747055415, 0.0658099864038729, 0.04908558987681905, 0.031116798429960207, 0.04742528965336181, 0.027606880419977733, 0.01910842384301847, 0.021003175699602694, 0.08210793242699678, 0.053675406492285194, 0.08703622967004777, 0.04165705744056933, 0.13553371683003443, 0.02128015861906592, 0.06778300754846105, 0.03679434498471599, 0.04151091467769396, 0.022412001816255432, 0.03764106366302698, 0.02948795760711355, 0.055395618621860786, 0.03256794515877001, 0.045134261580965215, 0.010142731198650456, 0.054390645330591555, 0.08572078775614501, 0.07253827617293404, 0.06219410502742376, 0.006424326669319623, 0.07876696936305493, 0.09267982320799943, 0.056292803342183756, 0.050978336498261466, 0.021518155324062514, 0.027662557775094628, 0.01288340691732423, 0.04695300793936176, 0.04094969398612457, 0.017254985192970886, 0.014543989635703546, 0.027609203581608115, 0.029120775495445537, 0.01873658966243027, 0.03960446657372579, 0.023381468847454078, 0.015438081276032235, 0.02845281960382577, 0.0410768224467193, 0.02682810224923155, 0.03118768263037407, 0.03526870386614915, 0.03304326441138983, 0.046444980562814785, 0.07243485430315619, 0.08182930624893597, 0.19010847224102867, 0.03612390313778193, 0.07625500536373547, 0.08338190600155823, 0.05067795342315109, 0.07926190812741557, 0.02818882762033853, 0.06048835280741896, 0.07131899361528697, 0.0640126560333996, 0.07477947405629581, 0.046791872835808226, 0.08747188855082759, 0.015873294868206066, 0.10129877966978859, 0.05855548999182159, 0.019721907052782275, 0.032284952279540806, 0.034879569505010886, 0.04881611844945339, 0.0788408278998348, 0.029534275283015547, 0.03525157414016224, 0.07553371826126691, 0.026330972473407467, 0.03925937843779403, 0.016513764482712554, 0.02353681232630005, 0.04817095750402059, 0.03156891670979319, 0.04801872434214719, 0.022607243154197935, 0.030955985083334872, 0.10265570524479113, 0.027313284883876483, 0.17621258724360697, 0.11826677683500514, 0.09222090589783846, 0.23414087722138052, 0.10204409895044181, 0.12152431292399285, 0.17165162149936924, 0.19132365622828085, 0.23495291509935934, 0.13882643933738434, 0.22469579452468505, 0.05637772801902987, 0.11207287935840507, 0.23919322708201027, 0.09209101569027671, 0.081506407849731, 0.12838649954045975, 0.2367916027264249, 0.09874645049773878, 0.2290676591256934, 0.20556944422423842, 0.1265201484784484, 0.11227288193279698, 0.11432950625256186, 0.17200403726629673, 0.17347630503917896, 0.13258987076340184, 0.16006061927445475, 0.1808723783300769, 0.06399798544964964, 0.20798760075722972, 0.2141987505338846, 0.13224433446603437, 0.12529799309108527, 0.09097460341910202, 0.06279223200474536, 0.10384796022046959, 0.19883332503659112, 0.14127739975529333, 0.14671777314957113, 0.05534521003644313, 0.13966518304040357, 0.1859595851912614, 0.2244122040968749, 0.20654763125123518, 0.2506187236717632, 0.10005250017368987, 0.2657755434272751, 0.12569006156897353, 0.13652950855753115, 0.1188898821090979, 0.1558060733781707, 0.11133179654397311, 0.09531099814921619, 0.1505320329940127, 0.18152678595675578, 0.1961231204651056, 0.16918144759631928, 0.1362757189499755, 0.1342094572441232, 0.14465748692952818, 0.2075777130742227, 0.09679018369605465, 0.14460075045785598, 0.15350227845051598, 0.13650148506126097, 0.1785920103711467, 0.15459234495797466, 0.07879631053055487, 0.20584508265939452, 0.14468094454176966, 0.17456284754218596, 0.11040885211719621, 0.10840388510616557, 0.10618107333298653, 0.1471959499101485, 0.1394960614702394, 0.12506478826605505, 0.20583909185182667, 0.1897578337980855, 0.18135357347707595, 0.29818415761955325, 0.0999354036344636, 0.175827153087143, 0.2030576870686585, 0.21865663148703116, 0.07501830196669025, 0.23885820151096393, 0.1852938394633032, 0.10477747002075757, 0.20930613000546733, 0.12000640929346124, 0.08215482466884198, 0.1131676419848396, 0.18970025462969659, 0.11996923104649591, 0.1314838849488766, 0.19123664396184106, 0.3202920148689901, 0.1364174298942089, 0.23634446784853938, 0.16367091586993587, 0.1985228908879142, 0.10230195648487538, 0.2162711869084066, 0.20408084345681055, 0.1767353503213775, 0.1486543055263258, 0.1456391213521842, 0.14175366129606, 0.21208148269403368, 0.22354604976792491, 0.18469868107668816, 0.15293903528682648, 0.15128975523816002, 0.1996097398260909, 0.18206431920970642, 0.16164159492379235, 0.14622415205644024, 0.08878861749244314, 0.11555502476591258, 0.14131084715406741, 0.0781080954437775, 0.19630977012697728, 0.09871635856407304, 0.07456598067355734, 0.12259155767218721, 0.15431096086338644, 0.09796796727084345, 0.08900273140640029, 0.11072771323304023, 0.08148910192352149, 0.2147852061616798, 0.13376370132450136, 0.11961193529949074, 0.1877045496216705, 0.27843438028808565, 0.14984606254485347, 0.09345442236911866, 0.23032756732596507, 0.14036629138694656, 0.20060340182915812, 0.0632357509476283, 0.21706358229200687, 0.18107442635922663, 0.1483637130548877, 0.1903683599084616, 0.21594293355461092, 0.09934864923237793, 0.1312579502982478, 0.12943959464469265, 0.12567005901327058, 0.17105977261258712, 0.12230001525172304, 0.17027048754595941, 0.17044782157867186, 0.1616575448743759, 0.13998664885519013, 0.12505286793795325, 0.15679734518691418, 0.1358392020507205, 0.22613381816735192, 0.08302336919211573, 0.08910842089643402, 0.10921983769343746, 0.08051102214883413, 0.15496394356652615, 0.1381030991192787, 0.07699012801411652, 0.1236616675892184, 0.11383017014351585, 0.19355071978943963, 0.12783522267014752, 0.10240115721019045, 0.2162743891559301, 0.12982458447016057], [0.05197245432364364, 0.03393044785386132, 0.05056114416689642, 0.02372353093608493, 0.05489989461737776, 0.020613510822576862, 0.02342883606381234, 0.005562307299940937, 0.035302576443721215, 0.05701147425439089, 0.08184665814042091, 0.05402288099210109, 0.01950681829194148, 0.03466845482527729, 0.05259474754453667, 0.020581722004158844, 0.04827755097780497, 0.024337699794540965, 0.03063110251640601, 0.035220808049123135, 0.013593915162698157, 0.03679420708888962, 0.02515612876102809, 0.01150952494372764, 0.17543506928749625, 0.04598493710340512, 0.020330979511322036, 0.12447172129947333, 0.13497864016361777, 0.04534435353331989, 0.027730212914907647, 0.04240965838694284, 0.057656344086412466, 0.04428726711100148, 0.08616806052985691, 0.07330104693650238, 0.06830776245483468, 0.029090233485124288, 0.056294848796941584, 0.019846947923783335, 0.036126369940898115, 0.02720858747770469, 0.04431231435568583, 0.02046034686387547, 0.0113837179848023, 0.02937657225336279, 0.06766959589215056, 0.07206917755425939, 0.06896410062308274, 0.0355835430203907, 0.02139842535759653, 0.08975934282305742, 0.04805641969846142, 0.04743471636527008, 0.037812659697186564, 0.05715030087758938, 0.027824571964541273, 0.028655693092713916, 0.03743978938268077, 0.07930232692630061, 0.02755680891324676, 0.03163962854042409, 0.053032742993485545, 0.09963835304182384, 0.07451395564261945, 0.043625378635742014, 0.05116580204377252, 0.01037626448387821, 0.033062860940492926, 0.03521781647577882, 0.0900063219089662, 0.04958861852966009, 0.04224661189401823, 0.024458540588497155, 0.0303949463376475, 0.02409451092863756, 0.05139708398811279, 0.020304578206231518, 0.08891721301141287, 0.021118684521605893, 0.08365857865541212, 0.020007885759696364, 0.12304719612603227, 0.05779870620538151, 0.022266577260809082, 0.014230887585830305, 0.04945962847540936, 0.06471276463520143, 0.04958833507712811, 0.05178367493734245, 0.055213948531496915, 0.1172813119727277, 0.03475275897090474, 0.009942994839812239, 0.11570342365772494, 0.0351708859295374, 0.03054146256838595, 0.06337318329080459, 0.012553263241575371, 0.060803406466279304, 0.041770974714909835, 0.018846877595229496, 0.02593279635954288, 0.08304839728460198, 0.040080946449550896, 0.04215273931021652, 0.10228609846484277, 0.010190493907899627, 0.02993761291426997, 0.020199162592630715, 0.05749249703160698, 0.005366088242285075, 0.12152366941013645, 0.054798912737638726, 0.04494973398264378, 0.05512270362927549, 0.02661331800834066, 0.01584008687190832, 0.06567424328456964, 0.01475639517358955, 0.040680138289087245, 0.06108803877366647, 0.051873288072285154, 0.04071215693388255, 0.021977660606705376, 0.038606545121799556, 0.0605477246215507, 0.06487398017798701, 0.016927545807594736, 0.0597852488018332, 0.050387786130510995, 0.008359990972695092, 0.034665865448093226, 0.12223034721588898, 0.013611960363754583, 0.052281034539543816, 0.05254594774376001, 0.014240131394246654, 0.08250166331568072, 0.009518670229872149, 0.06830272925717217, 0.017296840406713948, 0.03345816230942165, 0.061552514051718105, 0.01659862021164548, 0.03976476281100223, 0.003014230634078324, 0.03892572033369253, 0.028219218328294736, 0.012272502551035536, 0.01960613201522539, 0.03154158269265487, 0.0289303777484043, 0.021716179476389964, 0.06311980737072807, 0.06910536723632006, 0.04759901541195089, 0.0270763281432371, 0.040305946472912066, 0.020361243814770735, 0.05608143202299553, 0.016944148848133705, 0.01774194898203977, 0.040733982778845296, 0.05241700365478474, 0.04631492947678893, 0.05157120045154326, 0.05110513937148837, 0.015599802436847842, 0.03629948282914777, 0.055625571403652437, 0.01901527904274483, 0.03560312422773531, 0.049655417566217726, 0.053649780851218014, 0.03337877644826809, 0.06188481618019362, 0.09502196083626441, 0.06771003001279409, 0.05424230772581312, 0.01452725827543726, 0.01412389478871539, 0.008741204942306204, 0.017831655962753202, 0.045282311902772036, 0.0079942797498417, 0.0320749809860342, 0.08334390804051392, 0.026099657970330408, 0.021519143577484835, 0.04437571196185966, 0.051925960447519064, 0.019524478533815955, 0.027939050398286314, 0.026487800247606733, 0.0019228871538108517, 0.07943522019852554, 0.10737231707260494, 0.06213523883132204, 0.009016676753338788, 0.06711051258588992, 0.040831980746119254, 0.007402134482793871, 0.01780748588874215, 0.023729638572061257, 0.03200957814471857, 0.05100172899302937, 0.023213994366327123, 0.03257041962276543, 0.012484087417232654, 0.012897315243589542, 0.07711638696491718, 0.08588548133810682, 0.02235929879750456, 0.03109074761009505, 0.07194636599911798, 0.04122535540391842, 0.044385330195749, 0.06251704556146456, 0.047298739589149916, 0.030242014120543198, 0.05987896433761043, 0.0335927946012347, 0.014952937903393422, 0.010795597073381707, 0.05121908728934584, 0.041350541831625086, 0.020141389987040913, 0.11062439861557177, 0.030675616055246324, 0.057062235240253716, 0.015110011783338364, 0.05756501874495899, 0.08420089229701028, 0.049691718642509757, 0.029125519494916645, 0.028135613237898198, 0.04982992090404995, 0.048042166632630175, 0.021230835963280934, 0.03864931198017251, 0.03961982280616799, 0.09009965440078128, 0.027481513961608854, 0.04934660369350065, 0.023524675578359636, 0.05923260063413651, 0.04373055484686648, 0.008318175020958147, 0.03375753414847198, 0.04072279406471118, 0.035779918168461135, 0.09181040534449202, 0.018070667734249465, 0.06718092372701054, 0.01948117349867619, 0.025398193392902616, 0.05269816941431454, 0.06329789600004593, 0.050690812208960136, 0.04560925907665684, 0.013374422353902652, 0.053009358159596884, 0.09304279566652353, 0.04683840501632902, 0.07230772967300109, 0.05098536918540636, 0.06401625281620411, 0.01835537281998944, 0.07074552317780834, 0.03994711088917909, 0.03889025429323797, 0.08784115825208925, 0.024061617028388767, 0.07409607000168293, 0.044887316969013026, 0.044895046796169014, 0.06356848591578103, 0.040979119423296184, 0.12686300346808088, 0.02891480892656311, 0.0636857433334714, 0.054351368002713694, 0.06131768512028841, 0.01599670492953831, 0.028359820360257745, 0.029143378919651432, 0.012243580816674137, 0.030341844953175996, 0.0026773350902893132, 0.06049663421788043, 0.019079754917672085, 0.0786826843696256, 0.04234345306852653, 0.06448882181317576, 0.021258461093830488, 0.062162124687024665, 0.028490174051013686, 0.01273281031077908, 0.06811827060676391, 0.022030919039201353, 0.06124393383581793, 0.0288643907650464, 0.053421927150338895, 0.09658094210129592, 0.061807613669624256, 0.022518664237953002, 0.06009888519803363, 0.029087670921017567, 0.0694342717648514, 0.03265599164390757, 0.028531630899036126, 0.05795663523097193, 0.023257730325924295, 0.06731419238231837, 0.06674312746092197, 0.07657251050395351, 0.04683317646624581, 0.06323990697461752, 0.06344976527015529, 0.012445795469947401, 0.03398903825831029, 0.029194599558268825, 0.057623379323030674, 0.0761625002468786, 0.03976565913387364, 0.006503561228108142, 0.06668348751601673, 0.016088999372216004, 0.08665369132593756, 0.027902691865399964, 0.08750623993335233, 0.09853669562407079, 0.03763477791160826, 0.01617049389038115, 0.003632877994659207, 0.03241268594959571, 0.023194742576789953, 0.03303096103932589, 0.03406103903187379, 0.05429895609737404, 0.040804198567545226, 0.07103348796766612, 0.027617674598830844, 0.021600176527675603, 0.06781563523315615, 0.056597085804828716, 0.06405825741709241, 0.04344271263107658, 0.01541130267263901, 0.03862786151829266, 0.02318033437815405, 0.18506608152341458, 0.27553697447142295, 0.23929658766475417, 0.08205321076656542, 0.11846545407728803, 0.11284017770160591, 0.16459584446443667, 0.06617854364336499, 0.23937488185061565, 0.1463385289835353, 0.18355538678025046, 0.21293655939159856, 0.0909194221059161, 0.08405275387509216, 0.14398132240579975, 0.11590367904113186, 0.09807842182776622, 0.11797917210647177, 0.16363392914495162, 0.11153215917968944, 0.20865124740427543, 0.19458455544325615, 0.149085812210556, 0.07001534179453889, 0.20395767184034472, 0.14260051020931813, 0.09988790618315821, 0.1965627476813332, 0.155515618802559, 0.17194248976246004, 0.23117432430867227, 0.1186357401010971, 0.18872546903308363, 0.09895123346077819, 0.11016699049862162, 0.23467586706242255, 0.2260173574811028, 0.11789805871704895, 0.07558230355742478, 0.10695152029755617, 0.08161868569591353, 0.16587274449486888, 0.2017320178809666, 0.17747237286981077, 0.13855584176077, 0.1278125081631926, 0.2765045435197892, 0.19499741554740938, 0.1688039807542678, 0.1669102880142389, 0.13825783355822488, 0.13048113714302742, 0.15909076728407415, 0.11696624299210888, 0.19664830438071684, 0.12522182096877407, 0.10562507736106073, 0.2007013997964321, 0.11598577302309776, 0.13272681664074623, 0.14573083739847909, 0.3114745573651406, 0.1192516747922186, 0.2764820511783323, 0.18922099002426673, 0.15013694612970277, 0.17431403750613814, 0.06952256339812471, 0.1209457403409385, 0.07498101646741552, 0.2282286396310214, 0.16132553768975122, 0.12223474456057434, 0.11563252222033278, 0.14018744050014403, 0.1576235556914922, 0.2211482405302025, 0.11817641676433625, 0.20149485238136786, 0.1974398570676004, 0.13549896708178905, 0.1383798100775288, 0.13250800660781323, 0.19037957543567305, 0.13643429915030159, 0.12417712218819127, 0.1497790604949959, 0.36122075251994595, 0.09477058440567025, 0.1704769635633115, 0.13618561168832166, 0.2280898244991418, 0.10561703343785579, 0.1564558691555454, 0.2094244752680102, 0.19848853950538944, 0.15056932615416665, 0.10507090467839472, 0.16289051742322985, 0.15603018473953972, 0.1050952586135076, 0.13468363502573583, 0.09638083227459462, 0.27589718901341964, 0.16532709070992085, 0.10229749785315606, 0.2821003561539035, 0.12290705566204364, 0.12987088682430406, 0.18941200638730682, 0.14885688981702253, 0.0988401277291198, 0.2655283115323513, 0.2550839437472244, 0.23928394721400356, 0.17498886903687833, 0.13544886493154112, 0.10395728862814366, 0.15360493423236957, 0.16804668751935806, 0.17286855216708877, 0.14892084283694146, 0.14699592435311887, 0.33794056624174124, 0.12792025842974264, 0.1152635895977578, 0.11666482569830072, 0.20259558283273252, 0.19519526541473406, 0.09892655776873713, 0.09745544678862057, 0.10323456128037746, 0.11544062485617977, 0.19372960131975914, 0.12764292694027388, 0.13399332851892518, 0.11288474869704056, 0.1519298983076888, 0.197876266714546, 0.10524417844510849, 0.21929239253363303, 0.1608209921828201, 0.10543331023185484, 0.12408648632586965, 0.18224223546924131, 0.14662598049448383, 0.13227039677721839, 0.1358735840767622, 0.17962578473792923, 0.13124714845851546, 0.14614215000502526, 0.1478146425177974, 0.12270450967574313, 0.1653537812132028, 0.12589102941415004, 0.16315400570390687, 0.27782025356446544, 0.1522530341941503, 0.08516489137564937, 0.1455643971360499, 0.11343412566930057, 0.14338803327372, 0.22324073308658218, 0.15768802965119963, 0.16799079374440257, 0.13533536134467972, 0.13570309887009283, 0.13162268475899774, 0.1422682731983162, 0.13739937075203465, 0.16442909776683778, 0.1717826225344212, 0.17812488059843742, 0.15837868855845544, 0.15236741112124536, 0.10855353272129452], [0.016740911467481526, 0.0717929722140393, 0.026277001579141906, 0.0551453989840323, 0.03449895404159062, 0.002914660510742256, 0.05759904837055553, 0.02679370873187098, 0.04957664840584321, 0.020677406385901476, 0.035337647948894775, 0.10753293506680958, 0.05269318601236709, 0.04931394919572819, 0.09674656264964612, 0.07051795675990082, 0.05461906593653464, 0.049075569446769454, 0.008861352426690922, 0.048721085242446394, 0.06643116879727572, 0.03456821222038519, 0.09414558689440451, 0.029862103458013267, 0.07046318913419401, 0.03275030855870536, 0.054045944069061554, 0.06999310226209703, 0.010486217253210564, 0.039377861596163244, 0.007074790379603304, 0.018143243073756178, 0.023082753928798824, 0.05500187624185797, 0.07528632548787902, 0.03778857772328681, 0.025821855336788203, 0.07017252005396352, 0.012362750581345491, 0.02785285784592552, 0.043663671540637175, 0.03688722165421613, 0.03823686173305877, 0.09986355990892458, 0.04839963474941831, 0.05790269498022334, 0.041985686177447926, 0.02278685055282568, 0.02114994665457597, 0.030724209012283437, 0.03941149668647878, 0.0040155077905153795, 0.03302543754539183, 0.03742606108707767, 0.02533167014799772, 0.07862191827547166, 0.05130439884059372, 0.05760436502075004, 0.02712525051808165, 0.03899584802228116, 0.04022843369673337, 0.08719135481383532, 0.040287001118544614, 0.07500853434565567, 0.05889303599213881, 0.04134525965538718, 0.03245528809906494, 0.012339146454788506, 0.04863461689843286, 0.01942790932052078, 0.03104579548591808, 0.040556579798219666, 0.01720209448267856, 0.012116514600723261, 0.08726539721171703, 0.07227899371496133, 0.05924297346463127, 0.01709627858813732, 0.04943362362081966, 0.04395314935414542, 0.022763209079482385, 0.03347107855182502, 0.08500459513837293, 0.040082045785722234, 0.058903316892082655, 0.04526834228947278, 0.052638989122163866, 0.05798691868661873, 0.05747815969610407, 0.029565629346536535, 0.027043367210294933, 0.029470199689028725, 0.055071839221542886, 0.10426973758806145, 0.02333373007845254, 0.02775552062948625, 0.046210684062492464, 0.06330973588891568, 0.019799465794236432, 0.022180853937301907, 0.03630103032675482, 0.010213000613505082, 0.05709637594859927, 0.036606971369755846, 0.03981594897566303, 0.017350003078219392, 0.06502617886590381, 0.11145421739427314, 0.031538847758765184, 0.01979306704484888, 0.03342383390953464, 0.030185961382343408, 0.014747393640479254, 0.07479899397660648, 0.04552958210209205, 0.03276802434195434, 0.04219241117337539, 0.06627947572738895, 0.06678355392068624, 0.009804859610965416, 0.07006833209626137, 0.03811490436595294, 0.013613553826637087, 0.04191139480099083, 0.04054923301502582, 0.012266949371194408, 0.024251788779492342, 0.016410513067497842, 0.018426693690520142, 0.03622835156537833, 0.11384657208597469, 0.08001108083032793, 0.026448093910491275, 0.029529763025141535, 0.03295489616932408, 0.03628493481946569, 0.08695579043799832, 0.008172886446118355, 0.0229470529443314, 0.025180607185428663, 0.018752558765211896, 0.06051959770341074, 0.0437919108287221, 0.00765762672076122, 0.031940138020041975, 0.038349108935724345, 0.03942910138697874, 0.058436244575967716, 0.0801972938220828, 0.022527841971285885, 0.019230051792316863, 0.05652713431646267, 0.014589799778355707, 0.021148740066095226, 0.04197237923020317, 0.08917459557133336, 0.056654929273551514, 0.059660433926769806, 0.045691084927849235, 0.035230499061365286, 0.03009873269606502, 0.0777014329909317, 0.0496429379939312, 0.03397801425307989, 0.04169204084563159, 0.04058404405030512, 0.028998088429591833, 0.03311155731939981, 0.021454706006953796, 0.03107072015653455, 0.043874705781138716, 0.026706181271302126, 0.03972069743359762, 0.01869363128207624, 0.0458388211536071, 0.08851960571783205, 0.06313581860834552, 0.05440037464722992, 0.038623510138882745, 0.012038984587566267, 0.010325823339723773, 0.006057879044449018, 0.03771218726591718, 0.03617142740216467, 0.04280490996015649, 0.013833382756509369, 0.03220657382400767, 0.06937041067548337, 0.006209348033617942, 0.05492301898137216, 0.01853411453926275, 0.05840724431759408, 0.04821346772293891, 0.010689863533292328, 0.02589450153942791, 0.08838616086230164, 0.05609652778554348, 0.053820982350096594, 0.09496980557037939, 0.028214702239981102, 0.08232018474729792, 0.030912097821372653, 0.10040852421474072, 0.04871966414934686, 0.10485603233739253, 0.055924713416325475, 0.05387448976116796, 0.03749384071617838, 0.06688915148016907, 0.08266469448684685, 0.04987585936642943, 0.06562079333009259, 0.032623766155372706, 0.04764692272029577, 0.01651910411554479, 0.10055179797833967, 0.034824376700506095, 0.02262013449874376, 0.02123997730743741, 0.06188500004129545, 0.017496413971868255, 0.053415618416282444, 0.04917633682188969, 0.043485123258564747, 0.046065966223156264, 0.0559339715888904, 0.048008876281880566, 0.031056317703558073, 0.017959494969897696, 0.054656853223399776, 0.03659531534198792, 0.06144560265144514, 0.022629057507841818, 0.015263433339104298, 0.029222374075963616, 0.06347989550821724, 0.05971957208408464, 0.0318712571395501, 0.06446482027850806, 0.047805862981946244, 0.08501794039001388, 0.06560811457494575, 0.050437386493168535, 0.08671776691992437, 0.07389119510809261, 0.05741453609399258, 0.021368858194158926, 0.0717551198097006, 0.03544632901227282, 0.031096939515743046, 0.0892532574793985, 0.018700139198993004, 0.05444213793042207, 0.04818123074308519, 0.008252457125983652, 0.06790283136069775, 0.04387354132749381, 0.12853234735948424, 0.02188526657259753, 0.045162013116022276, 0.026486515135113752, 0.02604708135608704, 0.07753073327964352, 0.06756588290896147, 0.02075742426959257, 0.05378174332661494, 0.018978857307604725, 0.04126038860469576, 0.05327603336603892, 0.052233563901315776, 0.08959056599245918, 0.024366225078401547, 0.05188797014735399, 0.04852263399610116, 0.01963115627727201, 0.017444498108459577, 0.0439834826055073, 0.022005735813910444, 0.07441480854345907, 0.032002390324769, 0.02966146120020459, 0.033730414635952444, 0.04328438140932591, 0.019091140899446704, 0.04642355308357266, 0.033686406715142156, 0.025499370625062336, 0.02351468962226664, 0.05528357060205552, 0.0744401200884773, 0.06376171244248267, 0.023752933390618815, 0.06446129627405636, 0.10852023854010528, 0.06948454245444267, 0.03447742697091834, 0.09381241525613493, 0.11576622754575745, 0.021806064572545792, 0.041648251259879726, 0.028607502331837054, 0.030680586050655094, 0.051710498218815175, 0.029454956454555356, 0.024783434646744883, 0.03721908711257481, 0.03314367555562527, 0.052612344584157394, 0.0063388336509946856, 0.03885129106140906, 0.01875164903580181, 0.060052647961363684, 0.035599600223283616, 0.05371125940714152, 0.03162659163917265, 0.024095047190184557, 0.051225449649557, 0.045012166318033016, 0.04391656099488178, 0.058270306101128946, 0.05455099136358308, 0.018323289057720574, 0.02832364760369303, 0.04295785558379946, 0.07838794736251717, 0.02422578584012245, 0.043244835950674555, 0.06520592607557774, 0.0511229355939694, 0.054440644058969714, 0.024927962879319827, 0.019562666101621527, 0.015415196314514166, 0.09242695290595294, 0.049368889191217964, 0.05162900561586984, 0.056919401977211244, 0.044663316690393036, 0.05448200897644124, 0.012962271838689284, 0.04738320078280184, 0.03630535489308738, 0.028222751908845482, 0.09472304864996865, 0.011664968971613676, 0.0408436750782834, 0.034759136652874376, 0.03453419408610752, 0.021590297823892008, 0.006558856496872802, 0.043874426159046354, 0.07892787080979155, 0.13156286861386993, 0.30232682403537536, 0.1003329726236482, 0.12767002347015566, 0.10833352759119966, 0.17074613621638668, 0.13390329786606375, 0.11212443707570915, 0.1818240433931351, 0.13519043283116433, 0.14621172611030842, 0.21711121763913863, 0.11066313968190264, 0.15297950005098698, 0.13248335389840987, 0.11488400069215607, 0.09036164881000597, 0.10596779445486684, 0.10724816486359605, 0.1809427511668013, 0.28750856917712, 0.11806389377001794, 0.252328310161829, 0.08889714916867596, 0.1848190641331096, 0.1326316378770336, 0.13674150040793803, 0.11333397499495938, 0.1354779303073883, 0.12798495455494813, 0.13813096939796402, 0.16612973634994802, 0.14949858038415834, 0.13790661288845923, 0.20587569553284876, 0.2427264399105503, 0.23577647493971934, 0.10127470152632845, 0.12601688999923008, 0.16044360194956103, 0.19530355960371035, 0.06841172058615955, 0.13244849689785512, 0.4253382668379815, 0.18997707284025608, 0.08568217692476127, 0.1635566615169087, 0.21586528288260584, 0.15280671658054476, 0.18077974297827293, 0.15859484792717043, 0.14852298273434564, 0.13414190361096015, 0.16858310228393925, 0.10373997246666301, 0.19076315565936028, 0.13262866545588742, 0.11782994583970118, 0.25122800871970197, 0.21402319382515647, 0.24186419263001413, 0.17038434353326598, 0.14560645536309288, 0.1529313590858252, 0.15537665045309454, 0.1554840866235956, 0.1941780845123914, 0.194499014065631, 0.17601778640622096, 0.09612898086948742, 0.07476569213453801, 0.10628696966675982, 0.08257242685724651, 0.08740814237464821, 0.19839434133421993, 0.2380956682346521, 0.21112174306425358, 0.13748189374323816, 0.09147576281740781, 0.1132292967409857, 0.18688644432733137, 0.24071015778087804, 0.2380693760970908, 0.20247780447525365, 0.1200812484227842, 0.12013871267798448, 0.1508610217922157, 0.20863802472670234, 0.19028428941965106, 0.16192841824264298, 0.2050591377361167, 0.08567741185787224, 0.15456277396409743, 0.2036014409555543, 0.19491038795921112, 0.1776454474536642, 0.11343569614954534, 0.09939823810371662, 0.07283949428388188, 0.10752573384032135, 0.08612570352852346, 0.12208952493364773, 0.17336117734591808, 0.12068032917957153, 0.1164406224063808, 0.10354986774825281, 0.1984817826098973, 0.1706183527506167, 0.10670778942444634, 0.09381732587972957, 0.06629425356344831, 0.27252585056328005, 0.13885119929909706, 0.19096673586435858, 0.17255865427995884, 0.06869090600840508, 0.154359883238231, 0.2779679859597837, 0.12265168791336399, 0.11577700640285209, 0.17455998237334913, 0.18099133646295917, 0.08798027215825935, 0.10389946431161896, 0.13633573427796364, 0.1359408619182725, 0.19302924373938193, 0.09149306108273807, 0.09359118438536122, 0.07916563385797125, 0.19790367734047676, 0.16846598276207525, 0.18215542238566185, 0.2004598982391819, 0.1655534084045118, 0.11754643202068345, 0.17150252546754577, 0.1957378088827095, 0.08522756502873476, 0.15418542969611385, 0.22870660188698003, 0.1854527873858329, 0.15035947934994776, 0.0714749920993082, 0.07344989015931085, 0.19091150092501796, 0.12113532411956018, 0.13769379366309414, 0.18720372730205137, 0.1670085617731656, 0.13625161782387765, 0.20488822352020972, 0.07552826371524604, 0.17613384872674945, 0.15233621602096867, 0.14914483162424258, 0.15375041432919043, 0.18186637741183082, 0.15586136960454527, 0.119339621685926, 0.18232702608070067, 0.20103967358027736, 0.16697851580477532, 0.14259848773719805, 0.165584051921483, 0.1567514258767328, 0.27563334833229747, 0.15749180389027442, 0.11930861044675113, 0.14555647578691283, 0.09642486700848227, 0.20361657885293807, 0.15629260049712274, 0.10509968660170994, 0.15828896434076373, 0.18109564699472921], [0.061642958392058654, 0.02663709546229051, 0.013741836207167757, 0.03244273191798599, 0.05357792180392051, 0.05434185702113375, 0.0463466378559749, 0.024885902737057018, 0.11945622026800148, 0.017245094997868422, 0.02623189049172065, 0.042496762583933534, 0.032148933368584806, 0.03670319967392472, 0.0347053419588314, 0.002129312657240418, 0.07287773739306197, 0.031725807686246214, 0.05407992772938264, 0.06468683255896454, 0.012498692883509062, 0.05899255847438209, 0.10276949994506375, 0.05161138176317177, 0.042325312106479565, 0.05169139581642324, 0.03573492582466814, 0.034306926442490476, 0.05433367137166281, 0.01745558531594373, 0.09554021931704014, 0.022145652197181218, 0.021440529549914985, 0.05067668171719678, 0.022478197558572697, 0.04547848786798216, 0.06551681987700925, 0.09845629469641755, 0.0753853117085753, 0.03919134983011792, 0.01676605064271679, 0.01833187498813195, 0.04971289331273687, 0.022764676137857383, 0.052959079809126355, 0.019027337266673005, 0.11489687096928397, 0.036064443223538904, 0.023448717960667227, 0.06982807160144852, 0.0208834438179169, 0.02913413223840537, 0.015564694542497879, 0.08963332135951327, 0.04333775858545015, 0.015201174331107929, 0.018998210603791862, 0.018367919424969344, 0.016998784323673577, 0.06368311948233074, 0.0207360063664495, 0.014143405132927002, 0.004842068780318744, 0.03446523085116379, 0.022552408495797746, 0.04421684830900162, 0.008798073564145354, 0.043878237446469646, 0.053150739686022845, 0.014255364095011066, 0.017977651253703143, 0.020375288121642608, 0.041838390452246514, 0.02713163586093053, 0.018897592615816864, 0.048891804105932676, 0.044736673439582514, 0.1088230271312979, 0.044057276024813616, 0.061676099355663025, 0.016207463378387115, 0.05668403295379493, 0.038085360185153065, 0.03968366091289828, 0.02133727430426065, 0.05793800780309304, 0.023181198142288674, 0.0765593184698974, 0.06300453029032196, 0.0965442311679644, 0.02469020174635995, 0.07291150654876426, 0.04149339807730529, 0.01677763389213191, 0.043156919700484124, 0.04452405722751733, 0.039208874091385834, 0.046850206600802566, 0.018630496061016476, 0.039310016849588965, 0.08572804260878794, 0.032618709975072456, 0.04881074051222494, 0.05440766780426907, 0.056562450969772, 0.016507430850798567, 0.007851156330997906, 0.06185207741274949, 0.012516774473741893, 0.052776030760498784, 0.05017002946847389, 0.03194677617190586, 0.07667813104607406, 0.020651658170766408, 0.03882598717727008, 0.050482754220044425, 0.020450669258171995, 0.04255368291670757, 0.10633661982513244, 0.04892697903297601, 0.01104184263010299, 0.01674159711617376, 0.06418544716472108, 0.02349909015690848, 0.025955690897160003, 0.05626059317540738, 0.012162951977863427, 0.06187050948820769, 0.03270254680706609, 0.020997451107588508, 0.015895339048227236, 0.06891055873805477, 0.012737721891983623, 0.04032854606667834, 0.016019903987105337, 0.03806263035643966, 0.0684156506172111, 0.03906140599640147, 0.053753830913093784, 0.08672309889187736, 0.049949537872547106, 0.037112815395718625, 0.013274831881356097, 0.04671131869057014, 0.06400104597090714, 0.033800890894546624, 0.0480191188774282, 0.047978933735360066, 0.07821935439302076, 0.030444194299859867, 0.07129178983309577, 0.01505582351162429, 0.046093579862386956, 0.06251868882006215, 0.010164061001682234, 0.05636838940723289, 0.019403172341445764, 0.030207892564395745, 0.05169796502037395, 0.06398950485632786, 0.0052749711809860125, 0.1263652301784004, 0.029541466933404727, 0.016810008767812003, 0.08326339219967205, 0.010476273431953405, 0.06440754754528885, 0.029240160722345598, 0.04518161730600461, 0.023336775277951555, 0.07894904548001867, 0.014416827658762135, 0.05568690440287033, 0.011082772792677486, 0.0534157180077126, 0.047135336865340514, 0.04623065214423884, 0.05318150577706195, 0.07650362387780221, 0.02840348737194173, 0.013164249962315926, 0.056405697889145345, 0.06761030068681126, 0.058344130163952235, 0.0642975066758452, 0.005352065960441026, 0.05072227544001034, 0.012487780918637592, 0.031381460740381194, 0.028023134293635527, 0.09136071173293937, 0.10990082857108886, 0.043999631738951134, 0.06576619681812103, 0.029641416509665793, 0.05239557234510299, 0.025118061852070595, 0.09283327061923281, 0.017544405549884807, 0.02028903428224787, 0.06646740475609418, 0.028389021716711503, 0.023058666209239635, 0.03229510294453752, 0.03822786786082772, 0.027159676594179005, 0.05655775868123578, 0.01307196509573729, 0.09673248195359785, 0.014835834660897813, 0.05136670094103583, 0.044156970876839854, 0.00600773667458505, 0.10192756165540028, 0.003779763862821124, 0.011664470056852987, 0.02529709468475513, 0.028966550504969015, 0.0320507477097694, 0.030117134128006238, 0.02518324252788819, 0.030097867016710585, 0.05092590161028409, 0.061312889409882415, 0.019323554738695105, 0.021713802688604882, 0.026042726146237507, 0.015244550229380689, 0.0480117989073117, 0.05123915113208275, 0.004980645946136886, 0.030329440074462085, 0.06912766805579586, 0.04036020081970961, 0.03254182922143129, 0.06383018921159449, 0.09415115635361403, 0.021104190138078505, 0.04704970738760406, 0.021108554924027096, 0.028957420652131402, 0.018320289823497017, 0.034379536255953774, 0.1334535276457187, 0.04675448774510334, 0.06994001236894438, 0.03395051935747747, 0.03474310626305881, 0.03678991316607402, 0.06312063091524667, 0.058136282849215695, 0.02310284266939327, 0.03727296224584983, 0.05232076002885738, 0.07932874929880904, 0.057386405345413, 0.04449636697949422, 0.033995910066991084, 0.029556233278145234, 0.04390223515069774, 0.056171363084426815, 0.01981850499437461, 0.062486616549112146, 0.02040460439128501, 0.011563777375305373, 0.07375400408261246, 0.01929906865341529, 0.028603658485676975, 0.042491373155386224, 0.06784686097694982, 0.06405324337162799, 0.07432870026076994, 0.06715438644131345, 0.047280050874237096, 0.0873729712780445, 0.022581339806258198, 0.04734689204563056, 0.06666401356098152, 0.026142804042225885, 0.06295539724129824, 0.06904509909931691, 0.036824957858170235, 0.039829010774772015, 0.028431528105190205, 0.009923682720851033, 0.025040022390443954, 0.09186659789373798, 0.015790079525041006, 0.03470444180552037, 0.07715692067699087, 0.040925910786515286, 0.08299948257063666, 0.0074382761170366605, 0.06341490826960053, 0.04274768702265236, 0.022617081638365504, 0.007140630369840731, 0.029446313067549662, 0.03184089324467125, 0.04227762696363273, 0.03590531143990736, 0.06987942247501305, 0.04823747691848586, 0.024971712245455673, 0.024170558561661074, 0.01576333252277466, 0.050010273323184064, 0.04692093566841176, 0.039764103975387356, 0.01719308528868902, 0.032178535005979, 0.05116195628239263, 0.06932036981226937, 0.08723633183586983, 0.043821309452816364, 0.01691117259343305, 0.06357982018662077, 0.05888228777856116, 0.06933634274549062, 0.025093290399038987, 0.0642485574879233, 0.016306962877992662, 0.07260856473998678, 0.05090434006565521, 0.05830624711609656, 0.044527324592514385, 0.07412027071921096, 0.017419826246858124, 0.0656651804644254, 0.03614993097500936, 0.03695071119094088, 0.06085532424490779, 0.09808854184924595, 0.006760440564023392, 0.054734726060902884, 0.020884671473815557, 0.01921423207668047, 0.04740374343049142, 0.05134299435021897, 0.03660402193124737, 0.04131338656729749, 0.04398172443372108, 0.03197873544488703, 0.0316524451913973, 0.04178667568691796, 0.06203010858547303, 0.021775997536737594, 0.06627120197780671, 0.011347285715953238, 0.12471791897569934, 0.05295121591658362, 0.02521536842499289, 0.12539909371445257, 0.1805935376473973, 0.18445160239934924, 0.08858895965761716, 0.12890725546786863, 0.17807540664028737, 0.18930005029805247, 0.12311484168974623, 0.18975575003893147, 0.15435251347239942, 0.14718870271838483, 0.15023351917343755, 0.10900629834542352, 0.12178757903917183, 0.13795077019641477, 0.13693599481015437, 0.11101682715478445, 0.18984550490014016, 0.1706248644979731, 0.10939837448419103, 0.16040502176169427, 0.2798941761495606, 0.11344181719206034, 0.11211418681928229, 0.13609040228109207, 0.15071840686423166, 0.13869025954796424, 0.10090845787236769, 0.1559157312036522, 0.14364562267738004, 0.2024121660619013, 0.15154878488711773, 0.20829095625348631, 0.16858861811699408, 0.15440808549042673, 0.09664150135171029, 0.09273837530805219, 0.26042049690600366, 0.13289065220423285, 0.16786339332259473, 0.17486225002475325, 0.1479899234348728, 0.14673044424383871, 0.09394386062218298, 0.12302550051601664, 0.11562647012573098, 0.21949358254430756, 0.19308116917888965, 0.12125316376407301, 0.14998247216065086, 0.10697963572437726, 0.16800207055864796, 0.24260087809976072, 0.1904618226352238, 0.06357901962473989, 0.1520655418355619, 0.27620540150711614, 0.13988993791562898, 0.11466951905599526, 0.22045675424798844, 0.2302226439238556, 0.1122469345348016, 0.19406093434701044, 0.07346391722920441, 0.05740805115971354, 0.12418304404784596, 0.16021662541935522, 0.23364170965167785, 0.14146979507659713, 0.1498166447685611, 0.09008791027290207, 0.12352723448026566, 0.14123160301917984, 0.1447948158508347, 0.17072145286346638, 0.19607004589371144, 0.20679277938700494, 0.2094877081652803, 0.14631850344519462, 0.207436339208676, 0.10089749515417124, 0.09970176980019578, 0.12857017678118524, 0.15162429051293483, 0.31234964427928774, 0.15043722195250375, 0.12888209714043525, 0.12972638732002628, 0.12117958867982512, 0.17880895114954443, 0.13383398223067486, 0.2240664686166471, 0.09745562298884315, 0.1435921190967483, 0.2350850039792638, 0.22851299614675585, 0.16021622705363459, 0.10952367582508635, 0.13634285889565945, 0.11269721803405594, 0.1577347916580977, 0.09190848758143765, 0.2314548503847853, 0.21095865826693275, 0.09679373068314406, 0.08433042244324762, 0.16102907698481314, 0.11010938068671573, 0.10409242653798673, 0.16206133449750562, 0.1956267414554473, 0.1614420290195173, 0.15056636905477894, 0.15272093005478382, 0.09634124085066781, 0.1526330291263519, 0.10216623634820986, 0.16726710112585177, 0.186079815030098, 0.0696008422622277, 0.08936302255718939, 0.10066534753047651, 0.19229468799406485, 0.11508388835335932, 0.11658089310531655, 0.2071357722724638, 0.08850301991427138, 0.1398200553751761, 0.15155610868767386, 0.1085044188244689, 0.10625196710949945, 0.22828418100553177, 0.2505291526716563, 0.1999295662127195, 0.12273304645092258, 0.20537174757449858, 0.13529011619187173, 0.21848453749572078, 0.17685878240773756, 0.15717617566547087, 0.19338965746423892, 0.16464959319320419, 0.11034416365286998, 0.11908485914670652, 0.10264517153583227, 0.1720272956956779, 0.1904420269232604, 0.09987067686574114, 0.24579615422314216, 0.14161576546968954, 0.16606918476041288, 0.1523320331809021, 0.17038894006081168, 0.18814823710389678, 0.15954559368471946, 0.23682990712263893, 0.1554090559722916, 0.1318269391213694, 0.19044881446226952, 0.15128761019197204, 0.12103806159669354, 0.4034417272815782, 0.12413879480933952, 0.09563136079739179, 0.14175021390040077, 0.2274282156459747, 0.1718245581873963, 0.15784543007612228, 0.10365844538976109, 0.14652022971741616, 0.19082025985323614, 0.14319140914707415, 0.10668917348788631, 0.1881593913440743, 0.22321388936571537, 0.10013634849700237], [0.012233144783925627, 0.00957634611686151, 0.03625079794155975, 0.022691024444817055, 0.039791663988463344, 0.03898660900191434, 0.11694075524686806, 0.04113676882679424, 0.046371145008672635, 0.01664628045663478, 0.012405731944337249, 0.03605647590912638, 0.041094430977658886, 0.008526111393415881, 0.04693773214615161, 0.0239740876526001, 0.07895408633856044, 0.05299484845431102, 0.05699371250586645, 0.016002588484796788, 0.024643813207324956, 0.08140277913621358, 0.030979975126683715, 0.043358688107541496, 0.039235637373020577, 0.0157532460176416, 0.057217433162394075, 0.017039409966298172, 0.0489729174953555, 0.015565885809220135, 0.05021442426368595, 0.022691294490810365, 0.059430638193002636, 0.06606900073107212, 0.044578962749050516, 0.06670947321840832, 0.05716389127736611, 0.049981127508104815, 0.008166790301460893, 0.06334411025407814, 0.03500195205091469, 0.021550139494901224, 0.07370388661060603, 0.054596466342768366, 0.0894653795647525, 0.06931910576719431, 0.03303233999758959, 0.015231962447174856, 0.1089834229600045, 0.021915310625767997, 0.07563944605569686, 0.0286839138566246, 0.018477678757100817, 0.07336404234651597, 0.061034814815127084, 0.03200390909407889, 0.023998545009582758, 0.042669182162611716, 0.04048505399916922, 0.020061557879671454, 0.04133438503730201, 0.06358375021767232, 0.060725499154819604, 0.019436173494003957, 0.015805814971005725, 0.02863814010314884, 0.04756299395775122, 0.04044352437279398, 0.041728215517416116, 0.05076459030650797, 0.04072028512675916, 0.03510748832336357, 0.03628468584089029, 0.018901668203574036, 0.020878278470087438, 0.00912723952018085, 0.027923186632594275, 0.022998788777077873, 0.05914362718261058, 0.03803571768765969, 0.06709417959134426, 0.07162734400480986, 0.012716100017930712, 0.02972326917393554, 0.023560834928385677, 0.017292312827081453, 0.00916318245036828, 0.03564603281237426, 0.0854201825155366, 0.02577008694530495, 0.041592491550310966, 0.05182425844513121, 0.04171396245158488, 0.05003051719658318, 0.06633918462020737, 0.014507433835176692, 0.03516032540750119, 0.03683352272116369, 0.03579257011053062, 0.05879357479692948, 0.07717796511227086, 0.030908930047805754, 0.03109694143096286, 0.04743208485325018, 0.027499465316894556, 0.03914350763924661, 0.05968361957779816, 0.03126220957886788, 0.06283714007886668, 0.04555294012290336, 0.015870217109970268, 0.10640359889235228, 0.054594390244493564, 0.018615542024734522, 0.07525887655755205, 0.057585300922754316, 0.031712458604165626, 0.024731371311410785, 0.003823882866380436, 0.012638501056860532, 0.016522036317074974, 0.030895879740015637, 0.05570983341444404, 0.027826378016822764, 0.01934083193660744, 0.01288139880935271, 0.02259154792784924, 0.050133548361519654, 0.004870568687516836, 0.062012634119920196, 0.04161810953049891, 0.010612800833769144, 0.07400520431298403, 0.008964588520147147, 0.025575703625837644, 0.03585419039272013, 0.039959054199918624, 0.04509758512159029, 0.03679363252294641, 0.045578990942768516, 0.01760611584740541, 0.019094942610770948, 0.015403343019105736, 0.011217980608043653, 0.01849682329432859, 0.012905835098917446, 0.07308546213373061, 0.05175865450573545, 0.060709288734341824, 0.053717809458894115, 0.04027929044358673, 0.024785598845130978, 0.05045824323690707, 0.0604440652645163, 0.07986842759794767, 0.04714844462972495, 0.06421122219293349, 0.05118495041143991, 0.008618876022557098, 0.04941120788815522, 0.059548217367621205, 0.021678943772830313, 0.06785959335825137, 0.05933518746807691, 0.1025241909308299, 0.009810707734657392, 0.06120125890799588, 0.01365959666849625, 0.03156676591794578, 0.019222381336975004, 0.03221741013769661, 0.01008770693348901, 0.013399302974463472, 0.027514153137622822, 0.02314234599320879, 0.004325106903354848, 0.05890925024305621, 0.048905743075714964, 0.03931463252933275, 0.026081457636469317, 0.04077815157811969, 0.0032087578344339087, 0.06982988722982907, 0.0625318540410409, 0.052497412243317214, 0.023590965166447625, 0.021260724883646737, 0.06580569631149692, 0.06334337480967084, 0.020647358502291387, 0.009851470315498451, 0.06100535490399888, 0.010301093063918094, 0.028088830163582202, 0.017296608665116855, 0.005093827297265131, 0.025627441373803926, 0.03836742992843351, 0.0048684236413288505, 0.017283813081561558, 0.0196659826343098, 0.06160011875533289, 0.03586858518481736, 0.05649953599899046, 0.04594075298237224, 0.02639893979404963, 0.10211663981599194, 0.09276349533108935, 0.09761199685594729, 0.04660865141739769, 0.06763296156761146, 0.029928552009345546, 0.013323410474244627, 0.021670229522691622, 0.027615246100110874, 0.05728787877747128, 0.04699632255060058, 0.033772017040680495, 0.0599220721051097, 0.09357333453672548, 0.021688845459251635, 0.009972820557924289, 0.018617901575541305, 0.038937004808817184, 0.05137692821482497, 0.005001148853015396, 0.031670337174868876, 0.010825219778193822, 0.006775460675388816, 0.04235146251777488, 0.020204218772930965, 0.027886916199819218, 0.016866984641960552, 0.03717968338018945, 0.0038174003261261654, 0.058704348536388534, 0.03631845499659258, 0.04761280882502756, 0.05017999244192916, 0.03889518789947033, 0.012966232513257814, 0.019387607350044193, 0.026807391062198628, 0.04775344724616697, 0.011037561156216168, 0.0572590317366825, 0.03734541884172828, 0.06758898812075777, 0.012936626087814089, 0.03814449834246789, 0.0323016683180486, 0.04709468440963857, 0.04387287866143931, 0.0630886735574853, 0.0499756308272481, 0.01413922037764062, 0.0321765125338589, 0.03593852901230416, 0.04150131942644235, 0.042886134432328325, 0.06379617107731682, 0.06485188620225077, 0.03768392628239047, 0.04766106853381761, 0.04941396963512225, 0.042115484454458764, 0.0600199896331516, 0.041463493835181, 0.036834258165571, 0.02308152052724073, 0.046654440492631934, 0.06380593486791176, 0.04722705291163537, 0.03359420037257575, 0.03952615323566622, 0.0734374795349375, 0.06542830607823788, 0.020496866275225917, 0.04172524309626991, 0.040364107868123444, 0.042335386162683855, 0.013590988706827406, 0.08870283862756145, 0.022683461241784598, 0.04865558089448079, 0.03125904180530099, 0.034793288852538795, 0.03725112874000784, 0.01525144980874874, 0.016381859463909944, 0.023128309347216162, 0.08593985825897225, 0.03277712929693442, 0.030086316326032245, 0.048745082946674484, 0.011806034486770872, 0.03763429144577634, 0.06719517296240216, 0.04710821352238136, 0.05053019038431587, 0.022627561721169663, 0.014428831298925705, 0.11304643921433918, 0.03389651781969494, 0.04416130310405166, 0.06410796503205934, 0.06300898892204128, 0.04590432933201233, 0.016100596028169798, 0.03602666742799263, 0.04115759875745543, 0.07635534756005773, 0.028733426119170846, 0.038254841816641634, 0.02032347759532352, 0.09289149330147813, 0.03847366717133311, 0.013153161797221872, 0.05210106516437185, 0.045735161796572714, 0.05658110138028861, 0.023878087259588704, 0.042275826657010664, 0.03481961929449632, 0.008273188422824587, 0.02842933134806733, 0.02514994260103953, 0.009471440909340257, 0.020810391588677323, 0.01650870638719249, 0.0319818610836181, 0.02143988412083878, 0.08199545539795391, 0.01712118219133587, 0.056403418777570616, 0.0729545223857126, 0.0379092212496025, 0.05097567434272459, 0.01962293423862467, 0.017505710448829398, 0.051306091894906376, 0.05752107211118264, 0.054571553163470767, 0.003537195049331434, 0.055735822947275256, 0.020426751993175958, 0.0218554446849251, 0.06864683297012122, 0.04807403205984062, 0.06430542802498226, 0.03074885789124716, 0.010740785397619251, 0.20331795778005354, 0.21333019068885237, 0.14340140916887792, 0.08521939087058268, 0.10574716113267407, 0.14508956051882238, 0.24607323290359592, 0.1377675219649269, 0.12873008997449953, 0.08650550693874398, 0.08060577956418838, 0.10768375479646268, 0.08499223047927504, 0.058212186840753403, 0.16503406207888358, 0.15898259566916575, 0.15141570009291172, 0.2296799778818123, 0.12625017143305273, 0.10202282468878454, 0.15058077150775542, 0.19143299229683416, 0.12232725733831046, 0.1571256904712608, 0.1501672678897458, 0.1604701392352581, 0.156966298217735, 0.14024046910626276, 0.12806086620736506, 0.15717677321405182, 0.25407888235584386, 0.152793693085832, 0.2436836054849048, 0.2806614898145199, 0.20667870889507955, 0.18465412540301201, 0.12846811854791257, 0.08766854332099039, 0.14810307462128902, 0.11451222588338199, 0.14630525012410459, 0.12798793463697358, 0.25469878538241314, 0.16989907279850977, 0.22805755687577112, 0.09876451485099332, 0.12557940016831123, 0.13011940574694064, 0.13614367603534652, 0.13443948280426765, 0.10957654355274093, 0.15796262620677873, 0.12748841466682573, 0.12445653743681409, 0.14657240030505966, 0.1428255255544378, 0.1366544574979813, 0.10132470408514624, 0.10098049311988777, 0.10475896899738621, 0.1275579218241957, 0.14829766095405625, 0.18379080559938185, 0.15367412729369057, 0.09026771110873069, 0.07926087390871779, 0.15922304002508042, 0.16497839813030538, 0.10099763816763317, 0.2873011738542588, 0.2312957798881877, 0.14903476011128197, 0.12256663683201037, 0.1821694111511592, 0.10587002631397018, 0.12328230850999394, 0.13427624478936195, 0.11487662326544525, 0.18809534639360445, 0.0909614113850459, 0.2475954496091412, 0.23082385440507244, 0.12469159619462107, 0.14605846256017685, 0.18122539164558535, 0.07770661174529984, 0.1335536859809391, 0.18339800167708628, 0.17918644863511288, 0.11030064985877085, 0.1839990282972013, 0.15189263579105178, 0.1468620887927471, 0.1380535945176117, 0.14586764537999708, 0.10393337902402687, 0.20819426063568364, 0.1729345276591278, 0.09971543680876495, 0.18523745539207614, 0.1956187741410348, 0.1138264392953246, 0.10991402060514498, 0.14355476464956038, 0.1373097691084108, 0.15039525565601167, 0.1864411327387056, 0.17053304119936882, 0.18341347665315677, 0.09974906040776162, 0.22578108064349622, 0.12253129719606332, 0.10521502113871037, 0.12911967632751312, 0.11784816341054057, 0.11106099978449846, 0.0922617537059611, 0.0965130360676877, 0.11615856415441922, 0.12245901680040745, 0.07341121038001391, 0.1963442594053284, 0.2238069180279009, 0.1940675839901932, 0.10268850912970882, 0.19499013771212872, 0.21298427134752276, 0.17762209709373214, 0.10156359328257461, 0.16221228446210587, 0.15741594586401217, 0.10945088981140046, 0.1458221704008118, 0.13993184292508712, 0.11640710605969352, 0.12521795222475646, 0.13206847132213656, 0.0931352854616219, 0.237233895928629, 0.19915736490680327, 0.18488024391474264, 0.13464067281494219, 0.11532198848022569, 0.14575198142518922, 0.1303252688939533, 0.16664266285877075, 0.16576483334985473, 0.128120843230957, 0.14937487250614553, 0.09009886533021928, 0.11312951378884817, 0.0787226664983938, 0.22837001349656816, 0.14249849794132097, 0.21675241269892265, 0.07652986238920882, 0.2079215026911228, 0.13792271605662762, 0.1680592207177993, 0.13343301181110645, 0.11118220255499887, 0.18705810930940414, 0.15797750363426824, 0.15996098187902283, 0.15301360628537594, 0.21355249408272006, 0.13297155108903685, 0.05880215498168142, 0.12240505356702114, 0.0972044610628678, 0.10943664823688808, 0.20887062434227238, 0.13889373250065312, 0.1280857104387495, 0.0873261173405955, 0.11345068849022351], [0.04929599592522268, 0.10088752835027634, 0.05484602331454235, 0.027304323570382212, 0.039279262249868725, 0.008821260172783608, 0.0321901680511092, 0.025474074401802597, 0.03147729259404925, 0.022242089260309454, 0.0763588868862679, 0.040035065443765734, 0.04432223519430526, 0.03900792922884707, 0.0708537790623884, 0.013800889137201013, 0.0304736944306041, 0.011487292114555115, 0.08735839262484543, 0.01620692903205993, 0.08454297353783924, 0.0030033213026340933, 0.06363277218394703, 0.03783731240658991, 0.003996595473689658, 0.051857870552809014, 0.04717853273295107, 0.09025843378396765, 0.10787777422416596, 0.03045195860097245, 0.0979128166011745, 0.0838792272993634, 0.047076558769350095, 0.002245600016096667, 0.05643356433739105, 0.09184545386702785, 0.05017364157303687, 0.05556631450270934, 0.0354332059261299, 0.05444226050448995, 0.018716914609314936, 0.050603750146805286, 0.033578154661001704, 0.03322951187710128, 0.018541118498110486, 0.06292169320306952, 0.024935250290699547, 0.04217574493058267, 0.05496524957819812, 0.08235140283021235, 0.05689900105578765, 0.06496578815483278, 0.017163701986353246, 0.0337283308767984, 0.04720709632120786, 0.04230995587403736, 0.06490500673892037, 0.0238296743332138, 0.04534666711885122, 0.07799649175496833, 0.03034810197629756, 0.03388794529582224, 0.06046549657419805, 0.03801942682794986, 0.067670997833052, 0.024423413541949084, 0.026430843525656292, 0.037516072587741, 0.00946184470047874, 0.029884053792263714, 0.06023460533469916, 0.026070602170582262, 0.04888629210331748, 0.061490625638755105, 0.07487240818239028, 0.019441356078811714, 0.07238600087622482, 0.051842089141568834, 0.021615572979733832, 0.042338327940313086, 0.05144581867141589, 0.014351234253075336, 0.021101918687383016, 0.059887142326202125, 0.020736722658658703, 0.07698600646108389, 0.023928444134071473, 0.10439331523112713, 0.03307175522129382, 0.02592742416797386, 0.039939970949724804, 0.03582458875532593, 0.04733887110506335, 0.03626810003732962, 0.024392706822724115, 0.05427532611534961, 0.016110984180423043, 0.024177916836173787, 0.08923501692592137, 0.0732148926885378, 0.011962229280822701, 0.07599164731800556, 0.02353855900676741, 0.03893049689190042, 0.011902730104573553, 0.012497719951845225, 0.05542430478418547, 0.10001757422522192, 0.06445086215652766, 0.030373790819618492, 0.018395841414589557, 0.05396543971953854, 0.049939203346448566, 0.04003813362590248, 0.029388377668275952, 0.023122523468168035, 0.028160087831859148, 0.04436091114316256, 0.04366337276634671, 0.009934759394626224, 0.02823741674693602, 0.04193973622374958, 0.059912802441225904, 0.025889983535894466, 0.07423391986277796, 0.049163711692897544, 0.011955281820959382, 0.08964580859267905, 0.06732867144408726, 0.012501530281658615, 0.03863629614633899, 0.03736390837378079, 0.004076210203610602, 0.022091717692092065, 0.09592631996999826, 0.003618324478720165, 0.04972967829915786, 0.025996205457035574, 0.030609152182155562, 0.06981704759621812, 0.053999358262386055, 0.10824200306688586, 0.07903283251629722, 0.05526221590116621, 0.04763598681517667, 0.07953176259874337, 0.045464070093247204, 0.019097434311744668, 0.09174735630832373, 0.02326932506665828, 0.021617725686801058, 0.053257616612339215, 0.11071246042246781, 0.00976201422858022, 0.09259588295413602, 0.02943008541009359, 0.09189871996040307, 0.02635425388542635, 0.026018988911903677, 0.034315119752840656, 0.03139247325429272, 0.08783549686232883, 0.04737362851418796, 0.027378180191942283, 0.026208658875416846, 0.014859613072457574, 0.005994022743130524, 0.05376801503101184, 0.03957077785725555, 0.044987007990599646, 0.06841919760430051, 0.04560692250848778, 0.012347741961298932, 0.036634148338869695, 0.02522118303233818, 0.035014274575176745, 0.029877331370728153, 0.01588086094406824, 0.06604325251593705, 0.040647096916913025, 0.03365537632376917, 0.05642793359114759, 0.024335420682966232, 0.045792154907699556, 0.04783360685612406, 0.0281426114510865, 0.11315133197293167, 0.05435934297800545, 0.06894165424690132, 0.03301473146665, 0.026603284171752395, 0.020422626609703707, 0.029095327969820752, 0.04141192845699768, 0.04392681125130865, 0.016207708526522886, 0.046869263037919044, 0.054528659900590304, 0.04129088656496137, 0.05474971457114143, 0.04320571567082117, 0.04243441834865559, 0.03858546621256298, 0.03831489161858636, 0.05504148298754327, 0.0415295344446936, 0.05336737402925088, 0.08679762392515138, 0.031210230513205452, 0.05321416793571365, 0.047600842531650304, 0.050048248301590645, 0.05574640645194919, 0.03888583779635449, 0.0324020718014048, 0.0580481750770442, 0.010864880150033823, 0.043670363318655765, 0.025072784140525807, 0.02733129752619613, 0.06715841606379518, 0.04769480704600292, 0.03554441891009769, 0.08339849180511891, 0.04701241039701047, 0.08627617085773139, 0.048833320953793107, 0.07653049058130673, 0.06917221606859277, 0.025246846977801576, 0.07442322018886767, 0.04308023429926365, 0.03374612709927944, 0.006293975851393395, 0.03415174001166898, 0.060345649779323614, 0.04357623409539942, 0.12243244887119341, 0.0367459167365826, 0.06571078567855781, 0.04885663683976858, 0.012742653582996179, 0.07689278122157821, 0.028790733326346647, 0.042980010846569654, 0.03238049493501744, 0.06029789185812397, 0.08793482782259103, 0.028309212591979774, 0.056427569699383555, 0.04494981825231545, 0.028975293483404867, 0.015166707077784645, 0.03441199923174516, 0.053450850799920104, 0.014267630120288703, 0.0069493793923738265, 0.04335075143664595, 0.05918783045584156, 0.07955223246808014, 0.04434879546264007, 0.042287731663353985, 0.04533226466587475, 0.03593885076923236, 0.03602387120706901, 0.023638975896662282, 0.01885508048167873, 0.06809991514009815, 0.07872001583417577, 0.017086424782211264, 0.0529525910444077, 0.07585228060282047, 0.0313384372425536, 0.0613166815451076, 0.010191223606647504, 0.08302284825232722, 0.021144566802127708, 0.02601086263424687, 0.03455665578404742, 0.10882259046118106, 0.03387353518196652, 0.01897228235799459, 0.024880157077624917, 0.09377313026737782, 0.028624105372376023, 0.10784725328126263, 0.029972803163071795, 0.013079128017829312, 0.04641586922169213, 0.03760185145262269, 0.025972177109290517, 0.08123609372564862, 0.01732214237563312, 0.11384393674351516, 0.03352871900724788, 0.08946780040259324, 0.061826509228276635, 0.03528375366342164, 0.04879367207327197, 0.03779430806096043, 0.04860102394295316, 0.07518805172895232, 0.04043473734430248, 0.04725512237318101, 0.022083392231574944, 0.026839306285124154, 0.02944625561095534, 0.015507073239273122, 0.05453694897193102, 0.015967086055165818, 0.006599058397114278, 0.021903807815584927, 0.02415274318698193, 0.029196742689237002, 0.014368075738480736, 0.07026685612095941, 0.04554694165445624, 0.041780596779238795, 0.05696892190063673, 0.03070428498059271, 0.06845894990669144, 0.014793461380195955, 0.03215494715879041, 0.026681398326951652, 0.07811876704856273, 0.03786506777208659, 0.10678121129110937, 0.03054133041821901, 0.028966996751184908, 0.04676190347621038, 0.1010345099794288, 0.0197853218959344, 0.062253882868155364, 0.021042437705722068, 0.0188576526218845, 0.05436715324439349, 0.022483272891071056, 0.019503549011724613, 0.03202923213041598, 0.014463842474675227, 0.0715431969072069, 0.06035547868739213, 0.019114357193992026, 0.03353806911036372, 0.01945855858315143, 0.07521514059795488, 0.054550309545330466, 0.07510994906507193, 0.02430674218152079, 0.038320706225931644, 0.025956462730743715, 0.06101298130928509, 0.10243090440429027, 0.08419410475800115, 0.12461871058950502, 0.09856789838522674, 0.15445331532147624, 0.14258811490670328, 0.0828043906198394, 0.09162057641773455, 0.11477365338754271, 0.11731940952520217, 0.2376559490878736, 0.20360927037414045, 0.13411205682543018, 0.10584077707702115, 0.16822904708885378, 0.10180979861967987, 0.13680217457154106, 0.18728551484884756, 0.09006531834001504, 0.10643163004950171, 0.26028042538992824, 0.10907323910824715, 0.2385667969863261, 0.12553680567972123, 0.13588066272918256, 0.1073198706933087, 0.12466676728499514, 0.19652873337749513, 0.29295217546243824, 0.11068443692619763, 0.14397550013757524, 0.29349435120821, 0.13071597373533633, 0.08033284541940497, 0.14134637831199554, 0.20398120606137862, 0.20113719657303827, 0.1092234766110778, 0.1363778384702821, 0.12302976762575489, 0.15997926073689617, 0.1111978690530504, 0.10730040439915274, 0.13823601537414137, 0.12585958150485832, 0.11684655707569853, 0.0799978121874794, 0.1350361886884897, 0.16713338813954787, 0.28816875310674794, 0.2287574088381183, 0.17759772017598155, 0.16883211150284738, 0.07611529390898443, 0.23897244054223263, 0.13697334925734228, 0.10501357831902082, 0.13867089284523842, 0.18547819086140205, 0.13890373760894423, 0.08889275948486983, 0.2562298733861216, 0.13325831312085354, 0.1191940266759165, 0.17260518646047962, 0.2086399859117885, 0.2713646144876557, 0.13060798598152976, 0.11368475899460817, 0.098493350369315, 0.15032411673136298, 0.15770993976583406, 0.17082793908494134, 0.15266584833302807, 0.16679005817540232, 0.1353071846308247, 0.1344244215156763, 0.12811797040124095, 0.11174264949776473, 0.15266537335851502, 0.137881301343441, 0.14836409609884987, 0.1359189364818796, 0.16240426609593053, 0.13091842013020671, 0.2022908790217292, 0.12018279337714757, 0.1870387732501953, 0.13025720964276022, 0.08884410524079878, 0.09453002513656694, 0.19281844698613693, 0.19114169502450576, 0.13921564264643577, 0.14275446323858154, 0.14812636369418714, 0.07881455108403199, 0.1818359483994784, 0.16221147240890613, 0.2389380738379494, 0.06809605405695977, 0.11356097450780292, 0.12430842965841295, 0.1995034834309932, 0.08908148524501631, 0.16924538529447972, 0.09183310452968844, 0.24230728256365947, 0.14135469802685324, 0.17683344021920236, 0.1006292111630882, 0.09914012009938879, 0.206463162396704, 0.12247598564793026, 0.12732883089131888, 0.2532643317094734, 0.1460678854416455, 0.1771287671140125, 0.12883407874934136, 0.15441907119126091, 0.1673161460747642, 0.09071657734532511, 0.16082540484926394, 0.058893622049400886, 0.16779158024057267, 0.17593313369058794, 0.10741366283787836, 0.22536212247946572, 0.2035295819082568, 0.07657327659187779, 0.13409120391213125, 0.11490332142960642, 0.08868360982066201, 0.12024162126885307, 0.15367446437237725, 0.1708857021144321, 0.14292550002855642, 0.08441882898970958, 0.0934043508623877, 0.17061070719313237, 0.12569540886268502, 0.3725125208016365, 0.22486283233569515, 0.1633019679256024, 0.1295205548165306, 0.12290601378246663, 0.09855772473759229, 0.102766037227646, 0.17146468072408633, 0.12309488509931873, 0.1590947662630389, 0.13288158172320935, 0.1858368119405162, 0.09923434125319605, 0.24267495880203865, 0.07397244639334179, 0.19383130715258662, 0.14046487158104298, 0.06988812523383288, 0.12486877700974866, 0.070878975694218, 0.181227904413977, 0.11916649347591786, 0.1358251519981892, 0.19832969883516913, 0.1886625885362587, 0.07285736711515535, 0.17074661119089973, 0.12641640485174235, 0.15021110344077312, 0.1753482408821583, 0.19104896774215085, 0.09576257633706255, 0.12686445903513702, 0.23052625989000644, 0.1641313653559454], [0.010200446347645935, 0.06905676661840371, 0.03969316423359898, 0.027458276599645618, 0.017770221456885338, 0.02604885101919213, 0.09238328589426895, 0.04181766394345511, 0.025371098778240626, 0.0892968938475655, 0.02134587555643051, 0.05963495384240824, 0.02061154006139165, 0.022607580232884616, 0.03072675816985148, 0.028052454393717553, 0.06939353120903816, 0.004112131108770207, 0.06626305846317161, 0.08363579520054402, 0.014786875896876859, 0.04413899079325699, 0.012767771690813525, 0.03938726915587341, 0.03536058462134773, 0.0640350258007886, 0.07044945317771166, 0.0779485040073914, 0.042256421649888645, 0.0636704752011405, 0.06337237506804448, 0.05165757686500588, 0.08986946796217272, 0.04981233152530847, 0.09764480840174422, 0.010126043888439816, 0.0428266208919306, 0.07052288270525395, 0.05416574489866054, 0.054161784224092006, 0.04782415716157806, 0.009784735438804473, 0.048965356207542846, 0.050404011872747255, 0.018366065492192586, 0.07951713798026885, 0.04363741387703246, 0.07332108779660157, 0.0262872556660084, 0.01572866608659106, 0.05792583849641585, 0.044068227251691204, 0.02441683667711914, 0.0636363459841138, 0.08713925317410501, 0.03805546360390802, 0.0166308744284775, 0.016564324370495254, 0.0822002690045103, 0.018427170580253005, 0.043222251678666765, 0.01769851945761231, 0.0357530667867151, 0.05975420308870174, 0.015091970412721558, 0.023642040248359406, 0.024920794211568374, 0.03645036767627444, 0.026570269612655528, 0.04145639986100216, 0.05203775948874893, 0.06766611785297433, 0.037963134687273734, 0.02450593270271296, 0.03747617472864447, 0.057109031721108386, 0.029956336103139386, 0.04137579208960937, 0.047879426574875275, 0.042381382081657655, 0.07830733193024512, 0.05628585109427091, 0.0209323930058388, 0.016740915297921148, 0.028449546493169282, 0.01195312815628225, 0.04416443257322235, 0.02531461894602305, 0.03932005643183666, 0.16166169707092548, 0.08733874246958764, 0.08591612485507805, 0.04000742882189732, 0.020317588294405612, 0.0022935329405065147, 0.09634447374170828, 0.012946387005579329, 0.06863735646249787, 0.03039783831956166, 0.045391931423857335, 0.06333472184656609, 0.014076181875181296, 0.04576403565043884, 0.03559366687231007, 0.019850550452247262, 0.0925596010300421, 0.022726492400491433, 0.0354060021439387, 0.011281472059988208, 0.03351081936289707, 0.029733096166784247, 0.02699621449855547, 0.06903524720861066, 0.06925115376831063, 0.01495772882574989, 0.003662777927538921, 0.04352391029017107, 0.08634353296891337, 0.0429214051203622, 0.03239898446706995, 0.042852660220476894, 0.04759008282675378, 0.05531224527306134, 0.06031072000041605, 0.04862041745875632, 0.04792397841811181, 0.054922731698400555, 0.006905722435593846, 0.03779738390397641, 0.03307455527265707, 0.026311247624577056, 0.012829462836136021, 0.03232238333552115, 0.03270136320122308, 0.0416922208762938, 0.06270922254770994, 0.09749118479028826, 0.021810258903931228, 0.0521480723194057, 0.01753600539579507, 0.006530754476590383, 0.04720176051881525, 0.05684060600375938, 0.03842317048580416, 0.026487129920672987, 0.05139175584659942, 0.02238673049085323, 0.04098044858584481, 0.013279673557037549, 0.025115351816038453, 0.0505056410967823, 0.05967978147729751, 0.04804508542762168, 0.03591599070557183, 0.05025054913975539, 0.09723018629536515, 0.07024995622134979, 0.01953402781979211, 0.03965970534350603, 0.02566004224542168, 0.025468028052860213, 0.03473474058292566, 0.09459387090417648, 0.021922458226101536, 0.03254350312354584, 0.022392372728415558, 0.0034618677783592217, 0.029891948328323426, 0.03053805156190309, 0.09494862323927303, 0.010008751039182948, 0.0357446551413065, 0.01948051849350093, 0.007882068457547575, 0.01182222958549016, 0.02601222244031247, 0.01677014921311169, 0.05869941876059579, 0.04742214103199301, 0.04456557153213409, 0.03297081547639063, 0.026671506216629382, 0.04609155739026685, 0.04875184750304588, 0.07344514807505954, 0.08219280730812781, 0.10283888452836584, 0.015335185134092407, 0.10763506990887466, 0.036927824314202995, 0.06211961829854597, 0.025594553219214566, 0.017892952572794694, 0.09225207035459819, 0.07517510484303198, 0.056640990303769234, 0.0783766628873925, 0.03281729528680444, 0.030787501281367678, 0.057927018271819244, 0.13979071420767616, 0.04466193007125009, 0.03537988620659998, 0.08204423221609286, 0.0054279110589695555, 0.0737871910114923, 0.002775736929540853, 0.09539385821910636, 0.06142249360920922, 0.019755641734527967, 0.009977418043079877, 0.052310410181000355, 0.036908840655439326, 0.03811462474386058, 0.03556860430586723, 0.030247246501066034, 0.03850233418145969, 0.0133365603734649, 0.014519967033617921, 0.03328438292467787, 0.03562383158432861, 0.052628286873861674, 0.04082685561790582, 0.07058335768599665, 0.03804527846495471, 0.03411140548245561, 0.02527149394154549, 0.020340659032245318, 0.06058514035577255, 0.04296398811763333, 0.03803624245788782, 0.1438450966511042, 0.05410239708820178, 0.05847421572393468, 0.05482549598861126, 0.01203079702287552, 0.03678408323697025, 0.07933818750203618, 0.011273833205773225, 0.035814426599010345, 0.05635461514635433, 0.041494152673910704, 0.012369968087202119, 0.07696299317983851, 0.029795333149752794, 0.05712122784086293, 0.03155015713174737, 0.08934148016475862, 0.022484738034226244, 0.020389566085331386, 0.034234033176495184, 0.023525116078916098, 0.03443791598622357, 0.022757549604941762, 0.06144393257977021, 0.024936144698351145, 0.053957238748309114, 0.007896714622244961, 0.03143218725228743, 0.04703525896935214, 0.06716001718755692, 0.027391554171880408, 0.016648994323106545, 0.030770524772965623, 0.020228421405678796, 0.05730659047502184, 0.043257606636372306, 0.003475960444531314, 0.055769488681107766, 0.010434276491944349, 0.025077639222745935, 0.029889494931745916, 0.021183455340383996, 0.06165271835221399, 0.06784942737149616, 0.023336495655859192, 0.04531760940388326, 0.03663027959485208, 0.014328358867656321, 0.01687784585350704, 0.03256086650634966, 0.03145247326052237, 0.0695545782124804, 0.032661622390151024, 0.05395861004569358, 0.01179317857379154, 0.033505847452268485, 0.041901841684575045, 0.055500591819685315, 0.07899763843705578, 0.010565768780877755, 0.05717541323974729, 0.01918708383586378, 0.061901168326937386, 0.05217516501884788, 0.0524433417576215, 0.031332536450316834, 0.011642315751692701, 0.12337720382117456, 0.016699822341662743, 0.09736809744349412, 0.026821305134123372, 0.019514829656409643, 0.014221073999520273, 0.03384080407540164, 0.08095245733256302, 0.02265839867534176, 0.039339783195886886, 0.03308107085045307, 0.05836065468047896, 0.015051446276746932, 0.09064432759318622, 0.05053802746378126, 0.02880935309334628, 0.034094271926029075, 0.014885446514874218, 0.06406698698898958, 0.03633015315919634, 0.04258114716879303, 0.04441950537805115, 0.08572011359877164, 0.0416458495742371, 0.047682170425691915, 0.046025715963614565, 0.017104289952605482, 0.059010599844998894, 0.03574378563151245, 0.08246338190210444, 0.0355216546074277, 0.02669594633663374, 0.08837958016703207, 0.06452275950822138, 0.08639360447564433, 0.029857476286950613, 0.008315334749978878, 0.08290599686123672, 0.07897225028324513, 0.03410703495084759, 0.017380029894411564, 0.015465965918866138, 0.03493377405609335, 0.038651805596366044, 0.019899670094732317, 0.031325572711085124, 0.03755621942541292, 0.021214253990159884, 0.06261616967798722, 0.062084577436889374, 0.018051103763883154, 0.04779734408422824, 0.029414179509565718, 0.04293256702141897, 0.12669835585139452, 0.20101443864405158, 0.12035496397725037, 0.15768009298030408, 0.062400014139711864, 0.10652864742423258, 0.15322679323294472, 0.12384688466667168, 0.22483575878845108, 0.26685894496979257, 0.14218165929759705, 0.12710246723145247, 0.15413079230535418, 0.10749718940426266, 0.13156602489611796, 0.1866418324531086, 0.10171264334912263, 0.22978695439955882, 0.17777378250273967, 0.21190732026532774, 0.22233984433114531, 0.10519792205624043, 0.08213895898793014, 0.1945261642216675, 0.1741625819235079, 0.20719647707958377, 0.16868869984342208, 0.2311593089853564, 0.13184998304613177, 0.15736691623685822, 0.17061602384332689, 0.2762687110131787, 0.1814925877918159, 0.1803529247521393, 0.15851339745906093, 0.2789434916790455, 0.14359132236530706, 0.1613598431070005, 0.18151665827439678, 0.11733132985330398, 0.20373277906929294, 0.12238020933563672, 0.2076186221693793, 0.14756695097011907, 0.12106138131310865, 0.17487640732959395, 0.23790972337367075, 0.12535173415897355, 0.10681839719895395, 0.1342119240472394, 0.13956818098743118, 0.15629964850602612, 0.12520754108986548, 0.16837694802351538, 0.1765563615387486, 0.21039023634887513, 0.11462022895894705, 0.1819760812025878, 0.194394642246827, 0.15472818766870808, 0.18911723107580217, 0.19800343730997658, 0.09566024231213717, 0.17743681106836567, 0.1908824815144462, 0.0899388678672333, 0.1119013369504002, 0.11107995279974515, 0.1508793159718475, 0.1470484013759321, 0.1274017471399519, 0.2677085364778196, 0.1256999364423175, 0.13958463655604472, 0.12086701714583944, 0.19386147569504478, 0.10075744662073352, 0.15104523529448818, 0.1741822857049204, 0.12455699454632499, 0.16476954724038803, 0.1042957692557285, 0.10937771309287318, 0.12852712263984065, 0.1828995848735494, 0.09659837060157331, 0.15466231942897843, 0.14812648626825503, 0.13768443206865943, 0.1598492249726288, 0.14608890689428777, 0.14216213937728636, 0.1470161337525614, 0.16035256006063955, 0.1539319618454864, 0.20359902011771358, 0.12560675716808728, 0.187653451557121, 0.10266788604278719, 0.10540601451911273, 0.11154867603533691, 0.0872382240730428, 0.10694159945893673, 0.11792121755499994, 0.18886638324587576, 0.21099602803587916, 0.17628521237882877, 0.15473859114271982, 0.13798176611383117, 0.17781567219043934, 0.09462960124496492, 0.08021047053438041, 0.1672300224703166, 0.2062531930184172, 0.12090217292068467, 0.11305518027755523, 0.19241073499283484, 0.21802672335217077, 0.2765555649755463, 0.14532857995119788, 0.10934522330400445, 0.14147167965289087, 0.3026386218205575, 0.1983430287650516, 0.14898278870649878, 0.07652924951886939, 0.11858986675619118, 0.07322728033027343, 0.125366672873497, 0.19191863075379403, 0.16638159541593445, 0.060786640632056424, 0.085750603898158, 0.2039332029920432, 0.19844148638508013, 0.18124454384369237, 0.17379305175235196, 0.07248624348111692, 0.0924789013280984, 0.10665078482200062, 0.12173035993210732, 0.1411164600041605, 0.11304920479174584, 0.09139222859014427, 0.2365366180217074, 0.12156431037451952, 0.12174106218040952, 0.13657893655040573, 0.0821381469347304, 0.13483343585844965, 0.13459836943976342, 0.16458268307389753, 0.10938202616788688, 0.12012847774331609, 0.09944714515680268, 0.1532836676004433, 0.2594323660577497, 0.14080265506861672, 0.09151780572269233, 0.1350308873600537, 0.10756013884900079, 0.08504885203775861, 0.20578788653496774, 0.18190319559747176, 0.10695297586461229, 0.13004800635239772, 0.12719803670000646, 0.1407447694650581, 0.15203900454986483, 0.1378643861220729, 0.13960916669138018, 0.12901702054565953, 0.053587708577153184, 0.1002893056119642, 0.13299143873155117, 0.09484860279987897], [0.07436016349182015, 0.026704815719577096, 0.03968241602002133, 0.08073850429706997, 0.03428556025028229, 0.027524855385925022, 0.037172777097552054, 0.012957480916332816, 0.05069630505937723, 0.056185313545527964, 0.02964283377232571, 0.07490888928934451, 0.0009037335152125678, 0.02585678320047596, 0.041440147305688554, 0.016838775369368734, 0.034244704781280416, 0.013560491704171704, 0.049534605500558694, 0.0504768974778633, 0.021029460176284757, 0.029728283219399954, 0.061288175413445126, 0.0239303995734982, 0.0430965481416112, 0.038383896988365925, 0.07191895537318722, 0.015105224691421516, 0.0988688177218841, 0.05611027906378431, 0.02835841267369688, 0.03380900376566476, 0.019923370939889745, 0.03460346758666058, 0.06383895325744826, 0.031842168781065175, 0.016539403530318412, 0.04093766640571337, 0.02608998802550618, 0.019164064808958964, 0.025179948349813783, 0.03311352616536521, 0.043981326068000454, 0.08411331312550653, 0.03887077650776313, 0.0496175421792413, 0.07988859103211472, 0.02840495634553654, 0.011570326469448066, 0.028987108474417083, 0.057188835100180684, 0.05229833280487407, 0.03587916485905167, 0.07002816610639134, 0.056073548978254686, 0.09215737422627789, 0.03624351244539984, 0.04352949890157869, 0.06253155526675044, 0.05101805815713541, 0.02932390945422794, 0.055811428164522496, 0.044868881063115214, 0.06642778268865039, 0.04513141173388689, 0.010995362160517084, 0.035845276959721124, 0.009239726125322765, 0.023955994571048408, 0.03959121325263574, 0.005325778610929246, 0.020436195942062526, 0.054089381254368255, 0.0560601462700194, 0.06379757684865786, 0.029730307606739864, 0.05711421430591614, 0.05145470529133755, 0.013973648667395597, 0.01591277520938386, 0.019410930896898913, 0.03661860058444642, 0.0332307146351424, 0.03363349685265172, 0.07013973149080431, 0.05921580798683628, 0.039105559473917376, 0.03293881981423305, 0.024918262290978627, 0.04363795396901908, 0.05601932910541373, 0.06254218856713946, 0.03656910364365867, 0.03698422370718853, 0.04520529708374412, 0.03121943314439587, 0.033765520615082596, 0.025486314571612788, 0.05603985643134483, 0.04684081819329051, 0.015340143638182313, 0.04104583802062177, 0.07210354425854261, 0.04426831026531516, 0.07451888924885182, 0.02337279481693141, 0.09440093166044644, 0.03982212747477236, 0.028315553884773005, 0.018011060348081014, 0.10854633915568553, 0.024010202952570493, 0.08753100755594431, 0.05246506418071447, 0.039252629203181115, 0.002496604175840114, 0.060247184498415846, 0.03589360178598473, 0.04036762804213551, 0.02785393228423932, 0.042802630848581755, 0.05457909146864569, 0.06476875800158709, 0.020430697345986, 0.033556822942750114, 0.04044714796867582, 0.02369968070378227, 0.021937538666890997, 0.02853808902023781, 0.0729292874494868, 0.12191818170850316, 0.02698780285314687, 0.06443140352325094, 0.07675503861279258, 0.04723134300401134, 0.03581489008220454, 0.046467369482401884, 0.08940038466525656, 0.012580788780694768, 0.0420822745429412, 0.024089966112026767, 0.09937005372898233, 0.023268675807142453, 0.052451791707426317, 0.04344286201822181, 0.02539681060419929, 0.03199066534908789, 0.03896098336084716, 0.01844536899889429, 0.02594798405264174, 0.03855487632174646, 0.05930951969217389, 0.035482599445047884, 0.016631573483708407, 0.1104960099403416, 0.04277297558503286, 0.0180198454613527, 0.04170838916193574, 0.03328192378244093, 0.010875369808937033, 0.018867178925222928, 0.056880948193851984, 0.037428822834044695, 0.05603238324364347, 0.039871724006990274, 0.007101679108135643, 0.044834112162671746, 0.08292007755728499, 0.06038109666758007, 0.018270459634462194, 0.029817218366529674, 0.0296460532568275, 0.07305324047563538, 0.06880426403856085, 0.029946288860012448, 0.055577009090132294, 0.08519483009173025, 0.029366308590397242, 0.029689005891522093, 0.032792068011457884, 0.021969737342348503, 0.014536211928052288, 0.031339507850427786, 0.03648767615818689, 0.1395057448216023, 0.029111436883648558, 0.0316212500911206, 0.00994422632615052, 0.057119722478091724, 0.03822063216038289, 0.00567369504771646, 0.05773382238863457, 0.034888881303730516, 0.010214228269403741, 0.03568267479779259, 0.04241351947008122, 0.030324383894161835, 0.019899447929234277, 0.00995643585244374, 0.04103935308634274, 0.033075436273769986, 0.03600630098052564, 0.04427400229859256, 0.027797094305917144, 0.0433869490910682, 0.03401416594222669, 0.0691705919621933, 0.02670384278791326, 0.023114272701223532, 0.0806949828420916, 0.009599214799011187, 0.012979448487561558, 0.02521451998261675, 0.03229135677458779, 0.030024335982518333, 0.05278768678826671, 0.0450047544173656, 0.05548802031684787, 0.02485558672267343, 0.049904242924024025, 0.04476387722177371, 0.01933717769720862, 0.1335529658582903, 0.03728150412620556, 0.029190389905124906, 0.07033529841611463, 0.06828808165605992, 0.04622733115308708, 0.024049049355990948, 0.03802081727753243, 0.044190406784295075, 0.10043560542286405, 0.02454802731893236, 0.08905720025781663, 0.048024351257951035, 0.03608340773010447, 0.022244015971439022, 0.11015560643206682, 0.01191125953600051, 0.03555773734866131, 0.017266099213532383, 0.05343063373959834, 0.044631776850550406, 0.009478752260967609, 0.01975217710189041, 0.06129783961260992, 0.03142470640370683, 0.03746426589186153, 0.06799886814288555, 0.035358255714057915, 0.07684575108390662, 0.03776852537186877, 0.03162709342676305, 0.033081595620681206, 0.033429280794676275, 0.04458817112590036, 0.07990823352649327, 0.029417692022698543, 0.02351989902015175, 0.10268481658591379, 0.054349950740053776, 0.033313237626345894, 0.11706801777284954, 0.02277333484662156, 0.09940764566342677, 0.036577729793686065, 0.05745679733433551, 0.0536855724790404, 0.06655011926927874, 0.07534621058092003, 0.027315686569519104, 0.04735027432381626, 0.035141981432154294, 0.03592346389327319, 0.03686886618755037, 0.0435243469602879, 0.020755336679998907, 0.046030178425773505, 0.07396931309373149, 0.008818428520293487, 0.07734856523212887, 0.03828694090066898, 0.036489441990852356, 0.025039392283126235, 0.051952287059036956, 0.018086194421254823, 0.08505352517409671, 0.009742063383812146, 0.09752634056513348, 0.002096098436478285, 0.0383073992786869, 0.033683112537067746, 0.1201746192189955, 0.048124291258113044, 0.03530437675034327, 0.014068731670117667, 0.03701611594747632, 0.012940245853256316, 0.053458783640376026, 0.03208713688617272, 0.044389026569983656, 0.02193189451410886, 0.021221669721266916, 0.02742624837875126, 0.03084784794238306, 0.059774435470781984, 0.06260954301744219, 0.021324252724767696, 0.03652010082958206, 0.06800361022713684, 0.0107236843999295, 0.07156025002440138, 0.03508824802514526, 0.03548522712662816, 0.033473897755386374, 0.014170786072950692, 0.03618753057033305, 0.07862112920490966, 0.02783615138351677, 0.042568219435070796, 0.048438145989371885, 0.018940964683650002, 0.05663480797422029, 0.03940767390773662, 0.03254580904819793, 0.04812889544653797, 0.008407439585895309, 0.05255781827614673, 0.07067696596946448, 0.04578823636796686, 0.03830329304741275, 0.05627893332031466, 0.04068916280483527, 0.03635910745229452, 0.04635615266799446, 0.0011312889804567902, 0.010476156603544952, 0.0199885631070262, 0.02042735720263614, 0.00929998564383676, 0.05662531231439883, 0.0456510070380905, 0.011189668871191962, 0.05668530849018886, 0.08752131654370217, 0.10860984018372913, 0.030425346621702758, 0.04076094141290073, 0.019545965384872212, 0.017771267166901982, 0.017893232194887056, 0.008239063036237514, 0.21002925571895417, 0.16101729455253772, 0.14012198594789352, 0.1503532433942441, 0.23128664812013028, 0.14912886635190056, 0.1201131253413135, 0.11534319379396978, 0.1932096421237915, 0.12002251246162962, 0.09309620731660435, 0.14031739965561899, 0.1601803281735028, 0.12092048242207497, 0.10742687019369296, 0.08863720021420911, 0.1410827061702167, 0.13148397687942753, 0.19607576090962658, 0.23454578533287973, 0.12433237756692594, 0.13673480479947983, 0.18402775659436182, 0.10183646614032407, 0.13379376261465012, 0.0997901150596238, 0.24424386090568959, 0.13396643883278295, 0.18762067831572027, 0.20679395916240834, 0.17893423716868126, 0.08065592001883254, 0.09712648863393454, 0.19554008158945269, 0.13021407889262324, 0.07942788873709018, 0.1226337920994528, 0.22291258698509586, 0.1176715954657524, 0.12945459464625006, 0.20844304002821448, 0.1260051765148678, 0.10284066185235016, 0.16279748370570524, 0.280224880984714, 0.1589093883071215, 0.23208616812142635, 0.18299263391283252, 0.1520871301932681, 0.24292082706045723, 0.239078528397987, 0.1737164582816824, 0.16267670228356318, 0.11561812742823556, 0.1329230577234299, 0.1638405277363716, 0.13256920171120476, 0.1775961726783745, 0.11337790247653762, 0.17962731691377778, 0.12442347308200215, 0.2611002926864932, 0.1996143057101196, 0.3452386875306407, 0.10065927245323697, 0.13487665853913755, 0.19096808417910532, 0.10527208702819002, 0.12470077392795395, 0.19548739006202068, 0.14625212958743497, 0.09927813083894792, 0.18441273109807124, 0.14510074540251686, 0.1800013516819285, 0.1921660158663027, 0.2008972884786706, 0.24199824269500472, 0.16470200892898346, 0.11515539500021166, 0.3023917882913544, 0.06910678449897997, 0.1657740264049461, 0.17135206579921708, 0.11438988930275364, 0.10757422720592831, 0.2193039298177727, 0.10741711023353762, 0.22573453314121694, 0.15951377039234485, 0.07096491543756378, 0.20689116039824104, 0.15665669144401628, 0.16333184535464934, 0.12123445589696208, 0.16141086456275758, 0.07959032235967536, 0.10264860360973305, 0.17470374643321962, 0.2451675024724776, 0.06403103831314272, 0.14747092950968974, 0.11166674550622703, 0.15772582842938362, 0.10999591540425055, 0.11266172518052402, 0.15774259043316688, 0.12517088378268865, 0.23229644393488286, 0.15632517455566317, 0.25539644633329683, 0.062346476085123524, 0.2133017228615861, 0.1816041761588666, 0.126502750621688, 0.07815880280348562, 0.37267652490446646, 0.15894331068040865, 0.08679753199460045, 0.10800910467702536, 0.11897355423218782, 0.12450614929079049, 0.19170277782024878, 0.1495210574038567, 0.11741052036203685, 0.12545380005312542, 0.09421300263174119, 0.09740239519986416, 0.11270953672787837, 0.24396057691304918, 0.20339502622523617, 0.16673676909938936, 0.15348588416893638, 0.2650987200679318, 0.13828993264225223, 0.1251778398610411, 0.12632602179843572, 0.07700864435924638, 0.13611108665504765, 0.08710565255774606, 0.10837993719765257, 0.2208731230348349, 0.1079670541108616, 0.1616957420182805, 0.1210036719097726, 0.0850157417176712, 0.16473007839052908, 0.09678162649394044, 0.09653742830719679, 0.10080183375506632, 0.07690601156003053, 0.1394635793422499, 0.13293885445642856, 0.12298200970455525, 0.16693146268446601, 0.1966035188806634, 0.14450644503437704, 0.12611484966210781, 0.11155617603611563, 0.1084650265834024, 0.15374589441043718, 0.12712925732616456, 0.11546011413297347, 0.14488529083469223, 0.2565476006918377, 0.21944567140552307, 0.11206269038901215, 0.12948966615142363, 0.15940820347637902, 0.17688948721174272, 0.14290381974029925, 0.08437739129388526, 0.09461671564607851, 0.14786076101083911, 0.10542400226357485, 0.12702287835699896], [0.019215563154448907, 0.021058288064875433, 0.03041052090514812, 0.03038539322123172, 0.04467227991910712, 0.0707910671049068, 0.05070002441624961, 0.029475709776424115, 0.07189165966044511, 0.04046487524324367, 0.022755511811063178, 0.05487044236712879, 0.007010949400043296, 0.03188314873935475, 0.0539950336960535, 0.04346702443135362, 0.028478837864954146, 0.037687538386953455, 0.010467424158818059, 0.05339057883247734, 0.022805659926586577, 0.03635196751284023, 0.009869043414871539, 0.05823405865099161, 0.028247814475288315, 0.014891336773402028, 0.03125243238173425, 0.05311491358424387, 0.10718507752303155, 0.07377939223642312, 0.04184543080027065, 0.014011139095190072, 0.02919584062070616, 0.029351463721644495, 0.040619429651527636, 0.06075092561302647, 0.050279951594289274, 0.07636720660112559, 0.011520105575571859, 0.021637021526393872, 0.03961865835252308, 0.0462532670597636, 0.011927489108676392, 0.03394792614985378, 0.016035016986631578, 0.01860780262147948, 0.04633401272698276, 0.04489469056528422, 0.04445286467671395, 0.03537733896425174, 0.045750993003527966, 0.014225777779375354, 0.04706398343607303, 0.03174715472625629, 0.08883494282922438, 0.05073496568647604, 0.023651955341319406, 0.036593660592071475, 0.07580265342708557, 0.09961405273286567, 0.05821442764793193, 0.049252439996287714, 0.047974701099578416, 0.04105013194343737, 0.03922600381737275, 0.06458619924923105, 0.03085724401077436, 0.027869317244978684, 0.031242952043671283, 0.02453148748064714, 0.03803098326428764, 0.05000095386358519, 0.04096282090270712, 0.07780641001919586, 0.024835258579602646, 0.0642999045310482, 0.031755072244953726, 0.04876724587032392, 0.03900050966730041, 0.01652956313093103, 0.023225319061067798, 0.011484673051463981, 0.013966555650826665, 0.07202986192198531, 0.031205944251269106, 0.049022226744601806, 0.045051604524374976, 0.015210663287660048, 0.013876141954003083, 0.06557993786109072, 0.06554499659086428, 0.006788489436956063, 0.09715097280399454, 0.044278817161196665, 0.015209549587340125, 0.016109181958581173, 0.07391085292422965, 0.08063093789162175, 0.048907723412999225, 0.011304305310571387, 0.025900425314302408, 0.03834838881307552, 0.06134495018951355, 0.024543367589132923, 0.056729071262863376, 0.01076260741214238, 0.039649455087079157, 0.01236878160852939, 0.041076818616279674, 0.03859605737811616, 0.0035840418047061373, 0.054533604998141534, 0.07175296710263337, 0.0383575129202537, 0.0178273965138942, 0.05559593146186202, 0.03886234954059605, 0.08241082060961955, 0.0328944441712191, 0.05191779395024623, 0.007086983626528133, 0.022935755062668074, 0.024072978112305847, 0.09166348500237351, 0.01141436150177352, 0.04091172283815761, 0.025793153852705034, 0.08201028686016798, 0.03824879355247944, 0.016803786218647036, 0.044523865705536264, 0.05647977859142327, 0.04800775013263187, 0.08581022086042552, 0.01669014473595927, 0.010600397870275042, 0.01144716921713083, 0.08374782023771156, 0.07509930810380368, 0.03306365767193418, 0.026794432684959426, 0.05134986998933939, 0.019312364109341177, 0.04768957083504047, 0.06531048175548354, 0.010935225216070972, 0.10309249027481965, 0.048767483357580445, 0.045063578478631475, 0.01346396366810246, 0.08426722018949448, 0.031956132020681136, 0.05068058110473137, 0.02152395460964932, 0.016344740588758743, 0.06292908978197845, 0.09474592403538766, 0.06422417673973307, 0.07397439225666946, 0.062291834863924214, 0.021846117564446984, 0.030841742221626545, 0.010774670424120081, 0.04363803823869075, 0.05006993242028741, 0.04372369452950455, 0.029402912271419362, 0.07564722950900755, 0.04629783039431899, 0.05106500019469569, 0.031818105959363525, 0.06792425117906063, 0.021335826398083763, 0.03134425184989889, 0.012222386036639013, 0.027303262538607084, 0.04612263374691529, 0.013670681960760586, 0.04921124744859915, 0.025628768621132742, 0.015267964749176417, 0.03635667129269531, 0.015991826864680456, 0.04675166471110237, 0.009381977161542784, 0.017706546143838958, 0.031022826254728342, 0.05740015279321421, 0.006195358789315628, 0.03028884316013465, 0.08139378526398251, 0.11612202942131028, 0.026049829696515397, 0.05052618374447188, 0.025255124557823427, 0.037227602179853186, 0.018280979936882373, 0.0007625403386848649, 0.0597724513030581, 0.031047390864020398, 0.02024004104427032, 0.021561178821890105, 0.03897264704949433, 0.037260375421253905, 0.029734373618397984, 0.13820672017191687, 0.0253262079410976, 0.01695673184229001, 0.04774429632591144, 0.006474798456991032, 0.028962781352381554, 0.04807418527742548, 0.02990445279846749, 0.0908402469189417, 0.05153152475794477, 0.008801354335681086, 0.03420405232557847, 0.037822189830964616, 0.004099018556336242, 0.0378996106765924, 0.06063919551970978, 0.04685027554871575, 0.05407915398057911, 0.03875482526998367, 0.02006921301325483, 0.051939382307952454, 0.07142331946881549, 0.005175407042711853, 0.03636276552213296, 0.006151857444145267, 0.019988524802629987, 0.08831918179508179, 0.017463702017501477, 0.010635913706444686, 0.08027134388084374, 0.07688459174166765, 0.02759215429485325, 0.0656065670773387, 0.0884833391154966, 0.05313140362681401, 0.04759259559514542, 0.04932202376245011, 0.0829567501862203, 0.03595748968843011, 0.08384276917504688, 0.014754396641717083, 0.016219134727913528, 0.05968879067128705, 0.006177254216445069, 0.03955670865252614, 0.02339374923688029, 0.034784678024269884, 0.06855319404313642, 0.059019233655905536, 0.017210963865621917, 0.044249587076445746, 0.038182864025715864, 0.041067614069869446, 0.06485687343463784, 0.0681655535534505, 0.05518118678141506, 0.05899302195757628, 0.047454944916910706, 0.046504739251348286, 0.020005740713508382, 0.03366911611069114, 0.07161224441182229, 0.033059873197588234, 0.08843227935534331, 0.04658353139436053, 0.07684255649726238, 0.05305793579487551, 0.030945667794214624, 0.054168897350468946, 0.07736331242467127, 0.01371462763692703, 0.04416218027472497, 0.022702877740225485, 0.008920998117255588, 0.04636422340427676, 0.016516168083574985, 0.03508569312191779, 0.03985860475128697, 0.05382856662054697, 0.06725127358109721, 0.05799318145539972, 0.054434894569097995, 0.01882692483524161, 0.06730353609929163, 0.005867395112516299, 0.0046982309844855585, 0.08501097665078218, 0.017184999230648243, 0.02670605678201443, 0.01885166564475625, 0.06346385745752244, 0.02725378475001743, 0.04479662365009708, 0.017950920530805187, 0.09030919476983049, 0.049076848813603004, 0.02823433132782098, 0.044738531202798894, 0.048059759841811274, 0.013800362451753069, 0.03754471278479023, 0.03554199807225697, 0.02098882495756111, 0.026240528133066914, 0.05687293491416401, 0.04983623346854603, 0.047031011011812, 0.05580124302556919, 0.016634545904854615, 0.0454217437354307, 0.08578516978530154, 0.012450060664465832, 0.052043451522026336, 0.018804219904385747, 0.037317207653916655, 0.03740410117672817, 0.03296354147154958, 0.064287593498105, 0.024163167728411577, 0.01623932689037775, 0.04279673580200442, 0.03479136214140923, 0.025919096792236935, 0.057325577964225126, 0.023669316808903412, 0.046790865430187796, 0.06898641676431702, 0.039604849617687926, 0.06483752205367051, 0.005153480169904088, 0.057767503444225564, 0.09101719024681276, 0.013613949319527996, 0.04858792383944796, 0.06949162110686302, 0.023566021343633056, 0.04466835371849518, 0.023707420107037313, 0.050057533287232926, 0.022386820506184332, 0.04305213802464066, 0.03218313919440393, 0.014929593289120784, 0.06839549484392328, 0.027067052733693874, 0.018186122930097966, 0.03546530117971763, 0.06588525454243345, 0.08737169957209019, 0.17075735174359816, 0.09494097002090947, 0.13007765395506737, 0.17688273031625057, 0.12134275774681762, 0.09465721105375598, 0.19854195115547027, 0.06599313504393063, 0.16965548748210554, 0.18988552533330458, 0.08450902052103512, 0.13294899746054603, 0.18968700130860652, 0.16178938860614456, 0.15606729403859185, 0.1814508513217011, 0.11733506070149523, 0.16638004791832742, 0.0673616821727445, 0.1390591002399883, 0.11289167413187605, 0.16580339821596302, 0.1244463025021457, 0.2954227783747258, 0.1677413861597738, 0.17417748999451438, 0.1614787399528488, 0.13522723569504677, 0.15453537865992517, 0.07039912120108643, 0.17873130047753935, 0.14941899917058407, 0.14028347728233184, 0.1540706084380227, 0.12777128497198706, 0.149272691698805, 0.10063995171578662, 0.07762555964291096, 0.07791095037734316, 0.11658665408650715, 0.11631111524278119, 0.13414761862687527, 0.1307134609669447, 0.07437603683361123, 0.1594845517989128, 0.23741527490558165, 0.136939043840093, 0.1530387799345678, 0.14948050070914531, 0.10797125227268665, 0.17342416509505243, 0.13427413038669095, 0.16626790796797122, 0.14481758398394431, 0.11497246852565197, 0.13415532547139353, 0.134222986356866, 0.17938878777767384, 0.15461226324400595, 0.15317617014290827, 0.10763831812167361, 0.12746596062976506, 0.08084599409372577, 0.09451085761670144, 0.2309532619772419, 0.1514139227689274, 0.16162700860971407, 0.1994665120277674, 0.12180106984751841, 0.12225222668700642, 0.1552705319538232, 0.14669869756025655, 0.07409990810218357, 0.15700023591278062, 0.17510531440136895, 0.13432850730755638, 0.12106671328506163, 0.1196892105884129, 0.1048084889208117, 0.16871137604598077, 0.14294544895810468, 0.30567931672257764, 0.0700583346488495, 0.1545117065430649, 0.14170515260869457, 0.12843131568403016, 0.10922174525236893, 0.19872555178740334, 0.19372828364852937, 0.14650875372031044, 0.18491788947534177, 0.08988372485844359, 0.303736885468806, 0.13256891059779352, 0.22841810849645447, 0.1439435695928912, 0.1860076189041138, 0.10308308271510948, 0.21823923614236618, 0.14758067926572216, 0.14254654697593183, 0.12388415484418794, 0.09591457584211904, 0.1197938735206281, 0.10963325704177541, 0.09690659075614907, 0.21002125776102468, 0.08170069540820776, 0.13181633646449736, 0.12440549299841928, 0.1678394607358402, 0.1699518562564927, 0.05558402262507908, 0.1277843391102168, 0.09946765333053567, 0.1860798763171319, 0.1940939987018224, 0.1220088711969795, 0.07767042175175683, 0.14378881983218655, 0.09030813756849497, 0.155372942587541, 0.12133936397731306, 0.08159217905373344, 0.10017704308754015, 0.17449950739260645, 0.18767272632929588, 0.12094554115807819, 0.12889433922546525, 0.16562002741040724, 0.1562697557552207, 0.16709695299786909, 0.15892633417200658, 0.15962923516429242, 0.14536192009766258, 0.14409789034435827, 0.1187917156024806, 0.14618776288003693, 0.11307237895145533, 0.15962856100691905, 0.10361193619187802, 0.15790319310561304, 0.11419577028362021, 0.19590686916583971, 0.1606124936933479, 0.1113035891866011, 0.10738334873871458, 0.07125269636631974, 0.1796668010853952, 0.15017604725735803, 0.11316815526374888, 0.08533785870719342, 0.12850397912364814, 0.1182593227995019, 0.13546590272697712, 0.17117163677129055, 0.13935504000513785, 0.2390835386130118, 0.15828156393141518, 0.11169777206716039, 0.14965614934842433, 0.2435794788142366, 0.13693464649540765, 0.2953167211624884, 0.1389378131998162, 0.1731750486238349, 0.09711285226888235, 0.13093789408524192, 0.11654971332679834, 0.14953815648632665, 0.11614662084367969, 0.12319117469052154, 0.08140033531573512, 0.08506092558344526], [0.0874550499382519, 0.07602845784276724, 0.026815459883261113, 0.035076718401884845, 0.03519376514539604, 0.05909943923113808, 0.05996629836097841, 0.027573923317475185, 0.032313297532739184, 0.047070567961782224, 0.0742841292653353, 0.03544047610053132, 0.0798332105360685, 0.04502827331664101, 0.05150009217041154, 0.02696581996015964, 0.037924814969301224, 0.0036341446731615094, 0.030593537395038915, 0.026379124929888115, 0.027273086335269675, 0.012759053610235214, 0.0636718196854476, 0.011901101210124552, 0.0384078755403959, 0.02321065422297726, 0.04278603738414184, 0.03536191378389636, 0.05765986809086415, 0.006185321122287743, 0.05434607050471729, 0.03402225200026747, 0.03141265009499846, 0.019518324932564172, 0.029596682720547243, 0.010164026527725642, 0.08064695679011845, 0.007964928048632799, 0.0609143857934302, 0.03469944691225406, 0.08015943375686485, 0.02184041403985072, 0.01886306120262992, 0.046360247407949744, 0.07801033496376007, 0.043972627139620246, 0.04599174762505197, 0.03247080137953162, 0.024684720387261723, 0.023715981139591145, 0.13058298087168124, 0.07042854663825805, 0.00393818270587813, 0.057219980404742306, 0.04166674845281147, 0.04346995088722437, 0.01709794291415282, 0.05686070432045287, 0.10410497505818644, 0.10279117257244165, 0.030984104340595585, 0.00947405997243139, 0.034901533245800004, 0.03466781897230014, 0.03278175646799707, 0.03591265439266159, 0.024388885959201766, 0.019616219477968353, 0.027084860447493773, 0.032239561570027185, 0.01927612048964347, 0.042254851169643864, 0.07337993867094479, 0.1136207293658968, 0.033583199349983085, 0.06558454204951564, 0.060156142609494354, 0.05977618598168897, 0.06397001940997378, 0.06002543268785362, 0.034002846993145444, 0.02560495094756686, 0.01785277317638599, 0.02422932325111282, 0.04468769360814364, 0.06950712672645046, 0.06563632193231775, 0.02889379896523972, 0.028582020332255674, 0.12095015300738236, 0.028381383820106427, 0.036328299226419586, 0.09167320665813262, 0.07479231368990676, 0.026668384408337936, 0.032805562650244084, 0.012994470514146792, 0.06460794848540137, 0.0642624275097924, 0.021149603830229853, 0.06118417131684481, 0.03400417998613369, 0.030644120265459342, 0.036486894748504126, 0.012500868573214018, 0.03768566913241821, 0.06843322467419409, 0.021742327972465468, 0.040984654408549114, 0.016382627467054035, 0.0617623417037389, 0.026336402121570804, 0.05135435926457567, 0.043621958053160104, 0.0023197853372567486, 0.04198090578880041, 0.020551834999012853, 0.016233249897918394, 0.03705757279549876, 0.07180848549450598, 0.10197385634866454, 0.0523988665231774, 0.018885306480731216, 0.056640940508054155, 0.04411367541779915, 0.12390696128169376, 0.05515492145693111, 0.04891663301555861, 0.07676963258775012, 0.023027478769842177, 0.07759866229588948, 0.0857354966442912, 0.04351300502856893, 0.028073636724823908, 0.11988440213064033, 0.020579785716930227, 0.0669675452574607, 0.05367236129278618, 0.027204140337304245, 0.035460248829856995, 0.06563022387244048, 0.016291001436090278, 0.016364103461044933, 0.05304207011396366, 0.039803879260415995, 0.13858355882187046, 0.02917431546525369, 0.06759447331029562, 0.06871851581719614, 0.030455329387839285, 0.0270357733637455, 0.034276531904094645, 0.04389054464897321, 0.035564555531187404, 0.04976992472825993, 0.05368543458321402, 0.01054896081181904, 0.06690215199224411, 0.020693519130168904, 0.026452696183696393, 0.029778563485090292, 0.07792870829542799, 0.049764596586746555, 0.05210674953677001, 0.13591879858605324, 0.01295241132949389, 0.03148614857045393, 0.06056639035382579, 0.06752566329293674, 0.01690428929343339, 0.053280239188743216, 0.05027026441248675, 0.011889630958678262, 0.03890165751199088, 0.09022690160500427, 0.11209221541761391, 0.037402902249126666, 0.09283453466430788, 0.033348121439978, 0.02128495815991154, 0.03469503807624982, 0.0533528260195688, 0.04996363005991425, 0.05350765238906588, 0.07538633826639383, 0.09001916154257714, 0.10173046255424138, 0.04851580815269582, 0.0256413075652334, 0.09878685397486534, 0.02975724708859719, 0.05363477701922098, 0.013858862840870937, 0.09231259130061635, 0.03791148503941875, 0.052321752112719326, 0.016244268157489358, 0.03718668542381737, 0.011325636071213072, 0.05191099491991824, 0.04618739115915472, 0.056613656286630905, 0.04937726636266997, 0.0347332084070771, 0.12282020427406797, 0.026659530347153067, 0.05016850112306495, 0.0652145981908806, 0.057985612506707834, 0.005708233642977693, 0.018632895831439285, 0.007749994420596669, 0.019665333374793974, 0.01975658593789464, 0.03348175398704987, 0.03572234283051184, 0.002030360671098254, 0.018238155621915095, 0.024817885620699778, 0.027107691782857143, 0.02291503238431629, 0.08420842294130595, 0.019333766690725764, 0.037313982423755436, 0.06510585201002898, 0.06467557106647762, 0.04892179261772864, 0.04871713988963635, 0.018658806840258262, 0.012404348198024016, 0.033106593069650476, 0.027661875956842018, 0.013409560891769588, 0.008627110510133207, 0.0441593763929221, 0.06856557402399278, 0.029945687480991887, 0.011677822011763291, 0.03218647167687455, 0.052856581075297254, 0.006547795144856097, 0.025933112370811646, 0.03726457358307896, 0.06535800218942665, 0.016041767178854395, 0.019667597164610223, 0.023951101184432066, 0.049934763866927356, 0.07730916533018313, 0.021958680778381326, 0.014023566956541712, 0.00921683829097498, 0.03897889449651684, 0.12104458866580842, 0.03234682920118494, 0.025192132978249463, 0.15402881068087396, 0.05108775300604682, 0.02002733864731366, 0.07379318181906017, 0.016868083978131894, 0.031624504049578984, 0.05527568755731468, 0.01794538937599188, 0.09400610526603076, 0.07382335802239758, 0.01105045633120162, 0.05081538576632739, 0.03823692302009271, 0.03416846754149564, 0.02999267356860782, 0.005434147493478152, 0.07717905295712334, 0.02500996684595462, 0.04691572244008703, 0.056360081183694066, 0.059445584568405346, 0.05951318033640424, 0.0606944113068523, 0.034411543409430215, 0.02085220083714493, 0.027969146162391673, 0.0369505732951145, 0.04539289669464192, 0.05469194005033182, 0.021043027593423764, 0.013429302977578295, 0.009092433272951074, 0.056526598054915674, 0.040301591263062535, 0.020307866638646494, 0.013721489869508774, 0.01970287934396296, 0.0038395096236208998, 0.02448758681214625, 0.09609213204032953, 0.02619889316960208, 0.024144578604928912, 0.08064271266301794, 0.0751510726648473, 0.05348850019095887, 0.025794220630139596, 0.020412384014156078, 0.02240666792908263, 0.04715258533495569, 0.005779443430759374, 0.046629148099811814, 0.08427825185560411, 0.05921596503486076, 0.020448618057754733, 0.04080289238763433, 0.060827415661826256, 0.0268518069248286, 0.042313981666079456, 0.09446939693823939, 0.011720256579499091, 0.04709486060986116, 0.07135646297566353, 0.04499691350746059, 0.035480312672593904, 0.031330937241774895, 0.038126499106686924, 0.009371110204336865, 0.013624319277193039, 0.013194236558892075, 0.024257053718751958, 0.023354127169436505, 0.041928409613789096, 0.04346429332790356, 0.04986984174578421, 0.026242475911614396, 0.02035377637272881, 0.0885595418813248, 0.03303889004934219, 0.01237125511491491, 0.028521116342275377, 0.05973202484329382, 0.04120960463619521, 0.028799189021810893, 0.04641848924239317, 0.011730826677634351, 0.027677789518249132, 0.03370696468459022, 0.02372656655948489, 0.08558620909048666, 0.08755670214492468, 0.14280326303935822, 0.009340774080145263, 0.019578694576217283, 0.03612203771368631, 0.028962120601546862, 0.07893752351763748, 0.1888767867198875, 0.1661805279793278, 0.17385173408735186, 0.16497148801722836, 0.13530530005453095, 0.14185211891608854, 0.19509467807027603, 0.10068443078067034, 0.1288459684339262, 0.17929889502063875, 0.2569357467995536, 0.15641663013206375, 0.18779211347141575, 0.20880942923888085, 0.16056559379062346, 0.07552060283600323, 0.095701411877188, 0.1811053456678506, 0.2509432231947299, 0.11291171499197522, 0.16561979758402995, 0.11759880179118727, 0.12716854231492167, 0.1258840963184353, 0.12686026087331195, 0.08098938277051335, 0.09234039263138849, 0.10039812840160825, 0.22569141771283843, 0.15743318284230848, 0.1730663407473795, 0.15387945417915622, 0.15446578723288354, 0.0986439555943493, 0.09638448651399344, 0.11684035942439111, 0.18544508054131464, 0.06614143434431284, 0.17337907315982928, 0.21724771918548694, 0.1489674363044962, 0.08756307599645469, 0.1292527917652361, 0.1609205376477011, 0.178887122761338, 0.21754995619337406, 0.1123675091132041, 0.16431496598787848, 0.1771947732495685, 0.0985861312778246, 0.190718753203269, 0.14403651137986492, 0.07340910363822215, 0.08113179851563708, 0.09577048236444112, 0.13541796094467565, 0.07320160872393078, 0.13991390114590047, 0.2300846868104512, 0.23782241999381976, 0.12344268901694207, 0.19854650171774052, 0.11406094646982609, 0.16597350037867026, 0.12351192038265929, 0.1551640304105897, 0.09433686372733886, 0.2101504661503338, 0.10392302917616983, 0.12186739007912337, 0.1297760911045536, 0.10550525354882402, 0.21333766770699333, 0.28201020292697415, 0.14451186893688095, 0.17378971160900208, 0.14240118945317884, 0.15492007737198185, 0.13335093315089905, 0.14864321257318222, 0.20156735494252176, 0.23737392147942898, 0.1700710901810277, 0.13983505537673352, 0.13350358383069116, 0.23959211374242462, 0.19080064800237456, 0.09087387817881762, 0.12832028656116418, 0.18957297678195661, 0.11522091083949614, 0.12731190800907152, 0.1704071269881341, 0.16500334195311994, 0.17813421154935516, 0.10414416811639264, 0.15518911212923067, 0.12243011996390359, 0.20308540412975898, 0.09669678225632637, 0.23646278246756525, 0.13206211279236502, 0.15418688526316998, 0.11911036987458506, 0.11681035176039704, 0.14772393770756262, 0.2017419310587068, 0.1375335893563686, 0.09458935864630247, 0.0641734425669476, 0.1622771874310509, 0.10095561824498639, 0.20798318809078586, 0.09921762521468824, 0.2335988546931936, 0.11360194488999345, 0.15529614993401114, 0.08003841484746627, 0.18270130599698714, 0.18315996283725386, 0.1501111596101715, 0.13835754756244922, 0.273683256199283, 0.15409066461988036, 0.13161988087719487, 0.2029300414987149, 0.14887069472141806, 0.1850052694639852, 0.23909901358908225, 0.12047845735064439, 0.15889733008319334, 0.17986743951276427, 0.1367072562777227, 0.1467255719246403, 0.23464690893888476, 0.13492945731887895, 0.26050749385068495, 0.13944376830852803, 0.16637980277019163, 0.13720145959767605, 0.16630731553079622, 0.15816300416425352, 0.19660963226229916, 0.2115810587401352, 0.12524586846871724, 0.20123514857503677, 0.18741711343248046, 0.12498805689955912, 0.1329691455729546, 0.11152455192660132, 0.13405551953661826, 0.1030052328602441, 0.11785236157236562, 0.09199959841827232, 0.19209973393909394, 0.11647816837554979, 0.19849027086409832, 0.09372330390878263, 0.11268987125086208, 0.13301743975570127, 0.2094475804798065, 0.14388324782973336, 0.14866990307646413, 0.12953042202899534, 0.2079121564184466, 0.12965083572893374, 0.11823820175542948, 0.10397176002903331, 0.18445580056117428, 0.1920935899139412, 0.19569982624342366, 0.19025225162265763, 0.08910845153995099, 0.12171896054379402, 0.1771890122683779, 0.21808883776107144], [0.032705431128101, 0.05412540653900755, 0.026486298715275143, 0.012444033467721556, 0.019252105548437086, 0.03200375779171384, 0.126909198569915, 0.05034051850558289, 0.023287431554748647, 0.08561443176961715, 0.025472410075787096, 0.08484700319146918, 0.034091996644893964, 0.04052526212387508, 0.05032925701309597, 0.023919544107611143, 0.07134081179937048, 0.006186860959015546, 0.04314976826971097, 0.07616961720369517, 0.051320092151722604, 0.031031741602947156, 0.030605042120441798, 0.024211475317696893, 0.02470167582824586, 0.014852767119244223, 0.007238644137678127, 0.02227001316514948, 0.0022704114493418246, 0.03417410594861835, 0.05301733696532827, 0.01005116453950083, 0.03206820493834394, 0.06403648519828435, 0.033512673295673825, 0.060239757275989944, 0.03911975891359391, 0.034899893817642046, 0.041149459073259946, 0.09466614363895309, 0.02147712557005786, 0.0444732770894564, 0.01423266203698492, 0.04606915314892127, 0.021391890627602418, 0.04590072105788896, 0.030563276922029835, 0.07657118517184451, 0.0637498878753714, 0.03468642724798091, 0.015749930772149277, 0.04736951845247419, 0.03122319846654371, 0.03059707289080947, 0.049707392801440535, 0.10302658373069379, 0.016069799293613723, 0.05994622302692264, 0.010170808321075335, 0.03481104677062362, 0.042371924726232406, 0.09280938399775375, 0.034502600620110194, 0.03785636884370639, 0.023777193479960965, 0.11439772638221903, 0.021650271017044302, 0.04033125418749067, 0.011095571249062497, 0.024831527731411403, 0.06587691184493803, 0.04667438559174057, 0.018415995272657564, 0.07575939244200146, 0.10373162210828836, 0.04021211985438582, 0.08368217416347996, 0.0609922931048899, 0.07434576869972291, 0.041221375577151775, 0.01961148313937649, 0.06264245032422966, 0.05965613234307497, 0.022322260361585407, 0.045950873003851984, 0.04319305606787244, 0.02157968559092091, 0.04677205031076747, 0.03604392355848705, 0.08597437818084033, 0.07826231660381441, 0.0200079815206869, 0.028005920297976945, 0.035300485023687926, 0.05290782086611275, 0.032143264317945126, 0.03905212867163843, 0.03167496051549191, 0.04828199811820542, 0.04079294856637716, 0.07691107540121002, 0.012735359468347123, 0.018726258966771346, 0.04652785212402383, 0.04199038229642376, 0.03935732277891329, 0.05890067388874389, 0.031497662871955864, 0.07269774503525227, 0.029345993853865132, 0.03856926728340407, 0.046949139195344144, 0.05500549983773982, 0.018428783195333618, 0.02539730473091045, 0.03702929649021357, 0.04848596519760547, 0.056763993380891706, 0.08107755949059803, 0.032731443643569946, 0.07247260711606472, 0.05772390921089438, 0.016695287101151004, 0.003745959036149866, 0.029701947031783003, 0.058249962636299675, 0.011566541037492214, 0.03596234285543042, 0.01616150576380953, 0.055168492704509735, 0.05884003036865785, 0.04046179173934845, 0.03224736034509636, 0.01428540336013201, 0.033640192461109934, 0.02752237134583054, 0.03272592398007551, 0.02137843237799262, 0.04713672348448346, 0.05213443212391389, 0.05816145266796793, 0.021189894309387575, 0.014205430484106465, 0.0068406183685686805, 0.04749397326621318, 0.02101990705986898, 0.02916003175590548, 0.023703827154672435, 0.052120006688299685, 0.025125205621964512, 0.08713933744377668, 0.026940941254818634, 0.028288233274173354, 0.05926088076986133, 0.0668697924383225, 0.054273537300046415, 0.06978232083061049, 0.021726234380396146, 0.02448954991245222, 0.014148524515481006, 0.02370064405934705, 0.012319755811815061, 0.05818776012728772, 0.07666502328168961, 0.01888821378440386, 0.04605535207496536, 0.025062319379480138, 0.07340203264668103, 0.028332053503442197, 0.061053817626088865, 0.04671030745451008, 0.03476986954469354, 0.042283115983610196, 0.0374071310544687, 0.019218640912684704, 0.052820720499561685, 0.06788056884561816, 0.031668368328903476, 0.015337713224242534, 0.012331708698653647, 0.02875332525300403, 0.015915581006406537, 0.0465772801168984, 0.054246655274783416, 0.036817166743980306, 0.04343308290586837, 0.02824894445497663, 0.0826808819246869, 0.07054930507776237, 0.06656148035319583, 0.07297195088598998, 0.027326563102824074, 0.008760241269614668, 0.0036243401841455775, 0.08955594647916094, 0.09811902448775307, 0.011614779678864345, 0.037947927841976765, 0.006735678687090836, 0.009458321653636954, 0.027960485538407683, 0.003045861446861959, 0.04507694671291017, 0.042594856312198025, 0.05979727255180479, 0.07376597803686896, 0.04622407527940889, 0.03827696643589485, 0.020938060141258666, 0.026055696014795574, 0.042136594007212314, 0.021392660545966318, 0.030693969606692274, 0.03230405085149311, 0.015793294221493268, 0.0334558448934507, 0.024289566490258423, 0.04776875368289409, 0.03854184899659407, 0.0500944855382606, 0.048110034361842184, 0.040608378833219896, 0.053240682238773, 0.0249287634412007, 0.03954697933588778, 0.016202935798754616, 0.036667273980715585, 0.02299954911934272, 0.03942678014056818, 0.022146266982740453, 0.06334492996815713, 0.02726643669208692, 0.03735511368441005, 0.04687740272211452, 0.03442001634187276, 0.070727244319935, 0.04652798618941058, 0.013514812754076577, 0.07387703014237267, 0.03862814114038502, 0.026818708096060063, 0.08076294250185452, 0.007188617638612707, 0.010475465209193287, 0.08545529232510636, 0.031938751400899024, 0.09329537485515879, 0.055470626290527084, 0.05152903880263048, 0.007590093676211133, 0.0544839701615274, 0.028146286757903236, 0.07091872799660891, 0.05008602792757654, 0.04355304078349183, 0.03964193210366272, 0.055197021818809935, 0.0206296427190424, 0.0176013718479343, 0.032474126201123, 0.03805230349122036, 0.019411641443448684, 0.05120505255857303, 0.07362137128028177, 0.0135196314471203, 0.04524339463621859, 0.04593054103034158, 0.021667450538746292, 0.0575988645094537, 0.05846868073868175, 0.046033625821432764, 0.061341606215724064, 0.049116911381603255, 0.015703708857237812, 0.05461902380169881, 0.04427795914272147, 0.023364182073442687, 0.05895256868473465, 0.06769024196170992, 0.0480383055494918, 0.026379496482531392, 0.044379496436205604, 0.025508163399213267, 0.03876052113370069, 0.04399936743861726, 0.06088746546377098, 0.07000239490861855, 0.014040077108919862, 0.058717621009676695, 0.009961295722713395, 0.04620987583973235, 0.06343254361361747, 0.013233097326461107, 0.023308895423167178, 0.06288923022727813, 0.011666903343622484, 0.01889255750293453, 0.046586595746057655, 0.04190884372820297, 0.014755953715423183, 0.010872300669190385, 0.008180545410141349, 0.028228122185194687, 0.04954523880094771, 0.025487343044651133, 0.017082718831877557, 0.0941102932237329, 0.026770800787715182, 0.08563116312988343, 0.03888331353664398, 0.016335919086310654, 0.04973766476576848, 0.0054019785039277094, 0.028654250932196458, 0.02355427338531421, 0.068125625050837, 0.03299197482485925, 0.010173627524636686, 0.051750809765390815, 0.04754876770499734, 0.03815730350212224, 0.08735297638322077, 0.047076585582427444, 0.01857506002359573, 0.15678222261128888, 0.0898756732743594, 0.019000024316952597, 0.02041423986215265, 0.05090679920789215, 0.007597394494129526, 0.033901616134831024, 0.049338686174803206, 0.024308856584191806, 0.019674346399223133, 0.026006390595988884, 0.049890552932817134, 0.04227143697320454, 0.07157150385600906, 0.062062824370279435, 0.04923151813507561, 0.058947922361473885, 0.04481766042449782, 0.034482402711986535, 0.015480388481650623, 0.014288182344077336, 0.08146264124661684, 0.06817905968355556, 0.019589370011442134, 0.08634811417470056, 0.05049762015621509, 0.035115976577564594, 0.021706193520296967, 0.15695739627605484, 0.1017083609176259, 0.1253898470332065, 0.13220408420649268, 0.09012826778475316, 0.15627170161854836, 0.19259528557379402, 0.13778572421400778, 0.09070987407598766, 0.21410423060578687, 0.06692179448662267, 0.2556106291951672, 0.20229254909340413, 0.16900572234824782, 0.24729439237665748, 0.1127780173274298, 0.15655875476377626, 0.23422381390006314, 0.14586769134527253, 0.2127638065646733, 0.12647244418340345, 0.2359350704618039, 0.10074374130776814, 0.10548960237253098, 0.10926359663567237, 0.14558721123443497, 0.16292888310647782, 0.12465247208432806, 0.12643017911262092, 0.21404666675915643, 0.14256736924571378, 0.10417352460565106, 0.14704774254031722, 0.0843390102888788, 0.11683161836117507, 0.14943176219540258, 0.13060977862727258, 0.06066418147736019, 0.17047771432947728, 0.27155294954296083, 0.15998917391463635, 0.11448871464498582, 0.07966369826106295, 0.1552461550360726, 0.12254095756478849, 0.14312348779170744, 0.08975686069818274, 0.19068414135085, 0.3181406561165087, 0.12805644588004197, 0.12891330756247044, 0.1097009409098856, 0.1806517909731596, 0.15786727890372276, 0.1563393012169869, 0.1929389985819017, 0.17132618734913488, 0.192468069013088, 0.07702546765006359, 0.12188959130716902, 0.14561684351534615, 0.13017199002206326, 0.17722625946325643, 0.0970124947508016, 0.09179506826424792, 0.16953587051360838, 0.21532309181507558, 0.16428389346166966, 0.14772550052692815, 0.23824905435885155, 0.24591359550193434, 0.15226492387873514, 0.18535731750870907, 0.15477953088139335, 0.24064828852011313, 0.1099566763807689, 0.18114061635588447, 0.27815273572360316, 0.21861855691719442, 0.1306271075361198, 0.13025207685366755, 0.13695989675339193, 0.19768934126102156, 0.12361058484642737, 0.1618047716516641, 0.08733617607504131, 0.1201607300449283, 0.24692230347183444, 0.17493093746804422, 0.22393054929712128, 0.1316103967086923, 0.19699987745092762, 0.09213188648103707, 0.11263259085676364, 0.16355276979025335, 0.08619393897993911, 0.18992009122044812, 0.132074385520912, 0.18164073387461324, 0.1341410915577604, 0.10157056468268556, 0.14329309965814316, 0.16287357155834475, 0.11911026262227567, 0.1457721142158393, 0.1399622106504056, 0.2533922990363452, 0.13545407432942622, 0.18791090306495467, 0.1757240682960518, 0.17620576906108087, 0.17099652439355853, 0.15805926053754746, 0.13766158732675737, 0.141250096381672, 0.18041398195970446, 0.10849731718941082, 0.16185176348493946, 0.16993995125014938, 0.1156358700245619, 0.13474662277487018, 0.12249109290179708, 0.17371468095769807, 0.06498804300903313, 0.16368280555452072, 0.11331339021243396, 0.09591633018346564, 0.11600905443511664, 0.1075130014590198, 0.08780168174135108, 0.17891084084347372, 0.103597579704177, 0.19846863654111663, 0.1364018936311045, 0.07707232924839182, 0.10359867520990873, 0.1686273515224457, 0.08254683952057555, 0.1016764150511834, 0.166552433023049, 0.13604604579027624, 0.11183985073359744, 0.12798990348293898, 0.13278255719811688, 0.17594002848190649, 0.20001162955116844, 0.1790244823261615, 0.12898309817237238, 0.34037001491073643, 0.17616300603314755, 0.16355646233404839, 0.1106959588885788, 0.20994676337126764, 0.1449633858376934, 0.14143686861761157, 0.21463064026207695, 0.12333201229452126, 0.054770402775536624, 0.09361272677779199, 0.09141823727517359, 0.09453072227657804, 0.24286525504242992, 0.10177432874878568, 0.24063644480080376, 0.130114778575878, 0.1360481142276718, 0.19715240555665187, 0.1681578009118957, 0.0760150972693678, 0.11718365108414043, 0.14603433079056202, 0.12420657826887986, 0.11945910075859678, 0.1539131160825491, 0.17410762277582, 0.13396794036511453], [0.08146043491339491, 0.06074244885014431, 0.03930673416283342, 0.022843207810975374, 0.055897873525898305, 0.07831596574115177, 0.030661571748374455, 0.023537070880974495, 0.013638008310790024, 0.07365203777989072, 0.044151137117296464, 0.06708062749596373, 0.02660750531621518, 0.04556982853119412, 0.06244336705534689, 0.02485897474651856, 0.045692092333469665, 0.07430013284207353, 0.05700501996362883, 0.03418242183303641, 0.023623684781693646, 0.014833255817422704, 0.023674079960572626, 0.06691794106436354, 0.006309634688565689, 0.013209744093699322, 0.06643887564179397, 0.010022728313361446, 0.013935973420889388, 0.0008296193564385777, 0.0403627404011786, 0.04646621652007584, 0.06363545349168201, 0.030965743128270395, 0.013010844685918382, 0.05037410380018335, 0.015944135976174188, 0.02635375975871519, 0.017722798699152567, 0.013013041443041256, 0.016579954479370388, 0.023358300433404023, 0.046648867202982794, 0.02791000992029665, 0.019125168609823433, 0.028813267802639358, 0.010750435232635467, 0.016623788115177906, 0.04320967251495008, 0.028704014088537906, 0.05975560119916355, 0.017937512076910467, 0.016824836399586453, 0.10061764323543157, 0.07740144828154195, 0.05602338171053318, 0.03354140542327397, 0.01441856476313044, 0.0411873038167194, 0.015689423232669794, 0.08896866347640754, 0.06047046848482663, 0.021971675544796933, 0.09049255025362776, 0.02425399702793408, 0.032295003353107365, 0.0639332816635649, 0.04349433929629384, 0.06090740290200038, 0.049256327892503435, 0.023966453586434646, 0.05467195664682696, 0.05516229888364192, 0.05680695942212498, 0.028578412058132312, 0.016569041556889014, 0.013839607220894147, 0.021346785285840594, 0.05494107567374745, 0.01143747054400944, 0.06542459055180512, 0.11115058610636382, 0.028434617354744868, 0.018393522083398797, 0.01588104480517007, 0.03282425136515691, 0.06646726686026781, 0.0797284939776986, 0.029121702461833918, 0.008186323628310234, 0.04929461696695897, 0.06492320898800127, 0.034479334529849796, 0.026726557294868176, 0.039413584276072444, 0.02252414751227104, 0.04818858518715828, 0.027695844295404615, 0.07127013252747637, 0.03852376166070181, 0.05579613321911424, 0.011670242529362442, 0.023491345007994005, 0.022986464337596012, 0.06908518081951527, 0.009469373429554605, 0.02628880890927488, 0.037879910725619526, 0.05717101589506192, 0.024393099442785306, 0.02767360284774294, 0.09012506553722967, 0.019989017014121337, 0.022396574720680233, 0.03969631668540739, 0.02991666232476071, 0.0418822528163512, 0.05077000654813263, 0.04396933679198546, 0.018020544516583605, 0.05727813796951406, 0.13521375254757945, 0.02754557806427681, 0.04358529308510404, 0.05100903364138738, 0.01731038292599542, 0.03002883483385367, 0.03678039069317522, 0.017944426020427097, 0.030027856156530402, 0.06349246701105468, 0.009561823005036963, 0.02595588433436088, 0.01371937929727738, 0.012094976996342021, 0.03821690514263126, 0.07407676458599106, 0.059663888983308315, 0.02727773648897006, 0.014539935115364291, 0.02841061390485735, 0.029988550100355383, 0.028223577368583892, 0.01437697480733116, 0.022061261866662293, 0.06814151371438658, 0.04380918228097501, 0.0460839233241014, 0.016031870280482596, 0.03373282781291393, 0.08152926025251228, 0.07651835574858612, 0.07553876678068792, 0.04479442114731477, 0.08121381588881055, 0.014320793749404051, 0.019001070026969238, 0.007453466682965237, 0.03235866525961507, 0.02584837538550698, 0.0327523923178594, 0.04228193237776718, 0.047437895630155845, 0.009402146341369278, 0.008744319089718403, 0.033359716180711985, 0.018331018884876565, 0.05396412970918802, 0.022109069583577015, 0.05779129813515371, 0.07411981106645639, 0.04720369106038444, 0.04322326674516644, 0.026274013836237214, 0.02902111320215608, 0.014113534407149401, 0.02541211129526698, 0.011618390825817422, 0.07585157580193012, 0.03321196080275601, 0.006937376709820162, 0.03152308166928349, 0.019500160987879482, 0.0738339760010281, 0.03213855670765042, 0.01614028512830696, 0.017350334411246643, 0.016680731430589672, 0.0167895159158375, 0.01901121494630652, 0.006421288173089946, 0.022200814358169035, 0.014677311917166076, 0.02214131230909017, 0.059578516145026496, 0.0396227416011595, 0.026589959987529346, 0.005780594956670558, 0.006270239095864517, 0.04594233495393588, 0.032596615999336206, 0.0476356344147315, 0.042171516125240636, 0.020913062692289392, 0.014829917589292653, 0.04822559106434065, 0.01780925555184724, 0.014228419825104217, 0.05121455970971335, 0.12543556716052756, 0.02531877497301227, 0.024529828900291074, 0.012545877196375402, 0.03577330299923497, 0.011228798727144398, 0.026378831901257078, 0.07835627728772741, 0.014354393408153088, 0.05754852870238885, 0.05554018324361213, 0.018721124262458855, 0.03188719559881476, 0.026533715727348483, 0.033992792089139266, 0.04064276852014084, 0.08087142055193264, 0.04415899334895996, 0.039286321750090974, 0.08499776163408834, 0.04332244448784379, 0.051590467562838915, 0.031916728288295775, 0.03175002181031291, 0.0558809774567283, 0.07732629505617004, 0.04866753569653919, 0.05081897488825264, 0.053706207057280894, 0.007773940892694819, 0.033818748404061606, 0.05921665451399261, 0.032291916018772515, 0.03946581998118951, 0.023967788494642706, 0.07410492597808761, 0.0302375937932201, 0.027744056123699394, 0.022235230858167334, 0.03326954763202417, 0.056822181589180426, 0.0068869097101982805, 0.055230909718140486, 0.05442021249402916, 0.039242811786431464, 0.025630689586602876, 0.009198199371777235, 0.02667871893443648, 0.014171831782967334, 0.024086524462026936, 0.049620909135668516, 0.025179019468205593, 0.010698443718044268, 0.06755707289783225, 0.07554971417712589, 0.012350417523374482, 0.05180136390751408, 0.01815270042918142, 0.036082882959876335, 0.06423586724145759, 0.033348002696349736, 0.054379870303936546, 0.07318374355353656, 0.0034407000508039232, 0.024529957220018394, 0.06665704216087057, 0.05200191423477185, 0.012614830855220076, 0.04107366616447126, 0.030010544484661474, 0.03985415761088652, 0.06887574004189623, 0.019457210268404697, 0.028491769429116, 0.05946439968782568, 0.07006041840800355, 0.03811935916723263, 0.05636947342164575, 0.039256858008523146, 0.029668978437961593, 0.0014254325088263761, 0.03343954254242201, 0.047771726104040305, 0.04956272858825903, 0.014573630535103863, 0.04322922307877772, 0.01995432855290992, 0.07044836533285918, 0.08122958197829225, 0.06649339811936503, 0.020204289636063962, 0.01343647356054956, 0.038457276720193126, 0.04873237737845029, 0.03675856101777285, 0.030292694667173974, 0.038032722283875754, 0.11382427126649888, 0.017247303246310162, 0.013916101100133553, 0.07742156575043356, 0.09334966750635255, 0.1092598964309981, 0.03416701963531875, 0.061642464265347495, 0.03626753696270528, 0.05698339713196601, 0.003592012470753323, 0.04235416680814759, 0.024767078669561494, 0.06703409531544294, 0.05943028962299709, 0.06821668226151698, 0.053027326751860886, 0.03388047593856051, 0.07885600410161481, 0.05664407380766446, 0.02257402366658132, 0.07063487709890451, 0.04585246517953854, 0.04569285842139394, 0.014330672453187648, 0.0069791375989875495, 0.036240984355249715, 0.027643409407427235, 0.1016954216925848, 0.008580088033340871, 0.03245737951909823, 0.06651483325948639, 0.10408017679207748, 0.012228712007673758, 0.03338718809367668, 0.03110440887300478, 0.029323553223343148, 0.035630515701467955, 0.08418784581965978, 0.07174035729539972, 0.0615332201273451, 0.05223266757844437, 0.030690116184433142, 0.015228341724122725, 0.014786670010747209, 0.025572070453856743, 0.20165700255142105, 0.14987865192515237, 0.17357355224028712, 0.16699486412107947, 0.07182673370886235, 0.15428316719349355, 0.13105135170682786, 0.15104393294501692, 0.13357110682033724, 0.13529469739765893, 0.1419729156599891, 0.17723658632847572, 0.12221065875623496, 0.13310264405463973, 0.17029219847773353, 0.14393537245210142, 0.12867131570894874, 0.1408425069624378, 0.10115622602883848, 0.08954501440448147, 0.16231837231786023, 0.10352022014558317, 0.13775295097260706, 0.16776228503834817, 0.10655475570069206, 0.12266193050891162, 0.09036154921857581, 0.10166531443716058, 0.09080727449468068, 0.15782442394523852, 0.1062174165441144, 0.21597969045321788, 0.20502265662916247, 0.217320574147086, 0.04766037905468576, 0.10639610655245282, 0.15105750802303516, 0.11742742026164649, 0.11791538762589616, 0.14712301833975702, 0.14048661315633407, 0.14673340134322643, 0.235766178718017, 0.14283847244035813, 0.10120800591164059, 0.13050151508181326, 0.10143813872409445, 0.22777479382291918, 0.18231247041013934, 0.12349704295516976, 0.10124537568058699, 0.1423802599310875, 0.1289070869285253, 0.28992465727271577, 0.11812234627864054, 0.15837548631093196, 0.19610848818575183, 0.16205419455805134, 0.12883351184427738, 0.15767013383728845, 0.11616670000817507, 0.24284074022885294, 0.09567946345815737, 0.19971434147127215, 0.19413697623437454, 0.16873631986879534, 0.14115911577978443, 0.20966942422091964, 0.19223482588366156, 0.119966204999195, 0.14002962638774227, 0.14708846777437196, 0.11661941966702861, 0.184463553370968, 0.08140994971918483, 0.26774582963797355, 0.16519235116579842, 0.06881736414206606, 0.15134520468211946, 0.153734372448056, 0.17447035008620831, 0.13343549393598111, 0.16356113547038648, 0.10225382318059284, 0.21015654888845262, 0.15937192155228508, 0.13206684721573708, 0.13006417080760002, 0.1400822872716573, 0.10045563096120473, 0.11124332871047721, 0.17438154517402574, 0.171517203712175, 0.2198662077106776, 0.17133037018920147, 0.12768827934539126, 0.14882506652464791, 0.09869973445611616, 0.15398784029868343, 0.15623543501621293, 0.22121724973042167, 0.11546839554343494, 0.1410368175035523, 0.17511587109296553, 0.1487154393426834, 0.099032094041186, 0.17140630482425614, 0.11507356148814002, 0.12166387882203826, 0.10309779926413491, 0.1281949545767519, 0.14988208399905315, 0.11535705998539926, 0.10822751634423772, 0.14346537751055535, 0.11623538745146607, 0.1946822316536019, 0.16998904216433727, 0.22508830733356938, 0.09811817413015712, 0.28246142871437535, 0.19794363648660723, 0.12611285017262544, 0.12636847839119936, 0.13509312434302223, 0.11228496313936288, 0.09865153986479967, 0.18624818583409633, 0.12206039827076659, 0.1391601319154424, 0.24723600115506883, 0.09981983161020665, 0.08202088185616078, 0.11519110235836237, 0.19374601092309723, 0.22527694882404423, 0.18111052442221873, 0.14653974963772684, 0.10969418401439344, 0.19819647614513675, 0.09381413895396457, 0.12057418769766247, 0.08902795868174684, 0.15521021019066536, 0.1417578441361266, 0.16763287746617872, 0.1445574971336511, 0.16160728950654307, 0.13018285314882957, 0.07686170103449015, 0.2580099859304967, 0.1697996805512136, 0.19875002063570485, 0.1392522616492164, 0.16268568083403573, 0.10477468912159243, 0.13266782787057663, 0.20111222210670673, 0.1800540432093605, 0.13805888052428925, 0.44630217095536573, 0.2040422326254268, 0.1751192112363154, 0.11062808349848756, 0.1352618015821903, 0.09252838294712767, 0.09126281335709557, 0.1550461907660769, 0.1631040567712438, 0.1920479310736541, 0.22653754650344773, 0.21690005316368996, 0.13513217950540204, 0.09304440445116452, 0.22935773065734297, 0.11216665618121625], [0.08702230219158434, 0.012263251081739944, 0.007488488871228671, 0.03152807273211018, 0.05211746327639107, 0.025085018564676567, 0.028541099745780233, 0.03489832333739727, 0.018103904458844376, 0.02053525111067199, 0.021560113959675355, 0.037182996710461956, 0.04416285443209833, 0.0122085849626831, 0.04691175793507888, 0.01899981364277342, 0.03626998844406298, 0.02946499412158324, 0.05384576529444707, 0.024790323692403977, 0.019107498791849902, 0.000512058076339834, 0.07315927470523505, 0.07274635331404787, 0.07220957848814226, 0.06632756306639602, 0.035717979959783056, 0.03719088741608205, 0.0652604332313903, 0.024518109670269395, 0.012831352200479278, 0.08935214410866461, 0.03724895305030289, 0.07650029905621084, 0.032908245245175015, 0.035505677843766834, 0.04175450765497742, 0.040126425259175806, 0.11028446242093079, 0.0045587014756165445, 0.0308464594080203, 0.06705008357042266, 0.02460150983214619, 0.02293805524166073, 0.08065602727114193, 0.029481028341838432, 0.020594373946228338, 0.01416115539013258, 0.0386046375628681, 0.04514168497295149, 0.09848977273870861, 0.05745980805987793, 0.043230199840881174, 0.012518831419818586, 0.01835761554238777, 0.06581266771160788, 0.06017958106953771, 0.0748008938746587, 0.02767261842476024, 0.029935655559623436, 0.033497382180705186, 0.009733869115852061, 0.07627234959434118, 0.0682930918710847, 0.056403173629434845, 0.008099964451825908, 0.042814474567891135, 0.05652080643020811, 0.05170521221213764, 0.02471685777568529, 0.06813469553186048, 0.035909888815254934, 0.042443113446596174, 0.01302787865091476, 0.007444819465519921, 0.06087110565614797, 0.02041536601140134, 0.05125007171544337, 0.026995661000030178, 0.10386013335758641, 0.0705288888345803, 0.07465192807778236, 0.06886462410611492, 0.0571718356091409, 0.03537268498011174, 0.010617272872027132, 0.03132070805276594, 0.04647534828813327, 0.047021373625724554, 0.029124581037209402, 0.035991224370175795, 0.03021921725913642, 0.07663689253311004, 0.06146095505344772, 0.02994246225083067, 0.07431241323149974, 0.05993980704055679, 0.07511696643045834, 0.03967198573293225, 0.01240126852456841, 0.06802834720621187, 0.030098851439693285, 0.047934462331355586, 0.03229936622383614, 0.029570469106998176, 0.030429851218697526, 0.043710540799844655, 0.044946183165114735, 0.013181552058085801, 0.029344473169335437, 0.06311096288564225, 0.021720040559528336, 0.01933572787581192, 0.03615672617489773, 0.022201446380706567, 0.011037197264452136, 0.053473856420286243, 0.05216670740816382, 0.013854274931814403, 0.042798915322148995, 0.059961529463649764, 0.0455145935918535, 0.02061757874945479, 0.055165160222039114, 0.024585441137934406, 0.03884235464577233, 0.02455986146214268, 0.04384457554307677, 0.0697917360511999, 0.0676926551386714, 0.03629658318635437, 0.053251415130592165, 0.030364615001505425, 0.014780421606114796, 0.11966884797138554, 0.028030036745833296, 0.011239802622566781, 0.006615096447809089, 0.01797117398030335, 0.025748464113642133, 0.03210625461032314, 0.025080123262840415, 0.023059072235839504, 0.006446686381804607, 0.04480989995382486, 0.03983891629163296, 0.026510514754561648, 0.04025509355649833, 0.04286068882192335, 0.019134622134809053, 0.01891855469664499, 0.0294426147780952, 0.08078089194192041, 0.031286193876557296, 0.024930299447488882, 0.02888836740185657, 0.02315859663330259, 0.023959621997369875, 0.08701051975930892, 0.04482398448031276, 0.03617006759609907, 0.008441749791194116, 0.013892189580796948, 0.04789011350141899, 0.047833468960297686, 0.05698838436435308, 0.03412647060148659, 0.009280184186213921, 0.027412464541773644, 0.01634796007326053, 0.030984073697078614, 0.03576961811631918, 0.04483943264330587, 0.02184484202805306, 0.0141812575372657, 0.018843208034072193, 0.03242285193635091, 0.02401947644689391, 0.04471399340658419, 0.003049046936212108, 0.01789357884967279, 0.03342496771966258, 0.05082593096660511, 0.08453695974763363, 0.006945514957600784, 0.05200552250889521, 0.02515071251940343, 0.024536677726334142, 0.054617663995633205, 0.010604611353858585, 0.04799542760836983, 0.0825438977429463, 0.02258516833065979, 0.04981010603988844, 0.030636200831542094, 0.0695475991514902, 0.019025040918119976, 0.07914326409058225, 0.008374688369522413, 0.05304174835703546, 0.09314928188799851, 0.026840616295474674, 0.05386872111909813, 0.051981256673893625, 0.04157093383612172, 0.024520484542834665, 0.0190892429166143, 0.037822841005700256, 0.029530670839331807, 0.04355736918026402, 0.014802167011845498, 0.03202550511266435, 0.07575454310544076, 0.0314064103088552, 0.10986787146858631, 0.05651383886053678, 0.056997248001637, 0.025855567035896164, 0.04897478291945112, 0.030055753248293075, 0.036720949931130294, 0.03262240634930711, 0.053024128334777015, 0.025133655571769324, 0.033505452916987484, 0.01878975424915552, 0.05761655731006496, 0.015182960590708162, 0.025695035226583004, 0.01748891397108955, 0.06063852902321566, 0.02167896484024823, 0.04290233719192686, 0.011325187909777367, 0.04839365160272968, 0.08829348720610143, 0.05623859879110129, 0.01765861968329597, 0.03546825444866573, 0.03827058875392522, 0.03625664702286163, 0.0185156001093527, 0.0367117147412031, 0.028105687928355993, 0.02304832593748166, 0.027518334062469584, 0.037125892516586094, 0.016250393030443983, 0.04284953075130621, 0.04709998956851421, 0.05370347212339121, 0.07325295193661606, 0.029026782252795758, 0.07835732682818368, 0.005082097054729539, 0.04563550907938231, 0.017340758312193137, 0.06425590810155676, 0.049305572024276184, 0.0563818495720625, 0.04835177723678851, 0.05931775896779953, 0.11565927401064865, 0.03934825995876905, 0.049818180606610356, 0.026411758360242652, 0.04403162357066909, 0.07034892712028758, 0.09917785759053885, 0.056246290313861066, 0.049437687717257976, 0.039122524491000565, 0.046661147592409004, 0.07857994431810034, 0.08446826464346341, 0.07117090881952355, 0.006384296660056158, 0.0360296858144143, 0.043348391885839166, 0.07609103956530172, 0.03060082097597901, 0.016489410547599677, 0.008636465401298577, 0.004870437494959803, 0.03511311906960703, 0.08074701553390873, 0.06771007597806954, 0.033078573403819915, 0.008915297465489037, 0.05432816319948724, 0.01479990705246887, 0.011704425372543835, 0.05693777659607511, 0.04689724056891376, 0.03885890980581603, 0.0535868697108761, 0.07338755358491214, 0.07541209414240814, 0.02103555823616203, 0.0526190401926156, 0.05483795257826006, 0.03901042667548022, 0.04191888714089029, 0.034327005606985865, 0.13417254712793136, 0.04819141971247812, 0.04621984264362724, 0.062074116506283326, 0.05105813604689414, 0.01411764351125326, 0.07723159892784973, 0.05142773516596325, 0.047497052939668785, 0.014962666262421879, 0.01937437318115225, 0.027018482759294492, 0.012860861907322562, 0.019820640464463544, 0.04293132212854201, 0.06664452428418784, 0.038354682225373485, 0.03560154991705091, 0.07847689783140537, 0.10017115187140242, 0.025571210520161737, 0.0416148498263811, 0.019907357787052472, 0.03813370033317516, 0.036951714766121684, 0.023598354084477313, 0.05578680609863612, 0.04112702418839739, 0.047213316955153024, 0.015010273838866384, 0.03646688836236154, 0.020780630988038836, 0.045996623774690014, 0.06485459049262347, 0.0226516762538062, 0.04465851714954742, 0.05717749316846171, 0.01143085537478328, 0.030533776791285605, 0.030562202483716033, 0.0731289682669505, 0.04765608896230979, 0.035819578540301135, 0.033630934288545, 0.06382843870068751, 0.005632479517390171, 0.05982471765169214, 0.029205659952675624, 0.22615539120329967, 0.09171950135139689, 0.10533166568606131, 0.08286922464087125, 0.133435616510049, 0.12446849606931211, 0.19223874825383389, 0.13692937581048858, 0.12214869756491915, 0.1691053137784043, 0.07662242879309962, 0.09807656023411021, 0.1864456066921834, 0.17330889950596517, 0.1982280542893756, 0.21666927683737972, 0.325866959268047, 0.09732839110637866, 0.15656272309922403, 0.14152309947436856, 0.1260327326975042, 0.10872193416880985, 0.23511872716969062, 0.1745598138340058, 0.2709556154666409, 0.16530914893073423, 0.16842538010208838, 0.14918874378406233, 0.16131418426671337, 0.09311540547998683, 0.11060326224974087, 0.15818405626041276, 0.1773714944119415, 0.11822289531870235, 0.12879598885774612, 0.18191583604822237, 0.15782204907267325, 0.06845623029456024, 0.17032627406860554, 0.12079071478858111, 0.11040156662103631, 0.12190442276938308, 0.08594653854567198, 0.13110366019029773, 0.12361387902450179, 0.13682682728094442, 0.10507718659937383, 0.10859641832329574, 0.21940828631481818, 0.1283944745157515, 0.17738378246224698, 0.16811540560616603, 0.10625742931639957, 0.08407944437837409, 0.2452970632622319, 0.16074478175611268, 0.16170324967993846, 0.1847596463537024, 0.21949767345382323, 0.1663802624229462, 0.1005034654911968, 0.08730510354883249, 0.1479681971813402, 0.2831382520737187, 0.2744589968314094, 0.22745329736461564, 0.07145697371132913, 0.12762284777577848, 0.13705885999145048, 0.13230972773125096, 0.09508237452997316, 0.18048026388691318, 0.12840646379176648, 0.07210543649571557, 0.0789431082986055, 0.1867757905875483, 0.09548083984202917, 0.14380342146802333, 0.10357425232688267, 0.16076554273886068, 0.1528725848202744, 0.18784005525371722, 0.13986156201891362, 0.14160265004442585, 0.0829523298588972, 0.19083605658623481, 0.20178474005191557, 0.1345730578947452, 0.1362829814634977, 0.1284399341731783, 0.15558206926911108, 0.16785177942966262, 0.28145279735326767, 0.19973934658112066, 0.16284704959440618, 0.142923814635123, 0.12018380461320763, 0.10724674760093612, 0.1962590857499069, 0.15342786066955136, 0.1507735958382968, 0.09340388354875388, 0.24136387592842504, 0.15766448010840725, 0.12572795993858768, 0.14787548522074379, 0.20385254925537497, 0.09727969089703215, 0.16471469534500954, 0.17613541154611498, 0.12764573848295596, 0.18859106656764785, 0.08473900011590413, 0.13572588232496094, 0.13248304746324016, 0.0786916169548227, 0.17302226004821641, 0.10482879025080513, 0.11838458583600099, 0.1734999924777977, 0.194377098833361, 0.2480078347387814, 0.09015200118864737, 0.18818629635197504, 0.22565040136537245, 0.16037172758050505, 0.0981919790407823, 0.11268409494791301, 0.22978477870985387, 0.13180446210167102, 0.11205191153191751, 0.14714817666719038, 0.11323802248244325, 0.09319173848076213, 0.24586416750905976, 0.10710879814841094, 0.09779201985727395, 0.14356746638734497, 0.0732658988225364, 0.08667646711992641, 0.12267972673139266, 0.2507421404363648, 0.094398204387436, 0.14663410102648122, 0.18635519299535983, 0.12195603411284187, 0.24683572021463226, 0.17942318512547403, 0.10072654263386804, 0.1953836924005901, 0.13614741454441703, 0.1301707642813844, 0.11842976970177506, 0.08385089736792349, 0.20789317275968291, 0.16886269373278465, 0.14088952943923014, 0.06381883961899627, 0.14459397824060533, 0.2256706873736074, 0.14907519423192547, 0.09371684578758094, 0.1291877509004647, 0.15983607890384813, 0.1539857565395294, 0.07589078418189481, 0.14937278874699148, 0.157119071471595, 0.1718166828035347, 0.14752660878002644, 0.11591739967585572, 0.17566854224329995, 0.29348889666218914, 0.16909245882303486, 0.112343400326227, 0.1456426453566359]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.023768477314602465, 0.03457217289495372, 0.018666463889061444, 0.08683409737122637, 0.05107957501745513, 0.10667405091226102, 0.08050093277087135, 0.00858809844019913, 0.0763830109950035, 0.030018873775618213, 0.043574188640641595, 0.05457519591155072, 0.015154693861522022, 0.02785316045065561, 0.051084451167093176, 0.025130277124023246, 0.04938721018392713, 0.04757011857544703, 0.05494676387658524, 0.04957502046900411, 0.07059355431626882, 0.06853450149778398, 0.043653030579368916, 0.026976049149168596, 0.02407951284229996, 0.06897159296298219, 0.07581820501194847, 0.06758435328881587, 0.04625615904167776, 0.046771353170756376, 0.033218223571537, 0.010534596663238782, 0.016547665788581776, 0.017546671254920865, 0.04216990351016003, 0.020251515126156232, 0.02671099996434585, 0.01906578338915302, 0.042475538117991346, 0.025842566523821126, 0.039752359847508134, 0.012779177782396156, 0.043246869914113514, 0.08001848123967648, 0.04064003741669078, 0.04587853132116218, 0.05913500103258318, 0.04261669747891926, 0.012633419021092837, 0.019398234904773774, 0.08636385728154453, 0.017180929388550502, 0.04675228141188141, 0.02064371958465105, 0.050126140291291865, 0.007937580146150845, 0.02616138550482931, 0.034382830434028185, 0.07891016651786144, 0.015670298805250036, 0.06123782428462179, 0.051751683105624495, 0.021876165448057077, 0.005854084813636878, 0.039448950725096854, 0.054085343971007296, 0.09170161319836494, 0.025479178462598114, 0.014536644767729506, 0.04393595834112456, 0.01759645164824061, 0.04406530462626008, 0.05848230561241508, 0.03672655769473603, 0.023096719711658456, 0.0565110503004924, 0.017391122847555146, 0.012832112542744125, 0.07030660842335032, 0.04485741655732836, 0.04040190664630744, 0.041136849266026294, 0.024395083610509193, 0.04768343447076698, 0.016607614083876534, 0.012130025518877853, 0.031270755289663235, 0.010375693748374621, 0.02057059266183886, 0.0616786887328471, 0.07326987481886342, 0.03911063863685535, 0.042972468710955114, 0.026271759622520017, 0.022105758168524312, 0.06749582416828602, 0.08178160195389102, 0.04850070472926863, 0.014148939160570024, 0.052675462568238865, 0.04446811365684675, 0.06021176442323674, 0.05724264894642177, 0.08997671261069276, 0.05666406104160894, 0.028199932064800978, 0.08562223054468633, 0.019790002693151756, 0.04623503416716572, 0.025731941512335214, 0.03138662991865027, 0.05455581771750605, 0.0776210550459162, 0.04893597673564669, 0.01722276736531527, 0.03679319968326919, 0.07808653006870901, 0.020416852221974445, 0.026102867878733144, 0.026467096721453053, 0.06243147737076206, 0.03182796742616883, 0.007208487086538827, 0.02948659780104795, 0.05280866227563351, 0.009498782587357828, 0.009954244840980299, 0.03847813346393166, 0.011960519947141651, 0.06810998153542319, 0.05476485629896483, 0.023606936184449062, 0.029038057151821353, 0.0068582585006351435, 0.03246018723134072, 0.09415466503630723, 0.07598629236341485, 0.03608654102971477, 0.01758269079390072, 0.026746873946620092, 0.021714570691748973, 0.03704156921876054, 0.028164245774068182, 0.01030314905238488, 0.03162918867723596, 0.012610236242894205, 0.06368395068772859, 0.0065481279142982065, 0.03005040978502122, 0.032308835070580244, 0.020034105118904865, 0.08204075417691663, 0.0349390447410124, 0.02977819576288664, 0.04708825310151424, 0.009334270951278027, 0.06305511124552259, 0.055897674343037995, 0.021285957904652725, 0.01744100283230505, 0.027993272186347076, 0.05252671893686057, 0.022032859156869596, 0.040783027727757735, 0.023606842338678338, 0.012084021939024811, 0.020339576933052272, 0.05866134419075905, 0.036465379169150706, 0.03733672757422732, 0.03555189209779905, 0.05584603618650187, 0.018817762423667218, 0.03790448299579082, 0.00571784756762246, 0.03255393341063492, 0.011259114741527987, 0.04637774485614031, 0.04393192871864285, 0.03302952462446786, 0.05142612255088264, 0.13225254692858265, 0.006014777980219092, 0.016434106660345872, 0.0754786442003904, 0.06756671794479893, 0.03805314618793707, 0.053513221848275394, 0.014403437399455618, 0.008843175075467556, 0.020807639417809345, 0.05598780075688997, 0.04916987487024838, 0.006453892875147323, 0.030231819405490835, 0.035932473087262724, 0.02717880580964829, 0.008373550728954857, 0.037700481442434174, 0.013251024741499175, 0.02341370965774742, 0.10705350192203637, 0.04908997189974593, 0.08660692931903947, 0.009600313177572624, 0.04312948609191564, 0.0616266981758658, 0.02331944253866471, 0.04464103885355496, 0.045911308393002524, 0.0445142627934054, 0.017220787028031006, 0.0170851607371362, 0.017966734500782146, 0.04594749455610591, 0.031232899054884914, 0.030463350328406504, 0.038515782854970426, 0.029722499255571636, 0.01686495833940083, 0.07697133587733393, 0.05878006866682441, 0.013928062605461287, 0.10425027895478473, 0.03129956019561618, 0.0176777929488209, 0.02652635553761596, 0.04273780065798952, 0.030689545448929555, 0.012431959922034896, 0.023448030396755186, 0.05841811893567924, 0.024530924406022798, 0.08145571581178135, 0.09067923821989568, 0.012236856479918765, 0.028049784577301437, 0.027316272626781178, 0.03539533436959309, 0.06586973360108753, 0.05497423195911031, 0.0115897333917899, 0.027655396768222415, 0.01446582760000902, 0.014390767262797925, 0.03786818191949879, 0.030178850171186274, 0.028409150676921974, 0.03539806547304315, 0.037408670891196504, 0.03828674554824829, 0.06435444999125696, 0.026627615124227542, 0.04708369104792515, 0.06208963744762925, 0.03676352526752218, 0.018297288033570495, 0.03794769801559948, 0.047268157359212644, 0.044367116455349236, 0.04040921129466545, 0.018285813951684583, 0.032157226270365144, 0.026056056076119986, 0.07033349044861333, 0.024658211829861807, 0.039373563842908035, 0.10617018722358251, 0.01005580320188235, 0.03494099826521931, 0.021291096439404834, 0.06061304510841447, 0.052195094796198035, 0.030944089653090607, 0.08590074947043773, 0.04214619308890354, 0.07123837052213569, 0.05124452523887158, 0.07982338928887922, 0.022748149706110842, 0.04432731818768286, 0.06998608489671061, 0.07225211935057756, 0.025250692739181464, 0.014573033944132828, 0.05776636963409763, 0.04147412713557001, 0.036318830379675475, 0.029127804352150812, 0.15213612917690508, 0.0317987373414179, 0.017119730454719356, 0.09105103601130748, 0.05375485747091232, 0.0640046542450305, 0.01926498731688386, 0.018462810905710347, 0.07111924384991009, 0.06896176405491368, 0.021998864005229646, 0.04267723374669591, 0.0521922602708782, 0.08652581592961665, 0.07515262016245434, 0.017278697529447176, 0.038244323429441264, 0.06727203456384521, 0.039815784266759316, 0.05624816339883593, 0.04322364595868895, 0.04653917873398431, 0.059112443573652744, 0.021918518618950923, 0.06494138825444445, 0.07049314317203338, 0.03266474036800285, 0.06181677225075903, 0.050759802256981214, 0.05189740068970188, 0.012303534857628327, 0.027858191733098323, 0.040223389007751985, 0.02650890596992066, 0.04813821873657646, 0.0357197228098108, 0.03275455651624549, 0.019950134221524484, 0.06389758579673306, 0.011639164257494193, 0.031097780297239943, 0.04319331653776669, 0.05169220020874374, 0.09532771418772398, 0.047014942317600214, 0.051469755088610035, 0.06123867081177812, 0.007445608057276978, 0.027884621766485998, 0.028091904091378374, 0.03867008445423938, 0.04746722530633692, 0.030467536998912696, 0.010879426244496098, 0.04262286831714934, 0.10185989310904857, 0.012837949175117238, 0.07572039856665558, 0.03047476503847828, 0.061849832775131355, 0.06005690357978306, 0.028798597218889384, 0.027473814777969837, 0.07841962509818616, 0.12580888180602945, 0.1417687072628929, 0.19418338584082742, 0.1474738559655605, 0.2598332751902842, 0.08701018268062223, 0.174719313339841, 0.25741599199752657, 0.09499095725796877, 0.172577653260481, 0.11510824994935144, 0.11770318127087048, 0.08172336394988722, 0.1747993848496868, 0.17329655016862577, 0.13062557536027125, 0.10722876751735326, 0.1412797899496171, 0.15089410146878612, 0.1140502288997654, 0.15931181429374605, 0.1307764027508036, 0.12479072797202295, 0.10799323133523427, 0.17916098387250978, 0.14844116454403247, 0.2645461255263898, 0.1359215258590637, 0.12692720163613558, 0.13522758809549196, 0.13037866522227565, 0.19948276841352064, 0.1811018369851574, 0.13042977860858365, 0.13306513638986697, 0.09899732131030291, 0.0724953139621404, 0.21103476144133076, 0.24353800281401605, 0.1438838453783143, 0.12361272223173611, 0.18312008029991583, 0.09977424171783271, 0.1318632363672218, 0.20966875006354627, 0.09253957549170141, 0.13971831889883166, 0.11668259893814403, 0.1980928397707401, 0.1598106601065205, 0.10686253918515098, 0.10404997760610235, 0.14514333989110687, 0.13766722573388007, 0.1697064323290702, 0.16943767336347412, 0.1061392602540793, 0.10599364226143207, 0.12461098842322828, 0.13544662795480222, 0.16582840332581153, 0.1905216541021101, 0.1680106660651584, 0.10921891838792833, 0.26945362348229657, 0.12253256124113837, 0.09928474217773446, 0.1620453845469221, 0.17803624422559816, 0.08778060666255413, 0.12077468822920516, 0.14061874800151394, 0.18909380410707768, 0.18322299655166366, 0.11273267258319164, 0.2084365282808581, 0.13401701595754395, 0.14275837028699537, 0.08945922787872054, 0.12574132817286637, 0.1384184821959465, 0.13962375300545848, 0.17388633061801234, 0.17298827638789532, 0.11006621163218253, 0.10258665774017574, 0.08288964088405333, 0.14230533653209287, 0.16370355121551022, 0.13524248084473994, 0.1575996997135301, 0.09647322247826284, 0.19542872304877928, 0.11850250208930624, 0.17426471676557295, 0.1900800197355209, 0.10339468131743132, 0.15694866287371806, 0.22458022250042808, 0.20617842283700744, 0.11269547901446782, 0.16026570101178464, 0.1323952844306346, 0.27886409432657305, 0.19150408525620738, 0.152750562335695, 0.11623837519437076, 0.22885166829632175, 0.09430795922995576, 0.09193288748182597, 0.16344839797144936, 0.1754323573362443, 0.21020396973096558, 0.13649955451969178, 0.18384427853649665, 0.1617279177111003, 0.19201978500331604, 0.18417360441338632, 0.10350237029694742, 0.10811940601636326, 0.14519669025415374, 0.13212516182853332, 0.17412545730269727, 0.1385960613767947, 0.08656271072405, 0.18717605620622638, 0.375404809150965, 0.1475417619991687, 0.1433117768817371, 0.20878171217778038, 0.15741691113479678, 0.17294745922328966, 0.08078689041036753, 0.28478120423613057, 0.27521475789047056, 0.17552491607925585, 0.15043645586457946, 0.1584247457644632, 0.1412707194685936, 0.12735310055676008, 0.12359543928816435, 0.1233961261929043, 0.094602091027604, 0.18729339023270916, 0.2084968960092914, 0.1266107996625285, 0.1653060999007956, 0.10972716409953372, 0.10255245957523586, 0.0744940986436221, 0.273395820010093, 0.12314009960860976, 0.09174949369363247, 0.11008108139879282, 0.168419940877826, 0.23496203154565828, 0.11330271860764873, 0.1271654013544321, 0.1122850014437591, 0.17552618778521017, 0.11496465442882431, 0.1150767254312673, 0.10788179618576843, 0.205121114249191, 0.16638024710118773, 0.1420665928913701, 0.18877123512568014, 0.183342399015542, 0.1016949390571925, 0.10051170859726206, 0.19825428513990295, 0.1849317097014958, 0.24444672098803907, 0.12660336860966298, 0.14967072034074416], [0.009256626982542296, 0.037812828236529906, 0.05897597267082142, 0.008892993773183516, 0.03233913767842516, 0.05388452934341566, 0.048376131171901385, 0.03639462711890379, 0.07731696410525231, 0.04358455764069673, 0.041003806606656125, 0.023432164715843338, 0.014992889388644648, 0.034031939182069995, 0.04034835326996061, 0.08166825924549373, 0.030113108335964145, 0.07383750766635903, 0.04742161243132526, 0.05330233699491909, 0.023488389823826093, 0.02270780368557861, 0.07551458904579764, 0.01608932495958382, 0.03289547838991688, 0.031653372157785686, 0.03744864918952508, 0.10780027676974574, 0.10532381328483743, 0.09136580621763583, 0.07558996443666759, 0.07081011971158367, 0.04348300885589373, 0.03662460671377279, 0.035434692136703, 0.05042977540964081, 0.061559121560065024, 0.07290566129790199, 0.025150432897311066, 0.023109741291151415, 0.08903542037812934, 0.011943180504585467, 0.02397225287202145, 0.028190541742069107, 0.05336630533659651, 0.034964268185919335, 0.04528813800143619, 0.06927207562952273, 0.013907027746280356, 0.004986113419891486, 0.03318820824666369, 0.042757125225879496, 0.019335503795094067, 0.02571357838479021, 0.05569525859168461, 0.019067922689681573, 0.025638524750848452, 0.056969258979323416, 0.05142179798455008, 0.038641471070267504, 0.023075935746272726, 0.015304296468985418, 0.03378613221068536, 0.008161040811589169, 0.07337453009019937, 0.03622084007328076, 0.03632017869442221, 0.05250346433791903, 0.047745472270875215, 0.030455984393014546, 0.0405879051334435, 0.02216739185725249, 0.024586910111529213, 0.010627621762274254, 0.01726431039822919, 0.0363432456018223, 0.02300472978893067, 0.0372197651003878, 0.008767270126319941, 0.027763034036803632, 0.02512465978431846, 0.03404044658846913, 0.041313057149490046, 0.0056285681597317665, 0.03161609814982982, 0.011383048615478461, 0.03200818386469637, 0.01671890750707638, 0.06583949611071618, 0.05046329175632808, 0.020867149127767454, 0.046324137853638786, 0.0485035813894243, 0.06439168186437699, 0.017833090462391416, 0.0688789039850235, 0.04477678580329784, 0.05828123817580843, 0.020842425555231112, 0.03394235286020464, 0.0606465537942225, 0.058315110753380486, 0.013521778408528097, 0.048833129431812033, 0.05725753020435091, 0.040640474086807626, 0.15068207897486227, 0.01756907932670607, 0.08579380359620818, 0.07046400884827299, 0.012191375755074044, 0.01637341909020418, 0.02755648332587894, 0.14166341613857977, 0.03134309697235304, 0.05048276954180291, 0.016996918899577954, 0.02254296646213099, 0.05829033163946964, 0.0483178778461391, 0.01374176151359514, 0.017983362439178655, 0.03792784867748138, 0.04421048594879047, 0.07617710188271538, 0.04335658136574973, 0.058120980242928194, 0.06181221785804918, 0.00720877053907081, 0.03715066013917808, 0.02469829163484035, 0.044587956621281566, 0.054771923460066325, 0.09367257356643678, 0.034019279579121264, 0.04897747571850496, 0.02776974496702033, 0.052850356610912474, 0.04568379943168933, 0.06115939603337358, 0.014749988763322754, 0.03286164794718066, 0.022222824064233614, 0.04264382082187841, 0.040652712341398, 0.031438932656460715, 0.041243921544763355, 0.06793117661389612, 0.010638195690849136, 0.03136779564703184, 0.02959984666367452, 0.06267141610864671, 0.031003580210850607, 0.032641765391153675, 0.044586026079712376, 0.028343165608783884, 0.05097508062458327, 0.009342967006828516, 0.029425492712987528, 0.025781530383673888, 0.02544371050692374, 0.0892326420533561, 0.02376665594056249, 0.017321793805627574, 0.1114465871585473, 0.034480012517662785, 0.012826073854680986, 0.031104454838280237, 0.05146363404609504, 0.14041784910425065, 0.08719738392579941, 0.035880363786653165, 0.013162245684784028, 0.06683508865535259, 0.040799709292308944, 0.03925826761030382, 0.028721000173039017, 0.05304210841835988, 0.04060059921034882, 0.059793120355255185, 0.05013968855623276, 0.0606022585904406, 0.04103395216647656, 0.04931983658142629, 0.07466529631206105, 0.057843710040493365, 0.06155385087514597, 0.02501942037094024, 0.008568686729807769, 0.024453402053745046, 0.0350327909203066, 0.06784426393888651, 0.009459324271207856, 0.05749735019860729, 0.07348120783365543, 0.03956484833672162, 0.006763049093405566, 0.043659197587159373, 0.06449550976075473, 0.019486321609527357, 0.024661274266339118, 0.030763587846811262, 0.026484230277879585, 0.09855313587092585, 0.05026625394220314, 0.028752193358095906, 0.04028433896300774, 0.02531768712815979, 0.0419671047148445, 0.034388131762464205, 0.02507650158217838, 0.03661868868455772, 0.057081268694732464, 0.05153318333830084, 0.016526265122417002, 0.04020522889350692, 0.10709888497067076, 0.04232724264804875, 0.02658541134047893, 0.06023699552902292, 0.04322914646998529, 0.06041681168661003, 0.016594718908891082, 0.04895717438851153, 0.03921068205888714, 0.010173287573120287, 0.03435021424065194, 0.0406204600397858, 0.017524881799134518, 0.08440339231803533, 0.010456403984027285, 0.036584471367419734, 0.0330296203854584, 0.031411533521848826, 0.04258451412522024, 0.022987983106905897, 0.01594756900768487, 0.020893807072312604, 0.029705610847280874, 0.05309772257122302, 0.017349681321291194, 0.07367106740392985, 0.044582076896462715, 0.039643081235549146, 0.04511271918853445, 0.03782616199685201, 0.035444946223569494, 0.02195235672256639, 0.007347871038702227, 0.06823232577693078, 0.08808500403838773, 0.027554499158155055, 0.05480359353485608, 0.014105974076946658, 0.03642900914494549, 0.03855039853782904, 0.02998439598858597, 0.05244179809045407, 0.039896472477384155, 0.025856746811299555, 0.02519532756489371, 0.01891432780652277, 0.08731049680781942, 0.06797332677149004, 0.03631330305530179, 0.04297872381885687, 0.027442460714448846, 0.009094358068860827, 0.03796945108220943, 0.04480505061726417, 0.018698988151886774, 0.13398657162343303, 0.04151484853918514, 0.0414544195237179, 0.014576476551742564, 0.0455055920587432, 0.07459205830649984, 0.10616129294278161, 0.03276597888719651, 0.025522353262790752, 0.03142632667966668, 0.10553922188738663, 0.07186507640947258, 0.024503935128450397, 0.02688766367012455, 0.010134254435768292, 0.007539282415828278, 0.04846231223294332, 0.030209675634039507, 0.0691284801089956, 0.02952115028165281, 0.056803730361524134, 0.019621275658268603, 0.017561343753890648, 0.04934456973006168, 0.04268646893662311, 0.01693264220751101, 0.015658369858659083, 0.05655722241968878, 0.03134523244244197, 0.012573366346318397, 0.02249336609947345, 0.10517494707939126, 0.043727344938463746, 0.03306684076725956, 0.015098411296944947, 0.0786877328890466, 0.05284408618125224, 0.10178105500076087, 0.04832817406784143, 0.04690972014120029, 0.044903186480364496, 0.015480847176795286, 0.03835257165314209, 0.0248760202028338, 0.05867406891118135, 0.06781878385452494, 0.023705261654310653, 0.02604240821974893, 0.04159987280746141, 0.010844293452288595, 0.028672290387593453, 0.02580097177997232, 0.031129764468078653, 0.010825848927901638, 0.045827609456835255, 0.0171067452644028, 0.009577424385614935, 0.07358662153203642, 0.02539080255965312, 0.027857594184517383, 0.03640293917288223, 0.05423607943098872, 0.05450487670098102, 0.01902481492218231, 0.016995206693067186, 0.054731600422171824, 0.010168736053240156, 0.01819484101067628, 0.04238550363469028, 0.05377604746289792, 0.007166387682269898, 0.030792658968317895, 0.04107117637871735, 0.0492561785053582, 0.0676025248943798, 0.03886566287086856, 0.06668999160249388, 0.06802935844227191, 0.0707748337017913, 0.048531279298326666, 0.05655985776214831, 0.10706643348619824, 0.22686664255396014, 0.1464830131660546, 0.15700031252157304, 0.26565563534536674, 0.17816580501535248, 0.1622566409529217, 0.13415857368419248, 0.2480739634484053, 0.16604869956931761, 0.10551506713513406, 0.12081559732436173, 0.0945695169690636, 0.21121324460592963, 0.11601317598814927, 0.2523080088318356, 0.1463406740297233, 0.1541940098808658, 0.14671054127956593, 0.10205473225083082, 0.1291106671335236, 0.10575893590407026, 0.17934038634261779, 0.11778577320998716, 0.12146592170240418, 0.11764089066174724, 0.1442318025135225, 0.2693834498284325, 0.22064654487034968, 0.21759671820027215, 0.31179726424236454, 0.13399573403500742, 0.13804596428188587, 0.08627597167487107, 0.11240257295749842, 0.10484522283678094, 0.15613068015344683, 0.13965401347846756, 0.16343607927762693, 0.128797720216455, 0.17841017174143947, 0.12285205820995955, 0.1699271422600554, 0.12345496174548903, 0.13871316557690022, 0.15681675785491545, 0.0870659462206306, 0.13281781256439226, 0.14275041829434135, 0.08719013673403571, 0.1433520424630373, 0.16081150801431748, 0.08399187286774959, 0.17178945603870577, 0.16314528762332856, 0.11768555358773279, 0.10354229879956092, 0.1463587690264948, 0.13682621441060497, 0.12350530138299351, 0.06184980596205401, 0.09740092431104953, 0.12121307438299542, 0.14979367745259117, 0.1383543912802012, 0.21918051305317113, 0.17561514591497762, 0.1307535886524185, 0.17505990070921762, 0.10894364767497587, 0.08439740151046746, 0.10496556758880617, 0.10670428074175313, 0.15915804512558446, 0.27901473785600356, 0.12228167510681576, 0.09328223644725739, 0.2173667998924371, 0.07153628679412989, 0.09264435333710525, 0.24598522472285458, 0.13964572440712683, 0.08283242177698882, 0.13275370632688846, 0.13199432933282468, 0.1291856211760352, 0.08963083157375937, 0.08631779241465753, 0.22199470639949848, 0.1433925685142317, 0.13636450854039964, 0.14539237975353195, 0.1202275941989595, 0.10935718193650247, 0.1402505201798293, 0.20969252943271594, 0.09911336830907291, 0.11620817600839561, 0.10576859627279545, 0.14912710434967472, 0.17315681573123703, 0.17225140705704692, 0.132575866676146, 0.11727389624162067, 0.19905092465060376, 0.19781502564587902, 0.2468752963168006, 0.09535979028911361, 0.2310909432989936, 0.20708499596484248, 0.09344490755709911, 0.17324657059244572, 0.08871078295933624, 0.1819349729245709, 0.08698825724422933, 0.18365154613650617, 0.24262729281138992, 0.06953668239856921, 0.17217662155387864, 0.18391483523432287, 0.10897334124292098, 0.08944644953214353, 0.1816116378552491, 0.12564942060459044, 0.1743606922607268, 0.09487461148490829, 0.25253449506576986, 0.16016422500533445, 0.10003045982410831, 0.169810988008976, 0.12037287511292005, 0.1500907050625932, 0.17621860869469183, 0.17642893047342378, 0.14840996944375578, 0.14563769642864505, 0.19274750724434855, 0.1849969803926445, 0.15255600664644473, 0.16688725941123503, 0.12258557452549859, 0.16883083979689306, 0.11432183771243981, 0.2145607270781071, 0.11223173535038387, 0.10963730198601562, 0.0884152722034243, 0.21942250490669282, 0.18823917174050886, 0.15231346320961753, 0.09607618975062525, 0.13046094306534337, 0.2578771156409095, 0.08759663830841742, 0.12520263046627084, 0.10130915250028334, 0.1520500821812499, 0.09135387056777555, 0.11875815329051788, 0.1256255033395944, 0.11978488730927629, 0.1165158445796659, 0.17394683624227203, 0.08850293564459971, 0.19079660305813437, 0.11493278517117424, 0.16968557941577128, 0.18620528491033664, 0.16720216751338976, 0.20209140504800505, 0.22903036596553944, 0.1261517521174204, 0.10939213852848738, 0.13902116356597793, 0.14849687445788615, 0.14644167506166045], [0.0029608747647744756, 0.004519355678630452, 0.054407614178114364, 0.036389835238937414, 0.03620098307428341, 0.0578213632557421, 0.04320433288211784, 0.005610999369603252, 0.07388557968360764, 0.019741536140622153, 0.05790054227315611, 0.07683154015291123, 0.006318788960455887, 0.12289057711079238, 0.018902288734792702, 0.03735704422597924, 0.06402395199984312, 0.003251608723076061, 0.027432932495890607, 0.025620883661172083, 0.019210279062991182, 0.0699708703905344, 0.02342091279945547, 0.007628969765538651, 0.08622580823758919, 0.047973203397686445, 0.019402534573248798, 0.015612501301802697, 0.05684465094799957, 0.021568740109702753, 0.04468580137097067, 0.05850546061992646, 0.10626855291306012, 0.07591798030320676, 0.03794968218332337, 0.00848543978551583, 0.035916649541186715, 0.08999701394068618, 0.024168051538928866, 0.09276371749658739, 0.04612296316472273, 0.08767770573256478, 0.08835198567999948, 0.06142944585712207, 0.04547262346492179, 0.03581550295254396, 0.04476026511721073, 0.02448367784851261, 0.013428829918285052, 0.03309076186269522, 0.012121413732999036, 0.045158017967497154, 0.06590098998839818, 0.09179841606847702, 0.02330898735371809, 0.031490946196079735, 0.03949962744128801, 0.00983405617936965, 0.07857069763685427, 0.0735753983439457, 0.015072769376509374, 0.011567654737812138, 0.06180557587574567, 0.02409473117891579, 0.059347674701242685, 0.018302248452880213, 0.04074154023621832, 0.042125570001981916, 0.03790605730647522, 0.06655110752270108, 0.048606961124366334, 0.03292067119130685, 0.05375654669478536, 0.04146505282410691, 0.046215985390928485, 0.09040078058117822, 0.07332918534596121, 0.08217524091202406, 0.050524617094666734, 0.05520839056360626, 0.013426433978301865, 0.013064461264518962, 0.020362634264353304, 0.0810315405889865, 0.03322871897609965, 0.03018258101937752, 0.04638993714545523, 0.0978755540845375, 0.0017877390693625316, 0.017920332555208477, 0.036771890947655324, 0.06668215452302849, 0.04349748408722301, 0.04756569058724469, 0.014560706631821251, 0.03397542104545621, 0.052663113230899464, 0.09738675168445034, 0.018037241402893298, 0.006948066509193591, 0.018298881496453, 0.045338987087410305, 0.018220506871359485, 0.07308985181753674, 0.04156500431558779, 0.06316508316705305, 0.04003411932517925, 0.008572046982965643, 0.04576845597776194, 0.057389508001506336, 0.02119919078634872, 0.030169620726918502, 0.058134153124786196, 0.04884800302886194, 0.04235794362161429, 0.035626639296571096, 0.03416956304722736, 0.03920371831965543, 0.05193525309404058, 0.03551803484198547, 0.02091650242706941, 0.03626228159954471, 0.07442106748180044, 0.031953251530085845, 0.030537440606783477, 0.045808664102467804, 0.06815177929257193, 0.05787033159586211, 0.014602131878716812, 0.051639171602625045, 0.05264550469995988, 0.1229344126618197, 0.026862246788016735, 0.03430000866853422, 0.041094522908209793, 0.038751691970373356, 0.01380434993939895, 0.037428872629759774, 0.05508575903912706, 0.028733136920979428, 0.07862801633534894, 0.03370483496016072, 0.053587976707926685, 0.02723560165313463, 0.06897707815252005, 0.04036150699962051, 0.020627612586043054, 0.07605168562863143, 0.02990138461633075, 0.05434336238390496, 0.04745028327189146, 0.05709776639818184, 0.051874272495267854, 0.0350704824461812, 0.04579818785010327, 0.059965084111618425, 0.06039089876257124, 0.023510951113196153, 0.0245690277041567, 0.016373593375206958, 0.05794914289107246, 0.03176372712327829, 0.05521207544652205, 0.02322844086935924, 0.05619005179933964, 0.00541579537844706, 0.0327959367554755, 0.03688729826300856, 0.059413416536464814, 0.04834550680712827, 0.05419151609643333, 0.048223641370573354, 0.05279963009900624, 0.017656804054915425, 0.04158435569655511, 0.05490673578254158, 0.03691459397575067, 0.020667330414477377, 0.031376982956463774, 0.02168877651133845, 0.01556464091634318, 0.01753068108472132, 0.017421571012105674, 0.013509161898025103, 0.030159688396980206, 0.06094674151691218, 0.06162546860474733, 0.03385910208547308, 0.031094771486917333, 0.050003236805599545, 0.07991139746962056, 0.03874789600470855, 0.034905689272789225, 0.011979844515031625, 0.111419758759439, 0.03972800591239526, 0.008609383235565357, 0.026581075282827504, 0.014461607413156139, 0.03147884775253554, 0.05636150993767285, 0.041151707541317716, 0.02217211670452549, 0.02834342224823852, 0.025923145566916755, 0.08835756280008825, 0.0317427535511313, 0.04328920393280926, 0.031400415670847705, 0.10094345276874882, 0.04544196079575247, 0.023747321796573462, 0.017768032360641707, 0.03979203554110662, 0.025389099929241404, 0.08248878537767357, 0.007933288138555063, 0.07521458901464939, 0.013494785300516074, 0.03883738656558337, 0.01071892029065038, 0.037925929627231056, 0.012292107698627779, 0.020782281907515663, 0.03015128249723104, 0.05885295427194046, 0.051239158792961995, 0.034231520408103545, 0.015434676972818712, 0.047086916278086366, 0.02888036178304784, 0.06913925896609022, 0.042391850673142946, 0.047398124175566825, 0.047991938077874725, 0.07485000777148432, 0.023668047018168915, 0.009300108217904645, 0.0659098536256821, 0.044247928496089675, 0.06718796407503468, 0.05408558145826382, 0.04388765649749868, 0.06300012145431773, 0.09447498938008662, 0.06823548205917881, 0.01836009383682282, 0.050864633728539756, 0.10088859321249109, 0.011398884610483244, 0.0069540932271329155, 0.1127000219158588, 0.030293190709104946, 0.1424945908929071, 0.03985103197215546, 0.10584040169393825, 0.036515496641157136, 0.05965702483550676, 0.04241970563006978, 0.035342336406991366, 0.03044264488703301, 0.027779265524699327, 0.013305879509707373, 0.007701565214853374, 0.031026375157037572, 0.014064132269742268, 0.03415445579336055, 0.06698228478912385, 0.047301704349416884, 0.033356406680879094, 0.05926098036129148, 0.02582834218628705, 0.031739168259645664, 0.07486059510659787, 0.030627002030791297, 0.004267763307002644, 0.05316485102558809, 0.04588796569394969, 0.08142327964906731, 0.052954230472565665, 0.03161818190898386, 0.10761801679168018, 0.031061753097380844, 0.06125680028250622, 0.05665303703637854, 0.012122173117653979, 0.02049703672978907, 0.025470960254390395, 0.022406710063918464, 0.033286052996352795, 0.027433790514365803, 0.04321890004399804, 0.03815221667830502, 0.045655151573760856, 0.03919148389550467, 0.06410060675754663, 0.03324396029535321, 0.038771729000032916, 0.03961091320360861, 0.028619031955097473, 0.025464268476371805, 0.019550265053347237, 0.07050228260097004, 0.020064746720656272, 0.026756277675890637, 0.013781583721509144, 0.12663881549791944, 0.023305587838554097, 0.013921995189100986, 0.013406956192827033, 0.031152002085300706, 0.011066976059678824, 0.05094729844600924, 0.023788847592509082, 0.07804490851178285, 0.046130080121539296, 0.04924145812589315, 0.0069511519283086305, 0.053284678668264425, 0.05711007360068541, 0.04281849269905398, 0.029201287505847794, 0.011745435016740476, 0.026637348271305525, 0.050602053262053, 0.02364333493695144, 0.0296013462807863, 0.06578797669780832, 0.014906280275975025, 0.03232578859634457, 0.0793170358144468, 0.024421906263958064, 0.09309924102478451, 0.0028643402648383695, 0.03279487955414, 0.11731765518385558, 0.03287153048140388, 0.005838418315585342, 0.08593293282413676, 0.025638371533263597, 0.01854917008219467, 0.10456513343078476, 0.06027583235634431, 0.05169935930039614, 0.04102211993848605, 0.05771824399069433, 0.02459760278373236, 0.033427806075422034, 0.07731349372695531, 0.01990718733248932, 0.019310567633158738, 0.024711633056041696, 0.08481963086993465, 0.14721574562211193, 0.16279290249991804, 0.14660517354646038, 0.11073332099664597, 0.12356637391231715, 0.14349255831010882, 0.08268078233325675, 0.1335299525770449, 0.20835011356299926, 0.251398294743511, 0.18305177590058697, 0.17215144790468678, 0.16467154927311406, 0.20029276849762087, 0.10459408389344331, 0.15705133397733012, 0.061521391729794206, 0.2183511156228281, 0.13709595396874413, 0.13505273618765418, 0.20885784599569537, 0.08572513913555492, 0.09818792643566286, 0.14289936110857995, 0.10535777396252079, 0.09433979784408886, 0.10472163753283602, 0.1297282872180785, 0.19368648589138063, 0.20322778923136575, 0.22067204027646975, 0.17137152443249382, 0.27690333824965263, 0.11704281348014071, 0.13503372188537352, 0.11855800515942036, 0.15055446404843562, 0.09287150606753365, 0.2624188219347308, 0.14391009155060017, 0.16723668743525782, 0.1555169058302718, 0.1386944423880308, 0.13795443209669284, 0.07020880963893668, 0.08554483268169627, 0.1419505612143586, 0.06628161311269769, 0.11042568306889265, 0.21230419977538048, 0.09129670508686574, 0.2435547648177993, 0.16832270899847632, 0.12460381017937777, 0.21059700347963842, 0.10936617580873352, 0.09107655440006526, 0.16046194209446832, 0.19434231844159866, 0.11784526759818678, 0.06559648536025517, 0.21117354592969342, 0.0801145563262605, 0.10608980161768776, 0.1017517444767779, 0.19674625638271534, 0.14158974912378097, 0.19052148556276677, 0.1344717044623629, 0.13387400266383925, 0.1335465460414848, 0.20585827469345064, 0.1568772788009336, 0.14486368715522752, 0.22067340391297496, 0.2453613840043545, 0.15363090461300266, 0.25142081772848485, 0.13557477914277585, 0.11777880947075545, 0.18485435014290197, 0.18413018254983812, 0.15776086929104022, 0.14269610266050986, 0.11298920478551619, 0.177367250284841, 0.2975046989177504, 0.09423712674047678, 0.15333939283605547, 0.21584757092979648, 0.12228357500486797, 0.12068766064100689, 0.10634608867187655, 0.15971502169005333, 0.251674622657799, 0.16000011365019506, 0.3007858534974437, 0.1784985170008675, 0.13186119857334322, 0.20253423451175614, 0.13106265916459023, 0.27122350109200327, 0.1524322221596395, 0.14128599526180377, 0.1485586824316171, 0.16235103830695152, 0.14390552566657144, 0.18159668381896713, 0.12727112148798284, 0.1576950929818615, 0.12587077404943206, 0.12237772721076205, 0.14119837012502456, 0.11973354409659102, 0.12633792680477904, 0.14075319643222517, 0.12699850143924837, 0.15551797835336578, 0.17754734223408086, 0.09880280392544885, 0.17307706597831943, 0.113685731926272, 0.12507795731747343, 0.09440846230474212, 0.12598797784096774, 0.18593697027573663, 0.13070491142570972, 0.14940642000686738, 0.11765130945751745, 0.1816876184555792, 0.3002344540530636, 0.11831288000628834, 0.08722707749374452, 0.10637927560075637, 0.18259213846777717, 0.09217877872288228, 0.1714433068709989, 0.18192153574237901, 0.0951190548197877, 0.2087165180954241, 0.09908771202448877, 0.1587727948302223, 0.1624849198325988, 0.13506425815003534, 0.1373863472573219, 0.08880055314230342, 0.18980356924716504, 0.1682734189014281, 0.14898611352809016, 0.09542781889678971, 0.14438050017962534, 0.10830700562726106, 0.23211852767534796, 0.17146368480978474, 0.22691996227349007, 0.20002748757120103, 0.11341853578004146, 0.20473218673179228, 0.189134988993887, 0.11750056633665679, 0.10632017957827739, 0.23428215915637635, 0.1446635237023715, 0.13242632631332646, 0.2046385554656867, 0.09581873824279155, 0.16531100286351097, 0.18876484595239165, 0.1167594452178286, 0.13119752128278056, 0.1130893937642536, 0.13763806842748197, 0.06327138169698658, 0.07430925694925171, 0.24310170041937984], [0.07442538055681414, 0.044053537515743126, 0.022089999739921862, 0.018076131856369398, 0.033305576747103084, 0.02693378024794642, 0.016577510658891934, 0.017220342697034922, 0.08579989399520621, 0.02164168125619331, 0.018583954304396626, 0.04204940554054995, 0.08241695697389304, 0.06771761428324446, 0.05043449068081476, 0.04095231400682561, 0.012185195340744913, 0.056474527058702324, 0.05051556959628098, 0.08763576241871042, 0.025141634377500704, 0.0489752272504472, 0.048262880394055, 0.035308705147115454, 0.05265141889873532, 0.005902258337535445, 0.051291528563465805, 0.010613931771067363, 0.05919152299963659, 0.03365018224764255, 0.04418893589548046, 0.020580842918265733, 0.08526867330675164, 0.04310146642608508, 0.04003368648550203, 0.029258811132862206, 0.003987383745205139, 0.04942254598943457, 0.034662176734737815, 0.03486107614251875, 0.003791054801812636, 0.05440457663949459, 0.09195780832200282, 0.03888971803169097, 0.018712940528207732, 0.01129900493974527, 0.025565761719800295, 0.09281938910604486, 0.03155508882275993, 0.021182149160473097, 0.0616329264706902, 0.04255940942394157, 0.031561853379131324, 0.078751448421709, 0.055128648471567905, 0.025743597540103143, 0.03453217161398742, 0.06333207118234808, 0.05987041479637546, 0.06254229198900924, 0.0331555997141667, 0.011300141622702922, 0.0409815019567407, 0.01688726681975588, 0.058986130996697375, 0.01244576674165024, 0.023019229918117487, 0.043082321888857314, 0.029001053189858798, 0.012592376818159416, 0.007676170836578334, 0.07460308997260948, 0.024410623704053225, 0.028166584257457047, 0.055177869620702924, 0.01598930739301948, 0.009721728537472026, 0.012601608177646996, 0.10284918075006816, 0.09551568918170468, 0.048109272104357524, 0.029518593463205525, 0.04099025834171523, 0.09042148793777151, 0.020297300370950854, 0.01691420438639339, 0.016730090475551063, 0.02017907002159665, 0.04219971199129378, 0.041088639352951324, 0.039051105944259513, 0.011238292471746044, 0.0718192260472044, 0.08928653633882923, 0.00835483424335478, 0.03574683466145108, 0.03188620734539244, 0.038031553999791225, 0.017384490441350688, 0.013083668046390579, 0.04363755943373807, 0.05084559644362138, 0.0237534141107913, 0.04572783416557697, 0.04421793232341448, 0.042583020253767895, 0.025989542407314145, 0.05209702022013165, 0.029084575925803477, 0.03000840518413292, 0.04927999234848446, 0.020473500593535362, 0.043713467255715406, 0.04991382285351715, 0.031970967313334826, 0.006660121350338864, 0.045668818582330024, 0.041953001036158497, 0.042349685193790544, 0.025444354020780133, 0.05371331252277859, 0.016093538443167365, 0.012016113032586874, 0.03736560908897269, 0.01563782338052988, 0.032137101140594294, 0.020805410101949688, 0.0375174860199613, 0.05486000058872085, 0.04474814560624861, 0.022155098061287598, 0.0349354288060098, 0.04838511738325319, 0.01703217235063353, 0.02818707902465136, 0.06172336698059113, 0.08218552181196791, 0.03444611695745299, 0.06242147609291058, 0.029938390493513118, 0.02960054763412524, 0.03199952898637182, 0.045803397247988376, 0.03670249104259476, 0.04045533361814676, 0.012388046804605233, 0.010881449674226103, 0.02737754050852551, 0.08251135432792288, 0.03244034172366223, 0.028517757046727404, 0.03438907788105069, 0.07116071985013063, 0.06339895448857738, 0.02943978025277536, 0.09303724152907249, 0.07543213500250733, 0.021651176916014765, 0.037120775049251896, 0.017092361963624438, 0.03963982536187095, 0.007095102243305695, 0.01174584391617006, 0.05833833853924467, 0.04707346760457562, 0.045242678344009385, 0.022669911061623887, 0.007208098775722207, 0.02772445384893687, 0.04141429566868371, 0.020045548557273803, 0.06813825017982914, 0.0790237007482398, 0.07592734189764147, 0.0546234249768238, 0.016797308945247245, 0.03519766453293062, 0.05731248169115955, 0.06794448356114088, 0.014020852132460043, 0.06115335926053025, 0.05866723923733639, 0.025048575762118545, 0.006032465992780824, 0.04649025635913976, 0.04171733323845171, 0.026496788374178355, 0.03270573756327072, 0.07603153751622285, 0.08070059060569733, 0.0512161799856732, 0.013207840365207484, 0.025636875746591438, 0.025403155727432142, 0.046094418728664044, 0.060273193183445165, 0.01657345805377249, 0.03173508118056963, 0.012940063907374299, 0.07586951758111678, 0.03174516098243335, 0.062402239625131896, 0.02794294404016147, 0.04333417712440414, 0.02765507692651403, 0.04632383907934831, 0.02377802468535881, 0.026258441183956403, 0.04491799495994084, 0.025952339262491273, 0.05279945772922328, 0.003690878032601529, 0.0530920994858588, 0.05346749789051471, 0.07053691743602676, 0.052723132389327215, 0.028331697272557407, 0.01629923305083667, 0.08390179624961269, 0.04863863886003533, 0.016593629148818793, 0.03276078481106989, 0.04864426194539955, 0.05014494391939333, 0.01988350946996962, 0.03503521941902657, 0.041751684620976455, 0.05363226808126896, 0.041957643528979634, 0.036523578868758295, 0.07162249466824917, 0.04784349705122652, 0.03430063303019251, 0.02169559852430417, 0.04385545782204117, 0.060751492518090436, 0.015589945758092067, 0.07401428245488675, 0.03861186560243368, 0.009057453698328426, 0.05174186951931446, 0.02781350773969485, 0.021053649402493914, 0.01747258097654389, 0.009044129514105378, 0.049057558719669624, 0.04071092353232446, 0.08046599150064492, 0.019961637031707554, 0.016424306480574514, 0.11090480977849615, 0.00870660170837636, 0.016594550369547743, 0.03343682676073044, 0.048474224900165876, 0.018610443709598436, 0.07789584312347636, 0.04023847710942069, 0.039459802360544284, 0.04547315589602917, 0.015402081846860389, 0.0424123167120401, 0.023011028946888064, 0.003282548859715462, 0.05057707496528184, 0.010511441655727405, 0.0021033511344989344, 0.024508219475166935, 0.030347441225462866, 0.015249772076194566, 0.00953917361555561, 0.014906239098749094, 0.05421026226794047, 0.01901371813859911, 0.021850570450506864, 0.010690945632485373, 0.04484316349149712, 0.01502318625083013, 0.0795130470707532, 0.031076255141787475, 0.02696657647198487, 0.0326520424606579, 0.009229945097749513, 0.02146772184078732, 0.04753624982831459, 0.011495817715542452, 0.019273600060372584, 0.041301948874587976, 0.08090782505009445, 0.05367529923997579, 0.012049974118840071, 0.03404767845847434, 0.04660186770882818, 0.060143594089294636, 0.02697393283127777, 0.05519575011285563, 0.005610454010762154, 0.09623264788740105, 0.07584243637299345, 0.03346147947013378, 0.09873924927125055, 0.016203420349366723, 0.029111647557827736, 0.08647072654698165, 0.040458915079192775, 0.07642768158186829, 0.03215079879268043, 0.020450316857726827, 0.057195538369518135, 0.03113748088869597, 0.03701469485437678, 0.07242288034889968, 0.08324540445520993, 0.07022681270515727, 0.036626567898858944, 0.028256306559928966, 0.01568407115090879, 0.01612684028523584, 0.08406904090436236, 0.008086177742018575, 0.07679761777962409, 0.06675745330510602, 0.020047906192860777, 0.018466361723239386, 0.010281653582839476, 0.042149805193466526, 0.052898359680247885, 0.08839931459196153, 0.1084481496664305, 0.03816548915159318, 0.01109605675728451, 0.076496928269344, 0.06287461326968286, 0.06147213227626297, 0.03683073416111931, 0.03252407896422571, 0.033296421996407935, 0.04444141166224595, 0.023600301863024795, 0.030212360772214113, 0.03194881396578445, 0.016013543542113998, 0.025951163317527504, 0.05770579506192477, 0.016647146135989218, 0.11639045130821968, 0.05505636807591204, 0.015283907038880693, 0.040343404341969764, 0.006612794832401579, 0.046397015797875585, 0.04099898025273316, 0.20160631817435065, 0.1418048819346774, 0.13247659700291772, 0.1154448000353671, 0.16883342917407715, 0.14635120007780292, 0.19584565874068968, 0.10345079725788486, 0.15550202840278227, 0.12492333013083666, 0.10841164557683854, 0.18279519773298697, 0.22858261821731446, 0.16424321419289037, 0.1632846390167552, 0.09475808951162523, 0.09192876592879334, 0.14071179704079706, 0.1269606183913927, 0.13025514120536466, 0.168079215612623, 0.14401273201069525, 0.18993003504170528, 0.1299126999032113, 0.10158012545998059, 0.261636033293701, 0.3235419437048897, 0.14273253780218864, 0.09333370223401055, 0.121578460018481, 0.20597122669700654, 0.14887299298519088, 0.14821172121071047, 0.10041593994584777, 0.1488216804160226, 0.10659219441755165, 0.08100904058665037, 0.14492851351538014, 0.1667954973996647, 0.1348715870370788, 0.08576224077372782, 0.13451201600893853, 0.2069163340474329, 0.12165959639054154, 0.14303667470812798, 0.16020213103582784, 0.11709180480289845, 0.20542843808089534, 0.06367124894994401, 0.09893403478687811, 0.1636786533579711, 0.28437502441867707, 0.1912971036208253, 0.1379076394462778, 0.1731176686383063, 0.15223665523432917, 0.10025439498525474, 0.16423186076985252, 0.1282631057584959, 0.17758324111421264, 0.10582871885309297, 0.13041117799378213, 0.1363942480736202, 0.17914986027584923, 0.11814434832382588, 0.09375024722107957, 0.12593059019455988, 0.11454188114693088, 0.13915362016808602, 0.13400802208531287, 0.15919786637588856, 0.12515967591635643, 0.17150640187244262, 0.13920919218611333, 0.16358925089720758, 0.11082542774778222, 0.1141183800815094, 0.21455044617816327, 0.18175580028084018, 0.1690401350178065, 0.15362730399975855, 0.1027880316119521, 0.1789990328853169, 0.2745764840754771, 0.07796642280394032, 0.09164303811567445, 0.08292025375750758, 0.12795190552189467, 0.13112981443203267, 0.127937434121005, 0.11642473374283123, 0.09502125603537406, 0.1747556259074519, 0.26275020092725754, 0.13372518242366854, 0.15224508220149627, 0.1401565058697616, 0.09884862364420006, 0.14155996362528495, 0.1067098961662381, 0.15176414752439146, 0.06296568580212132, 0.17447459421330885, 0.1622316051995562, 0.13701513169273255, 0.1337776900899987, 0.08050989599958544, 0.13695890083909035, 0.12800216088972746, 0.09355744587317591, 0.11775849281900352, 0.12274442285659815, 0.1922036920704188, 0.15307234990740978, 0.12164317146544495, 0.10205140742923945, 0.10761240902807444, 0.1449285441588971, 0.08457291991479936, 0.18939513713121417, 0.0960221499084465, 0.1626067278125594, 0.12888762829524855, 0.10598512336371407, 0.18844839035262986, 0.11028810899945037, 0.1689478214229307, 0.13488992718198609, 0.13255646932990323, 0.16218429160935266, 0.12590898651509516, 0.11421450113336887, 0.1705614017743257, 0.16231372982503908, 0.15723922470163915, 0.1905546724916466, 0.17682110620362146, 0.19356403439756364, 0.1423853927201802, 0.1434584214322029, 0.13116807286297122, 0.08111764887167562, 0.18313621411160116, 0.124988715735174, 0.16887427698219978, 0.17599691817116353, 0.19047170516944703, 0.10379268697673276, 0.13946184798354103, 0.1453085390910987, 0.20160565933873578, 0.1705603292512317, 0.17878423715310712, 0.1801277408676763, 0.11251515723885068, 0.25425771792088786, 0.2233064787522439, 0.09615420048395473, 0.20472202840591633, 0.07961438518137702, 0.1157748460349056, 0.14282236927218978, 0.14069341093061433, 0.23436403863372343, 0.16995122806439478, 0.15876954661742335, 0.09395928197209874, 0.24207463698281398, 0.09265713168368225, 0.3733486598057132, 0.2834195902030314, 0.17735677020203683, 0.16202738148070153, 0.1318978635413993, 0.15044667547748936, 0.14359142961761645], [0.03838550194256729, 0.0314312698619981, 0.0278178476277859, 0.10141911676093456, 0.06103494121963459, 0.052399104010433926, 0.05928316243713903, 0.10047178009464856, 0.031691326068774346, 0.017943820810966918, 0.04555646412735505, 0.04232220561994661, 0.10053347315519087, 0.05531657750027315, 0.044493984446049704, 0.023849835852161053, 0.03856053388106727, 0.05850202088514644, 0.04688158556218109, 0.033194490167642796, 0.009618873572758129, 0.015282428489186832, 0.011761229834519328, 0.06720255038911296, 0.034662804926835725, 0.025302727346218405, 0.04841397974580046, 0.03738835423944458, 0.04784762243469877, 0.028210371927989107, 0.013114514576661731, 0.044137125369161374, 0.06660377606749535, 0.03552927718227429, 0.014408002325874424, 0.024564281789465778, 0.020037146487964258, 0.03522926182936757, 0.0064138513745649935, 0.05631376733823169, 0.055560450099648974, 0.02954515564676014, 0.09118506309366034, 0.029638348327529047, 0.019014940048838337, 0.026249071928642453, 0.07663742879465704, 0.01800889998013454, 0.07521170086317486, 0.03576540846317526, 0.028773682124371973, 0.01306851099680869, 0.05988145412336435, 0.025712883159998926, 0.010861643428553738, 0.008744518272578716, 0.02316255539265131, 0.04534544903905161, 0.08751928641070282, 0.048095700856778896, 0.01989288064050338, 0.026208109207331177, 0.03339424376345931, 0.03693802477491479, 0.06930387593925962, 0.007737583796223326, 0.058307017034460465, 0.034140635567206534, 0.05503929580651945, 0.03807021462689004, 0.018575487117613518, 0.042680868833896615, 0.025861373982362212, 0.044178214494980154, 0.05845337813239425, 0.02941790461209753, 0.03916993384219466, 0.02423203711758458, 0.017868112171849897, 0.03335840617036147, 0.024015716870405504, 0.0328603839021056, 0.04617925913583848, 0.007108277040383509, 0.043745673592052156, 0.007927402668076778, 0.007980692701699633, 0.020611490265676574, 0.051535274758334124, 0.04402395886098666, 0.013569225106508502, 0.06731939411932422, 0.06699869439246194, 0.015423193314833748, 0.04639295170143728, 0.014013927655234454, 0.01715401480455072, 0.030570845870721727, 0.0592545758662445, 0.03964724492341761, 0.08487564721895803, 0.02439343460625218, 0.06573474124795006, 0.022790610129314087, 0.060851834714412696, 0.0315757904336938, 0.03424708731472492, 0.0664797387716751, 0.02040242104070081, 0.035760417400348576, 0.03750128326036277, 0.11244961075604924, 0.02497066270499941, 0.028203168786281062, 0.013113645066867673, 0.006168404943309725, 0.048771689180284745, 0.0558592856771523, 0.007584354241243414, 0.04663302833514829, 0.037647100435870315, 0.01787981224967347, 0.04683447115483784, 0.034227808712110404, 0.021808948893580708, 0.17382554920209994, 0.08424088208665771, 0.05618032248270127, 0.04019548808554969, 0.04842908316922765, 0.0031506057759191123, 0.001964698197797031, 0.0878998329262099, 0.014922748293517338, 0.03983965939691952, 0.028720209187257196, 0.033306522865689574, 0.02011005316049822, 0.020921585420447013, 0.08599593589502959, 0.019840041641145945, 0.01406805176708487, 0.033331581601692785, 0.0745997651510181, 0.05275978586606441, 0.02536799420692748, 0.10424774320375535, 0.06974123553523133, 0.015178694438579825, 0.016822111041795824, 0.09323018077280253, 0.004119615787790428, 0.024897252329655235, 0.006591785828688092, 0.035551083875038934, 0.05588853108366171, 0.016758569794136192, 0.025183095055962765, 0.011083638472031924, 0.06459011395852413, 0.08908353836065339, 0.033242332358514114, 0.02828816624147998, 0.033160169428635033, 0.03220092775600572, 0.03742186292525261, 0.03489373447073083, 0.08829563991316865, 0.041598704523376884, 0.032340413214819085, 0.06116086309174858, 0.07575930817232979, 0.07401620533557669, 0.03835843222576284, 0.12707122616590033, 0.08275558315818349, 0.07090508397067748, 0.10968155122452206, 0.01328015715003975, 0.07105820962498266, 0.047409738068498915, 0.14068323728297988, 0.07121035468674476, 0.046285082691258965, 0.026693726596873135, 0.047286830752366976, 0.04197084705435461, 0.0658887172598512, 0.037657274083504756, 0.032997996275944096, 0.04234338795105296, 0.02764421188452792, 0.013430989328621617, 0.04555525370843468, 0.08864952656891077, 0.028349095129317818, 0.019478762236934517, 0.05253426107247511, 0.051542318936797886, 0.03821219370189694, 0.01051251800926102, 0.04425186618802048, 0.04744763643811307, 0.031922265188768506, 0.06106814730071253, 0.06595193483536282, 0.053835388633512685, 0.07352425431412074, 0.028914977465906454, 0.031617182164242676, 0.04238076538087861, 0.0030237442490855053, 0.06498153126167674, 0.06349114933982491, 0.0028930671255840293, 0.07934538872852441, 0.03301030347844766, 0.006254104805374218, 0.02941153459100714, 0.022753272919104468, 0.03796611859973881, 0.04417307021456861, 0.010385796532876069, 0.027260794454524596, 0.06726802026312198, 0.020088284772129792, 0.0445914346604578, 0.040451192912916024, 0.013491180856832334, 0.06642542313784361, 0.026320699234342864, 0.023095371396911722, 0.016510703961455053, 0.07345139935252167, 0.006466977656894034, 0.021890958605874932, 0.015704674128022407, 0.04354898817837239, 0.059895515667214516, 0.052561269502245614, 0.013021278803447082, 0.03917143537452625, 0.07695739307711202, 0.038137423520487164, 0.05659000332196874, 0.012471112760625059, 0.027526636540348974, 0.04177555975113665, 0.0560904833518209, 0.05196110856148505, 0.02968153461904055, 0.03203273889788937, 0.09386493824422361, 0.0413863564420852, 0.016043653670367936, 0.04363082169044403, 0.03593764418075162, 0.018472074823934707, 0.03392350709726734, 0.07124501250443921, 0.01282182781236066, 0.008998369167168296, 0.030407491027407592, 0.011764091172916515, 0.11290567055825265, 0.0889340439631093, 0.059177346542597785, 0.03363352749616869, 0.03927235213679172, 0.0431903479470601, 0.03374239242064857, 0.026425837141071117, 0.04952659222087072, 0.011266640597774137, 0.03198738074711254, 0.0385530223889697, 0.010667514833321255, 0.04269505678225429, 0.03501537391134808, 0.09457122534513475, 0.0419633815275325, 0.012820902761192092, 0.019291486298184723, 0.0054068355013676475, 0.02362531080331293, 0.07121102884411812, 0.09736010714644387, 0.06378530795055051, 0.03933127578948775, 0.023263903079374183, 0.019557060253235604, 0.027201229203191978, 0.10067166775585183, 0.03239253783718713, 0.024965154532823833, 0.049297129735350616, 0.03427853905445626, 0.003066358847483512, 0.028788354623341755, 0.03607013525681631, 0.008060246623391587, 0.09663280625376972, 0.04206440937254698, 0.05807966129073213, 0.011600517994543959, 0.13844469772471538, 0.040312661233568386, 0.022715974013291063, 0.08122687768791953, 0.0640425258015673, 0.044156453767490965, 0.02005004740860914, 0.018582588752671596, 0.041897337087580276, 0.03185575535040229, 0.0491800255352451, 0.022050827749133594, 0.024103918488347725, 0.06997383515080137, 0.04041490332794286, 0.045889792813649105, 0.04100597846592146, 0.11347056847185859, 0.06757463163305676, 0.03154182784079063, 0.03425925662140212, 0.024967150191866586, 0.03944005261385634, 0.023329981993282997, 0.021368660926518422, 0.03291238211996613, 0.0178927035942193, 0.06264574067186444, 0.05926105313964429, 0.043836596737345385, 0.02063467783192473, 0.025225189672182166, 0.019263391938781547, 0.061015536212512565, 0.040448511605181044, 0.01016463652523535, 0.0278780180885787, 0.0650940772386328, 0.051389289043483236, 0.04495676666978867, 0.02999054192895851, 0.049426544968399315, 0.06543927645731358, 0.08652419182321719, 0.00981407564869451, 0.04362961893240291, 0.036349968023357854, 0.1297374496296529, 0.21577306121828096, 0.10116211724497619, 0.14064225157903087, 0.1936905614791378, 0.29436704792803337, 0.21219146227644337, 0.21436627864116625, 0.10300348617977674, 0.10619801919787161, 0.15139660918183867, 0.13115930881711746, 0.1452490293811406, 0.07798491616643245, 0.11896766301605011, 0.13167344574486056, 0.1047815379476355, 0.17023438948296732, 0.13968968253222205, 0.06684337772669331, 0.09204017043474222, 0.22706435452545845, 0.18138184212148192, 0.15252671144422025, 0.08291659951810876, 0.08548173768025252, 0.20645832072102255, 0.10492989853505166, 0.14482288531238033, 0.1666794657226532, 0.07531013550056566, 0.17543759737764636, 0.1824944775791899, 0.0676447439998869, 0.15381844293686653, 0.16624428181638642, 0.20710473038977195, 0.1260312464869311, 0.09353059449142988, 0.11950558697384213, 0.13460336433302972, 0.13075230162470572, 0.24228129686126787, 0.19292042861061712, 0.088421446872094, 0.09519693531817007, 0.14131057136241468, 0.20964339255325257, 0.2275944107602681, 0.07405038817875809, 0.09965464773197329, 0.18512919184661683, 0.15943831073180323, 0.17434416008332085, 0.17287238260671017, 0.09882709657352778, 0.14747152705827068, 0.14236158270749355, 0.12661154276781506, 0.18654440139089862, 0.18180073899847848, 0.14743187434730992, 0.1324315969982455, 0.09257269347266806, 0.24494343707638405, 0.11689155708037077, 0.24257948892491482, 0.22092894020099796, 0.0964403726280697, 0.09712375370004485, 0.12325006386926099, 0.14393659819278026, 0.14523117953250486, 0.139525234098396, 0.18251102507835437, 0.0885250909073699, 0.1821155398483238, 0.14126794623030772, 0.06579156198929395, 0.12379263031987414, 0.1860740387271489, 0.0943112074427547, 0.1405172260297883, 0.1375985229688306, 0.11604568109877648, 0.08930837750555047, 0.0782559427522844, 0.12153738238398107, 0.21498484867474726, 0.16109359690979605, 0.2071784433698462, 0.13898549451222345, 0.2355914953495226, 0.08474276160761234, 0.15074001054369635, 0.1358384512845547, 0.12387702256561288, 0.08498192659669346, 0.0806397862071472, 0.1619082701302344, 0.17435951248532341, 0.18342637757380165, 0.2237222653122679, 0.2266050694930938, 0.12554749260626494, 0.18310938571249286, 0.11106659988722495, 0.1479674464151744, 0.08840632429646869, 0.1875390899517844, 0.18566068832672414, 0.16340661553605912, 0.0698139985662795, 0.17156430279775975, 0.0585942923451864, 0.1029920791305842, 0.15020833020248722, 0.1453698874120751, 0.11715191206143749, 0.13750944226499529, 0.08489816254305263, 0.06269963112689796, 0.16542208561253163, 0.16225962869582639, 0.09463730808948317, 0.3457072269051306, 0.1966533452392586, 0.15378999043135874, 0.1776949520553312, 0.24021609235675107, 0.10092271476863854, 0.0868343348584829, 0.20675838203920474, 0.1510899441857492, 0.11381762928419537, 0.17908745475353735, 0.20137806993819055, 0.09643582972667872, 0.11997169018873285, 0.1512692240817893, 0.17380140211072662, 0.05872378035658791, 0.12294515321451811, 0.1376062911003828, 0.1525752201315857, 0.13973086741903137, 0.2319787013074083, 0.1249348444323386, 0.08334464348492124, 0.1377050091903056, 0.15364284026286296, 0.08071013606123387, 0.19369642971263779, 0.0827246944930765, 0.10787558321270252, 0.1219784498455063, 0.12326015324722375, 0.1682024331943643, 0.1942980845248507, 0.1330384612083435, 0.2029119311801849, 0.10195900190381274, 0.10571058809516892, 0.1287348090761131, 0.09908100875515131, 0.18377070345224875, 0.10194210200420312, 0.1975827477872372, 0.11695631449261021, 0.1193213658106904, 0.09378698879792806, 0.18274034583760848, 0.16721784167232054, 0.11025930409349742, 0.1776104219137661, 0.25479595597472887], [0.01094820753355781, 0.043632920771356554, 0.06680928681406283, 0.05382725277975683, 0.03442321475895663, 0.029605642118821704, 0.06398438355855404, 0.05355049968667088, 0.025359188026237874, 0.009098905758301338, 0.04421166955463348, 0.06558866360254827, 0.024216341891235883, 0.06467206238378441, 0.0569757707266798, 0.03245088692393995, 0.030014600920220538, 0.022151815374532056, 0.02360988370773773, 0.03593800424207603, 0.061607932852160555, 0.04511991275414344, 0.07468431061434169, 0.02050432797160841, 0.13625940127718833, 0.07027531373164347, 0.037290735485693144, 0.06623377858270561, 0.04924705822861964, 0.06599701910970673, 0.006390830911245318, 0.09570128164224087, 0.03336687910280401, 0.03717660753717346, 0.08017037349242358, 0.037605065191465045, 0.07287793657592229, 0.03805752438042433, 0.07168085524632085, 0.029217997798696164, 0.010071841252577162, 0.044404919063972856, 0.011085597741898271, 0.02517688782855628, 0.13866127078090945, 0.05999660862970257, 0.04480470587769824, 0.028736837125653704, 0.0770848701077123, 0.01831066584394824, 0.019350408035660946, 0.048488259630938696, 0.01965497969649732, 0.025696684230840015, 0.047244895099391865, 0.04976358152024689, 0.06311100885091771, 0.04054209690601115, 0.11477549199856098, 0.05946865913668468, 0.01587343180642253, 0.06920574007615929, 0.012328567738164098, 0.04060991483950808, 0.01504623400603211, 0.017806369315592513, 0.027493208293772997, 0.035684616830680645, 0.03243867931286654, 0.03270412877862973, 0.02547612751743967, 0.00792897793637108, 0.017522194745740103, 0.034618751040749976, 0.035251229400596315, 0.02629530725009259, 0.027345849366317836, 0.02702017389838734, 0.02350433019831056, 0.014795736661331068, 0.049459356514196244, 0.00977180578986243, 0.010800214668345309, 0.023069213324737166, 0.0434004245776563, 0.01838508745535247, 0.1044540889861603, 0.031478677297972386, 0.08867449337436308, 0.0128733970209836, 0.019897670605249947, 0.014750283707173602, 0.008634317482280876, 0.0761337566279596, 0.05811677825066352, 0.04618207450896021, 0.029267107865082163, 0.035268033539215406, 0.03100665222342697, 0.07263373072829939, 0.041652549013134935, 0.04071005019209078, 0.025463284053389105, 0.02397109990969541, 0.0678502777290921, 0.029832986371231177, 0.023756911302165642, 0.03919259089255526, 0.05223931722162713, 0.01483727107575584, 0.022139113636747487, 0.06733303814525567, 0.05357461996496685, 0.004102281612088724, 0.01702146052623228, 0.030233290294305454, 0.047268846838344494, 0.022647186978569916, 0.018388596138045676, 0.006586370065868382, 0.04108947438878879, 0.037901843822891676, 0.07225517604139543, 0.044362948937041145, 0.014317809836938979, 0.029759292543355017, 0.05716994337196793, 0.029198091003983736, 0.028645228331668243, 0.02683126427713902, 0.07653673419788962, 0.06453976666014041, 0.03676957353168438, 0.02767193660650763, 0.02911285414630848, 0.037428294233376944, 0.013453285360047895, 0.004004400233820742, 0.04620473538976043, 0.020910128575539397, 0.014231218918857556, 0.042436076929011655, 0.04305371233532506, 0.021463177024176525, 0.06514668449639313, 0.02595287169359865, 0.04525492042903939, 0.05580625707103361, 0.03454095098159967, 0.02040848079618187, 0.028044986951675628, 0.0411750425794913, 0.024300448769222827, 0.05875874077901245, 0.04236399571621611, 0.04592779843557266, 0.029528814991335237, 0.054248869268884586, 0.01693725597203499, 0.023209880474173737, 0.016611513471411123, 0.01119605038360122, 0.05835527291281089, 0.040775301731041366, 0.04443059833119473, 0.02886647835464007, 0.06850606431403468, 0.04422231434634136, 0.0388156296685338, 0.10722968682286241, 0.049159685900855454, 0.013133551861580103, 0.027445643809774233, 0.012262485951425569, 0.04039529147708128, 0.06514741994080044, 0.03107627429398558, 0.02348053933782203, 0.07568766362965107, 0.035260690586461176, 0.02587988649705245, 0.007474904217111368, 0.04984420844383779, 0.004641109553631395, 0.07912215836826833, 0.0433750823891211, 0.02028575925637157, 0.038434420486972216, 0.047617244474109144, 0.038675324495641455, 0.1069199727968343, 0.04829453514708627, 0.036475062520513614, 0.03464054241175613, 0.03919865830891556, 0.05206043186086801, 0.01762633099250736, 0.09703547738853002, 0.02934065613625271, 0.0647713014134957, 0.03517295819737258, 0.03726072782169908, 0.023214515306115634, 0.0119474102675374, 0.030088892296677636, 0.018110490899773377, 0.08592904109748141, 0.039448360837395155, 0.0153893944732244, 0.041424499959835125, 0.035830943454657836, 0.03881778237560103, 0.024214817376266566, 0.04672423110253388, 0.030383297970758814, 0.07257844982368332, 0.029584362111505003, 0.055886757590117, 0.03895143024443139, 0.023314139295008876, 0.0897808009458165, 0.07081001245927426, 0.03436320326140812, 0.09656329909639974, 0.0659276804916801, 0.027194125652914087, 0.027970867945001494, 0.06096369887311613, 0.030528590376038226, 0.04645801554884642, 0.02130473280445703, 0.037908719462012096, 0.044534089148885785, 0.06357523898083357, 0.050004232719901114, 0.05162163201959864, 0.009216439925254354, 0.06587086741121546, 0.010535250710804137, 0.020090259363754623, 0.06901814812614072, 0.04261453328053317, 0.06563833674355861, 0.020316121236030615, 0.08338844073155234, 0.018811175982738217, 0.031354618934734214, 0.05609617921553793, 0.0174447528326944, 0.028681634745049863, 0.008949159509352139, 0.022834167973468864, 0.022475483692100933, 0.013397799526912071, 0.04179032992631678, 0.03357065849066262, 0.03124395561885209, 0.025561617184129935, 0.04020621331648962, 0.042632743190493316, 0.05206160397539216, 0.07404014558321045, 0.0014706162548992004, 0.04207515758612464, 0.06867451938770472, 0.017129858137078343, 0.03309564950365213, 0.0214880135946817, 0.00871697645409093, 0.05623165037362807, 0.11734030074289731, 0.020488667219216307, 0.044411564876715985, 0.015542003975790596, 0.03329486300748202, 0.07759396617691364, 0.01293834978564372, 0.03769182464888981, 0.01757050041980561, 0.027243042282099207, 0.019614909467617833, 0.0374888496533517, 0.07343329669487092, 0.06266257162356088, 0.04599365901442305, 0.02383535487517234, 0.046683532681556485, 0.07616993896062337, 0.015915802214294672, 0.012818216665407584, 0.05825713704971056, 0.030577292500604546, 0.047736114506880124, 0.0039506258889882555, 0.020751443038123752, 0.08265552441439322, 0.029903253870865995, 0.0584437215941087, 0.09290382731705905, 0.022870714197896665, 0.07099946600294883, 0.03539227001789597, 0.043146864796477946, 0.014362525431469325, 0.10168649676826694, 0.007204824228650861, 0.07857778395015387, 0.022083530127401316, 0.014592002281138014, 0.054858740374085405, 0.025019345677367626, 0.06950669005633363, 0.05918655491944763, 0.037025473711471406, 0.014781355275772514, 0.0285990811103294, 0.045226724562986244, 0.04267999932410256, 0.010962669358348415, 0.03328620621393765, 0.05220809147783345, 0.048951566624905796, 0.011965299378179256, 0.04641354031440231, 0.0070568543460760875, 0.009895846916122303, 0.02786665508944181, 0.035498614513104966, 0.05517400087668531, 0.049430509473407463, 0.03442278574971903, 0.0623005835880195, 0.037874069305196885, 0.021050711455304297, 0.047610682931037686, 0.05201030289754272, 0.014062398995813585, 0.08309390290730423, 0.050428492212367636, 0.05936395406963364, 0.03737370663833234, 0.06297676343350642, 0.05360820525956731, 0.029294392086505413, 0.013396085405181493, 0.03973618390098695, 0.06686737926136102, 0.03015414958128766, 0.09745794423525372, 0.08217633641775578, 0.021371912969756993, 0.045430473307327884, 0.10745117816353038, 0.11727804843817027, 0.19180384013921986, 0.09380050258891237, 0.11983006351417112, 0.08930286167249565, 0.09378017827628121, 0.1306401003873156, 0.12705316947352502, 0.14088228224746643, 0.1554359916237093, 0.12256109035543858, 0.12285174411391059, 0.33116225093122453, 0.16393645726624997, 0.12831355264830974, 0.10540173208761601, 0.09464949654835848, 0.20298159921601897, 0.17783493164085573, 0.09277967510805016, 0.15839125240041366, 0.16644187121381684, 0.14233381968111763, 0.18548841047431194, 0.15432706403155483, 0.19382039806054485, 0.09781720116734506, 0.16901871519944361, 0.13132371128566805, 0.1763798548809944, 0.29046606693056326, 0.1470317772679752, 0.08659190633484433, 0.14165397793535264, 0.16786403683645112, 0.14175461124508612, 0.12168832468770205, 0.1403816897542246, 0.2694396806820747, 0.09195487420525282, 0.15624890284192178, 0.14694833497126258, 0.10917383411358442, 0.47753419667001695, 0.2936609906534995, 0.15474196192958664, 0.16958395019173625, 0.2139245676657846, 0.1280535347459297, 0.08506879330642762, 0.2363036660056922, 0.12413876416582255, 0.1451092336567179, 0.1207602168283155, 0.14177748663050516, 0.14738721142132438, 0.11769542846107676, 0.20559434208177751, 0.21015215154376723, 0.07134374591612047, 0.23692723093253953, 0.08803680944707125, 0.0910202929029061, 0.1332486604130076, 0.12256018637168793, 0.17496113665401938, 0.1182506277015613, 0.1860115412742861, 0.07085110541553268, 0.14059029549600618, 0.18561073939406103, 0.07562167281585355, 0.10618689560121107, 0.1274953707451782, 0.1430582783875927, 0.14217831915424717, 0.0932114729056916, 0.09253153922937571, 0.11294932224817815, 0.1132378539430999, 0.07296068173262381, 0.12313111339725795, 0.15126761529714833, 0.13017696959357108, 0.18511529501167037, 0.13016166315684397, 0.18473042776027035, 0.1453120630955504, 0.1478439223982634, 0.10627664280154052, 0.12384099345053397, 0.09872539074070032, 0.17940144355018295, 0.1859548048026139, 0.25491359643638134, 0.12371442040368436, 0.1312937266043117, 0.14558957078524176, 0.1904723640050619, 0.14875653229894178, 0.13629303253706426, 0.10758564191600008, 0.11380831365503612, 0.18141646929565938, 0.10255195395720583, 0.12440888676792385, 0.1873704586778918, 0.1097910711541772, 0.09316906993908268, 0.0841928253911676, 0.12981667844278197, 0.09969914977949473, 0.11857206287283091, 0.13338565225562743, 0.07573590418624301, 0.1254794027115549, 0.16966848033330134, 0.12152181547735968, 0.15038217087426495, 0.07468460938863217, 0.14052337005494103, 0.19719382026983848, 0.0986427221927912, 0.12153013519221738, 0.13693541258333192, 0.1648330252857939, 0.11895738211610626, 0.12163446870662513, 0.12366544440268509, 0.1818505347135567, 0.22828024331360097, 0.10496441079604049, 0.1042653249216176, 0.18813228715331326, 0.16460736642681784, 0.1497011187095796, 0.19042071435720692, 0.09721727771384102, 0.15834124218071663, 0.16248271349937687, 0.11073677605318447, 0.17407161664337883, 0.2383251268897326, 0.17933906867138802, 0.12094996148540128, 0.14473411104371472, 0.2050098169955515, 0.14571456569096736, 0.15892334642910189, 0.10589915297685132, 0.11540002985707215, 0.24835957634833553, 0.2232120507546971, 0.16550929706183173, 0.1985337233711635, 0.13794113281032733, 0.1339773632465832, 0.1991750921813711, 0.16513161571516147, 0.11225015210408358, 0.3342155403187198, 0.19168290549949293, 0.13040696451019856, 0.1074894289335897, 0.18371683214941334, 0.09773417255811154, 0.11964541334178179, 0.23814014729953584, 0.17842607572674754, 0.0857771258620966, 0.09608644000705212, 0.1846310355129742, 0.16831746895707425, 0.12966180610800945, 0.10935662269231775], [0.061402644271091114, 0.03963073572864936, 0.03940303141491548, 0.04763162011400827, 0.06470421509396646, 0.004261624069899441, 0.06151237104448581, 0.04242185833713701, 0.02415552600136688, 0.029963845680017146, 0.014927452073372422, 0.026260691567233978, 0.031633371517302535, 0.04994761499185717, 0.015222272392542613, 0.09684034713333654, 0.016035262134767348, 0.06130856484354985, 0.06944278300169014, 0.047952450075817686, 0.0708313709906032, 0.11699726189216299, 0.052589289168076175, 0.0187854009545258, 0.02483225743015928, 0.03692432712282866, 0.04825701982143426, 0.02279955420583006, 0.0177426882568867, 0.0496898110835783, 0.03264034046761451, 0.025321109625961513, 0.07894982688970144, 0.009066978086447044, 0.023082265547747095, 0.013118291390128435, 0.011131630050048474, 0.06381605871983113, 0.054179231876567494, 0.01731459449435915, 0.044461303135199894, 0.0357303369580017, 0.06193555801385834, 0.020498687649265896, 0.02093457827164281, 0.010518469554822772, 0.03700458249377628, 0.048838388625412225, 0.021027774782851342, 0.04403081917834859, 0.054330346550071434, 0.09458884536739319, 0.037349214807393095, 0.010774003927625958, 0.05561037221923471, 0.04317419881361627, 0.08605715398105883, 0.02431573413853203, 0.02684926734335961, 0.06430527480739741, 0.031201625430595972, 0.016270374518729026, 0.05333845804054892, 0.048353680965280345, 0.015397487234534516, 0.020446620483492172, 0.04792855196301976, 0.054748733978598356, 0.059349731647319375, 0.049553179302282875, 0.05875432428212897, 0.06697677661694827, 0.041126564535642826, 0.057062545505863045, 0.07370065371956556, 0.031781015812509486, 0.03559502284793604, 0.05890183451194918, 0.036460188923463706, 0.03661822520136353, 0.048511092881521875, 0.0576394365259236, 0.04793142096229619, 0.07520931832973035, 0.07128740781016889, 0.06923873548305805, 0.04924200204831939, 0.027227303005694866, 0.01618767532730295, 0.003760126874699528, 0.019833292406533035, 0.03963600641356842, 0.04614486944891753, 0.016159546493943182, 0.06223776054778888, 0.027573620712745096, 0.06505987141281366, 0.06323440646332118, 0.02860588014065739, 0.027140233282660766, 0.03518110171200768, 0.04221958814248924, 0.04887727907888832, 0.03193909805568476, 0.028886819904249524, 0.03168057785519669, 0.07822731404655403, 0.0722128956488544, 0.0037011309224556413, 0.04548714849196615, 0.018263306288469224, 0.010428559560809406, 0.021329600018479174, 0.07607522751054457, 0.04013691683329883, 0.11519016773109475, 0.10996190876129175, 0.0405748050299383, 0.0463008564416199, 0.02876014918118956, 0.039430687188982, 0.08753829305210421, 0.01710291865522102, 0.04649396039425366, 0.044802277378978274, 0.03218270635472671, 0.01698696933266136, 0.023080654847886295, 0.06481481520759483, 0.00960598605865192, 0.042310541931299434, 0.03930275050562717, 0.12093146812290916, 0.02001013422775413, 0.020723595742076155, 0.023408687951403762, 0.1159786407445227, 0.056625025031427224, 0.04130575633157165, 0.06052367329116791, 0.05001067551934431, 0.05535349527734423, 0.06815488194866527, 0.01162910552304839, 0.023090481840735002, 0.07627177502839796, 0.04281101568091301, 0.057273235006798665, 0.08014279432714948, 0.02532099088233325, 0.07093646293205601, 0.05848063554074015, 0.052049798560479, 0.06999871002570277, 0.07103152678257997, 0.05571824505985264, 0.07313010973795768, 0.037876628038863984, 0.025102707534848202, 0.07321989524268335, 0.07257757648344963, 0.010947406014067032, 0.01820219545474937, 0.021745926670489774, 0.060414241461624066, 0.05367578953624733, 0.024620401560358947, 0.0509292685667113, 0.017977406105567372, 0.03194269675370907, 0.02250008469056939, 0.024587438712196968, 0.01605901756368938, 0.038380265731604836, 0.05803591767025571, 0.05344672541644785, 0.021832986817424817, 0.0824073578922018, 0.036022791023095774, 0.047429752115520744, 0.013634459408480796, 0.03293217400148992, 0.04478325541581839, 0.038573909776225206, 0.007318035744491124, 0.05434510906437232, 0.07594326886558726, 0.06171123980874978, 0.02691577526650602, 0.10617410959375483, 0.05366254387603653, 0.0218532077081862, 0.05046578154208199, 0.009347804852070348, 0.06474362265679144, 0.03986641118723539, 0.021799206170403672, 0.008200186946909995, 0.09820709395552836, 0.07782288857044713, 0.01308028385298507, 0.09049118661712255, 0.04978144286020149, 0.05717458203434945, 0.022712329349991296, 0.048756068647508664, 0.0017778331933978706, 0.05507397277641201, 0.07711897634210126, 0.0522915720789423, 0.04201819894895439, 0.035725039460005305, 0.01558572940167881, 0.07319703517902283, 0.09206732059077871, 0.02942691763652669, 0.030439153441318104, 0.038122856358606974, 0.09307282631315532, 0.02819660915842941, 0.019257131085220366, 0.04776887625696198, 0.05671066600048254, 0.021111345399291288, 0.014185196186806408, 0.03924928522939163, 0.02602566728338359, 0.05059235841937123, 0.04710139917029489, 0.0564862635257023, 0.06609883219484361, 0.07044262733430633, 0.046281344182188475, 0.0035037785334767957, 0.04006873883847748, 0.022502672152533647, 0.028560370687515508, 0.0560736409088056, 0.05093776065135195, 0.028750743536699205, 0.010923647712315283, 0.046809209405534694, 0.04443369715684845, 0.09041774942870102, 0.010802557939783701, 0.006358159655299519, 0.04682669153196677, 0.030379542224710027, 0.032088814618726896, 0.08268158672557724, 0.057387022046192046, 0.041497374073632305, 0.023643754370089982, 0.06465875543653965, 0.03791981241515568, 0.01317876349804142, 0.03570833108237675, 0.037972764412481944, 0.03999451257949395, 0.06895198111212061, 0.08550821367891566, 0.10332450766356722, 0.028073487337678674, 0.0180252502116585, 0.027479522133005724, 0.011920037946002859, 0.08619235317793586, 0.062095229889476494, 0.02760056210982223, 0.10164956366943736, 0.023808085975507577, 0.06376787945027314, 0.06475432490509364, 0.01931352090210684, 0.036903072013369495, 0.020534841253632502, 0.00617884528530281, 0.044061125616633126, 0.059517818998785756, 0.042627181392163045, 0.0728565167575594, 0.09384845203209309, 0.029749517261441198, 0.10255803669532461, 0.008007548392690238, 0.0718013838594479, 0.07041105685094673, 0.04615775887824355, 0.03002657104403742, 0.017794027639132355, 0.05093347821985522, 0.02710096553088196, 0.06396863662127046, 0.012281658259340593, 0.053222702155190135, 0.00132942421553326, 0.05447980647365894, 0.07760397894608398, 0.05794463829407769, 0.0502328142043083, 0.05010424166797631, 0.06990802053722643, 0.01383936973363762, 0.027397257696476676, 0.0513321542060904, 0.018307229939607844, 0.033693259371624845, 0.028527587870015737, 0.03497280623583544, 0.008538140889046895, 0.04514685223600076, 0.023161097910375367, 0.09620388128584433, 0.018441368104709734, 0.03491911496366224, 0.05430033888607737, 0.0988527451972327, 0.03419323516408763, 0.02614142316874237, 0.05031216942194489, 0.02903474573676865, 0.04649525125240607, 0.01658214740605364, 0.06234767501272502, 0.07630850894436722, 0.0288414100425378, 0.008997490081275183, 0.054904966119436495, 0.06917718797922134, 0.06727293854759586, 0.055056682171961, 0.006418111302228946, 0.01667539562819706, 0.043517318103582635, 0.011113253515964795, 0.03256298856989991, 0.05407710852582128, 0.07290018376924338, 0.036472794900257746, 0.0475809050934209, 0.060366276696684866, 0.020815263907875747, 0.021108775174305327, 0.0248393303369202, 0.06134080948428281, 0.047875772335476456, 0.02837262551991209, 0.0441510183736682, 0.032554140254374475, 0.009867850232929474, 0.05060588753211403, 0.03548458744321139, 0.12899451288244418, 0.20909798391644033, 0.17674771498047537, 0.25013087888158136, 0.14479893740386734, 0.15792311139164433, 0.15944074689140245, 0.18347839494386028, 0.1102120671120863, 0.12013485925572535, 0.15402168606317815, 0.15704987841027399, 0.10265781964746215, 0.1577968754234814, 0.11595239457223686, 0.1729266522752662, 0.15187628747474763, 0.13468322133825672, 0.18420904364076354, 0.14746765065337383, 0.19521533691835022, 0.1987004700687624, 0.2060104503987297, 0.19458389660764128, 0.10234946159706002, 0.25853736085757134, 0.1670982093820649, 0.13675743503676308, 0.15601680884438177, 0.24703988264645302, 0.18208990654637738, 0.16021792776882648, 0.19102555609518485, 0.19456722653440892, 0.10663920923346475, 0.09257543606743698, 0.11192641866904114, 0.1794226641856855, 0.22452612137121541, 0.15499588943296863, 0.1266116423592452, 0.16193470016362208, 0.2530729935895051, 0.08315303723417944, 0.10821911235970837, 0.19172134779153333, 0.1595930298489909, 0.11784880692439696, 0.13587090276902722, 0.0961679747448333, 0.14741875892204626, 0.23290209772606052, 0.12153371282282377, 0.09066919480720836, 0.20611345858102847, 0.1569250826874087, 0.12818080493279044, 0.08655953145916424, 0.0870915565399393, 0.20333283520754308, 0.13419461046015063, 0.1527827073849978, 0.16581069137300217, 0.1290406926625198, 0.15119829966175943, 0.0997849592878934, 0.1089283335773695, 0.17093264798243202, 0.14117498912157553, 0.15323305983216534, 0.1548856340589062, 0.23522089265527266, 0.12894258744293643, 0.15924940877143415, 0.17103533440780255, 0.09645757896284904, 0.08754364800669494, 0.23361760852558, 0.27436908875261584, 0.2075277794633181, 0.08493098941060805, 0.24459857493638995, 0.1520045152715137, 0.19855975503883055, 0.19121093405110223, 0.16446700379733117, 0.1911047082995215, 0.14627394777151848, 0.09054863555056435, 0.1799867347243332, 0.21855685619577286, 0.15686119095452372, 0.20543084359697758, 0.15730952092957112, 0.15534242164463768, 0.1940553572269217, 0.17137108010149774, 0.12746625940405554, 0.12110020664911117, 0.16071809125283074, 0.13836024419194268, 0.1593610584255188, 0.13117153558038896, 0.12557537820670875, 0.1890969757110842, 0.1731645225757553, 0.3280334252743952, 0.1694322494609702, 0.14811736982195609, 0.2482322678570786, 0.13543545839286622, 0.11020114269828606, 0.08317592794135695, 0.13944179180168337, 0.23855389606568123, 0.20314344295090248, 0.2786380064583594, 0.0745718106026611, 0.1031561062160519, 0.13263007505766808, 0.1769247425780181, 0.20303125703527083, 0.1408343251434065, 0.19703488766906724, 0.12643191813220903, 0.13227781250832543, 0.12448667533575528, 0.18127691871937246, 0.19451026023635942, 0.11785811489267696, 0.12699451012116286, 0.12024550533462917, 0.17340191790173132, 0.10125960193334088, 0.2055715892704264, 0.11411015229720263, 0.18935839555436568, 0.08508916358433424, 0.15683278441429138, 0.24696967834907196, 0.1759421428845775, 0.1782543647793993, 0.11537674844505326, 0.16230803013088244, 0.13234006481305247, 0.18565765461854397, 0.21633553829404617, 0.0815135860935815, 0.19593824812721825, 0.16083412292984225, 0.1281380802092533, 0.19271393727150657, 0.17732767418267267, 0.18189317516742215, 0.14346422837866893, 0.12265380997691425, 0.1320612854174068, 0.2198257429465171, 0.13058894103573215, 0.19236907513151247, 0.08453084636599788, 0.17859830761388426, 0.16730450153831514, 0.11108166883669554, 0.14317971864534965, 0.10103854726278975, 0.09203466992344587, 0.13338807309346815, 0.12875527894544986, 0.19715470382042471, 0.11321628856803141, 0.06891399081195555, 0.14901393784150002, 0.10809750356260808, 0.12553328167526953, 0.12564866217754542], [0.01388217298118698, 0.042802987079466545, 0.05034365563563282, 0.021601409929233695, 0.008758048342931415, 0.027729360642091885, 0.026530523055924043, 0.059975085389469905, 0.07230470362570017, 0.031749393618215, 0.02420747442351234, 0.017622628872613275, 0.027412897381450863, 0.02244348419950374, 0.08117332814201232, 0.06321942178352226, 0.015878939978598107, 0.034303387116280296, 0.02519485067516085, 0.01943706215599612, 0.033825378895046256, 0.04771097533164486, 0.01999434898607433, 0.019011822070986516, 0.027363044209778312, 0.016556431749655355, 0.05500471459761743, 0.08324275379099193, 0.045922589037687554, 0.03287552946036862, 0.04249619184842995, 0.09981047001577194, 0.03460443668788479, 0.06620798440229508, 0.03887668304565934, 0.04435511568801538, 0.028191551062909347, 0.07051051038527681, 0.026014746700022972, 0.06128668920287202, 0.015466266608376418, 0.06408561058642884, 0.06601960338171452, 0.017384846672235478, 0.016248736365307725, 0.013490431048276444, 0.07253948659185441, 0.01109896693378687, 0.06698013208205662, 0.0779384299511871, 0.03611431937784918, 0.024825282199608705, 0.009943271589074886, 0.05314805071740862, 0.03869640340487804, 0.061499175179990075, 0.036728871280267354, 0.004940754311504744, 0.04322494064728099, 0.039295587583535144, 0.03825328665815535, 0.020036617887296507, 0.053689464205695744, 0.06944945562751063, 0.056901222710768064, 0.02735531629784213, 0.07104885569142719, 0.06102182962481053, 0.03556164056663552, 0.01365679087147357, 0.047878660486951, 0.032111586582276135, 0.06279099860318726, 0.026028576502276045, 0.025091097472355734, 0.052472299881159305, 0.03722460677606925, 0.09979193068800435, 0.017992951944770835, 0.07814980127037534, 0.06228175314684069, 0.05684655850693103, 0.0380043272349623, 0.04103638832607577, 0.04087256425390801, 0.04225202430520327, 0.05003697531778486, 0.05815564189106227, 0.06520273148893349, 0.04656810238356552, 0.021583355152078217, 0.013572418735542846, 0.029654198686682412, 0.11286616340399751, 0.05524500190550762, 0.07259344216436148, 0.03554820338444364, 0.03720476509883039, 0.006734401714282051, 0.08486922740215257, 0.019171873160127192, 0.08937410018857449, 0.053861627144919294, 0.06598388070180532, 0.018485094488207853, 0.07137656512279665, 0.014298264061160868, 0.01586996142812554, 0.025579093564902584, 0.0305666170653797, 0.02120670610888591, 0.03601743606850505, 0.07103672851958583, 0.060212848437649596, 0.024200834356428638, 0.07353261999425388, 0.05444044870654902, 0.0904188372735535, 0.04327905709825216, 0.04982987876921412, 0.06352401451177656, 0.07478154249369137, 0.032493136672964024, 0.04062430580116568, 0.03754122708473475, 0.04120028517659634, 0.07987722994819765, 0.04206403015902446, 0.03253033407212746, 0.015951652256321284, 0.025333985648748857, 0.03707765579043377, 0.042660322355767416, 0.04777382518495283, 0.08010818247473048, 0.04770067910994253, 0.10562125458231858, 0.0323482004985694, 0.041125040020673506, 0.0555899138412168, 0.03844003974189682, 0.013140792350074457, 0.061893158877689036, 0.02833484397870639, 0.04787001135428587, 0.04408886949081094, 0.03249208330206814, 0.02293322888773776, 0.10512981683977189, 0.02765107220188985, 0.029727243255042744, 0.042571582561058384, 0.051820263296606085, 0.022452824726520527, 0.09067543842379125, 0.021410732560100097, 0.019701525283556794, 0.08257320826692928, 0.05596667971281756, 0.013194675144228726, 0.04247935323585426, 0.030881837348363576, 0.07866246730930383, 0.040321126505131685, 0.09007143938253004, 0.05899244356119345, 0.11022031787903079, 0.03808972305588184, 0.025504193148545684, 0.04504017066210509, 0.08752699325522108, 0.0608956128088457, 0.07339447901974763, 0.026954543145914233, 0.11151815509243358, 0.047509084350519606, 0.0787467216592162, 0.06014314209741931, 0.01657663540343844, 0.006877597432673699, 0.036541206551895994, 0.01310406034932502, 0.04084933263760421, 0.012550616407796982, 0.040990040006656805, 0.011979759287750049, 0.03752427355897042, 0.10428022533174484, 0.03592153718214362, 0.05274320006250374, 0.04534133131645861, 0.04998000135885612, 0.019577470750758247, 0.03479684733094708, 0.02501715083546456, 0.05898127399925744, 0.021385244814859285, 0.03822412935175723, 0.021874556663416086, 0.0661239215743638, 0.07184916476328528, 0.027509723234200673, 0.0436465839494861, 0.0032628065345042777, 0.05108306837838985, 0.025509940723197597, 0.031196762687496604, 0.01872482638235294, 0.04274093395759983, 0.028860114079209107, 0.05885063302552989, 0.039683469390917214, 0.008587692413599262, 0.027359100772188078, 0.06122274001339271, 0.05181721043622783, 0.023737209435972958, 0.036279464951686324, 0.06310277723617132, 0.016500685446625276, 0.04884261743075425, 0.04453085625784532, 0.06124612867772099, 0.015324475224910965, 0.07274928743079787, 0.039285532679528966, 0.04503301540089231, 0.022306965416177146, 0.0695401374551077, 0.1179659724115364, 0.01874607191571305, 0.07050020650269524, 0.025468849682159005, 0.03804375394998539, 0.03985928273909996, 0.03504117192219823, 0.014660595878658277, 0.06346321777410566, 0.06289415234219163, 0.01605136434532582, 0.03101872193867401, 0.020479943392978563, 0.059473347594781276, 0.04519276388530289, 0.03610516079671441, 0.04805298379412101, 0.07878337130551377, 0.02954125434400574, 0.024510990798233018, 0.021053329560785525, 0.027367943342054085, 0.027159741711652568, 0.014854984943785015, 0.03532179758974141, 0.036653400128406864, 0.015917427278304055, 0.03744627431695981, 0.02147392715297399, 0.04473590352121861, 0.0262785395006499, 0.0732914018895357, 0.03000635398371566, 0.01796500314207327, 0.030780372833232247, 0.02885963527425643, 0.028760007454923568, 0.07320844222821536, 0.04671333350181099, 0.056563860571552674, 0.05347659901505517, 0.021185426101569208, 0.010288780115755096, 0.04736213719532375, 0.011879650748244697, 0.039528432347240954, 0.04505306392187073, 0.014033558658294141, 0.025221824630974762, 0.05029523121793905, 0.08446176055698626, 0.06968308946177845, 0.023715268677821564, 0.04374169759572514, 0.04860600734490061, 0.028557248879224065, 0.060230591033975926, 0.0790684632656555, 0.03346486174831948, 0.04344375068021398, 0.05303036429048066, 0.008745096668961548, 0.0913473128551437, 0.0486558873296505, 0.01224930636629823, 0.053973981599894263, 0.06701376334193253, 0.10520702318078089, 0.02150183573605553, 0.042449916307363784, 0.033996783407224763, 0.0049662659969931895, 0.010215947179183846, 0.04044705603812491, 0.06223477280488419, 0.04374905203979823, 0.035730819593394, 0.03353068402277366, 0.03561416355472419, 0.03088228359457947, 0.053728668755220796, 0.06390807354041646, 0.03808478561920985, 0.02523249623575999, 0.008343500930124955, 0.016894874072843985, 0.04682854929518315, 0.011487765173848358, 0.04441218540793465, 0.006748926262521456, 0.030808346533787348, 0.03305402028584673, 0.027282537945035486, 0.0167210410619455, 0.031915759187071555, 0.031842193678922714, 0.010631573818353637, 0.039426033204842004, 0.003692881831328475, 0.01614364250863512, 0.08977906192622839, 0.02579084601283314, 0.09317706789701216, 0.02375862925433584, 0.08904424571101704, 0.03816332495320709, 0.02252259426900456, 0.06000097533087096, 0.04695581948204387, 0.057274843791439656, 0.0812852535877497, 0.03744300312152313, 0.05163036542193544, 0.03663936539763405, 0.035161344304440484, 0.04646053214767768, 0.07052982346184793, 0.10909067526940378, 0.05957085526578369, 0.0547729040526094, 0.08182343801543598, 0.016360749911156394, 0.0335299753914437, 0.16877888371386837, 0.17451953293094713, 0.1473016700436992, 0.08109314171897788, 0.14216972364773675, 0.1567526056521362, 0.14631887116739828, 0.1361413624498152, 0.22882974285992885, 0.14765742595397657, 0.07116925406960711, 0.22876490117801776, 0.13931897258566273, 0.16329134994697186, 0.12533488022463937, 0.0950200456164537, 0.2132687197938081, 0.16958232608533677, 0.10307689272468129, 0.10388074112274956, 0.110034579861789, 0.08902770587273183, 0.12418527336370562, 0.14183580124330136, 0.1047400159821395, 0.07949841479139944, 0.18593226649588157, 0.09404931262496019, 0.149045362768154, 0.1151645114465106, 0.1393035588966262, 0.13812834937726298, 0.14797653221795637, 0.203576757602634, 0.14751980591925884, 0.15728653829184272, 0.1337239413612312, 0.18713422780556066, 0.1214910340645621, 0.18190163277810623, 0.10407125952863887, 0.10999938578254755, 0.2299996204073391, 0.18243214866567045, 0.10957853538134407, 0.175724420696497, 0.1367616791638636, 0.11962197871217806, 0.15520746759589643, 0.21004713621110688, 0.15009392263187518, 0.14627318168359418, 0.1574659560837092, 0.20508526133433466, 0.1227320658583795, 0.16632465976140193, 0.16045884709925423, 0.1521582691179168, 0.16317021612438465, 0.10030667282520764, 0.1746114481601023, 0.2850406628943259, 0.1848805963151878, 0.1723888585524213, 0.13793494281989915, 0.12749498004033682, 0.10778037380547294, 0.10716978640806292, 0.0754286416415726, 0.12077839609475867, 0.27360039612939285, 0.10370417317796139, 0.1840689874464466, 0.14978292157813428, 0.09601174643443477, 0.11722148816672065, 0.08079812125933748, 0.19158863071953097, 0.0977563584643987, 0.24784816669360285, 0.1328638697704, 0.18733364049225085, 0.11024480970997004, 0.15541037364352137, 0.1482295710593462, 0.17537692321404336, 0.09974552108155144, 0.1565412726373442, 0.2447473798548022, 0.12597462492844752, 0.18428197521115505, 0.10231265107229834, 0.12229495907142279, 0.18461191395838417, 0.15772982740834837, 0.18297662267521506, 0.11373089280940833, 0.2163430459557041, 0.10325492389740483, 0.21010246308099842, 0.21707885808521704, 0.29851755908420013, 0.1329056981710657, 0.24872196658003717, 0.18328731729378625, 0.1691495783386692, 0.12970830764501326, 0.16235656946176485, 0.14129112805089644, 0.248829709185708, 0.15797951078462988, 0.11587213154040998, 0.18054513621234125, 0.1190548744653502, 0.12497055179048931, 0.25476886710572627, 0.11125164076445565, 0.2208703344747905, 0.1581066967018189, 0.1846114236621126, 0.17420496190747908, 0.17362607522837578, 0.25252758495269284, 0.07956144084493, 0.18293860939241227, 0.12130722658888948, 0.23812684801317033, 0.13514328778030413, 0.1379722666235701, 0.1051449394153972, 0.11926660584586284, 0.1377863524061057, 0.10378298830361136, 0.11571434807152518, 0.2109053845126783, 0.15278281463730722, 0.20285948480088867, 0.12931424733852187, 0.1518779115811471, 0.23325143381953242, 0.12015591901276382, 0.10676288646796059, 0.1394470931301194, 0.1521931874055055, 0.18406921727282388, 0.10751054997766211, 0.13377825699506268, 0.12481676730056926, 0.2308039820843166, 0.09799802090011298, 0.1174361919683795, 0.07712476030592957, 0.15196922926172135, 0.2097350473125135, 0.1384653054898785, 0.18133411484379924, 0.08693807082430971, 0.2068441225996902, 0.17457032456032692, 0.09837531920282111, 0.19390644505620006, 0.21577148307715693, 0.25488494474801326, 0.1595240512922887, 0.13933095420079847, 0.17679453827440741, 0.2614597411405656, 0.1516871250444843, 0.10355961238664967, 0.13289874209271324, 0.3016207054738076, 0.22432900694829805, 0.09280985131138757, 0.2302011321749418, 0.14667461175591717, 0.21813811253636115], [0.05091025809487028, 0.050237594592955806, 0.024068245604153604, 0.015802570588646397, 0.03751025414995609, 0.02635138871658954, 0.018522018010938363, 0.10337353729072118, 0.04080345546225867, 0.00947059821262355, 0.05263994673206922, 0.02607308238023712, 0.03692518514130385, 0.06546506297684486, 0.026548003267136314, 0.011839688729284512, 0.052994247075290456, 0.05572254664354748, 0.041676339873623465, 0.026717107600322174, 0.010394128696662525, 0.10349812616984691, 0.046614462194303354, 0.015891640758772772, 0.05994001771473597, 0.039592105745067524, 0.02509185972984039, 0.04306965462502934, 0.0694885184507697, 0.036953250772409865, 0.03705700205999517, 0.10305617770720875, 0.031914638783482295, 0.06480107925111248, 0.060078986064200444, 0.1117792072135114, 0.03844950092776168, 0.025067046141972946, 0.025482650756114916, 0.03294725444227938, 0.05721210119044108, 0.03427370503965405, 0.03226666576078823, 0.036500577078831774, 0.012034171640181975, 0.035121408140947746, 0.05229288975017206, 0.021959527305537657, 0.08553578518331052, 0.029010659932429274, 0.018842809668351567, 0.09940551593899728, 0.03180775228106687, 0.03829103564062426, 0.030793963233008984, 0.07425619003873679, 0.039833381306380033, 0.0052601607861898604, 0.0488434141621955, 0.05587505559707361, 0.03816424808915585, 0.027362889076973644, 0.02263575120108022, 0.0676382092698928, 0.0708766850913244, 0.04526846486354067, 0.0576752319841856, 0.05516444009939029, 0.06476311193358514, 0.017317346665227128, 0.07800917051011518, 0.043524638073699135, 0.039362865425045454, 0.012400750457609614, 0.06367102295400635, 0.050560611735789046, 0.024328715498408964, 0.05809923483719749, 0.009191330435926156, 0.04324625704377409, 0.036125561718138, 0.039275458623324676, 0.03770297122818809, 0.030919088373681715, 0.047028187977811026, 0.09049011409402856, 0.028292695736332286, 0.08693281546114914, 0.01922750454996863, 0.05343096315740578, 0.06252824576691755, 0.012225563386304966, 0.043993514526875756, 0.09443031879322183, 0.06852572979105097, 0.05990120770049192, 0.04401832428430358, 0.06366700099240388, 0.032958830030815255, 0.03498982104863371, 0.02218517467319485, 0.03386874713243977, 0.006409317091663158, 0.05467991630036024, 0.04234410041282254, 0.02925241046825484, 0.020639385442219434, 0.06078512377796635, 0.047212175484145844, 0.035152089962315176, 0.0413423829952315, 0.04527261706009027, 0.03820327643845831, 0.057397751107571594, 0.04624568278931322, 0.049420086847197627, 0.04048967733979225, 0.044974390522486744, 0.025406384788032983, 0.06602748642645537, 0.03492253554624415, 0.04860377036816171, 0.0519230148394502, 0.010284037073893894, 0.01399896500046335, 0.03020527828935414, 0.08175317243102097, 0.023331918280511614, 0.03561160482105709, 0.10515581020304274, 0.026965586303342736, 0.030271052683313048, 0.06137077884388067, 0.02906644645507538, 0.0030844327768370992, 0.04902611081037791, 0.02566165486050229, 0.01695834254215081, 0.03140307016550534, 0.02844180900513405, 0.03307249832658037, 0.004190388905455269, 0.014849328342074109, 0.09238363829471412, 0.07747889977068671, 0.012438400806258283, 0.008245731831618376, 0.05686723522000736, 0.0836661629258625, 0.021007362370108886, 0.06740760914380513, 0.08147858353632112, 0.06026268628756366, 0.03934068717963753, 0.09983100117214265, 0.03881020193559028, 0.06176316524825751, 0.014357550648011029, 0.060180599966477004, 0.03839546491602256, 0.05586153031477044, 0.07258223429802926, 0.03781234177069799, 0.04100074608539862, 0.03900783346785654, 0.03378165825720757, 0.05575792458389075, 0.0200351853028781, 0.008000618648610168, 0.08419491681120089, 0.03940578167056365, 0.016802005064223084, 0.06670021121540377, 0.04514181903833824, 0.03198683107902687, 0.04014251310558569, 0.08418523345983799, 0.0260298750213077, 0.061772752838629874, 0.07225174396749466, 0.023404893900958762, 0.029431904868913755, 0.02714286479468067, 0.0062524069630120315, 0.03203206474051601, 0.04284962268185712, 0.025995567688838612, 0.05718782003368101, 0.0454045259093325, 0.04606863603957238, 0.02603379930669983, 0.03903355486991425, 0.020024416021882527, 0.04305460865819647, 0.04337368044821967, 0.014934985590497813, 0.028658043067421646, 0.03132611280307174, 0.08099949513111385, 0.08000703588608774, 0.02967041485281962, 0.009628398918486651, 0.028680062349585277, 0.04058227055676041, 0.11658547431110375, 0.025554622801381256, 0.043513261668023565, 0.023937596969546813, 0.03374848665008622, 0.060769242775296016, 0.02282266324806598, 0.011729143199420745, 0.010923528011077115, 0.012218483776274708, 0.015498087985531218, 0.03411129439970659, 0.0800787800201966, 0.05206376051289901, 0.08331256738353161, 0.046050073729167064, 0.04070290259175724, 0.13074255698630888, 0.062440341008045984, 0.01269616928297065, 0.08754430684230982, 0.09391554601250157, 0.01174534308618956, 0.022064550299077265, 0.046410537249739134, 0.0033846295968208823, 0.024735716945161263, 0.030626521310618812, 0.10123761520991403, 0.0572199076263895, 0.015766372934224147, 0.010245015427860762, 0.0661723153485406, 0.0828049268813864, 0.018896748003880345, 0.058072873751723, 0.0858087346498524, 0.04615644886789303, 0.09336953216622915, 0.018808879634185184, 0.10829828754668275, 0.039626464788471503, 0.025378334478685455, 0.059232669582049695, 0.030780056821963483, 0.054388163205716884, 0.03505855828763978, 0.041644551055205446, 0.04476729780435563, 0.08592556305830518, 0.029347506877515587, 0.032458432889994115, 0.02685011578573575, 0.014489337880795282, 0.03213851840325421, 0.03579152057007436, 0.049538861118978074, 0.05939623701476282, 0.0335918638044067, 0.07355388659503191, 0.02111089149219615, 0.09445592911253053, 0.0551239944874279, 0.018536566020620447, 0.026374181747556697, 0.033134199048001925, 0.03892446394949671, 0.031116788853861155, 0.006698546884205914, 0.016832227232835947, 0.00804497370301115, 0.04320024197260219, 0.038487920237164346, 0.09059695271594871, 0.02788290572953561, 0.04245231033212716, 0.09053712890994164, 0.04421053574450555, 0.09062629388344866, 0.04717550285521054, 0.06873102603299965, 0.06157648877330846, 0.01722951276948856, 0.011440979226702645, 0.11173093601340249, 0.023013384667255228, 0.008868204125563705, 0.03062560966598892, 0.042934037910233584, 0.04879474076592634, 0.035555599963352565, 0.007106564833872742, 0.03188636056297729, 0.044318033202040585, 0.012023948196832453, 0.017303296612695824, 0.08579440880566837, 0.051204370740320415, 0.05495221076172687, 0.04712452736472891, 0.03732792905441696, 0.06977325034958702, 0.016108634205715313, 0.05344169604922495, 0.0069675677561111034, 0.026704978513261004, 0.04634430894868509, 0.07956442092695544, 0.06629675101008146, 0.08940734074360902, 0.06500257569695674, 0.061283134554903355, 0.028071696607155666, 0.04544479915151193, 0.12001133523881437, 0.021370141391432094, 0.05198709043343702, 0.014038703896315589, 0.03855734312486264, 0.04447051151204975, 0.04524882236916212, 0.028122978532807003, 0.025791441646194267, 0.05680005696992721, 0.04706830800240559, 0.008476429633916387, 0.019692401176378615, 0.05221661803643069, 0.030563907029347557, 0.03312340103870919, 0.0987130567251194, 0.05245445386296319, 0.05532324246521439, 0.028683710843324665, 0.004790274054563094, 0.03819334793895964, 0.08366828498941276, 0.07609826377442769, 0.06508311452043634, 0.07392446630664411, 0.027415996207104578, 0.055568187587684205, 0.02058766493123145, 0.07187120511286682, 0.028867152512013435, 0.04792495901065488, 0.07338513274707141, 0.022552592356899576, 0.2895624815456329, 0.11901257875105066, 0.17974546299346034, 0.15997536901024081, 0.09253368427556369, 0.11774096472729599, 0.11337522116880264, 0.14468201706486364, 0.08993694498654335, 0.07290741563924859, 0.1408434415897054, 0.10490326165792443, 0.24556436666077186, 0.22069483905309634, 0.12831611904285609, 0.147072471858513, 0.16333362267863366, 0.11326162565139034, 0.15041422399301685, 0.08962202156263013, 0.08936061704110715, 0.12935054458437428, 0.13262872674292134, 0.14408820699299538, 0.1071440305320486, 0.1275434427624268, 0.10403541427466179, 0.12731558523110806, 0.19468295177625072, 0.16544238694252508, 0.13774648519052615, 0.18581959028397838, 0.22025605453358543, 0.17454417031859198, 0.1793459328191896, 0.18314816508321993, 0.17057318420660111, 0.13281172982627346, 0.06958589588682498, 0.1459312919647463, 0.13160348659561527, 0.13458404359557938, 0.14487130206919488, 0.152690930051669, 0.22283219371832189, 0.14383758898944626, 0.1810362445370805, 0.0899887478519832, 0.36502382748069306, 0.21829514523908017, 0.14951437711715698, 0.17482106513794393, 0.18447895173824605, 0.11934530605832416, 0.1490946528652022, 0.13217396162930997, 0.18379615289309334, 0.12072725972581295, 0.13587747580341755, 0.2022518238593494, 0.16638251472144358, 0.18204532022918427, 0.12181764799019984, 0.23315153595420623, 0.1984784884318229, 0.10923930398759343, 0.23795263961918894, 0.09538052062834464, 0.22260178511421527, 0.07875471195626645, 0.1359308721317399, 0.12321777326325256, 0.1368581296335305, 0.1179783217488758, 0.1761034350361555, 0.1803550544765688, 0.07805047797099238, 0.15583202843704533, 0.2635191999856503, 0.10317397904732536, 0.19200913638116854, 0.10163918317806336, 0.09861569461082259, 0.15757696222393744, 0.22716497251343346, 0.17009479294140495, 0.11904181266624121, 0.1862001827647609, 0.16649182014647992, 0.21960336294385696, 0.18171761845869405, 0.15815287648189455, 0.10187844009769541, 0.08974744547759334, 0.17632567714298927, 0.1366805504526823, 0.152144740005174, 0.17861545266162965, 0.12096602634917344, 0.12397728049226346, 0.13306148981134738, 0.13212997286069778, 0.08067904055238732, 0.16403286177064144, 0.2238681284530509, 0.1796709839254618, 0.1961403574434019, 0.16680824510272474, 0.23173199035227302, 0.11756495602669255, 0.16649836253735328, 0.11708407497574246, 0.21185490452954847, 0.19428970352295907, 0.0806010221581786, 0.14632553613233953, 0.13287837947568587, 0.17734150973058518, 0.1309103455634848, 0.14973919327941634, 0.1843776289493807, 0.13802903373875927, 0.13499762382238142, 0.13031753140591806, 0.2078702973742639, 0.18844328820705417, 0.14817050568038417, 0.10818132890328284, 0.12554108811121795, 0.17086797483986424, 0.09725103920866406, 0.1574333820251688, 0.14314348268653118, 0.12252972671581853, 0.12439118247599372, 0.10206245441710758, 0.1666320755236572, 0.1456600049090001, 0.1624786225898612, 0.1821842426133733, 0.19818285510184305, 0.15480766162997292, 0.19428571986575283, 0.14484160850124975, 0.13694500400414392, 0.21567005303598222, 0.17832438521567853, 0.10762893354460117, 0.12797192339935612, 0.1855005759505495, 0.15455263095997995, 0.23626612769740246, 0.10088477043374892, 0.1403683904678591, 0.13183967150267095, 0.14057125055020855, 0.12427443067633337, 0.09576305897245485, 0.18889143432099975, 0.09394476460593362, 0.22246133055417772, 0.11431790768138825, 0.1541396789252758, 0.11316195761244144, 0.1491839940389318, 0.14482264016424456, 0.19164360518897736, 0.18370670446705434, 0.1990981309884979, 0.18992056619496117, 0.1039585679949772, 0.19691479572605705, 0.07901764099275874, 0.1401999430550683, 0.1091912089877071, 0.1465522215491341], [0.025306529057542645, 0.018167759802552964, 0.027736109876704794, 0.03644883166998625, 0.06421132944524288, 0.06546104101524239, 0.01748271440456231, 0.06033409334298584, 0.07392874873814083, 0.02042711396972018, 0.026936350472932382, 0.011394166466479581, 0.01660691311342582, 0.034679187717096466, 0.035295516943498965, 0.1197602958869069, 0.07338080435029923, 0.05201824339887789, 0.07124484396509587, 0.035358573640546495, 0.07309274762989053, 0.0201084922563525, 0.06494193983774993, 0.03810101519188574, 0.04320237552747131, 0.0530185780277656, 0.07138820199836647, 0.050578116844858856, 0.025382164918306856, 0.04114901857270349, 0.026445276622149735, 0.023953587139746355, 0.07313169553996095, 0.01021149333551406, 0.03428650253842916, 0.026332793847447442, 0.05734193394140852, 0.03289048349665057, 0.010070092656889991, 0.025399083970114592, 0.05824771416824191, 0.029393131243846113, 0.09219315053234178, 0.050922232049126784, 0.06208114153254898, 0.11822704751525195, 0.08477489133515666, 0.049002568928464774, 0.015552168047325987, 0.02376914764153621, 0.05338592484833733, 0.019883497978650758, 0.09146028018045811, 0.03027955625927256, 0.060213664321288954, 0.05648783400594708, 0.018251592804106976, 0.05247796893179898, 0.03183121180852815, 0.032945063430815935, 0.023314976246066155, 0.03766271713820677, 0.030485564962990826, 0.03006942408730186, 0.0981586005899214, 0.09873496683975382, 0.03369166590874234, 0.0436966248127001, 0.04208700130543402, 0.02716067825414, 0.08476210532770043, 0.03486155494747143, 0.005104684678371996, 0.044820663489161, 0.06169390706946293, 0.03493061011296607, 0.032682521268725395, 0.031176627981626702, 0.027439268043024406, 0.03553583106446651, 0.05105643916214186, 0.03893449970130478, 0.04985163566626368, 0.10461760279271873, 0.03947986620328119, 0.02365923317660007, 0.035018005423367984, 0.047788147198697256, 0.036627437408653, 0.05395813890162015, 0.0480729365541089, 0.0514619984483767, 0.03004049852250084, 0.07215692526510648, 0.029119869596475077, 0.051524089874639634, 0.05842984391136035, 0.033637327292273124, 0.050047643092130466, 0.01971470774151385, 0.01751265120542338, 0.012902733400434017, 0.04581752773975173, 0.060223309368255644, 0.03902088377564665, 0.15690734009108237, 0.01907067486054955, 0.004468887242593713, 0.11480715441247148, 0.10538660185111147, 0.10187661680843561, 0.0894549990733785, 0.016120221285570054, 0.05360085847637346, 0.1414965621886715, 0.0778353221774582, 0.018550978049695976, 0.11939275754435409, 0.05996612216075582, 0.04621412379727249, 0.03072727527920037, 0.047447567490199884, 0.04133191057330659, 0.024421107617297003, 0.02102487514005794, 0.021921288026797197, 0.015362030770179006, 0.05351655816118564, 0.02070164157738609, 0.04488103887847355, 0.055642942447335496, 0.031983182585287484, 0.02370993287542895, 0.036238410299824136, 0.024458603790750908, 0.02230323073754628, 0.09855770175495455, 0.05349212378684071, 0.022905839329224922, 0.06359683882985866, 0.0551143839144178, 0.049604438245296485, 0.024562981355214314, 0.03197320045963411, 0.03190426978342716, 0.04540193653214843, 0.022874240117568164, 0.037896381615991556, 0.02447163877678254, 0.053060088501942736, 0.04059956882209067, 0.011744320358810647, 0.010612226267825934, 0.0650515363761975, 0.0391149785249464, 0.00467793587895651, 0.07500274272094812, 0.030163924863201477, 0.053876473928891846, 0.03028417002379654, 0.028579731644581885, 0.10185014847065173, 0.029693707756157366, 0.005754284145716097, 0.07778924198881274, 0.021057721159811464, 0.011618374546449031, 0.040189351721276204, 0.05207544335374429, 0.027292075739692778, 0.007000899762891594, 0.0326783690721758, 0.03325855427031075, 0.028516841571657892, 0.03795763800641702, 0.06683781592836303, 0.11452384743719332, 0.047767853529583064, 0.049464079446249434, 0.0650721901066361, 0.018231165069606037, 0.05608388733479285, 0.05770521666554194, 0.06085874099705008, 0.05309392277511859, 0.034536798785050074, 0.04858840264440064, 0.014565508087886678, 0.04133481787697923, 0.06343587226564847, 0.04732653325904281, 0.046809649906091155, 0.021832666975716432, 0.02849310816776368, 0.05659544254623114, 0.061513481871976014, 0.02172714794024585, 0.0048510190812991036, 0.029833331110797105, 0.07841418587392376, 0.02601556066844252, 0.028460769681259993, 0.02322671334108999, 0.06882736925035715, 0.030696710286241387, 0.07987796539260496, 0.07255673889190921, 0.042135130779276934, 0.08257431143354024, 0.01765757780371895, 0.01409217396060065, 0.027662492657621062, 0.04216148803431181, 0.011395810682687068, 0.06118355078562614, 0.015696598603690586, 0.056211981066172166, 0.03958164481446147, 0.021730212291942972, 0.04675980056485823, 0.0030740470186086193, 0.0560190724659591, 0.06977299754057201, 0.02435044558238118, 0.06106517487956632, 0.03062872764384074, 0.001862190246972586, 0.04828628438014177, 0.12015500736813392, 0.015626867365602766, 0.023402063206078547, 0.061222548491411635, 0.04178103344935564, 0.04211725028712423, 0.016667426398564732, 0.013465317728508626, 0.01665933651008433, 0.10858825948690215, 0.05674950282780394, 0.035730022861952745, 0.02216818475825412, 0.03903806712778826, 0.050562898508243026, 0.023170932564103318, 0.050839525196821465, 0.031035642905701554, 0.05055279763896139, 0.024822376811155872, 0.033749072707348296, 0.020829900017669125, 0.00251514685524237, 0.0550730228273859, 0.0744524694258167, 0.04807097919946236, 0.0879095699037275, 0.03528011091534169, 0.06453594388139826, 0.0029551640581039172, 0.03911642260068367, 0.02502121684712268, 0.05681844691054956, 0.03916717592566725, 0.04690961671933051, 0.027675286325956547, 0.03777535504571373, 0.0548155176933975, 0.013994338787010601, 0.056836561059519175, 0.028638117120511113, 0.019105587402478825, 0.045139367556980545, 0.029852098349722165, 0.056699867991189805, 0.032124629229187004, 0.041914891992365165, 0.017302867603458224, 0.006562060180811152, 0.020357784927792607, 0.017401725504427187, 0.07690323832174463, 0.050131334367418484, 0.019632615674767765, 0.03364494603668009, 0.024488716791834564, 0.04685326712206007, 0.04443131462340394, 0.0690497875574135, 0.021778571592163176, 0.02551696766468306, 0.024587076735652746, 0.08174413259351447, 0.0014595511921441124, 0.0649822743669633, 0.05175847830551286, 0.043677844167236364, 0.025477661608508038, 0.036508789541380066, 0.04708520790201522, 0.017167304514817173, 0.02683186565615958, 0.06484899038989698, 0.03090299286639258, 0.026525357708094582, 0.08246890539603849, 0.0317960694402216, 0.019977952789274916, 0.07821850403542481, 0.03968853323209671, 0.10072161668851491, 0.020782046335478945, 0.04518130704039528, 0.04459293236234977, 0.044741434676031915, 0.14317086266894496, 0.041333959858504035, 0.030375746259045218, 0.021336933395134348, 0.06403538969255264, 0.053168700617407604, 0.04702054625076633, 0.0599269942200232, 0.04875674663532165, 0.015612257111276832, 0.08360144381801929, 0.049081521949941115, 0.02905215891528755, 0.0543250069172392, 0.026668604658616167, 0.03970143798318121, 0.024454206446065538, 0.06108959393215276, 0.0018194482864571677, 0.044798868287715225, 0.03577646694236225, 0.04463427812762318, 0.0485266329750659, 0.058515086514695044, 0.024286325938338717, 0.036918803628894596, 0.03836178386043157, 0.054920651769686135, 0.06326771213582928, 0.058293273417098876, 0.017183204669685617, 0.02624368441531495, 0.06511631677107466, 0.05468934684270813, 0.03733465913683176, 0.05809960255940115, 0.010429232760572867, 0.06295542405437558, 0.060268489403590086, 0.23605808886068486, 0.08232331038602898, 0.1614058237042158, 0.07076455280184746, 0.21402069637852333, 0.23609639325689888, 0.1622011608654453, 0.10544026631020731, 0.12951143837023166, 0.07735570517158316, 0.11942062016216018, 0.09234482828047007, 0.16381417431177633, 0.07883121349638508, 0.12681718374932968, 0.20992140586097396, 0.2637852776435114, 0.14596688440970837, 0.10655120871360264, 0.12799726558789132, 0.16511727454921893, 0.2053776004862401, 0.12970484492759551, 0.2268669030238544, 0.2170018202835514, 0.14643370774724793, 0.16679341364051067, 0.1564246740552687, 0.1329733284130212, 0.15429640519282511, 0.256506247265685, 0.1112184155311796, 0.19514407541963363, 0.14788826356732077, 0.1385978846660545, 0.1720001302178829, 0.25787659470112095, 0.14732483654252945, 0.18553624500430402, 0.12889614719296658, 0.23455143906176093, 0.08090429338476351, 0.15661176804813648, 0.18028851207946578, 0.15940710030976804, 0.21265669215110042, 0.23882391141547313, 0.1573791736436467, 0.14672477519319904, 0.11246012148237038, 0.1276016041576382, 0.20802100219072836, 0.21454247886375075, 0.10200564133664293, 0.14267019356691069, 0.17238675947150878, 0.1289103964283582, 0.17793150468459054, 0.12682000295289103, 0.09600976992759014, 0.1246609986429253, 0.15576864232219037, 0.12236933854799117, 0.20497912751330485, 0.162786559291905, 0.24998067968314697, 0.20696323395015734, 0.22050527825711236, 0.10556945171687873, 0.11742836254979334, 0.17569325623973725, 0.15301054193367883, 0.09828064605713853, 0.1776562033281211, 0.15950997059624042, 0.16882658034803408, 0.19646344736458796, 0.09472457316493797, 0.14014993283537128, 0.07299954537302256, 0.15022193592402244, 0.1704776223989264, 0.10481255684768963, 0.255790276813411, 0.23496187832807344, 0.17973391038756217, 0.1324585326496632, 0.11387692448953468, 0.18977634248233613, 0.13386503943512518, 0.10926066251892237, 0.13955178670585155, 0.17950065193637726, 0.2250056770900565, 0.1419574560056771, 0.10977294551388872, 0.16025554268590866, 0.16123638037712346, 0.1671970347242971, 0.12681181347298046, 0.1215202603188734, 0.16221089018208368, 0.1416383650634558, 0.18165507504055578, 0.21292295367006334, 0.17076901160180571, 0.2027163336113576, 0.1096896640956402, 0.2943249743792319, 0.18416628061283022, 0.14776640962208473, 0.17026768366415657, 0.13316638256993987, 0.16863804610986866, 0.27853305241273296, 0.22326149406933019, 0.16061255498038185, 0.2187814578534134, 0.16854268348505422, 0.12014169276000992, 0.07472490561344931, 0.12823899697151878, 0.2384543812443172, 0.10386941834322869, 0.08992677133890892, 0.12177368220422538, 0.17136656018274446, 0.08680129348630868, 0.13022529441983471, 0.1232553115715423, 0.19213669002056125, 0.08004050626749955, 0.20833140569588832, 0.12552489301249867, 0.1266761086580734, 0.20547409692118246, 0.21809274480948526, 0.18682331868237068, 0.09958788316937224, 0.1314923272378022, 0.09725234155813534, 0.200621634721756, 0.14681034721434116, 0.15516346350552576, 0.12257422876334, 0.1100042121364705, 0.09583062026649715, 0.18655446778622367, 0.2139137045390183, 0.1196128239614829, 0.19019654170880396, 0.09888554908215039, 0.1852433389473346, 0.10608259273032028, 0.10824212564095374, 0.052178486009999636, 0.22136588610949057, 0.11248787684786705, 0.18371079537657, 0.10092362641326844, 0.22636215833406295, 0.17768903785655576, 0.12173880988191213, 0.13763443717072088, 0.24190931520875425, 0.2364601777686227, 0.20822657422432977, 0.08844150305395165, 0.1515571199237339, 0.12149514029583625, 0.16703794890594098, 0.20187812616988537, 0.10199251058962076, 0.15591628278695768, 0.09864115171254643, 0.09424936882550679], [0.019176146015524864, 0.005449887248687447, 0.02817760251702801, 0.022399041523796417, 0.10525646649541394, 0.06180580187168333, 0.03568484665705793, 0.03705828908770796, 0.015488128842515572, 0.019665967312551314, 0.037772995494906945, 0.03805575854775887, 0.04071288854785023, 0.03326833338266419, 0.026770071088967305, 0.10528755434338125, 0.011926904966634129, 0.005340424296821678, 0.013002639884249339, 0.002999593806077516, 0.02715969000071768, 0.06899328091211858, 0.04084267533354221, 0.02476552734151483, 0.04994319849497369, 0.06968511193389855, 0.008681984430539512, 0.024614879981644695, 0.027650922814744617, 0.05181525308158129, 0.03793099729885017, 0.022776213421997045, 0.021250288850898226, 0.002138886841074113, 0.03557172228371905, 0.03702397600957944, 0.008441916415317646, 0.017037412392035607, 0.03682980719473093, 0.013722038579984538, 0.012206537592705461, 0.04382916185404024, 0.029702347312723438, 0.029562214509614056, 0.019102787351115577, 0.04558744089257333, 0.043704255048425934, 0.009032734913841612, 0.017473245557818203, 0.017854885663837194, 0.006576023090841069, 0.09211463418098227, 0.046608705043552384, 0.041005415391297116, 0.025998308368387724, 0.021000479070109226, 0.0787214330968357, 0.03970862388791096, 0.048290068854487715, 0.001499986749202494, 0.06453497861061366, 0.03112407051958144, 0.02117723087599922, 0.02040720142934832, 0.05230889332691028, 0.009979621503472088, 0.03181041443660375, 0.03859267509993046, 0.02018294834171332, 0.012134619173593821, 0.03155220258650521, 0.017185506763898076, 0.03079362806954211, 0.03878890086085566, 0.011694712335273865, 0.09305291568800327, 0.06572354104249709, 0.031021251944043947, 0.04494496891575475, 0.04720017471681199, 0.016639299480424776, 0.05291778767000764, 0.014409734642193204, 0.06503298172667142, 0.03236043109228054, 0.03913094762772803, 0.04080394575853021, 0.014258540487067114, 0.08463811399715562, 0.017030308841757717, 0.03902492871988685, 0.04146516007641631, 0.0525246849734216, 0.07329805919359769, 0.09536876883958617, 0.09855082994627376, 0.04901285748928786, 0.017322324321515137, 0.06294662553456522, 0.06917976203464693, 0.03377366029927808, 0.060356903610931295, 0.0548826499782022, 0.03143258753322786, 0.0516970074104686, 0.03849397999264541, 0.06805321442023402, 0.020300941203811, 0.029494745146122672, 0.03390032910711823, 0.02786043254027684, 0.04710069053896493, 0.011947804802818405, 0.061968396372732625, 0.06272749757514366, 0.025695839618903496, 0.027583834579995567, 0.030995032584835446, 0.020731180012526534, 0.04765630346692858, 0.040897806851013054, 0.04746642857489567, 0.01925491134545976, 0.04555770135935276, 0.05271870823156449, 0.018442245275383035, 0.08204787113373319, 0.03187294444820333, 0.04871380740716573, 0.09635568160804049, 0.034647647877253836, 0.04656305386414451, 0.03555373453925695, 0.054205681062153274, 0.07521540106784913, 0.030073890379900416, 0.041122121225682, 0.060143889033145485, 0.04940375385265197, 0.028286419561012622, 0.029758652859938242, 0.046926171879374215, 0.016973296578432766, 0.0362629595873577, 0.04457083072573428, 0.06008318039558588, 0.0573074255108593, 0.04866980331679506, 0.019143977983584328, 0.04845366310027819, 0.05277940537780524, 0.030405616027212916, 0.0905787657886263, 0.05488552280791825, 0.02543130562820983, 0.02351834194644565, 0.04805028716462755, 0.0149468848511817, 0.006329772267265306, 0.04549610022936137, 0.038094806049259446, 0.030798140327416124, 0.057275004669903755, 0.012856737481460217, 0.0056135178836543235, 0.026110789227870204, 0.1017797909556858, 0.059688863449639855, 0.04459716882857104, 0.03102270751110008, 0.07523541128443134, 0.08893027481052185, 0.14805206848729044, 0.03829414978803646, 0.004903663207040799, 0.04250532744692699, 0.03703604572482648, 0.016142133315424287, 0.06169700589511664, 0.09145310959748684, 0.06220049803115188, 0.04829858775220571, 0.05461127482234471, 0.048769440712226976, 0.022710714819690874, 0.06139370785545438, 0.039334029875575535, 0.012138212125958696, 0.044666882829680565, 0.012065562092879368, 0.031005568209014116, 0.018321477259779652, 0.047288516145800395, 0.09588510443967196, 0.09319350814386722, 0.02843751891275808, 0.0404078591494791, 0.030257669127275868, 0.03953886263433003, 0.07207061779955704, 0.0034580426055922987, 0.03978531311957106, 0.048705717518685326, 0.029930049711237514, 0.03844891870093923, 0.008176398959251182, 0.015441693380595216, 0.04800121923307738, 0.04122085080692365, 0.05092851013966626, 0.0362127578456796, 0.043331909504148274, 0.055402666630764166, 0.022320617102987828, 0.03560793525989979, 0.04300556370928403, 0.042345452558008895, 0.027001081072094462, 0.06443244540282796, 0.029861440791958765, 0.03247465480179076, 0.018443359933312864, 0.06350773131294597, 0.05355571674543524, 0.028436929025056384, 0.03950423162971293, 0.04020072812695177, 0.09584124590600691, 0.021974632644184658, 0.005059205868747085, 0.03977477174973296, 0.03250318391609096, 0.08569053494401517, 0.027850073116320758, 0.04471648702277772, 0.05474309557147565, 0.03561297611844155, 0.032972776661476785, 0.04544240512674855, 0.05059713880801874, 0.029686272872852224, 0.019357392842310573, 0.033377627316381664, 0.042026480359415856, 0.01885622769834534, 0.016258057740126407, 0.04441832560264776, 0.06361888300987982, 0.058923085790968714, 0.048393096188984575, 0.05279136017986363, 0.04230435577131087, 0.03821810407023277, 0.06936384530197229, 0.04247500568688397, 0.043499801503193956, 0.01116443872301569, 0.03615250119999532, 0.016827138493798913, 0.021980449166749755, 0.040182276899295474, 0.03416395145318201, 0.028481063350374182, 0.010775306277097234, 0.026214557752433806, 0.028477223334653724, 0.02554914527272265, 0.04082035919230792, 0.020260350035142996, 0.038854052808376095, 0.044988881075574506, 0.07264156780776478, 0.04405463302147485, 0.018707786671697132, 0.03654816263024846, 0.030435995243850256, 0.015758977312925124, 0.04124085719306623, 0.07578241338412608, 0.03824358798503395, 0.053092329312236085, 0.07109540319370647, 0.09826278088674431, 0.054111877426264755, 0.017664809673724156, 0.025502230048239715, 0.04417344942809113, 0.06482947046958631, 0.05526987678040901, 0.0020152811879186982, 0.01509801293122432, 0.01575457805301994, 0.040475857113638235, 0.07943162724616067, 0.08713110965946991, 0.1056918112801448, 0.007923854244572502, 0.07345378954684542, 0.08679744006404955, 0.008642157434575982, 0.03607565875075037, 0.019763038313436895, 0.021635060341307716, 0.019352622029762116, 0.010386232245383004, 0.03557098300887212, 0.011296950866498295, 0.08329192131397226, 0.009558591071606405, 0.03646234929141018, 0.04691487208249108, 0.0795684582103164, 0.0830558283374675, 0.024318852116383856, 0.09741294423058149, 0.0121297296174171, 0.04422010035224019, 0.020248305217753497, 0.00995728429481988, 0.02503957231378844, 0.01637062286928056, 0.06454594898968935, 0.04477909555838955, 0.05479359608744422, 0.012441763932245874, 0.042052339657299945, 0.033515392907805024, 0.05974733511046056, 0.06845301272527826, 0.019792904251164967, 0.026313139861750028, 0.016328871077407273, 0.05936473547931641, 0.024688414846276565, 0.048084247842310905, 0.04230795255411537, 0.07711694620910191, 0.027717537990200426, 0.034985071303503174, 0.0297970166279664, 0.04213704599908764, 0.028426998610337897, 0.015042684146112975, 0.06131451734672151, 0.02024309198942877, 0.010265716081184727, 0.013423342813527393, 0.030311249316700047, 0.03158621880556307, 0.01059293425867274, 0.029477573285299926, 0.10647321330203165, 0.19585376395092857, 0.06962371764764672, 0.11806934831603882, 0.10764996265812267, 0.2293572863263469, 0.16489235113465017, 0.09653939715316219, 0.20094089420332065, 0.08985609972789403, 0.18868437607682523, 0.20948858150551397, 0.08993537450629858, 0.13075581030739894, 0.12097050796353048, 0.12279768894997337, 0.21792365388283808, 0.12369150671386912, 0.14609471384075381, 0.14050198088009513, 0.12849732948046538, 0.07923687237405008, 0.20497793241614298, 0.14662460153622014, 0.19214614354554685, 0.13363953379373397, 0.1830384153271875, 0.12162310762270806, 0.14710786512061474, 0.19636845246197718, 0.10327828191821614, 0.09135299722754187, 0.1558666709329813, 0.15378038368878827, 0.13712668941626627, 0.15345059815914402, 0.13217224559235957, 0.14630364133946358, 0.17417726016813712, 0.1546882285225776, 0.0844655450313322, 0.12089178476843143, 0.1051274189845689, 0.1439104592728038, 0.1457717158501187, 0.09535875607041583, 0.2074652666886968, 0.17323622840546793, 0.11955077850049543, 0.2522815021896555, 0.1380286660165556, 0.11726117152119837, 0.20043440283306185, 0.11019136741637223, 0.12217420063191846, 0.07730431599362243, 0.10690694930212152, 0.16846400625523061, 0.16801103378736204, 0.134237342844567, 0.14132851314160133, 0.18125338449833855, 0.13389948274820082, 0.09557406508153486, 0.11815225435120445, 0.1457499589530691, 0.12117517601338126, 0.13771561184717765, 0.1383027263105877, 0.14152518323352262, 0.10396510272497132, 0.11704480530874384, 0.2510587952189869, 0.2064724320605878, 0.18175550916742894, 0.11753230535935973, 0.18476480978631205, 0.16887482856550526, 0.1900590595699126, 0.1488787233228645, 0.14769246681563317, 0.10803052449538823, 0.11170272865603048, 0.09698608770005165, 0.11188935533526445, 0.08223052947751938, 0.16410305074626402, 0.10181673937627386, 0.17057390432924996, 0.1833405910480407, 0.10004198944736874, 0.2042824471549642, 0.11925532137073817, 0.12634158104417786, 0.16949500738372728, 0.17275978300359943, 0.17564085582571645, 0.1101006779278959, 0.11370417932348867, 0.27392742374250967, 0.1969631665175961, 0.07973397150635719, 0.21455544107142957, 0.11146561678258643, 0.17451683630145368, 0.16266423037215588, 0.10496303183777679, 0.15016605747082543, 0.1921520424225638, 0.19805727796929498, 0.10115242623273404, 0.1647778516334872, 0.16796353633605665, 0.08874922525137664, 0.12648147636003074, 0.1340487013540922, 0.08875098725360248, 0.182574778915413, 0.15658029715620703, 0.14653578130227907, 0.1512524161127306, 0.16839994598300229, 0.2218009780852064, 0.16428078314469707, 0.23519691410324267, 0.11207013676363616, 0.0991400511514756, 0.21064391870412136, 0.1153515747958614, 0.1528849188358553, 0.12893642809602524, 0.13351841529290523, 0.18326125498260223, 0.1271959682626109, 0.14262527017103088, 0.1406848154241039, 0.1876703514567306, 0.14238565319007443, 0.12069823265436197, 0.21145701378343568, 0.08907403887039231, 0.14549849825280328, 0.1419021138140271, 0.12257772978515395, 0.21322563500894656, 0.1104257979820813, 0.10120023778008838, 0.1248320967199341, 0.20488854527713793, 0.0917380636618022, 0.16455404670728793, 0.13465168915929335, 0.15433201295954568, 0.1448971345540016, 0.10466977338036222, 0.21248153380809293, 0.07553195625904106, 0.13202580022475413, 0.09960484435601581, 0.14235623541378206, 0.17342292403261508, 0.17682698975887992, 0.13627483028798335, 0.2519456186001339, 0.16428121215393468, 0.08401591270681351, 0.1752826484340814, 0.19033941710668226, 0.1471328242651878, 0.18823408491669164, 0.11906744596818764, 0.14353719059257738, 0.12724395601018784, 0.24193870234152964, 0.11838627889031365, 0.05719374955421495, 0.2923951988979694], [0.014273410253677399, 0.021069187580818133, 0.027050997446020766, 0.003844662043716639, 0.02563960301960188, 0.03448827860636577, 0.007421338391835772, 0.013780267007889287, 0.05254829580324793, 0.061792115710916064, 0.017879840977970633, 0.02244216844349379, 0.056967784260069175, 0.0167410857524843, 0.0685557144724073, 0.03662092566129662, 0.04650369354133164, 0.008038189994441646, 0.022080663043344696, 0.10185612395646111, 0.028570249391299103, 0.060089282285902774, 0.04257673833278879, 0.023523938218732516, 0.02106756922007809, 0.06266631013263138, 0.08721878076152456, 0.018094889519195405, 0.07766266128108387, 0.010324368730277545, 0.06047958493112557, 0.035722113004134554, 0.021187636265230757, 0.002637403954248575, 0.05939549773991589, 0.020757433845691627, 0.011065635405811331, 0.0339080014776799, 0.03281500468391084, 0.034522932593620596, 0.03295967272753197, 0.04438667468005612, 0.02066668115496155, 0.03208943706516537, 0.002081443892694229, 0.010141647184237598, 0.033697641394551725, 0.05904248825484707, 0.04110777622929985, 0.04497487698831866, 0.051973063363543445, 0.018372929639994137, 0.0113017302975359, 0.019698572014608694, 0.032489310063782244, 0.1439087585576119, 0.022160426202800967, 0.036885505617265744, 0.017827553561918678, 0.04145924587764087, 0.03715853552303968, 0.01692843830002652, 0.029360574422284003, 0.04765688186331142, 0.047867360690067855, 0.04047521743022146, 0.052955954170395295, 0.06241366199608292, 0.014958380000485529, 0.006665183276298546, 0.04856507909754592, 0.10722754177667441, 0.024253437783749356, 0.01735070787910973, 0.035538500880882624, 0.008171401193155157, 0.048160764704188036, 0.04324873150776952, 0.059103376923068884, 0.03255146277707911, 0.018854256937160127, 0.03206428256817162, 0.040714608415240244, 0.02435486782492409, 0.04282377870573152, 0.02498115236390262, 0.0019568955922882347, 0.06515676621347666, 0.026529322213102734, 0.014955302242249733, 0.07654104727290331, 0.032535585604848406, 0.012107087888814991, 0.05152749130502344, 0.05220923294884063, 0.061568383563069574, 0.019072781602341323, 0.0035259270929776498, 0.03661824818400126, 0.023277646696735776, 0.011751083957572139, 0.035709798140751745, 0.07127156511189477, 0.018500048524489807, 0.02594387973658741, 0.027668617530575687, 0.07835918076096043, 0.03246032895760671, 0.039059762737803885, 0.024108806129304633, 0.038506570647680954, 0.014475411359941768, 0.0584692438133061, 0.03365924889822641, 0.013979498706307384, 0.030033029165239106, 0.06719478225756077, 0.028310679650354772, 0.02911308205746595, 0.023687436703532457, 0.006519357961106805, 0.0411068377715926, 0.008037567548003168, 0.04892555027899723, 0.05505573988381413, 0.051453747681432196, 0.020929564226178393, 0.013541330887575545, 0.054244199962986094, 0.018476686673238873, 0.03596824173244738, 0.021752733361697005, 0.01987725436206787, 0.01246916019402805, 0.030213467769264698, 0.07076212430312749, 0.02322797930138486, 0.04606259543628943, 0.03894063223513865, 0.05482529680575094, 0.05853426935631902, 0.05275468372048871, 0.009965609755336998, 0.0386912782766646, 0.027054373978547035, 0.04005963771393703, 0.024064949510859388, 0.06179326101236286, 0.0796083867129299, 0.074063794717433, 0.05474077049462546, 0.008902427188361125, 0.04628762227272795, 0.07246010456114046, 0.012309848379734303, 0.06655914378502677, 0.020690159834620934, 0.04615980050256176, 0.009550925404314072, 0.048241318849426125, 0.03857877443454439, 0.011794645632166537, 0.03561220620007765, 0.049132313579320915, 0.037004195619374514, 0.026675290690975326, 0.07543358290868421, 0.028723941950668252, 0.1006941754190672, 0.03406160593693776, 0.023816541670971823, 0.03152290163862129, 0.029112185734594544, 0.031753559221303275, 0.0357018806220543, 0.03592299274919975, 0.055138232231500654, 0.04242473116685306, 0.05818602876857885, 0.023578401324489427, 0.06397974872661215, 0.025797493740796082, 0.013910191689407634, 0.03661037280013965, 0.03788171486268121, 0.08380249593286745, 0.024957321283798066, 0.019316541203748316, 0.005087240856336129, 0.04004711217637505, 0.03773351898416877, 0.05253450239017125, 0.015871569255156624, 0.07966612675978292, 0.03305978509747694, 0.045066849674068155, 0.047205456893049905, 0.025603675411172935, 0.10057149409887292, 0.027031772469560948, 0.04380699126951156, 0.014462290189018654, 0.003828344610331941, 0.04756645667516897, 0.034010105676228, 0.008342713774782757, 0.054451725520794435, 0.020932839252054695, 0.04706475335443693, 0.014691561152557693, 0.04623249075525711, 0.035393537893410654, 0.06712188899156547, 0.05138917029985497, 0.023840181229095307, 0.06315323944774366, 0.034963666806898774, 0.0427869068939359, 0.02112916651962986, 0.027694645367803115, 0.03290787752297136, 0.013649536018830635, 0.04574647308477471, 0.043488781328403184, 0.05093775299047271, 0.028877538749046867, 0.025004460588998856, 0.01690196613180301, 0.039571842719470306, 0.012534235532756054, 0.08833903879407914, 0.06820129155511818, 0.02224529342305276, 0.009483966446902243, 0.09475379941924926, 0.0825071714878563, 0.05124480869140356, 0.031148093121667064, 0.007924359383797574, 0.0023063031473993176, 0.047169845295889724, 0.09351551788108003, 0.08333791723294605, 0.062383895649785, 0.008848858490255813, 0.0466257275172299, 0.029681741462780104, 0.02395116247146601, 0.03932662946622699, 0.06365261003074628, 0.0634702581221298, 0.03851906937216559, 0.025868209401866602, 0.034794901467619405, 0.03512084123588378, 0.1042278479003618, 0.08374834117750007, 0.02133533610181222, 0.014218179144776397, 0.06627507072182433, 0.06778867659910072, 0.08436983000607261, 0.036772488496236266, 0.03903125660614141, 0.03943794970250419, 0.010823743143719772, 0.05406347216076909, 0.027775950279207002, 0.05788535074961763, 0.027454151216173367, 0.053003524400053494, 0.04237725286774578, 0.02288494045065055, 0.024627537669373617, 0.014965322672299322, 0.026221552135182485, 0.027524422546247804, 0.014639695084864094, 0.04641294276582138, 0.044721566185715704, 0.022170331719661915, 0.024633478681226412, 0.0419322936795652, 0.02943485813786186, 0.0562344121205951, 0.05250274804570983, 0.01411919866973955, 0.02272282475455394, 0.032568324372292526, 0.04657991928979755, 0.044114874345400644, 0.013903824541146957, 0.011842878527879235, 0.027759268714655793, 0.02659958588229793, 0.04131209570914507, 0.004355208891924591, 0.06084015570400704, 0.05348160539964034, 0.03346591894965499, 0.09514682550704288, 0.01581845637936626, 0.07526525040908207, 0.006867779537119092, 0.10583758249037689, 0.12525843231067543, 0.04889889424967189, 0.07542686431758827, 0.029147433439990687, 0.04559250473375282, 0.05265044979751111, 0.024504120904772032, 0.025409523833302722, 0.06017801825017218, 0.08040845063665221, 0.10249611380840502, 0.03318862959502205, 0.031581547584444765, 0.020879416110654993, 0.029724810925883152, 0.024878193977318948, 0.034946713281134446, 0.03915476530129391, 0.011455145150032497, 0.01965745416049275, 0.07475565638272993, 0.02736708149313927, 0.05835941361804163, 0.08652179396801418, 0.08946415382407366, 0.006705617875747022, 0.05273552769194207, 0.020478690839222363, 0.03313287754633254, 0.05057674171703477, 0.046904016616604025, 0.016166527470153187, 0.00739723582932305, 0.024870322423896966, 0.10617569539575808, 0.04894127423364309, 0.016463784906532497, 0.06538700627823991, 0.07034698891783915, 0.049587143810405854, 0.014226454809578437, 0.0496565054110702, 0.018108621645238132, 0.036103613299107364, 0.03198834601789713, 0.04138002472539102, 0.02426920961889048, 0.20972514945653178, 0.10033745423800523, 0.13034307277731358, 0.1425374458513914, 0.1647804410106713, 0.1838650701627616, 0.12383341684096283, 0.17073285225177967, 0.114083660976781, 0.18216168898488247, 0.16414239702205505, 0.07805070779736965, 0.0837793983819504, 0.1954871755574019, 0.10177528635869104, 0.0995830414936908, 0.10005329690513112, 0.2353463625355113, 0.17677602959015679, 0.20035269189505808, 0.10740011074249783, 0.2702584141685117, 0.18853008596887513, 0.14926823306708567, 0.2074806190906994, 0.12543359831456216, 0.10530896650086488, 0.18344278717713972, 0.1228982073465182, 0.0659992867299626, 0.164015747366413, 0.10844874721501144, 0.14201786969938587, 0.09877340147091497, 0.15368502106397383, 0.06778876086877239, 0.1923023182297907, 0.18475181693511625, 0.2383488602936268, 0.12984525352235765, 0.15665600196488444, 0.09107665399149542, 0.16056658970492502, 0.12335137899724707, 0.11018620398376258, 0.08087614731442544, 0.15121795747789646, 0.12144281649060788, 0.14140932009585444, 0.13463793022017326, 0.11947419269070511, 0.09056954209001795, 0.07090617947640919, 0.14705813069257045, 0.1705957838003674, 0.30030858072061695, 0.08438067781108041, 0.18234035601058315, 0.18277754706721153, 0.21410165655036129, 0.108007357996558, 0.09209322202349864, 0.18294884432708064, 0.09775861842377533, 0.11844487695564186, 0.14551008150221842, 0.2006262006057847, 0.2467108785264915, 0.046414310232766216, 0.12138783436028228, 0.1832829046273424, 0.2143119170420593, 0.19005486140808753, 0.17359463497996333, 0.07836464296786055, 0.1904340442870894, 0.22670999289520327, 0.15381599145550884, 0.15153760000342323, 0.16911429232887684, 0.26614917982970515, 0.18735173548902237, 0.1974617978257518, 0.13667983033003347, 0.19273310479137207, 0.12635728584662562, 0.17275895562864121, 0.18466267494424699, 0.10244159899171322, 0.10212517403546842, 0.17261165224256056, 0.12067787003733459, 0.1488335701006074, 0.12427990820499198, 0.18813135252604563, 0.12665291151572622, 0.18143997287317631, 0.09377165937856322, 0.17697018691368643, 0.10720528692247407, 0.09508521671617225, 0.15467777908329042, 0.21512970057947023, 0.18008125465243094, 0.10079264069997496, 0.10777280485678105, 0.22675847093905174, 0.1286138591146277, 0.14086279297067275, 0.09052879387332548, 0.1018647118020923, 0.12333836316341355, 0.09799543918380815, 0.17807888467946362, 0.17051329145268088, 0.10777462814604083, 0.1293335067889383, 0.18049935479798626, 0.09535098027798439, 0.1660069937427198, 0.139622128899059, 0.1333540434678716, 0.1126126649098531, 0.12425119522958995, 0.1248478628094158, 0.18993804832139324, 0.11700131449728243, 0.06164596528716146, 0.18122649481219633, 0.17845020749636237, 0.10794397188170303, 0.15090301873222475, 0.14215824765063104, 0.1687657376450877, 0.1868125321643968, 0.11839155723611194, 0.10750818276597608, 0.14976082760239803, 0.11992008650615332, 0.14999229340784012, 0.11606938385915373, 0.2477545507492558, 0.08236731447639965, 0.12777917567760716, 0.08159346608144623, 0.1629217738105405, 0.1282385909449189, 0.1479528754228546, 0.15849239132817716, 0.20448688537843768, 0.20103231913620428, 0.14316439688686403, 0.16365358696108864, 0.13207314445847465, 0.09821919048385275, 0.1045141349576654, 0.08148940069781196, 0.11510500939743173, 0.27926380836194564, 0.11666851824209576, 0.1417150198211593, 0.057919096922682184, 0.11801111031203501, 0.2896806735905909, 0.1770426435095649, 0.2227630619440348, 0.20119761026674704, 0.2653478212173908, 0.20943572143873862, 0.11884122020414761, 0.11242167919032997, 0.12769292949909164, 0.19893072545528415, 0.12523539604679232, 0.23201653072910927, 0.1326665714863808], [0.01746812809048401, 0.05511287472120697, 0.030634616944758646, 0.054460140996642654, 0.0071563126684557055, 0.07278883288944922, 0.034547822790280465, 0.09477036224017221, 0.035734550441585244, 0.040181732976869236, 0.013546947269670427, 0.04402130053588941, 0.02917789309586008, 0.08384052453742874, 0.012035225968687766, 0.04760720489186145, 0.025329055872956113, 0.05918943541004293, 0.028229198538728302, 0.016054531161282814, 0.03742912543877479, 0.013289049515620837, 0.030003199616687435, 0.016765320943968914, 0.07698714793209108, 0.019584616435871973, 0.03194780081450459, 0.04316435841422889, 0.008680650479941359, 0.03974404013265045, 0.04106608572446051, 0.016749374823825016, 0.0050447406923218125, 0.052128123389857436, 0.0342455972737122, 0.02133126434449467, 0.004794339108611307, 0.04515984508719656, 0.043106986089579524, 0.044776667059669574, 0.018159325174506635, 0.031049277355533936, 0.11889645514348823, 0.028847036958341638, 0.02307984279468656, 0.04785172100509367, 0.023202493471363862, 0.07575323309509024, 0.019063278281640623, 0.009112296017607855, 0.02008940134527943, 0.04147416543996623, 0.08046331785378918, 0.023729705604754632, 0.06311215798280413, 0.03146351450273106, 0.04127522389734945, 0.055539562712393464, 0.11608425362576401, 0.06543427390316803, 0.017819153407828945, 0.020662046323019653, 0.013849259928740082, 0.022227345898206678, 0.026621017191979676, 0.04132575122639537, 0.010759281632941096, 0.025335862564163345, 0.022700560324254538, 0.06904290808785347, 0.02400213604672782, 0.023211657798158068, 0.07154197116652805, 0.08481226110410306, 0.04426367543337326, 0.053617589836639744, 0.0895414061303581, 0.04732728785564823, 0.03472312285955395, 0.04657863226208476, 0.040338187283205415, 0.04679460010881867, 0.0311569050480161, 0.04669005975067135, 0.040346464863227266, 0.01609811007285551, 0.04421343538729895, 0.08601289708167316, 0.039277450451927806, 0.05868008653182657, 0.02000945432472133, 0.05959159709633358, 0.037133116725712054, 0.0075798606567625566, 0.009767447707183179, 0.024717884333503824, 0.03150161397042534, 0.02251720867089687, 0.015876843770515296, 0.060255515704592394, 0.02360935510706998, 0.0448509622665663, 0.06355918177794065, 0.0382014301665608, 0.027845855802297596, 0.05477977969172982, 0.03959660268118305, 0.03157650098024357, 0.022205240431151563, 0.036332953210559585, 0.02078263622318064, 0.03411443152975652, 0.016401609210597894, 0.009158978542883792, 0.06766342122348086, 0.031748625615070906, 0.06668492776131438, 0.010764852049760522, 0.03184479837786527, 0.013322386789255807, 0.028294436671140216, 0.02615956221556952, 0.030879918298113252, 0.0030706455882248142, 0.07912552915513515, 0.048544218523367766, 0.039545987252025835, 0.01603010444781713, 0.01942526248674239, 0.027106163437448205, 0.09454376875392853, 0.08907534121986359, 0.05801801036502566, 0.08206854018593028, 0.04189221195936684, 0.026160690280038024, 0.04522250341852346, 0.06071653975654514, 0.05964359914463374, 0.043150005756967494, 0.0416378133119114, 0.0071843644142180925, 0.06517041790028734, 0.07215407541802815, 0.02481046031349369, 0.00979457296536214, 0.06267015206357164, 0.05768968040243753, 0.023404681311559775, 0.03051026938332906, 0.024395275132490263, 0.01764674532046962, 0.032852784309896736, 0.019335900245594884, 0.05036347049979433, 0.03571883797825825, 0.035642102781322696, 0.07339458627205703, 0.061022718286802696, 0.03893708141760961, 0.034408383296742555, 0.11944570188080111, 0.058785500230207566, 0.0518638996647731, 0.04856450070116309, 0.05745324268636685, 0.023133899873843598, 0.03661277065534265, 0.04018357541832713, 0.027855395512174697, 0.03692376021776469, 0.08738555810264043, 0.03405462687594756, 0.0368017568853834, 0.009534455471551948, 0.041241006580211466, 0.027112364919195255, 0.030919419706708966, 0.036047022384140766, 0.027536942338150357, 0.04248130292962155, 0.06707271380770592, 0.04562669523781346, 0.004527156847724391, 0.0959994200797331, 0.07102468561741614, 0.036642230566470854, 0.058048278498913974, 0.02980751011730923, 0.05143587101971911, 0.053512639621452945, 0.026388898296582124, 0.07638363918710141, 0.02623967202981153, 0.008365590117811676, 0.022400778628164725, 0.033503311701239116, 0.029426461814211744, 0.03650237738545384, 0.015597009088753935, 0.060505386772415334, 0.024045542588517554, 0.0032590167933038527, 0.008150726395298638, 0.014199753772587547, 0.043105706722745975, 0.0435943597356879, 0.019628633932781317, 0.04813123584514664, 0.05376561717580884, 0.06416971937963559, 0.009700622815158098, 0.024024963551651568, 0.012923565246315013, 0.0521627658857934, 0.008510873904601942, 0.06704796916775166, 0.05726568521030488, 0.014434902545725627, 0.014293351522346419, 0.03139663311172157, 0.010015030087332332, 0.03771301847131502, 0.02618930940966933, 0.02919540969624875, 0.03445853141226596, 0.003858111914239764, 0.031973476251286846, 0.1375887323651583, 0.038323261129159125, 0.06564326268891174, 0.07310810769277234, 0.05301997996866704, 0.05504900597095971, 0.026241545114786397, 0.07913751077027091, 0.043227575989740516, 0.07832894327058908, 0.009823451607277798, 0.06802556630704673, 0.051202007359074014, 0.03217156743630767, 0.0075563604308803, 0.04362540544881936, 0.007581281271057144, 0.06856448617914031, 0.03821024400812965, 0.037095934648307106, 0.10671701312305466, 0.04128311843340916, 0.07170197629039327, 0.0404690848963876, 0.022949686371571115, 0.08472377028796943, 0.028219111075985338, 0.04593669271637355, 0.048329434282476866, 0.059083079423515074, 0.05480485757993114, 0.020114580740130717, 0.03948794843088235, 0.010956955300043187, 0.031301891018125805, 0.06365202014304458, 0.003883891491099231, 0.06684100285412804, 0.04369968916439722, 0.06769344420923341, 0.009958896909900492, 0.01055839614221646, 0.06423271095920956, 0.03784699575795281, 0.04265808920946814, 0.03409485415285153, 0.05317811966843663, 0.03433165959112587, 0.009888346915343597, 0.021446154550499013, 0.011323833849371202, 0.06880041827718097, 0.0560032872242793, 0.046905108291896126, 0.019244373806061286, 0.01650544668307468, 0.0804283152965288, 0.03527521178306591, 0.03957084680516874, 0.08949243779023809, 0.02183886271180405, 0.039044115391950455, 0.12789929826413432, 0.048755800516735164, 0.02185736373517542, 0.04896288557398704, 0.04632819428919785, 0.025274324636425705, 0.0671092562016941, 0.044412599095413764, 0.040454230451535796, 0.040419944186484626, 0.03221927173135262, 0.048605371491923455, 0.020817087197135535, 0.05166847829616839, 0.030040806872890364, 0.023983351570824464, 0.061628341434463385, 0.041939560023526994, 0.05533626979036678, 0.029253044406012185, 0.021555239725257122, 0.023932906596230406, 0.019835257422058813, 0.05110480995368093, 0.07754897383312065, 0.05019175572200649, 0.01940387331189648, 0.040261547847260395, 0.03472793772215805, 0.05598735642589389, 0.02359480326694827, 0.04343888985233442, 0.05702775362278185, 0.02679876108173161, 0.03356778949138618, 0.057623375492591056, 0.04461547449952172, 0.020814296721871343, 0.02344052273509724, 0.06945098780335919, 0.03389246904501512, 0.02065698631227978, 0.03056746359253603, 0.049060301314438545, 0.06961051029183211, 0.023883120457251227, 0.015133194561536997, 0.04423290934233416, 0.019656421857014782, 0.06825696316457565, 0.04367039779261236, 0.03426475330225883, 0.04495441094942151, 0.006643803198746736, 0.01223592472548086, 0.058659643475567146, 0.03534987088172667, 0.030658465261841496, 0.06702009122818708, 0.05149206356896509, 0.024567221651875207, 0.024445291097846725, 0.11555853344860578, 0.1630502773989593, 0.15390389238394078, 0.10773676808082289, 0.1290342881674728, 0.11317232278205695, 0.15397549096134402, 0.14395420289328023, 0.142626756381604, 0.19016919236990715, 0.059015751786289684, 0.1194832631717286, 0.19935545992226372, 0.21983089105736828, 0.1752195227891207, 0.08664220000707334, 0.17128063576115718, 0.16770352609455588, 0.21375590574837502, 0.04551018475584927, 0.1735911416190286, 0.1228253294022814, 0.1885281094620305, 0.12850103734601892, 0.267434491505546, 0.1708323517513852, 0.08177769490547719, 0.10150731646365697, 0.08937940917788975, 0.11454807879823832, 0.16439742769204801, 0.12431658083392728, 0.0993928295229712, 0.13958845167390763, 0.12270798005404011, 0.0769602888894658, 0.14084521891368976, 0.15596284561099547, 0.12078707587094077, 0.10615577710972679, 0.14935139957214558, 0.23235383924216996, 0.2407575633016325, 0.15389836122912748, 0.12224838858650577, 0.07634329699700879, 0.11734952444150565, 0.3493323856063428, 0.12300472421151017, 0.10149161932208847, 0.10004425706762461, 0.1629825552264529, 0.25387686497021106, 0.15869522076700965, 0.2022244285551771, 0.12689065158126817, 0.12464250528043318, 0.09706624347956912, 0.1945771397121491, 0.2075203330886941, 0.1424578799595756, 0.11027272595393081, 0.21969871024691293, 0.19814061301369823, 0.13078748038218868, 0.13844313490534985, 0.14505825816623627, 0.15796202865819778, 0.11400696025380205, 0.1952051173054403, 0.12213372054599947, 0.09407129934838704, 0.1854918578699712, 0.18659643408271576, 0.15744844331376015, 0.23833798184510202, 0.1790849726286627, 0.15749356589250027, 0.1701976938713943, 0.08951493779257422, 0.12474580457614315, 0.10205011274064742, 0.0878633211757387, 0.18834524427450475, 0.23636878347925602, 0.15934714626881386, 0.14665098560433235, 0.15278500564877065, 0.1658684544024929, 0.20832910743211547, 0.15413250834230455, 0.1793756263871347, 0.12165290844296256, 0.09352382227417924, 0.16082557338860728, 0.12403194852654012, 0.18274941631863195, 0.15318147147134428, 0.19523324805401987, 0.12175824553255113, 0.12267822519906106, 0.1637850323271367, 0.1498355058532569, 0.16135559897989998, 0.1437124408661358, 0.28285115296321534, 0.09930914207812279, 0.15585468931784555, 0.2144318864110016, 0.16945458858484225, 0.1629206093568956, 0.12442127440965946, 0.11456414366201048, 0.1654373614057418, 0.23238152565975345, 0.15402194653307238, 0.1926751579007795, 0.13281981971475387, 0.12351262518354963, 0.17943738839559017, 0.09787185387986322, 0.10390754653922013, 0.13278926812833355, 0.11571396502756304, 0.1399451575332111, 0.21055057855142703, 0.11580060957179916, 0.16413426116829918, 0.0718434420864909, 0.0868549196410083, 0.2011707971893972, 0.16856736683797452, 0.1052764690511169, 0.13140971231604778, 0.07407322525978088, 0.10709392072092142, 0.12986717895875055, 0.1304795743236619, 0.14073212901430746, 0.23597784881149572, 0.1712565499568178, 0.10619546812508376, 0.1549064869722051, 0.13329303222558192, 0.11125906415644193, 0.158052840720742, 0.12072771171768829, 0.14491924385149635, 0.1466017261508011, 0.22618733706974217, 0.11549805080698383, 0.06947383254526124, 0.14846990816295147, 0.16588097227917564, 0.1378532012383784, 0.1690375762841394, 0.1319649268782908, 0.17509599877220972, 0.2030209608135685, 0.069442936219275, 0.09962942811750597, 0.13379534075577415, 0.08000932648898133, 0.16918520142714824, 0.10823372931730364, 0.12179690232921032, 0.13862475903043825, 0.15804487340632947, 0.10076162946080008, 0.15948908703942455, 0.13487400787491954, 0.18057466124094304, 0.20397711515186295, 0.16080516480630444, 0.1048263157868097, 0.09519352622690702], [0.1316059993640069, 0.03279116019726761, 0.029843202153701457, 0.04977210424840451, 0.04897453011043611, 0.17060073272835824, 0.009877092126126011, 0.028186000755897937, 0.08274602238088846, 0.034270219339598576, 0.045466900788127415, 0.036015704709796176, 0.02318012561919468, 0.013475005867921058, 0.00875109226457895, 0.03359326574530813, 0.029705557221126173, 0.034128493073606686, 0.0016309896994742656, 0.021626485902215206, 0.028605550722849947, 0.05946446097485962, 0.035793217454826644, 0.047346620084417444, 0.053946398604180545, 0.07084625607897198, 0.02869115338750905, 0.010993264037214462, 0.03410823004800947, 0.018920339681508563, 0.0995999184106627, 0.04452580007754507, 0.07831292437209238, 0.02405820793712572, 0.03377677061625066, 0.042377076667523196, 0.024615483275885065, 0.040420242960775093, 0.014358751490832338, 0.021395372497218273, 0.060326432463743036, 0.048616295905723694, 0.07071105688209496, 0.041033971318674665, 0.03840280020789754, 0.04289125956054177, 0.004902168377978547, 0.0019446069434765848, 0.053881763766009005, 0.01671865852850099, 0.06072713475253794, 0.019099824506068425, 0.01507927250537661, 0.007867666004571103, 0.03100949249440624, 0.04254164001453788, 0.004863645167901151, 0.02271741808902833, 0.08045377239825265, 0.07181755597552947, 0.05116634979663838, 0.038095093332231045, 0.042415978612318155, 0.03201008759318821, 0.028653808516420187, 0.02999261802723331, 0.010401884379285959, 0.0507309130813566, 0.02522337212858181, 0.031037276588200085, 0.015329258486388192, 0.05063910510451083, 0.030851576875354496, 0.02385188322213869, 0.03501843826304521, 0.06433948829409576, 0.05800937272367939, 0.02880347336852743, 0.033745135015417496, 0.04868387635196409, 0.04251747377096646, 0.07360173644678247, 0.041722764801834865, 0.06621543077691909, 0.018945976813894608, 0.02618725054837283, 0.06473648271733715, 0.021201090684400934, 0.03990910526725554, 0.012609851283712253, 0.04302983720516486, 0.07177034197675605, 0.06822574508166121, 0.042351393569861694, 0.06100455817255763, 0.07959865739629154, 0.06993156241913957, 0.037116124895551515, 0.02053262342909171, 0.06212875389704301, 0.06562619424995876, 0.10470155836834062, 0.044628923173032464, 0.01563463741237478, 0.01065299363671652, 0.05529087908085316, 0.028003681406018235, 0.03798256650747311, 0.03608904230678755, 0.07123801046081128, 0.11116922502556156, 0.03976764330159753, 0.01486977235594344, 0.02983862286313407, 0.07857076658476746, 0.036442312261750626, 0.060098877537154385, 0.07228951976304093, 0.003899611615305466, 0.06330667536765819, 0.019524777308106422, 0.03308218167794328, 0.023833893562456774, 0.026008307731019396, 0.01582112332295266, 0.009857576036254966, 0.01454864361984355, 0.043508584701245835, 0.010262835590589431, 0.01231923295680674, 0.03764048526664415, 0.016908550657512202, 0.02951778907088503, 0.013984328890669973, 0.031805053736353596, 0.031560064563828136, 0.07316260718770566, 0.010583136951731098, 0.052822382910357374, 0.018462889429722584, 0.03058440371176168, 0.03843853437912561, 0.015475381139455544, 0.004864556333726092, 0.051406683069804025, 0.11204523890609704, 0.06614891136245382, 0.05695038257286914, 0.11685196565644396, 0.01718013074188944, 0.051432492571973035, 0.009376334923980458, 0.047774851742771365, 0.04437381589424707, 0.019096984235089154, 0.007408318727562625, 0.029597192169016892, 0.06266347177687191, 0.04053463904006828, 0.03266297070489776, 0.07472322788089514, 0.028119799267921238, 0.0475071499785108, 0.021507998913406365, 0.008028097743649156, 0.01657007577558679, 0.024702771333977584, 0.051208243314777656, 0.04151142029572399, 0.026823159066900134, 0.041057245069814306, 0.05142457888371522, 0.02823544598575081, 0.03956500155430648, 0.023338393638691595, 0.018569429277352268, 0.05335468378278518, 0.022068936152443774, 0.03170858028404896, 0.018346172104018833, 0.01951496755223601, 0.08862236109111579, 0.012457855609095386, 0.04965538692270076, 0.1044068213612322, 0.1322478278269691, 0.03269575926805696, 0.011538756943698372, 0.023861811721637368, 0.04970628963482957, 0.022262930682289506, 0.050218810117052454, 0.056958361378600525, 0.01505217789071462, 0.03271783026115548, 0.024102083707769072, 0.06649854623021619, 0.05864742054273525, 0.043862716505123724, 0.04050841201998053, 0.058915876903601234, 0.02937012945391959, 0.042445695162901, 0.06842283652194085, 0.0019578208828592795, 0.013433578705805685, 0.08508650525923699, 0.028819846582689115, 0.08836050457771748, 0.04616103007368023, 0.029657134718652216, 0.04725572375220157, 0.04855223946393498, 0.06920108226157966, 0.05517468652537754, 0.059061858788012504, 0.060617316048592336, 0.040734059387637724, 0.03087996809382833, 0.05366142155722745, 0.03143352790615492, 0.034116794911002925, 0.023369366573470256, 0.03156035567723936, 0.024314475839116403, 0.04533697227616945, 0.0648903897813251, 0.034763568471516335, 0.030608290333240747, 0.028830682896378062, 0.04515372404468156, 0.06785998406309275, 0.041838696887416225, 0.06536423048425107, 0.01924651502180965, 0.03963320636220517, 0.04662881868200437, 0.013111186882240639, 0.04058149680795689, 0.040444497304457816, 0.032194304925900315, 0.04432020889174554, 0.018866073843392155, 0.03904881917180554, 0.07575376935663723, 0.03962646095803188, 0.033879165928209984, 0.0057857397158870534, 0.07300460155332282, 0.01934882989453693, 0.027097765198578278, 0.0638173572388628, 0.027380535912309444, 0.05898737972001395, 0.038705994825690024, 0.08513518248594577, 0.031105875931379777, 0.052171771249343316, 0.03584813446767869, 0.015183145409419894, 0.01190720022761173, 0.023015916587844975, 0.024266334873954618, 0.04017342092289079, 0.04088183774823143, 0.03021368801954293, 0.05362892410747948, 0.11390399803677875, 0.07240638647588991, 0.05298554431647063, 0.051520608005023776, 0.06398799183267741, 0.056967217355005206, 0.016650616514286207, 0.02911326591856778, 0.033540030295449885, 0.019482301563144695, 0.056610408073831955, 0.054171678249634085, 0.02546076170889841, 0.024641298523713506, 0.045483061412890116, 0.12736288349955313, 0.018227129701464888, 0.03006604180911616, 0.0409899136021493, 0.028121996025044112, 0.006305088435540037, 0.048794070438992594, 0.04727512109844435, 0.05724268342037836, 0.06857137330957959, 0.05286719905392778, 0.04237844796490766, 0.06983156496238324, 0.03351973662633569, 0.05398106791319386, 0.0550535680245488, 0.05612409545949871, 0.031071392398688103, 0.0413173970375811, 0.01870184949028396, 0.04079601674851391, 0.025640064587576256, 0.033624165901733984, 0.012695462566860502, 0.03472454778309311, 0.03747190378846661, 0.04330038881650375, 0.02878309159930195, 0.038837421039539965, 0.03952277861835976, 0.05249766122189261, 0.02951120071473622, 0.03693524387574965, 0.04815542890179542, 0.03991250669763934, 0.042792518487981254, 0.050749145973954475, 0.04246028913785854, 0.02673481380747211, 0.04734360935887502, 0.02758327342059103, 0.044042846758759795, 0.02393384696915746, 0.03309902412095859, 0.03219069282133733, 0.006437100227847095, 0.013513416558834574, 0.03687296092750565, 0.027799097625839136, 0.049586714801168254, 0.011196200728356358, 0.03202609691558586, 0.07172462951031423, 0.013836732475958286, 0.019663937179551973, 0.01484475383955625, 0.1128794243859668, 0.06198371430077861, 0.03984571149152133, 0.02544600110981734, 0.036300030582013636, 0.03961597321434848, 0.05365147007509105, 0.06089893763043708, 0.06179632536405998, 0.02684517260340433, 0.07433000261024122, 0.06550565797595248, 0.0784994897642924, 0.03150446764794329, 0.1458713532455506, 0.08812833397138504, 0.1482206537959076, 0.084178828964791, 0.13077594309804902, 0.17070251516997817, 0.1295230062978883, 0.12667736504226923, 0.19337991282584208, 0.24642601639272707, 0.15984540985476586, 0.12376869007224038, 0.11669150854070341, 0.10550130819601398, 0.11653982313169588, 0.14782141473504806, 0.13492798643006435, 0.18247023855726566, 0.12243064856457135, 0.10067319993170039, 0.12887431368712457, 0.09805520936366051, 0.23795371214228295, 0.1228205336918754, 0.25464515922771347, 0.10130950490072851, 0.07484521972195757, 0.12912082545939954, 0.16198517003607366, 0.0746993795638123, 0.15553846354446105, 0.10333498008549215, 0.30774870406716104, 0.18439100484453863, 0.10358221964129519, 0.22738791942115755, 0.15747761594191675, 0.24378834502591243, 0.10002987759728586, 0.1782596048208014, 0.08883880391236275, 0.14943157833430076, 0.16832319929474787, 0.19797011248527036, 0.13509424283139168, 0.1191996114568845, 0.07422022987157106, 0.12765575891300557, 0.13591879858605324, 0.17883789395132374, 0.14143198097665466, 0.10571585111920873, 0.11437582392846385, 0.1660324431835644, 0.2284704782669583, 0.10911109151258584, 0.11340403373563483, 0.14224453979442198, 0.13293416599833197, 0.17367213243438354, 0.12351985705355484, 0.11955588830695038, 0.19654806943670397, 0.2063186782141847, 0.14807492855095095, 0.1175852956610822, 0.1546123245310399, 0.10451782750146044, 0.14433019884651707, 0.08435430906472668, 0.09679773732298806, 0.2998915224546387, 0.18209752146034472, 0.0679758088963647, 0.09417070691744167, 0.2115206756899434, 0.10386639229592778, 0.09516237709190577, 0.08653831848454091, 0.12069630977367202, 0.13724552497508066, 0.19534442273359146, 0.12469587862611779, 0.1719727655572276, 0.11500709569982945, 0.10452951034230572, 0.09904837340957696, 0.1298130318642624, 0.16550516018704062, 0.10928040460473108, 0.1092944929616586, 0.18459768004475102, 0.21302708034073153, 0.1443572264284857, 0.10755812403775993, 0.200413994250759, 0.179344400643341, 0.13892596948050684, 0.20980388797338934, 0.15780802966365892, 0.2775943495573536, 0.22548186202203074, 0.10858650514555555, 0.1026384989100118, 0.08866887028899886, 0.12617760758486488, 0.234942113259627, 0.11706355148025098, 0.1304551820841528, 0.12939911455877368, 0.18569431958660004, 0.09903539588013965, 0.2353592481343977, 0.17353913957072845, 0.11792807404192225, 0.18871593889930557, 0.0927141975731619, 0.1497745865415181, 0.16162441923253, 0.1392973076191641, 0.17356871056460565, 0.10267758471590858, 0.15301552150518666, 0.15319394338275158, 0.08178467396646738, 0.11654776746347068, 0.09073924588700456, 0.09967527847977416, 0.07735709179072611, 0.10234561583568012, 0.06561574481067158, 0.14902935153053654, 0.11114933738304723, 0.14193856427746435, 0.09104136032082381, 0.17524553913502924, 0.1913310719593879, 0.12302925434684563, 0.1363803972039492, 0.18765325237426067, 0.13640195491813845, 0.17520561063241574, 0.12228385845739996, 0.19947912183500108, 0.09674627919711414, 0.2742597833275795, 0.15109815664829748, 0.11633805855507813, 0.21477636550703358, 0.10832549132887395, 0.11192096412302026, 0.08978047152800907, 0.09672001004219057, 0.10424937497103408, 0.08166275107331815, 0.13842672530201175, 0.09775530892394244, 0.1515302915246256, 0.1519302966734094, 0.1308518777331037, 0.18013353249238384, 0.14898959156726638, 0.31639247411681765, 0.08967262933090811, 0.08348232480667292, 0.12056602886126888, 0.12954698484991828, 0.1741531130767638, 0.12482036025293412, 0.12517115191346215, 0.1613173405489614, 0.1407595856055137, 0.1501683097693228, 0.09701769648780746, 0.13529062180990173, 0.10234904024870166], [0.03635687047555562, 0.03086993808767969, 0.04374869580891344, 0.09146271634005732, 0.001911760444918107, 0.04511633129309743, 0.046004372754044114, 0.03477669538809888, 0.030735786516039126, 0.10759847388873178, 0.024899307360512116, 0.027788900995566964, 0.057963024404260426, 0.05202741730177114, 0.08857170735756237, 0.03085812118144766, 0.03755392116164008, 0.05788950294616723, 0.017200546985071515, 0.045518983275659626, 0.030705108525111314, 0.00406267247237866, 0.029848250673122467, 0.09826080437989966, 0.026821887360945828, 0.10947417888429858, 0.02491578974220301, 0.03656412024171122, 0.06509648275471504, 0.08571937815436433, 0.015416537925991562, 0.018570091943406773, 0.012296196692923625, 0.060395556577150865, 0.024742470010213798, 0.05749254299688244, 0.024510517738939776, 0.015257512437059514, 0.04165139605080889, 0.011111512581156868, 0.03503816119665581, 0.022799098383515112, 0.038752565310607036, 0.06901441727794948, 0.02801717796002425, 0.04437087411661783, 0.005688590190989236, 0.05275235098275927, 0.026033025557896303, 0.04607667230189808, 0.01114474834814187, 0.012916003958502365, 0.04846115160973803, 0.027971724048256878, 0.11630139358702207, 0.032762554474174976, 0.024163730803035924, 0.022297816411141428, 0.034342629970201564, 0.020525150241390355, 0.06224873092686457, 0.02856799709280172, 0.03626799661545985, 0.03351837298983047, 0.022906781617371787, 0.011297282199525546, 0.05764338187873364, 0.020682924134176106, 0.010929491047957733, 0.06524771617184724, 0.022775776751880205, 0.09147455239848745, 0.007602610595283971, 0.036979688466676784, 0.011336742430895327, 0.041370824009420416, 0.02729653054097247, 0.016437774306283365, 0.06709830880525612, 0.011362696532160045, 0.025593712437717665, 0.05143782454392603, 0.03566132775778252, 0.024722116969285474, 0.02347527822900203, 0.027784388737692952, 0.0434335004237871, 0.014878580451852854, 0.02913500366341924, 0.027352020204547915, 0.027540292057599274, 0.02026247209869325, 0.03600610562810495, 0.020765088979275, 0.05071241971886447, 0.04618616541847587, 0.0706360568743079, 0.03825602542248465, 0.019466573778059215, 0.008480691955605102, 0.021451599520420837, 0.04361122133090131, 0.022996534563360677, 0.027012666236729394, 0.03072692862441463, 0.039447092961880474, 0.01581645401705417, 0.08903587237000467, 0.009636326013283144, 0.07236122559275358, 0.033307997584943815, 0.045038335881526434, 0.0800699393655504, 0.06405333530217891, 0.02884954972673328, 0.04531803458268124, 0.06380590039395517, 0.04381573999360685, 0.028707109083752, 0.03418801427488366, 0.02760898141611007, 0.011175040422277826, 0.11437688112979937, 0.028010557045138655, 0.04548282775607321, 0.03740993110583194, 0.010790248822060325, 0.05100908726754208, 0.06414699721180143, 0.049945431641272964, 0.03590504330913386, 0.06323449073299285, 0.1075757670426561, 0.057627987341895226, 0.02872243275745742, 0.027087430672479734, 0.030644505224641294, 0.04438604265751858, 0.031676490776120655, 0.0556387557768293, 0.045905911303575964, 0.01854880427521083, 0.05083091436855255, 0.02664126872625803, 0.04374803314285894, 0.01526694680984703, 0.06678739968206614, 0.012581643926340246, 0.03631629079820649, 0.05059704304702821, 0.03963009987567221, 0.02858252978072532, 0.019847329052525665, 0.05841334620791097, 0.03365029333039157, 0.01543591516242633, 0.011702742851940135, 0.06837764499528755, 0.10110542673857943, 0.012933700589553244, 0.009265038627950896, 0.043405450114439574, 0.018328724451543345, 0.01558761972363197, 0.024393754447960568, 0.10017494400662762, 0.025522115775534225, 0.034384699688563426, 0.035129490368548906, 0.015914335155919675, 0.00956681215264384, 0.025219834717591445, 0.04268527000902161, 0.04473421429734557, 0.016958648977320523, 0.02262760768644512, 0.050911123774224715, 0.03896507810080244, 0.0061875035152620375, 0.05519563903010661, 0.018981843135289608, 0.028959933420523044, 0.04652127142875426, 0.050737532081022385, 0.08304881863296033, 0.07942795002412412, 0.0413158955052495, 0.03531198017299175, 0.04798921463530391, 0.015225903649303704, 0.04697438945332843, 0.03538163671750696, 0.016122379738296715, 0.0720865600892613, 0.036429556897811355, 0.04412869074111504, 0.027378109328809287, 0.02598409743739232, 0.023946602333096728, 0.0402336469250581, 0.07877954852677162, 0.01999721798535076, 0.00914901652703843, 0.015187865468643367, 0.022677292318774328, 0.00853529966045772, 0.0354614477574585, 0.04064509742743066, 0.05285484205570914, 0.03876511766124637, 0.027784992031933322, 0.04257052535972288, 0.0331934712707035, 0.0428599457166368, 0.04851470881652448, 0.006592060662730928, 0.028177127542514956, 0.02987180596157428, 0.045781958277427384, 0.03452567518838952, 0.055055774357770725, 0.020843408062994, 0.03097056373653393, 0.007763584341568453, 0.059282465297127926, 0.03566317786011965, 0.026323070276468515, 0.05306221822637224, 0.055496297896869724, 0.025863679907014294, 0.03655029235467796, 0.01733904993612199, 0.023609789861967007, 0.025932361604645852, 0.02903553863777028, 0.062193346600378716, 0.02675246064280791, 0.09885619259289197, 0.021959423883667877, 0.03421877653548314, 0.03187106178712941, 0.05014612752523634, 0.03094017302857772, 0.042298165780882684, 0.04478429729539541, 0.021545441460705573, 0.027092431311405478, 0.04377897926456025, 0.029613184254436247, 0.014636539760225964, 0.038556354871440324, 0.04994183102802885, 0.03184768844455962, 0.01836042516985007, 0.04786725726819808, 0.029545115427144115, 0.05673506590087087, 0.027985812405184395, 0.0287719871548395, 0.005923607292765331, 0.02897806289125114, 0.048424007836729295, 0.09277697081767744, 0.06439365071034239, 0.058381369697951505, 0.019815888804113193, 0.08182007488944838, 0.041521597773798054, 0.036553038779886506, 0.05505637190635166, 0.0409987734089936, 0.040553124741681164, 0.09614195073804549, 0.0146901486779473, 0.016146258698896538, 0.00841298989290672, 0.025201942734119874, 0.029574334020576173, 0.03920887792182546, 0.06447228963576979, 0.060572710579201106, 0.03224578220397234, 0.04788318423614387, 0.02397200580866587, 0.05965984786950773, 0.05950305265404525, 0.030941952267781864, 0.025802931049838666, 0.04569329509151079, 0.06112017999252966, 0.041690190743294456, 0.011735813910021417, 0.035945144181530324, 0.10345959960813485, 0.004427386823320581, 0.02940779799715646, 0.023222844597072374, 0.03412041850688477, 0.04847395293895276, 0.01896851129018732, 0.021582077700464476, 0.06762864083171853, 0.05460008227777097, 0.0379186709441485, 0.05153252833312558, 0.025543449409005624, 0.011183157123835578, 0.04696926815555461, 0.10037365955330672, 0.03147855280868469, 0.01603612685651188, 0.015500709921452067, 0.038182297120651895, 0.022892139761918978, 0.03313042223453522, 0.06489046639011753, 0.08529675042917652, 0.0346167323990695, 0.024325492183467554, 0.06911372525557395, 0.029317150643515973, 0.03739373217667303, 0.019666978548611366, 0.043093958764427134, 0.06060995394364, 0.07191269643484585, 0.03268780344496331, 0.029358971383302446, 0.048098512399461, 0.021107953545006535, 0.03715751662610039, 0.009852037220562418, 0.04053409894808166, 0.01998129867828421, 0.02688941609625134, 0.01237499553920521, 0.012450210051611068, 0.01221553433776623, 0.02197267528953812, 0.01037856083243124, 0.011772331406152057, 0.017540125033607887, 0.024440581572332212, 0.01447380449052059, 0.045814088004971706, 0.04031489437986766, 0.043157471283789606, 0.06579622746475282, 0.052416540171590545, 0.03636393380621749, 0.021917313945689992, 0.061362662142322916, 0.0968354901358966, 0.10912409968554013, 0.16589940435463385, 0.14676501013098225, 0.15209836104223806, 0.14891878972130437, 0.12197304126476088, 0.1395274557533764, 0.14679543914333468, 0.2615537248071163, 0.11000258036919179, 0.1340864541670007, 0.09821869252670197, 0.18103681144214448, 0.13260430385989527, 0.1611971566754003, 0.07421685142382499, 0.14021204724427194, 0.062496211800363764, 0.10239639980418068, 0.18065159179029927, 0.17813272533878205, 0.12478317434508955, 0.21044822920474315, 0.11870255828985285, 0.12652271487299474, 0.08608536133843084, 0.22479701006124098, 0.2180527703415963, 0.23788228210422302, 0.14691122567221043, 0.10917381879182593, 0.1488652248536387, 0.12539964529775804, 0.25529481710926183, 0.11537461105974452, 0.18115733239439227, 0.10816059090317258, 0.21544618682274896, 0.080075700346741, 0.12197158569770476, 0.14563968825724818, 0.16279100260186583, 0.097841210362892, 0.06996524730517019, 0.12046678217067835, 0.12000052573820276, 0.11739925120867069, 0.139517787723772, 0.06390507047575328, 0.15151408110414782, 0.11953077594479246, 0.131547347672524, 0.1892599838996126, 0.11546585979240558, 0.13890997356464788, 0.13432927339548065, 0.16947712689157457, 0.15464679848763252, 0.18745563233331328, 0.12209340899942384, 0.170111769449807, 0.10354091218041797, 0.22263877183919956, 0.1508228093265526, 0.12660749016269562, 0.1505305161399226, 0.10945067530678165, 0.06568348230493647, 0.10978118861995398, 0.1882335946204201, 0.1980937743980077, 0.13093476844651084, 0.13333604040165103, 0.1388064597643191, 0.1021885984547196, 0.08086647162394178, 0.11622362800182835, 0.20053457649004078, 0.1600232954707838, 0.1128690055901966, 0.11840745356054076, 0.09388334733704407, 0.10133430316683747, 0.14038884501543739, 0.13283880337351753, 0.1973347344826306, 0.1721056664903318, 0.17585522254868863, 0.12789548314627142, 0.21635896526277068, 0.1528631006517718, 0.10186826645006096, 0.11905737191198335, 0.18872710846124158, 0.13052593796483933, 0.26163355116882636, 0.2866714495805002, 0.14605521434737792, 0.12266458883400887, 0.2262657538296715, 0.11509910285953553, 0.1612193885469629, 0.15807183970126415, 0.18971646505017437, 0.14211379922926426, 0.12956970701775244, 0.20758151287032714, 0.1475778600621608, 0.1504971913152164, 0.21186239686944794, 0.10068046244522257, 0.17462791905047434, 0.22932180113369421, 0.11471589035805195, 0.11087641089914307, 0.15884598687050805, 0.198623156475444, 0.08663899009867061, 0.10625269489302751, 0.1249987897913783, 0.10793225073646154, 0.18943783887211355, 0.09720489773298464, 0.22622801633852146, 0.15133981142313252, 0.1169444477906631, 0.13515634191853387, 0.10103825614937853, 0.13398375241987168, 0.16175964907292398, 0.13021607072122637, 0.27587671914408285, 0.18056024346620808, 0.11722700399977547, 0.08359861695357869, 0.11814849285949623, 0.1399135334236968, 0.11206153359624649, 0.253826946681065, 0.2106095979651136, 0.10519207680537816, 0.19173855412631266, 0.12053911619248892, 0.1321076030933088, 0.09818290855975882, 0.16716481306620184, 0.08111774080222653, 0.14583235937020472, 0.20398555744078853, 0.172955610398804, 0.18929576020567648, 0.10183943856147029, 0.1858598252217616, 0.27144597302521434, 0.1714008962435107, 0.14602120004353986, 0.18546058616090208, 0.20031804939912212, 0.14075995332771732, 0.12805203321359812, 0.17790967117874854, 0.10462186990245696, 0.1653134237013517, 0.12777711490109084, 0.16135829560939344, 0.17011857231057462, 0.17903885413562098, 0.14455754309892654, 0.11881101335729323, 0.1849114696585363, 0.1429151731633371, 0.0930711945458766, 0.1483133810782625, 0.14594915713514053, 0.11821739480740602], [0.04323180479508254, 0.035722017243144014, 0.038454396229597836, 0.038026164571243914, 0.04829205685265122, 0.07873991879844859, 0.01493226789358643, 0.09804448413272059, 0.03588017609511172, 0.10556048848816466, 0.035762608411812016, 0.030136303563091545, 0.04036263697930882, 0.04228182129501816, 0.04019957899506535, 0.03298966506976755, 0.05233482540314717, 0.08448903328709065, 0.07011958337839573, 0.13362218956312827, 0.033717161314862396, 0.08691375519359305, 0.029718157452260776, 0.031048511267609658, 0.026434683541376746, 0.08133216881223264, 0.030832851771265272, 0.006182382696293175, 0.05648972624312005, 0.02101303333596837, 0.02470855338258609, 0.01714935124431166, 0.032605759258712494, 0.06320395063789142, 0.035142065701825966, 0.06122654747037638, 0.03782671358015749, 0.044507222445381266, 0.10889988107186173, 0.02067852870471055, 0.02629135040596368, 0.06671142674261524, 0.12120345231866646, 0.03843371568608188, 0.024442318676700516, 0.07796119042341748, 0.04430761057583075, 0.0282881700719196, 0.09865063588104903, 0.049206505364347855, 0.043168495289020004, 0.09578065601207557, 0.03717244767974462, 0.06663165400705992, 0.012130528264078162, 0.038576579592641325, 0.07726164489624, 0.017626629766797828, 0.0172533591713516, 0.034928779162827044, 0.006509055993745044, 0.027504109724935506, 0.003994982619206572, 0.05106223461728904, 0.06990910072119967, 0.024767394680830262, 0.03903000405238521, 0.011157429976118429, 0.04349713934765708, 0.050054273583115115, 0.0783632027225629, 0.04257940431876529, 0.007750029373358214, 0.02139135245083561, 0.04066911045341723, 0.040703680171000386, 0.013710085693145952, 0.05320238550343821, 0.044800875438076836, 0.019908300075199337, 0.024277090748411514, 0.035102995217687664, 0.032655160438509724, 0.03552885966435556, 0.060903541818862005, 0.014685505227516256, 0.0589193970776133, 0.035999578558990074, 0.017311392246835658, 0.05194568338112966, 0.03513599445502605, 0.04537636451723595, 0.02377471327030611, 0.05619346472104231, 0.06675792061873982, 0.0599102781815154, 0.0735942058024868, 0.03637329923109182, 0.026075244663403403, 0.020146911565755165, 0.020393235646488688, 0.04602266693367593, 0.0464028533878586, 0.0692620475385939, 0.036208927406058196, 0.03929060801202732, 0.01842629724001933, 0.021941256108543566, 0.032573564413694606, 0.028995144736742782, 0.04861374483293584, 0.02409399764972829, 0.07231463212519884, 0.045194342026426915, 0.04431957686920801, 0.03640368227816878, 0.034405908832747134, 0.03956170354579245, 0.03253937007919435, 0.012661665640470963, 0.11781157505127693, 0.03228439303535608, 0.048258057870571656, 0.02077484893943033, 0.028435833519324664, 0.023431304782148332, 0.07721421639284781, 0.07622173416518396, 0.012689184476321023, 0.026439693756401542, 0.07257392990493006, 0.04831485945971743, 0.05459718263497757, 0.060721978980807535, 0.054813947213152726, 0.07635288841782079, 0.04812461301504124, 0.02785622671757254, 0.07577880511000272, 0.07637079955349046, 0.06764431499064931, 0.018918797929560947, 0.07686667294511873, 0.06395511133896728, 0.02541598961538365, 0.03700019664040977, 0.03805825599439202, 0.016327168446995558, 0.07019059972897654, 0.01927266351788515, 0.06451070128429322, 0.06762798965698288, 0.00904007595137603, 0.04940507152388173, 0.051369619736027335, 0.0134395589796646, 0.059380398146928325, 0.020098008343108723, 0.04104797923637014, 0.030077339690779487, 0.07314049789021093, 0.047417437252137935, 0.02857570202210017, 0.12593671123707487, 0.023973421156105977, 0.00868219893515831, 0.13658914084155716, 0.033749482564387784, 0.07270861582289781, 0.0437078824747474, 0.02539190189582446, 0.023527182601091844, 0.03129595958237206, 0.031069739563991467, 0.04174474386438247, 0.05437995840404784, 0.01739705428330889, 0.030409521160406933, 0.07110604415497473, 0.030156405710224665, 0.019137809060574062, 0.006755419815289638, 0.009115344089936585, 0.05287574859516275, 0.02072150432204287, 0.04289080373822682, 0.025216149834675655, 0.015374205822515634, 0.020499652920050487, 0.018437254212556348, 0.10652888491148911, 0.020114789499090086, 0.023632778245354855, 0.06911721861650867, 0.0622437781684341, 0.0077942192400505235, 0.03777462343174604, 0.04104817458879083, 0.03872885488935056, 0.03367053337335106, 0.039125968056220206, 0.03250802559177241, 0.059726466875403166, 0.016785545665169918, 0.02896249406940995, 0.007496887110098596, 0.029667080455129186, 0.06586935821800463, 0.03624627036192725, 0.021469717499830072, 0.03745165608462788, 0.01315091907482354, 0.05414581129087075, 0.03783671485800897, 0.03853395829097398, 0.018451618361136606, 0.004424487659332133, 0.022173087720969514, 0.027010649510268724, 0.03745247196826724, 0.03838529126838811, 0.021936194182583885, 0.03054394852370024, 0.022164442418744008, 0.034361893251057596, 0.023137749465663108, 0.021627493307835633, 0.03792640460174411, 0.02967967302538455, 0.04604540442326858, 0.024822715805062366, 0.04119362404209472, 0.03173235965321862, 0.007956402926450416, 0.010965161059322137, 0.055482826240721254, 0.15493273314449096, 0.03518685120187941, 0.028497043944474672, 0.06616913608365482, 0.03624300682736981, 0.054127995916191614, 0.028445806068878983, 0.04639730691128681, 0.03117804524428662, 0.020045623250846422, 0.02869948842412522, 0.003364501115415366, 0.03872908471572784, 0.041019159008658705, 0.059690138986033786, 0.029614643651932, 0.044592311831131104, 0.039369798520760196, 0.03424066749791946, 0.0142830035897092, 0.04227407231566407, 0.01623487783475749, 0.044363806955516345, 0.06184362746294468, 0.03128770498498794, 0.03397414167862266, 0.07238710404283578, 0.02391350158910838, 0.026662834101326527, 0.02840555963977691, 0.12877011040766395, 0.07138606461305773, 0.05576774966151965, 0.025701840002570423, 0.013962664881781226, 0.007909631822258234, 0.026311218896279895, 0.019221986801694, 0.10862395918417363, 0.03407658678629706, 0.06069627673094792, 0.05434064660221339, 0.035985156953815496, 0.01967502438703612, 0.08231047075241804, 0.035153262076839324, 0.052414326177489375, 0.07783371339281721, 0.02950134882402997, 0.05080783213939398, 0.0531150974453457, 0.03242015913729707, 0.05681525998478455, 0.01172563260150773, 0.015678455726423814, 0.04877596395090223, 0.05955397068793255, 0.052623242184880285, 0.022556742638229363, 0.061587501287219994, 0.028424934003381964, 0.01924018138989566, 0.05219891757494019, 0.017748855264677156, 0.01796508166608551, 0.03610282039810573, 0.06925634784443725, 0.09366375589442831, 0.010716132688215904, 0.06658409526872058, 0.033570271616260854, 0.02227203755248939, 0.027659167836029685, 0.02978141907782805, 0.030957302754564636, 0.04571426674843796, 0.019697131769311045, 0.04940487234102142, 0.01268936642220304, 0.057502808575067794, 0.032535432387263544, 0.03829957369054037, 0.04857529871045582, 0.04148612407246425, 0.03845841436076068, 0.03809980477296537, 0.05407093385715158, 0.03176114157653384, 0.04974840531846689, 0.06476850519257207, 0.06583181224883565, 0.008642010920260464, 0.040405675798894904, 0.07514276827174811, 0.034058955272719744, 0.03921367363223145, 0.039569961973616195, 0.049065085533525676, 0.029186900374629808, 0.06262572662484261, 0.10663305754743277, 0.005078190006315708, 0.028306079292369467, 0.07746547791025332, 0.03912016110975416, 0.03290462164929317, 0.009990288320207789, 0.05068251164630056, 0.02468654367652151, 0.03478098931091447, 0.04499218674496778, 0.01702135327392288, 0.030938265469646266, 0.048808974679559476, 0.015413778094244341, 0.07191258918253646, 0.11205595647615772, 0.10225733952416528, 0.08672927356054706, 0.1564341429020128, 0.2249762746355226, 0.1293465762489265, 0.11538806356369488, 0.21554957804900987, 0.09230670774535787, 0.17539066683140495, 0.09514734644683139, 0.10833699796949664, 0.09962310023125141, 0.10921602257557454, 0.12966624941797028, 0.08763849735260011, 0.15856737601420573, 0.16679057911519082, 0.15047405545990314, 0.17574700496850476, 0.09353755823066158, 0.2657872492507581, 0.09131877607996426, 0.1488109245415657, 0.11105552225583985, 0.1283304065826439, 0.1043829653832701, 0.16681327063950802, 0.21829626372744962, 0.07152527044977873, 0.08490029992836137, 0.1372583799304501, 0.11066044305240917, 0.1282310756223817, 0.1261956183119647, 0.20208809554817217, 0.1547077331211298, 0.14006532608501374, 0.16856021157676176, 0.12450641742156399, 0.18803238928798707, 0.16274370433342072, 0.19506225722932047, 0.15804557820721982, 0.1832096513000227, 0.22986996768703385, 0.19908287051704623, 0.13390268499572433, 0.17427813862600636, 0.12892590204794563, 0.1519705622547096, 0.1469330591780524, 0.0871644344841761, 0.17662796011615187, 0.10181833283915635, 0.08522878310853436, 0.16480415909280702, 0.13018072342440007, 0.07917245204049735, 0.17996528426245337, 0.14454091899096966, 0.11171477155820017, 0.11497763961914087, 0.1852863624451622, 0.17435821013585215, 0.14999154264167433, 0.09987541128911319, 0.17451162690356856, 0.1369996413949036, 0.14280926916868458, 0.17381828668857777, 0.19511349318969637, 0.2785219288160724, 0.12196652185652526, 0.18320010584448615, 0.17310064616462878, 0.11240133189506109, 0.0921980228515402, 0.22049747948204318, 0.08430024623991021, 0.0650995011411367, 0.09138935576042823, 0.09038795626932576, 0.09588806919993893, 0.1962007251718352, 0.08937056852324356, 0.17404920091071438, 0.12726554436789406, 0.15267671145979436, 0.12317126406536949, 0.21269076774197243, 0.10140986241880925, 0.15086419339622223, 0.16510736137147874, 0.23328292003322035, 0.16206853572399388, 0.1966650510627416, 0.12725528645058795, 0.13686818070709705, 0.18729705213298722, 0.1619831015986781, 0.11942088063205443, 0.1571156547194527, 0.15973624232555592, 0.0910763628780842, 0.18653606635428246, 0.15986335163395252, 0.19126601577285798, 0.15856425037547467, 0.17162839371350505, 0.17377615185274234, 0.12779737792668805, 0.1582397814960249, 0.09545159826595938, 0.133617164026345, 0.12657198964828445, 0.19777575597888042, 0.16429218253301037, 0.11202183492001026, 0.18757488157960678, 0.18348391077691512, 0.1347970926473218, 0.19035256317546292, 0.1489256998343814, 0.1449778648994623, 0.09405644490353524, 0.23542894681374874, 0.16476001710660998, 0.07556286024590654, 0.11692644472444251, 0.15499788126157177, 0.1937747698637747, 0.08064336383775358, 0.164336217266898, 0.19208527019908353, 0.13944373766501106, 0.07615464018477548, 0.1454288608604862, 0.16487738177660974, 0.13826411547920398, 0.14604715510241448, 0.1483003882270667, 0.11619060961229187, 0.15745124719556303, 0.10573457430807814, 0.15525619078788067, 0.11188900293481928, 0.08292052188828107, 0.14871148632899409, 0.12149128687357712, 0.16618242787738002, 0.2681845222269335, 0.1447497852026455, 0.21635772420033333, 0.14002214936960128, 0.09252149581668839, 0.15417363194207992, 0.10580501609271574, 0.0746502350234697, 0.2404514498888485, 0.2076648172712134, 0.1326282211248913, 0.1585185455699121, 0.23067625990558058, 0.1123708569174332, 0.2502962159773996, 0.26877425671104466, 0.0806642550554487, 0.12219818684482768, 0.14179876855304166, 0.12142483640702502, 0.07460183358841366, 0.13416289442008542, 0.14523648086094088, 0.07497084281978107, 0.21079117612492657], [0.05259640612489274, 0.03131145562586044, 0.009915355345114105, 0.03421539042685782, 0.0062353490577680215, 0.015316392997309808, 0.029600871306273247, 0.024109863330640142, 0.04390214705058644, 0.06046230964843304, 0.06619153649456079, 0.057613979424199754, 0.0444161843868994, 0.05287200625565264, 0.03186460558114754, 0.027616148168641715, 0.05912540195089194, 0.024997412580095475, 0.010653920603104898, 0.061611230860674576, 0.06191506516188384, 0.021397921654786316, 0.07845178546924746, 0.07465074830237897, 0.03679302731348622, 0.041786166238448316, 0.10795628291464622, 0.05024678764804717, 0.009339705387490892, 0.08163716373664719, 0.043281474105653264, 0.03209999758720158, 0.10558983731654384, 0.04526370362709126, 0.0071848245457776135, 0.03533370642652435, 0.031635070317274624, 0.051835102419699394, 0.01297306314471268, 0.03218568260631254, 0.02935152500867844, 0.08438048628909935, 0.09773598818649208, 0.047069104733846845, 0.038166450591938156, 0.010019768341144007, 0.03882111485807165, 0.0288475310850528, 0.09450314311130394, 0.06528061964819509, 0.06834576041587899, 0.0009152489538762659, 0.07004876621067524, 0.09186840586123929, 0.03622562812280752, 0.003991449278058304, 0.11141163822744163, 0.05390788736422697, 0.04279581649649528, 0.04903466035161288, 0.022964906623406757, 0.036767838342535886, 0.04366164906851707, 0.05507278150968975, 0.05935437797058014, 0.07798670115129602, 0.05469546405478351, 0.01808685134164989, 0.027615320793683493, 0.033318933490062916, 0.04089869551300522, 0.022610409012545022, 0.03528205677866936, 0.04929673520006961, 0.04533650879297526, 0.06713700390631153, 0.028550382816202702, 0.04301795518145927, 0.026290433015674356, 0.030070247631820462, 0.019958605238747214, 0.010183721690648987, 0.038422055827874335, 0.05683285319396565, 0.08617274898795352, 0.039654250797485156, 0.017503843109513965, 0.06232414462213075, 0.0595795197202073, 0.020245595181721355, 0.019891222060147314, 0.01907608344129497, 0.015693519887844884, 0.06902618438846643, 0.08204691352382784, 0.056151061754433386, 0.014594113810979312, 0.04352684440692106, 0.03646016594082598, 0.05296862143422327, 0.08307884927959212, 0.03992454959980903, 0.044817177789105524, 0.005319027461096524, 0.004307862742984247, 0.04176434039348557, 0.08685278991657881, 0.04020882184587179, 0.036152374795487816, 0.0181079359965459, 0.020604007501876163, 0.08203127766929327, 0.028942001217435447, 0.11625070920995167, 0.03480977506466931, 0.055350572651913094, 0.043671619702851584, 0.05933915963396431, 0.04979523627327816, 0.08350727629036674, 0.01806685836204598, 0.012630397761841456, 0.06350365189474917, 0.015713257185604065, 0.055723580862245256, 0.0298316840217599, 0.0037889449477886725, 0.058304925614427176, 0.07064050784514797, 0.07346369506370637, 0.04003972325834536, 0.057434841254425634, 0.08441951846884144, 0.017265109044890252, 0.02314283437426052, 0.05784261453476164, 0.07996847101997945, 0.05883414681339937, 0.03605354179237639, 0.01725109346631554, 0.04678064964771752, 0.01859748150191961, 0.06520005784207775, 0.12173716279287493, 0.027807731436745777, 0.050247140048492345, 0.07595659879546973, 0.021060074964958816, 0.03611536891830545, 0.008891766117284856, 0.017284159736347296, 0.03538388518556472, 0.004931722134877478, 0.07388422370798166, 0.0490403906892865, 0.04274052793099996, 0.03197809384625045, 0.02321278203218695, 0.012469428324801548, 0.008527617713796997, 0.1015176126853593, 0.02386002482155398, 0.040028224278601914, 0.031915535106353705, 0.029722208142160412, 0.01632908941246569, 0.017192608398956158, 0.06562436329981973, 0.09250343146343386, 0.032872285078009295, 0.012371808613440203, 0.03157556443775614, 0.045053833840234626, 0.016258191805513158, 0.039444584023928454, 0.05874800405675366, 0.04066292429342866, 0.015596382811875835, 0.026092223087025267, 0.02406053684441553, 0.009569974180551307, 0.013814285142166961, 0.00926743935598361, 0.06024858260887766, 0.034751682617371125, 0.05460424596563943, 0.046790988004255685, 0.0003576443768613371, 0.030144058288105076, 0.03318036350631907, 0.06321530789136887, 0.027888708845562035, 0.06334108420677724, 0.03746480598384815, 0.0730614222946667, 0.07632795225588546, 0.07395713229573543, 0.03214278934343207, 0.0009766383922279573, 0.05174403754814018, 0.03878732655017126, 0.028031406127997947, 0.08323232733434247, 0.03331786862784817, 0.028205059108234225, 0.05023702385745222, 0.01318749211232869, 0.03342758774036362, 0.05520477462860365, 0.03733608789081055, 0.02575998607602331, 0.016262372730359916, 0.07097898847273282, 0.04493343929249433, 0.07162474696674655, 0.05786871515034188, 0.035826553770851706, 0.066304434871962, 0.04749416861863387, 0.09070681738516978, 0.03270959864640909, 0.04735603147456723, 0.027896898325472593, 0.0597144469558712, 0.017602371592675487, 0.05222026461495027, 0.01928989092008241, 0.02809117630785031, 0.010452330311489923, 0.07104801299471049, 0.028159283439538656, 0.004946899294267379, 0.06003251134027397, 0.06163233275254888, 0.01087525298052858, 0.06023967300631827, 0.04114094783642119, 0.03508200440856238, 0.021525603613906333, 0.003253244799599352, 0.05941925795688745, 0.03715472423561639, 0.03581038548520977, 0.034344759694631063, 0.022424247731725057, 0.04733464229972132, 0.045981160289938414, 0.03860443838000779, 0.014888973392155624, 0.046730191266584786, 0.025702178996476917, 0.03321881728967832, 0.06046874095655738, 0.027094591679351947, 0.0444160235084353, 0.02117406884809175, 0.030684265187911453, 0.012702581438896878, 0.08435652305882785, 0.02157962813432659, 0.04142599383128747, 0.0804811293980287, 0.02770391694690672, 0.07305402188531815, 0.06235489922185099, 0.11697273175682753, 0.03745535245886253, 0.04609035463222573, 0.017238596657050714, 0.06412181207129071, 0.081125233142126, 0.09623319947070653, 0.023863340067046306, 0.03600095751725378, 0.05763751747567327, 0.02865039942515714, 0.039920496994689594, 0.05125532707860393, 0.08481957724377995, 0.04429751736742835, 0.019641019659297123, 0.044640265104751435, 0.11411824984656227, 0.02252923242086845, 0.07258522970181319, 0.06044742456006427, 0.01503885179127176, 0.03822228691029934, 0.0678551270656528, 0.06336441158407158, 0.07766096822677121, 0.04053590691558296, 0.04661995121428082, 0.03657778725028038, 0.04899742464805323, 0.06120413939859118, 0.026963611711717905, 0.06965576310551937, 0.01346423371409577, 0.021973778456149083, 0.0251442103481461, 0.01320008276736424, 0.043607919491947665, 0.09878608788694106, 0.030523087949522083, 0.06636073467351737, 0.09332938915899686, 0.07584097314505808, 0.07365229824978499, 0.056428603918081334, 0.02208501825319423, 0.034653895324276346, 0.06239543293392467, 0.06084512761463562, 0.10919161501430696, 0.08759272359912434, 0.05915087054393465, 0.013159857405680082, 0.04370783267903232, 0.04307100677021569, 0.05106749381088922, 0.03688422241999257, 0.03425176428150266, 0.03601873458753671, 0.050365247823778665, 0.03927784881764843, 0.042933815744735544, 0.02010873931970808, 0.04868781021345527, 0.0756998750711641, 0.005703924398403616, 0.03745414203994217, 0.08937966964778402, 0.036573585258015705, 0.013075517828486139, 0.03850398127049689, 0.015285981221935682, 0.01173390635108996, 0.08556505740289727, 0.055177329528716304, 0.08661542523411975, 0.019161711003811612, 0.05614986665727151, 0.02478362233828633, 0.010719554228407722, 0.04453966626897455, 0.033718417699058215, 0.10120204574758969, 0.08377440348868409, 0.04577517456885788, 0.03501371533099202, 0.06185115427680074, 0.1182142768295542, 0.09830530642742112, 0.09146116884245027, 0.1282492931932211, 0.12922007981086933, 0.09759697387175215, 0.10986967177520837, 0.24975894319434322, 0.1787900440995732, 0.1399305712191328, 0.17484508965524936, 0.11777517055311512, 0.12498277855376083, 0.1467150305548022, 0.11907817119912756, 0.1130078896699894, 0.11663441200770679, 0.2273511318790336, 0.1450169047400836, 0.2024153529876663, 0.1966024310358109, 0.12399408846132218, 0.15202161435398365, 0.18093159692662378, 0.13796345661244086, 0.15211892284212575, 0.25683278458253034, 0.14421543887545987, 0.14201555611385455, 0.17794958435960356, 0.17103406270184826, 0.11873134787404731, 0.20635646167061023, 0.12520574078324342, 0.09935278610716905, 0.2457365679043916, 0.12617980625720757, 0.172304542915475, 0.20626678341819396, 0.17927028929754613, 0.10728469193582574, 0.33409661282935454, 0.20692247807258562, 0.2354030223983911, 0.12656756166008212, 0.10844648725563481, 0.11518101298039961, 0.217237024598064, 0.15840540970525435, 0.14942082245984387, 0.15380534283336134, 0.12747257962943087, 0.25321187000841866, 0.1733106002211571, 0.11975497923671238, 0.09187923068360937, 0.1514188104098843, 0.22181151945504451, 0.126312684207674, 0.09911877688981834, 0.16738346988154998, 0.12399762778753236, 0.17770515634648262, 0.13885104608151222, 0.12459059516268393, 0.176485130683549, 0.19681737998560553, 0.16559349012471017, 0.15312513336539268, 0.10631494719775454, 0.09401151384677618, 0.13082751613711158, 0.17021474698858877, 0.08927616350833448, 0.12809915528182061, 0.1764879958523858, 0.10536143586279885, 0.14904779892775322, 0.1351671744017832, 0.2364474913525966, 0.14489911106084624, 0.17191029874788177, 0.17651375172840011, 0.1843435686802672, 0.21123631917420896, 0.14565356977043614, 0.07991190308765059, 0.2412179515006081, 0.17558727563629228, 0.2337855962856162, 0.09416340609952327, 0.15336390764963242, 0.1203208041167067, 0.15533929600590662, 0.18516789460855146, 0.19995147632735394, 0.10029305944279318, 0.11853870740460774, 0.1797915048777096, 0.2103554406353543, 0.20441962285868584, 0.08849808630803901, 0.19082151623743196, 0.1255213536862885, 0.15104080730628583, 0.23949593906441044, 0.23764405940328878, 0.1259965963301159, 0.1529373039281176, 0.12885620336859457, 0.13325080545919557, 0.22504278638910866, 0.11971245369603557, 0.15028441805512677, 0.14886029124740632, 0.1633197411654457, 0.13282216394380217, 0.10082811823174839, 0.08444312929866776, 0.24125046427211455, 0.0813074624766746, 0.14783198674840314, 0.16424713656306267, 0.1313523936175531, 0.10344833045476869, 0.11905302053257344, 0.11648120974460918, 0.18540398758505622, 0.1264636801375497, 0.15545719693745338, 0.13406861964012348, 0.1621876317527025, 0.19104268582117176, 0.10277212762664403, 0.2478152249128588, 0.11023750889205164, 0.14543241550845487, 0.157957018443173, 0.19565828895616919, 0.23397794564164456, 0.10286066440805312, 0.0580003903427672, 0.19931966829444134, 0.15102965306610833, 0.14953120040797419, 0.16235165117729097, 0.1353513419387802, 0.13230389014126795, 0.16439443994914332, 0.07185952993290079, 0.15288390759979525, 0.0925033854981584, 0.13057106054357945, 0.2459877681347632, 0.09182509891087971, 0.10252486508820327, 0.1704853752087201, 0.12156038034346797, 0.1388192227891376, 0.14190301779777775, 0.22936415047414843, 0.08722081855540315, 0.19690512769645263, 0.20978111984027972, 0.19247822733896394, 0.1291206722418147, 0.1802528430257113, 0.15035426995206266, 0.13642104582921152, 0.1161739165564218, 0.08923680191078494, 0.17357618758274665, 0.2188723005594746, 0.222585053753949, 0.15906116564667996, 0.23480429404204894], [0.048579845442286426, 0.02494463103733236, 0.05732989486967845, 0.06601539755901022, 0.043015595630652485, 0.045330682694311106, 0.04612878160250764, 0.05741259789154415, 0.015112462307086155, 0.06336961715151707, 0.01230430860643185, 0.049485223472959576, 0.06791184821556653, 0.0033178793983684196, 0.06832760413207355, 0.061531113385553324, 0.018207228652411894, 0.04866545959826439, 0.012848688770205745, 0.015912467816604242, 0.07622987767981906, 0.010926514796371902, 0.015491841496118616, 0.025584343182403716, 0.02484717890770445, 0.00297801933371492, 0.01907119196989844, 0.040963295877220175, 0.05065701624018051, 0.02282710655802681, 0.07768238038425485, 0.022922153171572476, 0.04983518009765014, 0.02088050012506785, 0.045002586388539885, 0.0672571418145972, 0.028524856766565677, 0.011221274786118058, 0.06815049992573839, 0.028114304502284335, 0.036068844398663896, 0.09794869249866855, 0.06955727484197387, 0.05321253616843493, 0.0663548894226551, 0.04880967181957057, 0.024901973346488613, 0.02430545898424762, 0.04585860537425165, 0.055022667868122946, 0.03111126535992709, 0.06731792323050961, 0.05520894597735136, 0.08397632894376594, 0.06948322478321291, 0.01391104108939368, 0.055484768273609306, 0.02556646843591044, 0.04522394749426073, 0.04095830864483311, 0.039872076407435446, 0.05018659995027608, 0.008646646709812265, 0.010780159444097551, 0.0614654788026406, 0.06215243750522214, 0.03309718934037993, 0.02818131421302115, 0.04490024853317488, 0.022139211312957832, 0.04162241111419374, 0.030363475445718057, 0.070344744280221, 0.06569914114210876, 0.035897807608689034, 0.033170515446052436, 0.0838558539567936, 0.023372666497204094, 0.030518759552749897, 0.03665264170136183, 0.02413624548353255, 0.03520846637266298, 0.007675500509644589, 0.008956344456471985, 0.011362321149077148, 0.05922281003046421, 0.06389459039294912, 0.012319800819480612, 0.06677607690254528, 0.0366516342957414, 0.058607706544740554, 0.02449960098601878, 0.0319362060737706, 0.10095206359701772, 0.0319776380239355, 0.035634192923504504, 0.05794546566903592, 0.03846501037778874, 0.06022496794861171, 0.0276595106603758, 0.052607667617379665, 0.03907193204448108, 0.03158711512843448, 0.07381455567214759, 0.00649939610382482, 0.014052549977937054, 0.02014089011467032, 0.05478592754732217, 0.018819064773138494, 0.023254346132518786, 0.014141830822242605, 0.0801194975933721, 0.0672990391631761, 0.03163995795823153, 0.013051515336208528, 0.016130268528696992, 0.048116404382932576, 0.054693832287504796, 0.05415038100533909, 0.05692131719702194, 0.015290445599314428, 0.057959776191461476, 0.03333746132651164, 0.0206939481394065, 0.03577984155966871, 0.0333269850741471, 0.010570742606726146, 0.016856851213942134, 0.04526424371907788, 0.05159805183328929, 0.020821457728743557, 0.03543876006358093, 0.03496732487673721, 0.031793489639136585, 0.05374860619345019, 0.10525189295050599, 0.06568487658495865, 0.010025072542409743, 0.033058567017677336, 0.048886529590574004, 0.004334141952811831, 0.034264439206209876, 0.039147594718322645, 0.06552181477027555, 0.017813342630923275, 0.08858904392728884, 0.019111162607347774, 0.021572899967131597, 0.14847052103329092, 0.04360273690713991, 0.027334350386574387, 0.028833396762849826, 0.02529318955156111, 0.02290118726030473, 0.03585777185376614, 0.038690849267427004, 0.03850254485563886, 0.03675445095605908, 0.0594158488656244, 0.026048699716827082, 0.05566627748550908, 0.03167359496376688, 0.050558654381142515, 0.03639458498406795, 0.04032313748593292, 0.017466096042264855, 0.04472525106863149, 0.11126601257391515, 0.044316535500148614, 0.08006288369576778, 0.00691670143315869, 0.06582545371906412, 0.012525811438418686, 0.057010803927457145, 0.0781708074012591, 0.08956338519290571, 0.03398141951390332, 0.03185440512043575, 0.030778072654239597, 0.0493909984887127, 0.024634926587403305, 0.06356238402546414, 0.0840137983041425, 0.06231928379425119, 0.0767507485204166, 0.022666243415686394, 0.05256067961454392, 0.023882036442838372, 0.06360865573609067, 0.02039228186702296, 0.04830878438247789, 0.04823481859338861, 0.02507434887511115, 0.02806531700996622, 0.040717044574839455, 0.0412975323777045, 0.060780550233058395, 0.06457695256798499, 0.032024403861273205, 0.0353130258830084, 0.04434252120254021, 0.019450685114509637, 0.05431112540405124, 0.023759820521058097, 0.10712469447283976, 0.05042591815694206, 0.010814617121321781, 0.003773653593417558, 0.033076566253458305, 0.052482822098799294, 0.03737376026448704, 0.03282971740249665, 0.05760416583788972, 0.03201314045356647, 0.03357011456823638, 0.09579916469632618, 0.027980225708996578, 0.07390873086067938, 0.0664605176256549, 0.044628517146432595, 0.0142079422948882, 0.02428614973811613, 0.020119680970486616, 0.03538549780064533, 0.06305260230757057, 0.04970363897061156, 0.010869507321096476, 0.0406936788931489, 0.07463363389815054, 0.09289915418072094, 0.030961847571175427, 0.02410431685406835, 0.011689820863877334, 0.039246538804183086, 0.041643639410575556, 0.03184835877149336, 0.01787724202468751, 0.018917530054046262, 0.016028397986965797, 0.04328514366681057, 0.06155073289729415, 0.03281755958713832, 0.03901179031198544, 0.01647034644960396, 0.001208555411487337, 0.023671917677406343, 0.023173929883107063, 0.03255540046900992, 0.021426498649581786, 0.1284172579706196, 0.031598891815050476, 0.024104470071653207, 0.041764677472172246, 0.047420256455699285, 0.06322887147806826, 0.058304665144532926, 0.021001049805612817, 0.06496953432478252, 0.026304665014087677, 0.03250730546912359, 0.04806217684921238, 0.06691361266759134, 0.019360355687357726, 0.028882286578957594, 0.018075532392568646, 0.03442427962117138, 0.015445259519882742, 0.04176602195647936, 0.050381833627339334, 0.027028457224068624, 0.041072291036647175, 0.10029083012693352, 0.044692447183713804, 0.04600706938353758, 0.05875741161646382, 0.056354952225041006, 0.07960638722344753, 0.040052164526235674, 0.022094284086638404, 0.07486086323737137, 0.018369771442526293, 0.02568631331556507, 0.041072834959073413, 0.019166725049276027, 0.05483187367058089, 0.07121382506504174, 0.002909788191543832, 0.07008808950382857, 0.08021451547862062, 0.03311786988389588, 0.06883673850567111, 0.031904957347339204, 0.04374835489978714, 0.035920908990045713, 0.03919398134213783, 0.05881689068290496, 0.042556536594225515, 0.03107689674042406, 0.047835399501866875, 0.02968538038042044, 0.055475617353353775, 0.01612889914653234, 0.07656776075882298, 0.07466482899842725, 0.017929749691017696, 0.034992490865049825, 0.027011555409239187, 0.09534280611983231, 0.01829858655260215, 0.014715612482940479, 0.08534675298799431, 0.015823298055047712, 0.07085205536455878, 0.034171378675607905, 0.013940188819692742, 0.02904344849558848, 0.01063483352247145, 0.03420371524689179, 0.04546053076703702, 0.08022454356954944, 0.04986613771067031, 0.012659611567223986, 0.028473230101348414, 0.015996728869785946, 0.02629096544678173, 0.05235917933826005, 0.01847216675448562, 0.03250506083150545, 0.016269851663720705, 0.028686426625016238, 0.12512843485080427, 0.05250247608449671, 0.03792467324303524, 0.0262102791513767, 0.05718659046256254, 0.014614818294742897, 0.00497866896048729, 0.02040187520305476, 0.024572630232620626, 0.05741860019043089, 0.006210413374637644, 0.025808230463054874, 0.03479040453150388, 0.04662522956007912, 0.020792587705317046, 0.06158978422923435, 0.015237033949233593, 0.004628729572775023, 0.05401051250256358, 0.040430290203902035, 0.03662864016669412, 0.03456622039178207, 0.20471614485065784, 0.14986878471268764, 0.20600709493362135, 0.11750405969759149, 0.09492433825207335, 0.16905548741980908, 0.22705762827348328, 0.18637687328361696, 0.15588300392752694, 0.12033564323980002, 0.1808888798639659, 0.1553634890625554, 0.11077852784505776, 0.09599516829175335, 0.1220977144135583, 0.13321047859086146, 0.12490448436789936, 0.09420348015884239, 0.1500716447950371, 0.13728894683862888, 0.1985237182628724, 0.14465345730704648, 0.11557032354176046, 0.11763024970047897, 0.14710444836847245, 0.0647396773039814, 0.1694483526291386, 0.15072304935705277, 0.20502215101113244, 0.14886470391385018, 0.1485393310506498, 0.06637433273417336, 0.11942474171519281, 0.10499945165769708, 0.17515895587782707, 0.15472811105991566, 0.1296749674985486, 0.10233518937903066, 0.11819400614307773, 0.32134026829754153, 0.23748307368688046, 0.20934806565844247, 0.20039778383028126, 0.17394066157360233, 0.15192896368042116, 0.16724074770125652, 0.12798411185823141, 0.1209735340108314, 0.1359315156455963, 0.20218097604811194, 0.09980226521410289, 0.18195760316185414, 0.1410234875736698, 0.22347890982224097, 0.15173284517180535, 0.07832282988895332, 0.14357724166925878, 0.11152717194730237, 0.09790966031892646, 0.12202833749113545, 0.14294292086795454, 0.2436981917989831, 0.1112699579267252, 0.1104916585609317, 0.16639702442672946, 0.16108454175053105, 0.08242612704634666, 0.23340809880004776, 0.22882326175608944, 0.12058042365336612, 0.18435982506602042, 0.14563025005402105, 0.1676610082147583, 0.1329276236074586, 0.09104029545860906, 0.0823408001733403, 0.24112283402392942, 0.14245846218639804, 0.11294126300321472, 0.1654512888842052, 0.14585532668617465, 0.1940036156485158, 0.16435864832132094, 0.12391786271285628, 0.14600658308594458, 0.13895506549987102, 0.1288671584259118, 0.09693400904295907, 0.11562048697904234, 0.15761371912254443, 0.09163775210899693, 0.1529618034199361, 0.19351027034703763, 0.16774124826394743, 0.1007650308911839, 0.2195085672241065, 0.20095589420487805, 0.09921364921836123, 0.11697935841737256, 0.11496756556293658, 0.1750723726206249, 0.13162424757836327, 0.15934829540070028, 0.18182969712201627, 0.1137653744268802, 0.15129687985585583, 0.22196476768341758, 0.125645115190456, 0.1050264792396657, 0.11794892695522118, 0.10521895116976193, 0.20014456112778958, 0.2560509918558021, 0.1487426661075123, 0.1616477389489451, 0.08261725066169616, 0.08831844635067448, 0.18984037211104748, 0.15796535347978916, 0.24112160828325058, 0.22436711216165175, 0.13429967175808646, 0.06052466920546948, 0.13456832347137315, 0.16154549685457062, 0.20822107371303344, 0.07203345487435019, 0.13259603011031307, 0.09056005792151536, 0.13776450357850523, 0.12421395569559067, 0.14653936659376468, 0.15084101157563348, 0.13789746579864334, 0.1573896384046924, 0.13575715403403008, 0.2031035757353229, 0.16751774977291786, 0.08496800677910929, 0.1543036677063473, 0.16843179991889387, 0.12108819439045845, 0.16841240257265108, 0.19230077073218363, 0.07628433887035617, 0.14654503564440435, 0.11807945301576007, 0.08521920700948085, 0.2660802319165199, 0.1490864710461709, 0.07389635087982302, 0.05665386824177639, 0.09218603357552521, 0.10120904779121762, 0.20145952040630005, 0.16736053320909702, 0.17664148922889464, 0.13574270561577814, 0.15980869892143434, 0.10276887941384509, 0.12300164453805455, 0.12713015364903596, 0.1382265158838803, 0.1469088967649206, 0.15074119031909974, 0.11730846978964345, 0.1381754178193308, 0.12278092694619011, 0.21821714216662993, 0.1643298587371265, 0.08932625033682393, 0.1419842997265439, 0.15452529694284164, 0.11308487384550034, 0.18048220975024087, 0.17387122336414554], [0.017707588023415977, 0.017907862559021, 0.047451562638725006, 0.05572505175105988, 0.036909790604465434, 0.034471118236861886, 0.014045613051782695, 0.03222740375466886, 0.05970706569872076, 0.0565659941264218, 0.0596585531809157, 0.02685059842112805, 0.08312348922293994, 0.05201371581924539, 0.01930475302581345, 0.01528463290718895, 0.06558730762692229, 0.08740199834949548, 0.01718657928699207, 0.04154184930807641, 0.039208625112810445, 0.03760854323064128, 0.01757585154395671, 0.02689020899725297, 0.07950066708989682, 0.06753251211897981, 0.05589007858126875, 0.02033233165650839, 0.02641442817665877, 0.058785255082071795, 0.017821861528641274, 0.08403920944059089, 0.042939683978235534, 0.021937339484030684, 0.11917175649995766, 0.010172732159375183, 0.04592457320541144, 0.03297952206565007, 0.06436923548819558, 0.06359348719518992, 0.018824097970801017, 0.034586165490890705, 0.026068725255167773, 0.016167745549952792, 0.032416202293168155, 0.014980919264827766, 0.05312398406526735, 0.05703485908827955, 0.048983738487285954, 0.03633032935941893, 0.06507598224186129, 0.03393295679181334, 0.02492741895689359, 0.03409339092491615, 0.06945718545466661, 0.021476727204337236, 0.05199519181323629, 0.06898571196342669, 0.10434508999629367, 0.013657302235163028, 0.056637473960196784, 0.07716711730726304, 0.0584382287436916, 0.01598745537546253, 0.06721128379144976, 0.04243304705127113, 0.10492390772748379, 0.02437005168758333, 0.03555459638817176, 0.02297169224719607, 0.04874794428507167, 0.03181625968746601, 0.10502714573615983, 0.034926009754980766, 0.018562976901810017, 0.08647758303390396, 0.03993778376870098, 0.04942425053506609, 0.10941564210600431, 0.07691548040677464, 0.030676521954216787, 0.02961721387691796, 0.05542542327255492, 0.010346535484366601, 0.08786356632387446, 0.045240288149685635, 0.02990531656260212, 0.025919209790205764, 0.036235866887915524, 0.03260741400862894, 0.072240206683355, 0.005014185275461886, 0.03273145896532843, 0.07403491320268762, 0.05878180768641253, 0.04406108348179729, 0.012171689210639847, 0.016063567168349703, 0.06787178181712666, 0.050734594133832765, 0.10921843575253602, 0.04414615371534902, 0.0043426239825484735, 0.05751382874985857, 0.026365321940712394, 0.06232969109870254, 0.0035534217491775995, 0.03091531347543482, 0.054652157104423935, 0.04654290575173594, 0.05046229201158689, 0.03730571633505245, 0.13349843571984, 0.0359712524579898, 0.04988574573109227, 0.02270108509448267, 0.022138650153553294, 0.04186186338624647, 0.01710722981501491, 0.044115391454749533, 0.019534772840298472, 0.08554487098609248, 0.06959046943173294, 0.023097231075347915, 0.015499952452016935, 0.029991482301885565, 0.0692527778747101, 0.015480359753353462, 0.04027271357875678, 0.06276400549517525, 0.04885124741122127, 0.041389267576197465, 0.050553119395889586, 0.027895977104743643, 0.0315207029662786, 0.018054991660098878, 0.067678980469223, 0.1009583225353591, 0.05140885492906936, 0.05415995710439259, 0.04535059714990278, 0.07135603396642594, 0.0772406847306317, 0.050260634687278545, 0.0537379767235008, 0.03684206843195904, 0.009547698258933042, 0.0008709633261934224, 0.026757032272496054, 0.04897265702546124, 0.05579924353608682, 0.026030982018358288, 0.06031680273853483, 0.10476261557590578, 0.010229312540632824, 0.046166630176406716, 0.022950931264448072, 0.006036255733981248, 0.09149502226782423, 0.02625802749647729, 0.01706912651688101, 0.024385522833214174, 0.05079344883861561, 0.03854697412480751, 0.03527503941328295, 0.031084500163072543, 0.03193529442914071, 0.024755462861409592, 0.05741665049666359, 0.005963045020302337, 0.02152306020199772, 0.07226478278396592, 0.132244196570208, 0.04159846320568074, 0.002985386226716782, 0.07485736221555742, 0.018229274747652874, 0.02961814467374596, 0.01726164058181307, 0.012596755968256584, 0.046638915720846386, 0.029675921109775384, 0.010397784851281153, 0.055656663082059354, 0.04745948781830169, 0.034060698122747486, 0.04192906844940397, 0.01088845363307384, 0.04221249799875002, 0.04498773960456733, 0.03459249720758489, 0.023733300472339316, 0.047228887692214026, 0.039630436954358896, 0.057481392587144534, 0.02842558134767798, 0.02109939634289232, 0.04006580855216711, 0.03255011063189276, 0.009849627874040557, 0.0499243374102779, 0.10418832542434817, 0.0071377134900690335, 0.049767729886356867, 0.0583416901739134, 0.042610170409804395, 0.052581823641254063, 0.02532069019282297, 0.030987760495214216, 0.03754743622736104, 0.03850845522397468, 0.08782638041602989, 0.03295886833521147, 0.02988022526786212, 0.07271567915355967, 0.01709712703051346, 0.10844457203582411, 0.033470343107417706, 0.003753700833429673, 0.013600580127639397, 0.061153903182956486, 0.04804136224030968, 0.02032427432676477, 0.04666364503904216, 0.019246543750106808, 0.06849856431325597, 0.04137800225327092, 0.044278633300094836, 0.030008861006447868, 0.011662702308967711, 0.07691956365541106, 0.0769810498722138, 0.05940923369639824, 0.054421327151958986, 0.11278667412097416, 0.05851296828158441, 0.02636837863153027, 0.06862759650234254, 0.014922701370631977, 0.065376533856315, 0.03364905609839386, 0.0277182849259266, 0.08026588167394362, 0.03326091382111753, 0.041350170278981815, 0.02522255241450283, 0.05184753219627085, 0.002328095476015381, 0.11192205196787273, 0.020167155439154278, 0.024709064746275548, 0.07328718074507291, 0.046157935078466134, 0.0244850721285348, 0.024783423155426018, 0.034564860585716464, 0.028722258472454645, 0.031437925250840285, 0.02321530246145783, 0.030759033454101414, 0.05581823485572973, 0.03281054605219153, 0.11955510689726762, 0.047321706905119845, 0.028450155533069087, 0.051868500022758404, 0.09383032639180461, 0.029899082522118287, 0.04059876826020979, 0.06856941978537268, 0.10185846052463017, 0.05852218048887388, 0.031102426620500705, 0.06380644814682103, 0.05191691294913331, 0.0767291295191934, 0.0519248228069515, 0.030498027298299056, 0.021173542162643808, 0.047930099460626804, 0.04196837259035918, 0.012910374169868809, 0.022098917003360488, 0.05779066228217656, 0.09690750240077896, 0.09681010964296519, 0.029066716501068686, 0.06137997955985128, 0.053136260624253945, 0.05134860977470394, 0.02140850898989987, 0.01076052078015862, 0.014119081841331097, 0.009370848776832705, 0.04679409832122826, 0.03401668254105795, 0.02316165332412047, 0.017843411581951286, 0.016109266228252844, 0.08262023840460085, 0.02650401066808451, 0.035942459043355725, 0.06688124545279049, 0.083504066381964, 0.10254472974807986, 0.04307247765903031, 0.025633179372356787, 0.026120104857029456, 0.025884548142071695, 0.008146678578228721, 0.02863450501594813, 0.032275506415434425, 0.05252443216440659, 0.04195570532653121, 0.015590681202499377, 0.029815645971065088, 0.030327687648335294, 0.025371018339008577, 0.09280249686731447, 0.023844794993619287, 0.049431011260997866, 0.032265214024171714, 0.07566446648730386, 0.028888047560148185, 0.011983077406072089, 0.024224864619393504, 0.022349377958885124, 0.03268317627390066, 0.016989135446267265, 0.06381713507336474, 0.03895887661905539, 0.015578514768651899, 0.028055488101897702, 0.031245104750738512, 0.05579964956268669, 0.05077997718246714, 0.06358323693876305, 0.037713508767586564, 0.06612890114587161, 0.026750675657944336, 0.04667453497888581, 0.05425640757405951, 0.014471494735428884, 0.010139274226892139, 0.0584580397774135, 0.039967082801365086, 0.11505486128190834, 0.025978552876040343, 0.08783993251141041, 0.05083350757617624, 0.03236533788543555, 0.03892196650286356, 0.06783659539876447, 0.20625368331468877, 0.10287686716765167, 0.1755313818613368, 0.17057611066247189, 0.12297519152202915, 0.09239416434279374, 0.14126790026503225, 0.12065333990199913, 0.11503663605018971, 0.151897722614869, 0.12102482359736197, 0.1606519012561729, 0.1370282930832717, 0.1248677274692924, 0.09607543132358021, 0.11734736407355917, 0.23884615860879424, 0.119663561964708, 0.12685125934020167, 0.1534672069453424, 0.09081979237136342, 0.10767548104688045, 0.12081423368785651, 0.13970647517952228, 0.15161682881655233, 0.12627215815647957, 0.1952986106757195, 0.11094810140709724, 0.16131542532915072, 0.17788275084908933, 0.12937942609911965, 0.14501408553652226, 0.1420547798155777, 0.1766636904569403, 0.15033674186035512, 0.07702031187833318, 0.08948078559290978, 0.22374650433419213, 0.1638062069973638, 0.2238203245665758, 0.1339998249445231, 0.06378757557080639, 0.09756650655500351, 0.12755758474550902, 0.12621583537228648, 0.15170923434197903, 0.18767329323435986, 0.12028161105850052, 0.13174895137067766, 0.14706560771071142, 0.14615710404130722, 0.1482318233578436, 0.14468105179407906, 0.18439420709206214, 0.1475428498440212, 0.17144690748424302, 0.1031966629107633, 0.24147426919831386, 0.1081847379945459, 0.14007085723982704, 0.1875549632935755, 0.14243782377771794, 0.21615373030785592, 0.12721558777435174, 0.2706352068531898, 0.2125634286071985, 0.0836686680333749, 0.13155514644759317, 0.13321031005151812, 0.1405053976322374, 0.1405006325653484, 0.24844396859407428, 0.10653620871204524, 0.08778003975749017, 0.18834931986226192, 0.1483584270482102, 0.1132469091023649, 0.14463494862279586, 0.1627731374314716, 0.15749969459589452, 0.08846096934810763, 0.13634966175642707, 0.09215902131531509, 0.26919949679605426, 0.23168391067414518, 0.2212146603532376, 0.10373259503995219, 0.14090865099382016, 0.10219108057959427, 0.17625023280420613, 0.1742789353574476, 0.18965260396080633, 0.20361855535978274, 0.1374422410322774, 0.14524876891124636, 0.13495787918086977, 0.13995945273387816, 0.16059616069880225, 0.18654478443486078, 0.13135725061499304, 0.21064532830590205, 0.18149059596321276, 0.27978005969235975, 0.10210504124481833, 0.1111534129708044, 0.11135504731247503, 0.1008676024033658, 0.16230165627935242, 0.1339086911250507, 0.1342688597017719, 0.10915724831002374, 0.23829747111566607, 0.19799560789139042, 0.17376790874667708, 0.08340651274568613, 0.0663909874856472, 0.07104350839771571, 0.11609857946994806, 0.11989879692273757, 0.13231176552512955, 0.29932274813613585, 0.15899241691635502, 0.1781452278937063, 0.104073504166257, 0.1661882807891215, 0.13643483541184856, 0.15513962284932215, 0.21109747339881238, 0.15476290677343646, 0.15163909133163192, 0.16472030310861527, 0.20285164006054404, 0.22145364914209614, 0.16297932233541243, 0.19224590351504667, 0.15374669114187842, 0.20900026174081912, 0.09589272701451856, 0.15998727401658414, 0.1314335223287344, 0.2113786123452648, 0.21623599282916517, 0.13360109150169358, 0.165873158182348, 0.09832462716487148, 0.1162357168692735, 0.1457876504789437, 0.11842143466515888, 0.15456081277901126, 0.16810789794450806, 0.11684982061025598, 0.08994557113657076, 0.1605491688655269, 0.09836982635240402, 0.1021862542256713, 0.12592793186946263, 0.12868907362703355, 0.2383037377148867, 0.1051285298120591, 0.11605233840283849, 0.12361988515382814, 0.1444994583125076, 0.11306880132084894, 0.20658927579079905, 0.15987790730451384, 0.21615507862260266, 0.15324755421569272, 0.11789271142333747, 0.09832240550989106, 0.22104544685252253, 0.18923189911630847, 0.16660860258965723, 0.16170185539991627, 0.08426213336567726, 0.16070195744114538], [0.06638145735186916, 0.030054180852828488, 0.05791823890420699, 0.04310314032819964, 0.016531192982989936, 0.024562640446088007, 0.008618680670136407, 0.008092192489834083, 0.046853987244708885, 0.04209949619947903, 0.014684083176806811, 0.017576196283522635, 0.033482106387495034, 0.02797678405899675, 0.03820012015621028, 0.017815681114312143, 0.021397138329883738, 0.01497043056353446, 0.051812625400001006, 0.0322948309833244, 0.03381059722854726, 0.09105749413250916, 0.02685977423924112, 0.04918911899890631, 0.10836145915691892, 0.01915231685064012, 0.025309070554231445, 0.04429816854216399, 0.0032258492560246063, 0.047090509230451244, 0.031020340299414053, 0.020946048523089098, 0.12247346521865939, 0.03831822410105698, 0.036519212167589896, 0.08278510052590601, 0.023622953167725957, 0.04817159335699774, 0.03597668785181257, 0.010879429117325815, 0.061395335792293476, 0.033764697070563995, 0.050509410249369766, 0.027801187130652612, 0.017260334401902173, 0.07027604151517153, 0.009126660166188114, 0.014818981684173548, 0.05185151968391673, 0.022894074133927786, 0.031076779912015608, 0.045375816764370094, 0.03524443037026832, 0.07444496176415875, 0.013974724063319306, 0.025047430460671746, 0.042497069019103245, 0.030541004830851193, 0.02270187991070411, 0.030293761444608533, 0.007442688304675564, 0.04451600181299352, 0.023759726675287373, 0.062251642060976844, 0.028117516325906883, 0.025750710666480086, 0.04096266385468264, 0.05649191342414387, 0.018455159602566593, 0.0406601395638239, 0.08920691682085877, 0.048607945547349034, 0.06560174838429497, 0.03137745984619664, 0.04999084150298469, 0.012142510836823814, 0.06464220027649595, 0.03041967374062346, 0.05231399930292561, 0.039861040910886186, 0.0501998111365303, 0.1323860300885093, 0.015810892218723893, 0.061732858809972965, 0.01612299835429557, 0.04703102250313086, 0.039986028155732545, 0.012615288592754834, 0.051586483905632655, 0.07141395021350154, 0.03684846143568716, 0.018157040317272468, 0.04975298652425409, 0.023243559614544915, 0.027903199398649797, 0.03715029241697442, 0.15316827943728817, 0.018843683008585247, 0.0099987018808362, 0.001444020315595422, 0.04508133256627668, 0.09434431010196287, 0.059010484931810256, 0.032175026323285796, 0.016428759366634394, 0.0777927813150229, 0.003665708213849294, 0.02114555314033022, 0.060065613999482126, 0.03504306798981082, 0.08359747548257151, 0.012876671089249994, 0.03904147238861169, 0.05544806883159665, 0.04987523117433152, 0.004034699729433463, 0.03699355082766664, 0.12164046717507225, 0.0664447668579317, 0.03548700828105211, 0.03809177234107929, 0.02765478198266318, 0.045557663054956545, 0.04806889927074794, 0.0720304135052908, 0.04296175880177368, 0.0239587314201579, 0.06543248891830444, 0.03864658087672245, 0.04013066938627632, 0.05788129048361894, 0.07523870546250574, 0.020818443172761512, 0.08271864239847468, 0.09657263770819673, 0.06517447050540678, 0.03627875632035636, 0.04405819149988313, 0.05868349179265, 0.03511063311429274, 0.04210976943854363, 0.035768047636074406, 0.029389287397686033, 0.05072592584896953, 0.03776199064187465, 0.0568936231185592, 0.03938543820573438, 0.027490446546805963, 0.03179080258574217, 0.038127433733954545, 0.03613693429337394, 0.05014579044654966, 0.06803632984238286, 0.05981260580160926, 0.0092524039228597, 0.06332871188680012, 0.0549717957995111, 0.03275190585202748, 0.05793354151049449, 0.02294516262237824, 0.033320814235917026, 0.05120041772663113, 0.018788103329678698, 0.013576282691510936, 0.00631558575532249, 0.04381843279266069, 0.01859125512231502, 0.011646815560637944, 0.04397798592465059, 0.02106825678399013, 0.040635555802333745, 0.012097132576238966, 0.0683774764559442, 0.10042948438034904, 0.031539608101030035, 0.0280009368960295, 0.09079827296157038, 0.029644848583566568, 0.09979873354877196, 0.04958337082737877, 0.07668642777829401, 0.129595187102114, 0.0462548605226461, 0.04875354821823778, 0.08840811694221151, 0.039479827898884975, 0.0168302679629696, 0.026570106818971616, 0.0409666475118889, 0.07309798767129261, 0.04741387877372965, 0.0468228840749831, 0.05357232553163364, 0.04502576437868899, 0.040555534088203025, 0.049089899121393124, 0.015485152590929743, 0.024237788522676117, 0.08790984569538025, 0.06807585997927575, 0.008457621217765396, 0.08879411800373947, 0.014801635538348028, 0.018018271150668303, 0.056095263740468415, 0.06342216312224347, 0.054896393595563794, 0.0374385942855189, 0.03214545532940857, 0.014870647611396929, 0.041662818421759916, 0.04231528401555073, 0.0969338711471327, 0.04547032520114895, 0.03480704779165887, 0.037577842257075736, 0.02394775146498315, 0.0262646330896044, 0.03581233134853744, 0.021274895595026114, 0.06922932792334788, 0.04371966490702283, 0.011607008674482425, 0.009788550556667391, 0.06481684534059418, 0.012159873262017727, 0.022372230361666412, 0.06504418959300365, 0.06532930453578312, 0.026409360505039656, 0.014254683234368362, 0.02508507602127089, 0.024572900278613936, 0.0026218332171875744, 0.04193130542614287, 0.03630354692558608, 0.012129614704228457, 0.023369071629619407, 0.04362955381492934, 0.06300139699071165, 0.041266076807533546, 0.047767075950339924, 0.05399894840534657, 0.024472123327394648, 0.03188802105855317, 0.009246867022386963, 0.07663032715959896, 0.009848521834599876, 0.05399985238909722, 0.034979459709457816, 0.010861875170150833, 0.03047304900152789, 0.019995777740053112, 0.018312226748093963, 0.0604411119955682, 0.07479934637705166, 0.0016704265891026046, 0.09785369759605778, 0.0957748797091265, 0.08969852310274878, 0.025511733368940415, 0.04665979161678303, 0.07461632797194105, 0.04442984756502894, 0.02595360522278615, 0.07289803106217616, 0.004181607143818251, 0.021496695286083608, 0.1093479352552564, 0.024095729008437167, 0.1001724542208737, 0.020681640936902935, 0.11566926379718127, 0.02562505500991979, 0.021522525855670535, 0.031709670044121244, 0.0028012972137319947, 0.013690205711510875, 0.04546876238178342, 0.014948101015761496, 0.03344003666913317, 0.01826029747814661, 0.045352554504549315, 0.013318371530922671, 0.0632718681628185, 0.05080218224095241, 0.021295572308102445, 0.05394333808292305, 0.041752891209457195, 0.05209261521456703, 0.0717457045891112, 0.06017673122245939, 0.019508057439159003, 0.0333833423322968, 0.04242120716240137, 0.05530723888847617, 0.04675680899151391, 0.03461898086712726, 0.07447485451496418, 0.07717898400921015, 0.02004299556926614, 0.06723751464197714, 0.039137558966514566, 0.03195687512596769, 0.04028811577647444, 0.023408664968766035, 0.1070031239801357, 0.1032181210335224, 0.021512748658536904, 0.03376615646805975, 0.06938590863419157, 0.005478820953172662, 0.021390572956372655, 0.10976978923164069, 0.03747047886492745, 0.04563950039746781, 0.0023044279078021646, 0.03588854943612411, 0.04217402123275303, 0.0389769371418703, 0.026813081180256222, 0.049085865668471784, 0.027115774010458303, 0.0037629283624776313, 0.023951704478672436, 0.04562660713770217, 0.03433051812011869, 0.025934150419949044, 0.020766400904845328, 0.08356371398774848, 0.04916537410369323, 0.04532530475708266, 0.025907302868642637, 0.060217368356402845, 0.04053337116455359, 0.0403284847796444, 0.011052395491259954, 0.012337014815139194, 0.055503483801599474, 0.030398596746606693, 0.03219593286273941, 0.054514958418064544, 0.05080127825720176, 0.05465165914727315, 0.04680043386836206, 0.054419814128308534, 0.05516577309237854, 0.02144635564857914, 0.08802570117216918, 0.028949891923055537, 0.025631484402824315, 0.01003632733162733, 0.23923983587132347, 0.0776515530061818, 0.17983937005121864, 0.15952835670642315, 0.13494988122294027, 0.14222106686042202, 0.16587351058279315, 0.21948169285972274, 0.18832256807194603, 0.14485755845183326, 0.1899168276858907, 0.10784130077809097, 0.11333535395322308, 0.23628786927269352, 0.09949096538607152, 0.11942765284930507, 0.1887604179641893, 0.21488741761253727, 0.1385398611666695, 0.0642290145849749, 0.12525829441484906, 0.1342386298722798, 0.2089866560192839, 0.10572378779010427, 0.23085279720685176, 0.1437598157433733, 0.11535888327465904, 0.16104056830367736, 0.08593562945363023, 0.11357146991236557, 0.18414188837332113, 0.11814394229722601, 0.1541164817829286, 0.09736504841355548, 0.13183432420895946, 0.1589456089441815, 0.19154107198119166, 0.21771350064344946, 0.14473130716191185, 0.20088682371762492, 0.16628237170798166, 0.2021597094473339, 0.1940567208634269, 0.09895705572900274, 0.11683983082372336, 0.15191802394486245, 0.13177801674652484, 0.1334327206976952, 0.12238199432050029, 0.06455763183053463, 0.07264684615356308, 0.17355318962325975, 0.11951046695391979, 0.1509337235362299, 0.1553551846694562, 0.14157454993936325, 0.1308773424957068, 0.1680354566703881, 0.1862409999293666, 0.13552829292753052, 0.1691058193964343, 0.13458891591477778, 0.16473583937171968, 0.15674180381240385, 0.2362064647698595, 0.25927072150572655, 0.13877745567550584, 0.1429480536570472, 0.1294255905574368, 0.14411941741503057, 0.26608216245808913, 0.10572836133501223, 0.16872196338109433, 0.09601413662875853, 0.16863513497575638, 0.14021981537582415, 0.22975105551942704, 0.1358545544527231, 0.19271340100995957, 0.16253724363782715, 0.2258668365257402, 0.23529789981342134, 0.1932812100576778, 0.18006777150496361, 0.09200332926646357, 0.10582969944563606, 0.22219520693104114, 0.1468641878736596, 0.10140102176416306, 0.1317579452429087, 0.1344607187615287, 0.22279369013924755, 0.21404781589104285, 0.1780137672058998, 0.1374375525741808, 0.10544881585144228, 0.32298033996935815, 0.14981354977334702, 0.08007950780372466, 0.17196325074520805, 0.10268877726048233, 0.19459362592427962, 0.17103101367190962, 0.16288081875010846, 0.0926686842895804, 0.15630162501287076, 0.10618780724584095, 0.12694721951359703, 0.11639112546559303, 0.1743031284140964, 0.15465638990844452, 0.10923370388486695, 0.1459314145388142, 0.15918871928607264, 0.14375644495650647, 0.08997892660479392, 0.14321091374562633, 0.2609342967550601, 0.09873615427603645, 0.1532736318486352, 0.14909246185373876, 0.11199472306836998, 0.1609854712601631, 0.14684616948568052, 0.0938414040231897, 0.12767043715763476, 0.21319725911223122, 0.20220569004454922, 0.16465019074178514, 0.15055201256707793, 0.1989611085023611, 0.1551792755602829, 0.1525060117485062, 0.12684153768444253, 0.23615444739980085, 0.09993340414498122, 0.08380031258228325, 0.17618482421723106, 0.1459131969679748, 0.16857001750219255, 0.08940556341962469, 0.1908403313568523, 0.10948621412558902, 0.12054948902298367, 0.13291397192064794, 0.16150688602318689, 0.12103908815451207, 0.10586175256438794, 0.15797097656515338, 0.1764118773562293, 0.10468064416800776, 0.1295526079352825, 0.13522717440801282, 0.11201852542017737, 0.14929700732952164, 0.15821859150403933, 0.09510229281600445, 0.15224667566437877, 0.17505473727660795, 0.17069030372846514, 0.17745116755606669, 0.13803139328956604, 0.1697404006676328, 0.15764212566277674, 0.16646635538387686, 0.10331518437352874, 0.11699956015593584, 0.15387167072584554, 0.14782507663532612, 0.19480719591581053, 0.18458335420056698, 0.07865581000524183, 0.13945486126167161, 0.16558604375008615, 0.09412187647314803, 0.07698997479653166], [0.036891117211311095, 0.05744581163350133, 0.028568460575995908, 0.028809063895154866, 0.016264444998195095, 0.019176343283165368, 0.0782987900498894, 0.050367745270411816, 0.08645648497246927, 0.015026118452360314, 0.026444633108293338, 0.03024483332410455, 0.03603935767445834, 0.06886983350400003, 0.08954259356664074, 0.056708528615173795, 0.053347371473547914, 0.014106762189898762, 0.014698106416260764, 0.02007647744199682, 0.0630310790673379, 0.039041162123002356, 0.03455603525282876, 0.04123225402567656, 0.011348171505115686, 0.049976048345166835, 0.029548128067906347, 0.046877762783438935, 0.006731101790548213, 0.08925650569219744, 0.017306498860219316, 0.017873539904793425, 0.04652745758874282, 0.10132924698653722, 0.043967241541512554, 0.010659682541905392, 0.04246400849473092, 0.022286750271075198, 0.015264480964340752, 0.0456972174616831, 0.017119885587524024, 0.038925402407203956, 0.023703221945212256, 0.028502268664118265, 0.027268482146844752, 0.03881968993453249, 0.02166804808732723, 0.003996177716368449, 0.07000679225330392, 0.014606324294882437, 0.07118971627806464, 0.07344040599080824, 0.03162621817130956, 0.014172884196253314, 0.07477462471973512, 0.03024983204781048, 0.07883909654112593, 0.018001154831220067, 0.019839191283549995, 0.0535657678190018, 0.0925461944913672, 0.020817012503562916, 0.08320606584029813, 0.0997226073917362, 0.03437004442657194, 0.04388725047089881, 0.060354850495294224, 0.059125099346161857, 0.027555682763998068, 0.0776021556568242, 0.025084032226474057, 0.032567795771624775, 0.009454115830932655, 0.07275985178327368, 0.008012000321140213, 0.020913340399161946, 0.025297950788010514, 0.009174947645665418, 0.035548103793013486, 0.046633143248336936, 0.07473943830137292, 0.07053918505628264, 0.04295648045597538, 0.025635324418544773, 0.016512282102579073, 0.015248473557162912, 0.05752962165241761, 0.009017891960308678, 0.03137736791564572, 0.048480426381912925, 0.037759416586449074, 0.040909738670433723, 0.0317872996487084, 0.03393307170500198, 0.022967164667563576, 0.04997612878439888, 0.03904949715961853, 0.036411017570043766, 0.08573622442781927, 0.09436304095171152, 0.02883774814225974, 0.00698891144448651, 0.03716570610601095, 0.060363116583997206, 0.017193537280564348, 0.0065352758317584955, 0.019085452696608923, 0.012908694522094824, 0.04391332810384132, 0.04694484144208893, 0.02560055743332111, 0.051732481111802404, 0.021164381666289225, 0.03945625154301524, 0.03035603481675348, 0.046618346260079456, 0.042700932676633524, 0.04874296088312422, 0.036496145260189815, 0.02203159894223415, 0.016549247760145415, 0.038293847183306376, 0.015913252099116725, 0.07130195581985098, 0.044815143825666565, 0.027102725617887995, 0.028817364457814448, 0.0722214681727271, 0.03873645831199904, 0.0018661634901711239, 0.1487585394493034, 0.0178627438107205, 0.08263808059235735, 0.027481238169956113, 0.012945381515178711, 0.047861109412605726, 0.07155662642851954, 0.01994146593666125, 0.012322122065891183, 0.03939791777802091, 0.04797244497064141, 0.026622633637499907, 0.021091275810894948, 0.07452431315135571, 0.04754672608067913, 0.022029827363909255, 0.04257031085510408, 0.039231837576916145, 0.08387525130303637, 0.05054203793406487, 0.04635563555864557, 0.010130632755106256, 0.04230143314587974, 0.08115318769048299, 0.03052185071752437, 0.025236305607963475, 0.0117543522801791, 0.014223951617285851, 0.022472511270954725, 0.03218605798939544, 0.04803117327091675, 0.020104273027109525, 0.026065865831990397, 0.029372680526707443, 0.08572299408936694, 0.051442382767075495, 0.04359204231971695, 0.09471429992587337, 0.015475565958167277, 0.12076812285569408, 0.019644574307265784, 0.033915332939115264, 0.08839844125172786, 0.0586458730451282, 0.042031452270044435, 0.021630519355136543, 0.033391229207477266, 0.037038255888488025, 0.03160730346045908, 0.03145109047181904, 0.003171253281893329, 0.011622962455505566, 0.069807325940459, 0.06122551708211822, 0.016759186494915236, 0.01404206702230318, 0.03323096361371779, 0.025137102967428587, 0.03934257558637089, 0.05804614494404486, 0.04768970106998759, 0.03521077229731506, 0.07712977052095436, 0.012912922369826947, 0.05063249376572428, 0.06173305416239366, 0.07661184911886532, 0.027125420972644806, 0.041193597229017366, 0.03564055911415527, 0.04767067527638809, 0.041377420026448467, 0.04546687014461045, 0.05537852720027009, 0.08010863446660581, 0.06906612055195917, 0.045683247848383846, 0.010201354161836207, 0.050946662593032085, 0.07316370269343739, 0.056499999482184655, 0.04767849703409499, 0.04473042982299963, 0.01014379893369492, 0.08203753660763465, 0.047621867814732176, 0.04176265500005215, 0.009015966206789017, 0.008958540255984953, 0.02371654421421549, 0.037223472965941314, 0.05575153541060225, 0.03471455416612087, 0.037747208975375666, 0.0461060096389584, 0.03820708006500237, 0.007278881948291054, 0.04112312480086281, 0.0017607909690160607, 0.03341730684041977, 0.06922279319335377, 0.016071683869907455, 0.03160999434429311, 0.052707718700290694, 0.056095999184875726, 0.036866843715430274, 0.07537179025671176, 0.051907371324036396, 0.03068706906971432, 0.05664111670827674, 0.024636870535511165, 0.06115587968980113, 0.03854476396114596, 0.021856388888291774, 0.019604201473656203, 0.01566226158531443, 0.013506091800668548, 0.08894762670200679, 0.024453022840222525, 0.044565471940703934, 0.04907905514682493, 0.027181008312430595, 0.04571849172334037, 0.014298902786967736, 0.09090675867252773, 0.041070088533864874, 0.032301917296623996, 0.0318899056348469, 0.027503167436788642, 0.07366211183609502, 0.024554989142944256, 0.03227944027692561, 0.007611888877656912, 0.0439415852569284, 0.012910530260283382, 0.10471720954463368, 0.03207030784969609, 0.030566875620054144, 0.040273000861728386, 0.0310628907379484, 0.035593881376928864, 0.01882961954951527, 0.047143725528111385, 0.031068674701776718, 0.04914753957681599, 0.04240478606774442, 0.051831666515359, 0.04151292948893482, 0.043355922530134844, 0.029645649145447442, 0.026703946209783037, 0.012166515244321238, 0.02628826498684864, 0.037167422142961336, 0.02024798729126492, 0.0044581107795238495, 0.032216149923061176, 0.04327694652602077, 0.033972961903219266, 0.04077547410082433, 0.012099925924332873, 0.036425523444890015, 0.03447119867609393, 0.03110028157431272, 0.05731684839232795, 0.01873500577564682, 0.15374453077393194, 0.055489161787855054, 0.05270145210107008, 0.02324314018140637, 0.02725406054167017, 0.0211469991312873, 0.039310840394107566, 0.052691037135739485, 0.014429097514479391, 0.04883487611227939, 0.03295445183832799, 0.018134584364991997, 0.01563078015967603, 0.06398752068860397, 0.026978069706068888, 0.028256860058454257, 0.025123773037546107, 0.04925803626857458, 0.0064469612158474425, 0.04339314291193601, 0.012634667744409415, 0.03233397424581551, 0.02421291939343416, 0.02957843450619088, 0.04644639016459546, 0.010076318078884676, 0.021461451411127083, 0.036538463957127065, 0.08697050698702374, 0.07593743127560423, 0.026732509798039834, 0.019947929803522366, 0.030034065299156695, 0.018858991360532183, 0.059715385413578445, 0.06759583694680084, 0.056908994672759894, 0.05882835135825219, 0.011931510112668959, 0.08007801393227232, 0.05839512863707158, 0.013690715159980521, 0.047642375988465165, 0.03859594629536714, 0.0740668207647339, 0.021826350580780737, 0.017668687993840828, 0.05462716348589428, 0.021824264906406887, 0.05497351566690111, 0.040066582300970634, 0.03200501034547004, 0.04016837240346978, 0.037013618500843164, 0.015264498201319048, 0.025442331548660033, 0.17356137144229106, 0.12217367203125071, 0.16881351088804586, 0.1047705292641636, 0.10457901494397272, 0.0624224107201782, 0.16313607924647872, 0.1251719639666619, 0.17610394065418553, 0.11533418459998024, 0.12455345522011481, 0.10319198977442519, 0.12000045679028958, 0.2145598843813904, 0.21453342370448575, 0.12831896122905517, 0.16685404183883823, 0.13217679615462982, 0.16245291267912235, 0.15105068984050907, 0.18983393697248352, 0.21134237638644635, 0.11439096182584764, 0.2166202318884673, 0.08485669420371134, 0.14183744067145934, 0.11739818634645593, 0.18828458543266022, 0.16585382212313915, 0.18881761408861608, 0.16286226410058238, 0.10750275886347217, 0.22990568270606382, 0.178326009322078, 0.2646332756886559, 0.13825172017658913, 0.1034603427134214, 0.16059639052517954, 0.12414316151050792, 0.1716634805404371, 0.18129139778114137, 0.10139554423550445, 0.06777294881401524, 0.14043658761487854, 0.113118780897029, 0.16255725385440936, 0.12039083987474443, 0.11386192448797727, 0.11225270317687143, 0.13452405891110822, 0.1727701405123357, 0.32930326197416554, 0.11388719006772004, 0.12201128437394097, 0.13964926373333703, 0.08323683193133724, 0.14830457106713327, 0.19821936685231425, 0.17227186160462518, 0.15234953062909265, 0.23198317526088608, 0.21422410804417827, 0.2129932805415123, 0.20567352492963115, 0.21837690214235939, 0.18269214358541275, 0.20569131349123296, 0.13317496275469182, 0.09095054059740036, 0.21022249373697469, 0.18499503452931682, 0.1984901942553059, 0.08742235330564362, 0.14986398900228162, 0.13687147488517148, 0.1535911446497325, 0.08569653341246229, 0.21526715207484462, 0.13972904412977158, 0.1862436505935846, 0.15154113932963342, 0.1650736535028104, 0.14127513213503745, 0.22033356730976414, 0.10572186490941433, 0.10943775906437829, 0.18621227163220608, 0.10770249330709059, 0.12029256611581772, 0.13557530008256435, 0.1676339806327897, 0.2012469463290707, 0.16929660593309712, 0.21327964420760834, 0.14730130232149555, 0.16983041599873575, 0.1777892115135347, 0.16739257100609042, 0.20143054696100376, 0.15783026153522153, 0.22454663720582763, 0.17758365480169175, 0.1292859020853235, 0.15398364213685836, 0.10727512349765148, 0.1001859833336165, 0.08788196775581568, 0.14170584208782644, 0.09361206028129786, 0.1250392545555388, 0.17448366469433232, 0.21087835693070967, 0.13566068824260466, 0.10411469671394556, 0.15760967417830424, 0.13232423743653682, 0.14312423855787323, 0.1090950649532099, 0.16842645262518238, 0.1430588146491397, 0.20455534299535139, 0.09739402185885176, 0.10173639207477532, 0.20409745224300893, 0.14439759926209528, 0.11552830361911368, 0.14156705759946378, 0.2968775793429344, 0.21517491508876124, 0.162899388721393, 0.21924616678828196, 0.1174904922804525, 0.20217329984711063, 0.07939696176758698, 0.14647124605553766, 0.13862976924546305, 0.11909486425499763, 0.13662107138624116, 0.13116848655045033, 0.07598723465156171, 0.18871885003341785, 0.11675818117275355, 0.14107190433048433, 0.11290967719809664, 0.19684014811871514, 0.10093403754815941, 0.11279671753366148, 0.0952245221443234, 0.321415406201155, 0.18668983552244403, 0.19636315113354116, 0.11611917191335272, 0.09061226681355508, 0.14223882477850686, 0.12243198921843884, 0.12293891725881446, 0.16168376040314475, 0.14861825342860915, 0.08938586729909144, 0.1572100061082071, 0.21493525214252934, 0.09998829434475592, 0.08060662992178433, 0.07094298234029163, 0.15465848898935705, 0.14115493293971787, 0.15720806024487943, 0.15753226865443493, 0.08132951048713538, 0.26041047647595406, 0.09696393243728146, 0.13039093795082263, 0.2657389550680115, 0.13700307346880436, 0.11186644164544922, 0.2621361048471543], [0.038931331927737886, 0.05436993414355863, 0.06475571152423659, 0.018301606854243625, 0.05995870642964879, 0.01428929412917745, 0.03743017114879143, 0.009453778752245972, 0.056920520465580694, 0.03239389381281311, 0.024684433104290117, 0.035653494508756746, 0.030409254944853248, 0.040227399478035594, 0.022368363532868606, 0.031187422160479813, 0.030433620371284987, 0.05914138637543206, 0.021838579259272066, 0.044995266418423385, 0.017601113293259855, 0.03537442399969986, 0.025609306157416394, 0.054938735275138775, 0.05549342506715367, 0.03514095104389614, 0.015742955541598703, 0.020441252122362776, 0.006549280876624248, 0.03873597950704637, 0.024533082858749458, 0.10675547839773279, 0.02311648286488508, 0.020713699801314264, 0.0167680386408803, 0.034678241598509976, 0.0034475294852464072, 0.03258665685632056, 0.01436800487534774, 0.02157782399726491, 0.055620224109940955, 0.03160683423160546, 0.02630711074978594, 0.027587190045103915, 0.012506743509983344, 0.050343808853217674, 0.029703835438516353, 0.057734006249736396, 0.09756892739284424, 0.03777888671104466, 0.03850109694946197, 0.03719253450511925, 0.027827151765626286, 0.061009840348795544, 0.05136085952061319, 0.01218039484228939, 0.03775920208183028, 0.013030744777361472, 0.03005467689475946, 0.029654215923660708, 0.1165781811540646, 0.060958378392482, 0.0414363973052992, 0.06402084551331017, 0.06056756629878956, 0.11749338809280627, 0.022318370550149874, 0.033325403102583466, 0.023999117660306157, 0.043689186098955335, 0.05656343922319432, 0.11622025721496153, 0.01886059631473355, 0.07835537330397675, 0.028376268267992045, 0.05813603004020068, 0.017914265138848175, 0.007473608092104476, 0.03775987623920364, 0.09155163616542855, 0.05972539052186955, 0.04566828232078303, 0.09272676907599935, 0.055134826970677224, 0.03189159868915956, 0.053196869670383395, 0.04160099895671011, 0.037185088130495245, 0.02521831594828156, 0.016211590677079175, 0.025321174743435076, 0.04421906996398203, 0.04037776721581336, 0.056478039571835156, 0.06357811564098924, 0.014388084039843131, 0.06375572929579405, 0.03185859753660137, 0.00644203718571413, 0.025786655511887326, 0.02990704217565156, 0.07687587366108933, 0.02098459040655965, 0.05044306320468745, 0.06724155958621733, 0.027998052574994586, 0.06777826546420974, 0.017955486414833896, 0.029703486868510806, 0.03125326741757172, 0.059166632802976724, 0.03520055651484478, 0.0339590076116785, 0.005201621613870826, 0.00990306442197893, 0.0774574569696861, 0.064938944433966, 0.042466119066962314, 0.027459226548671726, 0.04543235405318199, 0.015899215453124095, 0.039694983692419146, 0.0684393303949506, 0.007122268199905634, 0.013553524134500373, 0.04218321045740478, 0.03039412853878833, 0.01857210675464763, 0.04501549113962439, 0.10432005424292819, 0.02292683971444926, 0.04906389809724304, 0.10232834821386684, 0.08108271526232844, 0.0743293207919886, 0.07247181804550272, 0.023879527504886353, 0.022014890564605597, 0.04616660719376899, 0.059363716582377116, 0.04060460201975319, 0.03265796815075221, 0.028540431334066297, 0.039270184107966004, 0.03785725367525893, 0.02514288118559747, 0.0436705663319557, 0.04554548608740011, 0.06405294459733753, 0.058592254551307815, 0.05143600125466624, 0.07965272788198725, 0.049454518668954416, 0.028802067597186374, 0.05533381064812984, 0.056592948930037607, 0.011949913459829988, 0.01547743329748271, 0.044764819509920575, 0.08500530760014251, 0.005600898979126566, 0.0541330942313277, 0.038159935014142145, 0.01846979379714016, 0.0600840613966988, 0.05016327640342136, 0.01577880654123522, 0.023902584836187384, 0.09951113648111783, 0.05067426470979568, 0.015822351936461226, 0.037448369567432714, 0.060190930662135926, 0.05129601400826247, 0.06032127669201263, 0.029822222835895036, 0.03829074069677341, 0.05225795997126449, 0.052882022855262605, 0.03263783919054174, 0.06422991090784631, 0.04191752733482469, 0.022375618385511543, 0.022814090724193284, 0.08550753952154229, 0.03882474611483274, 0.03855244016214725, 0.04076330479414713, 0.044370586833646225, 0.06071651294346779, 0.00628441603170828, 0.023008987322569858, 0.012069055453814086, 0.04156220809466416, 0.056001057908419645, 0.052284600678831346, 0.03799852028849625, 0.06726504018109652, 0.07609576632779452, 0.037133185673625245, 0.022133860188806732, 0.006372495075582617, 0.06443080597467, 0.04686634424292753, 0.03244120357257705, 0.04500412622526769, 0.033159851502146453, 0.026097097321443503, 0.05271203177530439, 0.04415361924217113, 0.06348143534494505, 0.1251823597797944, 0.07715142782657378, 0.036584731837313984, 0.005327530558251086, 0.028052622933060895, 0.019787127948215893, 0.020977643904306238, 0.047944735570420186, 0.012407899973162962, 0.011099288690715067, 0.029135177948422013, 0.021625248670217492, 0.028348323295734106, 0.044697369298627304, 0.03815766739388628, 0.061619339901353085, 0.03685088993440713, 0.08147316729469646, 0.04032371588231575, 0.042275750048218236, 0.029393029737196145, 0.06747067350173189, 0.007737761911665721, 0.07498323812239593, 0.02572824896854018, 0.025305466110547705, 0.05740597506143874, 0.019967972578841354, 0.06330339268090264, 0.11125992217491712, 0.051526020416208816, 0.06089757399393186, 0.01830754595087661, 0.07090103136555803, 0.01993540426596038, 0.07825611129162774, 0.06211533586704924, 0.06626662843289875, 0.024606215527221083, 0.06968986167902909, 0.06190223318915214, 0.020162589555125565, 0.07557834288285625, 0.013823298166596122, 0.0803264792287542, 0.05517780067278974, 0.025203980527998462, 0.022596818612768285, 0.03691922880769257, 0.02393665468139995, 0.04383858090506927, 0.042954641844957106, 0.044545136136753906, 0.026291379134260842, 0.037077904769009164, 0.042020221421074484, 0.07969534535321497, 0.04605940084964518, 0.06521003230685188, 0.06629703446261345, 0.035985651080526655, 0.050753033870170196, 0.028901461759702336, 0.04424155081412004, 0.08250195442909196, 0.03564614389512328, 0.04210411954010206, 0.04051556345075369, 0.04943513664447012, 0.03716666754635592, 0.05544897664578692, 0.022443001564111442, 0.06879368436432655, 0.08702324447973121, 0.0646826573797772, 0.03443080285984663, 0.05696038385072062, 0.026940284334423564, 0.04377472747658049, 0.08412314203357504, 0.016627147410725875, 0.08871928653529576, 0.014871923147790856, 0.04692797218599627, 0.039588980106336456, 0.024637814738877842, 0.020537172076142123, 0.04299154046983008, 0.04155296907429734, 0.03760089001227771, 0.052292709719509854, 0.01318277779876465, 0.09269790288301245, 0.08283039164398948, 0.0813716606447293, 0.015155238741558167, 0.07641378474692184, 0.023956122890775724, 0.0036791133161093443, 0.02694082442641018, 0.07354857760571665, 0.07261321489368716, 0.06489482543040669, 0.023218927972559488, 0.045147560867330724, 0.015728082902158703, 0.051578401678031495, 0.046978342467017715, 0.046504609016401154, 0.03130290416940566, 0.029241007249501925, 0.07357670069341699, 0.06003358386336796, 0.050031689311107325, 0.03359443785983228, 0.12293909345903706, 0.10211943603691556, 0.10075196909207491, 0.019807141995237722, 0.027285431842169455, 0.017898612047335314, 0.03740767114645532, 0.01370602063909774, 0.044842198220712524, 0.040216042224558136, 0.007314675012528296, 0.0593168051883338, 0.05026692809957651, 0.040840982279229554, 0.026255937991663817, 0.05896951838005936, 0.02118460638749023, 0.036990045975413055, 0.06192215147518343, 0.04885033193615176, 0.03371022055826841, 0.012796880159106468, 0.009317949448051232, 0.023272364520497864, 0.045866626314818866, 0.009930994072478386, 0.08260539928150755, 0.11716327314535457, 0.10273674202542152, 0.1133404024726441, 0.137955320758685, 0.11205036403431047, 0.120903413983122, 0.16606481805924447, 0.1433192538998781, 0.09994019168399035, 0.10563107582950786, 0.1130850270630852, 0.10705562398558664, 0.17602331756103426, 0.1569555270215196, 0.1730388688344148, 0.14803161393971215, 0.16617672818322338, 0.07555452520929037, 0.1619121925004067, 0.10670763620686148, 0.1526795306633557, 0.1414560821027525, 0.13338127023270055, 0.12465095523023799, 0.17177977268734287, 0.18759006544226603, 0.22920146404254824, 0.07250102897805553, 0.3361910359273034, 0.12808642290051908, 0.26638568649368904, 0.09503205021422717, 0.09381940197800437, 0.11549991240063984, 0.15285642036507208, 0.18197514657532016, 0.09565330155554319, 0.1608260023978449, 0.07249423377816716, 0.17523934914460107, 0.1277970638306391, 0.13725975888871378, 0.20916319332055508, 0.10220287833362819, 0.10827404086387928, 0.12664841457961068, 0.19085392175662905, 0.13729142896350355, 0.11706991767090176, 0.1994003067093511, 0.14435822234278725, 0.1754898139305653, 0.1426933907092579, 0.1428319300494848, 0.10874123192362248, 0.17454535009399538, 0.075300712619097, 0.14373818142039163, 0.1316499728108606, 0.21989985429231199, 0.13815595918605406, 0.10905091530613362, 0.25870896455261017, 0.1396543812006712, 0.1641205175509376, 0.19699099083100596, 0.10503525860727796, 0.1888433699646304, 0.15349303943014916, 0.21865395017929617, 0.23749332394330736, 0.13903576520181474, 0.15000064376621478, 0.18038491658385725, 0.15447715597767986, 0.10309855769117994, 0.1275594080347688, 0.08976454456006328, 0.22645833301207713, 0.12384706852777351, 0.11068269790660952, 0.22897358352859176, 0.18448788432344315, 0.1021979753709128, 0.154434408271505, 0.1377938141024882, 0.11176362498513154, 0.19262897812070387, 0.14457076577649963, 0.1672418508678675, 0.17934815447417, 0.19871775301233416, 0.1351523735830861, 0.16343833157612433, 0.23035986559285274, 0.14696713476892442, 0.07848511029395365, 0.11487793327579576, 0.15070743648515594, 0.10047076119770927, 0.10155218623338208, 0.1130481935556858, 0.12203880991306036, 0.13738354337551903, 0.16763082435054166, 0.2116035051163166, 0.17200350100474973, 0.1533355317529171, 0.13728211333434429, 0.08998125551208373, 0.19884821778583914, 0.11850117675719724, 0.16490906717315798, 0.14565923882107581, 0.13536864020411046, 0.14844643522895154, 0.12806731666768753, 0.12946332804858685, 0.14579292116386278, 0.089043487283972, 0.2614931425740642, 0.11189852540771808, 0.1430741210858668, 0.11202501418489604, 0.19626564346253875, 0.14108396255441252, 0.24089760417419098, 0.19894560288277366, 0.20447830519368573, 0.13039728115883567, 0.10293468382329711, 0.16835698377220862, 0.14214865622981904, 0.11829568133238824, 0.13809591321454895, 0.17616844525740993, 0.2654836639281242, 0.13080818007790274, 0.16950547214477293, 0.15895340771925065, 0.22580041670270506, 0.20555439825740554, 0.16572490484724123, 0.15319827944040298, 0.07904245458062618, 0.18915259369438697, 0.15768792239889023, 0.104695828030667, 0.10670985020096264, 0.12798958938689003, 0.2839795698321635, 0.14389518347959365, 0.10785538913501848, 0.23566424305881226, 0.2589292607961163, 0.11276865573299509, 0.12867287852831427, 0.08460855832503689, 0.1297223423757861, 0.07867425740245851, 0.19409490268557303, 0.11700309182126677, 0.08422855573195605, 0.1487255517032839, 0.12216738244939236, 0.11114114024225744, 0.09538425913741512, 0.2326408311003639, 0.09436766046189493, 0.12157161119243792, 0.09981481373430261, 0.21611059955771894, 0.0884586404408178, 0.14015609218228248, 0.13665280274806485], [0.03650497059307752, 0.030926354717643514, 0.046294934581965215, 0.04852051959343014, 0.021870408297306108, 0.025591109653994925, 0.021218028888406775, 0.02608641614055922, 0.03607811789298731, 0.052802391845973275, 0.03483925412799563, 0.0696396446155925, 0.033849617916970484, 0.05750380831980898, 0.022155751151243047, 0.016235626685703476, 0.022906848650065162, 0.07451306698062728, 0.027229342714793263, 0.03670274768204939, 0.06282854074191663, 0.05007737496447179, 0.03340533671660289, 0.017886647669177864, 0.06166582994703805, 0.0138567264131721, 0.03575347281331497, 0.027463924582867373, 0.02453308860440889, 0.07944171662412344, 0.0461022136732936, 0.009788778467824864, 0.07933978096491869, 0.052076569502992984, 0.03201418807880292, 0.03866831479113429, 0.006833824605095171, 0.013726391874614262, 0.01866582612086448, 0.017826013725190874, 0.060576023909473614, 0.04655810110571404, 0.09174411575640402, 0.03524722659119195, 0.055843412335361206, 0.037784387222340995, 0.06203362492904548, 0.019980028887549718, 0.028714607169310895, 0.001112310827950076, 0.015225105960252545, 0.048389579845412124, 0.023091713327073285, 0.053113438864989634, 0.07478456854099229, 0.026254871214229255, 0.06275994905961618, 0.02512984619956584, 0.040402021559496085, 0.05530319011379635, 0.016789500594079014, 0.04522725699409362, 0.05328716845401833, 0.09112938382332364, 0.09175568368406066, 0.043025485825754946, 0.030084592628202615, 0.025860728553286003, 0.06722528787870562, 0.08971049705700529, 0.01613152108245319, 0.04418721219765083, 0.04585043121609957, 0.06706555854649314, 0.041415494596285206, 0.022584582273397717, 0.01789830369694579, 0.029676742739074176, 0.03704210931074716, 0.07997325140862696, 0.07062608240953377, 0.03597512120200742, 0.05405669228263921, 0.05379051503334796, 0.05858238350840346, 0.01719408886386983, 0.033916286718581, 0.01569115171854895, 0.015356708374325068, 0.04078053794200382, 0.08808308881857703, 0.029482183219384284, 0.011201478116544745, 0.03065656344856947, 0.1159439369615528, 0.054022275782640905, 0.024968621080681205, 0.03031786831636583, 0.0367808350241713, 0.01528591801968193, 0.01506863250171826, 0.06006896563415086, 0.09875817930385952, 0.04299124169553961, 0.03368059593823648, 0.04315793093654417, 0.03242672834124777, 0.047256359605178724, 0.10353197193434162, 0.05024430935361213, 0.0595161795706278, 0.046362683567548954, 0.05814240006129107, 0.03144201424513613, 0.04802084640569745, 0.08439783051970505, 0.028895534154388215, 0.03343776138799806, 0.04223975923753554, 0.0796120026479325, 0.08559523360623468, 0.07000067121078891, 0.035431401789068215, 0.03367099302610563, 0.024493772972134814, 0.05801536353124727, 0.01968474412757543, 0.02973272269892116, 0.03521076846687544, 0.10635096865195422, 0.014997939823285468, 0.03421304619780952, 0.013268707008401473, 0.1166556556258471, 0.05844356837652384, 0.049348875144196135, 0.02900079080474473, 0.03617723051819109, 0.016829084357126586, 0.03295334484127741, 0.09006236890150655, 0.06727804835405081, 0.06593519581421729, 0.08155237312518782, 0.08191121636980003, 0.020048930835459503, 0.053211237649403276, 0.07154000998144189, 0.01706522712934642, 0.020408905974979845, 0.10116860600969485, 0.05849874585927014, 0.03405420935802883, 0.10144934659042668, 0.016551816069911567, 0.030503320965855837, 0.020419889760594216, 0.022574613554283016, 0.022265186811226512, 0.018677160391704212, 0.013406355771416379, 0.029188924761969718, 0.03838315388307937, 0.039870846836316975, 0.05466358330581458, 0.03972996326704179, 0.025593180006610292, 0.04503756213272291, 0.06858569915376364, 0.05657072088891461, 0.04375499305165103, 0.09130101816187944, 0.03831318324251521, 0.06442256286860475, 0.05364918330263707, 0.06932393212111727, 0.06534510892966101, 0.03933253217368357, 0.0396412656071686, 0.05048254354586525, 0.01565981872244588, 0.02046076821223382, 0.0459852205559371, 0.02347293016951411, 0.03430421832167814, 0.06490366608505288, 0.029403975218414303, 0.012486086906715026, 0.04002869925311497, 0.006884799137966888, 0.050337385205972585, 0.09208792069506261, 0.04223037849090273, 0.016660548844224504, 0.02423104503372264, 0.0673729360043522, 0.06941033917809687, 0.052057627979065144, 0.04616248564073636, 0.060847360760934895, 0.039811000047672185, 0.014559746149086185, 0.03514269006348426, 0.05255371970575183, 0.017411910643380497, 0.03892606124281883, 0.008115536146496814, 0.02077874832696492, 0.043015844609227874, 0.020680463076719356, 0.07581330971011231, 0.06543029024596177, 0.05354119937927012, 0.008041187313445395, 0.048084692173306985, 0.02219244293237646, 0.004197854911082335, 0.05589875452701123, 0.038946366403251886, 0.03114920394915727, 0.04535189566893443, 0.03568099706523842, 0.050552403103680386, 0.045572839256736546, 0.060320602534639264, 0.04513321970138819, 0.016414044732828776, 0.045902797156163765, 0.03604373203650598, 0.05984550544751748, 0.03730129600772935, 0.04233902124988456, 0.0252250881655322, 0.03860092969731458, 0.055697487907544266, 0.060190352265753096, 0.012719101167374082, 0.012797863624479263, 0.05462556236213254, 0.05218497860515791, 0.037119530156374946, 0.03490509555464791, 0.08267214852235011, 0.022272815131732536, 0.09711883541557098, 0.03499557436894506, 0.018322199297648285, 0.041926011758586096, 0.06030929124643726, 0.0518759617191409, 0.0712392668450071, 0.06547082395803544, 0.03440566751505098, 0.04376727344107725, 0.01409049335521676, 0.02651139001001514, 0.021612916569856387, 0.040749836968438286, 0.06283242863813235, 0.03574290846083914, 0.07516961199261489, 0.02795742118671056, 0.08312814703751957, 0.030744223059305263, 0.04983032693064982, 0.06785119703460125, 0.03668245018249558, 0.055540447543946006, 0.01669050288206387, 0.032766932666662245, 0.007431784479488289, 0.028899615487804817, 0.026236925604602983, 0.033680519329444054, 0.08024904306136793, 0.013195105111076227, 0.033640548691994725, 0.053781310486937725, 0.015866603090187475, 0.04620099305025032, 0.05117752701945363, 0.020006443599178907, 0.016641999940357862, 0.04462011316190324, 0.03287071842820414, 0.04877108397082456, 0.04239052151059432, 0.04462383251877562, 0.04750693164345238, 0.0378072970817166, 0.06315608163394275, 0.019034438901731086, 0.10853162260666009, 0.03154895628892607, 0.03228180365817201, 0.07025709616080408, 0.025778017870541063, 0.025366582689926993, 0.05051978307986452, 0.038735845441659617, 0.051366934597852736, 0.10225431347686438, 0.005669194281161313, 0.03305305501506214, 0.05551841868568332, 0.02012539790162156, 0.018175052959592115, 0.05247392015711916, 0.03147501922813395, 0.03909724741993893, 0.02176807235716091, 0.03043351311897559, 0.07157280620548033, 0.020993861985663255, 0.03558209128377419, 0.06265840410525281, 0.060550976664789265, 0.015862018053960657, 0.03170258373082165, 0.05387075891297671, 0.013139203675241481, 0.023146783557510184, 0.05933483123719212, 0.052286569524796746, 0.01561236436358623, 0.05239706238611572, 0.04244747248688533, 0.02509172374923383, 0.04585853259589884, 0.030900947411634752, 0.03817917914280007, 0.02257164113313681, 0.027469143556851535, 0.026350228093384255, 0.016756066601843606, 0.10491692100561435, 0.024451626644980524, 0.0646951292911845, 0.04122216464771379, 0.039828137434538335, 0.033560032851152846, 0.023401971275527633, 0.019549805400592667, 0.04744513899147992, 0.0856966789691679, 0.03183857965913992, 0.07218465764796542, 0.017519875414549343, 0.00992588522363334, 0.06922274722807831, 0.07335130230433519, 0.04484606313429052, 0.14430424378764245, 0.17063281649062711, 0.12740505663978477, 0.12712187989945375, 0.11094504471627936, 0.0831585607281135, 0.20929266217975848, 0.16620325014716195, 0.11489849507568345, 0.12697080736078564, 0.16578207032815104, 0.12442010229513531, 0.08789755764507479, 0.11378223602209361, 0.0829537241389194, 0.2046534941802102, 0.0819545769463143, 0.14490111821120785, 0.11968461406086722, 0.17695949232626348, 0.26555837282250006, 0.1111461811007992, 0.25260955636059085, 0.1579210276324903, 0.2208609728803558, 0.09616969078178368, 0.13331120383114586, 0.10973187554026805, 0.23606254749240416, 0.1412695703367072, 0.12303778856632211, 0.13933947309851646, 0.1876270062019748, 0.1485645506651171, 0.257250486362365, 0.22449391503487864, 0.1794923015780026, 0.09094136286406748, 0.1619691587984562, 0.20531053714934858, 0.1459567567273494, 0.15687576194684352, 0.24086884523351348, 0.11467546389828767, 0.131871004498774, 0.14934991336157247, 0.1578019928908156, 0.09478189186343262, 0.19178071960566506, 0.14582954016664337, 0.21016491456858574, 0.1031977737382535, 0.17259568697021854, 0.15560852994601573, 0.13316440606309524, 0.16389772386079834, 0.08735902847782259, 0.13380977385226758, 0.16838560481705975, 0.2191121933320838, 0.11917057672455428, 0.08433082846984749, 0.1908342792622505, 0.21886615653432187, 0.22844538122655886, 0.18830796643610925, 0.14460959111250218, 0.10970484029742018, 0.16580192732714838, 0.2540130141161142, 0.08672224087340218, 0.14824434123452634, 0.13017753649863506, 0.14391254303195786, 0.19153849792576608, 0.1271746863400744, 0.11748610259664637, 0.1302874854375278, 0.10330540143073567, 0.2363526343458122, 0.18268279731273654, 0.12154734152699671, 0.16276604345729276, 0.13555797117371715, 0.28353615814158994, 0.15354914770972344, 0.1511169870894763, 0.11069571374044304, 0.14660382523171364, 0.16465279544072767, 0.1636312631589751, 0.10278143559492404, 0.13701033598232654, 0.13222582578178377, 0.21338069120482092, 0.19548645543475307, 0.11788194788800133, 0.10382009760266352, 0.21955194312237927, 0.10649994977058903, 0.16731086006808668, 0.2378554690268732, 0.16775324520084167, 0.14592271177999436, 0.16884580915493352, 0.10436473249067223, 0.09016572948425047, 0.08716569086837192, 0.20448179855462045, 0.14886514824484626, 0.18465617851864907, 0.1563415381937258, 0.23208685760055822, 0.097265740435931, 0.1965386925205108, 0.24607868744961678, 0.202923545073117, 0.23612142901026437, 0.1965067160105513, 0.2277870052644322, 0.19108442229128655, 0.17784322071219646, 0.14921903490058838, 0.10995433215172061, 0.06661598750900838, 0.2401478032791807, 0.07988173454519241, 0.1551114614572256, 0.15927433727249024, 0.20072530173966963, 0.10662842271549088, 0.1408486816311075, 0.1490606998483981, 0.20799746796969446, 0.1477951685627622, 0.14528636850657003, 0.16767855162822431, 0.2321677718071207, 0.17803105014947154, 0.25190611910675803, 0.10654824395333568, 0.12034560238281566, 0.24161746635312037, 0.14669295190082443, 0.10842434731462311, 0.12967380304490367, 0.127124791033566, 0.1427467410723048, 0.08895695765292452, 0.1276969821042111, 0.25783816773083906, 0.13917044345890323, 0.16614519600425998, 0.14046798189801557, 0.15068365711598627, 0.1540933765711323, 0.08676891861062858, 0.14631858005398704, 0.0817118343266268, 0.20696367828115342, 0.16523142164993673, 0.12323051330543335, 0.13520915602003375, 0.19794095517887225, 0.15527517444664432, 0.19126883497641933, 0.13825570383379537, 0.12572650437153157, 0.1484850154168183, 0.11228395956418208, 0.08592938583704733, 0.2452935545795387, 0.13167578997390886, 0.17168106991917859, 0.17589075370661675, 0.1594786988871713], [0.04680026532901872, 0.06441038973148792, 0.015395346976396058, 0.06824839064070294, 0.04984908076303621, 0.039531113654975934, 0.018686378344653115, 0.012278284599644043, 0.04223818492685114, 0.0439848424115729, 0.048314598989823175, 0.08202164794408506, 0.09334065065148378, 0.02440375572581205, 0.06616445528643747, 0.06407709551915046, 0.02808079964691593, 0.031762491806500384, 0.021296474376633283, 0.02979581195470547, 0.006548154248570603, 0.029849246587424032, 0.010875685820205799, 0.043882937395885106, 0.04753698144228228, 0.09633178732568219, 0.045360441379729784, 0.048704648826030955, 0.035652582864126856, 0.028998094175251263, 0.05710666450942236, 0.04360099022667255, 0.03918717848137021, 0.030610335787998575, 0.024292912379267718, 0.0330387483230762, 0.042985086179068016, 0.021725954758303783, 0.05269677896473197, 0.026196665768962235, 0.03080714952140566, 0.02976038996430655, 0.03338540693925273, 0.0238041348770381, 0.034747499777304555, 0.08261299121283716, 0.028370852026367382, 0.010584668169969754, 0.01422267895372164, 0.05104749508562589, 0.047495727607559775, 0.07389564607893268, 0.015198018048859894, 0.05597031480001827, 0.028989579107972886, 0.05219884479658739, 0.03763829042474109, 0.05700118952400743, 0.02935379645937393, 0.0576383448506315, 0.025901434635142648, 0.040932296129364165, 0.036003144698277596, 0.061902007193214474, 0.027785581919635018, 0.07897758225519812, 0.03221043490714604, 0.008115489223611452, 0.0745944485008236, 0.04087725654244423, 0.023896136291084752, 0.03980932997599725, 0.04260527893840786, 0.04781201083753859, 0.05341093761906509, 0.01759989138302063, 0.009930365880380475, 0.045085373680077256, 0.1011825028446413, 0.04689322243775091, 0.036832611076533794, 0.03274103506438194, 0.08309862966979704, 0.0825758436093888, 0.03508452100739364, 0.013288900128475601, 0.05299512807640338, 0.045697527727292436, 0.021038553639945966, 0.03403804107238689, 0.042884154095044064, 0.05010508819513264, 0.008934995501242098, 0.006709757623367853, 0.06426460319949735, 0.08120280720533864, 0.014416185102515645, 0.022817365750069582, 0.0929437481587933, 0.007810624055339084, 0.017702888074000517, 0.058214082908366, 0.03564388776618627, 0.01648711994470608, 0.039952898683447036, 0.05076697283995248, 0.0514498291416995, 0.016119995289632393, 0.048590624299381054, 0.07195496150562841, 0.03920309395799714, 0.026392611907795075, 0.01026572565728378, 0.042800933963829474, 0.038971597509038065, 0.08520194704854682, 0.02394649508078733, 0.06530284385887847, 0.07769774044713668, 0.023214632134524085, 0.03743662543955349, 0.013605856558217878, 0.06429438103711413, 0.05920595226569041, 0.006917615471813347, 0.05165450868286914, 0.04254287341609598, 0.034943135650528055, 0.07213302332186891, 0.059059901433365966, 0.024654904245248726, 0.037260375421253905, 0.021293207011636228, 0.01206076446725356, 0.045316192141223344, 0.01691270476928161, 0.06326104717088804, 0.0017482311968999586, 0.07064095217614405, 0.030139940565512068, 0.030793890454656178, 0.0726247828213438, 0.03242644105827616, 0.012728843890551119, 0.06554831375157641, 0.02993774697965672, 0.016075924166568344, 0.020614297977919062, 0.04367046674052554, 0.05726814818298144, 0.009469335125158391, 0.020949396327318206, 0.03316643985829527, 0.020138691442327637, 0.04543038903765621, 0.03824887016127187, 0.04870406276876888, 0.036051097971897934, 0.02358456067140064, 0.02280711740886252, 0.042322362667971083, 0.027326015349958214, 0.026753349304800073, 0.054580244430971724, 0.010476435268027409, 0.08744339008004436, 0.017234373597368118, 0.0660673842855519, 0.007792873319328553, 0.02743465810894005, 0.017041980191284133, 0.02324496730110578, 0.04886913939469284, 0.013696772042631864, 0.03097916881914341, 0.010724418886726903, 0.0321025256773517, 0.0444987801564557, 0.05726699139021578, 0.02307282542930015, 0.06645578320228285, 0.03156799357384443, 0.052320637454789494, 0.0069775833981111654, 0.041031175097751046, 0.03508003173215735, 0.020487924113929756, 0.03575842174130582, 0.09132495074863396, 0.054736484232689106, 0.04351188654019948, 0.026169728202324723, 0.051769789593714866, 0.033119930660412196, 0.03521991555669135, 0.03146338043734431, 0.04002603326713847, 0.014225089257853407, 0.07139048494038082, 0.010318494751118124, 0.027888509662701722, 0.10519419120804918, 0.03814352924124368, 0.025828123851228627, 0.04753737597756329, 0.021875041214028196, 0.019624853288874995, 0.08205777665059413, 0.016285263437537417, 0.03363071212304696, 0.14029558147153548, 0.03576307189500621, 0.04489623040201203, 0.028288179648018656, 0.012676896426015565, 0.02346607176737199, 0.018233834886022152, 0.05885715626420514, 0.022754498659783316, 0.02302578954596914, 0.04540653689013374, 0.07999946693739585, 0.004455484534358426, 0.07800143302207993, 0.01455569162874693, 0.010384448218129335, 0.01634374275923737, 0.03602847922593355, 0.04700533557502974, 0.07587570757154496, 0.022825302420965126, 0.013584164778641878, 0.02616840670065534, 0.029306448395213777, 0.08043653541995634, 0.03365460257496565, 0.06664404164879553, 0.028123957210130272, 0.020650945708996827, 0.038616734091192484, 0.03812090666483968, 0.05170544586895455, 0.05141885237648122, 0.06390644560357736, 0.044448655023570025, 0.08835352551672729, 0.10311331254460158, 0.04465184452372693, 0.050491663822603804, 0.089344015915788, 0.03246214075554763, 0.04912616189328894, 0.03591625117546609, 0.018420093843052467, 0.06016302590949401, 0.09444254555649335, 0.027790076940530734, 0.026965032804817445, 0.05078749633544395, 0.04165813379410294, 0.03782007159785398, 0.03585994371303147, 0.028792983709624218, 0.06996484893944956, 0.04297829480961927, 0.07924570536781704, 0.06348039729580765, 0.023490197791327393, 0.06888106435296998, 0.026822433198591875, 0.08362877783515761, 0.0643933289534142, 0.06396519305605082, 0.07654706872398816, 0.09149185832469695, 0.024351251889921488, 0.002618489003995614, 0.016903915825570305, 0.06610916672094215, 0.04388439679338087, 0.043246498361470244, 0.03826162935565076, 0.029444520421806845, 0.05892336541306108, 0.031576847635029305, 0.041625582718200264, 0.034788370568064914, 0.029579528096702792, 0.0350019175769581, 0.005486643189684518, 0.032887292740445946, 0.04979937697850889, 0.029742678011497183, 0.06869207046204998, 0.01263362203439277, 0.012043177961341798, 0.03545338851249507, 0.07350884062508423, 0.055516461331036784, 0.0674297797283338, 0.042601754933956175, 0.04483912620813616, 0.07975535302032387, 0.05783314951845716, 0.003339055744412866, 0.039941212012162136, 0.045967906968848365, 0.00645670585424429, 0.03603951472248282, 0.04354901882188936, 0.04879049663882583, 0.042252277114218285, 0.03745105470560732, 0.01999161979784408, 0.09251136047345015, 0.03941987768837041, 0.08801560413332717, 0.02308239003703479, 0.024039714574633587, 0.017723254521467516, 0.024130660702564546, 0.057799116062421, 0.04425443258256682, 0.059626749040739196, 0.04810039314531511, 0.10680633131414653, 0.06362462483887231, 0.013419429061844224, 0.04985023372536225, 0.0884201598443812, 0.04871003442413865, 0.03522984405619002, 0.039866970431420116, 0.07254160099452542, 0.04589325553106685, 0.061334971894299796, 0.009352289339257105, 0.04675025893976131, 0.011385818023324735, 0.019289193780071313, 0.09378465222975901, 0.03382451704613144, 0.06395635623184424, 0.07490525803258342, 0.019064618935508114, 0.02502949251192472, 0.040390223805462165, 0.019753458383943767, 0.018246209121219093, 0.02858540069522156, 0.04246430726902139, 0.016612697077254136, 0.12477989548877363, 0.10629255444772782, 0.1307322147993311, 0.12050330924290804, 0.22660156081040062, 0.12532073824155715, 0.11539098235868639, 0.09493430505596823, 0.1339785123784696, 0.11403148272825826, 0.1585682646761979, 0.20603642077936282, 0.166201074457457, 0.14346366147360495, 0.17645514600219267, 0.13640394674674158, 0.1622237298156946, 0.1613650218613686, 0.12870695411918626, 0.12524211463788826, 0.1085001057494552, 0.16886376625587865, 0.2611431936102529, 0.08920743009976803, 0.11988899865818602, 0.25291746241911767, 0.11893450673068724, 0.17398224482613225, 0.14340222122207766, 0.15728384166234927, 0.1237594587127528, 0.19111079103764028, 0.12054151404769191, 0.11495766004607563, 0.1868786455522622, 0.1993882944506984, 0.09405481313625652, 0.06491740970241447, 0.09841330950298617, 0.09002188881558758, 0.10507042204300243, 0.10964276419291574, 0.11518136538084477, 0.1883801012750595, 0.21090022108006864, 0.19509466274851756, 0.1394681758697956, 0.17167386869269033, 0.12336737491310605, 0.13760158732052774, 0.1128661250996013, 0.12159524500490197, 0.11953637604751896, 0.27992380843047177, 0.16155426090042438, 0.13572062696180037, 0.12906149961054325, 0.12983279693270885, 0.12428209155557618, 0.20092483700042774, 0.1073755499636454, 0.15266989327726826, 0.16821107466615018, 0.13816948829879686, 0.148569438306074, 0.1854354278334687, 0.17397440008578763, 0.23096553470578887, 0.18078024859630293, 0.16796171304679688, 0.18227582076384177, 0.1203498694925539, 0.13392252667296317, 0.17989195432634125, 0.20438160957588306, 0.11466475398910624, 0.1392305200739253, 0.15253967365189908, 0.28219801704249076, 0.22455993649219314, 0.25438196206044766, 0.17285614154271542, 0.20507516429549266, 0.1865754126300735, 0.12715607040351437, 0.1637758699155623, 0.1306447888454122, 0.15835759049702078, 0.14777839123722047, 0.1421990494934782, 0.12302383044434172, 0.09977192813230139, 0.20953876026455434, 0.1111754073551105, 0.13690326753402912, 0.2009163181027097, 0.13486375761849267, 0.1425975990752059, 0.13996435569659357, 0.1336330373681361, 0.09295057400219864, 0.15656260052515616, 0.16882544653790613, 0.22114416494244532, 0.13785303269903507, 0.13859396229588217, 0.1829918984684252, 0.10457875447407847, 0.09971014314120817, 0.14636638394046217, 0.08234216380984553, 0.14929481631805822, 0.05666449005084653, 0.09556795936077835, 0.1685732350714745, 0.17547256163051053, 0.19045783897801755, 0.16983159577413914, 0.13434719985290883, 0.1872400092261453, 0.13841157208286947, 0.13283969203550972, 0.22977151006700533, 0.172520135379126, 0.14195946315603872, 0.1616557062633576, 0.14484165446652522, 0.14076215966093925, 0.08916381671423874, 0.20290336631719144, 0.11603959069977846, 0.1046118341506489, 0.11798583707141301, 0.17109372562939124, 0.15303839689060567, 0.1325100903669673, 0.10328395096885581, 0.08310691874113776, 0.16521508865539106, 0.09200519086011956, 0.10177170872808465, 0.13069265401892124, 0.08214062139872583, 0.201035276235592, 0.2235573725474458, 0.11654013722774484, 0.1465682174649931, 0.14492842158482921, 0.14833055676952486, 0.17443057480117968, 0.10886145410157981, 0.09639042369540661, 0.1705806459029836, 0.18841051496565345, 0.10323981664353803, 0.21907148341978752, 0.1763215862334736, 0.2277815966836868, 0.10222540897948128, 0.09591192517790104, 0.20312331016025237, 0.12602195384040957, 0.1540921201869365, 0.15914126780004273, 0.2331075931508695, 0.20427546043309475, 0.09427277281159356, 0.22173628962088018, 0.0781060346672612, 0.08854195250258332, 0.1362066331409639, 0.12970982449910334, 0.08719313979869889, 0.115776025810309, 0.15553795792643102, 0.06387667925727945], [0.01197815241832887, 0.0524113767389809, 0.03293595464539624, 0.10073662435095157, 0.01667839677764043, 0.004601885851908235, 0.038357574207287644, 0.06919742802218085, 0.05682569410231325, 0.015388704994092546, 0.04338312248188642, 0.0722029977928727, 0.027750989219414133, 0.03729057077678942, 0.03738365812046874, 0.004274163971610007, 0.11107664329991226, 0.05131986232534532, 0.02304670949196143, 0.055867743287836356, 0.012293964504234254, 0.05485721585911609, 0.05170758708470291, 0.01825488506696157, 0.010863720484438443, 0.03023199560571342, 0.08765189623039576, 0.09869663180002282, 0.04052067325720864, 0.06925836265567811, 0.006043169198692927, 0.03097321248553213, 0.010476580824733022, 0.03138280713990812, 0.005064625462006417, 0.06448092344667643, 0.036182133480906487, 0.0440412188219207, 0.023242814594038555, 0.026744307552073753, 0.07963143063769226, 0.055534429923300786, 0.0613560737861741, 0.048744209606440804, 0.07760565667863815, 0.029562919310504393, 0.04981067294495241, 0.028280993743288903, 0.017898692486567364, 0.04844311790000047, 0.02102001622739819, 0.028490681584263523, 0.02218040194542658, 0.039764977315621036, 0.057688933466711355, 0.04162213149210138, 0.06856512203211747, 0.031903063194946416, 0.07881175486310836, 0.0074086103197788045, 0.01453248586791057, 0.022224180039859587, 0.033979619207281264, 0.04597425400730103, 0.04602020779143899, 0.04702847526078263, 0.016737079112640312, 0.02819161234994329, 0.043259464399588686, 0.022364663328194333, 0.018793103968604438, 0.044741342745481, 0.061942736257708846, 0.02960481091342386, 0.04153052269811592, 0.04785783438672943, 0.04842329920539933, 0.07686723985018269, 0.03232840861704561, 0.03781198937025282, 0.14289750717580318, 0.11086240681188722, 0.026658729785272194, 0.06245362880309263, 0.049365441795558705, 0.019796340155505368, 0.05151775049706621, 0.05807314571293612, 0.04631170807706733, 0.03562102770252574, 0.023942385019073566, 0.045632735841096415, 0.026923441891408256, 0.013983400966671687, 0.05241221177481836, 0.004400286941804112, 0.04377838171597931, 0.07795827928930521, 0.04069361760611496, 0.09914836320545405, 0.043604426131012945, 0.04001415890431212, 0.052595490649823225, 0.0029871412862708135, 0.013018066979824536, 0.04056349757217592, 0.0483900394981667, 0.022941569670013363, 0.008661610322193274, 0.021833760566228343, 0.014656122882790385, 0.039764437223634416, 0.03208861735108639, 0.054973343297118143, 0.05157309268871623, 0.02421717501185354, 0.09465869726432909, 0.017904053186817516, 0.041467025500511935, 0.05482893572339127, 0.008192666836323277, 0.02096683057325502, 0.05167109831686943, 0.02089888048959115, 0.05087558878585697, 0.006203448198991077, 0.04123755535411258, 0.02232032790479641, 0.006714304355198458, 0.03203854775957523, 0.049438859831782124, 0.012893273172179058, 0.040956703690631736, 0.059378896614596735, 0.04646094966559641, 0.057235409415537314, 0.008455263582178423, 0.03211148507562617, 0.06271345901393122, 0.020072804050399892, 0.0323818470802038, 0.03835744014190089, 0.0807236728348559, 0.04403298337673468, 0.010648354974335, 0.10572571067079421, 0.026555792466106436, 0.026283881048701947, 0.10038161154596076, 0.05604891542104944, 0.05144797137848312, 0.03185195746951767, 0.03593950960484724, 0.06862615625704489, 0.03606070088402879, 0.0259578914847225, 0.01447948311725932, 0.02772079960953805, 0.030705144914287715, 0.01849183414672171, 0.027200748483019493, 0.013693417535133421, 0.02342075192099137, 0.04326428309263241, 0.10190368269480045, 0.024042265647421443, 0.02532566401867136, 0.01954626224394287, 0.03971977812808849, 0.04490660323250679, 0.04060732163188439, 0.03292835505318738, 0.04525246128680245, 0.06734404682872758, 0.08894383456678161, 0.018289050673164668, 0.04606603134062983, 0.06211088489620917, 0.044563981899691206, 0.04391749945258902, 0.05728394491598011, 0.023510089264281338, 0.04242728607008054, 0.03328103512044876, 0.016973185495683746, 0.013556438141442357, 0.036916570482595314, 0.017124723432765856, 0.019329093554387652, 0.019692698035449274, 0.02345418399800697, 0.024444592042615818, 0.005418144395544885, 0.019154189935614987, 0.029655221414061326, 0.0591189859645261, 0.024410139153441115, 0.029576770180175384, 0.02393713157113281, 0.04049612013923545, 0.028375530908364924, 0.0861846310116591, 0.032059553890459, 0.047615497793641784, 0.01937765012224836, 0.047019163462063, 0.019358570702494155, 0.0830025316005753, 0.010839817583590988, 0.07742197177703343, 0.025986106502973748, 0.03841756272219843, 0.06979367425364834, 0.09198357185889637, 0.04149575762811207, 0.03275174497356338, 0.07432663182337439, 0.058905959895421425, 0.01853444012663057, 0.009336958962282347, 0.08418403070179686, 0.022349833781200073, 0.025078840065567244, 0.019631931941295346, 0.024947540256224816, 0.0037088686498933507, 0.027163547253416433, 0.010572200089002089, 0.020369825914742488, 0.024432620003579125, 0.13832770077691925, 0.08040943122919529, 0.018198554621889226, 0.04994392244806213, 0.01589970096134611, 0.021126249639858163, 0.054541292690461686, 0.0748136722212357, 0.04220519718083163, 0.095084419984731, 0.04076373763382435, 0.07026884794956254, 0.021652536722080364, 0.006726164832681178, 0.04399999563071517, 0.06709054067370392, 0.021752214337128307, 0.026855325183620857, 0.022182464637162707, 0.06673624799136194, 0.028660427516085968, 0.08934144952124165, 0.07820812354405081, 0.07124947113615852, 0.04603595472872258, 0.046011995328890706, 0.09483439952976282, 0.0501890552620734, 0.02184369289616664, 0.04581325679957386, 0.16694922060255082, 0.025749427469206915, 0.04591931018137163, 0.07703506673175482, 0.08978771105889352, 0.06681106413804716, 0.045221247034327644, 0.036899011747370807, 0.057234149200901877, 0.00952266346317746, 0.024343050918692065, 0.06750867912365545, 0.09685105704251798, 0.08581329287300188, 0.027480684671430822, 0.0460315918579938, 0.012799568170110786, 0.008090291634171961, 0.033352419193233215, 0.0032034624910597964, 0.07829045501327322, 0.009025447502461894, 0.02308574741736295, 0.040475068043076226, 0.05505863186572829, 0.02045201757291873, 0.012573035013291144, 0.06385626684453699, 0.006220727312123224, 0.03752143520321097, 0.022869984499148788, 0.0295322623869945, 0.03143802484227044, 0.01036362020268796, 0.04556445442440529, 0.026734606963732553, 0.0005522767946052726, 0.08389383659607942, 0.007876570819080959, 0.021588405586719032, 0.08791091821847424, 0.03055496486805139, 0.05435524440761055, 0.035941378859382485, 0.04463884784209152, 0.05553865872864282, 0.05859494735036166, 0.02929474257173077, 0.043643362549764496, 0.05584912735127634, 0.05574732192701871, 0.023618050205010562, 0.026434114721092968, 0.01658323525090612, 0.027668232571393735, 0.03696592569711708, 0.06092409212743083, 0.02864117381132899, 0.04134306098304449, 0.010408375059224425, 0.0342920758280783, 0.026732869859364246, 0.10394677024094329, 0.018551663698388204, 0.06019308719964278, 0.007834948783349848, 0.012239655573672105, 0.03052712140244342, 0.03554853280225108, 0.043959542357873534, 0.020740147071680235, 0.048555591098603704, 0.013571109682802233, 0.05910120889424317, 0.01110496444462408, 0.014167096401985376, 0.009496654778148138, 0.026258238170656468, 0.04301237806137051, 0.05155920734508865, 0.018553688085728118, 0.005133628437761217, 0.035095073868550604, 0.03248367931753878, 0.042093363665645166, 0.01623045367699477, 0.09037775197817434, 0.02173747672068496, 0.03805531421676278, 0.08822877575913746, 0.017951117798445687, 0.032977614506718614, 0.1268907818162153, 0.14489911106084624, 0.1526045000120517, 0.1516723395475457, 0.16430249407647118, 0.1333668371362071, 0.2729301917697153, 0.18480070866644385, 0.2167544658145597, 0.09184395233469625, 0.11811702962844603, 0.22942130063329974, 0.15795246788090275, 0.1588921513288252, 0.12861540661223475, 0.17552318472054698, 0.18053506981701622, 0.08913573959181387, 0.11156602792682187, 0.14386876876796448, 0.13282236312666248, 0.14557159836253813, 0.13295665833978884, 0.18358203131825696, 0.07710690279641459, 0.15096335581714107, 0.12855660170316696, 0.16653462913968872, 0.11926267581481127, 0.15713329006346965, 0.14049865605850376, 0.15880287144212954, 0.06575432245529468, 0.15918390825390816, 0.09824814094651131, 0.09335593410557316, 0.10142575874323807, 0.16283555827554197, 0.12787269203052407, 0.13940914113435054, 0.16806513491657474, 0.2059708436530444, 0.14854950469828423, 0.08921228709720797, 0.1764356107601235, 0.19269000468475206, 0.15934320857688306, 0.14086084710734506, 0.1319906980760636, 0.1128923099848532, 0.0826416505620845, 0.07637164225020716, 0.08503162272034154, 0.13144357340230098, 0.30773589507706706, 0.19587047998943638, 0.1454361999828008, 0.11617488948808563, 0.13423080045369365, 0.10103247984642945, 0.12455451242145031, 0.10456787602555369, 0.12071698648674835, 0.13752059650517282, 0.13944108700079305, 0.16721039529769652, 0.2242446300243178, 0.13060296044474648, 0.18958734859141613, 0.19269775749454576, 0.15013961211567925, 0.19543842172190068, 0.1297052892585916, 0.21133820886813828, 0.16509000181911454, 0.1816811526734983, 0.20929088485577416, 0.2979726560654179, 0.1337440741518813, 0.29002587280927167, 0.2557288059183667, 0.21831707067547307, 0.11000971264776685, 0.11829294639849856, 0.2899809187698749, 0.06391224488916417, 0.17446860340574097, 0.15186111893384688, 0.15803001130059843, 0.0956201222875426, 0.14698431046018678, 0.09094481025972674, 0.23796422286860405, 0.13911579074638505, 0.11644554835173393, 0.18793946282277185, 0.1943705870860046, 0.24469637372080358, 0.17377791385496819, 0.23101549896021045, 0.1268132154138819, 0.10811886209393702, 0.1321792782795045, 0.1154877009591268, 0.09953601901689846, 0.16877732089450284, 0.1545772070605909, 0.21018716176190685, 0.09660100594403283, 0.13121561627955208, 0.2186201657018354, 0.15216398413383192, 0.1578583309967672, 0.18064825164694942, 0.18724494283237766, 0.1105314644894773, 0.15103705347545687, 0.07889566447345481, 0.10489909413961634, 0.1845041253874379, 0.1337913264550509, 0.2361195597557291, 0.10092040884398645, 0.1783933178071053, 0.15941730460091946, 0.21846794403128086, 0.16482861261935006, 0.08506719984354512, 0.0873999605556169, 0.14642382521302472, 0.1811404784600581, 0.08849691419351487, 0.14427637350895714, 0.18106149479506478, 0.12898305220709694, 0.08987240973980197, 0.23174303734014112, 0.1269425233946212, 0.15382590463324902, 0.11555024437726506, 0.1636841845127844, 0.09242455505074994, 0.17402044197003688, 0.12172870518219088, 0.1656763655163588, 0.2212506664856788, 0.1583773708872257, 0.11055476888413392, 0.16565557389009386, 0.1082713595561443, 0.10936781523689147, 0.1005921095249153, 0.07980664260685444, 0.18673934012411103, 0.17999470203874574, 0.13340690353464696, 0.11633459583766038, 0.13855850774674647, 0.13036107584353418, 0.15356742656759678, 0.07778766384768872, 0.12514503597612345, 0.10498551651835443, 0.11726605150127604, 0.13996362025218625, 0.11934048736528044, 0.14903338115301826, 0.18202838968605767, 0.06873087281541479, 0.11500464421847176, 0.12995940062307543, 0.10837614506242738, 0.26262557374373563, 0.2087495671284776, 0.20970815762637124, 0.08954742758144295], [0.04796189977036369, 0.05568000195067256, 0.049039965510488524, 0.012390089386533345, 0.022600070656006856, 0.05515492145693111, 0.010669500916264953, 0.012788763457548716, 0.027446653130614472, 0.01216399385744045, 0.02659322352208678, 0.009355886122061601, 0.04490610910579563, 0.050051607597138614, 0.023738362398299, 0.07600739808572878, 0.04674987206535955, 0.021882393742881475, 0.05704695561660394, 0.01650812224515023, 0.03676845121287531, 0.022183018135687998, 0.01844367211414201, 0.020290143194518263, 0.03653452243475664, 0.002231155428284359, 0.07910264610883691, 0.0757071222629278, 0.045878351290499976, 0.0027852462353034606, 0.06402489811842961, 0.006794662190405953, 0.014392568527029888, 0.13585792523958992, 0.05279901722866682, 0.05354674968628153, 0.020155980131558834, 0.06541417175603491, 0.0574860580626034, 0.02258336036315849, 0.00915917868335401, 0.01645533495672768, 0.034461768133746046, 0.03002124481774386, 0.007591480295354081, 0.04217829983381014, 0.03896808116546562, 0.02428623017734818, 0.08293015161348928, 0.07052688934509793, 0.03310445951478135, 0.04735512749081658, 0.05016222686296509, 0.01017039942164575, 0.04283267681697204, 0.04357215467720263, 0.017596409513404774, 0.04594557550585559, 0.01740550231789389, 0.045961506304241, 0.01236775600832076, 0.07997067735320137, 0.02663280345469473, 0.04487389127814001, 0.03739580444450821, 0.022633006691091487, 0.018741067446347688, 0.08061182399791095, 0.02452489529405871, 0.09713274757227591, 0.035387631355514454, 0.038064852011420076, 0.07821964550643198, 0.04448411723358497, 0.04875835925040226, 0.043712348767345956, 0.05863956431107176, 0.011427554493439535, 0.03248780087057141, 0.07095484904223873, 0.03938734959510546, 0.04048149552076094, 0.021013228688389066, 0.05778647944210999, 0.036562572744104176, 0.0808631468023504, 0.07486549806931327, 0.24045365622207043, 0.14965915241308753, 0.24948048555562574, 0.07472941021044409, 0.035302587935040076, 0.03931356383667838, 0.03964228833454751, 0.07130125101896063, 0.08764533851776393, 0.051235454757848096, 0.13396409460373465, 0.09573796959293467, 0.02196319112103553, 0.04176623263065854, 0.033759334455094034, 0.07351417259703721, 0.02233447754875787, 0.04035824346506307, 0.012224217944387949, 0.1111630043916164, 0.02810382441948018, 0.05201257434823821, 0.04987711192018563, 0.035742942934795734, 0.02975654037248704, 0.059061219104595726, 0.04300891917439238, 0.04295582545080012, 0.13416254201964026, 0.008211337356647898, 0.019968985730121215, 0.03165866199490284, 0.013101378083980132, 0.008851575229557292, 0.012351739982653771, 0.13001154056720196, 0.04894045451956411, 0.045438421469542294, 0.05246541658115964, 0.007595011003075108, 0.026086906436830763, 0.1045549214787541, 0.03815824195982949, 0.053963708360829664, 0.037514724272994265, 0.030006859601745685, 0.037479346332650994, 0.04650527168245566, 0.03976103962369023, 0.03779124753970293, 0.08623621937248015, 0.04688190731910929, 0.024520997821743933, 0.015904003502650848, 0.09756809235700677, 0.037553783265813705, 0.06360349996436028, 0.01976179725099956, 0.01907681888570228, 0.035331523075940154, 0.027733708191062176, 0.016956582455144777, 0.05009726260698611, 0.036641426174150366, 0.06917669768294982, 0.04358024073524341, 0.037513234231981545, 0.056115588053099574, 0.04212795253542643, 0.06265296871143003, 0.037117454058100144, 0.04166582531686272, 0.0035444910792003, 0.032439242387490894, 0.011550281778909268, 0.04950372832677057, 0.011866524789272057, 0.11379918954785793, 0.06367699843981574, 0.023362755234683716, 0.039090245376311006, 0.027284334421217925, 0.03987893289435775, 0.031010007688535318, 0.04968330316666154, 0.02732198955791612, 0.07487719623191703, 0.051484222659060074, 0.031331923579977404, 0.0660548587479899, 0.003044541860412386, 0.049462037821931225, 0.009525697171357612, 0.05006274268511803, 0.06426081489471179, 0.06208715149231496, 0.032928933449570215, 0.02691598785590501, 0.0676114881230939, 0.040995283878498504, 0.03731622706137357, 0.030973901964663982, 0.04517603252503661, 0.01252637068260341, 0.040975365592467214, 0.009177389550924061, 0.06920776254827939, 0.014228420782714121, 0.045982646500511516, 0.027801028167408322, 0.10792704133857643, 0.018397153340159886, 0.08179272555055157, 0.02560033526782307, 0.006684830079921672, 0.03177684063332216, 0.038155526178137916, 0.01955462217841658, 0.06836003263390834, 0.03054913685416743, 0.007000982117343455, 0.03165156993594381, 0.07418433099143928, 0.01215220663711549, 0.11100335166819635, 0.04699938307185808, 0.08902661036700012, 0.08708173529275003, 0.007056184497947295, 0.0496551264528065, 0.088506352396742, 0.04223492522273333, 0.05306001189315031, 0.04811559232973284, 0.0813207081368854, 0.014056154421620793, 0.07382100613247003, 0.0054841969751813005, 0.045675709543208924, 0.07234523733777386, 0.019082453462385365, 0.06270407443685878, 0.04241798576267977, 0.015025247984956351, 0.016049571699583005, 0.04102664751811855, 0.053341794353459156, 0.048869353899311636, 0.06798510920376548, 0.1017171479461174, 0.06752439158698244, 0.06617239195733302, 0.04211771377031842, 0.10205339159696333, 0.045559681696637024, 0.010955286185978162, 0.017084182059812932, 0.04883053622418835, 0.05362743406646675, 0.026670642452494755, 0.07075891439472476, 0.06702264230097495, 0.11154892884435193, 0.026854712313281435, 0.012184019395781141, 0.045852151083489584, 0.09819934880661388, 0.1003298240022794, 0.08204392578092315, 0.02876858763967551, 0.06308691538569909, 0.049344876165231394, 0.04168439145770766, 0.1355529149934169, 0.09238179968369585, 0.030897220393883127, 0.17193375636012326, 0.155649776119859, 0.30755914327117706, 0.14086340584101217, 0.06763227208847962, 0.0716595120367504, 0.05855911741814306, 0.0570779285513826, 0.08813394173499077, 0.028410192556498993, 0.09911595002537775, 0.1368072307518413, 0.056971882830464074, 0.02342108133879881, 0.014814866834410257, 0.042368308791229804, 0.04615932935848833, 0.02991815811143287, 0.029961984086361144, 0.048256671251428705, 0.023061753543574485, 0.040259751371077956, 0.054375821529256727, 0.009040926308971981, 0.11838851586705255, 0.07261113113453312, 0.02919666033478514, 0.021351069632557132, 0.08039111406692574, 0.006951606793013672, 0.01039623256562458, 0.04362355917692185, 0.030924636765473315, 0.0589713340084399, 0.00799223237986406, 0.017221145174135605, 0.03815081090696397, 0.0782836674742641, 0.031203341467546362, 0.12104478018778948, 0.00513459706018048, 0.05054015718821076, 0.034195491293024634, 0.03636750377594464, 0.02041422645561397, 0.05124574714911081, 0.06190598701998111, 0.09408050772523689, 0.0074352773616180555, 0.053924649368010225, 0.02949806422205462, 0.023537976779944958, 0.02435620847879158, 0.017669283627201954, 0.012211794871085835, 0.04205995074082767, 0.049494067958045396, 0.024416292754692898, 0.027653268959012725, 0.029080335629142584, 0.018651527089757786, 0.044241259700708815, 0.037858088711096395, 0.06770556372019552, 0.06531646490217217, 0.04968751665024508, 0.015777653578909177, 0.036875960161729206, 0.07270226495400553, 0.04452778807570858, 0.0360888546152461, 0.05503584074998095, 0.013427521823154343, 0.02114353641386955, 0.049139832732297724, 0.005724782099752057, 0.027059711696159457, 0.04701394640329865, 0.049897689041831804, 0.05471874929724201, 0.06697283126413822, 0.06390004493897, 0.01925916313343952, 0.04734387748964852, 0.0353225483559072, 0.027834799238330418, 0.01457064662263879, 0.0008118018271371483, 0.01873642878396617, 0.2864484567075007, 0.09195200903641601, 0.1395589879323398, 0.13547557075658154, 0.12739472211368624, 0.1092578586371195, 0.12987454872458212, 0.09158044873226075, 0.14464455536536633, 0.20029557237942375, 0.14784185396086785, 0.1303831851410289, 0.10268338400149539, 0.1529668136349609, 0.15639105811715126, 0.11633812750299131, 0.21047432215944414, 0.1588805527576516, 0.14718300302422818, 0.18323531524548609, 0.1738961825087186, 0.16637277008304674, 0.07776709438692178, 0.13902859461884345, 0.08842292542178785, 0.18741758840699352, 0.20652394381261643, 0.1712554774337238, 0.12396630245230852, 0.13422764417144561, 0.1515658686478292, 0.11284259853944664, 0.14923143020320326, 0.17519866987582178, 0.14689535233041934, 0.2566469316520999, 0.17672698464124434, 0.18700134219421496, 0.22382312844837868, 0.10824356588625139, 0.20650834626247808, 0.22549675477127876, 0.14546785473583207, 0.07967660684258708, 0.09769654998015012, 0.13751414604485035, 0.13497097928437496, 0.1728237819887938, 0.14099069901051062, 0.192840157917911, 0.1680757988604807, 0.19981866732480066, 0.2780394466413606, 0.14434970344506926, 0.13206473281306605, 0.11127643903056461, 0.20029106778242897, 0.17550571791587338, 0.21381622751153287, 0.14265808937770708, 0.15483786081594808, 0.1285600797423432, 0.13900599502507718, 0.1601439389970995, 0.16384915388639898, 0.13006351197198515, 0.14102347225191134, 0.10655072607821035, 0.10956442404177882, 0.1754659885961202, 0.17006094717691023, 0.20238481672300448, 0.24562792131497016, 0.14816333509741292, 0.12035160085126279, 0.20256075647569474, 0.23912896762692162, 0.20980591044550945, 0.22164566141943778, 0.16877774990374045, 0.16865540566223283, 0.1531013999614985, 0.10616015913265367, 0.1351070058562102, 0.2149674738006246, 0.2932849640567457, 0.22258266355962525, 0.3561500778361675, 0.3930640244676221, 0.47959736338065523, 0.31120749911473644, 0.2501532026836949, 0.14293712924324697, 0.24499127160637613, 0.1467931868448373, 0.3003793059577865, 0.16175572670275168, 0.30068571048398174, 0.23206552971274624, 0.18503585169392248, 0.12292692798279947, 0.13494461053802123, 0.16072801975232942, 0.17188319455712073, 0.133743308063957, 0.13300795558719866, 0.24083596473980337, 0.1590619776998797, 0.10532506200815402, 0.11196470774349668, 0.13382491174965136, 0.21593533396240205, 0.14081569388508797, 0.1331894571382192, 0.16143162554550558, 0.19015641402333014, 0.12568873623686452, 0.09743425679663498, 0.15316029680111717, 0.13653882418669042, 0.19658386106452636, 0.1544199292097361, 0.2027948269800794, 0.15547391297596116, 0.16239029265219168, 0.2120017022975991, 0.1726823008709377, 0.16490542059463842, 0.25807366315876284, 0.07718029401956067, 0.14099267551735525, 0.18117323637970034, 0.1770295127625427, 0.1323819698225106, 0.16182038452356093, 0.15598659433664816, 0.17239469614240432, 0.15750571604697935, 0.1415979002992953, 0.1551619313296772, 0.12337768645656687, 0.18457679648793515, 0.1416047338035799, 0.21320456759102885, 0.15811238107421707, 0.1462484523653984, 0.10741972259335941, 0.2626964215549731, 0.08807512150416452, 0.13270452348214964, 0.14289980543957603, 0.17837830248378939, 0.13632540741274435, 0.12454253846719382, 0.17616309796369847, 0.13656222051189792, 0.09480754814801678, 0.06666070406114863, 0.15630449018170758, 0.06820242536524612, 0.18159538146949586, 0.1484067518744738, 0.08205520259516855, 0.09743002799129295, 0.24235315590856538, 0.12991542717622173, 0.17432957376924255, 0.2281949164405946, 0.22032388395840125, 0.17596298047611791, 0.16774089586350227, 0.14554676179203296, 0.08409570076412733, 0.1714532966575315, 0.08193219185716684, 0.1607312219998529], [0.043677660306134534, 0.02994618543814267, 0.06420121325420276, 0.031056476666802363, 0.06460918188695947, 0.09032451652831609, 0.018592959667946544, 0.05770329761529162, 0.03727248344089716, 0.05888980310109835, 0.04056989823678329, 0.03140074317343533, 0.07267757394020596, 0.06924562261349733, 0.022627410418804617, 0.08182993444103388, 0.0091416017535413, 0.021047564749155315, 0.04807232368376948, 0.05325646365001317, 0.023974836503546086, 0.07727358820697955, 0.06460029526703781, 0.040638892115243984, 0.048711551278228724, 0.039090785468297626, 0.01656411561153589, 0.02399574495821951, 0.031653324277290416, 0.03290746000505263, 0.041293226963570046, 0.05061381271169071, 0.0399756400034793, 0.019767948937031533, 0.021088077393811078, 0.0353368473870139, 0.023863769076283903, 0.047329972993822834, 0.05953659581380987, 0.05097895319904051, 0.03254585501347338, 0.053044808878292965, 0.06502583412633789, 0.0600092682326513, 0.05933741295349695, 0.022060999481548226, 0.05449708175635146, 0.04877192283710165, 0.006781806277426621, 0.06130733527243138, 0.03929959422337913, 0.03379548614424083, 0.0422131913083215, 0.0796482615893887, 0.046553849317734285, 0.03946758198341535, 0.011573501903894208, 0.02798544851342036, 0.05270216456283966, 0.0528234439421325, 0.0159125856026226, 0.060700662584314426, 0.07728260506184832, 0.044957475301118634, 0.06779004023560593, 0.05504673835070384, 0.024878163333801974, 0.019351313934631405, 0.0628971898808114, 0.13253500354626488, 0.054556376961690765, 0.04111631427921596, 0.04645460262714375, 0.059562573855322216, 0.07566255126749316, 0.04354922183518929, 0.3266339664978366, 0.09611657024511407, 0.10511724533693445, 0.07422402200679626, 0.226181116435797, 0.15265803423620042, 0.5394140294482631, 1.2450237860602718, 2.0430369843398375, 0.7663404881473511, 0.20735105830094508, 1.5896442099925012, 3.530099814937961, 6.916133424928112, 2.39154631572385, 1.0276937737099587, 0.8695586398243905, 0.5323969092099897, 0.1333310455083847, 0.11042374486644423, 0.15511564429729216, 0.2800211935274063, 0.24915155804445668, 0.1873085894171269, 0.025357278552086606, 0.02489325143547068, 0.12064623826694106, 0.09393955520804852, 0.04821745904102441, 0.04519060734779604, 0.07463499753465576, 0.08260705403142399, 0.03310575803381301, 0.08555484545086661, 0.021987596767083294, 0.024706936937065858, 0.024891024034830834, 0.012757629644305957, 0.08035470956876394, 0.030587088849936283, 0.09623395789775158, 0.0018923399963363585, 0.06082827751074107, 0.04851994119704731, 0.011260738847927462, 0.06335030024450633, 0.036897364658333605, 0.018490817165002227, 0.05572104511121589, 0.05912370506613966, 0.008785300005617882, 0.03437312026958793, 0.028555211085345478, 0.03133381390193057, 0.01513526970220189, 0.0410170637581858, 0.04971126154545815, 0.02412742781152408, 0.010624873421845898, 0.06631210341208404, 0.030276740886150833, 0.07574692819147341, 0.018113269883718704, 0.03671379850035714, 0.04291829097295, 0.025917009202643268, 0.030825727153569463, 0.0979794662505869, 0.055173035605900714, 0.013691952391978235, 0.014169135153473867, 0.00948252332877488, 0.046270837286306966, 0.020706178733117638, 0.0223986986994503, 0.011101158902860217, 0.03084079035738063, 0.007476853432073709, 0.03788744903079445, 0.03302860914939835, 0.05100782322246702, 0.041609245893214984, 0.03888732400692759, 0.023314849841558648, 0.029114319289463664, 0.06227689231896113, 0.014115767553448679, 0.049493493392102184, 0.025432284305533095, 0.06731107440446654, 0.04225794233441834, 0.12115764026079448, 0.03898671242378412, 0.07104499460828882, 0.042086465043887016, 0.029307955673204798, 0.031139537834772663, 0.044354544952511794, 0.013643585430878787, 0.04184040909392699, 0.03466894895198845, 0.056823533734366785, 0.0105903678641264, 0.028862320412431034, 0.052238256189852, 0.04787198020025127, 0.024110713688236092, 0.02478864212941018, 0.06564498638674136, 0.055933803049547065, 0.06333123614651061, 0.012761215893401495, 0.030600529862567786, 0.03485357614174005, 0.04481906619583888, 0.07674183891785723, 0.04716080928882284, 0.027824060600851814, 0.06965724931609246, 0.05107796240237452, 0.04102531835556992, 0.02651912366761075, 0.09493628922369211, 0.05469040021360402, 0.0807980523114243, 0.09186126592178499, 0.0035565153079768347, 0.02902406264066456, 0.04451091115873668, 0.036841160617768764, 0.006037466631706564, 0.04350775349584799, 0.013349596317106438, 0.06059884949917756, 0.03251189050535041, 0.07908671914089112, 0.010990431427114434, 0.054906283790666255, 0.09661909327992509, 0.011721854830431122, 0.02718733619868515, 0.014776596912152827, 0.056310909830274126, 0.03433932430080829, 0.04624556404568496, 0.02502326996275975, 0.04815431041342597, 0.058386510147923426, 0.03906544327976243, 0.051983643037777756, 0.032028500516448295, 0.07809017664722859, 0.006015130859469214, 0.03997958918672897, 0.060331254987226385, 0.03678714758866737, 0.0943901681251103, 0.014956598846061576, 0.05450214176709133, 0.010926996474154295, 0.04039188238581823, 0.04395766161201943, 0.052818433727107705, 0.07838880538099235, 0.07617147879735117, 0.034177871270766186, 0.017338408337485407, 0.032980943158749616, 0.1046437646953329, 0.1819723426935173, 0.11264540750773684, 0.04294186349838011, 0.04990008306659518, 0.02642070626719825, 0.087493798665462, 0.18520354834054747, 0.2625882192965477, 0.12507107018703414, 0.03058896385013096, 0.05345085463035972, 0.5924084986890517, 1.0318924871183213, 1.7865574888644682, 4.422787629788922, 4.9133290494641955, 2.825408505816614, 1.710653252178623, 3.6948891272467956, 8.341419293034463, 14.220223580637287, 5.8440373789879585, 3.3790253150847653, 2.802372916090873, 1.045028014529136, 0.12429625652129613, 0.0656180737179614, 0.056366638896325906, 0.06193789458202739, 0.172629272264819, 0.30154280965366675, 0.013123028686330205, 0.0994253499553569, 0.10025494656856022, 0.11655925878233488, 0.05814954766162461, 0.019689313842043765, 0.01721586108267788, 0.06859794123879365, 0.024062157120375384, 0.03905457632255651, 0.021967301182749293, 0.05378318357191259, 0.04887156406297319, 0.05438708302174365, 0.056650497454909556, 0.02714613790533716, 0.037461258996758735, 0.055250655634388815, 0.024685488390405814, 0.033674857939683625, 0.014509074220944558, 0.0914992051078908, 0.03570856090875403, 0.028085513002870065, 0.037580649969318224, 0.12977383880605622, 0.06957060477185635, 0.031209659777701865, 0.021257986119317434, 0.05200453808591251, 0.009401030725829545, 0.0360275560899848, 0.026654803584660255, 0.024602262513531793, 0.03877207373959884, 0.06079286892688083, 0.04017772250658563, 0.07750972714875975, 0.06177233532071114, 0.009442981700563144, 0.03187132608746329, 0.016213182224741867, 0.07707694875857524, 0.09707573530895096, 0.07079265290691007, 0.07656415248469961, 0.06722881188315731, 0.026442470825127056, 0.09743478539730273, 0.03473418516918056, 0.03148015967810587, 0.04169113303144132, 0.015623712040964636, 0.051549910868127505, 0.02264662007350595, 0.05611633498882575, 0.04591448765788828, 0.023116842926209493, 0.030746739658136523, 0.01699005092133678, 0.061999262055201884, 0.05714409939584233, 0.039597736491310986, 0.07757518170101028, 0.07890796784551875, 0.04488367039049345, 0.018882364703101978, 0.043085849723748626, 0.03290220847233169, 0.06450487135518944, 0.08360397956904866, 0.023868032355582523, 0.02853189519937, 0.018631214268445488, 0.03375706683483816, 0.05581648817526237, 0.09646615148672173, 0.13046981436350655, 0.14262785954821494, 0.21234855626619634, 0.15733470990052148, 0.1376453922280381, 0.07479160122813718, 0.10502299353961023, 0.20213232946492013, 0.1296960195947078, 0.21613627882494083, 0.1371285586708015, 0.11705270367524317, 0.25815281536309953, 0.09602270915263122, 0.2318357033354621, 0.12931531986161587, 0.1315395642192133, 0.14356031112613218, 0.1066121586688584, 0.17766637697575555, 0.1397736304469647, 0.18711015732297975, 0.15015424439503303, 0.1441645093502537, 0.1728501200916306, 0.0886935229984022, 0.08200673987307856, 0.22958199523629683, 0.10065700483298111, 0.20107393303225118, 0.15072347836629038, 0.15662021033706205, 0.14854461705732733, 0.13625601516856303, 0.12341108022918626, 0.08303145908059613, 0.1258541729241129, 0.21199643161268006, 0.09999393275187862, 0.11409915127460996, 0.14050719027798023, 0.2327670057814929, 0.12247118993752426, 0.1446748311601339, 0.15074122096261672, 0.18473243491063196, 0.13083064177584264, 0.11131947785015069, 0.1572068191824421, 0.1425038758785494, 0.07614191546435319, 0.11176776952080189, 0.1760193185820695, 0.1622986991799647, 0.10506426269609122, 0.22436931849487368, 0.11026680409427612, 0.15042668058266565, 0.1732698137000684, 0.12900710736791934, 0.13288268488982033, 0.15199743661909335, 0.1801788236104673, 0.24849947932506763, 0.1254427147608611, 0.14505798237458353, 0.10991458751020894, 0.18086853256869703, 0.34304868730325855, 0.24466543909042116, 0.1099575880253988, 0.13960709825398462, 0.16358414875163188, 0.2562424525498383, 0.4461873496972746, 0.48847169525200324, 0.28998484114004724, 0.14286750717268837, 0.16348377591179264, 0.44877225292786477, 0.85396108968604, 1.785236262986737, 3.8777659593089937, 4.749833383867818, 2.3239876570240146, 1.314312822876438, 3.7001656957211035, 8.721444991327102, 14.523189413932062, 6.234610820970228, 3.015887136420896, 2.5676068038709703, 1.1481593837661128, 0.2013143314228904, 0.3409274204844429, 0.20094691565440548, 0.2889436663639161, 0.4359000759019006, 0.4397925992886867, 0.2005707511618253, 0.20636312663555148, 0.39878691576661607, 0.25713621668757936, 0.14016016777003967, 0.09362843158023973, 0.17825258745541497, 0.26952168273348964, 0.11222788192812475, 0.16658891413000324, 0.10019683879950356, 0.128605570043287, 0.0948971268090029, 0.1193946727641648, 0.1451702448990076, 0.08222734255175437, 0.1525017522996472, 0.09267095957071551, 0.13210317510510647, 0.1311971688823354, 0.10013464012093122, 0.15669367816900054, 0.2413105715306536, 0.12586613155661092, 0.19411609267755864, 0.20048070518720537, 0.2014123906771983, 0.18701257304318492, 0.0989185904543246, 0.09239470826521998, 0.07244800803281608, 0.10397573602536034, 0.2288955957779, 0.12393482389949984, 0.09444961654803447, 0.18679511132499865, 0.10241844781464148, 0.14788794181039258, 0.15332070029070302, 0.17960402784087967, 0.10669414539851489, 0.19235272681520832, 0.09572901402509983, 0.17464687206572102, 0.27542209192629785, 0.10882810629423588, 0.20485696713289908, 0.08278495496920041, 0.15965424027414093, 0.09041552011284137, 0.08479132392113248, 0.1486177784540961, 0.1375457395108477, 0.0962521295033155, 0.1352825932084553, 0.10410273808144754, 0.14003282863526575, 0.3495412518180186, 0.16998084502354746, 0.15144801368155789, 0.15431114472448826, 0.1259333864154835, 0.13450931937944505, 0.1618879228349655, 0.2360230939643037, 0.2286493291537608, 0.10968537400326422, 0.14936244656001368, 0.13944576013713114, 0.18120398714898095, 0.20805028207119436, 0.14354957057343376, 0.22944105037998772, 0.126870863530184, 0.13359655626118183, 0.17704711746304266], [0.04853522465113671, 0.015334471714712921, 0.05151215039433972, 0.03815499757747016, 0.05629556891959041, 0.06152399259829714, 0.1053901335164424, 0.0669110079686488, 0.03879903237365427, 0.020289953587757006, 0.07469291378173136, 0.015673784505305512, 0.033035986576109164, 0.03691229188153821, 0.07914676511239621, 0.040821301480454784, 0.05134851018327379, 0.08751562451042476, 0.04271856802065046, 0.03335859769234254, 0.02243210013294893, 0.012350802482556433, 0.06150022472044634, 0.010344466089361138, 0.023792536305864493, 0.07020034436737338, 0.06041763523112863, 0.06441795101930058, 0.08227478637690507, 0.06013083872535537, 0.017962220327688322, 0.03331989109996827, 0.0676636970151336, 0.014568755343075723, 0.04703155493423824, 0.038359094891817345, 0.006530524650213099, 0.030063597988637707, 0.05292805707863262, 0.028275018257479516, 0.08446423502098169, 0.034010607463818406, 0.031011963127962047, 0.0436871214919994, 0.036424650104656335, 0.043583994566072384, 0.09079442720019049, 0.01795030574524595, 0.08621005746986597, 0.05462128759151506, 0.06311737121112886, 0.006896839167306861, 0.042173557749558846, 0.0049331848840079, 0.03822825090478986, 0.035629910492007776, 0.09008409515503915, 0.021771605937711654, 0.07329935388218972, 0.02793428916183691, 0.024530533701181415, 0.022623277374453122, 0.019581272462082487, 0.025932124117389325, 0.04964052864740934, 0.07888457918119046, 0.09656945078243172, 0.008584156917828706, 0.3124632091531831, 0.24477469855018202, 0.06443262160305055, 0.19296939695073714, 0.15566822351707568, 1.9783504811986803, 3.350765863733907, 5.559321843808697, 16.252165282926253, 45.28473246482111, 39.70713384689824, 53.88306210117956, 64.69422824921148, 65.78754186630249, 77.67973284567557, 88.9248151163901, 95.84799458903652, 92.13416114930185, 86.25386145807083, 88.65115919420796, 107.80261793444234, 113.75939599929319, 106.30390382582142, 94.3328457493936, 78.03224409780195, 65.70563885473436, 54.31572306540705, 43.26500600384128, 46.68895275362077, 27.395782701430786, 16.252678132826283, 3.4540330450381007, 0.3425058374001134, 0.11003834901437645, 0.2463460368134322, 0.1884554843268087, 0.10458491382098968, 0.08531725860290951, 0.12088037771923889, 0.07541498995476192, 0.0768547832605339, 0.08691639053605257, 0.01967551276808785, 0.013022787039048009, 0.05085537555597482, 0.09145439662519964, 0.027412127463086963, 0.0017143219907490178, 0.10540375455973611, 0.09778844988754681, 0.05188443465158344, 0.0076929261370922535, 0.01963414018973708, 0.0896773714151594, 0.05853428467807751, 0.015604432480740211, 0.07678335322247398, 0.021604411078677065, 0.031720615525339405, 0.053203611244117065, 0.02734454510162675, 0.01370323399427317, 0.015712047724293608, 0.053161614304108006, 0.042964899762263226, 0.02087489810712155, 0.005544488094822174, 0.009606811518390334, 0.06894197600382952, 0.02377070854568193, 0.07520250780808349, 0.06086388527746163, 0.012292588418800265, 0.019727932334306742, 0.07753072561876428, 0.03069155068407136, 0.013769316738621603, 0.017868736533508185, 0.017353178512665535, 0.01768754524809699, 0.020932442801553878, 0.03488466398970735, 0.008671887391697495, 0.013512435966291496, 0.03228617802021965, 0.09281794119986797, 0.014796906860635407, 0.04273972736911909, 0.09963622331739434, 0.06588821930270042, 0.005539584174496873, 0.06943490761782854, 0.09057061461311194, 0.021005121562930367, 0.03714207995442614, 0.03146067231653198, 0.009444204568412275, 0.03906278112422555, 0.027922169650874795, 0.08590020554801149, 0.03660724716140859, 0.048829498175050945, 0.02948979047247239, 0.05179314378408655, 0.0656724276561891, 0.011876126743793007, 0.02451501084461568, 0.006015106919221581, 0.014287982203607118, 0.05437747627917317, 0.01715491495786175, 0.027319520839580128, 0.02710213764540611, 0.08394882638728426, 0.060174915594078844, 0.055121362975408, 0.0985554341346987, 0.04926497702516856, 0.014016245071205401, 0.01492772020414592, 0.025061191315011635, 0.05031006651059274, 0.03727187440099736, 0.04112049711928253, 0.07342880741963465, 0.04933776686929407, 0.050535641099897124, 0.023382066396035017, 0.05106295857037749, 0.009520620881249348, 0.02006839521439566, 0.015849470491370848, 0.008700261373193035, 0.049323728308081634, 0.04475255827269247, 0.06415968745826714, 0.03856562453532412, 0.022591722212852012, 0.04207270610476694, 0.04893386999385492, 0.03864595268462454, 0.009619345674441468, 0.06590213145940535, 0.03124258623668744, 0.020833605968002832, 0.1089845491092532, 0.06196439739376788, 0.018801278126756513, 0.03917658348537741, 0.02072813481302752, 0.03443105949930126, 0.0269419735582966, 0.05094724865029416, 0.05926853398822489, 0.10031627956777812, 0.0072696999057136, 0.05163772369644815, 0.0713003317134515, 0.01584611694148231, 0.1131519831476673, 0.08553557833957096, 0.0671888450761476, 0.017278555803181186, 0.012431635292276982, 0.08361658171540307, 0.011131613770680083, 0.06390263431615407, 0.016557912214569027, 0.05141865702406053, 0.07262160355645804, 0.040314296831286726, 0.021338293201199943, 0.010948557061173264, 0.02640383126544616, 0.03922981510479604, 0.043243522109884414, 0.32235318975102517, 0.13585751155211082, 0.02935289056040347, 0.596448723827639, 0.6510952463553799, 5.3411542215654935, 6.831311189359234, 12.609393423603429, 29.837901361526985, 67.08785072449716, 60.2822756767273, 80.06037619806106, 90.64917533628403, 95.35013598780479, 108.18180914848082, 117.12057698157527, 124.30154246668663, 119.20941168262114, 113.58801980172436, 116.83171010786488, 135.15841207196635, 143.30125254969445, 135.07040977478027, 120.73659435395273, 106.09471597979146, 96.6268047209709, 82.8972068909676, 72.99835266605501, 73.1580166662893, 51.23175951742357, 31.75373600375268, 9.778985611854061, 1.3786219204625776, 0.13385622942399594, 0.04356567357336322, 0.28622460581602593, 0.17641621341388072, 0.11945004559933178, 0.06377767005394544, 0.12819904548626754, 0.032055922633697914, 0.03425888123831922, 0.034461438715938604, 0.0037671042598723887, 0.04198921018189961, 0.04060702668803354, 0.05551594039124828, 0.030635706704830935, 0.04662230310420837, 0.01803372122888123, 0.04902624870620428, 0.05640629543772629, 0.03264961396193793, 0.0401236328686918, 0.061750030670795715, 0.030860612882421385, 0.043226591566757816, 0.032941481969769926, 0.056254200171679265, 0.10073255642407364, 0.016198209036261808, 0.06657125563510964, 0.047938583884388215, 0.04652433195001176, 0.05558306501517373, 0.040065302934137084, 0.03839691665263907, 0.023332950583989584, 0.05202657077461482, 0.016140679663587964, 0.04471170663413021, 0.03748129602641829, 0.023184396559372548, 0.03426272316925949, 0.05211228835246256, 0.07699372862736065, 0.06245454044772252, 0.0494279928745762, 0.05965418264930768, 0.03919601913601641, 0.010034768342701419, 0.03791183743986391, 0.030028112795985037, 0.02659564627514732, 0.03295657007143863, 0.0410026574747697, 0.01306998763128274, 0.0460124243381283, 0.10393740864650858, 0.025382247272758715, 0.021271681856183756, 0.05522847355854127, 0.05750083206822315, 0.012099503618364614, 0.028695349634114294, 0.052954096407178915, 0.024309519250246308, 0.055423259074168826, 0.05555180479742347, 0.04685021809212143, 0.0773306540964592, 0.07892819256671975, 0.05866454260784292, 0.02940869240480806, 0.0239726550681817, 0.06610779542355769, 0.04430001864450113, 0.033729763461216804, 0.19582454535749652, 0.15716780998533772, 0.1949600304567045, 0.11665314285745544, 0.10962376521239359, 0.12432887654511199, 0.25935143652942877, 0.11184466942664116, 0.16851833721082057, 0.09054506558083719, 0.16163669196107697, 0.08758211328137307, 0.2179011768631397, 0.10825554750138715, 0.14076992779249145, 0.0978243334459201, 0.1891867305722929, 0.3037893778133777, 0.14875904506733342, 0.19903762536423825, 0.18018440073055608, 0.09593411108418819, 0.1524474519875742, 0.12529462230421845, 0.1057833358044586, 0.18266343061001072, 0.1569461807488434, 0.1709777092741382, 0.21945932309233376, 0.21857862841458092, 0.11866685859258137, 0.12006268611237889, 0.14214275735280207, 0.05846512226027347, 0.2128842355863702, 0.09541042870090854, 0.11221459030263847, 0.19001097989178475, 0.10805889273122435, 0.06410763944469153, 0.14131366635762876, 0.08659877814352514, 0.14844133308337581, 0.14616717043663227, 0.14271738458304636, 0.16022903604372857, 0.23134130083264845, 0.10522128773793098, 0.31099446538475256, 0.20528471998630032, 0.11923443781392229, 0.16220103829137741, 0.2336240896294194, 0.2663638989531225, 0.13301160216571825, 0.16548135017435397, 0.21769261708663357, 0.19543526543965264, 0.21247073196836058, 0.14638325319655482, 0.09998892253685383, 0.15642528692560811, 0.1770964841688833, 0.15869742710023158, 0.09635812542851895, 0.22441598857122086, 0.3100592558903079, 0.1324274294799374, 0.4320519856147228, 0.30850228943651725, 0.17863402263291422, 0.6691890173862058, 0.57773215395789, 5.5499846416134995, 7.112341657761605, 13.00841712182568, 29.645626775680054, 71.26085250608384, 63.825791958839666, 82.21379664636429, 97.32031114639776, 103.22848320007326, 119.29611959765036, 130.01591021014798, 137.4251654840285, 129.09984850114392, 123.71247306946786, 128.27038488080424, 151.11564943867347, 162.20654333791427, 149.09810773787962, 135.40798464129048, 117.29182766329859, 107.65607818480461, 87.43919387940439, 74.30330168816351, 74.21131426288237, 54.96370254024383, 33.7303360046879, 8.683323475622363, 0.999693627799711, 0.22119653471294912, 0.3295420669019222, 0.5631531330366288, 0.2948551991533849, 0.2513178248679446, 0.24592369254077637, 0.28527772114161526, 0.10040506915820223, 0.1589939184486866, 0.1692219889692722, 0.08617587462668458, 0.15114900956471122, 0.19817648125031304, 0.19274335504779894, 0.19668861592729248, 0.2382620931753228, 0.21581067613536314, 0.15151259489357471, 0.13627792528319743, 0.07030634795345607, 0.16962859779596332, 0.1300168265738795, 0.10461872128108818, 0.18203873187303546, 0.11016496802650153, 0.10465308032449215, 0.18606178132036041, 0.1401362658268021, 0.13876132186382048, 0.1463982838416292, 0.14176173586278193, 0.14798632282162869, 0.13196080532525817, 0.11741792077138541, 0.09512807167465649, 0.24326893741325026, 0.11990319426742294, 0.12722558522176358, 0.26994376653625124, 0.06791285179074734, 0.1021925361466504, 0.12222607244527149, 0.15507574643819563, 0.09382716244867734, 0.20881088480593699, 0.08721072917744037, 0.1291203504848865, 0.10781520782338996, 0.10385984990505442, 0.14012986133175512, 0.13033309831253945, 0.22249842453147137, 0.16477195275647027, 0.11947298993266399, 0.1418260872484215, 0.1779709428909325, 0.1210965064444369, 0.13504240932243486, 0.13056359884719695, 0.14411258391074597, 0.2604494550295415, 0.17792062623606575, 0.14200967255859606, 0.12739377982553937, 0.20608675275598803, 0.15394984233763911, 0.15778886214379342, 0.19793304915149368, 0.13356232745272498, 0.16048662544738862, 0.112038612245552, 0.2065834841660915, 0.1611615795521967, 0.14346193011489608, 0.1370351112657978], [0.004567445411662301, 0.043272124002537424, 0.09882512006668315, 0.10413406341667138, 0.1148075144737959, 0.06801396007499388, 0.12763499026937833, 0.05836657654013365, 0.02034451820016388, 0.13468394146090554, 0.07437984429059491, 0.0490620824688625, 0.061618535509032596, 0.064895024613267, 0.020795652057014165, 0.014989656497604184, 0.044474108294854243, 0.019426643360225905, 0.030523323521558798, 0.03614782806365721, 0.04832885205565442, 0.05398556867974901, 0.04896596907788227, 0.06343637405323886, 0.05678837029864231, 0.04352127494771154, 0.09268713934767632, 0.0784766526832696, 0.047471580516186454, 0.025956194599970214, 0.026606949902470076, 0.04108476677849408, 0.054219800062597766, 0.013057892060568257, 0.014144138662114501, 0.055130778195997404, 0.0283033998998543, 0.015860720492538907, 0.05648106561913606, 0.026458122001420108, 0.022608608705922965, 0.052298305991796724, 0.013414846898447122, 0.03809379481319939, 0.08084391799545096, 0.14249593920765385, 0.0789232589604874, 0.027777053445817965, 0.08182474036490725, 0.0682779846172179, 0.027779573875088847, 0.04315715335730103, 0.03199774017106862, 0.018935286056911273, 0.060782197322095596, 0.04626776910417023, 0.00504211301074153, 0.07251831192162729, 0.025842980211300236, 0.04170133349215312, 0.041908594749627576, 0.06136763788339111, 0.001159671939545191, 0.041271355153331836, 0.04982772989258651, 0.022896945048424027, 0.184805320515748, 1.614475632386823, 9.614338240315838, 22.837213893090528, 36.09379545334847, 63.146966964967795, 66.46747296856296, 87.39767951350059, 89.53455540441698, 100.74624261548443, 119.09952255987353, 121.2807212337371, 122.38286018371583, 119.87773649154173, 116.54209013908141, 119.88593424520185, 114.70238870190038, 106.28220527402817, 103.76587144790157, 116.10301217725201, 118.5684963964647, 121.01442367799821, 107.75332158611668, 109.33049094292426, 120.71716293211907, 124.4293019079393, 120.0569966531569, 129.69591540675012, 127.16931281551238, 129.89662308846752, 128.72449336513398, 124.16884868375718, 116.81751897258144, 93.1774410124748, 69.33263101885396, 46.09969508263373, 30.57358111104658, 10.94463950203311, 3.6307260153755068, 1.2011314832395124, 0.19786514311788544, 0.17990597373535558, 0.04929260981659736, 0.12670764849791605, 0.022038208365800883, 0.03156609176057241, 0.022941242167425734, 0.042181456116058176, 0.06023784588661887, 0.026534738454727397, 0.009399543557646535, 0.014804077443606673, 0.0017518066728840613, 0.04444080262234615, 0.08272583596408367, 0.05643248032297819, 0.10551977091498914, 0.015473127883348255, 0.007316764517341771, 0.012822584324185888, 0.06872214707395724, 0.030468960007232045, 0.0059516963853140275, 0.04338549735445169, 0.059007079670986826, 0.05368759112072088, 0.09569633271425002, 0.03787070234876968, 0.04284716353962018, 0.023432974853823264, 0.04273363697012106, 0.057931396464306506, 0.04598474941186367, 0.050532438852373636, 0.05621951937134709, 0.022677064407616857, 0.06109885210471769, 0.07617435928794646, 0.03331565846418662, 0.020624906380450534, 0.07061670549334058, 0.047814232492519, 0.03930895581781384, 0.014913325412048688, 0.004304323895579024, 0.07889110625030533, 0.017713446680816914, 0.04670546960926825, 0.007737308004570584, 0.028396083132153558, 0.0213559496126348, 0.038245085686925924, 0.02663739232136117, 0.07891731411819497, 0.051874218869113156, 0.06357101400593115, 0.014044015758460569, 0.049596356017695326, 0.11302134217393976, 0.07492802616569304, 0.029081128530144214, 0.05203795867160924, 0.08584146192597766, 0.05512716609143442, 0.07351881508985836, 0.03977665249558707, 0.10640195946419433, 0.027557017672206127, 0.024034263859052333, 0.026866433458522927, 0.032371075883988416, 0.04311419114650738, 0.038686088030977596, 0.024515359414621227, 0.05491631954247433, 0.028012006866535353, 0.07074635055276655, 0.03883716823052495, 0.034258115150394945, 0.046851980094347274, 0.04151696294185616, 0.031280302660419576, 0.06942907002784553, 0.0632160816401724, 0.017595321668552297, 0.026186896232707847, 0.04908487358460984, 0.03637562047750239, 0.050712687849637963, 0.07834000558021569, 0.03995364561917321, 0.10212525830514009, 0.05457803426731018, 0.009059208997284934, 0.03473743338197951, 0.02656023003040783, 0.11677108209339843, 0.0453737061921387, 0.033502243008584745, 0.014765423519777195, 0.005772039669776155, 0.05842138247023668, 0.03079220314600295, 0.046650836048948194, 0.0659585538350286, 0.044044999465827024, 0.06572274431105583, 0.06800760154522235, 0.08168798600954395, 0.021972792117946574, 0.07893467367055916, 0.019145671037896987, 0.010014620230292842, 0.01399596002058036, 0.046468932301767414, 0.08301213068226654, 0.045793729218383955, 0.023351882531818365, 0.06271208388610713, 0.013712820627035634, 0.051135319405265396, 0.036187779548908436, 0.004098574704145112, 0.05576920139813616, 0.07462733665541296, 0.030494690985388817, 0.045615146462354934, 0.03620751780427752, 0.06314360589209585, 0.05369542436974664, 0.060485173542533195, 0.0986460853187788, 0.03896783984776947, 0.06910277785913599, 0.08813909750672118, 0.04280246613967804, 0.17008955290000285, 3.6097231939915693, 17.66823603260902, 37.41771697998047, 56.98338193278159, 89.32096665905368, 94.3788080830728, 113.61018119319793, 115.74633536800262, 130.51781669739756, 143.08538098489086, 138.33672431207472, 144.5353557217506, 134.83359275325654, 136.09058687763832, 140.81144179067306, 134.18407963168238, 120.1940913354197, 123.16408649567636, 134.5231136198967, 135.34185348018525, 140.01014863291095, 121.89196771191014, 124.94063777308311, 133.70100052125994, 141.31377189390122, 134.4905265685051, 143.0520251489455, 142.54089324705063, 145.83893191429877, 149.00086433656756, 145.17128175304782, 141.560332082933, 121.698618396636, 97.17141797465663, 70.00609413270028, 48.761764572512725, 22.017540508700957, 10.11774895652648, 2.950928273700899, 0.10171385376804298, 0.2319500496190402, 0.06267719241159578, 0.06600893943780853, 0.01091884721385976, 0.04838161253099961, 0.03731698931885823, 0.054535068226076906, 0.010235547538726561, 0.06188173650673801, 0.021639105285547917, 0.06298763039071234, 0.03778706086919673, 0.0736135878269711, 0.053547381708819064, 0.03217869971488272, 0.10436021257191898, 0.06848935593640612, 0.025146401359609542, 0.07605175457654462, 0.024108151124129375, 0.04201273291161464, 0.05666019995847056, 0.05617029439177244, 0.027625525084834908, 0.04703122934687042, 0.04543259920131776, 0.024485192787382874, 0.022939717652456417, 0.07976119827118613, 0.02389380546857513, 0.018435032557575934, 0.027581331387702978, 0.04215098879930954, 0.053587126350330735, 0.03210808747568198, 0.09890915991197671, 0.0931920525768111, 0.02111419524636961, 0.03624053236337439, 0.03801218346662579, 0.010930984919410079, 0.06698361012123286, 0.004320952791585437, 0.05230668699368835, 0.03010938323343233, 0.03899116339462419, 0.06760280834691179, 0.10323473748060004, 0.02942140371869168, 0.03701053882738756, 0.021719946713757612, 0.032647177802338716, 0.049348698943973555, 0.03755726896586918, 0.02257500617434421, 0.01510546696672757, 0.14437484645074414, 0.055372996045456785, 0.051634421857494506, 0.019005779552483754, 0.08076858856985647, 0.04428314938840847, 0.03611734542515009, 0.024819444609625686, 0.020090353209525347, 0.03462024874264195, 0.024128810600227407, 0.011756278991308666, 0.04123478977670593, 0.11030020552777475, 0.11589785677290733, 0.14841052102706126, 0.3050388059308452, 0.1454922316535827, 0.21445558917137886, 0.17523778632523554, 0.19342976982795423, 0.14965892258671024, 0.21646611031986054, 0.1465101633220911, 0.10005644552649991, 0.0974215014326957, 0.11902567885455587, 0.14230720578662812, 0.09672758665176169, 0.12734382323199703, 0.10321713278010007, 0.18981961112829948, 0.2426711896494512, 0.1411338042347662, 0.1306932515675022, 0.167425497465076, 0.11505503748213092, 0.13931144960224628, 0.1571974269444904, 0.12586152736818598, 0.2059543574409139, 0.18198970224588149, 0.10922015945036566, 0.11340834681064853, 0.11304032583270343, 0.09487921567333323, 0.20026183386723842, 0.13033939555527704, 0.19169133246666004, 0.11495992766633151, 0.13282476864274473, 0.18930101556883705, 0.1785046916695372, 0.12064954776677395, 0.144028436813143, 0.07657983430450963, 0.0823567807674408, 0.14980097060963032, 0.28858127613221446, 0.14003419227177097, 0.1309355651779521, 0.17897808804146706, 0.19659234931872738, 0.13453020293626095, 0.114777070139685, 0.1883229357941497, 0.18529187827821703, 0.29378341150379955, 0.1560182797331964, 0.13581762901477276, 0.18609984056843867, 0.15417399966428358, 0.13500876274080048, 0.1886573638166151, 0.17572681089082073, 0.15815782540988538, 0.3332806372594449, 0.2645817639366273, 0.2096395467918727, 0.32308137164481227, 3.359763045464793, 18.42124677473499, 39.598139024549916, 60.74147931991085, 96.63226466025077, 98.5295464915614, 128.36732233724288, 127.79903365719704, 145.5593453684161, 157.99569068416474, 155.4827065621653, 159.97035303423482, 151.90090794717113, 149.74587932709727, 151.45091795152234, 146.46381255119078, 139.5806961674844, 132.9138122066375, 147.98123636553365, 149.82647618939802, 151.67111981299618, 136.15571391197943, 138.09775783169655, 147.62819167106383, 157.35482246645037, 151.7203220244377, 163.40874979572914, 162.7780640509821, 168.14019510822914, 170.6276681346278, 164.6804920319588, 161.46785120810233, 139.1801594149682, 104.66421973320746, 75.97725945134317, 48.916368715224735, 21.97271566237173, 9.83946071517083, 2.4391173114699702, 0.23755237400051088, 0.30698923514254634, 0.24993659898398385, 0.2204940474081424, 0.18761036677225945, 0.16076546613006823, 0.12053440475175459, 0.34841485742119055, 0.11276123234100881, 0.16491000180042562, 0.1410995294610339, 0.1698059624721927, 0.0897436993076436, 0.15984131894525022, 0.25781696241709495, 0.19448933071426808, 0.24850433632250757, 0.14484116417025367, 0.1272884427359508, 0.17929940063866878, 0.09457001492621438, 0.12993695424689403, 0.15319766657006356, 0.20365875965404898, 0.21875590116025942, 0.1340088801037881, 0.2608030199283554, 0.12825671658520738, 0.1583170797675848, 0.18933176633811769, 0.19818553640957803, 0.2042428404092789, 0.11262744274591246, 0.20352057271426727, 0.15560949521680034, 0.09709419036704688, 0.2579845211678936, 0.15685184468184749, 0.15683537379147547, 0.13423789442787248, 0.11512088273922283, 0.13303798623383045, 0.1169751066293928, 0.06702002994115315, 0.11260303518464489, 0.17604164238418304, 0.13667155658045124, 0.19741069976120226, 0.18208054495194267, 0.11443299707025291, 0.1839287627127863, 0.10692728127563193, 0.07707699472385068, 0.19621166490739395, 0.27070596273387637, 0.15018531692124185, 0.15766503169171273, 0.2030696227185188, 0.2339032673907857, 0.2634861049873214, 0.1163876474264168, 0.19388654209192724, 0.12414526059142045, 0.1280330572157137, 0.11344727173808122, 0.19868871828000392, 0.1781709990914791, 0.1595708745862207, 0.13731994275604525, 0.14608590382962458], [0.039114664428897446, 0.059156482137980006, 0.019326810612373294, 0.04358337403485372, 0.0755297958910946, 0.01668334187519166, 0.0718764987804236, 0.012385182593378329, 0.022145171477008733, 0.09065453954521688, 0.013623893140785158, 0.047401517945071386, 0.006330906556198194, 0.044133716277898326, 0.011577959578003616, 0.018237039048765457, 0.0384442072602049, 0.07476091940676974, 0.044031615909789844, 0.05064829049872295, 0.014141628766552576, 0.029580198423636538, 0.06015469853375709, 0.011949612770319707, 0.015036616729752672, 0.07685457641679434, 0.00788264015066107, 0.009044146751083676, 0.02500496620702888, 0.03795291890480346, 0.03829003206544346, 0.04535040945836133, 0.054904648192947915, 0.028314755238111944, 0.030562646814712116, 0.07196403964753113, 0.03226050258343739, 0.009597182750792034, 0.05452928043180897, 0.04295590205959255, 0.06283083134481023, 0.03978637798178581, 0.04875619505201617, 0.010293853533033644, 0.024540364524469744, 0.051832612633945487, 0.07806544732903281, 0.057436760304675955, 0.08078072340257707, 0.04965103171285122, 0.015786343888800233, 0.030049331516267794, 0.03721096275013782, 0.0480954863521601, 0.09308204235088441, 0.019725915607846072, 0.06391496067085574, 0.02214586478658021, 0.06824767051805412, 0.00473570465410669, 0.13913074478266702, 0.28487825225437846, 0.13557405902012704, 1.2981706761544751, 13.025323517860906, 30.17003982297836, 39.80596973050026, 74.206434834388, 96.83489430335261, 110.70934526381954, 115.1338964892972, 102.02373504638673, 91.40656148233722, 94.80461274423908, 87.42744245836812, 89.73478455697337, 77.03331839653754, 83.50776303199031, 79.79020334059193, 84.9936588348881, 80.34679551278391, 75.77990931849327, 83.89430476773171, 95.91913853922199, 65.79076997695431, 65.58408852546447, 86.24437716699417, 78.26136542904761, 86.94743064142044, 88.82947014224145, 83.45642705117503, 95.9136236867597, 91.48012945728918, 88.37915851223855, 97.72775127041726, 97.81247446613928, 86.42755969878166, 89.72927754925144, 103.10358708904636, 98.38004927481376, 112.9736589616345, 121.79306907038536, 116.60498926716467, 120.18977672823014, 96.25105734794371, 75.7112599957374, 39.828429222106934, 12.663473102354235, 1.3102080624911094, 0.10719420929108897, 0.23478097432563383, 0.16584092120249427, 0.09533380458672201, 0.009307093024554272, 0.030621174016907334, 0.0773392649247281, 0.11983628414811627, 0.04658518614427698, 0.05088818327133214, 0.04183694254606963, 0.061561189997460575, 0.029785128858601375, 0.040119266167523406, 0.0686620244936597, 0.027178169956671137, 0.014603446677116858, 0.019187120225040183, 0.03559865793513675, 0.014565374980109834, 0.03327403690726046, 0.05135057095979011, 0.01548545998370936, 0.014391135942611485, 0.05533846080183022, 0.058783424131932764, 0.008792938859832865, 0.026487229512103146, 0.05683769870008673, 0.03713806565370291, 0.02467237104992232, 0.06862269353962715, 0.04396344557584774, 0.0360780451146345, 0.057761290471159646, 0.0738353166548956, 0.014325988783140578, 0.043395395210433396, 0.03295856573048138, 0.03883741720910034, 0.05920230185673122, 0.0661828413966202, 0.07092461921274662, 0.05120402983119411, 0.09140018824367754, 0.04184679443677587, 0.018750651206280437, 0.07155854164833023, 0.01002301368111324, 0.0888412477328412, 0.049613420626208674, 0.04121495576034631, 0.06476328813380773, 0.054654911190511725, 0.09969570238383547, 0.05318814009848622, 0.037838170425065105, 0.05271772763902142, 0.027495012430834676, 0.0887086455740275, 0.09529366157948972, 0.08343744737606856, 0.044911762834676815, 0.1278039739437161, 0.019876091823642774, 0.06043565361910771, 0.04382563018870931, 0.09066055333542247, 0.027484088017034437, 0.02860848100916032, 0.018448816394553553, 0.17849951291516905, 0.026391545130360513, 0.01943348452538973, 0.011981197617827885, 0.026907235301370104, 0.0040922956559957275, 0.07451205574456723, 0.03819518271953829, 0.06033060764293037, 0.02621915427997949, 0.023879810957418337, 0.08993005019522483, 0.015903281464782214, 0.04601626243862895, 0.03340407650196745, 0.06890662104612397, 0.08086322341114283, 0.06806419246018895, 0.03872025555240051, 0.01736717302382233, 0.030772304012169762, 0.07361769405824524, 0.03207864097109245, 0.025743337070208885, 0.027914259793056596, 0.03298545924706325, 0.08062542971944617, 0.05814623816179172, 0.01144462389000241, 0.025365121377211426, 0.029505817031848337, 0.058970839881728736, 0.03020208753314951, 0.042528562893670414, 0.03186157761862682, 0.11993906250403774, 0.023369561925890948, 0.055588400817566344, 0.06992228509437654, 0.012301950013234973, 0.051405725459898674, 0.04751687929514916, 0.012167928676541534, 0.07606863915439575, 0.07216444058764367, 0.07867381307146243, 0.027191911658812917, 0.02754522183339202, 0.025357611800333666, 0.053737869471191406, 0.016122776188797528, 0.0496462857981603, 0.03274141810834408, 0.016433660414129976, 0.04238109479868605, 0.07249436401311429, 0.15065825364041716, 0.027344949213006807, 0.4415219661689574, 3.774302659496185, 21.909385073569513, 48.267800884862105, 58.60503096734324, 99.49123321040985, 121.39828251254175, 128.46425194894115, 128.78851429108653, 119.96784117914017, 111.82546354109242, 110.04633134411229, 105.44794067259758, 107.35897433373236, 97.84519487811674, 102.39825863992016, 101.5222913988175, 109.02523640663394, 107.98581615571054, 104.17460595407795, 116.61106109619142, 118.47876041166245, 89.96838523495583, 101.95411297582812, 119.67364772673577, 106.3200875251524, 107.61053162236368, 118.80306197750954, 119.35600634544127, 122.32564849238243, 108.59079468634822, 101.36133301642634, 124.93207916136711, 129.4715322986726, 103.33172782774895, 105.7364780672135, 114.01325179684548, 111.48395845966955, 126.33735456774313, 140.59502109404534, 134.29724785589403, 144.84912964605516, 125.74779879662299, 104.87833407617386, 63.50101578620173, 26.14631756659477, 4.447078377969803, 0.11391886780338903, 0.15812731978874053, 0.09013061201380146, 0.21323510385569067, 0.04156349129193733, 0.13908632700481724, 0.040271196724666704, 0.10722453871201124, 0.02611981757405785, 0.015429970320133914, 0.03414516697727865, 0.036423416703098246, 0.024135243823571552, 0.02121743900070508, 0.007676585002862398, 0.042295051633470485, 0.026737910717906013, 0.018982616884093133, 0.06654738433538906, 0.01654019834653985, 0.07183506108459926, 0.00937476061329606, 0.01600243143677231, 0.008854214402456439, 0.04439332432323887, 0.0627093221391401, 0.009680063888100127, 0.04547419011472695, 0.052681847911087744, 0.07899977582236452, 0.030201986026499542, 0.050799592863768346, 0.044589063618332155, 0.01639260959270741, 0.022156840911315336, 0.04144835976823684, 0.012410440512241857, 0.04697466524498117, 0.04014538976574137, 0.028521937971574166, 0.04734641324067789, 0.015834024243597544, 0.02566511949313985, 0.05619498923601163, 0.11352449340084869, 0.04063899553711376, 0.021115300328200384, 0.04058975140534101, 0.0476507225164002, 0.04046671768470157, 0.04932598826745826, 0.01189568879893951, 0.058704677954195976, 0.01870990682002758, 0.07718702027153584, 0.04720963590267686, 0.06015709255852046, 0.0487049246176837, 0.061175503031981576, 0.05445051510187407, 0.04981208254673308, 0.09407448627415205, 0.06506832902349773, 0.14141069905411813, 0.025272884391128056, 0.07548193071758555, 0.0721832940114602, 0.09873718083385499, 0.174671386879298, 0.10248790134585674, 0.17107354687346568, 0.30190792715837883, 0.17670099893885274, 0.14881000523605656, 0.12492218865982949, 0.14624079148615562, 0.3185935979408603, 0.22741364465365488, 0.13266263379445, 0.11761129668523228, 0.19356676167057407, 0.1414982629038634, 0.1822821792936133, 0.14853684892577512, 0.15403912222433477, 0.16677105919488017, 0.16138648764500696, 0.12569540120180578, 0.18397405383086976, 0.12161390690673744, 0.07522807982299598, 0.16589227973693804, 0.14060033124781426, 0.15275451534938428, 0.11221160255973378, 0.13165792480351465, 0.18731885499531226, 0.20978810656214916, 0.15606462805261537, 0.21771503281929802, 0.1080136399175371, 0.1785736549044809, 0.15673824916443518, 0.11348283353952632, 0.08669407182042638, 0.288529580519084, 0.21601391926167474, 0.24249744090822437, 0.18232445202527509, 0.16689950149626503, 0.07296004587964666, 0.1804321229217514, 0.1576992298566526, 0.20691593568171227, 0.22726163748771916, 0.15449834596966544, 0.13389321614898023, 0.11651055857298837, 0.09718845748612959, 0.1725660240457904, 0.1652091897783741, 0.163682499119351, 0.15303245204831326, 0.10259843251157193, 0.11808264760240433, 0.13008312382284673, 0.24080702193802406, 0.3669383424905039, 0.32793432414051027, 0.3770519901187189, 3.3280945641379205, 21.379306162557295, 51.33783609636369, 65.56872852386968, 109.26155920951598, 132.51523663920742, 144.37684489834695, 148.52109570657055, 131.22413358380717, 121.63694304804649, 122.50097843908496, 114.15523375234297, 112.00494335543726, 100.9696529757592, 108.1780279836347, 107.01779088666363, 111.36333773213049, 107.27710662349578, 101.87600289621662, 112.3682568150182, 127.99041394264468, 92.13441218099287, 96.56405464295419, 118.47733266891973, 105.48441087045978, 116.19833361717963, 120.690961499368, 115.90590523135279, 130.31987036428146, 122.15636684048562, 116.96366648520194, 127.47578328655614, 127.54999453021635, 114.63209982841246, 118.71706793385168, 130.93997355430358, 127.21360421949818, 143.38765451985023, 160.27869839822094, 153.76193138860887, 162.56868793118386, 140.0441477375646, 115.76593937412386, 67.30638165627757, 24.453840332646525, 3.5828919756797055, 0.17340953281569868, 0.40807462868190586, 0.35619754464395587, 0.2296535784919416, 0.1464994227693927, 0.2796139411868588, 0.15004541394450974, 0.2837463726680125, 0.1543020742434648, 0.14507373314230673, 0.0831444034232728, 0.29053005059399917, 0.151256752170382, 0.1054985885838828, 0.22050774506022855, 0.12089275770009526, 0.12626506418230074, 0.11387391376399225, 0.16094686042877937, 0.09908827126867349, 0.13746387535525909, 0.23117662257244512, 0.10292248004266333, 0.10597920150405939, 0.13102780216403548, 0.23274478923168876, 0.11362907972427146, 0.13203353771278936, 0.15187193609533772, 0.210374393650601, 0.17067443038667404, 0.15714642081049182, 0.11627661830355084, 0.22336295475402188, 0.12892260786987123, 0.1197888250012071, 0.17344065130718295, 0.12209536252363075, 0.10330729366790864, 0.1663833574181603, 0.1750246453429422, 0.3044160070919222, 0.13203367560861573, 0.14497130718683043, 0.1739898750618581, 0.14933862122556857, 0.1045229219861569, 0.18865189394883572, 0.16853293884665738, 0.16143108928395858, 0.11508992512620266, 0.08613929392830019, 0.13453794042429618, 0.09912400927034118, 0.28367365560223984, 0.11049925815314056, 0.09951846028167395, 0.18294625494989658, 0.13904448328239305, 0.2346439978047725, 0.19407132249926368, 0.3372967765936929, 0.17404748487376398, 0.23824724639135025, 0.16113829047929856, 0.18616861994228057, 0.1310582158546294], [0.047529236293367805, 0.10907107107942143, 0.06297779382176458, 0.049915918103990056, 0.03644088350777184, 0.05683432025234065, 0.023390257791165384, 0.052488280475259795, 0.061388961940763466, 0.011007790021868724, 0.052363381330524726, 0.048621095446569305, 0.06734831393846581, 0.08149859375290333, 0.054049939217586676, 0.018566027846968463, 0.041998629232928644, 0.03822828920918607, 0.09065617897337483, 0.07340239270800546, 0.04716246786917891, 0.02240967099374581, 0.06360469889196177, 0.05465704474538084, 0.030980237511797782, 0.027683945034720728, 0.06641375561875683, 0.036446249953681426, 0.019138387456956892, 0.047123588907021674, 0.031774076971135316, 0.03925080208348171, 0.07007856703092975, 0.01978457687542804, 0.05190738664579488, 0.05362279157364561, 0.023339607888051582, 0.08244557801874415, 0.021396902757847024, 0.04509141045292059, 0.02845130849539513, 0.011775772098541982, 0.08494325447827579, 0.0608063405830293, 0.04037207518253596, 0.1090013187739157, 0.03732520944228576, 0.10903193930824918, 0.106209862917181, 0.01906310016619823, 0.05802309718884288, 0.00405095515757679, 0.04614884927568417, 0.04647094328256865, 0.07368848058244876, 0.06415470788675932, 0.02722829508955681, 0.08017479381974667, 0.22038043656897163, 0.09078840574910564, 3.546204576569219, 20.897774427167832, 43.89999458866735, 75.32846804588073, 107.912781623102, 108.02202747714136, 101.00664877122449, 88.39684055697533, 81.09875309851863, 75.47897723413284, 73.58575113358037, 102.36098043380245, 68.57267179796773, 85.68867145046111, 93.94173837477162, 63.8393319806745, 67.73761487776234, 73.11095606896185, 72.05004907423451, 68.46123726137223, 38.472610981233665, 42.827512679561494, 50.435275185492735, 52.74156216652163, 51.2081939174283, 32.431117565401145, 44.43083247830791, 60.54619627614176, 67.27064101926743, 58.25773254517586, 53.292270783455145, 66.79709326836371, 91.39324111323204, 73.21730721381404, 72.23925636660668, 68.5005158762778, 77.4414017892653, 76.40786509360038, 108.03543413839033, 107.07203726614676, 71.97141339701992, 91.88364721113636, 83.2181901316489, 94.80110614530503, 105.77613322965561, 112.99950738107006, 114.93010582462435, 101.32497264492898, 78.68215730113369, 40.14890647703602, 20.035370742121053, 10.420221551772087, 2.2171920586016873, 0.1508838971776347, 0.06748750445342834, 0.00901694584172219, 0.06896619970399527, 0.13176673993227944, 0.04839666615871172, 0.033089788931031386, 0.06088834263444428, 0.07278372308299427, 0.03393103008068377, 0.025468995238864617, 0.05568995726324859, 0.02529395180904577, 0.11932856703717863, 0.004490518213940724, 0.0579746344667529, 0.017079763647709644, 0.00843575515318662, 0.038511232292700204, 0.03537559228378438, 0.07022619983481784, 0.11660520873603322, 0.03251734122093166, 0.09486085254578822, 0.02566970835980629, 0.008414195523777557, 0.010134241986839522, 0.02016836011241521, 0.061739217339744495, 0.03676106612528524, 0.02596819536730407, 0.013080838309120268, 0.022969675520735405, 0.019792756779239546, 0.03456941880886594, 0.03274189308285713, 0.028707880917335712, 0.051237691734587, 0.05883029722157986, 0.03878842205590299, 0.01689148413377904, 0.058450378898170695, 0.046135971337677016, 0.030599685250631267, 0.02595033785778909, 0.031217470044089906, 0.046199955001112916, 0.12642846307567052, 0.11017100479934486, 0.06327391361757632, 0.12243826347853869, 0.049683575127874656, 0.03991661292891349, 0.007985970568692973, 0.0054033162849654835, 0.03916312715098743, 0.10297425992546544, 0.04118614319351412, 0.04033114693518128, 0.05867722519342938, 0.030910376038762833, 0.038116091802235574, 0.020350675631855285, 0.0567341580866806, 0.021105630383376154, 0.023070885311631907, 0.09672889666211221, 0.03524898476297817, 0.019296839337555632, 0.049142425939921415, 0.054330541902492126, 0.04587084362884203, 0.012632571536326602, 0.020181360624490247, 0.0320745519767966, 0.12805384884197868, 0.04813768247502947, 0.022713422940503207, 0.03602460282103669, 0.07073110540307338, 0.06033813828722604, 0.038451852817689224, 0.04790492198099533, 0.03346900628398984, 0.017625721952607556, 0.05118941670403846, 0.033721639098779815, 0.00584256476647551, 0.024564653342109055, 0.08296060360847943, 0.035180186236938166, 0.028634690792269768, 0.0808431212640097, 0.034137437150122664, 0.025221460739210732, 0.12087211929141514, 0.01166556939302433, 0.07899344793610996, 0.05104088374683934, 0.05621660823723482, 0.07427671353422827, 0.010227784195223884, 0.06499705986390192, 0.04503697990590046, 0.026781236820463693, 0.05890182302063031, 0.037181138947245576, 0.053967285991436055, 0.0516419563322298, 0.01568811992558861, 0.06180448037001395, 0.020727135068286332, 0.07484874372640926, 0.03912568460368822, 0.02770999010892645, 0.0566977191145622, 0.027939301292081515, 0.028004723285595258, 0.056369837313409776, 0.008228855872256382, 0.059213402470754045, 0.13350278709924993, 0.17178564092084286, 7.943178597957858, 35.22861080784952, 65.0753257351537, 100.0494178648918, 127.53446194433398, 127.90829520071708, 117.20209167849634, 104.12502719509988, 99.16285237958355, 103.19806129701676, 95.75657198506018, 122.37748653657975, 83.60313154036, 118.68033101481777, 119.3711780732678, 102.74927939138105, 102.86354587924097, 108.14367586566557, 113.02459486069219, 96.53388377158873, 80.97952089002057, 69.06257583249, 78.50394048998433, 91.08407205150974, 77.87454128265381, 55.50215767275903, 74.62255124122866, 94.20048929029896, 95.30640156038346, 94.46727321993922, 90.61898877543788, 95.19641830075173, 133.57972083553193, 117.7174440506966, 106.68706447847428, 102.53430997171711, 112.88115378349059, 108.25645185286, 140.5496314264113, 135.0239375329787, 96.00983158234628, 113.41278399190595, 103.65198935231855, 107.92764740605509, 117.4301225908341, 128.58920297315044, 133.4017550560736, 125.02722801700716, 110.47063765987274, 67.7489269933393, 37.715468022131155, 21.719195227469168, 7.3151782058900405, 0.11137626028709835, 0.10791826963184342, 0.05695417087765471, 0.047098484205743, 0.16027130877539036, 0.030370481319785602, 0.04424147420532761, 0.02418792577490451, 0.017268426205602386, 0.043783686874854955, 0.03698027452393886, 0.03219131718299562, 0.04513231188719792, 0.014296382357696853, 0.08751807599178246, 0.054509051880168344, 0.011004111842222272, 0.08574945476627158, 0.03733835934150604, 0.05566723509541443, 0.029222234264917435, 0.05529030068447033, 0.05589157628316072, 0.0478816329080972, 0.03083295519313505, 0.058217951652383616, 0.01719144203009144, 0.05985427332381087, 0.020196891141935222, 0.07476785250248448, 0.026575421553946314, 0.030314725440656467, 0.04647673490727621, 0.021955371278548436, 0.045676360717944564, 0.03458593566451342, 0.03149858792312443, 0.04685828116752448, 0.06655018055631269, 0.05508713799739077, 0.022712610887303468, 0.021124830461978432, 0.02514820741189103, 0.04772790970521108, 0.04517299498641684, 0.02264459951660566, 0.029130027922351035, 0.032028872069091566, 0.028855883358647267, 0.06453923805947266, 0.05426529802442078, 0.07032229790403959, 0.043922636072121324, 0.003423415192012345, 0.055378875770275636, 0.07126765806348094, 0.03428206305890795, 0.017190681687826594, 0.01426291580672466, 0.03387337813394205, 0.03474957204513973, 0.07731273529991027, 0.02018160960306564, 0.14913985205273475, 0.17379032447934153, 0.1776389663498248, 0.19872018917193338, 0.11822357713695496, 0.18214200052522844, 0.19795279889818163, 0.20256942859099758, 0.112810269629042, 0.11303589784450109, 0.15213412202654347, 0.06961290814703511, 0.2337882775933512, 0.15427121622187479, 0.2057899549723633, 0.09070312484137474, 0.15001742109175653, 0.17274441527983836, 0.15530840734079962, 0.17678916033717895, 0.146627405418023, 0.1301060451735412, 0.14843724217386017, 0.15066026079077877, 0.10648823628622679, 0.1026319488582592, 0.12387449447546275, 0.1526455776465516, 0.10609418364061464, 0.2129714317139118, 0.13292532534368579, 0.0930921700332434, 0.1314315305001313, 0.07864298569338937, 0.1583549091892858, 0.21809236176552313, 0.17572468116639123, 0.1412549687008704, 0.11061862997350194, 0.2011981924935695, 0.09773744375354822, 0.13010023822707514, 0.1633437197174757, 0.1726031946318765, 0.15765753935181326, 0.13141567248009867, 0.16485564020131865, 0.21182789226933835, 0.2965218387544155, 0.1477180847958211, 0.16313339793874373, 0.0828170080879523, 0.23526337989155324, 0.13207758776843548, 0.21595041057275188, 0.10462052924858947, 0.32915418126410056, 0.13489766467002132, 0.24084866647758793, 0.20762749346754245, 7.443370578750488, 35.696612327329575, 67.84322077228178, 105.42909760628979, 142.58210951282132, 138.95981634816818, 132.65479456993842, 113.10694894483014, 104.85868300161054, 100.84321929562478, 97.2071429221861, 128.24238700251428, 93.37499510857367, 112.99068989292269, 123.80898690992787, 91.4847578540925, 96.61990134946763, 103.27110367436563, 101.16073516107376, 97.79094849863361, 59.10030864900159, 67.24447881021808, 72.20639474930303, 79.00987132903069, 73.10137764100106, 50.815352855190156, 67.75506942502915, 86.09992411828811, 91.439266204834, 79.67335593315863, 74.84789140762823, 93.20813748144334, 121.15271076079338, 103.62982796084498, 96.9122983563331, 95.03899005151565, 109.89786963309012, 106.89356157856604, 141.32715502092915, 141.69154320993732, 104.41657697000812, 120.81372384102114, 108.8279333422261, 120.03342320842128, 131.8147013264318, 139.87106138660062, 150.81095972368794, 140.94695183538622, 118.81669613622852, 71.56137666394635, 35.70507287979126, 20.828795625317483, 5.861526246993773, 0.16424886792177157, 0.32701701045997683, 0.20627177831146026, 0.1411614906523497, 0.3723830825859501, 0.1676193943187114, 0.12898397151260607, 0.13744915114535441, 0.17285378199190865, 0.14970816671848297, 0.1448094174866715, 0.19037949882688063, 0.2596996388127727, 0.21381060442616864, 0.177940038904067, 0.147430204275635, 0.082461443699656, 0.14431051038686307, 0.14991648134685334, 0.2024926512592262, 0.10007910640730013, 0.1376166332873606, 0.1721387768104192, 0.12101412900993902, 0.12618569747334527, 0.19948289098758853, 0.1383820470542677, 0.09142225157589683, 0.09737411123369971, 0.22110558475457856, 0.1089756012022976, 0.13600887520419014, 0.15615289670325097, 0.1747221785086778, 0.13890202157199383, 0.12250700454798438, 0.1723113457762426, 0.16104878076622564, 0.1098887013992475, 0.14031841089167904, 0.08890563742287698, 0.13040158657297013, 0.16018507791863335, 0.14946395320998085, 0.1714212435387796, 0.09848880746792402, 0.16224196270829247, 0.1764975719514393, 0.2300213313391132, 0.14078964689566245, 0.2015384581060179, 0.16364923558167874, 0.15540740122237515, 0.15966113506545945, 0.1398384874506343, 0.18114951829756462, 0.1450846422343485, 0.08491638777477127, 0.09335138354330294, 0.13422623456966493, 0.08784075988636864, 0.23451884968146203, 0.16021916883126383], [0.06979155219009808, 0.052213806493748585, 0.010492004089868598, 0.007389026239604479, 0.04416221474868156, 0.009839075012883593, 0.048223618387935624, 0.022987839465420094, 0.05893879825429571, 0.0191940131011389, 0.024001490617651614, 0.056234212937734784, 0.044703961485215736, 0.08765021083696235, 0.13703233802751189, 0.045918494297732274, 0.05945648216912824, 0.03473892342299223, 0.04113963399563105, 0.08692851004701468, 0.01577434886712581, 0.048678065575058424, 0.07938884889646884, 0.023247843961261457, 0.10686076186116665, 0.041461586276249546, 0.019929145327619007, 0.01705426249593016, 0.02063395387883629, 0.010501472936612705, 0.08646095892594707, 0.004953293734410357, 0.03779469110492257, 0.03457212309923864, 0.05700480545901003, 0.0361046398569259, 0.05219717089447284, 0.02924781585592897, 0.0315787073134655, 0.0192845206437332, 0.03602413933784251, 0.02472724401271872, 0.0488349488906322, 0.007175874723602207, 0.08933684533281673, 0.03926582506767685, 0.05635258501335498, 0.04874369632753153, 0.07571043942363993, 0.057109499034742196, 0.010897208102828553, 0.020268485888898857, 0.0752306615393008, 0.06137860443202719, 0.04597790441626022, 0.11335911033975501, 0.10616868569125092, 0.13852277740595803, 12.703570512033279, 39.33559125469577, 71.01658298123267, 99.70975629744991, 94.24268614861273, 83.45856082054877, 68.01104330247449, 70.25403499603271, 60.55973629797659, 76.07251813334804, 67.49975450577276, 54.75544821831488, 83.71214989692935, 62.01599074948219, 63.1167725593813, 36.87488055998279, 59.52866677315005, 40.18571399873303, 34.4334130133352, 30.79343584276015, 31.384517415877315, 62.11281837955598, 30.207163095474247, 39.73091125488281, 33.92936883434173, 31.04132179291018, 36.82921240406652, 64.83669265624016, 58.80097689167146, 35.40547440128942, 34.4084628166691, 26.11023568337964, 41.0128830325219, 50.07204801805558, 31.588133535077496, 25.445886196628695, 64.81217392029302, 54.49872124579645, 30.86122028289303, 49.14741200785483, 60.02981232058618, 76.38967314074117, 63.30498356972972, 76.22662805741834, 89.69976563607493, 105.03262442927208, 77.45452603986188, 89.48105427526659, 89.31754635226342, 96.74700183253135, 88.23261091786047, 104.52990208902668, 104.64543158008208, 114.26930412169426, 84.12403798872425, 44.96498084837391, 10.517574779448971, 0.6955679986746081, 0.17576061069003998, 0.2174191849846994, 0.0390610535959563, 0.03834905147913002, 0.0367201991649645, 0.11349027991415032, 0.017016557563516884, 0.04811245519968291, 0.010369865734490656, 0.030991121705981995, 0.08654363513473542, 0.029431131120110234, 0.08505207726791983, 0.05277251824736596, 0.014615768243769004, 0.015857483771058823, 0.0676044937403452, 0.040793327779899684, 0.02662436308098897, 0.020212327813609474, 0.025779823922822555, 0.026996645423012878, 0.0902961865968762, 0.01602438272863266, 0.02317370005672978, 0.038478190920525984, 0.023094396550028075, 0.03250034172989188, 0.0623373443170661, 0.007900674339203585, 0.018255224060868065, 0.005496131667431685, 0.06179230723289713, 0.15200641516956592, 0.01892271263885402, 0.03516406008613206, 0.037512360891747865, 0.02948752668265614, 0.039366492851366924, 0.06406341318882282, 0.04342057269006487, 0.0768622296351579, 0.05272245823195385, 0.0200105230173757, 0.08468884433950148, 0.03145244453222521, 0.05919538791321459, 0.033487832894729036, 0.030931958650809624, 0.04501106315142205, 0.03794117860736386, 0.045334608894923044, 0.0291964745584635, 0.10459702567107255, 0.04591332320424338, 0.07507446387241926, 0.0804965737305822, 0.038449454962486224, 0.055846760139590314, 0.060299822399693156, 0.03329739109763215, 0.0430801538600316, 0.06929788513169174, 0.01021455194155175, 0.05450883737554955, 0.13620309381475373, 0.07953219926886021, 0.0855361758881519, 0.029929396621282064, 0.042796230183974396, 0.02921381112818997, 0.06079893634324113, 0.045611614797024, 0.039104222650489504, 0.140102312809998, 0.03231405979022384, 0.10407715840565582, 0.11203421490086664, 0.07887483454279362, 0.033662619685093244, 0.046456333985852624, 0.03934829443272564, 0.14431800272676254, 0.023615512538761384, 0.05634313148836936, 0.032816398963933034, 0.02804645975571006, 0.04671839351255087, 0.06110795322925814, 0.03863701243854819, 0.05578924608867496, 0.032488118797059984, 0.017782526744169094, 0.04741150390116438, 0.03475739763328626, 0.09121701662098208, 0.0383264786984411, 0.07270699171649833, 0.07125139401684846, 0.02321117133232615, 0.010029494784952653, 0.04627390929888334, 0.04287767682164427, 0.02667309584907226, 0.06953366401214754, 0.02412469670807402, 0.009969875907465335, 0.018386740290049105, 0.02556132607071871, 0.03652536002318225, 0.05537418731217904, 0.04921371042127571, 0.03253114995576682, 0.021059900679956042, 0.03730557843922608, 0.15307244183796068, 0.06918568389430162, 0.4709059120185914, 22.649220574286677, 56.53598070144654, 93.5895566017397, 113.53915491411763, 109.35631582813879, 94.49590652219712, 84.41035532182264, 88.08172518207182, 85.58936488243842, 106.83183916153448, 88.47674708212577, 85.59531119561966, 102.13241607912126, 99.44140341974075, 81.35247553548506, 61.646083785641586, 79.90315191207394, 50.70272984043245, 42.53709254726287, 42.98886329896989, 37.348138055493756, 78.13368443519839, 27.846576782964892, 46.47506983049455, 41.42635183949625, 39.19097346644248, 39.311496134727236, 60.892102256897964, 59.745554231828265, 38.95469380963234, 47.61123141934795, 34.52223900825747, 46.469264722639515, 63.45515151177684, 57.232519119016594, 40.32535037686748, 74.98850837830575, 78.86852479750111, 47.91397563872799, 69.3589344332295, 103.90838684574251, 107.81021948783629, 93.04684961995771, 116.42710193510979, 132.8397107893421, 133.87725614732312, 110.5498146241711, 115.02405443499165, 110.98256972528274, 111.20416010579756, 104.75485786314934, 121.14756461112731, 128.74427780028313, 138.70908275727305, 111.67216162527762, 67.96828946759625, 20.683491422284035, 1.8360085256638068, 0.05384376197452507, 0.28359548399044626, 0.08181598397993273, 0.11012248079022093, 0.06142476505990471, 0.09208474909105609, 0.04347345573947795, 0.09125907484802509, 0.015855716023173545, 0.041413242297787825, 0.08573531278318937, 0.036711484914825815, 0.027012811793435006, 0.025060597596870317, 0.013413927592937986, 0.08561445475225488, 0.003967841560464172, 0.0484012435340593, 0.06888766036999804, 0.05127413836758464, 0.05455197578656578, 0.10230188753696219, 0.02181007695804921, 0.05668421298445714, 0.034208943796975, 0.10135317957329174, 0.026605086393594265, 0.045200604795207905, 0.01642664496396338, 0.06555916155658423, 0.06327132040995263, 0.015254937424024027, 0.03590643375871643, 0.024732125908016198, 0.10788820834169466, 0.0604589541833247, 0.023215787012069937, 0.025350965987590533, 0.042628659941856904, 0.017209646194392157, 0.039322477269677386, 0.0065861866835715075, 0.01838153663782343, 0.059134798019283244, 0.02447344099862441, 0.04248709838476874, 0.03861977162981226, 0.028304290477066275, 0.01706743537778816, 0.09255583187745464, 0.06078512760840597, 0.01592854225647546, 0.041832311544567354, 0.07707167041277693, 0.019496614000790065, 0.03920408221141946, 0.04232763335289013, 0.04543868576987617, 0.031316063644724994, 0.05207415249559188, 0.1637254153648692, 0.08081692871787856, 0.10034195117412076, 0.11398184789164413, 0.1383672615573291, 0.15066891758432313, 0.1286109786240324, 0.13100621380632924, 0.11784477730191524, 0.1598699859553768, 0.15181337633440573, 0.15333453583861553, 0.13015067745600978, 0.15255855005835334, 0.19474710397902997, 0.1701951351377272, 0.13915935050575964, 0.2080913290621773, 0.1162623843899177, 0.1858416229726807, 0.13604089767942507, 0.14694078134432917, 0.22210787290767317, 0.08024251599225306, 0.2630056146412127, 0.25139130802164156, 0.11208592583575558, 0.10567866521136415, 0.19116257858132163, 0.152448739015287, 0.23618411032422898, 0.1643244041911056, 0.0986009474182802, 0.1583675496400364, 0.13091552431785292, 0.3131111356760225, 0.16857724937219776, 0.20339303439663303, 0.13122554477905074, 0.11801228242655916, 0.18762608689646568, 0.19827290107646298, 0.16035104320654947, 0.062303188286962054, 0.12377058230941335, 0.090579355676328, 0.10338219408426555, 0.13109488082268547, 0.16745938919484618, 0.23133984526559231, 0.178617229985614, 0.22316049303739305, 0.11840293364178751, 0.15340124677506187, 0.20837971520039344, 0.2026369056153682, 0.2852563626102863, 0.37218592219775726, 21.6669806357353, 61.126255989074714, 101.53334463796308, 134.7662535021382, 120.02525683372252, 105.90033115879183, 90.40430961116668, 94.74495349391815, 82.2909261334327, 102.98031483927082, 90.21893055208268, 77.32132234881001, 111.68854144311722, 84.99794990785661, 86.06512485011932, 49.13876710399505, 77.26145129049979, 56.11144296584591, 52.74213483256679, 43.94466254018968, 42.02518009370373, 93.1079601472424, 42.23546228101177, 61.279326485049346, 53.54046267847861, 48.23515499791792, 54.602746425136445, 94.18494885967624, 86.67218223694833, 54.693384555078325, 51.970938021136874, 44.213913640668316, 61.257345522603686, 72.93946220028785, 48.803467212184785, 39.88733537735478, 87.14371388958347, 82.34471751797585, 51.39480852311658, 74.00383657024753, 83.72114781410464, 102.81988205448275, 89.59972950720018, 105.14141528837143, 123.08410936786284, 140.45554161071777, 106.73747477992889, 117.48978968589537, 116.8347538671186, 120.73548040082379, 113.09694690089073, 134.7269513530116, 144.54528716302687, 157.05383546890752, 124.11676745260917, 72.00478492244598, 18.75987087526629, 1.6120764901561122, 0.3211573877882573, 0.4404738353144738, 0.1335103713697003, 0.17759251077809643, 0.2433223337415726, 0.2535945768918722, 0.10336016139556324, 0.19258852867830187, 0.24647352916579096, 0.1695707888011971, 0.19826121057473844, 0.12850269209593534, 0.22421668313684004, 0.14423048484229273, 0.15742037385221452, 0.15862916866617818, 0.21201949085920088, 0.19777010224999922, 0.2826580375192627, 0.14872077131463637, 0.1835814490914345, 0.13266146934080508, 0.22264706091054026, 0.12799751073602708, 0.10731679868073234, 0.18667835952533832, 0.0826245591404938, 0.13148802182366773, 0.1743697474199918, 0.08229711783989783, 0.14143069394894187, 0.09422446330708843, 0.18103259795856091, 0.3509085961887914, 0.2228606155803127, 0.12198978028590642, 0.2064107773044417, 0.10760725325634403, 0.08181884914876954, 0.15436090979604952, 0.23428916120000426, 0.1716549616427191, 0.10258746213249623, 0.11119344106484806, 0.14792653732001781, 0.05777060993075852, 0.20755563442024494, 0.16254902607010258, 0.08074676272489371, 0.19420307430048145, 0.10046993382275106, 0.1296396048799638, 0.12151821486411557, 0.14172991257040732, 0.1676426833916095, 0.15654015414897474, 0.2975802045435675, 0.14579059225657295, 0.1375591307277641, 0.19605276295013968], [0.03985784249380231, 0.040661120156366984, 0.060589997353212494, 0.1309669747828476, 0.017538673296991377, 0.04481595970930592, 0.10639570818673219, 0.07486283974421602, 0.02894832144281076, 0.01659732935349307, 0.02618801855151692, 0.019508543904990922, 0.04446910191026907, 0.03959885497968044, 0.08986874017864467, 0.031523887976823796, 0.04853093838920036, 0.08533443429417188, 0.025852623343047117, 0.106463254159016, 0.0077408746226630635, 0.04988106493387492, 0.03548906905756843, 0.02229579968468076, 0.0208652243318577, 0.05459607563792698, 0.021473992270447557, 0.09704094725630938, 0.15202693100417816, 0.029311652047439452, 0.03377855560111423, 0.045394160739716985, 0.07328568687362057, 0.07767766128264128, 0.10756942383464306, 0.06176582357335476, 0.06377261004320557, 0.07373491317153939, 0.03077994382399465, 0.035866643151929306, 0.0479668410374753, 0.03454143744743159, 0.05196082893939269, 0.11882987444198902, 0.07440804398708767, 0.028861847353137793, 0.02571576365059422, 0.0778638666135169, 0.036845121292337295, 0.033492015734795606, 0.0356814950223892, 0.04316191842419006, 0.03445662002289488, 0.03221212030057946, 0.09152652380327064, 0.640393610923521, 6.177582990738654, 37.82794983156266, 83.4279820226854, 93.7614191732099, 84.68114006903865, 73.08602548414662, 59.179830781875125, 80.42747082248812, 70.53650056162189, 61.375793257067286, 67.92529244576731, 48.52134681517079, 54.19050139765586, 38.53565915938347, 35.64873195463611, 21.660316528812533, 19.238647145609704, 54.9287110759366, 39.69646892239971, 75.27847351566439, 58.89989906741727, 59.501006218694876, 70.63884304415795, 37.08468029575963, 104.52884304908015, 61.516782852911184, 69.73061038601783, 59.6414819840462, 67.26727562565958, 63.98349869635798, 81.89725352871804, 95.05782527308311, 54.990774739173155, 87.42586566555886, 91.188626750823, 45.801241936222205, 49.33045725668631, 86.51131014670096, 48.77799926265594, 45.53354801670198, 74.9929485013408, 55.2649131128865, 31.60426820478132, 25.414099308752245, 32.9243948382716, 28.777306195228334, 34.32373177620673, 49.57806864092427, 50.58664337281258, 69.34203686252718, 66.69966943802373, 59.47167081217612, 61.29276060288953, 67.58282246128206, 72.9350769904352, 79.74977154885569, 81.19682019756686, 98.25840088628955, 98.54463977198448, 51.6194308957746, 24.053201598505822, 6.764100395864056, 0.010196919470364529, 0.20447876484644031, 0.10088596553091081, 0.017330674679889795, 0.01744387374680129, 0.07828476297999583, 0.03770964002356895, 0.05228767652184733, 0.01730743731792656, 0.018053727615023815, 0.024654436931614915, 0.07428852661002068, 0.06442904397244416, 0.044360635351509824, 0.023309893252688552, 0.06681322450599363, 0.05187906054479461, 0.048381999405401374, 0.0070364357088692495, 0.05159885239517016, 0.06019950318600863, 0.005805678111726359, 0.057900986604152195, 0.02126849493041875, 0.05640630692904515, 0.036305224658140255, 0.060532916141974355, 0.07042905991716732, 0.01619398214613959, 0.05753771537133763, 0.04343515134326393, 0.01922756583700257, 0.04611713323561896, 0.03016417384177687, 0.06306078412660188, 0.029771253091072845, 0.03464055773351462, 0.12319016345446149, 0.05586117025344603, 0.03596520802426723, 0.08079220706056203, 0.02645773895745797, 0.022769400985130382, 0.018635460310765815, 0.03397375863466052, 0.0635590285603558, 0.10547914527236454, 0.027079706590983178, 0.007127225267580681, 0.06394861108292976, 0.016575800367600976, 0.021120027090693196, 0.06589989448266645, 0.0937047032939811, 0.087891222097941, 0.06315140849760463, 0.0716179900712544, 0.01752546019551735, 0.05803126751655533, 0.06070517484218844, 0.07647658863495435, 0.0511511237991433, 0.035251022556856755, 0.02069134535568376, 0.049016952229243134, 0.02594983990063831, 0.07117381995363582, 0.02144453235931935, 0.027081696504366495, 0.061456737739424554, 0.060006445198650324, 0.03581634947970029, 0.050938974900711934, 0.04375558676979235, 0.029881973863549294, 0.04331092635590223, 0.05241929042723872, 0.1072822864197435, 0.025734458111166477, 0.07434544694279471, 0.021076442433461066, 0.14377380450887067, 0.02924154159582911, 0.05661860521462175, 0.008294587173769552, 0.04508635044218071, 0.08187823628465976, 0.07378539836574947, 0.027206984438723134, 0.02434159918207555, 0.021542769729069645, 0.04550039032173734, 0.039443683870617426, 0.11581347218804783, 0.07063123818126417, 0.049438453805182254, 0.023770685563044205, 0.07626628983886012, 0.06067303745376487, 0.06523984078798564, 0.06468577535762902, 0.04730490659694037, 0.04391178060623427, 0.05761372661518474, 0.033015168136766845, 0.04027918319127733, 0.0541671353482431, 0.06912932280571231, 0.0375726098765529, 0.09249832931785815, 0.058612651642291784, 0.1121371005090975, 0.07718980883158023, 2.491222567135288, 12.30959294303771, 55.81299766417473, 101.43551288112518, 112.60497185491748, 96.78465658618559, 91.6730002434023, 83.53958129882812, 109.34394467261531, 107.99958367501537, 90.45957580689462, 88.5524723606725, 69.12054061889648, 69.81083070078205, 29.248155355453495, 39.05472993850708, 15.022709138931768, 19.64728359253176, 32.93724060058594, 26.701750678400842, 31.64879495097745, 30.439565489369055, 28.493030455804643, 28.845616232964304, 26.320874806373354, 37.51837284334245, 28.94927663187827, 28.710216014615952, 23.85469044408491, 26.54998044813833, 34.80159021192981, 47.63336143186016, 40.32195752666843, 29.75235446806877, 26.968036467029204, 37.12076217897477, 29.292372234406013, 16.6508496961286, 39.1833052327556, 31.25113525698262, 29.565412344471103, 46.949696233195645, 40.39475671706661, 21.344763809634795, 26.664093963561523, 36.94891529698526, 31.808831576378118, 38.918404040798066, 60.26769230442663, 58.042013952809, 96.83149753078338, 108.91332334087743, 99.75064308412614, 94.06330831589239, 95.60092449188234, 90.14777091241653, 89.53672839749245, 93.09463977813722, 111.18869027783795, 119.65120392460977, 76.87522334437217, 43.11230813303302, 16.280194540177625, 0.056047900354549776, 0.2768255650035797, 0.06020131498394955, 0.016519971710119038, 0.023733378996351556, 0.1158843046775268, 0.05851374203038793, 0.09518709108834306, 0.0663881759429651, 0.04922776047380702, 0.045302846889582374, 0.03244172451236556, 0.018999886421126225, 0.025127431107384544, 0.02655277216446496, 0.08305045040023905, 0.020299592889064265, 0.05712560986378982, 0.01251540509157724, 0.03115231043569023, 0.05387937357168525, 0.016105075727307027, 0.08206525366873511, 0.033793348758932085, 0.0755062616700607, 0.011491277686981185, 0.038322069862436865, 0.02990837899907943, 0.040018468148886197, 0.015684881288888716, 0.04021519186696218, 0.045178426549799984, 0.019127823104481065, 0.06620740983635187, 0.037228682363826426, 0.015329173259106616, 0.020356624304587324, 0.015863989772755775, 0.04310715462892287, 0.024016739597784418, 0.04002529782273116, 0.016793991784535108, 0.022403521222933646, 0.02703975893617157, 0.03365255712020782, 0.03827253461725289, 0.07370933349574767, 0.05262497737402878, 0.057532640038839275, 0.0504327631525455, 0.05728223270946934, 0.009320615434027728, 0.02348308466495045, 0.0642123330204237, 0.0539471953356218, 0.03816492224652921, 0.05556554841478506, 0.08216159688609262, 0.09610890170499202, 0.15994126277585186, 0.13309588715914758, 0.15424880048921033, 0.10620190326364772, 0.10386013335758641, 0.23732593373185207, 0.1463158681027351, 0.12983616771957568, 0.1370346516130432, 0.1555264666075668, 0.23702458538595708, 0.17710235240238328, 0.19542218065790593, 0.1904358522545907, 0.12506219122799175, 0.141385295578549, 0.19817884080111983, 0.16831147814950637, 0.31069612010352077, 0.14167290030708238, 0.16574140638113022, 0.13204610155474755, 0.1945991877226099, 0.12545216062496747, 0.1096420057658707, 0.1343162499007679, 0.20955984300423056, 0.37408278654179267, 0.1748115196824074, 0.11614001716577238, 0.1485865680320609, 0.1724729750065073, 0.235926965251565, 0.20062996975837216, 0.290570653253986, 0.1573311858960698, 0.09461776518653478, 0.09630010959001319, 0.11835090094997038, 0.19800386631921416, 0.2289317091626506, 0.12025053087141245, 0.22924306261683666, 0.21048644167040625, 0.08877444486584395, 0.2137719169859925, 0.121959604082569, 0.1402092127189521, 0.17278075849096622, 0.17861526880052783, 0.1494911799748098, 0.14239950405974544, 0.2756407334198875, 0.13393708234352453, 1.9681708274349092, 13.162365248126369, 60.16647161975984, 112.7670677246586, 120.61910367781117, 106.45890805029102, 94.06379468979375, 81.28745832750874, 102.95942429573306, 95.8986637669225, 83.2192962400375, 89.07275122980919, 67.47115258247622, 75.30458865627166, 58.853881820555664, 57.37679173869472, 32.725126666407434, 30.93850274239817, 80.06486338953819, 59.47892719699491, 114.75673706300798, 87.8992800558767, 91.28360302217546, 105.53406023210096, 57.11617769733552, 155.63815793683455, 94.70697710590979, 105.64318841503513, 90.46516910676034, 97.0402382266137, 97.39930768166819, 113.88499029221074, 129.12222954534715, 79.414165712172, 116.42873364110147, 124.42578746426491, 69.7370901415425, 71.43198551670199, 125.42195181692801, 72.29617780254733, 68.11141675518405, 105.58057954234462, 82.0410946876772, 47.324839561216294, 41.74989638790008, 47.83290024726622, 45.20598696124169, 47.55050920671033, 69.35497283935547, 69.46346559832173, 90.91599064488565, 92.18251612878616, 84.84347912573045, 89.46604728698732, 95.4105483331988, 93.20440338503931, 100.2118589032081, 102.69298553466798, 125.38275164942588, 134.28537091901225, 82.66064090113487, 43.409972883039906, 13.439263009255933, 0.12320389941094384, 0.44736752346638714, 0.14391081167324898, 0.14571713974639294, 0.19533259433604058, 0.21106194224088423, 0.1994100053824725, 0.23928564792919546, 0.1816808002730531, 0.12194531654278118, 0.11961009668847246, 0.08859529520475096, 0.1635335409833539, 0.15845961808677644, 0.12310754087182785, 0.15737223288705274, 0.11117438079729197, 0.13798558123169408, 0.1613847409645396, 0.1263749824776765, 0.2003784784145894, 0.07213348297462349, 0.15411001600084767, 0.18022097376806123, 0.12937018707875284, 0.10556827194147533, 0.14775943822197377, 0.15236719661662657, 0.1574645771254455, 0.1439588147425844, 0.11136252433061601, 0.10391250312809022, 0.15171047540441637, 0.1384235843415222, 0.20830601754207767, 0.12296318692425567, 0.09158495332925551, 0.20277786579343582, 0.16591751467316382, 0.13882031063399008, 0.22668500310711323, 0.06530332649427076, 0.12119292627058684, 0.1571494085533965, 0.1287805904904681, 0.18651490700581383, 0.18191785852034248, 0.1591259460415571, 0.15815379578740368, 0.1077894059821002, 0.14941682348087912, 0.10561546295761101, 0.12595404780680133, 0.21693147809034397, 0.2782879349204802, 0.11783793613675142, 0.1473003217289525, 0.12894287855634767], [0.07851969150285568, 0.03971874390939071, 0.05517861272598948, 0.0224153611118034, 0.03234297960936543, 0.05844758650768669, 0.07617985213836355, 0.05724673219505818, 0.06500880399178113, 0.04062942326849988, 0.0697147059104135, 0.02281684481028107, 0.01666163094341755, 0.058994508168149384, 0.07108788021029004, 0.010763755586418894, 0.049421710953597105, 0.04326995214327209, 0.037966612726449966, 0.034121506351737246, 0.06276889313613215, 0.08072411716585198, 0.03437159192417899, 0.028345504092172753, 0.05108248998200701, 0.06004091915524295, 0.026652145259563, 0.10378300362536985, 0.08125929852887508, 0.11044819073210801, 0.06194969233606131, 0.09413718290987516, 0.07779244423633622, 0.02647009212523699, 0.015906204090213344, 0.03509185629926863, 0.026729610155246435, 0.015953760913332865, 0.049515732924544045, 0.02148279845113716, 0.02492767368112841, 0.1050585859845723, 0.10007978822555273, 0.011094497768358599, 0.03267750339282136, 0.0212787585933843, 0.030430929487450954, 0.03007595115641673, 0.023672373499721292, 0.08854263432083592, 0.037001288315701875, 0.2365362809430207, 0.114281710026966, 3.39489326361687, 33.51375841325329, 56.080605291551166, 85.21636316853186, 83.343227448002, 85.6898089378111, 64.36446282171434, 76.17766118818714, 57.15298914140271, 67.5018019830027, 38.57567125751127, 37.53707078195388, 27.192227378968273, 29.705201695042273, 50.71830165001654, 29.08759705481991, 61.38604633269772, 37.702061360882176, 92.55715739342475, 55.947640865079826, 86.8424052576865, 65.53549820376982, 73.56773176500874, 75.84762511714813, 100.8742452436878, 71.85238515177082, 75.01428619507821, 65.65656215913835, 72.89877937686059, 78.50688226761358, 76.09837439752395, 83.5738863483552, 78.90317501560335, 78.4787824076991, 90.13778455795781, 91.16676345948251, 94.67974801217356, 90.97732866964033, 77.57564098604264, 81.58591931866061, 72.58953186773485, 59.96716814656412, 95.26175714308216, 61.859060641258, 93.11543618479084, 130.26582794804727, 63.81850811742968, 54.27605221348425, 64.75580946091684, 78.21896460748489, 38.30132107580862, 34.46059896099952, 44.41482528563469, 28.661784548913282, 35.17610596072289, 36.76695262232135, 36.12599026772284, 64.80377220338391, 66.20067334944203, 60.73486228143016, 83.53473324929514, 86.75081006942257, 102.92676664167836, 100.7208570357292, 91.59852227857037, 38.285682585931596, 2.9348016938855572, 0.0577720386847373, 0.37034783211927264, 0.04859608650628117, 0.0798674316836461, 0.022476745821956187, 0.0828491531372551, 0.06753186860512342, 0.07649781693133616, 0.03650051962223746, 0.020646353011890765, 0.044050695329544046, 0.01698964489473691, 0.037918169156558094, 0.029606105602015893, 0.042200351674710555, 0.02983129714735814, 0.009954325280212348, 0.024186464462188945, 0.02405943176258476, 0.051157214198141336, 0.06678412848662946, 0.015096831240601119, 0.050023764131530646, 0.02583547638008191, 0.06534651853144169, 0.058347703964119, 0.02519867536912282, 0.2577534077628966, 0.006108740579351904, 0.006899892985295024, 0.03052646831248797, 0.04724552712192939, 0.038507049452633633, 0.04003242627086659, 0.02602246695107991, 0.01585808610768929, 0.03733789968875147, 0.014136471079602359, 0.0767034808954885, 0.07396489276640839, 0.0732824539825801, 0.039011981833966515, 0.01048220582531705, 0.049708871351134394, 0.02382918212172245, 0.026687663010952455, 0.015089318790893643, 0.08653783584914862, 0.0783346736082627, 0.16228788201847386, 0.07549512275164166, 0.012382711959822525, 0.09529920805606151, 0.02570639439528027, 0.04829703642415905, 0.07077920806383894, 0.07886739582904885, 0.0558047172343058, 0.04207335344906296, 0.023349879211896372, 0.05882402679191963, 0.04905170963836774, 0.022254576493475228, 0.0386812731683735, 0.02923115535879568, 0.016659187122939095, 0.04498686626433365, 0.04667377655184077, 0.015358039452093504, 0.05273237524013366, 0.03809264185087335, 0.038096518255770206, 0.03479155749382992, 0.051007037982344634, 0.0394697729948788, 0.02180021166080429, 0.08991017021358975, 0.09839807967505149, 0.027495615725075046, 0.06760107698820292, 0.09431889130463524, 0.0701584163752775, 0.03619591923310392, 0.09539899100819904, 0.04121530433035186, 0.04639057682887201, 0.041422971614426186, 0.09440324524597776, 0.05405207660289542, 0.02242384936600443, 0.06072246927707907, 0.021525452311541286, 0.044241286513786164, 0.023647801229549993, 0.02529842959296319, 0.036026000931498506, 0.07858978854792734, 0.0634823393286957, 0.09065184291572341, 0.02473576291043672, 0.01994591499228151, 0.01583873951477149, 0.026574724413935217, 0.013018811042720993, 0.011082601380504428, 0.07362026045279157, 0.05838695830935913, 0.17276517626258636, 0.12406795465898131, 8.909446154871295, 51.16296898934149, 76.75121368900423, 108.029644720016, 100.83278579096641, 100.54280496412709, 86.10017514997914, 102.30234884446668, 89.03516707881805, 75.34114514627765, 50.10373684667772, 49.15239341797368, 29.249394824427945, 33.79134062797793, 32.54478000825451, 28.230100254858698, 49.26818570783062, 32.19862887936254, 50.97554637539772, 39.2366494670991, 62.56390271648284, 51.14327869107647, 67.63150691986084, 61.518030166625984, 89.28326483695739, 64.20642268273139, 54.106088069177446, 61.179043246853745, 53.21281925324471, 67.06478718788394, 66.51758516988447, 73.43239430458316, 66.21717083838679, 66.73780272083899, 84.03407450645201, 76.11333431736116, 80.91156190441501, 70.91697046833654, 50.189962310175744, 50.81675706371185, 63.21290200756442, 41.78528401159471, 50.94611290962466, 52.67190871700164, 79.4631874945856, 82.0345207952684, 36.70513999077582, 28.20256325506395, 31.531882824436313, 39.60401473506805, 32.0208925585593, 23.850781802208196, 35.68760264304377, 26.646319743125673, 44.323790996305405, 55.16371596244074, 61.294513902356556, 100.03468544252458, 98.93873599267776, 92.98207559893208, 106.63124915092223, 96.33362324007096, 115.91374212695708, 113.41662006993448, 112.52979570819487, 58.965912557417354, 9.398194070785276, 0.5271511681137547, 0.21670310728011594, 0.12621058767000515, 0.08462165842854208, 0.06892848519548293, 0.11266650556917153, 0.059805898701832186, 0.06545227696938861, 0.007438039587390039, 0.039982350933695995, 0.020303465463521502, 0.03211450154682802, 0.010856578629764338, 0.023673260246493646, 0.13046724030808096, 0.022929187773937182, 0.013306837119612724, 0.01767173127812003, 0.04717353783968476, 0.030912270191155618, 0.022444861242547635, 0.01691526924860814, 0.026641441096040993, 0.05260801618738521, 0.02573460941353152, 0.08240784052759409, 0.04166415524518779, 0.11673619444932669, 0.015590053010401467, 0.0378829482642393, 0.012721715442415689, 0.021004822788639896, 0.013401157864850136, 0.017587180069137006, 0.031169348231126225, 0.024934246715518738, 0.0927475760240228, 0.029106037879002192, 0.061024242801772016, 0.071000607473956, 0.07378817160403536, 0.035954846685091336, 0.05148352168860936, 0.03404940215630397, 0.031991192034535834, 0.05862240394156787, 0.0368818475474273, 0.0303605126006709, 0.05236186064599503, 0.015287959644000138, 0.02668606188719071, 0.053372303805043625, 0.07104020655876206, 0.005034476071746359, 0.09015039240400638, 0.07625611619122567, 0.14219379413031763, 0.17884789905961485, 0.14369767069095565, 0.15966957735438503, 0.12201435638651734, 0.10691451825081341, 0.18332183721565432, 0.16554525722899746, 0.1792035783610998, 0.17807441072598582, 0.1787501155969597, 0.18105931910535983, 0.2269147069103295, 0.12813740605187993, 0.23495836964538022, 0.15848640052060928, 0.0871823149763288, 0.12668577668767783, 0.15692931149275074, 0.1126512144542029, 0.1797450799494982, 0.18390610183198608, 0.1634352672244272, 0.16651003771731931, 0.18392813452068837, 0.17544547276150796, 0.12224704793263828, 0.21195803528591511, 0.15207403008976292, 0.13514721015047643, 0.07774246466015616, 0.2352590591556603, 0.23729224118494222, 0.11705089570774187, 0.1539104654183311, 0.15987537921436373, 0.15434575657690727, 0.1342021181218086, 0.15416135921353294, 0.15105684918742027, 0.19491529092192653, 0.19616177726176479, 0.21427185064361942, 0.15399825909445364, 0.12382215534847592, 0.17407874126107464, 0.10955413548095573, 0.16376589545078818, 0.18130458981519748, 0.21735204503901545, 0.1888797897845507, 0.3919891418228227, 0.2253324289115206, 7.719359820888889, 51.905720772281775, 82.15023071535173, 119.31788875210671, 110.56500204147832, 107.27449432496103, 84.32775020599365, 100.76267734650644, 77.50985499351256, 93.49060304703252, 52.415393552472516, 57.129494144070534, 41.757964703344534, 49.32873141381049, 75.24055988557878, 47.611831541984316, 92.52682178251206, 57.74897367723527, 126.18281318295388, 75.55452208365165, 132.67785810655164, 96.91651882663851, 114.43889171846452, 105.73169277560328, 147.6751816657282, 104.51845661286386, 106.31466680957426, 97.13650888012302, 103.8533873711863, 116.64344418433406, 107.55106849055137, 119.67048629637688, 110.15028984315934, 107.77298050542032, 128.42538910527384, 130.8443226352815, 132.99255771021691, 130.3635734127414, 104.57511917237314, 113.404021416941, 103.3749209680865, 84.59145115267846, 127.04803312978439, 88.03305641297372, 119.09871455161803, 161.97768088309996, 87.00354406910559, 76.0464108374811, 95.55183995154597, 109.75933936334427, 62.39029469028596, 54.39832033649568, 64.63457684363088, 39.98619479517783, 47.98941850662232, 51.989012302890906, 56.14018217209847, 92.20704663184382, 93.71859473566856, 88.55793229995236, 106.42806253125592, 105.80437429489629, 127.9916141879174, 127.22498693773825, 125.0904566241849, 58.997381733309844, 7.591521932232765, 0.3081377848021446, 0.4995691223490623, 0.30803810144143723, 0.2782947377812478, 0.17007925667830054, 0.23930256315056356, 0.08477579531890732, 0.1339955348521471, 0.07265262245651215, 0.1266247577845089, 0.106084224497599, 0.07108319175219344, 0.32814493703265346, 0.2352026597626748, 0.1831766482322447, 0.14958957630780437, 0.14949917793273926, 0.16801739231713358, 0.14215237941713105, 0.16844004302495913, 0.15122299833643824, 0.09883082742171903, 0.16030071122992426, 0.08829898771739776, 0.2656937865239959, 0.17525257182217416, 0.15323780957729588, 0.456615767531818, 0.16594069649375257, 0.18132948767273657, 0.1445711334987033, 0.1372747588902712, 0.2269174648268569, 0.13474820091599418, 0.13166950805292976, 0.17445502832772272, 0.20978000135191027, 0.08405613998371748, 0.25958282572607844, 0.12105614127170657, 0.2242744308445723, 0.17312114667748252, 0.20241725288571852, 0.17731304190331892, 0.17101362347602847, 0.12848813642537402, 0.06383467848683078, 0.2360652594436561, 0.1664898436396353, 0.2537197250151827, 0.2405587941287987, 0.18138614753561635, 0.21978599830500542, 0.24929063364623055, 0.14865942299365997, 0.2483102096424949], [0.05586093659662912, 0.0443326769727132, 0.004977301972347402, 0.004427487372360643, 0.0041260116643482645, 0.05630476963556102, 0.03267457693695061, 0.09622870253459101, 0.05620013734686279, 0.1097272330474469, 0.12500059009800035, 0.05244113542439957, 0.07282755097314235, 0.010661090228466258, 0.03426363098344976, 0.02359556552443293, 0.03902378341844005, 0.0322771305218339, 0.017161878697093458, 0.060084815993304216, 0.03348550398743922, 0.014569017728189788, 0.02792459240393533, 0.12657476288657035, 0.005416576309324873, 0.09445967528248027, 0.05792428333792956, 0.06364312586224367, 0.028383934892894282, 0.01742530377551673, 0.03190454749029971, 0.03335083722166958, 0.10026236229966726, 0.02625285448776859, 0.013274737077975466, 0.02687792477738713, 0.04071185815959208, 0.057431029967002334, 0.03887310924549257, 0.03346695699879239, 0.04839481222593496, 0.07994373404090444, 0.08335374460946168, 0.02185656317329455, 0.07660380519566036, 0.06602793075745145, 0.03306112575134443, 0.024353898723699877, 0.04537021283120398, 0.012388245029855641, 0.10050485977121901, 4.044517927592801, 31.831073376440237, 82.043730520433, 88.34530845765146, 89.99572415505686, 76.53991560782157, 68.17701447394587, 56.704807358403365, 59.48450872975012, 60.525929389461396, 31.278684023887884, 35.118607936366914, 56.98832019682854, 65.04472340306928, 85.27216280660322, 54.18889322588521, 63.360104637761275, 73.80020280038157, 61.211226294117594, 68.66306674095893, 60.39131756751769, 62.122314437743164, 62.125899484080655, 61.109997764710464, 49.371775504081484, 52.87530322228709, 37.694197008686686, 42.74615487744732, 41.382589955483716, 34.43537419842136, 29.949155469094556, 19.24237535845849, 17.49636757758356, 15.17885281193641, 15.274394885186227, 18.7191076432505, 15.599141640047874, 22.136890388304188, 25.591480655054895, 31.103554118064146, 47.15103933888097, 50.35380755701373, 45.396206225118334, 63.99504615414528, 58.432462369242025, 57.080323311590384, 59.68787970081453, 69.705962211855, 76.29923112930791, 84.12004501588883, 78.47221636003064, 72.85841034304711, 55.204873392658854, 59.76500918788295, 76.62825522884246, 86.57245205294701, 64.27012589669997, 61.82986644006545, 37.17873873249177, 27.871889798871933, 28.154865272583503, 33.539657823501095, 51.13280596271638, 89.9566573481406, 79.5149157124181, 74.46455817068778, 83.00493086538008, 97.45822952639674, 78.51225591474964, 41.6932769744627, 9.060777079674507, 0.14093436090455902, 0.2759761267131375, 0.025501774225924766, 0.1777864076317318, 0.03507238234423342, 0.012020269059576096, 0.04979901308674486, 0.05556142303131281, 0.06566756299786991, 0.03335260688477466, 0.0418393901969877, 0.03325804865228073, 0.06416727938959677, 0.020373206277708375, 0.04461129932033439, 0.05462798703041288, 0.006816317102000599, 0.019016816964252822, 0.030907516615585457, 0.06817764242089565, 0.03055115932628753, 0.07350756125825067, 0.020867798387283282, 0.03834120673878539, 0.04309153026570717, 0.03732258942158472, 0.03515514665313306, 0.061448073285000945, 0.038359872471060485, 0.04527434458835952, 0.04610634288720546, 0.005043582941946244, 0.1857473022274433, 0.09114241497891565, 0.04918277196045365, 0.06837357706840962, 0.019510110554796074, 0.05467081134538016, 0.0270687036531707, 0.026036442310038595, 0.026308077935790344, 0.06346977165629787, 0.041056065294410915, 0.0696866441097471, 0.02118409119336115, 0.04929946630351967, 0.04147925992466269, 0.10808195197774519, 0.05689367291427428, 0.06945825031688137, 0.038480849245623235, 0.027375745947562882, 0.041977557984571305, 0.04652117949820334, 0.03389025122047432, 0.06593126578316574, 0.06352343994583334, 0.057273935977249384, 0.00956716838352863, 0.018261343188163255, 0.044955912481753096, 0.01040685820513435, 0.03478862720751955, 0.041268122262291373, 0.053591286207759575, 0.03478087439772583, 0.008006614723032521, 0.03428501249741643, 0.025334000970507344, 0.03464290962344216, 0.10646088694732998, 0.034687001813924125, 0.029931601039284182, 0.04964686036410351, 0.011452097077703765, 0.0790643800170191, 0.019681652962800958, 0.01842116636614646, 0.07262306678439341, 0.05162820888442859, 0.03694257916762464, 0.017893877623963262, 0.009406323435776418, 0.04251423321904675, 0.048957408045328436, 0.013130597635022095, 0.010309247112262153, 0.1104330298520865, 0.012758631304266953, 0.027319873240025296, 0.03164937317882094, 0.02095692122595445, 0.022875607584513003, 0.04660392082446525, 0.06573967485418243, 0.11946328359866336, 0.04711730315560295, 0.0036460252604522416, 0.011788891354245285, 0.005049236192022481, 0.02246741104059883, 0.032529767167063496, 0.05794637348322619, 0.04384867411347167, 0.04445790170481609, 9.906387136828515, 48.47789479840187, 97.6018588773666, 104.59243251431374, 103.85487002711143, 92.58117798836001, 90.92698897084883, 88.97361724607407, 80.71898921843498, 79.5980699600712, 43.94299553286645, 44.99465750109765, 39.153809009059785, 43.1888767211668, 50.48415184020997, 33.35632231927688, 55.14928948494696, 57.35230830407912, 59.822448376686346, 69.85428271755096, 64.62584956999748, 66.1909144924533, 59.435898796204604, 59.2687548360517, 50.74016101898686, 51.47655071750764, 39.635527057032434, 45.6925844377087, 44.43807709601618, 31.402654455554103, 25.44385244769435, 17.392056065220988, 15.67365098384119, 13.115499788714995, 13.12508802260122, 17.534636182169763, 15.881043364924771, 20.382259276605424, 22.7394841178771, 30.494870908798713, 44.93095428712907, 44.19937341443954, 46.644708418077045, 63.42311751457953, 56.982691595631266, 54.68233131593274, 59.80019284832863, 67.51229824558382, 73.0242246197116, 78.68258091711229, 76.53221207280313, 74.55660050915134, 54.064742365191066, 54.38052846539406, 62.85254993746358, 46.43790537311185, 37.352099649367794, 42.624875191719305, 28.842527366453602, 30.77887208231034, 44.1070015968815, 47.98959893565024, 80.49066805070447, 117.29971162734495, 99.64398599440052, 89.5432238424978, 95.91698908036756, 109.67405919105776, 102.2763199960032, 65.18914899518414, 20.317838268895304, 0.11400711347138691, 0.23108918129676775, 0.06387478318966686, 0.18131790442332146, 0.012781325701413857, 0.05705708712940255, 0.01522298964236172, 0.003212744125067407, 0.04956645943645028, 0.03855298025413387, 0.06535182752075695, 0.0413738462262817, 0.07100192514518577, 0.05577398561722329, 0.020003291147370494, 0.08345286872598433, 0.01349880438928883, 0.02485569397498283, 0.020370172569528222, 0.0077657562008337875, 0.037548589189687086, 0.08164913003002444, 0.008850497918413773, 0.11408357670710934, 0.0217950769564918, 0.044684897387220014, 0.07802359594572937, 0.11419776211222334, 0.07428333253389405, 0.01261260153936042, 0.015137848545676999, 0.01283900733406265, 0.05253159891693823, 0.10403977331495094, 0.0347025687205455, 0.0988949643027398, 0.02821636273555698, 0.05372152498532688, 0.024151770255318093, 0.02044723909949103, 0.027855475951406746, 0.04435915297137634, 0.053854207583372636, 0.04003731774226312, 0.02411165789160277, 0.07239588341044803, 0.037641653550728675, 0.008556673513545145, 0.023819343637554877, 0.053376019331476385, 0.035572082345043464, 0.012634721370564114, 0.025521510566074043, 0.006336329022287241, 0.24610729317270943, 0.17949918104756266, 0.13243899740759404, 0.1338965409705716, 0.07409047755983568, 0.13016575406635963, 0.13091717906776937, 0.1632467023427448, 0.12753947442697902, 0.31187197313674037, 0.16669566082137247, 0.11607824749643765, 0.19814402976584053, 0.08830792030259486, 0.1270329907175995, 0.17229979317034447, 0.1904929104831911, 0.1334359382669772, 0.11147564487351526, 0.1332176644955912, 0.06196273498297219, 0.14662287017751127, 0.12948882345470691, 0.21947579398270578, 0.16503623776858853, 0.1403250605348618, 0.13612182720774604, 0.17836314926464714, 0.07906903783159872, 0.153843509333749, 0.12706444628777044, 0.11571232559940509, 0.17828785814344886, 0.2043217321437213, 0.07516647103212534, 0.08696537419793107, 0.11867480292435616, 0.1468496015595813, 0.1348972356607837, 0.1633771364727328, 0.13929108698521891, 0.26032829056343726, 0.13771351276626512, 0.0829367935957928, 0.11547427909869341, 0.16745508378071172, 0.10874013641789075, 0.11049420197284031, 0.122090038212557, 0.11908822227269412, 0.18277028455368935, 8.155356270651664, 48.86752343946888, 109.24881150645595, 115.95896705504387, 115.04034796068746, 95.27216711351949, 89.54023499642649, 82.36149741757302, 79.15794864777597, 79.53948543917748, 45.98864101594495, 60.92157886874292, 79.58906419815557, 89.38629765664378, 115.25300318194975, 75.40035724639893, 92.20881169842136, 102.5792524891515, 85.72013670398344, 98.85225557511853, 87.82910885349398, 95.74809182074763, 83.36862871723791, 83.34771463947912, 68.96872920374717, 76.03455743482037, 55.4311078594577, 64.34813007231682, 64.89597143665438, 52.03213484056535, 41.945548134465376, 28.348332258962817, 26.117137093697828, 20.562311756995417, 22.862660269583426, 28.230594473500407, 25.543727759392034, 32.90794441776891, 36.19488669979957, 48.14756454959993, 75.26651813137916, 72.89178186847319, 69.92807818997291, 98.44557639091246, 87.33055207037157, 80.9973676743046, 86.15654745409566, 98.42736090383222, 110.62966623613912, 118.46557340314313, 110.56322128542008, 106.9767079814788, 84.04657902256136, 87.38110357715239, 114.5641722217683, 123.3622524815221, 89.89025946586364, 88.35042322835615, 57.59650722626717, 39.45472540393953, 41.62463549644717, 46.35628084982596, 74.53914596188453, 119.23947272762176, 100.80644315288913, 91.28343828262823, 103.21227596652125, 124.05080103105115, 110.25067898534961, 69.38024074800553, 17.968683704253166, 0.16471726940043513, 0.6188354677250308, 0.09581175918180136, 0.3334415463670608, 0.09823628190544345, 0.14697816643503406, 0.12606484710329002, 0.1679614832204196, 0.2733527965122654, 0.16602556371400434, 0.11423181472045761, 0.1283822324307215, 0.13205708725558174, 0.18056727615335297, 0.17501341449397226, 0.21940563565060017, 0.11772817871983975, 0.13406362474685715, 0.0806441375865571, 0.11090900794032121, 0.18258194949838424, 0.28003198004538016, 0.16339719265459046, 0.14548599569787904, 0.12407379990984356, 0.1366784207282528, 0.20932635472666836, 0.21727679988309262, 0.18809386018303134, 0.14501109779361757, 0.16138933749208528, 0.13563100999641803, 0.2978920942593006, 0.17587466586020686, 0.18266074930227574, 0.21464364843503123, 0.12822485498843655, 0.2119853080160195, 0.1690581380840271, 0.09603480568095561, 0.12373276820947086, 0.18637318073982195, 0.2190317847435513, 0.08879706744224795, 0.17655162711537656, 0.20204030698345554, 0.1460367056631273, 0.18447322140057243, 0.13825153631548728, 0.1252359476300978, 0.14155538241949775, 0.11071509576492733, 0.15760987336116453, 0.26058404135607904], [0.025737170062418428, 0.11110531031003884, 0.02629714394589105, 0.031032413845100713, 0.02406768635996888, 0.03745134198857892, 0.02962201916342301, 0.014951368380758553, 0.061830263059105606, 0.021417221324818752, 0.044474242360240994, 0.023311166873862667, 0.08615936543191634, 0.02789981137480467, 0.029851351413995992, 0.09141448344434462, 0.014845841684408728, 0.01712110558254344, 0.06433592598524786, 0.04229307512662584, 0.0223847922884048, 0.017320922380613706, 0.03299420797115853, 0.01483980874200502, 0.046241921297605, 0.014272285062038611, 0.03988613412084599, 0.021847640164196495, 0.06661764225892483, 0.029577434761449698, 0.03713817290601231, 0.07160685115283535, 0.04771814591461613, 0.04699508914904249, 0.006671088856584843, 0.053635094945709554, 0.04717946736021869, 0.013456697324140659, 0.09495829126887745, 0.055149463080470605, 0.028339404117075667, 0.048763476717736454, 0.03821004099482971, 0.027871282260504462, 0.0966295810236085, 0.034684243897396716, 0.018968359987822273, 0.0609067976925402, 0.07302590645849705, 0.2978144742308125, 22.094218923199563, 83.86251003511491, 102.13401640615156, 82.28024944182366, 73.60077381134033, 55.18877598547167, 60.547055275209495, 67.37492899740896, 28.45566203517299, 33.03465266381541, 40.57567996363486, 62.54440069198609, 29.95423297728262, 108.18846933303341, 86.46035855816257, 59.8216050670993, 85.76479681076543, 58.081657348140595, 63.39224061658306, 40.597511876013975, 24.02050864311957, 16.762598022337883, 14.510392681244882, 10.197394644060443, 14.25596715942506, 8.224557176713022, 3.3053225086581324, 3.755786620801495, 2.615850486101643, 2.1061637324671594, 0.9762927673516736, 0.3684787920886471, 0.23768355889666468, 0.2935408374234554, 0.15877219728164135, 0.15031224236853663, 0.14932967331861297, 0.17603588140299245, 0.6714645436694545, 0.24583300305230005, 1.199413485104038, 1.9001168469267509, 3.0045107920323653, 3.1984239480187817, 1.831051875506678, 2.1226847556329544, 3.7587016772839332, 5.161373855606203, 3.4528183360253615, 6.694620511224193, 12.716361361165202, 18.74485996461684, 20.828354358673096, 38.824577023906095, 44.428808535299, 58.25386116581579, 70.64575426040157, 67.8347876764113, 63.74842320719073, 80.93944211159983, 85.28670695520218, 53.8150913484635, 45.420862244021514, 35.6270843936551, 53.20839874206051, 80.04114089473602, 74.49443878666048, 63.615525461012325, 71.78155499119913, 80.13050817674207, 92.29640606910952, 75.08965846030944, 26.609574979351414, 6.3022540557769045, 0.5552450831859344, 0.37029573814042155, 0.0231810238572859, 0.06647786185626062, 0.0794902099897304, 0.017574648785915588, 0.019157706279187434, 0.012487094312335455, 0.05344277623319819, 0.026092376304610122, 0.013856272506076964, 0.07354156790120948, 0.08914313234028318, 0.061641453029287446, 0.0692033268991978, 0.014883619395174809, 0.017654812226312298, 0.029929632193318782, 0.04132388963273937, 0.023961046920909036, 0.03400861180477566, 0.044498879747885856, 0.035018618293707414, 0.04958245152186963, 0.0379218042437588, 0.11780469558171688, 0.07679893545085385, 0.06416030032860656, 0.014360331547176166, 0.05989546204105981, 0.017505980494822708, 0.031058211855950858, 0.0400608136589008, 0.08439915585181407, 0.04412155846253999, 0.017664759878009077, 0.031936558474215775, 0.04890935518027795, 0.02408082285265048, 0.034273065356237274, 0.054692909151556036, 0.06264406293931027, 0.026193904021995205, 0.018159974434022463, 0.019273220846850066, 0.055069219200841846, 0.05212601281762604, 0.052161612923467354, 0.03267865252470778, 0.08278047335484336, 0.028670302389429945, 0.0796355904951211, 0.030397231194881663, 0.006384067312483826, 0.07707560810470775, 0.060777880416642276, 0.03643823284355383, 0.028089962058490323, 0.010652877765917971, 0.023793338782965176, 0.1406891974470308, 0.038174980980975014, 0.08169743953452957, 0.016142460818011916, 0.03729750770294378, 0.027092586444210143, 0.06134206586847864, 0.03159363070623048, 0.028745003622926535, 0.00712132782697858, 0.032437940038019614, 0.09089016520808782, 0.049808558542281396, 0.035235681646173043, 0.050752777230715564, 0.08328796830028297, 0.013898143999188418, 0.013229569491569795, 0.06459229730910833, 0.059616713288931124, 0.11572364837892594, 0.0578585529940263, 0.014067576792571816, 0.03154181251903215, 0.062289716630813584, 0.02018985845479033, 0.06575612276191674, 0.05301896490216736, 0.021052513677146167, 0.0236631402250139, 0.0614470620489409, 0.04181750306499101, 0.0539326626476982, 0.07282660868499549, 0.060538328553159396, 0.03280699906510211, 0.07569760745090824, 0.015490770888244434, 0.07969702308576915, 0.06350828672669108, 0.02578221411714631, 1.688006835118417, 36.85791630898753, 107.02750267521029, 116.52517687889838, 94.30123929054507, 85.78600114391696, 83.4578626386581, 99.56739779441588, 96.11608859031432, 45.82478792436662, 28.806253287100024, 38.61970770743586, 31.81781576525781, 27.78115753204592, 106.23815705699306, 82.81926155090332, 63.23556938479024, 84.85068059736683, 60.2548033960404, 65.10434735205867, 45.417402713529526, 25.198068887956683, 16.912128579232, 13.303930451793056, 9.955581503529704, 13.00893291350334, 7.686293750039994, 2.3465844315867272, 2.942752338224842, 1.6246910777784165, 0.7315599125239157, 0.7376296577915069, 0.19452142979829543, 0.13275624973879707, 0.12817467622939618, 0.06061112988860377, 0.1551448016036903, 0.10441862677614536, 0.36647268360660923, 0.5061506143500728, 0.66006000724531, 1.0038002880830919, 1.0193564694735313, 1.9591707039263941, 2.6930319445748485, 1.367543185910871, 0.45803505266385697, 2.1245297405027577, 3.6680498190464514, 2.0313665847624502, 4.807703052797626, 10.935322892281318, 16.328520101885644, 20.24991850699148, 33.42244563564178, 44.21388226170694, 61.33483979009814, 75.49458042267831, 53.09627386831468, 44.279413300175825, 60.92213976767756, 57.059409233831595, 28.96575450897217, 29.22703927563083, 34.87144762469877, 73.87175467706496, 114.26154567349343, 101.62251580146052, 87.12195257986747, 94.60781958795364, 94.5574563549411, 104.67047983600249, 96.70444411616172, 46.24943548633207, 15.965753812943737, 1.4079812289245668, 0.13681987120259193, 0.03372630457423868, 0.15085382056572746, 0.028888380808395245, 0.04267442986489304, 0.06659214685280478, 0.04286658003806107, 0.014313477609727173, 0.03015259250758156, 0.035823788193445054, 0.0337991327227604, 0.030333280090182543, 0.02135966705428737, 0.059229689500024246, 0.027967213705602675, 0.03546236706296763, 0.1174468942166817, 0.07903228093299174, 0.009755792637025158, 0.02806865140765665, 0.08184283536167876, 0.035815483800345854, 0.0375020225352097, 0.014249497776730888, 0.008442632707526848, 0.031164701907865466, 0.02181737203030817, 0.07949204093986943, 0.029070290301235455, 0.11531877857182296, 0.026231833035126332, 0.03390354284596059, 0.024993105250741207, 0.04116566183285848, 0.04299629021496062, 0.026078121323559075, 0.054598201531916864, 0.05165487640507279, 0.045582940126018184, 0.03825015718898466, 0.027258141875086773, 0.03294552308357051, 0.030044009120413856, 0.03520007004901286, 0.10201102693475063, 0.028484962737908768, 0.01951961196027696, 0.045771351790115725, 0.03892908729011974, 0.05690293491727883, 0.0501180389114926, 0.124603028769695, 0.2261948600531586, 0.11979860028312092, 0.07599933884076535, 0.13411515182064426, 0.14060698089099702, 0.10155492116727176, 0.12998739347582863, 0.22390073315510828, 0.1345496156042622, 0.1755304012687937, 0.15126200753354258, 0.3064162320187015, 0.1242864965611408, 0.10757238093403079, 0.24416084761821458, 0.11068963100232425, 0.07031790822023345, 0.21844989499978482, 0.15759020022326903, 0.10257633853583567, 0.08496478154894807, 0.1830525879537867, 0.20791269267999357, 0.11893425392167223, 0.1227979647416261, 0.10116054676473142, 0.12404704045864845, 0.2999434325723879, 0.15786361700344473, 0.07430467574346451, 0.12991646905579876, 0.13980263453577796, 0.2802441864004058, 0.13184762349532497, 0.21781364365691142, 0.1746334042400122, 0.07781810052092038, 0.11703660816795404, 0.12199671338162116, 0.26589729012020175, 0.17835119829302837, 0.11831884783121849, 0.09517202213887246, 0.24016438142186214, 0.12183405759353792, 0.18715497346655016, 0.18139183190801453, 0.2594157879150683, 1.0216348762473753, 37.82724772730182, 115.31582386262956, 129.9191374932566, 103.65416234539401, 94.89647465367472, 73.91968604057067, 81.49880347713348, 86.16372539151101, 40.87198757356213, 48.71964223923222, 60.338075314798665, 92.2850311956098, 44.232078136936316, 137.36240756127143, 112.68808687886884, 86.2742107145248, 119.0764197995586, 80.05728537036528, 91.05194783979847, 65.62448109349897, 37.41117446653305, 31.199075598870557, 24.665626748915642, 20.600250882487146, 26.08267514936386, 16.178565929012915, 6.68346332926904, 7.5429978005347715, 5.688777710160902, 3.4127809876395814, 2.5514645345749396, 0.6272585125219438, 0.5933710115571177, 0.5327794015888245, 0.5365318228160182, 0.4560422741117016, 0.4160560697557465, 1.2770146371856814, 1.5525333174774725, 2.3529639215238634, 2.983894814406672, 2.77147003239201, 5.64033692882907, 7.233350209651455, 3.477463813558702, 3.7132298850244094, 7.663884758949281, 8.924729670247725, 6.29475595489625, 11.508183094762988, 20.00294843027669, 29.57203918887723, 34.42819626100602, 58.66098357785133, 67.75379857709332, 85.55600120175271, 107.00739660570699, 99.38669420057728, 91.30364633375599, 109.12662183084797, 111.50560994302074, 76.61508390980383, 67.4888660061744, 51.205644376816295, 68.83609817874047, 104.05310661562028, 100.90475343888806, 86.43817363246795, 91.83128356933595, 102.01380360511043, 117.45866960094823, 109.42938958444904, 49.378031684506325, 14.411406766983772, 0.898296804197373, 0.643845480536261, 0.12752432120783677, 0.20470808560569442, 0.1391320318103798, 0.10236568733929627, 0.1456308322808435, 0.1468936822587444, 0.09475973660066243, 0.11077521068434562, 0.09707252540054823, 0.16801572224545866, 0.21552051267316266, 0.20028872355338068, 0.1484371962085847, 0.09147476690310626, 0.11043816264117919, 0.1543265584135248, 0.19169415167022139, 0.13726870679566938, 0.13621176593005657, 0.1580155628823465, 0.06798903157393779, 0.08837528241377685, 0.17079577871388005, 0.1411856530654815, 0.15107491354067482, 0.11954677186065144, 0.17713595301874224, 0.11656894213369778, 0.22486422661571737, 0.1221444457769394, 0.12752614449709654, 0.34033863594935787, 0.14837941785733547, 0.07871827681458766, 0.12067459118101867, 0.12762323848061985, 0.18849035664912195, 0.10829966650494646, 0.10764839983875714, 0.12491495678982428, 0.1523860117360469, 0.150921895138679, 0.08268794525534877, 0.1857958262365672, 0.14182772667657945, 0.14437896800377678, 0.1258944614880508, 0.18632191413592908, 0.16361781065502476, 0.2089606703168923], [0.057042248006309235, 0.023899441960478024, 0.052361079236312266, 0.0075529259629547605, 0.06544706757150351, 0.012844196622139745, 0.06071822131953894, 0.04214718134232587, 0.04542384664678285, 0.03765780268417251, 0.06796191206141826, 0.021071221544257095, 0.06564163858251226, 0.01676231021842649, 0.037073733420261455, 0.05630742796065827, 0.009932985901081515, 0.017528197044626843, 0.010019720460648739, 0.03771140968667404, 0.03348710511120097, 0.06846772927430368, 0.03828193451608381, 0.03489588717779806, 0.08825680691628687, 0.0873100831203403, 0.048903050276661114, 0.02951601557734032, 0.0619705222667225, 0.0413245561292335, 0.08265182420971894, 0.061945406074124965, 0.04669087946475033, 0.05140099486696625, 0.021970853915498145, 0.12493203288965649, 0.027545547420759837, 0.04037102947251932, 0.11955807165753458, 0.06302324198787251, 0.027606428428102407, 0.042719494987038836, 0.005069743408145564, 0.03028263593272817, 0.08691964640973077, 0.057983915621955553, 0.196260035698933, 0.12184705810561297, 10.464775754559426, 63.709321098942915, 93.0698190196868, 83.01517609627017, 67.58092403411865, 77.33305023562524, 58.24340804930657, 43.51686139260569, 32.725248259882775, 39.34946075562508, 38.23686476676695, 55.58260940736341, 49.05969604369133, 61.020783455141135, 59.1443137199648, 42.91000796902565, 41.73020216726488, 30.04642240462765, 17.923458776166363, 10.370023058306787, 7.409532291273917, 5.299545718777565, 1.4066868467677025, 0.10518111408718171, 0.0615480209460422, 0.03454957713162707, 0.04259689027563699, 0.06671871989965439, 0.058042333656621564, 0.09959103945162028, 0.05200587873978, 0.2709225817553459, 0.10309694890653896, 0.2052161857605942, 0.17021551307651306, 0.1307862086762344, 0.10423256700197536, 0.17701976812414585, 0.04804506627542358, 0.057355359632281534, 0.12218705558728789, 0.08454684994273609, 0.1210279262534553, 0.15162873382289566, 0.00272051707255624, 0.13254608117764996, 0.1298034557652089, 0.12198807957071452, 0.012876380933448674, 0.05642810213049093, 0.032403060054827126, 0.07450406544751699, 0.10308048567704617, 0.1032330291045289, 0.3331259487857742, 0.8074381022203354, 2.845870775561179, 11.167835112540953, 21.566726815315988, 44.05104898637341, 60.96309715701688, 46.64319046082036, 88.54175644536173, 81.7579544744184, 50.97100427073818, 52.62238094883581, 48.27879528845511, 33.64118053067115, 34.4501889905622, 44.506561679224816, 53.7431864584646, 74.06771629087388, 64.16342173853229, 76.8058209265432, 84.67087130392753, 80.08644427022627, 53.05468889974779, 18.326011626951157, 0.6859493664195461, 0.31672173870667336, 0.08758763677530712, 0.07077945321197472, 0.10678568524458718, 0.16608105912323923, 0.004185566381971923, 0.022155783709979827, 0.04491723270245618, 0.0445297071259589, 0.03241512210919492, 0.013696153426633008, 0.04701388894670433, 0.10096446656051183, 0.0227994890883565, 0.08890581362309957, 0.08459840766004018, 0.04558153435467713, 0.06352570756608922, 0.027597403912354383, 0.08595022342858777, 0.08544389293679307, 0.06544836992097479, 0.0372806690903681, 0.04256064665593928, 0.04113065927559811, 0.020849709136171207, 0.0519080339900909, 0.05885677705068262, 0.03760270947109788, 0.02392696558437761, 0.011339394052723243, 0.013469315749863464, 0.05542549605090773, 0.029221146420064955, 0.023599367235757174, 0.01908747325350921, 0.09358737692837754, 0.03881706608339183, 0.009166295640170574, 0.027827699518492146, 0.03435013763185951, 0.028697375936674017, 0.042512003903187094, 0.10297452039535969, 0.02358314149352091, 0.010848233059439208, 0.03444226736563348, 0.0430165647318767, 0.024610792902568658, 0.036544910587009885, 0.02029963885433972, 0.03672395299579348, 0.034801102949366454, 0.04544688291066597, 0.01795519721664248, 0.015184961037800438, 0.02244818223369939, 0.05832166080513309, 0.03565877285455504, 0.03851976651217669, 0.034096780863981095, 0.02728087936467942, 0.11496578057807301, 0.03196517760384708, 0.044632060303082394, 0.06658353602453586, 0.044221046470826676, 0.0186899195860831, 0.0887728973682369, 0.03528762623787888, 0.045853108693394935, 0.040056232453113606, 0.028264570733412143, 0.05428282611612832, 0.0804739511541782, 0.07899927020433449, 0.016653334211197593, 0.02606421299729376, 0.0396075998733361, 0.07147020404978145, 0.07168359784108978, 0.0335721063968395, 0.07930179066475361, 0.04767559356086197, 0.10536010286981061, 0.019339520011037108, 0.040342665067122835, 0.040678525674006635, 0.0499587002841215, 0.05952174902983731, 0.12327977275896458, 0.04801974323908648, 0.03124370089461727, 0.12733941822643244, 0.05182710063133029, 0.23904526486031472, 0.13029867032122228, 19.602425406056067, 83.94078485427364, 111.19241652950164, 91.53243034116684, 88.06782430218112, 96.19933697485156, 84.8989571294477, 66.69479000952937, 45.56884150351248, 36.22622643747638, 23.10352517712501, 41.861209331020234, 33.664114629068685, 52.35323575235183, 53.000603337441724, 47.55528665358021, 38.288742034666, 26.70526316089015, 13.612577838282432, 8.711904806475486, 5.229678500083185, 3.5361093763382208, 0.5505844494027476, 0.0445263784739279, 0.158296640541765, 0.11524583167967298, 0.09799232120595633, 0.045705429924231385, 0.05349903773035734, 0.07507113138994864, 0.06850345961509213, 0.4977017370683532, 0.05381567719122095, 0.2668919786810875, 0.10115035013445925, 0.20713661496918048, 0.1593567836549013, 0.18472152581859022, 0.15635860663267875, 0.08564944198775677, 0.11639141657900427, 0.11919542095593869, 0.06141629595790179, 0.23727701135700752, 0.08436671968910002, 0.05103836331756846, 0.20009784508616696, 0.07947797556557963, 0.015244744624191476, 0.0666332781134594, 0.11878010937042775, 0.050279430654500766, 0.11198761377243266, 0.14193197592131554, 0.06400329826940453, 0.20673713076018518, 0.8065013299065252, 6.94581498061457, 15.869150738562308, 38.5821274788149, 56.48738253501154, 46.48207126125213, 84.14680342520438, 78.25479938137916, 39.85312446471184, 39.734433543297556, 35.708701072200654, 37.65119214211741, 59.13533933701054, 66.61724475122267, 84.31712058282669, 100.56201673323109, 87.00482276178177, 90.2522236301053, 95.45108210655951, 98.47882240049302, 75.37802327063777, 32.410246633714245, 1.744121365970181, 0.36789674912729575, 0.020562583212590507, 0.053356618154793985, 0.04939279496489514, 0.0481265742001274, 0.10127894565342896, 0.01277013315684012, 0.043270032582504135, 0.06489249652311688, 0.06130813200387263, 0.07771362911068624, 0.017951223135535276, 0.09220985124909109, 0.0034552226838235178, 0.02725637795764112, 0.048516838540953976, 0.05301438369638017, 0.05785462679341436, 0.08745830581193009, 0.05943767088014753, 0.016108235839994687, 0.02764964153269126, 0.034105552570714105, 0.008232686311877783, 0.04761705295212808, 0.019285723401774323, 0.013440126842338473, 0.05866950302715263, 0.07778506680962541, 0.029336034710849487, 0.058259653648541826, 0.05400876965253584, 0.04277453840439839, 0.027839660066209977, 0.07211022454524232, 0.05489954604737221, 0.03976374391406294, 0.0528073714174811, 0.016861068527965296, 0.052902102019758, 0.030731722419600815, 0.030263332432256113, 0.025938842708485264, 0.02725646031209298, 0.041542829900619485, 0.053713917732238776, 0.05612719428515243, 0.046735458121064215, 0.023258352772362774, 0.11448165131432396, 0.11967517585764009, 0.08827443459942456, 0.13627976389421573, 0.1938153418802446, 0.20686240145756354, 0.1623283927479098, 0.11879897045512354, 0.16698110518195938, 0.16488738688490084, 0.1285828785189698, 0.11803335750535612, 0.16208105360067662, 0.1670510336876877, 0.1383682115063552, 0.09706816636025907, 0.1525692599675348, 0.09873724978176818, 0.11736313016304087, 0.18457288943952133, 0.18100733237881816, 0.14514147063657162, 0.15710252397243055, 0.1279437313637426, 0.1815418625671056, 0.24784003083984701, 0.15774527174090186, 0.1255634502177277, 0.1582360583087129, 0.07282945087119456, 0.137156245088385, 0.41718418018952497, 0.14680720625385163, 0.12353962212200127, 0.15827796331817107, 0.2759540940244352, 0.1204602780842012, 0.08463643626460145, 0.1875681553276316, 0.1877400194925647, 0.11710644474313145, 0.19924972446695452, 0.12524757684478838, 0.1298479501518511, 0.2880698971209988, 0.09832883298757578, 0.36634876122397764, 0.21620217770818742, 19.19523435254251, 90.96887988428917, 121.06368080262216, 101.40121567633845, 86.85494899749757, 99.5016824045489, 77.49146692214474, 58.48094678694203, 43.53726163987191, 54.23511443599578, 59.17130747149068, 80.4334955830728, 71.13633294259348, 92.09597295330417, 87.19515185202323, 62.93673184610183, 58.43361162370252, 44.980219256493356, 25.066944053096158, 18.690409621884747, 11.206612644657012, 7.401054088146457, 2.8528381307278914, 0.4931507151453726, 0.25760466413151833, 0.4345599123306813, 0.21159383708671217, 0.24063704234938468, 0.22736951798921634, 0.22971632109294016, 0.2350360203173853, 0.7370129263689442, 0.2591367174060114, 0.6386322215680154, 0.3856447999996524, 0.3997546686760841, 0.27324640222134133, 0.47093952795670885, 0.41265074764528586, 0.2357509642118408, 0.35497324421040477, 0.24152677686464405, 0.3117080916079783, 0.31995947142281844, 0.18395148488062044, 0.5294113113514839, 0.4937545456472905, 0.253542636130606, 0.18652318075539606, 0.14250522419329614, 0.20843444452170404, 0.36879874104934357, 0.3788253917328773, 0.5219597273295926, 1.0709056065928553, 1.786289296803936, 5.390276024418493, 17.535063720518544, 31.027365999837077, 65.10552798548053, 87.32994018062469, 67.62923978990125, 117.43098551227202, 112.24357251198062, 73.88070552579819, 77.0350520841537, 69.11683790145382, 46.31805735249674, 48.81874876637613, 61.12785631610502, 73.7602730720274, 94.79448518445416, 83.90297320581253, 96.45237691940801, 109.22534004334481, 111.07400801873978, 80.62722144588348, 32.4407862078759, 1.3640300905512226, 0.7056003184087816, 0.15057349367247475, 0.12471839395021239, 0.2147036177977439, 0.25196843269851904, 0.22569359340254339, 0.08149339967677671, 0.11925496897029302, 0.12470605227375224, 0.1536569362806697, 0.1281166910344074, 0.13180453871046344, 0.18374770549276184, 0.12029736182622372, 0.21666069665262777, 0.12076263000527698, 0.16173413834504544, 0.17768407360680644, 0.18823564773605717, 0.17977422193413783, 0.13744271600679045, 0.13351029476090787, 0.3061640358740284, 0.15193683906428276, 0.18070973786375216, 0.12315561288907645, 0.2341653001044066, 0.26936727005147165, 0.17305417527114192, 0.1276585934383254, 0.2102528001752592, 0.08702771077232976, 0.27072257152007473, 0.1770027762939853, 0.154738376638101, 0.1089844954830985, 0.26409229504004605, 0.10607863205575174, 0.15936300428884645, 0.0914775478022714, 0.10158859839242312, 0.16251893413643684, 0.1435065164320892, 0.20645396934161264, 0.17461520199093128, 0.17742515121015812, 0.2351088139919504, 0.12137236704509105, 0.08822416390983329], [0.05277096691931929, 0.02049826438568773, 0.056344717290372624, 0.022342464015368494, 0.023958817605049382, 0.023930480012730248, 0.02097274094159084, 0.13989850277862242, 0.016033889879772983, 0.06907512208506947, 0.05436494308073194, 0.06252872074143061, 0.0127862190880302, 0.006378066450011947, 0.0349819801387287, 0.06019783694477332, 0.05485684813691243, 0.10161358051963391, 0.033120815491964745, 0.03442893360531138, 0.11026986078509401, 0.07228997175491626, 0.052668192393837444, 0.033972521402662804, 0.12952941079293528, 0.006857215184643264, 0.022531703054424257, 0.04487230164569713, 0.06655335982119845, 0.019084493171483762, 0.04222447961388577, 0.03960816677840006, 0.07951831775567225, 0.05758845337456273, 0.0426810450341192, 0.03817180171608925, 0.007896048604555788, 0.012739085528488844, 0.08207024090112218, 0.0634121465226335, 0.027894557926863916, 0.06096945985430672, 0.10815990908491997, 0.12734001577501336, 0.32983023853551957, 0.19851421877261133, 4.058933373420469, 44.35622507526029, 89.76322174072267, 91.74370488812848, 63.88543944205008, 81.5424829913724, 58.366193925180745, 68.95511073450889, 50.32478594010877, 32.36174652653356, 59.98397550275249, 55.74108100706532, 68.27761542412543, 65.29910087585449, 58.29219056713966, 42.16675804507348, 32.60285069865565, 16.469612659946566, 10.21630144888355, 2.7103472477005375, 0.6725730422523715, 0.07608414477398319, 0.21281432240240036, 0.01910377943497752, 0.08996647767602436, 0.06162331972811973, 0.10797700559299801, 0.1774488080052599, 0.29876730374751553, 0.14586471892412634, 0.02100294778844522, 0.30822472045979193, 0.06732447328226221, 0.2545510683088534, 0.10511902266091878, 0.16670016541836724, 0.14277608223980473, 0.06908288255574242, 0.06795598254088434, 0.02055799817636369, 0.04179215321557657, 0.03610467816132211, 0.007126062250350632, 0.15367713035835376, 0.018387282297255534, 0.1396315977458031, 0.056122609248925606, 0.1330224040054506, 0.06540394448224576, 0.18487258303549983, 0.1603168450416096, 0.013520081523775816, 0.07368499488239327, 0.020785512883336316, 0.15049418825055325, 0.06300279510117347, 0.09881717573490836, 0.03265229143923329, 0.05307558263021131, 0.078904505128101, 0.10962568809308353, 1.4217098922498765, 9.607070088386536, 21.67794366036692, 38.44888848643149, 47.94356599930794, 52.18495822721913, 41.238470308242306, 56.17111790564753, 67.29783088930192, 40.1422776714448, 35.45958349781652, 27.20871113961743, 36.51010797869775, 56.777598704061205, 65.87526567520635, 58.69168789156022, 69.34854015227288, 80.32917622596987, 84.72678076836371, 49.41124239275533, 5.295955279181081, 0.25853258046892386, 0.02263889216156977, 0.05584651882189417, 0.05495086244698014, 0.0176004410511063, 0.019121813144715085, 0.045615211579828494, 0.03265429092871566, 0.024673824701758645, 0.07337717309353814, 0.04700767980407804, 0.044778226048595486, 0.076294366961285, 0.046781136113549435, 0.02634801984494252, 0.036241551260313684, 0.030877888165113908, 0.03653762126041036, 0.023436715278113564, 0.027032090396049525, 0.10448183669077774, 0.0524678067754834, 0.1813470310862026, 0.05972086294223705, 0.018342678743084113, 0.023719957135918162, 0.0409385665590244, 0.04416164784361759, 0.01898285820178928, 0.0438028812077978, 0.05048558491492464, 0.03575488624553527, 0.023230279480377515, 0.0004237093455759028, 0.08326048872643903, 0.041307043359284444, 0.04624287124663111, 0.09164568877989247, 0.048202336465399113, 0.05341845294160228, 0.09157390634138739, 0.0023085116352435323, 0.016984686390647007, 0.05631428061714096, 0.03143227535239872, 0.032429191313924334, 0.04638086666443175, 0.07058598536757693, 0.07042512988611575, 0.043933571977240425, 0.04387363325804473, 0.020075895215174364, 0.020155079978247805, 0.08062814167069812, 0.02207474309890982, 0.10341727325031835, 0.003955054116593073, 0.08804129872230754, 0.05876463582558979, 0.08436458230379128, 0.04063501954078674, 0.02582078664413383, 0.021707861676752087, 0.09134070151635716, 0.09155024188540636, 0.06833747134453828, 0.050544324706518845, 0.013736592335326057, 0.05333857678417718, 0.06996774475180334, 0.10203907341365853, 0.02997544042075113, 0.027891252257470644, 0.10176646102580333, 0.07167998956696642, 0.032730964838617274, 0.033493704958668644, 0.028328391603164138, 0.016953305514048667, 0.02952737091559797, 0.08297465366101073, 0.041138006058791955, 0.0673837301832053, 0.016176478952289592, 0.03030552663990567, 0.019916548926924026, 0.034525939488723394, 0.09179506060336867, 0.021816502520514112, 0.05075501037701484, 0.024228442249999895, 0.039462885864439516, 0.32945522317482584, 0.06073736585676671, 10.165470473227963, 64.46864097349106, 109.68538699611541, 97.99058929566415, 80.17365424863755, 105.87300792817148, 87.83529050888555, 107.21116373615881, 61.83169426456575, 25.815324437233713, 30.190849957927583, 30.267842162039976, 43.400523893294796, 63.18635148386802, 56.27577850895544, 42.27279932268205, 29.634253863365423, 14.096120768977752, 6.611627080748159, 1.5130674093961718, 0.45010926021683606, 0.03359428847268705, 0.051806718862104806, 0.022067038169611367, 0.04511355039393229, 0.11686290539200268, 0.21474987418661196, 0.4007793878836017, 0.3794451262201033, 0.12473463501420715, 0.15499714581716448, 0.296520306578567, 0.10577653294369098, 0.24584863124595535, 0.12391989284585561, 0.10849245253109163, 0.07519465540685961, 0.06570937607677714, 0.1289902227900682, 0.01558466262424425, 0.081792549350329, 0.31114863291863476, 0.3812482826892407, 0.15383480657492915, 0.2833324400407653, 0.05000776821567167, 0.16017652837739838, 0.11567766778171064, 0.0799677815408476, 0.19596807959098972, 0.2384621340541109, 0.048632621239390106, 0.0710495375096798, 0.006821616036411856, 0.17134483392921188, 0.06783896261045048, 0.05019122329089911, 0.046884960179487546, 0.04189385904840404, 0.24017021901184515, 0.212464404082106, 0.045151900755421776, 5.227444710270052, 15.655742422226938, 32.447318915397894, 48.30593416767736, 56.596247919144176, 39.75377475061725, 45.17656918494932, 41.8864772396703, 31.679499264686342, 40.245349714832926, 42.21651331070931, 65.84471825630435, 85.40028310591175, 94.86060850081905, 80.4813406544347, 84.96685335713049, 91.99761559886318, 99.70977983167096, 69.39631462097168, 12.966011397300228, 0.14133367657421098, 0.04815313063802258, 0.08904236879560257, 0.050371265444423885, 0.10325533758488395, 0.03568287781109253, 0.0748597217663642, 0.0652650680633322, 0.04924130107786867, 0.11741494835023919, 0.0899566411070766, 0.07984554455164941, 0.07504608031482467, 0.008219032709847295, 0.031130099631545526, 0.05107187200337649, 0.05115982272752351, 0.09679848808915385, 0.06723082669439816, 0.0791113795111737, 0.0443532042986443, 0.07815613681750913, 0.1292266068799842, 0.025093834321465225, 0.04635923234145007, 0.03977477174973296, 0.07908777634222662, 0.011392516504612663, 0.0494870888970552, 0.05747821332225877, 0.024968657469857606, 0.035965476155040726, 0.01364769357737274, 0.058322603093279954, 0.05180094638959535, 0.058465574252148794, 0.06899010164723282, 0.03343896031559956, 0.026166001184573098, 0.031107017402386958, 0.04048398530651485, 0.03226365120480618, 0.05038197535360533, 0.01707601173210048, 0.05004971919040527, 0.004288339471038912, 0.029165637604291403, 0.04047796768586963, 0.11246091055293238, 0.1460863328388622, 0.10868064969057038, 0.1578481726708912, 0.1335711527856127, 0.19665378957025467, 0.07809629002886434, 0.21538309182130524, 0.14883409104039594, 0.18158836410410945, 0.18460950844230192, 0.2978927990601909, 0.17394576371917803, 0.10021307220261905, 0.07188005342839227, 0.23783196544935628, 0.20498265151775655, 0.17478023265157977, 0.10317129773959037, 0.18043714845853467, 0.16126163063510773, 0.15545862186099255, 0.1723850281127999, 0.10604512336994372, 0.19963310550778143, 0.20819072130947344, 0.16662763221369636, 0.2825753306669574, 0.1440244991212122, 0.15813000109647551, 0.14080936599883342, 0.1242683326164561, 0.17423107018393857, 0.22521731654001823, 0.137148262452214, 0.07865385648103491, 0.1793206519176883, 0.0918820652089292, 0.19685571502533653, 0.1495064098027445, 0.15841140051282224, 0.190387083097331, 0.21353012431533108, 0.20263005678932514, 0.5510342349448513, 0.2722877504364137, 10.928723504466396, 69.51268349924396, 118.0502022466352, 114.30007119332592, 80.88617632465979, 105.10064617280038, 77.98739571725169, 91.66095856697329, 65.07154064793741, 47.601080325342, 84.99612208335631, 82.55374846919891, 97.28915968248921, 87.1418389966411, 80.53084096600934, 58.863860330274036, 47.69085553384597, 26.55839981571321, 16.871167267522505, 4.6109363725108485, 2.541637036108202, 0.33595970801768765, 0.6661009476069482, 0.09497758136281083, 0.23740421259595504, 0.2263311317731296, 0.49183843717459713, 0.9585932558101993, 0.9902918290707373, 0.3963577122457566, 0.7117026070913961, 0.8389246836304666, 0.5560185868413218, 0.4794157392555668, 0.35930341830657375, 0.30916593608356296, 0.21164039991074995, 0.24501912656330296, 0.4041100010996865, 0.14552005596699255, 0.18652468228772764, 0.30887025678830765, 0.508813198896185, 0.6045014110784377, 0.5398053471599856, 0.3880990699173943, 0.5151973772914179, 0.5634389757629364, 0.37360192847348034, 0.6965479170603137, 0.6982760275563886, 0.42174001314467, 0.447416645024092, 0.11089730977771745, 0.47667479923655914, 0.2780397530765303, 0.1204353649049036, 0.1305878378691212, 0.2674528163286948, 0.33820220058964146, 0.8066448028529845, 3.1074568292787, 16.96086402862303, 35.635035037994385, 58.18083055557744, 71.83591904178743, 77.16346263885498, 60.2462879303963, 81.86755334177326, 90.04141192282401, 53.921313055099986, 49.497428632551625, 41.21246107162968, 50.15315086610856, 73.81220525310886, 87.67383006311233, 77.1475221264747, 87.65202168495425, 103.76965261274769, 112.15611150187831, 74.71497797196912, 12.456582784652712, 0.20156488813940557, 0.17278779117811113, 0.19942387157390196, 0.09856646580080833, 0.2211469535024897, 0.1846410559430238, 0.1701991647602089, 0.13491030512077196, 0.1569655321298107, 0.2156325760147264, 0.18107347641020052, 0.14037874797659536, 0.10320240090931616, 0.1372213165966734, 0.10154738286209684, 0.26130431722248754, 0.14522203244268894, 0.19314610279135166, 0.1602334793536894, 0.20702593058588045, 0.21088401065959086, 0.21618821958620704, 0.438716889268929, 0.14046980518727534, 0.12336842445356232, 0.1281260526288421, 0.2680301095449156, 0.11633088031122762, 0.084923857132033, 0.14293548981508902, 0.1369959028858331, 0.13601351769701128, 0.08916755522330923, 0.11231310154882171, 0.2116240515944458, 0.11352538206284085, 0.14764850869053794, 0.14077038744524603, 0.13253224562973748, 0.12454687452484524, 0.0742515015806402, 0.10576599157385289, 0.13293548366956173, 0.19723246174473918, 0.10389491374934874, 0.08922983817155324, 0.1405571545324018, 0.12124334251688373], [0.020289442224067547, 0.030144108083820155, 0.017198145299428896, 0.07095654975743064, 0.028065334246944518, 0.05746700162548692, 0.09062163606886903, 0.008655946059603124, 0.05544816842302681, 0.03102608978928578, 0.01872495661730007, 0.02582537551080027, 0.03662220885856979, 0.03134804973078351, 0.042084408097810326, 0.019060003255764325, 0.04037300597936396, 0.044621576389838616, 0.022288952773857503, 0.043510480768858426, 0.06264709664749042, 0.05313934412814918, 0.030153036838577642, 0.058615122275847586, 0.017339559384591637, 0.06728181750663827, 0.04959963487401124, 0.04879118611795768, 0.05260208283641166, 0.016247209935118596, 0.040931510889241775, 0.08747929662105539, 0.052789119372685114, 0.027330466320798285, 0.1370627517181058, 0.013837670933665528, 0.01643087568452522, 0.03499173626844441, 0.10212737270781111, 0.06727290790407889, 0.07411053374169335, 0.10185899678617717, 0.09006951650184009, 0.17817348121635376, 7.348794389155604, 30.179529997610278, 77.4226136361399, 94.19611976992701, 70.90394819936445, 69.2100412614884, 82.45684239172166, 41.05561725554928, 34.35207874544206, 20.370411757499944, 40.773724356005275, 67.36680969115227, 68.50127681609123, 62.27176458604875, 61.91212638731926, 39.626074144917155, 26.20287618329448, 12.091336577169358, 2.4092612103108437, 0.6209669694785149, 0.2307600239592214, 0.06497380143452076, 0.18987699111382808, 0.059630131318924896, 0.032790834609899795, 0.0719368665088569, 0.07347602907928728, 0.05044153868971814, 0.03957513689754471, 0.18352414571469833, 0.16135644167661667, 0.16345567580673004, 0.029543859042948293, 0.15002557226727087, 0.0504051112089186, 0.08746631909161807, 0.04068465054696126, 0.21011856624916678, 0.06947095205466594, 0.21332222337443985, 0.03940345659371346, 0.09856453525923914, 0.025683356216177348, 0.3382005151962081, 0.3178112076655511, 0.08373881870460126, 0.058753757377065, 0.08648893645694179, 0.06200316527317609, 0.07566753083900099, 0.21209847452419422, 0.06967276259655915, 0.05372973744787517, 0.05720717907552758, 0.08189375722600568, 0.020453205009201364, 0.061958299333890604, 0.07591301605345742, 0.0985736900099343, 0.10134076128803915, 0.06388836975900397, 0.07709842986397206, 0.04808328640196593, 0.1602951034663185, 0.2557948120539227, 0.2328752846487107, 1.3677847793986722, 12.185317547090593, 34.558481708649666, 54.434539502666844, 50.22651880018173, 55.155828076024214, 69.6113467985584, 57.32937420568159, 51.44539533122894, 24.474891693361347, 26.19984615233637, 28.175767583231774, 37.3903113795865, 58.12841984533495, 65.19569543100172, 73.88009363605131, 82.53092027479603, 77.69680300066548, 32.48208288223513, 1.5132006474079625, 0.3379881249800805, 0.044231748719128876, 0.05550789263760371, 0.06153353039295443, 0.02453331268512674, 0.046771786010433594, 0.10519016924644671, 0.04739125236688603, 0.03880539856430504, 0.05411415270739987, 0.023739599630296714, 0.01501479950327907, 0.02828041151646645, 0.00962366832555422, 0.04074473865330219, 0.01916884136716685, 0.06551494296159475, 0.0024096563086664726, 0.08249437781952082, 0.05625110900690479, 0.017514608560069915, 0.04063889594568361, 0.030107075393560435, 0.0481499666948953, 0.03372243583022106, 0.026829207331062328, 0.03758888158406462, 0.0627363114167125, 0.03932493641191433, 0.08545729947546798, 0.061244336031978173, 0.053645437132687344, 0.06443992242096894, 0.016201541518732425, 0.0770667061630276, 0.04651370248006237, 0.01781493417858597, 0.023018488728050745, 0.10573759269449981, 0.018677658348854993, 0.0502314543982427, 0.033164995782558, 0.06447494029998779, 0.005807289769197064, 0.03335796183936539, 0.05568263346269246, 0.042022014066817305, 0.07236433590972617, 0.041909479581180124, 0.03639437047944915, 0.015063505458285012, 0.038485916917242353, 0.06026295441833716, 0.032134898637811986, 0.017590866867272605, 0.04170242516744522, 0.014824958127592842, 0.06324978567840112, 0.035848264702625816, 0.009513309529621997, 0.04910919304576613, 0.018141601730378407, 0.06898630185112839, 0.044132379454470454, 0.059483513581536474, 0.05690611035172498, 0.019695725997969992, 0.03861867995452016, 0.07360700713170153, 0.07037146542701991, 0.019521429503877318, 0.05998329402157857, 0.017751682129117752, 0.09097183018081612, 0.04500750850345339, 0.04539563928941085, 0.005404429506480454, 0.09142310959437201, 0.06539273661591354, 0.05422758351590845, 0.0805067933434921, 0.029264162257013303, 0.012972430164565243, 0.08037561610821756, 0.06895046425803054, 0.017649731148154508, 0.13438671466804322, 0.09027785411284817, 0.11613777252815424, 0.08904778503722723, 14.392722556667945, 49.64199150762251, 101.34842841855942, 110.31392328200802, 83.74096362821518, 95.07693506056263, 113.96138237368677, 64.32246992664953, 47.543456785140506, 22.357819849444976, 33.64800545477098, 37.13007388576385, 55.268125534057624, 62.591335773468025, 61.10831506790654, 38.33621840323172, 24.934673886145315, 10.567092741689375, 1.4051547934932094, 0.32853368068895034, 0.1286217344984893, 0.07602569992623984, 0.0792667268204593, 0.05826714981888091, 0.09412303326591369, 0.07552899149877411, 0.09285543354288225, 0.025101052784931757, 0.20740192653911732, 0.1272964406938803, 0.1648720038393813, 0.19632178238563, 0.1806330371407732, 0.23746916153017553, 0.25175173706825704, 0.1296128837331649, 0.3342001572732003, 0.3404062049042794, 0.3070160175763792, 0.784748416514166, 0.3520803736342538, 1.100218582057184, 0.27029668792120876, 1.014424947000319, 0.4432266956615833, 0.8057887455628765, 0.2102760126393649, 0.49934643591123246, 0.35753623732636053, 0.16451545119766267, 0.5116116874400647, 0.10653266172495582, 0.08301945448282265, 0.0290752737031829, 0.1017684605152857, 0.2880994068278421, 0.03443959371877774, 0.17306471664098003, 0.20226003632189768, 0.06397509474247214, 0.12531680054962635, 0.08371923749725665, 0.030071184174307895, 0.04570432675762042, 0.42568665298242725, 0.2536403276627102, 0.6797740848795061, 9.783181567345897, 30.1957215416816, 50.02502272205968, 55.328086806881814, 54.84207376357048, 43.45742571738459, 34.8712162048586, 29.825732208067375, 27.699674214086226, 42.02031635469006, 51.885465652711936, 65.6173227679345, 87.23803904748733, 90.24532810334237, 90.5536420883671, 93.36034113360991, 98.09074309564407, 52.19943177315497, 5.47886569653788, 0.1469161746002013, 0.077814775699329, 0.06737257594302778, 0.038527925348570274, 0.04794770033068715, 0.05475872376513097, 0.1253813664398847, 0.04164663481435949, 0.025882521839511972, 0.03719859043016069, 0.02248584503127683, 0.0595109012248295, 0.07853142796985565, 0.019201658658623215, 0.0718492413720777, 0.07603770452401332, 0.03615082346744115, 0.02599957624390241, 0.028021979416089676, 0.04039351798353657, 0.034140352114674546, 0.07545305686371942, 0.021690707052907637, 0.0454644991024848, 0.04154497494680747, 0.01965336325097709, 0.03472766193050531, 0.03306737319836694, 0.06545683519253809, 0.07102373566839003, 0.017327575854236082, 0.025077055080703674, 0.01644207972041782, 0.02832189517756624, 0.00858805534775339, 0.05094975758824618, 0.02761771864888649, 0.01358041956630205, 0.010808598543066653, 0.07548416769432445, 0.015952692220678494, 0.015446232451546579, 0.039181275773913636, 0.04327425755740654, 0.021601978749517473, 0.032340853715375546, 0.07157675155829038, 0.1593689491311389, 0.15938143636430466, 0.1454617566759548, 0.10216154022923402, 0.164794598315512, 0.16776165684625027, 0.2426855461371522, 0.13873627078869652, 0.14949622083335154, 0.08758397487502906, 0.1942612663392098, 0.17966549873592394, 0.10424415791226972, 0.19877038325273222, 0.13848157719739024, 0.28111728148594983, 0.11344184017469806, 0.15258620583241986, 0.09957348071639577, 0.12038892465493373, 0.1679353902657186, 0.26861950695034, 0.21675294896046962, 0.12200271185006827, 0.19562228282372798, 0.20403071066304562, 0.26027573693183165, 0.14848683870607807, 0.16034704422758472, 0.08973468245277483, 0.29248863098121464, 0.18279662265652613, 0.17734060574683452, 0.19019796663234312, 0.2906660465223174, 0.13961800734602636, 0.11873666452424181, 0.2673334904736088, 0.1943959292745398, 0.2546932695493583, 0.28398750650305904, 0.3114530149727099, 0.2806415102414547, 13.795209277060724, 53.40361510553668, 112.11806451120685, 115.95957110005041, 92.27013403369536, 87.41822488846319, 103.65452320344987, 53.04780906246555, 46.321677700165786, 29.772617432378954, 62.0820983763664, 101.89711309248402, 99.27312589460804, 90.30384202157298, 86.71828577595373, 60.013656077846406, 39.52708136650824, 21.800360833444905, 4.305440120158657, 1.1729921544751813, 0.4746230012707172, 0.19244340098192617, 0.37836325685343436, 0.475584686763825, 0.22277804662383374, 0.40435567017524476, 0.4496874828492442, 0.2362231654866088, 0.4075215744876093, 0.5888153011760404, 0.3355023535268922, 0.42502867538602124, 0.4722321021460718, 0.41328693770112535, 0.2678496192299551, 0.3143089907544275, 0.2532474011663468, 0.4240843341235192, 0.20671885190231187, 0.602127948114949, 0.19289954505380125, 0.6739515715068387, 0.2006412006073421, 1.51414888039712, 1.0843652198391578, 0.4547606090143804, 0.22414035013606473, 0.5176465910288596, 0.24358971374890498, 0.39288999993474255, 0.6941317370341671, 0.3091751291386543, 0.12675090948300016, 0.21581441464443363, 0.18411078520359533, 0.4099899710666749, 0.3308083489537239, 0.3334046822161444, 0.49472401459370896, 0.305434076656257, 0.3387724151534419, 0.3271443342729923, 0.1291811319007989, 0.24198154197825542, 0.5867419608177677, 0.6164590629839128, 3.0418527366653567, 22.41213683159121, 54.157447584213756, 82.33900654700496, 76.15688047101422, 82.18651263944565, 99.18641013483848, 79.03550794047695, 70.61838396133916, 35.72316285102598, 37.5365569514613, 41.74851179122925, 53.35340484496086, 79.91262835841026, 85.71071517082953, 92.67915879526447, 104.31738022835025, 108.12342074609573, 57.17075355591313, 5.016721746613903, 0.401985394137521, 0.20976587469058655, 0.25076113941688694, 0.14671734414033352, 0.15859660992939628, 0.179783629493848, 0.23028989112184894, 0.270161182289162, 0.10213597587520078, 0.20003373884866316, 0.1579056905522462, 0.11774186871104664, 0.1720568666895551, 0.2456122165125224, 0.24518458623318906, 0.17420468611582635, 0.16755605416913188, 0.08535190109884547, 0.14905054152252215, 0.15843053738917076, 0.13271642848849297, 0.1625554152433911, 0.14649413676271517, 0.1225543641034634, 0.11063640321334524, 0.14103997378580033, 0.15444285056043058, 0.12309503831690359, 0.154948131511769, 0.2968729215283548, 0.21259678407542168, 0.18829224631190303, 0.18293965127198927, 0.14609341149128255, 0.21112733550610083, 0.10857312925039761, 0.07099139909710615, 0.09098732813952431, 0.17180929771594464, 0.14655453513466543, 0.15393508748421747, 0.16715859243225667, 0.16498575257437845, 0.1475946067441856, 0.15394512323602555, 0.154822998710217], [0.04189612666865991, 0.03771897863536593, 0.016606627745674025, 0.012145630729895447, 0.011162170145149914, 0.028970200913928212, 0.08425949802321774, 0.0393685651192021, 0.12478283726640287, 0.010346056679413925, 0.04782373198278008, 0.06855430487062662, 0.015395732893187915, 0.02935469469746515, 0.068281332421447, 0.07087621777769058, 0.039569766621195504, 0.016062870028338606, 0.05248235478516548, 0.05968710527785363, 0.07376853677053606, 0.03979231133275936, 0.031793464741279046, 0.019162705002893365, 0.04831999224881011, 0.03328056014593571, 0.05977041733961913, 0.06414728832521266, 0.05418650588140853, 0.03867545090014896, 0.01925815381259928, 0.029406104942843802, 0.03981310678946395, 0.014569840315098484, 0.029083744720405633, 0.09747200960954351, 0.08720852284421844, 0.03573055912349974, 0.059598434431057785, 0.18245856337729963, 0.0490672918667476, 0.11752254539920438, 2.71608371407755, 30.610459235406694, 83.81146430969238, 102.46013010701826, 84.9017341675297, 69.61652432718586, 63.07862358708536, 48.199108416034335, 35.008036321209325, 32.701331607757076, 53.159945703321895, 61.46783167316068, 45.60760628792548, 52.73649054188883, 50.760047435760505, 37.12581419175671, 11.435729072939965, 2.8160340411047784, 0.2714550741497548, 0.12166657545153173, 0.08923100262519815, 0.09333047700384933, 0.1633014469858139, 0.05005802358350447, 0.13261092285956108, 0.028822355520641132, 0.14392352873279204, 0.0580505193060925, 0.13409537143043934, 0.06684284912602556, 0.06273348838271153, 0.08397390044504598, 0.07798233445012763, 0.212474531764465, 0.05226624521216559, 0.12052793130879441, 0.06845630690335266, 0.1180908217605564, 0.12138857746556883, 0.13385857365304424, 0.07501524527587237, 0.2916979669563232, 0.5900399386882782, 0.26861570715423555, 0.3670332761060807, 0.8690111627501826, 0.25759259058583167, 0.06444780546570979, 0.3025985401003592, 0.21933825055678047, 0.08989273405243313, 0.13895630656230834, 0.04971466680628158, 0.0658076958009793, 0.0924606454528628, 0.11380984583088469, 0.05151805693223592, 0.04762873579297335, 0.1363597587952691, 0.15672153312592738, 0.024850294970336462, 0.07496717325862377, 0.0739113278987427, 0.12645906062736628, 0.04351344935956501, 0.06516590564241333, 0.14711198667364736, 0.06034263139290195, 0.0829557466110395, 0.3399178391743091, 0.21599709597085753, 0.845870343187163, 13.162155401322151, 34.895381927490234, 66.82494209658715, 64.48477760437997, 69.70044735939273, 73.63047399828511, 48.387656750217566, 31.08809997958522, 23.947264263706824, 29.62401059366042, 47.178750884148386, 55.7855999085211, 66.29513186793174, 71.35771935985935, 86.0932090205531, 64.85865400683495, 18.222457132031842, 1.1786192847836403, 0.3047954044755428, 0.08122452579799198, 0.061916164498055176, 0.1467086260597552, 0.12615585834869456, 0.015194619491305805, 0.08100498032065169, 0.09924793931385202, 0.07481465281377878, 0.049751396891811205, 0.048059537676313234, 0.041684617453645316, 0.04757300289648195, 0.036030800472344124, 0.0822091096591565, 0.04365093532889601, 0.03142765967265493, 0.04509042219949826, 0.04182926634506833, 0.06249153866402565, 0.011419365971138882, 0.05939071735126838, 0.035013133104169564, 0.024737063344688188, 0.09387559452725035, 0.09013094909248814, 0.014317872081582826, 0.05843766566906726, 0.016376037195685412, 0.06590567078561553, 0.027316266881121744, 0.023706397379658396, 0.0625726941882843, 0.09227629405476394, 0.015632950103721552, 0.002067987558304242, 0.07108007377434163, 0.03297947610037462, 0.08200185223212166, 0.021382862281414772, 0.011287143025847693, 0.03485757129026517, 0.03284370233755439, 0.07352259190332505, 0.01568950175668203, 0.00946131322698127, 0.09716070978151214, 0.03498769898508345, 0.05712753657491938, 0.022013050038367513, 0.021002472813932166, 0.039905182897083225, 0.0860783209904067, 0.009032520409222812, 0.05644476454284403, 0.04652619737410738, 0.016767125081030593, 0.04742792499582133, 0.05023410123202109, 0.012715621212978038, 0.02768466707258936, 0.08220770771825507, 0.025479348917161266, 0.050089249327298135, 0.0607521475232657, 0.019153988837534865, 0.031019681463799173, 0.030276066728777466, 0.024206286987229705, 0.028810257077096935, 0.053553345703309586, 0.010654572735450441, 0.05052990310134427, 0.045511690118620475, 0.041454798737240416, 0.01831008361712579, 0.03462349312500127, 0.07769897384869476, 0.05529417708936719, 0.058910633031759536, 0.028306257407811862, 0.0392700577034585, 0.026370131057657065, 0.21971015560050167, 0.13113997275790862, 0.05872350839537479, 6.154471405090825, 47.56051125064973, 103.27388855718799, 119.69411465429492, 103.39451712946739, 99.2619392948766, 98.31320424233714, 72.92212532412621, 52.451153801333525, 33.137956127043694, 23.277994163574714, 29.152500514061224, 33.56927171830208, 51.001673283115515, 51.3615664359062, 38.7468199576101, 10.746778480468258, 1.578297773676534, 0.1976056078508977, 0.15035918823653652, 0.04215058277270967, 0.03646601502212786, 0.1911326092217238, 0.03970836341801671, 0.3205562539158329, 0.04287702181646901, 0.5247939462142607, 0.23128718438167728, 0.15963675814770883, 0.42323719409684984, 0.6910859553083297, 0.8164816169488816, 0.9691859841827424, 0.8113270709591528, 0.6292106884141123, 0.5096929436249118, 1.104870145359347, 0.7990963853174641, 0.9900725440632914, 0.9832979979053621, 0.867298741734797, 1.6292841732501986, 2.1912208199501038, 1.6068690534560912, 1.300603648827922, 1.6206053163736098, 2.9751243947013735, 1.7114618733044595, 1.8734992752152106, 2.6409759636848205, 1.3295099235350087, 0.630557899994235, 0.1566033410809694, 0.5097747005281911, 1.0533038478705192, 0.7759889671879431, 0.3241394309987945, 0.4413855718749185, 0.47746521811331477, 0.8237418015637706, 0.4530512217071749, 0.2727219690718959, 0.07954353737013956, 0.20098056223603988, 0.5802338906834202, 0.21534066587205858, 0.17666704592204865, 0.10158668317261244, 0.25322538379940296, 0.29956725275804924, 0.3943260777140818, 0.4924916650258726, 9.364146917097031, 29.97485483846357, 57.875795672016764, 51.42118254015523, 38.92670377608269, 20.836575646554273, 21.13293032492361, 29.89638782316639, 34.183871822972456, 47.390500037900864, 73.00389105273833, 82.96429511039489, 93.07722445457213, 84.60638753829464, 97.5809447996078, 85.40476245264854, 34.8792217623803, 3.0996785240788616, 0.36412557406771573, 0.05967836038419797, 0.03539663288862475, 0.17887843532427666, 0.15419906606116604, 0.0776688589323913, 0.08272802697554713, 0.07899990605731165, 0.08267440082084748, 0.008541994311306025, 0.015196507898039155, 0.10857931157994656, 0.03787079427932059, 0.04185000817561823, 0.03667671601438234, 0.027104577635444944, 0.01680795182173531, 0.04920405388299016, 0.031532916323011445, 0.06350814500042508, 0.006232813306738653, 0.024048233472351587, 0.009710144330447, 0.043700378643529075, 0.030715075329006202, 0.057611516451523195, 0.06430001178335759, 0.011412982543509816, 0.02798416340092738, 0.013547498852975908, 0.0159204782234625, 0.02200228267259175, 0.008282910078583706, 0.0436506288937263, 0.053471738187175606, 0.005096041291366302, 0.07043710384037226, 0.028201862606370164, 0.06103258932970705, 0.003316221536219781, 0.048539495591314576, 0.037512460483178016, 0.03075039006709572, 0.07166400131198668, 0.11087465655779648, 0.12880616250538057, 0.16054248857882716, 0.12413459664751446, 0.1588615690988879, 0.07703995437271173, 0.1790831493394029, 0.2394223333366456, 0.2529321253419884, 0.1362213420291101, 0.1228532839506384, 0.14181379919811604, 0.10464007215153788, 0.1709926020233862, 0.20960027712487408, 0.19609859032977014, 0.13782007559653253, 0.1666671010635553, 0.09875369768950248, 0.20064774299821547, 0.21399403651875837, 0.1778181389935555, 0.14781056693004024, 0.10137612390662394, 0.16815075290299233, 0.12608679552232066, 0.16512516525483903, 0.1472447343891667, 0.1567922123978215, 0.08686738389153635, 0.09535548487497915, 0.09641437926479886, 0.11463815541637522, 0.0848555067674287, 0.14099362546638136, 0.24647598064714865, 0.22844545783535128, 0.08119297063639087, 0.08439495002910977, 0.32597028920727394, 0.2978073036478412, 0.1767403452146438, 6.634849963649628, 53.51247656729914, 115.9687102225519, 128.41530076919065, 105.65407691463348, 89.47048741002237, 87.09774371116393, 65.40434198994791, 50.4639712456734, 48.437953302937174, 75.13403615643902, 89.53990551733202, 69.50745105743408, 80.8940367544851, 70.69883177357336, 55.694075322920284, 18.44014867659538, 4.708597015949988, 0.8388565324487225, 0.2976206846294865, 0.22641967621541795, 0.2909179975188548, 0.47965227656306764, 0.2815648300513145, 0.6448989433626975, 0.18043625979654251, 0.4916574259198481, 0.40512525146045997, 0.25713584896537567, 0.37379927272277497, 0.30175268710140263, 0.33938065832180364, 0.7859813277759861, 0.4801561479126254, 0.4185601660320836, 0.34115865646350774, 0.4524137752671396, 0.4738003147705909, 0.35776324450008334, 0.5395064502954483, 0.43551130160208673, 0.9685788135374747, 2.166195607954456, 1.3942552622287505, 1.0740781911919195, 2.644753206160761, 1.826397002704682, 0.5019070388328645, 1.1789915422278068, 0.8215613314701665, 0.5435684323310852, 0.4400035492595165, 0.27779629033419395, 0.37434868033855195, 0.5179082253767598, 0.5066575806948447, 0.2521893111688476, 0.3187915244169774, 0.629628236976362, 0.3550450726141853, 0.3579422639262292, 0.19727407564078608, 0.33309705194927036, 0.31142111507154285, 0.43119779757915006, 0.48002480979888673, 0.6782321031055143, 0.1972509397854728, 0.4353990237559042, 0.7412667981078549, 0.44667491869580367, 1.8861744144270498, 21.91816333801516, 53.78068039494177, 96.32608444459977, 90.97583032423451, 98.99335891969743, 94.86266382278936, 64.26399523212065, 42.33709089217648, 32.60442553027984, 42.42201805114746, 61.50449014479115, 74.20900006448069, 86.62690239567911, 88.50501168158748, 107.03856375909622, 95.01627952821794, 36.159734418315274, 3.114337156857214, 0.35263324396744855, 0.23410577507269, 0.13753653113399783, 0.24042137327694127, 0.35209005698561674, 0.1384313677948329, 0.18407614270765937, 0.20005059278299733, 0.14482336028689338, 0.09608925921061347, 0.1593476212433269, 0.1635534745911437, 0.12543500791634285, 0.07032599044783462, 0.16080665101687755, 0.07601621575773725, 0.21636590601936465, 0.11866449138089535, 0.1952985034234101, 0.24025088807027187, 0.07564424176610286, 0.15774887235414597, 0.07881481921480549, 0.0863294369511066, 0.18527946765384368, 0.12603811063473264, 0.1419512813370074, 0.09343267313294834, 0.10902502153429294, 0.1467226761122865, 0.12524666520015848, 0.14443222643627276, 0.13921098483185615, 0.1745181846162004, 0.13591326743123994, 0.11539377857961002, 0.08792767256137826, 0.15736909192656318, 0.1799292628082537, 0.0934531583240436, 0.10520937507070842, 0.1804136142375008, 0.1357645850868956, 0.21620652908759735], [0.06756599782215011, 0.04580661098683073, 0.01619783939883834, 0.030841485582171913, 0.024984149682906368, 0.05301163727117162, 0.026468851062799656, 0.04736897069960833, 0.0212833761883479, 0.04148422034397241, 0.003973323398367352, 0.1450404696046345, 0.07728472712539858, 0.15837344851705337, 0.0177013635590312, 0.03267370742715655, 0.015773313690818126, 0.04634924255491746, 0.03209254546691814, 0.043626864846315117, 0.06388613278226507, 0.007933432258845819, 0.01885164074689871, 0.05094909109175206, 0.023224955169303764, 0.02638102482794033, 0.012079551815986635, 0.03301060225273813, 0.05707993570174422, 0.03243932665716256, 0.02431397596674581, 0.005340881555551483, 0.0547641170241179, 0.014733079287614075, 0.09525770907320323, 0.03902497085472269, 0.06278622970585862, 0.022721915025143855, 0.03908774409923823, 0.19692141472572283, 1.9828184285471517, 28.96091038180936, 68.69430449701125, 96.04139881749308, 94.13663310389366, 63.21312166029408, 69.93946090821298, 41.768806134500814, 27.62813214332827, 40.66217999304495, 43.249112559903054, 59.46696789033952, 71.67653745220554, 65.73426823462209, 67.27025662699054, 36.860771794472974, 16.467143527923092, 3.6123421115259973, 0.3272570104848954, 0.0918899405927908, 0.050063405351172534, 0.1566213288254315, 0.10243903259716688, 0.19022370718659895, 0.055055713070736784, 0.04781828509763845, 0.04749877280705879, 0.08178671176034598, 0.03165446191785797, 0.06709445538299699, 0.13253995247425573, 0.028962045907974247, 0.25417873425589455, 0.1857957496277748, 0.16955411872796475, 0.2746097629349078, 0.14860005117952824, 0.45531875003249417, 0.398459060778541, 0.12138931290997614, 1.6166954487562182, 1.6275122425248547, 1.8536936347523045, 2.0647888558526195, 3.219768260755847, 5.072541486832404, 2.308244243744881, 2.269123504238744, 1.9662802450118528, 3.1556833511398685, 2.0181540808370038, 1.1458120903661175, 0.9399990148601994, 0.20351490366362757, 0.5749368523397754, 0.09130232051135072, 0.15172340696857822, 0.16811647812926, 0.06132482122930308, 0.21923965504092557, 0.09680552843717799, 0.15040089406313437, 0.04599696851425594, 0.06727375826167484, 0.1991062361987368, 0.11941539544251659, 0.03578865540123755, 0.05365095679618178, 0.08399237848577962, 0.08719130118768062, 0.07306942025259619, 0.2797154325150675, 0.17131569194457225, 0.014358197992307045, 0.2891815519861637, 1.0831910828428886, 16.068041382297395, 44.591724180406146, 66.96986582971388, 79.02610209680374, 82.67692658209032, 59.55080855277277, 57.33857216373567, 39.57320059499433, 28.3071473721535, 36.39601799749559, 46.222916341597035, 56.91019835010652, 62.338586084304325, 79.24189521420386, 84.20363072426089, 56.612011924866714, 4.329152809035394, 0.16156615058500923, 0.02996672425539263, 0.024578366315953677, 0.1406295651630048, 0.03591751139010153, 0.05574645624766427, 0.09208414388159591, 0.06172213740947266, 0.020942754345014695, 0.012321986085284623, 0.08315155102360634, 0.014898980415666537, 0.08531742714225285, 0.027820099926283284, 0.05514433795225717, 0.031062082515188286, 0.019279307415408474, 0.01752792316819391, 0.02880052201479914, 0.03850508443710785, 0.025783137253095067, 0.07825162201639145, 0.05177367365949097, 0.06524265233066774, 0.05185420865253095, 0.04005247862228463, 0.12043270657980636, 0.05608787865287835, 0.03642424407805647, 0.03281614998535764, 0.11249674814603022, 0.026718166716877493, 0.06788062247177286, 0.07571295985291082, 0.018778561704581784, 0.034203680772935195, 0.004388758754958549, 0.038182297120651895, 0.036294706270939885, 0.02683120873576451, 0.005266703655868168, 0.06381166137514577, 0.08346979926911094, 0.07067739497870207, 0.032190823056284464, 0.022907967138434612, 0.04706124850218335, 0.04223042062573856, 0.08589891085941946, 0.07138392722774899, 0.015076875607783516, 0.038018798635851954, 0.06305240312471025, 0.060862663367222396, 0.044036055389311046, 0.014106048770519275, 0.05650236669387068, 0.023000324783366055, 0.017264164841523575, 0.035347086152121905, 0.04306289389909756, 0.021889937793715827, 0.032472762564617785, 0.0399220023574608, 0.06587600786118739, 0.05205562465914315, 0.029347612214605176, 0.02852172729739499, 0.029524224209448988, 0.03308163775551704, 0.05552662348735237, 0.05226669720404091, 0.08913707258480211, 0.061930287328939286, 0.07729179811693969, 0.0640003947961715, 0.006671104657148282, 0.05126465419908205, 0.10346622626867988, 0.024949258208395015, 0.09881214253724584, 0.08167202073720195, 0.11468206757619498, 5.391541479095336, 45.90053673713438, 89.11304181621921, 114.41881702792261, 103.46828906766831, 84.16847844277659, 89.69644731090915, 64.21200029311642, 37.860611407987534, 34.51387259267992, 27.377677040715373, 35.51364944827172, 60.01631544482324, 68.31336390587592, 73.9210274911696, 37.803078082300004, 15.70913862797522, 2.5462379763203287, 0.18517123475190134, 0.14084213924023414, 0.1686159521341324, 0.17666169862833717, 0.29965069505476183, 0.24927598604511833, 0.06569197055913749, 0.09915396330818053, 0.13022204620703576, 0.24954532723753686, 0.20634723797200188, 0.4111984594454689, 0.8876133097275611, 0.4935843821975493, 1.6831039949770898, 1.276069591122289, 2.017817492446592, 1.7441268818032358, 1.3554123981345085, 1.7096508414514604, 3.925198446358404, 2.4146586368160867, 4.6869435714137175, 7.2551257379593395, 7.332768565224064, 4.0058661564703915, 7.410954640757653, 7.632494520756507, 7.621175541031746, 5.536444619778664, 4.769827665821199, 6.273612908778652, 6.08461203113679, 7.51741070901194, 4.3143340945243835, 2.368389867967175, 3.278749921629506, 1.8026063567207706, 1.6023381030367267, 2.0618429107050744, 1.7093271233381766, 2.535540447119744, 1.6985374184385424, 1.1540681892825713, 0.9016036074007712, 0.7007490206629999, 0.31312271892543764, 0.2887055355935328, 0.7992363649029887, 0.09021108955024712, 0.2993549544724726, 0.19079810459046595, 0.16874345980824965, 0.19036158769121095, 0.1394578336828178, 0.117291922290479, 0.3898335849085162, 0.3067091840409464, 10.926906466484072, 35.80062181718888, 65.02810432064918, 62.049574082897564, 48.43704723542737, 22.98377717694929, 28.976342947252338, 37.772412992292836, 38.62778386762066, 59.813999591335175, 73.44773077195691, 85.10775273846042, 85.02366496670632, 93.8919948762463, 99.22493565467097, 78.23503848045104, 11.233592667887288, 0.1904720728916507, 0.07137647319224573, 0.07185189203629572, 0.06490948835327741, 0.06852753009767303, 0.05534917071101166, 0.05701323242617711, 0.09201063008438196, 0.04045070644708411, 0.012058018999654922, 0.046639789061080066, 0.06096379080366704, 0.055923667706308834, 0.0650843785655114, 0.016080034228282112, 0.07077362328287094, 0.014233407057491283, 0.03136895627023713, 0.01437499925809642, 0.05131464526658097, 0.047004079190833915, 0.07207328378553353, 0.06450331619670314, 0.013019774398285777, 0.037516164518291914, 0.03404056916253702, 0.0422512773694771, 0.03772761244627257, 0.0492101289602297, 0.06794733340821921, 0.07445088362381344, 0.07519464774598038, 0.046352850829040816, 0.05441668848957747, 0.08189962545950567, 0.04344295011833311, 0.0070340167862483335, 0.1093866456780703, 0.05765102743621796, 0.009295974215943246, 0.017120799147373727, 0.08468948785335788, 0.01564571408614997, 0.16262781055223557, 0.10921790715186827, 0.07027155990081449, 0.2291946918252976, 0.16042501665651798, 0.1604149962264684, 0.18605186814262023, 0.11635596202986857, 0.10786865777786701, 0.17521667294204238, 0.07906674722870512, 0.28631258335325027, 0.1423302190678735, 0.21957258153105938, 0.12635313365007603, 0.15219185441251726, 0.1205913404062871, 0.1615341127880158, 0.2247260856412111, 0.17714410419425658, 0.16171454181594236, 0.11079571885807861, 0.1412681607349265, 0.2104593528014037, 0.10278256940505198, 0.17524846559090002, 0.2270274750527836, 0.11567362283747043, 0.1611131168301067, 0.22189437952493468, 0.1159566616819751, 0.15112817197317077, 0.16939002269458386, 0.2181572340909512, 0.18297473809892134, 0.22126946628334063, 0.2631668608275152, 0.15873159462165448, 0.18281712316937987, 0.2668392105448631, 5.009824748962156, 47.78922857776765, 102.65063962628766, 126.9131192853374, 111.05799690369638, 81.82322271408574, 87.63837968149494, 56.66234377891787, 38.24019093667307, 56.43623482796454, 62.921301241843935, 86.41768317068778, 103.29168042828961, 93.13634241780927, 95.56461118882703, 50.554013175349084, 25.02267029977614, 5.104760816020351, 0.5106303900960953, 0.27574087643334944, 0.4064106244233347, 0.6496983922777638, 0.5806782829665369, 0.3268246917474655, 0.28559144946836656, 0.21564323995863238, 0.20459689560436434, 0.2840765565633774, 0.18027415559176477, 0.24740601138722515, 0.3984858738558908, 0.1275366628842969, 0.8599158604779552, 0.43406544854083373, 0.5896062103490676, 0.7254824450900479, 0.5603259008738303, 1.0762861178767298, 1.7765996941635687, 1.156933725841584, 6.096462982316171, 5.728491708155602, 7.430675827687787, 5.062948349983462, 11.459229953827398, 12.726939012927394, 10.02504667928142, 7.113193792681541, 5.7058753217420275, 9.705500987268264, 7.091092217353083, 4.074304161533233, 3.022031038999558, 1.314087164017462, 2.4800607273655557, 0.6831538809403297, 0.692985056629104, 1.0027292358779138, 0.7891166498584132, 1.312131372190291, 0.4057172842083439, 0.7761506423834832, 0.6356808218744494, 0.44930238577146686, 0.490161654569449, 0.42411742912184813, 0.3793098657361923, 0.22297416513244953, 0.2787517245498396, 0.24877534758660103, 0.3800734715355981, 0.6212221686878513, 0.32747589712662084, 0.2540324267841155, 0.6510738571805339, 2.036659700735923, 22.59294632942446, 61.06698505340084, 90.95178619507821, 111.51157194568266, 115.48848659761491, 83.01771779214182, 74.41241418161701, 54.97036664716659, 37.85535543195663, 48.3304254470333, 57.46094619074176, 77.24325149290024, 81.26830147158715, 98.57920369794293, 112.54024490233391, 86.67378256397863, 10.14899455731915, 0.2783732158282111, 0.18135027929900155, 0.1678584137510869, 0.21780638114338924, 0.19051629148664015, 0.23079382375844065, 0.15056181849250871, 0.1876519347030309, 0.16045346916202577, 0.09519010181388549, 0.21493241761720952, 0.25751224328433314, 0.14993474488296818, 0.1122779151304595, 0.07844927270085582, 0.1927649127619882, 0.07754293706027732, 0.09967410636525001, 0.09394365377844342, 0.15261465833792764, 0.13331910985852444, 0.14198256836783502, 0.14444310488479753, 0.1134297819507699, 0.21607431763362503, 0.13082797578986616, 0.2967187539944726, 0.18568912551047342, 0.24676344747985565, 0.14828725748004454, 0.2029331211721705, 0.14941524533975512, 0.12704006937001983, 0.20792495008678208, 0.15067233433646543, 0.1451416851411904, 0.11807446578337301, 0.1630700884326812, 0.1636841998345429, 0.1109342965027017, 0.08012573354907575, 0.11593342623523167, 0.1499287693971588], [0.02420261551085259, 0.056634221916958216, 0.09829996679458888, 0.014034286441822207, 0.041403256341694825, 0.03669505615928962, 0.04799373838449678, 0.05627791059293574, 0.014965297774441782, 0.02398413872616666, 0.07679413974044785, 0.05013546358133036, 0.04289184944824346, 0.015600254428723167, 0.04030919851615064, 0.028358550569523248, 0.005055309354042214, 0.022616012945711132, 0.011564354814078298, 0.03911392132361089, 0.0117064057098281, 0.05019093983836713, 0.0766814482067862, 0.007691469612426215, 0.08284018224766178, 0.016897798613494924, 0.049330125142249374, 0.011040373656508184, 0.05536700140744929, 0.04629774995508694, 0.10509450784734181, 0.05491507464959737, 0.029708376424687526, 0.03018042639709048, 0.09305690700608878, 0.08049629793892946, 0.0692534750147212, 0.22590912457916046, 0.06709886804944085, 18.688675934268584, 76.09169067875033, 90.50371816081386, 95.76459715443274, 71.02005820120536, 73.55052824943297, 61.83349071010467, 71.3562523934149, 82.45809755017682, 57.80608338694419, 63.53889019258561, 72.363297400936, 77.8288221359253, 61.58213346235214, 49.12772955433015, 17.23629286212306, 3.918150192306888, 0.27514219404228274, 0.053291531324747114, 0.04137367768693836, 0.03681211056368005, 0.06394012282872874, 0.07171565862072092, 0.026780145145171595, 0.13942976422127218, 0.11891334738221862, 0.13263554492544744, 0.31532868442516176, 0.11656174856808879, 0.4807908364361333, 0.05955303223022531, 0.5402382174807211, 0.709840584426157, 3.2991768900425207, 2.751091113013606, 1.8758813796504852, 2.9015574003419573, 1.14843713660394, 2.362987293351081, 7.222886796920531, 2.9109799140884034, 4.213877291448655, 9.19402587798334, 8.282875957027558, 4.54008512919949, 4.890665104312282, 3.685501424535629, 3.773159043442819, 1.913610780912061, 7.21786420191488, 10.643543658717986, 5.2172112464904785, 23.266666358517064, 4.64903288310574, 1.5624588751985182, 2.610984295606613, 0.9138455085696713, 3.346762594676787, 1.3780604086575972, 2.7522540957696977, 1.6879774173421247, 2.0131941211800424, 4.121799161357265, 1.9375213043343638, 0.8558150224627987, 0.2711951864823219, 0.2747212440496491, 3.0097576975822453, 3.2817640179587952, 0.21572461381794947, 0.1053448883636344, 0.06601104617960031, 0.010847189264642376, 0.10664038900886813, 0.04895452372429352, 0.12338752302551463, 0.057506336409959107, 0.6295658467758087, 0.3777598553607541, 9.195484019094899, 21.766802995435654, 50.3507088845776, 88.8233434000323, 91.69383587375765, 68.97802522105556, 44.66795936707528, 30.98941118486466, 24.672645830339004, 41.63734789817564, 44.2826335660873, 57.29772460076117, 61.22989677613782, 75.80775030197637, 65.08324892290177, 15.930170070740486, 0.571404574138503, 0.19013422811704297, 0.06282706985310202, 0.09994577646495835, 0.09202877870730816, 0.06790757344494905, 0.09640621276752603, 0.09828111337077233, 0.04768281010910869, 0.1138085588031719, 0.030818774905656616, 0.027250517385020375, 0.04521094315174607, 0.06049888268593819, 0.045960514220379056, 0.027285956612397588, 0.037692445180108475, 0.10737697488718456, 0.03327022178939754, 0.011016917959486526, 0.013524534409835696, 0.06740223886745592, 0.0743612130322764, 0.05952394387174038, 0.0287968639449607, 0.027469415518064654, 0.013161670161230911, 0.04081323074417249, 0.07117643997433686, 0.02102763880224478, 0.011584387055688329, 0.03577117710524509, 0.055069985288766124, 0.028873141404361497, 0.06875966239960925, 0.010207259742122506, 0.025482700551829995, 0.07174506873613404, 0.029657029381562627, 0.031594906242624406, 0.008826193779015975, 0.018646581992206555, 0.07196512749238361, 0.013512495338105628, 0.06514524425109548, 0.05303268553689123, 0.048205569356439576, 0.07977971461631599, 0.04193654546754495, 0.06328691412965137, 0.04371800249622714, 0.03218525359707494, 0.044406715540155295, 0.02051366658340539, 0.028431252313537464, 0.011518048629495166, 0.02623467713654522, 0.03765510222423942, 0.013860457261363346, 0.026044413454890735, 0.03066874616178534, 0.018452692799450412, 0.014845051656236813, 0.0305205138940965, 0.010524941082563131, 0.07073265290068043, 0.08573230205764694, 0.06152809882957128, 0.08582224077995747, 0.034244302585120165, 0.06280241331325905, 0.027352648396645824, 0.03352589214280729, 0.020828814088036458, 0.06155363254008755, 0.03772275161839301, 0.10102961467759264, 0.07470551592808578, 0.10630344055713185, 0.3182806663455502, 0.9744192840110872, 32.74738023358007, 97.46417583957796, 102.83547739828788, 113.15481755041309, 85.51053308671521, 98.95750061158212, 92.78986377100792, 91.95762311258625, 73.57337213331654, 38.76936966373075, 45.88127789958831, 51.756251012125325, 71.38423458222421, 63.780061045000636, 49.34150265109155, 12.684221459973244, 2.431525564001453, 0.34307160865395303, 0.05179173418230588, 0.027518529414890275, 0.1743603858255571, 0.1741137974444897, 0.1087080909600181, 0.29412153207006, 0.1040939050876806, 0.364698117538806, 0.40788384214524304, 0.514361422148443, 0.3764590074218089, 0.958684021907468, 1.492936579931167, 3.673513435548352, 1.4293353475870625, 3.5084762784742543, 7.6024030773870415, 6.885006475833155, 9.43541246075784, 6.86496953810415, 7.587589756135018, 12.019069848522065, 6.818477194155417, 5.554299248803047, 12.626092914612064, 15.18547671456491, 8.886584620321951, 9.852357468297406, 10.637906232187825, 9.21779053826486, 5.7267668458723255, 6.353270853719404, 4.067007817568318, 5.571519924748329, 4.942990993299793, 3.421764686223, 4.880501262603268, 3.57544265927807, 9.579489942519896, 5.671401120001271, 4.424128099795311, 2.54327658684023, 3.7532419831522055, 3.6124757172599917, 3.0104821103234447, 1.0935541074122153, 1.2760520630305814, 0.21341631429329996, 0.37982087702520434, 1.8227528756664646, 5.921451728190146, 0.9491823253131683, 0.22712303686045834, 0.12450888422468018, 0.05252106137753976, 0.10206872867720743, 0.16749159553118292, 0.12367295206434305, 0.14430168505397536, 0.518287040533558, 0.3740915199441295, 6.294382839433609, 18.38563165357036, 52.36739158630372, 75.96686517038654, 65.82495735537621, 36.896390838007775, 17.300313788075602, 28.285564530280332, 33.065262840640166, 62.48301559878934, 70.33118017258184, 78.6412940486785, 76.63413093936059, 82.12309575849964, 82.45746997094925, 30.08900365521831, 1.0771019708725715, 0.3192609830969765, 0.013197119922317086, 0.10242495956199785, 0.12319986978846213, 0.06462387545334716, 0.06616174333518551, 0.09680864641502981, 0.028659207521066554, 0.01563656125067463, 0.02760731325965495, 0.035010559048743985, 0.04841147846872768, 0.08938826515429443, 0.014534153066755784, 0.038482128612456784, 0.017546527613435062, 0.06170266345443745, 0.02437243422102784, 0.029667101522547104, 0.023734060814604167, 0.028042541215977365, 0.0212520738357618, 0.021905002912746805, 0.051570365415705796, 0.03497916859604659, 0.02248751127251214, 0.08666330572938727, 0.03536077997376842, 0.06189111725337083, 0.039269923638071746, 0.033938985903777426, 0.0406424391023334, 0.04086727824723048, 0.03660691391316153, 0.022818488068878654, 0.036393412869543805, 0.05404374922715849, 0.015072132565922316, 0.10176460709302657, 0.054157114918193514, 0.009599217671840903, 0.17513373626335976, 0.08962828816185076, 0.1678271267202593, 0.14934033726251897, 0.1084668881770584, 0.19693364148899434, 0.17477588127216986, 0.20604987328331317, 0.11294958271807241, 0.137798288055966, 0.1335885123379769, 0.1546983562049366, 0.12313033964845443, 0.08877302760318403, 0.14252636822000628, 0.10403100160821792, 0.0683476603139312, 0.13303057050272343, 0.09240501214780154, 0.19613453517517737, 0.10527345066469525, 0.14532402938892766, 0.15514418873335087, 0.15307607309472177, 0.1767524647256059, 0.3199818411902074, 0.28029199028688095, 0.14991559268486115, 0.18740712364594783, 0.0997656308895638, 0.21096896981039356, 0.15327082796683236, 0.25806802475164015, 0.18371799660305824, 0.2669971165878158, 0.1650880099905114, 0.23763056093406296, 0.5106364881559726, 0.9838141573052254, 35.533269143873646, 108.14533895061864, 116.45622945600941, 117.15634115280645, 91.99920808115314, 98.13639163970949, 79.97939494348343, 86.33210489826818, 95.7854014058267, 82.22533625941124, 88.06247418926608, 99.52409482771351, 104.92266470386137, 81.05759174593034, 64.81039708660495, 21.647727681744485, 5.5350845379214135, 0.49249632284045225, 0.1870634719248741, 0.19899098593140804, 0.3290915152718944, 0.3795854122407975, 0.1965263431831714, 0.17084352131332123, 0.2312993805014318, 0.5392893716212243, 0.5756544622202073, 0.794332911891322, 0.5498922736414018, 1.0430948989045237, 1.0278130995650445, 2.0736195819993175, 3.3995518136409024, 9.851204291466745, 9.726503318355931, 6.501530562677692, 10.967335316442675, 7.588057008481796, 8.886816040162119, 18.628108655252767, 8.217727839946747, 13.778750031225144, 21.10420092459648, 24.634734161438484, 15.415960088852914, 14.934187127697854, 15.25173927507093, 13.990049093000351, 12.647065827923438, 22.631291420229022, 25.730393355892552, 21.55638352517159, 44.36767055142311, 15.179630421823072, 10.043544577014062, 11.962404347235157, 10.345280747259817, 10.224350152477141, 7.288701226634364, 7.23587719663497, 4.782444459776725, 5.900688661682991, 12.642609034815143, 5.169184765508098, 4.030723196844901, 0.7613019585128754, 0.6137740167398608, 5.194564461708069, 8.623420057758208, 1.0131757946745044, 0.29337168520977425, 0.21179937847679664, 0.16181252446145783, 0.32381978847326776, 0.34078210892696537, 0.2983031463959525, 0.2714990169530915, 0.7101718408446158, 0.8590851760198994, 13.06633189801247, 32.32361520490339, 69.63751685234809, 119.09148954576062, 126.68479811760687, 86.319945550734, 58.438165495472575, 41.36433916707193, 33.018735685656154, 51.77307405779439, 58.4860929366081, 74.1751656993743, 77.5269094590218, 95.16573752126386, 92.81191533611667, 28.77554701220605, 0.8826559854130592, 0.486488385546592, 0.1980855925789764, 0.2054593880330363, 0.19395575047500674, 0.176045396215012, 0.19903592464904632, 0.2971412361629548, 0.14481309470870804, 0.15883734539872216, 0.12147228023217571, 0.14679740032842084, 0.2869940951706902, 0.22455011524500387, 0.14613130220001744, 0.128545937759261, 0.16542740226272615, 0.1880762248390144, 0.10318494942640105, 0.08251598915986477, 0.12337583252379011, 0.16417422031442966, 0.20276629786577918, 0.08753951879278307, 0.1742384859150456, 0.08961419980492323, 0.15579039921923993, 0.24601949949658689, 0.16061653863758812, 0.16327121715632179, 0.0679676653817296, 0.22651891524512924, 0.24025125579247553, 0.14508690985460437, 0.21426422040789359, 0.10837155619576093, 0.12449713243592171, 0.19266532133183173, 0.11087304011227624, 0.17307207108505313, 0.1310728021687077, 0.09661051309517316], [0.06412105364424568, 0.03561423250263737, 0.032796384916911205, 0.03633876015702563, 0.01933507095541685, 0.027797048340641686, 0.07723115459685365, 0.055957842888610984, 0.018035667092208902, 0.05779429736937727, 0.034191254826803366, 0.09326738200240559, 0.03885649662885455, 0.053067714907228954, 0.04448079241199359, 0.027533558144744848, 0.03602223177891105, 0.00577293886547728, 0.024742623227798653, 0.024859152861960956, 0.028889062626647855, 0.040217899987774516, 0.03490881874195991, 0.038117834652263316, 0.04248810579038916, 0.08775910257451958, 0.07144044153392315, 0.04893370145451158, 0.047168539115978826, 0.04275427537880117, 0.04462382485789638, 0.1252512693885834, 0.08979983056985563, 0.10733271798779888, 0.05452726562056811, 0.09654860553001204, 0.2641024380441635, 6.526586663338446, 56.9052561636894, 101.1483326265889, 94.39324240530692, 88.87994320161881, 70.09608114919355, 75.50193094438123, 53.81534238015452, 30.433089656214563, 41.55942216996224, 64.44877024619811, 53.185339127817464, 56.28816535395961, 78.20772309457102, 65.37359060779696, 27.790837941631196, 3.2834597076139147, 0.12382226260078531, 0.05921765042829418, 0.24189146536011852, 0.12194654994433927, 0.14129811477276588, 0.2201125662653677, 0.04434019612569002, 0.10215279150513873, 0.16702713174445016, 0.243361848556707, 0.06798798203348153, 0.14733154747274615, 0.5136280615002878, 1.0858896735214418, 1.2354886267454395, 2.810837881219003, 3.417855554050015, 9.138470407455198, 2.845929611113764, 3.8208893854771895, 14.327351354783582, 5.073042569621917, 6.728882904975646, 4.701602939636477, 14.333985063337511, 5.735988338147441, 4.3533621680352, 10.00610359253422, 6.915295018303779, 5.9863228278775376, 5.5611364303096655, 5.583957760564743, 7.117491729797856, 5.971836534238631, 3.9351553830408283, 5.921009480953217, 4.245521503110086, 12.629526949697926, 5.230660563515079, 4.321791500814499, 5.379675819027809, 10.80146122363306, 5.195838251421529, 6.677859242885344, 4.997572735432656, 5.308144534787824, 8.775852187987297, 4.726372707274653, 2.4703143729317576, 1.958539570050855, 0.7576877395472219, 1.3637783234157872, 4.654719339263055, 1.5530348905632574, 1.8445314683260459, 0.3056681931259171, 0.08937519569430621, 0.123083692554745, 0.08987845417352454, 0.07192242575148422, 0.07933163745028358, 0.08162492931249642, 0.167501631282991, 0.032944285851572795, 0.24915615457200238, 0.22820585617615333, 5.41676575137723, 36.499772533293694, 63.64018932465584, 72.30998454555389, 76.71131533961143, 73.87307259344286, 56.795978930688676, 26.47051322844721, 29.061538788580126, 39.90840634992046, 62.473244974690104, 66.4940195698892, 72.49424180676861, 80.80862322161275, 51.820397453923384, 5.617219459625983, 0.953734235898141, 0.02547107899801866, 0.049194623340642264, 0.1552974522834824, 0.07733566431148399, 0.061086625341446175, 0.07001412371473928, 0.05199724875931298, 0.003917738213203847, 0.03901459802422793, 0.028670139595746037, 0.0194360739025738, 0.07383941522529049, 0.010702030924749712, 0.043107143137604005, 0.01952533463707134, 0.05823607729267209, 0.021331921264889742, 0.01708289311688033, 0.041766224969779296, 0.04510170667462292, 0.039888083814613284, 0.03133258624603191, 0.024692457875296957, 0.0442430829899686, 0.052204743673604344, 0.022321609186849767, 0.08883307357468913, 0.02916065228712415, 0.052278598379944606, 0.045060832053422935, 0.01662003619956874, 0.05239535784048419, 0.07482838110938188, 0.07876415015949358, 0.09281275478462059, 0.07534962733306232, 0.012094815160268018, 0.008706858347830995, 0.10393380803326446, 0.013950873831016643, 0.025785912406600775, 0.03949052631674756, 0.025588374720105243, 0.043205926345000346, 0.032227273519721725, 0.05742289411324648, 0.08314251118609983, 0.028055874976299466, 0.04479725184219499, 0.024315929490952723, 0.08241200804590218, 0.0228323312776704, 0.055374340529763894, 0.08734984308361046, 0.056265886842964165, 0.06372386769902322, 0.01032177648026376, 0.04383350174213129, 0.03676578139645919, 0.04451034042323309, 0.01614539493476191, 0.021440255673482053, 0.08341817260389367, 0.05257772890129878, 0.04451461902429019, 0.04817588727981333, 0.020229919107570764, 0.019065139875296625, 0.052238175750619946, 0.02906333996854242, 0.11226282319835118, 0.09655553096484754, 0.021642133248068636, 0.043598450645203554, 0.04856434365313861, 0.053317057374384136, 14.259444340582817, 80.88388566047915, 119.28210104665449, 105.87454549727902, 109.82203452817856, 97.57325695407008, 114.39926009024344, 81.42176028220885, 35.33132983792213, 35.103793144226074, 49.25887400104154, 46.19325930072416, 56.14419475678475, 82.26774492571431, 64.64834436293572, 22.790961304018577, 1.9953606974694038, 0.06343860336909853, 0.0836626006170146, 0.1829485838571864, 0.0820417347694597, 0.11640157490488022, 0.3228181131905125, 0.17190701989156587, 0.3646210797371403, 0.385929508915832, 0.12161820465999267, 0.33427832888499387, 0.5010109611095921, 0.3546712523506534, 0.21123429670208888, 1.1393637138028299, 0.5958783254027367, 2.211635776104466, 3.422082888503229, 2.660141399791164, 6.7063935052964, 9.189094478084195, 10.597032193214664, 13.694204322753416, 10.884993980007788, 18.28953946790388, 13.212072464727587, 9.485266766240521, 12.59491301351978, 10.037427640730336, 13.085930020578447, 10.331958416969547, 10.887541559434707, 4.62114385058803, 3.594000863452112, 2.5708251085973557, 2.216968728650001, 2.8384261169741234, 3.2148103848580396, 1.7157134774231142, 2.1567892739849706, 0.6903703679000178, 3.140010540523837, 3.5795851724763073, 3.976489319916695, 3.956288132936724, 2.495757317350757, 2.2027991664025093, 0.9576141954429689, 4.0052861359811605, 5.8673558696623775, 2.836381336373668, 2.9057207511317347, 3.57623081053457, 1.8944884908776132, 0.7429123549692093, 0.26302372495974263, 0.12918117786607436, 0.18185560621561545, 0.060709112534119244, 0.16329594647451756, 0.10832642595614157, 0.09797827881430426, 0.1092841507746808, 0.062332609893694046, 0.44903900474309927, 0.5244971943959114, 3.2646036484549126, 34.45809648882958, 62.0510841954139, 64.78079888128465, 43.532699923361506, 26.543526188019786, 20.255594176630822, 21.61068089546696, 43.9095220258159, 62.526408780005674, 89.26768518263295, 84.59575007038733, 86.02756423334922, 93.54521812931185, 71.9201244846467, 12.721497704905849, 0.513601370997006, 0.09122335982899513, 0.03990758841316547, 0.09783401679728301, 0.0969007991314415, 0.051149308170762756, 0.03270459226182392, 0.052199132079558994, 0.06433765734395673, 0.09485280096170404, 0.030431256990038583, 0.02287229425424049, 0.03951052887245052, 0.03108258111282222, 0.026133072810367714, 0.16833758642596586, 0.0436134391554421, 0.019421675280036948, 0.07649646861658943, 0.15718634931310532, 0.09514219833598023, 0.04320781858217332, 0.03619804895753342, 0.05788498685785359, 0.05505346843311864, 0.04554991790604207, 0.01367376450704591, 0.06493925086913571, 0.024459410098291213, 0.018757392780014107, 0.06055571491860094, 0.0301485188350442, 0.05308672537906997, 0.08630701355756291, 0.04086553156676312, 0.054051885080914346, 0.05651350561228972, 0.020411943513599616, 0.05517459076438701, 0.019974836726642905, 0.16829091634961868, 0.15521906616707004, 0.14408244601180478, 0.139777583460654, 0.1257124083537248, 0.11883658537220572, 0.13530491701056882, 0.2966000410097261, 0.15461336641061693, 0.2779750033251701, 0.16498866370849072, 0.15488799360971298, 0.11707137323795788, 0.20411979136688096, 0.16518116628210391, 0.14893211965118686, 0.12308855721306418, 0.1448621090141035, 0.1098099169171145, 0.1413233037437162, 0.14619983642572357, 0.06731358717285818, 0.07619600893268663, 0.25498288142825326, 0.2144297873300891, 0.198850991024125, 0.20431258505390537, 0.19690051584714846, 0.08208589207741522, 0.16249304036459616, 0.0832498707478085, 0.2878596519510592, 0.2663855026325872, 0.20552617557827504, 0.18727656694189196, 0.23655878860623608, 0.44534612386938066, 14.247577209626476, 87.28400922590687, 134.2443899954519, 117.38318750935217, 109.97213578993275, 91.25117286559075, 99.1811933825093, 68.97669161519697, 42.7557921409607, 54.50853501596759, 88.07882262814431, 80.28789720227643, 77.9985038695797, 104.34495449066164, 81.78632105550459, 37.00448743758663, 4.76190447807312, 0.7291132115548657, 0.1993417469484191, 0.5163731690376036, 0.3496283100497338, 0.5033708796385796, 0.29085021405931444, 0.23357185775474196, 0.45148922971660094, 0.8073185925041476, 0.6210728734731674, 0.7941960579445286, 3.1060531110532823, 2.140672745243196, 3.77012116774436, 4.380690301618269, 9.865041432842132, 11.79949458568327, 16.118649763445703, 16.265114007457612, 25.290513269362915, 28.127957813201416, 16.015117822154878, 20.630847331016295, 15.071135701671725, 35.11751359508884, 24.761693439176007, 15.257356109157687, 22.11449561580535, 18.10061654736919, 18.97122190844628, 18.53466603063768, 19.273634687546764, 17.944851383086174, 15.248468998939762, 17.259179892078524, 18.72923520303542, 16.81955672079517, 32.988376540522424, 18.57394268435817, 22.24111560852297, 20.864869663792273, 20.15160037625221, 15.363793546153655, 14.72642800500316, 20.42133196707695, 21.582116234687067, 25.307516744059903, 12.713438214794284, 11.27573069064848, 8.357860888204268, 2.867387672585826, 3.058270307317857, 9.240426536529295, 5.13457965466284, 4.458875396559316, 0.8907035245530067, 0.28000023336179797, 0.5739482924822839, 0.17386313347566515, 0.34183437665624006, 0.2875719093266995, 0.42949521313271216, 0.489635689244155, 0.14533999466126965, 0.5779591611316127, 1.1688670467945839, 8.300053977197217, 48.410606538095784, 82.6004638979512, 98.86674481053507, 109.44263935089113, 98.86141823184107, 72.40569822249874, 37.23854311050908, 37.87423772196616, 51.104898298940356, 82.21651877126386, 86.19562995049262, 93.6037555817635, 108.28411240731518, 76.75712862322408, 12.541514846586413, 0.8666107334917592, 0.2315654888028099, 0.15461116007739498, 0.26812614632710335, 0.2331999067457453, 0.14039909527186425, 0.17168238759040835, 0.16027224340265797, 0.13605326233852294, 0.16044047631082997, 0.12773051377265685, 0.1888682678221695, 0.18598834413193888, 0.16298889843446596, 0.1207881713766725, 0.31970473186623666, 0.16489106410693738, 0.12927159156289794, 0.162633786038045, 0.2221052069216967, 0.18159037125447106, 0.10008856759316499, 0.12431338624728304, 0.1910921291358048, 0.10590019485642833, 0.10755991668350275, 0.167881702823985, 0.19988318724978357, 0.06567711611428569, 0.13696355865367, 0.19619873334323207, 0.1345046922083824, 0.24068308423363396, 0.18468008046188664, 0.2214263304467163, 0.16070879094542997, 0.11158433742821218, 0.09032774941935655, 0.09618891192780388, 0.13354902816635947], [0.05445155698145109, 0.049001289561631224, 0.009373091499231035, 0.045924079078700275, 0.12448236992162083, 0.04021457516618314, 0.01033761726331807, 0.02825213904162088, 0.03437023211811339, 0.05472571303647372, 0.01734691574388454, 0.03589599198030849, 0.0379937322389695, 0.04527178968513205, 0.013453938450003344, 0.02345754520877475, 0.0659822489345266, 0.03803725369394787, 0.04845830559309933, 0.03628297363437953, 0.09039023155046087, 0.043422928410432035, 0.07946620845506269, 0.020603540188242352, 0.022178438845120614, 0.051699684887763955, 0.027190571004945426, 0.01526933604656088, 0.06343238273515336, 0.008396820649654876, 0.053597928190063086, 0.009026877214050582, 0.10301584317799538, 0.038579100021912206, 0.05305809667333961, 0.09137671530967759, 21.686117879806027, 87.29707071858068, 103.21025986825268, 85.71218213727398, 91.69708359626033, 83.20804688238329, 59.55878273133309, 27.364546906563547, 30.896741267173525, 71.63108502664875, 75.9165568505564, 54.52835867481848, 69.85136447414276, 86.74812716822471, 39.7752889510124, 5.501711541606534, 0.1908452189978092, 0.06890918744067032, 0.09416296176852719, 0.3254131900687372, 0.04973960679865653, 0.015124255273070548, 0.07090174382732761, 0.10976549147838548, 0.08682543291680275, 0.20631736054295496, 1.182405720314672, 0.07307223179527829, 1.7568182007920359, 5.339027316339555, 2.65261608746744, 3.493978708021103, 1.8473561877204527, 4.686866594899086, 10.113445135854906, 0.7639016932056797, 2.6416949831670333, 7.678618161909043, 8.883218246121562, 9.580474457433148, 7.022821893615108, 6.767504522877355, 8.37670591569716, 5.821990226545642, 2.8075501995701946, 4.706829007594816, 5.400286893690787, 5.067601751896643, 9.570874456436405, 6.959435411037938, 3.5229934607782676, 3.4682244254696757, 2.599840596798928, 0.9201483897143795, 1.456844032772126, 1.3765974871573912, 1.2827664253211792, 5.130715139450566, 1.260844175854037, 10.26751877800111, 3.86049846006978, 2.6295361259291252, 3.1655660079371546, 4.7169555867871935, 6.793665261037889, 6.70963534424382, 13.068218558065354, 12.873392470421331, 17.450373864942982, 14.276474291278472, 7.9000035985823605, 0.8202519952770203, 0.5756143192129751, 0.9315315369636783, 0.1361258261867108, 0.3016817167160973, 0.03718375130706737, 0.10853401280098385, 0.09043575249492161, 0.048787489743723024, 0.09514622795846193, 0.08847390091226948, 0.0820891096466972, 0.04997417526019197, 0.3519570947654786, 0.1019416346905693, 8.729997719487837, 59.08517614487679, 76.93447466819518, 66.65198910620906, 87.68253772489487, 65.37520662430795, 54.91923462960028, 21.517877617189964, 27.938928988672075, 69.2960431498866, 59.967411333514804, 61.06687914940619, 88.13765818072905, 64.41821890492594, 20.703724968817927, 0.0598406752631549, 0.20750412266821633, 0.07155141703063442, 0.17172202497961062, 0.008993721886297629, 0.08393797858227646, 0.008403833226991758, 0.032888265672109784, 0.013544532177489133, 0.046597642733925776, 0.06711957540603415, 0.03869883573403762, 0.07345237994506475, 0.03495913156638703, 0.042043073823855776, 0.03478795305014618, 0.020402957302247806, 0.025643420052684607, 0.04232149698861665, 0.009263603170702775, 0.08823528750649384, 0.05239087239568753, 0.02030761574485129, 0.07840146881438072, 0.017765573218404766, 0.008539798511793057, 0.07690197427666957, 0.06369141238411108, 0.0039452402908805645, 0.03812879354002015, 0.019163930743572213, 0.028832084837279497, 0.026482387836421692, 0.06155504980274747, 0.02879779665700851, 0.050714001690428105, 0.029502151301130656, 0.024258792738340074, 0.03967807613193028, 0.07338919301307009, 0.04557463190247936, 0.033835085229046886, 0.03013817856328622, 0.09115809679872568, 0.022440327917255705, 0.029604887522216287, 0.025737528208523028, 0.029044837029951236, 0.05320492125446758, 0.06344627957009981, 0.01834122509124779, 0.0450056315880389, 0.05386035543896499, 0.057072581257671125, 0.08796280535358576, 0.0221729421642639, 0.16822129427906007, 0.013323315670863997, 0.01836965652933765, 0.07655215554780538, 0.08061939294660285, 0.08266808825635141, 0.06708406723074375, 0.030916847566503192, 0.042901421716857346, 0.01783454411422774, 0.07821782987805144, 0.04300049986810454, 0.03766642117332067, 0.048001422246377316, 0.04159128879226985, 0.044205682577505234, 0.050438757790553, 0.051848275301557396, 0.18032536090862367, 41.45743270074168, 109.480513757275, 117.22943844333773, 106.28600997309532, 117.76770530208465, 114.68261211149155, 89.19432901567029, 45.08360116712509, 24.757825982186105, 38.75977554628926, 54.74358304854363, 49.48750895838584, 70.78147611310406, 88.63860760965656, 35.063941863275346, 2.425579005672086, 0.057981552240709146, 0.032120090158235644, 0.020324373918194926, 0.1792329348503582, 0.08807120679487145, 0.1322486705236858, 0.35024148682432793, 0.17818302667189032, 0.33260120920115904, 0.1377435434128969, 0.13174049375999358, 0.818441331146225, 4.619074310025861, 9.543568876481826, 6.527685417282966, 6.937984949158085, 5.3532145292528215, 4.741938143007217, 4.235629775831777, 2.2648047295308884, 2.0377800277163907, 3.168742637480459, 4.476276011236252, 8.40620311998552, 10.199515665731123, 10.31757116317749, 12.961426146568792, 12.045975346719066, 11.598754544411937, 7.851589783545464, 12.462972325663413, 10.066099186097423, 9.804118198733176, 2.2130872982163585, 6.181731877788422, 2.429260885523212, 0.7863480693870976, 0.7754688241308736, 0.7579366874790961, 0.5884668231010437, 0.8906295511030382, 0.4107484900422635, 0.77480606614582, 1.466593328983553, 1.7157621393280647, 1.3226425888076907, 0.7896671299972843, 2.3563239218727237, 6.343960617819141, 10.427952543381723, 18.556199842883697, 20.448137444834558, 25.672067711430213, 20.928202213779574, 11.616625843509553, 2.6075735495936487, 1.4086785527967638, 1.1006885310334544, 0.25824594101117504, 0.24528422362862096, 0.0763440860675708, 0.10014268404413616, 0.14048226177692413, 0.09428199651020189, 0.1401508521408804, 0.13716533089116698, 0.050640081866614284, 0.06953723398187468, 0.39298104182366406, 0.4429892390485733, 5.821922075363898, 56.40546383396272, 81.58810015647643, 59.51173390111616, 57.1851251202245, 32.15876779248638, 28.84085447557511, 27.329963368754235, 48.32058029790079, 95.7753130697435, 81.9519627478815, 77.66386293595838, 99.87367999169135, 82.99113981185421, 37.40897401686638, 0.13391737856211203, 0.3940810215088629, 0.18682500407580407, 0.18389597414962708, 0.017639996085856712, 0.02264503427150269, 0.03728889304423525, 0.06830999943157358, 0.02997677532895919, 0.013142264196498981, 0.03361202340813414, 0.03746381389998621, 0.04446690323792639, 0.04086493018774256, 0.05458627737337544, 0.010151536421730153, 0.016283292676352205, 0.056074560214314735, 0.051928997986138835, 0.060034303986016786, 0.007457154438710742, 0.043853734124211535, 0.027016958244325175, 0.06665157229309121, 0.05915314582506976, 0.03644860567404859, 0.1512479268374943, 0.028089446864361246, 0.0319545136599411, 0.03651641594666628, 0.10655894620163787, 0.03190390397644332, 0.08928585452057662, 0.048739436878672535, 0.06617669737146747, 0.12453161405339358, 0.07938564664894536, 0.019923593105387785, 0.031283673447286414, 0.2943713686639263, 0.16280649289969476, 0.17591958925608667, 0.12405886885619934, 0.2570964107590337, 0.1511377480722243, 0.16834776007360028, 0.11588121734319196, 0.18481777710539682, 0.14158945801036973, 0.16629142686724666, 0.11801559192639206, 0.13573193441956274, 0.19211289532963308, 0.17156569707778194, 0.1495481156293423, 0.13980818101234976, 0.3539019775006079, 0.1385157906840886, 0.0909867535735811, 0.17341924681057855, 0.15800687544528516, 0.20880677857466284, 0.14796042904978798, 0.121966008577616, 0.14153921796429542, 0.19499001513806083, 0.1729080210169477, 0.15826691633030293, 0.18023330778364213, 0.13801331361455305, 0.10541380563330267, 0.22028726495562062, 0.11954168503683422, 0.11847089330155043, 0.17346191790796098, 43.29462774338261, 124.53128353241952, 128.45858804641233, 108.29705622888382, 113.76152192392658, 106.44518759942825, 77.24316520075645, 36.279896228544175, 44.53919579905849, 97.86734058010964, 109.68267271595617, 80.30523407843806, 92.29613150319746, 109.5016239535424, 50.040810262003255, 7.060860058953685, 0.3637296904719645, 0.12100181797699583, 0.20818296849967974, 0.7568942563187692, 0.20474511829595413, 0.1595437550737012, 0.31042176869607746, 0.3018774981460264, 0.3152876527559373, 0.48371370701539906, 1.9562415514261493, 1.270648998118216, 4.503675728074966, 9.579178114091198, 4.79475530885881, 6.560791202129857, 6.405359929607761, 12.247532221578783, 20.284194138742265, 5.321961574016079, 8.421355235961176, 19.199482279439128, 19.948315697331584, 23.889942746008597, 23.936328695666408, 21.750905629127256, 23.22308490353246, 20.664628744125366, 13.093075598439864, 10.882230670221391, 14.946306270937766, 18.66418661609773, 25.27680262442558, 19.505525212134085, 18.08092232673399, 11.185424000986162, 7.656835769453357, 4.954659063969889, 4.349745252440053, 2.0956441808131436, 3.6491108998175594, 12.072446442419484, 10.21303999808527, 24.481487158806097, 15.215909404139365, 10.59006900556626, 10.427546578068888, 14.151114359978708, 10.966991128460055, 8.593594354967918, 15.694396399682569, 15.996288484142674, 23.08423496061756, 17.969352468367546, 9.1655602570503, 1.2680677108226286, 1.8685939835925258, 2.3582824103293882, 0.44035806410735656, 0.6120987969540781, 0.2147943226079787, 0.2916798872813102, 0.2533024522445856, 0.17260051332414153, 0.19587723688492853, 0.4609436740077311, 0.3441461542200658, 0.21832159059422634, 0.6839570475201453, 0.6133397368173445, 12.834293303951142, 75.31323356013145, 97.1076245461741, 96.2146734422253, 123.40483373211278, 87.62038384714435, 71.19839268345987, 32.031029924269646, 36.313801196313676, 87.94134355360463, 77.63929320919898, 81.2995941408219, 109.33565278207104, 94.05764441336356, 38.7425131951609, 0.1800985529177612, 0.4057100829818557, 0.2866484669427718, 0.3334589212411835, 0.23371946757599232, 0.20853507783143752, 0.0658243428915739, 0.08206365254497336, 0.14565717038368026, 0.228379221873418, 0.11926091381258543, 0.18301627538617582, 0.21839081429906432, 0.2553879121138204, 0.10738642075129094, 0.14413524479154619, 0.13459666872457152, 0.1496256437272795, 0.17120951215826696, 0.0974062333003648, 0.1683345680395442, 0.14509090883356912, 0.10019129232293177, 0.2452014554892817, 0.1377060663916411, 0.17877289905182778, 0.19767179784755554, 0.2701077706390812, 0.10892657923602289, 0.20414019994918378, 0.20254707414536707, 0.08504044039235001, 0.1991664966748607, 0.12222628694989028, 0.14719901426184565, 0.17570871589404924, 0.08374271809213585, 0.14263476966129196, 0.14245195043904169], [0.06472666147014787, 0.029763059780722665, 0.05810658162039134, 0.027636169876542785, 0.006363286698732766, 0.01958966495529298, 0.017902511434869903, 0.052661646172524466, 0.031736262871192834, 0.02761806721889204, 0.04642478648513075, 0.03914175712833962, 0.03483722399499628, 0.10452836887129854, 0.02020335117835672, 0.022266019931844166, 0.045889658748262355, 0.0400335562505549, 0.02916459189427476, 0.04519845974901992, 0.055627961597976186, 0.018947629648591244, 0.11257655918598176, 0.06292710178381493, 0.11203323430832356, 0.048007746302192254, 0.037084952777912544, 0.03541920566931367, 0.04755889921779594, 0.07691793954901158, 0.07724111373986929, 0.05212112900710875, 0.11097302990815333, 0.04593190849728642, 0.23113274105614234, 34.76684977931362, 108.55043349727508, 91.06525251942297, 84.53816967625772, 74.81407273200251, 61.98739667092601, 55.052622672050234, 35.09686623850177, 60.260879147437315, 87.46696426022439, 65.13853865285074, 70.84275922467633, 97.24082823722594, 64.15220375983947, 14.106416010087537, 0.15510861161014727, 0.1106419420290378, 0.10910886219672619, 0.040271131607193145, 0.05395216341581076, 0.041842891218801664, 0.18536415101299364, 0.003540412139808459, 0.08002591229254201, 0.4371386255708433, 0.5497768701564881, 0.13539530006387543, 1.611125192815258, 13.420953385291563, 31.01544003332815, 40.43940505673809, 45.94829943872268, 38.43335982291929, 33.05479011228008, 20.135157800489857, 16.685099832473263, 10.8294875391068, 7.752209671082036, 7.845105615354354, 4.820222768091387, 10.457156550499702, 12.808677284948288, 9.869230524186166, 9.175628981282635, 10.16962524383299, 6.61733461964515, 6.760175574210383, 6.15483912729448, 10.581113253870319, 5.593492061861101, 8.833671846697408, 2.641082848272016, 0.927035520153661, 1.4455849917665606, 1.9743500313451214, 7.332219433399939, 6.853923653402637, 8.76159437241093, 5.113542022243624, 0.6807539419781777, 1.9728570791982838, 2.87779028857908, 3.5824009439637585, 1.67393668043998, 2.8033361031163126, 7.920684785612169, 20.985627674287368, 34.57810140425159, 46.23611511722688, 47.5957106005761, 47.01169713850945, 36.78440716958816, 31.576497823961322, 16.78601849463678, 7.026401546693618, 9.427215687690243, 8.324423663077816, 3.292934192765144, 0.1865295086416506, 0.025307256841070713, 0.012255414002274555, 0.13698284874760336, 0.046491466778060125, 0.07308752291024694, 0.16826486936019314, 0.1487610675394535, 0.0552063757523654, 0.42697766435242474, 0.46648846518608833, 22.833018918191236, 66.190930181934, 57.75506904048305, 58.39966350986112, 72.22937199377245, 55.64976038471345, 42.118485435362786, 20.675676099715695, 43.085020203744214, 54.85587658420686, 54.34538795102028, 79.87611893684634, 75.21266398891326, 34.86914127103744, 2.346698180321724, 0.42624445692185436, 0.08315491414959393, 0.02934683080492241, 0.00547735485240757, 0.05722893980301677, 0.025953396463826783, 0.05933256744737587, 0.047072881547313546, 0.013761025752061078, 0.010202610546032028, 0.01851027196783933, 0.0324890342721295, 0.05166928268848889, 0.012220597221335817, 0.02664844888532835, 0.07411030391531606, 0.0636016805055401, 0.008338394954109625, 0.04918221654670854, 0.07611569227470506, 0.08686369134774131, 0.07295920318292995, 0.05590069655989928, 0.025471362450550643, 0.0425699737764174, 0.043351234072038246, 0.02966796145624211, 0.014352111423748636, 0.03137407756801094, 0.024274715875846245, 0.055010073382647774, 0.07309870013306219, 0.01747796465943177, 0.01074325890400477, 0.03620085283933628, 0.048583894216966246, 0.08437472530790875, 0.02410696368784674, 0.03140501985927263, 0.021419188255564343, 0.11336375283257616, 0.04612590494235197, 0.0777292802869793, 0.11308690397849969, 0.029730667668064276, 0.06271995926996873, 0.05210586853565709, 0.03229108864381429, 0.031256722474110224, 0.06902705006782087, 0.04134384239272725, 0.04130165010029751, 0.019624426194857207, 0.040235064187718016, 0.01944749435830501, 0.04868052854773499, 0.057831977403933005, 0.056150816606297616, 0.04008870692022386, 0.06695986139558016, 0.05843568150134337, 0.08747767251465591, 0.04290065562893306, 0.06324639573933617, 0.050411232251433596, 0.07766861378425553, 0.06663763715374856, 0.08099515141258318, 0.01910249049204492, 0.05717920537497248, 0.062497479675878445, 0.4233222911434789, 60.266511671004764, 128.31029891967773, 103.0900941356536, 112.95323910251741, 106.3004364505891, 101.61093696471184, 79.1196035569714, 34.508581315317464, 31.47186467724462, 54.906981145181966, 59.53698219791536, 75.04965812929215, 104.56193216385381, 62.12398536743657, 10.147623688943925, 0.20695036367302944, 0.041909429785465045, 0.24655318698815762, 0.14768482125814886, 0.23746212884303064, 0.11084467953731937, 0.23250102005418272, 0.1681669786452286, 0.16367949605468782, 0.18033369594523985, 0.34449913689205724, 0.47487553449407705, 4.900990253494633, 20.41654275309655, 41.39584364429597, 52.78593986265121, 59.436844087416134, 52.77158791019071, 44.22448050591254, 30.232458460715513, 24.661547483936435, 15.914181509325582, 10.087940904401965, 7.950610999138125, 2.12577729936569, 3.0898399939460144, 6.26445564531511, 8.025562590168368, 6.434565407614555, 11.542171412898648, 7.497677264675018, 11.584415339654493, 10.010808475555914, 17.152108992299727, 6.8604759727754905, 4.183570117719712, 2.509719729423523, 1.1168138851081173, 2.385549747174786, 3.519363307183789, 10.589364940120328, 10.573582303139473, 13.194566926648541, 9.900549669419567, 2.1329412633372895, 1.8804611145488679, 1.6458305692480457, 3.844270879222501, 2.0012411883761807, 4.466152864117777, 14.82460787219386, 28.8670108010692, 44.50320020798714, 55.75983385885916, 57.22164630889893, 57.1016021697752, 49.62192466182094, 42.078814583439986, 26.926118096997662, 14.278150123934592, 16.19115967904368, 14.126536788478976, 7.2991401245517125, 0.9270170727564443, 0.04354944400068733, 0.058282820147372065, 0.2695249003027716, 0.1317859534174204, 0.10488178821340685, 0.23924602586175167, 0.061102889388078646, 0.05680535829836323, 0.4730745230711276, 0.5221500235699839, 18.51431481299862, 71.80203760823896, 69.38549672403644, 50.47440082796159, 42.068941977716264, 24.99556672188544, 24.117703014804473, 39.338615402098625, 72.2271676217356, 83.75287978879868, 75.22687865841773, 90.5252911967616, 87.74784518826394, 54.94988795249693, 5.5542914040627025, 0.363945328900891, 0.14738859037958807, 0.06625132199617163, 0.035922372217981086, 0.03721743619309799, 0.04981148116771252, 0.06736718268404085, 0.008001260247246754, 0.020942273624842207, 0.033850759387977665, 0.03565532162845616, 0.03676303880169027, 0.12287276556655286, 0.01235286038624303, 0.07201244874346642, 0.013535435840998207, 0.02009693582001473, 0.02374721071382444, 0.018738227175368417, 0.03457902172099679, 0.06817623281911497, 0.03228760677419844, 0.017250095636794166, 0.02153155994751761, 0.031010764200360547, 0.011393077664017197, 0.031200671651130243, 0.021602237304191918, 0.06127641596380742, 0.02374709771585561, 0.07681060296994063, 0.021234319748116598, 0.07769692839393694, 0.013380931228429321, 0.065250106366171, 0.008826331674842345, 0.0614778472921781, 0.17247364916388067, 0.13395565231480908, 0.17864557523881236, 0.3078528307378292, 0.14221195041412307, 0.1256736979309109, 0.23220160224985695, 0.22657552914273357, 0.11621092626404379, 0.22021024247571347, 0.13057970201536534, 0.17753929831087592, 0.11722636814679831, 0.14426734899320912, 0.20083900450939135, 0.1603436581189594, 0.15833013390581455, 0.1377540694609765, 0.1478764964568038, 0.1728457227469452, 0.1869449887665049, 0.14065072451147342, 0.2786825008450016, 0.1498067469125794, 0.28168430912398523, 0.30430814191218347, 0.1847894778174739, 0.14512149106350639, 0.2815436247375704, 0.2272238080660182, 0.1679232707547565, 0.1598145058679004, 0.19130381455104198, 0.15332169620500458, 0.4344638449049765, 64.1141293125768, 143.83081959139918, 112.22213283661874, 111.28314095158731, 97.62684437536426, 79.80782262740597, 68.90558688871323, 47.81008774234403, 84.29858346139231, 116.7488225813835, 95.67871293713971, 93.88801759289157, 119.32744364584647, 80.67590590446227, 17.82521320927528, 0.8444102408905184, 0.21111858678200554, 0.5583791795276827, 0.48831271668595655, 0.45092416326365165, 0.3112382345622586, 0.4320787986920726, 0.3075846999643311, 0.42176989057371694, 1.1356695765449156, 1.6954282046325746, 3.521595135811837, 3.756472545285379, 15.7682801254334, 35.236180982282086, 45.225716483208444, 53.60673504491007, 47.59616951788626, 39.596334734270656, 25.1725636759112, 23.456793446694654, 15.45976806071497, 12.072518025675128, 12.732675479304406, 12.589271664619448, 21.04924459611216, 26.31670532688018, 26.364281715885287, 23.42631466927067, 23.166145816926036, 19.78588838731089, 20.799958359810617, 18.912904108724288, 27.290351352384015, 17.980150753451934, 18.396102420745358, 8.346999845197125, 3.1711865192459476, 3.0031548776934227, 3.0325613771715476, 10.36417382378732, 10.157150145499937, 13.103164915115604, 7.935945747360107, 1.096710144512115, 5.579681886780647, 9.275295426768642, 14.55713458599583, 5.779066258861173, 4.722108110304802, 13.844532101385056, 29.363125908759336, 43.85515013048726, 58.23666549498036, 55.89588126828594, 56.30034823571482, 46.71496199023339, 40.19751248821136, 21.906515859788467, 10.05726698906191, 13.044900067390936, 11.727927019519191, 5.255588206552691, 0.9539381991471014, 0.26594282638642097, 0.31159700885895764, 0.2898938298946427, 0.1654657985894911, 0.3152684086272794, 0.3926050152269102, 0.3977987236313282, 0.17134903209103694, 0.7630236338703864, 1.0856620534773798, 31.713080636916626, 82.47428124950778, 74.48178522048458, 86.45055263273179, 107.90501533016082, 73.09594908068257, 56.903820576206336, 27.943267130082656, 55.54156180351011, 73.30847878609934, 71.53625780536284, 95.91250188889043, 101.70082199958064, 60.99289148084579, 4.247315006871378, 0.6201642319079369, 0.2504723855564671, 0.2125174480099832, 0.10770636971198744, 0.13124328737537708, 0.24745712477353313, 0.19055735379938157, 0.12040112843556751, 0.20281379531708457, 0.11330160011927928, 0.12021746651660051, 0.143007364184145, 0.3286306980636812, 0.1415967205238919, 0.14797754345401642, 0.13961043839733447, 0.2053130805612572, 0.13112278174488776, 0.09664832719511564, 0.20124382069033964, 0.21568686100504092, 0.15141119549591697, 0.15108680322525964, 0.13001532504154792, 0.18782531572205408, 0.12106518877009231, 0.10884765685806352, 0.10941446233060091, 0.09472512474824345, 0.0881490336670991, 0.15255494944510922, 0.1990001636647409, 0.14826655778433048, 0.13785828806219563, 0.20987551719430955, 0.10954317276275928, 0.21142949590519552], [0.03865227674043948, 0.02672578354606465, 0.07132702221673343, 0.08606561159174289, 0.05871308959960457, 0.06807362300253685, 0.10245395598993187, 0.007757977056767672, 0.048799885046337886, 0.10793278699800854, 0.048277030038016464, 0.03885549305367374, 0.041505027291995865, 0.07064331938783008, 0.13507201095982907, 0.04311907112658505, 0.04227186598244213, 0.05362890112484175, 0.045018589965278105, 0.01671980957560722, 0.020200445789903886, 0.09320384266996577, 0.061146165694921255, 0.033952534168718324, 0.029881236503922173, 0.12688430837325512, 0.0331794748443269, 0.07645627198320243, 0.18267912009069998, 0.06206029628012931, 0.09297618432150734, 0.005277521774968914, 0.022132285878122337, 0.9569230615612, 51.78362523355792, 103.25734399980115, 88.5060001188709, 83.00612326591246, 63.59083021840742, 53.636478377926736, 32.52810405146691, 36.87650834360431, 70.56593402739495, 99.81415410195628, 68.10011248434743, 79.90059452672159, 87.68420865458828, 27.168142064925167, 2.5980306681125396, 0.04843522719438038, 0.008038935972557915, 0.16840820441082602, 0.08911859454406847, 0.0626058389823283, 0.0881582343830697, 0.07762794217635548, 0.25740088474365974, 0.2018961905231399, 0.6236514641392616, 0.5653722752486506, 2.2320818660720705, 14.20686791020055, 42.92430893067391, 68.76682127675703, 87.40391608207457, 93.96421355585899, 91.27901384907385, 85.53223948324882, 80.69052850046467, 75.55662447406401, 55.59013643572408, 36.617863332071614, 25.99935223979335, 21.41235213125906, 11.123732962915975, 8.547680070323329, 7.997098930420415, 6.3780769032816735, 9.040048333906359, 8.09828088168175, 13.383185863494875, 6.6728037980295, 12.58399901851531, 8.140014410018921, 6.569204686149475, 4.852293537509057, 1.4081729347667387, 3.7628814529988075, 7.080183125311329, 17.480636912007487, 27.40906580801933, 31.836301895879934, 39.70754569576633, 46.43251603649509, 44.755514514061716, 27.59503322262918, 13.120263507289271, 3.9029480661115343, 4.977493632224299, 18.48504020321754, 36.66265287706929, 53.49643407329437, 66.3821457278344, 70.96286219935264, 76.81683494198707, 80.0232078183082, 78.37074464367282, 71.37016111804594, 69.20544424364644, 53.7098345448894, 44.7194012518852, 37.01461499737155, 31.266197158444314, 13.801394854822467, 0.18453257789294567, 0.13345205675690405, 0.4688679342789035, 0.09858059246213206, 0.03214840093747743, 0.09445183054213563, 0.02962221643106351, 0.05575868301093579, 0.10535512329830278, 0.1958182787582759, 0.5087450170709241, 7.418165428023185, 61.7131680826987, 83.77931656376009, 62.36594461625623, 76.61238531912528, 67.02639502863731, 37.53092835026403, 27.343026822613133, 23.95011386563701, 46.28473681788291, 47.913520643788004, 68.73446172283542, 78.93544043264082, 67.08812529040922, 7.654996668138812, 0.44353251796095605, 0.04021598859840343, 0.08920088770889467, 0.0321792512981882, 0.06520410278631796, 0.018683040116523063, 0.03147430485114455, 0.04173785290350357, 0.021079705968018503, 0.03176672635750184, 0.03905735722172164, 0.016621644984209732, 0.04397427039821783, 0.052835739653317206, 0.10207864951582686, 0.019594736457351717, 0.09168344925368026, 0.020069659259470723, 0.03718120406471914, 0.013344899240520694, 0.035799798150096214, 0.08901130393027298, 0.048795863084735415, 0.0328270782295975, 0.02165050850430083, 0.06860390140284454, 0.008677532502089538, 0.05408360495141918, 0.044813642293334975, 0.08135407892686707, 0.011472147513901996, 0.08152592010916242, 0.05421059551618753, 0.054368934398817445, 0.025198006957408883, 0.015597415115353803, 0.04512154069098254, 0.015808633216957173, 0.035394468690238656, 0.1329366787667236, 0.06526632444752802, 0.14229940701155894, 0.028390850751630725, 0.0375587934808385, 0.06245208130548559, 0.04205330875852416, 0.10987697259312677, 0.01909653607365345, 0.060409518529570876, 0.06948514766390286, 0.0497913062422266, 0.1890818684572174, 0.014594357043895272, 0.021634075918325016, 0.05377088403028827, 0.0899037350750258, 0.0662477903308407, 0.022928044387710192, 0.014222749816854636, 0.030584497557532404, 0.05061568196622595, 0.07557598333204947, 0.06495118651899599, 0.07575690265624754, 0.22291932855882954, 0.018036866019810402, 0.11181236349887426, 0.06427512158669772, 0.0336499409299464, 2.8804354369640355, 81.15121087720318, 118.7004606185421, 103.20846342271375, 116.12639734821936, 92.90748780773532, 83.69116521650746, 44.4319111301053, 36.497364198007894, 43.27900102061611, 74.56561411580732, 76.99928006818219, 88.81942887460032, 92.15073708565005, 22.450146559746038, 0.9744612043423038, 0.10642010808712053, 0.237305234036138, 0.13989644966298534, 0.25473451572320155, 0.17948733732825328, 0.3022895921622553, 0.18262503428324578, 0.25986070113797344, 0.4609646035298225, 2.0801008084127983, 2.311779279862681, 7.412520156752679, 24.812950972587835, 58.03746792577929, 81.58963772558397, 96.87840907804429, 102.16276737951465, 99.9040626710461, 92.64892516597625, 90.5716065437563, 86.28497369827764, 67.55146703412457, 46.73984550660657, 35.38847877133277, 27.686347961425785, 16.09099215076816, 6.327006663045576, 3.328286760276364, 1.1718215721268808, 3.590739167505695, 4.771759433131065, 6.899482473250359, 10.748455293716924, 12.27390721920998, 5.751621434765478, 0.16045317804861456, 2.950235975365485, 1.5870365692723183, 5.1084983444982965, 10.401169619252606, 24.64807022002436, 35.27268648147583, 40.84136170725669, 51.90279468413323, 59.50748989658972, 59.96869002619098, 41.73342635554653, 21.512154879108554, 9.603216359692237, 8.96800616095143, 21.411163653096846, 38.79505726598924, 58.163073985807365, 72.97998812890822, 77.79373261236375, 85.37873360418504, 87.7056561746905, 87.75124196083316, 81.0355244913409, 79.6414670636577, 67.64139913743543, 55.01618777551959, 46.59057578732891, 36.25298876916209, 19.99059492541898, 1.0304703827827209, 0.15977805540446313, 0.6692637875676156, 0.30262330006207194, 0.13836136268031213, 0.11471665644597624, 0.06555199097361296, 0.15061902993869397, 0.16135133953104097, 0.15094801873689698, 0.621724967514315, 3.750407090110164, 57.139672694667695, 90.88871448270737, 67.36942983442738, 60.783064288477746, 36.293428405638664, 15.626404073930557, 30.094292971395678, 42.634394784127515, 70.12409471696424, 78.40705794672813, 82.80098330590033, 88.93076142957135, 88.48761989224343, 16.76989559204348, 0.25204580757887135, 0.04298646896777134, 0.02909622429269216, 0.055809681484055136, 0.12201663166765245, 0.06884936363466325, 0.041296919507365075, 0.06627016775910893, 0.05216589918540371, 0.05832940212360794, 0.09411515022117285, 0.023873276227424224, 0.04516941735581045, 0.04279824116477563, 0.10504478108017676, 0.0462229146562036, 0.019758169824678092, 0.009675098680740884, 0.03975128349397452, 0.07353687178223364, 0.007305366086638383, 0.17015422604257063, 0.058384863058886224, 0.038994882751496575, 0.037589873667926564, 0.030567808332101955, 0.07417012006044388, 0.0323225174009079, 0.06524508082938772, 0.03169676529303674, 0.039134632510643814, 0.03365064573083674, 0.040209649220830014, 0.031062793061738054, 0.023357574565095768, 0.04240876206407144, 0.1292100900243367, 0.2178607120989792, 0.16354267275141132, 0.19171639886354247, 0.21676686111717455, 0.1416788451493748, 0.19521697634650817, 0.06264406676974989, 0.19624327369514974, 0.32393372106936674, 0.19284928968596846, 0.1453254849559838, 0.2542016249630721, 0.19993725773547927, 0.2091785150790407, 0.2291935120498942, 0.13376933973162405, 0.159844214757604, 0.11639700902085151, 0.1283178580624442, 0.11224976906012143, 0.12450232651204833, 0.16544690686127833, 0.1772665250445566, 0.1435318586206244, 0.14473599562000844, 0.1480374208861782, 0.2653523871014195, 0.35913466445861325, 0.13789616344917205, 0.17155563068245688, 0.1283665735935492, 0.06233389692140683, 2.7606445358645533, 85.61376202491023, 135.89901831842238, 110.11950708204701, 112.10479905528408, 80.9100478695285, 65.39947825093424, 42.09562193962836, 51.31813795335832, 96.4691097505631, 136.85940281037364, 97.26883396025627, 100.48215727652274, 107.65222641729541, 34.42961223663823, 3.133770539875954, 0.4427899336141925, 0.3086683772985013, 0.4302770824682328, 0.34338472411036497, 0.28473416643757976, 0.32957997293241564, 0.21654965986888255, 0.6949165787908339, 2.0100328133952234, 3.0386979253061357, 1.8999283280103438, 4.9368760182011515, 19.138722804284868, 50.48024908188851, 78.08289758620724, 98.67872991869527, 104.37037144937824, 101.73333060356879, 95.6437881531254, 92.16394762839042, 87.6662677334201, 62.522717829673525, 44.22332340671171, 35.47140552151588, 27.72173950749059, 17.34391877728124, 15.097766633956665, 15.27219835788973, 17.013847404910674, 19.706176019483998, 21.14054168424299, 32.03836867886205, 22.196435889890118, 30.32588343466482, 20.37042940816572, 17.094891417411066, 9.691462824421546, 4.13934882610075, 7.010574783048322, 11.779706228163935, 27.543389335755382, 38.78154470074562, 45.048040959142874, 59.1792385039791, 70.55394726414835, 70.23501934543734, 43.944317371614524, 15.089916990649316, 6.045129452982257, 8.826816524228743, 22.400161835455126, 42.6700452066237, 62.66181684309437, 77.57268351893272, 82.46324369984289, 92.85649699549522, 91.7018767326109, 90.5684608028781, 81.66579446484967, 78.18753073292395, 66.44671578561106, 54.685751622723, 46.27438960536834, 34.48676117004887, 15.600425235686766, 0.6109577549561378, 0.41310500714086723, 0.9160283075705652, 0.21250312216579917, 0.1620464570700161, 0.3008274673934906, 0.34183045428606773, 0.2512647656183089, 0.3838583136037473, 0.28427681194678434, 0.7671081082474801, 11.700427282241083, 78.94286940174719, 101.74162249411307, 80.61386185307657, 111.07844814177483, 97.55082099668442, 52.482391557385846, 34.17589764441214, 31.480907701676895, 60.70998268742716, 67.59964158458095, 84.64025328236242, 100.60364877024006, 96.68565596303633, 16.977516451189597, 0.3777287521910283, 0.15246516394038356, 0.08919816809676348, 0.14265620480141333, 0.3400466951631731, 0.1584113392257883, 0.1959218844891556, 0.13640511120038648, 0.12878123400432448, 0.20142605768576746, 0.10720864238758242, 0.1445389884494005, 0.08376648213954703, 0.17187666748800587, 0.16650383240513264, 0.13614591301208542, 0.1858091561664497, 0.11158411526271414, 0.10288584571812423, 0.1414810106038086, 0.20706769769951222, 0.32262475259842416, 0.11691483849238966, 0.1807397225451085, 0.12933868554330644, 0.18577409998303462, 0.12208385588300806, 0.14008509115346018, 0.25797456202487795, 0.165464817996948, 0.19743722172514086, 0.2478403525967752, 0.15269506692646012, 0.12721577163545356, 0.13187776139426616, 0.10481480148530777], [0.05465695281482993, 0.06715063261048448, 0.13291225588369754, 0.0524366308274048, 0.07373891215050414, 0.0427187365599938, 0.12492257936467087, 0.04022602435021151, 0.03476806540763186, 0.059238350124008236, 0.023081329005259662, 0.06240329299602778, 0.020594481198537736, 0.022541047411880667, 0.03103215912086589, 0.01761049212467286, 0.05222899418684745, 0.03240437006517764, 0.013012032122201016, 0.06454991732513712, 0.07715620821522129, 0.11687308670051637, 0.04784912013659074, 0.05876147188246251, 0.08017769729297969, 0.12504608805982337, 0.10410031724360683, 0.13540345123938977, 0.07711100902768873, 0.19567143502494982, 0.07611009217197857, 0.0804730395095483, 0.35317422461605846, 43.74641810694049, 112.83070425833426, 83.94071425161054, 89.07290027987573, 60.06080688968782, 47.55002675517913, 43.853392908650065, 65.74774942090436, 65.57904827979304, 61.52996201669017, 62.15605074359525, 79.41491880724507, 69.07046764127671, 11.824952729286688, 0.3074720543959449, 0.03729092700767421, 0.15634158415900123, 0.23431018265264653, 0.049679285035498684, 0.09687167246856036, 0.35347784058220927, 0.350820618651567, 0.12199089877427587, 1.1178263469088463, 10.976966696400797, 26.43944609549738, 46.78878491924655, 62.214003762891224, 82.05086138940628, 95.31770583122008, 95.74939404764484, 94.93310959108415, 90.76053142547609, 91.96154548275857, 87.10312520304035, 85.9782757297639, 89.8344127593502, 86.30390305672923, 72.08965716823455, 52.89836283653013, 43.43276969848141, 25.309497540996922, 14.941833788348784, 6.860393112705601, 3.619537699607111, 3.0377217454295007, 5.7174953433775135, 3.0218015803444773, 7.9416081790001165, 7.920547992952409, 11.80351403451735, 5.118065985941119, 0.7234087370095715, 1.1638157694570481, 8.886662087132855, 21.96246650911147, 34.717314166407434, 47.388856564798665, 57.588889983392534, 70.0890051934027, 74.90215347659203, 79.72730421250867, 85.26958188702984, 86.80289914531093, 86.23405348870062, 69.8027192392657, 49.976181368674006, 59.63192316793627, 73.9896297454834, 87.26455426985218, 99.5714770593951, 98.10368691721271, 100.6539257111088, 105.2646561591856, 110.50173421059887, 103.74621252859794, 97.8272618016889, 79.75221126310288, 63.93749713897706, 48.71679067611695, 39.70625915834981, 18.997009531144176, 0.6680299570002864, 0.49056660864622365, 0.2577270849818184, 0.07961460734687506, 0.05504576541904, 0.030231980283954935, 0.030343013237260526, 0.12563522499535354, 0.07167795943396707, 0.11127711318793798, 0.7424007920968918, 0.6153913815656017, 33.406607104885964, 85.77133147947251, 77.39154846437516, 57.604822651032485, 80.80754849218553, 65.56396676648048, 35.6980400700723, 26.535246064586026, 28.127524391297374, 43.106271605337824, 59.03035317697833, 76.565214895433, 65.85006052447905, 20.15028638224448, 0.6516028255704911, 0.04990588618262161, 0.06403802503501216, 0.010590958709438002, 0.016829846614611246, 0.034006041579789696, 0.02018988718308749, 0.1305037214150352, 0.15811634940966485, 0.1333228790111119, 0.141476858407259, 0.036404030848174326, 0.059393919598791874, 0.06293148380674182, 0.16103108413517475, 0.15874582853528763, 0.11667940435149979, 0.14052736903390578, 0.06543874785664582, 0.03656356865840574, 0.02699886707799329, 0.06881076046415875, 0.04182062104284283, 0.021531879789226, 0.05171795991519767, 0.10856072628690351, 0.03129945485852659, 0.015984136299530587, 0.040617227148745334, 0.06208070486243214, 0.017246405008218942, 0.042844823141011505, 0.05235336856135438, 0.002024541036300962, 0.06849537738749097, 0.045885142659948724, 0.09069523413575466, 0.1391319245580704, 0.054220723198546525, 0.10424498528722795, 0.03881648002612976, 0.11298692950438108, 0.11179298913526921, 0.046431030101713636, 0.05988021306092701, 0.022346457248673807, 0.022108581202525287, 0.02975815681800727, 0.04003084046886333, 0.047238582534895796, 0.05296786683761785, 0.022398244792355165, 0.07404091933201398, 0.06887808427094452, 0.037818857348493995, 0.0354296627694801, 0.0254900933002993, 0.04299821692609018, 0.06609022136657469, 0.07130141189742474, 0.17249395049387412, 0.1160758036759592, 0.1471546730927883, 0.01787256697312959, 0.2831902541220188, 0.02986902314718933, 0.05112374764716914, 0.1261195534419629, 71.74610460958174, 124.2413733082433, 103.24389811485045, 114.07267570495607, 86.69068013468097, 73.55423096687564, 47.93737649917603, 30.40089484184019, 30.143073528043686, 53.67832614529518, 70.1130336330783, 90.86913401080717, 68.04348130379954, 7.691589930365163, 0.26436165155422303, 0.05128473336357744, 0.16210251938431494, 0.18400043789898196, 0.41545910340163017, 0.11885381468962278, 0.3353350092807124, 0.27673967122550935, 0.6563041539442155, 4.110027393025737, 17.565395409061065, 39.580484436404326, 63.66075038909913, 80.25512972185689, 95.96797989260767, 101.87720314148935, 102.92053791784473, 97.99482545545025, 95.62707885619133, 96.48939624909433, 91.42000736728792, 89.58077661452755, 95.31966701630624, 93.33179412349578, 81.0626123797509, 65.09391776977047, 54.71862108476701, 33.177956458060976, 20.82661870987185, 9.899142519120248, 3.714414195668313, 1.4807035653821885, 0.48700209346509754, 1.245669873972093, 2.039672816472669, 3.848397702940049, 1.7107761939687116, 2.975423720575148, 1.0062983475865857, 2.26913183927536, 13.546819302343554, 31.55136523708221, 47.65533847193564, 57.651283125723566, 70.9871102917579, 83.13019567920317, 88.8241357188071, 95.00203347975209, 104.5336675643921, 105.57438219747236, 107.09545381607549, 97.3561066965903, 80.22671607232864, 81.04739358348232, 87.31616481657952, 98.32969388654156, 106.41920581940683, 103.26336876038583, 105.61606914766374, 108.96832281543364, 113.70141552340601, 104.28707599639894, 102.48303674882459, 88.72072635158416, 75.65961022530833, 57.95840471021591, 49.53512260990758, 24.88023138815357, 2.3612612053271267, 0.4252538439487258, 0.3777407031626471, 0.30202480153210703, 0.6745434203936208, 0.012772593256686966, 0.03675020682895857, 0.12621760503539156, 0.08966040256763659, 0.11324304801922654, 0.6213216375439399, 0.4983558229381039, 27.035815023606826, 88.6734147225657, 85.35525429633357, 60.808038019364886, 55.68490089908723, 26.381948071141398, 18.647469474423318, 34.54670675339238, 49.11291083981914, 66.18008090603736, 80.41287176070675, 85.33674855386057, 84.95840457177933, 36.79582911152994, 2.1912161621355244, 0.07911119565007188, 0.10235240337468925, 0.0438631761578783, 0.047884532550890604, 0.03607293147773993, 0.08776056580245496, 0.1089166813800412, 0.13948738935493654, 0.11603130162843775, 0.09609435369530994, 0.0900533214031208, 0.12002856455623143, 0.07951157618193858, 0.23329252677579082, 0.16577143702776204, 0.09754131758405317, 0.2083071513522056, 0.10858598420576704, 0.06026454022034042, 0.10573586133579094, 0.07107558449910534, 0.08152909171316894, 0.033155986588568456, 0.0990228933252154, 0.10743270012279672, 0.05920117187704291, 0.019672607379635016, 0.028662689390682408, 0.024402472528538877, 0.002105431302615832, 0.020638801300177173, 0.06817234109245962, 0.02664485018730404, 0.027422178536653522, 0.15904146186526746, 0.15616187525372352, 0.24650688463401413, 0.13516849207301296, 0.11384348475163984, 0.12703159643757728, 0.4468031618143282, 0.2610042865478224, 0.14224296165329797, 0.11022708243540219, 0.12774685442808176, 0.12360467064765193, 0.15871808083067018, 0.12095576843186734, 0.1423537532889074, 0.20348628261877647, 0.07832069250364458, 0.24177598526641247, 0.16866156500914406, 0.19760047506180503, 0.11958611813644249, 0.16213455718130837, 0.14735817668899415, 0.14813433100859966, 0.11220602543964503, 0.32477865476281415, 0.18561838495154537, 0.19423103650971768, 0.11869007105668707, 0.3533107721276822, 0.1826777258106778, 0.2565033820968482, 0.24110873800612267, 81.58378554928689, 145.46647933221632, 104.69618705011185, 115.5178180817635, 72.1838568102929, 61.34268453044277, 57.62790187712639, 86.34812385805192, 93.39437946196526, 87.19019397612541, 88.29831061824676, 96.49698211300759, 87.4159263795422, 14.110411924700584, 1.6055583689481983, 0.18493932461546314, 0.30491644636757914, 0.22447186702441788, 0.31010264711033914, 0.2760595077228162, 1.135201711327799, 1.6683737789430928, 1.0807084676719483, 3.5347519911104635, 13.301669205388716, 31.246363693668, 53.856229166830744, 71.42741203308105, 96.10065798605643, 107.68224039385396, 112.08182181081465, 105.95682897875386, 100.13171703584733, 103.85965531872165, 98.46918121460946, 98.26775966152069, 103.25601039394256, 97.80394723338466, 83.88893896533598, 65.15842899199455, 55.357555573986424, 31.106252708742698, 22.250368479759466, 15.288756643572162, 11.680921335374157, 11.765923019378416, 16.609196086083692, 11.355904917563162, 20.788259890771684, 18.873176382433986, 27.4849989721852, 12.946578994874033, 1.2833332078110788, 3.392366766929627, 13.108879808456669, 33.93971212448613, 55.35764971087056, 67.18177580064344, 80.85369125489267, 89.19343471527101, 95.1473572946364, 102.09636949723767, 120.65674274198471, 127.60648450543805, 120.02580596554665, 108.03154314717939, 90.01648133800876, 97.30084050086238, 101.6039865247665, 111.05639657666607, 120.71692758990874, 114.66464765610235, 115.7070645978374, 119.77629615414529, 125.78810507251372, 114.76533489842569, 108.92744387349775, 96.66124313108384, 82.47534028945431, 64.32470175527757, 51.33034436933456, 21.48202323144482, 2.2895548853182026, 2.2944409328122295, 1.2850803785747098, 0.2687339604862275, 0.28700770089222544, 0.1083006777410065, 0.18059200547154874, 0.42623869594066377, 0.22789234235402078, 0.28957728236433, 0.9688719494208213, 1.2896999500451551, 43.86786253221574, 104.48685015401533, 92.53080691060713, 79.34762662456882, 118.1823233635195, 91.81108336294852, 47.260598982534106, 32.23946467522652, 36.05867455082555, 60.15436718540808, 78.59077392085906, 95.39954216249528, 97.44252435622677, 37.132901914658085, 1.5913641693130618, 0.1825065204813596, 0.21698257615489347, 0.1667312073010591, 0.16433971062783273, 0.1695667438569569, 0.24226674119070654, 0.25256072591629725, 0.3079675294218525, 0.19969834555541316, 0.2265730316961004, 0.1349383439388006, 0.2758647681724641, 0.08771898254992501, 0.2156252368924118, 0.1788660706651788, 0.20489620615638074, 0.20508763620689993, 0.2227993745116457, 0.11950530352131014, 0.15750043004030184, 0.24446624090834973, 0.15208751323723024, 0.1184016083096785, 0.24327256867001135, 0.18116344577602803, 0.26839017086932737, 0.0984596501615259, 0.11334100768210427, 0.145867201049001, 0.12683553155511618, 0.14733079670658036, 0.19264333460840488, 0.2308896000707342, 0.14386881473323992], [0.06746096716773126, 0.16486016012007193, 0.045948030817652905, 0.17389412939308152, 0.016894483368002602, 0.07517862884748368, 0.04984389817822845, 0.0983281588302024, 0.07030800270337252, 0.014891426788733132, 0.010550865497920784, 0.017498737133498636, 0.043837914408575145, 0.0358853625103591, 0.04666825688834633, 0.014210820870263683, 0.05470133611872312, 0.02708047650934708, 0.02490953080386164, 0.08524894654270142, 0.030246037997365482, 0.07018494600009534, 0.012165248326416458, 0.01649662326540678, 0.09512484644449527, 0.06040212961154119, 0.08226363979760679, 0.09481506347055398, 0.07946999292940864, 0.06715329859646098, 0.05044818450246127, 0.2730913766689839, 31.231321404057166, 93.62793307150565, 84.11414577114968, 77.80102037614392, 68.91611453025573, 56.80654971830307, 37.10023249349287, 69.10037963621079, 77.76232227202385, 87.22629547119142, 88.4071328563075, 101.91281041791363, 48.76875423615979, 2.3879215553883584, 0.25022653261980704, 0.030157683161838405, 0.13255173490653116, 0.024677890713416764, 0.04596162504786926, 0.30812047121505587, 0.764410253013334, 1.0827256691071296, 1.122844774396189, 8.629629169740985, 33.8440651278342, 61.106930471235714, 84.25435481532928, 91.34829859579764, 98.29152922476493, 96.92016663089876, 95.5239518996208, 88.76509620297341, 84.26631804435485, 78.59723798690304, 79.37309849646785, 78.91336533331102, 80.92532157897949, 82.7939308843305, 88.42450111143052, 79.18329500382947, 75.41166151723554, 68.95629529030093, 54.48707965112502, 43.376346403552645, 28.526070540951146, 11.352114927384163, 5.442704385326755, 0.8201378788198195, 1.9935885215959244, 4.969250771307177, 4.6756638153906795, 2.8875135990881153, 0.5171969893478578, 2.8462186407658363, 6.878364922538881, 25.27600246091043, 37.99555270902572, 60.52565090117916, 70.28534335474815, 88.2485592749811, 103.80520497598957, 112.50976024135467, 102.03666317847468, 97.59463387150919, 88.44080248186665, 89.15115156481343, 93.15841751713907, 96.21288484142673, 93.5004952646071, 98.94752210186374, 100.1145762781943, 99.19306247465073, 100.80936139629733, 101.30631785238944, 100.71636984425207, 98.47090705748528, 96.64951524426861, 96.27019066964426, 97.06884799465057, 92.1522746547576, 77.14595317840576, 62.95892069416662, 41.58673755584225, 12.72091523293526, 0.841573202802289, 0.5889747087513247, 1.0162532617968898, 0.1891830073849809, 0.04998909482251733, 0.00819234699461489, 0.05760499321284795, 0.08734281805734481, 0.05967034327407038, 0.13271005463696298, 0.07545359312526642, 0.8583972290638955, 8.289429256992957, 67.66458034515381, 83.7330561299478, 58.40193063982072, 84.72143065544867, 87.83430207160212, 50.4182638660554, 29.964187952779955, 21.373789348909934, 43.547181314037694, 52.76781459008494, 75.49114442640736, 78.23637993104997, 53.709210888032, 2.800791955763294, 0.03961982663660761, 0.13714574968382237, 0.07927088667788813, 0.07034268350370469, 0.05383835339377965, 0.06195310142732436, 0.13347059608467166, 0.1662483574041436, 0.18147113732993606, 0.14973930053172574, 0.1016501765397768, 0.16809714207005116, 0.28193200067166363, 0.31073326004608987, 0.18629908471578555, 0.19288344188563286, 0.286619539462751, 0.12073416983888996, 0.12670394063236254, 0.024692827512720422, 0.14419291589048602, 0.04935620277519188, 0.0366683503342492, 0.14864692043873573, 0.0469841915483196, 0.0042614631914353425, 0.052511535074201324, 0.15653531247329328, 0.05773360405357615, 0.02284969849091384, 0.020269815051447482, 0.010310976555751217, 0.027438821796808514, 0.0369653741138116, 0.17046507387872667, 0.06711748398600087, 0.15531412235671477, 0.05818509797175085, 0.028440860971327753, 0.09289809697938543, 0.07812778390343152, 0.12267578137858261, 0.09573364119616248, 0.08399308328666995, 0.06268587218777788, 0.03267243572120224, 0.03885803646558235, 0.03212340923416759, 0.06679466985646756, 0.044879223250093005, 0.012790473748839671, 0.04927718080580235, 0.10879987595422615, 0.05581678311911322, 0.011382452024507427, 0.08147002633420691, 0.05523156855375536, 0.09182868420236534, 0.13147320568321214, 0.03593351496683975, 0.07726637165873282, 0.12363211191709965, 0.084669393367104, 0.10009881784959186, 0.12367262264653561, 55.09587464794036, 105.00625825697377, 101.36320790936871, 103.01016407628214, 97.69357958147603, 83.01926320598972, 32.57812799945955, 20.44058099869759, 47.20573679093392, 82.00050600113408, 91.80222665109943, 114.23485786684098, 45.45310020446778, 0.4189095940561064, 0.25120216091313674, 0.021379945401643074, 0.08938905422485645, 0.12589082257041048, 0.22286786277207637, 0.5217541093307158, 1.1287468383389136, 1.384366844450274, 3.158239020455268, 12.544671373982585, 44.130249484892815, 72.65818119049072, 93.91926319368424, 98.37975117468066, 104.0411590760754, 99.50991938191076, 98.23234065886467, 92.63985664613786, 87.6209878921509, 82.88744803397887, 82.7029868095152, 81.4801565293343, 85.37506226570376, 86.33559580772155, 90.80584264570668, 86.9381973820348, 88.34547319719869, 75.98563763403124, 65.75029503914618, 53.234027508766424, 37.747541243030184, 17.85698244648595, 8.607755091882522, 2.449662603678242, 0.6248737114571756, 1.318218277827386, 2.890443854754971, 0.4510986168057688, 1.944813480780971, 5.857129760326878, 10.427039611724116, 31.82512314088883, 50.82422917889011, 78.04683531484297, 80.53364153831237, 99.65740050038984, 114.11827718057941, 120.30235659691596, 111.52294681918238, 110.07277596381404, 101.74543503792056, 100.37284866456064, 103.68643560717183, 106.96015557935162, 100.87606522344775, 104.94035459333851, 105.81262696173884, 106.6514415125693, 103.73400611262169, 103.72504741914811, 101.03248150117936, 101.3504288273473, 98.55073513523226, 98.40344229052144, 95.91665960127308, 95.73399482234832, 85.0464774716285, 70.10634206956433, 50.89616152548021, 17.771698351829283, 2.6942532725872534, 0.9035424840065741, 0.458665297877404, 0.37904961034655577, 0.3992007564633124, 0.19131748155961115, 0.06117641467661147, 0.06149088227820974, 0.017568518167301532, 0.14743748211091565, 0.06528083415281388, 1.106448163909297, 4.768042987392795, 67.25101347892516, 95.9163301221786, 64.85226446582426, 80.77314146103399, 50.79348956384967, 14.359506945456229, 13.965806884150352, 38.99040699005127, 75.87847848092356, 79.82205298639114, 96.92299858216317, 91.62371173981698, 76.79013144585394, 5.6266052011520635, 0.11776832938795129, 0.12675484717493096, 0.06550933519798903, 0.03873724355212143, 0.10905029477491494, 0.01678418777432413, 0.10070054927059721, 0.09944997968212252, 0.17947249054428072, 0.1600649093668307, 0.0729086720234444, 0.1853349170978031, 0.29389283950290374, 0.2753951256313632, 0.26346263205332143, 0.18973895739163124, 0.40882279014875816, 0.14721602141376466, 0.02823154468299641, 0.05166169075715927, 0.13613766990602016, 0.14261200152818235, 0.014015618794327302, 0.1011313894583333, 0.06429763691079232, 0.034086235663703376, 0.011254402343183758, 0.22693192856686734, 0.1000172831118107, 0.07055526524181328, 0.01443220591623216, 0.043150040230924086, 0.11251354079333045, 0.11719174097262083, 0.3065322177304376, 0.18146427318213448, 0.47338089695380586, 0.1823464847139774, 0.13363777179150813, 0.17813929837317238, 0.36923286775427483, 0.1643751958204854, 0.11189120160716196, 0.1314607950588388, 0.2828300089365052, 0.1604098787591342, 0.12469162683813803, 0.1379229458830049, 0.09454328611853624, 0.12279409599760849, 0.11927931524452665, 0.21422501202792893, 0.20384671166539195, 0.14479763505439605, 0.11390958281774675, 0.14006403905730094, 0.1224947318194374, 0.24500751267037085, 0.37962426822031703, 0.11520974127756012, 0.22630747497802783, 0.22261315385901162, 0.20886167643531678, 0.20168586874440794, 0.28551465681483673, 56.570493636592744, 123.61693982155093, 104.35421912900864, 100.03626223533385, 81.30764284441548, 71.45079720404841, 51.562332953176195, 94.83805487232824, 109.42957001347696, 124.21834899533181, 110.7857765689973, 121.01571021541473, 62.14223615584835, 2.762081594236436, 0.33014513131591583, 0.11528679440098426, 0.2951537282957185, 0.2756265454715298, 0.29483978546434836, 0.5792444728074536, 2.3132205057528714, 4.078064488787805, 3.979870648153367, 9.91919171425604, 39.72634561600224, 70.76492371097689, 99.93428061085363, 104.34624102807815, 112.57203179021036, 109.94245129246866, 108.94416885991251, 100.8167354522213, 99.01119001450078, 91.50633089004025, 91.27539742377498, 87.6629101845526, 93.54164877245503, 95.45152141201882, 102.24016358775478, 97.2709285059283, 93.34443984493133, 78.34169557017665, 68.48194737588206, 52.32301781254431, 36.67282750529628, 13.5358464717865, 9.553661134935195, 5.010761705137068, 4.655254252495305, 13.836777575554388, 12.954862060085421, 7.862320898040649, 2.4932447941072526, 6.758364910079587, 9.963237970106064, 35.28145297881096, 54.49744647549045, 86.4763226047639, 88.31961693302279, 105.4188523753997, 118.876982965777, 129.68538776520762, 114.2471976434031, 111.5633786109186, 101.73172243179815, 106.8971230906825, 113.47259229229344, 117.13247745267807, 109.5224517391574, 118.55606248301845, 113.29514426569786, 114.74643691893547, 113.38954787100516, 112.20688266138878, 108.49121355241346, 109.18924639301916, 109.95514408234628, 110.59336862256451, 108.03214719218593, 105.8505484365648, 93.02712009799097, 77.8085748610958, 52.7289988148597, 18.040210085530436, 2.8111210273158167, 5.493355422250686, 3.2155583318202727, 0.3580382087778661, 0.318777060676967, 0.17116051317463, 0.31162360743168865, 0.1663329794762596, 0.1900999380215522, 0.2752277507416664, 0.14455141439553232, 1.1245261228853658, 12.518834721657539, 85.61494658070227, 100.47790542725595, 76.04361026517807, 115.89511871337892, 127.38971864023517, 75.86770765243038, 43.755714124248875, 28.440641318598104, 58.2580110334581, 71.08983716657086, 94.05849949006112, 106.03057738273375, 85.95457676918276, 5.730298940212497, 0.2234087208466184, 0.2750952788177998, 0.1610380861788027, 0.10025280152237225, 0.1867239570785915, 0.19500152177868352, 0.19488693034696966, 0.2113703232739241, 0.23722758336413294, 0.18936127604496097, 0.11044940881190762, 0.277194727452532, 0.2206587869553797, 0.245802175674227, 0.42993338478188364, 0.216959087899135, 0.42109276077920393, 0.19373294146310902, 0.21896505848534648, 0.15845347406162372, 0.2629453081998133, 0.24737385101616385, 0.2016279984626078, 0.30062669107029516, 0.19043652641196407, 0.2088221309766654, 0.13829500414431095, 0.3199027502729047, 0.17108727516906877, 0.1498515630561498, 0.1494319767000214, 0.12548992109875526, 0.19239763488932965], [0.07077003799138532, 0.03728413946866509, 0.019779786910681475, 0.059057269921346064, 0.03448757380547543, 0.08727479711054795, 0.08680054272014288, 0.09655959123084623, 0.04716408048425952, 0.07883580236305153, 0.09549617692227326, 0.025954855861322536, 0.08413119361765924, 0.040128838436137286, 0.011359938615632635, 0.05452987414995029, 0.10962761863465272, 0.09407259403697907, 0.09307638096112399, 0.030627812168771223, 0.06710986141115427, 0.07995449757624058, 0.022348857019096616, 0.07811166541350466, 0.10748770523576007, 0.040473570341184255, 0.03217545150208377, 0.05762126492035966, 0.0019311283446562988, 0.08637274390146618, 0.8264807191106581, 51.14720890598913, 95.32577806903471, 100.44441623072471, 84.64992584720736, 62.94005801600795, 35.38918087559362, 39.64085363572644, 77.58911824995472, 77.86570026028541, 77.26074526386877, 100.28208501877324, 104.39013235030636, 37.30052440397201, 0.8679697734694328, 0.03175942937002307, 0.19144439168514746, 0.010200529659707702, 0.2675885364653603, 0.04736861446872354, 0.05069985587690627, 0.09379622781829489, 0.345531118613097, 4.081414192914963, 14.147889191104522, 38.752032787569114, 70.20521717686808, 83.69305579893052, 81.93416303203952, 76.35776858175956, 75.70835744180988, 77.46204914585238, 78.17143332573676, 76.82156532041489, 80.7943771731469, 80.63752158995598, 86.39511385271626, 86.38844582342333, 91.2734676176502, 89.70866157162575, 89.07562240477532, 86.73195131363408, 84.28774203023603, 90.57494840314313, 87.82562578878095, 86.29380687590569, 83.75795533580165, 64.77570764480099, 37.38638508704401, 15.780723844805072, 5.00988015244084, 2.0642831152485264, 1.1312392594352847, 0.730164897057318, 17.951217389875843, 20.933466034550822, 23.11057955987992, 40.09940224309122, 62.58708784657141, 81.95545365733486, 97.06213289691557, 116.46485082564817, 120.12692466858896, 118.03882737313549, 121.48887357404156, 127.89543767129223, 124.61379451136436, 116.45395448130947, 107.35968820510372, 103.16810223364062, 101.27471923828126, 99.68355486469885, 96.50328143950432, 95.60975766951039, 94.28355724580827, 92.03709033227737, 90.82113988937871, 86.88886965474775, 84.5220487348495, 80.16146352214199, 83.8318371003674, 86.41558078027542, 87.43989206129505, 83.97362293735628, 68.83966753559729, 39.26164673220727, 10.922062339321261, 0.8629685676386281, 0.6717042372592035, 2.4641050158008455, 0.800570093335644, 0.09822139681707467, 0.02358718643776111, 0.05432178934795722, 0.023950582159863367, 0.21160413330841452, 0.18594780275898595, 0.24119593413366427, 0.19772099601405282, 2.5981245598485394, 55.81226810332268, 91.34437622562533, 63.14548430904266, 104.30400494606265, 157.575589149229, 104.08225767074093, 32.07744529170375, 16.67731196649613, 24.1217940468942, 38.84369857849614, 57.216151068287516, 77.22290223644626, 56.90563271122595, 2.1340544810218196, 0.22848074384514364, 0.2830532469576405, 0.11456405939233881, 0.06174513153851994, 0.02473431691947964, 0.05298840948530743, 0.032216360597240354, 0.06833268329501152, 0.1567129835846924, 0.12799214812055712, 0.0914958419819032, 0.20376123157480072, 0.11812390143712682, 0.10649491657292652, 0.10667873937035761, 0.10784426553835792, 0.06660482560795161, 0.14873984690395095, 0.1654675912352339, 0.10612714840399642, 0.17706032481885728, 0.10078774539813881, 0.06323616463510741, 0.03297757237188278, 0.012175051379017534, 0.015521856820991924, 0.04726588590851715, 0.04517456163622199, 0.09472099553433158, 0.07130007124355725, 0.034455436417051864, 0.03951287310149881, 0.06018258413420089, 0.07029708595045152, 0.08368053473532201, 0.10916724575743561, 0.06472724369697033, 0.08601527961511767, 0.022834395884626338, 0.06735893957797559, 0.07607341954304327, 0.05603960362232982, 0.06169432075694204, 0.03787184765021648, 0.06388499514169751, 0.07570738273282206, 0.011585156016442324, 0.09633561010442435, 0.06844087789255766, 0.05269445005744215, 0.053008814237170646, 0.05306876827812484, 0.10787323898365421, 0.05600823615227015, 0.12495056455654484, 0.05927493848327187, 0.05855924382265057, 0.11913896027591922, 0.0797097937714669, 0.13467647976452304, 0.0894188627059902, 0.17890621367241108, 1.6918236690182842, 78.78632760817005, 106.871776734629, 116.47908902937367, 107.9326209714336, 91.34581181310838, 52.37842913596861, 23.571891477031095, 23.69115310330545, 60.27106946514499, 85.74072130264776, 110.17855444262105, 110.53894181405346, 28.82476491312827, 0.08844168691505348, 0.06956195563919122, 0.15482908144833582, 0.09236853870172655, 0.14402730300301506, 0.2524782335686107, 0.305530940813403, 0.5095392663873012, 1.7918074587660453, 6.413086508550952, 20.441051683118268, 46.49521512369956, 78.67570107983005, 92.87587350414645, 88.85984497685587, 83.86031350781842, 83.84715003352012, 84.27265659455331, 80.59318311752813, 80.80077848126813, 84.4927486296623, 87.21259855454969, 90.8828858406313, 94.8268525831161, 97.55122892318234, 95.93238830566408, 98.57051172564107, 100.08535462041056, 91.01882734606343, 96.5468668168591, 95.54681147298506, 91.84141112912087, 91.01203380092498, 74.65663663802609, 46.381211434641195, 21.898855470841934, 9.29153403928203, 3.180236407826024, 1.5271922321088853, 1.8378488527190302, 25.386881982126546, 34.294145337996945, 31.654698118086788, 51.69569746140511, 76.15557039937666, 93.491638552758, 105.550063502404, 119.57433331397273, 121.6658038477744, 121.66363085469892, 119.28152838060934, 128.38009357452393, 128.51248141257994, 125.72567662885113, 119.9079465866089, 112.4631703284479, 109.70493608905424, 108.42229750848587, 101.47805490801412, 103.56099820906117, 98.49225259596302, 97.14854271181169, 93.7699777849259, 92.60766967650383, 88.39604039346018, 86.88708105394917, 90.21354121546592, 91.40108585357667, 91.83192683804421, 89.17623119969522, 72.52020789730933, 49.36902984496086, 17.337413526350453, 2.360787824276955, 0.5258601567437572, 0.5699091092232735, 1.5893000220098805, 0.45505592058743205, 0.4617683829799776, 0.3198110955136438, 0.04520859126181853, 0.07422274263996272, 0.10134030929616383, 0.21300918452682036, 0.2682519379642702, 1.5604075981724648, 53.2545611166185, 102.59718556557934, 67.84791977174821, 102.26764371318203, 140.06244167204827, 58.4947221509872, 11.190809415232751, 22.023071050643924, 43.3512746134112, 68.03060024015366, 79.14277691994944, 86.84990482945597, 80.90818082132648, 6.067850272501669, 0.21572243812824451, 0.21192454192186558, 0.1520067369264941, 0.04652632760905451, 0.012253083179764932, 0.0819877025881602, 0.05756547839771356, 0.02762916400247524, 0.05199418823805548, 0.12896621359452126, 0.16425518048626764, 0.15860411759105422, 0.07662159375726216, 0.056486014547126914, 0.12601353453412173, 0.11328968745205673, 0.054158773498549584, 0.03430378931244055, 0.08751632165043585, 0.18937091343104842, 0.09529235923001844, 0.04637402166882831, 0.02232475972343837, 0.08468890562653543, 0.04163522010428771, 0.032871741155583056, 0.03745291629926332, 0.12076745635919994, 0.03877873487410046, 0.09038171265274288, 0.006655122626632933, 0.05493117781776575, 0.17204077884314523, 0.2665402523932919, 0.1556689436397245, 0.13508661259566584, 0.16431924075849597, 0.197398227849795, 0.11606906210222553, 0.17915698489354503, 0.18398436537433058, 0.1020184503267369, 0.3856818786551876, 0.11418177385724361, 0.11495860999510174, 0.14553718569297946, 0.16604673838423145, 0.13316514150750253, 0.23399800182350222, 0.17728082024522368, 0.17055145795306853, 0.2075947661914172, 0.19283553074684837, 0.22701337903497681, 0.23576113785947525, 0.13643940129587728, 0.11863849035674527, 0.15519698751309227, 0.13293726099354605, 0.21328751959146994, 0.20681050666157277, 0.28833738438064055, 1.5402585051713453, 82.26109258590206, 127.53000613181823, 125.19337961750647, 111.0681087740006, 75.38699765359202, 44.881348071559785, 50.99439728644587, 104.28753099133893, 107.8998770252351, 104.25352404194494, 115.68281650543214, 123.13332726878505, 47.24172845963509, 1.7974067647610943, 0.1787477713679114, 0.5024515741294431, 0.26236265236812256, 0.28449048919062464, 0.2930590294061169, 0.3459308632919866, 2.3824510747386567, 2.2882484909026855, 5.89866275748899, 18.424720033522576, 44.31877036248484, 82.04587213454708, 97.83820521446967, 97.25267379514634, 90.01292767063265, 91.72045307774698, 91.21744048210883, 89.1179604684153, 87.25774503523304, 90.7266107682259, 93.2750766508041, 99.68698301622945, 99.48672248471169, 107.11726219423356, 105.09768870569046, 110.00742143200291, 105.15883061193652, 97.26642562497048, 105.92351236651021, 104.03393407021801, 99.07312423952165, 97.61994100386097, 74.86820144038047, 45.05707417764972, 19.696350482202348, 7.977998948866322, 3.276424446413594, 3.6294571286247628, 2.3741802669340566, 24.713736580264186, 32.71075314091098, 29.929953505915982, 56.10041718329153, 78.78662570830315, 100.7807202492991, 108.0098524401265, 125.4460822382281, 126.87830432768791, 125.4634112696494, 124.21139855538647, 136.98243971793883, 133.21867450591057, 130.9422799079649, 122.03007436567738, 114.90631272715908, 115.36730104877104, 115.3604212114888, 106.9153856462048, 110.664763604441, 106.4595042505572, 105.37583181934973, 103.68582371742495, 101.23213798769059, 95.58326598136657, 92.40402021715718, 98.79905254610124, 104.84972430813698, 103.648129740069, 102.46574694110502, 82.47377134138539, 49.83739614486695, 16.55382790873128, 2.4617687540669597, 4.719705168277987, 7.720359044690286, 2.3415071685468, 0.427997358023159, 0.29137734383825337, 0.32480528397906216, 0.09354574771057214, 0.4654336234013881, 0.3066243014989361, 0.3629924993841879, 0.5572451855386458, 4.355583700441546, 73.51078679484706, 109.82711791992189, 77.64574158576228, 116.54873463415332, 180.8918519173899, 135.0003876224641, 47.3711274516198, 24.58956414653409, 33.30796733979256, 55.57071285863077, 75.21521352952527, 98.9938452935988, 90.42116011342695, 5.8690459209103745, 0.462334368738436, 0.422091402353779, 0.1760897986711033, 0.19433326328233366, 0.12568979343820003, 0.1296138183604325, 0.1067975213030173, 0.12479858803412608, 0.15021119537132402, 0.12559034756474918, 0.20297991382258557, 0.1759017547292094, 0.22133749489101673, 0.08925672785769548, 0.20391801912938395, 0.1924469862734118, 0.15643091001097234, 0.20755954146865876, 0.15430011305837862, 0.26412695285774046, 0.28099118341361323, 0.1771123575106744, 0.09478409053577531, 0.15961601248671933, 0.14807207870387262, 0.1804813364100072, 0.2185991748927101, 0.23050048869223366, 0.14138106677320697, 0.1397680992921514, 0.19660290601032396, 0.12525399666159384], [0.09754446620542197, 0.027125643138142846, 0.045212291466492804, 0.033056303227861086, 0.04256641912844874, 0.021682377761950897, 0.010192728011808809, 0.016269882307237676, 0.023360895556247523, 0.0800278964602659, 0.06171090273006309, 0.030621806039444865, 0.05656807022469659, 0.04008090814515468, 0.08509580556663775, 0.0802727688043829, 0.09361415936221039, 0.03783252818750278, 0.00678397334864243, 0.054459646869931495, 0.05361978467854281, 0.04376253518726557, 0.03455747166768678, 0.056004907500239155, 0.07444923653477624, 0.012038891699405448, 0.18214633658287988, 0.15748394382817132, 0.09020816309437638, 2.269456905703391, 64.74172815199822, 102.67091043533819, 92.94416196884649, 79.87218087719333, 66.20580380962741, 38.3078125984438, 50.61077771648284, 98.26058172410535, 97.58409838522635, 80.6320930296375, 110.4777293051443, 101.54678267817344, 17.954696532218687, 0.12407468857183573, 0.17670950251481227, 0.12325448419658408, 0.12898953331093635, 0.04311951545758113, 0.045155543503501726, 0.18785526975989345, 0.25992679920408035, 1.0504992306232452, 6.228565958238417, 22.367696377538866, 44.469252094145745, 66.02685743762602, 80.68061274866905, 85.65458605366369, 80.1341167573006, 82.71658958927279, 82.55742765242054, 81.90440793191233, 82.70973328621157, 91.99715275918284, 95.49882519629695, 100.02555416476343, 102.54661052457749, 102.22169706898352, 105.8988485028667, 102.12027242106777, 105.80106381447085, 104.41176814417686, 101.57829500013783, 100.2855759282266, 98.73335284571495, 101.52221295141406, 101.10378234617173, 88.70528005784558, 86.36006355285646, 70.77239190378498, 69.15755994858281, 30.789297742228356, 13.770500306160221, 12.012160593463529, 29.351782414220995, 65.1684271135638, 59.34648052338631, 68.42632032209828, 75.71224058828047, 99.01774037268855, 110.45863520714545, 117.58842945098878, 111.34458880270682, 111.76270561833536, 102.07038771721625, 100.19831103663292, 99.35167527967884, 107.25634159580355, 107.03528465763216, 107.2292850863549, 99.96063893841159, 96.5051249534853, 91.98941784520304, 88.73153640377907, 88.12220404225012, 88.58186660274383, 85.9095165806432, 87.41948789165866, 92.57480021445983, 93.3366813967305, 93.33672846517256, 89.44099903106691, 88.78004827807027, 89.05777562049128, 78.16178429511287, 61.53863437714116, 41.4984606927441, 14.505047471292558, 1.0001712376552245, 0.458039312112716, 1.2004124637572997, 0.6165021477687744, 0.40082507736740575, 0.07440160884852372, 0.18070812907911118, 0.006468686990575084, 0.03163464896891627, 0.15634703870502212, 0.019003320410246813, 0.16525310193819387, 0.8934371714149753, 37.530783222567656, 104.08406980576055, 74.25624109083607, 93.80280802326818, 142.7139639085339, 158.58743513784103, 61.46562337875367, 24.924746367239184, 22.820751705477317, 32.19859357803099, 59.441033178760165, 70.52477267480666, 54.18961886436709, 7.4575190582583035, 0.13731910005932854, 0.038024617073636864, 0.10139067191630603, 0.03287833334217149, 0.046429268099487796, 0.08711307594973235, 0.022013141968918425, 0.025225724018509352, 0.058550334220091184, 0.13679682727782957, 0.11618452687417308, 0.053214888058362476, 0.02075165945796236, 0.03488904984307385, 0.02556662356871511, 0.031693415573587826, 0.012236547171919337, 0.07552143021096146, 0.11712998662504459, 0.10335343514358807, 0.07746982162878399, 0.02758813233325078, 0.02894045755026802, 0.021355773412412214, 0.08105922700656999, 0.02469514492869137, 0.06183265708386899, 0.09731587322969591, 0.16140568580838943, 0.1596390257679647, 0.198543299470217, 0.028382569341169252, 0.011370195575328845, 0.09239338293311097, 0.0391897716889939, 0.05203928017327863, 0.030731687945644223, 0.03849015338346362, 0.07631435419522947, 0.06563475145207298, 0.07265949426519294, 0.01846443692732963, 0.009418085758243839, 0.16713475177605308, 0.035036812881909074, 0.06625839298771274, 0.016932349178879973, 0.06810370727532333, 0.08127957687623079, 0.06309347692877054, 0.02336235112330366, 0.09489633007756165, 0.025680860684764002, 0.04156796907585475, 0.04125724764420621, 0.05193406182731833, 0.1106831958637603, 0.1694466365921882, 0.1579072686933702, 0.32413140239734806, 6.158090281871058, 93.7305030515117, 117.00870313952046, 108.92847153448291, 100.23478907923545, 105.22726812670308, 53.67477247791906, 23.65743248693405, 46.93079040896508, 87.63035451212238, 92.77356240057176, 122.51137272004159, 102.0309365180231, 12.599722819943583, 0.14525143489722284, 0.11404392399614859, 0.09712815870560947, 0.14240281355957832, 0.09726957853643164, 0.113308027596964, 0.2808369852362141, 0.25159976054583827, 1.8049503406209333, 9.846846538205302, 29.963070077280847, 54.4439531910804, 76.0888901064473, 90.03168444479667, 91.88521615920529, 88.47425245469617, 87.5028931710028, 88.26793578363235, 87.41716584851666, 89.90944770074661, 98.79581266833891, 101.99994194892146, 105.21301423349689, 106.31654170251663, 104.47727172605454, 108.79012169376497, 107.90994182709726, 109.08234611634286, 105.48000997112644, 104.04244561349194, 101.51071256206882, 99.89226418156778, 100.28457964620283, 101.84564375108289, 95.93707161564981, 96.62569076784196, 85.59425215567313, 81.44539648486723, 41.2699826302067, 22.932915802924867, 19.464059875857448, 41.29816485989479, 79.66163589108376, 69.00801566339308, 77.08335215045561, 85.39411714000087, 104.21307656072803, 112.0330196811307, 117.77270240168419, 113.28088252775132, 112.84018854941093, 106.33752638293852, 101.30284263241677, 104.02182179112589, 111.46739821280204, 111.42441688045379, 114.50108481991677, 107.52319612810689, 103.62571731690439, 101.27849255838703, 95.59936338855375, 93.75628871302452, 90.66369595066195, 90.66260553175404, 90.18199751454016, 99.02935843313895, 98.3727301320722, 98.50832646892917, 95.46154699017926, 96.74548779764484, 92.90949606126355, 89.01753210252332, 63.8389358212871, 42.75554110926967, 17.011772471089518, 1.9403016519161964, 1.006484231160533, 0.8540843379112982, 1.712391842757502, 0.9090962537354039, 0.18822801750033133, 0.5365684111752819, 0.06346198054210794, 0.04554853894777837, 0.2204738226869414, 0.035479879832916686, 0.05876395400733717, 0.7273547639769893, 31.63419588919609, 113.68109764591341, 81.77336154445526, 97.26833189687422, 139.4215734543339, 124.49226379394533, 25.589639102258992, 29.161745540557373, 38.95166573985931, 51.37983683616885, 82.25963346419796, 80.63627427624118, 76.08970595944312, 15.735834279368001, 0.1274195433624329, 0.07092860286995288, 0.11894969059334648, 0.07661764074357287, 0.043332081873931234, 0.05042688725816627, 0.06022841151383135, 0.031019394180827567, 0.0189894120839815, 0.17493038588473875, 0.11026544811865015, 0.11028627804931133, 0.04890238761060661, 0.03989695894321607, 0.05175844000111665, 0.06503793831554151, 0.0634488191515688, 0.13340691885640546, 0.12137760708649313, 0.015399126662692476, 0.049843227851294705, 0.03588229815866198, 0.04144416543685141, 0.06227089002007439, 0.04817118733039787, 0.0446360171472113, 0.025447866533912962, 0.09594232354673649, 0.026666957569578965, 0.10034473973416513, 0.0495718335432391, 0.23621118387147305, 0.09945459919230593, 0.11962914163427008, 0.1424610822070991, 0.15350879019787236, 0.14127075011211057, 0.1569234892245262, 0.1747127249836922, 0.17468303141574706, 0.24350935112564798, 0.24777410131308342, 0.14920849353075027, 0.1285023779998864, 0.1832554480361362, 0.2262436292104183, 0.185554860940864, 0.20944391857952843, 0.10267881045658743, 0.14396537245521623, 0.2850940745444067, 0.20743627792164204, 0.06523064773289428, 0.23207682184875014, 0.1228873442197519, 0.15863954149667295, 0.17652299074876696, 0.2964235037084549, 0.2693859625968241, 0.3953897448316697, 6.022943056398823, 104.40554726508357, 134.90723917561195, 116.456402040297, 103.25538281471499, 78.04069288315313, 51.19593651063981, 59.51313810963785, 139.41683523116575, 135.13520733002696, 102.93576455885365, 127.73669150567825, 122.07991200108683, 25.335214561031712, 0.5957404908634002, 0.27243554411876586, 0.18624001933682352, 0.21585774457743093, 0.2041022939186904, 0.31196286180807703, 0.5672522550148349, 0.9967269676346934, 2.077408101289503, 10.006779220796401, 29.770734694696245, 52.59297101728378, 79.6132573773784, 96.71992963360202, 101.51968694502308, 95.89686732138358, 95.94287672350484, 96.3714898017145, 92.56071890554121, 94.85895326060634, 105.34009118233959, 110.1907608585973, 112.16376012371434, 117.57684276949976, 111.01721209864463, 114.49045519674979, 113.02762293046521, 113.42098959030645, 109.52817839960899, 105.33796525770619, 112.42382111087923, 109.77386782246252, 116.30156255537464, 117.00525145376884, 109.51636422064998, 106.39744450969081, 93.48649240309193, 79.76401759732155, 41.30422492181101, 19.251679220507224, 16.613143951662128, 40.46199006419028, 78.2250129022906, 71.01967380892846, 83.49022219257971, 93.21963787078859, 108.26321401903706, 116.99299796935051, 119.77227964708884, 117.45484921240039, 117.71258815642327, 110.4370072580153, 107.72263296188848, 106.6660091953893, 115.50310134887697, 116.13920780920215, 119.08515884030251, 112.33931756788685, 108.38867495136877, 105.5366176174533, 100.17046220840948, 98.4327345509683, 96.01394222628687, 95.5707222415555, 95.12969878412063, 105.5223951032085, 103.60489737602973, 104.03888410137546, 100.07288148326259, 102.90615850879301, 104.27497940678751, 103.50386496513121, 78.31132073556223, 44.75277669968144, 16.789564317272557, 3.0426423588106712, 3.750145271901162, 6.207219439168131, 3.820113491627478, 0.9371859400022415, 0.19674688457481324, 0.5539354405576183, 0.1237199592193769, 0.1726982508215212, 0.35232913770502616, 0.07957502358382748, 0.391826976331011, 1.4773581513474066, 48.6988458325786, 127.04840967732092, 87.66421241144981, 104.5870980908794, 151.3124112159975, 185.90341721811603, 80.83411078299247, 36.741751393964215, 28.91905869207075, 45.10035753250123, 78.63366111632317, 89.11060994671237, 89.46777312986313, 16.56161577470841, 0.23002917607945783, 0.19955068976888735, 0.1688674281561567, 0.19865452011506404, 0.07279510714954908, 0.17228672371035622, 0.13824795102400167, 0.09695699934156672, 0.23195810886400364, 0.1931967565249051, 0.20902013406157496, 0.19008532106395692, 0.15463143076387145, 0.11147587469989255, 0.10984886482718492, 0.13900556601583958, 0.1866734718843814, 0.17945597368863322, 0.25311934190892404, 0.1659121060924184, 0.1604052209445546, 0.1319229912253157, 0.10649714588878617, 0.21058937324391258, 0.18658805308082413, 0.10279199228652063, 0.29682070497543583, 0.24194904452850743, 0.2873255048067339, 0.28596091835248855, 0.22872347114307268], [0.07341569199437097, 0.10948580809898915, 0.015569702842302862, 0.03859586202569547, 0.06277166254397842, 0.04180628370733992, 0.0735086031378277, 0.04542719445101196, 0.03707766728175264, 0.07570149151668434, 0.029460870653330803, 0.0429188463866951, 0.10300271243097321, 0.0461739654682817, 0.057086213792283694, 0.053857789044418646, 0.06852815062889168, 0.03946791140122279, 0.10770505970163692, 0.02208960328942105, 0.050823475654807784, 0.016690158142497944, 0.028455259593864603, 0.012279253700868258, 0.044759453064010996, 0.11244133700646701, 0.13008749052401514, 0.33001235295687953, 5.055419360437702, 72.10252254239975, 97.92395607117685, 79.47202067221366, 94.36154180957426, 62.67189341206705, 28.507960957865564, 70.41671137655936, 93.58659913462978, 85.81358325096869, 93.6997752035818, 116.49441765200709, 72.8970221550234, 4.364265866817967, 0.18818945263422307, 0.12139734917230184, 0.038884244333471985, 0.12608036038375672, 0.11653588543976508, 0.06359089781800586, 0.208117728452048, 0.920601484756316, 2.209825847418078, 13.933970966646749, 37.97066527028238, 59.97246726866692, 77.58277185501592, 86.38580999066754, 92.2537777500768, 92.6807983459965, 93.67158120678317, 92.71504848234116, 96.23951773489676, 101.25128699887185, 103.28131752629434, 104.32678607202347, 108.94755778774139, 108.25210586670907, 109.91893276091545, 110.44744076267366, 108.63412118727162, 102.85824283476799, 101.14936813231438, 99.45875598538308, 106.17665429269115, 95.28811547064012, 88.42287725017917, 87.50488573505034, 87.03224012928625, 85.0751970660302, 86.02182188341695, 93.93208149940737, 98.60149845000237, 88.77034433426397, 77.38814384706559, 56.708906235233435, 64.06347190180134, 91.5777886298395, 91.77068295017366, 85.38892392189273, 86.3549566268921, 97.5903820222424, 108.28819167229437, 110.93989433780794, 101.79656705548688, 102.4084254234068, 100.28199872662945, 103.92533148488691, 104.06488157087757, 104.48462224775746, 98.44944384790237, 95.46341403838127, 96.75815705330142, 91.38519240963845, 88.77556893133348, 87.75007309452181, 86.30198894008514, 86.20058782639043, 88.44929049091955, 92.04348379565825, 94.0262262282833, 99.2107209851665, 99.37900635503955, 98.02685553027739, 93.40439719538536, 86.28724867297758, 84.29855208243094, 71.29090570634412, 47.16559917696061, 26.260338906318914, 9.859096100253444, 0.671312919547481, 1.178871051919076, 1.5908227596552142, 1.5293853273314815, 0.7042670802723977, 0.00498428869421684, 0.12545659627404906, 0.08583669685908864, 0.03791779760391482, 0.05223695384038072, 0.008760364801292459, 0.03544691889997452, 0.3970641065989772, 24.600201614441414, 98.3211588090466, 80.95774389082386, 57.204544774947635, 101.29236990405668, 146.48356560737858, 55.65959376673545, 33.86979195379442, 33.15381426965037, 43.13182976938064, 60.54235627574306, 83.11758133672899, 71.92025000049223, 13.33029172112865, 1.186479346886758, 0.07970613187118884, 0.15343959713655134, 0.06408011007513251, 0.0668362148046013, 0.13853711857190057, 0.017562349244291266, 0.09536398079005942, 0.08183767958994835, 0.02559918422071684, 0.10234419091214096, 0.032525710731504426, 0.02690833655276126, 0.10910318548520727, 0.062077809050078356, 0.05532391662258775, 0.20522283540377695, 0.38567075505852705, 0.1648412377483422, 0.050579668172905524, 0.025999208521698753, 0.06489489437831987, 0.059577179321598624, 0.04990137009430797, 0.01905578402652135, 0.05338498256019047, 0.04379392563996296, 0.06402490577930886, 0.1416131454489885, 0.09400694796274747, 0.10893296074843216, 0.048760201691860156, 0.06582127853987679, 0.028251447647269216, 0.04359116514904365, 0.039998331527796485, 0.04681211670920734, 0.07572795219358898, 0.008565371484315444, 0.03116851319528876, 0.04665813686686658, 0.029794716448973746, 0.0347855398731847, 0.044070709376565875, 0.06485714922629057, 0.010281943738640798, 0.10314473747125558, 0.05331848995880254, 0.07623667287970744, 0.1268007435024746, 0.07980301135009335, 0.09008479995592948, 0.10170109840410371, 0.024318518868136792, 0.16199014960758149, 0.27726149967601227, 0.23900306873744537, 0.19654586310348204, 13.9631788961349, 100.28329310878631, 107.25737710152904, 102.10273942639752, 128.2711144416563, 106.01746882161787, 31.372734615879676, 25.582378795070035, 60.391505841285955, 89.10030980263987, 109.4271146097491, 127.11155983709521, 73.86436493166032, 1.8214593515280755, 0.2671274434654944, 0.06245519162245816, 0.09040496342124478, 0.15629856066117365, 0.391128549292203, 0.1183077548780749, 0.08870238663568612, 0.6864970886418897, 5.319010480757683, 22.631793483611077, 51.69022575501473, 71.46123855344712, 86.57724518929759, 95.6608347738943, 103.05664416282409, 101.16228841966199, 101.59629867922877, 100.80593324476673, 106.3340982314079, 107.78987807612266, 108.3683256949148, 106.6079188931373, 111.04716331728044, 108.74907016754152, 110.07455671987226, 107.97415887155842, 105.78130291354273, 101.70390498253607, 99.40651001468783, 99.12122818731494, 106.30317426496937, 98.58738576212238, 92.1345926100208, 92.17118047898816, 93.90271079155707, 90.38922417548396, 91.35589230445125, 100.81186386846728, 102.89983564807524, 101.07748677653652, 89.15757640715569, 71.89916333844586, 74.99032835806571, 98.78159799883443, 98.29199206444525, 85.91753390527542, 92.86701679229738, 97.9588024077877, 108.89721024420955, 112.7327234514298, 105.69576386482485, 104.69908960403936, 105.52794133463215, 109.89775980672529, 108.94285878827496, 106.4897378798454, 104.64543942482241, 99.76328880556169, 104.87506281945014, 100.29797061797112, 97.60549099214616, 95.52214760934153, 92.05321911842593, 92.72785894332394, 91.35921847435736, 95.97358103721373, 100.7243714794036, 103.44997159896359, 102.19584080480762, 102.42409921461537, 98.26699087696691, 96.8525920375701, 93.53373342944731, 83.77706512328118, 63.88037958452779, 31.57592711910125, 10.995272397994997, 1.4241969200872606, 0.6541576981544495, 0.3264931901808708, 1.0492472590938693, 1.6946768255964404, 0.05409447956950434, 0.4908432583174398, 0.2718492723520725, 0.06516638061692638, 0.028381345515710213, 0.12751556482286225, 0.04144446804158149, 0.6917135958229342, 18.769863113280266, 103.42251500775738, 92.14997614583662, 65.88161991488549, 107.71974609744166, 131.71378658663843, 32.24028837296271, 26.93717721969851, 50.3750785704582, 66.28875409403156, 83.33571218675183, 92.53936552232312, 92.48910427093507, 24.390037098238547, 1.069780376649672, 0.15357291175713464, 0.16225613533489167, 0.03684089248699527, 0.2052798629888604, 0.11349426357135659, 0.059062877684951796, 0.11400895974328441, 0.07578694862463782, 0.0491340296162713, 0.07260230580164541, 0.040241717661340395, 0.058161107928402005, 0.03137441656191743, 0.037629633631196716, 0.012022226414222632, 0.09242339059710504, 0.25392174240081544, 0.11642874804355445, 0.03210013739824776, 0.06001574167561147, 0.06369605487693222, 0.14792053119069146, 0.02753458087212376, 0.12577974748226906, 0.11536891136558787, 0.031583723274149725, 0.12278969865292312, 0.06186592062154125, 0.03378911229271082, 0.18521425824972892, 0.168145252391696, 0.08588658450471778, 0.152731379494071, 0.18443329289795893, 0.15034401969563577, 0.20682092545734299, 0.11926082954291375, 0.2458411389060559, 0.273502275588051, 0.17103879712522033, 0.06838679208510345, 0.19150197085353637, 0.23264827747498792, 0.15609294266229676, 0.15708950047771778, 0.09580684855820672, 0.23678101539131136, 0.19948161928163421, 0.2733977199081452, 0.20913084908839197, 0.257408116613665, 0.1473543922146482, 0.11415422533548648, 0.22400086084681176, 0.24828218614622471, 0.42737112711033515, 0.300351113922173, 13.96855450445606, 117.68253495616298, 128.30388976681618, 102.22708640560028, 121.94062863626789, 83.0561883987919, 36.29871576063095, 89.74249593673214, 140.6592381385065, 111.59506351717057, 116.77419247165804, 136.63203085622482, 92.4630440435102, 6.112932524373455, 0.29034511696907783, 0.26302084446914736, 0.32003344487278695, 0.19597475987768945, 0.4363512710457848, 0.2943874565103362, 0.7273433033016421, 2.5654195922036327, 4.4245482837000205, 20.092598122935144, 49.54629352015834, 70.19385014810871, 88.27979703103343, 103.02115455750497, 110.62623023986818, 107.50083861812469, 108.04317689711048, 107.01694365470641, 108.60971620005947, 114.05448375209686, 115.19416762936501, 112.53007811884727, 117.26322574000206, 115.96487414452338, 112.52533989567911, 116.06716171387704, 111.25542548394974, 102.94738261930405, 101.74542719318022, 102.55388259887697, 109.9121549052577, 105.79160305761523, 101.91555607703425, 100.52531119315856, 103.81603856240551, 99.76415957173994, 101.06571966601958, 109.29641339086719, 110.90667970718877, 103.99954272854714, 90.08427558406707, 72.47478685071393, 76.68653380486273, 98.180722267397, 101.05260326016335, 92.20761929788898, 96.86101728870024, 101.50154206060596, 112.41412501181327, 114.91338868294994, 108.85976729854461, 108.80531695581253, 110.61510639805948, 113.90707323628088, 113.73028416787426, 113.08804312059956, 110.49461118636593, 107.68814748333348, 111.71375443858486, 107.35658168792726, 104.70750701042914, 101.74969473192769, 97.43107888006396, 97.02709828653644, 96.783550477797, 100.93941150173065, 106.05949309564407, 105.80257784935736, 108.99801515763806, 107.10414578837734, 106.26358970519036, 102.98149939506285, 97.04652186362975, 97.08770675043907, 81.79342054551648, 41.670640976198264, 11.646263272531572, 2.088730758236301, 2.7324350947333924, 6.3759514689445504, 5.1940996608426495, 2.114230577022799, 0.12848418341168474, 0.3288678482415215, 0.3346144269791342, 0.0836406751806217, 0.1892769144427392, 0.14546446862720674, 0.1149778771063974, 0.8280260716715168, 31.634384162964363, 117.46063863077472, 98.67440746676539, 75.57808768364691, 120.60468504505774, 170.77326651542418, 78.26851198750158, 45.35160495388893, 41.640548552236254, 54.37509206033523, 79.58689904982045, 99.29389876704063, 105.72831953725508, 29.7199753022963, 1.5329950110566233, 0.4712135729289824, 0.2873570063421803, 0.13888499909831634, 0.32479195404917965, 0.3056217375541887, 0.15785417880021757, 0.15441016924958076, 0.18933509115970906, 0.09260857703104135, 0.14801529626692497, 0.06413414991731126, 0.09923095514457073, 0.17039920563899702, 0.18331287398694024, 0.1670778467650375, 0.21564176906981777, 0.41665567145232235, 0.18986649570926545, 0.2767371584571177, 0.1509444947324453, 0.22820181123191313, 0.2669809980978889, 0.14570923371901437, 0.2772076590166938, 0.21298839290055538, 0.17310717323374364, 0.1516567726409243, 0.2698337563103245, 0.1739624184706519], [0.07435443315414653, 0.11179296615263147, 0.1358854277960716, 0.10126914738887742, 0.06650006308430625, 0.07917716348123166, 0.007981177731116694, 0.07806701780927759, 0.03619808343149001, 0.031860411249762105, 0.05699111546780314, 0.02842880466261939, 0.043842970588875395, 0.10180277359341422, 0.0068110425866419275, 0.04113145983747898, 0.08198722761364714, 0.06126249997666287, 0.04806810253930669, 0.015627488854431337, 0.040614779497827255, 0.08160596863637049, 0.1299487826444449, 0.0886595010336849, 0.05411081256405, 0.24912597070778572, 0.2471515935875716, 12.441456164083174, 100.24162184807562, 91.91804639754757, 76.5728086040866, 66.54170774644422, 46.820458058388006, 30.84355196645183, 77.74049035964474, 106.4705261107414, 88.91810001865511, 117.0249652862549, 120.22993395405432, 65.39399477743333, 1.1450104559621503, 0.2218926634879843, 0.17619377212418666, 0.02022657321856147, 0.06627770606428385, 0.0022812195135385642, 0.18072643858050147, 0.31278873523396833, 0.6309427825673934, 9.177327367567248, 44.118909912724654, 78.15119389564761, 91.51471691746866, 104.78102791693904, 108.30925480011972, 105.41822479617213, 105.6960698096983, 105.90546161897721, 106.48512517252277, 108.70718709884152, 110.41069599889941, 110.49878458822928, 108.78838016140847, 106.94438765125891, 108.80088467751781, 107.5703194833571, 97.54010508137365, 96.06630586808728, 97.73980863632696, 102.19507202025383, 102.09979764876827, 96.17446914795907, 98.92897713568904, 94.17862599895847, 84.1238889386577, 88.98298386604556, 87.92562269395398, 83.66701910572668, 79.6961998170422, 88.59983890287339, 87.2537128386959, 92.88241601759388, 95.41809497341033, 96.44203755163379, 96.42750909251552, 100.34325830398068, 107.41954357393327, 94.40329936242874, 91.49274379976335, 97.90507378116732, 104.42228794097902, 106.46778829636114, 107.41977107140326, 102.44226763325354, 96.94198285379719, 92.83392767752372, 90.69456500391807, 85.13846489690965, 81.84749434071203, 73.35115417357414, 70.25791814250331, 78.16494572547175, 82.47457150490054, 79.27358012045585, 80.48818126801523, 82.31606852623725, 83.70427377762334, 88.63531281871181, 98.09440658938502, 100.23624820093956, 99.91930500153573, 96.35077968720468, 84.62416371991559, 88.37392607042867, 90.15607064770114, 77.25822710221814, 67.0836224094514, 48.405629050347116, 24.02302484358511, 3.130278159533778, 1.0067355079996971, 1.7215245914074684, 2.241287668866496, 1.1721997131263058, 0.39962323863179455, 0.05373785414943292, 0.11775353623013343, 0.39137884553882385, 0.09045882706320094, 0.15352392809525614, 0.10260684415698053, 0.009684963977985806, 0.31468189171245026, 13.241224500440783, 85.80369103339412, 98.27059945752545, 63.3397122352354, 36.48868399281656, 82.5660333325786, 78.15228431455552, 31.0910496019548, 30.807489695087558, 48.007618304221864, 52.32210390029415, 73.60296249389648, 78.49860606654998, 46.59549051715482, 8.186095395395833, 0.26810837308726004, 0.05980197250122025, 0.04546051927571816, 0.10769644887336802, 0.03688394662833983, 0.03726273114162107, 0.10091922906858307, 0.04834631502988839, 0.043756268588044954, 0.06200787671391041, 0.05415762436666316, 0.03825279253144418, 0.08090028674491952, 0.17066600341950694, 0.09939349601946532, 0.23998643451881027, 0.12543486235963722, 0.041794788558036096, 0.07894388970828826, 0.02855809157594077, 0.08331717923283578, 0.06581613808990487, 0.012425679916275606, 0.06214982514540034, 0.16147841819592063, 0.01786330497012504, 0.029008445938328103, 0.03679601888683054, 0.03271312265086078, 0.017592946795987028, 0.10935515946438236, 0.08297145141348725, 0.031114032852553555, 0.03245835245076207, 0.003836795038941707, 0.0759394843912413, 0.05662973264172193, 0.02259829524724234, 0.03019913617942122, 0.05917266574538043, 0.057752373207721024, 0.0861724961789385, 0.10317315167236714, 0.014721487419709805, 0.117751061766138, 0.11782124308088135, 0.00232565859820874, 0.04227834325584193, 0.050271643370750456, 0.04009284762545459, 0.1626985817546806, 0.03122890390635979, 0.1026871454932036, 0.45296079268859285, 0.1013628552637754, 26.994349687330185, 127.00200019344207, 99.86176383110785, 102.89348925313642, 94.79757601214995, 85.23717526466616, 37.32311333379438, 28.154961370652725, 75.6004059699274, 94.26629097230973, 123.1616860051309, 128.971218293713, 66.41812170705488, 0.4265508308045326, 0.1544914665001054, 0.1047816451999449, 0.014857374180498865, 0.09680897583283725, 0.20919317800191142, 0.4726432155697577, 0.3912824716779494, 1.1687687423921402, 15.962532566439723, 54.947805173935436, 90.0387211768858, 98.08791114437966, 108.29937827202582, 108.95790500025596, 107.12104335907968, 108.01424549471949, 110.54801033389185, 108.77184344876198, 113.2428433818202, 111.21630376385106, 112.47591803150793, 109.45826607365763, 106.48525853310863, 109.0391843549667, 107.36950197527486, 100.48593844136884, 97.22209499728297, 100.87823037178286, 102.60231602576472, 104.391034495446, 98.7248726814024, 102.96771618627734, 100.00620119033321, 90.92056412850657, 99.42822425596177, 95.57080853369929, 92.27560181771555, 87.32542161018618, 91.43632442720475, 93.06557501516035, 99.70260973899596, 99.69556516216647, 102.2305694703133, 98.76730488192652, 105.23372434800672, 112.05687553651872, 96.76339733985164, 95.58380726845034, 104.32494255804248, 104.38091478040143, 108.64023224000009, 108.11487782386043, 104.36417410450598, 98.42983984178113, 95.71391228706607, 94.88279342651369, 91.02289092156195, 89.47009517300515, 85.0552635808145, 81.14808082580566, 86.51056489636822, 92.18795253384499, 89.37741741057366, 88.92690181732179, 88.80013081335252, 86.82642552160448, 92.84036036460631, 100.79182840162709, 100.6197932458693, 102.11600488232028, 95.79235184577205, 90.62640205506356, 93.55372967258577, 94.57465202577653, 84.6306356306999, 79.80613600823187, 69.45016091869724, 49.82804521437615, 12.02181648823523, 1.3216441004507005, 0.7839082938528831, 0.6337713017579049, 0.6961581928114737, 0.5913586517976177, 0.4413600458252815, 0.5079081426224401, 0.6351864193716358, 0.26636236677727393, 0.02079516559118225, 0.3732812747118935, 0.04117930968922954, 0.41602852123398937, 8.5108676456636, 84.86725653371504, 107.43253446394398, 65.43337929633357, 39.28755790956559, 70.86890574424498, 38.18884711111746, 32.59362724519546, 45.351973656685125, 69.19690916615149, 75.18537213725429, 82.18470050442605, 94.5668072854319, 66.0341138224448, 18.11798676367729, 0.32023900158462987, 0.037820075428293604, 0.04500234890128336, 0.11747146265641337, 0.056073686874081055, 0.07973199499951256, 0.037184854473678336, 0.054770153796961235, 0.019682070480719693, 0.03298440970660698, 0.0776835908031752, 0.05180603704385219, 0.03444628549679633, 0.020356566847993002, 0.06348323948200672, 0.196458621010665, 0.041272194019608924, 0.04065836990071882, 0.11686643705733361, 0.0889794499943814, 0.0701403903264192, 0.01778543404784174, 0.02067222954675315, 0.08804167410539043, 0.22353081993999022, 0.09370579113883358, 0.002774540635366594, 0.02906399305849787, 0.11431960839658015, 0.21397338278831976, 0.21777120238590628, 0.20116681353219096, 0.14926306963447603, 0.10942147203510809, 0.11732831146688232, 0.15404532753652142, 0.21400683018709385, 0.11885117934716326, 0.1250411008274363, 0.14296282383222736, 0.15794826971907772, 0.2197246040187536, 0.1837131396056183, 0.1401633087305292, 0.1417799840771383, 0.192267369298685, 0.15114343244462244, 0.2944512869561872, 0.17695963022208985, 0.19499543904056474, 0.2872645854949951, 0.2753345127547941, 0.2156850683592981, 0.48554291047396203, 0.5422981359785604, 29.913675669700872, 146.773617036881, 115.87185121351673, 104.57503288022934, 87.29452117796868, 57.337513123789144, 38.20031219913114, 102.58077436877836, 148.9956711184594, 112.94134647615495, 138.8300015849452, 141.0038418923655, 84.70665900937973, 1.9076978078772946, 0.2639058292392762, 0.38935061243753283, 0.2048371254556602, 0.23907097477105357, 0.1798390942595659, 0.6544929995171486, 2.5578776098066762, 2.115534274808822, 13.07718901864944, 51.8755106772146, 87.23188092631679, 99.84710201140373, 115.97573126516035, 117.30420666356241, 111.82144703403597, 114.56141087316699, 115.3676619068269, 115.04441938092633, 118.45855236053468, 119.48691152757215, 117.58071022648966, 115.20640542430263, 112.7147589960406, 116.91581356909968, 114.86565343795286, 108.81564063410606, 105.0886986332555, 110.68671318792529, 113.94391998167961, 106.05266817154424, 98.07801892680507, 108.15024975807437, 104.57690777317171, 97.62030186191683, 104.8072999523532, 106.3307563720211, 101.99888290897493, 97.335067102986, 102.96431156896777, 99.1808952823762, 109.16349995520808, 105.79379174017139, 107.68039687987297, 106.36163327001758, 110.52956734934162, 114.48496387850855, 101.00680566603138, 101.1530080918343, 105.35622781322849, 107.64042008307673, 109.9076912480016, 112.28080364965625, 108.60746475958057, 103.13124764350154, 101.20586595227643, 102.83152364915418, 95.61894386045395, 100.47887033031833, 97.53182103556972, 95.1170373732044, 98.39659383220058, 101.15559685614802, 96.86534758537047, 97.70227939851823, 97.10020342180806, 93.0302187704271, 97.9232108208441, 108.85909265087498, 108.37313452074605, 108.03330821375694, 100.83823788550593, 96.61655164534046, 94.57673088196786, 99.04026262221798, 87.32436257023966, 87.76289140024494, 85.15593513365715, 66.53121932860344, 15.533676301279376, 2.5257048587645254, 7.6868110126064675, 5.392793695772848, 4.123307802984792, 3.074954599142075, 0.7107539450930012, 0.6276270927440736, 0.757108577076466, 0.4522245821933593, 0.2139060436597755, 0.5695326842607991, 0.13525184243917465, 0.6307159592547725, 19.311858184875984, 102.7623801077566, 111.93328165238904, 84.62781936891618, 51.19062562142649, 113.88216618568667, 103.6384257962627, 41.87920124300065, 38.92773928180818, 57.74980914208197, 70.66429138183594, 86.31011609108218, 108.47292746267011, 76.6493340461485, 20.374779316686816, 0.429832904689735, 0.10092032457431478, 0.2716018565960469, 0.2106556092058459, 0.14743325330557364, 0.1453328240782984, 0.19934661926761751, 0.1308499471915345, 0.12235374099785283, 0.1760091908997105, 0.11247748103473457, 0.24339564835592625, 0.14105589309286687, 0.2426640497099969, 0.2916579465231588, 0.3230148445694678, 0.2544555065011786, 0.10678924755343508, 0.2164152574034468, 0.15924979181539628, 0.1391053259853394, 0.16646390390251914, 0.11787083961309926, 0.19699929522410517, 0.42402240357572035, 0.13366440100775612, 0.11901555883307612, 0.1287252176553011], [0.059414324350655086, 0.1341579454920946, 0.06759265768191508, 0.05969740149955596, 0.048584361530600056, 0.07774048815331153, 0.01316723770522062, 0.08025920904812314, 0.08751270571543325, 0.05762638621813348, 0.02759463641972792, 0.049507673679580616, 0.09088562230669683, 0.07318575836477742, 0.06958160579444901, 0.06513734588459616, 0.06834385285694754, 0.05469364459596334, 0.1270644233051327, 0.02881937160817606, 0.10733873177800449, 0.06984596741535971, 0.11015773615649632, 0.07115416979837803, 0.14433854920489175, 1.7201806893271787, 30.193372041948383, 103.4093201544977, 92.2595436342301, 94.05859362694525, 57.36900583390267, 58.82234596437024, 34.89563295918126, 93.4717756702054, 105.71448926002749, 74.2056268261325, 119.6741262558968, 117.78361443550357, 52.74547276958343, 1.6831147814950638, 0.07364622317254543, 0.16069806571449005, 0.06511709051987817, 0.10113696657842207, 0.05794248941745009, 0.24933973988217695, 0.7389129469952276, 0.0918535897207837, 10.06247687724329, 59.344013352547925, 89.27105842098113, 98.63434437782534, 101.31633558580953, 98.97376275831654, 103.07026263206237, 105.37103868299916, 105.33226997621598, 107.84240645747032, 105.15997594402683, 104.33804327441801, 105.977978398723, 107.49226431692801, 104.54944333722516, 99.51958410201534, 99.92036404148226, 92.38275312608289, 89.908569089828, 87.26707243150281, 89.45403698951968, 91.41671257634317, 99.00970735857564, 102.69035754665252, 98.32880743088262, 94.47821663271998, 84.05636925851145, 86.40227610065092, 86.63943044600948, 85.73191950398108, 80.59042176892682, 84.89737249189808, 85.5576172182637, 87.7228126218242, 90.30465002982848, 102.58579500259893, 89.0665303507159, 81.82036722860029, 94.64702760019611, 100.35431938786661, 100.16197419935658, 98.77665581241732, 102.38337716748639, 106.41356545109903, 102.60828587316699, 95.08234008666008, 93.55878953010806, 95.21111149941721, 91.68715999972437, 81.47377091069376, 75.56304931640625, 64.0529050365571, 57.804071211045795, 50.67707361713533, 64.51149678999379, 75.7648866407333, 78.8393658976401, 78.74532315038866, 83.59138796406408, 88.01351516477524, 94.39424653207102, 95.54849809215915, 96.36594357029085, 90.51093532193093, 86.136182508161, 93.0361964625697, 86.35909080505373, 88.41682895537346, 81.25040761886105, 74.51041067800215, 62.18687272840931, 50.41321185327346, 19.749828077131703, 1.3403948684853892, 0.6846383141894495, 2.309102262220075, 1.4083476028134747, 1.0104627402559405, 0.39386066397832287, 0.13082540173444057, 0.2980200615861724, 0.15542047068236337, 0.10873665837871452, 0.08514318044387525, 0.048242536929225734, 0.42418242402134404, 3.5995747966151086, 56.82592622695431, 102.74019518206197, 89.29485936318675, 39.37375983884258, 68.93274537978634, 70.30890111000308, 39.0398366989628, 27.605731487274173, 41.930984374015566, 64.24609745702436, 64.2267954734064, 85.45473344864385, 78.00899228742047, 22.021313828806726, 0.15027337106725863, 0.13522620913722824, 0.07684806466943796, 0.03746602789408738, 0.07483170593097326, 0.05815137861176364, 0.02591046106611048, 0.04745278837940386, 0.09539712941454304, 0.05472828709189931, 0.04108460973046961, 0.05442006310688392, 0.1441925328465239, 0.09042532603827216, 0.0729323134967877, 0.1457737230004803, 0.05710625082194325, 0.05963052202376628, 0.04331688268951351, 0.03258584480312082, 0.10163975008312734, 0.1326731751642881, 0.1077447507169939, 0.10205845543814283, 0.033988023191810615, 0.021201904652820482, 0.06652984858280228, 0.09202592886022984, 0.09922267373410926, 0.028528156690299514, 0.04870020934650975, 0.035844503210917596, 0.11294738404572972, 0.07936844797504526, 0.08189990125115841, 0.05205110857082952, 0.040642508050246585, 0.013738285389638717, 0.025688186400539936, 0.053419502482058547, 0.14203299227501118, 0.12091439202307694, 0.06228004477076954, 0.12109158815996302, 0.09968596540631787, 0.0846503330995479, 0.05987629835163394, 0.09796254336833955, 0.024626375130948522, 0.23502681194053543, 0.06364570757854851, 0.13331969208534689, 5.430663199194017, 51.49180873747795, 128.23986884086364, 105.40473184277936, 127.4474088607296, 87.46017071508592, 81.1231267067694, 24.847410955736716, 35.99006837414157, 96.62252149274273, 85.70978949146887, 126.48936994614141, 127.44304718509798, 52.1437890298905, 0.34015085247735827, 0.040711555554861986, 0.08714464643309194, 0.11554409269123309, 0.07017244344517108, 0.2861998458543132, 0.5839932986324834, 0.6674484656222406, 0.20213194642095797, 14.535460549016154, 67.51298858273414, 95.10777273485738, 101.54034999109085, 103.3538107718191, 101.4975804667319, 105.53782570746638, 104.52394008636476, 105.83065417505081, 110.31858305777274, 108.75266305861935, 107.41258528924759, 108.69700462587419, 107.11543436973326, 104.440793683452, 102.34299244419222, 101.31238968141618, 94.38818254778462, 90.82642724437099, 90.08833915956559, 92.74643528846003, 93.30931894240841, 102.97548247921853, 105.12237610355501, 101.7027125820037, 100.85900291319817, 90.7151339131017, 94.75702654930853, 92.4650993654805, 93.17769988890618, 85.61750396605461, 92.04367206942652, 91.0479627117034, 95.03636990824054, 94.74525943879159, 108.64699440617716, 93.41468164997717, 78.24579361946353, 97.40812516981556, 100.26843517057358, 103.44856739044191, 100.66293147302444, 108.99839954991495, 109.2557462569206, 106.52908709741409, 97.51960677485313, 96.10479216421805, 96.3140663023918, 95.21869736333048, 87.95387944867535, 82.71598554426625, 76.29987439801617, 72.00439268542875, 67.0450262869558, 73.71291437456685, 82.61492959914669, 87.96030429101761, 87.136441815284, 88.54363918304445, 94.25182527111423, 96.50750975455009, 99.1855864371023, 99.1759374064784, 93.97895382296656, 94.84593099163425, 96.00281838447818, 92.98813173847815, 94.53735813017815, 91.88501219595634, 87.06776895830708, 76.41021851570376, 76.9348669052124, 37.66759941654821, 4.8157277318739125, 0.7166745177199765, 1.371373135236002, 0.5465252252836381, 0.5087634951116577, 0.6792321849253871, 0.2530526769377532, 1.149240977341129, 0.4274447021945831, 0.09968136887877219, 0.029340451207732963, 0.05077393274874457, 0.5944178553838885, 1.146196972939276, 53.508934667033536, 109.61720051303988, 91.70059019519438, 39.164999531161406, 60.87021935370661, 21.979854376085346, 33.16516953129923, 46.958415662088704, 64.4215254629812, 92.33628872902163, 78.07439388767366, 93.86272615002048, 95.59917511478548, 36.48233759787775, 0.17460098339905664, 0.1440498413097474, 0.07556063093004689, 0.009062339424065525, 0.04889969481155277, 0.07440304143294212, 0.010897652433824637, 0.05616891926394836, 0.02518592192040336, 0.014693059812059567, 0.020681882254599084, 0.02368668593736666, 0.026470028922983238, 0.04053038725208852, 0.05454881950431774, 0.09001644193044595, 0.07484708897649281, 0.0714053700287496, 0.032318794213595896, 0.02506857831782151, 0.16038996047310292, 0.159550879691397, 0.10137675209872185, 0.10678820567385805, 0.06661509884701622, 0.06935449136841683, 0.03342437400152126, 0.2972041779468137, 0.2356708773802365, 0.2129122284391234, 0.17035967550210415, 0.08251598915986477, 0.1280760653917828, 0.11484123000334348, 0.17328162677586081, 0.10514722235741154, 0.1751839303441586, 0.1136821159912694, 0.16963048237225703, 0.21437510397405396, 0.19158342132164588, 0.24786616975982345, 0.13608413568187144, 0.20379083321219493, 0.22574919606408766, 0.1442050660449651, 0.10501861151668335, 0.270291080157603, 0.10585600690495585, 0.5014878661642151, 0.24990263064542126, 0.16205394940991558, 5.400462910052269, 56.18085715078539, 148.6830895946872, 112.19091077004711, 124.3259003854567, 80.2000831788586, 67.22503954364409, 41.82899882716518, 124.30813204857611, 143.59342205908993, 96.48947469649777, 142.43828404334286, 142.2334578729445, 69.76337002169701, 3.0854094316882477, 0.29050329880368325, 0.4747156366225212, 0.4331060306679818, 0.19137763478342565, 0.40900793827829823, 0.6376977168744611, 3.035248200739584, 2.182395241914257, 14.004838389735069, 67.38508009141492, 102.56052709394886, 110.20199452677082, 116.59531670231974, 109.97107674998622, 117.7332982709331, 114.8857516627158, 114.75592121001213, 118.52906873149257, 116.6515713353311, 112.92932833394697, 114.82034221772226, 113.11038494110109, 113.03065100023824, 107.43182843731297, 108.31564041876025, 102.45201864550191, 98.83462844356414, 94.72129375703874, 98.91913198655652, 98.69065392401912, 110.44347132405927, 107.51658301199637, 99.33545235664614, 104.43045431567778, 95.70691477867865, 101.04417016429286, 97.14942132273029, 96.27784713622063, 90.26487719628119, 101.3715390236147, 97.17477552352413, 100.71962541149509, 100.70916052787535, 110.07366241947298, 102.67160077248852, 95.29989827063777, 104.19643002171671, 103.07416146801364, 103.15919060860912, 104.2123156209146, 107.4384807771252, 105.0518754220778, 108.2724472784227, 98.09822697793284, 101.45641911414363, 104.89647896059098, 102.84885268057548, 97.99295840724822, 91.51529742825417, 85.60361093090427, 82.75479347475114, 82.00131400938957, 88.58845618463333, 94.47823232220065, 94.97535351783999, 95.70788752648139, 94.73602617940595, 101.86953883017264, 101.14482602765484, 102.30213703647738, 103.78858197119929, 101.47184971840151, 99.2014406573388, 103.07147072207545, 95.154017479189, 98.68597061403337, 96.58030110020792, 95.9031980268417, 86.62639248755671, 94.61493476744621, 47.83047230012956, 5.387268056792598, 2.2818515954479097, 7.130476736253308, 5.475057075100561, 3.5639530564508135, 1.8857096135616305, 0.2248096811555086, 1.3133713314610145, 0.6645591496940583, 0.3278120871513121, 0.2610774326228327, 0.19114226192956973, 1.076553206770651, 7.504597796547798, 73.74672520545222, 116.05738716740763, 107.88554468462544, 53.60615453412456, 98.33549114965625, 91.53888656247048, 52.25598450629942, 35.144703465123335, 50.09629611046084, 85.98357877423688, 76.95250188150715, 101.27653137330087, 110.62755600098642, 44.58399711116668, 0.3971401944516167, 0.24352628166877457, 0.18451059116951882, 0.11560052272773559, 0.12764347086270011, 0.1934182019002976, 0.10770483753613888, 0.22532925730751407, 0.200672181203, 0.17945159166570634, 0.1039850899589158, 0.17277421610009286, 0.16205270834747823, 0.1867488396143721, 0.18674006024675985, 0.2836735943152059, 0.17985380314771207, 0.20659716649641915, 0.16248942442959355, 0.07797333291701733, 0.246711460753314, 0.23565937073961382, 0.23516058621387328, 0.14513535725493587, 0.12023945324002736, 0.2086526570060561, 0.1178121802607371], [0.12942870087440939, 0.04738143495013637, 0.03648849970270549, 0.05826168761198079, 0.006574643653772411, 0.09863151432645899, 0.026154961857584216, 0.17044294925947345, 0.29111705780509983, 0.047022258457277095, 0.04048520338631446, 0.12151539566055422, 0.32813528432480754, 0.3892273335687576, 0.12875915535034674, 0.12988018713170482, 0.1170352598532073, 0.07688179552074402, 0.0375564837257468, 0.11826489991959065, 0.23856284397263683, 0.03522238619024715, 0.32764713309945603, 1.000092790251778, 18.020211881206883, 79.04550998441636, 108.75419278298656, 99.6363530620452, 82.66814831764468, 55.641837196965376, 66.88208318525746, 48.068485644555864, 121.5344201364825, 154.81579380650675, 112.35698392314296, 120.71105972413095, 122.90910105551444, 47.96560187493601, 0.3239235167782153, 0.10867106593063763, 0.3664318357984866, 0.07058349558182302, 0.24308712942706, 0.17772761804442253, 0.07093232605726489, 0.3469779829104101, 1.1138543342390368, 1.1327170123977046, 37.31318581488825, 82.75063576236849, 91.02868818467664, 96.40241376815304, 91.69713850944274, 96.57860663629349, 96.52281484296246, 103.9905918798139, 98.02000707195651, 96.50892180781211, 95.27863117956346, 92.71444443733462, 92.96494268601941, 92.71942584745346, 90.22752054276006, 91.57321514621859, 81.03593241783881, 76.48702636841806, 74.53264267213883, 77.34434666172152, 80.00575327104139, 88.85885653957244, 96.73777641788607, 99.67416471050632, 99.21024245600547, 94.21825762717955, 88.16168662040465, 83.31934021365258, 89.38219485744354, 90.51204143031951, 88.27983625473516, 77.84878700010239, 77.99331849621188, 85.66446258175759, 87.00963943235337, 107.1331399486911, 110.74473288751419, 71.40260696411133, 74.74889078447896, 92.70023761257049, 103.91215232110794, 111.90622514294041, 134.10282381119268, 114.8490696568643, 106.67591710244457, 92.22847061772501, 89.84900397639122, 84.72901651936193, 81.20575535681941, 78.97648411412393, 69.8878268272646, 64.18552821682346, 64.13251346157443, 56.32402366207492, 52.85513047249087, 58.68882063896426, 69.04523895632836, 71.25816176014563, 75.52097012919765, 84.61509520007719, 87.01964932103311, 88.17391657060193, 92.91427350813343, 84.64461495799404, 80.91888104715656, 84.38296933327952, 88.77077579498292, 83.11101528906053, 76.38375820652132, 79.07473948694046, 70.83682075623544, 61.79589086963285, 56.27260923385621, 40.28367127141645, 22.955081116768625, 3.991286706539893, 0.688439887617865, 1.4432891794750768, 1.2428978614268766, 0.2873975783586502, 0.3186285009066905, 0.08758590541659825, 0.1732522549648439, 0.06575092102491087, 0.07655587107423814, 0.05780096999519776, 0.2325112396670926, 1.3911461709968507, 40.198163601659964, 97.38340639298963, 114.4107291006273, 48.23970886968797, 68.91384740029612, 65.36713830886349, 30.88180095918717, 28.57602780865085, 32.07171078651182, 48.110415781697924, 58.33312049988778, 76.47027000304192, 82.99221454128143, 15.864891044555174, 0.6031082955098922, 0.11909781369350611, 0.1179650224625103, 0.12393269417507034, 0.25717795315769415, 0.03455700052361335, 0.09923136883204985, 0.05001423782819221, 0.140903533526486, 0.05034125011955058, 0.013360220999006304, 0.06639410546349903, 0.0992730286933722, 0.1525572170653651, 0.08741894421438057, 0.10045127192091557, 0.012470565965369105, 0.07998341739538216, 0.09494155990861117, 0.12942490107830495, 0.10225577670479975, 0.09409884020926491, 0.02255645727047757, 0.04097407090387518, 0.08041824124032453, 0.1361382980981181, 0.17578846564696682, 0.05176293310679255, 0.12687063370380672, 0.07875605261013394, 0.03349190082160696, 0.05737785580417803, 0.08623159986229674, 0.10432612165928849, 0.05988979682085976, 0.05646049615836913, 0.016312620437313474, 0.1301583383352526, 0.21423800487912473, 0.20024209944230897, 0.17622827672429625, 0.1535655113477861, 0.10985444960815292, 0.14702164958561623, 0.11992800019441113, 0.09169016018389695, 0.06072870523278272, 0.08696430167483707, 0.16894872540668135, 4.186145153737837, 34.3573857122852, 99.00266278174617, 126.65428207766627, 113.32414627075197, 119.30020670736991, 71.48998952681019, 63.04599731199203, 31.850583245677335, 59.35492538636731, 149.5051085564398, 121.7116955787905, 124.2129518139747, 131.75806230114353, 47.92789613046954, 0.3043441786881416, 0.057687588982404246, 0.32418135133001114, 0.10843824414956955, 0.21088010361117704, 0.45597482773084796, 0.39166251257542645, 0.7536301701780289, 0.1734363458930485, 2.1656001431326715, 44.099745212062714, 90.66161709447061, 98.45681005908598, 98.03983073080741, 94.23487278722948, 97.61823085046585, 96.56315249781456, 105.36066793626355, 102.33379840850831, 99.94883260419293, 96.50350109223398, 95.39234853559925, 94.7228862393287, 96.78621768951417, 90.75711111868583, 92.12347661295246, 82.94280836659094, 80.49871675429806, 77.0733501065162, 81.33837853708576, 81.11790210969987, 92.04250320311516, 100.4188580666819, 104.83086555234848, 104.21117028882428, 99.73419266362345, 94.37781964578937, 91.5403849078763, 97.20204384096208, 96.98252447189824, 93.03680050757625, 81.93326873164024, 85.37768240897887, 91.10437423952165, 91.36892241816368, 107.32980758913102, 115.44128479496126, 80.5434553084835, 78.35327440692534, 89.9587126701109, 106.791470127721, 120.8395016577936, 135.61223030090332, 120.90217328840687, 109.35083235463789, 93.07626739625009, 92.03420346783054, 83.99889869074669, 87.1967129553518, 88.48844358997961, 79.55255477659165, 77.87007762539771, 76.26920146326866, 71.41817877369543, 66.00935582191714, 69.2521910513601, 74.42161606204125, 79.5278673787271, 82.70210819859659, 87.11548066908314, 92.13055256874331, 92.74827880244102, 96.30864558681365, 91.50429910229099, 87.74046328759964, 89.19214817785448, 92.91558357977098, 89.48543948511924, 86.64893827130719, 88.89476976087018, 83.90531878317557, 73.24908625695014, 73.28329716959308, 64.05057907104492, 38.585390890798266, 10.904841173079706, 1.1224525373789573, 1.3815764457948747, 0.5995961194557529, 0.46690491058172723, 0.612759103457774, 0.40713724349775626, 0.6352963683105285, 0.09195593906746757, 0.06393448059116641, 0.02884628236173622, 0.35689419435877956, 0.5054098073272936, 37.37204097932385, 101.42375361534857, 113.12606657705, 44.16114599474015, 51.873561259238954, 23.54308755167069, 21.36931392454332, 36.56709609493133, 52.80191175399288, 79.53439420269382, 76.62874160274383, 85.30227092004593, 92.29235033835135, 29.997347670216715, 0.41206686607291626, 0.13904327286347268, 0.1178050020168866, 0.14102275212926252, 0.11627339307338962, 0.04432518463281374, 0.02018945051297065, 0.01998804216723769, 0.06401146859711697, 0.01024185052712358, 0.056221024734118295, 0.14030518821410595, 0.042630751361890186, 0.09776601883312387, 0.049757081264209364, 0.12446196900019724, 0.03401047722887128, 0.022973176542549364, 0.027790689810870156, 0.07252968832730286, 0.07734622100308057, 0.09776422618738106, 0.04338899071538641, 0.09035483828835911, 0.06817729768132971, 0.0983202834463408, 0.46983081486917316, 0.18472190886255235, 0.2621809975995172, 0.28686254255233273, 0.11890377128316511, 0.14885859053221442, 0.2447429825101168, 0.3435850101372888, 0.2982028501649057, 0.2777804782794368, 0.09639882001905672, 0.15962427091454306, 0.47253660677421483, 0.38183032565059205, 0.2128989291527579, 0.2097847510970408, 0.2696672700826199, 0.20861717181340342, 0.2115586736509877, 0.20021963774436907, 0.36885080438467766, 0.15929604820426435, 0.27220213244999614, 6.351543049658499, 44.37436995967742, 117.10336562125914, 140.83406602182697, 116.4745077010124, 108.69425112201323, 69.46109648673766, 76.5298508059594, 61.857083766691154, 148.81011163034748, 182.0524028039748, 124.53116586131435, 143.29347056727258, 139.70443910168063, 63.7643244958693, 1.0021579181475024, 0.22494567708382684, 0.8500405581247422, 0.5499281265562581, 0.3632787098326991, 0.5475422836119129, 0.2990746582227369, 1.9913136694700488, 3.480069247945663, 2.2978703100835127, 43.173748139412176, 98.20113428177373, 107.4803795353059, 108.48065453190958, 100.4351672818584, 110.07892624024423, 104.22795803316178, 114.91437712023335, 108.49180975267964, 108.9964226753481, 100.9508099094514, 102.32305111423616, 100.33546063207812, 102.80234121507215, 98.41523293525943, 97.29574141963836, 89.15118294377481, 86.59999493629702, 81.76397923500308, 86.61221704175396, 88.17751730642011, 101.46655451866889, 104.22763639880766, 106.70946121215822, 106.10163504077543, 104.91115646977579, 99.53710925194525, 94.16128912279683, 98.58806040979202, 102.52149951073432, 102.53389420047884, 90.43074638612809, 88.56448265814012, 99.25602436065675, 101.18080985161566, 118.42923656586679, 119.58369993394422, 88.42236734205677, 91.5483473193261, 101.10624559463994, 107.21961252150997, 110.09988738644509, 117.51242960652998, 105.46803105262019, 100.7609671931113, 96.44844670449534, 92.80545911481305, 91.25689168130198, 96.87897389934909, 95.45747556994039, 87.48595637659874, 89.29569090566328, 82.84772226887365, 76.86442113691761, 74.48464855071038, 79.44841584851666, 86.45840521781676, 85.11416973606234, 87.77153630410471, 93.1963860604071, 98.21901244501915, 100.4130215798655, 98.21996165860085, 94.33213972276258, 94.4790481751965, 92.50793949250253, 95.7692490854571, 92.95888654647335, 90.68166825079149, 95.01798968161307, 87.82706922100436, 77.06341082049956, 84.31545749787362, 79.46132829112392, 45.61884780083933, 10.881151037831462, 1.3324914151622405, 6.277934380116002, 4.1479839240351035, 2.117918585577319, 0.9994593887559831, 0.4900064451559898, 0.8739221540670242, 0.25875520561971976, 0.2983669461982866, 0.25310789655533533, 0.8463140000258723, 2.9513729724191853, 58.00482596120527, 110.82496104701873, 134.94467427653652, 63.06989239108179, 106.11748141627159, 81.93372372658023, 41.36919898371543, 33.663169337857155, 38.3016074088312, 68.06095154054704, 78.54722776720601, 91.70209638534054, 108.42027356547695, 43.292682247777144, 1.1167345796861956, 0.34597502059994206, 0.21053703411692576, 0.35914257048599185, 0.290080847278718, 0.11052477654189834, 0.15147976036514008, 0.16437085976283397, 0.20043990334435818, 0.20593857602967372, 0.13626568319816745, 0.22801339956781558, 0.15566820819531718, 0.17931787867940244, 0.20301109360110378, 0.1951377322116206, 0.1747807535913683, 0.17519254117242752, 0.2844871490472748, 0.26696674886249727, 0.16823773452591512, 0.2425793816726054, 0.2131032448021635, 0.14395564313857787, 0.13322471250449458, 0.42945255735708826], [0.12586960959578716, 0.09330170274141336, 0.04530264387628244, 0.1799768675118685, 0.020760247303593545, 0.1590087345891422, 0.01874661966857891, 0.1353988547118441, 0.17991674493157095, 0.055565395197200204, 0.09176892168339222, 0.16325764207830354, 0.31232503753515983, 0.6681386189114663, 0.05617660695626851, 0.06310222565286583, 0.03814136504285759, 0.12361354960669434, 0.05739146535615287, 0.034426811541761124, 0.03753333254867504, 1.5239122726263539, 34.236204085811494, 73.21678161621094, 104.84514297977572, 103.51286288230651, 88.99519028202181, 72.94181562239125, 45.09040647937406, 52.59466155882805, 84.36012544939595, 123.42516729908606, 106.6817065208189, 101.75895937027471, 130.87792950291788, 120.83874071798017, 42.27689819951212, 0.2278978428653171, 0.1401874864654195, 0.3700182917377641, 0.04206904037404926, 0.2060546230284437, 0.027845731313009898, 0.23222057058686213, 0.46274453221309575, 1.8036872148513796, 0.29078089842392557, 6.503744740639964, 67.27722275641658, 93.54261367551743, 97.42404999271517, 92.7944137204078, 84.02913232003489, 82.08019287355485, 86.9234335807062, 83.48762558352563, 84.45559593939012, 78.63716771525722, 77.62039522970878, 77.02950585273005, 77.87115235482493, 78.579618700089, 79.35271001631214, 76.34378140972507, 76.44785757987731, 74.58371193178239, 80.18973596634405, 89.72064833487235, 90.14384854224421, 86.14806728978311, 89.42723935650241, 97.8183658661381, 98.39846088040261, 94.14541921307965, 84.09874654585316, 79.64580520506829, 86.44356296908471, 93.15378912033574, 79.11295121715915, 66.817654332807, 71.84460316934894, 78.0413753755631, 81.10096531529581, 86.74576590138098, 102.73733185183619, 98.34805842368834, 71.29664805627638, 62.74636353215864, 100.26771345446187, 137.86542800164992, 128.9608867706791, 102.60731312536426, 85.03301589719712, 82.38383139333418, 86.0858271198888, 93.23477821965372, 90.29447540160149, 105.8316033886325, 82.00991184480729, 64.23294574983659, 67.39237569993543, 63.60019683837891, 72.10740981563445, 65.97425060887491, 63.41140923961517, 66.38860194913804, 73.89300607865857, 77.66270975912772, 78.40973300318565, 84.72480389379686, 88.88804681839483, 83.45056703013759, 81.47053887767177, 83.6515178988057, 80.56638548451086, 78.4976411634876, 77.93600482325401, 72.7541066754249, 71.46093260857367, 69.34228004947786, 63.006110729709754, 60.20241622001895, 65.82688716150099, 62.39776680546423, 34.59602271356891, 3.5183520711237386, 0.9621310498445266, 0.7902289482374346, 0.5689551152529255, 0.3351840899596292, 0.7240530475974084, 0.13570518262924688, 0.16139163575585813, 0.17445317439494595, 0.44238485696334995, 0.33480665376109464, 1.0681214592149182, 26.762376792969246, 83.33819896944108, 117.14462111073156, 62.39639397590392, 82.53166552512877, 84.2743432137274, 48.44732776764901, 26.81128286546277, 24.650237329544563, 44.11683890127367, 68.38030307523667, 75.80202364152478, 76.91776537126111, 22.0705807593561, 0.7974481318266162, 0.048656534673946525, 0.42590894105453647, 0.3954756079662231, 0.07458107260566565, 0.029148789415616664, 0.047553410197818474, 0.1452387025159213, 0.08465690613393823, 0.02323261221810695, 0.0942282707640721, 0.0035596952910700273, 0.11161969238591772, 0.1350101263773057, 0.05449396760893926, 0.03879658855317581, 0.0640213358095817, 0.30178225809527987, 0.17335216815192855, 0.1471705004693039, 0.18541017757548442, 0.06578009365306747, 0.09616838077143317, 0.14431181273633434, 0.2289313720839639, 0.07915441833075978, 0.036900317927281705, 0.029853881419365926, 0.18629045856575813, 0.09544461154408994, 0.13333640812385467, 0.040525970755205046, 0.09685741557228951, 0.16869810740313224, 0.028661381295551697, 0.07836913224309683, 0.06979069417162288, 0.11580928934798126, 0.31149104357727114, 0.06609336998794349, 0.10897344083435113, 0.038691611524911663, 0.09999735716490016, 0.046621410611776576, 0.06382294968071003, 0.10587507483339119, 3.9055441848693357, 51.377934486635276, 97.42618376208891, 124.82550051904495, 130.42562530886744, 115.91030613068612, 113.44246848937004, 80.336440455529, 55.530732139464355, 64.02324015094389, 90.87501756606564, 110.43711708438013, 116.79461233077512, 131.42595521865354, 127.75595034322433, 38.82144697250859, 0.4899072827350709, 0.11751991005674486, 0.27787672956624343, 0.14570129704811882, 0.15823608895222988, 0.27812757739616983, 0.4884577830952983, 0.11136362749722697, 2.981881167619459, 1.466467690563971, 7.71888570439431, 74.75927722069525, 99.77702494590514, 100.0960313120196, 95.10332476708197, 90.13324245329827, 84.39230457428964, 88.40012750317975, 84.57516547172301, 87.2591963121968, 80.4399831833378, 81.72442605418544, 82.51227332699685, 81.40595313041442, 81.258009172255, 81.89128368131577, 79.87495791527533, 81.07339105298443, 82.825513808958, 87.85997006200975, 92.86800522958079, 95.21198226559548, 92.49314431221255, 95.7294370282081, 99.91655149767476, 100.39922268159928, 97.44901980123213, 89.32922717063659, 84.65668016864409, 91.84028933125158, 97.79781264643516, 82.97864314048522, 74.83238235596689, 79.0782303963938, 87.53735511533677, 90.59954950886389, 94.20975392864597, 105.04315991555492, 106.19050025939943, 75.7096439792264, 70.18027090257215, 101.43253187979423, 136.1265471673781, 131.60648622820455, 107.38735660429924, 86.98306145206575, 83.41740731270083, 88.99163661464569, 97.26803379674112, 98.56870743536182, 114.45682479489236, 97.14254933018839, 78.92139050268358, 82.91532039642334, 76.39936923980713, 80.16119680097027, 76.59922184482699, 73.84141122141193, 74.29925380214569, 79.63924700214018, 85.275481131769, 86.3058485523347, 90.33238118694675, 93.8689862528155, 87.72032583913496, 89.51319417645855, 86.58265806013539, 87.3099047137845, 84.50027958039315, 84.94466843143587, 80.44636880197834, 80.07604214452928, 79.13694827787339, 74.3660831451416, 71.35392250553255, 81.26706984735306, 81.93544956945604, 55.112964414781146, 8.954420051267071, 1.845918639052299, 0.6363695042748606, 0.07555399660862262, 0.5064326266367589, 0.602357835779267, 0.3052925955384009, 0.29807479090748296, 0.16643448612622677, 0.4116059262906352, 0.44893135406797935, 0.10912379325037042, 24.970653787735973, 86.64279583961734, 118.17919331212198, 67.93371769689745, 67.3716655854256, 30.5141415134553, 20.581537254395027, 35.081467013205256, 37.24035916789886, 63.35213045920096, 89.66374258841239, 85.0749695685602, 92.50837095322149, 37.70601511001587, 0.32853898201738635, 0.062186271778397986, 0.1378936660025389, 0.17818183157472842, 0.15098636909838647, 0.032832168883854346, 0.07111761974351061, 0.10990977647804445, 0.03230985013707992, 0.062004578705396385, 0.08055083573825898, 0.01157274156162936, 0.12690968886618653, 0.023071590112522248, 0.05767527411902144, 0.03167257415160778, 0.12497421369076737, 0.21993607492937198, 0.061332539565140204, 0.10465886428832047, 0.13517831332020222, 0.05374595169879256, 0.06462632693470487, 0.08535337198766009, 0.17436864425338086, 0.48676521907891, 0.21709005829067002, 0.13822694489311788, 0.5136823005253269, 0.20891887255974356, 0.2096672025659392, 0.1336290843544468, 0.21650300511429388, 0.4778308259142984, 0.10706986556009901, 0.3004790199620109, 0.36046600269694484, 0.3814707852659687, 0.6371661744290783, 0.20918389301626913, 0.19027819135977378, 0.1099711707642963, 0.23997174095242257, 0.11527233832185307, 0.14853658845588086, 0.2318468575756396, 7.5519123673439035, 65.04605700892787, 122.04039019923057, 145.02119618077433, 132.92352399518413, 110.3309306790752, 100.47279065655124, 55.27519756747831, 61.336436194758264, 101.58613189574211, 141.69372404775314, 131.04612858064715, 115.61116264712427, 143.60694639144407, 136.32621149862968, 54.71402014455488, 0.7062264880345714, 0.2270222350113815, 0.6012200419941257, 0.16356300472492175, 0.3681749309743605, 0.2329056523740292, 0.4994060069082245, 1.9184170326878949, 7.222461710053106, 2.724162570891842, 9.938882012521068, 80.16484460523053, 108.37761386748284, 107.49402938350555, 104.79682722399312, 98.95166412476571, 91.69702083833756, 95.66406680691628, 93.98148767409786, 98.37064343114054, 86.98612090080016, 85.2418036614695, 88.1404273740707, 85.97653419740739, 86.93395337750836, 85.83007289517312, 82.84235646647792, 83.57641235474618, 84.45670204777872, 87.88859551952731, 98.4314872372535, 99.09409323046285, 96.17144107818605, 101.6992687409924, 105.25095139780353, 104.5832149444088, 100.26023741691344, 91.70288085937501, 88.22599780174994, 97.09073482021209, 104.74305152893068, 88.75576880670364, 81.77954319984683, 85.87442705708166, 93.23168739195793, 98.52802461193454, 104.96093919200283, 117.18465282071023, 109.58048712822699, 84.52909331167899, 83.60799527937367, 100.50373031247048, 111.56422584287583, 108.98605977335285, 97.98625899899392, 89.59411267311343, 87.11508058732556, 92.7143346109698, 101.03928289105816, 107.59616005805232, 115.6714730108938, 98.40877671395579, 86.81573314051475, 87.27865911299183, 85.77840743526336, 88.15209250296317, 84.22548617086103, 78.61746957225185, 80.5406782704015, 86.69867392509215, 90.97881132556547, 85.31916064600792, 90.8715815697947, 94.28298457976311, 92.6212332325597, 92.94105545167001, 87.60732235447054, 88.66640152469759, 89.13770567986273, 89.42993010244062, 84.5774326016826, 85.1870003054219, 86.73585014958536, 77.53530333119055, 75.90631946440666, 89.9845689342868, 94.90595110001104, 64.19577344771355, 9.081220473012618, 2.20871998417762, 3.286796909186148, 3.066625936377433, 1.9629952599925382, 1.4310942854612105, 0.4944265579744693, 0.44216931046497443, 0.3336078487336636, 0.752570639935232, 0.8405805980005573, 2.133111150995378, 39.806836574308335, 94.1476078956358, 136.0707239950857, 76.78817810550814, 120.1039082004178, 110.05031647220736, 62.26367665875343, 40.346809664080226, 29.283860691132087, 59.41050144933886, 88.93731963249945, 92.4344107412523, 106.48687454961963, 53.24748123845747, 0.7101348234761147, 0.17901907374541606, 0.36792944575990405, 0.2983492342454772, 0.2662949203964203, 0.22351811820220566, 0.2717711620273129, 0.5220946813783338, 0.10533698233625582, 0.16406414880146905, 0.19274582185091513, 0.16816135555986436, 0.20376800379205137, 0.22544928796349034, 0.13890025956976798, 0.08060516669384896, 0.17970699005790297, 0.4397920170618642, 0.21774812781762695, 0.33439860468910587, 0.36695369489250645, 0.11567684806763165, 0.14186426907056762, 0.3052909407884844, 0.5456634070123396], [0.06900396017778306, 0.046041275209356705, 0.04290250956170982, 0.010017449967563152, 0.04520666072024934, 0.08259406118022819, 0.05188930314034224, 0.11872832182674639, 0.15224606279403935, 0.06184739278509252, 0.05808158034098245, 0.04193878627472347, 0.1544939026597046, 0.04340328591605348, 0.05706587415789405, 0.053440700134923386, 0.017407042154621695, 0.09559890165204003, 0.1666534953420201, 0.09479029584796199, 16.192368749649294, 83.99542347077401, 104.14951062971546, 95.59031055819605, 98.68320926543205, 63.98049808317616, 60.4254892564589, 44.94172903799242, 38.61469099598546, 77.44730103400447, 132.9257675909227, 101.25043192217427, 87.2906223420174, 118.59738073041363, 118.25034510704779, 36.91927786796324, 0.788062880596807, 0.1837926748539171, 0.08840443972017496, 0.052714276412922534, 0.1969518743815922, 0.3895039219529398, 0.09065104618428216, 1.826193774900129, 3.6550422589625087, 4.398416963315779, 2.5086268590342615, 9.533658027648926, 70.61107266333796, 99.8380413363057, 103.81970205614644, 95.63239759014499, 89.09250428599697, 83.4826441734068, 82.6292384055353, 81.29829191392469, 74.60471230168497, 73.99707440407046, 71.74100552835773, 73.61559252585135, 77.9041551774548, 76.88527245675364, 79.11936821476107, 81.24555956932807, 88.9823405973373, 89.20029101833221, 91.70776813260971, 91.65999366391091, 93.31345312057003, 88.58770308956024, 87.13398641155612, 95.52659557711695, 90.57465814775037, 91.45683057846563, 82.47603062660464, 78.96829420520415, 81.31118082231092, 86.19555934782952, 86.1371317217427, 72.75684448980516, 65.3600388188516, 70.13020576969271, 70.13342995797434, 74.60725399755663, 75.56945062452748, 105.97533472122686, 92.50931232206284, 65.58417089523809, 93.27339003163, 98.00433328074794, 77.03464415765579, 68.70036848129766, 66.64159482525241, 75.19452694923648, 76.60117518517279, 85.0858659128989, 78.6824240223054, 79.2363097590785, 78.51295409664031, 65.18006086349487, 67.99232575201219, 68.97508344342633, 74.16302988606115, 79.06960118201472, 76.59908848424112, 70.90406587046962, 66.45154814566335, 73.85223696308752, 83.33425306504773, 88.20306762572258, 88.20673896420388, 88.84926242213096, 87.51817472519414, 91.49502661920364, 87.89287090301515, 81.30134351791875, 79.95196188649824, 76.52270424750544, 74.5427780766641, 72.12765709046396, 69.40993309020996, 71.1007256661692, 69.59694385528564, 63.76244175818659, 63.315071905812914, 55.70455589602071, 15.296366041706456, 2.446339865846019, 0.5502739692887952, 1.2298545097151112, 0.9113956819618902, 0.013089520000522176, 0.1343854429620889, 0.2150524176296688, 0.10441658898226677, 0.37147833274737485, 0.29260866163719085, 0.48098741459750366, 22.36902213865711, 70.05173483202535, 111.08041717160134, 75.92034586014287, 82.39402171104186, 75.84913915203464, 45.90335299891811, 38.341309639715384, 30.750785950691473, 46.3430977636768, 64.5153054114311, 70.9241170267905, 80.58937841846098, 32.4137669609439, 0.437080402888598, 0.254797442185302, 0.40626675311115484, 0.2772859838460722, 0.037244885123424956, 0.14851772737118507, 0.14504698135199087, 0.08617865552584972, 0.12282707608274876, 0.035503425545269446, 0.07661130519643908, 0.05946464483596145, 0.07738627207976195, 0.04243920256774272, 0.016043767625946673, 0.10533261563508742, 0.0722757684848001, 0.06291656424441645, 0.3052088468065185, 0.14466773718595505, 0.06949525236362411, 0.058596460374012116, 0.10202732162490007, 0.0782746812629123, 0.05149802756345561, 0.015071042805850027, 0.042722210768730416, 0.028359663312233267, 0.03787271716001053, 0.048984278579272574, 0.017522748244265397, 0.13386773606461863, 0.07652685166366639, 0.007919158604401615, 0.05806823125890186, 0.029560712977282466, 0.13640132672604055, 0.11539487408534174, 0.0776669820169768, 0.02192528892098175, 0.03895496190976232, 0.040274192128450646, 0.07838594021215554, 0.05926925028043409, 22.50756613669857, 107.52576135819959, 118.28240656083631, 113.01779347081339, 118.13490975287654, 91.65613405166134, 97.30056593495031, 79.88963542446014, 44.518203273896255, 62.41366809414279, 138.00572333797334, 108.88130111079063, 96.2299785306377, 121.98962688446046, 126.25700089239307, 35.0348182647459, 0.8899896531816452, 0.03881758319274072, 0.4421464504013139, 0.13565046862969476, 0.20344293736402067, 1.0472678104715964, 0.25169665534650126, 3.5763536297505905, 6.874397445109583, 7.412476030088241, 1.9069509640816722, 17.535357898281468, 79.75236031316942, 104.49290629356139, 106.45439732459285, 103.91050492563556, 93.14266527852705, 86.90027590720885, 84.52824607972177, 85.58419519855131, 78.48847066202472, 76.58471691992976, 75.7777363254178, 81.27531466945526, 79.15252008745748, 82.64138990832915, 86.40124843966576, 89.94940880806216, 94.74112526062997, 96.86287649216192, 96.37133290690761, 94.00990916836648, 97.38595593360164, 92.96164005033432, 88.20536613464357, 98.55817194907897, 96.46792519477107, 96.54503114761846, 88.38669730770974, 84.94727288523029, 88.0072001487978, 92.24117125234297, 89.36834889073526, 82.12098552334695, 74.56970122552688, 79.09581045950614, 79.98977353495937, 84.60121785440754, 85.23315091286936, 108.48590266320014, 101.99886721949424, 72.0645461543914, 93.83560688264909, 100.44892695642288, 82.07969081017279, 72.90598084849697, 68.75684276703866, 77.17794402953118, 79.87246328784575, 88.47458977853098, 81.08905699945267, 80.72531992389311, 86.12680804344916, 77.07556232329338, 78.03548397556429, 79.90178692725398, 82.96363615220594, 86.23634415288126, 85.12348928759175, 78.98613314474784, 76.70518859740227, 80.18683341241653, 86.60481160686862, 90.80320681295088, 90.52175321886617, 94.85030051200621, 90.91871276978524, 95.66780090332033, 95.1528250786566, 87.20311426347303, 87.2491942682574, 84.78427487034952, 82.6520352209768, 81.71096447975405, 81.05006863993984, 83.92125145081552, 82.59293294722035, 74.91481488750827, 78.1693152458437, 78.76626860710883, 30.413426814540742, 3.769642883731473, 0.7917274775043611, 0.6065848637973109, 0.5863986921406562, 0.5756065970466984, 0.21396638074469185, 0.09642541859178774, 0.3055154045502986, 0.1910200555838885, 0.29465794683464114, 0.24746657829851876, 22.70034278592756, 76.1661215751402, 114.06111255768808, 85.55735049709197, 73.2881687533471, 48.82429892016996, 19.84660275520817, 39.45696507730792, 55.45565012962588, 62.795675569965, 88.44568975510137, 78.30471546419206, 94.96815989094397, 45.14446458508892, 0.2682673210097898, 0.16258255007766909, 0.10916032032260012, 0.10041702779070025, 0.05517056497234491, 0.07024497664984196, 0.18123412504792216, 0.036852920067406474, 0.10461711249644719, 0.057436086147302584, 0.09093475918616019, 0.10228886404224943, 0.10327383094737608, 0.023586556330443393, 0.014968097825805026, 0.08490546336097103, 0.033429058629178235, 0.06875677424813471, 0.19470305392338386, 0.01554922626969675, 0.03868266361795607, 0.028161667888202978, 0.03759109940860541, 0.05641145887033594, 0.23447452383416317, 0.14191325273244612, 0.14209159800121862, 0.08366946476481615, 0.18608989674718152, 0.17452526326862075, 0.16616897537342964, 0.23200015176928815, 0.30114833565969623, 0.10772648718087904, 0.19485484658470079, 0.13601503455110137, 0.37475850673452504, 0.22637774056244284, 0.1437778034878354, 0.11778383500753872, 0.1304584609404687, 0.20019987267592262, 0.22250810788283426, 0.19410227245140463, 28.17517726652084, 130.3718888375067, 140.36113800541048, 123.77236766199913, 119.87011140392674, 89.52867969389885, 80.64438573775753, 54.755946359326764, 49.95370618758663, 87.75437201223066, 142.2946625371133, 117.48239994049074, 107.3982294144169, 139.11798200299665, 138.7730173910818, 52.70464874082997, 1.229465091901441, 0.18227821095816552, 0.7579707017829342, 0.2253974850980505, 0.6198878273848565, 1.8617501830862415, 0.20760650265841715, 3.3980076255336886, 15.534545106272544, 12.02527896050484, 3.6309446875126135, 17.50715409555743, 87.00981201664095, 111.93951822096302, 114.11367231799711, 108.26775612369661, 99.57285773369574, 94.13157324637137, 89.31578913042623, 90.33799017629316, 82.4168263712237, 81.06626018401116, 80.08048226756435, 83.77375464285575, 84.53896983977288, 83.11062305204331, 89.16418167852586, 91.62553956431728, 97.61872506910755, 97.01235017468854, 101.80700840488558, 99.57257532304334, 104.60939284293883, 98.41038488572644, 91.44098420296946, 103.75755602313627, 100.35436645630868, 100.60461367330244, 94.09707992307602, 89.09138248812768, 92.98964577336466, 99.52110598164221, 94.25388843782487, 84.40167119426113, 82.31000454195085, 83.04703358680972, 86.65792834374213, 89.93284856119465, 93.90635075107699, 119.27290701097058, 111.81667743190643, 87.69838410039102, 93.68169307708742, 97.23516433469712, 83.65432631584906, 80.78449280031266, 80.10283193280621, 82.9592509423533, 86.86968141986479, 96.35083460038709, 88.01141277436288, 94.35500714086717, 90.49624212326543, 82.85429616128245, 85.73114287468695, 88.46644693805327, 93.70392507122409, 95.27626991271974, 88.3079831830917, 82.30991040506672, 77.86208383498654, 85.53439678684359, 92.6789705214962, 97.11062123698574, 94.85008085927656, 99.21999346825385, 96.26917869813981, 99.26808957130679, 97.47535459456905, 89.74351575297695, 91.14773996414678, 88.95639804101761, 85.83048866641137, 86.47214920290055, 87.02228515378891, 87.82382934324204, 85.0705216007848, 78.8266025050994, 86.23630492917954, 93.97177588555121, 36.64980711475496, 2.705749494414176, 3.4703618720654523, 4.447367652770012, 2.443990856409073, 0.5219473473487363, 0.46985339914118096, 0.6702889357843708, 0.30287356566517587, 0.7461447557134013, 0.4971573549893595, 0.8773998868080878, 35.959771986930605, 86.81052423292591, 134.4162682564028, 89.63259112450385, 110.71756655170073, 111.77473160528369, 57.830460917565134, 53.64971245488813, 44.299256570877574, 58.696104480374245, 86.97850365792551, 83.60420626978721, 109.44580078125001, 61.34479476559547, 0.8886266295467654, 0.3316300242177902, 0.4816325832038157, 0.25303101197125455, 0.12084766576487212, 0.27291137665029497, 0.34939679827901626, 0.1636731375249163, 0.21034823940886607, 0.10465927797579959, 0.23355725611890518, 0.13585524393185494, 0.11431655936664152, 0.051875659114410805, 0.11525427396859854, 0.21839309724107867, 0.11604145229343446, 0.14222092896459565, 0.4793507749995878, 0.1788700696441435, 0.16492774439675195, 0.10517054207382664, 0.09726433083415033, 0.18255712824963755], [0.028356056953329715, 0.00729643110741651, 0.03217776125717548, 0.09577293384579882, 0.16372238165668904, 0.09269266284161037, 0.01736824746213613, 0.10844259552897946, 0.047528830266767935, 0.0418603120581998, 0.06416377453734318, 0.1128108595167437, 0.018296897328729113, 0.034137831685403665, 0.033251142369643334, 0.07846330743162863, 0.08251424247939741, 0.12227068174510233, 0.35623719735491666, 17.46327454043973, 98.97671238068612, 90.65919306970413, 94.16692949110463, 72.2608764709965, 54.28068453265775, 73.32658444681476, 44.1008238638601, 39.94089926442793, 136.6317798245338, 163.4610899033085, 98.55373967078425, 87.04504274552869, 110.75383278631396, 124.77974214861472, 44.97012307566982, 0.36553937401021686, 0.05491137827536272, 0.024400218314821684, 0.006013447381255608, 0.07257782929246465, 0.35445285600519955, 0.03658861973352971, 0.2725349823313375, 2.4357376992702484, 2.057981337270429, 0.18305837957849427, 14.98476020751461, 90.56939432697912, 107.9081924500004, 110.63868768753545, 108.64026361896147, 102.81968593597414, 96.9045477528726, 87.8126427435106, 82.25744478164181, 80.68664535399407, 78.95688795274305, 80.24340183504167, 81.57507788750434, 87.86100556773525, 87.28462111565375, 91.6099520652525, 91.25427153802688, 92.94806864953811, 94.9059981684531, 92.50483297532605, 94.55784074721798, 90.49139407373245, 84.4468725881269, 79.16849982353949, 85.29088035706552, 92.97962803994456, 97.06453338746103, 95.75883911501978, 84.2395596350393, 82.87658306860155, 82.30736086445471, 80.31616180173813, 83.61360426872008, 77.077601955783, 71.162840320218, 70.28063651054137, 80.83636222347137, 74.49177941968365, 78.14263528393161, 86.86387631200975, 109.26940394986062, 74.29011467964419, 58.725443809263176, 69.97622136146792, 45.055046312270626, 49.82278531597507, 46.97904732919509, 64.2198528782014, 71.2674891564154, 71.97524947504844, 66.70096382018059, 56.14788178474673, 57.41219897424021, 57.02294295833957, 61.715403833696925, 77.21339441114857, 79.47990463626, 77.83287786668348, 74.57899724283527, 84.17389131361439, 82.2097566050868, 80.05276679992676, 71.07358286457678, 79.65089644155195, 79.28689264482068, 85.85665087546073, 84.93393682664441, 91.18039761820148, 85.91463919608825, 85.30644432190927, 86.06857653587096, 82.69374570538922, 78.54325832859163, 81.92963661686068, 76.70264690153061, 76.54471658891248, 74.03370934147989, 74.4052048652403, 73.03290090253277, 59.70593044834753, 55.369730611001295, 33.03052633039413, 5.4921801820878065, 0.8106862537322507, 0.44128484663463413, 0.18189113737354357, 0.24469640436432055, 0.3510653684216161, 0.3558465538005675, 0.07791127213427136, 0.13872108692603727, 0.10837998316292802, 1.2952782958745956, 22.573709064914336, 59.895416229001945, 95.9884625096475, 80.84524246954149, 59.43180776411488, 79.24730024030133, 47.41299090846893, 22.186131823447443, 28.743420839309696, 49.028811300954516, 68.34164419481831, 63.20667720610096, 81.03423795392438, 30.755694796962125, 0.9777544018241667, 0.23596755258979338, 0.11954863345430744, 0.022554362020004663, 0.06320635615397366, 0.01837364976264296, 0.12401150930072032, 0.14618839107213483, 0.1339701926636119, 0.05012211449924977, 0.07407402965210139, 0.18066478382435538, 0.044792888971466216, 0.047378405072395845, 0.052602994481041554, 0.08571807580489306, 0.05342006172624327, 0.08704920719948508, 0.07556683624223356, 0.13703002444198056, 0.04053475778369654, 0.08461222788619419, 0.06343748488072908, 0.19435711926029575, 0.03383621137829558, 0.1746641396875343, 0.07227792119186732, 0.09932487752408752, 0.06048805020268887, 0.01269791596343801, 0.019108054205595006, 0.03050032747729171, 0.03336822358711112, 0.04296458949665389, 0.010720100066053772, 0.06715882975127428, 0.05121860848439317, 0.038809508626018806, 0.06644984602086967, 0.04453672832178493, 0.07327473947718259, 0.2457026455311045, 22.798119629583052, 119.30880454278763, 100.17189779589253, 118.32869052886964, 109.16065231446298, 86.9281090459516, 109.89916401524698, 63.75525205366073, 46.47892159800376, 76.83317553612494, 143.73442342204433, 110.93670152848767, 93.72309761662638, 119.08775544935658, 131.95311392507247, 47.11303157191123, 0.5600012021680032, 0.043288974106431975, 0.00505182221757188, 0.08280174761650064, 0.1085403406872384, 0.6162965910569315, 0.263754817987642, 0.687705301229031, 2.756404208560144, 1.0779389066080893, 0.26419504275245054, 27.821204931505267, 105.43067439909905, 111.88475408861714, 110.12820689908921, 112.12804302092522, 107.23247005093484, 102.45968295681863, 90.18429602346113, 84.76953460324196, 83.8240864969069, 83.4754034780687, 82.4330492942564, 87.61722241678547, 92.54069912818171, 94.0933144477106, 95.82031834510066, 95.28391853455575, 98.23280349854501, 101.83289604802286, 96.54840438596665, 99.92299987423806, 97.13157453844624, 89.62590740573022, 81.85423297266807, 91.81012630462648, 97.38019789418867, 99.53095113077472, 96.62214494520619, 89.12840966255435, 85.31268089048325, 87.28597041099303, 84.89052403357722, 84.71852810152116, 79.70551152383128, 80.52191365149714, 78.04396413987683, 86.94957225553452, 79.82983496881302, 81.28873702018493, 94.58852152670585, 113.3649467652844, 84.97821254114952, 68.72012938222578, 75.58420658111572, 55.057698219053215, 58.04665411672285, 57.13447163181921, 77.52241442280432, 78.3375535472747, 79.05445298840924, 74.64213171312886, 66.9146623919087, 70.9787791775119, 64.24526199217766, 71.08101967842349, 84.32252560892414, 86.69199805105887, 84.1557699634183, 83.10627706589239, 87.99579389633672, 86.98063742729926, 87.56310155314785, 77.9988411934145, 80.3683214802896, 81.80350888159968, 90.5804475661247, 87.39542807302168, 93.23543717784267, 92.2315614454208, 90.68123679007255, 90.12640183971774, 90.63595694880333, 85.84729994496992, 90.2098306532829, 83.35656350658786, 85.31341829607564, 83.76851435630553, 85.3703946451987, 86.06386969166418, 72.22431213625016, 72.53558358838482, 54.00532630182082, 10.431026701004276, 1.1591692316916682, 0.23603403369986245, 0.36515010941413145, 0.5136894404647813, 0.39569369787650727, 0.05590010667219759, 0.24309788530151694, 0.18710920737395365, 0.09903455318342294, 0.6130321371939875, 23.89568509594087, 65.21519353312831, 103.59611911158409, 90.68588087635656, 62.3273955622027, 45.820869476564475, 27.3267803653594, 26.53752103928597, 54.25174136315623, 78.01798235985541, 91.85484132459088, 72.03130014481084, 97.0025364045174, 48.34446360988002, 1.7054580728853903, 0.059407092480649876, 0.009579067644212515, 0.03972591066192235, 0.04563104278678375, 0.06626026224224799, 0.07039337554165433, 0.015660494795039056, 0.06015665588840362, 0.050220162262238806, 0.06011809485273496, 0.16050802994399302, 0.06398388177096363, 0.06150574055350116, 0.013587737621198739, 0.08124520251106832, 0.05534543603238079, 0.02155059148677655, 0.02882728529643388, 0.14190056631642003, 0.041865406542896264, 0.021605868560953007, 0.032695054467166626, 0.2869363934282334, 0.1551913031406941, 0.2996744131368976, 0.271747658449796, 0.1918275122560801, 0.15989122191263785, 0.15641620112282617, 0.1195093408046711, 0.10137220153645163, 0.20282678816828037, 0.17784654553378784, 0.21677306642936123, 0.25410571075495214, 0.15080854476940247, 0.1647670191502379, 0.2599368809211639, 0.14850306444831435, 0.2649588936999921, 0.36576635054042267, 30.727016387447236, 140.67171127565447, 119.070920636577, 120.58407691217239, 102.42408352513468, 79.71482323062035, 91.03677611197196, 51.92254381795084, 51.43756235799482, 155.2936012514176, 176.08961566801995, 115.18540505440005, 109.71889188212734, 132.43584786691974, 140.91593373206356, 61.74641409227925, 0.9785437175343115, 0.21032118118338047, 0.26379370461067847, 0.28377526950451637, 0.24721925447304405, 1.6893810129934743, 0.24752861609862697, 0.6590659928417976, 8.080824373229857, 4.162323128792548, 0.8370918948804179, 22.230078058858073, 103.92060895119945, 114.05032603971421, 118.06361675262453, 117.59531713301136, 115.3310348141578, 108.03319838739212, 97.37978996769075, 90.20499829323062, 89.58623655380742, 87.02637226350846, 86.0350638051187, 89.50012483904439, 96.29946724061044, 96.00601903853878, 100.0949408931117, 100.1806603708575, 101.97447792176278, 103.26610657476611, 98.79038410802042, 101.92432649673955, 102.21825322797223, 91.85300565535023, 87.78651191342263, 94.57020405800112, 103.57036482903266, 103.51611844954952, 103.92803792030581, 95.93038005213585, 92.40627950237644, 92.81785380455756, 92.55187003843247, 96.00430888514366, 90.399673369623, 84.55325511194046, 86.5331655933011, 92.7028577558456, 90.36814535817793, 92.4250598107615, 106.64365953014743, 120.66068864637806, 100.67196861390146, 69.18861727560721, 76.7136295380131, 60.57792432846562, 66.23992058538622, 66.40081620985463, 85.07091383780204, 87.90726600154754, 89.9209245558708, 82.79334252880466, 75.59402035128686, 77.09610769825598, 71.17827876921623, 77.26053345587947, 90.30781146018737, 92.99284642742526, 90.41261719119164, 88.84293956141319, 94.27088799015169, 91.45819556328559, 87.30001249620992, 80.59541886852634, 87.50568589856549, 86.79441113625803, 94.71195067128828, 91.23487933989495, 99.20270366053428, 94.16986342399352, 91.68633630198818, 94.07642472174861, 93.03632982315557, 88.35052520998063, 93.04801848626907, 85.38366010112148, 85.83864719636979, 87.60552590893161, 90.32263017469838, 88.0437566388038, 73.8617604778659, 83.18936071088238, 66.76496905665245, 10.28504785030119, 2.3449284559296024, 2.1947997375842068, 0.7729881701450195, 1.0517572082819477, 0.8720536349761872, 0.9600996298174705, 0.5840591821939715, 0.4689735318383863, 0.3298256113644569, 2.5190613442851655, 42.03127545695151, 78.53742968651557, 117.5507668525942, 96.35465498893493, 78.72564069686398, 117.74531641314107, 61.52854211868779, 30.199249713651596, 39.916419752182506, 60.21738006222633, 89.87589574629261, 83.83161744763775, 107.79966831207277, 64.23064331854543, 3.5409615933895116, 0.21181151330951722, 0.19768071511099417, 0.13427698023376927, 0.16960491035734454, 0.21523701417590343, 0.183178425556229, 0.27513373643159866, 0.22387842467475325, 0.14903814621990727, 0.14265897803969924, 0.22212091172414444, 0.12290799795019051, 0.17080912396552103, 0.2043723092684823, 0.15189033752727896, 0.1625083314795648, 0.20298896898185054, 0.25252470446209757, 0.3564310175997596, 0.20719011854981223, 0.15571202842458604, 0.19016612801821003], [0.04977123473861045, 0.028854040917189374, 0.09039461357338775, 0.10096466574337214, 0.09154592881039267, 0.11537518562568773, 0.01427330683180762, 0.012146201465399036, 0.038493872740336006, 0.06234898119263592, 0.037438479372330254, 0.07865576403996638, 0.03537970617593777, 0.09995219628176383, 0.07248697126464498, 0.08317398207802927, 0.06894399081507037, 0.3010042498428976, 3.204890220395981, 88.98053630705803, 95.58765903595956, 89.16816680662095, 74.81936793173514, 57.64430915155719, 52.158078224428245, 27.066937069739065, 54.937340290315696, 89.16564080022997, 128.10594343370008, 83.18243380515807, 73.47542270537346, 113.51219254155313, 120.16009223076605, 49.56205752588088, 0.3028528812912203, 0.13979043841602343, 0.18119848663768462, 0.018532634074349078, 0.07511055427453212, 0.7932013693836428, 0.558246860821401, 0.1920365470070993, 2.3230276569243404, 1.6925385209821886, 0.08169013105573193, 22.237104985021777, 112.98310402900943, 108.30801533114527, 107.43080862106817, 104.60803570285921, 109.9866799385317, 98.67621175704464, 93.85223773217972, 84.53790295508601, 78.01918260512814, 77.34029093096333, 81.52047064996536, 88.90665454249229, 95.2687781856906, 100.59850262057398, 95.66582402875348, 91.10129125656621, 97.01220112462198, 94.66918114692935, 98.66433482016288, 91.18176260302144, 93.20965151632987, 91.42381206635507, 80.9006969390377, 77.62911073623165, 81.09889430384483, 86.57009863084363, 87.79173651049214, 88.39363205817439, 76.6301771902269, 73.45619524678877, 72.2953462600708, 73.9522260235202, 73.71769966617708, 65.67003550068026, 73.0296531800301, 77.3033029802384, 76.22416480895012, 69.61309617565524, 74.01625479421308, 80.53778356121433, 103.26023086424797, 95.06643095324117, 49.17009115219117, 45.905518147253225, 33.129860355008034, 39.11222796286307, 60.01908071579472, 71.4467885417323, 74.73040073148667, 79.69418371877363, 72.95120577658378, 67.2495622019614, 61.00576469975134, 63.87112279092113, 70.01136579821187, 80.55143340941399, 80.03519458155479, 77.36271904360864, 74.02372298702117, 74.66130425853115, 75.82889972194549, 84.62454026745212, 84.72668663147958, 76.41784360331874, 77.32678228808989, 78.75364641989432, 79.9954217480075, 84.24362321053782, 88.62156098888767, 87.59163287378128, 79.32606143336143, 86.31557603036204, 86.85705923265027, 84.89652525994086, 85.3398629157774, 81.64288782304334, 76.37286186218262, 74.29197388310587, 75.8050517112978, 77.53425213598436, 72.81945336249568, 60.9349698405112, 51.074911778973, 11.444318083024795, 0.7116510034088166, 0.9238751316743513, 0.2260947476832136, 0.01763862287325244, 0.45326615533521103, 0.0825986960121701, 0.37354431866157445, 0.07641163203985461, 0.21411097217952052, 6.044339585688807, 19.585096374634777, 46.370405304816465, 91.16028370395784, 92.8803606956236, 70.48346227215183, 70.52281933446085, 73.50711545636578, 27.133717383107832, 31.31484827687664, 30.368274450302128, 75.7401051059846, 66.81202965397989, 84.64546218995126, 45.70652846367129, 1.482626997655438, 0.057483173741568486, 0.017270207360026338, 0.06332904513504717, 0.05997185632886906, 0.007774201362589075, 0.03282958716754952, 0.15493431128561497, 0.02709866918232893, 0.031817590765234445, 0.012356818187981846, 0.058981120781672586, 0.06566901856492605, 0.03527443803426239, 0.04514173476866657, 0.07909549084762413, 0.00946859201987184, 0.1238611339020633, 0.0665356861727853, 0.02790544595148775, 0.04202806999185874, 0.06458890353960377, 0.0616181256519931, 0.05095554538251412, 0.02148944043344067, 0.062366160714337905, 0.039624779395038084, 0.07689172402024269, 0.07039767329490955, 0.03159791505294702, 0.05259332262099751, 0.004138664085222709, 0.025498052953832576, 0.1805794722731075, 0.016330929938703775, 0.04025708538510146, 0.047985736596127676, 0.027612133867918488, 0.10591276635926579, 0.2750318467376694, 3.961839757619366, 109.80482316786244, 107.26322927782613, 110.49179492458221, 98.8417906914988, 85.1452035288657, 69.82081705524077, 28.019039477071455, 50.549070988931966, 38.51524322263656, 98.78931722333355, 95.80694306281306, 83.49459171295166, 120.18463057856407, 127.13096772470783, 52.984768729056086, 0.4195210241502331, 0.09667111831086297, 0.2900111026340916, 0.06986012472020042, 0.26093359195416976, 1.237244867990094, 1.5657216743115456, 0.5766789362795892, 3.778585642576218, 0.8166271736544948, 0.15204916287574077, 36.41367258564119, 122.19512770252844, 106.73101071388491, 106.53598262417702, 105.6501937681629, 110.01627029911165, 103.36536607434674, 95.57332669534992, 89.13459916268626, 82.2266306415681, 80.6640132780998, 86.26964507564422, 95.52846262531897, 100.98254972888579, 103.11773900062808, 100.06167134931012, 97.26994791338521, 100.47127662166473, 99.09064154471122, 98.54139989422214, 95.91134871205976, 96.75244608233052, 92.13443571521391, 83.02418185818581, 79.73387810491747, 86.63351551178964, 93.69236192395611, 93.93988701605028, 91.41336287221601, 84.35310440678751, 79.70398964420443, 79.64087086339151, 81.47133904118692, 82.50525228438839, 71.25387068717711, 75.44406029485887, 82.56037727479013, 81.02840146710797, 76.33312825233706, 83.93122211579355, 87.12268214071952, 104.70471428286646, 102.32600858134609, 64.11932253068494, 54.44707932010774, 44.04614602365802, 50.211868747588134, 65.43676822416245, 75.81442617600965, 84.42077313700031, 83.24429742751583, 79.32889338462584, 75.34141186744937, 73.30497218716529, 72.97199433849704, 74.54017362286969, 86.36280136723673, 83.22356377878498, 81.36056346278038, 79.99186808063139, 79.62245141306232, 79.09234308427381, 86.69271976717057, 88.96751403808595, 83.36833846184516, 80.90134020774596, 81.67057191171955, 85.6881929213001, 86.00808574307351, 91.34251702216365, 91.5692457076042, 82.97965511198967, 89.12907646548364, 91.76649385882963, 87.87445145268595, 91.26981196864959, 90.18763788284795, 82.32563126471736, 83.35859529433712, 83.49157933265933, 90.74867802281534, 85.20006964283606, 75.25219363550987, 74.89125713225334, 19.700490543919226, 1.1922757519829659, 0.368621529590699, 0.5275052233088402, 0.3443387487242299, 0.6423978195075066, 0.01199867495621044, 0.18963951917905963, 0.05696734375951271, 0.09804968586972646, 5.181873633015541, 23.837281004075084, 53.80605028521631, 101.98228343840569, 102.00213063147761, 78.70849993921097, 38.32340009750859, 20.134908729983916, 21.495629933572587, 48.76845221365652, 47.07727916779057, 94.8353562816497, 75.04754789413946, 94.4957810063516, 62.950464064075106, 1.2135057031146943, 0.10374487542937841, 0.04374842384770032, 0.07000412626732742, 0.13039628524453412, 0.04148772519622599, 0.13923963652022425, 0.129584553801725, 0.049695533760372675, 0.08789450861513616, 0.04593816743562779, 0.03987398779680652, 0.09538130969890664, 0.024284493072979876, 0.0318107821588074, 0.04353655457136132, 0.05435376968835631, 0.0549790085173182, 0.1032445204233931, 0.029596031545811606, 0.009651338463769326, 0.013146633770497096, 0.11432723863230598, 0.12389293421180018, 0.1611198277603234, 0.21800773969340712, 0.26142263184151343, 0.2635615799696215, 0.17937110646838145, 0.22982387983750915, 0.1717087256932451, 0.1610601341892635, 0.15185319758470983, 0.23617753728983865, 0.16027771327043736, 0.14674660869904105, 0.1365090386881944, 0.22678572834739763, 0.23614689377286743, 0.5461106797860515, 8.286591422173286, 131.98166877992693, 122.62741996395974, 121.49754985686272, 100.80310913824268, 75.53849527912756, 65.18975304019067, 40.729193687438965, 73.74591719719672, 118.36566279011389, 147.81404925930886, 98.72112289551767, 95.60621184687461, 133.99265227779267, 135.08785647730676, 70.44410520984282, 0.610717877505287, 0.20613068023756628, 0.3313386350149109, 0.16075780525082545, 0.9923618599291771, 2.0082738755210756, 2.2083397594190415, 0.5823216334946695, 16.856803547951483, 9.113256431395008, 0.24017902902297436, 33.00804722693659, 127.36505477659165, 117.26547718048097, 113.97171389672064, 114.34173460929625, 117.13665085454141, 108.96133315178656, 98.68906144172915, 96.30530372742685, 85.91494514096169, 84.38308700438469, 87.54555286899691, 98.56926441192628, 105.67743070663946, 111.51110910600232, 103.69125227774344, 98.8957860392909, 102.6610888204267, 104.51187487571471, 105.0713146886518, 98.46551772086852, 100.84999715128254, 99.82658017066218, 87.9435714598625, 85.42948122947448, 89.74703019665134, 98.09713655902495, 97.08278809824299, 100.17841677511893, 92.39097441396406, 90.88790647445187, 88.0010106486659, 90.18568454250213, 89.7044175670993, 80.45833203100389, 86.6391872590588, 88.22070260201731, 88.2494535753804, 83.5958908450219, 90.34849428361463, 98.25996198961812, 119.2546130764869, 116.808881913462, 64.72900006078905, 57.79505760438981, 49.69674779522804, 55.72724680746756, 78.36211542929374, 85.73781090397989, 92.24015928083851, 90.71942498607021, 82.26630933823125, 79.54818525621968, 74.39423791823849, 76.82078869112077, 82.92090585154872, 92.0896500925864, 89.87118890208583, 86.98703873542048, 84.77045243786228, 82.1615977441111, 83.71301281836726, 93.73771236788843, 91.02623278094877, 83.1970799353815, 86.33352479627057, 87.76152641542497, 90.47839533898139, 92.65288675985029, 94.13348736301546, 93.57154507790843, 85.70789890904581, 90.67086604333694, 91.61029723382767, 90.39182862927838, 96.85574562318864, 94.07507542640933, 85.94029934175553, 85.67349187789425, 90.65171703215569, 92.32431765525573, 87.41809152787732, 82.26417556885751, 90.45801470356604, 20.90609181311823, 1.6172082986562484, 2.5721834744176557, 1.1613153810462644, 0.37311083547049956, 1.4191673383597405, 0.21564702443297834, 0.5657509678313809, 0.23113304749131205, 0.5805245137983753, 9.915674328804016, 40.4385813590019, 71.4740333249492, 110.66336724065967, 111.0618486712056, 91.38903633240731, 103.6184452426049, 93.2959044364191, 34.56025854233773, 38.838426912984545, 39.96835977800431, 97.34143703214585, 85.98955646637948, 107.34170806023383, 85.17365640209567, 3.603923724543664, 0.19892464271716534, 0.12196713472686468, 0.17989357843274073, 0.22156062565984266, 0.12467517126952449, 0.18069939567677437, 0.2681450533770746, 0.11450500167425602, 0.21356409265389367, 0.1796895079314709, 0.21490094672528007, 0.18864378873859683, 0.1862146924700468, 0.1880387631395171, 0.11448777235683896, 0.18102004943836122, 0.4004664869318086, 0.2132285614648173, 0.10303269711232955, 0.08934037699814766, 0.14560051052080047], [0.05603180867770026, 0.03557713086446447, 0.019227496889089386, 0.07267020417437439, 0.06707387826135082, 0.012279708565573299, 0.06370375023013161, 0.0049532750610172035, 0.016615943374833273, 0.02649707948758958, 0.05995090765457961, 0.025631243085128166, 0.06063561405866377, 0.04870875122686548, 0.07043527289023323, 0.07834801885990367, 0.12559829955740323, 0.3119519833595522, 37.00519346421765, 104.40794775562902, 96.66229432629001, 76.68630630739274, 71.32408895800191, 69.2402748907766, 67.38921426957654, 186.62494505605392, 129.27535887687438, 87.55781419815557, 80.0824591421312, 87.40391608207457, 121.81239851059453, 123.99262443665536, 56.690294588765795, 0.27251190776305817, 0.02069467400771476, 0.10482079229287564, 0.028681906706262982, 0.06945498678232394, 0.49327105223651857, 0.14807685909252014, 0.3405364704949241, 1.9164521703797004, 6.483571010251199, 0.9790175275937204, 12.670645156214315, 109.1142192963631, 98.2179141813709, 96.60947568954961, 98.2981344961351, 101.06543725536716, 94.5817279815674, 92.18709745714742, 85.98286490286551, 78.88070767925632, 79.92217540740967, 83.13382779398273, 90.45526904444542, 97.48418777219712, 100.58573138329291, 100.7059363395937, 97.8413901790496, 95.07974347760602, 95.8392555482926, 95.80931217439714, 85.06803481809555, 86.6820901440036, 86.16234471721035, 76.2350062401064, 72.34321486565375, 78.4521730484501, 82.99163403049593, 87.99922989260766, 89.72316649652298, 82.16785784690612, 72.828702311362, 71.05641072796237, 73.94333793270972, 69.65123730321085, 73.17976228652462, 64.613478414474, 63.07839608961537, 71.46239957501813, 71.03430424967121, 68.16124654585316, 76.09162792082756, 96.80939105249222, 88.59422991352697, 95.9924711719636, 62.97584964383034, 35.30096284804806, 35.36726267107072, 56.88225538499894, 61.250555899835405, 68.70048615240282, 80.36130043768114, 77.51382443212694, 79.024901851531, 76.0790684915358, 68.62666714575984, 66.77238233627813, 66.44581364047143, 78.45014126070085, 79.42403439552554, 76.63746495400706, 74.50565676535331, 73.76021031410464, 72.57231266267839, 75.41894143627536, 79.47045956888508, 75.94165217491889, 70.73262691497803, 69.43703666810067, 71.84601522261097, 81.50679726754466, 79.16742509411228, 83.4238007760817, 84.19806880335655, 88.50010871887208, 87.71950214139878, 87.19912913537796, 85.32610324121292, 83.44582880696943, 81.05889397282755, 80.4537271684216, 73.4169166318832, 76.20888325475877, 76.52777979450842, 77.41795386037519, 62.54337303100094, 53.438104506461855, 11.358412292695816, 0.6127684190869331, 0.16481863815457592, 0.17579813367657124, 0.2154186842662673, 0.06607926630925748, 0.1951836055565265, 0.10022803389978024, 0.15475429594516754, 1.6340058489191918, 10.987000119301582, 16.924209479362734, 48.652106869605284, 84.7219091846097, 90.28382224421348, 79.78452374858242, 89.05209602848177, 100.79488785036149, 43.48792214547434, 30.871110539282526, 34.93375839725618, 56.70301875760479, 62.76196279833394, 74.89778395622008, 33.31907156975039, 1.6787294490683464, 0.11047464374813343, 0.0649339878450959, 0.13359749088844947, 0.10921778457780039, 0.014411864366622703, 0.044212339881567225, 0.11846119462842904, 0.06947050772366986, 0.10785473796028285, 0.034056676161145015, 0.07093568918325248, 0.02337650651292455, 0.05793227746541943, 0.1154566131111595, 0.053256567071882956, 0.03240188410986335, 0.1064530345461061, 0.0478944648808289, 0.0887058876575001, 0.019168778164913098, 0.05459248651600173, 0.07662280417618252, 0.035744413823610356, 0.10300018434082309, 0.024790791006037788, 0.022421650693661744, 0.0965328471014096, 0.048440494048859806, 0.04216159911706083, 0.012634851605511241, 0.0431783203666489, 0.08469076722019142, 0.023513561557798136, 0.06407940527424216, 0.016204839527246453, 0.03959651458107176, 0.04467192751866195, 0.25981875016323985, 51.216787830475845, 117.41717092452512, 116.32878380437052, 102.047300646382, 89.85265178065147, 72.47388470557429, 59.9127217262022, 121.11577772325086, 70.48310925883632, 65.92577795828542, 80.93369191692722, 93.13376934297624, 120.99601991714971, 130.93552558652817, 63.90909525655932, 0.1318140688442415, 0.07309589625125931, 0.10826056537729119, 0.22428949213316365, 0.1859841919353893, 0.5071062324268203, 1.3843386524146604, 1.4148893808164906, 3.0825620360912818, 8.304598043041846, 0.3863326243815884, 21.992294173086844, 123.23883902642035, 98.91043216951432, 103.75386115043395, 103.95051310139318, 104.55549163203086, 97.55760669708253, 95.30273022190218, 87.90223752298664, 82.47138654032062, 83.18232397879325, 90.51095885615196, 95.83365440368654, 103.12559158571305, 104.24391423502277, 104.81134783837103, 102.81327678311257, 100.04719780337427, 97.54853817724414, 98.20791998217183, 89.26832060660087, 89.2507326987482, 89.95898723602296, 80.1016159980528, 73.405439776759, 81.87782210688438, 85.46237422573952, 93.82380054843043, 96.13996013518303, 85.51807972692674, 83.56586117898264, 80.10228280098208, 83.03108522968908, 79.32595945173695, 79.17260262273973, 72.98264749588506, 69.75594105259066, 76.98996836139311, 76.06444589553341, 75.08928191277289, 78.81718097194549, 99.35223225624331, 91.48241227672946, 102.44517018718105, 73.51489743878766, 46.35552775475287, 44.55577565777687, 67.3206590837048, 70.80522214212726, 75.24458423737558, 85.08648564738613, 80.91617461173766, 82.39543376430389, 78.28351113104051, 75.4827662437193, 74.68220264680924, 70.4129223669729, 81.63174044701361, 85.88600589383034, 81.96454571139428, 78.1070593864687, 78.81741631415584, 78.46494428573116, 79.37079998754686, 82.01483049700337, 80.11242605024769, 79.02399970639136, 77.57600968883884, 78.40957610837876, 85.21880288277903, 83.36489462083387, 87.99111058635097, 87.79738472354028, 90.28728177470546, 89.00207011930405, 91.2220218104701, 89.39158501163607, 87.33934602429791, 87.08658849039386, 85.78320841635428, 79.70689219813194, 83.21167115242251, 88.05119345265051, 89.16789224070888, 75.06453960172593, 75.37369297396752, 18.596951307788974, 0.7885070277317878, 0.5086710129774387, 1.6274563487498992, 1.1095648547334056, 0.32392216846346855, 0.13360231724237243, 0.12331705059736006, 0.07850685953012398, 1.095681870656629, 12.615067132057684, 18.413962933325, 55.08267587231052, 91.78611355443155, 95.3525443230906, 87.3240723148469, 70.79907186569707, 37.23623283447758, 30.174130855068086, 53.81995116510699, 59.72276918349728, 82.91709330774124, 74.35932097896453, 86.79059859245055, 45.76609357710808, 1.2424784129665745, 0.08253734769119371, 0.11167660505781252, 0.13079452839109207, 0.022674758482964772, 0.029879403638563333, 0.03476412771570106, 0.08287403567303574, 0.04269947710957739, 0.08389629573831636, 0.02054432159169547, 0.04834595113812436, 0.023576493765557968, 0.030244275995139635, 0.020529057289804184, 0.03851191028051319, 0.06367732402718355, 0.06871339834986195, 0.02390057385538615, 0.10255941565358832, 0.00722913028326847, 0.18204473800236182, 0.1672172594454981, 0.17070657543597684, 0.24765652213846487, 0.1347371079628506, 0.10536640777342743, 0.19998789614727422, 0.16268739687098613, 0.16028325974700913, 0.1308939206383882, 0.13970204719131993, 0.1364835739255913, 0.1515177430044259, 0.17826913495457944, 0.15812085400665962, 0.10617900489559097, 0.19644253316425508, 0.31935147340259246, 70.85944498738935, 132.06976521399716, 124.49685296704693, 104.85869869109123, 94.18709047379033, 87.19364566187706, 84.86625240695092, 204.2699469289472, 152.19420709917623, 115.2229578264298, 102.06757930017288, 110.44871945534985, 141.30385614210562, 140.55302035424018, 79.84550876002159, 0.44559188487548984, 0.12069395022286523, 0.23508897231471157, 0.5413073697878469, 0.49291145056486135, 2.024576961994171, 0.7662304779214244, 1.1186338648680718, 6.158420251261804, 13.529904080975442, 1.589462432649828, 20.54250574881031, 129.93900822054957, 105.35512954958024, 108.1215536978937, 111.09620078917473, 112.32424782168482, 103.95263118128624, 102.16170049482777, 95.30484045705488, 88.13961152107485, 88.77093268978982, 93.35781512721893, 97.92345400779479, 107.56428687803208, 106.75864773411905, 109.12624528331142, 105.45170614796301, 101.37008774665095, 103.08453221474926, 105.10689843085505, 93.13055299943494, 95.49831528817454, 94.34524828387846, 85.21094245295372, 77.99148282697125, 86.39180337229084, 92.03377985185193, 97.81808345548569, 99.73657746468821, 93.20198720501315, 87.83514930355935, 85.55677783104682, 87.28793944081953, 84.8210745473062, 84.21744531200778, 79.33742061738046, 76.95876198430216, 83.97245407104492, 84.41451303420529, 85.21854400634767, 87.46219465809484, 107.88032793229627, 102.70157552534535, 117.87388386264925, 74.06324478887743, 47.79327254141531, 48.89258346249981, 69.57404505821967, 78.41413390251898, 80.32378688935312, 93.1416376175419, 86.78689587500789, 88.8459127180038, 84.86188288657897, 82.97067288429507, 77.8512659380513, 80.30119403716057, 86.82397011787661, 89.01130337868968, 86.7869507881903, 82.6796643964706, 83.5963301504812, 81.55544250242173, 84.75477080191337, 88.31154469520816, 85.3462250001969, 82.14419811002671, 85.27895635174167, 87.12575727893461, 93.3774269780805, 88.57045250554239, 91.87744202152376, 88.98297602130522, 95.01267879239975, 91.5272371230587, 92.72661947434949, 91.68676776270713, 89.08430653233683, 90.27295727883616, 94.01033278434508, 83.3296246682444, 87.80448421355217, 89.94442739794331, 92.00834720365464, 77.11247182661488, 90.68643785292103, 19.871119529970233, 1.8625350248429084, 1.4126581650587822, 1.0218426392924402, 0.42439135152005386, 0.6689494463705248, 0.39756571032827903, 0.31617481321577107, 0.23449200596059525, 2.8162522229456135, 22.632158264037102, 38.009830136452955, 71.01405697484171, 98.90654902304374, 103.72162711235785, 98.61590923801546, 129.87514418940393, 134.9125422200849, 55.80672971663937, 42.7548703839702, 48.336120728523504, 80.59039038996544, 83.05408600837954, 98.69250528274044, 71.27431408051523, 3.389756919876222, 0.2564038366319672, 0.2682374435807428, 0.2676640420911774, 0.28010206176869334, 0.1270101766192144, 0.1897059696456117, 0.17712680592892632, 0.2732716524793256, 0.17627044220364865, 0.08829299690982989, 0.18063415562914265, 0.058597015787757216, 0.14665089367378145, 0.10116788588704602, 0.12197155505418779, 0.09361327070021823, 0.22916473778745822, 0.13071997271430108, 0.21779447613704592, 0.10054721677255246], [0.05576157882328957, 0.029886262040705453, 0.08395000616268766, 0.06537533875915312, 0.09324678189812169, 0.03907479721331789, 0.015089539041171874, 0.0756984041823495, 0.08186115252394831, 0.03156305230673283, 0.06429813486794311, 0.015470586386659454, 0.10505195166314803, 0.0066517901441623135, 0.07207480830050285, 0.01953645248807246, 0.43817839074519377, 3.877014825420995, 81.31722911711663, 87.77809450703283, 63.42855784200854, 77.02032750652683, 40.7771211285745, 44.043423898758434, 40.96934472360919, 113.47693827844436, 146.43869369260727, 64.27618203624603, 105.29649796024447, 120.02284065369638, 125.90542316436769, 53.99449271540488, 0.42253714295164235, 0.098901407102183, 0.11464571670418787, 0.04143074357641801, 0.14162630683952762, 0.4067662424377857, 0.18530399778917914, 0.6060293581216567, 1.437079577196029, 2.3946847021579742, 1.8838268758789187, 2.210869197883914, 85.74166267148911, 101.64794844965782, 102.39627392061296, 97.47603708697905, 88.67030820538922, 83.97993010859336, 83.73745702928113, 78.93539336419876, 78.12591029751685, 79.51085213691958, 83.60358653529998, 91.205516476785, 95.08101432554184, 97.58880522943313, 96.92643457843413, 100.51949039582284, 94.73187631176364, 89.57395169042772, 88.21244993517476, 82.35571584393902, 84.60078639368858, 77.29447764735069, 74.76498819166615, 70.73625118501725, 71.6075429608745, 74.56664177679247, 82.33994791584631, 85.603650154606, 89.3538361210977, 83.33821465892177, 80.48820480223625, 85.79856057320872, 85.80180045097106, 84.8971999076105, 77.2034865040933, 78.09306436969389, 74.44147109985352, 71.14229494525541, 69.89469881980651, 62.97395513903711, 63.17805567095357, 77.27169652138987, 75.25722995881112, 66.40856681331512, 63.76409699839931, 68.96555992864793, 52.19713326423399, 69.09658278188398, 68.48361830557546, 79.66095339867377, 84.1632773799281, 79.92848257864676, 79.70296982795962, 72.03889385346444, 66.09021156064927, 59.13944998095113, 58.17762990151682, 66.16309704319124, 76.19575115942186, 77.4023820507911, 75.11758573593633, 71.26436694975823, 73.17142332753828, 73.01223001172467, 74.50540573366227, 74.57232136880198, 72.00903677171277, 65.29412338810583, 59.25625424231253, 66.14680351749544, 76.02491624893682, 74.78005009312784, 77.38534327476256, 84.16851766647832, 82.2454737078759, 85.07849185697495, 86.16152101947416, 85.74212551116945, 81.58820213810091, 75.86336166627946, 73.29932397411716, 75.27820679449266, 75.10766213940036, 75.4747881427888, 71.26099371141004, 64.4897315579076, 44.15587432922856, 4.4952387098343145, 0.949119689964479, 0.4504464001905534, 0.4725340940058232, 0.12549071783019652, 0.29643876417990656, 0.19697611340351645, 0.031073380396851612, 0.15179589420797365, 2.854747344409266, 2.506132231604669, 18.75207124217864, 43.87750371809929, 78.47498555337229, 91.49708978591427, 69.62884841426727, 72.22024856075164, 83.1076498954527, 26.78233773477616, 23.027199775941913, 25.802111933308264, 54.89481003053727, 70.51964221462127, 67.71644976831251, 29.5434235372851, 2.4191073400359002, 0.08036234746536902, 0.11479407729160403, 0.02368382268374966, 0.09753410869668569, 0.06134672751349788, 0.01935009010917237, 0.0034784873376690574, 0.04665218436369493, 0.10881905879585013, 0.026257297797729413, 0.06829406480274855, 0.029200038782531218, 0.008049144094148952, 0.09806430282732172, 0.036621316366138, 0.030942691542628794, 0.009319157951751785, 0.03418761973960265, 0.03930943079232689, 0.012702838078351512, 0.025825356358602166, 0.07226021689993721, 0.013079926664490375, 0.08776415875481983, 0.06209452508858616, 0.009278728619157788, 0.04491451309032498, 0.10701906626983997, 0.05411810572108915, 0.09018287453199587, 0.07489260226007431, 0.11637548195017923, 0.020012254376084577, 0.04882150021712146, 0.05831850835332467, 0.46627285740067886, 5.587097617887682, 98.36654847668063, 99.63041459360431, 84.31846987816596, 83.56880295661189, 62.807623109509876, 63.08995531451318, 47.97837703458725, 118.99113962727209, 120.57492210019021, 64.2079367176179, 113.37882411095404, 126.52417705905054, 134.77566719055176, 63.038109425575506, 0.3300822508190909, 0.06629884243011475, 0.17818678050271927, 0.11825686365726495, 0.2850616230599342, 0.7300913526165871, 0.5100587659305142, 1.025194427178752, 2.4542860975188594, 1.7859378769513101, 0.9117428117221402, 3.7759797178929855, 98.79527138125513, 104.6019874080535, 106.3684581941174, 97.49846519962435, 90.82558001241377, 84.95823983223208, 86.35035176430979, 81.84222267520043, 82.25781348443802, 85.43612572454637, 89.74878741848855, 96.58870281711702, 98.96985607762491, 102.3705510170229, 101.63637745764949, 102.44323253631593, 97.70819433273809, 94.59169080180507, 90.06566001522927, 84.62615628396311, 88.89995513423797, 80.93571585993614, 75.93902418690344, 74.00271477237825, 74.68054740659653, 78.59889322711577, 86.70782873707434, 92.89928220933484, 92.53648650261664, 86.88854802039363, 88.05362532215734, 90.5805181687878, 89.97786952603249, 88.02940076397311, 83.42409103147446, 84.00988132722917, 80.08600496476697, 78.42680315817557, 76.92336651586717, 68.87147011295443, 74.90716626567226, 82.031461346534, 87.44834084664622, 74.78491383214151, 68.3990284704393, 73.29195776293355, 57.222928923945275, 72.5936346669351, 72.85713949511128, 83.26589399768461, 86.15402929244503, 83.082640863234, 83.83594774430799, 78.18001547167378, 71.4880204969837, 67.84667245803341, 64.1419546065792, 73.3284044265747, 77.29785873043922, 81.10243228174026, 79.8141376433834, 76.77138251643028, 77.73757996097689, 76.6411990504111, 79.45080849432176, 79.67121431904455, 77.95196886985534, 74.93442673836985, 70.24997926527455, 69.50047708326771, 80.98907578376033, 78.13370012467908, 79.76999528946416, 86.63776736105643, 86.8362000680739, 89.46815752214002, 86.99911963555121, 88.58301193483415, 87.4377896708827, 83.96431907530754, 79.05187206883585, 80.21513723557996, 84.96654741225704, 84.19668028431555, 85.00998373954528, 76.52328475829094, 64.09651002576275, 6.355908647660287, 0.8219225572482233, 0.6877647496519551, 0.2636794655794098, 0.4390923949258943, 0.5393419558963468, 0.12020828878326763, 0.019426480566541997, 0.5085845676160629, 1.0166047429365497, 2.3764407778939893, 18.99677026656366, 48.95350963838639, 86.88201335168655, 95.20261564562398, 78.28731583010766, 69.35640842683854, 36.2116156085845, 24.122398091900735, 41.168283416378884, 42.02481923564788, 71.38098685972153, 77.59978709682342, 82.36600814327117, 41.42935245267807, 1.2760706942889, 0.10319193614827049, 0.15834419928010435, 0.006547663952299064, 0.03984109198133792, 0.08806006021557317, 0.12442014059953152, 0.06029362091794611, 0.009889645434375252, 0.09425810988872282, 0.03318427055473289, 0.04237053044621022, 0.017096847408421097, 0.05914342799975027, 0.058041586720895384, 0.03347274479306033, 0.041018703186343757, 0.05231326768895792, 0.015375327183714798, 0.027171865053054307, 0.12484466822277154, 0.07848591468627415, 0.181318394719593, 0.25730644142435444, 0.2097855171849651, 0.17870808801343366, 0.15397314673229573, 0.2801414080444844, 0.1443715982379452, 0.17878584593774813, 0.23438574956549754, 0.19293453995018237, 0.2705617543430098, 0.15723597648884022, 0.3027344747416435, 0.2239130518489307, 0.7448383612978844, 9.59478130263667, 123.21645013747678, 110.70525030935966, 88.92366193955945, 99.9504093970022, 60.90919202373874, 58.18132869658932, 52.17992974865822, 122.51606387476768, 169.27598799428634, 85.56826253091135, 128.36645941580497, 137.6193541865195, 146.2654504468364, 75.50036984105265, 1.6922958243277766, 0.28390210302126023, 0.22953596867380605, 0.3372075120287557, 0.9220055094169033, 2.9245089042571286, 0.8688911627377234, 2.694952189922333, 5.394059150449691, 11.199945595956619, 5.117621777519103, 4.180001741455448, 100.50944128344136, 108.39092639184769, 112.67896344584804, 103.41878091135334, 97.82900333404542, 92.78719655929073, 91.51339115635042, 86.04035116011097, 87.14220769943731, 88.26890068669474, 95.56132424262263, 101.12972490249142, 104.09857473065777, 104.34892392927601, 106.40547752380373, 108.5879078219014, 103.34413820697416, 98.03554750257923, 95.47809939230643, 90.3254307470014, 93.90625661419284, 85.4232446609005, 82.83331148086056, 79.60003114515736, 78.95633097617858, 84.47145015962663, 92.37782662914645, 97.37221194851784, 98.55988994721444, 92.82748714570077, 93.3061339778285, 97.7733527460406, 98.18048692518666, 93.34458889499788, 87.60034053556382, 91.86420009982203, 88.54123084775864, 84.78455728100192, 84.89292452412268, 79.34456717583441, 83.67903724793466, 90.70493575065368, 92.32857734926286, 82.49537575629451, 78.9136242097424, 75.20009671488117, 61.31812657079389, 74.0325326304282, 76.20015990349555, 86.2797647906888, 90.38699626922609, 87.46631314677578, 88.94170484235211, 81.93406105041504, 76.51467907813289, 72.93637137259208, 69.63566549362676, 78.5636075850456, 85.69274287069999, 88.79758911748087, 86.31623498855099, 80.11432447741109, 81.98179629541214, 80.60941388530117, 83.72292072542253, 84.23125205501434, 81.6454138294343, 78.24456199522942, 75.98757528489637, 78.28919856779038, 85.68439606697329, 81.75537355484502, 83.34682818382018, 91.67325911983367, 88.7065116820797, 93.64658001930484, 92.00821384306877, 89.79596568692116, 89.92585889754757, 85.50237455675679, 83.56218984050136, 85.51584397592853, 86.50719950276037, 86.41240366043584, 86.48694438319053, 79.57379833344491, 77.36772398794852, 6.870767291515105, 2.4817951504261266, 3.5791083593522353, 0.37353926248127417, 0.9235973788365242, 0.9860700104505786, 0.44402679788970184, 0.12650385378829895, 1.061774941702043, 6.191958477420192, 9.909396575343225, 37.905071473890736, 69.82615147867511, 95.88716337757727, 104.76471870176255, 84.58447717851209, 102.49528238850256, 115.57077792383011, 34.309383746116396, 31.803173557404552, 37.74432489948888, 76.81672511562225, 92.14082133385443, 92.1070497266708, 65.35396698982485, 4.134164923621762, 0.1747391243735629, 0.24852416267798794, 0.15847418907909624, 0.18135547337512817, 0.18625235335240442, 0.16587121231902033, 0.07458532439364542, 0.13640059128163323, 0.21567452698946002, 0.07778006425547986, 0.15010193591156315, 0.06189333507791162, 0.21063336201252478, 0.17539271994704203, 0.1621023661667301, 0.15286975029495456, 0.16585619699570442, 0.1628910843282938, 0.08976967734915596], [0.045847152359783656, 0.083077110260004, 0.04247425492071817, 0.023434941784568855, 0.05387960339806253, 0.05213008840538321, 0.058257910798514084, 0.022994596360912247, 0.04515821715035746, 0.01009002626467977, 0.07624542926468196, 0.07211533435169729, 0.0930752394901168, 0.08961881931510665, 0.051573284210697304, 0.15778428093800623, 0.2970031871189994, 28.945768071759133, 107.70152276562108, 85.0651793326101, 90.5304059674663, 75.58732094303255, 93.62476379640641, 38.33811290802495, 32.69444980928975, 31.260541100655836, 55.08938312530518, 105.77270507812501, 114.86767738096177, 107.41563689324164, 54.243018011893, 2.0985923322939106, 0.06316792918369174, 0.06333857909926484, 0.13265152551954792, 0.1556838363889725, 0.2139554410091331, 0.22348468612519004, 0.3708630722136267, 1.8853003387489629, 2.926891253840539, 0.7421838972837694, 0.6157253346135539, 36.4688995576674, 103.13095738810878, 104.80052209669545, 92.99538027855658, 82.7651563767464, 79.22509178038567, 79.47284436994984, 81.02766406151557, 81.04071770944904, 83.79908530942856, 88.05306050085252, 91.65251762636247, 94.80827623798002, 95.99755456370693, 101.6094699982674, 92.8031998295938, 95.14528628318541, 88.82081739364132, 84.91434851000386, 77.94319845015004, 78.05508013694518, 70.77953846223893, 71.78277877069289, 70.21790212200534, 72.92512985967821, 71.99128412431287, 80.71335669486754, 83.78122283566384, 89.50561615728563, 89.02125835418703, 78.20951954010995, 77.79717645337506, 82.36160724393784, 83.29955577850342, 84.54122912499213, 79.8303762558968, 76.81262231642201, 67.25390034337198, 72.88942060162945, 66.5111760170229, 64.98171837099137, 69.9972923340336, 66.83976081109816, 75.7315621837493, 72.37077343848445, 44.21097578540925, 75.50660640962663, 80.2951535870952, 67.9668931038149, 68.77415610897926, 76.26887982891452, 84.97595325593026, 78.74517410032212, 80.55054695375505, 73.23806439676594, 68.36783778282904, 46.149732758921964, 49.77510890653057, 68.02068448835804, 65.231871451101, 72.46366300890523, 73.65646362304688, 77.6824079021331, 76.0956601173647, 74.4191449688327, 71.85302842047908, 76.66735341472011, 72.10330701643421, 67.42231907383089, 59.17379425417993, 56.81445721657046, 67.20174066482052, 68.67530453589656, 72.51015878492787, 75.35684247170725, 79.05453143581268, 83.2991635414862, 83.90691126546552, 83.7451840985206, 84.31809333062942, 78.92584631519934, 74.23371099656629, 71.01253509521484, 80.01193492643296, 77.3260135035361, 76.3428714198451, 66.9560355524863, 73.09435659839262, 21.433344656421294, 0.3366092586469266, 3.4988113132215317, 14.236208219682018, 0.14493459625349892, 0.2184716365750759, 0.12420995671662594, 0.27642487037566404, 0.14306592394507703, 0.6391188406175183, 0.4198451099857208, 2.480646876558181, 7.60672454872439, 30.466265063132013, 76.25319034822526, 97.59581842730123, 76.65127954175396, 78.00554060166883, 108.1613108419603, 39.88996336537023, 31.324242353439335, 38.16716817117507, 54.98780158258254, 68.24102755515807, 72.26173154769405, 36.22969773507888, 1.4030888075790098, 0.15832057312851952, 0.02115134093459816, 0.0670472260624651, 0.017200878318098765, 0.055648799189516616, 0.04025256163590858, 0.08585034088502008, 0.05263751440290963, 0.025053735364288576, 0.023910758994339455, 0.05779494854411291, 0.06331106888190394, 0.0329444122560803, 0.02165711218220813, 0.054299542154636116, 0.006461455120569877, 0.04275983717713145, 0.02149861625155374, 0.03173577640536091, 0.0405163869952723, 0.077183396675654, 0.015329215393942452, 0.028396550445787372, 0.06511023403295586, 0.08688547888830786, 0.02420196816655657, 0.07289113627085764, 0.02154990775330413, 0.08115814427935308, 0.05547539135741611, 0.07078774994419468, 0.0932080178491531, 0.11816992033873835, 0.17451590167418604, 0.32554449753895887, 40.9266967927256, 120.66456394810831, 94.96390019693683, 89.23214066413142, 92.46051019237888, 99.50255317072715, 44.797358359059984, 29.117809111072173, 27.821557944820775, 69.98540755241149, 108.71024654757593, 124.97986931954662, 118.12983420587356, 66.20552139897501, 1.4547084247873676, 0.04223026357771408, 0.07626548544653962, 0.2736798241253822, 0.2508375030611792, 0.5709378120879973, 0.5906721144433945, 1.02171081088243, 2.5513954028006527, 2.1945379193752044, 0.5295080222910451, 0.8579618459747684, 46.001184755756015, 111.78031706040906, 109.37833601428618, 98.06147436941825, 87.20556966720089, 82.12380178513067, 83.44351460856777, 83.36214896171325, 84.82666784717192, 89.56394180174797, 96.21826633330315, 96.52835322964577, 99.51861919895296, 100.179397367662, 102.46178534723099, 97.84478695161881, 98.68164031736313, 92.32792623581426, 88.08705176076582, 80.36553659746724, 82.35076581278156, 74.32204277284684, 75.00003230187201, 72.92078387352728, 77.38566490911668, 75.56988992998677, 84.63491101418772, 88.14303967260545, 91.6238372556625, 92.92793120107343, 84.62293994042182, 82.0348188954015, 85.77049209225564, 88.92667431985178, 91.12110707067674, 83.74112836776241, 82.92345539216073, 74.62626180341168, 77.95965671539307, 73.93788583817022, 74.52328389690769, 75.5439865973688, 71.43131086903234, 77.91679305415, 78.19320248019311, 55.42463594867338, 77.83647075776132, 86.65805385958764, 71.80904296136671, 70.62446363510625, 78.3398049877536, 87.2433420919603, 82.03413640299152, 82.62598283829229, 78.88910155142509, 72.81447195237683, 54.48543617802282, 59.66146253770398, 74.5845748532203, 72.58853558571109, 77.19512401088592, 77.55258529416977, 81.78435202567809, 81.9751988687823, 80.078152379682, 76.48051523393201, 80.00936185159992, 78.3061118279734, 73.98652322830694, 68.545544685856, 67.5921812365132, 71.38580353029313, 73.46070597248693, 75.78816983007616, 78.406508814904, 81.71560856603807, 84.5774482911633, 85.25599479675294, 91.24084134255686, 89.61221833382884, 83.68233988361975, 76.32301638203283, 75.37098653854864, 84.61580907144855, 85.62592137244441, 87.4407628274733, 78.9172092560799, 84.61359685467136, 36.22623820458689, 0.493609203446296, 1.1113472042545196, 6.858665308644695, 0.14232291058907587, 0.14999310546103986, 0.035548931167971705, 0.20024326389595387, 0.08055333318489213, 0.5740022250721531, 0.36117564526296436, 2.211008687173167, 4.999030386247943, 34.92154413653959, 85.26114879115936, 100.17274502784976, 85.68048154154133, 60.49164002941501, 39.77819150493991, 30.837413457132158, 50.976091584851666, 61.091848957923155, 74.06511183707946, 76.26264326034054, 84.73935588713616, 43.88535630318427, 0.9257771134857209, 0.08817153366943521, 0.06002820592613951, 0.042555919893446474, 0.026786480692305395, 0.08892845918214129, 0.025484625347739747, 0.09245434821012521, 0.040887863029755896, 0.04303548327316681, 0.03908157709144777, 0.04847204921046092, 0.03408875226253464, 0.038434838004890955, 0.017879582423296188, 0.1135133621433089, 0.049279272225835634, 0.03900101528533044, 0.09608349056854364, 0.09850234424154605, 0.2243571683403946, 0.14467342155835322, 0.11410315791445394, 0.1322335479480605, 0.1601696948731138, 0.2230571477764076, 0.10552157888249045, 0.16790341375575912, 0.16015939865141146, 0.2062086220229826, 0.1541168035398568, 0.23139060625145513, 0.31921820474728463, 0.1910901219854432, 0.2982246683489892, 0.2820262601298671, 54.425176805065526, 139.50433546496976, 107.44632551746984, 112.81119438909717, 88.06419218740156, 110.76666678151777, 50.780180961855, 44.18677476144607, 50.05780196958973, 79.33737354893839, 129.67957481261223, 139.62523860316125, 127.81964963482274, 85.87814546400502, 4.370800045228774, 0.3496439075998722, 0.21546890899058313, 0.44726425481419413, 0.6000072941664727, 1.4201109135343184, 0.7132763355489701, 1.239383785474685, 6.555636227130891, 7.02407411029262, 5.600936230151884, 1.4019139351383334, 51.89724060796922, 116.44760024163031, 115.66802132514216, 101.3161551567816, 91.95508141671458, 87.60105440693518, 87.66960959280692, 88.56859330208071, 88.59629308023761, 92.45296355216735, 100.41342166162308, 101.1308623898414, 102.6216454659739, 103.81264963457662, 106.533888078505, 101.88267092550956, 103.75655189637216, 99.15463893644272, 94.5605158036755, 86.50199059517153, 86.2027608194659, 79.83705212993007, 78.76274631869408, 77.68962506325015, 80.71563166956749, 82.41706171343404, 87.4469837065666, 94.4014480037074, 97.24085177144697, 96.46198672633018, 88.77821260882963, 85.47533373678885, 91.60004415819722, 91.48339286927255, 95.02656398280975, 89.0917198119625, 88.34359830425632, 84.04646135145619, 86.41173685750654, 84.61056878489833, 84.70402317662393, 87.96290874481203, 82.86301951254569, 90.66510800392398, 86.6164767357611, 66.33631675474106, 86.77082984678208, 88.95745708096413, 76.60446213137719, 78.86505742226878, 84.38392639160156, 90.48732265349358, 85.96231168316257, 88.90712522691297, 83.71078491210938, 78.62767557944022, 60.829383557842625, 61.1065774579202, 85.34067876877324, 79.05752812662433, 84.73785754173034, 82.97117494767713, 87.44438709751253, 84.43756872607817, 85.40889663081016, 79.79354519997874, 82.7050107525241, 80.87975148231753, 82.44201583247032, 74.31491190387358, 74.35828547323905, 82.24517560774281, 76.42800254206504, 80.89598225009057, 83.63235319814375, 87.79476458026518, 88.9679298093242, 89.77125475483557, 92.18009210401966, 92.02493882948353, 87.59015021785613, 82.12377825090962, 77.8323365795997, 92.60391204587876, 86.5010178473688, 90.69462776184083, 81.10961806389594, 95.44239013425766, 46.66883491700696, 0.3170865804197327, 10.281214714050293, 27.214171078897294, 0.28112963082328923, 1.1470777901910967, 0.36155636031781474, 0.4784258004398116, 0.39392332997052903, 0.9121696146265154, 0.6848884878620025, 5.968762376616079, 16.03522094988054, 56.900486561559866, 95.01067838361188, 114.32555090996527, 96.31474879480179, 108.84979663356658, 144.74962695952385, 50.0877296540045, 43.324590729128936, 53.73332561985139, 77.00614421598374, 90.60868863136538, 97.5921392440796, 68.56120278758388, 2.0087754486068605, 0.29996531204350535, 0.16723081920175784, 0.1812852690777471, 0.1637495624562425, 0.25708479686610164, 0.09438645259867753, 0.1571293983368143, 0.11612016016677504, 0.15511097116095407, 0.10880184480019155, 0.1505367061303508, 0.1020559426697512, 0.12613375671207905, 0.10399357821311682, 0.23647597450162136, 0.2700555540861622, 0.11624137059815469, 0.22918663258033417], [0.03538831317376706, 0.053037626804002834, 0.016775050260607275, 0.02116874262179819, 0.013993468319606638, 0.047754021812110185, 0.0653803796176949, 0.0279245866582759, 0.09288768584449446, 0.05473154679601712, 0.01864383939743763, 0.03056235570130089, 0.04435675128573372, 0.01621523534037894, 0.04829302595387544, 0.03280512214968762, 1.3705864548683169, 68.73112770818895, 85.74005449971845, 74.87694832586473, 64.93638753890991, 51.198709626351636, 53.52206676237045, 84.03857738740983, 79.3886467718309, 88.58815023975988, 122.00355914331253, 110.04112243652345, 108.1614677367672, 59.93698550808815, 2.960690317615386, 0.09529304104827105, 0.08883475896812255, 0.25330214580941585, 0.13614163824146794, 0.3169697979765554, 0.40112075666266106, 0.22581094275078467, 0.3044130653142929, 0.5080752110769672, 0.9565530104502555, 0.3555833872768187, 10.099090241616773, 75.0711605625768, 106.54796938742362, 99.24398268422773, 96.17622636979627, 83.10465320464104, 82.53697641434209, 85.94448843309956, 90.82770593704717, 88.10366692081575, 91.05771372395178, 95.63511187030424, 95.83863581380537, 94.16486632439398, 101.22817639381655, 93.75094644484982, 90.18301733078496, 84.39101803687312, 83.84375326095089, 73.47699165344238, 71.84162216801798, 70.79753429658952, 72.64064035108014, 69.21653670649376, 75.72169350039574, 74.00335804108651, 75.42741375584757, 80.92382323357367, 84.070630996458, 89.79391036495086, 90.22420221759428, 81.03701499200638, 83.03927513860887, 82.17737351694416, 88.35967217722248, 85.1579276977047, 77.9227864357733, 74.55796549397131, 80.75165471723004, 70.8040532758159, 70.121380436805, 60.535503895052024, 54.398257578572924, 48.09080000846617, 58.55355378120177, 67.49452990870323, 39.950885618886645, 49.64949500176215, 76.65023619128813, 74.13653035317698, 68.39803218841553, 76.59712729915496, 81.919218801683, 79.03924203688099, 80.34348503235849, 67.72259220000237, 68.16370194958103, 42.407940664599025, 49.357419629250806, 67.1053131165043, 65.57787156874134, 74.09261549672773, 77.20944066201487, 73.88952301394555, 73.24517957625851, 76.21745755595546, 71.01820684248402, 74.52231114910495, 76.83519163439351, 69.75834154313611, 63.02687183503182, 57.23514318466187, 56.595949819011075, 65.99168162192068, 67.09687217589348, 71.02643597510554, 72.19483160203504, 74.99086180040914, 78.87141166194793, 84.33746983928066, 86.83306217193605, 76.43864000997236, 70.07022488501765, 75.86377743751773, 79.29405489275533, 82.5104376577562, 82.45891340317266, 73.95781147864558, 65.80663204193115, 63.77326357749201, 4.930759572213696, 0.4826017763585814, 4.116881980049995, 3.076003833163169, 0.05878565727823204, 0.1091757263507574, 0.17930557530733848, 0.3569007214278944, 0.28311530007950725, 0.439016092568636, 0.16570092629521124, 1.5311849597961673, 1.5577387929924074, 25.60857826663602, 71.26063285335418, 96.88885042744299, 80.5971682456232, 77.03261236990653, 74.44108670757663, 27.03293992627052, 25.62490905484846, 36.61323885763846, 59.94817995255994, 63.08741361864152, 70.8440222278718, 20.28938343448024, 0.9185589104890824, 0.031177508982739625, 0.0558084940477725, 0.020580417739467758, 0.08601638278172863, 0.019967242880093477, 0.11851940198891586, 0.05881623567772969, 0.11619747376009343, 0.0468620618114308, 0.07240186655713667, 0.021932968952422662, 0.04711721888593128, 0.022401086978554245, 0.06387243129973931, 0.04770749346202901, 0.06474103327960738, 0.03409170936192236, 0.02769847772264433, 0.06254716430820766, 0.060645810688935944, 0.08387029471416628, 0.02377275017000014, 0.08181520257024996, 0.014689596137031915, 0.02480934565556386, 0.07029441996447502, 0.054730554712155176, 0.05875929619275755, 0.03778745540447774, 0.045696413069362604, 0.048482157740621805, 0.03990008458194714, 0.18570846156968226, 1.3694305814081624, 84.6165386323006, 95.78008267187303, 87.89937419276085, 93.2293261251142, 73.36952655546128, 70.4232225110454, 50.55995556616014, 38.20312846091486, 102.87441084461828, 123.63803432833765, 120.53869508927869, 118.35098528092908, 73.06400529799923, 2.7827105647133243, 0.21517022663066465, 0.009413539026413233, 0.22908466627761243, 1.3073093083597, 0.44429771722324435, 0.6046301751367508, 0.5286107801141278, 1.2888288161446972, 3.6046216612862008, 0.9755999787199883, 0.2357174402042743, 13.78074553705031, 82.20261789137318, 112.10332424409928, 102.7715192302581, 100.96630327163204, 85.45405095623386, 84.8879901824459, 88.76197399631624, 93.6641836166382, 94.11174174278014, 97.68739792608447, 102.01692581176759, 100.12835164223948, 99.57394030786331, 105.74974352313627, 95.47743258937713, 94.5241475874378, 88.78791655263593, 86.84842217353084, 78.3411072146508, 73.88830707919213, 73.8795288147465, 76.14678429019067, 75.04848926298081, 78.78632760817005, 77.46615194505262, 79.26013423550513, 87.29166569248324, 88.26627269867929, 94.53837794642295, 90.33679777576079, 84.32436912290513, 86.0871607257474, 84.18595652426444, 92.7395554511778, 87.86965831633538, 83.93377165640555, 77.62328993889594, 83.29465281578803, 75.46926544558617, 75.53021907806396, 63.21309420370287, 59.411282001003144, 56.07782040872882, 67.33813716519263, 67.3998752717049, 40.32165550416516, 55.43847799301148, 77.94352792924451, 76.31208081399241, 75.83883900796214, 79.26208757585096, 82.76911797062044, 82.55131659969207, 84.59690324721798, 73.89634009330504, 73.90119598757836, 53.00271749496461, 62.409259350069114, 77.05211439440328, 72.25629514263522, 79.71655691823652, 81.23608312299176, 78.14912288419663, 77.292845941359, 81.00629498881679, 76.17089117726972, 77.86609249730265, 80.04980933281684, 75.66119486285795, 73.93644240594679, 67.97911520927184, 66.90354639484038, 71.03283728322675, 72.8692517742034, 75.30575752258301, 76.00837169154998, 77.65862264940816, 82.2671251912271, 87.72707231583135, 90.58643310300766, 82.05236757955244, 73.68309651651691, 81.2134353576168, 84.49299966135334, 87.40457504026352, 88.71270902695196, 83.96068696052798, 76.22416480895012, 78.71588183987525, 8.655371685181896, 0.6609931023370835, 2.143010477865896, 5.224195026582287, 0.18324044803457876, 0.16987803602410903, 0.22843346089845706, 0.24366661365474426, 0.2505763283660335, 0.2390700861090614, 0.19511831954361933, 1.600270278511509, 0.7109366417411835, 29.558826684951786, 80.71402349779683, 101.06710034032022, 95.07597800224059, 68.66782849834811, 41.49400880259853, 30.588860704052834, 41.994009017944336, 51.318424286380896, 75.7259375049222, 75.02712019028203, 85.28125486066266, 28.664310555304255, 0.8018038013289053, 0.09676507899477597, 0.06759440436238243, 0.06165371426651555, 0.016841730553536646, 0.04900407046079636, 0.04264799217062612, 0.03871069477510549, 0.07773510255520383, 0.08364365526264714, 0.022685546916158452, 0.06689937109307897, 0.0670507500669168, 0.08053208956675184, 0.016579590587606354, 0.05522404173989931, 0.08789011127045078, 0.1320206061486275, 0.09212391150574531, 0.1598034282365153, 0.16688405716371152, 0.23271884949457264, 0.12446486481255102, 0.218752101364155, 0.12071885574128359, 0.0707890063283905, 0.16111726902665632, 0.23139719460760397, 0.20591164037825602, 0.1581030807668163, 0.21884380208869136, 0.1958963124742431, 0.13077218926722003, 0.42195185177749206, 3.0900400348248023, 111.8110135293776, 108.1779573809716, 100.96566000292378, 85.73003676629837, 68.73199062962686, 63.893735254964525, 110.84362368429862, 108.0376071314658, 121.26155653307517, 142.05266798696212, 130.66240310668945, 126.90385464699038, 91.246717053075, 9.746219112027077, 0.5455444488794573, 0.1137829484838632, 0.4596659312805822, 0.8526443377617867, 0.827993834691663, 1.1995220857281839, 1.8743181925627495, 1.6357419880167132, 5.897107047419395, 5.731449175265528, 1.3312634681501698, 15.113587514046701, 87.06441140943959, 118.38876555042883, 109.54450330426617, 105.88059379208474, 89.10116487933745, 91.16314703418364, 94.85993385314943, 97.23295996266027, 96.7154973553073, 100.94228267669679, 104.79166538484635, 104.97877813154652, 103.17289536999118, 110.17316510600429, 101.37394735890051, 99.67221137016051, 94.26117620160504, 92.0061977448002, 82.92989592398368, 80.11238682654597, 78.53477031953874, 81.84937707839474, 77.23172756933397, 83.99703164254466, 81.18950105482533, 83.20394408318305, 91.88333342152258, 91.79787282020816, 97.29762415732108, 96.12383134903448, 91.73006288466915, 93.95130111325173, 89.8224259961036, 96.67741898567446, 89.57874482677829, 88.3127135615195, 87.91640512404904, 93.98723786877048, 82.2442263941611, 84.54919153644194, 75.45101857954457, 71.87238139490928, 64.00705252924274, 76.62698438090663, 77.83895754045056, 55.28760010196317, 71.68260928123229, 87.8306071988998, 83.8288325648154, 81.48545172906692, 85.60848251465829, 88.39056476469963, 84.01872234959757, 89.76837573512908, 76.86178530416181, 80.95262912011917, 61.31405122818486, 62.57223775309902, 80.59466577345326, 76.00091134348224, 82.5007180244692, 87.80078149610951, 80.30969773569416, 81.49564204677459, 86.84612366460985, 78.73118692828764, 82.8169002840596, 84.75706931083434, 80.66228743522399, 79.77791063247189, 74.00742161658503, 72.68672820060485, 79.56413361334032, 76.14979667048301, 78.87760116207984, 77.29290869928177, 81.7275639503233, 87.55992443330827, 92.39923492554696, 93.81890543045537, 86.20824429296678, 78.08947932335639, 85.45586309125348, 86.11543316994944, 93.5051550403718, 93.43827078419348, 85.06254349985431, 79.05813217163086, 88.36478694792717, 11.35447717482044, 2.844975494569348, 9.555388938996101, 7.097875466269832, 1.283440460120478, 0.3590291281861644, 0.4211903297372403, 0.6294804126504929, 0.6585690775705922, 0.8501012935753792, 0.3890605715494002, 3.027639783197834, 4.86413223128165, 45.08822564155825, 88.387340576418, 112.40285996467837, 100.63862846743677, 110.89759549786969, 101.50742561586442, 33.461143739761845, 35.92030509825676, 51.04592938576975, 83.18419102699526, 82.67203930885562, 98.02483943200882, 46.5890892090336, 0.9979626981000748, 0.1711763558729041, 0.16027273369892953, 0.16355735099604055, 0.29155241025070994, 0.13144210251348634, 0.29984065421646644, 0.08957690664476926, 0.2077553228985879, 0.19340897820168929, 0.12719717868153127, 0.22209915482709486, 0.17496073828829875, 0.17875327187920773, 0.14960862125360197, 0.13405233261085328, 0.21150716189895907, 0.1846281703441374], [0.013330750554169138, 0.02492531987598106, 0.040723675065824104, 0.11044082862715568, 0.047890707219560305, 0.034472313334023764, 0.04623847773238536, 0.05531105400633909, 0.04336622641271642, 0.0794675720915679, 0.02022513105804401, 0.0037964032925364953, 0.025472628410845518, 0.10407865993798741, 0.06334308369625961, 0.2140607474552047, 10.935607264118811, 99.55548947857272, 79.12721295510569, 69.31910668649982, 30.848976604400146, 35.03097041960686, 42.63461443685716, 78.68502063135948, 84.11022340097736, 96.49160062113117, 106.58785204733573, 99.8966258571994, 57.16080642515614, 4.847671514557255, 0.45670736100404496, 0.08943747098167097, 0.009893163693167511, 0.03315022560737787, 0.43084407946275133, 0.4360901269941561, 0.3968838307886355, 0.2193881382024096, 1.1405377282250313, 1.706530595979383, 0.15905564981362513, 1.5597839413150665, 40.16992645878946, 102.72855358739054, 104.85157566685831, 102.74126206674885, 91.72380278187414, 87.89881721619638, 88.84038217606084, 94.7256789668914, 97.17324579915693, 97.01867303540631, 97.3417978902017, 97.09887766068982, 97.07578274511523, 97.90347345413701, 93.53952284782164, 88.15639142067202, 82.65736964441116, 76.23237825209095, 75.62756446100052, 75.68551355792631, 71.09846638094994, 72.24346899217176, 72.56759012899091, 75.47015974598547, 76.47353341502529, 73.93964306000741, 78.24795876779865, 85.55919401107296, 86.20667534489786, 94.28303949294552, 81.75567165497812, 73.36519625879103, 82.8991602313134, 82.39940320291828, 84.28561610560264, 78.4050496931999, 80.80863891109344, 69.12655753474083, 77.93617740754159, 70.39689556244882, 66.11504016384002, 52.13573640392673, 46.39696367325322, 54.44580062743157, 61.65094752465526, 42.60728336149647, 33.52041075306554, 29.717747396038426, 42.163800577963556, 62.740860446806884, 75.1322240214194, 69.02360316245787, 73.22024899144327, 78.39121941597232, 81.01927803408715, 72.03717585532897, 62.24113087500296, 47.40879789475472, 64.75767650911885, 67.44971290711435, 73.41589681563839, 73.19063509664228, 79.44633699232533, 76.10294788114487, 75.40324411084576, 75.12771329572125, 73.61589847072479, 74.05794958914481, 75.39812149540072, 70.85167084970783, 68.39195251464844, 64.0714107790301, 56.63740534936228, 57.58142963532479, 68.23265721721035, 67.84188716642319, 71.29664021153604, 69.57511978764688, 76.44631216602941, 79.37964100991526, 82.34542354460686, 74.56840684337001, 72.21750290163102, 74.96288745634018, 81.37875541563957, 80.48362347387499, 75.51143092493858, 74.99283867497599, 65.57533379523986, 71.38867470525926, 24.554198095875403, 0.5775169751817181, 0.5586169119323454, 2.1249325188898274, 0.029342883536892555, 0.10421728354788597, 0.24623522985606427, 0.1357900192059817, 0.18509755241534404, 0.373580968307872, 0.4351048766364975, 1.4414467686606993, 0.15463611922196804, 0.5746108666062355, 39.39391297678794, 79.24036548983666, 90.34690180132466, 73.28258329822172, 68.27363029603036, 81.47199799937587, 23.15535145421182, 29.680635890653058, 24.519071309797226, 63.68176644848239, 65.93275193245181, 55.51817663254277, 26.782702515202185, 1.3190121900650764, 0.13207786356008824, 0.030550456440617, 0.04466174621014826, 0.02864087695225833, 0.07881331002159465, 0.033986766807614796, 0.0825088722030482, 0.035403807302035635, 0.025526842538027034, 0.04311388854177729, 0.04675285980826424, 0.0654415364166902, 0.06623415396578851, 0.02480677926101752, 0.13055020763028052, 0.04172613941914132, 0.07396223444131113, 0.05002525034210375, 0.03325009665962669, 0.03800004097302595, 0.02995331580149791, 0.07646930313879445, 0.04543610405357135, 0.10513434441940439, 0.05786041075724268, 0.03248118187090562, 0.04210040784410892, 0.0464551848539662, 0.0053706110338680455, 0.15341489846187253, 0.13151535584080604, 0.4372564498935977, 15.426078823304946, 112.7964541219896, 87.89508311979233, 78.09704165304862, 45.20147231317336, 48.91649030870008, 26.483480584236887, 43.25895770903557, 89.68553527708977, 107.2217619803644, 114.29940439039662, 111.93030849579843, 64.88628710469892, 2.9719127089746538, 0.29423335026348796, 0.09149019591390126, 0.059472033753991134, 0.19033367144725016, 0.060139457214503526, 0.2866107754168972, 0.30659237095425207, 0.760776422196819, 1.4301565938418912, 2.9493507454472208, 0.5600623666278778, 2.085889001046458, 46.03373258344589, 109.10120487213136, 103.52044874621977, 104.5471840520059, 94.23729681199598, 90.59166554481753, 94.60215568542482, 98.00599636570101, 100.52877072365054, 100.7050185049734, 103.13095738810878, 100.27865686724263, 100.99197126203968, 100.04066313466718, 98.33072939226705, 89.63794123741889, 86.05416574785787, 80.94140329668599, 79.65786257097798, 79.39852329992479, 75.56756004210442, 76.39937708454748, 76.79712110950102, 77.71830543395012, 79.3429825382848, 79.7114892159739, 82.73132201164, 90.78714862946542, 91.48820169510381, 98.13538751294537, 83.4998712232036, 80.44934195856895, 88.14837409603982, 85.47714587180846, 89.05761872568439, 79.96828679115542, 83.84767563112321, 76.10159858580559, 79.6078601960213, 74.29021666126867, 73.76831393088065, 63.59726682786019, 58.94621833678215, 61.31023868437737, 65.64413216806227, 52.83170215545162, 45.991822058154696, 37.860913430490804, 48.539981995859456, 71.65909074967908, 78.05565280299034, 71.21738479983422, 77.47562054664859, 79.97500973363077, 85.34019239487188, 76.21307234610282, 69.05364851797782, 61.47125982469129, 73.68745034740817, 71.27908368264475, 75.8210628263412, 76.92869309456118, 81.8175745010376, 77.70432610665598, 78.61811284096011, 81.12813949584961, 78.78762199032691, 77.11760228680026, 77.47948015889814, 74.37652449454032, 74.33582598163237, 71.92461952086418, 68.64389419555664, 65.27068722632625, 73.57303480948173, 73.39232337090277, 76.18552946275281, 72.91788916434012, 79.03733576497724, 83.58819515474381, 84.90764910174956, 77.82313469917544, 76.71702631058233, 78.33732604980469, 86.15448428738503, 84.83832513132404, 82.42886804765271, 83.46073381362423, 75.87101813285582, 81.25673047957882, 33.00616841162405, 0.6767226647465461, 0.32125857268129626, 1.3314435294558926, 0.07397430798699779, 0.07774378233138593, 0.6470474829116176, 0.04494238719944993, 0.1558027792000963, 0.16659228491687006, 0.3385057246252414, 3.47068595790094, 0.2681490983213148, 0.16323294340362474, 45.03599143797352, 86.34803756590813, 93.0983268060992, 84.78930334891044, 47.15755831810736, 33.43735064229658, 33.61897599312567, 46.3275416435734, 43.509365743206395, 70.2476336879115, 75.81958017041607, 67.54294764611029, 33.38208444656865, 0.9824941571681731, 0.15712156891822815, 0.054478446667593335, 0.032121132037812666, 0.0935329080769612, 0.1219855361588059, 0.027854074010505315, 0.0021625460302006575, 0.06528488675793333, 0.020452310601549766, 0.019742555037561445, 0.03607624480801244, 0.033875779819584666, 0.017049281009202524, 0.03867516744761698, 0.03878002573225287, 0.05205522246298291, 0.14017912078528635, 0.14697275785428865, 0.1240384219695003, 0.2859181093592798, 0.15707329005724, 0.11460318350263181, 0.09642355699813175, 0.2936292746134343, 0.14600100596585583, 0.16372728461940445, 0.15547429601992332, 0.14254898313553105, 0.10294643561205558, 0.3178868358654361, 0.43565633736791154, 0.8907888361042546, 23.872935348941436, 133.61900729517785, 100.35806132901101, 94.73723426941903, 43.62313016768425, 43.59913310697002, 57.86331076775828, 110.08661408578197, 118.20832867776195, 114.58763584013909, 130.16885911264728, 121.57755051889728, 85.15020062846523, 8.600513415951884, 0.8948586628802362, 0.20527724296815936, 0.3698596502504041, 0.296589468996371, 0.757176605684142, 0.8814010108190199, 1.17525291058325, 2.448916617901095, 3.897621732565665, 8.504593814572981, 3.5429100307726094, 2.0372763708714516, 49.04651295754218, 118.53806664866786, 114.84322532530754, 110.2588532047887, 99.41989314171576, 96.19182955834174, 99.42820072174074, 103.65973995577906, 105.4670661495578, 103.16930247891335, 103.9258727719707, 103.83671729795395, 105.59706918654904, 108.49597530980265, 105.69494016708867, 95.22927991805538, 93.13786429743614, 85.73803055670955, 83.14368863259593, 85.42921450830276, 79.8074774588308, 79.41133376090758, 80.32620306937926, 82.81464884358068, 82.5835741719892, 80.7536865049793, 86.92239023024037, 93.78082706082253, 97.11434748864944, 98.21179528390208, 87.96912962390532, 83.2197904586792, 90.10640559657928, 92.43346152767059, 93.35038615811257, 83.66372431478193, 90.14537042187106, 80.38750187043222, 87.49657815502536, 82.56199329130112, 82.30980057870188, 69.15065657707953, 64.63571825335103, 65.32039150114983, 70.2477199800553, 58.44508455645654, 48.36900195767803, 47.51105800751717, 59.52879228899556, 78.80360172640893, 80.41582138307633, 76.34115342170962, 82.48118462101107, 83.8322920953074, 90.12278541441887, 78.72149082922166, 77.19546133472075, 65.4309670386776, 74.90823315035912, 74.866255944775, 80.31828772637152, 83.18707004670175, 86.13199341681697, 83.93840789794922, 80.70147975798577, 86.68877386277723, 83.02954766058153, 82.47481469185122, 81.71535753434705, 82.00614636944186, 79.29718494415283, 77.99456580992668, 74.20005706048782, 74.81243318127048, 82.1940279006958, 76.95549072757845, 79.37462822083505, 77.12769846762382, 80.00405880712694, 88.81851888472035, 90.25176863516532, 82.66325319966963, 79.57473185754593, 82.65615370965774, 90.09341470656857, 90.93115452797183, 85.5802022257159, 89.5070674342494, 79.9211948148666, 87.7947332013038, 41.53672733614522, 0.8002576520366054, 0.7031234642190318, 4.486912498551031, 0.31657823511669714, 0.4321910152512212, 1.3287840399049944, 0.3183597572628529, 0.26691015028665144, 0.5347989319312958, 0.6471850110157844, 3.8753171745807897, 0.4409744584512326, 1.5040223012047431, 60.16776992428688, 93.32684409233832, 106.47035352645382, 90.46074467320597, 102.54731655120851, 108.14240501772974, 36.08180084536153, 43.93684133406609, 41.20314152010026, 82.97821167976626, 87.39198423201039, 83.63645599734399, 54.081326146279615, 2.87128871487033, 0.25410333588238687, 0.18167447238679857, 0.13497632657808645, 0.24602313075334797, 0.21637718283361007, 0.13671528487916917, 0.1294187723749107, 0.13541826737984536, 0.09104655439695043, 0.1250575104307744, 0.1888330277776526, 0.1593434843685358, 0.14669531145163123, 0.22521543196372448, 0.1479469918675961, 0.11279566033232598], [0.02817189899243174, 0.03968635371195213, 0.09111013969466572, 0.04721323268548135, 0.07105622545725877, 0.08159480673531372, 0.011564175741025999, 0.12733265367006102, 0.06863698874029421, 0.05363053672256009, 0.03866959798840746, 0.04680295046719332, 0.04755997557132956, 0.07723766634421003, 0.07612536030430948, 0.16686724919465282, 45.47103720326578, 88.04188959060177, 73.48526000976562, 67.09549934633317, 71.01158588163315, 51.272375660557906, 83.96684508169852, 70.34738740613385, 87.7825346300679, 120.07114856473862, 104.06965901774745, 49.90313506895497, 4.536153443398015, 0.5220730470553522, 0.13025442108271584, 0.16923634545697322, 0.140831092252366, 0.44286019919860753, 1.9889553444039438, 0.5844516643593388, 0.13895552515262558, 0.5189665911659118, 1.4496876683927353, 1.609149789137225, 0.5341972158320489, 6.072466902194485, 65.3337707058076, 108.2651516699022, 96.28264811731155, 96.9209275707122, 94.95025034873717, 90.32236345352666, 95.06654862434634, 98.89810808243291, 98.74777932320872, 97.28475093841554, 99.57852948096492, 98.7071200340025, 92.62552430552822, 91.93588533709126, 84.95540003622733, 83.30874196944698, 73.71951964593703, 72.70084873322519, 70.16760949165591, 71.23675346374512, 77.3776005160424, 79.84688943432224, 75.71074224287464, 75.84797813046363, 77.05562883807768, 78.758510158908, 82.7418496531825, 82.18382973824778, 89.14598972566667, 91.1362160405805, 69.88402212819746, 79.24009876866495, 80.93428811719342, 80.67607848874985, 76.56231234150549, 75.22010080275997, 77.44122920497772, 80.97164477071455, 69.46799201350059, 66.92128335275959, 66.93490182199787, 72.5909282315162, 62.76643822270056, 71.03231168562367, 81.21509059782952, 69.13553191769508, 80.71612588820919, 54.38833790440714, 45.16765755991782, 56.738033756133056, 61.65434037485431, 66.38536991611605, 69.57785760202717, 76.07247106490597, 71.32673263549805, 75.34721697530439, 59.752673333691014, 65.04951653941986, 71.60904130628033, 73.20368874457576, 78.31378398403045, 72.6303009833059, 72.55892953565045, 71.41781791563957, 73.03992978988155, 77.20391796481225, 73.12768105537661, 69.88271990130025, 70.68881404015326, 69.96211651832827, 66.56506153845018, 69.96785886826055, 63.5337205086985, 54.244394763823486, 57.07337287164504, 67.02695984994212, 70.88065716528124, 71.16673915616929, 69.8989506690733, 74.50967327240976, 77.13535493420017, 73.40868749926167, 71.61743517844909, 77.52528559777045, 79.27406649435721, 79.70038890838623, 80.06097239832725, 69.30112654162993, 66.99116429974957, 62.4379514878796, 42.6413530688132, 0.5911008172458219, 0.39117497422041436, 0.15053177252411842, 0.058176533108757394, 0.15099383079476897, 0.212095502103048, 0.17870661712461905, 0.08992062731375618, 0.12706679051681874, 0.09350451685848737, 1.780905230872093, 0.9342431204934275, 0.2668234597771399, 1.7263027737217567, 74.79789687741187, 84.33473202490038, 97.06008541968562, 82.50438151821014, 76.7508920546501, 46.50450329626761, 23.694553798244847, 24.743364203360773, 34.82349272697203, 66.21995572120913, 77.30746069262105, 69.8718157122212, 51.17013908201649, 2.0131514654044182, 0.04383476578720635, 0.035402619865753, 0.058083997348383556, 0.04115888578516822, 0.0608729902324417, 0.025834884577160402, 0.1721392977502077, 0.03859473970688639, 0.05446533507276928, 0.05343011663024945, 0.05802801164287714, 0.015304803044625349, 0.04986262519753749, 0.06472951897810544, 0.08963720542528937, 0.037694954118060495, 0.026332855134481387, 0.10874189075923736, 0.08373224567021094, 0.06836865878393573, 0.03786053253157485, 0.021038136122027234, 0.03712148751102148, 0.033381143659954114, 0.05553619575596625, 0.04878006252129713, 0.03871276704294067, 0.06800796160654676, 0.06659448342097384, 0.08847426863447314, 0.1370486403785406, 53.99622248065088, 101.39159802467593, 83.79992469664543, 87.09502158626434, 74.14882306129702, 39.987414652301425, 29.48258169235722, 60.85865228406845, 99.46234887646091, 124.54625129699708, 114.08027725835001, 63.46845226903116, 4.190841701722914, 0.3500708024347982, 0.1694003035945277, 0.1171655867308859, 0.1042027738426001, 0.38166414585805714, 0.32685089195447586, 0.6676369845386475, 0.3141848232236601, 0.0861973557320814, 1.2219483597624687, 1.482360766779992, 0.6056156706425452, 6.464043490348324, 69.98206569302467, 111.17809203363235, 100.11917329603627, 100.25818993968349, 98.43632744204615, 93.66765883661087, 98.36117482954457, 102.42292250356367, 102.4255112678774, 100.60582176331552, 100.60681020059894, 102.28436085485644, 95.19547693191036, 94.46239379144485, 90.47053490915607, 85.36999456344113, 77.28704083350398, 75.89998875894855, 74.83833651388846, 74.86347106195267, 82.50307144657259, 82.86673791946905, 80.92519606313398, 79.21707445575346, 81.67627503795009, 82.40961705484699, 86.42252337548041, 87.10612973859234, 92.20045704995432, 91.31762566105013, 75.59195718457623, 80.61784698117165, 83.49608221361714, 82.80571368432815, 77.82355831515405, 77.7722458685598, 80.77948785597279, 82.99366581824519, 73.42127046277447, 72.24709326221098, 74.20324986980808, 75.48093057447865, 67.91863226121473, 79.11330423047467, 86.02732889113888, 72.96979781120055, 80.21840064756333, 61.008659408938506, 54.257001261557306, 61.81203926763227, 65.01953394182267, 69.57485306647517, 72.64967749195715, 80.5243847447057, 75.67631167750206, 78.81714174824377, 73.77209509572675, 78.54803577546151, 74.46070640317856, 78.60288619995117, 78.73773728647541, 78.79171694478681, 76.74059191057759, 74.11967200617637, 73.14300183326968, 81.13952221408968, 78.94596022944297, 78.29614116299537, 76.49694996495401, 73.95085319395989, 71.98499264255648, 74.52540982154109, 71.50352170390468, 65.69189879202074, 65.01340327724334, 71.19485470556444, 76.96942298643052, 76.6958612011325, 71.31043126506191, 76.2760813005509, 79.06814206031062, 78.95251843237108, 75.04018168295585, 81.73954286882955, 84.3002857700471, 83.10886583020611, 85.52388483478178, 77.07547603114959, 78.11106020404448, 73.70666996125253, 56.140488116971916, 2.003537613538004, 0.5984517066709457, 0.0997293183219529, 0.2495784069141073, 0.17265066143966493, 0.2049200774561013, 0.17913587151035187, 0.19703959144892233, 0.12726451781007553, 0.03344090234848761, 2.153990908015159, 1.27707555649742, 0.4083855990921298, 2.294437500738329, 84.07904840284779, 91.50701338245024, 106.2532974058582, 88.1043964816678, 49.066446442757886, 25.076379314545665, 37.01893744930145, 36.31023183945687, 52.07165272005143, 81.21203899383545, 90.64758285399407, 83.48740593079599, 61.41983362936205, 1.6200607197899974, 0.03079554328935281, 0.07501889185439195, 0.025335435470145558, 0.06318735334301187, 0.1033462109344621, 0.019216988077988068, 0.06548452161012158, 0.02910206762833461, 0.029963207911820184, 0.054705902002751834, 0.057691082343338966, 0.02444819457107975, 0.03630302598579757, 0.051367053341481, 0.034470160626956535, 0.18886034647303243, 0.20221515889129332, 0.17612240337316068, 0.16336975138514273, 0.18178002398100593, 0.12290322522242224, 0.1533966349257577, 0.1866451572747, 0.21012968984582733, 0.11610043340272481, 0.21612380691353353, 0.1881113882747389, 0.1387519296258688, 0.14886013802982148, 0.1894514292718903, 0.21743118192159364, 73.22203759224185, 113.5108510909542, 95.12779251221689, 90.75975479618197, 95.8209223901072, 71.64071836779195, 116.53722640006774, 101.33893628274241, 107.34485380111202, 147.45206156084615, 128.93363414272187, 80.37807249253797, 8.26810529155116, 0.4514396791496585, 0.3346697078837503, 0.3488908431703045, 0.24786252318130386, 2.1760799807886926, 8.78892642836417, 2.5869266833028486, 1.5179354385022195, 2.246639007522214, 5.339228337810886, 6.336217859098989, 2.3029608111227713, 7.904182884000964, 76.01431015999087, 119.05545865335773, 105.69603843073692, 109.3027440963253, 102.58566948675342, 100.21342000653668, 102.68176755597516, 109.60638261610463, 104.60871819526919, 104.56601142883302, 105.676646232605, 106.31498059918805, 98.31589498827535, 104.04018632827267, 93.69009479399651, 92.67091397316226, 82.38737721596995, 81.36767079753261, 79.64814293769099, 79.44461114944951, 83.95163413017028, 88.11436714664583, 84.51009335056429, 83.6002132969518, 85.08254758773312, 88.19228895248906, 88.90841960906984, 93.43797268406038, 96.20477337991038, 95.80020443085702, 80.41568802249047, 86.40500607029085, 91.66569679014145, 88.96894962556901, 81.6180278408912, 85.3226201764999, 84.43594486482682, 87.92338694295576, 80.0594348292197, 77.8256763950471, 79.18505222566667, 80.48527086934736, 72.17693774930893, 89.62884133861911, 94.44577078665458, 79.58383960108604, 87.07366820304625, 65.68244587990546, 57.926637434190326, 65.03230125673356, 67.20385874471357, 74.68017870380034, 76.21664170295962, 85.36018079326999, 78.74595072961624, 85.20908324949204, 81.44050136689218, 79.84235517440304, 78.75319926969468, 80.85553476887365, 83.41386149006506, 80.09817215704149, 80.58947255534511, 77.95513814495456, 79.56083882239558, 86.73875270351287, 82.23066283810525, 80.84761158112558, 80.85879033611667, 78.961484970585, 78.59418638290899, 79.90017091074299, 76.46448058466758, 69.87289044164842, 73.73080822729295, 80.56023520808067, 81.05727795631655, 79.86141004870015, 76.41332503288024, 81.54900981533913, 85.40107542468657, 81.66312725313249, 78.51679017466884, 87.13843437933153, 89.52845219642886, 87.12098767680507, 91.1523134477677, 81.08146329079905, 83.90032168357604, 76.99517726898193, 65.1954443993107, 3.597406706502361, 1.2448416409953948, 0.3369712505129076, 0.4827364852591869, 0.39239749732998114, 0.651415532394763, 0.5946159350775904, 0.44529945379303354, 0.3324712500456841, 0.30870147229683015, 3.4537383769789054, 1.9312315386149193, 0.4265367347867258, 2.429219945784538, 94.11560919977005, 101.18940768703338, 114.95205540810863, 107.44234823411512, 114.06405433531731, 60.68494619861726, 35.9066552500571, 38.052046606617594, 54.448671802397705, 86.84618642253261, 100.76043375076787, 92.61373366079023, 84.26164257910945, 3.763726723770942, 0.11436292300781897, 0.20787032801778088, 0.1518434376245545, 0.27457810818187656, 0.23239655630482783, 0.05300157853672582, 0.17138860819320526, 0.0845903943803522, 0.20247916811175887, 0.18189997802818977, 0.13098726079108255, 0.11971697361478884, 0.14042371733775064, 0.12038230565526795, 0.1718791802563975], [0.05138010747971074, 0.07503190002734623, 0.09814602908708396, 0.031167630278956027, 0.0631906130471297, 0.06441413590143766, 0.1410869809408342, 0.04167925866861497, 0.03425790064577614, 0.03952660139710192, 0.05093942689258726, 0.05755665689526547, 0.06959315840034716, 0.2046609558765927, 0.0747575639416614, 3.4948582995322446, 66.84386361029841, 83.22359515774636, 66.73729281271657, 55.68681109336115, 35.49471616744995, 54.41186428070069, 57.8972275026383, 66.48907738347208, 112.40145575615668, 96.39289809811501, 63.03275931266047, 1.5851548121821497, 0.2623616104885455, 0.1033729857074157, 0.1514992956072092, 0.06430669207005732, 0.08211699524714101, 0.26338945533479413, 0.4172740269812846, 0.4352673485634789, 0.05439519206242216, 0.22749091228169782, 1.2153669903355262, 0.4113562122708367, 0.6354175940636666, 11.645220902658279, 61.32410818530668, 105.90119408022974, 94.8916187594014, 100.20876807551231, 95.53979043037661, 97.72779049411898, 98.53760303989534, 100.1536273956299, 100.7245126847298, 93.7495187021071, 96.55785729808193, 91.96825273575323, 90.26883094541489, 84.77360602348082, 79.68974359573858, 74.8810197461036, 70.55604180982037, 67.27277478864117, 71.48123479658558, 75.25897933590797, 83.33077784507506, 82.9913673093242, 81.3766138015255, 76.3037810787078, 79.04434896284535, 84.82636974703881, 81.24411613710465, 87.24315381819203, 94.95372556870984, 77.2661816689276, 75.58699930867841, 77.61866154209261, 72.12953982814666, 77.83317596681657, 76.11440904678838, 76.65042446505639, 84.06695965797671, 74.44009042555287, 69.37117222816714, 67.74213344820085, 68.9179894231981, 66.88476608645531, 73.00649550653273, 67.20600035882765, 64.67955074002667, 58.371308695885446, 54.77401279634046, 66.19404454385081, 63.41218586890929, 64.53273642447688, 61.9748019403027, 64.07626667330342, 65.98957138676798, 71.61868249216388, 72.88021087646484, 76.84456609910535, 73.84125432660504, 81.78932559105658, 70.5936102713308, 75.84946078638878, 76.11065926090365, 79.03815946271344, 76.85595666208576, 76.92767327831638, 70.34204513795915, 75.1662152813327, 75.0102932222428, 76.29050777804467, 68.03223194614534, 70.10775412282636, 67.07838212290119, 72.59307769037062, 66.41930626284692, 63.63764370641401, 51.994044703821984, 64.30574494023477, 72.77725650418189, 72.45612421343404, 68.40901482489802, 69.00979641945132, 72.32326569095736, 71.43034596596995, 72.45359036230272, 73.71064724460726, 77.32549575067337, 83.26176766426333, 73.0552113440729, 73.35219752403998, 66.33569702025383, 61.896076048574145, 39.50337456118676, 4.807598619691787, 1.1710788958495664, 0.35756660505167903, 0.40330585392732776, 0.038006606346537034, 0.21415140630016405, 0.024639360321265076, 0.6116982861872643, 0.021254875802344853, 0.12702251063479533, 0.8692912444952996, 0.6225174701502246, 0.23154786878055145, 0.4686706206731258, 5.923907131918016, 64.78110090378793, 90.37304832089333, 88.29157983103107, 78.76348372428649, 82.4159477603051, 40.37975757352768, 23.21839374880637, 21.631312562573342, 41.57852803507159, 47.40563646439583, 63.22462597200948, 70.6272328284479, 49.86749249119913, 1.014366417882904, 0.011587254139744948, 0.03995231645662458, 0.09292232067955118, 0.02003461456737451, 0.06668087515619493, 0.07951827179039679, 0.07101834240940309, 0.009380496696629112, 0.01861203908770075, 0.1331138442600927, 0.004149023030373839, 0.05908657278444979, 0.02406894082894489, 0.08223770772136989, 0.04475125209278157, 0.14552259937890116, 0.08783751933444893, 0.05561133365957968, 0.07898898164351141, 0.028039505592577403, 0.10481506195520202, 0.08608405132808032, 0.004162971576255176, 0.07441352917662553, 0.08265897947093172, 0.027866092014817462, 0.06825385284760306, 0.13936731273368483, 0.1566554044163035, 4.259962199195739, 81.39262491656889, 89.6290688360891, 86.10139108473255, 74.40685226071265, 58.7263459544028, 52.14984516943655, 46.69275353031774, 76.68486287516933, 119.01484643259357, 104.93261967935871, 78.54380746041575, 1.9783371206252807, 0.24178421305071926, 0.08757368631420598, 0.11199106882897117, 0.08699199575329981, 0.2101628308094317, 0.252777099789631, 0.3985232895901127, 0.3207278882543887, 0.2936086821700296, 0.3153048437689582, 0.2273306007226629, 1.3089093902418691, 0.5379893510572372, 11.730917826775583, 66.81737192215459, 110.95624277668615, 100.85504916406448, 104.23748939268052, 97.75929497134302, 103.35807046582623, 103.45320363198559, 104.06060618738975, 101.62347285978257, 99.30367331351005, 99.49892890068793, 95.09078887201126, 92.25700978309878, 87.43232188686248, 82.69939391843735, 80.4991639044977, 73.75480528800719, 72.53317525309902, 74.57021113364928, 80.93333105887137, 87.20711508104878, 87.76016143060501, 83.36713821657243, 79.2827663113994, 83.35712048315233, 85.34728404014342, 85.3865469655683, 91.8391675333823, 95.08776864697857, 80.17400726195305, 79.47713544291835, 79.44163014811855, 74.57028958105272, 79.92114774642452, 80.35103951731037, 81.6905132416756, 86.13761025090372, 78.19954103039157, 77.64913051359116, 74.30123067671254, 71.36778416172152, 70.58698931047994, 74.28326622132333, 74.05822415505686, 70.0860163473314, 60.41552643622122, 53.85004751143917, 69.10772231317335, 67.49986433213758, 73.07716092755719, 67.6165940684657, 69.53937915063673, 68.27622690508443, 74.40161197416245, 75.62194762691375, 80.67193646584788, 85.90159339289512, 85.295147895813, 73.09355643487746, 74.82667922973633, 78.60960129768618, 82.2990454396894, 79.34382977024202, 81.2089873898414, 75.21186382539811, 80.39317361770138, 80.57609727305751, 79.5988936578074, 74.09161921470397, 74.27691982638451, 70.60667176400462, 76.24287451467207, 71.8527146308653, 70.00118332524454, 63.30912559263168, 71.60493066233974, 78.44729361995574, 74.94253035514586, 71.56514213931176, 72.32489739694904, 72.61556071619835, 75.11915468400525, 75.24143849649738, 78.27237159975114, 79.88506978557956, 86.9472502123925, 76.72196849699944, 79.68333444287701, 73.67904863049908, 73.99596829568186, 52.336691194965, 11.13367126834008, 2.762354934407819, 0.4611372797479553, 0.32095952259917415, 0.34672155796039494, 0.6637256460324411, 0.03494629193277609, 0.13219892077388304, 0.07308369247062553, 0.20310012833966365, 0.5808540541798838, 1.9329610587127748, 0.6099940776344269, 0.4908379876325208, 8.155681337079695, 75.14871366562383, 93.40437366116433, 97.2789458305605, 77.16507865536597, 48.12621901112218, 34.843210481828265, 37.97102612833823, 35.81726835620019, 54.09907879367952, 61.94023409197408, 71.95967766546434, 84.34456932929255, 59.83119133980044, 0.4392664807458078, 0.041145781851223404, 0.02673878214291988, 0.0654046492831361, 0.017337751417090336, 0.07907115223426973, 0.1669902369500168, 0.04706365018782597, 0.07616869789818603, 0.08004953844412681, 0.07609073313013201, 0.07691996202113167, 0.04008460451938933, 0.05062117098620342, 0.035695334400741324, 0.15117168576726991, 0.2805984561001101, 0.10783039934692845, 0.17468228064958127, 0.26632550262635757, 0.1420941720566442, 0.2345863879928666, 0.22459369032613694, 0.10647898194410148, 0.2208523620520869, 0.15273697193591826, 0.06861855666483603, 0.31028672271678526, 0.2735772602740796, 0.35612651297161657, 7.556702071620573, 102.9611187596475, 102.97530989493094, 93.15656615841775, 70.31956211213144, 49.758301550342196, 77.10312874086442, 83.30306237743747, 87.34955987622662, 137.8359474674348, 114.43233351553641, 94.06276702880861, 5.609516414903826, 0.30787516986170127, 0.2878429512343099, 0.2921494072483432, 0.3885154846695162, 0.4718342573652345, 1.1136587060266927, 2.180941023172871, 1.6960073671033307, 1.2498125097443982, 2.250764605499083, 5.612828856514347, 4.573150219455842, 1.5387958288192751, 12.672612224855731, 76.71271170339277, 116.42783934070219, 105.23017068063061, 109.34530181269493, 103.61271858215333, 106.88038241478705, 108.20297425793065, 108.88293281678231, 106.9615048746909, 101.8805685350972, 106.26330729453795, 99.02679320304625, 97.74156585816415, 93.80106649091168, 89.20160108996977, 84.05330196503671, 77.5244697447746, 76.6928566655805, 80.17650973412299, 85.88482918277865, 93.68470545737975, 92.16062145848429, 88.12982128512475, 83.42142381975728, 87.57417048177412, 94.34871565911078, 90.10978667966782, 93.80392197639712, 96.16350220095728, 88.59039383549845, 83.83137426068707, 88.07901090191257, 79.15348499051987, 83.17712291594475, 82.80830244864188, 84.27758309148973, 88.0381868731591, 84.18070054823353, 81.33643304148029, 76.21079737140288, 74.35971321598177, 71.63972993050852, 76.99988411318871, 74.4711006841352, 75.16968265656503, 67.99291410753804, 60.31323494449739, 69.29454480448078, 67.90204063538583, 71.83778608998945, 67.40513909247615, 69.13652819971885, 67.294645924722, 77.36104811391523, 80.23034034236785, 87.93957064228674, 89.83841357692596, 85.6214184914866, 77.93493793856713, 83.08254672634988, 83.85911326254569, 88.6758073683708, 86.79881988033172, 85.7246474296816, 78.92763491599791, 84.339321198002, 84.42065546589514, 82.85714380202755, 78.57048742232784, 80.99551631558327, 77.2564620356406, 81.71333359133813, 76.07153754080497, 75.2917468163275, 67.90189943005963, 79.78701837601201, 85.43950680763491, 81.1374512026387, 76.34555432104295, 76.90843797499134, 78.61503770274501, 79.4300199324085, 82.12591202028337, 82.93330838603359, 87.12321558306294, 91.67787182715632, 82.34624724234305, 86.312296928898, 82.00467940299743, 77.97311828982446, 58.467026295200476, 18.514726661866714, 2.6978456733688234, 0.5865391007354183, 0.6410614557323918, 0.6627239094626519, 1.1892447404323088, 0.17915401247239884, 1.2329324671337683, 0.16890233112198694, 1.521436644177283, 1.5024152326007045, 3.699513601679956, 1.7520508049957215, 0.7945559354078385, 9.950674618444136, 85.07196503300821, 106.96962418094759, 101.09000698212655, 101.85730887997536, 119.77321317118984, 54.46327086417906, 37.21805657109907, 34.94612955277966, 61.479555637605735, 70.62207098930114, 86.40931283274006, 91.29957491351713, 77.20129782153715, 1.3445493939422792, 0.22301826115337112, 0.10056577142207854, 0.20890650790064566, 0.13845330855298427, 0.2656948590470899, 0.35667509321243535, 0.1513354294002056, 0.11125272860930813, 0.2704385674047855, 0.22786811865385503, 0.1349740283143136, 0.1454615574930945, 0.20084588397895137, 0.13427368605569487], [0.1256334629931277, 0.07330753570122105, 0.06057698534981859, 0.007984543729934, 0.10502730661462392, 0.07757278384580728, 0.030232547189018903, 0.05113217844477585, 0.04213426126948288, 0.08778498102460178, 0.06932120484810683, 0.044842516147201104, 0.060039731718960314, 0.09689877665932141, 0.39742324861787987, 12.923644896476501, 80.49011107414, 78.96573681985178, 61.493833065032966, 46.690670751756244, 57.961224894369806, 42.905752197388686, 49.10969449627785, 97.22265981858777, 107.66060459998347, 90.6869948294855, 3.067664138732418, 0.102152232260954, 0.07583943330833028, 0.02184328878478658, 0.0569713503993567, 0.10551553444876786, 0.05759386961618739, 0.14180662861514476, 0.11395422276109458, 0.46466609523180996, 0.04099481656486469, 0.11490286943773109, 0.33741135270364825, 0.6394819050065933, 0.47076862906256034, 13.422682169945011, 67.87554110250166, 103.62468965591924, 106.80031899482974, 101.93661920485958, 100.25099631278746, 97.36083707501813, 98.31471043248331, 100.13922445235714, 96.2157089479508, 93.87579548743464, 91.23217290447604, 84.35901149626702, 78.94736443796467, 76.22212517646052, 72.0692922222999, 68.68962118702551, 69.78309169892343, 69.22903337786275, 72.48066256123205, 79.23823172046293, 83.20166126374276, 82.63847950966128, 77.49677781135806, 78.04630187249954, 82.31691575819447, 83.14020556788292, 87.45170624025407, 92.76836918246363, 78.00121814973893, 74.34798532916655, 75.80942907641011, 74.73559394959481, 78.34073851185461, 83.80181527906849, 85.00268813102477, 83.74573323034471, 83.22940026560138, 78.19878793531849, 81.13763163166662, 82.37462951290993, 80.20238953251993, 83.31352726105722, 75.57975076859998, 73.61364703024589, 68.59822996201055, 57.098397593344416, 55.02709196459863, 74.4928776833319, 79.95833181565808, 84.41040239026471, 73.37779491178452, 78.61539856080087, 75.56690108391547, 76.61315410367905, 66.68691389022335, 73.77456618893531, 94.62725885452764, 79.11774435350972, 67.97067426866101, 71.15512894045922, 66.7687580662389, 69.11470413208008, 69.03200487936698, 72.96038412278699, 67.60560358724287, 73.33574710353729, 77.66120356898155, 74.03282288582095, 71.45708084106445, 68.84174639178862, 64.44194924446845, 64.69553439847886, 70.71664717889601, 66.5526197802636, 61.172983184937515, 61.70639022704094, 67.12736468161306, 68.54649389943769, 68.38472750879103, 68.86507664957355, 68.69643042164465, 72.76632093614148, 71.59579153983825, 73.05590168122323, 72.28874098870062, 75.71594330572313, 72.40023828321888, 70.55468466974074, 62.95468453438052, 66.44136567269602, 35.18440177363735, 14.690000953212863, 2.0609714090824127, 0.8694261985440409, 0.06147122063163308, 0.936018544579706, 0.3356726089071843, 0.15823467935044921, 0.09312362560341436, 0.12304729571746242, 0.1014116780471898, 0.3871884058800436, 0.06805053311249903, 0.33146672491585055, 0.01876268453235107, 0.11211855352045068, 5.7357701563066055, 62.71660450966128, 93.22022622631442, 80.96272530094271, 63.41895980219688, 63.62749653477823, 24.609509398860318, 28.71488951867627, 22.397586799437, 55.358194920324514, 64.03613690407046, 51.91767223419682, 72.32363439375355, 31.771082685839747, 0.2697177399550715, 0.031196038734408158, 0.029052967138047663, 0.053418495076438116, 0.0438133153253265, 0.08502779228072013, 0.06775219549214648, 0.13227865520504214, 0.06500509612622761, 0.059536124669736436, 0.012845881057963257, 0.07129550535952853, 0.051313718300192594, 0.04419827833771706, 0.049805340972999414, 0.0447979681344042, 0.04208999670921795, 0.07225327614334322, 0.02871904090317267, 0.07720005142712787, 0.025428478763769233, 0.027616151999081337, 0.08025475041640383, 0.1003963127732277, 0.20855366312448056, 0.06796270113198027, 0.1987115170566305, 0.2407577931280098, 0.6808225834561933, 15.914306044578554, 92.17625602599114, 87.89413390621063, 72.6906035023351, 57.18471719372658, 52.560391810632524, 30.83948446858314, 56.13675794293804, 102.24752979893839, 113.19724190619685, 104.14947925075408, 6.785062522657457, 0.4293284511133548, 0.03701832611113787, 0.17855188268567287, 0.018153037507868102, 0.22959454375649654, 0.09734321490771349, 0.16161413833258614, 0.19860556709670252, 0.20944710550529344, 0.12624491606989216, 0.6271009435576778, 0.2516726767944713, 0.4907829212325235, 0.5211004831137196, 14.894331924376951, 79.07029936390539, 107.53914448522754, 110.86853857963317, 106.30770852488857, 104.9361341230331, 101.00906495125064, 100.56561746904927, 105.56978517963041, 100.21855046672206, 97.49967328963741, 90.2794841028029, 87.86168806014523, 83.54202885781565, 80.86981219630088, 74.904906980453, 73.4988078763408, 73.22375559037732, 74.33761458243094, 76.64200705866661, 84.78222739311957, 87.55004790521438, 87.385692750254, 81.58791972744851, 84.30470235886114, 85.93977374415245, 87.7378039206228, 92.25877484967633, 92.97706280985187, 82.45058228892665, 78.3636765326223, 80.7575382724885, 83.44957859285417, 81.93304123417025, 87.51692741147934, 86.58484674269154, 85.24279994349327, 83.81136232806791, 82.75078481243503, 85.73007599000009, 84.51971884696715, 83.08300172128986, 85.95299213163315, 76.51319642220774, 77.87560816734069, 73.56982631068077, 67.1388650709583, 68.33900051732218, 77.02693277789702, 81.06148273714128, 84.71003224772792, 76.53610306401407, 83.41112367568478, 79.18149855829056, 79.03391545818698, 69.32346051739108, 77.71638347256568, 94.4056292503111, 80.48590629331528, 69.30636682818013, 76.1344680478496, 70.22268741361557, 71.53888579337828, 72.54968843152447, 76.07329476264216, 69.31498035307854, 76.38105961584276, 80.24185642119377, 80.35781737296813, 75.48083643759452, 75.6610458127914, 71.28272364216467, 70.19264205809563, 76.0703137613112, 73.68337892716931, 67.82398546895674, 70.36489686658307, 71.26027199529833, 74.13705595078008, 71.35964916598412, 72.83695497820455, 71.83953546708631, 78.29100285806965, 75.84498143965199, 78.30524106179514, 78.01616238009545, 80.54715802592617, 76.52443009038126, 76.57620537665584, 71.27921704323062, 75.10722283394107, 49.82275001464352, 22.283928278953802, 4.254564037246089, 1.2870615432339332, 0.07948925237982504, 1.3654161581108648, 1.7475986697020072, 1.2517691595900444, 0.16823577334082898, 0.40132113462013586, 0.3553817222916311, 0.5281922509593349, 0.12081915963320963, 0.4392246829886591, 0.04384971599304869, 0.36830430790301294, 7.604055866118401, 76.87579601041733, 95.2075578320411, 95.25260233109998, 58.77101390592514, 33.88801136324483, 30.58560121443964, 43.53248027063186, 42.32901473199168, 68.34986548269949, 80.46711814018988, 62.8963000543656, 87.36604952043103, 38.594165232873735, 0.1747876790262038, 0.07739238546139772, 0.041953606245618676, 0.05074521977334254, 0.018953254649175272, 0.035008923451025645, 0.0476584178695996, 0.05380649945788807, 0.069702984765172, 0.014670927531927105, 0.06846805869211113, 0.014563431989611879, 0.053452781341489286, 0.014458498053793466, 0.22666382843688612, 0.15381867276324382, 0.19232577584203214, 0.1977376201220097, 0.20369977600151495, 0.21554842891712345, 0.1175834340674262, 0.18874026985178072, 0.20851990929053676, 0.23439624497006017, 0.3079649247229099, 0.16111780528820333, 0.3548438059947183, 0.4027946894207309, 0.9918385299463427, 22.911966423834524, 109.52278906299223, 99.35470334945187, 80.14644868912237, 68.9702118596723, 81.78559149465254, 60.10349796664331, 72.9586269009498, 120.6681646839265, 125.13427734375001, 118.77256162704961, 8.452698896008155, 0.724711515490086, 0.2016815326867565, 0.4637379337462687, 0.28912814033608286, 0.6097056608526938, 0.2833961785560654, 0.3540034688288166, 0.46167105917007695, 1.382026660346216, 0.1789356774139789, 0.765872071346929, 1.5111249781424, 2.533538322294912, 0.8098530565058032, 19.098055670338294, 90.81206352479997, 113.76786047412504, 117.38190097193565, 108.95563787029637, 107.63655262608683, 106.11468084396856, 106.87898605100571, 109.34490957567769, 105.4482936859131, 100.82770239922309, 97.28315845612558, 91.10918306535291, 86.47786801861179, 85.52608920681863, 79.55444535901471, 77.90010729143697, 78.59696342099097, 78.11295863120787, 80.05128414400163, 88.18985708298223, 91.61544338349374, 91.8621212436307, 86.67300593468451, 89.0835455925234, 91.92565579568186, 91.97432456477996, 91.1455120578889, 99.11578393751576, 91.21389465947306, 84.67892000752111, 85.86017316387546, 87.42677565543883, 86.00660308714836, 95.50463814889231, 91.01267706963324, 90.97581463475382, 91.8243331293906, 88.67492875745221, 86.01649530472295, 87.94308508596113, 85.08996871209915, 87.82855972166985, 78.5874242167319, 79.59018599602484, 76.25362180894422, 68.37309375885995, 65.88195723872032, 77.45224322042158, 83.43700347408172, 86.65606129554011, 78.14106633586269, 83.71193024419969, 79.63689358003678, 79.4468782794091, 71.73068969480454, 82.2619084388979, 91.70698365857525, 83.26015949249268, 73.03483855339789, 79.02265825579244, 73.15924829052341, 75.25326836493709, 74.28034797791513, 80.93599827058854, 73.02019242317446, 82.64484159408077, 83.97137934161772, 82.97369310932775, 78.07031462269445, 79.36265714706914, 76.74922112495669, 76.53215715962072, 79.66251450200235, 79.58660094968735, 74.17082755796372, 78.85380021987423, 80.78681484345468, 84.2790186789728, 78.0700243673017, 81.5027807604882, 76.12938465610628, 82.77521333386822, 82.47611691874843, 85.29998810060563, 83.16402219956922, 86.74777415490921, 83.30519614681121, 81.69757350798577, 80.25761650454614, 79.27429399182721, 60.342048675783225, 30.922258246329527, 5.142241514498188, 1.646137004417758, 0.20185503627984755, 3.227644870358129, 3.889053805220512, 2.361888539406561, 0.4559172485624591, 1.3456030406298176, 0.5621601605126935, 1.3097992779747134, 1.6775826460892156, 0.8033457218158631, 0.19433985163848247, 0.5590841029920887, 10.627192278062145, 84.98298214327905, 106.96491733674081, 99.99488123001592, 90.29214551371913, 87.18949579423474, 36.29992385064402, 42.83353744014617, 37.63061931056362, 73.30915343376898, 85.45302329524871, 74.37507321757656, 97.20630353496921, 51.87941735790622, 0.3743455240563039, 0.2093473915010691, 0.18263721508124184, 0.2126249761110352, 0.14260190448934032, 0.2565641788345191, 0.1413859237706469, 0.21945749980307397, 0.13830425848643627, 0.23972103101832254, 0.19777796231210235, 0.12652559536359004, 0.24392791092395785, 0.15301858585688377], [0.06791478999319576, 0.021455608075484637, 0.009063137113116682, 0.0786801792621132, 0.04584035715989528, 0.05500471459761743, 0.030373256473291307, 0.10303108066680933, 0.06480068854627109, 0.05819731707414312, 0.0984492696701519, 0.033122968199031974, 0.053938082719762484, 0.036371567872382944, 0.018278413542336034, 41.31357585230182, 83.5746943566107, 69.65257090906944, 76.93913444395989, 50.40729299668343, 56.36493790534235, 40.417412327181914, 54.43966211811189, 100.3457058629682, 109.92879359952866, 13.306179931086879, 0.4584439597543209, 0.3330213011753175, 0.11349460065004327, 0.11822287999694386, 0.20455332052323127, 0.13016806765189096, 0.13753800202281247, 0.04133158881637839, 0.1890658878631169, 0.2443434216923291, 0.10751986560682136, 0.5388295962925881, 0.11112198804415042, 0.6939630751167575, 0.7507882904141181, 17.73016437407463, 93.09324341435587, 101.23489149155156, 97.52445482438611, 97.0544215171568, 97.93871202776509, 96.32424877535914, 98.30989376191171, 98.0861617672828, 92.940121927569, 86.83015961800852, 80.20505674423711, 77.70499290958529, 71.96917764602169, 68.91496919816541, 68.24906841401132, 67.21885004351216, 69.67768976765295, 71.24581413884317, 76.00749308063139, 77.83181098199661, 82.26615244342436, 78.75681569499355, 80.34107669707268, 76.26552228004702, 82.51109661594515, 96.10490199058287, 85.13780593872072, 76.8062053188201, 80.32429679747551, 78.15652831908196, 78.43407523247504, 76.93214478031283, 76.6601440983434, 77.72212582249796, 79.7021225960024, 78.45529525510727, 80.47355082727249, 82.83582964251119, 86.78051025636735, 82.42367482954457, 86.73960778021043, 80.56695815055602, 76.36897871571203, 80.28490835620512, 79.31950323043331, 78.62103892910865, 87.6847577864124, 80.95095034568541, 74.51362702154344, 77.33641562923309, 77.04139063435217, 78.69026876265004, 80.35543257190336, 78.80719461748677, 76.58506208850493, 70.58247074004143, 76.70270965945336, 73.57494892612581, 73.16318635017642, 74.96148324781849, 73.80606282141902, 71.7603349685669, 71.448192750254, 72.15713762467908, 65.68121033330118, 63.46823653867168, 67.00639878549885, 72.20128782333867, 76.47918947281377, 70.79255288647067, 63.535995483398445, 61.70765323023643, 65.09234489933138, 65.97957718756892, 61.92841991301506, 58.525665729276604, 57.065579122112645, 62.289470165006584, 62.64261291873071, 61.65616819935461, 65.48086743200979, 66.44365633687666, 69.56656902067124, 69.92268885335615, 69.85084672128, 73.65814239748063, 73.54091059777045, 67.39995371910834, 69.327100476911, 58.75295139128163, 39.03046223425096, 17.20589057091744, 2.7891711986834005, 1.9966021276289418, 0.17223251532883416, 0.2221197779140165, 1.87199026586548, 0.05835185233022898, 0.25552548618326265, 0.3177372648590996, 0.0342765778693701, 0.49941535318090075, 0.34575573559249606, 0.01959264695253824, 0.25655380600402433, 0.03509646814857279, 0.3023935656153387, 9.284868951766722, 70.11379457289173, 92.04970467475154, 74.89179057459678, 83.30232497184508, 70.71430160153297, 27.1295282917638, 19.916987726765296, 27.0569154139488, 43.86837244033814, 59.20681668866066, 55.323344661343484, 69.50603115943171, 12.514577969428032, 0.5477032846500797, 0.18810424833528458, 0.34449610318387713, 0.10230311327764105, 0.009170942921041241, 0.04025870183062169, 0.14826907055272212, 0.03124179333568581, 0.060129582341159546, 0.038532169475670786, 0.06276631525026695, 0.07065796698894232, 0.08405355060653341, 0.03815089900707526, 0.01960392185156384, 0.0333484431969062, 0.0643139009574248, 0.04391043995236678, 0.08210809330546087, 0.09265817356325927, 0.07243417248490357, 0.02219038981673939, 0.045948727957664, 0.07764289621263742, 0.07265353410114204, 0.0447198846227219, 0.037585323105656335, 0.035240737826473294, 45.158824382289765, 95.28077279367756, 77.40912852748748, 84.11180803852697, 62.950695483915275, 74.3471851656514, 37.80052069694766, 62.577160327665275, 104.88394306552027, 119.46175344528692, 18.669624982341645, 0.7076403186205895, 0.11788549487509074, 0.8319700148797805, 0.22292190261425512, 0.3140760693819292, 0.2199966571624241, 0.4090580404285462, 0.08002632598002112, 0.2995416654213783, 0.04769376133598628, 0.37237937472039656, 0.8873772933598488, 0.29409303359927674, 0.46669595243950046, 0.8116224744627554, 26.125099505147627, 101.04110287081812, 105.71465399957474, 100.28000616258191, 100.82838489163308, 98.65277167289489, 101.02247945723995, 101.70158293939407, 101.58937961824479, 95.88777526732414, 90.19620433930429, 84.34449872662945, 78.51116549584174, 75.13270255058043, 71.48623974092546, 72.25283561214324, 70.06202713135751, 73.39205664973106, 76.3311827567316, 79.97681402391004, 83.14378276948007, 86.96239840599799, 83.99234048781857, 83.89851739329677, 79.19994154284078, 87.15154294044741, 96.87016425594207, 87.18367499689903, 79.75616501223656, 84.59225916093396, 83.33089551618023, 82.27366770467451, 80.70157389486991, 79.7613896093061, 81.82159100809406, 84.28235269361927, 84.25744564302506, 86.17966590389129, 87.02485038388161, 88.31078375539472, 85.8701281393728, 89.65299529414024, 82.20236685968216, 80.5529474443005, 83.00992796497961, 82.93561473969491, 79.43682916702764, 88.31058763688611, 81.25852692511775, 77.8402989910495, 80.51586535669144, 80.8513064538279, 79.67716847696613, 81.53683477832426, 80.9132642130698, 80.84486592200496, 77.55613111680555, 79.06931092662197, 71.49604566635625, 77.69656765845515, 76.49284716575377, 77.63071106326196, 75.33968602457355, 75.87151235149753, 76.23002482998756, 70.94557239163306, 68.85395280776486, 68.36212681185815, 74.75515088727398, 78.3108735853626, 75.06198221637358, 69.84813244112077, 67.05673063955, 72.43175844992362, 71.80420275657409, 68.03715844308176, 64.45446945005848, 64.82849490258002, 68.8947376128166, 71.2679833750571, 68.25888218418245, 71.1084762696297, 69.92799974256947, 76.44908920411142, 76.5020804251394, 76.68984428528817, 79.64043155793222, 76.49313742114653, 74.848432694712, 76.01649884254702, 66.86182022094727, 53.35483651007376, 33.28184827681511, 5.833218011163897, 3.134298343812266, 0.54937458206569, 0.3812208260980345, 2.2316285871690322, 0.2794642476064544, 0.4657815805365963, 0.16937286232508, 0.02649463758233094, 0.5833385079618424, 0.2796154120756734, 0.08582980206777012, 0.4146302269110757, 0.08008318502576121, 0.47003211213215706, 13.744329271777985, 82.64715579248245, 96.73833339445054, 84.4019300706925, 59.14670244339974, 31.95120184652267, 30.762535410542643, 34.32841508619247, 50.10764352736935, 54.89445701722176, 71.32889778383317, 63.18120533420194, 84.49932252207111, 15.453996293006407, 0.6502852156277626, 0.14348037751211276, 0.16970563559762894, 0.05805279458722761, 0.05693737056947524, 0.09135490478647333, 0.058867406520632014, 0.024696837983004028, 0.0700145910283731, 0.0970163941383362, 0.07396624108115513, 0.06545960076994474, 0.04071625933471707, 0.22655269972259, 0.20076809541111995, 0.15070245691364811, 0.1781749367834099, 0.1628798075140484, 0.15890853028864632, 0.17952364989586417, 0.18994783892506556, 0.22598643817247885, 0.12861297045263553, 0.21599292845254947, 0.1343915103784492, 0.12409899654167315, 0.19927863662521686, 0.1083774397510194, 60.401292154865885, 109.36976171308949, 87.2578077931558, 97.44705077140563, 65.99265436972341, 72.79634275744039, 58.54357134911322, 81.44067395117976, 117.2576089059153, 135.76262966279063, 19.319161638136833, 0.8272583902843538, 0.5253004835497949, 1.332004428390534, 0.7941448219841527, 0.5060186633659948, 0.6643955746004659, 0.9614901713305904, 0.20694975080269, 0.3630994759019344, 1.029641782083819, 0.8665078938488038, 1.7007891040655876, 0.45351406138750816, 1.89806716336358, 1.321012108556686, 32.35387629078281, 110.73729607366748, 110.4770468127343, 105.2024159892913, 103.26940136571085, 103.65341709506129, 105.13150738131617, 107.02758112261373, 106.4489060063516, 100.99755671716507, 96.00677997835221, 89.18717461247599, 83.37550855452015, 79.71299540612006, 75.87859615202873, 77.07312260904621, 75.30288634761688, 77.35957330273044, 81.38584706091112, 85.12718416029408, 86.55609576932846, 93.12896051714498, 89.28318638955393, 88.09142128113778, 83.49390922054168, 88.45718229970625, 97.71492511995378, 94.00688894333379, 88.86663067725398, 90.40608252248457, 88.534774626455, 87.29696089221586, 84.5335412794544, 87.97278527290591, 88.82715594383978, 90.4171436063705, 89.39025140577748, 90.34141048308342, 88.57976421233147, 94.03082324612527, 88.13051946701543, 94.0939812506399, 87.74506030544158, 83.41911746609597, 83.7111928386073, 85.58225754768618, 81.71290997535952, 92.9703712463379, 85.02466909347042, 80.28033487258419, 83.9668607711792, 85.65722973115983, 83.83420621195148, 85.95773819954165, 86.5792848217872, 85.17217374617054, 76.73899158354729, 80.75497304239582, 77.21375526920443, 79.60301999122866, 78.55799859569919, 81.51748180389404, 78.61267643590128, 79.48506647540678, 79.04631799267185, 74.04676298941337, 71.80379483007616, 73.52322855303365, 78.13388839844735, 84.13377331149194, 79.2378943966281, 77.12106181729224, 73.96735068290465, 77.95198455933603, 77.08354826896422, 76.5568680917063, 73.3162215448195, 73.67370636232438, 76.29796812611242, 77.954055570787, 71.07210020865165, 76.66545498755671, 74.64038233603202, 79.21723919530069, 78.74154198554255, 82.74347351443383, 86.39014028733777, 85.33429315013271, 82.36672985938289, 80.44909877161827, 74.81033079085812, 62.52317674698369, 43.26187987481394, 9.561536273648663, 3.792025643971659, 0.5809717252850533, 0.9792486409987173, 4.912795607120761, 0.7753379150263725, 1.1387762162954578, 0.7406070431874645, 0.334856326902105, 1.6276424161849485, 0.8569218662957993, 0.4509640304792312, 0.48837385050231413, 0.34221536750274323, 0.9007579076193994, 17.90856945899225, 89.8261522477673, 107.27918547968711, 97.80418257559501, 118.59430559219854, 94.6620895016578, 41.05347171906502, 28.82047776252993, 44.11113969741329, 60.88984297167871, 82.45808970543646, 74.81865406036377, 98.98389031810146, 23.097294492106286, 0.9408862059635501, 0.34927404035002957, 0.5479049189917503, 0.2604961863929226, 0.20715860169260733, 0.17439826121253355, 0.19256785962610476, 0.1606176264824406, 0.2620713857393111, 0.16256925079130358, 0.13279910469728132, 0.18369787913416663, 0.1465807659851928], [0.07082484392148834, 0.05640533782782094, 0.07860493410619036, 0.08382553219675057, 0.019079536582613667, 0.06602241492439663, 0.022009681166720488, 0.015339630359273045, 0.012294150280555891, 0.0037533367022631633, 0.04821169039895458, 0.062746565503579, 0.07724971690725896, 0.08654031031314405, 0.6966282643618122, 63.01676388709777, 76.84142820296749, 76.27923488616943, 53.91061675164008, 46.36572199483072, 36.920136867030976, 39.75728527192147, 78.61583786626016, 114.64850318047309, 48.509371819034705, 0.12374733154091144, 0.11258569861491842, 0.02442028790321802, 0.29672430047104437, 0.09054790010615703, 0.19577586813078773, 0.031152950119107004, 0.6118872953999428, 0.1779214076457485, 0.04189681614779177, 0.18187031510376162, 0.19482760449811337, 0.42135978838609117, 0.11068092058262519, 0.165377545260614, 1.3066922705019675, 62.13022193601055, 103.92212298608597, 89.45485284251552, 91.82625509077504, 96.76077719657653, 89.29584780047017, 94.97518093355241, 93.23563329635128, 91.25890777957056, 87.3500305606473, 78.7720109570411, 75.35623842670073, 70.71509392030778, 74.99522347604075, 72.51598742700392, 69.13268427694999, 72.32690565047726, 70.89064351973995, 72.2171812672769, 75.67165190173735, 78.75384253840294, 76.51139997666883, 78.68359288861676, 76.06705034932783, 83.30102274494787, 93.60867423395958, 80.19654520096319, 73.81488030956638, 82.6103796497468, 79.05646124193746, 80.06483201057681, 76.58199479503017, 73.63835011759113, 76.34239289068407, 78.92574433357485, 77.4768521708827, 85.25727348942911, 85.18411344097507, 86.04055512335994, 78.45316148573353, 85.577268292827, 81.7394801109068, 79.65706240746283, 82.79560181402391, 84.09585968140634, 82.85950506887129, 78.18055675875756, 80.38740773354807, 76.55582474124047, 76.20500795302853, 79.44796869831701, 76.47457676549112, 78.94714478523501, 76.35801176871024, 77.56726280335458, 79.77940897787772, 79.30925799954322, 77.08043390704741, 73.60978741799632, 75.52221744291245, 72.37702569653912, 75.37656414893367, 76.21548068138861, 78.33313695846066, 74.97179908137169, 75.36850760059973, 72.08998664732903, 67.8167369288783, 66.26444324370354, 64.60208392912342, 62.69640430327385, 58.260474281926314, 56.26332106128816, 62.384387600806456, 66.70837709980627, 64.17930341536, 59.5728365836605, 58.89973040549987, 62.880669409228915, 65.47686269206386, 67.90896754111013, 63.48762481443344, 63.36783170700074, 64.65358464948594, 67.7707745951991, 68.64893836359825, 67.94936795388499, 72.66483353030297, 71.04313742729926, 71.91613935655164, 55.741233979502034, 49.769433236891224, 18.649911149855583, 6.654746676644971, 2.987376898527146, 1.5158493504408868, 0.2224992212629126, 1.7280762979099829, 1.0522320602209339, 0.23797577547450222, 0.26969926191433785, 0.2353079202434709, 0.4000946584968798, 0.3339824657286367, 0.15971799411119955, 0.06778584973466012, 0.1556450723400039, 0.06687736138701439, 0.3573099655970451, 18.89417871352165, 80.12588762467908, 86.61334668436359, 77.89749499290221, 91.39728115450953, 65.54810077913346, 37.31834373166485, 24.128666039436098, 29.267602466767837, 38.42344799349385, 66.74723994347357, 59.16785970810921, 59.00801135647682, 1.5675735233291503, 0.12665965308945987, 0.06260432212823822, 0.056044667463509314, 0.04803685381287529, 0.03610573919309724, 0.04851514931708094, 0.04812927082962087, 0.03832421490862485, 0.09518290058739724, 0.0693339065858914, 0.03797685149155798, 0.06651000690556343, 0.01600370601555633, 0.04918084141888446, 0.0395917801576997, 0.07902468134078287, 0.029757072803594416, 0.019752910631077907, 0.006573736797192044, 0.07331115163622365, 0.07465638670950167, 0.026700221107251225, 0.028036173110106782, 0.00800865299571606, 0.021190053272631862, 0.07309310769121494, 0.6977331470097266, 74.38454181917253, 83.76099909505537, 84.50454711914062, 69.34572389048915, 58.92282924344463, 35.13738432238179, 33.0508206736657, 87.26433461712253, 119.63986043007144, 60.922928164082194, 0.12497510235275953, 0.11031623974802995, 0.11780431253775475, 0.23952235377603964, 0.14100376847049884, 0.5361104744576639, 0.1002914889625484, 0.2290720411486203, 0.8761457089454898, 0.13417381883388566, 0.3260665404940805, 0.15396740107286364, 0.46345800521873665, 0.1649544042565169, 0.49674492389444386, 2.364546435494577, 70.13047249086442, 107.46138741893154, 95.66117994246945, 97.26077741192233, 99.28628936890634, 92.90311828736337, 98.37204763966223, 96.09124429764287, 93.06137807907598, 87.86942297412504, 82.71785259246826, 78.69786247130364, 75.59680523410921, 76.25770891866377, 79.69434845832087, 76.41303477748748, 76.1920484419792, 73.32343870593657, 75.42902192761822, 80.93059324449109, 81.47861896022674, 79.3068967326995, 81.79505225150817, 79.62636593849429, 87.76704126788725, 95.74732303619386, 83.89428123351067, 78.88679519776376, 87.78051068705898, 82.53042605615433, 84.65931600139987, 79.94057916825818, 76.74230990871307, 79.30625346399124, 80.98405514993976, 83.04653936816801, 89.12688778292748, 87.81844785136562, 88.00832979140743, 80.66356612790017, 89.2472339445545, 84.44534286375969, 82.74172413733699, 85.3016511855587, 85.80695444537749, 83.16117455882411, 81.55199866141044, 85.17994003911173, 79.74494703354375, 79.10116841716152, 81.19843621407786, 80.4834508895874, 81.40010095411732, 79.96609026385893, 80.59388914415914, 82.36272904180711, 81.16732397387105, 81.24837583111179, 80.06899756769981, 80.60512281233265, 76.9535138530116, 78.91072165581488, 76.253935598558, 81.65181513755553, 78.07149133374615, 77.66795004567793, 76.82116523865731, 73.65470640120968, 70.06052878595167, 66.425385936614, 61.83600102701495, 60.06438409128497, 58.94683414889921, 65.90052573911606, 72.51063731408888, 74.25941821067565, 66.43810226071265, 67.2955951383037, 69.42788970085883, 72.64158956466183, 72.1444683690225, 71.24126418944329, 67.4673871071108, 69.66981364834693, 74.30490985993417, 76.99994687111148, 74.37516735446069, 77.91276085761287, 75.50506884051909, 77.911238977986, 67.684843309464, 62.96263910108998, 37.070340110409646, 8.500168400426066, 6.323338266341917, 1.603625253323586, 0.16591492529597976, 2.139451907527062, 1.72980630830411, 0.6148144867151015, 0.7321504130959512, 0.7103365803918531, 0.347468892052289, 0.5670824899308143, 0.2990897654766037, 0.04395106559499137, 0.20042577668303446, 0.06151486466067934, 0.16752671300163194, 25.869604156863307, 89.46397627553633, 95.30915506424444, 87.68010585538804, 61.811960820228826, 38.89342638754076, 33.84215885593046, 31.653254685863374, 40.968462190320416, 55.19572250304684, 83.341383934021, 68.30368349629065, 71.1977101910499, 1.6311416606749258, 0.13972268560000006, 0.06104660490828176, 0.029481493740252433, 0.018011698116277976, 0.05273542810051192, 0.03411052831178231, 0.09212331395716437, 0.03138197210407065, 0.024508309490498037, 0.029056305366177714, 0.026432952182667873, 0.08993963395515758, 0.11914044648649232, 0.15520274849428287, 0.20384700277880316, 0.1536887902165613, 0.19297895772803217, 0.17264857768051087, 0.16700218792163557, 0.15110773274735098, 0.10087214530475679, 0.08503574427337417, 0.09984706603591481, 0.0876770468969499, 0.21825975197697842, 0.2558383411697803, 1.171376505686391, 91.16719492020147, 96.14368638684674, 99.64777500398698, 68.7014118317635, 60.497723625552275, 46.30358380656089, 56.189251022954146, 103.32167871536748, 131.81430908941454, 65.19188680956441, 0.3489017829058632, 0.35200422449458035, 0.3076873863897016, 0.9175170921990949, 0.9539684136548351, 1.0845988460125462, 0.9067789296950064, 2.300056541158307, 1.6912881429156952, 0.28640331880700204, 0.5812217763835384, 0.44393857520434166, 0.7632329903783337, 0.44096112852135017, 1.442723745299924, 3.645984035345816, 85.20295650728288, 110.08239361547656, 103.07057642167615, 101.94096519101052, 101.25987698954921, 95.39774571695636, 103.6557940513857, 101.95987101524108, 100.69813866769114, 95.77717227320518, 84.62045315773257, 82.19899362133395, 78.04785513108777, 82.27850790946715, 80.81085112787063, 78.96860799481793, 79.88771346307571, 79.66251450200235, 79.74559814699235, 85.16488598239037, 86.97239260519706, 84.52521800994873, 88.28601791012673, 85.18420757785921, 91.96425191817745, 96.93616990120181, 93.93226192843531, 84.73411560058594, 88.85459684556531, 86.56027701593216, 87.27548199315225, 84.41576819266044, 83.636683494814, 88.21838055887531, 89.84819596813571, 88.45691557853453, 92.8166300250638, 91.78961230862527, 92.1617824800553, 83.50077336834323, 94.07169434332079, 87.20632276227398, 81.6974401473999, 87.67522642689367, 90.29069423675539, 86.47335729291363, 84.09449469658637, 87.83707910968413, 81.3802537610454, 79.67470522849791, 81.32610151844641, 83.2469097260506, 85.68467063288536, 82.16291566048899, 83.15287482353949, 87.69734859466554, 84.24570206672915, 85.59303622091971, 81.50445169018161, 85.57355773064398, 80.20170704010995, 83.80733797627111, 79.88627787559264, 86.02179050445558, 81.96214522084883, 81.77678185124552, 80.13077489791378, 75.74045811930011, 75.51061507194274, 74.68836076797979, 71.1900301902525, 68.46292388054633, 69.12130940345027, 74.59624782685312, 79.7044760181058, 77.34893583482312, 73.7256306986655, 73.47175921163252, 76.25828942944928, 76.3223260448825, 77.2215372516263, 74.25611557499056, 71.91326033684516, 75.05050536124938, 78.5711463805168, 80.06970359433083, 79.95116956772344, 82.80223846435547, 83.79502957867038, 87.42572446023264, 77.17107988172963, 69.1335158194265, 51.02259520561465, 17.594348384488015, 6.38484005005129, 1.7664953008774789, 0.8079860695908148, 4.518090438458228, 2.530549966519879, 1.1580949925607251, 1.4998085724730648, 1.0512079538837558, 1.4119357135026687, 1.2975641796665809, 0.6650145736432845, 0.17524704066736085, 0.45090985274122614, 0.3659903852929992, 0.5158456102494271, 34.80575969142299, 97.30376658901092, 102.89193599454819, 101.46440505981447, 130.46260541485202, 90.41126789585238, 54.375900068590724, 37.996046927667436, 48.1582373188388, 57.335528404481956, 91.03890203660535, 77.85181506987541, 88.69914547089608, 2.8307804369157363, 0.28500628086828417, 0.1623702517920925, 0.13206962045402298, 0.17120430276038187, 0.128122452015598, 0.10407679834433141, 0.2179271472437728, 0.10813379314758124, 0.20526208974901708, 0.1508703987084089, 0.09633518875606599, 0.09331225943300994], [0.03816189619922831, 0.02748052187774691, 0.12519055692058417, 0.15343671664595604, 0.022417525310189496, 0.10544392054960613, 0.06794898815813565, 0.042947176318134994, 0.06846483346194991, 0.06843887074219604, 0.01783900083072724, 0.09113378882888826, 0.02679889323189855, 0.027273519174946893, 5.74121440610578, 70.64765268756499, 73.35096589980587, 70.11528507355722, 52.73964412750737, 51.95733916374945, 77.84670814391106, 69.76028703874158, 97.05541779918056, 95.96783084254112, 5.315082227030109, 0.1549227893232338, 0.12500468866839526, 0.09371936621685183, 0.0846601773293749, 0.11788482071771739, 0.30733143129656393, 0.06610913607742518, 0.3217359986757079, 0.48977775258883355, 0.08348649232498101, 0.16085361220663594, 0.33231417137768965, 0.7217487164082066, 0.034449617979266954, 0.18772655166685584, 22.17775756312955, 106.73419567846484, 83.8401682146134, 88.35982907202937, 91.1899289777202, 96.50114767013058, 91.21194131912725, 90.76486172214632, 89.71099145950811, 82.7334322467927, 75.42110658461048, 76.00126435679775, 69.86487311701622, 77.77717236549624, 81.04737004926129, 83.07073254739085, 82.69123538847893, 79.89983358690816, 76.50049578758978, 77.18032883059594, 75.74048949826148, 77.94417119795277, 73.27899825188422, 73.9762544631958, 79.24504095508208, 89.92696500593617, 80.71021095398935, 73.79583328000962, 84.15767623532204, 79.03382916604319, 78.90202183877268, 79.23751784909156, 77.17635154724121, 75.76222727375647, 75.39594850232525, 77.62160331972184, 80.79556172893894, 80.69861642775997, 82.07801988047939, 79.45965736143052, 85.99211385173183, 76.5254734408471, 77.38285649207332, 82.90556938417497, 80.7495915505194, 75.66131253396311, 70.78264497941541, 72.75667975025793, 79.54969144636586, 80.68599424054547, 77.69725015086513, 79.23788655188777, 78.07901443973665, 75.4797617081673, 75.77884243380639, 77.17623387613605, 76.47114076922017, 75.89409735894974, 74.18162192067793, 75.84310654670962, 77.6774735604563, 77.36554315013271, 76.46074648826354, 74.56492377865699, 71.40615278674711, 74.65593845613542, 73.48177694505262, 69.18587161648658, 71.27354529596144, 64.87120951375654, 57.75771271797919, 57.9717525359123, 52.734960817521625, 50.658501194369414, 52.00225030222247, 58.214633541722456, 65.37905054707682, 64.0099197818387, 60.38887393090033, 65.08662608362013, 66.39588186817785, 65.14922318920013, 64.27582117819017, 62.14258132442352, 62.06098033535866, 69.09156999280377, 69.24429139783307, 69.75649802915513, 66.0769147257651, 65.10662624912878, 68.31062609149565, 60.62871902219711, 51.83010924247004, 34.01496279624201, 11.267346624405155, 3.5683895022638383, 2.274325792827914, 0.34801079200640805, 0.3566955017947382, 0.28842735374646805, 0.3049185301267332, 0.08237171948196427, 0.27541752604226916, 0.6379154084190246, 0.24976300346034191, 0.04727055904485526, 0.11378341579749701, 0.17338973710373526, 0.16109393398848273, 0.04841523612999628, 0.9589091291831386, 34.92435255358296, 89.00495698375087, 83.37904653241559, 64.78414466304164, 72.50793872341033, 77.30899041698825, 35.45031885946951, 55.24328908612652, 54.673737402885195, 30.776324502883423, 55.08803775233608, 74.69332648861793, 14.945838528294718, 0.6303481757640839, 0.19628392232041206, 0.12805309041493362, 0.10261288092982385, 0.15126729354022012, 0.06061347411765207, 0.02342359410719045, 0.08607629085740737, 0.03457659705271644, 0.060068689842498114, 0.026016550837084654, 0.02182271740879984, 0.043696801012922684, 0.06564512428256773, 0.18915570401135953, 0.032766748805560415, 0.0098695375415827, 0.05658182916381667, 0.061431529616276105, 0.028898644471360795, 0.012528462102636697, 0.04025862522182926, 0.02527243048403292, 0.06702653402763029, 0.05157616853173222, 0.11234869399378378, 6.026731575689008, 82.9596588688512, 81.10764118932909, 82.99028473515665, 55.492602779019265, 63.575893832791245, 43.273584227408136, 59.853776347252634, 108.49210785281275, 107.0549592664165, 7.491034730788201, 0.5066957931605078, 0.13110752127343608, 0.2006435601581489, 0.1393025016952907, 0.31156783623080103, 0.07865669100635475, 0.28918244064815585, 1.0506385973384305, 1.5253894127184346, 0.2278721942416122, 0.17891859365326745, 0.9880082128990082, 1.943666555227772, 0.04699096759600986, 0.23969556625571944, 29.59896233774001, 114.36825767640146, 94.90111873995875, 96.67201395957701, 97.30229962256648, 101.31537852748748, 95.3232991310858, 97.78548855935374, 95.352826733743, 86.98113164594098, 78.13810886875277, 78.1769089544973, 73.31082436346239, 81.60987715567313, 85.4798601519677, 88.29659262011128, 87.67324955232682, 85.48612809950306, 81.17271331048782, 80.97788133928853, 78.3273946085284, 82.78530166995141, 76.80695841389318, 80.54268652392973, 82.12057759684902, 94.80393809656944, 83.53718865302302, 79.70387981783959, 90.30289280799128, 82.8052822236092, 84.40862947894682, 81.10522500930294, 79.6510454916185, 81.60615090400943, 79.9069409216604, 82.66122141192037, 85.35465025132703, 83.79958737281062, 85.2425959802443, 84.14608955383301, 85.70475316816761, 78.3497364290299, 80.27891497458182, 85.85557614603351, 85.09818999998032, 77.22739727266374, 71.1181253002536, 75.52683015023509, 79.92113205694383, 82.34388597549932, 81.70349628694596, 82.76214399645406, 79.60840932784542, 77.92803456706386, 80.95135042744299, 80.1480019477106, 78.88461435994795, 78.30156187857352, 77.87680841261341, 77.83237580330142, 80.00260753016319, 79.83449474457773, 77.62961279961371, 75.69907711398217, 75.1708750570974, 76.53538134790237, 76.30654242730911, 72.7825987723566, 73.38345881431334, 71.4444508091096, 67.28047047891926, 64.46085114632884, 61.52538461069907, 59.69789351186445, 57.056126209997366, 62.87265992933705, 66.52968960423624, 70.07279795985069, 66.72715740819132, 71.60413834356493, 70.90536809736683, 72.17189358126733, 69.48210470138058, 67.22946397719845, 68.94277880268713, 73.58580604676278, 75.55573801840507, 74.19580521122103, 73.30141851978918, 75.07058789653163, 72.37537830106675, 71.7959108660298, 64.92129818085702, 52.19527798314249, 17.578896207194177, 4.780556328835027, 4.112874298326431, 0.5487797914012786, 0.5705704576065463, 2.254173880623233, 0.5826919297537496, 0.4553947765980998, 0.5551089646835481, 1.265053124197068, 0.08895387797946892, 0.05101747209987333, 0.34567655274464243, 0.15066226794114038, 0.1722792926574907, 0.041881689741726846, 0.929377849303907, 45.52913535025812, 96.99301288973902, 94.57432254668205, 67.66980494222334, 46.92469112334713, 38.629411651242165, 28.658093598581132, 56.18683876529817, 58.56293216828377, 51.862829654447495, 61.80857581477012, 90.47551631927492, 17.41243277826617, 0.7254312704167059, 0.1693518715159547, 0.15663910206527482, 0.08919263694195018, 0.0530014866061749, 0.13976967743327542, 0.06481502971221363, 0.08171198754421166, 0.025553971626645616, 0.04379925761191596, 0.04585422335132476, 0.0655823510380522, 0.11269607656304875, 0.19030238441642255, 0.24693220132781615, 0.25887358152577955, 0.12161265052254162, 0.2076012626170151, 0.21007545082078827, 0.1518857256779748, 0.10217724503168177, 0.2012877175284009, 0.1467190908208009, 0.2650960234384383, 0.12181058465953797, 0.31790807182269715, 9.32452509480138, 97.36673631975728, 91.08046347095122, 88.7751688495759, 69.05204034620716, 67.6555981174592, 99.63759253101965, 101.90568739368071, 115.86104900606217, 120.47565475586923, 7.262192868417309, 0.5113586026333994, 0.1999351126892913, 0.5464531517317218, 0.5572371569371993, 0.7011594599293125, 0.8821772111039009, 1.1673878229433492, 1.8516560860218543, 2.056974023580551, 0.6883091623744657, 0.2482588970733266, 1.59594647826687, 2.6962752544110824, 0.20430326942474614, 0.21098720270299146, 36.60884580304546, 118.52139657543553, 97.16019999596381, 103.58266538189304, 99.58342459893997, 106.73337198072865, 99.20408433483493, 103.0469794427195, 100.22597159108808, 91.67326696457403, 80.17352873279204, 83.4917676064276, 77.281510291561, 86.83485861747496, 87.78608045270367, 93.22396816745882, 91.78435633259436, 90.14806116780927, 83.68798809666788, 85.00242140985306, 85.09213386043426, 87.33986377716066, 82.98682520466467, 85.57023156073787, 87.15898759903448, 94.73500636316116, 89.97899132390177, 85.04979579679429, 91.21653049222886, 86.40280954299435, 90.04316129992085, 87.43405557447865, 85.79664645656463, 88.84469678325038, 88.6281035023351, 89.7227664147654, 87.41084298779889, 89.12116112247591, 89.88264222298899, 88.01551557356312, 91.02404409839262, 82.13520803759175, 82.27759007484683, 89.7421350786763, 88.02612166250907, 79.23595674576299, 72.04528731684532, 75.27440209542551, 83.57106224183114, 85.74720105817242, 83.09595338759884, 87.73599963034354, 82.72823902868456, 81.97183347517445, 84.5639318035495, 82.45678747853925, 82.61912653523108, 82.77802959565194, 79.1295506877284, 81.39664926836568, 83.15432610050325, 86.22080372225854, 81.81993576788133, 79.8373031616211, 80.33821336684689, 79.63821149641468, 79.98865173709008, 75.92902214296403, 81.5884296355709, 77.13029507667788, 72.64244464135939, 70.51834783246441, 66.63644867558634, 65.8676484323317, 65.49122641163488, 74.7347310281569, 78.71491693681287, 75.16844318759057, 73.76413268427696, 76.87602350788733, 76.29161388643327, 77.37134825798773, 75.78656950304585, 70.9770219556747, 72.26276705341955, 77.79392088613203, 80.66893977503624, 80.47779483179893, 75.74929129692816, 80.00697705053514, 83.30804378755631, 81.68526511038505, 71.49000521629088, 59.92479478159259, 31.08616428990518, 6.993498254206873, 4.452009777868948, 0.5559845725374838, 1.8927863047968958, 4.936927009013392, 0.9185020361215839, 1.6168377572490324, 1.6046183484215892, 3.096082446075255, 0.6121334854152896, 0.16755041576200919, 0.5625181993649853, 0.2729548904443941, 0.41707125882948604, 0.24121330900778695, 1.9698739941081695, 52.98050119030861, 106.28959501943281, 100.80015167113274, 86.76678196076425, 102.56226862630537, 103.38095357341152, 57.06169989801223, 74.09660062482281, 66.52846582474248, 47.14490867430165, 74.26159904849145, 101.91579926398494, 21.04515160283735, 1.062321989767013, 0.4500876565373713, 0.21744201440484295, 0.27260723974435563, 0.2465377732991211, 0.318669501932398, 0.11009215136929867, 0.18332689339595457, 0.1019977429701436, 0.14397559206812613, 0.2884249635521443, 0.2601501904428005], [0.05307891128224231, 0.045584096918783845, 0.03196570428929502, 0.08513700577520555, 0.06104485439737478, 0.05986457337595283, 0.12547485214928467, 0.02263206823338424, 0.05760052692024939, 0.020889926836976123, 0.036341587021466226, 0.04885822647221146, 0.10276762302964927, 0.16370770341205984, 9.697224786204677, 75.17362856095838, 63.681582097084295, 81.39661004466396, 87.16877783498457, 53.956096633788086, 46.91383008033999, 73.36679658582135, 113.19816758555751, 35.13437194208945, 0.023616069867726297, 0.21090031301061954, 0.16682764244896753, 0.12714881555087146, 0.16131035382709197, 0.12904679072239708, 0.08034619833192519, 0.048735905213341604, 0.31702734650142733, 1.0273560208659018, 1.059962806682433, 1.439249505919795, 0.2895444018706199, 0.09454384536272097, 0.10344427018876999, 5.2034937374053465, 95.00666187655543, 83.6471248442127, 81.67758510958764, 87.33782414467105, 98.69464689685454, 90.30465002982848, 95.00547732076338, 93.91199111938478, 85.54911351973011, 80.22825364143618, 74.21151822613132, 69.69195150559949, 72.63664737824472, 79.75965592168993, 87.0318635817497, 90.12571150256743, 87.02252049599925, 84.29656736312374, 82.32634513608872, 80.75849533081055, 80.67467428022816, 79.26069121206962, 75.64340299175632, 78.04815323122087, 82.64375117517288, 86.36695123487904, 69.85266670103996, 84.03990314852807, 77.94970173989573, 78.27390132411834, 78.77271698367211, 74.75902618900423, 73.25350284576416, 80.3267365117227, 78.6897196308259, 77.72464398414859, 80.208218174596, 82.74059449472736, 87.01895113914244, 79.47920645436933, 77.73669350531794, 79.03222883901289, 82.61547088623047, 78.02804716171758, 73.87992889650407, 68.01149045267414, 69.77242285205473, 72.04103546757852, 74.28163451533165, 76.03665198049238, 79.57391600455009, 77.88525719796458, 73.88398462726225, 73.69625214607485, 78.1774502415811, 75.36045105226579, 78.48010816881734, 77.60192086619716, 72.755338299659, 70.27128558005057, 76.18216406914496, 72.62943021712765, 73.91609314949282, 72.81908465969947, 73.85513951701503, 74.03826713562012, 73.64879931173017, 71.52292174677696, 64.39998380599484, 63.57048488432362, 65.49140291829264, 60.65453998504147, 62.12806463241578, 54.6066217268667, 48.863742274622766, 45.0103352146764, 47.72741594622212, 58.894348913623446, 64.82836546436434, 67.48757946875789, 66.4617855318131, 66.99893059269075, 68.49929209678405, 65.73604114593999, 66.11209838621079, 67.40556270845475, 68.95691502478816, 69.89219634763657, 66.82780542681294, 67.3416123851653, 58.96067619323731, 63.83843768027521, 58.82217338008266, 44.391318521192, 16.64128891883358, 7.474012134536621, 2.0366561460879544, 1.5262389735829447, 0.4996632592331979, 1.416856572031975, 0.3701017033909598, 0.10681121129422419, 0.09318518842900954, 0.44119279350965257, 0.4388550608869522, 0.10803001121647897, 0.10337639479867874, 0.1735867749178602, 0.04389720195303521, 0.08376501125073241, 0.024610781411249793, 4.689055767751509, 60.956154561811886, 81.56868442412346, 81.26584606785929, 55.04373065886959, 94.01401981230705, 48.72842050367787, 69.35185063269832, 66.77307267342844, 42.62052920556838, 60.9467016496966, 69.14331390011695, 28.9129162603809, 0.6194185525659592, 0.24738063855517298, 0.07078765801364376, 0.045289658685965885, 0.0743583478634396, 0.07655950999187847, 0.13623087216288815, 0.06270388291487772, 0.13129774090503493, 0.010371312683057642, 0.0185295237573765, 0.05573424480615124, 0.03667731356296328, 0.019094199505484393, 0.04337833060192005, 0.05350681352278879, 0.06571331376870794, 0.07316340391914691, 0.04557549375139418, 0.07000860022080523, 0.03550784587259254, 0.054394311061309236, 0.03586161761514602, 0.07387837079624016, 0.06541106143906232, 0.39033874328578677, 12.510375149788397, 88.41973150930097, 70.98217595008113, 87.5459215717931, 77.9242612469581, 51.333188087709495, 37.51294820539413, 77.44195876582977, 121.35122975995465, 44.196227673561346, 0.08959520848528033, 0.4047053739909203, 0.3132813297692807, 0.12731031454618902, 0.5095790416723298, 0.04929919817274617, 0.04512303456243488, 0.10619214330349239, 0.17935397674239453, 1.1921779378767938, 2.1633631663937725, 2.8436249734893924, 2.376811932171545, 0.6568803746373423, 0.09939354198474078, 8.486094936247795, 105.5211477894937, 91.93244934082033, 89.75286668346774, 96.34816738866992, 101.69285958813083, 93.5315525916315, 99.04262388906172, 98.2149253352996, 89.19402307079685, 85.55567956739857, 77.64531796978366, 73.72920790026265, 76.11204777994465, 84.34664818548387, 92.13118014797088, 93.12507737067439, 90.2870778114565, 90.32580729453795, 86.81283843132758, 86.24082349961805, 83.62707368789181, 82.86010126913749, 81.96346313722673, 82.95699950187438, 88.48474871727728, 91.00202391224524, 76.36984163714995, 85.87904760914465, 81.69401984060966, 81.85045965256231, 80.48552974577873, 79.7504932649674, 74.8799999298588, 86.53627211047758, 82.4176343794792, 81.57668605927499, 85.36252637063303, 83.86790721647202, 89.22838303350633, 83.35629678541615, 79.07251158068257, 83.21377354283487, 84.80107045942738, 83.99941644360943, 73.1174672034479, 69.05078518775203, 71.83122788706135, 76.24930720175468, 76.88492728817847, 77.03866066471224, 78.82965410909345, 78.99174997883459, 76.46434722408172, 77.47586373359927, 78.74579383480933, 78.05306403867661, 76.590208238171, 80.4369943372665, 77.40708105025753, 75.87163786734305, 76.72062704640051, 76.83011608739054, 74.26856517791748, 75.31444949488487, 77.70189423714915, 74.5231270021008, 76.96787757258262, 76.13372279751685, 71.46691814545663, 69.72113393968152, 71.87908864790394, 67.83070841143208, 67.81256352701496, 65.4700848364061, 59.288460823797415, 56.85931344186106, 56.45539952862648, 62.296761851156916, 66.98791657724689, 70.23973403438445, 67.87312492247551, 72.36395635912496, 71.20323288825251, 71.9837845525434, 69.59970520388696, 72.92151343437934, 72.76466569592877, 76.07025100338844, 73.65935048749371, 75.27421382165726, 67.0263401154549, 71.0437257828251, 70.12522435957386, 59.92942317839592, 34.826116792617306, 4.851335008298197, 3.8293533700127758, 1.8903758857519397, 0.8817844837903978, 2.3703103584627954, 0.6647048902607734, 0.07847430079334206, 0.01948573555226528, 0.5860863734156855, 0.5500301694677723, 0.12389242859377016, 0.07147562795228536, 0.21802444041015642, 0.06364268536168723, 0.1594920134952953, 0.022393872345527335, 6.027302770845353, 75.92014974163425, 89.88383462352138, 97.18138863963466, 57.570078296046105, 66.83127280204528, 28.61237837422279, 80.54626372552688, 74.55857738371819, 38.26377222614904, 69.74112233807965, 77.51875877380371, 34.388509719602524, 0.6720083435216259, 0.29673263550766055, 0.07160629190865063, 0.12458279638761476, 0.081564967610663, 0.04139424331726567, 0.1327304632192658, 0.07117996397878855, 0.0650638320873822, 0.06704772401961588, 0.01693836871474501, 0.16320801490256864, 0.25502955150460044, 0.1502589379707652, 0.19173899845730877, 0.31225305591379443, 0.23908715454801438, 0.1874353769685953, 0.26073566547805266, 0.22992822101279614, 0.17040069184957013, 0.21730338313406516, 0.09452839336928823, 0.35749569595340763, 0.2531091529395311, 0.8109451301636235, 17.140177142235544, 104.8750549747098, 81.87400956307688, 98.67520763028054, 101.00676644232966, 66.52590059464978, 66.74551410059776, 97.22973577437863, 130.06978788683492, 51.86413972608505, 0.3866158011219194, 0.6821562506018147, 0.6022537091085988, 0.6002104606839919, 0.9974312782287599, 0.467502459162666, 0.4045042605890382, 0.3291901261095078, 1.3605047377847856, 2.1784704202605836, 4.487007125731438, 4.479279566195704, 5.848806981117495, 2.0351035003700564, 0.16075722302400297, 11.84251416114069, 109.40620053199031, 95.45544378219113, 98.19219127778085, 99.06816636362385, 108.50551451406172, 100.16613975647958, 102.70147354372087, 102.4336305741341, 94.07952339418473, 90.84545073970672, 83.89291624869071, 77.27605035228115, 79.9815522470782, 87.31199925945651, 95.00191580864691, 99.355252481276, 93.65206349280574, 93.807083406756, 92.06202876183295, 91.5297317504883, 88.23362288936492, 88.40183765657487, 86.64157990486392, 88.34855618015413, 91.53143405914308, 93.99526303814304, 83.67469910652407, 89.22682193017776, 88.65516001178374, 84.24498819535779, 85.28914666944935, 82.45670903113582, 80.2472222235895, 93.04383723966538, 90.81674683478572, 87.58162298510152, 87.887677684907, 88.29105423342797, 93.03159944472775, 87.47311453665458, 83.69977089666551, 82.07163426183885, 86.41878927907636, 86.33622338694911, 74.9516067197246, 69.84150363552955, 70.81010157062163, 77.26014906360258, 79.62525198536535, 80.90443103544175, 84.11264742574384, 83.90961770088443, 80.88138318830921, 78.3654494439402, 83.72925927562099, 80.97813237097957, 82.84452945955339, 83.6325022482103, 79.21250881687288, 78.20656207300003, 80.87879442399549, 78.0852980767527, 76.6846981356221, 79.03280150505805, 79.5163748341222, 80.15078683053294, 79.97835943775793, 80.46232500383931, 74.87267294237691, 75.81026061888664, 74.45214779146256, 72.59799634256672, 75.44963006050357, 69.2942859280494, 64.27562113731139, 64.14841475025301, 67.86079299065375, 75.48477449724751, 76.5104115393854, 78.16591847327449, 76.5297802032963, 77.67122130240165, 75.53321576887562, 77.21005255176176, 74.07188184799688, 79.14384380463632, 78.3726038471345, 81.52552266274729, 76.78008233347248, 79.5576773920367, 72.9701586692564, 80.79086272947251, 80.01541799114597, 63.32281858690324, 46.782842528435495, 10.420127414887952, 5.068983406789842, 1.9493506824777973, 1.3946362224317368, 4.668056378441473, 1.071026342049722, 0.31991047243918147, 0.3320469599097006, 2.7030869405115805, 0.814443210199956, 0.3119037504638395, 0.3877408778475177, 0.5600426322029484, 0.382727874262679, 0.2646552470903243, 0.2012567522545015, 9.878092138997971, 84.39805476896225, 98.74293911841609, 105.44080195888397, 75.83038237787063, 123.94407333866243, 72.7405901878111, 83.93416389342278, 77.00369665699621, 60.59666541314895, 79.07946202062791, 89.86892177212624, 39.63848060177219, 0.7667763002457157, 0.4473089943489721, 0.15416554205359953, 0.22076862864196303, 0.2131254000649337, 0.19440173622100584, 0.257903131986818, 0.278390345554198, 0.2072763953718447, 0.21487002741665612, 0.08176231185995764, 0.2238593031201632], [0.09986964264704336, 0.08736825217643092, 0.07180519131643158, 0.07653959170584718, 0.03618869119353833, 0.06412416396121826, 0.01804945284440633, 0.03249051282182336, 0.08935746075885911, 0.0635981718228469, 0.009460880387304051, 0.11487960334747069, 0.1305317295895469, 0.14192790033355837, 5.663879484899583, 71.13084162435224, 67.29694443364298, 73.75169877083071, 103.4516582181377, 69.03187151878112, 62.380571134628795, 99.65602767082953, 85.46717520683043, 3.1796473168557693, 0.23537228695086895, 0.06718923578098898, 0.14744325841386474, 0.1687402115954507, 0.012942502939803226, 0.07224113364974338, 0.049101241053112095, 0.05013811807598799, 0.23800366107494603, 0.10957034590143351, 2.9203754615399147, 1.3750360161066058, 0.7724278227936837, 0.05349462889435311, 1.071174166375591, 61.76344110119728, 83.55170142266059, 66.0642925385506, 84.35083727682792, 94.82408338977446, 82.95586985926475, 95.37624328367173, 94.08642676568802, 91.33532339526762, 86.70329447715514, 78.10844006076937, 72.4707232752154, 69.15436713926255, 72.0696295461347, 78.7519754902009, 88.22775502358714, 86.69554387369465, 88.38092357881608, 86.6361278103244, 85.69813220731675, 83.52298967299923, 82.22950181653424, 78.84002485582906, 76.92872447352256, 75.97249769395398, 87.97715479327788, 74.79345675437682, 80.29876216765373, 76.14142633253529, 77.1418817581669, 81.81194197747016, 79.70552721331197, 76.84317758006435, 78.74997508141303, 77.44798352641445, 71.98481221352854, 73.86723610662645, 83.64579123835411, 81.46179983692785, 76.04420646544426, 73.48882936662244, 79.14764850370346, 81.24009178530785, 77.53490324943297, 77.78011414312547, 67.29363395321754, 74.1281129467872, 73.76217934393114, 78.99295022410732, 76.10415597115794, 76.09381660338371, 73.70257500679263, 74.57816570035874, 75.6085095867034, 70.60067838238132, 68.4457125202302, 71.51088007034795, 71.84426584551412, 75.00427630639847, 75.90569972991943, 74.62557931100169, 72.46323154818627, 73.60544143184539, 71.26933267039638, 72.34880816551947, 73.3043916763798, 74.2146953459709, 70.48863980077928, 71.23807138012302, 71.9967911320348, 70.15176311615976, 70.54192912194037, 68.56808262486612, 65.65406753170875, 67.55134151827905, 62.364006965391106, 57.23251127427625, 52.07078195387318, 53.49186451204362, 59.05907277138003, 62.8205983100399, 62.62533880049183, 63.89763409091581, 64.7756919553203, 66.819976375949, 65.46030244519635, 72.3606066549978, 70.13780732308665, 71.33583253429782, 67.7827613584457, 63.80153994406424, 61.37394582071612, 53.43861441458426, 56.81023282389487, 55.2929659043589, 30.12095920501217, 17.62942614093904, 2.8552165579411293, 1.9866147925776823, 0.49337278871286305, 0.9102824642773598, 1.282642012642276, 0.4227981644292032, 0.27745210235157325, 0.17508417037465882, 0.05877916085263414, 0.04067922281401773, 0.0025102216280966758, 0.20794561913897916, 0.16050410757382072, 0.07550281427440143, 0.11199173532546529, 0.3401538248985045, 17.397621908495505, 80.51774024963379, 78.72972780658354, 48.45270533715525, 31.92004449905888, 51.632096229061005, 22.902860641479496, 25.30230783647107, 77.93926039049703, 54.79315396278135, 69.82167997667867, 28.21493833295761, 0.1577699397720637, 0.045991716981535, 0.030469693536419543, 0.05336106146475481, 0.10470216357780081, 0.07483522993542495, 0.08413179882711942, 0.08312266950886096, 0.026667304224364703, 0.031930715138573325, 0.018055671563131676, 0.05972296968402882, 0.04308826673114973, 0.01677553481121938, 0.014300621696747841, 0.05352254896875351, 0.05284740717240399, 0.08447056290723624, 0.03697586951837425, 0.038802682782613465, 0.05797626623403161, 0.10820376761858502, 0.044132992324809876, 0.1469890908488343, 0.0905586329979762, 0.288666955405666, 8.773596825138215, 80.03623793202063, 74.36870328841671, 82.93803091972106, 102.4517362348495, 51.43972358395977, 45.08714698976086, 109.97379887488582, 94.55654636506112, 5.755448687461115, 0.3880412456008696, 0.11289194992352879, 0.5022363034227203, 0.16042539970048014, 0.2040754501978236, 0.15149266128578495, 0.16690711641023237, 0.24186531111838358, 0.583008783719232, 0.551478443366866, 4.68375321357481, 2.461986935907795, 1.8009382462309254, 0.0604735060234464, 1.4636808465565405, 73.09170507615613, 90.37373081330331, 77.13512743673017, 96.30291108162173, 98.494551104884, 92.2295767261136, 100.23276513622653, 97.77503152047434, 93.76040720170545, 92.56275853803082, 84.12625805024179, 77.11418982475035, 73.21636584497267, 75.27265271832867, 79.18990811994, 91.26638381711899, 88.91165164209183, 93.16082585242488, 93.41552888193439, 92.67908034786102, 88.8611707379741, 88.70167147728705, 86.14023039417883, 83.11125063127088, 80.69183857210221, 92.9753291222357, 78.73259113680932, 83.64382220852761, 81.15213655656385, 84.16259488751813, 86.74556978287237, 85.86350717852193, 81.01952906577819, 84.58705025334513, 80.53211181394516, 79.67443066258585, 81.01317482609903, 86.60107751046458, 82.24275158297631, 80.19365049177601, 78.62070160527384, 82.86384321028187, 82.6889996374807, 80.77078803893059, 79.1874997846542, 69.45443630218506, 76.4410718794792, 77.91815803896996, 82.09901240564163, 78.43036467029204, 78.6152102870326, 77.96653655267532, 75.95618847877749, 78.39409059093845, 73.83478241582071, 70.68669596026021, 74.25050658564415, 75.89640371261105, 76.81099061043032, 76.29584220147903, 78.18706789324361, 74.7114949072561, 77.56640772665702, 73.58566484143658, 76.98849355020832, 75.26277619023477, 76.82590346182548, 71.97458267211914, 75.16901585363573, 74.9344345831102, 74.50539004418158, 73.64239800360896, 74.2362448476976, 69.51077722734021, 70.99799879135625, 68.66516913137129, 63.987742700884425, 63.48950755211615, 63.48878191363428, 67.09776647629278, 68.35793772051412, 67.85187352088191, 67.76517345059302, 68.67214310553767, 70.97918710400982, 70.68965342737013, 76.35657618122717, 74.14994485916631, 76.27022127951346, 73.859509037387, 69.0188963182511, 70.8593822294666, 62.84523079472204, 64.17749520271056, 66.49696134751844, 54.54926490783692, 18.44315517333246, 2.1621271294932214, 3.423732000012552, 0.6381199232512905, 1.2609190686095146, 1.3243575225914679, 1.3488675557797956, 0.5321792176654262, 0.18107123943346162, 0.15585108870460143, 0.07735142274008644, 0.07013358746565158, 0.36068341844985563, 0.2594401495110604, 0.41712994116448593, 0.01775159785944608, 0.24903210961530287, 23.664606501979215, 89.86121039236747, 91.20232366746473, 58.83449746716408, 40.60361900637227, 42.3912117558141, 25.543635583692982, 40.51795051943871, 76.97382388576385, 65.75706112769343, 79.64145921891736, 34.51685359401088, 0.30960885747786493, 0.06341383957694616, 0.07009446335535857, 0.08135763357483572, 0.07054217279918733, 0.05840497286689859, 0.025640369107526158, 0.06387682481398506, 0.040668807848687136, 0.03958717596927478, 0.0221598765347153, 0.060802284147470236, 0.18204590245600671, 0.13862826771313144, 0.11786636565962147, 0.2017976103290435, 0.1220478880549631, 0.21881921066632196, 0.1531116348961669, 0.14252359498172038, 0.19823280403450613, 0.3054754454041681, 0.08818418178106509, 0.35909495046061857, 0.2558717885685544, 0.5831542178507775, 11.166335786542586, 95.8958004366967, 87.07024005151565, 87.31302692044167, 111.83173933336812, 83.05523134046986, 86.70711486570298, 120.58825815877607, 106.47768051393571, 6.940440352885955, 0.5296232419148569, 0.28281496296967235, 0.4622060030458435, 0.4926070991543032, 0.5406219356002346, 0.4945646989489756, 0.24352105694913098, 0.5802102951753525, 1.6310865023443777, 1.071299804795173, 7.784956068761888, 7.0801174256109425, 4.142760307558121, 0.37697820052985226, 1.8097648048593153, 85.58723895780503, 95.19225274362873, 83.36978973880892, 102.18716452198645, 103.90946157516973, 97.47129101907053, 106.88071973862188, 102.18906294914984, 98.2151371432889, 95.60545875180154, 86.4017818820092, 81.77342430237802, 76.64067345280802, 81.6852572656447, 84.1126552704842, 99.68898342501734, 93.8446440235261, 98.36802328786543, 97.54893825900172, 94.17788859336608, 91.54809628763508, 93.86687601766279, 89.4117146153604, 88.00522327423097, 86.50482254643595, 91.89015834562241, 84.23038128883609, 90.04797012575212, 85.03677352782219, 87.06605880491196, 88.83107046927176, 87.59125632624473, 84.08535557408487, 90.69698902868456, 89.7303052102366, 87.12653390822872, 83.60204896619244, 90.8735349101405, 83.23817068530668, 83.55792230175388, 78.60421196106942, 85.15151854484313, 89.0711195238175, 84.39563074419576, 80.00991098342404, 69.05609607696533, 78.09855568793513, 81.39227974799373, 84.3474954174411, 81.35951226757419, 81.5700101852417, 82.27518173956102, 78.57621408277943, 81.99246514228084, 77.61203273650139, 73.95327721872638, 77.1839060321931, 79.42420697981312, 81.03794067136704, 80.22218965714978, 80.9829725757722, 78.68539717889603, 79.65696042583835, 76.63555083736297, 79.84219827959615, 79.29384308476602, 81.15721210356682, 75.91643917945125, 77.58607449070101, 78.90814858098184, 76.36183215725806, 81.64568055060603, 76.36136147283739, 73.27357753630608, 75.44556648500505, 72.18595920070526, 67.66432146872243, 69.91768390901628, 68.69766204587876, 74.33060138456284, 75.60869001573133, 74.00265985919584, 75.00132668402888, 77.677489249937, 76.40064793248331, 74.87850158445298, 81.38360346517256, 82.21134908737676, 81.1584201935799, 81.33236162124142, 75.38433828661519, 75.35660712949692, 70.69230494960662, 76.27361020734234, 74.85092732214159, 59.10783175499209, 29.77978752505395, 3.524402327114536, 4.64648824545645, 1.3077608712257878, 3.587513263187101, 2.7593295612642845, 1.8780422378932278, 0.6589474024311189, 0.26065108937121206, 0.7112483475958148, 0.40392702865985136, 0.31263845942674146, 0.9002257523036773, 0.3639621521917082, 0.42903706191047547, 0.18889192461727128, 0.6353751834361785, 30.315426395785426, 98.96671818148707, 96.93789574407764, 77.45987615277691, 62.70053063669513, 75.47960481336041, 34.386544612146196, 38.143516279036, 95.18407852418962, 72.88325463571857, 93.95483124640681, 38.54457862915532, 0.4586075654914303, 0.1904438502125202, 0.16352990972659281, 0.17922007989498878, 0.1391955098557857, 0.0855288367658373, 0.09041083931562402, 0.12633418829570855, 0.13363680652072354, 0.13263194431220332, 0.15489651250743097, 0.13645725114451301], [0.08253244472847832, 0.056494069961650725, 0.045957672034179976, 0.06205298780133167, 0.05676969690548797, 0.11048926836660794, 0.04843700451836471, 0.12182075830717241, 0.017139725349543077, 0.03342266945588974, 0.0858025216767865, 0.02345301954436206, 0.031785384428897695, 0.12230729308700371, 2.7641933002779564, 60.61521430169383, 55.871178180940696, 63.48754636702999, 57.4190160535997, 43.375742358546105, 59.284358024597175, 107.30057808660693, 31.26381039619446, 0.09853445098645265, 0.0733457558277634, 0.1096630885055469, 0.18414694455362138, 0.11388181213049159, 0.031260016652184634, 0.027209748100909977, 0.16200055308159322, 0.22543788857517705, 0.17937066213738534, 1.894073455083755, 0.8775992535295025, 0.342990679125632, 0.4357657653670158, 0.8203051311354485, 31.77019819136589, 86.36737485085764, 63.53544635157432, 90.36996533793788, 99.75313771155574, 88.57262549861785, 88.48884367173719, 88.99986574726721, 96.54456046319778, 87.52140675821613, 87.67592460878434, 76.65102851006293, 73.80281509891634, 70.4489532593758, 70.34477510759908, 72.48528311329504, 82.28191252677672, 84.12428902041528, 85.83583093458607, 87.32702978195684, 90.83846107605966, 88.36627744859265, 82.69868789180633, 81.61638829015916, 76.49949166082567, 83.3306444844892, 76.25344922465663, 72.76100220218783, 78.83851082094255, 74.5260295560283, 81.00736187350365, 83.11802848692864, 78.89359658764255, 74.59438077865109, 80.16167533013129, 71.8199000820037, 74.94618600414645, 84.43891802141744, 83.3460750887471, 78.79942047980525, 85.62428182171237, 80.83200054783975, 78.47733113073534, 73.51792550856068, 79.59239036806169, 71.80790547401675, 74.21431095369401, 76.17648447713545, 76.52337889517509, 73.80463507867628, 74.14564594145745, 72.37629613568707, 75.74757329879269, 74.28598050148257, 71.86575258931806, 75.27149169675766, 72.19850294051632, 74.11548291483234, 70.35862107430735, 70.99580226405975, 71.31053324668639, 69.24683309370472, 69.8308426334012, 71.13241841716152, 70.79764412295434, 69.46255560844176, 72.35609592929964, 69.8985662767964, 68.17164082680979, 70.97266812478343, 64.09595304919829, 72.16623752347886, 70.78275480578023, 70.64421669129403, 68.86221331934776, 69.28393087079449, 70.56735392539733, 66.21803375982469, 64.38779307949927, 61.47101271537043, 59.414074728565836, 60.05258952417682, 62.14931995637956, 63.16970886722688, 60.682584931773526, 61.63340276287448, 69.94031598491054, 66.96588070161881, 73.89275504696754, 73.62849712371826, 67.69370002131309, 69.0492005502024, 60.281095043305434, 62.97677140082083, 47.91180264565253, 48.14864320139731, 50.61015798199562, 19.484883739102273, 15.857700359436775, 1.8509614587791505, 0.6764278741132829, 0.08587620401334378, 0.2643263808661892, 0.8237821897191386, 2.0057613522775712, 0.21311672794963085, 0.1545710170701627, 0.11338493516368252, 0.18874227700214233, 0.09191328329184363, 0.15934012890342744, 0.047197508730835495, 0.10601601202882106, 0.05585804844515459, 1.3054211774180013, 51.191512077085434, 73.30646268783077, 84.26478047524729, 104.17392346166797, 47.10402188762542, 60.375639853938935, 40.15171097170922, 60.657179740167436, 46.177754171432994, 73.7032025860202, 23.42420247293288, 0.05796914927721505, 0.1031929397234513, 0.09590471629053356, 0.014735527896142055, 0.03790357135116093, 0.12056624336588768, 0.018567399144352927, 0.14198883496705564, 0.031429126731029926, 0.09682056674313161, 0.058671058185638926, 0.010372608329259582, 0.08848641112807298, 0.031374474018511754, 0.004754706986263515, 0.01898766923395376, 0.05051255887073856, 0.013753041200670264, 0.06758669751786417, 0.050157385187283646, 0.09546400889033273, 0.09346058937690913, 0.030256259525495193, 0.05771495747349917, 0.05880216264256066, 0.2349228231656936, 4.44820458850553, 69.79797317135719, 65.08434718655002, 70.96099515115061, 69.70639367257395, 34.52477285938878, 55.71282425234395, 119.09571786080639, 40.85861229127453, 0.08196203098181756, 0.15902718198635887, 0.5317041818653384, 0.26749191745635004, 0.12568182612378753, 0.0967379518213772, 0.05702039151782951, 0.2600586582576075, 0.29107348272396677, 1.9474319080191276, 3.8297264854754176, 0.7896058429633418, 0.4880112457659937, 0.1441601426490853, 0.7091759265430513, 40.122210825643236, 91.77877087746897, 76.28897805367747, 101.08236620503088, 101.39603030297064, 92.66808202189785, 94.51059187612226, 95.8510854167323, 97.83257269090223, 93.22117543989613, 92.47958860089703, 81.79145936043032, 77.63081304488644, 72.88894207246842, 74.2235363683393, 76.45953839825046, 84.50994430049774, 87.12748312181043, 89.2925843884868, 90.84733347738944, 91.5766119187878, 91.761426156567, 84.32715400572746, 86.9548596105268, 78.29364653556578, 88.04031279779251, 79.32535540673041, 79.50879681494929, 83.73763745830905, 78.64715406971594, 83.9678256742416, 85.29881923429429, 81.72961142755325, 78.16581649165, 83.57196438697078, 78.73207338394658, 82.41387674885412, 86.3871749754875, 85.85883955801688, 81.11015935097971, 87.18197268824424, 83.30477253083261, 80.53259818784653, 78.30946937684091, 83.91181422818093, 71.44230135025518, 78.63893278183477, 79.1657070959768, 79.04645919799805, 75.83177874165197, 76.45800867388326, 74.77361740604525, 77.91966422911614, 73.34145022976783, 73.38031307343515, 80.65872592310753, 76.73475542376119, 76.54370461740803, 73.69375751864526, 72.37193446005546, 74.18843900003742, 75.81031553206905, 73.3838902750323, 73.852566442182, 74.19786053319132, 71.5350575600901, 73.99214790713403, 74.90433431440785, 72.96394563490345, 74.18002943838798, 69.1980544982418, 75.4702538828696, 73.26774889423002, 73.99079861179476, 73.55607448085662, 72.81772751961985, 75.43513298034668, 71.83930012487596, 69.77394473168158, 66.61405194190242, 68.13281720684421, 68.51336556096231, 68.55619784324401, 69.73096339933335, 68.89345892014043, 67.64235619575747, 72.65766343762799, 71.57364583784535, 81.46861691628733, 77.35168149394374, 68.22894665502733, 77.57342876926546, 67.32882545840356, 71.42147356464018, 58.194849106573294, 58.94857175888554, 65.13532623167961, 49.631726664881555, 13.336992109975508, 1.9138643866585148, 1.2989762329286145, 0.0690862073773338, 0.08555077752398868, 1.1863499086710716, 4.164239696917996, 0.48240164354924236, 0.018396515571962924, 0.12970398690912033, 0.12002356200208587, 0.17999765913813345, 0.2727390375108488, 0.2677898643718612, 0.10708494217044885, 0.03224782382829055, 2.0758553329975378, 60.389505432498076, 85.5744049626012, 90.27258073129963, 112.67773182161393, 52.84085696743381, 51.978547419271166, 38.946072439993586, 57.46914786677207, 54.438230452998994, 81.13929471661969, 28.520287006132065, 0.18198270020225357, 0.13103088183749106, 0.028683795112996336, 0.03987533611155326, 0.04299829736532223, 0.04619497926004472, 0.03234809707669962, 0.16234418948090848, 0.08307955408048245, 0.06907054087928227, 0.07809750044778471, 0.007183070204431012, 0.13791514710793573, 0.17058602384021207, 0.112410195532345, 0.12269420579316155, 0.11214335178655964, 0.1945432939476544, 0.11466855378521067, 0.1881325476232075, 0.10236466844235698, 0.14857818703016928, 0.21842496649872875, 0.12598728070095663, 0.16141975118267923, 0.2587214671075344, 5.921040859914595, 84.76443552201795, 73.33694734881001, 80.5702058730587, 63.793095081083244, 58.80073762709095, 81.9686798895559, 128.15731863821708, 48.02913642698719, 0.157457682334127, 0.36676321479101337, 0.5800579968960055, 1.196078735013162, 1.51053502915367, 0.503779265789255, 0.3180593282224671, 0.44919902518872296, 0.5808707242531161, 3.026803828054859, 4.643865650699985, 2.2794547821244886, 1.0677993345645167, 1.6174969605861174, 0.9213714337637349, 52.95431152466805, 98.2431899347613, 79.38701506583922, 102.8960858621905, 104.88278204394926, 96.57684941445628, 98.63291663508262, 99.62458595152825, 102.11249043864589, 95.1311892847861, 97.85176877052554, 86.16954618884672, 81.93315890527542, 79.95965757677632, 79.34828558275777, 81.66732418921687, 88.30104058788669, 92.33674372396162, 95.06490907361432, 95.1066666264688, 98.91239335460048, 96.12859310642366, 87.04866701556791, 92.12330402866488, 85.91674943124094, 87.73637617788008, 85.33403427370133, 86.60483514108967, 88.03146393068376, 85.1967042492282, 89.02285868121733, 90.7897295490388, 84.36109035245835, 80.8727853528915, 89.37305573494204, 88.38738764486006, 87.18947226001372, 91.09145395217404, 88.2251819487541, 84.46377015882923, 92.97190097070511, 86.50173171874016, 85.12604667294411, 80.75637725091751, 85.42263277115362, 74.3592974447435, 78.47925309211978, 84.03318805079307, 82.58168358956614, 78.18419671827748, 78.53176578398674, 78.88325721986833, 80.09738768300703, 76.46259784698486, 76.01940924121489, 83.04096175778298, 79.50383109431114, 80.25244682065903, 74.89885084090695, 75.80855046549152, 77.93045859183036, 78.1185362415929, 76.4688265708185, 76.61403271459764, 75.8772547014298, 75.82995091715168, 75.95659640527542, 78.65647362124535, 74.98721399614888, 81.31981003669001, 71.39878657556349, 78.88295127499488, 76.19531969870292, 79.94122243696644, 76.99229824927546, 77.4759578704834, 78.2626441217238, 74.87187277886176, 73.01470894967356, 70.93586060308641, 71.64118905221262, 72.90900891826999, 72.52391845949235, 74.84079191761633, 73.85597105949157, 73.47779966169789, 79.57487306287213, 81.73737772049444, 82.66397491578134, 82.88756570508404, 73.8375908328641, 82.6287441868936, 74.67477367770287, 78.95453453063965, 68.05953948728501, 72.31694283023958, 72.45241365125104, 53.500227005251, 18.591171695340066, 2.342967761139716, 2.0327123254537582, 0.23766878872148453, 0.7061181938455952, 3.205908810900104, 6.8746675983552015, 0.8674348602371832, 0.30387606832288927, 0.4904778037340411, 0.3439236822868547, 0.3710762285176785, 0.6993044852729767, 0.6390954289705523, 0.21248983820119213, 0.2141725350051157, 3.0630578052613044, 70.71361910912299, 97.06892644205402, 105.9157774525304, 119.17471439607682, 81.22734408224784, 82.62116616772067, 54.499627313306256, 71.60658590255245, 60.43320848095802, 96.10585120416458, 34.94492930750693, 0.32202977807291094, 0.1901012097275065, 0.157365552600353, 0.1614979074727143, 0.15487423467059291, 0.16568375060394888, 0.14542881489521073, 0.22153862361465732, 0.19351757882583528, 0.24755614929862563, 0.1711870351385686, 0.15907668658802587], [0.028666115718923753, 0.06022075446502817, 0.07464693318451605, 0.062165100938610496, 0.09479452465330401, 0.05108968737805563, 0.04979538949086301, 0.030573797224450017, 0.07493402463414016, 0.04128559289740459, 0.03480621275582141, 0.044582161166134386, 0.0764589686126959, 0.03587040464363752, 0.8956335761374044, 50.22026654212706, 71.98296085480722, 54.723151422316036, 32.22288481650814, 41.18518883182157, 68.65837558623284, 87.1889623518913, 1.7675043306043072, 0.09607456564422577, 0.06357208652902516, 0.15315691069249185, 0.41061791801644915, 0.4062754252264577, 0.09188944263564003, 0.13084433942792878, 0.28943209338092035, 0.18929389095114124, 2.9727540573766156, 0.5848686000512493, 0.12271006381319416, 0.653228648006916, 0.499633320517117, 14.917231702035474, 90.25883674621583, 71.73747539520264, 95.15162483338388, 98.14720169190439, 94.90804564568305, 86.1897385504938, 84.46978707467356, 95.6033798956102, 92.41176297587734, 89.33141585319274, 86.84619426727296, 77.24994305641421, 69.23610933365362, 70.42483068281605, 69.42154330592003, 70.69843953655612, 72.45184882994621, 78.91079225847798, 81.24533991659843, 84.18503868964412, 81.81013768719089, 84.20243047898816, 83.40791517688383, 79.11826210637247, 60.92695251587899, 67.79315563940233, 70.42199088681129, 69.46576410724272, 74.23447978112006, 80.96085825274068, 78.53167949184295, 79.46965156062957, 79.04962062835693, 77.65004834821148, 77.86192694017964, 73.01654461891421, 79.64806449028754, 78.98779622970089, 80.53139009783345, 81.66141709973736, 78.78923800683792, 76.76141969619259, 71.33108646638932, 76.59843737079252, 77.17548078106296, 71.91573927479406, 73.67141569814375, 75.1173190147646, 77.45854254691832, 74.11688712335403, 72.57694890422206, 71.73976605938327, 71.75719707242905, 67.2730807335146, 70.57887000422325, 75.07364734526604, 76.97747953476446, 74.42493438720703, 75.1146988714895, 71.72522975552467, 73.56296216287922, 73.49929425024217, 67.60658417978595, 72.0084797951483, 74.14909762720909, 72.27833886300364, 68.77664289166852, 70.93542914236747, 70.82993307421285, 67.92115042286535, 68.38800661025509, 68.10292874613117, 72.62926547758042, 71.50047794465097, 69.2002510255383, 69.99042818623205, 72.12756295357981, 70.92878464729556, 69.55021273705268, 68.54177921049057, 67.21753212713426, 65.70284612717168, 65.76548637882357, 68.27027274716285, 65.66242218017578, 64.44506360638526, 62.24027972067557, 65.43981590578633, 78.53811217892554, 61.970899181981245, 59.3639664496145, 68.16973455490606, 69.54466650562902, 64.31151082438808, 58.18800849299277, 43.22499390571348, 41.90858371796147, 46.40313356153427, 20.457674687908543, 8.307674161849484, 1.332800792109582, 0.37419261290661754, 0.24418036753852523, 1.2964987658685254, 1.804457715442104, 0.7333935592924395, 0.560359179733261, 0.15839286118505463, 0.2684277398211341, 0.10437762575043787, 0.4055891943074042, 0.3904054235787161, 0.04578779203697078, 0.06580922031594862, 0.08848097956468982, 15.537761449813845, 69.8566439843947, 71.58137290708481, 93.94160501418575, 74.77360171656456, 39.5945422111019, 53.04203141120173, 76.52340242939611, 49.734520219987445, 64.98959056792721, 8.41008234408594, 0.18260805777484374, 0.08452598936855794, 0.06898630185112839, 0.13066070815247874, 0.08193168623913681, 0.06963141683128572, 0.07806697184400213, 0.037667214074322296, 0.05677337412752452, 0.053364849769540375, 0.007761443604625041, 0.07351194328117756, 0.031061486881827156, 0.03659673260464784, 0.06222140457060549, 0.036869268383710616, 0.08968864056852557, 0.020695078119094816, 0.03894173157130999, 0.06096117844384524, 0.05733238848587198, 0.03047235952239604, 0.030772491703711213, 0.004694734750721123, 0.024409731211621436, 0.02015039726581064, 1.5690489473842806, 61.831039228746974, 77.694378975899, 66.13195342402305, 41.68182365355953, 27.096658829719793, 73.18853270622992, 102.28075227429791, 3.8918663897821983, 0.12683442838850523, 0.07033267073453435, 0.5039705732657064, 0.6680309988798634, 0.5848452496913172, 0.198388948075233, 0.10265429564301046, 0.10940917632392338, 1.2469537147591192, 6.845290516653369, 0.7768893350035914, 0.2002897654329577, 0.8036028209232515, 0.47581491150682975, 19.700910237527665, 99.0485780469833, 82.99179092530282, 104.35221087548041, 102.13798584476595, 99.44262719923451, 91.05339911676224, 90.83719022812383, 98.97235854979485, 94.99413382622504, 94.02032698354414, 90.03864272948235, 82.30307763622653, 74.81364127128356, 73.52480534584292, 74.96943781452795, 74.19138862240699, 74.52024798239432, 83.35187235186177, 84.32409455699306, 86.77164569977792, 86.26656993742913, 86.58517622178601, 86.62338795200472, 81.29989224095499, 66.98638685287969, 72.59825521899809, 73.32976941139468, 74.23011810548844, 77.2041533070226, 82.60474712617936, 81.48403183106454, 83.92254583297238, 81.14957132647115, 80.88283446527298, 81.22947785162157, 81.06034524979131, 85.9787307247039, 81.12839052754065, 81.89811645015594, 83.01263440039851, 81.02913102796002, 79.73270923860612, 76.43638856949346, 80.6398985462804, 80.05488487981981, 76.28376914608863, 77.25409292405652, 77.05689968601351, 77.86806152712914, 77.32588014295025, 74.82538484757947, 75.26402350394957, 71.48305477634554, 70.87249079058248, 75.43995749565863, 78.48910608599263, 78.02710579287621, 76.22578867020147, 77.67166845260128, 75.66918865326913, 75.80197657308271, 77.5558251719321, 70.85003914371615, 73.42961726650115, 76.49031331462245, 74.24141453158471, 72.32748616126277, 74.77550014372795, 74.41216314992597, 73.71713484487226, 73.03077497789937, 70.16396168739566, 74.92776655381726, 74.95794526992306, 73.65800119215443, 72.2040177929786, 74.0947884898032, 74.10697921629875, 73.73342837056806, 73.25520515441895, 70.0948416802191, 67.24665180329355, 69.85389048053374, 72.56092209969798, 71.24393140116047, 70.4068426932058, 69.28611170861029, 72.06092188435217, 78.82366857221051, 64.25100434210994, 61.82662263993294, 70.32191553423482, 75.20798067892753, 72.3795360134494, 67.36408756625268, 58.40382906698412, 54.927463762221805, 64.88645576661634, 42.870082163041644, 7.222467103312093, 2.1420995073933757, 0.645252998557783, 0.19546797739401942, 1.653362010275164, 4.524465270580785, 1.4278171451822406, 0.794040205017213, 0.340012711502852, 0.3011414408683777, 0.055821555846881483, 0.7050957422583335, 0.36365439935076627, 0.025020967868547288, 0.10678607594942856, 0.15283198216028754, 18.591124626897997, 83.51220315502536, 88.08128587661251, 105.30610776716664, 92.77090303359493, 39.45011661898705, 30.174591733563332, 71.29694615640949, 50.559465269888605, 77.2842324164606, 10.458905927596554, 0.07338319454462298, 0.08776723842827544, 0.037928476869579286, 0.03122753452419514, 0.0903198816963742, 0.07825966593959639, 0.07987744445281644, 0.041965449964928056, 0.042800413024040966, 0.03313861937532502, 0.082403956461818, 0.062045380548243566, 0.1235109934162709, 0.21564092637310106, 0.16957026786140858, 0.18269491682369865, 0.16769379677791751, 0.1137266793258248, 0.12219327622123304, 0.16284611496713855, 0.12246030382812025, 0.13583477406251815, 0.08886083660106506, 0.1331221486531919, 0.13328233763815897, 0.19443781896223947, 2.353091153406328, 73.98209879475256, 88.06318806063744, 71.48432562428137, 37.02953961587722, 60.384249456467174, 88.35123908135199, 112.86004358722319, 4.830808264593925, 0.25152296789230844, 0.4407841622108414, 0.4772100801910124, 1.6135435791746264, 1.1403541122713396, 0.3676603956808967, 0.691170776563306, 0.5394007301618976, 1.8323976161979862, 10.605649640483241, 5.585206545168354, 0.8574616824907642, 2.10467029002405, 0.5927342392744557, 25.178582552940618, 107.60607580984794, 84.27191134422057, 109.6865793966478, 105.54611759801065, 103.83947080181491, 92.14682256021808, 93.81884267253261, 102.40499727187618, 100.92619311424994, 97.3569303943265, 93.44398959990471, 86.02448909513413, 80.36975706777265, 76.00888159967239, 80.63403852524297, 78.4730008340651, 80.45105211196407, 90.319366762715, 90.62028315759476, 90.6408912904801, 91.83082072965561, 92.1852304089454, 89.66980657269879, 84.0148784268287, 73.74569754446708, 82.02198490019768, 83.08797528666835, 78.65712473469397, 80.98544366898076, 88.24933590427523, 87.43278472654282, 86.95132947737171, 85.18955769077425, 85.7831221242105, 86.72682869818904, 82.85198196288079, 88.22696270481234, 82.54226376933437, 85.65118143635412, 86.76802927447905, 85.05196878986975, 82.84023838658487, 79.30839507810532, 82.84248982706379, 81.57357954209851, 76.71526124400478, 81.55422656766831, 79.7966124934535, 82.27085928763114, 78.11215846769272, 78.33327031904652, 77.52679963265696, 75.37508149300852, 73.87293923285701, 75.19549185229887, 81.64301333888885, 82.89650870907693, 80.4033011774863, 81.72290417455858, 78.25858054622528, 79.50221507780014, 80.18149898898217, 72.56251458198794, 78.02743527197069, 81.25367887558477, 78.5484907704015, 74.34417278535905, 78.27814532864478, 79.38299855878277, 77.36518229207685, 76.46009537481493, 73.98374619022493, 79.86443811847319, 79.56951510521674, 77.74354980837914, 76.85427004291166, 79.37346719926404, 78.40988205325219, 76.93767532225579, 77.59781806699692, 74.11831486609675, 71.27447097532212, 73.49351267660819, 79.93406803377214, 78.4836696809338, 75.68487813395839, 76.23519451387467, 74.27747680294898, 84.39305766936272, 68.35454879268524, 64.98012196633124, 77.61818301293158, 78.93865677618211, 78.90114322785409, 75.12539125257923, 67.44855973028368, 67.4976521153604, 68.47025871276855, 46.65286302566529, 12.0889929609914, 2.682031657426588, 1.3652246974168287, 0.628417695481931, 2.9518137487672993, 9.546906813498467, 2.16166012229458, 0.9375294538274889, 0.9016671007679355, 0.8229404123079392, 0.18931022394568692, 2.1015642631438474, 1.8125427009597903, 0.17773546278476718, 0.30914001166820526, 0.39788627215931494, 23.592825166640743, 91.8418739688012, 88.07548861349784, 108.66950096622591, 93.44373856821369, 55.341630751086825, 68.82451149725145, 95.59055374514674, 60.94588187433059, 90.71129783507317, 14.773225803529064, 0.5123984290947837, 0.2527495665896324, 0.27438254125656625, 0.19227604141398785, 0.21156170735916785, 0.1778547733180946, 0.22844038633329256, 0.13978028009014745, 0.18456346655805267, 0.18367190875353354, 0.10403919874900773, 0.21000094110927275], [0.057821753960583484, 0.06051987349506348, 0.024374540962819612, 0.05352525325912622, 0.04749822888463255, 0.07923108074934253, 0.08131778934189389, 0.1002645533111307, 0.03896268407603906, 0.029572001282846736, 0.02567102220059643, 0.08483247050354559, 0.16879808187725084, 0.1368931704951871, 1.42475328378139, 51.12660861784413, 68.98176716219994, 45.174082402260076, 35.63716488499796, 57.20983212993991, 89.63239500599524, 36.537458665909305, 0.5172975613705574, 0.24519866692923734, 0.14388263495939393, 0.11939682547123202, 0.13977718509493336, 0.1572808232759276, 0.18223079011565257, 0.12385590152154047, 0.31412868430056884, 3.696098197852412, 3.439147895382297, 0.06409719766628358, 0.1350781549849818, 0.17475406308808636, 5.323820777477757, 83.90756237891414, 89.38720764652376, 93.49636893118583, 92.89768972704488, 94.19248765514743, 89.33410659913095, 83.33683398462112, 87.67456746870472, 90.70917975518012, 93.01572953501056, 87.9712555485387, 84.28243114102273, 77.81156370716711, 71.48187806529384, 67.91062278132286, 65.93382666187902, 69.01860606285834, 70.20612716674805, 73.57862810934745, 77.09670389852216, 78.34404899228004, 80.32963122090986, 80.26945421772619, 83.29048725866502, 86.93369450107699, 71.84181828652659, 62.89746499830677, 70.99923041559035, 66.21855151268744, 70.43589176670199, 74.39507730545537, 79.32337068742322, 78.08325059952276, 76.59403647145918, 76.10150444892146, 79.22211077905472, 77.14094823406589, 81.11812960716986, 80.11994915623819, 83.16333186241889, 77.37976566437753, 75.83775643379458, 73.07083022209906, 76.6615169279037, 77.20340805668985, 78.85892283531928, 73.85244092633648, 74.67925302443966, 73.21853883804815, 74.65397727104926, 78.4778331941174, 77.50044914983934, 76.51630293938422, 69.30600597012427, 70.95559012505316, 78.12737726396131, 77.50343799591064, 73.71316540625789, 74.14344941416095, 72.96561656459686, 77.15306835789835, 73.36814588116061, 76.21551990509033, 76.02355126411685, 68.03228685932775, 67.5161107893913, 69.98617633696526, 71.59437948657622, 73.01777624314832, 69.2595729520244, 69.82345288799655, 69.5656825650123, 69.11327638933736, 65.82991523127403, 68.22179225183302, 71.71186231797742, 69.22510316295009, 72.14902616316273, 70.5677696966356, 71.76291588814028, 72.46464360144832, 69.58033653997606, 69.14739316509616, 66.71786923562327, 69.65911342251685, 70.03267995772823, 66.36927250892886, 66.03891480353572, 66.72080316851216, 56.5095047027834, 59.57491151748165, 63.42161524680353, 57.71326834155668, 57.83533250131915, 65.2809638361777, 63.326995911136756, 59.30297751580516, 46.204657708444905, 33.5184613350899, 37.056039148761386, 25.340847084599158, 6.353225256166151, 0.6531883824256159, 0.15010841701540256, 0.9976644753929108, 1.2067575103813604, 3.573083108471286, 2.027517023586458, 0.5160924744221472, 0.1086660480547336, 0.27848316476710383, 0.048334601545526136, 0.7444254705502141, 0.24457989771279598, 0.021759065078391183, 0.012194104943304293, 0.5838033701142957, 50.550569334337794, 77.90521421740132, 113.55875892023887, 81.00755799201228, 31.66412553479595, 66.7501974105835, 54.83041647941836, 62.37884921412315, 57.244874585059385, 4.09236422469539, 0.16264095662101624, 0.05679263357794093, 0.06444720791712885, 0.05577875068411232, 0.02981824492434821, 0.11612038999315231, 0.014290257484742231, 0.031280400336629925, 0.046923134340754444, 0.062312339207217585, 0.13093035578006698, 0.031995704292409846, 0.09268197591506666, 0.027916902796395367, 0.012496319926163603, 0.025809626658296874, 0.019856730866576397, 0.05664695429825976, 0.10646043495545465, 0.10724562911256667, 0.022724969800741925, 0.0566159277373264, 0.05061505377412804, 0.12037911106862369, 0.0561317180343453, 0.16057049675333887, 1.6553037060845284, 62.50097613180838, 74.4484450740199, 57.76029363755257, 33.00659202760266, 44.16548413615073, 104.14311716633459, 46.71467957958099, 0.439227961844975, 0.07982362677613575, 0.1467356842852408, 0.7714390177880565, 0.1572659305266796, 0.1924766645195984, 0.23898414636571563, 0.12482704053963385, 0.5264121077714429, 5.496371724913198, 5.89380294084549, 0.6939446890065748, 0.17393467076603444, 0.19218620994398672, 7.376996720990828, 95.36857897235502, 97.85131377558555, 104.01378093227264, 97.97042831297844, 99.84684313497236, 94.0307604882025, 87.97145166704732, 93.03059531796364, 94.31271614566927, 97.57569666831725, 91.15077587866014, 87.15748925362864, 81.40437633760514, 75.80143528599893, 70.26490780615038, 70.25395654862928, 71.6562117299726, 71.43983025704661, 74.54437055895406, 78.27799627857824, 82.09597649112825, 82.50835880156487, 84.10079402308311, 87.8803820763865, 89.53995258577409, 79.86860367559618, 73.65032903609738, 79.68069861012121, 74.08844993960473, 75.74465505538448, 78.6194464468187, 81.28564619248914, 79.54112498990952, 78.5465374300557, 80.70547273082119, 81.99044119927191, 79.55106427592617, 85.01079174780077, 82.86343528378396, 87.67608150359123, 79.25807891353485, 79.12555771489298, 75.73021288841002, 80.10600905264579, 83.00536232609903, 82.76616050351052, 76.89984798431396, 77.33929464893957, 73.22700331288, 76.99877800480013, 79.47455452334496, 77.65400209734517, 76.90344087539181, 71.02968369760822, 71.86350114883916, 79.45131840244417, 79.7640803552443, 75.41126143547797, 75.80544394831504, 75.40655459127119, 79.48187366608651, 74.87883106354745, 77.28990416372977, 77.17620249717467, 71.74828544739755, 70.66529550860005, 71.97091133363786, 74.8203799032396, 77.90537895694857, 71.27225091380458, 72.99738776299262, 71.02997395300096, 73.07871418614542, 70.5742572969006, 73.35356250885995, 75.23553140701787, 73.12067570224886, 73.24920392805531, 73.72489329307311, 75.8059460116971, 74.98328378123622, 71.93899108517554, 71.83679765270603, 69.941327956415, 73.45009988354099, 74.98893199428436, 71.66429181252757, 70.68897093496015, 70.10561250871228, 62.88497224930794, 62.48325878574003, 67.11180071676931, 61.859507791457645, 63.52435781109718, 67.26735407306303, 68.7302569420107, 66.6049285088816, 59.144627509578584, 49.09305580200688, 59.61177002999091, 36.117870961466146, 8.212019810753485, 1.8089255402165076, 0.17740936979891794, 0.966007148306216, 2.0830987249651263, 6.1517801688563445, 2.7514951171413546, 0.4274286143481732, 0.010627597822026621, 0.13237020271199365, 0.03680915346429233, 0.5175963356610268, 0.5421120072564771, 0.02926595298753631, 0.08414292242377998, 0.8282159389026704, 58.700454388895345, 87.69992951423892, 119.53805923461915, 91.69195313607493, 39.601147482472086, 57.24994620969219, 62.0760775381519, 66.60434015335576, 66.9138857626146, 5.961618759939748, 0.22295467585565584, 0.05418528780160893, 0.1161545881580922, 0.0374964032802851, 0.0210987834725529, 0.05307418835018912, 0.061337814080498876, 0.06277281933674408, 0.010913454912482731, 0.02113585446720883, 0.10505206657633667, 0.058908422868097984, 0.12372776565532531, 0.1394215364369654, 0.10250680073494874, 0.22325495167845683, 0.09826013022252629, 0.18664816033936318, 0.18414950328728846, 0.28416346157750777, 0.11742442485786254, 0.1673305178842237, 0.19621658319186783, 0.3693887819686244, 0.19821726777140172, 0.41139617141696716, 2.8916247333249743, 74.76766324812367, 87.55979891746276, 55.904734057764855, 43.60281229019166, 82.65843652909803, 111.63515014033165, 55.537474693790564, 0.7483882901649321, 0.4256564997617276, 0.27682424733234995, 2.381744557811368, 1.8451290169069845, 0.4972880495892417, 0.32263391500999855, 0.4341997284322016, 0.8492063190187178, 8.432412397476936, 10.909449958032178, 1.1155296765988874, 1.3351895155445224, 0.8067641899951044, 9.161971288342631, 105.22409100686352, 99.16733172632034, 107.60095319440289, 102.34977814459033, 107.29001906610306, 96.96616818827968, 93.05219188813241, 94.8212985069521, 96.82166807113155, 99.20548069861628, 94.81190835275959, 92.4940307678715, 87.0435679343439, 81.47671268832299, 73.07797678055303, 74.67888432164347, 76.4262217860068, 76.25041331014326, 80.24624947578677, 83.73154993980162, 84.62386561978249, 88.48995762486612, 88.25765917378088, 93.38949218873056, 93.08645771395777, 80.26382953889909, 79.47846904877694, 83.3584148653092, 79.67649382929649, 82.16975627406951, 86.6318916505383, 88.6952466349448, 84.45692954524871, 84.90731962265508, 85.1931348923714, 88.6514808285621, 84.77530048739526, 87.53193439975863, 84.74036001390027, 90.80353629204535, 84.06998772774973, 82.41186849532589, 81.137890508098, 84.24190521240234, 83.75329556003695, 85.2528412111344, 81.58657827684956, 81.21402371314265, 77.77016701236849, 78.94318319136097, 84.3865857585784, 81.89783403950354, 80.66335431991085, 72.39318586164906, 74.52461750276628, 82.83386061268469, 84.29328041691934, 79.19569753831433, 79.96433304202172, 78.6007288963564, 81.25700504549089, 77.412031081415, 81.02770328521729, 80.90726298670616, 75.51075627726894, 74.05850656570928, 76.30447926059847, 76.90225631959977, 80.1927718808574, 72.67987189754363, 75.71844577789307, 75.15422067334576, 78.94793710400982, 73.80090882701259, 77.00149228495937, 80.19441927632978, 76.16622355676468, 79.79534164551767, 77.2358460580149, 78.15418274171891, 78.97839823076802, 77.48090005690052, 77.29091613523423, 75.8358266276698, 77.95611873749765, 78.0188766602547, 80.22713968830725, 74.89470881800499, 76.24811480122229, 72.31455018443447, 67.27597544270178, 72.6492303417575, 64.95761148391232, 68.73569334706953, 74.28941649775352, 77.58942419482817, 74.95519961080244, 67.02026044168781, 58.38944965793241, 60.443618451395345, 38.66061410596294, 13.367963144856116, 2.600611097389652, 0.3331855810698002, 1.9964806567276678, 4.484651252146691, 10.747213863557386, 6.0911805302866044, 0.9257044270634652, 0.23109707200238783, 0.39961922433107133, 0.1614059462782837, 1.8812726774523336, 0.7005941483282274, 0.1461609498026871, 0.20824820854731146, 1.4900772946496166, 69.14899349212646, 92.56125234788465, 119.2277369960662, 88.8532946186681, 50.57616672208233, 80.0622824699648, 69.15803847774383, 75.96240935787078, 79.83877797280589, 8.240352561396938, 0.4810749324819734, 0.16560646765414747, 0.22076584008191863, 0.1720714683253919, 0.10482656859582472, 0.16178211077086388, 0.21305925603355133, 0.1700206203085761, 0.08126952580266422, 0.14686187428812827, 0.26122970025866266, 0.12113335527359478], [0.024905259863683776, 0.1484110266450913, 0.1125708748135836, 0.035246740125360033, 0.02500038308602187, 0.07465015841467727, 0.06240476771528202, 0.08683436550199987, 0.14713714500108074, 0.0414767739693484, 0.07609640218077168, 0.03172308615889521, 0.07346235440983888, 0.14065078579850737, 1.9480658610982282, 58.87560782894012, 59.529619909101925, 58.11788435905211, 60.69975706838793, 64.1255904782203, 93.51715749309909, 10.660492220232564, 0.27734956914378756, 0.17805073860912554, 0.11476169475504469, 0.7926184684038163, 0.1439445195419173, 0.33589489697929353, 0.15423165544146492, 0.1585742248402488, 0.1585315230993494, 0.9887866195171111, 0.7295132320254081, 0.35582142611665113, 0.12481151959828793, 1.7830958746133314, 61.73078344714258, 97.720165406504, 91.29162819154801, 91.93828582763673, 94.33025698507987, 85.20713775388657, 79.05861070079189, 80.6418126629245, 87.59098960507302, 97.01890837761664, 91.8456865126087, 87.76480551688903, 84.42378551729264, 77.12117948839742, 73.2456345711985, 65.95645873777329, 65.13605579253166, 65.7930527963946, 69.27603906200778, 73.11502748920073, 73.67524393143194, 76.00725773842105, 77.25059416986282, 78.1558850503737, 80.00132099274667, 80.83072969990393, 82.20489286607312, 80.94310560534078, 76.66734556997977, 78.5779477703956, 72.12537427102366, 74.46017296083512, 74.90999821693667, 74.45035134592365, 78.51156557759931, 77.93261589542513, 68.68027810127505, 79.31175262697282, 81.60812777857628, 82.672070687817, 79.67195172463694, 76.00011117996709, 74.96062032638058, 75.33670502324259, 77.7151910720333, 80.21115995222523, 69.16094103167134, 69.79802023979926, 76.34147505606376, 67.49535360643941, 78.2459112905687, 65.13302772275864, 67.43188181231099, 69.77811028880458, 67.02576744940974, 68.63138967944731, 73.3430427120578, 70.75587088061918, 74.28692971506428, 74.70176742922875, 73.25319690089073, 72.67441980300411, 75.2359079545544, 73.63746366193219, 75.19926517240464, 76.98998405087379, 75.89080256800499, 70.04366259421073, 70.7072570247035, 70.08459644932901, 73.88757751834008, 72.31150642518075, 67.37437202084449, 69.49995148566462, 70.28501387565368, 69.156767629808, 67.20523941901423, 68.87678884690808, 69.19063337387578, 72.06378521457796, 71.48734584931405, 68.30711164782124, 70.71578425745811, 69.99262471352854, 70.17545423200055, 68.7696453832811, 68.02770553096649, 64.40348256018855, 58.46015430265858, 50.416322292820105, 60.57324101847988, 69.79278779798939, 68.45716584113337, 70.41536208122008, 61.595669561816806, 56.04544124295635, 50.668091389440725, 56.84571458447365, 58.544434270551136, 54.12963405732186, 32.56096370758549, 23.621411400456584, 25.25251138594843, 3.6945388105607804, 0.2997365581893152, 0.05825447489417369, 0.7729132161025078, 0.5770578740104553, 0.5442593210647183, 0.040908099242275765, 0.11359894948620951, 0.10529388989051504, 0.13641142376488255, 0.07598744915618051, 0.10662441607564689, 0.20389400993383702, 0.06392360214264163, 0.05819959618571786, 10.324208794101592, 79.52305070815548, 62.88869457860147, 34.885179842672045, 24.946945021229407, 49.253712161894775, 48.66288162046864, 53.20819085644138, 34.37209067806121, 0.492274034768343, 0.03927037179950745, 0.13435832344956938, 0.033489767266737844, 0.06222492474461756, 0.08257060356798672, 0.024868983685249285, 0.017061412011483507, 0.06524540258631592, 0.061590060020887086, 0.13156622407897828, 0.062052577944292184, 0.07115690473226771, 0.05042178128215094, 0.09559588326561837, 0.07980549347496803, 0.02722447805647408, 0.019409867949903976, 0.037210100901223, 0.04319329738556858, 0.04484219055983328, 0.1410076601971542, 0.03813249374469442, 0.09726663675880241, 0.07864191317029538, 0.05995602895235343, 0.28400601518730967, 2.588623353550511, 69.05265223595404, 66.19824147993519, 58.032408068257, 36.71684042099984, 62.59029242300219, 109.03411665270406, 15.58978972896453, 0.32298269952016495, 0.22895835370065706, 0.31368049222134775, 0.7768616332642494, 0.5102467639071326, 0.1471534933173849, 0.3128130661864435, 0.3335152133818596, 0.302018458324094, 1.219777082723956, 0.8657778427004815, 1.864755454082643, 1.6643228285735654, 2.579259430208514, 72.55836471434563, 107.19777276439052, 99.4645610932381, 99.45924235928445, 98.04858546103202, 89.83571498624741, 84.620053075975, 86.32860614407448, 92.63299249833631, 98.21845546845468, 96.21074322731265, 91.76596826122653, 86.79609775543214, 81.35275794613747, 75.0501209689725, 71.35988450819447, 68.63783021127024, 69.97010246399911, 74.16754061175932, 74.65827618875812, 78.961484970585, 78.10161513666954, 82.6274262705157, 83.13318452527447, 82.64709303455969, 83.51702767033731, 86.02112370152628, 83.40010181550058, 80.90395250628072, 83.17502837027274, 78.4658307413901, 79.0186809724377, 79.68235385033393, 77.6571870619251, 81.26288075600901, 82.74789010324787, 72.2446378584831, 80.79498906289378, 83.72160280904463, 85.91096785760696, 79.82089980956047, 77.07678610278715, 78.08416843414307, 80.18314638445455, 80.46209750636932, 80.73514938354492, 71.4707463787448, 75.9378396311114, 76.7251063931373, 71.25848339449975, 79.47413090736636, 67.75019784127512, 71.88125379623906, 71.98185474641862, 70.34405339148738, 70.62071384922152, 75.55573801840507, 73.69575792743315, 76.00750092537173, 77.1230230023784, 75.31130375400667, 74.1976801041634, 78.82742620283558, 74.16290437021564, 74.34057204954087, 77.13142471928751, 77.1967714063583, 73.90716583498063, 72.43233896070912, 72.83662549911007, 74.83628119191816, 75.47836534438595, 71.33846052231328, 73.73716246697211, 71.92822025668237, 72.64094629595357, 71.34298693749213, 72.5492177471038, 69.6420197333059, 74.15404765836655, 74.588073607414, 71.2805663385699, 73.11445482315557, 73.98303231885357, 73.99625070633428, 71.40523495212679, 69.85514563898887, 65.112913808515, 64.0345993349629, 59.618210561813854, 67.37161851698353, 75.33374755613266, 73.43616762468892, 76.28192563210764, 69.67350852104926, 64.07487423189225, 57.11700139507171, 62.543753500907656, 63.25536950942009, 63.939999611146995, 51.82639475791685, 45.25720919332197, 33.18227890999087, 5.672480262094929, 1.2510436436822339, 0.03908991978894319, 1.7838150166696118, 0.6762799272133458, 0.9157788080553856, 0.15081052127624714, 0.12760310568996977, 0.05605684060062613, 0.11169299933939211, 0.09705627667567424, 0.9906814920325434, 0.19183636823248482, 0.11593877352894315, 0.0553147427196945, 13.593549439983985, 87.93594637224751, 72.68671251112416, 49.278458395311915, 28.542201288284797, 49.65965001813827, 48.862989179549686, 61.77401973355202, 40.64180327999977, 0.7158757025195707, 0.04659103905601848, 0.03244246378721249, 0.007308644942954304, 0.03882588758583992, 0.06754302284530095, 0.04229693620976421, 0.0570688006137648, 0.04132958932689602, 0.07661378732131374, 0.06040463088861397, 0.09142155443588573, 0.06361557351004693, 0.2513070843152462, 0.23652653630462386, 0.26745229538890625, 0.1705998287446076, 0.16074078277714793, 0.1683785414863979, 0.17628395599463295, 0.13658633695975428, 0.31301797938443005, 0.14314476971424397, 0.32757959478805143, 0.16788092141430225, 0.2525396891418965, 0.5826725017639899, 3.2951797496887947, 83.24444647758239, 77.0558798697687, 72.27356926087411, 79.95374264255648, 82.71572666783487, 116.23791817695864, 21.635856628417972, 0.5521776671371152, 0.5475512928059024, 0.3853614087547026, 2.807942681735562, 1.2461313653376795, 1.6050359582708729, 0.9627478425541233, 0.46379232598889264, 0.9867757306464258, 2.6219348176833126, 2.5662376515326963, 3.4548525752559787, 3.1278551153598295, 3.593279637636677, 83.48816687060942, 112.05786397380214, 103.58734869187879, 102.94156966670867, 101.27098514187722, 93.50360178178357, 86.88430401586717, 89.72532380011775, 94.26636941971319, 101.55617283236597, 99.50484383490779, 97.42820770509782, 91.23986859475413, 84.98900690386373, 81.69815401877128, 76.95127025727304, 74.53339576721191, 73.81927336415937, 77.82387210476783, 79.40744276969664, 82.54429555708363, 83.72106152196085, 87.44206505437052, 87.03978676949778, 86.6896681631765, 90.09242626928514, 88.65446182989305, 88.81083888392295, 84.48036178465813, 87.12062681874922, 82.45141383140319, 86.11322879791261, 85.16618036454724, 82.37880291477327, 86.21702255741243, 91.5109435973629, 75.97583955334079, 83.87117062845539, 86.88783414902227, 89.54282376074022, 85.71430806190737, 82.45802694751372, 80.28599093037268, 81.4964343655494, 82.88108594955938, 84.17968857672908, 75.59509508071407, 75.09143921636766, 81.23321979276596, 70.86128850137034, 83.20490114150509, 73.22044510995188, 75.48051480324038, 76.88878690042804, 72.54952369197723, 74.96634698683216, 79.85723664683681, 76.31342226459135, 80.23751043504285, 80.21972640868157, 78.3554474000008, 77.53419722280195, 80.54489089596657, 77.13064024525305, 78.2713282492853, 80.34030791251891, 81.91694382698306, 74.92752336686658, 77.24687576293945, 76.96028386392902, 76.50398669704315, 78.37073679893248, 72.87796728072628, 77.62304675194525, 78.42692867402108, 77.19350799437493, 74.74163439966019, 77.632123116524, 75.17420907174387, 78.31105401439052, 76.38594688907747, 76.55737799982872, 76.97305510121008, 78.36647710492535, 77.56338750162433, 77.00320243835449, 79.31418449647965, 70.4357348718951, 68.91249810495685, 66.52230770357194, 69.08825951237833, 80.78908981815462, 78.22463635475405, 82.20952126287645, 74.69628395572786, 69.28556257678618, 62.85065151030018, 71.18209915776407, 72.69964848795246, 70.25506265701787, 56.75987351325251, 42.97725308325983, 38.610439146718676, 11.347737562271858, 1.8017283586725112, 0.14860473963762486, 3.3524640048703844, 1.0677582722517753, 1.4445617434478577, 0.2738283838956587, 0.7017356806224393, 0.22717307772367235, 0.36652198902541594, 0.2654723258268449, 0.47149212249825084, 0.2607345316679247, 0.19763625136786894, 0.21318932244133568, 17.362997185799387, 98.14083960748489, 74.41230435525218, 55.118675385752034, 37.4846012361588, 57.47656506876792, 62.55899975376745, 69.92484615695092, 52.278596970342825, 1.2413558796528847, 0.11522358448635187, 0.201176879927516, 0.1153879946157817, 0.11683815309116918, 0.20413655337066422, 0.15941142104566097, 0.13703278235850797, 0.24990108314781423, 0.15753459756172475, 0.3613566871612303, 0.2146385769329725, 0.2566077232721352], [0.041243848766410546, 0.03842864418402314, 0.06161431053413018, 0.011991716005028257, 0.05608726578253893, 0.03413825686420164, 0.10146967856393707, 0.11985811765395826, 0.06541476930461584, 0.06085745396933729, 0.14328168494807136, 0.07658308251730858, 0.05414046016671965, 0.30798943953648694, 5.86926116097358, 64.06094197304019, 46.46536196431806, 45.5067386165742, 46.126571163054436, 81.37207169686594, 64.46615419080182, 1.3945960181374706, 0.08470179888630107, 0.07369481612958255, 0.16553702944469068, 0.5537477796596866, 0.16644528796595914, 0.3431656536075377, 0.15426979129833562, 0.09366625334106146, 0.8260442328549201, 1.1672608362090204, 0.6639921220560229, 1.496341564962941, 0.34359460155810084, 28.50205779075623, 78.18494981335056, 90.00103504427018, 93.12098241621449, 93.12881146707844, 87.12480022061257, 83.93519939914827, 77.86312718545237, 85.21745358743976, 91.10695515909504, 90.53946664256435, 93.16006491261145, 88.68648405997985, 82.50245955682571, 78.34852833901682, 71.55602655103131, 67.76562844553303, 65.50286800630631, 65.65116105541107, 69.17131177840695, 72.05193181191721, 72.81737450630435, 73.15101131316155, 76.05160405558925, 75.65194591399163, 76.83355992840183, 79.93069479542395, 76.76795436489967, 77.38298200791883, 81.5134652968376, 78.08765934359643, 81.75012542355446, 80.99156256644957, 76.38031436551002, 76.98691675739904, 77.00784652463852, 69.76973995085686, 75.22098725841892, 82.48552276242165, 82.11480386795537, 75.72162289773264, 73.84996983312791, 76.25675186034172, 77.6874206912133, 79.0812349319458, 75.59714255794403, 67.57186335902061, 73.3680909679782, 75.66952597710394, 69.24928849743259, 73.78672553646949, 66.65919057784542, 70.14090599552279, 69.0722248631139, 70.08620462109967, 66.76502396983486, 64.38340786964663, 65.54666911402057, 71.17613715510215, 68.89039947140601, 73.41762265851422, 74.15786020217404, 73.81221309784921, 75.23309953751104, 73.2310982673399, 69.88310429357713, 73.30982808143862, 71.99118998742873, 74.57050923378237, 72.09669390032369, 69.16550667055192, 68.4835006344703, 72.40796535245835, 73.5254878382529, 69.84559074524911, 69.09928137256254, 70.97291131173411, 67.77177087722286, 64.85471202481177, 63.35506439208985, 66.39923941704535, 68.03670344814178, 68.32845718629899, 68.40703010559082, 69.43915474799373, 69.70629953568982, 65.47397190524687, 64.94708384236982, 59.01059619842037, 63.02058035327543, 66.06301384587442, 65.70518385979437, 64.63702832498859, 67.74982913847893, 67.63321707325598, 70.96731801186839, 69.13892869026431, 58.87988713479812, 53.333577263739805, 49.96925054057952, 58.569506060692575, 62.91949695156467, 45.37324859249977, 31.252943469632058, 27.912792275028846, 2.3794602674822656, 0.4569001393693109, 0.1024127098160886, 0.2644454002861054, 1.213400534564449, 0.5155271015340283, 0.09244931501246269, 0.42163689771006185, 0.31183998130502244, 0.08250240642096728, 2.148567250659389, 0.1577613289437948, 0.05937266448933271, 0.027141865049939484, 0.580278875366334, 43.83363593009211, 69.89695810502576, 28.4348185600773, 33.15919576152679, 44.05557147918209, 61.21109293353174, 58.177033701250636, 25.567289437017134, 0.056931835584222316, 0.047953756255728584, 0.058822073267712716, 0.08526547105922815, 0.07524499504436409, 0.025231228360245307, 0.0390445520620673, 0.055994710869966983, 0.014751978676706074, 0.034773504631894256, 0.020648427194945758, 0.044981120604901545, 0.025086370709862922, 0.1727504520526817, 0.1423012456225772, 0.04304174987238742, 0.036732655754613305, 0.07417439483106136, 0.009986701113502345, 0.11635150339814926, 0.08372844587410651, 0.08564751910706682, 0.08494171464154798, 0.09069334189858168, 0.09669145028437338, 0.12445809259530037, 0.4939929522093266, 7.923775123011682, 75.33518314361572, 55.281065433256096, 55.87527313540059, 37.19320835605745, 91.70313189106604, 78.44421848174065, 1.8153707298540303, 0.007862281364073317, 0.152837865715546, 0.2563315638971906, 0.563884471212664, 0.2347564288685399, 0.15988975102382322, 0.2560880092243033, 0.5623689041503015, 1.1702423278362521, 1.5692496011334083, 2.310068145875008, 2.9094717627571476, 0.6164561212062836, 38.60797197588029, 86.86749273730864, 97.72968892128237, 99.67425100265011, 98.08682857021209, 91.3470277478618, 87.46447747753513, 82.44632259491952, 87.94667013229864, 94.02640665731123, 94.92611992743709, 96.04858459964876, 90.1763806804534, 86.61158161778604, 82.59985985294466, 76.546003126329, 72.97366526819044, 69.79603552049207, 70.34961531239172, 72.62182081899336, 74.34672232597106, 75.76642420984085, 76.22410989576771, 80.1895006241337, 82.18266871667679, 82.46274948120117, 81.56133390242054, 81.83087133592176, 79.64824491931547, 84.59784461605935, 80.13612501082882, 86.52983157865464, 83.43274378007459, 80.07321019326487, 81.34089669873639, 80.55708946720247, 75.57889569190242, 81.29085510007798, 84.86581310149163, 83.92046697678106, 77.2191838295229, 78.75342676716467, 80.33225920892532, 81.7254223362092, 80.47766931595342, 75.79750507108628, 70.96557647951188, 78.58847541193809, 76.97970744102233, 75.08469273967128, 75.2523583750571, 70.06983264800041, 74.75850059140113, 73.84155242673813, 74.6613827059346, 70.7745256731587, 67.52546956462245, 66.91946337299963, 75.39541505998181, 69.89226695029967, 73.86361183658724, 74.92262040415119, 75.59197287405692, 75.04046409360825, 75.20095179157873, 72.48955065204252, 77.70206682143673, 74.70692926837553, 74.82304711495676, 76.14262657780802, 72.32707823476484, 72.47651269358974, 75.8519789480394, 78.03932789833316, 73.33449194508215, 73.7001980504682, 72.61246988850256, 72.29050605527817, 70.64863328010806, 65.73564106418242, 67.54792121148878, 71.33597373962402, 71.6268253326416, 70.99878326539071, 71.49051512441328, 71.15921605017878, 68.3798873039984, 68.71268472363873, 63.44623204200499, 70.67969060713246, 70.87570713412377, 72.0800865850141, 69.88963111754387, 72.34716861478745, 72.59809047945085, 73.81933612208213, 74.64606977278187, 67.94255871926585, 59.08043399933846, 58.058087825775154, 61.55004062960225, 68.13168756423458, 64.7191745235074, 45.2950208417831, 37.64371610456897, 5.281060078451711, 0.5506304759652384, 0.31160666156680356, 0.7710247174386056, 3.296746736572635, 0.9494789545574497, 0.16830032390932884, 0.40637611982322513, 0.6609579235796006, 0.15123404532430634, 0.4980933305717284, 0.09219953970563027, 0.22174270943768565, 0.05238553659329492, 0.7234830168947097, 52.37656993250693, 75.17635068585797, 31.285983554778564, 35.03986635515767, 51.68831556074081, 64.33712782398348, 66.76498474613314, 31.727081537246708, 0.07599635109786065, 0.06653700384401506, 0.04887317284761418, 0.04976443187784284, 0.048724413894477396, 0.043123077766429034, 0.02988836303683779, 0.05227962110732352, 0.0762785472456486, 0.06966464206456177, 0.04439243949168632, 0.014551194692631404, 0.044523865705536264, 0.25962952644594256, 0.1981271145444724, 0.14427625093488924, 0.16758430749177936, 0.15239659907116046, 0.08919053020015841, 0.26532885288038566, 0.15852357110669538, 0.2092933976241658, 0.27506812866176333, 0.46019088536981617, 0.23314851756778457, 0.24301982094203275, 0.6068259669888405, 11.588193562722976, 91.7851721855902, 61.73247398868684, 58.06626596758443, 66.75805784040882, 101.54935575300648, 87.95844508755593, 2.16561877439099, 0.12287457353405415, 0.23642723598787863, 1.4023059270074292, 3.6559157217702563, 0.3484873599823444, 0.8048036177792858, 0.5455758278408359, 2.142238506386357, 2.00922517286193, 3.808507443435731, 5.469144102065794, 5.237387428360601, 1.0952614416037838, 45.85222490372197, 94.56956863403322, 100.02968834292506, 103.68870273713144, 102.98170335831182, 96.467650628859, 91.78340711901265, 87.39376498806863, 92.28783961265319, 98.86051608670144, 97.73337594924435, 98.32160595924624, 96.0824268094955, 93.32679702389626, 88.12687950749552, 79.60534203437068, 78.0618501478626, 73.5235188084264, 75.64425022371354, 79.03828497855895, 80.45826142834079, 80.33968817803168, 80.38118685445478, 84.02135818235337, 86.07435810950496, 87.90455956612864, 87.52167347938784, 87.10213676575692, 84.22666288191273, 90.09226937447825, 87.03629586004442, 91.34779653241559, 88.28906951412078, 84.96442148762365, 87.33418418515114, 86.0730323483867, 79.29119156252953, 83.4769332024359, 91.559384868991, 86.71636381456929, 82.76224597807854, 81.43486884332474, 84.78899740403699, 82.09335634785315, 82.86083867472988, 80.9887384599255, 74.3446199355587, 79.41954720404841, 81.72746196869882, 74.58112316746866, 80.00918142257198, 75.45259537235384, 76.31448130453788, 75.41384235505136, 76.56252414949479, 73.82483528506371, 70.78385306942847, 72.53402248505624, 78.15552419231784, 74.83167632933586, 80.10542854186028, 79.60932716246575, 78.24358140268635, 79.10478484246039, 78.34949324207922, 75.46986949059271, 79.8601705797257, 78.16078801308909, 77.6334410329019, 78.99805715007167, 74.72169306970413, 73.70321827550089, 78.46466187507876, 80.48071307520713, 75.40824905518564, 77.28065521486344, 76.28428689895138, 76.02029569687383, 75.60352033184421, 71.26792846187469, 72.78659958993235, 74.75906541270595, 75.94668849822014, 76.8536973768665, 75.43441910897532, 78.55598249743062, 70.23395246075046, 67.54604631854643, 69.09436272036645, 74.47937688519879, 76.80654264265492, 79.09976420863983, 74.51798869717506, 76.4153568206295, 76.83128495370188, 80.85432667886057, 79.5217171022969, 69.50446221136278, 63.31520526639877, 63.176776978277395, 70.29310180294898, 73.1759262084961, 65.13940549665882, 46.6841164711983, 45.71176482785133, 9.989532559148728, 1.037198350794854, 0.899020787929335, 1.6876527186362975, 5.397235779992996, 1.6004538944652005, 0.2924042080919589, 0.7223209534441272, 1.166019773771686, 0.4226213819797962, 3.740926966551812, 0.37336330740682544, 0.4962633303817242, 0.14760546987095188, 1.5716925023063537, 62.09403022643059, 86.30194971638342, 40.70666359316918, 48.723293965862645, 56.81390808474634, 76.23965817113077, 76.81890595343806, 39.72272526833319, 0.1234271067885622, 0.18225277683907942, 0.15895788167272845, 0.1835197024047375, 0.14826801335138662, 0.11989338834199215, 0.14509152170390854, 0.15660806018258297, 0.21690049749468604, 0.16126080326014952, 0.12195075576704358, 0.1318889156344437, 0.17355148890806785], [0.07941978352685129, 0.06555366870616713, 0.0530198842076765, 0.02451833758142687, 0.05159211465187612, 0.14828551079957716, 0.06106211435830882, 0.08449189845592746, 0.02449364273718769, 0.0049050957914592045, 0.0234107525583597, 0.08846324462924274, 0.01870062374960511, 0.17539164742394803, 17.652103324090284, 66.88117319537749, 42.89342811030727, 48.801129479562086, 40.0750207901001, 100.504561854947, 32.21723268108983, 0.1823375214852633, 0.06600379132695737, 0.025906347173957095, 0.1401631095476689, 0.44072646046838454, 0.18609676089498306, 0.1309328072614247, 0.07815382323197781, 0.15594338697771873, 0.7921772630464646, 0.13133647431048656, 0.4751836857007396, 0.7915219207925182, 30.09403801733448, 82.6275674758419, 87.16148222646406, 96.5784340520059, 89.88710588024509, 88.91940224555232, 79.7195771432692, 79.69619197230186, 75.97278010460639, 85.99585579287621, 87.29816898222893, 93.61782904594176, 90.59935339035528, 87.25997294149091, 82.16570838805168, 76.47742440623622, 71.11920002968081, 67.03718154661118, 68.41227823688139, 69.19897233286213, 70.25910269829535, 74.92072982172813, 76.1074899858044, 77.19884241780927, 74.25147933344688, 74.09223110445085, 74.98504884781377, 69.89846429517193, 79.95528805640437, 78.12557297368204, 73.20406529211229, 78.19505383891445, 79.98358403482746, 75.36592668102634, 79.60715416939028, 76.08680340551561, 73.98748028662898, 76.17272684651037, 78.65433200713127, 80.0202032827562, 73.6328431098692, 72.37592743289086, 78.69517172536543, 76.85900042133947, 82.84084243159141, 69.66914684541764, 65.84497713273572, 74.87474395382789, 77.87676134417134, 71.95912068889987, 75.2088200661444, 64.21127073226437, 69.09557865511987, 76.89430959763067, 76.01391792297363, 73.16575942500945, 75.02982662570092, 68.53831183525824, 60.633092464939246, 70.91304809816423, 66.17462881149785, 62.90047737859911, 70.1900532937819, 68.58421141101469, 70.62258874216388, 72.78284980404761, 67.48189987674837, 68.97438526153564, 70.3893175432759, 68.55771187813052, 70.1465149848692, 69.98791786932176, 75.44225600457962, 68.64612994655486, 69.21641119064824, 71.72013067430066, 71.4454706253544, 67.31483828636908, 66.64878845214844, 71.60980224609375, 67.8772355664161, 63.79881389679448, 63.06142399387976, 66.11210623095113, 64.12625335877942, 63.67342356712588, 62.15576441057267, 70.24745325888358, 67.38982615932342, 67.08633668961065, 71.60169862931775, 64.8503189702188, 67.89914592619866, 66.28915417578914, 68.40520228109052, 66.54863465216853, 67.30273385201731, 65.37901916811543, 66.99954248243763, 57.53527510550715, 51.546125719624186, 46.582578074547556, 51.12539268309071, 51.885877501580026, 40.89190144692698, 33.56563960352252, 36.22760711177703, 2.7878084201966566, 0.2169611256930136, 0.16072002179439993, 3.532561102221089, 4.003496309441905, 0.12958573357712838, 0.10243294219816886, 0.5849243712521369, 0.13321548880588624, 1.6981969076779582, 0.26596712669537914, 0.06556460078084661, 0.12462172897592669, 0.10494898944612473, 11.78736367533284, 82.50274981221845, 36.486181520646625, 23.934181197997063, 27.72555205129808, 45.05918441280242, 55.97849422885526, 15.977231648660476, 0.1578095311959905, 0.10098088382472915, 0.06492978968327084, 0.05862163019276435, 0.08154861929435885, 0.058123895207480084, 0.03937619535492794, 0.035309662757020806, 0.010435070350555884, 0.067168444154724, 0.07008415181189775, 0.02938954786758029, 0.04909931434198253, 0.022672494693148523, 0.02884012876048444, 0.04609141949444048, 0.06798543096069368, 0.04328035944772344, 0.06531320902849398, 0.04873930664372541, 0.0703461921863979, 0.06951075032233231, 0.03630754590455083, 0.0357997062195453, 0.04147252984224789, 0.08372309091951578, 0.32270163718250494, 24.742152190977528, 78.32894786711663, 53.112916484955825, 39.43377602484919, 38.86731909167382, 111.31838736995574, 39.40981426546651, 0.19326633263018825, 0.0345972967484305, 0.012238870333549718, 0.3207940169640126, 0.328100749081181, 0.14128867656953875, 0.09080984855010625, 0.15929430152379698, 0.3418133552035978, 1.0539659929852332, 0.3128585411656288, 0.5097221775401024, 1.658616515417253, 37.34218781994235, 95.03367916230233, 93.34284736264138, 103.24137210845949, 93.66024555698519, 91.03642309865644, 83.5871204253166, 84.01879295226067, 79.76498250038394, 89.34262598714521, 90.553571485704, 97.5078945775186, 93.33218636051302, 90.51830153311454, 85.30181592510593, 77.83513715190273, 74.3869109307566, 71.316510938829, 72.12670787688225, 74.02682165945731, 75.30721664428711, 79.1354577772079, 79.04467844193982, 80.66076555559712, 78.6902609179097, 78.84409627606793, 78.81354885716593, 74.44409908786898, 83.22195560701432, 81.88510987066454, 77.11180502368559, 84.37265349972634, 80.9989680013349, 79.48174030550065, 82.15438058299404, 76.92932067378875, 78.4684822636266, 79.7578908551124, 82.80379172294371, 83.15503997187461, 76.21914417512956, 77.42505335038709, 79.80980734671317, 82.27387951266381, 84.32061933702039, 71.51755594438123, 69.37461606917843, 77.09799828067904, 79.37628346104776, 77.23575976587112, 76.09373815598028, 67.61529968630883, 75.23069904696557, 78.56740443937241, 77.26621304788898, 76.10807049658992, 76.77162570338096, 75.77705383300781, 64.54520956162484, 71.15470532448062, 70.2430445148099, 68.03525217117803, 72.04903710273005, 69.79146988161149, 71.20837119317824, 75.93992633204307, 70.07686153534921, 70.92786681267523, 73.33246800207323, 71.55820738884711, 70.99937162091656, 70.61706604496126, 76.42376638227894, 71.9685265325731, 70.81417299086048, 74.58775197305988, 76.10753705424648, 70.90979253092121, 70.56061529344129, 74.38844849986415, 70.48861626655825, 68.71333583708733, 66.67618228543189, 69.25808245135893, 66.57451445056547, 66.19814734305105, 66.32858184076125, 75.26046199183311, 68.82711595104587, 70.78335885078677, 74.0822918184342, 70.11075081363802, 72.16546089418473, 72.38535681078511, 71.73771858215332, 72.99603846765334, 71.51385322693856, 70.0537666197746, 73.4432984936622, 62.28732070615215, 58.952788306820786, 56.08185260526596, 58.58387370263377, 63.817252958974535, 59.324970245361335, 45.12071071132537, 47.75890473396548, 5.970604419708253, 0.3412446728156459, 0.16395596186480216, 4.134744453814722, 6.886793605742916, 0.14655317149816022, 0.13345697504137793, 0.7557508241265052, 0.2167604566221276, 0.27670924221315696, 0.11376732029020788, 0.1576427232113577, 0.21917534962056145, 0.07964392553173727, 15.348596322921017, 89.68581768774217, 40.734967416332616, 27.895967268174697, 34.323861214422415, 48.62704292420418, 62.159231785805, 20.87822141185884, 0.1025930239308265, 0.08590641852107742, 0.042032827397868525, 0.04193710471172968, 0.0797455700775308, 0.08101809574591537, 0.038941988210764625, 0.04165422674568911, 0.039060034699017004, 0.005631195841312048, 0.05501206138081128, 0.0390098138051408, 0.04233607181137608, 0.18348495265649212, 0.21153815781637547, 0.17813257212119718, 0.15003530158390924, 0.08779865569405018, 0.23337140318847474, 0.18658374766668967, 0.14543892725581123, 0.1476746476105144, 0.0983352987696567, 0.1057484558212661, 0.15629834615655486, 0.23892076025086068, 0.40715204431645335, 31.795254292026645, 93.5924905346286, 58.58779215043592, 63.47357488447621, 59.171742854579804, 120.99244271555256, 47.32559657865956, 0.5069083365942202, 0.23460325724895925, 0.2305790280262309, 0.44562577660526004, 2.1808383061039835, 0.8028798177838327, 0.3649575149099673, 0.5675605287955654, 0.6749663009278236, 2.869134598201321, 1.4597067501275771, 2.3280808954469623, 1.7243877990591912, 41.17349624633789, 102.76687514397406, 99.31984132336032, 107.0109659625638, 96.47758207013531, 97.01591953154534, 87.37013663015058, 89.29521237650226, 83.70975725112423, 92.57099551539268, 93.51938539935698, 98.13564638937675, 96.05406022840931, 96.18245509362991, 89.66433878867858, 83.61301591319423, 78.63216277091735, 75.68228936964466, 76.97769134275376, 77.64744389441707, 79.5962578250516, 83.10144470584008, 84.34507923741495, 84.50214662859517, 82.7153971887404, 83.00269511438186, 83.19847629916283, 81.4979091767342, 87.08214052261846, 85.46112691202472, 80.84632504370906, 88.61210023203205, 87.68598156590616, 84.7609838362663, 87.35047771084695, 84.57558908770162, 84.44749232261412, 83.85176274084276, 86.0791120221538, 88.18774684782952, 81.33585253069478, 78.61299022551506, 86.58204617038851, 85.12716847081339, 89.41245202095278, 77.62405087870937, 71.6911522034676, 78.5591596172702, 84.59866831379553, 79.14776617480864, 78.90423405554988, 71.85793138319447, 73.30678432218491, 81.83363268452307, 81.75293384059783, 80.11963536662441, 80.45429983446675, 74.80731841056578, 65.10619478840982, 75.3576426352224, 72.7850071076424, 72.40892241078039, 76.75961540591332, 73.7027632805609, 75.09784836922923, 79.0908839625697, 72.01417507663851, 72.25919769656274, 75.21343277346703, 73.59541585368495, 73.02235757150959, 74.49624307693975, 80.82554432653612, 75.3222079430857, 75.29646935001497, 78.40109594406621, 78.24222426260673, 73.40613795864967, 73.89702258571502, 80.89388770441856, 74.8574855250697, 69.82164859771729, 70.15679159472066, 75.84026675070487, 69.91330654390397, 73.06473485885128, 70.63344586280085, 72.21177624117944, 74.07745945838191, 76.23434728191745, 77.84272301581599, 74.32993458163354, 77.94202173909834, 75.45664325837167, 78.15913277287638, 76.6187709377658, 76.41946746457008, 72.56656246800577, 79.49477041921308, 67.37308548342797, 60.99888878483927, 60.30910468870594, 63.94048598504836, 64.59046979104319, 56.69331873616865, 47.14197474141275, 58.793500854123025, 10.29075784067954, 0.6564657065656878, 0.7773695802015643, 7.050234358156882, 10.687450670426893, 0.590524719126763, 0.2650152471277022, 1.7736877020328277, 0.8061488068872883, 4.629391614467868, 0.8404807001352311, 0.5268810148681364, 0.32058916505306, 0.23733649042344865, 20.662487130011282, 98.75022688219624, 55.61830297593148, 36.16175836132419, 36.15863223229685, 60.253391342778365, 74.603347316865, 28.346726048377256, 0.4803746055451132, 0.16140905659525626, 0.24870407076612597, 0.11814290807852823, 0.20072095036025972, 0.19331373815094272, 0.09951591686976534, 0.1325105959849973, 0.07498023505773276, 0.13211054487093804, 0.2166138273934203, 0.06463764205334649, 0.22225246434250187], [0.05976080676660903, 0.0957229236261018, 0.049828354254244804, 0.06678441193916144, 0.12386885606834006, 0.06690240480125913, 0.039865254394469724, 0.03862900681973946, 0.08548833369728058, 0.04133199484297826, 0.06047553998688537, 0.07171840887636909, 0.021824914165922714, 0.1654487607940551, 35.319245015421224, 61.520595396718676, 41.143246927568995, 61.531397604173236, 58.932415516145774, 94.7339080995129, 10.930636640517942, 0.13088193902325246, 0.1936736309360112, 0.06719268317664824, 0.13280334882438183, 0.16471802016660092, 0.06357836461956463, 0.04049146615509545, 0.07486843218606326, 0.12476163195265878, 0.09189354886691417, 0.1412411331529579, 3.4353395190931137, 43.9835528404482, 96.09169929258286, 93.37293194186304, 95.00197856656968, 89.17425432512837, 91.36478824000206, 80.60912362990841, 78.16494572547175, 74.89468528378394, 82.2487606540803, 82.42097623886602, 93.8050594637471, 90.705626087804, 83.9040244010187, 86.20865221946471, 80.20013809204102, 74.35669299094909, 70.56411404763499, 68.59808875668433, 70.47427608120826, 74.46011020291236, 75.82107067108154, 78.79279167421403, 76.42413508507514, 76.98598323329803, 74.71180869686988, 74.00149883762484, 72.23728733678018, 66.1228770594443, 68.26244369629892, 69.48336770457607, 77.12988715017997, 79.13140204644974, 76.17449191308792, 74.73953200924781, 76.78196507115518, 73.87050736335017, 70.90151632985761, 73.63471800281157, 78.51023197174072, 72.53975699024816, 72.58284814896123, 76.83789022507207, 77.53250275888752, 83.01428179587089, 71.72340977576472, 68.51670742034912, 79.76238589132987, 76.91408618803948, 73.58608845741519, 77.71008414606895, 61.77543570918422, 70.77331758314564, 79.36221784160983, 74.1226137838056, 73.8120875820037, 68.71341428449078, 69.8738867236722, 72.62587654975154, 72.84678443785637, 61.760703286817005, 75.23034603365006, 72.63069322032314, 67.97542818130987, 65.36537716465612, 67.76608344047301, 67.34264004615046, 70.8988961865825, 67.97904460660874, 72.62656688690186, 68.40805776657598, 65.59945244942942, 66.93301908431515, 68.99391082025343, 70.55331968492078, 70.90106917965797, 65.14074694725775, 72.9187991542201, 72.71342385199763, 68.48961168719877, 65.25846904323947, 69.2305160337879, 64.68803482670938, 67.49707160457488, 63.26663847892516, 66.97675351173648, 64.18884654198924, 68.63020512365526, 72.01004089847689, 63.08962191304853, 70.98973827977335, 68.08592134906401, 68.45569887468892, 66.70199932590609, 64.20756409245153, 62.57877242180609, 66.61228687532487, 67.52176684717979, 68.05444825080134, 63.527205451842285, 59.65575941147343, 57.37977666239585, 65.04666105393441, 57.87006508919501, 65.57954642080492, 63.09597223035751, 59.28828039476949, 47.54421380258376, 45.52888824093727, 4.029862972036485, 0.8618123264562699, 0.1253601228217444, 3.384765458683814, 1.6096377565014748, 0.2969828398237306, 0.19944644052415125, 0.27037731101436, 0.07849292439078132, 0.22765335356516225, 0.1333707901498964, 0.0804362596283036, 0.1780005292065682, 1.3104625262560383, 52.81250607582831, 47.57376493946199, 25.160778914728475, 46.37874426380281, 41.0980494560734, 51.62329443039433, 14.411528360459114, 0.24246167992391895, 0.17340413955671174, 0.02696622215631989, 0.10976415848539722, 0.01040461356751621, 0.03329193655161127, 0.12306629469798458, 0.04206797168139489, 0.014315380380609104, 0.07319200964223954, 0.03910391621531979, 0.06746681241859352, 0.023454448298340844, 0.0195665271847599, 0.10321288865299956, 0.03597924658547967, 0.03346202339256003, 0.0476782480555196, 0.02914158627390862, 0.022516375550279216, 0.04489546431408775, 0.04964023370355849, 0.04537459485413087, 0.042281468894572995, 0.024937657722001596, 0.04884644403993603, 0.057191872638800455, 48.173420813775834, 66.60546195122504, 55.64232749323691, 49.62569013718636, 54.80788638514858, 111.30894230258082, 12.00927863197942, 0.18144663783811754, 0.17458474233506188, 0.042174235737371835, 0.033468584935631485, 0.1806293139534612, 0.07635219893868893, 0.12982964065046082, 0.289678436613852, 0.3575831525508435, 0.2244948343403878, 0.2513328095477435, 7.006092004237637, 51.15490067389704, 103.26346289726996, 96.72080824452063, 102.50710441220193, 94.58503846199282, 97.54606708403557, 85.18813779277187, 80.80881934012137, 79.23263842059721, 82.34138350332938, 85.64874956684729, 97.11735202420144, 90.20528854862337, 88.1727163253292, 88.44005723153391, 81.98331033029865, 77.16045810330299, 75.7823568774808, 73.3415835903537, 73.5705166478311, 79.58118807884955, 78.4377073472546, 80.39343249413275, 80.42361121023856, 79.10265107308665, 78.65951738049908, 76.51693836335214, 77.54280290296002, 73.3659101301624, 71.60269491134152, 73.0082291941489, 81.20754395761799, 82.39270379466396, 79.866163961349, 75.520522978998, 81.72109203953897, 78.57673183564218, 78.19029208152526, 78.63654798076999, 80.80969010629963, 74.09167412788638, 76.92801844689154, 80.65555664800829, 81.89488441713395, 80.41866902382144, 74.23134972972255, 72.30487761958953, 82.78194412108391, 77.17182513206237, 74.73291104839694, 79.3668697726342, 64.11692596250965, 76.23328039723059, 80.96369804874544, 76.33848620999244, 73.05291283515193, 71.17019868666127, 69.61948963903612, 72.9651145012148, 74.02489969807287, 65.66484620494228, 74.79708886915638, 74.81985430563651, 70.82473201136436, 68.36568832397461, 69.42794461404124, 67.0934126454015, 73.16537503273257, 70.4257014489943, 73.62190754182878, 74.63742486892208, 68.96279073530629, 67.7971564569781, 71.21399587200534, 75.38708394573581, 74.21169865515925, 67.5858897547568, 75.60595220135104, 75.54146843571817, 72.12106750857446, 71.16520158706173, 73.89086446454449, 69.55626887659874, 72.67492971112652, 66.09229041684058, 70.74856742735832, 69.7867081242223, 72.32751754022414, 74.15795433905818, 68.34333081399241, 73.53935733918222, 72.79807644505655, 73.54799439830165, 70.57766191421017, 68.21067625476469, 68.77322258487825, 68.69247667251095, 72.18427258153116, 72.80753720191218, 72.04200037064092, 65.65495790973787, 58.98050769682854, 66.07635774920064, 60.671582683440185, 69.66102753916095, 71.67448997497559, 72.89717904983029, 56.897619308963904, 59.62099936700637, 6.434606102205093, 1.0463947153860524, 0.2781851565645587, 4.57738834042703, 2.547967986714456, 0.5531692913463039, 0.11984252010381992, 0.13930513703775022, 0.11367401078103051, 0.19622897849448268, 0.08684813976287843, 0.19355807423351273, 0.05945553988098137, 1.711014232808544, 58.171899318695075, 55.05834933250181, 26.696496663555024, 49.67220160268968, 47.86295736989668, 59.4970642366717, 18.952776962710967, 0.225122781290162, 0.1895460564522974, 0.12029802832271784, 0.15869295314675377, 0.03944103320639941, 0.05797569932896764, 0.047791088976326494, 0.039903593264640345, 0.02213816368772138, 0.026187382698539766, 0.039856540144331036, 0.041111667955955195, 0.05788876750175992, 0.17701189274028425, 0.1333100853427764, 0.131964712373672, 0.14860558233434154, 0.21752222381051511, 0.11645314794394279, 0.08872386774108296, 0.11468343887357943, 0.14950486230513743, 0.1576593166757976, 0.1412842639030949, 0.13181892584168142, 0.16064221790481, 0.24195560224113927, 57.36724076732513, 83.92697811126709, 54.909958224142756, 80.77858571083316, 78.5500910974318, 114.01191819098689, 16.138176302756033, 0.49973147170197585, 0.5340228542204827, 0.3442359090812745, 0.375905248426622, 0.516043751230163, 0.7539540721524147, 0.32733046299507546, 0.45152088446963223, 1.369018977688205, 0.4860994580291933, 0.8024191231496873, 8.446841816748343, 51.339412889172955, 110.94063958814068, 99.90975010779597, 108.94937776750135, 95.21137037584859, 101.34388631389987, 88.9410537289035, 82.92654621985652, 79.68884929533928, 87.05866905950731, 91.04482481556555, 98.78234324916717, 94.60046906625071, 91.18293931407314, 92.27206383982013, 87.85100352379584, 83.03918100172474, 79.70973199413669, 77.08762753394343, 78.72839420072495, 86.2964113297001, 83.03420743634625, 85.51061153411867, 84.9388397893598, 85.37932980445125, 84.46887708479359, 81.71158421424128, 84.52413543578118, 77.01777796591483, 80.55122160142469, 81.06557769160118, 86.23294738031204, 87.86091927559146, 85.22106216799828, 81.35442887583088, 87.78310729611306, 84.19392678045458, 85.70358430185627, 83.49905537020776, 85.3324967045938, 80.20346426194715, 78.80892830510294, 82.5514264260569, 84.25811244595437, 86.21881115821101, 78.3308933627221, 74.1852383459768, 86.55189883324408, 81.73306311330488, 76.3612751806936, 83.79914022261097, 68.7576037068521, 75.422620619497, 85.5342948052191, 82.14181330896194, 79.8797667411066, 75.05704002995645, 74.56953648597964, 77.63031882624473, 78.34986194487541, 67.27507329756214, 81.42105425557783, 77.22453394243794, 73.64187240600586, 71.76103315045758, 74.43629357122606, 72.14802988113897, 77.06228902263027, 72.88199947726342, 77.05558961437595, 73.5997147713938, 68.52065332474248, 70.9138717959004, 73.03517587723272, 76.80672307168284, 77.41112109153502, 69.85727940836261, 80.3053831285046, 80.1300924055038, 74.84443972187658, 72.37846128402218, 77.85192489624023, 72.81615857155093, 74.7900442923269, 70.57180973791307, 73.0161210029356, 73.6678228070659, 74.02761397823211, 80.85547201095089, 74.13983298886207, 77.14871452700707, 78.18329457313784, 75.88044751075007, 76.53542841634443, 72.6582988615959, 73.5670571173391, 74.63888399062618, 78.4271797057121, 76.52486939584055, 77.34085575226815, 68.61565313031598, 63.45640667023198, 69.52323467500749, 65.18356354005876, 71.9348176833122, 70.23053999870055, 69.68646018735825, 57.31878380621634, 72.12993990990424, 9.769015927468578, 1.5453798948757111, 0.7609336234388814, 8.12975888290713, 4.267501975259473, 0.9280918634706928, 0.33608743019642373, 0.8934776208573773, 0.1745274542800842, 0.5538048991753209, 0.6839213784663909, 0.22853996244169053, 0.25780654362132477, 3.0279763715882457, 71.03490829467773, 62.95013066261046, 38.6374407429849, 59.464602701125614, 53.91127570982903, 72.08019641137892, 23.981700712634673, 0.4114038935832439, 0.23915905956058736, 0.21276769829132866, 0.3770994875700243, 0.1225700229406357, 0.14729877423134544, 0.13939100017230358, 0.10264593762375655, 0.11820883760529181, 0.10672772303223611, 0.10995620140625585, 0.09942883565541237, 0.1297482821129022], [0.07222514539476364, 0.008351771806877467, 0.09507999965740789, 0.0546142089390947, 0.06612309419940557, 0.04596301932789145, 0.0077943240983351595, 0.05107359570120612, 0.05805303207448414, 0.10853806540610329, 0.06795321696347768, 0.023942798706552675, 0.026485369833666953, 0.6453091374808743, 50.44475163182905, 58.55129841835269, 33.802499771118164, 35.87752772915748, 71.19132457240936, 75.05372954953101, 1.3474076986312868, 0.25345248290367667, 0.14438785462369844, 0.12887351695568333, 0.3380757347951013, 0.16744121758928224, 0.09147950898735754, 0.09753740287476009, 0.3074045467280573, 0.20842387250834898, 0.2375331911588869, 13.641497473562918, 64.9628007796503, 96.00240261323991, 92.5604364948888, 91.54888076166954, 90.90039530108052, 87.71598769772439, 82.0739092365388, 79.72233849187052, 76.48145660277336, 78.68480097862982, 79.91460523297711, 86.71984687928231, 87.25697625067927, 87.96359908196234, 89.13343029637491, 83.86951538824266, 77.65436295540103, 73.76864340997511, 66.98940707791236, 69.52162650323683, 75.94062451393374, 75.43015157022785, 82.66283742843136, 80.05766191790181, 82.52749996800577, 80.43659425550892, 77.60081475780856, 72.6835746149863, 66.71633166651573, 64.2242302433137, 57.52377471616192, 64.51136735177809, 77.34557828595563, 74.1130510453255, 68.5734405825215, 74.58122514909314, 78.91247887765208, 74.26060276646768, 72.20014249124836, 75.55048204237416, 71.47818319259152, 72.77297327595373, 79.88346161380892, 76.23963463690974, 78.92908619296166, 68.08413274826543, 70.54567106308477, 76.16000267767137, 73.5767924401068, 72.12746881669568, 78.4613121709516, 57.28027005349436, 70.4420655773532, 80.33788388775241, 66.2207401952436, 69.27632931740054, 63.800276940868756, 63.822202990132, 64.67433398769748, 62.86043782388011, 69.07292304500457, 68.58193643631475, 61.48523130724507, 71.53213147194155, 75.77022106416764, 69.213469413019, 67.33583081153132, 66.20554493319604, 61.446486134682935, 71.23682406640822, 71.46844786982383, 72.70867778408912, 70.02815354254939, 67.58132411587623, 65.7445252326227, 70.32536721998646, 69.27993789795907, 67.89305840769123, 67.29445765095373, 68.06589372696416, 68.66182727198448, 67.27361417585804, 67.80223984872141, 65.255476274798, 65.87543825949392, 67.4883404085713, 66.67769632031842, 68.55915531035393, 69.09870086177703, 65.40085500286472, 67.29748572072675, 69.77118338308027, 67.75481839333811, 68.36834769095144, 64.0818246718376, 63.19406678599697, 60.806025843466486, 66.6998420223113, 61.300260174658995, 67.66650230653825, 65.45626632628903, 69.21733687000891, 57.26971103299049, 61.54672622680665, 64.18424167940694, 67.75440262209985, 73.12681028919836, 71.27208617425734, 73.2331378998295, 62.45650822116483, 61.318534497291814, 5.787601826652404, 0.1796759788187281, 0.31887426191279966, 1.356559813983979, 0.12323435906681324, 0.054722660176095464, 0.1957687894783674, 0.13532331844251003, 0.21995507390989413, 0.1173758089181877, 0.04146211104647767, 0.14348790049552917, 0.2804036552627241, 24.437744886644428, 59.524222727744814, 40.003064909288966, 38.64155923166583, 26.159053502544282, 52.32277854796379, 14.659605526155042, 0.16042926078361852, 0.06745717503250608, 0.010177709815663197, 0.047321599652810444, 0.020812902441849152, 0.08803769810906342, 0.07683585322792492, 0.050663294330719984, 0.04631760312364467, 0.08742469753469191, 0.035739679400238304, 0.04238600542228069, 0.03846270828357628, 0.0649869091989052, 0.07867904545198526, 0.029687939114087535, 0.050353967179093635, 0.031114982801579663, 0.035142188275893854, 0.013859602115717868, 0.04255627229389164, 0.030973877066806443, 0.03276081162414724, 0.09395034938690164, 0.08723521334750038, 0.16751132995611237, 1.1696912348270416, 65.18449706415977, 70.01556273429625, 46.96074162760089, 34.1782549888857, 77.88418246853736, 85.33204955439415, 2.1547489060509593, 0.1390795547875666, 0.14720676707163935, 0.07322585540673426, 0.37385654545599417, 0.20288065947111578, 0.10090598340837226, 0.12087676178423629, 0.39072843689110975, 0.17216022727229904, 1.1379056952653395, 20.839784145355225, 71.95908146519815, 102.03316442428097, 97.28466464627175, 98.06301978326614, 95.09465632900115, 92.65526371617472, 85.39689417808287, 83.17971952499883, 81.4178143778155, 79.07211934366535, 83.28272881046419, 91.19917008184618, 90.52081969476517, 92.91865871798609, 92.64816422616282, 85.60192431173017, 80.15183018099877, 76.56907450768256, 71.5135786610265, 72.55828626694219, 79.56132519629695, 80.0551280667705, 85.81960801155337, 86.91245094422372, 86.60815346625544, 83.22712529090144, 79.42075529406148, 77.59686100867488, 70.56820900209489, 67.85173231555571, 66.85143378473097, 68.3152074198569, 80.88918086021178, 75.94245233843404, 72.48448294977989, 79.21618800009452, 83.42287509672104, 77.70195699507191, 74.80195260817005, 77.89451399157124, 74.29902630467569, 78.10780463680145, 83.73027124712544, 81.10716266016807, 79.81663227081299, 69.35611032670545, 75.11873106802665, 80.03704594027612, 74.01164993163079, 76.68322332443731, 79.31871875639885, 58.693072488231046, 75.2109303012971, 79.51084429217924, 66.93947530561879, 70.35833866365495, 67.10102988827613, 66.89153609737274, 66.06510839154645, 68.91076441734069, 71.37740181338403, 73.14358234405518, 65.02963404501638, 70.94938493544056, 78.53062045189643, 72.6953495702436, 69.19243766415504, 68.7678175587808, 65.68244195753529, 70.91378550375663, 72.42407060438588, 73.88360023498535, 73.21696204523887, 70.3980879629812, 68.17780679272067, 73.02776259760704, 71.51039369644658, 72.44947971836214, 70.8061242872669, 70.79494553227579, 70.92170084676435, 71.41380925332346, 73.10372321836411, 68.691590216852, 71.19954586029053, 70.62902142924648, 68.69522233163157, 69.13000922049247, 71.72342546524541, 68.70995475399879, 69.2537207757273, 71.39327956784156, 69.94346957052909, 70.59448888224941, 66.28082306154313, 68.6345511098062, 65.16803487654656, 67.6496910279797, 66.10107652602657, 69.85607131834954, 71.68806922051215, 74.7559118270874, 65.6620103313077, 63.72045670786212, 68.5700124309909, 72.39033037616362, 78.42341423034668, 78.41434571050829, 83.6389898484753, 70.54811862207228, 74.38695015445833, 9.103245562122716, 0.19815912169794883, 0.48011625005352887, 2.071982482748647, 0.1288826946890162, 0.15201448973628784, 0.14621374858242853, 0.025923769928575046, 0.2347868732026508, 0.16198161538810502, 0.13027199513969884, 0.05291358950818258, 0.15234792184445167, 24.943797319166123, 74.08651228873961, 22.413903859353837, 36.30166538300053, 33.889195919036865, 59.791481264175914, 20.356277496584003, 0.14800247195507252, 0.03184342899570062, 0.0545663514264649, 0.07281622053274224, 0.04166668333533791, 0.022562319758318128, 0.07049554102723637, 0.05097586203426604, 0.03951802887322922, 0.0761132101498304, 0.03649606865139739, 0.04577524734721069, 0.05475082156819202, 0.13922003999112115, 0.12030683833384707, 0.0908677724580611, 0.13799053015968493, 0.15627560866696222, 0.12313984679959475, 0.17191149384504364, 0.13426469218346382, 0.11819460369165867, 0.15482905080481885, 0.3020466503597075, 0.14611072507837128, 0.3562958796899165, 2.3496183849150136, 79.27964410474225, 78.3091869661885, 44.453699896412516, 49.485410490343654, 94.01871096703314, 93.92662940486785, 3.3267244312071034, 0.33231922755798987, 0.45805607411649923, 0.25585341778013015, 0.6693201716388426, 0.5320473892554161, 0.2448008221484, 0.43339230240352694, 1.373261756473972, 0.8407428247794029, 1.6227650714497415, 21.07020966468319, 77.96343788023918, 109.73056485576015, 103.26594183521887, 101.33330375917497, 100.71462046715521, 95.64567873554846, 85.81228102407148, 87.51870032279723, 84.67765700432562, 83.40472236756356, 85.09058060184603, 92.24841194768106, 92.31327226085048, 96.98005337868968, 95.94508894028203, 91.43928189431468, 85.6208928938835, 83.15443592686808, 74.95319135727422, 77.98097087490943, 84.75622207887712, 83.59729505354359, 89.9980697324199, 88.02254446091192, 88.79485914784094, 86.83892219297348, 81.90494137425577, 84.36101974979525, 77.81827096016177, 78.03014170738959, 72.04221217863022, 76.05933896956905, 85.1398769501717, 79.98298783456126, 76.82655457527407, 83.37883472442627, 90.65452544919907, 85.89155996999433, 81.79691929971018, 82.25087873397335, 78.50287360529747, 79.33354531565021, 88.38694833940076, 82.14228399338262, 81.90875391806327, 74.13442011802428, 78.30957920320573, 82.78936524544993, 76.19219749204575, 78.43061570198306, 84.55800117984896, 62.43479790226106, 76.70369809673679, 85.43374876822196, 70.72274254214379, 72.54068266960883, 68.83771419525146, 67.40269937822896, 67.52582257793796, 68.17408838579732, 73.53692546967538, 76.0177932247039, 67.53729943306216, 78.05125974839734, 78.94412456020233, 72.76284571616881, 71.9105774356473, 71.30165300061627, 66.82163161616172, 77.73028435245638, 78.2963215920233, 77.79861988559847, 76.36975534500615, 74.34542794381419, 70.29333714515933, 77.5922247671312, 75.90357380528604, 75.1456699063701, 74.88908413917788, 75.55759722186674, 73.7071406456732, 73.75280487921931, 72.65470597051805, 71.47703001576086, 75.47142274918096, 75.49286242454284, 73.7728246565788, 74.77166406569943, 73.74697623714324, 72.25043512159779, 72.92540442559027, 76.42793978414228, 73.99611734574842, 74.01956527463852, 71.18260122114613, 69.82124067121937, 69.58903635701826, 75.88211059570312, 69.42403008860927, 74.85330427846601, 76.43760450424688, 78.40937998987015, 68.06265384920182, 67.90059720316242, 73.57900465688398, 75.74176819093766, 81.43429617727958, 80.73282734040292, 84.63622108582528, 69.91847622779109, 82.53875717040032, 11.65394131214388, 0.49486509734584444, 0.8955469775584437, 4.405905748567274, 0.6945676104195657, 0.4306968986507385, 0.8404469309795288, 0.4865557399968948, 0.7579849816618428, 0.5109056608090478, 0.18639417154894722, 0.1611384590186419, 0.34065178204928676, 34.07689702126288, 80.87435430096042, 55.44475770765736, 54.499340980283684, 34.872294856655984, 77.47897809551608, 23.079310424866218, 0.196889805937967, 0.10801920937674661, 0.08675264690311686, 0.17852592762679825, 0.07849924461615664, 0.14582103659068385, 0.08689129349565314, 0.13792737387120724, 0.12796338917987962, 0.20777027693486985, 0.12789948212523616, 0.11812101328565229, 0.10688604276266792], [0.08048808547638117, 0.023617561823958834, 0.01855432585392508, 0.06408797013723562, 0.0873627899695308, 0.06786389111150658, 0.05918309986290913, 0.06359408091333124, 0.019246040047296596, 0.03769459022629646, 0.061187327599092844, 0.041532629439907695, 0.2651978518453337, 4.367347869180865, 65.67828424515264, 37.569281285808934, 46.659954670936834, 37.82717320226854, 81.73683643341064, 41.44527727557767, 0.13782162309413956, 0.13466118864955443, 0.24516541871332356, 0.30069027636801043, 0.10366378502259332, 0.06486399805233364, 0.10592454879154121, 0.12153453253690275, 0.3359330788014397, 0.20333988321644647, 20.039493153172156, 76.69415104773738, 96.73271656036378, 93.09218437440934, 90.01665392229634, 87.558120143029, 84.61592674255371, 80.63164587943785, 78.98687055034023, 76.79884695237683, 73.58678663930586, 73.7676549726917, 83.37919558248213, 86.05806458380916, 89.29729123269358, 89.20332693284558, 83.78232109931209, 85.34682120046308, 77.09694708547285, 70.91604478897588, 71.67268568469633, 68.25379094769879, 75.16733707920199, 77.35802788888255, 80.74116629938926, 83.43276731429562, 79.43725278300624, 78.75338754346295, 77.8703208123484, 75.18748237240699, 70.4962335094329, 57.935753022470784, 56.69442484455725, 53.081541445947465, 65.68267729974562, 64.22943915090254, 72.19158387953236, 78.20994315608856, 70.36019002237629, 74.32797339654739, 74.61523209848713, 70.97245631679412, 76.10069644066596, 78.48649378745787, 78.65102152670585, 81.33044750459733, 64.73300480073499, 70.69177935200354, 76.34884126724737, 73.4126804720971, 75.89525838052073, 78.21249269670056, 58.83593697701731, 65.82309815191454, 80.60214181100169, 63.05598366645075, 66.51290970463907, 73.90831116707095, 69.76730808135002, 71.36680356917843, 70.99891662597656, 71.73400801997032, 65.77173863687824, 69.4263364422706, 72.64598261925482, 62.916468881791644, 64.51359918040615, 71.64190292358398, 72.88991482027116, 65.57676153798258, 68.80649997342017, 64.2361464038972, 61.80771289333221, 62.435162682687086, 71.46156018780124, 67.25999570661976, 67.46143294918922, 66.80753461776241, 71.58043153824346, 68.0792768539921, 70.38545793102634, 67.55992366421607, 65.55013256688272, 69.59833237432665, 68.93890350095688, 67.83647429558539, 63.334683756674494, 66.89341883505544, 67.06342220306396, 66.99860895833662, 66.8958350150816, 62.509542588264715, 65.32438447398525, 67.29238663950275, 67.16151283633324, 63.99031577571746, 62.895166489385794, 60.465650404653246, 60.17790140644197, 61.086020315847094, 62.23220748286094, 65.20134756642004, 68.0728441669095, 67.70076028762325, 67.9842064457555, 63.654251021723596, 72.6279789401639, 69.90903116041615, 73.66693635140696, 66.02906180966285, 73.46176501243346, 76.29263370267807, 71.49639867967176, 64.02056117211619, 4.806208139465702, 0.25399262085556984, 0.275170661869549, 0.1009725870925092, 0.3622178312751555, 0.02130072233417342, 0.06089621035742664, 0.0806175236920676, 0.05806198764231898, 0.3316957239181765, 0.17258534478324075, 0.07319608522999672, 4.082458769121478, 54.412821339022734, 44.826132866644095, 48.850727850391024, 29.471891272452574, 47.35038595814859, 22.369239830201675, 0.030201798334958094, 0.15522263613679718, 0.0735994688265266, 0.020411307660622463, 0.026388953837956634, 0.01841142364296942, 0.08435405625571167, 0.0027158518364998486, 0.055162356340236245, 0.02680056138835367, 0.0357638762873267, 0.07943403276224291, 0.03553873836813915, 0.0384451189048348, 0.03816371565804847, 0.034021259916405526, 0.02799880142594057, 0.020732614512164748, 0.047700977884233005, 0.035215456924972036, 0.11238771085176738, 0.0430191234655438, 0.03603340134084706, 0.07560397618480268, 0.05164772497429963, 0.3891556890260789, 7.860801469895148, 75.35907037796514, 46.721316229912546, 47.48065963868172, 29.281064041199226, 96.26480917776786, 46.03761965228666, 0.08684087724935624, 0.06449474367283045, 0.06674914125112758, 0.739172375009906, 0.10455158133540424, 0.07684762799932111, 0.211401303869582, 0.6660908965333816, 0.6629082608607508, 0.6594671164789508, 26.156841285767097, 84.28276062011719, 101.78448615535613, 100.93707376910795, 97.4420379823254, 91.7015786324778, 88.65686232043852, 85.7988743628225, 82.33595494301089, 80.8220063486407, 75.97454517118393, 76.88643347832465, 84.39179466616723, 88.88362238484045, 92.6417786075223, 90.0783214261455, 86.85394487073346, 88.77775761388963, 79.8054378263412, 74.70722736850863, 75.78995843087473, 74.29908906259845, 77.96495975986605, 81.55069643451323, 84.19403660681941, 85.58344210347822, 82.82312900789323, 80.82716818778746, 79.74901845378261, 78.86658714663598, 77.26748389582481, 66.10117066291072, 65.90007074417608, 62.42743561344763, 66.09034492123511, 66.79832489259782, 76.69552387729769, 82.24570905008625, 76.05928405638664, 79.04645135325771, 79.05847734020603, 74.32547092437744, 81.34628603535315, 80.53543013911094, 80.51733232313588, 82.05989853028329, 67.47442383919993, 76.68123076038977, 79.1148574890629, 75.64779604634931, 80.39472687628962, 78.48377166255828, 59.757537072704686, 71.63499170734038, 80.51945824776926, 65.53363507793796, 68.49920580464025, 76.5354911742672, 72.75253772735596, 73.05228525592436, 73.098326037007, 74.37705793688374, 66.06099774760585, 72.4917785583004, 75.32490653376426, 67.26039578837734, 65.31122492205712, 71.57956861680555, 75.74301550465246, 68.6835022895567, 72.70590859074747, 70.62634637278896, 66.75477873894476, 63.61882417432724, 72.42586704992479, 70.22675883385443, 70.70562531871181, 72.0693471354823, 73.38520034666985, 70.85204739724436, 73.18603807880034, 69.03341693262901, 71.35666031991282, 71.75365909453362, 70.97896745128017, 71.31084703630017, 67.93199185402163, 68.82932032308271, 69.82187609518729, 69.6577484376969, 70.02860069274902, 67.40359367862825, 67.3102726474885, 69.5700599301246, 70.55228417919528, 64.55744735656246, 67.6511501496838, 64.4934578095713, 64.46838601942986, 63.867349470815356, 67.44971290711435, 67.06725043635215, 71.28225295774399, 72.59283450341994, 74.36553401331749, 67.61405237259405, 75.46961061416134, 73.14899521489298, 77.94311215800624, 76.45535715164678, 79.04457646031534, 86.14633360216695, 80.36805475911787, 75.42633902642035, 7.57209639395437, 0.23672012672308954, 0.3316097075660383, 0.013685997973586763, 0.8736567199230195, 0.13282901276984524, 0.10510449763387443, 0.1374271337784106, 0.17642485488566662, 0.23622978448627457, 0.26523778034794715, 0.12967971724367913, 4.047166262903522, 63.7379857801622, 40.8267665678455, 42.93885700164303, 38.270687364762836, 56.01820822684996, 29.999473594850112, 0.047709431664477435, 0.15720072112256483, 0.06132122444649858, 0.09660168776228543, 0.04897626146914498, 0.01438144205753962, 0.08087813914302858, 0.05536859487033179, 0.032876356835326845, 0.05564459719725194, 0.010395925172844963, 0.03553884945088818, 0.050907887052744634, 0.15557947989192702, 0.17625182626708863, 0.12163924909527264, 0.13991305844918375, 0.171095548918651, 0.09056500684950622, 0.17787122888670814, 0.1512134375591432, 0.28144859919144266, 0.18182554492546668, 0.09776354436912844, 0.435932649960441, 0.5419786466706185, 11.041332790928504, 91.6510114362163, 52.10167846372051, 55.346106175453436, 54.32954157552412, 104.61071075931673, 54.69562030607655, 0.16115782572136772, 0.15925259569719916, 0.39485706857615904, 1.7620807958226052, 0.16107697280183916, 0.397177119889567, 0.45583604324248533, 1.8731143926420522, 1.1600327659999172, 1.0611739610472033, 29.17981001638597, 92.47048870209726, 107.14362052179153, 104.36459772048458, 102.12678355555381, 95.97553437755954, 92.12358643931728, 88.34206857988912, 85.93825186452558, 83.64987834807366, 78.49397766974666, 79.75694948627104, 88.45730781555177, 93.12383790169993, 94.65874764227098, 95.49846433824109, 89.69619627921813, 93.3292288934031, 83.97976536904612, 77.5114082521008, 79.65982375606414, 77.54957291387743, 82.41018972089215, 84.7535313329389, 87.64799733315745, 91.0706183218187, 87.00247718441872, 86.4925298383159, 84.22951052265783, 81.14067539092034, 80.65133617770287, 74.32185449907857, 74.3614782825593, 71.18759832074566, 78.10854204239385, 70.78177421323716, 81.4395050848684, 87.18711099316998, 82.09330927941107, 83.23889240141838, 83.07283493780321, 76.78562856489613, 85.00881487323393, 83.34164281045237, 84.26232507151943, 88.69234408101728, 69.8166593428581, 76.72019558568155, 83.40826034545898, 78.91007838710662, 82.65386304547711, 84.39872157189154, 65.43803907209828, 71.5848873507592, 85.46099355143886, 67.14617636895949, 68.35198356259254, 81.26262972431799, 74.69006307663457, 76.73566541364117, 76.31686610560264, 78.74755890138688, 68.07835117463144, 74.9409221833752, 78.7768276276127, 69.49511912561232, 70.88775665529313, 75.8418200092931, 77.48627370403659, 71.40753346104776, 74.79107195331206, 72.57814914949479, 69.54142662786668, 67.29354766107375, 75.7112443062567, 73.66032323529645, 73.60400584436232, 75.05099957989108, 76.8298807451802, 73.04615066897485, 76.43640425897415, 72.24249624436902, 71.78953309212962, 76.67200534574448, 76.43096785391532, 74.7053446308259, 71.24457466986873, 72.42845581423852, 75.67125181997977, 76.42301328720586, 71.5226314913842, 72.79689188926451, 70.51721818985479, 73.87867373804893, 72.34596836951472, 68.35220321532219, 70.15220242161905, 68.93695800535141, 70.483352445787, 67.7343043973369, 71.23615726347893, 73.8806898363175, 74.95650183769965, 76.37538002383324, 77.64741251545568, 69.99599795187675, 79.91997103537284, 74.56859511713829, 80.63351292763987, 77.45745212801042, 82.00028634840443, 87.47838620216616, 82.75072205451228, 85.94237819794687, 9.018030108944062, 0.6171664379296765, 1.3547459629274186, 0.5433102300570858, 1.3600128480503637, 0.33769851310118554, 0.17531912954103562, 0.5953331159487848, 0.19349441232700504, 0.8819184572465959, 0.3172288582690301, 0.13262118843774642, 8.150719048515443, 73.85376668745472, 60.82337448673864, 66.11387129752868, 38.38346335195726, 66.97704376712923, 35.38174406174691, 0.1572961450344132, 0.21098763171222903, 0.11354724621219982, 0.1846611580901569, 0.19646176197115453, 0.223931928255385, 0.13951947311720542, 0.07982633106650845, 0.15824468445874032, 0.13063364992699317, 0.08765262401392383, 0.15061133841593422, 0.23050355304393078], [0.036733705295069564, 0.07933632590838018, 0.12625275314935755, 0.031412177035705216, 0.038557044350572174, 0.07766712757368242, 0.06582877087977625, 0.028552248240298325, 0.16953985417081466, 0.03260170665359305, 0.1398516794846904, 0.045751180695069414, 0.19793522484119863, 21.86399344475039, 63.475630206446496, 33.08820478377804, 45.73652282837899, 36.729195887042636, 83.02243248108896, 13.758931275336975, 0.23438741963717247, 0.24152431006152786, 0.06246049678133381, 0.42889806291749405, 0.21780794396275477, 0.047338645109125686, 0.12757248515563627, 1.598407030105591, 1.3798062311064814, 8.03305627838258, 59.663062864734286, 90.57721553310272, 93.3995726800734, 90.06657784984958, 85.91578452817856, 82.11791822987219, 81.2568324612033, 75.09940947255781, 74.09605933773902, 71.7668539477933, 74.52806918851792, 74.77068347315635, 76.883664284983, 82.91109992611794, 84.86567974090576, 87.6181951645882, 87.47163188072943, 83.51179522852745, 74.54368806654408, 70.40930594167402, 68.04723893442463, 67.0762248193064, 72.69152918169576, 78.32272698802333, 80.07455164386381, 80.07024488141461, 76.45059539425758, 74.54863809770154, 67.44682604266752, 66.07425535878828, 70.03079722004553, 64.4800825272837, 54.22527320923344, 55.537741414962284, 51.67341447645619, 63.397704478233095, 71.97769703403597, 73.43651279326409, 74.24535259123772, 76.52333967147335, 76.39719624673167, 78.26729605274816, 78.60367067398565, 77.65681835912889, 76.55129048132127, 64.46500493634132, 73.03082204634144, 74.98818674395162, 72.6782480362923, 78.12791070630475, 71.0610705037271, 57.81277102808799, 62.48512583394205, 74.7641723386703, 71.74131931797152, 71.44217583440965, 67.76283571797033, 68.85538055050758, 65.6398214832429, 67.48808937688028, 66.25958734943022, 67.36803347064604, 68.29247336233816, 67.82180463114094, 68.27814102172852, 68.63974432791434, 64.70430481818416, 56.64409299050608, 67.35516809648084, 71.5213135750063, 68.66196063257033, 72.02156482204315, 68.95997447352256, 63.96404374030329, 65.4886298025808, 66.84953535756758, 68.16794595410748, 68.98736830680602, 69.12371773873606, 67.57380885462608, 65.35084478316769, 67.71863060612833, 67.53231017820298, 69.55043238978233, 67.37532907916655, 66.82700526329779, 66.11371440272178, 65.94453473244944, 65.06603364021548, 63.78819996310819, 64.23775457566785, 61.51543747994208, 67.57409126527848, 65.43733696783742, 66.6839328888924, 61.94166967945715, 62.20620216861848, 61.64518556287212, 59.83092461862872, 61.64378527672061, 61.51910881842337, 60.16827198766894, 67.17023618759649, 67.91612194430444, 70.18914330390193, 66.24764765462568, 71.68775543089836, 71.88494866894138, 72.11668229872181, 72.35167149574526, 72.29755063210764, 77.45542034026116, 77.48844669711205, 68.81789838114094, 51.86563807149088, 2.6162034994171512, 0.07114162127817832, 0.16724027272674347, 0.05661897676726503, 0.15796826461390143, 0.33852218019385494, 0.4988312877474293, 0.1768142267340614, 0.11487027239655295, 0.19124430484108387, 0.031544135680662534, 1.3535527043765592, 36.15350569448164, 42.77224256146339, 32.48756047218077, 41.87294114020563, 47.9685083512337, 25.57015080605784, 0.02939910289921588, 0.13127673477415117, 0.04059478077256391, 0.13059077964675042, 0.06492588263485702, 0.040277417358611865, 0.03493241041958813, 0.03733174417227988, 0.08211996000740798, 0.018897502600485762, 0.05209672910672042, 0.039418330190763365, 0.035139874690362526, 0.01948420912207615, 0.022643285675815517, 0.06468309404989404, 0.039470627182914365, 0.10903259048298483, 0.06678288742419212, 0.0319189346215177, 0.04861610821418224, 0.12985395628117746, 0.02352702746828718, 0.18663859956206816, 0.174687382795157, 0.29452486204043515, 28.1076987712614, 73.1732354625579, 40.895666922292406, 38.23686476676695, 33.61178236622965, 95.43357264611029, 15.36580474145951, 0.22458285784288762, 0.07211264538308305, 0.28230667895367073, 0.27778985519563, 0.21888630464673045, 0.08463282032959885, 0.3075376928092972, 3.7165589967081627, 3.828082031780674, 12.602678325868423, 65.41922738475185, 95.19689682991275, 98.38672514884703, 93.70832597055744, 91.07371699425482, 88.6313747590588, 83.77653952567809, 80.36802338015649, 78.32089916352304, 74.52872030196652, 75.84652685349988, 79.4040773760888, 81.1622876505698, 85.13989263965239, 86.92381012824275, 90.87123640121953, 90.22531617072322, 83.88551081380537, 79.1055065585721, 74.72050066917174, 69.54509012160763, 71.11466576976161, 77.4844458795363, 80.6960355081866, 84.98296645379837, 85.12938853233092, 77.01835847670033, 75.25511187891807, 68.18639678339805, 68.06266953868251, 75.08969768401116, 72.76870573720625, 65.41070799673757, 71.85836284391343, 63.10966914699924, 69.1049531198317, 75.57654226979902, 77.4694702702184, 77.16023845057335, 80.46282706722137, 78.66576963855375, 82.21167072173088, 81.65481967310753, 82.09726302854477, 76.46503756123205, 65.28511370382002, 77.8590871441749, 75.33195895533409, 75.51634173239432, 81.72695206057641, 71.39698228528424, 58.80567981350807, 69.27115963351342, 76.46162509918213, 74.35573593262704, 76.1186138276131, 71.14817065577354, 72.98838984581732, 67.715163230896, 70.76275856264176, 68.80139304745582, 71.32269259422057, 73.00038445380427, 69.67939207630774, 70.2433269254623, 71.3096232568064, 71.96611035254695, 59.277658616342855, 65.79093471650155, 73.22144139197566, 70.62034514642531, 70.44106145058909, 71.83822539544875, 67.75317099786574, 67.16850249998032, 68.87796555795978, 71.07246106670749, 72.48579302141744, 72.73682471244567, 68.63110726879489, 68.42246855458906, 69.7176508749685, 69.29445851233699, 72.04600118821668, 70.75546295412126, 69.80013047495197, 70.12202370551326, 69.19759165856146, 69.15338654671946, 67.07586396125056, 68.55869247067359, 65.92027879530384, 71.02002682224398, 68.82391529698526, 68.19694795916158, 66.24432148471956, 65.12668917256018, 64.248046875, 63.312683182377974, 63.59944374330583, 65.04564123768961, 64.57199150516142, 70.76275071790143, 71.34292417956938, 74.79637499778502, 71.55748567273541, 75.17735481262207, 78.86790506301388, 77.41094850724744, 76.27705404835363, 77.01294560586253, 81.12053794245567, 83.31884599501088, 79.33178024907266, 63.92003866934008, 4.454050881247367, 0.12037307429578036, 0.1426882885636822, 0.2038642091135825, 0.10673709228755006, 0.42191786811717097, 0.6541616818116558, 0.16164344885656912, 0.18809192964146215, 0.3031572633452954, 0.06271188853368645, 1.0045555282023646, 42.17807016065044, 50.87970718260735, 30.326940513426262, 47.16588943235336, 53.42224244148501, 34.97187206822057, 0.015276714430881605, 0.11114001409300875, 0.07591953546169304, 0.09410684582807365, 0.03275093292036364, 0.031796914052158114, 0.014259209856390955, 0.04493346610557168, 0.03715043797368004, 0.043794404444915634, 0.060950683039282604, 0.03670182071566101, 0.03192387971906893, 0.1459360876751523, 0.15346193626042337, 0.1719283784228948, 0.092747361519404, 0.12422519420543987, 0.15939773871533333, 0.09890811037152045, 0.1379721440495022, 0.24203939693829707, 0.09264246109993228, 0.28623658743116165, 0.34161775763477054, 0.38224097942152335, 34.47050294568462, 87.69989813527754, 46.785996114054036, 61.3533063088694, 52.284872762618534, 105.94114734280495, 18.71469497680664, 0.40441560889444045, 0.35437465374988897, 0.3437462563235914, 1.4343958179796896, 0.8030812682644014, 0.12264391978181179, 0.6325319553575208, 6.79883788670263, 5.891724084654163, 14.784892893606617, 69.91957449143933, 100.3709816163586, 105.19067241299538, 100.09104990190076, 94.13692335928641, 92.34914625844648, 89.05306093154415, 84.73426465065249, 81.22113889263522, 79.75692595205, 81.94411800753686, 82.42316492142217, 81.58542510001891, 87.8998762561429, 91.12654347573557, 93.89904729781613, 95.55457776592624, 88.80479843385758, 82.74370101190384, 78.97362078389814, 76.01553393948463, 76.74122733454551, 84.30166644434776, 85.69814789679744, 87.58167789828393, 88.26252291279455, 81.46613797833844, 80.14867659538024, 71.06643630612281, 72.48252176469373, 78.77506256103516, 75.8212040316674, 68.50242999292189, 74.5667516031573, 69.09906171983289, 76.47501607095042, 82.26496004289197, 84.839462618674, 81.99819964747276, 85.29966646625151, 81.06201617948471, 84.57252179422687, 85.4327211072368, 82.12208378699519, 82.85504141161519, 70.151700358237, 78.85955041454685, 78.63618712271415, 77.78648407228532, 87.38046815318447, 78.63301000287457, 62.95754001986597, 70.49190321276265, 81.47223334158622, 78.39668719999253, 76.21515904703449, 73.78757276842671, 76.9673990434216, 72.68944248076409, 74.68520718236124, 72.40558839613392, 73.98000424908054, 75.57819751001175, 71.85211843059909, 72.34675284354918, 71.50716950816494, 71.06109403794812, 62.37551519947668, 72.38945176524501, 75.62565818909677, 71.81424402421521, 73.22386541674214, 75.30488675640476, 69.35931098076605, 71.80230432941069, 72.99621889668127, 73.86924436015468, 76.48760687920355, 74.66943925426853, 72.25918200708205, 70.86808989124914, 72.67161923070108, 73.26818035494897, 76.24570646593648, 74.41381054539835, 71.92903610967821, 72.37544890372985, 71.75424745005947, 74.8249141631588, 70.42852555551838, 70.58381219064036, 70.86154737780171, 74.16271609644737, 72.64126008556735, 71.1370546587052, 68.04984338821905, 67.28076857905235, 68.34914376658779, 67.26315713697865, 70.54838534324401, 69.24142806760727, 68.72387916811051, 74.53858114057972, 78.25722340614566, 78.05807682775682, 73.76732549359723, 77.50444212267476, 80.66751987703385, 79.17072772979736, 80.88759622266217, 78.98803941665157, 83.84189405748921, 85.55115315221971, 82.81438212240897, 77.87967174283921, 4.832774352642798, 0.23085806789177082, 0.36175514481240706, 0.3489971148871607, 0.3276025161387459, 0.970009436770793, 0.9687949116191558, 0.6875171500348276, 0.4542124271392823, 0.3766821228688763, 0.13225627011589466, 1.9658247597755927, 54.64727317133258, 56.02125198610368, 48.12253590553038, 53.18879865830945, 63.985048032576046, 42.741828503147254, 0.06464064511800967, 0.16737239225016487, 0.11672839567425752, 0.1573640817115384, 0.16986228525638583, 0.17172067666486387, 0.1333983693151705, 0.20094146110838462, 0.18737652609425207, 0.17258293926715854, 0.24633414712884735, 0.09821835544801528, 0.12925414007998284], [0.12514557223767042, 0.03153130945359026, 0.040996547923573566, 0.011577230836865644, 0.059665133876185265, 0.06240823809357901, 0.07474614923158962, 0.01465530604154112, 0.031090795490590316, 0.07094468305548353, 0.07742253102121816, 0.029143853894164486, 0.03073651429956719, 39.675813721072295, 56.719586849212654, 38.43778425647367, 41.74804502917875, 42.23014746942828, 72.18249182547294, 1.6698816851262124, 0.07544796237902296, 0.11090031284238062, 0.24322527040156627, 0.3540657364553021, 0.016860951699556846, 0.6376434165623881, 0.06209174801986064, 0.9017071212011, 1.8048258053679622, 34.140427650943884, 92.15709917006954, 97.2727406409479, 91.5460095867034, 85.96086825093916, 81.77068648799774, 76.40281308081843, 74.77451170644453, 71.56040391614361, 72.63202682618173, 71.03567707923152, 77.0422221768287, 80.35521291917371, 81.8842077255249, 84.57675010927262, 86.04357534839262, 87.07641386216687, 84.0699798830094, 80.00388622283936, 73.78201869226271, 68.46255517775013, 65.01444662770918, 64.04361294161889, 67.48228426902526, 74.17688369750977, 76.42120115218624, 79.88475599596578, 79.45412681948754, 79.1913672416441, 71.49170752494567, 64.67255715400943, 62.34492463450279, 70.10523596117574, 61.69872983809441, 61.919037603562884, 71.22744960169639, 71.8218691118302, 71.68459400053948, 73.46580505371094, 73.62378243477114, 77.07134185298797, 78.94322241506269, 74.90121210775068, 79.73125011690202, 75.5959423126713, 63.23380039584253, 74.93117117112683, 76.653852616587, 68.32791589921521, 78.81162689578149, 69.01651151718633, 59.290849547232355, 69.37113300446542, 75.9843824755761, 70.21932202000772, 69.23102594191029, 67.7119468873547, 64.73297734414378, 66.42497801011609, 68.6826236786381, 70.75440391417473, 71.34527760167276, 70.07192719367244, 68.32116942251882, 71.82144549585158, 65.19172207001718, 61.07921108122795, 73.80773375111242, 70.15799968473374, 56.101629195674775, 64.63866395335045, 73.39621436211371, 67.25568894417056, 66.70132467823645, 70.22472704610517, 67.48712447381789, 64.40059177337154, 64.43974879480177, 65.79442562595491, 68.16362350217759, 67.45893047701928, 65.44029051257719, 69.25222243032148, 68.20083110563218, 65.1030255133106, 66.09997826237833, 67.55622094677341, 66.77493972163047, 67.39061063335788, 64.40548296897643, 64.04460922364267, 63.939693666273556, 64.3703777559342, 67.63869270201653, 66.65712741113478, 64.94263195222425, 63.235945932326786, 63.514336155306914, 61.40969430246661, 62.63240691154235, 57.845985658707164, 59.73090417923466, 61.891710450572354, 63.501804182606364, 66.08344154973184, 69.07927728468373, 71.94967562152495, 71.98678124335505, 76.42159338920348, 69.39828365079819, 71.24578275988179, 70.46045364872103, 76.73826202269524, 77.19293532832977, 75.52178598219349, 64.06717854161417, 32.36396658805109, 0.5813071492218203, 0.19235994336345505, 0.18343946235554834, 0.10896226361153588, 0.12723634109622048, 0.0885179126635194, 0.20633024614184134, 0.08855640858171449, 0.2132322999738878, 0.05431980901067296, 0.08355189325107683, 15.969136857217359, 62.54346324551491, 46.864031668632265, 31.136472609735307, 40.9121173427951, 37.83187612410515, 0.15008738024100182, 0.16221450611708627, 0.04673047471911677, 0.01959892312785791, 0.05493402000396483, 0.03597556936344312, 0.021328403006097483, 0.11489618915103136, 0.04281849269905398, 0.014234601197043254, 0.02954010329689951, 0.07515024528988908, 0.04380833192337905, 0.08373838203448443, 0.0327623974261505, 0.08964745568171625, 0.04318563267588616, 0.03335695060330533, 0.11347120432483573, 0.011421039873253436, 0.057323118821988185, 0.14929869272295507, 0.04075783875680739, 0.019728976129103574, 0.06378732276179137, 0.02422141147807481, 49.791002350468794, 63.98063928850236, 57.24782420742897, 35.30505780250796, 44.670583432720555, 84.48814376708, 1.8209237028514187, 0.032855346874003453, 0.26971397080248405, 0.03945349362648783, 0.3154437508313887, 0.16981103397425146, 0.9757237172415181, 0.08118010035926297, 1.0379116092958758, 2.858284096564016, 38.95965168553014, 96.94364593875025, 101.00499353101178, 95.44576337260585, 92.48247546534385, 87.14079564617526, 82.27958263889437, 80.2215071647398, 76.42304466616723, 75.11775047548356, 75.50639460163733, 80.57201016333796, 83.40334953800325, 82.59188175201416, 87.45295355396887, 89.88348161020588, 87.93170236772107, 85.91209750021659, 83.89958427798364, 76.31106099774762, 73.44437322308941, 68.99969239388743, 69.00228115820116, 71.12759390184956, 76.7877858684909, 80.98578099281558, 83.73266389293056, 82.30088110893004, 82.00798988342285, 77.20249022206953, 69.32404887291693, 66.56354750356367, 75.50608865676388, 66.43956138241676, 68.63350775934035, 80.60391472231957, 80.70738684746527, 75.04949338974492, 78.11544541389712, 77.95735036173176, 81.5610122680664, 82.79224426515641, 78.97848452291181, 81.96617741738596, 77.09514279519358, 67.6289495345085, 81.15679633232855, 77.63966975673553, 71.23156809037732, 78.16155679764287, 69.77869864433043, 63.62225232585784, 75.57988412918584, 76.9088694357103, 72.48680499292189, 73.86743222513508, 70.61048430781211, 70.20806481761318, 71.33973137024911, 72.2119802044284, 74.40728372143161, 74.10308038034748, 70.67766666412354, 67.63671582744968, 73.6941497556625, 69.29795726653069, 63.302892946427875, 74.04338190632483, 73.51264599830874, 61.32507308836907, 64.45864677429199, 73.21843685642366, 69.92525408344885, 68.89782059577205, 72.50556176708591, 69.00367752198251, 68.22216879936957, 66.45954978081488, 68.82128730896981, 71.25540041154431, 70.96049308776855, 67.09973550611927, 68.25761133624663, 71.07375544886436, 66.95995007791828, 69.03853954807406, 69.32994027291575, 67.29175906027517, 72.01626177757018, 66.53363550862959, 67.9916040359005, 66.41143798828125, 66.54315117866763, 70.92559183797529, 69.7796086342104, 68.63273113004624, 67.33576020886822, 66.04870503948581, 66.65402873869866, 64.64387286093928, 62.686061013129454, 62.39430727497224, 66.8251617493168, 65.96205988237935, 70.79176841243621, 74.03163833002891, 76.00821479674309, 75.99154472351074, 78.48467380769792, 72.65959324375277, 73.26491694296561, 72.7248614834201, 79.49406439258208, 82.0288961164413, 82.5912384833059, 76.34374218602335, 41.322867947240034, 0.93595456091627, 0.046984249004913915, 0.1880358826489218, 0.48192630131398484, 0.18130206172504734, 0.14185720573990576, 0.13957628619767007, 0.33879328338849934, 0.26528803571577997, 0.12459707626652335, 0.07472832236559161, 17.44632205655498, 73.46096484891831, 40.24261190045265, 35.48501614601382, 53.15775309839557, 45.42341570700369, 0.19642753316269768, 0.1062557515838454, 0.014560816756960367, 0.025559046959143975, 0.033736405443520315, 0.06372089527787701, 0.05893988226870856, 0.007318263655648597, 0.09939027845018333, 0.050822069883466735, 0.029159416970346245, 0.04282798835887544, 0.013712226908894317, 0.2588381269766439, 0.1378773789732687, 0.13809364559429307, 0.1178189984432632, 0.12406205578196434, 0.18485980468892282, 0.18124437530434903, 0.10865932946363765, 0.16508027250247617, 0.1965837997774924, 0.16678791312921434, 0.28767992772402307, 0.27393505397823553, 57.78646369134226, 77.29330093629899, 52.397813489360196, 55.98672728384695, 59.513793145456624, 94.31216701384514, 3.076767469606092, 0.1438161385275664, 0.34160865651023004, 0.27586703579272, 0.8451776158425116, 0.29954806991642524, 2.1841164269754967, 0.15669020012982432, 1.9770862522625157, 4.656432924732085, 45.57763545743881, 102.4147718183456, 107.70373498239826, 100.64000129699708, 96.8651593116022, 92.31102082037157, 86.78886490483438, 83.6294271099952, 79.5583834186677, 78.839977787387, 80.34306141637987, 84.62550517051451, 89.43884172747212, 85.9289401577365, 89.39221259086364, 90.87621781133836, 90.44265470197125, 92.51949479503017, 86.3202436508671, 80.76879547488305, 78.27566639069589, 73.18713634244858, 72.99943524022257, 75.41603103760751, 82.55388182978477, 83.4834208027009, 86.78251066515523, 86.33807474567045, 87.47848033905031, 78.01104760939076, 70.42080633101925, 71.81691908067273, 81.75848791676184, 70.92122231760334, 73.66933684195243, 84.32835425100019, 86.29589357683736, 81.27751119675176, 84.64687424321329, 79.6929128708378, 85.73089184299593, 85.9350904341667, 82.30249712544104, 84.54796775694817, 82.75957876636137, 69.45700937701811, 81.57694493570636, 82.25607979682185, 73.01022175819644, 82.7267171490577, 76.61231471646217, 66.74093277223649, 75.90039668544647, 81.72310813780754, 73.94458524642452, 76.13716663852816, 75.35622273722004, 71.09561874020484, 73.22049217839395, 75.31611257983793, 76.10742722788166, 74.52250726761358, 71.07665015805152, 70.52885978452622, 80.76531241017004, 70.02004992577338, 65.55410200549711, 79.77591806842436, 76.08586988141461, 62.279915271266816, 71.31527146985455, 79.72400157682358, 71.15328542647823, 71.20210324564289, 75.80401620557232, 71.22968535269462, 69.92065706560689, 70.60379274429815, 71.9239370284542, 75.13907247974028, 74.14101754465412, 69.21707799357753, 71.95900301779471, 73.35249562417307, 70.76854013627576, 72.84186578566029, 73.02500909374606, 70.77383533600839, 75.9432368124685, 71.08403205871582, 70.07147219873244, 68.92438288657897, 72.69502793588947, 72.25442809443321, 72.46409446962419, 70.70097338768744, 71.03106437190887, 70.85152964438163, 70.17735265916394, 68.73517559420678, 67.91232508997764, 66.45625498987013, 71.61523865115258, 71.19156775936004, 74.50478599917504, 78.50664692540323, 79.61561864422214, 77.63435102278187, 81.57284998124646, 74.01809830819407, 76.56594445628505, 76.12313239805161, 82.46794269930932, 84.70416438195014, 83.40267489033361, 85.56983932372063, 48.72062675414547, 0.9328166034913833, 0.20340786585884713, 0.4529091890060133, 1.1252114344989101, 0.27451069244453985, 0.7591979746376315, 0.39693279912875545, 0.43158951365659315, 0.8576338377691085, 0.13685137273803835, 0.2283994619163775, 26.865152697409354, 81.31373820766326, 63.57162237167359, 45.37428409822526, 55.804133107585294, 57.481471953853486, 0.28335977405790364, 0.2024048116178282, 0.12693605761254026, 0.1000100895462017, 0.12331702761472234, 0.15594298861199812, 0.14314630189009253, 0.18658639833090768, 0.2576267581072546, 0.21160237130618867, 0.1136924964826434, 0.1359740028818769, 0.11813855669911831], [0.10406279425707557, 0.03308411221951246, 0.07388931819267812, 0.08678202637501302, 0.04973756517433832, 0.0870147409037717, 0.012988106238715833, 0.048970128935311115, 0.007041118900111366, 0.08409356337881858, 0.10308994686291104, 0.20511719187901867, 1.4087489103117299, 64.88709511295443, 46.58301345763668, 35.77074904595652, 28.077223916207593, 53.39478977264897, 42.838259973833644, 0.09496954510048514, 0.18482965146822317, 0.19552379456018248, 0.39413412672377407, 0.18507964127967436, 0.30976952143734504, 0.1388982370976479, 0.0027555787622282704, 0.27476849635281875, 5.181390200891803, 72.23111352612896, 93.58259831705402, 91.38937365624213, 86.0706397025816, 79.59074297258931, 74.3345315994755, 74.64284558450022, 74.13474959711876, 72.90767531241141, 66.57888397093743, 73.57778087739023, 82.33452720026817, 85.83721160888673, 85.3012981722432, 87.09506080996606, 84.3758306195659, 87.41997426556003, 84.2908642368932, 82.1869597896453, 73.78002612821518, 67.78445582236013, 62.78108827529415, 62.24011105875816, 65.01832192943942, 69.09190731663858, 72.00706774188627, 75.60879984209615, 75.76843246336907, 76.03589104067895, 75.87334017599784, 75.61657397977768, 63.96320827545659, 65.8618119455153, 66.75659871870472, 58.652978020329634, 64.52341687294745, 69.00315976911976, 63.05623469814178, 68.5048383282077, 79.16771534950503, 77.45152150430988, 73.16965826096074, 80.28818745766917, 74.97565869362124, 62.89705707180885, 78.18849563598633, 75.44366805784165, 70.90581524756648, 76.81604262321227, 67.1287218216927, 58.51470662701515, 72.05314774667063, 74.5449040012975, 68.66185865094586, 69.93511492206206, 71.23097189011114, 68.77643892841955, 71.97328044522193, 70.47105973766696, 67.49905632388207, 66.92635105502221, 65.4733011799474, 60.174967473553075, 53.6885949104063, 62.144813153051565, 66.29520247059484, 63.2213782495068, 60.264570097769464, 64.2169895479756, 71.44857714253088, 59.04629368935863, 61.75925593222342, 67.70163889854186, 70.25177571081346, 68.74761735239338, 67.58157514756726, 68.83863202987179, 65.2611166431058, 62.416551036219445, 64.8197558618361, 69.08230535445675, 67.03873480519941, 62.262244993640536, 63.42159955732284, 67.2601447566863, 64.49972967947683, 66.78955447289252, 64.60939522712462, 63.95963891859978, 61.44326979114164, 63.61109710508778, 62.18102839685256, 62.557481796510764, 68.52935314178467, 67.85102628892469, 65.8735006086288, 61.52698886009955, 61.22336995217108, 61.28007173538209, 58.761568838550204, 58.20528261123165, 60.82224092175884, 59.40337058036559, 63.504851864230254, 66.94101287472633, 70.53279784417921, 69.21000988252702, 71.49753616702172, 71.26454737878615, 70.84069605796569, 68.7179014759679, 67.81501108600249, 71.37618587863061, 72.03705033948346, 78.048702363045, 68.75922756810343, 59.90595956002513, 15.674295233141994, 0.11831252760584317, 0.0867674553826932, 0.049518157592824394, 0.14114138850521657, 0.2806894979890316, 0.07701002331751008, 0.20417897931991086, 0.20903612997743393, 0.024583958757800922, 0.04416714835491392, 6.1889215823142765, 49.211923230078916, 47.24798464005994, 32.056605738978234, 38.22892196716801, 47.500122439476755, 0.6823410922961851, 0.041580732100673264, 0.05510298069566489, 0.03740370664144716, 0.035558809871755304, 0.07167407536819097, 0.08393850718294421, 0.05301153767974146, 0.024103995097140153, 0.00988432399613122, 0.06577734339741931, 0.004144583072047681, 0.011497895729037063, 0.02749134095445756, 0.05786749707054227, 0.05080462223099125, 0.06326765467923495, 0.023374554903937445, 0.06840566849155773, 0.103241172619164, 0.039337607506181926, 0.07288588090769707, 0.08244888751857704, 0.16035599213454033, 0.22499090691487636, 1.9195828346475479, 73.58826145049065, 55.15132911743657, 47.257264967887636, 32.43829550281648, 60.16846810617755, 50.95775842666627, 0.07013436887533435, 0.03219030977737519, 0.41869692804832614, 0.14393183312589122, 0.36023541023173644, 0.5840297644176792, 0.2222212232769497, 0.0973656612838949, 0.2797554223047149, 7.44869617685195, 77.25601488544096, 98.19626269801971, 96.75098696062642, 89.55523413996544, 84.45141469278644, 78.63926226092924, 78.32547264714395, 78.30132653636318, 76.74471039925852, 70.38330062743157, 75.29319024855091, 87.32706900565856, 89.44747878659157, 89.20364856719972, 90.49781107133435, 87.29742373189619, 90.82731370002993, 87.25193992737802, 84.46252284511444, 78.66666393895304, 69.50075164917978, 66.63511506972775, 67.11867270931121, 69.71080241664764, 71.53825821415072, 74.87672082839474, 78.60562401433145, 78.3695993115825, 79.04153270106163, 78.31317993902391, 77.66817754314792, 66.53349430330339, 72.03395166704732, 71.66298174089002, 64.55700805110317, 69.60085838071763, 75.18957691807901, 69.91780942486179, 72.56771564483643, 81.31517379514634, 80.49986208638838, 77.44130765238117, 82.6929690760951, 75.47473322960639, 67.28534990741362, 80.78783465969948, 76.77710133214151, 76.30418900520571, 80.75812662801435, 68.35451741372385, 61.45797083454748, 77.60134035541166, 75.64367755766838, 70.81662839458835, 74.43408919918922, 73.15537298879316, 74.47266963220413, 74.01313258755592, 70.63444998956496, 65.26924379410283, 68.39016391384986, 66.0653123547954, 60.09795957996, 54.67223121273903, 63.68433167857509, 66.77518290858116, 66.32476929695376, 64.46484804153442, 65.60497906900221, 73.75491511437201, 63.32686647292107, 62.617027298096694, 68.56330517799624, 72.42396077802105, 71.53129992946502, 69.39865235359439, 69.81798510397635, 68.18290587394469, 67.87931442260742, 68.58847894976216, 71.29558901632987, 68.97656609935146, 63.359037753074404, 65.37673242630498, 72.3603948470085, 68.16302730191138, 68.25396353198637, 67.20747517001244, 67.55807230549475, 65.5535371841923, 68.23416340735652, 65.54576304651076, 65.24324240223055, 69.38342571258545, 69.13885024286085, 68.4666109085083, 66.46068726816486, 64.368734282832, 65.84522816442674, 63.14007536057503, 62.8181742852734, 63.612316962211366, 63.52160430723622, 68.12066570405038, 68.11234243454473, 74.21791953425254, 74.08272327915316, 75.28254493590325, 75.4623777635636, 72.613709357477, 71.20407227546939, 71.50553780217325, 74.02976343708654, 76.03929565798852, 82.0359956064532, 80.01056209687265, 71.83160443459788, 19.991118561836984, 0.11484498383417246, 0.07840583551554911, 0.0673644707327889, 0.028924247129790248, 0.18550118882088892, 0.1723595633501968, 0.6323998817993749, 0.2206982711269971, 0.18490100489749065, 0.059711941848358804, 7.241050312595983, 56.77905390339514, 39.55700120618267, 36.60453119585591, 49.07118466592605, 53.84490920651344, 1.267655126510128, 0.028673343758489338, 0.0902369986438463, 0.030655240031680277, 0.027867187520549185, 0.07368586056174771, 0.06677303553348587, 0.08081809317152347, 0.0634361480573012, 0.03408409061751539, 0.02620042343023083, 0.00812579789424255, 0.01984237629409519, 0.2618565440418259, 0.18485191398330275, 0.15943052727849255, 0.15371733465262, 0.15686698257923126, 0.189093467028391, 0.15283832536830058, 0.1404394221401984, 0.13288662258175113, 0.15177180840363427, 0.32457496730550645, 0.33004566245982725, 2.3015693503041423, 85.99774637529927, 63.865192167220584, 48.21765730457921, 42.15691289594097, 71.97693609422254, 59.46131575492121, 0.3872883650324037, 0.3159483576253537, 0.36942248983729276, 0.7024893885658634, 0.41372014510054744, 1.2794771502094886, 0.7528629790871375, 0.29732007172799885, 0.5430558888662247, 8.199996765582792, 84.0830570651639, 102.28074442955756, 101.58424915805941, 96.66671091510405, 88.52483534043836, 83.91659167505081, 81.83505258252545, 83.83462982793009, 82.47773293525943, 73.65411804568383, 78.26151447911417, 90.6670613442698, 92.90946468230217, 92.7294514256139, 93.5269320395685, 91.7749269547001, 95.70519678054318, 92.75991255237211, 90.64419392616519, 82.06688034919001, 71.10859394073486, 71.43214241150888, 72.15677676662322, 73.4564619679605, 76.66088934867614, 78.94739581692603, 83.78403125270721, 82.37040904260452, 82.14198589324951, 85.18525092832505, 80.84178293904951, 67.68947170626733, 76.95176447591474, 75.64184188842773, 68.74271438967797, 72.26403005661504, 81.02872310146209, 75.39663099473523, 77.89472579956055, 85.58079058124174, 83.82808731448266, 79.49376629244897, 85.27187255121048, 82.00951176304972, 69.58267427259877, 84.34747188322007, 79.69967503701487, 76.60494066053822, 85.03891514193627, 73.43084104599492, 63.26682283032326, 79.72809653128348, 81.50492237460229, 72.5232595013034, 77.6563790536696, 77.2476916159353, 75.80786797308153, 76.92309979469546, 75.60071191480084, 70.75040309659897, 72.62121677398682, 68.9459010093443, 61.78804220691804, 55.56468809804609, 67.36675477796986, 69.79548638866794, 66.75321763561618, 64.87827370243689, 67.67589246073078, 75.53901303199031, 63.05454023422734, 66.62339502765288, 74.44234971077212, 74.50633925776329, 74.91925501054334, 72.83482905357116, 73.6299091769803, 71.4871967992475, 68.8631860671505, 71.91033424869661, 76.137982491524, 70.98996577724334, 65.1315293773528, 69.08073640638783, 73.79198935724074, 73.01914907270863, 71.54985274038008, 70.42663497309532, 71.85742147507207, 69.84161346189438, 69.86954073752128, 68.84836735263949, 69.22903337786275, 73.138365591726, 74.66277122497559, 71.83832737707323, 68.16586709791615, 67.06710923102595, 68.14859297967726, 67.11325983847341, 66.07715006797545, 67.30997454735541, 68.96557561812863, 72.53125329171458, 73.62432372185492, 77.45105866462954, 77.90679885495094, 77.77225371330016, 79.045957134616, 76.55918229010798, 74.61022715414725, 73.21653058451992, 76.30847223343389, 79.5595601297194, 87.15377084670529, 86.40488839918568, 82.66591256664645, 21.347754616891187, 0.23931252229357922, 0.8852616649481558, 1.4464019479290133, 0.2531632081034684, 0.8536074022131582, 0.2027251742660038, 0.5666881691544288, 0.7043691844709459, 0.3070316764135515, 0.15191275325994338, 10.427080796610925, 66.9856337578066, 59.698650529307706, 46.58983053699617, 49.912497766556285, 68.58957721341041, 1.0462858696137707, 0.16832258642440842, 0.2787242373151164, 0.15922573665457387, 0.1273255596958822, 0.19112913118254757, 0.2502195612196961, 0.190426490660156, 0.0753315476580493, 0.1547682081018725, 0.09238091868258293, 0.1462445299952261, 0.1141702289122247], [0.1293381646035179, 0.05601881582650447, 0.023678912060155023, 0.06682296148351123, 0.024675320488430803, 0.11517053289759545, 0.04305833567594809, 0.09078425355255605, 0.08105168870139508, 0.05693316857721056, 0.04361880943179131, 0.40454615027673785, 6.180099681500466, 67.65500191719302, 41.11703765007758, 39.49651041338521, 18.48273188837113, 74.68229678369339, 16.65454456883092, 0.09843040858545611, 0.07632488024330909, 0.1545725032807358, 0.1656988425360572, 0.12818724773223364, 0.14651809999298665, 0.22089461946199018, 0.07932452815434626, 0.08962958285044278, 20.692952179139663, 93.4086411999118, 91.87639867105793, 93.56122924435525, 82.06503683520903, 79.48421924344956, 71.20614328692037, 75.44225600457962, 71.6710304444836, 69.75055171597388, 68.30567606033819, 76.67424894148304, 84.65717438728579, 88.5851300147272, 86.55302847585371, 87.19989791993173, 86.19089172732446, 83.4160658621019, 84.55903668557444, 82.62349605560303, 78.51251479118102, 67.52019789911085, 61.55492398046679, 63.29204759290142, 63.8207438684279, 67.35100253935784, 68.47702087894564, 72.14238951283117, 73.78857689519083, 75.82484399118732, 72.98875070387318, 76.61102033430531, 70.00294054708174, 65.67400493929463, 70.28471577552058, 67.98769735520887, 69.55425277833017, 70.86022946142381, 73.6423195562055, 68.11741013680735, 75.12233180384483, 71.38422673748386, 79.12773855270879, 71.9948927048714, 64.1323487220272, 77.49120804571336, 74.33527684980824, 76.67527660246819, 77.48823488912275, 67.635539116398, 61.384563676772586, 73.67165888509443, 73.58976764063682, 73.2948289378997, 72.6249194914295, 68.38458630346483, 71.9889150127288, 65.1702392485834, 63.396327726302616, 61.16725652448593, 59.80016539173742, 60.61492796867125, 61.827634611437404, 65.17104725683889, 64.10002839180731, 65.82862084911716, 68.46976449412685, 70.24503707885742, 69.32880278556578, 65.96975557265743, 62.45377040678456, 68.78712346476894, 63.936469477991906, 55.71765661239625, 63.795577941402314, 69.03958289853989, 65.87156295776367, 67.37048102963355, 68.7041731803648, 70.1203449310795, 63.55565048033192, 64.4198388438071, 65.74969491650982, 67.16182662594703, 64.78947908647599, 66.0448532719766, 65.65899402864518, 64.51397180557251, 62.849310059701246, 65.5503051511703, 61.081670407325994, 65.26429376294537, 58.20903239711639, 66.76762057888892, 66.1862547166886, 67.2227410347231, 64.17384347608014, 64.10408020019531, 60.56592972047868, 58.014016074519006, 59.771084939279866, 57.20059887055428, 58.683035142960094, 59.771547778960205, 62.673544729909594, 66.70962441352107, 69.90092754364014, 68.74047863867976, 73.8575086285991, 73.4752030526438, 70.3082186175931, 65.34159975667154, 71.35504430340183, 71.92112861141082, 67.97905245134908, 75.47244256542575, 68.72181600139987, 64.13860490245204, 49.84742172302739, 3.3702509730092944, 0.05328480890321155, 0.3524852051369606, 0.10765817512067095, 0.04251463924564662, 0.15330222224996937, 0.7320532731471524, 0.24516891207425828, 0.0393360638390145, 0.011910431203432383, 1.357345391185053, 37.02826092320104, 48.73112693909676, 37.40310615108859, 32.627087023950395, 52.5945556548334, 2.334432928792892, 0.027029010722593918, 0.112664406488259, 0.05540740871501546, 0.027585127353367787, 0.0997017544784373, 0.07296065874998608, 0.09898845767301899, 0.04986997964161058, 0.04752311142041318, 0.03409485798329115, 0.013656771719275464, 0.01069956795207315, 0.03413500099052345, 0.015240041801946299, 0.023985653665036927, 0.058876101618572596, 0.07105070962420396, 0.12751406329053064, 0.07722363927431646, 0.05499977333050582, 0.07736607034119868, 0.10286369811623328, 0.12823656081191956, 0.3943174975293298, 7.706436591763651, 77.60701994742118, 44.86582333041776, 48.254354999911406, 23.68296515557074, 79.60032924529045, 22.426420142573697, 0.17474162182019604, 0.06618191443023182, 0.7347297392064526, 0.09978915744971845, 0.28135437037675615, 0.08377366038339754, 0.16013002684039457, 0.15503972498399599, 0.3093701138371422, 24.306229775951756, 97.01227957202543, 96.46200241581087, 99.59363060612833, 86.40502960451188, 82.37091110598656, 73.58453519882696, 79.35023107836324, 75.17537009331488, 74.66998838609265, 71.97361776905676, 80.21239157645934, 86.7356304968557, 91.26647795400312, 89.38658791203653, 89.52925235994401, 89.88459556333481, 84.51288607812698, 85.53432618418049, 87.73131632035779, 79.37782887489566, 70.04925589407645, 65.79568862915039, 68.07599775252804, 64.49740763633483, 69.56265449523926, 71.14237339265885, 76.3655819431428, 77.73994122782062, 79.35070176278391, 76.76743661203693, 80.41786101556595, 74.56395887559461, 70.42589756750291, 74.909527532516, 72.94011331373646, 77.40928542229437, 75.05245870159519, 77.15299775523525, 75.73928140824842, 77.36511168941375, 76.01407481778052, 81.20373925855084, 74.6205351429601, 68.40623778681602, 78.99843369760822, 76.41701206084221, 78.19116284770351, 78.65776800340223, 67.35906693243211, 63.4397836654417, 76.21650049763342, 76.13293832348239, 72.27784464436193, 74.67954327983242, 72.06214566384593, 72.72896428262034, 65.94830020781487, 65.88333791302097, 63.637494656347464, 61.89809606921289, 67.24885617533039, 64.42443193927889, 65.94761771540489, 68.37627872343987, 68.29430118683847, 69.57255455755418, 71.81643270677137, 70.06727526264807, 67.67231525913363, 66.40673114407447, 70.69821203908613, 68.70487920699581, 60.440872792274725, 62.218565479401626, 70.55854428199031, 69.1522490593695, 69.7045030901509, 68.60681210794758, 71.19911439957158, 66.24786730735534, 67.69064841731903, 69.24905315522226, 69.57960697912401, 64.88790312120992, 68.68586355640043, 68.10813765372, 67.57642899790119, 66.40176542343633, 67.98637159409063, 63.321830149619814, 69.60423946380615, 62.51400624552081, 70.1972233864569, 68.53434239664386, 70.36251991025864, 68.18636540443667, 66.85711337674049, 63.86709059438398, 62.18415060350972, 62.986800901351444, 62.55060980396887, 63.250886240313136, 64.15916204452515, 65.82770301449683, 69.7826131697624, 72.56194976068312, 72.10268728194698, 76.40054595085883, 75.52520628898375, 73.48994331975138, 66.95146991360572, 74.7553470057826, 74.53373309104674, 73.68527735433271, 79.42359509006624, 78.13026412840813, 73.26170844416465, 54.69392584216211, 4.369016347392913, 0.07582037304077419, 0.11240960564464332, 0.21426382204217298, 0.02063518344995476, 0.18149824152069707, 0.1404918838412531, 0.08280141053781395, 0.03742806057656004, 0.01960976901764591, 1.4245847444380484, 44.795714885957786, 48.69951655787807, 33.86556363874866, 39.22360758627615, 60.645522456015314, 3.022269322987526, 0.14376320185199862, 0.1092383157341711, 0.03658317284838807, 0.05224809658923938, 0.014484808385942974, 0.025133937109081496, 0.06796666946742805, 0.038611624284737536, 0.005064186876669767, 0.02603050512862542, 0.04912250765389012, 0.0763048547049684, 0.2188767591911939, 0.183197072136306, 0.16149894935229134, 0.1309135324892498, 0.15792318800043675, 0.22826470705049656, 0.14728083245215878, 0.185302005960576, 0.20804579279595808, 0.2702149616614465, 0.24836595019986554, 0.7946482336809559, 10.09791058878745, 90.13930643758466, 55.72452860493814, 50.66390622046686, 26.84558987617493, 102.86432250853508, 26.720619240114768, 0.28852942730149916, 0.20715303989427708, 1.0814980898172626, 0.45680339778623275, 0.6375814553710722, 0.25939433745318846, 0.3557207315198837, 0.49989326947158386, 0.7985770389918359, 28.720394565213113, 104.9926790114372, 101.5854258691111, 109.07483869983305, 88.76227209644934, 87.59186821599161, 78.29081458430137, 83.08686917827976, 78.64436134215325, 78.04948683707946, 74.43195542981549, 83.87232380528604, 90.63616091205229, 96.86634386739424, 92.53428997532015, 91.06653905683949, 92.42447929997599, 85.99714233029275, 90.23293341359785, 90.25129010600429, 83.84888372113629, 73.29966129795199, 70.35389854061988, 71.99802275626891, 69.6329512134675, 75.84909992833292, 74.90927650082496, 82.10644137474799, 81.14089504364999, 85.17204823032503, 79.58821696619835, 83.42263190977036, 76.65351529275218, 73.36087380686115, 81.10977495870283, 76.58926686932965, 80.61558769595239, 78.71474435252529, 78.70726831497686, 79.64100422397738, 82.55533310674852, 78.21472844769879, 84.17339709497269, 78.71561511870354, 70.58537329396894, 82.02542874120897, 81.28027254535307, 81.296660207933, 82.32090873102989, 73.27466011047363, 67.50410049192368, 79.52196028924759, 78.82793611095798, 75.46556272814351, 79.59293949988582, 74.43401859652612, 75.93130496240433, 70.91830407419513, 67.65355848496961, 65.70597617856919, 63.97901150488085, 67.07948823128977, 65.41628168475243, 68.15144062042236, 68.43629883181664, 70.48980082235029, 73.22508919623591, 74.25375430814682, 73.74519548108502, 67.56102192786433, 68.04286941405266, 72.2223666406447, 69.02050449002174, 62.551829661092455, 68.30547209708922, 73.05965146710797, 70.19643106768208, 70.83363579165551, 74.80134071842318, 74.09195653853878, 69.07408406657558, 68.76434233880812, 74.41026472276258, 72.90101512785881, 69.71326566511586, 70.83363579165551, 70.76566896130963, 68.35054013036913, 67.93265865695092, 72.81157724318966, 68.98019036939068, 71.45874392601752, 66.10586181763681, 73.59540016420426, 72.56467973032306, 73.88523194097704, 71.750685937943, 70.27284668337914, 67.81378730650871, 64.58176212926065, 67.0063046486147, 65.34750292378088, 67.08943536204677, 67.01248630400627, 71.09848991517099, 72.7799629396008, 76.67694753216159, 75.56888580322266, 79.50017544531053, 78.42840348520588, 75.6503220527403, 68.89079955316359, 76.87236785888672, 79.75050110970774, 76.34324012264129, 83.26201085121401, 81.64823009121804, 82.92605984595515, 61.25142274364349, 4.741149746602582, 0.1869374044960545, 0.9588042057810292, 0.5005803277655956, 0.18068133132351985, 0.8273764903987608, 1.3265830999420536, 0.7536903540453603, 1.0523931225461345, 0.10399444389247126, 2.4647659351748805, 57.96482170781782, 60.650582313537605, 51.411349158133234, 43.4570844711796, 72.88369394117787, 4.078882302968733, 0.34060538776459237, 0.18643429923442104, 0.17112890438687417, 0.14608438697553452, 0.10475925244991818, 0.17198165217714925, 0.15924790723910257, 0.16479947063471043, 0.177630769209035, 0.09679139411497502, 0.12921727592906646, 0.15412120088454218], [0.07520686684837265, 0.10327533247970766, 0.09501167227544131, 0.038474191941561244, 0.022813173333903956, 0.10072689503431322, 0.021709593035460963, 0.0875102082688001, 0.04586527033919289, 0.13745428393444709, 0.07516013548499154, 0.5688455953232704, 12.967020427027057, 63.64180141879667, 45.933210080669774, 52.06217235134494, 40.35074772373323, 70.45824143194383, 3.255227467706127, 0.0489072714211239, 0.09843978550164931, 0.5507144392017396, 0.31942440497298397, 0.20054638956583318, 0.15561865762837473, 0.7589378724655798, 0.1004373674250899, 0.20956707487423576, 43.31995056521508, 98.26028362397226, 86.97276130799325, 87.71992575737738, 77.19827759650447, 73.62423742971113, 75.81085681915283, 85.43013234292307, 82.37349202555995, 77.28300079222649, 66.56469283565399, 75.90361302898776, 84.5971856578704, 87.87533790834489, 79.8132590324648, 86.65794403322282, 87.70096501996441, 87.90311613390523, 84.12053923453055, 82.64914835652998, 75.71971662582891, 73.45355156929263, 66.93034402785763, 63.759707866176484, 63.594132854092514, 64.70594044654601, 66.55895048572172, 67.97851900900564, 69.55116195063438, 72.73970373215215, 75.39688987116661, 75.86973944017964, 74.59414543644075, 65.34926799035841, 70.67557211845153, 70.21785505356328, 72.72252375079741, 76.19430772719845, 76.53393007093861, 75.949598896888, 76.65843394494827, 76.40289152822187, 68.28851961320447, 68.91426317153439, 79.7375572881391, 74.4368976162326, 71.75700879866078, 74.12681071988999, 63.983016244826786, 61.30788526227398, 73.4764503663586, 71.03419442330637, 71.74692046257758, 67.48124091855942, 69.53675116262129, 71.09446556337419, 64.75403262722877, 63.38341136132518, 66.47243868920111, 65.62963116553523, 62.1067661623801, 63.4654006650371, 64.6390954140694, 63.52294968020532, 67.07501672929334, 70.1875586663523, 66.55874652247276, 64.95527375128962, 67.98651279941683, 68.88739493585402, 68.90084866554507, 64.29977117046234, 69.31847910727225, 66.36132578695974, 59.188087371087846, 60.93797829843337, 68.1559984145626, 71.23662010315927, 64.88748734997165, 61.868658681069654, 67.53106286448818, 66.23715139204457, 63.23609498239333, 61.79797364819435, 70.54876973552089, 66.99373737458261, 63.91217431714458, 64.45670127868652, 64.42200399214222, 63.89986199717369, 61.18994743593278, 62.98600073783629, 62.875283994982325, 66.19893181708552, 68.47888008240731, 66.00961469834851, 64.8269102650304, 62.634426932181086, 61.190975096917924, 59.085486012120406, 56.61264342646445, 56.99763582598779, 55.9741953111464, 58.61196179543772, 62.10604836863857, 66.24830661281463, 66.18912589165473, 70.93303649656235, 71.44188557901691, 69.89341228238999, 65.16137469199397, 67.88851630303168, 73.04261269107943, 73.2655131432318, 71.71511788522044, 66.15187121975806, 76.00232339674427, 64.5141169332689, 69.05721003009428, 20.784480687110655, 0.0730628012529304, 0.23213507517451243, 0.2730334910654253, 0.20099127214522133, 0.15819053736425218, 0.8148706872617045, 0.15583267195090172, 0.3135743124350425, 0.08256694932858791, 0.16208923541970793, 22.906255452863633, 48.35763100654849, 45.06663691612982, 37.555815789007376, 56.05071290846794, 2.5474151776682947, 0.11774301784293306, 0.1295969031390644, 0.07798447183543637, 0.06534210586499783, 0.03406389270939174, 0.13692113270442333, 0.06419717214040219, 0.021036038956334515, 0.017903675888514808, 0.01425981219302142, 0.057257970704907374, 0.07893844282314663, 0.03910661284481326, 0.08350925279721137, 0.012948668032373874, 0.05947648089439158, 0.06333442690271525, 0.06851655205771809, 0.02987481094145727, 0.06532786429048547, 0.09892377686957199, 0.13328897195958322, 0.09882588615460743, 0.6879145351629103, 16.86522879908162, 71.16113801156321, 60.09551202097247, 55.73798233462919, 27.473724119124878, 82.60713977198448, 3.777313323751573, 0.05735090483100184, 0.06927219054271137, 0.3418639476501173, 0.5240721688155205, 0.2813948811061921, 0.0786464254281694, 1.3925116461130882, 0.08056063400281054, 0.4435729367598411, 46.17409460006222, 102.55833841139271, 91.98377747689524, 93.46837889763617, 82.51377167240267, 78.46838812674247, 79.13445365044379, 91.19554581180697, 87.25412860993417, 79.47113421655472, 69.68832723556027, 80.76416707807972, 87.42609316302885, 91.93708558236399, 86.34783360265916, 89.54734233117874, 88.21191649283134, 88.70583703441005, 86.85834577006679, 85.30773870406613, 81.08487575284897, 79.63720736965057, 70.92209308378159, 67.48539078620173, 66.25629255848547, 68.86702998991936, 71.49221743306806, 72.49679134738061, 73.899548592106, 76.76730325145107, 79.33733432523667, 77.98217896492251, 77.17817152700117, 70.91416989603351, 74.84943682147612, 74.99414874661353, 74.91014726700323, 80.03485725771996, 78.04474076917096, 78.68897438049316, 78.55102462153282, 78.84221353838521, 69.56274078738305, 73.85451193778746, 79.359785972103, 73.62937573463687, 77.32753538316297, 75.00413510107225, 67.83490534751647, 68.10380735704976, 77.42418258420884, 74.89766628511491, 73.50692718259751, 70.74819087982178, 72.54959429464033, 71.28122529675885, 67.30333005228351, 68.17653594478485, 71.14312648773193, 69.04004573822021, 64.98596237551781, 67.47140361416724, 66.49070124472341, 68.16960903906053, 69.0823288886778, 72.77957070258357, 69.76373087975287, 69.379409205529, 69.91803692233178, 70.03076584108415, 71.20724155056861, 66.07536146717688, 70.40477952649518, 70.71969878289008, 62.867137232134425, 61.62216124996063, 69.6701431274414, 73.25682901567029, 69.51298159937706, 63.098851250063994, 68.08610962283227, 68.93669128417969, 65.27196984137258, 65.83955641715758, 71.505828057566, 68.09427599753103, 66.56441042500158, 66.69084410513601, 68.1256784931306, 67.7369402300927, 65.30521977332332, 66.93443898231753, 66.43530953314998, 67.77460282848728, 68.90011910469302, 69.2077584420481, 65.29840269396382, 65.90516982540008, 62.72320978103146, 62.140980997393214, 59.66256864609257, 61.335435990364324, 61.51435098340435, 63.997909484371064, 63.568637447972456, 68.11704143401116, 70.10258443893926, 74.2915581118676, 74.30604734728414, 72.90339992892358, 68.66106633217105, 70.4450701129052, 74.48195780477216, 76.2095735919091, 76.42136589173349, 69.37648311738046, 81.26459875414449, 73.39430809020996, 76.40599804539835, 24.995305884268976, 0.04240525721181785, 0.1034729601815343, 0.5281255706664055, 0.3693013866582225, 0.15273265120002533, 0.39763502596366795, 0.1365466076400011, 0.16281856644538142, 0.10504281989509061, 0.0914065161299321, 26.845613410395963, 56.113070749467425, 38.961067661162346, 43.7670733082679, 64.62544164349957, 4.025578027771366, 0.16350185558680566, 0.11827263740762589, 0.04041834306272288, 0.05943856720301894, 0.05066389954018016, 0.04991219491667805, 0.0762831284514358, 0.10078572292601871, 0.06067432065103805, 0.11059538686587927, 0.017543970794987776, 0.06886648569977091, 0.16316635504124627, 0.2250250744362993, 0.16767214713317735, 0.09572346754852804, 0.13300476866143365, 0.217136375966572, 0.13621283845315058, 0.16786780598903858, 0.15062643034804254, 0.23906101562803794, 0.21922594206708096, 0.7601072290732015, 19.512824743024765, 86.83427810668947, 59.07414643995224, 65.17233379425542, 54.8949198569021, 96.43747191275321, 5.461315051201852, 0.1760817394261399, 0.37238538084972295, 1.531660056883289, 1.2675267914610526, 1.0023295831295753, 0.3434180949003466, 3.2594513700854395, 0.39255258416937244, 1.1821939123253669, 51.1311742567247, 107.7600759075534, 97.64393021983486, 98.85519735274777, 87.85097998957481, 82.52087116241455, 85.17837893578314, 93.65604077616047, 91.03790575458159, 83.81935611847909, 74.86596568938225, 83.41274753693612, 90.30548157230501, 96.46234758438604, 89.07490853340396, 92.50641761287567, 94.59945709474626, 92.93304597177814, 89.9427015550675, 92.30559226005309, 83.60769717924057, 82.03820782323038, 73.22229646867322, 72.22643806088355, 71.09604235618346, 71.60607599443006, 75.7990740191552, 76.12151638154062, 74.50265222980131, 80.99373555952504, 84.23063232052712, 81.89433528530984, 83.83222933738463, 73.63803632797735, 78.19193163225728, 78.77540772961032, 80.1314103218817, 82.47566192380845, 80.48887160516556, 82.64544563908731, 82.7086820910054, 84.11400456582346, 73.93239451992896, 75.98345679621544, 83.79897548306374, 78.71112792722641, 77.95002337424987, 79.51177781628024, 70.59477129290181, 69.6293112539476, 79.08303137748473, 76.87596074996456, 77.53504445475917, 75.12024510291316, 74.82369822840538, 76.63831218596428, 69.03802963995165, 67.8817698263353, 73.0327832314276, 70.48259150597357, 67.73009177177184, 70.50152870916551, 71.07076660279306, 72.0561993506647, 73.76937297082716, 76.67578651059058, 73.12318601915914, 70.78752440790977, 72.78223791430074, 75.41126143547797, 73.31814350620394, 66.2759671672698, 74.59479654988935, 72.41436666057956, 64.82896166463053, 66.65489166013657, 75.21279734949913, 75.50361756355532, 70.13648156196841, 68.55211073352446, 73.72007662250151, 73.69528724301246, 68.3893794398154, 68.89978962559854, 74.7020733741022, 71.71697708868211, 68.906583170737, 72.32104562943982, 71.0570304624496, 70.13225324692266, 69.69745066858107, 67.52034694917741, 71.42131666983329, 69.63914855833977, 75.61024327431956, 71.80892529026156, 70.23956145009687, 70.30933257072203, 67.92209963644704, 65.3762891984755, 62.223844989653564, 64.8613682869942, 65.56656337553456, 67.58052395236108, 67.37767465652959, 73.23498925855084, 73.08237767988636, 76.67195043256207, 78.70828028648131, 75.67181664128458, 71.81250249185871, 73.63321965740573, 76.66190916492094, 79.02677674447337, 81.09668208706765, 73.95591305148217, 86.39748296430035, 81.47981920549947, 85.1028968441871, 26.69084256695163, 0.2166616159581369, 0.5465502916805206, 0.945401712050361, 0.5197500846078319, 0.8099555897135889, 2.1510579557188096, 0.44662420367521627, 0.6234079707534083, 0.17944327195084867, 0.3094876930117607, 35.02321981614636, 65.15948410957091, 63.41095816704535, 52.3009584026952, 77.3546781847554, 5.069344755141966, 0.4671728574941236, 0.29194237964768566, 0.16828491022029232, 0.13173241919327167, 0.13694604588372095, 0.309374557147103, 0.25416592526580056, 0.15990282048381146, 0.12994786333893577, 0.23710778253453396, 0.1607729737917262, 0.21140818333914205], [0.00743589932925158, 0.06627155437825188, 0.014375381344448657, 0.09375824517900906, 0.0439487443485808, 0.09339754034074084, 0.0276608704664414, 0.03824634207112174, 0.02410530319227086, 0.15635735024848293, 0.10021101142610274, 0.40776948053990647, 23.498286239562496, 68.27728594503095, 38.28980107461253, 52.77299604108257, 54.82855335358651, 46.66087250555716, 0.4621968099907522, 0.06990579888224602, 0.19354687402805976, 0.13794781309702706, 0.2835433287245612, 0.07443845001680237, 0.5778752591821456, 0.8237426595822458, 0.21406155950840444, 2.4012762452325513, 61.82762284432689, 93.81102931114935, 88.31375691198534, 86.26040397151824, 72.65692603203559, 72.06794292696061, 80.90091659176736, 90.9537003117223, 87.95977084867417, 83.40354565651187, 69.14480440078243, 73.65888764781337, 83.62392010227327, 87.93819781272643, 88.22821001852714, 84.66332466371598, 81.16486072540283, 80.98235284128498, 82.44326314618512, 81.65613758948543, 82.43674416695872, 77.62339192052042, 73.27593095840948, 63.239625115548414, 61.06151726938064, 63.923490355091715, 67.13587622488699, 68.89014059497465, 71.3967469430739, 70.86037066675001, 74.91116708324802, 73.170529027139, 76.74551056277367, 68.10451338368078, 72.72497915452527, 67.75280229506954, 69.2773255994243, 75.23349961926861, 71.23381168611589, 73.88227447386711, 73.60107191147344, 67.64379178324054, 72.11985941856139, 75.50556305916079, 66.6606810785109, 75.0080104028025, 71.28404155854257, 63.88681227161039, 66.32345922531621, 74.85551649524321, 73.30641561938872, 66.82399288300546, 71.68102464368268, 75.01239561265515, 76.69255856544741, 69.90115504111014, 71.15309715270996, 71.14409923553467, 71.96499639941801, 70.12382799579252, 69.47728803080898, 65.27145993325018, 67.99547933763074, 66.34477338483258, 65.29417830128824, 66.19347187780565, 67.92475115868353, 65.42933533268591, 70.86626206674885, 66.27319797392815, 65.22697241075578, 69.76754342356037, 67.80441284179688, 66.550125152834, 69.53205216315486, 62.607613609683135, 59.100030160719356, 61.54507098659393, 72.10527604626071, 62.005753363332445, 63.81249904632569, 67.54239066954582, 64.75496615132978, 61.84841140624016, 63.413244908855816, 64.0593102670485, 66.34148643862817, 65.07752618482037, 64.15471799911992, 63.11428577669206, 63.56234204384589, 65.57390605249714, 63.12985758627615, 67.91258396640902, 66.41183022529849, 67.99521261645903, 61.735619729565045, 60.81485509872437, 60.39149407417544, 58.015302611935525, 56.6687725436303, 57.28831091234761, 58.89637677900253, 59.57629219178231, 63.258589775331565, 63.97204929782499, 70.06350978728264, 69.6805295636577, 72.23422004330543, 70.18009831828456, 62.64086746400403, 66.3906886500697, 74.65735050939745, 75.37264177876135, 75.46364076675908, 67.05794657430341, 70.08216457982218, 68.39457265792355, 71.36466195506435, 50.23113542987455, 2.206515366992643, 0.2034912621902843, 0.12986731685457692, 0.2580846948248725, 0.06246434637315332, 0.19155708321880913, 0.10620065454033115, 0.057176359358333775, 0.1574099397346858, 0.18179071856842888, 13.226160637794003, 42.057512191034135, 48.94864589937272, 27.777356755348947, 54.76457949607603, 7.088871665539281, 0.20605126756333536, 0.2539203021555178, 0.023043896034059506, 0.0758282331028773, 0.013763872726309686, 0.06493002717052737, 0.04870781659959786, 0.08458913799615637, 0.07912572067711623, 0.07375021194738728, 0.029479264424392776, 0.0773183583852745, 0.08772125783106012, 0.026148582260394772, 0.03984691808000207, 0.07763054687529802, 0.01546045583147075, 0.052191084325914426, 0.04326821695412359, 0.057725234543003386, 0.044342662928806204, 0.09488093171028361, 0.12805874414381482, 0.5383302295400251, 31.161358087293564, 72.78006492122528, 52.839648877420736, 41.635661279001546, 45.16927749879899, 63.79886488760672, 0.08445562419271277, 0.11461321925443989, 0.6389624973939312, 0.2187677602013273, 0.17585787321290663, 0.029254080539929773, 0.522756765206014, 1.485430266587965, 0.28246912023713516, 3.153423820772479, 65.61784836553758, 98.9043995641893, 93.87771744881907, 91.85566502232706, 77.8294183361915, 75.35882719101446, 86.17606516807311, 92.97689022556429, 91.50167895901589, 87.97254208595523, 70.74375860152706, 76.75690112575408, 85.30070197197699, 88.02638053894044, 90.41955194165631, 87.11615531675278, 83.63309060373615, 83.62261787537606, 83.9879160542642, 86.27666611825266, 85.54199049549719, 83.90577377811556, 76.36093001211844, 66.8577644901891, 65.33337454642019, 68.54944352180728, 68.78334229992282, 72.38335640199723, 73.70774469067975, 73.3490204042004, 77.20491424683603, 77.17097790010514, 79.30676337211364, 71.17274038253292, 75.37450882696336, 72.43695166803175, 74.6520160859631, 78.06114412123158, 74.25974768977012, 75.5087637132214, 73.89685000142744, 71.64406807191911, 76.44798309572282, 76.78911947434949, 72.7711925198955, 76.78793491855745, 71.29696184589018, 64.99301087471747, 71.12506005071825, 77.18991510329708, 71.8100941565729, 70.99966972104966, 75.78539279199417, 77.64954628482943, 75.01604341691541, 71.07519103634742, 74.25041244876, 73.04683316138484, 73.38519250192951, 71.67309361119425, 72.7960289678266, 69.13011120211694, 71.56481266021729, 68.38071884647493, 67.48848161389752, 70.87390284384452, 68.2300292291949, 65.42242019407212, 68.98270853104131, 69.96414830607753, 67.63404861573251, 71.03109575087025, 70.36679529374646, 68.05160845479658, 71.32594031672325, 65.98397808690225, 62.09524223881384, 63.07915702942879, 75.53236069217806, 66.85889413279872, 65.81874432102327, 71.15150467042001, 70.11701876117338, 65.97471344855525, 65.47874935211675, 65.98343679981848, 69.52115581881615, 67.63196975954118, 66.0743651851531, 65.78196425591746, 66.30784034729004, 69.0797636585851, 66.89645474956882, 69.01284017870503, 69.30587260953843, 68.5387432959772, 64.27314612173265, 63.24694033591979, 63.15755344206288, 60.51199713060933, 59.44219812270134, 62.110260994203635, 62.54964490090648, 64.43333571957004, 66.85744285583496, 67.35263424534952, 73.79313468933105, 72.13880446649367, 74.09102301443778, 71.63820805088167, 66.3306136285105, 70.10329046557027, 78.18827598325669, 78.60314507638255, 79.38764264506679, 71.09930576816683, 74.810715183135, 77.41174082602225, 78.87844054929673, 56.04980684095814, 2.7814872755158335, 0.1042818264555066, 0.2224550639549571, 0.40167932669001244, 0.3082536479398128, 0.05630896396694645, 0.26712915950244476, 0.07895526611396382, 0.12708638704592182, 0.26185393934288337, 15.497035480314686, 51.21657994485671, 45.11872206964801, 32.81843789162175, 64.3162961159983, 9.940805935090589, 0.3551726109318195, 0.2058571255615642, 0.06111038555841773, 0.18526780779563612, 0.03037448795962959, 0.07839788352289508, 0.03126306376690346, 0.08436650518448123, 0.027572979114108512, 0.04636481712241808, 0.05239122862657232, 0.010377410742934915, 0.1451917566479214, 0.10870646685361864, 0.09037950631952094, 0.14627502029461248, 0.1498649849165832, 0.15759050665843874, 0.07679619285608492, 0.10797106841158484, 0.25523824917693294, 0.17559072303195156, 0.22442341962408638, 0.5643164835149242, 35.00456110123665, 89.10099229504986, 51.676450390969556, 70.26590408817415, 71.84064942021524, 71.06828766484415, 1.4846601337194445, 0.21078310155820465, 0.9738089877270883, 0.5935642495751381, 0.9639359529941314, 0.290917752370719, 1.7584500293577872, 3.6487794595379985, 0.646753182574626, 3.4769970515081963, 74.92065137432468, 103.74704407107447, 101.93448543548585, 99.0951914941111, 82.42944855843821, 79.8674818777269, 89.77234517374347, 97.62569119853359, 96.46645822832662, 88.97323285379719, 75.93695317545246, 81.00559680692612, 91.81201688704952, 93.12430858612062, 95.42210363572644, 92.37421020384758, 88.5192185063516, 86.84391929257302, 88.70370326503631, 87.96516803003128, 88.45243623179775, 88.33458469760033, 78.76579792268815, 71.47709277368361, 68.60802019796064, 71.40760406371086, 72.52034910263555, 78.58172109050136, 77.73276329040527, 77.78237342834473, 83.1017271164925, 80.6708303574593, 83.13828360649848, 73.04187528548702, 77.73379879613077, 75.29544168902983, 77.4074262188327, 84.08637539032968, 76.62114004934989, 80.27749507657944, 79.5305581246653, 75.35987838622063, 80.02239981005269, 80.1081742009809, 74.65731913043608, 77.49612669790946, 77.42736754878875, 69.8536394488427, 71.71465504554011, 81.66892451624717, 77.99363228582567, 71.3242458528088, 76.61684113164102, 80.04581635998142, 78.9447364499492, 75.82444390942975, 78.77066950644218, 76.65014989914434, 78.15985448898809, 77.3956669530561, 76.36380118708458, 70.52252123432775, 74.2796419512841, 73.13349400797199, 71.36128087197581, 75.14632101981871, 73.2972921863679, 70.56125856214955, 73.10100109346452, 71.00903634102114, 69.44608165371802, 74.0295280948762, 73.26818819968932, 71.29601263230848, 77.37905179300617, 67.53908018912038, 65.2797165224629, 68.76703308474633, 79.06774197855304, 68.93464380694975, 69.6127353175994, 75.39041011564194, 72.39687288961103, 67.00645369868126, 68.76632705811532, 71.62946901013775, 72.79086712867984, 69.18639721408968, 70.42621920185705, 68.89543579470727, 67.7366578194403, 70.65873730567195, 70.42384224553263, 72.1506735586351, 73.92244738917198, 73.09307790571644, 67.71344523276052, 66.47367815817556, 67.21935210689422, 62.547103205034816, 64.67119609155964, 64.45241805045836, 66.93317597912204, 67.4010362932759, 71.62465233956614, 70.89271453119093, 77.55176159643358, 75.51379219178231, 78.19951749617054, 75.26652597611951, 67.702666559527, 72.3587788304975, 80.73581618647422, 83.21966494283369, 82.82890273678689, 74.22984353957638, 78.23046499683012, 84.69175400272493, 86.41546310917025, 61.156081691865005, 3.212170384583935, 0.6256298095949235, 1.0458132240080065, 0.5568981783524637, 0.6651004367778379, 0.33142213859865743, 0.47827932442868915, 0.134605708562078, 0.3517877893342126, 0.4095913295543963, 23.860103314922704, 59.09326799454228, 65.05727106525053, 38.578616957510675, 73.77522514712426, 11.637535018305625, 0.6209480317850268, 0.413623740596156, 0.12600564382850163, 0.27976899738273314, 0.1524078299201304, 0.21569971596041035, 0.16839727999702578, 0.19917763559327972, 0.1188679030465503, 0.25983459286151395, 0.10910439590412764, 0.13141423223480103], [0.03744506389803944, 0.05461358074699679, 0.06040453129718381, 0.025984409618221467, 0.027559790910492023, 0.021374634497108, 0.012812801381392826, 0.03915250151147766, 0.031765245892588174, 0.04651082198946707, 0.036570658802144954, 0.09514080405595804, 41.92169227907735, 53.56624441762125, 36.219978101791874, 38.106210616327104, 49.625003722406205, 34.63778811116373, 0.16666109493422895, 0.12712328950123442, 0.27223081478188116, 0.19488199674073728, 0.40286265674137306, 1.6127138753091137, 0.20117139473797815, 0.3866698869293736, 0.24011827825057894, 5.220171165081763, 69.99690009701636, 92.80105037073936, 83.36604779766452, 81.4151236318773, 68.51465209837883, 75.9891285434846, 87.85516908091884, 88.30435106831213, 87.69260252675703, 87.6674444444718, 72.70792468901604, 72.79862557688068, 79.29538065387358, 87.93629938556303, 83.87953312166276, 80.24395881160613, 79.7952239744125, 80.6078920056743, 79.94725504229146, 82.93577947924214, 83.42294569938414, 78.48537983432894, 73.39597901990338, 69.44556390085529, 61.924226899300855, 63.87292708120039, 66.8136299810102, 68.34457028296687, 70.08573393667899, 73.25993553284677, 72.64726915667134, 74.38948400558965, 74.14264140590545, 67.73949761544505, 69.94011986640193, 71.13781559851863, 73.39863054213986, 73.53651754317745, 74.7651372417327, 69.20492649078369, 69.38671265878986, 73.4408038662326, 75.24137573857462, 69.30042835973924, 72.8984812767275, 71.00070522677514, 60.674740191428896, 69.42722289792954, 73.23625226174632, 70.44889050145304, 72.60804545494818, 74.90585619403471, 69.84251560703402, 66.71223671205583, 54.02280438330866, 54.70344543457032, 63.790867174825365, 68.60871053511097, 64.12174263308125, 65.27784162952055, 66.16811767701181, 66.29459058084797, 65.56113873758625, 64.08169915599208, 67.62437605088758, 65.11119581037953, 51.824249221432595, 54.10244026491719, 55.75573105965891, 65.58713228471818, 66.8475898619621, 64.22232789378013, 65.87931356122418, 64.87597911588608, 62.75328651551278, 68.9118548362486, 63.633803706015314, 60.99191088830272, 60.00286955987254, 66.63661341513357, 65.14128823434153, 65.35773638756045, 65.3974150842236, 60.44335173022363, 64.37536701079338, 61.843673183072006, 63.286317010079664, 66.41999659999725, 64.1745573474515, 65.52378992880544, 63.66750078816568, 61.69676473063808, 62.49508473180956, 66.96848515541323, 65.17205922834336, 65.59658911920363, 63.4035409650495, 60.256792037717766, 57.80213356018067, 58.48920337615475, 56.08349215599799, 55.81760252675703, 58.3608869583376, 61.32714017744988, 62.167527598719445, 66.82618156556161, 69.10566699120307, 68.60244258757561, 69.8475754645563, 67.70339612037905, 65.26606275189307, 68.03693094561177, 75.05179974340624, 73.7010217482044, 74.95756087764617, 67.67371162291496, 65.79515910917713, 71.72931686524423, 68.30011413943383, 69.02048880054106, 10.873849545755695, 0.19535609791355749, 0.45504884193501166, 0.051850094760377566, 0.07005653434222744, 0.18296871664783648, 0.26777990522884554, 0.01675283179558333, 0.3312642938427387, 0.21561418990454367, 6.319667908453173, 34.03567683312201, 59.29591724949499, 28.150197652078447, 51.9582530759996, 13.198404965862153, 0.5657802017465715, 0.25451080272755316, 0.04421312129125, 0.06122338735768872, 0.023610057992740505, 0.09929783462036042, 0.021485496995850437, 0.10325507711498969, 0.022165495789639895, 0.06503974628304282, 0.04348316207347859, 0.021786839596085975, 0.0778242445460731, 0.02555832492127534, 0.07371432072813473, 0.029580928122384414, 0.028350751794454072, 0.07690067958807753, 0.017138570471997225, 0.07765957394674902, 0.057225959720991315, 0.07950529426095948, 0.03774328660520335, 0.09089510647519942, 52.49662191637101, 58.74025075666366, 50.243459516955966, 33.331764359628, 50.09201288223267, 41.95661314072148, 0.21117625788094538, 0.1447901120709796, 0.7207630370413104, 0.22563644324339208, 0.5712604270346704, 2.115987063415589, 0.5079298995194897, 0.723043037278037, 0.2794524192089035, 6.0984609396226945, 73.56368387899091, 95.11815917107367, 89.96570233375796, 86.06852946742889, 72.74306912575999, 81.2854814529419, 89.56271802225422, 95.29252421471381, 91.11465084937312, 89.81202387040662, 74.50217370064028, 76.41714542142807, 83.66133951371717, 88.68293823734408, 86.40364893021123, 82.80991846515288, 83.46133785863077, 84.2985285482099, 83.5642686966927, 85.16344255016696, 87.49641341547813, 82.08992819632255, 77.92299039902227, 72.44833438627182, 67.54658760563021, 68.14311735091671, 70.53066407480549, 72.99971765087497, 72.54828422300278, 73.66074685127505, 78.28921425727107, 76.84695090017011, 80.43107940304665, 72.80923166582662, 71.91653159356886, 77.65294305739864, 75.22614909756568, 75.87144174883443, 76.94319017471807, 73.78912602701496, 73.68296315593105, 77.64259584488408, 78.10367830338018, 73.00295752863731, 76.0855717812815, 70.79374528700306, 64.96868433490877, 73.39618298315233, 73.32736892084922, 71.69227400133687, 78.50072414644303, 75.44808464665567, 70.33245102051767, 63.5339048600966, 57.83714855870893, 57.2469691307314, 65.00350321492841, 68.24036859696912, 67.85077525723365, 66.44302091290875, 67.05385946458387, 66.65845317225303, 66.298097179782, 66.735959206858, 69.16145878453409, 64.28180671507313, 52.727151378508545, 55.87465340091337, 56.72094398929227, 63.83546060131442, 69.07213857097011, 67.41501562057003, 68.96143359522667, 66.77990544226863, 64.92735824277325, 70.15368507754418, 69.1260633160991, 63.98015683697116, 63.12831609479843, 67.92802241540724, 69.39738150565856, 68.08463481164748, 66.30409056140532, 64.11689850591844, 68.27708198178199, 64.84610242228355, 67.25807374523532, 68.41691447842506, 67.70451007350799, 66.9107400217364, 65.78362341850035, 66.60297516853579, 65.4203531049913, 68.31578793064241, 66.87925907873338, 68.55048687227311, 66.48240935417914, 63.921764512215894, 61.65673694302959, 61.246362886121204, 59.23848982780211, 58.14751786570395, 60.5873772405809, 65.02761402437764, 67.37037904800908, 68.80436620404645, 72.80600747754498, 71.18357396894886, 72.11463482149186, 70.11008401070872, 65.76916163967502, 72.38470569733651, 78.70593470911827, 76.00633990380072, 77.70841321637555, 71.31178056040119, 70.89057291707685, 78.50081043858683, 77.26495788943383, 77.02939602636522, 13.488747631349872, 0.1152484670221325, 0.3196260086711376, 0.024540776296729044, 0.13566879345284355, 0.31788763259687736, 0.14917038831739657, 0.05957358253879413, 0.2275877304735684, 0.2514353733990462, 5.685049007015844, 43.9009085009175, 58.75392413908436, 29.229129898932676, 66.50951293206984, 15.208843254273939, 0.47131503361367416, 0.21310894449632015, 0.10678367809422555, 0.07844932632701052, 0.08074314678989111, 0.10369760780445031, 0.01757793721833056, 0.037808584109429395, 0.04276997252036968, 0.10380086879576407, 0.07005936886754728, 0.030718386744058905, 0.14382130196017606, 0.07645845533378663, 0.21191233048035255, 0.23933786448211442, 0.13617755244335822, 0.25818909728719347, 0.10281797032803298, 0.14624904991397936, 0.13564335933375743, 0.19664545453363852, 0.14417767074079285, 0.15282554702172357, 58.480840882947376, 71.46082278220885, 51.80446478628343, 56.81091531630486, 67.76414578960788, 51.49010642882317, 0.2160403646168209, 0.24201117425916657, 1.1507157885259198, 0.8891666296028322, 1.1050063251487672, 4.023785994898889, 1.6065835784519873, 1.2271025993170277, 0.3684797420376732, 7.9583047282311234, 79.67010036591562, 99.87109122737762, 95.78777051741078, 90.1030872714135, 76.74411419899234, 86.33960447003766, 98.08904078698929, 96.56181889195597, 97.66181622782062, 95.20831877185454, 80.34248090559437, 80.71445495851579, 88.82395528977918, 94.77119415037095, 91.35012642029794, 87.30468796145531, 86.5663331554782, 88.94473291212513, 86.62676119035291, 90.18246819896083, 90.33973955339002, 84.54640665361958, 81.00045065726005, 78.4079679366081, 70.10466329513058, 70.17867842028218, 74.84886415543096, 77.66153304807602, 75.96960298476681, 76.43449014233005, 81.07261442369031, 80.57653657851681, 81.62805341905164, 78.42413594645839, 78.35249777763121, 82.10921056808965, 78.15211957500827, 79.52498051428026, 80.56199242991786, 77.23728949023833, 75.605222640499, 79.18311457480155, 82.28128494754915, 73.33103241459017, 76.49871503153156, 77.2842324164606, 67.76282787322998, 76.36799812316895, 75.81495177361273, 75.96041679382324, 80.02740475439256, 78.94572488723263, 75.71269558322045, 73.47545408433484, 63.314071701418975, 62.48722430198424, 70.40543063994377, 70.19693313106414, 68.72445967889601, 70.64143180847168, 71.8380057427191, 70.54273713019587, 71.1032908962619, 70.65115928649902, 73.66778358336418, 70.35405543542677, 56.191035701382546, 58.70936601392685, 61.470514574358546, 70.94824744809058, 70.9996618763093, 69.20421261941233, 72.6148860685287, 69.30975575600901, 68.35546662730556, 75.7466789983934, 69.0663726868168, 68.04311260100334, 67.50176275930097, 73.54378177273658, 71.82045705856817, 71.53612444477697, 70.25169726341002, 66.93646292532644, 70.86738386461812, 68.36455868136498, 70.17678783785912, 72.93963478457543, 71.11319095857682, 71.55418303705031, 67.07522853728264, 67.44092679792836, 68.61907343710624, 70.67996517304452, 72.20962678232502, 71.65366218936059, 69.43687192855343, 66.8136299810102, 64.70444602351036, 66.58539510542347, 63.295420831249615, 61.94021840249339, 64.4970703125, 69.46133967368834, 70.42562300159086, 72.64853215986683, 76.01385516505088, 75.23951653511294, 75.41895712575605, 73.14877556216332, 71.86583888146185, 73.85691242833292, 82.53638805881624, 78.39309430891468, 81.55352838577764, 74.27079308417537, 75.8909986865136, 85.15802967932918, 85.71934438520863, 81.26302196133523, 16.028117537498474, 0.29667058238579386, 1.4789039329175027, 0.1777656466489838, 0.42059201506837723, 0.28116621918255286, 0.8637282204243445, 0.17218153983835252, 0.7158437719748867, 0.4500660835014236, 10.576150475009795, 52.240444075676706, 74.2185784924415, 38.16455587264031, 72.05181414081206, 21.1534756998862, 0.9134183992301265, 0.5858669658341716, 0.2524444797346669, 0.22949619338877741, 0.11611941706148848, 0.2432831560051249, 0.14556735423543762, 0.14807152712056715, 0.3579530198006861, 0.18693812461870332, 0.1702960748826304, 0.1708945274473198], [0.04031755653540454, 0.019903692056334788, 0.03737953273699649, 0.02390355010697198, 0.044204931811339436, 0.1847688240870353, 0.047313613186199824, 0.1400500502918036, 0.03144640584416207, 0.016816574141323086, 0.12135355958654997, 0.09367683301529578, 49.97667950968589, 49.54713682974539, 33.03761797566568, 28.164771218453687, 59.80473887535834, 15.151617834644934, 0.016695836769236673, 0.1759651255223059, 0.4760204682186727, 0.2094574630140297, 0.12727286050757095, 1.4889171310970861, 0.34565289594954063, 0.06332093226392904, 0.2786725723455029, 13.819814305151663, 91.51209677419355, 87.58619646872245, 85.66781228588474, 76.50704614577755, 68.81698839126095, 79.57132724023636, 87.17113125708796, 90.48551836321431, 89.07903486682524, 86.47213351341986, 83.34528276997229, 76.83374035742976, 82.59420379515618, 83.58648500134869, 81.6869281953381, 77.53950026727493, 75.40591916730328, 77.72855066484021, 77.37776525558965, 80.1173839261455, 81.7961112914547, 77.39268595172514, 75.86881376081898, 68.2334573807255, 63.041835677239206, 61.62782123011928, 65.21034156122516, 66.04450810340144, 73.17830316482052, 73.36831062070786, 73.51997298579063, 78.21823504663284, 72.58097325601886, 66.55748351927727, 63.42575334733533, 72.64467254761728, 69.45670343214466, 71.12702908054476, 71.3656190133864, 72.84280715450164, 73.11859684605753, 69.90848202859202, 72.09738423747402, 74.19185146208733, 65.64856836872717, 62.42809849400675, 72.85533520483202, 75.71144826950567, 66.47359186603178, 73.05890621677523, 74.55077186707528, 62.44747108028781, 54.988990060744754, 58.589843550036036, 62.76607344227453, 58.957569676060835, 52.527514503848174, 63.64793600574617, 70.99426469495221, 66.1725107316048, 67.35722341845113, 66.02380583363195, 64.18475943226969, 70.08556919713175, 59.97909999662831, 48.87371686197097, 57.56780724371634, 60.282397270202644, 59.58232479710733, 55.36991496239939, 54.9391955714072, 62.82030805464714, 67.73748151717648, 68.6028975825156, 61.690300664594105, 60.66366734043245, 67.99432616080007, 65.88187879131686, 64.64257847878241, 58.40852806645056, 62.292000093767726, 64.60286840315788, 64.2018727333315, 65.13853473048057, 62.50436505963726, 60.66714256040512, 60.51140877508349, 63.89821852407148, 63.007620842226096, 59.8015852897398, 62.388004026105335, 59.89111731129309, 62.925278525198664, 64.33176986632809, 63.511982733203524, 66.16778819791733, 60.91264763186055, 60.03568410873414, 58.653491850822206, 58.11588395026423, 53.16360135232249, 56.32814215075586, 58.833434504847375, 60.16027035251741, 63.556403575405, 67.44370383601036, 68.56516438145792, 71.07146478468373, 71.88118319357596, 67.7386268492668, 64.18761491775513, 68.21524189364526, 74.47453668040615, 74.19869992040819, 75.79117436562815, 69.64482030560895, 63.60719042439615, 72.8374021284042, 67.85949076375654, 78.23358720348728, 29.556349708187966, 0.1075492757222345, 0.06297288319816993, 0.19786566405767397, 0.13859929426783515, 0.11647306622997408, 0.19541329403798427, 0.05070646721569281, 0.2940125330801933, 0.04330517303559088, 2.3356782813226027, 18.34831226256586, 58.204474602976155, 34.22314259313768, 40.63640609864266, 27.087780544834754, 0.31952228036619007, 0.18691292032599452, 0.06877568129810595, 0.09017465440856834, 0.07138339096620198, 0.21597728493713567, 0.019697060906178048, 0.03789178508844587, 0.08335846371107525, 0.023530020956851305, 0.014188422374577533, 0.03947599362882395, 0.006375561821304503, 0.041199687628015395, 0.14497961157992964, 0.045306485807222706, 0.05235811064560568, 0.0922605739305577, 0.05681297321233058, 0.10799105564552931, 0.0541428656828019, 0.034262903199921695, 0.12596936190440772, 0.5772606115187369, 62.43741804553617, 58.933502012683505, 44.30464590749433, 27.302495010437507, 65.88265542061099, 19.338396941461873, 0.08625249874087111, 0.14099339564000407, 0.5788876596958407, 0.12300940500872752, 0.18061413009080196, 1.845232714568415, 0.3302442018062838, 0.14462587814177238, 0.20089921902023977, 16.07593515226918, 92.61255694973855, 94.33043741410779, 92.86672653690462, 85.46974828166347, 72.74630900352233, 82.3059723454137, 90.67002665612006, 93.11618927986392, 92.4073071633616, 92.09817732534101, 88.67907862509452, 81.67855001265004, 84.20662741507255, 87.80280543911843, 84.77476704505183, 81.77970793939407, 76.65599423070108, 80.8184056128225, 79.9498281171245, 82.86909918631278, 82.20563027166551, 80.39937096257364, 79.77490609691989, 73.6497720595329, 65.45691743973764, 65.05006567124398, 68.33381514395437, 68.59916348611155, 76.0950796065792, 76.99067438802412, 76.86031049297702, 79.86527750569006, 74.3505270250382, 69.5643646486344, 67.93513759489983, 76.60002200834214, 76.13385615810272, 74.81149181242913, 72.02680510859336, 75.1350010595014, 73.37762232749694, 72.80650954092704, 75.43882000830867, 76.01427093628915, 65.70531329801007, 67.19145621022871, 75.27389218730312, 77.28455405081473, 72.0802983930034, 75.53356878219113, 74.89020593704717, 62.3391979740512, 58.35882771399714, 65.65522855327976, 68.82445658406904, 61.615250033717004, 56.16526572935043, 64.25962178937851, 72.76349682961741, 71.08112166004797, 70.67923561219247, 69.86897591621646, 68.66487887597853, 71.9288243016889, 61.234580086123565, 52.850757029748735, 64.12551595318702, 64.3735234968124, 62.67988328010806, 58.24103109298214, 58.61882986560945, 62.24373532879738, 70.90079461374592, 70.11432801523517, 65.5984365555548, 64.46805261796521, 66.44340530518564, 68.7669389478622, 67.92324496853736, 61.62925681760235, 64.24280266607961, 67.85464271422356, 66.57331420529273, 67.09572684380316, 64.68006064814907, 64.93535987792477, 63.05154354341569, 65.73365634487521, 66.70731021511939, 62.02582413150419, 65.16022543753347, 64.01950997691002, 66.62055523164811, 68.05016502257317, 66.32599307644752, 69.34980315546836, 63.25635402433334, 64.04574278862246, 62.46037567815473, 58.7342103065983, 58.49533404073408, 60.14341592788697, 60.79432933561264, 64.39395512303999, 68.24651102865896, 72.1494968475834, 73.5458920078893, 72.50465962194627, 73.65090170214253, 70.21310114091443, 66.55595379491007, 70.05137397396949, 75.94332310461229, 77.19034656401604, 77.54965920602122, 72.86403502187422, 67.01531825527069, 77.96830946399321, 75.20022223072668, 83.45820780723326, 33.044333073400686, 0.1829558004054331, 0.10700855554351885, 0.29044979522305153, 0.1464619457481369, 0.1280601001194408, 0.02611648317636742, 0.10603141805697834, 0.14480118970236472, 0.06738733079644942, 2.0029633540299634, 21.333840008704893, 63.34250104042792, 32.35132282780063, 49.94057409224972, 36.11547439329086, 0.13238052957721297, 0.12070976227762238, 0.1496939940918838, 0.04649275380577292, 0.04613962174663621, 0.04887819072351821, 0.04080874529937583, 0.027196525423336896, 0.11806096731414718, 0.05364479361883095, 0.02263589292734621, 0.05502742527413273, 0.07533491078403688, 0.11124902074375462, 0.24555253826322096, 0.14441914165452605, 0.18003069284942844, 0.389560152806582, 0.17044002280360268, 0.22189698422387724, 0.1441121089362329, 0.09345868947885691, 0.24857913714743432, 1.0110490733096678, 73.42441620365267, 67.41714154520344, 44.59931396668957, 38.82173722790134, 86.17137401334702, 25.857078067718017, 0.13012338940414692, 0.46431890418452604, 2.0550704483062994, 0.4673360342219953, 0.3056943320458935, 3.4062700983016723, 0.9938203074759053, 0.4232602073780952, 0.5141957632956967, 18.305319163107104, 99.9269457786314, 97.19137499409338, 99.403850647711, 91.6817706631076, 77.39955009952669, 88.6617966621153, 95.44282943971696, 97.9981908490581, 95.80596247026998, 92.0135953349452, 91.89619095094743, 82.79204030190745, 89.15600745908677, 89.64374634527391, 88.48689817613172, 85.76427905790268, 81.33133396025627, 85.70103476124426, 85.11731547694053, 86.24129418403872, 88.93870815154045, 83.09180351995653, 83.30441951751709, 77.3413029024678, 69.43997060098957, 69.42664238714403, 72.88156801654448, 73.47397927315005, 78.86204504197644, 79.79101919358777, 82.5338306734639, 83.43887836702409, 79.68401693528699, 72.1741371770059, 71.56263182240149, 82.14598671082528, 78.00648981525053, 79.70887691743913, 77.4145100193639, 79.74423316217239, 77.8980049010246, 75.43082621789749, 77.7525241913334, 79.4498828149611, 70.33918180773335, 68.77416395371961, 76.988964234629, 81.00962115872292, 74.33418643090033, 79.94351310114708, 81.16100111315328, 67.30733871459961, 61.96250923218266, 66.04828926824754, 65.81719106243503, 65.29368016027635, 60.85866405117897, 70.02621589168426, 79.54117990309193, 72.81964948100429, 73.01255949081914, 70.51319383805799, 69.47351471070321, 76.0436337993991, 66.47843991556476, 55.490461164905184, 62.56899395296651, 64.28288928924069, 63.648979356212, 61.73222295699581, 62.78947430272257, 67.11595058441162, 72.92323143251481, 72.87096977233887, 65.39661884307861, 65.51439192987257, 72.68519063149729, 71.61687035714426, 71.0840634376772, 64.81248378753662, 68.42249993355044, 72.13572932827857, 68.68791103363037, 74.01370525360107, 66.49679660797119, 66.76291373468214, 66.65670379515618, 70.9002847056235, 68.78640174865723, 65.1449203491211, 63.696059565390314, 67.98065277837938, 70.96118342491889, 71.55282589697069, 69.7627502872098, 73.39047985692179, 67.43763985172396, 67.59989261627197, 67.16160697321739, 66.34074118829542, 61.029577409067464, 62.86386989778089, 64.87021715410295, 68.97729566020351, 70.99370771838774, 75.5518627166748, 76.29378687950873, 78.26047897338867, 77.30956308303341, 73.5915562414354, 69.30118929955268, 73.27753913018012, 80.07974486197196, 80.3715221343502, 80.88307765222366, 75.08198630425238, 72.25176872745638, 83.65784075952347, 83.54515890921317, 88.96638439547631, 37.27882977454893, 0.4743685068622713, 0.5265214438399961, 0.596345393888412, 0.26936972153282934, 0.3373333343094395, 0.8579201707916876, 0.1611688114222019, 0.5872667004023829, 0.2008398165625911, 4.4313928196507115, 28.084839197897143, 76.69786160992038, 45.434621918586, 56.08969342324042, 42.353458942905554, 0.7357858986623826, 0.3125298281590785, 0.21519812755286696, 0.13689174557164793, 0.1433323386816248, 0.29541622066209394, 0.24624875896880705, 0.12756166033326619, 0.2592817531718362, 0.14131510660292643, 0.14810624622529553, 0.07955485248878118], [0.089415890284844, 0.03594098049366186, 0.06923758635117162, 0.029079521660723036, 0.06550670751640875, 0.025932361604645852, 0.08337448260957196, 0.04359853874531485, 0.06414893924468948, 0.11201937577777332, 0.37917929371037795, 3.799646564068333, 61.09202938695108, 39.762584394024266, 41.04978861347322, 45.75154942850913, 50.50880393674297, 7.901969196334963, 0.16929824536125507, 0.18368675553750607, 0.44952007731603044, 0.15271094026825122, 0.12037167235487893, 0.6695831543014896, 0.48204403370618826, 0.12170207596594289, 0.1681444863037717, 30.389784728327108, 98.68258953094484, 85.33366557090514, 85.24498862604942, 74.85270807819983, 72.26117457112959, 76.1210064734182, 88.84722278964135, 88.79976211055633, 94.38167141329859, 93.37588156423261, 84.20192057086577, 74.89261427233296, 78.58174462472239, 81.10693516269808, 77.56176364037299, 70.48834954538654, 66.20460356435468, 71.60217715847877, 75.43914164266279, 78.40453194033715, 80.49653591648226, 85.53539306886735, 76.9809861336985, 71.39366396011846, 61.46096752535913, 62.08262005159932, 62.0344651129938, 65.5901328979, 69.21303795230004, 73.17550259251749, 75.65293435127505, 75.7716880306121, 64.37133873662641, 61.778620673764145, 68.42684591970136, 68.14655334718766, 71.81458919279038, 69.4048418537263, 71.56132959550428, 72.36874165073519, 68.46724633247622, 74.65497355307303, 75.01162682810138, 64.37960317057949, 63.56828835702712, 74.5845199400379, 71.62178900934035, 70.40656812729375, 72.24994874769642, 69.65329262518114, 58.16762001283708, 58.35060642611597, 71.01196242916969, 75.44085964079827, 69.5110047248102, 63.788584355385076, 55.96241643351894, 50.102724875173266, 59.76443259946762, 64.59726725855182, 66.36536582823723, 68.19944258659118, 63.87118162647371, 54.44190571385046, 50.00833303697648, 55.173800376153764, 65.42825275851835, 69.93639361473822, 67.70472188149729, 67.30722888823479, 60.13298634559878, 53.13759996045021, 56.01766301739601, 65.79739486017536, 66.49962071449526, 68.35909874208512, 63.41636319314281, 65.64115116673132, 65.6415355590082, 63.22897195816041, 61.413879471440474, 64.69207094561669, 63.31217327425557, 62.5890294198067, 61.57819540269914, 64.22774076461792, 61.665609344359375, 58.35951805114747, 58.902460375139796, 64.42778948814639, 64.93298684397053, 58.063598755867254, 64.83191913174045, 62.61111236387684, 64.13207023374497, 60.792030826691665, 62.12551509180377, 58.03639319635207, 57.93402717959497, 52.92120279804353, 56.37275911146595, 55.54470754438832, 58.75592454787224, 59.44212752003824, 65.75452727656211, 67.68195644501718, 69.05230706737888, 67.88503323831867, 68.61238187359226, 64.48611513260873, 65.36485941179338, 72.52515008372646, 72.5143478762719, 75.49053253666048, 72.82307763253489, 73.06075757549655, 62.20041667261432, 70.92559968271564, 70.429655198128, 78.18871528871598, 51.74861023502966, 1.4204218839445424, 0.06011688060337498, 0.04041989439076955, 0.06684337006581408, 0.16029282052430416, 0.08869440399951513, 0.1106434282396109, 0.05990257133699714, 0.3333021490083587, 1.1601859835847732, 10.41809856891632, 50.308782669805716, 35.74949372199274, 42.37233338817474, 40.84899071724185, 0.05338525452140359, 0.04525803457645159, 0.04857532169309355, 0.04801776673224184, 0.02819920619649272, 0.02440247827419831, 0.10752712812034354, 0.06690499417844319, 0.05721002126172666, 0.026218210076612812, 0.08560327752943962, 0.04510448757378806, 0.06949567371198247, 0.04150364067285292, 0.049402654516480626, 0.03479795432799766, 0.03919581612271648, 0.08709328789864818, 0.05025161400197014, 0.08793285897662563, 0.04657867056648097, 0.17796201030573539, 0.39362795711044346, 5.499157098031813, 69.62074479749127, 51.07150323929326, 47.47809440858903, 32.97642115623721, 64.0126536738488, 8.912088851774893, 0.12223440748188766, 0.12526966315964538, 0.1270973344423598, 0.07356442030399077, 0.24580395299821134, 0.6330300350823711, 0.3201107891096223, 0.27733541183894683, 0.046118849272569346, 32.53414842390245, 105.46577176740094, 89.50453358311808, 92.94645263302712, 78.72247142176475, 77.58493700335103, 78.59420207238968, 94.12015914916994, 89.67186973940942, 96.61983859154486, 96.19507728084442, 87.80140907533708, 79.56136441999867, 81.19103862393288, 81.81006708452779, 79.57055845568257, 71.09914887335994, 69.39516928888136, 72.31302046006726, 78.02285394360943, 80.95899120453866, 82.10571181389594, 83.79502173393004, 78.4082660367412, 74.80857356902092, 65.98440954762121, 65.99148550341206, 65.08455507216915, 66.7464868484005, 73.24324192539339, 77.43566728407338, 78.1692603326613, 78.19056664743732, 66.4357017701672, 68.19595952187815, 70.70757081431728, 72.05518737916024, 75.99195265000867, 71.93125617119574, 75.93414475840908, 76.09085129153344, 72.65363124109084, 78.0636622828822, 76.70460808661677, 67.45755764745897, 68.30311867498583, 77.84147570210119, 72.56928459290536, 72.80527791669293, 75.90517413231635, 68.4789114613687, 58.58422671594928, 65.8588074099633, 73.33751217011483, 76.89463907672514, 69.9334361476283, 64.39469252863239, 56.621888452960604, 53.17965953580795, 60.33660050361388, 65.11482792515909, 65.3921159621208, 69.1473460966541, 63.930978159750666, 57.140331652856645, 51.42770151938162, 60.19615219485376, 65.37130386598649, 71.29235698330787, 71.38982003734958, 69.88868190396217, 64.86183897141488, 56.789420727760564, 56.267392481527025, 67.60938475208899, 68.6819725651895, 72.82233238220215, 64.45240628334784, 65.9760078307121, 68.27165342146351, 69.03969272490471, 65.22151639384609, 68.48105307548278, 63.24849359450802, 65.66750949428928, 64.20684237633982, 67.46083674892303, 67.26332187652588, 60.75901623695128, 61.01352314795218, 67.35826676891696, 66.59994709876277, 61.47373876264019, 67.77668952941895, 64.59669459250667, 67.57766846687564, 62.79307111617058, 64.90476146821054, 62.29383576300837, 59.063383456199404, 56.477855097862985, 59.23760337214316, 59.34910851140177, 61.35462814761747, 61.309956273724964, 68.55666852766468, 70.40727415392476, 70.22580962027274, 70.49336233446675, 70.78806569499355, 66.04937968715545, 69.00053178110431, 74.90639748111849, 73.48570715996527, 76.43562762968003, 76.90679057951897, 76.76628343520626, 66.265910210148, 74.150188046117, 75.82336133526218, 83.15722865443077, 55.15398063967305, 2.072136926074182, 0.07341664194339707, 0.0659286457624647, 0.09500634030348833, 0.33512301743030554, 0.05532128511056785, 0.03618218710706119, 0.053428423575936794, 0.11499189651541172, 1.4694602138573125, 8.836840141204096, 57.47801634573168, 34.12451459515479, 51.30005974923411, 49.55160833174183, 0.04138752855660935, 0.06203222681858367, 0.01762229562436621, 0.03261522427501698, 0.015726652232960107, 0.0376718680584623, 0.08052635922907822, 0.027020890190596544, 0.03727702634228814, 0.05186163204451723, 0.031160415645929116, 0.023122803090260397, 0.19654071499263087, 0.0840158207762626, 0.32248311826298315, 0.16078164590702904, 0.129541423051588, 0.27291407327978845, 0.1255287311129993, 0.14149765003352396, 0.21220096176670444, 0.2536395768965444, 0.45075488847590267, 5.559732221787976, 85.26554184575235, 53.96490235482493, 55.84455705458119, 60.701855536430116, 74.79452363906368, 14.46492946917011, 0.31990124874057313, 0.47076501312755775, 0.9376903935786217, 0.20608515929310553, 0.3953054445164819, 1.9030365612237685, 0.8400340402318586, 0.531047675157747, 0.16891806656795164, 37.75487999762259, 110.46142793470814, 96.56683168103619, 99.66986579279747, 85.13092610143846, 84.326369531693, 84.46617849411504, 100.82892617871686, 95.45214114650604, 100.09812585769161, 101.56204069814375, 93.21959080234652, 83.39181776969664, 84.93442320054578, 87.60831079175396, 85.33667795119747, 75.71211507243495, 74.19271438352524, 76.14477603666245, 80.61182222058697, 85.38685291044175, 85.68121894713371, 88.3321528280935, 85.31631300526281, 78.45902935151132, 68.94204924183508, 70.440763350456, 70.57530064736643, 71.14111038946336, 75.28496896066974, 82.20706585914859, 83.22683503550869, 81.1124578599007, 70.98458428536692, 70.04545903974964, 75.69722575526085, 76.40356617589151, 80.69316433322045, 74.53805554297664, 77.513392971408, 79.79949935790032, 76.45501198307161, 78.05730019846271, 81.72796403208088, 70.86153953306138, 69.31261124149447, 79.81243533472862, 76.53449489224342, 75.63205949721798, 78.54165800156133, 75.27327245281589, 63.21997011861494, 66.50553564871511, 75.2590891622728, 80.20824955355737, 74.81542202734178, 67.66198373609974, 59.70773866099697, 57.813571191603145, 66.53391007454165, 69.38250787796514, 70.72287590272965, 75.02631218202653, 70.52740850756246, 59.49196123307752, 54.83775131164059, 61.29402752845519, 70.80051529792048, 74.3551318876205, 73.80462723393595, 72.03065687610258, 65.1971153290041, 57.62576418538248, 62.75606355359478, 71.22861846800774, 71.5963642058834, 74.6042965304467, 66.54828948359336, 70.72256211311587, 72.18134649338262, 69.97842573350476, 68.54672139690769, 72.26475961746709, 66.92277385342506, 68.40379807256883, 67.11474249439856, 68.74623667809271, 69.12633003727083, 63.68130753117224, 65.71709217563753, 67.98051941779353, 69.52545473652502, 66.6437364393665, 70.86522656102335, 68.3093003303774, 70.46960061596286, 65.69398157058224, 68.3456293229134, 64.29115372319376, 62.6684142697242, 60.051130402472715, 62.99946231226768, 64.85668497700846, 64.73072590366488, 64.65593414921915, 71.97178994455646, 73.30340323909637, 73.50688011415544, 72.17842824997442, 72.60392696626725, 70.78681838127875, 71.92891843857305, 77.95174137238534, 78.41495760025518, 79.52952261893981, 80.14267536901659, 80.53829346933674, 69.6185012017527, 81.66500999081521, 82.19704812572849, 89.17226960582119, 60.96280297925396, 2.771531564574088, 0.2034964869099279, 0.2454961848355109, 0.0977517772586115, 1.2569919180485511, 0.41199816330786676, 0.3052011246402418, 0.1490044843165144, 0.7046278770412169, 2.734996892752186, 13.684626875385163, 69.31881643110707, 46.00073760555637, 59.3611894115325, 56.95462703704835, 0.10206420109757494, 0.15896111456376893, 0.11546766009902763, 0.13821602047931764, 0.07152340885612272, 0.12307631512803417, 0.10916138518481486, 0.11755226961066646, 0.1528218851214455, 0.13280618334970168, 0.200239418134574, 0.10652389767910204], [0.03416384037043299, 0.047299172428827134, 0.10406234226520024, 0.043645243295618606, 0.11990926168378323, 0.12851470435458806, 0.09311253265027078, 0.074036376430623, 0.12238882782478487, 0.12013737968499623, 0.24007510153516648, 8.57069653849448, 67.55061980216735, 39.74907967352098, 41.499331458922356, 43.65768624890236, 44.907074897520005, 3.6861049792458935, 0.030655523484212258, 0.07416808992744454, 0.28631794596872023, 0.11924105681358807, 0.07052270650503135, 0.21451673830949494, 0.08368465628835463, 0.1433584163145673, 0.9700361579175919, 62.735635849737356, 94.76443982893421, 83.681594633287, 84.88161240854572, 75.13477356203141, 71.66004780800112, 73.89458287146785, 87.10699266003024, 84.41993374978343, 85.30937825479816, 82.85042870429255, 80.24777135541363, 77.6102049120011, 71.63090459762081, 73.09962826390421, 67.75639518614739, 62.25739302173738, 66.33910948230375, 68.43364730958017, 75.80906037361392, 77.38718678874355, 85.98937603735155, 79.13248462061729, 72.67047389861077, 74.25876709722704, 63.02162762611144, 58.10498368355536, 60.19654835424116, 63.67793429282404, 70.78120939193234, 71.21752600516044, 76.23874033651045, 68.79398761257049, 63.43383735226047, 69.67011174848004, 65.41430873255577, 67.50269628340199, 69.01027494861235, 71.73131727403211, 73.18547325749552, 72.48588715830158, 69.11332345777943, 74.655883542953, 65.97422707465388, 68.97111400481194, 76.38544482569542, 71.37795094520816, 65.72503497523647, 74.08214276836765, 65.00016135554161, 55.5253271133669, 62.04735402138003, 75.5871562034853, 67.25259027173443, 64.29549186460434, 63.43855596357777, 59.59288381761121, 51.78476272090789, 52.06719690753568, 51.555880654242735, 47.55830687861289, 48.9913526658089, 47.012203124261674, 49.88738675271311, 50.6326174736023, 52.15695250418879, 57.705572651278594, 61.89918256575062, 63.978846765333614, 66.56567342819707, 66.5805313664098, 69.66899779535109, 67.07571491118401, 53.55569324185772, 52.45777083981422, 65.35253924708213, 66.59519318611392, 66.9943335748488, 61.497814270757864, 63.697891312260786, 62.730521079032656, 65.42305169566986, 63.27599333178613, 60.7539838360202, 62.99690100454516, 62.85497396223007, 62.29484381214265, 68.1503031330724, 63.22224117094471, 62.74581047796435, 62.7162475739756, 53.29279638105824, 58.3293354126715, 61.66749600441226, 63.324163959872344, 63.86177970517067, 62.501682158439394, 62.19602361802132, 56.831727412439164, 56.41129639840896, 55.15103493967364, 53.358558839367284, 54.61540783605268, 57.694393896287494, 59.60691021334741, 65.8996706624185, 64.52132232727544, 65.90189856867637, 67.88164431048979, 68.07213814027848, 64.05288934707642, 65.38817790246779, 67.68260755846578, 68.95576184795749, 75.02239765659456, 74.98566073756065, 69.59307639829575, 64.46549523261287, 67.43132483574652, 71.30474382831206, 73.64391988323581, 65.13325522022863, 4.448642423076015, 0.18976872756836877, 0.29845256418470417, 0.05238709941266045, 0.14373140920314098, 0.05205329575185334, 0.2085711758944296, 0.042975739906391794, 0.45813442958939465, 0.6319678082100807, 1.5531551357238524, 44.2930474588948, 39.37774104456748, 35.471993877041726, 46.34394107326385, 0.5051401137344299, 0.016492821554082538, 0.026437880043240807, 0.024609582483648293, 0.0592361054863901, 0.028464682475333253, 0.1147354409218796, 0.05752050137567905, 0.045015920148861986, 0.04223502864460311, 0.06175746938454048, 0.05296081882871447, 0.054429815406160015, 0.018358310767179056, 0.09891294438632266, 0.03985691552741393, 0.03682365550869896, 0.04884481993353656, 0.048813674628974936, 0.04974111216142774, 0.06215566273538336, 0.1496653577252742, 0.39071323770669203, 12.405703759962513, 75.80786012834119, 47.93219897054857, 36.97529323639409, 45.485024375300256, 56.94180088658487, 5.5103216344310395, 0.07228464744384251, 0.05726518342271448, 0.07905215325374758, 0.10088946655272477, 0.1474310316505932, 0.18920686336294298, 0.07065910079907026, 0.11614593902542708, 1.5302894336562005, 63.73820151052168, 98.67248550538095, 86.86360959083804, 90.65902048541655, 81.10230676589474, 74.40785638747677, 77.45690299618629, 89.12480108199581, 85.64185404008435, 88.08141923719838, 88.25780822384743, 83.61228635234218, 81.84743158278927, 75.47805155477216, 74.01803555027132, 71.25656143311532, 65.9325558139432, 69.50273636848696, 69.55352321747812, 79.79615749851351, 81.56878640574794, 85.6336013732418, 81.73702470717892, 77.34294245319983, 76.69677119101249, 66.11849184959166, 61.28852052073325, 64.53258737441033, 67.45453742242628, 73.7475489031884, 73.27067498237857, 79.34346891218617, 71.02372953968664, 68.45375337908345, 72.0977843192316, 69.57761441507648, 70.37872714381065, 74.83854832187777, 75.52413155955654, 75.5217702927128, 74.56268802765878, 74.75428012109573, 74.36300016218617, 68.88828923625331, 69.50383463213521, 77.9419432916949, 73.74849811677011, 69.02924353076567, 78.60529453523698, 64.3145388941611, 57.66830621227142, 69.04898089747276, 77.81161077560918, 69.49074960524037, 65.94894347652313, 66.91645883744764, 62.73022297889956, 54.169912876621375, 56.88322028806133, 51.58897761375674, 50.71834871845861, 51.890603957637666, 48.912803280738096, 50.47885664047734, 53.84121825618129, 54.08026318396292, 58.034412399415054, 62.90401143412437, 65.61361612812166, 68.94028417525753, 67.81382653021043, 70.4184764431369, 71.04438474101406, 60.72617030912831, 53.07532841159452, 66.51724784604966, 67.69306459734517, 69.39720892137098, 66.23691604983422, 66.90377389231037, 67.72365908468923, 68.20191367979973, 66.13549924665882, 62.25582407366846, 63.74202582143969, 64.38596525499898, 63.78728605085804, 68.70228259794175, 67.83219106735723, 63.38192870540004, 64.18888184332079, 58.681003355210834, 63.34466618876304, 64.71427940553235, 68.48765834685295, 66.16872956675869, 65.46898265038767, 63.428138148400095, 60.551209065221975, 58.4601229236972, 58.86080872627997, 56.38959392424553, 57.1365975564526, 60.23023366928101, 63.345838977444565, 67.8792908883864, 68.19853259671119, 68.30580942092404, 70.20055740110337, 71.38141832044049, 66.86287141615345, 67.90027556880828, 70.63087278796782, 70.76132297515869, 75.79772472381592, 76.99512235579952, 73.77710788480698, 68.81960068979572, 72.31047876419561, 77.8950160549533, 79.73057546923238, 68.76322838567918, 5.949339780115313, 0.10719101470444473, 0.29255227756596386, 0.11056407685241393, 0.05309133722837414, 0.08755235842639401, 0.2179092667516201, 0.02697053331611378, 0.38655623012492735, 0.755861753657941, 1.1484656963617572, 50.873435312701815, 38.054988384246826, 43.7210129153344, 56.280230399101015, 0.8705209688313547, 0.11231207499100317, 0.017768350287130284, 0.045931226679033814, 0.06146084014025908, 0.012646185876350972, 0.028970649075363914, 0.08144494461556596, 0.040859422015566985, 0.0534420101452739, 0.08455657159849521, 0.01168862097866593, 0.17951461005835764, 0.13695359951065433, 0.19892709419852306, 0.15127080222291334, 0.1674740367959584, 0.2578390563928312, 0.16287700363224553, 0.1513293006968114, 0.1499489941183598, 0.2817851875818545, 0.45674781044644697, 13.68178217641769, 91.1560396994314, 51.72540157072006, 56.971230429987756, 61.03105614262243, 68.84380171375891, 9.191059585540525, 0.11150448042298518, 0.3360582575682671, 0.7199694312387898, 0.3646937355158791, 0.5411162768160144, 0.7625006103227217, 0.333398706730335, 0.3122347004471287, 2.208333875863783, 70.0393872107229, 104.50718372098862, 93.8265383628107, 99.2347651143228, 87.20384382432508, 79.16291436841412, 83.16798379344326, 93.42977493040024, 93.30867567370015, 92.00116142149895, 92.94620160133609, 86.07905710897138, 82.30468580799719, 78.9201981021512, 79.23370530528408, 73.39161734427176, 68.95477341067406, 74.28194830494543, 74.28516464848673, 82.305705624242, 83.3930415491904, 88.04022650564872, 87.74510737388366, 80.09145705930649, 81.754895025684, 69.67393213702788, 64.56960670409664, 68.80162054492583, 71.9343234646705, 76.58748611327141, 78.23081801014563, 84.08993690244614, 74.43364204898958, 71.8468624545682, 76.75157454706009, 74.48240495497181, 72.33696260759908, 76.4501953125, 78.66936252963158, 80.05494763774257, 77.4250219714257, 78.32404490440123, 79.9197200036818, 73.1872461688134, 72.79978659845167, 81.56529549629458, 75.0194872579267, 68.61816344722625, 82.30761189614573, 70.50327808626237, 62.10091398608301, 70.77238405904463, 80.26912473863172, 72.4180458438012, 70.30338625754081, 68.02212007584112, 66.3732184133222, 57.833543900520574, 58.55894311781853, 56.92767250922419, 53.76746592983123, 55.09641593502414, 51.95253033791819, 54.78194382882888, 55.572595596313484, 56.96274634330504, 61.21581938958938, 65.07773014806932, 67.74428290705528, 73.5775141562185, 71.75883662316107, 74.12192344665527, 70.1795256522394, 58.77843110792099, 57.19477022847822, 72.67136035426971, 72.7448106581165, 72.36735313169419, 67.49472602721184, 70.13963514758696, 68.90721074996456, 71.49218605410668, 68.96480683357485, 65.99520391033542, 68.03408330486667, 66.03708697903541, 68.32841011785692, 68.61097766507056, 71.49067986396052, 65.0123324701863, 69.420131252658, 64.54190692593976, 65.63841335235104, 66.99567502544772, 71.69520793422576, 69.74409549467026, 69.29218353763704, 67.78425185911118, 63.42998166238109, 63.73827211318478, 61.314125753218136, 60.58920898745137, 62.28813655914799, 64.63893067452216, 66.85577192614156, 72.00670688383042, 72.07301847396359, 70.77632211869764, 71.93112281060988, 72.97898400214412, 68.80460939099713, 70.1035414972613, 74.89509321028187, 73.03636043302475, 78.87932700495567, 79.69263830492574, 76.56052374070691, 71.85966507081064, 76.26133318870299, 81.8775789199337, 84.7527547036448, 72.76403027196085, 7.380243462900962, 0.3641076169667706, 0.8516978820966137, 0.3839013983886088, 0.4127798487822856, 0.4776609688997269, 0.3397770322138264, 0.16881236175615943, 0.9208465103180179, 2.428897330837865, 2.228208770675044, 61.84065295803932, 57.120613898000414, 51.213830363365915, 61.76745368588356, 0.8335564910404144, 0.19413867694956644, 0.14018456000954876, 0.12726632577757682, 0.09976338625194565, 0.2535099548197562, 0.12554912437354365, 0.15547811113778623, 0.2369371594320382, 0.24068225685867572, 0.21640943513522226, 0.14215985643527201], [0.06399262283417968, 0.01595612429457927, 0.056216914672404535, 0.03151356302682431, 0.05438142929286246, 0.03252582947513269, 0.02504102405040495, 0.02460099655323692, 0.07360431050220806, 0.30380984768271446, 0.5698600795961196, 23.06467998412348, 57.07553017523981, 38.27498236010152, 50.773206987688624, 45.67993479390299, 34.18701756385065, 3.3667232913355676, 0.020995637394427773, 0.05411100025559145, 0.03729141730394575, 0.05696156362612402, 0.10871160730359056, 0.3260219848204044, 0.9264124148795683, 0.34111646034063836, 15.240538947043882, 79.16895481847948, 89.70765744486164, 85.45325863745906, 81.09460323087632, 73.21636584497267, 67.5444616809968, 78.53061260715609, 90.43059733606155, 84.54162136200937, 91.38557680191533, 84.34593431411251, 80.7528628072431, 78.67452436877836, 74.85475555542978, 70.82275513679751, 66.26323515369047, 62.3486351966858, 62.460124646463704, 63.63347422692084, 75.85899214590751, 77.68538890346404, 75.20055170982116, 73.79523707974342, 77.26600908464002, 70.72592750672372, 65.68381870946577, 58.062151401273674, 60.21519137967018, 64.14165258407593, 71.58700543065225, 70.14835849885019, 76.38601749174057, 65.52637869311918, 69.14944848706646, 66.27910506340766, 65.64374777578539, 66.329099593624, 70.71379953815092, 71.63266966419836, 68.94104511507096, 73.54805715622442, 68.6232703731906, 63.309062834708925, 70.55063678372291, 73.32019882817423, 70.48858488759687, 71.46278396729501, 71.42387405518564, 61.40261442430558, 52.66433069782873, 64.3728292372919, 73.04631540852209, 66.37171222317603, 67.80108667189076, 72.60850044988817, 65.29380959849205, 55.513065784208244, 51.604584724672385, 52.15992958314958, 53.17725120052215, 56.061268006601644, 59.427253892344815, 55.73098874861195, 51.57881867501044, 48.94109141442084, 50.11573537703484, 52.79089381617885, 60.471071120231386, 63.63242303171466, 65.09290187589585, 62.94777724050707, 63.76097479174214, 68.56536049996653, 71.66408000453826, 56.185156068494244, 50.65532407452984, 61.68748048044021, 62.941893685248594, 62.802598553319136, 64.05263439301523, 64.72098273615684, 63.09894538694813, 65.91963552659558, 64.6402995817123, 60.93664469257478, 61.91424838958248, 62.449016494135705, 61.963356464139885, 66.01623565919938, 60.83407471256872, 53.12675852929392, 59.10017136604556, 60.7224872035365, 63.201719330203154, 63.905855378796986, 64.5975379020937, 65.57257636900871, 60.53201690796883, 55.76653326711347, 55.225552128207305, 55.12703787895941, 53.994198537641964, 55.33880664456276, 58.009858362136356, 60.49299324712446, 63.941674463210575, 65.93295589570077, 64.99359530787315, 68.94078623863959, 64.07848281245079, 65.23181261554842, 64.96166329230032, 68.00039014508648, 69.71139077217349, 72.50877026588687, 75.00842617404076, 69.9026612312563, 66.07669507303547, 65.63856240241759, 72.5304139044977, 71.8861489142141, 73.35733582896572, 10.813248926593412, 0.027513873515530463, 0.06742618677596893, 0.14664819704428797, 0.06479858946535857, 0.12750298565914556, 0.09488664672619875, 0.039425983409126925, 0.23553432986861278, 0.4262039155489014, 0.14768269153371935, 38.06395100009057, 40.957106928671564, 33.34891688439154, 49.6440899756647, 4.750107459483608, 0.3242502379561624, 0.0897390797974602, 0.05531185073778034, 0.08090912739956573, 0.037445611650905306, 0.03727173267473136, 0.028266208246350292, 0.06472309150042073, 0.0992991369698317, 0.06488335709418021, 0.08020605786793655, 0.038024295316708666, 0.0151573205854924, 0.01795071943272506, 0.013755432352603925, 0.0701502345562462, 0.1748019129398369, 0.02873147067974412, 0.037063077137234716, 0.11681929966735265, 0.17956927809263432, 0.5306942941200349, 31.634388085334535, 63.67099561998921, 47.71178530108544, 42.96638027314217, 49.17434692382813, 43.97298989757415, 5.0061029099649, 0.08695527715908904, 0.03155030843411242, 0.09709612090861607, 0.05510480398492468, 0.2521400823588333, 0.7175686955451966, 0.689161726303639, 0.5013377129310562, 17.91558265686035, 85.41842014558854, 92.12324911548247, 93.08561832674089, 88.08526315996724, 78.38644981384277, 71.83163581355926, 82.19902500029534, 95.05744088080623, 90.04848003387453, 94.14960830442368, 85.35304207955637, 86.71345341590144, 81.7816299007785, 79.14069021901777, 73.21435759144445, 68.2581683128111, 65.21774307374032, 64.97030427378994, 65.21846086748185, 76.89946359203708, 80.72884221230784, 76.69284882084017, 76.06215523135278, 80.44720818919521, 74.55417648438485, 70.04280751751315, 62.35264778137208, 64.70577570699876, 69.69491681744977, 73.78552529119676, 73.44842110910724, 78.21646213531494, 71.04115270799207, 72.91168397472751, 67.7692291813512, 69.52448198872229, 72.76527758567565, 74.31149159708332, 74.2791477326424, 70.61315936426963, 74.58854429183468, 72.727567918839, 67.53693073026596, 75.98493945214057, 75.25342525974398, 73.84555324431389, 71.3419435870263, 74.43417549133301, 60.26222452040642, 55.64215098657916, 69.39777374267578, 74.98392704994448, 69.26214602685744, 71.461622945724, 72.74754062775644, 65.25582536574333, 54.918391320013235, 53.11269683222617, 52.254615599109286, 56.30270558018839, 62.901579564617535, 66.15759788020965, 61.136916991203066, 55.50430320924329, 51.687738972325484, 51.94329315616239, 55.45286524680353, 63.20721849318474, 66.33233162664598, 67.97168624016547, 64.68861533749488, 65.6206097141389, 68.46876036736273, 71.7169378649804, 61.174728639664195, 54.016712942431056, 63.218118759893606, 63.28320657053302, 68.82398589964836, 67.59661351480793, 66.88043578978508, 66.00645326798963, 67.0688429186421, 67.31323795933878, 63.448208916571836, 63.91117411275064, 64.63216458597492, 62.47096607761999, 68.42738720678514, 63.45095849806263, 54.88953836502568, 62.43536272356587, 65.07203486657912, 65.20098278599401, 66.87367362360801, 67.84762951635545, 67.51323961442517, 62.18583330031365, 59.33356023603871, 58.741709878367764, 56.27759848871539, 57.395364161460634, 58.187392680875725, 61.28083267519551, 64.85393539551767, 65.44523662136447, 70.63837235973728, 68.2021176430487, 71.59289683065107, 67.7525826423399, 67.60909449669623, 67.15124407122212, 70.18821762454125, 71.8753545514999, 75.19583702087402, 78.17611663572251, 71.0518450890818, 70.21032410283243, 70.50443126309302, 78.27612923037621, 77.68841697323707, 76.05116475012996, 12.984234729120809, 0.04131394198104259, 0.06117752933454129, 0.1408955355685565, 0.040358117060555566, 0.13153268474965327, 0.07377677221572207, 0.027780489350158363, 0.8147269691671095, 0.7113117183889113, 0.1555813185029453, 43.133528155665246, 44.292266907230506, 34.92536844745759, 63.86744360769949, 7.1983592356404955, 0.4685268106479799, 0.17551322557753132, 0.13052996758732105, 0.04827036890351484, 0.052165018184290785, 0.05424482049420477, 0.02516838808303639, 0.021756665307968374, 0.02908240406653814, 0.09665991044453076, 0.048444837767390475, 0.14470593432985968, 0.10373538359999658, 0.1254207356983135, 0.1307896101066182, 0.2716914275961538, 0.17208999233140101, 0.23111571858246482, 0.14152256321282158, 0.19165967771362877, 0.5399537230691602, 0.7727254326305082, 34.948078970755304, 77.35621575386294, 50.88918755131384, 74.73313854586694, 59.6275261909731, 58.13922989752985, 9.289833691812332, 0.20815065491103357, 0.19627722671195386, 0.22452461983888383, 0.2202966571935723, 0.36148673824725613, 1.3780857814896492, 2.5257036330238467, 0.9587705591993948, 22.730662707359564, 92.83231166101272, 98.79548318924444, 99.90974226305562, 94.26980541598414, 83.08706529678838, 77.44107231017082, 89.0760773997153, 100.15736149203394, 94.79417923958071, 97.54254479562083, 89.35590713254868, 88.44275582221248, 87.76167546549152, 80.59323803071054, 77.3551724033971, 71.14112607894405, 67.59869237099925, 71.17007317081575, 69.06322694593861, 83.65764464101484, 85.91829484508884, 78.60369420820668, 78.21823504663284, 85.89472924509357, 79.9717463216474, 73.5596909061555, 66.15096907461843, 69.78236998281172, 72.948593478049, 77.2059654420422, 75.75898739599413, 84.5015896520307, 73.68421831438619, 73.53278344677341, 73.40565942948865, 73.99128498569613, 76.8198080985777, 79.20908851008262, 77.58055179349839, 75.77250388360794, 80.29696572211482, 78.17785816807901, 69.44133558580953, 77.32579385080646, 77.49204743293025, 77.21909753737911, 73.72814886031613, 78.25164579576062, 67.12929448773785, 57.62676046740625, 70.11599894492858, 76.04487326837356, 70.93181271706858, 73.46193759672104, 73.5875162001579, 71.45583352734967, 58.94417870429255, 56.25574304211525, 57.121182641675404, 58.05568341285952, 62.34499915953606, 67.24251762513192, 61.39096106252363, 58.1400026044538, 55.25893934311406, 56.152953409379535, 58.09924133362309, 68.07058488169025, 71.71487469826975, 72.30071990720688, 66.15941785996961, 67.0074107570033, 74.00874737770327, 75.93511750621181, 61.247006154829464, 57.49595334452968, 67.14689024033086, 70.01611186612037, 70.23889464716758, 70.04438431032243, 69.61598304010207, 67.46983466609832, 72.05165724600516, 70.80330802548316, 67.15642944458993, 68.62418820781093, 67.36212638116652, 66.93013221986833, 70.87863322227233, 69.93979823204779, 61.16750363380679, 65.55459622413882, 68.44088016017791, 67.6989403078633, 70.37865654114755, 69.51468390803184, 71.35637790926042, 66.21016548525903, 62.75967213415331, 62.28745014436784, 61.54400017953689, 60.899931307761904, 61.997641901816095, 64.82324677128946, 69.81527866855745, 69.25800400395548, 73.85017379637688, 71.6867591488746, 77.40751251097649, 69.42117460312383, 71.39848063069006, 70.25491360695132, 74.7299143575853, 73.53079872746622, 76.77188457981234, 81.2075988708004, 77.04340673262074, 71.46415679685532, 76.76158443573983, 83.08690055724114, 84.56657548104563, 81.99413607197424, 16.138395955485684, 0.16356449093549483, 0.6100513197241292, 1.2978635055403556, 0.35263324396744855, 0.5412521501702647, 0.3803492019013051, 0.12593763820346326, 2.3321094147620665, 1.9891410441167894, 0.3799478637595331, 49.647553428526855, 60.631672566936864, 43.85428328667918, 73.41446122815533, 8.943812001136042, 0.6945209096997016, 0.34127896291113674, 0.28365468726523463, 0.1516668850015248, 0.1358705044033066, 0.14717748719117335, 0.24444160352070488, 0.30636009309561024, 0.1920608166725405, 0.294400480005049, 0.16033140071217092], [0.04923018131164774, 0.01883904626142354, 0.019376186894312985, 0.07455934635213307, 0.02833299196114944, 0.030320993955096895, 0.02215294535422037, 0.13996335978229202, 0.035222282768377376, 0.06439009606237374, 0.05288233312087194, 37.618840432936146, 58.36167535474224, 24.823317796953265, 42.010051511949115, 55.372350754276404, 14.40387091329021, 4.116282347709903, 0.09467407264896939, 0.18837426368507648, 0.1691504363571444, 0.016069335810419534, 0.15087810555292716, 11.857685888967207, 23.545388021776755, 3.994296390202738, 61.667339109605365, 90.03345735611455, 88.85362409776258, 84.7607014256139, 79.66068667750206, 70.35946046152424, 73.84148182407503, 84.12219447474327, 79.11043305550852, 84.85555218112084, 85.8002785713442, 87.00060229147635, 83.55929513131419, 81.84549393192415, 80.4929038017027, 79.0975284576416, 75.69722575526085, 68.7389410695722, 62.87866507807086, 64.25418146194951, 68.50860380357312, 78.71540331071424, 75.84797028572329, 75.79115083140712, 73.99587415879773, 71.24233107413016, 65.620566568067, 59.34958311819262, 60.36728128310173, 66.65339331473074, 70.98168173143941, 73.18044477893461, 70.53650840636223, 70.22300120322936, 65.37704229354858, 64.553999593181, 67.62064979922387, 68.60081088158393, 70.99169946485951, 72.40816931570731, 70.01362508343112, 70.75171316823652, 67.44622199766098, 74.27996358563824, 73.33773966758483, 71.84492480370307, 71.9639059805101, 73.55391717726185, 61.5703663518352, 56.77795956211706, 67.17859083606352, 69.7062760014688, 66.05060346664922, 72.55860005655597, 70.76008350618424, 62.85624088779573, 54.17286642136113, 51.078445834498254, 50.43150578775714, 54.50295348321238, 68.24003127313429, 66.75080145559004, 68.52333622594034, 65.6522475519488, 65.26396820622107, 55.83107586829893, 46.88616560351464, 49.825554509316724, 51.783613466447406, 59.56166175103957, 65.97563912791591, 67.03798171012633, 65.63852317871587, 67.99012137997535, 61.828344560438595, 65.3485619637274, 55.475897404455374, 55.22246130051152, 57.68551757258754, 60.070365705797755, 65.04740630426716, 63.08846089147753, 62.36932962171493, 58.95410230082851, 62.47631619053503, 63.86402722327941, 59.940880421669256, 61.024529318655695, 60.79452153175109, 59.985932765468476, 56.76452544427688, 56.939012081392356, 53.38585853576661, 57.79338275232623, 58.62128919170749, 63.38179534481418, 63.446765484348425, 64.79557837209394, 59.31423079582953, 55.100879592280236, 53.66052250708304, 52.87019237395256, 54.54665260930216, 55.51316384346255, 58.4563260693704, 62.07925465799148, 62.010209175848196, 67.2730101308515, 68.62927159955426, 67.42249165811847, 65.70484653595956, 63.70182544954362, 65.14193934779014, 67.31552862351941, 71.13143782461844, 72.94468679735738, 74.40434978854272, 71.26275877798759, 65.42918236024919, 65.96609207891649, 73.57361532026722, 72.19049346062445, 77.20917394084316, 17.517681737099927, 0.41180731548417004, 0.0970627501186344, 0.09804758678881392, 0.07414032690106862, 0.032928749588468385, 0.0551883343817486, 0.16072455703491167, 0.27727813910572763, 0.1912128799144299, 0.39700288085206864, 30.703393913084465, 46.13563576052266, 34.365116703894834, 54.32028870428763, 10.52346323767016, 0.6139167542419126, 0.22022285228294713, 0.08972109971387733, 0.05286780043294834, 0.0863126672864441, 0.07448696636504705, 0.02971203832496559, 0.08073438274403734, 0.08061474279290246, 0.026652750469023184, 0.08787899533466947, 0.030092617399209452, 0.059716128518865, 0.0921912046690141, 0.04131803672099787, 0.05066341307434825, 0.04349446953124097, 0.022524674197718985, 0.03023543725571325, 0.022165984170691624, 0.08024829229520214, 0.5154484702694802, 48.57471850610549, 68.04699574747394, 37.58761052162417, 41.23674446536649, 63.50263180271272, 19.926619106723418, 5.644761362383443, 0.035529974322285385, 0.15367608847877673, 0.41520001246563853, 0.024583931944723574, 0.763524532798798, 12.089971592349391, 29.61575596563278, 3.9097291086950614, 67.12817268986856, 93.28470999194731, 92.83168408178514, 86.86768885581725, 85.77798381928476, 72.24070764357045, 78.78692380843624, 87.50389729776691, 83.8167908883864, 87.79394088252899, 89.19425841300719, 89.77276094498174, 86.42530825830276, 84.3502724555231, 82.97093176072644, 82.33950076564666, 79.436154519358, 70.55211943964805, 65.76066970825195, 65.8765600573632, 70.21503094703921, 82.3417208271642, 78.46670150756836, 78.68949213335591, 76.39827097615888, 77.36719839034542, 66.1063717257592, 62.06688350246799, 63.582169625066946, 72.45202925897414, 74.64888603456559, 76.75506545651344, 73.88730295242803, 73.93085695082142, 67.8447348071683, 70.94678048164614, 70.74244068514916, 72.88817328791465, 74.2472667078818, 76.45585137028849, 71.73902080905053, 71.50752252148044, 72.77429903707197, 77.85565114790394, 76.45703592608052, 74.41757602076378, 74.7153780537267, 75.25029520834647, 60.763597565312544, 62.734498362387384, 74.03189720646029, 72.18071891415504, 70.18944924877536, 75.73338216350925, 72.19746743479084, 64.00298503137404, 57.9338389058267, 54.42102693742322, 51.47070246358072, 59.01907244036275, 70.161192494054, 69.33292911898705, 72.11223433094641, 70.19563874890729, 68.30577804196265, 63.609214367405066, 50.24722891469156, 52.45123617110714, 53.93231530343333, 61.57933289004911, 67.06532847496771, 70.117920906313, 68.3454018254434, 70.43600943780714, 64.27528773584675, 68.27021783398044, 59.9558638757275, 59.25814090236541, 61.96012835348807, 62.24077393931728, 66.40761759973341, 65.24461523179086, 64.92619329883208, 62.08329469926896, 63.405764948937204, 64.22812515689482, 61.69910638563095, 62.42845150732226, 63.834460396920484, 63.42748311258132, 60.99295031639838, 59.11366039706815, 54.69895432072302, 61.016327642625384, 61.50321929685531, 65.46122027981666, 66.07067031245079, 67.99015275893673, 61.946831518603915, 57.723917576574514, 56.541087627410896, 55.74173604288409, 56.966951124129764, 59.11371138788039, 61.38162974388369, 64.88125078139767, 65.33355105307795, 71.20575104990314, 71.92434495495212, 70.3750636500697, 65.54831650949293, 64.91992142892653, 67.3808753105902, 69.24003170382592, 73.57556081587269, 76.21149555329355, 77.65051903263216, 72.69967202217349, 69.84606142966979, 70.5421958431121, 77.78530736123362, 77.35209726518201, 80.97798332091301, 20.472354158278435, 0.48443526990952035, 0.032608601444911574, 0.21056321900217764, 0.07555857781440982, 0.08868806079150209, 0.14430704766944533, 0.23919367141300635, 0.3963947602577748, 0.14381813035616953, 0.4108080916827725, 32.25983354353136, 54.88034432934177, 28.94735270930875, 65.06941864567419, 14.741055503968271, 0.6354448055067371, 0.20444205391310877, 0.11328771094521208, 0.06730204222783928, 0.07934796278395, 0.09549221624770472, 0.15444346343077, 0.07223660607011088, 0.11102548394832881, 0.04866810260160316, 0.05394865856355718, 0.20094735998540156, 0.12839254397418232, 0.249430168900759, 0.1263339278258143, 0.2099359615315353, 0.1290753198366973, 0.13769246067010588, 0.1871802696898099, 0.15693589984889955, 0.2250995688260563, 0.43787367161243196, 56.624940056954664, 76.03297279727074, 38.32873844331311, 57.073937692949855, 81.49742280283283, 28.445297171992642, 13.388161390058457, 0.4161635672132815, 0.5284727004266555, 0.5732499880175437, 0.2490693721319399, 0.7065828108499128, 16.70816336908648, 34.64877467001639, 4.98576493032517, 72.38920857829433, 99.77743287240305, 100.62963055026148, 95.50893706660118, 92.55959710767193, 79.32358249541252, 82.71194550298875, 93.66220674207135, 86.55829229662496, 92.63048218142603, 94.3780549879997, 91.69036849852532, 90.84604693997292, 87.31365449966924, 87.96770188116258, 84.4672610682826, 82.3374689778974, 73.78191671063824, 68.60213664270216, 68.63203294815557, 73.63868744142594, 84.1810457168087, 82.9513983572683, 83.12168413592924, 82.13124644371771, 79.17058652447116, 69.17619120690131, 65.57974646168371, 66.73070323082709, 76.18634531574865, 78.92437150401454, 80.4178374813449, 77.66998183342719, 77.15746925723168, 72.91588875555223, 75.08420636576992, 74.442734103049, 76.17971651015743, 76.39598031197825, 80.96231737444478, 76.88135008658134, 76.94162122664913, 74.77303689525974, 81.04673462529337, 79.07507681077527, 77.97483628795993, 78.84913259936918, 79.3858697337489, 66.43185000265798, 65.007841356339, 75.11939002621558, 75.6725932705787, 71.68318194727745, 78.57796345987629, 77.9525415359005, 66.82296522202031, 60.52599214738416, 57.57658158579181, 56.45424242942565, 59.86354697135187, 72.00020359408471, 74.0703756578507, 74.59445138131419, 72.16567270217404, 69.72947289866786, 63.36846320859848, 52.72024800700527, 55.202237559903054, 56.05867531991775, 64.67181582604685, 69.99187161845546, 72.75571484719553, 71.73526317842546, 72.30206135780581, 66.09718553481564, 68.70464386478548, 58.036279447617076, 61.79882480252174, 63.59020263917985, 64.74811377063875, 70.25155605808382, 68.53940225416615, 67.40583727436682, 64.18436719525245, 66.62433639649423, 65.91183000995268, 65.66354397804507, 65.28600800421931, 66.1216297457295, 66.70327801858225, 61.0263139970841, 60.7519716601218, 58.876953201909224, 64.84217612974106, 63.42153679940009, 69.32167976133286, 67.38850824294552, 72.60141664935698, 64.80593342934885, 61.07128789347988, 58.66477258743779, 59.36723770633821, 60.970616340637214, 62.18002819245862, 64.53000645483694, 68.8330779537078, 68.32409551066738, 75.21674325389247, 75.98082096345964, 74.90633472319573, 70.83826418845885, 68.3999619945403, 70.38372424341017, 73.30727069608628, 77.51051395170151, 79.53589254809965, 79.80589282128119, 79.38433216464135, 72.95944275394564, 75.30440038250339, 83.08799882088938, 83.81203697573754, 86.81986731867637, 24.254919290542606, 0.8142649875052514, 0.2681492208953827, 0.27340795484281355, 0.24334485672654646, 0.25361112439103667, 0.2594089850543007, 0.4373343457137385, 1.4618631957038757, 0.6196823319600475, 0.35904895454164476, 37.67358103106099, 70.6251225932952, 45.01685027153262, 78.9532950616652, 15.894191149742374, 0.9708517657652979, 0.41762976756980347, 0.2481896886902471, 0.32945568282758037, 0.27048131511096035, 0.1485594331977829, 0.18109796058026054, 0.266054583292815, 0.3263533331694142, 0.22008264287104531, 0.19485775771881306], [0.022120790728818507, 0.09678364896606054, 0.012181332342386728, 0.04279939029666205, 0.03293002129442269, 0.04004051232890737, 0.13261530488248796, 0.043098731492195404, 0.17943847624044265, 0.10296851426603333, 6.563283378078092, 63.69589090347291, 34.088350342166045, 22.380638237922422, 52.28850095502792, 38.94594692414807, 3.117869006049249, 0.7780271287887328, 0.5618876170727515, 0.07308651933506613, 0.05375381942177492, 0.12220766335245102, 0.29790897883715173, 0.5057631270779718, 4.144318959405346, 27.078590431521018, 83.79531983406314, 89.24788505800309, 82.85038163585048, 76.4252176592427, 76.38545267043575, 74.54452745376095, 76.8516577443769, 79.38233175585347, 81.6460100297005, 84.17065143585205, 84.00260925292969, 84.71796328021635, 83.61895438163512, 84.14516387447235, 80.50736165815785, 80.98759312783518, 79.85274945535969, 78.51680586414953, 66.26387842239873, 59.31273637279388, 67.88307989797285, 79.30438641578921, 75.72485493075463, 75.74210551477249, 74.55229374670213, 74.36738537203881, 64.4798550298137, 57.88134582581059, 59.78810410345755, 66.7259414734379, 71.23197601687524, 73.89264522060272, 71.13913351489653, 66.63118485481509, 66.74997775785386, 67.63356224183114, 66.42764522183326, 66.80860934718963, 70.3994764820222, 72.84578031109226, 65.93931798012026, 68.86214271668466, 75.59544809402959, 70.09889741097727, 72.61994592605099, 72.56078089437177, 68.92610872945478, 61.979014565867764, 56.52453914765389, 72.22175475089782, 70.05937560912102, 67.19090707840459, 71.40543891537574, 66.68670992697439, 63.28796440555204, 57.53312956902289, 55.442737687018614, 51.42042944508215, 54.723476979040335, 68.24337313252111, 65.34116829595258, 64.39874041465022, 65.40555792470133, 64.75390711138326, 64.45051177855461, 66.19424066235943, 60.074464582627826, 51.081775926774554, 48.32764448658113, 50.790622311253706, 57.53888368606568, 63.60091463212044, 65.12965448441045, 64.74009252363636, 65.08513558295466, 63.58803356847456, 66.23879878751694, 56.706572424980905, 64.03927872257849, 56.420608105198035, 57.478585089406664, 60.64016057598976, 59.4479287055231, 64.27232634636664, 62.2478263608871, 61.37822904894429, 62.78876043135121, 62.15696073347523, 60.1352495531882, 59.869748238594305, 59.39385098795737, 57.94774763045773, 54.661966369998076, 51.31695731993645, 56.28411746794178, 65.42254178754746, 63.963337713672274, 61.833569157508116, 59.029078406672326, 54.919281698042354, 52.81849553508144, 54.07029644135506, 53.06022336406093, 54.04762121938891, 58.74174910206949, 59.66706760468022, 63.055312941151286, 65.34696948143744, 65.73267575233214, 65.25519778651577, 63.46552225851244, 61.9595282308517, 63.851856108634706, 66.46256216110723, 69.39346698022658, 72.94739323277628, 72.68577898702314, 68.4072889820222, 65.24664701954012, 66.89139489204653, 75.96235444468837, 72.62775928743424, 76.5714906877087, 21.795873641967777, 1.143741814359542, 0.17529322044743648, 0.12610443852721684, 0.1351735482533132, 0.11663179964788499, 0.04521780729954762, 0.4043835557756886, 0.09955805936648, 0.6739890178845775, 0.26716513499136896, 23.863507932232274, 50.976628949565274, 29.019355658561956, 38.1968173673076, 19.210965018118582, 0.4032794085721816, 0.2914861283235012, 0.050563132165059935, 0.024186108231304154, 0.015147296325003189, 0.03116981745997985, 0.011091473636277502, 0.07368772215540371, 0.10077525050409379, 0.02783972901412316, 0.017112104049433145, 0.07257732367443462, 0.008885878731586761, 0.05465091987242622, 0.08385229164794569, 0.021684007614009806, 0.09499330914789632, 0.0931169376558354, 0.10382858585686454, 0.16254061442469397, 0.20569937273619637, 11.959535133454109, 75.96034619116014, 46.93285357567572, 31.067633052026075, 48.75721070074266, 48.02168000128962, 5.046191494311056, 1.5143929253662787, 0.6041734641598118, 0.08082953852511222, 0.06435523906181898, 0.19466055136534477, 0.437409452973835, 1.0683780067390012, 5.486093644172915, 30.70862831607942, 86.56183027452039, 90.94880519374725, 88.14258467766547, 84.66274415293049, 82.15972285116874, 79.12729924724948, 80.57582270714545, 82.10633154838317, 85.86423673937398, 87.42632850523918, 86.20789912439163, 87.53238154995827, 87.18642850075999, 87.33398022190218, 83.19246722805886, 85.32309870566093, 83.25431516093593, 82.82702784384452, 69.46018649685767, 60.42326919494137, 68.53080441874843, 80.27437286992227, 77.07087901330765, 80.45413509491952, 77.54197920522383, 75.7323701920048, 69.2047695959768, 60.03404455800211, 63.327745083839666, 70.37899386498236, 72.7247045886132, 75.12648167148714, 73.49547386169434, 71.1841074112923, 69.9421359646705, 69.25622324789725, 70.26748088098341, 72.27353788191273, 74.84764037593719, 72.27886446060674, 70.49025581729028, 73.34868308036559, 76.0179344300301, 70.74410377010223, 74.04720229487266, 73.66280217324534, 72.7887882724885, 63.46467502655522, 60.325472739435014, 76.09773112881568, 70.57760700102776, 70.96280728617023, 74.62182952511695, 68.9335298538208, 65.83825419026037, 60.49028288933539, 55.39052701765492, 51.67607384343302, 58.32912360468219, 71.37719785013508, 68.22940949470767, 70.29558074089789, 69.05711589321014, 68.15118958873134, 66.96242901586717, 69.8363104174214, 64.58528049530523, 54.15091683787685, 52.252332779669, 52.73480392271473, 56.87088835623957, 65.62631284036945, 65.81388842674994, 65.876418852037, 66.2159941273351, 63.01619122105261, 67.99143145161291, 60.612802044037856, 66.52246459837883, 60.69002959036059, 58.194884407904844, 63.311647676652484, 65.61665988737538, 67.08958441211333, 63.27920967532743, 63.52151409272225, 64.36880880786528, 65.581915532389, 63.5679510331923, 61.01296617138771, 61.85262010943506, 62.13212428554412, 58.76482048342305, 52.990777800160075, 57.97970710262176, 67.1251210858745, 66.94948519429853, 64.43855247189923, 60.79008140871602, 57.925962786520685, 56.044131171318796, 58.034906618056766, 56.0083552329771, 56.87825848979335, 60.09184068249118, 63.49343384465864, 64.5838958986344, 68.33966732025146, 69.02034759521484, 67.97982123590285, 65.53113260576802, 64.89298259058307, 66.82879386409637, 70.16334195290843, 71.64617830707182, 72.9116996642082, 75.63995130600469, 70.49772401009837, 68.62079927998205, 69.76286011357462, 78.24267141280636, 77.05862552888932, 79.31683601871615, 25.807001167728057, 1.1724394680030885, 0.16678927676571956, 0.32381660154750275, 0.013657481308215329, 0.1332516328341538, 0.10802617311597833, 0.25903084405487586, 0.46404976217496785, 0.5250738440982757, 0.25596987846637925, 25.609335284079275, 62.63366991473783, 28.10503940428457, 46.994532846635394, 28.87887989321063, 0.27758334853476097, 0.13030443130241287, 0.038876162105870825, 0.015164237401838747, 0.13840806340017628, 0.04557270136091017, 0.04746943930043809, 0.039079148592727805, 0.039507115950747844, 0.06797420011172373, 0.06312957499176264, 0.13998727704728806, 0.10329061593379706, 0.07052832192951633, 0.13668514698022796, 0.17035596763655064, 0.2283616324946765, 0.2212047471754974, 0.21530715718625054, 0.3048472533062581, 0.25036133345096345, 12.062702294318909, 92.8805019009498, 50.927654235593735, 37.393382595431426, 68.52899228372883, 61.672206770989206, 10.692133980412638, 5.00175545292516, 2.279247877097899, 0.13024821577052917, 0.2863175782465166, 0.264904715961987, 1.0766363119886768, 1.7477100895297144, 6.374223174587374, 34.64668404671454, 95.0326358118365, 100.6697093286822, 95.20730680035007, 89.186719617536, 88.2125440720589, 82.99645070106753, 85.09604838586624, 87.95718208436044, 90.85622941294025, 92.26345031492173, 90.8098356185421, 90.25659315047726, 89.86108487652194, 90.29719752650108, 87.72966892488542, 87.99446813521847, 86.92099386645903, 86.02398703175207, 75.89266177146666, 64.83959913253784, 70.53119751714891, 86.91922095514114, 82.20108816700598, 82.51628198931294, 80.18056546488117, 82.26654468044158, 74.58823834696125, 63.36862010340538, 66.65959850434335, 76.03735016238305, 77.6754496174474, 79.83933494937035, 77.07087901330765, 73.22858795042961, 75.1323103135632, 73.75715086537024, 74.5630253514936, 76.7164614892775, 76.8497436277328, 77.37189738981186, 73.78878870318013, 75.59962149589293, 82.328855452999, 74.32980906578803, 77.23291996986636, 78.06576467329457, 75.81503022101619, 68.7007293393535, 61.31886005401612, 77.91880130767822, 75.13606009944793, 75.33315920060681, 76.6315813987486, 71.71777725219727, 67.85431323512908, 64.76927888008856, 62.61932972938784, 55.27986911035354, 59.654272833178126, 73.81977542754143, 72.25318862545875, 71.70504523861793, 70.33449065300726, 72.71348660992038, 69.51287177301222, 72.61206196200463, 65.58556725901943, 56.76030105160129, 55.96600540222661, 57.49049732761999, 63.28110810249083, 69.31709058823125, 67.38250701658188, 68.89691060589206, 68.83347803546538, 65.48085174252911, 71.17861609305106, 63.93250003937752, 68.73319871963994, 62.047718801806056, 61.55522208059988, 64.86441596861809, 66.34066274089199, 69.62313744329637, 67.45012083361226, 66.39467377816477, 67.06464598255774, 68.87521205409881, 65.98374274469191, 64.70120614574802, 68.40607304726878, 65.59480444077523, 59.240376487854995, 55.49517585385231, 60.43969215885286, 70.28717117924845, 70.648358714196, 69.29460756240353, 65.69699787324475, 61.232614978667236, 59.53533480244299, 60.40203348282845, 60.29463114277009, 59.87895404138873, 64.1803938342679, 68.21785419218003, 70.12543616756317, 71.24894419024068, 74.30858119841545, 70.81798553466797, 69.13641837335402, 68.33841216179633, 69.39920933015885, 71.58808800481981, 73.54662156874134, 76.08151605052333, 78.57870871020903, 74.29508824502268, 73.16129576775336, 74.11033676516625, 86.12665899338262, 83.86849557199787, 87.1680090504308, 31.011048939920244, 1.77509926499859, 0.6085291949491347, 0.7572837967065074, 0.34361884058002506, 0.21008461323236266, 0.30288680366450743, 0.48467257330494545, 0.8569617641548958, 1.071028303234808, 0.26489806631880425, 29.836561872113137, 77.05632701996835, 38.467672717186716, 61.67387770068262, 35.74639897192679, 0.47736194946112176, 0.3332599528854893, 0.10035426220706395, 0.14510990781409128, 0.1542039996673984, 0.06915402148039111, 0.14742096525526818, 0.1333463825886288, 0.16044436803748532, 0.15309441323962905, 0.10974072385579349], [0.0764023776977293, 0.010176031125499117, 0.011734363131014811, 0.047416602216300466, 0.05902492185874332, 0.03543182313742657, 0.05029875139195112, 0.03605195215993351, 0.07385412411343667, 1.403137592058028, 34.32240601508848, 53.31105109184019, 25.223581944742513, 33.76055786686559, 66.83903125024611, 22.32506217495088, 0.36018132442428225, 0.06491446026390599, 0.6489462165101882, 0.0897106579354694, 0.21225129374332968, 0.1505347909105401, 0.25880417395983973, 0.36996871052730473, 1.338127370803587, 44.16875147050427, 85.44586104731407, 79.59974873450496, 80.00005798955118, 74.33623390813028, 76.26803259695731, 77.8342350067631, 79.78887757947369, 84.564739811805, 82.76993382361628, 85.61132231066304, 82.47861154617803, 83.18770547066966, 81.08227129905455, 83.83514758079284, 83.55010894037063, 80.2295401788527, 79.66780185699463, 77.67031131252166, 75.93128927292364, 63.00424368150773, 59.431909745739354, 70.7366277325538, 75.58019007405927, 75.51552587939848, 73.22717589716758, 68.93513802559146, 63.71862888336182, 57.432426637218846, 61.68411116446219, 66.42824142209946, 69.06945566977225, 74.45416388973113, 71.96824412192069, 65.40797802709764, 67.86834747560563, 70.03231909967238, 66.2222699196108, 68.9507725930983, 68.5890829947687, 69.23539546228224, 67.05129423449117, 70.48277193500151, 69.21245744151454, 68.9333886484946, 72.58726473777526, 64.002482967992, 61.42083775612616, 58.78544430578909, 68.03020015839608, 67.81880794032928, 66.12723089033558, 70.77765572455623, 66.26186232413015, 61.12047833781089, 64.43649714992893, 54.347180474189024, 49.819455223698775, 52.6549836897081, 66.83882728699716, 66.18576834278723, 63.66150348417221, 66.77999173441242, 65.49689815890405, 65.52928516941687, 64.12850479925832, 65.11660868121733, 65.70582712850263, 61.84627371449625, 52.88644667594664, 48.21382122655069, 50.71267304881927, 51.43457351192352, 62.73225476664882, 62.3078582363744, 63.68653212824176, 61.580999897372344, 65.01537230706984, 60.59198994790355, 58.47046229147143, 66.42180089027651, 57.918600497707246, 54.88429807847547, 60.648017083444905, 60.51277375990345, 61.16738988507179, 61.69977711093042, 62.49572800051782, 63.938803288244436, 59.97649946520406, 56.29761826607489, 59.1629449782833, 58.99900951693135, 58.42346445206673, 51.67327327112998, 58.400989270979366, 63.23612636135471, 59.62987569070632, 63.0763368452749, 55.91907424311484, 54.27539717766547, 53.11511301225232, 53.755749810126524, 52.76463747024537, 52.93220112400671, 57.617323244771654, 59.48867820924329, 62.96202721134309, 64.19370635863274, 64.56586084058209, 62.509397460568344, 61.29627112419375, 61.32035839942194, 64.27751171973445, 67.06448908775084, 72.61852602804862, 71.97848935281077, 73.31353079888129, 67.43614935105848, 64.26952577406361, 66.98794011146792, 75.51879713612219, 75.12226904592207, 73.67201974315029, 24.668358679740663, 2.7760996549360217, 0.3189323007339432, 0.26475634005281234, 0.12907971718138264, 0.06978052052398843, 0.22246822534549623, 0.7015001545509985, 0.3780356163699781, 0.4087866307987321, 0.45319818801456885, 18.164610016730524, 67.16424280597319, 26.87695118688768, 21.665252831674394, 18.04154565257411, 2.6629819312403282, 0.30028155313864835, 0.03688640960101639, 0.018923484472437732, 0.07790769450366497, 0.07458242858129163, 0.04652751887577676, 0.09176274701472252, 0.04044482672226526, 0.07735771232194479, 0.07905547807533896, 0.057686164058865085, 0.10439773555845024, 0.061814083282144806, 0.03368102494747408, 0.01726381435629822, 0.021092275555636135, 0.07740026084525932, 0.07474835556481155, 0.008740458006580031, 2.2835943535450967, 50.239446932269686, 61.67447782331898, 39.59169064798663, 27.519311866452618, 63.53790567767236, 28.658158317688976, 0.45035830007926114, 0.17470250537078227, 0.6430186571613435, 0.20607279463400766, 0.2178519633748839, 0.21976511474818955, 0.5168868156690751, 0.6877151684414956, 1.5593078636354016, 50.1407483316237, 91.0207022390058, 85.29567349341609, 86.36200904846193, 81.3830857123098, 79.77457661782542, 83.2955784951487, 84.06109963693928, 86.29783122770249, 86.48236305482926, 87.92484606465986, 84.44202453859391, 86.08288534225957, 84.10836419751568, 84.9395065922891, 86.0799200304093, 79.78809310543923, 82.6041744601342, 79.89911187079646, 79.5848358831098, 64.38156827803581, 60.73877288449196, 72.26410065927814, 77.45381216849051, 78.14526327194707, 75.78902490677373, 74.15775037580921, 64.93237495422363, 60.04010069754816, 63.81649594153128, 70.60648349023634, 72.35101253755631, 77.41170944706087, 73.93032350847798, 71.81382040823661, 71.60695460534865, 72.22383360708915, 71.13153196150257, 72.74880363095191, 71.90831815042804, 72.37036551198652, 71.13711741662794, 72.34298736818376, 71.04118408695345, 72.62233072711577, 72.72241392443257, 65.10532402223157, 64.93564228857717, 63.153474177083666, 70.84255526142736, 68.59506068691131, 70.50949112061532, 70.89316952613093, 66.46059313128072, 65.96231091407039, 66.95442738071566, 55.80804763301727, 52.221349977677875, 59.83459987948018, 68.55114583046206, 67.7055142002721, 68.4464499258226, 69.48842756209835, 69.16943688546458, 67.92569252752489, 68.52854513352918, 68.06314022310319, 67.35905124295142, 64.39170368256109, 56.982605303487475, 48.88284029499177, 55.010315987371634, 53.407761050808816, 64.89339443945116, 66.2113735752721, 65.24648227999288, 60.603929642708074, 67.85613321488904, 64.94351840788319, 59.085803724104366, 69.2977297690607, 63.55234784464683, 60.001496730312226, 61.675415269790165, 65.12156655711513, 62.626688095831106, 65.97772582884758, 63.330329925783225, 65.31013450314923, 60.581948680262414, 60.15972906543363, 60.29509398245043, 63.46087817222842, 61.544094316421024, 56.09059949075022, 60.96492105914701, 67.65467243809854, 63.88404307826873, 65.07076794101347, 58.905088363155244, 56.060660039224935, 56.83599102881647, 56.99204644849224, 54.62799864430582, 55.747058699207926, 60.10812244107647, 62.48410994006742, 66.26309394836426, 65.79672413487589, 68.23308083318895, 66.79445743560791, 63.92617325628958, 63.19188202581098, 68.23974886248189, 69.93309097905313, 75.4673199499807, 74.31865384501796, 75.26264282964891, 69.16022716029998, 67.05046269201463, 69.54649433012932, 78.35481197603288, 77.19402574723767, 78.02530150259696, 29.24654326131267, 2.771971360329659, 0.21051725372672084, 0.5302190744588452, 0.07731821282856888, 0.14900624631874024, 0.17519606517687922, 1.476140745705174, 0.36811073280630574, 0.22583937993453396, 0.47172216338015377, 19.529977267788304, 78.65614414215088, 30.8437265119245, 30.052688390977924, 34.40899625901253, 2.9443911535124627, 0.15287322833413078, 0.04932088995232217, 0.052034790898042346, 0.026778664680257924, 0.028905211760091688, 0.11479922540245519, 0.06785164902647657, 0.03169509905180143, 0.006512150510154184, 0.024506311916235476, 0.1766079958648451, 0.1698529389837096, 0.16310805575020854, 0.1784177100466144, 0.13938306350140803, 0.11503380918574911, 0.2754019284921308, 0.14472649612974736, 0.14632988751174944, 2.531254767410217, 59.962543672130955, 75.82318090623426, 39.147341020645634, 49.692609694696245, 88.02076370485368, 36.834095754931056, 1.3343389740874692, 0.8344881152433734, 3.7835275838452005, 0.5229884301943164, 0.826592751808705, 0.6338753671415391, 1.40939156614965, 1.1656586705676972, 2.512788493787089, 55.41817580499957, 100.2299645639235, 92.53432135428153, 96.70397343174105, 88.34235883528187, 84.99682026524698, 88.84572444423553, 90.18914407299411, 92.59023866345807, 91.83734755362235, 93.5041509136077, 89.01374309293686, 89.10072557387814, 87.05141267468854, 88.96584310839253, 90.84062622439478, 82.584821485704, 84.7237213196293, 83.02542132716026, 84.36818199772989, 68.18915813199936, 65.15054895031837, 76.86608422187068, 79.89314202339419, 80.17250107180688, 79.5343549789921, 76.68155239474389, 68.62907548104563, 64.51252445097893, 69.5123226411881, 73.56453111094814, 76.41049308161583, 81.22254310115692, 76.28962916712608, 74.16942334944203, 75.18150468026438, 78.44887041276502, 73.89005645628899, 77.28705652298467, 77.0073523059968, 76.34217323795443, 74.606579349887, 76.81368135636853, 74.30935782770958, 73.98638202298072, 77.30618984468522, 68.18731461801838, 68.36668460599839, 65.24417200396138, 71.80234355311241, 73.09440366683468, 73.48606017328078, 74.28602756992464, 70.9016026220014, 67.71529659148186, 70.37165118801978, 59.092636492944536, 55.90549891994846, 60.78583740418958, 72.29813114289315, 72.34631353808989, 68.3996089812248, 74.02648433562248, 71.1374782746838, 71.89855144869897, 69.91181604323849, 70.94453688590758, 69.68453038123347, 65.0769692082559, 56.82512998580933, 51.86438683540591, 57.069854505600475, 56.00866510022072, 68.06118688275738, 68.3320265431558, 67.9401425392397, 63.813295287470666, 69.76792781583725, 66.62164565055602, 63.628147648226836, 72.60568418810445, 62.90038324171498, 63.77447951224543, 65.28251709476595, 66.08705013029038, 65.78272127336072, 69.10569837016445, 65.2781750309852, 69.3633274878225, 65.57851091507943, 63.857884791589555, 64.37960709294966, 67.57737821148288, 64.80565494106662, 56.00290313843758, 62.515214335533884, 70.76946581563642, 66.61600528224822, 69.61643803504207, 62.953068517869525, 59.43547125785582, 61.207923658432506, 59.67831696233442, 58.82727246130667, 58.599543571472175, 64.94381650801628, 66.91858476208103, 69.34540225613502, 69.78408798094719, 73.82856938146776, 70.48711007641208, 67.22324309810516, 67.4007381931428, 71.54910749004733, 72.47639502248457, 78.62172926625898, 77.49839382786905, 78.45696618480068, 74.03909867809665, 70.52617688332835, 74.61076844123103, 83.67191422370173, 84.04214674426665, 85.81394410902455, 36.36334073159003, 3.6949763999831293, 1.0440392095235087, 1.0845369461082643, 0.2400039626105178, 0.3748622656829896, 0.44875218142424866, 2.111486633939128, 1.2791085699873588, 0.6381955514511755, 0.48301046894442656, 22.102144072132727, 89.95602192417269, 38.63603653446321, 36.457210894553896, 52.26557470137074, 4.657783690960177, 0.47548987572231605, 0.2751558916943689, 0.13668130121884808, 0.19943068975642805, 0.14849174166879348, 0.30955621191570837, 0.19159354900400485, 0.13027046296385028, 0.08987486122115966, 0.1571601797496119], [1.1926912780730956, 0.1265145253930842, 0.07918618799697968, 0.05489445156267574, 0.011394549510441722, 0.14439284951696474, 0.05426304955636302, 0.05795727108394908, 0.2836129201516029, 19.199095925977154, 55.45348105892059, 34.0158845532325, 22.85458214821354, 47.58634790297478, 69.1422156364687, 6.339160617320768, 0.2850231654461353, 0.20648482736320267, 0.3484699238211878, 0.2772462085610436, 0.12700405557669942, 0.2553196077144915, 0.05739392449838981, 0.3196367951891115, 3.879459687779027, 48.2188497051116, 80.35228683102517, 79.2310380935669, 79.46190095716908, 79.27610612684681, 80.89908092252671, 80.85868050975185, 80.95028354275613, 83.76208951396328, 83.46737830869614, 84.64061414041828, 84.14680342520438, 82.80316414371615, 80.95620632171631, 82.52044754643595, 81.31629559301561, 80.61645846213065, 79.33032897210892, 79.01850054340979, 75.00267597936815, 67.84996724897816, 56.39141390400549, 58.499115205580196, 65.10655564646568, 72.23622829683366, 70.09558693055185, 65.23520546574747, 58.22039942587576, 57.42088310180172, 61.03191906406034, 68.80344836942612, 69.90405759503766, 72.31840195194368, 70.67843544867732, 68.96355167511972, 66.97090918017973, 69.92855671913394, 66.50912069505262, 67.65944204022809, 65.84704029944636, 70.61569321540095, 64.86400019737982, 64.64383363723755, 69.54840060203307, 73.4081462121779, 63.79120057629001, 63.47421030844412, 61.76232322569817, 66.82629139192643, 71.18027917800411, 63.5207139292071, 70.53752037786668, 65.37856417317545, 64.71133762790312, 65.06488830812516, 54.562753938859515, 49.72246677644792, 54.0234084283152, 65.98751606479769, 62.04546736132715, 62.847490079941295, 69.50639986222791, 65.2196297337932, 63.705524244616115, 64.85145645756876, 66.36021967857116, 64.64130370847641, 65.1035903346154, 63.65564738550494, 64.53241871249291, 52.87904516343148, 54.45077027043989, 55.25147899504631, 53.45417837942801, 64.65931915467786, 63.588178696170935, 61.471428486608694, 62.66192274708902, 65.68723117151569, 54.249231046245946, 62.67669047078779, 65.04215032823625, 62.46745163394559, 55.99210093098303, 61.1180111669725, 61.742895726234686, 59.47240429539835, 62.16191468700286, 60.53235815417383, 59.45085087130147, 58.93813040948684, 59.42763828462171, 60.05187173043529, 57.16433263594105, 57.96319784656648, 63.90576124191285, 64.2317964953761, 60.97490349123555, 59.70293375753588, 55.051995092822665, 53.97315502166749, 54.44074469227945, 54.02645610993909, 53.62274615995346, 51.070385363794145, 53.19618840371409, 55.21281226988762, 59.218289621414684, 60.38912496259136, 61.90950232167398, 58.7350183148538, 60.50132043900029, 59.419656261321045, 65.34110553802984, 68.48947048187256, 73.06560562502953, 72.53566988052862, 69.92755259236982, 66.19912793559413, 65.55107393572408, 69.82546114152478, 72.99139438136932, 75.15937466775218, 61.28311941700598, 18.47079807712186, 5.3809010694103865, 0.41902582491597823, 0.39614388178433146, 0.09171924854238188, 0.19658124104382532, 0.0902075961893124, 1.397470134881235, 0.2969204189796602, 0.35331530736819394, 0.4331993095336422, 14.531895114529519, 68.00019402657786, 37.88769929639755, 20.23500761678142, 15.823068772592853, 15.042355310532356, 4.272798645880915, 0.2595956347161724, 0.07732221946841286, 0.09396078350443034, 0.07400771708137567, 0.06608176375589063, 0.3758047070474394, 1.5692651680400296, 1.815286766617529, 2.433018271000155, 0.2925774665369142, 0.08985966203674194, 0.035162535571162744, 0.06633234345504353, 0.017284374240966096, 0.11895677690664608, 0.02487432331808152, 0.11267302497740715, 0.4771518268652501, 28.39976041547714, 69.16670691582465, 46.87575171070714, 33.16155310600035, 39.13855883382982, 77.90188020275485, 8.435560099540218, 0.342502006960492, 0.3549821308303264, 0.3850278847159878, 0.6543184540444805, 0.048568859741452246, 0.024076854517202706, 0.1716425050530703, 0.03631457859169572, 5.4514238142198135, 50.925442018816554, 85.54237488777407, 86.03140031137775, 83.98209525692849, 84.17991607419907, 84.18418361294655, 83.74931827668222, 83.18040986214915, 84.78486322587537, 86.09091051163213, 88.04363896769863, 85.26611451179751, 85.40316212561824, 84.48323295962426, 86.67639486251339, 81.30034723589498, 82.77887682760917, 80.64604097797026, 81.13848670836418, 78.01315784454346, 69.77861235218664, 57.99004647039599, 61.16170244832193, 67.5758877108174, 74.84379645316832, 71.2091713566934, 68.29788623317596, 61.40703885785995, 61.823335693728545, 63.8789479194149, 72.17389399005522, 71.86796480609526, 76.27685008510467, 71.78973705537858, 75.596891526253, 69.72298529840285, 71.87580170169954, 70.1782783385246, 70.02127370526715, 68.1865301439839, 71.50418066209363, 70.00530965866582, 67.93760084336805, 72.7963270679597, 76.98637547031527, 66.34136876752301, 66.25985407060193, 64.37674376272386, 70.35237666099303, 72.69046229700889, 70.18566808392926, 71.44023033880418, 65.38260421445294, 69.728633511451, 67.74953103834584, 54.36939677884502, 53.34386956307196, 60.85752264145882, 72.07106513361778, 64.46489903234666, 65.12317472888579, 70.93140479057067, 69.94194769090223, 68.25159442040228, 66.49915787481493, 67.37304625972625, 66.95668666593491, 68.62716136440154, 68.07759807955834, 69.12123095604682, 55.64229219190536, 54.66288812698857, 58.00311580781014, 54.81548009380218, 66.150663129745, 66.45517241570258, 64.98564858590403, 62.67275241113479, 67.10906290238904, 58.83119875384916, 63.420650343741144, 66.5979310004942, 65.41890575039771, 58.71592421685496, 61.462548240538574, 63.392958410324596, 62.72477088436004, 64.45857224925872, 61.4083920755694, 60.886434431998964, 61.19314024525305, 62.00632995174777, 61.95475470635199, 60.41604026671379, 61.4670354320157, 65.76025785938387, 67.54283781974547, 64.3630233118611, 61.51358219885058, 56.32956989349858, 55.41797576412078, 56.95654507606261, 57.058412951807824, 55.478623451725134, 55.30694523165303, 56.21288722561252, 56.94560950802219, 60.59286855882215, 62.46882838587608, 62.44977351157897, 61.00336420920588, 63.01052339615361, 62.22039330390192, 67.73573214007963, 71.26511220009097, 72.76652489939045, 72.94897002558555, 71.16040060597082, 68.31177142358595, 68.78305204453008, 70.56929157626244, 77.77780778946416, 77.01201208176153, 72.8991323901761, 28.62119193999998, 6.235963548383405, 0.44168244626733566, 0.37739026390256425, 0.050044287627022115, 0.2778130829814942, 0.06541815541324116, 2.451959641710405, 0.035306870366536805, 0.3838510510902251, 0.4467855111485528, 16.796497106552124, 81.1012634154289, 41.93249448653191, 28.30371137588255, 35.422218999555035, 20.011254049116566, 5.691385596029221, 0.19447808454353965, 0.019357111304998398, 0.1120829227710924, 0.03710670967496211, 0.018869509747732553, 0.2690833272232164, 0.66413571757655, 0.667872817045258, 1.1636140125413095, 1.978169807022618, 0.27413264337566595, 0.18907825252221477, 0.12315438714839759, 0.1474998263461936, 0.17692365473316563, 0.18678836975126498, 0.18664031559901853, 0.7674249622129625, 33.107322415997906, 86.84911251068117, 53.491942959447066, 38.1124589520116, 66.05472195533015, 94.80110614530503, 11.524147141364313, 0.306207028728339, 0.6492025188861356, 1.2941107778779923, 1.542000772972261, 0.36974954809392657, 0.5546941127507918, 0.39478465794555606, 0.46001609474901234, 6.568323623749518, 58.26326308711883, 95.23763456652242, 97.62944098441832, 91.4254359276064, 91.6197266117219, 90.14509585595901, 90.14762186234998, 89.63101433169457, 91.0838367092994, 92.70437179073211, 90.93808927843648, 90.3575235797513, 90.8692281476913, 88.47147541661417, 91.33146378301805, 87.71099059812485, 84.33190791837632, 82.19671080189367, 83.24043781526628, 81.33551520685997, 73.59845176819833, 60.50368562821419, 65.32332543403872, 70.63764279888522, 78.97578593223326, 73.63738521452873, 71.97058185454338, 65.92570735562232, 66.09748363494873, 67.78156111317297, 77.94574014602169, 74.49482317893737, 81.19187801114975, 75.7987210058397, 79.19970620063044, 72.92071327086418, 77.81161077560918, 74.21591912546467, 75.04309992636405, 71.57341834037535, 76.04949382043655, 69.7037656845585, 71.56243570389287, 75.31230788077079, 78.9718714068013, 69.60640461214128, 68.73281432736304, 68.22536945343018, 72.28852918071132, 77.83700420010474, 70.50839285696708, 72.94338457046017, 69.18611480343726, 70.48612163912865, 70.51699069238478, 59.00719942585115, 55.45012743242326, 60.96803542106383, 74.89473235222601, 65.58463373491841, 67.14391708374023, 74.35437094780707, 71.7602643659038, 70.51816740343648, 69.8862265002343, 72.93790109695928, 69.64023897724768, 73.41855618261522, 69.64248257298624, 70.75601208594539, 58.531568896385934, 59.80507227682299, 60.20169842627741, 58.175307858374815, 71.21802022380214, 67.3672176176502, 67.03178436525407, 65.38886823961812, 69.84237440170781, 61.11570873568135, 69.68975497830299, 67.82163989159369, 70.28556300747779, 61.31837760248492, 66.66254812671293, 66.8523359298706, 65.83215882701259, 67.0344280427502, 65.88679744351295, 63.2819200331165, 64.87152330337032, 63.950876343634825, 67.82751560211182, 63.633227117599986, 63.92241170329433, 70.46214811263546, 70.56794228092318, 67.09516202249836, 65.11954261410621, 61.574633890582675, 59.67559091506466, 61.81408674486222, 62.66351130700881, 59.70295729175691, 58.486571465769124, 59.25142188226024, 61.484266404182684, 65.30842827212426, 67.84395033313383, 68.83827117181593, 67.01890330160818, 66.35814082237982, 66.56478697253813, 70.68857085320258, 74.63355741193219, 76.98584987271217, 76.37114386404716, 74.91113570428665, 73.04194588815012, 73.54215791148525, 75.12099819798624, 84.85674458165323, 84.39759977402227, 87.22909604349445, 37.86592621957102, 8.162099805570419, 1.3839771814884678, 0.8300294222370271, 0.24885924953606822, 0.6160998596779762, 0.35686759578604854, 4.326911174481915, 0.3760980574354049, 0.5816365670292609, 0.566664389785259, 18.98388135817743, 92.91336351825346, 57.047571520651545, 40.84713543615034, 46.970586776733406, 33.34711651648245, 7.702840268611909, 0.42080924696018623, 0.1561003583934038, 0.17144460922047017, 0.22913711265690867, 0.11278930946343368, 0.7509173609076009, 2.7435981602438035, 3.586743498040784, 4.475544979495387], [8.873107356409873, 4.765272323162326, 0.1747392163041138, 0.0307995499291968, 0.03479523471586647, 0.11015906148860533, 0.047725573137042024, 0.3446792594848141, 2.2763494906886934, 42.33177608059299, 61.12564409932783, 27.430938905285252, 25.067799129793723, 50.52328532741916, 49.05801334688741, 2.3281115389639333, 0.24539538298643407, 0.6223668266207941, 0.5584311509324659, 0.5033914414384674, 0.02454306115396321, 0.16078498605037891, 0.10917597915977241, 0.11958497666543531, 3.0012160010876197, 56.00748446679885, 87.15875225682413, 74.61954670567667, 86.436581150178, 81.37357004227178, 82.4644047214139, 81.91681831113755, 83.20093954763105, 80.9996504937449, 81.71662053754254, 84.00817117383404, 82.7995006499752, 79.82970160822715, 73.22679934963104, 77.60994603556972, 77.25464990062099, 78.94785865660637, 78.30579019361927, 78.28920641253072, 78.17253943412535, 71.70063649454426, 60.05799847264444, 57.84573070464596, 55.432700341747655, 58.85552921602803, 59.31608999929121, 57.741085790818744, 54.41415102251115, 59.60795356381325, 64.64554379063269, 66.83923521349507, 71.31443208263767, 70.48245030064737, 69.8389462501772, 71.92172481167701, 65.32226247172203, 68.78808836783134, 66.94650419296758, 66.19233439045568, 66.40064362556704, 68.17732826355966, 66.48775946709418, 68.67877191112888, 73.06142437842585, 63.22534768812118, 64.0134616821043, 66.7655417226976, 63.622299394299915, 67.73674411158409, 64.26587796980336, 67.19088354418355, 63.59835332439792, 66.20541941735053, 68.28788418923655, 56.40073737790508, 50.19649697888283, 59.60220336914063, 69.88887802247079, 65.5992720204015, 64.92465572972452, 63.64748885554653, 62.647225626053356, 62.83554254039642, 63.21881301941411, 61.28963055149202, 61.065518086956395, 59.238807539786066, 58.09790380539433, 64.38884427470546, 59.7775137039923, 60.76910849540465, 45.9465814405872, 58.419463634490974, 57.96512765269126, 56.55461588213521, 64.69238865760066, 63.770831707985174, 62.3325534789793, 62.16791199099634, 61.61575994183941, 57.215829433933386, 61.06561222384053, 61.1747560962554, 61.28419414643319, 56.8362852065794, 59.03475407631167, 60.403798549406, 57.95522366800616, 59.63169959283645, 61.29671827439339, 60.70426779408609, 56.966888366207, 58.02082138676798, 55.24604651235766, 56.75808883482411, 62.038948382100756, 59.58179527713407, 58.65699844975626, 59.12414097016858, 54.97857224556708, 53.60201643359277, 52.41762930347074, 53.865176093193796, 55.39895226878505, 53.6065036250699, 51.059669448483376, 51.45897065439532, 50.188299225222686, 50.89674595863589, 52.560089788129254, 53.02722838617141, 55.73817060839746, 62.72854420446581, 67.16306609492149, 69.7250327756328, 71.98496910833543, 69.52941633039906, 68.1325347961918, 66.95607477618803, 62.84734102987475, 70.33606744581654, 72.31099651705834, 69.95784897958079, 35.952425387597856, 10.234798366023648, 5.1566679919919665, 1.1245554180875903, 0.15233404033126371, 0.07705575110571039, 0.13984961104729485, 0.15834517987264743, 0.93642310029076, 0.022319004487907215, 0.17754190300981845, 0.3989663029149656, 10.218883349049477, 73.832899678138, 41.32418194124776, 39.963790216753566, 14.4826909419029, 17.391848179601855, 20.365008692587576, 0.06699834199201676, 0.05360871853847658, 0.023817932120554393, 0.026451947332750407, 1.5769300922270746, 6.968819681675204, 10.461069114746588, 10.781316911020587, 10.449227479196365, 6.175169262193865, 1.9035360505503995, 0.07201021942760676, 0.03507704015881304, 0.026335584322711634, 0.14324285961206884, 0.062110655069831884, 0.23453907440266303, 3.6587464472939892, 58.52125698520292, 70.96760826726114, 43.38397933590797, 29.19592115186876, 56.321807522927564, 62.78040970525434, 2.982039043018895, 0.2826723173981713, 1.7948437410016216, 1.1490019579087536, 1.0654211524994144, 0.13179600449098697, 0.11257126551842499, 0.18479960549983288, 0.2387350452162566, 2.4945835480766916, 58.96758348711076, 93.68092429253363, 83.62335528096845, 90.19289385887885, 87.70633866710048, 85.26066241725799, 85.89527053217735, 83.56076209775864, 85.57010604489236, 85.03052126976752, 86.9030451005505, 85.10292822314848, 82.41651258160992, 76.26741286247008, 78.80295845770067, 80.08200414719121, 83.96100859488212, 79.65356365326913, 79.73023814539756, 81.18456671314856, 75.26646321819675, 61.370929518053615, 59.359471413397024, 61.385763922045314, 60.7851117657077, 61.406552483958585, 60.43764468162291, 57.73197804727862, 63.65165049029935, 66.12972551776518, 69.4707533621019, 72.77804097821637, 73.1188714119696, 74.77361740604525, 74.66630920287102, 70.28174261892997, 71.83762919518256, 71.49071124292189, 70.30281359149565, 69.71990231544741, 69.71934533888295, 70.2570552210654, 74.0122304424163, 75.07348260571881, 67.51550674438477, 68.00534802098429, 68.91455342692714, 64.49503852475074, 70.85429099298292, 65.4146146774292, 69.47009440391295, 67.04144908535865, 70.36575978802097, 70.34661077683973, 57.15770775272001, 51.92514434937508, 64.08807692989227, 72.97780729109242, 67.49210588393673, 65.28509801433933, 66.041197622976, 63.522981059166696, 63.53042964012393, 65.26395251674037, 64.3887540601915, 63.266328611681544, 60.2149050466476, 60.22036890829764, 64.51997695430633, 63.05842338069793, 62.9973481547448, 48.11971179900631, 58.86941440643803, 62.010479819390085, 58.07369885906097, 65.81504944832095, 65.36549091339111, 65.21795095935946, 65.46873161869665, 65.14306114565942, 59.11546076497724, 63.122134439406864, 64.25259290202972, 63.63770646433677, 60.106824136549434, 63.278844894901404, 62.66331518850019, 61.577348170741914, 62.10318896078295, 62.79526764346708, 62.57469315682689, 60.28674325635357, 61.22731585656444, 57.898918044182565, 59.0537501150562, 66.7129192044658, 63.245147812751036, 64.40096047616774, 61.57164504451137, 57.339148752151004, 54.4221918813644, 55.994018969997285, 55.270945718211514, 56.87619532308271, 56.31459428418068, 54.6514073494942, 54.71723256572601, 52.73004608769571, 52.75927559021981, 54.20051128633561, 53.59576809790827, 60.437789809319284, 64.78149706317534, 68.57460944883286, 71.03639095060288, 72.23884844010877, 72.71091353508734, 69.85200774285101, 68.31713722598168, 66.5172400013093, 73.78831801875945, 72.79420898806664, 78.21852530202558, 59.86550031169769, 21.676619860433764, 7.163046136979134, 0.8764640337997868, 0.7365802399093105, 0.06237756776353044, 0.15997245787612854, 0.5310188089647602, 2.0269083207653416, 0.10952679380293816, 0.3714708557292339, 0.5154541086766028, 12.137894130522206, 82.56804158610683, 49.136762772836995, 46.53093222648867, 21.225337443813203, 33.112692140763805, 23.354792210363573, 0.05724335757775172, 0.023684374267055143, 0.03715161391864381, 0.03197181767093078, 0.882316516532052, 3.664746938213226, 5.973213776465386, 7.835146227190572, 7.741422172515624, 16.042855843420952, 5.974827831791294, 0.30488555770247217, 0.09897244643540153, 0.09669447633167429, 0.2210469790283711, 0.1437413683461566, 0.3419488301921276, 5.84332105613524, 72.08553867955362, 86.0279643151068, 47.13408685499623, 39.74205470854236, 71.60963750654652, 73.73389905498874, 4.8735939687298195, 0.47027076384232896, 4.6093409484432595, 2.1718494594097137, 2.4957585430914357, 0.30872206474023484, 0.38096525916649454, 0.4832277008362355, 0.3182352832969158, 3.230870774676723, 68.71253567357218, 101.85057809275966, 91.62167210732737, 98.17593697578677, 95.90085244947865, 90.45679092407228, 93.78529071807863, 89.64138507843019, 90.67448246863582, 89.85931196520406, 92.92728008762484, 89.12194559651037, 87.89662853364023, 78.4149811344762, 83.79397053872385, 84.05789898287865, 85.271770569586, 81.85318962220224, 83.4894141843242, 83.17830747173679, 79.10728731463033, 66.65362081220074, 63.916661508621715, 61.86449704631683, 63.61457232506045, 66.28549068204819, 63.59533702173541, 61.12947233261601, 68.32422102651289, 70.35800133982013, 73.72484622463104, 78.26040837072557, 76.86317382320281, 77.78071034339168, 77.35625497756466, 71.66415845194172, 75.22159914816581, 74.65434597384545, 73.50762536448818, 72.51335159424814, 73.83107969837805, 72.3100394587363, 78.55969305961364, 79.34493587863061, 68.92347289669898, 69.50730985210788, 72.88247800642445, 68.2095544568954, 72.82765111615582, 68.1515504467872, 72.81234602774344, 70.31679291878977, 71.07317493807885, 73.24522664470058, 63.03108838296706, 54.33493875688123, 65.7627603315538, 78.34298995233353, 68.24529509390554, 69.82738310290922, 70.75765948141776, 68.37888317723429, 67.82025137255269, 70.22892398218956, 67.93352942312917, 67.0118587247787, 63.74837613874867, 63.24543806814379, 67.61868861413771, 66.85857249844459, 65.73600584460844, 52.83297692575763, 64.72604259367913, 62.25801275622461, 61.609452770602324, 68.50999232261412, 69.72702533968034, 66.69143246066186, 68.59779065655124, 68.47060388134372, 62.77425550645398, 65.41001373721708, 65.34798537531208, 66.33878784794962, 59.78150275445754, 64.53671370783161, 66.98857553543584, 62.65791408477291, 64.46693474246611, 66.26211335582119, 66.97949132611676, 65.1049945431371, 64.89226087447136, 59.77039460212954, 62.0718413783658, 69.66380457724296, 66.10137462615967, 66.32327095154794, 66.91112441401329, 61.18038469745267, 57.8626282753483, 58.15227962309315, 59.605035320405044, 61.589770317077644, 60.465936737675825, 56.25202855756206, 59.62718886713828, 55.575384401506, 57.49872646024151, 60.46379512356174, 57.92404474750642, 62.40115965566328, 70.15959216702369, 70.49137761515956, 75.3083384421564, 77.63453145180979, 76.47301566216254, 72.84731003545946, 72.80020236968994, 69.67080208563036, 79.02268963475382, 77.43995051230155, 86.56069278717042, 77.48484596129387, 31.91023269007283, 6.104484719614829, 1.3601804068011623, 0.9541962175599991, 0.2727948699987704, 0.3910455360047279, 0.9431462879142455, 3.7560577546396567, 0.17557091199822966, 0.9516311713284062, 0.5594373001686989, 15.200115000047992, 94.16084981733754, 62.35448345061272, 59.27368917772847, 30.509060082897065, 51.65887032785724, 28.263571800724154, 0.13896268041383836, 0.13227801169118575, 0.12905373147899105, 0.053777594960504965, 2.3215837344046566, 10.177675908611668, 15.299416665107975, 16.578454509858165, 17.68377254086156], [18.196779335698775, 15.978158308613686, 3.4171546755298494, 0.0961507760709332, 0.6866413583197902, 0.42786237333090077, 0.49455875410668315, 0.1417657195199882, 12.17194716776571, 58.863275897118356, 36.08532705614644, 14.761226292579407, 30.10761530168595, 53.35353428317655, 47.66954921906995, 3.7904204139786386, 0.2488290503500931, 0.45609102794720285, 0.1422390852484011, 0.4455035702595788, 0.11247827776617582, 0.08008738318758626, 0.02339543463031371, 0.22940988592322797, 3.169047111465085, 56.04439397012034, 71.64718243383592, 80.17538009151336, 86.79422286248978, 84.9760317033337, 85.59699781479375, 85.07127469585788, 78.03884936917213, 81.99265341604911, 79.30576709008987, 84.45640394764563, 79.6978864362163, 80.58552665095176, 73.76179495165425, 73.33120499887775, 72.35423672583796, 78.39086640265681, 78.1765716306625, 76.06496364839616, 72.76581102801909, 70.46431326097058, 62.42781608335434, 58.70705181552518, 57.09613830812516, 60.044105437494096, 57.256104330862726, 56.878007458102324, 56.648289926590465, 61.47173443148213, 65.53865178938835, 66.33761898163827, 69.1965247738746, 68.0961508904734, 71.16039276123047, 67.38074195000434, 70.26894000268751, 66.87831770989203, 68.26804484090498, 65.2676042433708, 65.75954791038268, 65.9887319995511, 68.66217244055964, 68.65604569835048, 66.36884889295025, 62.16109883400702, 69.99802189488565, 61.82310819625855, 66.70800055226972, 66.88926112267279, 65.5287987955155, 66.01033641446021, 67.73531636884137, 67.4017736988683, 58.133675821365856, 48.615624904632575, 55.33460186373804, 68.88269593638759, 67.61013784716206, 59.725659970314275, 56.55431385963195, 54.030908000084665, 56.42582877989739, 56.91091222147788, 60.06249350886191, 56.85742285943801, 55.60649271934263, 52.846403198857466, 53.833906958180094, 55.523746398187455, 55.62870510162846, 59.26939418238979, 53.4346685101909, 44.26207250164401, 60.55286038306452, 58.5319846676242, 55.93021769677439, 61.242675858159224, 63.06147890706217, 61.773505903059444, 61.24841820809149, 59.17559462208902, 56.4396551347548, 62.484282524355, 60.75347785026797, 62.23195252879974, 59.770480894273334, 59.607545637315326, 58.107948995405636, 59.417342062919374, 60.106251470504276, 59.954659708084606, 58.74156082830122, 55.10826933768488, 53.520721389401345, 59.883547136860514, 62.91639827912854, 60.70142015334099, 60.54945184338478, 56.74747882350799, 53.066350106270086, 54.61770634497366, 53.591724134260616, 56.78685549766787, 53.32159050049321, 50.62872256002119, 51.99792785029258, 51.6110291788655, 49.77861550546462, 50.68797780621437, 51.08882050360403, 53.917214178269916, 59.8194085398028, 62.99335125953921, 65.95548598997055, 69.3376830316359, 68.73333992496615, 72.399626393472, 66.72707896078786, 64.08537441684355, 65.34583199408748, 68.37012844700968, 73.15090148679673, 51.95300886707922, 13.5388715997819, 13.832298228817603, 13.3084225462329, 5.050902260888008, 0.24098153676717515, 0.049899519991970835, 0.08890870943545334, 0.46659525784273304, 0.24134138358696816, 0.08068621879623783, 0.18599277212014123, 0.06430782588018526, 11.234876263526179, 82.2037632234635, 35.064902843967566, 39.05303939696282, 34.896946953188994, 21.321353143261327, 42.91466774479036, 3.4947050819473886, 0.4023286628146326, 0.17073038544866348, 0.21598102344620615, 10.665448134945287, 24.513277969052716, 23.70152581122614, 33.803103816124704, 25.523543242485296, 16.98696740211979, 11.569402467819954, 1.5414528668888154, 0.08269720725835332, 0.1705627654108309, 0.18245183712532445, 0.3050962318816493, 0.28775295122496547, 20.149080253416493, 70.40381462343278, 51.98499971820463, 26.535291171843006, 36.992826231064335, 69.72418554367559, 55.830816991867565, 4.969254693677349, 0.3137829947856165, 1.5336794646516925, 0.13476402829250983, 1.0903902255719709, 0.1505663996982959, 0.09099702681264571, 0.07874606282360132, 0.0979648263103539, 3.0262348392317375, 64.13294884466356, 83.87947036374001, 82.84354886701031, 91.43419850257136, 88.34093109253915, 86.19892474143737, 86.52853719649777, 82.82020291974469, 83.00965339906755, 83.3392736988683, 85.11591126841884, 82.04971605731596, 83.23798241153841, 76.52399078492196, 77.60279947711577, 74.47965929585119, 81.40971860577984, 78.94609359002884, 79.43156534625639, 76.37108895086473, 74.04853590073125, 64.56528032979658, 62.02217632724393, 61.04529042397777, 62.75154890552644, 59.52080634332473, 60.54742397800569, 61.81892694965486, 65.84406714285574, 68.35491749548143, 69.12867561463388, 73.1037389078448, 70.52168969185122, 74.74140690219018, 70.40614451131513, 70.75666319939398, 71.0280990600586, 71.30089990554318, 70.10656956703433, 67.83150857494724, 66.89803154237809, 71.79625603460497, 70.35691092091223, 67.59030634357084, 67.08665047922443, 72.67890699448125, 64.23077275676113, 70.52190934458088, 67.4296146823514, 69.05991646551317, 69.57922258684712, 68.61700242565524, 68.43714606377387, 59.37698479621642, 51.87243946136967, 58.70448658543249, 72.78056698460733, 69.61097025102185, 61.3903138714452, 58.06151597730575, 56.03508226333126, 59.80905740491806, 59.64722825634865, 63.68532011585852, 58.86660206702448, 58.99403987392303, 57.25107585230182, 58.00436312152494, 58.36592720400903, 58.43981681331512, 62.68583743802963, 58.43015209321053, 46.88347093520626, 64.18606950390723, 62.14384432761901, 57.48017757169662, 64.30827879136609, 65.2566804424409, 62.70459421219365, 63.032778924511334, 62.673293698218565, 60.78480189846408, 65.42263200206142, 62.550739242184555, 66.0908156056558, 63.4498445449337, 61.698561176177, 61.546855665022335, 60.887893553703066, 61.651096574721805, 61.26186017067202, 59.916079275069706, 58.62778855908302, 57.251060162821126, 63.60053023984356, 67.23297842087285, 64.22490881335351, 64.10106781990298, 58.07230249527962, 55.433445592080396, 58.39511748283141, 55.78617257456626, 57.91862403192828, 58.972792394699596, 54.81493096197806, 55.53267371269965, 54.5314298906634, 53.05267280147922, 52.856177745326875, 53.6282806242666, 56.640303980919626, 62.64501340927617, 65.05096389401344, 69.98723537691178, 70.59096659383466, 71.15348154498686, 72.61471348424112, 67.72687542823054, 66.77039761697093, 66.58077455336048, 71.91438997945478, 75.6860391555294, 70.73883210459064, 37.873429713710664, 17.55993939215137, 17.83741766406644, 4.898252929410627, 0.3712998342610175, 0.07223367195336089, 0.04580396798349196, 0.5792950958974901, 0.6163031487695633, 0.16146531809241543, 0.3814674144791019, 0.1478331052367726, 13.058854879871493, 92.13535354983424, 43.70715910388578, 48.19573125531597, 45.19385899266889, 34.64660167694092, 56.63048628837832, 3.4683006665399, 0.1112639288147611, 0.033740906210075465, 0.14109752231067227, 7.114971116665871, 23.54704914554473, 22.424625658219863, 21.97758920731083, 20.076432074269942, 31.03981952513418, 24.851096022513605, 5.889022061901708, 0.474305932800616, 1.1140037520277886, 0.6289315872615384, 1.26152666826402, 0.42320063638110317, 24.8190482970207, 86.92790508270265, 59.20838563672958, 27.280229676154356, 48.09072156106272, 78.46365774831465, 68.08093209420481, 6.62244301649832, 0.37554019220894386, 3.3891920985714084, 0.639212977501654, 1.9584068223353357, 0.4562007623814768, 0.38106981484640035, 0.19342606196240072, 0.4414437945571638, 4.3580136087632955, 71.988373725645, 88.263762381769, 88.60450652337845, 96.29127733169064, 95.50993334862494, 94.34522474965742, 94.07061961389358, 89.26171533523068, 88.40514029225996, 86.20243134037142, 91.40875016489338, 86.84907328697943, 88.16298884730186, 82.92099998843285, 84.11348681296073, 77.92745405627836, 84.68372883335238, 81.96771498649352, 79.44556820777156, 77.6201520427581, 78.58707904815674, 68.43815803527832, 63.367290419916955, 63.27397723351756, 67.26559685122582, 61.71994201598629, 63.30212023950393, 64.98285978071152, 69.14467104019658, 72.03679930779242, 71.93419010408464, 76.43934603660338, 74.130748779543, 78.31369769188666, 72.0995101621074, 75.33503409354918, 73.87994458598476, 75.54306876274848, 70.53921484178113, 71.28890529755624, 70.23717664903211, 77.75794490691155, 75.09937809359643, 71.83274192194786, 68.21128814451157, 74.95490151066934, 67.60172044077228, 73.79112643580284, 70.98659253889515, 70.2984126921623, 73.96755464615362, 72.78210455371489, 72.02283566997897, 63.02272981212985, 53.62282852972708, 59.80172257269583, 77.15150725456976, 71.70794779254545, 64.23013341042304, 61.03257409987911, 59.84010296483194, 61.60290241241456, 61.73224649121685, 67.88071863112911, 61.534821833333666, 60.83788725637621, 58.57771165909306, 60.55592767653927, 60.90686605822656, 60.87777383865849, 68.89720870602515, 58.92701833478866, 49.96852490209764, 68.18730677327802, 61.96103442099787, 60.50777273793375, 65.1083795485958, 67.97665980554396, 64.62297447266118, 66.96646121240431, 66.46020873900383, 62.90650606155396, 68.0808771810224, 65.76180327323176, 67.95522013018208, 65.52119331975138, 65.18452844312115, 62.7123801169857, 65.04152667137885, 65.34829916492586, 67.24145074044505, 62.70260557051628, 59.94064507945892, 59.007540672056145, 65.24263051248366, 70.9215674861785, 68.4251122320852, 66.7721156151064, 61.23109309904037, 57.91605487946541, 59.9024215821297, 58.258175773005334, 63.11621950518701, 60.57852837347216, 57.01787525607694, 58.22243121362502, 57.99842073071388, 56.1554088131074, 56.01403482498662, 56.96239332998953, 59.40456298089797, 64.32824365554318, 68.26528349230367, 72.76944314279865, 75.80422801356163, 74.00693524268367, 76.97008194461947, 71.21849090822282, 71.23676130848547, 71.7223507358182, 76.87981251747378, 83.06972842062675, 86.17234676114975, 57.56452421988211, 30.710522820872647, 17.136388132649085, 5.734014895654494, 0.8277755302767601, 0.1453341111060112, 0.3001547196219045, 1.0410737750991699, 1.5869490513878486, 0.39202566889505236, 0.6064044960564183, 0.356859659115153, 17.17692582837997, 102.14569722452472, 53.61385022440265, 58.62873777266472, 59.28536999610163, 52.460426284420876, 66.87913356288787, 4.7967949413484146, 0.4330105454690995, 0.21262227948154175, 0.4777003458190349, 13.159800018033675, 38.935289844389885, 37.84596920013428, 45.589120157303356, 40.38352697126327], [24.645448115564164, 23.174333764660744, 8.589273864223111, 1.949986596741984, 5.238692597035439, 3.2632256707837506, 2.3569407145823202, 0.34652645068783916, 22.968601526752597, 65.11606347176337, 25.836307156470518, 16.364371545853153, 32.988855069683446, 37.66998421761298, 49.621940351301625, 3.365927540486859, 0.1247169996701902, 0.05621011564207654, 0.12557511007593525, 0.02027103887690652, 0.2845264033925149, 0.1644161815244344, 0.3045543012840133, 0.17537151463329795, 4.718918242762166, 55.353542989300145, 59.06267742956839, 89.92600010287377, 80.98630659041866, 85.71013466004403, 78.51097722207346, 83.8926887512207, 77.44919161642753, 80.39181647762176, 77.04072383142288, 81.47396702920237, 79.03067558042466, 80.42795719638949, 73.05997310146209, 68.26656218497985, 69.79988728800129, 76.80070615583851, 77.11240906869212, 78.00384613775438, 77.32340904974168, 72.45842272235502, 64.76528982962331, 59.34826127944454, 59.217395321015395, 58.203686206571525, 58.08737224148166, 54.846278544395204, 60.69587392191733, 65.54090322986727, 67.57922172546387, 70.35927218775596, 67.20465890822872, 71.45815557049167, 67.60430136034566, 69.60398843211513, 66.88649192933114, 68.26021579004103, 63.369894873711374, 68.46285327788323, 64.54422896908176, 64.18583023932673, 66.93484690881544, 66.0714469417449, 64.68552843216928, 67.32058063630136, 66.17529561442714, 61.92949464244228, 67.34875894361927, 62.74173121298514, 68.90973675635554, 67.13780603101178, 66.4324854266259, 61.185538691859094, 52.3634692161314, 56.387432698280584, 63.216212487989864, 69.3846808710406, 62.03562613456481, 58.160434230681396, 57.598707675933845, 58.42879495313091, 59.19525354139267, 62.08107071538126, 60.60709499543714, 61.82927023979926, 57.87376780663767, 60.44548549959737, 59.29248125322404, 60.22780964451452, 60.93953155702161, 58.05888014454996, 60.173559342661214, 51.0860905339641, 50.71308489768736, 66.81956844945108, 56.68628984881986, 58.01103115081788, 63.37287587504234, 60.307245485244266, 60.19546970244377, 61.25291324430897, 54.68200183683827, 58.06091585466939, 60.1445024244247, 59.53087506755706, 63.52887245916552, 60.06379573575912, 58.7489741079269, 60.760047820306596, 57.33575982432212, 57.54508887567828, 54.26544220216813, 55.53634505118094, 55.89890933805897, 62.247912653030895, 59.69108427724531, 60.27789046687465, 57.24299969211702, 54.57572521701936, 53.5343437810098, 55.620534804559526, 55.60031106395107, 56.03919682964202, 52.03388029529203, 51.68796254742531, 52.33803264556393, 51.89238079132573, 50.455883318378085, 52.075822199544604, 52.61506572846444, 59.08599199787263, 60.62021140129336, 65.55782041242047, 69.24208702579622, 69.80254665497812, 70.73065788515153, 69.63811305261427, 66.11546377981863, 63.67767933876284, 63.97800345574657, 70.11850926183885, 62.258844298701135, 30.034147347173384, 8.851807905781655, 13.276481705327189, 21.155307446756673, 8.950255474736615, 1.286865669873453, 0.08479323914094318, 0.1339763673322816, 0.12043125867362946, 0.15065761012656076, 0.06773676648135148, 0.3297715868440367, 0.1543108076458016, 12.877289345187526, 77.53019640522619, 49.50063713135258, 33.78669654169391, 58.145140909379535, 29.736410033318307, 57.74687520919308, 11.198537465064756, 0.6561155124537407, 0.15674952597868058, 1.5005713508975123, 20.717227728136127, 43.77265876339328, 33.96509770424136, 43.96490589264901, 40.00517906681184, 29.560113222368305, 25.756388864209576, 8.891658206139843, 1.7763463335652507, 1.2871006443615884, 1.4433222744734058, 0.6061292559869829, 0.40056699766747417, 35.609982859703806, 78.84135846168765, 33.91842542156097, 20.800413354750603, 38.27594334079374, 44.31362029044859, 56.34225483863585, 3.6219786395949707, 0.18521594364316235, 0.09750908060419945, 0.03895220399323491, 0.5357436715595184, 0.8043421877007332, 0.20669766191032626, 0.07194965251631315, 0.008818743573952346, 3.678990044901448, 65.96273453004899, 70.9088433173395, 91.44842886155652, 86.41985616376324, 89.33853887742566, 85.04532429479784, 88.29808312077677, 80.82548156861337, 83.46857855396887, 80.41119298627301, 85.0155064367479, 79.32683806265555, 82.9932108233052, 75.84227500423309, 70.89448744250883, 72.28858409389373, 79.74482936243858, 78.81158767207977, 81.7698000323388, 77.9275481931625, 74.4712418894614, 64.41231181544643, 61.72042054514732, 60.4823047884049, 62.01066809315836, 60.803652809512236, 59.976224899292, 65.74233655006655, 67.80410689692344, 69.4122943570537, 71.00337243849232, 69.7988360927951, 71.57636011800459, 69.97534275054932, 72.48692266402706, 69.65405356499457, 70.2853355100078, 66.20373279817643, 69.833023471217, 66.90709221747615, 65.47434453041323, 68.1350451131021, 66.89227350296514, 68.31526233303931, 70.17995711295836, 69.07499405645555, 64.88621650203582, 68.80959864585631, 63.80719992422289, 69.9335773529545, 66.19181663759294, 69.0842822290236, 63.108868983484086, 53.85031031024072, 59.769590516244214, 66.16792940324353, 72.63339181100169, 64.82892636329898, 61.64662899509553, 62.06393780246858, 61.1023412981341, 63.23339246934461, 64.4219647684405, 62.92077172187067, 64.36734184142082, 63.76420290239396, 64.65336499675628, 62.161714646124075, 63.55900802919942, 61.51793602974185, 61.71004979841171, 64.70981182590609, 54.91613203479398, 52.14145521963797, 68.25794081534109, 60.80240549579744, 60.66713863803495, 68.8289829992479, 61.29729486280873, 61.49256613946731, 63.427098720304436, 59.423704147338874, 60.108985362514375, 61.712622873244754, 61.23683152660247, 65.06038150479718, 60.666220803414625, 60.381931335695334, 60.985576260474424, 60.97429944622902, 61.89262436282251, 57.85546602741365, 57.39118291485695, 58.82365211363762, 64.19589504118889, 64.36518846019622, 61.67724701666064, 59.20922502394646, 57.4062644281695, 56.52936366296584, 58.1462509401383, 58.573820667882124, 59.265730688648844, 55.17972707748414, 56.30489426274454, 53.900512726076194, 54.89508067407916, 53.16727269080378, 53.30292394084316, 55.05488587963966, 61.801405722095126, 62.30494783770654, 69.30255428437265, 68.96665034755584, 72.67515720859652, 73.01740754035212, 70.55608887826243, 69.45617783454158, 64.82886360537621, 66.70891838689005, 70.39759374433949, 73.80854175936791, 50.51040818614345, 17.48874641233875, 15.07458640683082, 24.6231984707617, 9.584953804169933, 1.026669238363543, 0.03154260733525359, 0.44745326402687263, 0.1728653192760483, 0.2566032493186574, 0.06989422329371014, 0.6468346943297695, 0.1809413875302961, 16.427015719875214, 89.02137602529218, 58.62243060142764, 44.9453729198825, 75.16011991808492, 42.15293561258624, 71.1431892456547, 14.11639157802828, 0.3711512132037071, 0.07988210992827531, 1.8982360704291252, 19.62773253840785, 41.13370380093975, 40.09888449022847, 45.81963785233037, 40.81474058089718, 45.86409791823357, 39.16392872410436, 22.484245684839067, 8.931653634194406, 7.67876083812406, 4.811988732507152, 4.252924976810332, 0.6269802081008112, 44.27112533200172, 94.67748088221397, 42.741651996489495, 25.032187930999267, 50.859867834275775, 56.17569531163862, 69.03902592197542, 5.067898871437197, 0.23841201658210448, 0.44749619559414927, 0.35810433748749, 1.360502408877496, 1.4072830470338946, 0.3965124620064613, 0.7718332159903742, 0.3177107275734025, 5.307641000516954, 73.5202475517027, 75.27343719236313, 95.93289821378647, 91.60353506765058, 93.57984481319305, 89.03605353447699, 94.85599579349642, 86.97204743662189, 87.654633983489, 86.32846493874827, 89.45434293439313, 85.96046816918158, 88.31876970106556, 79.71390539600004, 75.17710378093105, 74.2946332500827, 83.14192356601839, 80.5194268688079, 83.95041819541686, 82.29485634834536, 79.91271465055405, 67.03297676578646, 67.19530013299757, 64.21592266328874, 65.60450446221137, 65.03091273769256, 61.854000783735714, 68.2422827136132, 70.71639614720499, 72.00697360500213, 75.14981192927208, 71.69578060027092, 77.73435577269524, 73.77873174605831, 77.7569172459264, 72.20105248112833, 73.99090843815958, 72.12335032801475, 73.62796368137484, 69.66488715141051, 70.59404957679011, 71.91160509663244, 74.44153385777628, 71.47167205810547, 73.34700430593183, 72.50487142993559, 69.22966095709032, 74.12772070976996, 66.16298721682641, 70.63926666013657, 71.10249073274674, 71.66737479548301, 67.24657335589009, 57.048226556470325, 62.997489360071, 68.8846492767334, 76.17913599937194, 67.27799154097035, 62.06065085626418, 64.22514807793402, 61.621290483782374, 65.25032620276174, 67.639022181111, 64.58266035203012, 68.33976145713561, 65.99117171379828, 67.02347678522911, 66.32967225966915, 65.20616815936181, 64.99182631892543, 63.9540966095463, 66.19458583093459, 58.16188550764515, 56.02688450967112, 72.62923409861904, 60.51036934698782, 64.0499750260384, 69.2263347871842, 64.78253256890082, 62.703366510329715, 66.26183094516878, 60.698415617788996, 64.0650918406825, 63.68649290454004, 63.344003308203916, 68.15292327634751, 64.93435575116065, 63.3277411614695, 64.39026417270784, 63.092700973633804, 64.07782385426184, 60.28233843465006, 60.75026150672667, 61.62729563251619, 67.33355583683138, 68.70757779767438, 68.37313298256167, 64.59025013831355, 63.23984869064824, 58.43136410559378, 60.44061391584335, 61.44753340751895, 62.55606974324873, 58.737571777835974, 59.190315277345725, 58.338411777250236, 58.30462840295608, 56.56995234950897, 56.86403205317836, 58.75831327130718, 64.1364711330783, 66.32866813290504, 71.75627139306837, 75.0804958035869, 76.4303324299474, 76.59433457159227, 75.25914407545521, 72.49769349252024, 70.30510425567627, 71.6123753209268, 77.42800297275667, 82.99330496018933, 66.74374118927987, 34.22028710765223, 26.629198597323512, 28.61429641323705, 10.28819457177193, 1.4043389404973676, 0.17710973748997336, 0.9983753436996091, 0.9401840404156716, 0.7870883554700883, 0.18255896686065584, 0.9413488617827817, 0.382970693491159, 20.976288510907082, 100.82793774143343, 71.5363048738049, 54.93856799217963, 80.67164621045514, 54.63366646920481, 83.47017888099917, 17.970078106849424, 1.133174703967187, 0.38534801753778614, 5.424458499877684, 28.659270309632827, 61.25338000635947, 63.069437396141794, 70.75452943002024, 67.80074934805593], [30.20659435179926, 31.681729132129302, 13.779815935319471, 7.874254709289921, 8.389383996686629, 6.826684263444717, 2.3781239649941845, 1.491338459234084, 40.16485483415666, 56.94698625995267, 35.06673066846786, 23.204112399008967, 59.86125238480107, 51.94346966282014, 44.09287321952082, 5.52036976621997, 0.5455415071018281, 0.5839945243731622, 0.32021712211351244, 1.117610493975301, 0.3142785617420751, 0.3751541758256574, 0.15677926551190116, 0.15435055228731326, 5.032232759460326, 59.72844485313662, 67.83059074032691, 88.95668045167001, 81.49863873758625, 84.27278211039882, 76.95364721359746, 83.21155348131734, 76.7222430629115, 80.90767875794442, 75.03458053834977, 83.03347003075385, 78.3733412527269, 81.5886414435602, 71.8914362692064, 67.3978042602539, 68.59508422113234, 77.34894367956346, 76.64594511831962, 77.8234798677506, 74.06214652522918, 71.88587434830205, 63.26076276840703, 58.66090120807771, 57.88942590836556, 54.85178947448731, 56.1415667687693, 57.9793187879747, 65.25605286321333, 64.67794256825601, 68.4642182627032, 65.36386705213978, 69.58789102492794, 71.84407757174584, 69.87197260702811, 65.20273608546104, 67.23064068825015, 67.02873276126, 62.56689548492432, 61.2748275264617, 65.81259404459308, 61.790160286811094, 64.82066585171607, 66.08105674866708, 66.86680163106611, 64.94394594623198, 63.10021231251379, 65.0489164167835, 63.59665886048348, 63.94860136893488, 68.2036473674159, 66.61103956161007, 67.588329469004, 57.02311554262715, 58.54573649744834, 58.82755879432925, 63.75842917350031, 64.49820387747981, 59.939405610484464, 61.153728269761615, 60.20410283919304, 61.55586142693797, 65.70095554474862, 66.21236985729587, 65.29846545188659, 62.60609565242645, 65.90502077533354, 62.66504103137601, 60.662706359740234, 59.358400606339984, 56.53846356176562, 57.90664511342203, 62.49195075804188, 58.96490450828307, 50.515872047793486, 48.40018087817777, 68.56375232819589, 57.78883672529652, 62.69749864455193, 63.664664914531095, 59.116237394271366, 58.57542883965277, 61.624981434114524, 53.20852033553585, 61.04708686951668, 61.13189243501233, 60.74955155772548, 60.03296198383455, 58.45859319933, 58.595821242178644, 58.89054813692647, 57.32038021087647, 52.70195015015141, 51.467325302862356, 56.1310822732987, 59.26351062713131, 59.990223838437, 59.62244672159995, 57.51321961802822, 54.2716670036316, 56.61935852419946, 56.412049493482044, 56.24875730083835, 54.52624843966577, 52.049130470521995, 51.258415945114635, 47.38089807571904, 50.40886586712253, 48.12231233043056, 52.943819184457105, 54.10741383029569, 58.7234277109946, 62.55237094817623, 67.02657545766523, 67.29433213510822, 69.95566814176499, 68.7626870985954, 65.43778411803707, 65.87922726908039, 60.08407831192017, 66.40247929480769, 67.18321923286685, 48.46326043528896, 19.206624915522916, 7.963182195540398, 11.368365307008068, 18.365937432935162, 15.713930783733247, 4.3408370594824515, 0.3001822375001446, 0.7033007063211933, 0.02672601911810137, 0.15781674774423723, 0.14777434629298028, 0.3464560625293563, 0.33825101571217664, 20.01362512188573, 72.70812080752465, 56.585477090651, 35.35280481461556, 48.84303608248311, 23.262014427492698, 66.15692323254001, 23.695028405035696, 0.29071170536260454, 0.02763904653669846, 5.272380853852918, 37.247125256446104, 31.032737685788064, 26.646955167093587, 26.786379737238732, 34.92974973494007, 42.67954518718105, 35.05693651014759, 20.477137488703576, 9.730203094020967, 5.807908917627027, 6.123325334441278, 2.0176549592325768, 2.0313391281712443, 59.62568267699211, 64.24407351401545, 44.363528528521144, 25.6984652626899, 57.87602316948676, 53.35084745960852, 54.06515029168899, 5.7904950649507585, 0.49462601662643496, 0.40669116582120624, 0.09381864355095933, 1.4769287743876058, 1.0508272388289053, 0.3279635580557008, 0.08089999563150829, 0.11629308153304363, 5.00623970262466, 64.79897122229299, 73.06536243807885, 90.06900187461608, 83.01997707736108, 86.85425866034724, 81.74981163394067, 87.47964920536165, 78.81328213599421, 83.43486970470798, 77.46330430430751, 84.51448640515729, 79.79456501622354, 84.07253726836174, 74.62649714562201, 70.45785703966695, 71.11228881343719, 79.08742443207773, 77.07993184366535, 78.80142088859313, 75.57725614117038, 77.01608350200038, 66.992858763664, 61.95505280648509, 61.20622527214789, 58.812053665038086, 59.01742504489038, 62.163907251050404, 67.69268020506829, 68.92940352039953, 70.93586060308641, 69.14357277654833, 70.92615665928011, 72.98796622983872, 70.31373347005537, 68.6861224328318, 69.42135503215175, 68.19994464997323, 68.45621662755167, 65.85672855377197, 67.56750952812934, 64.89136657407208, 66.32167846925798, 70.07746558035575, 70.44755689559445, 68.96308883543938, 64.11039913854292, 66.68811413549608, 66.62947470141997, 63.72967035539689, 69.20472252753474, 70.09750104719593, 70.41304003807807, 60.54205817560996, 60.529334006770966, 61.5099226274798, 65.43694080845003, 65.60287275621968, 62.97110749829201, 63.203892323278616, 64.24948638485324, 65.6771271459518, 69.07603740692139, 68.36084027444163, 69.63334345048474, 65.7161194278348, 66.36099630786528, 63.813844419294796, 64.54270708945491, 63.185602311165106, 59.1850475342043, 62.069954718312914, 64.95515215781428, 62.30292389469763, 53.0600860811049, 51.03755120308169, 68.47219636363369, 62.17609013280561, 62.09508142163677, 63.78864319093766, 60.73841594880628, 61.35733458303637, 63.943384616605705, 57.29153510062926, 62.642252060674856, 62.65718060155069, 63.1425033077117, 61.609860697100245, 60.45045906497587, 61.967031724991344, 60.11551218648111, 61.680192716660045, 57.5379462395945, 57.11250635885424, 58.82953566889609, 61.33829147584977, 62.14453074239916, 62.98222741773052, 58.512565012901064, 56.97077543504777, 56.967790511346635, 57.5465597644929, 57.92813185722598, 56.64270054909491, 55.113572382157855, 53.83087104366672, 51.075056906669374, 53.10041589121665, 50.98596026820522, 54.423733372842115, 55.08055779241747, 61.01144429176085, 65.11372573914068, 67.3029613494873, 69.30468020900604, 70.73488620019728, 68.92035853478217, 66.24316046314856, 66.30642829402801, 62.33034126220211, 66.86793127367574, 69.38770109607329, 67.55555414384412, 35.75731100574617, 12.52492714312769, 13.195370031941323, 21.540494003603538, 16.37986392744126, 4.327105822101716, 0.229550386448541, 0.8940866914006972, 0.38478273658021805, 0.3209889710189835, 0.35225632870870255, 0.48943313559697527, 0.29834491350958425, 21.790854969332297, 86.15745744397564, 66.13432253560713, 45.64783411641275, 59.297286156685125, 35.25644786896245, 73.31132642684445, 31.612607163767663, 0.7950553021604015, 0.09378207051345418, 5.225479602813721, 36.03760357825987, 55.55142264212332, 46.764195580636304, 45.04552279749225, 51.966996039113695, 57.01951872917914, 52.976570975395944, 37.66081763852028, 27.153217446419504, 10.127403870705637, 9.660241738442453, 5.049800565165858, 1.708775172310491, 76.13311090776998, 76.22978164303687, 62.71533366172545, 37.040871343305035, 85.49746374930106, 75.59189442665347, 67.27647750608384, 7.83912988439683, 0.5498472276714541, 0.9518644910666251, 0.4074030760074816, 2.6878799113535115, 1.874152594997037, 1.0439318346400415, 0.21315844909798717, 0.21366536947748355, 6.280167679632864, 72.01972130806216, 83.62202167510986, 97.74450763579338, 92.12569667446999, 92.39001735564202, 88.49981061873898, 90.56957475600704, 84.47058723818871, 90.13253642666726, 81.9768854879564, 90.79444423798593, 87.57848508896367, 89.49086020069738, 77.39314094666513, 75.03723206058626, 72.7552676969959, 82.76533680577433, 79.91322455867645, 81.04154140718522, 79.11115477162024, 79.49206398379418, 71.10305555405156, 65.31673585214924, 64.38726355952602, 62.39422098282845, 63.09803931943832, 64.88345515343451, 70.25992639603155, 71.67748666578724, 74.56478257333079, 72.34193617297758, 73.90420836787071, 78.5764729592108, 74.0156429044662, 73.65700491013067, 73.20206488332441, 73.30377194189256, 70.00136375427246, 69.57581012479721, 71.67409773795836, 71.1004981686992, 69.18100787747291, 74.57771070541875, 72.16782216102847, 72.77756244905534, 67.92988161886892, 70.00024980114353, 70.03997556624874, 66.93025773571384, 71.68047551185855, 73.19252567906534, 74.44587199918686, 62.94514925249162, 63.185170850446156, 62.8467526743489, 67.68092093929168, 71.78249636004048, 65.70184200040757, 67.58714491321196, 65.12197448361304, 68.4128430581862, 70.7493205224314, 71.67519600160661, 72.11126158314367, 68.04016297863376, 70.97458224142753, 66.80292975518012, 67.61194213744133, 65.8842400581606, 61.24599810569518, 62.41995957589919, 67.64540779975154, 64.47870969772339, 53.600588690850046, 53.536995303246286, 73.32126571286109, 63.18873628493279, 66.99356479029503, 66.55777377467003, 62.37755483196628, 64.56965769490888, 68.01320060606926, 59.07914746192194, 65.5338272740764, 65.50416631083336, 67.53846045463317, 65.8511587881273, 63.17510604858399, 65.33495133922946, 63.494441893792924, 66.58237488039079, 61.06528274474606, 60.21175538339923, 60.602254790644494, 63.323999220325106, 67.4448883918024, 68.21792479484313, 62.8591355969829, 60.020896773184504, 61.95751213258313, 61.82479089306247, 61.38254365613384, 59.3657942741148, 59.72415378016811, 56.926178086188536, 54.74188073988884, 57.63211058032129, 55.07450165287141, 58.091726072372936, 59.35260726559547, 63.497720995256984, 69.45456181803058, 71.93501380182082, 74.13569881070045, 75.78503193393831, 73.33440565293836, 70.22736287886097, 71.39157725918677, 66.75147610325968, 75.14066496203023, 77.6012775974889, 79.0913938706921, 53.66529603158274, 25.090176251626787, 26.633781886869862, 29.238808347332863, 18.022894782404748, 5.905919142307774, 0.42186880784650005, 1.634424194212883, 0.9172719440633251, 0.5231798296013187, 0.2942531766189683, 0.5005780295018227, 0.41827665221306587, 27.22795036531264, 97.3211269993936, 75.42928864878994, 57.09233360905802, 66.40425220612558, 42.558983295194565, 86.86910090907928, 38.72852210075625, 0.7465472276653013, 0.1543869261419581, 13.222558921383275, 46.71966491207, 72.98960578057074, 62.69140328130415, 41.89765991703157, 67.23628105655794], [34.46450956406132, 48.81336727449971, 28.953285294194377, 14.33594330664604, 10.425675607496693, 10.225249355839146, 2.3044111074939853, 9.938260316848755, 55.56674342001639, 42.783260499277425, 18.73480300749502, 26.92607887329594, 99.04001159052696, 49.22937385497555, 47.767847737958355, 8.588055968284607, 0.5008119314668641, 0.7771295188896118, 0.11262352037574015, 1.0042970807802294, 0.6381676658507317, 0.7848863123405365, 0.23449329298830804, 0.2927121141504857, 7.028700055614595, 73.68031947843491, 84.1754916406447, 85.13595457999938, 81.00728342610022, 85.18288181674096, 80.79457329165551, 82.10261314145981, 80.05726183614424, 80.18260509737077, 75.88454246520996, 79.650237483363, 78.60478462711458, 76.83584274784212, 72.63828692897674, 61.554398382863695, 68.89269013558665, 75.52040530789283, 79.22945345601728, 75.55368269643476, 76.05960569074078, 72.25732280362037, 68.59600990049302, 53.48892273441438, 55.15283922995291, 53.04617343410369, 53.400826300344164, 63.79755873833934, 68.82012628739881, 66.8960468230709, 69.60731460202125, 70.83715023532991, 69.78917921743086, 67.30668760115101, 66.64612908517161, 63.40538055666032, 64.29926518471011, 64.87037797128, 65.93767842938824, 62.81903328434114, 62.8821167638225, 60.29996948857462, 61.13749750198857, 64.8480204612978, 64.60598668744488, 63.70544971958284, 65.48699025184878, 66.04275088156423, 63.84369757867629, 63.395602087820734, 67.88778674217963, 67.54344186475201, 58.7797607914094, 61.305967223259714, 55.75014952690371, 59.86523359052597, 67.41190125865322, 62.00328619249406, 64.23161606634817, 59.5675374615577, 62.91647280416181, 63.79176539759483, 63.77922165778376, 63.25743267613073, 64.54654316748342, 60.066925787156634, 63.3788457224446, 59.896561561092255, 62.40475646911129, 61.79951513967207, 59.797043185080256, 61.934048514212336, 62.43852415392476, 62.35512279695081, 56.41845472397343, 49.53907635904128, 50.914730025875954, 64.196899167953, 58.32233398191391, 57.53132527874362, 61.24963414284491, 57.341910100752315, 62.404976121840946, 59.19192344911637, 55.737794060860914, 61.506384649584376, 61.49980291243523, 58.814442388473026, 59.774881793606674, 57.9502304907768, 57.33638348117952, 56.49676092209355, 59.38041294774702, 57.1179662981341, 58.09083177197365, 58.52146879319222, 58.12384636171403, 58.20184269259053, 53.53062929645662, 53.3171856787897, 54.13838878754647, 58.382969902407744, 54.974783235980624, 51.101815315984915, 50.61579442793324, 50.12688667543473, 50.16199581084713, 53.857421567363126, 53.85497008600543, 57.601202303363436, 58.697120374248875, 62.305853905216345, 65.01194023316907, 68.4908982246153, 68.638120466663, 72.15163846169749, 68.7289390256328, 64.15326279978599, 63.96533027771981, 58.848657223486136, 61.45499767795686, 56.40298097364364, 39.999448483990086, 15.01637843347365, 9.318596432285926, 8.922779271679541, 19.935289505989324, 22.059490257693877, 7.607406550838102, 0.7155100027880361, 0.2222470251182395, 0.08701981240583044, 0.029301367317055984, 0.09233826290695898, 0.4414508732095842, 0.35853230484551, 18.486809192165254, 74.71108698075818, 60.28982623930901, 41.98052783166209, 41.8896504371397, 31.982053249113022, 59.20749133633029, 29.44560354755771, 0.4620600786180266, 0.08190046815622239, 17.29577168341606, 35.28816023180562, 15.166652279515421, 10.229092298015471, 8.868271073987408, 21.19975966791953, 54.1940668321425, 48.991250684184415, 33.1747087355583, 25.035406235725652, 10.013180528917621, 12.232272240423388, 1.2154237421289569, 17.177276880510394, 70.19510530656385, 52.060505344021706, 37.45239465467392, 32.472916303142426, 107.72191909051712, 58.88139724731446, 57.692464090162716, 9.619842306260141, 0.5031099807350866, 0.6485069723379228, 0.19538534715050654, 1.6307703838233025, 1.0238068274432615, 0.8153768568750351, 0.19057333439348206, 0.13454688833125178, 7.477046087864907, 75.87641531421293, 83.81353532114338, 91.10185607787102, 83.15830338385798, 89.17432492779147, 81.26613632325204, 86.60270921645626, 83.60406506446101, 84.11753469897856, 78.4007978439331, 81.84754925389444, 81.29579728649509, 78.3841513049218, 75.39370490658668, 65.83379837774461, 71.87090658372449, 77.10903583034393, 81.24059384868991, 78.98958483049947, 76.12165758686682, 74.83614783133231, 71.16469167893933, 55.78801608854725, 57.42473094694076, 56.01297970741026, 57.58294367021131, 66.61275755974555, 72.42870684592955, 71.1591846712174, 73.56521360335812, 72.65363124109084, 70.72589612776234, 68.74680934413787, 69.97268338357249, 67.63166381466773, 66.78177249047064, 67.11643695831299, 67.05243956658148, 65.5642609442434, 67.62089298617455, 63.28397143271662, 65.20906679091915, 69.36486505693006, 68.29977681559902, 67.07500103981265, 68.98743106472877, 69.36408842763593, 67.75059007829236, 64.25293807060488, 70.53066407480549, 68.79236375131916, 62.59832151474492, 63.91818338824857, 61.25481951621271, 63.65006977511991, 67.98786993949645, 64.97322643956831, 68.14930685104864, 63.67420804116034, 68.6832747920867, 68.00593637651014, 65.68497580866661, 64.96469920681369, 64.87755983106553, 63.41561009806972, 65.10833248015373, 63.12755907735517, 65.86003903419741, 63.467322626421534, 62.65397210274974, 65.86044696069533, 65.56385301774549, 65.59381208112164, 58.91287034557712, 55.07310921146024, 53.58043947527486, 64.54095771235805, 62.26161741441297, 58.48787761503651, 60.87824452307917, 59.24696606974448, 65.01386611692368, 63.82367780131679, 58.7214312245769, 62.351957444221746, 62.83691144758656, 60.19193956928869, 62.38283041984805, 59.337788551084465, 59.94783870635494, 58.31644258191509, 60.614963270002804, 60.48168897628785, 61.83546366230134, 61.165585594792525, 61.41171432310536, 60.11157804919828, 56.00513496706563, 57.2987836407077, 57.60241039337651, 61.051840782165534, 57.755684852600105, 56.15013714759581, 51.64445953984415, 54.34973785954138, 54.203088283538825, 56.57142323832358, 57.60209268139255, 61.1356932117093, 63.33154978290681, 65.12779528094877, 66.1711222125638, 70.79428657408684, 70.73459594480454, 70.45980253527242, 69.2432794263286, 66.56111563405683, 63.83549590264598, 64.07591758235809, 65.54139744850897, 65.39060584960446, 61.47188348154868, 29.448327633642382, 15.66966683633866, 12.21387436313014, 25.25015208028978, 25.187358856201175, 7.718355694124776, 0.34948309042280723, 0.3277251821371817, 0.19685312564815247, 0.13524899259209633, 0.27997210261321837, 0.7601900278560577, 0.48140661790966993, 23.77627245841488, 84.57912706559705, 72.79305581123599, 49.14165789081205, 53.52356510777628, 38.646583787856564, 68.8254685555735, 40.814387567581676, 0.6233884814766146, 0.12049734907885715, 9.793367962683401, 56.687568541496034, 55.91169626482072, 40.50649327616538, 19.351762417824037, 43.02261921667284, 69.24205564683484, 75.74536892675584, 55.86732249106131, 55.47306153082079, 16.138264556084913, 19.175614656940585, 4.396925482057757, 19.47644672086162, 91.22691692844515, 68.92643036380892, 48.71472358703614, 44.06037246027301, 120.45777659262382, 65.73867305632561, 71.57770156860352, 11.045317919023576, 0.4551648889337817, 1.2098853554456466, 0.18691973850852062, 3.113970905542374, 2.57898731577781, 1.7635127060836362, 0.6863039119109031, 0.4479892191386992, 9.006309086276639, 87.36212715025871, 93.31728919859856, 97.10357666015626, 90.04711504905455, 94.71541804652061, 87.87779331207277, 90.1172705619566, 88.64851551671183, 88.67441100458946, 84.83530490629136, 89.55288856260239, 85.46594358259632, 82.8499972435736, 79.75297220291631, 69.31567069022887, 75.82061567614156, 81.91269982245662, 86.27726231851886, 81.76942348480225, 79.4427284117668, 77.1823606183452, 75.13474218307003, 60.562685920346176, 62.29379261693647, 59.20440443100468, 58.859533955973966, 70.33508685327345, 76.49303543952205, 73.15545143619661, 73.85152309171616, 76.82597406448858, 76.5731773068828, 71.43251895904541, 72.59352484057027, 70.77520032082835, 70.18271061681932, 68.91900923944289, 70.70223639088293, 70.14487543413716, 69.73666652556389, 67.72473381411645, 67.90165624310895, 73.63414533676641, 71.71762035739037, 72.27087067019555, 72.51645811142461, 74.24314037446054, 69.53566858845373, 67.07645231677641, 71.32501463736259, 72.71588710046584, 66.0170279779742, 67.5858191520937, 63.826097903713105, 63.60617845289169, 71.31826031592585, 70.00781213083576, 70.06634173854705, 65.8450791143602, 69.288449441233, 72.32883545660204, 70.14984115477532, 67.21899124883836, 68.80350328260853, 63.917626411684104, 69.49789616369432, 65.28166986280873, 69.3352746963501, 68.57238154257499, 65.31358618890086, 68.54051620729508, 69.69540319135113, 67.9817118183259, 60.886002971280014, 55.502083147725756, 54.458014888148156, 69.00896487697479, 63.712992437424205, 62.26837173584969, 61.48245426916308, 62.74869734241117, 69.60178406007829, 66.97903633117676, 59.97995507332587, 67.2391757657451, 63.766662228492, 64.38756165965911, 64.25327147206953, 63.32834128410586, 62.05561453296293, 62.10458140219412, 63.387949543614546, 64.18768552041823, 65.70127325673258, 66.0570518432125, 66.50295472914173, 67.06742302063974, 60.18009008899812, 61.36530876159669, 60.75952222270351, 63.20223316069573, 60.807296691402314, 58.70193704482048, 56.909402108961544, 58.93130156301684, 57.087450258193485, 59.15340185165406, 60.216536752639286, 64.46702887935024, 67.21582981847948, 67.29013519902384, 72.0231023911507, 73.72357537669521, 73.99296376012987, 73.02705657097601, 75.92619019169962, 68.12694149632608, 69.39868373255577, 70.62931168463923, 74.72319925985029, 74.6599941868936, 76.35706255512854, 48.57296128426829, 28.829173657201952, 23.326394250316007, 34.09462613444175, 27.18855800167207, 7.505179287925844, 1.0772996828440697, 0.7687635936083332, 0.4848829104054359, 0.4745013158648245, 0.2422142028808594, 0.8330174102898568, 0.6769226443383002, 30.36260270303296, 94.95814215752387, 82.95283394475138, 60.29438795581941, 63.04332617790469, 47.40777807850992, 86.22565177179153, 50.096970758130475, 0.469473205026119, 0.12835366501202508, 20.076920409356397, 65.52380954065632, 71.6376510743172, 45.950492043649, 11.527336028314407, 42.63087641808295], [27.32520357255013, 43.882579265102265, 40.395341150222286, 23.715540439851825, 11.073710976108428, 7.756232061693746, 0.42801464096673075, 19.146363581380538, 49.96898774177798, 38.166195423372336, 19.769224197633807, 22.792581242899743, 53.692121121191214, 34.67858076095581, 52.314055196700565, 11.864624561802035, 0.5762043907757729, 0.26797372547368853, 0.09955829685373653, 0.4426089530029605, 0.5561123560032537, 0.5661307022936883, 0.11655793345022587, 0.44193424404628817, 17.47093689057135, 87.71278704366377, 86.11996742986864, 84.49077175509545, 80.59047668210923, 81.97166089088687, 83.34046609940069, 83.1243670371271, 77.44137825504427, 80.38643498574534, 76.4494735963883, 74.60952112751623, 74.3020700639294, 76.05548720205985, 65.05339968589045, 60.779302735482496, 66.5463989011703, 75.08053502728863, 76.55329089010917, 74.7410068204326, 75.28418448663528, 72.5054205617597, 69.28199321992936, 61.45410337755757, 56.224709249311886, 53.252725447377856, 55.40489465959611, 69.67455187151509, 69.69195935033983, 69.04284631052326, 69.37709500712734, 64.25377353545159, 67.55507561468309, 66.4069272625831, 65.64386544689056, 63.52890776049707, 61.116093127958244, 64.41863859853437, 67.74916233554964, 61.396777937489176, 68.82707672734415, 62.41571949374292, 63.16744958200763, 65.89400675988966, 61.3005151287202, 61.4974259561108, 63.34265401286464, 65.26339161780574, 64.28704700162335, 66.33051164688604, 65.64518336326846, 59.795438935679776, 61.076300682560095, 59.14268593634329, 57.78506340519075, 65.32116420807378, 63.376774710993615, 63.08294211664508, 64.05301094055176, 62.05834450260286, 63.92012888385404, 63.0193095053396, 61.43991224227413, 62.13421883121614, 61.044050955003314, 60.772438587680945, 60.88021355290567, 62.43409972037039, 59.74815476325251, 61.582153074203006, 62.38712541518673, 59.534448346784046, 60.61714410781861, 60.40072733356107, 58.99537740215179, 54.352561966065444, 56.76056385040284, 54.779296228962565, 60.8151767330785, 57.439392766644886, 60.76009096637849, 57.16899241170576, 60.29354072386219, 59.77789809626918, 56.83042910791213, 59.44865826637515, 58.493019842332416, 57.356462094091604, 56.67971987878123, 57.401188881166526, 57.83552861982777, 59.39961294974051, 56.047500487296816, 58.12158707649478, 57.2970264188705, 58.96177445688556, 54.65103472432783, 54.58810029491302, 53.65631380388814, 54.17547871989589, 54.0747404867603, 55.931029627400065, 52.352851360074936, 51.92799983486053, 50.006473833514804, 52.668406040437766, 56.072136894349136, 61.64953547139322, 59.58316810669438, 63.77209863355083, 63.45342566890102, 66.02083267704134, 66.62810187185964, 67.66032849588703, 70.26635908311414, 68.31883168989613, 65.08819895405924, 62.61671743085308, 59.92412013392295, 51.262534433795565, 48.648451220604684, 44.14216956784649, 36.39541787485923, 18.40439627247472, 11.055145417490314, 11.260481496011058, 21.7409957608869, 23.349149880870698, 12.745400628735943, 2.7003422619835025, 0.7485730705722686, 0.017863151752540184, 0.07865851429561455, 0.5589730508865849, 1.4112920770722053, 0.1009753603307951, 23.598834237744732, 73.72618767522997, 65.0098809888286, 43.46869076451948, 43.25146990437662, 41.698878119068766, 46.37185658178022, 36.582024635807166, 0.640715183990617, 1.407331463790709, 15.868319196085777, 23.25591318068966, 9.03275860894111, 2.695935969391177, 1.7198221601786154, 17.338388235338275, 55.14626141517393, 66.72261530353178, 51.41090985267393, 42.96039473625922, 14.594064681760727, 12.14143995315798, 2.420442416783302, 29.26037746091043, 65.27659431580575, 51.25999666029408, 35.06759358990577, 32.253616586808235, 67.7386817624492, 40.14247378995342, 63.00445548949703, 13.243714224907661, 0.3313059077387856, 0.6852029516331611, 0.09282590851428048, 0.8561379438446415, 0.9154530674699815, 1.2564669333158003, 0.03141150670877147, 0.34974699239096335, 13.572290193650032, 86.84865751574117, 85.59309113410212, 85.77245327734178, 80.37685655778455, 85.34383235439178, 84.13770352640461, 86.17253503491803, 80.67052441258585, 82.61660052884011, 78.40395927429199, 77.32104778289795, 77.8165372725456, 80.617399830972, 67.54571683945196, 62.25862464597149, 69.23628976268154, 77.00645016085717, 78.10210935531124, 75.56364551667245, 76.84851984823905, 75.99258807397659, 75.02915982277163, 63.74215525965538, 58.43354102103942, 55.70203773437008, 59.767966654992875, 72.07612499114006, 73.95545805654218, 70.15650133932792, 70.0062196485458, 67.92605338558074, 70.67459152590844, 68.07142426890712, 67.64913405141523, 64.87614777780348, 63.753977283354736, 65.96191083231281, 68.0614536039291, 64.6928789538722, 69.04717660719349, 66.84770753306728, 67.15435843313894, 67.83637231396091, 66.20359159285023, 65.09915413395052, 67.59470724290418, 67.02867784807759, 66.88504065236738, 67.60298344396776, 66.07310218195762, 61.563561039586226, 68.19028777460899, 62.74074669807189, 58.86968112760975, 68.55279322593444, 66.24887143411945, 64.83789682388306, 64.91382606567876, 62.62347567465998, 68.09143620152628, 67.09606416763799, 64.44920562928723, 65.55042674464565, 64.58941859583702, 63.57359140150009, 64.72409317570349, 63.17286245284542, 60.572813480131096, 64.53688236974901, 64.27788826727098, 61.76178586098456, 64.18122537674444, 60.07086776917981, 62.1050520866148, 56.44005129414221, 63.43249982403171, 58.66739665308307, 63.602585561813854, 61.15960790264992, 62.37296958123485, 59.75987872769756, 60.86186862760975, 62.541274562958755, 60.192614216958326, 60.24079661215506, 60.81132888793946, 60.52063811209894, 57.410300547076815, 60.61757949090774, 60.09352337929511, 63.37326811205957, 63.17423136003556, 61.23820827853296, 60.1534846521193, 60.53120105497299, 57.985100361608694, 57.0491640029415, 55.61055629484115, 58.23741859005344, 56.81261762495964, 56.4453661057257, 54.445996745940185, 55.28388953978016, 53.43187186025804, 56.29715934876473, 58.240183861024924, 63.92698126454508, 64.17714611176523, 65.25671574377245, 65.00996335860222, 66.59421259357084, 70.69474466385381, 68.62155237505513, 68.93564008897351, 68.52274002567415, 65.95845130182082, 62.13692134426486, 64.30291691134053, 58.62602349250548, 60.314274372593054, 59.84003628453901, 54.004271184244466, 29.769697227785667, 18.454712437045192, 15.205364111931095, 25.642689158839566, 28.5399478866208, 15.227923623977171, 2.1508020210650662, 1.063674226883919, 0.09276865110281976, 0.1437940905171056, 0.6352079311205495, 0.6326802086926276, 0.39608339148183025, 30.964129547919, 83.27464088316887, 78.57371945534983, 50.300569226664884, 53.20756327721381, 46.179982077690866, 62.32547752318844, 46.33182094943139, 0.47934323669441287, 0.5507099652482618, 19.32306439645829, 56.89657988086824, 48.44182468229725, 26.9884818215524, 7.594178357431966, 31.235810556719382, 62.43128345858667, 87.29096751059257, 73.16202532860541, 72.96623629908409, 20.802219606214955, 17.016726424617154, 3.1225067184817408, 39.743223574853715, 86.7374740108367, 67.0592252669796, 43.674152358885735, 38.11027811419579, 77.67079768642303, 48.270742662491344, 75.51492183439194, 14.963757876426945, 0.6972719620793097, 0.8313153467832074, 0.3745782922112173, 1.5111883489354965, 2.536482796553643, 2.3530274148910277, 0.4484126818997245, 0.6165704215245863, 17.429044015945927, 93.68876118813792, 90.67899319433397, 92.15481635062926, 85.4588911610265, 89.53293154316565, 88.41622491036692, 91.45134710496473, 84.87310871001213, 89.61449330852878, 83.05585891969743, 83.97052426492014, 82.86215659110778, 84.74181129086404, 72.31414225793654, 68.5511536752024, 74.20357150416221, 80.56665220568257, 79.62208271026611, 78.54318772592853, 80.50577702060824, 81.22319421460553, 76.4203146965273, 67.14432501023816, 62.5644479259368, 59.371677829373276, 62.68150321898922, 75.46476256462836, 77.56691763477941, 74.70398749074629, 75.44681379871984, 71.65105773556617, 74.28913408710112, 72.1020753922001, 70.7177689767653, 70.0374730940788, 65.84471041156401, 69.1374695685602, 72.90445112412976, 68.97378906126946, 71.39914743361935, 69.21379104737314, 69.86008782540598, 71.07612456044843, 68.94464585088915, 68.23729345875402, 69.55119332959576, 71.11697996816328, 72.12418187049128, 70.70495067104217, 71.11713686297017, 64.7327341571931, 67.91603565216064, 66.83480293520036, 62.84368930324432, 72.04418120845672, 69.3281202931558, 69.84805399371733, 69.97365613137522, 65.69016902677475, 68.87417654837333, 70.77284689872496, 67.55029816781321, 67.92518261940249, 66.76908754533338, 65.8884056152836, 67.40535874520579, 68.67245689515146, 64.60779490009432, 68.75218299127394, 68.76072591350925, 66.07966822962608, 67.02586158629387, 64.7244187324278, 62.774161369569846, 60.031800962263546, 63.176616161100334, 61.344669249749955, 64.46431067682082, 61.67264999881868, 65.52061673133605, 61.03477062717561, 65.06519817536878, 66.86727231548679, 62.25597704610517, 66.21692765143611, 62.19786320963214, 62.96935419882498, 61.259200803695194, 65.79216634073566, 63.25984101141653, 66.14783117848059, 64.86521220976307, 65.46518579606088, 63.00373377338533, 65.6338006450284, 60.99846909123083, 60.74203237410515, 58.55016877574306, 59.734720645412324, 57.20272087281751, 61.69503104302191, 58.068764517384196, 58.59977106894217, 56.62376726827314, 60.12926009393508, 61.13912528561008, 69.7635426059846, 67.37738440113684, 67.22931492713191, 68.76648395292221, 71.66276208816036, 74.04148347916143, 72.1677750925864, 75.04932080545734, 72.40550994873047, 71.71467857976114, 66.69147168436359, 68.2056869999055, 65.36086643895796, 72.4050941774922, 67.56939226581206, 72.06286737995764, 52.91512312427644, 37.717201709747314, 33.46469740713797, 34.152300665455485, 26.236514429892264, 14.232297616620219, 3.0864253255628773, 2.3113679212908593, 0.2567311247149783, 0.5838315621499093, 1.2674758006488125, 3.6717956825610134, 0.6668265860888266, 38.65261639318159, 94.25017003090151, 88.32325689254269, 60.366386982702444, 71.43211887728783, 55.22012356788882, 79.3119958139235, 56.69782161712647, 0.33790324243807024, 0.8046133828259284, 27.614166544329738, 64.4774192379367, 53.18879865830945, 28.029143502635343, 4.200050936591241, 30.70725352533402], [12.988485597795057, 39.67804162733017, 39.09264749096286, 19.990745936670614, 10.99380543155055, 5.694253338921455, 1.4414228667174618, 24.396010868010986, 53.64919862439556, 33.03155791374945, 18.226181422510457, 25.18033585240764, 45.927252000378026, 35.99960365603047, 57.16379527122744, 21.919112551596857, 0.6162010445710152, 0.4621689550338253, 0.05795532905106103, 0.08491649502708067, 0.4881366390374399, 0.26357411316806273, 0.7044193785517447, 0.7034851802933602, 24.45180658371218, 61.535068942654526, 77.13507252354776, 79.66369121305405, 76.76148245411535, 78.40895637389153, 81.07252813154652, 83.45525818486368, 77.20377675948605, 80.12337730776879, 76.78797414225917, 74.5941532811811, 71.88888672859439, 70.30945808656755, 59.06849038216376, 58.35585455740652, 62.71899323309622, 75.86971590595861, 75.55455346261301, 74.00187538516137, 75.85765854004892, 73.20203350436303, 71.4744883198892, 64.89239031268706, 54.981608160080455, 51.29823976947416, 53.22078558706468, 65.01948295101043, 68.38645335166686, 66.55025851341986, 62.01328431406329, 69.08207001224642, 68.51745267068186, 66.95474901506978, 61.04408233396469, 61.31982103470833, 63.89220553059732, 60.643522047227435, 66.84439705264184, 64.65283547678303, 60.667840742295795, 66.7437647235009, 62.39145963422714, 62.943674441306825, 63.07011988855178, 64.11458430751678, 65.79380589146768, 64.47460689852315, 63.8116478919983, 62.76170784427274, 59.45922905398954, 66.78028198980516, 65.35302954335367, 48.35258683850689, 58.98274737019693, 65.69639382823821, 63.38228564108572, 55.046240975779874, 62.825615021490286, 58.57459337480607, 63.040231427838734, 62.17120678194108, 63.53341848619523, 60.00150457505257, 60.14500056543658, 59.91211768119567, 58.91245065196868, 58.804157933881214, 62.10222798009073, 61.15931372488699, 63.29528354829358, 59.24569914417883, 57.35662291126867, 63.40170529580886, 61.924297501963956, 55.17061541157385, 57.920130222074455, 60.70049447398032, 55.727737103739095, 63.76868617150092, 57.72715353196668, 61.57616361494988, 59.328484689035726, 59.96290060781664, 59.2035375871966, 61.475099825089984, 57.52191551270024, 57.525629997253425, 53.37537011792583, 57.50772045504663, 58.80634661643737, 58.52526172514885, 56.466601817838615, 56.33434341799829, 54.735299002739694, 56.21209882920789, 53.177117839936294, 55.16515547229398, 54.464184776429214, 56.25000069218298, 53.967385215144006, 51.81380394966372, 49.87812211436611, 51.03368374609178, 51.55292318713281, 58.98423002612207, 58.5148831336729, 65.40637377769717, 61.04718100640082, 64.85592011482485, 63.32559562498524, 64.94431464902817, 67.27579501367384, 68.06937679167717, 69.83638102008452, 65.73537826538086, 65.57109763545375, 61.13738767562374, 56.43138285606139, 46.722900867462165, 45.303246052034446, 44.52115681863601, 42.15715216052148, 26.183099592885664, 15.825807567565674, 11.140992372266709, 18.621768143869218, 29.738771300162043, 26.20287618329448, 8.124068994675914, 0.40376847910304225, 0.011873580459054681, 0.08234376493360727, 1.0044450889672003, 0.839740781774444, 0.7562349916946504, 24.69836873392905, 67.44611217129615, 73.48548750723563, 44.851181122564505, 59.25477550875757, 58.105850527363444, 41.49534240845711, 36.86462748435236, 0.2674136845575225, 1.2147544877183054, 10.169630146795704, 10.913346832798375, 5.435936335594424, 2.010262394624372, 0.5666640833500893, 9.178416805882609, 43.36815257226267, 76.40227179373466, 64.44152170611967, 48.42148719295379, 15.524669558771196, 12.454079331890231, 1.656397679640401, 36.821708909926876, 65.53712598739132, 48.65320121088336, 31.154603765856837, 30.230579645402972, 56.93502303092711, 44.84941213361679, 65.61066650575208, 24.543921486023937, 0.46533204014262847, 0.5894710724392246, 0.10295143050532188, 0.017801548707328977, 0.6257322202286413, 0.2684399665844056, 0.3813464338740995, 0.45311931160188496, 26.798493977515932, 75.71922240718719, 77.38599438821116, 87.37519648767288, 76.68712216038858, 83.01656461531117, 81.22499066014444, 86.61859481565415, 78.66185511312177, 84.49296828239196, 80.12241240470641, 77.08339921889767, 74.72286978075581, 72.64169939102666, 63.94163131713868, 61.088389427431174, 66.66436810647288, 75.99605544920891, 78.87341991547616, 76.13613897754301, 76.53414972366826, 74.42541291636806, 73.20259832566785, 70.43531125591647, 58.86864954425443, 54.193662828014745, 56.50910069865566, 68.43123897429436, 69.98921225147863, 71.39927294946486, 67.43103458035377, 70.90419923105549, 68.60591780754828, 64.91304943638464, 63.1297948283534, 63.22123312181043, 62.37740185952956, 63.25369465735651, 66.39104950812556, 67.97753841646256, 63.2260968608241, 69.26839044017177, 65.52623748779297, 66.47790647322132, 64.87710483612554, 65.8107348411314, 67.43498048474713, 66.52535146282565, 67.83664687987297, 64.84694573187059, 62.55238663765692, 71.51078593346381, 65.4114846260317, 52.532754790398386, 63.09747057576334, 68.31021816499772, 65.50915164332237, 59.98337538011613, 64.80735332735124, 60.92901176021945, 64.90318859777143, 63.85402910171017, 65.34482002258301, 62.41118523382372, 62.13824318301294, 61.70992820493637, 62.1406005274865, 62.067667976502456, 64.91454385942029, 62.711729003537094, 61.80198623288063, 61.92357578585225, 59.593287821738954, 64.03901984614711, 65.16456357894405, 57.69407618430353, 60.56710643153037, 65.35930925799956, 58.63421732379545, 64.46211022715416, 58.75055482310634, 64.29474269190143, 61.245276389583466, 63.39223669421289, 61.11387306644071, 64.63469059236589, 60.13186847009967, 61.584384902831054, 59.45589503934307, 62.88945159604473, 61.41907661191879, 59.51663294146138, 62.5599842686807, 60.27982027299943, 56.44541317416776, 59.19964659598566, 57.08086459867416, 56.9202043164161, 56.665297323657626, 59.53396981762302, 58.44739483248804, 56.20295578433622, 51.84593208374516, 53.610931980994444, 56.077436016451934, 62.00346269915181, 59.297858822730284, 68.61726914682697, 61.701224465524, 65.04759457803542, 65.55507083092967, 66.42704902156707, 67.16756113113897, 68.45406716869724, 69.12167026150611, 66.51516898985832, 66.45336812542331, 62.29677361826744, 62.18928498606529, 57.247941878534135, 55.28186559677125, 56.44657811810894, 56.412390739687034, 40.854258460383264, 28.356622188322007, 18.431031127129835, 26.052976923604167, 36.081075206879646, 28.165196795617383, 8.232870640293244, 0.7328469402367069, 0.09764805661454316, 0.16026236086843476, 5.074624755690175, 1.0345942647226396, 0.5641718461148201, 31.820437869718, 79.34843463282432, 84.15507962626796, 53.02218029575964, 69.54927136821132, 65.69202430786626, 55.78955758002497, 48.12944319940383, 0.2786893037057692, 0.32378764342396493, 19.44974126354341, 45.31730382673202, 31.64588651349468, 10.16818573397975, 2.566164352240101, 14.490869083712179, 51.38517910434354, 90.93313140253868, 78.35365095446187, 69.18471059491559, 24.08521402266718, 14.214417492189716, 2.991246561850271, 51.36534367838214, 86.95802104088568, 64.49789008786603, 35.90951073554255, 38.43104562451763, 67.12737252635341, 54.29810770096318, 78.6420863674533, 29.40837633225226, 0.6417338357817742, 0.7550094961639374, 0.25614541985334893, 0.25219691076105644, 1.5552075159165168, 0.7204849164812797, 1.4808721047255302, 0.7754850039078344, 36.25572658354236, 88.77527083120039, 84.00508034613826, 91.18084476840113, 81.17919306601249, 85.93453345760223, 86.82193833012735, 93.82354951673939, 82.22990974303215, 91.4350300450479, 84.64999644987046, 81.3515341666437, 78.4487605864002, 76.26580469069943, 69.12287050677885, 63.72030765779557, 70.23207756780809, 82.24150426926153, 81.29146698982485, 78.60569461699455, 79.6899083352858, 80.88932206553798, 76.5696628632084, 74.13931523599933, 62.374209050209295, 57.08801115712812, 59.22745620050738, 73.52726074957079, 72.21109374876946, 74.52766910676034, 68.2166539469073, 74.75055386943203, 73.21422423085859, 71.3116236655943, 66.7561907922068, 69.34511200074228, 69.59983071973248, 67.25117821847239, 70.8197819802069, 70.77676142415693, 64.81539418620449, 71.18144019957512, 68.47770337135562, 69.80392732927876, 68.42810892289685, 72.47837974179176, 72.59631756813296, 70.92774129682972, 69.44878808913693, 68.37788689521052, 66.4737016923966, 73.51332064597838, 71.0451143018661, 54.248215152371316, 66.4634015483241, 73.80054796895674, 68.47707579212805, 61.65541510428152, 67.42446853268531, 63.42656920033117, 68.29532100308326, 68.0952173663724, 68.44473192768713, 66.44451141357422, 64.2918989735265, 63.88021092261038, 64.85372750989853, 67.38107927383916, 66.75252729846586, 67.01593014501756, 66.99602019402289, 64.71657791445332, 61.2867711436364, 70.40434806577622, 65.69471897617464, 60.78833595398934, 63.206747808764064, 64.51839623912689, 61.301362360677416, 67.29590892791748, 60.38159793423068, 68.73137089513963, 63.76632098228701, 68.00804661166283, 65.07906767629808, 65.69513474741291, 63.39966958568942, 63.35675885600429, 59.41529458568942, 66.09168637183406, 63.64060509589411, 65.02634709881198, 64.34796533276959, 64.9509983678018, 60.81216827515633, 64.25118869350803, 60.86490454212312, 62.27866011281168, 59.8225111346091, 62.314392905081476, 61.67737253250615, 59.43895824493901, 55.78794548588415, 58.032839528975956, 58.40841824008573, 68.41112506005072, 63.40448233389086, 73.23430676614085, 66.06328056704614, 69.40297480552428, 67.50126854065927, 70.80060159006428, 71.67435661438974, 71.5949913763231, 75.72596103914323, 69.71538374500891, 71.24836367945518, 66.4678652055802, 71.45969313959922, 63.30176722618842, 70.80794426702684, 64.9096683532961, 72.5850917446998, 61.84477144672025, 56.33996025208504, 42.24850416183472, 48.151722261982584, 37.3353942748039, 29.77475512412287, 9.01542075218693, 0.6611449716071929, 0.1404040441998551, 0.506798908595116, 5.550645070691263, 5.420266466756021, 1.0738565772771835, 40.734488887171594, 87.95708010273596, 94.28693832889681, 61.3742752998106, 85.8740661990258, 69.23279885322818, 72.2176911753993, 56.69126341419836, 0.2443496882915497, 1.0385081772842715, 28.359558082395985, 47.71335817152455, 33.69880407087265, 9.608953806661791, 2.9522871298174707, 14.366642717392216], [4.635066793810937, 30.854265920577514, 43.469141837089296, 6.195092941484144, 13.058846054538606, 8.273402452468872, 1.9665135034630377, 39.80740139561315, 50.81923207929058, 27.805733142360566, 27.56202255525897, 33.34943855962446, 66.92246790855162, 44.85308347209808, 48.04187628530687, 36.65243510277041, 0.3541037344163464, 0.2847263216972351, 0.07736484460051983, 0.1686115701112055, 0.11203009334783401, 0.1016880289441155, 0.3018041375663973, 0.09683121536527911, 18.28059450272591, 40.19220159899804, 62.34510114116054, 70.64635830540811, 72.81663710071196, 73.37754388009348, 78.73784711284023, 79.83878581754624, 78.98229706671931, 81.17606301461497, 75.71520590013074, 75.87295578372094, 68.57993602752686, 61.08914644487443, 58.69046018969629, 59.9963858819777, 59.172664611570305, 72.3523461434149, 76.38965745126048, 73.85638683072983, 72.97468508443525, 74.7099651828889, 71.7271517169091, 69.94521894762593, 60.34461390587592, 53.31956263511412, 51.89572657308271, 57.62366571734029, 67.60644297445974, 65.57538086368193, 67.22074847067556, 64.99204597165509, 67.70973467057752, 61.469039763173754, 60.77998915026265, 58.470344620366255, 57.49661230271863, 61.27576497293288, 61.097873718507834, 61.38470095972861, 61.30584955215455, 61.04548262011621, 65.17607181302964, 63.32912183577015, 62.213078083530554, 61.1041691226344, 62.04944464468188, 63.52389497141685, 60.26946129337434, 59.35828685760499, 64.60349598238545, 67.19192689464938, 56.21434242494645, 52.97361350828602, 62.93924216301211, 64.69019605267432, 64.25998264743437, 61.27381555495724, 61.01216208550238, 57.04161736272997, 53.305120468139656, 60.39476140852898, 62.70321353789299, 61.685542829575084, 60.953146103889715, 62.96126627152967, 62.345611049282944, 59.090655696007516, 54.80691363734584, 51.03391124356178, 56.53172492980958, 57.789864386281664, 60.78681799673266, 62.09887827596357, 60.71197525147469, 58.730797844548384, 53.936790727799945, 61.703228796682055, 56.99424297578874, 59.80893973381289, 60.79646310498638, 59.556790167285556, 61.26527655509211, 56.62596379556964, 60.266276328794426, 59.65805792039441, 56.87388112468105, 52.42362268509404, 56.51863990291473, 56.43357938335788, 57.02056600201515, 58.751370676102184, 56.43695262170608, 56.076557405533336, 52.94832991015527, 55.46194945612262, 55.650250680984996, 56.971873698696015, 58.774081199399895, 57.8895906479128, 55.390801583566976, 53.951856551631806, 44.57665835657428, 50.02589348823794, 56.80235278221869, 61.2631663199394, 59.42361001045474, 65.73067534354426, 64.30243053743916, 67.8705204686811, 64.9645854580787, 66.56146864737234, 66.68774543269988, 65.83162538466915, 68.30924541719499, 65.99799663789811, 62.93448432799309, 56.063954830169685, 53.15501920638546, 47.7202497759173, 48.701952349755075, 48.64986719623689, 49.17652776164394, 42.013883667607466, 29.694348496775476, 16.917321797340147, 14.104036111985485, 32.708829218341464, 36.53031602982552, 16.202374715958875, 3.9446141787113684, 0.5674527249028606, 0.18540165867776642, 1.2844793979198703, 0.15328385146154513, 0.645231731957005, 34.17630949328023, 68.3207614960209, 73.60995215754356, 51.43191806731686, 40.75733277105516, 42.34652027007073, 53.961827216609834, 33.29751814565351, 0.04870159979609232, 0.9277632423946935, 6.239298543622417, 5.120281634792205, 4.054392984797878, 1.5023503909187934, 0.44649191561245155, 5.435135681783, 34.41967687299175, 78.02268135932185, 69.85475340197164, 40.478401260991255, 16.72957362667207, 8.945278967580489, 3.6640144355835456, 50.39287044155983, 62.24790873066072, 43.85860573860907, 33.60060361123855, 30.049834866677564, 70.45833556882798, 49.79703103342364, 55.880686006238385, 42.037833659879624, 0.5115960592464094, 0.6438938972930754, 0.14889583772709294, 0.17800583053500424, 0.2450176863180053, 0.34264403966165363, 0.8282704230758452, 0.07537350629366214, 29.31082306369659, 52.266402321477095, 67.41909488554924, 75.23004008877662, 77.08722745218586, 73.45166098686957, 80.26841086726036, 82.43734821196526, 81.54386366567304, 79.97027935520296, 82.00056875905683, 77.44135472082323, 72.95440643064438, 64.4153202733686, 63.86004993992468, 63.83551551449684, 61.52620830843526, 74.00778247464088, 77.33817285107028, 76.21053065023115, 75.34616578009822, 75.4033931609123, 73.54285609337592, 73.23175722552885, 62.56440870223507, 57.08250414940619, 56.25659419644264, 62.19068919458697, 69.93739774150234, 69.79587078094482, 69.12804803540631, 68.23640700309508, 67.27266496227634, 61.86868221529069, 62.43077355046427, 59.66935434649068, 61.054268729302194, 64.59702014923096, 61.85471857747724, 62.83835880218014, 63.76046096124957, 64.1716391040433, 66.98216638257428, 66.98207224569013, 65.347118531504, 63.978293711139315, 65.8683858379241, 66.2422347837879, 62.0034077859694, 65.45425022802046, 68.3708344736407, 67.3853232783656, 58.294147829855646, 57.86455808147308, 66.32200010361211, 65.88978628958425, 67.7651342268913, 63.149108579081876, 63.28254761234407, 60.22376568086686, 54.44037598948325, 59.44908580472393, 62.61924735961422, 66.33683450760381, 64.24604254384195, 65.18662691116333, 62.01205268982918, 62.19769454771473, 55.6007033009683, 51.83441992728941, 59.36469601046655, 60.751791231093875, 65.03104609827842, 61.987604556545136, 62.99734423237463, 60.88802299191875, 56.885726682601444, 63.484326101118526, 59.53517398526592, 61.93344054683563, 64.10410765678652, 62.62193810555243, 61.61977644889586, 59.13960687575802, 62.534182917687204, 60.71750187104749, 58.28243171015094, 57.746341766849646, 58.91306646408574, 60.11515525079543, 60.38102526818553, 60.43859781757478, 59.468093610578975, 58.54971378080307, 56.08386085879419, 58.11584080419233, 57.898843519149295, 61.317267571726155, 61.02103840920233, 61.50414497621598, 56.856540326149236, 58.16679631510089, 48.556138238599225, 53.75891516285559, 57.55346705836635, 64.36372541612195, 62.809537226153964, 65.88765252021052, 64.95060613078456, 67.76420854753064, 68.37052068402691, 67.11293035937895, 66.07502414334205, 67.73521438721689, 69.53235810802829, 67.27706586160969, 63.94271781367641, 59.90865815070368, 60.04598817517681, 54.7537459096601, 58.04344169555172, 58.99097258044828, 62.238091038119414, 53.170932262174546, 42.44535223130257, 29.34578314904244, 27.671305671814952, 36.94054495903754, 36.30671739578247, 16.128473339542268, 4.993042888179903, 0.49390163452875235, 0.10249448970200555, 0.9122617903255648, 0.45208230434406194, 0.7341041824510022, 39.26358046070222, 79.26196206000544, 84.56408085361605, 59.025461981373454, 53.69105423650434, 50.246883746116396, 65.26945560209214, 42.32802629470825, 0.07338436665914713, 0.2803683845746902, 16.339130113201758, 27.749806027258597, 17.201928977043398, 5.5021307449187, 1.6902067944888146, 10.046687376114631, 40.47813061744937, 93.94246009088333, 101.34174469978579, 57.42910046731272, 26.441287648293283, 17.00759710804109, 4.742929522068271, 65.79176625897809, 80.38279502622544, 59.78086733048963, 43.92791009718373, 50.73921180540516, 85.02532020691903, 62.79684443627635, 66.44807292569068, 53.58384409258443, 0.7080160081386567, 1.1266795041099673, 0.27770399206107665, 0.5394360314934485, 0.3004917676650709, 0.7026343936881712, 1.1126761522985276, 0.22488149423753062, 36.43131540667626, 65.22098295150265, 79.00696877510318, 79.51390374091365, 80.12984921855312, 76.05562840738605, 86.36379764926049, 86.05977473720428, 85.80946476228776, 89.03856385138728, 85.73003676629837, 81.13375632993638, 76.59176934149959, 69.23145740262925, 68.12818096530053, 70.37134524314635, 64.95960012558969, 78.4853563001079, 80.4604579556373, 78.58394899675923, 77.54845896074849, 79.29623573057114, 76.43028536150533, 75.15648780330535, 64.77435442709154, 60.68646415587395, 57.61150636980611, 63.271819929922785, 74.67005898875576, 74.27792395314863, 71.33126689541724, 71.84199087081417, 72.39691211331275, 67.0929733399422, 68.4064966632474, 64.13833425891015, 63.85047151196388, 67.78942154299828, 64.87611247647193, 68.15844597355013, 66.34773869668284, 69.06132067403486, 71.4172766285558, 67.005810429973, 68.03307133336222, 67.52608929910969, 70.71480366491502, 68.66978968343427, 65.33508077744516, 66.54142533579181, 71.0134921535369, 73.36900880259853, 62.19946353666244, 59.50813316529798, 69.12433747322329, 69.3604092444143, 70.92245394183745, 67.19034225709977, 66.67797873097082, 63.52299282627722, 57.21810440863333, 64.48689568427302, 66.21979098166189, 68.59360156520721, 65.78682015019079, 67.54940386741393, 66.73480603002733, 64.88306291641729, 61.17845096895772, 53.54807599898308, 60.86772864864719, 64.11520796437418, 67.07042755619173, 66.88489160230084, 64.49553666576263, 65.381717758794, 58.94210769284157, 66.65224798264043, 61.58371417753158, 65.28568636986518, 65.81122121503277, 65.12119785431894, 67.72849928948187, 61.45330321404242, 64.86971901309106, 65.70941217484014, 64.04449547490766, 61.77808330905054, 62.08508722243771, 63.34707452404884, 63.90383928052841, 64.12909707715436, 63.13020275485132, 63.25321220582532, 58.43195246111963, 63.33553098863172, 60.58033266375142, 63.542879243050855, 65.15529501822688, 63.97186494642689, 61.43832760472452, 62.163942552381954, 49.912909615424375, 58.145215434412805, 61.63891761533676, 67.62482320108722, 65.71159693502611, 72.14893987101894, 68.7138771241711, 73.06383271371165, 69.18822503858998, 69.10178384473248, 70.33820905993062, 71.37260867703345, 73.44685216103831, 72.48255314365511, 69.15408472861014, 64.34491765114569, 65.53463920470207, 62.12173392695766, 69.45940986756356, 67.20676129864108, 73.9653032056747, 68.97054918350713, 71.89899859889861, 56.735558740554325, 53.91656306482131, 43.9201634160934, 42.22987290351622, 18.307247008046797, 4.862699585576212, 0.5604022645181226, 0.23772258341552752, 2.394897981036094, 0.8692542271267983, 1.1034389705427232, 44.93567289844636, 88.35502024619811, 92.92085524528258, 69.60197233384656, 66.39433645432996, 56.760967854530584, 84.57023113004624, 51.084576499077585, 0.14391986683251398, 1.547327351666266, 23.90085477982798, 31.64807127368066, 17.632297315905173, 5.780200314137244, 2.02050885125514, 12.66951943597486], [3.2366866690497247, 34.89078098727811, 50.58707875590171, 1.2009095016025728, 11.77871681028797, 8.480769338146333, 1.8549305296713308, 44.85811195065899, 46.51189696404242, 28.46403237312071, 24.058161435588715, 37.93979229465608, 56.915215061556914, 39.95374502674226, 43.516888849196896, 40.717512869065814, 0.07408765835627433, 0.06769284666065248, 0.11833910319593646, 0.07064868200330005, 0.2687130309641361, 0.07383851890241908, 0.23441953404295832, 0.5132033729985838, 13.956651091575624, 29.158705703673828, 57.11022746178412, 68.77706650764712, 66.78117629020446, 70.47298954379174, 68.85641605623307, 78.43194930784165, 78.6245455280427, 77.23429279942667, 76.97011332358085, 74.39078623248686, 64.47860379372874, 59.00749752598425, 58.579955254831624, 57.19192651010329, 60.78460577995547, 62.124185408315356, 74.43606607375607, 73.62051117804744, 71.33190231938516, 67.81443057521697, 73.52522111708119, 68.1410934079078, 64.25929623265421, 57.0550161792386, 50.62725167120657, 52.29643983225669, 62.20788094305224, 68.03487562364148, 68.28902952132687, 65.18742315230831, 61.656889915466316, 56.60259039171281, 56.695746683305316, 54.99559533211493, 57.86991211675829, 59.746428920376694, 62.87235006209343, 65.28198365242251, 63.60102445848527, 62.72004050593223, 57.71763001718829, 58.96103705129316, 58.88881444931031, 65.0087905699207, 61.964643001556404, 63.54367548419584, 60.93534638804775, 64.73574653748544, 61.74896755526143, 59.295340661079656, 61.32050744948849, 60.19547362481395, 61.10498105326007, 61.115893087079456, 60.41276116524974, 61.39260453562583, 59.83816531396682, 58.21059742281514, 49.77941959134994, 49.78582874421151, 60.146883303119296, 60.499096455112586, 62.604138389710464, 61.29441584310224, 58.24656947966545, 56.084300164253484, 43.20859447602303, 46.03901209369783, 53.863073702781435, 58.49447896403652, 59.43225491431452, 59.20796986549132, 62.40021044208158, 60.07980685080252, 55.93847428598712, 57.602775173802534, 56.916623192448775, 55.83860289665961, 58.58853347839848, 59.799631949393984, 59.47291812589092, 61.88044932580764, 57.42974765839116, 50.355764819729714, 54.57847872088033, 56.25827297087639, 57.97275274030624, 56.5696777835969, 55.05419946485951, 56.83758743347661, 54.77847253122638, 56.90020807327763, 55.19954681396485, 58.33068470801077, 57.18749815417875, 60.746998094743304, 59.951243323664514, 58.8685122612984, 54.06662902524395, 50.20533800125123, 46.166073353059836, 55.454983326696585, 57.536538108702636, 60.22437757061374, 61.5665969540996, 66.04096228076567, 67.88814760023548, 66.97782824116369, 65.04136585420179, 69.19154336375576, 67.14472509199574, 69.8678933420489, 70.03141695453276, 63.479583955580196, 63.01921929082563, 53.99613618850709, 50.326970700294744, 51.51374655385172, 55.07688645393618, 55.32320737838746, 58.88699054718018, 55.88145871316233, 49.83055160891626, 33.56110142123315, 12.051063641425102, 23.24356555938721, 31.6713721136893, 21.17061841872431, 13.56988185836423, 2.5468192225502384, 0.20714806032276925, 4.3703033751057045, 0.23339377295586372, 0.7628383631667783, 23.52477792770632, 74.50746105563256, 73.61629855248236, 56.48228737615771, 46.69629935295352, 41.89452202089372, 65.691153541688, 32.09940664229855, 0.11353078298270704, 0.43792460113763815, 5.473793091312532, 4.563211423735465, 2.0488337571582487, 1.1181085124131174, 0.544666450831198, 2.6464361481128202, 24.061511139715872, 75.61287126233502, 83.23318927518784, 30.13275965567558, 18.699258488993493, 10.155346835813216, 4.119883083528088, 56.39348883782664, 61.29700852978615, 39.09414583636869, 38.0642020317816, 35.51029189940422, 71.73831478241952, 51.324472581186605, 51.15407697616085, 49.37098710767685, 0.05049516101397815, 0.20133087892205487, 0.09187916939657542, 0.062366934463141434, 0.13727842079054925, 0.02597053768113256, 0.358456676645625, 0.17314431317631276, 23.46585019942253, 48.62075536481796, 67.8820522369877, 66.05385903389224, 76.03933488169025, 68.6079574400379, 75.44276591270201, 78.43122759172994, 82.27964539681712, 80.38851384193667, 79.35620877050584, 77.62285063343664, 67.93316072033298, 62.95744196061165, 60.76236201870827, 62.23619261095601, 60.77328581963817, 65.21401289970645, 74.2235912815217, 77.07061229213592, 71.79440467588364, 68.85727897767099, 73.2615593940981, 71.67860061891618, 68.12915371310326, 61.28520219556747, 53.70737521879135, 56.919757166216456, 65.34682827611124, 70.4415713587115, 70.04368612843176, 68.56689806907409, 63.85488417840774, 58.19055411123461, 58.778274213114095, 58.269244701631614, 59.47300049566454, 61.71432518189954, 62.380641737291896, 66.22567453692037, 65.86296512234595, 63.96571859236687, 62.008855958138746, 59.64173301573723, 62.14831975198562, 64.34516868283673, 66.19708830310454, 65.47386992362239, 63.40229757370488, 66.87767444118377, 63.77940993155203, 62.982239184841035, 66.55191375363258, 61.83172172115695, 62.83951982375115, 63.17560811196605, 64.3614072953501, 64.89042128286054, 63.69627529574979, 60.54221899278703, 52.66836681673604, 51.07544129894626, 60.105792553194114, 62.43179728907924, 63.79529945312008, 64.49312048573648, 60.77260724959835, 55.958090059218875, 46.54381329013456, 46.171462689676595, 56.03847903590049, 60.00527397278817, 62.25352164237731, 62.66281704748831, 66.07467113002654, 63.75720931637672, 57.632561652891106, 60.426662045140425, 59.889999435793975, 58.22817748592746, 61.41382848062823, 61.77309405419135, 60.25941218099287, 63.75689944913311, 58.09619757436938, 52.98082674703291, 57.55765222734021, 59.869712937262754, 60.58046994670745, 61.4210024956734, 58.86056946169946, 59.71180223649549, 58.40584516525269, 57.95310951048329, 59.1315620945346, 60.781601244403475, 58.692605726180545, 64.05342278941986, 62.86565065383912, 62.93109932253438, 57.515882907375214, 55.07551362437587, 49.092761624243956, 58.3721088594006, 60.06675712523922, 63.00978206819104, 63.168202677080714, 66.13371849060059, 67.31625033963111, 66.48544526869252, 64.80506658554077, 69.43422040631695, 68.03580130300215, 70.60256896480438, 73.64052311066659, 64.6201229095459, 66.00235046878939, 59.396961427504024, 56.16846246104087, 61.675827118658255, 64.36514139175415, 62.37300096019622, 68.30880611173569, 65.34150169741723, 60.903849755564046, 50.293093189116455, 28.877199157591793, 29.773221477385494, 43.93318960743566, 25.336740363028742, 14.539995789527895, 2.310969065273962, 0.11685472357297137, 1.9107185232062496, 0.6141954263852489, 0.7540998740061637, 32.82657877091439, 81.47832870483398, 84.34785627549695, 65.74208159600535, 56.87870956236317, 45.7446107556743, 77.14192098186862, 40.52197094886534, 0.07356228291868203, 0.5955229218929046, 12.62307563135701, 18.135551137308923, 8.413741915456711, 2.599087501725843, 1.547661856297524, 4.770377287941595, 30.911371707916263, 100.05915318765949, 111.16509329888129, 50.73015897504745, 25.03647312041252, 15.675486653081833, 4.1368659657816735, 70.3694389712426, 78.58324297012823, 57.42839444068171, 38.41423434595908, 54.870652152645974, 73.88929551647556, 59.68414560441048, 61.64326752385786, 62.55288870103898, 0.17406047772495978, 0.5459957665974094, 0.16464928675803447, 0.37260632060708543, 0.4334897487874954, 0.18276083102870375, 0.5023719316288349, 0.5613629387751703, 32.190270308525335, 62.324038013335205, 82.4844244987734, 72.7274267135128, 83.48287951561713, 69.84406886562225, 80.54103912845736, 82.2884315060031, 88.69607033268099, 83.98255025186847, 87.13844222407188, 84.04817150485131, 75.12086483740038, 65.79909324645996, 67.00344131838891, 66.49935399332355, 66.54171559118456, 68.55608017213883, 77.01120407350602, 80.05741088621079, 77.21747367612778, 69.84075054045647, 77.49163950643232, 76.16528218792331, 70.30155058830016, 63.40104241524974, 57.06668523050124, 58.88813980164067, 67.71501418082946, 75.38048651910599, 73.97025323683216, 71.30184127438453, 68.7474996812882, 61.11309251477642, 63.74771718055972, 62.92683962852725, 63.27834675388952, 66.30997411666378, 66.80276501563289, 70.76369208674278, 69.45318114372992, 69.67457540573614, 66.9334662345148, 63.595913610150745, 64.59599248824581, 68.78053388287945, 67.98880346359746, 70.42925511637043, 65.83663032900903, 71.24890496653896, 66.07423966930759, 64.68535192551153, 66.8723713967108, 66.16912964851626, 63.72265715752879, 63.31264788104642, 66.42024763168828, 66.90526439297584, 67.16720027308311, 64.92534214450468, 54.21480048087336, 53.63350129896595, 64.1274183027206, 64.82160329818726, 67.59011022506222, 66.10583828341576, 63.69209012677593, 59.94025284244169, 47.16287705206102, 50.15624953854469, 58.37297962557886, 62.12160448874197, 62.18255027647942, 64.69173754415205, 66.78416513627576, 64.96592690867763, 59.62512177805747, 62.59429324057795, 64.20062934198688, 60.66138059862199, 61.9646861476283, 63.4621411754239, 61.62149444703133, 64.8538883270756, 63.537509518284956, 57.07592633462722, 59.375462916589555, 65.13174903008246, 65.38798570632935, 63.96079601780061, 62.227249606963134, 63.737934789349964, 60.23553279138381, 61.031338553274836, 61.42719984054566, 64.75978674427157, 61.7651669440731, 67.61224023757443, 65.61685208351382, 66.17995539019185, 59.12003032622799, 58.88734356049569, 51.987729687844556, 64.21167081402194, 65.3016504164665, 66.1923736141574, 68.58818869436942, 70.74770450592041, 73.44773077195691, 72.08494247928743, 68.91025450921828, 75.77858355737503, 72.11159106223815, 73.53440730802475, 75.17741757054483, 66.79691283933579, 71.38952978195684, 63.90915016974173, 59.4175656380192, 69.23226541088474, 70.31745187697872, 69.41729930139357, 75.86633482287007, 74.13962902561312, 75.65258133795955, 72.55208107732958, 56.57510242154522, 38.546226024627686, 53.36934927971133, 30.69808106268606, 17.821967447957686, 2.548258242107207, 0.32320768422176765, 7.825076522365694, 0.7901533200375496, 0.8361546322703363, 41.23853306616507, 89.81126293059319, 92.50976731700283, 74.9931759988108, 72.30745069442257, 55.769667240881155, 91.14278993298932, 48.892767813897905, 0.23370212334538662, 2.035605563752113, 24.816288909604474, 22.905898517177953, 9.629640386950586, 4.743850788762493, 0.9061775200309292, 6.7906881820771], [4.187134081317533, 50.64137220382691, 67.99733069635207, 9.64672819260628, 10.654480207350947, 8.140136003494263, 1.0046609419007455, 38.53909907802459, 38.896654498192575, 20.21594293655888, 13.99388909339905, 35.442721228445734, 33.71075945515787, 36.38013632066789, 45.47268067636798, 41.7134379571484, 1.513542874205497, 0.10730433443020429, 0.14574536242552344, 0.042461319526116696, 0.1989105466993586, 0.07023278819096666, 0.6945337799768294, 1.5895082753512169, 11.402383042920022, 37.4641146967488, 57.07564000160464, 66.32821313796505, 62.99964666366578, 67.48428467781314, 62.17339546449723, 71.35458930846184, 74.41552069879349, 76.3100568709835, 74.06630423761185, 70.06528269860053, 61.41805287330382, 57.61888434810024, 60.330587510139715, 55.300041860149754, 58.895686441852206, 56.01447805281609, 67.8530502319336, 74.50266791928199, 72.93143703091529, 67.42075797050231, 64.82133265464537, 69.12018760558098, 66.88585650536322, 59.852882046853345, 50.60233285350185, 52.70680212205457, 56.492383556981245, 63.59639213931177, 62.83879810763944, 62.07825837596771, 58.15515079805928, 56.1245083808899, 52.5518802673586, 54.04937059648576, 58.54890969491775, 63.18899908373433, 60.10771451457855, 64.45050393381428, 63.286379768002426, 64.4691312697626, 58.921072021607436, 55.38005428929483, 53.31849967279742, 58.44716341264787, 61.42933753228957, 62.56296134764149, 63.841336311832556, 66.10532837529337, 59.69397114169214, 62.21993046422159, 59.24252202433925, 56.47721967389507, 64.59734962832543, 67.06544614607289, 60.98197944702641, 62.077207180761526, 56.55595341036397, 52.54571822381789, 49.24551048586446, 46.82693781391267, 49.59930043066702, 55.98857079782794, 54.55744697201637, 56.95587042839297, 53.04197257564914, 49.04223365168418, 44.59428156575849, 48.39109666885869, 48.786565719112275, 52.6025612123551, 59.54497991069671, 60.475064093066806, 58.12071238794635, 60.79931074573148, 56.25607644357989, 56.412253456731, 57.44742578075778, 55.58326444318218, 57.193385631807395, 56.18626609925301, 60.40269636338758, 58.48869739040252, 53.656568757949344, 54.352330546225275, 54.947271731592, 53.911526741520056, 57.5975231201418, 55.57961663892193, 54.19820493267429, 55.34894597145819, 56.90099646968227, 58.867233568622225, 58.51005077362061, 59.34921441539642, 59.23147270756384, 57.861337815561605, 59.71686209401777, 57.00762610281668, 58.86303663253785, 50.08625876518988, 47.256943333533506, 54.610677457624874, 59.26076104564052, 61.14882138467605, 62.363653952075595, 64.70216320407006, 64.75820602909212, 65.85045276149627, 63.519399935199374, 67.17324072314848, 67.01082321905321, 69.01967294754522, 68.45979382914882, 64.29510747232746, 58.97016048431397, 54.34064972785212, 52.52128578001454, 53.071915949544604, 59.589863592578524, 60.2604280748675, 63.11390922915552, 60.571495563753196, 58.84506041003812, 44.57966681449644, 12.730798625176954, 11.632116263912572, 12.627169605224365, 15.457803933851181, 17.76022149670509, 12.580405146844926, 0.6444611087922127, 0.41380824521183973, 0.17724372626793, 0.019993900824638627, 34.56168628508045, 66.36816640054026, 74.28283476060437, 64.29825713557582, 41.60491774159093, 40.07353028943462, 61.97003626054334, 28.980575184668268, 0.13380545311637465, 1.010917796482963, 3.6534397255989814, 5.561633100432735, 1.794801575522269, 0.7088837712522477, 0.7519877389554055, 3.4847422617097057, 18.094787905293128, 75.73977562689012, 95.12026940622638, 23.04821779651027, 17.35610362022154, 10.821230949894076, 3.345272094011307, 52.26739075876052, 53.59619171388688, 30.71070521108566, 21.26200376018401, 42.70201252352807, 37.1211975620639, 44.499022883753625, 54.66841866893154, 50.418369770050056, 1.8379199456784034, 0.1472739989478742, 0.23182264919723236, 0.05117422135006036, 0.10394879271306338, 0.23465898248457143, 0.11473840568214656, 1.1670093142217206, 17.70598884551756, 50.52074755391767, 69.4150713951357, 63.83895543313796, 70.3223156159924, 66.56177459224578, 66.35366932038339, 73.17347080476823, 78.07871633960356, 78.50542314590948, 77.60137173437303, 76.96401796033307, 65.9235578967679, 60.73730984041768, 62.48690659000028, 63.09618796071699, 60.333329246890166, 59.46448895239062, 68.68301591565533, 78.9071209199967, 72.51666991941391, 71.39165570659023, 67.54086094517862, 71.74415911397627, 68.40841077989148, 63.348035504741055, 53.68057366340391, 55.46736232696041, 60.57735166242046, 64.8047096498551, 67.28407905947778, 63.34178716905656, 62.88952219870783, 58.285200903492594, 55.939803969475534, 55.15704008840746, 60.136010493001635, 62.483780460972945, 62.75627928395426, 64.55578034923923, 65.15076468067785, 65.3907705891517, 61.10348270785425, 58.855717489796305, 55.58779478073121, 58.09973947463497, 64.50369519572105, 62.521631333135794, 66.48042463487195, 67.99530675334316, 63.00927608243881, 64.67796218010687, 61.85361246908865, 61.00890651825936, 65.85446926855272, 68.34734732104887, 62.82414805504584, 63.65128178750316, 59.55403666342459, 53.11071603528915, 50.42959167111305, 48.059762293292636, 51.54425082668182, 56.83594003800423, 54.87007948660082, 55.757884440883515, 53.691925002682595, 50.98934135129375, 48.54582240504604, 49.01516145275485, 49.9234333345967, 55.35293894429361, 63.180216896918516, 62.44780055938229, 61.957296402223655, 61.968530070397165, 59.6916530209203, 57.3372503249876, 61.231316674140196, 60.237537122541866, 60.16349061842888, 59.58400749391126, 62.941305329722745, 58.67861855414606, 55.367659599550315, 56.28247007246941, 58.634095730320105, 57.36639745773808, 58.86841420204409, 59.19601055883593, 58.82604868181291, 57.20566265044674, 60.16525568500642, 60.65626190554712, 60.746558789284, 61.50575707035681, 62.75972704733572, 61.90376781648206, 61.8207351623043, 60.63180200515255, 59.71414781385853, 55.34301142538748, 50.42863853516118, 58.245016221077215, 60.24683313985025, 63.74855264540642, 63.33788048836493, 66.45696101650115, 64.8410660989823, 67.81702718427105, 65.56041309910437, 66.84071002467986, 67.78582865192045, 68.37840464807326, 69.73374828215569, 65.13563609892323, 61.1422396475269, 57.99318828890401, 58.15236983760711, 58.4504032904102, 64.51261466549289, 65.84476532474642, 72.25187070908086, 70.99460986352736, 68.70896631671538, 60.81453346437024, 28.694895236722886, 21.78547347745588, 36.59831031676262, 28.013548158830215, 23.435838184049054, 12.983364943535099, 0.9509421824928254, 1.1737842281018536, 0.17641872618227236, 0.1502858583004244, 48.06424164002942, 74.86761308485463, 82.49054339624222, 72.39468420705488, 50.94155119311426, 46.33774765076176, 74.51387020849413, 32.473186946684315, 0.16291710067420237, 1.252883480441186, 10.119143359122738, 13.585131053001652, 5.238026284402417, 1.3821529116361373, 0.4660526530877237, 3.784051955707612, 26.365866353434903, 110.36894629078527, 129.68242245335733, 38.707407982118674, 20.078491318610407, 15.042221949946496, 3.289753885999803, 76.4496304911952, 67.21236244324716, 46.61119568732477, 23.281263459113337, 53.488306922297326, 47.91503860104469, 56.380403810931796, 62.02899340660342, 66.96464123264437, 2.1138979110025593, 0.21874011974901925, 0.39078356457814095, 0.20182768694095074, 0.21881962435380106, 0.32772993188231225, 0.5537836938615769, 2.366535077171941, 24.565431764048917, 74.41941169000442, 76.81112397101619, 68.84329965037685, 77.97078055720176, 66.83854487634474, 70.52828711848106, 72.27673853597334, 84.78389047807264, 81.23627924150037, 86.47279247160881, 78.59242916107178, 70.30224092545049, 65.15850351702782, 70.86313201535133, 65.22666254351216, 64.54111852953511, 62.112881137478745, 71.53640685542938, 80.0394307413409, 76.32864106085994, 74.77728874452653, 69.88880741980769, 74.29523729508924, 70.23878482080275, 65.04545296392133, 56.304815815341094, 58.870602884600245, 63.84425847761093, 70.92928671067762, 70.74117768195369, 66.7664909362793, 65.09669480785247, 62.8924600539669, 59.26022368092691, 61.551044756366366, 65.89732508505544, 68.93152944503292, 66.39900407483502, 70.1618436075026, 66.7436235181747, 70.26315842905353, 62.56740147067655, 62.05302969101937, 58.33839216539937, 64.58160131208359, 68.0010804822368, 66.3793530002717, 67.89999315815588, 72.6708112224456, 65.9891007023473, 69.2823148542835, 65.39586182563536, 62.74929746504753, 69.46953742734848, 72.30033551493, 64.0068014975517, 67.32276147411716, 62.82155929073211, 57.82667975271902, 54.45745398921352, 49.56261842481552, 52.74308012377832, 60.84781085291217, 59.14788307682161, 59.112872000663515, 57.834700999721406, 55.53939273280483, 50.83712593201668, 53.092359342882716, 53.56888809511739, 60.64874272192679, 65.59976231667304, 64.8742336611594, 63.4138136525308, 65.15110200451267, 61.0715820712428, 61.44024956610895, 62.34654065101378, 61.243687829663685, 61.26541383804814, 61.71772979920911, 63.1731919319399, 63.88415682700373, 56.87700333133821, 59.76981016897387, 60.542791658832186, 60.637658103819824, 64.37113869574763, 63.72840342983123, 59.958958625793464, 61.380358895947865, 62.043619924975985, 66.21320924451275, 63.2661364155431, 64.93274757939001, 64.82735349285987, 63.959556548826164, 63.011919759934955, 63.46198035824684, 64.39749702330559, 57.893054100774954, 54.197455759971376, 60.541046204105506, 62.339907923052394, 68.14853806649485, 67.38472707809942, 70.36057441465317, 68.341659884299, 70.88508944357596, 70.52958150063792, 70.80101736130254, 70.51891265376922, 71.89717077439832, 71.6516068673903, 69.38472793948266, 64.88420040376725, 62.92020690056586, 62.76581064347298, 65.67589944408786, 69.88313567253851, 73.10132272781865, 74.90946477459323, 77.63694763183594, 74.01194803176388, 77.81701580170663, 53.53197074705555, 30.890659632221347, 50.256654370215635, 39.33030389970349, 30.067952294503492, 15.285565795436984, 0.9822590601059699, 1.437227646670034, 0.7608032046306519, 0.45099369340365936, 61.97306433031636, 79.33818940193423, 92.43959611462009, 81.28338690726989, 64.42336897696218, 50.75488951898391, 89.75703224059075, 41.73399117685134, 0.19135846726356015, 2.6508333702241225, 22.573934601199245, 18.702906293253747, 9.710244113399137, 3.020977637460155, 0.9436973809234558, 5.479970334037658], [2.7143654707939397, 44.10139260753509, 52.774200208725475, 15.788748033585088, 12.53638046403085, 6.0428044680626165, 1.3424206501053226, 40.965932261559274, 39.684654743440696, 19.783621257351292, 26.132538280179425, 33.29078343606765, 56.76719265599405, 41.996613471738755, 47.457066582095244, 35.832946069778934, 3.4266083230895386, 0.035713636241252386, 0.26674458336445594, 0.17906137712059483, 0.1046852483564327, 0.16768540045426739, 0.12488762277268595, 1.655568220923024, 18.187002828044278, 46.51545063141854, 61.830093937535445, 64.41000153941494, 61.9598969336479, 67.37151653535905, 61.63174752266177, 59.95427923817789, 63.91307646228422, 68.76215365625197, 67.17511561609084, 62.288564097496774, 56.357712899484945, 58.10703900552566, 59.31715688397808, 57.210804877742646, 59.46726991284279, 55.74233224315029, 58.27599510069817, 66.51520821356004, 73.83484517374347, 70.47741397734612, 66.69380941698628, 63.46682840777982, 68.37377625126993, 62.37633889721286, 53.66667278351323, 51.59281369178526, 53.13782353555003, 57.53183126449586, 58.047732768520234, 56.930814327732215, 53.373479535502774, 51.213936267360566, 52.50609444033716, 52.54207041955764, 55.62225672506518, 59.18173705377887, 58.80837448181645, 60.30817116460493, 62.61787845242409, 68.4825514208886, 58.23333540270406, 54.00355339050294, 54.702205965595866, 60.05238948329803, 53.83485617176179, 56.562429243518466, 64.60617496121314, 61.60691499710084, 60.46267724806263, 62.72024446918119, 57.68429379309378, 57.403832558662664, 60.22103571122693, 64.02812350180842, 59.85782815564064, 59.61761043917749, 50.2785215839263, 44.80868616411763, 43.991527019008515, 46.423996648480816, 48.444837062589585, 47.86263965791272, 40.95257266875237, 41.991847791979396, 46.77662557171237, 48.539981995859456, 43.836028575897224, 43.344222191841375, 45.063440184439386, 48.995647661147586, 48.125018765849454, 57.57816230097125, 62.44818887402935, 59.94759159703409, 56.90456582653908, 54.90697330044162, 56.39722685660086, 57.95844001154746, 55.65771102905274, 56.35206076406664, 59.32104787518902, 54.600369468812026, 52.83305537316107, 55.657922837042044, 55.65874653477823, 54.52272222888086, 53.38325408197219, 56.80921300765007, 52.23847896822038, 52.45626464966805, 55.29090273764826, 56.772248591146166, 58.367813864061915, 59.10596862916024, 57.495863130015714, 55.32386241420623, 56.70425822657924, 55.46587967103528, 57.21257778906054, 50.28843341335174, 48.77193920073971, 54.493014197195734, 60.10513751737533, 60.4565465834833, 62.512943283204116, 63.66855982811221, 64.53004567853867, 63.88625529504592, 61.98030110328429, 64.80891050830965, 62.441791488278305, 65.81107216496622, 63.821995104512865, 61.34057821766023, 58.09289886105446, 55.24588177281042, 52.63841952047041, 57.43548216358308, 59.774042406389796, 62.4434781074524, 65.14750126869448, 65.02344846725464, 65.47078301829677, 46.17060369060886, 17.982113899723178, 9.801608862415437, 8.704213038567575, 9.275184619811274, 16.26485905339641, 28.673792885195827, 4.660100340843201, 0.4171009523974311, 0.4081981833423338, 0.8133775512537649, 45.29056895163752, 68.24074514450567, 73.06815516564154, 65.74540384354131, 41.1629254587235, 35.531845323501095, 59.005312765798266, 27.928975974359822, 0.21408677912287175, 0.6789297946999151, 3.425464216739901, 6.5475404550952305, 2.7883776541679137, 0.5782173634056123, 0.7480350929883219, 2.6004627827675115, 16.434579030159984, 81.31491491871496, 71.2250255769299, 19.165946014465828, 15.103849249501383, 10.629005393674298, 3.3186730309840176, 56.85266502441899, 51.57544543666225, 30.22049915406012, 26.918061548663726, 38.67427179890294, 66.37444219281598, 47.839497673896055, 56.12381019899922, 47.773197850873395, 5.086560037828261, 0.30608408693825045, 0.2904704489534901, 0.24867224747375136, 0.09140624033827936, 0.29259729289239456, 0.15532999569850583, 3.041443584426757, 18.769015881323046, 62.44358793381722, 75.67398963436004, 68.04645446039015, 70.46607832754813, 67.56696039630522, 66.0321447926183, 61.7720663932062, 71.24506888851043, 70.8576956102925, 70.08276078008836, 64.82212105105, 60.2908892016257, 63.13068520638251, 62.82667798380699, 61.694403463794345, 62.03459062883931, 59.81154418760731, 60.32930489509337, 70.3456929422194, 74.28168942851406, 74.53405472540086, 70.65143385241109, 67.51414960430515, 68.9751148223877, 64.3728135478112, 54.001062685443515, 53.66356234396658, 56.598142423937404, 61.03191906406034, 61.30865012445758, 60.108926526961795, 56.637985860147786, 54.84299159819081, 55.25727233579082, 54.942372691246774, 57.74429821198987, 59.76275382503387, 59.97900585974417, 62.954064799893295, 64.86656542747252, 68.62512173191195, 59.884170793717914, 54.43639478375835, 57.855791584137954, 60.49256570877568, 56.05470588130336, 57.68410159695534, 65.92184774337277, 63.75268682356804, 65.50915556569254, 63.90734195709229, 60.77165803601665, 58.84362090018488, 62.87668428113384, 66.21114607780211, 64.2751818318521, 59.48009998567643, 53.18805733034688, 46.412445268323346, 46.89734043613557, 49.546736747987815, 49.48204901910598, 45.18767341490715, 40.73110780408306, 41.57919876037106, 46.41381417551349, 49.65362133518342, 46.063817162667554, 44.716879167864406, 49.009168071131555, 52.79206660486037, 49.628765275401456, 57.69642176166658, 64.92314561720818, 60.91569531348444, 58.34434632332095, 58.866386336665, 61.243370117679724, 61.084431755927305, 59.887375370148696, 59.941500156156486, 61.83698946429838, 53.52120384093254, 54.87860671935543, 56.63474990475563, 58.62104992712698, 57.77065653954783, 55.86059954858596, 59.79178720904935, 57.058122696415076, 56.34290595208445, 60.31912634449621, 58.03260026439544, 59.03396960227721, 61.04634161918395, 61.46439175451956, 59.192707923150834, 58.73880340207008, 58.14738058274793, 59.04027285114412, 52.230920560898326, 50.78456617170765, 58.03550281832295, 61.65426584982104, 62.84732141802388, 63.383478041618105, 66.06154687942998, 65.43709378088674, 65.7674632533904, 63.302249677719615, 64.68374767611104, 65.04309954181795, 67.31670533457111, 65.86458113885695, 63.744088988150324, 63.488091576483946, 61.01524506845782, 60.21505017434398, 62.47936387215892, 64.6212133284538, 67.6110399923017, 72.81985344425325, 71.6799577589958, 73.3815368529289, 64.67886040287634, 34.08222752232706, 19.726923396510465, 22.278623273295743, 17.7730849096852, 26.630912673088815, 31.302955650514175, 4.7660180637913365, 0.5565511098792476, 0.29322205291640374, 1.0290566134837367, 58.487532446461344, 75.78106249532392, 81.94133312471452, 76.17165211708316, 50.674222054020056, 42.490663451533166, 68.96770938750237, 33.2636994700278, 0.5465697196702803, 1.2170038444380606, 9.174950411242824, 11.9914504789537, 3.9869186570567474, 1.6362273813255372, 0.256994444456312, 3.0943899433459006, 31.821869534830896, 135.21106596915953, 92.23266755380939, 28.2320830129808, 18.439207307754025, 11.441493976500727, 4.838661830271445, 78.21285355475642, 66.79684223667269, 46.25593485370759, 42.8213349465401, 51.53785344093077, 70.0481419409475, 66.37695250972625, 63.669281544223914, 70.28746927938154, 6.237295683353178, 0.43625033130088164, 0.38316632170350323, 0.29199275758958637, 0.13543437054801372, 0.26407534917516096, 0.1891118837820907, 2.524427882125301, 31.370838149901363, 70.78971309046592, 75.77975242368638, 73.95727803630214, 74.95142629069667, 68.53685271355414, 71.44723569193195, 64.29274620548372, 73.81773579505183, 73.03246159707346, 77.09282075205158, 68.99510322078582, 64.81617473786878, 69.81102681929066, 69.24763325721987, 65.29161307119554, 67.82556226176601, 64.40259610452961, 64.02835492164859, 73.18326104071834, 78.80981476076188, 77.63384895939981, 71.69831445140224, 68.3906973561933, 72.32812158523068, 67.44321746210899, 57.07305515966108, 56.39783874634774, 59.13830464886081, 63.616576656218506, 64.74481113495366, 63.42943253055696, 59.997911683974735, 58.37589786898706, 59.48732891390401, 58.80898244919316, 61.700192882168686, 63.60528807486258, 62.94582782253143, 66.97801651493197, 68.03846066997897, 68.92420245755103, 61.35471836213143, 58.131538129621944, 59.38638279514929, 65.12890138933736, 58.23390022400887, 61.26689649397328, 68.12841630751088, 68.44065266270792, 67.1863728184854, 67.58022585222798, 63.31519742165843, 63.0561327165173, 66.7092086422828, 68.52582300862959, 64.36268598802629, 63.29865678664177, 57.15185557642291, 49.20260760091966, 47.61189822227725, 50.53183609439481, 52.226892286731356, 47.642657449168546, 42.10571419808173, 43.03859895275485, 49.29328495456327, 52.52370588241085, 48.560825470955145, 47.65834300748764, 50.600705069880334, 55.092964249272505, 55.16581443048293, 64.13321948820546, 68.47696596576323, 63.81888074259605, 63.027573939292665, 61.77445903901131, 63.939324963477354, 62.418402394940784, 60.47506017069663, 60.32133071653305, 64.3236505600714, 58.50050372462119, 57.27715569157755, 61.60121971561063, 62.76288455532443, 61.49594722255584, 57.802325756319114, 63.676498705340975, 58.60013584936819, 58.204474602976155, 63.285724732183645, 61.324469043362534, 62.745959528030895, 64.57562361994098, 64.40259610452961, 62.11464228168611, 61.30005228903986, 62.03146842218215, 62.75870723109092, 55.97721553617909, 54.73320837943785, 61.749618668710035, 63.10399739973007, 65.50619025384226, 68.08269716078236, 68.23457133385443, 70.33146258323424, 70.36033907244283, 67.64791811666181, 70.20988479737314, 71.43547642615535, 71.68945773955315, 68.21819151601484, 67.8757921341927, 66.2706405885758, 65.71830418802077, 62.56853111328618, 68.1009126478626, 68.2853268038842, 72.78366565704346, 75.94051468756892, 77.20492993631672, 79.22371110608502, 75.58607362931775, 59.10523906830819, 31.818965019718295, 35.58812349073349, 33.56824013494676, 39.62618789365215, 36.42530633557227, 7.934079189454356, 2.079562217958512, 0.6980083257921281, 1.6552577408090716, 74.66589343163275, 80.3883098786877, 91.25275750314036, 81.78107292421403, 64.01705457318214, 48.8288410248295, 84.30731465739589, 42.64304361035747, 0.6665995176280699, 2.2412023573152484, 21.751923484186975, 17.108525576130038, 10.700700436868976, 4.494215461515612, 0.5773589159211805, 7.170970795616028], [14.00979724622542, 18.873733358998454, 24.452665582779918, 14.543081714260964, 8.163735924228545, 3.816542909029992, 7.3990169071382095, 42.239753353980284, 37.56814772082914, 15.057390735995385, 33.50545083322833, 44.24803041642712, 42.377848240637014, 45.379783261206846, 54.08288332723803, 35.05336715329078, 7.884748030093409, 0.22302601396316485, 0.1444551784304842, 0.05513609484619191, 0.21431547169002796, 0.2906514295647222, 0.4838241462505633, 1.679760664701462, 16.846095477381063, 35.605934973685976, 51.67088062532487, 57.70785547071888, 66.92737871600737, 66.78880922255978, 64.47750945245066, 62.83924133546891, 56.54126413406865, 59.36884980047903, 55.10428420958981, 55.476430846798806, 54.00468303311256, 58.42662588242562, 59.949972475728686, 60.87887602467691, 60.125172984215524, 54.675788802485314, 53.885784226079146, 56.11628317063855, 63.54708010150541, 70.07089953268729, 69.92206127412858, 66.11751125704858, 64.64346885681152, 61.13610898294757, 53.434609674638324, 51.016990138638405, 50.45675016218617, 54.75245937224358, 55.523283558507124, 54.525240390531486, 51.99506452006679, 50.63197420489404, 54.314087437045195, 55.56495481921781, 54.615886365213704, 59.744965876302416, 57.727306504403394, 62.63436417425833, 57.67596660121795, 71.5502763563587, 63.91681055868826, 49.64689054796773, 53.322488723262666, 55.22381844059114, 58.483519861775065, 57.08985467110911, 57.55412993892547, 59.11845353341872, 59.91837778399068, 62.940591458351385, 54.77817050872311, 56.12126850312757, 62.2183144477106, 64.32650604555684, 63.133776034078295, 51.825622050992905, 45.97799570329728, 42.232014517630304, 47.953493518214074, 54.812169613376746, 41.01803702692832, 38.74283482951503, 37.43136290580996, 36.27034917954476, 39.38531121900005, 48.97201538085938, 48.79936049061437, 40.13423681259155, 46.78914185493223, 51.866752024619814, 45.92909159198884, 47.35752467186221, 56.20493658127324, 58.17463713307535, 56.84929570844097, 52.15116308581445, 58.25382978685441, 58.77495981031849, 58.40055781026041, 59.79166561557401, 56.60150389517508, 54.264241956895404, 52.79575363282235, 55.15869140625001, 56.151345237608886, 54.103699345742505, 54.953763254227184, 55.06801013023623, 53.20784176549604, 54.79497002017114, 56.020114498753706, 54.940019269143384, 57.1566173338121, 58.07945689847393, 54.49772888614286, 54.240366489656516, 55.440486246539706, 53.97761475655341, 53.812349611713046, 48.836281761046386, 47.610031174075225, 59.00808195913992, 60.09198581018756, 62.68735147291615, 61.457806095000244, 64.26312446594238, 59.78290304060906, 58.31444609549738, 55.21400859279018, 54.118553361585064, 54.86074424559071, 57.54956037767472, 59.23759160503265, 59.67350421413299, 54.413998050074426, 53.523694545991965, 53.933746968546224, 56.031901221121515, 58.99164330574774, 66.42645282130088, 65.64362618231004, 67.75019784127512, 63.90844806548088, 50.587651421946866, 25.66014566729146, 10.152178541306528, 11.132573004691832, 10.76711989218189, 15.97276406903421, 34.016343470542665, 16.57424972903344, 0.42212498764837947, 0.2500845305621624, 0.40443669163411666, 28.203412448206258, 74.60821105587867, 71.1518890626969, 67.96651655627836, 39.8931130286186, 42.021893147499334, 54.83321312935122, 33.05143648578275, 0.44337709404287806, 1.3598967704080767, 4.139586129496175, 7.050537361252693, 2.671708224281188, 0.9947242912265563, 1.0307396780098639, 1.7842177950566815, 19.716364376006588, 80.26979938630136, 35.89857516750213, 21.586574008387906, 13.307780258117184, 8.421683734463107, 10.698147954479342, 56.462467639676994, 48.166713560781176, 29.275947309309437, 30.86925918056119, 50.75118287917107, 47.38459687079153, 50.89268238313737, 62.53288853553034, 45.84900856018067, 11.35040379339649, 0.27174548276009103, 0.09287434059285349, 0.14914348330949584, 0.10427209713886823, 0.21675419002290697, 0.1805894927031571, 3.394160515839054, 25.19334243189904, 58.519429160702614, 66.92788077938941, 62.439104664710264, 75.51138385649651, 66.33113138137325, 68.2780311953637, 64.80540783174577, 61.20853947054956, 62.699248021648785, 59.648373588438965, 56.424353968712595, 58.15461343334567, 60.29888299203689, 66.17919445037842, 66.08145683042466, 62.133975644265455, 58.46388447669245, 54.59454867147631, 60.006827231376406, 64.30094395914386, 71.38763135479343, 70.88469720655873, 69.76917512955205, 65.45533280218801, 63.68443366019957, 54.427440012654955, 56.42944520519626, 53.62785308591781, 59.21381811941824, 59.04163391359391, 58.28850746154786, 58.05467928609541, 53.659385019733065, 54.63204653032365, 57.03748318456835, 58.7992863501272, 60.41975867363715, 59.356439421253825, 63.646296455014145, 62.802280841335175, 68.41265478441792, 61.08514954966884, 51.533825166763805, 56.098436386354514, 55.73763716605402, 59.584282059823316, 57.693177961534076, 59.63279001174435, 62.17077532122212, 63.340830110734515, 65.88900966029014, 57.1173426412767, 59.77777650279384, 64.40853065060031, 64.09197576584356, 61.837934755509906, 54.37378983343802, 46.93531290177376, 45.96400460889263, 48.58980786415839, 57.00989323277628, 43.742491814398, 38.026060904226, 38.07625155295096, 34.94964399645406, 37.98161260543331, 49.34460132352768, 51.39973894242318, 44.085765884768584, 49.64618059896654, 50.309159217342255, 46.40580077325144, 46.418164084034586, 56.89456378259967, 60.62548698917512, 58.60065752460111, 55.16371988481092, 61.95862608571207, 61.431192813381074, 61.24797498026202, 62.43790049706737, 59.31767071447065, 57.342482766797474, 53.7336080305038, 58.391810924776145, 60.332831105878284, 59.582038464084754, 57.64317558657739, 55.67958608750374, 57.71533935300766, 56.41851748189619, 58.06262600806452, 58.09498163961596, 61.19862371875394, 58.99587554316367, 57.382808654539055, 57.19932802261845, 58.59523680902297, 55.81752407935358, 55.54061651229859, 50.839867668767134, 50.7287351546749, 62.787234629354174, 61.65878834262971, 64.18024086183118, 63.539827639056796, 66.15845295690721, 62.83720954771965, 60.52132060450893, 58.14144603667721, 57.09696200586135, 57.6114083105518, 63.39202096385341, 62.09839974680255, 62.98439648843581, 58.821381061307854, 59.12687093980851, 59.38185245760026, 62.3591471487476, 65.92112602726107, 71.17880436681932, 71.91126777279761, 73.97339897771036, 71.40393272522958, 65.51801227754163, 43.50471381218203, 19.72414243605829, 14.40005248592746, 12.16576845415177, 25.22922819660556, 42.081419037234404, 17.76342018958061, 1.2689291613717235, 0.3493697094100137, 0.1670669070294788, 40.22809913081508, 82.42718927321896, 77.50960396182153, 77.009564522774, 50.66287463711154, 47.639288133190526, 65.80227036629954, 40.25399461869271, 0.6077237607490632, 1.9593669450090778, 10.63966247343248, 11.961687534086167, 3.482354518867308, 0.11723317100756592, 0.3059667222682507, 3.6120280767640764, 36.44711471373035, 117.95248031616212, 37.77611178736533, 24.573072541144587, 14.730571989090214, 8.402711229939616, 15.407507381131573, 78.9786414177187, 62.98482794915477, 42.52454096271146, 45.42085047691099, 64.08799456011864, 55.36456877185453, 68.54520736202117, 70.6200078225905, 66.64289705214962, 16.477598605617402, 0.7946100518588097, 0.24201405474976187, 0.18254560628725638, 0.36721361320345636, 0.3994056696612989, 0.5766493959292289, 5.0732195665759425, 37.10788111532889, 62.792847541070756, 66.80223941802979, 70.65832153443368, 75.80369457121819, 71.57871354010798, 71.13339900970459, 68.11459387502363, 63.45761868261523, 68.5271958381899, 63.569853382725874, 62.16885335983769, 62.75201566757695, 66.86422855623307, 72.00314537171396, 69.87808365975657, 66.68972230726673, 60.31692197245937, 58.77131200605824, 60.03191471099854, 67.115275936742, 76.87589799204181, 73.55082634956607, 72.65214074042537, 69.16215696642476, 66.30344729269704, 59.583085736920765, 58.140006526823974, 57.08437511997839, 62.16295019272835, 63.66008358616983, 61.61678368045438, 62.06609902843353, 55.96872360475602, 59.53820205503895, 62.14688416450255, 62.73640071192096, 64.56845744963616, 63.91360205988731, 66.91822390402517, 63.04705242956839, 74.62620689022926, 60.2866961879115, 51.758600511858546, 58.08032766465218, 58.084665806062766, 62.29593030868038, 61.139897992534024, 62.45996775165681, 63.89581803352603, 67.3316260307066, 70.74730442416283, 60.13173903188398, 61.15778792288996, 65.46056132162771, 68.65736361472838, 66.50752821276265, 59.71297894754718, 49.763757567251886, 47.86547945391747, 51.50163819712978, 58.100072876099624, 44.11883931006155, 39.80064315180625, 39.00884605223133, 35.37988485828523, 40.91269000884026, 51.78184447749969, 52.61728578998197, 46.485115020505845, 50.753379406467566, 52.52088962062713, 45.80542318282589, 49.49912701883624, 59.790998812644716, 63.46014861137637, 59.61516680256013, 58.75203747903147, 63.63699651533558, 61.580462532658736, 61.89852360756167, 65.44393439446726, 62.030374080904075, 61.10828368894516, 56.12853665505686, 62.46854989759384, 63.83937120437623, 60.279741825595984, 61.863806709166504, 57.855246374684, 59.307268588773674, 60.45254184353737, 62.6742664460213, 60.31692589482954, 64.065786100203, 63.97459099369665, 60.692269263728974, 59.01789572931106, 60.80510016410582, 59.60410179630403, 59.9806454104762, 55.021561422655665, 53.93807334284629, 66.12121397449125, 66.38754290919151, 67.02717950267177, 66.79571259406306, 71.2052176075597, 67.43077570392241, 66.2347822804605, 64.0777571739689, 61.604192872201246, 64.77387982030069, 67.03183143369614, 66.30170576034054, 68.339565338627, 61.09375915219707, 61.71111668309858, 63.32026120155089, 65.3625609028724, 69.62217254023399, 74.7031088798277, 75.23104421554073, 78.8032251788724, 77.82248358572684, 72.97713264342278, 65.27892812605828, 45.40609452032274, 26.863534719713275, 29.781444726451753, 39.47261533429546, 50.95356933532223, 22.639145966499086, 6.370555758476258, 0.8796460566020782, 0.4649348695191645, 54.64721041340982, 86.828873080592, 87.37728318860455, 84.96958332677042, 63.42933839367282, 60.85315704345704, 76.4884227321994, 54.51102572102701, 0.7861941776448681, 5.054165182575103, 20.937910079956055, 19.750445850433845, 12.62105364953318, 2.0288418041121576, 0.9490473712644271, 4.2158350444609125], [16.21073720916625, 3.667850268463935, 10.461494691910284, 13.332621609011005, 5.862064592299923, 1.3279502910952414, 10.933932412055231, 42.81095243269398, 37.78428992917461, 18.922339370173795, 31.255953888739313, 36.911150716966205, 72.85354660403344, 44.27327479085615, 55.718570524646395, 44.740860539097945, 15.002156899821374, 0.09447164923673677, 0.27051471654445897, 0.22376309779863204, 0.11480730763005634, 0.11278180180177574, 1.3375593625730084, 4.264869574577578, 13.149332192636306, 26.763380919733358, 43.505937591675796, 56.73857112084666, 66.14712515184956, 69.97029858250772, 65.30211717851701, 61.884948284395286, 58.5481369879938, 57.42571153948384, 54.96639328618204, 56.29455489497031, 53.93091893965199, 57.31975655401907, 62.51440632727839, 62.886407836791015, 61.296231900492025, 58.94653604876611, 53.62324037859517, 54.26549711535054, 55.129477593206595, 62.15112032428865, 63.545409171812004, 63.713745532497285, 63.037685809596894, 59.69714041679137, 53.144028725162634, 51.8657478978557, 51.54154046889275, 51.688609738503736, 51.7607891944147, 52.65622708105272, 51.70450318244196, 51.63733259324105, 55.4965369163021, 55.07730222517445, 55.63218424397131, 55.69349481213478, 61.945462611413774, 59.39633384827645, 64.36946776605421, 58.53726025550597, 55.96208303205429, 59.87974636016354, 55.794409551928126, 57.62840394050845, 54.01079016347086, 55.69750347445088, 55.583829264486994, 64.83285265584146, 60.915491350235484, 57.901844132331114, 53.25864822633805, 59.50820376796108, 59.186553724350475, 52.375295162200935, 47.05109342452019, 45.3216145115514, 43.09289240068005, 48.411387089760076, 50.61087577573715, 57.518695246788766, 51.0346878728559, 35.99836026468585, 34.965031454640055, 34.495759087224165, 38.0642294883728, 56.55206634152321, 52.75387056412236, 45.19911889106997, 44.933884297647786, 42.428654701479026, 49.20398435285015, 45.50371054680117, 50.61410388638897, 57.92684139743928, 58.914870754365005, 54.45383756391464, 51.87039982888007, 59.999680672922445, 59.657916715068204, 59.4307565689087, 52.594292856031856, 54.84475274239817, 49.73403776845625, 54.93633616355158, 55.727415469384965, 55.669081980182284, 54.81019666118007, 55.385612287829005, 51.16287485245736, 51.947921552965724, 53.01039357339182, 54.911848806565814, 54.50538927508939, 54.362085480843824, 51.44485796651533, 49.502865037610455, 48.6925700403029, 50.211551035604174, 48.20703160378241, 48.06916813696585, 46.70659949702602, 58.63688845788279, 61.77412955991684, 62.547495442052046, 67.23457874790316, 61.20779422021682, 62.418582823968705, 58.081673037621286, 51.99173050542032, 50.24699357248122, 49.06185726965628, 49.69891294356316, 51.90717989398588, 54.258840853168124, 50.82213855558827, 53.29218449131135, 55.918266234859345, 62.04707161072762, 61.29661237039874, 66.93650214902817, 65.39545782150762, 67.94340595122307, 64.08664918714955, 57.022789985902854, 37.35808910862092, 15.39302500986284, 13.772584065314263, 11.98109640229133, 20.60045680692119, 40.64539224870744, 29.1247340556114, 1.2610355139740053, 0.16373793324155195, 0.3153111869769712, 55.65385141680318, 73.06984178481564, 67.082885003859, 69.65476743636593, 38.270338273817494, 40.01904856774115, 51.34648100022347, 17.27168833055804, 0.334564569977022, 1.3952071724399444, 7.764934820513572, 9.337965096196822, 2.382764864352442, 3.5698346505242013, 0.38538331886933697, 5.789136453982323, 17.105266086516842, 64.3850709545997, 19.258304103728264, 17.51910359628739, 11.36694246722806, 4.1418527691595015, 18.16012478643848, 55.32675320102323, 50.98227324024324, 28.189621394680394, 31.08462868198272, 45.76898436392508, 69.29267775627875, 56.90132202640657, 63.035399067786436, 59.44109201431275, 20.880204169980942, 0.2619442764309145, 0.11514266261891012, 0.24986722206156103, 0.11143901054897618, 0.1797033128358664, 1.0285414346764166, 3.772487092402674, 21.533800478904478, 41.04177913358135, 57.923217127400065, 62.4341977796247, 69.65835248270344, 68.60974604083647, 70.50181111981793, 63.14968908986738, 62.675631430841264, 57.45723955092892, 58.07259275067238, 56.90699377367574, 58.463766805587284, 59.732916355133064, 66.28774996726744, 64.99128895421183, 64.96905303770497, 62.11012763361778, 56.36934272704586, 55.55489393972582, 55.865420141527736, 64.2477370077564, 64.94694263704362, 65.65838606126847, 63.91540635016657, 63.98673857412031, 55.57547069364979, 55.6927691736529, 53.032613800418, 54.330918327454604, 56.427613458325794, 56.62146091461182, 56.39897623369771, 58.491717615435206, 56.76910677263814, 56.526539556441776, 57.19955944245862, 59.56298358978764, 62.749077812317886, 61.66412276606406, 65.62457915275328, 61.07024454301404, 56.501228501719815, 61.00640404608942, 58.65013822432488, 61.49599821336808, 55.34139148650631, 56.67973556826192, 59.124619499329604, 67.38135383975121, 64.1444060879369, 60.60475726281444, 55.31539009463403, 61.25691013951456, 61.812545253384506, 52.988118433183246, 47.99048931367936, 49.00385718191824, 45.44047409488309, 50.141642632022986, 53.5810435202814, 60.57934814883817, 55.0375097797763, 37.93255159931798, 35.19131298988096, 35.11824315594089, 39.94796737547844, 59.48769761670021, 54.61304264683878, 48.725557173452074, 45.49056276198357, 46.64027613978232, 50.47337708934661, 47.747843650079545, 52.606471815416896, 62.464556924758426, 59.71322605686804, 57.559554576873786, 55.07349360373713, 60.233814793248335, 61.354702672650745, 63.30521891194006, 55.792985731555575, 57.95793010342506, 56.001091003417976, 57.6034027530301, 57.29258629583544, 60.96590557406026, 58.1726602585085, 57.77860326151694, 56.13520076197963, 55.22374391555787, 54.952139392975845, 56.744050671977384, 56.54969330756896, 55.79722973608202, 53.38420329555389, 52.250536334130075, 50.66185874323691, 49.937961793714955, 51.58562790962958, 50.46554019374233, 49.85975757721932, 60.72899833802254, 64.9067501098879, 61.90646640716061, 66.69404475919663, 65.28258769742905, 66.50690847827543, 62.09939210645614, 58.57424036149056, 55.48376175665087, 53.206374799051595, 55.79240522077007, 56.518859555644376, 58.68192511220133, 55.15881299972535, 57.7809331493993, 60.459358922896854, 66.56303759544127, 66.42566050252607, 74.3185910870952, 70.64991981752458, 77.5656310973629, 72.39148355299427, 70.00803962830575, 53.173768135809134, 25.57162169487246, 21.88542135300175, 17.794099007883382, 28.468770596288866, 50.922147227871804, 34.878868749064786, 2.2079168788848387, 0.316186610969805, 0.5044422076354104, 64.76716864493586, 83.23278134868991, 76.08230836929815, 83.37035456011373, 48.22577268846574, 43.56328264359505, 58.86512333346952, 37.17599699574132, 0.5416045506154338, 3.7621558145169294, 11.625239368407957, 12.385809498448527, 3.8847279212167187, 2.901056072404308, 0.6156621476815594, 5.359473161159023, 29.60000372702076, 58.73977614987282, 19.155512509807465, 19.91017064740581, 10.135954637681285, 3.444465648743414, 24.51991658056936, 76.03066644360943, 65.39570885319864, 44.90685132242019, 45.82537235752229, 55.17177643314485, 88.02853784253521, 68.00521466039842, 74.30771827697754, 76.74331403547718, 29.319093381204915, 0.6063922999366638, 0.4772870567056441, 0.6699374546447109, 0.3782172711385835, 0.19789148122072223, 1.8866915544194562, 13.402030890987767, 32.4303448584772, 51.98679616374355, 62.52729131329445, 73.21426345456031, 69.00195167910668, 78.579846197559, 73.30391314721876, 66.97647894582441, 65.4136223177756, 64.87428072960147, 62.4001790631202, 64.82915778313914, 62.68150321898922, 63.89990122087541, 73.94030201819636, 71.44773775531401, 70.0836472357473, 65.94866891061106, 59.21119013140279, 58.23050737380982, 58.84093407661685, 65.69975137710571, 68.4123331500638, 66.46751219226469, 67.37089680087182, 67.47039948740314, 58.76562849167855, 57.40030634787775, 55.99208916387251, 56.67422856053999, 59.416718406061975, 57.9910780537513, 57.366515128843254, 59.26901763485324, 61.88864707946778, 60.40016251225626, 61.02216412944179, 61.61250829696656, 65.84139993113857, 64.57824768558626, 70.4647211874685, 65.33353536359726, 60.558324244714555, 64.70971376665177, 59.60567466674313, 61.412506641880164, 57.45616089913153, 60.86029183480048, 61.391180715253284, 69.36758718182965, 68.8477554628926, 63.31255374416229, 57.94382133791524, 64.1159845936683, 65.77462550132506, 54.25471451974685, 50.78685291351811, 50.63501011940741, 49.012164761943204, 53.501160529352006, 56.002773700221894, 63.40629446891047, 53.002062459145826, 37.1132626072053, 36.50167488282727, 35.83108686631726, 38.09357666200207, 60.421915977231926, 56.567512635261785, 50.475671675897416, 49.93073286548738, 50.83140711630545, 51.56350181948755, 45.620518730532744, 55.862282245389885, 61.77610251211352, 63.74749752783007, 58.495306584142874, 57.56026452587497, 61.65367749429519, 63.069468775103175, 65.2412066921111, 57.58173165782806, 59.45714235305787, 57.18942403793336, 61.982791808343705, 62.390894812922326, 63.69481617404569, 60.61201757000339, 61.319903404481956, 58.418875278965125, 58.020201652280754, 60.15432796170635, 59.0045714378357, 60.237215488187736, 61.43383256850704, 56.99666700055523, 56.08517093043174, 54.49051956976614, 55.34835761593234, 56.29567277046942, 54.70480257464994, 52.93771205409881, 64.0105002926242, 65.8217723907963, 64.41181759680471, 71.63836494568856, 68.62849497026014, 70.75869498714324, 66.62047678424467, 63.1128344997283, 63.85366432128414, 58.78359294706776, 58.44138183901387, 62.15006128434212, 61.62228284343597, 59.69057829149308, 61.9646861476283, 64.76829044280514, 68.01034512058382, 71.40060655532345, 75.36408316704535, 74.90281243478098, 79.9327265831732, 78.91823691706504, 74.61058016746276, 68.4155494936051, 55.270286760022564, 42.100834769587365, 38.69389933924521, 50.57106371848814, 62.493633454845806, 39.78179616312827, 5.070557257821483, 0.8838379058626391, 0.9515310896019783, 73.19139603645571, 89.45271122840144, 85.94554747304609, 87.24786066239881, 60.37878951718731, 57.64479944782873, 76.91116009989094, 55.24707025097263, 0.7988202872295534, 9.130179497503466, 28.27669409013564, 22.22350612763436, 14.729637484396658, 10.154944792870554, 0.6219146508843668, 8.68951983990208], [12.465058046002543, 2.070288509130478, 9.796462712749358, 7.548272898120265, 4.374595428666761, 0.34111866667386026, 15.597882559222562, 40.01440055908696, 34.45158927671371, 18.9953484073762, 34.14743300407164, 46.41157450214509, 61.782025291073715, 43.478422164917, 64.81309959965368, 49.65473528831236, 27.080916397033203, 0.06487994034203791, 0.041037070144328384, 0.04948733404519097, 0.04487678709049379, 0.05684419895612425, 1.7491358710873512, 7.646563081972062, 17.1229540148089, 26.997062006304343, 46.112360415920136, 64.47035897162654, 71.27947591966199, 69.02463866818336, 72.03100988941809, 61.97280153151482, 60.20736625117641, 57.3408353713251, 57.41881601272091, 53.53575583427183, 52.90073587048439, 54.54533469292426, 58.68237226240097, 63.289447061477176, 60.32838706047305, 60.81724774452948, 56.67903346400107, 53.3438499512211, 56.879003740126095, 55.58733194105087, 59.89378452301026, 61.59978020575739, 59.19456712661251, 56.294774547699966, 49.93267443872268, 49.079088241823264, 50.292595048104566, 52.31761278644685, 51.26436618066604, 51.67306930788102, 51.131613562184, 55.35431177385392, 55.6081558042957, 57.24572181701661, 60.69788609781573, 59.7878844507279, 61.39204363669119, 60.71647421006234, 63.812797146458784, 68.35196002837151, 51.776717939684474, 55.23044724618235, 58.98080971933181, 56.92736656435075, 54.445675111586056, 53.27887588931669, 51.40745032218195, 58.790398259316724, 59.86678292674404, 57.19824937082107, 55.25584067067793, 61.34026835041662, 67.71124086072369, 58.992333642898075, 49.34170661434051, 45.99397151700912, 42.99679040908814, 45.632442735856586, 54.07470910779892, 60.5893188138162, 64.60751641181209, 56.20992583613242, 36.620338347650346, 39.88884548987112, 56.39681500773276, 59.43817377090455, 57.49514925864435, 49.64027350948703, 43.10052533303538, 41.755466153544766, 43.78704601718534, 45.390659993694676, 44.899975407508116, 58.49340031223913, 57.44869270632344, 56.819442549059474, 56.08889718209544, 56.74976556531845, 54.9778897531571, 53.51962704812327, 54.007730714736454, 51.55977556782385, 51.9604496032961, 54.99806250295332, 55.09238766085718, 56.60415933978174, 57.94748483165618, 54.52555810251544, 52.742362330036784, 52.336377405351215, 49.8088962031949, 50.69428497745145, 50.25773302201302, 49.2271851724194, 48.5322117805481, 46.13216446292016, 48.11529128782211, 46.86170178074991, 45.5779061009807, 45.24999203220491, 48.66908288771107, 55.5867749644864, 64.50029450078165, 61.54307057780605, 63.11368957642586, 64.97958460161763, 64.96415399735974, 61.92508589836859, 57.113247686816806, 48.16517206930345, 45.305568095176454, 48.08116666732296, 46.821493564113496, 48.356140505883005, 49.908740135931204, 54.591085218614154, 57.15223212395945, 59.24582466002434, 65.37623036292293, 66.32967225966915, 66.50324498453449, 66.74899716531077, 65.03387020480248, 60.97640183664138, 47.499604686614006, 29.25330934985992, 22.90145447177272, 21.205617727771884, 33.62682465584048, 58.49991929146552, 50.90726967780821, 3.009826584208396, 0.789484310775034, 2.159479774775044, 55.93770550143335, 67.00778730453985, 67.36557022217782, 67.2817962400375, 32.53452889380917, 34.39957080348846, 39.67398589657199, 12.442570117212112, 0.4841425323918943, 2.893790371956364, 16.717539794983402, 13.574160183629683, 6.1129148737076795, 0.323704568849456, 2.791191464470279, 10.269459370643863, 25.41225579477126, 38.63507555377099, 12.491040806616507, 12.737982446147551, 7.288404107093812, 1.7641399175890031, 25.240910976163804, 53.193125032609515, 45.04125525874477, 25.777697140170684, 32.92507340831141, 48.10821140966108, 69.77971846057524, 54.918607050372714, 75.626983950215, 64.64169986786382, 35.339351084924516, 0.11878135809374434, 0.11060191393499413, 0.040503830814193335, 0.026698480172443296, 0.1493201431848349, 2.2067990033857288, 8.011093456898967, 18.34268758373876, 34.38147690988357, 58.296983703490234, 66.65472692058933, 73.34771033256285, 72.90434129776494, 72.32336767258184, 65.43576017502816, 63.56810008325885, 58.20542773892803, 60.22059640576763, 56.581295844047304, 59.399546269447576, 58.519711571355025, 63.76324976644209, 65.91196337053853, 65.72716089986986, 64.28100262918781, 57.919953715416696, 54.2951149325217, 58.07686421179003, 58.767860320306596, 62.631375328187026, 64.04314617956838, 62.6112731810539, 58.716783215922696, 52.358699614001864, 51.927333031931234, 53.489165921365064, 53.81546397362986, 56.41332426378804, 53.83680166736726, 55.0892105410176, 59.92138231954267, 58.37604691905361, 62.90199925822597, 62.19859277048419, 63.44367465665264, 62.1479118254877, 62.43155802449873, 63.64680636313654, 67.1142247415358, 56.9719050776574, 57.01405878989928, 60.59298622992731, 59.57295817713584, 55.55782395024454, 55.3295341614754, 54.72234341406054, 62.96210565874654, 64.78505073055145, 60.25614092426916, 59.259380371339866, 63.96537734616188, 67.82225962608092, 59.875129730470725, 50.84142484972554, 48.687298374791304, 46.01861576880179, 46.94741733612553, 53.946380922871256, 63.00469867644772, 65.02538611811977, 61.26697101900655, 40.470380013988866, 45.09839242504489, 60.80037370804818, 62.3571781189211, 60.36230771772323, 50.41181156712194, 45.17022279001052, 45.34688242020146, 46.005966124996064, 47.57818545064619, 44.38110074689312, 60.66924102844731, 60.90956072653494, 59.80551942702263, 58.892658372079175, 58.056514955336056, 56.831099833211596, 56.93808247966152, 55.24159462221208, 55.57879294118574, 53.47614757476315, 57.16078681330527, 59.00235922105851, 61.792176385079664, 61.632877165271395, 57.49488645984281, 54.55386584804904, 54.80213226810579, 51.9434618180798, 53.13963174819947, 51.8418881200975, 51.035456657409675, 49.97023897786295, 47.631996447040194, 50.257831081267334, 47.22988682408487, 49.00582621174474, 49.134836889082386, 51.05450368696644, 59.64255279110324, 66.3077618998866, 61.910318174669825, 63.62468027299451, 65.59179206048289, 68.22157259910338, 67.52766609191895, 63.528491989258804, 53.99683044802759, 50.96664651747673, 52.19520345810921, 51.19212004446214, 53.76326507137668, 55.34991479689076, 58.93336472972747, 62.086636558655776, 65.09639670771938, 70.89723310162945, 73.31346019621819, 73.84626711568525, 73.38389811977264, 73.79279736549624, 71.70081692357218, 62.39719806178924, 42.55269181343817, 30.21089130832303, 30.740540719801384, 45.29931191475161, 67.39203053136026, 56.761022767713, 3.9339374871023245, 0.8222871538131469, 3.2364653002831245, 67.54214748259514, 77.41582009100145, 78.50916508705386, 78.56180329476634, 41.821448264583466, 38.51818892263597, 47.70993394236411, 25.133116399088216, 1.0611472399004045, 5.638265917378088, 17.38354059957689, 18.304873974092548, 7.385129265246853, 0.9580398951807331, 2.9953231301999863, 5.836773149428829, 40.17188764387562, 29.413630347098078, 12.559818586995526, 12.351363243595248, 7.20455805140157, 1.1760415521360215, 33.96162640663886, 74.17913513798868, 60.79197591350925, 41.2998201001075, 50.77106537357454, 67.95627917012861, 77.75297134153305, 66.42961425165977, 84.49104632100752, 80.49489636575022, 43.54472983268, 0.17777848628259477, 0.20845434748597685, 0.20994011372808488, 0.18191738354582943, 0.20011607797876482, 3.385706582377034, 14.944088170605323, 31.97526558752983, 48.32659329137495, 68.02738389661236, 73.51804317966585, 76.14534085796726, 76.52821125522738, 76.59757444935461, 69.93521690368652, 65.46685280338411, 64.91381822093841, 65.39976066158664, 63.059596169379454, 63.31094557239164, 62.41434666418261, 67.75364952702677, 70.88934129284274, 67.40480961338167, 68.9765033414287, 60.71339907184724, 57.22062649265413, 60.90068440283499, 61.06020327537291, 65.61785228790777, 67.8082489198254, 64.2251363108235, 60.15339835997551, 53.522502145459576, 56.1741263635697, 56.66450108251264, 57.583555559958185, 60.112888120835834, 58.78615033242011, 58.45426290265976, 63.584099431191724, 61.42631338488672, 65.85930947334536, 67.56203389936879, 66.95147775834607, 68.62227409116684, 65.79999931396978, 68.94550877232706, 69.64755027524888, 58.438589111451186, 61.1261579298204, 65.69493862890428, 64.58987751314717, 60.24546031028994, 58.79529337729178, 59.2886608646762, 66.03871084028675, 67.19187198146697, 60.356545755940104, 60.93992771640901, 65.68033564475276, 69.72242832183838, 57.961421012878425, 53.06100783809539, 49.6196771437122, 47.37451245707851, 48.87218713760377, 58.70427477744318, 63.889993313820135, 71.93605715228666, 59.445135977960405, 38.49777298588907, 41.87212920957997, 59.88348045656758, 65.37332780899541, 63.18232320970105, 54.62692783724878, 48.888704238399384, 47.33658705988238, 50.17655957129694, 47.72481933716805, 46.217123000852524, 64.14644964279668, 66.15508756329938, 61.69183823370165, 61.5101069788779, 61.35123921978859, 57.24720055057157, 59.43560854081185, 60.182396442659446, 59.30204006933398, 57.12152388788039, 64.09896935186079, 62.26533582133632, 62.7082145598627, 64.46664056470318, 62.21159150523525, 58.34594272798108, 57.24061096868208, 55.31445657053302, 58.04135499462005, 56.50369959492838, 55.04879836113223, 54.177059435075336, 51.715332846487726, 53.775820578298266, 52.707559139497825, 52.91882976408928, 50.49169063568116, 54.12463695772233, 63.721425533294685, 68.90898366128245, 64.8053607633037, 68.70872312976469, 69.4698747511833, 72.88138758751654, 72.62505285201534, 70.33019173529841, 59.746856458725475, 55.202574883737874, 56.22411304904569, 54.51771728454098, 54.23851905330535, 60.03256190207697, 60.70084356492566, 64.7110434501402, 65.86372606215939, 74.84430636129072, 74.16484202108076, 77.33542719194966, 76.48429639877813, 77.69233149866905, 78.99963394288095, 71.32226113350161, 65.90705256308279, 55.643461058216715, 57.05081139841388, 68.2788392036192, 74.29722985913678, 61.917358829129135, 6.305945986701596, 1.4557157384772457, 4.279633866202447, 79.42177511030629, 84.9970163837556, 87.60684382530951, 87.88680691872874, 54.02075690607871, 52.11456344973657, 64.69046669621622, 52.404073592155214, 1.5890263141162935, 17.984630100188717, 41.499472664248565, 35.96132524551884, 22.491458923585956, 4.024595719191336, 5.755336899911204, 28.72187133758299], [19.621537154720677, 1.7672493765431068, 4.64895345510975, 3.011937064509238, 2.1572962403297424, 0.14087707284958134, 19.94240664666699, 44.16154215412755, 37.93764675817182, 24.447142885577296, 39.79041753276702, 52.79021916850921, 61.45981434852847, 53.48086226371027, 66.82487149392405, 60.14256477355958, 39.52377873082315, 2.2673248523666016, 0.1144467943137692, 0.049693292953194156, 0.23610079060158423, 0.106489599922732, 12.383085412363853, 23.54523897171021, 34.213168005789484, 45.74318693530175, 56.70597622471472, 71.07696394766532, 70.33807569934477, 73.26413246893114, 71.44458416969546, 64.42691872196814, 58.551922075210086, 55.25127110942718, 54.307027170735026, 54.916108500572946, 54.47283752502934, 55.632270536115094, 58.21865789351925, 57.98695956507037, 63.108139422632036, 63.038984114123934, 59.66391401906168, 57.12822721850488, 55.168858189736646, 52.70692371552991, 53.23342346375989, 56.0370748273788, 55.22745447774088, 52.97473922852547, 50.4741301844197, 50.6055844983747, 48.58046085603776, 52.1233574036629, 53.90608249172088, 57.70101485713836, 58.543834147914765, 59.509658967295, 59.75793323209209, 62.675878540162124, 61.08943670026718, 61.27727116307905, 59.691429445820475, 60.283287648231756, 61.0324211274424, 57.17267551729756, 57.905550772143954, 59.780447636881185, 55.99173222818683, 55.660613582980254, 53.57065316169493, 51.449945280628825, 48.34548342612482, 56.599495641646854, 60.750791026699936, 57.07212163556007, 57.25112292074389, 62.640757637639204, 58.25418280016992, 54.463470905057854, 48.57858988546556, 43.10700901093022, 42.95391498073455, 47.39967053936374, 52.53724198187552, 57.414775971443426, 57.174111104780636, 62.86882385130852, 59.14647102355958, 60.63550472259522, 59.965697257749504, 59.1794660014491, 56.30671032013432, 50.979315773133315, 42.23201059526013, 40.26691490604032, 41.405841765865205, 48.43467812384329, 41.636179031864295, 51.44780758888491, 60.83705963626985, 58.180959993793124, 56.04679838303597, 56.621355010617165, 51.352195893564534, 49.83046139440229, 50.611828911689024, 49.81759209786692, 48.006547497164824, 48.13984140273064, 57.21261309039209, 57.07620482290945, 56.19334989978422, 56.69791575401061, 55.11758104447396, 50.041775165065644, 50.42383363170009, 47.63763681534798, 45.767121238093225, 44.22326064878895, 44.69740459995885, 43.66884931441277, 44.23510620670934, 45.84711013301727, 46.383686450219926, 47.503562358117875, 47.05632194395989, 52.02129733177924, 63.84478799758419, 61.471444176089385, 62.290701789240686, 62.42641579720282, 61.768551949531805, 59.66614584768973, 54.500498079484515, 52.83963711031022, 44.89691595877371, 44.194513597796046, 45.54428746623378, 47.28298394910751, 51.69610146553286, 55.68230036766299, 57.904695695446385, 65.66554046446278, 65.66263006579491, 68.74047079393941, 66.1808418458508, 65.25987325176116, 66.00500983576622, 64.14479440258395, 55.37674773123957, 43.457127617251494, 37.32052064711048, 38.073847140035326, 54.04459314961588, 72.36976931172033, 66.14099056490006, 10.41662964128679, 0.9226924144933302, 6.260211640788663, 65.54136606954759, 66.12350463867188, 60.121838969569055, 69.22140044550743, 31.26699732195947, 29.373759454296483, 28.06203846008547, 9.525765238269683, 0.5433681463041614, 4.263507531535241, 29.303980488930982, 23.295995881480557, 4.45537370058798, 7.85115243927125, 6.420830738159919, 26.99238261868877, 21.527277577307917, 9.9858102298552, 8.382544363698653, 7.803126448585142, 4.6624199325038544, 0.0683304233356349, 33.372407959353545, 60.71127314721385, 46.94034138033467, 27.558262963448804, 38.93913376715876, 53.397880600344756, 75.07925633461245, 57.956788693704915, 77.61594726193336, 68.82934385730375, 50.91758943373158, 1.8154982068846304, 0.12367402458743704, 0.2649064626424544, 0.1739449210224613, 0.11554937103703139, 6.723768624567217, 18.03846266961867, 39.930618732206284, 50.34415068164949, 66.10922721124464, 73.8032465596353, 73.37129946677916, 76.14466621029761, 75.33714432870188, 68.82680216143208, 60.940523916675204, 60.75889464347594, 59.08195980133549, 59.903406097042954, 57.82640126443679, 60.96732939443281, 62.58648380156487, 66.44245609160393, 66.51157609878048, 66.8252323519799, 61.46564299060453, 57.53403955890287, 55.23729178213305, 54.06668001605619, 57.12094729946506, 58.04685807997181, 57.42759819953673, 55.28945930542485, 52.220051673150834, 54.09231270513227, 51.79690245659121, 54.134238919904156, 58.26684421108615, 63.15815748706941, 61.25071671701247, 62.125542548394975, 65.13488692622032, 65.32039150114983, 64.74254792736423, 65.56690462173955, 64.77312280285743, 63.13695707628804, 63.51304569552022, 59.86850876961986, 60.08290944560882, 63.50519703280542, 58.61489965069679, 57.62269296953755, 55.01224579349641, 51.66123159470097, 51.51829258088143, 60.421919899602095, 64.40787561478155, 60.06784362177695, 60.15607341643303, 65.28767893391272, 55.58062076568604, 55.65358077326129, 50.22512243640039, 46.74708227957449, 45.681880289508456, 48.869072775686945, 54.89135834478564, 59.06972985113821, 61.368360365590746, 62.285477192171165, 60.798518426956676, 63.544824738656324, 59.320604647359545, 59.80318169439993, 56.475536977091146, 52.87967666502922, 46.523248303321104, 43.81591073928341, 45.28210839917583, 50.208624947455625, 44.42818095607143, 50.6231527943765, 65.58503773904616, 60.66237295827558, 58.686192650948804, 60.39814641398769, 54.11832978648525, 50.92603429671257, 53.74915630586686, 52.340856752087994, 49.40731217784267, 48.88444454439225, 60.824202106845, 58.53296526016728, 59.10490566684354, 58.749068244811035, 58.76002342470231, 52.509346085210005, 54.97705821068057, 50.54234804645662, 47.39106485920568, 47.56707337594802, 49.36183229569466, 45.243900591327304, 46.157448061050914, 48.90225994971491, 48.89238734399119, 49.49660885718561, 47.795163123838364, 53.59391281681677, 65.83870134046002, 65.11591049932665, 64.32236794502505, 65.82697345364478, 65.98883398117559, 66.135389420294, 62.74172729061496, 59.337490450951364, 50.76570741591915, 50.89956222041961, 49.784675567380845, 51.7806952230392, 56.686282004079516, 60.53714736815422, 63.83979089798466, 69.0684986114502, 70.13968221602902, 74.94795891546434, 73.32990277198054, 71.65837687830772, 74.66390086758521, 74.58613595654889, 68.73149641098516, 57.495553262772106, 48.23343307741227, 53.78654433834938, 68.1649806422572, 79.02134033941454, 73.10413898960238, 14.586856345976553, 0.99811046113891, 7.654869681404484, 78.35773806418143, 76.79566983253726, 73.93393208903652, 80.02228998368787, 41.28546030290666, 36.10381318676856, 38.008065069875414, 20.93567236777275, 0.5579370548648219, 9.226257954874347, 29.559673916909006, 25.771841041503418, 7.868303002849703, 4.909226740560224, 1.8928380310535433, 16.44875937892545, 61.322688287304295, 6.685285270214082, 6.737234121368778, 5.792695514617428, 3.8612677349198252, 0.22417632562498893, 46.49274795286117, 78.64203929901123, 65.08043266111805, 44.73646748450495, 59.11932822196715, 70.7890070638349, 79.87593066307807, 71.08992345871465, 88.09991713493102, 78.80378215543686, 68.75386961044805, 4.021802991628647, 0.24339759421925394, 0.2563627130321918, 0.5434970942235763, 0.27989154080710105, 17.508009172254994, 44.518619045134514, 65.78123077269524, 65.68850986419186, 77.42507688460812, 75.44813171509774, 77.24999012485628, 75.83894883432697, 77.96587759448637, 71.8342638015747, 66.03569061525407, 64.73169472909743, 63.606719739975475, 64.03320689355174, 62.747528476099816, 67.66291726020076, 67.18113253193518, 69.15057028493574, 70.25927528258293, 70.46328559998544, 65.17785649145803, 62.3894396135884, 56.81427286517236, 57.30693432592577, 59.7903633886768, 61.3047787450975, 60.27858864876532, 56.785051207388605, 55.35044823923419, 58.41116389920635, 53.553775202843454, 58.288942844636985, 61.63309681800104, 66.1625792903285, 63.88776148519209, 65.67875492957332, 66.40129473901564, 70.25605893904164, 68.691817714322, 71.92602372938588, 68.11400551949778, 66.19779432973554, 68.36795545393421, 62.73523184560961, 63.812816758309644, 66.1475330783475, 63.36099893816056, 62.136560486209014, 59.27128868718302, 56.95673727220105, 55.48627991830149, 62.822049587003654, 66.19441324664702, 61.70489972637546, 61.98905191113872, 68.32571152717837, 60.17814851576283, 62.61102607173305, 51.841237006648896, 48.829068522299494, 47.77477856605284, 51.75695703875635, 56.96740219669958, 64.50389523659983, 64.31033019096621, 68.18802848938974, 60.785617751459924, 64.44214536297706, 67.82943756349626, 64.62254301194223, 61.42833732789563, 56.120182006589836, 49.43128570433586, 46.79475476664882, 46.794291926968484, 54.87659454345704, 45.024471436777425, 52.53599074579055, 67.67499816033148, 63.612301272730676, 61.023207479907626, 60.15609695065407, 55.3957006239122, 53.44541972683322, 57.06087227790587, 55.67444386020784, 53.45355080020044, 53.01893257325696, 62.530146798779896, 60.552064141919544, 61.91626841022123, 61.653881457544145, 61.45733541057956, 54.43906199547553, 58.48671267109533, 54.793875678893066, 50.81713753361856, 50.65296673005628, 51.36314322871547, 48.5220959878737, 50.73420293869511, 52.87652700178085, 52.5725237015755, 53.65741598990656, 52.94465464930381, 56.99208174982379, 68.12668261989471, 66.31385726313438, 68.69748946159118, 69.24646439090853, 70.24938306500836, 72.73447913508262, 68.91517316141437, 66.24302710256269, 59.80905348254789, 53.592653735991455, 55.949354940845126, 58.28298084197506, 61.37801724095499, 61.963999732848144, 66.83246520257765, 71.48012084345665, 71.42992234999134, 78.35933054647138, 76.40096956683745, 76.36899440519272, 79.84166483725272, 78.8451474712741, 76.37996919693487, 69.2756389802502, 67.5651482612856, 71.5166537992416, 79.73798874885806, 79.83918589930381, 75.80952321329426, 16.919467333824404, 1.1406344391645924, 8.450651418778206, 86.85695725102579, 83.57134465248355, 85.86066738251718, 87.44715629085418, 53.877700221154, 48.370417933310236, 56.91882364211544, 48.76687149847708, 2.673983689277403, 24.390221449636645, 59.28889620688654, 62.213878247045706, 31.81949846206173, 11.24329366991597, 26.651983645654497, 63.34442692418253], [29.37040190542898, 1.5434477598436418, 2.908447288697766, 1.6629088141264456, 1.17903481087377, 0.28389462600311927, 27.431560600957564, 46.05117928597235, 30.06183339703468, 22.128812266934304, 34.83589918382707, 56.64138263271701, 55.94380086468112, 49.80625252569876, 68.56183036681145, 64.23679359497564, 62.047722724176225, 15.174815712436555, 0.4613493635289131, 0.6839716338342237, 0.0532994756565219, 1.1036285926257412, 3.268750084023322, 25.112890697294667, 57.678221964067035, 69.53414670882687, 66.71565701884609, 67.74844846417828, 72.35331104647729, 71.72420209453952, 69.7671982549852, 67.1215517290177, 60.064984213921335, 52.383857696287095, 54.48004291903589, 52.88839609392228, 53.54712678540138, 52.74482950087517, 57.83501871170537, 59.42220972430322, 62.22787326382053, 64.66451629515618, 59.807778712241884, 56.310589544234745, 52.318444328923384, 53.07170806392547, 52.33289041826802, 54.63749862486317, 51.28196977799939, 50.73323803563272, 49.258905380002915, 49.46566135652604, 49.57153004984702, 54.887514422016764, 55.59927555822558, 61.00714929642216, 62.34068455234651, 63.22315900556503, 62.149857321093165, 61.13509308907294, 62.074461521640906, 64.32759254209458, 62.379166926107104, 60.6218352625447, 61.22395046295659, 60.645985295695645, 62.28849349483367, 60.86186862760975, 59.91402787546958, 56.673357794361735, 52.25216411775159, 50.7675430851598, 48.19812390112108, 54.511033565767356, 58.73679514854186, 55.19803277907833, 59.54216757128316, 57.420800732028106, 47.4309318296371, 47.276178636858546, 45.501961169704316, 43.93478601209579, 41.46461063815702, 47.256806050577474, 48.9463670023026, 50.41310202690863, 54.87636312361687, 48.60597587400868, 53.24189578333209, 52.555430012364546, 48.92212283226752, 53.158557184280895, 46.84842063534645, 50.25786246022871, 46.74613698836296, 40.375321372862786, 40.73400251327023, 48.80371039913547, 46.73371876439741, 46.247941063296416, 56.212859769021314, 56.70126545813776, 58.52260235817202, 55.735150383364775, 51.45464820246543, 47.204850335274976, 46.796817933359456, 45.24357111223283, 44.479979776567035, 43.66487203105804, 51.186212954982636, 61.08848748668548, 54.348694509075536, 57.60609349896831, 53.35753117838214, 54.03364189209477, 52.99036202892181, 50.49554240319037, 47.202979364702784, 45.67532993132069, 45.499588135750066, 45.260425536863266, 43.59630115570561, 44.643393562686065, 47.913916803175404, 47.34238824536724, 48.3603217524867, 47.28282313193045, 58.08008055533133, 63.944459346032914, 65.19023941409203, 64.69326726851925, 60.33834988071073, 58.320035472992934, 55.089791051803104, 52.55520643726472, 45.71245516500166, 45.77395792930357, 46.500035716641335, 48.6527422935732, 50.59786919624575, 56.75247592310752, 63.07048074660763, 66.87651341961276, 68.49183959345665, 70.60115691154235, 67.49791099179176, 67.4091555995326, 66.5939772513605, 65.38446734028479, 58.411085451802904, 52.07499457943825, 49.89347427122055, 54.610018499435924, 66.63007090168615, 72.26362997485747, 80.05210784173782, 24.173806636564194, 1.169615238904953, 9.099018227669502, 64.10599039446923, 63.4478323690353, 56.14099410272414, 65.33549262631324, 23.53988885879517, 24.73745515269618, 20.173106731907016, 1.6395344296770713, 0.5689388129018969, 1.3218071239609874, 37.92151404965309, 40.903727392996515, 25.30098992009317, 12.588569560358602, 19.502385354811146, 55.276236995573974, 20.95002235904817, 3.549360123372847, 5.391002153196643, 3.395314918410394, 2.666813106306138, 0.1348084460703596, 40.427590877779075, 61.35733458303637, 41.08125386699554, 30.935333467298943, 44.44027754568285, 55.55792985423919, 65.83524965470838, 58.88863794265255, 78.89431830375426, 73.31696679515224, 74.09292928634152, 15.648538989405479, 0.3087600933447961, 1.5835288671716568, 0.031516123675711216, 0.41406237189808204, 11.458044417442816, 38.992124988186745, 72.12920250431185, 70.53038166415307, 71.50105845543646, 72.76060212043025, 72.8406027824648, 77.59125201932846, 70.16353807141705, 73.08910062236171, 60.63208441580496, 60.03504476239605, 57.15202816071049, 59.55766093346381, 57.604877564214895, 59.83222292315576, 61.15833313234391, 65.75270729680216, 67.08344198042347, 67.24792265122937, 64.84382352521344, 57.402938258263376, 55.601440706560695, 56.460506454590835, 56.81119772695727, 56.70175183203913, 54.06699380566997, 52.62775459597188, 53.7342748334331, 55.10358210532896, 53.21829095963509, 57.05372571945191, 60.98111260321833, 64.19449475503737, 66.04551223016554, 65.67800967924057, 65.42241627170195, 66.18100658539804, 65.32586712991038, 65.33162124695318, 66.37092774914157, 62.8761665282711, 65.06266824660763, 65.61162748644429, 65.56669673612042, 64.15669095131659, 63.949201491571245, 60.06786323362782, 58.063308500474506, 55.110634526898785, 52.314733766740375, 58.83841199259604, 62.04378074215305, 59.98925501300443, 63.9510920739943, 59.42896796811012, 50.76065932550738, 50.71825850394465, 49.599829950640284, 44.060878446025235, 44.60728030050955, 50.62451777919647, 51.175838285876864, 53.046651963264715, 58.39360344794489, 51.445971919644265, 57.1769783573766, 53.36235569369409, 50.81058325306062, 56.4692533400751, 49.23288829864995, 53.08770741185835, 47.66345777819234, 42.224860114436, 44.653627026465635, 49.2856010313957, 50.34017339829476, 47.23520555803853, 57.878843353640654, 60.02560361739128, 59.77178312117054, 60.05226396745252, 54.324979859013716, 48.53558894126646, 48.558079811834524, 47.2807325086286, 45.206516481214955, 45.91542213193832, 51.48971026943576, 60.631613731384284, 56.87785056329543, 58.762906366778964, 55.834256910508685, 55.57720045889578, 55.41325715280349, 51.70840986313359, 52.05559845893614, 50.769908274373705, 48.146713395272535, 47.71946530188284, 46.236534810835316, 46.597181058699086, 49.03923303850236, 49.52594034133419, 51.66362031813591, 50.13097770752446, 59.26140823671895, 62.991935283907004, 66.66986726945447, 67.63019684822329, 65.02262476951846, 64.34611397404825, 62.82761935264834, 63.449444463176114, 54.48547540172454, 51.105572946609996, 52.31233327619491, 52.7871754092555, 56.370189959003085, 61.88684671155868, 68.45256882329141, 71.35898236305484, 74.62572836106824, 74.72683137462985, 73.73088667469641, 73.41486915465325, 74.63715814775037, 75.21250709410637, 70.1752188897902, 62.976088908410844, 63.53975311402352, 65.8182030339395, 78.02497986824282, 81.5439264235958, 86.55718618823637, 29.970089158704205, 1.2264087075187315, 12.480954431718397, 77.269241117662, 75.03723206058626, 66.24790653105705, 76.7376579776887, 33.927274288669715, 33.27153636563209, 34.80071944575156, 5.648117930658403, 0.49311032699000457, 9.681113650721889, 49.44200946438698, 44.35296558564709, 16.01025898610392, 8.364482829647681, 13.87911661978691, 26.0060183079012, 47.257908236595895, 1.6568621127836167, 4.4930912121649715, 2.4217230706445636, 2.0510594570829026, 0.2904605510975084, 56.5725685704139, 78.63928579515027, 55.30038310635475, 42.677787965343846, 56.26148146967734, 74.54672398105745, 77.74261628427814, 65.95167344616306, 90.57610157997378, 78.56301138477941, 88.33080353275423, 19.095563004093787, 0.4763994672365727, 2.6138110987601744, 0.08064803697409169, 0.8914403785620967, 11.662324397794663, 50.62046597080846, 88.38966261956, 76.14586645557036, 77.7688334065099, 71.81286334991455, 76.11026702388641, 78.39325904846191, 74.3315976665866, 77.4672737429219, 65.21659381927984, 63.72443399121685, 60.81427458793887, 63.39309177091045, 62.15383068207772, 64.07339157596712, 64.4716376643027, 71.89570380795386, 68.70465170952582, 73.30588217704528, 66.06024465253277, 62.576928907825106, 55.56044801588982, 59.13234656856906, 56.961283299230764, 59.70001943649785, 54.648775439108576, 55.05362679881435, 55.14825397922147, 57.560166466620664, 58.14028893747638, 61.217015712491936, 61.44740789167343, 68.59519404749717, 68.29278715195196, 68.35017142757293, 69.94175157239361, 68.97127874435918, 69.49609187341505, 70.1769604221467, 69.56574532293504, 67.7755912657707, 68.045881794345, 66.28094857738864, 69.01565644048875, 69.80211519425916, 67.46315094732469, 63.4273575967358, 58.600967391844726, 60.63543804230229, 56.72671379581575, 62.669853779577444, 65.66155141399753, 60.6628946335085, 64.92729940722066, 64.51892968147033, 51.06716509788267, 50.39918545753726, 51.780585396674375, 47.12613228828677, 48.074686911798295, 55.11101107443533, 54.156184581018266, 55.370707281174205, 60.07777114068309, 54.83296994240054, 57.87135162661153, 56.83239029299829, 55.28832966281522, 59.196500855107466, 50.73683092671057, 56.168411470228634, 52.11353186638125, 45.46162743722239, 46.06261691739483, 52.29158393798336, 50.122030781161406, 48.27920321495303, 61.09540654766945, 61.471640294598, 61.6830050560736, 60.92872934956705, 59.01031771013814, 53.069291883899325, 50.9811592871143, 50.3246957255948, 48.63911597959457, 45.77806072850382, 56.7648196220398, 64.72703495333272, 59.431564577164195, 63.34392486080047, 59.95802510169245, 59.898095207829634, 61.315286774789136, 56.67707227891492, 54.20631639419064, 51.49677053574593, 51.52891043693789, 51.08922058536161, 49.138723957923155, 50.04217132445305, 53.81054532143378, 52.07576728636219, 54.78277537130541, 54.410432615587794, 62.5623220013034, 68.3549645639235, 68.96417925434729, 73.64302558283653, 69.70360878975161, 69.86829342380648, 70.65787438423403, 67.99688354615243, 59.476816961842204, 56.46989660878336, 57.78200787882651, 56.60139014644008, 59.4146042485391, 63.03608548256659, 71.21415276681223, 73.18045262367495, 76.68744379474272, 77.09962214193037, 77.44206859219459, 75.00226805287024, 78.85555744171143, 78.61113886679374, 74.88126293305429, 69.11526110864455, 74.33257825912969, 72.49924675110849, 83.34164281045237, 80.45375070264264, 90.44724387507286, 32.47355172711034, 1.3038565194414509, 13.52893231376525, 87.37837360751244, 80.88099095129198, 79.87430680182673, 83.0038090675108, 52.26836742893342, 41.76739015886861, 56.32040331440588, 26.702556725471254, 3.8847901888432044, 22.370430269548972, 72.48077238759687, 84.4209457212879, 47.166238523298695, 43.63235558232954, 61.35909964961391, 94.22858130547309], [13.531391639863292, 0.42678148455677495, 0.6489828661564858, 0.45475003700102534, 0.1427159596595072, 0.23646610728915662, 33.60972312188918, 51.04140689296108, 38.74126195907593, 22.477752201018795, 28.219943277297485, 63.40155232337214, 70.88325377433532, 46.97965921894197, 70.93836307525635, 66.51036800876741, 58.655386355615434, 17.285791212512603, 0.43538449872885987, 1.5982100535785, 0.31547411855670715, 0.996878530469633, 1.2636685275262403, 21.064065271808257, 52.53493562821419, 74.9232401386384, 71.51626940696471, 71.19611770875993, 71.10716619799214, 71.37677423415646, 69.57152689656904, 67.90666903218916, 59.836564986936516, 54.462243203193914, 53.392534409799886, 52.38567375367688, 51.45757821298415, 52.383375244755904, 55.388091225777906, 58.406947351271114, 61.256007994374926, 62.32465382545226, 61.032997715857725, 55.04917490866877, 54.13836917569561, 51.44202601525092, 51.86261000171785, 52.57430053526356, 51.862398193728545, 51.22920997681157, 51.5440115621013, 49.62133630629509, 51.1878760399357, 57.58288875702889, 59.795081999994096, 62.090382422170336, 62.67494109369094, 64.20470860696608, 60.756462773969105, 61.214615221946474, 62.784610563708895, 60.19524612734395, 59.842719185736875, 63.18539834791615, 62.9668007358428, 62.47136223700739, 60.12550246331, 62.20367616222751, 60.538269166023504, 58.81703507515692, 56.93104966994255, 51.5976538965779, 47.940922321811804, 47.27663363179853, 59.23361432167792, 57.887433344318026, 57.859215813298384, 50.57660210517145, 50.94096675995858, 49.75738763809205, 49.04447332505257, 45.79517402956563, 43.2933686625573, 45.29122398745629, 50.32564101680633, 51.37359242285452, 55.67964100068616, 50.35976171493531, 51.607118575803696, 52.91573109165315, 50.082673718852384, 52.098940649340236, 50.53831977228965, 47.75195037164996, 44.393405222123675, 41.35045397666193, 43.60864485463789, 44.80703484627509, 51.09662994261711, 45.63233290949176, 51.76450760133805, 62.51706177188505, 55.45823889393961, 58.399314418915786, 48.73015026892386, 47.44990433416059, 46.30113232520319, 43.242366083206676, 48.62176733632242, 46.02986512645599, 46.16774036038307, 54.39692789508451, 53.68344483837005, 56.91502678778864, 55.04313838097357, 53.50083497262771, 52.08331392657373, 53.760633160991055, 52.53962286057011, 49.815160228360085, 48.45205030133648, 48.421797060197406, 43.54272942389212, 45.74913717085316, 48.67300918025356, 50.62619263126005, 50.1349667579897, 53.64941827712521, 49.68336074582992, 52.97539818671442, 60.66790350021855, 58.76620115772371, 58.185380504977324, 55.81423321077901, 53.19801622821439, 54.398398783899125, 50.08352095080961, 46.12714775146977, 45.604633131334865, 48.6888437886392, 56.58237057347452, 61.30752048184795, 65.20356370556739, 69.12370989399572, 69.32183665613975, 70.22582530975342, 68.74080027303388, 67.38175392150879, 69.60252931041103, 66.60215147079961, 62.72188794228339, 58.78283200725433, 58.669110728848366, 62.49175071716309, 74.59904055441581, 71.68570795366841, 79.43499349778699, 40.698022611679576, 0.3237584095087744, 12.992493279518621, 72.06653087369858, 59.62540811108005, 58.359937744755904, 61.020446131306315, 20.8600627991461, 18.91954860379619, 12.669642010042745, 4.7285584480531755, 0.34034813543961895, 5.69428030521639, 33.05102855928483, 64.45111974593132, 47.71246779349543, 50.39860494675175, 43.62408330363613, 56.40629537643925, 20.902132180429277, 1.3208591361199657, 1.5492751761790247, 1.635719924684494, 0.633208931934449, 0.7528876164747823, 45.475398878897394, 64.416991203062, 48.11741329008534, 29.041605303364417, 37.00491889830559, 67.99296117598011, 77.61913222651329, 55.80534904233871, 82.4651970401887, 74.37151955020043, 74.33520624714514, 19.3518389040424, 0.32515891016491, 1.1106998906020196, 0.4038678866720969, 1.4781375998450865, 2.3550317460490815, 29.678806104967673, 73.00759377018099, 80.91433894249701, 73.00052565913047, 76.03652646464687, 71.20109127413842, 77.7558974296816, 71.23435297319966, 73.34224254854264, 65.01535269521898, 61.56684798579062, 57.22505484857867, 59.00984310334729, 54.591850080797755, 57.468814465307425, 59.32598221686579, 63.504726348384736, 66.0427273473432, 65.82106636416528, 63.56190666075676, 59.46679922842211, 59.05894725553451, 52.70476248956496, 54.976509078856445, 53.107303573239236, 56.29168372000418, 54.96070977180235, 54.07689779035507, 50.21132353813418, 56.88069428167036, 61.47199330791351, 63.662684117594075, 65.39192376598236, 63.01606178283692, 64.58175036215013, 65.35940339488369, 64.48843717575073, 66.19609986582111, 63.36057532218195, 65.91620737506499, 66.63984544815557, 66.31761489375945, 64.40330213116061, 63.69100755260837, 64.39395120066982, 62.73944839354485, 60.722593107531154, 58.519660580542784, 54.40761635380407, 51.80286445925313, 52.49462150758313, 61.66594666819419, 62.441634593471406, 60.2667470132151, 49.06361841386365, 52.95824958432106, 53.126342758055664, 52.06465521166402, 47.828660165109945, 45.32814525788831, 45.04503250122071, 50.65001710768669, 53.77389469454366, 58.28183943225492, 52.00043816720286, 56.99038728590935, 55.600389511354514, 53.97549275429019, 52.861935784739835, 51.40999986279396, 49.53069033161287, 47.11612632197719, 44.02191754310362, 46.68934891300817, 48.33450863438268, 53.87137736043623, 46.29008693079795, 54.20866981629403, 66.7876168220274, 56.794053046934074, 59.00956461506506, 51.53539411483273, 51.49521335478752, 48.617072259226155, 47.14941547762963, 51.981191096767304, 53.35886086187055, 47.710118293762214, 57.41985151844641, 59.101355921837595, 58.37684316019858, 57.319823234312004, 57.49541990218624, 55.532128503245694, 56.533584133271255, 55.88730304471908, 54.173031160908366, 51.12327068082748, 48.88842575011715, 47.19512285724763, 48.75625364242062, 52.113900569177446, 54.64519823751142, 55.158181498127604, 54.09333252137708, 51.11520236538303, 56.61800922886018, 61.83210219106367, 63.07226150266586, 64.12687309326665, 62.88442311748382, 61.03047170946675, 63.07547392383699, 55.79792399560252, 51.71047302984422, 50.09068712111443, 54.72628539608371, 60.953232396033506, 65.81783433114329, 69.70353818708851, 73.8680362701416, 75.53198414464151, 74.78105421989196, 74.80404715384208, 72.8954767411755, 77.32140079621347, 74.62929771792504, 72.46074476549703, 69.00057100480603, 69.84413162354501, 74.28566671186879, 81.74708166430074, 81.44936592348161, 87.7572431871968, 48.54551253780242, 0.2658510184095752, 14.803824213243301, 83.61864059202134, 68.1609562904604, 68.0431910484068, 73.9102174389747, 33.847226558193086, 28.52876520925953, 19.77104417739376, 7.95206472758324, 0.8719180680571065, 5.873556156312266, 54.024898928980676, 52.88372062867688, 27.329831969353464, 25.244317554658462, 16.16791473280999, 49.29264560822518, 17.605940949532297, 0.7206092678731488, 1.0053114424790106, 0.9435379733481716, 0.6512018245074057, 0.5092031682931608, 63.21617326428814, 82.7403199288153, 63.571241901766875, 38.17763697716498, 47.713989673122285, 79.0085377231721, 91.84056389716365, 63.42870296970491, 92.95421108122795, 79.37534993694675, 84.1813987301242, 27.886875214115268, 0.5211180724924611, 3.6511154761237488, 0.3117103285847172, 1.8639020934220285, 11.491502235012671, 47.72605096140216, 82.69758178341775, 81.75288677215576, 80.07910943800404, 76.87166967699605, 75.7234428774926, 79.8721573429723, 76.58915704296481, 76.15068312614196, 69.79680430504584, 64.9345754038903, 62.65756499382758, 64.27840209776356, 58.85198339339226, 61.054390322777536, 63.45522211443994, 67.67693581119661, 68.77792158434468, 68.70651875772785, 65.8467500440536, 60.392843369514715, 62.58339297386908, 55.45919987463183, 54.60330732407109, 59.18281962794643, 57.46540200325751, 56.45509750612321, 58.20117981203141, 54.02937043097712, 58.79365382655975, 63.37093430180704, 67.97276881433302, 67.55199263172766, 67.10998073700937, 67.28026651567029, 68.83628645250874, 67.76489103994062, 68.89983669404062, 68.06244204121252, 69.93918634230091, 70.87464024943691, 67.94790098744055, 67.38367588289323, 66.32189812198763, 69.0499379557948, 67.5162676841982, 63.41165634893603, 63.80486611397036, 58.43809881517964, 57.37517572218373, 54.86880471629482, 64.7798575124433, 64.79959880152057, 63.844529121152824, 53.78710915965419, 52.897107678074995, 55.35917943523776, 53.41053416652065, 51.61256674797305, 48.10933320753036, 49.1521070849511, 55.92726022966447, 58.12015148901171, 61.59685019523867, 53.79039610585859, 57.22557260144142, 59.390328699542636, 55.27715875256447, 56.95997322759321, 55.87807370770363, 52.82626967276297, 50.00200625388853, 46.91195910976779, 47.64815268977996, 50.517484141934304, 56.95667059190812, 47.42629166572325, 52.548303065761445, 64.20618341815087, 60.506176333273615, 63.9820081956925, 55.624974927594586, 54.44890714460804, 53.28534387773084, 48.362969352353005, 50.883292228944846, 55.10308396431708, 53.79618552423293, 61.89484050196987, 60.697333043621434, 60.87185498206847, 60.95936306061284, 61.079316985222604, 58.5190918368678, 61.35792293856221, 58.579970944312315, 56.2282354600968, 53.52704032774895, 54.8041287545235, 49.20178390318348, 52.22096166303081, 54.738613405535304, 56.860854933338786, 55.757468669645256, 57.98364516227477, 54.28034720882293, 59.085395797606445, 64.39561428562288, 67.38984969354445, 68.07764514800041, 67.76518129533338, 67.60473282106462, 69.19759165856146, 61.04832633849114, 55.684967579380164, 52.17800386490361, 56.64295550315612, 66.07205098675144, 67.60668616141042, 73.0290569797639, 74.82333737034952, 77.10550569718885, 75.41932582855225, 75.5274812636837, 76.4238291402017, 78.5319854367164, 77.20785602446526, 75.31596352977138, 73.35597084414574, 75.19001622353831, 79.02055586538008, 86.51662103591427, 81.01428093448763, 87.47889611028856, 52.81300029447002, 0.3997374470195463, 17.41380953019665, 90.80284595489503, 75.60514419309555, 80.54426331673899, 82.19362781893823, 46.5309557607097, 41.109122307069846, 45.985640402763124, 28.65998810337436, 4.631870552416771, 16.380788626209384, 61.61052750002954, 85.99958204453992, 75.2494950448313, 90.59282656638854, 77.44507312774658, 82.54336987772297], [0.5905779775592589, 0.22179808227285264, 0.2231612744470758, 0.013107130446681573, 0.08459019519749188, 0.24426639921242194, 32.961990756373254, 50.78365618182767, 41.09739834262479, 24.80495325980648, 42.544752936209406, 31.525077512187345, 48.411547906937145, 51.600536838654556, 69.7402358824207, 69.32191510354319, 66.33678743916174, 15.657389817699311, 0.49780286067435825, 1.0213639262703158, 0.19090198611299838, 1.1826913178928438, 0.5367348054724356, 23.55431337510386, 68.82468408153903, 79.41769584532707, 68.30019258683728, 74.92210265128844, 69.20207100529825, 71.21718083658527, 69.54512150056901, 70.27006964529716, 61.830125316496826, 57.42824146824499, 53.69649456393335, 52.83425169606363, 51.99588821780298, 52.47697868654805, 54.83794743014921, 57.77999962529829, 60.670319680244695, 59.49154546183925, 61.23082245549848, 59.09899465499386, 56.74079510473437, 52.46860050385999, 52.630453186650435, 51.76198159494708, 50.41621246645528, 51.702051701084265, 49.69418256513534, 49.32706832885743, 55.26760385882471, 59.68983304116034, 61.89683698838758, 61.942799322066776, 60.12541224879604, 60.05577841112691, 61.30692035921159, 63.19896190397201, 60.44203381384573, 63.7185896596601, 62.21792221069337, 61.72394675593223, 61.1768388748169, 62.458818497196326, 61.876444585861705, 61.639317697094334, 63.10382089307232, 61.184538487465154, 53.72432378030593, 50.45762092836442, 47.031599244763775, 46.88561647169052, 56.92872370443037, 62.54902124404908, 55.60139363811862, 52.762876326038, 48.89770215557468, 48.5186952929343, 49.40688071712371, 48.30152934597385, 43.54434544040311, 45.641483799103774, 47.125928325037805, 52.54336872408467, 53.915417732730994, 54.941654897505245, 58.12869441124701, 55.97417569929554, 54.74963526571951, 51.78984219028104, 50.39673789854973, 47.951387205431544, 42.437178011863466, 41.252194681475245, 46.27919450882943, 52.35063129855741, 50.13202498036046, 46.8442472334831, 45.093234508268296, 57.84435787508565, 56.07399217544064, 50.68505171806582, 46.131846750936205, 48.5383189109064, 47.26586280330535, 54.19522000897316, 54.38467833303637, 57.90704127280944, 51.28766113711942, 52.488596746998454, 56.02766113896524, 59.465296960646114, 54.59990662913169, 58.3623460800417, 52.7242527469512, 55.467927148265225, 51.97531930861935, 53.98328258145241, 53.31092557599468, 53.242562586261386, 45.94594993898946, 46.8256865778277, 48.55293758453862, 53.717271358736106, 61.61500684676632, 58.51762879279352, 58.11492689194218, 54.53156717361943, 57.43818859900198, 61.783362819302475, 57.976220115538574, 56.69320890980383, 56.208823650114006, 55.405063321513516, 53.768905439684474, 46.22242212295533, 47.48195794320876, 51.48054369034306, 57.99097607212683, 66.27560630921396, 68.07663317649596, 68.61741819689351, 70.82813662867393, 68.17307641429286, 69.04876908948346, 69.28805720421576, 68.10670991097727, 66.41394830519154, 62.948326372331195, 62.64648429809078, 63.23776983445691, 63.67047786712647, 76.37545062649635, 75.39115536597468, 82.96275754128733, 48.5711609163592, 0.531032721121465, 16.64970828640846, 74.9967061319659, 60.0124675996842, 58.694621824449115, 48.441373609727435, 23.090959864277995, 15.645604075924044, 7.408709574130274, 1.5982712180383745, 1.5435320908023467, 4.324787211033606, 7.850632725223419, 61.179435483870975, 57.68665113756734, 46.44550300413563, 58.31803506420505, 35.0257928909794, 4.783040660042917, 0.16044619132674512, 0.31988350614424677, 0.35866226400098494, 0.0758462897952526, 0.3616676882149712, 46.83633581284554, 63.249109406625074, 52.69017911726429, 31.133558288697277, 43.250571681607155, 37.51059086092057, 56.86762102188603, 59.16662808387511, 80.53165681900518, 75.96801050247686, 78.99502908029865, 18.792477538508756, 0.2790559840298468, 1.7335549910222332, 0.3181171218954748, 1.879447549581528, 2.0349332449897646, 34.78147629768618, 82.10515483733147, 80.40495641769903, 70.95676683610486, 76.69640248821628, 70.47228351716073, 76.94351180907219, 73.74774502169701, 75.44383279738888, 66.13782128980084, 64.67123139289119, 57.873473628874756, 58.59865711581323, 54.69834243097613, 57.73993653635825, 57.77852089174333, 62.79050196370771, 64.36841657084804, 63.19757730730119, 63.36858087970365, 62.221832813755164, 59.60472153079126, 56.139782090340894, 54.115093831093084, 55.643374766072924, 53.525334096723995, 54.55130454032652, 52.3800882985515, 52.87726832974342, 59.98764684123378, 60.674281274118734, 63.868349675209295, 64.44352995964789, 63.24013110130065, 63.638134002685554, 64.53397197108116, 64.95342239256829, 64.63122321713355, 67.46232724958851, 66.34336917631089, 63.66748509868499, 66.4592203017204, 64.13112102016326, 64.52884543326594, 63.267289592373764, 64.45120996044528, 61.956225595166615, 57.94948916281424, 53.42144227796986, 50.442759067781516, 48.57534608533306, 60.536912025943884, 66.19856311428931, 61.5572028775369, 51.48403852216659, 50.87865598740117, 50.30652730695663, 52.11651286771221, 49.458381437486224, 45.35968111407372, 46.2436931363998, 49.37601166386759, 53.37409534761983, 56.30033646860431, 58.85239131989018, 58.19877147674561, 57.48905389539657, 55.81216219932803, 53.434731268113666, 52.74753593629407, 48.26565142600767, 45.615505941452525, 43.23525090371409, 50.11160904361356, 52.22728060137842, 52.36009597778321, 44.71718119036767, 44.78737592697144, 56.777955639746885, 58.07979029993857, 51.86313559932094, 48.64719606214955, 50.959119489116055, 50.1862282137717, 59.014385208006836, 56.90258110723188, 63.59565865608954, 56.739033960526996, 55.27784124497445, 60.386367536360225, 60.552597584262976, 56.61840538824759, 58.65894394536173, 57.11367130279542, 58.18113257808071, 55.20193553739979, 56.88394984891338, 55.5251153053776, 52.32684212346231, 49.57593487155054, 50.6845025862417, 52.6451503076861, 55.47888232815651, 65.00871604488742, 61.5099226274798, 60.26716278445337, 59.04390496592368, 59.71784268656085, 64.03533281818514, 65.27583729836249, 66.0543610972743, 63.43679874174057, 63.350706638828406, 60.04647062670801, 51.97886513125513, 51.796702415712424, 57.101409973636756, 62.78883887875465, 70.40095913794734, 73.12273102421915, 72.95222559282857, 75.63913545300885, 74.53381153845018, 74.59275691739975, 77.10326994619062, 75.37727017556468, 75.91783554323258, 72.10354235864455, 71.76770902449086, 71.45802220990582, 74.90012168884277, 80.16439745503088, 82.80814555383499, 86.86823014290103, 56.34737745408089, 0.5698289457828768, 18.821312842830537, 81.22684986360612, 71.27320012738629, 69.72741757669758, 61.43301279314103, 31.52125124008425, 23.65445148560309, 13.54919331689035, 0.986092993088307, 1.5187925989589386, 1.5756006538867953, 43.23626287521855, 65.91968259503766, 53.40412893602925, 39.395701577586514, 42.46179088469475, 57.92058913938461, 0.7677668825753274, 0.25465223788013386, 0.30853593601815166, 0.23985918731458727, 0.19141008626789818, 0.3661352371977222, 62.52939370370681, 80.32716797244164, 65.5457434346599, 43.83186694114439, 65.31850484109694, 45.591136255571925, 66.14740756250197, 65.59266282666114, 90.4716645517657, 81.350584953062, 90.54301246520012, 26.00839722541071, 0.8754909182748488, 3.6812096161227075, 0.48763687391915633, 2.6854330878103934, 22.66229775644118, 56.548116514759684, 92.81957180269303, 76.24367467818722, 75.33492426718436, 77.12069311449605, 77.12687476988762, 79.61112360800468, 76.92141317552137, 77.96645810527187, 71.16239317001836, 67.25886606401014, 62.0085931593372, 62.893809349306174, 57.33088039582776, 60.733003077968476, 60.45251046457599, 65.81032691463348, 66.80866426037204, 66.13098852096066, 65.04210325979417, 65.88746424644225, 61.48185414652671, 58.64209344310146, 56.2994029445033, 58.081657348140595, 54.635941443904755, 56.89461869578208, 54.49530486137637, 56.436670211053666, 63.2637986829204, 64.80567455291748, 68.45698541210544, 67.98990957198605, 66.81169233014508, 66.81126086942612, 68.79874152521934, 69.60299215009137, 68.66217244055964, 71.20477830210041, 68.55624491168608, 68.39008546644642, 67.85993791395619, 67.85133223379812, 66.72504717303862, 67.07578551384711, 68.73847822989188, 65.65900187338552, 59.873184234865256, 57.214013376543605, 55.37150744468936, 51.657983872198294, 62.71496103655908, 67.48411209352555, 62.0816316143159, 55.44700522576609, 50.75160649514968, 52.064804261730565, 54.987311286311, 52.04474133829917, 48.48690056031751, 51.43849195972566, 52.995143398161865, 56.56688113366404, 58.18075210817399, 61.42366186265023, 60.44010793009112, 60.978033542633064, 59.76514254846881, 56.47629007216423, 56.3359712016198, 53.329882391037486, 47.876332652184274, 45.5454327983241, 52.138591889412176, 56.67406382099275, 55.1547102005251, 44.54729549346432, 45.20295889146867, 57.13618962995468, 62.219067542783684, 56.00846113697175, 57.145003195731874, 56.117228461850075, 51.961288990512976, 60.75867891311646, 62.93429213185465, 64.04807659887499, 58.74951931738085, 58.54458332061768, 62.915252947038226, 65.91121027546545, 60.915914966214096, 64.63299220608127, 60.370736891223544, 61.33729127145583, 55.99252454696163, 60.737941342015425, 60.087251509389574, 58.91473347140897, 51.75011250280565, 53.67048924969089, 56.79507678554904, 59.055232770981334, 67.3067738932948, 64.53121062247985, 62.14200865837836, 60.70232622085079, 62.039073897946274, 67.56993355289583, 68.44217454233478, 71.85264402820219, 69.14672636216687, 68.69848574361494, 64.84792632441368, 55.3677184351029, 54.74645030113959, 58.01438085494503, 65.76737696124663, 71.71531400372906, 74.7668238609068, 74.3222624255765, 78.12876578300231, 73.89488097160094, 75.94481360527777, 79.22104389436784, 77.11196191849248, 79.37224341977027, 72.75424003601074, 74.32262328363235, 75.3621768951416, 74.86838971414875, 82.17720877739691, 82.25133372891335, 87.68435770465483, 59.315380050290024, 0.7186083687889961, 21.013815787530717, 91.92584406945014, 76.80387543093774, 80.82053938219624, 69.58047774530226, 48.133589144675966, 37.533532804058446, 37.11302334262479, 20.42638594104398, 4.868217379816117, 7.887963883338436, 41.210123339006984, 79.53237025968491, 82.89700292771863, 66.36433816725209, 76.97447499921246, 47.865275490668516], [0.04211124798823749, 0.047502446198655714, 0.014954686499080591, 0.06585554565272986, 0.06810929971717058, 0.12984986537166182, 39.40793545015397, 56.070109028970045, 41.64533384384648, 26.676155251841394, 40.591683233937914, 22.365013476341, 42.594335617557654, 45.63769086714714, 73.79187168613558, 66.27744982319494, 78.70029434081047, 20.822731641031083, 0.3404383805970992, 0.880220132249017, 0.36882880233949233, 4.819498110202051, 12.4475731003669, 32.969494250512895, 73.86679680116715, 73.82833403925743, 68.34475855673513, 67.44143670605075, 66.13476184106642, 71.14125943952992, 67.8416596689532, 66.66304234535464, 61.75882054913429, 59.198783674547755, 54.403388038758315, 53.98666366454094, 50.94465378792056, 51.30761423418599, 52.346579490169404, 55.86902087734592, 60.51382103273946, 61.064659087888664, 59.94865063698062, 57.82356146843203, 59.47689540924565, 53.96913459224086, 50.83766721910047, 51.12992302063973, 52.712336586367705, 52.32538692412838, 49.36182837332449, 50.80610782869401, 55.63210971893803, 59.622705598031324, 60.05170699088805, 64.127928210843, 60.4669604762908, 60.33819690827401, 62.58794292326897, 63.49305337475192, 62.61816086307649, 62.163605228547134, 60.54449788985714, 63.882611413155836, 58.23347268566009, 60.878389650775546, 58.68465508184126, 59.61170727206815, 58.37299139268937, 62.01054257731285, 58.040633278508345, 54.42223894980646, 42.97464078472507, 53.92564335177022, 58.48945440784578, 59.34859075853902, 59.59513133571994, 49.70214889895532, 50.27695263585737, 45.16242904047812, 46.816927925232925, 48.30715794717112, 43.8476074126459, 44.45763403369535, 45.06429526113695, 50.216022537600615, 50.3424483729947, 53.46776546970491, 58.44670841770788, 58.084418696741906, 51.26400532261018, 53.20482546283353, 51.57260564065749, 43.786806752604825, 44.08298100194624, 42.384053430249615, 46.9709554795296, 45.43541815973098, 45.03426951746787, 49.27126869078606, 37.58064046982796, 33.23747842542587, 51.462281134820756, 46.40203922025619, 43.57819157262003, 45.10881808496291, 51.40145694055865, 54.57235197867117, 53.660094968734256, 56.956486240510024, 58.9948949506206, 58.0167656560098, 57.00071488657306, 60.24333830802672, 55.092521021443034, 55.61355690802298, 55.804199787878225, 59.09139702397009, 57.07110966405561, 54.217102912164506, 53.7053708876333, 52.445737008125555, 50.568663227942686, 48.344655806018466, 48.15704884067659, 52.22159708699873, 60.11264493388515, 59.519888508704405, 61.512715355042495, 63.265453923133116, 61.342955173984656, 58.53231022434851, 63.12134604300223, 59.143960706649295, 59.127757395467455, 57.183152168027824, 51.72073002784483, 48.42407595726752, 48.439337899608, 54.3884555755123, 60.99491150148454, 67.43066587755757, 72.53850183179303, 67.65501760667371, 67.86276202048025, 68.39291741771083, 68.95745631187194, 68.6615134823707, 69.56341543505269, 70.25554903091924, 66.18078693266838, 62.127550801923206, 65.37046447876962, 67.96866601513278, 76.08950984093451, 76.08964320152037, 83.3171985995385, 53.46026197556527, 0.731149779692773, 18.040298338859312, 80.00121901112219, 60.68299678064162, 49.463209875168346, 47.543750962903424, 24.78771640408424, 12.944051027297975, 7.432134459095617, 5.314422778544888, 4.087913805438626, 0.6424988205394437, 2.268445424495205, 29.32888165596993, 51.76332304554602, 48.64891013791485, 38.58045262675132, 3.0806408101512543, 0.8385785957497935, 0.13518226633389152, 0.05985016709253673, 0.11657128636274608, 0.058749689450187076, 0.0740661389464813, 50.09074203429684, 68.8422013867286, 50.51205558161582, 31.50219636578714, 42.301169826138405, 26.173007334432295, 52.27364693918536, 50.88104863320628, 86.43043871848815, 73.3491616095266, 90.38467422608407, 25.102967100758708, 0.5492442858315284, 2.6559503472620443, 1.3907527082389401, 5.102909457299018, 12.64006635835094, 41.97119651302215, 84.627929195281, 78.47507969025644, 70.1828282879245, 71.94967562152495, 73.61647113676995, 77.97691514415126, 70.85738182067871, 71.4454863148351, 66.85794491921702, 63.77633087096676, 60.14446712309315, 59.93655796973937, 53.770364561388575, 56.72971833136774, 55.727678268186516, 60.213065455036784, 62.46033253208284, 64.22363012067734, 61.41829213788433, 60.214775608431914, 59.522649857305716, 57.14022967123217, 53.40486241925148, 52.631861317542295, 54.43188405806019, 53.94774590769122, 52.1728341810165, 53.629025874599336, 60.314341052885986, 61.019340022917724, 63.010386113197576, 66.26943249856272, 63.66887754009616, 64.2882433245259, 66.06893662483462, 66.01993837664205, 66.84017658233643, 64.41295508415469, 65.00848854741743, 64.85116227980583, 62.68322513949487, 63.35478590380762, 61.32455533550632, 60.15447308940273, 59.85077181170064, 64.13671039765882, 60.60676551634266, 57.12540311198081, 46.98366788125808, 57.60900389763617, 59.851493527812345, 62.45067957908877, 60.922963465413744, 50.51133386550411, 49.885688366428504, 45.730964829844815, 49.03213747086064, 51.01035348830685, 47.318042093707675, 46.96262828765377, 49.308429225798584, 51.60555355010494, 54.4966031659034, 55.68135115408129, 60.29894967232982, 58.970011434247425, 55.158663949658795, 54.924153281796364, 53.622981502163796, 45.657796936650435, 45.06657023583689, 44.374185608279326, 48.292386301102184, 46.92734656795379, 47.16446168961064, 47.33033087945754, 40.073043915533255, 35.88174819946289, 50.33160694183842, 48.225870747720045, 47.03684737605434, 47.6307765899166, 56.59854642806515, 56.93239504291166, 59.369649963994185, 59.5947979342553, 59.635523903754454, 62.135524980483524, 57.741654534493726, 59.44381021684217, 59.19873660610568, 57.31708541993172, 59.24775446614912, 60.33349006406723, 58.32675449309811, 58.76923707223708, 56.62530483738069, 55.095725597873816, 52.595528402636134, 52.10752671764743, 50.59580995190529, 52.90041815850043, 60.50563112381966, 63.187367377742646, 63.72701098842006, 67.24542802379978, 62.25735772040583, 63.347694258536066, 67.22879717426916, 67.02824638735864, 62.94929519776375, 64.01525420527305, 56.971924689508256, 52.93200500549809, 53.27751482686689, 59.92492814217845, 64.61090926201113, 72.38578827150407, 74.51001844098492, 72.71334540459418, 70.75678087049916, 74.4661271187567, 74.33880698296332, 77.21410828251993, 76.1728209833945, 78.41247866230627, 72.53734865496236, 71.30905059076125, 70.08687142402896, 75.11679341716152, 81.14672368572604, 82.67786795093168, 86.37190911077684, 59.327704137371434, 0.8698235223850898, 21.069333014949677, 88.34576345259144, 69.99054585733722, 59.10650207150368, 61.73548636897918, 36.83291119913901, 21.925170652328, 8.822779424728887, 7.884682820689294, 7.1405155524130794, 3.1905306683432673, 20.960012635877057, 59.74258499760782, 63.74241805845692, 57.743188181231105, 62.323218237969186, 18.431662628727576, 0.3029680702715151, 0.10607679344473347, 0.08652819846306117, 0.17014512491803016, 0.13568572399597015, 0.3203412896442798, 59.514004953445934, 86.82411132320281, 64.6352122675988, 52.03347629116428, 62.833585277680434, 34.698129853894635, 60.68207502365113, 61.734305735557314, 92.25545652451055, 80.44021852554815, 93.7716644041, 31.123652342827093, 1.0499654205576068, 5.839676193652615, 1.9719427992259304, 7.678188172078903, 43.019089083517756, 61.272140702893665, 85.295375393283, 73.68474391198927, 74.00889642776983, 72.17244271309146, 79.33338057610297, 78.99768844727548, 75.27041696733045, 72.3631718850905, 72.13849852162024, 66.68251299089002, 64.2949741117416, 61.08731469800396, 57.4356076794286, 58.43554927456764, 60.20327129671651, 62.27938575129356, 65.38571465399959, 68.95737786446848, 66.35617179255333, 62.423823110518924, 61.73798884114912, 59.17047592901415, 55.15936605391964, 55.561201110962905, 57.828546800921046, 57.39956501991519, 54.307650827592425, 56.07436087823684, 62.37367560786586, 65.60525755728445, 64.50293817827779, 69.8463987535046, 66.27999936380695, 65.40911551444762, 72.06257712456488, 69.38071143242621, 69.57770855196061, 65.99680423736572, 65.46539368168001, 69.34890885506907, 64.3465611242479, 65.95566641899848, 65.57714985262963, 64.73520917277183, 63.12302873980615, 66.69672766039449, 63.40900482669954, 59.86346852394843, 52.78983085386215, 60.131303648794855, 63.115788044468054, 67.12964750105336, 60.587616505161414, 54.10868075586135, 52.41346374634774, 48.7898212863553, 49.85607839399769, 55.60178587513586, 47.298751877200225, 48.72067382258754, 53.23118771276167, 55.59952266754643, 55.53076351842573, 61.20433076735466, 61.74673964900356, 63.01998415300923, 56.43816463408932, 57.87205765324255, 57.386338787694136, 48.99412578152072, 47.851978655784364, 45.919352346850985, 52.03017365547919, 49.74949190693517, 52.38206517311835, 48.84483252802203, 39.69262107726067, 35.11616037737939, 54.12812002243535, 54.07974150873, 52.015900150422134, 51.30094228252288, 53.968385419537945, 63.33553098863172, 60.824837530812914, 64.5641859885185, 61.79097221743677, 65.30359983444214, 60.56422741182389, 64.5653901561614, 60.664471426317775, 60.94584657299904, 62.88453294384865, 65.07918142503308, 63.30472077092817, 61.38806243096629, 60.34983458057527, 57.31886617598995, 56.28007350429412, 55.34482748277726, 53.65681978964037, 55.97568188944171, 63.27270638558173, 64.3707739153216, 63.82936916043682, 68.76900995931318, 65.38466738116357, 65.03170897883754, 71.87800607373639, 71.40423082536267, 67.11709591650194, 67.28399276733398, 59.68229424568915, 57.17961811250257, 54.60557837640086, 62.88798855197046, 65.77226423448133, 74.42133365138885, 76.25999173810406, 73.10619431157266, 71.64507219868322, 74.5942238838442, 74.76323881456929, 77.60308973250851, 79.12252964511995, 80.16994368645453, 74.69749204574093, 71.007781182566, 73.97688204242338, 77.42539851896225, 84.95275635873118, 82.88777751307335, 88.678019585148, 62.73300393935173, 0.7699293955679863, 22.961301995861916, 99.26998015372985, 73.64674398975988, 71.1086174749559, 71.33359678329961, 54.284049926265595, 37.24319504153344, 29.308746168690345, 21.971433047325384, 8.983913333185258, 5.513238406950428, 24.306431778015632, 59.555844876074026, 70.70888873069518, 70.51447253073417, 54.96522049750052, 7.008227734796463], [0.0892189673839077, 0.09821334523299048, 0.0928068329249659, 0.0938523207761107, 0.04325245469508152, 0.09928359304584804, 27.290408226751513, 58.60972996680968, 47.20188502342471, 22.54613284141787, 41.87392565511888, 22.893672489350845, 43.884524760707734, 51.71346972065588, 66.55179608252742, 70.81494962015461, 74.93129668697235, 35.560564917902795, 0.06038062935394626, 0.6610112432991305, 0.486220132199026, 14.276198744773867, 40.404648934641195, 49.99702876613986, 74.75566079539638, 67.98444178796584, 68.07498578102359, 65.22947488292571, 67.37477210260207, 65.03796123689222, 64.90289049763834, 62.279185710414765, 61.17561901769331, 57.09921736871043, 54.31110643571424, 54.463647411715606, 53.60435416621547, 50.2759563538336, 51.579540391122144, 52.93298559804117, 55.68332018390779, 58.21679869005757, 58.01448283656951, 57.86127113526868, 55.15194492955362, 56.170961010840635, 52.11975666784471, 51.23803138732911, 50.398440207204516, 51.55517854998189, 51.80330376471243, 50.913443488459436, 55.16255886323991, 59.57979486834619, 59.26716627613191, 63.13660798534271, 61.07201745433193, 60.6990667312376, 61.5812470066932, 61.998979430044855, 60.440213834085775, 61.454546605387044, 59.55165186235982, 61.24113436668151, 58.126952878890506, 57.624505104557166, 54.791435964645885, 59.07679403981855, 56.67021205348354, 58.938314760884936, 59.159132434475815, 54.401320949677505, 48.520283852854085, 56.035180322585575, 59.742914476702296, 51.9299021843941, 44.305085212953635, 50.5345856758856, 48.55609509252733, 46.780791128835375, 46.27078886955015, 48.9423583399865, 45.16138176764212, 45.304709096108716, 44.732050895690925, 44.63930253059634, 48.91894963479812, 46.93820761096093, 50.059225789962284, 51.867156028747566, 45.97090798039591, 46.74288142111994, 46.44728376019386, 42.40726993929955, 41.07207159842215, 43.19017894806401, 43.32851702167142, 44.010099441774436, 41.163698165647446, 46.66076660156251, 45.169485384418124, 33.81232530839982, 36.72386146360828, 42.63943502979894, 39.803463335960146, 48.985402430257494, 50.60716129118397, 53.25166640743133, 62.45564137735675, 57.26024243139452, 56.077149683429354, 56.23404841269217, 56.69730386426372, 55.95815281714163, 58.39133239561512, 57.292190136448035, 56.47537223754391, 57.91049688093124, 56.6540361988929, 57.72096795420493, 59.40537491152364, 55.43208452963061, 53.71299205287811, 49.485159458652625, 48.36108269230012, 51.08778892024871, 58.758874170241825, 63.05990211425289, 63.831797107573486, 63.22811295909267, 62.76317088834701, 64.76049277090257, 64.48031786949404, 57.42425241777974, 58.42781436058783, 58.524183073351466, 52.99620636047856, 48.5699136026444, 49.62183836967715, 56.286039429326216, 63.244092695174686, 66.78851896716704, 68.16733406436059, 67.071549354061, 69.70400102676885, 71.12984534232848, 69.45456966277092, 68.24031368378671, 68.11697083134806, 66.46999113021359, 66.8121551698254, 65.20723896641886, 66.10926643494638, 71.5506293696742, 75.84900579144879, 76.64225024561729, 79.30881869408393, 48.648874836583296, 0.8652884044474172, 23.819689173852247, 74.7288239386774, 63.521914174479825, 41.86286064886278, 39.771197918922674, 26.800564988966915, 13.363736790995445, 6.4488957870391115, 7.595256518933081, 2.338232724897323, 1.9019811984992798, 2.0220410271037013, 14.712807574579793, 25.157297811200543, 28.87440839121419, 7.659439242655232, 0.11691998660324082, 0.06700483075673543, 0.014384839657483803, 0.02811452666778238, 0.049174226249658295, 0.007291226497580929, 0.09156056108974642, 33.26702171756376, 70.96228953330748, 55.57137181681972, 27.727372031058035, 43.01095408778037, 27.367159205098307, 54.97612860894973, 56.76504319713962, 77.0659838953326, 79.15805847414079, 82.8155823676817, 42.45307537817186, 0.10473179585871198, 0.4445965221572307, 0.6998000522294353, 16.240425629000512, 42.72786486533381, 59.95358105628722, 88.17488931840467, 75.1866037614884, 72.58178910901471, 71.02685174634381, 72.02855448569022, 69.94348526000977, 70.31622809748497, 67.75424572729295, 64.84369408699774, 62.917586757290756, 59.204239691457445, 58.92399026501564, 56.81591633827456, 56.933308955161806, 56.12251581684236, 55.74256366299045, 59.74768407883183, 61.530883773680664, 60.78752794573384, 61.41959828715171, 58.41553341957831, 59.60636108152328, 54.61956162606516, 53.144083638345045, 52.95537840935492, 54.8343349272205, 55.48178488208402, 52.89246359179097, 57.810115583481334, 62.30816025887767, 62.70293112724059, 64.92003517766153, 64.33289950893771, 62.74372377703267, 62.86741179804649, 63.881611208761896, 62.904756684457105, 64.39242147630262, 61.91392675522835, 62.25491408378848, 61.14442440771288, 60.374529823180175, 58.40875948629072, 60.894314473675145, 60.30333880455264, 61.64051009762672, 59.742632066049886, 56.90632304837627, 51.0042542026889, 59.268582251764116, 62.14329127342471, 53.963874693839784, 47.81099773222401, 52.052303667991396, 52.56321983952677, 49.42379005493657, 49.06475590121362, 49.21177025764219, 47.2993363103559, 46.474948237019206, 46.56438612168836, 48.48488838441911, 47.40382432937623, 48.147870494473366, 50.866751593928186, 53.173179780283284, 47.83142543608143, 47.01473697539299, 47.19665650398501, 45.24970569918233, 43.073178568193995, 46.3915390353049, 47.545261075419766, 44.22076602135935, 43.072570600817286, 48.17805705531951, 43.65659582999445, 35.369341527262044, 38.470508590821304, 44.17895747769264, 43.954958761892016, 50.30615075942009, 55.21226706043367, 55.83879509279805, 62.862410776076786, 61.03860278283397, 57.91818080409881, 58.5771115364567, 59.59480185662547, 56.89818020789855, 60.480751529816665, 59.1391558031882, 59.05810786831764, 61.100458560451386, 58.51906438027659, 58.494839822092366, 61.29590242139755, 60.99578226766279, 56.15703267435874, 52.099654520711596, 48.90759437314926, 53.09746626884707, 60.87198049791398, 67.55101988392492, 66.65321288570281, 68.06874136770925, 65.33923456745764, 69.56563549657022, 67.9943810739825, 65.0469748435482, 63.59788263997724, 64.95977663224744, 58.752441483159224, 53.80177490172848, 54.017677845493445, 59.72509514900946, 67.94842658504363, 70.70247957783361, 71.50338049857848, 73.53818847287086, 71.68311134461435, 75.20153230236423, 73.53538005582749, 75.99149765506868, 74.7552607136388, 72.86652180456346, 74.00773540619882, 70.92913766061106, 71.0232117868239, 77.40291549313453, 80.72828523574337, 82.57643545827558, 85.35432077223255, 54.827004017368445, 0.6556971671600497, 27.454310347956998, 83.81960715017011, 72.15458808406707, 52.11197860779301, 51.82883839453421, 38.97194047128001, 19.445734562412387, 8.607140260358012, 7.913292588726168, 6.281324288537426, 4.396155226615168, 7.356209139670096, 39.3299195074266, 50.512447818633056, 50.955283411087535, 23.76304622619383, 0.6750849526255362, 0.17011811265782004, 0.20592596622244005, 0.13826788463179143, 0.19603529614546608, 0.0981365679012191, 0.246531491378142, 40.34445231960666, 86.2339436623358, 70.3065476878997, 49.87362315577846, 68.65089954868441, 36.354758585653, 59.562516827737134, 70.61458710701235, 79.85416150862171, 84.9251820964198, 86.75102972215223, 52.269822628267356, 0.21370935824609574, 5.572979536748702, 1.425356103047248, 19.054721324674546, 66.10983125625118, 71.01821468722436, 83.42085899845247, 73.53563108751851, 72.71540072656447, 73.20256694670647, 77.54825499749954, 72.79709585251348, 70.49130701249646, 68.80338561150336, 66.84773106728831, 65.17072562248477, 61.1191172753611, 62.55671301195699, 62.05395929275021, 57.752044893080196, 59.21334351262739, 58.75364172843195, 61.49709647701633, 64.6293757807824, 64.03002977371216, 64.33537452451645, 60.69787040833504, 61.81173332275883, 57.58838399764031, 55.3639921834392, 56.097495017513154, 56.745368588355284, 58.43699662916122, 57.26780868345692, 58.90587283718971, 63.95216288105134, 65.39385357210713, 67.99346323936217, 67.65157376566242, 66.14865487621677, 66.1497139161633, 66.63018857279133, 64.11427444027316, 66.86889617673813, 62.78280235105946, 65.06422150519587, 64.46750348614108, 64.55592939930578, 62.75886020352764, 63.39445283336025, 62.97921503743818, 63.58401313904793, 65.134788866966, 62.80830952429003, 59.77628207975819, 62.84774503400249, 63.846313799581225, 56.44695466564548, 50.816631547866336, 53.949201107025154, 55.73779798323109, 48.8736697935289, 49.95659697440363, 51.75406232956917, 50.34498614649619, 49.626356940115656, 50.60955001461891, 49.38939086852535, 53.98334926174533, 50.73015113030711, 55.42527529501147, 57.86962970610588, 51.579901249178, 51.24630366602252, 51.09180934967534, 48.028618674124445, 46.47710946298415, 48.20669035757742, 50.333744633582334, 48.27238613559354, 44.86215983667682, 49.887629939663796, 46.296668667947095, 35.8982966792199, 37.68941171707646, 49.44892460300077, 49.762349436360026, 52.486027594535585, 56.987402362208215, 58.755826488617934, 65.12462600584954, 64.21804074318179, 60.76057341790969, 61.12924483514602, 61.84994505297754, 61.3178284706608, 62.3915655382218, 60.06840059834143, 61.335843916862245, 64.82877731323242, 62.65646673017933, 63.458481604053134, 66.32535765247961, 64.45849380185528, 59.4055082721095, 53.97893267293131, 53.049021074848795, 54.23254920590309, 64.17593017701181, 69.62281580894225, 68.28520913277903, 68.25306923158708, 68.39250164647257, 72.34720783848917, 71.76526146550333, 65.55567879830637, 65.36369839022237, 66.99898550587316, 62.582620266945135, 56.580581972675944, 57.466033504855254, 61.221228338057, 71.04683230000158, 73.08073028441399, 74.39339068628128, 74.14299441922095, 73.6199071330409, 77.25919200528052, 75.32163527704056, 75.03167013968192, 76.00233908622496, 73.7443325596471, 75.31053496945289, 72.64954413137129, 73.901870635248, 79.54943256993448, 83.78507460317304, 83.50381712759696, 85.80024719238283, 58.099908136552386, 0.8974832801088211, 28.994483909299298, 91.18039761820148, 77.98712115133964, 63.70231182344499, 61.57743838525588, 56.38866040014452, 36.761680956809755, 31.601575497658025, 28.55854384360775, 2.5923027819202793, 6.643593417059991, 16.308090436843134, 43.2719172200849, 42.82222140219904, 50.675186957082445, 11.2929351868168, 0.22160738766674073], [0.09488964212998267, 0.09864688205022006, 0.022294363269822735, 0.14674832473599142, 0.10190028892529589, 0.6223004527630345, 20.87751734641291, 47.656475959285615, 36.073481498226045, 21.02700279605004, 47.78725170320081, 24.419809849031513, 45.97132767400434, 50.6827453644045, 63.84312099026096, 73.03573285379719, 70.49764556269493, 52.00090885162354, 0.28343834403541784, 1.4305534886737026, 0.640755694720053, 26.164627190559145, 72.95173137418686, 67.24078393751576, 75.46310732441565, 66.98685753730037, 68.15486877195298, 63.16033832488522, 65.56493559191304, 63.11114003581386, 63.29888820648194, 59.52520332028789, 63.202111567220385, 57.60953733997961, 55.56315052893854, 50.6935985626713, 52.916790131599676, 53.012707771793494, 53.5647774511768, 51.30471560262865, 54.004039764404304, 53.43557850007088, 56.32943653291272, 57.72984427790488, 56.561734983997965, 56.3795958026763, 54.27405964943671, 51.770693179099794, 51.02113216154037, 51.13507701504616, 51.681000340369444, 48.921452106968054, 54.56136149744834, 60.62162345455539, 58.827978487937685, 62.38556823422832, 62.91875170123193, 61.94872602339714, 60.104686444805516, 60.62656171860234, 61.18262437082107, 60.64407510142173, 61.17104553407239, 59.40177025333528, 55.05698042531168, 53.23959727441111, 52.503925369631865, 53.248657949509166, 54.94553804397584, 58.1259330626457, 56.13880934253816, 53.59459138685658, 43.737812426782426, 56.51146196549939, 61.76633188801428, 48.42194611026395, 46.578032047517844, 52.83091768141716, 53.9043370369942, 49.38992431086879, 46.25802547700944, 46.85829716344034, 45.14911259374311, 45.20322953501056, 43.320134916613185, 44.56585614911972, 41.57988909752139, 44.47286067470428, 45.28515608079972, 45.7779352126583, 44.74271189781928, 42.407658253946614, 43.74641418457032, 43.818221015314904, 45.078898245288485, 43.179117864178075, 46.00236538917788, 43.36223763804282, 44.94483555516889, 48.55744831023678, 49.03757779828964, 37.335484489317864, 38.67385602766468, 39.34479313512003, 39.56605795891055, 47.27790447973436, 52.386116981506355, 59.07757459148284, 55.22149639744913, 56.844239773288855, 53.75930347750264, 56.713240454273844, 57.16583490371705, 56.29708482373146, 52.89767249937981, 59.118649651927335, 56.08716741684945, 58.21979538086922, 59.069816143282004, 59.16346273114605, 55.571363972079375, 58.010772274386504, 55.53781986236573, 54.57071242793914, 47.94215786841608, 49.42141702098232, 57.11172580718995, 60.30198166447302, 63.50877815677274, 62.62500147665701, 65.46195768540906, 60.69168875294348, 59.59075004823747, 61.279295106087964, 61.573668987520286, 58.769699911917414, 51.86227267788303, 45.706324500422326, 49.500762647198094, 55.57794570922852, 63.23785220423053, 67.45940900618031, 70.83631084811303, 70.38978038295623, 71.48081118060698, 70.99162101745605, 71.07616378415015, 71.82993350490447, 70.97794763503536, 70.49411542953985, 66.35438319175475, 65.33034647664716, 68.56784728265578, 72.2271676217356, 76.73411215505293, 76.4829392586985, 78.7916620316044, 40.52233965166154, 0.39533780407040353, 29.895160121302453, 75.47482736649053, 55.01704285221716, 38.23549193720664, 39.65976730469735, 23.130505200355287, 11.881057331638953, 3.3259053912854966, 8.01332969819346, 6.975999580275628, 1.7497393032235486, 2.313565919476171, 10.158191534780688, 15.015931283274005, 4.030660929218415, 0.21385151352132523, 0.0646827799538451, 0.06410144562382372, 0.06291788574608584, 0.017965449388289166, 0.18679722572766966, 0.24096469815459945, 0.44456241592284174, 25.30687543653673, 64.72000214361375, 49.44872456212198, 25.982391911168254, 67.74071355019846, 28.40479869996348, 54.36935363277313, 59.322640357478974, 70.98181509202527, 82.72920393174695, 79.30007965334, 64.20084114997618, 0.08917298678669239, 1.165277710364711, 1.0341672166701288, 29.279804960373912, 81.13358374564879, 77.39900096770256, 82.32354456378569, 72.27719353091332, 75.1757937092935, 69.38683817463537, 70.45144788680538, 68.0870117679719, 70.45204408707158, 66.26092880002915, 66.4721013653663, 62.88996934890748, 60.4007234111909, 55.45277895465974, 57.37964722418017, 58.7354576203131, 57.915074286922334, 55.51733724532589, 57.7386696107926, 57.32420844416465, 61.03931665420533, 60.38149203023603, 59.718136864323775, 58.41938518708753, 57.089215324771025, 55.51040249486124, 53.6040952897841, 52.71930271579374, 50.39327836805775, 51.320675726859804, 54.44188610199959, 62.480744546459576, 60.054409503936775, 64.14499836583292, 64.65393374043127, 64.3066627748551, 64.12613961004442, 63.15771033686977, 63.3123105572116, 61.49859090005199, 63.891291618347175, 60.9993790811108, 60.440904171236106, 56.502440514103064, 53.72245673210391, 54.404494147146906, 56.07944426998016, 59.544932842254646, 58.645972667201875, 58.909183317615145, 46.93975302480882, 57.82699354233281, 63.287580013275154, 49.538072232277166, 50.27795284025131, 56.105139716979004, 54.62527651940623, 49.99290635508876, 48.39738815061508, 47.5231114510567, 48.01429417825515, 46.045523228183875, 46.22547372694939, 46.959823792980565, 44.860237875292384, 47.80750290040047, 49.01098805089151, 48.99880909150647, 46.426228477108864, 44.88690607009396, 45.21651068041402, 45.63769478951731, 48.80025871338383, 45.504530322167184, 47.93333645789854, 45.607841630135816, 46.54525672235797, 49.03565191453504, 48.982088027461884, 41.53831197369484, 39.685674559685495, 41.09797493104012, 44.324838269141416, 49.64674149790118, 54.67757348091372, 60.91582475170013, 57.89427788026872, 56.617609147102606, 55.33854384576121, 57.2998034569525, 59.26644848239038, 61.223828869481245, 57.736076924108694, 59.223831930468165, 55.787553248866914, 60.4091251281, 59.60981668964509, 61.58735021468132, 61.08235289973598, 59.14969913421139, 57.87468171888783, 58.10111622656546, 49.45009739168229, 52.34965070601433, 59.22061166455669, 61.970793277986594, 65.61940946886617, 65.7514835173084, 66.43028105458906, 63.10157337496358, 63.70388861625426, 63.33733135654081, 66.4552822420674, 64.87296673559374, 57.32987626906365, 52.07408458955827, 53.36081420221637, 58.279654672068936, 67.55385183518933, 71.35089443575951, 73.66797185713246, 74.01485058569139, 76.13933963160362, 75.16419918306413, 75.97577679541804, 75.43065363360991, 76.33899611811485, 75.18982794977005, 74.17503233878844, 70.95106370987432, 73.56062443025651, 77.47278859538417, 84.90809625194919, 81.73331414499592, 82.7511299810102, 44.123452017384196, 0.1437103111417063, 35.02323158325688, 84.08988198926373, 64.47292420171922, 48.211001042396795, 50.642439088513775, 38.87519521097983, 20.027884898647187, 9.797897319639883, 5.4070137585363085, 14.191697162966575, 2.443799150566901, 2.3692954451807084, 19.311428685342115, 23.673524010565973, 13.628198677493682, 1.3241474306391132, 0.07591999511444762, 0.1919119657888528, 0.24824510749068954, 0.13628474346572353, 0.3983784070418727, 0.296257262628886, 0.658384113302154, 27.50538156878564, 78.28711971159905, 62.34025701399773, 48.1036889168524, 78.28889262291693, 38.987041596443426, 63.85968123712848, 69.37440426118913, 77.24383200368574, 89.96295667463734, 83.76435664392288, 68.8798326061618, 0.5871105410398976, 5.406726935217458, 2.377774383752577, 29.77050719722625, 78.44637578533542, 76.10023360098563, 79.39686805971208, 74.34986806684925, 76.17182470137074, 72.54206334390949, 71.81534228786346, 69.27920049236667, 72.38578042676373, 69.07570008308657, 69.74466816071542, 65.87818391861455, 62.64463293936945, 57.62939630016204, 58.94997204503706, 59.74907259787283, 61.35064694189257, 58.399639975640085, 63.58146359843593, 59.61650433078889, 62.788713362909135, 64.28678420282179, 61.58888778378887, 60.43624439547139, 62.36091221532514, 56.985637295630674, 57.00191905421596, 54.726579573846635, 55.76828264421033, 53.83279300505116, 57.41301874960623, 66.57026260129868, 63.9073968702747, 68.54621148878529, 68.93446337792182, 64.41809338908043, 67.38041247090986, 64.11976968088459, 65.76820850372314, 66.8029454446608, 67.95436505348452, 63.779849237011334, 62.166382266629135, 58.995824552351436, 59.33661184003277, 58.50813273460635, 61.36327305147725, 63.0505080376902, 60.4071835548647, 64.20288862720614, 54.218922891924464, 61.022281800546956, 65.65328698004446, 49.91113278173631, 51.78476664327806, 59.16129758281093, 57.21599025111045, 53.00893052931755, 51.22938648346932, 51.39097244508805, 51.743448395882886, 48.66217559383762, 46.933755720815356, 50.37487460720924, 48.61855883752146, 53.00665163224744, 52.78439444880332, 50.7546071083315, 50.53511911822904, 46.00759783098775, 49.00090755954866, 48.25414711429227, 50.94104520736202, 46.392099934239546, 51.317322100362475, 47.195601386408654, 50.42501426512196, 53.11506594381025, 52.19909444932015, 41.83876945126442, 38.341042918543664, 42.99283665995444, 48.32143929696853, 55.03716853357131, 54.661095603819824, 64.39032300826042, 60.0302908497472, 60.22860196328933, 59.98896083524151, 59.64700860361899, 61.375334339757124, 64.13394120431715, 61.234027031929266, 65.28060297812185, 60.34676336473035, 63.90289006694671, 63.92420814883325, 64.28756475448608, 63.97814858344294, 62.30294742891866, 59.81325826337261, 59.742561463386785, 52.36839179069766, 55.87996429012668, 62.4633135334138, 65.46121243507632, 68.11053029952511, 67.07786437003844, 66.66108900500883, 64.20030378526258, 65.43715261643933, 65.9207102560228, 69.47447176902526, 65.97898098730272, 60.34904226180046, 53.87677454179334, 54.61236015442879, 60.00938069435858, 68.61987360062139, 74.18718384158227, 74.01417593802176, 74.10564561044016, 76.15775908193281, 75.53844036594515, 74.77646504679035, 76.97123512145012, 76.33296351278983, 76.58577595987629, 73.47364194931524, 71.80086874192762, 74.52973227347098, 78.50695287027668, 85.63953984168269, 82.12720640244024, 83.39473601310485, 47.94801396708335, 0.6012741584450968, 37.66791320616199, 93.17142409663047, 68.83917331695557, 60.90861151295324, 63.31091027106009, 53.76367692024478, 39.38547203617711, 29.588350365238806, 35.71871096088041, 11.771298627699576, 4.216174819777089, 9.10187469374749, 25.164263940626576, 20.494701862335205, 7.6747340348459065, 0.294380224640331, 0.15491419381672336], [0.13489004975605395, 0.028233641848689126, 0.045309917881123485, 0.14357204759313216, 0.26194715692150977, 0.8357000050525513, 12.266322335889264, 35.44574537584859, 35.18715135512814, 19.444510782918623, 20.605801036280972, 32.143150875645304, 47.653620473800174, 45.91436701436197, 58.01533006852674, 74.16232385943013, 71.79961358347248, 53.138360900263635, 0.9459206293667517, 0.7168926382737776, 2.178519695035873, 37.12627310906687, 78.28503301066738, 73.27359322578677, 75.35295148049632, 66.27459433770949, 66.7929434007214, 61.92630575549219, 62.522859034999726, 59.42861887716479, 59.51360487168836, 58.97569102625693, 60.09881073428739, 55.1458691781567, 55.34344288610644, 52.516461264702585, 52.3814062149294, 51.050110632373446, 52.69717270328153, 52.2927410371842, 52.86955694998465, 53.1982554927949, 54.014469346692486, 55.78634123648367, 55.49308915292063, 56.046935665992, 53.842018419696444, 52.545894730475645, 48.16743135452271, 47.961589290249734, 50.78325217769992, 50.449250590416696, 49.07243197964084, 56.836751968629905, 60.6535162464265, 62.0272950203188, 60.4776567797507, 60.66102366293631, 59.26960599037909, 59.81679231889787, 58.15546851004324, 58.79420688075405, 56.741642336691584, 57.2691422893155, 53.299719364412375, 50.68896232112762, 52.05510031792426, 50.64166245921966, 50.98043364863242, 52.20660971057031, 55.54036548060756, 55.51967497794859, 41.19821502316383, 57.75354716085619, 52.837844587141475, 47.99919305309173, 54.20394336023639, 50.364927476452245, 51.018845419729914, 49.40211111499418, 44.61718428519465, 45.864497999991144, 48.17399740219117, 43.86591703661027, 44.52094108827653, 44.59246943073888, 44.21695739992204, 44.23865595171529, 44.95866975476665, 41.05570747006325, 41.481519975969874, 41.86214677749142, 44.86891023574337, 43.40217128876717, 45.10304435606926, 44.36576035714919, 45.22791693287511, 42.26029088420253, 44.86221474985923, 45.158079131957024, 47.4592552646514, 43.65451305143295, 44.84366978368452, 36.52972767429967, 37.370723062945956, 51.67477946127615, 59.69220607511459, 58.55954716282507, 56.39575204541607, 55.95146517599783, 52.226876597250666, 55.27708030516102, 56.23873564504809, 60.369807289492705, 58.62721981540803, 58.46700276097944, 56.7281376161883, 57.97437267918741, 53.85452293580579, 60.09153473761774, 61.532488023081136, 58.62823570928266, 59.1955751757468, 54.91470821442143, 49.27584609677715, 47.85312791024485, 52.016951345628314, 61.083949304396114, 63.53989431934973, 62.02365898316907, 55.024754231975926, 58.62874169503489, 64.32568234782066, 59.68473003756616, 60.01502890740672, 54.81385231018067, 52.03988936639602, 49.7204859795109, 53.746583231033824, 58.483464948592655, 62.06095680113762, 68.06907869154408, 67.12807070824408, 69.97763341472995, 68.83518034412016, 68.97954710068242, 73.43981542894917, 71.78556365351524, 72.33887672424316, 70.88479134344286, 70.06562786717569, 67.60689012465939, 67.78185921330606, 71.4674751220211, 74.56917562792378, 78.6181285304408, 75.7385596921367, 28.79713377644939, 0.11251556326545055, 40.65692009464387, 70.8981901599515, 57.69634723663331, 36.68470836454822, 35.33351459810811, 31.238018851126398, 16.38870789158729, 6.860795155648263, 4.53755961310479, 16.13851852955357, 2.0290995773769196, 0.5500940305571402, 1.1679380579340843, 0.8641306923762445, 0.13042072344931865, 0.15549580776883712, 0.038115375510026375, 0.07383390705311492, 0.0450996995242613, 0.13212893098112077, 0.1789521789478679, 0.2676661258503314, 0.4505119773168718, 15.531782777078691, 52.40581120214155, 48.71767713177589, 19.84763041619332, 36.828145519379646, 34.04790678331929, 55.024597337169034, 53.24232332168087, 65.8593879207488, 83.09906774951567, 79.31846772470783, 60.47252239719514, 0.9797519914084866, 1.221920412874991, 1.859077332961944, 43.98752227906258, 88.67989447809036, 82.25489524102981, 80.92253669615715, 74.95542710827243, 70.66542886918592, 69.25325009130663, 68.41362753222066, 64.90849556461458, 65.95058302725515, 63.87493925709879, 63.82383861849385, 59.58669431747929, 58.903464501903905, 56.44187127390216, 55.90170598799183, 55.72033951359411, 55.95255951727591, 55.91391240396808, 55.96090239863242, 55.93964315229847, 58.43980112383443, 58.778270290743926, 56.90630343652541, 58.70846779115739, 55.85862267401911, 55.38888354455271, 51.35573779383014, 50.88952879751883, 52.84948618181291, 52.58321608266523, 53.629167079925544, 59.36664150607202, 61.288493064142045, 65.9563018429664, 64.10073049606817, 62.303982934644154, 63.76557573195427, 65.5134113373295, 60.57123276495165, 60.55438226269138, 60.24548384451098, 58.293653611213934, 56.298700840242454, 53.566303253173835, 52.75919714281636, 52.75261932803739, 53.69103854702365, 54.53378723513696, 59.00928220441265, 58.37398767471314, 46.11010897544123, 58.54830172754104, 50.83996572802144, 49.43212509155274, 56.15127071257561, 52.327732501491425, 53.53556363813339, 51.13356298015964, 49.56526994705201, 48.51127809093845, 47.97813384763656, 46.11199955786429, 48.00752024496756, 46.514513184947354, 45.39006379342849, 45.615831498176824, 46.44314958203224, 43.15799982317033, 46.52952801796698, 42.93393834944695, 46.71371075414842, 46.33777902972314, 45.49124917676372, 44.82391672749674, 45.84163058188654, 46.16522612110261, 47.74500385407479, 47.81713231917351, 49.448363704066125, 45.15321539294335, 45.924722071616884, 39.48886571391937, 39.574377306046024, 57.06428081758561, 60.847300944789765, 60.03037321952082, 57.453838855989524, 57.04392763876147, 53.37072603164181, 55.79344464886574, 57.773406121038626, 61.20560553766067, 61.61926261840328, 62.897304181129705, 59.65642621440273, 61.30393935788063, 57.4351958305605, 59.992847904082275, 64.18208437581217, 60.69917655760243, 63.31564457185807, 59.69036648350378, 53.79561678055794, 49.670197271531634, 52.96287798112439, 60.67150423603674, 65.94159295482021, 62.751129211918006, 57.40577020952779, 61.77272535139515, 67.14543111862676, 63.831495085070216, 64.08022042243712, 58.460770114775634, 56.40503629561394, 53.74060553889121, 56.98364473158314, 62.1560860449268, 69.15055459545505, 71.7904587714903, 70.98072467311736, 72.01878778396114, 71.83495413872504, 74.59953477305751, 77.67865811624836, 75.10425752209079, 77.02527753768429, 75.21046746161677, 76.5147889044977, 71.09907827069684, 72.82481916489141, 75.22148147706064, 83.16323772553476, 83.89912143830331, 82.64084862124535, 29.182479189288234, 0.17733061596030192, 44.93827342987061, 81.11319526549309, 64.08656289500576, 46.255256283667784, 46.22224561629757, 47.99256032513034, 23.826192463597945, 15.361437182272635, 4.692841345264066, 23.093405462080433, 2.78603085106419, 0.8107253548599059, 7.441158361973302, 6.33448907444554, 0.9323300457289143, 0.148554514913309, 0.06343012660621636, 0.24482576597121455, 0.15392862170213653, 0.21081846417678943, 0.23988958568342272, 0.27741327701557067, 0.8472308540536512, 16.04565739631653, 68.69705015613188, 64.75237738701605, 41.62538466915008, 45.133148547141786, 50.4267087290364, 68.0402728049986, 63.35171861033287, 73.45384182468538, 88.447525424342, 83.8481306260632, 67.5140005542386, 1.0439200675295246, 2.6354302225574373, 4.448732147293707, 42.657693662951075, 80.74420221390264, 77.76332639878797, 78.6193758441556, 75.9308107437626, 71.807387721154, 70.5911470228626, 69.78662967681885, 67.20534924537905, 68.27310469842726, 67.46903450258317, 66.18313251003143, 61.73989511305287, 61.219439737258426, 59.923869102231926, 57.44430749647079, 55.744634674441436, 59.61115421787385, 59.48737598234608, 58.81837652575586, 58.976914805750695, 59.955785428324056, 63.95954870408582, 61.93922604283979, 63.952908131384085, 59.28342450049616, 58.476494896796446, 55.53089687901159, 52.33731877419257, 56.58754025736163, 54.891632910697695, 55.16954068214663, 62.869596558232466, 66.20925549537905, 68.47691889732116, 66.47993826097058, 63.76424604846586, 64.03408550447034, 67.43405480538645, 63.044459742884484, 62.88362687633884, 63.01346517378285, 62.90292885995681, 59.306876351756436, 55.16721079426428, 56.806141791805146, 54.50305546483686, 54.94966045502694, 57.74145057124477, 63.003792608937914, 62.406623517313314, 50.88938366982245, 61.669072797221524, 54.971037372466064, 52.85824875677786, 58.72731477983537, 56.77216622137255, 56.590799746974824, 55.5248172052445, 50.554793727013376, 51.35302743604107, 52.87645247674758, 48.870143582743985, 49.491596068105395, 50.46219833435551, 49.36151850608088, 48.500621011180264, 51.00491708324802, 46.177950289941606, 47.98580600369362, 47.48586854627056, 49.702772555812714, 47.43878833709225, 49.423244845482614, 48.640426051232126, 48.99165076594199, 48.45623547031034, 49.6560335928394, 51.923693072411325, 53.06344755234257, 46.07984788956181, 45.05150441200503, 41.80827302317466, 45.952225731265166, 58.93253318725094, 62.23637303998394, 62.706986857998764, 61.47404470751363, 63.01230415221184, 57.75754797843195, 59.49156115131994, 61.747245634755785, 63.976614936705566, 62.0363635401572, 64.64774816266953, 63.08613100359517, 65.33280972511538, 62.10374985971759, 63.84929480091218, 68.45179219399729, 63.49649329339305, 64.49264195657545, 61.16318902661724, 54.660558239106216, 52.97400966767342, 56.42728397923132, 64.65151363803496, 68.5461251966415, 65.04379380133845, 59.59739846567954, 62.32328491826212, 69.14655377787929, 63.629681294964215, 65.84712659159015, 59.23049603739093, 58.43375675139889, 55.920278410757746, 58.34499351439938, 65.35334725533762, 68.0733540750319, 71.77733452089372, 73.16916404231903, 73.19382006122221, 71.09142180412047, 76.49686367281022, 78.1842908551616, 77.2974508039413, 78.10335666902604, 78.19813682186988, 76.39241879986179, 73.7205316174415, 73.29933181885751, 76.9412446791126, 83.95475633682744, 83.98936733122795, 82.55097927585726, 32.85165644461109, 0.18679397751487073, 48.23672002361667, 87.60216836006411, 71.98475730034613, 57.41344628795501, 58.974490780984205, 66.13072964452928, 44.79098450752997, 37.65233747420773, 39.975631852303785, 35.28009976110151, 3.768364436203434, 1.896853312369316, 5.1155713585115254, 1.9909542823030104, 0.3814358210131046, 0.18141922721218678, 0.2434437433558126], [0.060132164057464375, 0.005320523247768682, 0.09664464997307909, 0.13234813937977438, 0.11971075298084367, 0.42585390529805617, 5.58443138676305, 28.452098561871438, 27.258013371498357, 26.598600187609275, 33.130303582837506, 27.804207340363536, 51.04085776113695, 56.200947530807994, 48.98726163371917, 69.77701202515634, 70.61015482871764, 59.61012263451854, 1.9580426547796497, 0.7259935176660939, 2.224703887777944, 44.307105233592374, 68.3483200688516, 77.73071581317534, 71.27560846267208, 69.59484146487328, 62.966635996295565, 64.77663724653183, 62.688500727376635, 59.488352652518984, 61.289367752690474, 59.17735184392622, 58.92502577074113, 56.85654424851941, 55.823486082015506, 52.67776481566891, 52.72098541259766, 52.28173094411051, 51.66813496620425, 50.91780516409105, 53.66932822811989, 52.24150311562323, 51.610789914284986, 52.584314346313484, 53.58207902600689, 54.45549672649753, 51.155598855787716, 53.536920778213016, 48.13560916531471, 47.93932591715167, 49.89550605896981, 49.13886908561953, 53.03294327951247, 58.60245004776986, 60.30996368777368, 59.64463949203492, 61.70840240293934, 61.36443799541843, 60.35350199668639, 59.40259395107147, 61.05698300946144, 57.924499742446415, 55.405867407398844, 50.73964326612411, 49.93089368266445, 51.32950890448786, 48.27991316395421, 48.606787804634344, 50.04584266293434, 51.4780725971345, 56.2108358260124, 53.93724964511011, 46.71412260301652, 46.62476708812099, 41.438252310599054, 49.243372794120546, 49.36593901726508, 44.584204996785815, 45.34294043817828, 46.61488663765692, 47.797673440748646, 44.944957148644235, 44.89360547834828, 47.26846725709977, 43.68233442306519, 45.02968426673643, 43.14358903515724, 44.70349604083646, 44.58794301556003, 45.75982955194289, 46.04908474030034, 42.271736360365345, 44.515602742472005, 43.85812720944805, 45.35908099143736, 45.413139097152225, 44.579192207705596, 44.45370774115286, 47.5262846485261, 43.24330352967785, 44.424160526644805, 44.23908349006407, 50.14003053788216, 49.517354273026996, 37.168948496541674, 50.980064945836226, 56.32666341720089, 57.40328734920871, 53.56731522467829, 52.04102685374599, 51.70893938310685, 51.079124404538064, 53.9272476011707, 54.7341654377599, 59.16341958507415, 61.23178735856087, 59.03655444422076, 60.298392695765344, 59.77676845365956, 52.944493832126746, 55.787514025165194, 60.2564468691426, 61.47221688301333, 60.73092029940698, 52.34300228857225, 45.691007644899436, 48.486033716509425, 55.933826277332926, 62.127637094067, 61.259949976398104, 58.45409031837218, 66.12643857156077, 60.20899011242775, 58.234586638789025, 53.81719373887586, 53.038203177913545, 48.91656091136318, 49.77367724141767, 50.57373485257549, 56.761622890349365, 62.315640218796275, 66.81223361722886, 66.30314919256395, 71.4109145441363, 70.74135026624127, 69.04201476804673, 70.34666569002214, 73.21451448625135, 72.47213532847744, 73.31454277038574, 71.27907583790441, 70.39141993368827, 67.59913167645855, 74.57250179782991, 73.98377756918632, 77.00514008921962, 72.83630386475595, 20.48594124855534, 0.059787141039006175, 43.46988708742204, 71.0536729135821, 61.306053515403505, 37.37864625069403, 28.759816346629975, 37.815257041685044, 19.192647549413866, 3.415992183070029, 4.428082829521549, 22.014294747383367, 2.783867418766022, 0.3376653568158227, 0.08347716903494251, 0.1820448452546712, 0.08158548344527522, 0.027770748542201136, 0.01692259113394445, 0.059149200472259716, 0.045341990152073484, 0.03452328116362614, 0.09221954226133325, 0.07076986945204197, 0.4433174004718181, 7.230259872251942, 43.99529249437394, 43.16009829121251, 26.542088639351633, 29.204738640016128, 33.90540707495905, 61.82794055631084, 63.839943870421386, 58.354215006674494, 78.20068636248189, 79.00947124727311, 68.39153674341017, 2.5462923992064694, 0.5550783824536109, 3.6853300659887256, 50.10800046305503, 77.03338899920064, 85.83280286481305, 78.87770314370432, 75.2188377995645, 70.42166140771681, 69.56991088005805, 67.52725816542103, 66.18578403226792, 65.3127742582752, 64.11555313294934, 64.12703391044371, 60.301828692036295, 62.10627586610856, 57.78600869640228, 57.93569026454803, 55.96036895628899, 54.884768762896144, 54.4993802039854, 57.927692551766675, 55.11072474141275, 54.08507593216435, 55.36884415534235, 57.326706993964414, 58.21482181549073, 54.60420554684055, 56.11472598968014, 51.06851439322195, 50.98268116674116, 51.43982556558425, 52.19831389765586, 53.86317176203574, 61.32682638783609, 61.00883591559626, 63.523177177675315, 63.70088408070227, 64.02139663696289, 63.516720956371685, 64.65661664162913, 63.33645666799238, 58.50943496150356, 57.11154930053219, 54.582259885726444, 53.38725489954795, 52.47850056617491, 51.518045471560576, 50.040414102615856, 52.31261960921749, 54.83078910458473, 58.09767630792434, 57.926209895841545, 51.56605136009955, 47.6018020414537, 42.97595870110297, 52.03626901872697, 51.560869909101925, 47.09254503250123, 47.75911261958461, 49.79977669254426, 49.01305513997232, 47.855881414105816, 46.836433872099846, 48.93617276222476, 46.25860991016511, 46.039016016068004, 45.737613247286895, 47.66423832985663, 46.59806359198786, 50.196948051452644, 48.2543706893921, 46.355359092835464, 46.77148726678664, 46.23524435104863, 47.19676240797966, 48.147031107256495, 46.66135103471818, 48.3258911871141, 49.83326196670533, 45.65690263625115, 46.90619714798466, 47.038514383377574, 49.843216942202666, 49.926053477871804, 40.18168180219589, 54.61696501701109, 60.24041614224834, 57.67848868523875, 54.79310689433929, 52.90387376662224, 53.59426975250245, 53.098046779632575, 55.27082804710635, 58.20211333613242, 58.87832995383971, 62.92054030203051, 59.69742674981395, 62.11352048381683, 63.776887847531235, 58.12339921151438, 58.13661367662492, 60.80482559819376, 62.80202196490381, 63.32936110035066, 56.420678707861136, 47.075580781505955, 51.29860847227035, 56.29526092160133, 63.28296730595251, 65.38668740180232, 62.645927321526315, 68.43709115059146, 64.25497770309448, 62.81262805384975, 58.45261158481721, 55.6209074297259, 51.859652534607925, 54.12930850059756, 54.42260373023249, 59.789457321167, 67.18762797694053, 70.69856505240165, 69.22318120156565, 74.44189471583213, 73.94547954682382, 72.74021364027455, 74.25962217392461, 77.95575003470145, 78.11673979605399, 76.36293826564666, 76.0111330401513, 74.35686557523667, 73.78699225764122, 76.80669169272147, 82.03066902775919, 82.42476524845247, 76.40139318281605, 21.74788344290949, 0.07110462689231481, 49.13241678668607, 81.58561337378718, 70.94644315781133, 45.94293755869712, 38.679076702364036, 54.21030152228571, 24.36827971089271, 13.943058117743462, 19.039506450776134, 33.656038468883885, 4.44335751956509, 0.4760732057113802, 0.22301138168381107, 0.2239380876022962, 0.17932615242898467, 0.12075427964690233, 0.12825493926122306, 0.20798583875500387, 0.12531968104022165, 0.14477403954632823, 0.404786640597928, 0.1653037403499888, 0.5461515582376911, 6.173525789091665, 60.39055270533408, 58.949654333053104, 49.528964488737046, 68.22147846221924, 44.88236788780459, 71.80175519758656, 72.7359853252288, 67.14241089359408, 82.6495013698455, 85.95441987437587, 75.47820060483872, 3.288943671411084, 1.133041465955396, 5.0628551936918695, 51.956837100367395, 81.3976533951298, 85.2379205149989, 79.19686640462568, 75.94714349316013, 71.67412127217939, 72.29702503450456, 70.81015648380404, 68.1550492009809, 67.25792469516878, 67.93543569503292, 67.86495854777675, 64.86451795024257, 64.76681563162035, 59.09029091558149, 59.29347753524781, 57.75522593528994, 56.11247847157141, 57.8713280923905, 62.181432400980306, 58.48197837029734, 57.52640270417737, 58.81398739353303, 59.94776418132167, 61.173034175749756, 56.47050065378989, 59.26600525456091, 54.391483645285334, 53.28486534856981, 54.267485757027906, 53.57807036369078, 58.640371522595814, 63.2334787614884, 64.60722223404916, 63.89342146535074, 66.63866089236352, 65.93010825495567, 66.42486818375127, 67.51589113666166, 67.3577647055349, 63.99545015827302, 59.560555642650975, 56.05235638157014, 57.474713710046586, 58.04950567983813, 54.34399943197928, 53.51751681297056, 56.678135241231615, 56.003589553217736, 61.661918394027225, 59.60097174490652, 56.18700350484541, 48.18649407356016, 45.83082445206181, 53.394389690891394, 55.514799471824404, 50.29131635542839, 50.69860742938135, 52.99234282585883, 53.45676322137156, 48.81649340352705, 49.97189421807566, 52.654858173862586, 49.1160330464763, 49.9836770180733, 49.54565809619043, 50.83142280578614, 48.942170066218225, 52.172767500723566, 51.62336111068726, 48.12654064547632, 49.97356514776907, 47.68830599323396, 50.00273189237041, 51.133033460186375, 48.64047704204437, 50.859671715767156, 51.000747603754846, 46.04971624189808, 50.102638583029474, 49.282172879865094, 52.098607247875584, 49.13185196538126, 44.570049162833925, 59.75383435526202, 61.39731137983261, 61.07282938495759, 58.75362603895126, 57.0991232318263, 56.11817767543178, 56.990661851821415, 58.63610398384833, 60.57291546175557, 61.00574901027065, 65.98845743363904, 61.57551250150127, 64.05890234055059, 65.26143043271958, 59.80695893687587, 62.665841194891165, 62.384728847011445, 65.38149026132399, 65.04888503782212, 60.31132475022347, 48.58147674991239, 52.38767808483493, 58.58860800343176, 66.78739716929775, 65.66346553064162, 62.560992317814986, 71.2702661944974, 65.98743761739424, 63.225379067082564, 59.73574046165713, 57.418537524438676, 54.31531513890913, 56.402941749941924, 54.998956803352606, 62.860006363161155, 68.49333009412213, 71.8992417858493, 70.036453277834, 77.44683034958379, 72.8568963081606, 71.96202324282739, 74.12823846263271, 77.61439400334513, 77.77128096549743, 76.59779410208426, 77.70388680119669, 75.54728923305389, 75.22090881101548, 79.02568632556547, 82.66193528329173, 81.3378764737037, 79.52590619364094, 24.75187182426453, 0.13626975878592462, 53.616866527065156, 89.25310181033227, 78.7644329378682, 56.79832058568155, 49.48996043974354, 70.49766909691596, 47.47144599114695, 35.066154080052534, 49.08257522890645, 60.67510104948475, 5.431459440338997, 0.6188658048068324, 0.12005998948288542, 0.2562080092367626, 0.3009351180686105, 0.18144023334307058, 0.18138847644290618], [0.0030643813830289633, 0.16073139053919624, 0.08605889300064695, 0.05251561832283774, 0.2395345345740357, 0.21245753993430447, 1.678602094611814, 22.16977946219906, 21.38162624451422, 17.62347786657272, 34.87201244600358, 35.61582719126056, 54.483118057250984, 64.34912243197041, 38.13243558329921, 68.54588200969081, 66.59156107133435, 66.6680629791752, 4.6363964772993524, 1.0902023195259034, 2.0771161298598013, 47.41745456572502, 79.07596326643421, 74.95794526992306, 75.8313629704137, 66.28278424662929, 65.41946664933236, 62.98338451693135, 61.65323034409554, 60.92507762293662, 60.99925748763546, 57.48980306809949, 59.352803384104085, 55.42938593895205, 55.70005693743306, 54.46904459307271, 53.70150343064339, 51.89116485657231, 53.212740805841264, 51.05625306406329, 52.50793403194797, 50.35446651520268, 50.555778241926625, 51.12197237630045, 52.9490477038968, 54.00867992831815, 51.01709996500323, 52.11820733162665, 47.55876187355288, 45.939352512359626, 49.953415932193884, 47.45829428395918, 52.81185888474988, 62.12016890125891, 62.046008648410925, 59.96264565375544, 58.910595370877175, 61.318138337904415, 60.083435043211914, 57.31184121101134, 52.73277213496547, 53.730434833034394, 52.17108872628982, 51.42866642244401, 50.29005727460308, 49.74345930161015, 48.133589144675966, 47.40970003989435, 46.4701315664476, 48.748965878640455, 55.21642085044615, 57.0973934665803, 46.23340868180799, 44.54771910944293, 47.675726952091345, 52.463313148867705, 46.853813894333385, 45.7550246484818, 47.792876382027906, 44.94281553453015, 49.91083468160322, 48.12101010353335, 44.995073272335915, 43.7234212506202, 45.64925009204496, 44.44470197923722, 44.85320114320324, 46.57475686842396, 46.75279325054538, 45.801920506262014, 45.3780613407012, 42.89694255398166, 43.606777806435865, 44.42708269242318, 45.48600889021351, 41.1938415804217, 43.40881970620925, 45.86001865325436, 45.12312296898135, 43.73560021000524, 44.25166645357686, 43.242154275217366, 42.01245592486474, 47.064225519857104, 40.219948445597005, 54.45755989320817, 58.79202212056806, 53.89390353233584, 51.07415083915957, 46.89971347008982, 46.42986843662877, 46.08704936119818, 50.11058530499859, 53.61414832453574, 55.632196011081824, 55.76042221438501, 56.68742341379966, 57.882608829006074, 57.88310697001796, 65.40758971245059, 58.5242066075725, 58.059621472512525, 60.03503299528553, 61.72502148535944, 55.539902640927224, 47.766635725575114, 46.2585981430546, 50.15979143881029, 59.708656495617284, 60.59867366667717, 63.61257583864274, 59.58640798445671, 57.4133913747726, 53.719236466192434, 52.792870690745694, 47.588513051309896, 48.88931612814627, 48.411312564726806, 51.60250979085123, 57.00227598990164, 64.5556430662832, 67.25516334656747, 69.17008015417284, 68.94626186740014, 66.14003350657802, 64.84515320870184, 67.58636828391784, 70.50097173260104, 74.78419996077015, 72.52580119717506, 73.74466988348192, 71.7731846532514, 69.51516243719286, 70.20137325409921, 77.79644689252301, 75.13132187627977, 55.63232544929751, 14.361169049816748, 0.06400172778915975, 43.07870126539662, 72.70782270739156, 59.51609949911795, 37.65487917007939, 38.01773371235017, 36.05972574603173, 18.833254498820153, 11.747852659994557, 14.519723999884821, 13.014738021358369, 1.7931867847519538, 0.2721238995511686, 0.1089218907779263, 0.12953083571647445, 0.05395806995370696, 0.03547401926029594, 0.03250080904352569, 0.014421857983594941, 0.08532516463028808, 0.11004687557297368, 0.01719078319447656, 0.1681043739400564, 0.1982579930054565, 2.356262634838781, 37.372025289843165, 36.327655007762296, 22.34109486303022, 47.786730027967884, 49.80311855193108, 64.95186913398005, 69.46788218713576, 46.1228645232416, 77.46295129099201, 74.45370889479115, 74.32932269188666, 5.715820981610206, 0.8623173316159557, 3.673218522341021, 54.811087039209184, 87.5250388729957, 80.37336564833119, 82.24155918244394, 72.5100960270051, 72.12923388327323, 67.69705757018059, 67.33414419235723, 66.27360590042608, 66.10344563761066, 62.66823776306645, 65.13484378014842, 61.752968372837195, 61.49935183986541, 59.488654675022254, 57.30336104669879, 54.235110513625614, 55.13813034180672, 53.74712844048777, 55.194800746056345, 55.73038470360541, 55.141582027558364, 54.872734931207475, 54.35256981080579, 55.347977146025634, 53.24093480263987, 53.24365692753946, 50.320514478991115, 46.603241120615316, 51.684134314137125, 50.41303926898588, 54.623374169872655, 64.3240035733869, 63.50173357994326, 63.27038042006954, 60.78739066277782, 62.87201273825861, 61.47219727116247, 60.29822403384794, 56.97819655941379, 56.89496778672742, 55.576753308696134, 54.38731024342199, 52.63197114390712, 51.1124723957431, 50.957460326533166, 50.92396328526159, 48.169725941073516, 52.01147963923793, 55.35669657491869, 59.082991384690814, 49.30842530342841, 45.84918898920859, 48.22411352588285, 52.86865088247484, 47.929508224610366, 47.866765991334, 48.9676772394488, 50.670354597030155, 50.006524824327045, 50.0237871754554, 46.388699239300145, 46.6865248064841, 46.79854769860545, 48.43787485553373, 46.89304151842671, 50.21562245584304, 50.282043872341035, 48.09441643376505, 47.231043923285704, 46.062511013400176, 46.70315565601472, 47.11366699587914, 46.48030619467459, 45.63455297100929, 45.55033183866932, 49.144823243541104, 47.67273810602004, 46.33238577073621, 48.50683012316304, 46.55973026829381, 41.92424181968936, 47.67562497046686, 41.004438169540904, 58.9158199679467, 60.9220770097548, 55.673843737571474, 54.184700212171, 50.65837175615373, 48.536169452051965, 47.77651617603917, 53.54240032934374, 54.116431359321844, 56.482510951257524, 58.598919914614775, 57.65134588364632, 57.87973765403994, 58.529199784801854, 64.6879328450849, 61.93342093498477, 58.760870656659534, 62.226892671277454, 64.52471125510432, 56.826593029883604, 49.357705962273386, 47.47533305998772, 52.03621018317438, 61.96452925282141, 62.023937471451305, 67.15089890264696, 61.51506485477571, 62.056920682230306, 58.65468425135459, 56.3062317909733, 51.2657037088948, 52.481144243671054, 52.927572727203376, 55.05519966925345, 61.35089797358359, 67.49700884665212, 70.2270333997665, 72.87613161148565, 72.06300858528384, 73.47864689365511, 68.88135448578866, 67.62934177152573, 71.79318089638987, 77.20046627906062, 76.54918024616858, 78.86387286647674, 75.80668341728949, 74.18765452600296, 75.99966402976744, 83.03256004087388, 80.61681147544616, 60.67483040594286, 15.376068603607917, 0.044768990858668284, 49.76164340972901, 79.92081042258971, 69.53352697433965, 44.91879101722471, 43.644714970742505, 52.698808331643384, 25.50442364908034, 16.5411723813703, 36.75845676852811, 24.986374647386615, 3.1317627766439995, 0.49241389177979966, 0.050662639325544725, 0.18466909476105245, 0.07950518700865009, 0.07524075091726358, 0.09953961196926334, 0.09566276274140804, 0.27992209239352134, 0.23600538201149435, 0.24574153215414096, 0.30266022550002225, 0.3367909747025659, 1.785541962712042, 48.71873224935224, 54.58133812873594, 42.77434102950558, 66.9700776377032, 51.29764356920796, 72.88447057047199, 76.19191508139335, 56.28106194157755, 80.53280999583583, 81.55409320708245, 80.66533903921805, 7.188100766751075, 2.390880983683371, 5.17439857605965, 55.157981457248816, 87.16169403445336, 77.5878474020189, 81.9816864690473, 73.76279123367803, 73.10733964366298, 70.90854521720641, 68.97106693636987, 67.87588627107682, 66.54500253738897, 64.8744180125575, 66.29958768044749, 63.63283095821258, 61.89838240223547, 62.378841369382805, 59.21620684285318, 58.19233878966301, 58.08087679647631, 55.86791476895733, 57.40669196651828, 57.823859568565126, 57.56712475130635, 56.8453380369371, 59.12236413648052, 61.49835163547147, 57.84600919292819, 56.29260939936484, 53.29813080449259, 50.04469733084402, 56.57512203339608, 53.27815809557515, 57.579115436923125, 64.70236324494886, 66.23250730576055, 64.60308021114719, 62.492213556843424, 65.22188901901245, 67.0100465897591, 63.386882658927675, 58.982190393632465, 60.308139785643554, 58.57771558146323, 56.52129142515121, 57.12751726950369, 53.35203201540055, 53.02079569908881, 55.9854878148725, 51.10500028056484, 54.39772413622949, 60.295623502423695, 63.26660317759361, 51.55129148114113, 48.28770299111643, 47.82066245232859, 55.08764943768902, 50.650778047500125, 50.261110182731386, 54.06632308037051, 50.85585132721932, 54.44239208775183, 51.9632972440412, 51.02972999695809, 49.57242042787614, 51.58098774571573, 51.70315388710269, 49.51041952256234, 52.66009061567245, 53.5055967300169, 51.96256376081898, 48.7757517445472, 48.26458846369098, 48.455372548872425, 48.96035025196691, 50.20335720431421, 46.736095720721835, 48.03199583484281, 51.61301389817269, 51.97777863471739, 47.7662552556684, 51.830360274161066, 49.75117852610927, 45.7970057764361, 53.4034699778403, 41.92855250450873, 60.46816856630387, 62.721680056664255, 58.09912366251792, 56.70595269049368, 53.96345892260152, 51.528412295926, 49.516609022694254, 56.39465770413799, 57.602135827464444, 59.977499669598, 60.641796204351614, 61.64584452106107, 62.633752284511445, 60.6519002299155, 67.33574451938753, 62.733086309125355, 62.6498261574776, 64.77875532642489, 68.71465375346523, 60.76067539953417, 52.57557530556956, 52.18174972841817, 54.56326776935209, 64.02192615693616, 65.40690722004061, 70.16884896063036, 63.61787103837537, 62.20919493705996, 59.281435858818796, 57.71699067085021, 52.20998687128867, 55.40506724388369, 53.06707966712214, 55.4141475308326, 62.77156476051577, 69.16278454565233, 71.34326934814453, 74.4515908148981, 72.40185429972988, 72.02207473016554, 69.36926595626339, 66.19795122454244, 73.61195256633144, 75.59858599016744, 77.13424882581158, 80.04097615518879, 78.02284609886908, 74.06882239926246, 78.93034135141681, 85.28961735387003, 81.07197115498205, 68.18587118579497, 20.072009601900657, 0.16350579327873646, 54.670438689570275, 86.03907246743479, 76.42434689306444, 58.31911763837261, 58.874278145451704, 66.84340077061808, 41.44876034029069, 40.71366502392677, 64.17880135197794, 49.256814756701075, 5.430545037792576, 0.46150582932656814, 0.27519735237283094, 0.2413972313966482, 0.09325276504481032, 0.08238246769554193, 0.2251789048914948], [0.09871281923786288, 0.02101231895897898, 0.04976615940611209, 0.030697847926808946, 0.046677369504205646, 0.13996587255068366, 0.22676538105212876, 11.241789440954886, 17.13159107392834, 21.28698337462641, 14.498088206014327, 29.403473369536865, 36.8657688940725, 66.69749644494826, 36.23440457928565, 63.26124129756805, 69.41256892296576, 66.50259387108588, 8.364593636605049, 0.3189490014506925, 2.5719902976866695, 57.276732075598936, 80.47741828426238, 72.90531404556768, 72.15603936103084, 66.61951972592261, 65.0792912513979, 61.85125512461509, 61.37388698516354, 60.01522894828551, 61.53617112867294, 58.83423074599236, 59.98457954775903, 59.54833353719404, 56.44364810759022, 56.7405911414854, 51.400558717789195, 52.47753566311252, 52.955978531991285, 51.09005212783814, 50.59597076908235, 50.10083037038004, 48.62239099317982, 48.25562977021741, 50.7737208181812, 46.8929591486531, 49.32300083098873, 48.271652652371316, 49.56482671922254, 46.635420245508996, 46.676016776792466, 46.70913334815733, 57.09565977896414, 60.795027517503314, 61.32829335428054, 61.077618598937995, 62.54594218346381, 60.784190008717204, 58.120398598332564, 55.033414825316406, 52.638972574664706, 52.7961144908782, 52.702871907141905, 48.542782568162494, 49.51436542695569, 50.13060115998792, 49.242215694919715, 47.60697957008116, 46.57288197548159, 48.93828691974763, 53.92355272846838, 56.71549581712293, 51.52459190737817, 41.59655132601338, 46.27491520297143, 51.14118414540445, 45.49187675599129, 45.69875824835993, 45.982039666944935, 46.40840522704586, 46.47273209787185, 47.35043302659066, 43.9816544132848, 45.82004185645811, 46.150101461718165, 47.97470961847613, 48.06295118024273, 47.740642178443174, 47.67126329483525, 49.93674978133171, 48.163544285681944, 42.23772156623102, 44.87581752961682, 46.47677998388968, 44.84819619886337, 42.753168075315415, 43.67156359457201, 44.56727212475192, 44.86456817196262, 44.17308176717451, 43.684366210814446, 42.112958815789995, 37.38513385095904, 40.7071852684021, 39.08337500787551, 51.3562673138034, 58.239936751704064, 52.85415380231796, 47.34406701980099, 45.711957023989775, 46.48638979081185, 47.24654905257687, 47.77613178376229, 50.50672115818147, 51.6000622318637, 54.743677185427764, 51.61543400056901, 53.32152382020028, 54.91998380230319, 53.78426151890909, 63.75101589387464, 59.098269016511985, 58.4920157155683, 62.76245309460548, 54.85172671656455, 46.046609724721606, 47.549183445592085, 48.25511593972483, 54.604672308891054, 57.66398376034152, 58.465818205187404, 58.133377721232755, 54.64816747173187, 50.83229357196439, 47.90019242994247, 49.997417080786924, 49.44076999541252, 50.02943146613337, 51.92814496255691, 57.38624465081, 67.60995741813414, 69.21040211954426, 72.10745688407653, 70.27179548817297, 70.94896131946196, 69.34173876239409, 67.97446327824747, 69.08480782662669, 71.71515710892217, 79.98383506651848, 76.79344977101972, 73.03812549960229, 70.58443192512759, 70.18226346661969, 78.56067365215671, 77.73102960278912, 58.15082442375922, 9.141418068639695, 0.26853425668612607, 47.00325619789862, 73.71706424220916, 55.54128331522788, 40.28896647114908, 38.54870496257659, 39.29062520304034, 24.18223188769433, 13.570390785894087, 19.040740036195327, 0.5176047932717108, 0.7486827743630255, 0.20262397405120636, 0.10433988059840857, 0.009828489592989847, 0.046715716035255504, 0.07131354673014534, 0.021708091503129374, 0.053729212677647034, 0.007434681728256927, 0.05430947831501404, 0.03759117984783746, 0.09917335299354407, 0.07191219847769507, 0.39336868231335, 20.04913433905571, 27.91280011976919, 30.991315495583322, 20.56749320799305, 36.277432980075965, 49.56079060031522, 74.20501493638562, 44.55574427881549, 73.3781949935421, 77.07372665405273, 74.63795831126552, 10.390507636531707, 0.20307895366943654, 3.198234203361696, 64.28578399842786, 85.12267343459591, 79.15815261102493, 77.07567999439856, 71.2619193907707, 70.2305321539602, 65.59182736181444, 66.3036669454267, 64.2462347399804, 65.13880145165228, 65.72519579241353, 63.19531017734159, 63.84610983633227, 62.307744487639404, 60.520422381739465, 55.04180869748516, 54.32891791866672, 55.71197702038673, 54.31696645675167, 55.46440878222066, 52.65596820462135, 52.77005034108316, 50.413435428373276, 55.29817088957756, 49.238791465759284, 53.97526133445002, 49.71119780694285, 51.55075803879769, 50.900197644387525, 50.98458351627473, 50.2202743868674, 61.19150069452102, 63.114234785879816, 63.107139218238096, 64.09430565372591, 63.284281299960234, 62.48034446470199, 60.477076268965206, 58.389014274843284, 57.261846680794996, 55.051944102010424, 56.14821910858155, 52.590146910759714, 53.25952683725665, 54.325803556749904, 51.06780052185059, 50.50451286377446, 49.96616363525391, 51.756549112258426, 57.92627657613447, 62.28981533358174, 56.33437871932984, 43.17588190878592, 49.24524376469274, 51.00431696061165, 47.70348164343065, 50.559465269888605, 49.55318120218093, 49.866413839401744, 49.47386303255635, 50.65822662845735, 49.09751161452263, 49.00678719243696, 48.35431268138271, 50.81974983215333, 48.694605750422326, 49.72948389668619, 50.238701681936945, 54.071751640688994, 48.326330492573405, 46.241151440528135, 47.433551972912205, 48.39763918230611, 47.60832494305026, 45.754891287895944, 46.8072396709073, 48.42774337337863, 47.05814976846018, 46.36281944090321, 45.04580520814465, 41.861028901992306, 39.46861843908987, 42.804578581163966, 41.59493530950239, 51.65723469949538, 61.036649442488155, 55.9666016024928, 50.17628108301471, 48.078930916324744, 48.47721622836206, 48.88447200098346, 50.45200801664784, 50.772347988620886, 52.37526770560972, 54.25580101628458, 53.075999136893984, 55.42986839048324, 56.1570248296184, 54.41708495540004, 62.709148083963704, 62.63513688118228, 59.43904061471263, 63.29877053537677, 56.625716686248786, 48.5261477962617, 49.98285724270729, 51.029310303349654, 56.27091084757159, 60.8568597608997, 60.541312925277225, 61.34852493962934, 59.58287785130163, 53.67613354036885, 50.58904778572821, 51.85379251357048, 51.80686135445872, 55.87674794658538, 55.0669667797704, 62.857009672349506, 68.27684663957166, 71.4392654357418, 74.648940947748, 74.29021666126867, 73.07586654540032, 73.02234972676924, 71.20545294977003, 73.71817035059776, 74.93872565607872, 81.27617759089317, 80.68116188049316, 77.92949368876796, 74.7267843061878, 73.92986066879766, 81.83228338918379, 79.1237691140944, 69.43939009020406, 13.250342049906331, 0.27117315379361956, 53.959132548301454, 82.64794811125725, 62.1974866620956, 45.945722441519464, 40.77942748223582, 56.73983412404215, 30.676686494581162, 21.220246207329538, 42.76045191672541, 9.662098000126502, 1.4075609224457897, 0.2514730496031623, 0.09333587026283627, 0.0334281929498238, 0.04831847922515966, 0.16473547164951602, 0.01918205638386069, 0.15186265110969543, 0.18518081085095484, 0.18568026953406874, 0.1198155078436098, 0.21191842854022983, 0.20273576160111736, 0.4119271009920105, 27.092263813941713, 47.33526914350448, 48.912732678074995, 36.25936654306228, 47.12795226804672, 54.575556555101954, 83.92627208463608, 52.33052130668394, 77.23214334057224, 84.7562377683578, 80.3757582941363, 12.64857299866215, 0.6592286486298807, 4.386126216380827, 66.1632147142964, 87.34849299153974, 79.64323997497559, 78.39860916137695, 71.46714564292662, 73.44030180285054, 66.88144776128954, 68.6064826288531, 66.78709906916465, 67.31825859315934, 67.81846277175411, 65.08619854527136, 67.59589964343657, 64.38585150626399, 65.17279271156558, 56.19503259658814, 57.66657252465525, 57.90347976069297, 55.37066805747248, 56.0202282474887, 56.278943861684496, 55.66552831280617, 52.665342669333185, 59.43080755972094, 52.289187369808076, 57.0926473986718, 55.141919351393184, 56.053635074246316, 53.596097577002745, 51.842452941402314, 52.896468331736905, 63.37274643682665, 65.63425563996839, 65.45417178061702, 66.06238626664685, 67.49977019525343, 66.17517794332197, 64.33901448403635, 60.10100333921371, 60.92070810256466, 57.89949855496807, 59.50777230724212, 54.837253170628706, 56.11758539753576, 57.00779868710426, 53.91643754897579, 53.647209982718195, 51.962540226597945, 54.63771043285247, 60.66152572631837, 64.99172433730095, 55.09254063329389, 45.21962896470101, 49.54871362255466, 54.32952588604343, 49.2134137307444, 51.92261049824377, 52.269344099106334, 53.584185338789425, 52.2976283104189, 53.01326474835796, 51.59291175103957, 51.50140285491944, 51.45080820206673, 55.983157926990145, 54.4074280800358, 53.61930624131234, 54.590265443248136, 57.40098099554739, 51.81789498175345, 48.1039164143224, 51.047082562600416, 51.60645961761475, 50.08519580287319, 48.05289030075074, 50.23986662587812, 51.0503145956224, 51.62370235689225, 51.18293777588875, 48.69107169489707, 46.609567903703265, 44.73808742338612, 46.82177205239573, 44.7465911219197, 53.61459939710556, 62.55509699544599, 58.15116174759404, 54.59738846748106, 50.45850346165319, 52.499810803321104, 52.69088906626548, 53.827164403853885, 56.99318785821238, 54.84086567355741, 58.834124841997706, 56.18892154385967, 58.95300795955043, 60.64900552072833, 58.452140900396536, 66.06688914760467, 63.218997370812204, 64.54820625243649, 68.40441780705606, 58.65067166666831, 49.256049894517474, 52.74366847930416, 51.76710028802195, 57.38786458969117, 61.60770731587564, 62.13455615505096, 61.341888289297785, 59.7230633612602, 54.28813311361498, 52.18001996317218, 54.63585907413114, 53.22041296189832, 57.084763434625444, 56.29527661108202, 62.382406803869436, 71.83125142128237, 72.2900353708575, 76.01473377596948, 73.32716495760026, 73.8674714488368, 73.15619668652936, 72.46811882142099, 73.3026344545426, 75.3020626498807, 82.84576892852783, 80.63113597131546, 78.77777684119441, 75.9000515168713, 75.04216640226304, 85.0939146164925, 83.5273591933712, 69.64092146965766, 14.693690922952468, 0.4112636994931006, 59.15657112675329, 89.40845904811736, 69.9437362917008, 60.98483493251186, 57.43422308275777, 66.53807563166465, 45.859826457115915, 42.04664330328665, 73.14959141515916, 24.130289900687433, 1.3121265918016434, 0.3744594872959199, 0.23836894711900145, 0.0996140067675902, 0.13030657634860085, 0.3452437437109409, 0.17309185147525805], [0.09893571251943227, 0.044596605753946694, 0.11879997403030434, 0.08068336128828027, 0.025935464260739186, 0.05664096349069188, 0.03558648096758031, 3.197086664938158, 16.481032640703265, 23.653378717360958, 31.893140962046964, 33.023297402166556, 38.31999940256919, 61.67656452425065, 37.92105513234293, 60.84687732881116, 70.071393751329, 74.69182029847177, 12.437022905195914, 0.3411582580977871, 4.290058055231649, 65.73327979733868, 73.42121554959205, 70.82910153173631, 71.84840786841609, 65.40456556504773, 62.79797407888598, 63.035006830769206, 62.38490927603937, 59.64005816367365, 59.945657868539136, 58.07079238276328, 58.87207377341486, 56.39721116712017, 56.158319211775265, 55.44868400019985, 53.61013573984946, 50.883900196321555, 52.13757207316738, 52.182165499656435, 51.542328865297385, 49.508944711377545, 47.71683339149722, 49.447489015517704, 47.989061570936634, 49.30292614044682, 49.38850049049624, 46.24578375970164, 46.687352426590465, 45.60706892321187, 44.68753199423514, 49.16566279626662, 58.34605647671608, 60.46175549107214, 58.127584380488244, 63.519556830006266, 59.42532016384987, 58.3480647302443, 53.87850038466915, 56.545174737130445, 53.54916641789099, 54.021886548688336, 52.072201851875555, 54.83453889046946, 48.54838371276856, 49.14308563355477, 47.39273971126926, 47.17520898388278, 47.39366539062993, 49.01566743850709, 53.730466211995775, 56.297414302825935, 47.939600483063735, 52.7760947135187, 56.48622543581071, 45.32511718811528, 43.99972869503883, 45.898779515297186, 46.09525888196884, 46.10382533842518, 42.18351833281979, 44.52121565418859, 45.157416251397905, 46.45611301545174, 46.373578502285866, 47.62055881561772, 46.100365807933194, 50.487670206254535, 49.53296530631281, 52.46759637709587, 43.32443775669221, 43.58900946955527, 43.76268025367491, 44.04895836307157, 43.32577528492097, 46.28939659364762, 44.10839403829267, 43.98077187999603, 41.7398198189274, 45.79673513289421, 44.02474164962769, 44.045667494496996, 38.62075890264204, 39.02180164091049, 38.895642526688114, 52.128091704460886, 69.82423736203101, 54.771882949336884, 48.63358543765161, 46.74771378117223, 47.11724027510613, 44.49406893022599, 46.09245830966581, 48.979765984319876, 48.473340926631806, 50.394321718523585, 51.381609747486735, 51.82804215338923, 53.03806981732769, 55.06610385833248, 53.37580550101496, 60.36608888256935, 58.750107672906694, 58.39170894315166, 55.11235644740444, 49.158065165242846, 47.24155587534751, 48.81823493588356, 50.52192818733954, 56.272742594442065, 58.9353729832557, 59.3123088344451, 54.18422168300998, 51.300098972935835, 48.784188762787856, 49.04283769669072, 48.239010687797304, 49.20356858161188, 50.41545937138219, 59.71825845779912, 68.94994889536213, 69.46843916370024, 69.81117586935721, 67.65588052811162, 70.77269784865841, 71.27225091380458, 72.0694334276261, 72.13212859246039, 70.50590607427782, 69.7064015173143, 77.81635684351768, 75.3310489654541, 71.35575033003285, 71.82016680317541, 77.27730551073628, 73.47192395117976, 70.25331327992102, 15.246427405265072, 0.2445619865771263, 45.83526849746705, 73.48416959085773, 57.258583268811634, 33.0583712362474, 43.200349653920824, 39.681540381523874, 21.143197128849646, 26.61547226290549, 13.29426278991084, 1.2999828111740852, 0.24316784445076223, 0.144960597277649, 0.016597373403548714, 0.046765423650222446, 0.037108536794661515, 0.053756562016543843, 0.04435716880365245, 0.05156908221843262, 0.030579912521305586, 0.004687026948592956, 0.06997918244451284, 0.06979139131163398, 0.05655521909976679, 0.3733455648104991, 5.45305012695251, 21.800376522925593, 39.2117424165049, 30.884387762315814, 31.22776773668105, 47.780791559527, 72.4625333662956, 46.132541010456706, 70.299816900684, 79.25523127278974, 82.37978350731635, 14.129956114676691, 0.5214099213480949, 5.065944060202568, 72.98620900800152, 80.73827943494244, 76.38426026990338, 75.06467296231177, 70.19214783945392, 67.38687653695384, 67.21160934817406, 66.21426828445928, 65.8149710009175, 64.8783992182824, 63.470731166101274, 62.93577086540961, 61.45163228434902, 59.35726311899001, 59.39147010926278, 56.78131711098456, 54.88003446209816, 53.57149647128198, 55.82647885045698, 54.18803814918765, 53.33458531287409, 51.547784882207075, 51.635928384719364, 50.18130171683527, 48.890841930143296, 51.467913658388206, 47.099185605202955, 48.91634910337387, 47.50262883401687, 48.01156420861521, 51.738278711995775, 60.80318212509156, 60.96002201880179, 61.572421673805486, 63.62285637086438, 60.32018930681291, 58.58420318172824, 56.01576851260278, 61.472546362107806, 56.57928759051908, 57.42799828129431, 55.72610147537724, 59.16313717442175, 54.761825992215066, 52.12819760845554, 49.53294961683212, 48.9088926776763, 50.129416604195875, 53.06272583623087, 56.764760786487216, 61.420759308722715, 58.39896925034062, 55.662967005083644, 56.941455718009706, 48.6130714416504, 44.712015428850734, 48.739736541625, 48.61943744844007, 47.0368669879052, 45.01147662439654, 46.96978269084808, 48.347134743967366, 50.64850307280018, 49.36051830168694, 50.91613031202748, 47.85860353900541, 52.37720143410468, 52.79241569580571, 54.42204283129785, 48.17434257076633, 46.12416675013881, 46.411621570587165, 47.141402075367594, 46.043456139103064, 47.37412806480162, 48.18594101936587, 45.62972453332717, 42.91675444572203, 46.77700211924892, 46.830766047200854, 44.88675702002741, 42.61058991955173, 39.61029052734375, 42.02316007306499, 52.4465528611214, 68.34289150853311, 54.354468237969186, 50.892831433203916, 47.84280815432149, 49.67599845701649, 48.13376172896355, 48.557130598252826, 50.10764352736935, 51.43931565746185, 49.56556412481493, 53.95837160848803, 53.38460729968164, 57.09636972796533, 56.83765411376954, 56.10681849141275, 60.31054419855918, 61.9847059249878, 60.57638675935807, 58.60269715709072, 50.06844728223739, 50.25063353200113, 49.349504286243075, 54.37853197897635, 58.76480479394236, 61.741114970176454, 60.892620009760705, 58.26989581508022, 54.77366762776529, 50.49663674446845, 52.4048266872283, 52.381468972852154, 54.05310077051963, 53.66385259935933, 64.1328311735584, 72.28074719828945, 72.08374223401471, 72.58300504376813, 73.8147077252788, 72.74026855345696, 71.71417651637908, 76.89897721813571, 76.78263187408447, 75.25192691433814, 72.89819102133475, 78.53961052433138, 78.27146160987117, 77.0695375627087, 74.40771518215057, 81.08402067615141, 75.87381086041852, 74.49028107427782, 17.770655001363448, 0.13920640362606895, 55.230278584264944, 80.24158970002206, 67.87835736428538, 40.35485836767381, 48.27194290776407, 52.60996664724043, 20.76759880588901, 39.59110621483096, 27.791218411537912, 3.0563873244870097, 0.37468195922913095, 0.093921743663809, 0.07061248434887779, 0.18669597954759676, 0.019399472136771487, 0.06886675383054441, 0.007900558468405037, 0.19762900417610524, 0.20862258039414885, 0.25304228878549995, 0.18838313498323966, 0.3259973780762765, 0.2570893933936473, 0.5779620416222081, 7.476767599582673, 42.06029707385648, 56.79538273042249, 60.459500128223056, 52.06477288276919, 54.923561003900346, 80.32985087363951, 54.18723406330232, 74.49035167694092, 83.2255014296501, 89.70884984539401, 16.901765677236742, 0.6794742687094597, 6.203783933193454, 75.36384782483502, 80.36723890612203, 75.29641443683256, 77.48658749365038, 70.77718504013555, 69.30263273177609, 68.62356062858336, 69.82552389944755, 66.81049992961269, 67.40135792763003, 65.9461272147394, 67.14479569465884, 63.734369354863325, 62.113347899529245, 62.75057615772371, 59.05513471172702, 56.94894352266866, 56.610105652962964, 57.038389252078154, 55.59436867314001, 53.95607702193722, 52.612908424869666, 54.62234650888751, 51.87475758214151, 55.26202624843967, 56.037341548550515, 50.04333626839423, 52.830784320831306, 50.22394180297852, 49.006775425326445, 55.61817746008597, 62.896696213752996, 63.89382939184866, 64.02600149954519, 68.31825902385097, 64.54615485283637, 64.20055089458343, 58.43446670040008, 64.0392198870259, 59.51437365624213, 60.48967884432886, 58.4587618612474, 61.50001864279471, 56.01594109689036, 54.484687005319905, 51.72643315407538, 52.53964639479115, 52.61323790396414, 55.61002285249772, 60.17450463387274, 64.72075131631667, 52.817346280620946, 58.336901664733894, 59.18253721729402, 51.73497215394051, 47.59112534984466, 49.513078889539166, 51.8030527330214, 51.57736739804668, 48.68566666879962, 48.99710286048151, 51.639352613879794, 52.91956716968168, 52.24531565943072, 54.26036273279498, 50.78473483362506, 55.88204706868818, 53.70380193956437, 58.15482916370515, 48.74118389621858, 51.22827645271055, 48.969693337717366, 49.977840531256895, 48.877415657043464, 51.54660817115538, 50.99817452892181, 48.37122594156573, 46.872786398856874, 51.21617201835879, 51.64636973411807, 48.759807309796734, 42.56722811729678, 43.94411340836556, 44.870526252254365, 52.314451356087964, 67.7375207408782, 60.39939372770248, 51.047988630110225, 50.22331814612112, 51.59653994344896, 50.690696008743785, 51.420315696347146, 53.15427003368255, 53.04436522145426, 53.460171761051306, 57.812323877888346, 56.246835339453916, 57.98268025921237, 60.794760796331595, 60.13999562109671, 62.00758118783275, 63.14277002888342, 63.56989652879777, 59.1972892515121, 50.72798598197199, 51.44071594361336, 52.69124600195116, 55.387659765058956, 61.25639238665181, 64.37039344541489, 66.01319189994567, 58.85087728500367, 57.23277799544796, 53.60097308312693, 53.65561562199747, 54.86059519552416, 55.053599342223144, 54.96759353145477, 65.79717128507554, 73.35783789234777, 71.89139704550468, 73.38253313495268, 72.40079525978335, 76.38797867682673, 74.6694863227106, 78.92648173916724, 78.18991553398871, 74.68536407716813, 76.25916804036787, 82.0594435353433, 77.89284306187784, 79.43195758327361, 78.25409335474815, 83.36512211830386, 79.45462103812926, 80.8725029422391, 18.339282966429188, 0.16971098289134043, 60.568392968946895, 85.72398847149265, 74.74120293894123, 48.914231023480816, 64.21419682041292, 58.49570274353028, 37.58656717115833, 63.5474919503735, 59.57441729883994, 6.1784954320999885, 0.43500341595180575, 0.27518457402625396, 0.097659946299128, 0.21550565056743162, 0.11542282863369874, 0.17648093252172395, 0.15153260511015693], [0.08580661258630215, 0.02249000105826605, 0.14214620474846135, 0.028235463222729105, 0.0929076654175597, 0.07517322792761749, 0.10537437508783995, 0.20929889813546212, 9.902430445917192, 23.33823392468114, 47.141935517711026, 47.402996709269864, 33.60749913800147, 66.52233123779297, 46.97983572559972, 61.83837798333938, 71.97211942365094, 72.68872860939273, 13.00195501696679, 0.7271466332097208, 6.191702052470177, 69.59496698071881, 75.00369579561296, 74.64094715733683, 72.4833611519106, 65.38990766771379, 64.87777163905483, 60.17527734079669, 60.52528612075314, 59.41610259394492, 61.64486000614782, 59.279902212081424, 57.76267843861734, 55.57272503452917, 55.5899207053646, 54.00565970328547, 53.56166308925998, 50.95113746581539, 53.44238773469002, 50.98405399630147, 50.50138673474712, 48.33712485528762, 49.09829608855709, 47.6454697885821, 47.16842720585485, 46.57404691942277, 45.72682280694285, 44.81790373402257, 47.674267830387244, 46.64357877546742, 45.63368612720121, 46.690384418733665, 57.565265547844675, 60.00929047984462, 58.9271124716728, 60.95317356048092, 56.88990792920513, 54.693776792095555, 54.5703358804026, 53.54110986955705, 52.77247828821982, 52.64980616108064, 55.41894851192352, 54.49166882422663, 51.57261348539784, 49.77446563782231, 48.98649677153557, 48.21766514931956, 49.22379232222035, 51.56947558925998, 55.174078864436, 53.66060095448648, 49.61426035050423, 56.30654950295725, 47.937607919016195, 45.30133193539035, 45.938999499044115, 45.34761198105351, 40.72902502552156, 41.76994754422096, 42.25318354945029, 45.466448030164166, 44.079560695155976, 49.429748135228316, 48.00279771128009, 49.30912740768925, 46.43517932584209, 52.98183087379702, 50.41311379401915, 52.74539824455015, 46.47275170972271, 44.24408843440395, 41.84555122929235, 44.07014308437225, 44.790247101937574, 48.547167778015144, 45.60923014917682, 41.533063842404275, 43.491966109122004, 42.66316144697128, 39.47660830713088, 43.410223914730935, 42.20890391257502, 40.81011610646402, 40.42391561692761, 60.469980701323486, 67.64764355074975, 57.03284694302467, 50.114848921375895, 44.43379779015818, 45.51859986397528, 45.32887874111053, 43.591460950912975, 47.5452846096408, 51.20930394818706, 52.92025358446183, 54.70844645654002, 54.5230987764174, 53.347764476653076, 51.95996715176491, 52.1727204322815, 54.60098528092908, 57.52273921043643, 54.41465308589321, 54.05114743017382, 45.08962200533959, 46.49511706444525, 47.262418962294056, 50.839581335744555, 54.9165831073638, 55.67014494249898, 56.01003400741085, 53.68965002798266, 49.006241982983006, 51.96297560968707, 48.38686835381293, 50.93031752494074, 49.33264986161263, 51.278792658159816, 61.22739038159771, 67.37354047836797, 66.83742307847547, 68.91399645036267, 66.36813502157888, 68.72318883096018, 67.32875485574046, 67.94524946520406, 69.67316335247409, 74.68313617091026, 73.29562910141485, 70.61681501327023, 76.50410436814832, 71.52981727353989, 72.85171877953314, 75.21525275322699, 74.97969873489873, 66.94218174103769, 17.71230974505025, 0.4896917362366954, 43.279954156567975, 74.97920451625701, 45.67726758218581, 34.683687686920166, 44.888082781145656, 38.07883247252434, 22.90884421717736, 29.416923176857736, 7.1155408409334004, 0.6170483378152694, 0.22390156053006652, 0.05348504130398074, 0.029686544834065343, 0.058456074761887716, 0.05038829557898064, 0.0860211018833422, 0.018550901440903544, 0.024791961205342126, 0.02996756695210934, 0.061059747146622795, 0.0076192078901635065, 0.10534094301082435, 0.03253967268392444, 0.07189292370552017, 0.3605645522475243, 19.386245935193955, 39.56833293361049, 49.61408384384648, 49.82137718508321, 45.154741194940385, 75.96031481219877, 53.760472343813994, 71.04978192237117, 77.80484076469176, 81.14251890490132, 16.018398884804018, 0.7191573780390524, 8.159701766506318, 77.10043799492621, 80.65347779181697, 78.28263252012192, 77.007948506263, 72.70187639421033, 69.4493999788838, 65.36894259914276, 64.27583294530069, 64.01179859715124, 64.38737338589084, 63.30730169050155, 63.66250761093632, 60.420872626766084, 60.92292031934185, 58.90058548219743, 56.45263425765499, 54.188473532276774, 54.40423919308571, 52.80553994640228, 53.26309619411346, 52.78230774787165, 50.89662044279037, 50.765185740686235, 50.30381694916756, 47.49210511484454, 48.83135526410995, 48.579829354440015, 49.837411834347634, 46.46807624447731, 47.83686184114026, 50.50823911543816, 59.742596764718336, 61.02130905274422, 63.35240502511302, 62.126507451457364, 60.80311152242846, 57.27606527266964, 58.41127372557118, 57.35236713963171, 56.530018698784616, 56.39758379228654, 59.149008797061065, 56.68566619196246, 58.797921365307225, 53.03939165607576, 51.40331614402033, 50.11510779780727, 52.92740406528596, 55.220504037795536, 60.831219227083274, 54.03171600834016, 68.28975123743858, 62.959163881117306, 45.26115509771532, 51.46902761151714, 45.46543605865971, 48.90108716103339, 44.158255207923155, 45.09443475354103, 44.19508234147103, 47.0814408025434, 46.14021316651375, 52.771525152267955, 50.7153598723873, 51.40927422431208, 48.518236375624134, 53.420434228835575, 55.04722156832295, 53.31878208344983, 48.33553629536783, 46.59411768759451, 46.07789847158617, 47.58968191762125, 48.82119632536366, 50.22619324345743, 47.79774012104158, 43.669602409485854, 43.8833402049157, 44.244614032007036, 41.848139993606075, 46.3491617479632, 44.581157315161924, 42.64574220103603, 42.092738997551706, 59.77536816750804, 68.08457989846507, 57.728569507598884, 52.34940751906365, 47.80700475938859, 48.82057266850626, 47.40012553430373, 48.343282976458156, 49.870261684540786, 52.308618791641734, 54.99542274782735, 56.03818878050774, 55.59316058312693, 55.12082484460647, 53.735067152207904, 54.493171092002626, 55.839269699588904, 59.95556185322424, 56.21704101562501, 54.315801512810495, 49.46220182603406, 48.222266089531686, 48.3827067190601, 53.133151992674804, 57.8718654571041, 57.22463515497024, 58.60314822966053, 55.71865289442001, 52.31123109017649, 52.822625790872884, 53.43324468981836, 53.9244705630887, 53.18723363261069, 55.46090610565678, 63.869667591587195, 70.70475455253356, 72.22677538471838, 71.60376964076873, 70.5934690660046, 69.82036990504112, 68.16199964092624, 73.2498550415039, 73.03652517257198, 78.80145226755451, 78.59634368650376, 74.72952212056806, 78.23787043171545, 74.8959953554215, 75.33013897557413, 78.7836290174915, 77.7569878485895, 72.21434147127214, 20.672567621354137, 0.24362429495780702, 50.28756264717349, 83.69882168308382, 51.86876812288838, 37.88086652755737, 51.88344563207319, 46.44488719201858, 24.736048982989406, 50.518660852986, 9.844415649291008, 1.1069578268835623, 0.1945026300006336, 0.12831206643773665, 0.030572768751411673, 0.08329942131475096, 0.021523916305253105, 0.10534595322584915, 0.017425096931777174, 0.29146715998649597, 0.18839854867227618, 0.18984774187687906, 0.09439640408081394, 0.13737683244530233, 0.15659813168308429, 0.22377495683969992, 0.5067764162536591, 36.88759296171127, 57.18627829705515, 69.37470236132222, 70.67457583642775, 50.36304473876954, 85.37987893627536, 63.39237005479875, 77.70871916124898, 83.97191278396114, 86.42732435657133, 17.988874104715165, 1.0351136110482677, 9.091357838722969, 81.07569740664574, 80.7478343286822, 80.9532880783081, 77.99355383842223, 73.24039428464829, 71.2600209636073, 67.88118931554979, 67.34868834095617, 66.79388476956275, 67.9992526577365, 66.1127887233611, 66.02690450606808, 64.34438420880225, 62.41523311984155, 60.068600639220215, 60.54146982008412, 58.2323665772715, 56.81010338567919, 56.47496038867582, 55.32752590794718, 53.9860596195344, 52.992436962742964, 51.922979201039965, 52.56986041222849, 50.86688103214387, 51.98955358997468, 50.540551600917695, 51.35257636347125, 51.6561129016261, 52.12762102004021, 50.963081082990094, 62.009550217659246, 63.832585503978116, 64.30905149829003, 63.885847368548, 62.0293503422891, 59.421868478098226, 61.712744466720096, 60.37060353063769, 58.36494661146595, 56.94349535049931, 63.222723622475904, 57.86921785723779, 59.5787162165488, 57.35859586346535, 53.63912597779305, 55.057878648081136, 53.69345080467963, 58.33776850854197, 64.70821542124595, 57.45638055186118, 62.03817567517681, 59.52292442321778, 50.54265791370023, 54.04491870634018, 47.98210328625095, 49.84914364353303, 45.89495912674935, 46.565637357773326, 47.804733707058816, 50.3779968138664, 47.582009761564194, 57.24898522899997, 54.012237518064445, 56.213601096983886, 53.05860342517976, 58.14896129792737, 56.276912073935236, 56.973509327057876, 51.57591219871275, 49.90070319944813, 48.027316447227236, 47.455085785158225, 50.823389791673236, 52.71856923257151, 49.46934053974767, 46.10619837237943, 48.163312865841775, 46.896210793525945, 44.26943871282762, 51.817330160448634, 46.64083703871697, 45.01852904596637, 47.12123324794155, 56.23297760563513, 66.88777846674766, 63.72498312304097, 56.665979816067605, 49.742435562995176, 50.87359612987888, 50.86743408633817, 50.902264733468336, 52.46457615206319, 54.57105759651431, 57.52608499219341, 59.097272734488214, 60.37159981266145, 58.25252363758703, 57.720316840756325, 57.86369516003517, 58.30548347965364, 63.07857259627312, 56.59629498758624, 58.28041561188237, 52.502858484944994, 50.33687076260967, 51.89667578666441, 55.35259377571845, 59.681356799217966, 58.74190599687638, 61.4665255238933, 58.69622607384959, 55.500251400855284, 55.64491625755064, 54.55281465284286, 53.66561766593687, 54.275899241047526, 57.3958936814339, 65.41955294147616, 72.79359709831976, 72.64479806346279, 72.63233277105516, 72.71817776464647, 72.21069366701188, 71.06230212796119, 74.53654935283046, 74.87072744677144, 80.41034575431578, 78.33115223915347, 77.18265087373796, 80.09337117595058, 76.45789100277808, 78.96072403077157, 83.26980852311658, 82.50559745296356, 77.11031452302011, 22.16220928776649, 0.6838021751853728, 53.85853944286224, 91.21857012471845, 60.43835070825393, 50.527607779349054, 65.44828822535854, 56.7446154932822, 45.20406499985726, 75.57648735661661, 33.23141836350964, 1.6135346312676708, 0.5057078155298387, 0.2362945035941178, 0.28709975401720694, 0.1584451696685245, 0.1098441916908468, 0.14583710911533526, 0.18930371219833053], [0.13284549898197576, 0.03757013541255747, 0.12081700692614242, 0.11249249635805046, 0.017480906437061006, 0.1014520738634371, 0.07127816112892282, 0.2537249497348263, 6.006826527657048, 30.759758372460645, 46.346765179787916, 27.78925330408158, 28.84987396578635, 60.433008440079234, 50.109428205797755, 52.67137919702838, 70.27185040135538, 74.45380303167528, 14.262670490049548, 0.6939153325173163, 6.185806239804914, 69.3767733727732, 68.42231165978217, 73.33568434561454, 73.37305668861636, 70.07645360885128, 66.98264491173529, 62.31517737911594, 61.699753576709384, 58.92022871202039, 56.929280680994836, 55.001882891501154, 56.57233322820356, 55.815025529553814, 56.841172479814105, 56.6688431462934, 54.765869955862726, 52.27673776688115, 51.62576552360289, 50.51787637895154, 47.29091105922576, 49.94854434843987, 50.03600535854217, 49.11442879707583, 45.31562505229827, 44.098976427508944, 42.3724236026887, 43.20437400571762, 45.862501513573434, 47.54628481403474, 45.02796234623079, 48.17173027223157, 55.726697675643436, 61.78590059280396, 58.82269505531558, 57.7899585231658, 56.5679637078316, 54.737699493285156, 52.768316653467, 51.76704537483954, 52.10317288675616, 55.215530472417036, 55.156596860577984, 54.79917872336603, 53.04654213689989, 51.66167874490061, 49.67789688417989, 49.125960565382435, 53.6945176893665, 55.839014745527706, 52.33251779310165, 46.41153920081354, 46.6838615171371, 43.454758505667414, 41.8021462809655, 46.959215825603856, 45.718323030779445, 44.73940141739384, 42.643522139518495, 44.34699181587466, 40.74893497651623, 44.00818924750052, 42.46685858695738, 48.67937126467305, 49.79075916351811, 47.71255800800939, 48.96925403225807, 53.499772010311005, 51.301048186517534, 52.228551449314246, 45.71990766832906, 43.21177944060295, 44.73633412391909, 42.57249978280837, 45.68264122932188, 49.86573526936193, 41.80751992810158, 42.749814448818086, 43.29941303499284, 40.00277073152604, 39.794320291088475, 43.40516797957882, 42.85689907689249, 42.51672367895804, 39.899416277485514, 65.89238289863833, 63.66273118603615, 51.730881121850786, 51.71739601319837, 47.39257104935185, 47.42677019488427, 45.12620595193679, 43.34203350928522, 46.7458624224509, 54.103554218046135, 54.92100754091817, 55.40702842896985, 54.88336063200428, 52.77697724680747, 52.130676546404445, 49.29424201288531, 54.33960245501611, 51.32268005801786, 53.22108368719778, 47.51198760924801, 44.70205653098322, 45.17856174899686, 46.892398249718454, 48.51859331130982, 52.07717149488388, 56.40928422251056, 55.29178134856686, 53.142636283751465, 48.50017778335079, 48.94096589857533, 50.807080576496745, 49.85854948720625, 49.3630599975586, 51.66515788724346, 57.88180474312075, 67.45409027222665, 66.34375356858777, 65.31921479009813, 64.57151297600039, 65.6946679853624, 61.16990412435224, 66.45469388654156, 70.64231826413062, 71.45107176996046, 73.02396574328023, 73.38150547396752, 71.2588442525556, 71.91755925455402, 73.92127852286063, 75.72134048708024, 74.9349444912326, 71.6747174724456, 20.146946484042754, 0.41331482330156916, 46.531999111175544, 73.21199632460072, 39.93834187907558, 40.13714721125942, 45.69689904489825, 42.27792193812709, 30.826413169983898, 36.844101721240634, 4.124611010474544, 0.4064520544582798, 0.003884576421584033, 0.09711315870405206, 0.061620408594007456, 0.07764925474240895, 0.09272158266075196, 0.08978493015972838, 0.08195244722188481, 0.06579394452273846, 0.01144379555743428, 0.06283688343941204, 0.06290397358938091, 0.06622518307619518, 0.07685421635546992, 0.0534601204638039, 0.33583269063984195, 12.386706740625444, 46.7552839556048, 53.0526335777775, 21.74431016368251, 38.92077315238215, 72.23411806168096, 56.83487707568754, 62.53065278453212, 75.50120922826952, 82.86742041187902, 16.399368893715643, 0.6879350663192811, 7.8181952141946365, 73.29245198157527, 75.59238080055484, 75.09152550851145, 75.77919544712191, 74.19396954198038, 71.39877088608281, 67.25339043524959, 65.68819999694824, 64.03158695467057, 61.92093210835611, 62.55773675057196, 62.0763324922131, 60.075629526569, 60.37198028256817, 59.45460457955638, 58.38154608203519, 55.708015426512695, 53.95264494803644, 54.50188267615534, 51.494891720433394, 53.36710568397276, 52.25510589538082, 52.14635818235336, 49.497514924695416, 45.85950874513196, 45.89444137388661, 48.73989735880206, 48.670428260680175, 46.8213798153785, 47.52737506743401, 51.63825042786137, 58.74324352510514, 61.45229124253797, 60.40608136884628, 62.22462161894768, 59.62207017406341, 55.9716026244625, 54.3986576603305, 56.49295230065623, 56.73853581951511, 57.7429332271699, 57.64046915115849, 57.08195893995224, 55.41371607011365, 56.5311404966539, 52.85800556982718, 53.11621519827074, 58.20561993506647, 56.74441153003324, 55.966593757752456, 50.77421111445273, 57.54551641402706, 57.07339640586608, 48.040832934841035, 49.022268787507095, 49.564995381139944, 46.815806127363636, 44.34632893531553, 48.92741410962997, 44.796820994346376, 46.18314350804975, 44.50727162822601, 48.96153873012912, 52.4404182741719, 47.685658393367646, 50.65526131660708, 54.271176707360056, 52.51802629040134, 53.625887978461485, 49.01725599842687, 49.69305684489589, 49.86025964060138, 45.842442512512214, 47.56700277328492, 50.4184482174535, 44.815401261852635, 45.84514894793111, 44.83797842456449, 41.864005980953095, 42.22223604879072, 44.609641567353286, 44.46977769174884, 45.05696435128489, 39.387178267202074, 66.31771687538394, 70.2809424554148, 54.634603915675996, 53.78372415419548, 49.55275758620232, 49.25147248852638, 48.092565075043716, 47.26496065816572, 52.716796321253625, 55.90937814404888, 55.75682540093699, 57.16556426017516, 57.09237675512991, 54.23476534505045, 55.904447724742276, 52.49559033301569, 56.697358777446134, 52.32486917126564, 55.424514355198035, 49.596872483530355, 49.5581586899296, 46.27099283279912, 49.520068553186235, 51.93913544377973, 56.401980769249704, 57.18192838853406, 57.9707758657394, 54.26554418379261, 51.44699565825924, 50.52204585844471, 53.91056183845767, 52.451746079229544, 52.69650982272241, 53.51083701656711, 61.27815369636782, 69.02576046605265, 69.32851253017303, 68.5696437281947, 68.91925242639357, 67.34640552151588, 63.427134021635986, 69.0358252679148, 75.08244129919237, 74.55976193951022, 78.31445078695975, 76.78241222135483, 75.68439176005703, 77.4120859945974, 75.66336785593342, 79.53195448844664, 79.86641499304002, 74.90244373198479, 21.653976017428985, 0.2237447270102078, 53.4975911724952, 80.56363198064989, 46.8499150583821, 41.869603203188994, 57.506732017763206, 50.95870371787779, 34.51322932397166, 60.045286070915964, 4.452705508278263, 0.4330779305629192, 0.09859422116630501, 0.16002973060934775, 0.05001554017766349, 0.036697511471086935, 0.05869869097706772, 0.027049390576599587, 0.11285806585463787, 0.23283259822956978, 0.12358835297486476, 0.25559556790657584, 0.20510369340979284, 0.1551285145744201, 0.21629761694179428, 0.1807494212182299, 0.5637244507670403, 23.851128931968447, 70.82356314505301, 63.34841597464777, 41.71961961253997, 40.79830584987518, 80.13588182387814, 65.36562819634715, 69.15828950943487, 80.05786588115078, 88.88795268151068, 18.0259758041751, 1.086532574507498, 9.92119800659918, 78.0759314567812, 77.9088306427002, 78.390074083882, 78.45757022980722, 76.17073428246283, 73.49411672161472, 70.40390876031691, 68.44117041557067, 64.73531115439631, 62.50448273074243, 63.762696712247795, 64.2439244639489, 61.874734432466575, 64.78867500059067, 61.76927366564351, 61.31520440501552, 58.98238258977091, 57.05025049947924, 55.52248731736214, 53.13707044047695, 56.446299629826704, 55.58756728326121, 55.400462381301395, 52.78139775799167, 48.27146045623287, 48.4944393557887, 50.95199646488313, 49.98843485309232, 52.80756388941119, 50.25434801655431, 55.15701263181625, 62.21913030070644, 66.56208838185957, 63.64992072505336, 66.06492011777817, 63.02614227417977, 57.52406889392484, 56.16464599486321, 58.25126063439154, 58.223392194317235, 60.581909456560695, 60.812623270096324, 60.06308578675794, 59.065128910926084, 59.78133409254013, 57.63744108138546, 56.27948514876827, 60.5567592190158, 60.14521629579606, 59.76531905512656, 52.14040402443179, 53.339978571861025, 46.75392289315501, 49.42313109674762, 53.035794842627745, 52.640686650430005, 50.95948819191226, 48.14656434520599, 50.285087631594756, 47.3682366648028, 49.78217309521091, 48.56333186549526, 53.76805428535708, 56.07219965227189, 52.306943939578154, 53.62872385209607, 58.982743447826756, 57.2091535599001, 57.988273559078095, 51.49242454959501, 51.23283032448062, 51.379487745223514, 45.950535189720895, 50.11868892177459, 55.167767770828746, 46.1984250622411, 47.91449731396091, 47.82353362729473, 45.63241527926537, 43.17930613794635, 47.19740175431775, 46.764834926974395, 47.38911151885987, 42.92318713280463, 60.351148574583, 70.6003410585465, 59.75730957523469, 56.321893815071356, 54.66695170248709, 52.76020519195065, 51.88222185257943, 47.37170011766496, 54.913617795513524, 60.825582781145656, 58.805660201657204, 59.90703821182252, 59.37803991379277, 56.815429964373195, 57.845381613700624, 54.43315882836619, 59.070278982962336, 55.043471782438225, 59.37793008742794, 52.30889727992397, 50.05001998716786, 49.57138492215065, 53.23540426069691, 54.28379104983423, 58.58793727813229, 60.827579267563365, 61.64450699283231, 56.723670036562034, 56.60756395709131, 53.503353134278335, 56.53648668719877, 55.178915146858465, 52.795918372369584, 54.172497718564934, 65.78943244872555, 72.09223808780794, 71.40705493188673, 71.36732916678153, 69.76207563954016, 70.5156021733438, 66.1076347289547, 72.03570104414418, 77.31081039674821, 76.4124385772213, 79.64824491931547, 78.78119714798467, 76.8529756607548, 78.56449404070455, 79.34917203841671, 83.66775651131907, 83.39754443014823, 82.16279798938383, 24.593243329755722, 0.5150771934178568, 58.68116809475807, 87.43991559551608, 56.092458694211906, 55.2281173583, 69.47457375064974, 59.12560793661303, 52.740899285962506, 80.76719514785275, 13.631479740142824, 1.1253760514720794, 0.543973294477309, 0.31743306666612625, 0.19947017392804547, 0.22848757734942823, 0.24960348863274823, 0.2048567373065218, 0.20742749855402978], [0.09842974208896199, 0.0869077873686629, 0.031787598422998865, 0.07025898073709781, 0.05448465964065925, 0.05580057269863545, 0.07227419800455533, 0.10348550104085477, 0.4533212830222422, 26.813412712466334, 45.866474874557994, 44.02718920861521, 21.919795044006843, 52.64049445429156, 56.589120972541075, 44.496991096004365, 66.89951419830322, 78.81266240150698, 21.14391492259118, 1.031739269533465, 7.449810129980888, 69.22217707480155, 72.83200494704708, 70.61312798530825, 73.45273571629679, 70.51366452247866, 69.89585984137751, 62.746975421905525, 61.90143008385936, 59.9050848714767, 57.49468641896402, 59.53562505783574, 57.374093148016165, 56.2160211993802, 57.4341485577245, 55.17147441064158, 52.10991936345255, 52.40132008829425, 50.706208982775294, 52.34583816220684, 50.97221236075125, 49.272382643914995, 49.40251119675175, 48.15458559220838, 45.25003910064698, 41.234512636738444, 43.32948976947416, 42.52259154473582, 46.54986942968061, 45.74536385074739, 45.222056911837676, 43.809823220775975, 55.21269067641228, 60.31414885674754, 58.64850651833319, 56.25602153039748, 57.37218687611242, 55.62735580628919, 51.94182618971794, 52.76522974814139, 50.579465435397246, 56.34183514502741, 53.9075533805355, 54.913594261292495, 52.07049954322077, 53.46862839114282, 51.86709719319498, 53.74859148456205, 51.52606671856296, 55.941188566146366, 49.469222868642504, 49.01839740814702, 31.354854491449174, 39.447492553341775, 53.82929817322762, 40.83013588382352, 44.609908288525, 41.72579734556137, 42.704173749493016, 45.12809261198967, 43.414177663864635, 41.764507216791955, 43.500842432821955, 43.175069978160245, 45.46619699847314, 45.79493868735529, 48.99982106301093, 51.2271232758799, 50.926936441852206, 48.048246214466715, 48.91562346489199, 44.570602217028224, 49.374627067196755, 46.07897320101338, 45.8110047155811, 46.188395561710486, 45.92948775137625, 39.565995200987786, 41.644055151170306, 41.62381964345133, 42.695191521798414, 39.23659455391669, 41.222796517033736, 38.27310746715915, 47.63590312773182, 71.91070295149281, 58.9133841760697, 48.12342236118932, 49.73222955580681, 48.787507087953635, 46.613007822344386, 48.05107816573113, 45.410150251080914, 49.50370834719751, 55.328671240037494, 57.03910704581969, 56.431873152332926, 57.01218781932708, 54.09604287916615, 53.33712700874575, 52.84350456730012, 52.05871674322313, 52.43203224674348, 49.13049874767181, 46.856237919099875, 43.28550038799163, 46.05724327025875, 45.36340736573743, 46.70104934323219, 47.06066793011081, 51.12958177443474, 52.38953336592644, 49.6700599885756, 47.757935908532914, 51.30930869810043, 48.652212773599935, 49.878683013300744, 51.71274015980383, 51.87510275071668, 52.95952435462706, 58.40278571651828, 60.325417826252604, 64.08484881924045, 57.53463575916906, 57.51061124186362, 53.928075221277055, 60.31787118604107, 68.90025246527888, 72.55024540808894, 72.95534779948574, 74.22968664476949, 74.49856512008175, 72.32104562943982, 72.59230106107651, 75.87347353658369, 80.2932002467494, 72.55572888158983, 18.769288486050023, 0.38281897743863447, 47.34352573271721, 69.46013158367526, 41.18136452090356, 40.491627493212306, 42.76529604388822, 36.65101520476803, 38.46163226712135, 46.689333223527484, 1.4924205431053716, 0.08511244499635312, 0.09314048719862777, 0.030347347379692143, 0.09362515272392381, 0.05125499383035687, 0.08283671953024403, 0.01838820351798448, 0.07758485739149394, 0.034093532651182146, 0.00994183708943667, 0.0033462646317803453, 0.04208408634088213, 0.06969786729783782, 0.0520139150021057, 0.018760072172529275, 0.020624444812476155, 1.1429265742340395, 38.365753850629254, 62.183644617757494, 30.364528586787564, 28.189793978967977, 75.13609147840931, 58.86802588739703, 54.034489124051994, 72.41764576204362, 87.21567369276478, 24.181110089825047, 0.9789981608909946, 9.102147298474467, 75.59123546846452, 77.61972842677947, 77.0819793208953, 77.79692542168402, 76.79635232494724, 75.82098437893775, 67.36478574814336, 67.75332004793229, 64.73453452510219, 63.13922420624764, 62.5919202066237, 60.434522474965746, 60.356314336099935, 58.64574909210206, 58.84110666090443, 56.24066152880269, 54.19446691390007, 55.6254260001644, 55.59351359644244, 53.59291261242282, 51.52126573747205, 51.16756208481328, 50.69563035042056, 48.6526716909101, 44.897319962901456, 45.33162440023115, 47.43981992044757, 49.53458916756415, 48.39397568856516, 47.63644049244542, 48.65519769730107, 56.463930683751265, 61.855907055639456, 61.32818745028589, 59.98121023178101, 60.47151434806086, 57.696562966992786, 54.554858207702644, 54.85156197701731, 54.71593818356914, 59.72577371904927, 56.75129528968566, 56.73837107996787, 56.641566984115116, 55.03116338483749, 52.288720607757575, 58.00668516466695, 55.646136114674235, 58.082779146009884, 55.18989386097078, 52.11191977224043, 38.9445544827369, 59.690397862465154, 57.1312709777586, 42.69769791633853, 47.60270026422317, 43.88405407628706, 43.76590836432673, 48.26616917887042, 46.54139711010841, 43.24706508267311, 46.16765406823928, 44.917822191792155, 48.30719717087285, 47.21614283900107, 49.764918588822894, 51.40502629741546, 49.075734615325935, 51.37673816373272, 53.99426521793489, 48.14456785878828, 51.97516633618263, 50.684741850822206, 48.307750225067146, 48.45918901505009, 47.31594362566548, 43.65333634038126, 45.222009843395604, 42.29819666954779, 44.3204765935098, 45.02203564490042, 45.550257313636045, 41.13821060426774, 47.07753412185177, 73.69108246218774, 63.958952503819624, 54.7390527109946, 51.86670887854792, 50.914675112693544, 50.08863964388448, 49.871905157642985, 49.15026357097011, 53.25649876748362, 54.655749413274954, 58.16611382269091, 57.86578186096684, 59.54282260710194, 56.645630559613636, 53.93509234151533, 54.98077661760392, 54.60435851927727, 52.986820128656205, 50.410634856070246, 49.947336258426795, 47.084633611863666, 49.38719826359903, 48.586462082401404, 49.82392280332504, 51.08440783716018, 52.48521174153974, 53.85922978001257, 51.6285268722042, 51.12387472583402, 52.08791094441568, 52.11059008875201, 54.258895766350534, 53.931515139918176, 55.70932549815024, 54.151532649993904, 62.03021718609718, 63.35700596532514, 66.6742132556054, 61.44659596104776, 59.677520721189445, 58.35707049215994, 62.90198356874528, 72.69591439154841, 76.49621255936162, 76.03344348169144, 76.95082310707339, 77.27467752272084, 76.68742026052168, 78.09465685198384, 80.91895949456, 81.49612057593562, 76.41135600305374, 21.746614556158743, 0.13586046865149853, 55.52664110737463, 75.8143477286062, 51.669660768201275, 43.25238381662677, 54.62038532380135, 40.56000617242629, 41.84410387469877, 62.902030637187345, 2.239636841320223, 0.06486965178121483, 0.03165912356287722, 0.038530779026088216, 0.05531085099303915, 0.012435353691539457, 0.10501483470321664, 0.03202493054672115, 0.08393994742824186, 0.12281189222008952, 0.2181753444094812, 0.08715062957978056, 0.15195127216077622, 0.11672698607247685, 0.19468619998904968, 0.15159574607687612, 0.39891718135726073, 3.1867090540547527, 64.80891835304999, 69.39460446757656, 64.35429211585753, 33.603000179413826, 71.07519888108777, 74.0679516330842, 60.88517535117365, 79.16901757640224, 92.76760039790985, 25.3368031209515, 1.1395036933883544, 11.10444764937124, 79.46234026262837, 77.65084066698628, 76.63735512764224, 78.29716882398053, 80.08772296290245, 76.91122285781368, 68.32244027045466, 68.15038158047584, 67.16687863872897, 63.19214090224236, 65.82519269758656, 63.747827006924545, 64.24222215529412, 60.68760948796427, 61.9824819411001, 58.8149562189656, 57.53462399205854, 55.01621915448097, 57.7901703311551, 56.78139948075818, 55.348067360539595, 54.44597713408932, 51.556555301912375, 50.75887856944915, 46.19709537875268, 47.323176476263235, 48.770574215919744, 51.603035388454316, 51.5378769751518, 50.46668160346247, 48.84565230338804, 61.45393079326999, 66.37284971052601, 63.85812013379989, 61.06068964927428, 62.721323120978575, 61.14095703248055, 57.83337916097334, 56.48412696776852, 55.32194437519197, 62.51847382514708, 56.1622102029862, 58.407716135824884, 55.89005262620988, 59.33047333071309, 58.877008115091634, 61.716011801073634, 57.13527964007471, 61.41454627436977, 57.76852669254426, 53.97561434776553, 38.18170447503367, 47.79873640306535, 57.56191976608769, 45.08076921586068, 51.66433418950727, 45.00402412106914, 46.40737756606072, 49.80432664194415, 49.265930344981534, 47.00061644277265, 49.111573311590384, 47.49631774040961, 51.20502856469924, 51.47204391417965, 54.45470440772272, 56.952583482188565, 51.92309294977496, 55.11649454793623, 56.762999642279844, 50.70136093324231, 56.088022493547015, 52.401986891223544, 52.35178839775824, 52.71218753630116, 49.183666475357555, 46.67852709370275, 47.388554542295395, 45.69515751254174, 46.41448490081295, 47.01505860974712, 46.99209313238821, 43.40274395481233, 52.11759936424994, 67.59743721254411, 65.05334869507821, 56.81822269193588, 56.83123711616763, 54.06193787051786, 54.0983453104573, 52.79308642110517, 50.35111288870535, 56.75165222537134, 59.74353028881935, 63.47303359739242, 61.50486276995752, 62.069080029764486, 58.957801095901004, 56.560075821415076, 58.12352864973007, 58.25685785662744, 56.56124468772643, 53.82731345392043, 53.632591309085974, 47.110309447011645, 52.530773993461366, 50.569985066690755, 51.71787454235939, 54.02569124775549, 58.05925276971633, 58.461503597997854, 56.09117215679538, 54.1731684438644, 56.243968086857954, 52.30827754543674, 56.51089714419458, 55.89282966429188, 59.76340886085265, 58.161367754782404, 65.22128497400593, 66.02848129887735, 69.6142650419666, 62.68341341326314, 62.91295836048742, 60.07634732031054, 63.37505671285815, 74.03545871857675, 75.65811972464286, 78.91876251466813, 79.8400645102224, 78.28135382744574, 78.87362387872513, 79.77529048919678, 85.54221799296718, 85.34410692030384, 83.45838039152085, 24.384663451102472, 0.5410264300242548, 57.61522869909964, 82.48087083139728, 58.678806827914336, 55.35129547119141, 61.96404287892004, 50.686954067599395, 56.40967253715762, 85.35171631843814, 7.704240064467154, 0.6117674179615513, 0.24131391167400346, 0.17387497719497452, 0.19554887627882345, 0.16304424062611597, 0.31289932768671747, 0.1044521201401949, 0.15670348409443133], [0.05441536698790808, 0.09224143705420917, 0.001021000688553848, 0.047980703398465156, 0.030835508181142713, 0.11956519627523039, 0.022427907716783307, 0.18747397247822056, 0.26003380636534384, 10.727553963661196, 51.97602925762054, 58.59537801434917, 24.98867315630759, 33.56685553827594, 68.19414738685855, 40.98245328472507, 61.99305272871449, 77.01497739361179, 26.351918405102147, 1.3510372393554257, 11.318524729820991, 65.77112674713135, 67.13933575537898, 70.74625322895666, 74.50227568226477, 71.77662064952236, 71.34866652950164, 66.42791978774532, 62.62894345868019, 61.47713553520941, 56.972924893902196, 53.83413445565009, 53.393640518188484, 56.93567022200554, 54.75345173189717, 52.95797894077917, 51.61863857699979, 51.08298009441745, 49.8867787853364, 49.63151485689225, 49.20551407721735, 48.52347273980418, 48.61118478159751, 48.6284432103557, 44.18704148261778, 40.08398732831402, 42.095112031505955, 42.769426299679665, 44.16335821151734, 46.00531108917729, 47.35677549915929, 46.03661944789272, 48.80675023601901, 58.14883970445203, 58.699489485832956, 54.769113755995235, 53.3068423886453, 55.10832817323747, 54.03128454762121, 52.346901124523534, 57.501758452384706, 56.54362932328255, 56.33722636007494, 57.3248242562817, 55.51546235238352, 53.84122610092164, 55.52224413041146, 52.88153194612073, 54.93245301708099, 57.16793729412941, 56.93369334743869, 47.03849477152671, 27.788315857610396, 28.659629206503595, 48.64467397812874, 40.298372314822295, 43.12287892064741, 43.61133167820592, 42.923606826413064, 44.364666015871116, 40.7842755317688, 42.965270242383404, 44.911793508837306, 45.30720372353831, 46.956752577135646, 45.581122444522, 51.16158047030049, 52.35027044050155, 49.5736873534418, 47.10110756658739, 46.86093691856631, 42.93931199658302, 46.403976871121316, 45.89587696136967, 44.706022047227435, 41.978233245111284, 44.84663901790496, 42.74273064828689, 40.173593874900575, 39.500550454662694, 43.07668124475787, 38.60271207747921, 43.64634275436402, 38.711530393169774, 52.7207814493487, 70.6421378351027, 46.01181437892299, 53.68158563490837, 51.58054451788626, 51.656320787245235, 48.560896073618245, 47.42689178835961, 49.08740366658857, 51.68166714329874, 56.55345486056421, 57.059777936627796, 56.987378827987186, 57.98633983058315, 58.248726783260224, 54.3511656022841, 52.82293958048667, 52.31727938498221, 52.393283151811175, 47.0117598964322, 47.20368146896363, 45.88776549985332, 46.631870500503055, 46.46063943063059, 47.049834343694876, 43.86532475871425, 50.65491222566175, 46.61185856788389, 46.24684672201834, 49.76149435966246, 48.08399077384703, 50.17462976517216, 47.944734865619296, 51.40839561339348, 51.124847473636756, 50.8595383551813, 56.254770294312515, 53.17208151663504, 57.31888578784082, 56.4450248595207, 54.169308831614835, 51.465991697003766, 60.073840925770426, 71.37361280379757, 72.75510295744866, 72.71847586477958, 73.49111218606272, 72.12804932748118, 74.41879980025753, 75.9307558305802, 76.98897992410969, 83.34361184027888, 79.18666824217766, 17.935584783554077, 0.31100574219899796, 53.63392491494456, 65.64444203530589, 35.70522977459815, 40.759980370921475, 56.96311504610124, 38.99361548885223, 44.136607646942146, 46.88862492961269, 0.7334281251795831, 0.042973315238111445, 0.08754845903885942, 0.036188786954528866, 0.061357153970147335, 0.039360452248083974, 0.08333387228870585, 0.0474902194353842, 0.00889047621674235, 0.04714269897029285, 0.032971164046396176, 0.06389275178193085, 0.04187465705458195, 0.09298217512907521, 0.0721561438554237, 0.05125889321789146, 0.2031836625669272, 0.4654047878519182, 13.91353443745644, 72.61561562938076, 53.70488059136176, 20.6762566105012, 49.69766562984836, 71.74389239280455, 48.934929370880134, 70.76785764386578, 83.8757441120763, 29.629174393992272, 1.3741027371537302, 14.129757054390447, 70.9117066475653, 69.72353443022698, 77.82540967387538, 77.55485242412936, 76.50411221288866, 75.25424895748016, 71.41343270578693, 68.64039544136294, 66.96579440947502, 62.66482922338671, 58.66308989063386, 58.44018551611132, 59.58858489990235, 57.95820074696695, 56.14936051830169, 56.79907760312481, 54.20560252281928, 53.18688454166536, 52.82144123508085, 51.851544995461744, 50.38344106366558, 50.715779565995746, 53.152854058050345, 47.36994289582776, 44.491856713448804, 45.93954470849807, 46.55199535431401, 49.440448361058394, 48.39547795634116, 51.52543913933539, 49.974110357223026, 51.025956676852324, 61.00476057298722, 60.72291474188528, 57.20625100597259, 56.76529030646048, 57.19194612195415, 55.55953410363967, 56.34096830121933, 58.72827183815741, 60.02627434269075, 61.70555868456441, 60.78138943641417, 59.20504769971294, 57.4832409428012, 57.657343187639796, 56.75677876318655, 60.29024985528762, 58.859781065294825, 59.38965797424317, 50.83277602349558, 31.960036985335815, 48.10288875333725, 59.1191360258287, 42.81837355706, 47.13616571118755, 44.82073960765716, 43.840645205590036, 47.158480075097856, 45.481443251332934, 45.69750308990479, 47.90365196043446, 47.70995355421498, 48.72748305720668, 48.16044169087564, 51.853286527818256, 50.00564621340845, 47.96699823871736, 49.38716688463765, 49.318627388246604, 48.658700373864946, 48.81892919540406, 49.05931949615479, 45.28452065683181, 45.67485532452984, 47.63717789803782, 44.013617807819, 43.38031191979685, 44.808231169177645, 44.3422104466346, 42.240231883141306, 47.37863486812961, 43.60585997181554, 51.09829302757017, 73.10443708973547, 53.61551723172588, 55.729251138625614, 55.01435602864912, 52.84421059393114, 52.826975699393984, 49.16026561490951, 51.68241239363148, 55.70424995114727, 56.925232794977006, 59.04906288270028, 58.57421682726953, 59.223584821147305, 58.906798516550374, 57.49683587781845, 56.2151425884616, 55.0921013278346, 54.58049874151907, 49.59298541468959, 51.478417765709665, 49.25912895510274, 48.15815102669501, 50.48837231051538, 48.87259898647186, 49.31307723445278, 52.015115676387666, 49.008418898428644, 49.760552990821104, 48.93440377327704, 50.54988291955764, 50.759106066919145, 51.99693941300916, 53.2162787837367, 53.68678277538669, 55.73192619508313, 58.02509284788563, 56.96704918338407, 59.96323008691112, 59.04528956259451, 56.54735165257608, 57.11704846351378, 63.861269797048266, 75.30484753270304, 76.6037247257848, 76.59025530661307, 76.37455632609706, 75.39227716384396, 78.34849696005546, 79.72962625565069, 80.15636444091797, 84.80190200190391, 81.6547804494058, 18.705759817554107, 0.3871802240610123, 60.44980010678692, 67.25572032313194, 42.957013653170684, 47.91971798866026, 68.57079690502536, 38.93915337900962, 50.100657786092455, 55.6944126467551, 0.811117040293832, 0.02624144743857605, 0.0779767649909181, 0.025017982040862405, 0.052536134157449975, 0.06382376173390977, 0.06421518669794164, 0.03293515408351537, 0.02587126034702505, 0.13367638262289186, 0.2203415959112106, 0.20017335071198403, 0.1361871591859287, 0.13819504499195084, 0.2631691590912881, 0.3426000968583169, 0.2583259818775039, 0.4255088899404772, 28.336249397647, 82.84086596581244, 73.91016252579229, 38.32208610350086, 47.369480056147424, 86.37040292063068, 55.82661613341301, 76.02736380792435, 87.75095955018075, 32.722975246367916, 1.5774189176097995, 15.645559949259605, 71.77003106763287, 70.6847583093951, 78.15871700163811, 81.50266308938303, 77.09904947588521, 75.08973690771288, 70.87892347766508, 68.6731864560035, 70.25833391374158, 63.676428102677875, 60.11098969367243, 59.034357916924264, 63.36094010260798, 60.366386982702444, 59.5275685095018, 60.66717786173667, 56.21896689937961, 55.746937105732584, 54.45599878987959, 53.408616127506384, 53.51255893707276, 52.78750881072014, 54.09784324707524, 49.222976469224506, 45.47321019634124, 47.034909725189216, 48.95937750416417, 51.16663248308244, 51.643149468206595, 53.32815262579149, 49.83431316191151, 54.237569839723655, 62.022109646951, 64.26725472173383, 59.39032477717246, 57.30318454004104, 61.20385616056381, 60.054872343617106, 57.32346711620208, 62.056528445213075, 61.359574256404755, 61.033213446217204, 64.58237009663736, 59.759533559122396, 61.170680753646366, 61.75088951664587, 59.51961002042217, 64.22954113252702, 63.7212254924159, 61.901885078799346, 50.99271458964194, 31.904723721165812, 37.27509960051506, 56.49305428228071, 46.10891657490885, 48.98865015276017, 49.3793535232544, 47.27832809571297, 49.47492991724322, 47.0273591626075, 51.37531826573034, 50.2500137975139, 52.413165646214644, 52.09524185426774, 51.98399559144051, 54.76233590033747, 56.24991832240936, 53.23177214591734, 52.14070212456488, 51.531244247190415, 49.58243816129623, 53.092771191750806, 51.376777387434444, 50.270472880332704, 48.59556198120118, 51.95325597640007, 47.41703879448676, 44.270517364625015, 46.90775825131325, 48.350005918933505, 42.821538909789055, 49.392579755475445, 48.04477491686421, 55.457587780491004, 74.29862622291812, 59.797757056451616, 56.205140544522195, 58.74752283096314, 55.68584226792859, 56.10685771511447, 51.56244670191119, 55.09791035805979, 57.8222200178331, 59.958695826991914, 61.74226814700712, 61.669072797221524, 62.28617929643201, 62.313984978583555, 59.558037481000355, 58.91349400243452, 58.00140173204484, 56.677637100219734, 50.707977971723004, 53.02940137924687, 52.440763442747055, 51.714301263132405, 52.56139593739664, 51.84142528041717, 50.997947031451815, 56.44054551278391, 54.191238803248254, 52.5413251692249, 54.17283896476992, 53.77324750346523, 55.02441298577094, 53.395813511263945, 55.399183688625214, 56.78843229047714, 57.683305355810354, 61.20328741688883, 59.9725692502914, 63.58081248498733, 63.1571533603053, 59.68139994528986, 59.08081054687501, 65.7043719291687, 78.6921593450731, 77.81563512740597, 79.43155750151604, 77.00071565566525, 77.59843780148414, 79.52204658139138, 82.73004331896382, 85.64518020999047, 90.24379837897517, 87.98645081058626, 20.477725844229422, 0.3867665672254178, 63.10178126058271, 74.5682107248614, 51.6996943566107, 58.42369194953673, 77.08575264100106, 52.384885357272246, 61.82061356882896, 78.00570534121606, 1.4681923076991112, 0.2845031143196168, 0.11365017012482691, 0.14028312488188668, 0.1684347570182816, 0.21510898556199767, 0.14010896245318075, 0.14250925381577786, 0.05263596690530258], [0.04266317220284574, 0.057951747590015014, 0.07498070237136657, 0.020948568952359983, 0.049572986505565145, 0.05995688697082862, 0.023622045353535685, 0.06778069396292971, 0.0605053446375795, 0.9827752195058331, 48.72440007425124, 57.05930332983694, 45.50530695146131, 29.294880590131207, 58.82210669978973, 50.17813244173604, 55.4018077542705, 77.0701337629749, 32.78010849029788, 0.6869796014601185, 18.56166566571882, 73.02784104501048, 70.0490205518661, 73.13467856376403, 72.79271064266082, 74.10628887914842, 71.7596681656376, 67.09560917269799, 64.84638483293595, 58.511988424485736, 56.355979211868785, 53.783202478962565, 54.652125143235736, 56.906817267017985, 55.53235207834552, 51.552974177945046, 51.50428187462592, 50.67899165614959, 48.54208830864199, 47.31010321647891, 48.32922520176057, 47.56584567408408, 49.09589167564146, 49.25487710583595, 45.47340631484986, 40.27928998393398, 41.615374780470326, 42.86752870005947, 43.44032026106312, 46.58561398906093, 48.610102207429954, 45.85854776443974, 50.271096537190104, 56.30423530455559, 59.839228276283514, 51.51080085385231, 53.10097679015129, 52.65168105402301, 51.91595031369118, 54.39668078576365, 54.558407952708585, 58.42315458482312, 56.1901923917955, 55.031049636102495, 57.383255804738695, 53.328619387842, 53.41190307371078, 56.32887563397808, 56.620390107554776, 59.731076763522246, 59.294948424062426, 51.64269447326661, 36.21946034892913, 22.16991674515509, 49.120775192014634, 43.5198070926051, 41.268131271485366, 42.614084751375266, 41.52388941857123, 40.720740979717625, 40.779588299412886, 40.76596590780443, 42.016452820070334, 43.636211272208925, 41.685189047167384, 47.51753776304184, 50.061759641093595, 44.74994082604685, 49.15331517496417, 46.18569697103193, 46.07765528463548, 44.52425156870196, 48.239775549980905, 45.85429199280278, 43.101474546617084, 38.58135084952078, 41.19137440958331, 40.36563704090734, 40.76704455960182, 40.13207950899678, 42.85124301910401, 38.28137190111222, 41.85085427376532, 38.72937717745381, 58.743682830564445, 55.8544728063768, 42.37012117139755, 50.05652719928373, 50.15691241910381, 54.78194775119905, 50.73323411326255, 51.45563663974885, 51.50242267116424, 53.50516526929794, 56.359438742360766, 55.553054348115005, 56.95132047899308, 61.23510960609683, 58.932168406824914, 58.05394188050301, 55.00739382159326, 49.369739793962054, 53.19727490025183, 50.75230075467018, 48.33072746953657, 45.47312390419745, 45.46189023602394, 45.35742182885447, 45.00056459057716, 43.128303558595725, 43.261303286398615, 47.27633945403561, 45.905110220755304, 46.552877887602776, 48.13906477343652, 48.582108251510135, 48.38576224542434, 48.94312712454027, 49.9935810027584, 49.496781441473196, 52.225684196718284, 49.731758871386134, 53.11752526990829, 53.56685238499796, 50.95685628152663, 53.21012458493633, 60.005772113800056, 69.23876870063044, 73.43372791044175, 76.12834915038079, 73.23653467239873, 74.07987563840805, 75.62261442984305, 76.01834235652801, 77.94316707118865, 79.6780784668461, 81.10688024951567, 12.829033405550065, 0.44616062855047567, 60.24609573425786, 55.0174193997537, 33.62008994625461, 38.50965384514102, 48.363271374856275, 52.158721493136504, 52.721126617923865, 29.414132410480132, 0.13764689376036968, 0.12346331976474294, 0.1120267608653634, 0.18361777698080387, 0.05322848228857883, 0.10303527116775514, 0.065328890848304, 0.09026057883015565, 0.0204982050138736, 0.026864732743331024, 0.017832335865786, 0.07994376468442141, 0.01593012135520938, 0.049713406591646137, 0.031064221815716837, 0.03893241211171112, 0.12367665226901732, 0.09264852851629259, 1.0048218816518784, 54.61398793805031, 64.60815183577999, 27.912449067638768, 39.24028942661901, 71.93982262765208, 53.9021405096977, 67.12543487548828, 81.3356642569265, 39.41774529795493, 0.485274626482879, 23.307280540466312, 80.34576785179877, 76.0177932247039, 79.19648985708915, 79.54605933158629, 79.00517232956426, 76.11906882255309, 71.75212152542608, 68.5505182512345, 62.82814495025143, 61.52045811376264, 58.351249694824226, 58.974082854486284, 57.74134466725012, 56.134730077558956, 55.7386177585971, 53.66183257872059, 53.88531354165847, 53.407317822979344, 51.27401128891976, 51.66575800987982, 50.60055209744362, 51.59632029071931, 51.570212994852376, 50.00481859330208, 44.6828055381775, 44.91800654319025, 47.782964552602465, 46.102680006334865, 48.61886086002473, 52.571637245916556, 48.01998945974535, 52.655160196365856, 60.409776241548606, 61.259965665878795, 55.2718400186108, 58.82855115398284, 53.91906945936142, 54.47120581903766, 57.74139958043253, 57.253342982261415, 61.81409066723239, 60.521312759768584, 59.328665118063654, 58.941703688713815, 56.826875440536014, 55.86391395138156, 57.78539288428522, 59.07831199707524, 62.695506080504394, 59.68250605367846, 57.33874082565308, 38.151172745612364, 39.43422317504883, 63.96076463883924, 44.08798202391594, 45.71633831147225, 41.79373671931606, 44.67885963378414, 43.44570567530971, 44.11492086225941, 43.3009623712109, 45.76193586472542, 45.08897089189099, 45.39517464176301, 49.39171291166737, 51.46279496531333, 48.291048772873424, 48.93694939151887, 46.625418201569595, 46.437779857266335, 49.33129664390318, 48.40834333050636, 46.55640409838769, 46.9620713110893, 43.384583380914506, 44.18250330032841, 41.8212599908152, 43.25196412301833, 41.7314887046814, 43.97234662886589, 42.689821797032515, 44.49547706111785, 41.25908236349783, 54.14301326197963, 61.32268044256396, 47.34672246440765, 49.349292478253766, 53.2493325971788, 56.63324763697963, 54.33890035075527, 51.46405012376847, 51.593837430400235, 55.28870228798159, 59.502916412968794, 57.70682388736356, 60.734979952535326, 61.31304710142074, 58.769460647336906, 57.95102280955161, 57.77838753115747, 55.87177438120688, 56.273523146106356, 52.410329772580056, 50.002892709547474, 48.23450780683949, 49.74235319322156, 49.71258632598385, 48.08395939488565, 46.9899554406443, 46.675840270134714, 48.24148178100587, 50.405480861663825, 49.058123173252234, 50.251645503505586, 50.697599380247055, 51.91763693286527, 50.68551848011632, 51.51408387768654, 53.28834056854249, 55.064817320915964, 54.36367796313379, 57.12017067017094, 56.55784007041686, 56.51354474406089, 55.891523515024495, 63.96788766307216, 72.78366565704346, 76.03834644440683, 78.31371338136735, 78.11071503546931, 76.63227173589891, 78.10911470843901, 77.9659011287074, 81.62173055833387, 83.23038870288481, 84.08570858740038, 14.1254424472009, 0.5386046115909854, 66.59742109237179, 59.17104859505931, 41.79886325713127, 46.59286252913937, 65.30529037598642, 54.92435724504533, 57.486359227088194, 31.06181225469036, 0.2864160052230281, 0.10529447977821674, 0.25476730428636074, 0.030868122459299145, 0.028825253248214725, 0.05934647577364118, 0.15797941885407896, 0.014607963723040398, 0.04014840815216303, 0.13693637785411653, 0.18233303221002703, 0.24242729789787726, 0.16132412808797053, 0.14148021387236734, 0.12575952276106805, 0.12212568428367378, 0.25928539975035575, 0.3056730348015985, 2.2319742460404677, 78.19240231667796, 70.26333101334112, 67.34594268183555, 41.683584797766905, 77.1818507102228, 64.12549634133616, 69.44951764998898, 86.95467133675852, 41.894757363104056, 0.9163451615360476, 25.076259682255408, 80.98447876591837, 75.78820905377789, 80.33189050612911, 81.47824241269021, 79.4472469822053, 77.13681405590427, 72.39844183767997, 70.5919393416374, 63.82313651423301, 62.89467227074408, 60.36675176312847, 60.15244914639381, 61.68014564821797, 61.61670131068076, 58.91561208232757, 56.15571083561067, 56.20028465024887, 55.555815696716316, 52.33335325794836, 52.8257126961985, 52.90241856728831, 52.29152902480095, 55.12662210772115, 52.93882992959792, 43.95621784271733, 47.61600886621783, 48.61465215682984, 47.3246826664094, 51.51898684040193, 53.919638203036406, 48.95304679870606, 56.550909242322376, 62.74943082563339, 65.47196757408881, 56.583735558294485, 59.323044361606726, 55.48568764040547, 56.957945362214126, 60.686899538963075, 59.26469910529352, 63.20167618413126, 61.39133368769, 61.03979910573652, 60.302550408148, 57.956035598631836, 59.21426526961788, 60.890227363955596, 61.787536221165816, 68.72000386638027, 65.52771229897776, 59.56634898339549, 41.22800934699274, 29.582066728222756, 55.690741308273815, 48.27717534957394, 45.540094452519575, 47.691722377654045, 46.36421188231438, 46.42542831359371, 45.63682402333906, 47.16305748108895, 47.58190385756954, 47.4530343855581, 47.6755347559529, 52.90878457407798, 56.943005054227775, 52.611072755629024, 52.134081163714015, 50.40207232198408, 47.59736191841864, 48.980268047701934, 52.17937277209375, 51.606902845444225, 47.638825293510195, 46.17826407955539, 46.98502109896752, 45.60762589977634, 45.90877763686642, 43.96183075443391, 46.47843130173222, 43.768155882435465, 45.738487935835316, 44.40516841027045, 58.310315839705936, 71.00705162171396, 53.83748023740707, 50.304075825598936, 57.19057329239384, 60.47776660611553, 59.284181517939416, 54.26037842227567, 54.11098710952267, 59.195022121552505, 63.061271021443034, 60.80451573095014, 63.11982808574554, 65.41115122456705, 61.498292799918886, 60.84610854425738, 59.81634124632805, 56.436458403064364, 60.5386810148916, 55.46758197969007, 53.943972587585456, 50.61249571461832, 52.119215380760934, 51.765574486024924, 50.422562783764256, 48.86726064066733, 49.29345753885085, 52.955248971139234, 54.1027658216415, 52.13323785412697, 53.55755636768957, 53.11346561677995, 53.835974047260905, 53.89974001915225, 53.85175374246413, 55.16669304140153, 57.47172878634546, 57.56654424052085, 59.15425300598145, 59.74932755193403, 58.49253739080122, 59.73689756085796, 66.23087559976886, 73.94408318304247, 78.937425151948, 81.04478128494756, 77.85926757320281, 78.669644940284, 78.54138343564927, 82.09875352921026, 83.3568145382789, 86.8583300805861, 89.51015826194518, 18.387053512757827, 0.673455085244871, 71.48129755450834, 67.6680398756458, 52.95259744890275, 53.739628868718306, 66.76001118075463, 66.78802474852532, 74.07168572948825, 49.332034049495576, 0.19898272750358428, 0.2013057972034139, 0.288158027875808, 0.24742615949963373, 0.15581767194934432, 0.2352662144168731, 0.19926766624614117, 0.308574945215256, 0.08228665307885216], [0.0851789644108184, 0.0527814738152008, 0.14238076554911752, 0.041192735380102555, 0.07030419524638884, 0.04820729305426921, 0.25213684946779286, 0.10919192144947668, 0.22662092751312643, 0.3891672109884601, 16.26070330219884, 65.24270503751694, 43.47304459541075, 24.996362963030418, 43.296031951904304, 51.618120824137044, 45.90312550144811, 75.99477675653274, 43.8925067840084, 0.08443769773528462, 31.971123564627867, 82.19884457126741, 68.81992232414984, 75.65054170546993, 71.28533594069943, 73.52479750110258, 69.81600038466915, 69.56300750855478, 64.74939246331492, 58.72737753775812, 55.04789229362242, 51.381378327646566, 57.19762571396367, 54.94537722679877, 55.128528379624896, 51.10834606232182, 50.40660265953311, 48.41578014435307, 47.88968832262101, 47.02140500468593, 49.401707110866425, 47.76854591984903, 47.39443809755387, 48.486304360051314, 46.29184415263515, 40.079500136836884, 43.839931334218676, 43.08876998962895, 45.154066547270745, 47.824345557920395, 48.26052096582229, 48.25474331455846, 48.057067624984256, 57.84091403407436, 58.01168226426648, 52.01762207092778, 52.78185275293166, 52.805794900463475, 53.88372890410885, 56.739179088223366, 58.675406132974935, 60.751795153464045, 58.20366267235049, 56.841882428815296, 54.26963913825251, 50.790732137618534, 54.74963526571951, 53.210795310235795, 57.73284096871653, 60.455436552724535, 62.19909091149608, 50.35118741373862, 51.56380776436099, 16.895021161725445, 41.68551460389168, 47.17764085338962, 37.454038127776116, 42.388297434776064, 40.581892997987815, 40.39675320348432, 40.365746867272165, 41.0092979861844, 41.44838771512432, 43.16655451251615, 42.452314438358435, 45.5374703868743, 45.79458567403978, 46.41526937484742, 46.79451550206831, 45.50767606304538, 43.516053384350194, 43.87745664965722, 46.07991064748457, 43.06550248976677, 42.05108342632171, 41.41205087784798, 42.623643567485196, 38.68005729490711, 40.53286337083386, 40.99382423585461, 42.815737724304206, 37.85963473781463, 39.423122867461174, 43.968816495710804, 53.91435084804412, 43.56572235784223, 40.038228957883774, 46.940247243450536, 54.10281289008356, 53.07195517324632, 51.04559206193494, 51.894914642457046, 52.366775774186664, 52.343618100689305, 53.41477817104709, 56.12412006624284, 56.295935569270966, 58.215457239458644, 61.59177857060587, 60.411796262187345, 57.563853494582645, 56.84801309339462, 55.462792765709665, 53.0667305761768, 45.36032438278199, 48.20202273707236, 45.30837258984966, 45.555893759573664, 47.34160769370295, 43.20417004246866, 42.11517103256718, 44.52279636936803, 46.54290330025458, 48.04500633670438, 46.66657170941753, 48.34809180228941, 48.15638596011747, 47.06930891160042, 50.431137084960945, 49.05217293770083, 50.753901081700484, 49.669805034514404, 52.02128164229855, 52.55635176935504, 51.06761617045249, 51.48058291404478, 60.568820507295676, 72.1306380917949, 73.50650356661889, 73.66626954847767, 74.32545523489676, 69.7631033005253, 76.83963175742858, 72.99528537258026, 81.659314709325, 76.67688477423884, 84.11274156262799, 10.094151977569828, 0.8076809214488153, 64.22610513625607, 52.214560354909594, 33.29419589811756, 33.523450589949086, 32.53213624800406, 25.100719582649972, 57.055396649145315, 15.030128302112704, 0.34725778886387426, 0.04448744588561597, 0.07308725477947343, 0.16711507863815755, 0.07637602427313406, 0.11978179997494144, 0.1708282148765941, 0.2168992870757657, 0.14391810483028813, 0.14542089354607368, 0.03909669966707307, 0.02724277989698514, 0.02268794668658126, 0.13657587219870862, 0.06209909863349411, 0.1644159976633326, 0.08755472563808003, 0.12118596253135513, 0.4447585650749745, 14.257338027800284, 77.18134080210041, 37.63604002614176, 25.528842364588094, 58.0909376759683, 57.13472266351023, 57.81644236656928, 81.2906119131273, 50.388065538098736, 0.11906645771476532, 39.39283432499055, 88.86379872598957, 74.07055608687863, 80.94580419601934, 74.23976713611235, 76.9615311776438, 73.70260638575401, 72.19834604570943, 67.28898986693352, 63.98863307891354, 58.4520467635124, 56.13556554240566, 59.75123382383778, 58.9062140833947, 57.15897075591549, 54.96084705475838, 54.3644977384998, 53.13388939826719, 52.06982097318096, 52.2035502618359, 51.50618814652967, 51.046886444091804, 50.49127094207272, 50.709578298753314, 49.14871031238187, 45.26146496495893, 46.6276421854573, 48.44484490732993, 49.22664780770579, 50.96258294197821, 51.65510093012164, 49.43849109834241, 50.065019130706794, 59.88034256042973, 59.76396191504694, 55.75224015020556, 56.802592046799205, 55.31742580475346, 56.19190254519063, 60.52049298440257, 58.837356875019694, 60.86244129365491, 60.0732643373551, 62.85534266502627, 55.835700342732096, 56.98189927685646, 58.45083082875898, 57.39512097450995, 59.26876660316222, 62.57966672220538, 60.24652327260664, 58.72524769075456, 53.55332020790347, 32.45508128596891, 59.95999805388912, 46.56714354791949, 42.02614499676613, 44.613603161227324, 44.46643583236202, 44.04745609529557, 43.94277195776663, 42.14492613269437, 44.350831816273356, 45.282959553503225, 44.74534773057507, 49.30229071647891, 49.3363957251272, 46.91000576942198, 47.90789988733108, 47.28544327520555, 45.97110409890452, 47.728514209870376, 48.90588029738396, 46.10404499115483, 43.535590710178504, 42.786304258531146, 43.843284960716005, 41.69572061108005, 43.03753599043816, 43.748065502412864, 44.86944367808681, 40.10398749382266, 43.86571699573148, 44.995908737182624, 51.841091878952525, 50.545329047787575, 43.17067692356725, 51.615375165016424, 58.112479332954656, 57.22028524644914, 54.876410192058934, 54.186441744527514, 53.5309430860704, 55.28697644510577, 57.51405116050475, 57.94757896854032, 58.3209180062817, 57.719493143020145, 63.22524962886688, 62.03457493935863, 59.71827022490963, 60.157689432944025, 58.88630413240003, 54.84214436623358, 49.36511531952889, 50.07715886639011, 51.27632548732143, 48.707624097024244, 50.00124139170493, 46.1905607100456, 46.03705090861167, 47.314868896238266, 49.22345499838553, 50.74755860913185, 50.208695550118726, 52.3536083775182, 50.928881937457675, 51.78255442650088, 53.749952547011844, 51.5403284565095, 56.43672904660625, 53.877641385601414, 55.84521993514031, 55.079345780034224, 55.69684843863211, 54.9509979832557, 65.00320511479532, 71.83173779518374, 76.9651476029427, 75.51337642054405, 78.1582933856595, 72.50855061315721, 80.83732712653376, 76.42597075431578, 84.50675149117747, 80.21932632692399, 87.49230277153754, 10.868477859804708, 1.161174175720061, 69.99329936119818, 58.05346335134199, 44.493868889347205, 39.55255323840726, 44.34122985409152, 25.799923250752112, 73.44369073067942, 20.059640407562256, 0.44248794175444117, 0.21309423560817398, 0.18922598491753304, 0.08547158701525581, 0.047311900979689056, 0.0990314505273296, 0.10541208959635227, 0.007752810751328306, 0.04325842635045129, 0.25831124234584074, 0.1674968508943435, 0.20833382653372906, 0.20222980649240557, 0.3122172642859721, 0.25068177270793146, 0.44532614429631545, 0.22084177471697333, 0.5484399547980678, 0.6033186938974165, 28.682865327404393, 79.09378651649722, 58.530517701179754, 34.689645767211914, 56.6742128710593, 67.12815700038787, 58.44256247243574, 86.86354683291528, 53.12918255406042, 0.2714236645448593, 38.90562888114683, 91.78952601648147, 77.96987841206213, 85.10066109318888, 76.67559823682232, 77.58259927072834, 74.72391313122165, 76.57999438624229, 70.72810834453952, 63.986420862136356, 58.438628335152906, 57.498263620561175, 63.55700369804137, 62.28434362719136, 58.883742824677505, 56.78935796983781, 58.03702469794982, 55.01463843930153, 52.917072542252086, 53.557391628142334, 54.752679024973226, 53.30729346121512, 51.60312952533845, 52.82552442243023, 50.106400136024725, 47.75094232251568, 48.97710661734305, 50.73739574801538, 51.257898192251886, 52.7135132974194, 53.137643106522106, 51.01338940282022, 53.161322455252375, 62.45032264340309, 63.832781622486735, 57.21759450051093, 58.221999752906065, 59.597367086718165, 59.57756696208831, 62.00529444602228, 61.34752865760558, 66.31756782531738, 63.374739000874186, 63.245453757624475, 59.70242384941348, 55.897548275609175, 61.39921765173636, 59.60721615822085, 63.54275764957551, 65.17063933034098, 65.22973768172726, 58.14352489286854, 57.74938160373319, 24.511134393753547, 49.72288254768618, 51.622898271006925, 43.14005105726181, 49.345440710744555, 46.41118618749803, 44.296208889253684, 46.4128767290423, 46.34949907179802, 48.5925692127597, 48.535224160840436, 48.686337394099084, 52.83829958208146, 51.85923676336966, 50.060775126180346, 52.85436561030727, 50.88403747927759, 49.04062155754336, 52.51551989586123, 52.199349403381355, 49.97590680276194, 46.67973126134565, 47.625006783393125, 47.85885457069644, 42.954448423077984, 44.73032113044493, 45.582989492724025, 46.69933134509672, 42.17751710645614, 44.76912121618948, 49.369492684641195, 56.845596913368475, 58.86690408952775, 48.706729796624955, 53.09318696298907, 60.17001352002544, 58.53262401396229, 60.23132408818891, 59.543206999378825, 57.4344309683769, 59.36851247664421, 60.924548102963364, 63.14446449279786, 60.96632919003887, 60.59117017253753, 67.89921652886176, 63.15144631170458, 59.49027853627359, 61.28173874270532, 59.56373276249055, 55.82327035165603, 49.81949836977067, 50.73724669794883, 51.585616142519065, 51.41046270247429, 54.011723687571866, 48.49676139893071, 48.0498073177953, 51.49338160791705, 52.266014006830034, 53.2009619282138, 52.684185735640995, 55.22361447734218, 53.18120887202602, 54.76659167197443, 57.2833255798586, 54.629489144971295, 58.801930027623335, 57.08938790905861, 58.285240127194314, 58.568878481465006, 58.91032864970546, 56.42313018921883, 66.48975987588206, 75.17513475110455, 81.87226018598004, 78.36905017975839, 77.68530261132025, 76.19770449976768, 80.9596658522083, 77.92580666080599, 87.84035821114817, 84.12083733466365, 90.63117950193345, 14.229827504004202, 1.2908929634478785, 77.37548243614935, 63.61594123225059, 52.716882613397416, 45.321771406358295, 46.12566509554463, 34.74706926653462, 82.31071056858187, 26.41291322246675, 0.4820606731359036, 0.2987652812753954, 0.2696230821311474, 0.24605837079786488, 0.14391104149962627, 0.33840570418584737, 0.39423678250562766, 0.3450666548263642, 0.2740747577721073], [0.04193477963487949, 0.17254285754696017, 0.022365961847225987, 0.012099885704716849, 0.08626820354331886, 0.111064677006535, 0.16356291279437082, 0.11706899070451338, 0.01503432899968879, 0.2973672627441345, 3.7347602651965235, 57.26559254430956, 48.94908912720219, 33.974644753240774, 28.156247908069243, 52.70352302059051, 51.614837800302816, 73.60606901107296, 47.4867550019295, 0.4958049952983857, 48.8429811693007, 75.76826772382184, 69.70183587843373, 71.53665004238006, 71.77543609373032, 72.2257947921753, 69.44456761883151, 64.34469799841604, 60.75513701285086, 54.60886924497543, 56.147626830685525, 54.062334029905266, 55.28456810981997, 51.41500480713383, 55.342042599954915, 52.4888163997281, 51.82113485951578, 47.941918603835575, 48.707263238968395, 47.69149488018405, 45.48047442590037, 46.79677870965774, 46.80405470632738, 47.82292958228819, 48.11589533282865, 39.390065131648896, 41.06188520308464, 44.82621131404754, 47.68037103837537, 47.86293383567564, 48.95831454184748, 48.04053875707811, 48.40662141000071, 54.238334701907256, 55.18646570944018, 53.04059582371866, 55.37903447305003, 53.48813433800974, 58.24998586408554, 58.86207565184563, 60.81930306649978, 59.3681594633287, 58.87211691948676, 54.87448430830433, 53.97001320315946, 53.86744714552357, 57.84933928520449, 57.442660100998424, 61.55375119178527, 57.319662417134936, 64.1688463764806, 50.27132011228993, 58.18934994359171, 21.191108880504487, 32.399848430387436, 54.49119813980595, 37.39821103311355, 44.20508046304026, 40.4845436926811, 41.90896026549801, 38.21867673627792, 38.53920105964907, 39.85908254500359, 39.97376872647194, 39.94195438200428, 45.93849743566206, 44.53935269386538, 46.042706966400154, 47.93046528293241, 46.635973299703295, 45.37113051260672, 40.0270894265944, 41.87208606350807, 43.409815988233014, 40.29651311136062, 38.61280433593258, 39.64293641428794, 39.14012385952858, 40.16369381258565, 40.62349757840557, 42.0597557867727, 39.61757436875374, 39.17688039041335, 42.80036987796907, 53.43086381112376, 41.708225127189394, 45.080361289362756, 51.86301008347542, 53.54021164678759, 56.00060070714643, 53.821108264307824, 55.294405414212136, 50.43655387816891, 51.255670285994015, 54.95576366301506, 52.996500538241484, 56.09205861245432, 58.276677593108154, 61.2181963459138, 58.63076956041398, 59.06438366059334, 54.27172583918418, 57.44176187822896, 55.68627372864754, 47.670274857551824, 48.54819936137046, 48.71657494575747, 45.91385710623957, 46.22086886436709, 43.40985913430491, 38.285580604307114, 43.52488656197825, 44.91483334572085, 46.376449677252005, 47.737916131173414, 46.13139175599622, 50.466724749534364, 47.665944560881584, 48.65221669597011, 49.308268408621515, 49.215865212102095, 48.5535063282136, 49.89342328040831, 52.8857445716858, 50.6182223750699, 50.47158456617787, 61.43072605133057, 66.83594042255034, 71.88352877093901, 73.9297273082118, 75.23241704510104, 70.05194664001465, 77.03152195099862, 75.7601405728248, 78.12696149272304, 70.83751109338576, 80.27871101133286, 6.39464940755598, 1.4905938217716834, 73.08967328840687, 45.34282276707311, 29.86298687996403, 35.7174087339832, 32.23220240685248, 38.09906798024332, 66.675091866524, 13.208845334668315, 0.3719060549572591, 0.05581348128015957, 0.10422445413085724, 0.13958158752610608, 0.054689174472925164, 0.04650347903671284, 0.13187642840127792, 0.11013002675627509, 0.030717842821632663, 0.1102550216620007, 0.11224604587280944, 0.10142467855926483, 0.07443275798352496, 0.14122107697110023, 0.06919231055484665, 0.06391435929183518, 0.03613897974813177, 0.0709976350528098, 0.10968359667927989, 2.0446711418128785, 63.14646490158574, 50.85848715997512, 27.972255406841157, 39.36422847932385, 58.6174060452369, 57.474803924560554, 82.18074675529235, 52.441995066981164, 0.8308096674661484, 55.565354900975386, 81.7713140672253, 76.80982174411898, 76.63109502484723, 72.58555458438012, 77.41302736343877, 71.52654601681617, 67.87770625083678, 64.65535756080382, 60.058920229634936, 59.98723891473586, 59.144694189871515, 57.09068621358564, 56.853441653713105, 58.73137835533389, 54.948821067810066, 54.20862274785196, 53.342261391301314, 52.53921101170202, 53.29698547240227, 50.76833148156443, 50.44058999707622, 49.561731969156575, 51.188229053251206, 50.98700754104122, 45.97482642819805, 45.566531227480986, 46.81244073375579, 50.08493692644181, 51.27004577267555, 52.27305466128934, 49.86021649452948, 52.133834054393155, 58.32163972239341, 56.51783973939958, 56.366357803344734, 56.961102870202836, 53.452617276099424, 58.22077989578248, 62.98821295461347, 61.857260273348906, 60.473604971362704, 59.30547606560492, 57.760230879629816, 56.787722341475956, 59.822770011040475, 60.33164655008624, 59.171436909706365, 64.78328174160373, 59.31889841633459, 63.44562015225811, 56.5395853596349, 59.24206702939926, 32.49056304654768, 49.68472573064989, 53.14702149360411, 41.68740910868491, 45.91201359225858, 45.774338399210286, 44.58029047135384, 43.14035307976508, 40.80506409368208, 43.1168306258417, 41.52646641577444, 44.01082508025631, 48.41440731479276, 48.44670411079161, 45.91300987428235, 47.75128749109084, 48.68256407399332, 47.442036059594926, 43.997602770405436, 44.31241220043552, 46.944134312291304, 42.50001438202397, 43.41020822525025, 41.925140042458814, 42.50372494420698, 43.17726650545674, 40.407998638768355, 44.66652770196238, 43.309493526335686, 42.230782893396196, 43.72369973890243, 52.06290583456717, 45.66067987872709, 47.82986825512302, 53.18150697215911, 56.85815634266023, 58.89538049697877, 56.42386759481123, 58.5408962926557, 51.81225461344565, 53.59934922187559, 57.00635525488085, 54.7312040482798, 58.583677584125155, 59.90842673086352, 61.29643194137081, 61.873698926741085, 61.755553214780754, 58.05655810140795, 60.434522474965746, 58.766095253729056, 48.94331539830854, 51.414785154404186, 52.842021911374985, 50.947297465416696, 49.85110875098936, 45.89768517401911, 43.07454355301396, 49.88999120650753, 48.68516852778774, 48.4287828014743, 52.63903141021729, 49.70159192239085, 53.42575296278923, 51.53104028394146, 53.12874324860112, 52.02995792511971, 53.30953705695368, 52.08794232337706, 54.440223017046534, 55.32350547852055, 54.250423446778335, 54.54900603140555, 63.672058582305915, 71.27680870794481, 75.41681551164197, 76.53429092899447, 80.53737563471641, 74.1713688450475, 81.12728441915205, 76.3312533593947, 82.7650151714202, 75.17207530237015, 83.24166943950038, 6.955078148072766, 2.1944016170117164, 78.96398744275494, 53.37250286532987, 36.507291716914025, 44.575058029543975, 40.71777566786736, 38.35934077539752, 73.99475236092844, 12.851375226051578, 0.2946906128237325, 0.0892887120285342, 0.14248055616213431, 0.10501453592892616, 0.0784601511493806, 0.03600797488264019, 0.023838886540503274, 0.15107661425586671, 0.06913567367460459, 0.22240632544121436, 0.2858321542941755, 0.20364876986751634, 0.12572307995851004, 0.29720022493312437, 0.20555727874800084, 0.3069256192013141, 0.2641550223192861, 0.483107945971912, 0.5124550583141466, 6.68445029566365, 80.10708378207299, 62.85012591269709, 47.16365368135514, 41.25332432408487, 67.90150719304239, 64.57389385469499, 87.0817247513802, 56.33188409190024, 0.7093621165521684, 57.42410729008337, 84.10393191922097, 78.65568130247055, 80.50395704084828, 75.12877233566778, 82.49812926015547, 72.43342937961702, 70.7695677972609, 66.12059424000402, 60.6202623921056, 62.35666036605836, 60.180278362766394, 59.4548987573193, 58.5195585989183, 61.83525185431204, 59.134735292004, 58.35094374995078, 54.53999242474956, 53.14758631490892, 55.46456959939773, 49.94716759650938, 53.26659102593699, 50.84807718953779, 54.69089777238908, 52.23216395224295, 46.296327421742106, 47.49931443122126, 51.36659099209694, 50.207146213900664, 52.90082216262818, 54.29091015169698, 53.970111262413766, 50.96315560802337, 60.91375766261932, 58.68673001566241, 57.66568606899631, 60.53973221009778, 58.285322496967936, 61.16299290810863, 64.66889366026848, 63.85792793766145, 64.61527486001292, 62.708002751873394, 62.00034049249465, 58.80267527795608, 61.69388963330177, 62.945243389375754, 60.612025414743734, 68.87502378033054, 62.22106010683122, 68.56769038784888, 57.718249751675515, 63.313197012870546, 26.671111083799794, 38.88543259712958, 57.29086437532979, 41.10942432957311, 49.239575939793745, 46.49510921970491, 49.1964259455281, 44.71399230341758, 43.85021578881049, 46.6706431296564, 45.754620644354056, 46.421250989360196, 53.5775996792701, 50.787060799137244, 49.170440243136504, 50.95008234823904, 50.185020123758626, 48.945237359692975, 46.69653077279368, 45.19750679692915, 50.02926280421596, 45.1240368812315, 45.06707229921895, 46.45310455752958, 44.785908960526996, 45.33627633125552, 44.64108720902474, 45.88314102542016, 46.98461709483978, 43.414126673052394, 46.41460649428829, 54.2160987854004, 53.304500733652425, 49.63232286514775, 54.255597053035615, 60.190653031872166, 59.52925905104607, 61.551029066885675, 60.765719567575765, 54.00139608690816, 56.59116060503068, 58.96287272053381, 57.84893135870657, 61.51525705091415, 63.6533018081419, 64.11170921018048, 64.5692026999689, 64.37432366032755, 58.88726903546242, 62.18331121629285, 61.78485724233813, 50.148047862514375, 54.11417207410259, 55.212321973616085, 52.962093507089925, 51.48443075918382, 49.80493460932086, 44.007039993040024, 53.46380387583087, 50.97100819310835, 52.06963662178286, 55.6629591603433, 53.49376293920702, 57.43129699460922, 54.30084943771363, 57.37021000154557, 57.16485038880379, 56.879792136530725, 55.38741657810827, 56.71379743083831, 59.83937340397989, 56.98591578391291, 56.186203341330256, 67.31223383257466, 73.33449978982249, 78.80087960150935, 80.33309075140184, 81.69227830825314, 75.14866659718176, 83.96217746119346, 80.48312141049294, 84.59823685307657, 77.09674312222388, 89.09838784125544, 10.303099578426732, 2.5358324185494454, 86.5214220170052, 58.99494201906266, 47.43375593616117, 48.78943297170824, 45.75603661998626, 54.521463148055545, 90.30714465725808, 21.32814080484452, 0.6150338942966154, 0.3841462094456919, 0.31443858218769877, 0.28990519863943903, 0.26381576794289774, 0.11650772404766853, 0.23836644967236828, 0.4441876150667668, 0.14599435632267307], [0.08613484295746011, 0.030573873833242445, 0.04051743270528894, 0.08359906894545402, 0.07216887623672524, 0.02459007022421687, 0.10684342529144018, 0.04191114199197581, 0.0532251306539101, 0.04928095378882943, 0.06636586746261006, 35.780845226780066, 54.17739283653998, 34.47171888043804, 27.366525742315478, 52.09747760526596, 45.08787655061291, 62.11486585678593, 56.63669932273127, 2.4229872995807282, 52.46308957376788, 75.5878386958953, 67.18507843632852, 68.86776739551176, 63.9872641717234, 65.92418547599547, 63.11764332555956, 58.962594232251575, 58.13853563800935, 56.8806315237476, 55.78722376977244, 53.403607260796335, 53.69258788324172, 54.470354664710264, 52.24917527168028, 50.37099146073865, 49.96708146987423, 48.72433731632848, 48.92604912481001, 47.72242669136294, 46.09617279421899, 48.11600908156365, 49.17829282822148, 45.58490360936811, 47.639609767544655, 43.349642907419515, 41.48486183535668, 43.018947878191554, 47.644512730260054, 46.26941211761967, 49.25718345949727, 48.69339766040925, 50.2767212160172, 54.77848822070707, 56.401227674176624, 53.54657765357725, 54.08218514534735, 53.66076961640389, 59.8725684227482, 58.73551645586568, 59.10289741331532, 59.02220641413043, 58.786279770635794, 54.43839911491641, 52.40843526778683, 56.785788612981, 58.24026623079854, 59.698630917456846, 62.34831356233167, 57.8713280923905, 60.607279346835234, 53.162001025292184, 60.31897337205949, 27.240152858918716, 24.16887229488742, 53.08336534807759, 35.553414437078665, 42.851984347066576, 42.690163043237504, 42.775482439225726, 36.414763004549094, 41.060618277518984, 39.08777982957902, 40.400114674722, 40.57062795085292, 43.93958699318671, 47.533905813770915, 48.01397254390102, 45.01809758524741, 49.48100174626997, 45.219079832876886, 40.87521176184378, 39.394968094364295, 42.54852625631517, 39.49642019887125, 41.9767858905177, 40.266746244122906, 40.18588266065044, 39.57997845065209, 43.12444786871634, 41.068153150620006, 40.340004351831254, 41.0831444494186, 50.31959664437079, 54.659652171596406, 33.85140780479678, 48.728628389297, 55.25885305097027, 56.676158366664765, 56.25027918046521, 52.76466492683657, 53.18190313154652, 56.3493464839074, 48.255288524012414, 54.071465307666415, 56.19642503799931, 57.62735666767244, 58.45566318881128, 62.08208268688571, 58.14852199246807, 53.77542441891086, 55.15159191623811, 57.805781364440925, 56.766388570108724, 46.93320658899123, 49.73780716619184, 51.68910003477528, 45.49985093455161, 46.173106162778794, 43.045459178186235, 39.35388518917946, 44.203935130949944, 45.324838699833045, 46.331111000430205, 47.45689792017783, 47.870943315567516, 48.8571487703631, 46.5239151062504, 49.074502991091826, 48.23753587661251, 49.26573814884309, 47.409146985700055, 48.92497047301262, 49.2053375705596, 49.26529099864345, 50.601128685858946, 55.56517447194746, 67.83373648120512, 73.11963235178303, 73.14787341702369, 73.07810229639854, 71.98779321485951, 75.25570807918426, 73.11884787774855, 78.93536982997772, 70.49314268173711, 75.29004450767272, 3.564474976831867, 3.0916442842252794, 76.26938973703693, 40.43720852944159, 40.41688280720865, 32.33875751495361, 39.831880907858576, 44.59980034059094, 52.10180397956602, 6.224307735120097, 0.3412253061129201, 0.08722337728907024, 0.09705406268157306, 0.05323299454645284, 0.036842279106138215, 0.09324246116222874, 0.11459071925210376, 0.09797843969276837, 0.03286130703805435, 0.09250346210695083, 0.015900453642731713, 0.049039731853671616, 0.0518145750937683, 0.022185080827424125, 0.039455876159932346, 0.06891893207906716, 0.052804421978972615, 0.027468595803985675, 0.04524060607617421, 0.11597210601452859, 39.70011280428979, 60.440747276429214, 32.22807018987594, 40.13140486132714, 61.53397852374662, 47.31541410569222, 70.3259006623299, 63.601981516807314, 3.1773196353066355, 58.41567854727469, 81.65309383023171, 72.02376919407999, 74.33928551212435, 66.01533351405975, 67.18882822221326, 65.73784151384908, 63.73001552397206, 61.711606979370124, 62.30777586660078, 60.15179018820486, 57.3241731428331, 59.02395186885711, 57.982174273460146, 56.53754964951546, 53.488863898861794, 52.93359356541788, 53.94110141261932, 52.38778398882959, 53.00171336820049, 51.77897330253355, 51.4189624786377, 51.40584999515165, 51.15442214473602, 49.552173153046645, 45.305658309690415, 45.65306263585245, 45.80145766658168, 50.78468384281282, 50.11166787916615, 51.99804159902757, 50.95163952919745, 54.64534728757797, 56.20248509991554, 60.04116758223503, 57.13267126391011, 58.960813476193344, 56.986366856482725, 60.70873145134219, 60.64941736959643, 61.17825092807893, 60.61618312712639, 59.93917811301447, 58.76735433455437, 57.082209971643266, 59.634539388841205, 60.849544540528335, 60.74933974973617, 63.237875738451564, 63.52405186622374, 61.4484041736972, 58.16225813281152, 62.7555654125829, 37.31608836881576, 41.39468654509514, 55.20390064485612, 38.92908073240711, 46.0925446018096, 44.31785645023469, 44.42529801399478, 40.8574983381456, 43.32513593858288, 42.31415679377895, 43.23645507135699, 44.375562360209805, 46.215816851585146, 50.11305639820714, 47.043150624921246, 46.87642635837678, 48.8940582736846, 47.0994484040045, 45.84868692582654, 41.788041437825854, 43.67293642413232, 41.77622725886684, 46.12051894587856, 41.72666418936945, 43.17923553528325, 43.043211660077496, 43.303660961889456, 44.297581718813994, 41.248970493193596, 45.187081137011134, 49.57430316555885, 54.800225996202045, 42.133923884361025, 51.94075146029073, 55.982232247629476, 59.94432818505072, 57.78809147496378, 57.190749799051595, 57.602363324934444, 57.170031839801425, 49.534279300320534, 57.340968731910955, 60.706115230437256, 60.62917009476693, 58.57081220995996, 59.576170598306966, 60.626997101691465, 58.86893587727701, 56.96091459643457, 60.92947459989979, 59.47510680844707, 47.5465750694275, 51.84892877455681, 53.32777215588478, 48.26383536861789, 47.18931382702243, 47.323141174931685, 43.88775679372972, 48.69047941700105, 50.051608547087646, 49.57946108233545, 48.77413965040638, 50.57352304458619, 51.942465536056034, 50.15122498235395, 52.40989438949093, 51.0641291833693, 51.906740588526574, 50.19308451683291, 52.2886735393155, 52.55026817321778, 54.00328666933122, 54.08318534974129, 58.75830934893701, 70.56879735762074, 75.82901739305066, 74.96706085820352, 80.22162483584496, 74.40103930811729, 78.15583798193163, 75.17159677320912, 81.77384791835662, 74.32945605247252, 80.32148053569179, 3.358952340579802, 4.557316591662746, 83.10826178519957, 45.19167423248292, 49.707263669660016, 42.79401563828991, 45.80654890306535, 47.41275948862876, 68.6882483574652, 7.74541808712867, 0.35858093610694336, 0.10760520780158621, 0.18346267481965406, 0.011759410375699162, 0.07557878721385233, 0.10693406881464106, 0.10208551366362842, 0.040961886275439494, 0.006581441726490495, 0.23360838482697166, 0.1940351325057207, 0.11645634253058704, 0.21689069156925525, 0.14126241507549442, 0.13986430461368254, 0.23613036159546147, 0.17536359328416087, 0.05869746140594925, 0.14513099055376746, 0.2481358020656532, 58.23976808978666, 69.89711499983265, 52.05901484335623, 40.58156744126351, 68.94343776087608, 56.392567080836145, 73.93199443817139, 67.85690984418316, 3.1530364867179625, 60.73495641831429, 85.74116060810705, 76.94542592571628, 78.44563053500268, 69.44462253201392, 69.646938385502, 69.36768131871378, 65.5879363706035, 62.98663223943403, 63.34367382910944, 62.549405636325965, 58.36185186139999, 60.63250803178357, 61.290736659880615, 58.806440753321496, 54.97887034570017, 55.21594232128513, 55.29432304443852, 53.75960157763574, 55.574537169548776, 52.21584689232611, 53.06544011639011, 53.32052361580634, 51.83891888587706, 52.481889494003795, 46.20520684026903, 48.00012265482257, 48.810166620439105, 53.37873943390385, 52.883222487664995, 54.82235600871425, 54.38800842531266, 55.86018769971786, 57.93896544364191, 63.921513480524865, 58.3008982289222, 60.73606252670289, 59.24265146255494, 65.35845418130198, 64.52450336948519, 63.32404628876717, 61.6841229315727, 64.92054116341376, 60.29057148964175, 58.82983769139936, 61.7919449652395, 63.18441383300289, 62.7202993823636, 68.40743803208875, 64.66543805214667, 64.23065900802612, 58.33923155261625, 66.49437258320471, 31.513408460924705, 32.754938640902125, 59.055660309330115, 41.023194943704915, 50.81014002523115, 47.3341904917071, 48.1614105163082, 40.54721532329437, 46.700617882513235, 43.51154265865203, 47.37689725814327, 46.60335879172049, 48.38374222478559, 50.56979679292249, 48.140582730693204, 48.32089800988474, 52.16476194320187, 49.693551063537605, 47.90547194019441, 44.80298696025726, 48.14816859460647, 45.21552616550077, 48.04704989156416, 44.906109994457616, 46.65340823511924, 44.2261435908656, 48.24300758300289, 49.75573239787933, 43.38973345295076, 45.52058458328248, 54.054477522450114, 56.492261963505904, 47.71399751786263, 55.41790516145768, 59.73217894954067, 63.40207792097523, 60.93202806288197, 59.42046819194671, 58.93982879577145, 62.128907942002826, 53.25300001328992, 60.4479173691042, 61.46088123321534, 63.90185848359139, 62.811765132411836, 67.0324040997413, 64.24081402440225, 59.03288310573947, 58.37903576512491, 63.448106934947354, 61.29827153298163, 48.23987753160539, 54.185159129481164, 55.19994689572243, 50.42036625646776, 49.49015655825215, 50.76701748755671, 45.52578564613096, 52.18468758367723, 52.145722758385446, 52.95349174930204, 51.77056766325428, 54.392122991623424, 55.4697157490638, 54.02791915401336, 55.538557267958126, 55.154914163774066, 55.610748490979596, 53.600192531462646, 53.6914856972233, 57.356513084903845, 54.134701759584495, 55.63955437752509, 60.962273459280695, 75.09388677535519, 79.05400583820959, 80.7164945910054, 82.05519168607651, 75.09363574366417, 83.27071066825621, 77.20117230569163, 84.92796697924214, 76.61618217345207, 85.25914053763114, 5.677173378006105, 3.9803989423859507, 92.05964396076818, 53.321009989707704, 58.78749962775939, 47.10927001891598, 55.84634957774993, 59.572993478467396, 80.84037873052782, 11.825213566903146, 0.4726152993257969, 0.3811301825748336, 0.188441327021968, 0.19792010226557333, 0.21882313303649428, 0.1536088412807834, 0.3019135349219845, 0.19164349793666796, 0.086449850651045], [0.1395129766916075, 0.04813380990057223, 0.035696744002522, 0.07735845542723134, 0.12391162675715263, 0.0700732963460107, 0.06551668198118288, 0.11771150864660741, 0.04099639087554909, 0.05379988045822229, 0.15512112948683002, 17.113179468339492, 60.116026016973684, 48.844683477955485, 29.83069988989061, 44.01235480462351, 51.555774750248084, 56.93215577833114, 64.67545578556677, 5.213567854896669, 46.9361719008415, 75.73880287908739, 69.83394130583733, 68.44472408294678, 61.37288285839943, 60.48499161197294, 57.467406334415564, 57.082708112655155, 57.97984830794796, 55.96616621940367, 56.80718514227099, 57.96457067612679, 54.037234783172615, 54.87309578926333, 51.33370191820207, 51.11234295752741, 51.69953746180381, 49.8318773700345, 52.801048832554976, 51.73596843596428, 50.30929257792812, 45.957269899306766, 48.354802977654245, 45.12118139574605, 47.00897109123969, 46.42218451346121, 39.6584415435791, 42.77427827158282, 47.09753036499024, 46.24864708992743, 51.452565423903934, 49.973184677862356, 52.60928807720062, 53.63450934810024, 55.01268902132588, 55.75537804634341, 51.43911169421289, 56.738700559062345, 58.0055162983556, 59.31299524922525, 61.48006162335796, 57.338921254681004, 58.56316751049411, 56.67647215627856, 58.27662267992574, 57.56384957221247, 60.020594750681234, 55.09685131811327, 60.28110288804578, 57.39640751192647, 59.146745589471635, 54.28043350096672, 58.037962144420995, 34.51926977403703, 22.155896232974147, 51.914836360562234, 39.76628318909676, 41.904935913701216, 41.89450240904286, 40.98289651255454, 38.70191666387743, 42.19645823201826, 37.36423154031077, 38.94774336968699, 42.98353279790571, 46.33332713957756, 47.52180922415949, 42.41711508843207, 44.430671661130845, 48.60198290117326, 45.67657724503548, 43.6205727823319, 43.73419992385372, 45.1507011536629, 38.79677526412472, 35.85983391731016, 38.37960766207787, 43.15878037483462, 38.986508154099994, 39.553051379419145, 41.33905164657101, 49.04428112891413, 40.64137966402116, 48.87710578979985, 45.22120967988045, 36.28135927261845, 54.19251357355426, 53.683276176452644, 58.22045433905817, 56.35695195967152, 56.04790056905439, 57.12446566550963, 56.00231870528191, 50.97121607872748, 53.54673454838415, 56.50358584619338, 54.92567123905305, 59.24946461954425, 57.83880379892165, 58.10378343828263, 57.50685361123855, 54.89903442321285, 56.42740557270666, 52.77251751192155, 45.02590310189032, 51.030392877517215, 50.86926191083847, 45.0646286626016, 44.872161880616225, 42.84256281391267, 40.26987629552042, 44.74385330753942, 46.28678429511286, 44.90845164945049, 45.86855765311949, 45.36428205428585, 48.79053515772666, 44.99756397739534, 47.49280721910539, 49.268354369748025, 48.90112246236494, 46.238335178744414, 47.240273260301166, 46.030065167334776, 49.63567256927491, 51.925991581332305, 52.81260021271245, 62.95466884489983, 75.44923782348633, 75.72377235658708, 70.59579895388696, 72.98745632171631, 75.55795023518225, 70.84969397514098, 79.18546799690493, 69.63984674023044, 71.66396233343309, 0.43935093427858046, 10.94217429237981, 74.14383380643784, 36.0830089353746, 41.826386528630415, 30.158072671582623, 44.18987735625237, 43.50775757143575, 59.37121106732277, 3.175377326626932, 0.17832620850493833, 0.03749364153331807, 0.060362005756507, 0.1449717515178265, 0.0748159475023708, 0.037877317517995834, 0.04330819908289179, 0.00652438780713466, 0.07465863900799906, 0.04786018244621735, 0.011539212766013319, 0.025813391980444713, 0.07233296460922688, 0.014151453844181473, 0.039719931345673344, 0.09294345704538208, 0.05019315766290792, 0.06361398387760406, 0.037426026613121076, 0.11987297209881007, 18.985258110107917, 71.26166051433933, 47.410712011398815, 39.82525602463753, 56.369495699482584, 57.10217091345019, 63.82154403194305, 72.59911029569565, 6.371925646258939, 49.40142470021402, 81.38656877702283, 74.27691982638451, 73.48685249205559, 66.2816781382407, 64.41928971198298, 60.12127807063442, 60.981598977119695, 61.91679793019449, 62.30760720468337, 60.718333413524014, 61.35316902591337, 56.88511479285456, 58.922754718411355, 55.47408134706559, 54.56914740224039, 54.28050410362982, 53.27090171075637, 55.57727106155888, 54.602420868412146, 52.70546851619598, 49.23965830956736, 50.655308385049146, 48.23099728553526, 49.39910657944218, 49.7289151530112, 45.16965012396536, 45.310647564549605, 50.23466556302963, 50.9954837829836, 53.030001501883234, 53.50517703640846, 55.75763733156266, 57.28191744896674, 56.78223102323471, 59.37314087344755, 56.22520346795359, 59.7857310695033, 58.6143740530937, 62.24481790296493, 63.18535127947408, 59.154782525954715, 58.665153057344504, 60.6288484604128, 60.45032570439001, 59.84759076949089, 61.507988898984856, 57.46267203361758, 63.37004000140775, 60.60493769184236, 59.00935280707575, 57.22910665696668, 62.569284208359264, 40.46607717390984, 37.024201270072695, 56.74016752550679, 40.60033206016787, 45.94599700743153, 43.60016469032534, 45.4525863739752, 41.87173305019256, 42.03928493684338, 41.74155742891374, 41.53991230072514, 44.56486771183629, 48.67236198917512, 48.683638803420536, 42.81919333242601, 43.928859310765425, 47.7488987676559, 47.52506871377268, 46.57784769611974, 45.398414519525346, 47.07631426472818, 43.21130875618228, 41.61638282960461, 40.424884442360174, 44.98442403731808, 40.181328788880386, 42.32043650842483, 44.08653859169253, 48.860035634809925, 42.727390258542954, 48.631992955361646, 53.056795212530325, 42.531879717303866, 54.249890004434896, 55.84535329572616, 60.20040012175038, 60.214140184464, 61.16722906789472, 58.95124289297289, 58.0858935079267, 54.313518693370206, 57.66513301480202, 58.09666041404971, 57.89903571528774, 62.56351440183578, 62.32764659389373, 60.617442207951704, 60.982171643164854, 58.02014281672817, 61.54879723825763, 54.178028260507894, 46.25686837780861, 54.95906629870015, 51.118748188018806, 47.77455891332319, 48.31628922493228, 46.14965431151852, 43.41598979888424, 48.32568330149497, 49.54881168180897, 47.93060256588844, 50.19855622322329, 48.62398739783995, 50.66609882539319, 50.07348360553865, 52.31880910934941, 52.24214638433149, 51.71428949602189, 50.16044255225889, 52.34811313690678, 51.934510969346576, 51.77221898109683, 54.714294710466945, 55.432892537886104, 66.08124502243535, 77.15055804098807, 78.90948218684044, 74.65097273549726, 76.08172785851264, 80.69169736677601, 74.66754082710513, 81.4645690302695, 74.84400041641729, 77.66781668509208, 0.8239816177275874, 13.552149803407731, 81.4213131320092, 40.027724850562315, 51.05965768137286, 35.21997374873008, 42.76531565573908, 52.4946254299533, 70.21755695343018, 3.301173621608365, 0.21293934795164296, 0.0827674498601306, 0.06731963926746, 0.026469473509238135, 0.07855447955549726, 0.014595336678828445, 0.012080307370201956, 0.03217730543486053, 0.04353168225216289, 0.1638375399934669, 0.1291909225044712, 0.10193198198272337, 0.19410075559731454, 0.2031677892251361, 0.0985288049184507, 0.2151860540071803, 0.34019176157251485, 0.08894593364769414, 0.3442475536177236, 0.27697250066745666, 32.74940417658898, 82.80334457274407, 64.85871676475772, 40.761996469190045, 61.01183652877808, 70.38972546977382, 70.3386640548706, 77.5241873341222, 6.593189979753187, 54.092324472242794, 83.46344024904313, 78.3514936508671, 73.69660515939036, 67.76059996697211, 66.90486431121826, 62.18781801962084, 61.933569985051314, 65.4916068815416, 63.443305953856445, 62.21287804265177, 63.78989442702263, 58.00839531806208, 62.85855900856757, 57.204689902644006, 56.07096802803778, 57.11063146591187, 55.13567493807886, 58.59569180396296, 55.52388368114349, 52.997300701756636, 49.721717603745006, 52.849756825354795, 50.52243809546194, 50.298302096705285, 52.832800419099875, 44.019571965740575, 47.8225177334201, 52.47416242476433, 52.50392144726169, 55.91626974844164, 56.63649535948231, 58.131914677158484, 57.43913781258368, 57.61413435782156, 61.658537310938684, 57.07513401585241, 63.74122173555436, 62.803669360376176, 65.23753143125965, 67.36851199980705, 61.29900109383368, 63.994924560669936, 62.377327334496286, 64.06855529354465, 62.22656319218298, 64.27292254663283, 60.0878006412137, 67.36156940460205, 63.87719461994787, 62.10596207649478, 60.198909621084894, 66.58640707692793, 38.11527129142515, 29.24845737795676, 58.82310690418367, 41.70826435089111, 47.64645038112518, 47.33523384217293, 47.41417938663114, 44.21436863560831, 45.941678477871804, 42.45782144608037, 43.87806461703393, 46.783532865585826, 51.08983639747866, 52.83773868314682, 46.365341524924006, 45.8790696051813, 50.71277503044375, 49.16873793448172, 49.196327886273785, 45.60870455157372, 48.93687878885577, 44.558780193328865, 42.191421908717004, 43.96484705709642, 50.13772810659101, 41.75923555128036, 45.46679712110951, 46.36713797046293, 51.32278596201251, 45.5013257457364, 50.93117260163831, 49.78859009281282, 46.07638835906983, 57.783694498000614, 58.24641650722873, 65.60821110202421, 63.48208642775013, 62.58981389384117, 63.84716887627879, 61.178725534869784, 57.35998438250635, 60.0510480326991, 62.793024047728515, 57.632173338244044, 65.11613799679664, 64.18140188340219, 64.587324050165, 65.28204248797509, 60.24482096395185, 62.1480804874051, 56.32454141493767, 46.575749228077555, 56.26009687300652, 54.53585824658794, 51.358004923789736, 50.93326322494015, 49.62135591814595, 45.47015074760684, 53.257236173076016, 52.363261330512266, 50.96258294197821, 53.08406745233844, 51.50257956597113, 54.76866268342542, 53.15533691836942, 55.97591723165205, 56.17640526063981, 55.80157179986277, 53.26687735895957, 54.53126515111616, 52.50600422582319, 54.47677558468234, 57.46788094120642, 56.204461974482385, 70.98836545021304, 81.2949892782396, 82.5448525336481, 79.07541413461009, 76.15196966355848, 79.19803527093704, 76.8952823454334, 83.30710241871496, 75.96288004229146, 80.1433970851283, 2.2922431797750535, 12.894186915889865, 90.1304183467742, 48.43732180133943, 57.62472475728681, 45.31970823964765, 63.0402353502089, 60.7343602180481, 89.08175699172482, 5.649092639646223, 0.38258893655673154, 0.27108713744148133, 0.14906198687611089, 0.19176728242347318, 0.2800291914853358, 0.1111589058212215, 0.1180380612852112, 0.1268595177680254, 0.1124797792985074], [0.04773356343409227, 0.05736572097145742, 0.019459230825304985, 0.0522360919914659, 0.07038125603069222, 0.06454855368863191, 0.1157006427585598, 0.07490950215968394, 0.2067302972559006, 0.046105638086315126, 0.2428791059121009, 7.985236212130516, 62.87774332108037, 39.991588054164765, 40.67858726747575, 32.84821456478488, 45.85595900012601, 48.5582680856028, 75.71104818774809, 8.65420085768546, 33.61909366423084, 81.88268584589805, 64.89932114078154, 73.9085308198006, 65.21558577014555, 64.24741929577243, 57.878486417954974, 59.55498587700629, 59.23883891874745, 59.02540314582087, 59.01145519748811, 60.58981303245791, 55.93854488865022, 55.7977004205027, 50.80358182230304, 50.13521778968073, 51.034299558208836, 56.42478935180172, 56.54880292953984, 55.43533225213328, 50.39072882744574, 48.345565795898445, 47.20962385977469, 47.34614587599232, 46.784125143481845, 45.912276391060125, 43.95343688226516, 44.04345527771981, 44.3513495691361, 46.592434990790586, 50.99251847113333, 49.49487909193962, 52.138791930290964, 53.5339750782136, 52.91860618898946, 52.8201586200345, 50.5370803033152, 53.0292405620698, 57.12691714686733, 56.43215164061516, 60.259078779528224, 61.362441509000725, 58.46876782755698, 58.17045196410149, 56.06117386971751, 59.00779562611734, 61.36451644282187, 56.94381306248327, 58.10257927063973, 57.56514787673951, 59.19267654418946, 56.030151844024665, 56.521107073753114, 39.88981431530368, 20.82835239748801, 45.42704389941308, 44.40982426366499, 41.12371352411086, 39.58353211802822, 41.02566603691348, 38.86141592456449, 38.08286074669131, 40.46973282291044, 37.9594551363299, 42.810320931096236, 42.95867673812374, 41.58322311216786, 40.221317352787146, 45.337798210882376, 45.97842716401624, 42.790603176240005, 45.08917093276978, 40.51255333808161, 43.46719241911366, 39.07112544582736, 38.400984579517, 38.1996375514615, 41.31795713978429, 40.11685286798785, 45.59029686835505, 44.649594829928496, 41.25305760291315, 34.132637823781664, 52.78608499034759, 45.52855483947262, 42.031216621398926, 58.7837851432062, 54.80785108381703, 56.49291307695451, 56.982550390305065, 55.20441839771887, 54.12622159527194, 55.73943753396311, 52.79090950565954, 51.71179094622212, 57.505057165699625, 58.19021678739979, 56.34461610547958, 59.95718571447558, 59.80997916190856, 55.55607457314768, 56.91042976994669, 55.51735293480658, 51.47991611111549, 47.377018851618615, 50.41861687937091, 48.576742449114406, 45.66170361734206, 44.65985575029927, 40.96501442693895, 42.48983583142681, 42.6079305525749, 46.72819998956496, 45.30788229357812, 48.80593438302317, 46.1914393209642, 46.711831938835886, 42.9560056040364, 46.716503481711115, 48.08412413443289, 49.50899177981962, 49.046065807342536, 46.935308979403594, 46.66323769477106, 48.9784872916437, 50.336831538907944, 55.82397245591687, 59.20325125417402, 70.66822159674861, 70.51958730143886, 75.53630659657141, 65.32629859062934, 78.03243237157022, 73.86436493166032, 81.31694670646422, 71.83521301515641, 63.61196394889586, 0.033815810456871986, 22.75478332273422, 71.85123197494015, 41.638889389653365, 34.08091352831933, 48.27927381761613, 59.259972649235884, 45.256593381204915, 47.479082845872455, 0.8776451575179255, 0.04540682417310534, 0.06960248169038566, 0.018476636877523798, 0.09947771206498147, 0.07105410339370852, 0.14793798267360658, 0.027151454555531664, 0.06944262212322605, 0.09445381470985952, 0.08008998788652882, 0.059802616015076644, 0.0483684741230982, 0.03659413939702415, 0.0066690836214430395, 0.025838416242491336, 0.02885536433407857, 0.09781337072772366, 0.13574226128478206, 0.16131343350054758, 0.5553812016883205, 8.409121363393723, 75.50331161868188, 39.41063011846235, 40.91985617914508, 43.80374746937906, 53.744406315588186, 52.47531952396516, 84.65128298728698, 10.9602407293935, 32.58902434379824, 87.94957268622615, 68.3447350225141, 80.352875186551, 69.68674259801065, 69.68569924754482, 62.373887415855165, 64.53170876349172, 62.89604510030439, 63.17421567055487, 61.463830855584916, 63.12483303008541, 58.89318789205244, 58.319713838638805, 52.522984166299146, 53.84805494739164, 55.369428588498025, 58.5526281018411, 59.663957165133574, 59.68518895487632, 55.352221150552076, 51.14682059134207, 52.72207583150556, 51.05757098044119, 48.80253368808378, 48.72436477291969, 46.24194768167312, 45.55211651709772, 46.37470814489549, 48.95086203852008, 51.963587499433956, 52.35347893930251, 55.08507636285598, 57.52866983413697, 55.50394627355761, 55.83006389679448, 53.104197056062766, 57.4226991591915, 57.5579228708821, 59.0454190008102, 59.83383109492641, 62.4824546998547, 60.366065348348315, 59.30478180608442, 60.382288271381015, 61.83484000544395, 60.789324391272764, 59.60716908977878, 60.79143462642547, 60.2166191224129, 62.909549820807676, 54.48145497229792, 58.8690653154927, 44.013100054956254, 33.57426489553144, 49.40470772404825, 47.935128981067294, 44.26963090896607, 43.56282372628489, 44.13494456198908, 41.199783971232755, 42.5661337760187, 42.806186752934615, 42.70313039902718, 45.255859897982695, 45.93634797680763, 43.33464376388058, 42.161235347870864, 44.598074497715125, 46.30390544091502, 43.288689274941724, 43.768646178707, 44.36878058218187, 46.17396123947636, 42.019339684517156, 42.30989317740164, 41.28750778013661, 43.5887505931239, 41.21890944819297, 46.85453953281526, 47.20523080518169, 40.60678435910133, 37.70237907286614, 55.251365246311316, 57.387374293419626, 45.40429023004348, 60.69199469781692, 54.421293658594934, 58.96482998324979, 60.006132971855905, 58.43562772197109, 57.64834919283467, 59.41272543322656, 57.86049058360439, 56.30964033065304, 58.64037544496598, 59.01933916153447, 59.34277388357348, 61.77662026497626, 63.391911137488584, 59.65837955474854, 60.28458203038862, 60.51353469971688, 53.819072554188395, 48.099539049210094, 54.02590697811496, 51.999712528720984, 48.52044074766098, 49.116507653267156, 45.5205806609123, 45.24166091795891, 48.14338330299624, 51.143459120104396, 50.12789472456902, 50.403829543821274, 48.21327993946691, 49.03381624529439, 48.19249922229398, 50.569734034999726, 52.79851498142366, 53.865517339398785, 52.299793458754024, 52.42870607683736, 51.01963773850472, 52.62704072460052, 53.77542441891086, 57.64643115382041, 60.953428514542125, 72.72315917476531, 74.12260593906527, 79.62192581545922, 70.3487523909538, 81.46450627234675, 76.93689084822132, 84.47198360197007, 76.74477315718129, 68.06067697463497, 0.4189652426829262, 27.287293864834695, 82.11219941416095, 47.97212869890275, 40.75741906319895, 43.61591692893736, 62.00187413923202, 51.162447314108576, 60.44695638841199, 2.8770533732829557, 0.0650930047155388, 0.0160099467593095, 0.03803553382655786, 0.10148248755403104, 0.06253488391878144, 0.11571838535488614, 0.02157498755672526, 0.014976282517666058, 0.01081525584712865, 0.2081026211981812, 0.17818638213699867, 0.10981069066591802, 0.23733957009690426, 0.1318763517924855, 0.22185641220740734, 0.1594977591547274, 0.19900079185683883, 0.2480501994009941, 0.39258708876948206, 0.7198737621788056, 13.379644943821816, 88.61171583975516, 54.12533121724283, 53.83582891956453, 47.42456190047726, 60.85114878992881, 60.22635052281042, 89.51226065235754, 11.140985508118908, 38.36249043864589, 89.11408516668504, 73.3848944017964, 83.71654295152234, 70.64347144096129, 69.2022906580279, 63.37327203442974, 65.83015057348436, 65.95419160781368, 66.71481763162922, 62.42047732876193, 65.90377346161874, 60.772599404858006, 62.3709495605961, 55.07217176498906, 57.123285032087765, 56.44078085499426, 61.69320321852162, 60.27550566580988, 62.36077885473929, 55.70019422038909, 54.85548042481946, 54.87887736289732, 52.87294587781353, 50.392682167791556, 50.49644062595983, 49.33643102645875, 49.26912707667197, 49.73515564395536, 51.44260652603642, 55.40839341378982, 55.03034753184165, 56.70987898303617, 58.75437913402435, 56.56176244058917, 57.467884863576586, 54.26009601162326, 58.87790241549092, 59.78416212143437, 60.37230976166264, 66.68055180580386, 67.32293405840474, 64.37903050453433, 60.318055537439164, 61.66617808803436, 63.172246640728375, 66.1510867457236, 61.761397546337506, 64.69069419368621, 61.492836783009196, 67.65096187591553, 57.235994338989265, 63.612214980586884, 45.026362019200484, 26.579629644270867, 51.58774598952263, 47.623849684192294, 48.52078591623614, 45.74775257418233, 46.98636647193663, 44.6287670443135, 45.7135259720587, 44.00522785802042, 45.52842147888676, 48.9371298205468, 46.6379423295298, 44.29165501748362, 41.149722760723485, 46.49018664513865, 46.56297406842632, 45.35324842699113, 47.19531897575625, 47.41231626079929, 50.09517823496173, 45.44094870167394, 42.44544244581654, 42.49420927416894, 45.35824160422049, 47.29204070183539, 49.630302844509, 49.98845838731336, 44.573202748452466, 37.78134815154537, 52.84417921496976, 51.49015349726523, 44.99335527420045, 62.66069896759526, 58.19239370284542, 61.92199114830264, 65.40213761791107, 59.06051620360344, 59.02215150094802, 62.91539022999426, 61.312705855215754, 57.31640292752174, 62.618219698629076, 62.19381532361431, 63.69672244594943, 65.33621434242495, 66.40349126631214, 59.77594083355319, 61.349874234968624, 61.012064026248076, 54.94952709444108, 47.805639774568625, 58.20462757541288, 55.47141413534842, 51.661921931851296, 52.74704564002253, 48.85213205891271, 48.25420987221503, 51.163659326491825, 53.865815439531886, 53.19865949692265, 55.21652675444081, 50.042806748420965, 53.217839887065274, 49.43858131285637, 53.25794219970704, 56.62728171194754, 57.74335292077834, 56.22281474451865, 55.8757398974511, 53.93118958319388, 55.59896176861179, 56.81899932123, 61.47722967209355, 65.35422586625623, 77.00284942503899, 77.7404825149044, 84.1110392539732, 72.57412479769799, 82.81573141774824, 79.04981674686556, 87.22340860674458, 75.52889331694573, 74.01752564214891, 0.8207673579454423, 25.677468815157493, 93.30535734853437, 54.585452695046705, 46.56200132062359, 67.55111402080905, 78.20741714969759, 58.5473721258102, 78.0519030171056, 3.7533873559967166, 0.16003665604418324, 0.2872547182825304, 0.10807232225253698, 0.22378719892472992, 0.12303418029219874, 0.24347187410439217, 0.198937788785946, 0.1764239049366405, 0.14409556143706845], [0.06335610719097239, 0.0863486044709721, 0.08867396477369532, 0.045725528240924886, 0.02045373935552855, 0.2202183936512278, 0.08354146679442737, 0.11016466925221105, 0.10688263367140487, 0.19663177220331085, 0.12278281152248384, 4.748146274397451, 59.156551514902425, 45.61259946515484, 40.268260279009425, 28.97891406090029, 45.741410101613695, 43.743503785902455, 80.37573475991526, 19.888709399007983, 17.413156455562962, 80.51180178119291, 64.89215889284688, 75.90207545988022, 69.12250180398264, 69.45371458607336, 61.75903627949377, 62.93654749470373, 62.09867039034444, 61.07420613688808, 58.82832757888302, 58.28644037246705, 51.60272552121071, 53.54062741802585, 51.757498325840125, 51.8349180683013, 55.42193735799482, 58.36436610068045, 54.4347160093246, 57.13247906777167, 52.698059158940474, 46.6560911363171, 47.41259474908152, 48.56819560450893, 48.78531448302731, 45.964832228998986, 45.10685297750658, 40.98170411202216, 46.258802106303555, 49.98991358664728, 48.92393496728713, 49.599245517484604, 54.165845378752685, 55.05923971053093, 53.292290395306004, 50.21367696023757, 48.13761349647276, 53.327356384646514, 58.89888709591281, 58.803177341338134, 59.40434332816832, 58.13495059167185, 59.80463689373386, 60.33102289322884, 57.05610267577633, 59.423884576366795, 59.544258194585005, 55.588908733860144, 56.69716658130769, 56.143539720965975, 58.57992387587025, 54.0018589265885, 55.910295978669204, 46.39566536872618, 27.059612043442268, 43.09541056233068, 47.88091005817537, 43.75641622850972, 39.10854877964143, 39.29069972807361, 38.8528416233678, 38.462965872979936, 36.719378194501324, 39.0766599101405, 41.31552919264763, 44.86364641497212, 40.21981508501115, 40.01369453245594, 45.220064347790135, 45.99759578704835, 48.402616670054776, 43.94197963899182, 45.72252388923399, 44.92078750364242, 36.726544364806145, 36.039352955356726, 38.19298521164925, 42.95306382640716, 44.44765552397698, 49.07227508483395, 40.362428542106386, 39.44701794655093, 45.00160401867282, 60.88098233745944, 34.12222000860399, 49.07871953902706, 59.87128973007203, 57.745290571643466, 55.06227562504431, 54.04121598889751, 57.04553188816194, 59.14113267775505, 56.13005853468373, 54.26279460230182, 54.12744929713588, 58.7997099661058, 58.161383444263095, 58.981955051422126, 57.06371207391062, 57.63715082599271, 54.99445392239479, 54.068111681169086, 57.65655086886499, 47.22555652741463, 48.5362635889361, 49.27115494205106, 47.7089298156, 46.47452854341077, 42.907717304845015, 42.2545289224194, 43.038916664738814, 43.528510832017474, 44.06678945787492, 46.11349005852976, 49.483770939611624, 48.194401571827555, 45.22066054805633, 44.539650793998476, 46.73319708916449, 47.553588267295595, 47.94387194418138, 49.63193062813052, 48.717979154279156, 46.69800950634865, 47.58856796449231, 48.02709287212741, 53.947898880127944, 57.08772874647572, 69.16842491396012, 72.98600504475256, 72.70484955080094, 68.02149249661353, 73.69320838682114, 72.77851950737738, 78.1720373707433, 78.2469311068135, 49.30606795895485, 0.6766103256133296, 36.40285861107611, 65.3961677705088, 41.612931143852975, 34.35524409817111, 64.31487229562575, 46.87299820684618, 37.36339607546407, 58.83559573081232, 2.9013642236109707, 0.09528149610325214, 0.14276624567085697, 0.10198253612484663, 0.11848446071868944, 0.12713266641742763, 0.1293726692036275, 0.11008933982661656, 0.0734485418445641, 0.10108906310051681, 0.04240301257419971, 0.01730260713356397, 0.06808173587365497, 0.059872035072335315, 0.04053958796805913, 0.16276023651082672, 0.10889530752695377, 0.06329578925825416, 0.08565936282637619, 0.05473750696006802, 0.1161120626174154, 4.570427604259984, 69.81146612474996, 46.00675844377088, 39.840494432756984, 34.31811494211997, 54.14555103548112, 49.628267134389574, 86.13407227300829, 24.533278134561357, 16.425331061886205, 83.25692745947069, 70.66365595786803, 79.23244230208859, 73.85237032367338, 74.78091301456575, 65.84579298573156, 66.43871415045955, 62.96648302385884, 64.90882504370906, 62.367364514258604, 61.89519743765555, 55.26725869024954, 56.91111226235667, 52.30117805542485, 56.268141654229936, 58.043971215524984, 62.558548681197635, 58.20010900497437, 57.75722634407782, 57.25588860050325, 50.60428227147749, 50.962790827597345, 51.02634106912921, 50.98592888924384, 49.61697463066348, 46.91198264398883, 44.45907354354859, 47.05485497751544, 51.14710300199447, 52.22317780217817, 52.00818877066336, 54.422968510658514, 58.74136078742243, 57.85463840730729, 55.361936861468905, 47.816496895205596, 56.96991643598003, 60.37021129362045, 59.46787395784932, 60.06089318183161, 60.656042252817464, 59.2811377586857, 62.07490474947038, 62.957402736909934, 62.11581507036763, 58.77141791005289, 57.35964313630135, 59.154751146993334, 59.662851056744984, 59.617849703758, 54.50750343261227, 59.37074038290209, 50.74461290913244, 37.41184519183251, 48.78056449274863, 47.5038565358808, 47.31620250209686, 42.755113570920884, 43.12401640799738, 40.458934537826046, 41.86106420332386, 40.21967387968495, 42.58921300211261, 42.22458554852394, 45.647135934522076, 41.816611982161, 41.19442601357737, 43.21507030917753, 44.06589515747563, 48.78874263455791, 44.46030516778269, 45.18821470199093, 47.99265446201448, 44.87700993014921, 41.816851246741514, 39.16450139014952, 47.569136542658654, 42.74297383523757, 52.011193306215354, 39.89156761477071, 45.103256164058564, 40.58469749266102, 68.8497401821998, 49.12573699028262, 48.657005909950506, 62.70877938116751, 56.350276085638235, 59.28367160981702, 55.63336487739317, 60.40012328855453, 62.00109358756774, 61.92337574497346, 59.64146237219534, 56.51442335497949, 60.278470977660156, 60.24471898232738, 62.868278641854566, 61.539442385396654, 59.42938766171856, 58.57092595869496, 58.24880915303385, 59.71395561772009, 49.47555357410062, 49.70697341426727, 54.86050890338037, 50.011447398893296, 49.517911249591464, 46.526990244465495, 45.30876090449672, 47.53844791843046, 47.897242807572894, 49.65413124330583, 48.58778784351964, 49.449022662255075, 50.98193199403825, 50.59391936948223, 48.535404589868364, 51.91679754564839, 51.341068129385675, 51.25898861115979, 53.07481065873177, 54.01309259476201, 52.167240881150775, 52.79810313255557, 52.58640496961532, 55.54829259072581, 59.40186831258959, 70.914271877658, 74.46011804765271, 75.03502768854942, 74.00065945040795, 76.1261369336036, 79.15601884165119, 80.35744867017193, 80.19306213625016, 53.80775651624126, 0.963646739480957, 43.83316524567143, 72.38563922143751, 49.57122410497358, 35.71727929576751, 68.06601139806932, 55.379446321918124, 45.81925346005348, 74.17413803838915, 4.363793711508475, 0.07834103979891346, 0.03682730208721854, 0.05072079689031647, 0.06700096201271781, 0.06357050455746151, 0.04314594166052919, 0.12977848129887737, 0.058230894707864335, 0.04810361071459709, 0.1479286976879643, 0.20843343328564398, 0.20591770779461632, 0.20123620577637227, 0.19992737520125606, 0.4623689652690965, 0.1633688474013921, 0.25034153773900003, 0.1947176862027376, 0.42870461039485475, 0.3580641331932237, 7.977769980507513, 85.71272342435776, 59.18332169132849, 57.782451106655984, 41.61995218646142, 62.09858802057082, 54.66250765708185, 92.7163742434594, 23.206052011059178, 22.780523876990042, 88.84076656833773, 73.47044913999497, 82.21208649296915, 75.86880591607864, 76.8738583595522, 68.09051836690595, 69.59351570375505, 66.52761859278526, 67.70665168762207, 64.47526193434193, 62.5886332604193, 56.01318759302939, 61.28755954004104, 55.85604959918607, 58.66108163710564, 61.20553101262739, 64.96946880894323, 58.512686606376406, 62.961325107082246, 58.36008679482245, 54.822332474493216, 52.46077537536622, 52.29527096594534, 54.08213023216494, 50.4067164082681, 49.43867544974051, 46.49810198814639, 50.41496123037031, 54.875335462631725, 53.68857922092561, 52.755674854401626, 58.29089226261262, 61.36665413456579, 58.475412322628884, 55.473916607518355, 49.36599000807732, 57.25493938692155, 65.83196270850398, 63.94975846813571, 63.99513636865924, 64.35852043090328, 61.56676561601701, 66.29492790468278, 63.757013197868105, 65.64379092185729, 62.98902096286897, 59.68448685061548, 61.872879151375066, 61.03259371172998, 63.27096485322522, 56.75104033562445, 60.80983446490381, 54.53213199492424, 32.61240559239542, 48.704592104881044, 49.85385833248016, 50.63679479783582, 46.309812530394524, 44.752466832437825, 42.95826488925565, 44.60232242461174, 41.887324471627515, 44.83037294880037, 44.55671702661822, 47.79626923222696, 41.36768102645874, 42.85008591990317, 44.259428824147875, 46.6514588171436, 47.96114998479044, 44.95694783426101, 45.156345444340865, 48.04659881899434, 44.39657057485273, 43.33128621501308, 41.85133280292634, 50.1240429570598, 45.44129779261928, 54.30502676194715, 45.87618274073447, 43.07685775141562, 43.01462542626166, 58.04101767078523, 45.52885293960572, 52.45000846924321, 65.28094422432684, 61.58099597500217, 60.69912556679019, 58.927367425734005, 60.69523457557925, 64.4702648347424, 63.427510569172526, 62.23412159950503, 57.48807722522367, 63.44563976410897, 63.0023491767145, 65.41119044826877, 65.25980264909806, 62.324696971524155, 59.73386556871476, 58.148851471562544, 60.810928806181884, 52.53253513766874, 49.97118819144465, 58.47501224087131, 53.95628098518618, 50.84169549326743, 48.480758128627656, 47.99009707666213, 50.4949579700347, 49.81876488654844, 52.243370163825254, 51.688186122525124, 53.1026045737728, 53.18387216137302, 53.40352096865254, 51.01617820801274, 53.2626372768033, 55.977988243103034, 53.32756034789547, 57.16313239066832, 57.77468089134463, 53.850965346059496, 54.726775692355254, 55.52114978913338, 59.24975879730717, 64.38729886085757, 77.20048196854131, 80.35911175512499, 79.67461893635412, 75.66186951052758, 80.333663417447, 80.4378886376658, 82.789412313892, 80.3030610853626, 58.75173153415803, 1.287851533101451, 43.549173878085234, 84.60961172657629, 53.04936624342396, 47.608340632530954, 75.32230207996984, 61.341586266794515, 54.2511647747409, 85.89035187998127, 5.772965502354407, 0.45290560371452765, 0.3116612683140463, 0.2576965027518811, 0.1552310171386888, 0.1593495364631376, 0.27346973217302756, 0.29950762047402324, 0.14644031142515523, 0.1902023639770285], [0.03598454791391569, 0.05620921165832589, 0.008809688414687352, 0.09553801298381821, 0.2638372490482946, 0.27610403275297535, 0.08498459258266995, 0.04716443671514431, 0.048916594711162394, 0.09966944855067039, 0.1401937683863986, 1.152277627298909, 50.817933774763546, 49.2157514633671, 35.55114338474889, 38.486237295212284, 45.68832866607174, 38.13709143669375, 75.27123282032629, 38.165877711388376, 6.618243138636313, 64.9371563234637, 68.77236750818068, 74.14325329565233, 73.23754664390319, 70.43956310518327, 65.79754783261207, 67.57839802772769, 62.52846802434614, 61.99912063537106, 58.88084027074999, 56.40192193369712, 55.55190509365451, 51.657105261279696, 51.866461769227065, 54.33948086154077, 56.775531614980395, 57.219881242321385, 59.80391125525198, 54.654156930984996, 52.16550719353461, 47.42204373882663, 47.28140323392807, 45.740433431440785, 48.523527652986594, 47.527524117500555, 45.993520444439305, 42.04293666347381, 43.41273423164122, 47.43741158516177, 49.615503741848855, 54.7513375743743, 49.873226996391054, 54.5460367971851, 53.2642376038336, 55.645159444501324, 47.744313516924464, 50.62865195735809, 61.05582198789043, 59.366155132170654, 58.07728390539847, 62.93071885262767, 61.964442960677616, 58.07909604041808, 55.90980568239766, 62.76734429021036, 58.65589234136767, 57.86695857201853, 56.29368412879206, 56.819936767701186, 55.42878189394551, 54.58406809837588, 57.27748909304219, 50.28323235050325, 32.936726770093365, 45.23201973207536, 42.24509954452515, 45.214447513703384, 44.63350526748165, 41.323703412086736, 39.84480119520619, 38.564767068432225, 37.52147543814875, 41.26834700184484, 45.11032427510908, 39.20755332516086, 40.57377369173112, 46.53765516896402, 56.07521203256423, 61.16901374632313, 65.31047574935421, 66.47526279572519, 39.93627086762459, 33.78541000427739, 49.07293796539307, 43.27949131688764, 48.48250358335434, 43.62876661362187, 44.774043790755734, 40.540763024360906, 43.6979886024229, 38.1045396866337, 61.86713287907263, 52.63524240063083, 27.328825881404263, 57.92463310303227, 55.83368032209335, 59.088839638617735, 55.935308933258064, 55.637420608151345, 56.34061921027399, 58.81618392082953, 56.42803315193423, 57.22259552248063, 55.41492416012672, 58.918651919211115, 59.77408555246169, 55.47002561630742, 54.907534199376265, 56.17077273707236, 54.39019318549864, 54.27475390895721, 55.016481953282515, 49.78904508775281, 49.90869698985931, 48.77382586079259, 45.501533631355535, 46.63346298279301, 42.778161418053415, 40.491329393079205, 44.56822918307397, 46.59681627827306, 47.255535202641646, 47.295241355896, 49.05234159961824, 46.88377295770953, 44.89403301669706, 47.68907870015791, 47.003409170335345, 48.723380258006436, 47.77404508283062, 47.44080051299065, 46.03950238996937, 49.54215934199672, 50.01529132166217, 51.980881229523696, 51.85796591543382, 55.601797642246375, 60.73072810326854, 70.21501525755852, 66.77815606517177, 69.96370900061824, 68.18213708939092, 71.7525843651064, 71.28437888237738, 80.44948316389515, 39.5452654746271, 0.8218647635752155, 51.39847201685752, 58.330465055281124, 37.949692356971006, 33.54505108248803, 84.05276852269327, 52.20314233533798, 43.667390192708666, 55.411535232297844, 2.055372715957703, 0.27334390989234375, 0.34067917735345904, 0.025398419388840278, 0.1253601917696576, 0.1827149576837978, 0.0839664617313012, 0.035012255933496265, 0.10368826153177409, 0.16496410292963828, 0.17574132059610661, 0.0462006674628825, 0.047356667327544386, 0.05015563084593704, 0.14405950933935183, 0.2174163044941041, 0.08405016449790809, 0.020430749056920893, 0.061692014832289956, 0.02727251943020571, 0.07992645109733267, 1.1375705777637422, 61.193450112496656, 55.038211884037146, 39.047516699760195, 48.59921763020177, 51.68145533530943, 43.23814169053109, 80.31062341505482, 44.88343869486163, 4.691885267534564, 69.19195129025367, 75.23316229543379, 78.57008734057027, 77.00032341864802, 74.29759856193297, 67.84310310117661, 69.3538510414862, 67.28020375774753, 64.68282984149072, 63.24807782326976, 60.2100020839322, 58.830739836538996, 56.885887499778505, 56.31610439669702, 59.48429299939064, 59.216434340323175, 60.26373463292276, 62.811623927085634, 60.377973664191465, 55.77241682237195, 51.82780288880872, 50.257634962758715, 48.46423318309169, 53.413746587691776, 49.15754349000993, 50.366708232510476, 45.3315459528277, 45.29038852260959, 48.33035092200003, 53.1525912592488, 55.896159756568174, 52.96174049377442, 56.50603340518091, 53.75639307883478, 56.94763737340128, 50.64758131580968, 51.19167681663267, 60.51750021596109, 59.851116980275805, 60.64618925894461, 61.63544239536409, 62.38417579281715, 63.13583135604859, 60.56849887294155, 60.330567898288855, 61.577324636520885, 61.84734452155329, 58.52593637281849, 59.209656484665416, 56.006480340034734, 54.29502471800774, 59.71364967284664, 51.86640293367448, 40.21981116264097, 49.802302698935236, 44.08648760088029, 48.43000658096806, 47.38909975174935, 43.32465348705169, 43.136438554333104, 42.70519748810799, 39.745290663934526, 41.471890557196836, 47.110062337690785, 38.44502495181176, 42.16036850406278, 43.276526005037375, 54.34522713384321, 58.83309718101256, 63.12851221330705, 71.41356606637278, 49.777258365384995, 35.7194915125447, 46.61070539105324, 45.9371599074333, 48.85929430684736, 42.86632845478673, 45.97247300609466, 41.27410111888763, 45.70119404023694, 33.795404203476444, 64.45431255525159, 75.13333797454834, 32.29754124918292, 59.374352885830795, 57.27050727413547, 62.73491805599582, 57.33350446147304, 60.09027565679243, 58.32000801640173, 60.09788505492672, 59.87499636988486, 60.84594772708032, 55.01550920547978, 61.37607566771969, 62.01331961539484, 60.655057737904215, 59.479931323759025, 58.511706013833326, 57.73553563702492, 56.247247188322014, 55.68049215501355, 52.138791930290964, 53.83178495591687, 54.62010683551912, 47.123912226769235, 49.347900036842596, 44.87174610937796, 45.339425994503884, 48.23003238247287, 52.08219212870444, 49.99216502712619, 49.26032135563512, 48.989289499098255, 50.76532302364227, 50.20589105544552, 51.70871580800703, 49.58826288100212, 53.04691083969609, 51.31592181421096, 52.987475164474986, 50.63366866880848, 52.24861437274564, 52.41429921119444, 57.08715608043056, 53.642161892306426, 59.81252478015039, 65.53971082933488, 70.7995190158967, 71.52492215556484, 73.48335373786189, 73.08287189852807, 78.23973747991747, 72.65106601099815, 87.10418424298688, 41.88641055937737, 0.7745967709249066, 63.1217461247598, 65.98407222378638, 45.855421635412405, 35.90489018347956, 94.53525573976579, 64.72773705759357, 50.05509161180066, 63.40541585799187, 2.7977663374716237, 0.17294030396207688, 0.2202122343043166, 0.05055614161275087, 0.021841465495526794, 0.19945177249610427, 0.026096991984353914, 0.04214407868623253, 0.06491577027425652, 0.15771047602738106, 0.29803470918728464, 0.17144713731062028, 0.1457004543514021, 0.15846793780163412, 0.26549331663597014, 0.4640873924138085, 0.1275379882164059, 0.13216331300716247, 0.1760470969302039, 0.16386251445979844, 0.2774669644573043, 2.944365167810071, 71.49701056941863, 68.5199551428518, 50.22223949432374, 55.0596123356973, 61.53538665463848, 47.979161508621715, 90.33011405698716, 44.8752958543839, 8.764373371678015, 76.10649370378064, 78.4469170724192, 81.73311802648729, 79.71180300558768, 76.86302477313627, 71.76794436670119, 69.8241981383293, 70.02311721924814, 66.8015726151005, 68.19888561002671, 62.87777470004175, 63.24728942686512, 57.80686393860848, 59.84484511037027, 61.17523462541642, 63.68076624408845, 64.34097174675234, 64.4991530910615, 60.32876360800959, 55.22363016682287, 54.12635103348763, 52.522846883343114, 49.78244766112297, 55.17394158147997, 51.80906964886574, 52.72040097944198, 47.01896921280892, 48.259352099510934, 53.242550819150864, 57.3623848730518, 58.36672344515401, 57.5305211928583, 58.28155309923234, 57.26048169597503, 57.86826472128592, 51.65182182865759, 53.48162712589387, 63.574258204429384, 64.68351233390071, 65.54935985995878, 64.69633456199401, 64.38163495832875, 66.13232212681925, 62.567087681062766, 66.2825410596786, 65.92389522060272, 65.86735033219861, 61.5284832831352, 60.80055805944628, 60.52791018639842, 57.710420700811575, 67.66996183703023, 55.25194967946699, 38.69389933924521, 49.96317871155278, 45.86666707069644, 50.148404798200055, 49.06053543090821, 44.80273200619606, 45.298135203699914, 46.256413382868615, 43.52271356890279, 46.0593338935606, 48.37356759655861, 39.066473514803, 40.83663525119905, 42.98871817127351, 54.602067855096635, 57.31198241633754, 62.54177662634081, 73.41253142203055, 57.336834553749334, 44.35799798657818, 51.58186243426416, 44.25070547288464, 49.95029764790689, 45.86104239186933, 48.29565755782589, 44.27304337101598, 46.777119790354085, 38.614432119554095, 56.135518473963586, 63.04724854807701, 32.126420005675286, 64.02919038649529, 62.7807705633102, 64.4536026062504, 58.82183997861801, 63.90174865722657, 61.56154101894748, 64.29381701254076, 62.05132738236458, 59.88881095763176, 57.88006321076424, 65.85402996309342, 65.63027443424349, 62.50587124978343, 61.54902081335745, 59.67333947458575, 61.04427845247331, 57.882922618619865, 57.374073536165305, 53.170861659511445, 55.24329693086686, 56.21112215903498, 49.609655487921934, 51.29953807400119, 48.519216968167214, 49.18926761996362, 50.27680750816099, 53.89615105044458, 53.064086898680664, 51.61530456235332, 56.02115784921954, 54.79052205239573, 53.395154553074995, 54.04482064708587, 53.393997453874164, 56.61512628678353, 53.245986815421816, 56.20653690830354, 53.96988768731394, 54.0737206705155, 56.93271275489562, 60.31868311666674, 56.69449152485017, 63.08921006418044, 71.63757262691375, 79.45958675876741, 75.55568310522264, 76.48566922833844, 76.70722038515153, 78.93553456952496, 78.42317888813635, 83.01292465579125, 48.281368363288145, 1.5303586880045554, 61.69220301412768, 75.07523198281565, 48.91089308646418, 50.15284884360529, 91.45177072094333, 70.77243897222704, 62.99202942079114, 80.88514081893429, 4.339044536313703, 0.5320965414566379, 0.27037960927813287, 0.14120128125913683, 0.17603467098407208, 0.32145990058779716, 0.3344875015318394, 0.1462625177396882, 0.21130221805745558, 0.23188632642549856], [0.16963630464048157, 0.2011222885020318, 0.16333052768341957, 0.09983095520686719, 0.18129495242911, 0.06050016588321137, 0.15898694704857566, 0.27426879252156905, 0.09378866653048223, 0.47193596319806197, 0.36117285670292, 0.7174356413945076, 43.04061505102342, 53.96840895375898, 29.4986653712488, 33.11553193676856, 37.36142312326739, 30.900624413644117, 62.67144233949723, 58.924464871806485, 1.883045098473949, 38.367103145968535, 79.29484721153014, 71.49293130443942, 75.87683893019154, 69.64721295141405, 69.62969564622449, 66.42048297389861, 67.1782535122287, 63.455610429086995, 61.195929050445564, 58.27348086141772, 54.113128723636756, 54.61573339277699, 54.59781600582985, 58.10282637996059, 56.82172929086993, 56.77306836651218, 56.78593766304755, 54.291286699233524, 49.711146816130615, 46.39692444955149, 48.1369702277645, 50.27862748792095, 51.42120215200609, 48.75426500074325, 45.88119160744452, 44.49129189214399, 46.175741995534594, 46.8516016775562, 47.90399712900962, 50.40075048323601, 50.33446242732387, 48.759873990089666, 51.27685500729469, 52.88395597088722, 52.95208754078035, 52.009302723792295, 57.28586727573026, 59.25302613166071, 57.25008741501839, 61.47875939646075, 59.610703145304036, 59.76426785992038, 60.17642267288701, 59.118555515043205, 58.4512819013288, 59.0150559333063, 57.04544559601815, 54.199989611102694, 55.467107372899214, 56.28845953172254, 51.513111129883804, 55.303925006620354, 41.7535206579393, 46.98590755462647, 42.021014536580736, 40.58335996443226, 46.63519667040917, 43.89506416936075, 43.633159668214866, 41.83806734700357, 42.45164371305897, 43.29025822301065, 43.59550099219046, 43.73692989349366, 43.20793551783408, 40.11077319422076, 45.36199923484556, 49.79837248402257, 51.42484603389617, 58.894564643982925, 61.47592352282617, 42.032091309947354, 28.60618102935053, 33.73436427885486, 41.662349085653986, 43.23543917748236, 38.90493854399651, 39.54368475944766, 38.56929348361108, 57.96698685615294, 64.422204033021, 23.29634693361098, 35.17373684913882, 54.44333345659318, 55.2289096770748, 56.07808320753036, 58.283933977926935, 58.08967075040264, 55.64024471467542, 50.127027880760934, 50.84292711750154, 55.732796961261386, 55.79683357669462, 57.773335518375525, 58.5144438282136, 56.26727481042185, 55.2525851034349, 57.46832809140606, 57.557526711494695, 53.858986593061886, 52.44457990892472, 47.198578465369444, 49.32726444736604, 46.99787078365203, 46.67538135282455, 43.574967384338386, 39.31999591089065, 41.244867693993356, 44.08165524082799, 45.86678866417178, 47.16798005565521, 48.82295746957102, 46.26702339418473, 44.61661161914949, 46.56912042248634, 46.98147527633175, 45.34816503524781, 48.26336860656739, 48.89050852867865, 48.569968515826815, 45.47059397543631, 49.60422692760345, 49.60940837860108, 52.192697063569106, 48.61572688625705, 55.473540059981815, 56.44007482836324, 60.35018759389078, 61.29310184909452, 68.02773690992787, 65.54883426235568, 78.08505488980201, 62.8341422542449, 86.0762643814087, 27.148469417325913, 0.7679348703353637, 69.33951870087655, 50.59402919584706, 42.90796441416587, 34.40319507352768, 42.07533151872697, 40.07901768530569, 57.38034148370066, 38.594145621022875, 1.0014517689424178, 0.3931483554263269, 0.24996405557519008, 0.18212664812322588, 0.09865272730108231, 0.05448043083531722, 0.0884213932459393, 0.11439182750520208, 0.16016972551663078, 0.28792415655428366, 0.023943403916012858, 0.1767716475672299, 0.09705306676727149, 0.07204092423161192, 0.09307970578271536, 0.11031643893089026, 0.022587114193987463, 0.049836068759642305, 0.05977744236588479, 0.15669908674974597, 0.03665730334638107, 0.6758937576124746, 49.74176483769571, 61.00940465927125, 31.380261644240353, 43.86634065258888, 48.13322436424994, 38.69047511008478, 62.83054151842671, 64.38385501984628, 2.183236590316219, 35.4200852301813, 84.55320019875803, 73.69302011305287, 76.9921648886896, 72.66718695240637, 71.6675473797706, 68.87787142107564, 68.7822832599763, 65.8911983428463, 65.40452634134601, 60.10112885505923, 58.03271401313044, 58.48472795178814, 59.43556539473995, 60.11635941843833, 61.72271120932795, 59.765628922370176, 61.76160150958646, 57.709636226777114, 51.33875785335418, 49.22576919678719, 50.163823635347434, 53.2351218500445, 52.43652336059078, 51.20515408054475, 51.18921749053463, 46.19456152762137, 46.4913280548588, 48.77050753562681, 50.23682286662441, 53.31409485109391, 54.28680343012656, 52.364559635039306, 53.9547904845207, 56.161672838272594, 52.44015155300018, 51.16858974579842, 59.12152867163382, 60.77765534001013, 60.331603404014345, 61.88924327973397, 64.78100676690379, 62.99523007485175, 61.13689345698203, 61.360499935765425, 62.143491314303496, 60.49336587229083, 58.05815450606808, 56.639162571199485, 56.63423215189288, 56.06132291978406, 53.89602161222889, 56.258284737986905, 43.892742126218735, 49.29763094071419, 47.28467841302195, 42.7477591268478, 47.6585195141454, 43.88805489386282, 46.158926794605875, 43.227853313569106, 41.64954646941155, 44.02829923937398, 44.30384966634935, 48.58158657627721, 40.82691169554188, 37.62908566382624, 43.73927154848653, 46.42682467737506, 50.24627185636952, 59.36939500993299, 71.15218716282999, 61.53828528619582, 38.97371730496807, 37.36984052965718, 41.635606365819136, 42.5573633563134, 41.880511314638206, 41.91195695630966, 38.91686647169052, 57.8928775941172, 80.09024112455307, 34.57468894220168, 37.12019343529978, 54.493296607848144, 58.12392088674731, 57.65005150148946, 58.516663889731134, 57.307663886777824, 60.21882741681991, 58.5059440520502, 55.74789024168446, 56.47189701757124, 57.54473586236277, 61.8730870369942, 61.234846807295284, 58.24111346275576, 55.07756894634616, 57.39590937091459, 57.09924482530164, 58.30515792292934, 54.0537714958191, 50.737854665325536, 49.93069756415583, 49.05352615541028, 50.76713515866188, 49.12574875739313, 44.28089203373079, 46.500620149797015, 48.20135593414307, 49.889469531274614, 48.84314590884794, 50.10074015586607, 52.17120639739498, 50.258258619616115, 51.29282689863636, 51.52304649353028, 50.24358895517165, 51.707813662867395, 53.78545391944147, 53.462544795005556, 47.213820795859064, 50.25669751628753, 53.74664598895658, 54.59675304351315, 54.16940296849897, 59.3539487161944, 59.58632953705327, 64.85335488473216, 65.68652514488467, 71.85615847187658, 69.81598469518846, 80.71817336543914, 67.17279357294883, 88.6144301199144, 28.313413358503773, 3.414952019529958, 77.29986698396745, 55.29062032699586, 49.788664617846095, 36.886569223096295, 56.572752921812004, 48.64889052606399, 60.97054181560394, 52.370235304678644, 1.144750108641963, 0.18590732267306698, 0.23592987638567728, 0.03759538950098138, 0.13520183221947762, 0.17086650395104963, 0.09396402405635004, 0.08725711580125556, 0.12442781680053282, 0.28283068309387854, 0.3428571040351545, 0.3651636844921497, 0.36466229526746663, 0.1873794678718813, 0.3442211082625774, 0.38782655712096925, 0.27406299066159034, 0.33665602065382466, 0.13997621473766145, 0.5659259423132866, 0.5971200619974445, 1.531070353042695, 62.42223062822896, 68.13756327475271, 39.01385884131155, 48.08233161126414, 50.17313926450668, 47.200931887472834, 73.12222896083709, 67.4131799513294, 2.7110902917000557, 43.780617252472915, 87.35709867169781, 75.27822248397335, 79.00606662996354, 75.60094725701117, 74.89843506966868, 73.55598818871283, 72.55135151647752, 68.12647865664574, 68.09083215651974, 62.9186575643478, 61.024101780306914, 60.10672215492495, 61.152249536206654, 62.78506555864888, 64.44511851956769, 62.732513643080196, 64.8473262017773, 58.67829691979193, 53.5073108057822, 50.11842220060287, 50.97331846913984, 55.984515067069765, 56.16304959020307, 52.64914720289169, 52.704958608073575, 49.065983603077555, 51.38812088197278, 52.983254694169574, 52.78266076118716, 56.28640420975224, 56.52437440810665, 51.372105844559215, 55.40030156412433, 57.50608482668477, 55.36800869049565, 53.27855425496256, 64.11101495065998, 63.874354823943115, 61.233921127934615, 66.08603031404557, 70.389160648469, 65.43157892842447, 62.79635414000481, 66.6118005014235, 67.30001172711773, 65.4536069593122, 60.77398007915866, 59.2801179424409, 59.00881936473232, 61.05519048629269, 58.06570899101996, 61.00314455647623, 43.602800523081136, 48.32423594690139, 48.18579196929932, 42.21102199246807, 49.928332374941924, 49.537660383409076, 48.21608835651029, 44.71170556160712, 43.63126124105146, 41.967466338988274, 47.01504292026643, 52.04964037864439, 46.06292678463844, 41.84856753195486, 48.46797904660625, 53.240479807699884, 54.3771081586038, 58.547489796915364, 64.36195642717423, 64.82461175610943, 45.01375944383683, 43.84652483847834, 46.31307986474807, 44.546746361640196, 41.82795155432917, 42.27873386875276, 40.03543623032109, 50.55431912022252, 65.98756313323975, 39.236300376153764, 40.29446563413067, 59.699505606005275, 62.50654981982324, 60.14280796051026, 61.11300230026246, 61.76382941584434, 61.085463339282626, 58.21291554358698, 58.13603708820959, 60.537676888127486, 58.0119058393663, 65.58606540003132, 64.9319984066871, 62.54140400117444, 59.25857236308437, 58.50317485870854, 59.98688982379053, 59.44004474147674, 55.089543942482244, 51.543042736668745, 52.54838151316489, 51.116488902799546, 54.06972769768008, 51.277082504764685, 46.7530599717171, 46.5450253025178, 50.47607568002517, 53.803896903991706, 53.53367305571034, 55.40635770367038, 56.01678048410724, 53.31007834403746, 54.3243169784546, 54.33046333251461, 54.08362073283042, 54.78125349167855, 56.61664424404022, 55.765568364051084, 48.32102744810043, 52.77247828821982, 57.29569673538209, 59.10972625978532, 56.07527086811682, 62.81416170058712, 66.44546847189626, 68.60712589756136, 69.20109825749552, 73.68435167497205, 73.31420544655093, 82.90782866939422, 70.09871698194935, 85.99176868315666, 34.39495025142547, 4.343785210963219, 80.26313920174876, 64.25929231028404, 55.58005594438123, 47.84396525352232, 51.20933140477827, 59.49869986503356, 77.63988940946518, 62.68095016479493, 1.8780146587279536, 0.7493846947627684, 0.7204448960481152, 0.1633981272818581, 0.2185286028731254, 0.24778763042582622, 0.24042468277677415, 0.19315658287415582, 0.20660643616030294, 0.3930945760540424], [0.11315252707009354, 0.21847977242883176, 0.14985095018581038, 0.006317581893170193, 0.045493951352733764, 0.19921914223701725, 0.08792486867957539, 0.3459814250949891, 0.14275984117581, 0.27934532011708907, 0.7061123715773706, 0.3574060330227498, 42.379985932380926, 58.9975150938957, 38.311032864355276, 28.88350829001396, 20.766641747566965, 40.147498346144154, 45.69580078125001, 80.99654397656842, 4.304285472439182, 12.96982394110772, 80.26145258257466, 75.1426810602988, 75.68777284314557, 69.57001286168253, 68.03942557304137, 66.70559221698393, 64.81436260284917, 66.15090631669568, 60.34495515208091, 57.84506782408684, 56.61183934057913, 56.36898186899001, 57.7699387458063, 58.18560015770697, 61.37960972324495, 57.85401867282007, 54.498168191602154, 50.6817255481597, 47.06007957458497, 48.2863340839263, 49.14784346857379, 51.554507824682425, 49.27961157214258, 50.70884089316092, 47.26596086255966, 44.99336704131096, 41.95104729744696, 42.18147477796001, 45.902788177613296, 48.69550789556196, 49.84612341850035, 52.83705619073684, 54.19269008021201, 51.09725359947451, 49.139025980426425, 51.17448899053758, 55.33814768637381, 58.398251456599084, 60.507745281342544, 55.01794107498662, 55.25681734085084, 59.22168639398391, 58.29938811640586, 61.36840351166264, 57.6612106446297, 59.29805886360907, 55.256680057894805, 52.00137561367404, 54.184209915899466, 56.00970845068655, 57.500903375687145, 54.91695573253017, 50.30622920682354, 48.959177463285386, 59.73900779601067, 45.505577595003196, 38.734880262805575, 39.64811786528557, 40.62660017321187, 43.078940529977125, 44.95598685356879, 42.47725286791402, 67.3306768171249, 67.04167658282866, 24.525045079569665, 36.72305737772296, 36.48884480999362, 41.91988406642791, 43.15847835233135, 44.35312248045399, 65.03166191039547, 88.14220028538858, 73.87395120436146, 51.73237162251627, 43.30483375057098, 47.83124892942367, 50.13012263082689, 49.73210403996129, 52.91155376741963, 44.9008422513162, 16.05395124804589, 21.185876438694617, 50.83807514559839, 53.59935314424577, 54.08035732084706, 54.90380402534239, 54.559474837395456, 54.156400311377745, 52.4994146439337, 55.611634946638546, 54.49228463634368, 54.93267659218081, 56.49634907322546, 58.882801455836145, 55.423141525637725, 55.65118812745618, 55.11409797976094, 54.94053702200613, 50.87852654918548, 53.514159264103064, 50.060865340694306, 46.828498917241255, 44.858970949726725, 46.673843783717004, 46.24736447488108, 42.80284097117763, 40.17128359886908, 42.93906096489199, 42.63075482460761, 43.418715846154, 45.751165036232244, 48.69057355388519, 47.8830595170298, 49.12820023875083, 50.906242016823064, 56.0835039231085, 54.98359287938764, 53.94813814470845, 49.26358476761849, 50.49652299573345, 48.139280503795995, 50.43951526764901, 49.95847578971617, 52.33297671041181, 53.01524554529498, 52.52036010065387, 50.925547922811205, 56.694660186767585, 56.829373990335775, 67.3899281409479, 63.11632540918166, 76.5635439657396, 66.42376992010301, 81.63764753649312, 19.97452105245283, 7.3327278706335255, 78.40706579146847, 43.54880517528903, 48.23597085091376, 29.840799993084325, 18.526040738628758, 36.03586989064371, 55.960537618206395, 51.23888646402667, 0.3591316920374671, 0.04353047566368215, 0.2498094283885533, 0.16144025169553297, 0.042832964099943645, 0.12010154975277763, 0.21714967525293752, 0.06629134242933604, 0.08638070355499945, 0.01971692556605464, 0.053976865920929186, 0.03836130122503927, 0.08544157169038251, 0.15679996520761522, 0.09272408010738512, 0.18180970222719256, 0.011428126186553028, 0.20265245720023112, 0.05122825353135986, 0.0906063832582966, 0.4169203395084028, 0.3060060991875587, 50.499472618103034, 65.0399616456801, 41.45285921712076, 35.49709704614455, 27.95157078773745, 49.99398892925632, 48.08929774069017, 89.16013379250803, 7.130094795457779, 12.931724979031472, 85.84952000648745, 76.55812325016146, 79.44570941309776, 70.50830656482329, 73.17135272487518, 69.61027206913118, 68.64836569755309, 68.47354565897297, 63.96500864336568, 60.27569786194832, 59.61099340069679, 60.77679634094239, 60.91546389364428, 61.190594627011215, 63.051088548475704, 61.64937857658633, 57.41765891352008, 54.34513691932925, 49.276889447242986, 52.77971506118775, 53.218518457105084, 54.57905530929566, 51.52065777009534, 51.28818673472251, 47.94118512061335, 48.125422769977206, 46.25763716236238, 43.353600578923384, 48.320341033320275, 50.56160688400269, 51.541709130810155, 54.76140629860663, 55.32496852259482, 53.28939568611884, 49.77592475952641, 52.22600975344258, 55.794091839944166, 62.79524018687587, 62.548017117284964, 59.21100970237487, 58.47795794087072, 60.50019471876083, 59.8457904015818, 60.44883128135436, 61.45847289792953, 62.29307482319494, 55.92336923845353, 53.385866380506954, 55.436246164383434, 60.20012947820849, 57.54744622015185, 57.26278412726618, 52.12952336957378, 53.42285433123189, 62.59730169850012, 47.636703291246974, 40.6185200906569, 39.64221077580606, 39.273947285067656, 41.65353551987679, 46.10901071179298, 44.635050681329545, 74.51673353871992, 69.14804427854477, 26.864242707529378, 39.17351891917568, 36.59705123593731, 41.218391695330226, 42.80966981764763, 44.06792694522489, 56.62881928105509, 82.19257662373205, 80.93672783144059, 61.057838086159, 48.49921680265858, 47.68041026207709, 47.45326580539827, 49.83292072050033, 53.19638844459288, 63.227034307295284, 29.53349601837897, 25.398241166145574, 54.0585450203188, 56.70907881952102, 60.99518998976677, 58.60840028332126, 57.65535454596243, 58.8550663763477, 57.03591031412925, 56.80613002469463, 55.26348537014377, 57.751746792947095, 59.17968565417875, 61.06275673835509, 56.34711465527935, 55.21455380224413, 58.85695695877076, 55.19711102208784, 51.268472902236454, 55.48966100139003, 50.77989855120259, 49.122520646741314, 48.85622701337261, 51.910427616488555, 50.20569101456673, 48.48645341011786, 44.65859666947396, 47.22857675244732, 46.23472267581571, 47.734844915328495, 50.0540090376331, 54.08505632031349, 51.56752617128434, 54.96861727006974, 56.10621444640621, 60.821503516166445, 58.26404363878312, 61.14847229373071, 55.38353343163767, 54.0208863442944, 51.35414138917, 53.77970372476886, 52.73973041965116, 58.01880921086958, 57.63808042772355, 58.458510829556374, 54.98128260335615, 60.62946035015968, 59.63404517019949, 72.15837709365353, 67.77002150012602, 79.61426150414252, 67.44358616490518, 84.99943256378174, 20.25054608621905, 11.138655620236552, 83.77058536775651, 48.58944700610254, 53.09889401158979, 33.713885584185206, 27.022486809761297, 44.316871935321444, 62.871487140655525, 60.93116906381423, 0.9816984063194645, 0.048393540519980655, 0.051751644801228285, 0.07720042681021076, 0.09509190466375121, 0.11404012420004415, 0.26655278559173307, 0.10141413718942674, 0.08537731223529385, 0.04858559493215815, 0.20045246718631637, 0.24555799280924184, 0.28716002981508937, 0.2372636967488835, 0.18420437050442542, 0.4619813554229275, 0.22801759772964064, 0.5673254317333621, 0.17600019702747946, 0.446458422248402, 0.7192421992940288, 0.6393163074408809, 60.094986423369384, 75.41898850471743, 51.06612959215718, 41.92054302461686, 29.803047180175785, 57.73718695486746, 55.936791589183194, 94.11171820855911, 6.648367431855972, 18.314136651254472, 87.62029755500056, 78.70185544413906, 81.24450052938154, 72.10057704679429, 76.13973186862084, 72.23278445582237, 71.45799867568478, 73.10802998081331, 68.43531039453322, 63.64351941693214, 63.02704834168958, 62.68879098276939, 64.54225993925526, 62.72669284574447, 68.34938695353847, 62.27010542346586, 59.780126002527055, 54.52313407774895, 51.86453196310228, 52.195215225219734, 55.732122313591745, 55.57661994811028, 54.05825084255588, 53.72291172704389, 51.082148551940925, 50.445202704398866, 50.050898598086455, 46.96780581628123, 54.18282531922864, 56.16567365584835, 56.27138153199227, 55.02469147405317, 56.52997163034255, 54.971590426660356, 52.499646063773866, 56.09414923575617, 57.44848482070431, 64.35253097165015, 68.04884710619527, 61.4472706087174, 63.601695183784734, 66.22210518006356, 65.56579851335096, 64.51415223460045, 64.45284166643697, 64.76249710206064, 58.673374345225675, 56.78243890885384, 60.68799388024115, 63.110453621033706, 62.47922266683271, 61.03305655141031, 54.74127277251213, 54.75153369288291, 64.24565030682471, 49.218877592394435, 41.9675761653531, 41.32548416814497, 40.25078219752158, 45.5307395996586, 49.103763872577304, 48.27344517554007, 78.55939495948054, 68.49134537481493, 29.22096940778917, 39.53487903841081, 38.79787745014314, 45.85478621144449, 46.869075836673865, 44.92131310124552, 53.18875158986738, 64.91652857872748, 70.72680611764231, 60.19200624958162, 54.22967410856678, 53.380375062265706, 50.333403387377345, 49.54173572601811, 49.00393955169186, 57.02032673743464, 35.429632279180716, 24.26430944473513, 56.21636636795537, 59.94587752126879, 60.98124988617436, 60.76751993548486, 59.34619026799356, 58.942664669406035, 58.408104450471946, 57.94980295242802, 57.27539062500001, 57.70592174222393, 62.26027204144386, 64.39523381571617, 61.964337056682965, 59.17524160877351, 59.050580839956964, 57.85508947987711, 53.38752946546001, 56.75336237876647, 55.25481300969278, 49.63663354996712, 49.38689624109576, 52.5614155492475, 52.312094011614406, 50.62113669610793, 46.212070988070586, 49.71144491626371, 47.76965987297797, 49.31403821514499, 53.339425517666726, 59.60492549404022, 55.54251493946199, 55.94865283658428, 55.98117320768295, 62.44300742303172, 60.35743221159905, 64.10728085425593, 57.45640800845239, 55.63731862652687, 49.960907659223004, 56.513831077083466, 55.727019309997566, 61.07358640240085, 63.24359847653297, 62.78746997156451, 57.39904334468227, 65.13112145085489, 63.01652854488742, 78.73426991124308, 68.649001121521, 84.49789477932839, 68.48998038999497, 84.68679612682712, 27.697169780731205, 10.023689539201799, 88.02006552296301, 54.46672647230087, 63.17630237148654, 43.74140531786027, 28.656810983534786, 48.78390242976528, 74.19451082906416, 73.75089076257521, 1.904411719691369, 0.26377914894011717, 0.39418006135571393, 0.4042356395192685, 0.2657483626277216, 0.2830989364414446, 0.3278210963453016, 0.26851819948323313, 0.15534171684374734, 0.1804339615327697], [0.28287125511034844, 0.04878706456492505, 0.07491182340609451, 0.14541281897935177, 0.007957609036126205, 0.08359241930227126, 0.07782289623132638, 0.03116488193852767, 0.1983590246809106, 0.11859695306949078, 0.1891700145337851, 0.34033449907456675, 35.837629379764685, 54.85127956636491, 43.88156729359781, 48.03524355734549, 39.15426400399978, 33.39465564297092, 47.03882425062118, 82.08700210817399, 24.325090492925337, 6.14093138325599, 83.21385983497866, 75.15029045843309, 78.696254299533, 71.66964977018296, 72.80927873426869, 67.06358694261121, 66.84346352854084, 60.170860751982666, 57.429359343744096, 55.46328698435138, 55.05102234501993, 58.12721567769205, 56.870574566625784, 59.876930098379816, 58.47348643887428, 57.136515186678984, 54.62304076840801, 52.112049210456114, 50.597135713023526, 52.227555167290475, 52.786183049601895, 52.16995908368019, 49.37105771033995, 46.869805397525916, 45.20524563327913, 48.78161568795481, 48.50137018388318, 43.484333176766675, 41.58701212175431, 44.038093397694254, 49.66933042772355, 50.20619307794879, 53.35100435441541, 59.22703258452877, 49.263839721679695, 45.908546217026256, 55.13516895232662, 63.22943087547057, 56.69087902192147, 58.28154917686217, 59.272590914080226, 56.10972496771044, 53.00533763823971, 56.49879270984281, 57.38681339448499, 57.09331027923092, 49.189091113305864, 50.76500531165831, 56.707819738695704, 58.96111942106678, 56.29507264783306, 54.95222176274946, 52.76013066691738, 53.61014358458981, 59.31125763923892, 58.85975360870362, 45.016944408416755, 39.632938292718705, 41.71546582252749, 44.98938975795623, 39.677225774334325, 44.37220481134231, 63.191309359765825, 51.753364147678504, 40.66831457999445, 48.024017733912316, 45.162299602262436, 43.75583179535405, 39.36955505801786, 38.27259363666658, 36.57239129466396, 55.07897315486785, 59.96129243604599, 64.76215193348547, 67.67309973316809, 56.52056578666934, 51.48303831777265, 50.275571961556714, 38.625720700910016, 24.15662861639454, 29.789163950950872, 54.77032969074865, 53.563581128274244, 54.8763592012467, 53.83093772395965, 54.298492093240064, 54.89939920363888, 51.90930581861927, 52.42985533129785, 52.92915736475299, 54.71835436359529, 56.87581093080583, 55.23861754325129, 56.20340293453586, 52.75226239235171, 52.08531041299143, 53.58965312280963, 50.32719819776474, 44.56626407561764, 45.555893759573664, 44.7846185007403, 49.811092730491396, 48.772606003669004, 48.678829977589274, 42.71183413843955, 41.93917428293536, 42.750473407007036, 44.01542209809826, 44.47381773302632, 44.62085170130576, 44.68076982805806, 48.11545602736935, 51.937546883859945, 57.938977210752434, 61.93594694137574, 63.83772380890385, 61.996912340964045, 62.20715138220019, 61.083721806926114, 57.23445284751154, 55.69489117591612, 51.27732961408554, 50.499205896931315, 51.39123916625977, 48.85203792202858, 54.362046257142104, 51.13769715832126, 53.85153016736431, 56.98930078937162, 63.32812947611656, 64.21698562560543, 74.98383291306035, 64.06204023668843, 72.98097656619164, 7.648730681788537, 22.343222748848703, 75.83822711821526, 42.76260529795001, 29.002709119550644, 21.373793271280107, 44.93080915943269, 36.999243228666245, 53.31567164390318, 43.55374736170615, 0.6547203131260411, 0.11680869701048059, 0.23135627019068888, 0.11144253455342785, 0.22440362391212296, 0.1754468363980132, 0.11582156973740748, 0.05653774080377433, 0.1239268872286043, 0.04040245822961292, 0.10001600374497714, 0.05076039597512253, 0.022114018511567867, 0.1732985573189874, 0.09258225424996308, 0.06890783912592358, 0.0876335943898847, 0.05668813535462945, 0.08355327987021978, 0.0775079804682924, 0.29231316620303743, 0.20596270779928855, 47.323372594771854, 60.38157047763948, 45.51075512363065, 48.290852654364805, 36.38512557552707, 47.37915654336253, 51.500073171431026, 87.88817974828905, 31.0584762788588, 7.511828685960463, 84.16833723745039, 78.10491777235463, 81.34078687237155, 76.17011454797561, 75.87122994084513, 71.93723386333835, 71.14769997135286, 63.16967356589533, 62.60645258811213, 59.3975733172509, 58.011501835238555, 62.37834715074109, 60.920394312950876, 63.08328336285007, 60.69720752777592, 58.35714893956339, 55.963887322333555, 54.68879538197672, 53.98764817945419, 54.94971144583918, 57.03219190720589, 55.5065821063134, 51.05780632265153, 48.186772561842396, 47.72670991959111, 49.74925656472483, 50.6038978792006, 47.135087059390166, 43.97329192007742, 46.899564420023275, 49.6889462009553, 51.56807922547864, 55.360866054411865, 60.145690902586914, 51.48416403801211, 47.58717160071097, 56.86449881522887, 62.97739113530805, 60.12573388315017, 58.56072387387676, 60.124796436678984, 56.322823416802194, 56.30911865542012, 57.340203869727354, 58.41885174474409, 59.29228513471542, 54.196686975417606, 54.409754045547984, 58.56730168865573, 58.51159226509833, 58.21305674891318, 56.48932410824684, 56.269357588983354, 56.202336049848995, 59.019131275915335, 58.07273395599858, 46.37941498910227, 42.69678400408837, 43.06024259136569, 46.1063866461477, 40.367508011479536, 48.383291152215776, 74.6010801869054, 59.447273669704316, 43.40309696812784, 47.82318061397922, 44.85437785425494, 42.92032772494901, 37.80235244381813, 37.99619597773398, 36.398002716802786, 47.60283754717919, 51.24786084698093, 60.127451881285644, 66.650098523786, 59.269829565478915, 51.97499375189505, 53.63361504770095, 46.73353441299931, 31.25783270405185, 34.585597053650886, 56.90288705210532, 55.058808249811975, 57.3178542044855, 55.89493205470424, 57.75952877536897, 54.565232876808416, 53.88747476762342, 55.301803004357126, 54.03048438410605, 54.7385859489441, 58.78354195625552, 56.99772604050175, 58.08820770632837, 54.88855385011243, 54.45122526537988, 55.558847688859515, 52.195681987270234, 47.485256656523674, 46.119044134693766, 47.68555641174317, 51.95728425056704, 52.57990952460997, 50.35206210228705, 48.27849718832201, 45.58393086156538, 43.61259468140141, 46.20887033400997, 46.18686191497311, 47.9356663457809, 48.792892502200225, 53.356130892230624, 57.92728854763893, 61.297836149892504, 66.21026746688351, 66.84960596023068, 65.74501552889424, 65.65174156619658, 61.55460626848283, 61.68377776299754, 58.5837991776005, 56.14148047662551, 54.81656266796974, 55.522781495125066, 52.81411032522879, 58.6470317071484, 56.03034796253328, 58.044700776377034, 60.77385848568332, 67.24127031141713, 69.24109074377245, 79.45264416356241, 69.453228212172, 75.5614568341163, 7.122507950951976, 28.776309913204564, 80.9606699789724, 47.31728507626442, 35.63382302561114, 28.071322710283344, 43.02748295568651, 43.12160807271158, 58.57802152633668, 53.37831974029542, 1.0471205990160666, 0.2058968548813174, 0.07101900890589723, 0.10747905610309494, 0.17701740857333909, 0.2805408769317212, 0.07259596259363237, 0.1602665896737768, 0.25450646666990173, 0.12808344281849363, 0.43853336524578834, 0.20487193649093952, 0.30494552706518485, 0.27033382786377785, 0.22581917053509146, 0.16095263673172844, 0.23602940652879978, 0.14266706792817963, 0.31357066585652293, 0.10837790706465322, 0.284229253208445, 0.4390728750055836, 59.474569443733465, 73.99951411831763, 54.4234666516704, 65.58057015941989, 52.12255724014775, 46.85945818501134, 59.66392970854237, 96.94732512197187, 31.752412203819524, 8.93821575949269, 93.57492616099697, 78.59257821113833, 84.1661250206732, 77.6715664709768, 78.21969416833694, 71.44390167728548, 71.89637061088317, 64.84458054265669, 65.28616882139637, 60.97063987485824, 61.31558487492224, 66.42236571158132, 62.29374554849441, 65.53355663053452, 62.5458166676183, 59.533432452909416, 58.220999548512125, 59.383570455735736, 55.46526385891823, 56.55935802767354, 58.950725140110144, 55.882341246451105, 54.91342167700491, 50.82717880125969, 48.26185849405105, 52.796538106856815, 53.62006718112577, 50.480680542607466, 47.22094382009199, 48.32609122799289, 53.05956440587198, 55.47921572962115, 59.3508186647969, 64.71923335905998, 53.25288626455492, 45.90868349998228, 59.93001937866212, 67.65478226446336, 62.59432461953933, 62.18852012388168, 63.98101191366873, 62.12495027049896, 58.88248766622236, 60.943304877127375, 63.97496361886302, 60.342711556342344, 54.54869224179176, 56.56396681262601, 63.536764267952215, 63.348212011398815, 61.89224781528596, 61.28077383964293, 59.78442884260609, 60.56213678852205, 62.32356340654435, 59.553868001507176, 45.9415804186175, 42.61620283126832, 46.242877283403956, 49.01183528284873, 43.26156608520016, 55.08458214421427, 74.30501968629899, 54.90221546542261, 38.866114924030924, 47.161115907853656, 46.33338597513015, 44.916751384735115, 38.42578964848673, 37.49985925612911, 37.4913594799657, 49.99468318877682, 50.11735139354583, 55.585841440385394, 63.83794738400368, 59.29248517559421, 53.72525730440694, 56.30572580522107, 52.12662081564627, 36.29105929405459, 33.82343346072782, 59.440621329892075, 57.66667842864991, 60.89904092973279, 58.70511416466006, 61.98887540448097, 59.523206833870184, 56.698531566127656, 56.991783649690696, 56.946142950365626, 57.1020414752345, 60.65092748211276, 59.76942969906715, 61.75325862822994, 55.96027874177503, 57.033686330241544, 57.00328011666575, 55.133811812247004, 46.79358590033747, 47.67055334583406, 49.839227891737416, 55.3777910817054, 53.73735781638853, 53.129786599066954, 51.06647476073235, 49.67102096926782, 48.239846152644006, 48.69537845734627, 49.53833110870854, 53.42059112364247, 52.75609454801006, 57.12156703395229, 58.71712446212769, 64.57538435536047, 69.48815299618629, 70.99072671705677, 67.78616597575527, 67.89073636454921, 66.03761257663851, 62.5320020798714, 59.90209210303522, 57.04677527950656, 58.01225885268181, 59.398781407263975, 56.64211611593924, 64.25410301454606, 58.74449083881994, 61.715419523177616, 65.51388986649053, 73.37901084653794, 69.29587841033936, 84.25784572478264, 70.66360888942596, 86.85935774157124, 13.81531338537893, 26.84751968229971, 89.67251300811769, 55.96359706694081, 40.450556355137984, 34.53024848814934, 71.82671716136318, 50.59712786828318, 71.02379229760939, 64.8128132666311, 1.87465833560113, 0.3764797530827984, 0.33473326253794855, 0.21782367940871947, 0.33571342607179, 0.5010357517148218, 0.2975071810426251, 0.25516168634978037, 0.37457446177159587, 0.3217974082837182], [0.10877510067075492, 0.08309192640045959, 0.10220511531036708, 0.11463848483418265, 0.02461721846503356, 0.08954788723419752, 0.03755777075345959, 0.06678492521807071, 0.046566497429364154, 0.08949436833180728, 0.08459126005970663, 0.1025364483376184, 36.61718083966163, 67.51237669298726, 30.53741293568765, 59.889622888257435, 65.93270486400974, 25.381986864151497, 50.61051884005147, 66.1632147142964, 48.25304492827385, 3.464515579323615, 51.656701257151944, 76.10129264093216, 75.53330206101941, 76.00987788169616, 71.6207613483552, 71.62669981679609, 67.23825793112478, 64.24342632293701, 60.15455545917634, 53.986910773861794, 55.424137807661495, 56.32346668551045, 56.654746147894095, 54.932990381794596, 58.88579030190745, 54.12281697796237, 51.87636575391216, 50.367614300020286, 50.64164676973897, 55.004608938770915, 59.709315453806234, 54.55426592980662, 52.69215206946097, 44.85704898834229, 47.789118751402825, 45.26447734525127, 45.88233693953484, 43.13623066871397, 45.69807967832012, 45.66966210642169, 46.90813087647962, 47.905283666426136, 52.14291434134207, 53.1955216007848, 47.95747864630915, 44.02745592978693, 55.94662104883502, 59.25455977839809, 57.29485342579504, 60.21457164518295, 58.20072089472125, 49.12839243488927, 50.62081898412397, 56.64186508424821, 56.847824819626354, 53.89999889558362, 55.12554345592376, 52.74627685546876, 55.258437279732, 53.400481131769, 55.141703621033706, 51.56920494571809, 51.98994974936209, 54.2708589953761, 55.66035078417871, 57.591204181794204, 47.8178422681747, 40.94305307634416, 43.78319424967612, 44.22129946370279, 42.516959021168375, 57.79459476470948, 53.86830222222113, 42.904077345325106, 45.86173665138983, 43.646644776867284, 41.80859857989896, 41.3887127753227, 42.964983909360825, 41.03963751946726, 43.112798429304554, 38.78874617238199, 41.20114503368255, 39.528822898864746, 38.108634641093595, 42.37981334809334, 40.82142429967081, 46.69988047692084, 49.58186549525107, 55.6784172211924, 57.20585484658518, 53.432648489552165, 54.58174997760404, 54.13645505905152, 51.57619460936516, 53.4329269778344, 54.562075368819706, 55.01041012425577, 54.10347577064268, 51.631041111484656, 53.73030931718888, 52.688661160007605, 56.166163952119895, 52.6728069397711, 53.22009132754419, 56.22998091482348, 56.48485652862057, 51.851878396926395, 45.122271814653956, 46.77216583682645, 44.37866887738628, 45.8741391858747, 47.269404703570956, 46.29633526648245, 43.655893725733605, 43.099336854873165, 43.44347776905183, 45.75708781519244, 46.16314726491129, 45.87652006456929, 45.07102997072282, 49.37500753710347, 56.059710825643236, 60.1608390961924, 59.909022931129705, 62.96207035741499, 62.938822469403675, 61.974499917799434, 60.563027166551166, 64.54497029704433, 60.717258684096805, 58.47281571357482, 51.06104620041386, 51.64915069457024, 50.2966703907136, 53.715922063396825, 56.87561088992704, 54.95371226341494, 57.97318027865503, 63.851820807303156, 68.00571672378048, 70.1741990735454, 66.07859350019886, 50.11380557091006, 1.2085989406031947, 36.43952100507675, 68.99298514089277, 37.72936890202184, 22.09611931154805, 24.26197171211243, 41.56609019925518, 36.58644122462119, 47.16686610252627, 53.45801445745653, 1.5185633854519938, 0.09728378946742705, 0.17368299556114983, 0.02714983427957181, 0.06964574267546977, 0.09740074811082694, 0.042895001900051875, 0.0710178597740108, 0.07944542448967695, 0.014782938204946057, 0.013953575248559637, 0.07057202724559654, 0.08043912479714041, 0.14082785936132555, 0.003929322180826397, 0.03934933631230266, 0.038594969533263676, 0.03166229133644412, 0.10735814444600575, 0.029711915750897704, 0.0658896672088773, 0.43482022900735184, 48.70898123710386, 76.43177586217081, 32.91528709473149, 61.728292742083156, 60.52530181023383, 31.88923232017025, 60.763562263980994, 67.26875828158471, 57.98406877825337, 3.5411594279350775, 48.24503152601181, 81.78570916575771, 78.81591796875, 77.20281185642366, 76.02351204041513, 73.46720141749229, 72.06864895359163, 66.89358357460269, 63.31003558251166, 57.70045788057389, 60.26168715569281, 59.245193158426595, 60.68836258303735, 56.802933293004195, 59.239646927002944, 56.16788587262554, 56.03520777917678, 52.59943508332776, 53.308850642173525, 59.943786897966945, 61.48403890671269, 59.41829519887125, 56.42725652264011, 46.456697448607414, 50.582501349910615, 46.744293474381976, 47.47963590006675, 44.82124951577956, 45.76685451692151, 45.94119994871078, 49.84906127375942, 50.76854328955374, 54.20741073546871, 55.434677216314505, 50.33931047685685, 47.50944199100618, 56.86164725211359, 61.45912793374831, 61.0257334862986, 61.08260393142701, 59.854878533271055, 49.842506993201475, 50.499594211578376, 59.578382815084154, 59.57076557220952, 60.064960679700306, 58.391222569250296, 56.63422038478237, 57.631318261546475, 54.82345819473267, 58.04971356545725, 53.49175860804897, 55.958039068406634, 57.37188093123898, 58.096778085154874, 61.12139617243121, 47.91694879531861, 41.90184508600543, 44.258463921085486, 43.64384028219408, 45.88101510078677, 61.88834113459434, 57.45680416783979, 46.19077644040508, 43.70773569230111, 41.781659741555494, 38.50189147457, 37.471916291021536, 41.74625642838017, 39.16286968415783, 41.652209758758545, 43.724833303882235, 42.271681447182935, 35.4968773934149, 35.27443585857269, 41.23139827482162, 41.31872200196789, 49.055091181109034, 52.406866319717906, 57.80910753434705, 59.12344671064808, 56.28860465941891, 54.42036797923427, 56.43739584953555, 52.7571378984759, 55.069892867918945, 55.8910136069021, 59.31861208331201, 57.19972025963568, 54.10250302283995, 55.594364750769834, 53.85842177175707, 56.04061280527423, 55.0006434225267, 56.19850781656081, 57.79729335538803, 58.71552413509738, 55.773448405727265, 47.21889634286204, 49.65650819963025, 49.17717495272237, 49.22541226110151, 50.4446025817625, 48.401459570853945, 47.38537350008565, 46.463185048872425, 48.086516780238, 48.868445196459376, 48.1884591810165, 49.544453928547526, 47.57677731975433, 54.86101096676242, 58.53611100104548, 63.73680122437016, 62.12093768581268, 67.20656518013247, 64.7048500276381, 66.60524229849538, 66.76815402123236, 68.06015137703189, 65.68719979255431, 65.27047149596676, 55.473343941473196, 56.05348602417977, 53.12546414713706, 56.873688928542606, 61.09294329920123, 61.45733541057956, 65.34701262750934, 68.69988995213663, 72.43978361929618, 75.34891143921884, 70.97571188403715, 52.69729821912704, 2.564624576799331, 44.805916970775975, 80.51236660249772, 45.26076286069809, 29.335239818019254, 33.48081442617601, 41.672406042775805, 39.68538430429275, 55.48657017369425, 68.61329186347224, 3.7700096253425848, 0.13676446772390796, 0.05131705078266321, 0.15154228846151985, 0.04589461916757207, 0.033171706712774696, 0.05255342093146136, 0.11697042583217544, 0.07114473159515089, 0.07700056979252447, 0.29209795678334854, 0.2932589477108371, 0.32572262830311255, 0.2250249365404729, 0.1265169079265287, 0.2393445907340896, 0.10026569478213788, 0.10315805207937957, 0.32024831721378916, 0.15086779400946634, 0.18269255727289185, 0.5190006054697499, 56.36190983556933, 84.37019809599846, 42.50948298361994, 76.68804783974925, 77.07630757362612, 37.956183879606186, 69.75421520971483, 78.53584504896595, 59.133535046731275, 5.1967776590777985, 60.06379573575912, 82.28075150520571, 81.09166145324707, 77.00628542130994, 81.78352048320156, 74.73393870938209, 74.98795140174128, 69.8981975740002, 66.89108110243275, 59.67544970973846, 61.46599992629021, 61.43253818635018, 63.75985299387286, 58.46213902196577, 64.65540070687571, 57.67042429216447, 61.27081494177542, 56.70806684801656, 55.164975043266054, 61.66975921200168, 63.700531067386756, 57.97488650967998, 57.25028745589718, 47.68750582971881, 52.505972846861816, 50.535770231677645, 49.13355819640621, 46.813205595939394, 48.253041005903675, 48.46985393954862, 55.509770993263494, 54.000709672128, 56.454054155657374, 59.73089633449432, 53.875162447652514, 49.13067133195939, 60.39252957990093, 64.54971244258266, 64.63045835494995, 65.09975033421671, 64.28105362000005, 50.718544836967226, 55.08073037670505, 59.81135199146887, 62.16380919179609, 60.15881515318348, 62.88397596728418, 57.58921946248701, 63.121938320898245, 58.85654510990266, 60.10920501524403, 56.32438452013078, 59.998252930179724, 60.667609322455625, 62.26165271574452, 62.11145731710619, 49.50662659060571, 41.817933820909076, 47.36637746134112, 45.92833065217542, 48.14924332403368, 53.370518146022675, 47.4923090780935, 45.53925898767287, 46.73857858104091, 43.351192243637584, 41.70085107126544, 39.15103197097778, 42.862080527890114, 41.03497382133238, 42.09813225653864, 43.60465972654281, 43.19173220665225, 37.894104526888945, 37.33189159824003, 45.01948218191824, 43.21534879745976, 50.23412427594585, 54.81328748887586, 60.45475013794438, 65.47840418354158, 59.485708975022845, 58.380028124778505, 58.14017911111155, 56.61161576547931, 57.09455759294572, 58.904370569413715, 59.66337665434807, 59.34439774482482, 56.390037152075, 57.54825030603717, 55.30827099277128, 57.54234713892783, 56.83348463427637, 57.7206463198508, 61.28828517852291, 58.548984219951016, 55.92872327373874, 51.679431392300515, 52.39254966858895, 53.38969069142496, 53.220546322484175, 53.49116633015295, 52.03006382911436, 49.53599337608584, 49.247958044851984, 48.9030836474511, 52.58558519424931, 51.88468117867747, 51.4838816273597, 47.675781865273755, 57.04791668922671, 62.12169862562611, 66.28083090628347, 63.90971499104654, 69.70686435699463, 68.27263401400658, 68.79489760245048, 68.41054454926523, 73.6588405793713, 67.4092968048588, 70.17150832760719, 57.558934842386556, 59.22429084777833, 55.82884796204106, 59.19146453180621, 62.89073421109108, 65.6455873673962, 67.88245231874528, 72.42750660065683, 74.9046951724637, 81.06484028600877, 74.86733851894256, 73.14454724711757, 6.1170206146855515, 44.31916652187225, 87.75169695577314, 53.78094711611348, 32.31528997421265, 38.453626709599654, 65.66694859535464, 52.02098354216545, 63.24492031528104, 80.1356621711485, 4.169482434949567, 0.2567441941749665, 0.28118806801015334, 0.13321539687533535, 0.18641916133703726, 0.2146853236181121, 0.09874057460335955, 0.1776649367304579, 0.1583708591398693, 0.15477101198367535], [0.4283612804307092, 0.2560955475294783, 0.09999433877847849, 0.05960434479939361, 0.03552802079807847, 0.0965951836758083, 0.04832961431313907, 0.1354233082383871, 0.07516995673218081, 0.21866870503271782, 0.01605634487444355, 0.42404841992162895, 51.799871690811656, 61.56897391042402, 36.238354406049176, 45.39736724668934, 69.47669967528313, 24.585830050130046, 40.1709266631834, 61.95903793458016, 67.13946127122449, 5.002403624596135, 17.637488572828232, 86.22887596007317, 72.34854144434776, 76.73837184906006, 69.11626523540866, 72.8635564927132, 67.91276439543694, 64.40254903608754, 55.35867737185571, 57.04378643343526, 56.03585104788504, 59.409905249072665, 55.39649294268701, 55.65311008884061, 51.73871801745508, 51.30747302885979, 50.304040524267386, 52.39705254954677, 56.2143071236149, 60.52327394485474, 61.07488470692789, 61.938669066275324, 59.794156320633434, 50.65765004004202, 45.03521088630923, 47.62701503692135, 49.87317992794899, 47.351613660012525, 44.50795019826582, 45.036987719997285, 44.99045272027293, 44.94803228685933, 50.30546042226976, 51.15546157283168, 49.978228845903956, 47.43585832657353, 49.78725256458406, 57.18916516150198, 57.77924653022521, 53.743982699609575, 51.96163415908814, 49.86114609626032, 50.40918750147666, 60.50095958094443, 59.097288423968905, 58.3987456752408, 57.48417446690222, 53.58037279498193, 54.19020721989294, 53.12188694553991, 52.1075463294983, 53.34203389383132, 54.48360443115235, 55.53145385557606, 55.82023051477248, 60.33118763277608, 50.529372845926595, 44.17854955119472, 46.44564420946183, 44.78868992097917, 52.990844480453006, 55.298398387047556, 46.010331722997854, 44.36824713983844, 41.34479399650328, 47.47281097596692, 46.936803402439246, 42.55936768747146, 46.93929802986884, 39.900753805714274, 40.730080143097915, 45.81222849507486, 46.391389985238355, 43.24890467428392, 33.200670903728856, 33.316306298778905, 48.13298509966943, 59.63729289270217, 59.613629233452585, 53.383371753077355, 55.13485124034267, 54.56480141608946, 53.32960782512542, 50.90686175131029, 54.427137990151685, 55.83100526563583, 54.536156346721036, 52.20504860724173, 51.759671318915586, 50.229166400048044, 53.67381934196719, 53.09877241811445, 54.76872936371834, 49.16409777056787, 52.33629111320742, 52.8377700621082, 55.16277459359939, 50.98357938951062, 47.393614399817686, 45.16698291224819, 46.03519170514999, 45.586731433868415, 44.500003476296705, 43.433762058135, 44.21554534666, 44.18272687542824, 44.17649815159459, 45.48462037117251, 46.30418000682708, 46.392758892428496, 44.4863889294286, 53.063922159133426, 56.797512577426055, 58.096064213783514, 61.83606378493771, 61.44333647143457, 62.477755700388265, 65.70893364567911, 64.33976365673927, 62.93286438911193, 66.8136299810102, 62.41067924807149, 59.79609397149856, 53.56420478513164, 52.86870187328708, 53.464133354925345, 58.74967228981757, 59.75073568282589, 60.113005791941, 65.60666176580614, 71.59085719816147, 67.83304614405479, 67.89476856108635, 32.25158479905898, 1.3379759918297491, 56.52243283487136, 57.69706110800467, 33.843304188020774, 25.33446146595863, 25.084828099896832, 30.806781707271455, 55.88792670157648, 49.66066198964273, 57.232217096513324, 4.274246490770771, 0.3236450897830148, 0.3461772065249182, 0.07326395295920872, 0.01397443869556751, 0.06939304091276662, 0.031573511322119066, 0.06710506570074828, 0.11904532900981366, 0.0781810959620822, 0.3578502414447646, 0.1932473489714246, 0.08079087406757378, 0.06922417215161747, 0.07396496171432157, 0.03808793807101827, 0.14249734880943454, 0.10591799107890938, 0.09146361266292873, 0.30734218717102085, 0.05784938675201228, 1.0016961816337802, 60.544293926608184, 68.79429355744394, 39.804730261525805, 54.65801262086438, 71.5239494077621, 26.311841587866507, 53.79460088668331, 63.672133107339185, 76.76730325145107, 6.893040960834873, 15.842502155611593, 89.99097024240803, 78.54916541807114, 79.18466783338978, 74.00171849035448, 77.3687045804916, 71.50505927301222, 69.32443326519382, 58.00167237558673, 63.03209250973117, 59.27372055668985, 62.78148443468156, 57.677296284706365, 59.14346256563741, 53.45519427330264, 54.33459358830606, 53.87069486802625, 57.936000131791644, 58.87823581695557, 62.575163841247566, 64.52304424778109, 63.98285150527955, 64.75651156517768, 53.732800022248306, 47.31179768039335, 48.952772232794, 51.85585175791095, 48.66131659476988, 49.28303580130301, 46.45026476152482, 47.22978092009022, 45.69638521440568, 54.12880251484533, 52.869651086868785, 52.828862359446866, 49.33935711460729, 52.83533034786102, 59.277211466143214, 60.05939875879596, 58.1400732071169, 55.66819552452334, 52.18023177116148, 50.41593790054322, 61.52021492681196, 62.24701443026143, 60.79368214453421, 59.92647355602634, 57.48209953308106, 54.84788671616585, 57.74821273742184, 51.569765844652736, 55.51465042175786, 56.60377886987502, 55.198546609570904, 57.596766102698545, 61.377083716853974, 53.5435535061744, 43.81949578562091, 46.89645398047663, 45.11103422411027, 52.34750909190024, 54.75491477597145, 45.47588133042859, 39.985402476403024, 39.15194980559811, 47.955631209957986, 46.293228749305975, 42.6209802781382, 46.55211694778935, 39.115173662862475, 40.01043896521292, 42.86843868993944, 45.80210878003029, 44.458359672177224, 32.393968797499134, 33.27029689665764, 49.562677260368105, 58.14093220618464, 60.66500879103138, 55.098812503199426, 54.608822176533366, 56.438525492145175, 54.58855921222318, 54.83333864519673, 54.52368320957307, 58.247436323473536, 56.72941630886447, 53.22857933659708, 52.86153570298226, 51.02983590095274, 54.9738654013603, 54.247818992983916, 57.68217571320073, 50.72894696266421, 53.73827957337903, 54.5810753299344, 56.19093371975807, 49.50976448674356, 51.53387223520587, 50.65141739383821, 50.5195394639046, 45.99575619543753, 44.49617524300852, 47.734582116526944, 49.9607664538968, 46.715216944294596, 52.05159764136038, 51.47153792842742, 50.14429415425947, 50.394325640893754, 48.788848538552564, 54.58422891555294, 60.40082539281538, 58.783228166641734, 64.89795615596157, 63.91750874057893, 65.11303932436051, 67.08029623954528, 65.94420525335497, 66.04701842031172, 68.74522470658826, 67.53436550017327, 67.88846138984927, 57.98617901340608, 57.84229078600484, 56.39444197377851, 62.43370748335316, 65.24925931807488, 65.92177714070966, 70.44656061357068, 76.6432700618621, 72.44835007575251, 71.60357352226012, 33.50482717637093, 2.1574879461719147, 70.15689357634514, 61.80157438401253, 40.18089340579125, 34.66331489624516, 29.68697051848135, 37.47836466758482, 57.84423628161031, 54.89959139977732, 65.42148274760093, 7.94826542177508, 0.3039277332925028, 0.2504688615520155, 0.15351617528546244, 0.053518052032637986, 0.08946672787949925, 0.026459393707374414, 0.019916374641921253, 0.09906718086811805, 0.15208532222576682, 0.6597433984279633, 0.44999428574116, 0.20918654368048717, 0.2070490970847107, 0.24467473939782192, 0.1453413582977749, 0.3356465006307248, 0.2656449714014607, 0.16665369452488038, 0.4556933363839504, 0.2382982678471073, 1.0370996786702065, 76.0890313117735, 76.37118308774888, 54.602138457759736, 55.873104064695305, 81.46495342254639, 37.50418563042918, 58.55541690703362, 75.06213126644012, 79.4349778083063, 7.6255484934776065, 20.989430412169426, 97.60596167656684, 79.19984740595665, 84.20021826221098, 74.85579890589561, 81.88778492712206, 73.4515276262837, 70.1782940280053, 59.44935252589565, 65.66450888110747, 62.543933929935584, 67.01600074768066, 61.991558305678836, 63.03492446099559, 53.58682117154522, 58.50439079346196, 53.741841085495494, 58.39195213010235, 64.00798605334374, 66.8884531144173, 66.8909163628855, 65.88873509437808, 64.00496190594089, 55.99379147252729, 50.35734161253899, 52.873110617360766, 55.24267719637964, 50.58330543579594, 53.239212882134225, 51.03315030374835, 48.65937109916441, 49.57345201123146, 57.25832439238026, 56.01700798157723, 55.90800531448857, 50.3037267346536, 55.327710259345274, 61.43927681830622, 61.96496463591053, 61.550209291519664, 59.34848485454437, 53.61761962213824, 52.326336137710086, 65.6652815880314, 63.352385413262155, 65.48433480724212, 61.95439777066631, 57.14244581037953, 59.71322213449786, 58.22051317461076, 57.05470631199499, 60.98387395181964, 59.17111919772241, 59.72356542464226, 59.81473699692757, 62.80278290471723, 54.58378568772347, 46.296915777267955, 48.04846978956654, 44.48397274940245, 49.08412064275434, 51.08736922664028, 47.29319387866605, 41.231555169628514, 39.14537983555948, 49.233943416226296, 48.73034638743247, 44.40737278230729, 47.027943595763176, 40.67176234337592, 41.832324997071304, 45.97971370143276, 48.822055324431396, 44.016108512878425, 32.29504466056824, 33.81705176445746, 49.96466921221826, 61.87866464737923, 63.73214929334579, 60.76265619647119, 58.69788915880265, 59.82855158467447, 58.874097716423776, 58.15294250365227, 58.80034539007372, 61.383430111792784, 60.89551864131805, 54.86050890338037, 57.21614322354717, 52.17547001377229, 58.21035423586446, 57.35857625161448, 65.3252983862354, 51.91833119238577, 58.12672145905034, 58.45980128934307, 58.423546821840354, 53.30979201101488, 53.1263937488679, 52.871239646788574, 55.173545422092566, 50.60515303765574, 48.52952887935024, 49.068003623716294, 53.65112843052034, 49.56618385930216, 55.46609540139475, 54.44793047443513, 52.803351263846125, 52.29636922959359, 50.66433768118582, 58.922719417079804, 64.79915949606126, 63.85846138000489, 69.88175499823787, 66.09625201071462, 68.97502068550357, 72.08618979300223, 69.28095771420386, 66.79298262442312, 74.93798040574598, 69.46384999059862, 72.51084127733785, 61.88508556735132, 63.01518317191832, 58.541480725811375, 66.8327554579704, 68.6608309899607, 69.80873615511003, 75.30251764482068, 81.79750765523603, 77.54533675409134, 80.69358010445872, 47.479494694740545, 2.747833094289226, 70.82079395171135, 75.33770130526635, 47.956094049638324, 37.78946745780207, 41.17548881038543, 43.772949018786036, 78.42473999146493, 66.84109441695675, 82.72434019273328, 9.787172578996229, 0.4873782426359192, 0.5490802817286984, 0.15956885211410063, 0.200583299682025, 0.32060767373731064, 0.11303841827377198, 0.1482201022126021, 0.2360444218521157, 0.24843204826597245], [0.3430772777045927, 0.2791822966068022, 0.13667011633515358, 0.024567484036989273, 0.11493568098352802, 0.08580518766276299, 0.30110148172224727, 0.37263304175388434, 0.010713749197161487, 0.047013846811868494, 0.0797422222733017, 0.7695839205576528, 53.89256992647725, 51.18694251583469, 37.650164481132265, 26.058295657557828, 34.27985222108903, 32.056409620469616, 21.302070771494222, 53.798786055657175, 73.30889455733761, 20.82080379609139, 5.4486291254720385, 79.45849633985951, 66.23503331215151, 73.57862810934745, 70.10636560378536, 72.11178718074676, 68.08798451577464, 63.87071094205303, 55.14594762556015, 58.08077481485183, 56.58861106441867, 59.93522436388078, 56.41673672583796, 56.97824362785586, 50.71996081259943, 53.76073122024537, 54.57919651462186, 58.434600060985936, 61.285359090374364, 62.742982449070105, 67.44690449007096, 65.39236307144165, 63.74316330878966, 52.07682240393854, 46.922902522548554, 48.21981460817399, 46.65792680555775, 46.3125934908467, 45.873021310375584, 42.9315221694208, 44.167327650131725, 43.79961329121744, 45.31579371421568, 48.9525878813959, 48.826424844803356, 52.18435810458276, 48.83471281297746, 51.22926488999398, 54.82731388461206, 55.01963161653089, 56.4424047162456, 57.92582942593483, 56.923718760090495, 56.34800111093829, 56.87602273879513, 56.78946387383246, 55.68451650681035, 57.85182214552357, 54.36836911785988, 57.31321796294182, 54.17869114106702, 53.8511771540488, 48.355516849025605, 54.165562968100275, 52.91927691428892, 62.80395961576893, 50.35456065208682, 44.6601067819903, 44.41512730813796, 42.42059423077492, 46.88725210005238, 50.09253455746559, 46.72346568876698, 41.48463041551652, 47.18929421517157, 43.6010629130948, 63.75664841744208, 54.62109919517271, 49.095405301740094, 46.31783769976708, 48.71041290221676, 40.43736542424848, 38.0380751240638, 42.77933028436477, 41.01189851760864, 42.80197412736955, 46.710749364668324, 57.21351915790189, 53.63046538445258, 54.094054237488784, 50.059669017791755, 54.47018992516303, 53.3217473953001, 52.15908627356253, 50.66926417812225, 55.872539243390484, 55.87874835537326, 53.772933713851444, 53.22770072567848, 50.797615897270944, 52.96898903385286, 53.07944690027545, 51.80160930079799, 53.22680642527919, 52.887929331871774, 53.199169405045055, 49.31299878704933, 48.20095193001532, 48.532474579349646, 45.8716171018539, 43.46498412470664, 41.148655876036614, 43.111527581368726, 43.68910051161244, 44.02148608238467, 45.481529543476725, 46.57327421249882, 43.563078680346095, 46.20997644239857, 46.760453639491914, 46.58373517374839, 46.96300091282014, 55.442074806459495, 55.866996934337, 61.02679644861529, 56.90282821655274, 62.233364582061775, 57.406342875572946, 56.56433159305204, 65.18812917893933, 62.97823836726528, 64.99364237631521, 63.95197460728308, 55.39969359674762, 52.88919625743743, 52.81300421684019, 55.200233228745006, 59.988784328583755, 65.54677109564504, 65.84285120810232, 72.77363223414268, 61.23316018812118, 72.2518079511581, 13.172549682278788, 3.928848702100016, 57.43180690273162, 41.539104292469645, 29.880800324101603, 29.184371732896377, 33.365065282390965, 21.44420766061352, 27.822838598682036, 40.985504888719134, 58.487265725289625, 6.890411501930607, 0.2802865050973431, 0.2794532159403447, 0.09208200649628717, 0.035358707705933246, 0.06479566300948782, 0.15466775865324084, 0.2060067425331762, 0.18830681730422283, 0.40041911205457104, 0.327930340483304, 0.22622368028087003, 0.07982662217991968, 0.017799214054379734, 0.011309500344307914, 0.028961042332793438, 0.11225032830430616, 0.26287044608785265, 0.01048508727352225, 0.09825259191735138, 0.0394688613502489, 1.218825417660898, 61.65805878177766, 57.23647286815029, 46.911151101512296, 35.42527452591927, 44.48546325006793, 37.29757085923226, 28.80230934389176, 59.731045384560865, 79.06998557429161, 26.019536756700088, 4.65072391494628, 82.6101678417575, 71.70066002876528, 77.59285234635877, 76.95798535500803, 76.76336519179806, 73.3134288172568, 67.70520825539866, 57.700956021585775, 63.327231253347094, 58.060974690221975, 62.517959994654504, 59.43282758035968, 60.895683380865286, 52.39831947511243, 55.698817468458614, 56.1738282634366, 64.75964161657518, 63.82412495151643, 67.74826019041001, 68.70532635719546, 66.20332487167852, 66.33402609056043, 55.478603839874275, 49.196524004782404, 51.45706438249158, 47.63332220815843, 48.870033756379165, 46.53942415791173, 45.589837951044885, 43.80321402703562, 48.54097435551305, 46.53731000038886, 51.00022200615176, 49.02604210761286, 55.92751910609584, 51.23075539065946, 52.952911238516535, 55.844419771625155, 57.99612614416308, 59.76338924900178, 62.152159752384314, 58.30949606433992, 62.58656224896831, 56.79791265918363, 61.16043944512645, 59.13430775365522, 58.815579875823, 57.405915337224165, 57.32388680981052, 54.2126549443891, 53.72521808070522, 52.12608345093266, 58.87792202734179, 60.08799283735214, 67.4097910235005, 51.41438507264661, 44.814334377165764, 43.411788940429695, 40.21234296983288, 44.3176289527647, 44.56785263553743, 44.41928109815044, 41.77983583942537, 47.36998604189965, 42.74435058716805, 61.67778045900407, 54.22634401629048, 48.79921144054782, 46.361705487774266, 52.411216228239, 40.69717537972235, 36.41828529296383, 40.59039277415122, 40.405660906145656, 42.597508815027055, 47.75904986166185, 59.593907556226185, 54.680205391299346, 55.76950250133392, 52.58421628705917, 57.21136577667729, 54.80154391257994, 54.46087429600378, 51.30242886081819, 55.5838567210782, 58.84515062455208, 52.97900284490278, 53.46374896264846, 56.375594985100534, 55.64643029243716, 53.52614602734966, 51.71619969029581, 51.714532682972575, 55.83904220211891, 54.51482649772398, 50.78278541564942, 53.128484372169744, 51.14529478934504, 47.55574949326054, 46.62732839584351, 42.33979732759538, 44.10248302644299, 47.41911372830791, 48.570737300380586, 47.98741417546427, 51.124867085487615, 48.32532244343912, 50.53722543101157, 51.204059739266675, 48.59291045896469, 49.723094355675485, 57.613773499765706, 59.64569460961127, 63.21828742181102, 59.326986343629905, 63.907930312618134, 60.026690113929014, 62.22304482613841, 63.40727898382372, 70.27330167831914, 68.28173391280636, 68.49101589572045, 60.21440690563571, 56.37950951053251, 53.62875915342762, 66.75997195705291, 61.45426811710481, 70.23304247087049, 69.67072363822692, 75.91410144682854, 65.68626234608313, 73.37274289900257, 10.724248386198475, 4.933078673578078, 66.99212135807161, 43.899888684672696, 41.35348989117531, 36.81785322004749, 43.562404032676454, 27.191352690419844, 39.63997110243767, 54.158498779419936, 66.65850808543544, 10.665289278953306, 0.33274256774494726, 0.2810277411293599, 0.06877686107350935, 0.07333165214907739, 0.044576480624175845, 0.08308219708382122, 0.3016484685001835, 0.17018968059170633, 0.42257802140328193, 0.44040945328531733, 0.545181752212586, 0.23684415635803055, 0.10498020752903917, 0.33596133212408713, 0.1814387164889805, 0.4634827651804494, 0.37710926285193813, 0.0831134764537696, 0.26504625836687706, 0.15276986775138687, 2.3515435332252137, 74.19223585436421, 65.58985833198794, 56.39886640733289, 37.36372555455854, 50.895737909501605, 43.43290305906727, 33.03355440016716, 71.17830230343726, 85.31447733602216, 24.398689846838675, 7.610811658443944, 84.19730786354312, 73.93573637931578, 82.90932701480004, 78.66333776904692, 81.12357385696905, 75.83377915043985, 71.16671562194824, 60.894526281664454, 62.79371046250867, 64.36069734634893, 67.3330145497476, 64.30427405142015, 64.49727427574896, 53.887015850313254, 60.70355392271473, 55.89291595643567, 66.18165769884664, 65.47778837142452, 69.65024102118709, 73.82087369118968, 68.52263804404967, 66.6893143807688, 58.670605151884025, 52.15739180964809, 53.29866032446585, 50.403896224114206, 52.840378438272786, 48.33455570282475, 47.65394603052447, 46.0064721107483, 51.2914187677445, 52.266488613620886, 55.602852759822724, 52.668927715670684, 56.09570249434441, 53.46309392682968, 56.81934841217534, 59.506999600318174, 60.72928074867495, 63.62865363397906, 67.73216278322282, 61.17969043793217, 64.59734570595526, 59.94283376201507, 62.484792432477406, 60.065996185425796, 62.10238879726779, 59.994652194361535, 60.4071560982735, 58.85888676489554, 56.58433568093085, 54.29848032612955, 62.53682659518335, 62.03437882085001, 67.59783729430168, 55.014077540366884, 44.62672348945372, 45.04787229722546, 41.28423652341289, 44.66996369823333, 44.86659603734171, 46.30689036461615, 41.02188487206736, 50.91168626662224, 42.64426738985124, 62.374514995082734, 61.84356727907735, 52.233332818554295, 48.833987174495576, 55.017744956478, 40.51619329760152, 38.91004546996086, 42.78087569821266, 43.200094699859626, 44.9758065900495, 50.06230092817738, 63.11397590944844, 58.55870777560819, 61.79873851037795, 55.437081629230136, 59.534805282469726, 58.206792723747995, 56.49625885871149, 52.84188855078913, 56.42865680879163, 59.58662763718636, 55.49731354559622, 54.37221304062874, 58.46329219879643, 61.566589109359256, 57.86997487468105, 52.79133704400832, 51.84670086829893, 55.70406952211934, 56.01579596919399, 50.08352095080961, 55.70153567098803, 52.90405419565017, 49.68675751839915, 50.091173495015795, 44.207994784078295, 46.3740844880381, 49.17511178601173, 53.218745954575084, 50.721537605408706, 54.78696446264944, 51.055480357139345, 53.58558954731111, 57.307467768269206, 50.781498878232895, 51.878444610103486, 63.26035876427928, 64.12249180578416, 68.78382082908385, 63.029087974179184, 66.90282467872866, 58.37512123969294, 63.25433792606477, 66.89957695622599, 73.02975516165458, 74.46058873207339, 72.50957042940202, 61.435001434818396, 61.7171649779043, 54.0903672095268, 70.77831468274518, 65.29754369489609, 71.88910638132404, 76.18622764464348, 80.30820723502868, 71.78858387854793, 87.8753928215273, 18.788629693369714, 4.953708869795646, 74.33658692144579, 54.22297862268264, 45.5140773711666, 38.338014848770634, 51.05133441186721, 31.668461715021444, 43.086342042492284, 60.47866090651482, 80.7850262426561, 12.645962661312474, 0.5144563557640199, 0.44114980065534193, 0.26838508404551015, 0.14351520386915054, 0.1689989348092387, 0.2362338294305148, 0.6448045000433922, 0.25464358108658947, 0.4862069861302453], [0.13682754740359324, 0.044274661134207444, 0.10926484535898894, 0.09490509412341541, 0.020777172101060712, 0.10810338711786656, 0.02295109022769236, 0.06920791576586424, 0.07747860099639624, 0.046946741340141145, 0.08452419672281512, 1.6802481417694402, 52.68641756426904, 48.23071487488286, 42.304754872475904, 33.46697630420808, 35.44169356746059, 33.12548298989573, 21.15334430048543, 38.47640391319029, 65.12320218547698, 48.53602040198542, 4.22270066315128, 52.48509407043458, 75.94317405454575, 67.78537365698045, 73.88789915269422, 64.54563709997362, 68.35750625979516, 56.663571480781805, 57.92036164191462, 57.97897754176971, 59.05589957391063, 54.59328174591065, 55.50920617195868, 52.89717435836793, 54.21458475051388, 55.205195027012984, 58.094079494476325, 61.368580018320394, 62.849863113895545, 61.70975954301896, 64.46187880731398, 62.75814633215628, 62.709485407798525, 57.219736114625015, 48.05254905454574, 45.33495057013727, 48.33199439510223, 47.1837362166374, 47.09192922038417, 47.0459198182629, 48.373787249288256, 42.377279496962025, 45.09503095380722, 45.14445674034857, 48.0679992706545, 48.19171474825952, 53.58209863785775, 52.97253093411846, 56.26742386048841, 53.286548045373735, 54.76667011937788, 55.48923346304125, 55.65584398085072, 58.807401734013716, 56.19616223919777, 54.18860689286263, 57.18259519146335, 57.6458231864437, 55.71087483436831, 55.12756347656251, 54.19781661802723, 50.91165488766086, 50.06524270580661, 53.776212815315496, 55.24034338612711, 56.93310891428302, 48.81273969527214, 45.1845355187693, 43.61348505943052, 40.62503514751312, 44.32046090402911, 40.87651006637081, 46.8256159751646, 47.29343314324656, 49.860334165634654, 42.853361098997055, 44.58920209638534, 56.35919555541008, 51.681800503884595, 45.0082955821868, 38.77669272884246, 42.45993560360324, 40.482233416649606, 39.55818968434488, 37.22506192422683, 35.372228391708866, 50.85388229739282, 57.675884231444336, 56.05503143802766, 50.285711288452156, 48.55469872874599, 49.735594949414654, 51.640768589512, 53.05560673436811, 51.297961281191924, 52.17120247502481, 53.723013708668375, 53.45862242483324, 53.358594140698834, 53.17172850331953, 53.70929325780561, 55.41663823589202, 54.04940982018748, 56.76488237996256, 56.00913186227122, 56.54758307241625, 56.13527136464273, 49.79826265765775, 47.48412309154388, 43.32195881874331, 46.32855753744803, 43.035739544899236, 44.27125869258758, 44.57583465883809, 45.62488040616436, 45.673925722799, 46.36108967565721, 44.683311523929724, 44.95861091921407, 45.8816622918652, 47.265752976940526, 46.65201579370807, 49.78728394354544, 58.076503353734175, 58.946033985384055, 59.41704788515645, 62.69814191326019, 64.85897956355926, 64.85430017594369, 54.46484765698833, 65.61441236926665, 65.28024604243618, 65.04278575220417, 60.616767560282064, 53.910495158164736, 51.34325288957166, 58.57723312993204, 59.485995308045425, 68.57879069543654, 67.76445957922166, 76.05460859114125, 66.67656667770879, 59.44295121777443, 2.2954580524275383, 12.597883228332767, 53.899139896515884, 53.167527644864975, 24.620276304983324, 23.60072482016779, 22.902966545474147, 35.65160312960225, 39.666651064349765, 33.75351329003611, 57.83841548427459, 10.724913227942682, 0.1081426797675029, 0.04140761155154436, 0.08440546841631014, 0.13849369670835235, 0.026381011421401656, 0.13896461095540755, 0.03802790742127165, 0.035640566775034514, 0.18204732737954588, 0.22904444666158771, 0.047475587156030445, 0.031773724570690144, 0.11750107961556605, 0.02909376706567503, 0.1648906197759413, 0.023141949542707974, 0.14622861068815957, 0.039408428504342036, 0.1444767055011565, 0.0962850789449388, 2.6602796633397383, 61.446325317505874, 53.696149395358184, 49.15044007762786, 45.847596506918634, 42.08743203070856, 37.18457129693801, 24.355832069150864, 44.680675691173924, 70.05772821364864, 57.21049108812886, 4.733888949117353, 50.43218043542678, 77.64949137164702, 68.9104663172076, 75.77477101356753, 67.63679427485313, 72.89814395289268, 58.53191798733127, 61.2079668045044, 60.456401455786924, 60.81168582362514, 57.4684496848814, 58.32274975315217, 57.005727675653276, 57.73568860946163, 58.541676844319994, 60.98303064223259, 62.42751798322124, 64.35400578283495, 63.226430262288744, 67.81565435471074, 62.5601254740069, 65.17954703300231, 58.525116597452474, 49.98162561847318, 46.391586103746974, 48.628286315548806, 49.75785440014255, 48.971513317477324, 48.95041488832044, 51.02031630854453, 46.14119768142701, 45.66133491454586, 47.69827273584182, 51.574115753173835, 50.14277619700278, 56.30295268950924, 57.38502871605658, 57.280046478394546, 55.82786736949798, 59.24359675376647, 59.83131685564595, 62.034131711529156, 62.333683121588926, 60.01293043936453, 58.04880357557728, 60.42403797949515, 59.09617839321014, 56.6949269079393, 58.819223757713075, 57.83155133647304, 56.040459832837506, 53.25722832833567, 56.60330426308417, 58.41079127403998, 60.36338244715045, 51.9029123552384, 46.4000270443578, 42.80260955133746, 40.56450905338411, 43.70047146274198, 41.15972480466289, 44.63698048745432, 44.85440531084615, 48.6483492389802, 41.87718906710225, 44.04374945548273, 58.53034511689217, 52.56864839984525, 46.8845142856721, 36.00867609823904, 41.38527677905175, 38.89432853268039, 40.954110237859915, 35.50590668955157, 34.55724616204539, 51.06235627205142, 60.254371935321444, 57.87038280117897, 52.54886788706626, 49.43944423429428, 53.99558313431279, 54.97628942612679, 55.21252985923521, 53.30829366560906, 54.07841966998193, 54.72500278103737, 54.55743912727603, 54.28994132626442, 53.36015132165725, 56.42662894341254, 57.00825368204425, 53.08034512304491, 53.388098209134995, 56.92645657447077, 57.19799049438969, 57.60332822799683, 54.850483325219926, 49.275140070146136, 44.35309502386278, 47.60913295130576, 46.49157516417965, 47.077847911465554, 47.6556993299915, 47.55793425344652, 49.45446298968408, 49.15005568535098, 48.09952728209957, 47.97977732073876, 50.230339188729566, 51.19417536643244, 50.097982729634936, 52.43851984700849, 58.6511972642714, 62.58875877626481, 63.12716291796777, 63.35198533150458, 67.86861419677734, 69.22796649317588, 54.62926949224165, 68.56268544350901, 68.479829295989, 67.51690310816612, 66.08677556437831, 55.63237644010975, 56.48903777522426, 62.25310587113904, 62.521329310632524, 71.04414939880371, 70.10523596117574, 77.59151089575984, 73.56307198924404, 59.83344278027935, 0.7417998727290862, 19.812842915135047, 59.59212287779778, 57.63955916127851, 35.700609222535164, 29.81738736552577, 30.564630262313354, 39.29902691994944, 43.216984425821614, 44.75141955960182, 67.88024794670844, 20.484095773389264, 0.1073152894875215, 0.007246833138783733, 0.07688252330427209, 0.032683873413911754, 0.06351037431628474, 0.07721115970202992, 0.05009993242340223, 0.011775775928981604, 0.17924715344223285, 0.43521029033487846, 0.16678982834902503, 0.15905917381807683, 0.16827867426458867, 0.14213765520722638, 0.28000323642646113, 0.1480272932038192, 0.1879909745748005, 0.12199482114444818, 0.2880541463532756, 0.25555392336701194, 4.162391279974292, 75.10114316017398, 64.63207044909078, 57.17560160544611, 48.15295388621669, 50.03810774895453, 45.8313500496649, 34.76834027997909, 52.102047166516705, 80.45654343020531, 55.694522473119925, 6.550404275617292, 58.23878749724358, 79.3344396160495, 70.34461036805185, 76.25961519056752, 71.6816286886892, 74.38851910252725, 63.21512599145213, 63.627061151689105, 62.62304421394103, 63.55781955103721, 61.60666396540981, 60.89400460643154, 59.461700147198094, 60.752328595807484, 59.85904409039406, 61.808089440868756, 63.637828057812115, 66.90142831494732, 67.04639127177578, 71.75695388547837, 65.63520485355009, 66.13360866423577, 60.01316970394504, 52.24624918353174, 48.83269671470889, 51.277529654964326, 52.12013321538126, 50.65981126600697, 51.436715126037605, 54.1157998577241, 48.7894251269679, 47.246050911564986, 48.66254429663382, 54.75923330553117, 50.44569692304058, 58.94748526234781, 59.32684121593353, 60.13648509979249, 60.052005091021144, 61.20043193140338, 59.07336588828795, 64.56932821581441, 65.97686290740967, 62.994390687634876, 62.6717169054093, 66.75912472509569, 63.1945296256773, 57.502256593396595, 58.54072370836812, 61.27671810888476, 58.443068458187966, 58.4684814945344, 61.02723183170442, 62.981238980447095, 64.39716754421111, 53.69947948763448, 47.98627276574412, 43.18486413648052, 40.421605340896114, 43.63971002640263, 40.128914156267726, 46.0914816394929, 47.072835122385335, 50.052326340829175, 43.398758826717255, 45.17245069626839, 60.289614431319706, 56.11992705252863, 46.4354185904226, 35.96809917880643, 42.73247365028628, 41.80133435033983, 41.276211354040335, 36.43957591825916, 36.357323815745694, 53.31280439130722, 61.281091551626886, 62.04199214135448, 56.0164745392338, 54.91401395490093, 58.9136665867221, 58.19075807448357, 58.82533481044155, 53.87133813673451, 56.49104210638232, 57.80231398920859, 58.21534349072365, 56.327530261008974, 53.650920544901204, 57.537114697117964, 60.421900287751235, 54.69253340075093, 55.65569493078417, 58.69377459249189, 58.51859369585591, 57.75331181864585, 53.48602018048687, 51.82304113141952, 47.96435456122122, 50.691127469462735, 49.13848077097247, 49.53281233387609, 50.839667627888346, 51.57172310736872, 51.7793498500701, 54.54591912607993, 52.26125617181101, 49.01377685608403, 51.82996019240349, 55.76571741411763, 55.46358508448447, 57.138978435147195, 62.92245049630443, 68.7424555132466, 67.55286339790591, 66.25449611294654, 69.47942964492306, 66.93678455968058, 58.24916216634936, 72.60336998970278, 71.3164246466852, 71.90393294057539, 67.19277412660661, 56.611866797170336, 59.675131997754505, 66.48655922182145, 67.01574187124929, 77.11116175497733, 75.85017465776014, 84.0378870502595, 78.48753713792371, 75.32438093616118, 3.73901873346298, 16.870880934499926, 68.95285144928964, 69.22340869903564, 44.219726593263694, 32.75425614849214, 35.964874990524784, 49.47691855892059, 56.68076322924707, 48.954717728399466, 85.1851724809216, 24.122509879450647, 0.291755699342297, 0.08502000882740944, 0.1514597041832824, 0.17003497679627713, 0.15554805496527305, 0.2081400062888861, 0.18046851209815473, 0.12426857776459187, 0.4293297074975506], [0.06685568109875725, 0.09637982103853457, 0.04540828740104072, 0.22911296556553534, 0.09085657225260813, 0.031204848745537382, 0.026673674245455095, 0.19231564815967314, 0.13279240908882312, 0.0504692902247752, 0.2798571894245763, 2.1362321319118625, 43.611253230802475, 58.4244607340905, 33.85796600772489, 29.678880630000947, 55.019019726784, 31.19965218728589, 32.498221474309126, 30.50282939787834, 55.58957161441926, 64.65929562045683, 8.28563142207361, 25.626195592264978, 87.7278018766834, 62.00395691779352, 80.16558201082292, 62.917308269008515, 69.89840153724917, 48.66700403151974, 60.13288044160413, 53.344971749090384, 60.124780747198294, 52.41347551345826, 58.84155773347425, 55.44409874946841, 61.29496889729654, 54.58585669917446, 64.41912497243574, 60.99332294156475, 66.20177945783063, 61.2962789689341, 65.58685771880612, 60.51686479199318, 65.02748850853213, 51.853200235674464, 48.970834747437515, 47.355359523527085, 46.795358811655355, 44.95056613799065, 51.25548201222574, 47.46382090353197, 47.36291793084914, 43.94470568626158, 43.15801551265102, 42.14644801232123, 46.09532948463194, 43.73359587884719, 53.550084252511304, 57.03714586073353, 55.658420978053925, 56.44566420585879, 57.03767145833662, 54.975210774329405, 55.575553063423406, 53.64264042146745, 54.647014294901204, 53.53151182974539, 57.14378333860829, 54.821085160778416, 55.32591773617653, 56.465374115974676, 55.60722620256486, 54.93721477447018, 52.39143179308984, 51.28577447706654, 51.007431322528475, 53.93221724417902, 43.57241784372638, 36.80681959275277, 40.427665402812345, 41.290171069483605, 43.09526543463431, 43.871631929951334, 43.32390823671895, 43.215270350056315, 43.147205460456114, 42.89136494359663, 43.71707485568139, 46.39750888270717, 47.65449123997843, 40.68982093564926, 41.43280413842971, 38.901341730548495, 41.17323344753635, 40.066662219262895, 39.57976272029262, 40.42998744595436, 46.45634835766208, 58.083567542414514, 53.731929256070046, 56.67418541446809, 50.20394948221023, 49.88118940784086, 50.5293296998547, 49.82500929986277, 48.91488213692942, 50.72689556306409, 53.727034138095, 53.33917056360553, 51.506031251722774, 54.05339887065273, 55.16922689253285, 55.773640601865715, 54.16876754453106, 55.44996661524619, 55.974226690107784, 56.35175089682303, 56.24010062986805, 51.76206788709087, 44.786803260926284, 46.00210651274651, 41.956264049776145, 45.06154567964616, 47.31151526974094, 44.93186427700905, 46.24023360590781, 46.73119668037661, 46.181299994068766, 47.007245248363866, 44.25501615770402, 45.09697252704252, 45.93196276695498, 46.89424176369944, 47.64349291401525, 53.61385022440265, 56.70161062671293, 60.73528981977894, 59.88818730077436, 62.8969943138861, 66.20672948898809, 54.642374130987356, 58.27998415116341, 69.0931938540551, 62.997732547021684, 67.02629304701283, 53.55388502920828, 52.77695371258644, 54.61562356641216, 65.78751833208146, 65.44906093228248, 72.94090563251127, 69.21123366202079, 78.67934103934996, 26.15140684189335, 0.6153756920849124, 31.807643098215905, 62.45932448294855, 41.42688135946951, 20.830484205676665, 41.04606628417969, 31.130434120855025, 40.430548344889, 35.46021892178443, 40.69935621753816, 58.772422036817005, 26.425447156352384, 0.2661601195652639, 0.1841134971548473, 0.1029939943503949, 0.07357273235796921, 0.017649738809033748, 0.06581781582245905, 0.03975814381133645, 0.11635325773949586, 0.05500012956139061, 0.02552773694567863, 0.04956926331825314, 0.08903728963266458, 0.10439924475166107, 0.06538672282570793, 0.07582384341907117, 0.03504884812319952, 0.023484907954210238, 0.1106618986194653, 0.33645567333986687, 0.2409331353321191, 3.496943529575102, 55.75355806658345, 66.13993152495354, 39.772637428775916, 35.749062261273785, 57.25181718026438, 36.895068999259706, 41.39386676972912, 39.738140183110396, 59.7830520906756, 72.31628387205063, 9.764993536856867, 24.106000623395367, 89.06260798054358, 65.37027228263118, 83.13323943845688, 66.62914522232549, 72.44687526456772, 54.48314159147201, 64.25089843811529, 55.3280750397713, 61.551546819748424, 53.93749283206079, 60.59353928412161, 56.251044042648815, 63.39969311991046, 57.939106648968114, 67.0662384648477, 62.77627160472255, 68.31836885021579, 63.22217449065178, 67.33077095400903, 64.25491494517173, 66.36179647138043, 54.624139032056256, 50.354941121993534, 49.79394020572786, 51.47021216730918, 47.23640188094109, 51.26056148159889, 49.19364106270575, 48.799917467178844, 45.110830260861306, 45.79176941225606, 44.345666054756414, 47.73946546739148, 47.97774553298951, 56.627434684384255, 58.446382860983576, 57.622135992973085, 60.51947709052794, 58.44987377043694, 56.541946626478634, 61.10406714100992, 58.968960239041245, 57.46363301430979, 56.54393919052617, 62.14836289805751, 56.96843770242507, 58.566132822344386, 59.037993954074004, 60.17231202894642, 56.639288087044996, 55.37524546346357, 57.199092680408114, 58.160065527885195, 55.51536037075905, 43.63324596035866, 34.56952710305491, 40.89270161044213, 40.87863206863403, 40.80225959900887, 40.60804343992665, 43.39274191087292, 41.64742054477815, 43.52006989140665, 42.737855142162694, 44.807074069976814, 46.883353264101096, 48.790578303798554, 40.79901187650619, 42.578787342194595, 40.67286452939434, 39.62693706635506, 37.8806939432698, 38.477051104268725, 39.49373337530321, 47.17209069959579, 59.550322178871404, 56.11133313948109, 59.959794090640166, 55.247356583995206, 51.8059435198384, 53.13881589520363, 53.370678963199744, 51.418821273311494, 52.51659462528845, 55.867742184669744, 54.664323714471635, 52.81700111204579, 52.97815953531573, 56.80267049420265, 56.66049634256671, 58.28615011707429, 57.61987278538366, 57.31739528717534, 56.594588756561286, 55.05134397937406, 50.84585320565009, 45.42696937437981, 48.20974980631183, 46.194796869831706, 49.86924186829598, 50.39812641759073, 47.28036380583241, 49.505551861178496, 48.655919413412775, 48.97235662706437, 49.258799476008264, 50.990518062345444, 49.517267980883204, 51.52561564599314, 48.48481778175601, 46.683696777589866, 55.92922141475063, 62.574238161886896, 64.87025637780467, 63.616184419201275, 65.79589651476952, 63.755942390811065, 54.57696076362364, 61.938559239910504, 72.59335225628269, 66.99715768137287, 71.4137621848814, 58.73542231898154, 58.34997492451822, 58.86628043267035, 67.65063239682105, 70.23433685302734, 78.85158800309705, 71.86121048465853, 78.52039875522738, 21.839035403343942, 0.6551837656767138, 40.48374352916595, 65.32250173630254, 49.14288559267598, 32.860897548737064, 49.38996353457051, 44.41626479548793, 43.193787528622536, 36.91169592642015, 47.61595395303542, 69.82957963020571, 36.70451241154825, 0.29730744659900665, 0.07950295003191118, 0.03384419018402696, 0.07195337570362514, 0.04461214967793034, 0.1447208424008662, 0.042971924788528876, 0.21025027208510907, 0.039412979066612265, 0.12701333290146244, 0.1834061988178761, 0.20686197244832594, 0.2671156763549774, 0.31817044161500474, 0.17508038590031286, 0.18923743027112178, 0.4483953376691188, 0.20875557325780394, 0.45942262175583076, 0.5476329884221477, 4.527358018582867, 66.80601273813556, 76.2209798443702, 48.073651406072806, 41.182494163513184, 72.15124622468026, 42.641953191449566, 47.94788845123784, 45.40145043403872, 67.2865266184653, 74.95894939668717, 10.027684473222303, 31.11805904296137, 90.85019680761522, 68.02397143456244, 85.18234052965718, 68.24441648298695, 77.75188876736549, 54.73913900313839, 66.34749550973216, 57.77750107549853, 65.42413426983741, 56.10663021764448, 61.99737125827421, 57.45777299327236, 63.489005488734094, 57.89071244578208, 68.1535194766137, 64.90003893452307, 68.90333544823432, 63.459944648127404, 71.73151339254072, 66.11957442375922, 71.38385803468766, 58.331229917464725, 51.44042961059078, 48.892359887399984, 52.7516975710469, 49.88300546523064, 55.91178647933468, 52.63009232859458, 52.739381328705825, 44.43891256086288, 46.92218080643685, 46.646453872803725, 49.40880660087832, 50.81036752270114, 61.03252703143705, 60.48817657655286, 59.88317843406432, 63.80571334592758, 63.157396547255985, 61.06787935380013, 64.597271180922, 59.40688110166981, 63.07325778468963, 60.72488377171179, 65.3240667620013, 60.07636300979122, 60.88546168419623, 62.80779569379745, 64.03744305333784, 60.561670026471546, 60.045654773712165, 61.70879463995657, 60.58967574950188, 57.290444681721354, 46.84246647742487, 35.75933887112525, 40.686137830057454, 40.67606910582512, 43.5472087706289, 41.25580718440395, 43.14029816658267, 43.012723076728086, 46.98764124224263, 43.690924413742565, 46.14235478062784, 49.02519487565564, 50.635606319673606, 42.12426308662661, 46.06571951220113, 39.953862697847434, 41.22083140957741, 37.99535659051711, 38.34456128458823, 39.45464303416591, 47.04023238151304, 62.443988015574796, 58.84797080870598, 64.10728869899627, 59.135582523961226, 54.96105886274769, 58.74274538409326, 55.08031852783696, 52.423446178436286, 55.92549516308693, 59.34348775494484, 56.90769195556641, 52.4285727162515, 55.94728000702397, 60.24400511095601, 60.07391152843353, 58.73955257477299, 59.578202386056226, 60.260541823602495, 56.818446267035704, 55.055419321983095, 53.660369534646314, 47.62025679311445, 50.89384340470838, 49.536577809241514, 54.335142720130186, 54.547527297850586, 51.40944680859966, 53.60400507527014, 51.20759379479193, 50.768896302869244, 51.7726190628544, 52.48225819679999, 51.19762705218408, 53.9887385983621, 54.36214039402624, 52.02962060128489, 58.61699811873898, 65.3953872188445, 70.25594911267682, 67.7826201531195, 68.37564329947195, 66.64689002498504, 55.17261189799155, 64.17438868553408, 77.13883799891319, 73.07206184633317, 76.45665937854399, 60.20747215517106, 61.764143205458126, 62.34157100800545, 75.43801200005316, 72.70228432070824, 82.28039064714986, 80.67487824347712, 86.31125357843216, 34.171292781829834, 0.7919097451433059, 40.55711930797946, 79.33316092337333, 58.57254197520595, 35.19031278548702, 53.025341726118526, 48.13973549873599, 52.52816953966695, 52.747496712592344, 54.1876616016511, 80.82854101734777, 43.5893742499813, 0.3943525537127449, 0.2410288503573787, 0.1761551919363199, 0.17564566685788094, 0.15650992431948263, 0.19339728769996475, 0.1554984890765721, 0.28838338029961436, 0.1573654606698021], [0.03378928083205416, 0.15962005743095953, 0.17582678536493934, 0.04484846481993314, 0.0695130945513806, 0.01931896012636923, 0.08842294840442558, 0.06923203987459983, 0.1359190590559475, 0.21352151348706216, 0.3521985656792118, 4.627981032094648, 55.31276210661858, 54.97608546287783, 42.82626928821687, 36.378269272465865, 38.40819389589372, 32.44888001872648, 16.458531964209772, 25.115818746628303, 53.729379715458045, 61.1157165804217, 17.88130702510957, 7.425109494116999, 86.45792668865573, 64.91932915103051, 78.81685933759137, 62.80194743987053, 68.13429986276935, 51.800267850199056, 63.08227923608596, 53.47626916823849, 59.00252788297592, 53.1046167496712, 61.83181193567092, 57.52501418513637, 61.71856918642598, 61.77244294074274, 66.0606918027324, 62.54951546269079, 68.1057999210973, 63.06728009254702, 64.39424537843274, 61.170343429811545, 61.82598329359486, 50.30039272000713, 49.42236623456402, 45.915665318889005, 47.6366562228049, 47.01447025422127, 50.239807790325536, 48.87254407328945, 51.40791316186228, 47.07434131253151, 47.28497651315505, 43.944407586128484, 44.474865005862334, 43.58388293174006, 52.81444764906361, 52.89012978153845, 54.452398054061405, 56.232181364490145, 57.84188285950692, 53.98144298984159, 53.64206383305212, 56.69008670314666, 56.54214666735742, 55.20197083873134, 53.53417119672222, 54.440152414383434, 54.133387765576764, 55.569975453038374, 53.740232913724846, 52.556712627410896, 53.76066453995244, 55.88010941782306, 55.48743701750233, 48.97074453292355, 41.190001580023, 35.28494388826432, 37.56977942682082, 40.010874348302046, 43.49356643615231, 44.12946893322853, 47.27826533779022, 45.07409726419757, 45.969464548172496, 42.63711298665693, 41.57475079259565, 41.545556591403106, 40.31002959897442, 36.8752767193702, 38.04866552352905, 36.764748250284505, 35.845046581760535, 37.92943331503099, 40.32977481042185, 37.725936828121064, 41.508086189146965, 54.974226259416156, 58.18656506076936, 53.98536536001391, 52.59754842327487, 52.10405149767476, 51.43993539194907, 53.586432856898156, 49.94218226402037, 51.49923378421415, 51.695760219327866, 53.59221835290232, 52.86042959459367, 52.94753366901029, 54.60234634337887, 54.156776858914284, 55.90561266868345, 57.874065906770774, 55.658064042368245, 56.816500771430235, 55.84398438853603, 49.86385645404939, 46.32261514663697, 45.286007235127116, 47.29116993565714, 50.79727072869578, 48.48522178588375, 50.29466605955555, 46.886408790465325, 47.42959822377851, 46.0024477589515, 47.57921311163133, 46.14692434187859, 45.25235329904864, 45.03667000801333, 48.566920834202925, 49.01576549776139, 51.73014371625839, 54.263335889385594, 59.80293458507907, 61.1482330291502, 63.64983835527974, 60.84793244638751, 58.94186058352071, 54.929821106695364, 67.39751400486116, 60.33281149402742, 66.82318487474996, 60.387885493616906, 53.95251158745059, 54.6667242050171, 66.38394217337331, 66.17407183493337, 75.1332595271449, 71.15234405763688, 72.36760416338521, 5.418251349079994, 4.038506405007455, 47.60010757753926, 62.81697404000067, 28.233677456455847, 26.4711663030809, 26.16601178722997, 26.990303762497444, 44.1236638253735, 46.71230654562674, 48.91122256555865, 47.028802594830914, 42.80695945985856, 0.9411799547172363, 0.11365713386405861, 0.03970026203821744, 0.07988529685404032, 0.04613347772148348, 0.1491972933252973, 0.11995664422189999, 0.23350594354973686, 0.1253101279238059, 0.029262007634726264, 0.13887753740193384, 0.12399637140333654, 0.06656818362253328, 0.12245170066073058, 0.12216287019151835, 0.05128374894059474, 0.1960294432337246, 0.09651364893802712, 0.33905154694953277, 0.45382205937658593, 7.513541781133221, 64.88184698166387, 59.716497313591745, 45.633693971941554, 33.75340738604146, 46.275986010028475, 37.978686517284764, 22.605072336812174, 29.569058187546272, 59.22527928506175, 64.40384341824439, 19.659076198454827, 6.345715878471252, 89.24688877597933, 66.56559498079362, 82.14981494411346, 67.23993670555853, 70.71764346091979, 53.062643466457246, 64.52825315536992, 55.450190190346014, 61.80599881756691, 52.84720336237262, 63.517917279274236, 59.151326917832904, 63.79902570478378, 64.6575854670617, 66.81246895943919, 64.44794262609174, 68.79533690790977, 62.803759574890144, 67.58361478005686, 61.036280739691954, 63.925792786382864, 52.89794706529187, 52.736137528573316, 48.6637366971662, 50.17335499486616, 49.03840149602583, 53.258805121144945, 51.38952901286464, 53.34150045148788, 49.93860898479339, 49.150491068440104, 46.98505640029908, 47.956094049638324, 45.97574818518854, 58.276375570604884, 56.52499806496405, 56.166450285142474, 58.94098197260211, 60.102125137083, 57.01966777924569, 58.99999403184461, 59.185663346321356, 57.04681058083811, 57.27989350595782, 58.19102871802546, 55.97861974470077, 57.73451189840994, 57.33819169382895, 58.53889980623799, 55.02323235234907, 58.81452868061682, 57.11031375392791, 57.41508976105721, 50.07513492338119, 41.82668070639334, 34.95075794958299, 35.41557058211296, 39.17142829587383, 40.814693512455115, 44.53086860718266, 47.40138069275887, 44.359033492303666, 43.27393331835347, 41.50015515665854, 42.21892164599511, 44.02417682832287, 43.30270782593758, 39.97662421195738, 38.69195776600992, 40.719046515803186, 38.31061709311701, 38.48701000213623, 38.302246755169286, 36.58594700597948, 42.78571198063512, 55.703222290162124, 57.69110302771292, 55.26439143765358, 55.28377186867499, 54.17391761656731, 53.6421932712678, 53.256024160692775, 53.50267064186835, 54.05083364056003, 52.81099596331197, 55.07602353249827, 54.16379005678239, 53.020921214934326, 54.24558324198569, 56.23443280496905, 58.32842542279152, 59.68204321399812, 58.39933010839648, 59.63103671227733, 56.12370821737475, 51.25161063286566, 50.316949044504476, 46.81314283801664, 49.900110921552105, 53.660118502955285, 50.253532163558475, 53.13977687589584, 50.62722029224519, 49.647192570471, 50.099857622577304, 51.70688798350673, 50.31248146487821, 49.71778738883234, 47.77837930187103, 52.46323077909408, 53.542647438664595, 55.96963751700617, 53.643177786181056, 63.774605028090946, 65.06092279188096, 70.53767727267358, 65.61687169536468, 62.60223996254706, 57.26225068492275, 70.11788168261128, 65.21154572886806, 69.29470169928767, 63.27180816281227, 57.097256183624275, 57.41516428609049, 70.75314091097924, 70.21598016062092, 77.40338617755522, 73.29038097012427, 73.58309176660353, 4.363169564354805, 5.934107255551123, 59.16943257854831, 62.71423147570703, 36.193392276763916, 35.048287683917636, 18.759976779260946, 25.162449844421882, 50.02543457092778, 46.41392007950814, 61.62263585675148, 57.55341998992428, 58.55962168785834, 1.7745036776027374, 0.12977530969487083, 0.16995447627719373, 0.11411366864077507, 0.08086375201181059, 0.0804433995677579, 0.13017681637598624, 0.04950452888865144, 0.055632293825187994, 0.14531282918347468, 0.262973347017842, 0.3654799255872927, 0.13037432916462421, 0.16517428681254387, 0.319021902377567, 0.1441721702294965, 0.5598358497504266, 0.25631388258789817, 0.6394004545384838, 0.593088417043609, 9.063254056438323, 77.64195257617583, 69.75351702782416, 53.7656145711099, 48.243466500313055, 52.814494717505674, 42.00752550555814, 24.279726320697417, 35.39993601460611, 66.4414833438012, 71.9449923115392, 19.461941795964396, 10.504085748426377, 89.87511127225815, 66.33579900187831, 85.51505165715372, 68.33125775860202, 76.07438518155006, 56.400231392152854, 69.80911270264657, 58.55728395523564, 63.78198300638507, 55.86350210251347, 66.3304175100019, 60.65524993404266, 64.21963322547175, 66.47235239705732, 69.15964664951449, 63.60394270189347, 69.70699771758049, 66.5654145517657, 69.84487687387775, 62.47786552675309, 68.44201764752789, 55.201468775349284, 55.89825430224019, 49.60641168778943, 52.29636530722342, 50.87318035864061, 54.83072634666197, 54.10738245133431, 55.33579034190024, 49.446865358660304, 50.99663303744409, 48.6141893171495, 52.10205501125705, 48.76849535972842, 60.661455123655266, 59.33810234069825, 58.228079426673155, 62.23645933212773, 65.7531975930737, 61.55153897500808, 62.281876456352975, 63.46569484280002, 62.15630569765645, 63.12367200851441, 60.45569935152608, 59.730041257796756, 62.767422737613806, 60.782440631620354, 61.11477128921017, 58.23428853865593, 61.82495171023954, 58.87543132228237, 61.7341802197118, 53.329851012076105, 41.98485420596215, 34.54066238095684, 37.979129745114236, 39.36449520049557, 43.133492854333696, 44.82470904627154, 47.17941768707768, 46.945664036658506, 45.12585293862128, 43.3080618612228, 42.01184011274769, 46.75184403696368, 45.52699765851421, 41.78902203036893, 40.40909298004643, 42.139450503933816, 39.000522782725675, 39.49613386584867, 39.391955714071955, 37.038090382852864, 42.27365047700944, 55.42054883895382, 60.22917462933449, 60.23924335356682, 57.196790249116965, 57.155217047660585, 56.548614655771566, 56.01590579555881, 56.314653119733265, 56.84558514625796, 55.782395332090324, 57.76618111518122, 56.80966015784972, 53.75139205686508, 56.98648060521772, 58.9241510821927, 60.33245063597157, 67.33925896306192, 61.17747037641464, 61.14217296723397, 59.33197167611892, 54.02663653896701, 53.28237856588056, 50.634955206225, 53.297365942308986, 57.088717183759144, 52.434267997741706, 56.63393797412996, 54.56334229438536, 51.85285114472913, 52.67804330395114, 54.987350510012725, 53.94054443605485, 52.18296174080142, 51.65007637393091, 56.59677743911744, 56.38593043050459, 58.920452287120206, 58.39103037311185, 67.35093193669474, 68.62249374389648, 75.66386991931547, 68.52107694072109, 64.28878461160969, 58.89843994571317, 76.09344005584717, 66.82160808194068, 74.11674591802782, 66.59105116321196, 60.188209395254816, 61.90010040037094, 75.2031953873173, 76.40106370372158, 84.22336809096798, 77.29809407264956, 85.9430685350972, 8.280454874038696, 4.748685109999872, 62.52265899412094, 73.45872909792008, 45.60177372347924, 34.11973714828491, 37.39173519995905, 41.967568320612756, 61.36600302111719, 57.96883037013393, 64.43538711917016, 63.26759945961737, 70.00116763576385, 2.9133392197470513, 0.30713696753786457, 0.25696957724228986, 0.33048410990065147, 0.190258257751984, 0.2599602619246129, 0.2697394662086041, 0.3815468118315743, 0.20343565952874001], [0.01259562790378808, 0.05014556062017238, 0.04174813763388703, 0.0821976183402923, 0.004798527694337311, 0.15724385187270182, 0.04578701828816726, 0.01767167573674552, 0.05267515230262953, 0.12512399154084344, 0.3680379238099821, 11.323304137875958, 64.65871510967132, 55.26437574817289, 56.69089471140216, 51.17470472089706, 42.29438020337013, 24.582403859784527, 34.542792227960405, 22.18185643995962, 57.67054588563981, 60.18562063094109, 39.100931536766794, 0.9623341550750117, 58.304224398828325, 73.57458806806996, 72.89298995848625, 71.21002643339096, 62.8532559640946, 54.23035660097676, 54.23693441575574, 54.10176953961773, 57.43562336890929, 57.505374877683586, 59.757415479229344, 61.28708885562036, 63.82720008973153, 62.3877255378231, 63.65513747738254, 62.553520202636726, 68.17247236928633, 64.13781258367723, 62.17715701749248, 60.47801763780656, 57.84760559758833, 46.938854802039366, 49.20085822382281, 45.28494819518059, 49.92894034231863, 49.26519293938914, 51.778447704930464, 49.871175596790934, 49.27615204165059, 53.91864584338281, 50.430266318782685, 43.75314104941584, 45.768148899078376, 46.91748965171076, 53.8774884131647, 53.92869103339411, 55.39902287144815, 53.25837366042599, 55.74588198815623, 56.008527817264685, 55.31625301607194, 54.41386861185874, 52.12462432922856, 54.996921093233176, 51.2637895922507, 55.07923987603957, 53.47413932123492, 52.196642967962454, 52.83450665012483, 53.37977886199952, 53.41856718063355, 51.1708882547194, 53.71607503583355, 42.5761083633669, 39.6636700630188, 37.89832499719436, 36.8235759581289, 35.54090599859915, 39.10011176140078, 44.81015313056208, 43.59591284105855, 43.438480669452304, 42.33050915502733, 45.09187344581851, 44.73345118184244, 40.548521472561745, 36.29891187913957, 40.560214058045425, 37.15016034341628, 35.48811874082012, 36.276558291527536, 38.876046365307225, 39.40481716586698, 45.14633163329094, 40.35630179989723, 48.9200282865955, 53.98155281620642, 53.77147459214734, 55.8321427529858, 53.6873907427634, 52.53082498427361, 55.1082811047954, 51.93733507587064, 52.728241797416445, 54.03953721446376, 54.20882278873075, 54.624315538714015, 52.85261231084024, 55.57986374824278, 54.10910437183996, 55.25253803499284, 54.44787556125272, 53.38769420500725, 56.51859675684283, 52.34732866287232, 49.432497716719105, 50.61902253858505, 51.99599412179763, 50.028882334309245, 47.47524284547376, 49.598637550107895, 49.85465849599531, 45.91789714751705, 49.410124517256214, 49.53084330404959, 48.35989421413791, 45.67083881747338, 48.389355136502175, 46.966260402433335, 46.688744868001635, 48.034702270261704, 53.316008967738, 52.79711077290197, 55.73756656339092, 59.76280481584611, 63.241762807292325, 66.31146461732926, 64.94851158511254, 53.640989103624904, 60.71782742777179, 67.68421573023643, 61.42584662283621, 66.80640497515279, 53.77657759574152, 53.784893020506836, 64.76294817463045, 68.679321042953, 70.69450147690313, 73.59172882572298, 49.68958162492322, 1.054942540584072, 12.64495853454836, 59.20944075430594, 47.805855504928104, 17.21616129721365, 23.927146427093014, 77.68400038442304, 51.75507037870346, 53.133685435018236, 39.08489296513219, 58.745361604998195, 63.32443068104406, 55.272726474269746, 14.722068290556631, 0.221011417226926, 0.0707760671033494, 0.06733388850285162, 0.1099451467575085, 0.014597134112620787, 0.10765262864409916, 0.04650865013020174, 0.1698611208027409, 0.056926327412046736, 0.03798930425076716, 0.04172246219710477, 0.05510069392321091, 0.02035016618338564, 0.13385535608376228, 0.06661184297333803, 0.10135483432320819, 0.10700369088519966, 0.41532277039462523, 0.5196270202436756, 17.11345011188138, 75.25559040807909, 61.37778582111482, 59.071188972842315, 53.21285455457626, 49.171903287210775, 31.90321949220473, 40.202242866639175, 25.80362008463952, 63.31712722778321, 61.53379417234852, 49.04989011826054, 1.0490417023820262, 57.41879247849988, 75.56642255475445, 74.12421411083591, 75.91280706467168, 64.71730747530538, 58.643917345231586, 60.86769726968581, 57.59646800256545, 61.53635155770087, 60.558896910759714, 62.221256225339836, 64.66188438477056, 65.79630051889728, 63.62161690188993, 64.54315816202472, 66.61943343377882, 68.8684263537007, 66.59738186867007, 64.92269062226819, 64.630140642966, 58.825625065834295, 50.58398008346558, 50.958244800567634, 48.92241701003044, 52.232583645851385, 52.23466250204271, 56.97550189110541, 54.03174738730154, 50.88654387381769, 55.785501849266794, 53.44955390499484, 46.95319106501918, 47.66652114929692, 51.16684821344192, 57.05012498363372, 58.582948023273104, 55.54511939325641, 56.388570185630556, 57.98486109702819, 57.802396358982215, 56.9248797816615, 57.47217201417493, 55.14866190571939, 59.00796036566458, 56.33924245834351, 57.97254093231694, 57.05679301292666, 55.561828690190474, 55.49575244226764, 55.651592131583925, 55.80761617229831, 55.32459981979863, 56.38765627338041, 45.33879057053597, 39.74238418763684, 36.53961989187425, 37.05740805595152, 34.4131382819145, 39.037283235980624, 41.703282940772276, 45.03992165288618, 41.321510807160415, 42.889423370361335, 44.14119289767358, 43.799079848874, 40.693052968671246, 38.0469592925041, 40.844519215245406, 39.284435702908425, 34.49018147683913, 35.741825488305864, 38.515635459653794, 40.01220795416063, 47.148297602130526, 38.81510057756978, 50.25268100923108, 56.30081107539516, 55.866149702379786, 56.914356062489176, 56.07844406558622, 56.466264494003795, 57.01097580694384, 52.92122633226457, 55.494238407381125, 54.92442392533826, 53.07763084288567, 53.871145940596065, 54.170587524291015, 55.53874946409657, 53.75804047430716, 56.902326153170684, 57.35353208357289, 56.1819750262845, 59.12721610838368, 55.45151987383443, 52.77540437636837, 51.95735877560031, 53.71034837538197, 52.39687604288901, 48.069175981706195, 52.290113049168745, 53.877943408104684, 49.34807654350035, 50.174147313640965, 53.3867528361659, 54.883089988462395, 52.10230604294808, 51.770799083094445, 51.13666165259577, 49.63005573518815, 50.91564393812611, 55.356873081576445, 55.320771586510446, 58.646360981848936, 62.11570916637298, 65.92398935748686, 67.80195743806901, 67.5681527968376, 58.01311785174955, 62.52997813686248, 72.23422004330543, 65.446068163841, 70.19951405063753, 58.24432588392689, 58.08762327317269, 68.57940258518343, 72.74618348767682, 73.6502270544729, 80.42402698147683, 47.707945300686745, 0.6457654194485757, 16.682724837333925, 69.51411908672702, 48.37438737192462, 21.661942351248957, 25.991385905973374, 63.09179882849417, 42.956170343583636, 59.05568384355115, 38.243022887937485, 61.97985003071447, 73.24379890195786, 68.0602612033967, 27.503828310197402, 0.22008284205390563, 0.22238640715518307, 0.07922916552953183, 0.09070879389201442, 0.05900558579953448, 0.13395186784046312, 0.10353450002449174, 0.03224585881276477, 0.10851546581233702, 0.19994908613303017, 0.13215962046336743, 0.22979225572799483, 0.10795917106612075, 0.34127485667986257, 0.20738429119510038, 0.5537061657636397, 0.2878437173222342, 0.5594665340838895, 0.7539894347709994, 21.38593496814851, 83.92380099142753, 70.08701262935516, 71.3933737047257, 65.56663790056783, 52.998904951157115, 34.8840384329519, 45.62384882280904, 31.643201651111728, 69.98332085147982, 71.21336829277777, 48.61808423073062, 2.1003044468741265, 70.20760982267319, 72.8550684836603, 80.90213252652077, 76.2365516539543, 69.32377430700487, 59.35206597851169, 64.72835679208079, 57.62566612612817, 64.23496184810516, 63.125503755384884, 65.55754192413823, 65.3985917952753, 69.47407953200802, 63.93508880369125, 66.91809054343932, 67.42000487542921, 67.25390034337198, 69.57096207526423, 67.8205337832051, 68.16019535064697, 63.99998049582205, 51.74271099029049, 55.48627599593132, 51.86144898014685, 53.58650738193143, 55.67369076513476, 58.91727124491046, 55.88904065470542, 53.48008171204598, 57.28784415029711, 54.79777843721452, 50.10462330233667, 51.2708459361907, 53.67550988351145, 62.102577071036066, 60.4729538579141, 61.39873520020516, 61.377115095815356, 62.10382046238069, 62.220212874873994, 61.49984998087729, 59.61064038738128, 56.612741485718765, 63.48645594812209, 61.199725904772365, 62.89559795010475, 61.3437278809086, 58.35702342371787, 59.54204205543765, 58.79326158954252, 58.44047969387424, 58.79015507236604, 59.81576073554255, 45.81071446018834, 41.75911395780502, 38.69429942100279, 39.0623354142712, 34.902457883281095, 40.53332228814402, 43.25685531862321, 44.730430956809755, 41.691103981387236, 43.96583941675002, 45.21670287655246, 46.91490873213738, 40.913207761703, 38.03917731008222, 43.30880318918536, 40.32752729231312, 35.54615412988971, 36.51810176910893, 38.381619837976274, 39.61077297887495, 48.542535458841634, 38.66575633325885, 50.89427094305716, 60.259153304561494, 59.00691309282857, 62.523431701044885, 61.0325191866967, 60.80668087928527, 59.55321688805858, 53.18996360225063, 58.892870180068485, 58.573338216350926, 56.699421944156775, 56.7267765537385, 55.51073981869606, 58.59900228438839, 57.88968870716711, 58.880804969418435, 58.21348428726197, 58.68867551126788, 61.61934106580673, 56.83222947582122, 52.83274158354729, 54.54199675590762, 53.934527520210516, 55.40232158476307, 51.75511744714553, 54.172925256913715, 57.125532550196496, 50.36898320721042, 55.10179350453039, 56.1016409627853, 58.09199279354465, 53.23793418945805, 54.3814855237161, 54.20217829365885, 53.052727714661636, 55.623194171536355, 61.05468057817029, 57.463534955055486, 62.12006299726425, 66.90056539350941, 69.23893344017768, 72.71035655852288, 67.29287301340412, 57.12527367376513, 66.74548272163638, 74.88538142173522, 68.79631750045284, 71.38228124187839, 61.655073858076534, 58.61298161168253, 72.00134108143469, 76.9473792660621, 79.71866715338923, 80.04172925026187, 58.827390132411836, 1.781280062371685, 15.195822946486937, 74.59895426227202, 59.119877353791274, 33.11409242691533, 30.847597891284575, 93.48744946141397, 67.5732675675423, 69.94350879423081, 52.54498866296584, 67.87235613792174, 74.78611407741424, 78.193359375, 28.642207999383253, 0.37395224515949527, 0.3391056940440209, 0.1803161831752908, 0.15749358121425877, 0.1890303260616718, 0.417173485602102, 0.2316374704241753, 0.23608024412345505], [0.07790004894618066, 0.04369431888804801, 0.09779179769177591, 0.028032656766534336, 0.06594038222946468, 0.1294742218188701, 0.03318928076975769, 0.12053565347507117, 0.08680319338436089, 0.07752699477057304, 0.22333267895925432, 10.852424579281962, 65.42576205345893, 53.249838582931034, 38.84995083655081, 22.225867394478094, 50.81199922869283, 16.507416463667347, 40.38280525515157, 18.521657489961196, 53.735498612926854, 52.9903777184025, 71.03637526112219, 3.6058459310762347, 14.260582808525333, 92.07382725131129, 64.4026941637839, 73.73329500998221, 60.4000291516704, 60.580897485056234, 53.31702486161263, 61.58820529137889, 54.836841321760616, 62.63794529822565, 58.15096562908542, 65.6371581938959, 63.33578986506309, 67.68398038802609, 61.12931151543895, 66.11148649646391, 60.08551782177341, 62.00343916493078, 60.332211371391054, 59.9288034439087, 52.69956142671647, 47.409056771186094, 46.05039481193789, 48.7775521124563, 51.875165508639434, 55.44838197769658, 53.90934198133407, 48.822114159983975, 53.03375128776797, 50.005297122463105, 51.73540361465947, 51.91289478732694, 49.926724203171275, 54.386486545685806, 53.58518946555353, 53.96505532726165, 53.17249336550313, 53.01590450348393, 53.79643655592396, 53.39282858756281, 51.6792078172007, 54.60039692540323, 53.81346748721216, 51.56705156449349, 51.202647686004646, 52.45720994087958, 50.97545223851358, 53.255384814354684, 52.23919283959174, 52.49826931184339, 55.22132381316155, 52.14865276890417, 51.29803972859537, 43.96413318572506, 42.01053004111014, 34.635446456170854, 34.41964549403037, 35.68543749470865, 34.63298320770264, 37.04587236527474, 38.40832725647957, 40.65430387373894, 44.83435807689544, 43.0349511484946, 38.9808246397203, 39.43477230687296, 42.34183303771481, 44.0559244924976, 40.94504171802152, 37.34142688012893, 32.02665452034243, 34.76557893137778, 35.22917170678416, 45.53201436996461, 44.989950656890876, 43.549173878085234, 54.43490428309287, 52.854126345726755, 50.58826723406392, 52.29025425449495, 51.852274556313795, 52.86817627568399, 52.997873367801795, 52.58773073073357, 51.067016047816125, 51.782334773771225, 51.833768813840805, 52.64192219703428, 53.17671383580854, 53.76335136352047, 55.31962625442013, 54.38598055993357, 55.991626324192175, 52.91862972321049, 53.05753261812272, 52.284606041446814, 53.79797804740168, 52.31070157020323, 48.68101081540508, 51.40473604202271, 50.59919887973417, 49.010576202023415, 49.658061458218484, 50.0553701000829, 51.007113610544515, 51.08882050360403, 51.41834666652065, 49.59534668153333, 49.238524744587565, 46.42256106099775, 50.5194688612415, 52.439688713319846, 55.98625659942628, 52.909961285129675, 57.706282600279785, 61.21360717281219, 63.05606995859454, 64.49631329505675, 67.93960909689626, 55.89984286215998, 64.3097379130702, 62.68936364881454, 63.7754051916061, 58.944057110817205, 54.954865440245605, 62.04583214175317, 71.4147113984631, 67.37385426798176, 79.04481180252569, 24.01961042035011, 0.1979576405738631, 26.952360714635542, 58.01434947598366, 33.582372434677616, 8.839894686975788, 68.96872135900682, 154.3937938444076, 80.07616766037481, 49.038209299887384, 62.35772725074523, 19.86371801745507, 49.758289783231675, 57.53052903759865, 40.56897663301037, 0.6478624778889841, 0.08023771262096782, 0.046668329666699135, 0.05054628206116538, 0.0689900633428366, 0.030615499220608227, 0.22478139718934415, 0.051710337340351076, 0.0683754156794279, 0.033376026192619916, 0.050440167392333674, 0.061947646881303484, 0.04330953590631966, 0.1436990343274609, 0.06560731018262525, 0.14360845209129397, 0.06917381719235452, 0.06313733163199599, 0.2618523152364839, 14.895508635428646, 77.33411712031211, 56.609784018608835, 42.50463101171678, 25.868390183294974, 57.86599366895614, 25.18204600580277, 49.70531425168438, 21.863913036161854, 62.819107809374415, 58.31439510468514, 80.34684258122599, 6.362293776004545, 12.36411584961799, 93.47976161587624, 64.68015086266303, 78.76780617621638, 66.97265071253624, 65.84209811302924, 57.171086957377774, 65.29344481806602, 58.56721931888212, 67.26654606480753, 62.00740075880482, 67.4035858338879, 63.464271022427475, 69.21607386681342, 62.73800496132144, 65.55640051441809, 62.8933386648855, 64.08804947330107, 64.35961477218136, 61.81318459972259, 56.356049814531886, 50.046960538433446, 51.14462798641574, 52.55296676389633, 55.11363906245078, 57.41986720792709, 55.58058938672466, 50.7895318923458, 55.348745930579405, 52.28854017872965, 55.4083385006074, 56.71205589848181, 52.75400784707839, 59.79820812902143, 57.61554248871342, 59.14174848987211, 56.50374666337044, 56.221037910830596, 56.29302124823294, 56.54744186709004, 55.48975906064434, 56.65975893697431, 56.29341740762034, 54.12835928701586, 55.33806923897036, 56.922542049038796, 53.42709833575834, 56.424601078033454, 56.15949200045679, 57.53150570777155, 57.205635193855535, 53.969291487047755, 51.830697597995886, 45.09324235300864, 43.50116798954625, 35.091312162337765, 34.41593493184736, 35.91121304419733, 34.56700894140428, 38.94681376795615, 38.3901313812502, 38.86472248261975, 43.22600195484777, 41.82720238162626, 38.390747193367254, 42.03759047292894, 40.32972774197979, 42.301346332796165, 40.850849920703524, 39.7120132753926, 34.020716913284794, 33.92882362488778, 35.643217102173836, 42.81553768342541, 45.796923406662486, 43.34799551194714, 57.472415201125614, 53.12870794726957, 52.59541465390114, 54.450546695340066, 56.19782140178066, 54.36747089509041, 54.237287429071245, 53.990613491304465, 54.54598188400269, 53.788352550998816, 52.96907140362648, 54.77105140686036, 53.89409180610411, 57.75222924447829, 58.33172805847661, 55.54366419392248, 55.88584392301498, 57.5639162525054, 56.07996986758325, 54.57934556468841, 56.798332352792066, 54.16061685931299, 51.81212909760014, 51.96231272912795, 53.45862242483324, 50.959068498303814, 53.67296034289945, 52.835530388739805, 55.22106885910035, 52.72166398263747, 55.954669752428615, 54.5686924073004, 51.535892255844615, 48.09971163349767, 52.36190026806247, 55.89934079877792, 58.76121582523469, 58.66561197465467, 60.75137153748543, 65.72913385206654, 65.88684451195502, 66.13813507941462, 71.44823981869605, 60.81128181949739, 70.58970359063917, 66.8338772558397, 67.51104308712867, 61.47607257289272, 59.878769689990634, 67.42317415052845, 74.84534971175655, 70.48572940211143, 83.26041052418371, 23.845774896683235, 0.11417911553214635, 35.124134555939705, 62.04437694241924, 38.73004005801293, 10.302269997135287, 74.53783589024698, 152.10735013408046, 88.11284526701897, 63.27111782566194, 61.266488567475356, 22.6016402629114, 59.898558047509965, 62.50366687774659, 59.38009131339289, 2.6591625232850356, 0.03150059315826624, 0.11429025956820096, 0.038058765442861665, 0.07296643505293517, 0.10900969977580732, 0.08516712835238827, 0.05563918861650652, 0.22529853718175044, 0.15192865724525145, 0.1768714228584882, 0.12397564872498475, 0.36869675942486335, 0.21719754042644657, 0.20677574159156895, 0.3164621268308932, 0.22089016083027088, 0.22131897088500763, 0.29484260466790974, 19.285256670367335, 88.13440261348602, 69.26408367772257, 51.511883428019864, 29.605277353717437, 65.27179725708501, 23.940137317103726, 50.97542870429255, 27.86506683595719, 70.65804696852162, 64.62698705734746, 87.39383559073173, 5.118883800122046, 22.615397976290797, 97.1306880827873, 68.04706635013704, 79.49664531215545, 66.56220605296474, 67.95417677971625, 61.878848998777336, 70.84932527234479, 61.43047109726937, 69.26969266706898, 63.98762502977925, 71.26687726666852, 66.68394857837309, 71.16185972767492, 66.08934079447101, 64.63873455601355, 66.71327221778132, 68.071330132023, 65.02202072451192, 64.45264947029852, 60.50865134885235, 54.01011159343105, 52.512982122359745, 55.05707063982564, 56.83488492042788, 59.529051165426935, 57.83955689399474, 52.882312497785016, 59.78188714673443, 56.69118888916508, 56.33493961826448, 59.958601690107784, 56.298536100695216, 63.54468353333012, 61.64495414303195, 62.69506677504509, 61.33534185348019, 60.57015019078409, 59.39885985466742, 60.17727774958457, 57.42018491991105, 61.12403592755718, 60.21146905037665, 59.401079916184955, 60.20703284971176, 60.71369717198034, 57.38150250527167, 60.66325549156436, 58.932948958489206, 59.805170336077296, 59.242749521809245, 57.52040147781373, 56.10416304680609, 48.20334849819061, 41.966517125406575, 34.03311552539949, 35.380943898231756, 36.30512883586269, 33.658321288324174, 39.870406427691066, 39.428845605542584, 42.46958463422714, 45.54977878447502, 46.208242754782404, 42.14361998342699, 44.46570627150997, 43.610860993785245, 45.21299623673962, 44.517171690540934, 42.23997300670993, 37.16136263262841, 36.283940192191835, 35.11615253263904, 44.74312374668737, 45.776515314655924, 44.49950141291465, 60.263538514414144, 57.020491476981874, 56.671235792098514, 58.51474585071687, 58.170279379813906, 56.42482857550345, 57.247443737522254, 55.6031822389172, 55.927393590250325, 55.73096521439091, 56.26555288991621, 54.47323368441675, 55.34657685987411, 59.86654366216352, 62.18960662041942, 59.8620839272776, 58.737034413122366, 60.0563746113931, 57.87543089159074, 56.75056572883361, 59.52685463813044, 59.6597876856404, 54.43271167816655, 55.83158969879151, 55.435018462519494, 55.59622787660169, 57.12377925072947, 57.57116087021367, 57.46701017502816, 56.99290544755998, 59.31180284869287, 56.25577442107662, 54.68230385934153, 52.269453925471154, 56.317900842235936, 59.843805682274606, 61.41708012550109, 60.525752882803644, 64.07389363934918, 69.56513343318817, 67.31842333270659, 74.28481163517122, 69.61948963903612, 61.84311620650753, 74.34825205033826, 68.90175865542504, 68.19517504784369, 63.118518014107984, 60.8538277687565, 70.60821717785251, 76.69619068022698, 70.99585717724216, 86.96205323742282, 33.15939580240558, 0.35770529760949077, 33.087945907346665, 70.31586723942911, 49.12594487590175, 19.765517557820967, 78.04618420139437, 154.79638591889415, 92.96578207323628, 63.110402630221465, 83.12078983552995, 29.596879559178507, 64.58672392752864, 75.10406140358218, 65.72930643635412, 3.035307036292169, 0.20699326459678913, 0.24506607243130285, 0.16925240265986613, 0.1891622617239914, 0.15408879536534512, 0.19807566407947771, 0.2446153216184147], [0.06585382195490022, 0.011864165238465273, 0.09356401890756623, 0.029203524482586694, 0.12047834243745574, 0.10951883414940489, 0.07732487013263088, 0.05008939105356413, 0.049602741360544204, 0.08834369660865876, 0.17325027845799926, 12.991319510244555, 65.18764672740814, 48.77237850619901, 45.36107747785507, 31.65135429751489, 56.2638545036316, 15.956867683318356, 28.58348031197825, 16.812672961142756, 35.388984757085005, 66.77136252003332, 58.82339715957642, 34.39476590002737, 0.6149145684415295, 59.953165285048954, 70.86474803186232, 73.38003066278273, 67.14938486776045, 64.01332439914827, 56.48991246377268, 61.851666973483184, 62.69637292431247, 63.098513926229174, 62.98228233091293, 62.741931253863925, 64.58310357985958, 61.125028287210775, 63.22122527707008, 59.00052747418804, 60.60944449517035, 65.24624301541236, 61.49979899006506, 60.19707395184425, 51.93430700609761, 45.177047714110344, 47.305612102631606, 54.61183063445553, 53.751290075240604, 52.53062102102464, 56.308702884181855, 54.60724930609427, 54.27956273478847, 54.246073538257235, 50.30722548884731, 54.35991248776836, 49.87104615857525, 51.22084356123402, 52.16371859273603, 53.49457094746252, 52.78793634906892, 55.14784997509372, 54.90176831522296, 53.87365625750635, 54.5926933903848, 50.89625173999418, 52.328928824393984, 53.45587284334245, 51.87816219945108, 53.011189814536806, 50.31764722639515, 51.94845891767933, 51.58722431428971, 50.6289343680105, 54.30847060295844, 51.254995638324374, 43.03332728724326, 39.799791997478856, 39.188749482554776, 33.958794455374445, 32.42968590028825, 32.194635906527125, 37.02629189337454, 40.60585867974066, 42.428607633036954, 41.85779686897032, 45.34645880422285, 41.748994242760446, 38.230365399391424, 39.796709014523415, 43.544251303518976, 43.2476612829393, 44.686418041106194, 40.176214018175685, 39.50016998475598, 38.68413263751615, 36.91502994106662, 43.58464779392366, 46.616934114886874, 42.39604019349621, 43.67525062253399, 50.872454720158736, 51.312509352161044, 51.69405791067308, 53.19511759665705, 50.0753898774424, 51.130213276032485, 52.02870668903474, 52.95772790908814, 53.06578528496527, 52.55657534445486, 50.639975840045565, 53.25988769531251, 53.50055648434547, 53.66624524516445, 53.08738185513405, 53.41187953948975, 50.377082901616255, 51.9022180957179, 53.44499611085462, 52.168688235744355, 50.90083306835544, 53.217514330340975, 49.126992148737756, 48.683070059745546, 48.09206301166166, 48.84038063787645, 51.04548223557011, 55.534191669956336, 53.4804896385439, 55.152011609846554, 53.07104910573652, 51.10944432597007, 48.475588444740545, 52.06046219794981, 50.402456714260964, 54.406780888957364, 55.37839904908211, 59.42468081751178, 59.32278940754553, 64.3375632070726, 59.809555545929946, 61.87752716002926, 60.893969305099986, 63.7467561998675, 64.9668368985576, 66.09735027436288, 58.867237490992395, 56.74712581019248, 59.24461657001127, 72.29057665794127, 67.14961236523044, 78.75106550032093, 7.610160054699068, 1.1393012010282086, 42.17676401138306, 58.022696279710345, 24.408154526064475, 8.143805380790464, 34.05356284110777, 31.95063702521786, 13.801858675095344, 32.35208180642898, 76.03667551471342, 49.303843975067146, 28.83889525167404, 52.85199257635301, 66.66524671739148, 14.914734132828253, 0.4308812806923544, 0.21086262148474494, 0.06986436884730093, 0.11808601838927116, 0.11295416392385961, 0.12168528331864266, 0.019363896928787715, 0.07111780360461244, 0.06151456205594925, 0.15500900485823232, 0.05577693122529215, 0.013134921243744753, 0.11763165164138041, 0.04764519519202652, 0.06458827534750586, 0.0933351961054629, 0.21302161047295218, 0.1393553004750321, 17.72407293319702, 71.92453322872039, 54.50455773261286, 49.77077860986033, 32.94657976396623, 63.972661187571866, 20.036084613492413, 34.794647616724816, 16.67617447914616, 37.40578120754611, 72.16615123133506, 64.28374044356808, 43.90033191250217, 0.2513999494934275, 56.52916754445722, 78.10449415637602, 74.5524114178073, 71.80831340051466, 67.62998504023399, 64.10622181430941, 65.91004925389444, 66.93578827765681, 63.35694320740239, 64.11089335718464, 65.34682435374107, 66.59834677173247, 63.16817522048951, 63.028338801476266, 61.83090586816112, 60.43651111664311, 67.883880061488, 64.2056695876583, 65.89674457426995, 56.55070920144358, 49.55050614572341, 49.44969338755454, 55.79197768242129, 58.14001437156432, 58.28411440695486, 58.10282245759041, 59.46976846264255, 54.418618602137414, 56.1652421951294, 52.48319564327117, 57.95184258491763, 54.983890979520744, 53.052986591093, 55.40283149288547, 56.24145776994767, 56.08558670167, 53.49537503334784, 56.056894563859515, 57.15507976470455, 56.68677622272123, 53.98459657546013, 55.94708388851535, 56.193651922287486, 55.69964901093514, 55.48777826370732, 53.16872789013771, 53.870435991594874, 52.828897660778416, 54.15298784932783, 54.74463424374981, 53.869063162034564, 46.833543085282855, 36.0568545710656, 36.2424885842108, 34.208280732554776, 34.734607896497174, 31.024796847374212, 37.04649994450231, 38.35806208272135, 41.42529672191989, 39.46404495546895, 45.54475422828428, 44.29105489484726, 41.22606777375744, 43.11888202544182, 46.591972151110255, 44.94036797554263, 44.94567886475594, 41.369646133915076, 39.79940760520197, 37.628932691389515, 36.935575316029215, 44.38818846979449, 44.3820107367731, 41.63344906222436, 44.35819018271662, 54.76907453229351, 53.18151089452928, 54.169822662107414, 53.30746996787287, 53.33752316813315, 55.32523916613672, 53.92347035869476, 56.153698659712276, 53.988295370532626, 55.691470869125865, 52.25161890829764, 54.815484016172356, 57.47520400631813, 57.98053080035795, 55.196204954578036, 54.96902127419749, 53.382249955208074, 55.311914874661355, 54.36603922997752, 55.54864168167115, 53.01140162252611, 55.45338692203645, 51.71129672758041, 52.443007038485625, 54.2593115375888, 55.769239702532374, 53.71367062291792, 56.88254564039169, 55.745313244481245, 58.37864352810768, 54.765838576901345, 55.13604756324522, 50.43278448043331, 52.97735937180058, 52.18774703241164, 55.85198210131738, 56.64273977279664, 61.27396852739396, 61.2118068049031, 67.13011818547403, 62.294267223727324, 62.431652161382864, 61.68342474968203, 64.29917497019615, 68.27503450455205, 70.20251858618953, 62.63419158997075, 60.1127939839517, 65.18386556256202, 76.73790900937973, 70.49062452008648, 81.41615913760278, 5.9731961257996105, 2.334370661166407, 52.50415286710186, 58.627306107551824, 30.930314794663463, 8.030383183110146, 33.75741997072774, 38.45263827231623, 29.117309008875203, 46.50497005831811, 77.28187114961686, 46.45813303609049, 38.123873049213046, 56.5507209685541, 78.91691900068714, 26.133820895225774, 0.36186438895040945, 0.07344894787116397, 0.0635043528651999, 0.07301118990947163, 0.13094474291128497, 0.09744074556135363, 0.0873148788307463, 0.2215209882706404, 0.18351118350701948, 0.22035100347092076, 0.15567942372252866, 0.1989648163679146, 0.19519442271801735, 0.15472300891433993, 0.21675506336314065, 0.1757863665660543, 0.3016118801409199, 0.28703567842322014, 21.41369946541325, 84.50973249250843, 61.94324254989625, 61.42193209740424, 45.225638035805, 77.95910758356895, 24.88589725186748, 39.60827835144536, 26.450536597159605, 47.87082956683251, 75.15447954977714, 76.1181588326731, 40.64132082846857, 1.6287775746276303, 70.3350397848314, 71.03894049121489, 79.987898642017, 73.44926049632411, 73.25951191686815, 63.35489573017244, 67.95774613657306, 67.57478944716915, 67.12039070744669, 67.40415849993306, 69.30522149608981, 69.526137228935, 66.87918063132994, 60.22995910336895, 64.60488450142645, 63.29596604070356, 69.80910485790622, 67.97877004069667, 70.62880177651682, 59.209570192521625, 50.097947428303385, 51.22109459292505, 59.22284349318474, 62.60739395695349, 61.68760599628572, 61.75994234700357, 62.140322039204264, 56.77484127783007, 58.561288695181574, 56.48373473075129, 60.253175612418886, 58.00590853537283, 56.300869910947746, 59.465995142536784, 61.275266831920995, 61.31560056440292, 58.35204985833938, 58.726463625507975, 59.73538352597145, 61.067440048340835, 57.245215831264375, 59.04956886845251, 60.00763916200208, 60.67444993603615, 60.74642150632797, 55.812436765240086, 59.81620396337202, 58.945645670736994, 56.67482476080618, 57.37847051312847, 56.18994136010447, 48.31628922493228, 37.68406160416142, 37.24561122155959, 36.471390262726814, 34.02081497253911, 31.18887547523745, 39.63817073452858, 38.51520007656467, 42.452439954203946, 39.98191156694966, 51.33751838437973, 45.350953840440326, 41.5080391207049, 44.0856639031441, 51.464152105392955, 47.52115418834072, 47.88530311276836, 42.177764215777, 42.20078068394815, 39.1207238166563, 38.15274561605146, 45.45952504681003, 47.11746385020595, 40.3749369805859, 46.58262514298963, 58.34333435181649, 55.73029841146162, 58.26453001268449, 57.89537614391696, 54.44257251677975, 58.66794578490719, 55.447213111385224, 59.00828200001871, 55.61858146421371, 56.48736292316068, 53.35695851233698, 58.643203473860225, 59.98510514536212, 60.48050834286598, 58.3383176403661, 58.36009071719263, 56.03177962764617, 56.94158515622539, 57.94264462686355, 59.096590242078236, 56.900455182598485, 59.73518348509266, 52.400382641823064, 56.97883982812205, 59.42438663974885, 57.63933558617869, 56.84159609579272, 61.012330747419796, 59.87463943419918, 63.25031357426798, 58.315152122128396, 58.53338887614589, 54.124699715645086, 55.96540135722007, 53.923976344446984, 56.16148456450432, 60.3712821006775, 64.54267571049353, 66.18396405250796, 71.655105621584, 66.59458914110738, 67.56022960908952, 60.43205922649753, 68.41546320146131, 72.27870756579985, 72.73974295585387, 65.5501914024353, 61.828042537935325, 67.53849967833489, 77.50069233679002, 71.3715261028659, 86.44671655470326, 11.142164180355689, 1.5248747242073861, 54.535975917693115, 68.36272301212435, 41.82472344367735, 14.448947771903008, 42.605851696383574, 37.86959363568214, 20.234540854730916, 40.17848507050545, 95.03149832448652, 65.7515541199715, 38.99100711268764, 67.8848449645504, 89.98161931191721, 30.208408448003954, 0.6795600705569791, 0.5989755269500517, 0.15445245730300106, 0.25747062938828624, 0.1332343958558575, 0.3090969881703777, 0.3065640563445707], [0.2771870359297722, 0.09300889627587411, 0.08442108894908622, 0.2710662998499409, 0.11074522600298929, 0.15227777883410454, 0.0921991336790304, 0.09133196811402038, 0.20365057783501767, 0.1890323638555504, 0.38691837520849326, 16.58790349960327, 67.16910654498686, 48.09902914108769, 37.712153619335545, 32.786398010869185, 45.8816191457933, 25.66057320564024, 22.29502074180111, 14.825535512739613, 27.72520492153783, 73.30690983803042, 55.64046044503489, 69.82478649385514, 3.3812846003040193, 7.9050526695866745, 86.08852571056735, 63.3056660621397, 72.62383691726193, 60.752101098337484, 67.20303504697739, 59.92800328039355, 66.06168808475618, 59.94169235229493, 65.4128299990008, 63.82576450224846, 62.26940724157519, 65.84545566189674, 62.790996182349424, 57.71795165154242, 64.09514896331295, 58.20879313253588, 63.16874788653467, 57.49438439646075, 52.97002453957835, 46.61856974324873, 46.59423535869968, 53.798068261915645, 61.59944680429275, 56.68967877664874, 55.27062800622756, 53.832549818100475, 53.85215774659188, 47.47503103748445, 50.52734890291768, 49.16407031397666, 57.68698453903199, 54.13523520192793, 55.51547804186421, 52.15022171697309, 53.941140636321045, 54.30197908032326, 52.15794094147221, 52.898103960098766, 50.533063796258745, 50.39607501799061, 52.99413927139775, 50.184588663039676, 52.16276545678416, 48.75871296851866, 49.90028350583969, 45.394582363866995, 48.866130998057706, 49.089572737293864, 50.71821535787275, 47.959537890649614, 43.553578699788744, 56.85761505557645, 72.84391326289024, 65.53176802973594, 40.12869842590825, 35.648849625741285, 43.081278262599824, 42.911674976348884, 43.42604675600606, 45.34164997839159, 43.47808876345235, 39.836979989082586, 37.98131058293004, 37.768937772320164, 42.75004194628808, 42.17334762696297, 40.91778909006427, 40.11942594282089, 39.82162783222814, 40.00324533831689, 36.470139026641846, 39.41492511380104, 53.95824217027234, 46.54518611969487, 42.55690051663307, 43.30307652873378, 48.8342813522585, 54.25103533652521, 53.549138961299775, 51.57257426169611, 52.07458273057015, 52.02184646360336, 53.898139692121944, 49.88983038933047, 55.20371629345802, 55.46607578954389, 54.43643400746008, 52.857405447190814, 53.01640656686599, 50.74934720993043, 54.52080026749642, 51.53731607621717, 53.116199508790054, 51.40664623629663, 55.48676629220286, 53.37473077158774, 51.07892828602945, 49.96328461554743, 51.38416713283908, 50.32860240628643, 50.09860246412216, 50.73700351099814, 52.509259793066214, 56.359976107074374, 55.9069658863929, 52.7690109129875, 52.372451443826, 49.25627346961729, 49.04441841187016, 52.139109642274924, 53.17289736963088, 54.87393125411003, 57.8312885376715, 61.169311846456225, 59.29320689170592, 61.58863282972767, 56.36647155207973, 48.376517218928186, 60.58334112167359, 61.641220046627915, 66.71899103349256, 59.74096898109683, 60.13212342416087, 59.76830790119787, 70.89198497033888, 65.32757336093535, 69.98241870634018, 0.7354735799374119, 9.876831096987571, 58.667631995293405, 59.17149182288878, 26.721129148237168, 5.66369072083504, 27.165610174978934, 14.060414452706615, 18.2634949299597, 35.00955820083618, 53.37661743164063, 52.591908054967085, 33.64633452507758, 42.81644767330539, 69.71939240732502, 32.356616066348174, 0.12689404535077273, 0.12836121097807923, 0.015477333706052554, 0.1189629745579535, 0.20860172748084993, 0.08270691359235395, 0.09269758112608426, 0.060164914316227364, 0.18749402866007822, 0.07164835779657287, 0.122275025463633, 0.08695130882364127, 0.041613183585145784, 0.05063068962866261, 0.09829530898000925, 0.1444799843574724, 0.3347260306679434, 0.31245150332970006, 25.09898393384872, 78.90590498524328, 56.57878552713702, 42.145510565850046, 34.55965057496102, 60.2933132263922, 28.283905367697443, 24.584670989744126, 17.98491054965604, 35.43294668197632, 77.39848321483981, 62.1091470410747, 81.02612649240803, 7.292752054429824, 4.294066227251484, 84.19555848644626, 68.96503433104485, 77.54339125848587, 63.09972201624225, 71.3522280416181, 64.5298142586985, 68.26612287952055, 59.549302362626605, 66.55818170116794, 64.69974702404392, 62.673254474516845, 63.88239176042619, 64.35588067577731, 61.516425917225504, 66.1291685412007, 60.26614689057874, 64.33435078590148, 59.77171251850744, 57.59786044397662, 50.28302838725429, 50.894400381272845, 54.72721107544438, 63.76434410772016, 59.58134812693442, 60.84229207807972, 56.226054622280984, 57.28217240302794, 52.19853355038551, 51.54287799712151, 53.41643341125981, 60.64644029063564, 55.85097797455327, 59.76846871837493, 54.192996025085456, 58.53626789585237, 57.846574014233006, 56.01220700048632, 54.81161655918245, 54.85666105824133, 52.369301780577636, 53.909534177472516, 53.72105644595239, 56.84531450271607, 52.596081456830426, 56.55564746549053, 50.20815818540512, 52.7977579639804, 52.37469896193474, 52.51048357255998, 51.34193497319376, 44.5306646439337, 56.16319471789945, 63.536725044250495, 48.393061776315015, 33.82218614701302, 37.47053561672088, 38.1262735397585, 43.85185533954252, 43.09088022478166, 44.32921955662389, 42.61490844911145, 40.56549749066753, 38.42870789189493, 37.77252281865766, 43.81359261851157, 42.36357473557995, 42.497402083489206, 41.91656181889196, 40.996667954229544, 39.783192526909616, 33.67300271987915, 36.43681064728768, 55.62264111734206, 45.09982409015779, 40.71299822099748, 43.51433538621472, 51.49273441683862, 54.48744443155105, 57.02621813743346, 53.56140421282861, 55.287913891576956, 53.80656803807905, 55.63654199723275, 50.77644294308078, 56.99224256700086, 55.01542291333599, 53.91260147094727, 57.92507633086174, 56.999487184709125, 55.096333565250525, 55.93428519464309, 51.61557520589521, 54.09108892563851, 52.35872707059307, 55.23563261955015, 54.742304355867454, 53.728987478440814, 52.24529996995003, 53.216376842991004, 52.09481823828913, 55.19703257468439, 57.26410204364408, 57.02766156965687, 59.031647559135195, 56.83664214226508, 54.214890695387325, 51.95701752939532, 50.58806327081496, 52.53329999985234, 56.78503944027809, 57.35760742618192, 58.728820969981534, 59.58968708592077, 63.078611819974846, 64.45151198294856, 67.89108937786472, 65.66197502997615, 55.2995829428396, 59.497546688202895, 65.2408262222044, 70.69260304973972, 65.80623980491393, 63.33820212271906, 65.3053217549478, 73.27190660661267, 69.69983546964585, 67.04584213995165, 0.6201353044279161, 16.747534159691103, 69.81239964885097, 66.0601975840907, 34.93751995025143, 4.493373622817378, 24.10201745648538, 19.734069954964426, 30.862908863252212, 47.328679561615, 62.15450140737719, 50.40308429348854, 28.03301488199542, 49.59060061362482, 71.95460211846137, 48.75180567464521, 0.3442979622031412, 0.18422013659390712, 0.05852445577000899, 0.14161283901381877, 0.09854714506335797, 0.0334951835083625, 0.03837908978664106, 0.30957809138682585, 0.3327148966491223, 0.1350850957415758, 0.2738368108628258, 0.1957512000996259, 0.25878247834982415, 0.2153826015250337, 0.2447434421628714, 0.31435152395598354, 0.5077660486342446, 0.37174244922014976, 31.544199066777384, 92.87092347298899, 64.64521431153821, 54.16470789140271, 48.82920188288535, 70.92020250135853, 42.947474448911606, 31.531708278963645, 27.977315264363444, 39.39397965708087, 87.56509411719539, 66.5163927693521, 88.41769187681138, 5.097948149327309, 12.669418434942923, 90.66956381643973, 67.53227095450124, 82.60575125294348, 66.22998914410992, 76.65790834734517, 67.08166906910559, 72.1773535205472, 64.14504543427499, 71.37075731831213, 66.39891778269123, 64.95823121839955, 62.42796513342089, 64.76911021817115, 62.413091505727465, 68.99321263836276, 63.69320800227504, 65.08173881038543, 64.32903205194782, 59.38854009874406, 53.400543889691754, 51.76242874514673, 57.541998047982496, 66.0485089209772, 62.13917278474378, 63.34481523882959, 59.710111694951216, 59.76063574514082, 55.584252880465606, 55.79679827536307, 55.230082465756325, 63.93679895708638, 59.40796759820754, 62.84621138726512, 57.055639836096, 60.39857787470664, 61.58549885595999, 57.01900882105674, 59.55310706169375, 58.425131459389966, 57.56252381109423, 58.69675167145268, 58.612789415544086, 59.033016466325336, 54.58901812953334, 60.41292982716715, 54.15091683787685, 55.39335504654915, 53.964674857354936, 57.46761029766452, 55.41199022723783, 44.810639504463445, 54.25934683892035, 52.95811230136503, 41.114829355670565, 35.83174974687638, 38.26044997861309, 39.367974342838416, 43.929894816490915, 43.8569857997279, 45.796193845810436, 44.955794657430346, 44.70239385481804, 41.578751610171416, 40.10368547131939, 44.04101556347263, 43.52412954453499, 42.392180581246656, 44.722696042829945, 41.30916710822813, 41.235438316099106, 36.407294811741004, 37.1884544434086, 56.479404434081054, 48.817944680490804, 41.67352391827492, 44.62132630809661, 56.08481007237589, 58.37328164808212, 61.02605119828255, 56.13649122176632, 58.31382636101016, 56.56335492287913, 59.27023356960666, 53.9195401437821, 60.09016583042761, 56.20889033040693, 58.66473336373606, 60.601325188913655, 59.82417029719199, 58.37752957497874, 60.72699792923466, 54.539725703577844, 57.565638173011045, 55.1147843945411, 57.909308402769035, 57.36014127731324, 56.24929466555196, 54.97552456394319, 54.56187532794092, 56.41808994354741, 59.166996786671305, 59.12974211477465, 61.46959673973822, 63.471743137605735, 61.6053617385126, 56.877368111764234, 58.30880180481942, 53.67240336633498, 54.037678011002086, 58.824307149456395, 60.279510405755815, 61.2428915885187, 63.370640124044115, 66.09053319500339, 67.1957786621586, 69.94426188930389, 67.75074697309925, 58.41749852703464, 64.09636882043654, 69.80653178307318, 76.63495463709678, 67.97105081619756, 67.03801308908771, 68.51834697108116, 79.2495987492223, 70.58728741061303, 75.40236549992716, 1.5379788726568224, 12.258557023540622, 74.65480096878545, 71.30326901712726, 41.43247073696506, 11.365040117694486, 34.73934219729516, 21.304043723690896, 27.007546501774943, 45.18696738827614, 62.65648241966002, 74.02682165945731, 45.262900552442, 58.939970001097656, 86.0419201081799, 57.84208682275588, 0.6552942049118781, 0.20641984778546518, 0.148327752887722, 0.2270297886383149, 0.2852184565797929, 0.15323411703350084, 0.15370915283358869], [0.04841452749866632, 0.16275367879819486, 0.13720306838231702, 0.16590354122942494, 0.07057095472250255, 0.14379648071142936, 0.06837311741565505, 0.22922861419858473, 0.07727307492807027, 0.1988061902023131, 0.38508721056484413, 21.63853560724566, 70.09347669539913, 47.46684112856465, 45.14731222583402, 34.7473555995572, 48.25619066915205, 21.152518641564157, 17.330476814700713, 4.016816188250819, 29.564410178892075, 66.53878165829566, 57.99100352871803, 65.3120211632021, 54.77475412430302, 0.022503970671565305, 31.44201740141838, 78.55160513231831, 64.35468435287476, 64.44472236018028, 61.360052785565784, 62.68611984868204, 61.42563089247673, 61.41638586598059, 63.024094796949825, 61.919892680260446, 69.11697910678002, 64.68683850380683, 60.91195729471023, 65.35956813443092, 63.173031114762836, 59.77510536870649, 56.714930995818115, 58.691323111134196, 49.39532933696624, 46.47688588788433, 51.35343928490916, 51.41316913789319, 56.92689587993007, 55.43348089341195, 60.602662717142415, 59.02477164422313, 52.89079266209757, 50.897789309101725, 48.89373663933047, 51.79767516351516, 53.40437604535011, 51.63385345089821, 54.863215338799264, 53.329223432848536, 57.06129589388448, 58.18400375304684, 54.96686397060272, 49.81812946258053, 51.89139627641248, 49.34127123125138, 51.04652166366578, 53.5689861543717, 51.36995246333461, 49.80990425232918, 47.11997416711623, 43.77652622038319, 46.150815333089525, 45.659083474066954, 47.309412879328576, 42.722361779982045, 52.07879143376505, 80.60561703097436, 101.02582131662678, 134.0585480966876, 105.73807054950346, 49.75337505340577, 45.063655914798865, 45.61712588033369, 43.21953396643362, 42.72632337385609, 45.63142291961178, 42.480806535290135, 46.41650099908152, 46.16374738754765, 41.03893933757659, 39.955949398779104, 33.29286621462914, 32.405580974394276, 35.20433525885306, 36.64848919837706, 43.77057206246161, 39.19204035112935, 50.3684615319775, 57.260085536587624, 53.550064640660445, 45.653376425466234, 48.661802968671246, 52.36906643836729, 49.94455922034479, 48.829480371167584, 50.02682308996878, 48.375717055413034, 50.29629776554723, 49.4947261195029, 51.38483001339821, 54.40419996938398, 53.426176578767844, 51.944748355496316, 51.34111519782774, 53.988562091704345, 51.70704880068379, 52.08628316079417, 49.80849612143732, 51.755537140753965, 54.947860087117846, 54.7474269713125, 51.22823722900883, 47.06631614315895, 48.45057941252186, 49.68321561813355, 51.19872139346216, 54.65807930115731, 55.034540545555856, 53.08317315193915, 54.91408455756403, 54.140957940009336, 52.23070875290902, 47.578667902177386, 50.21561068873252, 51.43139246971377, 51.59254697061355, 58.91581212320636, 58.77902338581701, 57.508034244660415, 64.42857003981068, 61.743574296274495, 63.74339472862982, 56.26626676128757, 52.833349550924, 61.83641287588305, 62.2946673054849, 62.965851522261104, 58.015941958273615, 64.7798575124433, 64.16686557954358, 79.18023555509507, 39.365640532585886, 0.3856500093975375, 37.45170431752359, 48.68040677039854, 68.24058824969877, 22.127382563006496, 6.150129831606343, 34.152371268118586, 34.84434012443789, 27.0249657477102, 44.140086789284986, 43.46127356252363, 35.16293464168426, 31.882721185684208, 47.11953878402711, 61.743358565915024, 50.0429714879682, 1.2324927939522652, 0.2653851143775448, 0.22704192347103552, 0.1308219696605398, 0.13910739442273495, 0.2108220035029996, 0.03407936002458296, 0.10949860176732464, 0.17887233726439938, 0.12781511286213515, 0.26971985435774254, 0.12109551053013533, 0.032042119644522186, 0.0495470812424056, 0.3558317223383535, 0.02421652192189809, 0.45715000660669425, 0.3360110665521314, 32.95099243041008, 84.82226694783857, 55.25123188572546, 49.110557417715754, 35.91394693620744, 60.51928489438949, 18.51463448616766, 19.598267693673414, 13.093952248173377, 31.249848719566103, 77.18463559304514, 64.87947002533944, 69.99648432577811, 65.85644614311957, 0.4032381623983384, 23.099906790641047, 87.07534697748001, 69.16229817175096, 73.89095075668828, 65.22826287054247, 68.26980990748253, 63.703531680568574, 61.5402582383925, 59.21043311395953, 61.11575972649359, 64.59983641101469, 60.668538924186464, 60.64642852352512, 67.25743832126741, 66.76453759593349, 63.65328219629104, 59.34079308663646, 62.026043784233835, 51.58895800190588, 47.342023464941214, 53.46929127170194, 57.57929586595105, 56.260245923073064, 58.13385625039378, 63.07573280026836, 65.29685335774576, 57.641943962343284, 55.8201991358111, 55.200629388132405, 54.83020467142905, 53.232438948846635, 51.520010579016905, 55.338975306480165, 59.835482412768954, 60.72471903216455, 58.5006017838755, 59.122654391873276, 59.43298839753675, 56.172600561572665, 53.71678890720491, 50.512490964704945, 53.529009357575454, 51.739882961396255, 54.21695386209796, 56.318806909745746, 52.20605665637601, 51.18846439546155, 51.24544858932496, 53.49307260205669, 46.869079759044034, 55.132435060316524, 78.80713970430436, 99.32852545092183, 121.41496043051444, 71.18268751328992, 36.88981694559897, 44.807874233491965, 43.63257131268902, 43.71183456913118, 40.84968497676235, 42.32739871548068, 37.749592642630304, 45.718374021591686, 46.949264772476695, 44.317303396040394, 40.76915479475453, 38.55499252196282, 34.431275321591286, 35.460418962663226, 35.99710902860088, 41.76003963716569, 38.99655726648147, 40.94577912361392, 48.347134743967366, 52.86355180125083, 46.42721299202212, 47.844526152456964, 54.01870550647859, 52.88869811642555, 53.144475875362275, 52.8508472442627, 53.895233215824256, 55.88942504698231, 55.30142253445041, 55.6172792373165, 55.26956504391086, 55.33271520368515, 53.664378196962424, 54.683578629647535, 56.35196270481233, 55.198860399184696, 54.38486268443447, 51.75148533236597, 51.76303671252344, 51.55058153213994, 55.91397908426101, 55.90956641781715, 54.39473921252836, 53.84833735804404, 53.22641811063213, 54.941980454229544, 62.01545730713875, 64.66136663190781, 58.562657602371715, 59.88621434857769, 56.03927527704547, 51.72452688217164, 50.64691451288039, 52.1779489517212, 56.19311455757388, 56.27362120536066, 59.88279404178743, 60.8874346363929, 58.8817031921879, 67.64648252917875, 68.84379386901855, 72.02697769288095, 66.34823291532456, 55.40498879648025, 66.94106778790875, 68.10413683614424, 70.94579204436272, 64.4486447303526, 70.389160648469, 70.50444695257372, 84.13177290270406, 34.13022164375552, 0.2509913794816502, 45.93549290011006, 54.332632403219904, 79.64462849401659, 28.50039666698825, 7.979100644588471, 24.64943128247415, 38.397179880449855, 29.291354379346295, 59.658356020527506, 51.88150013646772, 49.23812466282999, 32.09577844988915, 56.59096448652206, 67.05454195699384, 69.09726527429396, 3.5125859418222984, 0.49563421897830506, 0.23883593899588432, 0.2525943265326562, 0.0771374007566802, 0.03539681291928695, 0.16251628347221883, 0.3181708706242423, 0.46609913930296903, 0.23308859417034736, 0.24111122013099734, 0.24641758942556, 0.11170597686882942, 0.1639205532809419, 0.5559025091990348, 0.17579185175559214, 0.5542504559120824, 0.6133231280311462, 35.59080246956118, 94.09763689964049, 63.512159239861276, 64.15603591549781, 47.10634393076743, 68.26232602519374, 38.99489025915823, 30.89041840645575, 14.842484074254191, 46.50069859720046, 77.68470641105407, 71.82176713020571, 75.17988866375339, 65.23674303485502, 0.22845272034887346, 39.389672894631666, 84.83164925729075, 73.64879931173017, 74.68334013415922, 68.77424240112305, 67.94020529716246, 65.84988794019146, 67.42203666317847, 64.9481507270567, 63.68817560134396, 66.14682705171647, 66.99598097032117, 63.1816642515121, 68.45111754632765, 68.69400639687815, 66.28025824023833, 64.009084316992, 65.03170897883754, 53.37948860660676, 49.78972758016279, 57.46937144187189, 57.351131593027425, 61.85677782181771, 61.06245471585182, 66.39333232756584, 66.86790773945471, 60.307657334112356, 58.187431904577444, 56.44128291837631, 61.597077692708666, 59.119630244470414, 53.86401114925262, 60.17332792282105, 60.82879127994661, 60.81711046157345, 58.72398860992924, 60.39382788442797, 60.153355213903616, 61.10608323927849, 58.167212086339156, 55.11967951251615, 59.25629346601425, 55.33850069968931, 54.70341405560894, 59.364570494621034, 56.28624731494535, 54.98596983571207, 53.104808945809644, 57.450559754525464, 48.6036067624246, 56.91814899444581, 78.58438045747819, 98.70356636662638, 100.96515009480139, 55.086260918648016, 37.782517017856726, 45.80652144647414, 42.734929054014145, 45.82708251091742, 42.78981477983537, 44.79203178036598, 40.16262692789878, 53.38081436772501, 50.87717333147603, 44.5732694287454, 38.043652734448834, 38.420698412003055, 34.49254274368286, 39.652765873939764, 37.73177331493747, 43.727900597356985, 41.63294699884231, 42.79232117437547, 45.25345156269689, 50.39392163676601, 48.62823924710674, 51.09225649987498, 60.23849418086391, 56.76955000046761, 55.283728722603094, 57.41424645147016, 58.56552485496768, 60.21130431082941, 59.36448812484742, 58.38836316139468, 60.33718493676955, 56.569383605833984, 55.51951416077153, 56.82340022056334, 59.59634334810319, 59.23527348426081, 58.78552275319254, 52.46220311810894, 54.836719728285274, 54.64445298717868, 57.583932107494725, 59.95235335442328, 57.33730131579984, 57.32284345934468, 55.795288162846724, 58.974149534779215, 64.78294049539875, 66.97381173410724, 62.18037336103378, 63.05649357457315, 57.2572692748039, 55.61211739816974, 51.76852803076468, 57.95781243231989, 58.78010595998457, 57.5852539462428, 64.83904215597337, 62.965247477254565, 62.05295124361592, 70.58938195628505, 72.36253646112257, 73.36114052803286, 65.62123729336646, 56.86587556715935, 69.54799267553514, 72.77169458327755, 73.08165596377465, 68.6777913185858, 73.4450557154994, 75.55119591374552, 83.11600454391973, 47.57208616502824, 0.5255053048172306, 44.01286079037575, 63.095658440743726, 81.92808335827243, 36.554979893469046, 16.164562086905203, 41.89765207229122, 47.17895092502717, 41.035585711079264, 66.76542405159243, 49.67865782399332, 52.70145985387987, 48.87055935398225, 63.33303243883195, 79.05027174180555, 80.64962602430775, 5.356158268067145, 0.4928948724221799, 0.5538024476939633, 0.4385807401230259, 0.2730211417280859, 0.21280027234986906, 0.294287589288527], [0.0767839660928134, 0.20005070003530673, 0.07254012244483156, 0.18969365095178928, 0.03551898096057196, 0.05266427385410475, 0.029829651973540747, 0.2843259028609722, 0.05577830252267661, 0.1413117204943011, 0.17005860294786193, 24.407119020338982, 80.5913866719892, 41.04124569123791, 38.220983089939246, 16.944244946202925, 42.26475061908845, 31.99630714231922, 26.633821110571585, 12.800056895902081, 5.870634480830162, 39.20430560265818, 72.12629995038434, 53.71470220627324, 66.65990444921678, 27.4439670578126, 0.5786273123756532, 47.89082973234115, 73.32980079035606, 70.30366866819321, 62.512182343390684, 66.56965855629214, 61.80501430265365, 56.89899606089438, 56.420874826369754, 63.09681161757439, 59.935016478261645, 62.935915993105986, 65.67570332557925, 62.84428550351051, 65.51761611815422, 57.87020629452121, 56.2668864957748, 56.90782531615227, 49.32328716401131, 46.98407188538582, 49.89874593673214, 62.11921576530703, 67.41669439500379, 62.25891882373441, 56.97261894902876, 60.225342473676136, 55.95499923152309, 54.70578316719302, 52.3372442491593, 53.74352378229941, 52.9111615304024, 54.420662156997196, 54.009460479982444, 57.52467686130155, 57.563606385261785, 55.51872968673707, 56.34962104981946, 56.94955541241554, 50.33587840295608, 57.71122870906707, 53.505333931215354, 51.80091504127749, 49.52886642948274, 50.250484481934585, 45.658185251297496, 47.39705039608864, 43.220298828617224, 41.675881262748476, 40.07631517225697, 34.98046990363829, 45.81276585978847, 62.546746269349136, 69.17310822394587, 70.25394085914859, 116.4768454336351, 100.93756798774966, 47.33986616134644, 47.215476036071784, 39.532529538677586, 39.554675240670484, 39.905174316898474, 50.10614518196353, 46.21381252042709, 44.71848341726488, 49.83857285591864, 41.734414792829945, 35.48275686079456, 27.55569184980085, 35.13974558922553, 37.64721878113286, 36.072140047627116, 60.35858931079988, 86.82335038338938, 74.93106134476201, 58.66811836919477, 50.97923732572987, 42.884347823358354, 43.125918757530954, 45.76146125793458, 43.506580860384055, 45.475575385555146, 45.41551997584682, 49.94549666681598, 48.416486170984086, 48.13204373082807, 48.25416672614313, 50.73798410354122, 49.93987983272922, 54.004271184244466, 53.29223940449377, 53.453954804328184, 55.21220822488108, 54.12302878595168, 49.608027704300426, 53.04521245341147, 56.15925273587627, 50.32664122120027, 49.54229270258258, 50.46899187949396, 48.10400662883636, 49.76540888509443, 56.6367660030242, 57.66990653930172, 56.1096739768982, 55.48752330964612, 54.62149143218995, 50.85056004985687, 52.74335468969038, 46.94202799950877, 51.0084197598119, 58.144842809246434, 58.67897156746157, 59.28663299929712, 57.94595118491881, 56.85046065238215, 60.442186786282456, 57.679594793627345, 64.03821576026179, 58.12625469699983, 65.24974961434641, 63.950586088242076, 66.80059986729776, 63.16229166523103, 70.5397012156825, 63.79784114899174, 78.61436305507537, 9.96955200549095, 1.316370964050293, 48.76849143735824, 46.84444727436189, 70.79646741190265, 16.193665092991246, 6.001069959132902, 22.63520790684608, 21.148617844427786, 36.152317216319425, 41.472769168115434, 50.752308599410526, 43.609472474744244, 37.34276048598751, 47.78139168216337, 59.16662808387511, 63.40543546984273, 5.476515216212119, 0.2998979882367196, 0.23156927327715585, 0.09121906973661915, 0.13681101522618724, 0.11665918729117802, 0.04352683291560219, 0.05667208198217615, 0.19738359557044124, 0.19495612340829066, 0.22110186156726655, 0.04370597108537632, 0.06722434559055875, 0.022239155143559463, 0.1621449300118031, 0.04514888236900011, 0.3826525218544468, 0.09946569214544951, 30.280123103049498, 90.6639862060547, 46.596894725676506, 50.267334984194854, 24.975772480810843, 45.348906363210375, 41.88038579879269, 26.533604552668912, 28.92594833527842, 16.074131842582457, 35.881202990008944, 77.49233768832299, 58.836105638934725, 72.13832593733265, 38.68412087040563, 0.26626182539809135, 40.645737417282604, 80.45649636176326, 72.25915847286102, 69.46526204386066, 66.8048438718242, 60.69892944828157, 56.30272911440942, 54.132779798200055, 61.19850604764877, 57.73430793516098, 59.08088114953811, 65.22823933632144, 63.60048709377166, 65.80984838547246, 61.283319457884765, 63.98080010567943, 59.89901304244996, 50.92719531828358, 52.3952914053394, 57.5640300012404, 62.83828427714687, 71.24142108425018, 63.68422969695061, 58.253912156628026, 62.36999250227406, 61.94021448012322, 55.190839152182306, 54.58767275656424, 51.69935311040571, 53.65049300655242, 56.663285147759225, 60.256223294042776, 61.966513972128595, 58.06711712191182, 57.24156410463395, 58.59559374470865, 56.92123197740125, 54.68028776107296, 58.2318135230772, 54.146308052924375, 51.431082602470156, 49.84466037442608, 51.81556117150092, 55.457995706988925, 52.79068200818954, 49.05267892345306, 49.86311120371665, 47.24707857255013, 35.271607829678445, 49.99019599729969, 70.28055021839758, 77.72312210452172, 81.13878480849728, 123.77793742764382, 77.26928818610408, 41.13282911239132, 47.70867093916863, 40.44637903090447, 42.25614101656022, 41.16784411091959, 47.54239774519398, 46.24322637434929, 45.03980790415118, 46.13547886571577, 41.26587983100645, 36.693706281723514, 32.319528095183834, 36.511963259789255, 35.4611446011451, 38.41736439735659, 40.849261360783736, 65.83157047148674, 74.4502728985202, 59.09654709600634, 48.78675791525072, 42.52660020705193, 45.415496441625784, 50.89997799165788, 49.323765693172334, 52.593708422876176, 51.39349452910885, 53.76338274248185, 51.60204302880072, 51.61145279484411, 53.27321983152821, 54.25806030150383, 54.51941174845542, 54.47239429719987, 51.66129435262373, 56.636777770134714, 58.377549186829604, 58.09981399966825, 53.64335037046864, 53.34736439489549, 54.41088368815761, 53.27729909650741, 54.443631556726274, 54.69399644482521, 49.74592255007837, 55.922274897175456, 63.9185756252658, 63.15193660797612, 66.87788624917307, 59.84045990051762, 57.20512136336296, 52.04050517851307, 55.816751372429636, 49.557895891128055, 53.629598540644494, 60.13461020685012, 55.48485217555877, 56.358030611468905, 59.24724455802672, 58.81413644359958, 66.79230013201314, 64.32105395101732, 70.06191730499268, 61.32297854269705, 65.54764578419348, 68.31143409975114, 71.55885850229572, 69.84016218493062, 73.44431830990699, 65.49157158021005, 82.960906182566, 5.794913124653601, 2.5642144439681887, 51.52825540111911, 50.306037010685095, 77.79090066109934, 18.67084680065032, 12.723512822581878, 29.675527003503618, 24.102101787444084, 28.347820389655332, 56.38260426059846, 59.0251011233176, 52.00603931180893, 44.81855092510101, 55.79047149227512, 64.50899431782385, 73.30629010354319, 7.989679767239479, 0.8532974736825113, 0.23456458513054157, 0.1023735857057956, 0.13262327219690048, 0.14927918812440288, 0.07864648671520334, 0.2585564824121614, 0.351524377662328, 0.27473742382660993, 0.31671046189242796, 0.17259698931968984, 0.17874280711816204, 0.1381611226186637, 0.39241655759753724, 0.12914998276579764, 0.6603880767380038, 0.36007664617030855, 38.714664366937455, 103.85770197837584, 57.76844432277065, 54.53315965590939, 24.879978395277455, 62.257793103494954, 46.42740911053073, 34.591284490400746, 21.633246291068293, 20.251979712517034, 50.3617032881706, 84.22054398444392, 63.41437455146544, 79.30523364774643, 34.59470871956118, 0.6733170055573987, 60.7615343986019, 77.6352688574022, 74.64951361379316, 71.65239918616511, 73.0060326668524, 63.82447404246177, 59.621293544769294, 56.68519158517161, 63.095156377361675, 62.43280141584335, 61.86264176522533, 68.74822924214025, 67.64644330547702, 68.3895912478047, 65.09305092596239, 64.46310650917792, 63.21021126162622, 55.91295142327586, 57.359097926847404, 59.90349238918674, 66.20636078619188, 71.78711691210347, 66.41600362716183, 62.92938132439891, 61.89264005230319, 61.319013026452836, 59.300710385845555, 58.45210167669482, 55.89474378093597, 55.55375645237585, 59.56310910563315, 60.53043227041922, 61.55031127314414, 60.9585040615451, 60.454028421832675, 59.30677437013196, 60.916311125601496, 58.89338008819088, 61.45883375598539, 58.323153757279925, 58.16503517089352, 54.79939445372551, 59.69888587151805, 55.69917832651446, 53.52694619086481, 49.930450454834975, 58.93261947939473, 50.97094543518559, 39.069568264868956, 51.153551378557765, 78.82869705077141, 79.99119343296175, 92.01901605052333, 116.29099569013043, 61.71077935926376, 42.78950491259175, 48.3450754996269, 37.7390806905685, 40.63894387214415, 38.66060233885242, 48.41377189082485, 55.79604125791981, 52.037367282375214, 49.887469122486735, 43.558697392863614, 37.26468178533739, 31.754596964005504, 35.304500825943485, 36.440348625183105, 38.48779055380052, 40.176696469706876, 55.893982841122536, 68.06012784281086, 61.05440601225823, 54.089720018448375, 46.118722500339636, 53.40542724055629, 57.68175601959229, 52.48352119999548, 57.55958987820534, 55.052603060199374, 58.270170380992276, 55.111826927431174, 53.8208140865449, 59.873705910098174, 59.85914999438871, 55.26658796495008, 55.31418200462095, 55.875555546053, 60.402241368447584, 60.756278422571, 58.21238602361372, 54.104628947473344, 54.044416642958126, 61.57232361455118, 57.07284727404195, 57.122445644870886, 56.9687593367792, 55.677264044361735, 59.54687441548994, 67.5787353515625, 63.079506120374134, 67.51492623359927, 62.39318939947314, 60.283844624796224, 53.73809522198093, 56.42379306977796, 52.792011691677956, 54.59384264484529, 63.4275850942058, 60.183071090329086, 63.12517427629041, 63.795879963905584, 65.19169461342597, 69.43079225478634, 67.22059942060902, 72.26457134369882, 60.523470063363355, 71.3212570067375, 68.90968968791347, 74.61980558210804, 72.42068952129733, 78.01079657769974, 66.86057290723248, 88.31893444061281, 13.377696506438719, 1.7937573670379579, 59.59668067193801, 59.17360990278183, 84.98072285805979, 27.009807748179284, 19.010857459037535, 31.00902499691133, 31.37784154184403, 47.0723016800419, 64.76718825678672, 65.20146131515503, 61.34023697145524, 53.38072023084087, 64.42177649467223, 74.84296491069179, 88.51826144802956, 13.30732330199211, 0.7494697611658805, 0.363832438184369, 0.23367609167771958, 0.2737821121850322, 0.33773430472900795, 0.18340376265827688], [0.16023786137661628, 0.19203098520876902, 0.15907881631245538, 0.12501927498247356, 0.06523591075693408, 0.02244214929129568, 0.045381267479951345, 0.03205074962498921, 0.05980503302247775, 0.07994852209043118, 0.2236355901245148, 18.914074936220725, 69.97389147358557, 51.30677092459894, 34.25326639606107, 20.310405377418768, 49.29226906068864, 24.913114578493182, 37.541554051060835, 15.802492018668884, 8.955360439515884, 5.428417151974094, 33.64019209338773, 67.39101071511546, 54.844278135607325, 66.9520974928333, 5.751255673746909, 0.8016223917084356, 58.06685040074011, 67.81070432355328, 68.18486705903085, 52.846320829083844, 54.985369713075706, 58.31149255075763, 65.12377877389231, 58.40577456258959, 59.07831199707524, 63.31428743177845, 64.61985226600402, 64.1959224977801, 62.25728711774273, 59.163466653516224, 61.69112828470046, 48.966771171938994, 50.23919590057866, 50.85219567821872, 58.37764332371374, 55.125535611183416, 59.65930915647938, 55.1181419434086, 53.513821940268244, 63.251423605026744, 58.43785562822896, 54.58993204178349, 52.11150007863199, 50.92340238632695, 53.04758548736573, 50.53634682009297, 57.02056600201515, 55.591297457295084, 54.2446889415864, 57.99951507199196, 57.86455415910291, 50.74020024268858, 55.75800603435886, 54.5711438886581, 49.44173097610474, 50.37144253330846, 50.19288839832429, 45.79520540852701, 45.615243142650975, 44.6944510552191, 42.950788851707216, 40.939581778741655, 35.2106188958691, 25.98758709046149, 31.28555601642978, 34.85336942057456, 35.47709688063591, 41.77419939348775, 38.21495048461422, 72.3229048329015, 65.72392102210753, 40.39734155901017, 45.03294375634963, 41.240407959107436, 45.2105486777521, 46.97270485662645, 49.36867683164535, 48.982495953959805, 46.01548963977445, 40.034604687844556, 38.80421992271177, 29.50385270580169, 35.38275603325137, 35.84412482477004, 71.42016349300262, 111.7501618785243, 71.34439114601382, 52.57300223073652, 48.60525808026714, 33.72015353172056, 24.874283113787254, 32.847567373706454, 36.987299611491544, 38.44879827191753, 42.81693012483659, 46.56549615244712, 46.01457964989447, 49.80265178988057, 47.93686266868345, 49.1425286569903, 50.90988197634297, 53.02792264569191, 51.63311604530581, 52.947651340115456, 53.5642675430544, 54.57420725976267, 55.52394643906624, 56.29664159590199, 48.722187857474054, 51.46670164600496, 50.14917358275383, 50.84549626996441, 51.66697394463324, 49.16001850558866, 54.136125579957046, 57.92712380809169, 57.87063775524017, 63.74056669973559, 58.59545253938245, 55.39025637411303, 60.11690855026246, 53.200969772954146, 48.831488624695815, 51.92384996721822, 54.65354896360829, 51.843429611575225, 55.78363872343495, 58.2042706397272, 59.14480401623634, 61.1350695548519, 63.544801204435295, 64.25036499577185, 62.6832486737159, 60.92341846035373, 67.75953308228524, 66.57360446068549, 65.5718977989689, 66.95631796313872, 69.82963454338812, 54.55820398945963, 0.1353583746259251, 14.53349740274491, 60.99415840641145, 58.92588476980887, 58.158924118165054, 5.733132852661995, 7.630035684954736, 28.770277307879542, 32.204853680826005, 34.07376696986537, 34.26746145371468, 55.15992303048411, 51.589950361559474, 21.84587601692446, 31.748199578254457, 58.55239275963076, 65.31775959076421, 5.220442789216196, 0.5543479022960509, 0.18342075448843742, 0.21964212699282556, 0.35415742185808, 0.024233793374150995, 0.12936928309500217, 0.14523534705081295, 0.20644718180260352, 0.18966689916147342, 0.10297351682017888, 0.0713957249817829, 0.056299728777019255, 0.139262251435749, 0.021298111889571435, 0.05632481815653944, 0.08984178154458923, 0.13128634151672164, 27.18028964534883, 77.83452526215585, 58.26784833785027, 37.526994212981194, 21.013360792590728, 59.5414105538399, 21.373732474542436, 30.843824571178807, 16.102394480859083, 20.649149110240323, 8.6181434892839, 31.24430248814245, 76.6432700618621, 58.41005779081776, 72.61930265734273, 11.662822538806546, 0.6493688518962553, 47.68552895515196, 66.45506258933776, 72.60915940807712, 55.070908761793575, 58.01400822977866, 59.070847726637325, 64.78611761523833, 58.53150613846318, 59.67724223290721, 60.78982253228465, 61.91712348691879, 64.15369426050495, 63.49663057634908, 66.60546195122504, 64.61411776081209, 54.05236336492724, 55.49330096090994, 54.886851541457645, 63.405133447339466, 59.335541032975726, 59.674763294958304, 56.814735704852694, 61.92741970862112, 68.08043003082275, 61.3450183406953, 55.96108282766035, 52.188935510573856, 51.73460345114432, 56.41073942184449, 53.92697695762881, 60.15522226210564, 57.895831138856956, 55.51160274013397, 59.67303745208248, 56.661504391700994, 50.79186178022816, 56.312480126657796, 53.95452768571916, 49.09995917351016, 48.935109799908055, 51.2752389907837, 47.67759400029337, 51.37192541553129, 52.290787696838386, 47.94049870583319, 48.28783242933212, 38.69959462073542, 32.11031867611793, 38.660857292913626, 44.635458607827466, 55.52621356902584, 56.69835898184008, 50.85347829326507, 82.69790341777187, 55.289486762016054, 44.40623921732749, 45.364831186109974, 42.438158604406546, 41.24939410917221, 44.144707341347974, 51.368842432575846, 50.697101239235174, 44.42230916792347, 38.98732008472566, 37.425938267861646, 29.49603738323335, 37.672808324137044, 36.580028149389456, 46.71502867052632, 93.33771690245598, 89.30510459407684, 64.95347338338053, 53.676639526121086, 43.293749132464015, 32.221398238212835, 38.126959954538655, 45.28906668386152, 49.121249798805486, 53.71450216539445, 51.08507856245964, 52.07212340447211, 54.6130387244686, 53.844211024622766, 53.3253324416376, 54.70818758010865, 53.39089878143803, 51.92818026388846, 54.58314241901521, 56.132290363311775, 56.258284737986905, 57.160869183078894, 59.463657409914084, 54.821226366104625, 52.477006143139256, 52.33725993863998, 53.37475038343861, 52.54636149252615, 50.84058546250867, 57.68793767498386, 66.17861393959292, 67.85869844498174, 66.5745536742672, 61.97506081673407, 60.456134734615205, 62.3601395084012, 54.7716829084581, 53.75632639854185, 52.314463123198486, 55.326031484911525, 54.82040266836844, 56.73926538036716, 59.526254515494074, 64.90727962986116, 64.10248379553518, 69.98375231219877, 67.94216648224862, 65.46770788008168, 62.36373632184921, 70.39462058774888, 67.63498213983351, 69.24236943644863, 69.09226817469444, 77.76273019852178, 50.00404588637814, 0.1771119131796783, 20.078040246040594, 68.48898410797119, 60.67095118184244, 62.27973091986872, 6.724118205808825, 20.898860923705563, 32.45375944722083, 31.57443661843577, 35.187312172305205, 48.27272738179853, 62.61858840142528, 47.75923029068978, 30.688537936056818, 36.274726544657064, 61.89145157414099, 77.38820660498835, 8.830228986278657, 0.9676997123226043, 0.20974264690472236, 0.08023755174250373, 0.1279747655855552, 0.07110576836332198, 0.11902269877253041, 0.23649013180646206, 0.23406940121804518, 0.1888233444262897, 0.2504653375475638, 0.17379089138440548, 0.19395403443805634, 0.17452357787518732, 0.1845427975058556, 0.5378525583974777, 0.373064563759873, 0.5664112130480429, 32.62652220264558, 89.93106780513641, 67.3575685870263, 49.3583413862413, 26.744065207819787, 77.06576424260294, 40.43804399428829, 45.54240865092124, 24.589373911580733, 19.026947021484375, 17.38518995623435, 42.73538797132431, 80.8795867427703, 62.13214781976516, 78.84320982040899, 8.06715589377188, 1.5332393011739178, 69.17143729425246, 67.6243289824455, 71.39809623841317, 55.02285188244235, 60.56111697227725, 59.86510807468046, 66.26146224237257, 62.22269573519307, 63.96394568104898, 65.62784648710682, 69.69748204754245, 68.06492882390177, 70.53931682340561, 68.58818084962907, 66.1799789244129, 57.35085310474519, 59.07306778815485, 56.04582171286307, 63.26554413764708, 60.01337758956417, 65.34829916492586, 63.17134841795891, 64.95951775581607, 67.77520687349381, 63.41379796305011, 60.0096905616022, 54.385168629307906, 56.52366445910547, 61.148307554183475, 58.98625004676081, 62.5806983055607, 59.582571906428186, 60.153610167964814, 64.26358730562272, 59.74984922716695, 53.99306105029199, 58.752386569976814, 58.36427980853666, 55.05155186499319, 58.12252452296596, 59.17975233447168, 54.43708904327885, 53.84357560065485, 55.38434143989317, 51.54957740537582, 51.4820263462682, 45.71967232611872, 34.88956113015452, 43.31826786841116, 51.32642592153242, 66.49667893686603, 61.771011275629846, 63.65090131759644, 90.16837120056154, 53.13668997057023, 44.61525055669969, 44.203021218699796, 39.97321174990746, 39.68045388498614, 43.5145511165742, 54.67559660634687, 55.80407034966254, 46.72588971353347, 45.71665602345621, 39.79438304901123, 29.3668855005695, 34.90603508487825, 37.86076438042426, 47.00120872066867, 84.45423095457016, 82.98293421345373, 67.27260220435359, 54.73512249608194, 51.24535445244082, 39.86191841863817, 43.891259470293605, 50.88872863400368, 54.35638235461328, 53.821763300126605, 53.26186064750918, 54.26879582866546, 57.51680074199554, 59.97096107852075, 58.69617116066718, 60.79384296171127, 57.44550381937335, 55.81331537615869, 57.563912330135224, 58.81709391070951, 60.67415183590305, 61.46079101870137, 63.97394772498839, 54.80731371910342, 57.99933464296403, 58.580947614485225, 60.017947150814926, 57.59250640869141, 56.0851199396195, 60.494695555779245, 66.18998096835229, 67.87128925323486, 69.49564472321542, 65.33670463869649, 62.26286472812776, 62.55124522793678, 58.97607149616365, 55.8191518629751, 56.04181697291713, 60.25394047460249, 58.17958324186264, 59.867053570285925, 65.02257770107639, 67.68078757870582, 68.54931016122141, 71.47033060750654, 71.19687864857336, 66.96240548164614, 64.83175831456339, 73.96512277664678, 72.39794761903825, 68.08133217596239, 73.51861584571101, 75.51987971028974, 69.93737420728131, 0.2745900591534953, 17.29263770964838, 75.81477918932515, 66.93395260841616, 73.83071884032219, 15.657184873857807, 18.9856287740892, 37.50582125879104, 46.81866553521926, 50.07480544428672, 54.82371707116404, 70.86830169923844, 69.50360713466522, 29.712801287251136, 45.401054274651315, 69.83116426775533, 89.45607662200929, 12.833230341634444, 1.1113613002723264, 0.3816682214458143, 0.18986019846652785, 0.45716682989751145, 0.24789045474702315, 0.2574833770913463], [0.04238896635210803, 0.34202522447993683, 0.10790357606545573, 0.09122113051313548, 0.04096437606119341, 0.07305609798359294, 0.06646163611402435, 0.12078862336854782, 0.04279818370818131, 0.0742366471357884, 0.19030886552026197, 21.061172523806174, 76.6952100876839, 36.51252808109407, 42.29407818086686, 23.49959827238514, 40.597241232472086, 51.23449733180385, 68.23914481747535, 54.730466642687404, 17.336248582409276, 7.217700933256458, 9.079377939624171, 61.75907550319549, 58.879004601509344, 59.34750818437146, 50.30565261840821, 0.3713796912662445, 2.010913017776705, 35.446749502612704, 51.98369749130742, 57.92369957893126, 59.95460087253202, 67.677673216789, 51.7311909890944, 57.85267722222113, 63.71185495007423, 60.0972221743676, 59.6868912635311, 61.03156605074483, 59.9194799700091, 61.056943785759714, 56.73782194814375, 52.58841714551372, 51.94275186907861, 53.7059513984188, 55.6562715191995, 69.99235014761649, 74.57993861167662, 76.63278164402132, 56.48462118641023, 54.04507560114707, 65.36013295573574, 55.87848163420155, 54.72490864415323, 50.98017477220105, 49.55879803626768, 51.835082807848536, 52.44218726311961, 51.168099449526885, 55.12181720426006, 51.38621853243921, 52.067710738028254, 53.347380084376184, 53.64733549856371, 50.90838363093715, 50.53321676869547, 48.09257291978406, 44.638419997307565, 43.60651500763432, 41.64949155622914, 42.19633271617275, 37.34458438811764, 31.198228366913337, 21.02147029292199, 25.131794560340143, 25.174836689426055, 26.257224544402092, 15.905650354200795, 10.250213280800851, 30.197086526501565, 30.6386532322053, 51.71886297964281, 45.54830005092006, 45.768760788825254, 38.77122102245208, 46.93764671202629, 43.19831394380139, 48.53460834872339, 51.03123618710426, 47.33480630382415, 44.764304545617875, 42.55745749319754, 39.679598808288574, 41.23631692701771, 49.08387353343349, 81.13517622793876, 43.96058344071911, 34.65287746921663, 28.402107954025272, 21.61784706577178, 20.280012892138576, 18.96740151989845, 17.945208318771854, 26.194456815719608, 32.61265074053119, 42.008537477062596, 41.84246040159657, 46.765301689024895, 46.5556666927953, 46.76532914561611, 49.665219783782966, 49.31289288305467, 50.140862080358694, 50.04112012924687, 51.669641156350416, 51.204652017162694, 53.477002651460715, 54.75572278422695, 52.377970218658454, 50.32660199749855, 50.87627903107674, 51.84467692529002, 49.36474269436252, 49.579629744252856, 50.11679833935153, 55.19127061290126, 59.14247412835399, 64.00466772817796, 60.00876488224153, 56.999632312405495, 58.16666295451503, 74.06406848661362, 63.38870263868763, 49.31966681634226, 49.42346842058244, 48.235923782471694, 54.238319012426565, 56.71944956625662, 60.012569581308675, 60.85283540910291, 64.23704854903683, 62.25193700482769, 65.69021217284664, 64.25649958272135, 62.375813299609774, 65.84361214791575, 64.06582140153455, 70.10420830019059, 60.24482488632203, 76.54310841714182, 8.7257311613329, 0.04989020053237196, 45.88595336483371, 57.353892941628736, 64.06733543642106, 30.36459722826558, 1.5937954259495584, 15.575663312788933, 25.636128994726366, 24.752589618006063, 35.188955645407404, 39.767255936899495, 47.92014552700905, 46.99510551268055, 31.35709220363248, 31.379800765745102, 54.62655913445258, 67.35383449062225, 7.013106672994553, 0.622468072800867, 0.10411211499764074, 0.10309222980492538, 0.03696443948654398, 0.1572458743448219, 0.03933801736322142, 0.10928647968197062, 0.1631829331839277, 0.2217933325277221, 0.1686060542781507, 0.01161188290890066, 0.06164504981209194, 0.13834179679472602, 0.19394516313989318, 0.10403811090415525, 0.13964777752276392, 0.30003655822046343, 27.69441431568515, 86.13462924957277, 44.34322634050923, 45.06906878563666, 21.52230008955925, 50.80293855359478, 42.757157125780665, 69.58120730615431, 52.56943679624989, 16.43410736514676, 9.944346854763648, 12.741100730434542, 65.4083388851535, 68.9251438263924, 65.04922236165693, 59.77075153781522, 0.7958775902948072, 0.5384088608045732, 30.01411580270337, 46.55331327069191, 63.353295403142134, 65.70196751625308, 66.56794840289702, 53.29588328638385, 58.93334511787661, 66.07384743229036, 60.78049121364471, 62.27047020389188, 59.725354025440836, 62.28987024676416, 65.3122212040809, 60.4589549187691, 56.75005189834103, 58.26269042107367, 60.415871604796386, 63.191521167755134, 78.1596819047005, 79.84436342793127, 80.19016742706299, 59.88881488000194, 56.66760759968912, 67.73039771664527, 58.143430755984404, 56.47299920358966, 51.51327586943104, 51.178689848992136, 57.5211977189587, 58.04222968316848, 55.98797851993192, 57.05752257377871, 53.97295105841852, 52.40169271346062, 58.719670080369525, 55.883714076011415, 53.892311050045876, 54.66613584949125, 50.40816768523186, 45.53272431896579, 48.80753471005348, 46.59725950610253, 46.77825727770406, 43.2396557254176, 39.043719845433394, 25.07854446288078, 31.25088618647668, 27.62645729126469, 33.25396806963029, 21.366393719950032, 24.49801994908241, 37.56062461483864, 29.922528459179787, 54.681064390367084, 44.48346676365022, 46.472292792412546, 41.64216456874725, 46.966931127732806, 42.46544261132517, 45.38939306812902, 43.22820240451444, 41.29532506389003, 40.77644255853469, 41.98755671901088, 40.245549755711714, 42.92176723480225, 40.99009013945057, 77.66542403928696, 63.627845625723566, 46.7515577039411, 44.46696927470546, 40.846539235884144, 27.842736782566195, 21.637451071893018, 22.707240273875577, 37.13072892158262, 42.30844582280805, 47.244642780673125, 44.777354271181174, 50.57322102208292, 49.37419168410763, 52.02532560594621, 52.50575319413216, 50.527290067365094, 50.20709130071825, 53.76983896378548, 54.385400049148075, 54.61608640609249, 57.7758889813577, 57.75383741624894, 55.86414144885156, 54.38735338949389, 56.26098725103564, 51.00161444756293, 49.454474756794596, 49.429501025907456, 51.3889955705212, 59.33676873483966, 63.216993039654156, 68.54992989570864, 60.63533213830764, 59.99050232671923, 61.79498087975287, 67.45802048713931, 63.35823758955925, 50.07027118436752, 49.643560455691436, 51.073393821716316, 57.53602427821006, 63.43542591218026, 62.224347053035615, 62.90137560136857, 64.11335268328267, 63.692580423047474, 64.56806129024875, 66.01617290127662, 62.11516003454886, 64.86967978938934, 67.11789608001709, 70.24166384050923, 67.79329684472853, 73.65847972131544, 2.3008461633036217, 0.07298888142911658, 58.553942095848825, 58.27306901254962, 71.87183226308515, 29.26108348754145, 5.840248859697773, 18.979009774423417, 15.708266881204421, 27.119214419395696, 33.45563673203991, 40.476036071777344, 49.649428321469216, 43.22591174033381, 30.161349811861594, 32.22067259973095, 60.43654641797466, 78.12276455663866, 9.811460875695753, 0.6325757142997558, 0.28635168448090553, 0.08592065243471055, 0.018225005722694823, 0.020832225094519315, 0.06235488773053212, 0.17639010513742126, 0.3442249999892327, 0.12285791112170105, 0.3482291883518619, 0.12261117718392804, 0.16507156974365636, 0.11208229457899449, 0.20483344823362368, 0.21368496600658665, 0.2802396818034111, 0.6178542623116124, 32.22703076178028, 104.34446811676027, 51.55396653759865, 63.647955617597034, 35.447302556806996, 61.157493745127034, 71.04988390399565, 79.00143823316021, 65.34493769368818, 27.5319673938136, 17.259797665380663, 20.294596264439246, 71.8564095035676, 70.68228721618652, 71.75035645884853, 62.028322681303955, 0.33496823702608386, 3.004016818538789, 48.36238884156751, 54.28112776048722, 63.5262680053711, 61.41349507916359, 70.03823403389224, 56.579350348441835, 64.60342537972235, 68.60323490635042, 65.00249124342396, 65.98549996652912, 64.70597182550739, 64.23197300203385, 68.18664781508907, 62.649649650819846, 57.99844818730509, 61.82413977961387, 62.56078050982568, 66.09709139793151, 77.3512343437441, 75.00986960626419, 73.66176666751986, 56.468547313444084, 63.117517809714045, 68.419644448065, 61.59748561920659, 58.90337820976012, 53.36677620487829, 53.902681796781486, 56.306898593902595, 58.077178001403816, 57.033753010534475, 58.48388856457126, 55.179950652583955, 58.88184831988428, 60.314058642233576, 57.63574269510085, 56.72192458183535, 58.76081574347712, 55.72489338536417, 49.684141297494214, 54.354985990831935, 49.86568427854969, 50.58578829611502, 46.63007405496413, 46.55391339332827, 31.145876492223433, 37.43491657318608, 35.75969188444076, 36.947895480740456, 31.162252387692853, 38.69964168917748, 50.220764683138945, 44.385760522657826, 60.77128541085028, 42.349018819870494, 47.540326733742994, 39.981052567881925, 48.963825471939586, 42.997480746238466, 47.27210721661968, 45.38249754136609, 48.28781673985143, 43.50461575292772, 43.519418777958045, 40.85341907316639, 45.870342331547896, 38.42347937245523, 71.53078217660227, 64.49318324365925, 50.80231097436721, 46.00739779010896, 50.8464180269549, 36.30281463746102, 30.43771020827755, 28.994683950178086, 45.839771378424864, 48.084383010864265, 53.151606744335545, 47.77065223263156, 54.37267588030908, 52.733909622315444, 58.31002558431318, 57.44573131684334, 55.057521712395456, 53.35764884948731, 56.640931560147195, 57.414760281962735, 58.434690275499904, 60.96575652399371, 59.969886349093535, 59.05042786752025, 55.62716361015074, 60.07628064001761, 55.081840407463815, 52.2943413642145, 55.63267061787268, 53.151822474695024, 60.89702483146422, 64.4975959101031, 68.89231358805011, 62.163283594193004, 61.859758823148674, 62.27181557686099, 65.11396500372118, 65.01462705673711, 53.366289830976925, 52.5170535425986, 55.893876937127885, 59.410548517780924, 64.86033278126871, 65.80531020318308, 68.82563329512074, 68.72132178275817, 68.0493099458756, 68.68929170793103, 70.38329278269123, 63.97131973697294, 69.49501714398785, 67.23645364084553, 77.21697161274572, 64.99558787192068, 82.5310536353819, 14.218885071815984, 0.12147957338921486, 57.83925094912129, 66.83614438579929, 77.96722688982564, 43.56444366516606, 11.007307210276204, 26.134497504080496, 33.948298192793324, 35.94061513100901, 47.49175210152903, 56.51088145471389, 58.60340710609191, 61.05566509308354, 40.03584807918918, 41.64499259764149, 69.21316346814557, 92.6376130503993, 17.233527591151578, 1.0800953521843881, 0.3889325429354945, 0.2230121171282184, 0.22129591163848678, 0.21324939905635773, 0.11901558947659309], [0.08591968716392595, 0.14848165995170995, 0.07845303419256404, 0.029825641503257137, 0.08337249078096882, 0.08343239885664756, 0.052468354528349255, 0.08687081596543712, 0.07009872280421757, 0.15099606777150787, 0.36449507359535466, 20.95958705871336, 70.64177697704685, 44.958469713887865, 47.66348915715372, 26.675810083266228, 43.75743604475453, 27.51557973123366, 82.8357276608867, 88.16729560975106, 16.70202289858172, 5.321481573966242, 14.84813326789487, 36.86518053854666, 58.74066260553176, 51.59940327367475, 67.96268047824984, 15.427024114516476, 0.6655196400900042, 2.097533537495521, 20.020963876478135, 46.13906391205327, 58.44733991930562, 58.6669808818448, 52.57702658253332, 62.24977970123292, 62.327834867662006, 62.524051435532115, 61.86144151995259, 62.01089951299853, 61.44665871897052, 59.64861677538965, 58.135036883815644, 49.999570462011526, 52.09923874947333, 63.02223559348815, 74.40538529426821, 71.95818716479887, 69.68387926778486, 82.9156106518161, 94.98268835006222, 71.51837964211741, 57.770303526232325, 66.38726834327944, 56.50249934965565, 54.29970410562331, 54.16957947515673, 52.190363253316576, 54.247838604834776, 57.496090627485714, 55.70188083956319, 55.837771354183076, 57.31854454163582, 54.45486522489979, 49.41130515067808, 48.25880296768681, 36.7657406099381, 40.2377873851407, 43.42916504029305, 41.870850516903786, 38.24802390990719, 32.58850855212058, 27.876937889283706, 22.512653450812063, 29.692250028733287, 30.26719693214663, 28.98911222334831, 28.536806068112774, 24.663926401445945, 12.95251157975966, 17.741686336455807, 25.309189634938395, 33.0184454302634, 42.18714652522918, 45.42873051858718, 42.15075085240026, 45.88369407961446, 45.20700285511632, 42.709931788905976, 44.585883771219564, 40.70087809716502, 43.061713480180316, 44.62899454178349, 48.18066935385428, 44.962854923740515, 53.09772122290827, 35.0855972689967, 30.635644774283136, 18.005797170823623, 7.318590177643684, 14.937932991212415, 19.938264623765026, 22.35491337314729, 18.39678099078517, 20.501666030576153, 23.444806683448054, 27.866543608327067, 37.67541670030163, 40.0046181678772, 43.08937403463548, 43.23619619492562, 45.84603932596023, 45.601052007367535, 49.25396711595597, 49.40715528303578, 50.35449789416406, 52.03488049968597, 55.118008582822746, 52.86675637768161, 55.985636864939046, 52.178490238804976, 51.91611113086824, 49.01777767365979, 48.92080099351945, 51.89052551023422, 53.97679105881722, 58.518087710103686, 64.59710251900458, 59.40986602537094, 60.923763628928896, 55.06391517577633, 74.05732985465758, 102.00019298061248, 63.31219288610644, 53.143495282819195, 45.919976003708385, 50.70643255787511, 55.39655570060977, 60.45930008734427, 61.400413974638916, 63.33416600381175, 58.76186301631313, 64.12892841523694, 63.09545839986494, 61.06897761744838, 63.55752929564446, 58.87849469338694, 66.95059914742747, 61.04429021958382, 68.70421240406652, 27.766046600957072, 0.7858252909875686, 6.597734535894086, 55.035128901081706, 50.7969137930101, 62.81118069925616, 14.917770047341625, 4.462890432726953, 16.071064549107707, 29.67586824970861, 26.76945470994519, 29.425607304419245, 43.01626105462351, 48.38918647458477, 34.74502963404502, 37.35672020143078, 43.449820241620465, 56.191906467560806, 59.65550053504206, 3.572225335144228, 0.8384285650907025, 0.06448492242564118, 0.10079703804466034, 0.07959123400430526, 0.11346034119806944, 0.06149946246296168, 0.05915320328166408, 0.22518043706734336, 0.021738509024162928, 0.07822229617064999, 0.0651797182076881, 0.027795087155555526, 0.23671268034846554, 0.14281884526773808, 0.13582309888255212, 0.19469839610880424, 0.2601523661325055, 23.32059306483115, 80.53397886214718, 50.353411397626324, 50.028596001286665, 32.51446008682251, 51.65668556767126, 44.703582332980254, 109.83420956519343, 109.02475003273257, 18.23220422191005, 7.174658804170548, 21.334253818758075, 39.5571816352106, 66.30438081679806, 59.22787589411582, 73.7220613418087, 21.983510025085945, 0.5007352613874021, 0.4755019186244857, 18.68274138819787, 45.39383711353425, 59.31165379862632, 62.41486049467518, 57.86557397534771, 65.91530522992535, 63.95658731460572, 66.17227538939446, 64.60299784137358, 61.818789666698834, 64.9503747109444, 62.415037001332934, 61.98376455614644, 56.65191811899985, 56.60954083165815, 68.56762762992614, 81.84889854923372, 69.70349896338679, 69.57817923638129, 81.61660009814848, 94.7720492270685, 73.5715913772583, 56.0470062686551, 65.70575260346936, 59.206251867355846, 53.29527531900714, 59.577696400304, 57.52398260178105, 59.19412389878304, 57.17646060451385, 56.29380964463758, 57.386621198346546, 61.7307795247724, 56.800364140541326, 53.27959368305822, 49.071012081638465, 39.65165976555117, 43.554312183010964, 49.98692081820581, 45.19413355858096, 45.686163517736624, 38.795174937094416, 37.81235056538736, 25.98463550690682, 28.88463204906833, 30.899259428824152, 32.06568602592715, 30.991662625343572, 31.27852712908099, 14.484973761343188, 19.589105036950883, 25.98388437301882, 36.24959984133321, 46.067257081308675, 46.165273189544685, 41.42972507784444, 43.18475823248587, 43.35174922020205, 43.19558397416146, 44.7560126550736, 41.47296528662405, 41.004242051032286, 40.845558643341064, 46.44839379095262, 43.53708121084398, 55.76785118349137, 39.344961797037435, 32.036389843110115, 31.561300600728682, 21.21827521631795, 22.93069181903716, 20.21071049474901, 26.734210252761844, 18.453914234715125, 23.78266199942558, 33.389293762945364, 37.121758460998535, 44.33466772879324, 46.54003212528844, 48.66062233524938, 48.39916890667331, 50.484461707453576, 49.92854026056106, 52.813796535615005, 55.94536981275005, 54.48391037602579, 57.04003664755053, 57.30401608251757, 54.65657703338131, 57.22867127387755, 57.87667036056519, 54.466946125030525, 53.1380118093183, 49.30718975682413, 53.10121213236163, 55.69991180973669, 61.66631144862021, 64.32579217418548, 63.43302934400497, 60.23583481388708, 61.3112820348432, 67.19922250316989, 96.86658705434492, 66.21603335103681, 55.821069901989354, 47.227670684937515, 53.697322184039706, 55.66853284835816, 62.419222170306796, 61.49752009299494, 61.38592866159255, 59.18175666562973, 64.95621512013098, 63.50817018939603, 63.203872711427756, 64.52486422754103, 63.122687493601155, 65.21436199065178, 63.869436171747026, 69.56871847952567, 17.607376537015362, 0.8478832545299685, 12.80641015498869, 65.75314267989128, 60.6871231140629, 69.26575460741597, 18.14387244562949, 7.8123268581205805, 11.41325585303768, 22.092373448033488, 29.57987608448152, 23.35766926888497, 30.913927132083526, 47.070873937299176, 39.66684326048821, 29.513440939687914, 35.23923650864632, 63.152015055379565, 71.95760665401336, 6.774815330582281, 0.6431442955809256, 0.27477367510718687, 0.1235703728912819, 0.03696219867936546, 0.0982923442197423, 0.03948229087156154, 0.2517536063227923, 0.2784865355539707, 0.16362603843933152, 0.3620020396286442, 0.14686748205173403, 0.1391058469251279, 0.27325489047554236, 0.20900738635851493, 0.21892514530449145, 0.29218559724188625, 0.4879099076553699, 30.402985465142038, 92.72689404026156, 60.166032314300544, 64.1472105826101, 38.567512727552845, 64.86004644824614, 36.64760666508829, 91.84035208917435, 93.70902415244811, 27.373213383459277, 13.923100117714176, 25.405285742975053, 49.67359404410086, 71.06670302729454, 64.57329373205862, 80.40492503873764, 21.48329015701048, 0.7748623276429792, 3.665426733993715, 32.64422385923324, 54.73625606106174, 65.16449297628095, 65.68567399055728, 59.86040123047368, 68.3092846408967, 70.46813364951842, 72.37875153941494, 71.2938553287137, 65.88327515509822, 67.58634474969679, 64.95132000215592, 63.09561529467183, 59.11805345166115, 59.692072714528734, 69.56345465875441, 79.40099439313336, 74.83143314238518, 79.27030886373213, 85.13393063699046, 79.47173826156124, 62.89836714344641, 63.71535370426794, 67.73339440745693, 61.70080869428573, 59.319235740169404, 58.39205018935665, 57.6901420470207, 61.614296897765136, 58.26214521161972, 60.92245355729134, 61.84741120184622, 66.40072207297048, 59.72279664008849, 57.07190198283042, 55.23624843166721, 44.149731897538715, 49.27362603525962, 54.41020904048797, 49.804907152729655, 51.10810287537114, 47.26558431502312, 45.19383545844786, 32.58537065598273, 36.988692052902714, 41.861279933683335, 39.20252484659995, 37.49129672204295, 43.22599411010743, 22.844015282969323, 37.49624675320041, 39.27445327081988, 41.04448949137042, 48.00498639383624, 46.84129761111352, 42.825939809122396, 45.81747270399525, 45.58086356809063, 44.69342731660412, 48.54425345697711, 45.949107446978175, 43.97308795682846, 42.38008006926506, 47.18267717669087, 43.26350765843546, 58.41709060053672, 46.37444534609395, 43.26583754631781, 37.56973235837875, 29.465289923452563, 32.10347610135233, 28.5200555862919, 35.990382163755356, 25.072249058754217, 35.22642604766354, 46.01745474723078, 45.0185251235962, 51.70470322332075, 51.59006411029447, 52.31321188711351, 53.04482806113459, 53.45127190313032, 54.903521614689986, 56.40895082104591, 57.07623227950066, 57.57365549764326, 58.66348605002127, 61.753858750866314, 58.437557528095866, 59.208056157635106, 58.673998002083074, 56.90479724637924, 55.866153624749955, 52.05885794854934, 55.96024344044348, 58.32877843610702, 65.01525463596468, 67.5505256652832, 63.57511328112695, 62.92100314171084, 63.514512661964666, 61.54506706422376, 101.56238586671891, 76.27993306806012, 57.80251403008738, 52.363296631843816, 55.833386144330426, 60.9478783607483, 68.09971240258986, 67.17093436948716, 67.3866568842242, 62.49207627388739, 66.01989915294033, 66.48610422688147, 63.09269312889346, 67.60545453717633, 63.52802130483813, 70.79509458234234, 66.30008189908921, 72.61905162565171, 35.66429984185004, 0.6478862572581537, 10.105507239218682, 69.24031411447834, 64.21159628898867, 74.48419355577039, 26.466371205545244, 11.614677406126454, 23.33902624345595, 37.97216753805838, 38.390068623327444, 38.68163408771638, 65.2219125532335, 57.545261459965865, 48.09882517783873, 46.52260111224267, 56.4936936286188, 68.93280029296875, 87.90340638929798, 10.921338662024468, 1.2408050317918102, 0.36492843421236165, 0.3508405062940813, 0.17731949236364136, 0.23491482520776413, 0.18208889531031733], [0.09603213969497912, 0.09444259152176881, 0.07677763820655885, 0.08469308846660199, 0.054877360141085046, 0.014995470147339568, 0.07356968332803057, 0.024254058314968022, 0.07270644013319286, 0.08427016962800296, 0.19505880983366122, 17.737230523940056, 73.53990647100633, 56.491061718233176, 43.66105948725055, 13.563058895449485, 42.78886556625367, 14.568947784362303, 18.47954692379121, 28.528816200071766, 10.675977737672868, 4.130458774105195, 29.34519087114642, 53.62198129776986, 51.01306384609592, 56.312927276857444, 63.44454934520107, 25.41617620375849, 0.2248553399957957, 0.049271707107583364, 3.9473358133146843, 27.995134592056278, 50.82659044573384, 61.93924173232048, 53.96145459144346, 60.71615257570821, 63.13500373594223, 62.85165563706429, 62.212046500175234, 59.45549887995566, 59.650848604017696, 58.19601797288465, 53.22446477028632, 47.524205792334776, 53.45528056544643, 60.83121138234293, 64.6196992935673, 58.995797095760224, 47.79935613755257, 35.11515625061528, 45.241723675881666, 76.21637498178791, 77.20773050861975, 58.671554365465724, 63.153721286404526, 61.974911766667525, 58.99242777978221, 58.98176677765385, 54.60375447427073, 53.23252131862026, 50.18975050218644, 53.032300010804214, 51.051593288298584, 49.28103539251512, 43.03386465195687, 41.56308174133301, 14.303691617904173, 14.090119542614108, 37.42035673510644, 35.181040302399666, 32.67610488399383, 24.168756584967337, 21.88295025979319, 29.83873094281843, 36.45301788083969, 29.59030566676971, 28.00081810643596, 31.099655282112863, 25.39432860189869, 24.61174907222871, 24.025829338258315, 23.29930636190599, 24.834543620386434, 33.798055725712935, 39.528822898864746, 36.80141064428514, 37.723528492835264, 36.533018542874245, 40.981798248906294, 43.32692453938146, 46.93762317780526, 44.102094711795935, 44.080219653344926, 45.112057962725245, 41.665435990979596, 40.6699933544282, 24.57590057003883, 23.479019557276082, 7.885653607306942, 10.486428218503153, 22.424670765476844, 22.889471630896292, 18.351050076946137, 17.90490400406622, 17.430346242843136, 15.729987986626165, 17.44470015648873, 23.28062411277525, 33.68558960576212, 42.04683157705492, 44.64203250023627, 46.877328503516416, 50.49660928787724, 51.46736844893425, 51.4094703428207, 52.68238929010207, 56.63192187586139, 55.06096555340675, 57.33216693324428, 55.28703920302853, 56.910684724007886, 52.29134075103268, 53.37811969941663, 48.725647387966035, 51.5017480234946, 53.034508305211226, 60.79258388088596, 59.21342980477118, 59.71541473942419, 55.833848984010764, 60.61790897000221, 86.38568447482201, 51.609346482061575, 55.71123177005399, 57.60565419350901, 48.50653594540012, 51.33798906880041, 52.78934840233096, 55.932453447772616, 60.35844026073333, 59.174802303314216, 57.78569490678849, 62.5539908870574, 58.49818560384936, 63.83884952914331, 61.657286074853715, 64.8077847880702, 52.90665472707441, 64.74313236051991, 35.933692147654874, 0.10949765181829853, 0.06433176612781902, 22.98433219232867, 54.292483022136075, 52.27944027992987, 53.90372906961749, 27.568404251529326, 11.37520690118113, 5.067352681390701, 16.136698549793614, 25.241560128427324, 64.07492130033432, 50.932874910293094, 44.95757541348858, 35.69396080509309, 47.026802186043035, 46.13238019327964, 53.81931574113908, 58.44090330985285, 2.3910060092326137, 0.3434889120680671, 0.12178885840600538, 0.0788472323948818, 0.05758916966677193, 0.07746417556078204, 0.24935135377510903, 0.062266672706051227, 0.08646991449378191, 0.12997207171734304, 0.13423939596020407, 0.06534723099321127, 0.13609636244514298, 0.10242142023578768, 0.16145397999113606, 0.08400483507542841, 0.12543742875418357, 0.774418609517236, 18.41052693705405, 84.95823983223208, 57.53000343999555, 42.62433390463553, 19.381152737525202, 53.599910120810236, 23.809665556876894, 34.46917326219621, 40.43673392265074, 15.43735367636527, 7.5234393919667895, 35.588711846259336, 59.277262456955455, 55.81346050385506, 66.3626358585973, 71.5199250559653, 31.358212040316676, 0.10846716396871114, 0.0704847162048663, 2.408927808846197, 33.152072737293864, 55.025001341296786, 63.07596422010853, 58.88727688020276, 67.4118463454708, 65.6488625464901, 63.45961124666276, 63.04665234781081, 63.53861562667355, 62.39436611052483, 60.52732967561292, 55.26212430769398, 51.317820241374356, 56.26723558672013, 64.01011590034732, 62.241209322406405, 62.54087448120118, 53.77229828988352, 41.41931118503694, 49.345632906883, 80.0292561131139, 83.32960113402336, 60.78547262376355, 60.86066445996685, 65.6008174342494, 59.8303048841415, 63.872326958564024, 57.3410903253863, 57.605787554094874, 51.81725171304519, 54.365525399484945, 52.87873529618787, 53.085961957131666, 44.20344091230824, 42.400617599487305, 13.746565022776204, 17.306407190138295, 41.170934938615375, 42.27978506395894, 37.289945771617276, 32.75126338005066, 27.241966955123413, 31.45477883277401, 40.10594083416847, 38.58892886869369, 39.506304571705485, 32.71935685988396, 27.80037714589027, 30.796760051481186, 19.11998368078663, 23.13583177904929, 27.49638169042526, 36.59735718081075, 42.11431987823979, 37.826718207328554, 40.43963255420808, 40.73852108370873, 42.611001768419825, 39.217880925824566, 46.282708952503825, 45.17487472103488, 44.11719975932952, 46.83972474067442, 42.074107739233206, 40.38999103730725, 24.980540121755293, 27.54655468848444, 10.651233465440813, 13.167966392732437, 24.061458187718546, 27.03889016182192, 23.017393850511123, 25.252140721967145, 20.17991400534107, 18.920429175899876, 28.10960896553532, 34.593477095327074, 43.462030579966886, 48.66585869942942, 48.834112690341094, 49.796442677897794, 55.90943305723129, 55.48831170605075, 53.833016580150975, 55.90001544644756, 59.200819384667184, 57.636895871931515, 60.195253972084295, 56.90489922800372, 60.72332659075337, 57.35853702791276, 56.76284666984313, 53.944639390514745, 55.42098422204295, 56.083174444014034, 62.56346341102355, 60.07293485826062, 58.806962428554414, 54.49594420771445, 61.97475094949046, 77.30211842444636, 55.754460211723085, 59.91888376974291, 59.87494537907263, 51.976143006355535, 50.87105835637739, 53.72014253370224, 60.03828856252856, 58.920915126800544, 63.54467568858978, 59.48487743254631, 65.9091627982355, 59.77922385738742, 67.60263043065225, 62.75479270565895, 68.00747394561768, 53.60196544278053, 66.77958380791449, 24.481671510204194, 0.21811540569028548, 0.10588285828670187, 33.28524112701416, 61.08592225659279, 59.35150507957705, 60.07993236664803, 40.35022604850031, 17.1091825731339, 7.241280751843607, 15.94853460788727, 30.20744158375648, 61.467772837608095, 51.351905638171786, 46.417505125845636, 39.16633313701999, 34.59195521570022, 42.431996560865834, 65.45491703094976, 73.71504814394059, 4.250999583351997, 0.25589987335185854, 0.25220530708470656, 0.06872052296755776, 0.04634974817294748, 0.1439742590751379, 0.10432726313029567, 0.15097861628859274, 0.21361577294526563, 0.15058852431754913, 0.24518795702005589, 0.1765225004524954, 0.1289959837712588, 0.16350919470912026, 0.23058756224570737, 0.2698221117738755, 0.30831753967269776, 0.8837150253595845, 25.994939573349495, 99.50904077099216, 68.13252695145147, 59.71177870227445, 19.39644213645689, 62.631983295563735, 21.42364267380007, 26.478807080176573, 32.99982201668524, 16.10606679993291, 13.37273863054091, 44.98536932852961, 64.18239424305578, 63.127535543134144, 67.2182067748039, 81.2488857392342, 34.03505709863479, 0.33895167972772355, 0.23995185330990823, 6.843872579836077, 48.561606022619436, 59.52907862201814, 69.7612205628426, 64.03026903829267, 70.00459578729445, 69.79450579612487, 67.78149051050987, 64.75547605945219, 65.70261078496134, 65.17435773726433, 63.71311010852937, 59.36087169954854, 52.118160263184585, 59.97913137558968, 64.49523856562953, 65.98168742272162, 65.47187343720468, 58.469258123828524, 55.109599021173295, 67.68882843755907, 75.2248860943702, 66.66784332644555, 64.68620700220909, 66.1498394320088, 66.31728541466498, 61.91550354803763, 62.547777852704456, 57.48162884866038, 62.07036656718101, 53.98232552313036, 58.81079458421277, 60.37166649295438, 57.18629790890602, 49.09764889747866, 46.78622361152403, 24.261995246333463, 30.03354918572211, 48.60159850889637, 48.37110434809039, 42.972008874339444, 41.90715989758892, 34.08629502019575, 39.74053675128568, 51.9226340324648, 46.83510418861143, 50.33425061933456, 40.83422691591325, 37.47158681192706, 39.20452133301766, 31.4974699097295, 33.712854000829886, 33.82928171465474, 37.08314664902226, 43.56980946756179, 41.4952600386835, 42.624859502238614, 43.099030909999726, 44.786928776771795, 40.39631389802502, 49.24154496962025, 46.737739193824034, 50.037299740699034, 49.20721638587214, 44.12498958649174, 46.52922991783389, 34.13599929501934, 40.49103129294611, 19.665626556642597, 21.666037305708855, 33.71026131414598, 31.611187265765285, 27.14086198037671, 31.769419600886685, 27.581387296799694, 27.945320490867864, 42.990259662751235, 44.91670431629304, 51.67522661147579, 53.36483070927282, 53.81740162449499, 53.91576290130616, 60.52544301556003, 60.55841053685835, 59.35395656093475, 58.81085341976535, 63.7787195944017, 62.15243431829638, 64.36117979788011, 61.701977560597086, 62.9935081543461, 59.994973828715665, 59.00587758710308, 56.551897679605794, 58.31220249975882, 58.433831276432166, 66.73435103508734, 63.605813672465665, 61.50785553839899, 59.01057658656951, 59.51535032641504, 86.62320752297678, 79.58463191986084, 61.60336917446506, 64.55032433232954, 51.14793846684118, 57.02135439841979, 56.842851254247854, 62.25619277646465, 61.801229215437374, 66.76252934240526, 63.44895416690458, 70.13084903840097, 61.38510888622653, 68.13477054719003, 66.4595890045166, 69.0665295816237, 55.38791864149032, 69.39239225079938, 45.25669144045922, 0.5199226688954138, 0.3551744801863548, 32.00616601974734, 68.98083363809894, 65.6850032652578, 67.88761415789205, 39.684019319472775, 19.132900045764064, 12.138879626028, 22.866888584629184, 37.956415299446356, 73.07006143754529, 64.24880781481343, 50.69772881846274, 46.32349767992574, 58.05451454654817, 64.01281449102586, 70.72662568861439, 86.52539145561957, 7.224736684753049, 0.7766244524428922, 0.2913997136056423, 0.20598328492093473, 0.1297915047935901, 0.25724680914032844, 0.3457580951433028], [0.043336421762022286, 0.18594069346304865, 0.3670004262558876, 0.09893719106912614, 0.06802549735913355, 0.12451475245818017, 0.09199366889773838, 0.0845062243001115, 0.08039779435362547, 0.054543989319955154, 0.290923114986189, 8.411486552607629, 69.90430078198834, 50.98464235182732, 47.81590853967975, 32.852746863518995, 40.903601877151, 36.24244936050908, 17.247952107460268, 27.98473050517421, 12.27870035556055, 2.283863526198172, 18.736081700171194, 61.68849245194466, 61.59608925542524, 49.98110002087009, 58.869088849713734, 50.22370253839801, 2.204106051114298, 0.26813414428503285, 0.04539224935034591, 14.111868104627057, 53.3705573697244, 55.930052957227154, 57.947335781589636, 59.69716002864223, 61.99210743750296, 62.40808656138759, 61.13592463154947, 58.50289244805613, 61.60731115648824, 61.496814066363925, 51.973648378925944, 49.19839105298443, 56.48705697828724, 61.45813557409472, 77.80746875270721, 66.11357319739558, 62.279126874862186, 56.8947010655557, 39.14992194021902, 33.19058256764566, 61.33255697065785, 79.08055243953582, 58.90214658552601, 55.71621318017283, 59.806562777488466, 55.64457501134565, 56.291338551429014, 55.37877559661866, 52.29234095542662, 48.703893922990375, 46.95793321055751, 47.202657730348655, 43.86611707748906, 43.30522598758821, 44.307975999770626, 40.1912013946041, 29.367571915349654, 29.842270881898944, 23.805041082443733, 19.095072707822247, 25.563686740013864, 32.541567587083385, 24.61565967529051, 18.52789405853518, 17.81931984809137, 27.32442302088584, 28.905789313777802, 16.53071142012073, 26.55674065313032, 26.329472641791067, 26.626674552117628, 32.589622505249515, 32.35338599451127, 37.40421618184736, 38.215213283415764, 40.17200139261062, 39.74421201213714, 44.79041184148481, 46.034952440569484, 49.33881582752351, 44.87224032801967, 43.71236801147462, 33.717168608019435, 29.7643510372408, 23.502983277843846, 18.160036533109604, 14.947647721536699, 19.46121027392726, 17.71484555736665, 11.596153032395149, 7.371566199487256, 12.359607085104912, 15.936281123468953, 13.52654359033031, 12.970281877825338, 15.923249048571433, 27.265001073960338, 36.83565685825963, 43.80112732610395, 43.99308027759675, 50.0961745169855, 47.63165127846503, 47.357140279585316, 48.262741027339814, 50.93161975183795, 51.91451864857828, 54.105570316314704, 50.9500745034987, 52.1444401433391, 57.46966561963482, 56.295959103492, 54.49704639373287, 57.02932073223976, 54.980596188575994, 61.115967612112726, 59.50792920204901, 53.84368542701968, 48.830276612312566, 62.781241247730875, 36.95970965969947, 39.324365431262606, 61.076014349537516, 54.48640108108521, 56.478247334880216, 45.363066119532434, 51.6387564136136, 58.049070296748994, 59.922284464682306, 59.192562795454464, 60.9302943752658, 63.04267898682625, 60.96761180508522, 58.03418882431523, 63.15752598547167, 63.040800171513716, 63.91681840342861, 43.386081726320334, 0.8678326743745035, 0.3042196434351706, 0.5907264760425014, 26.365911460691883, 50.82432723814442, 55.35808901632986, 58.163058296326675, 55.89436331102925, 26.011140923346243, 5.771492162058431, 16.066733271844928, 22.842938592357022, 44.592139951644405, 26.09538362872216, 39.15419340133667, 32.17928374967268, 44.87100478141539, 39.835944483357096, 57.43265021231867, 54.257860260625044, 2.324306594748651, 0.193159616582336, 0.23238226110416077, 0.06995328101179293, 0.10356344282627107, 0.08795811689548916, 0.2506621761788284, 0.03361214981264165, 0.1473946424741899, 0.30155886685655964, 0.13105904322958764, 0.033866161585695324, 0.11720361533544718, 0.010223095737127288, 0.09101584959294527, 0.20471709479968395, 0.2873802954150785, 0.6322519961864718, 9.540130919025792, 78.99104395220357, 57.036482980174405, 51.5357941965903, 37.848899210653, 50.74745662750737, 40.98221402014456, 26.071133575131817, 28.46779000374579, 18.9745774961287, 5.884160284073123, 20.781725222064605, 64.64962697798207, 64.07538414001465, 57.6760450486214, 67.41873402749339, 58.53398115404191, 3.896171436194451, 0.04721452737407339, 0.0751360726632899, 11.472165930655695, 56.479765292136904, 57.780148675364835, 62.840308220155784, 67.15357395910448, 65.50202861908944, 67.63745323304208, 63.0801768456736, 60.66385561420072, 64.66709721472957, 64.10699452123335, 53.01840697565387, 52.50161509360037, 57.3138298526887, 63.121667677356356, 83.15724434391146, 64.57071281248524, 62.66870844748713, 56.94366401241672, 42.94209687940536, 35.18685325499504, 67.41015972629671, 89.6843977897398, 62.857778456903276, 57.052686291356245, 61.76437070292812, 54.521106212369865, 54.93193134184807, 55.38321964202389, 54.502620081747736, 52.18691548993511, 50.33699627845518, 49.52484992242629, 47.20560343034806, 45.92945637241487, 44.291541268748624, 52.979618657019834, 35.26775213979906, 33.72726871121314, 30.652371721882975, 26.013564948112737, 26.55854690459467, 40.73155103191253, 33.62538514598724, 21.90090490925697, 27.42360603424811, 32.338471181931034, 31.10067902072784, 25.609876571163056, 31.73465563404945, 25.867456659193962, 26.33375587001924, 35.40602353311355, 38.76731434176045, 39.385217082115915, 42.54625128161523, 40.04759165548509, 37.08150709829023, 39.090788287501184, 43.52812251737041, 40.501186309322236, 43.85630330731792, 43.481803248005534, 38.571862636073945, 29.21904940758982, 22.527491777173935, 16.192177534103394, 14.183799470624617, 18.694624208634902, 22.752998644305816, 14.393095181834314, 10.204576503845955, 18.994601195858372, 21.2357376083251, 17.201466137363067, 17.153338655348747, 28.521196996012044, 37.44656993496803, 48.31685796860726, 48.962652683258064, 50.55244814965033, 52.73176408583119, 53.49986222482497, 50.583179919950425, 53.45281339460804, 53.72528868336832, 56.028551516994355, 54.0755053489439, 50.684710471860825, 55.61915413025887, 58.923751000435125, 59.06793340559929, 56.679382554946415, 59.1975873516452, 58.65988531420308, 64.34727107324909, 60.87804055983021, 53.56444797208233, 49.962225575600904, 58.58448559238065, 41.36564923870949, 45.4991017618487, 64.67754248649844, 61.71106176991617, 61.866909303972804, 48.7497385855644, 53.88862794445407, 60.19240633133919, 62.66044401353406, 62.465113901322894, 66.1771155941871, 65.38509884188252, 66.1635991065733, 61.308673658678615, 67.40605692709646, 64.173521841726, 64.43307684313866, 35.226696691205426, 0.3257858458786242, 0.1269520994936747, 1.8977745790635387, 37.94435008879631, 56.71412690993279, 63.61767491986675, 64.6285952291181, 63.877441729268725, 31.00361408725862, 8.072258407069791, 19.79648074796123, 27.46911141180223, 43.61007259738061, 29.85492248688975, 43.70275820455244, 41.31297572966545, 40.70189399103965, 47.18865094646331, 68.42948175245716, 69.52615291841569, 2.3902972859721032, 0.27851270511746407, 0.17384692305518737, 0.016027511240193443, 0.20501724804841703, 0.11538311463570404, 0.161351308887524, 0.1398556018548627, 0.24813446907266495, 0.3713995789087588, 0.2484971657395363, 0.13095073371885285, 0.18816394190634453, 0.13655834410700107, 0.2938054748360188, 0.5781768526761764, 0.38062854820201475, 0.8027912580197858, 13.279008692310704, 95.79564663671678, 65.56217424331173, 65.57211745169856, 43.760687689627375, 59.262894815014256, 51.14680097949121, 22.269817552258893, 36.76177509369389, 19.555070630965695, 9.410496584830746, 28.49640761652301, 73.0121829432826, 70.77548273148076, 67.0209272446171, 71.92300350435319, 63.89167601062406, 3.11520375551716, 0.2717186390392242, 0.21958653965303976, 21.496724274850664, 67.54182584824102, 62.723339219247144, 68.57186378971224, 70.48339951422908, 68.12583538793749, 68.80190295557823, 65.92414625229375, 61.57472802746681, 69.07407622183524, 65.11325113234982, 57.971313230453006, 56.2486082507718, 58.89378409231863, 66.44302091290875, 77.7241889892086, 64.34569035806965, 67.32918631645941, 53.25822461035944, 47.541338705247455, 49.569435504175004, 69.62963288830173, 68.5764451180735, 62.18442124705162, 63.809015981612674, 66.7411288907451, 59.76679386631135, 60.49926511702999, 58.32408728138093, 59.31305016240766, 54.17430985358454, 55.19152556696246, 50.08712168662779, 51.239180641789595, 45.29642897267496, 52.44178718136203, 60.77665905798636, 39.48803809381301, 39.36574643658054, 37.150725164721095, 33.0643371612795, 35.43456269848731, 52.31174492066907, 38.302231065688595, 26.037669874006703, 32.22208857536316, 40.42977563796505, 37.82491783941946, 32.13370384708528, 37.77149123530234, 36.10684517891177, 32.65934067387735, 38.065488569198116, 41.3789656854445, 45.522804644800004, 46.64452798904912, 43.36658754656392, 42.66647977213706, 46.305297882326194, 48.06999967944238, 47.309322664814616, 49.15380154886554, 46.8131624498675, 40.38383683850689, 36.71245521114719, 30.800339214263428, 27.477424875382457, 26.424768586312574, 26.08307326993635, 26.866527488154752, 15.457406793871234, 9.052149826480496, 22.986681692061886, 28.33491579178841, 24.747157135317405, 28.6198151880695, 38.879074435080256, 48.08507334801459, 56.432092805062574, 54.40308209388487, 53.35843332352177, 58.50491639106505, 56.681202534706365, 54.683900264001664, 57.7325193343624, 55.29057718092396, 60.451353365375155, 58.002464694361535, 57.52417087554932, 60.96454058924029, 59.34416240261447, 61.15388516456851, 60.59100935536047, 62.3100547636709, 61.909180687319854, 66.30045844662574, 62.56962937693443, 56.879419511364354, 49.38550772205476, 61.706951125975586, 54.06852745240735, 46.233647946388494, 66.01217208370086, 63.25145106161795, 65.98387610527777, 54.762041722574544, 60.03678237238238, 64.44332991876911, 66.7876874246905, 64.0912462049915, 66.09708355319115, 68.14514129392563, 67.13014956443541, 65.61376910055837, 68.27541105208859, 71.50721657660701, 65.43988650844943, 54.88400782308271, 2.168808641933626, 0.18171498311623452, 1.754280917586819, 40.35787467033633, 64.22431653545749, 70.65482278023997, 71.45555111669725, 68.73927054866668, 36.37626494130781, 13.95494878292084, 22.252129623966834, 31.54172601238374, 50.440068321843306, 36.20703820259341, 49.76032941572128, 46.31441347060665, 56.93246564557476, 57.61753897513113, 73.45724644199495, 83.74067337282243, 4.278360566785259, 0.6060191231869883, 0.2709921118953536, 0.1291061778582873, 0.2927162203817599, 0.2258855443928511, 0.3808819394438498], [0.158258872407098, 0.12432156806631435, 0.13131136194832865, 0.0589445056093316, 0.1484515680180442, 0.07433243876984043, 0.007571373360171434, 0.043907938675294, 0.18011945179633557, 0.12236592179584889, 0.30896598713532575, 5.424266794035512, 67.70148200373497, 58.011803857741825, 41.55564100511613, 31.239846675626694, 44.931695615091634, 38.443318720786806, 28.387095082190733, 33.22889627948884, 25.3111017903974, 2.392155508841238, 15.428696024802425, 58.629298671599365, 59.93522044151061, 55.294476016875244, 50.22063524492326, 46.757825651476466, 17.803816679985292, 0.21318399046938266, 0.10391842498774491, 1.4637499783308277, 37.43051567385274, 54.746207114188906, 52.3459283767208, 60.155955745327866, 61.68856305460776, 64.77087136237853, 59.36907337557886, 58.43160729254446, 63.07066117563556, 59.89147424697877, 53.987534430719194, 47.23168719199396, 54.19065829246275, 59.59371928245791, 66.44757870704898, 81.47943481322258, 58.79732908741121, 52.13357517796179, 59.071600821710405, 45.91807757654498, 31.086587905883793, 48.0768402930229, 74.64847810806768, 58.489972160708525, 52.454189715846894, 50.34675121307374, 49.92356277281239, 41.8470025062561, 49.96918778265677, 42.71516815308602, 49.751531539424775, 47.963672068811235, 50.619242191314704, 36.52142401664488, 59.645698531981445, 69.02031621625348, 27.274057826688214, 25.547238280696256, 15.772102475166323, 24.162784776379986, 29.865169678964925, 28.505205492819513, 13.81507706257605, 5.871018873107049, 5.831516683101655, 18.916487193876698, 28.80719661712647, 22.631999408045125, 18.030282566624305, 29.084857279254546, 31.332910791520153, 32.63424927188505, 40.45448657005064, 37.20166498614896, 39.14714490213702, 38.88753498754194, 36.96723668806015, 33.95229508799891, 36.51763500705842, 43.09136267631285, 47.02856333025041, 46.07477234255883, 37.3658710910428, 30.94956578746919, 23.69531277687319, 20.16391073503802, 17.011239028746083, 14.551374585397783, 12.934767757692645, 4.24490176862286, 2.333665615127933, 3.247451613987646, 10.706486913465685, 11.864048953979246, 11.70885645574139, 10.64384372003617, 16.613863706588745, 29.546029952264604, 32.33876143732379, 41.503375422570016, 39.93089329811835, 46.26168504838021, 46.1541768043272, 48.078715185965265, 41.61247614891299, 46.094639147481615, 36.02251814257714, 31.151528627641742, 49.063488975647964, 54.45556732916064, 59.01689552491712, 56.39982346565493, 55.238782282798525, 57.92755919118082, 56.066806393284956, 55.03096726632888, 47.35346109636369, 60.786935667837824, 40.70135662632604, 37.60275087048931, 53.74028390453708, 56.84731098913378, 61.514762832272446, 53.56077663360104, 50.09200503749233, 46.975297543310354, 54.8338250190981, 58.62369360462312, 58.941382054359686, 61.972915280249815, 58.43520018362231, 60.251700801234094, 59.7637265728366, 62.916488493642504, 64.42815819094258, 61.56443965050482, 4.290251231962635, 0.04442634654321498, 0.24383233379452462, 4.991378332338026, 55.264630702234086, 55.6497682294538, 61.982328968663374, 57.08426529361356, 62.78983516077842, 23.205369518649196, 3.545981246617533, 17.443352822334536, 25.93269940345518, 57.82525593234647, 41.782051978572724, 40.17475881884175, 33.110589750351444, 32.2475584860771, 42.456366246746434, 63.65126609802247, 52.570440923014, 1.0565977807967895, 0.1049590251979328, 0.09186442220403303, 0.035618924791173595, 0.09011404919287852, 0.03414186896876462, 0.2999613590298161, 0.1382804944390251, 0.04251156723307025, 0.024133636954150373, 0.0161742438907705, 0.038453526719803774, 0.07990946692805137, 0.03008777763874781, 0.1184809290533585, 0.21414893949704789, 0.2888175989350965, 0.2859090082347393, 6.562122846803358, 78.50095164391303, 61.300648489306056, 42.924261862231845, 26.567564433620824, 50.87356867328767, 43.00188949031215, 19.034274008966264, 22.966597195594545, 27.90385319340614, 6.386412430194117, 16.373454774579695, 63.90121521488313, 63.75056874367499, 62.48981306629797, 57.58534416075676, 54.17864015025478, 21.853261839958932, 0.07136201711311456, 0.009935697852333468, 0.7249661018290828, 36.38180725036129, 60.64107056586974, 58.51486352182204, 65.55788317034322, 65.65160036087036, 66.50569254352202, 58.617570784784135, 63.94871119529971, 67.39404662962883, 62.22247608246342, 53.11403043808476, 48.02371963377922, 55.23933533699282, 60.93566017766153, 71.39684892469838, 89.09892912833922, 56.79799895132742, 55.39560648702807, 57.66855724396245, 49.141775561917214, 33.48763542790567, 54.717362003941695, 85.8043578363234, 64.53544678226595, 53.22235845750379, 57.391386878105905, 49.48114295159617, 45.351314698496175, 50.73975701485911, 48.634189482658144, 50.651158517406834, 51.151307782819195, 50.805080167708866, 41.54197154506561, 53.48373736104658, 79.20091429064351, 33.68888439670686, 32.19823664234531, 25.811688400083973, 23.676550119153916, 35.78057850560835, 34.649331646580855, 18.14406071939776, 9.800139934785905, 8.691665376386336, 24.824033629509714, 33.986447165089274, 24.325541565495154, 27.63437851782768, 29.443626672990863, 35.54382031963718, 34.855695386086744, 36.45228831998764, 34.85807234241117, 35.896586525824766, 37.10324487378521, 40.244961400185865, 44.14940634081441, 47.206136872691495, 44.335518883120635, 42.19916466743716, 42.98424666927707, 39.315151783727835, 32.83014028303085, 22.494824317193803, 19.85613803709707, 16.551501943219094, 16.631108407051332, 15.749777324738043, 5.15436016744183, 2.8342581083697658, 5.421498090990129, 13.453083480558089, 18.076825411089008, 13.760067782094403, 16.091042160987854, 27.550300551999, 32.74658791480526, 39.49551413136144, 45.151477782957016, 44.032794275591456, 48.083151386630156, 49.3645897219258, 48.29410429923765, 44.316212977132494, 48.63499356854347, 40.421511204011985, 29.95791216050425, 52.426195759927076, 56.71570370274206, 56.51223075005316, 59.026850500414454, 59.89205475776427, 59.936036294506444, 58.09332639940324, 55.93636405083441, 50.31300314011113, 60.188123103111025, 43.373906689305464, 42.67291245921966, 57.45622365705429, 56.726450997014204, 63.91469247879521, 56.36884458603398, 54.49319462622366, 48.66310911793863, 56.11225097410141, 59.63428051240983, 62.024670954673525, 63.84402313540059, 62.797519083945986, 63.929589640709665, 65.95186956467168, 66.01831451539071, 67.46586522748395, 58.44794788668233, 2.280116927239203, 0.04358970575154789, 0.027693249172561114, 7.595059910128194, 64.1062492709006, 57.971944732050744, 71.99708138742756, 56.70116347651328, 73.27138885374993, 23.677868035531816, 7.183396864321924, 23.427716916607274, 30.45885374469142, 54.503263350455995, 43.448769046414284, 47.303141009423044, 41.9807396396514, 36.87156223481701, 50.218501475549516, 72.21606731414795, 55.77122834420974, 1.0014299507583342, 0.029471590138611295, 0.1881440389420717, 0.0158625983655633, 0.11419515741328079, 0.06852833448999351, 0.2566065588184903, 0.18903552013779842, 0.28019720988888897, 0.20356974023724758, 0.16694768842670227, 0.18297801695523724, 0.14629642479121685, 0.1244131385559036, 0.24951284510954735, 0.3006752304011776, 0.3914621959049856, 0.6393138559595232, 8.837251009479646, 90.85406426460513, 71.33850759075534, 55.741838024508574, 41.522559735082815, 61.986459224454826, 57.92358583019626, 40.68805194670155, 45.340669385848514, 32.33951649358196, 10.40989395110838, 23.769980976658484, 71.26852466214088, 70.24659033744567, 67.68474132783952, 63.77427554899647, 64.29133415222168, 22.801818424655547, 0.2655582196049152, 0.13222976347371457, 2.561264821598607, 48.18237166250906, 66.13218876623338, 66.0317917793028, 66.21856720216813, 69.60017588830763, 67.80868038054436, 62.96434925448511, 64.17950345623878, 68.99243600906865, 65.6657640395626, 57.56569700856363, 51.67804287325952, 58.122783399397335, 63.13798473727319, 79.05163672662552, 79.31051315799837, 55.93769373432283, 60.94616428498299, 57.19691968733265, 49.97354945828838, 45.264363596516276, 60.507474637800655, 65.03194824341806, 55.40434552777199, 58.76275339434224, 59.26217309890255, 54.67995435960832, 52.53313918267527, 53.31685619969522, 49.70279216766358, 53.25021513046757, 51.03162842412149, 53.37601730900427, 43.61563059591478, 56.33973275461505, 78.0672473292197, 37.14956414315009, 35.279378044989805, 33.5428310209705, 34.166244691418065, 47.56534361070203, 45.83963409546883, 21.722780273806666, 12.016434015766269, 9.481462067173375, 29.03231909198146, 38.804929871712964, 34.017696688252116, 35.371086981988725, 37.85083293914795, 42.56059146696522, 40.375839125725534, 39.67760232187087, 38.71990465348767, 44.68520995109312, 42.6762778528275, 47.97781613565261, 51.30346044417351, 54.80406991897091, 53.71529840653943, 52.03941868197534, 51.09190740892964, 44.927577126410704, 40.38883786047659, 29.61708761030628, 26.849337700874578, 22.69278830097568, 19.618813068636005, 17.998352512236565, 4.371374672459019, 3.4401510415538668, 4.586659352625571, 15.799735573030288, 23.554107450669814, 22.853226969319007, 27.47845449755269, 38.77757133976106, 40.00828950635849, 43.281377976940526, 50.61275459104969, 46.52812773181547, 51.9730168773282, 51.500147696464296, 49.94751276508455, 44.83665658581642, 51.929913951504616, 47.69486811853225, 37.60622216809181, 54.697397139764604, 62.39763736724854, 60.53385257720948, 63.3387355650625, 62.80170425291985, 63.562577386056226, 61.673614901881066, 57.93134035602693, 49.76677779228457, 60.57506884298017, 49.07747614768244, 43.95743377747075, 55.052740343155406, 57.72504329681397, 64.1920393513095, 62.901014743312714, 58.822683288205056, 53.61797655782392, 61.5701388543652, 63.44083878301806, 64.76953383414977, 66.78987610724666, 63.341257649083296, 68.46761503527242, 65.41142971284928, 70.90641144783267, 67.11514257615613, 64.33460966233285, 7.149253612564457, 0.2349170775062615, 0.28195516717049385, 6.933566399158971, 68.7064246208437, 67.85883965030794, 80.09852517035701, 63.88115621382191, 76.11739789285969, 31.041502221938106, 10.952716642810453, 23.685304849378525, 40.73365342232489, 64.70353995600055, 56.92537007793304, 52.951914956492764, 47.24235603886266, 46.44130606805125, 58.48378266057661, 78.48598387933548, 74.4366701187626, 2.408667951822281, 0.45203830025369124, 0.3116403387919549, 0.2270266170343084, 0.21845672850406941, 0.1982085650125819, 0.38658074493850436], [0.06547234847300476, 0.06357859827638154, 0.09716742837260808, 0.03145904054925327, 0.06504772125833458, 0.03258968673406109, 0.05773146283782779, 0.07049713449011888, 0.0908893378331296, 0.1270841117647867, 0.10201965308477802, 1.6404547157787508, 65.0629859585916, 44.13523481738183, 55.814056704121256, 46.43055485140893, 44.79472644867436, 38.036251221933675, 72.09932973307949, 108.75846032173403, 33.7992795052067, 12.205772707539221, 1.1574057585770086, 43.88909824432866, 63.990704090364524, 62.7851204718313, 57.29296284337198, 57.76693028788413, 33.75618834649363, 0.1980497090206031, 0.05336201141378092, 0.3095162527695779, 15.175056938202152, 57.794265285615005, 52.046098478378795, 60.153178707245864, 60.968302142235544, 62.63599195787984, 58.3294334719258, 64.94220049150529, 62.20702586635467, 61.89107502660444, 48.724988429777085, 49.37031246000721, 51.72085554369035, 61.603357407354544, 47.52013437209591, 44.703919656815074, 75.90245985215711, 64.67474583656558, 55.43953703295801, 54.17493743281211, 50.609812813420454, 28.958533425484937, 38.02867712513093, 65.86733464271792, 63.50194931030274, 51.7227892721853, 54.17833420538134, 51.587028195781095, 39.856289817440896, 39.498267635222405, 41.634543403502434, 40.61096168333485, 45.25501266602547, 37.53572933135494, 39.74260384036649, 39.636946955034816, 30.537432547538515, 20.94292090785119, 20.16970407578253, 29.252207163841497, 28.863355152068603, 14.248488180098997, 4.086697380388937, 1.1928799195635704, 1.7702471705213672, 9.521596739369055, 25.17031811898755, 29.107146147758733, 16.157758735841323, 28.46531498816706, 34.959359707370886, 41.26999831968739, 44.80150430433212, 40.58177140451247, 37.18785824314241, 33.2430285792197, 20.64210649459593, 12.3087162933042, 15.689155132539812, 28.536560919977006, 34.62685646549348, 42.80004039887459, 36.47832501319147, 35.45715555067986, 30.3577507311298, 13.976056037410615, 11.152698686045985, 14.381522228640897, 7.969558008255498, 1.310504446587255, 0.7383625281433905, 0.6869014604918419, 4.796171774787288, 8.843345392134882, 9.907960007267615, 9.107589587088555, 10.658875223129026, 21.31199436803018, 27.302571496655865, 32.1050803507528, 36.11495271805794, 42.49767664940127, 46.888828892861646, 46.542840542331824, 41.920342983738074, 47.26382317081575, 35.939771821421964, 20.34544194898298, 36.853029035752826, 55.47194757769185, 53.282606063350556, 58.05927238156719, 54.89846960190804, 55.25323229451334, 54.81437790778376, 49.32890792046824, 53.152940350194136, 47.628666354763894, 42.3538629470333, 50.472824035152314, 52.18531516290481, 60.30952045994421, 62.16512318580382, 57.19138130064934, 51.80407647163638, 45.995552232188565, 49.05069420414586, 53.39392685121106, 58.844511278214, 57.86749985910232, 61.76547681131671, 60.67156307158932, 64.57157965629332, 62.979065987371634, 70.95322101346909, 36.94342790111419, 0.3141598794008455, 0.1311570258751031, 0.04171672036811229, 17.721391993184245, 47.34452985948133, 54.224786835332075, 60.859083744787405, 60.55677098612632, 67.08779581131475, 9.797511946770454, 8.369946691297717, 24.819836693425334, 23.251427950397616, 42.363104051159276, 38.09254900101693, 35.37685286614203, 30.781139212269938, 27.0759153750635, 50.502896847263465, 61.95914383857482, 37.86423567802676, 0.37153431845288126, 0.31885587580261693, 0.05617051655727048, 0.16158283598000006, 0.05763112064150553, 0.03132759709842503, 0.058197592865795865, 0.03326129303464005, 0.12010933320608833, 0.05278340052633036, 0.027786788508115758, 0.04381104387463101, 0.057265179592274854, 0.027406843371629238, 0.016125624120656042, 0.11539321933542529, 0.12134166224108589, 0.057907743499644344, 1.7199220580439416, 73.68365349308138, 53.63294040003131, 56.79996798115393, 39.66939280110021, 53.98649108025336, 41.19689318441576, 63.984765621923636, 101.93823522137058, 34.51042875166863, 14.577765272509668, 2.825679884802911, 41.07704908617082, 69.92907447199669, 67.40243265705725, 65.13413383114722, 62.59497181061776, 44.58498162607993, 0.08384207969591503, 0.04216049978088948, 0.2625371059102397, 17.42887535402852, 61.94566657466274, 57.26503556774509, 66.7199480918146, 63.51798788193734, 66.76728325505411, 60.80674363720802, 66.34670319095736, 64.52125172461233, 64.94643272892122, 50.85408626064178, 51.86921527308803, 54.08367172364266, 62.369572808665616, 49.2602821319334, 53.6992206112031, 82.38056013661047, 64.227219089385, 55.61811470216321, 52.258259480999364, 52.09168426452145, 32.57044015392181, 41.65644199617448, 75.82747982394311, 71.42770228847381, 52.60266319397957, 54.669779731381325, 52.76943452896611, 42.546663130483324, 46.766831413392104, 47.334767080122425, 46.58613566429385, 44.11203399781258, 43.26737511542536, 43.26008342927502, 47.13192562903128, 35.34307341421805, 33.14341998869373, 23.21991562843323, 30.9504855832746, 40.912607639066636, 23.360818932133338, 7.030305775903887, 7.103598694647513, 3.2920837738821587, 15.426844666081092, 27.330128108301473, 27.794687747955326, 24.693524606766243, 32.838275278768236, 37.18865448428739, 36.47150401146182, 41.36088748132029, 45.361740358414195, 42.11357070553688, 36.11956934775076, 33.17450869467951, 25.464968527517012, 33.28520582568261, 39.935337343523585, 45.516313122164824, 43.539207135477376, 36.421407499621, 35.395743000891905, 28.577402599396247, 23.857359616987168, 15.66617004333004, 16.674664366629816, 13.354956565364716, 1.6530526333278226, 1.9995408409064817, 0.9824798160022306, 6.741768381287975, 14.70688577621214, 16.096373642644576, 13.663462746527888, 20.28748304613175, 29.692899180996804, 32.07261881520672, 38.774123576379594, 40.29130420377178, 46.069249645356216, 47.22924747774678, 47.958714192913426, 40.42766932518252, 45.28915297600531, 36.640824887060354, 22.91906003029116, 35.8252150781693, 58.92238993798533, 57.53852675038, 58.941699766343646, 58.79978056876891, 54.78686640339514, 55.022593006010986, 49.43647892244401, 52.13946265559043, 51.61719906714655, 42.797541849074825, 49.43187798223188, 51.57084449645012, 62.8892711670168, 62.49683803127658, 60.39980949894075, 54.08527205067297, 51.545305944258175, 50.27351271721625, 56.274044821339274, 59.936710942176084, 58.16274842908306, 63.12560573700936, 64.52527215403896, 68.70531851245512, 67.36153018090033, 73.08244828254946, 35.56497366197648, 0.2564164770827178, 0.05256626822595155, 0.18661053010052253, 22.927489203791467, 52.844677355981645, 57.16437578201295, 65.5183417566361, 68.41405114819928, 71.12437755830827, 8.274265373906783, 14.658885771228423, 30.027553842913722, 25.72710837087324, 38.539346187345444, 36.76281452178955, 43.898033403581195, 39.01185843252367, 27.782273446359945, 54.68106831273725, 69.32587669741723, 40.84670789780156, 0.3180559880791172, 0.22196675951202072, 0.041837367724867604, 0.11573346962611522, 0.14744748721920675, 0.062334950292302724, 0.06891982074105932, 0.15955772851744007, 0.24284213450887512, 0.21694047196257502, 0.08986516254803828, 0.14524337565225942, 0.1912618482545499, 0.08929703940427111, 0.13670341051634283, 0.15001239555497325, 0.155412886411913, 0.4245365098599465, 3.320985758496869, 90.73553808273809, 55.696715078046246, 76.92998747671805, 63.76306149267382, 65.05885570280014, 55.195134147520996, 82.32084597310713, 118.34707860023745, 43.4719463317625, 19.46289493191627, 7.959277476033858, 53.92374884697699, 76.03942117383404, 76.51129799504434, 70.92656458577802, 69.78878698041363, 44.63414461381974, 0.239557639785832, 0.11614888080305631, 0.36687279600770245, 25.11154728551065, 70.69290114987281, 64.35583360733526, 74.23735095608619, 69.68851550932854, 72.08080045638546, 62.60927669463619, 69.00261063729563, 67.34388735986525, 69.17228452620968, 55.20304556815855, 54.89817934651529, 55.500945660375784, 65.69814712770524, 50.7987847635823, 58.610722326463275, 72.6062568541496, 60.1594505771514, 56.67628780488045, 54.593650448706846, 51.136638118374734, 40.38221297725555, 57.08528118748819, 63.26273179823353, 55.45944306158251, 54.184778659574455, 58.91543557566982, 55.016536866464925, 44.99490068804833, 49.760568680301795, 50.56538412647863, 53.25146636655254, 47.16959214979603, 45.859465599060066, 46.08228368143882, 50.877820522554465, 42.40543819242909, 43.4942763851535, 33.408960526989354, 42.72019663164693, 55.01531700934134, 28.057978806957124, 8.95556636394993, 11.324614209513511, 6.3478864200653575, 20.30234294552957, 32.80638052571204, 36.92215688766972, 35.04647947126819, 43.143353692946896, 45.00175306873937, 47.07333718576739, 49.64300347912697, 57.86071808107438, 52.80751682096913, 46.905981417625185, 36.74150820701353, 25.791292075187933, 32.621338790462865, 44.27746388220018, 50.655504503557765, 50.58919683579476, 43.69800036953342, 41.54330122855402, 35.61980055224511, 30.466769087699156, 21.037997199643044, 19.86386118396636, 15.612317862049228, 1.56865781353366, 2.928471478723711, 0.5542929278266046, 7.13761446937438, 19.975472227219615, 23.580575604592603, 24.40250042946108, 31.9926259979125, 38.31091911562028, 40.77470887091852, 43.98036003112794, 45.3211752060921, 49.954788761754195, 51.550193217492875, 50.623823519675966, 43.73240740068498, 47.65831162852626, 48.13968058555357, 33.426838690234774, 42.67052765815489, 58.685820025782434, 57.127795757785925, 62.16555464652277, 59.61711622053578, 57.34033723031321, 57.202799320220954, 50.065768303409705, 53.14762161624048, 54.19290581057149, 42.86789348048549, 50.676453882648104, 52.740448213392696, 65.20743900729765, 66.87590152986589, 62.9429135014934, 57.12065704407231, 53.38803152884207, 55.296280307154504, 59.16127797096007, 65.57453755409487, 60.90460285063713, 65.42819784533593, 66.87212820976012, 70.57993688891011, 70.04222700672766, 76.20823214131018, 43.036916255950935, 0.673163297676271, 0.29327687416826526, 0.18880442205455997, 22.636145353317264, 64.64989762152395, 66.44572734832764, 74.91259482599075, 70.45882194272934, 81.56815882652037, 16.741444679998583, 14.651829427288426, 33.56012867343041, 34.05307254483623, 50.691656989436, 51.077371105071045, 48.426190114790394, 44.86562721190914, 40.10093196745842, 65.57021117979481, 74.2896596847042, 57.073886702137614, 0.6511535303246591, 0.5287025880909736, 0.26493370472904176, 0.2182004567716391, 0.3094918911735858, 0.16483144714466988, 0.17795385913022105], [0.014704715839827494, 0.040183590740085616, 0.2930871295111795, 0.08046051397198632, 0.1740512233828345, 0.02210053727932034, 0.09974144549379427, 0.050384917131234566, 0.09049886281812385, 0.024759925323568528, 0.03471766831353307, 0.13710811944498172, 50.23598347940753, 56.33014255954374, 41.13491973569317, 28.83125447457837, 37.15487110999323, 46.32272497300179, 23.575474562183505, 42.44260264981178, 21.92572762889247, 14.533826881839385, 8.409431230637336, 22.320012123354022, 58.36243629455567, 62.18279738580028, 53.67611000614782, 60.617461819802564, 47.59287472694151, 1.9511742168857207, 0.16143812197110347, 0.11164319596343464, 3.668713925346252, 51.89204346749091, 50.59177383299797, 61.75994234700357, 60.89990777354087, 61.996127866929584, 61.69497220746933, 62.51702254818332, 60.85001522494901, 51.59394725676506, 45.46732664108277, 50.555134973218365, 52.974590178458925, 58.501739271225475, 62.33994714675411, 41.88505734166792, 44.237824409238755, 65.68968265287339, 62.86494070483793, 59.98085329609533, 51.76896733622397, 50.2722301021699, 29.75988345761453, 29.63460687668093, 65.63628350534748, 79.38087263414937, 57.02702614568896, 45.845992257518155, 47.83594400651994, 51.10227423329508, 41.24396554885372, 46.10420580833189, 42.870239057848536, 42.356490935048754, 33.85789148269161, 30.017598867416385, 27.76534449669623, 20.563817947141587, 30.92645322122882, 31.197275230961463, 23.51680963270126, 6.950451222158248, 1.859863032737086, 3.999843847367072, 1.5537312338429115, 14.175435996824696, 27.288896153050086, 30.704749091979, 22.452327397561845, 32.95813898886404, 40.552832157381125, 44.35351471747122, 36.96245139644992, 27.98876662408152, 24.694579724342596, 22.539841359661473, 7.6973876837761175, 2.518028290041032, 5.819002851363152, 11.243058327705631, 21.499979842093683, 27.965183373420473, 36.91015051257226, 46.94398526222476, 34.58428305964316, 21.009563938263927, 15.129487822132727, 14.583330135191641, 9.508381293665979, 1.5744993258868496, 0.3466262566226144, 0.6085572644106804, 1.1921034128435197, 5.092619609448218, 10.178728084410391, 11.939234906627286, 11.05518856356221, 14.344844145159568, 22.52578946851915, 28.790812876916704, 38.27713966369629, 44.66475871301467, 47.94056146375595, 49.10741559920773, 43.84356344899824, 41.4354399711855, 63.3589396938201, 29.14087853124065, 20.694599574612035, 46.24998069578602, 53.68562175381569, 52.880245408704205, 53.258499176271506, 50.393521555008434, 51.3006990955722, 45.55304611882856, 48.2218816972548, 46.79549609461139, 46.267858859031435, 49.5086113099129, 53.148143291473396, 57.12195927096952, 59.67623418377292, 60.15333167968258, 50.90377484598468, 46.05981242272162, 49.999982310879616, 47.73206787724649, 51.95565254457536, 51.899696011697095, 58.00023678810366, 60.3784365038718, 64.46206708108225, 62.04457698329803, 67.14310907548474, 19.721536021078787, 0.25438291200947377, 0.3342815158107589, 0.23564556583521828, 14.840217924887135, 47.62904682467061, 53.41489584215226, 61.6126024338507, 59.13830464886081, 28.8870305784287, 1.6490692212697, 26.890481402797086, 24.856442213058475, 29.669025674943004, 35.034488785651426, 28.433122134977772, 45.263959592388524, 35.39783754656392, 40.306185676205544, 42.96453283679101, 71.7390678774926, 25.21098917530429, 0.1746089966787446, 0.13824030546651733, 0.17409865954710593, 0.10112051867068776, 0.10458007980618747, 0.07620111107826233, 0.04117557118015905, 0.11802704494086005, 0.059143309256122004, 0.2620271058572877, 0.05711043749244944, 0.042023576886182835, 0.030690179386686896, 0.08007888727250599, 0.11064456971061808, 0.21325725911846086, 0.13257068792177787, 0.07610846040469986, 0.218507198376521, 62.188014138129454, 64.85481008406609, 44.307152302034446, 25.711654232394313, 50.94210032493838, 40.78276149688229, 30.548375960319277, 48.785279181695756, 23.69972936568722, 14.62619379643471, 14.423450404597869, 31.33638208912265, 61.528851985931404, 67.62734920747819, 62.1008865294918, 68.02172783882388, 54.18056603400938, 3.4739694720314396, 0.03216413255300253, 0.3207340476012999, 3.7397914403869263, 57.782231453926336, 56.881161043720866, 66.01443921366047, 64.79939876064178, 67.34819412231445, 64.53691374871039, 65.39370059967041, 63.875284425673954, 54.11641566984115, 47.35602240408621, 53.16532327282814, 54.829361361842004, 59.8111205716287, 62.10711917569561, 42.72312271979548, 51.86641862315517, 72.91311956221058, 64.75138110499229, 60.93898242519748, 49.66207796527494, 50.625517983590406, 37.70417551840506, 36.033543925131525, 72.97121770920293, 79.85125110995385, 53.60465618871874, 45.1039739578001, 48.80362018462151, 50.92443004731209, 48.685478395031346, 48.97217619803644, 49.20264682462139, 43.2131758043843, 40.70455728038665, 38.953489641989435, 39.06631269762593, 27.849143974242676, 32.95194164399178, 41.677575726662916, 34.799323081970215, 12.872934533703713, 2.7846474801340415, 4.034870122709583, 2.591915938162035, 15.660715007012891, 30.158974816722257, 27.61575314306444, 26.29748179066566, 35.46355685880108, 40.847143280890684, 44.55677978454098, 48.39969842664657, 46.71734286892799, 40.87544710405412, 40.78912358130179, 20.528708811729185, 8.914158882633332, 13.859920540163595, 23.262185050595193, 36.61024608919698, 44.346697638111735, 42.788626301673155, 41.2202234422007, 32.53318155965498, 25.01325857254767, 15.98373297722109, 20.477857243630197, 14.13488555339075, 1.3334717625571837, 1.4905126777387436, 0.2162226322557657, 3.0059583917740853, 10.106568240350294, 17.62623333161877, 14.257635147340837, 15.51269946559783, 27.4128391281251, 30.066803040043002, 34.32529680190548, 43.43994763589675, 50.37081887645107, 50.71630124122866, 52.363049522522964, 43.90947887974401, 42.666448393175685, 68.30992790960497, 36.10077727225519, 24.02695505849777, 48.470183418643096, 54.410699336759514, 55.256040711556714, 57.09170602983045, 51.21221042448475, 54.010688181846376, 47.13862895965577, 48.83451277209867, 48.920577418419626, 46.86006615238805, 49.962986515414336, 53.021262461139315, 58.57610740969258, 61.95824953817553, 59.23549705936063, 53.55175125983454, 48.70346638464159, 53.888192561364946, 49.83058691024781, 53.428584914053644, 54.11696087929511, 62.12331856450727, 62.42914184447258, 70.19203016834875, 64.97825491812922, 68.99956687804192, 22.828523881973762, 0.44877626722858804, 0.38044088730408304, 0.4565106909121237, 16.80397314410056, 55.52031040191651, 61.146475807313, 65.46786477488857, 62.995288910404334, 26.811294632573283, 4.242484608004171, 29.548042128163, 28.597049751589378, 32.52406989374469, 37.32511374258226, 30.204523340348278, 52.17629763387865, 42.14689908489105, 41.40566525920745, 46.10635134481615, 80.4824467628233, 27.07824722413094, 0.13758537690004996, 0.14372528049974673, 0.13999909012308046, 0.06451172018123251, 0.24856675716657795, 0.09021647514835482, 0.08581441136137133, 0.17748210218644914, 0.25366255953427286, 0.3334867761981103, 0.1646017586632121, 0.16049492984048783, 0.14360656751500023, 0.22838993178259945, 0.29313401409214546, 0.2245981029925808, 0.16080666633863605, 0.11430074731188436, 0.6065449046511805, 75.73063650438863, 70.45004367828369, 61.523878420552904, 39.64053200137231, 57.87863546802152, 63.17114445470995, 26.030360537190592, 48.32440068644863, 28.483495173915742, 21.389841648840136, 15.009975164167344, 33.28703365018291, 67.3213964892972, 73.25162010808145, 70.17845092281219, 72.8131305017779, 59.890803521679295, 3.5398245963358113, 0.17078240281872212, 0.4815284258896305, 8.547844809870567, 67.71015828655612, 59.57052238525883, 71.8163856383293, 66.56921140609249, 68.5209906485773, 66.9848414390318, 69.18398887880387, 67.05014105766051, 56.66751346280498, 50.00364580462056, 55.23652691994944, 59.57751989364625, 64.60903436906877, 63.47764630471507, 44.40639218976421, 60.53069899159094, 72.64447642910865, 65.05556875659575, 62.047059843617106, 52.60371831155593, 54.05671719581851, 42.623231718617106, 50.74326753616334, 69.65067248190604, 62.65526256253643, 49.09495815154045, 49.539370536804206, 53.26867772686867, 54.063797073979536, 51.63719138791485, 54.301214218139656, 52.634199050164995, 50.58696108479654, 48.96073856661397, 46.51730199013987, 48.09309851738715, 39.23108754619476, 42.99255032693186, 52.69427014935402, 46.38979358057822, 15.183796959538615, 5.074350189778113, 8.862975874254781, 8.157045831603389, 24.469727893029493, 38.817497145745065, 36.33855135210099, 39.72458447179487, 45.22297474645799, 52.35163542532152, 54.42480417989916, 55.1699564533849, 53.71159961146694, 44.34224967033633, 55.86160367535007, 22.68366682913996, 8.764764628102704, 13.2422423555005, 23.776652928321596, 39.03663604490219, 50.79192061578074, 55.371440764396425, 55.10114239108179, 40.452407713859316, 36.56035746297529, 23.596510233417636, 25.695154782264467, 19.97341690524932, 3.4079160228852308, 1.2233073384531084, 0.5191244665653475, 2.9635286427313283, 14.054858415357529, 24.33749498859529, 22.45626937958502, 27.94466741623417, 41.63036215689875, 37.15353358176447, 41.24352232102425, 48.293151163285785, 55.13005418162192, 53.06178446738951, 56.351205687369074, 47.87578744273032, 50.13543744241038, 69.59719488697668, 50.93838976275537, 33.11413949535739, 53.914950970680486, 53.25467486535349, 54.71181969488821, 59.95789958584694, 54.39015003942675, 54.42140348495976, 49.615370381263, 50.80076556051932, 49.430140372245546, 48.95502759564308, 52.32891705728347, 56.09300782603603, 61.440210342407234, 65.05534518149592, 63.3217046337743, 56.23179697221326, 52.34874463850453, 57.20292875843664, 53.75587924834221, 58.179045877149036, 59.1443137199648, 65.5663319556944, 67.66352914994764, 71.09228472555839, 69.26446022525911, 70.42476792489329, 27.545377977432747, 1.044773550764207, 0.8840106740113228, 1.401469236420047, 22.106023296233147, 65.72709814194711, 69.68650725580031, 72.38764747496575, 69.4829519333378, 39.5980566547763, 7.489542268937634, 36.38388218418245, 30.450422610006026, 41.33979297453358, 44.118917757465, 41.200388016239295, 62.24335093652049, 51.90687394911244, 59.50241042721657, 57.75005625140283, 88.58218039235761, 38.592486458439986, 0.5011707364070801, 0.21776481321261776, 0.37968757772637957, 0.22514797026111236, 0.33225548904268976, 0.18047894621568342, 0.20713548115905256], [0.06357647238239165, 0.006232219109792383, 0.0627294740819883, 0.15015134858267923, 0.10534930103007825, 0.12669598097882925, 0.07522003589979104, 0.08599208247277045, 0.017072236833853588, 0.02603828092105687, 0.2778779246634053, 0.1622661251214243, 49.39105395347842, 55.72652116898568, 58.08314000406573, 36.64530423379714, 35.43028339262932, 54.58811990676388, 27.759780614606797, 19.641684409110777, 32.57892031823435, 10.492888362176958, 7.466205147004898, 56.09416884760703, 59.397942020047104, 64.36116410839942, 54.8139464470648, 55.70384986938969, 48.047304845625355, 7.327364519719155, 0.23233680144673396, 0.4189073877228845, 0.3049764463738088, 35.06286713384813, 62.53527333659511, 60.94375987206737, 63.96431046147501, 65.25846119849913, 62.10636608062252, 60.56010892314296, 58.57170651035925, 48.75752841272662, 50.28959443492275, 52.78841487822994, 52.40213201891992, 50.26049437061433, 56.212498910965465, 61.98177983683925, 54.89932075623543, 48.15477778834682, 50.591287459096606, 47.816092891077844, 51.699396256477606, 52.66140460968018, 62.847490079941295, 47.27935183432795, 30.189286893413914, 50.50827049439954, 87.12508263126497, 72.25478895248906, 47.67987681973366, 45.16443337163618, 50.87434138021162, 46.84364711084674, 45.33239318478493, 41.49330277596751, 42.12983677464147, 34.433130602682795, 26.46439236979331, 30.362524255629513, 33.4368525012847, 27.619793184341926, 15.52924402298466, 3.399557697196161, 0.5692412644144028, 2.539350049149606, 3.159178673259674, 23.038739388988866, 39.82149839401245, 37.22798801237537, 36.74730154775804, 37.55554122309531, 44.87005556783369, 35.422858345893125, 23.74583878824788, 10.960124038880872, 11.911582196912459, 11.95585104726976, 3.9392557307597134, 0.7146585420254739, 1.707421709452906, 2.9539737489915665, 4.897429721970712, 10.16850442655625, 23.590656095935454, 40.22259996783349, 38.85115108182354, 37.907048348457586, 26.168759407535678, 27.177849931101647, 16.793790671133227, 4.548720717430115, 1.4497995785167141, 0.5478737238914736, 0.5289590743280227, 2.267543524503708, 5.720638142478082, 10.958809064280603, 13.864036087066898, 15.613910344339187, 22.083414754559918, 29.86349286571626, 39.24184660757742, 44.858347292869325, 47.48973992563064, 51.2967610359192, 52.739487232700476, 51.530777485139915, 71.23017172659598, 72.93928961600028, 25.705472577002745, 33.93258517788303, 43.28242524977654, 52.967388706822554, 51.25785112380982, 53.68411948603969, 49.76908414594589, 52.823516168902, 47.20295583048175, 38.48815141185638, 48.676829568801395, 53.99254329742924, 54.8370845087113, 58.3057580455657, 57.426915707126746, 56.33786570641303, 52.40548956778742, 47.01316018258372, 48.456651241548606, 54.42965615180231, 54.36127355021816, 47.31321757839572, 54.88595331868818, 57.898933733663256, 65.33199779448971, 56.885495262761275, 72.56740185522264, 18.47177278610968, 0.4742171891754674, 0.2584070033363758, 0.34588272232682477, 19.21860775639934, 56.231789127472915, 54.82681574360017, 57.85777238107497, 51.07639835726831, 43.31843653032857, 3.511620793611773, 26.18482935813166, 21.229042122440955, 24.833806214794038, 33.88721904447002, 33.32395492061492, 45.048201776319935, 33.02555668738581, 30.085244063408147, 41.19218634020898, 69.35185063269832, 18.548406093351304, 0.5523723760439504, 0.11269405409092866, 0.036258539260034604, 0.24018734873783207, 0.06226542781317427, 0.15401780965828127, 0.11157228686516324, 0.13145633642711949, 0.07795480891100823, 0.11861185347961804, 0.03794130118143174, 0.12373472939455703, 0.1439489168866027, 0.1284556083321091, 0.09375826050076755, 0.11211495290720656, 0.04789299016157466, 0.16920510439142106, 0.14345451438378903, 57.636201612411014, 62.376099632632354, 57.158892308512044, 33.59533586809712, 48.80846823415449, 49.302122054561494, 28.038068855962447, 28.44443621173982, 33.27518024752217, 19.51163822604764, 6.152437656156479, 62.70704961592152, 63.54727229764385, 73.0022358125256, 60.51256587428432, 65.84256879744991, 54.14009501857143, 9.270405211756307, 0.20456069028906285, 0.8004422485828401, 0.2798147175100542, 39.86782158574751, 66.89011619937035, 65.65273392585017, 64.77066739912956, 70.34162936672088, 65.35451612164898, 65.18614445963215, 60.34665746073569, 51.275819501569195, 52.82502235904817, 55.29408770222818, 56.36116458523659, 55.7540758194462, 60.14659304772655, 66.76878944520028, 57.47225830631872, 53.07532841159452, 56.248392520412324, 54.81368364826326, 54.132846478492986, 54.83525276184083, 59.47746023055046, 50.76539362630537, 35.86576846338088, 59.4886625197626, 86.9456498853622, 67.80114158507317, 50.07791588383336, 51.33026984430129, 52.91062808805897, 51.48352469167402, 48.62533669317923, 49.87580007122409, 46.79623742257395, 41.858565653524096, 38.737021876919655, 34.200188882889286, 43.53751659393311, 45.03142972146311, 24.9563959721596, 5.989871101994669, 0.5932025335008099, 2.4619406029101345, 2.823949629260648, 23.37842841302195, 40.32487969244681, 31.86048330799226, 34.56745609160393, 37.12788128083752, 49.87920076616349, 47.65575032080374, 41.2330025242221, 28.268759135277044, 23.12745555754631, 35.083800823457786, 13.23102633799276, 1.9894984700987417, 3.961248950612161, 8.55842246163276, 21.752709919406524, 30.153222660864557, 42.64894677746681, 48.95519233519032, 38.92444056849326, 32.51738225260089, 22.594430946534683, 25.58331035798596, 15.360235956407363, 3.68773766583012, 0.8583635211952272, 0.5328061227356234, 1.4590246254397978, 5.740300984151903, 13.37789164435479, 19.32238386523339, 13.54893542105152, 21.617101815439042, 35.01561826275241, 34.954480278876524, 47.440561248410134, 46.93330857061571, 52.60229841355355, 53.905627496780895, 61.75717315366192, 53.099148965651, 61.78597904020741, 74.27850446393414, 39.29314336469097, 35.198239895605276, 44.68337428185248, 50.26125138805759, 53.76067630706295, 52.533668702648534, 51.065231369387725, 50.011266969865375, 50.182243085676625, 39.66807096235214, 46.24328913227205, 53.49882671909948, 58.23022104078724, 60.55884984231765, 59.977978198759025, 57.45203064334009, 53.844717010375, 48.68675316533735, 54.79319318648308, 58.469901392536784, 58.494353448191, 50.035322866132184, 57.192154007573286, 61.46524683121712, 68.35484689281833, 63.09440328228859, 73.7019552723054, 18.773175554890788, 0.4456037439165577, 0.1537895307786042, 0.25136800362698497, 25.181824391888036, 61.737816256861535, 61.109585915842366, 63.2331100586922, 54.44928761451475, 44.92316053759667, 5.679308127972388, 32.33090100749847, 25.66831204199022, 28.477199769789173, 37.25781763753584, 36.536760484018636, 50.19215883747224, 38.367087456487845, 29.285574766897387, 49.60952997207642, 71.94376853204542, 17.636741361310406, 0.8022826982121315, 0.1239189428968295, 0.040190481700964516, 0.05804317635333827, 0.04964340913800463, 0.18126400247696908, 0.10607940580455527, 0.15095486756294005, 0.17912598897612866, 0.13990878367856627, 0.13467425810954264, 0.16062505753530612, 0.24457366175709233, 0.23347959012514163, 0.19366719579744726, 0.16292785654865927, 0.17653745448877736, 0.3440619458354289, 0.2616697718058863, 70.01611971086072, 70.36408101358722, 73.83147978013562, 49.999609685713246, 51.70088283477291, 81.09508176003733, 33.95177733513617, 27.74533844763233, 37.368267659218084, 19.285931318036972, 14.145984880385862, 67.13662931996008, 70.17120238273375, 78.73550153547718, 63.61648251933437, 72.14722971762382, 58.674245111403934, 9.992210557383876, 0.4111285615832575, 1.388269970493932, 0.9619299057991275, 50.39416482371669, 71.11884701636531, 71.1573725361978, 69.02150077204551, 73.2923343104701, 67.5954132695352, 69.65738757964104, 64.42525955938524, 55.12740265938544, 55.90174128932338, 57.313261109013716, 57.638986495233354, 57.371327877044685, 63.069810021308164, 68.88107207513625, 62.46795761969782, 59.2314491733428, 59.32332284988896, 59.30727251114384, 55.429989983958585, 57.409923999540275, 62.05975263349472, 52.318534543437345, 49.691715394296956, 73.32394861405896, 74.01670194441273, 55.58018146022674, 54.376041273916925, 55.52460539725519, 56.17628366716447, 57.826750355382124, 54.51718384219755, 53.469106920303844, 57.31823075202204, 48.95552181428479, 49.48353167503111, 44.96431012307444, 51.78985787976173, 56.000326141234375, 34.22565291004796, 7.071531357303743, 5.476200936302062, 6.5980532284705875, 17.078364510690015, 39.81807024248185, 46.27430723559472, 41.37591408145043, 48.85288907635597, 49.10565837737053, 59.332952268662, 57.355854126714895, 46.29443683931905, 29.986231673148374, 21.823381223986228, 44.273639571282175, 16.11074814873357, 2.753116036615064, 3.340847170160663, 6.97759892671339, 20.409058870807772, 32.50008852251115, 53.74546927790488, 61.347258014063684, 52.35606770361624, 45.47596370020221, 33.28348782754714, 39.099947021853545, 29.635499215895134, 14.417831609326026, 1.8911718817487841, 1.3571770969898471, 2.095446346267577, 7.467350969391485, 20.28852051304233, 26.43052858691062, 25.61578562182765, 35.0369441893793, 42.297423962623846, 44.35906094889487, 51.99671191553916, 54.4329587874874, 55.30660006307787, 56.96682168591408, 60.901908182328754, 58.69457475600704, 58.59253037360407, 77.54333634530344, 55.23477754285259, 42.713520757613644, 48.10422628156601, 51.278937785856186, 54.067119321515484, 56.12395924906577, 53.56493826835386, 52.90802363426455, 47.58228824984643, 44.71052492818525, 45.368930062940045, 54.13375254600279, 58.19845376476165, 64.04369923376268, 63.780296387210974, 65.29313102845224, 56.00690003364317, 50.59203270942935, 56.02244438663606, 60.335290431976325, 60.992848334773896, 53.577411405501834, 59.17188013753584, 66.40000035685878, 72.74998034200361, 64.39129575606316, 76.81865492174703, 24.468011856079105, 0.5203896148070213, 0.49975332052957633, 0.4832451063538752, 26.11650755328517, 77.074597420231, 66.4191964364821, 70.52679661781558, 63.74338688388948, 53.73666747923821, 9.50723498098312, 37.65053318392846, 26.55088455446305, 31.767052450487693, 47.10495148935626, 44.42142271226452, 63.432186034417924, 48.776900999007694, 42.14516539727488, 57.28323536534464, 88.83683635342507, 31.819363140290786, 1.0619503451931862, 0.20230396380347593, 0.2835543297471539, 0.30978775432994293, 0.1778861982447486, 0.37199081492520153, 0.2072394852556529], [0.24701526058056664, 0.06784269345864173, 0.05347972848422585, 0.08328907912777317, 0.03901355231421129, 0.12117428735138909, 0.11341213128499447, 0.033036499855018435, 0.035299895135986234, 0.11725558674023037, 0.04864262634768121, 0.04052353459560583, 34.427352951418975, 59.9852502730585, 50.63386870968727, 31.18139159294867, 26.150135993957523, 52.235239090458045, 35.16220115846203, 33.75866728444254, 32.34844576927924, 39.92875952874461, 2.447667343001212, 19.44701521627365, 65.35908176052955, 61.385799223376864, 63.95346903031873, 59.03283995966758, 56.20890994225779, 9.318870998197987, 0.13423156654161794, 0.95653971116389, 0.17392841948857232, 18.718517326539565, 63.52001574731643, 57.31853277452531, 66.203199355833, 64.3565357115961, 66.08660298009073, 59.10549402236939, 51.43935880353374, 48.2888836245383, 58.867916061032204, 59.96635229356828, 61.34740314176006, 56.07221926412275, 53.44567075852425, 58.24760890776112, 60.764915481690444, 60.583211683457904, 59.26389894177837, 58.33383829362931, 56.135608688477554, 54.37769259175947, 50.095562627238614, 52.42237537137924, 43.80132736698274, 26.96746772335422, 35.53085688621768, 76.03403968195762, 84.37830171277447, 55.05444265181019, 53.780939271373136, 50.38311942931145, 48.07330623749764, 42.17057058888097, 46.127124217248735, 36.841210934423636, 34.66367575430101, 38.49523129001741, 34.04734588438465, 25.42281677646022, 10.238326537993647, 0.9637928477698757, 0.6708008663788919, 0.8959508591121244, 10.139177845370385, 33.912428117567494, 51.56052081815658, 40.393933019330426, 49.59992408752442, 33.74868485235399, 32.38272728458528, 19.269786842407722, 9.270763128034531, 0.21783769881773382, 2.9468529310918625, 9.708363336901511, 4.030156169206866, 1.363983022109155, 0.15140659896837128, 0.4017726361991898, 1.8583482624061647, 0.2827437474362312, 6.770180559927418, 21.325477515497518, 37.63611455117503, 42.8599859822181, 42.48019464554326, 40.31996104025072, 29.74254069789764, 14.438267157923791, 3.6365213173051036, 1.0201167964166211, 0.43733857451908054, 1.9331775245166596, 5.4272134746274645, 10.246221288557976, 14.77890637613112, 13.767518324236717, 20.847932869388213, 32.087717979185044, 38.66102203246086, 45.3862787062122, 44.643766187852435, 50.653472715808505, 59.77648996537732, 50.71992551126788, 37.34342728891681, 83.52812797792497, 79.9787752089962, 32.07619013324861, 37.050567442371005, 43.21115578374555, 50.72593850474204, 46.41202165234474, 45.71161577778478, 49.85832591210642, 46.069661494224306, 56.5980012186112, 62.26752842626264, 56.309718778056485, 63.37573136052778, 55.32250919649678, 58.77986669540406, 51.61020548112931, 49.63523326381561, 52.4933506596473, 63.11444267149895, 62.64133030368436, 58.694641436299975, 56.57534168612573, 56.40906064741073, 57.11136102676392, 63.960537141369244, 60.76387605359478, 65.50509591256419, 10.071954304172147, 0.3145943125409465, 0.3832387629776232, 2.8289202528615154, 46.58091106722432, 46.69157681926605, 63.741002082824714, 46.536741256713874, 71.17631758413008, 26.35926892680507, 5.102486331616679, 35.64428790923088, 16.968169443068966, 38.07300383044828, 36.28658386968797, 28.414230039042813, 46.18073517276395, 36.09332476892779, 41.25994136256557, 54.74557561259116, 62.15191656543363, 5.769697677704596, 0.2949478038616719, 0.13116707694866966, 0.09197864591354325, 0.18656683244532157, 0.04972917268112783, 0.08097367030718634, 0.0895517483173359, 0.17178020169658048, 0.08503021311856086, 0.019474958610390464, 0.02046229272720314, 0.12674376188266662, 0.18715511136237653, 0.08923098730343966, 0.05924396554849321, 0.05576717509557644, 0.08815332375947507, 0.019135981940874652, 0.24575227270683936, 36.5795260860074, 70.12229827142531, 54.01464193098007, 28.118514707011563, 37.72465421307472, 51.58896192427605, 31.711831362016742, 37.070249895895685, 27.57538607043605, 49.73375928017401, 5.199456147609219, 17.678298873286096, 70.36041751984628, 67.49103899924987, 72.1827507019043, 65.594753449963, 62.679836211665986, 11.7965361379808, 0.030699435644032016, 1.0237484208999141, 0.38227716941506634, 19.968478641202374, 64.00881759582028, 62.122134008715236, 71.03799912237352, 64.36063851079633, 71.23454909170829, 63.81919060983966, 55.71064341452814, 52.099956543214866, 61.04766345793202, 63.73580886471657, 63.242335473337484, 58.129169018037864, 57.02993262198664, 62.524122038195216, 64.80406638114684, 60.34984634768579, 59.282094817007746, 62.02307062764322, 57.307483457749896, 57.15828826350551, 47.407840836432676, 51.48876890059441, 47.575337809901086, 33.82690868070049, 39.44859081699003, 74.2626267094766, 74.10816377209079, 59.72339284035468, 55.37551610700546, 56.76695339141354, 49.336776195033906, 51.75565873422931, 46.832884127093905, 50.01798206760038, 37.282618784135394, 43.633481302568995, 52.33118026487289, 40.609706524879705, 15.423128220342821, 1.8906404005904354, 3.0445160260123596, 4.8127604588385555, 9.519747341832808, 32.84048945673051, 48.571666902111424, 39.541303880753055, 49.08132399282148, 44.73372182538433, 49.806868337815814, 38.74289366506761, 24.615161534278627, 10.376291005842148, 8.402130719154112, 20.174357967991984, 7.53335367287359, 1.8761743316727302, 1.7079682672216048, 2.2603915727907613, 7.879373892661064, 14.629357187978684, 29.205281888284993, 45.08040443543465, 42.78601400313839, 39.60869804505379, 37.26741959971767, 38.467990429170676, 27.028146789919948, 9.914932020248907, 3.622079150330636, 1.6799739435795815, 0.1813754529481934, 4.281293519081609, 9.901440047448682, 20.846338425913167, 19.410472454563266, 16.42135770090165, 33.06504318791051, 35.14728046232654, 42.67494816933909, 49.17308392063264, 50.574331052841686, 57.4145955424155, 59.890944727005504, 49.07942164328791, 39.966429971879535, 66.06922688022738, 89.63861588508853, 46.12354701565158, 39.28896211808728, 44.91737111922234, 49.18049720025832, 48.3326925769929, 45.21267068001532, 50.74873532018354, 53.3048302127469, 51.25627825337072, 60.305127405351215, 59.62552578218522, 67.39052434121409, 61.29393731394122, 61.723515295213275, 52.50659650371921, 50.7542109489441, 54.95188443891464, 65.97200701313635, 64.3915467877542, 63.804987707445704, 61.468753430151175, 58.45680067616125, 58.862867970620435, 66.84046683772918, 63.73149033515685, 68.89136437446841, 7.813248124814804, 0.17494799058523872, 0.13829180189678747, 4.185357737925745, 54.93881117913031, 54.920081861557506, 73.94970786186957, 52.80622636118243, 73.22300249530424, 24.185287414058564, 8.455508293644074, 40.404276309474824, 20.334673081674886, 38.394493056881814, 36.540969187213534, 30.976861561498335, 53.666339382048584, 37.038482619870095, 44.351565299495576, 61.281358272798606, 69.34470407424435, 5.631132106627188, 0.4397857351408851, 0.036721524497073506, 0.12291748977957234, 0.028598284378888148, 0.04211270738573324, 0.1254700257953617, 0.10940945211557612, 0.4142986947009641, 0.1760450897798423, 0.2666926732467067, 0.14647104687267734, 0.16259497602380094, 0.220937397811682, 0.15572001106075703, 0.2458208988630964, 0.12695648151660158, 0.25798231483467166, 0.4748699573739883, 0.4645823771434446, 51.20795073047761, 76.24995831520327, 66.7462593509305, 44.092006375712735, 40.587615736069225, 74.40923706177743, 48.045112240699034, 47.56182132228729, 38.04852824057303, 52.74366063456382, 6.9901367829691985, 29.558548196669552, 74.28387811107021, 74.87221010269658, 76.18988329364409, 70.84771710057413, 67.55982952733194, 13.817454018900472, 0.3208162641573337, 2.593846234583086, 0.29038280849495246, 27.77991217951621, 69.43717787342688, 66.338819226911, 73.02111810253513, 70.02458418569258, 73.79482130850516, 67.73075857470113, 58.249079796575735, 55.24530126202492, 64.62713218504383, 66.5822022961032, 65.0277042388916, 60.54024996296052, 56.70772560181157, 64.05536044028499, 68.24411838285386, 65.29735542112782, 64.4205762493995, 61.75890684127808, 58.43927552623134, 59.147137826488866, 47.55360003440611, 53.27544381541591, 47.17581302888932, 44.13547800433251, 61.25507839264409, 83.87314750302224, 67.6718210404919, 59.644808153952326, 59.156728021560184, 60.225613117218025, 54.12291111484651, 57.30800121061264, 52.925133012956195, 55.75974756671537, 47.728604424384336, 52.97842625648745, 61.75819689227689, 53.477732212312766, 23.488076310003958, 5.810367263132527, 11.607275893611293, 11.751577931065714, 34.31214117234753, 50.55130673993019, 56.96990859123969, 49.145623407056256, 60.382951151940134, 54.92807957433886, 54.77649565665953, 47.11462013183102, 26.751507905221757, 10.52296901902845, 7.181647487225072, 27.67016230090972, 14.57631693732354, 2.863608714072935, 2.5226130504761977, 3.2291883230209355, 8.184991248192327, 15.463625711779441, 34.61333997787968, 49.68634566953106, 57.36092967371787, 50.52826281516783, 52.510824818764966, 48.54020557095928, 42.06212097598661, 25.21335240333311, 13.516810228747707, 6.726225989480173, 0.8907917778818839, 4.9192199591667425, 14.161359590868797, 29.451263527716364, 26.634458495724587, 28.396361681722826, 43.29361184950798, 45.210470230348655, 51.19705046376875, 54.358057206676854, 54.92225485463297, 57.36237702831146, 61.98216030674597, 50.24010196808846, 40.94688130963234, 54.7164402469512, 81.70210776790496, 59.45191775598834, 45.801316461255475, 51.24108691369334, 50.972345721337106, 52.88260667554794, 46.01328134536744, 47.27679837134577, 47.30066207147414, 41.952612323145715, 57.417360813386985, 62.11301842043477, 69.44120222522368, 63.46485937795332, 62.428651548201046, 56.00019278064851, 55.241971169748616, 57.58769758286015, 69.25837270675167, 68.13547657382104, 65.81806967335363, 65.82115265630907, 60.94080632732761, 63.2154986166185, 69.85036819211899, 69.78386832821754, 73.18534774165, 13.282540786650873, 0.3851708980096925, 0.6837802344272215, 3.643832125010029, 55.13336858441753, 60.94798818711312, 78.74963775757821, 61.207872667620265, 81.85919869330623, 36.107798314863636, 11.672219557146873, 44.59585835856777, 23.818959613000196, 51.2695711658847, 48.67510764829574, 39.44651588316887, 66.31967021572974, 45.533551939072154, 57.12103359160885, 69.25474059197211, 85.55355364276518, 14.281504731024466, 0.8561619683619469, 0.2694030003922601, 0.39054264524771326, 0.2338393909796592, 0.21938115148054016, 0.15046254881928045, 0.3256768162452406], [0.2074247099939854, 0.07419499493534527, 0.03501329398263366, 0.06455441426125265, 0.01962795402974852, 0.08491586683498276, 0.028956365366015705, 0.05744197353300068, 0.049258518903966875, 0.05714741655655446, 0.3995644950097607, 0.2019396430302051, 12.745735991385676, 65.62669331027617, 47.30119943618775, 49.393536813797496, 36.122201258136386, 52.56388664245606, 36.733690923260106, 39.10239850321124, 30.485215994619555, 59.34158148304109, 8.39332695930235, 10.031589192728843, 61.76042872090494, 64.87947394770961, 61.794988724493216, 58.4649827403407, 58.36320507910944, 14.59301740892472, 0.06928459350620547, 0.19185898314800956, 0.23912743545107304, 8.563130286432083, 64.13184273627498, 60.451372977226015, 68.02645037251135, 61.331921546689934, 68.13637871896067, 58.812434134944795, 48.356191496695246, 58.59341682926301, 65.0562394818952, 59.8843708345967, 58.58193997413882, 55.041228186699655, 51.18217683607533, 58.107599904460294, 63.223025644979174, 58.884186052506976, 62.12833135358749, 58.71519073363274, 62.65039490115259, 56.218362854373076, 50.47013328921411, 45.642997833990286, 51.345578855083836, 49.80953554953299, 34.76185267971408, 22.100743785981212, 43.78427682384368, 63.3219595878355, 53.40056350154262, 52.3629867646002, 49.305848306225194, 43.99391966481363, 40.36297375156034, 36.541985081088164, 40.552745865237334, 42.250006429610714, 35.463184233634706, 17.885239201207316, 6.202246854382177, 2.1996134663781812, 3.1707695222670034, 8.837057832748659, 32.27962974579104, 46.197542528952326, 51.89202385564005, 46.372386101753484, 47.06020901280065, 25.527587206132953, 18.947526870235322, 7.030374907678174, 1.4274581257374057, 2.2842677754740564, 1.69934076887946, 8.342757801855765, 1.946706269537249, 0.5705669029585777, 1.352761856490566, 1.6246847039268864, 1.1336684323126272, 1.9823886838651474, 2.5070108425232673, 4.464670698488913, 19.397971860824093, 35.49928180633053, 43.63019827873477, 45.22956040597732, 40.6110675873295, 26.738713133719664, 19.254607269840857, 8.443715687721006, 1.211176428102678, 0.8699491608046717, 3.8052410896747344, 10.106219149404957, 15.243948467316168, 18.500253115930867, 19.268290458186982, 30.946169014899965, 40.00073894377678, 42.73281881886144, 44.942839068751184, 46.882015735872336, 49.46253130512853, 52.355275384841434, 49.35417190674813, 50.400048378975164, 90.3935544721542, 74.33016207910354, 48.05673814588978, 36.81624112590667, 46.583272334068056, 54.323587417602546, 68.84832028419741, 78.77162656476422, 85.98146853908416, 80.58456959262972, 57.68902024915142, 57.328723092232984, 55.72483062744141, 57.30012509130663, 58.48451222142866, 50.646075125663515, 51.05737486193257, 59.71557163423108, 58.55578560982981, 58.88546866755332, 63.86794567108155, 60.69375584202429, 58.37591748083792, 60.12094859153994, 64.27753917632565, 61.09207253302298, 60.79521971364176, 2.9079292906868845, 0.12410778357016465, 0.34625657323387365, 12.705100236400483, 62.86131643479871, 50.905492844120154, 41.73878823557208, 52.27470597913189, 64.33793583223897, 10.085144254469103, 12.405202677173, 38.88114936890141, 18.613089899862967, 38.954831092588364, 36.64642603166642, 40.93611440350933, 39.287644201709384, 36.64041303819226, 37.71231051414244, 48.27544558432795, 50.92061358113443, 0.9229555197300451, 0.14366117426224295, 0.08770713883061564, 0.08631722550959357, 0.06371426861733198, 0.0416223306749617, 0.14389598021103492, 0.1869676343255466, 0.09645143493769631, 0.16228838763650388, 0.10967297870064936, 0.10120799825076135, 0.02663933435424922, 0.14343087291044576, 0.05829323511270266, 0.14428054102726523, 0.020324107702641238, 0.050331409720163194, 0.32555457925604236, 0.4791339721170164, 15.419980518279539, 78.0350289806243, 53.014472838371034, 43.482928968244984, 41.70147865049301, 56.32175653211532, 30.098676220063243, 44.95009937594014, 25.233958575033373, 57.38645645879931, 12.788627109219952, 10.655271545533212, 65.72058700746106, 75.04811271544426, 65.08307633861419, 65.92693113511609, 62.58076106348346, 17.826262443296372, 0.17107592174603095, 0.6438126306860679, 0.261374153797665, 10.252732423044021, 66.21815927567022, 65.66008836992326, 71.80906649558776, 66.32399266765964, 68.32014960627403, 62.066632470776966, 52.08071731751966, 63.6241429082809, 65.44214971603887, 64.12597094812702, 62.834028505509906, 57.86793916456161, 56.01126170927479, 61.334741730843824, 63.7540243517968, 59.559818237058586, 62.587695813948116, 61.0216659884299, 66.25673186394476, 57.40000824774466, 51.909537238459436, 44.879598694462935, 48.61143189091837, 50.97588762160271, 38.28606697820848, 27.047611551900065, 43.86121411477366, 61.88301847827051, 56.16343398247996, 56.76839290126678, 55.5593732864626, 48.877843195392245, 43.232187532609515, 46.967362588451756, 43.46962821099066, 51.98570182246547, 49.16185025245913, 33.351442890782515, 8.823158914043058, 0.2714581078579349, 5.90579362646226, 6.86719548317694, 26.823095083236698, 46.20119425558275, 51.17949785724763, 45.63356061135569, 48.125167815916, 40.00225297866329, 41.606463155438824, 28.21699561611299, 10.817653748296923, 3.678454641372927, 5.094831335929133, 15.228098169449838, 6.525485457912569, 0.7691241452290166, 1.124270433379758, 1.562061857792639, 2.4066229260736898, 3.7982374525839284, 14.017064417562178, 32.9721575398599, 42.1409410045993, 44.03589294802758, 47.62667379071636, 41.21137849746212, 39.424797719524754, 24.387801347240327, 9.538016761502913, 3.6743604223574367, 0.7372059192388289, 0.6333433956869188, 8.259686904568827, 17.896971010392715, 25.182765760729392, 19.661966985271825, 25.5577306209072, 39.68178749084473, 41.99198507493542, 47.546437786471465, 50.12851445905624, 52.105738116848855, 51.942375321542066, 56.81567315132388, 49.900679665227095, 43.733748851283906, 69.47135740710844, 83.02430737403132, 59.83697291343444, 48.988148089378114, 50.15168782203428, 57.58742301694809, 63.90503952580114, 74.03811808555358, 72.26399083291331, 78.89740913145005, 63.7912162657707, 61.310352433112364, 60.128220665839414, 62.1597416939274, 59.02489716006864, 52.976974979523696, 52.35537344409574, 59.090565481493556, 59.08903183475618, 63.0953368063896, 63.04649545300392, 60.35999744169174, 62.230689525604255, 64.14599072548651, 67.40753173828125, 66.36433032251173, 61.2963064255253, 1.7796949345257975, 0.1452989629920452, 0.4015412163590232, 15.778201760784274, 67.43006183255103, 55.42556162803404, 46.43077842650875, 56.264721347439675, 66.21876332067674, 12.395007456502608, 13.640315859548508, 41.56148925904305, 25.301501789400657, 34.50585919041788, 34.71892626054826, 36.745528636440156, 48.937855459028675, 37.7363036524865, 37.77422120494228, 57.32960562552176, 58.20004232468144, 2.771316814807154, 0.14812437186558403, 0.09301618943291326, 0.184409789320442, 0.09192580116852637, 0.029430267355975606, 0.11816644996044137, 0.14196929972498648, 0.3501353683250566, 0.23226515690405525, 0.16966442006730265, 0.2470054086898604, 0.06552610486265152, 0.27439911939924766, 0.14686365161211262, 0.20610066491269297, 0.14085278786238165, 0.22976873682871943, 0.7009959461227541, 0.7891968745858439, 26.818584357538533, 90.42373318825999, 57.73652799667851, 66.94182088298183, 46.527060847128595, 74.77395472988006, 49.00425726367582, 54.59710213445849, 34.29535735038019, 70.3489092857607, 12.90549118672648, 16.4172911836255, 70.10711869885846, 77.54849818445022, 71.9548531501524, 73.21009005269697, 66.2372455289287, 18.982465382545225, 0.3012411242290851, 1.8420337765447556, 0.4003092856897462, 14.045493756571124, 71.7121761075912, 67.7717944114439, 75.54024465622442, 68.54907481901108, 72.94973881013932, 67.46399033454158, 56.68236747864754, 63.97201791886361, 68.0352678606587, 68.55423665815785, 66.13023542588758, 61.82357103593888, 58.20999337780861, 64.64490052192443, 67.91292913498418, 65.03329361638716, 64.48735460158318, 64.02970813935804, 65.02035371718868, 58.991156931846376, 53.32317121567265, 46.902969037332845, 52.298848167542495, 50.3890343635313, 39.62960820044241, 48.34815456021217, 61.90192822487124, 69.30336229262814, 58.94750487419867, 61.299832636310214, 55.60516303585422, 54.237605141055205, 48.2145703992536, 55.693204556742025, 52.78255093482233, 60.87715410417127, 59.61091103092317, 41.50816463655041, 16.88428367337873, 10.850859553583208, 15.632925994934576, 26.403858430923957, 49.30426366867558, 53.15295211730465, 57.556487283399036, 56.99045396620228, 55.748913980299434, 45.82062628961379, 46.71446384922151, 34.00955777014456, 15.768468399201671, 7.390339153428232, 8.502102128921017, 30.05186273205665, 18.844462671587547, 1.8700284679089825, 1.7351203844431908, 2.3078360720988247, 2.887371413169369, 5.212052839417612, 18.74698392806515, 38.001483332726266, 47.27055788040162, 53.92624739677676, 53.845175927685155, 48.239469605107466, 43.860594380286436, 37.24244194646036, 30.84473848342896, 16.306232213974, 7.094787580351676, 1.022669094945154, 9.413726656667649, 28.99180885284178, 34.14614254428495, 28.6479248539094, 40.117382387961115, 45.882772322623964, 51.448968610455914, 56.18091990870815, 51.77713371092274, 55.559616473413286, 57.374446161331676, 58.48822278361167, 50.435863541018584, 44.91742603240475, 52.57477121968424, 70.85714647846838, 63.31736649236372, 57.0876032306302, 56.20249294465589, 57.19544487614786, 60.52966740823562, 70.62894298184302, 66.48647292967766, 77.75563855325022, 73.00693481199204, 66.46566867828369, 63.6585577841728, 62.91027153691938, 63.48151768407514, 56.38349856099775, 56.785298316709465, 66.47702786230272, 63.135541100655836, 65.67858234528573, 69.8699329745385, 65.20546605510097, 64.82876946849208, 67.74742864793348, 69.99673535746913, 66.8109078561106, 69.49007495757073, 6.193502910675542, 0.3492769821276588, 0.9340313737911563, 15.176470952649272, 79.72212668388121, 61.794223862309615, 52.83735821324011, 60.74591944294592, 76.65294262670702, 16.93803583422015, 18.580657782093173, 48.10952932603898, 28.093654724859423, 49.68642803930467, 48.0907529400241, 54.245771515753965, 55.78405841704338, 45.99063750236265, 53.09278295886133, 62.651932470260135, 77.0025513249059, 7.237434867889651, 0.5809820215067556, 0.47864695470179286, 0.31407426141442796, 0.26693337807251566, 0.16723366904883616, 0.21704484378137898, 0.39569029644612347], [0.06992047712687524, 0.0563732234220351, 0.0878702312888157, 0.0508190400057262, 0.02884430585489158, 0.060373083387892094, 0.022810078338689865, 0.10277594274450695, 0.05571374812373712, 0.11261980484930739, 0.14534210906394068, 0.29856288084580057, 5.518133524925479, 63.927287209418516, 48.418788602275235, 38.16272020339966, 24.64714454066369, 52.1450206541246, 44.078066272120324, 37.99513693778746, 31.710578164746686, 84.30249798682429, 32.13223099708557, 0.9421867168238087, 46.50217340838525, 62.5651696420485, 68.36535884488013, 53.86993000584265, 60.17927031363211, 15.519739139464596, 0.1219781434103366, 0.2578845007284995, 0.028695512427798206, 4.232655148352347, 61.4751821948636, 61.00330929602347, 64.991065379112, 60.71986706026139, 64.86783235303818, 54.52300463953326, 57.341239375452844, 63.005538063664595, 61.95344463471444, 64.45647378121653, 63.22595565549789, 60.638936796496, 53.209442092526345, 51.39488304814985, 57.56219040962958, 60.986945167664565, 59.801444084413596, 64.26715666247954, 62.77802490418958, 63.68237833822928, 55.03046520294682, 50.82144429606777, 47.523829244798236, 50.15012279633553, 50.63298225402833, 47.683481477922015, 34.89078098727811, 41.60231328779652, 52.944442841314505, 54.68059370594641, 47.32531416800715, 44.96318440283499, 41.70366733304916, 35.90301921290737, 43.076139957674094, 46.14704593535393, 33.820911376707016, 14.534282857371917, 4.263255028955398, 3.644290306875783, 7.090314607466421, 21.20123055673415, 39.79694827910393, 45.41971298956102, 50.35959697538807, 43.57945457581551, 30.72189965555745, 15.505483285073312, 6.2115664059116, 4.07448459056116, 3.455763055432228, 2.2204277688457124, 2.670862953509054, 15.61272971091732, 6.360418392765907, 1.1417342962757235, 0.9473794446356836, 0.23061710259606763, 1.7584063929896203, 1.5103412395523441, 3.436167629495744, 4.794273347623887, 6.734262435666977, 22.733810409422844, 36.452076511998335, 42.2371724344069, 44.58307535417619, 36.56295014965919, 31.717134406489713, 21.530662582766627, 4.60458948727577, 0.9886718901895708, 3.249273554932687, 8.613145409091826, 15.48644704203452, 18.80170295315404, 15.495636174755713, 30.388368752694902, 40.984559597507605, 44.63115576774844, 47.6438263154799, 46.814292092477125, 48.68487435002481, 48.98561031587663, 50.13340565466112, 45.567390226548724, 45.54609175651304, 73.79861031809162, 70.34418675207323, 67.95514952751898, 58.19608857554775, 66.47785940477925, 68.36302895699778, 57.15472675138905, 44.509001393472, 40.857929798864554, 50.39216049255864, 60.56591403099799, 57.11983334633612, 56.057518220716915, 49.663262521066976, 48.93244258819088, 53.02664003064556, 57.32314548184795, 60.861809792057166, 63.405921843744096, 58.05600896958382, 62.673203483704604, 57.42802573788551, 59.836957223953746, 59.184643530076556, 71.85804905429964, 34.960661934268096, 0.827853242235799, 0.21734383257646717, 0.09695401159866203, 23.17749127264946, 53.798374206789084, 37.071230488438765, 52.224170161831765, 63.893378319278845, 55.75271867936658, 6.432222281732868, 9.907409894850947, 23.61547685438587, 15.456735087979226, 41.40125651513377, 36.889887548262074, 47.001110661414366, 39.591004233206476, 29.9307301352101, 31.857576831694576, 55.70020598749961, 36.07472488957067, 0.5493025698008076, 0.04324204356019055, 0.13213444681417558, 0.05477287340909243, 0.1013164456573225, 0.0328975583186313, 0.015565850377653637, 0.13325170944294623, 0.12594037313735293, 0.05670975052541303, 0.03433142593430896, 0.03339545035194005, 0.027610209072008732, 0.025815720887734525, 0.04078169473476949, 0.1173141694838001, 0.07064597771292733, 0.024675602025742975, 0.09535414422111166, 0.33121900272465526, 6.197192880415148, 72.53614056494929, 54.580710549508375, 40.54352045059204, 30.435272455215458, 58.836458652250236, 34.13559529089159, 45.32327367413429, 35.10722521812686, 84.30293729228359, 34.61384204126174, 2.130971007770108, 44.89143248527281, 70.11730901656613, 73.06980256111392, 61.542811701374674, 64.44000767123315, 18.729141066151282, 0.046262237949356924, 1.2382766964935488, 0.12093354422118395, 4.420250346583705, 62.606684007952296, 65.99397228610131, 68.71524995373142, 65.19757032394409, 66.79819937675231, 57.81239055818128, 60.906705241049494, 67.47195274599137, 66.83410475330969, 66.22278767247354, 66.76176055785149, 64.07274438488868, 57.298320801027366, 54.02922530328074, 58.4582244965338, 62.99006823570498, 61.25806723871539, 63.80119477548907, 63.4383951464007, 66.36009416272564, 56.174934371825195, 47.34488287279683, 47.485091916976444, 47.61410651668426, 54.12270715159755, 48.94912835090391, 40.68038371301467, 44.66018915176392, 58.5245321642968, 56.3530295894992, 54.76220253975161, 48.83160629580098, 47.220947742462165, 44.99718350748862, 46.69010593045143, 56.64687787332843, 46.17725995279128, 21.16929069642098, 5.763847462592587, 5.048268389317298, 7.086615812393927, 19.853329620053692, 44.08905283097298, 52.72421744561965, 48.32042732546407, 49.441181844280614, 44.56791931583036, 33.4165620803833, 27.246799315175704, 16.077563916483236, 5.62011024644298, 3.859121462991161, 4.640146753480358, 13.60657367014116, 7.899102924331543, 0.3768032260479466, 1.4579614179749645, 1.1652242680711131, 1.3997213302120086, 2.063483932325917, 6.412971779223412, 18.916010625900764, 31.822063692154426, 36.3500831204076, 43.48687487263834, 43.856691621964984, 43.83575008761498, 36.80703140074207, 32.35881063245958, 16.60228486984007, 1.6414760029123676, 0.625487746250245, 2.36934692628922, 12.641625500494435, 25.676133248113818, 25.743992213279974, 21.688330096583215, 41.04835302599015, 44.180255782219675, 50.822271916174124, 48.69903410634687, 52.60028231528498, 53.57050803399856, 51.16043906058035, 49.601489113223174, 47.460275080896196, 39.101661097618845, 59.261521985453946, 69.61472788164693, 69.82808912954023, 60.10476881457914, 61.583690643310554, 64.43280227722661, 56.442694971638346, 51.00316378378099, 49.91347051435902, 53.59040229551254, 59.50543065224925, 61.73290152703563, 57.61902163105627, 52.197980496191214, 51.07955586525702, 58.083579309525035, 61.29734977599114, 62.04446715693321, 65.42826060325869, 62.992288297222515, 67.17326425736951, 62.452260294268214, 65.71445634288173, 63.12879070158928, 73.10930082874914, 32.59544330258524, 0.7824970373222906, 0.5250276949617171, 0.134809625845763, 28.670680484464093, 61.28901866174514, 40.353210972201445, 52.4697458359503, 67.42851641870314, 56.17143561763149, 8.010621301589474, 12.629465172367713, 32.3445685063639, 17.630267489340998, 39.489030453466604, 33.779126367261334, 46.00382058851181, 50.13807327516618, 30.31643444491971, 38.52220542969243, 63.916363408488614, 42.503713177096465, 0.3113115338548538, 0.06465071151333471, 0.0748451354522859, 0.010241744232424086, 0.09748727008099518, 0.09564292872504843, 0.05221742625919081, 0.05222774163309125, 0.25662810121092106, 0.230269605113614, 0.17344478818197406, 0.12737671904746564, 0.2359154739327008, 0.2928432071160886, 0.07223177205530867, 0.24943407594917283, 0.22698175492546252, 0.20948608405888083, 0.5060179279215875, 0.6083388987087435, 9.665971340671662, 89.18198923910819, 59.844519553645966, 55.921117797974624, 33.56368234080653, 72.39069907895981, 62.34804684115995, 49.93566328479398, 38.075078764269435, 91.29431109274589, 36.20599485212757, 6.392360214264163, 54.62421747945971, 76.65912428209859, 77.94072735694148, 69.13124868946691, 74.41531673554452, 21.841473156406035, 0.14266325281031672, 2.567971094000724, 0.293021613671895, 6.965454778363628, 68.03131411152502, 67.8112377658967, 71.92265049103769, 68.46769348267587, 73.80137166669293, 62.08748379061299, 64.87899149617841, 70.00057143549766, 67.23986610289543, 65.81908948959844, 66.76622421510758, 68.93905255102342, 60.95116922932287, 58.03099601499496, 63.31428350940828, 65.17995495950022, 64.62051514656314, 67.03937807390767, 66.35750539841192, 66.43201474220523, 58.23970925423407, 52.791584153329175, 50.261400438124134, 50.70449098463982, 54.49430465698243, 46.67042347692674, 45.33220883338682, 53.59041406262306, 62.184982145986254, 61.357236523782056, 57.61649170229512, 55.41256289328299, 50.72243975054834, 54.253867287789625, 54.09335605559811, 63.33349920088246, 58.26602051334997, 28.663941852508056, 14.957675260882224, 15.800988770300343, 27.10113621527149, 43.64882169231292, 49.70974652997909, 59.07147922823506, 57.2729116870511, 58.77657190445931, 54.25521266075873, 46.83606516930365, 37.920258891197946, 26.190065722311697, 14.346562143295044, 9.02315958853691, 14.126703489211298, 34.39425991427514, 25.522674437492128, 6.57878311411027, 3.288495295470761, 2.1855878060863865, 3.680485203381508, 5.438863894631786, 16.17271375271582, 28.16265117737555, 46.312820988316695, 47.685481886709894, 51.66600119683051, 54.057882139759684, 47.01731005022603, 46.59930698333248, 40.01305126374768, 34.33698938738915, 18.79271876427435, 2.570759163748834, 4.763611689690621, 21.774222158616592, 37.0210555291945, 33.62270224478937, 31.056085594238777, 47.23420927601476, 46.68653265122445, 53.81578168561382, 53.66841431586973, 57.02914814795218, 55.252969495711795, 57.38773515147548, 53.683421304149014, 49.69408450588104, 42.83655374280868, 52.07175862404608, 55.43039398808634, 62.05213146824991, 56.480239898927756, 65.43559935785109, 72.02066267690351, 72.59112435002481, 68.20824438525786, 63.62389579896004, 54.76281835186867, 61.01422917458319, 63.37963019647906, 62.439618495202836, 56.50177371117377, 54.884321612696496, 60.20547174638318, 63.05398718003304, 62.024294407136985, 68.73057857636483, 64.89835231534897, 70.1691549055038, 64.94571885754986, 69.42791323507987, 65.79999146922943, 75.44396615797474, 40.22908364572833, 1.6999716576068633, 1.4718155971457882, 0.5475526411206492, 28.619175841731412, 68.18333733466365, 47.69819428843837, 62.95111909989388, 72.95026440774241, 67.41790248501685, 13.20925129998115, 17.65295251723259, 32.41072516287527, 20.80308056646778, 51.97008686680948, 50.73904314348775, 66.85028060790032, 54.32900028844034, 39.05355714982556, 47.06049534582323, 67.10676439346807, 59.17133885045206, 2.1377844099075567, 0.4336540593254951, 0.2934044124858995, 0.19539855450632113, 0.20044079200635034, 0.176549022416434, 0.38011845621851187, 0.34722193594901796], [0.09355713177712695, 0.061884697436565356, 0.08835566290203603, 0.09939911910482954, 0.07383092697108946, 0.03551770159373841, 0.05174142518831838, 0.025615670432847355, 0.05516574244886156, 0.035522700317444346, 0.05835780483340064, 0.06280858032104951, 1.0455245620781377, 54.46089390785464, 51.927293808229514, 43.69163436274375, 36.58662165364912, 39.69914005648705, 50.78209507849909, 30.60639762109326, 24.861152979635424, 55.563927158232666, 73.0495160625827, 2.646763420874073, 22.64162882681816, 52.22092636169926, 61.200027927275634, 61.17297926256734, 59.62097975515551, 25.113351575789917, 0.12140184610841737, 0.4393094123130845, 0.11747180739597929, 1.8513126334836407, 52.00952629889212, 71.75530649000599, 62.790368603121856, 63.78627015698341, 60.19872134731662, 53.32363405535298, 56.64852134643063, 68.63656720807477, 64.46667194366455, 65.94842572366038, 63.964318306215354, 60.98663137805078, 50.760012134428955, 51.93326365563178, 57.13810374659877, 58.276144150764715, 59.88818730077436, 65.5942709984318, 64.61053663684477, 61.84932531849031, 60.454883498530236, 55.67771511693155, 52.87775862601496, 54.90709489391696, 57.58373206661594, 58.958601259416156, 60.10369016278175, 51.532311131877286, 52.85037263747185, 54.47225701424384, 48.63379332327074, 44.17764740605509, 40.26957427301715, 35.34613286295245, 44.41890847298407, 48.599335301306944, 31.56767837462887, 14.468591982318511, 4.144261594741575, 8.44145836368684, 24.60715597675693, 36.34982424397623, 47.42011393270185, 47.65698194503785, 49.05327120134908, 39.69689646074849, 25.659151346452777, 15.853524015795802, 9.170524016503366, 5.178772018801782, 1.5465313556694216, 3.6501010531379334, 2.778772995356591, 19.350995594455352, 12.438344743943984, 0.8277420062691936, 3.493089555732666, 1.4351203532949572, 0.6728023783333841, 1.1598356668987584, 2.083948898699976, 4.60059896592171, 8.836511642702165, 23.87262155932765, 35.44005401672856, 44.32506184424124, 48.89880041922293, 42.24634293586978, 35.48064662564185, 34.50641616698235, 18.439585816475656, 2.585614650480209, 1.1483979129022168, 4.658302424415465, 10.707417495789068, 17.70290978493229, 19.27617246104825, 26.568135138480898, 40.19929324426959, 44.74611259275868, 45.147037659921956, 46.74968673336891, 48.39019452371905, 51.207162334072976, 51.86689715231619, 54.21482401509439, 42.29980484131844, 48.43539591758482, 54.13763177010321, 56.61451831940682, 57.169796497591086, 49.609973199905895, 42.327606601099816, 39.9712231082301, 42.859954603256725, 53.37225967837919, 55.653855339173354, 58.65914006387034, 58.87403888087119, 54.256930658894206, 47.95165000423309, 49.23999955577236, 54.52487953247563, 62.09847034946565, 57.937176842843336, 57.784835907720755, 59.65589277205929, 62.07289257357198, 57.00989715514645, 66.24635327246882, 62.431256001995465, 64.15993867381927, 12.797198468639007, 0.2819453612450631, 0.6440246225364747, 2.231063275567947, 45.996799545903365, 45.98375374271024, 40.310202183262, 67.04895650186847, 57.554420194318226, 45.01831331560689, 3.441223809795995, 17.231684077170588, 18.150285520861228, 26.793408624587524, 32.98752538619503, 39.34025887520083, 41.12081097018334, 32.85993656804485, 35.977724675209295, 36.08806879289689, 61.6994397870956, 27.90958573741298, 0.36823998716089035, 0.058266349257000034, 0.11678720058332528, 0.04356762326713051, 0.034442681053112593, 0.04358992025616669, 0.15790592037862347, 0.03552108387192411, 0.1881093504808603, 0.14628121028504065, 0.1275704320399992, 0.089067718645017, 0.07957505422734445, 0.03257653300440119, 0.02873428222242623, 0.042984572900158745, 0.02119976918273155, 0.08586449818986078, 0.036567517841655406, 0.1262085575370058, 0.6561836636354846, 58.61855922206756, 59.61832431054885, 45.939003421414284, 43.31625961488293, 53.951680044974054, 37.056003847429835, 35.3761625289917, 38.6993278995637, 71.28175089436193, 68.2515081282585, 4.109957035510771, 23.88561441052345, 54.89751646595617, 66.97177994635798, 65.84286689758301, 65.8827103337934, 29.668733458365168, 0.5810907447049695, 1.2132138542590605, 0.18068419649235665, 1.6754362515864836, 52.821319641605506, 72.87943424717074, 67.01955441505679, 65.83274718253844, 61.896142728867076, 58.039421266125096, 60.32251919469526, 70.06753413907944, 67.39932613988077, 65.70342271558701, 65.98250327571746, 62.8717460170869, 55.07818868083339, 55.4213450800988, 60.63092731660413, 59.57147944358088, 62.16552718993157, 66.00981081685713, 65.89155920090215, 63.39642186318675, 63.2516981709388, 53.372083171721435, 54.118172891678356, 57.27333922539988, 60.715211206866854, 60.12636930711808, 61.66884137738136, 53.41519786465553, 54.39865373796033, 55.05792179415303, 53.40218736279396, 48.13910007476807, 46.37462577512188, 44.66633550582394, 47.701096842365885, 55.80909490585328, 42.19110419673305, 16.2019814983491, 6.273209394947176, 10.004642509645032, 19.608628634483583, 39.505665225367395, 48.43318370080764, 52.871682874618045, 54.102165699005134, 49.87902818187591, 42.19251232762491, 30.213809551731234, 22.811079140632387, 12.394435771049993, 4.4760264504340395, 5.082020874946348, 4.105740487575531, 22.486834449152795, 12.793188825730356, 2.0311964519562262, 2.491925161692404, 1.0620010908572906, 2.7972522618309146, 1.9263408333063128, 4.034972104334062, 12.996660797826706, 28.890996094672914, 36.05592889170493, 44.31638556142008, 47.913948182136785, 46.95979633638936, 45.50658956650765, 40.082065366929584, 34.74577488437776, 13.010208664401887, 4.558757082108529, 2.2302925298290868, 8.48023001224764, 20.617279852590254, 28.432396496495894, 25.151818260069817, 35.94684385484265, 48.08051947624453, 45.95505768252958, 50.77650177863337, 47.56111529565627, 51.76679042077834, 51.2456407854634, 54.52422057428668, 53.45551198528659, 46.954097132528986, 44.069593952548125, 50.16176439100697, 51.14786001943773, 56.9378157584898, 51.26335028679141, 46.28663524504631, 43.789889735560266, 49.012498163407855, 53.99790909982497, 60.978406167799434, 60.15395141416981, 61.06001892397481, 57.97077978810957, 52.826473636011926, 52.02232107039421, 58.777917277428415, 64.05342278941986, 60.670962948952955, 59.446438204857614, 60.75734922962805, 64.33551572984265, 62.471927058312204, 68.13062852428806, 64.59732217173423, 61.173465636468705, 11.988168435712016, 0.551375113427639, 1.442908954716498, 4.745304026911336, 54.54427173060756, 50.1559788950028, 48.4211459467488, 67.04003703209662, 62.76324541338029, 45.51240251910302, 5.771850568632926, 21.268722780289192, 25.010738449711955, 28.450884588303108, 35.3538050190095, 31.000527181933005, 45.02862914916008, 43.54749118128131, 34.925525342264486, 37.97418755869712, 70.29614556220271, 30.346244458229314, 0.3456868489663447, 0.049187081205027725, 0.16732181512540387, 0.0679611306517355, 0.06414609322805079, 0.06778869958173844, 0.09093175612149701, 0.04258868930440757, 0.5986983256955302, 0.2575243474735368, 0.33198484550079993, 0.2817542376297136, 0.23246391075513057, 0.13743333909059727, 0.12048087818848512, 0.10650373424493498, 0.15970339247536275, 0.2111942149818905, 0.21355578826079447, 0.22719788365066054, 2.2204995972494928, 79.1740538997035, 62.104216621768096, 61.23501546921269, 45.71079600241877, 61.07472388975082, 67.61370720401888, 40.23694799792382, 31.74040778990715, 70.30778715687414, 73.91939578517791, 7.097938224192589, 28.83872070620137, 62.59109258651734, 72.5440009947746, 72.87908123385522, 74.64483030380742, 32.48931181046271, 0.895209163427353, 2.725458423937521, 0.21685270892996944, 3.6378387433867303, 56.741403072111076, 75.7943279512467, 72.03822705053514, 69.81166224325858, 66.08379456304735, 59.77785495019729, 62.699691249478256, 71.9314601344447, 69.43298093734249, 71.89578225535732, 68.60069321047875, 65.68874912877237, 57.51052102734966, 58.13354638315017, 63.49232381389987, 63.574646519076445, 65.84554979878088, 69.67420670293993, 70.94184613996937, 65.35246864441903, 65.48486040484521, 55.6897371815097, 55.963444094504084, 59.21488108173494, 61.42128098395563, 66.15695461150139, 62.679620481306515, 56.34896209163051, 57.95179943884573, 59.88661835270544, 57.74702425925963, 55.97495232858966, 51.22892756615916, 51.83886397269465, 50.38263697778025, 60.764005491810465, 55.806160972964385, 31.70386306701168, 23.042595078868253, 30.65332485783485, 43.07916410507695, 50.33102643105292, 54.212949122152025, 54.88801648539882, 61.67724701666064, 58.874682149579456, 53.46199566318143, 47.49053616677561, 35.403105289705344, 24.54463927976547, 14.622559720470061, 14.039885747817255, 26.65222683260518, 39.73329997831775, 34.12906454455468, 13.091901829165797, 8.503323947229694, 5.43741604974193, 7.052427453379478, 11.556142895452439, 14.648679764040056, 26.17302694628316, 43.72748874848889, 51.995146889840406, 53.16653136284121, 52.88627801402923, 52.48774559267106, 47.71250309482698, 44.96264703812138, 42.257455010567945, 30.597395781547796, 14.362619346187962, 2.7065111696720128, 11.29212913974639, 28.61525543274418, 37.47431285919682, 31.48241585300815, 44.952625382331114, 50.311920565943566, 52.83138052109749, 52.28978357007427, 52.016704236307454, 55.32582752166256, 53.907372951507575, 57.1302511615138, 57.60209268139255, 49.53979415278281, 50.00796433418028, 51.43403222483974, 51.815792591341086, 54.5310611878672, 55.64639499110561, 51.20123955511278, 48.99115262493011, 49.03245910521477, 53.38549375534058, 61.07870117310555, 63.41798313202397, 62.81208676676597, 61.85648364405479, 56.410174600539676, 55.19727183926491, 60.51681380118094, 66.69930073522752, 63.507542610168464, 60.372211702408336, 60.44838805352489, 68.55291089703961, 65.65191415048415, 73.27091816932925, 68.7830912682318, 67.78444797761979, 18.71858204564741, 0.632327317951187, 1.9081219141521764, 5.166510689643122, 54.5754506511073, 57.83495595378261, 50.987486070202245, 77.9176716650686, 69.72279702463459, 53.19289753513952, 8.345089650923207, 24.318171431941373, 25.088981889909316, 38.47823566006076, 42.83165470246346, 53.257377378402225, 59.681125379377804, 45.28719571328933, 50.516872252187426, 47.97562745309646, 80.37560924406975, 46.129210918180405, 0.46086118166004464, 0.1495835548567195, 0.3285991352412009, 0.11604584963811983, 0.25189658897298, 0.10746676039191023, 0.1984442136580906, 0.24656325338348267], [0.08529059874314456, 0.10449096079795592, 0.014993763686488233, 0.08262188549363807, 0.05838208982060033, 0.03614657167946139, 0.09305696063224347, 0.09171043853125266, 0.039542639447796735, 0.04726517344674757, 0.06948457309795965, 0.1874411379497859, 0.1426219453494395, 37.802772137426565, 60.19201017195179, 40.0148045632147, 27.426624298095707, 37.460972878240774, 49.76108251079437, 46.75242062537901, 23.343772311364454, 26.083059541640747, 39.9969107104886, 6.345953672162949, 25.785384985708422, 67.18067753699519, 51.18559714286558, 56.24228146768386, 57.2910761833191, 40.28856246702133, 1.47634090915803, 0.2439241417713704, 0.03309311758306238, 0.5521141737699509, 32.58955974732676, 64.58875963764807, 62.386670420246745, 62.41382891131986, 60.39025852757116, 53.43140509820754, 60.160631210573264, 61.751097402265, 63.55179086808236, 61.88624658892232, 62.36408933516472, 62.06865641378588, 55.68017444302959, 55.681955199087824, 57.532639272751354, 60.881049017752375, 61.61430866487565, 61.36281021179692, 64.89492808618854, 63.186869236730764, 61.108126794138265, 58.546097355504195, 61.07373153009723, 58.32533459509573, 58.01949954801991, 58.893211426273474, 54.20095451416508, 56.85961938673451, 55.97686252286358, 54.43248025832638, 49.517624916568884, 43.11113142198132, 40.76840169968144, 32.56558425964848, 39.81852131505167, 47.919565016223544, 43.81869562210576, 30.12023945008555, 22.934441604921897, 31.603391555047807, 40.7533750995513, 46.51106542156589, 48.57624038573235, 51.65036270695349, 51.61133512373894, 39.31392800423407, 25.960636485007505, 15.88410379425172, 5.889288783073426, 1.2044152425181482, 1.2694499785861662, 2.906864122036965, 11.430954567847714, 30.351773038987194, 23.335327448383456, 8.450036587253694, 3.1505568133246515, 2.3795495014036856, 1.4584757387638094, 1.7673706022962448, 3.7538759362313057, 1.6952546397524497, 8.423988126939344, 22.247922881957024, 35.630292892456055, 46.30910258139334, 50.166533993136504, 46.81699068315568, 38.619052671617084, 35.04374165688792, 30.63438177108765, 11.739585284263859, 1.915900832222354, 4.9061270875315515, 13.479887977723154, 24.674699191124212, 22.76897249683257, 22.884229383160992, 38.383471196697606, 41.04701549776139, 45.35329941780337, 46.31133833239156, 50.4372638271701, 51.032248158608716, 52.78328441804456, 56.37480266632573, 58.35150857125559, 44.75689518836237, 46.00141225322601, 61.45536638075306, 52.61210433898434, 55.278398221538914, 50.98434032932405, 53.15204604979485, 50.980567009218284, 50.88118591616231, 54.09556042763495, 60.40998412716774, 53.40170098889259, 54.79546423881285, 47.00386416527533, 54.89402555650281, 57.21598240637011, 61.97210727199432, 58.902107361824285, 55.677495464201904, 49.88885371915756, 59.69629318483415, 55.7302591877599, 61.23033215922695, 55.9907869369753, 35.415425454416585, 1.3573196506307972, 0.21276068092594225, 1.222290954282207, 11.395049191290333, 55.113466478163204, 59.63426090055897, 67.1646507324711, 55.795409756322066, 63.5938229868489, 36.61533732568064, 3.1732695429555835, 24.522548490954986, 16.144831584345912, 27.195078942083544, 35.819413892684445, 40.43947173703102, 31.007636477870328, 30.069733050561723, 36.99260657833469, 38.61740135377453, 63.20693608253234, 16.54525164634951, 0.18248099443172255, 0.22957624957686473, 0.05670546043303706, 0.039115564582208474, 0.05308371082308793, 0.014032307062147847, 0.04955452378658999, 0.16496745839474664, 0.2627788832591426, 0.21567118684611014, 0.05599210617102443, 0.04457803578266213, 0.06083486586688988, 0.044695645600797675, 0.1122312910193878, 0.05256508462010853, 0.05527260022297983, 0.1531564357179788, 0.03641978544633716, 0.09118970558648148, 0.10779836154993504, 42.016115496235514, 69.49701755277573, 37.834574714783706, 26.70510430489817, 53.027702992962254, 43.64871971068844, 41.47398902523903, 30.564163500262847, 41.3278179783975, 45.87233489559543, 7.547492836752246, 28.018372674142164, 72.48707955883395, 59.581571702034246, 67.80478938933342, 65.03744348402947, 45.833762307320875, 2.4967393807826506, 0.10930964618080086, 0.2901012252175039, 0.8098610238202157, 35.616403779675885, 68.25465386913669, 66.08629703521729, 64.8037329796822, 63.146308006778845, 55.48982966330744, 63.08419335273005, 65.67122790121263, 66.98676340041622, 64.9229455763294, 64.45873698880597, 63.86357615070959, 57.25199760929231, 58.687953795156176, 61.224005376139, 62.73201157969814, 63.33498185680759, 64.86381584598173, 65.10574763821018, 65.24064971554664, 60.122392023763354, 58.16059504785846, 62.35227515620571, 59.68191769815261, 59.86652012794249, 63.20151536695419, 57.61922559430523, 59.347417969857496, 58.9793231410365, 57.26230167573499, 53.42338385120515, 48.94162877913445, 44.49008772450109, 41.909752584272816, 46.24432856036771, 52.474099666841575, 49.17545695458689, 27.001925745318015, 16.790072264209872, 25.434179882849417, 37.38852277878792, 50.433278699075025, 49.221289850050404, 54.35249528577251, 53.93228000210178, 48.54714816616428, 41.439499624313854, 28.19794466418605, 19.338228279544463, 11.770702427433385, 5.017520439240241, 6.50843148269961, 6.934717614804545, 29.824859480704035, 18.08654700556109, 0.555552069938952, 4.338523351377057, 4.0256368633239505, 3.8675405854179017, 3.6139728369251376, 4.70348616761546, 10.64451248415055, 22.967362057778146, 35.254651423423525, 44.14735494121429, 52.246841461427756, 50.558767087997936, 50.281632023472945, 43.63569351934618, 43.10653440413937, 29.55108980978689, 7.289422942746071, 1.8998128632383964, 5.121911869895074, 17.91482367823201, 32.490400268185525, 26.96648713081114, 29.162045601875555, 47.68132025195707, 42.84997609353835, 49.92388048479634, 48.93671797167871, 53.88100285683909, 50.90982706316056, 57.667882596292806, 54.72981945160897, 57.862726334602606, 46.8358886626459, 46.94067870416949, 60.445913037946156, 55.42937809421171, 53.26734019863991, 54.45498289600496, 51.68569541746571, 53.308156382653024, 52.38208086259904, 57.11008625645792, 61.65164178417575, 58.272751300565666, 56.58372379118397, 50.7329007117979, 55.45028824960032, 59.26445199597267, 62.846831121752345, 62.921156114147564, 58.5121060955909, 53.39879843496507, 60.553899811160186, 58.93367459697109, 59.638638265671275, 56.9952824038844, 31.706787193975142, 0.6295845393211611, 0.9927259661978292, 1.3088501869670808, 14.883696417654715, 65.28801625774753, 63.9263262287263, 70.50201508306688, 60.099587363581506, 72.76818013960316, 37.28319929492089, 4.743939532387642, 31.03524211914309, 23.752118502893758, 30.3187878670231, 34.68450353991601, 31.709185723335516, 40.34214988831551, 39.28756575430594, 34.005807984259825, 46.32579226647654, 73.79846911276542, 20.165367895557036, 0.1752095023590711, 0.31806233128713024, 0.03612919680533871, 0.06185365555387351, 0.08504820852390221, 0.02073721295493024, 0.049263241836020065, 0.11381492499382266, 0.7073205841645118, 0.4120669273599502, 0.23465700597772676, 0.2988028195836852, 0.19834586329037146, 0.1382801880038554, 0.18468541243383962, 0.1894858266196905, 0.1458865983952438, 0.2877415518366522, 0.1385306834333366, 0.45598515459606725, 0.34559835048933185, 57.40577020952779, 75.30136446799003, 55.172921765235166, 37.53631768688079, 55.03942389642039, 67.71014259707543, 59.959456766805346, 31.252704205051547, 36.13488620327365, 51.45965706917548, 11.7398412189176, 33.35094082740046, 76.29366920840356, 66.18338354172246, 72.02952723349296, 71.36563470286708, 53.09219460333548, 4.157731994505852, 0.6563639088023094, 0.23367388534449765, 1.4771278346738508, 44.768383810597086, 70.77454920737975, 70.90001013971144, 68.68314143150084, 67.10153979639854, 58.375034947549146, 67.26456919024068, 67.38786497423726, 69.29252870621221, 66.13269082961544, 68.27992962252709, 67.91564341514342, 59.36286818596625, 63.20099761409145, 63.67243905221263, 66.91751787739416, 69.00535629641625, 65.04515878615841, 69.7018829468758, 66.48502165271391, 62.7620255562567, 64.33762596499535, 63.67358438430294, 65.64623848084481, 63.67494544675274, 63.31890798384144, 61.31765980874339, 64.11714561523931, 61.58471438192553, 61.34228837105536, 55.706395487631525, 54.58255406348936, 47.70423866087391, 48.15573876903903, 50.22975083320372, 56.43887458309051, 58.641567845498365, 44.23307441896008, 39.469881442285356, 44.47676343302573, 51.14436126524403, 52.758746070246545, 54.21546728380265, 60.990671419328265, 61.96383107093073, 59.00455967072518, 55.48210651643815, 44.769011389824655, 35.05161777619393, 29.351343108761696, 25.203095405332505, 21.004484468890777, 33.01510749324676, 44.75701678183771, 39.27087606922273, 30.691393421542262, 15.540810112030277, 12.11073563944909, 11.160659136310702, 13.176078834841329, 22.363905406767323, 32.5860688378734, 40.20482378621256, 50.1368377285619, 53.2422487966476, 59.05614668323148, 54.69476522937898, 48.71833216759467, 49.81355990132978, 40.20203498102004, 43.31158022726736, 27.787937348888768, 9.266366151071365, 12.087895677935693, 28.891590333754017, 42.05733568437638, 33.41874291819911, 40.4803781355581, 49.46106433868409, 46.9602866326609, 52.82233161310996, 52.51006387895154, 53.56041577554519, 57.691558022652906, 59.784742632219874, 59.93449480302873, 59.971906369732274, 50.619995286387784, 46.1408721247027, 58.52130797601516, 57.33916444163169, 55.431664836022165, 55.23597386575515, 54.39212691399359, 55.02221253610427, 57.428967106726866, 58.14871811097669, 64.34779667085218, 60.42037056338403, 59.40737924268169, 52.80359445079681, 58.86433493706488, 62.60848829823156, 66.33152361839049, 67.42347225066155, 62.11989433534684, 53.15805119852866, 60.72383257650561, 61.077673512120406, 63.22932104910574, 60.47040039493192, 44.465380714785674, 1.9531885991173408, 0.9728051061111113, 1.9206232433357548, 17.230811349807247, 70.33822474941131, 72.16373505130892, 77.33963981751474, 66.36542858616, 76.23841870215632, 46.9637147841915, 8.451287823338664, 31.428069453085627, 22.45785205594955, 38.0043976537643, 47.17970402010026, 55.841301487338164, 48.50442178787724, 40.282545551176995, 50.86977574133104, 51.77350159614317, 83.49991044690533, 34.06832664243637, 0.2603460025162466, 0.440386348073521, 0.22054228030385511, 0.21832646291342475, 0.2542385044357469, 0.14340300263176042, 0.2519150057266797, 0.2768617549971227], [0.03482812287045583, 0.09792366440618232, 0.0515495163328465, 0.08495253180303881, 0.07630602681949254, 0.02131366730487395, 0.03127437122466584, 0.14449386587066038, 0.03507698653265834, 0.12492773513640128, 0.04017919339540024, 0.12809461238042963, 0.558674766892387, 27.003692773080644, 62.85864530071136, 44.199922546263664, 52.465595968307994, 31.589792697660386, 40.36427597845755, 43.58194135850476, 40.167282781293316, 20.521615205272553, 43.95800252114573, 3.9645074596328125, 16.568193589487386, 70.5029486071679, 54.84951449978737, 47.38309068064536, 58.374603486830196, 47.79747339986986, 2.369379040695006, 0.2943400816330987, 0.6539781884320321, 0.23021833850972115, 26.42361148711174, 75.34575000885995, 66.23709647886216, 64.27711948271721, 60.63980364030408, 57.842059366164676, 65.05758093249413, 68.41412175086238, 66.77195087555917, 66.00875962165095, 64.13995419779133, 60.97708040668119, 54.73613054521623, 57.28604770475819, 59.60185820056547, 62.86659202268047, 64.15294116543186, 61.191775260433076, 63.452456843468454, 58.60881213218936, 61.326932291830744, 59.692159006672526, 61.995916058940274, 58.517962194258175, 58.58841188492314, 57.04005625940139, 56.99177580495035, 54.41783412810295, 54.7263716882275, 51.83117612715691, 47.891163133805804, 40.83973392363518, 34.55925049320344, 34.66076927800333, 34.867980249466434, 45.23429862914547, 49.630746072338475, 48.544547634740034, 43.49134637463478, 48.37570528830252, 47.20723513633975, 48.166682181819795, 49.21881875684185, 55.54511939325641, 48.65838266188099, 36.19161936544603, 22.719146628533643, 14.275123034754108, 6.826697011147776, 3.0358809280780057, 3.5255925213136985, 1.9877970194624317, 8.747549345416408, 31.26091568700729, 39.07228646739837, 19.13966613431131, 1.7952217594269784, 3.6304281603905464, 3.26238947049264, 3.375568481222276, 4.0276000095951945, 4.471499544958915, 9.288113732491771, 20.304590463638306, 33.878087766708866, 45.87718686749859, 50.662972696365856, 49.47987210366034, 42.85356506224602, 37.59535328034432, 32.82769076285824, 30.493066618519446, 14.349571581809753, 17.984447709975704, 26.22076023009516, 30.28640477888046, 22.57546824793662, 20.012448410834036, 36.26444601243542, 41.06214407951602, 45.46166273855394, 42.45227129228654, 45.33516630049675, 49.92766164964246, 51.24817855896489, 52.92942016355453, 55.2206648549726, 60.356290801878906, 55.52857091349941, 44.89128343520626, 45.253545699581025, 51.28739049357753, 53.059858583634906, 53.74605763343073, 54.012296353617025, 58.031235279575476, 59.14653378148233, 61.55694007873536, 55.45590116131691, 52.82827792629119, 48.15244397809429, 53.720891706405155, 58.2390542184153, 60.929737398701334, 58.28248270096318, 59.68067038443781, 55.866490948584776, 55.7540052167831, 56.18600330045147, 58.31455984423238, 39.167552994143584, 8.11079373282771, 0.11145858409544153, 0.32137795982341616, 1.256159394979477, 26.018185500175726, 55.597749756228545, 50.705652006210826, 54.816539133748705, 55.436728615914625, 64.46233380225398, 21.5168950634618, 8.327202662344902, 30.122902739432554, 12.719995437129853, 31.97403984685098, 35.64992827753867, 45.2464226753481, 30.673921223609682, 25.711205121009584, 29.83726005400381, 48.46658660519508, 65.28881249889251, 10.310282418804785, 0.42648068779418546, 0.10082920607660087, 0.05040469752143949, 0.05499889615983252, 0.060212986333475965, 0.025348759654368606, 0.05821166207052528, 0.13475262890419654, 0.2142653082527461, 0.34696906564697144, 0.10361163741758755, 0.2568473555748501, 0.0592488493590105, 0.041918963749682715, 0.034618628466682094, 0.06190094233099973, 0.05505905321408665, 0.05957419157869393, 0.03178723261601502, 0.11321035904749749, 0.3474657664135579, 32.594560769296464, 73.60120527205929, 48.68960080608245, 40.757964272652906, 37.00607991987659, 39.32713462460426, 37.68511672173777, 45.33425631061677, 24.64747205857308, 53.83248313780754, 5.741594876012495, 17.63193645784932, 72.49677565789992, 59.8634724463186, 54.6493245709327, 64.88271382547194, 55.707678102677875, 3.9957449705370016, 0.2025356594352953, 1.8016425568249919, 0.5503041225094949, 30.496963493285644, 77.06098679573306, 70.62321632139145, 67.35621929168701, 63.6767222804408, 60.90279071561752, 67.02335911412393, 69.13983868014428, 70.21288933292513, 68.97037659921955, 67.08511291011688, 63.57041035929034, 59.098786769374726, 60.319742156613266, 62.758577792875236, 63.690423119452696, 65.75802995312598, 63.70217846285913, 65.25723741900536, 60.709410021382, 60.73434845093758, 62.6361253184657, 62.30527731680102, 58.91097976315407, 60.9007393160174, 60.160646900053955, 58.77548540792158, 58.290617696700565, 57.46577462842388, 54.68029952818348, 52.071805692488155, 45.039447046095326, 40.55600143248036, 40.964696714955, 41.86834804473385, 50.8042250910113, 53.82536403594479, 50.77040249301542, 44.0694841261833, 48.98387662826046, 51.133013848335516, 49.42881853349748, 51.89621294698408, 53.297636585850874, 53.611234003497714, 49.932090005567, 38.83320623828519, 27.897320485884144, 18.455649883516376, 11.062616552076033, 7.104095364770583, 3.9879894641137894, 16.226417864522627, 39.364856058551425, 31.250639077155824, 10.107558638818803, 2.0205361852722783, 2.0666946374600936, 4.700218342965649, 3.7223278226390963, 5.20768282874938, 11.435051483492698, 21.634542634410245, 34.3388682027017, 46.15816585479244, 51.085541402139974, 50.3930155692562, 52.759369727103945, 46.400089802280554, 43.204930982282086, 38.848676066244806, 29.24454285252479, 7.994965651342946, 14.513889474253501, 29.642169206373154, 36.12742193283574, 28.055523403229255, 28.466336765596946, 42.99932426021945, 43.275423819018954, 48.01522377998599, 45.14891647523449, 48.6154091742731, 51.1434865766956, 53.32203765069285, 53.57144940283991, 55.861289885736284, 58.789649086613814, 56.27804563891504, 46.95730170895977, 50.56626273739723, 52.939363371941354, 55.44035680832402, 54.269729352766475, 57.46516666104717, 57.483005600590865, 61.71492138216573, 60.47973171357186, 59.87558080304054, 53.58990023213049, 52.86374399738928, 53.91370757933586, 60.57792040609545, 62.60680560142764, 61.57375527966408, 59.58830641162012, 58.06487744854343, 55.70640725474204, 57.781909819572206, 56.82060357063048, 39.832167240881155, 8.182486814837302, 0.08149673982012658, 0.49964125718801256, 2.347690049679049, 33.40721899463285, 62.69517267903974, 53.89768861955213, 62.49699884845365, 57.79365339586812, 68.87879710043632, 20.742809426399972, 12.398410112627092, 42.09668882431523, 18.083697403630904, 32.23111787149983, 32.79615098430265, 34.49177788149926, 44.11018263909125, 27.97940588766529, 31.25851715764692, 56.01400736839541, 70.5820785030242, 11.51548360624621, 0.30083730396243835, 0.18754172529424393, 0.14434406503794656, 0.10668422455989546, 0.13771924310393874, 0.0650271977628431, 0.08394500360854211, 0.3057179275539614, 0.5108429948168417, 0.6065051906531858, 0.1897101524856783, 0.5582764624587951, 0.2932565881600303, 0.18887752216429482, 0.11742954998607598, 0.3411427218346827, 0.15451228876988735, 0.31168213654910365, 0.12395108028525308, 0.37972646434941604, 0.7255609537805281, 42.7628759414919, 81.53090415462371, 56.46600561757242, 67.85405435869771, 43.366434574127204, 60.154535847325484, 58.530980540860085, 50.4051160812378, 27.38212108612061, 53.89008706615817, 8.498349401258654, 25.41609383398487, 82.16982687673261, 67.62643921759822, 60.164408453049205, 71.7288383360832, 58.84192643627044, 4.718385290715003, 0.8719159842979524, 3.031328527196761, 0.5821689062060849, 36.81456235147292, 76.00406492910078, 72.18360577860187, 72.96941341892366, 66.20552924371535, 63.70334340680031, 71.00064246885239, 71.60358136700046, 71.60421679096838, 70.77319206730013, 68.9280620698006, 66.62973357785133, 60.851701844123106, 63.009938962997936, 64.68963515373969, 68.63717909782164, 68.95117267485588, 66.567242376266, 66.58664241913827, 65.0517209114567, 64.19516548033684, 63.43065238768055, 70.37613053475657, 63.51897631922076, 63.776723107984, 64.83656714039465, 62.271250755556174, 60.80409211497153, 61.61379483438308, 59.796741162576986, 57.143912776823974, 50.64198801594396, 47.22636453567013, 46.970857420275294, 49.53617772748394, 52.94878098272508, 53.57663869857789, 55.64942698324881, 53.878276809569336, 53.048452331173806, 51.55326835570797, 52.01481757625457, 55.193784852181714, 59.44083313788138, 59.531761523216005, 59.699223195352864, 52.249410613890625, 48.28451802653652, 39.96361763246598, 30.33691902314463, 24.251432303459417, 20.531352489225327, 35.52122746744464, 47.69608013091549, 47.76676908616097, 40.58792560331283, 25.111113863606608, 23.762202916606782, 21.86902584568147, 21.63352477935053, 23.226279674037812, 31.247901262775546, 39.73713213397611, 49.040594100952156, 54.41623380107265, 53.6335797463694, 51.99032237452846, 55.26838048811882, 47.653357674998624, 46.80354479820498, 40.02077441061697, 42.47648016099007, 29.515651195280014, 25.837021027841878, 37.15229019041985, 46.00954332659322, 34.62097291023501, 39.27915227028632, 48.24356455956736, 48.38466790414626, 49.65871257166709, 46.64522224856962, 50.72092571566182, 55.24835678838915, 54.64850087319651, 58.25096253425845, 58.594483713949884, 57.391351576774355, 59.54039465996527, 54.129281044006355, 50.204914385272616, 53.873542508771344, 56.00037320967644, 58.05051765134258, 56.50662176070675, 58.80383629952708, 62.97628110454929, 66.54644596961238, 61.52845190417383, 57.87426594764956, 55.216730717689764, 58.474482720898045, 63.745159795207364, 66.18830219391855, 61.865995391722656, 61.48473316623319, 58.96658328271682, 57.24372925296907, 58.106576165845325, 57.36697404615341, 48.55450653260755, 14.57956858219639, 0.30023013331717063, 1.3920706246168384, 3.1431332374772722, 33.952644178944254, 67.87575291049096, 63.720088005065925, 65.79712813900363, 67.13942204752277, 75.03379606431531, 30.678380958495605, 12.313357437810591, 40.30385186595302, 19.53125007690922, 42.22180066570159, 46.05416420967349, 60.36805399002568, 45.04186322612148, 33.467929440159956, 44.47364122636857, 63.07161431158743, 87.31417225253198, 19.689231380339592, 0.5160249361107426, 0.33572421258976387, 0.22329480357227788, 0.31017747857878286, 0.20161635392615873, 0.21014596155333906, 0.26765055894371004, 0.40445915333205656], [0.0995281895983123, 0.18342512118960583, 0.10799206688158935, 0.03938428524340834, 0.1734438995199819, 0.07156797985155737, 0.09018415389882942, 0.09248150602704094, 0.04172826148269158, 0.10763002138945366, 0.07834844786914126, 0.15614791713174314, 0.3679100790571782, 12.126732045604337, 69.61944257059406, 43.55538299006801, 47.34230587559362, 37.71566806300994, 51.66216119643181, 41.5910090169599, 37.418827010739236, 28.592790057582242, 34.687284500368186, 13.287758519572597, 1.4663714699206816, 53.533323964764996, 71.77385145618071, 68.00414777571156, 45.085444681106075, 62.982843229847575, 18.7827657499621, 0.04867342308223729, 0.46229658528201045, 0.12263718586895736, 8.561426016592211, 64.76687054480276, 60.88442617847074, 68.10772972722208, 61.29208203284972, 63.218652202237045, 60.53721012607698, 64.76727454893052, 59.50582288926648, 61.87099641369235, 62.77849166624008, 61.62254564223751, 56.71377781898745, 60.4800808045172, 62.93325662612916, 65.23957498611944, 61.004866476981874, 63.20085248639507, 61.5703938084264, 64.30196769775884, 61.24845743179322, 61.36501458383376, 58.13873175651797, 58.76378105532739, 57.9843629560163, 56.09367855133549, 53.679408719462735, 57.51931105890582, 54.012276741766165, 51.166463821165024, 46.04111056174002, 39.25099749718943, 36.45549289641842, 36.163672477968284, 38.31014248632616, 42.708472667201875, 46.64145285083402, 47.39236708610289, 43.25282312208607, 47.000063388578354, 49.853881866701194, 50.36599828350929, 51.910859077207505, 53.19176004778955, 46.406632315727975, 34.483972364856356, 22.506930712730657, 11.252166071245748, 6.101787109528819, 6.634496460037847, 5.021954188423773, 6.1032977123414325, 9.748677457532576, 26.696945774939756, 42.31572966421805, 26.33987084511788, 7.481308723649672, 2.4875372552102615, 3.584418267973008, 4.098524307051013, 7.554546238914614, 6.472643777247399, 10.089264704335122, 18.44301789037643, 32.01900001495115, 42.66137676854288, 50.74743309328633, 53.76051941225606, 47.61556563838836, 41.91853084871846, 33.971506857102916, 36.2413981653029, 30.643160035533292, 29.378250568143784, 28.923828294200284, 27.785146582511167, 21.62139681077773, 24.88602080652791, 33.80371962824176, 39.94094241049982, 44.56473042888027, 46.170054558784734, 48.089878251475675, 48.306024382191325, 52.00867514456473, 56.570438723410334, 56.4658801017269, 61.015900104276604, 49.361718546959665, 44.567640827548125, 61.444740679956254, 56.41541096471972, 61.54161930084229, 60.55699063885597, 59.786417484283454, 53.1550427406065, 57.729981560860914, 53.18300531756494, 58.35079469988423, 49.90727709185693, 51.57843820510372, 52.66884534589706, 60.80042077649025, 57.26037971435055, 65.33662226892287, 55.22814873726138, 52.28304493811823, 51.21761937295237, 58.70724008929346, 46.71567978397493, 19.56933040772715, 1.5290136827576546, 0.07580803136431402, 1.402700002635679, 6.527572158844241, 52.6624361930355, 54.28193184637255, 58.407998546477295, 61.73925184434461, 54.68217442112585, 58.00022894336332, 7.847883143732625, 13.363542633671916, 17.438338072069232, 18.123032892903975, 36.550594683616396, 34.00177186535251, 46.91481067288307, 25.75412565662015, 38.74993824189709, 43.18296963168729, 51.56716923559866, 57.16953762115971, 3.300736277334152, 0.17344074323773387, 0.016769505699255297, 0.1493202657589028, 0.0024163495230999205, 0.024168926794382355, 0.09124233582687956, 0.11827826815386934, 0.18728347705496898, 0.18319298122679034, 0.08808315010561098, 0.0798564613045704, 0.1743191090081969, 0.05856265291391362, 0.1082035301313285, 0.04239293085711618, 0.09546317385449525, 0.016482986900354588, 0.05996219979058351, 0.03172138352848349, 0.11147162291191279, 0.17168897594655716, 13.454468077228917, 79.51701025809012, 47.144983199334916, 38.66268511741392, 46.37641045355028, 57.07992715220298, 30.981919457835538, 41.96935692141133, 29.35016247533983, 48.06066051606209, 17.395103746844878, 3.1720013916492467, 57.98118191380655, 73.42621264919158, 67.17393890503915, 50.762616588223366, 68.7088486456102, 25.685450838458156, 0.191949013800871, 0.8280254588011773, 0.18717798674779554, 9.412749986494742, 66.56878779011389, 64.75458568142307, 71.27199203737321, 65.95736088291292, 67.73681471424719, 64.40687933275777, 66.25808115928405, 62.8796652824648, 63.77103959360431, 65.68588972091675, 63.88907155682964, 60.97743734236687, 63.28195533444805, 65.36529087251233, 66.62530914429696, 64.25412654876709, 66.17931212148359, 63.567841206827474, 65.33930909249091, 62.350835646352465, 64.86140358832576, 61.54351380563552, 60.01879830514232, 61.1964899493802, 58.09084746145434, 58.465653465640166, 60.01444839662122, 58.33822350348196, 54.92875814437867, 51.46961596704299, 46.35535124809512, 43.031444549560554, 42.7329953255192, 43.89800986936016, 46.77011443722633, 54.16133465305452, 57.968983342570645, 53.56805655264086, 56.37472421892228, 54.39512752717542, 52.40658783143567, 53.19752200957268, 54.367184562067834, 54.000031102088194, 46.70415978277884, 37.144755317318825, 30.916592382615615, 21.14665665934163, 11.432162657860788, 8.020200219846542, 6.124829073106089, 21.421175502961685, 41.354709748298895, 46.03927881486955, 27.931480407714847, 10.579265817519158, 3.6837351322174077, 4.329051808003457, 7.190736599506871, 9.608186983293104, 17.437377091377012, 26.2173399233049, 34.843857672906694, 48.25752819738081, 50.978676426795225, 54.08707241858206, 54.98891553571148, 48.03787546773111, 44.06787203204247, 39.95341947001796, 42.62543216828377, 31.347048974806267, 31.16635910926327, 36.27189067102248, 35.925863096790934, 31.441576134773996, 32.84537280759504, 39.54534392203055, 45.2039747853433, 47.8248123199709, 48.33167668311827, 49.65158954743416, 50.67273155335457, 53.123349989614184, 57.5245003546438, 55.774731020773615, 58.361663587631725, 55.165116248592255, 50.799628073169345, 64.5296573638916, 57.972564466537975, 61.1618201194271, 61.91716271062052, 60.79113652629238, 56.74454096824893, 58.27226100429412, 57.28190568185622, 61.961128557882006, 52.70510373576995, 53.54308282175372, 55.39311185959847, 63.615905930919034, 59.3626210766454, 69.37162722310713, 57.83203378800423, 54.56594282580961, 52.43369533169655, 59.876216227008456, 45.33103212233513, 21.139670918064734, 0.9308594020624316, 0.13347215890403719, 2.703615970188572, 11.219303473349541, 60.21181029658164, 59.511796659038914, 65.56380202693325, 65.63201204422982, 61.17810580038256, 60.4135887853561, 7.791278929479661, 16.95971869653271, 23.03108488359759, 24.664618699781357, 37.369656178259085, 28.911531663710072, 40.89856555384975, 38.38553044103807, 39.21791230478595, 47.400996300481985, 58.48044864593014, 64.31020075275053, 4.094504858216932, 0.23439060656293748, 0.21385333681058502, 0.04307240871111712, 0.05320462248017711, 0.03284390918129394, 0.02427366825060979, 0.09371800258034661, 0.10178549064984245, 0.25455871386633766, 0.23524546875588356, 0.2900320627996999, 0.385990213722952, 0.3772269646006246, 0.3429543359145042, 0.2942748722289839, 0.16178489933090826, 0.08029356043064788, 0.17560190791564603, 0.17655014090480345, 0.2531807668386929, 0.3231584094464779, 23.96326949519496, 95.85116386413576, 54.33250688737439, 65.84107829678443, 47.258904518619666, 76.55466371966948, 57.47878120791528, 47.60280224584764, 35.83122022690312, 44.61754906562067, 19.226676071843794, 7.974780153843665, 62.92314475582492, 84.79686567860266, 76.44163670078402, 56.5244097094382, 74.54386065083166, 27.36909685596343, 0.5154817491289109, 3.884293763868271, 0.21248953176602242, 12.935166858857679, 73.76780402275824, 65.74565095286216, 75.91732563511019, 68.92097042452905, 70.74780648754489, 66.27817153930664, 71.0374499905494, 64.47088064685946, 65.44451098288259, 67.34624862670898, 66.59307510622087, 62.00450212724748, 66.42311880665441, 69.75744724273682, 69.27847877625497, 65.8626905564339, 69.55038532134026, 66.32886425141366, 65.26338769543555, 63.694094457933986, 69.36968172750166, 62.53190794298726, 64.17776976862262, 63.62603741307413, 59.17163695058515, 60.598614831124586, 63.3568843718498, 62.54169817893737, 59.273340086783136, 55.743873734628, 50.44512033462525, 49.7812395711099, 49.251056717288115, 47.551591780877885, 51.3356238795865, 57.24060312394173, 54.818767040006584, 53.79445575898694, 54.024667509140514, 53.97039367306618, 56.221951823080744, 56.84766792481946, 60.60074467812816, 59.29629379703153, 57.33947823124548, 52.918088436126716, 46.59853035403837, 36.25732691057267, 25.13033739982113, 21.21354287670505, 20.606004999529933, 31.27477538201117, 48.922165978339414, 55.34107377452236, 49.511207918966974, 42.66329088518697, 36.44642045420986, 34.739099010344475, 34.52055631145355, 35.54627572336505, 33.72023197912401, 40.766699391026656, 47.41164161312965, 55.94904507360151, 55.32563532552412, 57.43791403308992, 56.781595599266794, 50.29182234118062, 46.78103823815623, 43.96490589264901, 44.0725161183265, 44.62234220197124, 38.86343202283306, 38.04994029383506, 40.15646488435807, 40.09255770714053, 42.22806469086678, 45.55525441323557, 49.162650415974284, 51.050396965396025, 50.43993888362762, 53.01061714849165, 53.94968748092652, 57.49954231323735, 61.41247918528896, 62.105236438012895, 58.24040351375457, 56.97293273864254, 50.40805785886703, 64.74867466957339, 59.34601768370598, 63.3079331920993, 63.64473927405573, 63.20223316069573, 60.24708417154128, 63.978293711139315, 58.18900085264637, 66.3630594745759, 54.47384165179346, 57.36590323909637, 58.05039213549707, 66.14670153587096, 61.962364104486284, 72.27398503211238, 58.976699075391224, 54.64631219064036, 54.88436475876839, 61.221389155234064, 50.1213522111216, 32.25968057109464, 2.8106657872276926, 0.19824771210551265, 3.644488386569485, 8.690723026952437, 63.80916895404939, 67.1567746131651, 69.17520276961788, 74.54781439996536, 66.48317813873291, 69.58694965608659, 13.524975622853926, 18.4546261449014, 28.027392164353405, 29.492271907867927, 48.5073321865451, 44.4439253499431, 63.74384580119964, 38.07585539356355, 50.77820408728815, 59.035695445153024, 65.78997373580933, 81.38373682575842, 9.249396016520839, 0.5563735000548825, 0.39883992905097626, 0.2669395067759099, 0.24543264550307106, 0.10809195708603629, 0.17487853705402345, 0.24153269106341949, 0.2642096903535628], [0.08070696445722735, 0.2068382850097072, 0.09118013714830722, 0.11454605632611822, 0.1988026661978614, 0.02216950242948388, 0.0901349863758491, 0.0765156131538172, 0.10845909706286846, 0.18157428340806117, 0.045904811967404625, 0.04735954398770006, 0.21465752994821918, 3.3704799413681035, 63.150673604780636, 52.50099928148332, 31.63514510277779, 45.95366916348858, 51.736552869119954, 47.22905135923817, 43.69823178937359, 36.830424416449766, 20.039652009164136, 26.12330698197888, 2.6546736157709554, 25.39825293325609, 59.49070999699255, 85.67595512636247, 80.5875898176624, 60.29354072386219, 60.95573486820344, 5.772035410327296, 1.7731598980965155, 0.7918572834422513, 1.3686831247422004, 28.74504666174612, 64.07998900259695, 64.31156965994066, 65.0706071238364, 64.71746829248244, 64.35144055274226, 66.60798011287567, 66.5005228596349, 67.8021300223566, 63.33748432897753, 57.91791016055692, 59.984846268930745, 61.933726879858206, 63.71413776951452, 64.24987862187048, 63.442596004855254, 64.09154038275442, 63.687038113993985, 62.210775652239406, 62.660063543627345, 60.44972558175365, 58.3481078763162, 55.599816845309356, 55.07982823156542, 52.211830385269664, 55.48467174653084, 53.234360910231075, 53.42388199221704, 48.227153362766394, 43.872651746196134, 40.09922181406329, 35.19597668801585, 38.98843011548443, 41.22733077695293, 43.138168319579094, 42.0196730859818, 38.58955252555109, 34.62353421795753, 47.34029762206539, 50.43845230533231, 50.95916655755813, 51.447678150669226, 51.78737109707248, 40.675045367210146, 27.06810397486533, 14.906974704034868, 11.148106571166746, 8.562898866591915, 6.272551907647041, 4.014594410696338, 7.431799096445884, 14.185541002981125, 29.019814575872115, 45.04358906899729, 29.741944497631444, 16.693966350247784, 13.59043017510445, 16.548758245283558, 13.459861336215852, 11.166699586376067, 11.199785759372096, 12.207717222552146, 18.516372096154, 25.229149749202115, 34.509703113186745, 48.99023871267996, 52.498845900258715, 50.58263471049648, 42.19133561657321, 40.351896978193714, 32.15402564694805, 32.53626258142533, 25.884091431094756, 19.507562883438606, 26.6353920198256, 30.75189990382041, 30.085075401490737, 37.2992221770748, 40.75517546746039, 46.14101725239908, 47.76079531638853, 47.21482884499335, 50.631436840180434, 53.79134531944029, 53.561721924812566, 56.221288942521625, 47.80875805885562, 51.12430618655298, 57.79652064846408, 56.70803939142535, 58.370080994021514, 52.74667301485616, 53.810992471633426, 55.14561814646567, 57.39121037144815, 56.98730430295391, 56.40147478349748, 54.886553441324544, 53.0558067752469, 49.62449773665398, 51.86528505817537, 55.91861532580469, 58.69211150753883, 59.42721074627292, 58.137370694068174, 58.725130019649384, 52.89890412361392, 55.53229716516311, 30.433328920795073, 7.101179082547465, 0.28214212326753524, 6.162068055522058, 22.461040942899643, 49.34860214110344, 52.26865768432618, 52.34643436247303, 55.02036509975311, 49.251397963493105, 64.02759398183515, 29.499306678771976, 2.884778481337332, 29.147338674914455, 19.26686663781443, 21.784587021796934, 26.1163761538844, 37.793181942355254, 39.368641145767704, 34.66191068772347, 32.19160391438392, 27.086090003290487, 57.52812462468302, 43.639564898706254, 0.4345314138598981, 0.08950711603486732, 0.037069968098113616, 0.04148934930262547, 0.07202520410740568, 0.016076309125750296, 0.02532295781307884, 0.07171031132700943, 0.17630983444471515, 0.224304553421755, 0.3418328444803915, 0.0468471001142696, 0.1614562935766674, 0.13204236304567707, 0.03921315652288256, 0.05407155821880987, 0.0792841399989782, 0.02479284795211448, 0.017521013055116903, 0.08168429346574892, 0.10295156074026901, 0.3909806023922659, 4.962653344677341, 73.05491324393981, 60.19533241948774, 34.732803606217914, 49.901428837930005, 61.30668893937142, 32.78108516047078, 45.79644095513129, 38.68849823551793, 30.00204274731298, 42.95086729911066, 4.608277986126562, 30.547795449533773, 64.73189476997622, 83.46036511082804, 86.60256016638972, 66.83346148460143, 70.24261305409094, 8.467719612583037, 1.2456988014521138, 0.5689560345584347, 0.6948923704124267, 33.73032423757738, 68.58359167652746, 69.17706197307956, 65.77511187522643, 68.39839304647138, 67.72522803275817, 69.54913800762546, 69.46761546596404, 70.81130966063469, 66.8279544768795, 63.899477604896795, 64.38911491824736, 65.62411239070278, 65.96005947359147, 66.27281358165126, 64.60437459330406, 63.12753946550431, 65.9354034546883, 63.978897756145855, 65.81955232927876, 64.14070337049424, 59.61624153198735, 59.274214775331565, 56.8101582988616, 57.361223851480794, 58.46199781663957, 56.162833859843595, 56.17933527115853, 53.064051597349106, 48.560056686401374, 45.09418372185, 43.065714297756074, 45.46883283122894, 48.294861316680915, 49.16535685139318, 50.27847059311406, 48.47407048748386, 45.439222858798125, 53.611088875801336, 54.77747232683244, 54.00572246120822, 53.53228453666934, 54.15387822735695, 54.04835078024096, 45.6094027334644, 37.61606339485415, 27.102675745564124, 19.30536077868554, 10.689457943362575, 9.188961117498337, 9.447734586654171, 19.240192559457597, 40.722054973725356, 50.34437817911948, 34.86503062709686, 9.501681885411664, 10.96384930995203, 10.385707636033336, 13.438664847804656, 14.828841090202333, 17.654576378483927, 23.73354608012784, 36.31026714078842, 42.85237266171364, 48.97003850629253, 52.873126306841456, 53.10894704634144, 49.72074877831244, 46.12342149980607, 43.144918718645656, 42.62552630516791, 41.51355397316718, 34.02869501421529, 28.565762965909897, 37.0900264863045, 39.26455320850496, 38.17414999008179, 41.97891573752127, 46.11711825093916, 49.127494212119814, 48.09717778236636, 49.74911535939863, 52.61150813871815, 53.170610627820416, 54.70062525041642, 57.29020541714084, 50.703161301151404, 52.046478948285504, 58.041578569719874, 57.23997946708434, 59.011447352747766, 53.71070531106765, 57.04510827218333, 56.52175818720172, 59.005512806677054, 57.90209516402214, 60.08783986491542, 57.19737075990247, 56.21819811482584, 52.70625299023044, 54.57645477787141, 58.94711655955161, 62.37173403463056, 60.050185111261186, 62.22690836075814, 58.9398209510311, 56.09504353615546, 52.74147587437784, 34.24832028727378, 5.1880302832972625, 0.08004653537946363, 12.116880032324023, 33.129966259002686, 57.76307067563457, 58.31992564662811, 60.72790791911464, 60.38682253130021, 54.18559451257029, 68.59990089170395, 22.399697034589707, 5.677953929670396, 32.25972960072179, 22.85887125999697, 27.707238504963538, 28.73620956174789, 28.028823829466297, 39.62533673932476, 44.15489373668548, 30.64190683826324, 33.820413235695135, 63.3918091558641, 50.674904546430035, 0.382435106101536, 0.12509949204902496, 0.06481096944621494, 0.027040383297829863, 0.07419359299444384, 0.0068826095629183045, 0.05492440177007549, 0.08642378833986099, 0.2155879743757748, 0.2468728448354429, 0.32510372119084485, 0.21507731548720793, 0.3670650534331799, 0.46836801594303507, 0.23237896692608637, 0.11739473895079668, 0.24137674620555294, 0.15046432614326477, 0.24233575039092572, 0.2862811124613208, 0.22411796504691725, 0.7790744016247412, 9.426155667151175, 86.98664649840325, 63.321186880911554, 48.01111705841557, 56.89091990070959, 75.74212120425317, 64.59764380608836, 55.738947237691576, 43.88278322835123, 26.96907981749504, 34.14940203389814, 8.05629288957965, 33.83884445313485, 68.82349168100666, 89.80939588239117, 90.58233814854776, 72.12330325957268, 72.60705701766476, 6.459403816730746, 10.32135134743106, 1.6418876066323251, 2.516981017205023, 42.141800003667036, 71.79013713713616, 73.63445128163984, 69.56092865236344, 72.27746025208505, 71.1315005825412, 71.71212903914913, 71.49825003839308, 76.31148461372622, 68.32388370267807, 64.88895823878627, 64.7649956518604, 67.96303349156534, 68.2926381018854, 70.0749631081858, 67.18776133752638, 66.06936024081323, 67.23726949384137, 66.49241924285889, 68.94514006953086, 66.26864802452826, 62.61133201660649, 61.298550021263864, 58.35944744848437, 60.925528695506436, 62.54863685177219, 58.44186429054507, 61.70407995100945, 59.55403666342459, 53.80984321717293, 50.21369657208843, 47.8592703419347, 51.508816134545114, 53.66464491813414, 52.8757974409288, 55.16825414473011, 52.83145896850094, 48.02542194243401, 59.5027595181619, 56.06049922204787, 58.804981631617395, 59.22664034751154, 63.30448542871783, 62.51115076003536, 58.583324570809644, 51.933871623008486, 41.91726784552298, 35.763249474187056, 25.96665732322201, 24.64239258919993, 27.82602160207687, 36.38980104077247, 49.635876532523866, 55.357963500484345, 47.288290915950654, 38.67214587426955, 39.38318921673683, 48.3339673472989, 44.89631191376717, 41.172044969374134, 37.16356700466525, 39.40020445854434, 47.88733490051762, 52.141870990876235, 55.77830037763042, 57.04277053956063, 57.60326547007407, 50.40317843037267, 48.352182834379136, 48.72683586612825, 44.06529503483927, 41.20908783328149, 36.5271310652456, 33.54199947849397, 42.96013978219802, 48.99647528125394, 46.97254796181956, 49.279886138054636, 51.86595578347483, 53.86281482635006, 53.2126231347361, 52.40627796419206, 54.587570774939756, 56.430127697606245, 59.368920403142134, 60.17723852588285, 54.38297210201141, 52.76333524334816, 59.09447608455535, 60.892208160892615, 61.85330652421521, 59.57022036275556, 59.67324141533145, 59.05355007417741, 59.34730029875233, 61.26737894550447, 62.10832726570868, 60.93898242519748, 61.00337205394622, 56.81456312056511, 57.78621265965124, 64.66473594788583, 65.49581950710666, 64.13465115331834, 59.69701490094585, 61.39778598662346, 56.59176465003722, 57.22159531808669, 42.792638886359434, 11.618321288016535, 0.46190851578308695, 8.569837539426743, 27.562942351064375, 61.4433168595837, 61.857887852576475, 63.99292022951188, 66.19158914012294, 60.534558603840495, 74.3770500921434, 39.881157644333385, 5.452987369029753, 36.906145772626324, 29.57760895452192, 34.83680917370704, 35.71638107299805, 48.800666639881754, 56.147999455851895, 46.063440615131015, 41.77809822943903, 44.08462839741861, 72.02671881644957, 69.94565825308524, 2.068993881825478, 0.5309064085445097, 0.2850281909829186, 0.25102375435733026, 0.17257578400594575, 0.08220566992437647, 0.1515941832575106, 0.17005667240629274, 0.42722253669654175], [0.043258801733534184, 0.06590495832384595, 0.18686022879856248, 0.1732741804012368, 0.13240553468706148, 0.20594588450847134, 0.018487722169788137, 0.048738992547676455, 0.12683937731649608, 0.16905340366065505, 0.04444450282702043, 0.08562855843094089, 0.07591342208005729, 1.2972283267205762, 51.93794696561752, 64.32181096846058, 41.52065738554924, 43.25792612568025, 42.88884285957583, 48.680147893967174, 44.58972377161826, 27.6850280838628, 23.323717232673403, 9.898121722282903, 3.9418797964049928, 9.217910170555115, 63.69965245646816, 61.791619408515196, 83.17597758385443, 54.643680280254735, 52.132119978627856, 44.021850862810695, 2.9655653334433034, 0.8009718911301705, 0.4415525483988947, 7.298119818010639, 51.9721814124815, 71.09448909759521, 65.80813823207733, 63.69749123050321, 64.18010750124532, 60.77959299087525, 58.149686936409246, 60.52545870504072, 64.8235801727541, 64.60867743338308, 63.11463879000757, 62.67161100141464, 65.17790748227027, 66.84165923826157, 64.80573731084024, 65.03274840693321, 60.625263414075306, 62.37387564874465, 62.47521400451661, 59.63351565022623, 56.98693167778754, 54.7781861982038, 52.628013472403254, 53.89247971196329, 53.39179308183732, 52.693422917396795, 48.44750035193659, 46.393778708673295, 43.77944446379139, 42.193842011113325, 41.367971281851496, 43.37786436080933, 42.685879815009336, 44.412448329310266, 42.90814876556397, 39.4916937428136, 39.47689856252363, 49.006810726657996, 52.6237420112856, 52.74249569062264, 52.41231841425742, 42.44781940214096, 28.779383090234575, 17.60966916238108, 14.72290473599588, 8.980314558552159, 7.171492961145217, 6.102842717401444, 8.160978007701136, 10.752489451439152, 18.845860996553977, 28.747519716139767, 45.33764916081583, 38.05463929330149, 31.542586972636563, 24.90188091031967, 26.665164770618563, 23.116345444033225, 19.811342608544138, 15.045897210797957, 12.26002202879998, 18.48138063184677, 20.15820956999256, 24.916093618639056, 37.88536156377485, 47.08311565460698, 52.695560609140706, 46.99873370508994, 43.34253949503745, 38.2593007241526, 29.61558730371537, 22.643995977217152, 19.072579876069103, 25.36506772041321, 36.71752683577999, 39.99717743166032, 39.17091838775143, 46.10088748316611, 46.53933786576795, 46.5996443071673, 49.04137465261644, 47.801183962052875, 47.75640618416571, 52.7849082792959, 52.05444135973531, 55.533156164230846, 54.76527375559653, 50.30729609151041, 54.03792512032294, 57.361259152812345, 59.15598277122744, 58.58954937227311, 58.054914628305745, 53.01508865048809, 53.180024316233975, 52.007898515270604, 53.76252766578428, 52.578748503038966, 49.831971506918634, 54.24603431455551, 58.793787187145604, 58.933521624534364, 62.221118942383804, 66.08936432869204, 50.172770561710486, 57.74160746605166, 35.006126126935406, 14.585059900437633, 0.3363878592368095, 8.810611251861818, 42.46885115100492, 52.48794955592002, 55.19127845764161, 54.977670100427446, 54.7913771290933, 46.10958337783814, 52.383712568590724, 32.26833920325003, 2.479139215523197, 25.415689829857122, 47.89111214299356, 15.13548218434857, 26.992847419554188, 29.304221714696578, 47.90732329891574, 42.4369465920233, 34.61999231769193, 29.024464545711396, 33.58615359952373, 60.88910164371614, 30.391955760217485, 0.10026043941897732, 0.04896179772913457, 0.09149064024489734, 0.1259691244171512, 0.09956021207354723, 0.07463565637027064, 0.06450604346971359, 0.046616044165866996, 0.027174213112542228, 0.21556074761094587, 0.08366879826832203, 0.12560959935428637, 0.2244981131967037, 0.16035491961144632, 0.07794580737789793, 0.049459931080139456, 0.056629797759195494, 0.03483646173751162, 0.09123422295576142, 0.1396834618982769, 0.02393379908866219, 0.1353167607298782, 1.3893477642728438, 59.56474865636518, 72.11989079752277, 43.486741512052475, 43.40458354642315, 60.58724780236522, 38.499726326234885, 33.68179275143531, 31.823648329704042, 25.16048669815064, 19.485068090500373, 7.498489195300688, 6.256136298179627, 70.75460003268334, 71.02099172530636, 84.81530866315289, 58.409838138088105, 58.175700095392045, 52.6519791541561, 6.961526524636054, 2.219477084375197, 0.3235408711817957, 6.6092378670169465, 54.73922921765236, 70.80560653440415, 71.40823164293843, 68.68682061472248, 65.05787118788689, 63.28395182086576, 59.909521072141594, 62.87424456688666, 67.02513202544182, 68.1661573533089, 63.64128366593392, 65.72294042956445, 65.56841865662606, 66.67869260234218, 66.48420579971807, 65.7723387595146, 64.98659779948574, 64.74268913269043, 62.7636690293589, 61.5715548299974, 57.70157183370283, 54.53596807295277, 55.89211971529069, 57.3451421337743, 58.88793976076188, 58.7794352346851, 53.92176805003997, 49.90375872581236, 49.74369464382049, 46.26641934917819, 48.14208892083938, 48.643261924866714, 47.176577891072924, 50.253626300442605, 48.93322313985517, 48.37184959842313, 45.62210729045253, 55.47632886517433, 56.87261027674521, 51.2907676542959, 52.70201290807417, 53.754855509727236, 49.228401107172814, 41.37331747239636, 31.048593867209654, 22.078021495572983, 16.450420502693422, 11.749051924674742, 11.87717712694599, 14.433602479196365, 23.580707003993375, 41.43717365880167, 52.31238818937733, 40.91699677128946, 25.323100320754516, 23.880329016716253, 26.310127512101207, 22.873048666984808, 23.92453020618808, 21.875450688023722, 22.832644331839777, 31.43539055701225, 37.672863237319454, 45.21551047602008, 49.773618405865086, 53.46730263002458, 52.7895837445413, 46.07749446745842, 47.82747953168808, 41.99695864031392, 39.845005158455145, 30.894554545802457, 27.92686377802203, 34.070115243234945, 42.88383791523595, 43.677427537979625, 45.191572250858435, 48.66627054829752, 49.034785070726954, 51.03590772997949, 51.42182580886349, 51.612088218812026, 49.752488597746826, 57.67405248457386, 55.64836794330228, 58.41940479893839, 57.539287690193426, 52.12677771045316, 54.18840685198384, 57.8672331379306, 59.84680629545643, 57.06011526046261, 58.252076487387384, 55.121150401330766, 54.51940390371508, 56.58911312780073, 56.29415873558291, 55.72576022917225, 56.39024111532397, 55.45515198861399, 62.732195931096236, 59.96219458118562, 64.94155330042686, 65.9695359199278, 53.09632485912692, 56.12038596983879, 38.750267720991566, 13.811168420699335, 0.5336619348775956, 15.413696881263489, 50.8279711200345, 57.000185366599794, 59.21897995856501, 62.76401027556389, 59.62079932612758, 53.751097879102154, 59.13642583354827, 23.674365358967936, 4.479889004461227, 38.90813135331677, 50.19646167755128, 23.722932146441554, 28.799651938100016, 30.11148471986094, 31.50761708136528, 47.959730086788056, 38.94579787408152, 24.544162711789532, 40.15617462896532, 69.1804430561681, 35.32192399424892, 0.07493024015979421, 0.023657856133556174, 0.05308658365280398, 0.04836910997607535, 0.13079281235414167, 0.10575970199199454, 0.04995721790398802, 0.08015077696332047, 0.07199620767947167, 0.21436160550482813, 0.16491617646909532, 0.2521064357771989, 0.28360718981392924, 0.25562984268030814, 0.2487739073413034, 0.17016550285681603, 0.21073028745670475, 0.24580329416259644, 0.325286632343646, 0.23378032560069717, 0.25212339696384245, 0.41032744811907895, 3.6472708179104716, 78.68434598368984, 79.29888725280762, 57.30733833005352, 57.74079553542599, 65.54671618246263, 74.12010346689533, 56.1522630722292, 32.41941909636221, 31.29813309638731, 14.19813769478952, 8.263715178735795, 15.702049924481301, 75.00005583609305, 69.99718250766878, 87.73193605484502, 64.11646704519949, 69.9954095963509, 56.54859896629088, 4.364075631864609, 3.833806731047169, 0.42563538637853443, 15.011503907942004, 64.09469396837297, 72.27079222279211, 75.07857384220247, 71.11699565764397, 69.61550451094105, 66.64346187345444, 63.82288156017181, 63.37276997104768, 72.010817527771, 72.18817926222279, 68.30446012558477, 65.59062319417154, 69.11996010811099, 68.97907641626173, 68.66871495400706, 68.83742393985872, 68.26000398205173, 66.76513379619968, 65.82201557774698, 64.34057558736494, 60.2538816390499, 56.9433698346538, 58.77412434547179, 59.758980504928104, 61.98399597598661, 60.45989628761046, 57.760823157525834, 54.05771347784228, 54.917371503768436, 52.025404053349654, 50.388634281773726, 54.57168909811205, 51.20245156749603, 57.20683543912826, 52.974303845436346, 54.93388860456405, 51.38728541712607, 59.17888156829342, 61.32071533510762, 54.78579559633809, 59.99934334908763, 62.24619857726559, 58.10733710565875, 52.067812719652736, 42.16297688022737, 33.79978156858875, 33.41865662605532, 33.22524847522859, 32.677630685990856, 34.92054393214565, 42.83946414147654, 48.670859721399125, 56.30127783744567, 49.73729725806944, 45.986671986118445, 40.10476412311677, 46.14936797849594, 50.040045399819654, 50.77111244201661, 41.43624405707083, 37.99386608985163, 42.93635452947309, 44.76337102151687, 52.540564229411466, 54.97931749589982, 58.309574511743364, 54.28447354224421, 47.813888519041, 51.104831618647424, 49.92198990237329, 46.78265033229705, 38.07542785521477, 36.87541400232623, 40.7319668031508, 49.642297452495946, 49.91567880876603, 51.28874763365715, 54.086264410326564, 53.085244163390136, 51.468576538947325, 53.40536056026336, 54.23136465011105, 53.63095568072412, 58.22571815982942, 58.53543243100567, 59.66869538830173, 60.3177535149359, 54.55978862700924, 56.61392996388098, 62.06156476851433, 62.64467608544135, 61.956300120199884, 63.05016679148521, 60.20861748726138, 57.91894174391224, 58.91850679151474, 62.25647910948723, 60.54432138319939, 58.09617796251851, 62.661444217928, 65.29443717771962, 65.14894862328806, 66.32685599788543, 68.41938557163363, 52.59616774897422, 60.115700460249386, 44.03767370408581, 23.20329458482804, 0.7101236079489032, 11.068607972514245, 51.558845966093, 62.84583876209875, 67.09735070505451, 66.09548322616085, 67.39421921391641, 62.10440489553637, 66.41540742689564, 40.51779362463182, 5.158069749032298, 31.65611997727425, 60.03966923682921, 25.509575682301676, 39.540338977690666, 37.07815739416307, 60.44750944260628, 59.722843708530554, 43.35082746321156, 38.34819732173797, 49.859122153251406, 76.726283104189, 50.81677667556271, 0.16832208080637842, 0.4150891748647536, 0.24260340618991086, 0.16983158045238064, 0.21942270408955314, 0.34073142454989497, 0.13972800225019455, 0.2020370587706566, 0.1529048371218866], [0.07106579389543304, 0.059845497786638245, 0.1117899094618136, 0.16785655981831013, 0.10562432659489494, 0.2728381386447338, 0.06299488524335527, 0.07604862893781356, 0.06153580567408955, 0.13930950373891862, 0.07109440727940491, 0.1246025461343027, 0.07516830198226437, 0.123700148185655, 31.973041603642127, 78.98972603582567, 31.79841180001536, 33.723785646500126, 38.99191710256761, 42.650990332326586, 57.07449466951432, 24.351197788792273, 29.11834255341561, 37.724846409213164, 13.403280165887649, 3.095223201859382, 31.90975416091181, 67.25221372419789, 67.68121119468444, 56.8651460063073, 45.709536921593454, 73.45268864785471, 63.5680647819273, 33.828273665520456, 6.377522378198563, 0.2743233379817778, 10.639490869737442, 57.64816876380675, 67.32157691832512, 66.42454654939714, 63.84370542341664, 64.38420411079161, 64.96730366060811, 68.23383392826204, 64.69373403056976, 63.492017869026434, 64.73652708914973, 65.13675397442233, 64.22907437047651, 64.1910901377278, 65.02586072491061, 64.70504222377654, 63.24708546361616, 62.65235608623874, 60.737906040683875, 56.78068953175699, 55.696181635702814, 55.28519176667737, 50.86338620032034, 49.69269206446987, 49.19175832502304, 51.99526848331575, 49.898294864162324, 49.35891012991629, 46.86245487582299, 39.96576709132041, 43.55814433866932, 45.49456357955933, 47.62820743745374, 46.897226687400575, 44.185672575427645, 36.59076759892125, 38.65491490210257, 47.453073609259825, 51.827704829554406, 51.63384952852803, 43.244884244857296, 29.42562495508502, 19.18768575114589, 12.071736493418294, 11.343515130781359, 9.633557854160186, 9.902335328440513, 8.374589796989195, 9.257553565886713, 15.072461462789967, 24.968553358508697, 38.694711269870886, 45.12275818855532, 44.388349286971554, 33.651935669683645, 31.678567701770415, 32.9608650361338, 31.55577005878572, 22.475916531778154, 17.260352680760047, 13.945221304893495, 17.02848961276393, 18.53965920786704, 20.517614387696792, 27.760127744367047, 40.03634622020107, 51.809665849131925, 49.36346792405652, 45.13731802663496, 44.76707373895953, 39.97822453898769, 35.29441641223046, 21.442348457151844, 23.85966597064849, 35.97863858745944, 43.45504483868999, 48.41479562943982, 48.18592532988518, 49.47291774134482, 48.9506463081606, 48.32643247419789, 51.69631719589234, 48.1665684330848, 40.59399743233958, 41.71374390202184, 48.75556330527029, 48.26636529737904, 54.753891037356475, 51.28603727586808, 55.210933454575084, 55.92130214937272, 55.38252538250339, 55.64557913810977, 55.59765169697424, 58.00222542978103, 54.76392053788709, 56.40945288442797, 52.5748888907894, 55.933132017812426, 52.952640594974646, 59.7373172544664, 61.24278568452405, 64.61969537119712, 57.09373781757971, 61.78292351384317, 34.22995182775682, 28.304723347387007, 1.4769022983889428, 5.976521805409463, 50.07885333030455, 48.850476818699995, 57.97465901220999, 51.20584049532491, 52.592210077470355, 45.21027803421021, 59.9877998136705, 30.302572788730746, 1.3400781370939747, 15.766386601232714, 69.656203023849, 25.383820572207053, 11.322542217469985, 28.014875881133545, 33.91485998707433, 46.895512611635276, 35.60423266503119, 29.816628386897428, 33.24545260398619, 37.68691316727669, 57.85842349452358, 17.73802676508504, 0.1985935701598083, 0.11776600814154072, 0.05630507224029111, 0.07585788070554696, 0.055504652085684, 0.12591182870129425, 0.08093436233579152, 0.04310940692742025, 0.02307796587927207, 0.14172539265165407, 0.11792402909768206, 0.030760663306160323, 0.21173110472098475, 0.17168718330081434, 0.3532831929624081, 0.15081824344252387, 0.060442981250103445, 0.07608691035138984, 0.1049544593139041, 0.07352991570388118, 0.06955283919289228, 0.02347472664569655, 0.0069743256092131625, 37.634922150642645, 87.09127964511995, 37.48602505653135, 33.091848665668124, 49.73431233436831, 47.76484320240636, 38.397203414670884, 24.109487610478556, 31.13630787018807, 34.824598835360625, 23.716789714751705, 6.0870924399745086, 25.31685002388493, 71.52421612893382, 74.81185267048498, 63.41895980219688, 52.526267190133375, 76.35010427044284, 64.35091495513916, 44.83793920086276, 10.643680941674019, 0.16383203948217054, 10.094529505698912, 60.52317196323026, 66.87304604438044, 67.67279378829464, 63.250262583455736, 64.39615557270666, 65.4464957021898, 69.54519994797246, 67.40258955186414, 65.95039475348689, 66.41435623168945, 67.19672003099996, 65.602402071799, 65.18832529744795, 66.43948293501332, 65.30150136639996, 62.50206655071628, 61.20436606868621, 62.32025292611892, 58.18558839059646, 58.41964798588907, 57.29173514150805, 55.29064778358706, 53.087209270846465, 55.40149396465671, 57.27277440409507, 54.452401976431574, 53.78277886298395, 49.57904923346735, 44.619757360027684, 48.125065834291526, 51.02083013903711, 50.68879758158038, 51.07735933796052, 46.89489679951822, 44.916574878077355, 48.45812213036322, 54.88862445277553, 54.70630092005576, 51.249006179071245, 50.97929223891228, 48.70112472964872, 38.518981241410785, 28.385847768475934, 24.434199064008652, 19.224336378036007, 17.437632045438214, 15.459501339543252, 16.824526363803496, 18.085623287385513, 29.90187914140763, 40.333673646373136, 53.659424243434785, 48.507461624760786, 40.91514149019795, 39.54918784479941, 37.88008597589309, 36.387361326525294, 31.180724790019376, 27.38186024850415, 24.047496511090188, 29.68619977274249, 32.609053927083174, 37.4056988377725, 45.063906946489894, 52.14726817223334, 53.789368444873446, 49.60468976728378, 45.92600076429306, 49.607725681797156, 42.35389824836485, 40.33455617966191, 28.14458474036186, 31.208461830692908, 39.919165411303126, 47.47052815652663, 51.37156063510526, 51.597885316418065, 52.15488933747815, 51.053503482572495, 52.54473763127481, 53.803559580156886, 51.95837466947494, 45.53314009020406, 46.78909478649017, 51.53058528900147, 52.216360722818685, 55.02683308816726, 53.138360900263635, 57.04606533050538, 56.93556824038106, 55.59670640576271, 56.39615212717364, 57.16729794779132, 60.0518834975458, 56.51826727774836, 58.0221353807757, 58.210946513760476, 60.82336271962812, 56.172353452251805, 62.6288140204645, 61.013636896687174, 65.26432906427692, 62.7459869846221, 59.61465297206756, 36.73003135188934, 29.320032788861184, 1.8619641974087686, 12.274038618610753, 57.56753267780427, 51.83515341051164, 65.38038023056524, 59.189530803311264, 57.45750234973047, 53.031374331443544, 65.21213408439391, 30.12210649828757, 0.9670199165421148, 24.706556681663763, 68.51364012687438, 34.27015612202306, 18.692068784467637, 33.35886793751871, 30.174011222777832, 37.63370229351906, 46.460972832095244, 30.156795940091534, 34.64265969491775, 45.21480052701889, 67.2151473260695, 21.648061083209132, 0.2838733900458582, 0.07362313328250762, 0.25424760556028736, 0.037646066217172536, 0.04466996250313617, 0.06330530023983409, 0.06256795593447263, 0.04784557314950132, 0.03498020664518399, 0.1650872745461041, 0.18521603557371324, 0.25450334103117067, 0.19206510676491648, 0.25580501634507413, 0.381782460477083, 0.34484117982849, 0.3968174875743928, 0.12928496745805587, 0.1855133542971265, 0.1838704174564731, 0.3230025258756453, 0.15545808559944554, 0.2836988752167071, 52.677753048558394, 94.51742464496245, 46.518255126091745, 48.95153668618972, 54.82247367981942, 70.53074252220893, 79.03902238415134, 28.928682227288526, 39.336905248703495, 48.050266235105454, 19.840024940429196, 7.853074890951957, 42.796631859194854, 78.76780617621638, 80.32111967763593, 67.08751340066233, 56.255841101369555, 83.04725323953937, 76.52957624004733, 40.56354415032172, 7.5600346153782265, 0.3075699910761849, 19.66321626017171, 68.95369083650651, 68.69450846026021, 72.40940878468176, 67.03673439641153, 65.47076340644591, 68.06040240872291, 75.71937930199408, 69.84431205257293, 69.37414538475775, 68.82219729884979, 70.80164494053011, 67.65602957817816, 68.53064752394154, 69.62488682039323, 71.01819899774367, 67.14959667574975, 66.25126407992455, 67.4562789547828, 62.468338089604536, 60.61582226907054, 60.987235423057314, 57.44005172483383, 59.597335707756784, 59.368026102742846, 64.75074960339454, 61.14510690012286, 59.88337063020276, 55.50824911363664, 47.16497159773304, 52.57501832900509, 55.413778828036406, 56.22692146608907, 55.17227457415674, 53.872075542326904, 50.89718918646536, 52.38854885101319, 57.9561964158089, 57.462409234816036, 60.14846401829874, 60.146600892466886, 56.20661535570699, 47.21194982528687, 40.19609259020898, 37.35807341914023, 37.69504816301408, 38.267392573818086, 36.358712334786695, 37.69873519097605, 38.92230287674935, 46.97937288591939, 51.841378211975105, 55.09302700719526, 57.30336104669879, 50.15294298048943, 46.46353413981777, 50.40899138296805, 52.772615571175855, 45.54424039779171, 44.16837100059756, 41.42939559874996, 42.777482848013605, 44.01395905402399, 44.39696281186996, 50.83985590165662, 60.809807008312596, 58.5245753103687, 51.5407403053776, 49.29053537307247, 54.34365034103394, 50.26363226675218, 46.2874589427825, 32.78021047192235, 36.88062290991507, 44.20672001377229, 53.395527178241366, 55.553842744519635, 55.00611120654691, 55.67875062265704, 54.84386628673923, 55.04686855500745, 56.30735358884258, 53.26530448852047, 47.66159465236049, 49.01875042146253, 58.345475965930575, 55.92279657240837, 59.0808968390188, 54.43543772543631, 61.584169172471576, 62.221848503235854, 59.92836021607923, 60.114759091408025, 60.01913562897713, 64.15264698766893, 59.82220911210584, 60.43938621397942, 60.32637488457465, 66.33067638643327, 61.524878624946844, 66.2991326855075, 66.57519694297545, 65.84547135137743, 60.788681122564505, 66.9703600483556, 44.122691077570764, 39.9481007360643, 2.99218891128417, 8.970576294006841, 59.33487030767626, 58.79425394919611, 68.41285090292654, 62.800547153719016, 64.90098422573459, 58.73907404561197, 70.6482724220522, 38.31813627673734, 3.252693371426675, 22.08215371254952, 78.8285715349259, 38.677295946305804, 19.784599888709284, 42.86807390951341, 42.642380729798354, 63.06915890785956, 52.461442178295506, 36.66007587986608, 48.272327300040956, 54.06842547078287, 76.58477967785251, 32.146988914858916, 0.42124331237808355, 0.20783105835078225, 0.3827501827430341, 0.19112352341894182, 0.0938452880889658, 0.21444901613698852, 0.19558882010319542, 0.11770010925829412, 0.11358622476578721], [0.0445095551831107, 0.05958323141620044, 0.06127397597376859, 0.08392437286074124, 0.23221140817528774, 0.2459527119513481, 0.06507449603128819, 0.05370507324715296, 0.05366804438733286, 0.02309590765845872, 0.07721788595400511, 0.11922897560702217, 0.10139039612465328, 0.14289949900440632, 10.01627233720595, 71.51822274731052, 49.225082782007036, 46.27753534624654, 30.146213385366625, 24.49876912178532, 58.051737508466175, 34.1481037293711, 20.04525511495529, 26.885188164249545, 42.647087574005134, 12.44540697143924, 0.8415374111744666, 18.26254963874817, 56.19918246423045, 70.10446717662197, 56.69700576413063, 50.21183736862675, 59.209589804372484, 68.97123952065745, 52.01143649316604, 9.20020459159728, 0.05294010381124193, 13.245326319048482, 50.58160312714116, 57.47112474133892, 51.75468990879675, 48.493415617173724, 51.69239874809019, 57.226906207300004, 63.13674134592857, 64.54814741688391, 66.17040834119244, 66.10731309460056, 69.30385651126986, 67.75237083435059, 63.95676382126347, 65.28408604283487, 63.676212372318396, 63.003467052213615, 59.05251849082209, 56.003534640035326, 54.14683365052747, 54.45227646058606, 47.46269518329252, 48.566603122218964, 49.82624092409688, 48.82436952283306, 49.1837880688329, 50.37920098150931, 44.995712618674006, 43.7738315520748, 47.32714983724779, 47.54477077914823, 47.810452522770056, 47.71463686420072, 42.333152832523474, 38.97634529298352, 47.85617559186874, 55.956470120337706, 54.228014945983894, 44.816844694076046, 29.967357227879187, 18.046825162826046, 15.094801322106393, 11.987856607283316, 11.591884513055126, 9.320748832917984, 9.255958141819123, 14.359209825915677, 16.105182305459056, 21.696525889058268, 30.621004527614964, 44.002560646303245, 49.42893228223247, 50.792909053064164, 41.33842406734344, 36.6814959433771, 37.019619941711426, 31.820779115922992, 27.603738923226636, 20.6503846568446, 13.85725921200168, 16.41995349237996, 17.02649312634622, 18.904922085423625, 21.309756655846876, 29.661873232933786, 44.976085078331735, 49.6907034227925, 47.876473857510476, 47.71840233956614, 40.858588757053504, 41.87244692156392, 32.37434910189721, 19.686601431139056, 24.726290126000684, 38.465605628105905, 40.64385467959989, 51.08661613156719, 45.17565919506935, 45.15035990745791, 44.232117360638036, 46.818406658787886, 41.273253886930405, 37.43372025028352, 32.201072515979895, 30.33654835916335, 29.228610184884843, 36.771812438964844, 45.19822066830051, 47.48452709567162, 54.55208509199081, 57.15324409546391, 54.57214801542221, 57.24670633192986, 51.376334159604966, 55.40157633443033, 51.955852585454146, 55.961886913545676, 52.572315815956365, 59.47220425451956, 55.94328703418855, 63.38182280140539, 62.570374627267164, 61.76510026378017, 26.35882373779051, 41.71086095994519, 7.620799974087746, 3.3080333567434743, 44.69277228078535, 51.16149810052688, 51.54973822255289, 41.55411912548927, 45.58517425291, 54.586111653235655, 56.51519998427361, 61.536441772214836, 9.454252585288017, 4.596883500775983, 58.65459011447046, 60.178885921355224, 20.94229332862362, 16.675307635338076, 27.401719208686586, 39.18680006457914, 46.9686608929788, 26.899971577429003, 28.960841740331343, 27.274326509045018, 48.2933747383856, 55.996372392100675, 7.6619647587499315, 0.37728662752816755, 0.1140083315511865, 0.10236152748186743, 0.09208273427981524, 0.15361941329413845, 0.059596427280696175, 0.11853907512681139, 0.03053274448780764, 0.0297582870529544, 0.0622775320023779, 0.06158740935666908, 0.08438145155988394, 0.08434369874697539, 0.1672191440217918, 0.27762413505584965, 0.07502226264125879, 0.18395222032502775, 0.05290200625876746, 0.05542848379381242, 0.04526962548674596, 0.07865154289550359, 0.031098793448519804, 0.24573371805731328, 9.064738673548545, 80.09636002202188, 58.50322977189095, 44.69138376174435, 33.210064980291556, 36.49622278828775, 39.648396353567804, 31.00998401641846, 28.291895235738448, 29.820995946084302, 46.29097730882707, 21.78021554023989, 2.144472296199491, 17.914309847739435, 60.62314925655242, 74.00401699927546, 65.38560090526458, 60.33089737738333, 63.63523929349838, 72.23563994130781, 60.43358110612439, 14.147816627256333, 0.08370928601512025, 12.247370423809176, 52.99265269310244, 56.335673101486705, 52.601749281729425, 54.53468545790642, 55.02011406806208, 56.7815799097861, 66.24760058618361, 67.1290591455275, 67.58122213425176, 67.67558651585733, 69.13226850571172, 66.01472946905321, 67.04261010692966, 67.27437511567148, 65.12623417762019, 65.13634604792442, 59.966807288508264, 58.45944435365739, 58.34904140041721, 57.31994090541717, 51.12744016032065, 52.36161001266972, 56.76201120499642, 54.42602011465258, 56.746812020578695, 53.8415712694968, 49.70133304595948, 46.77581364108671, 49.191852461907175, 51.87500861383254, 51.81908738228583, 51.61765013971637, 47.22896506709438, 44.570300194524954, 52.715992235368304, 59.142607488939845, 55.453614419506444, 49.692676374989176, 44.418222058203916, 38.332715726667836, 30.313706436464866, 23.20509103036696, 20.638317485009473, 19.772671961015273, 20.41329699177896, 18.38975602580655, 21.228404737287953, 27.50476771785367, 37.65472619764267, 48.21750040977232, 56.64293196893508, 54.61984403671757, 39.93691021396268, 50.409536592422, 45.12385645220357, 39.902550251253196, 36.72617566200995, 31.176474901937674, 26.086111145634806, 26.99977040290833, 28.81329982511459, 30.10669746706563, 35.48892282670544, 45.23273360344672, 52.20426805557744, 50.65002103005686, 50.12229357996295, 48.14728998368787, 46.063405313799464, 46.152525486484656, 37.18214727217151, 25.38431871321894, 30.67471746475466, 39.82709561624835, 42.63730910516555, 52.820303747730875, 48.70727108370874, 49.72499670520906, 47.748930146617276, 50.114295867181596, 44.651810969075854, 43.172088976829286, 36.37186404197447, 34.079940780516594, 36.067080190104825, 43.23712579665646, 49.351300731782, 51.40357894282187, 54.71216486346338, 59.29087700382356, 55.38998965294131, 58.84571936822707, 53.16564882955244, 58.42852823195919, 56.757508324038604, 61.83314946389968, 56.38009002131801, 64.19743261029645, 58.1146131023284, 64.58560212965935, 66.94623747179585, 59.48946268327775, 32.04706261234899, 48.90691580310945, 6.842359035245835, 7.013476846679565, 51.31513341780632, 55.051426349147675, 58.39171678789201, 48.42157348509758, 52.67430136280676, 62.38515638536023, 61.31381980834469, 62.94781646420879, 8.631766861484898, 7.7261121811405316, 64.38187030053908, 61.392769275173066, 30.590335515237626, 20.764619765743134, 31.885402125696984, 28.67954307986844, 44.23383535877351, 37.259551325152, 27.603387871096214, 32.032573376932454, 56.18200640524588, 67.35705083416354, 7.833653275043734, 0.34700421376093743, 0.09453934076572619, 0.23189622428148027, 0.17159220371996203, 0.23434528480133704, 0.10477732446405197, 0.0906947591612416, 0.06793734362168659, 0.04877900531996162, 0.21424385779086622, 0.20789108900052888, 0.20327599148356146, 0.11829242545871005, 0.30143739595528574, 0.29275697625933156, 0.27405254122230316, 0.3832990694190226, 0.1836704531864774, 0.18456581078710096, 0.2929120630987229, 0.3005071507105905, 0.3076095825001117, 0.43627242527661786, 20.788405018468058, 97.1065733509679, 64.62723416666832, 61.393534137356674, 42.055460791434015, 47.45621935013802, 82.84605918392059, 44.60768038226713, 25.663099212031213, 36.132811269452496, 53.258860034327355, 20.298916755184052, 5.294790825536174, 25.83681118103766, 66.84207500949984, 81.39259353760751, 67.63085580641224, 63.60251103678058, 71.19690218279439, 80.62316571512531, 63.23080370503088, 13.257017923939614, 0.10949520799782007, 22.925763360915646, 63.43183694347259, 58.45800092143398, 58.78596990339218, 61.25003422460249, 59.97743691167524, 58.30003922985446, 70.06612993055775, 69.1728493475145, 73.16050344897856, 70.07920711271225, 72.76431268261325, 69.06727483195644, 69.1052512199648, 69.01833934168663, 68.93255710601807, 67.52898400829685, 62.06543614787441, 63.35625679262223, 59.743683261256066, 60.00904337052376, 56.09252929687501, 55.293954341642326, 59.41234104094967, 57.93936552539949, 62.213717429868645, 57.87548188240298, 55.162441192134736, 49.56563080510786, 52.96675720522481, 56.36326697564895, 54.869628414031006, 58.251719551701704, 55.28974563844743, 51.4442813781, 56.89445787860502, 64.17261185184603, 60.953699158084014, 59.20775805750201, 53.09001768788984, 46.64058208465577, 41.713430112408055, 37.462698721116595, 37.020741739580714, 37.96742539252005, 41.873400057515795, 40.61656675031109, 39.42995171393118, 43.917696245255016, 48.63338931914299, 55.83321748241302, 57.89081442740656, 57.48887346636865, 52.31664788338446, 53.68324479749126, 57.55568711988388, 51.2527951886577, 52.73245834535169, 47.129666343812026, 41.766076164860884, 40.55412261716781, 42.563921559241514, 40.88462545025734, 45.22524187641759, 51.08383124874484, 56.12122535705567, 53.82468546590498, 51.53705719978579, 54.23863280204035, 50.253179150242964, 51.89084322221818, 43.75023457311815, 31.80307157578007, 36.521608368042976, 44.40726687831264, 47.82227062409925, 57.31404950541835, 50.81343873854607, 52.09648916798254, 48.64189301767657, 54.35902603210942, 48.077059945752545, 46.21334575837659, 39.2263767796178, 37.235377757780014, 40.38524889176892, 48.27717534957394, 52.3685839868361, 55.19885255444435, 58.54396750850063, 61.791744924360714, 59.15122101383825, 63.13971450251918, 57.77662246457992, 62.06777388049711, 60.031714670119754, 63.14674338986797, 60.789355770234145, 67.78953136936312, 63.94733444336922, 65.6748600159922, 64.4425925131767, 65.47272851390224, 33.913902928752286, 55.44449490885581, 13.469792777492156, 6.1574700570875605, 51.24686848732733, 60.02204210527482, 61.91396597893008, 52.43371494354741, 56.449515973368, 66.64930620501119, 66.76516517516106, 74.5975814327117, 14.214477308334844, 7.64374731048461, 66.39559945752545, 69.95159672152612, 29.556177123900387, 27.62408425731044, 38.606983538596864, 49.48926618022304, 62.91613548032699, 38.30985223093341, 38.334672989383826, 42.548090873226045, 61.5441256953824, 77.88885008904242, 14.216435551643373, 0.7928477431977949, 0.40654698807385664, 0.32610509003843036, 0.19149355920812777, 0.37816802700681074, 0.22636012054018437, 0.23109947751847007, 0.2616646543385521, 0.17651594273986357], [0.07612050330686955, 0.018253749341613824, 0.055001412758663784, 0.15622310100063203, 0.043963315340900616, 0.17845955376903858, 0.045096029963103995, 0.17350153997540477, 0.04691504062183442, 0.06029883797671046, 0.00932763662985376, 0.038561901348012115, 0.061838169086484186, 0.1937745860026729, 0.3463591677286933, 45.79194984128399, 67.07767609627017, 40.171954324168546, 28.15235495567322, 20.321186011837376, 42.012142135250954, 34.95939500870244, 23.468154591898767, 16.566330463655536, 26.732076483388102, 61.25376832100653, 8.559071613896279, 5.275919812340891, 35.872699291475364, 72.01535963243055, 53.41830830420218, 49.88503333060972, 64.27793533571305, 57.01177989282916, 60.3774441442182, 42.51107938828007, 6.315319961117161, 0.1432041415283757, 9.583270126773465, 37.895500890670284, 36.60860261609478, 60.6753207022144, 64.04396595493441, 66.55039971874606, 63.1157252865453, 62.66935563856556, 61.36810933389972, 64.81453910950692, 65.05828303675499, 66.3135434735206, 65.53807127860286, 64.7368840248354, 61.09101741544662, 59.547964834397845, 54.418226365120184, 52.899068863161155, 52.14587573082217, 53.37826090474283, 48.47404695326283, 49.71797174023044, 50.331320608815844, 53.66729251800045, 54.129743883686686, 50.6182223750699, 47.363184652020855, 45.28721924751036, 50.32728448990853, 50.33276796340943, 47.35397492685626, 39.041797884048954, 40.33933754890196, 45.524816820698405, 50.97843716221472, 58.22798136741885, 48.13425594760526, 33.17313194274902, 21.815971866730724, 16.006081661870404, 13.534544244889291, 8.747593472080847, 12.44678960692498, 11.115171409422352, 14.18187358687001, 17.597613757656468, 22.712360928135535, 29.904322778024984, 37.466409283299605, 44.64438984470983, 51.457821399934836, 50.35003031453779, 46.21987258234332, 39.36570329050864, 37.2406925693635, 33.931122133808756, 28.988131630805235, 20.5664655470079, 17.537038633900305, 18.16838529802138, 18.59215424906823, 19.14615177339123, 20.944615371765632, 25.98425307581502, 37.23551896310622, 44.47924629334481, 47.798548129297075, 48.64416799237652, 47.86787209972259, 49.07462066219699, 46.139495372772224, 31.459315053878296, 21.805991395827263, 27.552850092611006, 34.86415593854843, 43.52507875811669, 41.904916301850356, 43.179541480156686, 39.89812581769882, 39.12525415420532, 37.69723684557023, 34.73962853031774, 33.1507077524739, 30.667741529403198, 32.83844394068564, 34.27263113760179, 35.30357906895299, 40.87745143521217, 47.28137185496669, 49.21662615191553, 51.96912980848744, 52.76532388502552, 56.07134457557432, 52.376722904943655, 55.46965299114105, 53.9176417166187, 52.564863312628965, 50.9498901521006, 57.97220360848212, 68.02508538769138, 54.68128404309673, 33.76000873504147, 49.15362111983761, 31.981517845584502, 0.6894755159174243, 33.40099811553955, 52.00572944456532, 55.144629709182254, 51.35551814110049, 29.830101728439335, 49.64495681947278, 56.19610732601535, 56.53320758573471, 32.82569427644053, 3.064778990322544, 21.446925863142937, 55.68539904009912, 33.962199072684015, 9.725394268189708, 26.505185019585397, 29.908447150261175, 52.63896865229453, 37.64999974158503, 23.507260622516757, 35.87529590052944, 30.979016903908025, 47.64980008525234, 34.800335053474676, 1.2406677488357791, 0.050856957527538466, 0.034223464993579734, 0.1449807300682991, 0.10193171385194987, 0.07384223442885184, 0.10325204340680953, 0.061262848546668414, 0.03982929805774362, 0.09788755868231097, 0.09610700946781905, 0.05789372409063001, 0.021009737242674156, 0.07786019705235958, 0.055663511908102425, 0.1309337418886923, 0.04592809720986313, 0.13993352831852052, 0.06283664978259514, 0.11932130452365645, 0.055055230435344486, 0.08665914587195843, 0.08856095148310547, 0.1289077151206232, 0.2687998440477156, 54.86274857674876, 77.33668235040481, 43.82372410066667, 31.105344680047807, 35.48287060952956, 40.16118349567537, 30.467335870189054, 28.44824483317714, 22.655351238866007, 28.40984286800508, 65.9359133628107, 13.950066412648848, 5.062940995539389, 41.587153327080514, 81.53112380735337, 57.34216113244334, 58.98335533757364, 72.40386255325811, 64.54932020556542, 65.43796062469482, 51.12063484807169, 8.937461683827063, 0.061192556149176056, 9.032866474120848, 42.034836969067975, 41.88965435950987, 63.24994487147178, 69.37546330113565, 65.83444949119323, 62.270395678858605, 62.10329878714777, 62.00020320953862, 64.11565511457383, 64.55249340303483, 66.34234151532574, 64.07032428249236, 65.96075765548214, 63.43750476837159, 60.10302728222263, 58.59737842313705, 55.844494296658425, 54.77598574853713, 55.061518607601045, 51.42707786252422, 53.56866452001757, 55.71961387511223, 57.03481989522135, 57.605450230260054, 54.0434713517466, 49.48200587303408, 46.09826341752083, 55.1013659661816, 52.844457703252, 52.10246686012515, 45.293530341117616, 44.465043390950854, 51.896789535399414, 55.670164554349846, 58.21265274478544, 53.00848730148808, 44.15141459434263, 37.86258043781404, 29.194662071043446, 24.88529516804603, 21.99381213034353, 21.106495511147287, 21.424915482920987, 23.935063731285837, 25.244229301329582, 28.80785361413033, 35.45558268024076, 41.92769742781117, 49.91848722580941, 55.7905734738996, 58.41188953768823, 51.578187173412694, 48.57591482900804, 47.97601969011369, 42.546357185609885, 38.74990294056554, 31.56347751617432, 28.220523788082986, 28.137553891827984, 28.514725085227724, 29.538075385555146, 32.89284525379058, 38.81656754401423, 48.71738295401297, 48.8973020738171, 47.15196501824164, 49.75959593249906, 48.4460255407518, 50.6403249309909, 48.35488142505769, 35.5421729241648, 25.912983609784035, 33.264499633542954, 38.74856541233678, 44.56372630211615, 44.035669372927764, 47.04583352611911, 44.91401749272501, 41.884665104650686, 41.7304688884366, 39.96683397600728, 37.95001006895496, 34.896735145199685, 36.104962441229056, 37.055490016937256, 41.15260570280014, 45.94517723206551, 49.7800628600582, 53.34713297505533, 55.66055474742767, 56.88441268859371, 59.7070679356975, 53.33062764137022, 59.25188864431074, 60.53729641822077, 56.35882293024371, 55.80490973687942, 62.730148453866285, 67.65870463463568, 53.73058388310095, 36.57228931303948, 56.2665883956417, 24.079438332588445, 2.6631209302333096, 43.18271467762609, 56.794213864111136, 60.49818646523261, 55.75242057923348, 34.402053663807536, 54.02502836719636, 61.699486855537664, 61.45405238674533, 34.422630417731504, 2.436217699320086, 30.4742294357669, 60.41112161451771, 40.83071639460903, 19.16226879242928, 31.599267182811616, 29.98921071329425, 37.911453170161096, 38.77154657917638, 30.635758523018133, 35.12285586326353, 36.81847295453472, 57.61944916940505, 40.921680081275206, 1.09619582372327, 0.09121625819393704, 0.04390510031953455, 0.1425743712893417, 0.04398733219732681, 0.09964731627053793, 0.14021472855200692, 0.1621416511554872, 0.024839642517749342, 0.050986434047621106, 0.11084714634043556, 0.15888825960216985, 0.10617342777550222, 0.20297602209593021, 0.1464606740421826, 0.27327968108077205, 0.1557737138242491, 0.2943139427131222, 0.21458605394488384, 0.20517071078140892, 0.1707080156812745, 0.28898993807454265, 0.32047605983191924, 0.46819347047036697, 2.1563911534124807, 74.17794273745629, 81.52852719829929, 55.03221458004367, 43.810478256594756, 42.660831559088926, 62.559262552568995, 47.030155812540364, 28.6273245657644, 22.78227129290181, 32.935385319494436, 72.76387337715396, 14.300204630820984, 10.943483383424821, 47.09122711612333, 84.35510481557539, 65.92527589490338, 62.57231620050246, 75.54216661760884, 70.6544933011455, 72.73163149433752, 53.466518155990116, 8.801377011883645, 0.1699917847591062, 17.724392606366067, 54.43489643835253, 46.83166034760014, 65.81303335005238, 71.45348010524627, 70.87880580655991, 65.94441706134428, 65.08826563435217, 63.12207952622445, 68.39191329094672, 67.11184778521138, 69.79900083234234, 67.72697740985502, 68.80398181176955, 65.68324212105044, 63.555285699905895, 61.42591330312914, 59.95132177106796, 58.015549721256384, 58.90263688179755, 57.01660440814111, 56.7256155321675, 60.92202209657239, 60.21647399471652, 61.2460647859881, 59.21680304311938, 53.79997061144922, 50.63035818838304, 61.27388223525017, 57.944197885451786, 54.78399130605883, 50.73017074215797, 50.755611235095614, 58.93135255382907, 59.62880880601945, 63.671348633304724, 57.81436743274812, 53.10693879281321, 48.96349599284511, 39.010061986984745, 38.74622375734391, 36.29163588246992, 40.48021339601086, 42.70145162459343, 44.963961032129106, 43.6874766503611, 41.559535918697236, 45.7031120792512, 49.448716717381636, 53.37316574588899, 58.15899864319832, 58.1038305067247, 55.58822231907999, 52.494743101058475, 55.62632422293387, 51.37633808197514, 47.544496213236165, 45.13332505379954, 44.92897741256222, 45.58724918673116, 45.25598933619838, 41.102568026511904, 44.55559522874894, 49.319141218739176, 56.264042777399865, 52.48055981051538, 50.80255416131789, 52.27926377327212, 53.120706312118045, 55.36171720873926, 52.83058820232269, 41.208483788274954, 31.27246314479459, 38.39273975741479, 42.67503446148288, 49.163791825694425, 48.543872987070394, 50.273465648774184, 48.86790390937559, 45.96727978798651, 46.25180459791615, 44.11857651126, 41.926869807704804, 40.10448955720471, 41.02855682373047, 41.81069312557098, 46.032096955084036, 50.27546997993223, 54.72015080913421, 56.36742076566143, 56.639645022730676, 59.64864815435102, 63.084766018775206, 59.89249798559374, 60.49603700637818, 64.94750745834844, 58.987948433045425, 59.73651316858108, 63.11673725804975, 70.84805442440894, 57.69240133223995, 39.123998995750185, 64.02584852710848, 38.36803667006954, 2.7415156268304397, 41.41011322698286, 61.07183310293383, 65.05976177030995, 60.10850683335335, 38.24076360271823, 59.99626036613219, 69.52165003745787, 67.24401597053775, 43.67494467766055, 5.967308157874692, 28.499372928373276, 64.38005032077913, 43.90302265844038, 18.693573013428722, 41.142356549539876, 40.31714085609683, 68.52281062833725, 49.60383076821604, 29.399343113745417, 50.639250201563684, 48.51511809133714, 66.9756160243865, 56.94904942666331, 2.579459471087302, 0.6381628854620842, 0.16402864828705788, 0.21279898532215627, 0.12580731132578465, 0.25856867853191595, 0.27256348080212073, 0.23922626079330522, 0.1738302683037135, 0.2614483417522523], [0.08320084112065454, 0.16731230031338432, 0.058142051491285526, 0.1531065021070742, 0.06202730853410979, 0.11319306844304647, 0.12056342416232634, 0.1782459684557492, 0.18010371635037084, 0.11315094892896953, 0.10792869608849288, 0.04980982641779608, 0.15679314702508912, 0.053340476682229396, 0.052336947466697425, 21.46199364815989, 66.71380566012475, 47.82953485365837, 29.756218002688502, 48.187717853053925, 55.34541976067328, 43.32506141354961, 37.05696482812205, 23.22641891817893, 20.45790610774871, 49.4046018200536, 25.646629179677657, 2.4394512032308886, 14.984851402621116, 51.07459798935921, 75.08001727442588, 41.694116361679576, 51.41378102764007, 64.44294160412204, 58.6665847224574, 55.91171195430141, 22.58743343814727, 1.1446119676674567, 0.12012536742634351, 8.272918039752591, 39.88072618361443, 33.903528259646514, 39.42872008969707, 46.88657353001256, 54.78944732296852, 58.79619552243141, 60.61766578305153, 59.87337250863353, 58.03980173603181, 61.756067045273326, 56.14191193734446, 55.820512925424886, 52.255580502171675, 48.84216531630486, 49.10365796858265, 51.66707592625772, 52.29127407073975, 53.52651865251603, 50.75936494335052, 51.274336845644065, 53.65791805328862, 53.66984598098263, 54.67433752552156, 50.167314544800796, 47.7558413628609, 49.31986293485088, 50.02183383510959, 47.6030493551685, 40.992067014017415, 38.54334700492121, 47.61972727314119, 52.176281944397964, 57.969818807417354, 53.48740085478752, 39.05656560774773, 27.736826904358406, 20.750297231058923, 16.27435805336122, 12.402843371514352, 11.746749493383593, 13.806281147464631, 17.259546633689634, 19.20247112551043, 23.05246964577706, 29.53283509900493, 32.62481204925045, 40.676473109952866, 48.15247927942584, 54.5447894834703, 51.518312192732296, 48.135836662784705, 44.90800449925084, 39.71227999656431, 32.56671390225811, 29.435972167599587, 25.64617418473767, 21.428524063479518, 22.619355647794663, 23.676444215159265, 23.311128385605354, 20.62908422562384, 26.90648271191505, 35.981482305834376, 43.72775546966061, 45.17180350518996, 49.86500963088005, 48.286679252501465, 51.426144338423214, 45.95099410703106, 46.71043557505454, 39.410818392230624, 14.860801542958907, 15.563584373843288, 26.726587126331946, 27.753653872397642, 35.21998943821077, 39.43408981446297, 42.51471934779998, 39.82754276644799, 38.89789396716703, 39.09307110694147, 40.25746591629521, 41.740384640232215, 39.40761381579984, 44.0044786853175, 41.36712797226445, 49.60003391388924, 49.35621546160791, 49.89756530331027, 48.659967299430605, 49.279082052169315, 48.560856849916526, 43.18264407496299, 53.77605984287878, 53.49962296024446, 55.689584209072976, 61.922705019674, 49.253680782933394, 40.535561961512414, 41.80861034700948, 18.456369638442993, 1.6539373729498157, 11.675650650455106, 51.041304911336596, 43.77237635274088, 54.56966123273296, 42.444183364991225, 59.05580543702649, 62.72923454161614, 57.79965854460194, 55.9268876044981, 9.955191227697558, 4.515360959114568, 35.01777948871736, 32.64701266442576, 13.454893654392613, 13.426896756695164, 21.332751550982078, 33.148436700144124, 46.65651475229571, 26.307197501582486, 27.025607055233372, 22.868994897411717, 34.79897006865471, 50.294254210687455, 19.360736800778298, 0.31947322009551915, 0.11734861279687575, 0.06456329322029507, 0.2210316572698855, 0.09676684865788107, 0.07046073765283631, 0.06439244029142203, 0.09811158577400832, 0.022227016480399236, 0.1366934360515687, 0.019415469967850277, 0.03191944023954772, 0.012473472311431843, 0.13620646460162056, 0.01888330316080922, 0.04575783799913141, 0.11389898782175396, 0.17088521181816058, 0.1048740124209754, 0.08619282815244891, 0.13104925262591532, 0.025650567653018142, 0.1546109608945347, 0.12042915193183769, 0.1009825922008003, 21.97145069799116, 77.5435559980331, 55.58471572014594, 31.74028031287655, 59.940735293972885, 63.03699547244657, 30.63335999365776, 38.262615126948205, 27.861654373907275, 30.23227018694724, 52.67243039223456, 39.86351874566848, 6.211299194443611, 11.405625862459983, 53.794079211450395, 83.09123085391137, 49.91359603020453, 57.00570021906207, 68.81755321256577, 66.08679909859934, 61.50007747834729, 27.86969131039035, 2.802886501435311, 0.2426636053790008, 8.098652035959306, 45.047738936639604, 36.60257001076975, 42.88852514759187, 48.124034250936205, 55.08584514740975, 58.46578290385585, 62.43086376497823, 59.96514028118503, 59.32091843697333, 62.98256081919517, 60.88974099005423, 58.11171839314123, 58.99013711560158, 54.263065245843705, 52.55043683513519, 54.73041565187516, 55.863035340462964, 56.574200276405584, 52.81841708767799, 53.92984813259494, 56.01676087225638, 56.58066042007939, 57.82832322582122, 53.04394945021599, 50.966752421471384, 51.71837268337127, 51.960563352031095, 52.505513929551654, 46.50882967056767, 42.7318892171306, 50.5880005128922, 55.83777919892342, 59.399389374640684, 59.10254047762964, 46.98272651241672, 39.079609532510084, 30.870700651599517, 26.91145039373829, 23.541775518848052, 21.328266320690034, 20.723393694047008, 25.666852920286118, 28.196089383094545, 31.593607202652965, 35.49851694414693, 38.07842062365624, 45.692655040371804, 52.181059391267844, 58.21648490044379, 58.742600256396884, 53.24590836801837, 53.03669698776738, 50.143603817109145, 43.00745533358666, 38.51944015872094, 33.151660888425766, 29.53584944048236, 29.998002706035493, 30.468957770255308, 31.07182214337011, 31.272447455313902, 39.1335460447496, 44.99992916660924, 50.696956111538796, 47.23912792821085, 47.894783481474846, 52.292737114814024, 50.54911021263369, 49.44934821897938, 49.84205592063166, 41.46543433589321, 20.148221254348755, 18.533495203141246, 28.16444762291447, 30.990868345383678, 39.3814790633417, 44.57312430104902, 47.27584915776407, 42.360319168336936, 44.031656788241484, 40.21807355265464, 43.619294089655725, 44.62031433659215, 41.754614999217374, 46.808581121506236, 44.581176927012784, 49.88098936696207, 52.14253779380552, 52.94393685556228, 53.94370194404356, 52.183181393531065, 55.23602485656739, 47.91923161475889, 57.98475519303353, 57.473540921365064, 59.539904363693736, 61.270218741509225, 51.7769415147843, 45.48667177077263, 41.01516977433236, 11.531620237135119, 3.898290986976316, 18.35432721722511, 55.90092935869771, 49.746091211995775, 59.91968785562823, 48.78234917117704, 61.05320184461532, 69.04581946711387, 65.49760810790524, 56.352594206410075, 7.124003844876444, 9.68877011729825, 47.853653507847945, 29.748381107084214, 20.290187520365564, 20.398395907494333, 27.820112551412276, 28.669790106434977, 37.09587474023142, 34.863394998735004, 34.0588148947685, 21.779870371664725, 39.77899166845506, 61.73558442823349, 23.374521732330326, 0.6085807373446803, 0.04556777158511743, 0.11894124830442092, 0.2085317989751216, 0.08902623498391721, 0.11223990184765671, 0.10464348124280091, 0.042049137409776456, 0.025919723069115032, 0.07429441016527914, 0.16387481783186236, 0.15616929098483057, 0.16700157505129615, 0.23750542813251097, 0.18725632689893248, 0.1705497878813936, 0.23678532080544581, 0.3025796636939049, 0.4339311992929828, 0.24193052052249833, 0.29217404463598806, 0.22004095236620597, 0.45100671689837213, 0.2765120818249641, 0.16457883731251763, 39.574463598189816, 87.74718623007499, 64.352413300545, 45.56791190178164, 62.0289110368298, 71.51863067380845, 59.32172252285866, 47.179288248861994, 30.185146831697036, 28.083282016938735, 58.51133731103713, 34.452138408537834, 5.947069218081813, 23.89149404341175, 67.35707436838459, 85.5666700486214, 58.009203326317575, 65.46456606157365, 74.552199609818, 72.31477768190446, 65.74395256657755, 27.619061662304787, 1.973290991398596, 0.19063095952714645, 12.219093076644405, 55.96393439077563, 44.36788235941241, 45.66425708032424, 52.065302402742454, 60.17346128340691, 60.9963470889676, 67.09249481078118, 65.24189310689127, 63.70512416285854, 70.03212298116377, 64.66987817518174, 63.12309934246925, 63.354774136697095, 58.15950462895056, 55.573466362491736, 58.80559744373445, 58.383044427441014, 59.05609569241924, 57.283474629925145, 58.48572815618208, 60.12542401590655, 61.920069186918205, 63.47605382242511, 59.93038808145831, 52.97955589909708, 54.33526431360553, 56.25374263332736, 56.44404034460745, 54.50003916217435, 50.881460482074374, 57.797010944735625, 60.3763537253103, 61.95313476747083, 58.48609685897828, 52.982662416273556, 50.663329632051536, 45.3899775012847, 40.743792749220326, 41.16429828828381, 42.47942586098948, 40.10343051725819, 45.58212657128611, 44.14931612630045, 48.10386150113998, 48.45177181305424, 47.55282732748216, 49.01238049230268, 54.82785517169584, 59.19148806602725, 57.71515107923939, 56.22821977061611, 57.249365698906686, 58.362859910534276, 50.3550156470268, 48.81918807183543, 47.693397229717625, 45.880685621692294, 47.87479116070656, 50.36644151133876, 48.14611719500635, 45.160816946337306, 50.78838656025549, 52.06101525214411, 55.676554095360544, 48.20644324825656, 51.20982170104981, 55.777743401065955, 58.810312132681574, 54.38019898629958, 53.45328015665854, 45.98813110782255, 26.791637674454723, 25.18913765107432, 29.77685751453523, 34.42388949855682, 43.25414888320431, 49.55885687182027, 52.35440854103335, 46.988206063547445, 47.70005349190005, 45.27059232034991, 48.14996896251556, 48.933109391120176, 47.24527820464104, 49.05570307085591, 46.79683362284015, 56.25025564624418, 56.32069356979863, 57.34270241952712, 60.28616666793824, 56.23106741136121, 58.12234017156786, 54.298452869538345, 60.36862273370067, 62.20035391469156, 60.2282097262721, 61.09548891744306, 54.6335840994312, 51.15402990771879, 53.82091214579921, 23.12946773344471, 3.1284569540331444, 18.902582391615837, 59.84579824632215, 56.05032067145071, 64.42860534114223, 53.73501223902549, 68.95571477951543, 70.12260421629875, 70.78590839139878, 65.27375451980099, 16.64680181011077, 7.294742166996003, 46.14148793681976, 39.56361039992302, 21.270889889809396, 22.928530593072217, 34.23709838621078, 44.01353936041556, 57.68262286340037, 37.42397708277549, 35.20817918162192, 34.2236642683706, 49.76335748549431, 74.3090283486151, 33.72790413518106, 0.8563790470361711, 0.17677305716901057, 0.20716944949761515, 0.3390957961880392, 0.22905077454784226, 0.1326898912027959, 0.3730908865409513, 0.23044631095422854, 0.17562905807168255, 0.16154984823398053], [0.0943386410513232, 0.02840564582466839, 0.06606576017915242, 0.061059563285520965, 0.051627902449258876, 0.1880737733576567, 0.08959840307192457, 0.06629157225571333, 0.16906391438697616, 0.027748702446960156, 0.04472152788131949, 0.05553460612352337, 0.056638703531315254, 0.11481424072577108, 0.28246921216768606, 2.1172726202395658, 59.16422367095948, 64.99638411306566, 27.28707225091996, 37.210396182152536, 49.74388291758876, 41.59898319552022, 47.97920857706378, 24.841909831570042, 19.185506874515166, 35.8248620648538, 62.92003823864845, 8.88373992135448, 0.45312657411540713, 6.171514103489538, 41.59994025384226, 46.808498751732614, 53.108499896141794, 60.968000119732274, 63.133383797061065, 60.875930324677505, 37.67777796714537, 12.958779527295022, 0.6267603715100597, 0.3632236434327018, 11.756103365652024, 48.55849558307279, 40.072651678516024, 34.80921922191497, 30.018716742915494, 42.4758525817625, 40.608722009966456, 43.9739038098243, 41.113958589492306, 40.37728648031912, 36.644515837392504, 40.07977078037877, 41.8076297544664, 44.38008877538866, 49.42482556066206, 55.11090517044068, 59.516056353046054, 59.663043252883426, 54.30978067459599, 52.00617659476496, 52.00560000634963, 51.07936366911858, 52.75042280074089, 46.31713167313607, 47.46663324294552, 47.94353069797639, 48.11008630260345, 42.12767162630635, 33.41478132432507, 47.935038766553326, 51.4468740647839, 50.74411476812055, 55.17460446203909, 51.367826538701216, 37.51966722549931, 23.557017849337672, 18.612366222566177, 19.0701146664158, 15.19880198663281, 15.632453349328811, 18.218479848677113, 23.332450389862064, 28.111530926919755, 30.337275958830315, 35.45936776745704, 36.84230919807188, 41.264354029009425, 50.40606921718967, 54.89617501535724, 53.87237364246, 50.51744884060275, 48.60403037840321, 41.28873548200054, 35.02855816195088, 30.932150463904108, 27.235936310983476, 26.806679964065555, 29.935895896727043, 27.75765076760323, 28.017415615820116, 24.22294609008297, 30.776063665266964, 37.929727492793916, 43.48875761032105, 44.73616546200168, 47.22153217561784, 48.35851746220743, 50.32432310042843, 51.12231362250544, 50.039041273055545, 44.02150569423553, 32.30451130097912, 16.28640953571566, 16.21289255157594, 27.964891156842633, 28.484616971785023, 30.350945418880833, 41.224114433411636, 44.235380772621404, 43.982364362285985, 41.13830866352205, 33.5178376782325, 34.826920878502634, 42.56521986376855, 43.60252987953925, 43.66212244956724, 43.24204052648237, 44.02763635881486, 46.39915627817954, 51.61650872999623, 52.578697512226725, 59.401154441218225, 55.305015425528254, 42.8391581966031, 52.75587097291024, 53.595544522808446, 45.9435219918528, 40.67508851328204, 18.315283944529874, 2.0618421752606673, 0.4133758958308928, 2.8783102477750475, 40.67904618478591, 43.75261937418292, 52.28826953518776, 52.465776397335915, 58.252719756095644, 40.58525446922549, 47.812005781358295, 47.646756325998616, 12.295968590244172, 0.22289792406222514, 13.962264003292209, 56.49241101357245, 35.95321378400249, 16.308415012974894, 15.206749689194465, 29.812984505007346, 43.84661113062213, 32.34103445083865, 24.180074584099557, 30.410885118669082, 28.62264713933391, 50.23935279538555, 33.94951412754674, 9.275917122440955, 0.4417778088921501, 0.16129572154773822, 0.2595235305207391, 0.01728141522635856, 0.13866998886148776, 0.05926335523385675, 0.0787780240118023, 0.05000813593787532, 0.10174524039030076, 0.052510251876928156, 0.0189205254578302, 0.06194473957763084, 0.01752251075700887, 0.04976967191924492, 0.05621640522393489, 0.1802287725431304, 0.2109020596910869, 0.06509032340780382, 0.13460901806191092, 0.06531959820178247, 0.025717879968485045, 0.010242750680434608, 0.021693035960197452, 0.06826074763892159, 0.13615423272694313, 2.388403271475146, 65.05791041158861, 73.86038764830559, 30.720830809685495, 39.91501162129064, 56.79569652003627, 31.13924768663222, 36.91426115651285, 29.113219937970563, 24.148981955743608, 41.682141365543494, 70.3572560894874, 23.796054932378954, 3.8753532113567477, 5.026648284927492, 43.53070735931397, 53.8412457127725, 62.26983085755379, 68.13308392801594, 68.92371608364967, 66.51825981755411, 45.31596629850326, 14.865495639462626, 1.869855393325129, 0.5867564858448121, 16.02824893689925, 58.32857055048789, 47.96002034218081, 42.86210406211115, 38.97302696781774, 47.355230085311405, 45.36862019569644, 45.594591863693736, 46.39761870907199, 45.91139385777135, 45.380002913936494, 45.79720581731489, 46.337104382053504, 48.15796667529691, 53.765551813187145, 58.84531144172915, 61.624746091904186, 60.99663342199018, 56.26929090869043, 54.82887498794064, 54.77007081431728, 55.95117099823491, 54.41934031824912, 48.87535249033282, 49.95734614710654, 51.91034916908511, 54.13845154546923, 47.90933547481414, 41.32020073552286, 49.7553676174533, 55.224340115824056, 55.39826193163472, 56.55873437081614, 53.29890351141653, 47.28575314244917, 33.250284964038485, 27.38073256707961, 24.789489315402125, 22.56624871684659, 24.18017460453895, 25.72766926980788, 30.664393786461126, 34.482050403471916, 36.4218742616715, 40.36607242399647, 40.939813198581824, 47.49080681031751, 54.45462988268945, 61.29723210488597, 58.025622367858894, 56.45710968202161, 55.61225860349594, 50.68095676360592, 43.538116716569476, 40.65131110529746, 35.799068558600645, 36.618894915426935, 34.783598299949404, 35.931421095325106, 32.430960670594246, 33.59160177169308, 40.25870930763983, 45.556764525751916, 47.48370732030561, 46.284528932263775, 47.476803948802335, 49.052541640497026, 51.09964624527962, 52.71147758729997, 51.80667308069045, 44.48060343342443, 33.36927398558586, 19.019888716359294, 19.801405283712572, 31.297986007505852, 31.697852034722608, 35.16460557137766, 44.666143309685495, 47.83731683608025, 45.83275033581642, 41.98282634058307, 36.50088648642264, 38.25342501363447, 46.543574025554044, 45.777350779502626, 47.085622049147084, 44.34277919030959, 45.97277110622775, 49.38857501552951, 55.42263946225567, 56.11137236318281, 61.47669230737994, 58.32428339988955, 47.637397550767474, 51.93791166428597, 54.7157459874307, 47.824239653925744, 41.57981065011794, 11.360198932309306, 2.865697621337829, 1.3333647553959203, 6.517061677671249, 46.52235008055165, 50.019523559078095, 56.26641581135412, 59.950702036580736, 61.19704692594467, 43.73853022052396, 54.548974652444166, 52.325092746365456, 7.133180720190849, 3.064045507100321, 26.6740999298711, 55.834935480548495, 34.05780684563422, 22.50508915993475, 21.323053490731027, 33.28928901303199, 33.95518979718609, 29.459735847288563, 32.46564226765787, 31.27722097981361, 23.999119958569928, 60.166710884340354, 46.58464908599854, 10.605784962254187, 0.5489037750709442, 0.15430437250723764, 0.12246216542177624, 0.0718254390202703, 0.11485534134290873, 0.1534342191993229, 0.10332846833813576, 0.04977178249147631, 0.07473893268334289, 0.05639716366966886, 0.25180200775784833, 0.15454461768029198, 0.21762982852035956, 0.1605264773412097, 0.13016688787648756, 0.19071548966871155, 0.2611928054642293, 0.17448190269210648, 0.26067155924054886, 0.27539941572373916, 0.30700945986374734, 0.17183986462412343, 0.2024695460474299, 0.2582543066913082, 0.5963150568066106, 6.164985318337718, 83.69710368494835, 79.51299375103366, 44.213968553850734, 48.902965976345925, 69.18097649851154, 58.61085960941931, 61.584169172471576, 32.031804592378684, 27.042088854697447, 41.96199463259789, 72.55576026055121, 15.42255751548275, 2.253387200255548, 10.754688920513278, 53.86069282408684, 61.18000422754596, 67.4684932154994, 74.12001717475154, 75.259230367599, 72.10167531044253, 46.80561580965596, 16.30663033454649, 3.050032839659722, 0.40147861165385096, 21.971338910441247, 66.64624675627678, 57.94108744590514, 53.47749687010243, 47.52733976610246, 56.85997240005001, 53.14842177975563, 54.12421334174372, 55.534195592326505, 54.333699287906775, 50.00713671407392, 50.14196034400694, 51.234724829273844, 49.82848451983545, 57.92017336814635, 62.36698404435189, 67.42598256757184, 64.37425698003462, 60.64326317079606, 61.33093703177668, 60.14862091310563, 58.666074814335, 59.39411378675892, 56.910861230665645, 53.95735963698357, 55.51675281217022, 58.39713358109998, 52.42448952890212, 47.9839664120828, 56.815194622162856, 59.66811487751623, 57.947963360817205, 57.01144256899434, 58.12865910991546, 57.138335166438935, 46.57978926935504, 43.15107683981619, 39.51944058941257, 41.293822796114036, 45.146233574036636, 43.287689070547785, 50.44219816884687, 50.80579011671005, 47.861015796661384, 49.09694287084764, 44.947949917085715, 48.44307984075239, 57.098130872172696, 60.22913540563276, 58.296501251959036, 57.93323878319033, 59.31368166400541, 55.72211634728217, 51.45647602696573, 47.071066133437625, 47.29189949650919, 50.72365568530176, 54.103358099537516, 50.88956802122055, 46.86557708248016, 47.21373842608544, 53.94640837946246, 54.36868290747366, 51.085325671780495, 49.369120059474824, 49.2739829709453, 51.10572591904671, 54.15532165958036, 56.16432436050908, 58.562053557365175, 48.51462779506561, 39.15125554607761, 24.88620908029618, 26.407651362880586, 36.833593691549, 38.432320394823634, 37.32965976961198, 50.60682788971932, 53.487930374760786, 51.07784963423207, 46.93954513918969, 40.506944348735196, 41.41519269635601, 48.90955555823542, 50.22886829991495, 49.542759464633086, 49.57457773147091, 50.4374481785682, 52.40006492983911, 56.80318432469522, 57.14345778188398, 62.417151158855816, 61.54264696182744, 52.01285246879824, 53.35624464096562, 55.571344360228515, 55.16216662622268, 54.23744432387814, 26.62815916922785, 2.9941903006645942, 0.5708680674433708, 6.593590061510763, 49.17450774100519, 54.414998254468365, 62.47655153274537, 62.703417501141956, 67.21380587547057, 51.897640689726806, 58.70869528862738, 57.43883971245059, 19.175924524184197, 2.1654768336203793, 20.39976481468447, 64.55853777547037, 41.574284030545144, 23.62459832622159, 27.127125840033255, 42.13883076944659, 57.566654066885675, 44.8380333377469, 31.34735688086479, 40.54257908175069, 41.59803790430869, 68.1996230156191, 64.60329986387684, 16.65647045258553, 0.8965715741918934, 0.3704537361139252, 0.46344390920092987, 0.15146580224315967, 0.35615473565074707, 0.20155860621842647, 0.26604134529348344, 0.18175250610276578, 0.22230190765713492, 0.13733612253300606], [0.02939975981961095, 0.05975953506065473, 0.061323878941156214, 0.026420367273291754, 0.1283303682782477, 0.051708667268676144, 0.05802750602484711, 0.09616708608284112, 0.17663562099539465, 0.11208699835884957, 0.08046481938612077, 0.06862689936233145, 0.05410806996928108, 0.03414047851918205, 0.019918431587997946, 0.1322326133207929, 27.14426463650119, 59.908650305963334, 38.003107193977606, 39.085077316530295, 67.71851293502316, 44.538603521162464, 47.319681644439704, 35.69330969164449, 23.79666486094075, 19.14760697272516, 56.907782170080374, 59.88241749425089, 7.465489314448449, 1.546805799007416, 23.83883426266332, 49.296662115281634, 61.82588523434055, 60.26313058791622, 51.05794360560756, 69.5774418307889, 55.11308208588631, 28.507150988424982, 4.582479576910696, 0.6892770685015187, 1.723538238194681, 11.77711550266512, 17.424190082857688, 11.989030376557382, 15.573692321777346, 19.618995458849017, 22.356384261961907, 20.448816014874367, 20.59188054453942, 23.452657307347945, 29.74561191374256, 38.50672383462229, 38.36933105222641, 43.97303696601622, 48.564179097452474, 55.04606054675195, 57.44387995812201, 57.99341186400383, 57.82174541104225, 50.27773318752166, 46.7233205610706, 50.8897876739502, 50.6283381677443, 48.48050317456646, 48.09159624961115, 44.08258092018866, 40.95043105463828, 38.3454163612858, 47.2914013554973, 53.28379454151277, 53.717953851146085, 55.27519364510813, 52.96813003478512, 48.732793946419996, 36.45286883077314, 24.38961152107485, 23.298341458843602, 21.472338899489372, 19.304680247460645, 18.49185336020685, 25.568968211450887, 29.42099851946677, 34.20547623788157, 36.84067356971003, 38.33011519524359, 38.5155217109188, 45.9634986231404, 55.43657564347791, 56.679865006477606, 55.52015350710962, 51.481018297133915, 47.95700796188847, 42.924975733603205, 34.710395105423466, 30.66295035423771, 32.49487765373723, 34.76005623417516, 34.15842740766464, 33.66029031815068, 30.661306881135513, 28.592309567236132, 34.965176582336426, 39.58524227142334, 44.72781473590482, 44.94131326675416, 46.043934668264086, 46.9651464493044, 47.53862442508821, 50.2079346103053, 52.606452203566036, 49.624415366880356, 42.7724818260439, 30.89068904999764, 19.97572522009573, 22.034867578937163, 30.064886962213826, 33.95937496615995, 33.64824079698132, 41.43525169741723, 44.720664255080685, 46.446605190154045, 40.44506895926691, 36.960552969286525, 38.23158133414484, 40.047301400092344, 38.11470647012034, 40.04725825402045, 36.75746440887451, 38.805271117917954, 39.548681859047186, 41.97594258093065, 35.28299447028868, 49.40559025733702, 50.05390313363845, 41.11382130653628, 32.98904726582189, 23.06474078086115, 6.371337290733091, 0.20656678344934218, 0.524548736791457, 0.4170279595400057, 9.798141487183111, 51.40397510220928, 54.384509671118956, 55.11409797976094, 48.29971721095424, 38.39914106553601, 34.50803610586351, 47.974438974934245, 20.383030022344283, 3.4980699852589643, 5.388767382790966, 52.811458802992306, 60.83241554998583, 22.157445569192213, 15.220587811162396, 26.20633767497155, 34.17636048409247, 46.47898435592652, 26.452946893630493, 30.534455468577725, 35.537422933886134, 27.555372176631806, 56.00900634642571, 19.486168315333707, 2.2042673585876345, 0.0921134927099751, 0.03685892236629321, 0.2672686794352147, 0.06302763550211826, 0.08242808823143283, 0.12023517846940987, 0.08652852788086861, 0.06197865045959912, 0.12264277831080461, 0.09211589822605734, 0.019676571884643168, 0.03275948246159861, 0.013412797613249672, 0.05310467098869624, 0.0839389361921818, 0.17851595316202412, 0.0513199121210604, 0.11707378641491938, 0.1233954290528932, 0.07733077667052708, 0.07810605764989892, 0.07377404494271164, 0.0816920386146634, 0.09010639597451495, 0.10101135114147779, 0.0637309501818832, 32.070490929388235, 72.63807512098744, 43.47005967170962, 33.60140769712387, 74.24560362292875, 40.356937223865145, 31.432699811074045, 39.2911272664224, 29.850586306664255, 29.2682731920673, 57.694123252745605, 56.16921947848413, 17.81687621147402, 3.1030559299453615, 24.30026188973458, 53.38720783110588, 65.2666275731979, 69.1202974319458, 57.015568902415616, 74.03606276358329, 59.95684054590041, 36.33884552986392, 3.565805640912825, 2.9283300282493716, 2.7971681760203455, 8.85813174709197, 18.38464321628694, 10.847558879083204, 17.5848013354886, 26.58500329140694, 30.883422859253425, 28.521271521045318, 26.619061231613163, 28.237895965576175, 35.5017372100584, 42.43070217870897, 43.99887754071144, 48.02582594656175, 51.33465897652411, 57.39297936039587, 59.31690585228705, 60.904493024272305, 57.96258987918977, 52.382892793224705, 51.73847875287456, 53.187653326219134, 55.41120575320337, 52.05114264642039, 53.056830513861875, 50.733951907004084, 45.875923864303104, 43.44143029182188, 50.836800375292384, 54.25414577607186, 56.42905296817903, 57.89849835057413, 55.829624591335175, 53.59482280669674, 43.927772814227694, 33.28161685697494, 29.014193819415187, 28.743873873064597, 28.30774945597495, 28.145753606673214, 30.87382481944177, 38.46107529055688, 41.479947105530776, 43.10841321945191, 45.48883299673758, 41.987160559623476, 48.33325739829771, 55.40647929714572, 60.32815171826271, 59.25930192393642, 56.39269651905183, 56.26595689404396, 50.32004771694061, 44.10515808290051, 40.13011047917028, 39.116550414792954, 38.75940292112289, 43.45902212204472, 40.50137850546068, 37.30261502727386, 37.444781334169456, 43.24994802474976, 46.35151909243676, 49.30913133005942, 46.9528772754054, 46.82085421777541, 47.917584219286525, 47.791432949804495, 52.0163865243235, 54.07917668742519, 51.021555777518984, 40.9529923623608, 31.339041456099483, 22.788798116868545, 25.197670767384192, 34.43342478044572, 37.48674285027289, 35.62195393346971, 45.608661405501834, 46.54996356656475, 48.23963042228453, 43.13161403902116, 39.94287613899478, 39.436278497019124, 43.94409771888487, 42.60094088892783, 43.51056206610895, 40.10524657464797, 41.19613224460233, 39.117221140092425, 44.40128134142968, 38.602186479876124, 49.8116026386138, 55.28606645522579, 43.58177661895753, 37.174722225435325, 23.41605374889989, 5.6396980727872545, 0.6891601941277904, 1.9363651857260737, 0.9628931541116008, 13.0640677098305, 55.91046856295679, 57.856983984670336, 60.54963227241271, 53.664519402288626, 41.74012968617101, 38.40385183211296, 49.68017578125001, 18.20309239049112, 5.649431924666128, 16.206871713361434, 54.024079153614665, 55.55908695344002, 23.181460711263842, 19.814253007211995, 29.225992002794822, 36.27935101909023, 31.03118834957, 27.767525334512037, 36.33715106594947, 32.836308210126816, 28.90367319506984, 67.83583887161748, 32.356806301301525, 3.4971168493070914, 0.07212443547623773, 0.13143568269668088, 0.1685628315974628, 0.13615110708821204, 0.07873464045265029, 0.019653083628884727, 0.02704319292529216, 0.06681623523153606, 0.07888087131563695, 0.041140492014106245, 0.1659507782108361, 0.0946235491503631, 0.15364996488055876, 0.1398230431180808, 0.15633568528198427, 0.24863735982967963, 0.12758148668874658, 0.1581240715759416, 0.20016546000636395, 0.3025905114989127, 0.15462599153960907, 0.17975531488416657, 0.1747021682920956, 0.16504710089535485, 0.1906095090652666, 0.20568429612584654, 52.249504750774754, 84.05307446756672, 53.66799069989113, 52.65026115602063, 80.33840948535551, 62.29034877592518, 62.44684350106024, 47.13789547643354, 31.910981862775742, 26.7734202261894, 65.3730885444149, 70.34044481092884, 13.453408056689849, 3.815368404311519, 31.379628181457523, 63.451809652390025, 72.2916356978878, 73.9712259846349, 60.27860433824601, 80.84275568685224, 64.148869745193, 36.70193149197486, 7.045400527215774, 3.6948464714711715, 2.088005364902558, 14.435814695973551, 21.453735097762078, 14.366426006440195, 23.79106959988994, 38.11452211872224, 43.39070227838332, 35.9443570721534, 30.98195475916709, 32.198420993743404, 37.755334992562574, 45.605488208032426, 47.224744596788966, 51.270312493847264, 55.95295567666331, 61.19188900916808, 62.30057047259424, 62.986530257809555, 65.12893669066891, 55.173051203450854, 54.57992215310374, 58.11099667702952, 61.38291628130021, 56.53180337721302, 58.39697668629309, 53.30802302206717, 51.01275005648213, 51.07427635500508, 57.55392989804668, 60.50390528094385, 59.95591878890992, 62.781558959714836, 56.08566514907345, 58.37070072850874, 53.83574654979091, 45.37791621300482, 45.96628742833292, 45.99672109849992, 46.99334436847318, 46.94178873492826, 48.98328435036444, 51.482516642539736, 50.336505982183645, 52.247594556500836, 49.3254287781254, 43.41817848144039, 49.50979194333477, 58.37612536645705, 60.572154521942146, 59.09949279600575, 57.516235920690725, 57.87309315896804, 56.004605447092366, 50.43581647257651, 48.532066652851725, 49.36797864975468, 50.83576879193706, 56.2323578711479, 52.00667081340667, 49.20453348467427, 47.0129797535558, 54.76835673855197, 50.83267796424128, 49.83670188534645, 48.59250645483694, 49.22230966629521, 52.43724507670249, 53.1810833561805, 57.189004344324914, 58.03269440127958, 56.730161559197214, 49.577668559166696, 36.55397576670493, 30.0981721954961, 32.38645353624898, 38.466280275775546, 41.54396018674297, 38.74678073390838, 50.064520989694905, 50.632115410220244, 52.82654423867503, 50.13633566517984, 43.03699470335438, 44.66553141993862, 48.24129350723759, 47.364467267067205, 48.775386964121175, 44.21674166956256, 46.88753451070478, 45.385580524321526, 49.01539287259502, 41.07804144582441, 53.120886741145966, 58.35436013437087, 50.363786066732104, 48.15329905479185, 33.82755194940875, 9.561177376777897, 0.513919573277235, 1.5678202649278026, 2.978546662676719, 13.987702535044763, 59.912070612753595, 64.37680652064662, 66.55156074031707, 56.95027320615707, 47.4417144252408, 43.234133028214984, 58.84799042055684, 27.464241789233302, 7.77007459632812, 9.269333424106721, 62.03846200819939, 65.04624920506632, 27.173456876508652, 21.463378244830718, 36.8769476490636, 45.495846194605676, 59.23580300423407, 37.418058226185465, 39.115122672050234, 48.80567942896197, 41.13062474035448, 77.0427163954704, 45.73384777192147, 6.434506081765698, 0.3002495306634134, 0.2972510625277796, 0.3175857939547108, 0.187310611889247, 0.2735705493438629, 0.22751512066010507, 0.22594313888299852, 0.2282061166460476, 0.21844465495838275, 0.18629782833158973], [0.09135330366271158, 0.05494561857513844, 0.06584790775612478, 0.013450705558962881, 0.05395171908481468, 0.07378997957153667, 0.2452239018654631, 0.1096765486703765, 0.1066526770591736, 0.05734093419666733, 0.11045698542147876, 0.031856379712060574, 0.04094333928679267, 0.0075251974105354285, 0.0826260606728254, 0.22342552881567712, 4.734016916444225, 61.0286517297068, 46.339026343437936, 36.67180376668131, 34.842163208992254, 42.14870729754048, 50.0491492209896, 40.05629147252729, 20.022075868421986, 21.045024125806748, 25.02064439558214, 93.95407815133372, 43.4992068044601, 2.467266201011596, 14.019727706909181, 50.02421863617436, 62.93598267339892, 62.06013702577161, 53.847172414102864, 60.55121690996232, 57.44727280832107, 41.27697229385376, 11.970546207120343, 0.74248781968509, 1.808794018241667, 0.9010048330791536, 6.365036983643809, 17.574352141349546, 3.9434730141393604, 8.31832928042258, 11.078729648743908, 12.826950626988566, 21.931717088145597, 24.58551233814609, 29.869707861254295, 35.66115410097184, 40.62328184804609, 42.713536447094334, 46.189466368767526, 49.49314932669363, 56.6133455307253, 57.10020972836403, 56.93162625835788, 52.407619414790986, 52.46483110612439, 52.23772587314729, 54.10544087809902, 57.12075902569679, 49.98273957160212, 41.958017349243164, 37.88289047056629, 44.5681546580407, 53.18614713607296, 53.81721335072672, 53.78265726950861, 51.68224373171407, 52.50198771876674, 51.85497706936252, 41.75242631666122, 32.05629194936445, 27.628542031011275, 26.528889863721787, 25.093116068070938, 26.981884394922567, 31.725187032453476, 37.95460708679692, 39.155840796809045, 40.45088975660263, 41.123709601740686, 42.030483138176706, 46.528488589871316, 53.77933109960249, 57.680951933706964, 54.86676508380521, 54.880434543855735, 52.96704353824739, 45.29016494750977, 38.89882749126804, 34.20076547130462, 34.797950252409905, 35.24150363860592, 38.99944413092829, 38.60939579625284, 34.82487732364286, 30.756553796029863, 37.9018315961284, 43.282856710495494, 43.589107528809585, 44.26794428979197, 45.54999843720467, 48.324745855023785, 48.348742915738015, 45.68182537632604, 49.42672791019563, 49.56660747528077, 46.62405321674962, 41.6387991751394, 30.444199769727646, 24.462787259009577, 30.740366174328713, 39.22772215258691, 39.0639514307822, 37.73405613437776, 41.331748193310155, 44.75213343097318, 46.60895209158621, 45.001847205623505, 41.224185036074736, 36.84333685905703, 35.81744486285795, 29.26739654233379, 27.960413771290934, 27.050878886253606, 26.786956325654064, 31.739891998229492, 34.69965565589167, 33.6025647963247, 23.207889641484908, 11.509475515734765, 9.267274179766256, 2.350476403390208, 1.0649246049504126, 0.3660278010272211, 1.701015620943039, 7.2635720718291505, 30.916937551190777, 52.42668997856879, 53.13993769307291, 55.32345448770831, 47.01385051973405, 39.37125344430247, 59.763918768975046, 58.99561274436213, 20.21242064814414, 2.7040503726851557, 23.852207583765832, 59.423668846007324, 25.13049037225785, 15.502691538103166, 24.15689337638117, 31.589078826289025, 33.3127369419221, 44.888478940533055, 20.933813164311072, 34.98776943452897, 28.08323887086684, 32.04271270382789, 50.95206706754623, 21.66046557887908, 0.44958755434040104, 0.10172786551617807, 0.06052495648844108, 0.04898504849763648, 0.026877844338155082, 0.13964146495826785, 0.04115396367025472, 0.06041911761126211, 0.07068009160819554, 0.0296912620204591, 0.03326527286140669, 0.05419312488107432, 0.06463565022474335, 0.09643080418989544, 0.140241802099251, 0.07291723688643786, 0.0677035182654377, 0.11646897532045843, 0.21487318369890415, 0.12604024802004138, 0.02977341728945894, 0.08211637471592234, 0.03148996943397628, 0.043448799199634985, 0.07108534445926067, 0.12318596529263644, 0.14008386541278134, 6.107117610592996, 72.04801728648525, 56.07500022457492, 37.115929818922474, 39.96298220849807, 45.66169969497189, 34.36643069790256, 37.79658263729465, 26.913382161048155, 28.778424070727443, 32.68029789770804, 84.85133955555578, 46.29407990363337, 6.154779801445623, 12.47260860858425, 52.847226896593654, 70.52145434964088, 67.56936873159101, 56.507343476818455, 67.45682808660692, 62.81790756410169, 47.764725531301195, 14.925257852000577, 2.4631641372557613, 1.9545119087542258, 1.2483175964124742, 10.301447279991644, 19.15840918017972, 5.126327478116559, 8.96897400579145, 13.593373913918773, 16.895489884961037, 24.85261201858521, 28.908480059716013, 33.108000986037716, 38.82412202896611, 44.57568560877154, 47.38535388823479, 49.59361691628733, 52.47127556031751, 59.26149845123292, 60.01637035800565, 58.15661776450373, 53.18629226376934, 55.53730210950298, 54.53022964539067, 55.94399306081957, 57.269918918609626, 53.04457310707339, 45.357751307948945, 43.37148658690914, 48.037157673989576, 53.5393879490514, 56.021773661336596, 57.342659273455226, 54.14186008514897, 52.77130157716813, 54.49495184806086, 45.43075053922592, 37.300571472414084, 32.02055131235431, 31.992476947845955, 32.318231751841886, 34.984784510827836, 39.97888349717663, 44.02492992339596, 47.34990742898757, 48.67671974243657, 45.24215513660062, 45.898351976948405, 50.08687065493677, 58.52605404392366, 62.540023326873786, 57.76375316804456, 57.3878175212491, 60.361087860599646, 55.10825757057437, 45.85225628268334, 41.47917047623665, 41.786492101607784, 44.765304750011815, 46.55495674379411, 45.79513480586391, 42.758655471186486, 41.53800995119157, 47.87739561450097, 50.4039393701861, 46.886353877282914, 46.69542074203492, 46.66191585602299, 48.77144890446817, 48.51111335139121, 50.33141866807015, 50.72247897425006, 51.283534803698146, 49.447928320977, 42.03868089183685, 32.665873381399344, 25.852043705601847, 33.50835730952601, 40.4280262608682, 39.55494980658255, 40.031345198231364, 44.914150853310865, 48.17534669753044, 49.196967232611875, 45.731604176182906, 44.2755772221473, 40.78042768662976, 39.516522346004365, 32.64073883333514, 31.933282498390447, 30.50427479128684, 29.30736549438969, 35.144401442620065, 37.20452439400458, 32.41276283417979, 21.559291962654363, 11.627019143873646, 7.171175739457531, 3.522048169566739, 2.2569119401516455, 0.6305779408543342, 2.542409743032148, 9.924992899740896, 37.00060429111604, 57.64154388058571, 56.954556434385246, 60.83377661243562, 51.19300257775092, 44.55068049892303, 67.65315055847168, 61.74233482730005, 20.928547382354736, 5.317599408088192, 25.28080540318643, 48.8187958348182, 23.29336004872476, 18.608049654191543, 29.625903137268562, 34.07638319077031, 29.852025816517493, 32.17082711958116, 28.25185960338962, 36.05480317146548, 26.645864748185684, 36.8865260770244, 66.77597522735596, 28.548849705726873, 0.49927163508630573, 0.09639271429830021, 0.04447959731483171, 0.08226175522131306, 0.08446975851491575, 0.08904721047128401, 0.09626044155729395, 0.058642617171450015, 0.05796787757126074, 0.05209970152786663, 0.06867248159382613, 0.15718527679001132, 0.18262950823672358, 0.29397334002198716, 0.22532217865509374, 0.14004707787065737, 0.2033309046659739, 0.32080832748643817, 0.3089193783460125, 0.10366200769860899, 0.20137494429945949, 0.31520145254269727, 0.11508265495180123, 0.1592849246076038, 0.16644870471810141, 0.3138815443361959, 0.4925912258125121, 11.034087192627693, 89.47645725742464, 64.7374802251016, 56.4458603243674, 43.30222537440639, 57.90690006748323, 70.54816569051435, 51.084858909729995, 26.273553371429447, 30.120615997622092, 30.883650356723418, 101.1486856399044, 50.78261675373201, 6.217983403513509, 19.681423902511597, 61.58868382053991, 76.50746191701582, 72.24399458977484, 65.64288877671765, 73.8984424837174, 67.72367477416992, 50.04561516546434, 17.079853050170406, 2.683540544202251, 2.7938219039670886, 0.9273352750366735, 13.77182508668592, 20.751756352763024, 6.754214552141006, 10.564830514692492, 18.49509519915427, 27.41579463404994, 29.254631188607988, 36.60206010264736, 39.25763414752099, 44.262527496584006, 47.69098104969148, 52.55895622314946, 56.341842989767756, 55.83405294725972, 63.593509197235115, 66.57205120209726, 62.75980941710934, 59.788574787878225, 60.65761904562674, 61.12109414992794, 60.67439502285373, 64.36394899122178, 58.939656211483864, 51.89774659372146, 48.06462210993613, 54.954296696570616, 58.33218305341659, 60.55505691036102, 61.13263768534507, 57.87926304724909, 57.34049804749028, 60.38529280693301, 55.72540329348657, 52.84210035877844, 52.11823871058803, 47.682128260212565, 49.6629761880444, 51.43341249035251, 54.68497891579905, 54.58238932394213, 55.7154247837682, 53.888922122217, 48.189945759311804, 47.658684253692634, 50.598261433262984, 59.81628633314564, 62.15643121350197, 56.39608152451054, 58.856415671686975, 61.09544577137117, 58.46030335272513, 51.94676445376489, 44.88948306729717, 49.17436653567899, 50.01317324176912, 56.11767168967955, 55.52820613307338, 52.95571573318974, 49.494482932552216, 57.5267949411946, 54.943121863949685, 49.753226003339215, 48.217112095125266, 48.30656174690493, 51.230751468289284, 52.15043744733257, 54.770953347606046, 54.257966164619695, 54.727756284898334, 54.45936026111726, 48.17387580871583, 38.75924210394583, 31.7751697955593, 39.25549253340691, 46.71305571832965, 46.73224003084245, 43.73032069975331, 47.63393409790532, 51.22447175364341, 53.1935094248864, 49.88708080783967, 50.70427133191017, 44.78622667251095, 46.249870869421194, 37.78336032744377, 36.6075514208886, 32.97987676435901, 32.34879289903949, 38.562021409311605, 42.69135936614006, 38.90903742082658, 33.2561763640373, 20.98611600937382, 11.634235324398166, 4.565467276880819, 2.488096928404224, 2.025986931497051, 7.689639041500707, 12.488568732815406, 36.29189083653112, 61.25810646241712, 61.75247023182531, 66.41197143062469, 56.58253139065158, 49.78678188016338, 71.13284987788047, 70.93330321773406, 27.081583199962495, 5.161241965909158, 29.02295247200997, 64.3969871151832, 28.975356471154, 19.394310328268237, 32.94711320630966, 42.30137378938737, 42.416518888165875, 62.283159071399325, 29.390517780857703, 44.734106217661214, 40.67044050462785, 44.82272040459418, 73.02337738775438, 43.15458736112041, 0.9218203000003292, 0.40076164528727537, 0.345850546634005, 0.12788990602618264, 0.1590142657439555, 0.23924965711851276, 0.133726300912038, 0.10506944145045935, 0.12337038563864848, 0.16915889396782846, 0.15987007788592772], [0.12855946687200379, 0.10538557529329293, 0.03631367843838469, 0.012329151880206361, 0.022027147971394084, 0.04785063316024119, 0.12719749277758022, 0.2755359938788799, 0.04245550491877141, 0.19245121507875382, 0.13821559147008006, 0.08619174030759642, 0.011222575220369525, 0.03452117059139475, 0.018146374458146673, 0.04111570523931615, 0.685532124292466, 39.19440946271343, 58.12464652522918, 32.67663440396709, 29.812959009601226, 37.31512346575337, 45.80597231465001, 50.038774551883826, 30.458290884571692, 23.233812585953746, 23.94901756317385, 33.69232039297781, 67.8450878204838, 9.32401812845661, 4.65794401784097, 30.85995335732737, 58.474698451257524, 66.88532306301978, 67.81260275071668, 61.01517446579472, 55.312464006485484, 47.780203204001154, 12.591874157228778, 4.498579098332313, 1.329661792805118, 1.0411015994125798, 15.489655540835475, 27.42203904736427, 19.92270458129145, 3.372992219463472, 13.920599606729324, 12.209789214595673, 19.888499552203765, 25.677355066422496, 33.40420269197033, 38.418325378048806, 43.173324523433564, 43.37348699569703, 38.80014065773257, 43.60681703013759, 53.92391358652423, 54.06964925027663, 58.05148255440497, 52.186570321359945, 56.614883099832845, 56.705482006073005, 60.08036382736699, 54.76156319341352, 44.7721218293713, 37.58457852948097, 46.97897672653199, 55.24803123166485, 58.10908648275561, 54.4542964812248, 52.18999455052038, 51.391505887431485, 50.39959730640535, 49.58328147088328, 45.44470633229902, 40.32371474850563, 33.40393989316879, 32.13546499129265, 33.758835946359945, 30.784743870458296, 34.09305326400265, 39.70331738072057, 44.03163717639062, 44.289254526938166, 43.85794285804995, 42.114233586096, 48.20630204293036, 55.97886685402163, 58.58350499983757, 54.490299917036495, 53.337287825922814, 54.68211166320309, 50.13599049660468, 41.415055413399976, 39.174130808922556, 38.454732817988244, 40.601238127677675, 38.98614337367397, 37.05615289749638, 32.618055766628636, 32.19073510939075, 36.7052851184722, 43.09814445434078, 45.245410703843646, 47.52178961230863, 46.99534085489089, 46.92285545410649, 46.70853714789114, 47.034219388038885, 48.794214340948294, 48.09947236891716, 43.064780773655066, 39.09318485567647, 34.29882080324235, 27.927964002855365, 25.587707334949126, 38.23538603321199, 43.81332197496968, 39.52273930272749, 33.666252320812596, 30.87111250046761, 38.66361471914476, 41.632080155034224, 41.65933278299148, 42.94327751282723, 38.369617385248986, 39.33464204111407, 33.28948513154061, 26.74599305275948, 25.99399232095288, 15.661703444296315, 9.8955790458187, 6.279318976786829, 0.9527975861583987, 1.2280768180085768, 1.9092578080392655, 13.711020504274677, 7.181614637374879, 4.537130603867193, 7.055328536418177, 10.329486343168444, 42.88385752708682, 51.67291241307413, 48.58413219451905, 53.9129231053014, 56.7318207217801, 66.01959320806688, 56.704505335900095, 53.61242248165993, 16.41496914048349, 7.11981132145851, 78.33728682610297, 71.38901202909409, 41.950290280003706, 18.8126895120067, 26.34818626988319, 30.65480359138981, 43.24640612448416, 32.21351231298139, 17.17072456113754, 34.84036676345333, 27.261714127755937, 44.080149050681825, 54.409824648211085, 3.8678102483672485, 0.4644621013393326, 0.14154609743385546, 0.1683027141036526, 0.07726744418182681, 0.05056381015287292, 0.05478025083580325, 0.07878471962026051, 0.036148954212905905, 0.04843976243489212, 0.055226592812687166, 0.08718412294383011, 0.06406721298492725, 0.1114743272022855, 0.04330852850069923, 0.042968102009786714, 0.02032408088956389, 0.03156123284791266, 0.08074875455349684, 0.07852218128860959, 0.09175084966925845, 0.11687905452544652, 0.09863156795261369, 0.033537471561782786, 0.04827324556367052, 0.03206498162340253, 0.08798204948224368, 0.09535586025806204, 0.5874102346358762, 44.19365459872831, 69.80860279452416, 34.83356537357454, 32.532526523836204, 45.216608739668324, 33.79161519388999, 39.44067547398229, 35.257059758709325, 27.292169370958884, 31.57478767056619, 41.27430900450676, 63.3687573863614, 12.698307671854574, 6.089151194018703, 32.77740989961932, 62.16923382974441, 71.28673230448078, 71.35736634654384, 68.40677122915945, 60.053130811260594, 55.54700605330929, 17.88431352184665, 6.696153667665298, 3.743735628743326, 1.0502239292667759, 17.483961120728527, 41.623878479003906, 31.06487758698002, 6.9091486642437605, 17.575901477567612, 16.53341197198437, 24.510879439692346, 26.22905800419469, 37.69840571188158, 40.64850661062425, 46.807729967178844, 47.58527709591774, 43.27541597427861, 46.736723299949404, 56.878478142523, 58.501488239534446, 60.94335194556945, 55.32156390528525, 57.25822241075578, 58.9242216848558, 60.87617743399836, 55.807941729022616, 48.282792183660696, 41.399793471059496, 49.13272273155951, 54.33218917539043, 57.27720276001961, 57.05451803822672, 56.35928576992404, 52.20413861736175, 53.258412884127715, 54.98661310442033, 49.43410981085993, 43.5734494270817, 39.88651560198876, 38.931881304710146, 40.85938499819848, 39.339560693310155, 44.554489120360344, 47.656883885783536, 49.12029274048344, 50.04893349063013, 49.61715113732123, 47.44252635586647, 52.26908914504513, 57.58816042254048, 60.99394267605197, 57.67097734635877, 56.85690118420509, 60.01140071499733, 55.39018184907975, 47.6960644414348, 43.345595021401685, 44.13119869847452, 47.797049783891254, 48.266624173810406, 46.47736441704535, 42.41354180920509, 43.58902908140614, 45.809439689882346, 48.69832415734568, 48.9547844086924, 48.71941081939205, 48.40310304395614, 50.5879299102291, 49.26483600370346, 48.93049709258541, 50.034659985573064, 51.21847052727976, 45.834778201195505, 43.176835044737786, 36.43359430374638, 30.402908978923676, 26.713321670409172, 41.50210065226401, 45.81905734154486, 41.76062407032136, 37.00824899058188, 34.66138116775021, 41.10463903796288, 43.59984305597121, 42.647515112353915, 45.94763655816355, 42.32561011468211, 43.9166921184909, 35.96820116043091, 30.38319318525253, 26.26740505618434, 17.656929800587317, 10.86670102611665, 7.475797793557567, 0.9266258163317558, 1.2823561699159685, 3.492157012224198, 19.637928739670787, 6.885662492244475, 8.061204677627932, 7.383298008672654, 14.288736601029674, 44.20433129033735, 58.105940741877404, 51.38385726559547, 60.24682137273974, 61.24143638918477, 68.47789164512389, 57.34225919169765, 60.252465663417695, 18.02129641655953, 11.284553081758562, 67.79389304499473, 67.68685940773257, 41.211707976556596, 24.510651942222353, 27.342005045183246, 31.620267552714196, 29.63753100364439, 31.228422772499826, 21.23062675999057, 31.23282171064808, 31.146402089826523, 50.43275310147194, 70.48004981010192, 6.042533334224455, 0.19366567894335718, 0.04869452497411159, 0.14182922820891106, 0.07294133801253573, 0.09205586757631072, 0.07317823538136098, 0.09187464181694294, 0.06106744249982219, 0.01095332787372172, 0.005441076758753268, 0.13940485104197456, 0.2276042013639404, 0.24205379939127356, 0.14993532710979063, 0.21912258148433703, 0.18255993213144042, 0.14716846267542533, 0.14776886110344242, 0.24553179260223146, 0.1402692740122157, 0.3435840908317797, 0.261415675763161, 0.16631269346802466, 0.13331376256481295, 0.2048726106483129, 0.30061703836244924, 0.14885172638441288, 1.148985655557725, 62.31481652106009, 79.41029041044175, 48.773586596212084, 40.517664186416134, 52.861539625352435, 65.54701428259573, 66.615385547761, 40.65858710196711, 31.49473797890448, 31.398410451027658, 44.09333605920115, 76.27438683663645, 13.960053747700108, 8.632640569440781, 37.50179298462407, 72.60290715002245, 75.12677192687988, 80.31256106591995, 74.08750072602304, 66.70188165480091, 59.82428012355682, 19.550875656066403, 8.742351224345546, 5.078227452693447, 2.0142937331430377, 26.45387257299116, 56.5252177176937, 42.52470962462887, 8.244987822348072, 20.725558842382124, 19.74521536980906, 27.73787025482424, 29.098642449225153, 39.768503250614295, 44.27003099072365, 52.43652728296096, 53.536316733206476, 48.934948982730994, 52.03413524935323, 60.944434519737, 61.866552368287124, 64.76790605052825, 57.48784972775368, 62.57048445363199, 64.8954301495706, 66.97301157059209, 62.8216181262847, 53.37004353923183, 46.72535627119003, 54.447604917710834, 61.85500883287, 61.97158167439123, 63.23688337879797, 59.421087926433934, 55.64548107885546, 55.89917605923068, 56.57322360623268, 55.326392342967374, 54.165488443067, 52.93824549644224, 56.0113872251203, 57.276308459620324, 50.52980430664555, 54.24280228153352, 54.8939980999116, 55.14652813634565, 54.28780755689068, 51.21080229359289, 48.93583151601976, 51.7802559175799, 57.57319265796293, 62.21672196542064, 55.816339523561545, 54.51765452661822, 61.86673279731505, 58.71331976306055, 51.81311753488357, 47.79926592303861, 50.80947714467203, 53.91703374924199, 52.11360639141452, 55.83133866710048, 51.320173663477746, 50.99948460055936, 53.02543194063249, 53.67357223264633, 49.87050879386164, 51.749739877639286, 51.56781642667709, 54.854405695392245, 54.80141447436426, 53.95172711341612, 54.94244721628005, 54.65746741141043, 50.86089157289075, 48.98495920242802, 42.537527930352, 32.889693629357126, 32.09111671293936, 44.72832072165705, 51.80528848401962, 46.24572100177888, 41.89900529000067, 36.77258122351862, 45.06011793690343, 47.51691802855461, 48.80191787596672, 48.62398347546978, 46.725399417261926, 49.42903034148678, 42.41094912252119, 35.65208558113345, 33.250732114238126, 22.044698999774074, 15.949322023699361, 12.6173528932756, 3.2259207435192603, 2.1401542569360426, 5.5255453336623415, 21.65444277947949, 13.62883214027651, 14.655585096728418, 16.49925793370893, 14.961627048830833, 50.60844782860049, 61.964713604219504, 59.64964051400462, 62.340445287766, 68.10664715305452, 74.99402323076802, 66.3727947973436, 62.358252848348315, 21.752698152296006, 9.360896252816724, 88.31752238735076, 77.652723404669, 48.59633076575495, 25.113306468532933, 34.7341372120765, 40.99742104930263, 56.00855135148572, 45.255526496518044, 23.111966117735832, 45.23903685231363, 42.177207239212535, 59.02685442278462, 82.10191495956914, 14.967519429422195, 1.0952777439548125, 0.28771234856497857, 0.3152395730778095, 0.22431432870366882, 0.24639132793151566, 0.23717368141778056, 0.11696806628136866, 0.24000122001574886, 0.07627590424230984, 0.0988493973930036, 0.16661456275370815], [0.0455858244470531, 0.051741080448752454, 0.046877601904974836, 0.007760019638695785, 0.027280729977534186, 0.05617050506595162, 0.041686440742905104, 0.1501784374516818, 0.14710267104448813, 0.058372329860444994, 0.06285096413546032, 0.048337539492715756, 0.046459949920855226, 0.07439587084997086, 0.06120089118579223, 0.075896154458244, 0.3110859975699456, 14.96230758005573, 66.86668395996094, 40.933592319488525, 34.99700661628477, 29.6035397437311, 47.46502507117487, 48.878839477416015, 38.824879046409364, 23.85092692990457, 24.003693442190848, 27.449075944962043, 72.33909637697282, 52.62487949863557, 6.827446183850689, 22.983039771356893, 61.946917810747706, 67.71005630493164, 61.91653120902277, 62.82501882122409, 64.37445702091341, 57.82197683088241, 26.38231089038234, 11.937107020808805, 1.009010972995912, 0.48617775221505477, 1.1736378746647989, 3.9843181256325018, 4.821162175747657, 12.221785783767702, 18.602781911050123, 26.210675816382132, 36.06520921953263, 36.452166726512296, 45.1832882050545, 48.40239309495496, 51.10600832969912, 44.70659863564276, 46.62351977440619, 45.68836788977347, 54.24490859431606, 56.23609981229229, 53.25890710276943, 55.930103948039395, 56.85520279792048, 56.83794829153246, 55.75045939414732, 51.38481432391752, 41.79726685247114, 44.676000225928526, 54.43408843009703, 58.77011176078551, 54.073214684763265, 53.53594803041028, 48.351076725990545, 51.27467024710871, 49.87364668999949, 50.989584538244436, 47.638076120807284, 44.14970051857733, 39.43629026412964, 37.73879435754592, 34.76615159742294, 35.796821040491906, 37.35426479770292, 42.744931097953554, 45.867651585609686, 45.27709168772544, 43.603122157435266, 41.04519944037161, 49.49470650765204, 61.38976473962108, 57.59902146554763, 54.860324551982266, 54.85218563387471, 57.95192887706142, 52.94192467966388, 44.793451678368356, 39.52997215332524, 41.5878358194905, 43.73028147605158, 43.59679537434732, 40.04555594536566, 36.417579266332815, 32.61496101656268, 39.48597492710237, 43.23007337508663, 44.64833574910318, 44.75816211392803, 45.40828712524907, 47.980875584387014, 48.90681774385514, 46.316531550499704, 49.697363607345096, 45.08121244369015, 39.564618449057306, 38.96684531242617, 37.15816982330815, 27.046411306627338, 20.2363000377532, 25.883944342213294, 39.632240110828036, 45.07836872531522, 41.77736866858698, 28.01906889484775, 30.299695730209354, 30.83990808456175, 36.726905222862, 35.10310280707575, 25.692562095580566, 18.73926470356603, 9.927064891784422, 11.250114671645626, 6.267952928620001, 9.80859656487742, 10.236035873813014, 27.32783744412084, 12.160000608813379, 6.4795383234177875, 9.000960934546686, 1.327158585190773, 0.41077910291571773, 1.1228369296558443, 3.852568653322036, 20.014325264961492, 41.414094432707756, 52.90648998752717, 43.672865821469216, 51.381056693292436, 55.9236712609568, 50.79366214813725, 58.032180570787006, 49.40539021645823, 5.556687481941716, 17.35902382481483, 66.52837168785834, 50.26664464704452, 26.336915339193038, 10.48389534796438, 32.13366070101338, 32.27055534239739, 47.50567651564076, 20.49921847158863, 34.579662507580174, 37.63756975050896, 23.967034970560384, 54.50394976523615, 27.55484461784363, 1.7944711158352515, 0.21934500745227262, 0.074340344797219, 0.09527718302823844, 0.08795299176727572, 0.04142385644597873, 0.07127599310009711, 0.009097098748409941, 0.16261221300209724, 0.06959260681704169, 0.028055530236733538, 0.04098707141595022, 0.02996148421399055, 0.049148700200021274, 0.03920703164992794, 0.003150692679018023, 0.014477539169151458, 0.03454025384158858, 0.04810731858015061, 0.21360086487425914, 0.10143227049059446, 0.09092104621231557, 0.05726517193139561, 0.12861998781802195, 0.09163401359992643, 0.07736980118938992, 0.09399943264021028, 0.05466759760653781, 0.273384083543093, 19.01480728580106, 77.2050319179412, 47.32726358598279, 27.823426954207886, 34.369482301896625, 44.477077222639515, 31.1084766926304, 39.6292983331988, 29.02055786501977, 28.402635512813447, 29.485111621118364, 62.54967627986785, 49.63116968831709, 10.598180467082608, 25.79513011440154, 70.25692970521989, 70.61752103990125, 68.36647279800908, 67.2983015737226, 71.42140296197707, 61.61239454823156, 34.12474209262479, 12.670288220528635, 0.3396181762218476, 1.4109990024758925, 1.861435780602117, 2.8497441161063413, 3.9404500924771835, 13.994099920795811, 22.689201293453095, 29.834761504204046, 40.51134524806854, 38.86025490299348, 46.898120987799864, 49.98139812100319, 54.324838653687515, 49.374925167329856, 50.10838485533192, 49.75944688243251, 53.944580554962165, 57.91261496082429, 55.45129629873461, 57.01362340681015, 58.60004171248406, 58.89745150842975, 57.42086741232104, 55.975438702491026, 46.5727956833378, 45.18575929826306, 55.601154373538115, 58.122842234949914, 56.259818384724284, 55.03269703157487, 50.32713936221216, 52.54952684525521, 53.00105441001154, 55.51172433360931, 51.6508137795233, 48.610192421943914, 45.89041309971964, 44.11739980020831, 45.68115857339675, 45.227477627415816, 45.99124939210954, 47.68024160015968, 54.01839563923498, 50.0969393791691, 50.33619611494003, 45.64452363598732, 52.51296251050888, 63.42541994587068, 61.73041866671655, 57.44386426864132, 58.798188086478945, 62.416154876832046, 57.031026963264715, 49.83636063914145, 46.31523324597267, 47.09687140680129, 51.68267127006285, 50.75609760899698, 51.74825329934397, 44.31312607180688, 42.908701819758264, 49.05820162065568, 49.43899708409464, 49.942633336590184, 47.552909697255785, 48.73664179155904, 49.51905658168178, 50.324903611213934, 50.00526574350173, 50.89107813373689, 47.17413425445557, 42.02065367852488, 43.54609481749996, 41.115598140224336, 30.94117976004078, 21.65796114552406, 29.957264969425818, 40.01129404191048, 47.648219370072894, 43.1362267463438, 31.481252870252057, 31.284187109239642, 33.27195605924053, 40.421993655543176, 35.73466716274139, 28.27204804266653, 21.059650644179314, 12.076117780900772, 12.69705153280689, 7.005641421964092, 12.017949031245324, 14.136479996865797, 30.770462520660896, 20.072590112686157, 8.934756229000708, 11.459309381823386, 1.7874347514683202, 0.9090611362649549, 3.459976416441702, 6.673346556002095, 27.145029498684792, 48.13497374134679, 57.93024993711903, 50.4635319402141, 55.696911196554865, 61.42636437569896, 55.370389569190245, 66.56635592060705, 49.45551418489026, 6.954150507527014, 20.542905830567886, 55.3894248316365, 48.86911592175884, 33.946368386668546, 17.826231064334994, 32.181458703933224, 30.47378032438217, 33.608958259705574, 26.01992899371732, 35.69238793465399, 39.727267372992735, 26.24511226530998, 66.93414872692478, 41.40410415587887, 1.6546585987652502, 0.2733413971239521, 0.0866480069535394, 0.03385601475113823, 0.047647367051291856, 0.12158684102037262, 0.05607921802889436, 0.08787543302582157, 0.11787920529323241, 0.10186992886085665, 0.010133657844797259, 0.013610633116425767, 0.11296471295457695, 0.23183433969895686, 0.13450040211600645, 0.10151701513677837, 0.12496127446572627, 0.14642642991196725, 0.1668717537916476, 0.20594897950368546, 0.18128862454285546, 0.14614837063897043, 0.11797654442489149, 0.1447948158508347, 0.17080622815316723, 0.22292444602616374, 0.18431048900369676, 0.2318918269367949, 0.5746108053192016, 31.05447546128304, 87.03800601343956, 57.6393630427699, 53.10866071331886, 40.10142226372996, 67.92078172006916, 66.07199607356903, 50.29900420096613, 31.30541301542713, 31.69592222859783, 33.529138026698945, 81.24433578983431, 60.11386086863857, 13.058300845084652, 31.047577973335024, 76.14665092960482, 79.64421272277832, 75.18942002327212, 75.45027332921183, 77.78684493034118, 66.80392603720388, 37.00512678392472, 14.430680313417989, 1.8295301184538872, 2.60337489747232, 3.149052094067297, 4.390466809272766, 9.228081857004474, 19.092170153894735, 28.434693044231786, 34.63142210437406, 47.56418258913102, 44.75970752777592, 53.71860104222452, 55.064958526242165, 57.89425042367751, 52.869439278879476, 56.47873763115176, 54.259142875671394, 62.29566750987884, 62.276989183118275, 60.83349027941304, 62.93202892426522, 62.43509600239416, 64.89664216195384, 61.31704007425616, 60.52221098253804, 50.14379601324759, 52.207853101914935, 62.03613996505738, 64.70168859727922, 61.42579563202397, 59.0930954102547, 54.4028663635254, 57.2638863132846, 57.645670214006984, 58.78457353961084, 55.19050967308783, 56.28603550695605, 56.892963455569365, 56.252079548374304, 56.56215075523623, 56.94628415569183, 55.45653266291465, 52.8918791586353, 59.89248229611305, 54.978203542770885, 52.14234559766708, 46.50742153967581, 52.414232530901515, 64.66327682618173, 61.30000129822762, 57.371990757603804, 58.909771673140995, 61.64497767725299, 59.019488211601015, 53.04633817365093, 48.221003086336204, 49.24297271236297, 55.81494708215037, 58.10227332576629, 58.96013098378336, 53.85848452967983, 51.41932725906373, 58.327166341966205, 52.254901932131865, 52.22299737315024, 49.18089335964572, 51.40768174202212, 53.86714904539047, 52.03348021353445, 52.95616288338938, 54.451009535020404, 49.2129744252851, 43.90811389492404, 47.58048788193734, 46.76711382404451, 35.61091638380481, 27.413572611347323, 35.542270983419115, 47.134377110388975, 52.827450306184836, 49.32220066747358, 37.338885184257265, 35.989221142184356, 38.12165298769551, 44.375115210010165, 40.15897127889818, 30.231648491274928, 23.95892154785895, 15.377827786630201, 14.590195263585738, 9.516524134143706, 14.357878181242175, 15.894353928104525, 30.132798879377305, 26.009217000776722, 10.339781584278231, 14.509778830312914, 3.372654405332381, 0.8221035991464892, 4.664058502643339, 10.360320095093021, 25.32671674605339, 52.61828991674608, 62.220585500040364, 54.990488406150575, 61.33542814562398, 66.38315769933885, 58.79528161018126, 68.97975890867173, 55.9635696103496, 10.377550086667462, 21.59521302869243, 79.40200636463781, 53.86485838120984, 32.592679992798836, 15.753306477300583, 45.165955251263036, 41.20233351184476, 63.53944716915008, 29.66818628772613, 43.7439234795109, 49.22833834925006, 37.67522058179302, 71.4603756320092, 60.24586039204752, 2.1280944395449857, 0.5550565642695273, 0.14706937686329888, 0.15985972037719143, 0.2740957485812326, 0.20114678799385027, 0.2323470823466778, 0.10372866500890064, 0.3688751353371528, 0.17495718364033008, 0.10059022494862158, 0.10489901753082391], [0.0661965160660686, 0.058525493819146394, 0.010090029137509485, 0.014229342961052974, 0.06395184780440985, 0.07832446931711129, 0.058169634486999244, 0.06049851879417416, 0.3103492048478896, 0.23799523410777892, 0.09860011238244273, 0.09334383757724878, 0.04760262368607426, 0.06824359493029696, 0.03847797258546756, 0.06221293163816295, 0.038691439155128696, 1.8534345131727958, 60.59499448345554, 47.92748428160145, 33.89159640958233, 38.540071825827326, 34.21276007929156, 53.47462177276612, 43.47196986598354, 26.492570677111228, 27.362909317016605, 37.40396907252651, 61.647374245428274, 73.97868633270264, 22.821371439964544, 14.109626470073579, 42.68596218478295, 71.41252271590695, 63.59469767539733, 63.28987067745578, 58.06799573283042, 54.961156922002, 25.742878260151034, 13.476326465606691, 3.707951110216879, 0.7562793022201908, 1.233540679658613, 2.0567470164068284, 1.0343933658253763, 7.112820186922628, 20.494193915397894, 21.894399658326183, 33.10988372372043, 37.55469006876792, 42.91365969565607, 47.38245917904762, 50.38887746872441, 51.72639393037366, 52.07027204575078, 48.82718578461678, 46.769204447346354, 48.09238072364561, 49.1693772808198, 54.264865613752804, 59.83359967508624, 56.24647055902789, 50.26799786475397, 43.6227967662196, 38.580684046591486, 45.138769303598714, 51.54736911096881, 58.85558412921045, 53.05746593782979, 51.03238544156475, 50.32541351933634, 51.29002240396316, 53.79084325605824, 51.57054247394685, 47.83966241344329, 44.347803746500325, 41.30487211288945, 39.77348073836296, 37.91847029039937, 36.02909595735612, 40.43640444355626, 44.50397291491109, 44.94806758819088, 45.069131543559415, 43.24289952555011, 43.752913551945845, 50.840204992601954, 55.06252665673533, 55.44152567463537, 54.19783622987809, 57.16675666070754, 59.80085965125792, 54.3551036619371, 48.71988150381273, 43.02734567273048, 44.76273167517878, 45.76014334155668, 45.341901010082616, 40.9594681955153, 38.18971395492554, 33.82175860866424, 40.32764496341829, 41.5537465003229, 46.44976269814276, 45.43939152071553, 48.74078773683118, 50.72573846386325, 52.746214097545995, 48.68229343045143, 45.21994667668497, 42.566306360306285, 41.16508668468845, 38.43095148763349, 38.83186086531609, 28.409536923131636, 22.21461803682389, 16.196149914495408, 22.752639747435047, 30.63982209851665, 39.89039874845936, 40.201980067837624, 28.40869361354459, 26.471674250018214, 31.26520283760563, 26.226157411452263, 22.148667304746567, 27.510870925841797, 17.844919197020992, 24.31996983866538, 24.03046557980199, 47.13648734554168, 38.68064172806279, 45.42656144788189, 16.772811874266594, 11.467806216209166, 2.6717641180561436, 0.9885116245958113, 1.3806398573421663, 1.1062834243620596, 4.899015830409143, 35.03368077739593, 51.261926466418856, 49.4376281769045, 57.76147034860427, 54.69640478011101, 53.92139934724378, 58.42279764913744, 55.46555803668115, 25.73723985302833, 4.7340816355520685, 34.03275858971381, 44.91603359099358, 18.574034860057218, 8.62261106891017, 16.524182634968913, 31.285493258507024, 32.87937975698902, 36.25429884079964, 22.143895741431944, 33.068549786844564, 31.45180371499831, 36.41056214609454, 60.26418570549258, 14.289588735949609, 0.8386358378394958, 0.22942044261482455, 0.26723466513137667, 0.04786481727815924, 0.12023612075755674, 0.03946966191212978, 0.053390471580167936, 0.0941597595210037, 0.0300134843470709, 0.025122112541970228, 0.03846048279815624, 0.03549597534020582, 0.08453455423155139, 0.03566233516340295, 0.03799976901181283, 0.050771462115188765, 0.06165181819890296, 0.05882704900878091, 0.0351199870478482, 0.01799329859955657, 0.22106731100188148, 0.214534251079444, 0.19259482592103944, 0.034726099111139774, 0.0944176936642297, 0.007292536507931448, 0.021758580527779077, 0.08564877549126264, 0.1274917548101756, 2.8690931681663763, 74.44849998720231, 56.17654646596601, 35.26604198640393, 35.38302275442308, 40.15067938835391, 37.04976727885585, 39.412226523122484, 31.292682963032878, 30.44719449935421, 33.66198085969494, 60.33589447698286, 76.17438208672309, 30.27902287821616, 15.274814578794665, 45.532626259711485, 74.27504493344215, 71.5307507976409, 72.17299184491559, 63.77851563115274, 66.03241935853036, 31.970248876079438, 16.050945731901354, 5.198817781863674, 0.4586859822513596, 0.7417917828406058, 3.6112065853611117, 0.9174708817755023, 7.269713032630182, 23.1699054087362, 25.69892025762989, 37.5376630598499, 39.922542572021484, 45.788811945146136, 52.18605649086737, 53.76160590879379, 55.945526707556944, 53.74526923702609, 51.29182669424242, 49.671499498428844, 51.84584579160137, 53.08185523556125, 57.811272682682166, 61.88918444418139, 57.66754135008782, 54.888973543720866, 47.040867805480964, 42.963109016418464, 47.338493331786125, 57.12923526763917, 59.346311861468905, 55.556517800977154, 54.262622018014234, 55.15464352023218, 54.66020914816088, 55.28564676161736, 56.247764941184755, 51.88529306842435, 51.64608732346566, 50.40968564248855, 50.0733345554721, 47.627611237187544, 46.65482813312162, 49.81677232250091, 52.065961360931404, 52.122494482224994, 49.66972266474078, 49.07082380787019, 46.82647497423234, 56.08105636412098, 59.38607685027584, 60.556268922744266, 56.24477217274328, 60.19164539152577, 62.49346479292839, 59.109804707188765, 50.370218753814704, 48.43929867590628, 48.14823135252922, 51.690786653949374, 53.38705485866916, 51.60826783026419, 48.415560491623424, 43.840292192274525, 48.06453581779234, 49.801663352597146, 49.699952371658824, 47.42312631299419, 48.845754285012525, 52.06809120793497, 51.93236151049214, 51.25614489278486, 51.623804338516734, 45.52234964986002, 45.49186498888078, 41.83735347563221, 42.09660645454161, 33.009498503900346, 25.759601285380704, 18.09929470862112, 25.438408197895175, 33.39833874856272, 42.862759097929924, 43.68385238032187, 31.100582922658614, 27.466946263467115, 34.694364378529215, 28.717525351432066, 24.80305091027291, 30.779189794294297, 21.591653477761056, 27.844274351673743, 31.090010173859138, 53.26683421288767, 43.804724139551965, 48.55061554139661, 22.190005163992605, 10.002327330650823, 2.2115166341104815, 1.5162886559001862, 4.972133713383829, 2.221499311347162, 9.3576906957934, 36.654055041651574, 56.4113473892212, 54.83731985092164, 61.94986743311729, 59.4706117722296, 60.73303445692986, 61.07032299041749, 60.775862816841375, 29.27754371396957, 6.99499708990897, 32.71044131248228, 56.01989876839423, 18.478138792899347, 17.678294950915923, 20.6801103391955, 34.52766364620578, 28.855245651737338, 33.12462399082799, 27.28108083048175, 31.578564913042133, 37.18438302316974, 36.42236848031321, 77.43478082841443, 21.774535948230376, 0.4031537701525996, 0.1169531275668452, 0.03929138559127047, 0.04811602899984968, 0.12267886871291746, 0.06104157171061924, 0.14702169555089167, 0.06659554828318857, 0.05941798242049352, 0.034394440496520656, 0.05102714395991737, 0.021431985754339446, 0.16870003794470143, 0.22923618314727662, 0.15311376462059637, 0.17727234731278113, 0.12050599821152226, 0.1455594022427836, 0.10946941381740956, 0.1924046216111991, 0.4939922780519532, 0.38800297184817256, 0.22276154508994472, 0.18218150001860436, 0.21784770392602493, 0.354650353472079, 0.1297920716986541, 0.1564451132810885, 0.3095348840278964, 5.9489573490235115, 92.4704102546938, 61.923101179061405, 51.27834158559, 49.63019301814418, 51.615853694177446, 73.56694729097428, 55.87172339039465, 33.75738859176636, 34.62666034698486, 45.31742934257754, 69.13276272435343, 82.00616990366291, 30.537454120574463, 19.497670665864025, 53.58892356195758, 83.21287924243559, 75.72457252010223, 76.00748523589104, 71.78325729985391, 70.19204585782944, 34.05799511940249, 20.372386670881703, 6.586550877940271, 1.8351247666343566, 5.122512973123982, 8.216398646754604, 2.444361520390357, 11.162861547162457, 27.149908927179155, 33.34555541315387, 41.76346778869629, 44.457692869247936, 48.14797247609785, 57.2736059465716, 60.641113711941635, 60.85289032228532, 57.97680062632407, 56.84495756703039, 54.337762863405295, 56.5128073384685, 57.84230255311536, 61.504941217360965, 67.36193810739826, 60.83937383467152, 61.60235328059043, 51.26410730423466, 46.76199120859946, 52.047687038298584, 60.895259764886674, 64.49812150770619, 59.895988895047104, 55.305015425528254, 57.45582357529671, 56.41094338509345, 60.2394159378544, 60.37370612544399, 52.34736396420387, 56.99100702039657, 57.09276899214714, 57.65483679309968, 56.28731812200239, 56.83599495118665, 57.52038578833304, 56.36659706792524, 54.96642858751359, 51.35408647598759, 49.54290851469963, 49.227345989596465, 56.02203253776797, 58.754865507925714, 58.74136078742243, 55.53899265104725, 58.301796451691665, 63.98749951393374, 60.48262250038886, 52.998551937841604, 48.68487435002481, 51.747123656734345, 55.89463395457114, 62.1151678792892, 57.8576547099698, 57.763031451932854, 52.89337358167095, 55.95220258159023, 52.49366444926108, 52.21549780138078, 48.80495771285027, 54.47376712676018, 56.97782001187725, 57.929885156693004, 55.68356729322865, 53.89200902754261, 47.01913787472633, 47.67682129336942, 45.76703886831961, 45.69148617406046, 40.15910463948404, 29.467545286301647, 23.770987064607684, 31.397092534649758, 39.59160435584284, 45.986044406890876, 50.07211862071868, 33.97351118826097, 31.122967889232022, 39.72060326606997, 36.0730774940983, 29.62944503753416, 39.422405073719645, 24.27559606490597, 32.711947502628455, 33.03352694357596, 57.15239686350669, 47.90095729212607, 56.668647027784786, 29.548628522503762, 12.264950486921496, 3.725299998637169, 3.6954480649963504, 5.257861220067547, 2.9384536656641194, 10.154794762211463, 39.51774220312796, 62.66562938690186, 60.16765617555188, 67.6796422466155, 65.28263084350094, 64.5742311785298, 66.29200181653424, 67.15475067015618, 31.40064620202588, 8.437195727902076, 42.50133229840187, 67.05498126245314, 28.788602621324603, 13.21583794009301, 24.988333871287686, 44.36314805861443, 42.708915895031346, 51.72345607511459, 29.519195056730705, 39.66012424038303, 48.143218563449004, 49.505128245199884, 86.47668346281975, 36.36046563425372, 0.9008629535955768, 0.3390497083385145, 0.474063205502687, 0.2024139893511611, 0.167752341217091, 0.14565225209920638, 0.24336425407278925, 0.15576361678540707, 0.18617088756253644, 0.10578066215760286, 0.13015893588383354, 0.1128231705496869], [0.009501115325087262, 0.055493428897593296, 0.02923471383720396, 0.018766128097570712, 0.008360043641239887, 0.01394162044650124, 0.018223961927897988, 0.033335235841091604, 0.2274600542601078, 0.10574624948804418, 0.18706984577640412, 0.1735043898224831, 0.08092892311152913, 0.019195828729519443, 0.006968150461738509, 0.047155990595779115, 0.02391593008782835, 0.0168937134496387, 45.38858505987352, 70.50673761675435, 32.44855250081709, 54.23629899178782, 34.47589620467156, 42.09909323723086, 48.948069310957386, 39.21038919879545, 21.35939032800736, 37.74444257059405, 43.28786949957571, 76.48184099505025, 45.075568153012185, 9.024238240334297, 13.455606545171431, 52.07729308835922, 55.93494415283204, 41.83431363874867, 62.59043362832839, 57.21420557268205, 39.14378343089935, 24.023976018351895, 5.879392152832401, 0.2552902512252331, 2.1245657772787157, 0.23124043769653768, 0.7003469164333036, 3.312653418510191, 10.094302008228919, 18.45586561387585, 23.960919995461744, 33.413145695963216, 37.21999814433437, 45.772467428638095, 49.547772253713305, 54.14033036078177, 52.021768016199914, 53.417849386892016, 47.7227287138662, 48.39174778230729, 48.558134725016934, 58.60982410369381, 54.86204647248792, 51.537229784073375, 43.05986996619932, 35.9352610957238, 26.049354614750033, 40.538303698262865, 53.69494522771528, 53.84537596856394, 52.41747633103402, 53.509468109376975, 51.657093494169175, 53.81102777296498, 52.633485178793634, 54.07856872004848, 45.6215307020372, 42.08403525813934, 41.95617383526218, 36.55912976111136, 38.01837698105843, 39.989430750569994, 39.63539369644658, 45.3157348786631, 46.595647411961714, 44.78971758196431, 43.51933248581425, 42.21789790738014, 54.07861971086072, 57.70991079268917, 57.450826475697184, 55.24966293765653, 58.90901857806791, 57.55800916302589, 55.89192751915225, 50.236116839993386, 46.061514731376406, 45.1872694107794, 47.12167255340084, 45.788549146344586, 44.022580423662745, 40.81909441178845, 37.55144234626524, 35.756463773788944, 43.82796810519311, 43.169206034752634, 42.38239034529656, 48.74543574548537, 52.772635183026715, 55.58306047993322, 40.36560958431613, 34.2567337712934, 40.191193549863755, 38.495290125569994, 40.40153849509455, 36.829051586889456, 31.570902562910515, 21.263141247533984, 18.781165422931796, 10.565907205304793, 14.696356173484558, 22.996775911700343, 33.93065144938807, 37.674145852365804, 20.784343404154626, 20.449333767737112, 19.044807534064017, 25.98838137042138, 31.5374957361529, 30.105816894961944, 28.069794947101226, 28.45126701939491, 33.90347726883427, 25.714703875203288, 23.735187592044955, 3.437710101566007, 4.486061344223638, 0.18528734303770528, 0.6850669557048429, 2.776534302580741, 4.863785591817671, 11.011481592732093, 40.63144822274485, 45.45524181858186, 53.97492008824503, 50.22428304918351, 53.28874065030006, 49.809272750731445, 57.00131108683925, 58.479934815437566, 27.744706946034587, 8.886317899150233, 35.25845612249067, 30.29122929419241, 36.66935620769378, 16.082640444078756, 27.582224722831484, 28.586822171365064, 40.22138403308007, 30.238708757585098, 28.46045517152356, 31.339855347910238, 28.546841452198645, 46.8582461726281, 51.97157344510479, 4.75374153544826, 0.7744418985901341, 0.13836189894185913, 0.13790716447176474, 0.09233980274368679, 0.17470776073394284, 0.03661052218728489, 0.15349933667288673, 0.06287447537385649, 0.05021801721605082, 0.0035875603029008715, 0.056524813070052096, 0.047079151976973786, 0.026529128775901856, 0.04352626984097785, 0.02791786615196015, 0.05335789752162753, 0.027133673654809117, 0.129632985880298, 0.027014998974458828, 0.041488146544584346, 0.08082923975082175, 0.08352121142970939, 0.13680557600192486, 0.05829960130335343, 0.05765854275875515, 0.025319560213134657, 0.02197215818018923, 0.03287249192174885, 0.11817927427229383, 0.1968467977618979, 53.534943903646166, 78.12582400537308, 36.11831811166579, 54.55556031196348, 39.08371233171032, 40.2147630722292, 34.82279062271118, 39.67744542706398, 24.300940459774388, 42.18304764839911, 51.28076168798631, 81.16682975522934, 65.39116282616892, 14.105035335786882, 14.320768637041892, 56.876242391524784, 65.30328996719854, 46.74322266732493, 65.88597374577677, 62.85517008073869, 43.72582174116566, 26.66179153227037, 11.433470768313255, 0.2973549134067951, 1.5339785453773316, 0.4650978930294514, 0.7152024031646791, 3.8311096112574305, 11.236662903139669, 23.40330016228461, 28.915969825560047, 36.95911738180345, 38.566100674290816, 51.37035254509219, 52.58120390676683, 57.23508042673911, 55.57085798632715, 53.98436123324979, 51.15980755898261, 50.72649155893634, 49.662191714009936, 59.307805953487275, 58.81558772056334, 53.591355431464414, 46.36514932878556, 39.169247458058024, 31.20317251451554, 45.42969149927939, 57.33069604442966, 56.470759530221265, 53.47409617516303, 54.739111546547186, 53.04227459815241, 57.42509572736679, 57.99471016853087, 56.85656778274044, 53.37023573537027, 48.23519814398981, 50.678591574392016, 47.8111546270309, 49.930415153503425, 50.50894514206917, 49.42068746013027, 51.026344991499386, 50.87670264705535, 49.959891765348374, 47.71657059269567, 45.847361164708296, 56.83578314319734, 60.59371579077936, 60.36952880121047, 56.96886131840368, 61.22862200583182, 61.69785122717581, 59.02196714954992, 54.442415621972856, 50.27927467899938, 49.95950737307149, 53.08517356072703, 52.48043429466986, 51.932891030465406, 47.989147863080426, 45.91618307175175, 47.019082961543916, 49.37157154083253, 47.56621829925045, 45.170214945270175, 51.69432855421498, 54.46283155871976, 57.64391299216979, 44.54862909932291, 39.92054608560378, 43.658866882324226, 41.852756623298895, 44.78450082963513, 40.31862351202196, 35.585201324955115, 28.902474910982196, 21.770042873197987, 14.160394687806408, 19.364998455970518, 25.237631874699748, 38.48948109534479, 37.336123835655954, 22.2908846024544, 22.256304987015266, 23.67434770830216, 27.642405648385328, 34.145275700476866, 34.0503425751963, 31.429371679982832, 29.945693977417488, 38.395520717866965, 29.44523484476151, 25.105116559613137, 6.48776206278032, 4.009846381602749, 0.3222850692127982, 1.6816066301638082, 2.4391479549869417, 4.654912515994042, 16.044797416656248, 44.948644176606216, 55.79632759094239, 57.77053102370232, 57.299317083051136, 55.916159922076815, 56.69311477291969, 58.8323401635693, 67.6537859824396, 29.942514896392826, 11.848647767497647, 33.33886384963989, 42.25934951536117, 44.00145846028482, 24.836951955672234, 28.30152857688166, 30.045198625133885, 29.178058678104033, 29.50588057118078, 31.410960074393984, 29.113427823589696, 27.643556864030902, 54.30476788551577, 66.26401178298458, 5.508346230753007, 0.2367088039435687, 0.1357478537266293, 0.04317644345123441, 0.08228856063778363, 0.05476783255055066, 0.06101644402670284, 0.10527735005222982, 0.04673321348344607, 0.05762951185686454, 0.037820688298633026, 0.11418228713615287, 0.013072896850175195, 0.11280640854590362, 0.15703362202452076, 0.14994159370901125, 0.18676304288448828, 0.07253522714299541, 0.12544420097143422, 0.05262307364553694, 0.08581301708134913, 0.31539110526923214, 0.26645423604115365, 0.25628728401516715, 0.1935241671819841, 0.14863579684207517, 0.08811281303003912, 0.2420988913264967, 0.2601995571486412, 0.27656797559991964, 0.7360403624273116, 69.26580952059838, 89.1633972044914, 46.40374152891098, 67.38198141897878, 51.42463422590687, 62.4327661145118, 66.5334786138227, 48.93873799231745, 26.32372440830354, 45.53985911030924, 53.52223150191769, 84.50697114390712, 56.433214602931855, 12.146910678955818, 19.456413215206517, 62.189402657170454, 68.9107330383793, 52.458394496671616, 71.7272223195722, 67.28549111273982, 48.17597427675801, 29.911232033083518, 10.203010497554656, 0.5203076740426402, 2.765642370908491, 1.244204868712733, 1.3410848379135134, 6.289188640732919, 15.380357715391344, 26.66859096096408, 32.789741831441084, 42.42373604928294, 41.28656248892508, 51.654057579655806, 55.381937026977546, 62.20714353745984, 59.686295063264915, 59.848732179211034, 57.0980877261008, 56.626897319670654, 56.47263442316363, 65.92065534284039, 64.1358474762209, 60.988980877783995, 50.23133154838316, 41.803621092150294, 33.4071836933013, 46.69049816746866, 61.31970728597334, 61.369878322847434, 57.52112319392543, 59.217685576408144, 58.3436167624689, 61.84570104845109, 61.76479431890673, 61.96174829236923, 53.89229928293536, 52.331992195498565, 56.12704223202121, 54.49251605618385, 58.70665957850795, 60.63175101434032, 54.23785225037606, 54.977383767404866, 57.112180802129934, 54.0207725955594, 49.42721036172683, 46.95749782746839, 58.013894481043664, 61.61372815409015, 58.48880329439717, 55.98433463804184, 62.09898417995822, 60.26225982173797, 57.439341775832645, 55.375806362398215, 51.54328200124925, 51.82399034500123, 55.97922378970731, 56.7268196998104, 57.58101386408652, 56.455297547002, 55.790934331955455, 53.31085889570175, 54.97770147938883, 51.95800596667875, 46.66185309810024, 54.39312319601736, 57.40074957570722, 62.27421998977662, 45.45728145107147, 40.30434608459473, 45.7117412936303, 44.19955776583764, 46.99856112080236, 43.6960195725964, 40.425704217726185, 33.64288676169611, 25.819291914663008, 16.110350028161083, 22.378292660559378, 29.521258223441343, 41.836996539946526, 44.39829641772855, 26.761300102356945, 26.170920633500625, 28.954709114566928, 34.53561036817489, 38.40111009536251, 37.237048687473425, 33.41597372485746, 33.770512842362926, 43.06554171346849, 33.308261517555486, 28.807859497685588, 9.379477500915527, 5.308262205892994, 0.47695328751879357, 2.9936355304333473, 5.974050221904632, 11.841798328584241, 15.96625195395562, 48.164234622832275, 60.13878360871346, 63.240923420075454, 63.557784249705655, 62.27625569989605, 60.69874901925365, 66.48711619838592, 67.67251137764224, 32.51250478529161, 13.499285078817799, 44.42773772824196, 43.77255285939863, 53.44055991018973, 23.003677322018532, 38.19981405811925, 37.2538128975899, 49.26369459398332, 42.03220898105253, 35.50114493216238, 41.835800217043975, 41.10281121346259, 60.82941101443384, 79.20874334150746, 11.594749804466002, 0.9100398901970157, 0.40281877522507026, 0.37953040712783415, 0.2247705800278533, 0.264536319600959, 0.270445462196104, 0.3212828423467375, 0.15076843240568716, 0.09871583762428454, 0.11231329307080277, 0.23113065729698828, 0.07752537832505281], [0.020751096383338014, 0.07744981141220178, 0.045746170480044625, 0.053419146251173756, 0.07686752330271468, 0.02852241294608722, 0.05193437209292766, 0.044912180352595546, 0.06755661324507768, 0.11565181997514541, 0.11665216992579161, 0.0740051813303463, 0.06464490456686867, 0.02727828424183592, 0.01918121177192417, 0.07441808739977498, 0.06491192451287663, 0.11882583715862806, 22.331947895788378, 75.45731790604131, 42.98964777300435, 59.99918645428073, 38.72889472592262, 36.664519925271314, 53.93124057400612, 41.34428408838088, 27.34692369737933, 21.87306392577387, 39.823145789484826, 71.40464659660094, 43.72596686886203, 32.30940445776909, 11.961909148000903, 38.855332328427224, 65.76669054646646, 64.67346322151923, 63.88831061701622, 63.814169976019095, 53.0498133936236, 33.12223526739305, 15.973718185578624, 3.518611682999519, 1.4507321220251823, 1.6732226864945505, 1.7206545606736214, 3.9567377346177257, 7.997317602557521, 12.164158321196034, 17.573532365983535, 32.01420099504533, 38.32702044517764, 46.24235953054121, 49.80941395605765, 55.59078754917268, 51.045423400017526, 54.82793754146945, 49.421671975043516, 49.65503338844546, 57.16216748760593, 57.104136020906516, 48.0457829659985, 42.29319564757809, 36.33029868525844, 24.311897600850752, 28.899629231422182, 46.06245217784759, 51.13521429800218, 49.04958025101693, 52.102706124705655, 51.1362458813575, 53.274961363884714, 55.88648719172324, 55.31549992099885, 54.68333152032668, 46.587280996384166, 40.562728297325876, 42.311952421742106, 39.792535612660075, 38.49643545766031, 37.83279395872547, 42.61072328013759, 44.361853676457564, 43.883253912771906, 45.27024322940458, 43.452436462525405, 44.08902537438178, 56.64472056973366, 56.630713785848315, 53.680314786972545, 51.60059959657731, 59.38615137530912, 61.08814624048049, 54.996266057414395, 48.594004800242764, 48.40733920374225, 46.10779085466939, 47.09940133556243, 47.161763098932084, 46.45179448589202, 41.73463052318942, 36.08407974243164, 38.41701138404108, 42.157081557858376, 42.446254376442205, 42.37385919017177, 49.88840656895792, 56.48475454699609, 55.082730785492934, 41.71967452572238, 34.33314546462029, 34.65623501808413, 34.35886836821033, 38.05805960009175, 38.38909979789488, 35.43493532365368, 24.33995431469333, 22.9835771360705, 16.914103492613762, 6.796894842578519, 20.50727698110765, 22.1351037486907, 32.10616880847562, 22.6919920598307, 18.620503179488644, 15.206477084467489, 22.657471279944144, 14.51850022039106, 5.553377982108824, 7.8177662049570396, 10.528681951184428, 16.956702393870202, 6.986228141092486, 1.8807508796453478, 0.6431798420606122, 3.015263479563498, 0.7051785410411897, 1.8803499398692962, 6.960200273221539, 2.5957821694112595, 13.612580780060062, 36.76031989435996, 52.41640160160681, 52.04500805947089, 56.64959607585784, 50.205949890998106, 53.97413561421057, 52.50007360212265, 40.171260064648045, 14.904492824308335, 12.208904720121815, 49.66645140801707, 36.64507281395697, 17.671987779678837, 13.056019006236909, 31.993718378005493, 28.8393404406886, 46.53857300358434, 27.11771019043461, 27.328631724080733, 32.19675398642017, 38.47628624208512, 54.48795433967344, 42.88663064279864, 1.1849628605188862, 0.21263346436523625, 0.12477863144369856, 0.07310453006216595, 0.10830204137751173, 0.02329737537600581, 0.062313312138881416, 0.16462135519231522, 0.0845275215444065, 0.03219326687676292, 0.044304848828863715, 0.053400327301313805, 0.017434282325989297, 0.020310745214021975, 0.040287001118544614, 0.021562703336859425, 0.04425897931439742, 0.014286695175894327, 0.08379504189736421, 0.09411985400102793, 0.012393739795492542, 0.11960121006855082, 0.11378523908675679, 0.12004564065606364, 0.0655605175322102, 0.1023356796753022, 0.025039970679509065, 0.06311058367211973, 0.03605595879977749, 0.05397544482782964, 0.10965860689118986, 24.564584532091697, 86.72858592002623, 48.26956987380982, 66.51332547587734, 46.18924671603788, 41.02956487286476, 41.69283374663323, 38.742689701818655, 32.506925213721495, 30.565975635282456, 41.77269320334158, 78.31274063356462, 44.87454275931082, 35.46076805360856, 15.011887319626348, 41.055695702952725, 70.10506337688815, 66.52896004338419, 70.66155356745567, 64.17005838886385, 59.30453861913374, 36.24118635731359, 18.850993417924453, 4.501309558268517, 2.8867394212753545, 2.349998119377321, 1.9527886399338323, 5.099647025908194, 9.899384725478388, 14.820520762474308, 19.023822853642127, 35.25630666363624, 40.868888901126006, 48.48558656630978, 53.26956418252761, 59.80358962089785, 54.28543060056625, 55.20029598666776, 54.09399932430637, 52.920033931732185, 58.75140205506356, 58.911003297375096, 50.62785963858328, 46.10633957770563, 38.53003448055637, 28.106114133711788, 30.818886141623224, 46.01304992552727, 52.38024127098822, 52.928823963288345, 56.28684743758171, 56.13454572616085, 54.459513233553984, 58.42995597470192, 60.76816712656329, 58.37852193463234, 51.855518356446304, 48.312033453295314, 50.10849860406692, 50.37556494435957, 47.7543116384937, 49.00805804037279, 51.536213890198745, 53.01027590228666, 49.76396545287102, 50.626714306492964, 46.83157405545635, 46.97485823785105, 60.92316742866271, 63.69662046432496, 58.546383688526774, 56.45601141837336, 62.71887556199105, 63.33596637172084, 59.69965073370165, 53.39763741339407, 52.17619957462434, 52.60147079344719, 53.510809559975904, 53.83546021676833, 53.15027313847696, 51.76062445486746, 44.26448868167016, 46.24940018500052, 47.00017321494318, 46.10618660526891, 46.36005416993172, 51.53927333893315, 56.92887667686709, 57.86424821422946, 42.85960943468156, 36.37319372546288, 39.403028565068404, 36.713263219402684, 39.56288476144114, 40.38518221147599, 37.66746997833252, 29.82135484295507, 26.96564578240918, 18.362383765559045, 10.81029930422383, 24.774088128920525, 22.470382067465014, 37.16515556458504, 24.665911120753137, 22.54089059368257, 16.872812701809792, 25.060691795041485, 15.4123632754049, 5.635757561652891, 8.567551778208825, 12.994035751588884, 20.85430475973314, 7.51746807367571, 2.7407294367590262, 0.49079042889418145, 3.1319074140441034, 0.13925200117932213, 0.1782378479237518, 3.2069354912927075, 3.859219277097333, 16.629070735746815, 41.78284821971771, 59.47279653241558, 55.49462672202818, 62.30021353690856, 56.34855416513259, 59.67396313144315, 60.53994794045726, 45.44540059181952, 13.87726624165812, 16.226003073876907, 48.476121887083984, 37.255574041797274, 30.108195812471454, 17.812763606348348, 31.231033109849502, 26.044459496774984, 31.6130131290805, 31.78458348397286, 25.71436655136847, 31.598823954982144, 37.7594966273154, 64.88816984238164, 50.24330262214907, 0.6090350581272956, 0.11586313766817893, 0.06892871502186022, 0.14060515760173722, 0.07371942287371044, 0.08780562709416113, 0.004979621303538162, 0.08406219973919854, 0.03488613870896159, 0.006601654477567683, 0.019726982385280634, 0.06229334022669543, 0.023736544854698644, 0.09721819701935015, 0.11276939883828165, 0.13946356402049143, 0.11585841090568613, 0.165229537073643, 0.2315562191389261, 0.21324644195697, 0.1327338646496496, 0.15046273268038227, 0.25085374412517397, 0.26307211107304024, 0.15054220664164714, 0.3139420652822141, 0.09139622756910902, 0.21957731595443142, 0.1946020835349637, 0.18824641893227256, 0.16822593677188122, 37.16812087643532, 98.82002153704244, 57.538875841325336, 75.05202724087623, 52.341103861408854, 53.15334827669206, 75.86840583432105, 51.16641675272296, 36.16427260060465, 27.823138660000218, 50.32679811600716, 82.49086503059634, 51.761561901338645, 39.57016860285113, 18.28799797642616, 47.57245486782443, 78.56455679862731, 76.4175219689646, 77.65055041159354, 73.89155480169481, 62.88179905183854, 42.21284197222802, 21.15315994908733, 6.492378202176864, 5.3657724876557635, 2.7561107662416275, 2.2618158834595836, 7.120955182660011, 14.446061888048726, 17.87143441938585, 22.171526878110825, 37.20992157536168, 42.50094398375481, 50.49862930851598, 54.954226093907515, 62.862626506436264, 56.89794878805838, 60.45765269187189, 60.1778974840718, 57.169408182944025, 64.52191068280128, 66.08537135585662, 55.04751574608588, 50.56049293087375, 42.37265894489904, 31.28756230877292, 36.45169211972144, 51.52476056929558, 56.48063998068533, 56.00467604975547, 57.646772400025405, 59.839294956576445, 59.11240131624284, 62.16038496263566, 63.03515195846558, 60.7814561167071, 53.572990894317634, 52.50404696310721, 55.46806443122126, 56.91459924943986, 56.218527593920314, 56.93540350083382, 59.70449093849429, 57.95010497493129, 51.98117932965679, 54.35639019935362, 48.692020908478774, 49.835768361245435, 62.75590273641772, 62.85717048952657, 55.145163151525686, 54.218334536398615, 60.32704953224429, 61.802688337141475, 58.9302150664791, 54.82388965545162, 53.01754405421596, 52.705205717394435, 56.496984497193374, 58.6159037774609, 58.612491315410985, 60.15787378434212, 52.18233023920367, 52.253607549975, 54.360100761536636, 49.12544673488986, 50.104380115385986, 57.07480453675794, 61.55018183492846, 61.70240902131604, 46.89962325557586, 41.390987750022646, 39.407880536971554, 39.55363581257482, 45.24958410570699, 43.14606405073597, 42.134778961058586, 35.930052188134965, 30.631953823950987, 23.75924741068194, 12.077481785128194, 27.457628673122777, 28.108281243231993, 40.537287804388235, 29.411247507218395, 26.258903318835845, 20.128283846762873, 30.04985055615825, 18.668469844325898, 8.191152801436763, 11.550166183902371, 14.515791823787076, 24.383676975004136, 7.776577886073821, 3.7738569801853554, 1.3741151171345867, 4.055342443527715, 1.4331682386898226, 4.682432845715554, 13.709778093522596, 5.376187851352077, 18.77976905915045, 47.13904473089403, 62.79720921670238, 62.588676406491196, 66.38999831291937, 59.7849936639109, 62.7617980587867, 64.84741641629127, 47.385663755478404, 20.088295282856112, 16.481113049291796, 58.24886798858643, 42.74008697079074, 26.403497572868105, 18.717752464355964, 45.096960759931996, 37.92181607215635, 60.406763861256266, 38.781752586364746, 34.277887113632694, 43.72605316100582, 52.678870924057506, 72.077011446799, 67.5971548018917, 1.772192543552768, 0.2910424714847919, 0.2035645921263964, 0.36148217236322744, 0.180609839998426, 0.12269817412860932, 0.16055754986741852, 0.19308011197755415, 0.12775919610454192, 0.14546468313182556, 0.0888562630561571, 0.16801422071312705, 0.10668797839072444], [0.010092702784365224, 0.06318684389454222, 0.034522541888779214, 0.03349274351832367, 0.06692428427237658, 0.06461586983453843, 0.03003012186156646, 0.15818853021389054, 0.0493117505233855, 0.11622763464167235, 0.14310343160984978, 0.07474732134611377, 0.1030453069195632, 0.11563272906407235, 0.11655624039591321, 0.05076811814139928, 0.1264239508177965, 0.12556080721438895, 6.91611381307725, 63.67431002278482, 52.384171485900886, 44.82293613495366, 37.8312877685793, 31.673243084261497, 41.330394975600704, 47.994996117007354, 33.20985709467242, 15.203132283303047, 47.978930088781546, 74.4550895690918, 86.21316294516288, 58.85460353666737, 10.464652199898998, 40.48120575566446, 64.13643583174675, 67.03691482543945, 59.113938885350386, 67.12166155538252, 55.77604501478134, 44.24273129432432, 27.049762971939582, 6.079708578125124, 1.269617537336965, 1.321620075933395, 3.139888701900359, 5.640249165796465, 10.002442059978362, 14.318021016736186, 24.048535939185854, 31.32725669491676, 33.852251114383826, 40.16989115745791, 46.93038248246717, 51.942571440050685, 52.478845734750074, 50.59453125922911, 48.43017524288547, 50.5914443539035, 52.85360467049384, 47.33575159503568, 37.55918118261522, 29.341195937125917, 24.72356996228618, 21.2404130735705, 32.70377720555952, 42.99770824370846, 46.28299920789657, 50.21257085184897, 53.28079392833095, 54.766854470775975, 54.781739865579915, 56.640323592770486, 57.96299780568769, 52.42520732264365, 47.5437548852736, 40.10418361233127, 38.943060059701246, 42.44551304847964, 39.1151265944204, 41.18408664580315, 43.09292377964143, 44.08268290181314, 45.5276370048523, 45.60867317261235, 43.25811439944852, 46.88183530684441, 55.038411924915934, 59.38564931192706, 54.01452818224507, 55.18993700704267, 59.790339854455766, 56.345835962603175, 56.10783438528738, 50.128432089282626, 49.38754735454437, 47.11405923289638, 49.16323484912996, 47.76256430533625, 49.51782495744767, 42.49354639360982, 37.30298373007005, 36.87678683188654, 41.95555017840478, 41.22407128733974, 40.04506564909413, 47.24750611089891, 52.95810837899485, 55.405989000874186, 40.266157888597064, 28.603962929018085, 28.68349486781705, 30.59285563807334, 34.07946617372575, 40.236171368629705, 34.000818729400635, 32.942053348787375, 19.310983496327555, 27.85213282031398, 11.50777614885761, 5.62838742809911, 20.52403726885396, 21.911320763249552, 23.00908430930107, 12.453704745538774, 9.29207532636581, 15.945337876196831, 7.412296091356586, 2.1674676816309653, 2.5579820429125144, 4.1519224739843805, 3.47383905322321, 1.6954529645942873, 0.8279208418342375, 0.6484611909235678, 3.446249591727411, 0.9272219553109139, 1.0035854770291237, 2.2254579634435716, 4.768127808647772, 23.21336723143055, 41.47425966878092, 50.85223097955027, 52.967153364612216, 54.03068442498484, 51.16734243208363, 55.531857859703806, 48.064163192625976, 24.882592654997303, 13.699632883071901, 32.189295599537516, 70.76499431363999, 66.11856245225476, 12.633157103292405, 26.884807694342832, 30.6591691893916, 34.476578697081536, 39.93487842621342, 22.000282079942767, 33.01693924011723, 33.24065162289527, 43.75880102957449, 54.87238191789197, 13.11437406847554, 0.21951256620307125, 0.16846812780826323, 0.09176026488984786, 0.04367070039734245, 0.13603582617736634, 0.018247360168325327, 0.04113635130887551, 0.018756825874950138, 0.07889391779298745, 0.048678111540333885, 0.07220073017261683, 0.021524163368608684, 0.057334667597446716, 0.012198508991259, 0.1327350597468115, 0.08942217220582309, 0.049430543947364056, 0.017753869310141574, 0.031330862548202276, 0.040692675317968094, 0.10967749095852337, 0.09892265838120254, 0.0720903905288827, 0.056471252032826026, 0.014107967820769597, 0.05813847769111876, 0.01983183109381747, 0.060171311150395104, 0.03178588238604848, 0.11181895951590232, 0.2247809375365896, 8.427683980234209, 73.98504841712214, 59.85369005510884, 48.04461409968715, 44.33337334663638, 37.934383346188454, 36.957579812695904, 35.30887034631545, 36.678307056427, 21.19593535700152, 49.674758988042036, 73.83105616415702, 73.83404501022832, 57.25894804923766, 11.441322372805688, 44.722150833376, 68.3442957170548, 72.48397304165748, 64.63355702738609, 69.47928059485652, 58.99565589043402, 47.82961330106182, 29.46933977065548, 7.384813514447982, 1.6337868090598815, 1.3789415936316214, 3.373902209343449, 6.890540449850022, 11.895079805004983, 15.431657414282522, 27.870201218512754, 34.62408334978166, 37.0053856603561, 43.79670289254958, 49.73001341665945, 56.228208003505586, 58.13353461603965, 53.71860104222452, 51.537892664632494, 52.18344419233261, 53.5634320782077, 49.905151167223536, 40.671636827530406, 35.01362569870488, 27.3882144881833, 22.925720214843754, 33.71368162093624, 46.43645017377792, 48.55825239612211, 51.88699929944931, 57.21402122128395, 58.003872825253396, 57.219022243253654, 60.10532186877344, 60.39968398309524, 58.857784578877116, 52.791207605792636, 46.01057098757836, 47.61643640456661, 51.036084236637244, 47.559577726548724, 50.170064126291585, 52.45080863275836, 51.11690075166764, 51.31036381567679, 49.733684755140736, 46.696942621661776, 51.16183150199152, 57.49348225132112, 61.8068499718943, 58.18789866662795, 57.50714778900147, 63.38390950233706, 62.25734203092514, 61.109327039411, 53.17473303887152, 52.642302666941, 50.865947508042865, 54.726885518720074, 53.96001115922005, 56.078789234161384, 50.088800461061545, 48.55456536816013, 47.374594826852125, 50.21851324266004, 45.94603623113325, 44.74933678104032, 49.75477926192745, 57.47426263747677, 59.24185129903979, 41.681219608553, 31.651579833799797, 30.93715540824398, 33.237435279353974, 34.972130944651944, 40.985791221741714, 37.06621377698837, 36.4629767787072, 26.242221478492986, 30.7552731421686, 10.334668774758617, 13.618553569239955, 22.414286290445638, 23.814358672788067, 26.206439656596032, 13.50000189196679, 13.238390587991285, 20.183149960733232, 8.781331739118023, 2.325231048368639, 3.1686830664834673, 3.8145562285377137, 6.244969310299044, 2.0586420114963286, 2.1671418797585273, 0.7674109887692236, 3.7101446957357473, 0.9449313340648529, 0.363985778343293, 1.018864947461313, 5.619800379199367, 27.286825141599103, 50.50075915551955, 56.74015575839628, 61.06545140666347, 58.27995277220204, 55.81393118827574, 59.18712246802546, 54.79326771151636, 23.59473732209975, 17.560596389155236, 34.59002933194561, 67.25134295801963, 55.670545024256555, 19.49381301479955, 25.20684519121724, 33.19974130199802, 24.79621029669239, 33.78192693956437, 25.320511556440785, 28.175673446347638, 35.941552577480195, 44.75651864082583, 68.64206637105634, 14.110062833755249, 0.24270862070543153, 0.05812944551449149, 0.07505323557603745, 0.04931138280118185, 0.10996508802617751, 0.07763439263667792, 0.08702412548084414, 0.040792343356916984, 0.07922522017672178, 0.05731412878019675, 0.025661773604130553, 0.06888091879626436, 0.018817511529872016, 0.1123193298436461, 0.18135654589822217, 0.2565059561522738, 0.17169021700899448, 0.09613840375095607, 0.15496533784654834, 0.2460079775342057, 0.1792695691748973, 0.1368066178815019, 0.2059909764436945, 0.19422394253553885, 0.2147282245418718, 0.1767426894436921, 0.19128095448738147, 0.23235034588123524, 0.3039800724194896, 0.45867721820550583, 0.2737777914491392, 12.925875744512005, 97.4011355061685, 71.78636381703039, 62.29354942998579, 53.50418467675486, 45.37116581393827, 60.185483347985056, 63.05681520892728, 40.63832413765692, 18.644494356647616, 55.96515817026938, 85.69901866297569, 92.23891981186406, 68.20491821535173, 14.522196073685924, 49.7532848388918, 75.55389450442406, 80.43941051729264, 74.56956786494102, 78.27114782025738, 67.7571875049222, 53.133869786416334, 32.747570468533425, 9.252867314123339, 2.567303800775159, 3.3174546447492417, 4.650155171271294, 8.990144998796525, 16.69330346968866, 19.333113508839762, 33.71670184596893, 41.15819900266586, 39.121931906669374, 47.21568392169091, 52.52615344139838, 59.434274934953265, 60.829720881677446, 58.858376856773134, 58.15990471070813, 60.45024333461639, 60.41227479134837, 55.28095168452109, 45.822724757655976, 40.37035957459481, 31.733084724795436, 26.567380082222726, 38.36596173624839, 48.50423351410897, 53.747669727571555, 57.69326033130769, 62.77320823361797, 62.34957264315698, 62.301484384844386, 64.08801024959934, 65.13782870384955, 62.556571806630785, 57.68006547804802, 53.034065077381754, 55.450880527496345, 61.964533175191576, 55.62766175116263, 59.206899058434274, 58.88027937181535, 54.68313932418824, 55.14870112942111, 53.309219344969726, 49.79933346471479, 52.836887528819425, 58.147423728819824, 61.19782747760896, 57.27887761208319, 58.97810328391291, 60.462889056051935, 59.696085299215014, 58.205616012696304, 52.524557036738244, 54.16712407142886, 51.093342996412716, 57.198143466826416, 56.81579474479922, 61.61296721427672, 55.861607597720244, 57.997738238303896, 54.2923810405116, 58.59076138465636, 50.42078987244637, 46.67183945255895, 52.54109374938473, 59.741294537821126, 62.87748052227882, 44.571386691062685, 33.182914333958784, 33.367724649367794, 35.9778227344636, 38.82678924068328, 48.99660471946963, 40.29892536901659, 42.89309078647245, 28.59595148794113, 34.212987576761556, 17.80584454536438, 11.387141693022944, 26.84783543309858, 28.102179996428955, 32.824641120049264, 18.649462038470855, 16.97690848381289, 25.170304390691943, 11.034734383706125, 3.833004116050659, 5.4034713679744355, 7.280209785507572, 9.67380529449832, 4.061548368584726, 3.2083686272944174, 1.9778914413144513, 5.728761371104948, 2.2360672393152794, 2.98872692931083, 6.317485109452279, 7.196916293713355, 28.56052464054477, 53.25863253685736, 65.1414215949274, 65.95666270102224, 64.6711725573386, 62.11580330325712, 67.98234724229383, 59.564846715619495, 28.807545708071803, 17.923401901798865, 39.17760602889523, 80.54700113111927, 73.44834266170379, 15.593312997971813, 35.82762733582528, 41.11890862064977, 44.89539407914685, 54.952657145838586, 28.671359054503906, 42.84259027050388, 48.27033081362325, 54.50674641516901, 80.63530152843845, 25.681971696115312, 0.3658200686256732, 0.4084061915355344, 0.19741324317311087, 0.26878035477092194, 0.2283632412793175, 0.27748547314155486, 0.24987097589239, 0.09381482843309642, 0.23335626529109096, 0.1820964949025262, 0.2132239955807886, 0.2918035338722891, 0.1793117193324912], [0.026783994736991106, 0.049955072857800036, 0.09754045956557798, 0.06935073753758784, 0.0678889345257513, 0.07861142287090903, 0.0623664096929133, 0.062074560837279406, 0.037040140464781754, 0.14622268116762563, 0.11464260638721528, 0.14987068461073985, 0.12049719586127228, 0.05656886312569823, 0.042873674012239904, 0.10198954582935381, 0.0775117572817591, 0.08823182478907608, 0.13896931473526264, 15.053500725376992, 57.7339078534034, 60.464901231950336, 43.16079647310319, 41.77727845407302, 43.19305404540032, 47.445338695280014, 43.1172267852291, 25.970412992662002, 22.830783167193015, 76.48708128160047, 71.05517125898793, 51.27718448638917, 18.93111175106418, 37.32891059690906, 68.5833877132785, 62.99222946166993, 61.38088057118078, 57.52145659539008, 67.0865249633789, 55.87906214498705, 33.395138094502116, 12.05832394861406, 3.069437050050305, 1.258802091883075, 3.2944251837268954, 6.429894355035598, 10.277266848471857, 14.69398117834522, 21.0295876379936, 28.915069641605502, 30.99928967414364, 34.40439924117058, 38.32083486741589, 45.67285883811213, 47.91835692621047, 50.841060069299516, 48.877905953315, 46.68590899436705, 41.16149379361061, 29.477455154542003, 16.175657491530142, 17.014143543858683, 12.034383762267328, 21.963535354983424, 31.98634236089645, 39.1372722964133, 43.26478635111163, 49.03839757365566, 54.05400291565926, 57.49613377355761, 58.50870147828133, 59.68286298936414, 57.488210585809526, 51.160756772564305, 48.564230088264715, 38.736362918730705, 36.87525318514916, 39.41690983310823, 37.33473923898513, 40.59394251915717, 44.80466181232084, 46.10711620699975, 44.66117758904734, 43.28980322807066, 44.39566058497275, 46.51832965112502, 52.83731898953838, 57.89986725776427, 56.033987922053186, 58.416110007993645, 57.26600439317765, 59.45032527369838, 56.55505910996468, 53.71118776259884, 50.440068321843306, 49.424939309397054, 48.24242314984722, 48.264023642386164, 49.70288238217754, 43.839201773366625, 36.65616135443411, 37.41154316932925, 37.95077493113857, 40.298050680468165, 39.74330594462734, 48.589917690523215, 52.92470155223724, 57.08679914474488, 44.1689593561234, 27.286952618629705, 22.350522279739383, 21.790480382980842, 25.774365086709302, 32.17422781452056, 29.37343978112744, 34.65044167733962, 25.49097384175947, 20.68675679545249, 26.18638457790498, 6.400392247784523, 8.485055508152131, 24.146089207741525, 23.972577279613866, 12.783020081058627, 1.0868931874152155, 3.0268298137572507, 2.168253871702379, 1.3024443436053492, 1.207009154942728, 2.5823713406439754, 3.3219457585965437, 2.445400458189749, 1.6491591906355274, 0.2835730529360233, 0.6441902813892211, 0.14661140950216403, 0.18033983997039257, 1.3579977303743365, 6.399029224149643, 21.195513702207997, 45.120863683762096, 51.686813292964814, 53.25615359890846, 53.25146636655254, 56.35468875208209, 51.91975501275832, 46.90741700510825, 25.308526754379276, 19.580754310854022, 62.478712758710316, 62.341794583105276, 31.02628342566952, 11.328594434645868, 31.696961656693492, 29.686615543980754, 44.53332401091053, 28.457527122189923, 27.161011195951893, 46.034364085043634, 30.520289828700406, 53.14653119733257, 43.345563642440304, 2.617160067442925, 0.12214184107799685, 0.09400124826859083, 0.050101207959796154, 0.05535735253004297, 0.060773969537788824, 0.05934505085010202, 0.06082661509994538, 0.022699842116825526, 0.1463263022202638, 0.009882948868307135, 0.018112944296350884, 0.006880562192940664, 0.05835703874547636, 0.021631892567740816, 0.049570990846522396, 0.06355556967337767, 0.02925759113784279, 0.06245457875211874, 0.03448697242645487, 0.035271009790801236, 0.055409729961426034, 0.06619892924303009, 0.03190716176534132, 0.03982807997794401, 0.0660774966461524, 0.0419489216179617, 0.023605448058656147, 0.09401299239647004, 0.05559619193175628, 0.12768544482007144, 0.05619055741736966, 0.7800510105106139, 21.807132805547408, 71.22532367706299, 66.34011360906786, 39.605160067158366, 43.21950258747224, 41.14889121824696, 33.80650058869393, 39.775759635433076, 31.293520389064668, 31.70942694910111, 76.63495463709678, 70.4780964697561, 54.75009810539984, 23.796025514602665, 41.9819006612224, 77.55129875675325, 69.93647206214168, 67.22129760249969, 63.66592007298624, 68.76947279899352, 59.06041422197896, 34.50361167230914, 14.175437958009782, 4.800520702715843, 1.5828656188903318, 4.2951478208265, 7.201554496442118, 12.59790970433143, 15.021150977380815, 25.872606731230213, 35.14656266858501, 34.18826879993562, 35.983396422478464, 40.881746430550855, 47.31718309463994, 50.03961001673053, 50.69833678583945, 52.54288627255348, 50.635951488248764, 44.85267162322999, 33.34917576082292, 24.759724409349506, 22.55156336292144, 15.00436225245076, 25.119242975788733, 35.934774721822436, 43.39188291180519, 44.742998230841856, 50.612432956695564, 57.77710491611112, 58.39204234461631, 59.46450856424148, 62.235184561821725, 60.453424376826135, 56.77780266731017, 52.282962568344615, 46.589583427675315, 46.45609732597105, 48.97835000868767, 47.83276296431019, 51.083544915722264, 53.082753458330714, 52.82574799753005, 52.07679886971751, 49.11491909334737, 48.07511052777691, 51.05523324781849, 56.988720278586115, 63.96956643750591, 59.491345420960464, 56.94098503358903, 60.793976322297134, 63.37127162564186, 61.232108992915, 55.79255427083662, 53.951609442310954, 52.31178806674097, 53.027306833574855, 53.12758614940029, 56.01845533617082, 52.24498225796608, 46.538400419296764, 48.22997746929046, 46.6588681743991, 45.96377318905246, 43.75050129428987, 49.418891014591345, 58.06290449634675, 60.22965315849551, 45.6454610824585, 27.75537971527346, 24.633492731278945, 23.627236120162472, 28.04093218618824, 30.657376666222852, 30.312235547650246, 38.31828140443371, 29.9653293625001, 27.051630020141605, 22.67662617468065, 6.570430917124595, 16.923452461919478, 23.104074308949134, 25.642077269092685, 11.683176698223239, 1.9839978362283401, 5.3650189022864065, 4.118938282612832, 2.612698861668187, 1.1060132711164414, 3.8207932874079678, 5.307373789048964, 4.018833021963797, 2.1537072716220735, 1.164766576501631, 0.7010596846380542, 0.4447447448488205, 0.16355381166983038, 1.012536325762349, 6.891658325349131, 24.425642413477746, 51.13839141784176, 57.223034827939934, 59.723945894548976, 58.770570678095666, 61.102333453393754, 59.04322639588387, 49.52169633680775, 25.69831817380844, 23.24736241371401, 58.04894870327365, 64.03263422750658, 34.50061890386766, 17.251344957659324, 30.317020839260472, 31.86463905918983, 32.42683433717297, 33.614143633073375, 22.693347238725234, 41.98586617746661, 32.848371459591775, 60.381970559397054, 51.20554631756198, 2.443588078022003, 0.10197194878973308, 0.017347193450757095, 0.05157672394547732, 0.1351667147490286, 0.15750156385042977, 0.11140362494775366, 0.08184120359440004, 0.028345954168828267, 0.0985504775458286, 0.006842244868992918, 0.03926526965393175, 0.06701430726435877, 0.012540345083952192, 0.141490173015383, 0.13685613780492736, 0.14091454987083712, 0.1881396875626618, 0.16212879620011778, 0.16233842849971789, 0.17015535985269856, 0.13195702085091224, 0.1637172948328718, 0.17746077429863716, 0.18348660740640857, 0.23504398763179782, 0.3223684195789599, 0.12433790872173926, 0.2569697457816332, 0.12784150459112661, 0.3034049242494568, 0.19844104205408405, 1.1382953582271453, 43.195215271365264, 83.12097026455788, 78.24499345594838, 60.74423674614199, 55.000863075256355, 61.191700735399806, 63.47899560005435, 54.44594967749811, 33.11861884209418, 31.62667278320559, 85.73534765551167, 79.18964139876827, 59.567258973275464, 24.263107238277314, 48.35232796207551, 82.45091176802113, 76.72902091856926, 73.38989934613629, 73.14890892274919, 77.57266782945203, 66.45455268121535, 40.4453396028088, 17.06354187380883, 6.148314264512831, 3.69447972986006, 4.8932582812924545, 9.02161221350393, 15.697240118057499, 18.124517510014197, 28.43738575135508, 39.05751089895926, 37.10477067578224, 39.78467126046458, 42.692104616472804, 50.518515725289625, 53.51735207342333, 56.92836284637452, 59.30438564669702, 56.00472311819754, 54.068649045882694, 40.70553787292973, 29.10122729116871, 28.69253004750898, 17.058844835527484, 26.73123121261597, 39.066218560741795, 47.39292798503753, 49.568388231339, 56.296433710282855, 61.36778769954559, 62.3247754189276, 63.39402137264129, 65.35583796039705, 64.2886983194659, 58.237595096711196, 56.90139262906967, 47.20466598387688, 51.20982170104981, 58.98424571560275, 56.014552577849365, 59.17464933087749, 58.93395700762349, 59.4040491504054, 55.64528496034684, 51.43483631072506, 49.185733564438365, 52.684864305680804, 55.155930057648696, 61.309528735376176, 61.492997600186264, 55.39089964282129, 58.64947142139558, 62.83919034465667, 59.342746426982266, 56.21709200643725, 54.188226422955914, 55.425153701536125, 54.59866716015724, 56.34693422625142, 62.71842056705106, 60.712853862393295, 53.26926216002434, 57.13367539067423, 54.49774065325337, 51.56760069631761, 47.88662887388661, 51.81058760612242, 62.987926621590894, 65.45375208700857, 50.36491570934173, 29.329972074877833, 27.14325462618182, 26.57813326005013, 30.738716817671257, 36.181123102864916, 36.37946167299825, 44.50347085152903, 34.89439349020682, 28.276317542599095, 31.47735207311569, 12.238877511793568, 15.102286184987715, 31.62432328347237, 27.5777022300228, 19.52553322238307, 4.84122411858651, 12.034316101381856, 4.016565401707926, 3.493596522077438, 2.1297523763871964, 5.210544197790084, 7.692988255331594, 5.481125962349677, 3.5304444932168533, 2.469736803923884, 0.9690227768113537, 1.4233674613698837, 0.45152453104815177, 2.4385507741282066, 9.598245736091368, 26.638914308240338, 53.38796092617897, 62.67490186998921, 66.34551079042497, 64.45753674353323, 65.16757203686622, 64.00791937305083, 57.4501439832872, 32.8107088611972, 24.966056769894017, 71.85541322154384, 70.3399819712485, 38.128528902607584, 15.008389546025185, 45.28064927747173, 39.721544634911325, 55.68698367764873, 42.104149172382975, 34.3182247684848, 58.00352373430806, 44.86066149127099, 67.31972555960378, 71.10347132528983, 4.9946726329865, 0.46886085562648316, 0.25334846348531787, 0.10474802926182748, 0.16490923571250132, 0.2968718183617438, 0.1920927472172245, 0.22767101955269614, 0.13146620363958422, 0.18383160744222904, 0.2044548016161688, 0.07907559554423056, 0.1615692762237403, 0.14722237994353618], [0.0325941989919351, 0.027260497595453938, 0.10404005676748292, 0.07743596054253078, 0.04954426203884425, 0.07725641251571717, 0.09679101107101287, 0.153571977129867, 0.07666847833822812, 0.10168167807522321, 0.04733838463923143, 0.11239452903429348, 0.10635714332062392, 0.025869521327436935, 0.0528694398611063, 0.07186714484686814, 0.03740999622330551, 0.043850918751089804, 0.09636629192579178, 3.4170524487572336, 50.71429298770044, 65.88286722860029, 67.14554878973192, 55.263136279198434, 46.27724901322396, 44.131516410458474, 44.960681930665054, 31.09580351460365, 13.98675822442578, 55.156361518367646, 78.7149404710339, 63.628720314271995, 21.429979262813447, 23.478252733907393, 49.311331779726096, 53.196819905311834, 57.13603665751796, 53.03813649762062, 54.99244174649639, 58.094295224835804, 38.5729608997222, 20.664907232407604, 6.723874528561869, 0.5170114734961141, 3.932576179504395, 8.864403616997505, 16.65533296523556, 11.300701479757986, 16.941101166509814, 18.151393590434907, 18.28688794566739, 21.320005809107137, 28.57788112855727, 31.592412840935495, 37.13944442810551, 34.6113395690918, 26.997795489526567, 21.178147408270068, 11.238710380369618, 4.296072519594624, 10.503053184478514, 11.152968348995334, 10.411456035029504, 24.942355848127796, 29.650531699580533, 35.973037442853375, 43.1962154757592, 46.234075484737275, 53.891632480006066, 56.83772863880281, 57.84927652728174, 59.133174188675426, 57.125673755522705, 55.851852663101695, 48.240505110832956, 38.812809913389145, 34.47365653130316, 39.00486092413626, 39.6202729594323, 41.42365324881769, 45.33187935429235, 45.60411930084229, 46.65777383312103, 42.66219262153872, 43.01832814370432, 46.42162361452657, 55.35212701366794, 61.31124673351165, 56.122825684085974, 55.58269962187737, 59.861742681072606, 61.090864443009906, 57.060550643551736, 51.66448323957382, 48.738787328043294, 48.30319243092691, 47.62076277886668, 48.30127046954248, 48.517965732082246, 44.73760497185492, 36.16847738142937, 36.79912782484485, 37.376124166673236, 39.183262086683705, 40.173633098602295, 46.79815153921805, 53.92701225896036, 56.99377621373823, 42.58393349186067, 23.278782559979348, 14.317856277188948, 16.096386390347636, 17.130728152490434, 23.386888965483635, 20.106418594237297, 27.239758660716397, 33.66084729471515, 26.816782028444354, 21.408894561952163, 20.942181541073708, 6.648139444089706, 17.109382614012688, 20.64195352215921, 15.521542449151317, 2.80232094468609, 1.8068779404124908, 3.0742806869168438, 3.30208434693275, 3.895782876399256, 2.6278294046078963, 1.7613862911539695, 0.5388470018102277, 0.2108462884901993, 0.47051477816797077, 1.221350933755598, 0.13833251180908374, 0.28700436074887553, 1.0490461150484702, 8.254793747778862, 20.71040084285121, 42.55120131277269, 48.211609009773504, 54.30763121574156, 54.914112014155236, 52.86413623440651, 53.1303043519297, 57.282031197701734, 32.33127755503501, 60.08043050765992, 63.192356632601836, 42.897197508042865, 14.097966244143826, 18.795089837043516, 35.27070568453881, 29.467908105542584, 37.14451213036814, 19.12360206727059, 49.58154778326712, 39.293476766155614, 32.5533543094512, 61.99004427079232, 14.146020181717413, 0.3589687604577311, 0.10586183683405961, 0.0506701699698404, 0.10322146117687227, 0.14515291599016036, 0.07812317971500658, 0.04418284549648243, 0.053733334230679664, 0.060125388009774114, 0.02255342356229742, 0.05982071484228777, 0.08397695713586385, 0.014022474323639707, 0.0067830353697401384, 0.061753033735458894, 0.020468827457197254, 0.027697048968665545, 0.025389107590120648, 0.021712956161448554, 0.06475265483341872, 0.09109741497424342, 0.029825314000669508, 0.08576383423661033, 0.017025061139476397, 0.055166945206902684, 0.06849238964458627, 0.12947322590456856, 0.07752026085771861, 0.038283796109739816, 0.04537208591617885, 0.02152644439540323, 0.06869353368998536, 0.0949714909638128, 2.8292384551417444, 68.41232530532345, 70.2284925214706, 72.62667671326669, 54.05612491792249, 45.97200624404415, 34.8520318923458, 38.48833184088431, 33.41006663537795, 23.01685452461243, 60.49988092914705, 82.15205853985202, 69.6088521711288, 28.138687456807784, 25.307259828813617, 55.15338051703669, 62.82254380564537, 62.66898301339919, 60.53460567228256, 62.514586756306315, 62.05621073322912, 42.3018366290677, 24.389805678398382, 7.627816113733477, 0.3081200115623013, 4.984632836234185, 11.665768238805956, 19.61553200598686, 12.66495575827937, 17.224070756666123, 19.51327777677967, 22.173313517724317, 21.56711316877796, 29.840529349542436, 34.62119648533483, 41.1420702165173, 37.36180751554428, 32.47996480234208, 25.512011474178685, 16.428583687351598, 9.869173649818668, 11.094234778035073, 12.69843024592246, 14.124093151861622, 25.969075464433242, 32.92332795358474, 40.63770048079952, 45.5322418674346, 50.26786450416812, 56.58244117613762, 59.289763050694624, 59.23131189038677, 62.16271877288819, 59.76972387683008, 58.63975571047876, 52.13481856930641, 47.43756847996866, 45.29127105589836, 50.9779860896449, 51.253779703570956, 50.231339393123505, 52.11246498169438, 53.37061228290681, 51.693442098556034, 50.9357500076294, 46.511822439009144, 49.08910989761353, 58.58938855509604, 63.58258539630521, 59.50114350165091, 57.43694520765736, 61.419688501665675, 61.30128391327397, 60.972506923060266, 56.536631814895145, 52.54398061383156, 51.90274761569116, 53.30721893618184, 54.77393827130718, 54.983553655685924, 52.81386321590793, 47.67561712572652, 46.04641752858316, 46.95753705117011, 45.48203945159913, 44.862450092069565, 49.96708146987423, 55.989665139106016, 61.015990318790564, 47.530897355848744, 24.07976192812766, 16.803265156284457, 18.63230166896697, 19.606991044936642, 26.666251267156294, 20.268712543672134, 30.17429167224515, 37.107849736367505, 31.32158494764759, 26.809333447487127, 15.356356732306944, 10.843329583444904, 21.462058367267733, 18.442529555289976, 17.850218319123794, 3.3091737858710752, 3.6310841768018665, 3.974383252282297, 4.91314273688101, 4.5369992044664205, 4.376124172441421, 3.0229138174364647, 1.842333837862938, 0.9679751975401756, 0.6870911438618937, 2.0450342062019535, 0.7585940522051627, 0.11743741004817909, 1.8814934333485944, 10.467525336050219, 25.184275873245735, 46.1239549421495, 55.50601336263842, 59.068211893881525, 61.483956536939075, 56.124998677161436, 58.8767296268094, 58.170208777150805, 36.70009582273422, 57.65769227858513, 64.00724472538118, 43.45466829115345, 21.70890881169227, 21.71594358259632, 39.03964842519453, 25.81136480454476, 33.006093886590776, 23.29822182655335, 37.946362264694706, 40.815744707661295, 33.96614889944754, 74.69808040126678, 17.578678515649614, 0.4792441968475619, 0.012724476231772815, 0.0883675066213454, 0.020211347221066395, 0.09753936405984626, 0.06381817312250215, 0.09661144772244078, 0.07108017336577177, 0.041921940001268546, 0.032362039876921524, 0.01618049708345244, 0.056256908292491595, 0.04610903568625931, 0.007668023970308564, 0.19419391188890706, 0.1202631023742499, 0.22361000278784385, 0.13561907434655776, 0.21200769310516698, 0.3807157902948318, 0.2313805398561301, 0.23101965115676004, 0.1587332800150879, 0.15960450584609664, 0.2198124436601516, 0.16405467995472495, 0.22531289366945145, 0.1877994066284549, 0.14831194083296484, 0.2315597431433778, 0.15678255968997556, 0.2103235100906703, 0.4903067822658247, 10.88852999671813, 90.54564829795592, 79.96988711818572, 86.40123275018509, 70.66311467078425, 63.77068265791863, 60.525697969621234, 56.30884801187823, 36.83639426385203, 18.370055921616093, 66.12381842828566, 88.14070193998276, 74.12732062801238, 28.79885961932521, 29.88994925252853, 62.95453548431397, 66.31849350467806, 67.05169431624874, 66.5401231088946, 68.78982990018784, 71.59863918058335, 46.33320554610222, 26.23599667702952, 9.718271243956782, 1.1789008374175718, 6.516969011675927, 13.971113850993495, 24.37946827180924, 16.333185761205613, 20.690586989925755, 22.937030369235625, 26.26625580172385, 24.79818913244432, 32.53980055932076, 38.06384117372575, 44.31479700150029, 41.03892757046608, 35.30620313459827, 30.416815742369625, 21.908577065314017, 12.0620443167225, 19.012081238531298, 16.081442159991113, 16.52591043902982, 30.833151801939938, 36.61529810197892, 45.88127005484797, 48.59406755816553, 54.03303784708823, 58.277658185651234, 61.20705681462442, 62.03940337704074, 65.0237387226474, 61.409921799936605, 62.552151295446585, 57.51896981270083, 48.2799719995068, 50.851866199124245, 57.26567099171301, 61.1831146670926, 59.74313805180212, 57.818638893865774, 55.85308820970597, 55.662076627054525, 52.098548412323005, 48.44078133183141, 48.90543314718431, 60.00941991806031, 63.06990023582213, 59.54105361815422, 55.28842772206953, 60.43800553967876, 60.613786558951105, 59.50490505464616, 55.00415394383093, 50.84846550418485, 54.3305221680672, 55.69335360680857, 58.30302807592577, 63.2849520252597, 61.21590960410334, 59.26904901381462, 55.417042240019775, 54.123005251730646, 51.0462353306432, 47.84626768481347, 51.674936356083045, 57.83036285831083, 66.79068411550215, 50.65868946813768, 27.13021862891413, 18.183547219922467, 20.87460106418979, 22.452152852089178, 30.58336154107125, 25.4881497352354, 37.83599461278608, 42.1688525907455, 36.921866632276966, 29.283289986272013, 25.415880064810477, 11.929191677801072, 23.780155604885472, 26.68924027873624, 24.57409824094465, 7.290619265648627, 7.446191743496926, 7.114986806146561, 5.303145964299479, 6.169033204355548, 6.076480957769579, 5.7682032546689435, 2.279635456300551, 1.4273627631125914, 1.671864688396454, 3.980063089439946, 1.241501375071464, 0.6897624005233088, 3.5057102720583644, 12.377493093090674, 28.895369537415046, 53.714992461665986, 62.2935337405051, 67.01027408722909, 66.91328171760806, 62.93596698391823, 61.47104801670198, 66.39510523888373, 42.23287743906821, 67.0079912677888, 68.60910277212821, 50.20980558087749, 18.739482395110592, 26.672825159565097, 51.949863126201016, 36.33211082027805, 49.12576052450365, 28.686020874208022, 58.059943106866655, 53.071649228372884, 43.32756388571955, 84.68061447143555, 29.37905073165894, 0.7005831779491517, 0.1834847687953903, 0.16129901572581262, 0.2095388981603807, 0.33278948296943023, 0.20404241648652863, 0.15458693637722923, 0.1844835789093087, 0.15899512886760697, 0.13096979398640896, 0.09508301804382956, 0.2098643016670981, 0.09688386858831491, 0.09859655007359483], [0.008198875021339666, 0.07310714242198775, 0.06560999149036023, 0.06440986879169941, 0.05281169598381366, 0.028516280412253354, 0.14321160322475818, 0.019313616663097374, 0.1220985034841203, 0.05526897662709798, 0.22969896154057598, 0.11227086712155612, 0.21766174374328506, 0.02351519907073629, 0.02692382876581002, 0.0371369548262127, 0.05381986003128752, 0.03131451997755757, 0.17363974223694495, 1.662273757880734, 47.8222627793589, 64.95068850055819, 68.88781855183264, 51.589699329868445, 52.68917891287035, 46.23894706849129, 45.90535733007616, 41.17993285579067, 13.22581252744121, 32.303991586931296, 64.05400330020537, 58.48725395817911, 54.66367652339321, 20.024382222083307, 41.675740057422274, 57.42340126345235, 59.21753260397143, 56.811205571697606, 45.5304846455974, 55.05059088430097, 37.28458389159172, 22.878216389686834, 4.6048890582976805, 2.112437563557779, 5.698595892998481, 7.97939335146258, 8.638266228860425, 8.412000383100203, 10.750955804701775, 11.357114968761323, 10.2796055616871, 10.712188078511147, 11.074224806601002, 13.831734388105332, 10.518461235107916, 10.463313691077694, 7.36193334864032, 8.280352892414216, 2.3818359980660104, 7.95772421744562, 12.577921305933307, 6.489885045636085, 13.913969820545567, 28.917509355852683, 26.9790602883985, 37.50325210632817, 39.191138205989716, 42.86973699446648, 47.46632729807208, 55.335515775988185, 57.69169530560894, 62.54568722940261, 60.79386257356214, 58.381114621316236, 53.074818503472116, 41.53292655944824, 34.128233002078154, 37.40094884749382, 40.80403643269693, 41.05358546780002, 45.54387169499552, 49.52028428354571, 45.05707417764972, 45.980666837384625, 43.026129737977065, 48.55002718587076, 57.491579901787546, 59.77289315192931, 60.39982126605127, 54.08813930326893, 61.25633355109923, 59.648000963272594, 59.193653214362364, 52.4811520884114, 48.3214706759299, 47.42354208423246, 48.627517530995036, 48.59073746588923, 47.96298173166091, 43.06799711719636, 34.37959024983068, 35.77023129309378, 38.803643334296446, 37.8804664457998, 40.2937243061681, 49.24518100676998, 55.53499967821183, 58.36486816406251, 40.20216441923573, 15.656713208844586, 6.05429309029733, 7.858780468663863, 9.41626835253931, 15.921818364051083, 14.371570194921187, 22.3178332467233, 31.66859115323713, 34.80132741312827, 23.56360743122716, 20.10008200522392, 16.051987121182105, 7.890586478094901, 14.14543672915428, 14.714225511397085, 4.06164373120954, 2.2947804629802704, 2.5317448185336207, 3.7002338469028477, 3.7364159957055127, 4.499319445702338, 1.347703224708957, 0.401382728089248, 0.7922616552922034, 0.4464386878234725, 0.6803494475541577, 0.7568724994217196, 0.24634022986696613, 1.6408739190909172, 11.59703850746155, 29.31790098067253, 50.24526380723523, 47.43764300500193, 51.5613405935226, 53.490538750925374, 56.029818442560014, 57.218131865224535, 56.423671476302616, 61.68382090906943, 60.97463677006384, 50.49725647895567, 27.7015059609567, 7.356172857746002, 29.77215067032845, 23.86738911751778, 43.17051610639019, 27.78982989249691, 31.24794637003253, 65.77846550172376, 29.602929815169308, 43.959634227137414, 57.91752184590986, 5.425942136395363, 0.2624419271465271, 0.1825354479613804, 0.10383564152664716, 0.0757458863118964, 0.07956124166206968, 0.07428622834624783, 0.0619853767115743, 0.045438865800538374, 0.002653950495803128, 0.020508202461285457, 0.12019125864871087, 0.02686560416834489, 0.07092445067340328, 0.012680812092918544, 0.024078622265087984, 0.08062007476485546, 0.033648470041131785, 0.04938167902911383, 0.008494516012198743, 0.08633585676791207, 0.0891831910778438, 0.04539557034149767, 0.10084516368806364, 0.08287831810453246, 0.10931692401608152, 0.04996766351283558, 0.03669963353463719, 0.06479717220269865, 0.05065577900818279, 0.007647779139299547, 0.032808699780294014, 0.04003633331928042, 0.12507108550879265, 1.5438196495656045, 63.252490489713615, 70.12834656623103, 79.2604794040803, 53.31791523964175, 55.76525065206713, 38.252522868494836, 34.44121460760794, 40.501025492145175, 20.64284586137341, 43.52750278288319, 70.06168980752268, 63.03277500214116, 54.740198043084916, 26.790731606944917, 43.50345080898654, 64.84788710071196, 64.21738178499284, 61.95302101873583, 49.23166451915618, 62.19743959365353, 41.1103186299724, 25.118691882779522, 5.075630843639374, 2.8933814648659, 7.3944483264800045, 9.106434449072808, 10.733217866190019, 9.086679431699938, 12.515084935772805, 12.405557651673595, 12.61163309697182, 11.665131834245498, 11.815449806951708, 17.309492134278823, 12.908659481233167, 14.232225052772032, 10.468682435251052, 10.076839616221767, 3.6438958635253296, 7.961049897055473, 13.377425862896828, 9.218057259436577, 17.008960131675966, 30.607488040001165, 30.64539186416134, 41.02941190042804, 41.998911980659734, 44.80338704201483, 52.793525726564475, 56.69834721472956, 59.532993147450114, 67.77415567828764, 64.36889902237924, 65.40041961977559, 56.18507369872063, 48.31897212613014, 42.51533123754686, 47.49220709646902, 49.59260886715305, 50.18556925558275, 53.43388795852662, 55.013073413602775, 49.86517437042729, 51.289328144442656, 48.454980311855195, 53.221472001844845, 60.50989474019697, 62.37648402490924, 61.62010592799033, 56.526594469624186, 62.54553817933606, 60.84753628700011, 58.992478770594445, 55.793256375097464, 51.378954302880075, 52.79119976105229, 54.91546915423486, 54.700244780509706, 56.41326542823546, 52.602698495311124, 45.768741176974395, 45.32200674856863, 47.64975693918044, 45.079898449682425, 43.81831907456921, 51.71853350054834, 56.168540908444314, 58.413117239552165, 45.175208122499534, 18.153090015534435, 7.7483289760928, 12.190604902082875, 13.496731615835621, 18.665930109639323, 16.135337487343822, 23.49400301133433, 36.941760893790956, 40.744149684906006, 28.703614665615945, 21.985280975218743, 12.395163370716958, 14.984746479219007, 17.353226561700147, 17.892032746345766, 6.483380775297842, 5.184274123560998, 6.864038955780768, 8.342311632248665, 7.250405165456957, 7.50673843006934, 2.196019594707797, 1.044666053306672, 0.35598824942304247, 0.44541868771756854, 0.5084473765905827, 1.447532816279319, 0.471616504533637, 2.416674489936521, 13.298951983451845, 37.082409243429865, 54.964173224664506, 53.02116047951483, 56.226850863425966, 59.921766711819565, 60.3634883511451, 60.926136662883145, 61.688414004541215, 65.3575167348308, 62.00014437398603, 54.96721306154805, 30.900216487146196, 13.481414760312727, 29.641280789529127, 29.259400790737523, 28.082848595034694, 29.921989133281095, 27.927301122296242, 60.51316991929085, 35.1247307562059, 47.021401082315755, 70.6980472995389, 5.836136744868371, 0.35038921921964616, 0.033406409239696885, 0.02278974061952003, 0.022942443010247043, 0.13100880318351332, 0.0635146797304192, 0.08461172226816417, 0.050731200364328204, 0.06915641167471487, 0.01587547343074074, 0.03320746003620086, 0.024133887847945578, 0.0763554854558841, 0.011036882210793275, 0.14586363107927386, 0.24017086252570155, 0.14864384076528012, 0.1920745449681436, 0.09921120539788278, 0.20069694116471276, 0.25746336687476407, 0.12231482373129939, 0.37770095852113544, 0.17971425257142515, 0.25713621668757936, 0.16231374514679756, 0.2858366282476533, 0.35689750385861246, 0.11527072187633285, 0.19049864082086473, 0.1691114731253155, 0.23007955402135852, 0.2881534007047453, 5.606553064238641, 86.42558282421481, 78.66851529767438, 90.60928483163157, 66.52651248439666, 72.93149978883805, 62.93202892426522, 61.17805873194049, 50.886645855442175, 16.222629835528714, 40.67223695016677, 75.18335603898572, 67.70804805140342, 64.82115614798762, 28.273326735342707, 51.345469028719016, 70.99366064994567, 72.54615045362904, 69.34555915094191, 56.610744999301055, 67.08157493222144, 46.55709051316785, 27.408324480056766, 7.533786604481359, 3.926172665049953, 9.914364257166463, 11.40225850766705, 14.121625000430694, 13.113315028529014, 17.06459306901501, 14.082442483594342, 16.002953571657983, 13.655619967368342, 14.90579014824283, 19.640211559111073, 15.061159153138439, 16.963003681552028, 13.276557210953007, 14.645367322429536, 6.451655174455335, 12.711435844821315, 18.33328958480589, 14.208006378143066, 22.522667261861987, 36.97402631082843, 36.89319410631734, 47.564464999783425, 45.81250306098692, 47.81787756950625, 54.54712721609301, 60.519959542059134, 60.56483930157077, 69.64886034688642, 65.68285380640339, 67.4843474357359, 59.93789549796813, 52.66073780675089, 48.321231411349395, 50.87966011416528, 59.276517206622714, 58.37249325167749, 59.229966517417665, 59.885700518085116, 52.13836439194218, 53.46771447889267, 50.40119763343565, 55.42866422284035, 59.77521911744149, 63.135792132346864, 61.64425988351146, 54.99532468857304, 62.518383610633116, 63.48880937022548, 58.51371034499138, 55.3532801904986, 51.41694245799896, 52.28956391734462, 55.988613943899836, 56.96656673185287, 62.07915659873717, 59.154139257246456, 55.61310975782333, 55.26460324564288, 55.79595888814619, 48.23331148393693, 46.822042695937625, 55.32301125987884, 57.46379383148686, 63.345305535101126, 49.87148938640472, 19.027966837729178, 8.179742136309224, 13.104669144076686, 14.188722045190874, 21.795173498892016, 21.744957354760942, 30.810688387963083, 44.39706871586461, 44.99160589710359, 32.198687714915124, 26.848576761061146, 21.99256873899891, 16.003916513535284, 18.667081325284897, 20.996612271954938, 9.269977673407524, 5.313845209537014, 8.327835144535188, 8.721097861566852, 6.805469634071474, 7.426065571846501, 2.7986969197950056, 3.071668878678353, 2.3524679868452014, 0.8209523835009145, 2.8560755570088667, 2.199421025091602, 1.1669718065569479, 2.925345104548239, 16.733190051970944, 40.12491726106213, 64.97670950428133, 58.655076488371826, 63.15612569932015, 63.677283179375436, 67.20110524085261, 65.30762026386877, 67.83882771768879, 71.35300467091223, 70.75518054346885, 58.323545994297156, 33.81486700427148, 10.203255645690426, 43.18226752742645, 34.293431466625584, 51.77570989055019, 37.682327916545255, 42.1096993261768, 77.38957943454866, 44.394778051683986, 58.196186634802054, 87.37103093054988, 12.113456783756135, 0.658109424816024, 0.35973763694205596, 0.3021917780560832, 0.278633103495644, 0.25187994954326465, 0.29547634324239147, 0.18885479999646065, 0.0857853766290411, 0.13990861513922292, 0.1013931540411807, 0.19663586311282652, 0.15903222284490065, 0.12196194065073807, 0.17051604936920828], [0.024937199984466838, 0.08681013414095487, 0.12120018878410901, 0.06065077493868529, 0.10034544453505548, 0.025730600858467723, 0.046358500727482384, 0.0986263815373663, 0.07391946375249855, 0.08169798345695581, 0.18413528469541382, 0.05557866384004874, 0.06602480511872039, 0.06052509821470707, 0.025747257525161393, 0.06294280275582306, 0.02097216829086744, 0.09136967496165345, 0.110752189742221, 0.24593869254233378, 24.87462239880716, 69.83416095856698, 40.86395063707906, 43.0899388559403, 49.677794902555405, 48.093937904604026, 48.10111584201936, 48.252825275544204, 29.34944272041321, 16.104086002995892, 35.18739454207882, 54.27519321441651, 81.6588754038657, 40.142818958528586, 46.99600373545001, 68.54007690183579, 60.28986154064056, 64.72177897730182, 62.12026696051321, 48.65828460262668, 39.55835442389212, 20.7558120835212, 4.535839163487958, 1.0295888300864928, 5.087748515990473, 7.594436253270796, 10.271391137953728, 8.836433195298719, 8.534128281377978, 6.506609051458298, 2.6498630739027456, 2.245639293424545, 6.390925607373638, 4.068266653245495, 3.7689221482123103, 6.080844594586281, 5.012741521481545, 3.6351149024501925, 1.5370525804258164, 10.383247329342751, 8.494784947364561, 10.472000760416831, 23.150693639632195, 30.126872178046938, 27.934114279285556, 35.68545710655951, 36.99778802933232, 35.25895034113238, 43.509648153858805, 49.87972636376658, 50.6011914437817, 61.40768604893839, 62.26546525955201, 59.6155394277265, 55.10535109427668, 46.09504315160936, 36.44145081120153, 34.540525098000806, 42.61823461901757, 41.913996588799264, 44.78155120726555, 48.5656774428583, 47.79634375726023, 47.21191844632549, 46.08714349808232, 50.204718266764, 57.02877160041564, 59.364978421118956, 59.87208989358718, 54.92971520270071, 59.686777514796105, 59.22236888639389, 58.797419301925174, 53.794753859120036, 50.715018626182314, 48.320254741176484, 47.9701518243359, 48.79954484201247, 45.902486155110026, 42.16727187556606, 33.5637725553205, 37.45841549288842, 40.77664652178365, 35.839931811055834, 41.961418044182565, 51.3628843522841, 56.292083801761756, 55.47717609713155, 30.107683943163966, 10.335738601223117, 5.887099119924731, 10.382497176047295, 11.945678380227859, 16.105481386184692, 13.038171241360327, 17.317162329150786, 30.550521496803533, 33.56140736610659, 38.91923950564477, 21.3529949034414, 22.573840464315108, 23.316170592461866, 5.00508701609027, 9.060550562797054, 5.052023568461019, 4.155449175065564, 4.4943792204703055, 2.0460241143741915, 1.9927327094539522, 4.717519427499464, 1.8796940460320444, 0.6941873243739528, 0.3464055926569047, 0.2685350840610843, 0.4519264514167463, 0.8514976573567238, 0.39534555688019724, 1.1766214500511847, 8.764232166351812, 29.838917255401615, 47.92381686549033, 48.90783363772977, 51.182416100655836, 45.23477715830649, 50.28289110429826, 58.259850625068914, 57.61201627792851, 54.608198519675966, 49.27210023326259, 51.67217108511156, 20.336355778478808, 13.791869378858998, 31.701746948303718, 30.590943482614335, 45.476049992346, 22.933888550727602, 55.12455109627017, 48.99035638378513, 28.43255339130279, 59.53046321868897, 35.73484759176932, 0.036297215208891905, 0.05820379051710329, 0.1280751690689114, 0.0726778497318587, 0.1404242842428146, 0.026932610048642083, 0.03872477164071414, 0.033754734097108725, 0.10234084310791186, 0.06746309689216076, 0.041818200205002105, 0.012832751268550996, 0.006516647446269711, 0.057037931100855914, 0.06414983556756089, 0.047978983531075145, 0.05183506028486356, 0.07485868754766642, 0.06373122980397555, 0.016845689312885367, 0.053688318904248945, 0.04848141463533525, 0.0971807123372151, 0.11757799484316381, 0.08624616319373732, 0.19380337558686736, 0.04768928738250848, 0.04458032638555573, 0.03533908819419242, 0.054115903218306845, 0.08056170652590453, 0.06646263968920516, 0.12062336288152203, 0.0714938914884002, 0.3831310203719524, 36.749753029115745, 81.41952453121063, 51.28318963512298, 50.89883265956756, 54.93106842041016, 49.60152833692489, 34.945152882606756, 42.14585573442521, 32.36802231880927, 25.268040049460627, 45.35970464829476, 59.61588459630167, 75.7854869288783, 43.63269682853453, 52.986980945833274, 70.32049563623244, 63.61821228458036, 69.20019611235588, 65.46532700138708, 58.04047638370145, 45.18796759267008, 24.29174642409048, 4.8020715098227225, 2.7087481464109113, 5.792650407360447, 8.20727962640024, 11.105331163252554, 9.084468195515296, 10.958878686351161, 7.560099824782341, 4.228122849618235, 3.0971471244289033, 8.820870211047511, 6.206597253199547, 5.238519522451586, 7.020964161042245, 6.1566782286090245, 8.235403510832018, 4.343783249778133, 11.912482380867006, 9.884732711699701, 14.059725096148831, 26.134521038301532, 32.88958576417739, 29.833000359996674, 40.905849395259736, 38.78737726519185, 39.073706365400746, 45.06424034795454, 54.845227349189024, 55.96151036600913, 65.38858582896572, 66.82065102361864, 65.35502602977138, 61.0919705513985, 53.30755626001666, 43.872055545929946, 45.463647457861136, 51.671974966602946, 50.18998584439678, 51.803923499199655, 54.22728930750201, 51.52327399100027, 49.933235337657315, 48.99972300375662, 52.90086530870008, 57.90277765643213, 61.828203355112386, 63.00602051519579, 56.84218052894839, 64.73894326917588, 64.13603574998918, 62.64315028344432, 55.22631306802073, 53.592759639986106, 52.54456112461706, 53.914182186126716, 55.62909341627552, 54.924384701636534, 50.79502321058705, 45.44848357477496, 49.04248076100504, 48.769201386359434, 42.1407566532012, 46.41564592238396, 54.86232888314032, 55.54015367261825, 58.62775718012164, 36.075474062273585, 12.630790933485954, 5.5029490493959, 9.292096899401757, 12.740862446446574, 18.8197027098748, 14.804952875260385, 20.754037211018225, 33.379880074531805, 39.30215697134695, 42.576543746456025, 27.205757594877674, 23.670237064361576, 24.53365860446807, 15.340065167796228, 17.72846991016019, 11.170744530616268, 7.5290689737566066, 7.1246623127691215, 5.586748526942346, 7.575273023497674, 9.234668497116335, 7.6593259842165065, 1.700823792526799, 0.752293867689948, 1.1787565677396714, 0.9190316173818804, 1.141171558730064, 1.3332679218822912, 1.6469406000068112, 10.825558304786684, 34.189880894076445, 57.35937249275946, 55.012775313469675, 59.621987804289795, 50.29018279044859, 57.05569474927841, 61.465007566636615, 63.231219476269146, 60.56796543059811, 57.19929664365707, 54.863607575816495, 26.93324112123059, 17.77560111015074, 31.865329396340158, 27.46755030847365, 28.26463084067068, 25.79178629382964, 42.82024845000237, 56.87104917341664, 32.82335654381783, 67.55946082453575, 41.057390166867165, 0.21712938924470257, 0.04483492038543186, 0.055097303984145966, 0.053779180762508226, 0.02247508724160012, 0.020395468792787964, 0.06585303288433822, 0.04815121158777226, 0.14412059719043394, 0.041323847497903535, 0.05447273931255745, 0.03003722541184435, 0.05442243414900957, 0.016594219036520492, 0.04870067666014356, 0.14754844228586844, 0.12325079165278904, 0.17998247527547423, 0.2432895758219304, 0.2621868811547756, 0.19226490249556882, 0.0900027979045145, 0.1964398671782786, 0.17706620837411574, 0.22104086564673533, 0.5414082482457161, 0.2689524487622323, 0.14078750184947444, 0.20837475095064412, 0.1762352481244072, 0.1506662975636221, 0.22781554970049092, 0.2611431629667359, 0.16409223358477318, 0.4756319697105116, 57.68814556060299, 93.57773457804035, 63.98240827745008, 65.09532982303251, 64.80987541137203, 69.82984635137743, 62.17320719072896, 58.68443935148178, 36.34607053572132, 20.765157130456743, 43.65526222413586, 65.02417018336635, 93.54196256206882, 49.911164160697695, 59.275179678393954, 81.14804160210394, 74.50429178053334, 77.75165342515515, 72.83979477420931, 64.40166258042859, 49.41444304681594, 27.341310785662746, 7.402739726728009, 4.148163372470487, 9.389980627644448, 10.04811119648718, 14.001386703983432, 14.364475607872011, 12.92988342623557, 9.699060455445322, 7.809216418573934, 3.7951846228491877, 10.142454005056813, 6.414892269719032, 7.11352474266483, 9.846071870096269, 9.687357083443674, 9.899094470085638, 6.99802908205217, 18.34815929012914, 14.254788487188279, 16.767285254693803, 30.281282163435417, 37.567261265170195, 36.06700174270138, 45.34987518864293, 45.91816386868877, 42.04912224123555, 50.35389777152769, 54.71663636545981, 56.58697151368665, 67.04038220067179, 72.01105286998134, 66.45414475471743, 62.73260385759416, 57.3270207835782, 48.87584278660436, 50.99995136260987, 57.9613386431048, 61.00703554768717, 58.67430786932669, 57.48571988075011, 54.40156021425801, 52.24923802960304, 51.08339194328555, 54.520380573887984, 57.60185341681204, 61.06151726938064, 62.054492735093646, 57.32999001779864, 62.12649176197668, 62.86223426941903, 61.03570022890645, 55.19734636429818, 54.94915054690454, 53.732909848613126, 54.4504290242349, 60.227397795646425, 60.06593734987321, 58.07886854294808, 55.95157107999248, 62.999850626914736, 58.91651814983737, 45.8640508497915, 48.34864093411354, 56.3826983974826, 58.52190025391118, 62.04314531818513, 38.73846923151324, 13.089019867681689, 7.902058920552654, 15.381360861562914, 21.616087882749497, 23.88751087650176, 20.900622067912934, 27.580620473431004, 40.889147943066014, 44.42710622664421, 47.01885546407392, 27.859624547343103, 30.791733534105365, 30.788523074119325, 13.393854710363573, 17.45002281281256, 13.407554568782931, 10.617859978829662, 6.828915601776493, 6.789658069610597, 7.129182844392716, 9.158758867171503, 6.477992419273623, 2.2712165790219463, 1.4153502593117377, 2.3962722814852193, 2.608351404628446, 2.1539499682764855, 1.9396982197799992, 2.7035632633393814, 12.310434291439673, 39.0993861229189, 63.107692272432395, 60.35227429482245, 61.971562062540364, 56.47863172715711, 62.12988068980556, 69.20465192487164, 68.40186826644405, 65.41994125612321, 61.1222198701674, 61.08730293089344, 26.076670000630042, 17.093149885054558, 46.506856718371, 42.148401352667044, 56.835343837738044, 34.45624120773808, 63.920513276130926, 64.93398312599429, 40.19886178355063, 77.95045483496882, 55.87619881476126, 1.165778302857953, 0.26254599253016137, 0.27439130530242, 0.21884018615368875, 0.2866509490676465, 0.10426625954888522, 0.14343595973426296, 0.10816821347801917, 0.3614052571356297, 0.23230860941112044, 0.13555548904884246, 0.1594165078694782, 0.16937581942446772, 0.15437744197345551, 0.16948281126397272], [0.04919436670118763, 0.031970415730029345, 0.08183603250091115, 0.06414806973489542, 0.033956785956698085, 0.02893452419929447, 0.08797788196393559, 0.10295858576653466, 0.05661025868668672, 0.08644947526796211, 0.06525291024797386, 0.19218927429568386, 0.10282589167717004, 0.022053315619667693, 0.0857592300481854, 0.040086458452166095, 0.09691163161469084, 0.028215521954060085, 0.08994367889939778, 0.14338774216030875, 6.701516528283396, 68.8050800754178, 56.40684843063355, 39.37294398584674, 41.261682894922075, 42.390827363537205, 48.13515024800455, 46.87268441723239, 40.653119317946896, 15.131549027658279, 17.99996852874756, 56.921314347174864, 61.924477930991884, 80.17300313518894, 48.90299343293714, 50.86223694585985, 60.978406167799434, 59.88348830130793, 57.70571777897497, 47.7433446914919, 35.00970332853256, 24.326592760701335, 4.470053170957874, 0.962054870061336, 4.778273019098467, 6.001344034748693, 10.259081759760457, 7.610515029199663, 10.152904179788406, 7.313133670437721, 6.9102028012275705, 4.240576374915339, 2.563485618560545, 1.3380013646618014, 2.2100602090358734, 1.8482823573773908, 1.1938698277358086, 0.5972343623157471, 10.59577311238935, 18.93518317130304, 10.243385414923392, 20.242373827965032, 31.839500588755456, 26.573249909185595, 22.650591442661902, 31.87284269640523, 26.220622947139127, 31.228775785815333, 39.92227977321994, 40.740568560938684, 39.04998779296875, 41.901927455779045, 55.38862074575117, 57.60992957699684, 59.96764275335497, 52.2131561463879, 39.1276938684525, 35.299350753907234, 41.964124479601466, 45.224465247123476, 44.77784848982289, 47.37274739050096, 49.590435874077585, 48.746573232835345, 45.08093787777809, 48.35912542958414, 57.74820097031132, 58.32535812931677, 60.5046348417959, 57.15859813074912, 59.29420709609986, 62.79081967569167, 56.64882729130407, 54.49805052049699, 49.00198621134604, 49.01650290335379, 50.37954615008447, 47.94281682660503, 43.94479197840537, 40.11629981379355, 33.79692608310331, 36.410181676187825, 37.88971539466612, 37.65384758672407, 43.84751327576176, 54.80695678341774, 58.20621221296249, 53.24923846029466, 22.461888174856863, 4.490916257904423, 3.8013871158322985, 5.215873718261719, 13.852750447488601, 13.134933171733735, 14.143604982283808, 14.312440464573523, 30.069878178258097, 35.72740685555243, 38.4100805559466, 32.53591741285017, 25.136925020525535, 43.07461023330689, 17.562647788755356, 8.540846320890612, 11.327961952455583, 10.303056432354836, 11.123731001730889, 9.509520742201037, 3.5706360397800325, 3.332016444013965, 4.161264579142294, 2.947800183488477, 0.27995255204939073, 0.4191339965308867, 2.1718210222259646, 2.22139046557488, 3.0966430998617605, 2.008297900038381, 9.802869904425837, 32.84190150999254, 42.98538023425687, 53.660491128121656, 42.48079869054979, 51.0625994590021, 55.23694269118771, 58.12896113241873, 58.16121870471586, 52.09740308023269, 53.604942521741314, 45.604417400975386, 10.932041829632176, 30.105332482245664, 36.19712637316796, 36.631466111829205, 35.88615694353658, 29.001097025409823, 63.54584455490113, 29.383769342976233, 42.013871900496945, 58.80811168301491, 8.232137157071023, 0.333364631139463, 0.21021104838338592, 0.11597862542276421, 0.20958147732721222, 0.08427655114041221, 0.08706538697644588, 0.07965053687052381, 0.015586894812933622, 0.05729237954402643, 0.016554317346984343, 0.04595727749889897, 0.04474001358293238, 0.04408253777411677, 0.053295419220962835, 0.04503953097868831, 0.10976343070186916, 0.10878031772951927, 0.023996013088993007, 0.07705617245406875, 0.03383377904913599, 0.01299855950844264, 0.08177555752016845, 0.2617807319808391, 0.060232931432584604, 0.05828907142483419, 0.06925018083664679, 0.16962760188166173, 0.04529712038234838, 0.10733872411712524, 0.09591463712915298, 0.01391112152862573, 0.06790414137104828, 0.05756557415870409, 0.013749900240180715, 0.2895446163752387, 10.559169553941297, 85.29248852883616, 63.71699717737014, 47.94748836948026, 45.44754612830378, 52.5518096646955, 41.04514844955937, 36.88293710831673, 40.44000910174462, 24.867450344947077, 25.463128935906198, 62.10576203561599, 70.95016940947502, 78.21989028684555, 55.35033841286936, 56.05620814907936, 66.39062589214694, 66.3893158205094, 63.5805183072244, 54.1350547729, 39.95711042035011, 26.798395918261622, 6.43113725608395, 1.3707461688787708, 5.886861326233034, 5.7282622495005215, 11.916196865420188, 10.012914788338447, 12.333517439903753, 9.541468447254552, 9.157730225593813, 7.808766816892932, 4.70084935426712, 3.026442969999006, 5.3127209601863745, 6.202585649105811, 6.120490931695508, 5.3440994312686305, 11.79304915089761, 23.09643549303855, 16.308459139639332, 24.38756012147473, 35.122761726379395, 30.16075949515066, 25.42636259909599, 35.32795659957394, 30.322165027741466, 34.546110553126184, 46.74740783629879, 46.54311118587371, 46.128493124438876, 53.046157744623, 62.98830316912744, 63.54447172534082, 63.06753504660822, 56.94645673997941, 44.90674541842553, 42.8797508055164, 51.109354111456106, 53.57824294797836, 53.43903803056287, 55.291161614079634, 52.52862845697711, 52.917327496313284, 49.71148413996543, 51.874184916096354, 64.27685668391567, 60.76212667649793, 65.3780895663846, 55.52264813453921, 62.62535841234269, 65.91816071541079, 60.69255559675155, 55.507095936805975, 53.06003116792249, 53.537815078612304, 55.675910826652284, 55.62832855409192, 56.48655883727535, 51.067710307336625, 46.96953165915705, 45.88063855325022, 48.77340224481399, 45.40991883124075, 45.48191393575361, 57.569168306166134, 59.27745857546407, 58.468006887743556, 26.934545309312885, 6.9814457912598895, 5.072004612415068, 8.011995111742328, 14.601175938883136, 15.036261908469664, 18.54900033243241, 17.55065121958333, 33.015189863020375, 37.53973407130088, 42.55538648174655, 37.09165426992601, 29.224442666576756, 40.84536644720262, 20.243630947605258, 19.319002782144857, 17.30717597469207, 16.17001908440744, 16.92990868322311, 12.52534487555104, 7.655637485365714, 7.278485903816839, 9.314431855755469, 5.895462593724651, 1.7229527018723951, 1.1188814644851992, 3.2779178888567033, 3.191415898261532, 5.247236990159558, 2.564549071173514, 9.939311512054937, 36.30148887634277, 50.24833894545033, 59.29340693258471, 47.9105317977167, 58.92994442293721, 60.01214988770024, 63.365592033632346, 66.5828690990325, 57.85408535311299, 57.9738784605457, 48.08273953776206, 17.61711774333831, 27.828131837229577, 38.14676400153868, 24.86829169334904, 28.92549530152352, 25.58461846843843, 60.96523877113097, 38.65821361541748, 43.91785706243208, 71.20080886348602, 10.202094624119422, 0.4462629166101256, 0.21633535443294435, 0.09329320682633309, 0.1454069354240933, 0.08898203937156547, 0.03250306900290232, 0.006025101014998772, 0.03940508453055255, 0.03262535578781559, 0.0168776773141637, 0.04831360690596123, 0.04786131242590566, 0.04391872136282825, 0.024994987911815127, 0.041930060533265916, 0.15625032776546094, 0.23135846120215234, 0.1181489525122508, 0.2081507468415845, 0.1808162700505026, 0.1279487645614051, 0.24887602686160998, 0.2776285477222935, 0.1450956892222166, 0.21217830088590423, 0.1535391885667078, 0.26215099759640237, 0.16171006786246456, 0.21278121208231296, 0.2581313342577027, 0.14776674670077142, 0.18114850706150457, 0.12656185430504624, 0.18575637270846676, 0.3174584701416954, 17.49909362485332, 101.41918013172766, 74.7529229810161, 63.64173081613357, 58.032506127511304, 64.60289193737891, 67.29826235002088, 61.11390836777226, 50.70462826759585, 18.71533040077456, 24.91367351624274, 67.49751091003418, 78.09638269485967, 89.34650128887546, 61.48732193054692, 64.29701766660138, 75.20229324217766, 73.7596768717612, 69.02718820879537, 57.9516621558897, 43.535735837874874, 33.083862719997285, 7.897520738263284, 2.0897753344428156, 8.343451080783721, 11.684503439934025, 12.893802523612978, 13.46599788435044, 16.33788181889442, 14.352479038699983, 11.707092369756392, 7.513835958896145, 6.331193302908252, 4.624587691599324, 6.8476233463133545, 7.983758949464368, 7.228525694339507, 5.411352880539433, 17.155905846626528, 27.486632639361968, 18.20803849927841, 31.413670432183054, 39.94704954085812, 37.684344014813824, 30.900869561779885, 40.154338959724676, 31.689032585390155, 37.45716425680345, 49.32742134217293, 47.832774731420706, 43.08182739442395, 45.8342408364819, 60.411702125303215, 63.763069337414166, 65.54352337314238, 60.46063761557303, 50.56842396336217, 48.539876091864805, 59.54810211735388, 63.502282711767386, 61.22202457920198, 58.928983442245, 57.63203997765818, 57.12278296870571, 50.620387523405014, 52.08087421232655, 64.58156601075204, 60.72855903256325, 64.73634273775163, 57.931159926999, 62.66128340075093, 65.98670805654218, 61.82174321143859, 57.59256916661417, 53.68862628936768, 53.405388016854566, 59.01389883410547, 62.286528387377345, 60.461622130486276, 59.73857633529171, 57.736771183629195, 55.78782781477898, 55.33076970807968, 50.43605181478685, 50.02757226267169, 59.732559419447384, 61.82883877908031, 59.54454844997775, 30.158863029172345, 8.85205207332488, 6.651885797900539, 9.696418739134266, 20.75362143977996, 19.580762155594368, 23.490596432839673, 22.400867862086145, 38.57778541503414, 44.64757873165993, 45.8764337724255, 40.01607541115054, 31.959791837200044, 49.213139164832334, 24.668148832936442, 17.142507030117898, 18.079231785189723, 15.724125023811096, 16.983107789870232, 12.786991480858097, 7.1772264857446, 6.807407284936597, 8.994373313842281, 6.236331760883332, 1.3406110891411382, 1.344443367373559, 5.906313340510092, 5.857918647027785, 7.428517053204199, 3.552717427092214, 12.111517171705923, 42.56022276416902, 55.57283878326417, 67.80340087029242, 50.682286447094334, 60.7025105722489, 66.13367926689887, 70.28729669509396, 69.69927064834103, 64.96327538644114, 62.211454222279215, 53.697522224918494, 13.90025721442315, 39.22640031383884, 48.87847861936016, 46.53481145058909, 47.44666053402809, 39.58129636702999, 76.54116292153635, 45.74491277817757, 54.56059271289457, 82.04936304400044, 16.98290578780636, 0.524897950310861, 0.45956440930885656, 0.26266430714918726, 0.26105849492934446, 0.22321646342114096, 0.17696304697423212, 0.16072297889378764, 0.09388490249553035, 0.17052363363965867, 0.1620497818916075, 0.1385721287900402, 0.11020885720368355, 0.14379726212111213, 0.12334124365400885, 0.09818834012314197], [0.03181211898223527, 0.04663017465763035, 0.11113614534899113, 0.07503591432806946, 0.025129357818514112, 0.04444495864933537, 0.08686641862075176, 0.09772540851225776, 0.10662029452261426, 0.04733483382170239, 0.055778103339816296, 0.07063352112327853, 0.07671771480912164, 0.1861265463934791, 0.05819454766629685, 0.11040216416961725, 0.04191310700750159, 0.03800471410936406, 0.05135187330926138, 0.020769476747861313, 0.14001508603893942, 47.08181735007994, 61.35086659462222, 42.96348948632517, 41.552063803518976, 34.75263510980914, 49.52575991230626, 47.37723850434827, 47.95107733818793, 21.15875521013814, 24.82609679622035, 70.30328427591633, 63.03039412344656, 64.34409395340951, 70.0960183912708, 64.27925325209095, 64.87418267034715, 60.24658995289957, 56.11292954414122, 38.04888517625871, 25.923785817238596, 27.566525436216786, 5.4645166858550045, 1.4196553057239902, 3.0241393129671774, 5.964646829712776, 7.865985372374135, 7.037374867546943, 7.670625842386677, 6.864530232644851, 3.8446359047966623, 1.3379530704790548, 1.2772337996190595, 1.6940645681273554, 2.351423410638686, 1.2674936964627237, 2.093317970152824, 4.5108193447512965, 22.318125463301136, 19.789351840173047, 19.989380951850645, 33.38282577453121, 31.995342239256832, 22.54365978702422, 19.31918321117278, 25.23259359021341, 23.895351694476222, 28.117063430047807, 24.46899244862218, 28.8920041438072, 15.62266899693397, 20.24905754673866, 51.45142009181362, 58.80849607529179, 62.76237464720204, 54.109618202332534, 42.500010459653794, 34.529260050865915, 42.32188778538858, 46.9479037100269, 47.525798274624734, 48.32285135023056, 49.343091211011334, 49.55839403213994, 47.213212828482355, 51.106129923174464, 60.34863041293237, 59.74624456897859, 58.04456349342101, 60.99495464755643, 62.735922182759936, 59.32176566893055, 59.23837215669694, 53.019230673390055, 48.46688078295801, 49.661301335980816, 49.161222673231556, 49.22500041223342, 44.167029549998624, 41.64957784837292, 33.39400845189249, 37.91383797122587, 34.74723400608186, 34.71678856880435, 44.77716207504273, 57.804177115040446, 57.01397249775549, 48.050458431243904, 10.12956411607804, 2.0076085434805964, 0.2979304292990316, 1.11802258799153, 5.1644666444870735, 11.752528125239957, 12.231989829770981, 17.84548794069598, 20.704823232466175, 36.345125244509795, 35.265759575751524, 36.25231019912228, 30.733653037778794, 39.182187357256495, 36.62011477255052, 12.885831286830287, 16.210668567688234, 11.48697974220399, 15.016637309905022, 12.186827659606935, 12.937362405561633, 6.618449553366631, 5.322002268606617, 4.385915388984065, 4.596424583465823, 1.8981495331371985, 1.2452787401214724, 0.5576894552476945, 6.215975149985283, 2.5481364034837295, 6.334762659765059, 32.45434388037651, 39.4205262584071, 58.07104341445431, 45.86803990025675, 43.30561430223527, 60.644949789970156, 62.315302894961455, 57.22758869970999, 51.61213528725409, 59.111765892274924, 31.636923897650938, 12.208982186932719, 50.7999026390814, 34.88167324373799, 37.397057856282885, 29.132974955343432, 44.98632246448148, 46.85509258700956, 28.931402391003026, 51.06003815127958, 52.87772332468341, 0.4924653116012774, 0.09564143485359608, 0.08922529527016225, 0.06214697529832202, 0.14267883503869658, 0.06686655954728205, 0.09914985707690639, 0.04599144118988226, 0.03506886600066097, 0.13106982974756148, 0.05034534102906624, 0.10583563662704923, 0.027541050484644312, 0.13198790951601921, 0.058816921326421925, 0.08395458736847486, 0.03166059062125222, 0.0392070776152034, 0.059139222177045966, 0.08675244005937731, 0.012312615872360768, 0.14294719563857203, 0.04433946451172233, 0.03887945245350561, 0.09796271956856213, 0.13961560182994412, 0.0368873059238878, 0.07140340884366343, 0.020208863180971915, 0.038494895467714924, 0.0392260842566048, 0.05345290774599679, 0.020242322071064866, 0.05289685048703706, 0.11771361538839918, 0.08260133135462962, 0.2648971776568121, 61.107644342607074, 76.46626134072581, 51.42470482856997, 49.837376533016084, 44.0017173367162, 50.176214402721776, 36.04193779730028, 42.705938816070564, 27.79240688970012, 32.21987635858598, 70.71203447157338, 71.98333740234375, 70.26636692785448, 74.47878852967294, 68.64342351113596, 70.37259255686115, 67.34140842191636, 61.63210838071762, 45.35226391207787, 29.618544770825295, 30.027730349571478, 6.759627422978801, 1.8223004547819015, 2.8645209102861346, 6.188953451571926, 9.40466009801434, 8.35152037682072, 10.127271490712321, 8.576420257168433, 9.036961428580746, 4.412790488812232, 3.409493551138909, 5.089246371100026, 6.796604587185768, 5.481721672319598, 5.676686513808466, 6.7650000895223315, 23.419119081189557, 28.2052343891513, 25.14096506180302, 37.39441417878674, 34.9701540700851, 21.958579440270704, 22.61115004939418, 27.0317945941802, 26.923878423629272, 33.99303282460859, 29.1667995145244, 33.09572788976854, 24.145389064665764, 27.306044755443452, 55.90580878719207, 61.25329371421569, 68.45262373647383, 59.45110974773284, 48.977039937050115, 43.40837647837978, 49.13184412064091, 55.20256311662736, 53.36828239502446, 54.6337527613486, 54.869702939064275, 51.622396207624874, 49.799058898802734, 51.48742744999548, 62.22346844211702, 61.2239347734759, 62.47286450478339, 59.6450670303837, 65.18985502181515, 63.427122254525464, 65.59861306221255, 56.194581524018325, 50.325178177126, 53.45012264866983, 56.421965245277654, 58.16050091097432, 56.259512439850845, 52.151355281952895, 45.81293059933571, 47.15586777656309, 45.19956211889944, 43.42752156719085, 51.42192779048797, 59.51834309485651, 61.38491669008809, 54.72413201485911, 18.743938207626343, 2.551525576460746, 0.8323232120563908, 2.1137329263071862, 8.211674151882049, 15.247457027435305, 17.274428106123402, 20.15199653563961, 22.059955058559297, 41.17797167070451, 38.88202405744983, 42.50605875445951, 37.06488801587013, 45.48541268994732, 32.82046771818592, 20.112963068869806, 23.151888001349665, 10.139789735117267, 19.153517984574844, 16.649321932946485, 15.890916951241033, 10.750794006932168, 10.978112028491113, 8.719245522252976, 5.203634452435279, 0.6326154895847844, 1.2188105861986838, 0.3504917217839149, 7.892509420071879, 4.451785222176583, 7.484460348083128, 37.00644077793245, 48.57150216256419, 63.807035184675655, 48.7922296216411, 50.96584635396158, 67.09913930585309, 69.57460987952449, 64.4120333271642, 57.992894111141084, 66.66210882125363, 35.37085163977839, 15.665716028982594, 39.64120272667178, 36.42267050281648, 26.646784543991092, 32.4336886790491, 36.795323125777706, 53.564969647315245, 32.69715428352356, 56.049818608068655, 61.34244526586225, 1.9046124960145645, 0.19866598079041128, 0.14871831983327866, 0.0654353617480205, 0.07107275763466474, 0.019093167202006427, 0.02978696938483946, 0.0353061885482842, 0.0566266491378267, 0.11195847178779303, 0.07151625359490996, 0.10605990120600309, 0.03151616198010743, 0.10678210761398078, 0.061126618961533236, 0.06424443593489067, 0.15966804517853647, 0.18533571382924435, 0.24597466803125798, 0.15413695165226537, 0.12070679751735543, 0.2539316249350386, 0.12468547515210607, 0.12119252790486622, 0.14631871794981344, 0.20403806510711872, 0.1233727528503345, 0.20404135928519312, 0.28595871201926665, 0.19748939231278437, 0.16540097222933847, 0.15198943866116388, 0.17173638146731163, 0.16902502776393968, 0.13755485595714662, 0.17303699957987956, 1.1625284965961211, 77.0973785461918, 86.28894313689202, 63.33203615680818, 64.25606812200239, 55.6421313747283, 71.71654562796317, 58.71962693429763, 57.91904372553672, 26.746167598232148, 30.447067022323612, 81.19088957386633, 73.77641754765665, 80.33996274394374, 82.63680073522752, 77.76611912635066, 78.79909884545111, 72.74126483548072, 67.87623143965199, 47.871304173623365, 32.249156851922315, 34.480367706668, 8.184953005083146, 2.54499483012384, 5.2409317801075606, 8.640399998234166, 11.039431421987473, 9.146441644237889, 12.046967706372662, 11.430334833360488, 11.432363679332118, 4.87739670661188, 3.3466385497200877, 5.699993237372368, 7.474889274566405, 6.3815079965899075, 4.742230849881326, 9.415380916287823, 31.432052619995613, 29.905164126426946, 29.650851372749578, 42.31640431188768, 40.6557120046308, 32.13837931233068, 29.489522326377134, 32.12218972944444, 31.543055695872155, 37.757523675118726, 28.95481894093175, 34.041376036982385, 21.61878058987279, 26.085648305954475, 55.85745773007793, 61.597720961416925, 68.7445108352169, 61.43276568382018, 53.325128478388635, 48.62305779610911, 57.292515693172334, 62.98319232079291, 60.35781660387593, 61.811800003051765, 59.67460247778124, 54.56506813726118, 51.91139644192111, 54.464200465909904, 62.76557530126264, 61.32142920647899, 61.61236316927018, 56.25085184651037, 62.76000161324779, 62.43226012875957, 63.94980161420761, 55.39221755919918, 50.130965940413944, 54.6573575850456, 58.4679441298208, 61.494868570758456, 63.1571965063772, 62.41032231238581, 57.8313159942627, 58.66963240408129, 53.029715168860655, 46.443643800673954, 53.099298015717544, 62.173320939463956, 61.182094850847804, 56.57671451568604, 18.332811055644868, 3.9504563039348977, 2.017029586338228, 2.6274839908845964, 9.599137094713027, 21.299081925422918, 22.816923472189135, 28.97303835038216, 30.602669408244473, 48.16723523601409, 44.84598790445636, 47.14050385259813, 41.68209037473125, 46.7021672187313, 43.1223847020057, 19.849164062930694, 22.8674671342296, 15.45958959287213, 18.34256991263359, 18.259562753861953, 18.475069538239513, 10.448626375967457, 10.924538335492535, 7.662963492255058, 6.555709771571621, 3.455058009393754, 3.075685876031076, 2.301242812987297, 9.865258143794152, 6.36507865882689, 10.866898125217809, 44.108833343751975, 54.10937893775202, 71.09448125285488, 53.15867093301589, 54.59041841568486, 70.80774814851823, 76.74612245252057, 67.63961838137719, 62.52211770703716, 70.15479903067313, 37.412661044828354, 15.440781827895874, 64.25355388272193, 42.98966346248504, 47.460847746941354, 42.28814363479614, 54.44554175100019, 64.19903685969692, 42.30938719164941, 64.22397921162268, 76.1546996331984, 3.7707183486030953, 0.5115925658854746, 0.4961087338386044, 0.1416779718091411, 0.295825035822007, 0.23503735331037354, 0.22726496230931054, 0.09655117958543763, 0.15981220760412757, 0.2451615269866682, 0.16947375610470775, 0.19042132722754634, 0.14402310484119002, 0.2369530174520708, 0.20613028187184565, 0.15846142605427774], [0.04277211373611804, 0.029224021165000818, 0.06142598697014394, 0.027352560296534534, 0.019423088712257244, 0.01558690726186239, 0.04136444632745078, 0.05613518075176305, 0.09989241844103222, 0.03202857904046053, 0.1285157845385613, 0.09702098300500263, 0.052812109671292774, 0.1537854705126055, 0.05852093942643655, 0.08517131885333408, 0.030409308571007945, 0.10235198968721014, 0.17578160149916527, 0.08816357401590194, 0.07521772997513895, 8.783683200036327, 51.74096161319364, 53.19806329665646, 38.36455360535653, 45.59120293586485, 36.5907048409985, 51.281255906628026, 43.63873335622972, 44.75146270567372, 12.524289757974687, 60.30205226713612, 75.70558824846822, 60.51659414845129, 62.950664104953894, 69.03264030333489, 71.18731591009325, 68.7077425372216, 64.82492946809339, 41.36265254789784, 36.84846339687225, 35.030374219340665, 11.599525290150797, 0.658933551561448, 2.275009020682304, 5.149147827779093, 5.774857555666278, 6.7750286094604, 4.5183949124428535, 9.827992685379522, 2.191366683090887, 1.4845237087818886, 3.7240874959576518, 5.382426871407417, 6.167031324678852, 5.160912486814684, 6.522522107247384, 16.625428815041822, 29.963336798452563, 25.97135436150336, 32.76530546526755, 40.41709461519795, 28.489441487096972, 19.623594437876058, 18.253643897271928, 17.957193120833367, 26.634087831743305, 15.034817495653707, 13.228497389824161, 15.85893100307834, 7.990846182069472, 22.699595574409734, 59.45229430352489, 61.58509092946207, 59.5806146437122, 52.93712369857296, 41.95141992261333, 34.81429084654778, 41.217324810643355, 45.766034741555494, 47.55138389525875, 48.33745041201192, 45.60301711482387, 48.69540199156731, 45.51048448008876, 48.38597405341364, 57.92819853751891, 58.14311696637062, 59.76549556178432, 55.79056955152943, 61.13019012635755, 62.4126757344892, 58.91250948752127, 52.44853758042859, 48.00643374842983, 50.74577785307362, 52.85078448633994, 50.58008516988447, 47.984672438713815, 36.08087124363069, 35.69184272520004, 36.690921398901175, 34.007984899705455, 36.23710316996421, 49.61009087101106, 61.334526000484345, 60.56489029238301, 35.514249570908085, 2.032141743167754, 0.6214127713634122, 0.7057645063727134, 2.8734085108003313, 2.3784433930150928, 11.263879249172827, 17.12251078697943, 21.939622625227898, 26.115566184443814, 26.861887324240904, 37.805768828238214, 34.07420627532467, 40.42792820161389, 40.044944055618785, 40.524485188145796, 18.41005821381846, 8.564724729907129, 22.281312058048865, 17.22223900979565, 15.68480424342617, 16.03950810047888, 12.196029540031189, 11.127271921403947, 6.600789081665778, 8.288986029163484, 3.190041107516135, 0.6074949149643222, 1.0655572097147665, 1.540565430637329, 3.7962848476825224, 5.107980591635551, 28.590250322895667, 46.117957638156035, 50.311049799765314, 44.597360626343765, 62.19366235117759, 62.0564970662517, 55.995678132580174, 55.78871034806775, 54.14500974839734, 61.796612585744555, 25.792315813802905, 20.582788490479995, 50.428767973376864, 33.93935518880045, 35.15775319068663, 25.57062149047852, 47.73488806140038, 43.69027722266413, 39.15884140999087, 57.85713695710706, 18.408738336255475, 0.37025590156835897, 0.1302408306829391, 0.06439352813627451, 0.10829745251084529, 0.035790313981593616, 0.048993452482165835, 0.05475532616518679, 0.07070181786172813, 0.04608240647001132, 0.04168192848503109, 0.04273116633656525, 0.05605997390023643, 0.057175915027337695, 0.029661057088824532, 0.04572997155088571, 0.03920465677736267, 0.11076820097983846, 0.019765815382162412, 0.023640948573067307, 0.016991540962349505, 0.04233517165806505, 0.10082519943675688, 0.02642863144677493, 0.06193521327429241, 0.08663404883155901, 0.03366200681475382, 0.2219440986312205, 0.13778429929046862, 0.05813678846724572, 0.05957539816717467, 0.11340751177481107, 0.05030675318032023, 0.11098139558828647, 0.03311701186542069, 0.11566420761688102, 0.02292923948487207, 0.08305819554915352, 14.608699044873639, 72.0237535045993, 63.80608204872378, 50.6695112874431, 54.117851257324226, 47.55687521349999, 41.503932399134484, 38.110772332837506, 43.78448470946282, 20.790693721463605, 63.606402027991514, 81.23645182578795, 71.51998781388806, 66.9800796816426, 75.87673694856706, 76.88331127166748, 76.49808745230399, 67.58053179710143, 46.99635674876552, 37.75236575834213, 40.61606468692903, 11.993439120631065, 0.9894055572728958, 2.993078308720743, 6.3379623332331265, 6.960536126167544, 7.54510215213222, 6.169496044035881, 14.856623238132848, 4.171905969419788, 3.7570170192949237, 7.0560747673434605, 7.953380192479781, 9.291401659288715, 7.765776168915534, 7.478222308620331, 11.335939072793531, 33.592696112971154, 31.34092027141202, 37.342736951766476, 46.13122701644898, 28.26112031936646, 21.173454292358894, 22.720164483593358, 20.774686528790383, 28.19819569587708, 16.412751040151043, 14.65726092938454, 19.9818500011198, 11.457701210052738, 23.76925926054678, 59.85315661276541, 63.74204935566072, 65.33295485281175, 58.262255037984545, 50.1818783052506, 45.955528366950254, 49.699756253150206, 54.27925678991503, 55.19758562887869, 56.928531508291925, 53.8243991328824, 53.06248657165035, 48.158190250396736, 53.61899637406873, 57.5971975634175, 63.17912255564044, 63.67982879761727, 60.184451764629735, 61.918398257224794, 65.50100488047447, 63.11732169120543, 54.72091959368799, 50.59315450729863, 55.702010277778875, 57.922232612486816, 60.13059762216384, 56.79439821550923, 51.43107475772981, 45.660154281123994, 50.28946499670706, 42.36588501161145, 44.232721405644575, 55.84879713673746, 62.25332552386869, 61.8759346777393, 46.130242501535726, 6.633389861352983, 1.543967228743338, 0.40623607895066666, 2.932421550635369, 5.353122353553773, 13.353704348687204, 16.840810083573867, 21.82666817019063, 25.86103181685171, 26.362969683062648, 39.23856358374319, 38.58355522155762, 43.801084180032056, 47.57723623706449, 41.016421010417325, 15.17916169858748, 15.547715444718639, 17.883305472712365, 17.835272127582183, 16.97939330531705, 18.532138063061623, 15.023032734470984, 14.567393545181522, 13.208892403110383, 16.481013028852402, 6.207645016331827, 1.0896002357044527, 0.5713201206057303, 2.2242150623952193, 4.7960080158325935, 5.548338717029941, 36.08727647412208, 53.67990293810445, 59.56780418272942, 52.37476564222767, 65.36141164841192, 66.70914588436004, 63.92228226507864, 60.46372452089864, 64.21908017127745, 63.29621315002442, 31.38810246221481, 17.89102077484131, 48.241752424547755, 33.24029468720959, 31.218897296536355, 27.505869903872092, 41.54288937968593, 52.15295953135337, 42.06470974030034, 68.22773856501426, 28.71588776188512, 0.5291509640312965, 0.023671174572119792, 0.33670342617457916, 0.2030257565239745, 0.04964214126248995, 0.056501428236163435, 0.02997630993054519, 0.024261795803003257, 0.032240817954223004, 0.08456034075108268, 0.03660942285111354, 0.015425435079622175, 0.0568146241318074, 0.0419825681995961, 0.021544516409537005, 0.021052894805888497, 0.20366922441509464, 0.10296062356041324, 0.09812686922809771, 0.13735473846956608, 0.1141372794706014, 0.2384211483501619, 0.09672515815304172, 0.14815774265556567, 0.23770318606928473, 0.06520764211252814, 0.3721953910445014, 0.20338736534599336, 0.14415009157551875, 0.1761139764059936, 0.17925251605770282, 0.13364561653185275, 0.18552536655577923, 0.4358178593458668, 0.40424924524080375, 0.16804235146170662, 0.3317266738703174, 20.49595702079035, 93.28185450646185, 74.24598801520564, 65.05587862383935, 65.71104780320199, 61.06336862810197, 65.86997047547372, 55.82961282422466, 56.58060550689698, 16.343699674452505, 69.84046812980407, 85.74793846376481, 74.74074009926089, 77.33058698715703, 84.26819293729721, 86.9335219167894, 83.14573610982588, 73.7382842648414, 49.200340470960064, 45.03489317432527, 46.85269994120444, 15.167850563603064, 1.3384567273239936, 4.217253961870748, 7.981969858369521, 8.120477574486888, 9.185510412339243, 8.698312813235868, 16.613436168239964, 6.174745155918983, 5.156860678426681, 6.105313320313731, 9.35534707961544, 11.867652631575062, 10.081198350075754, 9.467948521337203, 22.6737000865321, 40.86941842109927, 35.58657023214525, 40.916224064365515, 50.53979066110427, 37.16080173369377, 25.48108554655506, 28.73665082839228, 25.92610589919552, 33.32322535976287, 19.488076548422537, 16.892412785560854, 20.77608093138664, 15.41943040586287, 30.191538333892826, 64.32802008044335, 65.82937394419025, 65.40671894627233, 59.21815233845865, 52.273478277267955, 48.66805522672592, 56.164649917233376, 61.893240174939564, 61.72913997404037, 61.69788652850736, 57.33526952805058, 53.92085806015999, 49.83659990372197, 51.921892704502234, 59.91792278905069, 61.31711459928944, 63.49192765451247, 58.483845418499364, 62.23688294810634, 65.62672861160772, 61.97549227745303, 55.03625462132116, 50.5565470264804, 55.62430027992495, 61.6464211094764, 64.7565782454706, 63.14948904898859, 61.929573089845725, 59.42962692629907, 60.8447749383988, 49.913211637927645, 47.62176298326062, 60.08918523788453, 61.53587695091002, 64.64814432205694, 45.1236250323634, 7.444062877085901, 2.127897340443827, 2.442094635578894, 5.566100189762731, 6.5365004539489755, 19.071199201768447, 26.163168068855043, 30.397574555489328, 37.96027883406609, 36.03992169903171, 48.78487909993818, 46.192000219898844, 49.171507127823375, 49.15151480705508, 47.2034735833445, 25.98279199292583, 15.829989794761905, 31.747746544499552, 24.212736160524432, 23.251059247601418, 21.708038045514016, 17.223298049742176, 14.709538279041169, 11.05391477384875, 14.017816532042719, 5.986256147584608, 2.3326244709953188, 3.0950079617961763, 3.4255659532162452, 6.101039898010993, 9.96861553961231, 43.669065044772246, 61.88297533219861, 64.41380623848208, 54.91435520110592, 71.97667721779116, 71.758083528088, 70.01890459368306, 66.53747158665811, 63.47941529366278, 69.64359652611518, 29.998853860362885, 27.529419814386678, 63.42616127383325, 41.50251642350228, 46.654267234186975, 35.424658713802216, 55.695126518126465, 63.82532127441899, 48.83336744000835, 82.81635115223547, 43.03202898271623, 0.6632119381139356, 0.22417226535899026, 0.38060222542093647, 0.2900298871099949, 0.1933128035236751, 0.1483319970148225, 0.09511235155045025, 0.14709914704003643, 0.13051659169216312, 0.22252833260403526, 0.24998619551620177, 0.10546235262506432, 0.14053535167007677, 0.15104332007467747, 0.24152812517939076, 0.12165170568492144], [0.012217885270083865, 0.02607313409117201, 0.08183646151014874, 0.01653647324400804, 0.03189635226472972, 0.04555849426035439, 0.04116029921738852, 0.09567976223244783, 0.03217571963285727, 0.13989612790605715, 0.0815423833386552, 0.034136613605604056, 0.21428600794846014, 0.12172741815447809, 0.039032589599129655, 0.08306269248526904, 0.0162815019458292, 0.016628534029868823, 0.08461694698780776, 0.10547133117553689, 0.05547863957021506, 0.26984377674037413, 31.406920033116496, 52.421026076039965, 40.786024908865656, 48.99333738511609, 27.114840976653564, 52.95376239284393, 46.324764605491396, 50.02684662418981, 20.955209693601056, 27.7261306008985, 83.2125654528218, 52.90139090630316, 63.60950854516799, 66.33341420081355, 70.9011084033597, 64.31321313304286, 67.26234912872314, 58.954502382586085, 58.49651467415595, 44.4209873291754, 8.568061686331227, 0.38757304330506637, 1.8760814205292735, 2.8144486681107552, 7.190407120412396, 5.501960612112477, 6.5249358357921725, 3.638416312394604, 3.4397029107616794, 4.772908197295282, 9.243708579770981, 9.304478841443217, 10.659279227256777, 10.160709696431315, 12.229892342321335, 20.407234968677646, 28.522875770445797, 38.126265695018155, 45.16883034859934, 41.560732241599794, 24.32802050344406, 22.58405431624382, 14.11756338611726, 19.497498081576442, 10.336180848460044, 4.84862563110167, 9.218451457638896, 5.501878732635129, 15.077981218214958, 46.11008544122019, 61.59990964397308, 61.134775377088985, 58.193974418024865, 53.723586374713534, 43.15533653382332, 36.019799940047726, 41.060724181513635, 46.83780277928999, 46.7110082410997, 47.207843103716456, 45.88374114805653, 48.57165905737108, 48.37182214183193, 50.702165019127634, 59.080618350736565, 58.31893720934468, 59.22951152247768, 56.75449986611643, 57.82900179586103, 60.8346866023156, 58.4370280081226, 51.62094493066111, 50.081689203939135, 51.02998887338946, 54.30013556634226, 52.84310056317238, 47.815806558055264, 36.97901556568761, 35.88694141757104, 34.440940041695875, 30.968908955973966, 37.22376361969979, 54.60271896854524, 57.29400619383782, 52.26390377167733, 17.23716951185657, 4.299814951035285, 1.321832864515243, 1.6879576829171952, 2.781627009953222, 5.694617629051209, 6.219609716246206, 15.31726246879947, 19.770000826927927, 29.4064151471661, 28.228301848134688, 29.671149638391313, 37.275844850847804, 39.15775491345314, 48.16720777942289, 25.699985181131673, 22.4452494805859, 14.766976487252021, 12.8860136770433, 24.1885410201165, 20.025719750312067, 20.991217051782918, 19.57376072483678, 15.407055327969214, 8.01040949360017, 4.7067250647852505, 3.9787343865440743, 1.571467701465853, 2.2218795361057406, 1.2117106058905203, 0.8590831535477793, 2.8084638666722084, 24.92386187276533, 56.883816488327525, 39.87053194353658, 33.688770647971864, 55.572685810827444, 63.95815626267464, 57.49931089339718, 59.861350444055375, 51.753775996546594, 68.97713092065626, 19.93444423521719, 30.2084162927443, 39.897439402918664, 34.26404114692442, 29.981440497982888, 33.27097938906762, 53.81660146097983, 52.1163873518667, 42.73976925880679, 53.409651633231874, 6.292818304031126, 0.12612054169538522, 0.18497977405786517, 0.043575261163735585, 0.04028335837046466, 0.05008169186992511, 0.07514996949823634, 0.044078707334495364, 0.058527462665111794, 0.006179406444707345, 0.032275176997626984, 0.07328849075542343, 0.03902414731020409, 0.029270696987007416, 0.058989685644666036, 0.03271180881007064, 0.051880087102613145, 0.03771244390537182, 0.08697210044990625, 0.09542947364670616, 0.03549537396118526, 0.0839538059587921, 0.05066599479065307, 0.07958056239952004, 0.039422528352588415, 0.05390014987619174, 0.14082928428486471, 0.06728586245087848, 0.11892509151009784, 0.03650942539435722, 0.09477163394612652, 0.07962033002366943, 0.033941433554695505, 0.04966700847651209, 0.024815832505062706, 0.10371657614145549, 0.048459994816972364, 0.2133715594367635, 1.1332516804818185, 49.68178003065048, 70.38048436564785, 52.06035237158499, 51.52226594186599, 39.01700850455992, 47.956199953632975, 33.20299686924104, 48.19756692455661, 26.993482843522106, 40.61041255151072, 83.37149989220404, 66.05951509168072, 67.16562348027384, 72.50107457560878, 77.19002492966192, 72.87972450256348, 71.70825373741889, 56.50293473274478, 56.096808602733, 49.66028936447636, 9.907068648645955, 0.12621215815024991, 1.6952740064551755, 3.366421513980435, 7.042422467662442, 7.372273206710816, 7.97719584357354, 7.7354611504462465, 6.230730616277264, 8.758753595813628, 10.537703402580755, 14.324544898925291, 13.991670012474062, 13.80694696980138, 10.576020056201566, 17.203666587029737, 36.03717996228126, 41.10768671958677, 51.222741988397416, 42.13579877730339, 24.800315057077718, 23.977978383341146, 18.194435719520815, 20.620290271697506, 14.163773809709857, 5.129849766531299, 8.005718338874079, 7.544948199102956, 16.32517137835103, 44.60482097441151, 65.00222059988207, 65.98599418517082, 61.65939631000642, 55.67100001919655, 50.8333408448004, 44.122330219514915, 47.64246917540028, 54.632768246435354, 53.37352268157467, 52.58116468306511, 50.94816038685461, 52.66424440568494, 48.551996215697265, 52.66649976853402, 60.68961774149249, 61.95085194803054, 60.27755314303983, 60.61710880648706, 62.71781652204452, 64.96306357845184, 61.80426905232092, 54.39473921252836, 52.51710845578102, 55.81722597922049, 57.25208782380628, 61.42424237343573, 59.008933113467315, 51.50318753334784, 46.89588523680165, 45.0791218203883, 41.22447921383766, 45.231239180411066, 59.50684662788146, 61.86472454378682, 58.081818165317664, 24.570479854460686, 4.9405350992756505, 2.0826165185820673, 1.6271261342110175, 3.0658049352707404, 7.14777684019458, 11.56786293752732, 18.986213207244873, 23.679333040791175, 29.48397021139822, 27.487711291159354, 28.98485056815609, 37.10325664089572, 44.48452188122658, 48.888900356908, 35.250572158444314, 15.844977171190324, 16.16220964539436, 15.497117850088305, 17.87302690167581, 23.365472824342792, 20.992585958973056, 20.847160162464267, 17.848759197419692, 12.452274061018421, 10.158468061877835, 11.771843837153527, 5.9282947932520225, 1.2830927174898887, 0.6515871360898018, 2.6353981081516515, 3.6389642184780495, 29.057124160951187, 65.004836820787, 45.93940350317186, 41.43338072684504, 60.266350853827696, 67.77308879360076, 67.27504976334112, 69.04854159201346, 57.21848095616987, 70.20000826927924, 24.955482059909453, 25.550558567047123, 48.89157149099535, 32.504687501538186, 31.085652420597693, 29.791254574252715, 58.148192513373594, 54.23307088113601, 48.521209532214755, 65.8220548014487, 10.885575471385833, 0.4847037071181882, 0.3254640889504264, 0.12164991303917863, 0.03230778169968436, 0.08532012377174632, 0.10397565175568867, 0.02820130144696563, 0.10757441106703013, 0.035268868575052875, 0.050219426817831495, 0.16167375529485364, 0.07924205878929746, 0.04107157091399835, 0.012017693088930703, 0.010569437384425152, 0.040130255698797204, 0.16971087563903103, 0.14976911667373874, 0.1108247995556843, 0.11845914917367122, 0.18053056522002145, 0.159978372074904, 0.24075852857241709, 0.1486331155343402, 0.1374764238754588, 0.29088857974256244, 0.27497907860144494, 0.19346758392789673, 0.29732675201469855, 0.2894603773470848, 0.34187550025601543, 0.22821339448132824, 0.09552574025527125, 0.05104274534049535, 0.31076571153056237, 0.1469845096430471, 0.34775461220452863, 0.843019086507059, 69.12438454166536, 85.02350807189943, 66.27420210069226, 68.93169418458017, 47.296127811554946, 71.761794090271, 57.725537515455684, 61.42276363988077, 26.76326324862819, 37.506723403930664, 92.34869910824685, 67.97094883457308, 75.86191038931571, 78.71800776450866, 85.43481565290882, 77.92728931673112, 79.71305816404282, 66.0867363406766, 64.06324832670151, 55.3095143841159, 12.548030884035173, 0.8907605214945732, 4.102060568909492, 4.396431753712316, 9.25725938812379, 9.112593550835888, 8.693311791266165, 12.062439495517362, 7.085351338309627, 8.307526092375479, 12.145699647165115, 16.436684362349972, 15.372610053708478, 15.838950449420562, 17.839218031975534, 30.029958255829353, 38.50494307856406, 48.512348897995494, 55.20026068533621, 53.195800089067035, 32.26728996922893, 30.826626939158288, 22.475624315200314, 27.73517950888603, 17.678818587333925, 8.055272583038576, 11.623091870738614, 8.618524939783159, 22.740186222137947, 51.98416033098775, 68.2966624536822, 68.5904715138097, 63.132085492534024, 58.10712137529927, 54.83011837928526, 49.16163059972948, 53.09271235619822, 61.82468106669765, 60.44235937057003, 56.60397891075381, 52.66316575388755, 53.38699994548675, 50.48410084939773, 55.661754992700395, 63.33125560514389, 61.57251581068962, 60.35611429522115, 58.29586582799112, 65.04067159468129, 62.59820776600992, 61.27070511541059, 54.73137663256738, 53.55974897261589, 54.185865156112186, 60.276317596435554, 67.69643783569336, 67.58752930548884, 62.615474039508456, 59.109553675497736, 59.33063022551998, 49.44371569541193, 49.28980188985025, 63.809784766166445, 62.393212933694166, 56.7976341709014, 21.93233290026265, 5.502926005471138, 3.747608478992216, 3.611189179843472, 5.406849018989071, 7.942186238304262, 12.188084779247163, 28.123619671790834, 32.8938768371459, 40.30743691229051, 37.19867221770748, 38.32277251828102, 47.36085868650868, 49.97390639397406, 54.8743470253483, 36.60717095098188, 28.740816385515277, 21.564722484157933, 21.27062709100785, 33.7602166206606, 27.467960196156657, 29.01126184771138, 25.766330111411314, 23.014836465158773, 12.090609958094936, 8.502294325059461, 8.761159969914345, 5.188684338523496, 3.6703824035583006, 2.3777792867152923, 4.193943315936673, 7.098868806515971, 33.614496646388886, 71.93343700901156, 49.46634384893602, 43.41046317931145, 66.40913947936028, 75.92180498184698, 68.01310646918513, 74.15530281682169, 60.701196578241166, 77.75776447788363, 21.47382155541451, 40.158402535223196, 52.11387311258624, 44.27689121615502, 41.45271408942438, 44.267826618686804, 68.7669389478622, 67.02266093223326, 56.78873039061024, 79.4665999566355, 18.696618733867524, 0.7745566279176743, 0.5057735152302251, 0.33712452938479764, 0.1709762996723575, 0.28955016285181046, 0.28862114334779404, 0.11337575743034964, 0.38412445254864236, 0.11286640855213327, 0.11232116079378514, 0.3052547507949414, 0.12006222645962432, 0.20570260562723686, 0.09458129174045979, 0.12446904765261758, 0.0924225249177506], [0.016079572660307732, 0.036344344937993635, 0.020394583961235422, 0.0709052831535378, 0.05392264987852785, 0.04236222988355064, 0.09972136632929887, 0.027857463949570255, 0.07306037275421043, 0.11678306370853417, 0.030486030361404827, 0.0405399058945477, 0.035589660232466076, 0.015412090785591113, 0.07286361839261747, 0.17816202054100652, 0.09837337333949343, 0.040917905167706554, 0.11386839793093743, 0.06036798507275601, 0.2526775696465085, 0.1284720945442396, 1.8170839476008571, 34.42456806859663, 47.65197700069797, 52.01895175441619, 80.95058948762956, 55.122378103194706, 51.62911130535988, 47.98782210196219, 35.270839045124674, 14.465552145434966, 64.27330301653954, 76.77963518327283, 71.75874248627694, 71.99556735254103, 70.50798493046915, 65.3166691718563, 71.38993770845475, 77.90060935481903, 59.914710367879565, 46.083072077843454, 12.140856500594849, 0.09965702260453856, 0.6796095904804046, 2.1998649883654813, 3.9182068215262507, 6.252216379488669, 4.283115460026649, 0.7196861625679079, 5.0408590320617925, 10.458214609853684, 15.707743244786418, 11.822554199926316, 12.843261803350142, 11.956302119839577, 14.360192379643841, 21.430761775662823, 35.86622345832087, 45.58285220976799, 50.0450268099385, 34.84444995080271, 20.47699628337737, 21.704900149376165, 13.553202959798998, 16.289688637179715, 5.022136578636785, 1.7446081075937518, 1.2769870580204072, 3.615176759419903, 22.572212680693596, 48.85605442908503, 64.0312417860954, 61.7109009527391, 55.23696622540874, 52.461406876963956, 44.7046374505566, 39.038103011346635, 40.59261675803892, 43.781299744882894, 46.07790631632651, 49.910536581470126, 45.3839135169983, 47.51722397342805, 49.30740156481343, 54.30056702706122, 59.91150186907861, 59.58103041495047, 61.850772673083895, 48.82791926783901, 60.846230137732725, 63.39540596931212, 57.68738069841939, 49.20445111490066, 49.389100613132605, 55.42293756238876, 56.81781476543796, 56.780681687016646, 43.988675455893244, 37.10524136020292, 36.25527943334272, 33.74881036819951, 27.833603543619958, 42.97801010070309, 55.146555592936856, 61.55740684078586, 49.90380579425443, 17.470401487042828, 9.677023599224707, 6.033470697941319, 1.6358431116227181, 3.171326989127744, 6.981736046652641, 7.834498545815868, 10.48773927073325, 15.347288212468548, 23.634672934009185, 27.585178267571237, 28.836900726441417, 32.608459688002064, 41.66521633824995, 42.472247923574145, 29.535163025702204, 10.440615915483045, 21.928292858985163, 13.739335113956084, 27.078172699097667, 20.9695420342107, 22.759878481588057, 24.96702951769675, 23.063381679596443, 18.641899708778627, 13.029064478412753, 7.281999857194963, 4.96506707322213, 0.3692991190379666, 2.6850317803121384, 5.236568143290858, 0.8898602762529928, 21.37519551861671, 59.60498040722263, 39.54692463720999, 53.13551325951853, 66.91488988937871, 60.87780521761987, 54.881470049581225, 57.93333684244464, 68.25645815941596, 56.860129294856904, 15.567959777770506, 36.582671826885594, 36.651144642983716, 35.28129216163389, 28.988686646184615, 43.970487425404215, 54.6596953176683, 60.740259462787265, 45.202539197860226, 53.36479933031144, 3.8271553718274642, 0.31623049248610774, 0.12889225546631122, 0.053336470042385405, 0.05370053034576197, 0.07149249720837801, 0.054586599130303635, 0.11685165922127425, 0.009109800486194511, 0.03498317140545096, 0.04235887058800267, 0.10340627222772568, 0.12204454791161323, 0.034972955622980674, 0.03895379745611741, 0.07446883306387933, 0.08316290444664418, 0.006379001556084522, 0.06189740300478955, 0.0439814065072325, 0.07300231095042921, 0.05410068105125139, 0.071007801039565, 0.07441519924830045, 0.07291058724325511, 0.010277388388321046, 0.10004510742522056, 0.02128561891074623, 0.1063727638534, 0.03480343185665627, 0.05319222717756226, 0.024488862348540176, 0.09867588613903332, 0.0852449322419782, 0.008471020095561062, 0.2011036419219548, 0.043828453222710284, 0.40559713097829975, 0.16919444044751508, 7.4865995107158545, 58.567917500772786, 62.556948354167325, 58.219611029471125, 65.3834161450786, 45.124433040618904, 32.215961833154005, 40.90267227542016, 37.68585412733017, 23.842544824846332, 69.88364558066093, 73.52528387500395, 81.99987842190652, 81.16884585349791, 78.47436581888508, 73.44931540950653, 73.8925353942379, 74.74676485984557, 61.98383123643937, 53.38881992524671, 12.823401862575164, 0.43395788979626476, 1.1104913921125474, 3.3650089704221298, 3.9635557945697544, 7.946632244894582, 7.791687836570125, 3.6091892613518626, 8.461928233023613, 12.970933971866486, 17.361428237730458, 15.16407528231221, 15.111503754892658, 14.99211367099516, 11.980980692371247, 24.234985805326893, 40.701913602890514, 51.73985550480505, 54.15321534679782, 35.673611548639116, 21.48680656186996, 24.04675518312762, 14.320335215137852, 17.48985055954226, 5.694612726088494, 1.3666390795861523, 2.947261347886055, 5.568283969356168, 21.320215655911355, 48.87967101989254, 65.91110044910063, 65.8293660994499, 59.48835657488916, 54.44078391598117, 49.66312523811094, 44.53861136590281, 48.73696734828334, 51.36546134948731, 54.843387757578206, 56.37273165487475, 50.6810587452304, 52.17631332335934, 50.521955643930745, 55.595969000170314, 63.277150430986964, 60.88969392161216, 66.09095681098201, 53.58747620736399, 63.3292708858367, 68.75241048874395, 60.7637309258984, 51.6980508835085, 51.71916500214608, 59.527964668889204, 62.56996277839907, 64.14911293214368, 56.68222235095117, 50.17116238993984, 47.86569126190678, 45.1072609040045, 39.17715495632541, 49.78086694594353, 61.70623333223405, 63.75141989800238, 54.101608722440666, 21.280809563975183, 11.073204009763657, 6.912839124279638, 4.74672882787643, 3.9874572475110335, 6.9344523645216425, 12.331200299724458, 15.2971887588501, 19.920394305259954, 27.539876853266072, 29.48472526765639, 31.417194681782878, 33.09071510068832, 44.54451061064198, 44.39359741826212, 33.415554031249016, 9.377488859238165, 17.627470839408137, 19.442253458884455, 15.848403361535842, 19.504326928046442, 21.69630623632862, 24.855363561261086, 23.71473047041124, 22.08639575589088, 18.092467823336204, 12.952566492942072, 9.934580153034581, 2.8953350503598494, 0.38163696505850364, 6.04339135269965, 1.5333000979115887, 24.717268674604355, 67.52023712281259, 45.22149993527321, 54.48574604526643, 69.03080463409424, 68.58071265682098, 67.0978056999945, 63.28998050382061, 70.54513762074133, 61.99195838743641, 20.018320198981993, 32.6344257785428, 40.331555566480084, 31.95705402281977, 29.007059028071744, 40.08057094389393, 64.93597176767165, 64.23516188898395, 49.064987321053785, 67.78460487242668, 6.623945774570589, 0.4849916948906837, 0.2450444381083212, 0.04305553179414522, 0.09465581677373379, 0.13548661774444964, 0.09044084697961809, 0.011512709954272837, 0.06471228966068837, 0.08372795557783497, 0.07662075106054544, 0.11361908993773884, 0.08295386203474577, 0.046967234192115646, 0.07957984993775045, 0.024101143334842017, 0.09322741519539587, 0.1615330555866803, 0.11068151813120612, 0.14077708305370423, 0.21613987943818494, 0.157611497467564, 0.1707352884113789, 0.2859452595153163, 0.16776341884847612, 0.1483815322600065, 0.23889187873611528, 0.3458010267105795, 0.1758604779118492, 0.17043919542864447, 0.21590033906602094, 0.2572541942279185, 0.3641226016465695, 0.2839914901602653, 0.11523548183181595, 0.3837772308578415, 0.2720537871843384, 0.44505988277735253, 0.25577071092782483, 12.183677996358565, 88.05512366756317, 76.8398121864565, 76.61673915001654, 93.27516294294789, 82.43249231769194, 66.7425880124492, 58.414576361256266, 45.31240086401663, 18.004520439332534, 76.08428524386498, 84.22103820308563, 83.54915972678893, 80.78000560883554, 83.69202813794537, 80.24675938390916, 81.99704647064209, 84.95925180373654, 69.45864892775013, 59.43066635439473, 15.200922027710947, 0.5010150366973493, 1.2778171296081235, 3.745846844488575, 7.564517884485184, 8.762946609527834, 7.783332207510549, 5.383865890964385, 9.69317493900176, 13.228457185529894, 22.6499540575089, 17.22128391265869, 17.18034613517023, 17.548662577905965, 25.081876516342167, 31.03109617387095, 45.54025919206681, 58.36198129961568, 60.79002257316344, 46.121652510858354, 28.07423899250646, 29.850839299540368, 21.053153237988873, 24.225460329363425, 11.018186884541667, 5.828573434583603, 4.555594671157099, 8.264050541385528, 25.62962570498067, 51.38431226053546, 67.05510677829866, 68.85970300243747, 60.604568989046165, 56.43215556298533, 53.84843149492818, 49.61940257780014, 55.95990611660866, 56.727839516055205, 59.19937987481395, 61.1207607484633, 54.76368519567675, 54.536815304909986, 51.98026541740664, 60.332242750352435, 61.28051104084138, 60.65191199702602, 66.12509712096184, 52.918857220680486, 64.18555959578484, 69.13856783220845, 61.08592225659279, 50.12669447929629, 52.08329823709304, 61.01066766246673, 65.13019184912405, 70.36564211691581, 62.79562457915276, 59.06054758256482, 58.2680993695413, 54.96193355129611, 47.89206527894544, 58.06616790833012, 63.488005284340154, 64.84561604838218, 55.809957827291186, 22.816246863334413, 13.145749107483896, 10.08723585836349, 6.046329207958714, 6.57529563673081, 11.568161037660415, 13.392994730703293, 20.684925048582016, 27.79317371306881, 33.62288659618747, 38.75060112245622, 38.19369908302061, 41.378153754818825, 51.04065379788799, 52.77062300712832, 39.336442409023164, 18.87691047883803, 30.343247767417665, 23.17035059775076, 38.89947860471664, 28.99807680037714, 32.237097524827526, 32.850679774438184, 28.157230461797408, 24.08056209164281, 19.353917760233728, 12.012462615966799, 8.505526358081449, 1.8615725732618764, 6.683255933946179, 8.977053107753877, 2.9809015556689236, 30.730815202959125, 71.95010708224389, 47.96992432686591, 60.19996866103142, 77.3004396500126, 71.67122656299223, 68.84004408313383, 65.40540887463477, 76.81582297048261, 67.10601914313533, 18.734463722475116, 47.7549627519423, 43.667680448101414, 44.33712705489128, 41.470784448808246, 58.91079933412614, 68.59495086054649, 73.03567794061476, 58.769323364380874, 82.2543147302443, 10.044169214464004, 0.8809400097497049, 0.3567666253976284, 0.16770150362243577, 0.29786485217271313, 0.2873646059343892, 0.13562503451060864, 0.26398289768445876, 0.19147146523239153, 0.18459821630629802, 0.14883036785308393, 0.15660318786338454, 0.25693177846410586, 0.14334481059303208, 0.15390069013641727, 0.1586870695914953, 0.2815248096181501], [0.07130174131523218, 0.05025662038655532, 0.03642887507955875, 0.0632564966086178, 0.06242986092524183, 0.009380182600580156, 0.03479354166155381, 0.09367264251434997, 0.036929287542138374, 0.019909954825115782, 0.09006799198687078, 0.10342766906345084, 0.13328754703604406, 0.03601309234997438, 0.14358514769663736, 0.03856669705841811, 0.09965264824249091, 0.10815107609115301, 0.019451550793864077, 0.22195873091057425, 0.022952279579194806, 0.1270196224833208, 1.36793615837251, 5.178172386461689, 46.022938220731675, 30.368631385987808, 115.89356545479068, 119.24519938807335, 53.08930381651848, 48.331519788311375, 57.13083559466947, 16.314382899192072, 38.274044913630334, 82.2522750977547, 56.790773945470015, 54.47437117176672, 62.067365953999186, 71.9592462047454, 64.71462849647769, 65.588858127594, 47.329452268538944, 53.53811710111557, 9.409382631701808, 0.09915462214379542, 0.12155579913768078, 2.2910296965029935, 4.007190201551684, 7.307317776064719, 3.614081192401148, 5.632706938251372, 14.499329636173865, 19.368958088659472, 21.977950065366684, 19.378926792452415, 19.580411103463945, 17.58649383821795, 16.053886528938047, 20.98301341456752, 38.15037258209721, 50.29669784730481, 48.38815096885928, 26.721903816346202, 25.316551923751835, 15.936927333954843, 15.199643335034771, 10.117493021872736, 2.7752842922364516, 3.460367672866391, 1.126660750277581, 2.2589407861232758, 22.631611093398064, 46.752836396617276, 60.056692323377064, 60.84167626596267, 57.26672610928936, 52.59649330569852, 47.05339585581134, 37.30646679478307, 40.36309926740585, 44.121102517650975, 45.019372355553415, 45.95350050157117, 45.977474028064364, 48.44230713382844, 53.644480013078265, 61.40186525160267, 61.28304881434287, 61.80954464020268, 52.64826074723275, 57.88578987121583, 63.856782605571134, 60.958421691771484, 57.15196932515791, 50.17775981656967, 54.236569635329715, 54.75965692150978, 56.56570834498252, 55.27215380822459, 42.62796994178526, 39.0818884295802, 39.35178279876709, 32.308098308501705, 32.58997355737994, 44.117768503004505, 56.76424303362447, 61.498190818294404, 49.10808240213702, 30.17251679974218, 24.177577995484878, 13.718059197548898, 3.925565923413923, 3.0516772933544654, 10.335267916802438, 10.973128657187186, 8.179376865586928, 12.22954619315363, 16.37638282391333, 23.335541217557846, 28.483106859268684, 28.316900345586962, 37.72707039310087, 38.598279799184496, 28.342105496314268, 13.150445165172702, 18.886143738223662, 13.74064616618618, 15.76361740789106, 28.775074366600286, 29.919151298461426, 32.7467801109437, 22.998919486999515, 21.734045320941558, 13.580886067882663, 15.84218248244255, 9.196298891498197, 3.8484077540136155, 2.4971473072805717, 8.428548862857204, 0.07873077170863267, 12.763631805296868, 57.162332227153165, 46.509680824895064, 57.67555867472003, 59.759031495740345, 52.411773204803474, 49.12300702064268, 65.80792642408802, 68.53768425603067, 37.72319901374079, 18.223153352737427, 52.33293356433992, 27.94117258441064, 35.975120221414876, 33.69123781881025, 60.677450549217966, 43.495582534420876, 67.03656181212395, 58.67002856346869, 28.17502429408412, 1.4674531860697655, 0.44830052662760983, 0.09937435148223754, 0.04023797149139066, 0.10642764639229545, 0.04896332990498312, 0.0906840569129394, 0.1059953659592617, 0.056503998461149396, 0.08670789970745964, 0.031475262461049903, 0.03296965868362496, 0.04375710745432204, 0.12649005654478265, 0.01983993630405636, 0.022679902763376315, 0.06683728732769528, 0.04727740404045871, 0.009052193547118335, 0.04835484541892525, 0.03662525788850842, 0.04053694496472036, 0.05155836081793232, 0.078133384006158, 0.09242378130194642, 0.03696638151943203, 0.04696972397786956, 0.06666958302019105, 0.0983819765068831, 0.07014627388167767, 0.10109930569606443, 0.09385451944845338, 0.119843500696363, 0.09301439678717045, 0.09896877687424423, 0.08536562939444858, 0.12938527901086117, 0.06714651871833109, 0.17031611574272956, 2.37264784593736, 16.834889265798754, 70.72525285905408, 40.74917031872658, 106.02776896569037, 114.07517033238565, 44.9575008884553, 36.06906883178219, 49.37925546400009, 22.96950367189223, 53.333451747894294, 80.95671622983872, 71.77510661463585, 57.93919686348208, 71.96986798317202, 75.89325012699251, 73.367949762652, 67.60373653904085, 55.2986611858491, 58.20986393959292, 11.3291072845459, 0.6434917930633791, 0.5322236507650345, 2.6078517927277476, 5.410676271684709, 10.787161242577339, 8.152309079324047, 7.742426299279737, 17.879738077040642, 20.282372197797223, 21.017255706171838, 21.042586372744655, 21.014111926478726, 17.903135015118508, 15.614276105357757, 26.535867760258338, 44.27189803892567, 54.50899785564792, 50.00865859370078, 28.46357345581055, 27.252323973563414, 16.709612684865153, 15.56712039055363, 12.665144032047642, 3.30042518434986, 4.895727413315927, 2.14805954887021, 2.357283921972398, 24.308296865032567, 49.6589518362476, 64.41114687150525, 63.72647754607662, 60.92839202573223, 56.95555271640901, 50.724573519922075, 45.18877952329574, 47.56229592907814, 53.13504649746803, 52.46173635605843, 54.00800135827834, 50.64146241834087, 51.41073334601618, 56.0510737665238, 63.19075630557153, 64.03022981459095, 64.71164357277655, 57.47880081976614, 58.771068819107555, 68.07806876397902, 62.0130568165933, 59.82331129812426, 50.69514789888936, 52.601623765883915, 60.21487366768622, 59.86459816655805, 63.68809323157034, 53.85876301796206, 49.23332368173907, 48.764584756666615, 44.4859496239693, 42.305217712156235, 54.04654648996169, 61.542188044517275, 63.417296717243815, 51.25077516801896, 29.15451465114471, 24.68409130650182, 14.574279266019023, 5.810333432689791, 2.929286596275145, 9.884670934369488, 14.700463875647515, 18.83088342605099, 20.11228842120017, 24.110330920065604, 28.59940121250768, 31.748415308613932, 33.63810931482623, 42.17044115066528, 41.27305776842179, 31.37367794590612, 12.952155624666522, 12.251682089221093, 16.982744970629295, 17.30244363507917, 24.466893980579993, 23.125237457213863, 27.98373030078027, 21.151885178781328, 19.727117553833995, 17.894866658795266, 22.350526202109553, 14.176705864167984, 8.88185816426431, 4.328171235899772, 9.235858936463634, 0.3032161601849141, 13.566156587293072, 66.9631193530175, 52.41066317404471, 59.17632810531124, 62.00028950168241, 57.66954960361604, 54.10076933522379, 69.64257670987037, 68.02295946305799, 48.2256510949904, 20.591288266643403, 40.77783499994586, 34.45407213703279, 34.59487738147859, 28.172553200875562, 60.111727099264826, 50.88161345451109, 75.64381876299458, 67.02870138229864, 45.85821044060492, 3.242797476630057, 0.25061438761411176, 0.13610662802332832, 0.12222176703113703, 0.0812212699243138, 0.06376029517982276, 0.05303096566950122, 0.09674152179110436, 0.16208067055671446, 0.09123220048364132, 0.037500429072327195, 0.014706413682189681, 0.033909782632103855, 0.059410317710811095, 0.08473424270989434, 0.004131231117137378, 0.030724316264592835, 0.19130424356027959, 0.15762744741814752, 0.18064218423058911, 0.16592728995507763, 0.26481125323522475, 0.09696001006710915, 0.15602140537192746, 0.18691327272643968, 0.16622554330575853, 0.14315880444501677, 0.249335955407831, 0.16724709090926956, 0.2668699766359022, 0.12956891028631118, 0.3106886430853798, 0.2665864628168845, 0.18744797145407047, 0.3293111067145102, 0.28997445298779395, 0.224611203096086, 0.19517805907995472, 0.18884353850397373, 2.096920422007961, 32.01364794085103, 92.67540116463938, 55.87923472927463, 128.40587923603675, 128.8351042039933, 76.60257154895415, 58.65835166746571, 73.6023662936303, 19.843345226780063, 51.51627256024269, 91.71228670304822, 71.01777538176506, 62.17482712961013, 75.91465057865267, 85.33244179141137, 80.27277254289197, 76.3848800043906, 59.3437623208569, 62.9807290723247, 12.317261176724589, 0.4486826819277579, 0.5107912992037112, 3.6481043215720885, 6.562651386184077, 11.014551827984473, 8.299277347903098, 9.775244651302215, 19.517655141891975, 24.70353057307582, 27.803446400550108, 25.226490382225286, 25.318328757439893, 24.275951039406564, 28.815131571985063, 32.355700192912934, 50.32433486753895, 61.838848667760054, 57.62636823038901, 35.90023825245519, 33.78802622518232, 23.61904621124268, 21.80193958743926, 18.182450917459306, 7.312485989063018, 6.286690581229426, 2.711615889303146, 4.262655886911577, 29.275790414502545, 47.751071760731364, 65.6752993214515, 65.38614219234836, 62.95473552519276, 59.400460181697724, 55.147771527690274, 49.09558573076802, 53.679028249556026, 60.20121597474622, 58.37341500866798, 58.90306442014633, 54.49840745618267, 53.37514262045584, 58.87316811469294, 66.54071146442045, 65.99663949781849, 63.69383558150261, 58.598225655094275, 59.5922052475714, 66.43772571317612, 64.11145425611927, 59.58044205942462, 53.20890080544257, 57.91338766774824, 62.08065494414299, 64.48253793101158, 68.00446156532534, 63.837115841527144, 59.683086564463956, 61.45659800498717, 54.28733687247, 49.765044104668405, 60.37042310160976, 63.43497091724027, 62.23771841295304, 50.70458119915378, 32.69649532533462, 29.413683299095403, 19.18314756885652, 9.690508707877129, 6.1993810726750285, 15.915372929265423, 15.637689713508854, 20.12476940308848, 27.69148038279626, 28.35494733625843, 32.93307504346294, 39.26769110464281, 38.07265081713277, 46.024981775591456, 48.202869969029585, 35.27217265098326, 21.982366654180712, 31.34469751388796, 21.456800430051743, 26.279374168765163, 39.10115903423679, 38.36017624024422, 42.36279026154549, 28.970345643258867, 27.898871783287298, 19.435412845303937, 25.29930526210416, 15.546596588626986, 7.231731741659104, 5.860947207097085, 14.213574182602668, 0.3982042292914083, 19.670429498918597, 69.87371413938462, 55.64283347898915, 62.142777442932136, 72.46574186509656, 63.02104319295576, 61.71969490666544, 73.27998668916764, 75.33996843522596, 43.852737872831284, 23.700451081798924, 57.95255253391882, 35.09779584023261, 42.975303665284194, 48.95387049644224, 75.0426684656451, 61.905936887187345, 79.62694644927979, 80.93104039469074, 54.53864705178046, 4.599384011760835, 0.572538445553472, 0.3010269566889732, 0.22867868564301924, 0.14912678259274653, 0.16538926640585547, 0.1463604850634452, 0.28276507532404316, 0.25471341766176686, 0.14840837598087328, 0.1426852088902266, 0.09846102911978961, 0.23737010636156608, 0.12163079914546783, 0.20687369359356744, 0.07983244444814422, 0.19961321786526712], [0.11866197095162447, 0.09947414209525432, 0.024389290070581823, 0.16234794331173744, 0.03663517489668824, 0.01979351329106477, 0.05484973884097511, 0.06817112301266001, 0.05458208304199, 0.0828674090124907, 0.06456200619258227, 0.027830279319577163, 0.10039954566426816, 0.11293044584172388, 0.09348187896032488, 0.04318779687427225, 0.07390748213736281, 0.17783640252967037, 0.07290435128755147, 0.1511621403117334, 0.056053251478700876, 0.20390047571591793, 0.46959179543679763, 6.6827229818990155, 48.56692867894327, 35.02303546474826, 53.449604895807084, 63.30734483657345, 42.01103210449219, 51.34478653630903, 56.44884524806854, 33.845732135157434, 20.778646161479337, 65.49587834265925, 66.88471901801326, 78.58546303164574, 56.10309616211922, 76.14032806888704, 69.08850269932901, 70.24826126713907, 46.559239972022276, 56.07337636332358, 6.081614359732598, 1.0718325116942007, 0.6044252312952473, 2.398569319517382, 1.7042653046308027, 5.436244731949222, 4.006589833767184, 12.54299456073392, 15.109820077496192, 25.666543053042506, 24.14315135248246, 22.312308588335593, 20.7048761844635, 21.241070070574363, 13.722625817022017, 23.989261081141812, 41.969172570013235, 49.32397750116164, 35.46220364109163, 24.65500104811884, 19.551228669381914, 11.218551358869, 18.241213906195856, 6.972647914963384, 7.655821346467541, 5.458796399254953, 2.4392602328331243, 2.2075606786435653, 20.675160308038038, 42.57286064086422, 60.285872490175315, 59.24458126867972, 58.730742931365974, 58.558076274010446, 48.451626685357866, 41.890140733411236, 39.80379281505462, 42.634324181464414, 43.358499619268606, 47.13250613981678, 46.255001329606586, 50.377812462468306, 53.357127174254394, 59.552338277139974, 58.492808034343106, 61.944227064809496, 61.2800128998295, 62.33472254968459, 56.69645270993633, 62.262480335850874, 57.18820418080976, 51.47315786730859, 53.27179993352583, 55.9667153512278, 61.486972839601584, 50.12310158821845, 43.05229586939658, 41.27744690064461, 38.168144841347974, 31.516210994412823, 36.33560957447175, 50.3732232893667, 58.668573364134765, 59.934726222868896, 47.07964043463431, 40.21849324626308, 32.927826912172385, 19.816906490633567, 8.080644924794475, 3.755798878208284, 9.738558723080544, 15.744223248574043, 8.892112220487288, 8.931340825173164, 16.16406982944858, 18.386145484062936, 26.663744872616185, 30.189057434758833, 33.32918344005462, 32.63876391995338, 22.151813045624767, 12.538454417259464, 13.74008232547391, 19.613221729955367, 11.883723562763585, 18.827363098821333, 25.71954211881084, 25.511782015523604, 28.06944193378572, 31.50923505906136, 25.635468075352332, 15.478360095331746, 11.106181336987405, 8.741756004671897, 3.230544727656149, 5.933994977704941, 0.2244279701863566, 2.115927247270461, 42.14424364028439, 55.44846826984037, 65.46325206756592, 61.14474996443718, 43.470483287688225, 74.23343643065422, 66.49887546416252, 56.102178327498905, 21.519299476377427, 31.408308552157497, 43.860151152456964, 24.75529605342496, 39.73868539256435, 52.11190800512991, 62.4904171113045, 59.691425523450306, 51.56252122694447, 43.23807893260833, 20.77017972546239, 0.8737401315762151, 0.20782787142501724, 0.15788030239843553, 0.06489569110976112, 0.042220281452060714, 0.08247532521284397, 0.038468063238167, 0.046858093475983034, 0.12540877706581546, 0.06916869206414109, 0.06111208244317001, 0.10073991852902597, 0.02630838437096006, 0.06541754254290173, 0.046192684826711496, 0.04677684985161309, 0.05776600574233359, 0.07801705355485601, 0.03535593829808697, 0.045214172212346915, 0.034949693363159895, 0.031402187249172604, 0.09511074276580926, 0.07343443050499886, 0.0043257374894775215, 0.059381761783433545, 0.0623732278754394, 0.0763482382641204, 0.11226242483263055, 0.13196583086204144, 0.08998117124241206, 0.05327868403025693, 0.0709791110468007, 0.06767241509571191, 0.18601779255174822, 0.0546267727810529, 0.19600154231152228, 0.07406691269528481, 0.15302445409038376, 0.610094098073821, 6.764903501156838, 77.52604653758388, 47.723203320657056, 72.75172187436011, 70.4696241501839, 46.60191535949708, 40.59017312142157, 48.82760155585505, 30.231977970369403, 30.179735922044326, 72.86680421521588, 73.77594686323597, 77.53357748831473, 66.9050996534286, 83.463346112159, 75.07573404619771, 80.10749170857092, 53.03535161479827, 62.2838141072181, 7.286446354081554, 2.307723549104506, 1.5964121371507647, 2.0775039542105893, 3.0838890229502036, 9.995338647596299, 7.743670671216904, 17.51695413743296, 20.53355097770691, 24.39098435063516, 22.119165197495494, 23.4930577201228, 20.51419996446179, 20.749489222803426, 15.78529046427819, 29.255986367502523, 44.35806466687111, 55.15778141637003, 39.91177958826865, 28.88434571604575, 23.886259640416792, 13.525538482973653, 17.936314344406128, 9.822405269069057, 7.945405033326919, 6.583678722381593, 2.8303828066395176, 1.5504984653765157, 21.288770014239898, 46.68845069023871, 63.151210969494244, 62.6385336537515, 59.90060944711009, 62.02906400926652, 53.91459795736498, 47.30030905815863, 45.87928533554078, 52.39264772784326, 53.784257596538914, 52.37755836979036, 50.09113427131407, 52.42974158256285, 59.5798929276005, 62.34561497165311, 63.087782321437714, 64.94351448551302, 61.559693582596324, 66.38008256112376, 61.914436663350756, 66.35357518349925, 60.780781469037464, 54.18757530950732, 57.30782862632506, 62.169822185270256, 63.45442195092479, 62.1034792161757, 52.939720307627034, 51.74480161359234, 48.45877324381183, 43.269183328074796, 42.73481530527915, 55.25727625816099, 61.455597800593225, 64.03496803775911, 52.87679372295257, 45.33766877266669, 35.03339444437335, 21.07356329118052, 8.184665201171752, 3.3795692987980384, 9.85854991020695, 19.773662359483783, 17.912227069177938, 19.828020526516823, 19.961965545531243, 22.566482097871845, 29.70378964178024, 33.00801192560504, 36.22445744852866, 35.87986153941001, 24.95380916903096, 15.491762834210551, 7.859855198091077, 16.37074931975334, 13.168621428551214, 21.30339457142738, 28.637648244057935, 22.6180749939334, 23.57300739134512, 22.23346894787204, 21.418472989912956, 17.518454444023874, 19.466428987441525, 14.981028072295652, 9.650449541307266, 6.616361381546144, 1.6854804610052418, 1.4598670770083706, 48.56705811715896, 60.43735050385999, 67.7636751051872, 64.87811288525982, 52.74295853030298, 73.22551281221452, 66.92289936927058, 58.88571969924435, 33.45709977611419, 21.286897082482618, 42.8882662711605, 32.20112939034739, 33.35660865229945, 42.895526578349454, 68.99708009535267, 68.9615826452932, 63.10197737909133, 59.3417932910304, 26.579713975229573, 0.929371536739411, 0.09937540868357306, 0.11256233293322787, 0.08915461599826814, 0.012722591655479084, 0.10494346595219067, 0.05733116657563275, 0.22290812835337656, 0.12699595802733976, 0.06979779580668097, 0.04324573227354596, 0.09241846465175191, 0.04783008668211199, 0.022286252313924414, 0.015274630671727563, 0.03162759521435345, 0.06359791518339226, 0.14959343739094275, 0.16061424037381528, 0.11885037495484276, 0.32593409921373095, 0.1658035054682724, 0.14588275263386388, 0.22418997731179963, 0.15286515376740886, 0.1845640641066336, 0.1114391254621648, 0.24370027555813714, 0.1306763210243756, 0.3913022367463958, 0.28008425788533303, 0.08530601243218107, 0.12463616973329937, 0.18480291499966578, 0.2955831358990362, 0.20116701271505127, 0.29151012219728967, 0.13850978455476223, 0.34181170045368137, 0.8469299347169938, 15.609830098767436, 100.43655580089938, 59.642062494831706, 85.76260812820928, 74.69961012563398, 64.97224584702523, 64.45422234073763, 69.59448845155778, 41.84917549933157, 27.87943840026856, 78.94260268057548, 77.85305453884986, 88.62161590207009, 68.64663985467726, 91.34930272256175, 84.9818132769677, 84.25466860494306, 60.8188323820791, 69.10076402848767, 10.048790747119535, 2.82235003767475, 2.4963380732843956, 4.274465162907878, 3.466860176094117, 10.98309834157267, 7.291947478248227, 19.678705699982185, 20.883377367450347, 34.08543994349818, 35.468875592754735, 30.807813290626775, 27.57665103481662, 32.19864653002831, 28.194532202136134, 33.95336981742613, 52.754502065720104, 58.7599685115199, 46.90954685211182, 33.69906294730402, 30.58152194946043, 21.86657632550886, 27.098657277322587, 13.512914334574054, 10.928196926270763, 9.937966139085832, 4.283070843065939, 6.527304947376252, 25.643522662501184, 46.13969541365101, 65.50591176556003, 59.85318799172679, 62.01091128010904, 64.27396981946885, 56.4952664990579, 52.53748909119637, 54.69592232857981, 58.26500854184551, 60.20309086768859, 58.15492330058929, 57.39152023869177, 54.699495607806796, 60.891207956498675, 63.290451188241285, 62.85270683227047, 65.68698406219482, 62.32967838164299, 62.460783604652654, 61.7295047544664, 67.92457072965561, 59.77412477616341, 55.51269315904187, 58.71006419581752, 62.74601836358348, 68.83427035424018, 65.771687646066, 63.984981352283114, 60.529832147782855, 60.588577485853634, 49.95666757706673, 50.454294758458296, 59.45236490618799, 61.435966337880785, 60.847014611767186, 53.51299039779171, 48.9896660466348, 37.624920106703236, 24.168115277444166, 13.8321638876392, 10.96267750186305, 14.47106699789724, 22.85929487597558, 16.631516333549254, 23.509033533834643, 30.046691086984453, 29.81744423989327, 35.17149325340025, 39.78665990214194, 43.42860021898824, 41.867657707583525, 29.75547471354085, 20.052584063622263, 26.572536037814235, 31.845015441217733, 21.004121649649836, 26.833648220185314, 38.379085986844956, 36.51940791837631, 36.72215131021316, 40.60478002794328, 36.37931654530187, 24.806773239566436, 17.652370045262, 13.992143638672369, 8.956591083157448, 11.865046216595559, 0.8627148393181063, 3.9387347909712025, 54.75418913748957, 61.668837455011186, 73.3882676401446, 67.89186600715884, 54.68547705681094, 83.15157259664228, 72.15430567341467, 64.22162186714911, 27.599185051456576, 37.801203189357636, 49.1389436106528, 30.137546908470895, 51.53768870138353, 66.02861465946322, 79.55148789190477, 70.90804315382435, 68.73534033375402, 69.35172511685279, 32.66699321808354, 0.7422747246680722, 0.2601299350780826, 0.2483662106697598, 0.11941893476872675, 0.09536753543802808, 0.18415177090754434, 0.18304629071104914, 0.26719685103143415, 0.202769668652646, 0.12270545196388999, 0.13070743951585986, 0.14979058245737709, 0.13003778673948782, 0.14054705749355978, 0.20380088428576149, 0.12668131805595853, 0.18554922253374131], [0.05039169317892483, 0.019160339706427148, 0.07156190477431783, 0.042435364467242075, 0.10428816200264039, 0.04899971142050721, 0.0690311179946988, 0.03939743514262861, 0.07670394820912231, 0.05700883125105212, 0.06443115837511516, 0.10164376438385057, 0.08260387476653823, 0.11971797718996964, 0.023089150762966564, 0.09621822245178685, 0.062450411233810656, 0.03581225473974501, 0.024148410959770123, 0.09966300575122719, 0.028901588164209843, 0.024054421547559962, 0.059913181654748425, 0.6191343645895682, 33.91853132555562, 53.307709232453384, 31.921978227553833, 75.28139960381293, 48.81609724413965, 46.16986628501646, 41.58903606476323, 49.44377453096452, 17.821788980114846, 37.77459775247882, 82.05077509726249, 68.86280167487361, 67.98456730381136, 70.85282402653849, 67.68288996911818, 58.4546119936051, 56.35210391013854, 42.52459979826405, 2.0934858966258267, 0.5429175640306165, 1.2851882437544486, 1.5361642861558547, 3.7231093548959304, 4.928581676175518, 7.974206016909692, 14.62658799463703, 23.45968423351165, 30.603853964036514, 18.042908676208988, 23.28849630971109, 24.58125460532404, 21.385032823008878, 15.841333289300243, 30.059046553027247, 40.22651057089529, 44.05289642272457, 30.355056062821422, 28.464018644825106, 16.271937950964897, 13.896105385595753, 12.683664483408775, 6.431957521746236, 6.931552752371758, 6.590044729171261, 4.924957406136298, 0.6468323041354457, 11.535269021987917, 37.906338399456395, 50.27200260469991, 55.014838480180316, 65.49618036516252, 61.756608332357104, 56.599974170807876, 46.074670360934356, 37.345106063350556, 43.7138428226594, 46.594717810230875, 45.012598422265825, 46.5491202569777, 50.45910358428956, 54.09725096917922, 59.177140035936915, 58.27242574384136, 60.01442486240018, 62.78583042083248, 55.995030941501746, 59.22191781382407, 62.177992482339185, 56.28239554743613, 48.964578567012666, 57.966500482251575, 61.51855576422907, 54.85369966876123, 48.320517539978034, 45.365968673459946, 41.943571259898526, 38.41032374289728, 36.48052154048797, 41.87662816816761, 49.028791689103656, 57.3441223175295, 53.874283836733916, 48.48620237842683, 42.2578864712869, 32.74675853790776, 21.64144208354335, 8.608125755863806, 3.7734318933179303, 10.400118424046426, 18.76801371574402, 18.106806047501102, 11.759544264885688, 17.591086933689734, 23.488513654278172, 21.232185902134066, 26.145621345889186, 28.706781979530092, 25.677415863160167, 20.088426682256884, 13.707338379275415, 13.699552474483369, 14.100016663151404, 17.33523072734956, 23.35935784924415, 19.317065131279733, 20.11102737918977, 20.807304959143362, 18.278535258385446, 29.649904120352964, 25.30556340371409, 13.75209556471917, 13.608493670340508, 6.254819362394272, 2.9510756077304965, 0.5199343134318629, 0.3905591314598438, 27.834662583566484, 51.76018514940816, 63.35664118489912, 76.72583595398935, 45.51803896504064, 57.24397636228993, 63.229870180929865, 39.17130278002831, 15.655970900289475, 33.52239155000256, 24.256227400995073, 34.96022655117896, 44.4461493338308, 67.79635629346295, 67.26002708558114, 54.80279514866491, 39.91943213247484, 35.05419477339714, 6.491776608651684, 0.40596595634856536, 0.1401147693996468, 0.047311471970451456, 0.05613045781970986, 0.09586792108753035, 0.10509331275017993, 0.09250167712208726, 0.07968474269634293, 0.053912246404516126, 0.035159927041780566, 0.056216347767340566, 0.03829614161663959, 0.015208395667404178, 0.036805077876535156, 0.039049428211705345, 0.0997644664359189, 0.02520438655459833, 0.02617124888685442, 0.013418345047431368, 0.06124794047566191, 0.012748764091802221, 0.040192672712427956, 0.04917247190831169, 0.05900259422619016, 0.029083830905297113, 0.03216844945845585, 0.07368039069396835, 0.12478612378359803, 0.05786276264717022, 0.056136264766175906, 0.04893143383425571, 0.056856896863469196, 0.1056741989187656, 0.06409314889160377, 0.0441851131167383, 0.02308126580300591, 0.10992807831855551, 0.18565468219739778, 0.12948001344357768, 0.20529408158073503, 3.9847782686833417, 67.00255486272997, 65.16296325191375, 48.75683415320612, 77.71175507576235, 46.26288137128277, 44.735479047221524, 40.67714775762251, 39.25385690504505, 20.323963049919378, 50.080708611396055, 85.22325869529479, 73.92381237399194, 68.711711975836, 77.94155105467766, 78.1295581017771, 64.97150844143283, 61.99883430234848, 48.75993282564225, 2.1231679426085566, 2.138694399787534, 1.2859466095124523, 2.909198912882036, 7.097127764455735, 11.19697440055109, 10.598548189286264, 16.381063192121445, 21.346279805706395, 26.896015867110226, 20.415468023669337, 23.81304075641017, 22.18167797211678, 18.58913794640572, 19.46492083611027, 33.92991012142551, 44.62616651288925, 47.144524282024754, 33.59957202788323, 32.27142610857564, 19.745458556759743, 14.107345611818376, 15.477339298494401, 9.994025634181115, 9.769128695611032, 7.097867621529487, 3.6826738859376604, 1.323799442860388, 13.476688304255086, 40.563316652851725, 56.38628736619027, 59.763561833289366, 69.2582550356465, 65.34163898037326, 61.40117491445234, 48.55790330517677, 45.139530243412146, 50.390952402545565, 54.29395783332087, 50.300071085653, 52.04137202232115, 54.30542684370472, 59.05124764288626, 60.608334464411584, 62.61046909516858, 64.86887570350402, 67.44534338674238, 60.50761584312686, 62.20189540616928, 64.2375780690101, 59.193064858836514, 51.38759528436969, 61.01013814249347, 61.30340983790737, 64.41452010985344, 55.88695003140358, 56.4381254103876, 50.81786317210044, 48.11680140033845, 42.89638557741719, 47.42227908103697, 50.92063319298529, 59.23127658905522, 60.111621195270175, 50.17515144040508, 47.44977881831508, 35.06706406993251, 24.77591203105065, 9.664265109646706, 3.6164326533194515, 11.731992556202798, 19.606781198132424, 23.85921685926376, 22.80588003896898, 23.088325992707286, 28.511377342285652, 23.52020052171523, 29.095604573526693, 31.56794509580059, 29.00025175463769, 21.328515391195975, 17.021758825548236, 11.508084054916136, 8.82727740272399, 16.653587510508878, 18.905422187620594, 21.145003380313998, 20.295300329885176, 22.734740011153683, 17.56363034248352, 30.52435536538401, 21.072196345175467, 19.241339852733, 18.951890507052024, 11.796228231922274, 5.473912233306516, 1.5508940118935801, 0.26592771913255414, 29.59831710784666, 57.95029324869956, 63.26561081794001, 74.43135138480895, 52.39852736073156, 62.857346996184326, 66.59868409556728, 47.18318708481328, 24.091511387978834, 23.680160660897535, 33.637175790725216, 37.731016297494214, 34.19358361151911, 64.20669332627328, 76.07711515119, 69.30840646066974, 55.49605054240073, 47.56766565384404, 10.193748800985276, 0.25515391821822814, 0.19065300753760725, 0.06171971657163194, 0.03509372172336425, 0.0874514340032493, 0.052867654876242724, 0.07691281442079814, 0.06255940256279803, 0.050473580317151163, 0.030224340472130046, 0.09343060469555278, 0.06829801781643784, 0.042705939061218695, 0.05282798684352348, 0.019534372559358037, 0.037425513334211805, 0.030687724074889577, 0.13334313437582987, 0.09905143010039484, 0.17528280165166626, 0.0857868628396142, 0.21719052306106015, 0.10787392080190683, 0.21350354106435854, 0.10707485279248607, 0.19352599047124389, 0.1844473582722487, 0.20225019975294992, 0.19505468828062858, 0.19008594925605482, 0.2369374811889664, 0.13980119429048032, 0.2096985202402838, 0.17105782674925943, 0.14528174133550736, 0.22667657613994616, 0.2520673346495436, 0.35574475603718914, 0.17156324559642425, 0.28038229673139514, 9.872800861635517, 91.87165260314943, 79.30694380114156, 59.48603845411732, 90.26065672597578, 68.93509095714938, 63.11544287589289, 53.83082789759482, 62.376582084163545, 22.167284834769465, 47.86213367216049, 93.0212208532518, 81.62483707551034, 78.69404992749615, 85.00544947962608, 84.45906331462245, 71.72828920425908, 65.70604285886212, 52.63372444337415, 3.600240864099995, 2.0822490415265484, 3.397629607108332, 3.6800015261096344, 6.111820042133332, 9.878087236035256, 13.564058119250884, 22.101993060881092, 30.82150628489833, 40.78912358130179, 28.077867184915853, 33.79700060813658, 32.62941887301783, 31.288097712301443, 29.597575779884096, 43.084447537699056, 52.400774878840295, 56.079926721511356, 43.881885005581765, 38.900431740668516, 29.33530845949727, 23.26938456104648, 20.700163456701464, 10.468608890810321, 9.8811908114341, 11.194415054013653, 8.227746063663114, 6.416966713243916, 15.140202756850952, 42.32467266821092, 53.65623535648469, 58.705494634566776, 69.4683450268161, 65.9824405177947, 64.4548773765564, 56.535670834202925, 50.117700484491166, 56.73951248968802, 62.54565192807106, 55.51770987049226, 56.741979660526404, 55.74268133409562, 61.02004997191891, 62.417496327430975, 61.01191105381135, 66.7350099932763, 64.91474782266926, 59.91565173672092, 64.20893692201184, 65.89332426747968, 58.762529819242424, 51.73500353290189, 63.00904074022847, 66.92475857273226, 66.71162482230895, 63.513853703775716, 68.25343008964293, 60.2965570265247, 57.84180441210347, 49.00727356633833, 51.77979700026974, 53.20532752621559, 58.5202528584388, 58.93538867273639, 50.88313925650812, 47.498557413778, 34.63923546575731, 29.849866551737634, 15.488722016734464, 10.42930478049863, 15.917707720110494, 27.009546910562825, 27.198716940418368, 23.010751316624305, 32.49823324141964, 35.91322522009573, 33.44139068357406, 34.714709712613015, 41.39592209169942, 34.334702645578695, 29.342051013823482, 18.96534815911324, 23.738168593375917, 24.30896955151712, 29.09434941507155, 31.649159731403476, 27.438691469930834, 27.010131343718502, 31.27101775138609, 25.8683725326292, 41.44810138210174, 39.81074325499996, 24.764064511945172, 20.040265860096103, 12.993195383779465, 8.296595427297778, 2.3444764027672433, 0.783423881136602, 39.01081508205783, 59.97363613497827, 71.41533113295033, 75.61877050707417, 53.95653593924738, 66.3009605100078, 72.80946700803696, 45.954496783594934, 24.621186294863303, 38.55273715911373, 28.49498183496537, 41.98696051874469, 61.85721320490684, 82.29089475447132, 81.37340530272454, 74.05056768848051, 63.530539466488754, 54.31907669190438, 8.794564835486874, 0.3677095785256355, 0.40098255440112085, 0.170732484529576, 0.17249433353783625, 0.20608987839471912, 0.24852950997169942, 0.2842195698570821, 0.15460769735997723, 0.15892406655175073, 0.08909612518524931, 0.25279922440888425, 0.2058037905202758, 0.1093089720234275, 0.16603469548206176, 0.09727130223426128, 0.18663279261560212, 0.2445389886176394], [0.048061479709201285, 0.04854411510149798, 0.04468945177992986, 0.018454916369650635, 0.048562934051357934, 0.07006864619231032, 0.05047839517975527, 0.09403643468695302, 0.05125988913219302, 0.007063246870999255, 0.03883688860843259, 0.034776251057102796, 0.13228205663542594, 0.12884252103826693, 0.04585454127781334, 0.04597018224998348, 0.05583654052668041, 0.08688606877600955, 0.1721257839592234, 0.1707824487839976, 0.07159778067181188, 0.11423110225868803, 0.1574358335065265, 0.6091686025742562, 15.478285570298473, 63.10006718481741, 41.33136772340344, 53.46719280365975, 77.33872198289441, 45.911903765893754, 35.25294519239856, 35.13829823463194, 22.78211439809492, 22.21003278609245, 64.06868865413051, 75.05627124540268, 74.23021224237259, 75.69513905432918, 69.30631191499772, 85.78440866162701, 69.29203448757049, 34.96927153679633, 2.129445205773077, 1.6721019917918791, 4.558077041179904, 3.966937367954562, 3.1740540169900466, 6.242214335549263, 14.9544059653436, 21.455453095897553, 25.9100418321548, 20.58151372017399, 18.158271466532064, 21.14659390141887, 27.968766458572883, 16.713266372680664, 16.44655010392589, 33.38357494723412, 38.89662704160137, 41.742400738500784, 29.493762408533406, 24.832753058402773, 12.49785396360582, 15.356513627113836, 6.742772017755817, 8.308973446969064, 11.104923236754633, 4.873886675603928, 8.032842018911916, 2.520185838783941, 4.811699948003215, 25.165454379973877, 39.67118924663913, 47.89241829226094, 56.97256011347617, 64.49031599106328, 58.32444421706661, 51.6494684065542, 40.65298595736104, 42.55011089386479, 46.86635763414445, 47.28712989437965, 49.99452237159976, 52.42120258269772, 53.88221486922234, 56.502938655114946, 55.69682490441107, 63.49724638846613, 57.35793298290622, 51.2178272585715, 62.15605466596542, 63.370353791021536, 53.08589527683874, 53.00326270441855, 60.20106692467967, 60.251681189383234, 55.96640940635435, 48.924429185928844, 48.031525150422134, 42.63875253738896, 38.40293007512247, 38.08374327998008, 44.337601661682136, 51.36688909223003, 57.76407088002851, 57.25295858998453, 40.99730337819746, 23.59162296018293, 23.423180695502992, 22.60180892482881, 9.044255075916167, 6.749513591489484, 12.830387603852058, 17.47637721800035, 22.373405387324674, 15.11991527772719, 18.219127039755545, 21.05297084777586, 26.44566893577576, 19.616320402391498, 28.044338764682895, 19.39714227953265, 23.29670386929666, 13.361782470057088, 14.698134968357703, 16.321857956147966, 13.933584613184776, 22.88006970959325, 22.742127795373243, 25.76896006061185, 21.300858759110977, 27.75363426054678, 19.846810640827304, 16.213240661928733, 26.653419233137562, 18.437885469005955, 13.07316662803773, 3.4224663001875726, 3.091961015616694, 0.2317105092468762, 10.196176748121939, 54.587927710625436, 55.104464638617735, 64.84903243280226, 66.79427700657999, 55.874139570420795, 68.62900487838253, 26.56972565958577, 17.680817034936723, 19.73221859624309, 18.885769151872207, 42.109373769452496, 60.2863706311872, 68.92475158937516, 55.9812085090145, 42.402112022522964, 58.15553911270634, 23.815390256143388, 0.7769843911932361, 0.12244772466440355, 0.04158169354101823, 0.07491313341644502, 0.036732521689226555, 0.05208598855402201, 0.07190236190874731, 0.10973298636775826, 0.009939770567260925, 0.02843473226793351, 0.07205550288481098, 0.028654965309185848, 0.06364749256341208, 0.07327529872136732, 0.05772305885329843, 0.026307373134900006, 0.050906044611286734, 0.016719464836041295, 0.029639865181619124, 0.06281186683824466, 0.0405953859820241, 0.05842057807791618, 0.05499033895771831, 0.03906949205444225, 0.06181781796077567, 0.051863662177516576, 0.054879328987050446, 0.07197419031252784, 0.11622783382453265, 0.02909385325056651, 0.07370041623230904, 0.11717333187980038, 0.0219855398210066, 0.0685056736091933, 0.05470177661927958, 0.06786375321568021, 0.2711684959790399, 0.25692296845297663, 0.1290528274952404, 0.08357806281457025, 0.23039532014198844, 0.9970199809439722, 33.27903593740156, 82.64328049075219, 47.88643667774816, 74.31724179175593, 76.3476017982729, 36.70152356547695, 40.45448657005064, 33.970275232868815, 25.13451668523973, 32.65190582121573, 71.53569298405802, 83.05741217828567, 77.65241745979556, 81.98061958436044, 74.21143977872788, 88.08595349711757, 72.12261292242235, 41.8549100045235, 2.4812009113450206, 1.8741934121616426, 5.521882820513941, 4.627388263902357, 8.806218197268825, 10.873452405775748, 12.449983396837789, 18.717536733996486, 24.157450352945638, 23.033130399642452, 19.383894474275653, 18.94504204873116, 24.42980600941566, 13.04181218147278, 18.760543561750843, 37.50551139154742, 44.888031790333415, 40.67819110808834, 32.8712918296937, 29.16400678696171, 15.578030463187927, 17.15482327245897, 14.77758453738305, 11.643324436679965, 14.075415557430638, 8.737838537462297, 6.250718524379115, 4.38799669665675, 6.980821153809948, 28.02861398266208, 44.96922877527053, 55.13283906444427, 64.42127443129017, 66.53145467081379, 63.18225652940812, 53.8519420162324, 46.76659214881159, 49.08970217550955, 53.77516946484966, 52.6473468349826, 52.55408071702527, 55.126249482554776, 59.87829116082961, 59.559782935727036, 59.831379613568714, 67.40207964374174, 61.723158359527595, 55.93740740130025, 65.88188663605722, 65.201551529669, 57.0428176080027, 54.34428184263168, 63.09709795059697, 62.918841915745894, 62.64916719928865, 59.30144779143795, 57.402581322577696, 52.59332010822912, 47.11418082637172, 45.05395197099255, 49.826209545135505, 53.165637062441924, 60.360593641957934, 57.84341258387412, 55.85892861889255, 36.7223435063516, 33.1399957595333, 24.24173228202328, 9.242005290523652, 5.758077165772838, 16.342526885770983, 17.744812465483143, 26.252972695135302, 23.78991642305928, 23.68962141775316, 24.06051681887719, 26.761064760146606, 23.644755386537124, 29.1303587344385, 24.177154379506266, 23.594515708185014, 16.483033049491144, 17.109996464944658, 9.547021542826007, 15.731856996013274, 16.358573302145928, 20.81698929109881, 23.076252937316898, 19.215007020581155, 26.602206806982718, 25.2866615018537, 20.570603647539695, 20.747161296106157, 21.416972683322047, 16.40782356262207, 7.4820588769451275, 1.885367019041892, 0.2465393667620036, 11.000163593599874, 60.0726406804977, 56.248992643048695, 67.63783762531897, 66.4224676932058, 64.59648278451735, 71.34250056359076, 34.12676995800388, 19.722446010958766, 21.669887112032985, 25.38638580229975, 34.78747752404983, 52.645303280122825, 77.75662699053365, 68.52129659345074, 53.05465359841624, 67.47309023334135, 32.972541932136785, 0.9419465942248222, 0.16756854140229765, 0.061092003278674624, 0.04803915590708775, 0.033124887249282295, 0.054057113630997564, 0.04741284455503187, 0.10826212819665672, 0.01877068632072018, 0.09261128132141407, 0.0785631133664039, 0.06148961057225543, 0.07877695148870831, 0.02677838697338537, 0.006592496375237862, 0.04784586426291255, 0.015043980749924819, 0.06355495297259862, 0.07933992652162429, 0.10884253172985009, 0.15199726807975, 0.14119273171790186, 0.21436531337038164, 0.1281540301598368, 0.10090286543052043, 0.13687659235250565, 0.10713257751758061, 0.1978654035877797, 0.29486267617152584, 0.16281672783436316, 0.13302084118608506, 0.2469058632249794, 0.14107222608741254, 0.1240411798860277, 0.1411257143462858, 0.37148455338132, 0.34192189454070987, 0.22138657048344615, 0.15898719219671142, 0.13306184221179257, 0.26922686145670954, 1.1151972557267835, 48.74927574588407, 98.03314701203378, 64.26817647872433, 76.9548317693895, 93.62372829068093, 65.59240787259995, 45.911205584003085, 47.03622764156711, 28.020124012424102, 31.526977900535833, 74.01230888981974, 89.00913038561421, 85.04061745059106, 88.24077729255923, 83.00398949653872, 98.70708081030078, 78.175991119877, 47.75483723609678, 3.341949111030948, 3.5566226368950264, 8.254679999043866, 6.050378074569087, 7.063541979559007, 11.334469164571455, 22.793110762873006, 33.35250585309921, 37.4591411313703, 29.221181215778476, 26.538658526635942, 31.29802719239266, 35.57805084413098, 29.513921430034024, 28.951351565699426, 44.40402700055031, 52.00005377492597, 53.468785285949714, 43.23672571489888, 37.99375234111663, 25.508500952874464, 27.501692579638576, 16.062589287757874, 11.610300041014149, 15.448215699964955, 7.906535815808081, 13.374994973982535, 8.03448990468056, 8.917917493850954, 30.68825944777458, 45.4265026123293, 55.14427669586674, 61.03400576499201, 65.58532799443891, 64.00667990407636, 58.227279263158, 51.86681478254257, 55.842046737670906, 61.133724181882805, 57.67977914502544, 58.30442836207729, 59.12951853967483, 60.32494714183193, 61.909282668944336, 59.605870785251746, 68.51405589811264, 61.262801539513376, 54.85446453094483, 68.36284852796986, 67.1837369857296, 55.88359640490625, 55.39182139981178, 63.68258622384841, 67.27549691354075, 67.29380653750512, 61.765123798001206, 66.08639117210143, 63.666606487766394, 51.279757561222205, 48.73169960514192, 52.912353930934785, 60.11562593521611, 61.28817535215809, 59.63457076780258, 55.76238339947116, 39.3849778175354, 35.108441152880275, 26.650034227678855, 16.93199146178461, 14.622918617340828, 18.170907382042177, 25.636023090731715, 32.86479834587344, 21.450024535579068, 31.17094632117979, 31.326411424144624, 38.29293112601004, 31.110486907343713, 38.42884125248079, 28.771622680848647, 29.584426033881407, 20.05466880336885, 21.083951688581898, 28.849713148609286, 24.82646353783146, 33.35302360596196, 34.26118958380915, 34.167884242150095, 28.888607371237974, 36.0765056456289, 27.979013650648056, 28.124957200019594, 39.15033771145729, 27.731931786383353, 18.40568280989124, 7.962392818543219, 8.481368480190154, 0.341873845506099, 14.528657197952272, 65.44809210684993, 63.01140592944238, 73.2072816356536, 73.17085850623347, 67.07376941557854, 77.05267137096774, 32.0390845114185, 26.071119846836215, 21.374734640121464, 21.64286002036064, 56.572431287457874, 77.86157392686414, 83.26223834868401, 72.25791900388657, 64.02514250047746, 76.44163670078402, 37.231114141402706, 1.024077716133287, 0.43646805348896217, 0.2665450021384224, 0.18438289963429977, 0.1560969416412615, 0.09506558188267293, 0.1767314126294467, 0.30804095128851555, 0.10091969638221687, 0.22409847577012357, 0.1451772469426355, 0.14137245594493805, 0.12186018119175589, 0.10064830207416128, 0.10958436531044784, 0.11185719496420315, 0.095978498218521, 0.17559608564742152], [0.015382014173683862, 0.03646431430693596, 0.05759427564278726, 0.12172610814412757, 0.08484399246592676, 0.01992997078735742, 0.1427321547582265, 0.03356813423095211, 0.011582381820546524, 0.03459214863757934, 0.09071682249346087, 0.15050750285867723, 0.04735956697033779, 0.08999463906812091, 0.05314941435391384, 0.10036785260684068, 0.017781291427391193, 0.032539634379528226, 0.14231252243682263, 0.15626771796134212, 0.08349140294857564, 0.06182188971809322, 0.30034069512640277, 0.34520038313442664, 6.11968243314374, 63.27906062526088, 58.46638302649222, 48.80006651724539, 64.0134616821043, 66.34191789934712, 34.79574195800289, 24.125408511007986, 22.42817932559598, 21.76615776554231, 57.16479155325121, 71.12113768054594, 70.35742867377498, 70.44565062369071, 79.89870394429853, 82.28611730760144, 70.70211871977776, 37.43324564349267, 0.7173062031788211, 1.681774924359014, 6.024151146411897, 4.2317221145476065, 8.444176566216255, 19.33553949479134, 20.071385945043257, 13.23743352966924, 18.364441048714426, 24.632631771026123, 20.51386264062697, 18.16949336759506, 24.95865917974903, 14.78831712276705, 23.283795349059567, 31.116244946756673, 41.3073157495068, 31.60481929779053, 24.381994278200214, 16.297608883150165, 16.69710816875581, 14.510562323754835, 7.139094673818158, 14.448969344938956, 16.570184192349835, 5.611481522360156, 6.298038978730479, 3.1585415332548084, 1.3275947037243074, 7.964086792161388, 25.9663043099065, 32.118222252015144, 41.9908122862539, 59.62734968431535, 64.47986679692423, 56.74778084601126, 49.201548560973144, 42.56632204978697, 46.69263585921257, 49.14502720679007, 50.26667994837607, 52.15865481284357, 53.784881253396314, 53.57492070044241, 56.17935096063922, 62.37393056192706, 51.95734308611963, 45.50436558261995, 67.3285508924915, 59.98508945588143, 57.99534167012861, 54.58644113233013, 62.63172441913236, 61.43512302829374, 60.97255399150234, 53.078850700009255, 49.71610861439859, 44.81848816717825, 38.138444654403195, 43.238945776416415, 48.787777731495524, 41.671515664746686, 51.76200512916812, 43.54460039446431, 22.290639454318633, 9.185593762705404, 9.955649164415176, 11.382087719055916, 5.593082664474364, 10.58048665523529, 16.455172454157186, 16.134459857017763, 24.366698995713268, 19.61938181231099, 19.614723997731364, 23.29886901763178, 22.2146592217107, 22.957954252919844, 19.416587429661906, 21.601904592206402, 18.581126505328765, 20.96127367788746, 12.31581578331609, 14.318615255817292, 11.609852890814505, 15.611758924299671, 19.100160021935743, 22.300312019163563, 26.981631402046453, 26.381689194710027, 32.351783706295876, 19.532893550011423, 24.73739435595851, 21.361053412960423, 13.339793662871084, 7.8071498197893945, 2.58252406793256, 0.627486132566006, 1.9173793206291816, 42.77737302164878, 49.93131337627288, 50.78730398608793, 67.11969252555602, 50.34700224476476, 68.3182119554089, 30.275122081079793, 15.484680994864434, 18.748582293910367, 29.90267146018244, 53.335554138306655, 67.868606352037, 44.020638850427446, 40.300482549975, 50.07951621086367, 47.522048488740005, 1.6188310567409763, 0.08979862015093527, 0.03776692807854664, 0.016521524953385516, 0.05380532734336392, 0.09598683325513717, 0.04985538566665304, 0.08789524405954346, 0.16144547641517656, 0.02517903478996408, 0.03574267863446186, 0.016742146784259428, 0.06967859252566291, 0.03568977643285067, 0.03824368757646411, 0.057902909484842134, 0.05997198273337657, 0.07770743912025806, 0.031062241478432572, 0.10986220241794664, 0.02815304748383501, 0.07083798232938975, 0.03495606338425029, 0.060476892132071726, 0.02774551743641496, 0.16085471537324691, 0.028900287729958375, 0.045797617114599676, 0.09977810280097109, 0.0968673287500297, 0.03989942191589264, 0.13164825677391023, 0.08234881345302829, 0.05522705246544173, 0.0859177106570813, 0.08638595891816002, 0.0779262568140703, 0.13632848708619996, 0.2013194488902246, 0.1329044111433529, 0.12249813324982121, 0.18924760391875622, 0.6105707886238253, 12.824459921929146, 81.96449864295222, 68.0093566833004, 54.050053088895744, 73.25416180395311, 46.90531069232572, 36.086441009275376, 31.632758340527936, 23.87249408229705, 33.81549850586922, 65.28520391833398, 79.51831248498733, 77.00576766844719, 77.76823720624371, 85.91130518144178, 88.07962279165946, 79.8297800556306, 44.83479738235474, 1.1625656365386903, 2.1759532392024994, 6.2981208582078265, 8.236033051244675, 13.316004487775988, 20.7613092853177, 19.46437562665632, 17.481772438172374, 19.570946424238144, 21.541182379568777, 19.71309704165305, 19.31999514179845, 19.689031339460804, 12.189611561836736, 26.630959741530884, 37.548010272364465, 44.52542043501332, 37.118404834501206, 27.264995190405077, 22.923629591541907, 18.720641289987874, 22.50116090620718, 14.210647113861578, 17.413531041914418, 19.39361018519248, 9.985531741572965, 10.571652497014693, 3.069171309471131, 0.507574986305929, 10.897874063061131, 31.18298015286846, 41.49700157104, 51.722644144488925, 65.50858289964738, 67.6879027581984, 60.63934864536409, 50.69226887918288, 50.69075876666654, 53.14946120785129, 53.688285043162686, 53.997018721795854, 57.568634863822695, 56.972352227857044, 55.44397715599307, 59.713410408266135, 65.40313389993483, 57.55271788566344, 49.4261944678522, 70.18777047434162, 63.319311987969186, 58.35493280041603, 57.40417380486765, 64.82089727155625, 63.827521724085656, 64.06302082923152, 57.25039728226201, 58.30704458298222, 53.77726401052168, 49.61758259804019, 47.277912324474705, 59.01051382864676, 53.760774366317264, 54.76445398023052, 49.790374771241225, 26.91369398947685, 15.128111070202245, 16.68032434678847, 17.612399132021014, 5.30746155208157, 9.225196953742735, 17.263584713782034, 16.98272731996352, 25.028169462757727, 26.73554385862043, 26.16948896838773, 24.57983078495149, 26.606546909578388, 22.843881922383463, 23.092836718405447, 24.388885882592973, 22.34362086942119, 22.16742604009567, 16.957528052791474, 13.7034228732509, 11.191809619626692, 15.955900819070878, 15.55388141062952, 21.152500990898382, 25.800274302882535, 26.972755078346502, 31.250813622628492, 21.327324951848677, 20.519200986431493, 22.566325203064952, 14.218985092255378, 12.741385102272035, 4.452052923940844, 0.6211727100514597, 1.4525263612308812, 45.488680024300855, 55.029586592028224, 58.05235332058322, 67.38257761924498, 51.926454421012636, 72.58425235748291, 34.815204758797925, 23.80884578151088, 19.34359015957002, 30.181426463588593, 41.64757351721487, 66.56672462340325, 54.34998104649206, 49.77532071451987, 60.60750292193506, 63.101306653791866, 3.3205300281124734, 0.18140510055086306, 0.04519548349743409, 0.10318256689295655, 0.034329820980107596, 0.03268159430233702, 0.08667394669065553, 0.03507410221162342, 0.22489433387114158, 0.037566550121071844, 0.018307695338021845, 0.010943567913566387, 0.09507633775712983, 0.035909406179862643, 0.045228601478400736, 0.0566971637008171, 0.026911852896333705, 0.06041145290157968, 0.035259434202265356, 0.2773760757859676, 0.18321066253608276, 0.16702719303148408, 0.16313909763290038, 0.1463364299026228, 0.08707386756976766, 0.26198221310492487, 0.16420958293301446, 0.07866551633924246, 0.3251737416271241, 0.23791242000316423, 0.20332442356213448, 0.22996151519398536, 0.35058408134406616, 0.09727081193798974, 0.1485525230847059, 0.2629632040137245, 0.1991338153640109, 0.2921518893732179, 0.28263946754797814, 0.4407641826377761, 0.1827464898627612, 0.3224724849625942, 0.8427428045580465, 21.306259862838253, 103.87459170433783, 79.59854848923223, 69.21419112913071, 79.26728863869944, 90.31861366764193, 47.49459974227413, 38.16056682217506, 28.320383410299982, 29.43262246347243, 71.09088836177703, 85.74680097641485, 85.09816646575929, 84.2926214587304, 91.17313338864236, 93.88265179049586, 84.15135337460427, 46.0438052300484, 2.191577510487649, 6.605333637806678, 8.931143726072005, 7.968191552546717, 14.57736421015955, 27.754022575193837, 31.278493788934526, 20.212687369315855, 29.55057401810923, 33.03252673918201, 31.057317218472882, 29.679110088656028, 37.219009707050944, 28.727854913280858, 37.442125889562796, 45.13435271478469, 52.68953192618586, 42.82503766398276, 36.007781797839755, 30.834765857265843, 29.749291096964193, 27.907157790276315, 14.562251317885615, 21.29497128148233, 21.239920816113873, 8.152496372499774, 12.889714433300881, 7.580799152774196, 3.900110476439999, 12.369830742959055, 30.418727897828628, 44.18901835718463, 51.445826791947894, 62.993127684439386, 67.13347573434153, 65.6713612617985, 55.269227720076046, 51.88288865550872, 58.32373034569525, 59.25787025882352, 56.67112596573369, 59.181438953645774, 58.94631247366629, 55.799849879357126, 58.37507417125087, 65.58900325529038, 58.10286168129214, 52.44019469907207, 69.43334179539835, 64.04870417810255, 60.49164002941501, 58.37971433516472, 66.9609385152017, 66.20312875316989, 68.1232701578448, 62.6727367216541, 66.33467720400903, 59.82366823380994, 51.71304610467727, 54.716452014061716, 62.995092791895715, 58.08283013682212, 57.62903151973602, 51.80196623648367, 37.15765991518575, 27.07931018644764, 23.107963338974987, 21.992431456042876, 13.181820204181056, 16.36927058619838, 22.9362968860134, 21.055055587522446, 35.727045997496575, 27.243171122766313, 29.07825985262471, 36.741700403151974, 34.22812008088635, 33.08862839975665, 26.88844177030748, 31.094267906681186, 23.962026103850334, 29.501738548278812, 18.277856688345633, 26.053447608024847, 23.538123792217625, 26.778205517799627, 29.6136986824774, 34.70475081474551, 37.15870718802176, 37.798245722247714, 42.80132693629111, 26.84366399242032, 36.868526320303644, 31.297621227079826, 19.341801558771444, 13.80972694966101, 9.279632587586681, 0.7898395917107983, 2.5570919100315344, 54.19032881336828, 58.64314463830764, 63.311557462138516, 75.41819618594262, 58.45037191144882, 75.27645741739582, 38.29770465050974, 21.52233931326097, 18.80792775461751, 39.87670967655797, 68.48642672261884, 85.01341973581623, 60.091977965447214, 59.01416555527718, 70.1170030716927, 72.43775967628726, 4.087581384566523, 0.28357945743107027, 0.14616645031398343, 0.20460212032400793, 0.21236951643180466, 0.22987191355036152, 0.16517034912061307, 0.16863812271866108, 0.29814536292706767, 0.11994792614132167, 0.19181068896526293, 0.15205630281519505, 0.2213472088858966, 0.13518347675281187, 0.11032828265019964, 0.18604509592536958, 0.11389443725948373, 0.15400890771660114, 0.11507482553321509], [0.03717113383895448, 0.054609225537147255, 0.04909587460720251, 0.07732840179796181, 0.029255559089623635, 0.06750314796884214, 0.08306206429317113, 0.07278894014175862, 0.08965099500792642, 0.04310687883727012, 0.11944537246299368, 0.02494323101165074, 0.04345355660564477, 0.05945394258765925, 0.1566047966480255, 0.1604721923508952, 0.06969947608247881, 0.017564155296572757, 0.0395844065614285, 0.10315539375428232, 0.05774479659814989, 0.04656230692841834, 0.09338678446628394, 0.11834671810990381, 1.1262895960000254, 54.963282846635394, 67.54035103705623, 72.5115551487092, 74.18763099178192, 65.81246852874756, 60.385783103204545, 22.915304360851167, 28.779459576452936, 22.866774835894187, 45.157180909187566, 79.63681513263334, 71.6296886628674, 67.70726357736896, 70.52154064178467, 68.38543353542205, 55.13317638827909, 22.778766655152847, 0.5212019744419283, 7.110173567648857, 5.279030742183809, 6.782175658210632, 14.875894823381978, 19.269555422567553, 15.211709526277359, 24.15093137371925, 22.022943573613322, 18.567423705131777, 16.846156274118734, 21.03901113233259, 18.83228175101742, 11.992951766137155, 22.314042275951756, 36.56842970078991, 39.50585742150584, 27.300345551583078, 21.141334003017796, 11.763677462454766, 19.364923930937245, 10.528903565099164, 13.51872826776197, 20.217476583296254, 17.396045115686235, 14.255149345244131, 8.16946013319877, 7.81921552073571, 2.6351112848328007, 1.5267144383922702, 10.541725793192464, 17.048379951907744, 23.37899127314168, 50.00821144350114, 66.17028282534692, 58.24783640523111, 52.45695890918855, 45.066617304278964, 45.53280276636924, 50.03660548117853, 51.585188604170284, 53.41199721059492, 52.85894301629836, 54.83973995331795, 56.747074819380245, 62.419508503329375, 49.78172202264109, 46.71261641287035, 66.58228074350666, 57.11561287603071, 58.69226055760538, 53.63721970588931, 65.48362093587076, 65.46566824759206, 60.92025702999484, 60.8444336921938, 51.686468124389656, 44.91117769672025, 39.479044099007886, 48.557667962966434, 41.816596292680316, 49.311959358953665, 53.753733711857954, 30.987618661695915, 17.082212355829057, 11.400316934431753, 5.333657591573654, 3.693338320139916, 2.233896697721174, 18.526803639627275, 21.227739895543746, 16.05168607927138, 25.090899928923577, 24.31329788700227, 13.920705510723977, 20.02795942368046, 20.836528578112205, 24.129958460407874, 16.47860077119643, 19.580324811320153, 17.687614502445346, 17.81568184975655, 15.661063117365684, 14.63205970102741, 12.652243356550894, 7.866537445975889, 18.11149916341228, 14.39658707188022, 21.351798580538844, 22.808680611272013, 32.10771029995334, 24.086563318006455, 20.863771400144024, 19.559985360791607, 15.525885493524614, 17.503961286237164, 5.068865245388401, 0.2803589157279461, 0.24141741015257376, 23.608071419500536, 53.84230475271902, 39.63521326741865, 60.33813807272143, 53.31609525988179, 69.47263609978461, 28.893971212448616, 20.2412304570598, 38.20790983015491, 38.31755968832201, 61.07432773036342, 57.961475926060835, 32.0073329248736, 40.409140048488496, 58.72581643442954, 10.441199368046178, 0.33990408023518903, 0.23781324226048686, 0.05255294978738793, 0.07446729322715152, 0.04759349574845645, 0.04302358209726311, 0.05666187769102474, 0.03325527924443445, 0.011978555572099023, 0.054636888972093026, 0.008051207743494982, 0.02740144245176306, 0.06143320734883028, 0.04460567623497017, 0.018658167156841488, 0.08381712821222122, 0.03507957974028203, 0.04651008654505976, 0.0612335495140043, 0.04878709520844202, 0.0858922612162367, 0.016971415832578655, 0.1336463366545016, 0.1324831240720326, 0.11189592836965477, 0.04700136340914234, 0.05542758364050139, 0.08516848432801424, 0.04561737960865421, 0.035758735837354776, 0.02479411008196973, 0.11063706204896012, 0.08996438625599108, 0.1866235382734768, 0.18307693422802035, 0.1197346319414435, 0.0938230562174032, 0.1834911579686788, 0.21607664654091482, 0.024830865065356898, 0.05226210067649523, 0.017603733313960895, 0.10488070802943361, 1.9543564848361479, 74.32791848336497, 79.39373016357422, 78.03996332230108, 82.4946540401828, 63.573203086853034, 42.613606222214244, 25.96288400311624, 28.530728355530773, 32.791873639629735, 57.8380036354065, 84.04053857249599, 81.0884137307444, 74.8827063652777, 80.1860724726031, 75.69408785912299, 70.90926693331811, 28.484138442624, 0.4419410162635388, 7.700823189750795, 8.992457236013106, 9.978366551860686, 17.5563366951481, 21.398939586454823, 20.723621191517, 23.637096958775675, 19.439931415742446, 15.895901303137503, 16.314702572361117, 17.369753468421198, 15.735219447843491, 14.125268882320775, 26.39044588611972, 41.07360132278935, 43.91430731742613, 34.34186097114317, 25.349135052773264, 18.8493852461538, 24.274111447795747, 20.31969943354207, 18.847528003877212, 22.17701819635207, 19.399629062221898, 17.285887310581824, 14.570467702804075, 6.930705520414538, 3.7925818850917206, 0.7442800977057027, 14.016497635072279, 24.280724563906272, 34.129711735633116, 59.047835180836344, 69.42413991497409, 62.33238481706189, 59.07176948362782, 48.94333893252958, 51.9536913594892, 53.700946454078924, 56.34576928231024, 57.71868121239447, 55.22210436482584, 58.4383184679093, 57.79495562276533, 66.46304069026824, 55.33333493817238, 50.21306114812052, 71.96757731899139, 64.23753884530836, 59.89876201075893, 57.644277772595814, 68.19264119671237, 69.2199883922454, 66.90486431121826, 63.543557813090665, 59.941111841509425, 53.25228614191855, 48.1607594028596, 57.69230327298565, 58.18021866583056, 49.790484597606046, 55.17942113261069, 36.78759997890842, 18.534709176709576, 15.941627314013822, 7.006623975692257, 7.8919431278782515, 1.4843000111079987, 15.441716332589428, 18.386002317551647, 18.912233383424823, 24.793803922591675, 29.143910523383852, 22.406910273336596, 24.78079930428536, 22.88200539927329, 26.820008177911085, 19.63834647209414, 20.325471201250632, 21.88129698076556, 20.471916814004224, 19.891653137822306, 18.769102173466838, 9.873724579811096, 9.898290384200312, 18.232316009459957, 16.287987309117472, 23.0051697838691, 23.74755874756844, 32.20116469167894, 22.742657315346506, 19.581605465181415, 21.39313251741471, 18.829357624053955, 22.675516143921886, 6.403888060200599, 0.21364324485823033, 0.2534551642114117, 18.99063567961416, 61.08619290013468, 51.19859587761664, 61.91504855309764, 56.21711946302845, 74.29403704981651, 37.425444049219934, 25.636011323621197, 24.375649844446492, 36.84223859540878, 48.87840409432688, 67.60295990974673, 41.558323906313994, 45.394923610071984, 68.99566804209064, 14.722113397813613, 0.4819377619893321, 0.2433920783861991, 0.0705106865854994, 0.119906856167701, 0.028675988677047917, 0.05867165573421986, 0.031796034966265006, 0.03675116443886392, 0.046504520916289864, 0.13995507071095128, 0.06280362756261904, 0.02248254319232318, 0.08085838173546138, 0.035831165620155876, 0.023772303923784245, 0.016768988589906407, 0.03166448809356699, 0.01735773099015557, 0.06729235121559712, 0.23396472296407148, 0.25185033258411194, 0.10484703846516148, 0.2107846337340532, 0.2611609668500962, 0.27127675952449926, 0.15704001119780928, 0.23867558147157394, 0.23876332918242102, 0.14106154682174807, 0.23819441696809185, 0.10891362468922332, 0.20179698213694558, 0.17956549361828836, 0.25270176270315725, 0.19755167526102838, 0.2886708164888044, 0.3452501788495049, 0.5338741105891044, 0.38492890615617076, 0.284569947830131, 0.24363394766565294, 0.15837484279707556, 0.2310166021268214, 3.2263676485707684, 90.59197148969098, 93.77131139078449, 90.64379384440761, 89.14536999117944, 83.92587984761884, 81.36244620046308, 30.45974804509071, 37.05052429629911, 33.11155465341384, 55.9789845251268, 93.22527039435603, 86.36282490145776, 80.40506624406385, 84.75872455104705, 81.58791972744851, 69.90823884164134, 31.725204683119255, 1.1354175642613442, 12.38227544292327, 9.94503915309906, 10.04359752901139, 24.087792981055475, 28.850213250806256, 25.058799251433342, 33.15333181811918, 33.955825221154, 28.536292237620202, 26.37311685469843, 30.450614806144472, 34.93783766223539, 28.965450525283817, 36.5068563338249, 51.52726304146552, 50.6753634637402, 39.744918038768155, 36.00534600596274, 29.256409983481134, 35.68089146767893, 22.239831032291537, 21.690336388926355, 28.235864177826915, 23.183939649212746, 20.36992734478366, 12.936846613883974, 14.44841334896703, 5.049551984956188, 2.2723523503349674, 14.516801834106447, 30.59119059193519, 40.91976596463112, 60.695403237496656, 70.36859958402573, 66.47742009931996, 60.62951918571227, 53.70668095927085, 55.33022449862573, 59.86922656336139, 60.53508027907341, 61.06191735113821, 57.57449488486014, 61.3038295315158, 58.94499063491822, 65.73754733608615, 54.23409069738081, 52.79183910739038, 69.62517707578598, 63.966546212473226, 61.613481044769294, 55.921670852168916, 70.98976181399438, 68.01692685773297, 65.48002020005258, 68.84760641282605, 62.67541177811162, 56.26078721015685, 54.98420476913453, 62.34768206073392, 65.25748452832623, 57.262807661487216, 61.75169360253119, 43.53016214986002, 25.13407345741026, 18.90188224854008, 11.91191069541439, 11.975956136180509, 9.237363165424718, 25.73045023026005, 29.696339099637925, 24.040791219280614, 34.46622363982662, 35.667943723740116, 20.31659095518051, 32.20696391597871, 28.81156025394317, 35.80949421851866, 24.651561129477717, 28.3375673140249, 23.879797535557902, 25.067987403561993, 23.00828806815609, 21.82042964043156, 27.27485799020337, 15.92378935506267, 28.830889694152344, 24.67925306289427, 34.69491351035334, 32.08766110481755, 42.07379787198959, 33.54807522989089, 32.220649065509924, 29.748908665872392, 26.668339929273053, 24.866063787091164, 8.348164789138302, 0.6119621881554204, 0.31030930698879305, 29.734874425395844, 64.98684098643642, 52.10554592071041, 68.99431874675136, 66.05562410046979, 81.06402443301293, 36.63066594831405, 23.118755740504113, 44.306732608426, 54.46574980212797, 73.94632677878104, 78.84111527473696, 51.04833772105556, 58.72185876292568, 80.9533037677888, 23.32304454618885, 0.7399827121726928, 0.501557212443121, 0.16191563989606597, 0.39471258439363976, 0.14133905451143944, 0.2633485462396376, 0.22242584536152504, 0.15336537853844706, 0.12832459963617787, 0.24161947350348198, 0.2716740527220311, 0.13780017263225972, 0.1510178399903159, 0.16261829574021602, 0.049517012291377595, 0.17666540649389068, 0.12272346269098983, 0.11641531086136257, 0.15899753438368922], [0.06260565512122647, 0.07402897602127445, 0.021632635673027367, 0.017114126521553245, 0.05851686383867937, 0.04052826518853826, 0.13146211273006855, 0.10926880603355747, 0.08606496041700726, 0.02126210384191044, 0.05519262064368494, 0.05719966375299039, 0.06276458006111846, 0.03649283959079654, 0.015185914817266168, 0.04945296734090775, 0.10363273547902223, 0.07602575355239453, 0.0991351635105187, 0.05566323611644968, 0.10658002894131408, 0.027041404109988964, 0.07521200729834457, 0.12192273993165263, 0.19040931496889363, 19.12947581660363, 84.17901392905944, 49.895329552312056, 54.99185731334072, 74.72683137462985, 59.7748778712365, 43.21856514100106, 26.437643766403202, 32.686612913685465, 30.17357191731853, 78.34213487563595, 80.56949200168734, 70.42866676084458, 74.84004666728359, 62.379896486959154, 51.28673153538858, 12.024648439499641, 0.34376427471157045, 3.501310108169433, 5.339303843436703, 11.942845448370903, 16.819625362273186, 19.85412782238376, 18.126370829920617, 34.61379497281967, 23.857190955069758, 21.980574131011966, 18.583030816047422, 18.008272186402355, 11.633341023998877, 18.332016775684973, 30.32327505850023, 28.882941507524063, 32.974840441057765, 23.780598832714944, 16.836638642895608, 11.272158392014044, 16.047964730570396, 10.603980671974922, 22.276089422164425, 24.291430673291607, 20.252770070106756, 16.26311654044736, 10.947688164249545, 10.2258014294409, 3.6907684322326415, 0.9648098448111165, 1.8517961881814466, 11.488832081517867, 27.330414441324052, 43.4846273545296, 63.010907788430494, 63.92264704550467, 53.905984432466575, 50.75000616811937, 44.33171026168331, 45.63568261361892, 52.035241357741825, 56.04386052777691, 53.48610647263066, 54.9573169216033, 58.02297476799258, 59.32680983697215, 49.2854166799976, 52.338750439305464, 62.74311188728579, 59.759408043276885, 56.661574994364095, 55.80733376164591, 63.119902610778816, 65.24137535402852, 65.33624572138633, 65.16680325231245, 53.04283941945722, 43.5116603297572, 45.307258636720725, 48.61263998093144, 44.60004352754162, 52.19518384625835, 40.55240069666217, 18.651519321626235, 8.561202441492389, 4.103445165580319, 2.3584662714312157, 1.1751788758462476, 3.92033078497456, 20.510434489096365, 23.52059668110263, 18.831642404679332, 25.438421926190777, 30.766118495695054, 20.75629649623748, 15.92407568808525, 23.87228031312266, 21.04091936542142, 17.218555904203846, 12.903639828005145, 21.103377226860296, 19.959531714839322, 22.230638957792713, 14.238487116752134, 15.742404249406631, 9.58927821728491, 12.447215184088677, 12.47987577992101, 16.75005428252682, 23.1705290655936, 30.57676019207124, 30.382461663215395, 22.192817503406157, 18.998427467961466, 12.242909708330709, 19.201443464525287, 7.097937243600046, 1.0638600491708325, 0.7762568528133055, 6.645082446836657, 49.56629368566698, 42.434808900279386, 62.041337105535696, 58.705145543621434, 67.11653109519713, 22.57440528561992, 38.11112534615302, 44.46356465739589, 36.492010162722686, 74.99822801159274, 37.907083649789136, 32.50605248635815, 58.1842783189589, 33.362001911286384, 0.028651209563137065, 0.08545058088437205, 0.05553280964734093, 0.038849011949834325, 0.11987523971906594, 0.06723971331431981, 0.0468708488399223, 0.048656377625922044, 0.010395022146704217, 0.030707027575361635, 0.12871401744984812, 0.04672728013247252, 0.022608555079768264, 0.04932864276211589, 0.05440495968345673, 0.006881454206567499, 0.04028746077129918, 0.07332722416087505, 0.047193720426049926, 0.05146037434197722, 0.03673256382406239, 0.10837506487845414, 0.01929248604292591, 0.07557239037968459, 0.08907364050467169, 0.07779550858803334, 0.05544410815702812, 0.0892577161111178, 0.11862627125435299, 0.024007695929838285, 0.10222347843791209, 0.05898813431661937, 0.06326815646682536, 0.05282160150067461, 0.12381791888225464, 0.11380559404290493, 0.05739760172042636, 0.10513996750476862, 0.08798766490672866, 0.09075089042345363, 0.04979151308596615, 0.007275308148124286, 0.06393436184753815, 0.10085973468038345, 0.12127224701426684, 28.558194752662416, 99.60746088335591, 61.51584540644, 67.8402711499122, 85.73986622595018, 45.91504950677195, 40.677022241776996, 24.077406544839185, 37.17931139853693, 43.31192147347235, 83.73147933713852, 86.87176812079646, 76.59486801393571, 85.07612274539086, 66.54710492780133, 60.866269526943086, 9.708353530976082, 0.2009732997225177, 9.984996338044445, 10.467265479026302, 16.08114209867293, 18.738788135590095, 19.91671512203832, 22.760333476528047, 35.119266894555864, 24.721659768012263, 20.16322039788769, 16.112641672934256, 17.19716133609895, 12.546168738795865, 19.568398844811227, 34.917021643730905, 34.39810775941418, 37.1583894760378, 26.82970819934722, 21.92309767969193, 16.373053712229577, 20.417031088183005, 16.43450156334908, 26.826270241891187, 23.667142314295617, 23.633000043130693, 20.586616723768174, 16.906935361123857, 12.916222791517935, 3.1308905395769306, 0.5609708243320065, 1.8017163464138586, 13.06192707630896, 31.96665010144634, 51.310869801429014, 68.11326811390539, 68.98882742851012, 58.39674526645292, 55.12965409986435, 48.19694719006939, 51.33547482951995, 55.59457263638897, 60.14086246490479, 56.21323631655786, 59.595762837317686, 62.96894627232706, 65.3647299735777, 57.33142560528171, 58.40489202930082, 67.4646806716919, 62.48880109479351, 58.46908161717077, 58.79800373508085, 68.13139730884184, 65.6983079448823, 68.66826780380742, 68.2947483370381, 59.48195918913811, 52.326410662743356, 55.68005677192442, 60.410474423439275, 53.23188589465234, 60.37068982278148, 45.79245974940639, 25.518289227639478, 20.986521974686656, 14.071847181166373, 6.794467876034399, 1.5099860199036137, 2.38368466015785, 16.205419455805135, 20.5559241771698, 18.701007866090347, 26.693741198508974, 27.596964989939046, 26.113216684710597, 22.312955779414025, 26.94720083667386, 22.761884773931197, 20.26312904973184, 15.98665024003675, 22.34005347374947, 27.11262091513603, 24.863773122910533, 23.28416209067068, 16.865556316991007, 6.074585962680079, 12.823115529552584, 16.141437753554314, 20.524339291357226, 26.012386275875954, 31.933813979548795, 29.055761137316306, 21.53833866119385, 22.383746716283984, 20.334084726149037, 23.30997716995978, 9.14413038761385, 1.2459055839046356, 0.4391567156680169, 4.077354049490345, 55.28646653698337, 52.151535710980816, 72.38549801611131, 64.82985204265964, 72.4217877849456, 35.1432914118613, 27.963337898254398, 34.257949706046816, 38.28760062494586, 68.0999634342809, 54.93470053518973, 37.44293782018846, 66.70086183855611, 45.190932904520345, 0.2109698891159027, 0.0152947538862786, 0.06405867876545077, 0.047617757753018415, 0.022440818213527242, 0.10527537354538519, 0.052057712248736815, 0.04171847470945889, 0.09548620245749913, 0.055233349708179315, 0.027867658664622617, 0.036844971905192064, 0.04541056268217583, 0.009345434767554605, 0.05344942970682056, 0.017240038817568172, 0.04566608364844034, 0.09694771435592445, 0.020464330521081726, 0.044882015640577005, 0.1222371883810528, 0.19161467770895652, 0.058610066095547336, 0.11774149332796374, 0.17561460965343062, 0.227427909210805, 0.12842468136260587, 0.18788677129533984, 0.22283242354469918, 0.2087024680428928, 0.22865738839872424, 0.13075939559888455, 0.22418844513595107, 0.173769042556805, 0.17675733704480434, 0.12057167492927083, 0.17249667776688454, 0.21848443024341138, 0.28391331854847174, 0.32052086065373114, 0.22457217857722314, 0.11230358673680214, 0.18927230259343503, 0.36311884260466026, 0.3015432693064213, 35.4564416793085, 116.52363930979084, 73.02491495686193, 72.58584483977288, 93.47590200362667, 82.18821494810044, 60.70615837650915, 33.62873877248457, 42.96402292866861, 39.91666293913319, 93.28688298502277, 95.9535926388156, 82.90375724915536, 92.52401336546868, 70.75491382229713, 65.24194409770351, 13.762527108192446, 0.492641389249794, 10.217132991360081, 12.97943570921498, 18.138822394032633, 26.754020183317124, 29.790117086902743, 28.064185957754813, 45.45242947916831, 36.988703820013235, 32.867545966179144, 30.679151704234464, 28.134604269458404, 27.52053172357621, 34.22484882416264, 42.99657860109883, 40.97094505063949, 47.339736723130756, 35.67329775902533, 30.352565357762, 29.382661273402555, 32.38818918505023, 20.861710194618475, 30.21042258508744, 32.44431830221607, 28.244820910115397, 26.780943332179902, 16.815969713272587, 15.810599557815062, 7.004289675143458, 1.1884195718073076, 2.3985055810020817, 16.701289415359497, 38.26016756796068, 53.26196262913366, 68.13538243693691, 73.32907122950401, 60.05208353842459, 58.24010933599165, 52.026792572390654, 54.007565975189216, 59.46761115904778, 60.593817772403845, 56.231522406301195, 61.969185106215946, 63.430024808452984, 66.6961314601283, 57.95488634417134, 57.69853984155963, 68.12711408061367, 61.58048606687977, 58.849959450383345, 58.28007828804755, 66.67789243882703, 63.43304895585584, 68.68119593589537, 70.38995296724381, 59.9682899444334, 56.01135192378875, 62.667214024451475, 66.48946962048932, 61.73949503129529, 63.84146182767807, 47.20421098893689, 30.06974089530207, 24.558112621307377, 20.18939241286247, 7.069350029191664, 1.0801968435125968, 5.991015453492442, 24.08361173445179, 32.12379397884492, 29.7492048048204, 37.22968247628982, 42.40498711985927, 28.723563840312345, 23.861083907465783, 34.205821406456735, 28.90463221457697, 27.05124955023489, 21.7939712924342, 28.447281891299834, 29.791413430244695, 31.18837537304048, 23.945259932548772, 28.084082180453887, 21.10862339696577, 19.309728337872414, 22.67087401882295, 29.886597587216286, 35.615599693790564, 42.43652297604469, 39.643030551172075, 32.44562249029837, 30.293829825616655, 24.187501592020837, 28.220831694141513, 11.944923323969688, 2.979860901832581, 0.4390566645851059, 8.596720483995254, 64.06568804094869, 51.4345342882218, 79.50966758112754, 68.21100573385915, 80.95491193955945, 26.761313830652547, 46.41123717831027, 56.58237057347452, 50.505411086543916, 92.0678181802073, 62.158521836803814, 51.754791890421224, 81.11897683912709, 60.52605882767708, 0.4150746191941923, 0.15484429595451202, 0.2087396386289789, 0.14202205253945244, 0.19129213937107595, 0.24316217540012253, 0.1277895868124981, 0.1222330208627447, 0.15107037830016307, 0.18977513206341576, 0.11987060488712405, 0.15934161511400055, 0.16234104852041892, 0.14784196121317728, 0.11486787454134996, 0.08534171979033178, 0.12121610043029632, 0.2159536894290678, 0.13303959501847146, 0.19502424394651768], [0.11509475148012561, 0.11068855081835102, 0.10916882389855963, 0.061865273277245225, 0.08038782754973059, 0.05300291536015369, 0.05889567899547758, 0.07340151170689253, 0.06346520194182954, 0.014757567288113699, 0.02959167825118188, 0.1433695092677109, 0.020917329802027634, 0.03828681449616148, 0.056857459938093546, 0.08851706230592343, 0.026371036956627524, 0.08226442886816879, 0.07447831723238192, 0.05393349002265642, 0.10405410682001423, 0.07092958346249596, 0.0625576941867269, 0.05102309135479793, 0.2644604156094213, 1.1800521756372144, 68.87859313718735, 76.56583462992023, 31.097392074523437, 60.8781699980459, 69.83821668932515, 35.867776716909106, 40.335171991778964, 25.599417571098577, 31.02722675569596, 71.00810281692013, 89.47160920789166, 71.2236370578889, 70.57758346680673, 48.407570623582416, 55.99317173804007, 2.605973222563344, 0.6177492163354351, 8.237792234266959, 11.048732342258578, 13.608762352697312, 21.14113396213901, 21.434146781121534, 24.369666268748624, 25.740689577594882, 20.492573976516724, 17.12431899962887, 11.361159913001522, 10.52682274772275, 11.782265574701372, 28.0200396814654, 32.81395462251479, 37.02930819603705, 29.786922316397394, 21.900569546607233, 14.733846187591555, 8.895190300480012, 8.12328108856755, 17.164988094760528, 38.028139760417325, 23.912341440877608, 24.253813182154012, 22.14465864243046, 21.795257829850723, 17.774632284718177, 7.896278327511204, 3.467683138385896, 0.823970340913342, 4.888535747604986, 27.518988270913404, 42.72075753058157, 57.93350158199188, 58.13425633215136, 60.9816264337109, 53.76841514341293, 46.44607567018079, 44.29339654984013, 50.08740017491002, 56.3768462211855, 55.24382252846995, 56.944793655026345, 58.670232526717655, 56.99457637725338, 43.081254728378795, 54.56986127361175, 62.42224631770965, 57.79590091397686, 56.08728508795462, 59.24471462926557, 64.47257903314406, 62.98838161653089, 63.87259760210591, 60.16575382601831, 50.73121801499398, 48.110607977836366, 50.39865201519382, 47.903836311832556, 43.66465630069856, 42.423614455807595, 29.834314354004402, 12.49500632286072, 5.7311123417269805, 2.3612337487359203, 0.3022677126911379, 0.5680540732799039, 3.419545605298012, 14.920391171209275, 24.285270590935987, 20.34872497281721, 25.759503226126395, 32.35147580023735, 34.796094971318404, 10.653496673030238, 16.181802864997618, 17.04709537567631, 20.432330293040124, 12.178066065234523, 18.03118863413411, 20.990069758507516, 22.261174609584195, 24.488684708072295, 17.055404916886364, 10.683602825287851, 15.831793104448627, 13.845789221025283, 16.28354424430478, 16.124644125661543, 23.597892868903376, 29.283219383608913, 21.601429985415553, 24.161423713930194, 14.386862535630504, 14.613530424333389, 12.187439549353815, 0.547754091601218, 0.26622119209458756, 0.2544914360248274, 36.49311234874111, 62.385313280167125, 53.87523697268579, 65.40976270552605, 53.08641302970148, 18.47010381760136, 57.89453675670009, 25.970875832342333, 63.583024701764515, 60.193253563296416, 29.340562474343088, 34.19650969966766, 42.154551629097234, 4.374661618663419, 0.5141321473544644, 0.049421071270180326, 0.04247056237692314, 0.014280634462803364, 0.07800215314472876, 0.05295751315932121, 0.039602957380514954, 0.051353122032577955, 0.01648881299901874, 0.06740462140090044, 0.046619035739211306, 0.07235118218006627, 0.06850901375254316, 0.01816336054264778, 0.06616735875967049, 0.06027107111989491, 0.0720865064631066, 0.006560068352208023, 0.0362334996762295, 0.06923354906781067, 0.09647251767737251, 0.04530456292653277, 0.06837801271749121, 0.07486846282958023, 0.059669106042072664, 0.035335433954793605, 0.07597758960459502, 0.1446834419884028, 0.040782303774669286, 0.06601903647665056, 0.14898441281289826, 0.04491900619600089, 0.14378071462194766, 0.07198111574736334, 0.04657125100493432, 0.013200822999821076, 0.028424196643754843, 0.032174290878878485, 0.09600904214406207, 0.07682043187800916, 0.04027765101542877, 0.03092582803219557, 0.10050213249820857, 0.07162978016440907, 0.0997224082088759, 2.2944642218851277, 86.28281639468285, 83.6821908335532, 37.08016957006147, 77.56005348697786, 62.38903560946065, 36.253494754914314, 37.9334419773471, 26.360020060693067, 47.11317669960761, 79.60471445514311, 94.33355962076496, 79.05846165072533, 76.50279429651077, 55.452261201797, 53.61334816102059, 1.5671970983666759, 2.144199936620651, 10.199226390930916, 15.385141045816484, 18.62779486563898, 20.510475673983176, 20.473923106347364, 27.617208342398367, 29.022171920345677, 20.918166829693703, 19.656811029680316, 12.883840683967838, 12.849454245259686, 12.274300436819754, 30.351686746843402, 38.07097204269902, 41.194061233151345, 30.662483592187208, 25.752874420535182, 21.07732484417577, 12.809371544468789, 15.014658474153089, 23.98002389938601, 34.20708048728205, 25.069191571204897, 27.24934493341754, 22.13054987692064, 25.84705641192775, 19.802556499358147, 7.902875263844767, 3.1945466851034476, 1.3153565410644779, 5.431738418917503, 30.449312579247263, 45.9741674700091, 60.8360751213566, 61.83805242661507, 66.65538587877828, 57.20975760490664, 51.250912450974994, 48.38465613703574, 54.45993292716242, 58.32669565754553, 56.83802281656573, 61.51217406795871, 60.66399681952692, 63.6909330275751, 49.066983807471495, 57.4712698690353, 66.41314814167639, 64.34456463783019, 59.07336588828795, 63.32532890381352, 70.38205331371677, 69.30971653230729, 74.35382181598295, 66.78025845558413, 58.178069206976126, 53.89576665816769, 59.37488240580405, 58.63297785482099, 59.44986243401805, 50.86367645571309, 33.03964976341494, 14.746834135824635, 6.652090741742042, 3.524715871580186, 0.3405463377073888, 1.1451208951973146, 3.843119908725062, 12.827384048892608, 24.22383058455683, 23.957562446594242, 31.204486508523267, 27.375245171208537, 35.48625953735844, 18.538478574445172, 20.11193148551449, 20.104241678791663, 19.383417906299716, 15.856496191793873, 18.666485125018706, 23.34143653992684, 26.00286276109757, 27.370599123739428, 23.39129182600206, 7.769836312340153, 7.766452777770258, 11.723683995585288, 19.50187348550366, 24.09497876321116, 28.264016989738714, 29.138185824117354, 27.108504387640185, 28.127840142096247, 19.328594938401256, 16.67115580651068, 15.73908200187068, 1.0677450342524437, 0.10052611871111779, 0.18170476350332462, 35.42166594536074, 66.59490293072116, 59.74968448761971, 71.94202699968892, 63.16985399492326, 25.61639358920436, 31.206196661918398, 31.815687879439327, 50.75736845693281, 72.49153537134971, 38.73435466520248, 42.069279301551084, 59.763330413449204, 6.757954041804037, 0.46484039555634227, 0.0613994918192827, 0.21350439908283375, 0.1313797735999669, 0.051952482411457654, 0.07940977841856019, 0.024408325440280383, 0.05293189517913326, 0.03301107722725118, 0.055522498103880116, 0.02104471107163737, 0.056964880786836154, 0.0524018734182802, 0.10984639802406873, 0.053544217765691786, 0.03739562058340638, 0.12545115704978668, 0.03300270005579918, 0.040246884924389666, 0.01877661009559468, 0.22593615216112908, 0.12604886650918953, 0.23270326726619275, 0.1100206217398086, 0.17319436936128527, 0.12935420648465235, 0.23926789001111062, 0.22726784279990583, 0.2170074740124326, 0.11622559684779375, 0.23500146975200023, 0.21726003787930936, 0.2632467791197762, 0.10489684950199821, 0.16081786654408903, 0.2121614163080531, 0.14020273161511268, 0.1198479746498408, 0.21335108956742674, 0.16134928641540391, 0.17361577900667347, 0.15528540938131272, 0.21330520090076233, 0.25959931193820895, 0.37689727100153125, 3.4038095464629516, 102.83883494715538, 101.44299676341396, 50.43490648269654, 77.42715574079945, 87.28218140140658, 51.31084626720798, 51.37873465015043, 33.032001141578924, 43.00711800975185, 85.95290583948936, 105.98194783733737, 82.85154265742149, 86.89310581453385, 62.63179502179546, 68.05767243908298, 3.157361144981077, 3.3062374015008253, 15.417516289218781, 16.982150731548188, 21.772245284049742, 29.86138851411881, 32.04668998718262, 34.36140221934165, 37.72893744130289, 34.84776435359832, 28.25583100318909, 25.24552368348645, 22.39154438818655, 27.005089136861987, 42.14315322137649, 46.80961270486155, 48.73599852285078, 43.110354792687204, 36.12379374042634, 31.485567477441606, 23.407956015679147, 24.639264498987508, 27.074952433186194, 48.16994559380316, 35.20828508561657, 33.40688167079803, 33.37420048252229, 34.942709245989406, 27.959009562769246, 12.697134883173051, 6.061070455658821, 3.2156299150759176, 5.984486668340622, 37.393692462675034, 49.77805068415981, 63.37604907251174, 64.62716748637538, 69.99491537770918, 56.705215284901286, 52.22566850723759, 50.057299906207675, 55.28427000968687, 59.127133738610056, 58.53496566895516, 62.36844316605599, 63.64326446287094, 64.53106549478346, 52.81135289899765, 61.09863465832126, 69.40350824786772, 61.35547537957469, 57.87004547734415, 65.13565178840392, 69.99303264002647, 66.13398521177231, 71.52755014358029, 65.83208037960914, 58.295112732918035, 58.94525343371976, 64.38051316045946, 68.86387640430083, 65.4257659758291, 49.557844900315814, 34.62218884498843, 14.395048522180128, 5.825786590576173, 3.5779024756723836, 0.4857684161153532, 0.5211008508359233, 5.735835856006992, 21.599411925961896, 33.65737991948282, 34.2095241238994, 36.64501005603422, 40.87922042415988, 44.27419262547647, 17.200711081104895, 24.21281264674279, 26.397166867409986, 31.14335244701755, 21.004205980608543, 26.844005238625314, 28.70401670855861, 31.79419917445029, 33.81887566658759, 27.001084396916053, 27.276821136474613, 27.823646606937533, 22.362016785529352, 27.304252232274703, 29.464370127647157, 35.10304789389334, 40.673676460020005, 32.18613220799354, 35.348643179862734, 23.908177844939694, 20.48850255627786, 19.560152061523933, 0.9250671031974977, 0.24169341630993352, 0.364563929577989, 46.8973796598373, 70.30162119096326, 61.5682404272018, 73.57704347179782, 66.37912550280171, 22.351414618953584, 71.46156018780124, 37.78216792691139, 79.38101383947557, 85.5874272315733, 53.44168170805901, 57.73822246059295, 78.30094214408629, 12.418496570279522, 0.7622323569751556, 0.24952068984989198, 0.34058571462669684, 0.4337003923231556, 0.16007998597718057, 0.25263826933599287, 0.12541954060115162, 0.15407774837747698, 0.09273291310115207, 0.12941743938192246, 0.21112967973514912, 0.16644550247057793, 0.1499879726719472, 0.17366048789793448, 0.16759720841242423, 0.15264520992434796, 0.18657772621560484, 0.14121012191378302, 0.08456743472526151, 0.2626030201152448], [0.030945181328382705, 0.3122941182265359, 0.05945110040146017, 0.11733437122236337, 0.08662592829956163, 0.045690518022785266, 0.022067365672198996, 0.013043514505449324, 0.09492605428902373, 0.0401584783779277, 0.11393491734540272, 0.045596116838315805, 0.06303916512537869, 0.06465887801060755, 0.03280080907467393, 0.0317175358518838, 0.01205075074047331, 0.0749648520122132, 0.045043610396885106, 0.10052224230622092, 0.0828212139106566, 0.034697646605632, 0.023165236700386293, 0.06480058895484095, 0.013074511380475617, 0.2900147492126111, 17.20324493223621, 87.18632651913552, 56.82438473547659, 39.94313893779632, 73.029582577367, 53.327870215139086, 34.23297989752985, 43.98427847893008, 22.464114119929654, 60.98002218431043, 77.896192766005, 81.17094824391027, 68.30581726566439, 66.3662758181172, 37.724026633847146, 0.16666546163539733, 1.7147891463771945, 10.612691275535092, 10.833612891935534, 17.941225151861868, 21.682572057170255, 23.515405424179573, 33.19914117936165, 26.496118460932088, 17.374634858100645, 12.837261557579042, 11.07646938293211, 8.70577218071107, 14.090515702001511, 36.88296848727811, 33.35234895829232, 30.698461532592777, 22.310649425752704, 18.689230949647968, 12.570145207066691, 9.813821161946944, 13.287686936316952, 29.29740659652218, 50.95026277726697, 38.475093841552734, 26.14022416453208, 22.53957267730467, 22.26489301650755, 26.38229912327182, 9.633643165711435, 4.073087001039136, 0.2051437598082327, 1.4637134512585979, 15.787349708618658, 37.28625089891496, 56.52311532728134, 65.31844208317419, 58.26207068658645, 58.03313370673888, 49.932552845247336, 47.17206716537476, 46.28961624637727, 52.70271893470518, 52.67299913590955, 58.955930125328806, 59.49167490005494, 59.28507974070888, 38.95861617980465, 51.64244736394575, 64.13066210285311, 55.314209461212165, 50.78868466038858, 55.495983862107806, 62.174427047852554, 61.96319564696282, 65.42381263548329, 63.65439614941997, 50.06126542245188, 50.249241090589955, 50.19272758114723, 47.08360987324869, 41.429501502744614, 32.29944359871649, 18.812660094230406, 9.540250551316047, 2.8835368060296585, 0.3363102392083214, 0.271766810647903, 0.8456837241688083, 3.2427788453717388, 10.878047462432615, 23.27767449040567, 22.18271347784227, 29.82334544581752, 39.6425167206795, 46.1509604607859, 17.004153267029796, 10.202201508706617, 12.178241591299734, 14.162358814670196, 13.304375640807613, 7.923826604120194, 21.51707353130464, 24.616373546661872, 26.510162507334066, 21.00532385610765, 13.462870774730561, 13.27991574041305, 16.822912308477587, 15.973353405152599, 17.485308454882716, 25.669504442522605, 17.668910680278657, 16.63581132888794, 28.757788481250888, 28.216622990946618, 14.102883915747366, 14.68552258706862, 1.3955150784984713, 0.08145396913131399, 0.05340483955918782, 17.90041289021892, 66.13991583547285, 69.68903326219129, 75.10212375271705, 29.707131501167055, 32.2589059029856, 45.38324279169883, 29.844698829035607, 74.99876929867652, 37.285509570952385, 23.889760355795584, 33.190186408258256, 5.111466107829925, 0.9418007923710732, 0.24422962699205647, 0.1959173186051269, 0.15437981684602078, 0.1419210668292738, 0.019846268020750537, 0.06782266792030105, 0.090712157018002, 0.022258895314148357, 0.04226490990408967, 0.03170375393012599, 0.0197929099968244, 0.044839647147924676, 0.03563817275027114, 0.08109441342493219, 0.04443649337777207, 0.02754724239029231, 0.05260523911865969, 0.05671369587822307, 0.04088172283504279, 0.2197315294535891, 0.048303429427887165, 0.34952580748546513, 0.08719051211711862, 0.11905174116573988, 0.044189246161089796, 0.05287339670523521, 0.03289781495808594, 0.08726888291177251, 0.04095994807299107, 0.04347551651599427, 0.11739099278084694, 0.01869550628227092, 0.029837483307346705, 0.07050492560430881, 0.034970481158985246, 0.19447593949735167, 0.04570014391755385, 0.11399543063054163, 0.05531248276031787, 0.06284539084581119, 0.06298238268843101, 0.07655903501736541, 0.07541476778926388, 0.023352077884239056, 0.04754984405853095, 0.43636723631812685, 23.581232601596465, 105.25839605639058, 54.683005963602376, 49.056589526514855, 80.95588468736219, 39.628356964357444, 37.08202485115298, 30.87804921211735, 31.881309132422174, 79.72519397735596, 87.51491131321077, 86.19190369882892, 74.05098345971878, 73.08345240931358, 33.26666478187808, 0.21879069687378025, 3.896377115480362, 9.559859460399998, 15.037040498948867, 21.75706571148288, 25.245060843806115, 24.648215347720733, 30.743659004088375, 26.30279071869389, 22.792294909877164, 14.698199687465547, 15.057436823844911, 7.95139596346886, 16.081240157927237, 40.8549056514617, 39.164964229829856, 33.333329385326756, 26.85315024468207, 21.74125267613319, 18.75995912859517, 13.372570949216044, 20.386668020679107, 32.38562983851279, 39.106050229841664, 31.39553535369135, 28.019480743715842, 22.76655827799151, 27.62186223460782, 24.983934933139434, 9.727931061098653, 5.164079800728829, 0.801420818653799, 1.4784738205132948, 21.593226348200155, 43.00045390282908, 62.43114225326046, 67.48145272654872, 64.11654157023277, 61.794902432349424, 53.77033710479737, 49.96509675056704, 50.50538755232289, 57.20743163939446, 56.80040728661322, 62.741323286487216, 65.13823663034748, 66.19329929351807, 45.74292021413004, 58.26374161627985, 68.81009286449802, 59.78753143741239, 57.72037567630891, 58.48769718600858, 70.55821480289583, 68.6499503351027, 72.93114677552255, 67.7132648037326, 56.65605229716147, 57.147317394133545, 60.481410488005615, 54.89746547514393, 51.03238544156475, 41.047529328253965, 24.85868973116721, 11.162366347928202, 2.204233528144898, 0.6989851798261366, 0.8384659501814073, 0.8502541434380316, 2.9246461872131597, 9.462847478928106, 23.89943684301069, 24.204259918582057, 33.6197369329391, 34.15175545600153, 38.89137498794064, 22.56614085166685, 13.142532763942597, 16.354977469290457, 15.765247152697658, 13.861831715030055, 10.22089356376279, 23.027372360229496, 28.415179252624515, 29.51702206365524, 27.636861378146758, 18.154088258743286, 10.09816260107102, 6.73676981079963, 12.836885990635043, 21.331508159637455, 27.407687094903764, 21.04939756854888, 26.33104355104508, 29.58791498214968, 33.02524682014219, 19.9227536109186, 17.709779816289103, 1.7486345431497021, 0.8093140983293134, 0.06225905779208388, 16.27458457023867, 67.17905367574384, 76.190291220142, 72.4476989623039, 45.723069098687944, 24.84712854508431, 36.77832357345089, 34.30078983306885, 73.43077828807216, 58.75978023775163, 35.85975939227689, 51.87048219865369, 18.87824800706679, 1.2795794995561725, 0.20333999046875587, 0.1979833811281189, 0.10926831573728593, 0.2704170556558717, 0.048925634548668905, 0.06264909230653318, 0.026901129580613588, 0.014917243951781383, 0.02347278652802831, 0.002373860371599515, 0.05069104203533742, 0.024126368694968765, 0.042929223047629486, 0.06535715949270995, 0.0246943807559869, 0.03394857349414979, 0.12284110315264234, 0.0748869791747101, 0.05452377992051263, 0.053068649534496574, 0.11349463895443948, 0.3184903599321842, 0.168196335134487, 0.21370125303585685, 0.20752876005586118, 0.14444557168791372, 0.1353520007743951, 0.2544347301966721, 0.2879191310175004, 0.19990328939691668, 0.280217373323056, 0.23187195461603904, 0.12994213300126214, 0.20242454604275767, 0.14512309984814736, 0.21063365312593602, 0.0676953747508026, 0.3628073512546478, 0.20614713580617983, 0.28046331819026704, 0.2677250533334671, 0.09966432342245694, 0.20176142033550049, 0.14962003596367376, 0.19230041833173847, 0.5487667985500828, 31.06043354157479, 121.94625331509499, 74.06773198035457, 62.7394130922133, 93.95508227809783, 74.41633655178931, 46.8812979421308, 57.63615454396894, 30.477151601545273, 74.24612922053184, 94.42844959997362, 92.01911018740748, 81.90152106746551, 77.38007160925096, 47.278892917017785, 0.34460451994692126, 5.765817963307904, 17.07370081255513, 14.70586988233751, 28.577208442072717, 31.737256165473696, 35.914880460308446, 45.80920434767201, 41.23270050171883, 29.133816303745395, 25.2797757810162, 23.878950303600682, 21.660351830144084, 28.788402580445815, 50.09344846971574, 47.13461245259931, 41.34389969610399, 35.52819359687067, 30.83444030054154, 31.07061013098686, 26.01773246642082, 29.54535726578005, 39.35333605735533, 58.75084115612892, 49.435098248143355, 34.198353213648645, 31.46642238863053, 37.974030663890225, 39.40877091500067, 16.715003982667003, 8.837279446663397, 2.128491089228661, 2.361321511768526, 20.035464879005186, 47.49132064081008, 64.34541971452775, 71.32794857025146, 65.67511104768323, 66.24864393664946, 56.48381317815473, 51.898676195452296, 51.891957175347116, 56.75756715959119, 57.749660092015425, 66.49727513713222, 66.3793686897524, 67.07568353222263, 50.67079390248945, 60.21471677287933, 67.78004707828646, 59.64897371107533, 55.00600530255226, 59.0610182669855, 67.04392802330756, 69.22034925030124, 71.37038861551594, 68.61812422352453, 60.926936826398304, 61.24038519397859, 63.56689591561595, 62.88878871548561, 59.125705995867335, 44.418747655807, 26.910567860449515, 18.933533814645585, 3.3343551572292083, 0.7738237575657907, 0.568003817912071, 1.0651321228473418, 5.886623042245065, 17.403938885658018, 32.71130031155002, 33.93997492328767, 42.57688891503119, 50.81138733894595, 54.87141701482958, 25.615324743332405, 19.535666665723248, 21.580090330493068, 23.638087357244185, 25.564635953595563, 16.84765461952456, 31.376978620406124, 34.06427483404837, 39.2888326798716, 32.42262955634825, 27.967503455377397, 29.5742396385439, 30.78841717012467, 24.140264488035633, 27.237717067041707, 35.80032763942596, 29.54378047297078, 27.475400932373542, 43.10886036965155, 37.126124059000325, 22.80602320548027, 19.765927445503976, 1.8635277522187081, 0.7871988559922865, 0.14535208352871481, 20.051585820413408, 80.62613102697557, 77.14781238186744, 84.06600259965467, 37.376394810215125, 42.359734735181256, 59.68072529762023, 43.94854960903045, 94.50821491979784, 69.9363700805172, 50.60568647999918, 72.45303338573825, 34.782974643092004, 1.0145172452734363, 0.5213072655662414, 0.5243234456546846, 0.35710269284825175, 0.3866169962190813, 0.24271998945022785, 0.1475496833483058, 0.2027666196227074, 0.0871428844308661, 0.11428249143664876, 0.226181652697344, 0.21712468546484748, 0.15648881093628947, 0.16223192695648442, 0.24082022929383864, 0.15992272344808425, 0.09884103171287045, 0.1774939459057585, 0.15785264662436901, 0.1944014757511116, 0.31844926697592585], [0.006094098723899093, 0.12192131500811347, 0.050164597905090744, 0.10944718960672618, 0.05030001160658656, 0.11860495102742027, 0.10637572861366695, 0.014290586902549671, 0.08293177571988876, 0.05426968770822691, 0.0245492875335678, 0.03970592342797787, 0.08363635444472875, 0.01567660275125696, 0.02311117770600944, 0.09726941765796754, 0.02067700227452142, 0.010489215529824217, 0.10468494958214222, 0.07963392042344616, 0.0798050951092474, 0.024235365769615578, 0.07476542400376451, 0.05870952346031705, 0.1746318873859221, 0.05084180047795658, 0.4926937590202978, 37.99750604937154, 68.8628173643543, 41.734677591631495, 59.0092037570092, 80.40381893034905, 41.47926853549096, 51.717599976447325, 34.99222916941489, 36.31837860230477, 62.45417048854213, 81.92774603443762, 68.96894885647681, 63.80591730917654, 9.094299616352204, 1.06498503396588, 3.5455568951945153, 8.137935553827594, 19.769638007686986, 21.505957534236295, 19.28694917309669, 16.379646235896697, 30.334355754237023, 28.109155931780418, 20.252566106857795, 13.31111035039348, 9.493838125659574, 9.811544226061914, 33.53593941657774, 32.9855602787387, 37.80766725540161, 28.4153086908402, 18.860463980705507, 17.680938628412065, 12.138237337912283, 10.579937523411168, 18.953667340740083, 42.39534985634589, 62.242954777133086, 51.01538588923793, 27.401019065610825, 23.63641054399552, 23.567410169109223, 33.89089430532148, 14.926637545708688, 4.612852450340025, 3.3736109733581547, 0.7229445490144915, 1.932318893171126, 26.265492900725334, 50.674578989705736, 59.761710474568034, 65.25841805242723, 63.24916824217766, 53.157902148462114, 48.87858452335481, 52.459480993209354, 51.19030790944254, 55.399466099277625, 62.12572689979308, 56.10281767383699, 62.302861136774865, 40.58869831023678, 44.29751111615089, 64.63900519955543, 56.571646813423406, 51.74158527005104, 52.03580225667646, 60.78496271564115, 64.34539225793654, 66.6148050369755, 59.20653427800825, 49.324707062013694, 51.5379201212237, 51.65128838631415, 48.18062620778238, 42.25790216076759, 36.26728188607001, 28.40346117173472, 17.571653550670995, 7.143429873451111, 1.0956989084520647, 0.8489753281877888, 1.1601497016606794, 3.3156724178021957, 9.13714268515187, 26.564118631424446, 26.461858518661995, 37.079043849822014, 45.24925462661251, 51.17379080864691, 27.157241798216297, 11.142901585948083, 9.13321247023921, 8.689818920627717, 8.106589932595531, 6.6339340902143915, 12.12668203538464, 18.70925072700747, 27.04199471781331, 26.827929404474077, 18.122630849961315, 6.804305670722839, 17.728365967350623, 27.683296357431722, 22.730576415215772, 26.053653532458892, 13.954709518340326, 19.524197655339396, 32.479372524446056, 25.6503495477861, 15.067459460227722, 9.144905055722884, 2.2811725351118275, 0.4293228739932661, 0.0919970167019675, 4.881485287220248, 65.18304970956618, 73.65618121239447, 77.94519885893791, 23.345839400445264, 37.571595484210604, 28.293428882475826, 54.23520857287992, 57.734845299874586, 23.340865835066765, 16.046223198213887, 25.023543027139482, 1.2421108133369878, 0.0386297116206298, 0.11982498435123314, 0.121495668896504, 0.05780649731957144, 0.11281808372586967, 0.01468761579974765, 0.06782294371195378, 0.0831938007726304, 0.04047037958497963, 0.10207517147665063, 0.09546660592839604, 0.12481356505304576, 0.09325726964180509, 0.03179188468493521, 0.0668345140894094, 0.009933897545711409, 0.04093297028673753, 0.05238069874805309, 0.04214764865595968, 0.023460433360249288, 0.09099534908009153, 0.040247635690555464, 0.05136113148182631, 0.05914409066580477, 0.05853895781441562, 0.06503499653791228, 0.12024229542622644, 0.16752424619851575, 0.035377691364696914, 0.0339496306954853, 0.05329676753570957, 0.05381100022444322, 0.0667422924250845, 0.04735376002387174, 0.011045631892498464, 0.030581050161873142, 0.01995280978360003, 0.02742694934920198, 0.026507090341540116, 0.07316430790289756, 0.0588601554984287, 0.061826214284425786, 0.01873728105678193, 0.09027634491963733, 0.09147930980449723, 0.11362087492260242, 0.02819314069535223, 0.9651922146158834, 61.17565039665469, 83.47292454011979, 43.200635986943404, 73.9917556701168, 68.04698790273359, 34.45674327112014, 34.73991486334032, 29.331646926941414, 56.30350966607371, 75.63507187751033, 90.28979209161575, 72.4256944656372, 68.68439658995598, 7.351618985975943, 0.47991525922571465, 4.6929570551841495, 9.472471994738425, 21.039879937325757, 25.647701947919785, 24.4610418042829, 19.721981210093347, 30.287236321356993, 26.860665505932225, 21.56063537443838, 16.918251399070986, 14.77741881724327, 8.123592916996248, 34.961073783136186, 38.465268304271085, 45.26164931635703, 30.178363092484016, 23.339942116891187, 22.573785551132698, 18.22476544687825, 15.710124123481014, 25.58810937789179, 40.5774450302124, 49.016530359944994, 39.69495096514302, 27.63472760877302, 23.740241566011985, 26.17653746758738, 24.886156128298854, 7.177375535811148, 2.1334641643108863, 3.7581888273839033, 1.3509840422099637, 5.861189413455225, 38.35535956967262, 56.980640196031146, 65.59796979350429, 72.23520848058885, 65.24932207599764, 56.42320471425211, 51.56695742760935, 52.48020287482969, 53.594489405232096, 55.11713781664449, 64.20635208006829, 59.312563788506296, 69.0402889251709, 45.25485184884841, 50.028666603949766, 68.1518328574396, 61.498987059439386, 56.69792359875095, 56.34525545181767, 65.42305169566986, 69.46621125744235, 71.26714398784023, 66.26402747246527, 54.94840137420162, 58.969674110412605, 59.267887992243615, 56.131682395935066, 51.23425414485317, 44.005824058286606, 28.81524532072006, 17.93081714260963, 4.846104527673414, 0.9925285606615006, 0.982502798639959, 0.8045813297071766, 3.6704721277759926, 10.571605428572624, 31.65504524784704, 28.550357857058128, 36.65779306042579, 37.44732695241129, 40.04376342219692, 28.68779378552591, 13.383365311930257, 11.875837637532143, 10.239872932434082, 7.059236687998618, 7.4937289088003105, 12.93502075056876, 22.14271510801008, 29.855061731030865, 33.581160422294374, 23.874496452270016, 12.3437616902013, 13.723526000976564, 14.82640039536261, 15.862629798150833, 19.92094539826916, 20.531134797680764, 27.160322819986654, 36.95179039432157, 29.412486976192845, 19.328802824020386, 13.725122405636696, 1.7536587316182353, 1.3038144765361663, 0.07026945315902272, 4.535468009210402, 65.52113056182861, 77.12848294165828, 80.16194989604335, 37.527382527628255, 26.12361292685232, 29.712922880726477, 46.58342530650478, 76.07603257702243, 41.42911711046773, 28.903890886614402, 47.1436260592553, 3.2300772301612364, 0.767245575064613, 0.03175719430850398, 0.06355527855996644, 0.05806715873580787, 0.03620849073594136, 0.02459804136906901, 0.02233007445841307, 0.06367245936886438, 0.09619547730131496, 0.06430213384690785, 0.1023255673147017, 0.09895324827201905, 0.04848941642370436, 0.02516830572858453, 0.07745135890980882, 0.04490699393734817, 0.044307430545168544, 0.07198738234658396, 0.05589657117642703, 0.06067465006884548, 0.12272962969878029, 0.14277756845037784, 0.2652404156904067, 0.10399245206386813, 0.16857536479590401, 0.2750703043514683, 0.23783513705336282, 0.23343782301150987, 0.15076302382494175, 0.18324853792305917, 0.14306460627384726, 0.14224424868101074, 0.17543468624353412, 0.16806600825680842, 0.1614158134907484, 0.1459089528408743, 0.27862642320894426, 0.11666739209284706, 0.1852548609097158, 0.24623510728199638, 0.20188025589431488, 0.19784761502617793, 0.2011676255853907, 0.2877564139423832, 0.29558007154733906, 0.3347567661154655, 0.16417743788371164, 1.873875945325821, 84.7634235505135, 103.24708307943037, 60.52867112621185, 84.96513535899501, 102.89326175566643, 62.8596023590334, 64.35122874475294, 49.81206155592396, 48.3026982122852, 77.29816467531266, 98.46021467639555, 79.18443249117944, 76.81985516701975, 11.935000708026271, 0.8557565546324177, 7.893143863447252, 12.492641133646812, 24.1029921654732, 32.953557660502774, 28.598408852854085, 27.28764883933529, 44.88930263826924, 40.791857473311886, 33.183341872307565, 26.191364026838734, 18.9244358770309, 24.86700515593252, 48.46994023169241, 49.79646228974866, 51.89862128226988, 42.081650457074566, 32.70890766574491, 33.5617172333502, 29.88199664700416, 26.652979927678263, 33.00612526555216, 52.55561436376264, 67.85430539038875, 57.63232238831059, 36.54678998454925, 34.80143331712292, 36.69311008145733, 47.56743423400387, 25.571388313847205, 8.029554582411244, 3.815894982507152, 1.7708751174711415, 5.658404346435301, 39.98795201701503, 60.26033786035354, 67.93512190541914, 74.1407351340017, 69.93412648477863, 57.26321558798514, 55.12713593821372, 55.07378778150005, 53.99553606587072, 56.16809375824467, 65.92892369916363, 58.555299235928445, 70.6322613070088, 52.06495723416729, 52.56978196482505, 66.52137417947093, 62.229402988187736, 56.10982302696475, 55.51867869592483, 64.26127702959123, 69.20945290596255, 70.99455495034495, 66.30913472944691, 57.59722109763854, 61.70963402717345, 63.36285421925207, 61.39919411751532, 62.58374990955476, 55.62941505062965, 39.73961107192501, 26.25410822130019, 11.145462893670606, 1.3520843896173662, 0.9302867973043073, 1.585985986936477, 4.775177778736238, 18.713835977738906, 39.84422852916103, 41.16075246564804, 47.557757746788766, 53.68162093623992, 60.71785880673317, 35.47746166106194, 21.156664586836293, 20.510891445221443, 17.182830956674394, 17.425313841912057, 15.697250904575473, 21.981129146391346, 29.10207256194084, 37.335194233925115, 39.354230357754616, 29.283558668628817, 19.616838155254243, 30.820723772048954, 40.622630734597486, 33.09660650068714, 40.113707127109656, 27.383101678663685, 28.557694650465443, 47.38025872938095, 34.43082424902147, 19.031469514293057, 15.794408013743741, 3.7590858244126846, 0.7852050662040712, 0.15875528206027326, 6.4459432228919, 76.87903588817966, 81.51370063904794, 90.33305583461639, 31.390857927260864, 48.1736247770248, 43.66413854783581, 72.4718136941233, 89.68742585951283, 53.24337451688705, 45.55226556716427, 71.06308660199566, 6.183573920880595, 1.2900313903247158, 0.14566395792268938, 0.2227988535718572, 0.19642106738061677, 0.2709950230294659, 0.26992587072234003, 0.19969019437989882, 0.18747792549190984, 0.10126769182182128, 0.18215251125154958, 0.16780202967985985, 0.27068579929970926, 0.15037573573570098, 0.21179329573867783, 0.12949090721386095, 0.1708303599227821, 0.16361488419915401, 0.14429616922092053, 0.1356401111209585, 0.18057038647032556, 0.1989865732649642], [0.04984716171278589, 0.09794648616544663, 0.022922042088823456, 0.004002671508539108, 0.10215671387531104, 0.19204832943937472, 0.1325839565646264, 0.061642981374696385, 0.03043182389510255, 0.0952623745486621, 0.03946664352570811, 0.030149813523636233, 0.0023181813406652862, 0.08411411751782702, 0.057759459521020615, 0.013294345098397425, 0.1042406109251803, 0.09295890903881482, 0.08624045583870142, 0.08579403342258546, 0.08244665054183814, 0.11688856933746608, 0.06778200397328024, 0.07845678036251376, 0.2323086553763959, 0.09187032874192923, 0.19478536240996855, 3.0716235262732354, 50.78888862363754, 48.26889914851035, 39.65058503612396, 77.6738492904171, 57.277410645638746, 43.17720374753399, 42.84153123055735, 29.951620678747858, 59.554032741054414, 76.02841500313052, 86.99136118735038, 39.370704312478345, 0.7219714947765874, 0.28005603520620254, 3.8273201113747017, 7.307143720888323, 17.339106029079808, 20.59836422243426, 25.169900386564194, 23.94509715418662, 29.377964235121205, 29.953515183541086, 21.787834744299612, 12.002107558711884, 14.045713409300774, 18.39386078619188, 33.93892765045166, 30.530723333358768, 40.53155722156648, 20.683597326278687, 13.213411954141433, 14.394190503704934, 10.91803994870955, 10.796689660318437, 19.802383915070568, 45.63438038672171, 60.21815276915028, 59.330763586105846, 32.87654584453952, 23.775484062010243, 26.522810189954697, 32.20936832889434, 12.700356129677067, 2.126791477203369, 5.179898229337508, 1.6791851794527424, 0.68558752777115, 2.8494565573430832, 30.676586474141768, 55.48620931563839, 59.74819006458406, 62.996214589765, 59.54054371003182, 53.691226820791925, 51.256046833530554, 51.304382201164, 53.53425748886601, 60.686401397951194, 57.32793077345818, 66.3419492783085, 36.20211562802715, 30.49929730353817, 66.66812573709797, 57.10567751238423, 57.191389145389685, 48.686298170397365, 63.72166087550502, 63.44722832402876, 64.5342347698827, 59.82474296323715, 50.32174218085505, 53.43042842803463, 54.87042857754616, 55.017215436504735, 49.794171625568026, 46.13209386025706, 40.477044120911636, 22.970858850786765, 6.656239138495538, 1.8338430096064846, 1.7753298268202813, 1.6149157958645977, 3.2927895553650397, 13.337604980314932, 24.716111575403524, 23.566180506060203, 43.69065377020067, 49.26028997667375, 50.14762424653577, 25.497294741292155, 11.010081306580576, 9.983182241839748, 3.8016798227064075, 4.316859610619084, 3.1602090308743143, 6.683933523393447, 14.519582794558618, 19.559793164653165, 29.92778051284052, 27.479972454809374, 11.02811538404034, 7.8080151927086625, 16.245748285324343, 30.028348122873616, 33.51136576744818, 16.470673661078177, 25.226043232025642, 21.746045812483757, 29.929267091135827, 12.809793199262312, 6.303428805643513, 2.9510532992501415, 1.150932744626076, 0.08098070299433124, 0.8721941048579832, 37.767917956075365, 89.35343603934012, 55.35324096679688, 22.578570842742923, 33.622521815761445, 45.400662037634085, 64.35417052238219, 39.19180893128918, 12.71180062524734, 23.11964611853323, 11.977009292571775, 0.9931220030111652, 0.08284118582284258, 0.09687836041613933, 0.12091592419892551, 0.09706262754456652, 0.08167844055400741, 0.08510867584376566, 0.03040588032754679, 0.07304978541909687, 0.10612759273499252, 0.05283402361636681, 0.07745017147352619, 0.08801031812664964, 0.06057417380713648, 0.0758802964382114, 0.028684666538010203, 0.03195727923734775, 0.030891917150227294, 0.08184658153162849, 0.05942028451470598, 0.018027996636867043, 0.04144837125955571, 0.06280796745071007, 0.0947622340472956, 0.08307648206790609, 0.04985815124405969, 0.09255222360333128, 0.257439985871315, 0.08328180895337174, 0.13870538212358952, 0.02170753800460408, 0.08985664365032027, 0.0634890502589124, 0.04073805070572323, 0.024701386630054445, 0.03186430297641745, 0.04032588774158109, 0.057683333363984866, 0.019318065718717633, 0.05904831818395084, 0.054279807729706656, 0.04776622942318359, 0.10739588959803505, 0.152805935170862, 0.038479209817465276, 0.04291238060461418, 0.18806479480718413, 0.08410071097915212, 0.07937555727098258, 6.760540354636408, 78.63950544787993, 53.903062266688195, 52.79945242789484, 79.26072259103098, 51.98976539796399, 36.96446749471849, 25.27208793547846, 48.12626215719408, 72.15138743000647, 82.86841669390279, 89.2106774545485, 41.66449462213824, 0.7292159286237533, 0.5538124987675298, 5.518934669033174, 9.551180235801205, 23.288231549724458, 24.140672414533555, 26.73631460435929, 28.067374844704908, 34.23607856996598, 31.435194438503636, 24.135063425187145, 15.541656363394955, 9.870797511070005, 20.084582759488015, 44.67573742712698, 38.44919050893476, 45.66981507885841, 23.33794955284365, 17.89556484068594, 17.931176039480395, 16.45938115735208, 16.24529525156944, 24.41733091108261, 44.42542352984029, 50.735983694753344, 48.30010944797147, 29.238824036813554, 25.078630755024573, 26.980782208904145, 20.922081355125677, 5.654895786316165, 4.187590056850064, 7.481989254874568, 2.0202358788059604, 0.6856575175639122, 6.24124845189433, 41.8918469644362, 59.94159821541079, 66.24454898218956, 68.1810623599637, 59.829794976019095, 54.23542822560957, 54.362936635171216, 56.75428413575696, 56.28802807100358, 63.57397579377698, 61.51144058473649, 70.48139126070085, 42.69377554616621, 37.63031728806035, 73.61688690800821, 62.4115421695094, 60.6464873590777, 52.75361561006116, 67.6594969534105, 70.97668463183989, 70.08844821683823, 63.910938770540305, 55.036874355808386, 58.88287598086942, 59.27659173165599, 59.658838472058704, 54.15463132243003, 50.728013438563195, 41.608938171017556, 24.38629907946433, 8.568386262462985, 0.7570358906542102, 1.7524963617324831, 0.11497283624785562, 3.8252106116664026, 16.68015568487106, 31.749256657015895, 24.467052836571973, 38.534278485082815, 37.812225049541844, 36.690584075066354, 27.263388979819517, 13.81117626543968, 10.738825874943888, 7.3584282205950835, 6.685522083313235, 6.341215939291063, 9.440439958726207, 18.793287507949337, 21.35249480124443, 34.68275416281916, 32.34644143812118, 16.091403999636253, 12.255492671843498, 15.349794607008658, 24.076302397635676, 22.833079714928907, 19.545325502272576, 26.183774240555305, 25.769946536710187, 27.790002476784494, 13.495946161208616, 7.917898922197281, 4.4744138659969455, 1.8292267476358723, 0.140940229138059, 0.5325658775625691, 38.33681852586808, 90.15120690868747, 72.64842233350201, 29.863233989284886, 20.01263668460231, 41.43893872537921, 65.73297385246524, 64.90465948658606, 29.36460856468447, 42.78806148036834, 24.04415661288846, 1.8795143524485252, 0.27530105003426153, 0.09358880951279595, 0.023252413675729788, 0.06707952432935277, 0.07100451452236983, 0.07372375127048263, 0.09730136352441004, 0.016860706551421075, 0.12031547980563295, 0.11750654182246617, 0.1092966226860881, 0.09119791038815053, 0.024691308743410537, 0.02504375898429463, 0.02977285038439497, 0.014982933118458719, 0.11816148571069203, 0.02298526732521432, 0.06161477018688476, 0.08281610410420165, 0.038326187585029876, 0.08275238857153924, 0.15147252849513484, 0.140588901215984, 0.15894398483778202, 0.24392457078060797, 0.370989446077616, 0.2906724510173644, 0.2509502712036333, 0.07916315173309657, 0.26859866935879956, 0.11137409991915188, 0.07617467338399542, 0.13540306819542763, 0.24247940719848682, 0.10728501369275394, 0.09211318627480539, 0.13155370620229553, 0.17555684662393986, 0.1510080340648851, 0.18623143915207158, 0.15654023075776716, 0.24620617980197554, 0.14270474413229575, 0.22013439977120972, 0.319957786029385, 0.25613409707382806, 0.37225110095835506, 11.553271720486304, 103.26382375532582, 78.76060470458, 64.01199079328968, 101.0174431339387, 81.16410763032975, 58.73266097038024, 53.54941352721184, 38.49616873648859, 76.68353711405109, 92.46911587253695, 102.5128310726535, 48.33753278178554, 1.3051995635032654, 0.5962841681415035, 10.839188541135481, 12.897591533199435, 26.26544387109818, 28.61999757828251, 37.33372726748067, 38.3617804896447, 40.15650410805979, 44.984906488849276, 35.30213171435941, 22.716089140984323, 28.968739432673303, 38.17759775346325, 51.50463488794143, 46.266521330802675, 55.1819706732227, 33.07725744862711, 25.962793788602276, 28.658036724213634, 28.121838915732603, 26.25575561677256, 33.07558259656353, 53.557124906970614, 64.84004236036732, 64.49348526616251, 43.12657379334973, 36.71229047159995, 38.55878153154927, 47.07147405993554, 23.011047455572314, 6.385650019491873, 7.839334337942063, 2.087303505789849, 1.1880044134393817, 8.952335311520486, 40.79881575799758, 66.73268010539394, 68.6237096786499, 72.45834427495157, 64.30631368390976, 58.51488705604308, 53.421273616052446, 57.01758500068419, 56.33173111946353, 66.06767362163913, 61.493142727882635, 71.39538980299427, 45.2402880883986, 40.08255174083095, 70.94834942971507, 63.22151161009266, 60.22022378060126, 52.93594698752127, 69.04945158189344, 68.7426830107166, 69.2147010372531, 63.73347113209387, 55.44789168142504, 59.29914143777663, 57.88644098466443, 63.54338522880309, 64.5579807989059, 60.325806140899665, 47.516631695532034, 29.569485725895053, 13.309482566771969, 4.025610877621559, 1.7963705235911955, 2.1653819612918364, 4.470050719476515, 23.259866929823353, 37.27247161249961, 34.22065188807826, 53.0574071022772, 56.4562742171749, 56.4414829592551, 34.74952074789232, 20.27312913248616, 22.888173326369255, 15.07831265849452, 17.8513793406948, 15.649066548193655, 17.99262781297007, 28.763864232647805, 30.245714110712854, 43.19041036790417, 40.49172555246661, 25.056930242046235, 21.795542201688214, 31.49066067511036, 46.0260094365766, 46.809067495407604, 26.77522255528358, 34.61730941649407, 29.749387195033414, 36.74535605215257, 17.98409861903037, 9.49668380521959, 5.3374220863465345, 3.4678677349321307, 0.18217512616707435, 1.197938796493315, 46.26840014611521, 103.33327324159684, 66.85093956608927, 28.460657173587432, 43.042588003220104, 65.63839766287035, 88.32797158148982, 78.41162358560871, 40.60996932368125, 68.80862589805358, 36.40732226833221, 1.827386298006581, 0.7114167643650886, 0.14857152206522806, 0.22773131067233704, 0.18693588764196445, 0.2315966685813281, 0.18106331808432458, 0.15392788625772924, 0.13395882391881558, 0.15032413205312145, 0.3309414643914469, 0.16077436807174839, 0.23970399322288655, 0.15635296822555605, 0.17276748984811768, 0.15952608908616728, 0.1526817829618531, 0.21873829645975945, 0.1120468247081003, 0.12945087145893805, 0.19181033656481775, 0.12479900172160519], [0.03167731623585907, 0.12185186147689821, 0.03287272174812613, 0.09570823772059334, 0.042716185487205946, 0.052213844798144796, 0.13726810924708843, 0.010494770624885156, 0.03171363263390958, 0.05418971578981127, 0.08055409161193718, 0.03338150755171815, 0.16346143678792063, 0.006731480046460826, 0.026584405850078312, 0.044498672904146296, 0.07714467093108163, 0.03416573643804558, 0.12649989311373042, 0.0837142349431111, 0.1259977454620023, 0.08497690872078942, 0.09789076092983447, 0.0433720218678636, 0.05308393681902559, 0.1308684099105097, 0.14358229784955903, 0.2174923310597097, 12.384488640293, 47.15351827682988, 43.703475998293975, 64.74474445466073, 72.05070803242346, 41.502328149734005, 55.50783726476855, 31.053075175131525, 53.02378454516011, 81.09557597867905, 85.3506729679723, 13.991944578386123, 0.30760066523667307, 0.7507064722238049, 1.9330262681168897, 11.649000106319306, 10.959816132822345, 20.406026878664573, 27.854721584627708, 19.888270093548684, 25.631137778682096, 23.603221408782467, 16.976651568566602, 20.22511932157701, 14.63344527829078, 20.43877278604815, 38.51972256937335, 35.26963487748177, 45.7475721451544, 12.549548841291859, 10.295333285485546, 9.73680248183589, 5.426847713608896, 8.485072178225364, 15.688192190662509, 37.38513385095904, 61.12757782782278, 57.12876850558866, 31.04071382553347, 19.95342654566611, 25.733992130525653, 25.168849191358014, 6.886495015313549, 2.616577840620472, 9.072644210630848, 3.1154533163193734, 1.2257399434043517, 2.274083096173502, 6.24605433594796, 32.21239443748228, 53.801708221435554, 63.5602435758037, 62.143471702452636, 61.407866477966316, 53.82895300465246, 55.52941030071628, 55.71658188296903, 56.331629137839045, 58.106740905392556, 66.03205065573415, 46.788137728168124, 18.20824050134228, 66.14105332282283, 57.45652175718739, 62.00949138210666, 51.7916190239691, 53.82228497535952, 59.55763739924277, 59.17572798267488, 55.862446984937115, 47.99101098891228, 56.302623210414765, 54.480482224495184, 60.21043354465116, 58.95997016660629, 56.02139319142988, 45.738644830642215, 17.40072842567198, 5.83659517188226, 0.180096622376192, 0.4913184779786295, 0.39284719094153375, 3.8876723954754495, 23.64390030983956, 22.557268450337073, 22.2915082593118, 46.18670894253639, 51.88586965683968, 46.44299660959552, 30.08588929330149, 11.195314257375657, 7.104137530249934, 2.002410177261599, 2.097983629472794, 4.807868772937406, 3.0217839296787017, 10.55886164788277, 18.80903974656136, 24.415177529858006, 30.212175884554465, 18.14911469336479, 8.286598286321087, 11.42253618086538, 15.665876846159659, 28.498109925177793, 35.902207282281694, 32.02387552107535, 31.962011898717574, 25.189769152672064, 12.205878611533874, 3.564548766420734, 0.6337333650838944, 2.92503156008259, 0.2397282016012938, 0.6718407847708272, 27.400342456756103, 86.12569409032022, 43.40022971553188, 25.382439897906398, 48.80223166558051, 54.800335822566865, 60.61675971554172, 25.503243015658473, 13.65344697429288, 29.670478913091845, 4.21440730171819, 0.30183337148158784, 0.0837267987850693, 0.1114258261757993, 0.06041408824403921, 0.08224305501508136, 0.05237101156625056, 0.03813776442961347, 0.12677646617615415, 0.11984288782602358, 0.07528525296478503, 0.10348338663818375, 0.15323017934157004, 0.04816293273301375, 0.186475346225404, 0.06747893959043488, 0.10018990570378881, 0.019666622317726576, 0.04989115048139807, 0.018410012125968933, 0.0029529469517705544, 0.10551090727770522, 0.03522054374878926, 0.052695047606023095, 0.09504694296347518, 0.028587030547280467, 0.19286304862508852, 0.0505116357347898, 0.10157534507133308, 0.0231276715790192, 0.04193027886832434, 0.032674339449694084, 0.040608149006842606, 0.013819053081885703, 0.0733546347868058, 0.00351845151125153, 0.06814305355111439, 0.01942832683843951, 0.10060414476620574, 0.10488548075720187, 0.08033354255941608, 0.08415170179139222, 0.04720348038620526, 0.020239288362884716, 0.09920815636794414, 0.07795456376287245, 0.007317050842703471, 0.06234925315384904, 0.02298963977204215, 0.23048315978338643, 0.2555541072281138, 33.16288671185894, 69.21123366202079, 52.290469984854425, 87.2331125505509, 64.26980033997567, 44.96807167606969, 27.025132448442523, 41.20653437029931, 70.34635190040835, 80.87483283012145, 96.65459079127159, 16.69146780044802, 0.6818583956168545, 1.2948154561942624, 2.913876339312523, 11.019464596625298, 14.113086000565561, 23.601636771232855, 32.597608450920355, 29.98450190790238, 30.44805742079212, 29.123649520258752, 18.496354279979585, 19.42353786960725, 14.148689354619673, 28.16003299528553, 46.789188923374304, 42.71528582419119, 47.31752041847476, 15.325326861873751, 15.85531653896455, 12.968776668271712, 11.52415204432703, 12.78487830392776, 19.87586755906382, 36.75815082365467, 54.61059116548108, 48.15297742043772, 30.464682386767482, 25.121747409143758, 23.949127389538674, 11.68284918031385, 4.667606776760471, 6.897693872451783, 11.883907914161684, 3.042000560991226, 1.586222309739359, 1.945778874139632, 5.201912531929632, 42.87207472708918, 62.29613034955917, 67.69919133955433, 62.07946254361061, 62.688430124713534, 57.294594549363666, 57.279010972669056, 56.87261419911539, 59.988713725920654, 62.5120803617662, 71.93318597732052, 49.674013737709295, 22.69232742248043, 72.91479833664434, 63.589069074200054, 65.7366491133167, 56.36429463663409, 58.95217249470373, 64.90188244850405, 64.25418930668985, 61.56632238818754, 55.03132812438473, 62.02195275214411, 60.027380451079345, 63.933566924064394, 65.07639654221074, 61.48607069446195, 48.777634482229914, 22.441860552757017, 8.678696059411573, 0.35109812634125837, 1.530673213062748, 1.2569724287717574, 5.433339236244079, 31.90404711231109, 26.108566714871316, 26.49689901259638, 43.25130908719955, 39.301780423810406, 35.44243097305298, 24.43399510075969, 14.773323862783371, 9.944086997739731, 7.0671368318219345, 5.345954222063865, 8.923405870314568, 5.055423773104145, 13.30772436434223, 20.91007301884313, 28.354007928602158, 36.085013266532656, 22.874641149274765, 14.756619468812021, 16.409659231862715, 21.0627414718751, 34.44540762132214, 32.8850789608494, 30.50711262610651, 31.30461285191198, 19.432910373134, 8.992403303423236, 2.8205982090965396, 3.199550403702644, 3.842294494951925, 0.23503678640530956, 0.3115205839276314, 31.553551958453273, 87.04027314339915, 70.84996069631269, 20.156479804746567, 39.16250098136164, 58.48300603128249, 75.99669871791717, 43.769246301343365, 30.462154419191425, 50.474298846337106, 9.419421938157852, 1.5452559724930794, 0.039078635313818534, 0.1988492903089331, 0.07207441759566147, 0.1455609803839076, 0.0717635314551092, 0.030280768593412735, 0.03789482645750527, 0.04849982372815571, 0.11649169748829258, 0.06117204031456382, 0.15906781528986272, 0.09224430222304598, 0.11197301213659587, 0.018927452807885506, 0.04339450654844123, 0.08063649968995203, 0.07544189496266265, 0.033083997306323824, 0.013175210765292569, 0.07700335835256884, 0.043610788491224094, 0.10002504358248365, 0.18952140374289406, 0.10983908954527109, 0.35941728961563885, 0.15277397398266102, 0.1631589852754147, 0.2683891902767843, 0.15965549665833675, 0.18780775698682955, 0.14109528533393337, 0.13840489179616974, 0.2921196217498472, 0.13005461003030502, 0.1480146221095516, 0.06950981569506469, 0.2474331155779862, 0.29590599599384493, 0.2532701692994564, 0.25823006766938394, 0.17778576411787542, 0.1388112707964836, 0.22013884308117054, 0.29862931599059417, 0.18391126526459572, 0.11402535402486402, 0.33117619373144647, 0.29648966306159574, 0.9670515406516291, 54.97068435915055, 91.44948005676271, 72.0931637671686, 99.06303590343845, 91.74332834059193, 63.35519775267571, 66.89387382999544, 39.011289688848684, 68.25482645342427, 95.88161714615362, 104.46080561607116, 20.389743158894202, 0.739149882668449, 3.331315075197528, 6.113575302785443, 14.745671153068544, 18.293169621498354, 33.50023015852898, 39.20971062875564, 33.44753311526391, 34.21147746424521, 35.12608397391535, 31.859137935023156, 34.600749169626546, 32.94496374745523, 39.103673273517245, 55.32238760302144, 51.563242943056174, 59.926422565214104, 24.65120811616221, 25.197582514055316, 23.671725603841967, 21.516194920386038, 22.332169509703114, 29.385591283921276, 48.28454940549789, 65.59107034437119, 62.78379471071305, 42.06813396946077, 34.73005402472712, 37.07352899735974, 38.86166695625552, 18.02344587541396, 6.628381484939206, 13.351784348487856, 2.8158955324080686, 1.9204832637502303, 6.8002509205572075, 8.034233479730545, 44.817684081292924, 65.46778240511495, 75.7724803493869, 65.563751036121, 67.59804910229099, 61.2865593356471, 59.18824426589474, 57.84947264579035, 60.99765323823499, 61.77890308441655, 72.97411241839009, 51.095704263256444, 25.3399625901253, 73.88154491301506, 64.66603817478304, 65.13014085831182, 58.27422611175045, 58.487226501587905, 63.959329051356164, 61.990169786637836, 61.024725437164314, 53.59632507447274, 61.70742181039626, 58.574534539253484, 65.07325864607289, 66.80743263613793, 63.604154509882775, 50.18276476090955, 25.73972075216232, 13.73794855610017, 0.3816790386073051, 1.5475758093018688, 1.9191680440018255, 5.038313413819959, 35.30463026415917, 35.7809393636642, 35.97893276522237, 56.609160361751435, 56.778528305792044, 53.315875607152144, 36.233471055184644, 21.086150177063484, 18.531367317322765, 14.45544517809345, 14.66595192109385, 20.626789639073035, 13.298745078425254, 21.082280758888494, 30.419549634379727, 39.50655952576668, 41.849669717973285, 33.51746897543631, 20.73242691255385, 26.317732987865327, 32.44216688217656, 46.58206816642515, 47.626626722274295, 41.279670884532315, 42.8436924565223, 31.862099324503255, 16.10628253029239, 6.974827772186649, 3.936943493543133, 5.515146149742988, 0.3166778265468536, 0.8398854191745482, 34.218427904190555, 100.86531008443525, 57.365628673184304, 33.82996420706473, 65.81082897801554, 77.69419854687106, 94.17850048311296, 58.83790208447365, 44.6023145798714, 73.98973172710788, 13.24655500150496, 1.8875353543027755, 0.11236066028716103, 0.24053458575039144, 0.15755404087324298, 0.2220869740290988, 0.22153997192940406, 0.15325274829181934, 0.1884627161968139, 0.15723399998199555, 0.1938040650659992, 0.17732131565290113, 0.26349060958431614, 0.2027560629311108, 0.2971170277845475, 0.1738065502215778, 0.19289579122297226, 0.2136759721343556, 0.17160020167789153, 0.11175800189976731, 0.11033778980133996, 0.24011763473672254, 0.1455484318637079], [0.055445084919131575, 0.07257949170326033, 0.05071093350829137, 0.1232385955330345, 0.1052490660860654, 0.11417697814683761, 0.0696768152016786, 0.020788989007292737, 0.09416031876518842, 0.011664068818302646, 0.0066825734721797135, 0.037139199463830846, 0.04779698785334345, 0.06739838544519679, 0.028310813715741522, 0.012685757190469774, 0.0663415365101349, 0.0774752302095294, 0.024990533110535434, 0.07947595309345953, 0.06867909293261266, 0.09422611039612563, 0.06954278045844647, 0.04011007311243204, 0.05769623428462975, 0.047284310323096095, 0.20103222720565336, 0.4081697768021015, 6.2341636707705845, 21.594879627227787, 40.536397426359116, 28.27314630631478, 73.29416213497039, 59.47829961776734, 47.85860353900541, 51.488933640141646, 31.68167814131706, 72.25552635808145, 65.21427962087816, 4.763305254520909, 0.225800477989739, 1.4378363494911504, 2.005386030481708, 9.655296610247705, 16.76804031095197, 19.451839731585597, 24.222575426101688, 24.10098587313006, 29.996372961228897, 28.984377922550326, 23.123864627653553, 14.576588561457974, 5.76968296881645, 33.0146054298647, 42.37759328657582, 44.847650989409416, 30.561986584817213, 7.508784436410473, 5.828140502975834, 4.8387672439698255, 2.0335086891728062, 5.490357750846494, 13.116277398601657, 36.890220949726725, 50.015652179718025, 42.966568546910445, 28.309312520488618, 27.94047244133488, 31.216849819306407, 18.660319159107825, 5.646685284952964, 5.369000108011308, 6.590995413641776, 3.880547900353709, 0.32067447660430787, 0.6753991712485591, 2.0579097540147844, 8.321533856853362, 28.509092561660278, 54.33021622319376, 64.64926219755604, 62.88301498659196, 57.646344861676624, 53.45419799127887, 56.581009511024725, 55.3808662199205, 56.07678490300333, 63.09900030013054, 50.62589845349712, 11.40818520899742, 60.111982053326024, 58.93720473012617, 59.60807515728859, 53.52409855011971, 56.45040635139712, 53.836652617300714, 55.98878652818742, 49.54875676862655, 54.99403815115652, 58.47929939146965, 61.02571779681791, 64.70946273496075, 62.98704408830213, 64.31269145780995, 37.39586937812067, 19.14407095601482, 2.077990818408228, 1.1341993006006366, 0.805230298109593, 0.5168907380392475, 5.079880241424807, 16.408939476936094, 22.56983376318409, 25.678004218686013, 42.10629470886723, 44.922230935865834, 39.9835785742729, 28.655891187729377, 15.493466123457878, 4.939504986809147, 4.369128134942824, 1.3786302554991938, 1.4641237066638086, 1.9886413096420228, 4.83738656966917, 13.070980887259207, 22.70369641242489, 24.093531408617576, 21.181453966325332, 12.50123308550927, 14.81347422445974, 16.453866304889804, 18.42090552853, 33.42992951793055, 34.66339334364861, 28.972434305375625, 25.821355081373646, 11.334724118632655, 2.3115591368367596, 1.9891357734318704, 2.9819949163544566, 0.18812764466049212, 0.17944272036754316, 17.97610875098936, 77.04679566044962, 21.855460328440515, 40.25960360803912, 44.57913337215301, 54.31732339243735, 41.300871295313684, 12.409503556066944, 29.28891270391403, 25.30402191223637, 1.7178427115563424, 0.21641398569749248, 0.2540699957359222, 0.061176893481564146, 0.07395674925177328, 0.010106001113120829, 0.03320182162907816, 0.08078177294303333, 0.0426178504412453, 0.011060600292928999, 0.04203276611083458, 0.005916620092090941, 0.027267786922053467, 0.0447609392745841, 0.02061279261514785, 0.14728440242188592, 0.015395963677175105, 0.07318923640395365, 0.047386793735166716, 0.028572032460942868, 0.03961841320438732, 0.058817032409170945, 0.05636555871235267, 0.044961359366894736, 0.10778910720780974, 0.04720226613684528, 0.07441798780834483, 0.24624286009179008, 0.3745091297934133, 0.09681233895882484, 0.019928373494035295, 0.06349049433464966, 0.04564868196124031, 0.05125278366669532, 0.04408272163521859, 0.038961868192399704, 0.017490986238924727, 0.08773206733167173, 0.029839364053200812, 0.06781456271006216, 0.09954969368634686, 0.010542704746307386, 0.017524226793959256, 0.0555030049966468, 0.07468971919508711, 0.029579279118127404, 0.10282369300482735, 0.09742982880843264, 0.058030263941374526, 0.4705002224974094, 0.32789506979527017, 15.56407270892974, 63.498572149584376, 54.925518266616336, 49.05251026153565, 80.13614070030951, 54.893966720950225, 34.96640036183019, 35.419685148423724, 53.891808986663825, 78.32796727457355, 76.16728259671119, 4.312704349717786, 0.29463162405356286, 2.7004008523879515, 3.015819475535424, 10.612609886354017, 18.505199224718158, 29.334029766821093, 30.26347068048293, 29.530520900603268, 27.682249084595714, 30.502896078171272, 26.408555469205304, 19.980014331879158, 12.734027716421313, 38.76480402485017, 49.73936434715025, 49.35093595135597, 34.0312720114185, 10.951058460820107, 13.054437310464921, 8.011793599974725, 6.434292312591307, 9.723599783835873, 16.188667012799172, 32.86199385120023, 45.23629511556318, 41.752991137966035, 27.801118473852835, 24.108842380585212, 24.87830158202879, 8.370016313368275, 6.0782617138278106, 6.871160999421151, 5.496759058967714, 7.12903771669634, 1.1987301346755799, 0.44869757467700594, 0.8213571230730703, 7.417883017370778, 35.9077182123738, 59.53685275969967, 64.1575264161633, 64.68370453003915, 58.41563932357296, 59.38945401099421, 61.71282683649371, 60.91936665196573, 64.66854849169331, 67.64110103730233, 55.20226109412409, 13.913536398641526, 67.89949893951416, 65.82101929572322, 63.56266367820002, 59.26863716494653, 62.720891660259625, 59.50241827195691, 59.52610546542753, 55.20591282075452, 58.956447878191554, 65.06705737883046, 68.08144200232722, 70.2849668072116, 67.57584064237534, 69.52306993546026, 44.8421282922068, 22.781512314273467, 7.086842329271379, 0.6360032529600206, 1.0815510418145888, 0.8135535063282137, 5.79513571916088, 20.60470081144764, 19.17279447278669, 26.660206894720755, 40.610938149113814, 36.28619163267074, 31.867282736685972, 25.26380585085961, 16.09637854560729, 5.922321513775857, 7.479846169871669, 4.348394976508233, 3.768399492386849, 6.96826760807345, 6.431149023194467, 15.109623958987576, 24.92596426317769, 28.35180355656532, 27.261208142003706, 18.391313206764963, 22.632846640002345, 25.12990790028726, 28.439578356281405, 39.19827299733316, 34.72503339090655, 25.523121587691772, 18.052900914222963, 6.193971143614862, 3.321567249874915, 3.7032393630473845, 2.4781583778319822, 0.2794581495465771, 0.4415013124385188, 18.2792216731656, 96.21003720068164, 33.20913537856072, 23.87128010872872, 55.118655773901175, 64.20723461335706, 58.76393010539394, 32.71320069989851, 39.918671192661414, 40.53070606723909, 2.848107016855671, 0.19422987205607278, 0.22535964035459105, 0.10693911733406206, 0.027549975408962177, 0.05493596203685288, 0.08125002886499129, 0.018739698064183036, 0.13651587219247896, 0.052629937793338494, 0.09565035977791395, 0.13640868117011365, 0.08121486542926681, 0.056814616470928156, 0.04472275362199834, 0.07856803931175702, 0.021784765413030985, 0.01645111764270452, 0.10230894320674482, 0.029549484043532324, 0.038923448882997036, 0.05882533297183053, 0.07562479079370538, 0.24027779307817262, 0.13319716398273745, 0.1454473848664953, 0.1567426158656036, 0.30981349488419874, 0.43570303808777566, 0.19087858978779088, 0.09028850273499567, 0.16623999172401044, 0.1407893557822512, 0.16695472111384715, 0.22326278109704295, 0.14329717524590033, 0.1878059949846037, 0.18812448837824408, 0.11775017310414584, 0.11198235840927209, 0.21315717739203285, 0.17746288870130816, 0.16483284142469207, 0.13393435507051407, 0.1629966052789842, 0.3412145502384632, 0.21444834197961518, 0.18366777187874242, 0.2756637467011329, 0.5148194201530949, 0.4337789316571528, 28.747627581319502, 94.38439353819817, 74.47140662900864, 56.680363147489494, 98.38038659864857, 82.13472166369039, 61.9173352949081, 64.29167932079685, 39.91592553354079, 90.86564310135381, 77.3940509365451, 7.443970211090581, 0.5004553941469039, 4.932746252705974, 5.917983372365275, 14.61742239613687, 27.359081083728423, 35.35643692939512, 37.21058837829098, 35.39320522739042, 41.686581488578554, 43.35959396054668, 42.31350175796017, 38.235444868764574, 23.33854183073967, 48.877435268894324, 61.522168267157774, 59.76678602157101, 44.51912110851657, 21.009222692058934, 21.901869812319358, 17.481901876388058, 18.940945133086174, 21.03724018219979, 27.45993894915427, 46.267588215489546, 53.864854458839666, 50.631723173203014, 38.71712761540567, 37.83321757470408, 41.43034088996149, 29.11166471819724, 13.42607109777389, 9.230410764294287, 10.114141356560493, 6.440733334710521, 1.0523578212145837, 1.4408578002645125, 1.828629689351205, 6.255085102973446, 37.277252981739665, 63.258589775331565, 71.70859106125371, 70.03271133668962, 61.31944448717179, 59.06752547910137, 61.29090532179802, 61.8046259880066, 65.78755755578318, 68.81512134305893, 57.14420695458689, 17.06511082187776, 69.67762700973019, 66.05234499900573, 63.27153751927038, 61.83640110877253, 64.76447789899765, 57.83644645444809, 59.5384217077686, 56.32905214063583, 59.34590785734115, 60.714532636827045, 69.28955554962158, 70.20484062933153, 67.4355374613116, 72.03815644787204, 45.42561615667036, 27.315858525614587, 10.293673142310112, 0.8553838681790137, 2.680498991281756, 1.2067309118086293, 8.986968859549492, 27.705373417946603, 31.05140228425303, 38.98972842001146, 51.80948934247417, 51.78078543755316, 45.859163576556796, 40.84872007369995, 25.84925686159442, 15.853993719623936, 17.570784745677827, 14.369299142591416, 15.954430910848803, 18.270500283087454, 14.082320890119, 25.096863892770585, 34.75900111659881, 38.472740419449345, 34.11574809781967, 26.77332412812018, 30.82058845027801, 35.05521458964194, 31.035085224336196, 46.21466759712466, 46.938501788723855, 36.90108591510404, 31.225496684351278, 15.99560206936252, 4.552360676950024, 5.586650467688038, 6.258940792852833, 0.7762642685444124, 0.5980503991726906, 20.9418991304213, 97.20296952032275, 28.606045707579586, 51.30399780888712, 74.48875134991061, 81.97492430287024, 79.91185957385649, 42.9317065208189, 61.908713925269346, 54.50874290158672, 2.404863988199542, 0.7129661618701874, 0.37532605531234897, 0.2580240206612695, 0.12276658578024757, 0.15197053161119262, 0.21489647277180227, 0.21721689180741388, 0.23810426374116253, 0.1963944075208518, 0.41829215783265333, 0.1812064999173726, 0.16593409281584526, 0.25116037847774647, 0.12049387870056015, 0.21638340346755522, 0.1977371145039797, 0.13984334444807422, 0.20190028143265557, 0.23055022312027795, 0.12914702566640993, 0.2464854035286173, 0.19946830467351023], [0.00532669743763343, 0.12159294674112914, 0.08912263182742942, 0.03644888912658057, 0.10449422433251336, 0.18365381375676204, 0.16950629951973117, 0.05029496308716555, 0.02375152570405795, 0.058730146547238675, 0.033828504533777316, 0.03396303340372059, 0.06349954566347503, 0.0306244969232789, 0.07216735938263517, 0.0627774924730822, 0.026049437076454202, 0.05708185092155492, 0.07812619810142825, 0.06161369000291152, 0.10866845357081584, 0.060451392895512046, 0.12035194559082871, 0.049016396815498034, 0.030482345478489038, 0.18524286397282155, 0.07799143557466807, 0.22216732133059736, 2.6350914278338036, 12.444799984655074, 43.051534929583156, 34.62972764045962, 56.398285896547385, 74.3846594902777, 42.93217328286941, 53.09788596245551, 30.850394541217437, 59.80036543261621, 50.232214081671934, 0.9979391025920069, 0.04374201552221372, 0.6979327588792771, 0.8241082980267463, 6.395571164546475, 18.611285609583703, 22.070292465148434, 30.241856459648382, 22.18928933143616, 31.940538883209232, 30.539568278097338, 18.613472330954767, 6.989853391724249, 17.840494763466623, 32.13592194741772, 36.58658242994739, 38.3117232015056, 19.106043577194214, 5.900295444073216, 3.512975972506308, 1.407235856017759, 1.8574073838610805, 3.953233342016897, 11.803957262346822, 26.82168499115975, 34.46478020760321, 26.625817514234974, 29.37031561328519, 30.136376080974458, 25.308597357042377, 11.06139277258227, 6.353611119331853, 9.489788278456658, 5.456226266199543, 3.2289132668126017, 0.1166359901488308, 0.21363143178243793, 0.3890705000488989, 2.35390234858759, 12.368800140196278, 39.27066426123343, 63.04681708735805, 70.43800200185468, 64.9766702805796, 58.144819275025405, 56.6781234741211, 56.958592553292554, 58.638429949360514, 59.2609061733369, 52.9319187133543, 10.062195447183425, 55.26914535030242, 60.06825939301522, 55.003302789503536, 55.58649647620417, 50.513397032214755, 47.67240078218522, 46.018478485845755, 45.68279812412877, 57.78912698068927, 62.17441528074203, 65.22710969371181, 65.19427945536953, 67.64610598164221, 53.505792848525516, 26.201099349606423, 17.49516340994066, 3.632788201493602, 2.658382461917016, 2.084144772060456, 0.539627124465281, 3.7772250704226957, 12.907703403503666, 22.952125610843783, 26.793787133309152, 35.44019522205476, 35.61301877421718, 30.646262630339596, 26.463843237969186, 14.697700565861119, 8.497082475692995, 6.017875354136191, 3.2127587401097824, 4.271707246380468, 1.163834155567231, 3.7292314392905084, 8.020435071760609, 15.75971268838452, 14.523469863399384, 9.874995427746928, 15.363589582904694, 20.045863082331998, 13.546708495386186, 12.13372955399175, 20.325522192062873, 28.17670306851787, 33.09734782864971, 21.683107460698775, 6.0126134945500285, 0.21198403631006518, 2.0093712811508486, 1.0488997616114155, 0.595447845276325, 0.08723804787282022, 17.26831509220985, 35.62040459725165, 34.561458787610455, 50.69636383364278, 51.89627962727701, 53.19066962888164, 29.95892805437888, 19.732587299039288, 38.29352732627623, 21.39549574544353, 0.37652369588613516, 0.21007730475356504, 0.060626225651151715, 0.10373384376326877, 0.03220179343536016, 0.02401971967980987, 0.09805974460417226, 0.024972124017714977, 0.20859138529387214, 0.040137165811874216, 0.05481855140157765, 0.07592489807716302, 0.050434276176195954, 0.07452966810594644, 0.11515000940210397, 0.07920530189069049, 0.04267718778142045, 0.07532699709577907, 0.04799459640297198, 0.08961777743552962, 0.0881215081279797, 0.037858601990005666, 0.16152462861951322, 0.00863420735714176, 0.0616564798439222, 0.0832065254930527, 0.02525035566049478, 0.0385048431194117, 0.11854612313571478, 0.16376690668684823, 0.02048607592681243, 0.06330834543933311, 0.059564040913697214, 0.026155940534907485, 0.06040013395249844, 0.11440160278711589, 0.031086633717941663, 0.07030129177315582, 0.10877243468477842, 0.05896476863492882, 0.03727075974306753, 0.0516248993845957, 0.05515110250862856, 0.07806170881996233, 0.05241292806702757, 0.058306411825000286, 0.03419094456119403, 0.02470787347955329, 0.06452105879302948, 0.354919740629773, 0.3256611574080683, 5.524219082247827, 33.59133112815119, 64.58189156747633, 44.51892891237813, 73.80345052288425, 78.26774320294781, 44.11106125000985, 30.183069936690796, 38.37989791747063, 76.5009900062315, 51.68160830774615, 1.3450271876588946, 0.10142870818174655, 3.172583373323564, 1.8368139598638782, 9.766846856763287, 21.289179901922903, 24.3479069202177, 33.828865943416474, 30.03605361907713, 36.18997589234383, 33.45055726266677, 31.264290886540568, 12.770665595608374, 23.608324412376653, 38.722830741636216, 42.31460394397859, 42.16648740153159, 24.570672050599132, 8.69301074935544, 8.750236168984445, 4.842684220883155, 5.436542341786047, 5.90412809002784, 15.054864729604414, 23.549522199938377, 33.982485571215236, 29.30414326729313, 30.005484627139186, 28.650931350646484, 23.975389619027418, 5.772445788306575, 2.2484857084289676, 4.014106811054291, 4.085661139219038, 3.872215315218895, 0.21416311212364705, 0.5408964402252628, 0.46114297944211197, 3.5744593701054974, 13.437935286952605, 40.63159335044123, 61.22458196455433, 72.73975864533456, 64.80761220378261, 59.91617733432401, 60.61061728385187, 63.324250252016135, 62.38206555766445, 63.18713988027265, 56.670898468263694, 13.626262987813643, 63.109798585214925, 67.32149847092168, 64.1926786976476, 58.871226541457645, 57.607964469540505, 53.11262622956307, 53.40076746479158, 48.83399501923592, 63.104981914643325, 66.6483569914295, 70.59891331580378, 72.15905174132317, 74.38251787616362, 61.561835196710405, 32.00085513053402, 22.828965148618146, 2.083275967067288, 2.077828775490484, 0.9712447995139707, 0.7317293711727666, 3.5803559182151674, 16.81940570954354, 21.81767809775568, 27.63559837495127, 33.12491032385057, 34.097481619927194, 22.175635560866326, 22.48067632798226, 17.518876098817397, 12.840497512971202, 7.95341206173743, 3.376903803117814, 1.8951175409939982, 4.204516555032423, 8.708914979811638, 9.221333419123004, 18.17082501226856, 18.88812061279051, 16.314048517134882, 20.20572320107491, 25.37169456481934, 22.56896888056109, 23.41323748711617, 29.91597810099202, 30.00784589398292, 27.58479975884961, 11.005339161042246, 2.4077998822735203, 0.46258267315645374, 3.3639989601027582, 3.8729750292916454, 0.4705967495758688, 0.08204951056189115, 15.98603540851224, 53.71882853969451, 19.509057306474258, 47.649929523468025, 63.89673586814635, 69.61308048617455, 52.73800065440517, 32.61074642981253, 54.147982904987956, 29.039859848637736, 0.8986813190483278, 0.0941476783144378, 0.27594297042777466, 0.0200033275365469, 0.08824844889703297, 0.010381199047720481, 0.066790203563869, 0.03267260809098521, 0.04825196747157363, 0.03971121326509503, 0.051842778620700684, 0.04720364126466936, 0.055498695752072724, 0.06119428750788493, 0.05708425260719754, 0.03500208228586182, 0.06142426710275393, 0.1811558155403022, 0.11511107681379204, 0.032309325366851785, 0.0970167541996606, 0.021079817050767523, 0.10101846043741512, 0.1007485140355364, 0.1690670859909827, 0.37769357343354537, 0.15262867774694197, 0.1696690778818823, 0.23757106654586332, 0.3507845205885749, 0.10562085621659795, 0.14587617959947358, 0.15663775375052807, 0.1813515050396804, 0.14842205831120092, 0.09478550779843524, 0.10176506674578113, 0.22113711693354193, 0.2349950346134363, 0.23291864522522499, 0.14039451406607706, 0.1939397085938723, 0.2082748837288349, 0.2227672294623429, 0.10756042230153277, 0.23124242952514082, 0.11957553846220817, 0.15403170649322773, 0.2230117953712902, 0.5755948299361814, 0.4824626241480151, 6.84209966851819, 55.32725134203511, 90.31387544447377, 64.56473119797246, 86.85005387952252, 98.24912840320219, 61.013656508538034, 65.75921058654785, 39.56019009313276, 77.26786044336136, 62.00727132058913, 1.8247717931385965, 0.2819842785116165, 4.111041080567145, 2.5755464165441455, 11.795013277761399, 28.47272042305239, 34.25776143227854, 45.79298534700948, 31.732404193570538, 46.604880671347345, 49.003943474062034, 42.17031955718994, 25.999089440991803, 39.55637754932527, 48.7136802365703, 55.38685567917363, 52.867246673953154, 35.73358458857383, 19.212294701606996, 17.18776333716608, 14.65140385012473, 20.066910520676647, 16.34652280038403, 30.098276138305668, 35.99670502447313, 45.24143342048892, 32.965305159168864, 44.247575421487134, 39.09886444768598, 35.322916353902514, 21.057475689918768, 12.811937755154027, 17.23864040067119, 9.310545767507246, 6.041438992946379, 0.4086043018727534, 0.7504102719887611, 0.4979972018589897, 3.5577934643914624, 15.32197911893168, 41.38615146760018, 66.85459521508986, 77.43325894878757, 68.70494196491858, 62.74801877237136, 64.59074827932542, 64.87809327340895, 64.55530574244838, 64.92243174583682, 59.428818918043575, 16.681297094591205, 63.581710707756784, 67.67926569907897, 65.15535385377946, 62.635156493033136, 58.50366123260991, 53.8189156593815, 52.94457620190036, 50.80258946264944, 64.7513928721028, 64.30912602332332, 69.72843739294237, 74.48324434218868, 72.1797461663523, 63.14728467695175, 32.16768726225823, 26.64174233713458, 3.8989788726452863, 2.305033538610705, 5.29336259249718, 0.3445348365893287, 7.514315468649711, 23.324954740462765, 31.202801850534257, 43.384089162272794, 42.10660457611084, 47.2800107925169, 38.304898277405776, 38.7998386352293, 25.41017693857993, 22.258960431621922, 18.653831558842814, 14.63295792379687, 13.44945332696361, 17.166796307409964, 18.381652409030547, 18.50660147205476, 28.77951841200552, 28.93683683487677, 25.460587240034535, 31.717332486183416, 33.89494219133931, 30.633656132605772, 28.198942907394905, 33.405300955618586, 38.21810014786259, 43.659886698569025, 26.31657784984958, 7.190613044846443, 0.5865196114586246, 7.060080487881938, 5.040782545843433, 2.926746371292299, 0.16915460387545248, 21.55859378076369, 47.822866824365434, 49.78963344327865, 71.26460229196857, 79.49502145090412, 90.42953045137467, 70.88307334530738, 46.75122822484663, 72.4476440491215, 32.223655562247004, 0.6370506483700968, 0.1912895346721334, 0.31637978770079156, 0.23734284895322016, 0.2664648693415427, 0.13197626497957016, 0.2765681594610214, 0.18336345111170124, 0.4396541518790107, 0.16149329562341014, 0.1803722148460727, 0.1416262302307352, 0.1368801776439913, 0.12967934952147547, 0.16380309668039122, 0.12124747939167485, 0.13329568288979993, 0.28206070344294276, 0.1217944278652149, 0.3683072190371252, 0.2199290269204686, 0.12014936130013197, 0.23070010056178417], [0.01884945931153432, 0.12290989018736348, 0.05796969703008091, 0.08350585902770681, 0.1894994323412257, 0.22380612129645966, 0.19907281944347968, 0.07498789593697557, 0.03695931052789092, 0.05487453710708407, 0.03186111222021282, 0.13856120437623995, 0.14007934549402806, 0.05386152372304952, 0.0341341697851256, 0.143261322331044, 0.08809061946287271, 0.06674544870733254, 0.04362259007569763, 0.044649576903471065, 0.08211478891391909, 0.15445978110355718, 0.04951913435492785, 0.22727918090118518, 0.015010594638184676, 0.18489063206699588, 0.06698092115261862, 0.5703399570718889, 0.21473582413408066, 10.162547326857045, 40.40384877112604, 54.56940235630159, 39.19480169973066, 67.54477547061059, 64.23001966168805, 53.92246230956047, 40.69597121207945, 50.232692610832956, 35.460658227243734, 0.573910907391579, 0.3341256015964093, 0.7879447804823999, 0.7862690704003458, 3.5077199964754047, 10.747022648011486, 36.73647188371228, 36.10645686426471, 32.2589353207619, 27.493200648215513, 25.92958111916819, 15.82154199000328, 20.518944071185206, 17.631075497596495, 19.79273488444667, 34.821409948410526, 31.135703825181533, 16.606136637349284, 3.3141973614692692, 4.296705001784909, 1.7072095337413973, 2.1249246741494825, 6.554768402730265, 11.379266554309476, 21.307826849722094, 20.80856796233885, 18.67075462495127, 26.972702126349173, 29.916884168501827, 30.479010805006954, 18.25405182376985, 8.853283697558988, 9.940057742980219, 5.376498208891961, 2.6568095914779173, 0.33403121956413795, 0.049026593445770206, 0.06869247648864985, 1.1657999984679686, 5.0713731108173254, 21.492390055810255, 53.19538431782877, 67.56517179550664, 68.69426527330953, 62.36351274674939, 60.53927329278762, 60.03303650886782, 57.28004255602437, 57.77051533422163, 43.24741025124827, 15.186424947554066, 55.982110654154134, 55.81588060625138, 54.53854114778581, 53.49781866996519, 49.28267102087698, 42.00149290023312, 46.18281402895528, 53.71029738456973, 58.91216824131628, 60.996841307609316, 60.65898795281688, 66.59667584203905, 59.74135729574389, 41.10014007937524, 30.345754161957775, 15.617774859551462, 4.1531825354022365, 6.108020736325172, 3.6896569305850617, 0.8397467266167364, 2.1129830181598663, 14.346416035006124, 24.187378037360407, 30.30648535297763, 31.66488647460938, 25.310068245856996, 29.433287305216638, 27.276477929084535, 14.807902497629966, 9.914039681034705, 6.865426003932954, 4.35376666245922, 3.483204692602158, 1.6410907526170055, 2.4878375616765793, 4.4677752544803, 8.081874097547225, 11.140204956454616, 15.668130247823655, 16.240787467648907, 21.677151341592115, 13.537340894822153, 14.679312494493301, 26.478242258871756, 28.60300979306621, 30.12525812272103, 17.092941999435425, 2.1220351130731645, 0.9123711263941181, 2.621523459111491, 0.9440328048602228, 0.5673789966010279, 0.06045246924904566, 6.568997290826614, 24.524631269516487, 52.99884219323435, 43.272482041389715, 50.537680425951564, 38.44365212225145, 20.65549550517913, 34.639419817155414, 43.761954615193034, 3.6212831543337916, 0.38318921241068077, 0.13446526932379893, 0.11133039460307169, 0.050852567843732335, 0.07809262812858628, 0.012888852844855959, 0.07372386618367127, 0.041234169245487264, 0.028102173500003356, 0.0445772965078152, 0.05301003614740987, 0.0807727101228891, 0.13454923256030007, 0.030719556943363244, 0.06013689848083643, 0.06724880677798102, 0.022755333695620782, 0.09953195875089976, 0.06051024760029489, 0.13039754162872993, 0.09885791629072159, 0.0486346781854668, 0.03741084275046184, 0.020540910585212614, 0.13288852247980334, 0.06948867932923379, 0.1533125184716717, 0.046390768350853075, 0.20257889743774168, 0.18912052525387657, 0.08379297345996865, 0.03763495028139122, 0.06689872757922258, 0.057751557324081666, 0.19802828920224022, 0.17160636102480276, 0.07974841992460913, 0.021413766268280246, 0.11314518794777895, 0.024222575931719715, 0.05484591223179333, 0.0454654835254675, 0.06667289252002394, 0.0702889194531787, 0.1309498297351022, 0.058363987162949583, 0.18299251133876462, 0.03171845515739293, 0.2846151776611805, 0.17974224542417835, 0.8845911847968256, 0.45374054762144245, 24.5212992160551, 79.9909737802321, 68.95120405381726, 59.1508601557824, 81.79779006588845, 67.65849282664638, 36.64289982088151, 37.86821296138149, 73.30877688623244, 37.296221563892985, 0.31553056391496814, 0.30946599740174513, 3.574771933978604, 2.877818725762829, 3.5045303740809044, 14.534031825680888, 41.83768687709686, 43.549319005781605, 30.62617225031699, 30.64320710397536, 33.911459292134936, 25.747314460815925, 26.768574137841505, 25.801064660472257, 29.561144805723625, 45.04658183743877, 37.73168702279368, 21.057118754233084, 6.41422595708601, 3.6291193144936718, 3.217414838652457, 4.140124965098597, 8.690572996293346, 13.338891517731453, 17.64319758261404, 21.505794755874142, 22.069200085055446, 30.372806749036236, 22.953574926622455, 29.244356539941606, 16.077494294412677, 5.292760018379458, 5.952486011289782, 4.57164304871713, 3.1636815542174928, 0.07491330195578837, 0.12360918290552594, 0.12355654500424863, 1.8276813337879798, 6.311275507173231, 27.911797954190163, 54.08349913935508, 68.6786699295044, 66.636440830846, 63.794075673626324, 63.98360460035263, 65.96846903524091, 64.47210442635321, 66.86540526728477, 51.85465151263822, 22.063757796441358, 61.82718353886759, 63.67678111599338, 64.69966465427031, 60.79145423827633, 56.714236736297615, 49.72027417152159, 55.07234434927664, 59.9976763417644, 65.51072059139129, 65.85294738892587, 69.2229066356536, 68.21998796155377, 66.9467552246586, 45.46872300486411, 33.55542967396398, 21.437392542439124, 3.338418242431456, 8.097323333063434, 5.568304561799573, 0.6380421500052176, 2.6447321234210848, 12.921725876869695, 21.290823375025106, 21.914764604260846, 29.836328491087887, 25.146136706875218, 28.138548212666667, 9.296147727197217, 9.086715713624033, 10.716586036066856, 8.196181770293943, 4.642643342095037, 3.3315798351841592, 4.609856740120919, 9.556666651079732, 10.034937916263457, 10.51861518813718, 18.25369292689908, 22.607604226758404, 24.27078723907471, 31.42779684835865, 22.626659101055516, 23.307459008309152, 32.80163838017371, 26.623373877617624, 20.815098708675755, 4.045114618155265, 1.9690156079107717, 1.4322463591252605, 4.151946498501686, 0.8078870297439638, 0.4558792812449317, 0.1442321242704507, 6.164819107901666, 19.766064728460005, 36.87447655585505, 56.42278894301384, 62.821767176351244, 61.6705358412958, 43.965549161357266, 49.11696657057732, 54.66175848437894, 7.482321185450401, 0.9915054349168655, 0.10478129279949974, 0.12090695330933218, 0.06211995154679303, 0.12657150701289216, 0.024175383000364228, 0.05907017850287019, 0.06703706773658914, 0.02293164500095431, 0.02398424406325625, 0.08160273574533002, 0.0842326466414717, 0.08486673761639865, 0.07769964800606813, 0.09755676957748591, 0.12868691325908707, 0.08875724619194385, 0.08690795590800625, 0.09269380431261756, 0.04927329674002625, 0.15281298317976538, 0.07463394799419949, 0.03708344741514133, 0.12416619011351179, 0.1899382015389781, 0.13678806323197581, 0.24301419785666853, 0.17897205126862373, 0.36439296939680654, 0.28889549475523735, 0.20275993933600767, 0.10486501088786511, 0.14412018350295483, 0.11846745356677041, 0.2281227356363689, 0.301850256059439, 0.2608584846940733, 0.13194551421028952, 0.13579239407854696, 0.1553541274681207, 0.22154864404470692, 0.13943587760290793, 0.4055119113576028, 0.19826098074836118, 0.31386974658216205, 0.1809021178632975, 0.2867220726705367, 0.21131341826290856, 0.3003368340432644, 0.17829902770538486, 0.8538149813971213, 0.5745759942839223, 49.11418561012515, 106.1015958170737, 93.49560014663204, 74.17327511695125, 98.62821763561618, 88.40768198813163, 68.99498554968065, 52.60874286774666, 66.8568858792705, 45.607390557566, 0.76822193880235, 0.5895543615183523, 3.7812896265137583, 3.7531355888612814, 5.636143424818593, 21.133487301488078, 52.644036354557166, 52.105447861456106, 40.307213337190696, 41.97573077294135, 43.185303441939816, 37.414406499555035, 39.601971180208274, 39.32422030356623, 39.29599492780624, 55.440450945208156, 45.39879498943206, 30.880304574966434, 15.823595350788487, 15.65572084919099, 14.161783206847407, 20.166393595357096, 20.61401055705163, 30.98076431981979, 30.678983042317054, 33.25676471956315, 25.374275484392722, 40.34528386208319, 34.80517525826731, 39.24328611743066, 29.960775490730043, 16.328243574788495, 20.21209901379001, 9.338368119732026, 3.6875138455821626, 0.37168741346366946, 0.41967050322601873, 0.12912116253808623, 2.3895677251200524, 8.129786339498336, 27.686406796978368, 57.41183811618436, 71.64101646792504, 68.29790192265665, 65.16318682701358, 68.58547441421017, 69.53066364411386, 64.7580099105835, 68.1739785594325, 57.193813170156176, 26.353450090654437, 67.32912355853666, 65.928021554024, 65.25811995229414, 61.01257785674065, 59.68986442012172, 50.665400643502515, 56.14474388860888, 60.33535318989908, 67.878325985324, 64.31595486979332, 66.15680556143484, 66.42569972622779, 66.01177200194329, 45.59148926888743, 35.13808250427246, 23.318845648919385, 4.205300048474343, 10.824078590639177, 9.725224625679756, 0.5412159908202387, 6.708725844660114, 22.666245622019616, 31.196781012319754, 38.93494467581473, 42.22676638633975, 32.46702882551378, 40.35434061481107, 41.94643851249449, 27.40066016874006, 19.39874456774804, 22.047501533262192, 14.523851313898641, 14.07831418898798, 13.226282231269344, 19.98840820404791, 17.202864462329497, 19.729021864552653, 26.0972624440347, 33.160576435827444, 33.48639595893122, 39.723847066202474, 29.963166175350068, 30.566328648597967, 36.90390609925793, 40.8669630173714, 34.71921651594101, 22.31537784299543, 3.3717976125978657, 3.2202735110636684, 4.432800460246302, 6.336655203373202, 1.8523529195977797, 0.2990563333995881, 6.847683652754753, 39.55649914280061, 71.04539671251851, 74.51159523379418, 82.00046677743235, 83.10386873060658, 56.91049645023962, 64.12204073321435, 70.78408841163882, 5.4815422238842135, 1.553212255239487, 0.13770140857706148, 0.35476024112393784, 0.11507249662592528, 0.18680678650496468, 0.0916222847938057, 0.1531565582920467, 0.12109966272668493, 0.18281966658128848, 0.11920650624820303, 0.22890788382820546, 0.19862792154233302, 0.20887686029797603, 0.19263768087952368, 0.1990272218902265, 0.29622790613962763, 0.2004002965986729, 0.19739712468318402, 0.27635926260582866, 0.24786571010706887, 0.22408865452293428, 0.1835975216160859, 0.10151804935547615], [0.04314005810527071, 0.09666753301937735, 0.095327430735192, 0.03586681169127265, 0.1009647653348023, 0.2751616833190764, 0.3142806761447461, 0.1472900867942841, 0.03719452633372238, 0.0981086133528621, 0.015313003058244866, 0.1778864127493674, 0.21649401124206283, 0.23093947239460486, 0.09666698909695111, 0.0021951287072302116, 0.009476176290322215, 0.05583881963825515, 0.006158549700968809, 0.06576358445829923, 0.04587171313863608, 0.11528763709770096, 0.015175695204356266, 0.05671776763554062, 0.07829487534059633, 0.08560478672265046, 0.0784260219323539, 0.04412992031223351, 0.15147570009914138, 2.3607755668701667, 27.554648499335013, 50.67202160435338, 30.54381620499396, 49.48739128728067, 71.93560215734666, 56.397305304004306, 49.049454735171416, 38.96482136941726, 24.868250508462232, 0.5834800810102494, 0.05566573356308284, 4.360714650923207, 1.9288370541987883, 0.2422069710108542, 7.731765297151382, 20.50505299721995, 30.142804845686886, 40.58129679772162, 37.52901423361994, 27.09126360954777, 20.259885249599336, 11.93387302660173, 12.09518736408603, 19.422582772470292, 24.215077815517304, 25.12755643936896, 10.876165705342448, 2.519686472031378, 4.354716366337192, 3.4333128794547054, 1.668045648163365, 7.230241731289895, 11.61996279993365, 18.795438927988855, 14.375563167756605, 24.60847193194974, 30.61104366856237, 35.65046171988211, 22.88477655380003, 22.68191941322819, 14.083513290651384, 6.784006914784832, 3.9236402848074516, 1.5778227991634801, 0.2175818867380581, 0.4823039826606551, 0.8134084399188719, 0.48004800694123395, 2.65888697678043, 11.643422495934272, 37.99952607001028, 65.0723368890824, 70.75858516077842, 62.52628326416016, 60.15830524506108, 61.540881895249896, 62.116128859981416, 56.931167341047725, 47.4056129301748, 29.660988738459928, 47.25369561103083, 47.972387575334125, 50.54035940477925, 44.26743830403974, 38.48356616112494, 43.03393525461997, 49.683145015470444, 57.02729286686067, 55.51679595824211, 58.39023413196687, 52.94560386288551, 55.563895779271284, 46.522252021297334, 36.26488924026489, 23.98850210251347, 5.393183481308722, 5.526763719897117, 7.35254172355898, 3.0970309242125484, 2.6908905756088997, 2.056031674146652, 13.373954565294328, 19.82342743104504, 29.72365644670302, 23.238727315779656, 19.209331350941813, 18.48717789496145, 43.87664471903155, 12.335855172526452, 4.790030323689984, 10.444043086421106, 5.490341080773262, 0.3660170451527642, 1.2306878908026604, 2.607670137959142, 4.3879589438438416, 3.6201113462448125, 9.710765788632056, 15.016988362035445, 21.019120793188772, 18.414643464549897, 13.458738557754026, 24.203065556864587, 24.320944547653202, 32.47065113436791, 28.64580285164618, 8.374168142195671, 0.4129641695368675, 0.4628797926970067, 2.69735096443084, 3.994574388188701, 0.24101689938575993, 0.20125140496079, 0.4345700246912818, 17.66834193660367, 16.26324793984813, 32.82287801465681, 36.739252844164454, 25.17253621931999, 18.53504453935931, 49.23696364125898, 34.71826337998913, 0.3409178290636309, 0.06689309683297912, 0.11441366101104407, 0.07252329149313512, 0.11572148801097948, 0.030502443795182535, 0.0409344679886295, 0.05863428213483384, 0.0016966068060062227, 0.12124134302740136, 0.009837506447858628, 0.049862062122913144, 0.0533717981870136, 0.05140355360063334, 0.0330968254486159, 0.03415032274900906, 0.09884632538042723, 0.19150509649226743, 0.04060890743388765, 0.060679246596391165, 0.010103888625669624, 0.10263690544712929, 0.017610009489280563, 0.05257752205755922, 0.04409315192230767, 0.05803763753764572, 0.08955845924755258, 0.03858573434333648, 0.22116492592519332, 0.12862564154690312, 0.14465753289480365, 0.1371406015729712, 0.06335542537271976, 0.07134751506870793, 0.01824236910549864, 0.16732725434966628, 0.10731244730132242, 0.2609012630437651, 0.17241812311112883, 0.11098468976636088, 0.04391064296566671, 0.009618329650331891, 0.03565391968755472, 0.07597667795996513, 0.056540215267769756, 0.07609270963697665, 0.16911876628235464, 0.0750103269913985, 0.009737998329763933, 0.08276957958456009, 0.23381795583953782, 0.157010501490966, 0.31370261684060097, 18.728056530798636, 69.60984845315257, 75.86477371954149, 54.853550618694676, 70.66350690780148, 78.89298469789567, 50.50144949266988, 29.571884255255426, 47.83049583435059, 31.689342452633767, 0.4184696757264676, 0.08415121149512068, 1.2329186162640973, 1.892004649965994, 2.453168467167885, 8.302165192942466, 22.647722228880852, 38.87682691697152, 37.71457372173187, 38.5934042930603, 34.92218740524785, 33.81716159082229, 26.39109503838324, 24.310514965365012, 28.50083793363264, 32.763763973789835, 35.82571714155136, 17.746344151035434, 9.212776768592096, 4.36257581556997, 3.242673186525222, 4.280352640536524, 10.597896095245115, 12.318638909247614, 18.489262634708037, 16.479685306549072, 26.232807790079427, 27.758384250825454, 27.992863539726507, 24.201951603735647, 20.922695206057643, 9.209511395423643, 3.686542568668243, 2.238051713474335, 1.01599769486535, 0.13168887475565558, 0.3837526547572305, 0.9574167286196064, 0.30935414856480015, 5.061602486718086, 20.564747548872425, 50.309480851696385, 66.21712376994472, 72.28017453224429, 69.82309202994071, 61.13202579559819, 65.91049640409409, 64.74983961351457, 63.17026584379135, 56.48198535365444, 38.864902911647675, 57.78041931890673, 57.31404558304818, 61.650739639036125, 54.106425393012266, 45.43880316518968, 48.90955163586525, 56.486217591070364, 66.3695078511392, 62.79962539672852, 67.4223739870133, 61.63131998431299, 68.45256882329141, 53.96811085362589, 41.64009747966644, 28.140493708272135, 7.97807788656604, 7.834930496831094, 8.234501365692385, 6.769410794781101, 1.658909222291362, 0.9623958098311579, 10.131476271537043, 12.90884187144618, 24.427617326859508, 20.580327203196866, 18.510257121055357, 26.27970168667455, 37.8551750029287, 17.12399736527474, 12.666734553152516, 12.940040403796782, 8.176879786675977, 5.861942018232038, 3.97126006503259, 7.306469563514956, 10.20514524752094, 10.011506657446585, 18.00809371855951, 23.231922003530688, 30.62690377235413, 26.98237665237919, 23.907218825432565, 35.74816403850433, 31.10075942931637, 24.78976780368436, 14.318967288540257, 2.8786304112403625, 0.4266232414351356, 2.168727497900686, 1.2290224769423086, 0.9069435466681758, 0.267267269833434, 0.17897255688665376, 0.9717847382830036, 12.756669598241007, 31.191297538818855, 51.85973490438154, 54.65176036280971, 45.451205699674546, 32.222812252659956, 57.87814124937981, 44.08718578277096, 0.581253032770849, 0.03054337204253722, 0.1846512755559337, 0.06870969048430843, 0.22501058005277189, 0.0679219529152878, 0.05819464342728738, 0.03695741446027833, 0.04256500952666806, 0.07981759766417165, 0.06964809456539732, 0.022057559746768207, 0.08561168151396899, 0.12044122547752435, 0.07082923360529446, 0.07489952003403057, 0.06416528373055401, 0.06715244823886503, 0.049871875709223176, 0.04328526624087845, 0.042235216336144556, 0.05951977252299267, 0.03009277636245374, 0.0850382187373696, 0.08602749871750993, 0.1588087703191465, 0.15796402048680092, 0.09495955531395252, 0.18029468674813548, 0.20410799361284704, 0.3118685410628396, 0.1795407336565756, 0.17696836362442664, 0.22056475732355352, 0.15041094513670092, 0.2220839096774017, 0.21607260159667463, 0.34527965791283116, 0.2427132325547357, 0.26121146736606476, 0.06870979007573859, 0.21734875086094105, 0.10177700239564143, 0.2378161840381161, 0.25364999569231467, 0.21935954780107547, 0.20025268677742253, 0.21228726923225388, 0.16529232563991703, 0.17823225548190458, 0.26808676940779536, 0.19590204281191673, 0.5380104950839474, 23.543856336224465, 90.14356613159181, 102.39363808785717, 75.30642432551231, 83.25828459955032, 99.64529606603809, 74.2423794346471, 65.66368518337127, 51.24682534125544, 36.69182746641098, 0.736252967148058, 0.4764395489567711, 6.955936166547961, 6.654647636798121, 1.890722525215918, 12.322960380584965, 29.935844905914802, 41.39756164243145, 51.05486062265212, 49.74916635021087, 44.59226154511975, 42.0827369536123, 33.49632347783735, 32.00363216861602, 37.47013161259313, 43.951589445913996, 44.07184539302703, 25.084526077393566, 17.670734582408784, 18.235795151802805, 15.297478033650307, 16.828797824921146, 24.12414158544233, 31.895743454656294, 30.436031433843798, 26.896315928428407, 33.587114580215946, 43.68594300362372, 44.692458491171564, 36.39004422772315, 33.530153920573575, 21.196149126175914, 14.828404726520663, 10.117215514183044, 3.0971949283153783, 0.48980024493029045, 1.4527769026256379, 1.415306255221367, 0.22215956852080362, 5.039773516116604, 23.296293981613655, 53.331117937641764, 71.17135970823227, 74.2784809297131, 70.95463306673112, 60.4321494410115, 69.7168585561937, 69.77301120758057, 66.01746728343349, 61.414750237618726, 44.765908795018355, 63.11643915791666, 61.701589245950025, 66.19385627008253, 57.56781901082685, 48.39745090853784, 55.49721156397174, 59.45159219926404, 67.20182695696431, 64.31770816926034, 68.33598029228949, 61.09784233954645, 68.8722938106906, 55.40432199355095, 44.14400523708713, 29.57640478687902, 8.297038655127249, 7.995768266339456, 9.876109380875866, 10.854349482444025, 1.4554340632692462, 7.087612584713967, 23.018280306170066, 28.90743474806509, 38.62397916855351, 34.55958389466809, 25.626895735340735, 31.563467710248887, 58.72233336971652, 34.5081930006704, 16.783366972400298, 20.316139882610692, 18.07314818905246, 13.83918002728493, 12.118916723035998, 18.10935951048328, 19.777219949230073, 17.0880861051621, 27.306921405176965, 32.3037209433894, 37.65422021189044, 33.608063959306286, 30.44950281420062, 40.61501349172285, 35.242119450722974, 39.07396131946195, 35.552449534016276, 11.081504725640821, 0.8997169473478872, 2.3782967944299025, 7.457743123654397, 6.975701480142533, 0.4406694635268181, 0.22931721992790702, 1.9554301110967516, 22.497303255142707, 38.30682023879021, 69.95231843763783, 76.0313803149808, 65.3329195514802, 41.259345162299375, 77.19810501221689, 46.887903213500984, 0.3049548426943441, 0.11457371976106398, 0.18383876270344182, 0.13558982510960874, 0.5470479423961332, 0.1386091768020584, 0.16352744292347662, 0.12950877238425518, 0.11023328774758887, 0.2055319672029826, 0.16543081901486845, 0.197712293255233, 0.09249121236104159, 0.24986637936484432, 0.15811296330103952, 0.18646284367047972, 0.1573755730304026, 0.3649673208353981, 0.21119059904688792, 0.29247484139857755, 0.155140848590001, 0.19598369246288655, 0.16151004230543492, 0.1978010062368647], [0.023531139445220752, 0.01853289071380371, 0.08475747815663777, 0.09144071429487198, 0.3645930715626286, 0.27374699471458314, 0.1835368321307244, 0.2189417387689314, 0.11532684547766564, 0.0834608973274308, 0.052443334096742254, 0.18375501397155947, 0.3381577062029993, 0.2477189889478107, 0.08252066229620288, 0.060315335680159836, 0.03872788578812634, 0.08026916053025954, 0.05566011430815824, 0.07064403184959966, 0.12104992829864064, 0.10449409409756623, 0.14675471390927994, 0.031275629524081465, 0.055188533564608906, 0.0392383991199876, 0.08484740921806905, 0.10765328747971405, 0.4526730194207161, 4.129053094694692, 33.22206743301884, 52.760471913122366, 31.462190151214603, 34.73246628238309, 59.059653282165534, 56.268478978064756, 64.05514078755533, 46.73944150247882, 8.403480995085932, 0.0787217012276092, 0.32561828712782553, 0.8708050955207118, 3.038101234743672, 1.4695179462432864, 3.297404714169041, 19.19717788696289, 33.66668378153155, 42.967050998441636, 37.21597379253757, 27.58953994320285, 18.623786203322872, 13.88198289179033, 18.31346200358483, 10.958287389047685, 18.22953897137796, 22.48291207898048, 8.124280802665218, 3.380016939293954, 3.394972936760995, 2.1135963787955623, 2.840150243812992, 6.531500412571815, 9.963979298068631, 20.046527924076205, 17.749462435322425, 27.960568704912742, 23.836216080573298, 29.7323876427066, 19.773379948831376, 10.403582857501123, 2.619204112598973, 3.0156603743953094, 0.8283918326900852, 0.6265453153079557, 0.3957987744962016, 0.5532897816550347, 1.0376256439955005, 1.9607336458659943, 1.4563483432415993, 8.773019256130342, 28.74229904144041, 55.04603309016074, 69.2579726249941, 67.58177911081623, 62.15954557541878, 65.5908977600836, 61.99531593630391, 54.30935313624721, 41.15274690812634, 25.145093356409383, 43.219459441400346, 45.69926423411216, 40.485477216782115, 38.16636800765991, 36.81832390446817, 43.65185368445612, 47.26909091395717, 50.66218429996122, 49.24809140543784, 55.27723327759774, 47.46493877903108, 40.17297806278352, 33.288653589064076, 31.67602796708384, 20.970540277419552, 2.7237129692108404, 5.92591489514997, 8.602090208761155, 5.045387898722003, 3.2679013811772872, 2.3937072965406605, 16.784016124663815, 23.152093925783714, 27.222459047071396, 25.3530123156886, 16.111797382754666, 5.228009041278593, 17.43269770376144, 15.370720451877965, 4.410287526346022, 12.249890546644888, 9.07704903233436, 3.1413740544549884, 5.698329171826763, 3.3694726276782254, 3.472906754862878, 3.974738717079163, 6.074923286514898, 9.843860633911627, 17.664594111904023, 24.629129094462243, 17.397725851305072, 21.256398693207775, 26.806142599351947, 31.543175328162413, 16.31104790395306, 2.0355955126785465, 0.39353565883732616, 1.5328384839719342, 3.622036494555012, 0.3286714845847699, 0.14760272727618295, 0.5295746412969405, 0.21953320461175135, 5.839911045566683, 15.208843254273939, 27.753922554754443, 37.781897283369496, 13.555107270517658, 18.879638487292876, 56.41752904461276, 5.957637554214847, 0.39366745660381935, 0.07272639672362036, 0.08854929928577716, 0.11043143638920401, 0.03663369251655475, 0.05103036535963897, 0.039813547290020415, 0.05117132553770658, 0.03148037418272467, 0.03938738406906205, 0.09063407733675935, 0.09823551581751916, 0.11121632411114632, 0.06256720133786721, 0.05704335883379944, 0.09161614842953221, 0.045308795562314416, 0.10511811101628889, 0.03180850687767229, 0.0601561694225717, 0.008446034137910653, 0.02818205348786808, 0.10400408893943795, 0.053902356209413665, 0.0685946240780815, 0.042263507963188236, 0.07046747922656998, 0.19789537294737755, 0.18419540727571135, 0.17431679542266554, 0.1232514275057662, 0.20861099714473372, 0.07301872821464654, 0.15880167634496767, 0.0847394980730549, 0.22066817919333137, 0.400161553294428, 0.2239519384719672, 0.048264715174633654, 0.054690771766247294, 0.046660726244050654, 0.05611710490718965, 0.07366215780137048, 0.1080997252175885, 0.0298694827999439, 0.051281167224289916, 0.07002641942592398, 0.040832631920854894, 0.07938040660754328, 0.016896341131218982, 0.046121940437343814, 0.08171364995500735, 0.4527884535491467, 5.211932716831084, 51.43884497304117, 87.36648882589033, 53.325697222063624, 57.17481713141165, 71.94291345534786, 64.64695976626489, 47.80165464647355, 37.50722546731272, 11.448945499235585, 0.13639852284423767, 0.5062988370416627, 0.462149067391311, 2.1980204937919496, 1.08470119535923, 3.930576261012785, 8.379088755576841, 27.182949012325658, 36.24346917675388, 42.69384614882931, 39.38848441646945, 32.82459012923702, 31.642254398715114, 34.13125322711083, 25.24148560339405, 28.962889217561294, 32.651446903905565, 19.508553281907115, 12.0396799425925, 9.395639627210556, 5.809432268142701, 8.841375381715837, 11.915444750939647, 11.157664406684138, 21.893799535689816, 15.32905605531508, 24.850752815123528, 19.8372616306428, 19.56902446285371, 11.260957083394452, 6.484847741742288, 0.7783265772365755, 0.6556321416170366, 0.8028715440342504, 0.6267953051194068, 0.32965452860920663, 0.3172026274185027, 0.5377741109940314, 2.4848337615689924, 3.7075223461274183, 13.137476828790481, 38.598801474417414, 61.066906605997396, 70.75795758155085, 74.28444293237503, 65.67166328430176, 67.51167066635625, 66.89896506647911, 64.48682508160992, 50.129734316179835, 32.564278110381096, 53.227732104639855, 55.49834905132171, 51.42667385839647, 47.019726230252175, 46.63745595562843, 52.36655219908684, 60.440566847401286, 59.77423852489841, 58.94681453704835, 64.06377000193443, 59.42394733428956, 51.52058716743223, 40.313544042648815, 38.72605100754769, 28.42874869223564, 5.7927102235055745, 8.495547848363078, 11.927164793014528, 9.716767014995698, 3.4208032152345105, 2.049089936960128, 9.263257672709804, 10.948429492212112, 15.177806519692945, 11.230747968919816, 7.7218274820235475, 12.481355494068517, 30.527993363718835, 19.777361154556274, 8.734923235831722, 14.633284461113716, 13.453374716543383, 8.32316948521522, 9.044442369091897, 9.292085132291241, 11.337891432546801, 12.28996148032527, 12.778028865014354, 19.208548838092437, 29.527316324172485, 39.92985387002268, 31.17042268476179, 29.138934996820268, 25.51225858349954, 17.033219991191743, 7.260855830484822, 0.9870566704100179, 1.7988524033177284, 3.942352442010757, 3.777510177704596, 0.1379810919564578, 0.12647668831050396, 0.5262228534106286, 0.27762637203258855, 13.62529710415871, 42.54854194579586, 46.37442573424309, 55.661347066202474, 36.08341293950235, 34.47192676605717, 63.41682211045296, 9.399199178141933, 0.9180833843927231, 0.029900449989063126, 0.05720808688971785, 0.04906570989518397, 0.14781845763566034, 0.03581025525026264, 0.07611342465444919, 0.025528288528984113, 0.02820739567640328, 0.10133099366700458, 0.11749731812385783, 0.028565107026107373, 0.08420499852828442, 0.09226916943706813, 0.03001995587481126, 0.04657479033114449, 0.10245753362053826, 0.08485973557277073, 0.04243738693936218, 0.04075016638624572, 0.023694590049525423, 0.06298674172872017, 0.07284528590858945, 0.06312252698285926, 0.16665594682337778, 0.15399816716390272, 0.18598459030110992, 0.31672455791023474, 0.3233934145781302, 0.20990020054722988, 0.17327208132032426, 0.21640611031363088, 0.14459158804628158, 0.22641665782899628, 0.10511586637867075, 0.27601504397969095, 0.5317557855479179, 0.22244295976575346, 0.18442889555327355, 0.13206785845179714, 0.5065429126543384, 0.3668869839560601, 0.23190871151464604, 0.23396856872545135, 0.17054093190498892, 0.21454197324572072, 0.3172709011743146, 0.17621390491483674, 0.13528270046076468, 0.1702300381035574, 0.2851645852769575, 0.11450591331888592, 0.5445787490856263, 5.6494265314071415, 75.45651774252616, 113.27243374240015, 77.55362079989526, 76.24339226753482, 92.39121760091474, 86.86797126646965, 80.92302307005852, 67.73952114966609, 10.707858762433453, 0.3084974171173188, 1.1808552809299961, 4.391276288417078, 5.683167740221947, 4.120206679067304, 5.023631491968709, 28.400074205090924, 47.14105298442226, 58.12094380778652, 49.91740465164185, 47.53913433321061, 37.776280449282744, 36.48699737364246, 37.31004399638022, 31.20974248455417, 37.207850563910704, 40.31952173479142, 24.299753942797263, 21.354546200844553, 19.801020891435687, 18.132501494499948, 20.672051829676477, 22.804626841698926, 25.029681536459155, 31.823769923179384, 23.907848365845222, 39.43329357331799, 34.89959847542548, 39.22439990505096, 29.12711101193582, 15.617931754358354, 9.262815425472876, 6.204725302034809, 4.306132418494071, 1.1419579939496134, 0.8957797457133571, 0.7457964614995065, 1.5061373167460965, 2.0467078325248536, 8.022800260974515, 20.70437215989636, 47.17579341703846, 65.27574316147836, 72.83438190337151, 75.91028890302105, 67.59806479177168, 69.42778771923435, 68.9992452436878, 67.01292560946557, 54.72866627477831, 43.31383951248662, 60.35778522491456, 67.30003526133876, 58.8098689048521, 54.83062044266732, 51.419013469449936, 61.99959524216191, 67.85028103859194, 64.91720322639712, 61.97679842672041, 68.97172589455882, 62.498826672953946, 56.41928234407979, 41.16141926857733, 45.091394916657485, 34.45528414941604, 6.054390168959095, 9.825184268336143, 14.102283793111003, 15.923249048571433, 4.836332922981632, 6.462515236869936, 23.639787704713886, 32.536117453728956, 33.11738721786007, 33.140803767788796, 24.320685671221828, 15.056058110729342, 36.72878403817454, 29.40181616813906, 12.267378434058159, 19.028296316823653, 18.607406385483284, 12.739588656733114, 14.686266856808817, 17.76715624716974, 20.044303940188502, 19.322950647723292, 21.622967720031742, 25.813041617793424, 35.64635499831169, 42.73426225108486, 34.528687384820756, 30.89559985745338, 35.20661415592317, 39.10257500986899, 19.23466201751463, 2.695840116470091, 2.9913911992503754, 4.553454037635557, 9.369159706177252, 1.0176301363014406, 0.29423898867061066, 0.9544407528254294, 0.4001352305133497, 19.170350836169337, 59.43172539434126, 65.83091935803814, 84.48975193885066, 43.32603023898217, 49.56556020244476, 78.9728755335654, 6.244010781088184, 0.9662559736640224, 0.20333638985551175, 0.2602929279448525, 0.2085717274777351, 0.36650728013726974, 0.14245127628166832, 0.16351875548641528, 0.1753156515018594, 0.1468378957360983, 0.31339995082347627, 0.18653415113447175, 0.2992913998182743, 0.48304077538271106, 0.2185799460858107, 0.10538736793903575, 0.19275729784802084, 0.24689087854518046, 0.30438278951952535, 0.12845033764719002, 0.28269208246661776, 0.1657513348806289, 0.1740250078540656, 0.2943598773450621, 0.13240004949752363], [0.05708303452739793, 0.042530282761060426, 0.03448960393847477, 0.10399495717138053, 0.209076518132802, 0.4394884930262643, 0.35160515397306413, 0.15923952623721094, 0.12277872827384742, 0.18391037660260356, 0.05770623173204161, 0.1292210450816539, 0.2636147771150835, 0.24931067450632974, 0.038815070424349084, 0.1652554155237252, 0.07352308986047584, 0.0483660762678952, 0.1673785515970761, 0.049400651196558634, 0.015558716183858774, 0.053459304580164534, 0.18059199014979024, 0.05387505283579231, 0.07411278604019074, 0.05538439160333045, 0.045490542261470715, 0.08986919217051999, 0.4211794819322325, 0.4140537610698131, 6.722964538681892, 34.53982691611014, 41.50443054014637, 35.4003910095461, 45.75812724328811, 56.539377474015765, 33.802856706803844, 24.28304856823337, 4.189337963058103, 0.15262296273102685, 0.1402357346828907, 0.4670662486985807, 1.459882398766856, 0.13853374778503372, 0.6816663833395128, 11.374759750981486, 29.148462433968824, 43.32476331341652, 45.3194611303268, 36.946291231339984, 29.96449782002357, 22.573893416312433, 20.44265397133366, 9.835227497162359, 19.793436988707512, 21.801355154283588, 6.997312268903179, 10.756695212856417, 9.720983562930938, 2.7947512605497917, 6.861139343630883, 13.246724644014913, 12.513429695560086, 24.8425393719827, 20.672393075881466, 29.845359748409642, 25.01373121815343, 23.241341575499504, 25.440092855884185, 10.887531753509275, 1.8756396635886163, 1.1374336625299146, 0.46077945540028237, 0.3442568386033658, 0.5705401818117788, 0.26973057958868246, 0.5906070276133476, 1.398407091056147, 3.036563175339853, 8.787898767379023, 28.496082059798706, 49.279760622209125, 71.42730220671623, 70.92514468777564, 69.58144264836466, 69.88152750076787, 65.31499431979272, 53.05892898190407, 31.11700784775519, 18.640095418499364, 34.674093569478686, 33.32180546176049, 29.67495825982863, 28.455734599021177, 32.371601481591505, 35.52867997077204, 37.608767786333644, 42.616104772014005, 48.05307072977866, 45.021317851158884, 33.77879296579669, 32.362585913750436, 31.02679333379192, 27.216189138350952, 10.730098601310484, 1.7188006278968628, 5.110656138389341, 6.302866435820057, 5.011398109697527, 2.2873233018382906, 2.276508346680672, 14.874322933535423, 20.02482152754261, 25.576691358320176, 20.21106350806452, 10.616883308656755, 4.661291760783042, 19.140101517400435, 15.728687720914042, 7.64373456278155, 19.939172652459916, 18.535974141090147, 8.732780641125096, 7.38055185925576, 6.09904194070447, 5.476994235669413, 3.146742798628346, 4.610021969964428, 5.788025932927286, 16.134557916272072, 11.063400045517954, 15.500595031246064, 29.7463571640753, 33.64060394225582, 17.52050780480908, 3.0758263459128723, 0.053499099017391284, 0.46598131498021467, 2.832019170445781, 0.5155692670133807, 0.3425442643703953, 0.3163286130274496, 0.16240394433900235, 8.378402340796686, 27.029992265086022, 16.851396560668945, 43.192877538742565, 25.54280011884628, 12.981631255918934, 44.95763817141133, 28.305592152380175, 0.4822599785702844, 0.09976129483191237, 0.08870658479751119, 0.096169889964644, 0.08543702112811227, 0.042984266464989034, 0.05496916045705157, 0.10613568262347292, 0.013344861893734385, 0.11638478225757999, 0.14270102094498374, 0.03963806719008473, 0.13520040729593846, 0.022563681479603536, 0.0825493369672087, 0.011677874680308085, 0.13019658144443266, 0.08250668119158476, 0.0920437480653486, 0.12563987514905392, 0.032150028874316526, 0.05404513584630144, 0.0672385641824334, 0.06589339039618931, 0.07434506389883257, 0.10825615271084732, 0.02593279444432307, 0.06653801508007512, 0.178598583405537, 0.17434233679406105, 0.25864841296307506, 0.337090116715239, 0.13620672507151482, 0.18802276722365813, 0.1307487163332201, 0.07761398405437508, 0.14134863061049294, 0.3510340813907885, 0.21567077315863104, 0.07724841455778769, 0.030584417118300355, 0.03689835674219555, 0.002650492566434907, 0.13626747584391025, 0.12698679561576537, 0.04751212955001862, 0.09055599765551668, 0.053509797435253866, 0.0790939280282586, 0.14060511163646175, 0.08484479685824725, 0.03839754484473698, 0.07595201758968254, 0.08355120377194497, 0.3145052931241451, 27.112028637240012, 77.07717833980438, 61.54613394891063, 62.32267695088541, 67.9507250939646, 69.64388678150793, 43.89870020651048, 22.94269427176445, 3.5735979195564025, 0.2895786919661107, 0.22035301062128237, 1.1877385502861393, 1.7797583053188941, 1.500144670567205, 1.3653325625965673, 4.745805599997121, 10.102093796576224, 33.130550692158366, 42.619203444450136, 41.21683843674199, 38.181586803928504, 39.466782769849225, 40.62015964138893, 25.56900743515261, 33.772685835438395, 37.41541062631915, 22.41422941607814, 18.45658732998756, 17.694802245786114, 7.696147724505394, 16.187609934037734, 23.698817414622155, 18.339892894990985, 26.32600134418857, 19.77638840675354, 25.860931796412316, 16.307852152855165, 10.65076474220522, 15.17308790837565, 8.639201714146523, 3.8694559278026706, 0.6771974553984981, 0.7794683546789232, 0.6038424528894887, 0.3557903535904423, 0.22691518188484255, 0.2960582942731919, 1.723433069644436, 5.1899605797183135, 16.015273736369227, 37.717233088708696, 54.96075684024442, 76.90253088551184, 72.0794354715655, 72.2649557359757, 72.04439301644602, 69.6598586728496, 63.37854762231151, 42.6023764764109, 29.263678135410434, 48.56033517468361, 44.55624634219755, 38.30755372201243, 41.230264709841826, 43.90124974712249, 47.698029548891135, 51.24833545377178, 55.09452143023091, 60.596457527529815, 51.78601787936304, 48.870496596059496, 42.34414723611648, 36.6477321809338, 33.82142128482942, 18.713941881733557, 3.695860649308851, 9.233833032269633, 9.412195951707902, 6.7021362627706225, 2.931727045966733, 2.811990812901528, 7.391964975864657, 8.931816412556557, 9.258264495480446, 4.68324673752631, 2.6726819526764656, 9.549859377645678, 22.275379473163238, 19.555755084560765, 11.191867474586735, 16.215553879737854, 15.511059914865802, 12.667934798425245, 9.20930645158214, 13.681734127383079, 12.169466268631721, 11.034575527714146, 16.440095843807345, 22.302596799788937, 33.57379028874059, 24.884557762453635, 22.572581383489794, 28.06333088105725, 20.34757571835672, 8.382769899983561, 2.3334047775114737, 0.7200020359408471, 1.806979799462903, 2.915830905399015, 0.28426207241512114, 0.40443010327796786, 0.3050252921398609, 0.2966765885151202, 11.819806579620609, 50.65814033631356, 36.45486531719085, 56.750891285557906, 50.235171548781864, 26.47877570121519, 48.23384100391019, 39.25777143047702, 0.655341212066912, 0.03390728901591032, 0.16007627811162703, 0.0306771865354911, 0.06149855847921103, 0.06606851809567983, 0.034755030421600226, 0.06159348443390862, 0.03147114856889652, 0.052496067759010105, 0.06526752720556914, 0.09007507830017036, 0.05887071219002528, 0.03214416830169578, 0.017549706878320828, 0.025355229266889157, 0.08202409942544277, 0.18135532015754333, 0.12742418585525406, 0.09086879901587964, 0.007051405545714642, 0.026277488044973825, 0.050802733824257894, 0.047690781253960826, 0.019813322409566854, 0.17882176013963838, 0.0996835905337526, 0.12244027062890031, 0.22259702004732626, 0.2415881405073789, 0.33622740978194826, 0.25884183484219736, 0.23836838021393747, 0.20595984263045175, 0.2239096657403054, 0.13014456407437403, 0.17443809778459612, 0.4607747975857028, 0.5709932155666814, 0.198512441448627, 0.24834399411995567, 0.2126194602779804, 0.11147939870434423, 0.19923608810190233, 0.4434849592226167, 0.27398187727216755, 0.2269006568577982, 0.3038035351182184, 0.2399219758808613, 0.26674001748042725, 0.5121076221187268, 0.11928045671553382, 0.23421763923139344, 0.673892613380186, 0.4295776135498478, 29.51064232856997, 103.26320402083859, 93.46903001108478, 83.34416881684335, 86.18247432093467, 93.22244628783196, 54.36055575647662, 30.83473643948955, 8.923016575074966, 0.48846051036830873, 0.7608099462043855, 1.610901249993232, 4.194501763389957, 3.8212938799012095, 1.9896869890151487, 14.886174375011077, 42.63204920676447, 56.31113475368869, 54.92209011508573, 48.86063183507612, 47.66311260961717, 39.87007694859659, 41.3801267070155, 30.96296656516291, 36.066456533247425, 41.05131441547025, 24.001755791325724, 26.04445557440481, 26.671413106303064, 18.01414397455031, 26.653544748983077, 36.33799045316635, 32.343534961823494, 37.82057185326853, 31.5384018036627, 42.101046577576675, 33.96064189172561, 27.18297843010195, 32.56753367762412, 17.308505658180483, 5.482236973700985, 1.6327538773898156, 1.9305233056506805, 2.1565372617013994, 0.9001503079648941, 0.6056613294828324, 1.2203710766569262, 3.441645709737655, 10.025669355546276, 21.61243615611907, 39.225902172826956, 54.213396272351666, 75.37833706025155, 75.07982900065761, 75.72445484899706, 76.81795673985636, 72.8047287848688, 68.14063841296782, 48.967269312950876, 37.331099279465214, 58.425598221440474, 55.514136591265284, 51.71462681985671, 50.92587740190568, 56.84302383853544, 58.08917653176093, 62.55888208266228, 62.5979410448382, 65.63556178923577, 62.19515285184307, 55.5636957383925, 51.40075875866798, 40.77851356998567, 36.42487095248315, 24.5682539093879, 5.286450885957287, 11.798288456855282, 9.887820597617857, 8.088417101290919, 3.0648689596883716, 7.900635100180104, 20.975537377019084, 28.05388189131214, 32.11347814529173, 31.927053774556807, 27.606721885742683, 12.245391588057242, 23.283405073227424, 20.817497238036125, 8.959434801532376, 13.82209320222178, 16.258242995508258, 14.789326152493878, 11.342206039736348, 18.45673834123919, 20.408864713484242, 21.347729121485067, 22.73017829464328, 24.852782641687703, 33.91815477801908, 25.324928145254813, 27.62381361376855, 39.644171960892216, 40.329429641846694, 20.74631210296385, 3.2231287514009788, 0.7456426310443109, 1.8953157432617682, 7.170201030469711, 3.8556050581316796, 1.2579720202953586, 0.7189323320504158, 0.4982476513231955, 17.500613543295092, 65.86913108825684, 46.91861537195022, 86.44583794378465, 57.38227913456579, 39.131592704403786, 68.05139664680728, 40.4610800743103, 0.49749406595383927, 0.214911135694673, 0.22835626987920654, 0.1150569833454586, 0.126162056000002, 0.19117727214770933, 0.15383748788266413, 0.14257100050247487, 0.10050980869920985, 0.19559205299423588, 0.20292326928146426, 0.3216147116355358, 0.18953268055713948, 0.05122168815784878, 0.14865419827401638, 0.19372094452621477, 0.2823083949906211, 0.25291087406296886, 0.26556646271098044, 0.23976612295354569, 0.2920405921195784, 0.2145021673171751, 0.12157827615737916, 0.21057939877913845, 0.2376311431608854], [0.13448083623042031, 0.07294558213963624, 0.08192489103924844, 0.057847808610888264, 0.2349664748556191, 0.4906520734150564, 0.34064476468390037, 0.16327400571636616, 0.024569207734818903, 0.012705800923398666, 0.16368061454305727, 0.1987460216567401, 0.15740425536228767, 0.2676520604760416, 0.09127972857846368, 0.20585842791103548, 0.0728745581281762, 0.08704100239781604, 0.14541525513895098, 0.09726390948579197, 0.039566514577956936, 0.06698374801705922, 0.04841576090022441, 0.04414740626910522, 0.09567894251836885, 0.028204978669002175, 0.042013625404046434, 0.058192712885718194, 0.057862042524521394, 0.8965590103499351, 4.722580265614295, 21.771613782452, 50.95058833399127, 35.665460863421046, 41.4628416492093, 54.80915331071424, 34.25783595731182, 11.651496694933984, 2.7690396337739887, 0.29041308428972, 0.29608397354041377, 0.23352714886348094, 0.4456959196156072, 0.20172975026071074, 0.1674170704979089, 1.2096577354015843, 18.139581372660977, 30.871071315580803, 47.69666848644134, 44.96440425995858, 42.513268070836226, 29.016582542850127, 27.708619179264193, 18.908793464783702, 16.127708477358667, 12.901104015688743, 8.587207755734845, 14.287959971735555, 11.760553294612516, 3.584608993222637, 12.3351187475266, 15.148248518666914, 7.263525493683354, 18.490635464268347, 9.294499351132302, 23.300183011639504, 14.554682124045588, 14.652443278220392, 12.016558551019239, 2.983446683614485, 2.6835699619785434, 0.7452187086305311, 1.3246323336516659, 0.5567838780341611, 0.2618794653925204, 0.8454049294514041, 2.366991297852609, 2.663194229525905, 4.467745346407737, 11.360370536004345, 21.379068859161872, 45.037379957014515, 63.45811682362711, 67.8146110042449, 65.51634919258856, 69.24799411527573, 62.06637359434559, 50.207593364100305, 33.131566586032996, 24.74893200782038, 27.4500879164665, 24.103529530186808, 19.280957752658477, 17.324579531146636, 20.078793341113677, 22.280254979287427, 29.48719636086495, 38.47511737577377, 42.20634652722267, 38.89878434519614, 33.67052378193025, 29.794772940297282, 27.03244766881389, 18.2022451585339, 5.181653489989619, 2.7857283382646503, 4.496928761082311, 3.8724482059478764, 2.1880522802952798, 2.926531376377229, 3.120346227961202, 11.63096602885954, 13.713701444287455, 12.293456312148804, 3.9721847638007137, 4.771106358497374, 3.5907188202104265, 15.994779352218876, 18.718301596180087, 5.978849241810461, 22.354831003373672, 23.99125168400426, 11.050644497717581, 9.711334532307042, 9.212923857473559, 6.5773681190706075, 2.503935459160036, 3.5200433481124143, 6.748124582152213, 12.199912686501781, 20.122653284380515, 33.34968174657514, 27.892521465978316, 18.257254439015544, 5.037047959143116, 0.670226913306021, 0.23691376310683068, 0.828501720341944, 6.4868961995647805, 2.3947207389339327, 0.5782174246926461, 0.13599514690858705, 6.350927237541446, 37.13825987231347, 17.79556401314274, 42.86492032389487, 39.6062034176242, 9.22997243942753, 31.434961057478386, 53.91440968359671, 1.8073053561872052, 0.2329019138649587, 0.10152384864106294, 0.0238388731339646, 0.023159291858093876, 0.03734934887277984, 0.08780696008714937, 0.039698871588634874, 0.08081182657230286, 0.09930752563260256, 0.05052199324352607, 0.11792959089601233, 0.11784365115266655, 0.16147670215897023, 0.0656743965021545, 0.03633439728629686, 0.05739561755270247, 0.025001599250601667, 0.04205373776776176, 0.14165005556518032, 0.27582232690145897, 0.09428404962583896, 0.15650787120384557, 0.07968593013262557, 0.059210092970921155, 0.05154468614848391, 0.09177637571889548, 0.06458518035229176, 0.194243477777608, 0.08168667599919342, 0.2659775761346663, 0.5003418292730085, 0.36805174403613616, 0.10140111369471397, 0.07913068492686556, 0.14080712902209452, 0.19212637847710043, 0.3984973038877211, 0.2652823053781064, 0.17275592192046105, 0.04525391302341896, 0.15718300916975544, 0.07567257169754275, 0.057288698491550265, 0.09871176969740661, 0.03470609655543681, 0.07105211922598463, 0.0371529545725113, 0.07651436443050062, 0.005737152025704423, 0.07307610820017515, 0.10903809865516041, 0.019763867603614926, 0.18837620954840414, 0.0592086871995801, 0.5104892460569259, 6.768657209411745, 51.74659413676108, 84.77279017048498, 59.84167975764121, 70.03864196039015, 66.79172746596798, 51.61942697340443, 20.83078818936502, 3.154632155933688, 0.230184952397981, 0.19774345771199275, 0.30510043004347437, 1.5713142387328611, 1.529756359034969, 0.5678328270873716, 3.0621132494941836, 5.239919808603102, 8.034334480762482, 31.981060889459428, 46.22765064239503, 48.422052014258604, 40.47081147470782, 45.1099673394234, 43.625620872743674, 34.961254212164114, 29.59103522762176, 22.724714432993245, 29.27212888194669, 20.223744530831617, 16.193912202312102, 19.788408510146603, 20.623983183214744, 15.212872509033451, 25.28671641503611, 13.709353496951442, 20.096312607488326, 17.131206681651456, 15.705748719553794, 15.628576086413478, 10.08227994365077, 4.098957728955054, 1.8975882664803538, 1.5933085617519196, 1.0021642919990326, 0.20893571117231924, 0.24588918794066678, 1.4576490992499938, 2.9754217593900623, 5.308545597137944, 12.96237143778032, 26.06660127639771, 50.684279011141875, 69.69287718496015, 73.01297526205741, 68.33623132398053, 72.67570634042063, 68.1649806422572, 59.04472081891952, 41.032000664741766, 35.5390703293585, 41.22241212475685, 37.45951375653667, 30.397647119337517, 29.19283816891332, 30.807854475513583, 35.80738006099578, 45.76731735660184, 52.086855826839326, 51.591009401506, 48.258391118818714, 42.81257237157514, 32.5630445249619, 30.156817513127482, 23.86333730912978, 10.362708818527961, 4.887528188766972, 6.769840294314969, 6.476936321104727, 3.223082663551454, 2.249536168190741, 3.439917660528614, 4.830458683352317, 4.669063937279486, 5.232958091843513, 3.6444452404975896, 6.362022642166385, 5.757955572297496, 28.437942727919552, 33.322617392386164, 18.71724843978882, 28.283101281812115, 28.743197264209872, 17.897063186091763, 16.953499778624504, 17.219916966653642, 11.466605970936438, 14.114660832189745, 17.35584278260508, 20.485592157610004, 24.640247052715672, 28.99279532894012, 33.31366262128277, 20.329807381476126, 10.98703149826296, 5.437873496163276, 0.6213791247817778, 0.9459829582802711, 1.8272900773632912, 1.983639061931641, 0.4781813877484491, 0.49887391287953625, 0.30065132845794, 6.648292416526425, 55.00944522119338, 37.74277164090065, 55.58486869258266, 63.972127745228434, 28.176999207465883, 37.68871745755596, 62.01197424242574, 5.65714918798016, 1.0803973746876563, 0.0881610076213556, 0.09932769672764886, 0.02288839933762868, 0.05847494350746275, 0.047394764880018855, 0.1326265204096994, 0.10411374676491945, 0.038298030023372946, 0.09743916742022961, 0.1089534076351312, 0.08882138307296461, 0.044324357257855516, 0.042292626965190136, 0.025650408689773856, 0.04084179050198967, 0.0582974485962862, 0.13838221559361105, 0.01487634443272386, 0.10938531268508205, 0.04584791461726831, 0.05360079718933952, 0.024468434614039237, 0.12229659849958074, 0.048045748093676184, 0.230148256786408, 0.18208442135683953, 0.13122493190871132, 0.2666456354481559, 0.4386126093806759, 0.6375608629276676, 0.36590580918615867, 0.2690946346809787, 0.21421787208847462, 0.3530701285889072, 0.2842887629184031, 0.34959368287555637, 0.30245442364004355, 0.3529174319438396, 0.24252161864311467, 0.2953756180021071, 0.2334365053402801, 0.1315495999710214, 0.24126419256771767, 0.3351521287714282, 0.1265225846380476, 0.12171651672331557, 0.277411928700824, 0.12601233943695986, 0.17682901223100003, 0.20990151821845965, 0.21054254994998056, 0.46797378709720033, 0.20957559377195376, 1.2185946106910706, 7.305250196687638, 68.61792810501592, 115.32092294385357, 85.25972104841664, 94.29286895259735, 94.97456119906519, 79.53400981041693, 27.379769625202304, 3.6306318784913714, 0.6418787183300142, 0.48858093939000563, 2.5422359330038873, 2.0148759599654906, 2.496348369506098, 1.853320519289663, 3.0711155793359204, 23.53801004348263, 46.8133742578568, 58.102583193009906, 57.47478431270969, 54.163727298859634, 45.69829933104977, 43.83090988282235, 41.82279755992275, 35.14763347564205, 31.463894421054473, 25.631631997323808, 31.369092695174682, 30.604720807844597, 22.24026249301049, 29.13175705940493, 32.66753842753749, 24.95128708501016, 34.02182302167339, 22.88770656431875, 38.340505553830056, 27.730602102894938, 25.79704030867546, 20.96799465917772, 16.622239928091727, 6.324343373698573, 2.3157070432939837, 2.628055431189076, 2.5852817393118337, 0.22826452318939472, 1.315752455303746, 3.398352548960717, 6.613292126886307, 7.317429156072679, 13.82430051603625, 23.381703592115834, 51.74083609734812, 66.83514810377552, 72.46767167122134, 69.10205841064453, 76.54359479104319, 70.80141744306012, 64.53287762980308, 55.018243097489886, 47.30798121421568, 53.80126499360608, 55.44469102736443, 48.02359804030388, 47.93301874591459, 51.81828721877068, 52.10851123256069, 63.57929452773064, 63.557764637854795, 59.787217647798606, 56.973885874594416, 48.99720091973582, 39.61276946529266, 33.06119534277147, 27.08698626487486, 12.159782917268815, 5.945098717366496, 7.094839061460188, 5.778444072892589, 1.801886356646015, 2.368630603436501, 7.067630560167375, 14.49895897219258, 20.13176691147589, 25.03729093459345, 20.802025448891428, 10.846289011739916, 3.611324746762553, 26.60592913627625, 32.05665476860539, 9.79233539873554, 18.7028847202178, 21.616442857250092, 13.609263435486826, 16.389034428904136, 16.54772666192824, 15.74915857084336, 20.99101112734887, 20.399078399904315, 22.94354738727693, 26.715353458158432, 35.82329311678487, 42.958476697244954, 32.710613896769864, 23.253369523632912, 7.1716689775067, 0.7460278813396731, 0.9501939903824561, 2.1160228550434113, 14.810430465206025, 6.710006498521374, 1.063437046062562, 0.7519493732721575, 11.364467451649329, 66.39946691451534, 41.4198838510821, 86.0423594136392, 78.12260766183176, 34.68020462220715, 57.58881153598909, 77.91429058198007, 3.7178526434206196, 1.1642272506029376, 0.15262529163831665, 0.2771530829129681, 0.11876576820448523, 0.15756784577763852, 0.2976521861649329, 0.2563393473505013, 0.1503109706625823, 0.20440420916964933, 0.17608354739364118, 0.2892974151238319, 0.18084602490548166, 0.1567685709244782, 0.2564864668754801, 0.18330884436445852, 0.23451693446165134, 0.10910098681286459, 0.24183094441410036, 0.20798726367854303, 0.4404987791372884, 0.15840550163580527, 0.2439938557724799, 0.15003458146126042, 0.33435064758504596, 0.26275415394094687], [0.07993794241619688, 0.07607106765311572, 0.11432549961271787, 0.17683066698091646, 0.5143264272520619, 0.24831451505662935, 0.2960211543306228, 0.07041261967031226, 0.07471572788011643, 0.07471080193476332, 0.2463198519281803, 0.11919453229394653, 0.24364914685007066, 0.17497544717644492, 0.07388497447414745, 0.10703524604680077, 0.024487326342251994, 0.025402537111433286, 0.028098402432196086, 0.08702403355029323, 0.039129599312981295, 0.14460047466620324, 0.052773004713197874, 0.07259644522902466, 0.10137569489738635, 0.04644982223849624, 0.02674618638270805, 0.09641127660870553, 0.16286474622545705, 0.13767959039297797, 0.6280444574452216, 13.159825513439795, 60.618846416473396, 45.273118326740885, 43.84791335751934, 43.25851840357627, 44.750701765860285, 27.930135034745742, 15.292133804290527, 0.706794434978116, 0.13783656180866305, 0.2148095677576719, 0.5742625723923407, 0.633240923766167, 0.7049481017935662, 0.4151860696654166, 1.1354804447581692, 18.367979026609852, 37.58117783454157, 42.1473736916819, 39.81839187683598, 41.12724757963612, 38.46299332957114, 25.924138830554103, 19.706713384197606, 18.062510721145138, 18.61670240279167, 13.810546725027024, 22.271051137678086, 20.723746707362515, 15.998514429215463, 22.82458778350584, 7.2722689470937185, 13.691380216229348, 13.80601344570037, 17.715039714690178, 9.781052700934872, 6.054125408972464, 3.8319602752885515, 0.8784745549482684, 0.3316548454665369, 1.1134416273524685, 2.2014601672849348, 0.9023234236144251, 0.10261484211491001, 0.08472749347528143, 1.1689220825510642, 1.1440641841580792, 2.427343091657085, 7.91279640889937, 16.805991203554218, 33.800126737163914, 57.66735307631954, 67.86523311368882, 68.05015717783283, 64.10884587995469, 57.45958905066214, 38.239328015235166, 19.490371134973344, 10.026350867363716, 18.74767818758565, 15.893289985195285, 10.076117900110061, 10.718493288563145, 8.157226260631315, 12.98984960202248, 25.38044929504395, 32.77527220787541, 37.31275827653947, 23.443810401424287, 25.38850780456297, 21.68420768553211, 15.524428333005599, 8.844070050024218, 4.905984411316534, 3.7859518537598276, 2.709136215909835, 2.8588141068335506, 1.2795560879092063, 1.941505329262826, 2.9329780369035663, 5.206758129981257, 4.687814337591972, 4.101491334938234, 3.6835961332244263, 3.4658991954018994, 0.45076212034590785, 19.743667994776082, 17.98437906849769, 3.9629539558964395, 8.337452796197708, 9.178819829417813, 14.1890299512494, 13.336901895461544, 5.495799549164311, 5.2401610343687, 3.590240045901268, 5.2684550516067015, 13.629672508085928, 26.84673128589507, 29.096585166069772, 21.08515193385463, 11.816279388243153, 3.935590275833684, 0.3829141255588301, 0.1290483535417626, 2.068963973752914, 2.494902730949464, 0.898128632576235, 0.2031095358993738, 0.5109332706178389, 9.11064217167516, 41.93914682634416, 22.445349501025294, 39.55791904080299, 55.252722386390936, 14.092081708292808, 20.186038786365142, 60.324433311339355, 28.383523764148837, 0.2168220807347567, 0.030666706452686942, 0.07119643486916058, 0.07961187241298538, 0.06892961900561087, 0.11939088828981885, 0.03633422491651389, 0.09626306157799498, 0.06428299697055932, 0.1161660947987149, 0.052165596580673615, 0.029062889891886906, 0.015444703148527732, 0.12015975711326446, 0.10605194921334905, 0.05567507217487982, 0.05475789255973312, 0.1139906655636526, 0.06807669501511321, 0.13639452386527293, 0.04520849550082799, 0.11250652342794404, 0.0519952837437872, 0.024690678636092814, 0.023721908744905266, 0.08077523055215997, 0.08753618631031244, 0.13547246043960895, 0.14692524508122476, 0.25145115481028635, 0.4253724956464383, 0.4022383257266014, 0.4672285061209433, 0.06692598498756848, 0.1558593164889082, 0.0277842010461515, 0.2472063229088822, 0.2923939731572905, 0.24032098511534356, 0.1349748556892718, 0.1389658520178449, 0.1432201221224762, 0.05369538989579005, 0.003868010727831373, 0.05804309974454584, 0.03890351144476764, 0.059431201267626986, 0.03237533916328703, 0.027299255898763097, 0.11492314778508679, 0.07410235192266203, 0.013493743420939052, 0.09279282883771005, 0.09545832451793457, 0.09445812778487321, 0.2042855268284198, 0.7996316662719174, 27.76769791879962, 73.09571373847224, 63.93536729197349, 74.75934782335835, 70.29760468390681, 65.25774732712777, 53.04928387365034, 17.6185925545231, 0.8887443006519349, 0.20426842774594986, 0.5558708850895205, 0.656039577818686, 2.4793441593647003, 1.2305709551418982, 0.8506343681966105, 1.3763366495409322, 7.120186398106237, 11.036795589231676, 28.2027123051305, 44.216678911639804, 48.630977061487016, 48.74076028023997, 40.42305661785988, 38.97013618100075, 32.6480697431872, 27.170770052940618, 30.412826691904378, 30.315306763495173, 29.926792075557096, 37.49278330033825, 35.64940660230575, 17.83432487518557, 19.664214503380563, 19.6249908016574, 17.72230786661948, 18.382705565421812, 11.892560662761813, 11.39767914049087, 4.160394793556583, 0.7288506579014563, 3.411222335792357, 2.762956037636726, 0.5969510936448651, 0.49855515901600167, 0.7456164614808175, 2.2685537799712154, 2.716642406678969, 5.321608560700571, 11.387058342656783, 22.510988404673917, 41.81616875433153, 65.2871141126079, 76.52901141874253, 74.29576289269232, 71.91380162392893, 68.98732123836395, 46.6793704032898, 32.98384228060323, 13.946962837250004, 24.733507287117746, 28.6301859348051, 16.21444384897909, 20.854316526843657, 21.194378176043113, 30.93732407016139, 43.132135714254076, 45.4520490092616, 45.85253477096558, 30.441259953283495, 29.133329929844027, 24.743858422002486, 19.65617952808257, 10.830540695498067, 6.255922529005236, 3.3462254751113156, 3.1030574008341762, 3.615137290570044, 1.3248722111025166, 3.0535923905910987, 1.8572837066265846, 3.153949663523705, 2.79354537686994, 4.896622694307759, 6.26218851535551, 5.370088565734125, 4.261721872514294, 33.8388091518033, 31.475220264927035, 15.691597788564621, 24.94595854513107, 26.847429467785744, 28.515382082231586, 30.740283804555094, 15.893413539855713, 13.791639920203918, 19.111270135448827, 22.244153484221428, 24.94352863680932, 33.853251318777765, 27.175469052407053, 15.11414154883354, 6.26117556325851, 3.0319994976443634, 1.4718325123671563, 0.9745392227365125, 2.075610184861768, 0.33608825757138194, 2.0734729834141272, 0.553427922629541, 0.5139450073963212, 6.471413623902106, 58.25400237114199, 38.877650614707704, 47.35315515149025, 71.48532975104548, 36.696730429126376, 30.525320268446404, 68.72367520486155, 40.99607175396335, 0.5193940682276603, 0.08706018523944002, 0.13976557120200128, 0.020199321555875, 0.053782317892558155, 0.010158117116999724, 0.033104934489294406, 0.08121141803360755, 0.07930592753954473, 0.009109772715507256, 0.012914803115681056, 0.005334625011234875, 0.024595386874411377, 0.07530740056667598, 0.04082292558685426, 0.05417600664640627, 0.06190682971669782, 0.08147266167666643, 0.09981249248789203, 0.027948754817067135, 0.055666108946165735, 0.1020531158053106, 0.012524211272266845, 0.05597400351337368, 0.05052575473523429, 0.041547062536401135, 0.20679697754882997, 0.22104906278752515, 0.21174812719466227, 0.30941218738594367, 0.6021939542505049, 0.32065504861454813, 0.5605496598347541, 0.20889288685735197, 0.2225191395489439, 0.1787068622727548, 0.41109114584903567, 0.46800826105379295, 0.32692553956181775, 0.20504563926689087, 0.14824113898700284, 0.23467001415068106, 0.20507131853411276, 0.1724459474245387, 0.10174695642725115, 0.1346529915087646, 0.19485997937379346, 0.15436066464791376, 0.1465092286948235, 0.1760073063234168, 0.3846950654781634, 0.16884879689783822, 0.18008718417296488, 0.34239377405854965, 0.23506223584615418, 0.43279211848012866, 0.5476690251981059, 33.47202831699003, 102.69801401322889, 92.11418059564407, 98.13847834064116, 92.32859303874355, 95.20907186692762, 76.28356518283968, 34.09262572565387, 0.7550568710411749, 0.2892531045982915, 1.12911272193155, 2.459658273766118, 2.8242246854689816, 3.9901712825221405, 1.0665357184986914, 1.8556151058404677, 24.969718302449873, 49.31784683658231, 53.003698087507686, 54.0976510509368, 53.13350500599031, 52.102455093014626, 39.718175318933305, 37.3570300686744, 35.72054663012105, 37.949374644987046, 29.54163101411635, 42.52543918548092, 39.400102476919855, 35.55381451883624, 46.858273629219305, 26.43001671760313, 19.865830213792865, 22.52263588290061, 27.48822512165193, 18.767856820937126, 9.844277385742435, 8.275795098273985, 1.9866812277224757, 0.35592518506511567, 3.340174238527975, 4.816861787149984, 1.4599588849852163, 0.37135799565622885, 0.7328783191980854, 1.920205633486471, 3.188796735578968, 5.633475722805147, 11.230004679772163, 20.166209243959, 39.498655949869466, 63.69462005553707, 73.18082132647115, 76.00197038342877, 71.95318222045898, 72.35368759401383, 56.27819076661141, 53.28896422539988, 26.916614194070142, 40.8352820334896, 49.47521232789563, 37.251333959640995, 44.31752304877005, 42.28373096835229, 49.71300994196246, 55.29986927586218, 55.17642444179904, 53.99160192858789, 37.337241711155066, 32.29280302601476, 27.69303168019941, 22.279088074161162, 10.651180513443487, 8.688550033876973, 4.756625948413726, 2.952336894889032, 4.532369827070545, 1.0203777566071481, 4.218481663734683, 6.228094783521468, 8.577591084664869, 14.632132264875597, 17.911887784158033, 10.903693879804305, 4.646633863449097, 1.7066173784194456, 29.42591521047777, 25.972448702781435, 7.468777731541665, 13.672710714801667, 16.179915224352193, 19.901353159258445, 25.05796378658664, 9.477762291508338, 10.63714333118931, 19.292803310578872, 23.62699685558196, 27.65529455677156, 37.92496181303455, 34.996943858362016, 26.389557469275694, 16.227554371280057, 6.360691978085426, 0.770834788920418, 1.5405311098983212, 3.231077189407041, 8.143140048749986, 5.139596366113232, 0.6930231771642162, 1.3234085541579033, 13.85850162275376, 73.56344853678058, 42.32191524197979, 75.39753313987487, 93.88851181153329, 40.88940289712722, 44.4581792431493, 92.37004464672458, 40.813022582761704, 0.6448499137355436, 0.16736306129924713, 0.27617399190222064, 0.17637902750603615, 0.28714673052872386, 0.1384560511477532, 0.299071379366421, 0.2707210087007092, 0.25818915857422736, 0.19133746113267638, 0.2464419356997936, 0.15008708912759058, 0.12743025327161436, 0.2102486633004681, 0.1733239914380735, 0.21844961920813208, 0.16109531294674645, 0.34508035247845037, 0.17879392050447004, 0.20196665529041521, 0.22241732646380702, 0.2914896829714698, 0.17092789823730148, 0.10579564683740178, 0.15848090000931295, 0.1548722121984728], [0.011507562801031577, 0.04598778312004382, 0.14164798712778476, 0.303547385959856, 0.1062950365726025, 0.16409561969339848, 0.025310464834253636, 0.11958970342792812, 0.1077110351874463, 0.03681825458883278, 0.15494685980581469, 0.10321890244320517, 0.08637796096023052, 0.09265342381812873, 0.11150683997379196, 0.03273258128413751, 0.10440443116690844, 0.043974266567778204, 0.10672608360407815, 0.06158065246117692, 0.12197805914066492, 0.03347802313885862, 0.046531410602432106, 0.034569916766016714, 0.0740801353728579, 0.09796890955899032, 0.04893190880876876, 0.04352527009623666, 0.21337840826280657, 0.09834468334672913, 0.14841862623730015, 1.657668895298435, 45.36157169649678, 54.62841049317391, 45.328329609286406, 48.184289701523326, 46.686944500092544, 39.94105223686465, 34.923885791532456, 28.741606743105, 0.35345197745388557, 0.03727044181657895, 0.5952375081758345, 1.1170211578569105, 0.1935928393035166, 1.6483195582705161, 0.601980920520521, 1.197605517602736, 15.415560987687881, 32.20556951338245, 37.30693355683358, 42.146867705929665, 40.36723736793765, 37.00114165582965, 33.40654434696321, 20.803857195761896, 33.40368493910759, 18.056933110760106, 21.802678954216745, 44.76406920340754, 12.568737076174829, 10.021074298889408, 13.17003740418342, 14.951851521768878, 23.491575064197665, 12.867633450415827, 10.931324035890642, 8.834961325891557, 7.432569351888473, 1.6711307148779593, 1.0152233331914873, 2.443009528421587, 0.7303068991149626, 0.49888767181865634, 0.07704638185039644, 0.32604705121728683, 0.5314613013498245, 1.9301315589297203, 0.9646640429573675, 5.071492743107581, 11.88499931366213, 30.711799552363736, 43.6508927037639, 56.52488823859923, 51.963611033654985, 59.88193112034952, 41.763405030773534, 19.89605207597056, 9.393495071318842, 3.8256133900534723, 2.5767581837792553, 11.668347197194255, 4.589011794136417, 3.8296691208116473, 2.894312292337418, 10.385415419455498, 28.13139577065745, 26.409049687847016, 15.833811163902284, 10.191529720060288, 9.66166457822246, 10.055208725313987, 3.9085371984589488, 1.5737973442000728, 0.9888134019509439, 0.7451245104593616, 1.5547975056594419, 0.4291146206519296, 0.12045090882888726, 0.7090277957820124, 2.629255186165533, 2.1901980619276724, 1.595601554839842, 0.5392891264730885, 0.372797352291884, 1.364781347013289, 8.188982259842659, 21.582118195872155, 12.090157904932576, 2.7310063713981263, 0.5340128031469161, 2.427152611555592, 6.116465109009897, 9.862340880978493, 3.1016012209077037, 4.490875073017613, 6.650499240044625, 14.863110838397859, 21.377062566818733, 27.18154284261888, 17.48379638118129, 13.444679802463902, 4.171746623131537, 0.8857814402830217, 0.7558555023804788, 0.4525402717051968, 1.994552444065771, 1.4676915926318017, 0.4245897376489255, 0.42502855281195334, 8.106327133793986, 43.58223161389751, 28.78306619582638, 38.125747942155414, 67.81092397628292, 35.62469567022016, 18.464312438041933, 42.89581291137203, 40.57158500917497, 1.3135157237129829, 0.2357750346944217, 0.0688635286003832, 0.054663977841095585, 0.04223713155595526, 0.042360027380768335, 0.07184862084085904, 0.141439595890622, 0.11830857459215388, 0.08188388235266171, 0.061966810570729364, 0.017055930652385278, 0.12716422157902874, 0.02082013431185436, 0.10753362454594144, 0.059372844519994916, 0.03470104037513656, 0.08441719722243086, 0.09112743029911673, 0.10056934905268493, 0.03875000274650032, 0.07459991836860295, 0.07597025814315966, 0.07785661176087395, 0.1101979481116418, 0.04741169542314545, 0.031924540469903624, 0.017132891845258496, 0.11050664324073062, 0.26213521618516217, 0.5424617110721527, 0.17711329213794202, 0.15746379571576274, 0.1638038934118325, 0.06269235329161729, 0.0991741803685023, 0.25751469476569083, 0.16041850490916162, 0.12898473760053036, 0.09815545962943185, 0.08640201612105293, 0.04113123384154132, 0.06611145732383575, 0.052406044767027905, 0.1511637950616498, 0.06445533611000547, 0.03065263533273772, 0.057722932448790926, 0.024927581750577497, 0.04933096783896608, 0.05780035712485833, 0.018065550266915274, 0.0414743033357926, 0.10512165034249907, 0.04007902356886095, 0.1613815387170161, 0.06638454468620401, 0.4169476735255411, 5.805427528196766, 76.22531798578079, 86.4693094068958, 72.05123363002654, 73.58517846753521, 69.84089174578267, 63.45869733441261, 59.61851258431712, 25.881459520709132, 0.5034314005845978, 0.08705496051979643, 0.5298995851509033, 1.415394631124312, 0.7074377036863758, 2.0498400902555836, 0.9844132380620126, 1.0332786772520313, 10.09513355070545, 13.168778323358106, 23.762159770534886, 34.583686859376975, 42.71489358717396, 47.95758062793363, 46.11820082510672, 36.72833296560472, 45.11391324381675, 33.759655721725956, 44.69397644842825, 44.77368685507005, 27.421301641771873, 24.251826501661732, 27.23663253168906, 23.611562328953898, 30.815154006404263, 21.98405327335481, 14.545658711464176, 14.746879243081617, 13.340602651719125, 9.901543990258249, 4.5661801676596365, 3.7771453972785705, 2.3948692987042093, 0.41072566062211996, 0.27794619841921714, 0.4424158988460418, 1.1088205849932087, 1.710145427815376, 1.506443629341741, 6.340755551092087, 12.995149704717821, 35.922870328349454, 49.290335332193685, 62.96018761973228, 60.76982628914618, 65.05199939973893, 48.70676117558634, 26.726363551232126, 20.43824326607489, 9.416338955202411, 2.6267100582199716, 23.833415508270267, 14.875742831537801, 18.11436641600824, 16.20141177408157, 31.025361668679025, 39.797956328238214, 31.084620837242376, 21.20328195633427, 10.342875353751644, 13.274206730627245, 11.932022648472941, 4.721930132758233, 2.4449837063589404, 1.9486369336805038, 1.266171980288721, 1.8812690002302972, 0.44725690037012106, 0.37099287815151677, 0.6192237823720902, 0.9478831014806225, 0.8228307698042163, 0.9866388154125983, 0.6467753071938792, 2.418483683178502, 3.8827652652417464, 18.058490291718517, 31.34208129298303, 19.5648745952114, 6.056189065979374, 6.148667768124612, 9.075557551076336, 20.127297370664536, 26.03445745283558, 22.09098885136266, 22.96744638873685, 25.088415107419415, 25.986765353910386, 25.305902688733994, 23.358110535529352, 12.223149787995125, 8.433935257696337, 4.027503666377837, 0.7463046535849572, 1.4198785131016087, 0.51034108465237, 1.697469798307265, 0.8385231309840757, 0.8814157809942, 0.14915892764204933, 5.989450918089959, 67.1512911396642, 47.45943177130915, 45.28515608079972, 76.1175783218876, 56.9022241715462, 31.12956923823203, 51.67496381267425, 62.276828365941206, 3.207453979599861, 0.6531230504474332, 0.02543384712489863, 0.05225480368901646, 0.05357516388739309, 0.039268494884092967, 0.11122665097636562, 0.1230162921391668, 0.04868530127550325, 0.06155738254047691, 0.029908118529185176, 0.07359859548629293, 0.10192841201299623, 0.08829619149647414, 0.017455533605008837, 0.08934607669230431, 0.10625224290115219, 0.09170712137054052, 0.1041803657708149, 0.14882112883271711, 0.039765226294196425, 0.04390657120834916, 0.09833579672680748, 0.07630701507291487, 0.02786979796515117, 0.03347015158543664, 0.04733384939871969, 0.22483048810353204, 0.21576604385289455, 0.3099780812138512, 0.6236805141933504, 0.2937281918862174, 0.28488949842510686, 0.3626628670721285, 0.2961215424922205, 0.3991626665717171, 0.3794659331681267, 0.34342780889522645, 0.19509005089921339, 0.194059279597094, 0.22254656549663315, 0.12770720937800023, 0.2302824907125004, 0.17634648409101272, 0.18880589294337458, 0.26989669809418343, 0.1571119468538992, 0.3474698726448321, 0.17954923723253513, 0.1563601541302858, 0.21514767300217383, 0.10787583602171753, 0.13075354268714307, 0.14879872842181116, 0.19108612300647845, 0.3136999814981415, 0.27390177511880476, 0.4305880222349398, 3.5532952412482235, 86.56627039755546, 118.74268101107691, 97.0298517903974, 98.74826569711009, 94.09272609218475, 84.94496653156897, 74.07738101097846, 51.552115178877315, 0.4860714498546816, 0.26589566601380227, 4.134929295509092, 4.65262234210968, 0.7944758332544758, 3.4142607017870876, 1.1864597350358963, 1.5350209152506245, 21.307840578017696, 44.69266245442052, 52.73122672111758, 54.86539617661507, 53.21925586269748, 53.305124390509825, 51.056762972185695, 33.67244574331468, 48.44355836991341, 33.32002470570226, 41.57290335624449, 60.17092743227559, 29.027733841250022, 23.4457637417701, 29.76038552099659, 19.769210469338205, 22.547033025372414, 22.077788114547733, 13.406235671812489, 9.066993055805083, 7.985165609467415, 5.458952313469303, 2.415405603185777, 3.8192248296353126, 4.285355623691313, 0.5971273551544836, 0.7261328843812789, 1.4172528539934468, 2.9874935890397722, 2.612879045547978, 2.913750578318873, 6.280286331330577, 12.390996833001415, 35.98971928319624, 48.74436101605816, 58.42865374780471, 62.33278489881947, 69.76072634420088, 65.95188525415236, 45.554642523488695, 41.85133280292634, 14.73382265337052, 7.842023122695185, 48.23862629552042, 28.254893556717906, 39.93221513686642, 36.631391586795935, 47.67147902519473, 54.79912381018362, 38.263305464098536, 27.628644012635757, 16.6563468979251, 16.28572508212059, 14.176945128748494, 5.419143197997924, 2.4548717564152134, 2.7744125454656543, 2.1992825163948924, 2.584210196810384, 1.616845601989377, 0.7962160785832714, 1.083843299458104, 4.547351810239977, 4.2751005868757925, 2.315014990106706, 0.5040904507040977, 1.4878685099463311, 1.3954849252777717, 12.374337546287045, 31.253094480883693, 15.665583648989278, 3.509716728041249, 2.5211573608459967, 3.491078115278675, 15.291685673498339, 18.994732595259144, 16.22098244005634, 14.4806650377089, 20.9557843208313, 26.223562763583278, 33.4071405472294, 35.16678640919347, 24.73682757346861, 17.677559506508615, 5.446957215186089, 1.1059723313777678, 3.5703121990926805, 0.9599339096776901, 6.42564348636135, 6.966394186019898, 2.1450121123944563, 0.906763424075419, 12.655734266004256, 77.34814351604831, 50.61777522487026, 68.94445757712089, 103.24275278276014, 66.90278545502694, 46.093674244419226, 73.92476943231398, 70.73221114373976, 1.426477042898055, 1.13682949494931, 0.08434035860362553, 0.16936127907566487, 0.180627919673439, 0.18507161267822791, 0.20836471519883604, 0.3032800212742821, 0.14900914213109404, 0.3130747311778607, 0.34906961744831455, 0.10315692593013087, 0.15942888785033457, 0.1412828696230727, 0.18094671950224908, 0.20962434760745496, 0.17719046783543405, 0.215083091790157, 0.1571515535995845, 0.2846118988048646, 0.1049578607442879, 0.28829469796149965, 0.1914761843340051, 0.14915517381122037, 0.16218688098653672, 0.20228455113547467, 0.3268483791860842], [0.10821790960166724, 0.07798049583910935, 0.11199253971778578, 0.17881507985293868, 0.10495022284768282, 0.049587327671507676, 0.1272963717459671, 0.06904992545323987, 0.1445774307414409, 0.2466266701418546, 0.14293449390078747, 0.12423126162180018, 0.05194261902943254, 0.0171167312204958, 0.03687805541220211, 0.019569874988989006, 0.008521548382216885, 0.016356578562408686, 0.009338119585487631, 0.03961772372525546, 0.04115890493736633, 0.06558397514445168, 0.02611661915697398, 0.028015605564559662, 0.08483053230109715, 0.13730102038431552, 0.07648817188436947, 0.11767518075723803, 0.03942386900645591, 0.07370138150309363, 0.0070542793330405995, 0.22542769960578413, 4.99350719874905, 53.421238314720895, 60.039920268520234, 36.930872394192605, 52.20520550204862, 60.33063065621161, 36.63584347694151, 37.32620416149017, 29.75390184310175, 0.6981408896465456, 0.2021162722620272, 1.3848333613526438, 1.2627162495928428, 0.12786411950665136, 0.727449942740702, 0.4794001110619115, 0.9060473463708355, 8.786065059323466, 28.002991099511426, 36.452182415992986, 41.41324720075054, 34.62060420743881, 46.54413492448869, 31.911691811776933, 18.54233426432456, 26.89236806284997, 15.717283429638034, 54.174313775954715, 39.424782030044064, 9.999208065771288, 3.627971285773862, 7.573637395135819, 32.398077480254635, 29.398611591708278, 16.24731723339327, 13.294951165876082, 11.549530759934457, 5.727438551764335, 2.603316307067871, 0.6263266431708491, 2.9479678648133434, 0.8699828686733401, 0.46801552356731513, 0.7354496779941744, 0.6739261986747865, 1.5197425479850464, 0.7817997134500935, 2.1272832443637233, 4.974454285637026, 9.941664934158325, 21.412907146638442, 41.35671015708677, 37.515293782757176, 38.88034920538626, 21.17442704016163, 10.33898534313325, 9.289545397604666, 6.62853543796847, 0.1022255392144284, 1.2075419844158235, 3.621593757021812, 2.5866415760209485, 9.04559064295984, 17.551510218651064, 19.184037946885635, 12.425767663986454, 4.663988880572781, 3.055921297880911, 1.566804248479105, 1.8134601678579085, 0.5491545003268027, 0.28559742495417595, 0.07047812018783824, 0.1576145005322272, 0.30385768221270654, 0.1762027659964177, 0.27850976333983485, 0.2952796731504702, 0.04531612319331016, 0.04548097382329645, 0.25426360147614635, 0.7125878370096608, 0.5404157047310184, 2.4536621955133255, 12.286764748634832, 25.25096989447071, 10.07062069831356, 2.081840624732356, 4.215692368245894, 2.9960247441645596, 2.1454112135594894, 5.673353479754541, 16.3271874766196, 16.719326434596894, 17.592842194341845, 16.827344586772305, 21.37254987993548, 21.197570985363377, 12.012454771226453, 4.055178439424885, 0.10908816250101214, 0.7289102288984484, 1.7218974617219742, 0.9103870812442996, 1.594829583360303, 0.26104069104598415, 0.1723201711091303, 12.49864726297317, 41.6116955972487, 22.811277220326087, 34.866250484220444, 73.7383548675045, 43.89766862315517, 21.336175780142508, 41.549820207780414, 51.80459422449912, 3.617349017050959, 0.23311246547006795, 0.0587302576299877, 0.0642267584560379, 0.01023782186225177, 0.0950856916906853, 0.03202695876450068, 0.07441613387556807, 0.03856468607761687, 0.07098690216099063, 0.035494079272593224, 0.04679718565556311, 0.033841083697494, 0.02979390056533439, 0.048334455988820524, 0.018074871641733957, 0.037122288072902354, 0.08841088251961816, 0.08674398244869325, 0.024943520209842154, 0.04394618944535333, 0.04185572319153336, 0.042636998808912696, 0.09337246628297914, 0.021097011894228, 0.04899296984677354, 0.028308931054667603, 0.04310670646748716, 0.16157344374204838, 0.10002178004792622, 0.08318982477630339, 0.23054507500942678, 0.09807475992748815, 0.10206173429445875, 0.0689382145121213, 0.19782437191855526, 0.2073629633072884, 0.26740645268751734, 0.23165558074270529, 0.06806224659686128, 0.03854176855736202, 0.04511316351953053, 0.03941259602265012, 0.06341395832057442, 0.03087082291923223, 0.03342102236685253, 0.02927532798850969, 0.03601715261597307, 0.023018084616670688, 0.06584033880743288, 0.10662060861866321, 0.05233881289079305, 0.0649374429016344, 0.01925327000208199, 0.21145079314949053, 0.1144929511112071, 0.11868053326202978, 0.047129786558329105, 0.06542900321824897, 0.26246046647429466, 23.00238293986167, 82.86983659190517, 79.66257725992511, 72.92288626393965, 74.68184178875339, 70.64591899994882, 54.011547180914114, 70.3774013826924, 25.209535937155447, 0.49200026558772214, 0.49227850872182083, 0.19311386581149795, 0.4676630311915952, 0.20577598152862442, 1.2943567840322372, 1.6719090602090283, 0.3902666697338704, 6.722541903295825, 15.21703806615645, 22.223992501535726, 25.368246801437873, 28.277574662239324, 46.414280937563994, 40.97291800283617, 34.54993094167402, 39.28724411995181, 36.53366965632285, 63.042067097079375, 41.38358231513731, 29.460663487834317, 17.77751522679483, 25.808248481442853, 49.24369835084485, 44.825564122969105, 24.64451066909298, 13.241267646512679, 14.402529462691277, 8.544188180277425, 5.768724929901862, 1.5763682126998904, 4.273808165904015, 0.27562516651326613, 0.2205435673315679, 0.4432411594015937, 1.6024210856806849, 1.9072271234566167, 0.5241381749510765, 3.1039820996022995, 8.218978585735444, 15.79467865728563, 27.011139392852787, 45.94227075576783, 44.82768220286216, 48.03524747971566, 35.24715185165405, 23.859473774510047, 18.139689237840717, 7.455067576900606, 0.3596976471524085, 3.4326046464904665, 13.979574403455182, 19.04487813672712, 23.434418286046675, 24.855900925974694, 20.85769957111728, 12.007442962738777, 5.241425018156729, 3.3679794303832518, 3.3331529507713937, 2.469745384108636, 1.2328154088989383, 0.38097215395781303, 0.0203988395796548, 0.5163659984546324, 0.24007206782698634, 0.41767662150725243, 1.2516550431328437, 0.5553895367249366, 0.08401942138950672, 0.23079045297157383, 0.13629772099516085, 0.8535300579763229, 2.1868439451340707, 12.308943790774192, 32.474485251211355, 27.604319434012137, 11.298366688912916, 1.4104970616679038, 3.87401788946121, 9.905418311395954, 9.68470948357736, 18.421974374401955, 30.378994287983065, 25.418229564543694, 19.62016824753054, 13.168178200721742, 14.106619973336498, 12.647733611445274, 7.943900314069564, 3.686849003837955, 0.47219254136566197, 0.45983018053154795, 0.6228273986808716, 0.7908326255217676, 1.188527927283318, 0.2002654038369656, 0.14069863565025792, 10.32326546407515, 62.81753101656514, 40.87646299792875, 41.022520296035275, 78.48108876136043, 67.27396718917355, 42.98635298205961, 49.33292050515452, 66.1668860527777, 12.784187966777434, 0.3975903477159239, 0.06667370457322368, 0.04328689034727793, 0.1078993472601137, 0.02987003246802957, 0.025491121773337646, 0.13961039243205903, 0.0940165087400425, 0.049999149726523515, 0.10433401236490858, 0.020160289376132914, 0.049865210744281935, 0.10341449235115321, 0.0897978004368563, 0.05458970561683659, 0.017904294504513665, 0.08702440127249687, 0.08317827983128448, 0.17263851128518584, 0.052589400250825195, 0.08823799179686655, 0.07233550036025625, 0.020568411226474473, 0.0361373020155776, 0.18291349703025434, 0.07210027306310593, 0.008358846628858198, 0.2143128669910854, 0.22782995215346738, 0.22682093774839757, 0.30420334108414193, 0.2805326644691729, 0.36378821958937957, 0.3293425163194057, 0.28361730217452974, 0.3122037198514708, 0.4697533787017869, 0.40981533366345596, 0.21774598277143895, 0.15101650699732766, 0.1876888754627397, 0.12444450219552364, 0.11166234816154165, 0.1767970970080745, 0.12291417261886022, 0.07829068483965052, 0.09930571000422202, 0.1932687381462705, 0.14194659287891082, 0.13876426364144973, 0.11072765960688553, 0.21373211105744686, 0.1754660039178787, 0.366413296470719, 0.22749734742026176, 0.13963786434502373, 0.32652190315627283, 0.19675505107208607, 0.5183974797687223, 20.738620335055938, 104.90915606098791, 107.94728279113771, 89.5457890725905, 95.80527213311966, 108.10485224569999, 73.95972559528967, 81.70566143528109, 52.229567343188876, 0.5530530298429152, 0.6486018446664656, 4.498210885832387, 4.307184594292795, 0.645329668637245, 2.2349513250012554, 1.303023751224241, 1.2410673402970838, 11.116332430993358, 39.40672343777072, 52.39684074155746, 56.5696503270057, 49.97801311554448, 63.60920260029455, 45.297758656163374, 30.81616793909381, 42.75798866825719, 30.45547462278797, 72.38004592157179, 54.73056470194171, 26.11938068943639, 16.861188757804133, 21.083747725332938, 38.65145144924041, 36.47560681066206, 28.27413082122803, 18.9526730199014, 12.041916674183263, 7.131554897754424, 7.980320501712061, 2.3122259397660536, 6.57165861898853, 1.6767924110735617, 0.8765446262494211, 1.6883428106384895, 3.5686086646972166, 4.082927982653342, 2.591119206720783, 4.178305316355921, 9.307685379059086, 17.2042667096661, 26.875229266382036, 49.585368171814956, 51.152143247665904, 56.532964398784024, 52.5214740537828, 36.814185803936375, 27.42999557525881, 11.767119342280973, 0.4480014152584538, 8.28150704983742, 25.23814178282215, 30.678261326205348, 36.296554534666, 38.17956678328976, 28.003873632800197, 17.46312156800301, 7.77518593495892, 4.110599323626488, 4.8409544556371635, 3.416430998233057, 1.3586076589361316, 0.6875637281806238, 0.4398063275842898, 0.721507674503711, 0.5762354633019817, 0.41608404728674125, 2.93072929305415, 0.5010555474267853, 0.3659796907055763, 0.2745216934671325, 0.2870653413476483, 1.044408402615978, 0.9868455978651202, 6.252738545017858, 29.437356764270415, 37.55079907755698, 9.93451935629691, 1.1317000153564638, 3.380866622732532, 11.143274211114454, 13.309846366605452, 17.710234811229093, 31.18820671112307, 26.26360231830228, 27.095558604886456, 23.860399453870713, 32.88806584573562, 27.04919226707951, 17.187818250348492, 5.259268370366866, 0.5981840661937191, 2.049890835919688, 4.061393680111054, 5.483727964662737, 5.991730305456347, 0.45187337684535217, 0.8384146529339975, 22.970737257311423, 73.6431432539417, 38.667921481593964, 55.13776163901053, 104.98879586496662, 73.62922668457031, 47.796959569377286, 65.98750822005734, 85.22563565161921, 9.72736623979384, 0.4075757215820974, 0.1879907294266647, 0.10539165037053247, 0.2293618215668586, 0.35285758515519483, 0.140174723440601, 0.22434607538725101, 0.15371845314098945, 0.11293248363560247, 0.1820217706863919, 0.20393626734374032, 0.14394425907202307, 0.1897367817019263, 0.1393636355116483, 0.14963874383078468, 0.14252085238695145, 0.17847882854121347, 0.11351276459472795, 0.1812776235202628, 0.15344906598329544, 0.3845319806808426, 0.17302362368472163, 0.11826930492515526, 0.18522279246920542, 0.29134581165928997, 0.19149797187457163, 0.1656466719484137], [0.07712830729301899, 0.1648808138505105, 0.09306277523958877, 0.05064595776099352, 0.029140571207408945, 0.11439918961015441, 0.012218402379432754, 0.03828456602810371, 0.15621648200096624, 0.19849033215113226, 0.12605671891041342, 0.1598377030102476, 0.06717944517731667, 0.021268414491186702, 0.05954929755159444, 0.032441812612476854, 0.029465915342312188, 0.03386571342425962, 0.010572211580320953, 0.011649226822379616, 0.0491392198619583, 0.017110531653968558, 0.047354514620477156, 0.01785372121019229, 0.14408004049572254, 0.18410628060660056, 0.10565444917207766, 0.01433939244898577, 0.04352616641910807, 0.08654906669811857, 0.06041452874459567, 0.13404874731936764, 0.20794713599306924, 33.3172986584325, 73.263104807946, 53.401755902075, 25.307995273220925, 63.13638441024288, 59.03276543463431, 28.657801382003296, 40.63752397414177, 37.133611863659276, 1.477367344402498, 0.18527310912407216, 0.4788446360297742, 1.6522576179235213, 0.38239548403409224, 0.13430550934806948, 0.4447360727335177, 0.8924361702895934, 3.7081996904265497, 11.408394075209095, 23.83380578410241, 31.023053353832616, 27.496393457535778, 37.111987836899296, 28.706268149037516, 33.219906207053896, 23.550340014119303, 24.86499494121921, 34.165832842549975, 16.285025919637373, 8.140443419256519, 7.5514887513652935, 29.7033699481718, 44.72344913790303, 43.188582543403875, 33.482442209797526, 10.465982863979956, 2.1265867785100014, 0.4025277231008776, 1.1955332804110743, 2.1230662061322123, 0.2104231781296192, 0.10421561347621103, 0.4011310222408464, 0.2808295082180731, 0.8321361640287984, 1.7613925424314316, 2.3303217945560335, 1.6903593992033314, 1.1855660475069478, 2.5720457011653535, 9.736101358167588, 17.360251526678763, 28.29032236529935, 22.93379637502855, 12.898501523079412, 9.454762493410419, 2.8146903841726245, 0.07048294654176121, 0.3759692627335749, 2.8847046917484653, 5.037129838620463, 10.440706129997007, 14.474649102457109, 8.073151726876537, 4.8076059741358605, 0.969418445902486, 0.21811382754916148, 0.03017493737711301, 0.18262849700066353, 0.16895094706166178, 0.05782957188785077, 0.03126422822054836, 0.008395987529037221, 0.1323249115939102, 0.14915583264683524, 0.21449311215791012, 0.7062468966168742, 0.11291789732152417, 0.6301072564336562, 0.3611196902009749, 0.2559078100227541, 0.34005365124152553, 1.8599544729917281, 12.179340835540527, 9.73268203196987, 2.540424288280549, 4.523885250091553, 6.941012038338569, 7.620365081294891, 8.625532254096, 3.975934304537312, 9.374789287967067, 17.659302834541567, 17.742570830929665, 19.97179892755324, 13.780132666710886, 6.087663635130852, 1.961415280257502, 0.39595122599313337, 0.8151562848398763, 0.21574335232857736, 0.5600723564144104, 0.20568285588054888, 0.26541042592256303, 0.3062821053449185, 15.149738038739851, 36.227073669433594, 17.679697198252526, 32.698521229528616, 75.299269922318, 53.00867165288618, 20.245623511652795, 35.75472224143244, 65.59193718817927, 13.66358434000323, 0.617685539107169, 0.0347176912961708, 0.19556229813925682, 0.13750959548258013, 0.03462346631192392, 0.05094123869052818, 0.0554415992190761, 0.02886749725157936, 0.08449582082609977, 0.0479276096748729, 0.08582073158674663, 0.04002573066240838, 0.09827993359536895, 0.11773756329691219, 0.04065316433327333, 0.05635488327712782, 0.028239841415216366, 0.04808424401187128, 0.050224617063518495, 0.09622285728372874, 0.022992162116532846, 0.13276435494903596, 0.03171811424826663, 0.03512608127728586, 0.048694720326532284, 0.05053851009917356, 0.09094912333474045, 0.05013320745239335, 0.08528790977453032, 0.1503867980453276, 0.2168605383485556, 0.12222329154610635, 0.09808980589432102, 0.12293458886204228, 0.06202137901357586, 0.05996375111863018, 0.12903413494988797, 0.14904582242090858, 0.05477513336846906, 0.2039527995211463, 0.06512037703707334, 0.054694992910710075, 0.05217393544772941, 0.03934313866099523, 0.04019372608332385, 0.03584601240412843, 0.03058560263936318, 0.017614029535663225, 0.08692583640015895, 0.02515448741765032, 0.04036999525382154, 0.03718893389187513, 0.08968536171220964, 0.16161511892512923, 0.2066953023595195, 0.06047883033452015, 0.163834230493634, 0.08359549897572688, 0.09500389648300987, 0.13950922286077855, 0.42619049368846806, 55.117549665512584, 90.69965624040174, 65.32269393244098, 64.3993091583252, 82.0538188565162, 67.57647606634325, 49.55709180524273, 68.25756426780455, 31.74355353078535, 1.3024437307350099, 0.058328973114370346, 0.5116903493481298, 0.9455511911261467, 0.42801127017986396, 0.2626949200226415, 0.26823241804395953, 0.23897325259543237, 3.1949271550101623, 7.7033016374034275, 14.365066905175487, 14.659936966434604, 17.073367411090484, 24.04700033126339, 27.144105780509214, 33.202918421837595, 23.740384732523275, 43.25394491995535, 34.9329190100393, 27.163441104273645, 29.342433444915283, 19.488925741564845, 49.08141028496527, 58.23304122494113, 44.296761943447976, 24.497621828509917, 8.553185116860176, 3.4318870978970684, 1.799621678167774, 3.1307353608069883, 2.9044327428264003, 0.3207559883594513, 0.1063191070551834, 0.44265032175087166, 0.7673887415759025, 1.3558096606885235, 1.79880827665329, 3.0528608685539615, 2.3115637946513394, 0.9726533594150698, 1.4933034441163464, 9.30280496997218, 19.068875197441347, 31.055401140643706, 29.389792142375825, 15.044884258700957, 9.345626465735897, 2.6375914485223833, 0.30569050160627215, 0.47370660689569294, 6.181923093334322, 9.31988787266516, 17.868067064592918, 17.470348535045503, 9.68541649080092, 6.087177261229485, 1.4360764310244591, 0.7670127456226657, 0.34666581740302427, 0.11254697287034605, 0.21682854651683764, 0.05671828857532913, 0.0728448109340764, 0.04387418867178983, 0.03911030155816867, 0.07239370005986384, 0.3631994044107776, 0.19151975941513816, 0.056618628197259484, 0.5464421200656122, 0.5626020400274185, 0.2374985946282264, 1.2987440776440407, 11.061374141323952, 23.277294020498953, 15.724820263924139, 2.022560373429329, 3.091412864385113, 6.970661724767377, 6.539085786188803, 7.193900971643387, 9.645438713412132, 11.265701190117868, 11.337498214937026, 8.694362986472346, 8.336314328255193, 8.719423990095816, 6.166707238843364, 2.798807481604238, 0.9605294357865088, 0.8439597811910414, 0.8981065079569818, 0.4950716652937474, 0.304948530129848, 0.557680384766671, 0.2709265960560691, 15.141429478122344, 61.88918836655156, 38.11001139302408, 31.378873125199352, 72.72270417982533, 77.80288742434594, 45.01742293757778, 45.26927440397201, 72.59598808903849, 35.562557481950336, 0.6567123255902722, 0.06661522908196335, 0.1080245030443034, 0.13986379899565252, 0.04400904695954054, 0.03521359533131604, 0.07724244673285754, 0.04917594611704831, 0.0356022815310186, 0.19758705320137163, 0.06265760737381156, 0.08087708960257231, 0.1016700411996534, 0.05984427204595939, 0.06860832173016763, 0.03674299411115147, 0.037942454143757784, 0.01982298277829203, 0.018518564869619666, 0.0819952025889389, 0.045372855834542744, 0.12662264338183787, 0.05065432344112666, 0.038981905222059264, 0.04898391085706892, 0.015034203552791189, 0.03517922479659319, 0.06038770417592699, 0.19600955559121025, 0.31770812287445993, 0.27678916050541785, 0.35476587953106054, 0.2616863805920847, 0.3520059405315307, 0.2309624090670578, 0.15804629832986863, 0.19020961116879218, 0.36640018104545535, 0.326337521114657, 0.31869977772716557, 0.11818603882866523, 0.1900986509938394, 0.1352927055690558, 0.1101735175677365, 0.18492179652375562, 0.14251149079251674, 0.1702242158353329, 0.1041478836428254, 0.3605251446846993, 0.22871148952793693, 0.151848754274749, 0.11923593168537464, 0.46989148903277617, 0.555841589887296, 0.3203729137537941, 0.13365531520497415, 0.28916975423212976, 0.20088682371762492, 0.19586710920256956, 0.2846926138285668, 0.1492485292856732, 62.72949734041768, 117.70332351807626, 95.05284386296427, 67.19766139984131, 99.99124911523636, 107.00028142621441, 63.533571458631954, 76.56778797026604, 66.54745794111683, 1.8246364713676515, 0.27707540159744604, 1.5594583845907644, 4.699635870995061, 1.2705434618457672, 0.8640265657055763, 1.108107939362526, 1.6706467924579498, 3.5805625780936214, 16.282033151195897, 33.56145835691883, 47.66926288604737, 45.18335096297726, 54.11481534281085, 39.714751089772875, 40.3616048443702, 31.63797901522729, 36.515995456326394, 46.54493116563367, 25.87177126638351, 20.79668906427199, 20.78773037079842, 50.203208154247655, 57.29883463151994, 59.26657792060607, 42.87420849646292, 12.918510513920939, 1.9402428163636116, 1.04467254973227, 4.520773829952363, 3.9136845738657065, 0.31190641644981604, 0.22937533535784294, 0.9408652457979418, 1.09405163555376, 1.6532246047450652, 2.329091396062605, 3.728672991837225, 3.2454982736418327, 2.371008295205332, 3.1662274176074616, 10.811390703724278, 24.484840785303426, 40.11314622817501, 40.28028234358757, 23.65351600031699, 17.179602846022576, 4.178656368486343, 0.44444612377593595, 1.1748311332156582, 9.922593389787982, 19.842527412599136, 26.963190378681308, 21.964341402053837, 12.193178957508458, 8.366306731777808, 2.1256956650364787, 0.9772844528478961, 0.4463802199930914, 0.3336192174784599, 0.43708132219410717, 0.13182986557724016, 0.11900063544031113, 0.18204838458088138, 0.2962779776463586, 0.32176590674827177, 1.210610013334982, 2.841054104989575, 0.24399805393430496, 3.8492182137504702, 1.4586993138636313, 0.5527513750618505, 0.3866636969389454, 7.054707331042136, 20.04204465496925, 12.736789065022624, 1.8825131270193287, 3.982869790446374, 7.062850171519864, 21.344132308037054, 13.56305987604203, 20.23276794341303, 22.58067911671054, 27.939976261508082, 24.87332409428012, 28.72899240063083, 17.686480937465547, 9.205352702448446, 4.164500534534454, 0.8707411731443099, 2.296855396801426, 2.0843649150863772, 1.3783450256432257, 0.9061587661985429, 0.9041655279936329, 0.45576893394031837, 36.252851486206055, 64.97150844143283, 32.69188850156723, 53.014810162205855, 103.68986375870244, 83.63953898029943, 46.42268657684327, 61.28459815056094, 95.38271519445604, 34.581266756980654, 0.8363590245285343, 0.11495607424407236, 0.26276187610722357, 0.21357549204220697, 0.14268291062645375, 0.25426563927002493, 0.1815268778873067, 0.10611715095658457, 0.19401003546532125, 0.34986307003325035, 0.22074972159199177, 0.1730105542247334, 0.18596154637634757, 0.2963270379170295, 0.1253911187391608, 0.23500378333753158, 0.19128164396651332, 0.11079259321934755, 0.09567079134285451, 0.19103566845578535, 0.10067745171968015, 0.23039392586196625, 0.2146440927660273, 0.13325874213009112, 0.19309045416453194, 0.1544805114427882, 0.19409542362536156, 0.2051782797301008], [0.03996711727532168, 0.1132403207462161, 0.09510228515512521, 0.05902232865111963, 0.09251415669437378, 0.0574287508554276, 0.06746014745365228, 0.09338932787819255, 0.034712160141357494, 0.17584743909537795, 0.028682322308961904, 0.016155327264700207, 0.06554590057461493, 0.05324540517082619, 0.0782056337582969, 0.037964004197067795, 0.038668927661473715, 0.05863432426966968, 0.031690477626398206, 0.04537337677433126, 0.038354065524594444, 0.020247043087898244, 0.04440835496831325, 0.06000683207305209, 0.05970296329788624, 0.13520235315926615, 0.05916654470286543, 0.0706057044707479, 0.06570336228657155, 0.04722196225737853, 0.2255737925729444, 0.14241687893386812, 0.2843594268685387, 5.606150530999707, 61.84382615550872, 71.46439213906565, 47.724631063399784, 33.238113849393784, 69.74757855938327, 65.31873233856695, 26.655409836000015, 38.22937303973783, 39.97877367081181, 4.222432471090748, 0.5129217590776183, 0.1400966897246338, 0.2768668724644569, 0.6036305836131496, 0.3319298710313536, 0.015779721058694827, 0.08362798110371636, 1.6009057024794242, 3.724604023079719, 13.744863694713963, 24.04860850303404, 27.74378322785901, 26.704096255763886, 24.210435690418368, 32.094182045229026, 14.233626319516091, 18.85336252950853, 25.11761715335231, 11.022406374254535, 12.685412879913086, 28.627508917162498, 33.12116446033601, 34.45164418989612, 32.773634618328465, 18.913610135355306, 1.8147207195720367, 0.1324969596199451, 1.2466795165692608, 0.5068817686650061, 0.20559420418595115, 0.09151188386303764, 0.07562405534929807, 0.08588947265619233, 0.2839701622724533, 0.5362514346357315, 1.7652386715335233, 1.893624098550889, 0.18554517758950112, 0.15673210513928246, 0.44884159920677064, 1.1737859441388039, 9.024839343563203, 13.049220558135742, 5.488581407454706, 2.290835294031328, 0.3480080953769146, 0.010016530662054017, 0.5603415290674856, 0.6924257511573454, 2.0243949395033622, 6.121536733642702, 6.590636516771009, 2.6990569503076616, 0.3215418413521782, 0.0709821907202563, 0.05823043122467014, 0.041933764568379814, 0.09210344163640853, 0.03603401421118648, 0.07576981889865092, 0.0760259450743756, 0.07655194870406583, 0.030969575483111605, 0.02680447035198731, 0.01003022448370053, 0.178289819328535, 0.10810973798675884, 0.33343731756171874, 0.1061322428886929, 0.4694303041023593, 0.41960704050237135, 0.4668952272303643, 1.764945106640939, 1.1590369742724205, 1.2850916553889553, 6.427372271014798, 3.959975160898701, 4.665566653974595, 4.340339408766839, 5.997347139543103, 12.205630521620474, 8.387663056773524, 8.126914183939657, 5.491178506805051, 1.7915109520958317, 0.5864507861195073, 0.08157769999196453, 0.25001872360946675, 0.8245692990960614, 0.09349968284368516, 0.18527589768411654, 0.7161185830350846, 0.5173122702587036, 28.060377336317494, 33.33141526868267, 14.489312883346313, 35.782504389362956, 75.84010985589798, 65.6595157038781, 24.029545783996586, 34.04159176734186, 66.08272767836048, 26.70928555150186, 0.9654932565266087, 0.041681311784252044, 0.03641000250354409, 0.02961802784533751, 0.10013715288932286, 0.10500889752180347, 0.07436067677072941, 0.04021891505427418, 0.02791898655554941, 0.046186828084530375, 0.04355836126412596, 0.08675498347128592, 0.13262336412745138, 0.17278454296531218, 0.034620536025613546, 0.011904452844793278, 0.03785484432873707, 0.05623381074157454, 0.02608679343886193, 0.05983533179988304, 0.08098591239221635, 0.016674426526972846, 0.06829136051237583, 0.07443673397985197, 0.019436181154883197, 0.017393135743576194, 0.05418677018174241, 0.03219481437436996, 0.03648245526898292, 0.042077337106269215, 0.15858202361531798, 0.12378577383295183, 0.08718725624344043, 0.039451497967445084, 0.03732536649031024, 0.12188936148079173, 0.08305442639656606, 0.041904955831987244, 0.09745222155845935, 0.07633575103095463, 0.044182393504607106, 0.04024976924542458, 0.0747590501522345, 0.08290184466468711, 0.025838492851283763, 0.023668975899777105, 0.06036741816769205, 0.037455616759196404, 0.07183968825566192, 0.05120602549023686, 0.0997029189320822, 0.036813466539306026, 0.04954069972999635, 0.03183949321898962, 0.019921865577118534, 0.0801280701172448, 0.09887624111387039, 0.03417240523342644, 0.04964290351997461, 0.22733554965065372, 0.03207129227267879, 0.6537883824879124, 15.842883606110851, 93.27601801964545, 88.57829724588703, 51.81072488907845, 68.07234210352745, 86.90366483503773, 66.26255266128048, 47.79794408429054, 71.27338840115455, 41.08086162997831, 2.7725244145239554, 0.6346504029727752, 0.23405320611932587, 0.752789005637169, 0.3590580863097022, 0.41715077875602635, 0.3692323468144863, 0.40852524159896764, 2.209637818797942, 4.125779386489622, 10.6082413465746, 13.829404500222976, 12.0021124616746, 7.926227094665651, 16.16207334303087, 20.030746267687892, 18.469278158680087, 26.2194227018664, 16.44241298398664, 15.808843316570407, 23.650978226815504, 35.654301720280806, 47.86377322289252, 46.271259553970836, 29.0844670034224, 11.05203595853621, 2.1343508651179652, 0.8105334038695982, 3.0535605213334485, 1.7182457350915479, 0.3804256881196653, 0.05451322705935567, 0.09676109533756973, 0.1527934632594547, 0.2816079761232099, 0.5886548517211792, 2.2062915467446853, 2.725500834565009, 2.1253046537599256, 1.2334564712739762, 0.8870281411274787, 1.9370576066355554, 9.648899224496658, 13.178546005679717, 3.5923453780912586, 1.0662727971230785, 0.09603923366915795, 0.4041199295991852, 0.2151939293910419, 1.644192979701104, 2.01237422323996, 6.056233192643812, 7.5630249323383465, 2.749450581689035, 0.7755915207728263, 0.11041808347668379, 0.13548871682536218, 0.0037653274146930106, 0.05115560158306072, 0.057901775674714204, 0.10540096599969173, 0.06883543615619983, 0.012554570379096174, 0.05105521725190263, 0.06803750195690701, 0.03424068281967794, 0.07225515305875771, 0.08866009858226584, 0.26624671814422457, 0.4617621623460324, 0.9100625051125404, 1.0904314104587802, 1.5714886616314612, 3.654645609278833, 1.9341600782448247, 2.1770152209266542, 8.203090535056207, 6.75794227469352, 10.186677748157132, 8.861226497157928, 5.913633954140448, 6.854815012024296, 5.22903032841221, 6.572919660998929, 4.7273871302604675, 2.607110219617044, 1.4315332231983062, 0.5956073141386432, 1.0508076269780438, 0.8230777565510043, 0.0838751670333647, 0.23137002912980897, 0.366304757133607, 0.6619197622902933, 23.645231954513058, 61.623016326658195, 32.94271230697632, 26.188535997944495, 67.26297670795073, 88.25025373889555, 44.49388065645772, 36.04977861527474, 71.57534814650013, 59.428199183556345, 1.840243704857365, 0.3483860831587546, 0.08098686234124246, 0.12004269887843441, 0.1570906649313627, 0.0621512845428961, 0.14156776240035412, 0.05625999945726606, 0.03493235296299381, 0.21220382693554127, 0.05905832329224195, 0.08730628332423587, 0.14468019377560387, 0.0711554721478493, 0.022370349615812305, 0.06391724744330972, 0.052639333861729795, 0.055171089742573044, 0.09799711691636233, 0.05878396039347976, 0.0884870239984124, 0.015720500546928137, 0.11024277191609146, 0.04098013448979586, 0.034857207398501136, 0.11694761173379038, 0.045905528259613824, 0.037865125228680914, 0.025900691529856096, 0.11977544144516993, 0.18932792057673778, 0.363576932539863, 0.3004316757282903, 0.28789498392612706, 0.18065257238284235, 0.23281920701265338, 0.24744200219790785, 0.2858503565432564, 0.2148553644937854, 0.2401375836662708, 0.17202128956635154, 0.21142928140057674, 0.1720211057052497, 0.10523058804533175, 0.13949975401403444, 0.12095083482563497, 0.20073083289448293, 0.0883234259221823, 0.16167720269051292, 0.07820398666925969, 0.19175372266721344, 0.17991922705644564, 0.15151375934721964, 0.1211386182976346, 0.16112339773005055, 0.2768187314992951, 0.1273921557191399, 0.150489132070253, 0.2926123695027444, 0.37809043762183964, 0.112762373812016, 0.7794610002348501, 11.150197194468591, 105.34591197967531, 117.82177125253986, 90.62197762150919, 68.47702872368598, 106.21128097657235, 106.80028761586836, 57.664477978983236, 68.12729450964159, 76.36342463954803, 7.8279805471820225, 0.9743625322176565, 0.5020771409955718, 3.1704976529844346, 1.3485511921105848, 0.3820327567237039, 0.67162909935559, 0.36273049731408397, 3.004338452892919, 5.521569521196428, 16.000954143462643, 32.510918186556914, 43.846956299197295, 45.26930186056322, 36.20450827383226, 40.187231955989716, 22.830208539962772, 28.327445637795236, 35.604209130810155, 20.3453536956541, 25.53141740060622, 49.23996425444081, 57.006312108808956, 49.134013191346206, 41.09589215247862, 23.490678802613292, 2.4253890158668643, 0.472949528165402, 4.244906671585576, 2.983789891004563, 0.5973368955235328, 0.0999908684001815, 0.138884830558973, 0.26621457309492175, 0.6478375340661695, 0.7007837704112453, 2.969772320601248, 3.914379813978749, 2.890478175493979, 2.4573759446221017, 1.0900565789591883, 2.868577376488717, 13.125873477228227, 15.977657225824172, 7.162300886646395, 2.1839279080590894, 0.3141665903310622, 1.1522366875602355, 1.9429882303360972, 2.780774629885151, 1.7814951798608227, 9.128102602497224, 11.747885019548479, 4.103620936793666, 0.7778851880181221, 0.18311407417058947, 0.21986751006014887, 0.11942517838530964, 0.29865079709599096, 0.17318949704208683, 0.19612062301847244, 0.1517094948118733, 0.16552664129243744, 0.14710843202567872, 0.2239320201859359, 0.1307124956961601, 0.3862768838242177, 0.32956952349312846, 1.178561062101395, 0.7169132920042162, 1.2778983962151313, 0.4193692468106747, 0.3439890755520713, 0.9841773442683682, 1.6165999635573358, 1.7951853549288166, 10.98851219300301, 8.872107152015932, 12.49007688414666, 14.836320069528396, 15.933468784055403, 19.645661692465506, 12.263888505197341, 11.334918275956186, 7.18896221730017, 3.7094683320291586, 1.4620338188063715, 0.5362096368785828, 1.1039714322936152, 3.4916282276953425, 0.08812507809770685, 0.8362814351435631, 1.4844702664882907, 1.0026635974645615, 54.014936108742994, 56.88946470137566, 27.851834720180882, 52.64990029796478, 97.16423219250095, 93.88921783816431, 45.96751513019685, 55.23660536735289, 92.78378409724083, 61.23859659318001, 1.1881247811740445, 0.2837506627603885, 0.2905418483480331, 0.12786202042573883, 0.21239122736357877, 0.1876190695310793, 0.2654318763844429, 0.13979629132776492, 0.11991889140899144, 0.3508915277498384, 0.1729201711714268, 0.24004372257378795, 0.4582744091749192, 0.2608900168730367, 0.18898788479066667, 0.13280763891675781, 0.17339811810562689, 0.15393213038482975, 0.20062428538597402, 0.15156101165038927, 0.30038993925817553, 0.10975472794304933, 0.29815489306084575, 0.15181213527196838, 0.11430886784388174, 0.20349434186373988, 0.19574329407224733, 0.11467544091564995, 0.12342803375495058], [0.04417068002024486, 0.06692616884867031, 0.014187572974591486, 0.07425520944619372, 0.06110513402569679, 0.06917706540515346, 0.03264096865971242, 0.08231068525703684, 0.05506908130501548, 0.04159846320568074, 0.056587908071495836, 0.052480887726790486, 0.07467009202246705, 0.023024582957488396, 0.02078801224518928, 0.009351201494404627, 0.042304336619112766, 0.031110616100411263, 0.030043459452328183, 0.025783876527942, 0.04086174326197755, 0.08631836698060075, 0.07469803890994481, 0.14520775256378038, 0.038960991021726406, 0.02664495552439363, 0.08804223334957516, 0.019100513985200275, 0.07018696847221545, 0.15687801424534092, 0.0071451967326743955, 0.11146787674196305, 0.13371902307675732, 0.3601120087888933, 10.740102606434977, 65.97610981233659, 73.73247915698637, 37.938019383338194, 27.0578783558261, 78.73437189286756, 69.4492587735576, 30.952656615164976, 31.089357099225445, 49.933858994514715, 8.726484256405985, 0.9620335421735241, 0.3767475161340929, 0.13926376828983908, 0.4114477750995467, 0.0276175769226205, 0.1270823727451986, 0.08211655857702417, 0.3230676739927261, 0.5238969491854791, 2.9733164272000714, 9.357424955214224, 18.51783710141336, 10.962589248534172, 16.50204673890145, 18.270137463846517, 12.413751482963564, 31.156994450476866, 40.25436724385908, 16.696731621219268, 22.062073138452348, 25.808540698020693, 17.53167087031949, 10.101492693347316, 4.055758705062251, 2.029861375208824, 1.1375676359861129, 0.5082710231504133, 1.11392138225417, 0.21165962871764937, 0.02834460202364191, 0.03629229692441802, 0.027998460516814264, 0.044118746919857885, 0.08948427129296527, 0.17595659130282942, 0.465232479355989, 0.586135893339111, 0.7128573773849396, 1.1321084321506563, 0.7434917013010671, 0.7967167323635471, 1.668221174228576, 0.20179128244278893, 0.5426590553214473, 0.372516259310707, 0.1234898723721985, 0.03489058584936204, 0.3666394149824497, 0.4763696817380767, 0.9133341908454896, 0.3130485616143673, 0.6551252978463328, 0.12131668011387511, 0.09970619012751888, 0.12939727594775538, 0.059666374938622604, 0.012049779724029284, 0.03187328727254945, 0.01949834918993856, 0.06344218099970492, 0.040486743223042264, 0.09147474392046852, 0.021891764913415237, 0.06364874128672866, 0.10604992674122896, 0.05954437543668094, 0.3079801851943616, 0.16503196299797104, 0.32131783724311863, 0.05850380203957039, 0.14515359014753373, 0.13077655596838844, 1.5894626777979637, 3.012359945043441, 4.374981782128734, 2.931812357517981, 2.9553142189979558, 4.746369931005663, 5.120134055614471, 3.7945374317707556, 3.991734592183944, 2.307940014908391, 0.7343165420236126, 0.3641115393369429, 0.3049725852906704, 0.28040132635543424, 1.4509324080521062, 0.9006314724683763, 0.5400292286949774, 0.6442632742466465, 6.070944532271355, 35.14783743889102, 26.684872719549364, 15.555454281068618, 50.52620749319754, 78.02370117556664, 68.58350538438367, 25.761311438775834, 31.45727542138869, 70.22362878245693, 53.24460221875099, 0.867102807087283, 0.05781081805546438, 0.1172710004292669, 0.002226212964160368, 0.0596767018038419, 0.0164357939689991, 0.09743064852251161, 0.07050320956735842, 0.024955948071193793, 0.08625662795478299, 0.07112849819203539, 0.06114993484750871, 0.058557983608015125, 0.1385344372641656, 0.037240480117860346, 0.06323086713711101, 0.03096859680578834, 0.05509992783528663, 0.049806811861814036, 0.038838631458460324, 0.0867752388360039, 0.026915970618926713, 0.013329155176066825, 0.03661490037977215, 0.01626397002368204, 0.02616477352867444, 0.020084609465313055, 0.06911800002619144, 0.05711945817775785, 0.011747733280513317, 0.040003805226015474, 0.04729893877201023, 0.01744160995698504, 0.054479944369485306, 0.06984629683316716, 0.038390431718360034, 0.04174238048313607, 0.02194967541483141, 0.04262505932861278, 0.047727695200592286, 0.04603737965226174, 0.08997009361102697, 0.005890503675947267, 0.009306369071465828, 0.018007653172037775, 0.10878911241889001, 0.04934966421475814, 0.049383057987377535, 0.030624765054052396, 0.0628278550932244, 0.026464543733445388, 0.02320566316015057, 0.05642260928007384, 0.025645055650402943, 0.03513556161534882, 0.0995505593657013, 0.028854849139949488, 0.10386810067199892, 0.06433614048986666, 0.06822370728778263, 0.001979766429060199, 0.10207642019996721, 0.15519689558254135, 0.7212153966388395, 34.69967526774253, 96.80870071534189, 82.69241994427097, 54.22577919498567, 65.12688136869862, 93.71390358094247, 65.50365640271094, 45.327352939113496, 61.87440103100192, 57.002499565001465, 6.653315011532077, 0.7202838337229145, 0.10427760531104381, 0.3082306040150504, 0.37192392012765335, 0.043678728998788906, 0.6729715918340992, 0.156505833409967, 0.5430923546514204, 2.2210857464421183, 3.2904616286677704, 8.897086766458328, 10.203681222854122, 1.8452817441955691, 5.215232901034817, 9.416273255502025, 14.645935085511978, 21.454492115205337, 11.361928697555296, 7.416917624012117, 18.137453486842496, 21.464878551421627, 22.06806063652039, 18.278264614843554, 8.007204917169387, 2.931829272739349, 0.18864912071054984, 1.7809172431307456, 1.971417324196908, 0.284787149078423, 0.08300439319423131, 0.04211707791734127, 0.09614005850087251, 0.015268323852890923, 0.061289542880389965, 0.5959518698434676, 0.620911504712797, 0.8514543887107604, 0.6241018012646706, 1.0622216016054153, 0.9196062446121247, 0.4355351116147734, 1.6539616426152568, 0.5673779547214508, 0.29498543410051253, 0.18451454418320812, 0.10623904320621684, 0.13374827231370634, 0.4962154345646982, 0.3931167006732956, 0.8069588989019395, 0.9782378339479048, 0.9294311690234369, 0.1670586179581381, 0.10529259520192301, 0.16967261720809246, 0.0826776260510087, 0.03791426593858389, 0.019603919936344028, 0.022174487746651136, 0.03628543660705609, 0.05745565969376795, 0.05202896479937819, 0.03979533738006027, 0.10000861099650783, 0.09027759364295392, 0.08875624261676304, 0.36886091674527816, 0.7018577031070187, 0.4108470702363599, 0.1098622483832221, 1.3200405864946305, 0.6679045024418062, 4.646324976798027, 8.59600563203135, 7.2625453914365465, 3.2214551250780783, 6.170022622231515, 8.835239814173791, 4.796893981195265, 3.1705616366478706, 2.706259157388441, 2.415885603235614, 0.7225200137303722, 0.5960445358387886, 0.8387959808591874, 2.4929692476026477, 0.492753176799705, 0.42216552902133236, 0.4415248160160357, 0.4663968717138614, 2.910062569764353, 37.44530300940237, 60.548569310096006, 30.481224982969223, 30.439245816200014, 67.36618995666504, 91.43227654118692, 47.495113572766705, 39.67668056488037, 71.48951884238951, 77.62994227870819, 5.472544797005193, 0.4851189267731482, 0.20875468459581176, 0.0894451548435515, 0.10720655862842837, 0.04362445933023288, 0.056601946632708275, 0.04057439900333843, 0.06679250182764185, 0.09613294154405595, 0.08659091808142201, 0.08080280971743407, 0.07516375141999415, 0.057841645433537425, 0.017147154487188787, 0.12150453253378793, 0.06873335494028945, 0.0701829694932507, 0.11001269272979229, 0.03543106471038154, 0.029706646981198463, 0.08405110678605496, 0.05941565734364333, 0.006749509925758767, 0.05089793940104785, 0.05984103915491893, 0.01248937342391019, 0.04366141924213979, 0.07469166505841479, 0.05224636140009088, 0.08093520503250823, 0.24705295210644124, 0.14395501494647997, 0.15703904592702467, 0.264961161320248, 0.26857035474911817, 0.09739862604727668, 0.26289480768384477, 0.19243396277869904, 0.13033619330775353, 0.2396450504179924, 0.137368681269788, 0.16241750409526212, 0.1505043465764292, 0.1383109540948945, 0.29749201250172436, 0.1492228653402098, 0.20644021040249258, 0.16827188672557955, 0.20449609375528752, 0.16339319367562571, 0.3640114576105149, 0.26061321398423565, 0.24650469362255067, 0.20214723753592662, 0.19445127146618982, 0.20993069084661625, 0.24800743637306077, 0.15286354498276788, 0.20478264128248538, 0.11461113549528584, 0.1831146717191704, 0.2441972214728594, 0.471747444281655, 25.432359903089463, 119.0030400983749, 121.56866242808681, 82.37573562129852, 59.23063332034696, 114.9027669045233, 108.54840170952582, 58.56739582553987, 54.2914592835211, 93.40601321189635, 20.13338488917197, 1.7749542598762822, 2.0416471169840906, 0.9699259638305634, 1.2944324122321222, 0.1595266100259558, 0.6016526671667254, 0.20733302459120753, 0.5403063686624651, 2.1431666372283815, 4.5351806955952805, 12.817174119334068, 24.832884457803544, 17.41515882553593, 25.109686120863884, 27.403266583719564, 23.5444466529354, 43.335365479992284, 51.61108409204791, 25.251803398132328, 35.966600833400605, 45.7972607304973, 38.32559270243491, 27.850761951938754, 15.457004750928572, 7.609975213004698, 1.9302019164446864, 3.7299019194418386, 2.4179669109082993, 0.8036744654659302, 0.19138051527402095, 0.18227787387947883, 0.30661691641134603, 0.11777678699863535, 0.15764883659299345, 0.5606992614846076, 0.7997494599511548, 0.9116905951692212, 1.2076657842243872, 1.201459859167376, 1.1151683282467628, 1.0725586404723506, 3.215899087728993, 1.7185764399267014, 1.209651729272258, 0.3969473547993168, 0.15274732944465455, 0.2170244658425931, 1.1447439799385688, 0.8359275638095794, 1.078497354061373, 2.0264338365485592, 1.5229403828420949, 0.47118151981023054, 0.38316236868981396, 0.3063621462112473, 0.2535949139705589, 0.15204010771647578, 0.11025878315370892, 0.14640666484352083, 0.11304743512864075, 0.10674876746751609, 0.17521373116441313, 0.09226892428893237, 0.24162952457704853, 0.2140534083328901, 0.22176892496645453, 0.38456979478078507, 0.6324887479985914, 0.6657245839315077, 0.12186472409314687, 0.9446495362827856, 0.30697749867554636, 2.8713713297920846, 11.7670448172477, 6.613405875621304, 5.393979722453702, 9.375855192061394, 11.621476834820164, 7.756847873810799, 4.752934998081577, 5.376707075103637, 4.129864044727818, 1.7783999394985939, 1.3761616137719925, 1.1803868028425402, 1.8233123037122914, 3.9410896839634066, 1.5893115439722616, 2.990858982647619, 1.5875579993571005, 10.288995715879626, 60.610950685316524, 46.04246377944947, 27.628496923754295, 65.76051673581524, 101.224089284097, 98.4111693597609, 47.24493303606587, 57.346424748820645, 89.82201022486534, 85.94916389834496, 3.76810678551274, 0.3620177597528504, 0.3049987242106469, 0.18060447738295604, 0.23920674087299457, 0.17464419075798604, 0.16797292857400833, 0.18883912583752988, 0.15369540921622707, 0.2450343870347546, 0.1488306130012197, 0.2899480689196818, 0.22415213256834016, 0.24045938655974405, 0.17339719880011775, 0.12226132781154687, 0.13626856368876275, 0.20312102721823802, 0.21615009905109484, 0.16375038983120074, 0.1686237202656846, 0.17595622358062576, 0.13775307354667496, 0.10084571527136911, 0.17981100947626177, 0.20558688038539505, 0.10654286601610723, 0.19471813053373369, 0.11792078854576235, 0.2006825233899778], [0.06243369902574247, 0.08412675796857766, 0.03418078240487845, 0.04186634500060351, 0.01843539453412016, 0.08767573688659938, 0.04686049899206527, 0.038145701100509015, 0.05094033087633791, 0.014900436940332575, 0.022068555023701444, 0.034068634793643034, 0.030665750758001403, 0.04205246223136783, 0.007133247676275431, 0.09091254263635605, 0.06986691992008878, 0.019383700301630363, 0.03146408332301484, 0.00732092533238052, 0.04025336602822908, 0.01788622823603932, 0.05439117393125931, 0.04023288849801306, 0.04308896770160045, 0.11195518527059786, 0.010940526544506992, 0.07162268619023024, 0.07360172878590322, 0.04818224197914524, 0.10760497031432968, 0.03523377025680196, 0.08949190918957034, 0.007487364158394837, 0.2798168319127252, 24.881774840816377, 80.4103300648351, 69.39310612217074, 38.199684619903564, 41.0164955354506, 81.24748937545284, 82.10977538939446, 39.60330478606686, 34.45836713237148, 61.883328345514116, 25.65806681110013, 0.14507287512383155, 0.5914500920522598, 0.48629214446390834, 0.6272094828947898, 0.3385597797891786, 0.2239366013917231, 0.05118418815395525, 0.07024694549580736, 0.2572700982132266, 0.2827726442727351, 1.4882079175403042, 7.1099794103253275, 9.01845274433013, 10.185997216932236, 11.219808478509227, 10.640174342739968, 24.366459731132757, 25.58696992935673, 18.20564781465838, 14.026372201981085, 12.387409825478832, 8.86639618104504, 3.4333604381930445, 3.142017078015112, 1.1861551384772024, 0.15815486831049766, 0.1965214248986975, 0.11898368957542604, 0.04617783421229932, 0.034399140445936116, 0.06791000194366902, 0.09670624344219124, 0.06108216670972686, 0.0463428801947063, 0.01863327121452218, 0.05622569020957716, 0.06648343131547013, 0.0446057528437626, 0.0899046313978972, 0.13450622438423096, 0.3249629142303621, 0.3690099668118262, 0.25072127220130735, 0.0014474630429063954, 0.057072309296458006, 0.22650402249588122, 0.2950468437085229, 0.09008560434824998, 0.5941217164358785, 0.24131262464629066, 0.18452324694202793, 0.0832719570626655, 0.10056240829609095, 0.042926116561096524, 0.014398051801347926, 0.05846732476305577, 0.11737179461746447, 0.0694139244695825, 0.05080053898235483, 0.028221970499162714, 0.05044263419544986, 0.06500092860791953, 0.021336623129525015, 0.039470699961267175, 0.0330975953669798, 0.3506433152623715, 0.42704045291869874, 0.7804319707136002, 0.9269435283157134, 0.47504937516585477, 0.9079625048945028, 1.509583364090612, 1.707437766655799, 0.924527041854397, 0.5334842024791626, 1.1764204285798536, 2.898588901565921, 2.0059079508627615, 0.5803049223557596, 0.6442802507550486, 0.3015501947412568, 0.28211782295857707, 0.1581733769947483, 2.0259551848134687, 2.771773280635957, 0.6015734843188717, 0.7106192974794296, 1.4564085271089309, 18.71470674391716, 39.71151513438071, 19.485234791232696, 18.188055984435543, 61.50231715171569, 83.29113052737328, 79.94774926093318, 23.29577034519565, 29.516180715253277, 67.63813572545206, 63.35424461672383, 3.6024253791378396, 0.04241895103346437, 0.17141778082136186, 0.10418464054143238, 0.12046063814552561, 0.10533804719847058, 0.039435490560267246, 0.04792975472106088, 0.029907739315662655, 0.026161209304606723, 0.1385151624919907, 0.026773531891165242, 0.06893911849587195, 0.04956572016160335, 0.020808587451615644, 0.09764096264036433, 0.03528668778017163, 0.06699867140982421, 0.04872626782725415, 0.02270695907364209, 0.01270845924849592, 0.12634787828691546, 0.05088190901123228, 0.02872833354969419, 0.027909226595394077, 0.022777247640694824, 0.061612966049823074, 0.06383419585143847, 0.008821948694305555, 0.03493843953155222, 0.035273212293583545, 0.012533595849339281, 0.05822676932439209, 0.07990542964469041, 0.05860607860790146, 0.040366421453654766, 0.08163177813853949, 0.002567073252360006, 0.048046399268411824, 0.04039507697246248, 0.010653408281805535, 0.02288354425540855, 0.05507688008008465, 0.008064478301563332, 0.04325076164076886, 0.040978870444720795, 0.028829949367190563, 0.022624150714686802, 0.02233699414758913, 0.032723054980799075, 0.03905011002995795, 0.03522625110382515, 0.013357939014601852, 0.03377480177028525, 0.030863610201425133, 0.03075551519530916, 0.08684748858814278, 0.019113780712829005, 0.041157024191512216, 0.058104298678376985, 0.022643486773895643, 0.02527406416653145, 0.01084205168750017, 0.061802201258439216, 0.2490410268787415, 1.1157371944958165, 53.243280380002915, 100.44965651727493, 73.41901117755522, 57.63556618844309, 74.43373618587371, 95.42448059205087, 65.63174924542828, 46.975336767012074, 62.071868834957, 69.42845452216365, 13.395401104804009, 0.3633929488639678, 1.120111495256424, 0.5123210235709145, 0.9041497772259097, 0.802006354976085, 0.8417631926075105, 0.09556962943245327, 0.4180182047909306, 0.308949715427814, 0.5801574044650601, 3.022877045216099, 5.07122504134332, 4.103992826515629, 2.0468090787049262, 7.3473328159701445, 16.511811479445427, 17.659487185939668, 9.84721229922387, 8.597470637290709, 9.363351656544594, 6.078348986564144, 3.5165798952502594, 1.7985435166666586, 0.998588377429593, 1.7826962831520268, 0.2785762597716624, 0.060124438060748006, 0.09745902441922696, 0.06595761920776098, 0.008019449089788983, 0.10870075949858274, 0.09800953520161491, 0.055952281090280706, 0.01815524192587022, 0.012994436997800105, 0.019832505251190836, 0.04172327808074413, 0.06798764495479484, 0.18036982465174892, 0.14081051513071985, 0.2987247092589256, 0.48884756863117224, 0.1382384362119821, 0.027338140606579762, 0.20745159968012766, 0.042625499829169244, 0.22634712768898857, 0.3636246444957872, 0.9104220148536467, 0.12737895602420454, 0.29184983622643257, 0.15220932121719086, 0.1659334186584719, 0.05959381109043475, 0.09149331389175308, 0.08788437327189792, 0.048604341103665294, 0.08943986883687396, 0.010691335379716851, 0.05037870032772903, 0.02976224772752293, 0.08155058814032425, 0.05128744531482939, 0.04145742258838108, 0.04231631057336927, 0.26026029259927813, 0.35353545039411516, 0.8971146385996573, 1.0186245184271567, 1.605485314803739, 3.7757272153131427, 4.657651801263133, 2.419083070370459, 1.3970004310531001, 0.7860565882536673, 1.8533531239917203, 6.763409078121186, 4.105925574418038, 0.9639830827232331, 0.5861906226604217, 0.47040749521505454, 0.06383832506535035, 0.3217717596600133, 0.9121856105423743, 0.5424205261853434, 0.4618953697143063, 1.0940736988859794, 0.7204173781698751, 13.070574921946372, 56.16058634173486, 49.14956931144961, 24.62986453886955, 32.40399241447449, 74.35389241864605, 95.905959375443, 49.10275582344302, 41.86789697216403, 63.95202167572514, 83.92083567957725, 18.922851239481282, 0.33857828847342925, 0.08601149514077172, 0.032766047835109696, 0.09197462395194078, 0.1345601416523418, 0.034054351084294825, 0.00825255863263362, 0.09292485643058054, 0.03791546869662501, 0.034010986677340926, 0.02544754286176495, 0.032417588912311106, 0.08131443387678555, 0.01707149755900666, 0.042883725085806464, 0.043585262441587065, 0.07830891773224839, 0.03530948655679822, 0.018713082254473722, 0.032143731631578944, 0.04276038876043693, 0.10486154817044736, 0.021230585069485733, 0.0995857994102182, 0.023538807985342802, 0.0551011574064051, 0.014770601316535426, 0.024481873711450927, 0.0408783252350986, 0.08283600706847445, 0.16322480754986887, 0.2929721243919865, 0.10457836376923708, 0.10861174008178134, 0.12634955601946962, 0.17753235755428193, 0.22036903718065834, 0.18978214942880217, 0.11826606437323556, 0.11977037760399042, 0.1931493816476676, 0.15290652251532003, 0.11506823717706627, 0.10465561607552153, 0.06800806119797692, 0.16924851093321078, 0.11992008650615332, 0.09789151169600026, 0.0980900357206983, 0.13956885514480455, 0.1671408958012058, 0.15188187991659488, 0.1381597283386415, 0.13670103564377756, 0.2019756338408878, 0.30058706900285137, 0.11844016551490753, 0.2601093732781949, 0.17430112126373476, 0.1942806177201771, 0.1576204453745196, 0.12233103415177715, 0.14035919741276773, 0.20211797297721912, 0.38306237889393685, 47.91313232914094, 125.27712222068541, 108.63957328181114, 79.23902403923773, 71.24397846960252, 114.76298932106265, 118.42103881220665, 70.48946349851548, 54.41834011385518, 98.53377480660716, 53.55366145410846, 0.35644214119642015, 4.436051614822881, 2.433133245475831, 2.893704324960709, 2.02425250843648, 1.452947035431862, 0.07672151460522607, 0.658755757875981, 0.3501571252221062, 1.084400030874437, 3.022975104470407, 10.900073532135258, 13.122341382888056, 13.206932198616768, 17.65228375311821, 19.306674772693267, 34.538512922102406, 37.22657988148351, 26.71914835130015, 23.133986303883216, 18.67816790457695, 13.36403096875837, 7.5015104009259135, 6.256212294101716, 2.9215568304061894, 0.33687147522164934, 0.39482179788812516, 0.19877853442824658, 0.16655793353434534, 0.19531420822585785, 0.28015672980296996, 0.24299136843652497, 0.12926978359539665, 0.2097111913345514, 0.10570573875860823, 0.19190416701378363, 0.14394776775471627, 0.12878072838629448, 0.3875812864111316, 0.36283073225809687, 0.6069813909069185, 0.9199292272810013, 0.5899652297939024, 0.14059855392382992, 0.1871323738727839, 0.3288915050366233, 0.5956302354893377, 0.8344392694773213, 1.6717846475301252, 0.5427592596219433, 0.6973560478898787, 0.6754273632841726, 0.415457142216544, 0.252927191735756, 0.21777045161974048, 0.15324093521602694, 0.19084794627081966, 0.19425483120064582, 0.08827271856247418, 0.14099083690633699, 0.08712111221205804, 0.14566236445980688, 0.1597668092337347, 0.2091220850425382, 0.14207005560878785, 0.47444067234473847, 1.0714369651771363, 2.2156682177897427, 1.664029508829117, 1.1276173183033544, 3.321497382656221, 5.596720172512916, 1.416835244144163, 1.5100363978455145, 0.887264280069259, 2.1553098049856003, 7.896225865810149, 4.391993591862341, 1.645126626376183, 1.4531496503660757, 0.738546327958184, 0.7555198332955761, 0.6721934916511659, 2.5458812857827833, 5.822170655573569, 4.588540619419468, 4.393005563366798, 1.704251208612996, 27.613625257245957, 64.82462744559011, 34.50147398056523, 32.51614670599661, 77.39674952722366, 104.24920159001505, 109.57253256151753, 42.03599014589864, 55.58646901961296, 83.88307894429853, 93.86794290234967, 14.282832453327796, 0.36782602389012614, 0.30870000140801557, 0.21008772354933525, 0.3554108029892368, 0.27660018193625635, 0.34101861559094926, 0.13128248043358326, 0.20360600683958302, 0.266022652748131, 0.3197926787599441, 0.13396964108030643, 0.1609402414291136, 0.21140039988583137, 0.1105677234309335, 0.1728046297906868, 0.16798982847361796, 0.19077265514962136, 0.18059390536960096, 0.10160939767956735, 0.10685132365793952, 0.14063566322288207, 0.3357894219938786, 0.22623805209032952, 0.16463273925887, 0.14674041870861285, 0.1990200819507722, 0.1700948389066804, 0.1794535528507925, 0.10613083328691222, 0.16385725909663787], [0.08184579246106648, 0.03080140577719337, 0.04841147080784844, 0.026624410961484237, 0.06165715783173519, 0.04576067252445125, 0.047982725870585254, 0.028191049275318944, 0.036265269342449405, 0.021296665898614356, 0.13132135173486126, 0.07469678252574898, 0.04749853915024189, 0.04113895983825769, 0.052488908667357705, 0.10716571082030574, 0.026807103779227025, 0.08147127505752348, 0.05014823043658849, 0.039433743879799886, 0.05281338903812632, 0.031451245604623715, 0.08685137265391889, 0.011860847120143235, 0.018674940651943608, 0.0324499637879912, 0.05565040797415761, 0.0339359560260369, 0.016988733250107017, 0.027327549441026586, 0.04942565630640715, 0.14380064822973745, 0.013390703637513423, 0.04284730143544655, 0.01786541554235643, 0.3801961068905169, 45.494453753194506, 80.63548195746638, 68.4888272131643, 45.69178427419355, 53.67469010814544, 86.57446030647525, 94.11712323465656, 53.94137990090155, 21.79525390748055, 51.84255100065663, 49.834983887210974, 9.37718193377218, 0.23925079092864068, 0.9485489238173732, 1.5681920320756975, 0.6553787197316847, 0.35647011872741485, 0.15092662956205108, 0.3214394920054944, 0.2160357987327922, 0.437381689947459, 1.9349683316484576, 1.3814913793917627, 3.0230005998765273, 3.1325283742720083, 5.229579460236335, 8.282841636288552, 5.223913596522424, 2.4786106761424773, 3.691766920589632, 4.575762517990605, 1.9831633519741798, 0.8329377371457316, 0.7067177036116201, 0.06527217735926952, 0.47606631092006163, 0.4098536993467039, 0.036163659270612464, 0.133931229431783, 0.028400855859921827, 0.06050824044993328, 0.075104272353553, 0.022144321119412783, 0.042441022026562886, 0.11164387012080801, 0.06733049473334705, 0.10354848112910987, 0.026712265924640724, 0.031127412578151114, 0.044099874343843236, 0.023235366304194736, 0.06389799565377255, 0.04770647073465009, 0.041680568678965496, 0.017166155382930752, 0.05030290741894034, 0.1127417583859736, 0.22601464552985084, 0.027529155054400047, 0.14769971400739687, 0.18945165909826758, 0.07094121267718655, 0.05692859503230261, 0.05218149673554206, 0.04922074693886023, 0.04271207159505256, 0.05600290034987754, 0.00949331176196856, 0.03703486977986271, 0.08497817276586449, 0.08110029698019067, 0.019569932445583325, 0.021198035908802863, 0.10652265661666471, 0.10998151295127408, 0.10094643285077426, 0.08181100440842491, 0.009109446170529532, 0.11358381158882573, 0.020056373379643888, 0.22260820493102076, 0.18988957027754477, 0.3839570470154286, 1.346801569865596, 0.8718166380159317, 0.2445310213032269, 0.605432728846227, 3.674197153699014, 0.6250034561080318, 0.1968498774353535, 0.6919969257808501, 0.6283347741250069, 0.8345549793974046, 0.3898842386420696, 2.5207548276070626, 0.7963083155693547, 12.906047182698405, 31.085891685178204, 31.18267813036519, 23.699221418749904, 37.80408613143429, 79.27274857797931, 92.95623502423688, 69.71091224301246, 27.691486266351518, 35.45851269075948, 64.82571786449802, 76.50517125283518, 12.419951769613451, 0.2841045647378891, 0.09779902956178112, 0.055663906443383426, 0.11757746624249606, 0.06640561210412173, 0.09751893249490569, 0.056249094195663936, 0.08894536674263016, 0.002295404349664046, 0.062465813431528315, 0.028576485347002748, 0.09125319129276661, 0.04068377337628796, 0.06930290300759577, 0.03743057334495168, 0.02233778704859076, 0.019024929835370952, 0.04814677593869068, 0.06499361246824265, 0.03704235828932255, 0.13007457428161176, 0.06019596002935883, 0.04033076772165876, 0.017694880539971976, 0.05021057084142681, 0.012491397811250101, 0.04325608978228223, 0.04024687726351042, 0.039712044470492876, 0.026156999651462804, 0.042032589910612, 0.07211159584262679, 0.030919419706708966, 0.0535363806862264, 0.061753857279977495, 0.07950214563959068, 0.018562015461465044, 0.0051609959712462326, 0.05300686071296373, 0.03204205261182881, 0.06898092391389994, 0.11750890903415219, 0.10782995501593237, 0.06293578922087628, 0.026971916104817105, 0.02180371076739844, 0.07908132588190418, 0.03511795691484886, 0.036316700655245976, 0.03823497715676504, 0.023371986594171296, 0.06603572953252063, 0.052482304989450404, 0.056482176446626266, 0.01950264119753434, 0.05027668422929222, 0.029090501615897785, 0.04771009050009232, 0.04996925314527847, 0.03402535082592118, 0.025216992531392365, 0.1062419007141744, 0.05075508698580727, 0.029894024426598224, 0.05039187704002665, 0.069519322846205, 4.695738505932593, 81.05015493208363, 101.84015243284165, 75.94475084735502, 65.4020199468059, 79.8801197544221, 100.63919328874158, 76.53473023445376, 50.57078130783574, 56.0466532553396, 76.70855399101012, 28.15611650866847, 3.371750299007662, 0.27417753612802875, 0.37077157067195066, 1.069220458307574, 0.6074288475417322, 0.798812258628107, 0.37646746503249295, 0.6873068129343372, 0.7132424438191999, 0.9221109844023182, 0.8452653788751172, 2.352606740690047, 2.5360871274625105, 1.5119715972292809, 6.126886846557741, 11.063951138527164, 4.991141519238872, 8.094505600390896, 5.448524202069929, 6.371609405163796, 2.142759201026732, 1.019137368327187, 1.384182615626243, 0.08282569552501363, 0.4954623394916135, 1.5881972231211203, 0.4550716100681213, 0.05034330323518765, 0.08268770776809224, 0.08516822385811999, 0.03832864672726682, 0.021978662266666373, 0.1288640634306977, 0.055460483286409616, 0.07818995193848688, 0.07009896795235335, 0.04239622886563021, 0.03034668854407726, 0.05653438150822636, 0.058402651620488015, 0.09370677173137666, 0.05848147057657761, 0.03204939364936323, 0.28741001962654056, 0.125498462979111, 0.013159171756987852, 0.20425603244333498, 0.3149135873442696, 0.15533681388103193, 0.22013262244722537, 0.054018288294995026, 0.05847818405938245, 0.060647691434790055, 0.1119563727068805, 0.04636032401674217, 0.03526919416242069, 0.08186900492517218, 0.06900708581651412, 0.051354619734469927, 0.04704904089110994, 0.05991381367728595, 0.043029741444174326, 0.06757625573945623, 0.1733785062547653, 0.27699061098598665, 0.15766867827023232, 0.33666037203323457, 0.10696197739772259, 0.2775315609910796, 0.34391736972235865, 0.4797045544030205, 1.0238649275514389, 1.1264132732345213, 0.2273571992953939, 0.3605420905495844, 1.7232227325439455, 5.9830697121158725, 0.417735640920939, 0.2912058933607994, 0.2868024506155522, 0.3554773300645813, 0.4156702372335619, 0.18767232796357525, 1.3291130287031974, 0.4586364010409002, 8.38391915444405, 37.692255435451386, 56.68842754056377, 45.747152451545965, 27.991561312829297, 45.698730791768725, 82.59225045481037, 88.2267822757844, 55.46515011018323, 40.77548157784247, 63.103573783751465, 89.89992418596822, 32.419277891036, 1.1552940525354878, 0.0925712149229742, 0.03600685639427074, 0.0421988922772148, 0.05381709062344125, 0.041663117196050384, 0.015496996310239118, 0.18463762386912302, 0.15938952625278505, 0.05512486399722196, 0.03731422374145158, 0.07971037599828937, 0.04438371375022877, 0.07752285789578192, 0.023374909219602426, 0.07442466809504455, 0.03984809402496584, 0.04451498674649385, 0.0878627849141917, 0.04539531753248265, 0.05195116090978827, 0.07981556753117232, 0.028469399661727013, 0.06686445280549026, 0.061046007359700824, 0.04410183935936901, 0.044824359863395655, 0.023084594455036907, 0.030047178809200565, 0.025005469909839095, 0.028659207521066554, 0.2340710559679616, 0.10404848373465, 0.12634522762269745, 0.11776174103180248, 0.27366306212159897, 0.07919722732396857, 0.08486579532825178, 0.1394587836318439, 0.11145114538169677, 0.17930517694161785, 0.26243944502165245, 0.20302001086454238, 0.1652575299263962, 0.13330758789614325, 0.18871030049218288, 0.19765197149207517, 0.1158825656579387, 0.16059743240475655, 0.12746844275463975, 0.12523957122597965, 0.1511672271355506, 0.1887917203167754, 0.21589848513324417, 0.09597795429609476, 0.12131085018477133, 0.1450728138367976, 0.20277654812220605, 0.13219772567672114, 0.12556656053470028, 0.15722964860258565, 0.21302441435475505, 0.21097666133315335, 0.09810379465981837, 0.1881890695902609, 0.18467664838798586, 1.4066233534005381, 81.47149593599381, 125.59466946509578, 107.11704254150392, 87.35649462669127, 85.30377711019209, 120.56947785039102, 122.32426781808178, 87.24370295001616, 40.482609964186146, 74.75159721989786, 79.66353431824716, 17.10895703684899, 0.2555664565654532, 3.772492485661661, 3.0357983131562514, 2.3323543177497004, 1.917386307351051, 0.4719852379733517, 0.722013415107804, 0.9878268645655726, 1.111838726266738, 1.6353776978869594, 1.497605303602834, 4.946603986524767, 5.848653028088232, 6.734766950530391, 13.546714378941445, 8.928092122077942, 10.952444038083478, 7.092642534163691, 8.427465308097101, 4.196827238605869, 0.9806429210209078, 1.1563528473338773, 0.3388520882975671, 1.0270764294170565, 2.0838076933737724, 0.5001312776678993, 0.16971881230992658, 0.15188281454386252, 0.09505478770381982, 0.17529332769974587, 0.08200877000607791, 0.259393755226366, 0.1449633858376934, 0.2900411026372064, 0.16339881676098994, 0.07923478861489604, 0.12693503105472173, 0.12936791945849696, 0.12500936180473338, 0.19649594481433594, 0.24332630207702038, 0.16277935806541674, 0.5116557834609863, 0.27181369522886895, 0.17996350693846905, 0.3837945138014132, 0.5389239783248594, 0.5873687433138971, 0.6251240077037966, 0.39483555682724525, 0.14703600607331724, 0.2025170281769768, 0.12253370271214556, 0.16686977728480296, 0.06476511142306751, 0.17008311776143892, 0.1578164719525845, 0.24391534708199963, 0.2826660354771922, 0.20040329966333606, 0.15129471948790937, 0.3486617828809446, 0.5630460645883315, 0.25504210002480016, 0.2657999969538181, 0.37836665828381816, 0.18810236375899086, 0.22077897082894082, 0.44172148610795703, 0.31873808212337956, 0.6216705446281742, 2.8326121837862077, 1.2859761498628126, 0.729057501641012, 2.0282543066047856, 9.765475988388062, 0.49537184918599747, 0.5106577854002676, 1.3403625089314677, 1.8368584542505204, 1.3085854269804493, 3.8229964337041302, 8.502305111577435, 0.9707439005855591, 18.41594765263219, 47.334410144436745, 48.35032363091746, 36.254953876618416, 51.50863178314702, 96.15135069816344, 110.71689190403109, 89.67494487762453, 47.57037993400328, 58.58428947387203, 78.83963261881183, 103.87711771072881, 26.88036168775251, 0.8679391299524616, 0.2573093832019837, 0.23678164358340928, 0.47032463514516437, 0.12550788586057965, 0.19390837559776922, 0.2062183053743455, 0.4687985573564807, 0.25046054183715777, 0.16756383762244256, 0.10784070322951002, 0.22382823059395437, 0.1036969796123524, 0.17394315902023547, 0.13387642350168, 0.15133985738840797, 0.1450728291585561, 0.14318714969821517, 0.1676576067843745, 0.12106247681884036, 0.19481462696867605, 0.14874249756816896, 0.16342138571123924, 0.18882510642851555, 0.15620839211248583, 0.13975438631830678, 0.22568190290081888, 0.08963984842862814, 0.16865773456952265, 0.13269791980424236, 0.13174596362777297], [0.015940182004874993, 0.045903632192001234, 0.06770390897027909, 0.021559047182240797, 0.047792356851841175, 0.05876869226114885, 0.007912157518383598, 0.061231170810999415, 0.02362804765242242, 0.04509609508057756, 0.0236010545444104, 0.042174542172541546, 0.08308593559289172, 0.0971264656512968, 0.055487587477170655, 0.006570123735019156, 0.05728728888976959, 0.019760521714605635, 0.05100801474444809, 0.028828200771503394, 0.07922823856314344, 0.07329435132804417, 0.0035405258559847194, 0.031796508025558244, 0.07439989281157333, 0.06154411772806799, 0.016310394951893438, 0.06068025783245122, 0.04736364638853458, 0.052487027921503594, 0.03260229654129475, 0.020980955319358938, 0.04100646110131376, 0.0762157816620123, 0.027390343752960046, 0.12169907290127971, 1.2011167743513662, 48.39295979469053, 85.74269033247425, 71.31919384002686, 50.910180076476074, 65.75613152596259, 87.37350986849877, 102.24076763276132, 85.27919953869235, 23.38127213139688, 24.470231917596635, 47.050155978049006, 37.083515351818455, 8.576310430803607, 0.6841432988162964, 0.3860068837961843, 0.20615203876889523, 0.9194385632872583, 0.9668701310311595, 0.1324535377563969, 0.13544457483916514, 0.3056051900550243, 0.38563370704650884, 0.6915127582127049, 0.9191518012554416, 2.2932397069469577, 2.1278105580037643, 3.010760598605679, 2.1128594634994387, 2.457463952802843, 1.4166212298216359, 0.23962879403223916, 0.20818350476122674, 0.17495071785824914, 0.3086642710672271, 0.5215012390286692, 0.7063223409556574, 0.1159964293061245, 0.0657002060043235, 0.07127885060805468, 0.04053839287089725, 0.07567523768351925, 0.041045596702925624, 0.0654476038330505, 0.017390923664694833, 0.1018101433592458, 0.01108746795404342, 0.05397702296895366, 0.02016281746628304, 0.04014490329990945, 0.03670551708989567, 0.014650502670255881, 0.025886155011492874, 0.012998449383303525, 0.22528958927479484, 0.14671846262870297, 0.03836504356454938, 0.06237803507716425, 0.09901017626567234, 0.023116601608513344, 0.03133176844717274, 0.028633972584840753, 0.0715208807659726, 0.024212383131887165, 0.004720272291677013, 0.05022750138455341, 0.015659761265851557, 0.03845306323660958, 0.06334502955958729, 0.03926266112454957, 0.059328361624671574, 0.024540801194586584, 0.05382526478159332, 0.08054365749440848, 0.04192138075708382, 0.10153089664996633, 0.18208483504431863, 0.03153175761502597, 0.28911557649412467, 0.1994197959861448, 0.09169242780415282, 0.2144779282952509, 0.2353639365924943, 0.424738297419202, 0.4404287280574922, 0.25946570620421444, 0.02735637732961726, 1.6755229114524781, 2.1780308696531483, 0.14891267633966862, 0.19824346797841214, 0.09348344177969041, 0.19265836525347926, 1.8997178683357856, 10.347900890534925, 25.73288994450723, 31.401309082584998, 29.970463745055664, 36.525279706524266, 52.889584572084495, 78.23192411853422, 87.29240309807562, 49.75371237724058, 27.456553943695564, 41.296658669748616, 65.90498939637216, 78.80960295277258, 19.255807515113585, 0.013737080716377786, 0.11000735309696007, 0.05623643842315482, 0.044997641290988655, 0.023878719282126235, 0.007398773272026091, 0.07208217040545518, 0.16444713147657533, 0.06789515515969646, 0.03205085879251842, 0.018371236585681478, 0.04904745018950874, 0.030273161340324633, 0.10470931117813434, 0.03955585063405095, 0.013572433099691427, 0.04520469187428394, 0.049840990874555804, 0.031072654528543357, 0.02689290945718606, 0.07012280094767771, 0.024457504454579566, 0.10029089141396746, 0.03373428337997006, 0.05676539149135352, 0.059454367766457225, 0.0281182709225123, 0.012893459906110601, 0.06471078046747754, 0.07388205567915594, 0.03435380719301682, 0.05037055681309393, 0.012306391407975988, 0.018482122067061645, 0.030802847937710827, 0.07636696911386906, 0.0029063640179247748, 0.05078251293349651, 0.08850121194677008, 0.1030393620772708, 0.02271104615271813, 0.016644483980452342, 0.040026646137477896, 0.10998930406546402, 0.1360723992148715, 0.049932143846226316, 0.07786058009632173, 0.012422257418473883, 0.039851338407325174, 0.061537226767189084, 0.05492287725510617, 0.030384006602088773, 0.08086725303362455, 0.012470648319820964, 0.02994509759329019, 0.02205579199888293, 0.0582504491021316, 0.021092003594423016, 0.06122789195468349, 0.047870164571870724, 0.07392750001482426, 0.04130601297102628, 0.04650475457310677, 0.09019348484974715, 0.07195706058654093, 0.08146230416793017, 0.05239511652278805, 0.086304523771809, 11.581092111525997, 86.58152057278542, 99.2407428064654, 78.23419909323417, 76.72204694440289, 86.87282716074299, 107.20986935400195, 91.35478619606265, 48.50688111397528, 44.70925408024942, 61.114135865242254, 55.93927444950227, 22.013357300912183, 3.319080222037531, 0.26132821916572513, 0.793252298908849, 0.11489995064273958, 0.016910205407428647, 0.8530873204431227, 0.37485132594743087, 0.5979762418616204, 0.851430302906421, 0.615299512301722, 0.3137049151043738, 1.4332555114261567, 1.971145700062475, 4.772641476123564, 4.155102535601586, 3.985382313689878, 2.792527521810224, 1.745107229198179, 0.5138349052398435, 1.7282807514552148, 0.4732282922392892, 0.6437992088256345, 0.5123552830228882, 0.4373240494920362, 0.08308653314147266, 0.025488555378791307, 0.10595134654713255, 0.04775971384538759, 0.004907338992662488, 0.0578866875730455, 0.047042644056942196, 0.04675962053419602, 0.05287270339566374, 0.04237279040558685, 0.036675628169529864, 0.0376852018187844, 0.006742745848192323, 0.03519148986426092, 0.07343887381495968, 0.04652988991790241, 0.013828706747341542, 0.20905388789551876, 0.01891068888888244, 0.06401074464402853, 0.03179035825474608, 0.07503603690213735, 0.01918440444334861, 0.01847109423139163, 0.04259578327858641, 0.11237410513023216, 0.02476340336274476, 0.032946859906998374, 0.06689791552602284, 0.020294387321618777, 0.011302761643403962, 0.035872982529502724, 0.04955102276477603, 0.020547765156915112, 0.014607279031958072, 0.02911476745089937, 0.11518396241890809, 0.022982970976661292, 0.35503014922142034, 0.2155800070613623, 0.07707577664405107, 0.4652629390118584, 0.45292208992665817, 0.677348650511234, 1.221839513990187, 0.7582323974178684, 0.3732789458046037, 0.9992548126366831, 0.3649335210361789, 0.17657975786395613, 3.805311937485972, 2.830480375597554, 0.2721321120137169, 0.18964992265307135, 0.32553269978492494, 0.2207960239461353, 1.1172802794364192, 9.208295460670225, 33.163000460593935, 52.573225805836344, 48.95427842294016, 39.63900619937528, 34.57861523474417, 54.12759442483225, 92.21455404835363, 81.77198087015461, 50.43846015007266, 39.80871931199105, 67.25163321341238, 87.75633319731682, 44.838237300995864, 1.079262951689382, 0.10019460948364389, 0.019074704483031266, 0.08744273890530871, 0.04148980512494042, 0.025355016677490166, 0.02444472993844219, 0.10301707657955347, 0.05215139331055745, 0.05578332805945989, 0.012677632828032779, 0.021124280793892763, 0.06227432209397517, 0.038662009887517466, 0.021937862339039004, 0.04201785037894884, 0.07442197912643034, 0.022442492115641796, 0.03631882271879623, 0.03953089531991751, 0.010084461593519776, 0.013817644437714932, 0.030308690583032948, 0.05433880033031587, 0.09213471334547767, 0.06822886305951303, 0.031053722580714576, 0.04899811412718508, 0.016154306452541102, 0.03175295209662328, 0.03215793107125548, 0.02136037760083714, 0.26809816879610865, 0.0956303419004525, 0.11651648043264305, 0.11339774415377649, 0.15989396450740678, 0.1966207711807182, 0.13254503929807296, 0.25354087412838017, 0.10721795035586243, 0.15953264679879914, 0.11049896703972933, 0.2644542256189931, 0.2809952590013704, 0.19313772178946004, 0.12191536250494181, 0.1393482831096457, 0.11367725899382947, 0.17617777620832767, 0.1181827599723493, 0.12614308766299678, 0.2702840627922166, 0.11415752717444014, 0.14274890144025126, 0.13436618351167248, 0.1554992245209794, 0.11323915629257118, 0.08720660762440774, 0.256399822331244, 0.12259063836667808, 0.12859472223827917, 0.14460471879330375, 0.15972018512266298, 0.14212774202948616, 0.15439162992181318, 0.12976355790611238, 0.22978673989494003, 4.219367138801083, 87.2413730621338, 126.71115644516485, 108.89444889560824, 90.84872199643044, 98.70358990084742, 116.37889600569203, 124.51961840352706, 110.29510374992125, 42.62493402727189, 40.42933241013558, 69.79558052555208, 64.35723389348676, 15.50588728920106, 0.3793976900558318, 1.5408224684576837, 1.594001105235469, 1.7273494336874256, 1.7408738886156392, 0.3856320216530754, 0.7743836146208548, 0.7426029167348339, 1.6317746331614833, 0.8462378815297158, 2.34392604520244, 2.7769194303020357, 6.052745715264352, 5.3139368949397925, 4.592150670866813, 2.6518828493933526, 1.6479794152321356, 0.7736795491749241, 1.5431450018959663, 0.7468561143163712, 1.5504596093969962, 0.7410103731578397, 0.7703144620022466, 0.3870335029017541, 0.12169861324852514, 0.26339353092255136, 0.1223116597881721, 0.16622243298878595, 0.1088658897506614, 0.2720384654258528, 0.1259638613931114, 0.131365800156228, 0.13648466177044377, 0.13386332339817478, 0.13713084161281586, 0.08691970003588546, 0.17118545699744456, 0.17216991062366194, 0.12652027871339552, 0.17441261770023456, 0.2470890808129503, 0.4054288061395769, 0.16076129861176014, 0.20126249791393358, 0.2582499246683813, 0.08363076966376075, 0.12573510753892123, 0.11406941174138939, 0.18444414070296675, 0.10882940098282792, 0.13053467136717614, 0.25323396398415493, 0.15756928602293616, 0.11034017233478446, 0.0860854992342572, 0.16206640599956437, 0.17339647867746893, 0.0624819012779382, 0.08688426080850825, 0.21164632943128386, 0.1428281915404143, 1.1033121063824625, 0.6360610466330283, 0.1973110930092873, 0.5878494175211076, 0.618740656683522, 0.37089595270733683, 0.8915126972621488, 1.7336042657975228, 3.0249061363358654, 4.419879682602422, 0.7639124184366196, 0.20767984791628777, 5.217943749120159, 4.1995013144708455, 2.883573333101888, 1.530750925021787, 1.365418119295951, 0.556572070044856, 2.8747178469934775, 18.70982535423771, 42.75367406106765, 50.66331002020067, 45.105856695482814, 47.76079139401836, 65.74932621371362, 92.0520894758163, 106.79583964809295, 70.6184624087426, 48.95147000589679, 61.98767123683807, 80.2163061018913, 107.24124047064014, 34.94970283200664, 0.5533719062805176, 0.25119138971692134, 0.20985369901022605, 0.17951811874105086, 0.1267094641262966, 0.12365796738454413, 0.14237785441500528, 0.36733575826210363, 0.14843256903752206, 0.24185429477403242, 0.10713294523978427, 0.2056319723206182, 0.15235760519581457, 0.15156527109924825, 0.07925082283515124, 0.10682454122410667, 0.12493333523912777, 0.12364020180558005, 0.13677860970699018, 0.1401357295652551, 0.21746432288519799, 0.18807662320473503, 0.1503104344010353, 0.09738675168445034, 0.17512052890754518, 0.1357787270699778, 0.166607805858216, 0.19445732356079165, 0.12359282692834256, 0.16029421480432635, 0.09265409031462285, 0.14899015847233035], [0.06739248656817982, 0.08846911286274273, 0.05187468235230735, 0.0070261504996808315, 0.0432091209316446, 0.06077696494157277, 0.05820223918905663, 0.1161455483205857, 0.05762131471607474, 0.05167566803133777, 0.004069415003722233, 0.04234461369173181, 0.049198878959061644, 0.006606304631268065, 0.02896858446840798, 0.00976668544969852, 0.11885252000103075, 0.05021741200659064, 0.0461672890120216, 0.12437870290370719, 0.06773226954523595, 0.049578111633778586, 0.07840376707815355, 0.05151078292739488, 0.03735082359203408, 0.05221721175457201, 0.06281918297792155, 0.0447713733921128, 0.007010993450098942, 0.018454456716896068, 0.03996065915412, 0.03251592778871137, 0.06707606927281426, 0.05739560223094398, 0.0316881851082848, 0.03387186511029159, 0.36291451163349614, 2.5955693808294114, 66.83816048406786, 80.64191464454898, 73.43814449925577, 56.87670130883494, 50.59442927760463, 92.82527492892359, 105.56916544514318, 116.42783149596184, 44.989950656890876, 15.565079777471482, 20.2911033938008, 37.989845660425004, 26.893670289747178, 10.440661022740027, 2.687414865339956, 0.5957806338706325, 1.7023955597992868, 1.5018976023120265, 0.347630720465414, 0.19421795172797096, 0.4786294572536023, 0.34134205791258043, 0.35426586926464115, 0.35978332642586003, 1.5894020036343606, 2.0063976342639616, 1.3417024886415851, 2.616984296229578, 0.9662415712110459, 0.534483487567594, 1.1836252097160587, 1.0499337964480924, 0.03591191128737504, 0.09424877893780509, 0.05630821703122028, 0.03871736357048635, 0.0694731277443709, 0.08526660486935608, 0.04541480680927635, 0.03425259165646088, 0.043895792351254535, 0.021242357925662113, 0.0719481586448608, 0.052393756716722445, 0.1144847539704173, 0.03656353801488876, 0.03208837028773081, 0.10142149163349982, 0.02134590428472767, 0.06189702762170665, 0.05681396912663214, 0.08307825173101119, 0.27244721929873195, 0.13992338531440304, 0.051362790062182376, 0.10486718657757006, 0.043615461627562205, 0.08610246042090078, 0.038294835436728694, 0.03647762125418071, 0.14572763515095558, 0.07001234639075495, 0.052328987813164154, 0.04179732430906546, 0.008405148983001709, 0.02711510751396418, 0.0750738969673553, 0.010709372919894034, 0.018277082464567596, 0.0505417927859291, 0.05408583426727884, 0.05156402603813237, 0.026025098463099812, 0.03038473438561684, 0.0355686885755389, 0.026598021147712588, 0.01848161836425143, 0.12129605702695348, 0.15794044030049156, 0.4621914780187992, 0.23131244996142006, 1.0758713272310074, 0.2853922053210197, 0.18562014695377121, 0.14947141490636334, 1.3898769165239027, 8.265210582363991, 2.0471190685226075, 2.14745918108571, 6.7414354701196, 14.387302821682347, 20.930306565377023, 23.91851132915866, 22.37797494857542, 30.644311251178866, 45.09370911505915, 67.11300096204205, 94.0830692168205, 91.58047153103738, 39.22213669746153, 30.297234442926225, 54.11090081737888, 73.73366371277841, 84.20835325794836, 21.686015898181548, 0.36080256044383974, 0.08874924823401437, 0.0934940520974417, 0.07385561798488902, 0.08634239915878543, 0.03245558687335542, 0.024361781768440723, 0.13773336976526246, 0.06600047416624523, 0.04545659307510622, 0.10172915254389087, 0.04726045051469438, 0.055295510082355434, 0.06372101019106566, 0.05362969402584338, 0.06661116115508542, 0.04788670441015594, 0.02742613538078243, 0.06729268063340457, 0.0220748292838013, 0.0361303765807421, 0.031194629132627483, 0.021974900774958155, 0.005363536690692268, 0.048793871256132285, 0.04085703182124323, 0.043387427896020875, 0.0348798223140259, 0.07546338372893872, 0.061866196413193984, 0.056380183330827185, 0.033681354365281524, 0.0531152583238098, 0.02967858518053207, 0.027050283069031376, 0.032886201065153844, 0.04191871477110733, 0.033721076024155465, 0.022924796174911242, 0.02260641769445952, 0.022754749553578518, 0.05784228894739382, 0.027011656915889155, 0.05952644131837353, 0.026715297717601064, 0.040786115062092586, 0.018612510231774182, 0.042043590933204665, 0.013802374390164211, 0.05981886857039025, 0.026949211173961242, 0.03265447095937787, 0.034958399952419346, 0.08029462529286262, 0.042407413749324704, 0.03551104428967641, 0.05398320146806298, 0.01888207167447094, 0.08327306022927647, 0.0935410515915963, 0.04524975316599012, 0.03753414460187478, 0.022085772849799647, 0.021533201290895383, 0.06512941687457985, 0.0469906879739175, 0.02500061865805859, 0.010522230088921085, 0.08943197813125388, 0.3188038431107998, 15.527895708237926, 98.80949389549994, 102.61421649686753, 85.41427812268658, 82.21615791320801, 80.41504475378221, 108.29980973274478, 103.14603497905117, 58.6816740805103, 37.0845861588755, 45.43299413496449, 58.77721517316757, 45.87040901184083, 23.851876143486272, 6.772451612257189, 0.7353088403901746, 0.5545755836271471, 0.5406890449024017, 0.3866584875410603, 0.26333601304119636, 0.7518048584461213, 1.1757028799864555, 0.24266810997599558, 0.07420630239310765, 0.45455784086258183, 1.7254251433957009, 3.43619508608695, 5.050150146407466, 6.075607249813696, 1.7659592844786185, 0.19494527560328284, 0.2686500585367603, 0.32084485455866785, 0.15173794731738108, 0.09613639660059445, 0.04366325019227882, 0.06262293806479824, 0.054487942327414794, 0.07134684857221381, 0.06498458795249462, 0.033351300704863765, 0.017788791428169897, 0.06018313571750637, 0.04803438317931948, 0.048418338786089615, 0.02872100974913807, 0.05273792171670545, 0.029821613795995235, 0.029473959265517134, 0.028027171576996485, 0.06354608167443546, 0.049349461201458215, 0.06778643196148258, 0.32186914475694783, 0.12933453334675682, 0.010211622612851282, 0.02862951395312144, 0.0031783132609205264, 0.0625640335643003, 0.09617535983242335, 0.04853587965631197, 0.07674530163527497, 0.017173492590025548, 0.014605829210561371, 0.05777974552925556, 0.03771655396708558, 0.04223673702067426, 0.026610475822141575, 0.06841149075978226, 0.020752772200672377, 0.08877102811370166, 0.02960637756322901, 0.09125974134451921, 0.11478808648403614, 0.0888531297565468, 0.07623922395249529, 0.07856699743218, 0.03445709882784755, 0.3764884251981013, 0.5944465377157735, 0.48695199131484956, 0.1906886919131202, 1.8554107748693036, 0.975177527195023, 0.12116107233469525, 0.017585703434662956, 2.5638398576167325, 10.111957576967056, 2.0967865711258304, 0.9095438329442855, 5.827076560066593, 14.982739206283325, 33.30142482634514, 41.24154544645741, 41.61853228845904, 39.47644748995381, 41.45627952391102, 48.34685625568513, 68.61195825761365, 93.35583040791174, 72.10089868114841, 41.18739712622858, 49.37732565787531, 72.08505230565225, 89.18795124177011, 46.99403862799368, 1.9389155843565542, 0.20878874486492527, 0.03950628474535, 0.11048885467912882, 0.007938403690669445, 0.1308547735454575, 0.04641899102998357, 0.10110630007881312, 0.057983877317559336, 0.06192178375297978, 0.09388576051400555, 0.05190040375436506, 0.024529246673468622, 0.025834541752814286, 0.02164835005157417, 0.0965863430211621, 0.035024137957201856, 0.03274816351251737, 0.07135939709241353, 0.04336878131594389, 0.06423369538219226, 0.02974332152535358, 0.11425813750153589, 0.04364923844414373, 0.01691114961079532, 0.042537552935461846, 0.03419247290660297, 0.024954588265128197, 0.030026990477175965, 0.02574108094127188, 0.03490891450295045, 0.06661518311668789, 0.06708472606635864, 0.15986545071486505, 0.2358587374610286, 0.1733696656001191, 0.09752200450748207, 0.17973404828338854, 0.21847470092677304, 0.16393955226146406, 0.29102013236091984, 0.13363518241432407, 0.23486988649012583, 0.17585424195614555, 0.15776624722826868, 0.0922340672883776, 0.1325304989492701, 0.10912576975721507, 0.11487142918931861, 0.19917636388732543, 0.14487816621699642, 0.09188722864153887, 0.15601149219418728, 0.17026288795375055, 0.17141914445786707, 0.11737044630271774, 0.15075205344586604, 0.06020704149118355, 0.15293546531709934, 0.2416157349944115, 0.16472042568268316, 0.09826850356353868, 0.14382143985600243, 0.1275687160030488, 0.1489141778720002, 0.12838147400367644, 0.1810328277849382, 0.19864569478217634, 0.34134631736143944, 0.5418798519719032, 6.468337995390739, 111.3095541923277, 125.55877977801909, 111.47808274915143, 95.97957441883703, 76.85873370016776, 124.69650160881781, 133.85703240671467, 134.61073936954622, 69.71207326458347, 32.07811993937339, 40.714249457082445, 63.03068045646914, 52.48760438734486, 16.543115915790683, 2.393604334323637, 1.1858643927881796, 2.337747576736635, 3.201655245596363, 0.7521356858553425, 1.1526432657434096, 1.9739101130154826, 0.9365725793665456, 0.9350225689911074, 0.6957457310730412, 3.648409531001122, 4.8514972963640774, 6.0957275379088625, 7.205524915649045, 2.6544725942996243, 1.197334016042371, 1.6586084255287725, 2.432653735722265, 0.2618043274889069, 0.18384256249954625, 0.10059752576653996, 0.16509934809179078, 0.1805753353983164, 0.19496646559526845, 0.1964356077294196, 0.12187125882314098, 0.1430196215909335, 0.12424409359453187, 0.36135175355499793, 0.1456636208440027, 0.16102386758692805, 0.1325576644270651, 0.12449661915701245, 0.20216211496341616, 0.14327097503888991, 0.2041842653265884, 0.27851295026559986, 0.3417417413044361, 0.46252074260865494, 0.28471357399417513, 0.1342356421293751, 0.1798100135619602, 0.12260449689722831, 0.20974967959186724, 0.2853219703801217, 0.1265992164131134, 0.2203958962232836, 0.1567157721447368, 0.2704687819125191, 0.17547882822973115, 0.15306953070384843, 0.15331343777718084, 0.18903312994347465, 0.18227670942583393, 0.0845207569880351, 0.19629737482436244, 0.09035306096437479, 0.2734678629184923, 0.16929038529915197, 0.1376116383940943, 0.25523463324193035, 0.1923763989320686, 0.29243981585867945, 0.6160839250491512, 1.8148165724931227, 2.146989477257575, 1.457932000198672, 3.3325324808397605, 2.70176975957809, 0.2023808330657982, 0.23159671454660355, 2.881312086697548, 10.47979647113431, 2.4390533278065347, 4.1744368787734745, 12.040264375748174, 26.473737416728852, 39.47352532417544, 36.472060988026286, 36.85659054786929, 45.26457148213541, 60.91309085969002, 81.8297887617542, 106.72066350137035, 108.29436548294561, 59.48210039446431, 49.593232524010446, 72.52206710077101, 89.79823281688076, 111.42382852492794, 36.37892430828464, 0.7846615115000356, 0.18949819127878836, 0.17739637694772215, 0.10742766692513421, 0.19929238024257845, 0.22041576854403944, 0.1116676188464607, 0.2763564740457843, 0.1873413626585276, 0.2044871918136074, 0.1702430309547532, 0.16307123756456762, 0.18438530515038198, 0.18456444715059575, 0.14101502996298576, 0.29339062290326245, 0.10958228155129379, 0.1154542152559565, 0.17823466099798682, 0.1617425040251786, 0.12349628452812472, 0.11713904178430957, 0.15575695182046584, 0.17263317931323283, 0.22150514557236628, 0.13652888036543323, 0.19797372842027297, 0.12110982105256089, 0.16576245847728946, 0.12653255910282174, 0.15378873404716292, 0.18203893105589575, 0.17436980870702576], [0.06550990976393223, 0.006454973059120558, 0.060744138074017344, 0.05473510144398578, 0.022203382667935184, 0.08079447468081791, 0.044304956081173116, 0.04592184976284062, 0.022140310649129174, 0.05208246838000994, 0.06953050772989951, 0.027629596842152458, 0.062340266942497224, 0.021646478881819115, 0.04493564562571626, 0.012277411259410363, 0.03698709653690457, 0.038087646957607045, 0.03254897682176482, 0.014292383378732109, 0.02152007820475246, 0.08107447215626318, 0.020816344091848984, 0.03528289947538607, 0.010928206893074657, 0.08918709812625762, 0.045608921997970155, 0.06630328574007557, 0.028608963644552617, 0.06078337326705937, 0.015970052730652596, 0.03953488663800302, 0.03888623999251474, 0.09745834260097436, 0.07305029869800614, 0.06486213645867764, 0.0049945039978821675, 0.06181106106528352, 1.2473943685331654, 37.43807015880462, 94.9600641189083, 84.45119504005679, 62.83788027301912, 56.906123007497484, 69.03944953795403, 101.61870325765302, 114.34544517147927, 86.35030469586773, 34.569142710778024, 14.74170465623179, 22.02356330810055, 34.3893922528913, 27.237605279491795, 11.661164356816201, 6.329939125045654, 2.1316988525852083, 0.9369929471323568, 0.9914922582045679, 0.37207542167555907, 0.23063467665305062, 0.37771165310855837, 0.25671430142416113, 4.788903132561715, 4.4457241796678115, 1.5797652304172518, 3.4123090774782243, 0.6657888740301133, 1.1123557436850764, 0.6034113598927375, 0.34798829966495115, 0.16681172314190096, 0.10507281223732619, 0.10714281245224899, 0.09749169806919752, 0.04802239007286487, 0.032674940828714645, 0.04583525501431958, 0.09122231794941811, 0.07558993379315061, 0.016753663000981175, 0.05641601326304579, 0.04449674236257711, 0.062434874970706246, 0.11616306109053474, 0.022112294813738238, 0.004396561360467345, 0.04331997002384836, 0.04630061129348413, 0.019621248845191255, 0.02107702657550333, 0.4301198505826535, 0.23565733294573524, 0.05905478013559215, 0.03161998221560592, 0.023419928376472766, 0.021045251163623987, 0.02949628689807029, 0.039709217606052276, 0.04564223533135749, 0.05854034443355857, 0.04989113515963958, 0.036232902127648556, 0.1340278177972763, 0.008618932521541514, 0.03308289413971286, 0.0789070102356134, 0.049632967359596686, 0.043558001202801545, 0.05427997626905, 0.16066631903090786, 0.04089409898545954, 0.05450178170576692, 0.1044781058425865, 0.0306477093873846, 0.04452314941332706, 0.0901908418464084, 0.14346010682563629, 0.3220343133134227, 0.23622259858154485, 0.35082705379013096, 0.5297257138356086, 0.08435951846261179, 0.36713378684174636, 1.6640217866628402, 5.993867506903987, 4.343044863593194, 3.7213580166139915, 23.41622437200239, 24.255721415242842, 24.339971965359105, 39.52387286770729, 47.25699040197557, 60.261553795106956, 74.80445508033999, 93.7531900405884, 68.48941556869015, 40.023320028858805, 38.904871863703576, 68.92138619576731, 90.27571862743747, 74.51776119970506, 9.118490834389965, 0.06951402151776899, 0.05222776461572898, 0.09236378895659601, 0.0894043300180666, 0.019120056888148673, 0.05585065569668528, 0.10651455906730507, 0.09348777783734184, 0.11889332950475717, 0.11515067589859809, 0.04583772564787538, 0.037603023567146836, 0.036178479241507674, 0.05079053387406373, 0.021087357271162253, 0.03803927233562835, 0.08265508774427638, 0.07503915487998918, 0.03359919526584206, 0.06138334651627849, 0.023346454798874837, 0.08033549608362299, 0.028032216265977874, 0.06933871761805589, 0.03375515544546708, 0.1141839725295863, 0.041840933864155126, 0.10198034511338319, 0.0730573237242718, 0.03616934747345025, 0.06965357209405593, 0.019166474155480825, 0.027814712412955783, 0.04898314859958426, 0.04596369348526482, 0.021240532721182512, 0.06731615356740452, 0.06015657161873195, 0.01679999791386147, 0.08540305278954968, 0.05758561501880327, 0.06060732243162009, 0.05632928061869837, 0.009539998117684117, 0.052739541992665305, 0.05077811175837152, 0.06119578904021652, 0.021561012197766575, 0.030065767932683233, 0.028858355907422882, 0.05241102433853573, 0.0336882951218755, 0.05456429064994859, 0.016974091394654205, 0.06663217494684844, 0.06119431049052266, 0.01253452281572766, 0.024301444683524392, 0.00998489793405057, 0.0697941339064029, 0.027981014779558586, 0.05818902417236279, 0.0313312245247465, 0.04284464694078892, 0.046385696848794344, 0.00487340608566639, 0.05702366271326619, 0.07979692861197457, 0.02063005832174132, 0.06711720819434813, 0.060473670732350125, 0.3331382061925627, 17.682566412033573, 80.090194056111, 104.40587674417804, 80.0035567437449, 72.42370190158968, 86.79523483399423, 98.04821675823581, 117.87550772390058, 72.24699912532684, 31.86776714940225, 31.094530705482732, 43.47431544334658, 49.47385518781601, 47.732491493225105, 30.09482445255403, 13.516883773188438, 4.095736237302903, 1.4496681791159416, 1.1194836708807177, 0.3769440942954633, 0.3127685717998013, 0.8732054634921013, 0.3612397515004681, 0.2749004473368968, 4.648944139480591, 6.838725939873727, 10.519249631512551, 3.194677839356084, 0.4502641938386425, 0.8687498348374522, 0.4335480021132577, 0.6777869140909565, 0.11476217739043698, 0.06849717769411302, 0.034117200937602794, 0.047593338700431975, 0.01589542714833853, 0.055024196213531884, 0.0605893729915542, 0.15903035359036538, 0.02265478465555897, 0.05614739219327608, 0.06487487650085842, 0.010604203412038906, 0.04612536101992573, 0.07460104451785166, 0.06024550676586167, 0.07238300547244088, 0.032737874951694286, 0.027525426121428612, 0.08277675016753136, 0.042882108640286236, 1.0404660528705967, 0.2571524271080571, 0.05681255186397222, 0.017096531397152333, 0.005797796024595418, 0.033915022673505935, 0.020675770788183136, 0.04979245537411302, 0.041461490515259006, 0.07125259677488958, 0.06702985118834243, 0.01051044191098622, 0.11176526441328949, 0.04219602327793837, 0.07146176176085588, 0.02807848031572517, 0.024107312257852287, 0.044516744918280074, 0.046413513501324964, 0.10886782029223059, 0.46355661605635, 0.21373997111954998, 0.1499874364104002, 0.08782745293912389, 0.11603271889109766, 0.663898230320023, 0.568690661701464, 1.0143456415783976, 0.5144618715970747, 0.5968910323516016, 0.43771398824549496, 0.047044501820158575, 0.20041739568114283, 2.120282303902411, 4.630271696275281, 7.052483837450705, 13.988531135743665, 32.08515667146252, 39.51555352057181, 36.54307942236624, 37.98261673219743, 36.344325080994636, 50.32225208897745, 58.73071547477477, 85.2279890737226, 93.93905547357376, 69.62947599349484, 40.4985426318261, 60.31102272772021, 86.23892507245465, 90.13916523225846, 38.07319994895689, 1.21299076945551, 0.09132279804156673, 0.08205916326973708, 0.09606512744099864, 0.04390344940005772, 0.08565063708491864, 0.1513906336960293, 0.08016243682152803, 0.06648658759771817, 0.08290824149885485, 0.052864590524545604, 0.03260749827830061, 0.10048615956498731, 0.036719632259900534, 0.024351468309760097, 0.05580824506919711, 0.0385072946007694, 0.03786040995750697, 0.0354055003563483, 0.044776146119881066, 0.02685388685354302, 0.03072449438003523, 0.07132216521929349, 0.11642861014772808, 0.04340980149384949, 0.07980394597736098, 0.034371565111101635, 0.12185736198819454, 0.042133173424630396, 0.043344925337981795, 0.035968391119592616, 0.027504852830222058, 0.030567528710009593, 0.049240496685548175, 0.24878735984525374, 0.08213554989666709, 0.20037107800524082, 0.18109463575866916, 0.09316963684414664, 0.3277954477215967, 0.19593565875003416, 0.1831234051215072, 0.20881269277343828, 0.1501329624724965, 0.13170309334753022, 0.12326457357454686, 0.15539250847312713, 0.09970342455011222, 0.18057795541901744, 0.1558135197527947, 0.18012622401358622, 0.13072417087612614, 0.17568280680045006, 0.1187027115074377, 0.1292627968735272, 0.16653110513523703, 0.12073784706092651, 0.16218980744240746, 0.1778177253060764, 0.11134867346094501, 0.07714446408734207, 0.10781998821203748, 0.27303765858373336, 0.1476832737605418, 0.16801339333816884, 0.15231223746893868, 0.1998022423997041, 0.26360402124062665, 0.1622030914070145, 0.24689081725814652, 0.20927718720368801, 0.27657962013636866, 5.377644031278549, 79.96386235760104, 129.5367613146382, 107.39965715715962, 94.47566709210797, 83.68806654407133, 95.18108967811831, 131.7154496715915, 128.9648718987742, 108.45153485575031, 54.207187160368896, 33.86919575352823, 40.41192885368101, 65.81392765045166, 55.55735718819403, 24.573470661717078, 11.533461789931021, 2.5589685190108518, 2.7198060433710776, 3.268565977773359, 1.3993913608212627, 1.8131575324843008, 0.6601368611858738, 0.3319589517289593, 7.7906827292134695, 8.439848230731103, 15.5489960985799, 4.87120867736878, 0.3626786791268857, 2.7507944837693246, 4.0184623579825125, 1.7877015952141055, 0.47443910952537294, 0.35495185503555887, 0.25060223745963267, 0.21433250948546395, 0.15186258982266151, 0.14036629138694656, 0.15528240631664955, 0.22112815370482786, 0.12178987730294467, 0.13166318016667522, 0.17551653507736423, 0.13325416092430392, 0.12070231590299837, 0.19597983137974817, 0.24827424947532917, 0.09437675392555614, 0.16191994531020043, 0.09350702196599976, 0.1255331131359262, 0.17239746938069023, 1.3378009560608095, 0.5319283085484658, 0.1503101279658656, 0.20908368871577326, 0.29034386058488204, 0.1691951452484054, 0.13703514190931476, 0.18994558662656816, 0.14364851848973384, 0.2569634332171371, 0.2298174293771867, 0.06420979343895471, 0.22517803155126112, 0.1450929466274477, 0.1973676609416162, 0.13176888497846742, 0.14634179251809276, 0.09107529801586944, 0.21192926102347914, 0.36113105894577124, 0.21673568133865634, 0.22802395625941216, 0.22066350605699325, 0.20192245201718426, 0.3101174172855193, 1.0123140376902398, 1.2475580049137915, 1.3124082670096429, 0.5352230382061774, 0.8324701170767508, 0.581313890795554, 0.20215071557510286, 0.6163240476481376, 3.3379811433053788, 13.673892328816077, 25.369345065086122, 28.052512984122, 45.20028383501115, 42.61782669251965, 37.7374646740575, 56.908103804434504, 66.43592142289685, 78.85300005635908, 89.17308545881703, 111.75491579117315, 88.18413042253064, 59.94835253684752, 56.73776311259116, 80.44522346988802, 108.07611696181759, 106.74066758924916, 24.333576540793143, 0.40982446543151335, 0.17009044156199501, 0.3300053662350101, 0.18997230777336707, 0.09214732315271132, 0.16862411863140522, 0.32687568255970556, 0.23311237353951703, 0.2594776571758332, 0.17430056968042928, 0.24816020962692079, 0.13793577019485737, 0.18155180638836277, 0.17685579466483287, 0.16962511975678707, 0.2580730196449065, 0.17563298044185485, 0.2446077833132398, 0.10294186972802687, 0.1727028473490669, 0.10047787049364659, 0.1463222419542651, 0.15326839180723315, 0.22221949191824084, 0.12925329738326613, 0.25661711551008687, 0.17435116212694876, 0.3215204215338153, 0.10486918606705244, 0.17211548773752106, 0.19080460101606386, 0.152508876917343, 0.10348992136817786, 0.17407959927954983], [0.021577107705055706, 0.010594737438124516, 0.04015677000185655, 0.060945255306339076, 0.10002037810702478, 0.035282278944167404, 0.017075613366379853, 0.03052711565678399, 0.06512302770129134, 0.03477361188420365, 0.06472239436040964, 0.03490364764847102, 0.049129486714880315, 0.04650982990560513, 0.067660081080131, 0.10034963503600129, 0.04876805409308403, 0.05162733554419491, 0.011359433955212515, 0.06351094888222795, 0.07169419283708257, 0.05845253160523792, 0.1041809403367581, 0.021880101224768068, 0.06638898799616484, 0.051692299800173896, 0.06652306870467241, 0.018229343695566058, 0.07988136682298877, 0.035153036080901666, 0.05825049506740705, 0.10986352775005565, 0.015950063581488306, 0.028606171254068617, 0.11834963690489532, 0.009439185734898334, 0.1330383692777926, 0.08526774634036326, 0.4056829328258192, 1.8097719141552526, 90.01335128661125, 105.28205579326999, 97.33148990138885, 66.88111043745472, 47.696303706015314, 65.29965000767862, 79.46547031402588, 112.14513671013617, 102.37567363246795, 66.57655408305507, 30.841008309395086, 18.424716111152403, 20.244193807724987, 29.648723486931097, 33.20154166990711, 20.174285404143795, 10.293938882889288, 4.470188002432547, 2.8059758582422814, 2.474380890207906, 3.1161485564324165, 2.7254804872697402, 13.182038876318163, 4.925281491971785, 2.9552661699633447, 2.9348825927703612, 1.5954136487937745, 1.5772758736725778, 1.2569776994566764, 0.2553142144555046, 0.2285622402785286, 0.44029677707341414, 0.21730059457402076, 0.0548334671334634, 0.0125396843331175, 0.03311845594115796, 0.06207144668986721, 0.050427051967069994, 0.11237716182105004, 0.08560185260590046, 0.07963454095466484, 0.061542489791228894, 0.06354484444243774, 0.019847013041256897, 0.027835911981040434, 0.02512433036651102, 0.027011116823902535, 0.019859096163042614, 0.04573670546374014, 0.04405182913967198, 0.22414863920740544, 0.3427352654116769, 0.05690628655194756, 0.057213277135404854, 0.021716520385516268, 0.03741909734784596, 0.06027005222295562, 0.05490244952060523, 0.025316957429411913, 0.10279392282808981, 0.06945606696629716, 0.04613839217551774, 0.05265364821459498, 0.007124839861306452, 0.0877861837826429, 0.046816808997743556, 0.11833724160228046, 0.05531451672375683, 0.0476300151598069, 0.14573555650009265, 0.7156973572507982, 0.025442268346406283, 0.06385920096128699, 0.05956022962627392, 0.054020180532168, 0.11735824252208395, 0.43595164894096317, 0.40911945003655653, 0.504770491632723, 0.8026134643343188, 0.3662266468088473, 2.3365426736493267, 4.1654889718178785, 1.7121839571383692, 4.47947274292669, 8.577339072381298, 24.862894511991932, 41.12147385074247, 50.00134337332941, 62.85454250151112, 72.56260871887207, 69.8800213106217, 84.60914888689595, 84.04989734772714, 41.75932184342415, 31.058197790576568, 46.83890496530841, 68.6033368879749, 83.97341897410732, 77.01222388975083, 7.768760112024124, 1.1135458153101707, 0.16848928715673187, 0.12307946374940297, 0.10566391035794251, 0.06815389369524295, 0.09062424076781159, 0.1581064821972001, 0.06141280259696707, 0.12259899638593198, 0.015114728012122216, 0.04124913094264846, 0.055131574927438656, 0.08807155919531662, 0.03619158317545249, 0.03560722279813021, 0.06720834967469977, 0.06985909816238188, 0.05312285408557904, 0.031079447813211914, 0.008737931831649715, 0.00940115713033705, 0.019315654456975962, 0.02955876136829536, 0.03519047096732163, 0.013331551116050012, 0.04962172118886825, 0.0285500246700981, 0.09126581642175875, 0.030666139547622977, 0.029071847374941555, 0.0530038844613779, 0.06178649645599146, 0.008089378074322256, 0.022833811742584073, 0.03484027302493492, 0.09978386378216167, 0.035595260335192565, 0.028425401317015774, 0.05361318866151476, 0.06523621719210379, 0.027524780692352403, 0.031129278002246737, 0.07585654005167947, 0.037269438241398146, 0.01849612615431749, 0.03777974089908023, 0.004940611627628847, 0.1071360632176361, 0.006522226002773331, 0.0742892467326695, 0.05722532386801416, 0.022616405565772327, 0.025910574064079313, 0.05030681829779379, 0.009273449315749591, 0.021602635669912544, 0.009620751445782522, 0.04836781911792294, 0.019780060787114407, 0.010658122595369576, 0.0843927207132501, 0.0618335189327838, 0.02198490396802945, 0.050587723587429335, 0.08915082386304295, 0.019483565608219757, 0.030875423277217536, 0.022359147495139512, 0.03763970002652176, 0.09681781648748344, 0.07093591134875052, 0.07628298289473019, 0.07414352148771286, 0.6861867311020052, 12.221273914460214, 117.64952428879278, 110.20973728549097, 89.51544561693746, 74.171721858363, 75.15018847680862, 91.5467313028151, 115.36185679897186, 106.82777558603595, 60.563262508761504, 30.46214657445108, 31.72821902459668, 43.2185023830783, 47.80982102117231, 47.342415701958444, 46.438670235295454, 24.418607642573697, 11.908791430534857, 5.343026172730231, 2.703912599432853, 2.2520141255471016, 2.3397614686719836, 5.030027406830942, 13.057549711196655, 9.237253339059892, 10.604722980530033, 5.318515281523428, 2.12317529705263, 1.0433364923923247, 0.396077232134919, 0.17852565183514552, 0.2147227853176094, 0.18388868099258793, 0.20517984254946633, 0.03607511482832413, 0.06447407462063336, 0.06603608959384503, 0.032969505466040105, 0.06539555581947488, 0.04564960509718907, 0.05658764760160158, 0.04806419932133248, 0.018927177016232765, 0.07304491309989845, 0.012953001217195585, 0.024525889293140462, 0.04241061599684819, 0.09327059957168757, 0.10584134398208511, 0.051499954274585175, 0.04308584589330901, 0.7871927885759262, 0.28542269562040606, 0.05120293432546239, 0.03652541364933695, 0.03694368616467522, 0.1050792933411656, 0.03184010608932905, 0.09216889618865906, 0.03551523096018261, 0.06022230579307484, 0.07316358778024874, 0.017299006520319852, 0.026202894063786637, 0.01759162146387802, 0.04683268616997427, 0.07163152684487643, 0.06435484835697759, 0.06128156790509821, 0.04449935472239891, 0.06126688966046899, 0.18215243464275716, 0.22988124450127925, 0.16114322408553095, 0.037671178579330444, 0.056614261496091084, 0.09408299751099079, 0.4107611764582896, 0.5860652293889754, 1.309620932705941, 0.6705964741206939, 0.5775869649744804, 0.8038382857076584, 2.7061226098768176, 1.7365120904099558, 2.2527956578039356, 17.837778522122292, 39.013709791245, 49.02277477325932, 44.955692675805864, 51.72884148936118, 63.08520140186433, 67.03314935007404, 74.89947057539418, 93.95613347330402, 77.6232820941556, 51.931161265219416, 45.82509386924006, 64.7571587562561, 90.36944758507514, 104.18338421852359, 26.535781468114546, 1.1914086630267482, 0.02834112973012511, 0.05026238902862515, 0.0975199896962412, 0.06543903897005705, 0.03214216498177379, 0.08556260592153958, 0.1709425458384137, 0.04743365916393457, 0.054511522513724146, 0.026140153378007874, 0.11178185787772942, 0.06236413441177818, 0.0531486904008254, 0.024639130494887793, 0.005793056813173838, 0.1025757333263755, 0.04682177707793252, 0.05808367559145536, 0.04945809246912118, 0.04864857118997363, 0.04420612307806169, 0.054824243434855056, 0.07994336631870078, 0.06571077801767858, 0.04715297987023669, 0.042500757732458656, 0.01619464481219409, 0.053294285410834905, 0.053995432061774117, 0.07015998685552229, 0.04807889288772018, 0.028411395314540115, 0.05347464932128788, 0.013440139291267241, 0.13070907894401781, 0.09160017549631097, 0.07513366714720765, 0.24652680292004542, 0.180278706154035, 0.14278833964659324, 0.12585969641804695, 0.20442538383987643, 0.13849358945604295, 0.16152056835351453, 0.13926071925990044, 0.18105484515188203, 0.1333118167014853, 0.12567654777798923, 0.132988435666888, 0.21895686134455666, 0.08805809136960777, 0.13081159683004503, 0.15821787138139048, 0.14665772717806602, 0.3148092768124996, 0.08003943374440556, 0.2401412149230319, 0.24653847810001145, 0.13195487580472423, 0.1791199675250438, 0.24135722628524228, 0.14486900380542203, 0.16804166198257478, 0.3340936404082083, 0.19491697631535992, 0.17984958966412853, 0.1535863795828435, 0.11861597503265066, 0.24241168502598043, 0.2199608655346017, 0.2442579262799794, 0.23259124988990448, 1.0184632722408542, 5.1669607816203955, 132.19622242835263, 133.01425626201015, 121.99786386182232, 100.03809005983415, 76.46430800038, 90.71438081802862, 114.15524944182366, 132.2107195085095, 118.09015550921042, 88.33904835485643, 52.18386388594105, 36.46541649295438, 38.56318635325278, 51.069702871384166, 60.228715712024325, 40.98218264118318, 23.43151180974899, 8.55583958087429, 4.806447404046213, 2.6531725737356373, 3.474284242237768, 7.527715756047157, 18.309829888805268, 12.311720828856192, 15.21844227467814, 7.128425336653187, 2.3136058786223015, 2.8524993360042576, 1.497997172897862, 1.3667508671360633, 0.7038043631661324, 1.1377051640902798, 0.43908657265766976, 0.12960044246527458, 0.08960590307270327, 0.15857692146974225, 0.11683438393858173, 0.16605046157154346, 0.12824062107791825, 0.20265847865131595, 0.17270152967783714, 0.14848467833813161, 0.17969787361160403, 0.1073311092031579, 0.20546720212986394, 0.1493122984444903, 0.10050959419459106, 0.24512922871978055, 0.15025579701027564, 0.22917820561316707, 1.2102422911313273, 0.8572798438610569, 0.19269777281630426, 0.2317725470469844, 0.1373940234583232, 0.3684353089380649, 0.18274252152731343, 0.27587206132950326, 0.13177397180228465, 0.14920631784104532, 0.20277231931686404, 0.12844194898441916, 0.10301860875540203, 0.2231950436027781, 0.2297972046559857, 0.13586483535266694, 0.19633688963949683, 0.18903859981125404, 0.2420042335025726, 0.2942251378009397, 1.7345257776398815, 0.20353885157214058, 0.2534167525628882, 0.1011438996741368, 0.11241953414414199, 0.24379991295356906, 0.669736065451176, 1.3691302749418444, 1.5632560969360414, 1.69270534428858, 1.6103576340021628, 3.3650266210879054, 5.154292506556358, 1.0998599303345526, 14.62145753445164, 32.79999882944169, 55.26401489011703, 61.929231843640736, 66.00794376865511, 82.38521991237518, 85.85232057879048, 87.2448718163275, 102.1429672548848, 103.94632401004915, 62.70892450886389, 56.56926985709899, 67.42527654094081, 85.9790131353563, 108.20138962038102, 107.98175258021202, 15.235131959761343, 1.8986172757802473, 0.3395479412809495, 0.16880752008047797, 0.397320868627679, 0.1881480838863119, 0.22331502829347888, 0.269641590815398, 0.2980298368680862, 0.36000711603030083, 0.062618923764075, 0.11460190413579827, 0.22836609112639583, 0.21847542104942186, 0.203191859707717, 0.10375808278519301, 0.2609070546684727, 0.2004859758721244, 0.17485072806237206, 0.1387402391241443, 0.18601362503344016, 0.16724440960153458, 0.11007374993735745, 0.12123205804175909, 0.13015699002050585, 0.18576288445582315, 0.19972051613994185, 0.11306903114722622, 0.19263248680339706, 0.16755830646762926, 0.1730364020312986, 0.15546979142292855, 0.1806082465355435, 0.14245624053141764, 0.16983539557024357, 0.18426593333002061], [0.02325004837926357, 0.05622613837101287, 0.024765692050418547, 0.09297468278917576, 0.042862711294043454, 0.03922700739255355, 0.08075581022327946, 0.06406051354602942, 0.0747695915220726, 0.0329154196585859, 0.032421526604241906, 0.0772921581782641, 0.01015457108752021, 0.02883452865775795, 0.036862672366682565, 0.05001048399736324, 0.017236112616956234, 0.027216974225255753, 0.024503435256079804, 0.013957891196403054, 0.04032478840540975, 0.02630363462582952, 0.048502049213575746, 0.05568536839658215, 0.012692048687547927, 0.011070415794458843, 0.040158252381990035, 0.171024747072689, 0.08357645402992926, 0.05206219769353348, 0.03872135105813223, 0.0554243277668232, 0.04086922411055815, 0.08699866071824106, 0.032658125198776686, 0.07058109006574077, 0.05750894110890166, 0.20644448517311006, 0.21813504818466403, 0.3199483171826409, 2.9313367701345876, 58.97201968777565, 96.25914527523904, 100.75742137047553, 87.68784076936784, 57.71257408203618, 35.94474146443029, 63.44971902908818, 99.41296623599146, 97.80854425122662, 90.43661425190588, 75.04458258228918, 58.973792599093535, 45.46704030806019, 40.707816769999845, 49.18401556630289, 42.55190733940371, 34.771576235371256, 28.711076974868778, 20.97318199373061, 12.48418156177767, 12.602063494343913, 10.43973534337936, 6.39853157343403, 4.12861967279065, 3.4703920252861518, 4.738122657422097, 1.6906571316142238, 0.5276413418112263, 0.22850849154976108, 0.07664492879543575, 0.15378058287164859, 0.08107502373956865, 0.039797570526359544, 0.04791222662935334, 0.015196328824986855, 0.042789576710352016, 0.08908647247740338, 0.02726142456184232, 0.048397436077075626, 0.07845105002484015, 0.04917896833390959, 0.0753592877017875, 0.046093200648864435, 0.014115201605994616, 0.0927768022783341, 0.02206958732717941, 0.058270382709921374, 0.10406847096859448, 0.07330015827451022, 1.0941583975668878, 0.6176006565651586, 0.043069306055023786, 0.04395399971174137, 0.042919532035387335, 0.027913848020797296, 0.1460022010630177, 0.0362441138244204, 0.054759930353611715, 0.03370167867791268, 0.020077258851679585, 0.043985030103114345, 0.09563270145125928, 0.1241958300553022, 0.042378421151830305, 0.08678211830556394, 0.07306299277491148, 0.037439387186520526, 0.09460724679933441, 0.05526706140728728, 2.589443374064661, 0.8050019426211235, 0.05811776650408584, 0.08542798895148501, 0.2947775484813798, 0.7940557719238344, 0.623580800189126, 0.5873185492330982, 0.5896019202566917, 0.6902101635932923, 2.1235832235505505, 4.510634993353198, 5.047591780462573, 10.806026862513635, 9.7842719862538, 12.490226914805751, 41.39475714775824, 58.93847165569183, 68.62191323311099, 64.8158727153655, 71.77257276350453, 75.85583856028896, 52.92536835516653, 33.25885534286499, 38.98981078978508, 54.38629042717719, 76.31273977218136, 82.99361874980312, 21.927920233818796, 0.17871046288599893, 0.4483582590135836, 0.052863533323210095, 0.16767501230201415, 0.16202036411531512, 0.08092883884185746, 0.18776336985249675, 0.32665627497819166, 0.18060743448234376, 0.09771488246417816, 0.06479930958800739, 0.0480312537101488, 0.022869490372437625, 0.027992268611166268, 0.09486705019709565, 0.043498261666466156, 0.030918601907849796, 0.07791909389197826, 0.049395028111194415, 0.07578502574394788, 0.11798368436434578, 0.04041603713807079, 0.012317979445440635, 0.04745675671485163, 0.05306966460099625, 0.005660751034625836, 0.029267163406456673, 0.07212192270784609, 0.05211238411345309, 0.05802006731110235, 0.03143719746731222, 0.07042034949746824, 0.014175973445807975, 0.07870989581269604, 0.05129673413091129, 0.06385547011309574, 0.009429528239002873, 0.032495978859163104, 0.033382522618217815, 0.05826289803090115, 0.03314819547437853, 0.06498273401971787, 0.0535015351769905, 0.05421616497539705, 0.03240044769500533, 0.07910056234968287, 0.03642671854205189, 0.03602732243316789, 0.03373782653661986, 0.0973499105161717, 0.03233642189673359, 0.016325460070924416, 0.03188033528145283, 0.03758377943848891, 0.11270574459265317, 0.08197400493607407, 0.052497297330128576, 0.04333879280414793, 0.030623022204024658, 0.09410829373425054, 0.16197177881915725, 0.0768819180948119, 0.05355043456919732, 0.0550423295146996, 0.07221392986755218, 0.07419000770295821, 0.05913800409724636, 0.04657971627649762, 0.09258496620121504, 0.0557096648751007, 0.09391325540960797, 0.022440147886593497, 0.07109114374484747, 0.02229615783078536, 0.27926730172288033, 0.2656678927521552, 0.9898809607951873, 26.329833499846924, 104.84222473636751, 114.76449551120882, 93.46853579244306, 71.86499164950463, 77.33490943908691, 72.37951247922837, 97.96842790419056, 107.85082386386011, 89.40524270457607, 60.26314627739691, 44.03626949556413, 44.67741227919056, 51.372858939632295, 58.001660608476215, 57.72702409375099, 51.39596954468758, 40.475941934893214, 27.845280439622943, 19.35239980297704, 11.914478867284714, 12.814325497996423, 16.26694183195791, 10.45258895043404, 8.943633533293202, 3.28693762421608, 6.492257589294065, 3.5356504590280595, 0.1551619313296772, 0.2543437342730261, 0.1607067378297929, 0.0775171275581083, 0.08668251155364899, 0.052405627249109174, 0.04400771779699191, 0.03340373176240152, 0.06538738166132281, 0.10440209459873939, 0.03765976386925867, 0.08422256492438816, 0.03231466499968402, 0.046531437415509455, 0.06577525197738601, 0.07062212173496524, 0.019103488321566296, 0.02865818479368764, 0.021983703125208136, 0.0503383543071968, 0.0493255669190999, 0.03207050894777621, 0.6407717519229459, 0.7168057332596471, 0.1347372305369185, 0.0537649660010732, 0.04512303839287451, 0.08386369103625899, 0.10344009500958266, 0.03389635694123084, 0.02046177178741463, 0.05578815058294324, 0.023325098182765708, 0.0188017416099507, 0.04949763792777254, 0.09066738683970706, 0.11144506264357798, 0.06605858959618115, 0.08294581811154082, 0.058669667736056356, 0.04093300476069412, 0.04905548645183445, 0.6083061714326182, 0.3833625934297039, 0.30187075657229273, 0.11178813213782926, 0.2927784267212114, 0.6563914266805495, 1.3767483758349575, 0.5062482752386601, 1.598053649067879, 0.2682324793309935, 1.1851735653415805, 5.007271776276251, 11.011120734676238, 6.618679992614254, 12.963957055922478, 31.33950233459473, 53.14057311704082, 63.69433372251449, 71.64703338376938, 74.5462219176754, 76.62896125547348, 85.71022095218783, 83.89750542179232, 62.98674206579886, 39.433925074915734, 51.585282741054414, 74.9134812816497, 96.94851752250426, 59.59782208165815, 6.619945447291098, 0.49798926518809417, 0.22412646862287677, 0.13219273078345484, 0.17895498282967076, 0.11495567587835175, 0.12206988243926918, 0.2257290326299206, 0.13642323684067498, 0.10069026837065335, 0.02075319163381092, 0.14443012735536023, 0.028151942402004238, 0.07341778341440425, 0.08174985527030884, 0.05185145456644316, 0.04963057333483331, 0.03866179921333829, 0.14307249697946733, 0.10105864940992287, 0.11072353039297367, 0.0406219462503589, 0.08600985571261376, 0.04566100065506274, 0.04833845496778527, 0.016453925354947007, 0.040526231225099296, 0.020540366662786375, 0.04474921429890298, 0.03399498693104233, 0.03240715096434278, 0.03009966349289302, 0.04113147898967709, 0.04660710775023026, 0.052691209505522446, 0.0514158952770935, 0.03468109527602792, 0.08969512933324422, 0.18716418184340003, 0.17983353246123562, 0.07795456376287245, 0.24767547515371155, 0.13519936541636146, 0.1958729008272771, 0.22717166812189166, 0.21006101772429484, 0.1660384033476153, 0.16982969587608693, 0.1483296527857742, 0.13412757776677608, 0.09592635827439447, 0.07954012061799727, 0.13422854815519628, 0.09973345519674402, 0.15885485816867123, 0.1607296285369704, 0.08840614809624611, 0.12406273760021695, 0.13348421712796535, 0.1770744668019395, 0.2530760579412022, 0.1620998993636139, 0.15505729904097898, 0.20669778448439416, 0.2831939313440554, 0.17524150951254755, 0.1927679005048929, 0.15342191582725895, 0.15869738113495613, 0.22752725549282568, 0.19255779323077973, 0.13751768537106054, 0.18955025461412248, 0.053457504273542476, 0.5648887818378787, 0.47030002840103646, 0.9251937834966568, 8.717227462799318, 100.73632686368882, 133.76171881152737, 121.1347149264428, 110.32529815550774, 87.47603278006278, 58.5851170939784, 89.26000518183555, 123.83824779141335, 125.6015806813394, 111.92372675864928, 103.18814554522115, 83.7137737581807, 64.54617446468723, 60.82604562082599, 71.0124723372921, 70.12083130498087, 60.20330267567789, 46.29493105796076, 29.66511114951103, 16.288982610548697, 17.844919197020992, 22.79378737172773, 12.593009683393664, 12.430093057693975, 6.756148280635958, 12.035369257773123, 5.445020544913508, 1.621959392101534, 0.9315929465716886, 0.46616275524420125, 0.3117231375748112, 0.33647890112573103, 0.2943485086002658, 0.09673282669316377, 0.08336067770517643, 0.17432701503557546, 0.25339733989488694, 0.1776001103703053, 0.11255635744741849, 0.12353763795427739, 0.17824748530983928, 0.15520596606356485, 0.1394745497213256, 0.20194937234684346, 0.15557777917673513, 0.15864260584837006, 0.17570021231808972, 0.15064372861337277, 0.19375975454045882, 1.4185347335953868, 2.294007020611917, 0.24375053092596993, 0.1192779669297799, 0.12881705627566384, 0.1526150260601313, 0.32429215828737906, 0.19642647596136217, 0.15485894355562427, 0.1824492324263819, 0.1891735232164783, 0.43619814539147966, 0.25387686497021106, 0.344289657810042, 0.20437595584700186, 0.1873406118923618, 0.26337575768270804, 0.139055177869816, 0.23656583661513947, 0.13504927347023643, 4.270993865305378, 2.4850274285962506, 0.1593531677198987, 0.2124835103149376, 1.2695032983056962, 1.5909210640576579, 2.3503827568023437, 2.408625296046657, 3.9959241738242492, 1.7603084973750578, 4.545489174704398, 9.700361701749987, 10.924600112822748, 11.975215788810484, 30.34588948372872, 46.77998704295005, 72.3071761285105, 86.35363086577385, 87.83980907932406, 82.60848906732376, 94.24905607777258, 93.72838497161867, 73.39721064413749, 54.24577936049431, 57.615715073001006, 72.71089000086631, 92.83643014969365, 115.5352020263672, 48.58814477920533, 1.5483330718932615, 0.6462215175551753, 0.41445065590162433, 0.2910270271522384, 0.3675597930146802, 0.15722157403586373, 0.3029336882454734, 0.3090765489445579, 0.20444594563976412, 0.25440722764019047, 0.1938148056186976, 0.20013631802172432, 0.1119721924225169, 0.163978484849776, 0.18294084636915117, 0.1498302658118548, 0.11069972038028703, 0.15824655371327556, 0.24222811503756433, 0.14391649604564713, 0.2317635378529949, 0.2796592323049423, 0.10310857812122953, 0.10415895361333125, 0.12620294977340007, 0.2705032252255948, 0.1529402916710223, 0.21061862248086163, 0.18289848170693845, 0.15578275366175562, 0.09486708850149186, 0.0993807866208015, 0.15397230403557902, 0.1294468724799733, 0.18825421770734174, 0.16137778488618715, 0.13117795539719443], [0.03145767499752824, 0.06130741571166343, 0.071112678476399, 0.04603354155176109, 0.04536300777427612, 0.04157528904597125, 0.032493197959997965, 0.07185890174080288, 0.03034423131706013, 0.03931404647207068, 0.04562581423670054, 0.04639380205903323, 0.03860339266999114, 0.06659320405414028, 0.02215024489428728, 0.10311501325979348, 0.020345931632384177, 0.06788953973521149, 0.03173731624208872, 0.04805609794153322, 0.08868299695032258, 0.045335011091083295, 0.016310475391125488, 0.036653978524789695, 0.019851479333855455, 0.055755591846161315, 0.06452956236898899, 0.10650885171226918, 0.05667783147204788, 0.11477713908759818, 0.040132147935970176, 0.06396494790791504, 0.09709610558685758, 0.07682534250160379, 0.1736975052664357, 0.0723114375385546, 0.17000955799894948, 0.06825007603413637, 0.02168931851854488, 0.23421987620813234, 0.6816975784397895, 1.494370819099488, 34.336126465951246, 121.7642161153978, 93.31732057755994, 79.1120098483178, 65.76570603155321, 47.56725380497594, 65.26954973897627, 93.2443723370952, 105.59764969733455, 100.63516893694478, 95.71119016216647, 97.7051035050423, 82.83386061268469, 79.04280354899745, 65.99649829249229, 55.797480767773045, 56.607748308489406, 45.68610468218404, 39.66185400562902, 18.92886619414053, 7.8901241287108395, 8.705150485038757, 10.303082908353499, 7.140873958987575, 3.6074999455482732, 1.0448072586328754, 0.6225178991594623, 0.09050314524962057, 0.08460987599626665, 0.19189010163949383, 0.05948235678877081, 0.04936949823111777, 0.07638044460045715, 0.05994878942146898, 0.15974954161192143, 0.03281368318224146, 0.08581353802113764, 0.03902146217202948, 0.04573626113274405, 0.05715396660830706, 0.04402266800283425, 0.02991441194148314, 0.04016253864392638, 0.020658859397254644, 0.08383592800988306, 0.021025654634520895, 0.02375081707272799, 0.08278660205823761, 0.33075410992868487, 0.5896716649013182, 0.08978753485867093, 0.03956451508847456, 0.09824386617589383, 0.03028656404855992, 0.07587946906325317, 0.01281891380541868, 0.06318014445564439, 0.04615412762148246, 0.04671292747521112, 0.03220032637698516, 0.03784120796368488, 0.043603073985826586, 0.039746135383123354, 0.011742084339681652, 0.00538145405082633, 0.09763643506073183, 0.05237984839045713, 0.141159575432539, 0.06687573728061492, 0.6542833978610655, 0.20800390310825842, 0.08512202875628587, 0.7962806751170467, 0.5652895377528283, 0.24304533166991127, 0.6996999705030073, 1.0427700776246287, 1.9788686017836294, 3.4518549038517863, 6.486127415011007, 10.489874020699533, 10.492709894334117, 8.81726751404424, 34.42570947831677, 47.64833311880789, 52.43743335047076, 55.17183134632727, 60.619419082518554, 45.729325279112786, 30.0395719851217, 31.50560098309671, 52.3345652703316, 75.03287822969499, 81.26208843723421, 63.591975550497736, 6.47835474821829, 0.9628229191707027, 0.11367885245671196, 0.04510808052615293, 0.10193504633442049, 0.06236291633197858, 0.03788134331003793, 0.13663950346169934, 0.17731140247516095, 0.16133876036732428, 0.10284774050477052, 0.08412019259506658, 0.029393326596266804, 0.039545902982354164, 0.05879242183460344, 0.05497622761815306, 0.009797811602062036, 0.022572227190398884, 0.0483093244744645, 0.05227962110732352, 0.12405896078675024, 0.08933289231912744, 0.09231392429360459, 0.04486380190017723, 0.02219629443941578, 0.06767326545330786, 0.07853903522294375, 0.04877122952753017, 0.03310112320187111, 0.047679822366203994, 0.017728494562869592, 0.052366878521899064, 0.03325336785506337, 0.05173430823150182, 0.0378512169024156, 0.023567760363221172, 0.028405075089164802, 0.02299569569708359, 0.08996823201737097, 0.010442372126084183, 0.04352823485650363, 0.023709007824260383, 0.07127475969853901, 0.11331872218438696, 0.013729724357084883, 0.0489766406826675, 0.01785765890212309, 0.08055927802718456, 0.04314965335652233, 0.0710642310760675, 0.047973142110652504, 0.06464829067549398, 0.10646744465996182, 0.024435082976255688, 0.027169199067077814, 0.07555571264557301, 0.043566566065795, 0.05139337612255927, 0.028728752982832735, 0.042738279462942196, 0.057210569014592524, 0.0656853132550755, 0.035594099711987286, 0.0732172905437408, 0.053514474402031595, 0.07833049842907537, 0.1646665084145723, 0.03340082445872888, 0.1205075610308878, 0.05068892380222679, 0.08137610395469012, 0.20179689020639469, 0.08133929342992845, 0.15358929071695576, 0.07075024994030114, 0.1360032674405844, 0.07842972979790742, 0.3955903679372803, 0.24586383043037308, 1.338755562901497, 11.236910993053067, 74.33069552144697, 122.54370873974217, 99.65910280904463, 72.38614128481957, 59.11195024367302, 72.49057046828732, 94.75134695729902, 109.74195541874056, 106.46974163670694, 94.51052911819951, 82.2993278503418, 73.8362729164862, 67.43313697076613, 75.72793006896973, 69.07904194247338, 67.91105424204181, 70.23243058112361, 61.68579386126611, 51.506529392734656, 30.602598805581373, 16.837079909539995, 14.449248813813734, 7.732015348249867, 4.46380679645846, 6.039213538169862, 2.389529727159008, 0.5972089894836949, 0.183324319340529, 0.31012075742886913, 0.41655028839745833, 0.07354131509219447, 0.09008871466522256, 0.055555478189020395, 0.049676465831937335, 0.1298613720122845, 0.045835442705861026, 0.07244420057583241, 0.029565966425223217, 0.00853181491801215, 0.060355551465744936, 0.04038871078181171, 0.06686992267326963, 0.043522018052998095, 0.07555269425915134, 0.008073910759131034, 0.05796087935807244, 0.02160781442428068, 0.12630903762915444, 0.35706616577602207, 1.7705116853598626, 0.044768040909642176, 0.08652042267062972, 0.017540065661793756, 0.19346265032166438, 0.09404922835528852, 0.05222906313476063, 0.06022240538450499, 0.10735937018668461, 0.04282976951329939, 0.03395022441362662, 0.04759574038607459, 0.13016187766146275, 0.030584035989558025, 0.058560320176184184, 0.023826878112290176, 0.08997973099711443, 0.05421951277962616, 0.10228866485938912, 0.10695330528241974, 0.4724362492561341, 0.25507798358317346, 0.050171128804645235, 1.0347900155090517, 0.5580451651926964, 0.23115561644156135, 0.5371902907086957, 1.6816670591792755, 1.4966218918561938, 3.918914809342354, 8.951127221507411, 9.518144073024873, 6.010948448411881, 24.433342026126002, 49.626623661287375, 64.19014876888644, 72.84683150629844, 71.29023105867448, 71.6205495403659, 76.06559122762373, 61.409870809124364, 45.6509445559594, 45.42962874135664, 67.69351959228516, 84.35423404939714, 88.29163474421348, 29.45790998397335, 1.3625047788504632, 0.3589338881354178, 0.0643722998398927, 0.15281191065667138, 0.032792998808285886, 0.056171451184538104, 0.1561542143744807, 0.16976837819862753, 0.17054879196709202, 0.15054907078944868, 0.1001091523756904, 0.09357759398558448, 0.08821962866932155, 0.06704130420281042, 0.028000595986903198, 0.04810998073568748, 0.07356556177499794, 0.026557755566412405, 0.083849303905041, 0.09258730276938408, 0.06498788979144828, 0.03300947610348944, 0.0508629943003818, 0.02512503708262117, 0.07684071788624411, 0.06905338050977838, 0.09141084452670428, 0.03228278425071509, 0.014855099856973657, 0.009688711105545443, 0.011470670879427946, 0.0270060453218438, 0.04801097919323272, 0.013798372538369751, 0.027491674202704625, 0.03497961675748229, 0.01496380486059934, 0.01635466717303761, 0.09045082910527145, 0.20555355556068883, 0.14095263976243236, 0.2060692553077975, 0.15623103767152757, 0.1387397028625973, 0.37825064192856517, 0.19252836013272887, 0.19863135361623382, 0.13296497805464652, 0.11737724916348535, 0.18884226679801944, 0.14603733385522522, 0.26358514483417234, 0.10734889010388045, 0.2187822239413377, 0.10946723046682535, 0.12866244441078556, 0.08684313720873288, 0.1612110841538637, 0.14441629180744772, 0.16976588075199436, 0.15425998537290483, 0.0923799840553153, 0.12708300859817576, 0.0979176123115805, 0.16577797941863537, 0.21051734565727173, 0.2926940038319557, 0.3770196305647973, 0.27667090717342596, 0.23650473344229886, 0.49903289144558294, 0.3016497555278963, 0.3387540290432592, 0.20904213610676028, 0.5221559071252423, 0.47789205166120685, 0.6230018828665057, 0.4721301511651086, 0.5690477812482465, 2.6271177395697567, 60.46202221224385, 149.4969343370007, 113.94350421044135, 98.95125619826779, 88.76629644824614, 73.21893107506537, 88.07432759192683, 116.13581103663292, 130.16110066444645, 124.63910164371615, 114.66398085317304, 112.85142221758443, 99.64073042715751, 100.20879945447369, 86.98630917456843, 82.18723435555735, 85.35071219167402, 69.5507775583575, 65.62975275901057, 43.19426605778356, 21.325914859771732, 21.23165834334589, 15.821818517100429, 15.38152462051761, 16.808564278387255, 5.498615320651762, 1.163041591644287, 0.6873784574770159, 0.40743390338555463, 0.8246916280158105, 0.21084797388363272, 0.31256356667126384, 0.16148244781840235, 0.14862188468537024, 0.25639439842874007, 0.21689649851572132, 0.15822338721444532, 0.15022765093993756, 0.06403607917168448, 0.19314685355751746, 0.12623585324974793, 0.11320249132451513, 0.14478695578873158, 0.10255285794095648, 0.13602183741186896, 0.16064781034665723, 0.10995927341883222, 0.23455078022614603, 0.9129872449463414, 2.086145425996473, 0.17062779095384384, 0.2510511036962271, 0.1611853282778494, 0.20978783077049643, 0.10843564711150624, 0.1723515041052334, 0.1689026835224321, 0.1604715488370388, 0.16338151849565968, 0.11424978714316122, 0.18823141893071516, 0.18883129641894372, 0.14860705322315618, 0.1583862881506643, 0.17665235235566096, 0.19130445806489838, 0.3323784308327783, 0.5611148488617713, 0.23747630146962984, 2.29047124904971, 0.32281701002390156, 0.12291235699047967, 0.8858855669536899, 1.2518681994368954, 1.3953627189320903, 2.772074322546682, 4.289330945860955, 4.695806166818065, 10.016608680448225, 14.571152156399144, 8.603526776836766, 26.215227726967107, 49.22099174991731, 73.64730096632435, 79.1287426794729, 79.57109974276635, 81.20897954510104, 83.3713508421375, 64.59453336654171, 50.48245345392535, 52.63226139929987, 69.29896923803514, 90.17737696247717, 104.14197967898463, 94.63493101058468, 17.3760724067688, 0.7572782195864186, 0.26687760687162804, 0.21669550768790707, 0.3961710932274019, 0.18040098910850866, 0.19141298208025195, 0.3394810464834014, 0.18489985576560422, 0.2415900404054311, 0.2136352009350254, 0.18284215892274536, 0.16258262668646153, 0.16800678966026153, 0.21687374570437018, 0.19928167033339703, 0.23716022891383018, 0.2849957394984461, 0.250952186423444, 0.18116833341698493, 0.2506180495143898, 0.22930408918088485, 0.1936355257226575, 0.26516668738857396, 0.19733974469765542, 0.13127708717459632, 0.17474572805147018, 0.2641451551068214, 0.06417356514101548, 0.23382696503352737, 0.17043248449842777, 0.09191649320024638, 0.1209072980488981, 0.1692401912183531, 0.13411610176967037, 0.12956448229810885, 0.15922782041372793, 0.06390150816690537, 0.1897797592344784], [0.039989103998748526, 0.06452427636231146, 0.06496793320102077, 0.02240551879719621, 0.06532929687490387, 0.04696709629628928, 0.06748118422805302, 0.04103155048083394, 0.05103410386870946, 0.0973437894736567, 0.07854205360936542, 0.03428582455061617, 0.02225670813312454, 0.0692087124973055, 0.03580735560746924, 0.026556690704197656, 0.04459940963574956, 0.02936225981571742, 0.010996318812812529, 0.034718959171685486, 0.06853995604380485, 0.02707403370990388, 0.0280538410128605, 0.032113369651919896, 0.041496339854934526, 0.01836812243826928, 0.09385728502586003, 0.05611523565265441, 0.07034069167510157, 0.15743194177987116, 0.19113453976329298, 0.13629562191424832, 0.04915825331643705, 0.10201607545417163, 0.0412566002999102, 0.2387537837268845, 0.26191930196458296, 0.20779143628333846, 0.196786537285774, 0.13798679165061445, 0.19865998998284343, 0.289731664402831, 0.1538669056589565, 13.964841981087963, 93.65605646564116, 118.62443723986227, 99.83269906813099, 95.35836512042631, 59.38101307038338, 44.12834321298907, 65.03101471931704, 83.67140431557932, 98.42985553126182, 90.24089582504766, 84.92486830680602, 76.06295539486793, 87.37159575185468, 97.69346191037087, 80.71778112842192, 66.02024432151549, 45.728325074718846, 44.00010524257537, 38.81896411218951, 30.393154044305128, 21.614140425958944, 11.32139394360204, 3.8914140914717033, 2.192410033556723, 1.1662157697062339, 0.2033496278548433, 0.0468090676792687, 0.2379369501384997, 0.16229655413377672, 0.41518040061477696, 0.38638750692048385, 0.37899209246520077, 0.08959152360236453, 0.014619176377422147, 0.05080873995358425, 0.01882623918654938, 0.04153285926628498, 0.09702715001279309, 0.06095353288636093, 0.03257707309638781, 0.029368401925650336, 0.06385239043964014, 0.1054140431205592, 0.015915725605502244, 0.0664860743188089, 0.08567363504440555, 0.37271988548098073, 1.6308961448169526, 0.04151174971353143, 0.07846702295806139, 0.029343237852557536, 0.049144306685775525, 0.04413599921991268, 0.046397804868437593, 0.07081126118259085, 0.10884053990124695, 0.07900305467868045, 0.0955916314776386, 0.019368472388915477, 0.03908139706078557, 0.10050485211033976, 0.07116353139281273, 0.18831193477155703, 0.08850942440931836, 0.31908701985113086, 0.06449404653281936, 0.21258788213374155, 0.37053411405894066, 1.6910228926327922, 0.11832434068163557, 0.17124202492977345, 1.1315220378098951, 0.1538417932967986, 1.3202053260418678, 2.9066304958635762, 2.0595250350813714, 5.908455935216719, 9.388799013630036, 4.877981139767555, 9.618210600268457, 24.304080317097327, 23.74304017712993, 33.49418578609344, 47.86606388707315, 38.47500754940895, 22.354723138193933, 28.46917263923153, 45.24721107175274, 72.45500241556476, 78.95437763583276, 73.82670233326574, 27.763316631317142, 1.0318542440091412, 0.5604211409245768, 0.08440256494307712, 0.060735328062888116, 0.10266079972948759, 0.028387004990250837, 0.032738231182579076, 0.09449652411163816, 0.023029602748612245, 0.09455473913300423, 0.09205368422572652, 0.06242011628684498, 0.09132385524290224, 0.06698528785378703, 0.07622507430853383, 0.11974594706008512, 0.05687611417904977, 0.0646906936421029, 0.01512615995917229, 0.1156225017902832, 0.07437647350372807, 0.0760469205617424, 0.07144133019591532, 0.029080094311446435, 0.0763719333636184, 0.040282657400013945, 0.028528411414534337, 0.06433033354340062, 0.04892560007471231, 0.03457083224108623, 0.022597912203280196, 0.0110198664403851, 0.062343756472992326, 0.02887642409111704, 0.06649770353349947, 0.04353417586835642, 0.06421197295909928, 0.12479087352872857, 0.018972630928000136, 0.021515694266605764, 0.05595128900641876, 0.03268862698948191, 0.039824410416786714, 0.017063853916742148, 0.030372791074877305, 0.06095581199793566, 0.06502748887625433, 0.020068441179671118, 0.05889391316281212, 0.07328274509599132, 0.07988505936678379, 0.05106452905062226, 0.032502276101900686, 0.12373521969082857, 0.04141861640457665, 0.02573416699775525, 0.03790897610146673, 0.10325089427492312, 0.03825406806783811, 0.004680096725707934, 0.025855791116614017, 0.0612148646295311, 0.025436867426540104, 0.022414505008548018, 0.05512073478331009, 0.017363717967283823, 0.07083802063378596, 0.07105345221897287, 0.14423238474034494, 0.04912012512044561, 0.1376352798674376, 0.059293018158284895, 0.22653708685069318, 0.15040834043775836, 0.14999834550244195, 0.12224946110959976, 0.23786487658658337, 0.20006367756474405, 0.23108084626015157, 0.3653860951383268, 0.19287984127238875, 0.6430612516499336, 2.4617292852171007, 53.05342981892248, 115.2306378272272, 116.23396442782496, 85.6414931820285, 75.47162671242991, 77.58130488857147, 87.34180142802578, 98.88277161505916, 105.29017509952669, 102.59764840525966, 99.10720179157873, 89.62032979534519, 87.2518301010132, 91.69577352462277, 94.56750546732258, 89.40172041616133, 72.61790629356139, 67.62483889056791, 58.572165427669404, 34.58068624619515, 29.31546714998061, 18.47920567758622, 11.018808580213978, 7.620550903581805, 1.5276995661758608, 1.0527023769194082, 0.13931955481248517, 0.02780312533310104, 0.10972512630565513, 0.026297241622101397, 0.0704906610471587, 0.2833306933602979, 0.20913748340981625, 0.1277440352245204, 0.0467221933086553, 0.0765915707715096, 0.06103147467177722, 0.0404315734011752, 0.11547866878249954, 0.04388946063456036, 0.11436447816630525, 0.07361045452736079, 0.06881040040283434, 0.03510044414489981, 0.03149630306589027, 0.04472785576757404, 0.05782173480838538, 0.2583382086407754, 2.696073007199072, 0.00753389921174535, 0.062060867015632896, 0.058328298956996975, 0.03785448809785228, 0.09982359310191485, 0.019206906360904538, 0.09473563547456458, 0.05356619299779977, 0.036417157764756874, 0.08671531543856667, 0.010344851048543088, 0.05468106926268628, 0.060663695011528275, 0.07023510177649799, 0.045431787148118026, 0.11203348711733857, 0.1269896301410852, 0.10104933378076363, 0.34281116940321466, 0.06174024389756303, 1.260035064431929, 0.5226986038108026, 0.8686016427893793, 1.0385242344871646, 1.2278127934663527, 3.560963720083237, 3.369756264071311, 4.9946412540251215, 9.535346608008108, 8.732125605306319, 8.371068489167, 31.696061472738947, 51.97022022739534, 62.1747604493172, 63.17426666136711, 64.08295039207705, 63.51717595131167, 55.28368165416103, 42.91392641682779, 42.11730480194092, 58.41891842503702, 80.6113515361663, 88.65109643628521, 57.078699450339045, 6.615609757361874, 0.3982666807789957, 0.3140764064606159, 0.03962078424651296, 0.1085356139247456, 0.04250253888688261, 0.0180041138458276, 0.07607126683597604, 0.06169003832544531, 0.06825805100942813, 0.029994535162263823, 0.06456874776631594, 0.10075225254460689, 0.037155229853646415, 0.18529272097493374, 0.016770898064057675, 0.03278509278090731, 0.03760410375112007, 0.03609489521852905, 0.03069329736453872, 0.012598978580846902, 0.08979676621815852, 0.11822389123300392, 0.08460327231835935, 0.009733929445276098, 0.04049965563500601, 0.010289508856893068, 0.08696497583221044, 0.020547795800432082, 0.0216918638456733, 0.051058101572937546, 0.049709078194873954, 0.02348400780089921, 0.03868575861317016, 0.05852267844602466, 0.05571793862468293, 0.01275437472823767, 0.10300899435195232, 0.08211822864869911, 0.01901789523300625, 0.19510085273894573, 0.14288017826695598, 0.15010256410366105, 0.1098043857623012, 0.08705995541306273, 0.21383518052677955, 0.1384081400089687, 0.11666350036619172, 0.14179559694903512, 0.3414184828439067, 0.12035134038136852, 0.16054526181711307, 0.13335338463225674, 0.27943115260812545, 0.2344647791957663, 0.14204980024406988, 0.15718852500281028, 0.2072214668676738, 0.08672305292660192, 0.21182452148247152, 0.15431407118035903, 0.12232931045394753, 0.10544392821048537, 0.112487401873354, 0.13621789463345083, 0.11725689675058089, 0.2766485986930709, 0.16194738657964816, 0.25242433162225836, 0.3959217469298071, 0.6640361874334274, 0.44361568446601596, 0.4164801760306282, 0.27533249028267404, 0.2924390191272382, 0.4293266737893705, 0.37040807727363806, 0.4062455171538938, 0.4501228046513373, 0.3977976511082342, 0.4338425475983851, 0.30953396472238726, 0.40058602729151327, 27.138761551149432, 130.64529372799782, 150.43944851044688, 118.1012793510191, 115.80179768223917, 89.01761054992677, 72.39063632103705, 83.20329296973445, 105.16672242072322, 120.02870851947416, 113.96555577555011, 102.48186003777289, 95.74958232141311, 111.34227460430516, 120.99584733286213, 104.22005837963474, 90.67062285638626, 74.64701898636358, 77.5202492744692, 62.16127534066478, 51.79457256870886, 35.43581785694246, 25.89941809254308, 16.030495474415442, 5.738815386449137, 1.9664764860945365, 0.3164445680956687, 0.14345676668228644, 0.6237702384110421, 0.4252944159651957, 1.0408763082758075, 0.7948270692459999, 0.5413410776565152, 0.2457420990592049, 0.12140556929572938, 0.29380627156746003, 0.18906999409439104, 0.1520788411219274, 0.27221104971343474, 0.3253037927131499, 0.1913478952502051, 0.1712851863234274, 0.19284928968596846, 0.16533136548053834, 0.1899123230888959, 0.19489673627240045, 0.13346109659441058, 0.4738725108965751, 3.048107936497658, 0.16356210074117108, 0.13413905376388183, 0.15789392344172926, 0.10952308593738465, 0.1945555360326844, 0.18208517212300532, 0.1295533587014483, 0.2343488394493057, 0.15181055713084438, 0.2571126211795115, 0.10550834854403812, 0.23261516715490052, 0.19174520376949541, 0.1805583895334313, 0.3002277431228469, 0.2781538695337311, 0.8348295453094667, 0.5136525456703479, 1.3603102127390525, 0.8264939571099897, 5.75322078120324, 0.6709821534252937, 1.5778875182713232, 2.090816233427294, 3.1071668190340844, 6.869247863369604, 9.676363660443215, 12.394249458466808, 17.11280684317312, 21.627196035077496, 31.7926537606024, 51.11143689001761, 66.26700062905589, 60.71414824455016, 66.65679008729997, 75.45818082747921, 61.92205390622539, 43.28977969384963, 48.212013013901256, 61.72672379401423, 88.26898697883853, 97.58098402330953, 101.2085174745129, 45.079490523184504, 1.8245549596125081, 1.0345116498008853, 0.23892362541969747, 0.12204716027143503, 0.2521155675452563, 0.26782614629595514, 0.19865163962446875, 0.30099876465335973, 0.11697961888726681, 0.19388782911964003, 0.11845058431067776, 0.19666874360653663, 0.1368399273844496, 0.1328065817154223, 0.3788962395441148, 0.26756380714716455, 0.3414876452617107, 0.23802725658301385, 0.123601391791336, 0.3254202074341236, 0.15005529647873295, 0.181287000436456, 0.21622791826244325, 0.21071395446215907, 0.10735428336286738, 0.16780460373528544, 0.11798937639762318, 0.11418825496108302, 0.14364222124699624, 0.19031988186461313, 0.19237261445772266, 0.17607331245897279, 0.1818211475807813, 0.2426684164111653, 0.18906518306222656, 0.18319432954153708, 0.1733787207593841, 0.1706124079083243, 0.15207547033506055, 0.10636654321945484], [0.06948487187225012, 0.022565730764800986, 0.02622645318267807, 0.012153311718946264, 0.0704430333609062, 0.052263862678721074, 0.0853907800610027, 0.0351083003765633, 0.03508891835207901, 0.01444726816243342, 0.026254603083455758, 0.03530791990699307, 0.03310340614388547, 0.017840293604099465, 0.059434641002407, 0.01738993541127251, 0.04229295255255796, 0.06245990689363211, 0.022862524717986103, 0.11911963953846887, 0.020804659335783893, 0.014990563354184552, 0.0602311043128852, 0.040760083394425536, 0.027333551739913323, 0.004446595520412009, 0.05106480867271462, 0.03353387477897829, 0.029067291067011898, 0.08167694668255507, 0.08251942123376554, 0.24217281881118977, 0.0524719053458783, 0.13291674515893384, 0.3014824112817165, 0.06247006521950807, 0.2562428509155589, 0.18941994305820237, 0.036786527057448705, 0.1787482923076999, 0.06649149056043356, 0.15880619626372092, 0.04908850484137093, 0.29067536215147666, 0.9101569484318457, 33.44649368716825, 109.08898276667442, 112.1174918451617, 85.17636283751457, 69.62876996686383, 56.330966257279925, 29.96149720684175, 49.72413378377115, 70.28513939149919, 92.62029970845869, 100.76690566155219, 86.18588678298458, 82.40213317255821, 73.08332689346807, 64.38988370280113, 51.85861702888243, 44.682562351226814, 33.82245679055491, 31.86878892683214, 18.655180854182092, 5.321139347168708, 2.3402429396106355, 2.7654183055123975, 1.1696039620907077, 0.05682503143625875, 0.015289120267205423, 0.10498050630332963, 0.6256208616879679, 0.7974139949487102, 0.34964672680343356, 0.699776824443571, 0.24739481118177217, 0.15147615975189596, 0.064835392329241, 0.013789759794881028, 0.06305053770061463, 0.025888888030162743, 0.0450569786311638, 0.0618127043238811, 0.08055157884354554, 0.04899461693581074, 0.03260208969755519, 0.061321749216726715, 0.04094610869463894, 0.02969713408439871, 0.061287007129360596, 2.1321263909339905, 0.1477587640646004, 0.12482992869110839, 0.11664421793313758, 0.026601271275731347, 0.03598873458442188, 0.055084449028776544, 0.02945680272645287, 0.06353886129574911, 0.0447947658868807, 0.020799440361799735, 0.015839930781493747, 0.05280249909828267, 0.1252274440541383, 0.03633504846103249, 0.01571067738451905, 0.1006487004398819, 0.07639980364230371, 0.3239161316906253, 0.46779253069431553, 0.32532030956879743, 0.2536274727073408, 0.3716841958943875, 2.2224374932627526, 0.30212371880489014, 1.9093436098867849, 4.127719979132376, 8.848371909510705, 11.201242919891111, 7.140848953877726, 6.480513032405607, 6.55914576784257, 8.964605466012033, 17.06471074012018, 30.013931451305268, 29.961612916761833, 20.025337319220267, 21.953943198727025, 42.40042148097869, 63.95381027652372, 71.39766477769422, 68.2521749311878, 34.04593383112262, 2.875950206671992, 0.28277086694875075, 0.17094706575716698, 0.04545679225796654, 0.17030647835664212, 0.049116283189505346, 0.025106947831509095, 0.06954896278799542, 0.1362717965798032, 0.0638612962117599, 0.10832981972564613, 0.01745321618903789, 0.0784684555424798, 0.021496408003112002, 0.08189011830836535, 0.025353448112465204, 0.03724783073149381, 0.05944777557986879, 0.012650810174583908, 0.13021977858677988, 0.1359297996086459, 0.05762406880216253, 0.05439492393164866, 0.044386873862916426, 0.027626339053254456, 0.035102393838667104, 0.03655688071082677, 0.032669493943573005, 0.017476420992264347, 0.026542098644459923, 0.03244318774030094, 0.0449517066590488, 0.07956154809723939, 0.04117082909590775, 0.08613219995412134, 0.08495548890242655, 0.07253878945184332, 0.02182405997788714, 0.04681578243992502, 0.03283815969142222, 0.049259330957166614, 0.009881803566860336, 0.038431654909565564, 0.03425354926636623, 0.06228061167583351, 0.010351422167713604, 0.019997363542056373, 0.035355068788292913, 0.09663939460991852, 0.07046695828678147, 0.025296728877771287, 0.0953868868189954, 0.03431121270442682, 0.02604989481398896, 0.05096087352402749, 0.02640458777727139, 0.011771368050587275, 0.03658494634193279, 0.022606758603585825, 0.054428130012726596, 0.03157415675119527, 0.032277180317548976, 0.06028905503391739, 0.06965048475972108, 0.02156086281062134, 0.053203718496426466, 0.02010289406884582, 0.024608289710276073, 0.06569582398139662, 0.05490775084904125, 0.06499049449039083, 0.024749791895550106, 0.3195860188814902, 0.3332753359310089, 0.08739028486513323, 0.18713667928691835, 0.26076961849485675, 0.14910942304038233, 0.41466270903906516, 0.2476365732089166, 0.3660503546557119, 0.09511025246953773, 0.24759422386846236, 0.09624990784833509, 0.07909240351328928, 2.4824923517242556, 15.910255216783094, 82.94121588430097, 125.62433827307918, 111.23732766797467, 77.8617229769307, 61.558144246378255, 75.31320218117007, 72.81027501629245, 93.26784380020635, 93.6488079255627, 101.01141837335403, 96.12758113491921, 98.95389203102359, 96.77424661574825, 89.38485422442037, 87.5460627771193, 67.8322224463186, 68.69030367943549, 62.885089920413115, 43.93579798360025, 33.542952614445845, 15.732267864288824, 4.683950312675969, 3.2482753117238325, 1.9220373803569426, 1.2332677072094334, 0.1450146064763108, 0.15477635927738684, 0.22960335376762578, 0.12797798315483716, 0.28981958065302144, 0.5353816490500204, 0.13668359948262093, 0.03779727282122739, 0.13761978956960863, 0.07449766861334925, 0.07070029334675881, 0.08678133689588116, 0.06697539765868457, 0.04171185954023273, 0.1055618597855491, 0.10125197169761505, 0.09494520648713074, 0.011966081745471927, 0.024383205417243224, 0.01515938423483843, 0.1881125220848668, 3.1600658643630246, 0.4827744525767142, 0.034457512515326666, 0.06786112553409993, 0.1094563213747836, 0.13946832908738044, 0.038791486407600106, 0.02036273194056365, 0.09431709865889243, 0.09212437881937913, 0.06834673334754283, 0.02231235101428484, 0.07095662636622306, 0.1334523325485568, 0.04444899593269633, 0.03234399850630472, 0.09679019901781313, 0.3405518841839606, 0.6727759636217548, 0.24742254356463111, 0.15760967417830424, 0.13414112220127739, 0.30370403561861287, 2.645127792512217, 1.0641107131396572, 2.671156640975706, 4.218399293961064, 9.286377103097978, 9.892196001545075, 9.207668862035199, 18.64029153700798, 32.95946474998228, 39.532262817505874, 41.61286838593022, 41.91974286110171, 47.447601902869444, 51.52089311230568, 45.68592033078594, 40.00006037373697, 55.84718896496681, 71.43313869353264, 86.20410227006482, 62.14106336716683, 18.126539491838027, 1.4564532666437089, 0.3687785776151765, 0.12223569450960045, 0.14769879470188774, 0.1096548530603609, 0.07032525500342732, 0.06406971809243964, 0.13567020305462424, 0.08997041536795516, 0.12079341141807458, 0.03918989809350141, 0.02556821128593818, 0.032818233744511684, 0.03427519508066677, 0.1474423237865971, 0.07671368518663992, 0.025889223193629615, 0.0888809617308359, 0.11617451410500274, 0.05561957676564494, 0.05138217208666667, 0.05051267761436682, 0.009013100080342304, 0.09888157308582338, 0.020967200210678483, 0.0572951297996746, 0.03804602923112051, 0.0196840048527285, 0.009711993475174232, 0.03825603308336389, 0.01047810917014196, 0.1170367077593842, 0.036226126079958294, 0.06261868244637886, 0.09815798771958198, 0.007946721490307321, 0.06759628893867617, 0.04405067234690632, 0.029243129313052185, 0.047272374673235806, 0.024222595083917824, 0.19041648555186488, 0.13112661218450916, 0.12331020943219624, 0.09126609987429074, 0.22338719377594612, 0.09781909340451803, 0.22863979901998277, 0.1393982013987918, 0.13320762874378314, 0.16378699351222287, 0.1443761641219739, 0.09978518145339144, 0.08113735265308812, 0.11621008356732708, 0.16930946088846655, 0.15497753396630287, 0.13938539240869785, 0.20298495468112732, 0.12447457114655165, 0.19226671046307012, 0.13275700050496286, 0.10095616982829186, 0.11314548672206941, 0.18423194966969952, 0.0653137835944372, 0.08747261633435566, 0.23489023378539473, 0.25400628786413904, 0.38324587227356055, 0.567320283622511, 0.5695826331934621, 0.49712309553738565, 0.25484818784940627, 0.34787329454575816, 0.3946353320873553, 0.4429815168822966, 0.5620380154540462, 0.5248380728786992, 0.42682610151748507, 0.298388856312921, 0.3406011896027673, 0.2736197934756356, 0.19098853872668362, 0.8766227672176977, 3.371316141659214, 60.92609351681125, 149.36048292344617, 142.10979338615172, 105.3051507088446, 90.41400571023264, 81.72951729066911, 52.150288397266024, 71.32721116465908, 91.08543703632971, 117.09875291393651, 123.97453446542065, 111.19883352710356, 105.79991848238053, 101.77126776787543, 99.28100201391406, 88.87036477365803, 96.12214472986038, 89.65734912503152, 72.63269362911102, 56.69308339395831, 33.81885605473673, 12.487048814373633, 5.188355840021565, 2.8803116371554713, 1.8958763970482735, 0.18511589256025132, 0.5064562221448268, 0.7572410183568156, 1.0536590675192496, 1.8149549586157647, 1.1753075786175267, 0.5452588513012856, 0.3549375138696163, 0.14817936165678888, 0.2039278863418487, 0.22390536032617095, 0.15467787101384134, 0.13297763382715563, 0.14874815129705016, 0.17576362907646165, 0.22340346548345782, 0.20114553160965445, 0.12430062322246453, 0.16978759168376847, 0.2619169117702592, 0.5933797143159375, 4.494916585183913, 0.41815138151568754, 0.15614364236112566, 0.27639640254839776, 0.27559669868599984, 0.25216392301503693, 0.1649217382674256, 0.1936888760857044, 0.18202056026747152, 0.23092542234207356, 0.130232434359289, 0.0904751064315919, 0.18512297121267166, 0.23158286367693257, 0.1955362358280728, 0.17055403200849412, 0.5986520539849036, 0.6376594124782471, 1.2060101762894662, 1.302478664344357, 0.46889949710138384, 0.4079137808613239, 0.4354596059889563, 7.190551757812501, 8.93327945663083, 18.044544304570845, 15.18890976905823, 21.274300390674224, 27.385808114082586, 34.49975990479992, 35.10786064209477, 40.41749077458536, 47.248172913828206, 52.69802385760892, 61.62545604090537, 50.94819568818616, 44.92013246782365, 45.78482681705106, 62.404638798006125, 79.84314749317785, 92.97121063355478, 97.49888097086261, 56.76282313562209, 7.477045597568636, 0.5423582585588579, 0.3515865533582626, 0.45452897466959497, 0.32643671417909287, 0.17523818469095617, 0.2231437923206437, 0.29204822235530425, 0.5644581791373992, 0.3483671761087833, 0.3177993179809663, 0.12749502600561227, 0.14690374865406944, 0.18635356888896037, 0.23598794585033772, 0.2186780972706695, 0.202780868858099, 0.13921795623196712, 0.2160055382597831, 0.21278084436010933, 0.19692057202900612, 0.1522885040650445, 0.29192154205614523, 0.1343511681883566, 0.19212006591260436, 0.09740459387220683, 0.14536602632893672, 0.13102538132619473, 0.09592989760060465, 0.12084917495808295, 0.11270943713644821, 0.11795068129656777, 0.24301223667158237, 0.1897094936500634, 0.22201744388909112, 0.21368689654815584, 0.1331846461060547, 0.13445344092624803, 0.20387743179115558, 0.22955588695983734, 0.24015604638524596, 0.11826385804001363], [0.1272776332353392, 0.029265600587091142, 0.021676683813453685, 0.05334856657070979, 0.03705683735109145, 0.034999565687030554, 0.08221779709621783, 0.02103391880800407, 0.049710173700605674, 0.05829810360146146, 0.006337820499714825, 0.10332341981871475, 0.06549739954812873, 0.08548956709883868, 0.04477832947046526, 0.0775791576973373, 0.00785355897425043, 0.041421925904409546, 0.02832752975424932, 0.05475943239646093, 0.0029058624697368475, 0.07826461486758725, 0.02012892190607325, 0.02670215164882041, 0.08245182929620629, 0.09955105732285208, 0.03247194668097842, 0.013892291087446915, 0.01739877989635833, 0.08438079272426906, 0.09631930775339566, 0.10457683159338851, 0.1461902450049116, 0.11979491540020513, 0.12233877930069163, 0.1291135323023604, 0.1509092546879284, 0.21655859245407968, 0.11635632209119298, 0.10436544495244181, 0.08571558601913914, 0.046429555382459395, 0.09020967228758721, 0.011432451710495497, 0.11114522349089385, 0.5633422648233752, 5.782671407345803, 57.60453239563973, 112.10648567445817, 103.56767408309445, 94.6101337863553, 75.84160035656345, 54.50538927508939, 49.57731946822136, 41.58025387794741, 45.559368979546335, 59.9230218702747, 59.86857544991278, 59.713198600276826, 48.178445369966575, 48.126281769044944, 47.4743289332236, 41.46784267117901, 20.650908293262606, 6.743859985182363, 5.049530902216512, 9.179734722260507, 2.9814433330489747, 3.151826680667939, 1.7578372815924308, 0.36545323508401073, 0.4363496162958684, 0.30940474101131965, 0.7238444878209023, 1.5394142149917542, 2.9544939533356698, 2.967227928100094, 0.3220367647947804, 0.4582079740301256, 0.2965259449856897, 0.05023424295828708, 0.15167050093652742, 0.19076462654817491, 0.03408962560276832, 0.0059751717133387445, 0.07422581465253908, 0.05345333675523439, 0.039774993915231004, 0.07440563081012619, 0.23013042225953073, 0.0997430083131598, 3.1453672724385418, 0.312281217305891, 0.022490135123652798, 0.07718636909680021, 0.10790252652499946, 0.01996670853376629, 0.03777088875311517, 0.04458812899106453, 0.013669391102608175, 0.057543870887809226, 0.01742669230987949, 0.05675333709786496, 0.02155386842787266, 0.04072246464690374, 0.042124635374714295, 0.08017211251201169, 0.17102526801247753, 0.36291889365642305, 0.20798838216691248, 0.23349408450866901, 0.21531304074150903, 0.8928170692055457, 0.33480959553872386, 1.550526779986197, 2.1831583880609085, 4.847562668784972, 7.574755270634928, 4.755617899279441, 1.8896618918065105, 3.8232702641717853, 6.4814127260638825, 11.71637171699155, 16.04316963303474, 25.26526301137863, 18.768717781189952, 16.837819276317475, 36.13269359834733, 57.811253070831306, 63.962819960809526, 67.36149095719861, 41.843503752062404, 5.055490943693346, 0.04339190951037792, 0.27240919069417063, 0.1841286197304726, 0.13425598942464398, 0.06223175824890214, 0.04026132185132273, 0.09955809000999698, 0.10172604222691829, 0.23151475846046404, 0.13908579074327024, 0.05360574611733037, 0.021696703606134942, 0.07418369513846214, 0.06275624885494191, 0.0065643637114384725, 0.02845598929261248, 0.03330632368282926, 0.014320923026741273, 0.055400184505889495, 0.041093844920396805, 0.04757812802469538, 0.10858547858773701, 0.1163906887954762, 0.12748197186738253, 0.11969910078351537, 0.15144592992240383, 0.06923705008962462, 0.015910243288794115, 0.049720286061206174, 0.05727401641648143, 0.036524413904595765, 0.034043897814568014, 0.05863444301329794, 0.030959662305371418, 0.05442925999241491, 0.04749712571802159, 0.03888246317904803, 0.020932189992538864, 0.06990783667612462, 0.05272620440190358, 0.04148808142711078, 0.020291271258986766, 0.06566570906509316, 0.03400594964923878, 0.02190827027774386, 0.037338478085134304, 0.07802128236019805, 0.05016817936613675, 0.03940473213010738, 0.07764067455765701, 0.048298350264949184, 0.013723248041294997, 0.03941027860667917, 0.03545290587710277, 0.0407800859501285, 0.049034809738758116, 0.1014900871462399, 0.026118655035632755, 0.08055934697509774, 0.04159801887468465, 0.008356918002508821, 0.034867614702952486, 0.022481811578355493, 0.03942975639215401, 0.04914337971938714, 0.04337882855907083, 0.05613528800407245, 0.15367337652752477, 0.04590376625738798, 0.012731416988366795, 0.046853791892288194, 0.09999969373306922, 0.1404253720876671, 0.23857381435171252, 0.20335540415779238, 0.04695065604943422, 0.1700835467706765, 0.20529041968045697, 0.2635834900842559, 0.22614101939384015, 0.46210782121746774, 0.24679439743199658, 0.11674995338844678, 0.11961076318496659, 0.16970886848866942, 0.06220854195435682, 0.2298549063984425, 0.13445615287749998, 3.5949745918473894, 34.4119615708628, 100.97628178135042, 117.53152370452882, 94.19622959629183, 77.71661097003569, 53.890420467622825, 64.67104704149308, 84.30099179667812, 89.24830082924136, 97.14608730808382, 92.78934601814517, 87.95955904068487, 85.63525661345452, 75.95071285001694, 78.94647798230572, 82.61553364415323, 62.92754957752844, 40.69243323418402, 27.563909215311853, 5.745266214493783, 5.518062922262377, 6.998785118902884, 4.31965773144076, 1.9476616118223438, 0.5450436725251137, 1.2237981250209193, 0.32969709245427964, 0.5162222190730034, 0.7270172562810683, 0.9529246954667954, 0.3283102588067132, 1.0725185587521524, 0.38387863025549923, 0.44466678774164575, 0.3216099006033713, 0.05159875280374, 0.08591571882847818, 0.07945594287687734, 0.010097331870647689, 0.09124088025982342, 0.04142798182945098, 0.03429403318272483, 0.04691117953869605, 0.3089399095023832, 0.13116016683559265, 1.7348199554028052, 0.6992211961938489, 0.11069995020666432, 0.08419161497224724, 0.23206415075448253, 0.02004119334742427, 0.07381945863486299, 0.06310782575559232, 0.02570750330755067, 0.1041348907916296, 0.08391905621054672, 0.12662981396480916, 0.0540511419756278, 0.06279184896078321, 0.06629699615821724, 0.17191610569434781, 0.27512481916816006, 0.2641873818732077, 0.18752683254499591, 0.2698930208721469, 0.39568318715018613, 0.6691966169784147, 4.473160668726891, 5.134924332941733, 1.3919085816990946, 5.979630283771023, 7.180314371662756, 7.99383600873332, 17.31334194060295, 21.045987067684052, 19.466634911875573, 18.216267631899928, 24.08564352220105, 40.597782519555864, 46.431005923978745, 42.413184873519405, 38.96052637407857, 48.877827505911554, 66.1214336272209, 82.74925508806783, 69.7397259742983, 25.293755108310332, 0.403928499548666, 0.17439910390925023, 0.22998785329682214, 0.06546432753243754, 0.11965384796982813, 0.05301752848730934, 0.18767078046596822, 0.07243848555991728, 0.24958291151110204, 0.10893920436501504, 0.1297451105088957, 0.11514891389637225, 0.12707767662622277, 0.11875016299346763, 0.036995669060777274, 0.018495369642492265, 0.023257640310593193, 0.13682106629975382, 0.02525204679958763, 0.04949894793812306, 0.0667510258274213, 0.11210334667515372, 0.15972966929116558, 0.14782006642030132, 0.0804371023250203, 0.12416741585419064, 0.14448539293821783, 0.044157599068937764, 0.08553524126088427, 0.052039517660535155, 0.07106993843110339, 0.05388430717791762, 0.026398646765418594, 0.03701240425148318, 0.07265412398884374, 0.047466803957978566, 0.07040034694176528, 0.04410424870589087, 0.07564728313516225, 0.03363251242966902, 0.10003007678014618, 0.008832581037084663, 0.05583421544983022, 0.21310862273939196, 0.09426764002250088, 0.18463371682070917, 0.148809514939785, 0.15231000049219978, 0.16185467461905173, 0.21206798422480785, 0.16023020049737347, 0.11733780329626416, 0.13186640797122834, 0.12835535040545848, 0.21899870506698088, 0.22357036539864159, 0.21130830079557436, 0.21365706508438434, 0.15783099697962885, 0.15101728840701042, 0.15711623694627516, 0.07735969648966867, 0.10032997721986425, 0.058526244585312186, 0.11506542563438417, 0.14878527591786078, 0.10960279738590603, 0.22031826087303702, 0.21412618668569675, 0.2621628566374702, 0.39645230878264676, 0.43791540808254675, 0.43951181274267936, 0.45647827007116815, 0.36553373560309416, 0.25564910213072456, 0.30090398425536774, 0.5369673284792131, 0.516651718606872, 0.5698347680511013, 0.5777404277074722, 0.4382423437651127, 0.17001557945003434, 0.20387507224034881, 0.17499426229586526, 0.2425526605258065, 0.4286679913920741, 0.1808546050902336, 0.86591990604516, 13.290273739445595, 92.45386569730698, 151.83935811442714, 129.48389560945574, 111.16186911059965, 93.87251638597058, 76.0000954904864, 73.98341671113046, 66.11200424932665, 74.2178253973684, 88.56898553909795, 95.10921616708079, 91.94250629794215, 84.72072462881766, 86.62410966811642, 91.77789226655038, 91.59867917337726, 73.91506548850768, 61.10510656910559, 40.47260399787657, 19.380297660827637, 13.369771357505554, 8.828148168902244, 9.276127949837717, 4.300997055345967, 0.9822405514217193, 0.2081579787115897, 0.8248450907488024, 3.1251575052738194, 4.798813000802071, 3.90759484902505, 1.6882443836619778, 1.466445382083616, 0.8438441938450261, 0.5180578270266133, 0.2577994956124214, 0.27071641217316356, 0.17347822025898965, 0.2019995817494008, 0.19736099597667495, 0.14537544921040535, 0.11311154902702379, 0.21595411843830542, 0.4423932532870001, 0.25077869815211146, 6.991684648298449, 0.5485368495987308, 0.28006737330748194, 0.21506567095075885, 0.2983029012478167, 0.1820117349345838, 0.18926571423728622, 0.16513420509234553, 0.09664337060624555, 0.33671813506272535, 0.29244686386758284, 0.29102748680499296, 0.19871159366542296, 0.2118643580545341, 0.2730038894280311, 0.30373670160770416, 0.3520360018216795, 0.6992911246995772, 0.9122674900197214, 0.773690335692898, 0.465646657131372, 2.0178905465910515, 9.64055928491777, 14.13032187569526, 19.679925557105772, 22.26936059613382, 28.832882258199877, 30.055294805957427, 35.319190102238814, 28.935844475223174, 24.21540533342669, 32.81068336579108, 42.08253691273351, 55.12945405898556, 43.04735760534964, 42.20582092961958, 58.77770546943911, 78.08401153933617, 87.30297780806019, 99.51941151772776, 67.17421347095122, 13.864777415029465, 0.1288112646509563, 0.6574284645818895, 0.3046549958807807, 0.2780516427611151, 0.39796039882686834, 0.15778189074368248, 0.16558507847930157, 0.23240896692920118, 0.32731406871349583, 0.3405696574238039, 0.23478713367254506, 0.182688680867995, 0.3360446518467319, 0.29673367738723755, 0.15318979118620196, 0.13060820048614857, 0.16946021167020645, 0.29389688444714396, 0.18377732245191453, 0.3377042434388592, 0.168452407684057, 0.1997193823298139, 0.32329296512949857, 0.2710536134339148, 0.3212437105755652, 0.4869615827356616, 0.27377181596332983, 0.19133039780201452, 0.22760697460222631, 0.15260856027805036, 0.229241622371539, 0.1111696080695237, 0.20034771232355028, 0.15311797810417993, 0.19448822754765713, 0.15020768668863083, 0.17350396081324548, 0.1652411203230581, 0.15940495526358006, 0.15421523051636835, 0.22152429777047328, 0.06450793570688655, 0.12420325344728848], [0.02109674567867431, 0.020061854738742113, 0.026614842523309975, 0.0103149286118306, 0.036648527809208443, 0.07840144583174298, 0.06547908238585919, 0.02766780930781557, 0.06118673388095153, 0.02630309261862309, 0.12061793131813889, 0.02356620711995469, 0.04614397695648574, 0.12288810264679695, 0.018925681229560606, 0.06499933514503703, 0.03581038165477014, 0.03920576377441326, 0.05112585438896091, 0.04800208491243182, 0.04251251335165674, 0.06483334687448318, 0.04225578196647187, 0.0344376708380878, 0.15117969904695788, 0.014955899790830672, 0.08318594837140653, 0.1637452110768326, 0.2769132054621174, 0.1610364927159202, 0.11522556099319652, 0.1205130385595464, 0.15835236577737719, 0.20226786574048383, 0.07912103987989888, 0.21370761156562837, 0.1264358328415021, 0.0843167630955577, 0.013949121404889853, 0.04925810521648777, 0.03984017650626841, 0.01277181376222401, 0.03910431458104042, 0.2588308644631217, 0.07403461442839715, 0.035023084586305965, 0.2759409785991715, 0.29411325832047774, 12.893879009831338, 63.99771336586245, 117.18868501724737, 118.4130685560165, 89.50194481880435, 87.56630220720845, 62.21044225077476, 33.79151321226551, 24.375363511423913, 27.91976232682505, 42.05869674682617, 53.88856126416115, 58.18290941176876, 27.89531223235592, 19.1503643989563, 17.556758349941624, 14.678449573055392, 6.020565119481856, 4.542787642248215, 7.595752698759879, 3.5616243943091366, 3.547749745268976, 3.7301431452074363, 2.6632243827466042, 2.704791945795859, 0.9024515748023988, 2.743270887482551, 3.7169607945026892, 6.443884468847706, 3.4132332859500765, 0.5634073516534222, 0.10934144649053774, 0.05991981980661231, 0.22511089160557718, 0.2806085071736767, 0.08581428878730343, 0.15195062864691983, 0.07689290379564609, 0.012548169714488812, 0.01680770667359954, 0.021575000963263938, 0.11679478485377566, 0.5334387274999772, 0.28084277686092163, 1.1304899641583044, 0.12579311571654775, 0.09210249934826167, 0.04922318309845944, 0.13066813920534429, 0.022060438322143692, 0.016318900443072763, 0.031216297929565755, 0.08238207699070055, 0.0385235280038849, 0.047695580794806444, 0.1622685612810235, 0.23076049893373446, 0.15018792162018438, 0.06670249415741814, 0.028538163713810426, 0.1143094500707042, 0.05514419239555156, 0.38404658737201847, 0.6581429488235905, 1.5872985100553882, 0.574321775667129, 3.8632338229686987, 6.76013978258256, 5.1409201660463895, 1.9158481253731636, 6.0063602559028135, 6.382696474752119, 9.314162192806121, 12.494554269698359, 16.21843780240705, 14.047098986564146, 11.523884342562768, 38.041048280654415, 44.86033593454669, 51.164353586012325, 64.98446795248216, 56.66652110315139, 12.309499786746118, 0.36242188645466683, 0.3131291540640016, 0.023739900319806995, 0.1510101944328316, 0.05271790766968362, 0.10775363733691555, 0.04342294373219052, 0.14419391180478758, 0.032286358050881855, 0.12136043139523077, 0.04837449174374343, 0.06352856124360716, 0.0902291079382262, 0.07133400127772363, 0.040445374475131114, 0.15335537343015596, 0.05682852096675385, 0.12196675934378179, 0.026941353027077935, 0.06768646514824322, 0.05669735905323779, 0.04193513586576428, 0.10000972182399805, 0.12667377975078362, 0.13219838451233604, 0.0966339860291731, 0.22556181095780867, 0.2924940548837185, 0.176327561719283, 0.14032381947242445, 0.04680226098806147, 0.024446543651602926, 0.01071183493496069, 0.031621094958315936, 0.07672483942681745, 0.0657471671940819, 0.04242635144281291, 0.026783996652210915, 0.11456372997453136, 0.00755523476043656, 0.05308719652314341, 0.07371940755195196, 0.029769912437205354, 0.0334370527566681, 0.03261053581692038, 0.015153776471232696, 0.048993479295243184, 0.05057568451569927, 0.07284808212951308, 0.045813842856835936, 0.044411932598919644, 0.04255135400941776, 0.024125445559020006, 0.03697173647402275, 0.11397495310032561, 0.11741979002592065, 0.0776945611822509, 0.052795159975968065, 0.029442572643259363, 0.03538441378623247, 0.03931366342810854, 0.044836674726778464, 0.0896323407669702, 0.05040306958460039, 0.07030273201845347, 0.04446157892685264, 0.023319463606082627, 0.06851104388554251, 0.029648889697367148, 0.17255096275719906, 0.2231697014142429, 0.15078516376595344, 0.21136333655205466, 0.17978678577609603, 0.14381750216407163, 0.22503308771598726, 0.11952868452475918, 0.201778442809178, 0.2419714602611719, 0.2237049210816622, 0.25156432131846107, 0.17614851164962017, 0.1433362763735556, 0.20144638965927786, 0.0967416903304477, 0.052011628229651725, 0.05771423352041072, 0.036104164882412845, 0.09123809936065828, 0.055037962813531204, 0.20007844773992417, 0.9114065297668981, 2.555775464542451, 47.17311836058094, 103.41579206528203, 119.84740088062902, 104.39947543605682, 74.70721167902794, 70.12752286849484, 61.80728535498343, 59.40499444161693, 68.05330291871103, 67.38901030632758, 72.73636187276533, 73.86015230609526, 73.09726699706047, 65.8824828363234, 63.58192643811626, 55.77858278828283, 39.037640171666304, 18.066888086257443, 1.270430816277381, 6.363612672974987, 7.670863145782103, 5.969564501316317, 3.042894125946107, 7.454786146840743, 7.003601299178216, 1.2445014979570144, 2.693100586052864, 4.701574502452727, 8.14530666797392, 3.233258027222849, 0.9587475765616664, 0.3048861705728116, 0.23398931438644088, 0.1416308114365224, 0.19307402923943537, 0.034695991855715556, 0.24111229265409134, 0.0577498451175709, 0.1321678635694327, 0.0673392741009593, 0.022075143379850254, 0.03712643643901233, 0.4973083968845106, 0.9074053444689321, 0.7661189355196492, 0.10612658149893246, 0.07463856750438291, 0.10619316986131092, 0.20536635431551165, 0.09879640709128111, 0.08697177869297805, 0.03092736212326394, 0.05916908811477404, 0.04881803749970371, 0.310416957663913, 0.28404925318975605, 0.32231586594735423, 0.06584178671360978, 0.14187752239165768, 0.20247201285054608, 0.1636387248553576, 0.18557598964581568, 0.14562416731590225, 0.3947573239284177, 2.416809811707466, 2.563789111952628, 2.8495129414143103, 3.6305232778672254, 4.68903027234539, 18.89447485246966, 24.775572746030747, 23.1989505598622, 16.39391876036121, 17.407019907428374, 31.807801954207886, 40.61151081515897, 44.474739490016816, 44.00249788838048, 45.65493752879482, 62.15348551350256, 83.34312546637751, 78.89558915169009, 39.04185671960154, 3.3782464794574247, 0.596565843349503, 0.13433224581662687, 0.12347664969462542, 0.1561599906774298, 0.07651500794435702, 0.06232136372296561, 0.05964713080996468, 0.037030625652762196, 0.17279820997388134, 0.05217028120833059, 0.10832703116560176, 0.17738339941828482, 0.23079917105215214, 0.16578824499682074, 0.23702450877716466, 0.08867653882912091, 0.061035799238109784, 0.07217908052787667, 0.0252092492976977, 0.02917314335072954, 0.04264436091386503, 0.12218104945796153, 0.11877136830721172, 0.14022727707220664, 0.205435210298146, 0.2568496385168645, 0.3943772217439067, 0.30958691671971356, 0.1520155929028988, 0.12627267143538884, 0.12319806948184006, 0.04579022436613037, 0.023140541856147112, 0.06085327879014996, 0.02449940563359809, 0.06877098517913012, 0.03310927437738546, 0.08245886198335117, 0.008971066751156845, 0.08061055995283589, 0.03732331337467317, 0.0226732780180511, 0.06605545629657085, 0.02094328486090226, 0.1254180160861823, 0.2286909583715662, 0.17885609620040466, 0.1283140812489775, 0.20009786040792543, 0.11994958089123811, 0.17195113123424594, 0.14991249768964707, 0.1069985964005032, 0.24369875870404706, 0.2379837734324317, 0.21403387309082095, 0.177977332064221, 0.1718500076282409, 0.11644609227416017, 0.11540458808022162, 0.2503281771656006, 0.2982026663038039, 0.2129454460115202, 0.15147793707588028, 0.15664333087061683, 0.17522202023575384, 0.17822206651251163, 0.16137033851156313, 0.4568033671427158, 0.5238492678730718, 0.3801274347689844, 0.48024924291718396, 0.5247082056537752, 0.26741503287226925, 0.4235395230352879, 0.3127936688402007, 0.5777583848084173, 0.6394805566918466, 0.35083220190098213, 0.3887497237132442, 0.23950027512206187, 0.20273767682092808, 0.28330026434794553, 0.18305257263202823, 0.15924567026236366, 0.12897471717048076, 0.17597604993610613, 0.631704580399298, 0.22235332747861264, 0.2638151550725583, 0.5485606289679005, 0.3304969801777794, 23.69620511608739, 103.68124238906368, 153.11688976903116, 143.3559303898965, 108.67723588020571, 105.17030746706071, 84.57389462378718, 58.78627192589545, 54.745724662657715, 51.88636779785157, 70.4010062063894, 91.46437721867716, 97.6227572656447, 78.63657151499103, 69.45803703800325, 74.71313445798813, 68.86579836568525, 54.02105500621181, 32.309114202376335, 19.913751771373136, 13.180025719827222, 16.042024300944423, 20.517855613462388, 20.693195366090347, 8.115653059174939, 0.6061520547636094, 5.140255324302181, 7.6428196699388575, 10.106112264817762, 7.217913721838306, 1.3078961929967328, 1.1862295409364085, 0.3619746443244719, 0.35222449009456946, 0.4141204413627425, 0.12582201255305162, 0.32019242343883364, 0.1671653952930243, 0.187386209445615, 0.12108355189763731, 0.13460737863375297, 0.20037463265320948, 0.7667539917653607, 5.547614549436878, 2.604502824044997, 0.1750101969246903, 0.19814461199266298, 0.215870461636974, 0.3639947568937656, 0.21391254008537341, 0.16923441491540403, 0.1572429019236757, 0.1786982514444859, 0.18470758301836832, 0.4284654071013774, 0.3452646732330323, 0.478344411258736, 0.8636448700581828, 0.6775964339894633, 0.21773614620249118, 0.20525104276114897, 0.33263402840783524, 1.4034169383587376, 2.1080131300034064, 12.967593093072216, 23.008097833202733, 22.96349067841807, 21.978440361638224, 36.17241936345255, 49.20726737668438, 46.522965892668694, 41.05542505941084, 39.528767985682336, 49.24909160983179, 49.487516803126184, 45.37658652951641, 40.617786607434674, 63.469338724690104, 68.88775579390988, 73.74867854579803, 95.44142523119527, 81.23121153923773, 25.22844764494127, 0.7665019794817894, 0.5990766505560567, 0.1570660581872348, 0.4509712929927534, 0.3318744981961866, 0.2239879139608914, 0.13215888501896014, 0.21795455786970355, 0.14962823310446355, 0.23096481458314005, 0.09280913884961799, 0.16788444541875394, 0.2539484941911313, 0.37433421659854155, 0.23874975410440277, 0.5892230438128595, 0.43766057659541413, 0.6585842154679761, 0.3411169199933929, 0.23602084166580634, 0.18356399760851938, 0.12535622343420982, 0.24194510683657663, 0.23801536689842903, 0.2579997509958283, 0.20328593530481864, 0.41918581471808497, 0.6567855023087994, 0.6046676828015236, 0.26546322470230443, 0.4042282237881615, 0.23061180126763162, 0.15941707477454217, 0.12507411921697278, 0.17109026291197346, 0.15809079271651086, 0.16276849493865045, 0.06617030053729973, 0.1814149677633278, 0.2610215082043602, 0.297679765330207, 0.16322906699872788, 0.07712065407465543, 0.10324422930998188, 0.14670804383293276], [0.032713620608011564, 0.02017508253395077, 0.030026525078761964, 0.07706685171973321, 0.007859228982500011, 0.046742199694797884, 0.014822687634507255, 0.0306254813462616, 0.027808495609450246, 0.031168197184019995, 0.033404578289557854, 0.022775183033738888, 0.03948882177111603, 0.027436540770013968, 0.10214546004370337, 0.028171688318252567, 0.046309428965492595, 0.047364454611294696, 0.02225502082447131, 0.05589352597692802, 0.09856657305311772, 0.05722880956806964, 0.036354124050347075, 0.08159212542757874, 0.03276607847862667, 0.21772122280972622, 0.09307352345316641, 0.05188427377311934, 0.08144328220477028, 0.16038562441545148, 0.07855458680780665, 0.0432982859051516, 0.15724449538655821, 0.1520453171143609, 0.14166505556673775, 0.07042959617871432, 0.0701963760319256, 0.0329901400442806, 0.1318138390178642, 0.07737566176201068, 0.024840513942763213, 0.06531687858965128, 0.04279715715036277, 0.1656220805260443, 0.05854844198291821, 0.16684909291084737, 0.0257620238699019, 0.025948234946436943, 1.0776835848246853, 0.33673495835354256, 9.871616305843476, 58.38518996392527, 126.01222930415985, 124.66589927673341, 102.96191892316266, 74.65123161192864, 61.83047440744216, 35.060733364474395, 19.8170006275177, 14.489961055017288, 30.41147935775019, 48.64586637866113, 41.06904745101929, 19.84111143696693, 2.619752754126826, 14.245179660858648, 19.31353499812465, 9.703490772554952, 5.510546680419676, 5.1014689668532345, 4.862012190203513, 0.4575680148216986, 3.7449829424581225, 6.398172676563264, 6.385785341262818, 5.224684832557555, 4.150271646438107, 1.172781817374691, 0.6718634609733859, 0.04653576964272126, 0.10018009977835803, 0.1158288935379636, 0.2662854515496762, 0.11838363588697488, 0.13153064695577468, 0.02524298206422358, 0.1088342656411471, 0.03474916601853986, 0.23054875223146332, 0.6577417638994033, 0.11390472582030682, 1.1476053489792732, 0.489836925220105, 0.28099755726514325, 0.22877201047395507, 0.28820834453067473, 0.03690628958265147, 0.1662182041834439, 0.047621695444949215, 0.01573599850563633, 0.21030690130447188, 0.1830620568005308, 0.25809869891212833, 0.2881417255247793, 0.19830360588046814, 0.25498966896726244, 0.27581230647140936, 0.21049312195710598, 0.5603733983251357, 0.4188422396058037, 0.5335282065695333, 3.7741793499838923, 4.026258558996262, 3.2450888762550973, 3.1348960149672727, 5.3141212463378915, 7.669603574660517, 8.267391420179798, 11.605416690149616, 15.658457682978725, 17.40796127626973, 14.605075755426961, 6.861012356896555, 22.333026547585767, 39.64358752773654, 36.207457896201845, 55.06869654501639, 62.16356208247524, 24.685819110562726, 0.7946402663665434, 0.1389357141189037, 0.033118279740935376, 0.07426238769004423, 0.03569684742439178, 0.09691721639565884, 0.016648944527391466, 0.057454721236060706, 0.04647476989175043, 0.06359234572418275, 0.03911105615477409, 0.07756418067841761, 0.080016604324262, 0.08817833653020282, 0.10438836630313628, 0.10189943856769994, 0.11401313492247175, 0.24141229268523956, 0.043745355665563576, 0.11899164156808008, 0.13558728169770012, 0.1203288940051871, 0.07484929530971474, 0.0437070589302288, 0.10435537855711677, 0.01273424385280739, 0.13941822693713252, 0.13597150543524375, 0.07932400721455775, 0.15253284014761448, 0.08715553254249596, 0.18262451334345728, 0.14915548024639008, 0.048244341066287416, 0.08490172485190053, 0.06663722346626944, 0.007621754653706787, 0.042230428286617806, 0.037865025637250756, 0.1186854745291414, 0.0036653945966052914, 0.05227279143347856, 0.02406954220796545, 0.010681943141765172, 0.026726518990471963, 0.024250737323816267, 0.054023122309797236, 0.08056002113247111, 0.041340479266739664, 0.03749386369881611, 0.05159539733863166, 0.049985360143886465, 0.03576710534792754, 0.026240171902182124, 0.019200762335751808, 0.012423474540663584, 0.010186177960056211, 0.09967609819385315, 0.07545727800818221, 0.03664193945305963, 0.038385927121365265, 0.04083388830505071, 0.05277275190418286, 0.037032016102344766, 0.07245138648056215, 0.02211951519242458, 0.0880041741014969, 0.04950496555876829, 0.034215919027525576, 0.10689761069032455, 0.2167508652013156, 0.35493015942554323, 0.3168152933639865, 0.22913453860148308, 0.019088178054399548, 0.11459760638254304, 0.1807005448086608, 0.04863876909498246, 0.24052490239902852, 0.24729293680960135, 0.23429896712543505, 0.24198852870012486, 0.22462768930821653, 0.13600196509111312, 0.1280780495595067, 0.14128049475050744, 0.031081521996266903, 0.08861529009957468, 0.07825670117932944, 0.08778153362894252, 0.18600705199904982, 0.08218219699037653, 0.12392599090573289, 0.029893434538896528, 0.05373809929756869, 3.4681150894011226, 5.514131236460901, 45.94099206309165, 96.48985124403431, 125.27739678659748, 115.12826396572976, 88.43899819158739, 67.41690620299309, 57.95729860182732, 58.03376128596645, 62.54408298000213, 65.1775505465846, 69.49881399831465, 59.37632976039764, 53.05532432371571, 48.622100737787065, 44.84280686224661, 43.94861628932338, 39.07536945035381, 21.360082626342777, 11.432961840783397, 4.63059970448094, 5.19527784278316, 1.0764069759076642, 6.766262112125275, 10.478686440375544, 5.606624157198015, 5.13728020652648, 8.128341926682381, 3.2688432403149146, 1.0521428262995136, 0.19459198649612167, 0.4141847314613481, 0.10856954395891198, 0.058466213935565566, 0.11715656987601712, 0.25691032800222596, 0.06968357975804998, 0.27460204076863104, 0.023856973876395536, 0.1194815471347782, 0.26292866877009796, 0.18140582067351188, 0.48985904983935824, 0.7746969139383686, 0.2302404631289744, 0.3440353166191809, 0.2915332886961199, 0.16139738141529023, 0.26918981344469134, 0.1670924484008743, 0.08968463392868158, 0.3128261203246732, 0.6016431063894303, 0.48735020381789057, 0.6484957568107114, 0.5539601392322971, 0.3093924223174972, 0.12448570240409144, 0.03994728325896206, 0.535514151617404, 0.4402002499949548, 0.506779695109975, 0.48714366651350455, 2.395749625659758, 3.404323622103661, 4.185783805385713, 15.949709357753878, 25.55168232610149, 24.564768883489794, 20.343604318557247, 24.96768455351553, 33.96874943087178, 41.713304596562544, 38.65871175642937, 41.37206623631139, 37.90220814366495, 53.368447134571696, 66.7211954055294, 76.34880204354563, 46.502887279756614, 8.893434059235359, 0.7664547271786198, 0.10506636177700375, 0.231261397862146, 0.08477218704478395, 0.057841373472324306, 0.08195642321821182, 0.03833658722860198, 0.0354845721214529, 0.056566898110172445, 0.03222276509228734, 0.08029297820382542, 0.1606108082999145, 0.08222584101942279, 0.07055875094186875, 0.16398427647448358, 0.17478622345914765, 0.3078896029581947, 0.21350449101338465, 0.14631179251497792, 0.12909588163658497, 0.0910330712494831, 0.0782786189548431, 0.04207631054845068, 0.06666715452147108, 0.06828860259584843, 0.07619264580669903, 0.0869838139342685, 0.2340235585166562, 0.2727112744844729, 0.46278133507697816, 0.2647050734489195, 0.2080077641913968, 0.1854014441731476, 0.1697152729837164, 0.033408270833352884, 0.011759976323153223, 0.015428533905275888, 0.015392859105861958, 0.010820961286944729, 0.014356349805189718, 0.08589388532263618, 0.004137782126499881, 0.029407836301552675, 0.05345427904338126, 0.0767175845741745, 0.032129191282776096, 0.2900877114265196, 0.09984427747587044, 0.13755975891986202, 0.10101240068193405, 0.11331544332807103, 0.07939608076647406, 0.20733939844273752, 0.13961376321892585, 0.11974373306598395, 0.11620976947127812, 0.17861203590948738, 0.1996831923362709, 0.14429586278575082, 0.15272682893180078, 0.21671482842535744, 0.07653235983584197, 0.16740541063970135, 0.222409374471153, 0.1439765879824277, 0.13936717483785846, 0.17447223466250206, 0.30168554715571866, 0.34968880035223504, 0.7271536812186242, 0.5243166427939169, 0.586173155855748, 0.5079766615263878, 0.1790960196165308, 0.22716969161504702, 0.45456709520470717, 0.4935492340835833, 0.6371005360157259, 0.4233212492639019, 0.41412611041338215, 0.5332669399438367, 0.2859419500154834, 0.28200306298751987, 0.232201004701276, 0.17788308792777602, 0.14205991260467038, 0.13041362947513982, 0.09972422383725645, 0.20078185435024, 0.41223240235159475, 0.1991337081117015, 0.6395082584311885, 0.13004097366525283, 0.12020962943713512, 1.4295366142065296, 0.7900370585341608, 21.229487311455514, 87.91923707531345, 165.31825373249671, 159.907281321864, 132.0704084827054, 102.12730130841656, 92.15179612559658, 68.69256296465474, 56.092337100736565, 47.784710007329146, 68.5805400725334, 86.4289717520437, 93.11164717520438, 71.25083477266374, 61.21314433313186, 59.48042554240073, 57.152220356848936, 52.18424043347759, 39.83441083661972, 31.5717968633098, 20.729271365750222, 17.024045567358694, 16.647670615103937, 13.772491889615214, 9.559975170320081, 9.182647082113451, 9.486942598896643, 4.500723163927756, 1.355440590170122, 0.28240216415255304, 0.4797344011885505, 0.2709809270116591, 0.36105613554677657, 0.16684248923294007, 0.2014619106006238, 0.20202861648173104, 0.3023085604992605, 0.13916868145667738, 0.25169457158734726, 1.133535439448972, 0.14140642428350064, 2.994795081115538, 1.0907650570715628, 0.5983732592674994, 0.3894316645399217, 0.39403940761281603, 0.19343550016562785, 0.4104151192211336, 0.12370282183251075, 0.11473265236183522, 0.7102007070376027, 1.110276887493749, 0.8563259724647769, 1.103761708063464, 0.6294269090698612, 0.2570766150470703, 0.365155901038839, 0.3014359250664711, 0.7168296964899187, 3.310001405977434, 6.4868854130468065, 14.765385966147146, 18.150052139835974, 18.921515672437607, 28.456536723721413, 50.35553732225972, 43.967812368946696, 38.796481086361794, 54.006785423524924, 57.8317121536501, 51.90496375483852, 47.5239194593122, 39.309699689188314, 54.08384823030042, 61.61976468178534, 60.53039696908767, 82.58909686919182, 86.65888540206417, 35.22715560851559, 2.3060788502616267, 0.18416332351344247, 0.10968353539224594, 0.4501116197676428, 0.19756828404722676, 0.32753326179039094, 0.11180815001529072, 0.22758940054524332, 0.2097807980833515, 0.2342827260614403, 0.12840684683572862, 0.17528632565611796, 0.13130196971037697, 0.18791438110413092, 0.1566617782678335, 0.2638697311762841, 0.3394797594556886, 0.4510906801348733, 0.3231027301761412, 0.3628940417641594, 0.5053717787227323, 0.319687387635631, 0.1812392884805318, 0.07953778404982821, 0.2749238589838628, 0.19085196057154288, 0.30595615025489564, 0.16739784169100946, 0.4961972936026512, 0.4939270686478385, 0.5712860450148582, 0.44926429587987166, 0.48170143918645003, 0.5010222072803205, 0.2510697349545456, 0.1081575342123547, 0.11000231989929754, 0.13540803244517696, 0.10675040689567405, 0.22979607084585776, 0.13175272052326512, 0.1889147080721394, 0.14042966218004305, 0.11008460540324451, 0.12442939494165683, 0.1795280778840665, 0.18803776722521554], [0.012405948364175858, 0.04130024432895645, 0.059277592977929505, 0.04490309454981358, 0.032560648171291236, 0.03799866584520187, 0.024664897862220966, 0.027713324506616885, 0.056645690253184694, 0.0160719788137583, 0.05054330580957955, 0.013949776410065113, 0.08029802672324643, 0.012834545829513622, 0.016794338439320846, 0.08493820595885478, 0.08795269299298526, 0.03278965100405678, 0.07307616182632985, 0.03757305420754898, 0.01748648547236958, 0.11172046359147757, 0.17892554973161992, 0.08897588002465426, 0.04192162590521959, 0.07345358270310587, 0.1670192257170716, 0.09579026275464604, 0.2557764872307739, 0.06951301794258818, 0.1590953025245859, 0.08249380325357761, 0.08108931894023573, 0.13858331367373466, 0.06871966494908256, 0.00723864270126327, 0.08561620909360149, 0.08709838238334464, 0.10411033001277717, 0.07242415971573322, 0.07548442816421871, 0.05939426050791818, 0.1435078953903529, 0.07787908878057234, 0.030723699563813787, 0.0416535449274365, 0.06833577062934637, 0.027173684511874473, 0.18033818522047612, 0.08655201613662705, 0.7227541914870663, 0.3508716094638071, 8.449915974370896, 49.22165070810626, 89.77602435696511, 93.85580708903652, 73.96067480887137, 57.522903949983665, 54.51727013434134, 31.293000675016838, 9.569713434865399, 11.158558707083426, 31.224347429890788, 31.829335766453898, 21.080294078396214, 12.071443296247914, 9.130862970505992, 14.934394032724443, 12.581865249141572, 6.321114282454214, 7.192193760025886, 12.13375504939787, 10.52084211380251, 5.4716299041625, 5.353547930717469, 9.299264050299122, 11.947795479528367, 3.8288461585198683, 0.386027476239589, 0.17731362413014137, 0.04769697507482864, 0.20965382667078128, 0.4206282050619203, 0.23553043814195743, 0.046759314099026304, 0.043803172321209026, 0.10689401773795967, 0.16619868426313325, 0.39634033737163393, 1.1206233645639112, 0.22131840397994365, 0.6577599661484842, 0.7700683945609678, 0.16256301483559996, 0.047750321607435905, 0.10435686476768986, 0.0611505055830123, 0.3123671417274783, 0.0926400479229708, 0.0850378969804414, 0.01441490286285238, 0.14293363588231225, 0.6817738807970478, 0.37768143860082476, 0.47120870060978404, 0.9259320471075274, 1.211919594676264, 2.0149382275919763, 2.416416839245827, 1.2887310020385252, 1.7425444505868422, 0.8062798998528912, 2.181750012020911, 1.9458049824160917, 7.991402668337669, 11.625308990478517, 7.057806493774538, 17.586825278497514, 18.038405795251172, 13.025693201249647, 11.759546226070775, 25.28814611896392, 27.510484572379823, 32.66993499571277, 39.43310137717955, 66.21631576168922, 40.6694128436427, 3.477511372297041, 0.1278524902919608, 0.0789011573238719, 0.03330414416268468, 0.08477392606437208, 0.030642105454218485, 0.06347816031906875, 0.09891682845209876, 0.08319133396951423, 0.07135224183120074, 0.0635401291712638, 0.08931883460571689, 0.026864047094638792, 0.05178410777701967, 0.10241536048030662, 0.032470943105797616, 0.08589757020555197, 0.05923545431165446, 0.024399048115517345, 0.11111490173085083, 0.06619005794486692, 0.23080917616044325, 0.18177460007850202, 0.15749627784375222, 0.2640098946229104, 0.039382913946023876, 0.026612841118607792, 0.07185836547925588, 0.07566095014373142, 0.05227894694995015, 0.0501273277275745, 0.14483140421009835, 0.10305712765623486, 0.07955806239718392, 0.3002831772450478, 0.11940121515503815, 0.1800025314573319, 0.1442837585965472, 0.09301835746173898, 0.05809627390737015, 0.038026179893002394, 0.014183846914449768, 0.07935662723837361, 0.04471951690051825, 0.04819206705677414, 0.0461928648573737, 0.030901100629219608, 0.0261094102696065, 0.05901396680142611, 0.13285473800234257, 0.03021869823456772, 0.01630264022687991, 0.04484129040652225, 0.09168689664933952, 0.053072905152915954, 0.023692130907288483, 0.02819636592551345, 0.06908478245379464, 0.022918987313225385, 0.03328998302740436, 0.028663361632835963, 0.034923056486032666, 0.0401043925704735, 0.0583740842017916, 0.07437351640434035, 0.035408679621234056, 0.07124494355652602, 0.10086691292423396, 0.06885632737389497, 0.03637635975234932, 0.23959572967742723, 0.15884692149777568, 0.42561031998165194, 0.15153672666318957, 0.157429444333238, 0.1440524766522069, 0.06587105893319653, 0.1038007845260924, 0.16434418458131053, 0.10817830285598194, 0.09239119958252677, 0.19735099086838384, 0.2836210406836002, 0.1869300653737399, 0.15862680911537141, 0.15136915259063244, 0.06795596721912585, 0.04825774760496232, 0.036057245827490286, 0.027485143303150134, 0.1360701622381326, 0.1355556729099443, 0.12821869564152535, 0.05959804755665603, 0.13271423747702954, 0.0728513992902252, 0.15130657852897722, 0.24386112337871907, 0.1995409451304905, 2.774143372812579, 3.721940733732716, 40.62121868133545, 91.01055114499985, 115.3894075270622, 108.38002220276864, 92.10909720390075, 63.60282090402419, 50.65639488158688, 44.63914171341927, 57.76382377070766, 62.76419462696199, 60.75207364174628, 51.07982258642874, 37.35308416428105, 32.85260565819279, 39.42369553350633, 44.26546535184307, 38.70037909476988, 28.176977634429935, 18.647214520362116, 7.8141679206202115, 4.488938402745032, 7.8823593066584685, 11.898148079072277, 11.277189812352582, 10.780362794476172, 4.3701415773360965, 1.2450058902463605, 0.09688311782214912, 0.6680708967389599, 0.16997549772983597, 0.15978916367936521, 0.4137906558330982, 0.09790325582387949, 0.17904979387117972, 0.5538745212458795, 0.3049724933601195, 1.0116272551878807, 2.184059552607998, 0.8902675898805742, 0.5887106229220668, 0.7690462494088758, 0.4793777412945225, 0.1834498351860431, 0.4465369922259162, 0.388017374301149, 0.6619470963074315, 0.11918536988237213, 0.16661679973044705, 0.6958805625477146, 0.5789110713428067, 1.4802424417388056, 0.9255442227567396, 0.5956635143487685, 0.5389388710741074, 0.7086229336357887, 1.2374441734244748, 1.959302103327167, 5.828827898348532, 5.952165847824467, 1.7969136492859934, 3.7184503145756262, 9.151118090075832, 20.176107345088838, 24.474385707609116, 20.4906932000191, 26.01623804338517, 41.12842821305798, 43.10775818363313, 40.40713571733044, 42.65460283525529, 32.168173636159594, 43.97791247214041, 60.127491104987364, 71.38157521524738, 65.1059006106469, 16.71988537234645, 1.1809040654090144, 0.06433812465759055, 0.17542366989918295, 0.029603700085933653, 0.0507548418376715, 0.035650541239808646, 0.05175324975542965, 0.048361870445190906, 0.03022207859753361, 0.012159063124037799, 0.049788375955916224, 0.03885937711944984, 0.10522160183397994, 0.06326551346348659, 0.0343136258813883, 0.08206122404625339, 0.11949131475581277, 0.037619655335982966, 0.10273370065636213, 0.17316438467992892, 0.14294465222666342, 0.20643196729642732, 0.06202968723711468, 0.04932869255783097, 0.07858382072299719, 0.08880007050691113, 0.04098469654338495, 0.03858634338323628, 0.06968947863506694, 0.0651206375069676, 0.2833779456634676, 0.27381594262776837, 0.30173178822282826, 0.434535765239308, 0.36012181471432414, 0.3075577030258794, 0.20321657370415427, 0.10408815176736924, 0.06016425548061248, 0.060214598948556575, 0.05943807307630778, 0.01815971970978764, 0.06497656701192742, 0.015094752269496602, 0.01829246167964753, 0.040850983557081035, 0.05275114822471815, 0.029499943052688916, 0.12298940245302455, 0.1426351527052541, 0.09998515338426638, 0.18631367102986385, 0.1748429139655444, 0.12166747177440314, 0.09965084793586886, 0.14121666430465638, 0.15203734979994837, 0.16199817820902795, 0.13417725090778646, 0.09495985408824298, 0.25457172203929196, 0.09217132468737903, 0.12250263784681598, 0.21687823497960645, 0.2842372205228575, 0.3444976966467596, 0.29719130766968577, 0.26520618688194986, 0.3446567977868742, 0.4296312703480644, 0.6163965502092915, 0.45071771788981657, 0.33194715397492536, 0.26196434793453066, 0.2911601732334783, 0.47069110096462313, 0.5320906579013794, 0.42397453840221133, 0.51725858281697, 0.5509011195071283, 0.3280546612316563, 0.402877580134138, 0.4683093642515521, 0.20178380542464797, 0.244235449260281, 0.17736058531989976, 0.14544516321151488, 0.2138956248640053, 0.16856784181248757, 0.2775328480187924, 0.2660009571381154, 0.16849619726980888, 0.26932026289643785, 0.19616018379888228, 0.3799640435364939, 0.26304174334772173, 0.13901740973514898, 0.1725099157662161, 1.2621954323784, 0.5636240013184086, 15.287126898765566, 72.18222510430121, 127.09856110234415, 142.2599574058287, 120.81222549561532, 91.4574581576932, 86.34062428628245, 66.9838765359694, 51.41948415387062, 50.893670820420795, 60.82197027821695, 66.1399942828763, 63.24746985589305, 61.504356784205285, 55.97380699649934, 61.25444689104634, 58.94860313784692, 60.41078821305306, 52.164303025891705, 34.82940766119188, 30.574165544202252, 31.380698988514563, 27.187126336559174, 20.17056699722044, 15.780731689545417, 8.17419933695947, 2.9591260273610396, 0.2652825505262421, 0.8698899575298833, 0.3069675701760477, 0.3721451663201855, 0.3016098576687998, 0.11196908210554432, 0.14834027076440473, 0.24545659341158407, 0.25381262083688094, 0.4043036681269446, 2.3544227980798293, 1.8642948207355317, 2.357997303047488, 2.6366873421976647, 0.5121153442850036, 0.15022608812057203, 0.5681564226265877, 0.5074687758761068, 0.6746201517601168, 0.13932197565032592, 0.20755367323515878, 0.38330314500677976, 1.39447957277298, 1.7383852673153726, 0.5236121483387486, 0.7372545811437792, 1.323219299797089, 2.0553204994047842, 4.617036638721343, 7.815894744088573, 14.302977746532811, 21.737636250834314, 28.771277512273482, 37.03643906501032, 38.260904973553075, 44.75091749621976, 37.06332691254155, 50.873188203380955, 63.24018601448306, 58.61986537133494, 46.71216141793036, 46.96023956421883, 61.103008101063395, 57.93591776201802, 63.84238750703874, 70.97362518310547, 94.15530358591388, 59.23706600742956, 5.710018325236536, 0.250986262014316, 0.28397000905486847, 0.26089378602562413, 0.1456175176727195, 0.2809618882113888, 0.13371286372984612, 0.3031274472032824, 0.2659642768483008, 0.19726955572203284, 0.39005317635113196, 0.1857215003861535, 0.1414575989568426, 0.2166195883746109, 0.1670612533005976, 0.12012774995978802, 0.18182457965468207, 0.27705321569115887, 0.16145489929664522, 0.3337743656048852, 0.32490073853442747, 0.3196621373776467, 0.5267838749193376, 0.21382275458064773, 0.515798848242529, 0.3020910834593158, 0.25954427618172865, 0.33584801239832757, 0.5048223098199214, 0.17514286803141718, 0.28042718948375794, 0.36355483856412674, 0.48357786430466565, 0.46086115101652764, 0.49297586323753484, 0.4697843592974448, 0.48497965198851406, 0.4069908594171847, 0.42018022748731804, 0.20876599205357416, 0.127011647508029, 0.15171536304537328, 0.20768931676303187, 0.22721767936262394, 0.14881308490951217, 0.12884982951706456, 0.0859558848183482, 0.17031424648819432, 0.19714017879338036], [0.028173896566694303, 0.08802688094757258, 0.040253036610421636, 0.1108694165163944, 0.019855882424200257, 0.049451408351981835, 0.03909673414102966, 0.06331146724762456, 0.04417328471918741, 0.15676169145491817, 0.03581392864185957, 0.05677688281021773, 0.032182802115717245, 0.055016558316926804, 0.07850452296195493, 0.1404782627979594, 0.03310575420337339, 0.15215546523611392, 0.060931921546016975, 0.14021295122802258, 0.08687714385169168, 0.13756916647957218, 0.06452102048863327, 0.13740844123305815, 0.1574820439301191, 0.10918764667885919, 0.2218817084306671, 0.14250749181355202, 0.12276450968197278, 0.23087283806695094, 0.06616941187530756, 0.09027099762592586, 0.07013909563782715, 0.07712852945851703, 0.06250147099396394, 0.10613274850672293, 0.0921843481820918, 0.010249536304223922, 0.09769754589445169, 0.08345850713310704, 0.0407528821679373, 0.10790212049839959, 0.05874477499615281, 0.10915407670601722, 0.02663344888377094, 0.059386170619437774, 0.026526533653058355, 0.08576515956871933, 0.21015861732584817, 0.008425722274208262, 0.043079786137827945, 0.023544042281085448, 0.1949631254519186, 0.3634139396730931, 2.2722199703416517, 20.900172956528206, 56.246996156630985, 81.14712376748362, 65.28189343790855, 41.55935548966931, 35.700373880324825, 22.16952843050803, 13.90769991182512, 16.366003251844838, 25.71031278179538, 31.880456016909694, 33.153877027573124, 23.156838032507128, 20.84014892578125, 26.127284265333607, 19.487992217463834, 9.35270732448947, 3.0366582928165315, 7.5888978665874856, 11.228444557036124, 11.565647778972505, 15.818182479950691, 19.789602871864073, 11.486189384614269, 2.440005728314, 0.3338796567291983, 0.18724475897127585, 0.778524044059938, 0.30796179908417887, 0.015395238766476754, 0.06624610493740728, 0.5972779373968802, 1.1884232490293443, 8.633189701264905, 5.453796357877794, 0.417784670548093, 0.37844930384908954, 0.43801677683668755, 0.7613097419661861, 0.40690153356521364, 0.4713676485323137, 0.07068261969834566, 0.12857443623004422, 0.0888578565190396, 0.16342310174818964, 0.30829624242840276, 0.05329155813782446, 1.9984946712370844, 5.2389602987997, 3.0958466135686447, 1.3197500859537434, 2.555950990607662, 4.846847326524796, 4.34404359709832, 3.116088495139153, 3.2637091029074887, 2.5559745248286956, 9.182778481514223, 11.609107640481765, 5.870356973140471, 16.575859861989176, 15.331460468230711, 9.863180268195368, 7.126707828813984, 19.567222133759532, 44.009711127127375, 40.1413284578631, 35.70670850815312, 54.08147519634616, 51.06053236992129, 8.549528487267034, 0.10259801882409281, 0.21645694790828615, 0.04321764749024184, 0.06197413437128548, 0.08774438602549416, 0.003767657997800158, 0.03367097387390752, 0.055370192163653915, 0.016960462690481258, 0.05233271100047616, 0.06337107654901282, 0.08946467476386218, 0.05170746451063503, 0.03550408438088433, 0.1239095813023948, 0.1017929983115004, 0.14371676160202873, 0.13949026984553184, 0.023886632970384052, 0.015024609259149481, 0.06737902640335022, 0.0860628919796117, 0.10350150461759298, 0.1236777937400245, 0.30591248324321163, 0.1465857915219761, 0.13645150548508092, 0.3227054676221263, 0.20078937733365645, 0.2784783230914224, 0.20731851488592165, 0.19429996910114444, 0.2796073834742269, 0.13040272038309805, 0.026107652097820278, 0.03130927993615549, 0.16829519112023617, 0.15575725825563555, 0.06938477482406363, 0.17802348120077965, 0.10763441873413902, 0.15429729385481727, 0.06151352400681185, 0.21434957792441692, 0.036707340379155455, 0.05643543742236592, 0.1716095939158432, 0.005223638023204741, 0.02778321087750937, 0.03771952638823179, 0.06434570892804092, 0.11021906915571421, 0.017180902575473153, 0.06472877587281889, 0.021245345668566805, 0.06061579919450226, 0.023968966354826288, 0.041115762695910475, 0.08455047353861794, 0.06930952200726156, 0.026992529615639683, 0.021623724155248176, 0.025629381491472165, 0.05145427628209995, 0.049003848295298316, 0.05535291305052177, 0.017597455223421418, 0.13011879287660122, 0.20559834106074226, 0.2105378461701255, 0.1761347220669831, 0.17842678052763786, 0.08657009581164007, 0.10054751554684294, 0.2231130415513631, 0.12590356261259125, 0.21044378589478233, 0.24267099046659088, 0.1176458778941343, 0.11603489458080261, 0.16297835706462785, 0.3149363861208962, 0.21396224386990073, 0.22292953284998096, 0.058528286209630395, 0.03950124771724786, 0.08633655390792316, 0.005819887127501951, 0.10237205352994705, 0.0439432323459656, 0.0702343510103322, 0.09816011744401149, 0.04445878270592901, 0.08628262131805382, 0.04083011532202363, 0.10376546021190383, 0.018593995801864133, 0.08279308316207702, 0.18273322121991267, 0.03790149142244651, 0.13473621930085844, 0.024436659202159896, 1.7154586459359817, 5.163798370668966, 19.48195568976864, 58.94390806075066, 90.52773875574913, 102.89632904914119, 92.40626381289576, 59.86686137414748, 36.76367352085729, 40.32148684224775, 55.918478042848655, 56.33201353011593, 49.143874029959406, 48.083743664526175, 43.90839238320628, 48.3109155777962, 50.58940472141389, 54.04445978903002, 47.56745384585473, 35.26350421290244, 23.55677466238699, 13.71485952408083, 10.88499496060033, 12.069621355302873, 19.276517629623413, 24.8583935922192, 19.024028778076172, 6.711769113617559, 1.3182744167504774, 1.492658581945204, 1.0574376583099365, 0.4102041386067868, 0.0651911712221561, 0.14798089891912478, 1.4557445433831986, 3.603868566213116, 7.245947882052391, 3.2085291993233467, 0.956617545696997, 0.9349640398736924, 0.7725489872597879, 0.6496749193437639, 0.5870501733114643, 1.140288902867225, 0.8434048883857266, 0.8510698738598055, 0.16379741230799308, 0.19783384076529936, 0.625639921955524, 0.8285487887840118, 1.7477661058787377, 1.8960848955377456, 3.4590213193047434, 4.858967940653525, 8.247508925776328, 7.841056748743981, 4.747193138445578, 1.684430368965672, 5.142856346022699, 14.964105986779737, 25.261138639142438, 39.58272803214289, 34.38556009723295, 25.235974673301946, 38.868644852792066, 39.192797368572606, 41.93851140237624, 43.82320634780392, 47.56828931070144, 51.18457732662078, 51.831038844200876, 68.39268992024084, 66.46671202874953, 31.801859563396825, 0.9831493768480517, 0.6144255591977028, 0.036661160599079826, 0.05983564972637161, 0.0844435812905431, 0.028626487905820532, 0.05112072159986823, 0.033821962142903964, 0.05008375264644142, 0.03870396469269068, 0.0493384869919429, 0.08344751377139362, 0.037685213310103265, 0.1224561439706914, 0.03694665858582143, 0.0695117155931169, 0.11886944288327811, 0.04374858472616442, 0.031525768722677906, 0.030598633794955192, 0.22153028857804116, 0.06706858459379404, 0.13975073973978722, 0.09972993119229233, 0.15709889271566946, 0.07537405787696762, 0.0788703759110743, 0.14140970313981657, 0.26309092619246055, 0.14346678711233601, 0.02810925406764352, 0.029668524530866457, 0.0861645135427675, 0.04469346225021347, 0.09392195050754855, 0.09282786203848739, 0.3407150915553493, 0.09887145306434363, 0.14143824757587525, 0.21403984857663033, 0.06273053894420305, 0.12129954272700895, 0.2043586575816716, 0.12453024275600912, 0.0630135586365096, 0.08913328811045616, 0.12205969346987626, 0.07214165713277555, 0.06812265262969079, 0.049395031941634034, 0.15250746731556233, 0.18683876301492416, 0.10438743167586866, 0.18778040764793275, 0.1524915326867373, 0.19720385602164656, 0.11906915434425878, 0.11828003781697444, 0.12591848600535624, 0.20611296828475692, 0.10698695186405413, 0.1718395888324707, 0.14333641426938196, 0.1660691541168959, 0.18223642852277527, 0.19769923911700327, 0.244389831298782, 0.38340518791829387, 0.2814118269710772, 0.42950793019225525, 0.414101810104424, 0.4007325033026357, 0.30547198268675035, 0.19085114851834314, 0.39576528113215204, 0.36161844408319843, 0.7363347240513372, 0.5673584654446572, 0.4619645627756273, 0.5426836927090922, 0.31487791829051515, 0.4140978264472177, 0.3671485263734095, 0.26599289789315195, 0.15219642029654595, 0.27406099883298723, 0.16105150803923607, 0.18759400313419683, 0.21791755582296082, 0.2973059144231581, 0.1508761290460825, 0.24516066896819302, 0.18437215908160134, 0.25615187031367137, 0.10482374939226335, 0.3181368256768873, 0.05606200403323578, 0.16307303021031042, 0.4685391293418023, 0.11885179987838192, 0.22447249521651577, 0.10084935418900945, 0.5550956653971826, 0.7908277225590522, 4.952498818597486, 36.13588640766759, 91.62392354780629, 135.15486624933058, 121.01181137946345, 88.45790401581796, 72.32900804088962, 57.80105098601311, 57.66942016540035, 55.26263421581638, 46.40369446046891, 49.47966421804121, 70.66746065693518, 73.21249838798278, 70.09286480565225, 72.25487524463286, 65.76112470319195, 63.149716546458585, 62.22478635849492, 57.44650010139712, 52.9254154236086, 54.249246735726636, 39.147443002270116, 31.49333377038279, 18.956132550393384, 5.004635453224182, 0.5809803054698053, 1.666029059598523, 1.074592879702968, 0.2766257079858934, 0.11888115636764035, 0.14576221635985762, 0.8737634206491133, 2.254258456730074, 11.405313053438741, 11.468525971135787, 2.116803406707702, 1.3888615129455444, 1.0104230262579457, 1.6272985959245314, 0.401592513606433, 1.013060942772896, 0.863180375627933, 0.8072427804431608, 0.26094989430519844, 0.1545189384130701, 1.1434060839876052, 2.0105494630913583, 7.20274591638196, 11.593437771643362, 13.922468616116433, 9.654656283317074, 18.104405556955648, 22.13894178790431, 31.68246065416644, 27.150103084502685, 29.673387350574618, 40.33887078685146, 46.86834235345164, 64.80900856756395, 72.29771537165489, 65.27473511234408, 49.516448205517186, 34.8853563493298, 41.805845076038, 60.96371296913394, 83.26958887038693, 74.49123813259986, 67.10140643581268, 91.13425485549435, 75.02688484807169, 14.657581583146127, 0.24515967305389144, 0.455835307798078, 0.11843042853738993, 0.15962823924999084, 0.22503987525499639, 0.1774282615271307, 0.17272622835251594, 0.09443971869205275, 0.13578444208589294, 0.232263823911067, 0.25900038439900647, 0.22850970196868145, 0.3197460393271139, 0.24450204785793062, 0.14515696093440056, 0.20562159949012343, 0.35316279458422817, 0.2262121123532134, 0.1558098118872412, 0.10747524864611127, 0.40326739631352887, 0.18333026418282142, 0.15741352502617145, 0.34636076119157577, 0.46277284682277714, 0.2960732176659569, 0.36806902697970795, 0.5674361774036961, 0.5794272920297039, 0.5417135802488173, 0.348846624575315, 0.3728383226740745, 0.46973744407296186, 0.31061531314926766, 0.32974449797503413, 0.129935912367317, 0.38071818048915557, 0.5057125346314523, 0.17740498777599106, 0.30960714144091456, 0.2383137275014193, 0.3359548356984893, 0.2577128357464268, 0.5551278410900025, 0.20599690596422843, 0.23721734842946454, 0.33347871695314685, 0.10847038919887236, 0.09678889666834185, 0.13252449281994375], [0.016768982844246973, 0.051199326051339034, 0.06439768799370335, 0.045775507817104946, 0.018827426622832016, 0.04353639369289722, 0.12407535506832985, 0.0782488564389848, 0.06435517777478503, 0.09664959890106994, 0.03874575478896018, 0.08808528749091972, 0.10826742952509273, 0.07453398118096013, 0.17453932864291055, 0.09905683102026101, 0.11970974940566287, 0.17469792416499508, 0.1885044526669287, 0.19501094466015217, 0.130491157573077, 0.11953606195147, 0.2021300005576303, 0.24077274716429173, 0.18863294093358904, 0.08061139498867335, 0.1653392715079169, 0.1365889569804553, 0.09973566919084519, 0.10444000062923278, 0.01470173863063176, 0.07779343248975855, 0.04227516399095616, 0.05727932923623631, 0.07875809040401252, 0.1410160718425628, 0.046221738711239836, 0.1734743285323343, 0.04088811966921053, 0.028354440507809484, 0.005014814903974654, 0.051824695115248044, 0.13581298652195162, 0.060248613252394626, 0.00957517208711755, 0.03443158426952939, 0.049592690286977645, 0.021458555598773306, 0.09467583465119524, 0.11690372255660834, 0.15549910194691152, 0.027129873858704686, 0.13620084151625633, 0.0514273138176049, 0.09804551069053913, 0.17600522256426274, 0.15784316245586644, 13.15512945575099, 49.735591027044485, 76.75548907249205, 52.109691865982555, 39.03217631001627, 35.7464813417004, 32.906575510578776, 21.06106269744135, 8.745574432034648, 18.9011566100582, 26.49208430320986, 25.426117450960223, 26.380245762486613, 20.312678390933623, 23.79633930421645, 29.472624755674794, 17.429008714614376, 17.95048390665362, 19.15865432831549, 10.559732414061024, 19.553687995479955, 47.95716093432519, 38.32054068965297, 12.389912297648769, 5.459047430945981, 2.1599587942323377, 0.5252408512657689, 0.4961299391523485, 2.935405003447687, 6.115512953650567, 5.157501985949855, 0.421247112174188, 0.6989447303837346, 0.4056739542753466, 0.09849040093080652, 0.06092376654006301, 0.5682334604282533, 1.0987242815955993, 0.5338875324495378, 0.5480931314729875, 0.253826946681065, 0.8339345707528053, 0.8126159372829622, 0.210138009560685, 0.9806833704633098, 2.042581744251713, 7.2835031055635024, 10.012317607479712, 11.260353038387915, 6.691584596710821, 5.126997713119754, 4.472140362185817, 5.936419983063975, 10.900079415690515, 11.465787176162967, 11.250691260060957, 12.084095881831262, 16.974837472361905, 12.932580055729037, 7.176314044383265, 18.493694913002756, 22.113871958947954, 26.717363672871745, 38.88457359806184, 57.571043199108495, 59.056589911060954, 22.963200423025317, 0.7667983635779351, 0.3045965586939166, 0.0583138773518224, 0.04616511332231664, 0.14182823229460947, 0.13927381936340563, 0.046120622766114054, 0.02538608345803955, 0.07367836822184824, 0.02636321711414043, 0.04764620642808657, 0.012104773345673758, 0.02624759337894859, 0.023907045383126508, 0.036289416433822726, 0.03480728144847578, 0.00418782442612874, 0.0696435286813686, 0.14197168991931025, 0.03890278749167919, 0.11732666437784511, 0.04240656339172875, 0.06716125824999425, 0.11384675594707651, 0.12531381280672166, 0.03196072663300701, 0.06813711636970121, 0.2993864253644021, 0.3018714000861491, 0.4549938674655653, 0.3815600498309059, 0.3963596121438088, 0.2535676718839715, 0.3318692275112675, 0.2744399365638533, 0.2047496228929489, 0.07017768348657316, 0.14765909602565153, 0.14163661838298844, 0.17562744928704155, 0.15872140565226156, 0.01105301027681919, 0.14913562324739274, 0.11981640416648119, 0.2337085125186751, 0.06548918708558045, 0.09995027340107387, 0.09771998460975387, 0.11187525931745769, 0.0455720080513387, 0.0797559505689048, 0.026331987539907138, 0.09343880949722183, 0.0586864450615981, 0.08668304781519598, 0.031714341265239546, 0.030960531815165476, 0.03732036393616469, 0.06677276740271239, 0.08470730705847664, 0.04431620608234117, 0.17847973252496413, 0.07664047016371643, 0.06858543868386938, 0.08922678148073536, 0.07268931806808518, 0.16485852069191395, 0.11739697592753558, 0.22332149407555982, 0.255824260473732, 0.30526054241964895, 0.2417750046738694, 0.027268541518658884, 0.006496751664071194, 0.18866729231611376, 0.06413390476917548, 0.17941261311211895, 0.36775575830571117, 0.25685242707690886, 0.2139277545915496, 0.16761882741364742, 0.10470787093283669, 0.32431697953612576, 0.13629718473361385, 0.1020281336780998, 0.06196722425820847, 0.01593791151178941, 0.07964737292739653, 0.00863794395099244, 0.19893564373975803, 0.08971483311465672, 0.048120920471246206, 0.013000444084736369, 0.060095851489853476, 0.03627539702480839, 0.0932484136654004, 0.04952243236344188, 0.07112561770144009, 0.10582502630929794, 0.073532497420186, 0.12466460691704867, 0.04982158203699416, 0.08513760332378649, 0.08548873206300121, 0.10745917612145986, 0.18168683704589644, 1.1882066606513917, 2.394395672505902, 4.878303754714228, 44.02166258904242, 79.04681221131356, 92.34687912848689, 81.30457555094074, 54.067421344018754, 42.675901305290964, 42.29012050936299, 46.64741485349594, 44.842038077692834, 53.2832807110202, 52.2331759237474, 51.326233725393976, 59.54032405730217, 53.28650489930184, 55.66896823144729, 63.47258644719278, 59.70384766978603, 44.83351868967856, 37.7787515424913, 33.17811727523804, 43.8992650278153, 69.99038896253033, 60.39586751691757, 27.17350982850598, 11.26997265123552, 4.13867368813484, 1.5441964422502827, 4.365196449141349, 7.450009680563404, 12.944034357224742, 13.45346885342752, 7.586190940872316, 1.9994516069850616, 2.291897030607347, 0.6290382267005983, 0.9737985689313182, 2.617832999075613, 5.533247888088227, 4.864398462157096, 4.760479677108027, 3.775368318442376, 3.3593889494096083, 3.367361902229248, 4.7563180423552, 5.844512966371352, 10.895992305970962, 18.152607564003237, 22.97484790125201, 17.00941316543087, 13.077557721445638, 13.276833738050154, 18.213339582566295, 22.651456325284897, 33.808202897348714, 41.68655795435752, 35.08181218178042, 35.7506900448953, 42.301703268481845, 45.7096153689969, 38.10057809275966, 33.05673560788555, 35.98359254098708, 39.235304094129994, 69.19335549877536, 79.78544942794308, 69.64009777192148, 46.8333940352163, 7.919764989806761, 0.9597397523541605, 0.02032154513853452, 0.07070599304091546, 0.018382536382564617, 0.10046626426159375, 0.034824633339960734, 0.04186588917828856, 0.054363066165317456, 0.03985674698807059, 0.0592661016590653, 0.07535620802833189, 0.11478810180579463, 0.045402966920406594, 0.029693033598784, 0.03631335285101687, 0.0369435750819262, 0.08969100778021159, 0.06553024939832187, 0.16617560969485393, 0.03909413327252673, 0.029928959951165224, 0.047287198474570635, 0.031667410718998125, 0.03052185454796399, 0.07449341682536949, 0.06422684272570957, 0.141142001375556, 0.13994524946376202, 0.26323112028260387, 0.3253568366410271, 0.1428685337305069, 0.05130392003564104, 0.08238534818613723, 0.21883080923749557, 0.06171768260819297, 0.03167726644014399, 0.05267882569422645, 0.1196582453145135, 0.1951820274154025, 0.24779535259210297, 0.4052746386056946, 0.45862365333784016, 0.22842748541264768, 0.423014538302537, 0.08070587661237487, 0.20879514935997226, 0.21444270357249245, 0.26380216222136255, 0.09610726227683407, 0.009389209989157897, 0.09317499179873737, 0.12457039342412066, 0.2515573805618671, 0.13479807323986484, 0.15582358614811975, 0.11603305596978435, 0.09252134259910354, 0.2776542882765493, 0.28022552449857036, 0.2315156471224562, 0.2611629280351824, 0.1794483434529074, 0.1690879542260401, 0.19425064836057926, 0.3025723398933488, 0.37820253160692036, 0.5148409931890426, 0.5505880040507163, 0.4261758154438388, 0.5635205488051138, 0.4938348010182381, 0.3712437872684771, 0.41899484432032036, 0.47964044816551676, 0.46423340877217634, 0.413504537315138, 0.45155042481999247, 0.38498384998210017, 0.6021110941806148, 0.4881488351571945, 0.3474524977707094, 0.4911560060516481, 0.3426208425193064, 0.1410427776676032, 0.1862475882855154, 0.24909679807962912, 0.282837669815748, 0.17228966548798547, 0.4279778993898823, 0.2365878386603248, 0.20711475081982153, 0.11150703149577303, 0.16899280610584444, 0.2995428605185401, 0.2787920514181737, 0.11256979462961036, 0.13841898781397652, 0.2120201190512988, 0.18168352754606357, 0.25775782042934053, 0.21862542106499597, 0.3370586458233095, 0.1422403569543554, 0.17558220413423356, 0.30206892819654557, 0.45091417347711904, 0.3838649326034131, 0.5055550575977372, 21.769646713810584, 74.84527126435312, 131.20333717715357, 116.57884274759601, 84.13182781588647, 72.37519002729847, 66.34657767511183, 61.90672136122181, 41.88900716843144, 47.40140030460973, 54.542381148184504, 62.00829505920411, 75.58349270974436, 70.21219115103446, 72.91945811240905, 86.55495043723815, 94.4918429466986, 71.78934481836134, 69.77460368987053, 72.17199556289181, 66.7267494816934, 78.17938004770588, 57.81500677908621, 25.698928102370232, 9.292081209921069, 1.9582550756392942, 0.3618544604509108, 2.1329986280010593, 5.806366935853036, 12.774267312019104, 10.71194391096792, 4.211066422923919, 0.41830521197088305, 0.5175082661932515, 0.1442325226361713, 0.24403923882111428, 0.8863105312470467, 3.270468572455068, 3.0348464029450573, 3.9820747750420726, 3.092520933958792, 3.2648995422547866, 3.4213391090593035, 4.077019667433155, 4.0137513462574255, 7.597228980833485, 14.703331128243478, 24.942738279219597, 26.969781921755885, 30.269603306247344, 32.575003831617295, 37.63539283506332, 49.79514829574093, 63.588163006690245, 72.51000189012098, 66.68516451312651, 60.657446461339156, 49.02290421147501, 41.512718508320475, 42.38927802731914, 54.97099814876434, 57.78001531477898, 53.90249744538338, 82.84674952107092, 108.29165904752671, 90.41712007214947, 34.40680757645638, 1.8701533708841571, 0.3640224892766245, 0.16846590615328283, 0.15360939286408887, 0.2952303983751805, 0.25975430684704937, 0.244470224565556, 0.1241062207507991, 0.163281635952092, 0.15017212488718573, 0.38431407463166023, 0.19080643962708213, 0.22871738840495387, 0.12218196110259141, 0.14613949934080725, 0.14033806870781607, 0.10742406631189008, 0.12030188174497698, 0.1379115618164501, 0.17319631522461293, 0.18621663833337446, 0.18781128099128125, 0.11545520350937882, 0.15049014330631302, 0.21061096160161882, 0.14862347814825275, 0.14558321225547022, 0.38519673049449926, 0.35252059839906236, 0.5469064306347602, 0.625908297877158, 0.6246467042834528, 0.4094727697872347, 0.43439410026035, 0.7579998131240568, 0.3835634310399333, 0.19595769143873648, 0.18209332329851968, 0.13112609124472066, 0.3053916660287688, 0.2722220507360274, 0.5337276345779819, 0.3714587515400302, 0.352793540204725, 0.32211561056394733, 0.10481947462164587, 0.38346705717905877, 0.32876151523763136, 0.4429292083988267, 0.1903947592983323, 0.23434516222726917, 0.28636498376727104], [0.06360382938216771, 0.0574473093353933, 0.036981431316704526, 0.01626669155103305, 0.045032969435616854, 0.21633494074546525, 0.21520747382554317, 0.3051581624294481, 0.14128323734527634, 0.05066278488225034, 0.0777777813134655, 0.11660092630453649, 0.10411995207710613, 0.1018031642982556, 0.10373590453978508, 0.10350080747758189, 0.22276565132121887, 0.16749348010747664, 0.07943734992295504, 0.09542072492261088, 0.10964733007694445, 0.10480612937000491, 0.30888910255124497, 0.20824473050813522, 0.05420575001006646, 0.07666345280144485, 0.15384675754654795, 0.030657974965569955, 0.02156031697297529, 0.04933207866645629, 0.10065040881595305, 0.10722438549442638, 0.0469424742304029, 0.13866376822754262, 0.20690467418922534, 0.09273190952597127, 0.05455968646152366, 0.0492751851467596, 0.027691289902694767, 0.015440015648041042, 0.07289862861075709, 0.05873804491373801, 0.03405952217778371, 0.06700805598689664, 0.037537703080283064, 0.04962024646961401, 0.01400462064456435, 0.03777926592456718, 0.13544011620744584, 0.060182480712331114, 0.14984926479237695, 0.06813746110926713, 0.18542635735244523, 0.12231909084103762, 0.10103995686457043, 0.04425821322647314, 0.11708929203450681, 0.06358646216892427, 0.2420259750778637, 7.330755408733123, 33.44508555627639, 69.67849777590844, 55.53179902415122, 39.78963305873256, 31.38888889743436, 40.718101224591656, 42.43557768483316, 32.18996632483698, 21.38680181195659, 24.374135809559977, 39.256316231143096, 35.41566864136727, 37.44978235613915, 49.71988193450436, 34.444254444491484, 22.686977309565393, 30.105565863270915, 37.61762449818273, 55.75819430812713, 75.90366009742984, 73.99512106372465, 52.804276943206794, 35.08211812665386, 25.717759401567523, 23.914390879292643, 26.1142365009554, 29.969147789862852, 31.352520681196648, 33.088997102552845, 32.17892289161682, 32.353619375536525, 27.533120570644257, 19.984929061705067, 13.530939586700933, 7.108899777935398, 3.21749696327794, 2.74249670966979, 7.537708484357403, 9.356440440300974, 14.221440495983249, 18.64460418301244, 23.87494360246966, 21.233815646940663, 18.659379751451556, 12.377620570121273, 4.164891790959143, 13.116700033987723, 11.689032796890507, 18.86800669854687, 24.088585299830285, 23.65596159811943, 9.660723209381104, 8.469681778261739, 24.591084064975863, 18.400397416084044, 19.99131271916051, 27.07114185056379, 27.376810196907293, 37.95197125404112, 44.42137564382246, 50.42416311079457, 32.25882353321199, 3.4424934319911467, 0.03313923607610407, 0.03038670514680205, 0.07336873080461256, 0.08794155407456622, 0.08757236864297621, 0.0907985104488269, 0.06961763490952792, 0.0843186246892137, 0.03758317805946835, 0.061373908313051354, 0.014628899948401077, 0.024624465656797254, 0.05012674933119167, 0.023343310007945667, 0.032848643604665995, 0.02274293073212668, 0.05778121258763056, 0.04949705187051047, 0.013469584838246867, 0.05821986687219432, 0.09983028871037307, 0.0721830795068414, 0.1608202260948958, 0.0706428061089208, 0.0654683111896438, 0.06301697155821227, 0.044557853196296966, 0.07842815165678341, 0.006594253110609228, 0.12948867023712204, 0.15418426524246895, 0.18526546356658782, 0.2913410312706425, 0.23696001949569873, 0.46726772982266646, 0.46117941458379075, 0.19379197619855407, 0.15994579801636358, 0.11724520624885637, 0.06426473343444448, 0.0957406432397904, 0.04043104480050745, 0.08421032283935817, 0.07716193089201566, 0.11833645253171844, 0.11566587002767671, 0.04253075773557348, 0.03805159869033002, 0.07957436474821261, 0.11469145215326741, 0.13402850727640814, 0.051621172366844076, 0.043619104375642155, 0.07126414938078773, 0.1566317782647187, 0.06568441693220409, 0.08412724060396995, 0.03387001883839408, 0.1736849414244775, 0.18491713870917598, 0.2637816310649918, 0.20688581310452955, 0.256161262551623, 0.21389954723417762, 0.1650822643310793, 0.12463856758850238, 0.0413904550124801, 0.1901324967583341, 0.0841581216081977, 0.4247955701524212, 0.4546026416843938, 0.18965133225485203, 0.21832080918454358, 0.3216184807881233, 0.22508176494269605, 0.20766230450282175, 0.2595908543275249, 0.2864705506832369, 0.22694173449229813, 0.19052479506259967, 0.12522608041763306, 0.19993816171922993, 0.11848448370132716, 0.1266669922117745, 0.10361255672309669, 0.04700192648376669, 0.12652516635435243, 0.08324403315782548, 0.11308264452964069, 0.07911874927700528, 0.048777461652794195, 0.020012085836741234, 0.04460066218950576, 0.03612909338346893, 0.05825005456685059, 0.057803191650178165, 0.04794666994242899, 0.06413694230779525, 0.049810309053188374, 0.07289518121509783, 0.09860348316930956, 0.10838701585007292, 0.0707031891591126, 0.09070415906007252, 0.015152790133030185, 0.11697096209372244, 0.09610103398200967, 0.20289421922737555, 0.18501153606320583, 0.08514482753291246, 2.1730769161255132, 3.150902472196087, 32.51022000466624, 66.0118269151257, 93.332868852923, 90.10507199072069, 64.5736506677443, 44.93634362374583, 33.19411662317092, 47.141170655527425, 58.991082406813106, 47.80502788482174, 45.704186808678415, 53.56535011722196, 55.365572898618645, 61.766877097468225, 80.09187283054476, 63.29362046334052, 60.29383882399529, 71.12491100065171, 70.63692108277353, 76.99939773928735, 87.05274628054711, 85.95941697397541, 81.147155146445, 67.39820434201148, 65.67643680880147, 62.828003744925226, 65.08308026098436, 70.02216800566643, 72.98143940587198, 67.58924730362432, 61.24815540928995, 59.152197684011156, 53.81247512755856, 45.50702887196695, 41.31960845762684, 45.17536109493625, 39.538789641472604, 30.168645420382102, 33.73053604556669, 32.05728627020313, 39.53164700538882, 46.414296627044685, 55.24204569478189, 53.79273383848129, 51.42441065080705, 35.14932793955649, 37.5436838980644, 44.08096490367767, 41.45029790939824, 44.43786921039705, 52.12132953828382, 49.39317203337147, 39.625360273545795, 44.11270864548222, 53.36737240514448, 39.39896891194005, 28.875916542545443, 36.73180818557739, 42.33301554956744, 51.4852701464007, 67.9980759466848, 75.07931124779486, 59.452266846933675, 15.819859293199356, 0.8907606440686411, 0.09188018829351471, 0.1266533941511185, 0.058978504591411164, 0.02765446022573498, 0.05546309181579179, 0.022951128532088572, 0.04814343196490119, 0.05089860589754197, 0.019638457095190402, 0.024179278557459195, 0.021858499460523168, 0.04918091419723727, 0.056329288279577616, 0.05271868907936639, 0.026046964527678587, 0.04958776817206414, 0.1341055450780738, 0.07907892036582194, 0.09193866378477505, 0.06263488903641701, 0.08383487846942679, 0.08557592052966358, 0.045561462851060976, 0.17650966081888447, 0.1720438891601178, 0.06176539839455678, 0.06211499112748331, 0.16601125319157878, 0.08253871132769892, 0.0812850544048894, 0.0700941799028266, 0.13786927376302982, 0.0541390007692239, 0.19520920821495596, 0.3192076020904126, 0.006181602244220314, 0.039468397867054715, 0.0913418889526398, 0.03501515557628966, 0.09626809477565751, 0.08053407373447573, 0.10231317201208684, 0.31158983827598635, 0.4423962257081463, 0.22320802113221538, 0.18419436539613432, 0.2674992719004231, 0.14572493852146212, 0.05926278832879278, 0.15905541998724784, 0.04647000865530103, 0.04839311534118268, 0.20288842760266798, 0.2628335512934193, 0.1287501155128402, 0.18786847711570803, 0.200344264927891, 0.26603748421034507, 0.38988132750795734, 0.5018238723278046, 0.3186700535157035, 0.5156815448595632, 0.1961665576504123, 0.18498715914545522, 0.21370329082973544, 0.4470911189433067, 0.45364708489468025, 0.617556713761822, 0.4912800203648306, 0.6129294814121339, 0.38548079589682244, 0.3748601819238355, 0.655740313231945, 0.5387273082329381, 0.3982062517635284, 0.44445905534009783, 0.635949565518287, 0.6156132406284732, 0.3731605086115099, 0.4084039239152786, 0.29973055205998883, 0.39226330936916415, 0.1689796600370638, 0.17022752533516577, 0.08975639338454894, 0.2637629078761224, 0.3675623670701058, 0.31915155509787224, 0.19658133297437624, 0.1638950272313049, 0.18423637765790188, 0.1104558822548678, 0.17597309283671841, 0.10287382579859226, 0.19851481632119228, 0.10153181595547546, 0.18298840510749048, 0.25250055737072424, 0.17287826616196864, 0.1283101971832014, 0.44559828937053686, 0.1277895485081019, 0.2992950463967939, 0.13746850252632173, 0.30603989898677797, 0.21541626342842657, 0.23955270617959962, 0.20672047600871135, 0.15313460221213682, 0.4327549172505256, 0.3676167593127297, 12.420395978035467, 57.15414231823337, 131.44399812144619, 129.39908612158993, 94.1125968194777, 70.02307015080606, 76.90464112066454, 80.71671424373504, 77.08470144579488, 49.70404340374855, 45.01657570562055, 62.19520384265531, 67.55228288712041, 77.21890926361084, 92.4643462704074, 78.17774049697384, 77.82014585310414, 93.46557832533314, 95.93580861245432, 107.0449572224771, 108.34599956389397, 102.94372697030346, 91.86652214296403, 70.95755131013932, 67.90635524257537, 64.9675468475588, 62.611798778657, 69.25092804816462, 70.05795571111864, 64.11822818940686, 52.29603582812894, 51.15803072529455, 45.29783710356682, 35.31542854924356, 29.882298669507428, 35.537328797002, 32.292832443791056, 24.37846218386004, 30.27734998733767, 31.158224113525886, 42.0162880805231, 52.50822820971089, 69.40629313069006, 74.55165832273423, 83.27112643949448, 60.9900438401007, 56.037212110334835, 67.98315525054932, 65.42957067489624, 69.24262831288, 76.43399592368834, 63.697181363259595, 44.235365083140714, 42.3516389631456, 69.91729951673939, 63.21305105763098, 53.1446994504621, 63.90230563379104, 61.22107144325011, 77.33677648728894, 97.82644594869306, 96.22839389308807, 49.806244680958415, 5.087765676359977, 0.2576854404422545, 0.21091318328774747, 0.18485418160355863, 0.23326928366816815, 0.19078695035028845, 0.20886774385167708, 0.16833153433136402, 0.25508811126553244, 0.0794100312275752, 0.16399780558722635, 0.10654576182846101, 0.26068528753615194, 0.21892793386453585, 0.11440305069329278, 0.16081308615544151, 0.12513630257378663, 0.20962054781135053, 0.21913022704182133, 0.09884793416506822, 0.13183622410701168, 0.16289837748533295, 0.1310796203512338, 0.22428291909877332, 0.1503227837383747, 0.250851032173922, 0.2065003329827901, 0.2765772605855619, 0.1913217869737456, 0.26437203970647627, 0.16639749940124252, 0.2676033679275744, 0.3846428489252445, 0.6569788016138539, 0.2116441690633374, 0.42363430343327985, 0.5278945798354765, 0.267202336220972, 0.263948607588968, 0.2042233511324852, 0.11215410000013729, 0.1897516744511743, 0.10455746489066271, 0.17593272000310883, 0.3603202621302297, 0.4624903135963025, 0.21963054374341043, 0.26270083422141693, 0.2928713685081851, 0.12571791652590036, 0.17052674395663125, 0.4131410132733084, 0.12031302832427526, 0.22402022754953754], [0.054573303674377745, 0.03086740425187013, 0.06474684788695266, 0.02330661056593301, 0.0572838912898254, 0.208635741784688, 0.3198057328981738, 0.23580144940605088, 0.22960047327703048, 0.21891031384227738, 0.3384000657787246, 0.21607439424241745, 0.07611543946569005, 0.17109746413846172, 0.1720613559647914, 0.11216712349485006, 0.07160635319568458, 0.1780363055126321, 0.11754303059029965, 0.05167140858247877, 0.08163899468678622, 0.1883877468325438, 0.1791368980681704, 0.07843921396641002, 0.014354532261589363, 0.045705759342038826, 0.11478268556416997, 0.08819938096548281, 0.04868826986620984, 0.11222747590152488, 0.1292762034122021, 0.10440797815399785, 0.11905932543619026, 0.09206335991621019, 0.07616746449662794, 0.06550713652564634, 0.02367718644710558, 0.059983818791806705, 0.050102969962022, 0.020577485537937572, 0.09306632988755742, 0.08025480404255853, 0.020355865877542286, 0.037274839161264325, 0.08870665374542437, 0.057440318783084234, 0.057597860934272896, 0.06168071503540682, 0.042339703068137176, 0.0363382353867975, 0.03861145957583382, 0.004594205341662371, 0.03707950972321053, 0.09989843223123782, 0.05576967254220959, 0.08494066510109172, 0.05719583714380861, 0.08748146464988109, 0.08825188863181299, 0.07210383537195383, 0.0556201781446655, 4.593802969301901, 25.311750942660918, 40.94791681535783, 50.18172141044371, 56.45877276697467, 55.97228903924265, 64.3592970601974, 53.24806959398332, 50.42398268176664, 47.79618686245334, 51.521022550521366, 58.87772590883317, 42.12612621245846, 49.39026555707378, 46.72492481047108, 43.14696227350543, 52.127342531757975, 70.13241798646989, 83.8096913983745, 104.05414996608611, 101.43981964357438, 95.87268198690107, 90.83589584596696, 76.13976324758222, 76.00896004707583, 71.1147520619054, 79.77829502474877, 95.81576055096042, 103.44558638911094, 103.81897249529439, 80.08775434186383, 52.647319378391394, 56.96423292160035, 39.045178967137495, 13.183315607809252, 33.03234631015409, 43.344971364544286, 48.55048610318092, 52.63104938691663, 52.088444386759114, 52.0438313484192, 51.829167873628684, 45.96142368931925, 22.268066213976955, 14.38212235127726, 15.450337702228179, 25.82154335514192, 21.820774809006725, 30.608531390467, 32.912247257847945, 20.530216963060443, 19.23786267157524, 30.207090531626058, 32.846406352135446, 37.48378146079279, 52.70622945600941, 61.99534731526529, 45.8637958957303, 16.71436071395874, 2.931205615881951, 0.2528583510748802, 0.16661306122137656, 0.08701318574528541, 0.07353537024990206, 0.054156191782244754, 0.06043882522311422, 0.021068756656360724, 0.03442233758828333, 0.014141125063742361, 0.04443293106892417, 0.015552219758260877, 0.07172148854982469, 0.027403307875858682, 0.06053735562149556, 0.08361982992820202, 0.02608345521073188, 0.03081191841873431, 0.09407366656007306, 0.023778367509704926, 0.06459777483776694, 0.13935514725744724, 0.06126546090649021, 0.13572064228355885, 0.11079834653965889, 0.07247536503259214, 0.1746315656289939, 0.12551608300136943, 0.01871561225984366, 0.14360442246881225, 0.03723490299777158, 0.055878866884496906, 0.0971400483901943, 0.0917079947107742, 0.04203648546770696, 0.09700008412642826, 0.27989497288100185, 0.19259160835175745, 0.22140584525562104, 0.16697114603894372, 0.2612609260024563, 0.30138128767571143, 0.1780781645568148, 0.025846433352618933, 0.06895260930421852, 0.07450870794033812, 0.04731376640378468, 0.14569326844667235, 0.23349598440672123, 0.06631696807040323, 0.11317167926820056, 0.11156954427039432, 0.058365389103851015, 0.099577495017119, 0.05558625194093874, 0.049189540347264665, 0.043751852091161475, 0.03996529398606189, 0.07597211207593642, 0.016895919782860626, 0.0903043301115113, 0.16812806137867514, 0.18998127100208115, 0.20725758025242438, 0.16353374016621422, 0.24110959602459786, 0.16634327569796195, 0.2866636661271895, 0.15542451562660356, 0.1966745199094857, 0.20705511853579553, 0.2106890106393445, 0.37780333851133624, 0.2825397535437538, 0.19882408601622428, 0.2086052821288186, 0.19905490830781, 0.1527847605006349, 0.07690110093643589, 0.3152419326286162, 0.13149830272361157, 0.220902280341233, 0.24220392198091556, 0.17922032504312455, 0.13656064237077392, 0.07758860356144368, 0.056277550531611334, 0.10552327959768235, 0.08195216376935283, 0.1061005115268692, 0.18615768020672185, 0.031143973483854247, 0.04320642430215113, 0.011433828753539392, 0.034651524282150695, 0.03509767473705354, 0.09800798770400787, 0.03472299262460682, 0.006897160924235059, 0.0914071060176338, 0.07791984465814407, 0.05708877635639041, 0.04154301759216093, 0.02356237668033329, 0.07465163696437113, 0.047012429549208576, 0.06186720764925403, 0.06267797765171816, 0.027719229129293275, 0.04533083591189596, 0.04443383505267482, 0.021365339935366667, 0.02755997860203347, 0.17946397164656272, 0.046586411884955825, 0.8718884051326783, 0.8510255020472312, 26.450291449023833, 63.426388771303245, 76.51401227520358, 79.46634892494448, 78.88069983451598, 71.7723923344766, 64.25877847979146, 48.16104965825235, 46.42461246059787, 58.18803987195415, 59.62489820295765, 70.01646487943589, 66.98397851759388, 76.40922223368, 76.53760925416024, 77.8997621228618, 82.87814417193013, 100.08439756208851, 101.9520184301561, 118.67362376182311, 124.8209584143854, 126.50043103002734, 143.39553063915622, 120.82568707004671, 115.63435954432335, 97.53683382464995, 102.27790463355281, 117.94142707701653, 132.4945265246976, 138.87317903580205, 124.61723050763531, 98.36225740371212, 118.29412660291119, 97.29881655785346, 69.66625213623047, 100.46024691674018, 114.59685341004403, 104.62051668474751, 111.11823666480281, 100.96549526337655, 96.0954333889869, 94.13891592333394, 98.41755497840144, 67.85470547214632, 59.30925330808086, 58.65766133031538, 60.04450944162185, 60.43424790905368, 61.48471355438233, 52.98937751400856, 32.647087189459036, 26.180485333165816, 48.47955003861458, 46.033399181981245, 48.770021161725445, 63.799139453518784, 71.92862033843994, 74.04474689114478, 45.85562952103154, 14.732889129269509, 2.565070010962025, 0.4193936390501838, 0.14225426911106034, 0.10549471217898593, 0.016054331020812596, 0.09115379138459122, 0.054904954628117626, 0.06534641894001154, 0.050315134182211854, 0.0073502890037132375, 0.009566680960086806, 0.00812179412722828, 0.04764524881818122, 0.010637364485451292, 0.05920734271527298, 0.11100224084070615, 0.03405412508835716, 0.07810988042864107, 0.04892354695907524, 0.09579983119282032, 0.15226434165191266, 0.043913048481748956, 0.13325348676693055, 0.07076862072872539, 0.16673379667824315, 0.1505368133826602, 0.07842559292311631, 0.021709376615622354, 0.1251852096268727, 0.04920508810168794, 0.09964368501377684, 0.05440901994945542, 0.09052313248356504, 0.08877430697001758, 0.02910706635204054, 0.061969135647579554, 0.07646433888904511, 0.001426839237777336, 0.04237317727998861, 0.1475988355495276, 0.11343725896891087, 0.0846000777317151, 0.09829367721273054, 0.1293337059717986, 0.11007019528938879, 0.0981805949742275, 0.13795541268923592, 0.2694071679105682, 0.13700466693168686, 0.06663011417033211, 0.09802273489655026, 0.09075166417225715, 0.05404175739855536, 0.0136504246808228, 0.016115230222743367, 0.14772743106849734, 0.10453515641030767, 0.16086934765260066, 0.17434120298393313, 0.1917780229761716, 0.2906749024987221, 0.3578921924194982, 0.20661736057410318, 0.3130759262750226, 0.5484392806406945, 0.45826273399495315, 0.39044323767865863, 0.30599742707225586, 0.5357059800336438, 0.5834990799907716, 0.3977688768457982, 0.43072646964461575, 0.38356150049836407, 0.32612010536174624, 0.21668001739007814, 0.36544606450103945, 0.38333964143549243, 0.4814566894164009, 0.5687079446450357, 0.29647942812692735, 0.42983060642596216, 0.32185563096596354, 0.2287108766575975, 0.26620924112296873, 0.1295141656432421, 0.1892456274119116, 0.2085938827405053, 0.18257428861914143, 0.2698108043161131, 0.2919988862929806, 0.170369956402048, 0.1800802434163709, 0.1081489080623273, 0.18124287377201742, 0.22899553960850164, 0.23108524360483695, 0.14507307430669186, 0.10206134358961737, 0.14804776307315598, 0.15965931177619966, 0.27278282709660073, 0.12997665292313024, 0.2050016351765202, 0.14338158281339755, 0.11891446587058807, 0.1674215444513867, 0.12622008716026623, 0.24670714001742103, 0.25808840269042604, 0.15933982246825773, 0.24910219133861605, 0.2247449467259069, 0.17722195404912197, 0.19341014265533418, 0.24948836093948734, 0.18304091277382067, 8.98015864433781, 51.232457699314246, 100.62653187782534, 119.05282282060193, 121.09783680208268, 104.07780970296552, 103.02230773433563, 84.08089976156913, 82.76425423160677, 85.1049364766767, 88.3774640483241, 102.6084819916756, 82.20994487885507, 96.62915814307429, 92.14000548085859, 86.22437307911535, 93.58823084062146, 99.79247123964372, 104.33084964752199, 119.14120166532456, 132.28511902593797, 142.96934158571307, 149.7143905393539, 132.31469369703726, 128.97975337120795, 111.03934995589718, 123.02483450981879, 133.88463020324707, 147.08160154281126, 151.50964367774228, 132.7899751355571, 103.43363100482573, 132.1806113950668, 131.31102977260468, 100.88700079148816, 116.20390338282432, 130.014294193637, 119.53077147083899, 119.18703848315825, 114.36450789051672, 117.93100926183887, 106.35243923433366, 99.42405869883876, 65.13582045032133, 62.596383863879794, 60.86225301988664, 74.14326114039268, 74.46905320690524, 86.82367201774352, 81.09494055471113, 61.621055141572036, 48.45875363196097, 70.6558661307058, 67.99190998077393, 76.68713000512894, 97.11626160529353, 109.42104278072235, 87.86803445508404, 34.52370597470191, 4.778543172344085, 0.4752696407658439, 0.29855200239727575, 0.2291368521870144, 0.239943579560326, 0.17313450725088197, 0.35126093534692643, 0.17971049874059616, 0.14579526539291107, 0.08372381104216461, 0.12945974275710123, 0.08525987861738091, 0.07640802376573125, 0.11141646458136459, 0.1903866387663349, 0.2915537279219397, 0.17086627412467234, 0.14069357946995767, 0.18392272593994297, 0.17908981430434412, 0.16825121767338247, 0.37167849620023086, 0.16115428639515755, 0.20306628257516893, 0.23554710821518976, 0.2714179954942196, 0.3597687094682648, 0.13700339522573257, 0.1881671594756265, 0.3465089838831656, 0.13774691419976373, 0.2569068652848082, 0.17699804187061327, 0.14417791588892861, 0.2230776942545368, 0.1473920837405228, 0.2727672601899793, 0.21995881241896462, 0.26390233587834144, 0.278908833861351, 0.3241858865705229, 0.45021976073903425, 0.2156352726442199, 0.15839252410636795, 0.18632844120504397, 0.20222340199735858, 0.20818443938849435, 0.2853568733459519, 0.32869575425021114, 0.11856827073760572, 0.16505755033464203, 0.17777473245176578, 0.15850950573240558, 0.1253842239478423, 0.16440441441391745, 0.10570327961637128], [0.050806644703111345, 0.062472187283058325, 0.05991808844790344, 0.03566474450992481, 0.03577770034392034, 0.08139355543760524, 0.0769475105428888, 0.1718027400033128, 0.13143744469890672, 0.14653352900378167, 0.33822417199130983, 0.264307412529184, 0.06768579865174909, 0.04651531126470335, 0.20760084892953598, 0.19925131792983702, 0.06336340800889077, 0.08171345077214703, 0.06922925131455546, 0.031104690410316955, 0.0546857807034206, 0.030490707328182556, 0.07812422925546285, 0.08878467980051234, 0.03318042479335301, 0.09241258109649343, 0.2600078819499862, 0.22204090150133257, 0.17604243911562428, 0.1859661582256517, 0.04559433951433148, 0.016501001457894043, 0.05644175764774123, 0.07870346833501132, 0.06236259457505038, 0.03977535397655541, 0.023160306924593546, 0.025203120594303456, 0.010746445829769777, 0.07179945331787871, 0.05861339857801796, 0.18096564187397882, 0.057949774913609996, 0.035153173976728035, 0.05418248008936644, 0.044970131073627746, 0.055590549694193955, 0.05667138867260468, 0.0768262924506299, 0.050818354357033975, 0.09321278291604213, 0.06186481362449066, 0.055369119640559926, 0.1364276648288773, 0.08077760542472524, 0.014898373290986545, 0.033486890606582165, 0.034667723211309606, 0.07246634817772335, 0.04616135949148767, 0.13674568324800462, 0.09360483607217189, 0.05156549309650737, 0.9706136656384315, 8.397864160999175, 29.111902021592666, 54.53967863513578, 61.772862634351185, 80.8825049861785, 69.96165367864793, 60.97382876180834, 61.91738628572034, 65.45687429366573, 67.29959595587947, 70.30078180374639, 70.69426613469278, 75.7409837169032, 74.19258102293938, 68.68480451645391, 69.17477915363928, 71.51102912041449, 65.15747193367251, 68.12807898367605, 52.910655544650176, 56.8282090463946, 78.94035124009656, 94.7006699346727, 83.32580427969657, 89.29037217170962, 83.04373879586497, 82.57368979915496, 47.86022740025675, 47.10137428775911, 78.81362730456938, 80.6548192424159, 93.45647842653337, 44.92473340803578, 44.842661734550234, 40.68167417280136, 40.84643725425967, 57.630569088843565, 67.55553060962309, 65.78361557376, 46.64956431235037, 40.38248754316761, 55.62387666394634, 49.9889329941042, 43.43227155746953, 36.77833926293158, 40.359063148498535, 35.39850042712304, 41.87025823900777, 38.58317867402108, 48.65169894310736, 57.511478085671705, 53.37499357038929, 31.35868468592244, 6.723414140362894, 1.1425301696985, 0.5611036333345598, 0.1782755394496264, 0.03924529391130613, 0.04320834335240145, 0.019470624467958848, 0.008089130053356772, 0.05115766619001666, 0.04690109016073327, 0.020535067249570164, 0.10836741932096983, 0.0023260078864217166, 0.059295435165686, 0.02784334877956539, 0.03551157672078379, 0.06429006796210043, 0.11826791064513308, 0.056577818693533066, 0.022260776060002468, 0.12150230321792826, 0.02993863564164889, 0.025486693785135305, 0.05596030969172717, 0.03698295583167384, 0.05885180514005404, 0.05638137076710982, 0.051164070685063644, 0.03620461050060488, 0.15086600136372352, 0.1622053130619949, 0.07069588068031496, 0.17056486449174343, 0.14018573978495213, 0.09053312993097691, 0.1366807343137841, 0.1471789427582295, 0.04791725982701586, 0.0016943557045212196, 0.10961834897076893, 0.0733736950543619, 0.1916852803720582, 0.1300895589614107, 0.18987089305395083, 0.16697402652953902, 0.5676915604741343, 0.20637307045680864, 0.21441970561300555, 0.14901154764717625, 0.07754369548732236, 0.03506695461128989, 0.08341490906933624, 0.04837274123283644, 0.0521179688944211, 0.032789804221641634, 0.009678349766369549, 0.03674069967781825, 0.02251677583121965, 0.02676705653298526, 0.013589779245516947, 0.05134847953975682, 0.05311499402347592, 0.02710352617976887, 0.05544265642041161, 0.17063047226157882, 0.06205923141791456, 0.09474854405608871, 0.07856274564420024, 0.1853353614287992, 0.18440948288527229, 0.08728764440503814, 0.06451828555474359, 0.05497740739355645, 0.24021566334751346, 0.11562998646930342, 0.17080077360714638, 0.1620093937362394, 0.23786881427851417, 0.11847856184167248, 0.14122360506125037, 0.15388334590581157, 0.22721380295772708, 0.16332090561909063, 0.1379030429187321, 0.19285949397711985, 0.2015358840505923, 0.1090848989664547, 0.06840047441543111, 0.1461966035346831, 0.11023343330429447, 0.07143648852023386, 0.04970134070683872, 0.03990870690153491, 0.050041418627745686, 0.019359311892560894, 0.029024765526335088, 0.01959679531864822, 0.022862275739410715, 0.030740848441998807, 0.034774489054876956, 0.026872497044443607, 0.03389412762537118, 0.0634323367698779, 0.04573126623947774, 0.02178653699135588, 0.04075176751000747, 0.03160026311243494, 0.07236729300911389, 0.04865802854539887, 0.03912519047697706, 0.032816372150855685, 0.053119096424310445, 0.04948510855977093, 0.08213978636288836, 0.1323141710412118, 0.02586137589758202, 0.08186470717191696, 0.022812215723998608, 0.13310011596448962, 0.08533864011687618, 0.5447769513533962, 0.800335854291916, 10.289278126532032, 37.9926383879877, 72.90616127752489, 98.30658328148627, 105.32854372455229, 93.46395446408181, 78.19342997766311, 68.45853867069368, 75.1140477580409, 81.56355396393808, 73.98930811112928, 81.56549945954355, 80.25806365474578, 88.144804739183, 85.24798531686106, 79.89689965401926, 83.83386888811665, 94.87003003397297, 73.28840409555744, 71.51968186901462, 56.31173879869523, 61.30759108451105, 81.83176563632104, 92.51781602059641, 80.76004858939879, 91.87206837438768, 82.07037910338371, 76.75422606929656, 51.84600660877844, 50.70034896173785, 83.29700623789142, 116.6707831044351, 144.6849706096034, 65.45940030005671, 66.7367515256328, 53.52065863147859, 49.94424150836084, 65.83202546642673, 83.43451669139247, 79.84312395895682, 65.96602147625339, 57.79852497962214, 79.31550241285755, 61.71669821585379, 61.76210357296852, 55.84371766736431, 57.38083962471255, 56.58765400609663, 59.13509222768969, 64.2920833249246, 72.25289052532565, 73.16520244844499, 72.82259910337388, 59.07160474408058, 30.77890346127172, 8.107094937755216, 2.5160798526579335, 0.560013214426656, 0.037090070245246735, 0.026001537428988565, 0.03952725257183756, 0.022405725640935764, 0.05778428843064655, 0.05664270634071962, 0.043718488962059064, 0.054066647595215234, 0.013361368215672914, 0.04920854315822644, 0.029861142017668294, 0.04057463649059496, 0.039749624913618456, 0.07609807991332586, 0.05335719272073719, 0.07180031133635391, 0.05142658986451645, 0.06323743634106171, 0.02732971555463249, 0.028001061385317196, 0.0470833424779196, 0.06152921731794073, 0.041921694853132775, 0.0723454058771172, 0.1038031287551407, 0.14073462646094062, 0.11319377324393681, 0.06079011101035341, 0.09135115095564435, 0.11779384777670908, 0.17484668311813187, 0.0758349976592487, 0.17383435921322915, 0.0690702957311465, 0.016869857471676606, 0.06364252448322312, 0.03270531238447274, 0.07700488286753816, 0.054173363643067504, 0.14725060262266668, 0.1940924971694908, 0.08492902056464265, 0.08403580801020707, 0.16014950079542978, 0.15543157895726545, 0.08557859417651931, 0.06691569642674539, 0.07937653020264641, 0.0076952808998495105, 0.03441926557570696, 0.08657384964246904, 0.05432453194272615, 0.035233505956468084, 0.030527720866244168, 0.019974472834878874, 0.20908229443575108, 0.11222587477776313, 0.13597202637503225, 0.11255182220690674, 0.12497089653005525, 0.24527146060380245, 0.19813760994903504, 0.23677015226454506, 0.17251521709465212, 0.18675434012566844, 0.4042912575025713, 0.32938676555791213, 0.20351111918928164, 0.17631469144215509, 0.30866846922905217, 0.3382327521760618, 0.2621260537735878, 0.3381556224438452, 0.4205434450939779, 0.14115844162241106, 0.19532193039213458, 0.25421991914270387, 0.33947966752513764, 0.2785879655951454, 0.356375185111838, 0.27341619794887884, 0.33852077059207425, 0.2936624615423141, 0.1886522463492809, 0.3925280999993125, 0.16063855600453195, 0.09808427473950772, 0.10719776393905764, 0.2367832983333257, 0.21898011977393783, 0.09396975439402366, 0.14856513289193954, 0.15271406590698228, 0.12190349580299471, 0.21037229456968848, 0.13588470767342276, 0.22863808298303237, 0.2714999975456346, 0.1368659130868412, 0.19591111329294023, 0.15116106778863939, 0.13704569860091134, 0.13297527427634886, 0.12892671410114537, 0.123887280482919, 0.21633258119465845, 0.24004052032626447, 0.13437951344155497, 0.23825455487014788, 0.182321893291608, 0.20915703397364388, 0.1388776752977602, 0.20906390832556834, 0.20408891802353246, 0.15481251862741288, 0.12330211954371584, 0.15896603284824282, 0.12466827647820597, 2.257268140392919, 21.3406119808074, 68.4739222065095, 121.21861442442864, 137.490323897331, 142.89539706322455, 117.93158192788403, 101.65107850105532, 103.14669393724012, 106.52430180580386, 105.53551935380506, 106.59532808488416, 107.9203204185732, 119.04789632366551, 110.22352049427649, 105.37224677301224, 102.18794115128057, 111.7902563464257, 93.13319667693108, 93.72311330610707, 76.70532195798813, 80.94738883356895, 106.01680986342892, 112.71004430709348, 99.38521938939249, 119.76145390541323, 105.65334735378143, 108.72176262640185, 66.9429583703318, 64.18226480484009, 94.995953805985, 134.83368689014065, 150.6226545764554, 78.46641909691596, 90.971539251266, 83.98064397996473, 77.2643538444273, 98.29481617096933, 105.64949558627222, 107.4760727728567, 88.29922845286708, 84.14055116714971, 100.95397133981028, 88.50821233564808, 87.43407126395934, 77.9396604722546, 80.8301648785991, 77.26628365055208, 89.79257675909227, 92.55743195933681, 108.89695921251851, 113.48137055673908, 93.50464513224941, 51.470004281690045, 16.192982600581264, 2.020333325189929, 0.7931004909257736, 0.3927397547710327, 0.11754552037605356, 0.11427847713592554, 0.2909584469612568, 0.11151923527640682, 0.132456065846547, 0.30264281998238257, 0.09734630224204834, 0.17152320984150135, 0.14752139938214134, 0.11155853558692241, 0.12084322245491129, 0.1279618799866688, 0.13936807882160912, 0.2373005608997999, 0.18986638845695605, 0.13549227147333084, 0.29625885609176855, 0.16002305032264802, 0.1578571512213638, 0.2539891887816691, 0.11687978996985382, 0.20209342752012516, 0.11923929481136224, 0.20983168164328223, 0.1987257050049882, 0.16058670717381662, 0.18017543750184198, 0.19508785988774993, 0.33671470298882455, 0.24329636336093952, 0.1489337744011033, 0.1103382264714568, 0.29772928525363246, 0.14578443290966173, 0.0908243888989091, 0.3546505986202148, 0.1236217390866049, 0.4115502163767815, 0.20621257503667187, 0.3534301286262851, 0.45085987316504605, 0.4651684956925531, 0.2020305623450587, 0.32510350668622606, 0.29818201257336524, 0.11877059455840819, 0.19966921889253203, 0.09176082413403258, 0.10466072588197647, 0.10082576634182085, 0.19696558735543684, 0.07712608563803858, 0.10707505197534639, 0.08786595651819822, 0.14295611290201066], [0.0270595048524199, 0.008808960631159286, 0.05234779910214486, 0.044971571318925395, 0.046461562535935835, 0.04432204750276381, 0.03152626667982869, 0.06644756307885533, 0.08328064449972684, 0.10031090163054968, 0.11322339786396873, 0.20147689528042273, 0.03141716235287247, 0.13714164345254823, 0.1461462562362994, 0.19374329897184528, 0.3141740367056862, 0.05488888210346622, 0.15398644601866124, 0.015502522677002896, 0.08122328473555465, 0.1271909044214314, 0.08772457499177226, 0.13513930412309785, 0.1511655110986002, 0.07173618977709163, 0.056216780607017784, 0.06355064755846417, 0.04515479656777555, 0.06940034939156425, 0.058343452176139246, 0.03729889815252635, 0.05200850259092066, 0.037881213075090805, 0.02113200870582894, 0.11996237455957359, 0.02654195500297412, 0.016991110037892096, 0.04066553282281084, 0.02311596000987676, 0.07861766648749191, 0.050974280062702396, 0.04391253903327931, 0.026268319887739998, 0.016021346147622795, 0.04361618941109027, 0.0553419656540838, 0.10722640796654648, 0.051841633319253885, 0.05533790921852474, 0.02472546285829477, 0.06810431248478352, 0.047360248788590395, 0.055532254233595826, 0.02756835768870529, 0.05709582436529379, 0.01827697329703839, 0.023437504348675572, 0.07013696591339766, 0.012781314210094994, 0.03614904997389644, 0.06033571744938532, 0.08623389812606959, 0.06702253504866554, 0.2039390559037847, 0.23096749589087504, 2.329768740361737, 9.008683100823434, 29.58444956810244, 59.18998579825125, 82.05108888687627, 89.60074147870465, 88.53576306373843, 89.47788500016736, 80.01274293468845, 79.35953494041198, 81.96715800992905, 78.30556269614928, 81.57918853144493, 72.47962705550655, 76.05663253415015, 73.20447321861022, 99.67689468014626, 88.02332109020603, 73.09666295205393, 84.99973850865518, 92.09048947980328, 96.61449632337018, 84.22858484329717, 81.91191534842216, 79.0009989277009, 76.71118197902557, 79.57340609642768, 67.57679770069738, 63.57786678498792, 69.39865235359439, 64.05668620140322, 62.28266093038744, 63.281359134181855, 67.07773885419293, 68.19801484384845, 63.604440842905355, 63.96837011460335, 52.124381142277876, 59.73948632517169, 58.52801915137999, 64.26780385355796, 76.70033270312895, 72.70660677263814, 74.82068584811303, 83.77459403007262, 70.27716913530904, 36.88372158235119, 18.409134495642878, 10.735313392454579, 2.043814226504295, 0.31169601806229164, 0.2619146441500033, 0.12697689775978366, 0.17218877170835772, 0.041657896306846416, 0.09833467823843803, 0.06332524916938236, 0.038354597955701814, 0.031587931012073835, 0.024469076212675824, 0.034345690491459066, 0.1282993493781936, 0.05058338752977791, 0.025153790277639226, 0.022739309051464644, 0.006770723857991999, 0.02058806904261151, 0.03670721014420833, 0.062417201322293094, 0.027248810924169038, 0.03549772202067318, 0.0060232035109713195, 0.02918059738623279, 0.025596734654578953, 0.01869952441343377, 0.04038291149622491, 0.04625007630355897, 0.053293412070601225, 0.07761592225682351, 0.04955015708542159, 0.0458922251428087, 0.011395928468705427, 0.046653222412832325, 0.153936650303583, 0.06752507340523504, 0.10018185411970462, 0.09679413670974393, 0.1095180297570844, 0.11830305109821981, 0.09831957864545046, 0.11847492292403214, 0.07892913485486662, 0.11587311979383232, 0.038793443762246645, 0.0747705567928572, 0.04361288757213662, 0.04217042828038816, 0.06638729494185218, 0.09698415715848246, 0.016766757358826937, 0.1193454362932713, 0.11996142461054748, 0.08127537871440572, 0.09996984694753924, 0.037334835337054346, 0.07674296506710591, 0.08765890593490294, 0.04410053317945811, 0.056549331714068694, 0.029440747438779766, 0.06740875827569155, 0.010049143024990636, 0.07965281981253818, 0.031810023731762366, 0.03162990688466497, 0.04075974631573885, 0.07792115466849459, 0.03604124991163131, 0.04840127800801589, 0.09949543933954932, 0.07120369738268276, 0.1087583463278509, 0.1066027281265105, 0.12541031690254328, 0.10954626775797337, 0.3319793603112621, 0.4120562940595612, 0.23502187833430307, 0.31542931773489524, 0.16172252445211335, 0.05878244736982931, 0.10765314192300844, 0.22382035521009278, 0.2885131249504705, 0.19632671599186238, 0.12899180093119222, 0.09261413116849239, 0.11958959617561872, 0.11563673570391633, 0.12811836110608232, 0.03372691361413848, 0.07856557250864084, 0.0690164091065526, 0.026639160069246447, 0.019535406778055816, 0.06615684803334937, 0.04255978863746409, 0.06601126834509835, 0.05890178088579447, 0.04034380653813001, 0.09087561719840573, 0.04463960243869693, 0.05849158293717812, 0.03211353627604342, 0.007109842732578757, 0.010572007609411113, 0.036615708602532264, 0.016832593039819793, 0.06910603373281418, 0.07369432583331101, 0.024234337296577233, 0.020013459049345508, 0.05209734197705985, 0.027381514589632713, 0.010819348671864118, 0.01311415260011751, 0.07228928993666364, 0.11181329812614188, 0.06560711099976493, 0.07154807688728457, 0.02347753627315885, 0.0321627842382558, 0.06338714907366423, 0.2404103569325901, 1.2594688948123687, 1.634685031829342, 17.68359407301872, 41.84997174047655, 69.59783815568494, 96.02309703826906, 99.76220623139413, 106.48783945268201, 102.09919360376175, 101.12551227692636, 91.18378654603036, 91.27187513536023, 91.33655501950173, 88.38828978999969, 93.01576091397195, 82.79585284571495, 86.37566674140193, 93.3819612379997, 100.05180266595657, 88.80735581920993, 81.11613704312234, 95.79268132486652, 105.98032397608604, 107.91288360472649, 98.80682668378277, 91.42698918619465, 86.68994272908857, 76.11365595171529, 78.02736466930759, 60.24839032080866, 58.73321010220436, 59.40097008982013, 62.057528649607015, 73.19508306441769, 83.53270146154588, 92.3191636608493, 93.42538972054759, 82.10017342721262, 88.8297603976342, 75.2257490158081, 78.82515907287598, 74.70572117836245, 83.48358554224815, 91.85595527771981, 86.77316757940477, 93.60679934101721, 95.15965784749677, 95.13877514869937, 70.75414503774336, 47.41535609768283, 30.38828246055111, 10.678238984077208, 1.2913782341826348, 0.5802573023303863, 0.05559415796831731, 0.18929435060389582, 0.06950072989228272, 0.05994271051378981, 0.08431205931570261, 0.020912624106952743, 0.00869082891562533, 0.06022246667153894, 0.04228708431905797, 0.08616557074410301, 0.06955786472967557, 0.07099483883188618, 0.08206506214675405, 0.022070418532577255, 0.05785050907082135, 0.02710184078633545, 0.0110848335691938, 0.10075822803041629, 0.04620554744296017, 0.012416190959723487, 0.040622612746853026, 0.050211884682216955, 0.039509303131771666, 0.04849783956043182, 0.06288086454714499, 0.025441036860068, 0.012310190246470515, 0.05106250274806254, 0.045675816795518326, 0.08060179590698212, 0.04837282933294774, 0.057110372374975876, 0.06761203204552013, 0.05344910028901312, 0.12222530635734721, 0.1068054656347921, 0.12542538585201388, 0.13202341003043036, 0.11781719813664114, 0.03873190391928919, 0.034140129949176506, 0.040732136506947784, 0.06120049665051122, 0.03310029199647327, 0.18057440077104878, 0.09291865111839387, 0.11223775680146872, 0.0652632447740724, 0.08663291502143107, 0.12698625935421837, 0.059923025884575425, 0.02864101101764508, 0.0631285637557026, 0.04348059184849263, 0.06526977184318727, 0.06762119445709452, 0.037401588408336524, 0.08594743486854338, 0.11177504735608255, 0.13878692452224994, 0.21766528306949526, 0.12008076578739191, 0.08369893616726322, 0.2030277943178531, 0.11726158520867748, 0.2313078227903574, 0.24447888135910037, 0.18488450336360163, 0.10521265392702435, 0.341592752524922, 0.2326672458119931, 0.25013228848336205, 0.1911831710247263, 0.37462585094955664, 0.37856004951942357, 0.3554913035083202, 0.3621536024635838, 0.253253591156775, 0.2127862835843717, 0.2604527338858574, 0.23262940106853364, 0.25490181400410594, 0.24676717066716766, 0.2654091695383672, 0.18835514213048643, 0.14950737507352907, 0.16289977176535517, 0.1947436872268877, 0.17168545194210547, 0.18122153056244697, 0.14837043930686292, 0.22735525343206622, 0.10851014916214252, 0.1717167236511746, 0.18997998397436835, 0.24109761440946212, 0.18593713881507998, 0.09722702235223786, 0.15418999558014257, 0.12314408326581602, 0.14044187362155608, 0.15149279918161132, 0.15701428596531192, 0.15058124648226848, 0.09626791091455568, 0.21531918476666176, 0.24856050588911582, 0.17799346587590634, 0.16513394462245126, 0.09862637387648707, 0.2594644804635356, 0.12090568160337788, 0.11141722300840963, 0.17727725027549654, 0.22161952249946135, 0.3334602082688963, 0.15228658884523377, 0.16034744259330536, 0.18244627532699417, 0.12616376437607313, 0.19916183886028108, 0.18901215445610786, 0.4477208738605823, 0.17865355787498338, 5.217832942162791, 24.988533912166474, 60.11080141990416, 105.92350452176987, 133.4794807434082, 151.4297842210339, 144.6818797819076, 136.85712783567368, 124.79865581758561, 116.6869354248047, 110.09720448524722, 108.69656532041489, 112.08863889017414, 100.26820767310359, 102.15164353770595, 98.84919612638413, 117.30331236316313, 100.25030597563713, 87.79657671528479, 103.59929623142366, 123.36732018378474, 122.6693501011018, 105.20634620420395, 94.69768893334174, 94.82069446194558, 86.71867016823062, 91.80232078798356, 79.3386600863549, 75.3108879827684, 81.64006371651926, 77.80892787441131, 78.481488843118, 85.56656806699692, 98.61652112776234, 104.99809972701534, 102.16460304875528, 104.26927628055697, 90.09230075343963, 94.30309064926641, 96.70503247168757, 111.82028601246496, 124.72500939523022, 124.69157511188139, 131.33953755901706, 132.6913667494251, 108.70419825277021, 75.65946901998213, 38.74445084602603, 19.187142502877023, 3.430097761654085, 0.39492935663269413, 0.5637958501615833, 0.19770501541995233, 0.2687466162587366, 0.23813590317243533, 0.17239347040172548, 0.1725812538737251, 0.12760056227806116, 0.16673074764830453, 0.15955541493190875, 0.16613454738211247, 0.19960039355341466, 0.14168477466990873, 0.08753468477798086, 0.18649089781026687, 0.1815743753386121, 0.1976408632171731, 0.17928227091268187, 0.21112941926525486, 0.2305280372139908, 0.0880207828876953, 0.051832310029215393, 0.13147141303746931, 0.1036334632625503, 0.08902229729198641, 0.18674208271887996, 0.1444823132647622, 0.14387993832990048, 0.16671570168147165, 0.13799682740242253, 0.1426314141961836, 0.07481975495935449, 0.08832831356313922, 0.24648203274175046, 0.1894850605317662, 0.11438036682985483, 0.14838067424153129, 0.1823041200517647, 0.1987476304413811, 0.23768115338058243, 0.19882669071516684, 0.18985135781188167, 0.4120401142826004, 0.0742361645003961, 0.16224409243272198, 0.12461452774943844, 0.2766332769345853, 0.2571815078056628, 0.3533545310699171, 0.17324784229840004, 0.23005228129125413, 0.20149027117558066, 0.20531035328824676, 0.1149074889479145, 0.12340261495762295, 0.21517129915375866, 0.1537266809252962, 0.15369525599864223, 0.1726278013760044, 0.16744481820252635], [0.10856680136414305, 0.026017979591063438, 0.027534502348111525, 0.06931596480670475, 0.029829872223818978, 0.022882385547423077, 0.04816022844264104, 0.05014892757659958, 0.0834232594277109, 0.06371093613486137, 0.09364489480973252, 0.026749959365735133, 0.034750713516146906, 0.11307117619341421, 0.07923609096436732, 0.08381224823214355, 0.002591795627883966, 0.12183509947311495, 0.05005908078483997, 0.09891132794080243, 0.040216046054997755, 0.05696535576134921, 0.05955939075999683, 0.05018358156385441, 0.07078992563389963, 0.041467025500511935, 0.04123005535333388, 0.05369094658582922, 0.046967605744758924, 0.04616780612137049, 0.04258691581086286, 0.034422463992790836, 0.06562522131829493, 0.0011769894767747892, 0.03632528850087716, 0.059590179833673665, 0.043463354870196313, 0.0072943502210921825, 0.03514447887878745, 0.09765869757581143, 0.07019921055724544, 0.04686972269067361, 0.04327103615768495, 0.012904968461953105, 0.03977080724472481, 0.035133022033879836, 0.02240939137165345, 0.005127723815084826, 0.0618527056048474, 0.06381292925066044, 0.06380798415310922, 0.022668459325007374, 0.05765056012258415, 0.050972372503770944, 0.05323034388223483, 0.047796589487622824, 0.028571860091159904, 0.03573013777514139, 0.0455405984464432, 0.024927733052942543, 0.029857717604646762, 0.014184811227624456, 0.035033832799883625, 0.04023283104141874, 0.09730828129836629, 0.07153164430130875, 0.051159520122793414, 0.1543645410528106, 0.027739518967967842, 1.186348315208189, 5.813904260435413, 14.622927442673715, 24.431072934981316, 36.75106702312347, 70.30388047618251, 102.26758879999961, 110.38917787613408, 118.71152954716837, 128.74630174329204, 125.4978967482044, 118.03962753665064, 119.7499692055487, 120.89836074459939, 117.1753881823632, 119.84514944015012, 130.99993874949794, 71.16455047361313, 80.5761129625382, 110.61148997276061, 135.00057589623236, 125.24906158447267, 105.97765676436886, 99.62326019041001, 89.56665608190721, 88.95235799974012, 90.66363319273918, 96.22269861159786, 111.62935287721696, 121.81238282111384, 105.92649336784118, 81.19502375202795, 82.69108633841239, 82.21723264263522, 102.08497108951693, 89.10132961888468, 83.89324572778519, 64.50537397015479, 51.923230232730994, 38.13754250926357, 24.58156055019748, 10.30604527842614, 1.3748456585791804, 0.5118052625367718, 0.5422774822481218, 0.3337749171881907, 0.15142216587499266, 0.07314207603133495, 0.031043667676708395, 0.04819903079600585, 0.12456711456780473, 0.05963984914424439, 0.013001846025637802, 0.07063724431059054, 0.042677930886707, 0.03273132873038131, 0.012016618650616899, 0.008823469378835252, 0.10176689769592016, 0.022817457680620497, 0.038054421724330996, 0.05772360660616429, 0.04819341920196049, 0.04663898466875957, 0.017435559777603034, 0.041584554879415425, 0.04276148426616865, 0.050461828528392705, 0.11777506330080571, 0.006684912434373532, 0.021487841224898736, 0.0604801097013537, 0.030462268229213454, 0.04920200842823233, 0.02553897737074764, 0.026287422290131934, 0.05154616086773815, 0.06041457087943151, 0.0943134980456483, 0.05978553991524443, 0.0513225436330803, 0.01141676893307557, 0.07737244419272869, 0.1041306849689253, 0.049724296531489784, 0.039242283185763706, 0.04997043292068186, 0.05603735132383243, 0.00798002093835103, 0.02483206207773859, 0.09037926117138517, 0.015525769615065188, 0.05438248266375834, 0.03478737848420297, 0.04134483064614958, 0.04089237528762991, 0.061021538511399305, 0.05658420020594232, 0.08630326738761318, 0.04108491616563932, 0.06612975916434681, 0.0775975208248823, 0.07151449159268411, 0.15640717660707815, 0.0475798670442835, 0.011727907882642843, 0.02648046495573175, 0.04949615554763906, 0.008361269381918736, 0.07593355487070738, 0.09751679510959695, 0.021278624527997548, 0.019874414091088602, 0.038777712146721544, 0.10140204832198159, 0.08193158664770665, 0.08625658198950753, 0.03873882935412469, 0.05457607691266364, 0.05859694300940441, 0.056248075298724644, 0.043061614532264016, 0.22600186718327386, 0.03821092965682188, 0.09827707608741137, 0.06338072159597952, 0.09018691181535683, 0.08563004464151398, 0.01731689658857161, 0.04257267806679011, 0.02800886016038637, 0.0799722018681707, 0.10332304443563185, 0.041896835299989874, 0.06527473609293662, 0.05771835507344335, 0.04579621900413786, 0.03883906812857717, 0.044517545480160944, 0.04617065979888843, 0.032037938719675425, 0.011351272245989212, 0.10338366497308017, 0.017296911269846945, 0.05865417360778778, 0.011632867014756607, 0.07852693869461937, 0.048413711615026965, 0.0559467499354674, 0.05669439812341044, 0.05788864109725241, 0.008854097574047985, 0.047785527177996216, 0.03048986654668566, 0.031551764001168554, 0.02974329471227623, 0.02837128295082479, 0.10783678852021696, 0.04428993309697798, 0.06403278499361008, 0.04604269247201662, 0.034473519922504504, 0.014025413228439228, 0.0352931956970884, 0.05085495037717685, 0.03749940634494828, 0.03353999582149329, 0.044213420065540465, 0.0321529055344722, 0.06408981257869352, 0.09577461923923224, 0.043286369407489415, 0.044389654762081565, 0.19409278828290202, 1.2888246486263892, 0.348814694030631, 8.11656795201763, 24.44051015761591, 41.45504005493657, 62.37269109295261, 74.9506025929605, 103.59282432063934, 127.42495721386327, 130.2289027552451, 138.62997639563778, 144.5005407641011, 138.74629820546798, 134.49890475119315, 133.4274701149233, 140.32348325175624, 144.60980230762112, 146.43202566331433, 154.52979026302216, 93.67522116630309, 104.94808166257798, 136.49032346663938, 157.34431051438855, 147.601221453759, 130.007351598432, 123.43858964981573, 115.67668191848264, 121.85042196704497, 124.97695892087876, 125.54192927575882, 134.21170880717617, 142.9475175180743, 144.5476248956496, 118.31080452088388, 122.36990851740684, 117.52598531784551, 127.71365934802641, 119.17068219953968, 119.10389992498584, 97.72680205683555, 84.7584342956543, 67.28160012152888, 52.662326366670676, 29.63683282175372, 9.533836495491768, 2.201090483896194, 1.3480933779670348, 0.524935212827498, 0.20728839230873894, 0.24747316665466756, 0.13601793036345514, 0.07782187733438709, 0.08993767277007142, 0.09803739015854175, 0.06247274269680343, 0.0013393558272641274, 0.10225423686807195, 0.020151479365003687, 0.03128510603170482, 0.09013224378108017, 0.012839129908130536, 0.03210089391007299, 0.07050261201877749, 0.020483137979622812, 0.045006949259268667, 0.06897828857144041, 0.04462349927052856, 0.037936968954219934, 0.07922414765362779, 0.06922125335662596, 0.04441331921806259, 0.025728988243387114, 0.034897817719367244, 0.041311298977703824, 0.06441464918034692, 0.02323242261134569, 0.06107597671929867, 0.06359642514237954, 0.05545060458262602, 0.01716350088827312, 0.04924228167041175, 0.0180302795788814, 0.03288308308730203, 0.051467108254831646, 0.08042924226291719, 0.06742049474269152, 0.02383341092706448, 0.07470556955424047, 0.06285809641403538, 0.03117725617372461, 0.060976553828485554, 0.020317888983915892, 0.05600499943079007, 0.06881613074050796, 0.014490290702651105, 0.08775536406544909, 0.11557355643280091, 0.03669258552573381, 0.012015874587720441, 0.013568492534930908, 0.06002662395457587, 0.06007539694227519, 0.05173565654624855, 0.12125124854426231, 0.0066154201199570975, 0.013388789375312628, 0.009989852607700854, 0.06913522168272926, 0.03159961002247949, 0.1624756654904735, 0.09240812246477412, 0.12338092700848657, 0.17518722452223304, 0.14902210433877286, 0.15929209519057505, 0.11456559156818737, 0.2419389628114239, 0.13683871696552924, 0.19792635354303545, 0.07427425439199133, 0.1426722160390308, 0.14575003556186153, 0.14172991257040732, 0.14241491774878196, 0.2273626385196563, 0.14488214987420267, 0.2306574754296772, 0.16737916446741552, 0.21965743342955268, 0.14596199676875146, 0.18722113281969102, 0.233747506394021, 0.25424006725511245, 0.14273557151036878, 0.1616937195461604, 0.22787394092207958, 0.15487598135106026, 0.12364024777085551, 0.10981241436374765, 0.10378434427923734, 0.11824332688364292, 0.13772934014278074, 0.0992144842541987, 0.1340142886845335, 0.169210497650408, 0.10191878994866725, 0.23263739902646313, 0.14545222654217674, 0.18621568838434835, 0.22195479321864345, 0.12260527064603184, 0.18646226144365727, 0.2083997713822511, 0.167455282963572, 0.17772377228304265, 0.12967152010288932, 0.22188112620384465, 0.15738508784242217, 0.12825180596161273, 0.13960539753879272, 0.11425845925846409, 0.2203295683307994, 0.15699042998734983, 0.11706306118397944, 0.1181396981701255, 0.12942565184447075, 0.12835118288715042, 0.10134348090017035, 0.08367922472497148, 0.06882491776899946, 0.1894536509268707, 0.14276402401587657, 0.1917077420699981, 0.19752668547293833, 0.11615843391947209, 0.2397943149891592, 0.4458734987964554, 0.1473819867016808, 1.91903970895275, 10.517844442398319, 24.558093009456513, 48.09585202124811, 65.51786322747508, 105.0461801405876, 139.5850735325967, 148.4364195792906, 159.43413365271786, 170.74435080251388, 171.43978703406552, 167.80227507314376, 170.89327535321638, 175.43682344498174, 179.59784630806217, 177.04847828034434, 181.57880013988864, 105.36663778366582, 121.49416092903384, 161.7142701918079, 187.43642068678335, 178.78025177986393, 157.7372064898091, 144.68738678962956, 132.097441457933, 142.09193875712734, 140.84150283567368, 145.59039485070014, 167.2372341156006, 176.1760647066178, 175.1732715483635, 139.09622069328063, 141.37086591412947, 135.09927841924852, 147.4150186969388, 133.54129729732392, 128.871927415171, 101.80853812925278, 80.05573995651739, 57.2480046364569, 39.63674299178585, 16.07670589800804, 3.314016687293207, 0.6397578805204361, 0.8439029068235429, 0.4907347802673617, 0.42082793950553865, 0.22114558986598448, 0.13943955482494447, 0.12982763350009918, 0.19582724198699, 0.14771570992325583, 0.09033958547778669, 0.13562907945484887, 0.16552740738036173, 0.13028281230118968, 0.08701913058757783, 0.10608928067789924, 0.19889389194788473, 0.13219922720905275, 0.14953607272717262, 0.13996769583994342, 0.16163065518823364, 0.15148978079518965, 0.0893116410401079, 0.1792579706037237, 0.16958031893497513, 0.1995395661722268, 0.19181044381712714, 0.0964799257476003, 0.13087861420166108, 0.08571128826588394, 0.11193106882274152, 0.1452617924059591, 0.23541033087718874, 0.1395313168365148, 0.19485352891347102, 0.12657483949536277, 0.16855955274114687, 0.09133432000394791, 0.14558676690343889, 0.13971065801958885, 0.2534392908696206, 0.19134109238943747, 0.1360782368048545, 0.11603680980061332, 0.08049803695851758, 0.14081459071847702, 0.1492935599338624, 0.14634723174235514, 0.11529642412619245, 0.11980245370538005, 0.10309907097008922, 0.14250989732963426, 0.20953854575993555, 0.18117260818760242, 0.11875161856052377, 0.15122762550750088, 0.2568446283018397, 0.13194721492548145, 0.1475620939726791, 0.3115630558421535, 0.1584928816244487, 0.19518438696620927, 0.09519148077214919, 0.1439900098428611, 0.0662898868622799], [0.03401403570727956, 0.10256699226315945, 0.014942036472230911, 0.04401828597990736, 0.04178407864885465, 0.04799490666858131, 0.026454404559767535, 0.04654972010382241, 0.07157259170086154, 0.04627922977951746, 0.02700879749271178, 0.058815913920801495, 0.05775477489336364, 0.06504898530340965, 0.04079549963916502, 0.03163472174726908, 0.017033882641924486, 0.06480753737231416, 0.03401340368474203, 0.03034892743603597, 0.047127610868624145, 0.031126161939614726, 0.0646960256140559, 0.07577242359759347, 0.06503491992911985, 0.02401466541472943, 0.030455744990538207, 0.03435799769396263, 0.06800323484405395, 0.022103827626955126, 0.07536531681375158, 0.06957569925655281, 0.027170189235719944, 0.03474050539455587, 0.04633890419837929, 0.05161127451086237, 0.052787384183536616, 0.04034613927585944, 0.05927756233441253, 0.02581141930403969, 0.043473340826289314, 0.04170126454423993, 0.026076428269246416, 0.017481613153171156, 0.057718086942669854, 0.064831669141929, 0.038806804335646095, 0.04338102340097389, 0.04635191237133357, 0.02221582202060569, 0.04438190195228785, 0.022854283527140657, 0.051244670795577194, 0.03465792877719768, 0.062326228381284786, 0.005842493903342514, 0.07145983121928669, 0.046846789848660274, 0.09869808736707895, 0.013054302938643002, 0.027095219871449857, 0.06307608290244976, 0.05291617505492703, 0.06575474380365302, 0.042595580265286474, 0.05405399565314574, 0.04294436477545289, 0.10848519001756946, 0.061549166247489, 0.10233908876656525, 0.11275160261580061, 0.3356127314750226, 0.1831508923562304, 0.08410329269545694, 0.28950597490033797, 1.6675959239082954, 4.944413342783529, 7.495774424845173, 10.15427504816363, 16.66345227149225, 18.537568584565197, 26.695925958694954, 27.124692009341334, 20.106318573797903, 13.86799179738568, 3.552380103257395, 0.17670527370947023, 0.3775425621819112, 1.9927405541942966, 17.164658615666053, 38.84640109154486, 47.14827014553932, 63.09969455965104, 71.62400122611754, 86.2625220514113, 70.1309431752851, 42.67641905815371, 26.972433443992372, 15.477793312841847, 5.150520167043132, 0.8705657083661327, 1.2633917552809562, 2.0985920871457746, 3.5869636410667054, 1.9092312094665345, 0.8342163685348727, 0.2557875801839175, 0.10122170356372673, 0.2894088962385732, 0.38746671030117624, 0.3803811937330231, 0.061726534754158034, 0.21719692755610714, 0.11230857396918921, 0.1013691371847545, 0.05749995106711023, 0.05617004924363667, 0.014804140645860425, 0.05390651989728213, 0.022757402133016337, 0.05624512586021616, 0.007476917591937368, 0.03879452011578026, 0.021194818339520888, 0.014631777566166656, 0.019374928594897353, 0.06472050212323666, 0.03902673668738815, 0.04878673131667799, 0.04494244465604425, 0.0657610027419944, 0.018181126121611848, 0.039566836334885135, 0.09871913180235894, 0.01972661466307698, 0.020263709330690965, 0.055811217490343325, 0.016039559888022564, 0.0679537915294209, 0.07858270223462775, 0.06659516523922644, 0.0024534049565948907, 0.01410931422029652, 0.0754419026235419, 0.033740228222262476, 0.02622363780955634, 0.05231700236758879, 0.034777001823268594, 0.0363775012233565, 0.06840908524370001, 0.021975864130522937, 0.044505008451280095, 0.015978493104358355, 0.07225768880978709, 0.039580637408841046, 0.026463084335949634, 0.04719713717819222, 0.13325140300777652, 0.039491564365884954, 0.02013037747312938, 0.041229319908926566, 0.05843579641453201, 0.04105894961544583, 0.10320690550631094, 0.09514537760086599, 0.03569236197959512, 0.06511054046812557, 0.047145315160554264, 0.02469514684391118, 0.02152385310299935, 0.03801341303774426, 0.07085114371992889, 0.02697964018631366, 0.03987331746987278, 0.04528286348607752, 0.022557841974400708, 0.07685017141122973, 0.0525939469826558, 0.035185376482625166, 0.0694270781992424, 0.09271494067844846, 0.01889858853011843, 0.012385922825835165, 0.05335975145440429, 0.032278436701744795, 0.04721336292042848, 0.027139823425621278, 0.024174886958433256, 0.012383227153951603, 0.05824851473012279, 0.031636596747463754, 0.01058404476592137, 0.029495040089973522, 0.024846703933191397, 0.015456179145633455, 0.009351600817735157, 0.03975163972485931, 0.02972018758526012, 0.03366080788715232, 0.1122972971549438, 0.0380057598193807, 0.014271593667686948, 0.0554784863526302, 0.0036808044552021934, 0.051556556680870634, 0.027747827191506664, 0.03938673289432641, 0.01707425930597369, 0.013267313685989188, 0.058480570423266584, 0.03716329292904946, 0.03718493874335001, 0.03345401011287205, 0.032134297258791425, 0.06475064002217785, 0.04095515236258507, 0.029893480504171985, 0.02511771902772448, 0.011050779045739723, 0.0651897769421339, 0.013030100305895171, 0.06827038502500904, 0.019731852789259246, 0.0036462883637737365, 0.028363915100213022, 0.08007026878335784, 0.02831837500355417, 0.023968389873663266, 0.03500008662681907, 0.03201666637323797, 0.029872644827851368, 0.08988955478754737, 0.036133145988588376, 0.10175606521267085, 0.07309135334986834, 0.09290776500898985, 0.02506527456364805, 0.022690991886080276, 0.018153048999186967, 0.04978226640472009, 0.026015487890089714, 0.022630160674452785, 0.046200901119699406, 0.19057794624278623, 0.15371866764560824, 0.1423305255030432, 0.12955383367596135, 0.6094570193559893, 0.8681006825739338, 0.40268801933815407, 2.913473070629182, 9.132945749067492, 15.728854421646366, 19.517378614794826, 25.867135024839833, 34.61843513673352, 37.91781133221042, 48.05602819688859, 47.14558332197128, 35.286261804642216, 21.574812781426218, 7.058578710402212, 0.18318247050046924, 0.8895553732591291, 4.344169112943835, 23.6858755542386, 51.483552148265225, 65.13371413753879, 89.12441668971893, 103.60938456750686, 109.58913203208678, 99.12118111887287, 70.22225595289662, 51.91600522687359, 34.068809093967566, 13.270213757791828, 2.7309695991777607, 4.739039511449875, 7.29774130928901, 9.6576706247945, 8.0050564389075, 3.7925885040913863, 1.5153588090212116, 0.5422416906202994, 0.7489109459903933, 0.7375638968040867, 0.11830866652270479, 0.21882454263827494, 0.19311729788539872, 0.07509406040152235, 0.11336900053485749, 0.06381309779000378, 0.06522274936639494, 0.10353013332332335, 0.08724550190832346, 0.024709526314249924, 0.051991058768884796, 0.043021168920301625, 0.0536683738051403, 0.07577877446648575, 0.06449525695173972, 0.02217195965650101, 0.01937213620441335, 0.023002642199337002, 0.013987449741351509, 0.01990273061598982, 0.037015656294721755, 0.06561572182803385, 0.030618249476256392, 0.013337383917983503, 0.02232175282833557, 0.04616906250556631, 0.030959541646523342, 0.046532406516733675, 0.06266857392244762, 0.011358193850385086, 0.05529102463755877, 0.043923080403117404, 0.035474471252171264, 0.04482854653390185, 0.05638681765225145, 0.01861739212707166, 0.11270179157896389, 0.04053247484168218, 0.02300044927265375, 0.01188636072085149, 0.04315018195719008, 0.060555994540693305, 0.026422564030414628, 0.06568447055835878, 0.019124628517836816, 0.03614894272158704, 0.08177793239273372, 0.11036922238887319, 0.01814597800764586, 0.008362980630819597, 0.008215446460751757, 0.022560831632525213, 0.01122746573415615, 0.08231811630990236, 0.036733912138809124, 0.07698380012786196, 0.12233088859507155, 0.02355074171998328, 0.06815493557481997, 0.08342863736493934, 0.09433148579011041, 0.007076477209451579, 0.04632628289982677, 0.07211465253344468, 0.044609610096461354, 0.036328571187632705, 0.1425848973374213, 0.14610096511821594, 0.11686245340012735, 0.22564114702324714, 0.1642444705770862, 0.14596699166201776, 0.126005245462781, 0.17944926275841652, 0.12568940273335866, 0.16480271884750936, 0.04660294023192218, 0.2588811811179884, 0.11780265012695906, 0.18573446259383233, 0.12379383307791526, 0.14157692481192852, 0.1295691094691715, 0.24387756362557414, 0.16874716767380316, 0.14684100605307088, 0.1482844229547247, 0.21768936887383464, 0.11517024944506346, 0.2583860738142844, 0.1790444006121928, 0.1059909456319386, 0.12772714298579002, 0.19499212954073183, 0.18299568294277116, 0.17975580518043813, 0.19260588823066604, 0.16132193707650708, 0.0931565290797622, 0.14019431996970408, 0.11020794555905367, 0.20261910173200792, 0.11283358168457785, 0.10553335365388664, 0.23596284880993829, 0.11536283628834833, 0.11813903167363136, 0.23261787910615248, 0.22986664286544248, 0.18006410960468555, 0.09738423125517946, 0.1206402321376147, 0.12576988793068355, 0.097070372693481, 0.15924168660515742, 0.13610374753273305, 0.14746860060239994, 0.08242922970244, 0.1507417878676807, 0.102472985613971, 0.1329283896953829, 0.15242541929887188, 0.13242556022540217, 0.1326917144920557, 0.22814633114443672, 0.2136896084994078, 0.12670243910003093, 0.19947953552248018, 0.09727092685117837, 0.1572634484018049, 0.155350067202122, 0.20524200292364245, 0.18171182683398648, 0.2465141318257778, 0.18171458475051389, 0.19848035768635813, 0.3198293284062417, 0.47195854747006977, 0.4375394121293099, 0.17041855701996436, 0.7092367845677561, 3.0024841523939565, 6.8882733198904225, 9.708620252147798, 14.352350581076838, 23.831577877844534, 26.76293965308897, 35.094273551817864, 37.01841577406853, 27.599955797195438, 17.072875153633856, 5.066420628178505, 0.23397831336384822, 0.6926117573053606, 3.26892928731057, 22.552498848207538, 51.333117485046394, 70.11206088527557, 101.34011299379411, 115.62685997255387, 118.99969039424774, 107.80397507452197, 71.33373014388546, 45.322551958022586, 27.139983369458108, 8.627896462717365, 1.242995307810845, 2.35217307363787, 4.216831816780952, 4.582492814910028, 4.016703420108365, 1.248870405458635, 0.5338925579863211, 0.2221484142806261, 0.42046030923243494, 0.7840445349293371, 0.503866691743174, 0.29048837541091826, 0.4347197489152032, 0.442393283930517, 0.2634302418558829, 0.20533974042102215, 0.22410357791569926, 0.23803131684901255, 0.14184356937485357, 0.07901084579287038, 0.18911467234213508, 0.19767112369018217, 0.16857426162929307, 0.25562991928910056, 0.08729447790932271, 0.15461237049631535, 0.1396692126628853, 0.1884167355995986, 0.13862229222732206, 0.11668521895884507, 0.11973248689525551, 0.1239872549570376, 0.18948679189047507, 0.2417673284728681, 0.21283515999394081, 0.2011250464185592, 0.10756662761371945, 0.17203552347998466, 0.19315528052468456, 0.09805382274451757, 0.16002416881101747, 0.17880816973986166, 0.18863522387560339, 0.12613026335114433, 0.10338377222538957, 0.07985531217268399, 0.15863877540874868, 0.1972753320249819, 0.14437599558263056, 0.21061272360384467, 0.2609601598833838, 0.09997459669266978, 0.08599445734533571, 0.16272542547554741, 0.15261422932869004, 0.08130852733888934, 0.1733732049263293, 0.20331613449079378, 0.16444538479610799, 0.19750633817766944, 0.1021235422681897, 0.11880638618623057, 0.11585635012916981, 0.2660232043314365, 0.18509220512163255, 0.2084288367580983, 0.20907356103341426, 0.11720822718475135, 0.21460473116847778, 0.26215366358237885, 0.22917117292602218, 0.18357414061263685, 0.13770505515558107, 0.16857672843240923, 0.17335858796873402, 0.17254365427840143], [0.015552630572910271, 0.011842299173886498, 0.013315384745627884, 0.07244311273097992, 0.07790606273638626, 0.08910224622776432, 0.014980995873620194, 0.01993114481710138, 0.008317604285454559, 0.03037034342395923, 0.04583453872211037, 0.03935441930568026, 0.015636026904347445, 0.04896579287765969, 0.04325887834232661, 0.019646355461689736, 0.05157760877702987, 0.024887881159121474, 0.08890469513473012, 0.013796666077518416, 0.03616586560383439, 0.028057410982587648, 0.024213446078882105, 0.0474457978270948, 0.044337790609607776, 0.022891565195975766, 0.07929455879474841, 0.016027928758112174, 0.05950478784319374, 0.07452867985252412, 0.02027551857604375, 0.015358598696278229, 0.09982706348021185, 0.03540799397254183, 0.035316833339992075, 0.05865421574262362, 0.029907386915217486, 0.015859234281965805, 0.03832380122114574, 0.03800783974809512, 0.07392573801259841, 0.044944865493884975, 0.027810966243006052, 0.05185936442426136, 0.021406768055091945, 0.06602486640575432, 0.01680549459471818, 0.08707143141016846, 0.025999735207146695, 0.17314518651654645, 0.06026807188567135, 0.036400943513839476, 0.07102219583166224, 0.037564742153570536, 0.04261457924580863, 0.02260163347537239, 0.024623494640353228, 0.04406376095909265, 0.02161896100357896, 0.025058736003214316, 0.037031648380141106, 0.06429160013794899, 0.03277143726365701, 0.03125930610563486, 0.03602733775492638, 0.09655218316061843, 0.12266261998804347, 0.04155206892098631, 0.050970012952964154, 0.02187552767986011, 0.031925538299424995, 0.055732574734476306, 0.094092090974652, 0.12134324804308916, 0.08188955906418063, 0.0381500831234359, 0.03533556035930111, 0.21579290289551983, 0.23159479932679286, 0.11887272173959403, 0.4575379228880329, 0.8736770059312544, 0.6840486103488553, 0.6875121857850783, 0.2805633079861441, 0.0608209805232623, 0.3324474400329975, 0.1642824685381305, 0.07439651436382726, 0.5756479657946095, 0.7783057396450351, 0.9102220352618926, 0.32493423189847703, 0.3612877086045281, 0.12937694397424498, 0.479984053921315, 0.8670914689860038, 0.8043179793223258, 0.5863593458648652, 0.4236553248859221, 0.14786454548518504, 0.03601226880545578, 0.01884454102706044, 0.03726345892514914, 0.04693690860163301, 0.05976430012754375, 0.06992964719932887, 0.03935123237991526, 0.07849420375761487, 0.10588520251575018, 0.13637307340339308, 0.1520730648189783, 0.20009102690364086, 0.12721963271859194, 0.1507104548715776, 0.11128189357658548, 0.053316601552069194, 0.045272337437997905, 0.051465311778649214, 0.04374577701392193, 0.029094494849203095, 0.03146605408420006, 0.02143084428333227, 0.05173535394151846, 0.03921728190635482, 0.05926202990174775, 0.10455437755632786, 0.01917186932968757, 0.06920228501962078, 0.038065824943083915, 0.011469448011578813, 0.03655026937204023, 0.036651205286503806, 0.027508936078858473, 0.027522790778969086, 0.021416194767000216, 0.08305290188159674, 0.030995409883138154, 0.012341562504579705, 0.04165963532643453, 0.01854332674655222, 0.013872906190132903, 0.02389634888048374, 0.03969645841167339, 0.052542236047766866, 0.05751488212075445, 0.038302940646967584, 0.021671828731233557, 0.02488361213416342, 0.020291367019977302, 0.05771182800432848, 0.012219500757994191, 0.010144363923539079, 0.07929133356458719, 0.06147983145990199, 0.02696537562916356, 0.015947369824824555, 0.07962333308833261, 0.05510325648731763, 0.034611618762174924, 0.03946171374991536, 0.025783570092772285, 0.024925340943398978, 0.020946467956227642, 0.058901731090079394, 0.0038343318268626693, 0.04019660657391914, 0.05785247791678675, 0.05385774307914319, 0.04958521709927628, 0.02246184158138931, 0.04025976286239682, 0.0221278770421181, 0.03668425431955726, 0.06734470566434246, 0.022635098111124772, 0.028826191705921968, 0.07744605758137281, 0.04291316584473656, 0.02863799837688285, 0.06457964919747845, 0.04224439023903782, 0.054204263799493356, 0.016486256180571455, 0.044368300061192245, 0.041589637872793024, 0.006178490012027925, 0.06299934387507458, 0.041418436373914444, 0.035866398003793536, 0.037221071280298695, 0.014189487236792283, 0.028108719721316334, 0.06337314115596876, 0.04778935761761762, 0.1010309859749771, 0.013087762786345858, 0.04332813652112119, 0.03296071843754861, 0.067294082574306, 0.05507408768960065, 0.07110730820004979, 0.05133919838455416, 0.06618191443023182, 0.03313742810860276, 0.030621991815766504, 0.03305710378974196, 0.07026152414900642, 0.057289299870570826, 0.06324015212275329, 0.04098446288656804, 0.10459612934820114, 0.0437203390643962, 0.0862076825973007, 0.046821604708149556, 0.003648656054264716, 0.03418912127193424, 0.060275307586116184, 0.013718832502021425, 0.01595622101317971, 0.014171142303835482, 0.042755922467838374, 0.030905084286425865, 0.05948268237613863, 0.0728917568020763, 0.12012829388221426, 0.030497416343179443, 0.03974042036720822, 0.045104453099831465, 0.03954120686337833, 0.06169026049094335, 0.07409908072722536, 0.006228898118640627, 0.0384412539912568, 0.014327964332375317, 0.01706521755324737, 0.09495864366932262, 0.05769357978997212, 0.07853257710174208, 0.04620353263171931, 0.05433524951278683, 0.03459052836161948, 0.12774851683887745, 0.10318156331777574, 0.029542489660783645, 0.029416320725314082, 0.06889593411958025, 0.06070614011297303, 0.05150011898348889, 0.134701025221617, 0.06613579593719014, 0.22449806723142826, 0.04842818684635624, 0.1841815257625234, 0.34264900391140296, 0.16771730035543445, 0.4600307423501246, 0.3978651587761218, 0.23016521797305156, 0.3195512997767618, 0.19489926436255056, 0.038441790252803795, 0.3736603043733105, 0.16424379641971282, 0.04870428493426693, 0.27693569780357424, 0.3329841305892314, 0.339931781974531, 0.3997550976853217, 0.5927178756363931, 0.3102301547844564, 0.3137780918229011, 0.4284989617524609, 0.4338217406503616, 0.3660475967391845, 0.2644135616719723, 0.11690156218866188, 0.009054449676055341, 0.0539292075911597, 0.058308357688327955, 0.15862539951359073, 0.10154037315758968, 0.04761305397316333, 0.04914534856535254, 0.06928543620292218, 0.014985052309179259, 0.06345738784500188, 0.027239393788359823, 0.12101006874394034, 0.10374328962737515, 0.11746344937672538, 0.008529518569459119, 0.029747531178497502, 0.025242227467618165, 0.038839183041765805, 0.01612755466222523, 0.061903010768395286, 0.015876040335804704, 0.01201794494033581, 0.02007352991870815, 0.08074812636139893, 0.007321273423581114, 0.010012256849046436, 0.0661197157516595, 0.06916631719157582, 0.01526841099539231, 0.041855711700214494, 0.11839653680761976, 0.05162840040640966, 0.02011414598523369, 0.01468241502035169, 0.021695148447648655, 0.05172604980367807, 0.03832345265114019, 0.023211542884969426, 0.06001360812074235, 0.032692484242180665, 0.008225132684944379, 0.054568626707600015, 0.023556378211886175, 0.020325488576124755, 0.04429331537516368, 0.00971399775270613, 0.029347261729379816, 0.024317187790368355, 0.04273654810423332, 0.07489556702034128, 0.022989563163249724, 0.01678689589513646, 0.05939548624859703, 0.010383581581164994, 0.03063063903321182, 0.021645546169771303, 0.02078416648380939, 0.012884118421483907, 0.041722297488201054, 0.02817456880884786, 0.024727954559268493, 0.03104235000547863, 0.013134737382642927, 0.013914673303764676, 0.04878091287889308, 0.08554003697129027, 0.05084863398224116, 0.03298709101434196, 0.020157157991742416, 0.045375881881843654, 0.026142388439526962, 0.026577009271169384, 0.04968112747695658, 0.045604505501086676, 0.013726827587121198, 0.1068569927085792, 0.16131380122275124, 0.18167618842374894, 0.23197359916183258, 0.13735509087001124, 0.17510413462596555, 0.1547920640798346, 0.14774839123410566, 0.1836271232534801, 0.10175913722524721, 0.16182833651621498, 0.14773850869988242, 0.23750012680407495, 0.15148169090670927, 0.11249896980101064, 0.08675338234752418, 0.17535747990252512, 0.120480464501006, 0.17254967572948626, 0.19328569933291406, 0.2648456965483004, 0.15907023612770343, 0.08787586969593841, 0.13926510128282732, 0.15703641058456513, 0.14633693552065283, 0.2084107570830853, 0.15410695164915056, 0.09644199673446918, 0.15764021044296606, 0.19091770623720464, 0.08889629881108001, 0.13778780797316184, 0.1131677645589075, 0.09858260727337292, 0.22189220383522973, 0.11735618940644688, 0.13140785838327101, 0.11669975930764792, 0.17962455899725038, 0.19884912176958977, 0.15517414277119024, 0.07048381988199488, 0.21288697818113914, 0.05357776092545641, 0.13169296566517125, 0.12477610335354844, 0.17803944647312167, 0.14379094955661606, 0.34441741063229503, 0.15899347411769052, 0.12510563607417768, 0.21052610970312552, 0.08458165331713616, 0.13692920727114524, 0.16879495623851978, 0.13469598436307523, 0.17825706140889278, 0.08931707260349105, 0.10943943679693247, 0.11940417225442587, 0.1305320360247166, 0.2249977863844364, 0.07255960406074602, 0.14012517287365853, 0.2339686453342438, 0.1819675623048698, 0.1810683895863833, 0.12311153218991334, 0.17274858279814645, 0.08263343043865697, 0.2057370489403125, 0.26878433842812816, 0.3373618940672567, 0.17132909848324715, 0.18678679161014097, 0.1991271044337942, 0.3625511101657345, 0.47710298109919796, 0.48163791517576865, 0.6799119807058766, 0.9079189911004036, 0.6588392921032444, 0.6232393701230327, 0.27755567743893594, 0.155768504426364, 0.6112171216837822, 0.36502790306845023, 0.18507547376136627, 0.46690702498439823, 0.6546298534639421, 0.7550821825861932, 0.35574539955104556, 0.32237424184718444, 0.16834215230999455, 0.3993929219582389, 1.4475391901308492, 1.0601200692115291, 0.6805476498219275, 0.3140331991016865, 0.18858424838512175, 0.14359259407126135, 0.1559917577692578, 0.1847502847592677, 0.18893027497876078, 0.10083151966213219, 0.15837324933419306, 0.15776040963828564, 0.3075384895407385, 0.1620705428743555, 0.20895677859023695, 0.21795969065879622, 0.3195867543258975, 0.24989752849984556, 0.2742478936429947, 0.2833009385053189, 0.1402713730931282, 0.2388152086566533, 0.10633393085651821, 0.10767466133280147, 0.12583443849918344, 0.1901445396605038, 0.0770525871625831, 0.13825680700040635, 0.26898205039962647, 0.14418542355058656, 0.2032767116062103, 0.13300020277740496, 0.16953628420108752, 0.11396284125024274, 0.12275860314407658, 0.1937103725128597, 0.09050402625073349, 0.0900882013863133, 0.11816759143144855, 0.06531948328859384, 0.21767092147661796, 0.1871865362890305, 0.0816636550570688, 0.16621216741060058, 0.13465040213158055, 0.1266966015100479, 0.1667747517386752, 0.12910888980953925, 0.12881563135212468, 0.1634026012353359, 0.08785962097106442, 0.14653921337617984, 0.06795838805696658, 0.17928597877823538, 0.16711388354099568, 0.10311929569129022, 0.10258191565592444, 0.22195722937824267, 0.17378511508145641, 0.17227904750935494, 0.23780821672370359, 0.2569909970606527, 0.1566036781596561, 0.1469905770594074, 0.09505690210649083, 0.1430504796125235, 0.11273058116315834, 0.17983955391232045, 0.12399992605130519, 0.16695145757928972, 0.18732956490449368, 0.14525469843178027, 0.13912240974605083, 0.15467391800015204, 0.16579788238290818, 0.15040035780158736, 0.10488011814173191, 0.2912789168617418, 0.18103907906240035, 0.1288678938703191], [0.043409950880994724, 0.025150463540828037, 0.049339613141191584, 0.017503540504783872, 0.07049351855511628, 0.03870322924828337, 0.07468562828557146, 0.04583308698549386, 0.01920265074248516, 0.0481133132181581, 0.04004281825355945, 0.0324649982635052, 0.08476590512380486, 0.02366358072557036, 0.04673392977565528, 0.03799187447575312, 0.10060942311200405, 0.07878990603550788, 0.024932170617243937, 0.05410263457545831, 0.011229369462647987, 0.058621978762769894, 0.043869565331166795, 0.049570952542126186, 0.04612068788358762, 0.02410772977577102, 0.05242186065222468, 0.024893406568275347, 0.0586936041532505, 0.019331093043870023, 0.012346857129746388, 0.0502996783583395, 0.032382873638022336, 0.016502146759340842, 0.05500266531241998, 0.06724921280458089, 0.03791769418204504, 0.04418712409753953, 0.018621529001862775, 0.029972088786082405, 0.06771528537595464, 0.05994969340521963, 0.03453711671153865, 0.029357063824370987, 0.04071560815998143, 0.03166444404351135, 0.033166604567198985, 0.022345465164811864, 0.07075889141208704, 0.025676195209305135, 0.06365812203336148, 0.04925144791242577, 0.03420599818890614, 0.07988566457624398, 0.0309776998455486, 0.055956896770024495, 0.0662972949325077, 0.1227667160151947, 0.008638565439821012, 0.0525151816527209, 0.050261887241034746, 0.01805502038839604, 0.16136701368997175, 0.04691589480986999, 0.034566718348932844, 0.05347362276346934, 0.037097363402285886, 0.053787473664288564, 0.05305655300617219, 0.04758421459325379, 0.09328956024781351, 0.11445724375305638, 0.0825722813005409, 0.040735645189640984, 0.03697586568793462, 0.044574216834359595, 0.019319437016102097, 0.07171021173557929, 0.13184341001174144, 0.028977237431512728, 0.1677263861582164, 0.27462643300814016, 0.37685142830014234, 0.20286948990917977, 0.03063190116306707, 0.13978611768013047, 0.23043164803135782, 0.20203613946514748, 0.05962355828453457, 0.1498413434432399, 0.37263420620752924, 0.46621092685288, 0.3583720086082336, 0.19816083773489923, 0.11300870172318914, 0.36019165128950154, 0.38239186809908965, 0.2428373541202276, 0.23480599475724084, 0.22725100418733013, 0.10560696704253074, 0.0008403901336996276, 0.035887618639296105, 0.015571322160652809, 0.014084748653394562, 0.11341282842500557, 0.07570556710444151, 0.08825505257494028, 0.1106996973976493, 0.13609746561175393, 0.051016093141609625, 0.026518171803364833, 0.05533910048524699, 0.04026014590635896, 0.10709360662487247, 0.01618086863609572, 0.04207297423554044, 0.054658220690344615, 0.0773623701365244, 0.02353926763809737, 0.004188786824083617, 0.03865603057126846, 0.0634425908567444, 0.0029167220054659997, 0.06110398489381037, 0.0266911429653485, 0.04612212812888526, 0.05713626614681656, 0.07938588413620189, 0.05366082017820689, 0.0520220929906974, 0.049887254924303105, 0.02346904801895782, 0.07568312838913933, 0.06429353834039743, 0.03730243747873652, 0.06336253466865709, 0.02537984750233591, 0.09391815071144412, 0.08601903344594664, 0.03451105823079425, 0.020220492395662495, 0.033340809130740744, 0.03770176080926772, 0.08857732278204734, 0.019864324713125825, 0.020741978021819266, 0.019183950536253474, 0.06779501214623451, 0.05032382544971282, 0.041167933283553976, 0.004286782397332812, 0.037631403294301806, 0.10123495688481678, 0.0696784086645611, 0.03012382973646445, 0.04745239001368323, 0.0430538617224703, 0.07852947444564874, 0.03186802999416907, 0.04451271146535874, 0.025568624973417293, 0.0100131627480169, 0.05033500267252807, 0.033491885499848474, 0.018916790779199333, 0.07444024266254518, 0.02293800927638527, 0.015414134325129131, 0.03252351588960136, 0.006043704023825066, 0.05377699741192403, 0.04185558912614661, 0.04744421585553116, 0.09194463160970519, 0.08228801671535739, 0.1011138307231088, 0.04030991480835984, 0.016874959617252314, 0.007556037716342197, 0.04289982825397484, 0.062181131328426065, 0.061270965248226165, 0.07721489055022117, 0.021622492668909893, 0.05400600790556881, 0.0610579047051649, 0.013307290069097954, 0.04550570314149222, 0.058663569676179084, 0.03371103644190777, 0.009844295902087564, 0.034009228505554705, 0.02881562926866595, 0.008157039917404614, 0.017554437471253258, 0.07807022005680107, 0.02430704478625088, 0.02444232633757976, 0.03627640826086845, 0.03807638929555974, 0.04230492267637484, 0.021712111549512036, 0.0067495511029846975, 0.057521692642401305, 0.01764012823602365, 0.012086884235031905, 0.02725094256381835, 0.0688482451462938, 0.04612707705687612, 0.05633126478642226, 0.03316147943898555, 0.030372505707125512, 0.06392638304180677, 0.023449627690077312, 0.005315120891487647, 0.08170257998450149, 0.026617025873894175, 0.08583232249704101, 0.028189796721562747, 0.06413113919176883, 0.04878937815045638, 0.05288297280428871, 0.03387339728614015, 0.058519269354761615, 0.04363563655304813, 0.03117146837945667, 0.04219058405367598, 0.05347815417354146, 0.025393744337282358, 0.022193028989638534, 0.07496511248210747, 0.04838019526833969, 0.04973401052636966, 0.009813661003605494, 0.028758693614133427, 0.06574120703003099, 0.03962071146816015, 0.04714784325070439, 0.07962378508020794, 0.037697390277659705, 0.02175265483768477, 0.02885499278143529, 0.04827973049794955, 0.05721818775899949, 0.07545582244112607, 0.014407316677182194, 0.053201259354189526, 0.054948292221994176, 0.06400617109912057, 0.07227734662592411, 0.07169630723975359, 0.04113026090987748, 0.09644384300636669, 0.09286350810960417, 0.127143690422658, 0.1626517431389901, 0.13455582091644888, 0.07950663491482697, 0.14145120978355408, 0.06002985684561634, 0.11483003745876974, 0.2640299048394926, 0.19408534190827803, 0.044803618032845764, 0.059185493887672504, 0.2069125648948454, 0.20994814232953135, 0.07597352167771709, 0.04282103994140222, 0.09438989999433679, 0.2149029232321247, 0.4955845458372947, 0.360358321378308, 0.1324295438826084, 0.14725300813874892, 0.11856926665190728, 0.06235663441099948, 0.03811134588754466, 0.053167233559032606, 0.021983126644045118, 0.0484469176961049, 0.13738993254880752, 0.03326881218761687, 0.05064055684112734, 0.04498483613133431, 0.019456526534932277, 0.05225529398528799, 0.11698044626222504, 0.06876566086805637, 0.03880554029057103, 0.030566996278902216, 0.09272094680777482, 0.017659259366712744, 0.05676303194054673, 0.007634056589355873, 0.029577815890192028, 0.024144561367950613, 0.04709158941442448, 0.07637288331264451, 0.0377249694429338, 0.07107209879904985, 0.03754771201901379, 0.025105440553518075, 0.10322747496707786, 0.04845386994401774, 0.021057194474363522, 0.05862729924340403, 0.040935594137878194, 0.0765270661682852, 0.05484090584720816, 0.0473127321850869, 0.012030470477897796, 0.015179290071940951, 0.016808710248780348, 0.039110431793115796, 0.08571068305642375, 0.07139236951667456, 0.06249967834822113, 0.046186130944519274, 0.09214625062961733, 0.04791524118533538, 0.039041790315100265, 0.04491966503161577, 0.030955603954592542, 0.08625206207075427, 0.032047166248723384, 0.06146241445094348, 0.05638396780517313, 0.029366584382049983, 0.031593881600025686, 0.03798027590457951, 0.02275328824086295, 0.010420172813258344, 0.07612515346056993, 0.02830288279050541, 0.022023219855562336, 0.04991529374233177, 0.09441693523718465, 0.05801472384783049, 0.015335619888989436, 0.014120065306703893, 0.02425535874921949, 0.013809190657470497, 0.019165005181886016, 0.017452641623094678, 0.07343898872814833, 0.060043776663200515, 0.020194437745357716, 0.06033795059568459, 0.04856137889287165, 0.036422263740772204, 0.1792610809206963, 0.10074753344299332, 0.11989816873063965, 0.05273003101108536, 0.16249771350093428, 0.20467476078098823, 0.1461063430554444, 0.12499318202777256, 0.14785444844634305, 0.2178684802305314, 0.13806156183202423, 0.11604562747262179, 0.1299094057251369, 0.1743708046213273, 0.14023100025951862, 0.1888238653660782, 0.18029822607434567, 0.1340790384358937, 0.08678728173817359, 0.15883618094507726, 0.14098702178847405, 0.13321296071573613, 0.11975206810260013, 0.08102805488893101, 0.13734419709972798, 0.11773737943581036, 0.11870527790198404, 0.1507071760152617, 0.13407703128553208, 0.10910091786495141, 0.11964591895981182, 0.10812826965364719, 0.22119739273142433, 0.21903749975946643, 0.1727185981167901, 0.16563680473594897, 0.1499362157717828, 0.20174504137567936, 0.19243440710969512, 0.10093887922384086, 0.2420298055174851, 0.15415893837569222, 0.22272232138822157, 0.16238669203894754, 0.13597722045115887, 0.12455549301399339, 0.10521872900426389, 0.20396779952270372, 0.16855521668349543, 0.2021179882989776, 0.1570297456196239, 0.10847356080287889, 0.1068519441891582, 0.1517785959426434, 0.11303832634322106, 0.125431384320461, 0.12650293448278982, 0.2973733608040118, 0.1370872665316828, 0.14695236459374428, 0.15394812630068871, 0.12984995730221272, 0.2853302441297039, 0.21445083942624832, 0.18254352252810233, 0.09033006300488788, 0.14365786476241005, 0.12700161175622096, 0.24710857008974402, 0.18144942639816194, 0.26052220273883114, 0.22965435990162436, 0.270661621564819, 0.15177211483880398, 0.20238690048215852, 0.13061100436795142, 0.10363533251708555, 0.16203652857051742, 0.22962147940791425, 0.2635772388067938, 0.24320945834680913, 0.4387873387144458, 0.38061460540179287, 0.24762741079734218, 0.14419086277484894, 0.20658898467738784, 0.5229553351959875, 0.440776041678844, 0.13608929911448112, 0.1621262987534846, 0.3606391998548662, 0.5137859981867575, 0.36472165175983984, 0.33269234302063144, 0.24037386050387738, 0.4589659107788917, 0.9142357231147829, 0.6240413109621694, 0.2377977672844164, 0.25589884679404, 0.14976376938002725, 0.1901662505922779, 0.22036505352345206, 0.10626648447566456, 0.07708989564449557, 0.24848604214287576, 0.187277041916405, 0.23385736340236282, 0.25609853527238297, 0.301021900508673, 0.1450293613297324, 0.14226341620087624, 0.2774137979553592, 0.20609494989677785, 0.1691507734358311, 0.16556324497345956, 0.1728726583983629, 0.11404057619191947, 0.22369634089691026, 0.08561712073823137, 0.20453989866279787, 0.10694770517969325, 0.2571847866619787, 0.17794875698464532, 0.11844592649609813, 0.2403905305771097, 0.23382783837376103, 0.15638773329555988, 0.2222659628117277, 0.13876830858568992, 0.2570249041121814, 0.2089401391605216, 0.13679659745145228, 0.1549684788070379, 0.16421918967558494, 0.13670167915763395, 0.1270603017521001, 0.17853017175389876, 0.20671325946046462, 0.19312408542440784, 0.1753598394533319, 0.1817120260168468, 0.24713244138946458, 0.22983655093177674, 0.21952958867674877, 0.13459596392368117, 0.10684506471959815, 0.16798305625636734, 0.08672012647073116, 0.16330143166405542, 0.24788355995570463, 0.1483510572823786, 0.19443283939073164, 0.12030401146940647, 0.1691144455464617, 0.0909882551059127, 0.08367743207922868, 0.1328603610877068, 0.21484344416568357, 0.06885629673037799, 0.09859232126825279, 0.13971450378096875, 0.16370813242129742, 0.1497477581424098, 0.1509138205719571, 0.17737999798790102, 0.13310883404506793, 0.13989219021412636, 0.12438503078996174, 0.0966345759168748, 0.18918798695648872, 0.14696328900754452, 0.14291669001742718, 0.2019277227021033, 0.218679154472005, 0.24955522509351855], [0.023144613613464662, 0.01384569283184265, 0.023237350471918623, 0.05811798483914426, 0.05018091557787792, 0.031572036602864825, 0.023311327752326767, 0.029446060258534648, 0.015785815288132478, 0.015047937594053727, 0.007378076449141748, 0.018602821134751844, 0.09178086499413175, 0.040708380120415846, 0.006037054859447263, 0.0064656504095652175, 0.06097070091674405, 0.021655564684601083, 0.05185563357607011, 0.03932788585042281, 0.09503804102179506, 0.06375085697659562, 0.03755778224477845, 0.026786568792416688, 0.08033283775852573, 0.05781898455273721, 0.07082856710880034, 0.05336818608245062, 0.07807061076164246, 0.07927782743448213, 0.04240475542422745, 0.08971232034626508, 0.05470991630347506, 0.049004154730468034, 0.04510433052576358, 0.010966082280051085, 0.08437346892371293, 0.011070500064130512, 0.04217366500186824, 0.08737176852000338, 0.050726473601835395, 0.04767450954644911, 0.038076576987101186, 0.03466966141375803, 0.04750872045875557, 0.04292476441591017, 0.042631896663336985, 0.016368562092764244, 0.04761765433114864, 0.02244487847952593, 0.005734269141084365, 0.021103401067516497, 0.018793004377174283, 0.05320165771991015, 0.017177694582290227, 0.02681042668559859, 0.041680572509405114, 0.04231435704916235, 0.037347690292423776, 0.008980414939052876, 0.011416157977955957, 0.007588443714344213, 0.04989938975702371, 0.03552927335183467, 0.045214432682241165, 0.005719427145161336, 0.01032006906180252, 0.015022648074063323, 0.03572000626234278, 0.10656165049201059, 0.07488242861243986, 0.04408713813210207, 0.05698520509946731, 0.07101261207172949, 0.023239438061512286, 0.09149074749720675, 0.021645191854106325, 0.07183433330107121, 0.012757341403724446, 0.0482069521451429, 0.08552507527412907, 0.12628125928102002, 0.145528084568439, 0.15045445893080006, 0.08895832128942975, 0.04969475235068991, 0.055891944005364375, 0.06620287459584014, 0.05592020498889108, 0.04921122446596142, 0.23468335940232202, 0.20338589445717875, 0.16555144721942563, 0.18143894631535779, 0.10785685236295385, 0.18496221532264065, 0.15337296280889742, 0.10415454860776664, 0.03542355704872358, 0.019991389971466798, 0.05412680847990898, 0.005358179820881736, 0.020907322778516722, 0.04909510851927823, 0.03970896862747689, 0.04014337495450051, 0.04365784544197302, 0.1297182974315459, 0.08657771838648666, 0.09726626903659875, 0.13428434999960084, 0.03549665715845843, 0.07853785544754037, 0.040780334928703886, 0.02659147684161942, 0.0748827733520058, 0.025047514730343418, 0.03535549779753051, 0.01573995918020486, 0.021248086348115917, 0.007574430529794266, 0.02595467391544052, 0.05076297003054812, 0.038844116647998174, 0.0368491126104228, 0.008190087035238262, 0.02083949526892074, 0.06382816673947439, 0.007081547275095457, 0.04729015557395835, 0.041441648838020144, 0.02502774391623755, 0.04906367210130538, 0.013260032977878809, 0.07551151703322127, 0.03461368719957048, 0.03847100884623585, 0.03711824695910177, 0.010138106900417517, 0.02261502469228881, 0.09412496380748288, 0.03568396182550538, 0.02250480570740277, 0.0993168565835203, 0.02604640145305424, 0.04359193123696793, 0.07386664965099866, 0.021913694180247766, 0.029989117005419348, 0.01690641710264308, 0.028189551573426976, 0.03042441582487476, 0.045013349923876025, 0.04580838448037544, 0.03745529500226821, 0.03234734631053383, 0.03470525002828048, 0.05828141054559139, 0.01557581430871881, 0.015326835733327656, 0.059219764830965194, 0.03710180288180709, 0.05251586347097351, 0.05773160456409378, 0.043973354923148314, 0.03505522197472953, 0.05031254097458817, 0.01622296516753493, 0.036248944008782986, 0.04171540652732215, 0.03807730860106888, 0.03651970629430106, 0.018169408806809978, 0.028815313257397186, 0.039422685400612896, 0.0213996013025603, 0.020677404470681664, 0.03979211598033867, 0.011990327470665498, 0.07015915181968482, 0.09435769365800005, 0.026289502218846354, 0.037834615777096445, 0.05759019622459047, 0.0181343162342185, 0.010472276368208472, 0.13887030553192864, 0.021558240874700492, 0.03727128834373528, 0.03816200728197733, 0.015875198596697903, 0.04816077236506728, 0.08068431123730638, 0.013429325960216024, 0.04763599064561629, 0.046328615637556206, 0.05969542882315094, 0.05034969240847615, 0.03932281434836407, 0.04615240775409245, 0.02971109603681872, 0.04889040599547086, 0.16692256074278586, 0.04807207853563371, 0.04188741624896084, 0.064740106313219, 0.03347481706089551, 0.08303386459667837, 0.0193505076270911, 0.11413530296375675, 0.07011693271417772, 0.02614451050307722, 0.08649404626339675, 0.04892673388484025, 0.03062596589687371, 0.030008282610065037, 0.05290106014018098, 0.015285758098827736, 0.0500934130151666, 0.02259401856140504, 0.010464289901597847, 0.03549318678016144, 0.07431444336449908, 0.08400402302222867, 0.08278547590898891, 0.14064609734041078, 0.045155309846684824, 0.037139030924487504, 0.0933868840577141, 0.06364902856970026, 0.041402934584766626, 0.031926534213726564, 0.09363885037600995, 0.025759897975912018, 0.06843854898526784, 0.061546082743593765, 0.02667387917397484, 0.03482236188926524, 0.03455854036034115, 0.006501864822160814, 0.03782902716568882, 0.04436202963153201, 0.013739353124683183, 0.0756604828300976, 0.08289531759557225, 0.046589744367426446, 0.03512657540399702, 0.08870024925037738, 0.0165581401257265, 0.06216778224634548, 0.007910239904548132, 0.11862182028351292, 0.07851750815227147, 0.10519000070710337, 0.09953632545206817, 0.10568534549806388, 0.21448145229970256, 0.18193917108639596, 0.14978168051569693, 0.11349767266261963, 0.0704304541971895, 0.02644949968183233, 0.07216754324373699, 0.10137738029081976, 0.016299489690291307, 0.08004724018035397, 0.1546069772373284, 0.06164637131376132, 0.10333143309840273, 0.03990926614571964, 0.055879629141981565, 0.22549336866265346, 0.3385344682441604, 0.12968639753037883, 0.12516706866482574, 0.0678199406472906, 0.041558392976801244, 0.017551158614937338, 0.06987113340367233, 0.08220971486861668, 0.05881531254178094, 0.006201055131837606, 0.0691766440567951, 0.03267702458786868, 0.07530452773695992, 0.010936387754496067, 0.04611130330651518, 0.019510106724356453, 0.06789605914344711, 0.04186559040399809, 0.035198629803715215, 0.05996092042374996, 0.06715586499100731, 0.007183492031594318, 0.03372930380846224, 0.0490395671447679, 0.02288146049625451, 0.009234440118645229, 0.06139968717170339, 0.04518892961524187, 0.05346590059719259, 0.06527286683840137, 0.05045387653573867, 0.0423409249783764, 0.03012227266275835, 0.02846598099436491, 0.010877200759076064, 0.03072905643362432, 0.05721928709517083, 0.020787828384087454, 0.020301287858596733, 0.010374038998458174, 0.026361698344830545, 0.0076632220354381836, 0.06995833719209318, 0.07142375613893233, 0.08471296844823707, 0.023357047879647826, 0.0016816828147350482, 0.02804868141069047, 0.045832784380763776, 0.034254365150005586, 0.009771222605430072, 0.050123619862020984, 0.04331732319006997, 0.04914706077186331, 0.0373705503560843, 0.09470428715670302, 0.03786739667937641, 0.05639325279081541, 0.04817003436807183, 0.035822616078920906, 0.008527941385945006, 0.03044207223630961, 0.026166794085574728, 0.007457007924395223, 0.038705106163697864, 0.044231170322746045, 0.04440606053498003, 0.0392970469810309, 0.04335886430776408, 0.062483195966530236, 0.01299393137977008, 0.006097354597577285, 0.028288443948352532, 0.061654572284990744, 0.033435283093563015, 0.03623647975825495, 0.03612068173806033, 0.029923057243708643, 0.041197117403029435, 0.03326722638561361, 0.22252030400258882, 0.1009585906661326, 0.162172218063666, 0.18124172464013102, 0.1216290601258797, 0.13873305321941454, 0.06261049679690792, 0.13437096390032, 0.14789808481451006, 0.13610573936133616, 0.20770514413954752, 0.09849358785657153, 0.1732724796860449, 0.18176367566470178, 0.08187906365961799, 0.13605634201197855, 0.2021075388596904, 0.09902378964808681, 0.19817920852332346, 0.14430001498230044, 0.2348454329635828, 0.14592386091188078, 0.1285505036432897, 0.16930320961100442, 0.11450441178655434, 0.1323798554198396, 0.20489268215192905, 0.16791511957924213, 0.21651463432898446, 0.2294550085019681, 0.13679880378467424, 0.21448713667210073, 0.08991934794692263, 0.209868116784961, 0.27477030432032, 0.09709764542358537, 0.19785929020614396, 0.16082817808754984, 0.13674896210432053, 0.09974143017203578, 0.16676896011396763, 0.07832619301494091, 0.19512363619381384, 0.17869331783825354, 0.14988620555208576, 0.1429392283241595, 0.16047947018617587, 0.16941807683437102, 0.13268678088582334, 0.19426518870938211, 0.14269693003546807, 0.11646615611689708, 0.20024156318076197, 0.20914948034671046, 0.16110798404101404, 0.12244895806596165, 0.13662258824033124, 0.16212220784396897, 0.19959967343076584, 0.23296854819261262, 0.18457719485365576, 0.07180956567847921, 0.19357650630897094, 0.1316295489067993, 0.17384097821289496, 0.1943098056700922, 0.08042568761494853, 0.29135629174209415, 0.1949882378140765, 0.23873501457273963, 0.3270160911544677, 0.1646758853307655, 0.22251953791466453, 0.21515245339082134, 0.11042591289526994, 0.13480455434370425, 0.12280890447718483, 0.1728098391885719, 0.2684133680116746, 0.18043376234990938, 0.22109153470204723, 0.3208144561898324, 0.34576180300885634, 0.45909167177254157, 0.18606813985013193, 0.07422171608214417, 0.1717462027145009, 0.19637062815168213, 0.19459183327853682, 0.21963192270167414, 0.41609719335552187, 0.3380285131354486, 0.30699818304950194, 0.3616265339716789, 0.1653380304454796, 0.32016515070872925, 0.6480838466555842, 0.2232518720050012, 0.25504881095501686, 0.2345558057629293, 0.08413227380163248, 0.1285673269341069, 0.16208614042449385, 0.1705185927811169, 0.18544526440241646, 0.18783414105494178, 0.1842007698911813, 0.24468601621206731, 0.13719913069038622, 0.13542151559264431, 0.1862847282280845, 0.18701048928403086, 0.20476393341537447, 0.2488314711879338, 0.16010705952442464, 0.1747914022135158, 0.17027750491134583, 0.13673460561661951, 0.10300921651745036, 0.0730893078951105, 0.08828506789981358, 0.16505698342957806, 0.22001109025891752, 0.14917306962513155, 0.18761997351482992, 0.14068129141965222, 0.16172603313480655, 0.09957379481244473, 0.09378605417066044, 0.1084603381253058, 0.1284826895402324, 0.09383339840438097, 0.18400503442652766, 0.13641370670689693, 0.14228388607021303, 0.2189702525614731, 0.12595608560067992, 0.10458019471937612, 0.08823720272630454, 0.21112367360582276, 0.19305398837933618, 0.07105557428252313, 0.12916577949879632, 0.15940872441616752, 0.1834219495855993, 0.12529999258056765, 0.1910137736629094, 0.1308428225738387, 0.08619350997070152, 0.11479261406366864, 0.11677218526000939, 0.17412721930492311, 0.0955522392365721, 0.13176395137223507, 0.19788018908471833, 0.12485284238092362, 0.11608510398335996, 0.17193813838305014, 0.09857920584298911, 0.11092809119051504, 0.2262380827338465, 0.08317658677697183, 0.14044699108889028, 0.13095701563983195, 0.16405274941315576, 0.19657681305562297, 0.08253606832436017, 0.16687153928702878, 0.20044007188370153, 0.23989006065793578, 0.0568175237746008, 0.11466159004597895, 0.1329387165606022, 0.1667272389656113, 0.08226811375108459, 0.13316757766710174], [0.031080752077903, 0.0371429494642202, 0.03966773777539211, 0.07821198462718919, 0.023773499020946123, 0.028371516607641697, 0.05640449896154385, 0.05208518416170151, 0.08138866779664833, 0.04968602660923235, 0.030354098529524864, 0.01502136583440006, 0.038808662098862474, 0.04711687414636535, 0.02253551051140793, 0.020380338556283427, 0.014826768010313955, 0.03700808351559024, 0.0812153480646591, 0.03601912912281771, 0.024793874509933016, 0.08667454423923647, 0.07341864909375868, 0.06313861865970878, 0.010628325605554687, 0.03478004702276761, 0.09621697372847027, 0.028418079431679462, 0.032258801868245486, 0.02102225320413709, 0.04833654740885381, 0.01889247323326286, 0.09338223390401372, 0.01880148688571588, 0.027961004562976382, 0.006434276236236216, 0.04108668965918403, 0.06435243518001611, 0.12701618274854076, 0.05637018971385495, 0.025805857505709417, 0.052617829773695245, 0.014362006406900624, 0.046862065641870426, 0.06323674303149024, 0.04279333437162061, 0.010025238208923369, 0.06760616381202014, 0.02267305968299268, 0.05339406070209319, 0.013813816870923245, 0.05728073117713775, 0.07091265291936936, 0.01089485046724158, 0.03871646724761494, 0.03661242974621635, 0.012441629866859125, 0.011712917457184484, 0.04859154360489019, 0.04761680780399231, 0.13449195982708087, 0.03321615130370183, 0.07631360342906368, 0.043384547405425584, 0.03615422489782495, 0.08473330808262672, 0.023059572108210098, 0.06976670795871366, 0.01734464812362867, 0.06221306953398932, 0.05024035250948322, 0.05315530557005156, 0.04170650841608163, 0.018343885331564856, 0.025378041450054418, 0.04395756202058927, 0.01833586630621745, 0.08687643905080135, 0.024563739782259352, 0.03363760308392587, 0.09683034968592467, 0.08775273638386881, 0.14062611776734554, 0.07475871307354781, 0.08067469683385665, 0.042193502848667484, 0.022378631026273774, 0.01987610714540126, 0.06902877376565049, 0.04666881230209143, 0.05480358587397684, 0.0771865299752643, 0.07534834796622877, 0.08492940360860479, 0.07148911876063194, 0.1093986732584815, 0.13651939619693065, 0.04092430583231392, 0.05865531124835534, 0.06509968500223852, 0.05252216454415072, 0.04314728997527592, 0.053550334977767164, 0.031301881442026745, 0.05511025470050593, 0.04131788733385263, 0.045241628803553126, 0.07500805171026338, 0.06428628348775449, 0.09822194840038016, 0.028991913760922132, 0.042854763131829045, 0.03610414573021474, 0.014983848593528233, 0.019371961919410575, 0.002504568617422915, 0.006254426562302416, 0.04600111688036592, 0.022769900857500976, 0.057933292531919096, 0.028536870940438205, 0.027851835118546605, 0.008973530681443312, 0.04320981041077645, 0.02959694510566131, 0.005814834777641321, 0.06605276732795662, 0.016511035294482307, 0.05509676006171973, 0.04737014281413248, 0.0630053959696764, 0.03737592829331275, 0.05253132695572511, 0.0785998932476486, 0.038525795624140775, 0.0018456268275434513, 0.07481673657293282, 0.009674396752680262, 0.054981731959889014, 0.023817972340170416, 0.03745707232625254, 0.05253326132773392, 0.04392015777768628, 0.039432518139121034, 0.08608059627154181, 0.013379257326314767, 0.059189695879937186, 0.062117013599603414, 0.026185275956747994, 0.012849117779443342, 0.05426000052642438, 0.05389056994669861, 0.030339745872263468, 0.06663838791991435, 0.08451066761007232, 0.04655735800042749, 0.017105075192727873, 0.030025983071555535, 0.026844548241746043, 0.03214611033458383, 0.02715411671106854, 0.019171354135558493, 0.06085789446989375, 0.016071490432706573, 0.037104131789096904, 0.04795635712423152, 0.0684997670712971, 0.04230248651677563, 0.10045251298335292, 0.11323906436202028, 0.0290384229588052, 0.02105355938716281, 0.02219550345363396, 0.05323115976587419, 0.04302224144339562, 0.04735217422186848, 0.06879360775553411, 0.05741282388748181, 0.013265521040246373, 0.07185895536695758, 0.025930032697356036, 0.03510168137689752, 0.01639171135461619, 0.0453365700800092, 0.061700035772857174, 0.00853210890425309, 0.02167939767992545, 0.05715980419829007, 0.12500532452137242, 0.05036226008087397, 0.014210162034648803, 0.015306944260373713, 0.03352426420596819, 0.01247368107039121, 0.03933066674958795, 0.07525288574998418, 0.02851662132137966, 0.0693092615373673, 0.058552789531888506, 0.01763576153485525, 0.04754609788858122, 0.04062751954000804, 0.08635651815922991, 0.03533493599764282, 0.08706763161406403, 0.016660933803406455, 0.0483267376529834, 0.006342090482282783, 0.030544199417495442, 0.020346096341287898, 0.009639989828781016, 0.03735676460388688, 0.034914043461603504, 0.05379246472711525, 0.07191121788515199, 0.03300024091356224, 0.00855536254558472, 0.03832038063856383, 0.07805211739915033, 0.014106887636796362, 0.0660732908234481, 0.027572684170257662, 0.03799591175911408, 0.062377732472434166, 0.08057541949974914, 0.02208542619501391, 0.017638833547431617, 0.046155694271287614, 0.017070003687554312, 0.05130434904487864, 0.06347056838773912, 0.020159042568036148, 0.04200788357505395, 0.015165339610839804, 0.04483751359305555, 0.013315644257912233, 0.17622580992118006, 0.028052758913667455, 0.040820068078896696, 0.06329668558112557, 0.025012389599015156, 0.04014409890758895, 0.04921001404704106, 0.030877328920929186, 0.01382257134067796, 0.05163288968164594, 0.05085563602586908, 0.013650186235956369, 0.038120163559553125, 0.0043442251063102195, 0.06247029887632497, 0.05784460636336477, 0.008530752928627115, 0.04099638704510947, 0.02520127432240594, 0.09983162936424056, 0.1322716684831727, 0.06746055348025215, 0.12890589183136342, 0.030935321776797215, 0.05546227210171281, 0.013974641708867445, 0.09383178195886074, 0.12362080445933728, 0.053693214206085096, 0.06408559526467035, 0.07064786228922106, 0.040889988923745776, 0.01535330119828183, 0.04759825315446623, 0.12739447696555045, 0.1561835095767052, 0.26585956795081017, 0.12637941812675807, 0.08202472761754068, 0.04661789043776451, 0.039988441332694025, 0.03712512642866181, 0.013636650419944238, 0.04370897031959988, 0.013048168489589326, 0.05418793463538732, 0.004452557599682722, 0.024408499725283157, 0.06234256903670969, 0.04167520989393515, 0.011715417776647355, 0.012134840381481956, 0.09292625071060273, 0.04538074270972321, 0.05232590813970855, 0.07222361321891509, 0.045315874214734764, 0.0360363622706744, 0.017460965168391986, 0.03748945103237226, 0.02412922428770652, 0.04175926123054759, 0.011044343907175767, 0.02669573374723475, 0.06559598740310439, 0.026106556592088555, 0.08802120423605365, 0.031151157473364187, 0.004239702942751108, 0.0404250578233792, 0.08413644131994055, 0.03736605341996878, 0.03054376083215879, 0.09109972089889551, 0.008672937889763666, 0.020243829349055886, 0.045615797637090574, 0.06706871482874117, 0.026995477138928352, 0.03133900797805719, 0.08520859669172957, 0.06764207801391041, 0.06198489024574238, 0.04494552432949986, 0.09719722153198335, 0.030922508956263625, 0.04700531642283163, 0.02829742824448453, 0.03842584030222028, 0.02524604258548108, 0.010242168453612156, 0.04449889506964434, 0.02329832724025173, 0.03355026523011827, 0.02611028552505999, 0.030144701801961472, 0.032821784562040726, 0.06319935411034573, 0.01058098232944406, 0.014131293282844128, 0.0589912178205146, 0.03835343350205691, 0.011361438232744414, 0.012226566003875868, 0.042435548328343904, 0.039833193614838586, 0.024944315026063594, 0.1385608366540363, 0.027747357962653044, 0.11160886756354764, 0.04669021679869583, 0.0696261308246082, 0.04805624349823883, 0.032221393794902874, 0.03517080932074497, 0.054871411468353004, 0.15443192614663034, 0.17865041691449382, 0.15811031263682152, 0.18239260320701908, 0.15012321783409965, 0.1945600099861622, 0.1410268890040536, 0.14657932573989516, 0.21030847944559591, 0.20898892363953978, 0.06902193260048667, 0.09254433289771119, 0.16514546658483245, 0.17663683141431502, 0.10402481161778974, 0.13828850771871307, 0.11009167639478562, 0.1379687426191184, 0.10068779390665794, 0.12574216320870385, 0.1464977067324423, 0.3073996437653419, 0.1977853627214509, 0.12793389479479483, 0.08896714662231746, 0.18082132623080285, 0.18720941167444954, 0.17338081984029663, 0.2240700998734082, 0.20057612909905373, 0.15551692115203028, 0.07019748685941582, 0.17641022260631287, 0.07693136907032422, 0.15772048113567216, 0.10359600156305299, 0.09764597285538913, 0.15638803973072962, 0.16752754037659015, 0.19130559187502633, 0.08388914047710358, 0.1596953638739163, 0.10428532747732056, 0.09889361598799307, 0.11320775434855493, 0.16133606373783083, 0.11120679397736827, 0.13055946197240584, 0.17729339940894037, 0.16792658025458937, 0.1296817703593162, 0.23097083603422489, 0.08315737329183087, 0.12600618775092787, 0.21692208585239228, 0.0891795751428412, 0.1438359342395298, 0.15618942377548065, 0.1584633719176054, 0.14924911151249565, 0.23319151042209518, 0.08966970287503735, 0.30348187012057154, 0.19958922399147866, 0.24775107271007954, 0.21235630907599004, 0.1294137774816444, 0.12862467627611854, 0.07878599898709406, 0.2948707660600063, 0.27780162230614697, 0.20613166083010936, 0.09893598065020577, 0.09900017881826048, 0.1420547798155777, 0.26623706543637865, 0.07571981633983313, 0.15338145106309845, 0.15461428571612607, 0.26723530864523304, 0.3189439452703922, 0.16715690703882327, 0.2797649830820099, 0.1200860441331902, 0.2416209597140551, 0.14100716990088263, 0.20848482246360472, 0.2583324476595848, 0.18540314488833953, 0.18709036161101636, 0.304883596517386, 0.20694922986290148, 0.13122261832318, 0.1438307248416447, 0.22304921110551204, 0.2854425219758865, 0.32747240376568615, 0.25157349905179394, 0.13309038664785125, 0.128151195634517, 0.17403208650648597, 0.15952840267169863, 0.18252182691808672, 0.17325564107346922, 0.12438622588712363, 0.10934953637901815, 0.22185877175821414, 0.1253106488635944, 0.16417179947658894, 0.15462016927138453, 0.19191067876114, 0.15151607293275096, 0.20068114443171411, 0.08909178146671864, 0.15217663990634103, 0.1576085556899348, 0.1274773140528029, 0.11201053512312713, 0.12113995895150209, 0.12178464492242183, 0.22736055476050224, 0.1277931108169498, 0.08499166357421106, 0.148397512854107, 0.1892167458971662, 0.11932138879332813, 0.3608319169330982, 0.12817963281826628, 0.17192929772840393, 0.18457285879600435, 0.15734177323118334, 0.1332699576573026, 0.11380132693316668, 0.1486138407621653, 0.19357301294803622, 0.08470326211423644, 0.12705604996412032, 0.1539449546966822, 0.16064522096947317, 0.12316322014216455, 0.18429902832834952, 0.11916865384386433, 0.15649520010957796, 0.10890541988755427, 0.25975265209713294, 0.11910951951698912, 0.12543048799758957, 0.2138348281263344, 0.1716019330366004, 0.12099195842541034, 0.11299247598095287, 0.244822119392695, 0.13393300675576733, 0.21354654924042765, 0.0758183352468956, 0.10832326967389354, 0.08574142616482512, 0.10348086620891288, 0.14350021918935163, 0.07933277892129076, 0.1406455304353468, 0.12880553431328268, 0.17086604429829508, 0.0754468055862573, 0.14825989281938923, 0.11033307836060563, 0.13812389074554368, 0.18345550423668278, 0.1906087582991008, 0.11805633248220529, 0.14075279806650456, 0.13250678086713438, 0.1142142176808369, 0.16947582454210328, 0.17778453837719657, 0.22089550812398234], [0.07310620779472013, 0.00982618654116748, 0.03293840612675394, 0.02697534243305845, 0.05041166892155044, 0.029459616184354793, 0.07599937714516156, 0.07434978300044615, 0.05136637918410763, 0.017484225512992953, 0.023298928619272286, 0.033791356930328954, 0.04575227620080114, 0.026114499008643533, 0.0179618047249894, 0.01715950957018762, 0.041372819668463165, 0.10315101173135544, 0.03383156505503482, 0.07502214772807014, 0.02516920588189556, 0.09163146252713858, 0.0295007455297896, 0.037674671940265164, 0.05798320316018597, 0.011530995515415506, 0.03920415882021189, 0.020682487464059266, 0.03021538681951502, 0.03324558823219231, 0.017509722834332817, 0.08220559331558405, 0.08317785848292612, 0.05478019720964855, 0.03924741980529601, 0.0456033640300795, 0.10013717587196058, 0.04745173117806835, 0.0349024448904299, 0.07172064585310799, 0.08726202642485019, 0.05182093362353983, 0.039490147103225036, 0.05677548853019553, 0.0005943089866289689, 0.04424889376687427, 0.022502771743963805, 0.03315710507693791, 0.0317050447882784, 0.029231931022819013, 0.03628745907917619, 0.06347459417978121, 0.0634215962171795, 0.011144276246458534, 0.046209956278964404, 0.053033911277570074, 0.09150679703922042, 0.0027298851308578086, 0.03563549144253616, 0.05199622220149444, 0.03038050941071443, 0.039123091396064534, 0.010536820233439007, 0.04692866932600737, 0.022016244625011762, 0.017066663544204448, 0.03883053007866106, 0.026108414355304935, 0.030529051944012606, 0.009713778460037806, 0.08348216392820881, 0.030608031778566303, 0.07051967279685122, 0.10947679890499962, 0.03109834720230391, 0.0650105889766447, 0.051562765823496934, 0.08016396899737659, 0.04449269741833691, 0.010870118276216091, 0.040481491690321315, 0.04887739399207696, 0.08656726128632024, 0.029849886270840804, 0.008586312497725651, 0.07064470600697302, 0.07645064123695897, 0.07682382564751372, 0.08052059824788764, 0.07827615981260616, 0.03370897949583108, 0.08996355888103286, 0.07001496641145599, 0.0819353711220526, 0.08441319824346612, 0.0992297523865296, 0.08500051188973651, 0.039942862931638956, 0.017831820671656923, 0.050227432436640226, 0.05696880315700847, 0.00294215229411249, 0.00529326344539802, 0.121316802687943, 0.07365728548217206, 0.03697866956973749, 0.04423679723854988, 0.06445227175830834, 0.009711868985886536, 0.12123673117809719, 0.0693239014776003, 0.06231048527444082, 0.031041210449691263, 0.04183531077879091, 0.09482694549425956, 0.01972519740041706, 0.02960287271097543, 0.06987642707122911, 0.05399488430890826, 0.05090782959615031, 0.01743344729015183, 0.049577943094435244, 0.03254804602493683, 0.0260776961447611, 0.06060364904002317, 0.07499491330236197, 0.1103317836720136, 0.01443403495115138, 0.024639881261053587, 0.06217428633282262, 0.02309129389393474, 0.024570799282481594, 0.03461796197018797, 0.028338467574588237, 0.03882171623709221, 0.02632877380106478, 0.021007036782741066, 0.1465645708864735, 0.05056864033723551, 0.0463823605358841, 0.04653109267594353, 0.02149369222142043, 0.08009106807050206, 0.04289077692514947, 0.09234091357117699, 0.018153512482381156, 0.07230849576092536, 0.05276766891080526, 0.016208782964836688, 0.1134593835881641, 0.02302446038342051, 0.06369554542846258, 0.056568227272721074, 0.03872286408178268, 0.07139612334750353, 0.04004947172718183, 0.0709844813231499, 0.0479169265787688, 0.022836688402739745, 0.05294809027785256, 0.030076747887857982, 0.024429938695844144, 0.05927100079134107, 0.024761536023429325, 0.08232666585113733, 0.03658360568806529, 0.02093433312350704, 0.014266634205987137, 0.05202015861868859, 0.09327580896957267, 0.05291497229688591, 0.01566701516088459, 0.10835549899286802, 0.04823356987007203, 0.09180973884799788, 0.0281607236848363, 0.034514632030961015, 0.029616926593946356, 0.07132624846792991, 0.13756875279209307, 0.06092136102398077, 0.08299939064008575, 0.03018346202049044, 0.03240211393624064, 0.06945792855995317, 0.025651366299679203, 0.023182448780825062, 0.05918229930102826, 0.03690802860223959, 0.048892773207156896, 0.027969259160360502, 0.036509306650728955, 0.07724682875578442, 0.06164394664548098, 0.03969303016821223, 0.048693452451017596, 0.03126850682160547, 0.015474139119408306, 0.042478250069243294, 0.032739280723035336, 0.009107073213184073, 0.030441560872620156, 0.08101821831998327, 0.07441866962659745, 0.04853513655102542, 0.07284818172094322, 0.045987576276304266, 0.08656298651570275, 0.01683520923008121, 0.0606768180976712, 0.050837372489754236, 0.010824831946182155, 0.0520961353885791, 0.026290425354795113, 0.021384484472594435, 0.06965501233935356, 0.036798876394788106, 0.018047001363048633, 0.04054711095147556, 0.04764621025852619, 0.03845889699615298, 0.005021976389651818, 0.018207816624893777, 0.015858948914214008, 0.03522032924417046, 0.06508270083295722, 0.0028186048157588252, 0.02029381658611519, 0.0037861293352644656, 0.0033144492396874536, 0.007140579137710795, 0.020616197875971277, 0.03589247180629642, 0.0810017780731282, 0.05717150236089384, 0.03597097283589744, 0.05528249424852191, 0.09900579424274546, 0.01432006692348589, 0.01685391709719214, 0.035130390521859935, 0.030032019844398867, 0.08633089251816274, 0.044275051839048826, 0.06689792318690209, 0.05194648777345016, 0.035320522053347486, 0.02240277045676785, 0.08217592273027667, 0.014392823251264711, 0.04470182793034662, 0.024064773310636802, 0.05370071803730342, 0.09672171075738246, 0.013760355425127333, 0.09582472138948019, 0.10632122911873365, 0.12803541676652047, 0.040198157901965806, 0.027707404562182007, 0.036094117639285904, 0.07316148103845697, 0.07130780107071323, 0.05150866852472386, 0.1284251716588774, 0.06483648783497273, 0.08558641593422621, 0.0791737697117271, 0.023017044652313478, 0.025271516924183217, 0.03944703550528615, 0.14765053116265806, 0.19148421293545156, 0.09766561534976768, 0.06830069146329357, 0.04805222153663636, 0.06309724225091838, 0.029006871627643708, 0.06690936087961159, 0.06849847238270507, 0.159103698848236, 0.06512256804853678, 0.056008132730400374, 0.03443348799802123, 0.05407097982242704, 0.06650573213494594, 0.11491545626232702, 0.020964938336082047, 0.061573539334799976, 0.008204505767583126, 0.06858173081831587, 0.034467858532744075, 0.024448834254496524, 0.09203525215026834, 0.01943727857583473, 0.11894029069451556, 0.09186020105957024, 0.03988600005545924, 0.05218636905474048, 0.026584442239254717, 0.058225459314041564, 0.04823972538654362, 0.029145615896390333, 0.07409505110474364, 0.06197339126599893, 0.003453807815188362, 0.005852890195279953, 0.006634919930459752, 0.016116647485403285, 0.0809399088123633, 0.03481434094869802, 0.022873508503600475, 0.04882534214806172, 0.04863426066754807, 0.023121048748913794, 0.08779840288503517, 0.07016336530326836, 0.027651771257120757, 0.001103925157710159, 0.06872672061886519, 0.08911832641329497, 0.025593536237495083, 0.03902130512400501, 0.006432265734239932, 0.048499923319585865, 0.02843140936156194, 0.01799709073478176, 0.06230795335385108, 0.021901180134004643, 0.04838938832343106, 0.041379645511868506, 0.07428687186010423, 0.031024615070031538, 0.03336881347481282, 0.01816277640060552, 0.05677373035840931, 0.02574599922574576, 0.01158749258461138, 0.09123411570345202, 0.022979619341992566, 0.10488046288129785, 0.02117070763732397, 0.04621654463511321, 0.04233483074893875, 0.08434291733729263, 0.019988900185712886, 0.05926441243519226, 0.03471482229689437, 0.06075590135409467, 0.05354350147348258, 0.12965368557601206, 0.05111592971990186, 0.17019495127662537, 0.09154384505123862, 0.06171176840941753, 0.14218714448713488, 0.16974942518338082, 0.14876675191185168, 0.16229894432810046, 0.1226144100749685, 0.13832157207352502, 0.12259817667185299, 0.1904118737025607, 0.08622619128155132, 0.12418764057539164, 0.10987248331789048, 0.12668829711694873, 0.1392987631862202, 0.18636935030020055, 0.2803400086779749, 0.14974887663077924, 0.12765969660493637, 0.12315455568774093, 0.13720302241704158, 0.22843549869233565, 0.10326370326501709, 0.1481943616583463, 0.12155807441881589, 0.17653995193541053, 0.1741657688492729, 0.16296351028065528, 0.17700991623343962, 0.11493595677518076, 0.37269031448710355, 0.16511310703091084, 0.11005213093613425, 0.08965183770464313, 0.07390375128917157, 0.13640347177222853, 0.2082565742274446, 0.16945403700153674, 0.2121598075234121, 0.15080597071397692, 0.1905910769898084, 0.19924808503879657, 0.15527647679611561, 0.10742922208362049, 0.1807691096778839, 0.09465553332120182, 0.13959586740501467, 0.08586402321534772, 0.11650632210676709, 0.181101729732848, 0.2388580023281036, 0.15079218113133985, 0.06682126842919858, 0.13586420716056902, 0.14760329418124693, 0.13340293519919919, 0.1694281279079376, 0.08307788400880753, 0.1337112549452051, 0.16296557871805084, 0.2172409622899948, 0.10418015126619609, 0.1941781917647008, 0.13592664332639787, 0.1552157873107541, 0.20846838221674968, 0.19530473937911375, 0.15507603755160687, 0.13661526443977512, 0.2575832443131555, 0.0928839703180617, 0.3005990812615041, 0.2643200070146592, 0.20775538418562184, 0.16409073205244157, 0.11089137259630427, 0.16358414875163188, 0.12775775585924426, 0.19410976479130407, 0.29963800863873574, 0.32643843021604324, 0.26657006853530485, 0.15289210474058507, 0.09014285409883147, 0.1168193456326281, 0.26459950653295367, 0.160909965634346, 0.3042080295422385, 0.18649673540024989, 0.18645567308750846, 0.19629660873643814, 0.11751787226286628, 0.10910891582288089, 0.12888436476069112, 0.2592939799351077, 0.31831305654298875, 0.20358274841020185, 0.17060085530242614, 0.18232538665254272, 0.1073904580346519, 0.13618084662143262, 0.17280075338578996, 0.25128305979794074, 0.26917746410735194, 0.199263054396837, 0.1406057091850427, 0.1593064363565176, 0.20235087902795887, 0.35816856629906163, 0.20499985785253588, 0.1339699781589931, 0.18038151515347345, 0.11699700142226874, 0.21469612545784444, 0.18395810388028624, 0.1124201623362399, 0.14574438183298036, 0.10858333354154903, 0.17927379798023932, 0.09623998700971566, 0.12685354228221601, 0.23614093360881652, 0.09529109518494337, 0.17392117229680862, 0.11656191710743213, 0.1511591372470702, 0.07970316711092189, 0.23539773639171357, 0.11541178164583062, 0.08273201829363262, 0.11830128909599398, 0.10350659910228946, 0.15147091971049387, 0.20531884154244778, 0.14121956011701015, 0.1487586467016128, 0.29202667996287346, 0.15351816711406555, 0.18867302265378738, 0.1872778999348802, 0.08169216884961052, 0.1254929701286939, 0.20673302452891104, 0.22657989584390195, 0.2071933820843697, 0.16450961360767966, 0.12645075623426708, 0.1855524401030233, 0.31605845978183134, 0.07475528099964704, 0.17820227080054823, 0.15433092511469318, 0.12618925212131393, 0.11487876065075399, 0.1026351357840242, 0.15617143603101855, 0.17634315926942135, 0.09118926891636464, 0.16511460856324242, 0.18133101984858516, 0.17097712704731574, 0.1729062130494464, 0.18952125052530922, 0.16153270318623514, 0.12618993393956654, 0.14517808963935222, 0.09614781897154548, 0.1277051256188462, 0.15688659443009287, 0.17032149367995802, 0.096247065662136, 0.17169821496692397, 0.23045866029156795, 0.3056354045627579, 0.12154914183361877], [0.032511120586986506, 0.04229405954960854, 0.05482790533513312, 0.06043296082005386, 0.029305372041680162, 0.01805385593475113, 0.029037187642027295, 0.021136995938216007, 0.0018140835163649174, 0.05696192751788805, 0.04118526602284082, 0.06590939397292753, 0.021054972819383108, 0.07044938422979848, 0.0345373580292348, 0.012001776654693869, 0.04815594601114431, 0.06250154760275638, 0.04869752420833515, 0.05802757880319992, 0.024436475341058066, 0.010851306029625479, 0.06568663092630525, 0.038752381449505206, 0.04174276352709821, 0.021291287961385904, 0.006917392348705401, 0.04198748265363036, 0.011036130487017575, 0.03163304592993471, 0.042516002882151835, 0.09799241313650724, 0.03374042740512279, 0.014450683956965806, 0.07904959452008048, 0.048381654665835445, 0.046072018317758076, 0.06758029302281719, 0.0071585558696589885, 0.019929737130540515, 0.08821774409302781, 0.019054133107044527, 0.06804422054800295, 0.018370594987044894, 0.06271966432611789, 0.00475775218576253, 0.0471988340629445, 0.11681981294626191, 0.033080074936151505, 0.05941278451392728, 0.011083156794249531, 0.04396409675058338, 0.07604286029574371, 0.04032509867101908, 0.04265516275359739, 0.04606270651903845, 0.02799399613943552, 0.1129485791428916, 0.011201262654316042, 0.009574901083514336, 0.05444236009592011, 0.028945791437440825, 0.021144313993112698, 0.018237833864986897, 0.0894665210357597, 0.0449525838297221, 0.02952849131918723, 0.0793886267309708, 0.0344360773752053, 0.06306267636377486, 0.023565008192353194, 0.04094692840871792, 0.024258515031467524, 0.05382712637524932, 0.03044815880486802, 0.06121068561990416, 0.040596584909625595, 0.026650069161288203, 0.061571310018940326, 0.04322254279207799, 0.08437259558347926, 0.015580513300524365, 0.06068447131603476, 0.05892515805880389, 0.03699471145087192, 0.09434781112377683, 0.07630524540980978, 0.022075689217496305, 0.050600884977968476, 0.03246744208398365, 0.054718090461627136, 0.0808307336222741, 0.10624265148034019, 0.09352119459259896, 0.06571576525006564, 0.05168186185220557, 0.01655581121843669, 0.03740240429197589, 0.009365871120544692, 0.05881054364445229, 0.07817537328528781, 0.08501553487393164, 0.020344914650664698, 0.04642868970310496, 0.031269232689913724, 0.06579910795534812, 0.024283711663297108, 0.023115730183499477, 0.04602203108069878, 0.03443734525071998, 0.013810107090149917, 0.0651081655955603, 0.08043281989352358, 0.07620134090463962, 0.07129761210132031, 0.04361687889022212, 0.024765358802171487, 0.03797509715021138, 0.00981402202253981, 0.0197912992969636, 0.026846829268540588, 0.03759444338239489, 0.07730150445094032, 0.04749045692264073, 0.07759310815843844, 0.03644913427471634, 0.04955196505292289, 0.06308119653934433, 0.01933174038816604, 0.11236678132967604, 0.062058346586362015, 0.011020553046687236, 0.08380202861923365, 0.021300567201368754, 0.055339931690644835, 0.050433291753213254, 0.020455968671388203, 0.052529771797238826, 0.05429087770021251, 0.010800822750635205, 0.04098143300882751, 0.022986640537818594, 0.029536924032013745, 0.04457323624181651, 0.04322708186302935, 0.044033400894653414, 0.03817117352399134, 0.01747668720781803, 0.06339032450811037, 0.061581142757448463, 0.02578104200262216, 0.020007998757665197, 0.06874116137623787, 0.02198791660879168, 0.03693313330351826, 0.005281501122930598, 0.02304242897568451, 0.05544274835096252, 0.05800119090464808, 0.06621768307541648, 0.042115101410496625, 0.017403753722206722, 0.0431432067266395, 0.029932621851443287, 0.030953393790930993, 0.04156681228308909, 0.025600080543588248, 0.08317052702149076, 0.019493361957551494, 0.007839129229391655, 0.034932483197940935, 0.028444168555940834, 0.06775025728969805, 0.04518214973711199, 0.028296863254640373, 0.02532628838032965, 0.03548972789318331, 0.01088154926565626, 0.11353216194097074, 0.06245109688250288, 0.009337545977154327, 0.03479409324485929, 0.024416635579039014, 0.033684709830389875, 0.03916917158471, 0.03863877061033442, 0.07184244617218934, 0.023539993506405624, 0.04358599405555476, 0.05158267644864898, 0.03921409115015019, 0.043078211827143546, 0.010226672410123773, 0.06901795660415966, 0.04884447519397063, 0.06606141646062175, 0.019269129937334407, 0.04494507616806415, 0.036309112554355975, 0.06378224742929302, 0.03390766822943284, 0.007443397414810475, 0.040159593035857526, 0.00688551351495628, 0.04033905296255985, 0.008247447868568764, 0.07233455041123014, 0.05989923885452652, 0.020858760464996583, 0.05478290150002126, 0.029381806549105435, 0.03117025987575612, 0.035480668903478695, 0.06848231558838198, 0.04675168003286085, 0.038065369120768966, 0.11368860475598805, 0.04045737907290459, 0.11040178878653435, 0.06465038975640651, 0.015132072242727924, 0.03340380837119395, 0.04850126780389298, 0.012104994553561893, 0.05730735273250649, 0.04986362877271829, 0.006749876690352517, 0.07708262547009415, 0.005867019250628449, 0.06657287974150912, 0.016841935482056394, 0.06058883289956759, 0.07056510947164028, 0.05419992774184193, 0.05879002397940044, 0.05325172156576188, 0.10909428354352714, 0.016975891701276266, 0.02140565531238193, 0.03003169808747067, 0.007526433206118284, 0.014678646825374135, 0.013769315781011699, 0.0651474122799212, 0.036170105900495284, 0.009663199420056997, 0.031703200431600694, 0.05261024550324487, 0.02393982628540647, 0.03558265818883816, 0.0696067334783654, 0.07051514521721872, 0.07400826100380191, 0.01362707049045111, 0.029285244996689504, 0.13112068266397522, 0.043115669696201245, 0.004496834130071465, 0.08219143601074334, 0.036506441481892145, 0.05178009347629644, 0.026479011303895426, 0.05134372979462628, 0.032234455594011856, 0.04784560379301829, 0.056556563584073904, 0.1797613669787684, 0.0579192616315859, 0.0732023441683381, 0.1124481705107516, 0.032484560318651705, 0.0712838301795625, 0.1619702466433087, 0.06994566609782558, 0.018471827760579127, 0.036196957282241315, 0.06855127116244647, 0.04393345706405179, 0.096985719977848, 0.035031840971280495, 0.023141422857260032, 0.04608466642938795, 0.01291801302408379, 0.021902246911439206, 0.014694961625331593, 0.09035409518307255, 0.017026206440923196, 0.06945069668994797, 0.035574847922450116, 0.06095354054724017, 0.04347928566858173, 0.022788608724611904, 0.018756527100659667, 0.06081364140094769, 0.10611875208034631, 0.07214775519265283, 0.06112189985991967, 0.025085505030508486, 0.02008202008812899, 0.05455572961739475, 0.026413074116252606, 0.08121694918842086, 0.06282482138504425, 0.046462462689246864, 0.04599043378426183, 0.08947834177243133, 0.023416017497619315, 0.01245992691932066, 0.06973499191864845, 0.02819357545024926, 0.05939923624898638, 0.028667973482140133, 0.01861847997192414, 0.03183004543966344, 0.024601339377583038, 0.052841178877579595, 0.042279082530688857, 0.04992115431495252, 0.02354989136238733, 0.0657908188840074, 0.03543545439418766, 0.009811865485032961, 0.02896612724139085, 0.007115224500246827, 0.10833247038986414, 0.02476968528372386, 0.031884916487240025, 0.005988298629921291, 0.008787396213700695, 0.04898814349285057, 0.019770011628767657, 0.024189469442071936, 0.024339668640506365, 0.056619057206497084, 0.056789289604151444, 0.03157641479535209, 0.05236712750047446, 0.039388659605455976, 0.03343618324687404, 0.07823328953236341, 0.08449837189888762, 0.011289248810029559, 0.04017736244526121, 0.04042897636311189, 0.018584406296271953, 0.02775482540469497, 0.03582104559867613, 0.06796510664806252, 0.054306716568047, 0.014928154959042948, 0.05368489449122741, 0.015279740478182513, 0.14901334029291907, 0.1502422219322574, 0.2855383442534555, 0.24113513739599338, 0.09698542120355753, 0.07661573318464142, 0.10157228071963596, 0.10657347888956148, 0.0972701071370994, 0.137545402432161, 0.17431124894609376, 0.31672017588730783, 0.2063142349042239, 0.14885855988869745, 0.11589594155309663, 0.11446845928026785, 0.10430605015567235, 0.11839760166983451, 0.15468225303676822, 0.16652488450129188, 0.08277646671499937, 0.15856460277591983, 0.14849163441648408, 0.11697301520935952, 0.20002713517075588, 0.08756867609918119, 0.1040004117174014, 0.08761099479611843, 0.09731818681522723, 0.14984690524157018, 0.11769291569268513, 0.15393344805605952, 0.15449013350711716, 0.13082481950761812, 0.09400377635874095, 0.10551399461204007, 0.11586350539038259, 0.14645351878096982, 0.14369629173269197, 0.15006949974884912, 0.19946490324312643, 0.12131498705956245, 0.2749186189424607, 0.1153091028813393, 0.11614055342731938, 0.11917259153579512, 0.18029749062993836, 0.17816984995959267, 0.1932544735891204, 0.16529689152394572, 0.15536759529382954, 0.18715244537640005, 0.14219100557027325, 0.16635193249150632, 0.11414274933838076, 0.2313341302496772, 0.11792035953652476, 0.2888625223309763, 0.12905489593263597, 0.08038899966425474, 0.19387652166187766, 0.21175488409015442, 0.08725173786402711, 0.07564543686326473, 0.13317364508346205, 0.10589677810428605, 0.10658912240497528, 0.21157735087458165, 0.15141383083837648, 0.21256889847497787, 0.21941256108543566, 0.24504854433959533, 0.23497408976958645, 0.16875341895126528, 0.19383363605987644, 0.2171952728061907, 0.07006005834667914, 0.0964352551607355, 0.12492129233695808, 0.29001101070354063, 0.17982783276707898, 0.1288062544359315, 0.12480609569578402, 0.1706067541794431, 0.08413087952161029, 0.1946946882432507, 0.28150651543851823, 0.11698326546578638, 0.11376109965626272, 0.1153441284212374, 0.2849460050704018, 0.22872756205258832, 0.20421869331790557, 0.3191578676623683, 0.15632393349322582, 0.15377123659897238, 0.23955898810057874, 0.13093220971284375, 0.11091400283358752, 0.11146131902933122, 0.3300440077099108, 0.3131365697951086, 0.1691011309383377, 0.24240685867205744, 0.09298755306630366, 0.13194048867350625, 0.18645703672401368, 0.05377596702366587, 0.1747742265222534, 0.11385719006460522, 0.16705106433120467, 0.11976192765418561, 0.21930218313730535, 0.2225986594754842, 0.2365440643963314, 0.1067809661429736, 0.12174364389671434, 0.13216444681729042, 0.2667426528228868, 0.1420930995335502, 0.1393936201930046, 0.1625608238241365, 0.13870555066293286, 0.13484388529773683, 0.1878484975426428, 0.17621378234076887, 0.11193004992580223, 0.1557213287319868, 0.12363184378632616, 0.22197029883823088, 0.14707742078650385, 0.13084490633299276, 0.16095744776389292, 0.16132005250021336, 0.0827936347453825, 0.11676958822194608, 0.08346065984017427, 0.11648247378968424, 0.15617364236424047, 0.2032696789190654, 0.13292091267724193, 0.1453386769900399, 0.09401840863809471, 0.12325127428818135, 0.11369965940473542, 0.11696890897808537, 0.14515378933039405, 0.1102967964365117, 0.20465452073802873, 0.12179903971451907, 0.08840767261121543, 0.09062417948077764, 0.11924984384207957, 0.17899825147563414, 0.1214299308917215, 0.07260625115445546, 0.1320143395494069, 0.21458502738706528, 0.13930340567904134, 0.23447397225085767, 0.1753370559984638, 0.12652545746776367, 0.11385568853227362, 0.17256603936754888, 0.21756137090344585, 0.08395638001421768, 0.2101546336686419, 0.16187191159734804, 0.11140148756244492, 0.08652868875933271, 0.1375515771008307, 0.14236820170715933, 0.24007876343544454, 0.19060894216020263, 0.15446407119593314, 0.12948038116578134], [0.02679206930371302, 0.0520132523360512, 0.022363902985929482, 0.03170663250550147, 0.018266474062036124, 0.013628935914546733, 0.0218113812227403, 0.012481459735652373, 0.046140058416753046, 0.04177833681986217, 0.03946974618180145, 0.015541747336335962, 0.0342937956954683, 0.00651047804445449, 0.05830166974074899, 0.038074619632454655, 0.04214513971800766, 0.04339268325918144, 0.002822796513717021, 0.03293876235763873, 0.07387726762962919, 0.03133237174141311, 0.05747011577289912, 0.06572117383081107, 0.03073186606108662, 0.026634059838890552, 0.03265426028519869, 0.04922175817492028, 0.035952165377356356, 0.011563225791999891, 0.08071620347759417, 0.04815170571448342, 0.01918697466833457, 0.06429968236555016, 0.07165564329273279, 0.009570998823150031, 0.01617131743489975, 0.11778535952250804, 0.02131029077234768, 0.07735883081031424, 0.03758419695640764, 0.0693986410154931, 0.15871267224992477, 0.14313225183756123, 0.022696835221722726, 0.028140215511103312, 0.03882050964861147, 0.04222983839891611, 0.01885811418985888, 0.04630730307150272, 0.04598144757291002, 0.039117644510922894, 0.08797978952286706, 0.04805873328399274, 0.05666288892708479, 0.03282773706521238, 0.07499100625394814, 0.03287356827528246, 0.00983162385021006, 0.06378816545850809, 0.07164343951209899, 0.019088078462969393, 0.04276543727985794, 0.02751506669747253, 0.03131237110092996, 0.09652723933780387, 0.045155838447352575, 0.043641221334016135, 0.0780824851244688, 0.0261819836938934, 0.06903163127360806, 0.025809806688959082, 0.07062854921264995, 0.026718969193978176, 0.05401686720189549, 0.0905406988796688, 0.0788336496559843, 0.012092828119714415, 0.05010604963547761, 0.06453009096965676, 0.07869206128581878, 0.07782950757011291, 0.006725558665611091, 0.051069600552681, 0.011869503913687603, 0.06175062821937665, 0.02105697230886548, 0.029659388932369413, 0.02758584173035718, 0.07327114652481771, 0.018818405937523614, 0.026339594792995243, 0.0530627851314362, 0.0856873710008879, 0.030180991386934638, 0.07355217055808153, 0.0319001788739115, 0.16013731999743372, 0.03219469946118132, 0.01865475615035863, 0.03493216910189198, 0.00968314643438545, 0.011130975044873214, 0.05819471620564019, 0.03133643009219199, 0.06824698869980152, 0.06793518325374012, 0.027332739686713587, 0.08924025696732345, 0.013078116781769261, 0.05815016819284328, 0.03493462824412892, 0.02202517337976925, 0.038988240769193064, 0.03681126786696334, 0.05587887071493653, 0.010265030432492495, 0.04858904232781741, 0.05453655060621039, 0.03532002026575708, 0.07304644527574701, 0.011335448699913198, 0.01169425172490939, 0.041128066067974416, 0.07659273522515452, 0.034616858803577004, 0.031387748407019724, 0.025808349206683137, 0.02977869946569685, 0.013927296517537007, 0.11772687637036848, 0.01613212246147375, 0.041018618916672085, 0.03935665245197954, 0.03568779609556641, 0.009917972492985427, 0.06931119207893649, 0.028856994186137474, 0.030869036019148848, 0.04373181889194154, 0.042794732482082425, 0.03166605474337215, 0.03226098521882969, 0.08744682215394513, 0.004018760791363856, 0.011435562027468076, 0.017462120045937838, 0.03806557596450852, 0.04135670883941554, 0.07754122102332693, 0.015494407890664955, 0.034004187647012935, 0.018414608653514616, 0.10720785331702042, 0.04534313928395991, 0.02685846805933022, 0.05765632493421436, 0.021648361542893034, 0.023140919154449817, 0.028394187064540964, 0.07939458689502171, 0.04168060315292209, 0.04482625976144787, 0.009496241090669027, 0.03019195410513109, 0.010734302378560026, 0.039685782976448536, 0.051804704050863945, 0.03254321201013462, 0.09487465745018375, 0.05661656742074317, 0.027609324240456187, 0.03971419334712048, 0.08875853321965664, 0.02670300200641636, 0.03266119721135305, 0.041787261744180036, 0.03422799257321223, 0.07586345782563572, 0.033226068311881636, 0.05379265624909632, 0.007212566983540573, 0.03739690378067955, 0.053189354347846204, 0.10616562133955379, 0.06269225370018713, 0.1154528899238475, 0.04238107181604832, 0.03681081970552764, 0.023032121262663317, 0.024781521342153993, 0.07142312028595517, 0.04332038754176709, 0.037649513612831795, 0.02456649195312733, 0.03407880461083786, 0.053339791033537164, 0.03675383808571966, 0.05824917739617729, 0.05738721739861274, 0.024253062400666457, 0.008194849229297571, 0.03856544450466191, 0.013383638391631746, 0.057438702337564006, 0.05464509377376207, 0.03626561025157571, 0.03933936184752853, 0.03709581590467884, 0.03436493078967737, 0.06690638845846539, 0.016540774827702873, 0.08064518712701337, 0.07562633829131242, 0.023930778787020716, 0.007831043650155828, 0.024631603681031736, 0.0342075839909094, 0.062082493677735336, 0.0563342257162496, 0.08090141289416822, 0.03903109189723769, 0.028545160011778918, 0.015085180000882718, 0.023477262396725918, 0.05944955290385312, 0.03488965122209441, 0.04628433958597241, 0.040083248543763356, 0.08824443459630975, 0.08594548900521572, 0.04816602389778822, 0.02555938978349009, 0.07026129432262913, 0.09751644270915179, 0.10348955364597422, 0.03914301351253544, 0.055224639288480246, 0.021456150082691063, 0.028652418066837618, 0.030988304417640455, 0.060087179374550624, 0.02468071949307717, 0.044210064600432114, 0.02445557008257076, 0.020292087142626127, 0.02680605423877076, 0.03754777713648735, 0.03708944588358845, 0.016941067259458285, 0.05127784623313816, 0.01819314987158343, 0.06809128899007075, 0.06860733347674532, 0.062066382848687714, 0.0819830141300636, 0.06334662685290941, 0.11213708518733902, 0.0725451403207356, 0.06490401848549805, 0.01440472634238822, 0.06037390310197108, 0.05431862540482994, 0.035654268257560275, 0.04988198806982368, 0.03007854627926023, 0.03512285221668501, 0.10414773808611978, 0.027094170330993594, 0.052070161177506374, 0.058804571989082524, 0.010266762748811274, 0.03849019168785984, 0.04719544795431918, 0.015526592201973884, 0.07120782659659464, 0.04604730049088117, 0.06955296176696016, 0.027969697745697155, 0.07780456374729834, 0.0561739371398524, 0.046934204311260296, 0.046775218084334366, 0.004976767147215264, 0.05381043714981887, 0.03049526746655184, 0.04183294356710488, 0.04138878877124479, 0.028876877998212175, 0.02272948971949518, 0.0390697333721384, 0.038121404621990464, 0.020540809078562646, 0.0192486543223382, 0.03528356597188019, 0.06466140610075767, 0.01831027705432667, 0.09036740213031731, 0.044333167268984744, 0.04527145643688498, 0.043370512674652764, 0.07986137958904428, 0.014678046403963481, 0.02800082006762105, 0.086903688798268, 0.02481915541143427, 0.17660825633473937, 0.02111695699333664, 0.005829103644035998, 0.03787142630185812, 0.020194960600366036, 0.032843254176118684, 0.028994552933821277, 0.04545693398423253, 0.04479601461019728, 0.002390209166708613, 0.03306872151311367, 0.05544697332586493, 0.008104685468659287, 0.054647997246995095, 0.043394954709876934, 0.022610673312878898, 0.031770880469271255, 0.014407355939188312, 0.035980633204622615, 0.08227236553906433, 0.02044776003927954, 0.02411748782070654, 0.05690165555044528, 0.033390172006141756, 0.06854289782143409, 0.0610449654801238, 0.09688209892520983, 0.007914388749463064, 0.013436478348599087, 0.025263857960160223, 0.12799041676184825, 0.01942763352886804, 0.06350116593943489, 0.03621806300455525, 0.024170910962106242, 0.023116268360266284, 0.1110597740438196, 0.04068316816682777, 0.06763094675637062, 0.05831932040652441, 0.02430381955608966, 0.056793139195970954, 0.05802053462473616, 0.04802963726462857, 0.03964061443243296, 0.011555897203394243, 0.09257825527099833, 0.12723985743979294, 0.154720266319571, 0.13799975385829327, 0.09651777049105975, 0.10068815396798235, 0.09661885579266856, 0.08699637011534746, 0.2159075862577846, 0.2052792347967625, 0.16869588574815184, 0.10123868007212879, 0.10822823646688655, 0.1397354179813016, 0.1724836389504133, 0.1416236868188266, 0.18455206716973938, 0.15848492963179467, 0.08023347615474656, 0.12001532655689987, 0.14987952526538603, 0.15924150274405557, 0.16761314304124925, 0.10019579691992653, 0.15121443347344476, 0.11845839840750541, 0.12835007972053944, 0.18045723528390933, 0.09100183018393095, 0.1082548427004968, 0.23612737385255678, 0.12330455570331506, 0.10551333577642519, 0.10035138937734789, 0.1866793401178814, 0.12659733183681965, 0.15827891326719717, 0.15017030159792594, 0.10687600701085984, 0.145904999827185, 0.09753312044326337, 0.14752970377524055, 0.334316480063623, 0.2867508162894557, 0.16333642656043654, 0.12417765078885902, 0.1401634159828386, 0.13223704130899522, 0.17435756662199575, 0.19782067937476022, 0.12989730153593326, 0.1045657692837619, 0.18424914068272039, 0.2425719352979814, 0.25265239599731665, 0.17307176464988341, 0.16305841325271517, 0.15972481229372565, 0.1858747179710096, 0.21100696777143788, 0.1752158762106011, 0.12473897107185856, 0.11566994561543388, 0.12616728838052482, 0.11447511658432985, 0.16322951132972396, 0.11381186064212553, 0.205658249136421, 0.14515208861520215, 0.07517328921465144, 0.11462962119689873, 0.1124877772564369, 0.11495890110851296, 0.1271293722393532, 0.10927881114184858, 0.12399622584663092, 0.2080189337533328, 0.11326269051360507, 0.2781163312254414, 0.18359022845904674, 0.18623762914249975, 0.2725316728315046, 0.24711328919135758, 0.11197466688651232, 0.08447178864791509, 0.1474527732258843, 0.1358273889749281, 0.28726712890690376, 0.17758880291254292, 0.1661278211301373, 0.23585078546837454, 0.13818407461287516, 0.20222778402028546, 0.17854560076469378, 0.1906166490047209, 0.23279573407865342, 0.18101445699651397, 0.18474076994724814, 0.11014210796284099, 0.1763460857252921, 0.13085268978630343, 0.14800411138323047, 0.0798937391429659, 0.11663197584810758, 0.12406526569036708, 0.15496673212657053, 0.21459884761321932, 0.18608356886092695, 0.13032556000736453, 0.15202480127974866, 0.14813235450175502, 0.12230717817381506, 0.05954703376177819, 0.1550507719718641, 0.13773897752886818, 0.17130472156549656, 0.09700362345263844, 0.18834483058702564, 0.12043039299427502, 0.11576388331670916, 0.21237717731104744, 0.1361816280311154, 0.1333768575662567, 0.15344319774979545, 0.17517423167103724, 0.129012270800529, 0.1367076852869603, 0.09257862299320199, 0.21633613584262712, 0.13394068295676864, 0.18218448776150906, 0.08693460810689196, 0.10093164735383565, 0.12437065898050224, 0.1443564756623199, 0.16219533859722077, 0.1574616047042993, 0.1453127066094068, 0.12696952033307285, 0.14788584272948005, 0.14807665990965982, 0.12580181847536756, 0.12177963470739704, 0.15525260549639502, 0.18332703129178096, 0.07636806461960077, 0.14188170523172425, 0.106009699464325, 0.16138351522386074, 0.2146770192250129, 0.08093100687068316, 0.1164890698067123, 0.07013499706743226, 0.14119826287271517, 0.14049197577180403, 0.09633543390420177, 0.23001339466821766, 0.10783659699823588, 0.1433988810787278, 0.17339251034202116, 0.18414720502351561, 0.1807563466530654, 0.10505698486081055, 0.19131213426589969, 0.1492308173328638, 0.17165923641333658, 0.14040454981788514, 0.16364739697066047, 0.13610914079171998, 0.24514646569807685, 0.09376613588462915, 0.11284904133888984, 0.20841397465236727, 0.16724692236992622, 0.11455799963685775, 0.12195503053766106], [0.09832077374261233, 0.06788916435212859, 0.025478383646376675, 0.047497730927481774, 0.010829840245987139, 0.05477104628939302, 0.022638737028765104, 0.03723214125080455, 0.017037109787305518, 0.06829778032918131, 0.03357941104519752, 0.03120962338852546, 0.05273366992872569, 0.0894392100012591, 0.01209990006886543, 0.010838337118677314, 0.01554682266883432, 0.035924953934285915, 0.03162837470881641, 0.02854923176909647, 0.05229237264082317, 0.03801569597975862, 0.021824651780808647, 0.027462919092466755, 0.01004260925260643, 0.01881760154520312, 0.02716714595144074, 0.06154928882155688, 0.07121996909019447, 0.007380143450122448, 0.06924377634159981, 0.02652060413252442, 0.020101141642719027, 0.055559032836989056, 0.03380051168102411, 0.010439081778449398, 0.034355484925570993, 0.02266612084161851, 0.026700889518965158, 0.038427617626204606, 0.020750142603872285, 0.05906542875773965, 0.0223076012691543, 0.016593414644199996, 0.026321425102651123, 0.03511298117378066, 0.030484371781048757, 0.0359511005151416, 0.013037670212196968, 0.03639990163426246, 0.047165130024715785, 0.039752823330702326, 0.02807467860440093, 0.05527414772058687, 0.008362302643006608, 0.15399640516167687, 0.07139366420526659, 0.08991070647513674, 0.024066297825606122, 0.03461109399194679, 0.04054629123739658, 0.04025517016529076, 0.04114475146296524, 0.021155207763395963, 0.022956041070903023, 0.03991756670837922, 0.02039272428279923, 0.07797003107806368, 0.04704621785710897, 0.0314755478288017, 0.051407334244539665, 0.021814654333396785, 0.05386259624614351, 0.02630615313988059, 0.05945128426256199, 0.04877607886409087, 0.06538037195681565, 0.012388021906747693, 0.057677135712677435, 0.019166799742848645, 0.07570194350855966, 0.0625054010250155, 0.05936265172016236, 0.06425960830623104, 0.017209950714342056, 0.0029264111024883367, 0.01026922093343831, 0.05847081812399049, 0.03677817669907405, 0.06057578642221709, 0.018757754756558328, 0.11787784165672718, 0.055520762914731625, 0.04879664449441818, 0.07367046219446967, 0.1076169289468277, 0.07239289566754334, 0.032924961283682816, 0.03727955826287789, 0.046140698100169825, 0.013909806730225684, 0.015690788784394824, 0.018931800356855797, 0.04560214978071951, 0.023216756113294153, 0.05303567327979592, 0.039824755156352636, 0.021161826763061747, 0.05066820878475424, 0.11283222570895188, 0.0528272207555992, 0.026390405574573145, 0.07528735204569756, 0.03150593087587866, 0.05384517157630575, 0.0443369364215722, 0.040594367085084807, 0.06313775681079396, 0.020468879168132142, 0.04421479519336455, 0.03742169438590927, 0.04276678559460467, 0.005199997986276304, 0.018063895516998826, 0.05193798802793027, 0.046791428504812146, 0.041391761192391, 0.01179718234080581, 0.04595726217714049, 0.019876693202663335, 0.021600475301966075, 0.057295819278806455, 0.035343638756462646, 0.06297063473011218, 0.1222047062530633, 0.0157756531318169, 0.026198715054159685, 0.016661069784013015, 0.01574997673742473, 0.025518534314488212, 0.050597858930667566, 0.09015769322192477, 0.08538752418732451, 0.042532730411978505, 0.03524682056459208, 0.057437143348638094, 0.09522562531093437, 0.026719779331958102, 0.07019014007622196, 0.03030380485729585, 0.01923375965787038, 0.0698372493347814, 0.007502364638757202, 0.018649970016051686, 0.008618077375896035, 0.018126212939199422, 0.06261225113825453, 0.04735439970728852, 0.027900598530146866, 0.03206435343130462, 0.007061439861107859, 0.03569687423746913, 0.0664386994415714, 0.033174905129858566, 0.04106089164833388, 0.0094991177508247, 0.017299673016813975, 0.16487004265429514, 0.020900249871755802, 0.027755066722391114, 0.035189869588301066, 0.02614964712260952, 0.04117981530725956, 0.041516775250314705, 0.04485812901909794, 0.010359938192601887, 0.01099700063106514, 0.10014416259383002, 0.011863841566317266, 0.008921041209701329, 0.022471023145161813, 0.04808204150908897, 0.037669945177772356, 0.06830267563101745, 0.026720394117517338, 0.028367144160813866, 0.021095064115680514, 0.04673979800915526, 0.02179322876937447, 0.07598154261828431, 0.052647343310978145, 0.043610022403299815, 0.035118431889361916, 0.0422856938694754, 0.08037462019391599, 0.06253810914894266, 0.05659475306709928, 0.04376661460546236, 0.029312073395797805, 0.041171131700637846, 0.00532222492057049, 0.03317064185055994, 0.07046204000230759, 0.054974703103183746, 0.04051134230629091, 0.014918636316583763, 0.07916004907700323, 0.0064463789890249895, 0.04570498176279568, 0.05865757886861121, 0.012241869567773275, 0.02521697529441407, 0.08143654063103661, 0.01685900392100936, 0.05013302742173115, 0.057195584334793596, 0.0221986424989037, 0.04156199742048498, 0.06050141460652794, 0.01626686392081601, 0.04581712554359148, 0.03995783612011902, 0.0050354719860479236, 0.022531915643823244, 0.03103443057156138, 0.024440981853272647, 0.031331479248981324, 0.017114720239694563, 0.06458396227249215, 0.08985849758309704, 0.050425749617598714, 0.02676652793231751, 0.06067474966027564, 0.038333507555146376, 0.06737052282739071, 0.04841887121719699, 0.03999247861605498, 0.026221690031008858, 0.03761684379330085, 0.04105894195456659, 0.010432024193446963, 0.04339272156357766, 0.02605398572350462, 0.04920617977698003, 0.046886289342036175, 0.05086617739570718, 0.04905138405099992, 0.01610691625354511, 0.06961548986333994, 0.05086961330004758, 0.07288503055010112, 0.11240814241670793, 0.13843734328064228, 0.04366504283802163, 0.04099934797493681, 0.032117554407206275, 0.0622832048834572, 0.10038354208752995, 0.02838155618988939, 0.04856735054824141, 0.04428843922552563, 0.04018452536735324, 0.039229462704350876, 0.017544292551915974, 0.013884341010012695, 0.045540449059297966, 0.04046582136183016, 0.06423094129610447, 0.047948477909930294, 0.006700918405136515, 0.02203125611788804, 0.06590409264449151, 0.06915986673125336, 0.09108989199082698, 0.05988267986404319, 0.08566384444073324, 0.01532022535215102, 0.01838962269586421, 0.04166378369254451, 0.05110960566408692, 0.016501089558005333, 0.04335015388806501, 0.008140243439664765, 0.07252967300554437, 0.0364229072546286, 0.033034914053015174, 0.03538735556386171, 0.0633388931953138, 0.06165162284648227, 0.029619389566622918, 0.026384384123488303, 0.058314831131288124, 0.036629471372091965, 0.05371156201187161, 0.12827961495326412, 0.027602054066054767, 0.025775325071487217, 0.05394306995214955, 0.060660090567844535, 0.10732585383999733, 0.12305809755719478, 0.012380190572941737, 0.013709074457085902, 0.03951281181446487, 0.02114344448331864, 0.042378172173254916, 0.04816275270235154, 0.034377567409988374, 0.0566721968953648, 0.02023921941497153, 0.0627404980872187, 0.03673742848238157, 0.052342838682835145, 0.019273713058341416, 0.05898016700220685, 0.058169879635135015, 0.01980355478853228, 0.04983328019959792, 0.03941685930194874, 0.012121859021605024, 0.0443915048644187, 0.031795989000989545, 0.04091893555596471, 0.06321723460249844, 0.023482667147031715, 0.04790815870247541, 0.016124710560806336, 0.05367041542945851, 0.051455260705082655, 0.014619642733446053, 0.034016203736105276, 0.01876139558941847, 0.042048107021518295, 0.046521348037546685, 0.055665101540545305, 0.04338142559713414, 0.04998667015423698, 0.09556160083100682, 0.07073878926495392, 0.05597219554587238, 0.07976115996678991, 0.060306345638368404, 0.07394355721771717, 0.1325917093744201, 0.04666626122930358, 0.03856322284968149, 0.05857334367089695, 0.02158497542803807, 0.01915668738224814, 0.05123721292963432, 0.02616139125048874, 0.05649386694835079, 0.14530835522999688, 0.10083558758901012, 0.09702349577339427, 0.12834719922994414, 0.07494993628032746, 0.14235756840677033, 0.08423882897102064, 0.15389546541677368, 0.08619317289201484, 0.1843114236309644, 0.09742317150437063, 0.11100726637748942, 0.12708042688187093, 0.1839353510689351, 0.1524978912165088, 0.10919944443289312, 0.20108838145050312, 0.11940148328581165, 0.22778259259798836, 0.15455073106192774, 0.193617966987433, 0.09989491588766537, 0.10457755937691658, 0.15026908097488267, 0.10110341192733857, 0.11807119458793633, 0.1817404632005961, 0.20192108838067901, 0.13613607644313766, 0.10853684732630368, 0.19674303881343336, 0.11667489209362578, 0.14779351381284578, 0.15933441388751232, 0.06886137589331597, 0.10693180119438518, 0.13720717461359117, 0.0807960145175457, 0.15109487779198155, 0.18798070899661512, 0.150950669401115, 0.11630872504845743, 0.14168148049183432, 0.08834789477048383, 0.164548653448301, 0.07583530409441841, 0.0812161141525834, 0.10213487270858981, 0.0897733009450378, 0.1352843858541981, 0.1866090592117079, 0.14811254346803313, 0.16195104847992622, 0.13701723077364508, 0.15608975573653178, 0.1685724076965163, 0.20166333043767562, 0.1177767793377561, 0.14688050554644677, 0.1798488848632382, 0.15449586384479078, 0.11316228703024889, 0.12349230087091848, 0.1489505976919205, 0.07323511740973881, 0.16814382746815684, 0.1413138502187306, 0.28574714917809735, 0.12988104515018004, 0.1767431031311712, 0.12035373823657153, 0.18898768560780635, 0.13313258277072063, 0.1266876842466093, 0.18167226605357664, 0.07689440532797769, 0.24836645581789557, 0.1446058372816732, 0.20122449995288927, 0.10418160683325223, 0.18820875804991494, 0.21025316789746287, 0.1992869256965576, 0.10903200825616237, 0.11242521851654015, 0.15284172679868438, 0.15835921460342023, 0.16475736644239197, 0.07056795165783937, 0.26266130408452404, 0.16365256040327011, 0.2643965238765363, 0.10946147714651401, 0.16412005789818304, 0.14073122503055682, 0.25312783016312507, 0.18858810946826013, 0.1061559916143456, 0.146409667908184, 0.1304591044543251, 0.08426473040374056, 0.21263089030981067, 0.10553789655527762, 0.18099516690258058, 0.05947897834102473, 0.2630959517292438, 0.17988948752322506, 0.12793946425400435, 0.09397511700949363, 0.21873540064740568, 0.1886744016120511, 0.15317417831430513, 0.22765119319721577, 0.09395545919335659, 0.25431941864230945, 0.1452813889350622, 0.13567296097115164, 0.09418369976863747, 0.21791541077677282, 0.09734755862624415, 0.0930397313148264, 0.18551436553318656, 0.13114738848901566, 0.17374109566932724, 0.22938593801471496, 0.15573640534233663, 0.17193737229512585, 0.10734327467939547, 0.11226717457776109, 0.1319344825441799, 0.10160689257205495, 0.1787007948563945, 0.1368185075660867, 0.2196429237242668, 0.255811007152642, 0.14727130231838073, 0.11451979483207388, 0.1274185704307691, 0.09484178461735288, 0.18165795553115108, 0.22336359826787827, 0.10481608085214131, 0.1840128485233553, 0.11114549162166734, 0.12108846252123195, 0.1287726231760556, 0.1675409162717481, 0.12789447191021136, 0.1918117768101154, 0.09578001249821917, 0.08240626238647007, 0.16658037991052674, 0.18952310445808596, 0.12729330739426997, 0.13972650071786297, 0.15798577738385047, 0.0840495746102064, 0.12973251602342054, 0.12819397398420881, 0.20100890748923828, 0.14501344202266586, 0.17400816924148993, 0.12984940571890724, 0.14853577640268112, 0.15196095551213912, 0.17913885925325657, 0.1582763392117716, 0.3435127833677877, 0.154783116172879, 0.1689379082451905, 0.30720750891393234, 0.089728913810705, 0.1005345150347679, 0.15189871852917058, 0.09938408079887591, 0.1927104898758473], [0.06983128150985127, 0.06765946054891234, 0.038764497130027706, 0.030565793520861098, 0.030116201415958426, 0.015856486899147353, 0.025809846908575105, 0.04259215585226494, 0.054898507998234806, 0.06402030159088393, 0.061423604436699426, 0.043600737417657534, 0.04242431747937395, 0.013123731572000731, 0.03906098847848274, 0.06147644918171629, 0.024402491680736986, 0.06455155675329509, 0.020375203851970936, 0.0591049550641929, 0.032916955664874084, 0.04534282135747133, 0.036003290254983215, 0.053761012987383915, 0.05850924126383278, 0.02175703303017203, 0.04534135046865671, 0.04505415942760245, 0.03473772449539073, 0.01734710726586561, 0.025650060119768305, 0.016895234134168397, 0.03418258271150051, 0.024096173339433247, 0.04225299723686711, 0.04095132192296367, 0.07237880731061583, 0.027798787360229803, 0.04818718324625685, 0.020361195934275468, 0.08387957203892932, 0.07007788521267715, 0.10674357339138947, 0.027044966418836868, 0.05883976223788435, 0.040393399239908305, 0.03193316853515083, 0.10586486288136053, 0.02215707456813224, 0.0881621720750005, 0.015620412117230798, 0.052241385659022685, 0.03960039481640824, 0.027701578463517854, 0.024255404714494947, 0.01940807913460078, 0.0368496680241679, 0.08994938625443367, 0.011968900949033278, 0.023856920250240835, 0.05203013691390234, 0.022207626795035698, 0.01567710932689689, 0.06324672515714361, 0.008812040304614892, 0.07865106026011129, 0.09212064797118788, 0.0626171502705303, 0.025217647536567626, 0.021460846201666904, 0.07937926513653609, 0.10247293964869554, 0.07568842205669611, 0.017023042497795918, 0.02942180974529155, 0.061052450159144026, 0.05732958460406912, 0.04370143201442496, 0.03579301827196633, 0.027142633053083575, 0.0484637409869221, 0.05816309209612589, 0.05986032158797307, 0.029678600502290556, 0.09582809217634702, 0.04421438533632506, 0.04264473629694793, 0.046042861011359966, 0.05577827954003888, 0.03348725066790658, 0.04718844974113088, 0.05354325632534681, 0.05733472888448066, 0.044611969647268136, 0.04545661988818357, 0.0827193242167273, 0.07774873892025602, 0.04866093584907152, 0.021842562916478323, 0.07104748439404272, 0.025054170119185603, 0.06110163683432245, 0.03820144165787966, 0.05230140098701081, 0.059256215294402455, 0.04390957427301234, 0.009228213739040638, 0.05301542557595719, 0.00754643815584601, 0.05796625346486127, 0.004894256126135588, 0.030592478278483597, 0.06088971010138912, 0.03613460921652375, 0.007652787439104531, 0.07417552098031006, 0.09418409813435809, 0.10434102973029499, 0.06572559415813416, 0.028956564548876018, 0.04053014976483199, 0.07480311552963911, 0.05718623423167775, 0.01848973123536956, 0.021091337097928892, 0.03122739854358858, 0.12061949413750442, 0.015772624211686275, 0.017945322343298507, 0.03204565514029274, 0.02797471562160119, 0.09652408305555583, 0.07989259001107947, 0.0797725057289485, 0.08659063462889002, 0.017912212023211103, 0.07253466789881069, 0.03697555542232529, 0.0664351754371197, 0.07898634630105189, 0.023547566285537138, 0.03630982884656518, 0.0338833028030011, 0.030846716047474937, 0.03603885971730755, 0.014691634888520405, 0.027040580565470363, 0.07505508184793495, 0.12425484946898877, 0.08377729164015862, 0.061806384098505786, 0.017548739692316424, 0.023506201368065614, 0.04384926017073374, 0.03053346078001684, 0.024063917207381418, 0.0682213937022513, 0.04874282681773748, 0.04584422973435252, 0.030874684002370607, 0.032167020704477065, 0.031008544460599943, 0.03952239557439762, 0.04557616790876754, 0.033956383760537834, 0.023204448910790588, 0.04622101475815139, 0.0017474421263379497, 0.028284155771196372, 0.006712382432118419, 0.017622845292451884, 0.019114738322734352, 0.012775111770738038, 0.05806299887837903, 0.05020180679557305, 0.015692946279511576, 0.05112989167232187, 0.07039263243636779, 0.05903264785545969, 0.062275739356635086, 0.011383872159997062, 0.045204297339002934, 0.04668388125156203, 0.01458773134096015, 0.06476214666280054, 0.03975494539425258, 0.029321555649080587, 0.03936077783545179, 0.02566946321167052, 0.050706781311741764, 0.03427777296653198, 0.0030032291326807033, 0.09075631432595754, 0.04059975268319249, 0.006335067850041894, 0.07531881527674776, 0.018583151827295943, 0.021228566427805254, 0.08964746334259549, 0.014348669773748806, 0.017074150138444478, 0.04358841489339548, 0.05690003144404581, 0.05291746591307944, 0.02565359370031905, 0.07298409337958983, 0.027548127221844854, 0.028207548893988136, 0.01696385837520563, 0.032560560071179946, 0.03170943064164491, 0.07445036268402493, 0.04762944825474293, 0.07284118733819454, 0.028455776703213493, 0.02999015888499637, 0.11732528541958141, 0.036040146745020346, 0.023343164451240052, 0.041588247423210455, 0.051447166986162626, 0.02339655694912278, 0.01134983295830147, 0.048378077035229054, 0.021360017539512728, 0.03242504294781435, 0.013956027687527241, 0.0421155993676474, 0.006101973150150791, 0.015342815369818241, 0.02916901222159786, 0.059122061807542085, 0.06657260394985638, 0.07356486463498685, 0.04408473261601983, 0.015731579135923136, 0.01113813509413552, 0.013352419351107411, 0.02950804443248818, 0.025248132090294556, 0.04887648617788669, 0.016791408153010473, 0.02798740778328671, 0.011576178423579664, 0.06794603871962718, 0.032749894871226246, 0.03006477584882129, 0.036233687367770946, 0.024921813108507666, 0.05399035672927576, 0.0701232452786738, 0.03234380698432365, 0.038912041833804506, 0.04591805762761543, 0.03628598052948233, 0.026165805832152406, 0.04737880726855609, 0.09506532907365792, 0.028915521388332692, 0.06461353326636939, 0.005299248986111413, 0.05196516116660449, 0.051573138653991685, 0.0706309930331284, 0.013964203760899125, 0.053414350540767756, 0.04896609165195016, 0.007823155338560503, 0.11079378065563018, 0.04832871415982804, 0.05812381093780841, 0.04174811465124931, 0.06862141417279359, 0.10154940533421694, 0.01769136419639953, 0.053959341659661264, 0.05983991683610986, 0.018368702749871922, 0.07534706093851598, 0.04965930546243345, 0.05930768108115562, 0.07669090173177182, 0.08728658720370262, 0.01136914603487258, 0.050395378061840614, 0.06229944977789156, 0.026671837549656633, 0.03493437926555353, 0.05725030982566457, 0.0387562272108851, 0.015895920317439784, 0.03696885598342746, 0.023735864951665846, 0.09847088101049585, 0.09208743039879108, 0.016744289915227605, 0.05074235460450573, 0.029394201851720293, 0.009725458428053366, 0.034359667765637564, 0.0499777069255229, 0.017279519158745968, 0.057732489395646326, 0.05294428282086888, 0.034732545741022594, 0.02027952904632736, 0.07092179234830603, 0.031351690563643654, 0.12474442561787945, 0.0852151697261199, 0.049146558984272906, 0.018447944969539682, 0.01843774833926751, 0.050038247023739164, 0.017934669890711387, 0.012979349853741306, 0.035970593622374925, 0.023265398866046342, 0.079049042936775, 0.05736209737557558, 0.08874765477113186, 0.029602495412672722, 0.10207327157859841, 0.08809002191429177, 0.023284744501354235, 0.09336154953005815, 0.02585923659705347, 0.02692781433823609, 0.008232544585611791, 0.03962357663699696, 0.033384391872753064, 0.016422783880825007, 0.08498838471789515, 0.054284840927369175, 0.07344654235508173, 0.07899533251240369, 0.019980176359475143, 0.07133219331022232, 0.016792430880389387, 0.025248105277217207, 0.07801443353415498, 0.019696561033807455, 0.012595033228036859, 0.02166872032948079, 0.09629893747548904, 0.07152547729351828, 0.034235618978498444, 0.036602926425515644, 0.040815812460477316, 0.04298968653705332, 0.07471036526464647, 0.032581608336899555, 0.2380776651684315, 0.18253647451919897, 0.12141080933713144, 0.15817861703615035, 0.1510591780947101, 0.12443959923280824, 0.09006984591964753, 0.10985182958745188, 0.17962602988606502, 0.08853102042790383, 0.14265776762077886, 0.12030662382922827, 0.10775356072812312, 0.14505278829845691, 0.10297708678990604, 0.16765264253462517, 0.10986597923141335, 0.17034646814628956, 0.098479499499644, 0.1770954269675478, 0.07424023242727404, 0.12031919533206571, 0.2591489441692829, 0.17978320048461038, 0.2390120932531934, 0.1589459153793512, 0.1278292471843381, 0.1494551891641271, 0.19135673590485128, 0.14404018860190146, 0.1346131702584605, 0.09357570940929075, 0.0957262178041762, 0.11968652161979869, 0.10020908088453355, 0.15501164020069186, 0.13620359943278376, 0.11944759411797409, 0.13993637816559884, 0.20804859667776093, 0.2004256387872081, 0.11558128625995691, 0.13398913035710014, 0.1487174311712865, 0.16616129917242836, 0.11685028792388978, 0.2455437588956087, 0.2571777386530753, 0.18511566273387403, 0.2504512568515155, 0.04509502638792319, 0.12304076864834755, 0.06990113340678715, 0.17666159137602777, 0.09927141990873123, 0.14022401353764918, 0.13875721563254634, 0.16317660529767314, 0.11759471854255085, 0.14172232829995696, 0.08924889843910934, 0.1351420313961083, 0.15953131380581087, 0.1253506309923626, 0.09838573033771209, 0.12392075852521005, 0.19208798215033548, 0.11678405962283574, 0.18735919718540486, 0.049848107831372376, 0.130223379200024, 0.16338340307195343, 0.11286439374089242, 0.07400050819400819, 0.15208667054051353, 0.18634331863253348, 0.155575787348132, 0.17188926197348103, 0.10159372352063657, 0.10588918617295642, 0.1343691559328187, 0.22423100898102408, 0.0818018036924543, 0.212181227341775, 0.2259062287668067, 0.1891904690813634, 0.2570802309820729, 0.18750740455523615, 0.14535203756343934, 0.17872717892450674, 0.17180045706129846, 0.26244358189644357, 0.20269966353812527, 0.19065208823209812, 0.0895917151243456, 0.23247924783537466, 0.14877125650884646, 0.19369702726121873, 0.11928498429516632, 0.18175575431556473, 0.15238167567839547, 0.1006695686749393, 0.19629300812319403, 0.14598969850809346, 0.15827874472785383, 0.1923318892236679, 0.13396715895543176, 0.12781014095150656, 0.14122614847315898, 0.18100140285828423, 0.19033886552337678, 0.15815244747265694, 0.2254802225938728, 0.17020691757000264, 0.13827773652249767, 0.1164342485548508, 0.1970796578473622, 0.24366639915012547, 0.19357805380657797, 0.08673262136477618, 0.11466437094514409, 0.2427133398070451, 0.17259089125981256, 0.1497290196317819, 0.09524171315734425, 0.1305669543123053, 0.16635583953992014, 0.10346547550251407, 0.09697867196894462, 0.15979670198454013, 0.1670858600447255, 0.14619850343273533, 0.2474371452004679, 0.12704084311882335, 0.16325315280306726, 0.06562106912174533, 0.2631392203752072, 0.09535795167809534, 0.1669542461393341, 0.12668052132451726, 0.2070303432523243, 0.07493715793375047, 0.10713018732325685, 0.14257184319919156, 0.16208134471408783, 0.16247099235413537, 0.14203522925175008, 0.1547662775603033, 0.34138370245214433, 0.10494812376677029, 0.1244412539827247, 0.10135571532432111, 0.1723211517016734, 0.08750395699133796, 0.1324297890307442, 0.12936312374809097, 0.21630210621703058, 0.2026164817113069, 0.21842174892944677, 0.16152026191834482, 0.10276207655307748, 0.10214477056457151, 0.08404953630581018, 0.13821975898838815, 0.2535347607467444, 0.1582724628068747, 0.18892410031009108, 0.08375058581511821, 0.2032191937248553, 0.10789588454269594, 0.11368992242721782, 0.09135467496009604, 0.09932199703349222, 0.2095301954015609, 0.16889034950685117, 0.07683586088880416], [0.026656680500074744, 0.0856357366747914, 0.03803960175343579, 0.006928085020908545, 0.09934347813888904, 0.024841316419863896, 0.07958752613875174, 0.07732361374843506, 0.04559991280398062, 0.03091670392501739, 0.04301228996125921, 0.05641108348725304, 0.04430209857321555, 0.07061176422622896, 0.08052580764577275, 0.03811044190379401, 0.04632453238891979, 0.0638926368687422, 0.02786632950207399, 0.0056751678517508895, 0.026498320550026915, 0.023277652442395207, 0.04452202709451799, 0.06859434828642877, 0.03590392865120404, 0.12498524535687701, 0.03488240403033072, 0.0351533999726657, 0.03112847360992624, 0.08084433934380932, 0.04049035149716562, 0.023823511155862964, 0.06904218796520464, 0.08615038688144377, 0.021288553027496226, 0.06503978458743903, 0.055235697767667236, 0.05467866757704366, 0.060071306032759536, 0.08214504172604892, 0.020511701567879608, 0.0419565097188517, 0.0352325062117269, 0.028987891799319657, 0.0118632928558415, 0.040504888015528845, 0.04764710275095798, 0.0274143893376834, 0.10919071103055632, 0.026228533111392494, 0.019206739736781008, 0.018161870501635057, 0.08129068515113286, 0.048934651403537685, 0.056014012455219225, 0.0900958622655561, 0.03326424630358815, 0.016808970718674602, 0.0319429170039873, 0.02294625621289015, 0.03251741399928447, 0.043268531050172546, 0.08203877000919274, 0.05563799351934464, 0.016880705276684418, 0.026947640693716468, 0.07261819446519499, 0.040866780290079695, 0.007883077778387815, 0.08389919921154938, 0.022468638696497487, 0.08173428070280822, 0.06420184910717992, 0.04227732818934225, 0.09838036006136287, 0.04095976804232886, 0.06959348015727536, 0.03584096388470742, 0.04794594598934055, 0.015586519429850725, 0.034819649938013286, 0.09733019141300071, 0.023311381378481467, 0.02886758152125103, 0.03489284197829905, 0.02779389205839365, 0.02093540373138122, 0.04566049886747234, 0.040592968974622994, 0.016503064149630167, 0.04827085919978638, 0.07556069221708082, 0.01694004261685956, 0.06149347548583343, 0.021227919083509236, 0.07183670817363648, 0.021660461901657043, 0.023252024886108214, 0.045425049404823975, 0.11695697332822508, 0.018250589228926167, 0.011557526097843244, 0.1047331058690625, 0.054278026575282703, 0.08148003144249802, 0.14333250722096813, 0.040422273093774434, 0.038049331070074154, 0.05353274559902568, 0.07858120836317539, 0.009601825243613173, 0.03914435416640293, 0.037501796539272034, 0.016851559461605166, 0.052052594781402624, 0.007328845245102722, 0.027107697528516574, 0.03753150925941525, 0.019029932389516505, 0.070930341889541, 0.04698059859595472, 0.12137180014002709, 0.02186792808765125, 0.012935945227171385, 0.05989908180650204, 0.00931145972572267, 0.007458965757846713, 0.030222965344305963, 0.07996303179571707, 0.1018571045490042, 0.04911597292389601, 0.06634313763389665, 0.02502490364525828, 0.03274223399198344, 0.024306788146796248, 0.10656291453708565, 0.07721136654576949, 0.03800960941120021, 0.017169593202490962, 0.00774429424763507, 0.07240526798752046, 0.008677816912231427, 0.06316356248252335, 0.03645263912696992, 0.011057727463212947, 0.03792046358989131, 0.042301027119279876, 0.03916114298326354, 0.02706482533305403, 0.05541022791857681, 0.05471736650853869, 0.03996982156569439, 0.0522249224295299, 0.05708380444576183, 0.026740291336130713, 0.03520522965118289, 0.0467169494368136, 0.08411337441254048, 0.06541074734301337, 0.00795004822711851, 0.05314456884779277, 0.033874665161654834, 0.07806409901428608, 0.059229222186390436, 0.006212238579117243, 0.05722188413323415, 0.02633259849502675, 0.05785820825446037, 0.06853129158938123, 0.027754026758033904, 0.05146160391309569, 0.039111933325447386, 0.016609891280231458, 0.018901536053407098, 0.053959119494163224, 0.01857301265361809, 0.03991476282657635, 0.059372783232960975, 0.017872057524659944, 0.027658455374260104, 0.03209380759677339, 0.01313963843013851, 0.03865413067321624, 0.06746564796494861, 0.04218033379724911, 0.04789055783241507, 0.055764164370034015, 0.0396193056968191, 0.03337905607036045, 0.0359191891226557, 0.011265520194184878, 0.05531351314857603, 0.07958163492261403, 0.16486973621912543, 0.07113563047061044, 0.027170275420611425, 0.012283037217604298, 0.015511012846423734, 0.019849544961846644, 0.04464024595255333, 0.040046231175262126, 0.02888852636510086, 0.03598359413444996, 0.03863465288774141, 0.03812856754408248, 0.015100428023405615, 0.017648003619885253, 0.06056472028215086, 0.028240239780936992, 0.037610887459689574, 0.06478656188494737, 0.029186618837317633, 0.042431043731349136, 0.044159552593144684, 0.0628415642366294, 0.05974612852197982, 0.01602946380679045, 0.028557248879224065, 0.03374072617941326, 0.016120918425581148, 0.05904501251455757, 0.05342920881605918, 0.03238319156451091, 0.024867512796434666, 0.04525847507700805, 0.030022652504304727, 0.025310955130525177, 0.005503989814314992, 0.07590938479669633, 0.02322680335642109, 0.03171520885981379, 0.048930196602257996, 0.025112517290718617, 0.02875717101438392, 0.03423068537226608, 0.03665213991377143, 0.013118654324282563, 0.029969194888948437, 0.044428958903036775, 0.019206266677487763, 0.10749834619702832, 0.02275543711749056, 0.07858618027380398, 0.01946364540696865, 0.06611210083769214, 0.05301418068308023, 0.07017660330259992, 0.03792155909562304, 0.050596951116477294, 0.041890756392310706, 0.12339958891032204, 0.027810763229706117, 0.012996164526069358, 0.027810263357335524, 0.05421226558786246, 0.010556843856559887, 0.03501804755820382, 0.06729618165521853, 0.044384326620568196, 0.06653754010556207, 0.006275750140869811, 0.03322774221399619, 0.03526680779853656, 0.016818922200811007, 0.021822644630447034, 0.04098822820871588, 0.02739923228810151, 0.0281238729404586, 0.037346326655918555, 0.013169073443409177, 0.08524775144553955, 0.04848941642370436, 0.03574774247564135, 0.06594180715300384, 0.08455728406026479, 0.008252799950329768, 0.07264405759351869, 0.027635461245212826, 0.06582947568066659, 0.03828797128892714, 0.0320148277622197, 0.039172507897620244, 0.03320835635907227, 0.048046556316436305, 0.02819403701822364, 0.04935396196801336, 0.09566426427373964, 0.01891938398682302, 0.06340704054661817, 0.02122451956834524, 0.05704219054971492, 0.024430241300574234, 0.047742484527970516, 0.014653948150695333, 0.036314624556971174, 0.04901093843903753, 0.008863252324743137, 0.037072771979916486, 0.029103174625385194, 0.051846494147133444, 0.06128575840604402, 0.0065984498360194275, 0.04227288104894181, 0.042497670398123806, 0.039904949240266316, 0.057198430351432294, 0.021013203790531527, 0.05367277498026529, 0.014063679320257039, 0.07079420806539637, 0.025358178705397635, 0.03196633439661274, 0.08920167677945669, 0.030916318965835438, 0.016330793958097216, 0.010789313237182798, 0.0663201320135305, 0.1049078735072286, 0.1120583160269645, 0.05411141011263094, 0.06624596704158091, 0.026197719139858123, 0.10070650943464811, 0.04117661305973607, 0.012790642288183014, 0.009723727069344493, 0.025548231712872946, 0.008881006412388337, 0.034685994408303694, 0.026389965074016686, 0.02740202467858551, 0.05846281250518176, 0.027419928153375947, 0.035493006749499234, 0.09684191761358131, 0.021899814582279614, 0.016683274842498284, 0.0434372580850557, 0.12310090655040358, 0.007686182648138775, 0.04710506107057295, 0.009444276389155177, 0.03259470460996513, 0.08153685218384189, 0.041435014516595876, 0.048428956764720144, 0.1059409047687246, 0.06836747900853235, 0.022221789845535835, 0.024937268932380026, 0.013965933204388187, 0.02142819744955388, 0.1001957739372888, 0.2194262587375218, 0.13649940130210694, 0.09525419272963079, 0.17885899201275843, 0.12364873602505654, 0.09274098766787399, 0.1547888311887941, 0.1518462108628404, 0.1796737418419892, 0.23646172526622974, 0.1172483625311044, 0.08725484818099968, 0.18543118370636819, 0.13612979452215856, 0.1030347272453289, 0.13025353242072368, 0.1885576957776662, 0.19801569471676506, 0.12750819505703065, 0.12084002786826704, 0.06310154766505284, 0.11004528977097043, 0.19609802342470617, 0.13290035087735425, 0.19531587829753277, 0.1416105867153214, 0.17988542725722637, 0.1487822881749561, 0.1636572641831252, 0.13354961039318194, 0.07677982921802229, 0.20921772345900538, 0.23394581591410024, 0.19666275279896875, 0.2006091628103487, 0.13683720011143916, 0.10436972738393854, 0.13386911502288235, 0.17734167826992853, 0.09814046728875368, 0.092834664899255, 0.11134971534052204, 0.14875745160445092, 0.14300788512393353, 0.10318872623986776, 0.1645888730643257, 0.12011863351348909, 0.22882344561719128, 0.1281254780628989, 0.09210906472177276, 0.10283870066726401, 0.20439803450097963, 0.19887342207854797, 0.23292834389834638, 0.1897272822116652, 0.12724662199616432, 0.10851738869302696, 0.14549698139871323, 0.1218732123473479, 0.14289157765526928, 0.10107844512188628, 0.13688541768539336, 0.10461589441664758, 0.22914599927683033, 0.10691940589177032, 0.18263206697039067, 0.1046746916648361, 0.11795185341109192, 0.1686861257879965, 0.16724132992807897, 0.18730788461623654, 0.1253145559120082, 0.2117049658010083, 0.2089140308840621, 0.11352314508610195, 0.16068401566195875, 0.19649651171939989, 0.1551593725960101, 0.10894404604069649, 0.09668961167335512, 0.162121640938905, 0.10765688043207892, 0.16910229539198263, 0.08126108351373866, 0.16299603837392024, 0.16348549194874304, 0.1420068686767932, 0.10692726595387345, 0.07044183060286507, 0.15032315146057837, 0.19956009732859753, 0.1439531610137032, 0.11083763918929523, 0.2664198846586289, 0.18048688288657896, 0.08150029446809523, 0.08090597111731768, 0.15022190528050547, 0.2724791498434159, 0.28786415654805403, 0.12197697895669168, 0.179201218810293, 0.10555164783351845, 0.16048936804215755, 0.2967365578778329, 0.10252201524112495, 0.1325506164181617, 0.1414063783182252, 0.1532896277644942, 0.18517886498762717, 0.1740090579034821, 0.16625224913079895, 0.16936446600142988, 0.13023854774092475, 0.1150619246125702, 0.09447808437530072, 0.08106189299254649, 0.13035977349406289, 0.11769892948289072, 0.10468158645615463, 0.14156558671064917, 0.156829995854247, 0.1720506920208854, 0.149169392403095, 0.12528924436699, 0.12485080458704503, 0.1270777532350152, 0.09796998974296356, 0.21271932749978958, 0.13364647455032796, 0.14642253818531192, 0.04297144215313658, 0.12683571541621802, 0.15849804505705833, 0.1913204233372404, 0.22529766384151675, 0.18534479963202632, 0.14425083213756162, 0.10202061835556261, 0.21181224875392454, 0.19352280354547888, 0.16193209546467952, 0.1625892763296443, 0.14429788525787093, 0.16071476643123936, 0.208668714208949, 0.17202561030224447, 0.09550771420641292, 0.09848967314727845, 0.16644983852822937, 0.15004167543543925, 0.09881755111799126, 0.1261690197392337, 0.0769966933876276, 0.148619479169288, 0.16164567051154954, 0.16316488415243166, 0.1772487364829548, 0.10811612716004734, 0.15294448983284736, 0.17851078972941448, 0.19575544422672642, 0.10632804730125975, 0.15836071613575184, 0.1292570358923366, 0.17988421683830602, 0.12464261253274257, 0.1526871149338061, 0.16859637092678778, 0.19931484194051838, 0.15570622147812, 0.2030727943225253, 0.143185724774676, 0.1945603470648489, 0.10593315961981013], [0.04350981044192468, 0.030001734473532247, 0.03998990073018978, 0.06824714191738637, 0.007168977538258919, 0.07585070246169645, 0.02254364636516379, 0.045417756247784824, 0.05303089672158803, 0.03419502780983045, 0.025797447775520628, 0.05010054529374165, 0.030003285801578915, 0.06854462151926372, 0.03751126155557652, 0.021641179468602906, 0.03187874756422976, 0.04934579164030091, 0.027807313918827042, 0.0815884328837837, 0.02219724247322208, 0.04818730198988511, 0.019447097907804196, 0.021324032474489465, 0.038097563965786854, 0.02095967531204224, 0.015829224702751925, 0.06405172268709829, 0.09674766581625709, 0.03436409192340028, 0.022621431102555607, 0.04437025741583878, 0.036209823728929606, 0.019650588097471385, 0.09843161134349723, 0.013394832851425295, 0.058519135289374864, 0.09511691743447896, 0.013939106720499696, 0.0972512996785583, 0.014067825771147206, 0.03764573296892547, 0.005290014753794117, 0.03959561442776073, 0.03830026700011185, 0.022188340531541936, 0.03883328799518847, 0.01022123127064157, 0.04693703883658013, 0.09946275802869951, 0.02003376037933894, 0.0035383527997070027, 0.051676411136624315, 0.03414180768173068, 0.019016242398309614, 0.04243681237341897, 0.06730044110407753, 0.05575121748411367, 0.0223859912160063, 0.041219391409427895, 0.07515343221565408, 0.03967414993131834, 0.045670136253559784, 0.053776721620271285, 0.033343540234190804, 0.039568977550633495, 0.023474958387293646, 0.09295860260364511, 0.04510735274262486, 0.017484993516137044, 0.04216957026191297, 0.01821036386724201, 0.006562718537621081, 0.05274167937797405, 0.026389884634784637, 0.044600872863684936, 0.0663243378362348, 0.049481557742241895, 0.06413052249098979, 0.012138263836893584, 0.047748134426412084, 0.05534878000617028, 0.010539877881866791, 0.020621759674301552, 0.026564395633496107, 0.12837044999844607, 0.019102486661605297, 0.037300625680795604, 0.04746832081206864, 0.033019634429365396, 0.06465513950153705, 0.05878213327378035, 0.026492745345157963, 0.070142719233709, 0.08136927811128479, 0.07141196604577765, 0.061975199233500235, 0.015186405113537707, 0.005343905208827627, 0.07796115977990051, 0.09857110829362947, 0.04667308707270892, 0.0330514921956966, 0.08604571628834932, 0.06202486854407096, 0.06500839030430203, 0.047773867319788665, 0.011389990329682347, 0.07556271468920094, 0.11037948796705854, 0.11005472031331832, 0.042312307763964906, 0.06251996052601645, 0.0276253986803274, 0.031132091460148656, 0.02977582472076099, 0.024237709998663877, 0.02594503461413326, 0.045142148456145684, 0.0028785792059235035, 0.020774672739207748, 0.0009195589765083916, 0.034962525335891594, 0.008007791625606197, 0.06742073222994804, 0.0013530776590003723, 0.0150159323557971, 0.04156667438726272, 0.03834838115219628, 0.03772877689991747, 0.03433846245189348, 0.014280684258518441, 0.036562082447832635, 0.012673970927754718, 0.025187659024771665, 0.018016708331302773, 0.034472535499521804, 0.035910651072739594, 0.029226664168339585, 0.06305125782326346, 0.021613809062288176, 0.024214306012577107, 0.035287312141829924, 0.01821336118624576, 0.0283601708454831, 0.061386380224458637, 0.0738262078694759, 0.030368658030525814, 0.023858260904108326, 0.04368720959211069, 0.09046995065986149, 0.012780118155323211, 0.05385510007580442, 0.007378944043715995, 0.07008701698073456, 0.08176728377058622, 0.018182051172780416, 0.019842339904918786, 0.017103583236495336, 0.0645837018025979, 0.053729925139416615, 0.02390932449470124, 0.03838948559977355, 0.03674764426485185, 0.006018001773965455, 0.038708611015951445, 0.07190543392132367, 0.03589790336967957, 0.02708220212239652, 0.021370466978799914, 0.01533345664821325, 0.04117333803385977, 0.0377957712888958, 0.07373844483687032, 0.04442158530676558, 0.018031250595325427, 0.02376844092542606, 0.028752712382664605, 0.06219657566097956, 0.03966507178941562, 0.08235329506738533, 0.05571287478350344, 0.020709007512778044, 0.06060706579216546, 0.038582865344060045, 0.03201142058617646, 0.06428314252726494, 0.06365634853981676, 0.026019666899716663, 0.037639623417729334, 0.14841225238577013, 0.06860940191414087, 0.0046104856676632364, 0.04362334467230305, 0.05811313550258356, 0.029037451942361174, 0.061089567119075414, 0.03324472638327749, 0.016580463927840034, 0.02367920508878606, 0.025340491650445808, 0.02596040616833395, 0.028817653656005863, 0.0764563026267194, 0.04714118977708202, 0.04173475407784985, 0.025640633407860033, 0.020938039073840748, 0.09605368208740989, 0.017652184544732014, 0.02219911172775732, 0.022348834036458886, 0.04058825370344905, 0.07567809519147681, 0.0362113444134593, 0.07347307964077882, 0.024413502279428706, 0.06898342902141233, 0.01081148477932138, 0.08122392058853181, 0.014851187062900395, 0.05529656345325132, 0.015518012017221942, 0.01577108245973866, 0.04755960401868628, 0.09104881435632707, 0.037416136418018615, 0.055241983519085956, 0.026325941190964756, 0.01776082730371385, 0.0276040114207013, 0.025350996631107507, 0.04650874589119227, 0.035625053494567835, 0.025677336680312312, 0.011961234324131043, 0.04156747111870397, 0.01393417502948714, 0.04785629455000163, 0.10030576884145699, 0.028451429154243202, 0.034483050056282556, 0.014561638386259157, 0.05279438622716454, 0.04821988370930476, 0.05911305261355254, 0.006167154304773337, 0.0982215423737803, 0.009069930397785239, 0.01388426823165989, 0.030411405736700665, 0.09634000744910971, 0.03387397568252298, 0.050441098189161676, 0.0426115148941115, 0.026623535706030748, 0.06827459850859258, 0.04146026860501978, 0.05236592091199371, 0.02706185291190782, 0.039909771763749664, 0.061840030680140184, 0.0044012646615174756, 0.014517494484842306, 0.04400988582581763, 0.06509977693278944, 0.044740817975252874, 0.015440163119966465, 0.013474085604802016, 0.040377062414923025, 0.03549093065122443, 0.009563188556761993, 0.05436399313170583, 0.08451666607851945, 0.04314321055707913, 0.04955409094691277, 0.05687145636447015, 0.04136769454024973, 0.009972427937863095, 0.02432878061588253, 0.07522506909745355, 0.04808948405327336, 0.040499261099725, 0.03553952360826154, 0.04339504664042785, 0.03411086922090861, 0.04488716758186779, 0.013161191356278235, 0.043492447059120865, 0.0585600903498069, 0.02960956640421383, 0.02541958831340796, 0.03290418497917633, 0.020486313414068955, 0.045342974575056184, 0.062138736022696386, 0.0033280688465663023, 0.00858360629213313, 0.019356588449990077, 0.03307131855117698, 0.06847110772204977, 0.01746548125670562, 0.03359054613317694, 0.0534049621332557, 0.04291910685658936, 0.048788765280116955, 0.07527955327062838, 0.026164570515374505, 0.020938713231214115, 0.035117252113958525, 0.021835844325382384, 0.08144093031484274, 0.009935566659776435, 0.06208616706933226, 0.017211808477558436, 0.02962657355613286, 0.02285737277669532, 0.025220598890295914, 0.002687705287356831, 0.01750150654134491, 0.039228348046421044, 0.04987749113370815, 0.0501386926419312, 0.044589013822617075, 0.022490698198277145, 0.03053425176579866, 0.038807493814777945, 0.024406306798599904, 0.013796247601989779, 0.049874901756524086, 0.06337620550766587, 0.025330748927268772, 0.03507422478569131, 0.037077199968118826, 0.009217580438651627, 0.028365636882822842, 0.012796393693274549, 0.03874620295039589, 0.045881488420549905, 0.06870281867562764, 0.04805271566334752, 0.03368743710340031, 0.05810961915901112, 0.026642023322863445, 0.028953433164485523, 0.03908755640769678, 0.013991248579846035, 0.04798512755622787, 0.01757698152364502, 0.02341543718601667, 0.06568619425618841, 0.06453054296153207, 0.21948392983646164, 0.06967779579422168, 0.2336187729792249, 0.11350510371548515, 0.15822046075857457, 0.12020575303223827, 0.15347076159331108, 0.13804585702957647, 0.10869788666886669, 0.09782027317992142, 0.12796283759657415, 0.21774049758190112, 0.15870160994029817, 0.10795313429327742, 0.21935484402122038, 0.22851861923212008, 0.11051569839999562, 0.15389793221988987, 0.1489311237368853, 0.15141056730381905, 0.15783355571329594, 0.10601556003694573, 0.123465120071365, 0.1492340349021458, 0.14023449362045334, 0.10997651805800777, 0.1160230048962178, 0.2160251501106447, 0.18732504498574043, 0.15820305524093492, 0.11404306597767339, 0.14567836037566587, 0.20968532820622768, 0.09925664207267185, 0.17556798554235892, 0.07795275579537116, 0.09675049268069769, 0.17232617723845667, 0.13940028515794586, 0.22038743861259955, 0.14840552613379496, 0.1178711307265105, 0.12138105448215239, 0.17059923119602666, 0.14039079087876505, 0.30999272881496337, 0.15687252905580307, 0.1603998889726016, 0.17701552399704534, 0.19347184337675574, 0.1365083798525795, 0.1396217152115799, 0.08803746828268613, 0.10373466347734775, 0.13889434537099254, 0.1507894845018464, 0.11400373502364082, 0.08508295061126833, 0.10470147409866895, 0.11268677625564799, 0.18651722059134515, 0.10309254390097435, 0.14027759372707338, 0.11684525472622727, 0.0821819058769653, 0.12771946678478874, 0.13292601482281763, 0.1452117668645036, 0.15848433208321372, 0.11389805319448633, 0.09350059448831505, 0.2843339008189017, 0.1691984394264798, 0.10962525908384593, 0.14034908505216723, 0.12507100890000022, 0.11730041820555927, 0.193077078269374, 0.1891304997186507, 0.21971334252626668, 0.19279868191769048, 0.152414632780898, 0.0885054407521121, 0.14729952499751123, 0.06614334190324431, 0.21479185580486254, 0.10738943147683337, 0.1664523359748625, 0.1393308163049721, 0.10550536846201267, 0.1731748187974576, 0.1309211933684926, 0.09620912898812564, 0.21151944994926455, 0.2920291008007142, 0.12468312326217852, 0.16361482291212007, 0.10202853204382044, 0.12178272970261113, 0.1355299017121715, 0.15590745745406998, 0.13050131589895295, 0.1824484816602161, 0.15850616558905573, 0.2760433279458554, 0.11319565782023054, 0.13276936516406077, 0.1746709731918189, 0.18174838454973313, 0.17281140200793746, 0.2504632231448927, 0.10492281988263132, 0.1566396383268218, 0.1996594589323767, 0.21876851096749309, 0.1151106937698299, 0.06345228186898655, 0.15475823363709837, 0.06984232849771939, 0.13283903319989482, 0.2045917474935132, 0.11492790519109658, 0.11149334916544539, 0.08868420736924296, 0.11542868154544024, 0.05510237931664433, 0.12697193351003433, 0.1545852663055543, 0.14363986169618947, 0.1186997927124462, 0.3163098591950632, 0.22794063653676744, 0.1439916033057436, 0.12389243625464941, 0.06155593846473963, 0.13969870704797008, 0.07479420592707973, 0.13085776128836218, 0.07683153249203198, 0.11597660295064412, 0.08552759570339996, 0.16376134488851796, 0.0951601630978046, 0.10173280678328969, 0.1336322866019703, 0.15726786106824875, 0.1629729791273994, 0.15534268211453192, 0.0996561339425464, 0.0739761695806538, 0.10714773073672287, 0.18067129557171177, 0.1931939679648607, 0.1410853415126762, 0.1173627777625957, 0.17114785740212088, 0.1082815638472957, 0.09299249433341528, 0.07010256856559746, 0.1615270801008709, 0.13270792491253347, 0.11269161793132944, 0.11409539744378099, 0.12296030643366038, 0.1987315579167297, 0.11612180725581224, 0.1409404589644363, 0.1282170638742466, 0.13614346153072773, 0.18786993268276417, 0.06680364840694013, 0.12097030878067018, 0.08042214828873835, 0.1413519401103258, 0.12618468623728524, 0.1555173195177509], [0.024769505253061656, 0.020649055387043667, 0.027138350621586847, 0.041638805395773346, 0.048395900070787444, 0.04241497120669773, 0.05837435999344434, 0.10380040148213025, 0.02262272004548821, 0.07180825566812869, 0.014095990993683378, 0.012179938062364537, 0.012096554179856134, 0.040627167139562874, 0.030183251346311266, 0.03720088103305429, 0.01774747247597383, 0.04207918720860635, 0.048233221300066485, 0.053311802011223576, 0.010597732841908451, 0.02754875349872295, 0.06310087350767947, 0.027635103099108226, 0.09307578341254304, 0.022465997608378533, 0.032728095839340846, 0.017019198651635842, 0.08763337222438666, 0.013632730922601638, 0.024679558869871884, 0.028344121303469427, 0.021431729114884814, 0.07202040073612044, 0.012797630925272262, 0.03550473555561996, 0.027910557673162514, 0.03871745933147688, 0.026253961484819174, 0.06845115113162226, 0.009471505069203917, 0.01818711692917972, 0.0531397233416717, 0.0084498186122566, 0.030968773006010922, 0.030970174946912357, 0.03477491423367493, 0.08866350767352889, 0.0581247225824383, 0.03954179675108002, 0.0326623693258772, 0.005873998790423596, 0.07738683898482593, 0.06426381412893534, 0.06162796605138048, 0.032016572527467244, 0.035330109643719854, 0.08433632898114382, 0.051817827137006875, 0.013076748357214516, 0.062055301386863, 0.023009284181640517, 0.05507447456400241, 0.07139583223409231, 0.01645156005848079, 0.033349331858898365, 0.009927064999036733, 0.058239497875254, 0.01242328589151223, 0.025724267226553736, 0.044807555724776564, 0.08753047129439731, 0.02271936586757581, 0.04923620659317221, 0.06872633757490305, 0.020217002865167397, 0.045016571323597626, 0.06288117864319394, 0.0249443878044164, 0.10101894307280741, 0.058662558440119035, 0.05127843229040023, 0.07880957917340341, 0.051406782661234184, 0.03561592938738965, 0.06576031326286255, 0.01728465960871789, 0.012175083937754315, 0.05394995708258883, 0.008375381679093886, 0.05489326029595348, 0.017439564502227212, 0.007849359376010516, 0.011092874619569029, 0.024756439623513052, 0.008573233461638373, 0.03095281347932835, 0.08430162519817391, 0.06581692716046687, 0.08989178410340702, 0.06040391459640476, 0.046662557194189686, 0.04042770082671796, 0.016563834074223717, 0.05445258736970925, 0.05921121912016984, 0.03986577533425824, 0.0305353683389483, 0.03355222641520443, 0.058964443047560995, 0.05958704653406336, 0.055660263695303476, 0.03524208614122003, 0.023201407541731195, 0.06532620954056902, 0.06015999986219311, 0.03201997204263124, 0.07628813100558135, 0.06579887046809159, 0.03500397069259517, 0.0362736618356599, 0.020789559742796327, 0.05350009493169285, 0.014101004081537888, 0.0344168562291851, 0.016109331345726407, 0.07814567205646346, 0.019534744112001314, 0.0328126527939833, 0.02736610090059619, 0.030987907967139638, 0.038329278749804345, 0.022676244693537875, 0.03636119121144857, 0.0579655793074879, 0.0072357205546370925, 0.040722123737777435, 0.059776561364771864, 0.08896612006449893, 0.06170615298493255, 0.019373821597846768, 0.05726158663990998, 0.013180995686730791, 0.07545719373851054, 0.05438145993637943, 0.00923157686502823, 0.04513812649454321, 0.041583708352259094, 0.03860199455952933, 0.037063820242521264, 0.041773016339228045, 0.012421562193682598, 0.032222991088224996, 0.019567371796696417, 0.03867066668106183, 0.06862951938303248, 0.03938121323083197, 0.0454613849550726, 0.04923224591860368, 0.026990191132250815, 0.033442982277202035, 0.07723800342289672, 0.055412158460146, 0.043110073423914375, 0.0414076536863802, 0.02020991080620837, 0.01179158032285951, 0.04060173302047676, 0.009618525002752582, 0.01490180536488732, 0.03991317319413347, 0.038510443222138195, 0.053442791554956674, 0.05970916477963329, 0.062385657652010845, 0.05192741601457519, 0.058258316825113954, 0.028275811158481146, 0.051516379199681744, 0.038325118892375505, 0.05004425698350515, 0.07340040087940232, 0.03203871821413838, 0.03948148264880142, 0.053770481834128026, 0.03524467934884372, 0.0381139314342891, 0.02926079530058609, 0.015935972351731074, 0.06119632913220314, 0.017721871732764186, 0.07781705098046411, 0.0873266919065387, 0.06855003010000914, 0.04996701616853957, 0.03082493042212821, 0.03459535471554245, 0.04047356651074464, 0.04998525289157706, 0.05899863355162163, 0.06908938664221956, 0.07346092182542048, 0.017851436352958123, 0.02037772619646163, 0.014714769786223771, 0.016805042602842855, 0.007061078363368589, 0.010158518355550065, 0.06292635867852839, 0.06308098586516515, 0.04279683922387419, 0.04506112316683416, 0.033922698874507225, 0.014694990353628755, 0.020202541040376793, 0.03756239792452224, 0.046156517815806215, 0.029834807745271155, 0.007110790287580102, 0.07126308451857298, 0.06375959037893242, 0.02065111233312036, 0.0793530802512842, 0.03309451952396381, 0.03257233867301576, 0.033624840059107354, 0.036283965718241475, 0.037257199986807765, 0.043648874552379695, 0.010208273851012271, 0.020939182460067735, 0.04018660146562804, 0.1285356108940417, 0.006941248805472448, 0.03966631285185295, 0.1085668090250223, 0.026034032963516734, 0.03649012380910497, 0.0795131543230626, 0.0034252219625012653, 0.07575311052102236, 0.040029082297077107, 0.028107455676241268, 0.038684437111500776, 0.041857531159034664, 0.049979997528416496, 0.048458320914857814, 0.02804098031183164, 0.03739563590516487, 0.029718237891492826, 0.01968976966435871, 0.02659374254665548, 0.038435711345124635, 0.0437434442761925, 0.04761326081690289, 0.05041301340585755, 0.05741005831007516, 0.02965870902933661, 0.013428889290099184, 0.034897790906289895, 0.01857134066672335, 0.04838073919076593, 0.027431109206630822, 0.010920821805484595, 0.014947728505508314, 0.03145995410910297, 0.06110744761122812, 0.0219135390474431, 0.060423468990672025, 0.03264749189838767, 0.08383710778528645, 0.07730306727030585, 0.04410581535569603, 0.05981763133839254, 0.05033986350040763, 0.04552032775996674, 0.049377388936737855, 0.07044613601699953, 0.029884159129353303, 0.035375511844552336, 0.04955149007840984, 0.010722853194531656, 0.018058938928128734, 0.04023782593468505, 0.04793568041115519, 0.03491099826210449, 0.07641357024230304, 0.06876025994819018, 0.05207810167884154, 0.03285917731362485, 0.05757490510962183, 0.029454770678233717, 0.012105583483653684, 0.055911011933799715, 0.03191927936108362, 0.06777363063226785, 0.012704065734250172, 0.005792928493446521, 0.017511628478044466, 0.022541794347606843, 0.11452570903084933, 0.03286850060366335, 0.04543576697488466, 0.0173955891401537, 0.10561043742082774, 0.06591376833497517, 0.03176948235880944, 0.05647377629253653, 0.024160438540181326, 0.025827606741879738, 0.01712989261103494, 0.01225511618559399, 0.02213174961657534, 0.03553544035962513, 0.0655393964881378, 0.05743614360389691, 0.030705215777420712, 0.03524561397611134, 0.026657561501187664, 0.012525929224437043, 0.04448313664104189, 0.050823364572058764, 0.05957001256906699, 0.059672070802339626, 0.03195899144385851, 0.08210659177312929, 0.048319888826940334, 0.013549186161629135, 0.08022773049531445, 0.05780706039419579, 0.06536212374245928, 0.06807535436124572, 0.05087845395469377, 0.04313577567377398, 0.020752189973849925, 0.0791022170995993, 0.038840818639484145, 0.02884454908780754, 0.023156160473703377, 0.04421780591890697, 0.030968211846606388, 0.03779994263764351, 0.04190911568941609, 0.05631227346677935, 0.03427006612201372, 0.008320116096236294, 0.05912477375879403, 0.042527413761784, 0.04023315279834694, 0.07314807449978206, 0.06765606677940778, 0.0805182846623563, 0.16220630897629648, 0.11341191678037567, 0.15889998074741135, 0.09950115435546446, 0.18813666917624014, 0.1143783903230102, 0.1515882230934597, 0.19239251742199545, 0.10947487602430968, 0.12660297024394238, 0.07648141498887732, 0.07987070287908278, 0.132086627605942, 0.1822143498687975, 0.10740980941561923, 0.16608046157465828, 0.1277947732277455, 0.13913230760203255, 0.11897861041248807, 0.10467577184880934, 0.06237273757916786, 0.14434515288279903, 0.2422177268853111, 0.19416141443915907, 0.2724762999963376, 0.17049343445368353, 0.11924348531230805, 0.13406938572804775, 0.1628762988313552, 0.05861633652520757, 0.1341043806244289, 0.15841305526273866, 0.16176999125990177, 0.160442054451954, 0.21919004318694915, 0.2057435147223934, 0.12886078457438177, 0.041918205322637674, 0.1654604512957796, 0.11207435790809894, 0.08099371882816477, 0.1862529049357099, 0.19525108258089713, 0.24993253871798518, 0.38598874283413737, 0.12450828667609923, 0.17497247475529873, 0.1569591582782807, 0.14403143987780617, 0.09228189415749043, 0.254240526907867, 0.1565716250409042, 0.1380051317955217, 0.2218288023986163, 0.1526394029778819, 0.16462697827767941, 0.17449438992527225, 0.16158357142440735, 0.15769811136828316, 0.19881973463681438, 0.18090597894643584, 0.1951169712288726, 0.16345271870734232, 0.14958335567385922, 0.13563419692218304, 0.1127078972997204, 0.07619813865711612, 0.1349096003198816, 0.1474113431909392, 0.15667556785047054, 0.2622573306002925, 0.136571720002159, 0.19123279820046118, 0.149547916446482, 0.11544555080153289, 0.08695056571835473, 0.10376680852665056, 0.12385741837563054, 0.10045273514885096, 0.15101480628213576, 0.2285917346636134, 0.19143853877340594, 0.1826214796352771, 0.1295162034371207, 0.10125778630496034, 0.3127533113283496, 0.12941552416211174, 0.07362185391567408, 0.10346905313312046, 0.1099455068188329, 0.24103550000056145, 0.09578826326516368, 0.11950935612642959, 0.10027321776555431, 0.14679496416882162, 0.23888096964407354, 0.15438714064657688, 0.22610003368989115, 0.1850594778455073, 0.18274174011763067, 0.20698111444231004, 0.08784220013166628, 0.16107829047306893, 0.1178339601404244, 0.1778816017172029, 0.09929334534512413, 0.10969537911155533, 0.11098417648745161, 0.083475859024592, 0.17294111601527662, 0.2781467602377938, 0.09524380457737754, 0.23670820639498774, 0.1298594721142323, 0.19058557647851207, 0.14771880491846992, 0.2706476481210801, 0.17671624408854594, 0.13123274600553897, 0.09205616635060118, 0.1068893522625008, 0.08851025944515582, 0.1191237074653468, 0.19187913126041814, 0.16702907760777783, 0.23143211289519267, 0.10234567712271407, 0.15922406658289895, 0.24356380465530583, 0.23664638309949831, 0.13829868136634751, 0.23299333879784231, 0.11592050233194906, 0.16543074240607603, 0.10675114234008136, 0.13498418664018955, 0.09425616402539516, 0.07235515817639328, 0.15020499005913734, 0.14785328399269812, 0.09008852314324149, 0.16197626809439353, 0.10172203558707431, 0.08449667884457497, 0.21706509914609695, 0.11299907199798093, 0.1662265392200601, 0.18056002896158926, 0.20046113930161924, 0.1695878265966331, 0.11750125581578863, 0.10365346581825327, 0.12729091719994623, 0.149320587515831, 0.17402338374766613, 0.19107374302562208, 0.13351201079785824, 0.12482438987541584, 0.11560716471003911, 0.18050344570750193, 0.14247281867409908, 0.16245688101457012, 0.15791422477172268, 0.11403609457756243, 0.1080572379813079, 0.13159895135510352, 0.09695811016905694, 0.1487093259610476, 0.10964917634884197, 0.14724160875043563, 0.16593951671834917, 0.19111655201883088, 0.14247444278049853, 0.16739698367253428, 0.15987750893879324, 0.12728426755676348], [0.027607106415915395, 0.05404093002359714, 0.05081201497946055, 0.013808610345867854, 0.010814799067203798, 0.010107587872733994, 0.019059614466142752, 0.00856526518961595, 0.051469739766851555, 0.030955969761576385, 0.017615061839141192, 0.049338601905131535, 0.020570098535127698, 0.01479461817296162, 0.026998936025906476, 0.028377283334491715, 0.017811323989242796, 0.045900238422496666, 0.02397113055321238, 0.10960083620081987, 0.0176919138644852, 0.07519999503969185, 0.015523428258846606, 0.035736936805469376, 0.06286681066417406, 0.03304187013136764, 0.015116262103190586, 0.005538881767631299, 0.02676317055198935, 0.032869527161481886, 0.01766716922453094, 0.04487306773362141, 0.04821977645699536, 0.03406138377143972, 0.059450433904966044, 0.04553217914015536, 0.06044355964648628, 0.03137444337499479, 0.04542451314327698, 0.007332725001634249, 0.01583851064600411, 0.013422519269008792, 0.0698864475012787, 0.11260810668670362, 0.04603008649522259, 0.014847108602313506, 0.04240476308510669, 0.024588601250622063, 0.05572965210904518, 0.04769956828245232, 0.046884615439921624, 0.033834460867388595, 0.046193152140345306, 0.012788851557660007, 0.028001296957353913, 0.05392821167685813, 0.04788657034476919, 0.05600464319990528, 0.0684867742201013, 0.04349810078800206, 0.042168723734756636, 0.04980676206609896, 0.06225242347065961, 0.038036215644810474, 0.10318498773079726, 0.03372147438987609, 0.024990098355638406, 0.01504096715155268, 0.00982023403799582, 0.06436462363889141, 0.11101667393719959, 0.09109251967240727, 0.05805776649785619, 0.029271614377296744, 0.06199932717267544, 0.025936335685753056, 0.012761705232063129, 0.028491892003183885, 0.015604654646238253, 0.05018315638505644, 0.06390151965822424, 0.022494902105761633, 0.03363630073445459, 0.059337550849323316, 0.10345280440824647, 0.03165610134601593, 0.023530817688292554, 0.07684113923460245, 0.015696046062775196, 0.07383257406012667, 0.0179816349109094, 0.033519299956218856, 0.03665821882145059, 0.09465092147189764, 0.008992735548095118, 0.01970640143319484, 0.05875380717278008, 0.03072244126439816, 0.05160805311114077, 0.003647635960313041, 0.02760735922493041, 0.04485838948899219, 0.03922100509366682, 0.0653167560155834, 0.024301724305616754, 0.022068662276010842, 0.0340894072677099, 0.06758290538263899, 0.06304211839432679, 0.03228994717280711, 0.02962354942405176, 0.034152015803321716, 0.12513565905993024, 0.035884014195612365, 0.0465330385392712, 0.04015045743736048, 0.05150977552177445, 0.0479838979851094, 0.056315341648916085, 0.03821838369232513, 0.0404481094090208, 0.08269805761594927, 0.03170000584495645, 0.05922423878444299, 0.04327333442145779, 0.07886689787189807, 0.012840442791310771, 0.07226267604217415, 0.00960363608394419, 0.009811780257751385, 0.002330338916621141, 0.048726003526920275, 0.04954589380612297, 0.04691316370641993, 0.018964979624856385, 0.06667647015063033, 0.03392057681095696, 0.039091624334574714, 0.01740154355854517, 0.04796437806479874, 0.0253276213733179, 0.055313654874842015, 0.11655692987504507, 0.029446577367883538, 0.016429117512738994, 0.002979384167232521, 0.011697864787082278, 0.049176907557393276, 0.03493614126777938, 0.01799349203675745, 0.03659886232907734, 0.007504631301403167, 0.047386441334721544, 0.03819181193267146, 0.04804473302717652, 0.0350272597654933, 0.03938227043216748, 0.0705688173371938, 0.033829132725875226, 0.028495272366149772, 0.04987251922307957, 0.011069657367413804, 0.09874459656496203, 0.08525590262105388, 0.0338852716489665, 0.013131834867019809, 0.006423804293116254, 0.05035915359434101, 0.034179326837822314, 0.05017557211460606, 0.07654939763127797, 0.02723827721521018, 0.031357838419236006, 0.04963339253839466, 0.015813399241456104, 0.029908474760069966, 0.02823149488728133, 0.04240527636401596, 0.04353951933162828, 0.03726396454317916, 0.0290373849096678, 0.05456377737103932, 0.04676828498861963, 0.02942415971999928, 0.03407580920705392, 0.0387605939120535, 0.029756797011941675, 0.01763477328143293, 0.07137408299792199, 0.044584513056061925, 0.03632875504873453, 0.01395482301426631, 0.07328403978458337, 0.011400818982492051, 0.04998160631305749, 0.07317239013049873, 0.04695800666306769, 0.04067768680772955, 0.03231417470341248, 0.06017673888333863, 0.04878206584121912, 0.05016594238939786, 0.050790258082410986, 0.03515530753159716, 0.058492379668619365, 0.07857006944475636, 0.03404884674255887, 0.022003987218223272, 0.04276859356210597, 0.019533305781923478, 0.06193509836110377, 0.011376618264964031, 0.0279197545586935, 0.025021747363010244, 0.028758109472091162, 0.03490033048775888, 0.04627865521357425, 0.014005248836662262, 0.10531206915695822, 0.030016903014433, 0.018035956290400317, 0.02723144179570579, 0.029326173244044188, 0.023462235582091158, 0.01939456534361647, 0.03944391369699471, 0.028398615052743305, 0.02788531316083766, 0.03189909485949865, 0.009852674988759382, 0.016474297548073436, 0.021147052757442, 0.008580362867383708, 0.008229772304935802, 0.04189676635207669, 0.07339792641540689, 0.02793765037260469, 0.05721091758459807, 0.06132141213804003, 0.03429280361160636, 0.025013452546010097, 0.07043056911037815, 0.014348694671606346, 0.009664220232216102, 0.044889975294110276, 0.0500934130151666, 0.07501647867743047, 0.05332883214578033, 0.05900049131483801, 0.02803949793169816, 0.024818310799497752, 0.0016915521818220676, 0.016283756159546397, 0.01828667197015978, 0.01563073227918076, 0.0498428677899703, 0.012685197946285049, 0.021493274703501694, 0.030746406409889463, 0.009473294842117017, 0.054141502046296676, 0.06384664478020803, 0.06563268301467742, 0.0322001540072022, 0.010094267518950567, 0.01625161877112283, 0.06803405456124775, 0.04221809810147651, 0.011797284805065682, 0.1085298146391588, 0.030944503340569716, 0.047556382618964686, 0.029960741108704, 0.034296055654844934, 0.007448966395215042, 0.03261615507184498, 0.05216918187215925, 0.0311552943481553, 0.07143831180949366, 0.034581676215654424, 0.07973960225260066, 0.03325013879446253, 0.05964672095292519, 0.091064051845141, 0.056307259421314926, 0.023571625276799166, 0.052226159661527605, 0.0268101240808685, 0.09843629214071459, 0.08665252687229265, 0.09082682505850831, 0.03524154604923341, 0.034697543183762225, 0.06826884518828123, 0.019846836841034315, 0.015020428334302722, 0.0806795921356928, 0.011856769617166252, 0.033155297109436606, 0.03957862642803981, 0.012761372941425972, 0.10619504677672541, 0.07573726016186899, 0.035897190907909986, 0.034005957310118025, 0.07687787315057171, 0.08253509539269632, 0.08237320569253738, 0.05126859955189209, 0.030969816800807754, 0.053214608436270114, 0.0292430967543154, 0.02070321014241105, 0.02341616688476455, 0.0515296861469265, 0.016477882839559067, 0.0777357230864225, 0.02098552311860746, 0.11806043871347943, 0.030673810002964833, 0.03220219180108078, 0.05711307666534859, 0.032287748500464425, 0.01759358264896418, 0.018318920441332365, 0.0394609859663873, 0.033722462643298416, 0.020805346899695938, 0.001873712089652526, 0.024249919524957097, 0.038394365579851215, 0.04643037509653838, 0.027227163194648685, 0.023390807459251057, 0.06436771863410551, 0.05902460393225474, 0.03981132946547963, 0.01817332351610305, 0.020175681997751518, 0.056596645304272254, 0.035936567827218005, 0.010349858390738167, 0.030169074889272455, 0.05070930557145227, 0.022669296276064652, 0.009180044045581693, 0.015399919563694107, 0.019862455458590583, 0.05246740457932315, 0.04059001570567489, 0.03521627663905102, 0.10614263104094614, 0.1669771368465116, 0.2128872386510334, 0.12348107002194851, 0.10706202848063362, 0.15363018449035384, 0.11206197026636332, 0.1844089313019668, 0.1501289328500148, 0.16780172324469014, 0.09706558464395423, 0.12945577442165346, 0.17446406816522922, 0.14233738965084478, 0.1541521508366831, 0.106443029437815, 0.11067646195090587, 0.10926391073172131, 0.08919586983299063, 0.11447126316207071, 0.2820342274442796, 0.1681631175620902, 0.2832235329814496, 0.1952799640956425, 0.12054783427306723, 0.12609695384819664, 0.10521546546970645, 0.124586527235806, 0.13859771612671115, 0.11333862514865976, 0.1646440467166324, 0.14965781942009926, 0.10701217147852145, 0.13618113773484386, 0.14971225762799864, 0.11225403616985968, 0.08557979693456043, 0.13859270591168635, 0.1493929828246755, 0.2215989300560567, 0.11605108967952191, 0.1402761994470512, 0.0579375519807781, 0.18111351216512342, 0.1746357484690605, 0.14585341146636396, 0.08970285149952097, 0.11004006505132684, 0.10454382086473127, 0.15836826976268523, 0.12655978586765068, 0.12855563643238238, 0.11080544817471698, 0.07687224240432824, 0.13412627541730482, 0.09446484637596915, 0.11852639637166455, 0.1668041235496921, 0.1317100647476412, 0.21273567581609373, 0.14577655752580013, 0.10270163987673099, 0.1829611476991446, 0.09946882544505982, 0.19130192997474826, 0.17314575342161043, 0.11125519541242432, 0.07666585065664784, 0.06810968276113272, 0.13006941084900212, 0.14831069977052752, 0.17243756642264707, 0.12851088157584592, 0.18674710825566324, 0.14341924369575518, 0.1306214691289971, 0.09798828392259537, 0.09793102651113465, 0.12161938443539605, 0.13370370131827172, 0.1307195437050635, 0.1969974566130869, 0.09193917706368432, 0.2173644556633888, 0.1370622461000758, 0.2280855803720413, 0.20018277359345268, 0.13649685789019833, 0.15805173755413102, 0.09320298465149057, 0.1332318524439489, 0.16318288721865223, 0.16041871941378041, 0.10229069499238845, 0.21854888888136034, 0.10682932927363342, 0.09618284451144357, 0.263827228618245, 0.10627702584550267, 0.1404159798497154, 0.11719621492609864, 0.15001080209209075, 0.13230315469686063, 0.14767352912214496, 0.27635475800883386, 0.12881492655123436, 0.22352996192151503, 0.19777920337453966, 0.2036324368729707, 0.19048829863388694, 0.16302038464815388, 0.10666558564069772, 0.20387035313873522, 0.15691972007193875, 0.24044780331032894, 0.23571665879459153, 0.1205698976052865, 0.11164465919137002, 0.23247552464806268, 0.09119712131758852, 0.17266690250365965, 0.12881362420176307, 0.17292824573814872, 0.12045121526405697, 0.20761483769503333, 0.3108293887588286, 0.19319455019168316, 0.12574747985889836, 0.20916166114470652, 0.06972330907780318, 0.14785224211312112, 0.14801690505156595, 0.19955473471312754, 0.1688039654325093, 0.0886964571151522, 0.2139412837042924, 0.14864989285988195, 0.12485707884714489, 0.13125301669201545, 0.10714342532258843, 0.10184882313854272, 0.2525953684122332, 0.13630688340673525, 0.28587710833357227, 0.2469406589385002, 0.10874066501855852, 0.10007057984870288, 0.11909787498054006, 0.09349412870623412, 0.12741936716221033, 0.11350699595265812, 0.11366634224090846, 0.09936563340165924, 0.10032843738313645, 0.21300852569120549, 0.13495893638220527, 0.13784132687555206, 0.08444625493739882, 0.14713394275355726, 0.21991856215942293, 0.13252035594515263, 0.09787386103022484, 0.09717014798473927, 0.1436516441284649, 0.19324420801093503, 0.16217941929015423, 0.14492403956190233, 0.16222944483160973, 0.10600648189504301, 0.14517154724847886, 0.23362159218278625, 0.19571573022873173, 0.0698134086785778, 0.11302402348167474, 0.27981585132018216, 0.11450543834437286, 0.15686230944289317], [0.037638095072320396, 0.03276423603716878, 0.03345690592522583, 0.01674028710582324, 0.01793290788848554, 0.04170855387083946, 0.03278227740778558, 0.08443044288264168, 0.07080180765760523, 0.05572316717476614, 0.025885427227964806, 0.038147765707464955, 0.06413192443189121, 0.04889029491272184, 0.016092655526834632, 0.008981029724612111, 0.059588260783423344, 0.09337993564024087, 0.01438661602385823, 0.09936608539353456, 0.04694997423118161, 0.044878143066119765, 0.062477760572707465, 0.034656664732122616, 0.01969121565531579, 0.05558017303325957, 0.05486114205972803, 0.07862316699878824, 0.02762750159167955, 0.009142602455892391, 0.06334597184773415, 0.06854317361308683, 0.01342743180782324, 0.04624202088903516, 0.039320791876243974, 0.02963248392446868, 0.016034946123498584, 0.06144132405038803, 0.011770958193547785, 0.02310579785356118, 0.025475462936165354, 0.041047255283281694, 0.03504765685647726, 0.023845798568800095, 0.037398056743005594, 0.05225704066575535, 0.08523182447759375, 0.07558374380272243, 0.011125983982046526, 0.048413087253368674, 0.02860859592234896, 0.03315276518884686, 0.04051902616817144, 0.01854030836013056, 0.015793232934459323, 0.07920221455635564, 0.022587667692512758, 0.005232786549435508, 0.0366228370506677, 0.04785187805311815, 0.011565240603240748, 0.053577791568973375, 0.05746430116555384, 0.05483226054498265, 0.05585453210158214, 0.05829094834024868, 0.062465323135256774, 0.00629605817413258, 0.04201552530209865, 0.03226059068354868, 0.026231275706161416, 0.008467083361240165, 0.08897107665336902, 0.023005296693994634, 0.024706984817561124, 0.013414940744217847, 0.01357356116415993, 0.030593221383770148, 0.036461272937876564, 0.06415059782504555, 0.06156121681053793, 0.038705301516118555, 0.03460152555377253, 0.05814282907052867, 0.029229259291183085, 0.031231374539915594, 0.051668562565840064, 0.016269796122346195, 0.019301372662847562, 0.05251322046763474, 0.05060877568358856, 0.025781248846361716, 0.060167090005932324, 0.03771727792017403, 0.03390562660511463, 0.02678975188774207, 0.011285652027225063, 0.061765540120822776, 0.01771570855541335, 0.05469034658744932, 0.011346138499286628, 0.04770419545351498, 0.023933260911895383, 0.04171911822331529, 0.06521951647535448, 0.019853723971473596, 0.11926831422193397, 0.03884528876252232, 0.04348522668043452, 0.043470464166133635, 0.012775098364199362, 0.06114135083231715, 0.061290427711942506, 0.04898482633213844, 0.08299935999656878, 0.022446475772848053, 0.055771177904980804, 0.037506515640885606, 0.039843516649618264, 0.07130675153025696, 0.015324961690742885, 0.040137977865073955, 0.0636100921509487, 0.029893922919948256, 0.017493512413855043, 0.06366787816307719, 0.030004530694455873, 0.05146351147202715, 0.02037308753408011, 0.011434530681600014, 0.04644300405597014, 0.05879691494027934, 0.020416315960427447, 0.022168449058587995, 0.049085287272088954, 0.08315961792944901, 0.03389294018908855, 0.042114672401259025, 0.03250559326261282, 0.009272876665026191, 0.02029417473221979, 0.008067834724281586, 0.05675255951862182, 0.06564237402691957, 0.03217542468900642, 0.0313065622392441, 0.016117541893054883, 0.03469099696244925, 0.060077622427695224, 0.06977284432298715, 0.03581669421926622, 0.03380105560345035, 0.07479271971650663, 0.0704136309063723, 0.039173603403351964, 0.013988896689918495, 0.031145260511567036, 0.03173421167077557, 0.008380805581597792, 0.028079472399587115, 0.05243645845762184, 0.006127065881305645, 0.0501787475490522, 0.05686642699724725, 0.028167622306594448, 0.0300271398643212, 0.022577528518834905, 0.032129953540260756, 0.058903362857358116, 0.0483939235639428, 0.07226338850394373, 0.04278950776243883, 0.0327172058994972, 0.01640523089125993, 0.05531887576404599, 0.05143372980397075, 0.025718730326080998, 0.06850139117769657, 0.0334706457121478, 0.025740874097532323, 0.029604033334180716, 0.03727216168396896, 0.035264969187518286, 0.050153351734362306, 0.03771279630581698, 0.03413971626169739, 0.016143234566815438, 0.05227925721555949, 0.03268859251552532, 0.009292584276878306, 0.036428388613726825, 0.017710154417962316, 0.026414163876324896, 0.033524088005745606, 0.022750777387691122, 0.0631496120214222, 0.05093270830149132, 0.05779523582708451, 0.014961229847563852, 0.025655815355299462, 0.013144502130847786, 0.01942084215941929, 0.03502761599637809, 0.04599011968821288, 0.04089459694261032, 0.008146354906080712, 0.04239275465689359, 0.044430789853175806, 0.028963794503661416, 0.010094824847915481, 0.042549266419824094, 0.030235962025941383, 0.032463845301179156, 0.06402846425771713, 0.02647418686519227, 0.02096023072578734, 0.004670597235446856, 0.03119066079717971, 0.019528716915257035, 0.039399484427826065, 0.01397862823890342, 0.05999956955952991, 0.0017402716630679227, 0.053125102553636804, 0.016872753284030387, 0.047729618081282225, 0.03515010579459129, 0.05087032193137754, 0.04120601551426996, 0.038171974085872216, 0.022305693710222844, 0.017253514304156267, 0.037322915008952545, 0.024204237702032252, 0.01572789808344697, 0.07062680253218259, 0.016890181784307765, 0.07595377193102915, 0.04767762369386131, 0.045263186517742374, 0.06675989712558447, 0.010095547843394021, 0.06907602606882011, 0.044238218331649426, 0.06431157205013499, 0.05284774425109068, 0.03887721164632709, 0.048366869168896834, 0.09025338526454665, 0.028975230281151114, 0.06225253455340863, 0.041597202991045294, 0.02596128716944687, 0.03534347787799855, 0.036600735414052205, 0.049085716281326554, 0.0036606362329856044, 0.040981199352010604, 0.08344492439420954, 0.03771363134165445, 0.028197886610043146, 0.04864150785931176, 0.019592106860551625, 0.0438800186008936, 0.07706668318038987, 0.042422555477148106, 0.08600876020688204, 0.015733278893505134, 0.12152304887891778, 0.05447857690254047, 0.013040194471907473, 0.12202796210805256, 0.04411538379387029, 0.036942081210473855, 0.046619319191743294, 0.16113671233817456, 0.05264170107341582, 0.08216911986950906, 0.011479640811411364, 0.04816485944414332, 0.04739233638129888, 0.014448479538963688, 0.048349436838179834, 0.01765378758371357, 0.032927006738440644, 0.03157751030108381, 0.016158322668484142, 0.046525040581341714, 0.023198852638503718, 0.10048061308841552, 0.0894228540240757, 0.04630466006816395, 0.03916958144174949, 0.014740026747477392, 0.006592606979181931, 0.0227648044575847, 0.03331695698321827, 0.07363164451934638, 0.050045245236927466, 0.006752490486589171, 0.022591626451861475, 0.02692077399021195, 0.03409340241623502, 0.026174753739108002, 0.013254343817431121, 0.11606133993594878, 0.07150700691366388, 0.1419958982977175, 0.0823126617638815, 0.06670962643599318, 0.043262429159855655, 0.09458440205743236, 0.017078503433074203, 0.043723901373244105, 0.028880639489920392, 0.03534354299547211, 0.004489635297607992, 0.02752621710721043, 0.05825879946050625, 0.011975454831225498, 0.09181754528394631, 0.01788952815977316, 0.007772636628003732, 0.1325562701470429, 0.056251423102953745, 0.01687613173177646, 0.01950242286247592, 0.04412090345736473, 0.06927320177877141, 0.048531463159428495, 0.021286421387846914, 0.028079150642658916, 0.031916607629447695, 0.0130670630906318, 0.008054817932838155, 0.010360963792810518, 0.018831787578340982, 0.04240038872305905, 0.054235646591311505, 0.04149145987485686, 0.027283353828674844, 0.03905920349361916, 0.0036513510079408487, 0.02830157852581432, 0.03496454397757207, 0.032593467377967415, 0.0662221263853773, 0.07012439441056022, 0.015847300547325326, 0.018440090653095997, 0.06196776818063471, 0.03249839586656421, 0.13913653640737458, 0.14368673095539694, 0.1459726913561744, 0.0869931755287032, 0.12939617278114443, 0.1533802406441781, 0.131632000388157, 0.1343136911671008, 0.1314347021041378, 0.11698447588470676, 0.10087039096341019, 0.11431026212390392, 0.23861881435638477, 0.09579450688174657, 0.07689068980154491, 0.1147730251954448, 0.1650781274562882, 0.1516872322967937, 0.11070720505930724, 0.19467109273518288, 0.10991370650909602, 0.13336130598139379, 0.12834309299867, 0.13553498853598872, 0.0993687054142356, 0.20478334608337573, 0.21107174816631505, 0.14479291595278249, 0.14306855928753653, 0.10840554751696126, 0.09188016531087699, 0.20094028133298122, 0.18305916098817704, 0.09845503065134249, 0.13381516711125452, 0.19637923897995105, 0.07731291150013286, 0.16659272924786614, 0.12025843689879102, 0.07507608797881873, 0.07733395593541284, 0.17652371087141577, 0.06335942435168451, 0.1282649367086349, 0.09580179237790647, 0.12752678801095294, 0.19331815081738657, 0.12712348868409473, 0.12825213537942018, 0.0839044469138307, 0.16706362817316286, 0.16395738678834132, 0.21061407191859138, 0.13915391128149726, 0.07482238264093477, 0.17981012081426961, 0.1000154598225509, 0.09646529346824655, 0.13162288394185806, 0.18011715353256275, 0.17523095282095094, 0.13680854842307108, 0.11627739205235436, 0.13649259844133932, 0.16155819859235518, 0.15011166522820152, 0.10240332523901617, 0.13751403879254095, 0.09355962156288086, 0.16353798429331473, 0.16302734072650635, 0.151927002495335, 0.23174576461315158, 0.13289054495192346, 0.12106194821817261, 0.09623000488406229, 0.10208450242756836, 0.20838271826505664, 0.10205562857370223, 0.11829702964713497, 0.167356840665302, 0.14173752748437468, 0.12897802667031366, 0.17432012024425692, 0.17292948680058604, 0.10443908898460288, 0.09679295693434055, 0.2097914926707745, 0.15483510289942065, 0.10699534818770425, 0.1294121686970034, 0.07631405542093901, 0.18855708290732678, 0.16394969526558154, 0.08466070593004266, 0.21645823493599894, 0.16153207499413721, 0.1926938044808565, 0.10863384171839684, 0.28379242987402026, 0.11225913065455614, 0.25474494984073026, 0.07992048327240252, 0.16026396965307577, 0.14953412686384496, 0.17065975214204482, 0.1943063889179499, 0.09891855981080763, 0.1444470732202453, 0.09111550997101492, 0.10956297613560192, 0.08662072656255576, 0.1446028495387685, 0.15360471972775075, 0.2280093393018169, 0.13484762380680732, 0.16587312753883102, 0.1447156176812226, 0.11084474082435332, 0.15924612991511822, 0.12358812314848747, 0.15710702856942532, 0.2231393643324414, 0.10697962806349802, 0.15687637481718295, 0.149680464979141, 0.12473995166440165, 0.19852520447344552, 0.0844731676061788, 0.2603730607417322, 0.15030776841505883, 0.357038555967231, 0.11666578330820608, 0.2243668516917575, 0.13703269042795704, 0.1949785697844721, 0.10347087642238026, 0.1255837821912381, 0.07872268182015227, 0.1234304009666366, 0.11815182534196686, 0.16410119681348725, 0.18395454923231758, 0.11081045838974177, 0.17702744432514717, 0.12461562325517017, 0.0839387370093215, 0.26386813771340156, 0.2020266399748864, 0.1834505859522089, 0.10746920421238869, 0.18722289482191687, 0.20404889759036804, 0.20796487858939558, 0.16867210637898217, 0.11148847684624696, 0.20068702798697258, 0.1742419792759803, 0.09266112300176775, 0.1681390624012678, 0.31289604883040156, 0.162574690015566, 0.10946551442987497, 0.10328133860903402, 0.1316134610603894, 0.1557531520243614, 0.12308957611000347, 0.14857377436372543, 0.0854256600441952, 0.13056582050217738, 0.12023592923557568, 0.17147197388112548, 0.11531130921456123, 0.08281305507426301, 0.16298653888365916, 0.1026983840030528], [0.07857475790285295, 0.03308080271967957, 0.061164999966539686, 0.060129793015338724, 0.017819124679531784, 0.06366356891850311, 0.05146901964420273, 0.029607088109778783, 0.06664323725647504, 0.03200465794502488, 0.032534739077692075, 0.017922506329693624, 0.03384194937684844, 0.029376214107258186, 0.021110772748567888, 0.05370472467714741, 0.0014513748793697526, 0.014023620582696412, 0.04488672708131133, 0.05292757827367994, 0.0025147599808406085, 0.021576232449602217, 0.03143062060248227, 0.007380243041552604, 0.0303631785866474, 0.03130082615591105, 0.021657355415124088, 0.024842059525150447, 0.06262095772751397, 0.04962255239426609, 0.04121029794576668, 0.020171081639766213, 0.015206363619185023, 0.02499270113936115, 0.02683394175443438, 0.007952540885702136, 0.002274583755699437, 0.0342080666263017, 0.044853191582425955, 0.046637954280501416, 0.0896746671247867, 0.06523414875470823, 0.02049903430405163, 0.03361559337786129, 0.07042831681188076, 0.07741991866139636, 0.052482883385833234, 0.074231744173073, 0.047477333836497805, 0.02819839031285336, 0.0749045915360893, 0.03906260875444259, 0.06415430186015945, 0.03187454365674527, 0.03374074150117175, 0.05477729373641553, 0.056906681087228565, 0.05212718493215019, 0.030589578635690194, 0.04089799071211488, 0.10691746002844266, 0.07028944805384645, 0.048165158218433785, 0.061651749250989776, 0.07075888375120779, 0.049675492900273496, 0.019996135886157715, 0.053464184560242205, 0.03589964238926768, 0.07354514553181588, 0.01500406469624009, 0.05477172044676639, 0.03347026266818566, 0.029226635440042423, 0.006516404692158704, 0.0054178484940841315, 0.044057682051413485, 0.05489481545443978, 0.045849419980039524, 0.023728506677153132, 0.024644357129751195, 0.03776730346162954, 0.05444784528545795, 0.017282437953737476, 0.032407947695784034, 0.03997125798055241, 0.04618435362053495, 0.06563022387244048, 0.022653727454223463, 0.024880486495432355, 0.05956849571497691, 0.02961213088354036, 0.040817746832486124, 0.06051834131921492, 0.07259986198116695, 0.02644279832771469, 0.03631603032831223, 0.019771425060987956, 0.11468447309227721, 0.029893126188507004, 0.02715468361613251, 0.04638849690015759, 0.07049711150748116, 0.033634167179585464, 0.016333052002254034, 0.05278234715543447, 0.035668996297904564, 0.035974665379692475, 0.011850194667556114, 0.008003540316431393, 0.01814849269125731, 0.01575836827302532, 0.05823461789517634, 0.007771009648774541, 0.05227144694917145, 0.0220356343103753, 0.04920958503780346, 0.05879598031301172, 0.052787372692217754, 0.07366221908840441, 0.037773083595018235, 0.02560969877747759, 0.04049151978125015, 0.01961039912496363, 0.03459762233579832, 0.04298809307417081, 0.05410962512776737, 0.021593072977397713, 0.022038934234109138, 0.07569657323221046, 0.04245303811565523, 0.025107436212560823, 0.006267819694438649, 0.021786222895306927, 0.029735938352983327, 0.01704200125870205, 0.04878212712825306, 0.031844825190942616, 0.06614768562177498, 0.016982208096211957, 0.04369660183006237, 0.012660622803284036, 0.06377309267859786, 0.036929004089606386, 0.0275002965222924, 0.11103430928121652, 0.08551595116695089, 0.09356939684479468, 0.0382126878286081, 0.04349476830553144, 0.03641852906214134, 0.034664524794225736, 0.010363709260409158, 0.05147447419022361, 0.041556596500618805, 0.06807314802802379, 0.10632299878183873, 0.04020768420530423, 0.03272292857629157, 0.05474455879941102, 0.00965393262900292, 0.028425186812396974, 0.05673340732051481, 0.08256884156576089, 0.019625079284812656, 0.0016442681578243332, 0.04258727970262689, 0.016567457670105562, 0.02801278827621812, 0.028343705700770504, 0.020171340194440657, 0.06961912112010103, 0.027906160328477144, 0.03846429408557954, 0.006053909272586386, 0.06364559266535987, 0.06437795356877389, 0.07955079988366173, 0.1199237330846729, 0.0272566250209967, 0.00970445133955969, 0.08250988343910826, 0.07965467374531493, 0.07158049006736086, 0.025044758729035818, 0.01619315860162099, 0.01659744618190152, 0.03610980711997517, 0.014060786380732973, 0.022615583936473536, 0.03444895914365207, 0.01636865402331516, 0.06623595427241057, 0.028976923335463773, 0.022593723617554195, 0.04052235865064206, 0.021425234604506724, 0.022573464422396595, 0.04160340830323197, 0.06256300317604216, 0.10850765937638861, 0.03739422247294457, 0.05233716197131623, 0.04597694680635487, 0.06245122711745001, 0.06973854656661711, 0.057895118370652206, 0.011408087241673663, 0.0013777568223773532, 0.04106799328339197, 0.05516041430734819, 0.016155022744750305, 0.1046608561169236, 0.017246789967400894, 0.03273741912937934, 0.0781550566335359, 0.07550178005570367, 0.08626452632128231, 0.07163453757041885, 0.019953654395536553, 0.08552470755192541, 0.05749646536705475, 0.004049072496502871, 0.04246992652394599, 0.015529660384110628, 0.019404195068824678, 0.034562681065571886, 0.04491517575637949, 0.03704689736027391, 0.08111438533711819, 0.009694944188419369, 0.03999809787097958, 0.04128753876073226, 0.016601937372357618, 0.031159565288333163, 0.0358035366591667, 0.055210294292098096, 0.013754727551713588, 0.009654621150524867, 0.030571347658312133, 0.05571962401811635, 0.053545447336810256, 0.02247569053584049, 0.04784672228138774, 0.029166323252983635, 0.036487327588181344, 0.07944722479629902, 0.025955041637644175, 0.014863738455929825, 0.05520745976677826, 0.023464983922519514, 0.02839507572653313, 0.029270172216779286, 0.045282200820023016, 0.08126056257395015, 0.014107359738479701, 0.05629545400640177, 0.021153597063535166, 0.056500221647682695, 0.031223426377701185, 0.031906592945057544, 0.021806832575689883, 0.053935975977970715, 0.03311292095590503, 0.010610199965266211, 0.0184396080177037, 0.08845874769312721, 0.03604048765414665, 0.04078162195641668, 0.07077605944247016, 0.1023589993917173, 0.03732789458046037, 0.016678172696922577, 0.01960757609096266, 0.030192888732398712, 0.06864767566683792, 0.013060277466842485, 0.08082763862706001, 0.12610691299121227, 0.06671458302486329, 0.09409107973859196, 0.025412320054226348, 0.04044511783567648, 0.024285094452000434, 0.029756888942492586, 0.05636503394212454, 0.00303794656159176, 0.049342796236516974, 0.029648468349008795, 0.029698352164198315, 0.06542543324852182, 0.011894810670656304, 0.04547296054360848, 0.04996093343042078, 0.05647590984740565, 0.047142338908968434, 0.061727664733846346, 0.061859799579026244, 0.029517938458030264, 0.04920897982834328, 0.0771450233315268, 0.028813534018193043, 0.04832491436372361, 0.028997222750237393, 0.005329355762730683, 0.04033494673128571, 0.04529300649019499, 0.005834072203029909, 0.07087087814485835, 0.018205807559312354, 0.03281122787044414, 0.0523509017582382, 0.06886700663955943, 0.06861285697067938, 0.050109240391682235, 0.007905080781183056, 0.03647639168306224, 0.04546960890893975, 0.06906806641528684, 0.013907338011889689, 0.02841964991192424, 0.029729055052983667, 0.015849249283482712, 0.04389017309632994, 0.0227201511076982, 0.032240863919498465, 0.08573780256894328, 0.038920434327014995, 0.005043252087723945, 0.04941596912460462, 0.005235107317041125, 0.0339607083268704, 0.05653405975129816, 0.01122208396648808, 0.04025795489489552, 0.003917348705374846, 0.028672841970898935, 0.021061869525921442, 0.05321968759920809, 0.0300545945403076, 0.044091416733159174, 0.04119060182523343, 0.07842078955183107, 0.04784799398734205, 0.032702638737617, 0.0356538086048057, 0.01622334055061783, 0.14602475469150852, 0.02088683184176203, 0.07225829401924726, 0.009081179441343392, 0.06060271058231593, 0.1366845953969225, 0.12271645298648266, 0.2626284848778479, 0.13499193944998328, 0.07676135117728865, 0.13629283335420395, 0.20104189523525778, 0.07383505618500133, 0.1830397176766588, 0.13708783343674677, 0.24362478525407855, 0.15811216656959828, 0.15997959781558285, 0.10602846861846986, 0.10575369586266818, 0.1505634425989082, 0.13719162302872828, 0.07350881764244649, 0.18330469216790893, 0.11216780531310266, 0.0740516981891086, 0.23634937081125476, 0.11339675590035417, 0.16995027811536867, 0.21641976200044158, 0.0796454347249481, 0.1171158523028416, 0.19319756857810483, 0.1453366545179198, 0.18238394641347472, 0.15412549097691813, 0.08983821157486209, 0.06637989453250362, 0.07800771494305904, 0.12553245430031132, 0.1586242503817043, 0.18570584154898123, 0.12412916508413131, 0.12321979573537266, 0.19511370769431516, 0.2199201862658224, 0.2746808252507641, 0.10148501564418116, 0.13340607615968875, 0.13598094363847088, 0.1478760980910832, 0.12020340880318997, 0.09724612092419017, 0.13141366532973706, 0.0961777653485056, 0.1735642059676109, 0.21393124795248433, 0.17069131496452516, 0.25061176759341075, 0.1327509024450856, 0.18129280738292203, 0.19244865634508673, 0.12354418800602998, 0.13982192462971135, 0.2423909393649909, 0.15822697250593096, 0.16355566560260712, 0.16520422552862477, 0.1747925513454022, 0.23463590791629207, 0.20418769740048917, 0.07346148873048444, 0.1677088121012334, 0.12303692288696767, 0.09224095441881688, 0.30420254435270067, 0.154540863849463, 0.1670972594330388, 0.0846413315664376, 0.11919968040479768, 0.1403513526724231, 0.10915999856567192, 0.16663320933378514, 0.1970433299579928, 0.19904065907241839, 0.12017756865750398, 0.09260874557038469, 0.14101486142364242, 0.10449472228966414, 0.16775454755031294, 0.1386013933487477, 0.13965229744151716, 0.11897337037108599, 0.1946595401292847, 0.11657114846691971, 0.20081577672352716, 0.1091445695548769, 0.21473268317359112, 0.12972693890333176, 0.13579947273096732, 0.17093462448927665, 0.23326330818235877, 0.16802830140917532, 0.19831220138697855, 0.2139375605169804, 0.14812982641160488, 0.15990586951375008, 0.2554049499092564, 0.24818929032452647, 0.14228543356782006, 0.12677189263124622, 0.19989565916119084, 0.11652793344711104, 0.09920840917695915, 0.12139438441203487, 0.13164094829511258, 0.10581203345810214, 0.14221812508279277, 0.11700910561147237, 0.15058535271354262, 0.18245681669683228, 0.23764369168108512, 0.11757234111428262, 0.19754084277777903, 0.20653463840003938, 0.12563909373937115, 0.18854153132246387, 0.15617344318138016, 0.14353682287037373, 0.16570763722542795, 0.08137552938874691, 0.13813481515934392, 0.13694079052056038, 0.0825650877349319, 0.17056979809797582, 0.13213521290209987, 0.19218210371271258, 0.1403814599278473, 0.09774937174252926, 0.16228497088436158, 0.0922083114123633, 0.311156906668217, 0.1737849158985961, 0.229299676514441, 0.11532257070704816, 0.18715203168892092, 0.1708377756538891, 0.20835279487073424, 0.07333765827840374, 0.09206679199011096, 0.18763708791905837, 0.13186309847139543, 0.14052792061721125, 0.10414406086408323, 0.11622659276209532, 0.19587614904007605, 0.16114967454585338, 0.05293998123717405, 0.12445510485239568, 0.1685188581506091, 0.14978833015887968, 0.18331914058616086, 0.12264788811725956, 0.11381952918224758, 0.10328692339000203, 0.13820635244971322, 0.1544136319669985, 0.1339460302504801, 0.1944769660551702, 0.11966856451885355, 0.153612962833816, 0.20892613507326574, 0.14624828382605506, 0.24822710442446896, 0.14549246147995995, 0.14182659286645152, 0.313354445200774, 0.09889491833746435, 0.1219629135824019, 0.12765885390821965, 0.10229204330713519], [0.10113067699656372, 0.030624893373779716, 0.057788023109277414, 0.07375441777009158, 0.003277580061319074, 0.0478802194758769, 0.022074509442092913, 0.09235206781135452, 0.03383575938642025, 0.04343872897387032, 0.02368859541151793, 0.02504418990875204, 0.022973862191241597, 0.03556675037309047, 0.10004683112305018, 0.024152685730387608, 0.05510649703923733, 0.04804622689862886, 0.09187684048928561, 0.03958852045358189, 0.07007906498808054, 0.058949251524022514, 0.011005049342319611, 0.04752127280939491, 0.0659960308562844, 0.05268446410134916, 0.056583012769659685, 0.015132834500212584, 0.040909600774607355, 0.03310181651144259, 0.025627567778311433, 0.011711774070957496, 0.047743097398309946, 0.018795779530679988, 0.029505682966461586, 0.0322835196951224, 0.012462353502820819, 0.028827101435332052, 0.011475146748125555, 0.03898790369050638, 0.07157240017888046, 0.08001976060651003, 0.022694649955918713, 0.025460003281853376, 0.04733750746855813, 0.03757315762941876, 0.070162154884348, 0.09711194062425245, 0.05336449736909521, 0.05610775480407381, 0.01981153167904385, 0.015920926384898205, 0.010864542113737235, 0.01476214179063156, 0.011806041190040209, 0.02922102193077726, 0.02046511193076449, 0.054202972941340945, 0.02385901167027412, 0.07953061346685694, 0.026984614012162053, 0.04252195155488388, 0.024432880473473383, 0.04206449747265827, 0.05331966207332669, 0.06737190944653365, 0.028706145728187218, 0.051831471162938306, 0.05100305815557799, 0.02789262930051454, 0.0128111322673278, 0.030460904592708237, 0.06657219792325651, 0.02544349217186532, 0.06193974468436453, 0.05613449893351044, 0.024205245107652682, 0.04065121080906641, 0.026880830165839968, 0.07173032920447088, 0.08649557843924531, 0.05280172151903953, 0.05062599734012639, 0.022807274456886996, 0.010361705940487164, 0.028756073593432387, 0.07198879194836463, 0.04937632790496273, 0.029024585495672883, 0.04293154046360043, 0.02555422443566063, 0.08432042499583575, 0.01258749683808175, 0.03331237194699145, 0.035080334336887446, 0.030548497170750654, 0.040381291220265056, 0.01211025183194227, 0.026031774919359915, 0.02419854758397466, 0.03889348718427843, 0.01777882653949482, 0.02175976796406171, 0.055968805606807434, 0.08324042488370212, 0.020884165855785532, 0.043683294882817615, 0.016072888543168386, 0.05881015293961091, 0.020145764349088557, 0.03959470661357045, 0.08194208971314854, 0.06507174577564001, 0.036651320199692444, 0.027436236250064066, 0.027479931990045215, 0.031965012894943357, 0.02452320798540548, 0.03293912241896314, 0.03095814162084172, 0.08025710230633136, 0.0547649214164384, 0.03428184089340991, 0.007337147722982111, 0.049988891809217395, 0.024971183644787922, 0.028572511265895544, 0.12611793699644266, 0.058250035414652485, 0.013783859002644257, 0.049846793990582235, 0.01327533175372669, 0.027693804586306218, 0.023550479334869215, 0.030475548363380858, 0.01963315576675438, 0.023600458911049272, 0.011935969701998178, 0.042241130534920006, 0.04336751727086883, 0.029471592053831108, 0.020878180793877092, 0.022811089574749914, 0.034478131771808675, 0.07830062866090767, 0.019936597447902448, 0.04785164056586162, 0.04564687399373901, 0.027975979666676254, 0.042109344259745655, 0.028108733127855008, 0.04005235221777712, 0.03570787142962217, 0.04601915442054311, 0.046329600060538906, 0.027354831747230024, 0.024007711251596772, 0.027232079563902754, 0.050127726093295126, 0.10321602195260987, 0.05384311846066868, 0.03528650391906981, 0.05010738645890548, 0.028260669430657744, 0.045886632700961445, 0.0249896138050263, 0.021406321808876052, 0.014685999354227416, 0.04775565740982852, 0.04038660020958032, 0.07339280128719346, 0.06186014814903179, 0.03092290732198425, 0.04934358530707898, 0.032155046750220566, 0.02533371751797536, 0.034472397603695436, 0.01588936068958813, 0.02120337937207472, 0.024017273944111604, 0.011486069246705984, 0.02315327615266846, 0.046145286966836264, 0.07785882575497513, 0.07585938989875779, 0.05983964870533636, 0.024442751516377734, 0.022441438744745912, 0.02528116580158953, 0.040681773886805585, 0.1446336462733246, 0.00856721584099315, 0.051822186177296024, 0.0657710078502855, 0.04254925109806561, 0.049442502579862074, 0.0733540065947079, 0.08578226631206852, 0.029408690489588246, 0.024713701493437254, 0.054299009723528746, 0.035289342274829265, 0.00990991707846162, 0.0034609580489491387, 0.02974665975348363, 0.013857503992415244, 0.04319172307488419, 0.04575737451593723, 0.0919290800248423, 0.02337259754929091, 0.03160531737751538, 0.016553834711592046, 0.02073606382304382, 0.05379017412422165, 0.032571595567729206, 0.04534262600505064, 0.08761480225310211, 0.028734902753644896, 0.039098170555887685, 0.01647957780909154, 0.05188214021825022, 0.06511044853757467, 0.029138297841493643, 0.05058793809204813, 0.09985678769167393, 0.0670713501712007, 0.07536409873395197, 0.04328464187922017, 0.007778106016978141, 0.008064786651952854, 0.028315052097182603, 0.03787878457637083, 0.015326545577526334, 0.014468380588016685, 0.02624018913916042, 0.04160512817062197, 0.04650911744383555, 0.03791624627586815, 0.010786083218972049, 0.03283393471651981, 0.09486419268913808, 0.010411339819491392, 0.030492798748215845, 0.012879202052229836, 0.040522458242072214, 0.022134254724087737, 0.0485654698023873, 0.03845234694440038, 0.018539754861605265, 0.03452886211415453, 0.013106920730112302, 0.026956592431111683, 0.03189086132953244, 0.04474018595271534, 0.03536483257888787, 0.05210562338752132, 0.035490792755398064, 0.029736853828052842, 0.025117071683428464, 0.0312786957909984, 0.01760279294103384, 0.03034991377423848, 0.04587309592733941, 0.0641422857710671, 0.01835449564931614, 0.08149601969747775, 0.05925143873619457, 0.032709851455424106, 0.014977030411002137, 0.05378141007836788, 0.06495618141226231, 0.10171198451350774, 0.08714248606514546, 0.09036514983181992, 0.019934396860339952, 0.04430271144355497, 0.06247898631338632, 0.06200752431346525, 0.0263157656281105, 0.06554117381212211, 0.01290136497587927, 0.04677634423358306, 0.010379230201755081, 0.0015705090927733711, 0.05724591631141882, 0.007157066786256169, 0.0265565374866128, 0.059046705568870234, 0.021310625935814554, 0.0344515408599569, 0.02974340579502525, 0.07343472927928933, 0.042152547788235455, 0.02119383966219762, 0.012447018337796533, 0.018609126038368673, 0.04128271623724892, 0.05556742916063917, 0.028000618969540925, 0.03435283426135298, 0.04933664838092462, 0.018002863207291213, 0.05113685541155358, 0.10409699242201545, 0.061553341426676324, 0.0342861884423802, 0.005985232363004358, 0.018814389721580574, 0.07356271192791962, 0.023592878471038515, 0.018656893535667372, 0.030163905711003372, 0.06541777236927902, 0.04274672941274701, 0.016294084939985506, 0.025993236866328987, 0.06997558949214798, 0.014199805483522435, 0.051999255909674594, 0.017778941452683463, 0.0761114404867253, 0.05374464551888166, 0.010594852351313157, 0.024288677828266256, 0.003022887427622693, 0.04661430514627888, 0.02812991354374155, 0.04195120455997606, 0.03297171179926203, 0.03791654888059824, 0.05762740894551239, 0.039402943314804185, 0.041240405201190905, 0.05038391355605376, 0.03244340607535935, 0.03040579605787512, 0.028648645083810535, 0.01972607074065074, 0.012508879937682182, 0.03956806207556398, 0.06056233774870635, 0.015707111245231525, 0.019936394434602513, 0.009352271144668902, 0.07034264519930848, 0.0225163544828613, 0.10039595271190328, 0.0145140394283038, 0.0024526623301132913, 0.029542164073415825, 0.02966639863687658, 0.049633155051138134, 0.20400694661563445, 0.07991695160707159, 0.130277679512097, 0.19860210437928477, 0.16092635991592563, 0.1642383725172089, 0.11392812980639358, 0.1182374203457467, 0.13178739366271805, 0.2006490759912037, 0.12950998280317555, 0.13028543232189072, 0.10132226792554702, 0.1921431098373667, 0.18943181742102871, 0.10519745474260662, 0.10137116731775385, 0.15540827456260883, 0.16682623284718684, 0.1509030646975002, 0.13806684783870174, 0.12956883367751876, 0.10404446177304753, 0.0965903343392476, 0.18392764422441685, 0.1449498567249506, 0.10208575115088495, 0.09360777784980114, 0.09862773751299228, 0.12046830668564766, 0.10565441086768143, 0.14804105214293928, 0.20890189605134152, 0.09683382772510091, 0.11028603290117557, 0.08069580255617058, 0.0507091140494712, 0.11506973870939786, 0.09797343713862282, 0.11848442241429322, 0.23380951355061225, 0.1329861833683906, 0.10084250536296638, 0.1303583792140407, 0.15401183417247188, 0.18053425776381649, 0.09384537235863748, 0.1893730584772364, 0.1437000762070379, 0.11280283857617648, 0.13807411035222394, 0.17378707626654258, 0.0980087997572076, 0.12497969888030522, 0.097043743477233, 0.11545105131282923, 0.07881664250406527, 0.1951035493684392, 0.08242173736254055, 0.1689157989476958, 0.10726836660215933, 0.1594402719168894, 0.1694675048272456, 0.11147303251369346, 0.17944339452491653, 0.1236662870994018, 0.1562257669866085, 0.0995309781583567, 0.14738895810179173, 0.16101939363345025, 0.1974839071232465, 0.15033635881639298, 0.11816276507752559, 0.08461972022609365, 0.13169196975086966, 0.16892641692632632, 0.16894777545765524, 0.11676220313435602, 0.10294753877866654, 0.1912373487627314, 0.20526999577639565, 0.10329160418721939, 0.13203274098134812, 0.1571967987523925, 0.09159195537288344, 0.08072071573546818, 0.17419624382690077, 0.14935997975689752, 0.07610256918856213, 0.21575678951076924, 0.13326733763660156, 0.17041215252491737, 0.10898235043691051, 0.16440832146233128, 0.2502750719506895, 0.2279965456334814, 0.29036770124108563, 0.15675030738836335, 0.13529273621257276, 0.13080255699253854, 0.32512391526852885, 0.17511162696586502, 0.12510264067039376, 0.12593389969439278, 0.17575480374357394, 0.0986169126906222, 0.1013183991815294, 0.10713207189955058, 0.16258634987377352, 0.07019426929013384, 0.12023093434230936, 0.16720708579786364, 0.16252585957127233, 0.15008990833115193, 0.1327458156212684, 0.13201867560705832, 0.16926493585830735, 0.18983707793297308, 0.08072680613446621, 0.12890705628500831, 0.23699335964216342, 0.14607625112177866, 0.1196962432755578, 0.11682031090341269, 0.1712463150221494, 0.13513101505175715, 0.15186700248910537, 0.33803007595481416, 0.1413040749368168, 0.10191606267565682, 0.16197893408037004, 0.10772595858021129, 0.17261065632825898, 0.09294810719908246, 0.09715919292742208, 0.11405644953371057, 0.14009158757905807, 0.06159111339178297, 0.13096187263727188, 0.11071136491673608, 0.12292854442831971, 0.11723681758608549, 0.1498659348656093, 0.17914494199137534, 0.20580480175633586, 0.16650544118977365, 0.09336477476021937, 0.13695099481171177, 0.1363535688048409, 0.12639192068168234, 0.22218820488741323, 0.09808546217579035, 0.18590758314296124, 0.15086298297730186, 0.14572988744945298, 0.15950741186257333, 0.14989155284579725, 0.10441531727631247, 0.24490416740938542, 0.17721599388507106, 0.09609859016153122, 0.1449893255748095, 0.17800621357896637, 0.15564695691629765, 0.17252903732080616, 0.0908638347661303, 0.1271274570195425, 0.1063715840779966, 0.15615923991126401, 0.181187424328058, 0.2292851974526721, 0.13463622950498136, 0.10830565731251433, 0.19495046967940946, 0.13288806282704876, 0.12693979612161077], [0.042093011265199994, 0.017264076741412282, 0.06424169334012174, 0.042035190779114925, 0.014082929194574396, 0.05037144164464647, 0.047827895670648546, 0.016874172461910114, 0.06952319159022263, 0.022203602918213414, 0.02310945783861943, 0.010756706619905609, 0.032646438527491786, 0.0044795013907846185, 0.059341159123446674, 0.06552307115447137, 0.019806743629517096, 0.045834262930457635, 0.04670080030336977, 0.038119841802624926, 0.008816830269361456, 0.0386839046803934, 0.09930940254801705, 0.02829917875539151, 0.1049579679965973, 0.04036108948170178, 0.08727680426090957, 0.04589727749266932, 0.037980429122164365, 0.010859610422724679, 0.012644303215277052, 0.01682411627693763, 0.03055307646131804, 0.05906163279207484, 0.042262868279771465, 0.04831285613979544, 0.09455085506722813, 0.06381679799467807, 0.022456896483838078, 0.08124640526910944, 0.016072336959862904, 0.018021548091764414, 0.024267522310237252, 0.07213716785753928, 0.03557281012857153, 0.012709489636754077, 0.03086352210131384, 0.07798191310176927, 0.015453423144325856, 0.06688774187838839, 0.026654581419162215, 0.06541018809882865, 0.030962445119756366, 0.027094168415773782, 0.07197321738086401, 0.04735744873722715, 0.08335881611152042, 0.0355568946519446, 0.04667490653152909, 0.012504911602234409, 0.04232420127898936, 0.01940174358746698, 0.045058273319755836, 0.02459271322755564, 0.04343680992362, 0.026084816932017287, 0.07082548743534474, 0.07009116917728417, 0.1505271300312973, 0.024681717322598544, 0.034566764314208305, 0.016787035706182642, 0.04149836998793387, 0.07136875102596899, 0.045455091542774634, 0.012815535357672603, 0.047344586120978485, 0.005686579688992953, 0.042081393541828285, 0.039791771240772746, 0.14055058149801147, 0.03188656357627723, 0.04026764973757729, 0.025260862556376287, 0.031208784522248373, 0.04670754187710343, 0.027014604439177824, 0.05967009812593461, 0.03500885450311246, 0.06642359218770458, 0.03613414956376918, 0.041172250189007296, 0.04643412126648811, 0.05217618391578717, 0.021237774804655104, 0.07954630294754621, 0.0780845229183474, 0.020794807445077647, 0.03263416579894481, 0.03267987060450739, 0.10832624209503974, 0.034072384794032386, 0.05990300034623473, 0.01165509026783008, 0.028942466615849448, 0.01939187829022206, 0.03699419817196266, 0.04276211628870618, 0.03610236074535116, 0.04681412385956896, 0.02759430125626105, 0.05430852836598793, 0.101216348609136, 0.06812987683881676, 0.05229347963787375, 0.04549420033130915, 0.01472491949361058, 0.055555727167595784, 0.07571263043510337, 0.054828598644704594, 0.009752334707656936, 0.04125826271070589, 0.06686201664589106, 0.0038007565871662195, 0.036711055905588215, 0.05368745705533413, 0.037206235987645005, 0.04179665398213171, 0.023328315752047687, 0.053071319350912693, 0.05682046555223004, 0.07604099104120847, 0.05965217549894607, 0.03063925560714016, 0.049559859588982604, 0.01130299051217134, 0.033698376838959036, 0.02090786095528353, 0.08659056568097684, 0.02475611212092542, 0.08291780993702912, 0.047265104498834386, 0.05023109050647867, 0.020239290278104526, 0.07910603221746222, 0.04281043345409055, 0.009746442533909314, 0.043570633992672934, 0.01780996035273758, 0.046722158834698706, 0.04596185870468617, 0.024086382735760945, 0.0034450464027618332, 0.049845158392863895, 0.013769078293755172, 0.044330141221683834, 0.0324371854414142, 0.04221418722262306, 0.018559318831971577, 0.019477247298064253, 0.1210786106305257, 0.01851346655448358, 0.012633734074751697, 0.06307817815292267, 0.03397210005430445, 0.041710304381746444, 0.03339211786946943, 0.05938636214141885, 0.015822722531494596, 0.03358843556094555, 0.021206451384651086, 0.020387767693929134, 0.010618659491170078, 0.019983462876670306, 0.11022794811475663, 0.04590692637007564, 0.06042723048238024, 0.05314899683599511, 0.03444991675355742, 0.014705347862365025, 0.030173636942861543, 0.033959616651578296, 0.04402257607228333, 0.09474089849860438, 0.02055475187878455, 0.03493995638564229, 0.04236887569629377, 0.024646596021709904, 0.03930432864675119, 0.04847890186694361, 0.041532912892439676, 0.08352194687411671, 0.013142292924796142, 0.0397070380859077, 0.030667240799014128, 0.042010622339383255, 0.054275686176674026, 0.06959605421270094, 0.03546874091449765, 0.037107180819035544, 0.01278847617457711, 0.01847512002343372, 0.031775988360506394, 0.027121647989617723, 0.04702099824264165, 0.004642933321696136, 0.03671118614053534, 0.025916974728686676, 0.06500544086579355, 0.053173791271664446, 0.028776652630298372, 0.0165961534085293, 0.021194672782815272, 0.01668424011328288, 0.0497653550137916, 0.04334974786146514, 0.025870128452116926, 0.02792775634706261, 0.016103131779199167, 0.015666454001480055, 0.030384148328354767, 0.02221053218348853, 0.02465928243773599, 0.053838008654213725, 0.006056256374464401, 0.09968627184148758, 0.07276199682946168, 0.04216992649279776, 0.05292691560762544, 0.06728185581103449, 0.08112978370439622, 0.031088931981714505, 0.030097020489554253, 0.060525117366905176, 0.034394850353560144, 0.04011243649367844, 0.06113015445730379, 0.031267558787799174, 0.0693318458093751, 0.008369756678509857, 0.055700219010994326, 0.039356836313081366, 0.07568551858346309, 0.056763319223518335, 0.035607299406922636, 0.030602136731988965, 0.015311374163795865, 0.02748158290952204, 0.03257625338230883, 0.03398695832959587, 0.02242426305348354, 0.038627792570379474, 0.05345016515122787, 0.017929429849309307, 0.026967928617171226, 0.040974664622016495, 0.04680303856730462, 0.07344623591991202, 0.060761459321985324, 0.041906036015960484, 0.020088482039770292, 0.04313002235346264, 0.04087911047522099, 0.07133658299402845, 0.08133958454333967, 0.031166687990809162, 0.0873613573851124, 0.066895081000703, 0.024404757385773045, 0.025527271547264634, 0.06811478490670843, 0.0339264182313796, 0.04928735828387642, 0.05668783274989936, 0.025907770182276448, 0.011519307886520702, 0.025849595380526398, 0.03477757255877218, 0.06426877837868468, 0.03374409696628009, 0.04263629783846198, 0.029462075326591734, 0.03171192234261863, 0.026323698468566425, 0.08604226889269007, 0.06113328392647448, 0.02937974577258912, 0.0040286892908625305, 0.03183841111979658, 0.0686134315366226, 0.0917784211736533, 0.06576841847310144, 0.04302645109653954, 0.08404385959429127, 0.06685529805479512, 0.048650559188137134, 0.020705320714642445, 0.05926935370230387, 0.01401811528335055, 0.044905473252818476, 0.011135429846152905, 0.043789444025605924, 0.033648715189267556, 0.055914834712541876, 0.025141270485736673, 0.03435144381177041, 0.05971515558720116, 0.02700880898403064, 0.037550408648507255, 0.005386676855250112, 0.03483153196171888, 0.033869988194877104, 0.10925597406082577, 0.0395400922054485, 0.0331610236166706, 0.01228241285594601, 0.017653936970858805, 0.033759778786090114, 0.03663201095356095, 0.015337450839128467, 0.08616864275667938, 0.03036933410311899, 0.018355744372632717, 0.042135939002037055, 0.010341361518047992, 0.02894432820950545, 0.12415872075625005, 0.06800033903170018, 0.05893632379030028, 0.05508242655665644, 0.03198934959307794, 0.036515324271374175, 0.019548409205350666, 0.05482593648916772, 0.051868867744962056, 0.03552832723324818, 0.10014900426951148, 0.02504058163462868, 0.05764780220605674, 0.029111718420960733, 0.03783608666591106, 0.012899522534421375, 0.11493094656015597, 0.0327609648417321, 0.03623123971685287, 0.029197646672987652, 0.024214459230161967, 0.022871357711753058, 0.011538786629605438, 0.008457943932303499, 0.11518435312374947, 0.023053228900197054, 0.17777336881526057, 0.10985063449029, 0.12110671073558832, 0.1840620466898526, 0.0875769651705219, 0.1080418472749091, 0.06484831623252361, 0.1662882859067571, 0.17239886366071241, 0.18050177563582698, 0.12980157118891517, 0.2038583408800825, 0.12007879694142651, 0.18552958003936276, 0.2397487327576645, 0.186801117454325, 0.11685208823051184, 0.09591400127617583, 0.1473253115170425, 0.25284137456647815, 0.15166501574698957, 0.1329273324940474, 0.16278822936357992, 0.11893783921315787, 0.2001171811453758, 0.08890637286728428, 0.16389102825234014, 0.1478488560044958, 0.21453627355156407, 0.1144727263900061, 0.11281092080377764, 0.1709215703510469, 0.2882441668020141, 0.16764498165538236, 0.11895464718221657, 0.13892992249419614, 0.21014478177793566, 0.1072224396310987, 0.23004725575447085, 0.19941513817156517, 0.18073255196213725, 0.13642984051858226, 0.1327327001960047, 0.15235424973070621, 0.12917920135922972, 0.11412526721194868, 0.1556670284199138, 0.24157874826942724, 0.07832708167693309, 0.2991719207456035, 0.311969266303124, 0.18623834926514857, 0.18852513704088428, 0.2740979855579715, 0.17454616214719512, 0.23084928852415856, 0.18130293506528103, 0.15804611446876682, 0.11499470039721459, 0.13156634665304615, 0.17246672372904517, 0.14356264003342198, 0.20776067019229938, 0.08153135167254556, 0.18772449855121875, 0.10899860682266374, 0.2792081597351259, 0.1409935641793474, 0.2076366099138414, 0.0901021441865352, 0.09700795951028986, 0.13831467728220648, 0.16025148241991, 0.19529779862251975, 0.12027392719661999, 0.19985154781851078, 0.1630561456324593, 0.14246626096146722, 0.2353132675371824, 0.10106160650931059, 0.2555215638130903, 0.15328008230895768, 0.1586716405807003, 0.24177400875956784, 0.14053345177202456, 0.1482512207040864, 0.11830233863645023, 0.18545151567987858, 0.2799720413261845, 0.20376386691726026, 0.1972962155817978, 0.20077269193866562, 0.12057794152849144, 0.148527380079031, 0.0835548580113438, 0.17967023315929598, 0.123246310038432, 0.14207973896015075, 0.09338670785749152, 0.14876995415937516, 0.30097219672414566, 0.12489008191492289, 0.14581872300515253, 0.0918686050440996, 0.1353535023067267, 0.1736472498986029, 0.14799761495763256, 0.08892157205170201, 0.0867016101256013, 0.17532890482294947, 0.09051140367744431, 0.13135455398549958, 0.23160952353669753, 0.15956252422784606, 0.22668127991980125, 0.141822885000898, 0.12634140484395529, 0.12872486525485594, 0.15107987779042414, 0.1513705775141716, 0.08452341531313236, 0.17135807192854344, 0.18457000894892603, 0.13233195960281358, 0.07796482934105782, 0.11871296176386457, 0.10829864760800716, 0.16478966470927964, 0.16483540015835918, 0.14553720101473794, 0.19215113843881315, 0.18102622410703093, 0.17778328199300075, 0.14380893730107816, 0.1358938241197217, 0.11472820905187439, 0.15220293204390234, 0.13408959512749027, 0.12336591934604992, 0.16227360213956527, 0.10022341438959684, 0.06464248372902794, 0.12401822023093702, 0.09433040560613717, 0.23856796143997103, 0.26400529809536477, 0.13056977351586666, 0.16961471628277533, 0.08586968460510816, 0.11356832129099678, 0.185534099958116, 0.12075020405914515, 0.16431819887891894, 0.12615496202582313, 0.1262177735747349, 0.1258630672049138, 0.12234138399963418, 0.11935225447579739, 0.09220182264764464, 0.14251677679919428, 0.30058624162789316, 0.10932079276009914, 0.12412787805641852, 0.11438307878110679, 0.1824047227179812, 0.1333635276363742, 0.12225737479785759, 0.12267991059249449, 0.10890793265594591, 0.14864719623038847, 0.13661514186570722, 0.12793649183285813, 0.08027745726247949, 0.10982037401728093, 0.2228230313067475, 0.1228818130649386], [0.015855404799954308, 0.02966618413225778, 0.019956069487717845, 0.06469609456196909, 0.03294152410460576, 0.01644893429212032, 0.04547845722446519, 0.03319990640926746, 0.028513110723466645, 0.048083217454052744, 0.03510462315452676, 0.05548001852847877, 0.014297267189249398, 0.04408803445497348, 0.014014509882056906, 0.014175348126539781, 0.0543614267371595, 0.010718738344768363, 0.05716346226812852, 0.03463390425989225, 0.05310937476855132, 0.07388361083764224, 0.0829911475340205, 0.019018975416979483, 0.03542772456703167, 0.010106768158655013, 0.0388551636358663, 0.02121280225354337, 0.04836911380651498, 0.043617870974084066, 0.048202581613534884, 0.057835175821016875, 0.024789302880244873, 0.02891283625015809, 0.035472046583890915, 0.05962148984713901, 0.014866345070092189, 0.09079251964125903, 0.036961827126722184, 0.004811387916561216, 0.034853346315362764, 0.03600306042860593, 0.04671665449296275, 0.04005561192189494, 0.00266320196509872, 0.06258373351527319, 0.029914400450164275, 0.07307236969110466, 0.007666315115432466, 0.03434538788672897, 0.10303188505912982, 0.06286045979528178, 0.017795427664813977, 0.0326771165184196, 0.025066630539274024, 0.0387271082088832, 0.04959477787657131, 0.0027424958957013705, 0.0583885096374058, 0.03123613960680462, 0.015321047939059716, 0.01197813805418029, 0.016844973020676165, 0.022783255685240995, 0.06856890650646341, 0.03549822380826358, 0.027941609131953413, 0.033642429437848835, 0.04455049109134463, 0.05347876321344126, 0.02931786885094499, 0.040947085456742395, 0.03105097998594565, 0.09079375304281713, 0.01580545778251103, 0.0337823439058998, 0.044711859851715066, 0.07110786744423452, 0.05446512822902972, 0.01135014418152071, 0.02429777512236709, 0.10074280668050052, 0.02700618704810979, 0.04319665668111655, 0.05400906076594707, 0.01778576346564918, 0.07959456648677588, 0.0261814646693247, 0.034464759707090356, 0.022128932328233798, 0.012743635133149163, 0.04449280467064631, 0.06773049222125162, 0.06283359309177726, 0.06109188836548598, 0.03483540070573649, 0.011175433999948926, 0.0327492973226453, 0.032745627761488004, 0.0564098960509704, 0.04374276628837951, 0.05483014997275126, 0.03724090529665832, 0.08198842271080903, 0.03961218874000254, 0.03903109572767731, 0.030235693895167885, 0.06641908759070982, 0.02413766274619247, 0.019704457485086976, 0.054365035011282856, 0.011860801154867777, 0.037695777662579096, 0.01963719688055496, 0.029323133790204604, 0.04154013710156564, 0.022871191087629528, 0.036253126848849564, 0.06717392168338261, 0.05248351923881039, 0.05974736575397754, 0.058834587313955834, 0.08519480710909252, 0.04434385036508884, 0.01782925236189077, 0.06874811745459034, 0.053845363098286816, 0.036384212153573195, 0.042343127481158704, 0.02816094393511453, 0.04188149821974578, 0.019637610568034074, 0.014441293634233937, 0.018400840138295488, 0.04691078883385466, 0.05373524178961112, 0.007200510196027256, 0.03520623705680332, 0.017560648529099363, 0.07176796710419078, 0.0417145561697262, 0.0621371463902535, 0.029713256404765194, 0.028348154756390763, 0.03758774011305744, 0.03816285380913365, 0.09610988995841435, 0.02614693900179719, 0.02275666860382884, 0.0498658312755006, 0.05657318003115155, 0.03199717709644428, 0.03952542545213815, 0.02153106199036683, 0.008067693955625498, 0.05710991272222131, 0.04729830291903308, 0.02393963859386502, 0.014777276815185625, 0.015551953542707189, 0.011249650682833408, 0.014116981802808662, 0.008442285095131206, 0.0326949242322195, 0.04223855647949442, 0.014823975619829953, 0.07335501783076795, 0.01220794240643661, 0.056530014807057966, 0.06702446559023473, 0.024794035388397116, 0.04705690478365268, 0.04029573835132103, 0.07325450709510235, 0.008846698122309342, 0.005920019128449983, 0.052691209505522446, 0.050733571406453855, 0.004921220027045497, 0.028270341290701783, 0.050295438061678605, 0.010285755983673999, 0.055606062974660635, 0.0646122309168981, 0.03287648707027397, 0.0314488994603556, 0.04019953302978989, 0.02853060434121759, 0.0210816920509622, 0.06368105870581443, 0.05485514359128091, 0.01951725049425037, 0.020982510477845228, 0.005664903709980389, 0.017516079448884534, 0.041452630708414706, 0.05300530172403782, 0.01942883437168935, 0.03814970007947376, 0.04463058941426777, 0.014450625542761579, 0.02261141258772583, 0.0400863703520548, 0.001274892042161927, 0.09856439736341277, 0.03673546729729541, 0.03408960262013059, 0.05732411090585013, 0.07213174395503537, 0.07170762235839521, 0.022679240097321814, 0.0514718771521603, 0.034941105517528714, 0.027184576366937933, 0.02939392031440812, 0.06344786154166346, 0.03247851971536875, 0.017996035448666063, 0.0968789273212033, 0.03238107333140027, 0.028840308791146647, 0.037845551682215546, 0.0563297517627718, 0.07475544187811113, 0.030228209216147665, 0.039794306991802114, 0.17271220894350162, 0.03419128930075996, 0.026411465331611615, 0.05424614582631377, 0.031482628396441864, 0.07687919848268071, 0.1662092715982468, 0.07750303920118079, 0.022801877367460442, 0.028003070450898622, 0.059835412239115086, 0.0350442630869727, 0.034697853449371555, 0.06540918452364784, 0.061889447181695895, 0.007446979354661439, 0.04169057761769622, 0.03680929519055832, 0.054013982880860574, 0.10592645635047268, 0.10651513363324827, 0.014990140090606388, 0.015180018813078924, 0.1066099753182742, 0.07699727561445006, 0.07905114201768752, 0.07291234924548096, 0.008502104113088741, 0.017311442042550734, 0.043070409221634756, 0.05413606282203429, 0.07065327086996648, 0.02712562590116455, 0.04266674983345213, 0.05869058576682883, 0.04659284319308016, 0.029826338643268235, 0.06492939897842946, 0.04105052647871837, 0.03643956200610246, 0.12499262278358783, 0.02829079009262064, 0.09279402393487193, 0.02915666671469808, 0.020394901887724, 0.037652834603983554, 0.024890962747796893, 0.04172491367846247, 0.050039637473321734, 0.044805475796062144, 0.023689945641484474, 0.06857937892838832, 0.016916399228296453, 0.028354576488416043, 0.09813601631791362, 0.036686181030686826, 0.026894895540129755, 0.06377768537570393, 0.04014738925522374, 0.048329717735008854, 0.04184764479437182, 0.03484994488497896, 0.08425049649010743, 0.039819725789129734, 0.029222042742936365, 0.03084205440245569, 0.006311016519659109, 0.02368108200420055, 0.02662362572136185, 0.04581197743274031, 0.06012706574232829, 0.0548204742822676, 0.04099567841377951, 0.02886574865589219, 0.009861668860990434, 0.024698628713527036, 0.017818255169737725, 0.07863484983963352, 0.04425987180682921, 0.06824472874042488, 0.052614152551658695, 0.049539029658321417, 0.037704365508210276, 0.0348263455464715, 0.02779930063913907, 0.006332745167216467, 0.03668055411488299, 0.02511824571317242, 0.014805846149101855, 0.021940834760185213, 0.0642430646375062, 0.05369080102912361, 0.04615420039983527, 0.044766945403910456, 0.020711309606990507, 0.046966249769132946, 0.03406836666286953, 0.053201102306165045, 0.07634252324820527, 0.027318444486046513, 0.03725120151836065, 0.00924401717530864, 0.029193641948363477, 0.04680535981371518, 0.02528840724769379, 0.030696991823553562, 0.03872916132452027, 0.010415313900598596, 0.06202217574501711, 0.031410688909912304, 0.004875473565452042, 0.03658556304271183, 0.010402836243531877, 0.014243890013125156, 0.016884602748999195, 0.022191280393951365, 0.03605500118987214, 0.026555539657091422, 0.034236810245220704, 0.04345253387826585, 0.0323827242508771, 0.01787477713679114, 0.0521325015823447, 0.03804190767808788, 0.018002114356345227, 0.029748990575993256, 0.17949101455028982, 0.14978373363133402, 0.10855150258829517, 0.18377474839648894, 0.12933776623779727, 0.08792761127434431, 0.1519774723677866, 0.16258506284606072, 0.13229878799569222, 0.12128152433902988, 0.15501907125355738, 0.18151033038814224, 0.12027964987341436, 0.2607915898965251, 0.15555986804106545, 0.17018188181663715, 0.14605124601193015, 0.07972751338515552, 0.172743174217401, 0.12563841958199778, 0.13351035604794181, 0.11757376603782178, 0.1557683665305376, 0.12437988267911058, 0.09854745149852769, 0.15090139462582527, 0.10266711229398366, 0.06617092106851839, 0.3109587656874811, 0.14514226736801286, 0.2926495400888305, 0.13217046826837525, 0.15558442881991788, 0.18115246007519384, 0.14253419763859243, 0.17073957850375485, 0.11392154145024477, 0.19485873831135614, 0.15072456621114286, 0.13484956967013498, 0.15680013374695856, 0.061667955841027924, 0.14910156297827923, 0.08857481767453494, 0.12609147631953802, 0.1691398796655478, 0.13155081038994174, 0.19519279861161787, 0.07819683906892616, 0.12444781935623578, 0.2980909400409268, 0.21600304081314997, 0.13750300712643132, 0.1479307048383259, 0.14161190438655116, 0.1361417148502604, 0.20738115023461082, 0.1488740348647679, 0.09835710929286096, 0.12472077648365691, 0.13166328741898461, 0.18169546319592386, 0.09928605218808498, 0.20188485242186055, 0.13872168447461822, 0.1365572562621486, 0.10761684467715603, 0.16758217776734985, 0.20194627735162937, 0.240124054553528, 0.16275655928879015, 0.12120350594482115, 0.11246215161536971, 0.19890827907910272, 0.11148856111591864, 0.1132637323931821, 0.21995303611601555, 0.10016834032872032, 0.16914784697996033, 0.12104242829786194, 0.16484735112997795, 0.2171573667756973, 0.15483157889496896, 0.09503406502546803, 0.13974516261969844, 0.15076429553089604, 0.14085350798503046, 0.18768547403235591, 0.20150324870501796, 0.12249578902077292, 0.21764568654039215, 0.15138726290916243, 0.12092478017533019, 0.22035829662795992, 0.10209747229612644, 0.17776558536194986, 0.11622593392648044, 0.0929111741002529, 0.1184381353819082, 0.20798758543547124, 0.07964329733963936, 0.1931735593825579, 0.07655884349538435, 0.205528887529527, 0.18026028940033528, 0.07794517918580002, 0.11989680509413443, 0.1624907880660988, 0.1945887536050812, 0.19389513759843766, 0.16680067615403285, 0.13637387013483432, 0.1935621651430284, 0.0880278155748402, 0.09443148324686675, 0.09917127689526928, 0.14902317686186684, 0.11113934759651461, 0.14029357432117387, 0.16680384775803936, 0.1681989245116711, 0.14638852388147386, 0.10773421700803504, 0.13665471796787557, 0.0905919731444409, 0.14625130221247673, 0.09662183587469401, 0.19013540789244637, 0.19833127697629316, 0.09828836822341527, 0.11745390392118886, 0.1689828469628288, 0.06976886066578089, 0.12199929509792598, 0.08437376003712417, 0.11840521658380186, 0.14682614394733984, 0.11605682767807476, 0.14845052613846718, 0.10470508237279232, 0.18452349209016372, 0.2230438331682836, 0.09047468508323354, 0.08146113971428526, 0.08583478930015719, 0.11429458030409391, 0.21437871990905655, 0.12640604734300606, 0.1593955477038699, 0.08947349243587063, 0.19437755848611557, 0.13840064766906923, 0.15368488316814746, 0.09952088878039392, 0.12071417494406625, 0.11111538436624313, 0.13445167892402218, 0.07274335791026393, 0.14020902885785028, 0.06817326039796875, 0.1126211684858126, 0.12065966012737445, 0.08744233287870885, 0.14471950940787792, 0.19051247636877722, 0.1179413963109255, 0.10620994718685266, 0.12553895838678847, 0.257502805081106, 0.12708395088632263, 0.10102831232812136, 0.11941307419610601, 0.15498275868594646, 0.09613207586470152, 0.08972601799835121, 0.09173789512245886], [0.035678970762678695, 0.07215884048491716, 0.054978012603016636, 0.04074303027723105, 0.01754457983488758, 0.04034289106306049, 0.01339442395199571, 0.03418334113854555, 0.057022662968525005, 0.027598147017640934, 0.06855707810891253, 0.001526593222215231, 0.025879689229411945, 0.04057619164908125, 0.041025912073711236, 0.03113137133749983, 0.011957775437152915, 0.06594648028934194, 0.031716534191922795, 0.01816952755043824, 0.008058879156446746, 0.05315661174996246, 0.07587764577399339, 0.02644083905784834, 0.04779881880348248, 0.056020014754105965, 0.09320037229166878, 0.019875570883854263, 0.059373978330122854, 0.09851126150498468, 0.0769618287261936, 0.05613628008793439, 0.050721578299999244, 0.012800489390839734, 0.032859453105277596, 0.08214923222699473, 0.038045282295394334, 0.042488025351157116, 0.024670084277468345, 0.06636786695209242, 0.044684092994899526, 0.07515514059172523, 0.03802480859561794, 0.02228242378952282, 0.03666475738188432, 0.046012022141968055, 0.030482975585806756, 0.028824611649578138, 0.05815778693725025, 0.0720803317944369, 0.05225870307655104, 0.046265474670837005, 0.030894592712302844, 0.013667059322488646, 0.025676436527001283, 0.07352487484533941, 0.01890935589589419, 0.020126535542189114, 0.06864671805693258, 0.008129696324167233, 0.11959440720778321, 0.06148975995940067, 0.05851009545186835, 0.06968428455894032, 0.04683782278950657, 0.026453301393156572, 0.040920854606215036, 0.01764009950772649, 0.020105508343887427, 0.0682859136272342, 0.020140545375104395, 0.011012077241414979, 0.03475181285231825, 0.034119637097202005, 0.02266232679117351, 0.07386333249028652, 0.06011900649736485, 0.0685859443018994, 0.06961876105877661, 0.06634731281308398, 0.10248343505325819, 0.05031973837063678, 0.011294829760557942, 0.06375527730391872, 0.029502949947791717, 0.014888400741432224, 0.051631395810193596, 0.00408025658426566, 0.10555412229751387, 0.04512564309181706, 0.05005025162151264, 0.03199680745902081, 0.05764132110221733, 0.03353740644430922, 0.07584445884511357, 0.019922398008225907, 0.0990639326553191, 0.025159737035151453, 0.05026137779256509, 0.021695023958360957, 0.02131599238172414, 0.017394970524154844, 0.052665587694894885, 0.011062694585792, 0.04517052052242141, 0.03265616401369053, 0.07790653771089931, 0.08464058080027181, 0.08946907210854754, 0.03530398987594151, 0.040259284057444146, 0.03466569307831026, 0.017903356046806422, 0.07539046748030571, 0.032246609578930566, 0.03980616220243035, 0.018099154713713837, 0.04407410314607044, 0.048214892646478075, 0.005763896155141054, 0.023709921384110086, 0.059287927504028046, 0.02479096529104056, 0.01785268890671432, 0.04937650410518531, 0.021232674574299205, 0.025321498415583087, 0.0550358867152564, 0.010716567443112933, 0.029249597010352922, 0.07754943348587522, 0.04703229420908517, 0.05489157873295969, 0.035963334939292366, 0.038020223559391116, 0.05194253859020049, 0.04612223921163429, 0.023645581489789392, 0.021290477823405977, 0.07787846824935368, 0.04927832993768877, 0.028684812094715816, 0.06092263656037469, 0.01748856348586419, 0.09190438901104274, 0.0448643496530431, 0.0478011477107723, 0.025742915721850532, 0.01371189653347697, 0.057994656174653963, 0.043015216417129964, 0.03344508135811456, 0.01851609040562424, 0.02125710128776489, 0.08007347869176058, 0.021476920641538118, 0.03829599222949436, 0.0453829950082206, 0.04895821626808855, 0.03797974730391176, 0.04240875823363181, 0.03263672836305153, 0.05503854887079328, 0.026835318797478275, 0.03922024666662178, 0.06196605597412395, 0.050792288215410326, 0.024530966540858633, 0.07335975991501924, 0.06724014232355742, 0.054376254368933945, 0.055527787940997275, 0.07353442030087595, 0.05549055606787724, 0.041195366892122456, 0.04237796532951536, 0.07294402698114996, 0.046360933056641976, 0.008246868514576027, 0.016718208451845473, 0.012286674220024819, 0.005805366409702167, 0.03151620411494326, 0.025023218251824863, 0.04007356519240045, 0.0668145268554649, 0.022541949480411508, 0.054471237780225855, 0.024713134588373285, 0.034256923883672685, 0.02040066861457402, 0.0353057786912447, 0.05147311438415801, 0.02982913869463148, 0.050214121658955856, 0.027341344769323067, 0.02093250217336801, 0.051613423387489976, 0.05442940554912052, 0.07889224006043327, 0.011374418635011442, 0.07015371259542243, 0.05484405829901657, 0.0346219226447565, 0.034883262048805916, 0.03808288189071802, 0.04598489113812966, 0.027383602179226377, 0.03811090921742782, 0.05033330961821541, 0.03194470581929049, 0.027006799918449214, 0.04861514294339765, 0.05847241541731262, 0.028601287443551327, 0.04303971207850883, 0.01716188444275289, 0.037054309260941325, 0.023489990947587837, 0.005179677504084764, 0.02432154108499808, 0.04852883930828783, 0.023876943873361717, 0.058535828345244935, 0.039969557265360514, 0.031923274509608746, 0.021990739642792655, 0.025995002698994456, 0.04521034943360475, 0.019821651700523593, 0.10444680349000039, 0.08940105116175068, 0.032340076136132406, 0.031745206947708805, 0.031234260776170322, 0.052299841998084906, 0.05405872624607817, 0.031073912827958985, 0.01613330223687714, 0.031003813867667512, 0.019107527520147063, 0.02632452967396427, 0.029966404413684245, 0.030939673156207128, 0.07452464256916316, 0.03742210807338838, 0.04216819130364926, 0.029511055158030604, 0.045803596430848685, 0.006513712850714764, 0.0837483641601378, 0.042436555733964335, 0.0739175025674124, 0.04102220803859734, 0.021093907322914853, 0.08487164823999328, 0.02762211407835205, 0.02549385862244714, 0.03598939725047639, 0.056832033479886676, 0.04734075568135708, 0.09453856701692266, 0.04316048583977165, 0.03483862593589771, 0.02295799651032975, 0.06162228550942195, 0.010447834332984303, 0.10591786850484149, 0.05663675000710834, 0.05105310667967124, 0.07183113871442695, 0.018899341211504033, 0.1484130337954529, 0.02345768693504074, 0.02801382824057533, 0.04777490536892607, 0.04849908445330878, 0.027715017560929544, 0.03519690993632521, 0.020002747224944255, 0.03441783299128856, 0.005844672465877187, 0.070095076225698, 0.06871149845180974, 0.07443155522548384, 0.07433551078241679, 0.0533510372042656, 0.042828191372175375, 0.02861238422713453, 0.02336587512775535, 0.04882374102429998, 0.012027680002633604, 0.02954926187803428, 0.057133845308975834, 0.016806276004400947, 0.06348169198439968, 0.11378988924045717, 0.03314490512674374, 0.03962490196910597, 0.057604456951300946, 0.06683085985001057, 0.059833949011179714, 0.04372163375298824, 0.06007053611439563, 0.031549143980467514, 0.011003691451473823, 0.028047457585231434, 0.02153377011117916, 0.07349070732391651, 0.017742320534683043, 0.0549551870133127, 0.02750818531269268, 0.03360760691125066, 0.05894282021589818, 0.06111207478229077, 0.044107860810453856, 0.031985703014558366, 0.07251422101211163, 0.05542579099475857, 0.10003962989656195, 0.03143845768194766, 0.04001661038566982, 0.03588769141764891, 0.022304397106410998, 0.005797267423927664, 0.030453860414244478, 0.02205710009401364, 0.02528829233450515, 0.07361150406781705, 0.06216974343143164, 0.03761084915529336, 0.010308797035606639, 0.041287496625896425, 0.0600524909133392, 0.02760813105851412, 0.0692038095345901, 0.06015317018834814, 0.00952024166772683, 0.015946255166894727, 0.024334622036305167, 0.0013700413593699435, 0.10157863924940748, 0.05075432855876223, 0.04780356088773378, 0.04173746985954143, 0.025013058010729092, 0.026913277819872867, 0.047770446737206755, 0.05100480866648498, 0.01929784291273644, 0.03901268280441723, 0.012769449423367699, 0.15703978137143199, 0.17263342446136862, 0.10171592220543854, 0.1262332562116846, 0.08970668960002162, 0.1440234265981182, 0.09402579372568477, 0.13052625972176754, 0.13442704153637733, 0.15445699254351278, 0.09736867967031657, 0.14377222636774664, 0.3265865609770821, 0.13577592318817494, 0.11247570371075023, 0.11220023381493746, 0.13289750103027592, 0.09648246915950891, 0.13569413564137875, 0.16418528262405627, 0.14262628140709094, 0.08722173020003304, 0.16562876081274402, 0.24477149630265854, 0.16325163594897718, 0.1461660672700213, 0.17553752588648952, 0.16615756066335788, 0.2250558098838214, 0.1912969810467574, 0.27536270479040764, 0.11799977221075567, 0.13516221015203383, 0.1448451937927354, 0.189953216862294, 0.24126072985029992, 0.14627462192889185, 0.13862696536366018, 0.15961959777820497, 0.12741169096120905, 0.14987946397835208, 0.2116928309682877, 0.18764208281232467, 0.11945265029827434, 0.12022955538404566, 0.1677230766583835, 0.2138232142334023, 0.15253287079113145, 0.11937029584641419, 0.16739041063814394, 0.14819704296608127, 0.10291575379068814, 0.11993670295323096, 0.14108426898958223, 0.1999824875665288, 0.1541559812763045, 0.1483918438034673, 0.11332044588221658, 0.2061391838135258, 0.15843010837993315, 0.1918454080699913, 0.23813673054739354, 0.21132664094048165, 0.16841447101004664, 0.08426748065938873, 0.13974134750183553, 0.12960471723589206, 0.15208005154084775, 0.24321189450640834, 0.17026843443032236, 0.08931315789419798, 0.11137959276956898, 0.17680514093127944, 0.11589630161442104, 0.25336219178092095, 0.24521032678744487, 0.17071658054426794, 0.16806945565246767, 0.1682535312589138, 0.1887206886444361, 0.25802650278614414, 0.11073065501066948, 0.05900446731116503, 0.148607773345805, 0.24871697168677087, 0.29572645562791056, 0.1319804937849122, 0.15674584875664405, 0.1874195036268042, 0.15785762619587684, 0.15555516426121035, 0.16693959853822188, 0.10071505897588308, 0.16659697337496668, 0.22016248455451382, 0.14084347223322238, 0.3264087672916151, 0.10288975276653806, 0.20306928563983212, 0.2993457001303473, 0.16057785119741194, 0.18040492680043946, 0.0806551615917875, 0.11624402126237271, 0.10678732467274513, 0.14720066901176207, 0.13368658691404328, 0.19214382996001553, 0.37923739381855537, 0.2633068710565567, 0.1082681036824661, 0.14619439720146118, 0.12150693038899092, 0.13865011654073192, 0.11431855885612388, 0.18810772637446083, 0.09818791111390437, 0.1343376390756138, 0.12902935456124046, 0.11202836965000439, 0.18404185261216857, 0.24303095986045178, 0.1537571405811656, 0.17591131550650443, 0.20152777884035342, 0.11132330828977209, 0.08522964112700955, 0.12155874091531, 0.16256067060655163, 0.08507907420637147, 0.15976028216461982, 0.09493422078629656, 0.12253839883112139, 0.11716456017306737, 0.2048820948168155, 0.1488327427256492, 0.0815582413586878, 0.14562821226014247, 0.1291653504895587, 0.0871798251905749, 0.18343497308031206, 0.141449723572981, 0.12628646867890514, 0.25749486841021046, 0.1228246322622703, 0.08244947740627874, 0.07871356537385334, 0.19311443271656192, 0.1073022966363257, 0.11489336994747001, 0.12162473938998677, 0.15834844340720486, 0.18294973298907283, 0.08653513921965515, 0.2332521079769058, 0.10517447210487821, 0.1132320546575131, 0.18265966145742327, 0.2300490177566967, 0.18022900236950767, 0.15848183463658058, 0.11650774703030625, 0.17979358863686362, 0.09508258137371271, 0.1234830005635177, 0.2693035928232055, 0.11895303073669634, 0.17171673897293308, 0.16459011412676305, 0.1426584724216692, 0.13308753680077293, 0.10274346827739671, 0.22469250034661065, 0.14829237494737874, 0.12627178277339668, 0.1158840365467533], [0.04134188886852034, 0.009938099537976086, 0.006405920928133833, 0.019009127356712858, 0.027689351700246338, 0.09492807676114383, 0.03806536529032934, 0.005867331910262546, 0.039839245709440405, 0.030028034271972797, 0.010558669061039486, 0.024721563470760183, 0.05024629352133601, 0.022155580696679895, 0.06531532343116499, 0.020043064517179326, 0.03752696252758465, 0.03192834601166748, 0.05171588764736249, 0.022407767265253974, 0.04127837634915787, 0.04463440070169107, 0.047539226079900423, 0.048045338236636696, 0.029698576244916168, 0.018748111624811447, 0.031212837127367818, 0.018801739694730892, 0.014072481670507021, 0.037590452064309395, 0.06781396516148122, 0.08003883619582461, 0.01535185520732475, 0.08020133876632299, 0.02714549247626095, 0.06808909031772806, 0.04766206444811918, 0.016249473724934845, 0.028975762712258487, 0.01997883762082746, 0.03905955972450395, 0.07669035780934558, 0.039714392529980796, 0.0455395603973058, 0.024078599282450253, 0.04854280126070784, 0.06150589377108601, 0.08220540945448222, 0.014516962053734931, 0.04464784554476219, 0.045574735324349136, 0.029463942665907166, 0.02047797837745278, 0.008449809036157545, 0.08288931146624588, 0.01649048690113329, 0.12001744862045012, 0.039455788059821056, 0.057078303934465495, 0.021240948323881435, 0.024990063881681814, 0.0068229825457467915, 0.030695344734516357, 0.06123482888083785, 0.010290059482588643, 0.03076273365877569, 0.06763346718564149, 0.00965778605126205, 0.03680030131832727, 0.04827729433835034, 0.021036004482377923, 0.019969996966181264, 0.032668222237618706, 0.027106366450748137, 0.006058748554243076, 0.04337795904927677, 0.03022464690729976, 0.07466652205273991, 0.023243718577789205, 0.03315972509763895, 0.037885284832408356, 0.05017395949952545, 0.07149664940492761, 0.04652374206231006, 0.0803412264212966, 0.005963819726715766, 0.006063498778178567, 0.0459792067657315, 0.0445084098816639, 0.03720887133010453, 0.011151029311511065, 0.05452967496708997, 0.06657107177400781, 0.04083348227845084, 0.06336230484227981, 0.016752979267508756, 0.017660680459812284, 0.04661858374733598, 0.03951470788207747, 0.057057646373587276, 0.03940166394797064, 0.012264291046097154, 0.05136334547592748, 0.04841311406644602, 0.11082398750248457, 0.05077090287100404, 0.07324667001563696, 0.0373707648607031, 0.06480737649385007, 0.10414385402034368, 0.021780701316592675, 0.03840206093305061, 0.06710740226891733, 0.058982622314004175, 0.03260089460039332, 0.03482616551580929, 0.03634988375368618, 0.025792952754624912, 0.04226057767687787, 0.0721209038109068, 0.024378999594538927, 0.01950766864953743, 0.04529674499926548, 0.06078901933506132, 0.030915876550059167, 0.05757644111591001, 0.074334760016251, 0.030252735521043503, 0.08159919641911983, 0.02584973327635277, 0.05925166856257185, 0.08221877768876092, 0.028888984102635618, 0.04082043963153997, 0.02864804945044941, 0.029980672801273967, 0.035495270539315484, 0.06785201674868023, 0.01952105795123404, 0.04068579967884768, 0.018215234271220623, 0.05530004149242755, 0.04714893109555687, 0.031031921633609363, 0.05956287262961269, 0.021156487130229513, 0.031554113975876284, 0.0375649681495082, 0.09224555094636257, 0.04567140412907447, 0.07092210644435498, 0.05277459817608038, 0.047611276649179, 0.019377424126310695, 0.06655880670634008, 0.05729570053517819, 0.11166060914195354, 0.02498802800302304, 0.07189282411409002, 0.036200266782074206, 0.04896092055846126, 0.018913465957607956, 0.019105370982640216, 0.07916468390894514, 0.0095980896073724, 0.030282214584369815, 0.02019379806194094, 0.005724161568533389, 0.011278357912576007, 0.04878538683237088, 0.035229564434097665, 0.05000472684661227, 0.09684334253712047, 0.02670260938635517, 0.04058462244668796, 0.06199696379142904, 0.01047193450147226, 0.03585122563245316, 0.04536743193203884, 0.02371784464846696, 0.07805721954472604, 0.039613031436719244, 0.05661547191501145, 0.025045084316403638, 0.04956532179588272, 0.009301264053060403, 0.020261437879995476, 0.03654489143481178, 0.02615726969745611, 0.05283899935743502, 0.03433137613859388, 0.03330116791109885, 0.02113631795040302, 0.047505935729150815, 0.051310240261016354, 0.0683800351896113, 0.04081325755724984, 0.04235720817720698, 0.04187003371395892, 0.04026769570285275, 0.036841589627006364, 0.04199990859976219, 0.06104295066888295, 0.03703367085226121, 0.02765857603310818, 0.04170701020367203, 0.013227294210434682, 0.04015844007353148, 0.03816729711909448, 0.0919075146497738, 0.01930918101401579, 0.10092650690386373, 0.06349368509085429, 0.06593508090102865, 0.037336742895985806, 0.018080812653586752, 0.058534694535117, 0.039927855269202304, 0.02737532651442434, 0.04792484026702662, 0.041045198337205, 0.03275791198135384, 0.06455890353648894, 0.05161783605393383, 0.09175690176386027, 0.0636249810697571, 0.049470748241630294, 0.04553551928350522, 0.035988160018478675, 0.05837815212866953, 0.04070304048758361, 0.04342629153641962, 0.044176555914624084, 0.049734259504945054, 0.040749691411732666, 0.03256060220601578, 0.03143361217582659, 0.03524261091144816, 0.013766453485004606, 0.07670830724941147, 0.026937742837734764, 0.06073994374263191, 0.07630264837174647, 0.01690930525411762, 0.04776452870799169, 0.018995510143858772, 0.03094623086883897, 0.0131086386822825, 0.02915653839497076, 0.012096867318295184, 0.03158160121059947, 0.025367517317194613, 0.08390263128545015, 0.053435693750338215, 0.05801903309240457, 0.03083587590334637, 0.06391462359216905, 0.07934590966831293, 0.024445398350156123, 0.030166841742973176, 0.023744847332578034, 0.030142725295116825, 0.031184413350157203, 0.0760115732649161, 0.04638622161902247, 0.046266616141844186, 0.030413728898331046, 0.06724245590908874, 0.08686527714974458, 0.02540064104382069, 0.014725579286835369, 0.01870898176885901, 0.01779032743445808, 0.015315377930810135, 0.04597928720496355, 0.032131945368863886, 0.10083069994805322, 0.020976954425174384, 0.07156103909496339, 0.04194350920677666, 0.049286071256163626, 0.0366225152937395, 0.030426244859793977, 0.030017699745874253, 0.04358906606813112, 0.12757056227494634, 0.04261603481286476, 0.00721076954974823, 0.07561660897467407, 0.0321296566811901, 0.01835638022560987, 0.02023700542087036, 0.010147267396772101, 0.05763116660678099, 0.014303838308419914, 0.08202679605493624, 0.04012899548416177, 0.029894522383749008, 0.082265539695659, 0.06940803325344479, 0.03201084218979363, 0.08992985101236452, 0.053452743037093076, 0.03547578126252179, 0.022422140989933285, 0.06838510669167004, 0.050214998829629154, 0.07530645061764987, 0.07237833999698201, 0.056777315649894945, 0.05758227870589303, 0.04338428310509171, 0.04735071865481235, 0.048201631664508776, 0.010145143418002033, 0.04136458422327715, 0.04677910981098971, 0.011290670860739005, 0.08033734235552051, 0.07082326578036433, 0.023209436143177654, 0.01517783642010463, 0.014731663940173965, 0.02078689758725945, 0.054068451732276916, 0.05557428181712186, 0.030127171795034123, 0.05593809314192303, 0.057709931936715884, 0.029974036564629887, 0.015560681199384554, 0.03299082186253321, 0.07615367491399089, 0.004800729239509712, 0.02565326428251161, 0.02565692618278967, 0.07612091699434866, 0.02915271753144841, 0.03637811792413554, 0.012214938704405102, 0.02561373989127817, 0.0261008913718885, 0.09270557908401375, 0.02142402035514674, 0.024608898750175873, 0.03800212473217999, 0.03192043040818986, 0.03755303249964791, 0.08711895184411157, 0.07220511219554371, 0.03868964267894626, 0.05042763802433207, 0.11829811749198746, 0.16358079328652353, 0.1253876790043808, 0.07810002087705559, 0.15114865716426604, 0.13950985105287644, 0.1385351573868144, 0.18535649013375083, 0.1467997598792276, 0.2010147297574628, 0.12742745705069075, 0.12479198435621879, 0.1580907314294769, 0.13554412030404614, 0.15073821789795352, 0.14928209925851516, 0.06450157717711504, 0.1173481378223627, 0.18365263398135864, 0.1586236221896064, 0.16267161545974596, 0.15383727337804534, 0.18273110681724164, 0.14883983669982803, 0.14312577073372182, 0.06932691986402197, 0.11812782380729915, 0.19172130182625788, 0.08991602312533126, 0.1051422044815075, 0.16271535908022236, 0.17156342945752606, 0.20102148665295494, 0.23662651077874247, 0.08989338522716876, 0.28785349260414805, 0.1420186051437932, 0.12870379783693822, 0.15996084398319646, 0.08573214884006208, 0.2304324141192821, 0.1015408787756197, 0.15899557319860305, 0.17607842992630698, 0.13586708765116431, 0.19441813050258547, 0.18308436528088587, 0.21210469515813937, 0.19763453533091854, 0.1264813308033251, 0.09438721868660181, 0.22044327110052112, 0.15262745200626313, 0.14085320154986075, 0.13419194447417415, 0.1560662981242903, 0.22931363463642138, 0.07902246734668171, 0.09728833236881802, 0.2002083149648482, 0.0703339884057641, 0.16649656989161046, 0.12426520697772504, 0.17395659620242734, 0.22604156585951007, 0.1224499003541085, 0.1349761427169846, 0.11659876593659002, 0.14931476524760648, 0.09887077890697027, 0.23062333855177128, 0.134886295925225, 0.1290011931691439, 0.10403850160899664, 0.16215718741859161, 0.07891209705943063, 0.16453071166911434, 0.13671628079347073, 0.18625694987995012, 0.18574501928542891, 0.19033423835231414, 0.1777743953730791, 0.13320218951952073, 0.18308744495434148, 0.18576286913406465, 0.14023584193520008, 0.13881818090956058, 0.1522462160116242, 0.12873854758518358, 0.20930504216061485, 0.12068466523722296, 0.18262167881813743, 0.1334146563444407, 0.10109272500079486, 0.10100430313257441, 0.1434586052933047, 0.12820332025688502, 0.12941849658325796, 0.12235050044593312, 0.1585152360700792, 0.1460389426398662, 0.1219922470890226, 0.2164765904026647, 0.1382191461180487, 0.15312312621503107, 0.12159246410573683, 0.18442200076195503, 0.09433652664865218, 0.1552241223473703, 0.2366866486807985, 0.2788182516251841, 0.15688999586047667, 0.1205874027143563, 0.2721743081365862, 0.08366964862591798, 0.12236674917080712, 0.0875948456626746, 0.1092233540370099, 0.13554810396125241, 0.13268120376573456, 0.17070187165612177, 0.11800300510179614, 0.16679961895269735, 0.12989930868629487, 0.12673146617148193, 0.1584681676280114, 0.16099489414163176, 0.20711214612087897, 0.15338666046098356, 0.15738378549295087, 0.17174655511494608, 0.1816380372451198, 0.11954125602759662, 0.17999450285588542, 0.19026181239995266, 0.13727662814480646, 0.11081811160810533, 0.11838240248541679, 0.09925454299175933, 0.12289996168786481, 0.14154505555427846, 0.11669644214693578, 0.19305466253670955, 0.1893002188373958, 0.18538210811393876, 0.09425404196184489, 0.12050927706783819, 0.07350645043076047, 0.20647474564611915, 0.14220297186365052, 0.14564615403932912, 0.12902105016814125, 0.19622637379554012, 0.08276307549808296, 0.14277553065649926, 0.13238193917899363, 0.2136597770356363, 0.11597662593328184, 0.1269645024571688, 0.13975833933199608, 0.17490067699503514, 0.1549334379453813, 0.1469837435551228, 0.15162841206596744, 0.1567263288363334, 0.12740585337122604, 0.14548469334840775, 0.13662194472647485, 0.13408938062287148, 0.2095941637432383, 0.09393007870042518, 0.12759746728284707, 0.15486202322907988, 0.20984870411695974, 0.0762630646086989, 0.11904759663006953], [0.016015020176588048, 0.056518665214459744, 0.02124074914102112, 0.0176636184070019, 0.0443896432707627, 0.052876939861885006, 0.07761730121508723, 0.02442985059573285, 0.10619440326286901, 0.023778936329988704, 0.08021461507005077, 0.05588907117564833, 0.043244479719789765, 0.012158864898787392, 0.03847652084885105, 0.022593539756452365, 0.05485854502166471, 0.044172913166544134, 0.012527755386526547, 0.055907943751662977, 0.04655522444555837, 0.048194694738354416, 0.04677227247626551, 0.037014415232284416, 0.017738633736547445, 0.032341359333405574, 0.02650084672495723, 0.03048533130617392, 0.06933529320503436, 0.07870701532210074, 0.012157266647855361, 0.02947908247851076, 0.02505414139088844, 0.012967566463855967, 0.015387776112484356, 0.0734769254021587, 0.05203084937567192, 0.03148436741602998, 0.03436569687760165, 0.020787592812050736, 0.057419132621538256, 0.0018314890340045697, 0.004213271472948574, 0.04037513570379346, 0.07246952744260912, 0.031633643478515654, 0.05109055305741007, 0.0036100957368034874, 0.04043117120501496, 0.056108651126945214, 0.02771907782692823, 0.054481273532033934, 0.013596735323869414, 0.07107891698157595, 0.00857404551483811, 0.028409759716821775, 0.07621012793313112, 0.019966643416292725, 0.023710160786586425, 0.024454035991502386, 0.06389232660313288, 0.016519310959284345, 0.06864900099894694, 0.05195979855113453, 0.036141661055866754, 0.04116814012729353, 0.023023652160660397, 0.027460628489573157, 0.010108849044979341, 0.04385402523762277, 0.029641449068402572, 0.02909658052357695, 0.05403479365932365, 0.015724331944159443, 0.050193172984666405, 0.06768466484162115, 0.08362967415802902, 0.05295580861368968, 0.04103460717165182, 0.054990415566510735, 0.03247238718153488, 0.04272144085036651, 0.007631258453212439, 0.04792402821382688, 0.0375600996607494, 0.05531324884824215, 0.024647668544803897, 0.058184676623392495, 0.05324693351623513, 0.01774066386954679, 0.011683446054737414, 0.009258037541932877, 0.0026896518688919327, 0.021483076158009713, 0.05587130942712388, 0.04421208707255222, 0.04393239986271628, 0.039201910352154125, 0.0314159500187323, 0.03360892841292005, 0.01618937412727504, 0.03695810393941018, 0.0470095337368548, 0.06295684131703551, 0.0874200243983538, 0.013099384340157193, 0.03700538305565715, 0.046831326363908674, 0.013985605384673805, 0.08115684959076105, 0.03923468742399447, 0.030787656414172346, 0.06877625586404916, 0.032273058764516346, 0.02898150262603116, 0.08918412570511142, 0.04650540191740279, 0.017342135355237032, 0.013270986119976208, 0.019901016494259238, 0.042106184147057996, 0.06758300497406913, 0.031595559332579855, 0.022783113958975, 0.011632924471350928, 0.0681991311871717, 0.034742803658328714, 0.03386306276004161, 0.0010731140590055036, 0.01951441405371072, 0.04033247226729028, 0.060292985064968954, 0.013727783281806738, 0.02809854607368189, 0.0676144069180854, 0.030742560648509575, 0.0384654508783452, 0.06877740499593558, 0.025146525848897237, 0.04966875132653983, 0.04270896127807998, 0.05101744145635636, 0.02951076404461938, 0.044694094272751006, 0.0935348769229266, 0.03427168639797357, 0.026207337373747464, 0.022623549335666245, 0.02156968048262981, 0.041225075781826055, 0.04793780247470544, 0.042363375184997436, 0.04588308571387203, 0.0460686934961667, 0.08049422184065466, 0.03966221428145805, 0.11166070107250445, 0.06299163703055632, 0.08746311684409458, 0.03465275768370878, 0.0657069169345402, 0.08633908199807329, 0.03129928823440306, 0.05755988978630593, 0.05448175233698661, 0.050015513364586144, 0.12665971437649381, 0.041188713418500084, 0.1127087553181956, 0.06585842614332515, 0.03952039608491525, 0.044164103155414906, 0.06301791767679876, 0.01870219806028951, 0.012897341099056988, 0.04338273177704504, 0.07603867745567715, 0.014612750814957245, 0.02619550706097676, 0.03155281354162482, 0.01583959370280706, 0.04104279665156238, 0.04805671081187264, 0.07583275302163056, 0.017252771198869716, 0.03225729650547428, 0.06990189183383219, 0.06489921511421282, 0.08737418169696486, 0.03032082350053374, 0.06387371066657287, 0.014346159878186883, 0.12314440502274422, 0.03348468044292062, 0.08214848912170819, 0.12102588845957672, 0.054638145356288845, 0.06999435098541361, 0.013677890848128066, 0.02842591651114485, 0.0956421013500902, 0.04875665087433112, 0.028553200104544242, 0.051554476752156214, 0.0349416762530323, 0.01032394546669938, 0.03717995151096294, 0.03575020161787829, 0.025996444859511914, 0.08194636448376602, 0.06492815791599213, 0.037711762087119204, 0.11221322666613326, 0.017534415763352188, 0.01893054205744017, 0.04811314084837514, 0.062191404567490664, 0.005333360008549907, 0.05342247873364438, 0.04038369673634729, 0.07872301889883895, 0.07534259464591742, 0.011608489139396097, 0.012027105436690394, 0.049995610400313334, 0.06273614670780879, 0.027630541045519135, 0.007920666840002543, 0.022664255417522886, 0.025796017106322032, 0.037779430633470897, 0.04077842353933281, 0.028336282308784225, 0.050023446205042066, 0.044815906083151225, 0.03230718798154304, 0.0466233832881816, 0.03508329143627517, 0.09127723879270977, 0.016535871864987478, 0.00872968393753493, 0.022733463800602385, 0.02578145377488146, 0.03869014063609704, 0.04589522054659263, 0.04710749339973254, 0.03342734642266747, 0.0411902379334694, 0.05509635020468024, 0.1010681412393047, 0.021516140512821656, 0.0385839493584729, 0.06895231052992806, 0.04641202729075186, 0.046672918533365575, 0.07396408071320865, 0.026541608348188382, 0.09365100819136828, 0.03510569184718113, 0.05465955368333286, 0.009566031700570979, 0.012063937986479893, 0.01894993557324333, 0.07593992106135815, 0.09094120964648263, 0.05679246503859759, 0.03568892990569434, 0.03492205674129148, 0.07951922940030214, 0.032439859088269934, 0.014177382089978745, 0.017031057692703702, 0.06278108159500746, 0.14122605654260806, 0.04660627654483242, 0.07411599594859347, 0.04890203521016145, 0.02590789084112452, 0.022093826349103646, 0.11495322439699404, 0.03155926591716707, 0.03214045277526302, 0.01961971666934269, 0.0271522838457097, 0.03388950428474815, 0.04476477354464512, 0.02172010376178209, 0.08788451882860354, 0.03348097640780672, 0.037123862383586746, 0.04478968672394272, 0.06575531836959624, 0.028536713892413725, 0.04269655831458588, 0.028338569081238205, 0.019880406813876286, 0.06602310440352847, 0.025914036781497063, 0.02158896674612357, 0.05297800218085608, 0.060028818796478936, 0.06551988422870636, 0.024064342386179396, 0.03468928475593848, 0.004977723320705756, 0.013012564553308391, 0.0319827918804461, 0.039574799818858024, 0.05193175207222662, 0.08068710745822999, 0.07959960734531765, 0.11999744606474716, 0.08006835356354713, 0.04638769250783709, 0.05579716743781202, 0.044413878462247314, 0.04182712512931997, 0.061439523743765975, 0.014716323029490249, 0.06362436819941768, 0.0320378084847283, 0.053663781108034235, 0.056498256632156914, 0.084928652842439, 0.14393636836640297, 0.04768622303081136, 0.05071584030144638, 0.04042986502510406, 0.04282984612209182, 0.016280755010103027, 0.03974694360588347, 0.03808150676289394, 0.04705597398682468, 0.05114472696497556, 0.04071929687333684, 0.004726789305887876, 0.04135591210797429, 0.0414395114527114, 0.01556233977974062, 0.044909510536179434, 0.11242949328715764, 0.09133330110700862, 0.07830094275695663, 0.05204989049102991, 0.04806954661504396, 0.07587442054383217, 0.013556137451932076, 0.014575571610382008, 0.025502436891979268, 0.02170262738100944, 0.06489654912823631, 0.03466216141297933, 0.16283632436346623, 0.14577813566692416, 0.12156928994602735, 0.11142182719683456, 0.13727687329294222, 0.12066832458179806, 0.1992881667589949, 0.11320550205005754, 0.18879666924476626, 0.12771005156419932, 0.20961745281613645, 0.12863864971985742, 0.1694233015540146, 0.08289018480647957, 0.13393090767485483, 0.09536831684771085, 0.1434415521761102, 0.1712872087955475, 0.17374109566932724, 0.25629970996129897, 0.2220079597205885, 0.13962104105420653, 0.12005613606062629, 0.07977116507508102, 0.20035552642037793, 0.13510135212732902, 0.09418269619345666, 0.14342799241985046, 0.1297982463673238, 0.18363550425537173, 0.10388683918262683, 0.10337811849650838, 0.060829905447580164, 0.14071892165849287, 0.11379768801552635, 0.2123878872202289, 0.15680970984601206, 0.11232721288838696, 0.24068415675672794, 0.11392724880528067, 0.1435377268541244, 0.13735342079833632, 0.08362218181812957, 0.18825461607306235, 0.2287362035243742, 0.13247314960725848, 0.17140659593766736, 0.06944004040692123, 0.174410549262839, 0.1430598718504752, 0.11051906918686245, 0.19570060765310643, 0.10123516372855633, 0.19221343670881566, 0.09318509649845863, 0.22328666771852204, 0.1482793974179414, 0.1551198731026342, 0.08178498806251634, 0.0819737444661798, 0.1549008638868409, 0.14546969334685034, 0.13061959987446187, 0.20457474034159415, 0.11818765527418545, 0.2512431312953272, 0.10979375246191218, 0.12593108815171067, 0.11763366645262127, 0.2108038931844696, 0.10511680100593837, 0.12193509692987128, 0.08603577246709217, 0.24056988708194227, 0.11097905135923818, 0.1138798815889224, 0.22836033014520524, 0.07868201787313146, 0.1627629024968032, 0.19649113378217145, 0.11123104832105099, 0.1687396753339037, 0.14306675132003524, 0.18403547876063855, 0.18070961528968427, 0.1924755307094705, 0.06480525443029982, 0.1514542802807785, 0.15567678838006913, 0.137444784444186, 0.12817885906946275, 0.14687034722057082, 0.1345298505358158, 0.15415953592427317, 0.13612237879105155, 0.08811090547110766, 0.13652777719882228, 0.1915989422629918, 0.14844882542327528, 0.15508152274114473, 0.13427163294005778, 0.06082879462008996, 0.17222036517435507, 0.18641701629084928, 0.2516429985482847, 0.06858799741753648, 0.08920228198891686, 0.14313012211313172, 0.078668404490717, 0.15170793199250776, 0.1516222986843317, 0.1607711505024664, 0.13924265490664592, 0.1375396567727289, 0.1058423245746282, 0.1818477767970293, 0.08683109430656319, 0.11768248923603566, 0.15921138016687286, 0.1676926476460311, 0.180774855337316, 0.26475977212671314, 0.05331902622034954, 0.136407210281299, 0.09328161591603872, 0.12772698976820515, 0.1747203705411765, 0.17043856723654657, 0.16968580924214857, 0.11228726140313572, 0.0886729228941183, 0.18208698009050664, 0.10527174994950333, 0.1799318062201623, 0.21525723889710444, 0.20876798388217727, 0.1257784298110393, 0.16973626379284168, 0.1677441747198182, 0.20366471981809986, 0.1655205125890432, 0.15160371339128864, 0.12599111880145727, 0.17514867497788322, 0.19871274279730938, 0.1973651175297076, 0.14096794619915948, 0.17105424145777381, 0.16590640639826176, 0.13290867059221192, 0.1170695499486981, 0.12351269413146282, 0.1227497471676719, 0.21471915406084832, 0.13731344633044737, 0.05610510797029542, 0.24341608758174607, 0.21162898520067816, 0.1565156086918808, 0.09213251467313498, 0.11190004226180816, 0.15338126720199663, 0.12081805646659867, 0.20136809547341641, 0.137946801860967, 0.2577446130735259, 0.2575569215320772, 0.14931444349067827, 0.18069392580899502, 0.16212331101057992, 0.11225326242105615, 0.08002111658213601, 0.16068153353708406, 0.11801625842288618, 0.15986781026567184, 0.13941646493490667]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.05759111169965998, 0.037369205871777195, 0.016476429187722744, 0.06098217691384977, 0.0842425444974534, 0.015217133857790503, 0.047179808269344994, 0.03624974840110348, 0.02149153759913339, 0.019074817481000098, 0.03889604591794553, 0.08641411264937732, 0.047174395858159954, 0.03818286019527624, 0.03210420915556531, 0.026218489698705175, 0.026799427578225735, 0.023861239070913965, 0.04508433946137948, 0.0033614516066717767, 0.06375201759980091, 0.023322679260144794, 0.03481255596383445, 0.051923022500329444, 0.023252080427482728, 0.08457779223399778, 0.04418442746804607, 0.04937028730167978, 0.044069280622587095, 0.10650424752384426, 0.03219358480325149, 0.018840833161506924, 0.020252438262104988, 0.07787466845324925, 0.023051484134949507, 0.07325821496065586, 0.031599899220670906, 0.05336618276252862, 0.0180033266904854, 0.017310834917870742, 0.03852346288641134, 0.01729804507997488, 0.020467251231293046, 0.027329673419796655, 0.07511395570491591, 0.018305805016068682, 0.013416564850617322, 0.0476642171551864, 0.040057270502251004, 0.06292442047607995, 0.05614111793317622, 0.04853847286393566, 0.01611483185702274, 0.04470200796100882, 0.047345708439787554, 0.035675983019774, 0.01720260776158783, 0.029523371936633225, 0.011087067673102984, 0.03714055543945682, 0.02746622859229965, 0.033720068618535035, 0.020356241260625182, 0.049819414008168444, 0.07252647841890013, 0.05160239555181996, 0.047194042182978124, 0.05222626308339739, 0.042278553930021105, 0.035014546536389864, 0.044559626689841675, 0.02596817238466634, 0.017549327664798307, 0.036699664178154165, 0.06284139569728606, 0.011568164186281784, 0.03267290686527568, 0.007055716226703578, 0.04717578630774252, 0.06393218232739357, 0.07316431556377681, 0.02516046481867952, 0.013434032612900822, 0.033603803284706614, 0.012794029354418238, 0.006324089810086956, 0.024627671734760367, 0.055070586667786685, 0.047196256177079295, 0.0376595914994757, 0.007835014858433317, 0.07374281153803872, 0.08742100499089688, 0.025329536593128598, 0.0810719900313885, 0.010874604678622658, 0.033582165131285306, 0.04545247535251322, 0.021245728712528947, 0.02560418294442277, 0.057625160477454626, 0.019805102286139326, 0.056211701444079804, 0.011227645764818356, 0.058165386529459115, 0.02902334826367517, 0.05574961636035193, 0.058150884485052484, 0.0667786586188501, 0.03166765395191408, 0.03625281658324023, 0.03993147503464453, 0.05854155485247893, 0.057241407883984435, 0.04344514879067579, 0.030749964888297746, 0.077470610699346, 0.061277499978220275, 0.04470774212912206, 0.03331531372462069, 0.07874731920779714, 0.05823739879434148, 0.08930755013059224, 0.06101034979726519, 0.012321868299266264, 0.07523232395009649, 0.0589938493325345, 0.05549329866264617, 0.013769631792280464, 0.03709763919393863, 0.023473071895780104, 0.030919712735340003, 0.030482069686836297, 0.037877918897016395, 0.0482879544518167, 0.059329273269301465, 0.07406541116295323, 0.04918109422789947, 0.04066839799164765, 0.07382047753180228, 0.05091848587917705, 0.016289032590124878, 0.03392588963071185, 0.023866944510730046, 0.06401932099834085, 0.05411930464869065, 0.04414390141685163, 0.014666678616777064, 0.03089561543968176, 0.022827286588689013, 0.02584424808681492, 0.057336770508798866, 0.06622491494542168, 0.06144689734003717, 0.087983573997213, 0.03786777589289892, 0.006087041138896659, 0.04339585103274834, 0.02062211207474672, 0.026412746613664974, 0.01689833679026173, 0.059737406610961885, 0.01659981913924698, 0.03816551596467053, 0.05258271613368585, 0.048166142641416484, 0.06756795900723628, 0.020430450282630422, 0.010163266185460793, 0.07628534244553697, 0.08190959226340055, 0.0531960652780629, 0.10264964548931008, 0.09455529837718896, 0.025764839243023627, 0.03637400786242178, 0.041370433304579034, 0.008939747161592447, 0.021454215710682255, 0.02779239435650168, 0.02546261755689498, 0.025544272953524225, 0.03906665752912241, 0.034208713970597715, 0.03763359047532563, 0.018554092197108175, 0.02964834769016072, 0.026116735985382434, 0.048184609190831264, 0.08630343592695652, 0.009963398634065545, 0.0365118385713187, 0.030278635038543614, 0.019394061640806256, 0.02534584660503653, 0.02511413756667847, 0.05331295114310999, 0.048803922329698844, 0.05601060336395618, 0.01856533453739699, 0.03908828802166447, 0.0998973367255061, 0.012812818618371122, 0.04832989776567106, 0.02386506951053537, 0.10577135418932285, 0.004764047992085257, 0.00997779246855287, 0.031241088534795472, 0.038872691727573835, 0.04500693393751018, 0.015277406782843174, 0.06188500770217469, 0.06717391402250336, 0.03608772080511816, 0.03990912441945365, 0.029682689496586402, 0.019941619154246106, 0.00997685113801591, 0.009450111106308478, 0.01739850027426597, 0.07890006181814017, 0.01648138386137303, 0.09495827594711896, 0.02817623121964355, 0.028716434289010304, 0.002105580689761067, 0.07810435693470702, 0.025476389902553735, 0.026465457293295094, 0.04276743293890069, 0.03369356197635493, 0.02427928750553439, 0.05099218353749283, 0.03766246049875214, 0.04922438968694018, 0.04490416707290758, 0.022981609255375884, 0.05353594784654918, 0.012412857519642962, 0.0342600763354811, 0.03459100716657216, 0.06358039475256397, 0.0663230125041258, 0.03220121503897733, 0.04564905351388358, 0.049169304134744796, 0.029054254165760456, 0.024102114351286043, 0.012701383468905285, 0.02555518204556598, 0.06322571519582022, 0.03357760690813584, 0.02000270700532823, 0.0686336026316689, 0.10347343515604736, 0.08075574893624553, 0.030738052221075184, 0.03203880631424968, 0.016978157406312325, 0.09170115354561037, 0.03769451361750403, 0.013941129192619795, 0.053174001945843624, 0.01904024393297732, 0.05534551264117322, 0.05647741137973725, 0.06113354822680835, 0.018039556903644435, 0.027903333464036548, 0.050701947296939553, 0.0155344340694888, 0.08480761861128193, 0.06881929468363523, 0.04674815985884878, 0.04281330245336698, 0.054713183668472117, 0.060406009846877676, 0.03129382028184351, 0.03189898760718925, 0.05774205783382059, 0.02797200941600867, 0.045965225661113385, 0.059426972462284955, 0.04899044175662341, 0.05280383592171054, 0.058010770834141204, 0.03274452842531666, 0.04779234153008269, 0.0026516840725596394, 0.03300147431512033, 0.014981885493222265, 0.009307199319253766, 0.0849217810337582, 0.0699910031811845, 0.022457187597249306, 0.0425905202545466, 0.02427661385867865, 0.08808450608123695, 0.026714439699125868, 0.03974646097049117, 0.04167350534830363, 0.0405726753055088, 0.028436802620548877, 0.031929569837126526, 0.0441100173479607, 0.007991295358571675, 0.018010623677964174, 0.024961343245400537, 0.01621088970662846, 0.08214806011247058, 0.050699756285476114, 0.01956171615259542, 0.013187410715486736, 0.025076524564816106, 0.00980018360179759, 0.07323094989143072, 0.0595748121099126, 0.07288775016223231, 0.01131501905019245, 0.035691664839584025, 0.06117524639252694, 0.0215655627600368, 0.015486770951669785, 0.013162586593910331, 0.018530299421399832, 0.07786364444801885, 0.01842431498751525, 0.06253509459296061, 0.05063422129399354, 0.05360900965188781, 0.020820276038120353, 0.02657448501145888, 0.0372469152564243, 0.032566156343466816, 0.035268171435041774, 0.028016319941549052, 0.05916719204716145, 0.02148528440645145, 0.023591097316614563, 0.02190599882704837, 0.022467211857738516, 0.03544937804221146, 0.0433304118022563, 0.030077224777590846, 0.010196781574538159, 0.054904992932513844, 0.07399937438388025, 0.0503044932209436, 0.10396074368468217, 0.017430810032472495, 0.040678368625982154, 0.1313128788024187, 0.13263105565021116, 0.0531314917269253, 0.13091819030382942, 0.1435361180694834, 0.11435220543775829, 0.159888387387318, 0.1747399517485211, 0.14550246658825106, 0.09947325343326216, 0.1519471199642266, 0.15113713520188488, 0.17923961513705794, 0.20269833054513703, 0.11195372204266249, 0.07679882053766521, 0.10670354529734581, 0.14782729829030652, 0.07844894328304837, 0.09615666728707091, 0.22136443054243443, 0.12401395312119877, 0.10449613189144481, 0.20604052701063696, 0.09618980825067529, 0.2097319523172994, 0.13590626538761202, 0.14073251205826962, 0.13789456998628957, 0.1973490296832977, 0.15377008746708595, 0.11286824716315155, 0.1521667880156348, 0.23331909470500486, 0.1081808003026151, 0.13983605129103507, 0.18931049973733965, 0.15384438267398268, 0.12855091733076882, 0.08265356322930706, 0.1467310111489027, 0.11278801477484166, 0.11390929170433553, 0.12187111326643538, 0.12341164713425022, 0.2456655821973278, 0.15199555204279963, 0.22991567249259642, 0.13048076942082376, 0.18835288983198906, 0.15782863742882208, 0.300186098583283, 0.10480513345570334, 0.1257179548302966, 0.12484973206395104, 0.11867674878768383, 0.06644200894140428, 0.1682562891754412, 0.09734403462179246, 0.14310911598224796, 0.11274377319721446, 0.11909982084386772, 0.18285418650315655, 0.11524249919720235, 0.13941560691643146, 0.1154655073919604, 0.14307654192370756, 0.1604953894932424, 0.22709852204688136, 0.10675943907230132, 0.16225011388380683, 0.09625992061750543, 0.1053517065461605, 0.20121630281209948, 0.2046240917256763, 0.16489411313687602, 0.1386242840559252, 0.13463679641004533, 0.1519991066907683, 0.1411607398861839, 0.19101553566513524, 0.12605447427279529, 0.15771449032810428, 0.15687202343777304, 0.252032324431404, 0.12023766825516378, 0.10487834081774759, 0.09234387067056472, 0.13380822635466053, 0.1819113467729861, 0.12484400938715666, 0.1937741263499183, 0.21376854619912564, 0.14958216057669732, 0.17488633582909263, 0.08474592555073962, 0.1463057710638931, 0.19291250726148007, 0.21534353104089538, 0.12480499252917306, 0.17478047779971556, 0.17572103458787167, 0.1314224753408663, 0.08717314490387518, 0.20815716665838996, 0.09112898545760302, 0.13920182242028176, 0.198171210565394, 0.12388772481391508, 0.09766370779083622, 0.1687960900486477, 0.0929028697071537, 0.11434255272991235, 0.15977499105276602, 0.2558518702825231, 0.0935789576220897, 0.1878070675076977, 0.12339100106469086, 0.16174092588405456, 0.13837072427474684, 0.13675046363665214, 0.16064810146006847, 0.19308774221327998, 0.1999101841882352, 0.15826435759663582, 0.1538409352783234, 0.15009543948596524, 0.11628002739481388, 0.19135466746745572, 0.10373945918775375, 0.11612128631602373, 0.10361849390450986, 0.09290897542791021, 0.12354562825132763, 0.1582019061090485, 0.17653426756301235, 0.16465757582937518, 0.13027276122762313, 0.11090808863481207, 0.20824281528832453, 0.13304408429370773, 0.13379983003101042, 0.09217919241036139, 0.12057881486872513, 0.15193591975877363, 0.241944708470856, 0.11602750183233332, 0.11415583412012748, 0.0909907448916666, 0.1048736906640472, 0.17556813875994376, 0.16197101273123296, 0.26031370424935896, 0.11694123022138112, 0.18044347634478924, 0.06710848245289057, 0.12597445638910418, 0.19837696646009723, 0.17761569259868515, 0.12669323838406032, 0.18344894652405094, 0.15012894817177327, 0.1349183490439769, 0.10498665032848235, 0.1658277751337136, 0.07972329224069273, 0.1449421805239493, 0.2168003851247411, 0.10975700322418444, 0.11036239654546785, 0.1467241929663766, 0.14060750183078552, 0.3095767430720791, 0.18942369688903132, 0.13186798611235234, 0.22328305178351943], [0.02349037399154998, 0.025879084019951766, 0.037914315734298966, 0.04435444153064201, 0.05245904272962963, 0.036062819117139426, 0.02690590613882148, 0.03790255628466126, 0.026035289347712553, 0.03666800559468327, 0.023560662558602712, 0.030779164329531695, 0.08326579771575429, 0.07076924125994406, 0.012721969209040606, 0.10102177759812725, 0.0666316846505769, 0.042798064964553045, 0.020160457915476254, 0.04019995054770862, 0.019107372387342395, 0.03515713848173618, 0.05605056251008665, 0.08941919212379763, 0.09977210433252397, 0.031152798816741958, 0.05282822050034039, 0.044903615489602096, 0.06142914708283159, 0.021996205680132396, 0.006562230635374304, 0.06917783149307774, 0.025681599959610932, 0.03094555096580617, 0.030225418740883473, 0.0418116846272061, 0.06105694709525955, 0.011003165723635785, 0.03121493812350016, 0.055042256736346794, 0.06603923821521383, 0.03430728267337527, 0.04147028903506937, 0.01768506503844213, 0.06276350753802447, 0.07810093252168548, 0.05199999901496115, 0.011792281293310227, 0.0749641701939606, 0.0161108156410797, 0.018546203406707897, 0.04684624209579441, 0.03021968265755042, 0.02073204760710078, 0.04253919236361981, 0.023955940944893707, 0.0634896784510103, 0.05239694747292707, 0.022891890783343586, 0.019945005262871424, 0.04118892792311888, 0.08799129616348975, 0.048643461383518674, 0.012830866692257265, 0.012712395982816817, 0.022355937586736777, 0.04099803030370705, 0.021557817611122326, 0.04430013355768977, 0.04343214444816113, 0.058272646499737624, 0.06802550502001278, 0.022763471464596452, 0.02856029599394289, 0.021044498482238383, 0.05423179316905238, 0.0346970567179303, 0.011774678508030071, 0.042795579009238756, 0.057181465334349105, 0.024943931982101455, 0.04914850484760058, 0.040970493273268786, 0.04079481782091241, 0.06578490468523195, 0.018508297376214497, 0.010009331350785591, 0.05527358464596253, 0.04269802537296088, 0.08709007032936619, 0.022043333494014317, 0.027102279371672103, 0.0641822487476372, 0.03547684612473653, 0.04665624462969361, 0.03560858643463543, 0.02673880129511799, 0.04509394620394996, 0.05563417840148172, 0.04600138501113942, 0.04720272962003947, 0.008536266846462123, 0.0054256530148127395, 0.01937909802842525, 0.015742854034948735, 0.07077915443768425, 0.06707028530898594, 0.04427721986787454, 0.014155376214353789, 0.05562853233347978, 0.02543857005695182, 0.03934562461630952, 0.027638108078991214, 0.05430114710883749, 0.05548841485212888, 0.046614768629473065, 0.06290738268064396, 0.0510123469716599, 0.017148104436214895, 0.01225955087706567, 0.015872683913086452, 0.024420027433323766, 0.12232176448789336, 0.03166923592347772, 0.05262879632233132, 0.041237279562459844, 0.034514076617215915, 0.06634352833873804, 0.06776315054946369, 0.023849659651938467, 0.028278785494847164, 0.02092043245812097, 0.06645435061786445, 0.018861050221828685, 0.030636371286105246, 0.02310565995773481, 0.02359442022298613, 0.0461881036209243, 0.00639716693718407, 0.04125332910447352, 0.03594068554981101, 0.04953913308019119, 0.08825493766175163, 0.045787998880710334, 0.02433426772064019, 0.056046130691444686, 0.01192072167947528, 0.03787653227787345, 0.0196164071695098, 0.012531796500327127, 0.02528540609825042, 0.05028006650747792, 0.0652485129032885, 0.03287500852058011, 0.06362213888355801, 0.0010658949970327799, 0.032843315463152625, 0.03923730744469551, 0.027051943564607252, 0.01297666758839642, 0.0672646954415306, 0.05599988196345587, 0.015731083093992165, 0.05357346317220119, 0.07710357797482321, 0.025571808068742676, 0.034677690015204495, 0.03594254331302739, 0.044664151726230505, 0.027159728305113894, 0.03278907260767395, 0.04880748080810712, 0.03581353410657856, 0.02978357753055471, 0.06405088765126082, 0.04122019963218801, 0.03887783217754576, 0.01477350862020807, 0.05669296170855242, 0.053484777003646865, 0.033879116132494905, 0.059765698238005566, 0.04381632605086892, 0.01505023968826619, 0.026424739720119585, 0.004669087084626118, 0.01707336489832209, 0.012840330750951845, 0.06943576563630374, 0.02145027227309202, 0.04274641531669805, 0.04615610795876673, 0.016792097632142327, 0.07928564919218903, 0.02086413457178541, 0.02443413877288901, 0.0334171153184387, 0.0890783672671645, 0.0669581147151128, 0.025844883939792073, 0.07173232103307402, 0.02571674807357692, 0.007939896125706935, 0.019991740456692154, 0.03390759928151965, 0.03382564702581975, 0.014684513143654314, 0.06729986653813431, 0.009496902799113624, 0.013500508934920354, 0.023238959256559614, 0.022773662349209193, 0.02520616579380247, 0.028288206461096005, 0.04118705866858363, 0.0067632420518014946, 0.022318627189604506, 0.07053950681321083, 0.03353980812995184, 0.051439789559451804, 0.047789024369370554, 0.022469996587343277, 0.04923540603129133, 0.0047171385132617535, 0.05766208591540495, 0.11374217728453298, 0.05601834468243103, 0.053186167422081196, 0.014648827810531423, 0.02283085655841616, 0.04251845819394916, 0.017889704359995744, 0.022981383259438222, 0.022098524383299296, 0.02727930313877521, 0.05934282153424236, 0.0409570369388788, 0.03175278738771956, 0.0313918067577986, 0.009855190629980737, 0.04581943529868319, 0.040017165799414924, 0.008820877128821469, 0.06384109830363624, 0.06737433794525362, 0.034990790149857925, 0.04083086225774981, 0.03438838840191884, 0.01879848956671213, 0.10990219986847333, 0.006941028076389264, 0.06590958549490859, 0.04133126322901057, 0.012967227469949473, 0.018106308059706804, 0.04467220331031469, 0.054502421389183695, 0.025250037734006203, 0.07438546737595912, 0.03607337197829639, 0.04982482641935349, 0.022276904126028382, 0.02189655296294199, 0.044389727540434375, 0.0529434094806352, 0.05390763838565158, 0.03737218212336302, 0.04697313306913261, 0.01612947754291517, 0.019750508945435286, 0.023203970105837912, 0.07868416291931946, 0.018440435392661922, 0.053014054278572725, 0.1061359660760049, 0.043167438087684494, 0.029205376500143643, 0.04961605596866819, 0.02598785892910054, 0.017556421638977145, 0.0898841385459227, 0.03367968429360659, 0.1759174442098987, 0.023983175370601878, 0.026703858109671744, 0.042187385636592106, 0.024999818096177715, 0.06208418290160837, 0.0254068884908432, 0.048143887787216136, 0.0295548485742221, 0.03963475769025184, 0.06028760329730088, 0.02109497026990979, 0.013000137649566658, 0.033029708485569687, 0.036982258691662745, 0.004608046156429356, 0.05973777050272592, 0.03898080971632754, 0.05279170874986918, 0.029177569423712073, 0.06292330581815013, 0.057616928862708236, 0.0416363271013383, 0.01796363375990862, 0.046945841186830116, 0.04778125623781835, 0.05152027092633709, 0.029852826133250233, 0.08643376280463512, 0.03498718187573456, 0.023283712197876266, 0.016723662997866352, 0.03733502685903542, 0.013268402488451573, 0.041269118176592935, 0.042744308574906284, 0.013743989871844891, 0.10675509535377065, 0.07161864124599003, 0.035001262571782835, 0.04179887946755175, 0.021881484013471394, 0.02182137675493235, 0.04817724708587893, 0.05221742625919081, 0.06358849613236324, 0.02679182032513763, 0.03326043501616486, 0.02498352723646789, 0.04204939021879146, 0.08396035601054469, 0.03972197680043117, 0.025314728113552256, 0.03427786872752252, 0.008706210045925072, 0.06971660580846571, 0.07580885107839301, 0.050582583137457414, 0.028827628120779995, 0.03423454262496483, 0.0142860459163785, 0.09184959074181896, 0.07472837599174631, 0.06195882027367912, 0.03992197937482307, 0.07511486734954581, 0.04668125356998175, 0.017696795759782676, 0.038493650574837966, 0.025588252146037358, 0.0945977396481941, 0.12414440257294525, 0.07774231144257131, 0.09306672825327805, 0.16242314250238482, 0.2113048687216736, 0.07625469126768651, 0.15432151755498302, 0.13033167338900029, 0.15076608817663886, 0.05987701847428276, 0.08974249654960248, 0.15937949050097697, 0.10718932931101131, 0.09012436839721857, 0.1235743105832127, 0.1609453282529308, 0.24708785507227146, 0.2278794261116174, 0.15972573159923478, 0.1295714690199783, 0.20901938329540917, 0.12567927505099966, 0.19699649134230232, 0.19914435673384898, 0.15394310076390544, 0.20430683939447328, 0.12190533441401298, 0.15366041431984595, 0.127251501976242, 0.10969920189029748, 0.18484694973355342, 0.14572383535485114, 0.15029905033448052, 0.08880821402154623, 0.22019812296475136, 0.09554888377146376, 0.15651108877312753, 0.13512992720690467, 0.12621241095926494, 0.16811932797633833, 0.17873914521788398, 0.0956298056389055, 0.15486320300448328, 0.16200263684074726, 0.11037734292087056, 0.12662281958206048, 0.07400237744854343, 0.12442514315367707, 0.15615577719384627, 0.12066759679827, 0.14961609827174296, 0.05836611305693946, 0.12698407600363418, 0.17814315945631076, 0.15598400495946407, 0.13748367106722248, 0.08173402023291396, 0.09078860493196596, 0.1311417960471684, 0.16966733120141492, 0.18902923821681933, 0.10392393315992049, 0.11427325241628195, 0.09298411333152364, 0.09000783876305626, 0.17573050343461577, 0.13421791485480725, 0.11780091110737094, 0.1526019259566261, 0.12632183129748992, 0.14890391229381486, 0.13706302750975857, 0.278283920619757, 0.14098979502675996, 0.17449152475643545, 0.09383589585101414, 0.13649766994339807, 0.13107061115724425, 0.17257009963354758, 0.1459630386483285, 0.23571904898891527, 0.12251245909400525, 0.12162533693856771, 0.15302194132199212, 0.10496599659804376, 0.10259656325703669, 0.2447686617773387, 0.21461544107765923, 0.12090561265546469, 0.12325030901739675, 0.14834336575961884, 0.21951202994152424, 0.07583766364522519, 0.08865490450613922, 0.1294936344868714, 0.09620924390131429, 0.14159209335282927, 0.2279524649343183, 0.08167870868478092, 0.1628125449942966, 0.11364380393417613, 0.1030631491073197, 0.19230146021131547, 0.07659519436739146, 0.15757858633033692, 0.2494351637940253, 0.14919568454065632, 0.09661938439333632, 0.14982658858981826, 0.10968089238890719, 0.16177892384509887, 0.12571035523808774, 0.13843748117646865, 0.1369782522200577, 0.13251991161415655, 0.14307707818525453, 0.15940828008517144, 0.09170856161583817, 0.09791579668319995, 0.11168173018602595, 0.1149892075467975, 0.2046287955055314, 0.09666084507179838, 0.15277831004031245, 0.12909528408800403, 0.154940148875598, 0.22501038086991157, 0.14677322259353054, 0.11968513500065574, 0.10266916540962073, 0.2030456594882473, 0.18496630623215632, 0.14766289582175596, 0.18308985047042373, 0.1667463298766844, 0.08203107848643296, 0.10170978584116507, 0.10806466137329418, 0.11026444454346934, 0.1344870262208485, 0.10713875218625031, 0.23029661737382415, 0.2887773639973133, 0.16890789292031722, 0.11500744810027462, 0.08536936790351907, 0.2051716760521935, 0.09132003246416008, 0.08480331319714747, 0.06595016517225774, 0.23719507059262646, 0.11840870228385734, 0.15090969901892448, 0.24743251802940525, 0.10278633855763944, 0.22841228622822995, 0.12722563118703906, 0.11167474346415651, 0.09125260140506491, 0.21502439413339863, 0.18457921732577587, 0.17637994681154529, 0.18041634151051122, 0.1293276385554383, 0.12286908068363706, 0.0954250073541076, 0.26863743340776813, 0.10755191872557325, 0.16742013484960602, 0.15142570520120283, 0.1707973415332456, 0.1525851026658089, 0.1418125734574372, 0.20116650709702125, 0.09525581683603027], [0.028302281411484848, 0.014837220322430856, 0.07343126656187159, 0.04007422785845496, 0.020355446444403742, 0.01645048945060661, 0.06926888104287848, 0.002679861265219628, 0.026718226088691625, 0.03470915324625469, 0.01804716032629292, 0.07757915003645806, 0.060078174011000705, 0.0590886335609661, 0.05005951362451719, 0.04237682768894781, 0.012510597889852381, 0.005431509756993864, 0.06134934753419892, 0.007957829765209389, 0.003971630344054692, 0.03559762371643897, 0.03629072644417325, 0.05803713958049494, 0.03151870539201604, 0.05969589230634513, 0.05107356122724953, 0.07964908130346768, 0.0601402577763844, 0.007974824947004598, 0.06511641636250481, 0.012326832549015601, 0.08324174255493187, 0.08480615538334654, 0.042977226116964896, 0.0484802961469658, 0.051637869253153765, 0.060542534375863696, 0.03502629832514832, 0.0281231930374258, 0.004184324840729636, 0.02619091053343108, 0.04538779071862659, 0.05726172453573635, 0.011966485856851984, 0.07064262990869823, 0.07398075844732023, 0.022891726074439865, 0.008289168059315172, 0.038284317049528324, 0.022340880128585046, 0.09855559501316279, 0.054133358531661575, 0.03241719054659048, 0.03129981108941138, 0.060414291257339145, 0.029166292609466665, 0.016539376717241063, 0.0702331176087741, 0.05102515596175387, 0.017988313282389316, 0.005430649344493906, 0.057807064224635406, 0.013115404196263803, 0.020270621358987786, 0.049495607794773196, 0.04224410295606621, 0.01539378319942062, 0.04059229481724962, 0.06310206860484135, 0.020977837341507117, 0.04207269461344808, 0.030600152564265078, 0.10006419067541439, 0.04308423327822839, 0.016899991540178176, 0.041259745090839364, 0.023632429675349308, 0.07120146040594386, 0.04478797451743195, 0.05264352053223599, 0.04316807011022203, 0.058323771377364476, 0.07598514323152843, 0.052108197442946896, 0.010378389420258182, 0.02288062162997742, 0.028854868292147597, 0.06480461857732266, 0.05883498184923684, 0.03870054411010877, 0.04110226422668465, 0.04149673055977591, 0.01278386241005313, 0.036600551552950375, 0.03614838347740231, 0.047083499525944074, 0.09465254557829711, 0.022780388601184375, 0.08630079292361775, 0.034396252294461575, 0.062400615518732425, 0.007933573506306857, 0.03506818801284798, 0.074096261523664, 0.0018760838499856033, 0.018749427380821398, 0.04640866799520389, 0.004529318173280767, 0.0543607832233031, 0.007893190617793271, 0.0571260541947859, 0.005721080937467877, 0.028785815041872765, 0.03611411636454925, 0.09327553317791994, 0.05956698269132645, 0.03706049925136951, 0.007726771901586965, 0.03834455837345412, 0.04791997177826782, 0.05661618820722065, 0.01553193566524574, 0.026964678489152464, 0.016131969243888895, 0.059960261588135076, 0.03042685198447397, 0.03585492583712743, 0.020612830919544065, 0.019510269518040364, 0.06860952448820876, 0.06173682714542074, 0.0876039927524905, 0.07604277602607205, 0.06477860223141409, 0.032070907313496835, 0.07790677519815584, 0.0267853181538803, 0.06454754245257185, 0.037930928350936984, 0.01629078884669129, 0.11451728972456149, 0.02756037888297391, 0.03410874715735836, 0.03136913438567952, 0.007243592108059074, 0.06501377590240971, 0.027859260425752694, 0.06249664080960136, 0.06424746964307082, 0.027253112507863875, 0.03142065954424682, 0.06924540810887853, 0.0356368780616791, 0.02074382429371678, 0.026049042541173198, 0.04389314168703653, 0.056912671894796436, 0.036928931311253584, 0.07654018925442811, 0.04586149352572618, 0.018606866078992045, 0.01863124108152284, 0.05872820834479025, 0.05779784435646669, 0.06918361545690606, 0.05660221093304216, 0.015892947896293575, 0.04860219222703769, 0.03710646069638672, 0.03836828411646909, 0.04581373560452654, 0.04492950926144277, 0.01366504834168741, 0.026979295446747736, 0.11180393653170717, 0.031287561343502135, 0.04377980280907885, 0.006763585833757515, 0.045466257274271026, 0.007507015271262536, 0.0428788987318835, 0.10506793225724852, 0.007678707066412656, 0.03202321834021038, 0.015123418322013272, 0.009694902053583533, 0.0332434929817194, 0.043427896490620996, 0.0791457232328192, 0.009125611583341756, 0.03732216424278675, 0.08186695180953511, 0.03122168735811307, 0.01874715593012591, 0.01293659735951693, 0.03643247952324249, 0.025457980809733275, 0.04594125476996264, 0.10656315202434218, 0.005536871744439968, 0.03680996934793169, 0.017979970584893902, 0.11232184261203775, 0.049416815651760954, 0.0232258208486582, 0.0330546599692635, 0.048444554314858494, 0.049752515380180655, 0.04578314571371002, 0.07644050589372074, 0.08065755944699049, 0.034121395268988226, 0.07800219144912497, 0.05348427138561684, 0.020756696486064506, 0.05140622341704946, 0.020068356909999446, 0.012214927213086237, 0.017366205837817925, 0.012972250133903037, 0.043402201901640625, 0.01558088293794783, 0.022395728193523905, 0.06508670747280121, 0.03253212288743065, 0.03616727903605469, 0.09219304328003237, 0.023371844867905302, 0.05931541090831161, 0.051971967857811725, 0.05612500327368898, 0.061714491851988344, 0.04722097783439583, 0.058967200964088404, 0.028123091530775832, 0.00799931582033394, 0.05115215418740146, 0.031783821609532165, 0.04012197045789611, 0.07212988236137936, 0.03472174007085062, 0.03580093579066377, 0.09157884760849899, 0.03306579888768254, 0.04034551108376153, 0.023428671354908618, 0.04327479381895354, 0.055504330328755805, 0.08041608087237805, 0.03104571504668603, 0.033530707005411386, 0.04266893318403633, 0.10142372094935949, 0.06155755107982024, 0.007549836234595146, 0.04228785806786149, 0.022567186331857118, 0.04055418194301667, 0.006575592645188614, 0.03650159980621069, 0.0438392129276068, 0.07591252575718588, 0.011662545260943232, 0.022148923392617897, 0.037150610343463, 0.01370518847608999, 0.026009290238782286, 0.011197624694285615, 0.04139561078421051, 0.08386395150615324, 0.04728416093595086, 0.019960842215486115, 0.036709910604141416, 0.011103009005197355, 0.053116736873503656, 0.012655061962563666, 0.06618317081442764, 0.00460574358341194, 0.06063082983957664, 0.023588529006848415, 0.0224388417066826, 0.033976547194704894, 0.05743605167334599, 0.02970926891711931, 0.04199924976414731, 0.012151063250888501, 0.06734425367246713, 0.03520079783254093, 0.03241113845198866, 0.032756391296824144, 0.059038424158408764, 0.009541535081582205, 0.05109088247521751, 0.02472183160153368, 0.09479343680845154, 0.035466718442377546, 0.11162150801429827, 0.024336278701441425, 0.019769423656285773, 0.04140553162282994, 0.014721288236849492, 0.01522446244639615, 0.02633800324533255, 0.03694245659355675, 0.03384834621101618, 0.0637142188216169, 0.04177512691145943, 0.04617047210734698, 0.06858553827529953, 0.050289259562569286, 0.009860962144880286, 0.014913020892098788, 0.007574620615360478, 0.03399384929047477, 0.02556400546323388, 0.05007706086842283, 0.047145311330114646, 0.05331946289046638, 0.0646787733140011, 0.04673337436191017, 0.020404265397378517, 0.06422453680105748, 0.020971934634050535, 0.011328212041858465, 0.060623268551764, 0.04480358738932879, 0.01692367897879693, 0.027776498032072862, 0.04213549467104097, 0.03836230480022008, 0.0550034735351801, 0.010225763638323594, 0.033751179449140065, 0.03136814230181758, 0.06285558364564373, 0.036835181301519755, 0.022924120102318066, 0.02381972668151702, 0.0464414757105612, 0.05840031888275858, 0.023142771172006766, 0.06075305533745597, 0.056432710149355476, 0.036066228208402475, 0.03204001864838985, 0.064282008717137, 0.05866548106555016, 0.027237361740140666, 0.02757865774084724, 0.016774694029722485, 0.014940297452642795, 0.1221153267749375, 0.1677452165993952, 0.1323915459215641, 0.09398139893047272, 0.14361625086636315, 0.11458474376629438, 0.1886835640236255, 0.08601113507944731, 0.15378660432273342, 0.11632616120961406, 0.07942741376257713, 0.18166670425524636, 0.17975692366880758, 0.18413099460303786, 0.14952686435032278, 0.1483388151973486, 0.10881187289112038, 0.127178555084092, 0.06088653466694298, 0.14833238005878466, 0.08787451372031244, 0.08900838513528148, 0.07571066925001722, 0.14742618997491178, 0.17511083023442378, 0.08829086718540038, 0.09327414655877699, 0.2174215292137477, 0.14629423377975342, 0.11915788264764894, 0.1650166872047609, 0.17532116733491424, 0.17301125902562373, 0.1455149997866923, 0.15895981221429764, 0.18489384963627786, 0.18132823128854075, 0.16856606448850325, 0.130408113642085, 0.11351787440118291, 0.14827006646702368, 0.08343959242225656, 0.11743954743348783, 0.09543411613952729, 0.07772175730356286, 0.15311089945175957, 0.18624346673248277, 0.10650188797303747, 0.1296916528935394, 0.08760665107758776, 0.17116227517685584, 0.18055639770482818, 0.11912261962049431, 0.13061489609460677, 0.12569474236619088, 0.16469433272798217, 0.13741783347100983, 0.21127221805434074, 0.17994561112455784, 0.1566204861287148, 0.17137523229804733, 0.11907349806278945, 0.1599227847351182, 0.09530883012039047, 0.12700977825349377, 0.10695429353584206, 0.0864679073434203, 0.10093184653669597, 0.12620711729170817, 0.21249610480041276, 0.14373677181861094, 0.14747998466895473, 0.23373337973269726, 0.31843618219417913, 0.18505327253332063, 0.1777624750449773, 0.14350274727950174, 0.21843337814413735, 0.14346404451756709, 0.0871130146626984, 0.23642308379132904, 0.1522158636080642, 0.11728325783605538, 0.2682869635041683, 0.0862839772936798, 0.13034360903886058, 0.16440858193222554, 0.12015457835889633, 0.11358805571592624, 0.15912560896287042, 0.06674784656253553, 0.14825454552567777, 0.13790629113153105, 0.11941016306199374, 0.20448172194582803, 0.1698288838228872, 0.20176027120361406, 0.16702449640199063, 0.16031008814611744, 0.17618611124494385, 0.1943715370350307, 0.16696910824506514, 0.09085566826885746, 0.10144685680467276, 0.17971082049752438, 0.13234996266903418, 0.14644305401992413, 0.1837625369549759, 0.1023918952071859, 0.16529376588521466, 0.12531048032425104, 0.17791572327335037, 0.17636689267331557, 0.11762536205952207, 0.11357203681742954, 0.14412828871319372, 0.11993785208511738, 0.07480385863492567, 0.09365164404434544, 0.2230696043660564, 0.16962692772428836, 0.18752317064471785, 0.1165038706254094, 0.10854357357827887, 0.10869026409402009, 0.18563563725160015, 0.12912456396847002, 0.13495182708626793, 0.08563042002459688, 0.1337642835513238, 0.12139420055093304, 0.17112873584753083, 0.18658368637965572, 0.20857538937801318, 0.1954511694249607, 0.08360203370572099, 0.1215023798267207, 0.12287556178747647, 0.13139434459228672, 0.12278250508731413, 0.13837262417279905, 0.16127148252581397, 0.1567847660231975, 0.1733041804043516, 0.13546990170594186, 0.09698666226599487, 0.094550724832281, 0.12514305180839955, 0.12471127699339583, 0.1705971627586311, 0.1904173282485816, 0.08822577269447428, 0.18243414049427356, 0.08088887203484774, 0.1022576842637312, 0.19921480617936582, 0.09875478553435496, 0.1566828610075097, 0.1495936825390785, 0.19842146084673945, 0.10905047097513754, 0.1068108359111413, 0.06790429458863313, 0.17631453822457022, 0.24298358498321426, 0.19288946333671772, 0.1387993351466233, 0.14058838027619547, 0.14405030096250196, 0.15434128262342947, 0.13579869132128455, 0.16565782618859123, 0.10335463790162917, 0.12707334822945057, 0.15885720239771953, 0.2884408368939354], [0.04564778946880852, 0.02835770978802635, 0.06177052735320984, 0.022183811036689628, 0.015045825106602524, 0.021407195149109732, 0.054663633101529656, 0.10548567234147942, 0.021078972438831004, 0.04726318544858406, 0.03094390770720859, 0.011658801963823217, 0.0394714928622688, 0.042120352943217566, 0.03955326125686688, 0.04360990749011117, 0.019029321434396892, 0.038929006850887696, 0.016755712286178625, 0.016487286568829612, 0.06623630667285574, 0.015425347937120786, 0.02842512169492341, 0.0681075836802202, 0.051743045464278235, 0.04709866040596559, 0.013692733801661, 0.038761720061302185, 0.04067998507150239, 0.09895796737363262, 0.053499562500585476, 0.01211159248580976, 0.03128695421882215, 0.04950674671319224, 0.05911751507571148, 0.02827715564278826, 0.0743744740142457, 0.02717891689239731, 0.0660471978687471, 0.08105215601502888, 0.06926929473035759, 0.06835365112149908, 0.050171412257177216, 0.03887535005267109, 0.018266966273527474, 0.031210016008586656, 0.05694738333864559, 0.04791124220637064, 0.03530231214338734, 0.0286845228965244, 0.041229802544318864, 0.09484121005140966, 0.05637349538324822, 0.050016605039878245, 0.040227767200239246, 0.03334976852901521, 0.03806496692460872, 0.06510792044742454, 0.02235599695855091, 0.03757910247171118, 0.0670823588546726, 0.019304661095262538, 0.0326178059913218, 0.02168481583676992, 0.027421508209719777, 0.049809236530094385, 0.0694699254968474, 0.0987635802237257, 0.06026795697248271, 0.027800878780263088, 0.051735319467561866, 0.03380234263116314, 0.057197162475917614, 0.028432104586353226, 0.04809113114231056, 0.02160281761579456, 0.026970692279358065, 0.03060879403605096, 0.05824047080691784, 0.024840527349301887, 0.10465142557457571, 0.058755864118856777, 0.04840033571986903, 0.03285487956036964, 0.07093137610823878, 0.010294475021862216, 0.04697659195611074, 0.03942181972125846, 0.04860977266704844, 0.05210228707461108, 0.0350762089534152, 0.041708370009737636, 0.043315116856848045, 0.020036813239717198, 0.06501682493234835, 0.0659593735491076, 0.03646947390910599, 0.015178997043309914, 0.05549445928585145, 0.025978648637030876, 0.03994498882562884, 0.049238294182765874, 0.03370753925053343, 0.03607341794357185, 0.03889672007531889, 0.049828503641390035, 0.05466287850492424, 0.04692201968282462, 0.034443945098187656, 0.034293060251061, 0.0383347830915403, 0.006435829000697742, 0.04132457911187122, 0.027505383346109625, 0.01098357781302184, 0.02676260173170557, 0.03758260349352514, 0.03502186267606674, 0.02284945334277807, 0.05566163882312756, 0.04096334567293525, 0.04841546595637356, 0.06395290500574535, 0.08186112188043133, 0.05563590209931136, 0.055264322642957976, 0.05903080158356217, 0.058705773459927696, 0.05023480603291143, 0.015379158580946106, 0.025195823606824683, 0.04661738098929486, 0.030939772747637286, 0.03255403300206507, 0.05173924183773418, 0.10229476291926638, 0.04663919151249913, 0.03278159941997259, 0.050893959574281215, 0.021951954526406144, 0.062453919916503856, 0.016533537212038235, 0.07401762259823662, 0.03799284740741696, 0.04290020363705774, 0.0408914253386038, 0.038952885811487516, 0.04016325493613559, 0.012792489517690435, 0.013988694634228466, 0.09638926690264095, 0.017752270101599636, 0.07290354689523097, 0.06192589381469354, 0.0061336408309157825, 0.019067168093076157, 0.04484050899683949, 0.030483977245767752, 0.012815365860719356, 0.06832833191560161, 0.07507939747865162, 0.03822767250840703, 0.029897883594516787, 0.03907808373051305, 0.01537174093461926, 0.05200913461345819, 0.053984791100505865, 0.04956129600384063, 0.043133642118904865, 0.0656662529875194, 0.021788969320515474, 0.023617521604342807, 0.11314977681444538, 0.046554538796866135, 0.035442421963858994, 0.07250523480075984, 0.02208539938193656, 0.06637168973083458, 0.022484942962745988, 0.05372915522105271, 0.025742572897504416, 0.07736482927876134, 0.05134556074476531, 0.0290048836294802, 0.03127572911551162, 0.054982134156049266, 0.09720629201300683, 0.039047375096068274, 0.05651613712430962, 0.028188831450778152, 0.03921450100718968, 0.03814241075287423, 0.015763339226043994, 0.02219485036367851, 0.006065758737555195, 0.01785998206375347, 0.040554415599833575, 0.06543380658953421, 0.08652645178259381, 0.022737510660062396, 0.017146355840527726, 0.04084821031879514, 0.025656336295087973, 0.061348650394187826, 0.0430782922663756, 0.03289108870611076, 0.01085229811348742, 0.07252201212630158, 0.02745801038409193, 0.05917584117982657, 0.02315209637726507, 0.04512458206004193, 0.024662383178609516, 0.04789246156090691, 0.04927543795577461, 0.06526524426355478, 0.04348473638416298, 0.0275046632234608, 0.034634586078144854, 0.03182194405986417, 0.04170235238909241, 0.020647846883343115, 0.009209984676882384, 0.007401454100956119, 0.0696505077423588, 0.04719232231558812, 0.06468651080203634, 0.044968683167450854, 0.05708316859278468, 0.05488263082600409, 0.05221601665741014, 0.022866730540690404, 0.046017840579752965, 0.050995500698204965, 0.06416383582437712, 0.023849594534464905, 0.040549937815916155, 0.022743629787357587, 0.060115509305990515, 0.015032336213475755, 0.022164296862038396, 0.029251215371092962, 0.021847973412443555, 0.05929433965995427, 0.06758252999955608, 0.01808605077976902, 0.010602379165169214, 0.04263914385510068, 0.08406585397859735, 0.04740856212353514, 0.018792661552828167, 0.02250381745398045, 0.009917893011363284, 0.013273389720838639, 0.024967062091755293, 0.042006688477892073, 0.11638693496464722, 0.08485905375451812, 0.03416561769441732, 0.023542014063305916, 0.0191094312486389, 0.007702720571204179, 0.05826338066629345, 0.023515040107492, 0.02176142462919797, 0.07731696410525231, 0.008570427664615696, 0.021610363581848722, 0.04682934985706403, 0.028647905808963606, 0.040006731681886225, 0.03486425923784414, 0.01278380495345881, 0.07484409357270888, 0.031682244096432007, 0.038109116571685, 0.013725643981278185, 0.06199728554835724, 0.012242572453443804, 0.031022198062630433, 0.035296290692302494, 0.09452840869104671, 0.03637051450148706, 0.011878372339021054, 0.01942332045385434, 0.08534181938176194, 0.012514002193065902, 0.042449031475811236, 0.014205893967300655, 0.004269273457823381, 0.03719292904040025, 0.05291365462565615, 0.07243918269992837, 0.05127329184042831, 0.04623850454546271, 0.019535077360248374, 0.010447145811462355, 0.05323589418924624, 0.0516411864138659, 0.04061819624996955, 0.017532134736557643, 0.06286173150123608, 0.08769262146445052, 0.023045068148583658, 0.03864079691289413, 0.03610950068480546, 0.04171755540394976, 0.017471180950862267, 0.04271246229989394, 0.039934765382279316, 0.031103275062876846, 0.06390183758471282, 0.02551956278752656, 0.025081368155717373, 0.025402397300387104, 0.012994660120908053, 0.0841263366202193, 0.017832672944472685, 0.06329949329336805, 0.04328662221650443, 0.05066060919254538, 0.06384545351348578, 0.07556645319827142, 0.05042904762611274, 0.00515152425167241, 0.03490942012098047, 0.07552978823021536, 0.01733063446027377, 0.04489989613272971, 0.03755350747416097, 0.02916562802819235, 0.0768005212528571, 0.035968084684422905, 0.06623698849110835, 0.02367064788667185, 0.02927898797356794, 0.0381445711208207, 0.0354543078180042, 0.023591677628217206, 0.023695241224261063, 0.05439405059141498, 0.04774025138167124, 0.03208013675776461, 0.06274782954865406, 0.040326083094001784, 0.0755592366500247, 0.07164777556975042, 0.03518950952697666, 0.0844471972255457, 0.042522066468072515, 0.11030998847056782, 0.014437821340717137, 0.09032869170750342, 0.1290035220764337, 0.22415496709366, 0.11338811442856828, 0.09639813053992488, 0.15332733461212728, 0.14734287025226703, 0.17582627974690931, 0.13029425765477842, 0.12276044941597408, 0.14308188921741902, 0.15998318310706847, 0.156111344094238, 0.2551543778709827, 0.09582433834551804, 0.11931064824062972, 0.13911588267693598, 0.12454517380965334, 0.052763532036014145, 0.11094189609491056, 0.1259325973449215, 0.13629718473361385, 0.16983076839918093, 0.06284477414503213, 0.1408838297450735, 0.140440356767466, 0.09818045707840113, 0.23392268005878697, 0.13354270028010493, 0.13463740928038476, 0.15757178346956932, 0.11889951183430611, 0.12413085047756472, 0.19836642509025915, 0.11513006047255571, 0.07699414231483975, 0.11496617128291439, 0.11741613578652182, 0.21839461409516875, 0.13922206246324126, 0.13462038680670724, 0.1522973140761737, 0.11495909263049403, 0.15051930061271115, 0.1479033708211876, 0.07856017158877465, 0.1494589123514391, 0.14867178765275788, 0.17190979312985175, 0.17693323083221915, 0.10735382371011282, 0.16524450643168342, 0.13255892081126092, 0.12990384392680662, 0.1273927302850831, 0.13028979902305912, 0.2064967936565799, 0.13921041792679217, 0.11898553584732356, 0.1850790590528519, 0.10680277666617786, 0.13038241905310463, 0.16651618174247204, 0.11742545141568107, 0.0835535326792348, 0.13510893639777938, 0.1498990605074552, 0.2630506299676434, 0.1314240534819903, 0.10788512866823904, 0.2848644013847074, 0.16493293847287857, 0.23275658698572269, 0.18130975324780713, 0.1583369061230652, 0.061335672864750515, 0.10302500558956977, 0.07014940718128797, 0.10367864712832436, 0.13945300732889485, 0.1258607229758655, 0.22532225526388616, 0.14437267076103918, 0.14483296702946388, 0.1412302700261916, 0.12313539582875468, 0.17225948162376883, 0.19608668532342682, 0.14744581714753183, 0.1604760074687581, 0.1317668931498643, 0.0908171417071454, 0.13351262366819766, 0.22037614647659565, 0.1962135188401707, 0.12865414001768635, 0.14476487713475383, 0.11093638026185575, 0.09956588878506616, 0.11350954702544598, 0.10181713774199448, 0.1113675345456408, 0.1712920045059535, 0.1019189048618559, 0.18675682225054313, 0.1613671822293151, 0.13191940593383006, 0.06933730801627522, 0.09036226168034539, 0.17669367513829665, 0.1424750096855625, 0.14898504100499615, 0.10809585647357088, 0.11198606627482562, 0.1126230454012271, 0.12344100362350865, 0.12091719590487982, 0.16185591568148908, 0.13441697514105228, 0.13532327247723458, 0.18816443220261606, 0.27459526855138044, 0.18931446807278743, 0.2083446130517029, 0.1580899959850696, 0.1482381052788227, 0.12498294709310417, 0.1811599677368518, 0.12253675940296344, 0.13696355865367, 0.1773340480342027, 0.13490314985955917, 0.15986692160367966, 0.14946894810324715, 0.15369859614199208, 0.14779185906292933, 0.13842494797802743, 0.13712635233757958, 0.1078583462344062, 0.12366621815148862, 0.12085756362085381, 0.08553213860479095, 0.16189737635995113, 0.1660595626960839, 0.11955137604907637, 0.24110542850628977, 0.11819954495877029, 0.1289761880592954, 0.1283152610243809, 0.13214659696865466, 0.18937791547467633, 0.16578482824467844, 0.13562811418406426, 0.11115526690358117, 0.13972780306733426, 0.1041917498373697, 0.21354941440926445, 0.18076641304839045, 0.07748864440908355, 0.14691949942179267, 0.26597279574601884, 0.19627117461735205, 0.1449591110670759, 0.27202139698689987, 0.13296652555225358, 0.11775853112339975, 0.2311023273655484, 0.10198568474621543, 0.09028397515536317, 0.20966919439454235, 0.19195183300443236, 0.08842632685217167, 0.17201220376356957, 0.12091398599647707, 0.16821490510577158, 0.17668439015265436], [0.07647898649015734, 0.06633366878715254, 0.02833897510783807, 0.04668206179274186, 0.025841662540070476, 0.0460734892065727, 0.0459839680021809, 0.02640581926360967, 0.03998558382473646, 0.029935389344069748, 0.020095346187571847, 0.008200606380048539, 0.05958631875053529, 0.03290345336520865, 0.02261633470263933, 0.004010614403899038, 0.005889299481491288, 0.04219738308400397, 0.05657378141017211, 0.006122595279462516, 0.035664530005306005, 0.025958998481773084, 0.039558252319693565, 0.03390736945514237, 0.0353455999415488, 0.014037487731735795, 0.029869934791819226, 0.05664287871050258, 0.10309147903875959, 0.031391237937514825, 0.04847857244913617, 0.059353849369912386, 0.042393156853053844, 0.049960021785790884, 0.028192343963910977, 0.07124862077856256, 0.04604640033757014, 0.058577373293378664, 0.013041912424077672, 0.023166933585138574, 0.018218453755722414, 0.164390548222488, 0.052159103985515334, 0.07791064394217345, 0.04154471830735284, 0.060646101802347176, 0.01795279170056024, 0.030263531615116426, 0.02337406843810553, 0.019300972381907127, 0.01682925098125012, 0.04811095366735132, 0.047698262102541425, 0.03588322512505036, 0.02211146169312058, 0.024091946449311032, 0.02453858145482598, 0.061804970666285486, 0.048331966203066616, 0.05420126073483018, 0.044413801853454886, 0.08282926549474079, 0.0255951680047738, 0.050529328535401055, 0.00772318613129638, 0.00549589992583459, 0.0610507111395559, 0.021306314776020668, 0.021443369820894256, 0.054475539363920696, 0.03582260841804166, 0.03465078117686414, 0.03900340547965419, 0.13326341526642924, 0.05335860998339711, 0.058886079913786346, 0.08121327962726355, 0.0421537007505615, 0.02934696870074878, 0.06268962984904647, 0.05935130978844339, 0.030882272103260604, 0.05758750725597624, 0.04180820275759024, 0.039345911899281126, 0.020677546196947658, 0.00869104725068375, 0.050054449783337694, 0.007742538948678562, 0.027431833159719265, 0.04570120111888936, 0.02760010054184785, 0.03501305266493752, 0.05646911847795691, 0.05664301660632896, 0.02042949075750526, 0.06338990315975201, 0.05598619197224898, 0.04463256592111242, 0.033326908465354674, 0.048330158235565315, 0.02440223312606254, 0.05498527894697844, 0.031091672661263618, 0.04011005396023393, 0.09993757166328932, 0.009861633429423937, 0.028291450843455333, 0.09522884288021634, 0.018822322562036496, 0.08953092604755394, 0.04274500571491738, 0.05309445520622596, 0.01967909039869424, 0.025538839474921266, 0.0557520448590719, 0.014543135447667973, 0.02946922101170546, 0.028895668219774965, 0.06917166448528729, 0.013534283836282069, 0.03468318286562159, 0.032773046048298, 0.02860047539035159, 0.02746429038985122, 0.044393937193578294, 0.02436830692233578, 0.019142302166249965, 0.07899785294167458, 0.006027900108752112, 0.005434560223347358, 0.013494274894436522, 0.062106851443287835, 0.04457112566958513, 0.042125041401314164, 0.06329670090288406, 0.010609787235397005, 0.08002582036199109, 0.04597299379266558, 0.020006799830063697, 0.03640974586408946, 0.06559787964027736, 0.03136478492148942, 0.025465063292593248, 0.023659332768030228, 0.07143018361661704, 0.014228115305154315, 0.026300294482479655, 0.04667813942256955, 0.05036477284926561, 0.06440770842375294, 0.04146645476500835, 0.05964565226027082, 0.02061448758468032, 0.055720003231638865, 0.043274004748391534, 0.050835330865436026, 0.03933283860885328, 0.06212300057673167, 0.06708648040770523, 0.04812958492566982, 0.040341707457217484, 0.051228874062578526, 0.02693855872137412, 0.031077402358454083, 0.038151324185873234, 0.046759237490233876, 0.023320633805386966, 0.029281449031024694, 0.03883296240782065, 0.02636719694090707, 0.09277576039875708, 0.05592077955483429, 0.04538851467171504, 0.01564715624666743, 0.03188200918356738, 0.05602374560229721, 0.07774389724457458, 0.019898605232517567, 0.02947121667074821, 0.039091007633795666, 0.021387207915165254, 0.022527100781219143, 0.03628974968206979, 0.03183149909149976, 0.07490739541789217, 0.0058485220576966965, 0.028981690317572608, 0.042661199526440714, 0.008107620543019186, 0.0350386783060047, 0.08010589187183688, 0.05952138513807328, 0.03856745931590277, 0.019927331614458275, 0.013041940194764927, 0.03221340732829225, 0.03405341262658758, 0.030496184856841163, 0.020115421521627617, 0.08110536082137017, 0.023910261037188674, 0.03192400803879625, 0.03881318584805535, 0.042442818502745325, 0.05472018954253966, 0.024569562050483884, 0.06694371226213633, 0.06917444538445243, 0.04320986020649153, 0.01603698200215736, 0.0316569900080081, 0.058605209098107396, 0.07560660386638296, 0.026840242827611587, 0.011804197790972408, 0.03648949944744668, 0.07911296531317696, 0.042721019502008156, 0.06296143018370194, 0.023157139151026646, 0.0331896408310821, 0.030763082228781238, 0.04242676129985241, 0.06203077508196716, 0.035861341823493285, 0.05148193971704572, 0.0635075551127234, 0.05671555364143945, 0.03535233385440323, 0.026003824201442545, 0.038686984353849006, 0.06469453174260355, 0.056853369028577884, 0.03411744225529894, 0.005697689400309878, 0.0169961930312697, 0.009930748924342616, 0.029005994456970406, 0.06939807411042914, 0.03422844073464794, 0.016925306915636026, 0.018596625398664225, 0.01984848967573095, 0.06978256597874627, 0.02577402463723575, 0.08824912305440634, 0.020229710348611398, 0.031001984832748294, 0.03175655654030702, 0.10397250313431987, 0.018850215823359547, 0.10961621158546019, 0.022350383449285742, 0.06501422023340579, 0.025957339901417017, 0.01078260039174629, 0.05669208453787912, 0.016897553465359153, 0.06931162108817408, 0.0718891162485365, 0.030854608668314836, 0.10572412486879096, 0.058087490709318276, 0.06893185598234977, 0.049434799565783435, 0.04662260953937808, 0.04178863687200412, 0.0483760622239882, 0.025429129938504873, 0.03475303476255748, 0.028454773128032688, 0.0733168513303803, 0.06200673907334286, 0.013461111905804325, 0.01130933850823391, 0.009615494167402146, 0.010516978556200141, 0.008848489810442253, 0.04103317841767304, 0.006484317578255169, 0.04535213315619096, 0.019471538027808554, 0.08094258245921905, 0.022246997968684283, 0.13884370695919762, 0.051939336342677, 0.01943649525093215, 0.04505745360567685, 0.02307146370801474, 0.023922369056831927, 0.067570916106624, 0.0901565517509176, 0.039533216566328085, 0.04037745695020403, 0.027991529336319338, 0.031784694949765845, 0.01104234346008349, 0.011011558216846278, 0.0409466372953067, 0.05038531549695519, 0.08206711526239112, 0.019982938106442173, 0.05614791696350421, 0.05315820904328458, 0.052700460017208135, 0.10179787063069883, 0.08031974531589978, 0.03824268017084368, 0.025006159388970946, 0.06460600262207371, 0.017392909747638532, 0.011455805900867188, 0.059355657337413686, 0.044491747469310804, 0.027617155574262146, 0.10934207468263565, 0.016574710607528687, 0.06634129902287837, 0.03541691506642007, 0.022609652500719796, 0.02046139257389211, 0.03798273504681645, 0.026034444735776034, 0.07667078426288021, 0.07595518153280982, 0.03520133026364831, 0.05910691624927906, 0.07175390939078025, 0.034656607275528294, 0.05859107860634404, 0.04514170029470998, 0.08055843533046785, 0.06767543348213358, 0.019522513518290176, 0.028529326889603853, 0.05054729712766506, 0.056210839595164985, 0.02702175203951136, 0.11152322659449232, 0.016351231268697208, 0.05724076820056766, 0.027303779647955974, 0.08092454108860224, 0.07470385351729009, 0.041346140656500094, 0.07106184854262299, 0.038957631726178436, 0.04392779567429135, 0.016717402144305168, 0.029402588599271355, 0.034222009426523606, 0.1478927221990401, 0.16759737695176757, 0.10333655822661617, 0.10806315218008335, 0.17577458413377886, 0.13979272135803777, 0.10785504439545256, 0.1369147588528933, 0.13773292543426638, 0.15731512869317688, 0.11505565035247034, 0.09105365603200852, 0.15452954106994216, 0.14954019428020524, 0.1654374686580512, 0.19008326794831984, 0.15959733526312536, 0.08122469433733533, 0.16755363333129114, 0.17058936398356192, 0.1313090636845558, 0.11670208055405848, 0.1173234391476839, 0.08489921974438815, 0.17515362390587408, 0.12825650208058859, 0.08412832078794319, 0.11268519045364474, 0.16842390921327377, 0.13211898715986362, 0.12147740536038915, 0.17946679085012407, 0.1337477666956763, 0.09704487728736094, 0.1383477569587769, 0.1424581863947453, 0.10789632887369204, 0.20952258048759353, 0.10775161486479545, 0.07563023767884701, 0.11878654450899172, 0.20254738058053678, 0.09027518046599242, 0.1958774820330643, 0.11620497376087213, 0.2631994042425387, 0.13258093817820474, 0.175789859926989, 0.15528816729784012, 0.17864189801677582, 0.13075824646699813, 0.15910195216776865, 0.15782494488502705, 0.1160442331925996, 0.08074435720881147, 0.15557767192442573, 0.13410998838803462, 0.1577159305734019, 0.17700738814328948, 0.10152895078663865, 0.14649338599654937, 0.14159384003329661, 0.12619464538030087, 0.1098945160065928, 0.09960916509190876, 0.1452817260137489, 0.15964104824008482, 0.17467206103667138, 0.142409555133312, 0.17986403808238047, 0.12388287547735438, 0.16465475662581383, 0.09931633564373178, 0.19958490325558573, 0.18060095337850435, 0.1203339042202119, 0.17029717804924135, 0.13286200051586475, 0.17740310319969732, 0.14501557174709537, 0.14574462698111612, 0.13810424825116513, 0.12200908570159828, 0.1534264510677707, 0.13686765976730855, 0.19891365701633118, 0.24815547520354872, 0.1277395459492841, 0.2163558549457981, 0.14847091939901153, 0.0862949476727555, 0.07192401155348747, 0.09481740003872303, 0.10321692593636052, 0.20315069014266615, 0.1207474384817385, 0.16322287700829968, 0.1654780253527626, 0.1482924975214466, 0.17375202008312748, 0.2847032777724728, 0.15527165044219265, 0.14326732846037035, 0.12446812068622921, 0.12499639193617529, 0.16337641635008399, 0.1177632655467718, 0.20464358100247002, 0.18977772144059982, 0.164230297950487, 0.1496490553742455, 0.10821738866187873, 0.09549167232527848, 0.16319664615777232, 0.12355381773123819, 0.1881815466068445, 0.14775825844657037, 0.13153207187931384, 0.14031721579451717, 0.21453812748434084, 0.114827647264446, 0.12939107063556873, 0.14084108203889864, 0.08249613982174667, 0.16686478239153663, 0.2781312852617233, 0.11017779999923323, 0.12413699450271747, 0.23712652104516185, 0.15270899440492355, 0.14950385106907738, 0.12050449667919068, 0.11418981778044855, 0.09641128426958477, 0.19713935141842212, 0.17808394085976387, 0.07639961212032265, 0.12799411696652252, 0.14956953544770518, 0.15195568482722008, 0.11593996862610502, 0.1293009174086394, 0.1937097443207618, 0.14727652703802432, 0.07888345303194177, 0.08364977630516214, 0.10159062852542247, 0.09366204751835716, 0.09890601129060793, 0.1280928197346868, 0.16280086981433053, 0.1290508203448788, 0.15983615551264058, 0.11622802534651373, 0.20701325949161284, 0.10269831505513961, 0.16598027259592088, 0.23498872204894022, 0.12398715536560743, 0.16307157464325428, 0.17120836302638057, 0.12456611099262392, 0.16343802514095462, 0.17503966066625812, 0.11784963429935517, 0.1449896779752547, 0.17656616746417939, 0.1380359285300778, 0.19315701188339343, 0.2374778336454784, 0.13507129083718025, 0.1336259893592327, 0.1292536651054698, 0.1553369517768583, 0.09953643270437756, 0.09026224890183057], [0.007203928384584405, 0.03709198163461782, 0.05744713313517071, 0.04530030347767376, 0.052431053707316044, 0.07100089858736723, 0.034279496664361614, 0.06695207794226947, 0.0646299122261905, 0.04642375226643297, 0.02395506377422041, 0.03752734174110717, 0.022130309371277693, 0.10985318556307785, 0.05642905974039628, 0.03287929095207684, 0.08443929119816712, 0.020520980807862455, 0.023842791673697294, 0.06028825830247614, 0.025774304259328112, 0.054861911978091926, 0.017528886523758693, 0.03139058101711975, 0.041619986445913394, 0.01953602156361505, 0.07439911140189057, 0.06019837703675993, 0.04037227053495665, 0.01514941743094354, 0.07086664167863709, 0.009780643571678911, 0.03854703541184145, 0.0767127505593723, 0.02792789041244936, 0.03900720527575862, 0.0178061701327322, 0.05370865087775935, 0.0516272091396874, 0.017337389440546115, 0.04864154233326835, 0.028763138839314063, 0.03086259896536508, 0.019965385116877097, 0.0318944332144794, 0.03572235815227032, 0.014628927719088332, 0.08871189378682645, 0.044156059232209964, 0.030413050910518057, 0.02620281745499421, 0.01798329732170509, 0.036713813822115623, 0.0037211751341894874, 0.055417911780457345, 0.09055579081177713, 0.021246764846446536, 0.06616761922956475, 0.058843922095313195, 0.019015487801704197, 0.03317211656981418, 0.031205854235938003, 0.015246568871061168, 0.07101996651580257, 0.06535805581558136, 0.052825064218092355, 0.045107184203281525, 0.05294350141118612, 0.024410775006418268, 0.05027690639479026, 0.05449498267543893, 0.04132574739595575, 0.03135372261186281, 0.02232351866100104, 0.06002487344366889, 0.039891209453344345, 0.04684982355684043, 0.010105191932750807, 0.06130595631416767, 0.061602290614598224, 0.06861424358982234, 0.05147447035978398, 0.03828610586483152, 0.0695724204002369, 0.04245932386707395, 0.024577100355658802, 0.03978057486575939, 0.04768183334700523, 0.036607783422955585, 0.03694157942288345, 0.04272657363945919, 0.06564373000254554, 0.08221356062999657, 0.02463134512635729, 0.034914395862048676, 0.038183882922655156, 0.007980282844660144, 0.029027517697203065, 0.039406371558265346, 0.10480134132047815, 0.06588641899607836, 0.047705984268818176, 0.08417088463301621, 0.020849337583527933, 0.02824746399006296, 0.06132384063676, 0.04215411826848023, 0.0432325134264125, 0.021264515103652112, 0.057668697254191485, 0.06260355604031394, 0.030833211832589684, 0.0681744325124929, 0.02202269125489458, 0.054321597825976155, 0.031186851424976226, 0.01268647252506907, 0.06714836499022861, 0.06029799911043337, 0.059371086348208695, 0.058467493302399115, 0.007666803017679242, 0.04274033257857927, 0.0347929134694559, 0.01899994770816017, 0.1005148648795101, 0.07331310516043056, 0.07252859282157115, 0.040509859926157424, 0.03723216423344228, 0.11953809974534858, 0.0210161704660183, 0.00969871334100683, 0.05760275623610905, 0.0637522129522216, 0.02862576778317171, 0.022763710867072788, 0.017167469223720894, 0.033096790974659306, 0.04702206693529602, 0.056498413680181395, 0.011847862887436585, 0.042956449812458414, 0.017085289056863517, 0.02936261987704183, 0.035819973075582136, 0.07954968905617153, 0.058251931482265075, 0.061300283433088375, 0.02400254781898712, 0.036102368406230406, 0.04938577376906911, 0.05117855740771179, 0.028694334567614624, 0.04999220513948991, 0.015031799951928758, 0.051067746619904236, 0.04591211661576264, 0.020995832746848467, 0.026763817896285368, 0.06102793151512743, 0.03935990449521811, 0.04884496932068179, 0.04380838171909413, 0.03783575724810362, 0.014119548197355003, 0.04887545962006815, 0.04941547882833308, 0.06595263963625317, 0.02315690549420974, 0.04433816216225105, 0.019759814998495485, 0.032724472243458994, 0.02310031266402333, 0.06247714770236804, 0.03817964645643388, 0.08530281784553682, 0.021953683969895207, 0.02711178077715299, 0.015215834381148942, 0.01766321046518222, 0.03082815373706962, 0.01632484720058499, 0.030630520289583556, 0.01724354750026138, 0.04731257513706242, 0.09155021124188939, 0.007830328315556532, 0.039983396643712636, 0.03912341698343235, 0.036505729020122564, 0.02388907870608232, 0.06566921774778636, 0.0568778378768794, 0.09232577567379321, 0.038862234627407406, 0.03301445950543688, 0.029496419048237226, 0.06335514958106703, 0.048305670235065684, 0.03649857375890978, 0.05339165901645057, 0.021453566451166427, 0.03894622850742552, 0.027327922908889673, 0.01436785261537279, 0.06420743771858754, 0.028951872260339802, 0.016773987313612335, 0.02935259561655262, 0.02584722433840075, 0.0008183934152193909, 0.015430256645495613, 0.10155873628513468, 0.03928728702087556, 0.029469069709340413, 0.04267440305181569, 0.07979718908186882, 0.02485892112036386, 0.038877820686226895, 0.0125660827653783, 0.09343872522755016, 0.03763532566447412, 0.052949189614023895, 0.06942184581871956, 0.03513109149231065, 0.0510854585727136, 0.038559308140388424, 0.03228112567035902, 0.06011798760042556, 0.03968341193432289, 0.03332066101833217, 0.030230760288935517, 0.0815018802700985, 0.0576439296315995, 0.015291688576971572, 0.03128626090925067, 0.016976726737113732, 0.008809174178168178, 0.04442120226280344, 0.0359225177746867, 0.04024038083791252, 0.060197243226632, 0.07651458659599866, 0.037290084310957504, 0.02414070220003205, 0.043083819590749285, 0.027267317693199844, 0.028888871104666786, 0.05843190085743705, 0.03906280410686328, 0.02217663470805893, 0.01337535985399999, 0.02680886386623306, 0.08409436777113907, 0.01061498035391372, 0.07632773775126665, 0.045776174313599066, 0.052682893621104385, 0.02326131753262974, 0.055312521064714085, 0.06711132463908966, 0.06835179718872232, 0.07987487805827011, 0.0202052089415731, 0.02289523284191326, 0.030991949080940218, 0.0504640118789769, 0.02381926702876245, 0.04176223365169379, 0.09181913108594957, 0.04579723790107716, 0.054713639490787065, 0.025351590349248825, 0.04570081041404798, 0.05943630341320269, 0.01116890405800434, 0.03733996046526778, 0.032027085169008186, 0.05105380381968233, 0.08610679647855221, 0.018698118642092715, 0.03990183509285412, 0.04629115393805889, 0.05361487405494817, 0.0573546203574346, 0.0052312313909492186, 0.05306939263978312, 0.02098721808813993, 0.013521689350806899, 0.033547338774247516, 0.038625735624302784, 0.02544226643118647, 0.051498747686104435, 0.08043049098623377, 0.005535337174566644, 0.03242130060830424, 0.03217134527080963, 0.035512725852670214, 0.057972336202980056, 0.10417105014165563, 0.1370824708212768, 0.011409206687653018, 0.04891953648879163, 0.024077457811443076, 0.04274895106772742, 0.07825609596986925, 0.033564376569683516, 0.06482872736429976, 0.018585227925570744, 0.10132779141948109, 0.035897079825160966, 0.05395382582660645, 0.04584268989762472, 0.020486305753189712, 0.025407191095573288, 0.0825208078529085, 0.06348060796998682, 0.026994954283920028, 0.006499739406975888, 0.03635642614455954, 0.021491736781993703, 0.018660208781159694, 0.03038829094880531, 0.006145010054517057, 0.02280913413532319, 0.04628923105736894, 0.0206467705298095, 0.0400151394968552, 0.04097874787065291, 0.09179211882573944, 0.018369279231034943, 0.011356202979391862, 0.0285887906342865, 0.0315575000845016, 0.0477738366762717, 0.010148315979618459, 0.024125843924740632, 0.039652235986244296, 0.03758917652791546, 0.058813247934825, 0.05517926390072512, 0.05833221366629005, 0.036468700160302465, 0.013325970165521629, 0.045402683467874606, 0.04728568545092018, 0.011244494911103, 0.06371174818806111, 0.03576546208932996, 0.030058503503941243, 0.04588451829829043, 0.10441745466162121, 0.18982891143570024, 0.179609528352176, 0.07836789884153875, 0.17201592695088158, 0.15834461296758345, 0.07060881478772049, 0.14463991287254518, 0.12221559236246733, 0.18334160228410076, 0.10762562404476828, 0.1029614202918545, 0.120163181526286, 0.17928551912548082, 0.1605882240279067, 0.1485026814043522, 0.15378222229980654, 0.15698946471656525, 0.1566050417961613, 0.09629385831255106, 0.1214352858463122, 0.17322629990596927, 0.11759768330281782, 0.11554152629668675, 0.1294429347880425, 0.1473795198985646, 0.20543876494611465, 0.12417217326020041, 0.17425599868499464, 0.10835574414100378, 0.07986953842543787, 0.07838553418555567, 0.09931215280366522, 0.22593875686007164, 0.12180782674301056, 0.11117395178805436, 0.13692113270442333, 0.26992626908806067, 0.1123587374064711, 0.15545382615058653, 0.20477737059756634, 0.1118633236675974, 0.15359793218874163, 0.2134292918227373, 0.17194783705617153, 0.286869682491787, 0.1226080362234385, 0.1188514015126613, 0.252801614603208, 0.11177597432247094, 0.1506484170714694, 0.21201823447500506, 0.08898998370334026, 0.11510310949937952, 0.14718569965372164, 0.07870746731397607, 0.06935997655795467, 0.21555160052112995, 0.1459916596931796, 0.18322065232261536, 0.1340999066709511, 0.09532496393207582, 0.13802855876424622, 0.13137483999373453, 0.1831013877545634, 0.12779900969396676, 0.22244041635384484, 0.1428230893948386, 0.09509431784071269, 0.1219204416678798, 0.12420570492864617, 0.11982280100064895, 0.10020836842276397, 0.12184695851418281, 0.11572422294486916, 0.12332373854493904, 0.10827686772831988, 0.13224585132012445, 0.1574453329967876, 0.1960844636684464, 0.09805802090634262, 0.11082323673631876, 0.13871342604679449, 0.12548378473448177, 0.16416678926156414, 0.27150054912894006, 0.23864075511453614, 0.23245678613743476, 0.1580768958815644, 0.11049709012431484, 0.13047404316884856, 0.13749085697195224, 0.12368726258676861, 0.1928775430086159, 0.18598894168051983, 0.13738374255837935, 0.09408032386413506, 0.16369290259336272, 0.2294453098288467, 0.23157531004999918, 0.14011351301545097, 0.08766783852010004, 0.2374126855283976, 0.10647996253664456, 0.09736429764738969, 0.16520376587587018, 0.15649607344981165, 0.10901015176768265, 0.13070679600200347, 0.1416502853915576, 0.16917775505252425, 0.13023362945645087, 0.21136932735962255, 0.10633838182735829, 0.19331982088906152, 0.15691398973426512, 0.1471314299851656, 0.1227281281664487, 0.21501438902510753, 0.1308801923427851, 0.12036738226250296, 0.1723462640638313, 0.08644959018115075, 0.16973971118850095, 0.14192376345876725, 0.35974079322430397, 0.18542536143814364, 0.127908943311101, 0.13459388016452714, 0.20288142555904007, 0.21791314315651694, 0.09106840322455091, 0.12411175190561241, 0.1065213466063142, 0.3565174629611354, 0.13242205154270897, 0.22618893053262468, 0.11833322730155722, 0.256446109363629, 0.16650979256918355, 0.20997086449736552, 0.12937366511792908, 0.14022957533597946, 0.13941598996039362, 0.11195396719079827, 0.1084549678489566, 0.18376399252203204, 0.20171779928909195, 0.10993253695027483, 0.1426103467782659, 0.09487520903348924, 0.13762668436092718, 0.1700151810843137, 0.12813214302784012, 0.21104456736676155, 0.07844514348694394, 0.16457774946766515, 0.061939894071509766, 0.08341101734268089, 0.14232540803570903, 0.10611084605296774, 0.07802937990955769, 0.20179598622264402, 0.12193665208835756, 0.16344481267996375, 0.13314359911507176, 0.11537940677015052, 0.07929085859007413, 0.2530882387391983, 0.18152456430177535, 0.1019815095670281, 0.18433475866913798, 0.09852017110754406, 0.08650470254642349, 0.14335714460861299, 0.22039093197353427], [0.010597892762762646, 0.034320719855567144, 0.0250275562246961, 0.04159172929282631, 0.02150159058791976, 0.01781698537900323, 0.049147325072197184, 0.0006355818538483413, 0.039707493908222646, 0.026157857669937997, 0.030845752691910155, 0.03232337158894347, 0.04027945515249045, 0.030021819383687073, 0.03388036102537186, 0.04203190043148014, 0.030820048526830734, 0.030831405780308192, 0.07045704510904129, 0.04001565660620409, 0.020754135837177598, 0.0472257697143622, 0.1574229325858816, 0.02810341264722088, 0.06343685668863117, 0.04072773150138317, 0.049994959225577694, 0.037427087644896204, 0.088800476533511, 0.09636685883085574, 0.00782541338271732, 0.02174511844772966, 0.04764977256737409, 0.048890892461302786, 0.0506534003051779, 0.07520263038215137, 0.08255920417967343, 0.051954370818191, 0.03133995026620406, 0.10307696933347373, 0.08207561883835063, 0.037242805194710536, 0.030834970004375906, 0.026806285980367855, 0.038849280080607826, 0.03975268543487595, 0.020253736781136646, 0.038679028530755354, 0.0639449300304536, 0.047986632918999086, 0.02587808427521058, 0.038564965699709235, 0.008310227816353643, 0.06026478919891581, 0.007779171357997844, 0.030240594942663467, 0.021365033500196955, 0.061291523217674226, 0.016249477555374467, 0.03964928654773582, 0.12435679278907277, 0.07096384291446979, 0.07333873080149775, 0.05142617617703734, 0.031703972265184406, 0.05869936513444109, 0.03558789056936099, 0.044020530617525505, 0.021919547091989268, 0.09136631949654511, 0.03686992338888588, 0.08055285054949984, 0.029594447659028154, 0.10076207379179616, 0.026671408540419033, 0.01896990173976989, 0.06342373743292785, 0.07735352948187821, 0.011279408410642178, 0.027702459464630777, 0.0454150672791706, 0.044888807010025754, 0.11392869671145756, 0.04923926328399009, 0.05355683523380468, 0.040407100722434065, 0.049232697910479004, 0.012115408561282582, 0.03620174916220769, 0.056984810564186306, 0.030485865652501106, 0.02342916165118016, 0.05680223265963216, 0.007581705971050167, 0.02751906376121746, 0.018574117735448866, 0.030024697959062555, 0.06397386900179329, 0.013495889424736942, 0.054381544206051104, 0.047716835904265606, 0.02095137666460247, 0.02279102956245263, 0.01916525990612084, 0.06270902719528926, 0.09426433052266799, 0.025285526757098498, 0.008713288698345423, 0.041676424143295136, 0.03642090393470661, 0.002940745804564006, 0.06268577642678734, 0.02213134358997547, 0.02436994826571355, 0.02559743370980986, 0.045294626766154845, 0.028637172917144436, 0.02570504991097316, 0.051482916479149175, 0.051155628396138075, 0.019212148317526427, 0.10626532002201966, 0.05829405482678164, 0.02766347133494433, 0.05539365743677463, 0.06842540291648719, 0.06611681227842647, 0.05046960815126377, 0.055086973288487044, 0.013368624025925755, 0.08911266502353454, 0.024370536238195437, 0.006195392784467268, 0.010245166730225809, 0.019431745505801613, 0.04624508141029266, 0.08878390605170881, 0.015527071964536465, 0.03793482773847157, 0.03423116800765838, 0.041217219550162554, 0.032517161190269456, 0.009745594091533173, 0.035933476662443536, 0.04176549718625123, 0.04752369747767526, 0.05277829455031503, 0.02717105491507438, 0.047868119117112896, 0.0645311558318715, 0.09859744639646623, 0.038199748603567, 0.030077962137217966, 0.01745514864582689, 0.026440065309044816, 0.015131433516921056, 0.08486836938367737, 0.032580221717756604, 0.03652246804126809, 0.027279063736298875, 0.033465681462398464, 0.03823198941386035, 0.04268842629126964, 0.03424817132913778, 0.11092143388645304, 0.08115874948881327, 0.03767436550509545, 0.03051305411293382, 0.04244679449907234, 0.008679238962940872, 0.025784249995805086, 0.0476240013696013, 0.033262468979603825, 0.03837342839688063, 0.0078509581057475, 0.05799277542879986, 0.027589727711353092, 0.021083134211479657, 0.020392333577957847, 0.06833787737113815, 0.010339903078162143, 0.03431845989619051, 0.04805583747163896, 0.02297369939755769, 0.04747276795246909, 0.03768778736552885, 0.07683663463760769, 0.08549322899911674, 0.026808521041886944, 0.012515723975675722, 0.05479374547458945, 0.050772385251137524, 0.01969468794883259, 0.046464500483125455, 0.037339313120971766, 0.03316844317821726, 0.02245755340423315, 0.011140747453957316, 0.012434153806328053, 0.07435691527902119, 0.0436486064216062, 0.020005162317125548, 0.051922122347018415, 0.029452702240838163, 0.017501822552613674, 0.09520300273453036, 0.019604816259215438, 0.051296818400582964, 0.017825362550455238, 0.014461465686890147, 0.022642827938280763, 0.025001545624446966, 0.02382511227962471, 0.018617227418167938, 0.027618682004451275, 0.0732031868650548, 0.033190219227464936, 0.03411814322574966, 0.017559892017274134, 0.0241487288862587, 0.009719708938181642, 0.02326722407052594, 0.012932777453604485, 0.03388306148530495, 0.021292113421124317, 0.01380754644126301, 0.12820934170796988, 0.009951740691077807, 0.02936684676716405, 0.055393404627759615, 0.007193900772460527, 0.010408218968809854, 0.11288818077094133, 0.038023962068461606, 0.022644237540061438, 0.046495048239106135, 0.099560457221683, 0.08632681693040556, 0.013068222756227179, 0.05231171253047163, 0.03989390991327744, 0.025840078653287024, 0.07669316169114844, 0.03329907266062594, 0.05839982858648705, 0.08725705451422161, 0.07880990859121084, 0.05522923198558631, 0.05552969166948911, 0.04747038158858496, 0.03405450430187968, 0.09843176456108209, 0.03582096132900446, 0.043178519549509214, 0.08269910715640554, 0.043381092348887075, 0.02735825616025156, 0.05799147307932858, 0.043229548666145534, 0.04938811033723816, 0.06342589013999508, 0.11000486331120615, 0.009894793545226417, 0.09288138860175688, 0.030079980778898445, 0.01193319263327266, 0.021642382226644025, 0.04024915254464553, 0.05100563987188282, 0.02028786408294353, 0.044986912229609106, 0.05506092246862189, 0.011783909867517652, 0.005712510807619941, 0.022665463921223438, 0.03502973422948872, 0.04603963195075912, 0.03527537266153001, 0.07098254312070147, 0.06332863144756806, 0.007665660589062159, 0.050385844097622944, 0.012475590544542479, 0.013408304507573767, 0.139000846914226, 0.04648918383604577, 0.04904142107754465, 0.04307756831328716, 0.008681805357487212, 0.055886661829126466, 0.043325386265473026, 0.050182566497354746, 0.042572478883929794, 0.018358525271797856, 0.026883360171209902, 0.006627618154931453, 0.08218799627596333, 0.132420948376098, 0.023861836619494904, 0.023939483461060354, 0.1002211697519787, 0.03546017605150419, 0.051520634818101124, 0.04940086570117743, 0.05629125584457671, 0.027132767755838654, 0.04757336678824598, 0.07999941331124114, 0.05021755756329625, 0.05119446139301985, 0.03709480083817917, 0.02954638521787861, 0.04430753779747794, 0.038428196022587444, 0.04201324236008429, 0.021946731721982363, 0.031142219142507643, 0.0256430427543819, 0.029769933504623272, 0.049256661140750495, 0.05857183830812574, 0.023527368377413482, 0.038896704753560406, 0.05274029658927072, 0.04203235242335547, 0.08728841815384165, 0.04658539681845615, 0.09069866620965543, 0.07128446603253966, 0.019387331558391452, 0.07113490268708238, 0.08561777957384625, 0.033543232542973374, 0.12013634546629845, 0.11095616831293992, 0.02680717464236002, 0.08013966868841842, 0.07970657620218494, 0.05449840708846047, 0.012167664376207659, 0.04987500134795424, 0.026555240882800955, 0.037698891809991295, 0.04722742063383903, 0.036356950914787675, 0.020005568343725418, 0.012258252358034015, 0.0560662864647325, 0.07286998458326825, 0.020772391712413203, 0.03448021936140234, 0.046493891446340474, 0.045854303790556813, 0.15982596654324763, 0.1577176619321108, 0.10067544456931854, 0.07508933363902955, 0.238023380178117, 0.10595631845776113, 0.1114459436446909, 0.18695876302738346, 0.11045425048758907, 0.14530956564891725, 0.14890510739097673, 0.10423042961666662, 0.19904965294464944, 0.24808424434834914, 0.12111992575228216, 0.1292105190335743, 0.18070887984527698, 0.15127159895435457, 0.26699589084713693, 0.14328808944311835, 0.07947844287921345, 0.2574942248963541, 0.11182494266259094, 0.09338740499750262, 0.11346612516189776, 0.1466254901982123, 0.1527847605006349, 0.12638548554311838, 0.1704116009416119, 0.14395406499745386, 0.15668568021107107, 0.15419865237368693, 0.13357755728065968, 0.11329402350970816, 0.11738280330093638, 0.21161058376873695, 0.09737064851628197, 0.20315016920287765, 0.25501188551706655, 0.18094002389379088, 0.11315760623303153, 0.08053770499123682, 0.1374781092688922, 0.0892068708555833, 0.1321073732669315, 0.09636752532734986, 0.13456383419613685, 0.12950710231258025, 0.17149656530349486, 0.28656376826186336, 0.15630461275577545, 0.26224819883223505, 0.1931141109596337, 0.1331461272052219, 0.1669392461377767, 0.16078944468209821, 0.12479085820697008, 0.09036916413254316, 0.17159592690727404, 0.2264023626283292, 0.2309348299017837, 0.2332783847927086, 0.11510342359542848, 0.16411184543563476, 0.1131975117530073, 0.1678093075151405, 0.09677934355192608, 0.11250090034257983, 0.321670942489178, 0.17056941505401366, 0.22942395129751778, 0.07875775332532584, 0.16223952654869328, 0.18706169460088978, 0.1780210910064559, 0.11175884459648402, 0.0833589386855883, 0.12036482352883586, 0.12887730143002926, 0.11215091307437229, 0.16830352615685235, 0.181475994327376, 0.18912585722582956, 0.15091785019443882, 0.2056808180866703, 0.09708520415569506, 0.1583230552533942, 0.08035898433938142, 0.15577780473376476, 0.13586226129724135, 0.07108261718625022, 0.16298044082378188, 0.09867811545489297, 0.14016690934377332, 0.16988324542199412, 0.07769798559527244, 0.16013713613633188, 0.14118597482240972, 0.16723633503481267, 0.1671221726123364, 0.11060454927745367, 0.08212447992616123, 0.16875732599967913, 0.08772658214213387, 0.14397117940168228, 0.12370990048493109, 0.09653450951220528, 0.14961303392004582, 0.07926834326597952, 0.11755960873298107, 0.19375859008681393, 0.09871682587770686, 0.17163649892374394, 0.10105389200391308, 0.15442201296889013, 0.1588457110788553, 0.06618611259205688, 0.10467675244135242, 0.14796490300326579, 0.2332101416804137, 0.33345585688948637, 0.12999451809352444, 0.10433938264125779, 0.20941335167134964, 0.21842587048247938, 0.13273645402683368, 0.12468306197514459, 0.12446042916346943, 0.11978053592986639, 0.16602689670699258, 0.1679675353150214, 0.10382796532564587, 0.14407737450974603, 0.11746136561757135, 0.12100575566892663, 0.17403642256413737, 0.12284740805625917, 0.18176922214127358, 0.17652231659139359, 0.16470544100288423, 0.18908631176717822, 0.132030718509228, 0.1611079380757386, 0.09383520637188228, 0.08558078518798275, 0.13145394623279572, 0.14447980049637058, 0.1406849073546548, 0.18341292506985127, 0.24368446350338, 0.20253659406256294, 0.18436403854960398, 0.12122121023675128, 0.11958591129270293, 0.1490210777809543, 0.1382892125196034, 0.21991085531490467, 0.19884225762178823, 0.12217214751628139, 0.18832373252559095, 0.1154224838941328, 0.17925996243232684, 0.155531584074901, 0.2341479252302839, 0.10483488064980316, 0.12966980406593892, 0.06859366646817616, 0.232393185517961, 0.10454730656478675, 0.12967315953104727, 0.13179336914852743, 0.2058719263802613, 0.19557195084710277, 0.09929120795981539, 0.19738950976921668], [0.024856098086362886, 0.024995495445064964, 0.043085788436714685, 0.018365801191858707, 0.03713129726689189, 0.021694524085990364, 0.009222912410604618, 0.029013109498567162, 0.08969352820948248, 0.029918807370948697, 0.06170066013451546, 0.03021817729477921, 0.0066920174210662806, 0.02009259784714349, 0.010903587700018, 0.010608143976799423, 0.047771480955904534, 0.009797346203648036, 0.03861613271217193, 0.0250308312505724, 0.04384210107908134, 0.05225284633436992, 0.024915211345820178, 0.08159858354878041, 0.02903664755004068, 0.021191206234957904, 0.013878884548772008, 0.00510767960335098, 0.04376431634168952, 0.046296221609678, 0.01966646910014172, 0.00851587071308806, 0.04822833365910957, 0.032840722255528934, 0.07262521183058139, 0.022806207679452437, 0.047779620640100016, 0.09900454551942887, 0.04709879830179196, 0.07343266084189377, 0.048826590871378306, 0.043263685544051474, 0.025966902593931845, 0.058740247416520314, 0.05352287838656095, 0.024543246930284847, 0.027947485026332642, 0.07056651907342096, 0.04563084360392344, 0.05427068745296809, 0.01624405556809037, 0.0321899343942923, 0.037718894365694255, 0.06219425824500861, 0.029822755267002413, 0.021518952055503766, 0.039355786772625106, 0.06303077263216819, 0.04720148855760213, 0.026534811233080206, 0.04477034300385464, 0.03440306281610843, 0.05585775350130374, 0.0417540020369474, 0.06890686619425974, 0.04670415576847811, 0.056751877700369206, 0.020974093086777196, 0.08222603254140386, 0.024284018098466822, 0.03823414212092757, 0.020468411854498332, 0.05126515981711207, 0.057826338996810306, 0.042329226815772635, 0.02620715925830507, 0.031244681487160347, 0.02978789826644765, 0.06679984094995646, 0.0763842827009578, 0.04515727103177098, 0.08017239596454367, 0.06122254083053239, 0.06903184577822685, 0.039353771961384246, 0.013016413187517995, 0.032811220209564895, 0.04820232114364063, 0.00990265648015925, 0.07047055890002558, 0.06802404179207741, 0.0075494134498219345, 0.020549253282708027, 0.08581115548769314, 0.025009405686550086, 0.08238865002509087, 0.011921908158148009, 0.051046847741329865, 0.0836522737517953, 0.0822643599202556, 0.02748712747087402, 0.031352872254266854, 0.014188687632521315, 0.040264822873136694, 0.09252461379454022, 0.059659031985868374, 0.03164953022684542, 0.05188503986104362, 0.06874004288786842, 0.008430565865109525, 0.0861617556262401, 0.05263797788610382, 0.02493758877408841, 0.02458282877811261, 0.09727193808723843, 0.02834295876504433, 0.03828073941892193, 0.08682354067962977, 0.03585935382532977, 0.09783223181241944, 0.06303944474747104, 0.03828866459849862, 0.06367349741800178, 0.054462918065368175, 0.0409391755989242, 0.037538982447116606, 0.030200321700484044, 0.017468965041541287, 0.010502995536362213, 0.04267440688225531, 0.02119583149080075, 0.04437370864193767, 0.08671162289477165, 0.016101155272354523, 0.04272521766383321, 0.04532903943571352, 0.009191304580458711, 0.014796917394344366, 0.02111919780051516, 0.03598776931363729, 0.0708466008185379, 0.04067937220116297, 0.04582281757686888, 0.04095263576375381, 0.03810864159717195, 0.020713650005599184, 0.028289075970890063, 0.05632492923928846, 0.1351378791995587, 0.07270223431048856, 0.03657952243942888, 0.013594296291440487, 0.037152391497886954, 0.05180764582849318, 0.051924118006061164, 0.006660691128232547, 0.05065154254196152, 0.07839737790486506, 0.06890616905424865, 0.023534065901091503, 0.048490856669002005, 0.06683166424233107, 0.04903718078088376, 0.05844582067502122, 0.023837337127676415, 0.009057032349970072, 0.07777939009810649, 0.057552531511793216, 0.03987674571333393, 0.08317130843117353, 0.051986312854193875, 0.0819395233186022, 0.08379608377694123, 0.024301584494570573, 0.03274468930378076, 0.03378333982020136, 0.013181118260798676, 0.03463354419856783, 0.04713155622143419, 0.013608983154558848, 0.007988300912397644, 0.0422433138855042, 0.03259233356783948, 0.0647886456441014, 0.060328573679491404, 0.0506035739465827, 0.03837539341240641, 0.0808508510911657, 0.045588084406429724, 0.044407021975325006, 0.020626049766677524, 0.04214328195479128, 0.05228561574533101, 0.016268857664638953, 0.07820988554627666, 0.014686403465607475, 0.0343893306900657, 0.007600736073894247, 0.0853136962940616, 0.03514323015547088, 0.05955954014714207, 0.03877669324978225, 0.018226267852550073, 0.0398470483149492, 0.0712122775674347, 0.045865346947985317, 0.02883226103750208, 0.012601161931431102, 0.0596589285639986, 0.03845585945753321, 0.013125514641644494, 0.04243045384364744, 0.0465085007430565, 0.03910384343696698, 0.012623257822387162, 0.017153490034322587, 0.06358796370125587, 0.03728391347272742, 0.036524095978107185, 0.030506521298159516, 0.02885638323101786, 0.015008698570572082, 0.07753595799928711, 0.08255031755975178, 0.02068765664232835, 0.008359120505291128, 0.03332022817865495, 0.020952543033467188, 0.047906258804423195, 0.018226187413318024, 0.025664317016039166, 0.022165110830457944, 0.04990002944044048, 0.03663047494727277, 0.046820306189117894, 0.03995472580314644, 0.022024215769863898, 0.0518311111016139, 0.10295736768673505, 0.047242692596609556, 0.06834729259172756, 0.057175842248984886, 0.05059675959449622, 0.031473487052285386, 0.08822368127444098, 0.07011098021100606, 0.06365812203336148, 0.03618285360355531, 0.035153618307724115, 0.04488983739828391, 0.02772992371671623, 0.023479512780003493, 0.056632662928032304, 0.012589919591142286, 0.03442317262412079, 0.026538201172145146, 0.08566224331697149, 0.060450063732963424, 0.16533058407085557, 0.028178098558958982, 0.005373975117465542, 0.042921696233773426, 0.027345330341749137, 0.034810376443689874, 0.03438636592979874, 0.039669089920578465, 0.06880889120962351, 0.04708467164046822, 0.024052619325718092, 0.020871414322285883, 0.03654416365128371, 0.02661630575124535, 0.035411828242602854, 0.045623152081163666, 0.06705122504142985, 0.029161565846973853, 0.019469078885571613, 0.014508143424116557, 0.08089458705076287, 0.05724239996784637, 0.07544060793494986, 0.043401780553282275, 0.024982297665349422, 0.03702969485593419, 0.10405996739263497, 0.0553715136653233, 0.06709421789574047, 0.02273487340238306, 0.020831445600056363, 0.04218165146847887, 0.04468516934843314, 0.05014924550308816, 0.01766924340758593, 0.06807949123603683, 0.10527976322919132, 0.08634449057881871, 0.06457685297655483, 0.0835805602612034, 0.032513813386040355, 0.07728562344826999, 0.02009552238779443, 0.02910174012574698, 0.04564671694571453, 0.050459476638465166, 0.06043947639784986, 0.10899869109233541, 0.04766442782936558, 0.048420208040624864, 0.05236205982885534, 0.11154027205080756, 0.02026606696627794, 0.07328223181708206, 0.025731730838156035, 0.058113572172700405, 0.05373280946045153, 0.040430596639071746, 0.028865055346320716, 0.007228334988242076, 0.011449450243925376, 0.05842554998854476, 0.08242915309364758, 0.07032797461555851, 0.040378180903292475, 0.06965234635337707, 0.031178439779567624, 0.026195058899541056, 0.0977889861490938, 0.022539835077740496, 0.020671691369986343, 0.04158301504268762, 0.06055430531682027, 0.05206607792886996, 0.06268783337286403, 0.02288299650254269, 0.011872589332802642, 0.05593380687998668, 0.034276520412775784, 0.07211611576138005, 0.07456454808913893, 0.015033137732966533, 0.04696241549907192, 0.018172406125813723, 0.05522286579493554, 0.046355248684243816, 0.03152457937117546, 0.017487502454089063, 0.036679971888060534, 0.005019679083488882, 0.042403430092118444, 0.014022244497262424, 0.026806759039661097, 0.04048218499989279, 0.09638307691221276, 0.14742291111859585, 0.19535015307126508, 0.17716146374662078, 0.10208267913830858, 0.21868609522859897, 0.12690335331905273, 0.1350510048289453, 0.2627282295255892, 0.10339989071531643, 0.164293117160278, 0.18778868139751498, 0.13619892629644564, 0.16320021612749946, 0.08685954681207096, 0.10604808046933144, 0.23369959525523648, 0.13345338974989232, 0.2117230607977798, 0.11360854856790074, 0.09954626927332533, 0.08423354296434311, 0.1822222405744176, 0.1582398887483343, 0.10394752100710908, 0.10940890053227063, 0.09119633990790575, 0.13279599438030876, 0.1446985798857866, 0.2106280300405718, 0.094328727873583, 0.08974299450675327, 0.18250200056260635, 0.11780975942289638, 0.0925209442333829, 0.1573429836501037, 0.178843486393171, 0.2291462444249661, 0.17060480831611544, 0.24297148079401065, 0.1083093192127924, 0.11815769357546685, 0.12071419026582472, 0.0885205633277374, 0.16812099804801328, 0.1416662813074166, 0.09862854190531278, 0.2978774160146713, 0.11922035711787402, 0.21784626368072726, 0.11429226671856259, 0.1085298146391588, 0.2723024593245599, 0.1291675108575052, 0.07751106780262725, 0.1928411385104541, 0.12087782664645104, 0.2151215340821974, 0.13429498329998987, 0.21345884749485602, 0.1604249094042086, 0.15946014423764523, 0.27203429790754474, 0.1295944516577067, 0.1729741497265716, 0.13368651030525086, 0.1671259877301993, 0.10365354242704569, 0.20772310124049265, 0.12820489073712982, 0.12911036069835388, 0.1833695798150955, 0.0957124358824184, 0.14442315595524927, 0.09700182314601638, 0.0708189680271091, 0.09306687380998366, 0.1146807652267237, 0.17380777596225663, 0.10368487542314876, 0.2740605085367157, 0.1535062008206883, 0.2793115203178698, 0.15864734027174213, 0.08316110414002212, 0.1225184805450901, 0.09288271393386588, 0.1267717164310236, 0.12199095240043056, 0.1311677664278015, 0.17866157115467135, 0.1730774337005231, 0.12673861377181547, 0.16268872986397437, 0.09504146543481658, 0.1336281190836622, 0.126892697036026, 0.11281843612631483, 0.1706671219078764, 0.18745852814566707, 0.1112129916286757, 0.12361183356974395, 0.09333830642243547, 0.2404888349795534, 0.1660124176452237, 0.2654795270533331, 0.15319182898008055, 0.09932902972063712, 0.16594046666737527, 0.17575299577607265, 0.19527354427883703, 0.14148939160570023, 0.1600258695262094, 0.1944820682007459, 0.24283203747003312, 0.0932993661732443, 0.1966338559624649, 0.20059387169538007, 0.2916030333407464, 0.20023062344520323, 0.13585345128611212, 0.1188615674994165, 0.16762717777202207, 0.2505288309147281, 0.12273437944391083, 0.17936821065602765, 0.10567003906133676, 0.14103974395942304, 0.11008842052110743, 0.2355289978966598, 0.13311358379019847, 0.10383397911585147, 0.17433214782466813, 0.22015802592279451, 0.11388149037356339, 0.13458081070453892, 0.13588291502767993, 0.2477069307238825, 0.12360180547881512, 0.09903318188603848, 0.11460434795627672, 0.10679514643045203, 0.14451347772152195, 0.2182012228595634, 0.18864369680804594, 0.13679167916697843, 0.17371642763816542, 0.19430945326964702, 0.25388199775930376, 0.14880568450016363, 0.2498802302345153, 0.08608150025529247, 0.0987963151607302, 0.15382083313119027, 0.17873042713730566, 0.08700131904333831, 0.1361759896239927, 0.21061218734229767, 0.1654107628330108, 0.09810457606950114, 0.12771176760114972, 0.1995621504442346, 0.2197871014716164, 0.23449229707400646, 0.13347807310281262, 0.11930255835214931, 0.1630188524723053, 0.19841401447211543, 0.13797654139418758, 0.10420660428222149, 0.17338389951375224, 0.17367508953377125, 0.16891196850807438, 0.14489665957948855, 0.17257267368897317, 0.1409173384308815], [0.018045034432303042, 0.05577370599513093, 0.08492816254616746, 0.033005343059137944, 0.02238017852388082, 0.08129112948212894, 0.05134424690397517, 0.07108522188519278, 0.022940211779167576, 0.035802268783652016, 0.05960341017212599, 0.03950628091491038, 0.040354033811919154, 0.05612358601102906, 0.07367739529018441, 0.11585317852516329, 0.03952542162169853, 0.06090157680333622, 0.04830860435181568, 0.056823939760966655, 0.008826532772922469, 0.04699508914904249, 0.034028361551463604, 0.05220182104817322, 0.046099042069287076, 0.03671972036001183, 0.04669595096680907, 0.05270869546239415, 0.05336570778801557, 0.04656241418072774, 0.08923275696654474, 0.050707827021758405, 0.06826952700653384, 0.08326523847156957, 0.10865319309936416, 0.05948784580874828, 0.03810341687752836, 0.03978434784878646, 0.04282940179109574, 0.02241649492193134, 0.04140053289912401, 0.023633048291348165, 0.028812689406256524, 0.11632210860449461, 0.03865642510654946, 0.028686685179690682, 0.015160285345759365, 0.033202082098972414, 0.016054574253728554, 0.01695831955951308, 0.01646740467197472, 0.011844022871716129, 0.04694733505828246, 0.051615759955659035, 0.03707034348119651, 0.025323427041932463, 0.026597762593038143, 0.040745064240670016, 0.05498356674046767, 0.06181566525370844, 0.011942849171558216, 0.03088879534193585, 0.01802288683041209, 0.01573155806850522, 0.05599854130958838, 0.06349235592830567, 0.11743018583905314, 0.017860887962723934, 0.1345561273516186, 0.07545735461697464, 0.012297344867200142, 0.020896112996964686, 0.02651010489752216, 0.03447413662328355, 0.07010209359108441, 0.01658168583807926, 0.025117437490412307, 0.059749522291484385, 0.06587975403113712, 0.07940229373953997, 0.09274507091651041, 0.037433495970382806, 0.014388852042987222, 0.06206603427868217, 0.009711517543051272, 0.012042958668673472, 0.02421692794849796, 0.02015935091842567, 0.03974782843743602, 0.03194202451155551, 0.020514852104468212, 0.03712604573417095, 0.019018345309661764, 0.07584380767037792, 0.07384018897409401, 0.0030020139257108136, 0.045036696453368476, 0.1019087388751007, 0.05180116855509339, 0.021560265262040402, 0.044176184361980814, 0.05258971817731377, 0.020545503282318675, 0.055342034601996985, 0.07014261198139961, 0.058539394484532464, 0.04832927723445239, 0.02779439193076424, 0.004136005281320503, 0.03552626645673187, 0.025321956153117844, 0.04690405492100024, 0.039820131815729604, 0.026267877471963727, 0.025387596481690006, 0.024285153823814565, 0.042031858296644305, 0.012663047471564385, 0.06421787183611624, 0.030791678375774817, 0.008866033223908274, 0.02575994968684691, 0.07513442557425269, 0.01614468247299233, 0.04832050169727976, 0.03626125504172618, 0.07001599296927452, 0.07208678225475935, 0.03736649392052524, 0.021640189299960772, 0.05399059804697191, 0.06827541056179232, 0.04968667395352837, 0.029711954055293918, 0.07014103384027559, 0.020273678049805666, 0.051880064119975415, 0.03693537028025716, 0.04344227213052012, 0.04545194292140584, 0.04331060076853441, 0.009405261446391384, 0.045109930628490065, 0.041927180042670625, 0.025675205040663004, 0.045249982992367405, 0.05382933270847125, 0.01982212859025646, 0.024173069414832903, 0.02459700715037123, 0.05726890661002648, 0.07861826403607285, 0.00530754380311156, 0.05009956470119858, 0.04024689641570853, 0.022110596013766144, 0.06050985689545351, 0.07431188463083199, 0.04234994949412443, 0.03341107854559537, 0.04092728208389975, 0.06263414976157008, 0.04934756513384562, 0.0482746743176493, 0.04046208285275967, 0.047680986819848906, 0.043203674046502966, 0.03852059771757453, 0.015374163687679798, 0.055238808084639816, 0.0726502169404299, 0.06773602337606492, 0.020957610705086303, 0.061176318915620934, 0.00876655191889093, 0.02769224751260012, 0.033913007862265074, 0.055633412313557444, 0.030472943664438305, 0.1057198730808112, 0.03470747551370052, 0.015309051002165484, 0.05251083793419023, 0.039491476265773665, 0.027399381675246744, 0.01392574901992996, 0.03487499979054255, 0.02441151811170482, 0.031542674367946964, 0.007969295228606151, 0.017691486770467415, 0.0708116289047945, 0.004397626222682096, 0.032127616972091703, 0.031675466133521936, 0.04733069311647166, 0.07903650207745452, 0.04725721762365392, 0.0371280605454118, 0.003030969176418899, 0.06922597245823953, 0.056174316353374915, 0.08193845845638745, 0.056305612332277724, 0.06346701757021009, 0.08414420945149276, 0.06040556551588159, 0.03976360218779695, 0.0681840239333049, 0.038565149560811064, 0.0627095174915608, 0.05955967804296844, 0.00994542908419164, 0.045272877529984525, 0.012095309286979179, 0.036917784731955304, 0.04212458174855959, 0.008420033113760574, 0.029885178026292595, 0.08867274669389572, 0.035822443709137945, 0.04953441397857763, 0.0020243497537223683, 0.07829980128594945, 0.01346559256255146, 0.01720424335930617, 0.026833359527611927, 0.050285766201634566, 0.07405795712744997, 0.03326631474098371, 0.05573589955606768, 0.022857930105660233, 0.030504443284664905, 0.06233306954644861, 0.03349657395794507, 0.03155694084031688, 0.03364454384051985, 0.02283448589995744, 0.016914072236226454, 0.06839338810213151, 0.04917743232762141, 0.05957025771720275, 0.07057211917614745, 0.05704510934470643, 0.06591061971360637, 0.0677975862016601, 0.02345093961564764, 0.04362229513184678, 0.03675698287664883, 0.04204042699007739, 0.07309882270713007, 0.03508475466421054, 0.021621345452243285, 0.0757199006095048, 0.055698499143604314, 0.012452050577849151, 0.0655395956709981, 0.06232633180315457, 0.008588184625090612, 0.03620908062364306, 0.020620872927529198, 0.059623600419370405, 0.004905717759092729, 0.04344572718705862, 0.10742968939725431, 0.0197579744722574, 0.029072534938853596, 0.07809786050910912, 0.016082583385850155, 0.044558914228072094, 0.08196875723379274, 0.042828340759320606, 0.021265068602177407, 0.10172870055201555, 0.02583891611486193, 0.02309665076374527, 0.005052200952289446, 0.05460849392317957, 0.026498228619476, 0.05566420904811352, 0.03442502272645793, 0.02678044008902244, 0.08401898471938987, 0.04157675227390663, 0.05198903246632507, 0.03131446826662267, 0.03655010466313651, 0.015037140542370899, 0.013470558727520609, 0.0065869915546969545, 0.00856550842253191, 0.009720634946960115, 0.0225452589802444, 0.028974533141140017, 0.011342864431020235, 0.03467347270118133, 0.015702478328509437, 0.04189713407428034, 0.0069732554801439335, 0.021201040888685855, 0.019873791644650123, 0.06025948020960055, 0.04847061279560289, 0.011103977148811664, 0.03788035122617599, 0.037603690063640956, 0.0416657870124665, 0.03517608766654327, 0.025271135795440887, 0.016083043038604722, 0.029244000738066052, 0.005099703670449315, 0.0398530429529567, 0.027041879084502018, 0.011962017649033619, 0.03382733624969279, 0.06508669215104272, 0.04994014563459543, 0.048887046699922894, 0.06027263010882082, 0.022918774723826398, 0.011332729087782004, 0.024395744361343886, 0.017752193492807208, 0.035603832859065265, 0.014462107285526733, 0.046422970856750206, 0.057827568567928776, 0.031555602101669196, 0.03404313938752298, 0.06757732826255022, 0.0597202270892599, 0.051310757370365244, 0.08034062121183642, 0.02803166085223277, 0.03560637627097388, 0.025094255669823578, 0.094373183955829, 0.028611238925687732, 0.03146294185200767, 0.035754281036075086, 0.016150703924077175, 0.019070709334506143, 0.061045467267714204, 0.02629897298081027, 0.07003101595346967, 0.12211458366965094, 0.027086871428295013, 0.0065424617364882465, 0.027883579886908975, 0.046519222143556804, 0.017490739175569148, 0.1488358223991048, 0.19309079124321862, 0.19530181292324297, 0.1701327142936568, 0.10977508289919746, 0.15291950004475732, 0.13698916131209943, 0.15900855072804038, 0.16226880642915928, 0.07486737498472776, 0.1632955940740724, 0.14077496865103323, 0.16688859240422327, 0.1401902597037054, 0.11914923351498381, 0.18924579595125493, 0.14385710890975692, 0.16887991538932248, 0.1324807645212258, 0.23088920170501356, 0.16094548147051566, 0.12548069740014692, 0.11855163130789034, 0.10125109069650212, 0.21258627334910057, 0.11570567595622233, 0.09346733095064279, 0.15175300860597243, 0.21116596165924303, 0.14259700152662494, 0.21440089049358524, 0.14402221617919786, 0.15194430076066526, 0.14736412153128656, 0.20206345816052732, 0.17955401762118264, 0.11864653427995021, 0.20745733001780128, 0.17153620269269715, 0.13782720021422834, 0.16229201889326497, 0.10081157073258393, 0.08895036163589648, 0.2248241602172775, 0.06086871929226383, 0.1759191142815736, 0.1376749785436738, 0.14763596017033825, 0.11186196769197142, 0.10729757753471214, 0.06958270130018074, 0.12457157319952404, 0.17417346037203268, 0.13359350723124322, 0.11011802981938086, 0.07899491882492458, 0.0774438359263924, 0.14177952442438374, 0.1793330318985447, 0.137824381010667, 0.20976618112575626, 0.06919855417142953, 0.0677907143929793, 0.15271524568238568, 0.11739308420088022, 0.16785321967496028, 0.2448415780259717, 0.06259602922645789, 0.18919264477106834, 0.15003985214617946, 0.11732966744250829, 0.16595966483075775, 0.19147733346589152, 0.09689129964118043, 0.1862576853243574, 0.15201737022688314, 0.06109131762998239, 0.1275146455173531, 0.1672539550570711, 0.139477874542917, 0.16904471622359368, 0.15660835129599418, 0.09367063536398834, 0.1168316413438128, 0.15213721702175756, 0.1372223737980089, 0.12884941582958545, 0.26844333737127246, 0.26005724865582686, 0.17310276056729978, 0.14264417722100212, 0.20177784526059706, 0.12639667042681288, 0.2078256957353123, 0.17426836334409254, 0.16565364334852467, 0.08985137296540123, 0.2559535607935921, 0.13224405867438163, 0.10786181661270319, 0.13863540765258575, 0.16261924568924213, 0.13107540686765026, 0.1849094625081747, 0.11418276977154518, 0.10716286863410666, 0.18081118322668538, 0.08374160726464565, 0.14073608202799676, 0.12862616248669165, 0.14366885046324424, 0.10423085096502498, 0.2125754868311267, 0.10533351195795883, 0.0758096554707135, 0.11917521921737541, 0.1255975947565129, 0.086029551833147, 0.08617176839541044, 0.1525275081756615, 0.10335316701281456, 0.1960576352693381, 0.1288437314571873, 0.16828314821806648, 0.21176749389738808, 0.15956063965155234, 0.2001978502038025, 0.08243497536187211, 0.13090384913788689, 0.13693461585189068, 0.14473930511984134, 0.07702011269547286, 0.11961391946721463, 0.11436229481572106, 0.14558957078524176, 0.08002179840038862, 0.17949718921895952, 0.07918782742513765, 0.10600173981079172, 0.1413001219231275, 0.1322242016753843, 0.13663545851745915, 0.09971357521510894, 0.10088023519323719, 0.09023252469036849, 0.1896191105967568, 0.16097895951280672, 0.129960396537377, 0.14690267613097546, 0.1011268235743046, 0.18190255208361536, 0.17650843507820563, 0.09485444038986199, 0.13735835440456867, 0.14769111850088643, 0.128099009725115, 0.13654023378847108, 0.16004626278675374, 0.12010233882333964, 0.22930597375717857, 0.1673424382123255, 0.2253206158357282, 0.16413878108705246, 0.09956950472006876, 0.1286945434948129, 0.08357103012742535, 0.09700566124651702, 0.20145878496189273, 0.17496985473459767, 0.17292712724977927, 0.23788436586337708, 0.14529668005003085, 0.09149820153270999, 0.15275293720826028, 0.1525769208467776, 0.14622412141292326], [0.02224685432719848, 0.04669931409279666, 0.08205677307541333, 0.036145192721197685, 0.10240521747618915, 0.044277231359193404, 0.029276549898748918, 0.026094873751243277, 0.01629537579813792, 0.025117408762115146, 0.0383499248193637, 0.04020759610519294, 0.05710732717547686, 0.014373524538842181, 0.018593312068391713, 0.08761897743228944, 0.04851194706955745, 0.07826680587905069, 0.022518049452393767, 0.04438687769335605, 0.06057366818910646, 0.034473270943929116, 0.06522690922382378, 0.035186525614511584, 0.0643585025963764, 0.062167276628315456, 0.05449293339024148, 0.06792300245574406, 0.04324424989341248, 0.05050355350718864, 0.0428382539370608, 0.02836882572380766, 0.04139680205093276, 0.033102965643329006, 0.02552543102102655, 0.06232277332474628, 0.049552957136784835, 0.031079867246350458, 0.044069663666549234, 0.022603586999579303, 0.0320653876500024, 0.01661451270563468, 0.041823317672336296, 0.048001705698909304, 0.033577514977584925, 0.015032756604224205, 0.02396170767174373, 0.056796249512943535, 0.01666594018799163, 0.016843793245272774, 0.03691251021659663, 0.054002024248362555, 0.03307086272886203, 0.031369921541021716, 0.03082553371636858, 0.016714554212446657, 0.07703965559842126, 0.039559064372893304, 0.03589687681186103, 0.03347172972656066, 0.0486253357432302, 0.05969558970161504, 0.06660844920383346, 0.01887777966687516, 0.03664752806446726, 0.03842757549136877, 0.00400105219018916, 0.058540639377409415, 0.09061614321845193, 0.04703581055265762, 0.080148900047906, 0.13019658144443266, 0.0037997228472733935, 0.012639664552895533, 0.06446214663165231, 0.01814398809426254, 0.06392493130519025, 0.04815227261954739, 0.017628336227649165, 0.03143559059789104, 0.04069771617650986, 0.013577660692164735, 0.014817749240225362, 0.04263943113807229, 0.037461373909947374, 0.02377741947589863, 0.013798639711533344, 0.05231785655562436, 0.01940905972714386, 0.04867366439993343, 0.03092752300172804, 0.01956940192969576, 0.016117193323049336, 0.03334953870263792, 0.03135106811720518, 0.04202421273915999, 0.039058782145260804, 0.05064261761764365, 0.029458116567243012, 0.050334481732739564, 0.06881589325325144, 0.01948830386203143, 0.07133327349419556, 0.018933073978029916, 0.045112083335557294, 0.03688575459584113, 0.008433574675432137, 0.04208736902763767, 0.026340527505043055, 0.02480738255525789, 0.022195108918352954, 0.04250276105238065, 0.0605449513832648, 0.061775074085040446, 0.0276047449498888, 0.026315784780308608, 0.05381954976567819, 0.0575966275327148, 0.06261803893252246, 0.021808941232701464, 0.011928464913169944, 0.0730391751013456, 0.04575999070619864, 0.02907956188033906, 0.07911903272953727, 0.01941548145916914, 0.03155848833792393, 0.03772846663430814, 0.025365870228157412, 0.040841832636825504, 0.048602039009452834, 0.07795464037166489, 0.03539180653470178, 0.07221538543460831, 0.04561005963853771, 0.013606203213003615, 0.10036904770400255, 0.019252377509650205, 0.02594478946599749, 0.03648462712824826, 0.02068064310738156, 0.0678100964174636, 0.03190406485490742, 0.04434120353131045, 0.06278569344431162, 0.04916433222411622, 0.055608878347782366, 0.03839946006454768, 0.01728376520106629, 0.0456627473355301, 0.044362688467146895, 0.05915783428316636, 0.041903599856361266, 0.020978670462124774, 0.03183130182385926, 0.07872855005365226, 0.06708671789496176, 0.09299303059496226, 0.03376674635576145, 0.030199289397006075, 0.036773584001967986, 0.0687226603528665, 0.07255706830971664, 0.036169941191591566, 0.03529177460398886, 0.03306776390320832, 0.04258293981453584, 0.05530252361730222, 0.08339446218263719, 0.05464977457097942, 0.03688522216473376, 0.042574482203851786, 0.021089479334712512, 0.01423353920765822, 0.03163042590923367, 0.05847408165854793, 0.01370326272257033, 0.08422085654831703, 0.026760336026669513, 0.05804578488272044, 0.06325261254284172, 0.026266418074467973, 0.023899254268936576, 0.015125466649600816, 0.0433101870810553, 0.04714531899099389, 0.03144518584914265, 0.021880716010327303, 0.02381667573635857, 0.08384049389391177, 0.033344716179154577, 0.023229622559982444, 0.03603556553923315, 0.018437265703875213, 0.03610488883550129, 0.019764794570003307, 0.01887471914561766, 0.045885537195229725, 0.038656011419070345, 0.019871606378846114, 0.04157446933189227, 0.03632597414956939, 0.088689225245147, 0.01116235209103193, 0.03509895410388708, 0.013155882366962973, 0.027095509069641272, 0.05217033866492491, 0.07028082190381904, 0.03447256231259915, 0.040390250618539514, 0.04959706081858566, 0.04189654418657865, 0.10414966096680972, 0.02899442269887415, 0.06801326293498278, 0.031873132139744784, 0.012684800538174328, 0.062014679574678024, 0.03942440526800291, 0.03009217498343318, 0.010712734130661814, 0.04658362715535107, 0.0772643798301297, 0.07465454043760415, 0.00314543659765003, 0.03235848905939249, 0.04151325124586302, 0.03171305615274656, 0.023075336282471978, 0.0401529663753125, 0.03844928642314288, 0.13621722047607746, 0.028198290721423207, 0.03404141952013297, 0.14736413685304506, 0.042640285326107856, 0.03487437159844464, 0.0650580864279501, 0.0081086968965528, 0.11302722572919824, 0.010202325178280233, 0.055644076257463426, 0.03651517488422894, 0.060784756055762695, 0.06839484366918765, 0.07482903228411752, 0.04580218299862839, 0.006955453512003466, 0.009432940203095637, 0.06535080096293842, 0.021932040070814472, 0.034887372110519684, 0.02856764086191693, 0.02521342447688503, 0.020623845348675406, 0.041491804614422784, 0.04795469088299621, 0.04308309946810046, 0.00813846898851015, 0.055148245000670996, 0.00820829886041822, 0.047418176526984865, 0.03420925789302395, 0.03137418098988072, 0.025644651539022886, 0.021531192225313956, 0.04088427390783064, 0.049259648883655194, 0.03510669925280156, 0.04535661860098762, 0.028785263458567283, 0.04893966161856248, 0.05603031480624791, 0.0478387511365356, 0.07405514558476788, 0.08130683428457669, 0.025050504388467922, 0.10569294509027274, 0.02568738775387887, 0.051697298523879824, 0.03785656419612708, 0.09701879965441843, 0.04888942157248816, 0.09569989502309792, 0.028041252273044763, 0.035533448531022, 0.056732281171266115, 0.04062697178714218, 0.03968023649987675, 0.041163348247327154, 0.05947404856523199, 0.06230354834828646, 0.05434942980026526, 0.04970657691780118, 0.04223004141221604, 0.0198987182304864, 0.03345510561860377, 0.06788274453532311, 0.012637563556763194, 0.019947412694173477, 0.015808669606133575, 0.05520298964374008, 0.005071620323560051, 0.029130711655823455, 0.03542049652746609, 0.01561569301561723, 0.05997127793248623, 0.09018164879131703, 0.04872596139208444, 0.014837023054790354, 0.03378176933995659, 0.030213659291245767, 0.047026088896898494, 0.038385731768944574, 0.030194690954240582, 0.03261806263077644, 0.011048226057732058, 0.007164756872601086, 0.07331475991034701, 0.03894721293040822, 0.024341555132019906, 0.02125005710930113, 0.0438883229939928, 0.03615231733889349, 0.12191055913365657, 0.047666622671268644, 0.05484760145566637, 0.0435626820000189, 0.05588396903007262, 0.04695282024782031, 0.02310847916129616, 0.03517329144561964, 0.047916455434695374, 0.02461380937377051, 0.038522486124307885, 0.03181664656186777, 0.09638816373602999, 0.11618028274707257, 0.018284392858585043, 0.026062544840838642, 0.049758778148961645, 0.055863893696016846, 0.012310240999795498, 0.011050731165244455, 0.07873244178030761, 0.006650909621854343, 0.017460298671897863, 0.030799586318373203, 0.047368733212351806, 0.03777981367743304, 0.01668940737633215, 0.16072271842389338, 0.18036273067757008, 0.18907243025399026, 0.17417643279317888, 0.21751079377868485, 0.16803677434161787, 0.15430406607206792, 0.10612155596214919, 0.12374169313378873, 0.14162068375416342, 0.11212976904766214, 0.105649822001015, 0.10071669840404104, 0.15623828486329125, 0.13115719441444645, 0.19995912188483825, 0.1365832419645402, 0.2060556189427453, 0.1520339177260476, 0.1627313856395983, 0.13883014720293785, 0.13069392572487556, 0.14732609292672527, 0.1474497854829796, 0.18882075504910564, 0.15903122693059907, 0.17615963524628073, 0.15487300892991407, 0.15465919379024737, 0.11215750909140033, 0.10941361197300496, 0.1266914227556798, 0.11727591105286153, 0.10157182106688138, 0.09874375386824531, 0.24586330949058458, 0.09887306184898462, 0.1340667657073467, 0.12458543173007428, 0.09167950390087021, 0.13282207201325125, 0.03324577209329413, 0.13984532095491886, 0.17350560024140343, 0.08193195436991031, 0.08924802509887565, 0.16102535379750116, 0.13015835365701106, 0.16686265266710715, 0.10315260519423794, 0.15136711479675385, 0.13275289427368872, 0.10139824086499792, 0.123762967395446, 0.17790626974836474, 0.12635671894156164, 0.164839307206773, 0.1413479258096026, 0.07957076413496848, 0.2234302172737737, 0.16847373557186898, 0.26938856729576666, 0.14487281892328494, 0.1644826319909865, 0.186080320648128, 0.11463453182049337, 0.09804057708430676, 0.17540356775204982, 0.18364503438914978, 0.1945255207078111, 0.2320794112259342, 0.22929282768839793, 0.06744853356072018, 0.09661548500580174, 0.09306911078672256, 0.13467304769062227, 0.14957780919728741, 0.09227915922360075, 0.14604050545923172, 0.16078769800163087, 0.14719421855143963, 0.13957349763762567, 0.13540614786888325, 0.11301386515579878, 0.13084479908068336, 0.1452103572627229, 0.10902865279105403, 0.15517921427324896, 0.11504632706243186, 0.1996278501446209, 0.18369974838870187, 0.18931742517217515, 0.18112341002110513, 0.09696823785141592, 0.12047645786116201, 0.14065401868954783, 0.11639842628351144, 0.16070083895277593, 0.12670897383002505, 0.14823157820970784, 0.1999356489508383, 0.09846453780248281, 0.19923179800952637, 0.14634292632822068, 0.18817169471613823, 0.10395597095691389, 0.13583059122245159, 0.10873128044148607, 0.21003618115378966, 0.1272234018711794, 0.12715324353907378, 0.14411284438064023, 0.1055689460988487, 0.19055306370700562, 0.18021559583083277, 0.20502098655748754, 0.16486247370560325, 0.22806255176903742, 0.16496250946675578, 0.08305524611064503, 0.07731330220497425, 0.14214428952865063, 0.11826103117557303, 0.10747699532657863, 0.31341861272531174, 0.11149881903322474, 0.12724587889087777, 0.16621486404009406, 0.161496666410277, 0.1657608190491315, 0.1480224821716547, 0.27050025280444856, 0.18921116877707744, 0.1228665449326077, 0.0954039935623446, 0.13871262931535322, 0.2061749754413482, 0.1521939381716713, 0.15600271282657502, 0.13429443171668437, 0.10568070300524274, 0.08878774415220946, 0.1833386911499885, 0.1558187444724383, 0.13785336977772175, 0.11747618175802693, 0.1515598012314689, 0.11878615380415034, 0.08532121927747804, 0.1731070046944003, 0.10173617757015652, 0.16837985915762765, 0.12228514548511275, 0.280998936223407, 0.10969730199224527, 0.18893401348783126, 0.10289557503476258, 0.1314498093580046, 0.1903328900375674, 0.11728919501746855, 0.10477866511791946, 0.2005164355279938, 0.1955423338879501, 0.12422556958852277, 0.13550834399798226, 0.16291179934576636, 0.15046158354849587, 0.12584366985867101, 0.17998572348827319, 0.19350123050953114, 0.22791886431795938, 0.12441166766708898, 0.10429076670158295, 0.19257467780863086, 0.11565053294743262, 0.14513250740785755], [0.043559870457336794, 0.11137997581353111, 0.040834646732095754, 0.035742621177867535, 0.05685880825284028, 0.023989147025971644, 0.04884499996419876, 0.019981377202296452, 0.01584872451325458, 0.05133168689245659, 0.03435264656981153, 0.017523887800052762, 0.0320178538095206, 0.05481351054303589, 0.024710079812775218, 0.011693013535301772, 0.022695506059174097, 0.013471667639791005, 0.04090699224522518, 0.07426516858920937, 0.03024068112755495, 0.0027231428389167113, 0.03397859264946273, 0.031709062919441255, 0.036036262679244244, 0.053806786740859675, 0.08214486552582634, 0.026060859447405226, 0.00546846871129087, 0.04512957312286862, 0.03266840609872053, 0.030620335150630246, 0.03578353027302412, 0.05410478728252554, 0.03686356868955397, 0.01383087573377716, 0.04738499725898428, 0.18510794056759727, 0.03321302566497076, 0.04324870852513179, 0.03533193293297964, 0.036903600614037246, 0.07045541334176256, 0.053587999690564415, 0.06624282608109136, 0.02234338140565782, 0.08722321641060614, 0.05303154789632367, 0.03188122202822518, 0.02976934936258101, 0.028232207349050912, 0.08346516443716903, 0.031916050300482786, 0.029336618852891752, 0.04203735497750102, 0.03526205805340602, 0.00918357475330272, 0.007661384382029816, 0.04937586059132892, 0.029250681024765777, 0.03436914044282129, 0.0505149643868208, 0.00870003154681575, 0.008237289542692804, 0.040287234775361516, 0.025783430281726104, 0.06021414695668125, 0.009965990884079328, 0.030409030864135395, 0.04265423961764863, 0.027074183097049117, 0.030970088762020877, 0.037874877527957006, 0.029576720384460305, 0.04399637586527294, 0.031634551292705926, 0.07198147580868776, 0.024028880176164454, 0.06761719547812978, 0.03974809273776989, 0.005097704180966943, 0.02197346819053975, 0.05580982321032113, 0.018425140447253664, 0.039193188441136194, 0.049157621293899514, 0.014558336547305508, 0.01822882850143698, 0.0032092158113711427, 0.024456847534184496, 0.06904787999848205, 0.0512614059862831, 0.04612618456444433, 0.020406446832742904, 0.04520415178229732, 0.04090665133609887, 0.09320967259906954, 0.07515307215432968, 0.025937927233415748, 0.026293166034344225, 0.030017377988946055, 0.018417491059329723, 0.05339958036558763, 0.024867535779072393, 0.027335240963786363, 0.03823705325503984, 0.04011121841387884, 0.017217707354575396, 0.02649986038675472, 0.056880860093740694, 0.060600255270518606, 0.05249666147715142, 0.0055016613858301314, 0.019833367100105654, 0.05293815028703502, 0.014183723382771978, 0.003459687061202262, 0.02001646594444831, 0.051179373291351145, 0.021217676487961606, 0.07881632074713707, 0.011561504966999975, 0.007610421340476963, 0.007435629283258271, 0.022665379651551767, 0.03662320094243173, 0.03470081820963852, 0.056716434642552375, 0.062445504440655636, 0.011719874493146857, 0.04341715593792258, 0.016952347904143315, 0.03619770421796749, 0.08840102296803268, 0.03416100201467353, 0.08704552997744854, 0.039393210167726206, 0.03153225748739656, 0.027482498384591554, 0.04199877095919463, 0.022367564886207544, 0.04395070170322734, 0.0849537269002007, 0.02471352912365429, 0.04670868334811061, 0.029475910874504237, 0.007800927297437504, 0.08981415641403968, 0.0805012621886788, 0.13813149033775254, 0.0299290269838586, 0.03817961964335653, 0.05158597445716301, 0.01790119567885995, 0.026338614200452165, 0.041410449907303824, 0.03144432783066746, 0.05268984969945685, 0.0522689150285817, 0.015262258351750433, 0.06729081137886933, 0.024382879829875404, 0.03672397980887083, 0.06108513146999383, 0.0013285986360936097, 0.05002051208829207, 0.01950864541164089, 0.028403531421997377, 0.03567988623774821, 0.021304667686983463, 0.012679656257762784, 0.02279622746901887, 0.09043935310816573, 0.025168792194416447, 0.021551116257004684, 0.041832250257533406, 0.03008102648891509, 0.027562439659490224, 0.035396403062247464, 0.05458696302206767, 0.1496099695683487, 0.09824742848474173, 0.027782864222723632, 0.0782666833049828, 0.09428460887002368, 0.04186165654250691, 0.028311371044706435, 0.020845057067251014, 0.006877181829974777, 0.02213109461140008, 0.09877524774281249, 0.06263008566513177, 0.00878487195399019, 0.027252164474057577, 0.02292134686403217, 0.0161673529298916, 0.04431892952491199, 0.016577602589442846, 0.005159461401372908, 0.027337849493168538, 0.006658391906849801, 0.02928316123753546, 0.11837697092203364, 0.009347418935278492, 0.01580945771908568, 0.01626956821118872, 0.07432335296705847, 0.07730483693341095, 0.06456797401751242, 0.040728214136775465, 0.01456046148368548, 0.03492070459610513, 0.026601432154195446, 0.09573423874474342, 0.06906119460660605, 0.009497911162343959, 0.06117722289937158, 0.05784241152146171, 0.0031098453497003407, 0.04957731107189771, 0.0376095506362617, 0.018807355119215868, 0.011519403647511237, 0.018522433613637285, 0.043567596454053156, 0.0818735708092009, 0.02961139160869343, 0.09658892473746693, 0.04673026021449797, 0.035644722802023736, 0.026328438637597908, 0.0439746764248177, 0.03503263387228212, 0.048905038274824626, 0.030005059295123624, 0.03412827856898789, 0.07911520228991586, 0.0338451822678889, 0.0053690352867687904, 0.04001393673881408, 0.015402514686537607, 0.017628617764961337, 0.06498728458198809, 0.009847671477003925, 0.04455189303224606, 0.049582493656705466, 0.07751193348198168, 0.034686990322605256, 0.047913712839926445, 0.03816799425910558, 0.04552890794471868, 0.07478780143203274, 0.06416762029872307, 0.02606352351816191, 0.059612235505013704, 0.08918430956621325, 0.05944826587614033, 0.038199706468731165, 0.03540702487131761, 0.07289610818148622, 0.10089362641015362, 0.030927593864861037, 0.006028211810776303, 0.03532984534338598, 0.023616998749334487, 0.08132744971061907, 0.041667257901281125, 0.02771156058917123, 0.08313709494447516, 0.04052995058197168, 0.0129844673210755, 0.0618913624015066, 0.019038271256572297, 0.0426652406402413, 0.024548793406856638, 0.05337449098606745, 0.04516183308536007, 0.006733132881157461, 0.010361714558976312, 0.03713377556132694, 0.012431070302432824, 0.02402734033943665, 0.08003646898413859, 0.02005889380891477, 0.025636565480982105, 0.009709417504528839, 0.034044119980066054, 0.053489377361632166, 0.02115923738587768, 0.020460718416518742, 0.06546527748146365, 0.07503695620764649, 0.061132192251182375, 0.056438467300106446, 0.03222162362128016, 0.04823006884825807, 0.025825710674267144, 0.06642206767273527, 0.004594694680324005, 0.04380819785799231, 0.023237815870332624, 0.053547331913103985, 0.034566162935187744, 0.04822471772410697, 0.019894696268883925, 0.03372496392037119, 0.02089734448330297, 0.04345159925099823, 0.03679325713986351, 0.057889721281225645, 0.020527965614512082, 0.05156280795833276, 0.019582582472433007, 0.024514687172467672, 0.045626587985504063, 0.029262247037202604, 0.0432018737398809, 0.0845769725199188, 0.06147246169407041, 0.034872165265222715, 0.051076012708607225, 0.02615967329831854, 0.02362951662601723, 0.062177388988915956, 0.044355284227358724, 0.041646002791821964, 0.027516238811996677, 0.04689064072144609, 0.04793283822495611, 0.014653218451947456, 0.02590665935478624, 0.01586046672591399, 0.037438329985185016, 0.026087649542117314, 0.014957046049887375, 0.058448988448588125, 0.01930647480842327, 0.08064922441037432, 0.10242092993951614, 0.07849774308382504, 0.036388617159137805, 0.03862947030293365, 0.0340718868368816, 0.05995308717472419, 0.03248608483362102, 0.016720361158912702, 0.008864687781991258, 0.007840872558224346, 0.00551290947177838, 0.03929208273128156, 0.05307305837050081, 0.0010711966845725154, 0.20998609432530022, 0.1893899736986045, 0.09877749238043063, 0.14153659794359438, 0.21896245378640392, 0.13782709296191895, 0.10208953562523089, 0.0979965040460229, 0.1423196776980354, 0.15651908673105702, 0.12429456346698346, 0.06475010376063085, 0.1391574812512244, 0.10939104302275567, 0.1803404681624905, 0.1181125863184852, 0.13428769014295072, 0.10939885711958332, 0.1488014556948216, 0.252326195759158, 0.14980159880172822, 0.059650409666280595, 0.09302146777871156, 0.099661611471205, 0.17625294475545808, 0.12394980857929877, 0.23712736374187857, 0.13425519269320274, 0.10897165584948756, 0.13317131617617223, 0.14739010723367815, 0.12907959460731477, 0.15117378484818245, 0.11143789972148596, 0.11631361268941434, 0.143704213081829, 0.09459289797251264, 0.1799094670962903, 0.13106857336336566, 0.20145549078381833, 0.16463198849270422, 0.15001556715897976, 0.13850031570801813, 0.10828927069181397, 0.17160472159664478, 0.10958215897722591, 0.12583456873413057, 0.08946445259836414, 0.16126314748919782, 0.1786911115050316, 0.24797685414312348, 0.24941352947104364, 0.086939625982796, 0.1401742944313634, 0.18983560704415847, 0.2764392728286405, 0.1096386579616416, 0.17190616187309066, 0.07802271494461645, 0.12083914686715412, 0.19310428971244445, 0.14610666481237258, 0.08966768040291725, 0.14252489733119167, 0.16984883275243545, 0.06364164731254981, 0.24130038256126068, 0.2195562638582722, 0.10274055714328444, 0.17678715318681734, 0.14597540330742637, 0.18432064732957273, 0.14231419250849756, 0.14282429981375896, 0.22310574839432395, 0.140383405791175, 0.17127010971307757, 0.05340920242991659, 0.17292533460403645, 0.15852125752116406, 0.1383244678858788, 0.1304531596120327, 0.14659256373922672, 0.16803308179782284, 0.13928926369595912, 0.24617585804193254, 0.07046630711204584, 0.13610089768565473, 0.12935348636200353, 0.16219449590050405, 0.20072868784829495, 0.09307669505717293, 0.17357191281212916, 0.20832765186505936, 0.1601673506440655, 0.14299722118002756, 0.14374745108427542, 0.11378401334607795, 0.12611129501413915, 0.18928079084763605, 0.12035853394697751, 0.22209362367228155, 0.17406256148411384, 0.21080464395063542, 0.10421686219952761, 0.13980096446410303, 0.1984422677947629, 0.10036652727473168, 0.06688678426848305, 0.15665425528441707, 0.1418025530273876, 0.12965900222620658, 0.07733198708944744, 0.06995758642592738, 0.17513387415918613, 0.14672921850315987, 0.12974845065224555, 0.13250270527937721, 0.12131907030819886, 0.11326531053430612, 0.1989357816355844, 0.11434070645801483, 0.07710406061021552, 0.15124872356893557, 0.14927633827732456, 0.15147007701377715, 0.17492370559803902, 0.2406694019033063, 0.13505347163206147, 0.1589363086367807, 0.1381378335457656, 0.1506783404657918, 0.1836708668739565, 0.14732430028098245, 0.1592900267531795, 0.13261167362572687, 0.19496744618781153, 0.18725425846153693, 0.15427231938848573, 0.09136622756599419, 0.07925489076202916, 0.16571816327350755, 0.0754949312296606, 0.14561479039970907, 0.12992134137499717, 0.14496674130280174, 0.08320033550262453, 0.17035130982197103, 0.11851144233538259, 0.1631942099981731, 0.06818125835589825, 0.30017592493564854, 0.14625079659444673, 0.12356956849896139, 0.08562642870651138, 0.1393959797438114, 0.10081712487003497, 0.12647662702347004, 0.17027745894607038, 0.11620737927695436, 0.19080784922886282, 0.18819349757846326, 0.177983200297721, 0.19994505651054845, 0.0839068447690337, 0.1671355791510113, 0.22916794003498173, 0.092529907462097, 0.09229821949115685, 0.10782011078610536, 0.14191610257952444, 0.08334737841881092, 0.18168165829152833, 0.1179679029531056, 0.10466248788420232, 0.07023889391172318], [0.04188453575836555, 0.004304776366259302, 0.020961353044596412, 0.02340150587711363, 0.024813457632497437, 0.06906500972446895, 0.11003225095449917, 0.05809984004665768, 0.05097663578306956, 0.01585391284372177, 0.1214007429418064, 0.01658070141509656, 0.0132444248940315, 0.011901690140216342, 0.0729287511879398, 0.059461270218654994, 0.030041875565544735, 0.08788702393611593, 0.012654157978813014, 0.022289914214202476, 0.09062213402601982, 0.06795589061033341, 0.07725599882823807, 0.0597575432320516, 0.027218558112039205, 0.010231487272727874, 0.028892331906864722, 0.047064466071465326, 0.01822293153963983, 0.041691642479910966, 0.004729098103369677, 0.029801168824516, 0.04000931722863067, 0.048881052061915405, 0.005951244393438702, 0.027011737355121204, 0.023762588013684558, 0.016876572232332923, 0.007950565336467399, 0.03623856734784861, 0.06039124733257679, 0.017420647876156915, 0.06647986134574299, 0.01263786520388338, 0.035644523619163426, 0.06615339297681086, 0.0768875181975384, 0.030137716995311842, 0.035909455975577716, 0.0226638819496598, 0.005897383145507306, 0.031399111406156616, 0.05161495556333854, 0.022086950709983226, 0.006884614798060108, 0.04126944376396076, 0.033461422013539466, 0.05743878660723568, 0.03613149506911155, 0.054164335296879855, 0.024806181712436582, 0.07428846532298673, 0.012480939753473768, 0.07172013257419871, 0.08470460276810393, 0.06320405789020081, 0.03178427934706692, 0.06384937971409771, 0.00159648725398696, 0.08754654381904872, 0.06612370706974499, 0.010490187503878149, 0.07983295772705348, 0.03324119471794656, 0.028598115839544806, 0.03769485069619071, 0.022406646861664714, 0.04890641340264871, 0.025542407529428605, 0.09826977526949299, 0.04137581124180748, 0.02866586290990874, 0.023346694201351176, 0.03297098784617359, 0.06316543556749821, 0.048204684524887034, 0.03426410212752319, 0.041274837022947694, 0.06455687340348959, 0.0430477062059987, 0.03945841574140134, 0.03527563313142427, 0.033177352780776645, 0.025728890567176768, 0.06153327758393942, 0.01137624575471085, 0.02188974435651495, 0.08212299371558814, 0.007178515811721164, 0.10194763315901642, 0.04629238733961698, 0.06900339327271908, 0.049403221421544595, 0.04724679499744408, 0.053434881697138475, 0.056046452448372884, 0.021751478892720996, 0.013849361435390048, 0.030988068845603737, 0.019930390220495964, 0.03143861664519195, 0.07763729610991094, 0.019332833978677952, 0.053906539049480236, 0.018284180269186056, 0.024845679290592674, 0.10062676734260975, 0.05293990845882124, 0.018335393246924205, 0.03972526331762633, 0.03840276573394095, 0.027993373692997044, 0.07469210938941087, 0.047401261305616754, 0.04858839115308178, 0.007792692331056441, 0.026546170401777473, 0.029591519287937594, 0.027923814824692188, 0.05044241202995182, 0.057784479952627615, 0.028895693117632505, 0.038634679700818755, 0.020699044539322777, 0.09336204748720893, 0.057188720186992045, 0.06113146063721469, 0.10445778919083458, 0.016843592147192648, 0.03408316748156663, 0.045047126740457556, 0.0035311604311103906, 0.06307481885737469, 0.02675885364653603, 0.08054040928160952, 0.01333955960768846, 0.001725104319179551, 0.022611902883997368, 0.04520634662420039, 0.052194271251679435, 0.04195527631729361, 0.033573983312253995, 0.03661070221794709, 0.011518744811896357, 0.01505088224451268, 0.05003661525646045, 0.06224670462430485, 0.010350810254984086, 0.07384890705467233, 0.033256137262909644, 0.017885768583284754, 0.04846405508297105, 0.044495214017168175, 0.029081015532175382, 0.06277718603791249, 0.022114466673003572, 0.032937287638384494, 0.054737384386000135, 0.02545696191279398, 0.0666784696401127, 0.045360885710725864, 0.01558080249871578, 0.042394313645819505, 0.026978935385423324, 0.06824678185606195, 0.05607586256378601, 0.1281963182132571, 0.03230011699000194, 0.05369079719868399, 0.04237470945583717, 0.02330199680140903, 0.03936268922482287, 0.018322701085238688, 0.07542485716722666, 0.03671331586496484, 0.012500307413809484, 0.023793695013849966, 0.03270861805386601, 0.013515025343475564, 0.013160413777035092, 0.02176200685602042, 0.12742715061552104, 0.06413060676066146, 0.060425349736526135, 0.026185965435879848, 0.05438396504389183, 0.0075518577491053415, 0.035094196697877306, 0.04172451914318147, 0.090139621207791, 0.07369798773358907, 0.03133805419859146, 0.085050568074709, 0.10728833851434531, 0.034557402719773596, 0.016665356045949365, 0.027141206214324604, 0.061421145294462486, 0.029058852608525948, 0.02836396106548848, 0.03392070321546447, 0.025449304863990798, 0.06400346297830825, 0.002720571656320845, 0.08592180156659696, 0.01597797312217975, 0.066927831259466, 0.024495383671995614, 0.046510412132427584, 0.020567526394921928, 0.07150893745523307, 0.04778252411333304, 0.05164739555649219, 0.011097121619499259, 0.06074612224174123, 0.01222883936979117, 0.04654329645657732, 0.09417789282217141, 0.06256810915205749, 0.03100793159026052, 0.013366168714128436, 0.030468463965301073, 0.03868783088100534, 0.024058468407019976, 0.042621558306798826, 0.05415951660383613, 0.006917435441151142, 0.06171924159711888, 0.042284483450555035, 0.04649311386709733, 0.016232999004123193, 0.03093229572949631, 0.023382616064120686, 0.041016209570150224, 0.021098528748318073, 0.10683175011147415, 0.015316984800231314, 0.027614389996855494, 0.06420316677840968, 0.01037859817921755, 0.030456704515663367, 0.08050788884922382, 0.062178155076840234, 0.033610150323159275, 0.011614456964326243, 0.03336246260592053, 0.05214417676231073, 0.05369702932394801, 0.02910474319041016, 0.05593421290658655, 0.06101062558891793, 0.022748865998320045, 0.05501478865382172, 0.028125723042795737, 0.03350631093546268, 0.033636944248310985, 0.03470862464558694, 0.043655639108751094, 0.026242000937101342, 0.012153050291442103, 0.0629272741535979, 0.03610902187985278, 0.0701441518181274, 0.02451042197794924, 0.0302688961458062, 0.015291895420711129, 0.028005075686040427, 0.012036455539806236, 0.041315677170191085, 0.04889378827365656, 0.011787981624835202, 0.07270503053141218, 0.009714140436582027, 0.02326670121551762, 0.014752968845348206, 0.023396792521159497, 0.021361239449751955, 0.07593317182674524, 0.035985011397109884, 0.0281640159476909, 0.027420964287293535, 0.06073475732738453, 0.017516025822729837, 0.04600690850507348, 0.042923898736555735, 0.07227052844339801, 0.03340935484776574, 0.03414522826431259, 0.022723849397152666, 0.08088790676406316, 0.08727812959301857, 0.019254225696767532, 0.045337596637827736, 0.05177791778659148, 0.02347759181453336, 0.06483605116485588, 0.06455535654939952, 0.03786940766017764, 0.046552003045836766, 0.027484992000785087, 0.051467897325393655, 0.05527353101980783, 0.042114116987513925, 0.04436529316608945, 0.007038091895200553, 0.10564839707747584, 0.0012635528635714325, 0.014147557329476602, 0.041345757612537955, 0.04140764985594057, 0.029145223276329138, 0.02806839668342183, 0.02039800071337771, 0.036184753501607526, 0.0448990879099696, 0.042817025640678984, 0.013431274696373412, 0.016195675200452248, 0.02689955143948957, 0.0702050175037115, 0.026992814983391476, 0.009167264741394789, 0.04308107316554074, 0.030398880199138677, 0.044053376637279026, 0.033481612260783875, 0.026571085496294885, 0.05443421275084538, 0.06737888850752385, 0.026154954196704973, 0.08491349196241749, 0.024999346952104283, 0.024001781731062842, 0.06549787452264179, 0.05068792022704598, 0.039146242573136286, 0.04546212039947991, 0.04028584815621857, 0.020650687154322382, 0.09403885552479375, 0.07048830149635192, 0.03304357850743878, 0.2571478918675454, 0.12388372583495033, 0.1233109525374828, 0.0933057017203781, 0.10512701295796903, 0.19146587279054428, 0.1626522947222956, 0.2324719546783355, 0.11074857380721839, 0.11372574469855717, 0.11109719743892071, 0.06489956751465797, 0.06863715727963755, 0.10280047287984241, 0.11941485152009035, 0.38042286891610394, 0.11873788260404142, 0.2339049681059776, 0.0914584722129568, 0.17611976803070115, 0.1442558576743449, 0.1604218144089945, 0.22009045696787297, 0.2536630651523029, 0.1065932592797664, 0.059255276836695216, 0.21955070205994193, 0.1787301819891699, 0.0968898287523658, 0.13809598982334137, 0.11031634700033935, 0.1071796995858031, 0.12667997740209103, 0.08821425073209309, 0.06927766041049073, 0.09155385015952973, 0.07016922587588911, 0.12055747932003391, 0.1984894281673816, 0.11946988727657065, 0.25427979657486566, 0.1331694315998785, 0.11314956230982659, 0.04816223176256303, 0.18774662317047197, 0.21819967536195634, 0.12326498726202596, 0.13184861940962653, 0.23071215878571236, 0.059099550313887105, 0.10812531255425946, 0.16350571666994404, 0.10803047086923354, 0.12691836864236863, 0.17253371045714425, 0.1189531303281265, 0.1463215371533748, 0.2288836601280397, 0.12150070975504576, 0.14072129653105814, 0.10882855828611121, 0.19099246109685591, 0.11548081382868752, 0.27109823039462494, 0.21150411286902046, 0.18115503413061942, 0.23847253752812264, 0.14122138340626994, 0.10515326679113413, 0.2815518678436356, 0.19735543417834467, 0.13949505023417935, 0.23007756219275538, 0.13238213836185395, 0.14329489230388595, 0.16747759144392707, 0.2291289921249113, 0.12166358004774779, 0.13724858932677778, 0.17799210223940112, 0.1403642382713095, 0.13833747605883306, 0.20395871371992175, 0.11977378669525347, 0.2672576171255881, 0.11567817339974067, 0.19415016826843062, 0.14539460140851238, 0.13005701554638724, 0.11328027989234656, 0.15012580721128374, 0.1963996322404954, 0.1585260991968455, 0.12667230120108974, 0.18330879839918307, 0.12575758455861963, 0.18460328780835678, 0.13506362995793744, 0.13870728202164173, 0.18117769501141964, 0.15961812688939034, 0.15906222284801547, 0.13406406907785323, 0.17506599876909487, 0.1629134387739243, 0.24709556191678972, 0.09273852086475781, 0.06556640874834792, 0.13228608625790766, 0.14174305863918799, 0.07182442012333101, 0.23804916669764828, 0.1287996201145072, 0.13640345645047006, 0.13003211768884815, 0.14831010222194657, 0.1540959506265579, 0.15126032214010918, 0.19501125109532189, 0.16814742808140096, 0.11511345168635731, 0.16572085990300103, 0.19428706818049957, 0.11287792285363521, 0.12762911437499908, 0.08952448324811074, 0.12702811073752182, 0.11605456771869814, 0.11105681694443188, 0.15448363708151927, 0.13130472762690437, 0.12514495170645176, 0.13555530518774064, 0.16300060425794896, 0.22043708111009291, 0.1243945072975851, 0.15035978578511747, 0.26296403138868274, 0.2234981539508989, 0.1449664501893905, 0.18482845637106127, 0.11500472082726418, 0.16327308641085703, 0.0800001410947692, 0.1498067469125794, 0.09349546936010161, 0.058272351555886774, 0.10454706141665097, 0.14697585284950274, 0.143584442895747, 0.1370464800105941, 0.11720658775659339, 0.1493013127436561, 0.1170206199129743, 0.11924419777407763, 0.1841262601796658, 0.11744739983471171, 0.19124220576017134, 0.1863599120969734, 0.056688966560027296, 0.13566755239040623, 0.10156379246543493, 0.1630459106977909, 0.12873133103693687, 0.19120144988259963, 0.06820062505862406, 0.1369913216800459, 0.2257276689934154, 0.11181191916787818, 0.14392872280891866, 0.18263266451897162, 0.14889687960666997, 0.1530198422410796, 0.14745614401275112, 0.23279404868522, 0.10321104238110204], [0.03650919939841955, 0.06648536185703932, 0.03620790084823966, 0.053197497862481305, 0.018799788085743785, 0.0358111247600567, 0.04527788774500932, 0.04375831404280278, 0.033858496876012896, 0.08421899495466102, 0.022059055533440366, 0.04883706712374284, 0.05619916058475933, 0.08609473825462403, 0.05924940094231598, 0.013382519903262297, 0.07152356973458683, 0.043548172294733026, 0.03352494219378118, 0.04794278204621327, 0.038316002446076566, 0.011720124429332153, 0.013144587358129362, 0.03808859690663315, 0.07934180343703878, 0.03414566110398981, 0.039110504571468606, 0.05877091008568964, 0.02538450340169572, 0.07528847053406701, 0.04918140066306918, 0.09124103347740828, 0.07886977070161412, 0.08722507800426214, 0.0375966995113319, 0.033032516197812174, 0.014439304678460524, 0.03858984057461062, 0.02662955141145616, 0.06064477263979855, 0.012659714989093764, 0.044983062637789596, 0.020693657025995276, 0.06997345210683924, 0.04799241305238778, 0.040409709251816237, 0.0015864826245008097, 0.031469624053927205, 0.05938217164047303, 0.07759969651458726, 0.04741289052030733, 0.011939002452568423, 0.05380595553546183, 0.05190252964835494, 0.032678005180411765, 0.04941125002299105, 0.015889346325439552, 0.0033102716664753615, 0.07053744603669451, 0.06258494010375393, 0.03683303242489215, 0.08348898977161416, 0.03680047368811023, 0.05275212115638199, 0.09510055379641634, 0.030257820429640914, 0.03809839134074507, 0.029843705856511672, 0.044650055708423744, 0.03137861089330287, 0.08270533545122993, 0.05421126584312128, 0.039625246708671895, 0.04274546153723233, 0.04293683413115721, 0.029853605627713185, 0.03393512099019943, 0.09058746854744612, 0.03292020770811266, 0.007784664208414935, 0.034964647399441856, 0.03786384969228699, 0.045644916639092474, 0.05309000040494627, 0.023886474007139766, 0.0767647602685517, 0.03853147616609931, 0.0785272834341853, 0.011052418473897683, 0.02218367697130288, 0.056751732143663594, 0.022409879752705177, 0.054702270745990746, 0.06368734445723315, 0.06185194717780237, 0.0392499057606103, 0.013050127759455674, 0.03954596426938811, 0.02687562268317467, 0.0503029189102592, 0.018185142337554888, 0.04447477862178799, 0.04605317255482078, 0.03001185257979218, 0.054526315671542, 0.07397263025444362, 0.049900554210668614, 0.07262422357715907, 0.01605064134984728, 0.033870566591259935, 0.01935490497177647, 0.04423585111996339, 0.034244241298086224, 0.04666910341550266, 0.05581392944159527, 0.06118766467777952, 0.1104046079900957, 0.04612634544290843, 0.021057606246622822, 0.055922158513098, 0.04469050132038613, 0.07393306947403377, 0.033195095377102975, 0.02379698153104513, 0.024117202452954747, 0.01700570209762983, 0.04759692782235723, 0.10676668626406502, 0.04178056613572183, 0.07166410856429609, 0.028118043011354826, 0.021031972944676396, 0.011859615633804953, 0.07365556178434242, 0.046506842162700436, 0.025717305402541836, 0.008197898259236207, 0.021108284878033786, 0.035725433995286306, 0.017394621954149297, 0.016024099276100677, 0.07139990782184948, 0.027722040671975385, 0.017526385246685917, 0.021025493756056796, 0.012853465328413635, 0.012140691378003648, 0.026203303920826124, 0.05953936139121652, 0.023445741709081397, 0.043160263674273606, 0.02665339015243996, 0.030585401541283055, 0.07281465771337671, 0.031212057632904862, 0.08143856310315671, 0.03963418312430863, 0.07353916238512724, 0.04995558230626968, 0.02101378601735398, 0.04197638587004716, 0.026906614770151438, 0.04686077861415763, 0.022079757144374233, 0.03306662243220114, 0.06468988924978242, 0.07238348810783318, 0.062106644599548275, 0.040323252399121566, 0.02618164661520672, 0.04166374538814829, 0.023531576115337592, 0.08896613538625742, 0.012053721246399708, 0.009023507384793654, 0.053512049733751246, 0.015722608246329813, 0.11987353134299479, 0.04709225974135822, 0.013601915035847456, 0.027040774002671245, 0.023506310535594824, 0.0374761785590841, 0.043048441650406014, 0.037148246962216594, 0.0572550748925536, 0.06259074321978035, 0.012075723291585043, 0.03808745543562597, 0.0893610000850693, 0.02461981933353649, 0.07492670849446328, 0.051108958319790905, 0.1116757087349411, 0.029973868025286548, 0.07803131811200612, 0.020280998019922166, 0.057577134425481485, 0.022560186203449004, 0.04494457438047375, 0.06904061748495988, 0.018767055063959093, 0.07011360789258635, 0.07049008648121549, 0.019270370999771743, 0.08122044254935558, 0.03946406563984291, 0.03403255588284904, 0.021692403937659917, 0.06603931482400625, 0.018994966221432534, 0.03183047636412084, 0.004114354678970432, 0.02859454778503747, 0.04349573740675565, 0.03151015393556126, 0.014699805216232856, 0.05164218998904671, 0.02608520572163886, 0.05395636923851506, 0.02982750501213295, 0.055011057805630474, 0.04057093245548107, 0.02453468015207158, 0.026566117416105928, 0.07440851130072149, 0.046362974680960185, 0.05900728268428676, 0.028231966031354763, 0.03109755430130228, 0.01400475279473129, 0.10352387438498198, 0.040035900479603204, 0.061067917474335244, 0.04493414409338467, 0.038811515776380416, 0.05640330003394235, 0.008661937824780903, 0.03403031890611014, 0.024556050174719384, 0.007423135825628115, 0.031358750063865896, 0.00999912801724408, 0.033724297423877066, 0.019639384061578783, 0.052019032469439896, 0.021950240404675567, 0.03506016707228076, 0.02374562299660137, 0.01077874026621782, 0.007646291013506632, 0.07718024805428521, 0.022281703666874, 0.0354258323298587, 0.010770997032523157, 0.042392149447433414, 0.010046961589626247, 0.04778536629953212, 0.09727505606509025, 0.11924227489338768, 0.07914941577661423, 0.06082694451775282, 0.07357569711823618, 0.007967296696733683, 0.024745013422122406, 0.06428619921808282, 0.027146894417162386, 0.014132317925442853, 0.043155134715620554, 0.05913587437281686, 0.029539484680900653, 0.0413168263020775, 0.02549446383190732, 0.015208020284321281, 0.017954413891739903, 0.03772362495862669, 0.01927361729735088, 0.013462465008600585, 0.015758517660170553, 0.027256496701269384, 0.06417506284290744, 0.024510628821688796, 0.00431932102430672, 0.02036546687445333, 0.04467720969489986, 0.01306574063135251, 0.03293176031401081, 0.0059547104624911185, 0.009085545184901886, 0.028765515627099142, 0.03979178273209161, 0.018255743085436763, 0.03800598198487874, 0.049541538596273436, 0.022335465802180193, 0.029996804697739504, 0.04048916406088299, 0.029346811652724302, 0.02280165711718221, 0.03346102747825846, 0.034105648331704645, 0.03343661225611164, 0.040098650741481015, 0.057921012142492886, 0.043249080077775066, 0.0274430429412713, 0.05582799481588507, 0.06268350497609185, 0.036197275208729895, 0.08557995781302453, 0.05727173730490669, 0.018702839658926093, 0.04567390923658687, 0.01282316080534891, 0.06711821943040817, 0.021472507975094264, 0.043342221047609084, 0.014864273759866915, 0.06753481038275265, 0.06318081861301776, 0.0052593267079623, 0.04134046011454156, 0.010353576790000643, 0.02094684333931054, 0.020172803422376033, 0.08470872432113656, 0.015825292756480556, 0.0624752439738762, 0.05182499388953851, 0.09158915149108057, 0.004749296969103237, 0.015151297219187744, 0.024589635469319842, 0.04120885387002941, 0.0339781942837421, 0.09423639895694871, 0.04466140913146158, 0.047839605324571176, 0.01200188773744289, 0.01961719049441238, 0.06142432455934825, 0.049289790613036004, 0.025745388270626147, 0.030369447101087823, 0.04025621204486778, 0.03812192173133935, 0.024549084520267866, 0.0037108645483385776, 0.03127798141400901, 0.042735770524990176, 0.039685361628090186, 0.05159666138370672, 0.12503630511703032, 0.232230284581742, 0.2091124170129338, 0.25271506198952276, 0.16946588072084612, 0.16268208022079161, 0.17738336877476785, 0.12476966821498449, 0.16091929658526377, 0.19672302859685115, 0.1908457399375977, 0.08582130615268985, 0.2268784249862356, 0.3169954466002603, 0.10615148701735082, 0.16323300469065868, 0.19470982614063448, 0.1968784371931707, 0.13741547392020304, 0.11412235607783641, 0.1303557285498227, 0.12323239788172707, 0.07630523008805129, 0.1170945703803051, 0.18706000920745636, 0.06691126077766381, 0.12961101447862963, 0.14082776743077463, 0.12873471714556217, 0.15439559825726096, 0.10792085134814824, 0.0998461160868887, 0.12725666540885164, 0.25773523615733274, 0.08817298157561211, 0.14557679243866475, 0.10102457381905088, 0.1781247886678865, 0.12678251827075598, 0.19105586253346937, 0.16719882737003988, 0.11573284143401731, 0.09855064608517194, 0.3372171647366016, 0.09638907538065988, 0.09448280347691429, 0.19801636887413843, 0.11740889625563738, 0.16954656510103136, 0.29080069413588894, 0.13698744527514906, 0.15714511846102056, 0.11763684571750703, 0.1935027473636212, 0.13300501380956944, 0.20828899506840015, 0.06728073732266504, 0.11060933732698042, 0.09545027293385037, 0.10070644814761416, 0.15258779929530236, 0.11964499965430268, 0.18989808917526277, 0.1515786316726477, 0.21264752973952603, 0.09669482107124022, 0.15137362654411024, 0.116838873213818, 0.12789451021460757, 0.1172765315840802, 0.15185987787140956, 0.09306841364671146, 0.12190015565964485, 0.17562711220835486, 0.10104731130864351, 0.14593208869618757, 0.12560429802585032, 0.22232372584121846, 0.08760914086334168, 0.15486478114560728, 0.13742840548436489, 0.1330442221895341, 0.18103603003246171, 0.30297373932215477, 0.2105088727248292, 0.2783650646526968, 0.13767793564306152, 0.17961786338879218, 0.11481732806010593, 0.19854783471072876, 0.11463590311787783, 0.08990858441158649, 0.17792585095570934, 0.14231163377483047, 0.09337113328999089, 0.162367585806116, 0.20339927035233668, 0.18446862487302673, 0.0847911477209099, 0.19194463177794413, 0.11236978439433921, 0.154933238762521, 0.11795004544359063, 0.1896485896600831, 0.10976782804655452, 0.27984851730927346, 0.1538445665350845, 0.18781204707920554, 0.1377942277899673, 0.12991251604210946, 0.16626404688483284, 0.11848379422219531, 0.08789279257818576, 0.14413162885654357, 0.16144731502619483, 0.1690019378739019, 0.18590902338825888, 0.1340886911437396, 0.06518271361147204, 0.22492447177008276, 0.13337995256147078, 0.1440165011632827, 0.1410948410029373, 0.13894852310899766, 0.11047814476994738, 0.08013517941318213, 0.14459281378696043, 0.1682149663928055, 0.13316227633866573, 0.24976612909907298, 0.1398475426098993, 0.23470718473676713, 0.23554575990044305, 0.17850913497949802, 0.1507053374042434, 0.1155303490738715, 0.2009017471103899, 0.14078259888675906, 0.21083631402542516, 0.0866914824432423, 0.13939688372756207, 0.14197970319899822, 0.24083930488315322, 0.08930121458345845, 0.09871956847247579, 0.11695174094770225, 0.09845768897643975, 0.10968595623008667, 0.1786370256975774, 0.17022787773561093, 0.2095032597501432, 0.10645933178884369, 0.18536552997125735, 0.17080451211621686, 0.15127621080365874, 0.1421171546943726, 0.10955623456186826, 0.18380730713327087, 0.13011327704354642, 0.1619086838177135, 0.12668915513542392, 0.1874930787110521, 0.10480740873683846, 0.12381553634881012, 0.08881541524803446, 0.18949342621189935, 0.10890089996880102, 0.14537244614574218, 0.19731628708541396, 0.24556827370918569, 0.15868926060295876, 0.06787051011117236, 0.18118910972149144, 0.10565096347202217, 0.11529887560755016, 0.1841563061480561], [0.08558858396305193, 0.023026411992407615, 0.03813656550201197, 0.0608012575896517, 0.031305359481202985, 0.07991050114674915, 0.04641542872113567, 0.05087038321841148, 0.017017547732159015, 0.007897789060558763, 0.05594305356123275, 0.04761651286014146, 0.05403303548753743, 0.0695134163083088, 0.023432589894641313, 0.014233789143843517, 0.006899375875946135, 0.024212572738648425, 0.032748420151972005, 0.03755174547193512, 0.03250192753189514, 0.011099601829154117, 0.02450062179817788, 0.0200574669701558, 0.03129423205410281, 0.0117218509999915, 0.11394378098268663, 0.04573371389039582, 0.011318818846296881, 0.020535980809419867, 0.060558162569519014, 0.023648666908904433, 0.02035437775174937, 0.018759579961037925, 0.0294585436612608, 0.05740012981057648, 0.03547699551188177, 0.03657133678995794, 0.04451743822785155, 0.04675292492573781, 0.0349905526626014, 0.01956996883475973, 0.062207680105442004, 0.027486550989711, 0.03059494508159978, 0.006663796657155599, 0.022297674684875438, 0.08830594379575023, 0.00176154209428557, 0.023057360029328736, 0.014988900943388863, 0.01163696941559113, 0.01347579015043354, 0.021038557470385588, 0.061604772739472895, 0.03329750218038117, 0.04425242543220521, 0.08354778701980269, 0.045472569838767095, 0.024082561872238596, 0.1438977881785362, 0.08712816022096143, 0.03364990262555019, 0.02708157009985899, 0.024347212691340717, 0.1061843598501817, 0.08491408185011919, 0.0276453533555351, 0.07043411609746757, 0.07045257881644272, 0.028041832584647403, 0.024243662501835538, 0.07374142491889578, 0.05338924966992871, 0.08842418946686292, 0.04649064706398114, 0.051273774475820606, 0.053939473169345054, 0.052875170198779915, 0.0674681147680648, 0.0330052089937512, 0.010687512600974692, 0.07316069196789496, 0.06367460824549198, 0.055128847654428215, 0.04105417305723794, 0.025721612731896104, 0.04132131557731379, 0.049340042150429184, 0.08302047337976196, 0.04250894338192959, 0.031222985877144723, 0.049195718846373984, 0.031412408777302316, 0.054040765314693415, 0.07986173198948945, 0.05037365180830802, 0.04061295620856747, 0.03822795213049939, 0.046126908517532775, 0.010645354782501537, 0.053370825255349766, 0.019517001515674978, 0.07855893052633732, 0.03859473204600715, 0.055335316010901046, 0.05568061865145161, 0.08286063679524007, 0.05380038224581269, 0.01757011929106328, 0.033882065571003386, 0.04061660278708704, 0.052989968474233345, 0.04713015045009313, 0.048388936331555735, 0.01712732813170841, 0.04794591534582358, 0.10479097615086264, 0.021269542555655205, 0.07311585284168683, 0.04528196333276649, 0.07554550835442159, 0.039766900196310975, 0.02395679321770947, 0.02614215669792987, 0.016272251434143514, 0.050057866535479986, 0.03227993057319715, 0.036179835217133645, 0.03955045737506401, 0.0685038120155373, 0.03764249241700576, 0.061595732901966384, 0.022164756514792962, 0.03446631486557665, 0.040408958485650445, 0.012057283555247612, 0.09295965214410136, 0.04008214537715239, 0.063432244839327, 0.018318930017431418, 0.03316956166658671, 0.030270064429890726, 0.03707268387980519, 0.045781307102691744, 0.02360763715489978, 0.06750471078820768, 0.07144781896063397, 0.006219918131753202, 0.027673974400386218, 0.04531789668685487, 0.09086624028221255, 0.08087787867313431, 0.018816956116126913, 0.03562263265672711, 0.019772014948689652, 0.0800078709219252, 0.04723134683445097, 0.07327703774095544, 0.03215468668889615, 0.028388000904552402, 0.05454485116886997, 0.043777079366508036, 0.04045072942972183, 0.052426637210432565, 0.03877516490437331, 0.04192785036960437, 0.023469549806548223, 0.02259100592064281, 0.03596140056728356, 0.04675120122790818, 0.04122313757937762, 0.08720667657232092, 0.025863212593380484, 0.040893669976221944, 0.06361218357098199, 0.0636578960374238, 0.08652518773751874, 0.030484720351054307, 0.010254802201093446, 0.0672112531479328, 0.05767131344445291, 0.016581992273248972, 0.03600250884530044, 0.022705200901855866, 0.02265779155066177, 0.03755220512468969, 0.03531995514828352, 0.04778543141700568, 0.036135965192149726, 0.07683380777316709, 0.03690792134993019, 0.010062834931417339, 0.04768904989525195, 0.009599180325054595, 0.039194368216539585, 0.016348578689259388, 0.028035523850590955, 0.04548865385473736, 0.034191254826803366, 0.05702933176390587, 0.06439250157845598, 0.04705432306734785, 0.07329482630255722, 0.01565401847924917, 0.056832883837482626, 0.05322121977505665, 0.03099850679357206, 0.03261017575559597, 0.01916806761836333, 0.03026316006247315, 0.03380587046605445, 0.03739723319848699, 0.02751583853105624, 0.022037806169640635, 0.08664049163100221, 0.08344375994056465, 0.020420755439948653, 0.038561223360199126, 0.03111497705592023, 0.04817858773974642, 0.011063221271239944, 0.04540780859608804, 0.04209417954928452, 0.066528293424316, 0.033446452655499025, 0.05827312147425068, 0.05653735775981219, 0.040023803951278816, 0.025458589849633076, 0.016967719458344004, 0.06388856128098504, 0.08104439554435593, 0.04862971010527784, 0.05882747418757889, 0.10232837885738381, 0.024259750348245426, 0.008568183984607458, 0.08876185038036878, 0.07075411102343952, 0.03126741514631337, 0.12412804659576186, 0.07954274829957755, 0.08978961861782497, 0.05544710739125168, 0.038196247581753044, 0.02279594018604727, 0.03134475938314873, 0.04103458801945371, 0.0722598415168543, 0.07763282981731238, 0.044996040167226914, 0.06226710171528882, 0.0466700227210118, 0.06733020361993583, 0.020927580058454506, 0.06392179417514032, 0.040098918872254516, 0.055654483561914776, 0.044193674149292136, 0.10975406910743445, 0.035353900504208384, 0.020179464556877653, 0.05084598714846277, 0.07934940302924764, 0.011072535942789289, 0.024487169294227517, 0.02250229676945075, 0.04005852688644682, 0.032841580274004134, 0.08080629541748956, 0.03293114361323176, 0.015342981036331867, 0.06857731815187201, 0.019146801017585303, 0.02233674325379393, 0.003671348057386856, 0.03408282657244033, 0.05409514606599847, 0.020763179505123727, 0.03921945376562015, 0.031554481698079936, 0.0763136800378561, 0.07013875089826123, 0.014947553262895635, 0.032975174516679785, 0.07261863879619107, 0.051022401875666076, 0.014112006061740462, 0.03174207556331831, 0.02704190589757937, 0.012771469980267989, 0.04858867843605338, 0.06234454937399395, 0.014570705036843016, 0.05356281071961407, 0.028359751412344557, 0.05970480190890451, 0.03927466572232304, 0.04844184236360654, 0.029947342230908336, 0.04124173053329991, 0.017210657430452206, 0.07236612855546898, 0.045976406714368256, 0.015325270998742313, 0.03256037621007812, 0.026834478015981378, 0.0387788497872891, 0.01899935015957923, 0.007915054288347283, 0.04453819154972031, 0.014909546683362175, 0.10830109908936486, 0.01152936757857641, 0.01351770569360064, 0.021971614257762992, 0.04313934564350113, 0.023634421503952435, 0.01878455251214966, 0.13844472836823235, 0.0585567616977759, 0.04126835208866866, 0.029754343615364165, 0.038738136044553215, 0.03287108231996817, 0.0367735150540548, 0.03893792794476594, 0.020800509054454106, 0.00831299052093058, 0.033215281793907765, 0.02694153305774014, 0.04283337395698313, 0.05256092476267969, 0.08822741212263223, 0.052957356111296726, 0.0030032071076528805, 0.04128835847481124, 0.02714332253221543, 0.026303900841383204, 0.023482324322685603, 0.09382656490009639, 0.04535325164456041, 0.0077876691882979255, 0.02768362519301234, 0.036256681496818224, 0.09637956822951955, 0.037829448514047175, 0.05576520241917141, 0.010365727902089637, 0.015396943312108278, 0.02029942243450111, 0.14555466781941154, 0.3095248942413638, 0.09782964243523537, 0.1420678799190829, 0.15923459263097856, 0.15284249288660867, 0.17292703531922834, 0.15130916790616128, 0.10469438778536935, 0.13542625001601635, 0.11748021138050865, 0.09342596986361089, 0.14869414209838838, 0.16407721826145727, 0.13464079538901008, 0.12416098837650592, 0.0862714134517216, 0.19441580159529565, 0.17343056959009942, 0.2115406705847671, 0.07257068169213111, 0.11218301215839964, 0.1320220004286497, 0.11159319340461686, 0.12087119232502677, 0.09210409281114418, 0.2184545221708475, 0.19715335550567797, 0.09216439159166429, 0.25666088977408025, 0.15067466324375522, 0.21026429149412343, 0.09005191180134013, 0.16366624273359776, 0.10827238611396282, 0.26899154988988755, 0.13258104543051413, 0.10661320054843541, 0.10139864689159779, 0.1685021267903428, 0.10990789956262997, 0.09854432585979662, 0.1957660162400815, 0.2426675430709316, 0.09354806129610346, 0.09002805582337803, 0.14220156226186983, 0.15240116495518916, 0.23368464121895455, 0.09749209643491814, 0.14807885092112327, 0.10217822562422484, 0.12004484392462239, 0.0991501098859214, 0.09848516855028369, 0.1452864910806379, 0.20359488324292246, 0.12375405013200738, 0.1261591984920444, 0.1910294325000817, 0.14827340661037355, 0.13006777142084416, 0.15419992407964123, 0.1819846767090982, 0.1019403093584603, 0.17989095841203967, 0.1775218468279608, 0.13311304752865147, 0.2006252659785171, 0.11122223830992177, 0.12230827367954678, 0.16639798969751404, 0.2310094928308841, 0.1825325061837512, 0.21688699902546024, 0.13741311436939624, 0.21554501216498115, 0.10528959979813908, 0.10682539924258187, 0.10838701585007292, 0.1260580748860394, 0.1425551884477177, 0.20532996513910834, 0.13237240904521558, 0.19007422811081334, 0.14419466257095337, 0.1806359176313685, 0.19634510210204512, 0.10004743633251037, 0.18657198055617272, 0.21832208089049787, 0.13164163777424445, 0.15834599192584717, 0.11895908283129816, 0.20681062923564067, 0.19970291143944188, 0.08180782514353914, 0.13692283341961523, 0.08790672005664918, 0.18449732252667028, 0.11288276452931667, 0.13583262901633017, 0.14438126626754963, 0.2231891600475196, 0.09575637868575512, 0.13546291498407242, 0.11580748904135921, 0.13974068866622064, 0.2215170352569511, 0.11783694022244985, 0.11749885796058564, 0.13941212887725524, 0.1578727947367776, 0.156130496292345, 0.09139088027539755, 0.09241451163806262, 0.19607926959231978, 0.13689436559234897, 0.185948813995046, 0.1372770111887686, 0.15003717083844448, 0.20646518486882412, 0.09249333442459184, 0.1997034017357134, 0.08202259023223193, 0.18796292043501334, 0.10343604240446322, 0.2084279940613816, 0.11531333168668133, 0.13021371117041958, 0.13611055039350065, 0.0925059442318255, 0.10479434693772947, 0.13153653051103317, 0.06723969033168209, 0.1472290602302359, 0.09845373596275046, 0.1345556064118301, 0.1644156605846459, 0.19646524001033078, 0.08419808075432816, 0.10660668114019979, 0.10610069538797103, 0.11782919507353537, 0.20346736024704673, 0.1472112869903926, 0.12478358037168942, 0.2605816818052723, 0.1640664317434834, 0.11698936352566366, 0.13810130647353588, 0.1795683128218497, 0.1541079782069691, 0.1021970101001282, 0.22197336318992802, 0.0886887272879962, 0.15046135372211858, 0.19625966797672934, 0.2532895206804237, 0.18376964625091324, 0.11523612534567235, 0.1081707262464108, 0.09892947656372864, 0.19010199113718926, 0.20423576175685854, 0.1383442789196007, 0.12219120778383748, 0.09440458589984525, 0.2245298598802859, 0.12834431873934884, 0.192912599192031, 0.2269497324502276, 0.16583915920026843, 0.1574945005197679, 0.10034160643455484, 0.1784098346627528], [0.036129139348744385, 0.029535646580400008, 0.029454318686358394, 0.029688360462445888, 0.014815910629207089, 0.036472193521237185, 0.002312486913363119, 0.025640824929841106, 0.07887377734145812, 0.042649007237125794, 0.018068197100693663, 0.03260606952432183, 0.02597914276374204, 0.019312823762095744, 0.05275881293440058, 0.005174396764261709, 0.02951251838596598, 0.06228926846937788, 0.08608235061288842, 0.014018378626074524, 0.01799502421260601, 0.022387479341799216, 0.04099035793314538, 0.03975675336175388, 0.024573348440049637, 0.09467453230172397, 0.011674269279014441, 0.015815384366789895, 0.017556959815743952, 0.049828614724139055, 0.0566869440879072, 0.05128598974777326, 0.0386668132588027, 0.056902007950890454, 0.04405038123349509, 0.008025335039072221, 0.002934306356755476, 0.07253660610125912, 0.056121935091552236, 0.04479134530429879, 0.021393110622621832, 0.05204108814077993, 0.08240593296866264, 0.046416872796872934, 0.04116326780809511, 0.055534996828364755, 0.05371332401409746, 0.009449793179819902, 0.04475032895683281, 0.02290610171433899, 0.012655951582165736, 0.016283729346469045, 0.08180609378483027, 0.04856730841340558, 0.023428782437657638, 0.05406249156822601, 0.05850825684085008, 0.050012839717730406, 0.05180722831057445, 0.011809986542850252, 0.072675934512048, 0.019336919142534176, 0.018721229599548445, 0.041503993073298086, 0.052759904609692675, 0.034859310309853286, 0.053222395720020424, 0.027602126844407573, 0.05481110119651403, 0.01936169825644503, 0.10567799105399078, 0.022314773767345378, 0.036111791287699056, 0.05454202430442937, 0.03643951221038738, 0.024031921545223846, 0.01988383505733744, 0.05611225940106858, 0.009498465618479156, 0.0324662508172614, 0.012592097196067053, 0.06456030547739038, 0.03477763767624575, 0.07491959153764671, 0.06103816261935619, 0.029174598917785673, 0.10208895339840844, 0.022802465339942325, 0.052366679339038755, 0.04075389723443697, 0.04427248927494211, 0.023791308649965835, 0.05800148967893855, 0.018541446000698115, 0.035480776155788096, 0.09013691691741829, 0.015443354833781, 0.03164777397027901, 0.035279092018402396, 0.04045283617151361, 0.0601943972099933, 0.0074108856009139175, 0.0868174043153563, 0.011474867126033192, 0.04694741166707489, 0.010811820900398157, 0.04133254642628374, 0.06896213943799658, 0.07539061303701132, 0.03569539568777527, 0.009590398084612624, 0.029536489277116718, 0.030169320037408225, 0.030769113255965135, 0.013942200758103884, 0.08275756732590737, 0.05112987252012376, 0.04213308915495873, 0.05377007197708853, 0.06694831645056125, 0.050195375487448714, 0.021957399496327967, 0.05684985268500544, 0.07358675942786279, 0.01770964305427286, 0.04683302707910057, 0.04330855148333696, 0.018563767887591835, 0.0398201126635315, 0.03439720224348768, 0.03548156905678972, 0.004212532198101643, 0.059676820547470165, 0.04199551508551644, 0.0554279973279805, 0.06889820940071537, 0.011348583277374988, 0.01492090680966935, 0.013694414407044891, 0.004970182621506073, 0.0509870775614775, 0.036689245382383946, 0.03293323886370467, 0.03417214476353219, 0.03273794389960747, 0.008659727661119354, 0.04513026260200047, 0.0419175464870228, 0.038705067859301646, 0.019313017199296626, 0.016840462678021962, 0.034446798775705605, 0.0515411046874379, 0.0861951877032557, 0.0786596864101387, 0.056908048554173404, 0.05979062290862203, 0.04369323870407478, 0.032849206679290345, 0.01933974409175496, 0.03162869263530499, 0.012016868586802195, 0.04246297810647277, 0.03161016479885626, 0.07029595980120283, 0.08822523643292728, 0.03153346216065749, 0.10946911504311908, 0.028572854090241656, 0.03908548797030122, 0.06347429540549075, 0.10141006160166957, 0.13286592288603707, 0.0050998918407957165, 0.06621355386150461, 0.047714667875439896, 0.029002979900988362, 0.016387091844432777, 0.025710828129142046, 0.05640325789910652, 0.03617315876087354, 0.023221758667439706, 0.031219084574390325, 0.05181074082370728, 0.03321262729925013, 0.042847531261823835, 0.06279105222934196, 0.08106593027590744, 0.026689848276756467, 0.009570921256747699, 0.00914605463960118, 0.029585053505856666, 0.005180378953340434, 0.09246609999888367, 0.04132269453557749, 0.04071850014189559, 0.05173231257245906, 0.05704256976323743, 0.10678328738938417, 0.04879443816119625, 0.057283408654433106, 0.07662039099922104, 0.03480353144808643, 0.039105708861062606, 0.029741595912304138, 0.025935265077878873, 0.001118468020239004, 0.016454928930127816, 0.009892931951570415, 0.04282967758274848, 0.04467124570040934, 0.04158056356132992, 0.028448920216291185, 0.05615771905849538, 0.015882831705253453, 0.03501606339047994, 0.060447593099407615, 0.018074697356731183, 0.07498780400642464, 0.06043376904281397, 0.018091947741566167, 0.0629494294163681, 0.01480868737769103, 0.05460519591466554, 0.02190430960317533, 0.006163793572810509, 0.03420065089519467, 0.06098742078569147, 0.04585316614998926, 0.02784338516874179, 0.05692864865845731, 0.08878557612338374, 0.012531781178568641, 0.01293713457867383, 0.04791600727325967, 0.013542978934222653, 0.03515790456966047, 0.0382411441645555, 0.04959920586477365, 0.052268620084730856, 0.0671230381234519, 0.024616885216786497, 0.05980454272620621, 0.060625720033121694, 0.03443979673207768, 0.034838928540627805, 0.0839822814469376, 0.034643514832902345, 0.02456395811731777, 0.05959966017173664, 0.08166837415868237, 0.0807905906150418, 0.015684743393062344, 0.024663009455487616, 0.039628900948070714, 0.022942667090964895, 0.03000665275800613, 0.024973866867742715, 0.03889434520275362, 0.025691407800261534, 0.04316682138690545, 0.028300419817828847, 0.071862502354047, 0.0334890624658475, 0.0554096878265902, 0.02593366969977656, 0.004787105323386289, 0.017782371611364426, 0.0166880207571892, 0.08151544002635826, 0.05701558431610466, 0.0588060160648198, 0.011371401206199682, 0.027682135151999614, 0.020397481688809012, 0.07059477239606843, 0.04692327223658081, 0.02706706422501274, 0.0850230808399858, 0.03708060139850263, 0.007848248069715357, 0.02316788353416468, 0.07832050864254275, 0.03641291746809598, 0.10689156625660197, 0.01419478952283821, 0.040937647253515265, 0.07237234152853489, 0.04154908500852124, 0.01979151188636259, 0.04079541153905373, 0.029269827477213357, 0.0437884557721836, 0.05792185866964921, 0.023720997100275372, 0.023786669987584316, 0.04381467130095248, 0.018860481401544907, 0.04324286327426953, 0.02967913293339793, 0.03989862135401176, 0.029035730159751354, 0.05385164501926592, 0.04417519227811887, 0.07517354968454569, 0.08183538898705475, 0.10243046773417343, 0.06161784219946112, 0.06746957033512092, 0.02892012940719724, 0.05798731322189974, 0.046251574005450935, 0.01879165797764736, 0.05897977246692585, 0.04264410810485002, 0.03639733523971612, 0.023188709634386247, 0.09487619728691156, 0.04761442144010817, 0.04933019409016256, 0.029072640275943185, 0.07125932302686476, 0.018282650008557305, 0.020073876573493885, 0.045554242472374634, 0.015138184666753778, 0.024851943974593477, 0.060574629629451426, 0.04713779217713783, 0.05829796570563509, 0.04407834344273133, 0.05355944376318686, 0.039028751498629013, 0.024283432041204745, 0.061456094225568164, 0.037114588889263334, 0.02171688619250011, 0.01709420248986252, 0.04807258415366373, 0.01383366046338192, 0.01861955632545775, 0.01596179238760904, 0.05460684300370274, 0.06500289745388493, 0.051022267810279326, 0.054052854182138566, 0.020393176274674556, 0.11570088024581633, 0.06301399530662645, 0.10632334352140466, 0.06016073530660041, 0.04770639795629729, 0.12214518888222596, 0.08700658206737812, 0.17340541126266604, 0.29031622013257397, 0.12232161893118774, 0.09689739004017846, 0.13456660743442275, 0.13797562208867845, 0.3202589198706612, 0.14968369787018146, 0.17007879702554596, 0.18401027446792972, 0.09023550477239395, 0.08023388984222567, 0.1342343857451793, 0.15811492448612569, 0.10139339152843722, 0.20379533780918968, 0.12390661654212784, 0.11107812951048536, 0.10416712011060408, 0.12348035756017893, 0.1760203911051635, 0.1419408778629957, 0.1540960578788673, 0.21167029266155538, 0.08651103043267805, 0.17399856249891943, 0.11508702165296963, 0.11386901846215611, 0.16369662578067473, 0.1636300220965378, 0.13041025868827297, 0.115930155039795, 0.1492613995628011, 0.1443281610526385, 0.15000326378691584, 0.18031429859899706, 0.1575435914339558, 0.13508511106333426, 0.27239944605577376, 0.1358351571064803, 0.214845129559117, 0.1134798764401386, 0.10216457393741417, 0.14154422817932022, 0.1870119601728455, 0.18807768040607054, 0.20178357559827068, 0.13533862487923715, 0.14814614408439206, 0.17293671867059124, 0.21773636070711, 0.08690979451902452, 0.13547652070560764, 0.22882836390166517, 0.1300247019577411, 0.1458211131994763, 0.16050305037248522, 0.08222578739326808, 0.2095463598567632, 0.11527618408323297, 0.13712141873134723, 0.12387633308648102, 0.19439690986708288, 0.1347708617967944, 0.17285951232958227, 0.16685707554701837, 0.17932200023243505, 0.1319362751899227, 0.17887109620196207, 0.12161995900133926, 0.17914434444279442, 0.250266507087696, 0.18887579080558595, 0.2730127760479527, 0.1971611083154717, 0.17136582473833717, 0.08949586220325963, 0.20731744236282765, 0.2929550865965505, 0.12651581242079699, 0.18432052475550484, 0.1269053528085351, 0.2555566353182639, 0.14321149597244878, 0.25343472498559183, 0.16365254508151164, 0.1565316658947737, 0.14142419752334395, 0.13849461601386148, 0.14007766010059466, 0.1964993615664782, 0.22118151938963324, 0.28042112206739767, 0.1912660004510995, 0.10006297259561478, 0.13924017278177125, 0.33262367089909894, 0.1561837394030825, 0.1745385472332278, 0.08743433492077936, 0.24598668028991072, 0.2451144738663589, 0.14610173120614023, 0.087969723127542, 0.11785452960119133, 0.18575480988910123, 0.1920365316853408, 0.11461429177753388, 0.17131035997261926, 0.17083559996418415, 0.1395761329800852, 0.11669165409740903, 0.07231305398407482, 0.1480537998459993, 0.0935735337195858, 0.21397306103139155, 0.11145686805849114, 0.09883359299912568, 0.13561578016848336, 0.061727607277252024, 0.23273672998672534, 0.17708557507684156, 0.1264871990368251, 0.11416728713459547, 0.19965385116877096, 0.14994393793805955, 0.21995240792391763, 0.22780018197672985, 0.22509135636350802, 0.12412111350004712, 0.20500220208158418, 0.09414264511677528, 0.19241890149010768, 0.18307779224649554, 0.18072820058272732, 0.1338362498509307, 0.17495899160783138, 0.1711969176727918, 0.09490161608423918, 0.242468023131932, 0.1267553910973572, 0.09592717032759421, 0.12333513793325233, 0.2422917003352796, 0.13947815033456973, 0.2321098708818036, 0.19657567924549504, 0.05962523218664912, 0.09527922082211703, 0.21477958307631556, 0.1630489137624541, 0.21987786756888514, 0.1302685324222811, 0.18328210789590113, 0.2806695184159664, 0.2088510124914108, 0.11690563011553981, 0.12416805936804703, 0.06334661919203016, 0.0997771758345827, 0.12728807501374714, 0.1373677006772449, 0.14868948428380876, 0.18516820104372117, 0.17289050824699864, 0.2125619423966254, 0.26407917961478233, 0.10630057538829504, 0.13451825196464218, 0.24086538251609574, 0.18419977397687975, 0.19894048541543946, 0.12510945119204062, 0.1844189517320164], [0.05915348673419607, 0.037100883576297955, 0.055988524709978414, 0.049769120335939436, 0.01485207380967275, 0.047606074912173134, 0.01912912736917215, 0.06399757942304977, 0.02588182469950088, 0.04775527053542676, 0.03127532883457119, 0.06579562225529263, 0.06970935095582279, 0.010651459545648147, 0.04795149629635196, 0.036131721065049215, 0.09716459384728825, 0.039643537057864095, 0.06786626598407185, 0.022109592438585336, 0.04296682647339279, 0.011012444963618633, 0.05228286165924323, 0.026535876095294956, 0.049902201299705816, 0.06485868906301838, 0.023205860427791075, 0.04936169179516935, 0.016990230951998985, 0.016530231542644963, 0.04329934310648711, 0.056666727027585434, 0.08439881877312738, 0.05045935406439728, 0.010113330659336381, 0.0072906682110061094, 0.04990047377143657, 0.028966328339470975, 0.049276135095785704, 0.026359616500896313, 0.06046582216156587, 0.049781078968437455, 0.07273366689802178, 0.031287607308777596, 0.05339541667771917, 0.05472070665188855, 0.05993555142213741, 0.04147215062872537, 0.027810378270524166, 0.03056799219320378, 0.0038550406198708284, 0.052925961828159715, 0.018604102416805202, 0.05434226687817324, 0.010802562727833228, 0.017891763221292246, 0.017148642612981702, 0.09105024694074547, 0.04246479373485331, 0.14667072002926182, 0.020493964717212706, 0.07387711441204434, 0.04611062914914182, 0.025338375332554983, 0.021626836387440566, 0.0495366279726788, 0.04757685631874108, 0.10158679042492183, 0.03948933121958568, 0.049582627722092217, 0.018702960317774166, 0.013468693303424987, 0.06614395477358373, 0.061887363422541856, 0.05746667220767948, 0.019793469241009127, 0.05454451025974366, 0.04811471898949916, 0.008068130625742338, 0.10921252155376059, 0.055487771338272485, 0.07513006653396354, 0.017569002717913642, 0.026428267555010897, 0.02522438336464186, 0.1246170941439848, 0.02208133528549825, 0.049566045748971166, 0.07900152250283188, 0.02056805691080949, 0.03254840991670086, 0.038202242219760534, 0.062141279434605, 0.04610006096622637, 0.033951250971445156, 0.06205137901669068, 0.030799821890409917, 0.06673637822630905, 0.11884908026625073, 0.058182696286108226, 0.036183546913126786, 0.053292956248286276, 0.052299466615002004, 0.04889489144026753, 0.02045420092350293, 0.05345613680659764, 0.07133063815173603, 0.02225592097778234, 0.047696454135040124, 0.029648860969069987, 0.04396868561724982, 0.018348506756968076, 0.03727032307295069, 0.03429744993486712, 0.0510741281323135, 0.041836567162986726, 0.03497170306922447, 0.029769925843744032, 0.09579874334796783, 0.053220131930204174, 0.06543122487322939, 0.07832932631455122, 0.03169039718716616, 0.054390706617625496, 0.032963920685072104, 0.03922956995666027, 0.034432741062295054, 0.046260801534498894, 0.007806833835333707, 0.03318465742913466, 0.04515779963243873, 0.03462720099055479, 0.021799457064198873, 0.04062361632203383, 0.01785424406520061, 0.019072659028273438, 0.04718452354051894, 0.06551318862024816, 0.060883351571617596, 0.06048156143797021, 0.08929325492992517, 0.009487856258337778, 0.0867165718227625, 0.02884498575792438, 0.026928115027746367, 0.013196306911507442, 0.030184191719238317, 0.04373229769689422, 0.03424375866269393, 0.07579017385479904, 0.0897635639675202, 0.025242669883394436, 0.017641514855166598, 0.0357779799660127, 0.030761858403322198, 0.031881289060918555, 0.014501747547558721, 0.07450812571351567, 0.03616402699281612, 0.06018759434922569, 0.03757699956035903, 0.019479763896895513, 0.03414513633376168, 0.044980120860160365, 0.01865552989916215, 0.02541251923708666, 0.09356175128731037, 0.0471497776227132, 0.018404245399118915, 0.028110280625462055, 0.060464937330013326, 0.00437522868460585, 0.012918576098708136, 0.05868658295742447, 0.0713940778927457, 0.01888985321256182, 0.017895721980640968, 0.03205536338951319, 0.05119956353859556, 0.03609576089788349, 0.06558599761657177, 0.015130749783448636, 0.033466738663733966, 0.025961183747577093, 0.03220275870614475, 0.03346925526256523, 0.03240974034152685, 0.05655936363543715, 0.03980055826926424, 0.026963366563582135, 0.07315725223311494, 0.024864716575511044, 0.0063704965437101505, 0.037068232908965125, 0.0107705574895766, 0.06049918146022867, 0.02904285286222735, 0.03505385067734507, 0.02071133833528767, 0.07185476486601176, 0.06848541824447532, 0.05336015365056453, 0.06382974105015879, 0.02792792680162576, 0.04754410222953847, 0.04231209708978573, 0.03178987370413398, 0.01713637946053378, 0.026833642980143912, 0.02083559013572672, 0.03557673632918346, 0.009926288377403492, 0.05340706121416823, 0.03667526427776583, 0.073821036775987, 0.09819448414829471, 0.07522786531837718, 0.06130568818339418, 0.08306882884954253, 0.020919436543819406, 0.01925023246346222, 0.07165614124988356, 0.06274266611604441, 0.12164802080200565, 0.051903521732216885, 0.020033044087129737, 0.009023715186143115, 0.11978181529669993, 0.015618638623686088, 0.014707450773717176, 0.023939353226113225, 0.03408425149597949, 0.00764094994425954, 0.051241445565415975, 0.03809697024764554, 0.1205024052591574, 0.05563485638929471, 0.07840708423886569, 0.03293826823092757, 0.10892919925672394, 0.027346335832149755, 0.03186411145443638, 0.07991075395576416, 0.02927547737565493, 0.05137126299462492, 0.07303093965615957, 0.029352658818806374, 0.04608223793066798, 0.01123874637884118, 0.05906578881906406, 0.051407924132241364, 0.02383951281738137, 0.011064929647311088, 0.13523279749337705, 0.06289299554942597, 0.0470959254720759, 0.03258788642743903, 0.04093957396464483, 0.02809109778383807, 0.05750118829910794, 0.04619372670628852, 0.025075400330787225, 0.1071818982581458, 0.04310456908217842, 0.046521371020184416, 0.059190167024010615, 0.030911990569063255, 0.05747246766282667, 0.037583909673436035, 0.04520773707378296, 0.039657832258531166, 0.03333799375761901, 0.028383664846900972, 0.06679595688418036, 0.024898016502359704, 0.0218144953701525, 0.04069940923082252, 0.0310453339179437, 0.05452903911411282, 0.07262069191182814, 0.02595738586669247, 0.04079381041529198, 0.03447779469312199, 0.06130597163592616, 0.07688232412141177, 0.026118239432933833, 0.012546400051383723, 0.029806246072234168, 0.020871391339648156, 0.019928478831124884, 0.04759403967088269, 0.07348368229765086, 0.041823857764322916, 0.031519779830329844, 0.032104538573372754, 0.05728330140212371, 0.011279011002531456, 0.1145594935083101, 0.01045960144350125, 0.02139038909527083, 0.05321537069375477, 0.08010928564134144, 0.059325779908366745, 0.036784719089947404, 0.013444714751395007, 0.04711513129633762, 0.06666983582920606, 0.03259135680573602, 0.018740429678150726, 0.04596160206523153, 0.07202207080779538, 0.012703803349136105, 0.021181944231953354, 0.050228355572588985, 0.06054505480513458, 0.03563251519095033, 0.12234783445995663, 0.010980620713634117, 0.02090668692553957, 0.048521006059262066, 0.017123583876978488, 0.030079184047457193, 0.016228117108825716, 0.015628684909203123, 0.04735972401836226, 0.023247847791701075, 0.05820914164125439, 0.07106772443700222, 0.06911868184444404, 0.02165006417330475, 0.01690683079012219, 0.021781350576108503, 0.008038285755432181, 0.044575362135806394, 0.06717386039634866, 0.027709206784023877, 0.023276913167548277, 0.04376202573879592, 0.02472631130067091, 0.06495980500814415, 0.062255100947954965, 0.021399315934808507, 0.060579540253046064, 0.03360986304018767, 0.08126706666042728, 0.014591736065584325, 0.1352971642007751, 0.03550466660770678, 0.059216122082885236, 0.12405095516794151, 0.04694505977714735, 0.02788406060708146, 0.16338556343989988, 0.12349944847125201, 0.1020140836255685, 0.10476415541263358, 0.10926896691202156, 0.16423546138309664, 0.14402915693579182, 0.11791094431593535, 0.10502899200805735, 0.11929908797385232, 0.09424772173646959, 0.12410690256905173, 0.1625781833765007, 0.13964146495826785, 0.20043006677541042, 0.12900298581488673, 0.1748142009901424, 0.13484875761693524, 0.18428952883808844, 0.12170571488358321, 0.14816008688461396, 0.11855536981696084, 0.2168246241466653, 0.10855158685796684, 0.219309460972586, 0.1980528959463681, 0.3232044360089687, 0.14586116427615767, 0.11862604908885495, 0.24392798753275027, 0.1968017671137087, 0.17970807790275545, 0.14497254824926778, 0.1521526153890356, 0.08977976672711874, 0.05795060611900784, 0.09452666201057935, 0.07871993922538335, 0.1390522820574622, 0.19600820727646354, 0.22311586075492446, 0.1707126888176126, 0.12368185400602319, 0.11596659018147377, 0.16409086994826794, 0.19759128200671366, 0.17213375127363592, 0.1901142945092532, 0.1051655778240773, 0.08547634442126559, 0.08780247847279234, 0.2862632779344436, 0.12939670904269143, 0.14241268077204305, 0.08695097940583384, 0.18786504504180726, 0.09202035940102032, 0.18410476375251048, 0.15041099110197637, 0.4446349797710296, 0.08274285077688195, 0.22329264320433143, 0.20029226287959084, 0.23199143368870984, 0.13471576475328015, 0.12775430080270575, 0.16485079852563722, 0.1858882470837524, 0.095605589599619, 0.1711518717028441, 0.09882240811543119, 0.08720802488706766, 0.1946674461566633, 0.2222348596420019, 0.11772876860754145, 0.12991306762541496, 0.1754388384400837, 0.3390536000651698, 0.1858320468736272, 0.21593223896718797, 0.15506938790842412, 0.14585969338734306, 0.16301401079662386, 0.10640180624660947, 0.18009443136472858, 0.21214456237371893, 0.20145587382778046, 0.1477265117629882, 0.1688943944510914, 0.140778936986481, 0.13080752124228787, 0.11430665384978057, 0.13790684271483653, 0.10459541688643156, 0.09252194014768447, 0.14345322735607624, 0.11883991785467633, 0.22829387967865314, 0.1861599478269777, 0.1279839279971296, 0.09268505558852227, 0.13289065220423285, 0.16272772373932023, 0.19188051021868185, 0.1582105169373174, 0.1634847871478527, 0.2012706950547234, 0.13781535649491897, 0.15030213000793613, 0.13355468189524067, 0.13657369650900364, 0.1395146927285579, 0.15122636912330506, 0.11494482041246469, 0.16731878141722373, 0.12321165988161681, 0.16574935837378427, 0.12353886369495623, 0.1890585487408023, 0.29661625143020387, 0.17199947138226804, 0.17760364969651546, 0.24494227262273913, 0.12036369737958717, 0.19502110298602812, 0.22711382848360848, 0.22214887393338068, 0.1641660997824323, 0.13471706710275144, 0.13694083648583583, 0.1682917590463354, 0.1730199311409266, 0.10290739577143423, 0.1196340139534685, 0.14879673659320802, 0.08441741172704967, 0.11196722051188832, 0.23386530007325837, 0.22872478881430244, 0.14322819668919812, 0.22403076891937565, 0.0819554349647895, 0.1670695730154553, 0.09863397346869593, 0.12417602668245956, 0.1506941678423074, 0.12888134637426946, 0.18881127088060304, 0.07561804155909246, 0.12159814081725576, 0.18612417152091382, 0.14683130737994948, 0.18254546839143002, 0.1318504733424033, 0.1475346373814729, 0.0765977071357831, 0.06377637153491378, 0.32059719365450645, 0.17820182646955215, 0.1639464470527826, 0.08336126759287812, 0.07594300073481376, 0.11078347677304862, 0.19430068922379326, 0.0937817334347675, 0.10142906058219173, 0.1835647330529267, 0.1549518700208395, 0.11521053800900137, 0.21359519582361947, 0.21319309159392313, 0.08090134394625503, 0.1854852541920639, 0.17424417028744377, 0.3486579830848402, 0.1406311739476458], [0.11998246138494824, 0.07897229624852058, 0.045184333087696184, 0.05148571653051242, 0.0455633282751566, 0.06730663109450571, 0.04857491566649368, 0.10398450773209335, 0.042295074616108215, 0.08444568803233486, 0.024201303585282257, 0.028651155936982364, 0.03101967571813974, 0.05393390371013553, 0.00743937497440305, 0.049270780141194986, 0.03263793495153228, 0.01835682072616633, 0.04369716490468672, 0.0736644177607471, 0.027440221822490136, 0.0632202529889201, 0.03714053628725871, 0.05908980184505063, 0.028757033118557547, 0.03510065098863936, 0.04216393568522988, 0.043497687100522944, 0.03886716057276053, 0.018538810658238588, 0.06260993755272319, 0.031465186489625804, 0.08482581319948358, 0.011407781764113856, 0.11193354328673695, 0.04714378298470571, 0.05843931275810446, 0.0747995685425497, 0.023258707088027752, 0.06357715420064426, 0.04781438187966424, 0.05948532920991702, 0.03346091256506982, 0.03176343792508687, 0.02497068760285695, 0.03736536394083693, 0.019383213835798444, 0.13605680166473313, 0.037253683643235315, 0.055530247083234216, 0.11074584653420795, 0.025755221009134285, 0.012915467696955368, 0.015027285778834937, 0.03632133548718788, 0.0497070289096765, 0.03901531048599751, 0.028610873118703885, 0.07660176740178178, 0.05198158226126144, 0.06342201373509823, 0.028552188868484193, 0.0454028788202953, 0.032473317978362885, 0.0420841169843991, 0.02444661834517554, 0.08610235316859138, 0.03899895833925374, 0.029898448584360943, 0.031868602644892476, 0.033954989480515646, 0.03564666866535141, 0.037089196905013055, 0.03445249846986225, 0.043948671570228, 0.02579325152891538, 0.03361045292788937, 0.05312900577161101, 0.040111750844986215, 0.02675631789550666, 0.04560934717676813, 0.05429932765001732, 0.02151584173853119, 0.10210632827253112, 0.00893702180380182, 0.053172343365487554, 0.0512910076236773, 0.011622946176137175, 0.07321568175909982, 0.05925382126963908, 0.02788195195006988, 0.06861664910590456, 0.04159391647385013, 0.007483380501188579, 0.020686563051816438, 0.06118735441217019, 0.06115298004700773, 0.02733400756222827, 0.023766278642259782, 0.041388957310588136, 0.04880850353548604, 0.019765547251388915, 0.04902940881889194, 0.018968042061333696, 0.040069964579156334, 0.013686373356669662, 0.056234408290155476, 0.010039691415224827, 0.028882286578957594, 0.04259341989734, 0.04837347284680413, 0.018481411520511876, 0.045554759581723524, 0.013121396919051486, 0.009282877942877672, 0.012117251002740477, 0.021643809065403, 0.04333740235456536, 0.0314423302564049, 0.02213271297214012, 0.08677419695642688, 0.03712608020812754, 0.038967770899856286, 0.13975602574646473, 0.013329288283843669, 0.03779944851093235, 0.026250334058497703, 0.03501526282859906, 0.04943418669544401, 0.021407940169616092, 0.0050248525710025384, 0.021337086612719203, 0.008366593692992485, 0.015390788753246589, 0.054172080445794336, 0.08143965094800919, 0.028816619437308084, 0.05986721637929159, 0.010956615348526788, 0.06841302293563081, 0.0477427143543478, 0.047482367034160325, 0.018939964938908815, 0.013310040324746121, 0.03361322999661488, 0.03591641205393019, 0.0652592151515907, 0.06444958278969412, 0.0684339754403599, 0.023427261753127943, 0.10816954647100742, 0.02862660856466861, 0.022265667531398997, 0.11288968996415216, 0.0578142041640897, 0.0018260539992855142, 0.05018882543569611, 0.051996448197432106, 0.05251317833279891, 0.0525354408478785, 0.033456296885326024, 0.01250470954654438, 0.04343945675739839, 0.02872516577612729, 0.005612915547023858, 0.03075847420991669, 0.021201320510778218, 0.07117711413171023, 0.07883165782738118, 0.06377309267859786, 0.0923389983513663, 0.0618540117847583, 0.052827979182644244, 0.06530542557518329, 0.023119445709932237, 0.0492294573585593, 0.032102613777463, 0.09324657505438214, 0.06214170844384259, 0.020693544028026443, 0.017494546632552822, 0.04952048650011421, 0.13079602992342365, 0.042395949243537845, 0.010414312240637599, 0.047372916052418376, 0.07252040334166059, 0.023844810315377774, 0.034557946642199834, 0.07098170808486401, 0.056447633542120464, 0.025525224177286993, 0.051130401120791515, 0.030155281476195783, 0.05071978948469605, 0.05542914645986692, 0.07526989290190321, 0.04069045366298768, 0.012461080839256606, 0.011158369391435578, 0.04936882024330478, 0.07704938491505962, 0.053672832436859615, 0.09295419759808049, 0.014233466429305414, 0.02557105347213726, 0.02937812741184908, 0.02109286544333783, 0.06860069149444181, 0.011749974087691836, 0.041892798016628915, 0.05649552935914648, 0.01649381363794448, 0.05437574875090392, 0.055625100259579, 0.06761092121802992, 0.051205404959018194, 0.04526025240099238, 0.02907511090949899, 0.038282493760268536, 0.008668010029190732, 0.04999078404639037, 0.024203318396523118, 0.08535665850485526, 0.031564247403894706, 0.0526529549050235, 0.1562634585124831, 0.0727819917242854, 0.04927828014197369, 0.019097078080859878, 0.037342860108061184, 0.0129275182600043, 0.036988973452319066, 0.061384449682889454, 0.04737599189543436, 0.011068118488295905, 0.05077557217690253, 0.046174700912689014, 0.07997917326828165, 0.06637605643200298, 0.07370001020570917, 0.09600993080605423, 0.12936410434063406, 0.06600716977470344, 0.019238151256896315, 0.05601972747113436, 0.05150343231376141, 0.05301634871190595, 0.03961960830154919, 0.00976199986443164, 0.029448753057588494, 0.08559115035759826, 0.011223102863427373, 0.03200187321542011, 0.042147778890906804, 0.025618294283988017, 0.08069458447637097, 0.034854909134728294, 0.036279327055859956, 0.04249685834492407, 0.026315832660803874, 0.015634260114072072, 0.12278010723211112, 0.03068936924870697, 0.09724789058729526, 0.03323489747520897, 0.04835776804435638, 0.022556353848607793, 0.016736950792912996, 0.0144439356799628, 0.0637541281720323, 0.02878850784092661, 0.04155877985120301, 0.08950630398166758, 0.04277317476789317, 0.037957117066628514, 0.049830545265708244, 0.03329959360041446, 0.046140452952034054, 0.05696620611894516, 0.03389795040411334, 0.028780620965746143, 0.015949809814863387, 0.04457167725289061, 0.05225287314744727, 0.04827214239705955, 0.06538941179432216, 0.07227365408212909, 0.07501044956546637, 0.03218027785600674, 0.02813712243110903, 0.020585374328337853, 0.0221700789106469, 0.03258361165682155, 0.03616131504156417, 0.010335454980151789, 0.0467765127729264, 0.04091753361506328, 0.030212261180783954, 0.020335951421950615, 0.07577937967594593, 0.041462164672632376, 0.011847713500291351, 0.049142782170806205, 0.019331552696624593, 0.06545842099454134, 0.01844924731901096, 0.037169157332109834, 0.024898910910011302, 0.026698616153049855, 0.05402627859204527, 0.005429190425803104, 0.03876375402474115, 0.04656670810354333, 0.029093554476276044, 0.07109072239648911, 0.03979739049569734, 0.07087614116889816, 0.02692107467972223, 0.03970444870872363, 0.033151187047722845, 0.10415137700376012, 0.027189502312291055, 0.006225198871576258, 0.08354014912319761, 0.051056960101930365, 0.03665546856580242, 0.04080683391000475, 0.038607690423246355, 0.02220647957836909, 0.11294334676236877, 0.02742173995131687, 0.025640794286324133, 0.06105024765636172, 0.04754792883872025, 0.015116882634409254, 0.029968779286249515, 0.023474711323938063, 0.01702974002147394, 0.05670945558156218, 0.06354697416686723, 0.12115921074103926, 0.04356231044737562, 0.0597026338800788, 0.09527314574487748, 0.04318356040805098, 0.04507277153372284, 0.04898303751683524, 0.017610612783520933, 0.03995835322946791, 0.0690301527239142, 0.08058407629329352, 0.22496890486969104, 0.2747854728612208, 0.1615332547695406, 0.12406710430138534, 0.12113150134081803, 0.11695657496250446, 0.267120364813074, 0.12783775076029763, 0.19025050494219028, 0.10165920105552483, 0.15784483252754136, 0.12632553916304343, 0.05597128390124249, 0.15540016935236994, 0.13104657131818034, 0.18878093379880154, 0.17333917530073276, 0.07539592968720583, 0.15500650741159916, 0.12616680574513253, 0.149053881665872, 0.13247616799368014, 0.18113595854130485, 0.22700970181294028, 0.2002407051622868, 0.1628715031209492, 0.2076360889740529, 0.1126496056695619, 0.1369043400571231, 0.11717988959243221, 0.14298231310902104, 0.09855607764855509, 0.17896809825493445, 0.09447777027925176, 0.1815150341679973, 0.14220070424339465, 0.09731049529246746, 0.13120873680999204, 0.1990648368073087, 0.09420077586846967, 0.14292061238759948, 0.12962808291758263, 0.14815981109296122, 0.1412219809548509, 0.1655110284205406, 0.12111062544488138, 0.14515902937179612, 0.1999637643776594, 0.11473989189271966, 0.2881578133711892, 0.20877037407650104, 0.14651797741891878, 0.15598167605217428, 0.08273997028628666, 0.18425663302261985, 0.104735488402507, 0.183084212063301, 0.09836543666859789, 0.17135361329682414, 0.16919010438986365, 0.1259375386120331, 0.10739706937343844, 0.20993341811962668, 0.13392366048309112, 0.14881708388847692, 0.16169687582840844, 0.42157012548658157, 0.1187736742318638, 0.1255971121211206, 0.16136417916465193, 0.18602701625035656, 0.13402038674441077, 0.10346266395983197, 0.1214152909514885, 0.17130485946132293, 0.10957865795541195, 0.16333610480350835, 0.12009105434821499, 0.1470077374289113, 0.13997575508490687, 0.21052733544380436, 0.10775454898154545, 0.0878291383325573, 0.2547428967250932, 0.13278205158008685, 0.14927477545795903, 0.1347964491334654, 0.15078763056906963, 0.24421134813418313, 0.16809801541028485, 0.15726107352923963, 0.2552169978979134, 0.09973062067142419, 0.14368853892289823, 0.2080274679728093, 0.12936882344224762, 0.1738776585027095, 0.17827742402592014, 0.14098257847851323, 0.2420588555715738, 0.17238633046227117, 0.09923178251952895, 0.11685922816996613, 0.12147444826100143, 0.1436204183846712, 0.10913802716400355, 0.12532328931434503, 0.15364743679040863, 0.22108011999197547, 0.17841728103737678, 0.12293787537923745, 0.11113842063012624, 0.1458133297461656, 0.13845079578459263, 0.16848067632846295, 0.16895739752198422, 0.1355221489023778, 0.168257545559637, 0.2068366609033077, 0.10811550662882867, 0.18243116807312737, 0.10303452040158934, 0.11166703661963825, 0.2563784791216735, 0.15067818724820692, 0.16730267824905534, 0.1885466334680396, 0.13452062683720745, 0.13146093295466516, 0.1459734421223402, 0.0734486490968735, 0.18087916586908603, 0.1095458081052188, 0.11113403094632011, 0.14409033671742486, 0.13719727675760948, 0.11156922251346613, 0.12842039127022992, 0.10932829276087785, 0.1902020115765833, 0.16087498605972336, 0.21006049678450633, 0.1164010846086087, 0.11288841825819786, 0.14272602605483226, 0.17096721386957556, 0.10803901274958927, 0.1505630289114291, 0.12790364964354423, 0.14117080628150894, 0.2601938880980015, 0.18865791539992058, 0.16698426146420742, 0.14823121048750418, 0.27429054941861863, 0.0654839700268161, 0.13391966150412637, 0.13578568314833028, 0.20286451033767194, 0.1338912243203771, 0.1629662528754242, 0.21838045679032805, 0.13843406442432635, 0.13531080056582728, 0.1689216365376788, 0.18813450880829366, 0.1333632212012045, 0.2562896282442155, 0.15646218172004148, 0.15007921374372898, 0.1617418605113222, 0.25149938770599906, 0.269566023902547, 0.11700768834881245, 0.1772653759126702, 0.165891804762425], [0.013198877136493403, 0.05791885943542566, 0.03829102797974502, 0.029260138380191023, 0.02098101277595326, 0.04019852562416946, 0.0483588635500881, 0.024390933329179406, 0.06077906402248529, 0.023695222072062955, 0.1148062963939963, 0.07952977077014024, 0.033123094603539474, 0.010000125846765455, 0.033063588724020994, 0.050283257263682546, 0.012364526947719917, 0.049188395045817866, 0.04184394075925793, 0.03287439948068031, 0.03279482592798529, 0.0665632653380594, 0.008296450682645364, 0.027912702719350497, 0.02166288656993739, 0.03468981335660623, 0.04025825749962561, 0.05981454017361807, 0.052824240673573754, 0.03746213999787166, 0.08895088257568498, 0.03791026695961914, 0.024826774155841242, 0.10307912204054095, 0.026704896158809145, 0.033883321955199205, 0.04383050250790773, 0.0691583498771633, 0.057099781209422704, 0.08621949567309312, 0.07469531163693437, 0.03931380898481415, 0.1058190431626093, 0.008164170280759855, 0.11090612744972592, 0.04233812492701315, 0.06070984414808693, 0.02743201127516166, 0.08611156154544124, 0.02903130600198863, 0.01122767353550561, 0.06601229490291688, 0.05067780020556623, 0.07746110354820568, 0.05032741074119845, 0.05929491039545787, 0.04153358321937342, 0.029430043275257754, 0.047182684929500666, 0.03665121294738304, 0.015152520087036877, 0.04053314899905555, 0.048996896047385476, 0.02613647615597133, 0.02295250940557209, 0.049931144101485136, 0.03940049949432573, 0.04461334477509222, 0.023719746461738984, 0.10456943884491922, 0.024806637534751527, 0.046426242052186886, 0.010331315232530959, 0.07077690213918686, 0.025538412380903482, 0.049021981596466035, 0.06444260372870392, 0.02893389983763618, 0.017963459474905845, 0.024533778083540743, 0.006167271611986743, 0.07167006872834698, 0.1413190596166157, 0.037690185220731844, 0.11346498369089059, 0.028515058502014128, 0.02925609343595082, 0.06931622527659902, 0.029568109556191394, 0.04309282878473882, 0.04527699525257753, 0.023707646102974975, 0.010358915465222973, 0.025561935110618512, 0.08605201353108691, 0.044682016896624724, 0.09151680214751153, 0.050687284374068824, 0.03448136083240952, 0.06256586451443934, 0.03563110175873003, 0.013142662562219607, 0.015681353453997404, 0.030232955130838582, 0.008708980411381252, 0.03925599615960833, 0.013443057128648846, 0.035196546044561176, 0.04101574225651641, 0.04057591968786813, 0.06168865170630236, 0.0967043205615013, 0.05363880281126308, 0.06496887548916763, 0.037456942091305415, 0.030748844484708486, 0.07654982664051556, 0.044752359089832154, 0.05996426822797907, 0.02172939257786399, 0.01868942354415213, 0.03198482009822563, 0.03369004180234286, 0.0337448324106874, 0.040295294020324945, 0.013194326574223177, 0.02097388432781783, 0.04382260031096878, 0.03529296204027149, 0.03985731772357418, 0.04996906545373702, 0.02174902549614349, 0.02707798863881298, 0.017355679789738312, 0.008020558480864332, 0.053885146044194705, 0.05400334958047156, 0.09569798746416647, 0.019576815745582985, 0.007589832727511925, 0.009133514737890614, 0.04818091281659661, 0.08904061445425596, 0.040962571924131726, 0.024237725320422364, 0.03710577121725486, 0.01887819143913446, 0.03448221885088471, 0.018917597086739638, 0.06881739478558302, 0.0622798226052715, 0.0923668303256554, 0.017316279887792566, 0.07901798573232467, 0.07344971395908825, 0.014703711307036781, 0.024240272562770594, 0.004551086082844245, 0.04587937018743927, 0.05321624020354883, 0.062226192620132244, 0.04673714351449763, 0.02935147712818317, 0.010176501311962644, 0.04501185222198406, 0.01608095544901106, 0.06271330579634636, 0.048901215496082465, 0.039994455122899626, 0.020856044683305007, 0.034966865223982645, 0.04623163656722154, 0.04295325905625378, 0.0655549863773969, 0.021600695552244302, 0.02868493083834408, 0.07822369045067219, 0.05279191559360874, 0.03328149477320333, 0.024412789817659125, 0.022533581885058555, 0.02214519445964646, 0.036573006861632874, 0.04471897297809201, 0.05297123762448469, 0.049702053168608304, 0.08571028469070312, 0.02936658055161036, 0.05900795684166013, 0.06082409850111412, 0.052909012132835005, 0.011537813697941603, 0.035513438314439795, 0.023809415138056202, 0.03706858147897067, 0.06837821956123076, 0.014152801201318302, 0.0582931355212725, 0.02213887806471077, 0.015773262937493142, 0.052677580801349495, 0.061294710143439235, 0.05558352083748868, 0.04851659339281821, 0.02864286686564165, 0.07265707342735223, 0.06773613828925357, 0.025711563573549354, 0.005065067398977737, 0.030684776551600908, 0.013910333415673626, 0.027707285818553744, 0.05167044714213379, 0.019021415407018318, 0.02310448975843047, 0.05022404249757529, 0.04406566468758449, 0.025644766452211528, 0.04464614099913067, 0.020718824929527698, 0.10711280478825493, 0.06645374540840426, 0.044996545785256935, 0.06092969989103656, 0.026482205890539675, 0.021191372859081434, 0.03964793440254946, 0.049747765635050116, 0.07401866447781363, 0.06553243274890608, 0.033003975592193105, 0.020946646071670037, 0.04675998442596005, 0.059529972983704466, 0.01591169406780072, 0.08375708224071611, 0.008473789503407336, 0.0934801092972198, 0.038183147478247845, 0.0570071803315753, 0.03780386883825545, 0.016748147167926355, 0.020718233126606193, 0.02149009160817631, 0.015876831321586526, 0.053035114035611196, 0.03334594191983342, 0.05174123366633731, 0.04840023612843887, 0.031906742332202774, 0.018743294846987533, 0.024326034190673983, 0.05007473579157264, 0.04669720735100489, 0.027339617241053816, 0.082893448341037, 0.04320331398517855, 0.046337425648685426, 0.06943946584097802, 0.026922514925019878, 0.07293696365048809, 0.07041474939474175, 0.02568923977143582, 0.0876285458704637, 0.03458289046501441, 0.019417756740304253, 0.04823896312905897, 0.0407107166885849, 0.018589079432610064, 0.02586071706196714, 0.010929642350322778, 0.07781992381018016, 0.08207151260707649, 0.03522033307461008, 0.0570217130194989, 0.061656280661061894, 0.03398829898346336, 0.05475783510313881, 0.03675952245811782, 0.03572970876590379, 0.006744842535080088, 0.06389897624631563, 0.0687490597427372, 0.04339100169618765, 0.09444464463740589, 0.028922728360480363, 0.0383816025550327, 0.12084211162742108, 0.034049984383126425, 0.0362735009571958, 0.009797793407473835, 0.02004212605947208, 0.07160163409407101, 0.031408400222238515, 0.05499248400390629, 0.07420021199410962, 0.04735136982954798, 0.10914406393684688, 0.005653687225159017, 0.027613991631134868, 0.011282058117250282, 0.021171868260529254, 0.01811238696738597, 0.03056337459824018, 0.06810547693842842, 0.0368868041362974, 0.012577605685369383, 0.09442658794503059, 0.021206020460193677, 0.004675426462199539, 0.03438577221165742, 0.020354596086807793, 0.03682952757263857, 0.04282354887935423, 0.027352972068793835, 0.028370375136634516, 0.06919852352791256, 0.04407989094033838, 0.09662545947057587, 0.05961839485192492, 0.05180803270289495, 0.01797606736691969, 0.03411665318473693, 0.032932599180287896, 0.007404535689631538, 0.05042213368259611, 0.04694952990018553, 0.02933721448625288, 0.036357016032261234, 0.04623829004084391, 0.06222819977049386, 0.027173278485274604, 0.022453970027967327, 0.03665506253920255, 0.023479545338740273, 0.07768665515487233, 0.07707324089302171, 0.038226278228384834, 0.05014471026257642, 0.02055133321142245, 0.07078807936200211, 0.08122561364284447, 0.043459539752333395, 0.04404115753488676, 0.012246145296000667, 0.06426549186148951, 0.014553752468688595, 0.03763453659391211, 0.01285955860024138, 0.0672423946220548, 0.06420714660517632, 0.07850908884598364, 0.19372002522070564, 0.2224154418875133, 0.12484239294163643, 0.08200875468431942, 0.09439812011776433, 0.09443506087747314, 0.20061421899064896, 0.17557261271342156, 0.14595277307014312, 0.17260143262965066, 0.2859318070113659, 0.18025817499766428, 0.20716172733133842, 0.12856089179554295, 0.20615350965770984, 0.09965973455579051, 0.14589543904988997, 0.12795952809674124, 0.16609058925701728, 0.16499234093052728, 0.09285725683214203, 0.19152139884329614, 0.12922343527597766, 0.1088137191630179, 0.17872766922077826, 0.14647680785386794, 0.14741132786918074, 0.19677921348521787, 0.15327260529081668, 0.14029432508733966, 0.1387099020423428, 0.12388872072821665, 0.21701205521821978, 0.1512715683108376, 0.08282695190920945, 0.09610093439057951, 0.17475473724545973, 0.14452772695691357, 0.1805237010722199, 0.10770916593291106, 0.14406384539700326, 0.07270077108255318, 0.24557896829660864, 0.1656512531542009, 0.2801805704591736, 0.19793438214448192, 0.1942764655236275, 0.18821568348475043, 0.21413354112976984, 0.08681775671580146, 0.14469758397148502, 0.18559869649189134, 0.1750883378929669, 0.16634540542239146, 0.10639928581733858, 0.14165800755783436, 0.17182682580765218, 0.13990175099142138, 0.15453262074339777, 0.2287197939210361, 0.08169907896268754, 0.14204639881368608, 0.1031153733211179, 0.21541597231501536, 0.1764757537673558, 0.21359631431198892, 0.14777845252425442, 0.16311878098114846, 0.16074639054075365, 0.1937704184843648, 0.14902978053977414, 0.1154065722479455, 0.14127012192001268, 0.145482839415631, 0.1922937840103142, 0.12135974191609891, 0.17258399646849404, 0.09092855387397351, 0.09999619271125525, 0.12537283988128747, 0.1176762686020905, 0.17339352157808122, 0.2834770161538355, 0.12883040152730482, 0.1847400804681163, 0.12333041117075952, 0.21228529272540925, 0.15026472959547274, 0.161998116921994, 0.18073690334154716, 0.102775628648458, 0.21572784670898992, 0.1715213405869661, 0.1196583908712191, 0.1622241741466907, 0.13296310880011128, 0.3695266471514779, 0.11581995329188725, 0.19044075521730608, 0.30031060319273706, 0.12145565612421882, 0.15102439770294776, 0.17782305727802938, 0.19128702190374175, 0.1425933089828299, 0.17861772028188552, 0.1642365798714661, 0.197088360606182, 0.19941224235921137, 0.16487408759853533, 0.18100108110135604, 0.20812039443802452, 0.18863068863509164, 0.10150296508424705, 0.13370932440363592, 0.1028225745164579, 0.15114842733788877, 0.1462002347914442, 0.11348155417269278, 0.17529046253090905, 0.12410754608290812, 0.11875589333114125, 0.2120612120075572, 0.18156214857534056, 0.11130674546884914, 0.09082051249401224, 0.15627565463223766, 0.14550815096064923, 0.11140147990156567, 0.26267380663944834, 0.15955063454326124, 0.16394479230286615, 0.17767794490341218, 0.07469026311751335, 0.176636862057832, 0.11427856906647645, 0.09370601330433162, 0.28443061175846285, 0.06315282576026456, 0.07930002866252776, 0.1828331497287558, 0.12604914996172153, 0.2954077630514099, 0.14090146508909043, 0.15937320857999787, 0.14137835482195502, 0.11407085198668704, 0.07492376671683404, 0.14973928520996727, 0.20671704393481055, 0.16196442437508415, 0.1415720371709716, 0.11352313742522271, 0.26219705480241007, 0.20509891302114536, 0.11340500666729866, 0.14195695038764708, 0.10846215375368634, 0.15388786582456482, 0.16499804062468393, 0.1492503372531745, 0.12387978814301953, 0.144428258100825, 0.16302508842800895, 0.19228774723747086, 0.14523666472204272, 0.19579704280101484, 0.15774122679666167, 0.1536448320914661, 0.2764010603629774, 0.09094722343668823, 0.10222562348410007, 0.11610006568052116, 0.18767484073196689, 0.2368776344003216, 0.1400677162793375], [0.016662544503267256, 0.009849488062994375, 0.017568142784218636, 0.027476377342076554, 0.02764319490280844, 0.017161020678618265, 0.05497191071269974, 0.02515099214149579, 0.03356192508832582, 0.04810792762005041, 0.016465343895458406, 0.010624022106640043, 0.06366907709067868, 0.03065441265672205, 0.025533344709284367, 0.009392489803083723, 0.03390892078318904, 0.037814084620725726, 0.04780624219546876, 0.06437477430388813, 0.07611232914871748, 0.06492123248115664, 0.03664953904526849, 0.017621131170721307, 0.00708736427646551, 0.03078193182215816, 0.0445017334254038, 0.06438737645024253, 0.017863553948700428, 0.05793360662796806, 0.043626041301796516, 0.08449100979393528, 0.02130585703848591, 0.054739598380101305, 0.06903396784177712, 0.031635805761681936, 0.029343670692234754, 0.03780034100336414, 0.11758973897104302, 0.05335710845106552, 0.06333907705641563, 0.041876633561426596, 0.03770822659134865, 0.042477767433850996, 0.10492547054684932, 0.010049697481125835, 0.023892213920912436, 0.02208883911671658, 0.016020956400391317, 0.06560530303226364, 0.05827404077975981, 0.02247735103141637, 0.03840829688875425, 0.031329347609332016, 0.029713890342522534, 0.036352473130870255, 0.09515221110515057, 0.03355888371926642, 0.08485925293737843, 0.06159963995038022, 0.01143673126916251, 0.046441483371440447, 0.024081790038654884, 0.016191861997809143, 0.019441223928644773, 0.06552566053165544, 0.025044040521606806, 0.042118755649895444, 0.040545460031998735, 0.012223206708327898, 0.08918156697144432, 0.05903429877493651, 0.03298677308785339, 0.06157382661777158, 0.04213491244421851, 0.013778052056178212, 0.04660097904683602, 0.08147429344394515, 0.01923820679827083, 0.04847154742287052, 0.004016710069751547, 0.0815288695476709, 0.05487947454375606, 0.10387373141824238, 0.055248062426765124, 0.039501638422089244, 0.01737010139491289, 0.06513823454658832, 0.007182084345033453, 0.03330487194621275, 0.07429667778553502, 0.05382946294341838, 0.0009113559105073013, 0.025621322246508735, 0.015912951409606444, 0.03539328508439564, 0.04978315123627263, 0.030991696271925207, 0.06252616966864274, 0.06273389057887178, 0.08643282051648825, 0.04165851683806508, 0.013026011311599325, 0.07864623390618833, 0.0234290256705736, 0.14234846728222986, 0.005319769608773171, 0.021851221625242504, 0.051228184583446676, 0.060124196743051854, 0.07318356735331398, 0.011782444724362465, 0.05500761040997121, 0.03501682947840422, 0.033076359409718745, 0.006444921506749046, 0.05749946077083869, 0.018478793415030646, 0.026072151583409118, 0.0309232022658351, 0.051163013483728134, 0.0770264559034859, 0.02349524056508897, 0.028820775464297305, 0.08065933677097482, 0.008498065872117877, 0.06589964933453069, 0.03455143489484345, 0.029729874767062646, 0.015783348485016297, 0.06431231515542155, 0.01151965645652625, 0.0021298640011434234, 0.03800967452867377, 0.031986381002371354, 0.028111686396803108, 0.07193190991998681, 0.036358785695366325, 0.04803407291371015, 0.06023013138122136, 0.08065365239857666, 0.032263823574589144, 0.038786208061801816, 0.052244093779835014, 0.03392456046816322, 0.06647066062977237, 0.052733539693778565, 0.01279644061615991, 0.011705633876244388, 0.037684968161967494, 0.01822865996209364, 0.06725539513412984, 0.040702305043176304, 0.0696711614727974, 0.003117134436897393, 0.07039797206920001, 0.035447872679440245, 0.023117884805786516, 0.16485960853676643, 0.019942264583322312, 0.10797064706322648, 0.03411954516665109, 0.0537913998649005, 0.05086478694612461, 0.037754816228463765, 0.029215770398056316, 0.06977332695837944, 0.0400258953713121, 0.015292243990716676, 0.03051267298419149, 0.10012360845482159, 0.05597336382995691, 0.057869446764309565, 0.011928532903473224, 0.03703406921798184, 0.013758606829440162, 0.06526234079032175, 0.07735315409879531, 0.056482092176954594, 0.05650721603043138, 0.027693837145042997, 0.03751885348690614, 0.02755186573091534, 0.032612462528049946, 0.006590078889031805, 0.03624379589793183, 0.02197589860447953, 0.04444519230615228, 0.0490548697510554, 0.018961367520293402, 0.023368931818573226, 0.032968237590525425, 0.018138230943511573, 0.04103928030798993, 0.025288750072039907, 0.05982158818252145, 0.05373589679478638, 0.009077042566552278, 0.043901855937175216, 0.015365590206197193, 0.0407507179695512, 0.062011527122869614, 0.01952110583172931, 0.01622599887571508, 0.025516326066046476, 0.034915790142070864, 0.030172625706801494, 0.013337917306700782, 0.003288893264740886, 0.01924927868399649, 0.03444383018499902, 0.04884867335579569, 0.04184871731746582, 0.06968764002404867, 0.10824017211674683, 0.030950208780385798, 0.03489361189666294, 0.030005423186887658, 0.04054941304568802, 0.03856660512786719, 0.01218023204860548, 0.006334853345423096, 0.04493746891497605, 0.03218397423024139, 0.0433381607816104, 0.031218726428285725, 0.0713927908650329, 0.04193485241323229, 0.09132308915497796, 0.03872348461300135, 0.007884731570694355, 0.03596412017941475, 0.023147271938561913, 0.02319148478789195, 0.09591744101095585, 0.11876210630420717, 0.019259034813712203, 0.059979180129425186, 0.06853146778960383, 0.013704340991323755, 0.030463084112852815, 0.01358817237609577, 0.05696911725305742, 0.03423846499513715, 0.045302084632097714, 0.022454692065835963, 0.01331223612425909, 0.031159517407837897, 0.02148681275186039, 0.033031949292748206, 0.0706779005967321, 0.022555865467556065, 0.03875164217465828, 0.08782053516516763, 0.056077858222828764, 0.049359673153488874, 0.030220931380867, 0.03752695869714503, 0.0071041133525150445, 0.07803818992068691, 0.03091009067101104, 0.05791528946569851, 0.09552149612817074, 0.06154927733023802, 0.05210502966938, 0.02677395898518303, 0.042975418149463596, 0.032733450793931564, 0.018837864570800337, 0.04020494161053531, 0.035997310938734206, 0.04992514946347764, 0.03967390861362219, 0.03009097797105149, 0.04299808669114306, 0.013684016678692594, 0.07509588369078214, 0.026030817309454567, 0.07142843693614968, 0.04703592163540664, 0.05473410552968422, 0.057411441098778486, 0.013015692107259266, 0.02504336636423344, 0.05546308798535217, 0.053248155426474354, 0.02716648711582586, 0.014640344344379922, 0.08156977864282747, 0.07059260436724271, 0.048858222641771844, 0.06906749184934363, 0.020831436023957307, 0.026925431804791577, 0.03749520052224398, 0.029323874980271347, 0.058744119990977554, 0.008820607082828159, 0.027350382691609765, 0.03279171178057309, 0.07115832199492762, 0.02329890563663456, 0.07329205306427133, 0.027810292085632685, 0.0067561610053563795, 0.04813480198443417, 0.02380233073997642, 0.027811655722137903, 0.02302221000014294, 0.027838133636020848, 0.08304856582394532, 0.034836220419815475, 0.059712405331552997, 0.02214360482720358, 0.022134854187888485, 0.012395071830870885, 0.11329264455144444, 0.04928305670018158, 0.03011762442427778, 0.03834196899627005, 0.061305925670650706, 0.03304329888534642, 0.04683739378026897, 0.028645431344968178, 0.10449771769344808, 0.03825523252148302, 0.06240592833848731, 0.060490903880206816, 0.04850944962292429, 0.01382239609806528, 0.022942971610914797, 0.06617612280552426, 0.036533863599141764, 0.022681547937193708, 0.09105548698214755, 0.013902832457285016, 0.03468202607285592, 0.05814724173697253, 0.034122157526472886, 0.024751609439150463, 0.0479569623336917, 0.0531195713988235, 0.036514634792242325, 0.0291551670975863, 0.11741599022981622, 0.0683417154716388, 0.005423068425678198, 0.04642924128641044, 0.042287386923788056, 0.027884051030982408, 0.04238432002884727, 0.01759136865486301, 0.22359563097838434, 0.2696411924496774, 0.13868544851579975, 0.1371038753178812, 0.10029486741029447, 0.14045203194743203, 0.1668826015966554, 0.07117896806448698, 0.11007572644420209, 0.17280176462184998, 0.12792509244454484, 0.09123652121953427, 0.17066627921115968, 0.09416644746858267, 0.0994600690600853, 0.14448366157950895, 0.11824105926338704, 0.0993531691511312, 0.09892593723751845, 0.18569007545949953, 0.1761624084845666, 0.24377887617916832, 0.09776162914931776, 0.11908585506100809, 0.0885038472892296, 0.17001542623244947, 0.06721502230052026, 0.08777610972643861, 0.12658003357148942, 0.14843967833345936, 0.2470623749879099, 0.17170938452885998, 0.07970197201376, 0.15104367247512265, 0.22719351694949214, 0.15961354568360314, 0.16648183035994732, 0.21831978262672502, 0.23193132643017078, 0.16304588005427392, 0.12449481885039038, 0.2536582847636554, 0.13960948844830837, 0.1495311084774233, 0.1899426908142144, 0.09774257654264089, 0.15399790669400848, 0.083713821255632, 0.105774387897503, 0.23557692435720276, 0.1978162360647994, 0.07911142547644916, 0.11470422283896517, 0.12515509471056924, 0.11530913352485626, 0.11188701876709539, 0.132608869743924, 0.1866612297993514, 0.22248803637921813, 0.2930402142866966, 0.13355383919852395, 0.1437936461861095, 0.20761175802157772, 0.08722377565479086, 0.13385457467407952, 0.2602317941284949, 0.21178850002827185, 0.22255807213725584, 0.1081170158220395, 0.19147017820467874, 0.2626839496435658, 0.1541198832133124, 0.1562526413509923, 0.23986845697847106, 0.12366457872333066, 0.09342630694229757, 0.08078853749940473, 0.21598968023975051, 0.11397664615463828, 0.1735927504036696, 0.1941352755191826, 0.2093051187694073, 0.09706406012898493, 0.14613271180179813, 0.1735128627549256, 0.11728724915414088, 0.24309246139901303, 0.16284703427264768, 0.1586493933873792, 0.15613023582245075, 0.2600866970756362, 0.13398195977412886, 0.13650153102653642, 0.13671670980270834, 0.11685758874180818, 0.16737936365027584, 0.2317903356085862, 0.2523482284478603, 0.20320264622569087, 0.17248530902208822, 0.2182248643329067, 0.09890969617352371, 0.17402177496302515, 0.21611916442071238, 0.23776738423733945, 0.23736137295922927, 0.10301238046057763, 0.11344985345438605, 0.12661349629202198, 0.14745985187830465, 0.12334910371611196, 0.12885205117204498, 0.13629203662276268, 0.1365029406283171, 0.21555055864155295, 0.13070049875926587, 0.06689674341149869, 0.07695707132018383, 0.13304883403883827, 0.1272073676509242, 0.16270760627042863, 0.22708447199435006, 0.16879541589127434, 0.19798958644030556, 0.19226156235221895, 0.08834322929502496, 0.121648725602896, 0.0787588564919368, 0.06886683810021609, 0.16386214673759478, 0.11820351329421806, 0.11830585498002269, 0.2208921679806325, 0.18268426820155115, 0.09497192763392964, 0.15354615996681875, 0.1764299723530008, 0.11640584201461847, 0.07872399949138204, 0.11209321133191548, 0.15773053220923872, 0.12399896844139985, 0.1052406391188983, 0.20661448008350788, 0.13047004418988384, 0.18961652121957273, 0.19616917767111333, 0.08955010888917793, 0.21386640627057324, 0.0740805107559408, 0.13608499370034666, 0.10156389971774432, 0.15951603801260072, 0.11554269075033166, 0.10696304992081658, 0.1629868299970704, 0.19479086292126488, 0.20024520975928153, 0.2398098665740221, 0.06888345454729373, 0.11556929698394192, 0.1357941560807728, 0.09376584477121792, 0.11133196508331646, 0.12999615752168242, 0.20109090954065326, 0.15974635468615642, 0.07967724269556423, 0.1285473167175247, 0.14739998976790136, 0.1664929079913324, 0.20311875959798215, 0.10055071013348718, 0.10892621917469848, 0.13389539183868518, 0.11205154380971387], [0.03250408023896237, 0.044023640934498086, 0.05367940547124994, 0.009018283622759965, 0.03753645052652686, 0.024767898383640477, 0.03807373863134173, 0.06056201599177815, 0.04050737780128275, 0.040916097200205254, 0.056319535980301524, 0.05113035898595568, 0.00668295412211709, 0.0410403490006443, 0.04531425393877491, 0.017445415498748902, 0.04625926935865034, 0.03075361338203713, 0.013508689796341764, 0.04271067348459075, 0.08494959768628882, 0.05347052776825525, 0.05881929236854758, 0.026315671782339775, 0.019860714523782654, 0.02793666020396256, 0.024622016090659365, 0.04466973267675889, 0.03667745528922927, 0.04091121722012758, 0.0453355856570265, 0.02912944378030877, 0.018314015563397158, 0.027519291672374935, 0.037159611876573295, 0.055140289177577344, 0.0894619934561272, 0.05763570567773235, 0.03723488001513385, 0.06328399533465986, 0.039975954099528255, 0.015093762100854469, 0.04355537352122126, 0.04376860260362587, 0.0343005410996416, 0.04939472933690395, 0.022937767958689122, 0.027492143431558248, 0.01868264558124206, 0.03410531125301796, 0.04007315150492134, 0.022522155683667913, 0.05876280104501113, 0.03637832859831472, 0.04050837754602394, 0.042001348845059835, 0.048035114793287176, 0.02464171221119262, 0.04435296681138777, 0.04868556940627675, 0.11083726380621234, 0.024779784237785686, 0.004775206062702402, 0.05567167074449601, 0.09826049028385071, 0.041794409344513575, 0.039275462453764294, 0.025908794824875174, 0.052524363216493404, 0.034525334279263215, 0.02705512665993264, 0.0402614061209944, 0.028477717461364887, 0.038948641684387005, 0.08235154072603873, 0.021759995875219186, 0.03677037026312563, 0.03800413954342085, 0.06638101302087307, 0.026249843762226166, 0.05913465629301726, 0.04521366659431689, 0.04286794750500591, 0.03141357514616703, 0.04129884238805502, 0.08055072848594959, 0.053055177878348105, 0.10359387183862348, 0.024792840291235237, 0.05828874200702675, 0.062708908451661, 0.01861968464518507, 0.08002579737935336, 0.048973465248221354, 0.05497713160190371, 0.02650898066349328, 0.05299389850528491, 0.017783911448092233, 0.0023205562132305557, 0.06090905765191682, 0.018180275764015895, 0.020928959016718214, 0.05208836342658728, 0.02689846167941728, 0.019077504534394513, 0.059750483731829354, 0.06157634704704247, 0.06752771640857382, 0.03770197531388652, 0.0029686766520758434, 0.030270326815004793, 0.07095188428197177, 0.0475108540136247, 0.025817798901229136, 0.027127885860541177, 0.055997897795731985, 0.035719236343978875, 0.01491358492433304, 0.06414989685459484, 0.037152943081192435, 0.09120273674207349, 0.026581029317552046, 0.05185444613978748, 0.031713716903581254, 0.07328672875319758, 0.017110246286216765, 0.05716109505644249, 0.047615827211449226, 0.027225495038193562, 0.04706969845198816, 0.0445634801121008, 0.02375245458566614, 0.051637202756659645, 0.029944172542121623, 0.05499561347307698, 0.054100596781579725, 0.03565704532628579, 0.01855859296366332, 0.04906834140720387, 0.05009253967493292, 0.04136592487714464, 0.021394501072204402, 0.06780480274990683, 0.0058847809991528915, 0.09160492524144151, 0.02378086304111827, 0.023409333380479968, 0.035001863950803395, 0.05421605772308765, 0.06952533663641061, 0.0258177740033716, 0.011586875883832334, 0.041541339859606764, 0.08881867112171266, 0.028287859806310267, 0.026445537092043992, 0.04293784153677764, 0.03608134312314853, 0.043725107961724845, 0.013879485927792567, 0.0763628782043534, 0.007145043036284587, 0.049158245655557806, 0.006080785552189956, 0.010076882111118927, 0.015103114119190124, 0.033470258837746035, 0.03351992431787714, 0.0025152335189388047, 0.010098667736465653, 0.039343391470010244, 0.04467826306579575, 0.009444105934592025, 0.03717831208280498, 0.025614846888328754, 0.024388972144093246, 0.08853817568911661, 0.07853210978810826, 0.050501944722547654, 0.0789913794987144, 0.05932234400402635, 0.031603639644961205, 0.06203558611413164, 0.06503865843819034, 0.04309061096019803, 0.034503619517049486, 0.016166717076914448, 0.07780692329810512, 0.06606707785038218, 0.012250084903151279, 0.05425602453009737, 0.0194167091150678, 0.037948284072861556, 0.015621020199520694, 0.017467218361073927, 0.045599411016390215, 0.02610919001932827, 0.02236373253136633, 0.07265999988322297, 0.048327270084090775, 0.04346798587169859, 0.06509867376617848, 0.010244618977359947, 0.03606222156855849, 0.06494330347425516, 0.008836977424160128, 0.01056682215177364, 0.03511268239949019, 0.038588155181177204, 0.05778434205680125, 0.07863245964530977, 0.04435217774082576, 0.08944242757054106, 0.056736326115506316, 0.05103763936448002, 0.04094875935885695, 0.05258711730881084, 0.03249468034013145, 0.039673835835269386, 0.011165110007559341, 0.02998808661716119, 0.02534272862718471, 0.06284876546311764, 0.04041604862938966, 0.020281105272231564, 0.008609517300952106, 0.0696768152016786, 0.033022488106883345, 0.05173507048898647, 0.020554075806191372, 0.018613412300305023, 0.04970762262781782, 0.026876827356435602, 0.03657155895545598, 0.08845808885751233, 0.054770732193344066, 0.08728977412946763, 0.027388813492331295, 0.0021358646242128267, 0.012215329409246484, 0.03283850060054853, 0.059379965307251106, 0.07301901932805777, 0.03555841916691392, 0.018482980085536838, 0.023859524949183388, 0.037449599138551184, 0.04179932762898746, 0.02872322565845905, 0.04251138337196843, 0.09189412343285738, 0.057611688821306156, 0.039190296459222035, 0.023738268552528276, 0.03498684479704788, 0.037036313855599974, 0.02510539267302281, 0.0958610186353326, 0.03233315836217615, 0.061599153484548294, 0.026168178789497867, 0.02431755551257201, 0.03397094326153879, 0.030555510705697442, 0.04170806740500754, 0.06521126570840997, 0.040612220764160156, 0.05143852168393712, 0.09801844480417429, 0.04845084389671684, 0.04696369486590547, 0.03674683604209173, 0.03488419667607354, 0.052171503118569815, 0.04693180262561768, 0.014925900745325753, 0.012935803500905394, 0.05224337748762581, 0.0375220863779466, 0.0333789756311284, 0.01354567556371612, 0.05237199215879364, 0.008942344199655759, 0.06330626168017907, 0.03291450418351639, 0.03112759069359351, 0.03528810504283156, 0.05207715556025506, 0.04332347870654157, 0.03648570731222149, 0.024123425002119715, 0.049502640481918096, 0.06863895758625961, 0.025257340467144406, 0.043287905413777604, 0.04190767544411844, 0.061610357520440896, 0.11185878842708566, 0.04122443226796966, 0.02400557769672765, 0.02710331550558969, 0.050712672527879483, 0.04190888586303881, 0.05465120332495821, 0.02202795236371458, 0.036590301296523506, 0.050761188876124165, 0.028553786161806316, 0.04309815692625219, 0.03613557831774797, 0.11994344452696463, 0.06074837070979899, 0.04963909606299093, 0.01561422212680261, 0.005166407424821369, 0.026999288426351645, 0.060012102757971135, 0.024112785956071272, 0.11166060914195354, 0.016234557993049105, 0.04307975549431097, 0.005343632768809555, 0.04554727490270331, 0.03589060255176118, 0.05732109251942846, 0.06526611760378846, 0.07697656059697752, 0.015547469055520432, 0.037477645617459095, 0.12140749217641932, 0.020499281367407213, 0.029013670657971696, 0.015528597437115687, 0.04066282087155888, 0.06820598767409403, 0.007299450451448079, 0.04896789961945146, 0.1102824782532069, 0.02442563328170969, 0.0027176301180940844, 0.04759019773994242, 0.03418589987221264, 0.032667647671675494, 0.03399420169091994, 0.04227045638066146, 0.026193365845228397, 0.08059547568160681, 0.04312254150488204, 0.05362226680341748, 0.053066335948965246, 0.03248593544647579, 0.01528814829315149, 0.17531865456652257, 0.2312045234946474, 0.13102050900699633, 0.11873035195974574, 0.17647625938538583, 0.13705015723263064, 0.14559678733348846, 0.126771318065303, 0.12755760772814675, 0.19088946823631564, 0.15375798327788232, 0.16841491534104272, 0.16322024166584015, 0.11830646018948286, 0.14697649636335913, 0.13758217465252648, 0.24565251273733957, 0.1250434986826393, 0.18845857932202278, 0.22855802679494505, 0.14582325824566428, 0.09177658256263503, 0.12368836575337958, 0.1661556148000302, 0.16033159989503123, 0.16783362314585717, 0.15486884141160598, 0.09928415229003276, 0.1148836865961071, 0.09591253038736121, 0.20803304509289805, 0.11712917457184485, 0.11632936345713756, 0.1539739281419785, 0.14605598043530219, 0.1875899735117151, 0.17754816960903907, 0.19051767044490386, 0.23844137307136293, 0.1333207492866824, 0.09899959659143802, 0.16583419495051907, 0.1626714315986441, 0.08994374018643173, 0.05730275237452119, 0.2349620162238998, 0.12020878674041842, 0.1781762391328812, 0.12417065640611034, 0.07248713214310908, 0.17019890429031465, 0.10479477594696707, 0.12945004408397984, 0.12087825565568863, 0.1282075184187101, 0.14909978565429488, 0.1493967060119875, 0.13901693476063592, 0.1902215161751355, 0.15871489390490517, 0.20835722285893657, 0.11917083719444853, 0.07476813595501647, 0.16763522169522702, 0.20109452547565584, 0.16434651348860035, 0.09428139130074172, 0.19516589360371714, 0.10727520776732315, 0.11252070371542247, 0.16159877060882508, 0.10198547790247588, 0.19703189992616255, 0.17223288305103782, 0.1685978571373609, 0.13189772564557292, 0.12608622861725668, 0.15051341705745266, 0.18273207208802625, 0.08560621164618962, 0.1651998128621809, 0.20206609350298682, 0.22994239363939534, 0.16179234570553228, 0.11749234621322925, 0.15440391797211864, 0.09821357505936777, 0.2398635233722387, 0.19381327344284904, 0.14958170092394277, 0.1632166870178715, 0.19591213985075875, 0.1962636363121771, 0.1984653730065592, 0.21372221320146517, 0.20153285034241217, 0.15274265630831643, 0.18509209786932315, 0.1337370414647364, 0.23252008032173882, 0.15546976077941158, 0.17248036009409737, 0.17310207108816794, 0.13242497799857972, 0.12205895802546894, 0.17439003342822676, 0.10627160194299876, 0.1552461703578311, 0.15926925044867302, 0.174344512483766, 0.11021834137218614, 0.17552067195215534, 0.13106540175935916, 0.1134947155632319, 0.15599885174343664, 0.17352335815948827, 0.12131549267759248, 0.16846929226190815, 0.13457141846658724, 0.09900074572332444, 0.28894063265573594, 0.1521810678945434, 0.1390677570335327, 0.17861638728889728, 0.17410541644259808, 0.14420426931352387, 0.09766603669812603, 0.11453412833713716, 0.13548860957305278, 0.1509579932016711, 0.2228357790098075, 0.08639047883691327, 0.11121408713440742, 0.10204522509969051, 0.24652865685282216, 0.19608794170762264, 0.10288602957922606, 0.08889200871870404, 0.1421452701211937, 0.1573317221576168, 0.15360527131105625, 0.09750031655834568, 0.1623194448409542, 0.14149308414949527, 0.12025763250647054, 0.10465318757680156, 0.13081219437862598, 0.13381764923612918, 0.11294088762013182, 0.12893200010782288, 0.16338658999771843, 0.09731229559908952, 0.18417433985779363, 0.23019943145974991, 0.16292076257448043, 0.1172318609972154, 0.15225749282586962, 0.0776058788441362, 0.20278957161691882, 0.23585688352825182, 0.12708130788298386, 0.20612897952237438, 0.14649539314691098, 0.11652911322251444, 0.10260651473917308, 0.15162425986941785, 0.12745542692080622, 0.1242063177989856, 0.12079723419681673, 0.09325214451359165, 0.21448379652875088, 0.1750486392167307, 0.130736060560711, 0.10582101200857472, 0.20828373970523958, 0.09659178224542449], [0.07047371518227362, 0.07694491350482549, 0.01619337885189922, 0.017416166261799874, 0.022377562333619403, 0.01834136107185435, 0.06945630445355369, 0.02846595226606775, 0.057011589167579535, 0.01435253277210699, 0.04296007723877988, 0.10109762796351027, 0.14119878381250367, 0.07435783458453032, 0.0798921303583249, 0.03401286359275541, 0.04274996996466671, 0.043515303292341774, 0.038605415142111243, 0.006204750548462354, 0.030900658213443337, 0.10726454382341717, 0.03903502192828925, 0.0470611144367966, 0.046826477027347976, 0.01995397232202513, 0.05048773379155225, 0.06166114531938107, 0.04039587370390373, 0.04758054503209649, 0.05407763712648904, 0.03394959622152871, 0.007977441137266016, 0.03913644430858474, 0.05665684449336222, 0.08028863448529475, 0.05648632864317587, 0.041688961172175985, 0.02338811082975759, 0.021702504806941556, 0.03134464830039971, 0.06461780037610762, 0.042929311147740776, 0.01717348875958593, 0.04840825706900609, 0.02625383891075129, 0.026872995001594388, 0.014576701590070322, 0.05134084164315174, 0.025384838565162597, 0.06192267624541156, 0.02166725327110579, 0.02515517498156236, 0.043755797443971525, 0.0406597450285429, 0.01915441976199227, 0.07052318147954441, 0.04477400107369308, 0.04679669152885195, 0.0313609334144501, 0.019491835527362365, 0.061013912106113094, 0.0445023424653036, 0.03094134131266225, 0.0029130450228319294, 0.15044906567181313, 0.03309719317081956, 0.0442892206352084, 0.09162993035129002, 0.0608708068818575, 0.03127583062216159, 0.03115125323435472, 0.04166542312070247, 0.031945711309691115, 0.0646878284732661, 0.03556199296708069, 0.03415143357649927, 0.08226344061474647, 0.040452284588208126, 0.021632051530985102, 0.02390175363078954, 0.00774840335173893, 0.030898718095775095, 0.07288253310346797, 0.0322765214819341, 0.035994112521650336, 0.023427491579505227, 0.053609492287280104, 0.02271159773602361, 0.06820880687765538, 0.014812106045053132, 0.008874777159954031, 0.13117444671450124, 0.027899675394198107, 0.08052005432546139, 0.061946551375571764, 0.055097671706349625, 0.02333583682024431, 0.06589688375712403, 0.04948145432037212, 0.01915878263272105, 0.021780965616926554, 0.03317525753030374, 0.01644869297442417, 0.017609745188946688, 0.034082033671438694, 0.0479976071285144, 0.058812784451630816, 0.04907656536107102, 0.007143680836194225, 0.004057327572691945, 0.03438993589952588, 0.033687145989989085, 0.05702627507308799, 0.062466085392741434, 0.01986996312024853, 0.021733937394474784, 0.03627090008869287, 0.008314865521125255, 0.0336325622253841, 0.005135158219585015, 0.03700424924552922, 0.02328694508891673, 0.042048267899982394, 0.015906826536651823, 0.019054577438040607, 0.027547866751950596, 0.018792983309756366, 0.03621195728379873, 0.05908301047560188, 0.07126824029030339, 0.06595238682723815, 0.08842196781188251, 0.04325910050782465, 0.057207431884542595, 0.0067078294758234295, 0.010962880990137498, 0.07481253075022852, 0.03185016673899466, 0.014878990308892344, 0.057553477630379705, 0.046549800543054465, 0.05481499675360899, 0.07765750550935346, 0.041576116420929475, 0.06676099263131618, 0.031584550649107944, 0.020529273709642793, 0.03578497051832176, 0.030672228031401193, 0.051927178527318665, 0.0378939914216678, 0.03986350005312313, 0.025635636599373915, 0.025682375623634266, 0.01017680487430264, 0.044636526595680945, 0.0159950022991266, 0.04924112104720647, 0.05920230185673122, 0.0774732077374093, 0.025201168985316352, 0.008971279340555832, 0.060562475644532716, 0.05978966146827706, 0.07822322313703838, 0.047175931864448135, 0.08147628527254829, 0.0624590105707607, 0.06293342583962987, 0.04984618495068243, 0.09952311809625357, 0.004778958457116519, 0.01650332461952442, 0.03992243519713802, 0.040486275909408447, 0.05172331486978839, 0.08905814254596349, 0.06682299978790746, 0.04399194021619136, 0.07801141514773331, 0.026753533165901903, 0.021278095927329797, 0.02182629695462604, 0.04084091716175599, 0.041887695871053204, 0.06006387114945439, 0.049050503049887, 0.11437374783018905, 0.015277267929406898, 0.040648238387920206, 0.05569310205417776, 0.01903923078169746, 0.05114010362435253, 0.05497061985454733, 0.05615977983501169, 0.04813837961504056, 0.014860359050573842, 0.025595422729008624, 0.015185578696189389, 0.04163859472159417, 0.07265925677793642, 0.009206906918646588, 0.0511346031130562, 0.07945215840253138, 0.05155675969417057, 0.03619898358480104, 0.05095845651662639, 0.05740479528603535, 0.0018502143774962714, 0.055122757255430185, 0.11010454667191352, 0.06796244832296526, 0.05593349278393773, 0.05826597004347752, 0.006545385319529282, 0.05993605704016744, 0.015759602632193316, 0.02441222865825459, 0.028464837608137922, 0.039244056679308414, 0.01803254528391746, 0.03863260743298358, 0.03817677745715745, 0.0195838158739911, 0.06919636315996609, 0.014920331286116233, 0.02106806143156944, 0.04236991374543117, 0.055451037422303236, 0.0114447474216802, 0.017108765821303093, 0.05206069233076227, 0.05717898320947444, 0.014266357456724492, 0.045390717174497344, 0.02878623447501131, 0.023223878815770153, 0.02160950556337353, 0.03320808056741953, 0.054475160150398175, 0.11364347451636869, 0.03517984915825148, 0.021934995254982385, 0.10225293451860067, 0.022757992020718033, 0.04118545754482189, 0.057232858342749465, 0.04796276928015775, 0.022173551204163703, 0.030826504732812607, 0.06793905199775774, 0.04286014872993674, 0.022188166246539163, 0.04184509755202359, 0.0287408993068722, 0.058957663169431115, 0.039653377457251476, 0.03701487871547861, 0.035607820346711144, 0.07336121548207537, 0.05987619492976416, 0.06436506030900825, 0.08514215388605673, 0.05152485213212429, 0.041702371541290514, 0.03771918547910549, 0.0441709749640957, 0.019343846492589484, 0.010798933386291948, 0.007970570286195125, 0.043660607188940055, 0.04017623629601252, 0.011943442889699533, 0.025272143201061317, 0.034972327430882764, 0.00891129274086486, 0.018154194300633766, 0.06411449593161384, 0.02971871286600588, 0.011087108850328913, 0.029011106178645166, 0.07051482346029052, 0.019784262779379086, 0.012664178408862603, 0.0022116817126516253, 0.03956187208513579, 0.09161832411923716, 0.03847797258546756, 0.07338415981540758, 0.03516240150577599, 0.030064563259422302, 0.048092084921776294, 0.012561748622946683, 0.0591119341251831, 0.06916698368806994, 0.03226396147041552, 0.022786524965457862, 0.04955649263255539, 0.054708782493347125, 0.06250262012585037, 0.08636200334876777, 0.02124353578584569, 0.09904862621859198, 0.017649652624142267, 0.05086836840717062, 0.014397989556704079, 0.08462725853126857, 0.02592295979059512, 0.06076933853628655, 0.0758106590458943, 0.04660854799552791, 0.008875311506281217, 0.06681809682519206, 0.051477887111926274, 0.023152981208817616, 0.010665402345870052, 0.033242860959181865, 0.01000359143701292, 0.0380172856122015, 0.010615457243646586, 0.06656213152793146, 0.03821330452938715, 0.013330172157786308, 0.06079278082676953, 0.041298309956947644, 0.002179050436919375, 0.010712365450848256, 0.03525228660193182, 0.010511169694514285, 0.03759736983826564, 0.037778028692569465, 0.04998299676264006, 0.036889933605468085, 0.05754518472859937, 0.01646755980477939, 0.0754924644265444, 0.02343219727458012, 0.0412673753265652, 0.06576130917716412, 0.03643822518267459, 0.05067101266655711, 0.05334696927738767, 0.054311795730984984, 0.07245590639931541, 0.04011701386902602, 0.04415410953844267, 0.020667054622824636, 0.05050364926817918, 0.0320172983957755, 0.004559798417763124, 0.01733953831717372, 0.1299596457712112, 0.24611279368400577, 0.12603098601703683, 0.0959343102670485, 0.10623394106064113, 0.06936962160492136, 0.13826278248621574, 0.11263967717006323, 0.16886621773723634, 0.0970334166120137, 0.11942050524897153, 0.19579669040056968, 0.24781957629226872, 0.15736083349873944, 0.18834875295719794, 0.16752427684203272, 0.2412194377111812, 0.14664194576682585, 0.2010419871658087, 0.12329121811255334, 0.1909634110427672, 0.25837020047249337, 0.16682451681023644, 0.1480273085255777, 0.10202935941877866, 0.14085752228575368, 0.1393498918942867, 0.20234148679000719, 0.2764177304362097, 0.1725997012709418, 0.1525736113469447, 0.1498121708150833, 0.18444360444141975, 0.13732794071397475, 0.11470523407502521, 0.2605251138729434, 0.25864712593536227, 0.09813709650188686, 0.14984462229955584, 0.17432251043858069, 0.11670646257698537, 0.23026772053732028, 0.09668652433902027, 0.08607403855890998, 0.17378103949369925, 0.1305415048714607, 0.13332191374032729, 0.1090557799644528, 0.1815643242650455, 0.15129758465674617, 0.16640758111832604, 0.07970615485382658, 0.10109358301927006, 0.17596805197817666, 0.09124868669577184, 0.15710249332891357, 0.18061728637305, 0.24326314578854272, 0.16029706465140467, 0.13505563200000795, 0.07819543712802472, 0.19404558194500787, 0.07221941505709002, 0.19218881464292928, 0.1271646965535418, 0.2329789823101413, 0.16975726992372545, 0.17431785262400107, 0.21443625311217002, 0.14940422899540395, 0.10179394059964728, 0.21672664150114984, 0.22436869030277576, 0.17391666769981387, 0.13189096875008077, 0.22319378721858227, 0.1478062308723888, 0.12239435131871894, 0.10903668139250049, 0.11265234826433082, 0.14834825340057575, 0.1405145753655703, 0.14073447324335575, 0.17979004931065345, 0.28200597412163214, 0.16482213151551064, 0.20729985298408618, 0.1406086969279474, 0.18496691910249574, 0.17676695910913331, 0.15699904081561875, 0.15996401558720297, 0.19228275234420455, 0.10531419122050847, 0.10972056042162642, 0.39032743582802437, 0.22165447143056702, 0.0849755987104389, 0.2734761060245576, 0.18450579545911283, 0.15078039869906443, 0.1506974620203818, 0.12911078970759146, 0.2505904550273573, 0.11194181703631917, 0.21943896047530637, 0.2302929095082706, 0.21175313740968707, 0.23897423318797545, 0.08281106324565989, 0.11114935270480572, 0.13108475314032647, 0.14811206849352007, 0.1939759292309323, 0.23792956505090962, 0.08878942188476363, 0.1647214522405017, 0.09680336040835227, 0.11205607138934637, 0.21684251996057652, 0.08073869581905105, 0.10740608622830723, 0.12853429322281193, 0.15321772275192125, 0.12172374093244154, 0.16303150824481444, 0.16126852542642625, 0.1453567719868114, 0.1421305918765645, 0.10328998774169915, 0.0840523861528885, 0.22117093205451968, 0.1631523815975074, 0.12985823105179495, 0.15327724778363783, 0.10451603485571762, 0.09622569946992783, 0.16177437328282865, 0.16561031341552734, 0.10038341951346207, 0.19011634762489027, 0.13876602564367557, 0.18520164844249526, 0.15110097585185883, 0.10820690857907457, 0.15720340243029982, 0.08604831332641263, 0.08765541257396822, 0.2044798526912928, 0.15756662003695965, 0.157584898894833, 0.08269696211021754, 0.18178966136709337, 0.12236836561632734, 0.07020393731973826, 0.16091923529822982, 0.15600566992596274, 0.11080059883815628, 0.1572273503388128, 0.15108861119276093, 0.1741835267673577, 0.15194411689956344, 0.1234365756353063, 0.17756297042773617, 0.1790042576049605, 0.146897834455294, 0.14298145509054586, 0.11105497067253436, 0.16042143136503237, 0.11807630439439129, 0.20283945926254798, 0.13103976845741272, 0.13960397261525356, 0.10174746204528118, 0.15856063444047205, 0.08734670978400015], [0.06631118410657491, 0.04768215127349381, 0.02570956025362736, 0.05450203451478193, 0.0530095573424572, 0.023971151620630297, 0.03980388309085562, 0.02841203499795689, 0.034609783981596275, 0.03164918165683987, 0.037572380050175616, 0.026900761858409932, 0.03344111302266679, 0.046152959337397936, 0.04632117309337182, 0.042352377992844394, 0.04331107191260784, 0.05082236482731758, 0.017668414117407896, 0.014668739393293379, 0.07058711151682562, 0.016874201190207275, 0.15690134928351449, 0.02015293301684001, 0.014859473261411392, 0.019971234198178978, 0.07949535810058156, 0.02235763830192868, 0.016499702938862385, 0.019785375522089102, 0.01724358388943778, 0.02969398546302992, 0.06649935062253667, 0.03792425189467688, 0.031006805441011826, 0.023804906710621812, 0.007929948474010153, 0.003255848062127048, 0.019586774888598633, 0.033826834462102384, 0.03646780000699144, 0.026904529095777584, 0.1133258161585658, 0.05191826509431966, 0.02006037427382844, 0.04242517166740952, 0.03158724919382123, 0.007046079319421083, 0.032274326640031034, 0.04372998411136289, 0.03528547353081165, 0.00847149602768402, 0.029874514082386613, 0.0671057321972424, 0.009261975233863679, 0.009952411975621456, 0.022672012057756225, 0.05509506700740707, 0.008820594633899389, 0.04083053667038199, 0.034129194044057405, 0.015867596131659324, 0.03627707475736257, 0.034676877962004755, 0.023493995672212015, 0.03523046075696907, 0.038835072980052045, 0.07980396129911946, 0.03995800082902274, 0.09493308697616863, 0.009871763027002736, 0.01665848615248838, 0.024587793027861946, 0.01430242008815009, 0.050772496333886544, 0.06914259144856084, 0.019990761779368888, 0.015560595972102978, 0.057995943202366756, 0.03642230204516842, 0.12274013276422217, 0.021169050972187714, 0.033585957266510494, 0.042738869350643895, 0.08228327463110609, 0.16800804604445735, 0.05278549960724289, 0.09631437414716329, 0.0853006115123149, 0.1044771558935604, 0.07360254849998221, 0.051329082193514036, 0.07466462981556693, 0.04022263058070694, 0.0687995832413435, 0.030573331826036016, 0.07939413490314638, 0.02124443019349729, 0.016882172335059415, 0.07244036247533175, 0.07997737296165959, 0.09521456300130776, 0.009005808838522963, 0.02201140486455012, 0.039791441822965304, 0.015161135703355316, 0.011457400321359596, 0.05245060044070406, 0.07506727030681026, 0.031231845683989026, 0.036395002501986684, 0.035453518747442195, 0.02318104875514344, 0.03689407431069882, 0.005413279258420752, 0.039267154230225476, 0.025346382866583528, 0.10715146158491412, 0.0955748618129761, 0.040699344113348954, 0.03303114106998809, 0.04273639105620884, 0.04163860621291303, 0.035982736115974766, 0.0560114843650691, 0.04112187224710661, 0.03028541874711312, 0.009787062430874476, 0.04579502773741561, 0.02721625601782674, 0.013772502706776706, 0.0654563372353873, 0.05096762658908002, 0.025085114325667103, 0.09402695817932968, 0.0311414951894192, 0.01980242097840434, 0.06905921043888216, 0.07088895781987137, 0.057636893114014986, 0.0195598334915215, 0.04114145728489084, 0.04393838683984453, 0.12125682566435107, 0.04235083815611659, 0.11589622500562861, 0.0345716672769237, 0.02211068794431706, 0.0188090615800672, 0.018628243762519092, 0.05005118241834064, 0.034512418036859845, 0.07016708849058037, 0.05320702033538011, 0.017271975107911616, 0.0222097392824869, 0.03946301609938664, 0.04452636698260904, 0.02232634169500201, 0.016165299814254526, 0.025324491904147213, 0.024773324201364192, 0.03228340861237338, 0.00990821349044, 0.03680411260575056, 0.03501419030550507, 0.03803117861670833, 0.04845736330495246, 0.028326677481433558, 0.006339890852330193, 0.03137494899302481, 0.049628612149747155, 0.028833911956978903, 0.08736107393258041, 0.01721282737449773, 0.058394113570571914, 0.010689989937799833, 0.03729698293271565, 0.05867566237406385, 0.02193280041307932, 0.04210637566903907, 0.04862967180088163, 0.04974310399003087, 0.034076372281678265, 0.06974248425854791, 0.021297776726104563, 0.04689054879089517, 0.043010305793535326, 0.04994758817877981, 0.05746270004179209, 0.047256014865612796, 0.04251861141153401, 0.03780806316964088, 0.02456354634505847, 0.04022346178610479, 0.04218715581021482, 0.04345029690152696, 0.01658911114528535, 0.07016370238195505, 0.012076147512773113, 0.01993557472052353, 0.03856857397383259, 0.05738873042226319, 0.05316845546927183, 0.013719020193562874, 0.020465117676423925, 0.006190416085789161, 0.025253017816031655, 0.025527051296986403, 0.029293009297802087, 0.04203802913487439, 0.060435328031739885, 0.024520074685795173, 0.04813003308710553, 0.028388202002632524, 0.022058751013490464, 0.05080925706293314, 0.029721179669122064, 0.05490611908176253, 0.012376650289121655, 0.014037028078981226, 0.0684167231403051, 0.022879754035403172, 0.013526857571466076, 0.05771099679893064, 0.014427703234457202, 0.05709250337414204, 0.0937614397656533, 0.028354390712094404, 0.09532730050024488, 0.025412860146212964, 0.048041588236247344, 0.08867935037180301, 0.04293684562247607, 0.010385243991960683, 0.02824233886184952, 0.015201676118698333, 0.050578434771347436, 0.044673333290003, 0.056465617456142946, 0.010250794603639554, 0.05426925869898931, 0.010247361572128872, 0.061514554395070004, 0.0750371553905068, 0.012799123839114704, 0.048721587030036796, 0.025339080133445324, 0.05001219620387401, 0.04218031081461138, 0.0266752140821829, 0.07389433606858216, 0.07444611089604516, 0.019810587475677172, 0.022158679522333607, 0.03168706661991535, 0.09488827849347746, 0.05925982739896544, 0.03696911262288209, 0.05998292629937491, 0.046334633258201426, 0.09778474202199329, 0.0377303205670849, 0.07848022265299674, 0.010434971716735634, 0.03970476663521221, 0.06092139166749774, 0.06966486423005981, 0.1224716802337958, 0.01605936421847512, 0.006294229618018314, 0.04038213774742138, 0.05326169603053601, 0.10214708415010285, 0.06652012692704316, 0.03716826867011767, 0.051673860063836466, 0.009525452023221841, 0.01577338934200065, 0.041924042912620696, 0.01849032686873069, 0.03257036216617112, 0.05376594659361628, 0.01074604363360953, 0.035140587152132106, 0.011495947950489579, 0.06416908735709806, 0.04652310237889329, 0.15256769714816926, 0.035462413028243094, 0.04695725206646228, 0.08785677878486534, 0.0854320492174837, 0.037082516618313334, 0.04707787261014024, 0.03514157540555443, 0.022638037973534197, 0.04137040266106206, 0.011523322187243931, 0.01130713025979217, 0.054093859038285674, 0.07027991025918914, 0.05010680806252265, 0.03453097651682554, 0.05651719432564513, 0.0122493370098152, 0.06924532383920685, 0.03264239741369121, 0.02334115921609825, 0.060186548639209046, 0.03568102004787615, 0.061925748257987925, 0.0232447911008832, 0.06212454424389909, 0.0704437151791588, 0.009147968901801974, 0.024435889283795992, 0.038714077053291183, 0.07506834282990425, 0.03577040718688119, 0.03551419291104521, 0.08428915328676663, 0.05665959474901038, 0.03597423254001526, 0.036612402933139, 0.03491563309404639, 0.008049723448141689, 0.04607723920696205, 0.13528999361780383, 0.030246624054627556, 0.0049566525511533744, 0.025674291480813297, 0.012275652130014233, 0.013920755084273557, 0.006521055803468992, 0.014285413893840969, 0.03555727769590674, 0.03914758322700378, 0.1501098572607002, 0.026823591906577352, 0.04722714867262591, 0.003529128622293713, 0.05566874428862526, 0.1292344975856043, 0.0987029979906736, 0.02171387355173788, 0.049654571039061395, 0.05919001380642576, 0.06971235402048596, 0.06187295713912576, 0.04432657125195669, 0.029763461976882913, 0.14393456039890168, 0.1189011742451018, 0.15255620582930504, 0.18180153572991972, 0.16600524706225242, 0.10675638238148344, 0.08567791747590227, 0.17308045208694475, 0.16760568134486678, 0.10659898961744002, 0.14089081646694293, 0.1884117407063323, 0.1345902948730415, 0.18884456506179226, 0.10746705150532146, 0.14307992803233285, 0.13403026927863398, 0.13308865528914238, 0.10743263883576279, 0.0677004232702236, 0.15275610881226678, 0.12490389448019767, 0.24608159858372905, 0.13345705165017036, 0.09804968586972646, 0.11655879146870106, 0.17190617719484916, 0.2452082736718078, 0.1298608357507375, 0.2831563930357656, 0.14289504037268702, 0.18633455458667972, 0.1268863461671337, 0.10981230711143826, 0.12325433097899922, 0.17970519741216015, 0.09986292405594742, 0.10400742908278782, 0.09679762240979942, 0.12676805453074555, 0.12907766406574558, 0.1414738706643543, 0.16578602334184034, 0.12129562801771587, 0.08878398266050125, 0.17196656024504095, 0.24964732418377555, 0.11619916681440608, 0.15260230900058824, 0.11888972123063381, 0.14974054159416308, 0.11426403637855284, 0.09012595419922183, 0.24495862093904328, 0.1371407088252806, 0.13237961027170383, 0.1573647252253948, 0.15947865292189584, 0.2026497146054622, 0.11204618885512314, 0.20409614989353767, 0.11753569912886429, 0.205023683186981, 0.12428738522313296, 0.12623042168636478, 0.14350702205011923, 0.13800399798539378, 0.19764545974471878, 0.142910469383482, 0.20088775834489256, 0.1766126843229417, 0.06888093411802285, 0.1892519859416831, 0.1460857659337982, 0.14395895263841077, 0.22966010556105645, 0.16756149339339427, 0.162284005613577, 0.11073112232430328, 0.14201077572520704, 0.26373584965063684, 0.23627931973145855, 0.16248764710560923, 0.1890769501727435, 0.20191204854317252, 0.23347649512992752, 0.14448085769770608, 0.18370255227050475, 0.3999119005616634, 0.22555404282625646, 0.18998084199284354, 0.14854775801781686, 0.1851973583501193, 0.15194672159850597, 0.10579128779711262, 0.09195363314281549, 0.2496825335847755, 0.1697155947406446, 0.2748413359926593, 0.23105423236566208, 0.3201081537671628, 0.2073200470617702, 0.1207346065090068, 0.1525479320797228, 0.095167716724738, 0.10193840179952884, 0.13206297081084023, 0.1288172094932487, 0.19074905964155353, 0.20405514886783016, 0.11874778812090236, 0.16048120154488474, 0.2454446424399653, 0.1071661704730603, 0.1305749522702348, 0.13645591815152477, 0.11273702396260155, 0.17568406318464588, 0.17746356285868153, 0.16477207533053814, 0.08003813905581351, 0.23349940115886353, 0.14080308407785433, 0.12374285758743364, 0.3187076837545441, 0.11748162098228933, 0.17339408848314516, 0.09375212413649406, 0.19957145075163535, 0.15554580266677565, 0.14975892770434582, 0.1551657464475401, 0.1380180173944081, 0.1227167287781354, 0.13041785828048183, 0.0874427006009125, 0.11842203221373981, 0.2054181571809515, 0.18945967237795555, 0.14642731857395944, 0.09779097031681769, 0.15876029227529803, 0.20995918931739949, 0.2513605419306025, 0.20420099668685468, 0.3204158146775538, 0.17391593225540655, 0.08721685788083462, 0.07456097045853254, 0.1981723750190389, 0.09427775238310138, 0.13415721004768727, 0.26241698332371255, 0.10635217907087458, 0.08732293807570973, 0.07844881304810125, 0.18900886027803346, 0.10905541224224914, 0.08410538411549023, 0.1897446111205124, 0.19360687403428942, 0.10389603989859743, 0.16451430206577625, 0.07934674470415039, 0.15616472510080184, 0.08279487580781983, 0.12249323794798506, 0.22340876681189384, 0.24385125616625433, 0.13261156637341748, 0.11173371691256763, 0.10011250784079875, 0.18238711801748123, 0.13121618318461603, 0.13859839028408452, 0.13926024428538739], [0.04110187735228289, 0.09210857442550122, 0.05574201676814307, 0.0548996877736382, 0.07983694138425974, 0.009564572303075223, 0.004127492608066889, 0.011267195053909336, 0.051067907498368335, 0.07807739063977234, 0.0437306123034608, 0.08069529693814055, 0.06826278543280018, 0.036891657303297715, 0.02062497724358353, 0.03672437434415183, 0.029721210312639034, 0.03297879811256163, 0.0421994476909599, 0.04885495910721441, 0.02920046013088957, 0.022550123638563582, 0.054633606285337484, 0.012202676509567087, 0.021879499845747507, 0.05458179575901839, 0.05278252335565706, 0.035802858671353716, 0.02667939883746928, 0.08800378339665552, 0.04214653016759023, 0.02721238152814969, 0.05903349821305564, 0.06882102604234411, 0.040661399778459346, 0.021999335149303082, 0.059202761509485786, 0.10074567184933733, 0.046327179222698175, 0.023685994543014996, 0.06164131513346107, 0.01994933940530304, 0.10875556542868577, 0.04482994464436366, 0.08290822617709637, 0.06807913883559166, 0.03951330594117603, 0.046272350309957425, 0.0384947307588112, 0.04138550608448925, 0.07487151952039811, 0.017011386470027992, 0.04812393885766787, 0.05134760236908352, 0.06459697044544643, 0.04185296144456633, 0.03162453469309596, 0.010920202231875831, 0.03323388623914892, 0.08924798679447944, 0.037250791661321156, 0.05266579836907406, 0.03528894390910864, 0.03300272303843691, 0.028312223317522197, 0.038809769095913056, 0.018842323202519648, 0.04667218308895827, 0.04777623070103507, 0.05985458358942021, 0.055813803037087766, 0.050791108440006935, 0.04237617268377254, 0.023985374042944565, 0.03539549907849681, 0.053373020097252824, 0.003066991827630949, 0.03448860419373359, 0.06734504274302913, 0.07734606012461648, 0.03458600078198699, 0.04582977748566097, 0.02626356248173022, 0.0629309973409099, 0.10982386737821564, 0.0934680817168086, 0.1307066427844186, 0.09961000778862547, 0.05503432389589087, 0.026187206498317184, 0.0344906113440952, 0.05690388486630494, 0.041960175449569384, 0.04741878939732429, 0.04184909653098833, 0.05842690596417074, 0.08461272584334498, 0.01854099209360298, 0.010632030598278488, 0.043765247138517524, 0.038311869401725075, 0.06310609056644383, 0.028405630502909906, 0.11416410020883046, 0.029933790135527813, 0.039425956596049576, 0.020417570429403457, 0.10544953597409111, 0.07797399941351145, 0.021838380076411753, 0.11008089753769099, 0.06506189388493377, 0.049768396382850986, 0.034999695921977686, 0.02665380767035869, 0.009497058889528197, 0.017169687048261686, 0.016890089853756854, 0.06350598846291823, 0.011800615372316492, 0.013882905552764575, 0.04795216279284609, 0.06562043326876818, 0.034455137642761396, 0.062088338928597595, 0.02378695535533611, 0.04947539839533068, 0.02365650781880944, 0.029628569215175607, 0.02104558441187105, 0.05380633857942397, 0.029810936445550575, 0.008794416451916821, 0.02102189888847211, 0.025774039958994237, 0.09536653186284727, 0.0973677910083244, 0.04782839745823895, 0.05876400763349188, 0.019659227654037457, 0.05836609773518098, 0.03154186422996704, 0.053220852052853, 0.05012807849374029, 0.03350442635916895, 0.04396060338964866, 0.013245515611713693, 0.037161630518253774, 0.0256735043254711, 0.04263799855365388, 0.09392963436942908, 0.04443539787204035, 0.013405356984285098, 0.04950516091118898, 0.025758879078972726, 0.04832872948158653, 0.0444753531877312, 0.04256698220307308, 0.06061528591559299, 0.04782793397504476, 0.055958199119495775, 0.03519016836259154, 0.035382586666533065, 0.0267695865383552, 0.0655664776962611, 0.05579528669195791, 0.04492650619677959, 0.06314303898703187, 0.08223661987651741, 0.017262063845391237, 0.05092219757517019, 0.02496503578919557, 0.03933817824168552, 0.023313225735159173, 0.03925060673106102, 0.03228665682517233, 0.10231338651670564, 0.06561684797728254, 0.04574608237993333, 0.05921091268500013, 0.023500833006936218, 0.0943962891676253, 0.028141284203757683, 0.05060726649037773, 0.027941789162615617, 0.08259632880048406, 0.04371569657157506, 0.05677035957154247, 0.031529966884502963, 0.0679614907130599, 0.038067092818598595, 0.10372242139231774, 0.06671024696721185, 0.04658330922886249, 0.10767525122050317, 0.017012018492565523, 0.008697390458696793, 0.05504345183350867, 0.019866416133159114, 0.09219121232989336, 0.03458274107786917, 0.09778509442243846, 0.022987368321346662, 0.0253685706880905, 0.042590091245309006, 0.04541996258100675, 0.07025321209502798, 0.015186160923011843, 0.06364553520876555, 0.04426595837538762, 0.0052561709045192175, 0.03387106837885034, 0.012043838712176489, 0.05285110354663865, 0.021537818885858984, 0.06202746558213427, 0.057208799351487434, 0.0797019183876053, 0.06559379639164095, 0.1260648087988938, 0.09767845498337861, 0.0659380609830541, 0.039029774226007924, 0.08160868824850168, 0.01861236659028838, 0.035472142344881455, 0.08667676589421688, 0.07372775791032661, 0.03597505608453386, 0.05134563352311811, 0.04447062642523839, 0.043909237194325657, 0.02389728159253155, 0.037017579175411694, 0.0742920199709554, 0.04057660150612074, 0.026921107238459013, 0.03845441538179594, 0.06991574270350319, 0.020786556678133148, 0.05251526592239257, 0.03401827983438008, 0.028933466997958963, 0.016936237075095697, 0.0500338496790538, 0.04856338221279364, 0.033212596655733166, 0.012213271505559885, 0.14588298246024117, 0.009470060035856742, 0.07412075335460325, 0.09203945031209339, 0.08055249814905467, 0.01005554752003762, 0.048468862284695914, 0.05021933105684096, 0.04036421512043284, 0.0775069615713531, 0.023903408380705985, 0.010653023322623585, 0.13708029513157186, 0.0578890509542919, 0.07081787252137739, 0.048370239955763665, 0.03325955018461232, 0.05266006803140045, 0.051765633566725644, 0.05797780607075942, 0.06675121734940237, 0.040687948555475285, 0.035027623657257326, 0.04384191721797951, 0.08147694410816317, 0.06382812843507817, 0.03418801810532328, 0.04047298428392218, 0.05868570961719079, 0.10244132320006048, 0.020315765005145824, 0.11854888105224218, 0.1014689124760128, 0.05743008384841585, 0.04095951906375347, 0.09283644988411859, 0.01799810197084181, 0.008676217703689492, 0.06574543583537303, 0.03758499751828852, 0.03627190366387367, 0.09831163431367568, 0.10296560313192107, 0.017735720687215368, 0.022904784043109225, 0.07674887926588136, 0.017051473935885776, 0.022954382490546956, 0.07599354721605778, 0.021236635248867736, 0.021606517820468834, 0.062167192358643784, 0.04904441648132859, 0.055253516972786, 0.062187194914346745, 0.05808829127119915, 0.04494075160173159, 0.03030730204867019, 0.0212588575443313, 0.04730427074396322, 0.014952448564731788, 0.02806004249460755, 0.025490644883604783, 0.04842653975731904, 0.057004273027902654, 0.0545130891635293, 0.049773858589751106, 0.007407145176623618, 0.025651090508026463, 0.06138507021410812, 0.040746676855750626, 0.04855588604245455, 0.022994787882893317, 0.020073018555018692, 0.01991388294094753, 0.039693964795479854, 0.07848849640257897, 0.05489189665944827, 0.036195237414851304, 0.057521593050971154, 0.04397976707907454, 0.03876117996931557, 0.027874338951322342, 0.03344780097024576, 0.02669958333905426, 0.0763054445926701, 0.0429447248367773, 0.018477477659020695, 0.014549613678677669, 0.03065984230488539, 0.04610815085470677, 0.038944447353001566, 0.1202725865427525, 0.029868130654757543, 0.03500413157105927, 0.038148654369457115, 0.0579896153161122, 0.043510871473699815, 0.03333548865010662, 0.025411167091900305, 0.023722648019752195, 0.018252527431374597, 0.022033483518527883, 0.0484983911437373, 0.1587986732803045, 0.18000256210084886, 0.1730967850814904, 0.20911050179312307, 0.16637997130953497, 0.3148162022473351, 0.0904330635263074, 0.12009628672873783, 0.10685225828520714, 0.23519365056868524, 0.14428847769816078, 0.18468913562115163, 0.11264754489304558, 0.23095332326427584, 0.1002027913026752, 0.24614795711973023, 0.06646719025147539, 0.1496123291191555, 0.19793095007058115, 0.10741333342007092, 0.09832721654205553, 0.07956004656490781, 0.17636295498138474, 0.1531505828062373, 0.11564385266073289, 0.1825994775900918, 0.11095792265428651, 0.15933924024143528, 0.14602173630508686, 0.10341492136039081, 0.14874652719065068, 0.12313136620627296, 0.1420306174024459, 0.10862961291305481, 0.09226122510529335, 0.16343807110623007, 0.12913643833129637, 0.20378445936066492, 0.22361651453520023, 0.07391812309863106, 0.23711205730515145, 0.13436747053938528, 0.17137903209415176, 0.2277546457105106, 0.2218522140455823, 0.15858596130724878, 0.11604732052693445, 0.2605535510566927, 0.10767962558255081, 0.131494625501575, 0.14749107762209832, 0.09464038010205954, 0.12293102655319438, 0.18933617900456154, 0.18662660262517392, 0.16315117117858705, 0.29252908042361664, 0.16472736643927713, 0.1348682928590044, 0.13417604048886608, 0.1439302703065257, 0.12719966080640593, 0.1809603405455428, 0.08285086917420549, 0.1262301918599875, 0.15706523081227658, 0.20992427102981076, 0.22745777131809344, 0.17680075890835256, 0.1944424614550606, 0.1268549365622382, 0.13033115244921178, 0.27034605462704936, 0.13171882879349495, 0.17912287865915608, 0.23097436003867658, 0.13805394691805686, 0.17172452242624375, 0.0994916778478411, 0.2271645894694713, 0.20561168631238325, 0.11394505268864094, 0.14536890681953202, 0.1504636673076499, 0.21497207032817028, 0.3233063869899319, 0.19066845187016074, 0.1233339504969697, 0.12587195382483546, 0.22358018664583085, 0.18865547924032136, 0.2052721714661006, 0.18934652119153933, 0.17947884907405223, 0.12029165447118784, 0.10711510305202777, 0.15965206458443598, 0.07598643792012046, 0.09182205754182032, 0.20513131854034242, 0.17782051386612077, 0.22420166781352413, 0.08089022801047371, 0.2750772910733377, 0.15176362658460296, 0.14742920836133344, 0.14038800231872067, 0.28556166396987054, 0.2085497101107913, 0.1120612501437145, 0.33936895249832066, 0.1387491717093414, 0.11484109210751711, 0.18172717923598905, 0.18361676574474384, 0.09546109009534122, 0.14441299762937332, 0.18680310928292815, 0.11102406668566889, 0.13487331839578767, 0.27042646321558184, 0.11740318890060149, 0.1344110149770014, 0.22470728584354926, 0.17019096761941913, 0.1227438942559304, 0.18773781315934276, 0.11990459620832436, 0.11763114602335038, 0.0752338101606696, 0.18878508599535113, 0.21821086024565084, 0.09352972881207544, 0.12482227547274483, 0.2043128608455581, 0.1928255103167988, 0.18777829324526174, 0.11818110522243286, 0.14032668464126127, 0.12003073258505714, 0.14715842692361725, 0.09252875066933133, 0.17742737286513854, 0.12999376732735865, 0.08989250422605584, 0.16696533909247768, 0.08372857610905364, 0.10622330009937288, 0.15619083337726133, 0.10601239609381846, 0.2180714169216733, 0.17104360815738479, 0.1608448328390237, 0.1633612631309417, 0.09614534450755005, 0.19881591951895147, 0.11823921299148953, 0.09946079684361335, 0.12781601684588578, 0.12704242125994739, 0.17426940522366957, 0.17705206639103352, 0.1786271278415957, 0.16916211153711044, 0.228860447663934, 0.1341504837957121, 0.12616529655192169, 0.17597007445029675, 0.19492725721530377, 0.11498235105987518, 0.11393947556855218, 0.17291863899557822, 0.11147252689566343, 0.09374325283833089, 0.09449105424385879, 0.06070636227847107], [0.013054660127137699, 0.017710294229008498, 0.021956847913022486, 0.03017037340830411, 0.0288634063420637, 0.04754952613204237, 0.025919665612520713, 0.041934599604217276, 0.08025262069197432, 0.02816951837420704, 0.07521334029133282, 0.033529071407693053, 0.035993756290765545, 0.029491374359255838, 0.011942361748116392, 0.02792480690855413, 0.03614435002448098, 0.01299994325475587, 0.019810924554363857, 0.049015523475264354, 0.12593154780446522, 0.002937264413753104, 0.04225885397904823, 0.10749428593102964, 0.05325511533526644, 0.03482571735437359, 0.04825048892187977, 0.03313771539157437, 0.06229794058468073, 0.06370928521538455, 0.0960273593063316, 0.03577620647246799, 0.014354117616500347, 0.014434013883733462, 0.06354245041767437, 0.034639347314594254, 0.027415145849508625, 0.051311075296853824, 0.08790092077106239, 0.047247553424489115, 0.09512622540275897, 0.06742504530496175, 0.0261220277377194, 0.033454879622666106, 0.06869978496744748, 0.03522738108351346, 0.04412452322280696, 0.0552172925052864, 0.021696019872662523, 0.07965300367363999, 0.021897600588178443, 0.07658973216049134, 0.0206362291599714, 0.030378601851782976, 0.029275214990540862, 0.025643864383680687, 0.03851839521479222, 0.026778348668989156, 0.030064770103161855, 0.07770494933450416, 0.07629709423429544, 0.07035936889869553, 0.027533577296942956, 0.11163970260249992, 0.08611505490637596, 0.05460306235979642, 0.09073999665317037, 0.06181789073912848, 0.007068870913973379, 0.021004347814126842, 0.09622553093058449, 0.07275540847331285, 0.0433549304462729, 0.06318932984985652, 0.05879382760594449, 0.10502254920861415, 0.027414632570599357, 0.030845429019762144, 0.03260212417151178, 0.021212511140132145, 0.04966613896671803, 0.07824697186269107, 0.0956912995165875, 0.14112925367249599, 0.054973718680201046, 0.0799526589652223, 0.11332919460631187, 0.05200032077188935, 0.08789883701190834, 0.08801634723861372, 0.08631286646930442, 0.06338652471200594, 0.10379871608869684, 0.053099526708284696, 0.029222728391628594, 0.05825767331125756, 0.044485963505482486, 0.04428876481289345, 0.03461543388003784, 0.046477010698928956, 0.052262054711219766, 0.029918462631382772, 0.05110620806414274, 0.0017802808443159468, 0.04993872071105627, 0.02340573085201604, 0.03976507690705119, 0.02488424415670095, 0.0422539969816083, 0.08192272301042273, 0.007009789255642964, 0.027661462269362905, 0.019778191532579162, 0.03130556824016235, 0.013253868842918067, 0.011981776014210717, 0.04164660800128214, 0.046241078600888295, 0.03649481992808081, 0.08441367321797917, 0.07631554929239136, 0.01979664659067508, 0.01456525623648157, 0.0049943713689102765, 0.026613406108451948, 0.009415872721752573, 0.011039106738603404, 0.026128437978425817, 0.06316326370823287, 0.07516049554631596, 0.015230354620143773, 0.03609877162342591, 0.03066280131949292, 0.015869760330045418, 0.05933944308649629, 0.04823430914491896, 0.05669223392502435, 0.027009088606123003, 0.04231765122723676, 0.06907122269753488, 0.05184221937651596, 0.04456300130714813, 0.061804936192328894, 0.02524562889800197, 0.0457099958082601, 0.09585234652002973, 0.04252339946106077, 0.028412354839665276, 0.015198371406914967, 0.06178161264547418, 0.11448588011966598, 0.01955741456890058, 0.04010000288666737, 0.07143681793804131, 0.017016258789226413, 0.023148151024455027, 0.055588040756241935, 0.026944467174490134, 0.016993785599967646, 0.04830732115454251, 0.02117775564622735, 0.055659524420456546, 0.06676882204990234, 0.05592819911638095, 0.03757933612852808, 0.012955991832929994, 0.043124219237436215, 0.025909001668614727, 0.019944490068742347, 0.025276017690738364, 0.04409657250488958, 0.02115105173640674, 0.018009892063996485, 0.029780160778412418, 0.029317321098079125, 0.06160725103390794, 0.015602724104669067, 0.01473819005167893, 0.06738094928404016, 0.03510720487083158, 0.03158516543466718, 0.03665766340770549, 0.052143414504826076, 0.09260014240299502, 0.009799092884115394, 0.020398609753277515, 0.07524847308354032, 0.039735651469879577, 0.0637596057006909, 0.05332181478039392, 0.004887497794228576, 0.035056777133215825, 0.02157520589178368, 0.04043808897897121, 0.04235488310035679, 0.04597203618276023, 0.0858376927733902, 0.07140015296998524, 0.02899183523690989, 0.01789949879410767, 0.02733414162761502, 0.04701785345171248, 0.021703104270742308, 0.09260822463059619, 0.034404529874483426, 0.01600621495350835, 0.04124729616206981, 0.0968705693019494, 0.013492904554661966, 0.036300563013121005, 0.0960674640091677, 0.05634404696343888, 0.008213558054018405, 0.0658969680267957, 0.02285827293000635, 0.0338131099969389, 0.03255297580072957, 0.04090264469625489, 0.02954275587633733, 0.02529914013951296, 0.0547485462870569, 0.03216556130698131, 0.027766345451856335, 0.08243056269542826, 0.01890028733009052, 0.03894734316535535, 0.010101993515666936, 0.03279525876766251, 0.04349469935761825, 0.05454209708278218, 0.021125767004465865, 0.008552977139310492, 0.08837750406875726, 0.05220103197761121, 0.023616665501087427, 0.04850614395353103, 0.03351785971092121, 0.12024840114698296, 0.03594256629566512, 0.06044291230219026, 0.10357792188803996, 0.01990568196971811, 0.10808310877051085, 0.055712227439207423, 0.04318491255323734, 0.011393700110455676, 0.01407004742612762, 0.02049635108109684, 0.10092312079523841, 0.09989949709345257, 0.02117972066175313, 0.042097102174715656, 0.0404637337722365, 0.019812669319611405, 0.02816049768889864, 0.04671960393147123, 0.1254272014803944, 0.1694603955313083, 0.062260092010781656, 0.03831250525470223, 0.13818436572628637, 0.06511020338943889, 0.05636516034663205, 0.11293727934600846, 0.17390483930226297, 0.09991950731003478, 0.019785444470002286, 0.061987981410516854, 0.12197055913988622, 0.013972808843508605, 0.03188553701845869, 0.03447106461070719, 0.04122504513830908, 0.00238231151841671, 0.06493146741582502, 0.04357054972300126, 0.03933404902777365, 0.03691092441459337, 0.0526809286055786, 0.012435883249817117, 0.0556923397966931, 0.029512755873222506, 0.05413313253572392, 0.00527897973604981, 0.03942806716828097, 0.031215506943783937, 0.03636740035407486, 0.010484575909832794, 0.02088549118789454, 0.016909795550389156, 0.04090018555401795, 0.01172279424574827, 0.018029938669755094, 0.04165056101497143, 0.054304831991753275, 0.059892604533102245, 0.03981907844483372, 0.02148293826218334, 0.021765218679642966, 0.023428523882983193, 0.046503314327809124, 0.02923408181466643, 0.05617047442243465, 0.06727252486011676, 0.0579722366115499, 0.053300299201040506, 0.021520474655253273, 0.031174645729122624, 0.052603511590390443, 0.031480178830303976, 0.009308932593182452, 0.037757164287951686, 0.0571896969490955, 0.004871753250969755, 0.02865838014610833, 0.03418630589881251, 0.024355978652414297, 0.00923277770784954, 0.05891698773109144, 0.07266787526708457, 0.021201937211557262, 0.031076258972227096, 0.026523695297298894, 0.033535797659668236, 0.0332874319546165, 0.03166862496835811, 0.005858863765869531, 0.04728204270284023, 0.02363661826107531, 0.07237480067077183, 0.023658562849666324, 0.02349718259797702, 0.07495524526964273, 0.03176531292528155, 0.022148613127008564, 0.051102293354849664, 0.04896060646241231, 0.03681983656039642, 0.06218390073627234, 0.06823111535801042, 0.08977198327380805, 0.027305578039358222, 0.05325688882881115, 0.021132730743697575, 0.017976346989012053, 0.08062572849373664, 0.03856501932586393, 0.04106817331405417, 0.03655526426530654, 0.02099010432439466, 0.04298471462642474, 0.04606064191208251, 0.11728783138096334, 0.11262926603517226, 0.13721436051832092, 0.1407276244173127, 0.15643777415877388, 0.15044191041060034, 0.11274882171663547, 0.2378880737289306, 0.22437500286727186, 0.09214579097686276, 0.1781223218647703, 0.13041900741236825, 0.09352043616555392, 0.2629162581457246, 0.14346738466091696, 0.12984928314483937, 0.10230543452405161, 0.12636392782892913, 0.13360988619106431, 0.1687552269187666, 0.18147387992470496, 0.11712940439822213, 0.12746063631869134, 0.22406346555198395, 0.15181185948031564, 0.13413804252782177, 0.26064836209820164, 0.17683976810545693, 0.1619621414330698, 0.16655997132822392, 0.1634609311698906, 0.2631148587792151, 0.05809645776847198, 0.12462188985439078, 0.15638833084414083, 0.20728961804941778, 0.14456183319130253, 0.18266571355202507, 0.21699930751515975, 0.1971699183266009, 0.2549312317803983, 0.11339361493986462, 0.13963791031029918, 0.1765275106675202, 0.10197876697225917, 0.15666096621463377, 0.19089988703208585, 0.16031073165997384, 0.14616275777018842, 0.1635663448682716, 0.1283864382534258, 0.14089720564023142, 0.15656594066850602, 0.07071406760763738, 0.0750373162689709, 0.08585173516504227, 0.20558884157048118, 0.09278543608924074, 0.1248823520877669, 0.18759386523837046, 0.13015233220592623, 0.2555073452212157, 0.154184740216982, 0.14771658326348952, 0.22614722470602683, 0.12108503810821042, 0.2374744168933361, 0.1781943034861357, 0.09688327870061321, 0.1080789106086858, 0.1368330172713726, 0.133024120042401, 0.21608939424397486, 0.28011686258739044, 0.11966475706186988, 0.20277098632387577, 0.176676269620657, 0.04456552556685863, 0.07873135393545513, 0.10727634157745108, 0.2198033885008866, 0.3565743986156679, 0.1991355007574443, 0.3537342348887075, 0.25071201785918207, 0.3201454775708337, 0.1975455772011511, 0.23950838033230076, 0.30245803957504613, 0.23383857892645946, 0.15160071032662548, 0.21806443019980387, 0.2038117167690108, 0.09220075778542988, 0.11598585729276943, 0.1273617496894252, 0.10102091957965206, 0.18134369094285274, 0.22699557515161656, 0.15195249790145507, 0.1549764614432089, 0.1749953041754423, 0.14309762466338374, 0.1562158844523853, 0.20673284066780923, 0.12909582034955103, 0.1825810301928751, 0.10277109340794625, 0.12321942801316901, 0.19321158798711915, 0.09972358798427929, 0.14744698160117672, 0.0852154378568934, 0.12481732654475397, 0.11975330916503746, 0.11436311452980004, 0.15471533271333865, 0.15319587392432077, 0.13284822625498618, 0.11733142178385489, 0.14890709921957987, 0.12000614882356699, 0.12578989048638653, 0.07386955312423168, 0.12367576360702516, 0.13640675062854446, 0.14959725250880565, 0.1685946395680789, 0.14642621540734846, 0.2037766912291127, 0.16243913841824378, 0.22519955862193342, 0.13325010065830525, 0.1379397691738221, 0.1782728887854084, 0.16889030354157572, 0.1013285115421299, 0.13262261336128559, 0.1309955958276987, 0.15020673673960472, 0.11278625277261581, 0.127456997401051, 0.11164034611635631, 0.10446505170435676, 0.17676723490078605, 0.22063965007903116, 0.16236326507022306, 0.1535259965326517, 0.2075094699619278, 0.20937251918498548, 0.3533943676419797, 0.08857448059584826, 0.1344022662529061, 0.21398844407691112, 0.09849831461906434, 0.14230810977037878, 0.2476923444098042, 0.07888998776193588, 0.07477506138985196, 0.10605949517940322, 0.24907770716855604, 0.1618239544932881, 0.18656171497798738, 0.2113060025318015, 0.18143877777601444, 0.12169550293155255, 0.1389212350571348, 0.1261476535470255, 0.14778591422063692, 0.24097389120969082, 0.22544438500077496, 0.13114516683403524, 0.11393660273883613, 0.18311027437448504, 0.1673580817277393, 0.18435194968215882], [0.049387512788657224, 0.05399534779210245, 0.030520714992176623, 0.06282875141609581, 0.016663936868069634, 0.030467399103086323, 0.022157769792923526, 0.046053900338348844, 0.032836118067104014, 0.04784722406897814, 0.024208039413356496, 0.0625850779995803, 0.09172873271088447, 0.04514474932464861, 0.07997988573005123, 0.02431327308107528, 0.022869716368375287, 0.0716847316512177, 0.04855735310082955, 0.046961377449934526, 0.05523586630701058, 0.014728084394347765, 0.016401452162573417, 0.020256420004091436, 0.03317114746858997, 0.04663486311572694, 0.0364978076709855, 0.05262259484058427, 0.09941821767678184, 0.036468677177664735, 0.047105210457718184, 0.0405261775989446, 0.03198898187087428, 0.03824587092704831, 0.042997956456195925, 0.05947682563395751, 0.012414548658735812, 0.05007021970325901, 0.06650507329933106, 0.03360371901503494, 0.047283103734615355, 0.0670610079842229, 0.022182541245955135, 0.06786923840521805, 0.0638074632133207, 0.05377166160953142, 0.01951402909452877, 0.04784843065745888, 0.01966204877281862, 0.03750000772396884, 0.07411108532499883, 0.09200717502784345, 0.0174351594966626, 0.061153535460752834, 0.08423191119706439, 0.022702249548127575, 0.03913708399200151, 0.031636815082522175, 0.07358369507616566, 0.014329142192558897, 0.034416844737866235, 0.032931285339497754, 0.037260448199606715, 0.022911014253153436, 0.044112882516797514, 0.02443121231701826, 0.07585458652747255, 0.030675562429091627, 0.03640556302402289, 0.020831294297691316, 0.03398600838056976, 0.029297379829410105, 0.07925147400988687, 0.028255046345293525, 0.0823040202920956, 0.05598362174726302, 0.1523482129578629, 0.0573571790911017, 0.02628539024191278, 0.051767257673125115, 0.06342523896525945, 0.11945357726466273, 0.010749185551708985, 0.14753966291825618, 0.1450103317056933, 0.22223761755852933, 0.10007997974753381, 0.07511728052650729, 0.08159720459051671, 0.14732155768621355, 0.09864194844398769, 0.10290487534216336, 0.0953685390132089, 0.02621590415196073, 0.02618042853540711, 0.013022591686627318, 0.034109785206495755, 0.036795949938917355, 0.12703347335299178, 0.08485154609286016, 0.04388248540400978, 0.04442628142574141, 0.08422650261631898, 0.11517749663682715, 0.07369873083887563, 0.00681621368013082, 0.051973607285969683, 0.04625659954223422, 0.01906900861931424, 0.01811784534384647, 0.03187953280435214, 0.08484503434550378, 0.03749113259536605, 0.049787058284686464, 0.02538719237030995, 0.0074289197894564325, 0.09808800558769896, 0.03404707707945378, 0.015032488473450706, 0.042528313915095026, 0.07704805192207137, 0.023270885970804, 0.057012734469026334, 0.09291394733853879, 0.03859557091228424, 0.01936312892564362, 0.05901311261339053, 0.04206082025062173, 0.029252253420230363, 0.06408492493773661, 0.0097965523450365, 0.03657147468578431, 0.015101151018884155, 0.04415651505452491, 0.020720177074714054, 0.03251478248726457, 0.03625060258913906, 0.023413943314564326, 0.007565841247748224, 0.06793111532686219, 0.08354683707077658, 0.060000339477893815, 0.05211156439937411, 0.02247525769616327, 0.03244185474731269, 0.040519566260158055, 0.02664949459534499, 0.0366487538051461, 0.007657169462031415, 0.1213990422266145, 0.06088330943678176, 0.02908029732474637, 0.01808152894579595, 0.011687003575535792, 0.048700427681568174, 0.005332809382854331, 0.05438612924227792, 0.03888810158617074, 0.01043206824350261, 0.0495861862005005, 0.035039827437891115, 0.06541305326766546, 0.033223597678325834, 0.0749093872464953, 0.043380081112827026, 0.042631046305741035, 0.045352910735434106, 0.08367792237550022, 0.021242537956324317, 0.045291118083461646, 0.028771858835112185, 0.0802654143603098, 0.06616689144603669, 0.02927024116469247, 0.04102423051071744, 0.03349558953496237, 0.07891863178942474, 0.05040657443685397, 0.024324486693066937, 0.02439239655711478, 0.062051608843067964, 0.06284571260273938, 0.031020409247327237, 0.01602265903080303, 0.06336860591545701, 0.04339717253441772, 0.08036792458545777, 0.05118269811294252, 0.048629445804943966, 0.025846877683615013, 0.023425497835682287, 0.006094182514765811, 0.02291489831892954, 0.03689112104175072, 0.038575790522079316, 0.07856322827959254, 0.04734095486421739, 0.015079567449227458, 0.022633025843289592, 0.033641617384649096, 0.0321115444474403, 0.010202545428558463, 0.030828238006741292, 0.07180165965110064, 0.01898030904422124, 0.03004159785867218, 0.015628315271779655, 0.09598186900538784, 0.008386447819160118, 0.07249330681177878, 0.12251162405816779, 0.060062427073717124, 0.013105280344344437, 0.03209623034983393, 0.06283070110986311, 0.045489289707714514, 0.04408148057278126, 0.03833982778052169, 0.04366301653546192, 0.04648762484711986, 0.02408278595295645, 0.04451451943286004, 0.022003441380577225, 0.054298090418019605, 0.03695243488877051, 0.05476186855606014, 0.10190677769001454, 0.043768039529001525, 0.05272060812961671, 0.08442265176845175, 0.05518424730267256, 0.014267108222890287, 0.05256362522261278, 0.07475878968234025, 0.03707253449265996, 0.0736165066219626, 0.03211922830932083, 0.033949443003943855, 0.058681404203056335, 0.050658628855261116, 0.013267104927029823, 0.028998574895423748, 0.04360477087057887, 0.040620253196046244, 0.021981468063689048, 0.00951713135075425, 0.04809563573930533, 0.03392881991702222, 0.09073876325161227, 0.034260589614390366, 0.015872246285359708, 0.05430137310477515, 0.035277544520795345, 0.03335010560770189, 0.0840308744039747, 0.01559016792359011, 0.1090094086623961, 0.15455970961240031, 0.11762531609424662, 0.12379993113779253, 0.18734692445685788, 0.17538498245900677, 0.10843119614066617, 0.14195690442237163, 0.17382893531072527, 0.25083705873018314, 0.09570400125437206, 0.05462235628416943, 0.21551392431701386, 0.051667145303180145, 0.055438419954190334, 0.07759690029366363, 0.059002540600035465, 0.0931249049702479, 0.058361340329171195, 0.06859349792883282, 0.024836061056703333, 0.026778122673051494, 0.01855465335651271, 0.11076111466653886, 0.06778528282959616, 0.03924144431948662, 0.031711204135189616, 0.018035253404729792, 0.032248490324784676, 0.10192542427009153, 0.00980857034934865, 0.06931423344799588, 0.03564666100447217, 0.0603264975812166, 0.015325109162668308, 0.06430936571691306, 0.021041934002911853, 0.07257364645239807, 0.026759248181817033, 0.055101276150033365, 0.09511972131628184, 0.054785575146877, 0.07877137436861954, 0.06583431735634804, 0.04925604827041107, 0.03770117092156603, 0.023905164637272398, 0.056116189432120135, 0.05934897705071396, 0.07782933903076956, 0.04303854379442431, 0.029990844533688603, 0.060105186271210836, 0.055414931698431896, 0.031027443849691944, 0.07410871811331281, 0.0575049574516954, 0.027310682100153742, 0.05100560539792623, 0.0022101050079424657, 0.05019535250481098, 0.021337548180693583, 0.033269827254116535, 0.0475460059580303, 0.034791833285482666, 0.042072709935206565, 0.05046733287012866, 0.040272939574694445, 0.028464276448733387, 0.14498405488989047, 0.055939847483269634, 0.03029194964666761, 0.07519659360930805, 0.05212650311389758, 0.014981662370114317, 0.060000377782290025, 0.03254676665810328, 0.039915858332308075, 0.015173701460533326, 0.02924243791870052, 0.0537237657925054, 0.060759942467895255, 0.03858760359787172, 0.049448344000284715, 0.02050172901832529, 0.060679893940687187, 0.04947045712821907, 0.029245048363302505, 0.028406697280344465, 0.03008777955396762, 0.04018593879957353, 0.021506085608815475, 0.027338554294058875, 0.034668550586267825, 0.04946623981419591, 0.03741295715313285, 0.1515783099157195, 0.10358565171519596, 0.21018794317158962, 0.18816872229499204, 0.09896100874269202, 0.12627394314134313, 0.14039154164493084, 0.16603140130398736, 0.10602859885341699, 0.11571315297436331, 0.11975716258729659, 0.13150792478794052, 0.14770864659259397, 0.122760005084978, 0.13943475911453848, 0.08174492932495572, 0.1318447123612127, 0.25752664573730966, 0.14051373266885359, 0.16899153439989015, 0.24050434059914083, 0.09504441487332506, 0.06819857960386623, 0.10357632842515746, 0.15865754456289355, 0.139525770359943, 0.10735073637577797, 0.16449173311552695, 0.19511605192336345, 0.11721977212977026, 0.13671649529808952, 0.1690104108063444, 0.08219964847329163, 0.14229674102558246, 0.2166680204531839, 0.16697064042091372, 0.07963791174153168, 0.20266805475036945, 0.26047881151879987, 0.12764135646002908, 0.2771546457323336, 0.1458652858291903, 0.17223712717813833, 0.18581385994630475, 0.29083532131006645, 0.20029639975438196, 0.13791606641344487, 0.1897950963147225, 0.0918398077990259, 0.09456330399599769, 0.16157398000359535, 0.2625146442122998, 0.13044978882516586, 0.2329362805692419, 0.13588826232139142, 0.11284512662959677, 0.12434895570960738, 0.16300539996835495, 0.25873694208360487, 0.23266600474955576, 0.1436340700714819, 0.14183152647268388, 0.14081232309822114, 0.20454717649807855, 0.1939545247343279, 0.21466735119540847, 0.16012137004685018, 0.10952069574306089, 0.1122481679363597, 0.11409677640204469, 0.16857461402973822, 0.21807169271332605, 0.18863079588740103, 0.22088335796950326, 0.10718960510266405, 0.20665139019969972, 0.2134172335988091, 0.10660308818783491, 0.18749097963013958, 0.16296666656290332, 0.28283013151057307, 0.23342225610488848, 0.2394285846141077, 0.2748948089297741, 0.4427917415816938, 0.3787643498470707, 0.22632796016912307, 0.27947420674947004, 0.2872126753772459, 0.36392602348519915, 0.3199546910341709, 0.20309055224061015, 0.2945606536682575, 0.1877046415522214, 0.1390068377217939, 0.192193380526958, 0.15113951007445015, 0.18383151551167812, 0.3021364971514671, 0.2108933416105086, 0.08491257265690835, 0.13676129611990145, 0.24415573015088038, 0.2532826412108637, 0.33732055596286253, 0.09815621039559765, 0.16669311740946385, 0.14303872782376506, 0.1381358876824379, 0.2643492409298497, 0.10941006498591554, 0.18857412070276278, 0.14553326332280714, 0.28032352246584435, 0.051229195819506725, 0.13749661795314283, 0.2116947615098569, 0.2606441332928596, 0.20689898981682717, 0.18631354845579595, 0.14565205291634606, 0.10162018419754121, 0.2266421328268705, 0.2152780611668864, 0.1260801458791379, 0.15618553204882532, 0.17427083014720873, 0.142222170027033, 0.10376136164150893, 0.14397047460079193, 0.09251931246610419, 0.10718213574540232, 0.15491223263163723, 0.10851067010193102, 0.10558211515026708, 0.1844651468338505, 0.09383745100950042, 0.16197730997397056, 0.12737331761708184, 0.1391620624570116, 0.1725260955431769, 0.14625770670752372, 0.20617555766817064, 0.1353133439777359, 0.10434646129367814, 0.10280558268629736, 0.1626488779701533, 0.05206537312797962, 0.2231263714812456, 0.3126375707647493, 0.18511992218273302, 0.19133347747547014, 0.11899393217097368, 0.1421933038340461, 0.11578011671982466, 0.14437092408057184, 0.17158690239152602, 0.13689997335595472, 0.22820233217170163, 0.09191712905322352, 0.1316206009998437, 0.1549001284424336, 0.07963657874854342, 0.2281026947762697, 0.12316744128662734, 0.09680010453467408, 0.17840352209825672, 0.16861687143964155, 0.14435655227111233, 0.1141047973426119, 0.15757970481870637, 0.2486898981395268, 0.2392852648852333, 0.11861372273415328, 0.13906840054738906, 0.17873021263268687], [0.014131486720045008, 0.04429845965557522, 0.06339246572385873, 0.02618015274375437, 0.06591369172618275, 0.0346971448180416, 0.02355005032563162, 0.03432182302217811, 0.05156996704998517, 0.0636273444510035, 0.05456201536881347, 0.028707042051058625, 0.017280739153765382, 0.04540245364149732, 0.05545528921028299, 0.019484896685988195, 0.027014363121481675, 0.058887432058972705, 0.0482821551662299, 0.015378954610036267, 0.06584481276091068, 0.041895517628760114, 0.02385408955536062, 0.046403929741392215, 0.03404431916292637, 0.07280845240119004, 0.10076885366992605, 0.07052519629078527, 0.05763655986576792, 0.024189404324598374, 0.047826244751171726, 0.060039904088743275, 0.03972219896592921, 0.0155955353271096, 0.05943004830530094, 0.04522559841373756, 0.021877161362358642, 0.06938680495706297, 0.02864745190186847, 0.07416982128615342, 0.0594738723650094, 0.07827907094671842, 0.020894732123481172, 0.006148711216801237, 0.01557307267155979, 0.1009719435786528, 0.056718330710164966, 0.04562926546279942, 0.03239437261776578, 0.024428488874447443, 0.027862916580371322, 0.043004893382350286, 0.11280172008780703, 0.050228566246768164, 0.012541819803206431, 0.01829337523949723, 0.027479677265810392, 0.010246885640005912, 0.03573489901159079, 0.054801532758339766, 0.048990376639149846, 0.05717815966495583, 0.013785798162702593, 0.0068010652490380795, 0.02441673708568898, 0.022654472474729823, 0.010290002983604229, 0.03591927722276699, 0.030772805799760168, 0.05148436055488644, 0.0639318299269484, 0.03459141702361165, 0.12036423364113416, 0.1147638091577157, 0.04529952972887024, 0.042344242139088537, 0.0545714152676444, 0.0735915398165103, 0.10152352688413474, 0.1165261178187305, 0.15743702860368838, 0.3003437901216169, 0.33682995325615334, 0.413978347374547, 0.47769415582860675, 0.4952203169945748, 0.3401289117192069, 0.4415049283735214, 0.6087847005936408, 0.7164622807214338, 0.4386906890619186, 0.49016211422220357, 0.5274834664117906, 0.2094588572940519, 0.05667563663014481, 0.0180566425795757, 0.02661315712987656, 0.04000487008823022, 0.0586402882641602, 0.023644223598943605, 0.029804551102701696, 0.06654861773694716, 0.05385123516222643, 0.11046419430884624, 0.025044088402102073, 0.04033908360607682, 0.07917661189792619, 0.0625729086929031, 0.04788600343970522, 0.04899804517927189, 0.028908816203775427, 0.05603989856618066, 0.03013458944136097, 0.01949822087021124, 0.016284198575322668, 0.035921682738849235, 0.024847743897548607, 0.10209419343981052, 0.02673482529879097, 0.06698777763954095, 0.022241644929313374, 0.0605447905048007, 0.03169474856657607, 0.03727972680222123, 0.08352519508691565, 0.1143579894015866, 0.0454623693780553, 0.0878040106486409, 0.02281468252711479, 0.011560949553254873, 0.06756791304196082, 0.026978360819480112, 0.03818920723372891, 0.03462234016267523, 0.01540693022581118, 0.037403147397262436, 0.05876823260839428, 0.02859224952126463, 0.02295529605039666, 0.03559019649401307, 0.07069499967920204, 0.043750300763114806, 0.011858206032024277, 0.030011687870888464, 0.030525495380824132, 0.05005878584098913, 0.016359382444211555, 0.0439551679958259, 0.002303178226875682, 0.030552356338669217, 0.041229262452332244, 0.044490820502922426, 0.04700858761826831, 0.03636260464366886, 0.03370701064986568, 0.018482660243828452, 0.054981866025275765, 0.02219077094548172, 0.012160673823898599, 0.014033005159768849, 0.04368764626222753, 0.020240169363997636, 0.003237137800991355, 0.03275439563778139, 0.05290705094774885, 0.05816209618182433, 0.024167530599140355, 0.05168833146472612, 0.02885690417080637, 0.04860917894890712, 0.036454504551065546, 0.027385467603322, 0.03520229936487252, 0.054051819963440786, 0.07786439521418465, 0.07993496233417142, 0.034565707112872796, 0.037013541892050736, 0.029908333033803972, 0.06325909747712075, 0.07048782652183887, 0.046373014263207876, 0.05551438523276199, 0.10596313664028723, 0.03362493198965827, 0.05430274823259923, 0.07402134578554861, 0.031516581413245974, 0.018771124906056834, 0.006969425040522531, 0.026241914752209862, 0.07771198968252829, 0.017166237737382614, 0.02946971322319681, 0.05534204226287623, 0.03201537934552518, 0.03750838106498122, 0.0575691556197501, 0.0598863494252005, 0.1177952497176105, 0.024366816881323056, 0.025144941962113785, 0.048186095401404366, 0.03191628395729969, 0.03502086293132555, 0.028374060019550305, 0.03233863589083476, 0.01341463909709766, 0.03615818557239348, 0.09849185649786266, 0.027571402888204304, 0.048240334426443425, 0.07191032156228058, 0.05816250603886382, 0.059181146338702216, 0.04077705607238797, 0.048637110514626394, 0.06341877701361814, 0.046648583750450806, 0.015762986825598825, 0.06052748840903083, 0.002337512851227075, 0.04309239977550122, 0.03759284608907277, 0.030366539797415177, 0.033675348235955166, 0.08378584884227284, 0.022183554397234996, 0.08756084668059504, 0.024554000889521935, 0.024444877410367615, 0.05952781261575799, 0.02134713385584614, 0.07058495880975839, 0.02992441513455443, 0.07931743418016741, 0.070743209592277, 0.06010236323720986, 0.04949110702821805, 0.02381215581760532, 0.024965589287720864, 0.04503792219404732, 0.1059399011935438, 0.017056028328595624, 0.007713459687487734, 0.029015509268989968, 0.02230374976211498, 0.09018711865909639, 0.09451490256094164, 0.08459269264412504, 0.03527713083331624, 0.04379615878626224, 0.09420499701293246, 0.05729720206750978, 0.17105416484898137, 0.13593946763825032, 0.24135198624384022, 0.5212951307335209, 0.38267666894582014, 0.3138769478086503, 0.28245919173763645, 0.5264933743784505, 0.38874797703277686, 0.3966533608974949, 0.48314802769211035, 0.6248371230979121, 0.32223628473378, 0.3801570364063786, 0.7025299605823333, 0.29689541386981166, 0.13231784826324833, 0.01822167515544401, 0.0884365541259608, 0.06421266626867075, 0.040972178666702205, 0.21091447031546026, 0.06551651344183954, 0.044807800872912334, 0.053904106720320644, 0.12327967316753442, 0.09051665137972563, 0.07587495680537916, 0.04541115640031715, 0.012967764689106376, 0.046246012207120664, 0.017341578026272116, 0.036649550536587354, 0.054046890187648036, 0.033189361208989736, 0.012513346230280737, 0.038752638088959845, 0.0407176421234204, 0.02273962697795322, 0.004247167033158363, 0.0522918593619139, 0.004663102980327583, 0.03271152535753866, 0.03385928977701453, 0.04699373317341651, 0.02526911906898022, 0.05142537561515647, 0.06474120181895072, 0.013334032283314775, 0.03384098793650347, 0.01964809639649766, 0.020732675799198692, 0.03326803460837372, 0.06108629975407835, 0.0160093559139979, 0.04594015160335168, 0.026022520577234608, 0.04504385171458126, 0.044426756400254466, 0.015951242399281793, 0.07091794658692614, 0.027766531228177974, 0.09253373024083915, 0.03931608426594927, 0.09244808927178384, 0.0895738882583476, 0.04795682060742571, 0.02191256228533964, 0.04523032134579075, 0.11604796404079085, 0.023285855328844442, 0.013834311638117559, 0.021681278425779556, 0.06834540801543383, 0.04508890151496857, 0.0015644920706343389, 0.082167319562887, 0.03942505644273855, 0.06785925627956468, 0.06146612997737624, 0.009446583271417166, 0.03463190093997025, 0.007422932333523228, 0.010522693572115275, 0.05020572150486612, 0.01651749150046418, 0.006895699611519494, 0.07611157838255167, 0.026132094133044445, 0.048768552050234816, 0.03952886901735779, 0.07501824834053555, 0.020052269063589555, 0.021387297930496357, 0.040482487604622884, 0.04883996293609662, 0.046530242318347584, 0.08768781809316528, 0.17039258663933124, 0.15768115018163958, 0.07727693601120865, 0.1940638454811227, 0.12679172664760582, 0.09857254853892712, 0.1439753162764734, 0.18989841093219098, 0.16583191200850472, 0.15132007699820305, 0.1220791367813945, 0.14954744147196894, 0.19250710885370934, 0.13457275145957548, 0.17192617208967287, 0.12951791947407107, 0.12188232879364684, 0.15050437721994617, 0.18421865038333401, 0.1339864950146406, 0.1541026462350161, 0.15141922409736341, 0.1571660479831119, 0.1976051941634186, 0.15473276887449527, 0.19343232856162135, 0.1626191690804497, 0.1544961396364435, 0.12066850844289988, 0.15730071091844192, 0.1196840011905278, 0.13949135769038432, 0.13637488137089437, 0.2582047254808488, 0.16815063032892444, 0.2131315900553619, 0.13370558589456544, 0.20693844334492761, 0.10946263393927967, 0.22236343983921314, 0.08470421206326255, 0.20253438772934101, 0.11441620442295268, 0.11140953148564986, 0.2118567891058422, 0.16306239690992141, 0.16216127832810726, 0.17631797029847102, 0.09106277247830745, 0.2209298595065071, 0.12582239559701375, 0.11375357667284627, 0.1941358271024881, 0.16064758052027997, 0.17561177512811077, 0.14791014303843822, 0.11730075528424595, 0.23314588222532506, 0.17615744423481727, 0.22057879205432632, 0.1738291957806195, 0.13521013661257683, 0.16496044102936022, 0.11927843424341372, 0.12241405510013142, 0.161699480527351, 0.20611454642588095, 0.20783749348934621, 0.17236167775286784, 0.1371396516239451, 0.138978507790354, 0.18672870682372203, 0.3266189511745207, 0.2851852083638791, 0.22189611088364358, 0.21925076331582763, 0.25530574152306207, 0.13588300695823086, 0.33157235311885036, 0.21135330080024659, 0.35318957701806103, 0.6104484597040761, 0.6909956795073325, 0.5332712913232466, 0.49680667058114086, 0.7692530931484315, 0.5274534357651588, 0.55129102761707, 0.7465696587197242, 0.8872569869122199, 0.4965262517573372, 0.6091008191147159, 0.8275036609941914, 0.36726098808069385, 0.21085664599893555, 0.27906061120090947, 0.16666728492465713, 0.12250445347519652, 0.23243153587945048, 0.2875086304641539, 0.14473259418962464, 0.15936855076541825, 0.1577606701081799, 0.21529917455007955, 0.230409630664414, 0.23110801173794657, 0.14661485689782328, 0.16880598790462942, 0.15702764653871137, 0.23844431484899214, 0.14420503540144813, 0.18499321124005705, 0.1076643574502199, 0.12129243343107163, 0.11283532836504521, 0.1383740797398552, 0.16296203939184067, 0.2005169717895408, 0.25268227342636357, 0.21751822483155037, 0.13603150544147338, 0.1010711826083641, 0.26940741305870397, 0.1750444716984226, 0.2099636173056018, 0.19172741520789363, 0.23117011082508873, 0.12065629700138686, 0.09630277557598968, 0.12140621280958577, 0.2070425853373543, 0.12491770704547245, 0.13518624999109777, 0.1868815260428575, 0.16939832708768307, 0.15608537371360487, 0.19709931566349922, 0.16869619218332155, 0.1446311641484499, 0.2618667789764943, 0.14286488715198734, 0.09650272452422688, 0.14298985141419596, 0.1728078473599688, 0.14017787972284904, 0.10763075683386096, 0.11441685559768831, 0.2212619126564072, 0.22463577919669692, 0.10849136468623916, 0.12117249470564628, 0.11978540058818557, 0.09512078617849658, 0.1462164298901635, 0.12421473710527345, 0.07456611856938371, 0.21575432270765307, 0.09914021202993971, 0.1475933043947143, 0.13781751686286542, 0.20010948962261602, 0.08954502972623996, 0.11854282895764036, 0.0945929439377881, 0.12783234217955222, 0.15687934723832916, 0.20257246229917775, 0.171493225160145, 0.07489519163725838, 0.12007445322289584, 0.20318894857360473, 0.09903138157941642, 0.11664647789251421, 0.11505087762470208, 0.1702814885685521, 0.18742169463826766], [0.09186361015083329, 0.03210745736836426, 0.07436630751697287, 0.02177680192905809, 0.02588355222777013, 0.0587109637056147, 0.046236995352251876, 0.031541774214635936, 0.0208718107727867, 0.08264823125735407, 0.0287993518154948, 0.06947715736685262, 0.03129147605279521, 0.030342088186091958, 0.020181525333393967, 0.07476776057193357, 0.08131850180366347, 0.02916904669555445, 0.017270552099592263, 0.032935491162202055, 0.03455949030936726, 0.03433435239017971, 0.021639817747317498, 0.09697926185664632, 0.05881964859943237, 0.010205265998299564, 0.034331521695299495, 0.01880832230522027, 0.020507009279343392, 0.022963286347446904, 0.03366412121742483, 0.06140871168745141, 0.049423223977247556, 0.008887266308339614, 0.01885149902063272, 0.028563207128055157, 0.021131217720047123, 0.031134236506336642, 0.017214478293974555, 0.015654894692312567, 0.024139271530833457, 0.05966398091385922, 0.029078454883288474, 0.01152543563230504, 0.029300436520227985, 0.030742321246033235, 0.0785609683202159, 0.06908538000237557, 0.04294049603143527, 0.05767368065613893, 0.018202423365906845, 0.0570358703243396, 0.037821649738977996, 0.0356147381206674, 0.07848769967113772, 0.037152659628660455, 0.031030582894961682, 0.04214827301761797, 0.10825743207768088, 0.01789840328837595, 0.06134249487771623, 0.0026813446029630163, 0.03117823485104788, 0.03284767833388141, 0.05888506484728667, 0.018374159211112608, 0.08612335929947515, 0.05562261047382509, 0.012547861364099288, 0.029947499278932813, 0.03666047495038759, 0.09164396508206284, 0.18838825245057383, 0.13142846614843415, 0.09533293124648834, 0.11777592131928091, 0.12831699238308977, 0.17612159131996094, 2.601532609232011, 5.070559709302841, 6.541748094943262, 10.776527697040189, 17.48400034443025, 25.271436822029855, 22.623562389804473, 16.667545264767064, 9.634724759286451, 16.415142705363614, 17.77557953711479, 27.463567141563665, 22.879959883228427, 13.212853996984421, 14.362143758804569, 3.6581044043264086, 2.2337981481705946, 1.172242001179726, 1.224699412142077, 0.09407314562028456, 0.10787527677753281, 0.2957362921968583, 0.07739129761654524, 0.03247693008292587, 0.07847997750486098, 0.12130246918287971, 0.0938152727640925, 0.09802848821686161, 0.005452814662168104, 0.14824426462573392, 0.07756347587752728, 0.09662012749862287, 0.06598637814843847, 0.06759952949059587, 0.04029652742188304, 0.032534260272739396, 0.03570697510675077, 0.007148958703187565, 0.015941032362470946, 0.020968671099493102, 0.014989724487907466, 0.08719938341528179, 0.1072289360566966, 0.013241500353380559, 0.056518649892701264, 0.03989356517371151, 0.011223423662745665, 0.07744536044136172, 0.02270684607567326, 0.045462668152345766, 0.020612604923606403, 0.014890756461799387, 0.015391915860105188, 0.04880504464850791, 0.04384218534875301, 0.04315957802558138, 0.08744228691343339, 0.1547254910392146, 0.03210778104051227, 0.019413941622441335, 0.05121882298901197, 0.08809851016849281, 0.01909870410247916, 0.002118548882501801, 0.013558329421005422, 0.039302742844747926, 0.020164497114057024, 0.036272033898820805, 0.09967121055289622, 0.03135996239800607, 0.018661451758816838, 0.036878802347928286, 0.018312967938160705, 0.022022794676764358, 0.01782124482786223, 0.0321453174335822, 0.06311579690044446, 0.007132638157570675, 0.061599693576534914, 0.019395530614401066, 0.061420812046215426, 0.05070705710339451, 0.08352954646632557, 0.052308916309548, 0.00445360426730927, 0.04240141911131721, 0.05629299869460445, 0.020840198154591268, 0.05561362426247328, 0.012300762576952338, 0.012037986758044891, 0.028137020924459064, 0.06070076983662383, 0.020335736917331815, 0.013765395326059193, 0.10080157328517207, 0.04322266153570625, 0.052141054954019286, 0.05230303658472915, 0.04462371760558698, 0.06689925617989033, 0.051246834993963285, 0.004167303803466982, 0.011228372590736517, 0.00948512898532734, 0.051753368499057914, 0.042662540180308205, 0.03180217133053849, 0.01409250146318828, 0.051844709162269874, 0.016659300120907928, 0.027715670650884993, 0.0691114423135596, 0.011314417671171889, 0.03318064312841142, 0.0333742335468771, 0.01798384698979076, 0.03232351714564908, 0.07589514322218395, 0.013928087503318826, 0.019969617752658746, 0.030261020761944597, 0.032833203102552125, 0.03304217656653735, 0.017778108332065806, 0.014852632096247568, 0.03410070706459303, 0.0162332862870948, 0.020235486651560473, 0.007652578201340212, 0.004968604001577103, 0.012968957871048441, 0.020649373313532244, 0.022702605779012366, 0.02318468192712434, 0.018924694891358097, 0.09380898318223416, 0.006654209066783229, 0.02540822722949088, 0.04076269575424733, 0.058660003536891554, 0.01664461613061928, 0.02985673509688387, 0.023755394448075565, 0.07343164194495448, 0.012908494381624605, 0.013240674893642146, 0.05919693924126126, 0.013568309631438987, 0.09474260687467553, 0.05347637301911751, 0.022738468269967747, 0.028786391523035786, 0.03098266601051775, 0.030953947289456284, 0.059026691521848404, 0.0009621588516541036, 0.041364898319326104, 0.04082638830427201, 0.01330744328668281, 0.051143746372432485, 0.053445472862691655, 0.03996227176920061, 0.06615038991214768, 0.02804185365206532, 0.08034415287716735, 0.05708542089128206, 0.04180756307417347, 0.07995360891424841, 0.07905913231473777, 0.29894561837277106, 0.15169389726173493, 0.06125282045573958, 0.15590344315334675, 0.0973990933609105, 1.834185481552155, 6.444475275854911, 8.899347032270125, 13.8976429547033, 19.066517852967788, 27.645563156374042, 38.33823057913011, 35.4603091362984, 26.68866957387617, 16.21195706628984, 25.432161823395763, 29.844777276439054, 42.77860856825306, 37.117671351278986, 21.76587143251973, 24.949094480083836, 10.260569318648308, 5.953502395460683, 2.7790061312337078, 3.184582639125086, 0.4491920384668535, 0.05188200998330309, 0.17061049268851358, 0.11858954499926298, 0.035182955644784436, 0.07399812566056367, 0.14119104632446844, 0.24963178792067114, 0.12269174665092461, 0.054236362883520704, 0.021248247226580017, 0.036373226452739015, 0.03194660188690309, 0.06455796890922132, 0.04564455657776806, 0.04596403822483075, 0.020751644136203874, 0.05616360261375385, 0.05022628330475381, 0.03683053880869862, 0.06098954284924173, 0.02873835589496359, 0.06751897534535778, 0.05491184941943615, 0.05644582940505878, 0.06534489442504222, 0.06814519093642313, 0.05788082700042475, 0.08065592001883254, 0.028242365674926873, 0.08376872677716517, 0.07827859597220536, 0.03331974937370227, 0.0673790570468672, 0.01290504985879506, 0.04754812036070132, 0.017797611015398177, 0.06675312490833384, 0.05831752009990235, 0.0215019200057272, 0.018652611104170644, 0.02640937391157833, 0.05684495738316929, 0.014733272724814955, 0.051640929774411266, 0.01794077369624809, 0.027708647539839152, 0.018116468300802574, 0.008767077646728967, 0.03818321259572141, 0.04006228837815504, 0.03154424293297193, 0.021477677153363343, 0.0325609277933836, 0.07276414187564965, 0.09871913946323818, 0.016440260261597655, 0.06378016750057859, 0.041014459059243245, 0.056035616134683934, 0.024005878386237932, 0.02665732784437076, 0.024236304227322824, 0.015700498948835077, 0.010611369206960644, 0.025532304744927153, 0.029628728178419897, 0.020565716512200814, 0.025849398112885898, 0.013727841696010963, 0.051839492103505525, 0.03265894491285567, 0.11379228709566017, 0.03532290458679199, 0.03915199589344763, 0.025599471503688444, 0.056272027037677266, 0.01532434690518365, 0.03995001819285174, 0.2686526938792198, 0.14196402904006744, 0.24577517873577534, 0.13255415574437188, 0.10949649502553287, 0.09905919057106781, 0.12843067217017376, 0.12926137194998805, 0.155667350176842, 0.1437374459759843, 0.22643876712649103, 0.10775922211788355, 0.16207366851308655, 0.15338485249348227, 0.149506394480986, 0.1363308772805237, 0.18379016208552545, 0.11002470498844502, 0.16338323453261008, 0.07913611649024872, 0.17225912922332365, 0.08463612982943174, 0.17216076353384605, 0.17510407333893163, 0.11206940131922884, 0.15270919358778387, 0.12853158127155997, 0.11066276429881973, 0.18031337929348792, 0.11289546626710123, 0.13117961014711088, 0.2823249731333025, 0.11038101248202786, 0.10193633336213329, 0.09339181000306722, 0.14752403472460088, 0.11064616317350058, 0.13322408431239668, 0.15877250371681106, 0.09353952707662698, 0.15795896430650067, 0.14495174130124433, 0.08062553697175558, 0.10130843237763452, 0.12269870272927708, 0.12341827379479525, 0.13967383983394793, 0.16459961361702413, 0.1569512828944191, 0.16756366908309922, 0.08872494026417695, 0.1486866804020059, 0.13411067786716646, 0.14455470857360672, 0.1821106675291254, 0.11045571371552446, 0.12167431293956696, 0.24793643534423845, 0.24896400439883434, 0.11772853112028492, 0.12271247699015564, 0.07998738573082993, 0.25439618065232233, 0.23662151588547617, 0.2157842001367, 0.25460636453522795, 0.19157442744941483, 0.2684579849723847, 0.1810752230906679, 0.11369601282621584, 0.2881860973373536, 0.2919699281694428, 0.4279646920340677, 0.2572759511249681, 0.3653410491683791, 0.2422511283188097, 0.227823976667658, 1.9020833026978279, 7.40808738816169, 9.649509153058453, 15.337502879481162, 20.280287458050637, 30.056283243240852, 42.35116827872492, 38.05319978344826, 28.503232540622836, 17.20156615780246, 27.421854695966168, 31.588780726155928, 49.768323206132465, 41.75916494861726, 22.739578254761238, 25.66895138832831, 11.595776484858606, 6.396211981773377, 3.3215138075813173, 2.6952051827984476, 0.35526475598735197, 0.2638221111509108, 0.5398500866947636, 0.25188662982996435, 0.253456941535396, 0.16372938370031698, 0.3051217272877693, 0.39712413724872375, 0.25747954665172484, 0.11429722330743268, 0.28726464678202906, 0.23009305249058434, 0.21800438422829876, 0.15337314666999927, 0.284728589317491, 0.12910780196468677, 0.10186309535657206, 0.16339422023344427, 0.1255276739116638, 0.19101977979223575, 0.14368375853425072, 0.08992779023584821, 0.23961520363246244, 0.2139196953465862, 0.20708122681225502, 0.23092936003400436, 0.17166706583192273, 0.1593059154167291, 0.14591258409763538, 0.10295692335573897, 0.14073821175242626, 0.2199799104803993, 0.13511065243472978, 0.12244101373418687, 0.19738528096387464, 0.09797798770089304, 0.13420023354551486, 0.13663227159169414, 0.18470782816650408, 0.10362173445642957, 0.16338530297000564, 0.12403444597317327, 0.1582378815979727, 0.09936150418774736, 0.11131656671603841, 0.12421869011896274, 0.19073018323509924, 0.16587490486281534, 0.1436305767105472, 0.19345679740992286, 0.10472868554173939, 0.09881817164920992, 0.08079953086111816, 0.07944847351961559, 0.14647264033555984, 0.24022654179603825, 0.10094786543519267, 0.16059089001388321, 0.0785577813944509, 0.2224761313728748, 0.09749614904003759, 0.16782505828286373, 0.16236505771596588, 0.16186751425266266, 0.21080252954796438, 0.08772324965966326, 0.0857382009346639, 0.10588530210718032, 0.09386915938868638, 0.08898810678792578, 0.13604420717925797, 0.12141231086946304, 0.20438019997410237, 0.16178226398844875, 0.11350778502322013, 0.13051939557396597, 0.21605105920424386, 0.0961237867933608, 0.20400161464368144], [0.05454248395718394, 0.03107455251137576, 0.09184708563430656, 0.11022203391598118, 0.042133495181558595, 0.09339985392627217, 0.049523642782362244, 0.05584112556290723, 0.05042034486729292, 0.024474358388913736, 0.060062794795920776, 0.06715980268293811, 0.04272282363906984, 0.059281737513599865, 0.017147807577144236, 0.0326690802560939, 0.08807014193265669, 0.039738566434431466, 0.069549675249765, 0.06376795605906556, 0.023503094881532655, 0.009207369444230873, 0.034454095763184374, 0.0840824167995203, 0.04864449943265608, 0.04548940462090316, 0.03600392993839999, 0.030331481698780294, 0.03643606864516774, 0.044036622294375015, 0.01861405772938123, 0.010363272590292318, 0.04887247187716346, 0.0648541844660236, 0.05079470905325106, 0.03409567003649089, 0.046324942245959275, 0.018334816765761184, 0.013427367647959581, 0.056901690024401874, 0.04601692893512307, 0.016534575261175632, 0.0328390866578106, 0.07841039373869858, 0.12770349385156748, 0.03923983170440601, 0.015935844989613663, 0.03333014518683476, 0.04897847929368577, 0.022224542016403812, 0.041628708356931325, 0.06903769868996835, 0.014228902460496514, 0.010867124787651965, 0.028224002547381867, 0.0573663070287195, 0.0271954165110665, 0.038837398056902235, 0.09032321417884481, 0.059822013361319426, 0.03197429596536583, 0.11226672258588577, 0.08406996787075074, 0.04523522813894576, 0.055342390832881776, 0.036110098233386394, 0.22112435390872343, 0.24742452007147575, 0.08848523901354882, 0.4114093174857478, 2.1642300102018543, 4.803420805161999, 13.814923109546786, 33.8553850881515, 29.31333730297704, 45.55060248221121, 53.784485094008915, 78.90518326913157, 94.15069087859123, 94.96542992130404, 111.03974219291442, 118.57116360818188, 127.05143774709396, 125.70990870075842, 127.60682182927286, 120.53824793907904, 120.74812612225934, 139.88113403320312, 137.02889627025974, 135.74902688303303, 133.3646337447628, 129.75221710820352, 127.88367840551562, 107.2448725854197, 103.29771303361463, 88.05410385131837, 87.5885969592679, 68.71196300752702, 49.42703385506907, 14.74782257310806, 1.7803797558430703, 0.5999605934466086, 0.2213146348273562, 0.3515336626479703, 0.5024265996631115, 0.20778041993898733, 0.021289345928497856, 0.04855420830990038, 0.040336712563951174, 0.05224790123681869, 0.07440180803138403, 0.04696743720541558, 0.03413153444266608, 0.06283212220296264, 0.03629937174639875, 0.01813964437573187, 0.016703752372714303, 0.02468504405940973, 0.05123033346007428, 0.07789961227606382, 0.042706969449476856, 0.044235046727642904, 0.04747886218190674, 0.07727947942311726, 0.07262407802045345, 0.04095791027911248, 0.03655868867832807, 0.06044783441710377, 0.012691616805480614, 0.025825545965363423, 0.025935085047216668, 0.05809825424465442, 0.03835016230662023, 0.008902714471332729, 0.04729533815876611, 0.04982045588774547, 0.03746005240827799, 0.02739469321715015, 0.11531547673286931, 0.027999337687487566, 0.04796440104743646, 0.041607311521206176, 0.028227926832773996, 0.01222073894760181, 0.018564825088927345, 0.045440317537154884, 0.021673355161422686, 0.04776334510214868, 0.012907122126630238, 0.032671313402393175, 0.013490032682555818, 0.022468594646441842, 0.04280517426049037, 0.04668127655261948, 0.014170574441161609, 0.11062055285419188, 0.01882582549907027, 0.010323044355778445, 0.05649613073816704, 0.04961901306805592, 0.016854775115667332, 0.09155251716654147, 0.05892936771194782, 0.06229903609041245, 0.021269188239990224, 0.0060232892170578485, 0.017612985740866394, 0.03243412875059632, 0.08957026466246575, 0.06335048793604778, 0.04071974120433292, 0.003622084534013524, 0.049891449255688544, 0.056009163118658535, 0.07451741069915795, 0.03655411896385974, 0.018289529478117343, 0.05040429532527924, 0.032878770012288325, 0.03665002934154003, 0.1088094597141589, 0.027306999132457762, 0.015165248637898796, 0.03755495538033786, 0.01992982523065181, 0.01694217234128906, 0.17533699471142986, 0.011934106193122365, 0.008533490735346512, 0.041370778044144955, 0.04009785784047939, 0.010125008712132132, 0.04479245230134937, 0.03516023347695028, 0.03648674153091927, 0.04065605631518749, 0.048882013502260374, 0.03233859375599892, 0.026781234905243884, 0.015617918501037265, 0.0341572749969219, 0.017051994875674287, 0.04036635250574158, 0.015825217105298033, 0.09958748480365162, 0.002486351046583525, 0.04330650219813951, 0.02050284942191455, 0.039102648339805104, 0.04583558826256664, 0.013547135918821781, 0.05189669205837193, 0.032457115218764356, 0.04566417225906926, 0.02757341386900554, 0.017914525608742432, 0.05740834610356439, 0.03519423245902985, 0.057696866307167284, 0.040976032088961334, 0.07292356477269242, 0.031523851587647395, 0.017679173822304415, 0.08028508749820533, 0.05388239961898616, 0.04170087766983817, 0.05896094202574703, 0.024158086650253787, 0.026272029668513327, 0.028905884002245245, 0.031969184243691065, 0.07109631483833637, 0.012276863506544503, 0.06274995544264395, 0.05335894706208379, 0.02636829627707841, 0.061121585763870716, 0.04603385181737043, 0.034553763802133264, 0.014731740548966393, 0.0341922277584672, 0.12766517413359496, 0.18302015179107267, 0.10632719694366378, 0.10426823605572987, 1.1442267173720946, 4.559092444758262, 9.364374414567026, 21.371634006500248, 48.19723352309197, 44.7292620904984, 63.906271150035245, 75.66237941864999, 105.75791774257537, 120.2107535639117, 126.34794496720838, 138.46427979007845, 143.10700108928066, 154.00664021891933, 156.7639252447313, 154.6236761154667, 150.571679453696, 146.57073636208813, 167.49494952540246, 158.63638631759153, 159.16072876222674, 156.86320827853297, 154.91485718757878, 152.03133460014098, 140.07902545313684, 133.39568322704685, 118.57186179007255, 116.38422258438604, 93.79985055615826, 73.05699994487148, 27.264191104519753, 5.688835074824672, 2.2326589447836724, 0.30089031724679854, 0.13703391616863592, 0.4676364326188642, 0.3281828124196299, 0.007636879144551894, 0.041435397560558015, 0.06610080104080901, 0.045052382103618116, 0.01352700312817169, 0.039665918316571944, 0.09355545404457277, 0.008705589514706404, 0.03048443115286289, 0.03746032053905149, 0.036311311226698666, 0.00171874794403031, 0.07016082189135975, 0.03457754317130293, 0.031152896492952303, 0.028786586875456478, 0.02288318227886433, 0.059733625967055566, 0.043095812697203896, 0.028857540023783525, 0.02852659195571417, 0.04348959338160292, 0.02064509854291476, 0.033613314266286554, 0.033933450918524496, 0.020895333502501733, 0.0292659510723165, 0.015601820120918415, 0.026928316125826492, 0.010150253224456984, 0.02140544655342256, 0.08339119864807976, 0.04480332691943453, 0.025795578520985383, 0.029287424516834082, 0.06132623466152338, 0.02059848209272229, 0.10397415022335707, 0.047257332536842556, 0.04474197093757891, 0.022088590138141188, 0.04983256773782834, 0.04878588095908204, 0.02180130142087658, 0.0052687251703783635, 0.0047548271663066365, 0.04812835535455135, 0.05149485595944909, 0.028928200143479535, 0.039824965830531814, 0.1022567343147051, 0.028254695860068166, 0.025583345352882342, 0.013362717488029552, 0.037481261552461696, 0.05567637452435109, 0.06359247595912988, 0.022619247751971407, 0.06984674116416324, 0.02033283152887898, 0.00828066639857547, 0.05311084182692632, 0.041043800226743185, 0.024660460297919573, 0.013760453101337678, 0.013439344475045802, 0.04106258853308616, 0.04174097088135539, 0.08489848429998083, 0.05047322408626637, 0.09662727509895641, 0.20949000642905313, 0.14649007649671647, 0.18944246604317622, 0.18199250612768436, 0.2386150452037973, 0.1522896378751724, 0.12398952257729347, 0.10612783788312828, 0.13234771037053678, 0.23915064791517876, 0.1744256565167058, 0.179253910337725, 0.11811101583824044, 0.12571940273647347, 0.1578162421262072, 0.1600243833156363, 0.10359082280868485, 0.13507458501525466, 0.1533417983521377, 0.14801618492891713, 0.14143558158989877, 0.09519482857637829, 0.1378041409677075, 0.16842752514827639, 0.0899510563261086, 0.0866666918380126, 0.2717999056462319, 0.1633077442285515, 0.11528054312352212, 0.1105659537678284, 0.12997604005279081, 0.14500699156234342, 0.13783196528111735, 0.13274489631575923, 0.14071892165849287, 0.09436050520068216, 0.10596963306588512, 0.1246408811740337, 0.2129473765530894, 0.15097032721725204, 0.23335102524968887, 0.1759234043739496, 0.19646306432062582, 0.23043763883892568, 0.1536735757103851, 0.17576436452086897, 0.29132414669279133, 0.20436038894038047, 0.10359996989850076, 0.22065475733289797, 0.21218878096870838, 0.26108840300190833, 0.12053012232025787, 0.20608063937435228, 0.1577432186252648, 0.09060056099007208, 0.14648661377929872, 0.21783247409809023, 0.1197284036466191, 0.15538651766555925, 0.24452990281485745, 0.22066395038798933, 0.12822947449861996, 0.1379033646756603, 0.3552715282046026, 0.4384970220346605, 0.2615077288881425, 0.11991155994755608, 1.1670833489587231, 5.0710156848353725, 10.300598086849337, 22.393250619211507, 54.64446083191903, 52.931373503900346, 72.89504528045654, 85.67117767949259, 119.01438359291323, 136.9849971032912, 137.91130404318534, 155.0312888237738, 161.05455890778575, 168.28679761578962, 168.91955437198763, 173.2595314518098, 166.10545773659985, 164.24082571460357, 182.84837722778323, 180.4835488719325, 177.14887526727495, 174.789208750571, 175.49079525855282, 173.12209160097186, 158.7136099415441, 149.19417442813997, 133.87808768979966, 127.15018733855217, 105.01933543912827, 78.53433101407944, 28.98604100750339, 6.503382411695297, 2.226282886920437, 0.466992489753231, 0.4841061891807664, 0.7022867123446157, 0.549903734316749, 0.09343598263278123, 0.1664940877667358, 0.1228139836401228, 0.09835212206047389, 0.24368398852886694, 0.1777381900577776, 0.2200168818836251, 0.16974030873708187, 0.1027763794146238, 0.21621176912899942, 0.10362184936961821, 0.135991485008309, 0.265875717084254, 0.15552914791530179, 0.08355952348680266, 0.1812459994107485, 0.0731244023829218, 0.21437231541400958, 0.20578413270413878, 0.10855527940176188, 0.17938852730777957, 0.09366811493471747, 0.13094946201289856, 0.14182316079255075, 0.12269398362766351, 0.14899193579631467, 0.10049988019971118, 0.09194619442907073, 0.25998462352060503, 0.17854074376725382, 0.1220985034841203, 0.22321794963171407, 0.20248643062528104, 0.16131611480828256, 0.22720306240502866, 0.15058064893368753, 0.11307270070838352, 0.21494047686217294, 0.1219674947881891, 0.11287081355769789, 0.20137031712839681, 0.2258580724798864, 0.21499696818570938, 0.14784265069230912, 0.11759723131094249, 0.09813648363154742, 0.18554502437191625, 0.10210629762901414, 0.08598999871361641, 0.19612525018953508, 0.1276790326641452, 0.10237439775899534, 0.11292626300165731, 0.06684481797199096, 0.11682785686946685, 0.2593709564497394, 0.2215781537515502, 0.1290091911270734, 0.12879424217727878, 0.11224154127581466, 0.11303610468824064, 0.13811299697526042, 0.15031582766002224, 0.1290296303528932, 0.18029785835214202, 0.09513517330971458, 0.13667396209653349, 0.07789050349064412, 0.20579246774075494, 0.09025174583638869], [0.0035733321349271725, 0.07507749758059941, 0.0906788475150543, 0.04520652665486259, 0.018532810274571664, 0.021889481971400882, 0.0051971174956810095, 0.045318333356971705, 0.034712627454991304, 0.031705904721973405, 0.05562605020860511, 0.05011660249663457, 0.044846921152765715, 0.03828145571113114, 0.03521895411634638, 0.01587209785582438, 0.02158954131206678, 0.05331532984611489, 0.03581090259455866, 0.016222863660884962, 0.030759263280478698, 0.02701243257991249, 0.041597126382252866, 0.06717246611632648, 0.024408325440280383, 0.028092403963748968, 0.036443135806269226, 0.015870659525746542, 0.005650355700298303, 0.031219494431429816, 0.0047346589440900476, 0.01241422115614818, 0.020080344270794623, 0.044751447445202264, 0.10669106572505929, 0.036753213724061366, 0.01709199041098116, 0.01951968282340996, 0.035479845358960094, 0.11379085451124177, 0.05746165050133582, 0.023196684609678005, 0.01117003499530256, 0.026964381630081805, 0.1064671382247921, 0.06608341084492785, 0.037067520447195544, 0.09688681036594415, 0.028143695465499358, 0.034553576110591816, 0.01618917877485435, 0.013440291551242193, 0.06665209323287972, 0.03216597882490004, 0.033339686811931675, 0.04614819427050891, 0.027906708081343004, 0.04637612458018046, 0.03060042835591782, 0.005275090403419229, 0.07423365173200447, 0.07494139439997173, 0.13430460536431882, 0.22693949751555922, 0.040788945756972804, 1.2165570619606203, 10.23246749754875, 22.59012810645565, 47.378693703682195, 72.78355583067864, 80.34658370479461, 98.16899438058176, 106.60431031257876, 116.84317911824873, 118.8161313149237, 113.9656420676939, 110.84821285740023, 95.01012925178775, 102.40241635230281, 91.54034568417458, 93.33796793414702, 90.25028597924018, 87.56893803996425, 94.3882296162267, 101.80554928318148, 102.69786496316235, 98.74092302014752, 92.88662864315896, 106.21717237657117, 95.50847422692084, 103.88116559674664, 107.96674559193274, 104.29539142116424, 109.46662072212466, 116.12027845075055, 124.2905519854638, 114.63475135064895, 127.5816402127666, 136.43150360353533, 122.19446089959915, 99.08475798945274, 86.83893003771382, 63.27155713112124, 38.923361916695875, 21.343216434601818, 5.3025845750685665, 0.06382429033457752, 0.278573471211618, 0.31640224939873146, 0.12744695398836367, 0.010904742577563851, 0.1102018321774179, 0.039223916227779085, 0.09971622587932695, 0.022061602775788596, 0.03861013041328519, 0.07100810747473471, 0.005617771586853891, 0.006103623590822662, 0.014161020367135926, 0.012379785503951773, 0.059278133069916125, 0.055525194733373584, 0.04400697086126574, 0.04364633497091071, 0.019504565993444096, 0.04377548973406515, 0.042369400466521906, 0.056225847257601644, 0.015180521558279233, 0.01883217062230312, 0.03016967052263358, 0.03482861699716699, 0.037612768205543684, 0.016039491897719284, 0.029710967717091405, 0.020684101994359688, 0.032750500080686425, 0.07094669020584515, 0.03555632774688063, 0.04706200309878877, 0.023990108466316617, 0.10071432353147577, 0.03865028491183635, 0.06723771382483744, 0.05075980608742084, 0.035145275610228704, 0.04527322609999007, 0.024528892357803644, 0.08501849197331937, 0.04545596871344794, 0.03804221028281796, 0.01447179829776888, 0.029467426450742833, 0.039041001244538256, 0.026849070075719107, 0.04518533283243737, 0.03350147309022085, 0.09145307895396987, 0.04432851711528436, 0.09659601871164576, 0.1118535713683213, 0.009071507581299352, 0.019027260657880577, 0.10965025653281521, 0.01995821261868602, 0.01297880114326554, 0.03758712341227839, 0.043644419751100005, 0.042024599613561746, 0.04712451204297043, 0.06025147459079182, 0.018344808467513612, 0.00952636271024183, 0.03678327501421014, 0.09738707344137854, 0.045118342273898666, 0.019794363648660725, 0.01834493487202112, 0.018526336831611492, 0.04661838839491529, 0.03353593172505498, 0.030682068430788578, 0.010151094005953883, 0.02523086063804165, 0.02698075101380387, 0.036431502761139024, 0.09404793366669648, 0.015552540557579169, 0.03981127583932492, 0.03305735659875697, 0.04878522595390678, 0.0751640118898884, 0.02126035141578365, 0.05657514504667732, 0.016747517060608636, 0.06966320948014337, 0.03909563863529794, 0.038373723340731476, 0.0639761979090831, 0.03382742434980408, 0.01749467495228014, 0.07211003302326126, 0.036873903215652516, 0.03268957693850802, 0.020586963960780733, 0.027580613180273966, 0.0036367577511907346, 0.04860973819309185, 0.023695813874984463, 0.04188745838379668, 0.004165068741947894, 0.027609841349805077, 0.031210132836995107, 0.01714926122898056, 0.08292021545311136, 0.10907350723902065, 0.039653331491976015, 0.02961647268685122, 0.0475509625469004, 0.06686982308183947, 0.045845421001074776, 0.008193129361907562, 0.05076327646571783, 0.009768050043813644, 0.019891553393174565, 0.0140797441840292, 0.045726156433022795, 0.03748086318674107, 0.03379709875932144, 0.015353253317786562, 0.11315249642657657, 0.018003479908070257, 0.0594491736903306, 0.09466057417974358, 0.08277853515239493, 0.14191408010740436, 0.027457885894804235, 0.1655951601963851, 0.14545331438702924, 0.2047342092039124, 3.1251025920914066, 15.427074124736173, 35.66361342706988, 64.59192499037712, 92.93070823915544, 104.85558432917442, 126.43607278023998, 129.17063159327355, 136.7391272514097, 142.3405542681294, 137.7296826147264, 126.64918299644225, 122.11806097338278, 120.11468687365134, 117.52054891278668, 115.91652700977941, 117.51284537776824, 109.77825303231518, 114.88233920066588, 124.03344846540882, 129.40425580547702, 127.1661513851535, 116.24236614473405, 123.69154330222838, 112.377607745509, 120.52062080752466, 123.33609811721311, 124.37577724456789, 122.89785954260059, 132.4104622871645, 138.0392360687256, 133.8426608424033, 147.18772519019345, 156.52180517873458, 147.65889598477273, 130.6377000193442, 114.48588171312886, 89.07737962661251, 59.99824116306921, 37.46633083589616, 12.697305506275548, 1.1676109077468997, 0.03881967844321363, 0.19035041812927495, 0.1862077670352113, 0.05174538586288691, 0.11421367375841064, 0.07263043655022498, 0.019052325139543223, 0.03018815622424647, 0.014560637683908065, 0.021126577142445792, 0.01269067834777337, 0.0365871335229566, 0.04449077070720735, 0.03654669940231308, 0.012293057647653887, 0.09137190427751311, 0.031012863281273076, 0.04234693493814238, 0.04986043035563442, 0.020472077585216013, 0.07769027875075418, 0.023703350264939572, 0.019166121755035657, 0.07190293647469052, 0.023732455860402797, 0.07746710201665279, 0.025297268969757904, 0.07081136843490024, 0.031007866472786957, 0.041489969833844134, 0.01350726104236298, 0.027990100582340555, 0.06239135734616749, 0.06376921627370101, 0.03225711264437245, 0.05746549243227609, 0.01516442796620991, 0.033413633448822845, 0.036619259420061306, 0.007607912402524944, 0.06493483054181261, 0.05568521900943691, 0.029800730239179347, 0.0569917704729784, 0.03438988993425043, 0.05260233564542667, 0.019215176280047146, 0.00909086662314592, 0.05716929219723229, 0.009466357915962656, 0.0093285032668181, 0.06881692747194922, 0.008252436058565734, 0.02362243988881669, 0.07565259212447752, 0.07299136355399125, 0.014052410166890872, 0.08295077470041091, 0.02575943257749802, 0.00028641821993533674, 0.05630985262893862, 0.03061105782586721, 0.010680502896467525, 0.07747958924981856, 0.05456792956758892, 0.06388705591821382, 0.02892641707383577, 0.002189892975072707, 0.09270567867544391, 0.1945132786227811, 0.16694600303326884, 0.11681866381437549, 0.1519274161828141, 0.14442413654779235, 0.11580397269778675, 0.08756639315716683, 0.0980314759597663, 0.09623992572268171, 0.12976069273727556, 0.0758462208473394, 0.167166237989741, 0.14393423864197347, 0.14699882016547267, 0.1295944516577067, 0.18533297123447542, 0.14350553583954612, 0.12915618807798432, 0.06950374827870438, 0.12096976485824394, 0.1485237641440284, 0.2032493622673135, 0.1301836805237878, 0.1161813629310458, 0.08744464646424017, 0.08832672776113595, 0.23428290992254214, 0.1178408166273467, 0.17591543705953708, 0.08434369874697539, 0.13839860987519065, 0.11936888624463352, 0.12899279684549378, 0.11703868426622883, 0.24148065837160235, 0.07140367697443693, 0.14211572977083345, 0.0983725612862937, 0.1535644541464506, 0.204457268419285, 0.22966269493824054, 0.1436429260478866, 0.09419818649128561, 0.09308116134977149, 0.17115844473723443, 0.10018472694942068, 0.14051036188198676, 0.17861557523569754, 0.1423955050807807, 0.17625251574622047, 0.14259314044348656, 0.1280387492489911, 0.13584241962000249, 0.13926743019011714, 0.14943375402400572, 0.20032644572277225, 0.2226227606015821, 0.19716254856076934, 0.16959194814966572, 0.11257783089193607, 0.2706603651806232, 0.14326665430299698, 0.23375438586358102, 0.3639411307390659, 0.21288389850768352, 3.0425146366319353, 16.927553299934633, 40.43790278896209, 73.21793479304161, 103.59758607802853, 118.99980806535291, 138.07252914674822, 142.8402328491211, 150.6567164390318, 154.8446310720136, 148.65244803890107, 143.07383352710355, 128.2851879058346, 132.20020755644768, 120.54948945199291, 120.8443340178459, 119.28170096489691, 118.51384993522399, 121.832167256263, 129.15525590219806, 133.16906436797112, 128.3006420443135, 120.9005964955976, 133.53787699053365, 122.676206404163, 132.12762801877915, 131.47206660239928, 134.64911583931217, 137.40798550267374, 145.3209750883041, 154.26132755894815, 148.0572832784345, 163.50062739464545, 174.54930090135144, 164.19347486188337, 145.37526069148896, 126.67712596154983, 97.44254789044781, 63.736012827965524, 37.98922984830795, 11.762588024139406, 0.9686595285611769, 0.4567688931861232, 0.41244751984073275, 0.3629400376831332, 0.1880460103312808, 0.17601790898028882, 0.198037558866124, 0.17341884844485791, 0.15046371327292535, 0.10373359095425376, 0.17450856255187144, 0.14258270632595788, 0.14347346739903574, 0.11008261357464137, 0.20021939259623328, 0.16162446519780546, 0.1867157446160432, 0.12676276852406804, 0.08140672448902361, 0.20637153828096008, 0.1569958079245783, 0.251620827963756, 0.16699134011662778, 0.20409320811590842, 0.1429171956354572, 0.1573401184812669, 0.14390230809728946, 0.09053301501778827, 0.13330179627143568, 0.07031438421578178, 0.134917153946815, 0.10598772806265663, 0.16119518016855564, 0.17819562115736548, 0.13169336403089185, 0.08716962856030272, 0.12071782918346506, 0.19619899381312633, 0.19070016791022595, 0.14346839589697702, 0.08387723547076026, 0.1378233238093315, 0.14939324329456977, 0.1608004150611739, 0.22885652529376171, 0.16891797463740074, 0.10289882324756154, 0.1416121801782039, 0.07319396316644645, 0.18146744478614102, 0.1668143584843605, 0.12794828192601282, 0.2690548593959501, 0.12117892984421023, 0.09828235443320968, 0.219810405866273, 0.15481490882173662, 0.14102790024011366, 0.22653201534863443, 0.09283598257048477, 0.10946939083477182, 0.20886008297243427, 0.1442612049680564, 0.12939549862377106, 0.2387815467532604, 0.21292378104502158, 0.21364633985344442, 0.12735297032181295, 0.1445255665889671, 0.23976797688632245], [0.045353944954131885, 0.04044583412788568, 0.09669928736383877, 0.03627173129409071, 0.05170816165064612, 0.027138996050663056, 0.014650712386825153, 0.04406681764991053, 0.047657111689688704, 0.009106538866856887, 0.039366209398834937, 0.02221609398181881, 0.014989524347437246, 0.035722530522053285, 0.05684274721950774, 0.09751916998216222, 0.026370855010745507, 0.015693404974656242, 0.04237046915917628, 0.016489653780515638, 0.10511386688918838, 0.007201665552378062, 0.049621047031494885, 0.025232697333840114, 0.025204428689434163, 0.09709823531128707, 0.026707692379732768, 0.025246592253566753, 0.048953841906040914, 0.05761642707511783, 0.02154222772186322, 0.06550787197005364, 0.01889796033802052, 0.025749101881839098, 0.04109987786280052, 0.006767430637527498, 0.03499776154996888, 0.05438708685218327, 0.004189297230163169, 0.007399060554997696, 0.06076874864858486, 0.027634260402391517, 0.031228511286298596, 0.027730762582993316, 0.025000195394480423, 0.024398963845845674, 0.052994469240788496, 0.017480243771006505, 0.047289990865054636, 0.04136287201676638, 0.061739807227446195, 0.03911272622644901, 0.05965899368147216, 0.03796691533118006, 0.13158148455042995, 0.08833187587198713, 0.05255029146229068, 0.07009101595969931, 0.053444415661356146, 0.23337362484345514, 0.15029382561483692, 0.7030165796318363, 7.115475141233014, 24.658156594922467, 59.155943547525716, 80.050154501392, 97.26883396025627, 113.30539734132829, 107.51000911958756, 93.35301414612802, 98.35299276536512, 73.34439200739708, 75.75388047002977, 67.94410413311374, 69.9518399084768, 68.20773447713545, 72.07192805505568, 55.98836291220881, 56.859713523618645, 66.04325294494629, 67.56991786341514, 63.26926254457044, 60.76206784094534, 101.56135820573377, 56.42524042437154, 60.63577928850728, 67.2327587681432, 52.94934972640007, 83.87273173178397, 68.97714661013696, 73.87467292047316, 77.37979704333891, 74.5790207770563, 94.91089328642815, 80.16638217433807, 107.15676830660914, 90.20140540215277, 100.65152522056334, 93.19323247478854, 97.20628784548853, 109.38594541242047, 112.54204134787284, 114.91345144087269, 120.11085864036315, 120.55920124053956, 105.03077307055074, 75.93558034589215, 39.09334959522371, 14.574716610293235, 5.219551920890808, 0.09044015750048623, 0.16913119222848647, 0.16943500737749762, 0.024626047628360893, 0.050093455150002436, 0.015786430073691713, 0.013188097321788871, 0.0814753583061599, 0.0349224895809687, 0.09021234593444294, 0.022442765992074724, 0.022513506551002784, 0.15871003690746524, 0.03110785052300461, 0.08078109112478073, 0.04108145727866119, 0.06846215981509417, 0.08033247003632207, 0.0047007183762147065, 0.034635141491889954, 0.035135308806333816, 0.05544059947433491, 0.029587282821716323, 0.013655881142063488, 0.030075847734546954, 0.030199457936349417, 0.02303221319321423, 0.01352114925882028, 0.03931851276466924, 0.0346407875598919, 0.05962996661002117, 0.024157355036286098, 0.0373629431029962, 0.08809681711418015, 0.022738542963540363, 0.0942395092739213, 0.005548363542109127, 0.08755666384052846, 0.01927973067898664, 0.058614677944851507, 0.07331000250433722, 0.05399327169382765, 0.11865714459770149, 0.08080023566200849, 0.049629707655478875, 0.034376556173928326, 0.030721498976251295, 0.0869231780750617, 0.05426159781974651, 0.021297958671986576, 0.02158828875831058, 0.011260878658973643, 0.018437315499590292, 0.10040938223321592, 0.048144830075363, 0.05222586471767676, 0.042867694695990895, 0.04699703118193054, 0.04203818618289886, 0.05333964930727117, 0.040545927345632546, 0.057128076666906, 0.03250797962649696, 0.05971646176711206, 0.016712905208189643, 0.030574676310343128, 0.020258490356706807, 0.03880536792078807, 0.050711209299944104, 0.0757362412649297, 0.029460411000576232, 0.015669296187679135, 0.017289491708300287, 0.05260485607469755, 0.036197903400827805, 0.03498408688052047, 0.0324193432536577, 0.03827449963277867, 0.04457832689607336, 0.030868482520623557, 0.023446314359804796, 0.06233187061884712, 0.04582899607597821, 0.04545688801895707, 0.03448982610397282, 0.06116981482914379, 0.021161807610863642, 0.02847655109250017, 0.038652073727139545, 0.0527177965869346, 0.06264574067186444, 0.019005769976384698, 0.0448406545535451, 0.08491425805034176, 0.02268379832047128, 0.029631786784457586, 0.020467096098488378, 0.04727491425470479, 0.017780096330229315, 0.04022635759845857, 0.005714144011313517, 0.0322288976261212, 0.06652448596733232, 0.020468122656306913, 0.09479886837183468, 0.013813977749387344, 0.05311612783360386, 0.01747949875050014, 0.01343596506968982, 0.04071159002881858, 0.022056594475983612, 0.05049136887875296, 0.0951299332683125, 0.015715545873277854, 0.03034663300270275, 0.06048597793485369, 0.05609402267803108, 0.05169676609277245, 0.020620397953016144, 0.03138343533200603, 0.0649782294227231, 0.022934140532367656, 0.023370458248762355, 0.0874500014188309, 0.04282707671424554, 0.1683566773370389, 0.040326171194113074, 2.1548793248591886, 12.580576750539965, 37.33666120036956, 78.06748267143004, 101.42809960149951, 116.79654998164024, 132.250884579074, 123.93532645317816, 115.60351402528825, 116.33484778865692, 103.0252024435228, 104.04666608379733, 102.21245596485754, 100.228223031567, 93.34188245957898, 104.92934057789465, 87.52256777978714, 89.36372833867227, 97.32242138155046, 95.12245808878254, 93.4012592992475, 93.76702031781598, 131.40155807618174, 96.68436158087947, 96.72233796888783, 111.81244911686068, 90.32645840798655, 121.74207825814526, 113.24849159486833, 107.42017115316084, 117.81763707437824, 107.61368520798223, 126.30353589211742, 114.62478853041127, 136.55585842747843, 117.37673913278888, 122.6757670987037, 117.23192522602697, 111.89872557117094, 129.78058368928973, 122.95969963073732, 132.03783712079448, 138.72309346352856, 144.02896204302388, 130.91536460384248, 105.04264216269218, 58.55198483313284, 27.60913218221357, 10.027102001251714, 0.09269371238206664, 0.05413609729599088, 0.25160075646013985, 0.046356259920303865, 0.023782140492732008, 0.018894892155883775, 0.02648189179449072, 0.05103159110031782, 0.033191490933419235, 0.03662462969641051, 0.07518792915488444, 0.04764641710226575, 0.06326862378045917, 0.05073396211129524, 0.10140527355214281, 0.040780580076839656, 0.08192508256122952, 0.11172295337723148, 0.08501958747905108, 0.09662472402616855, 0.013645882737041723, 0.03880521087276359, 0.017231849337657614, 0.02086290500066694, 0.043029963609672366, 0.024630335805517052, 0.03342448508427028, 0.025886409735727697, 0.04719180903667885, 0.036596820704759135, 0.06384002195010263, 0.0752716472432498, 0.048776990508720766, 0.1266352072237961, 0.029382220236584548, 0.06708418980481164, 0.059223070500358466, 0.010454848825540996, 0.06896236926437387, 0.03165427805675614, 0.006888019580078582, 0.06868453981775431, 0.04385332043673243, 0.06879834983978542, 0.019985707514288447, 0.020455610525283604, 0.03691991828682442, 0.04027075622411024, 0.17653000811415334, 0.05074266487011506, 0.030918954308294964, 0.05022711834059127, 0.03992622350192359, 0.036564273459296075, 0.03151320105028008, 0.026080093999964096, 0.05058563599783567, 0.027661169240731868, 0.03894340930386417, 0.06379778752283705, 0.06778362041880047, 0.03097417201065729, 0.030473219456091046, 0.020828938577324155, 0.034964712516915415, 0.029371479683886134, 0.17328306702115845, 0.1986270022368239, 0.24197567374475543, 0.22874893590567574, 0.14030281334154068, 0.11446475907559357, 0.10828553984362273, 0.1426881966331313, 0.09451517069171514, 0.13104361421879263, 0.10571741393857426, 0.16520296914442895, 0.16258820380655029, 0.09893366706467445, 0.11469782600479742, 0.20594151780730297, 0.19148862560189542, 0.1309572607879677, 0.12454299045906914, 0.15028293184455366, 0.1320261526251993, 0.08903302252292634, 0.07582738274528135, 0.0846626288107326, 0.11348346173162423, 0.18759352815968378, 0.09811217566171, 0.11652028788962673, 0.2272346405492675, 0.1793960656129545, 0.0715249410319713, 0.09977784999195607, 0.051252902410323584, 0.12950710231258025, 0.14788334528284688, 0.17261346021006185, 0.1313489768654108, 0.21690857206140796, 0.1681783473900249, 0.07126718308896789, 0.10893601743925004, 0.10742862453503955, 0.11583448597981084, 0.12279874615130887, 0.13180581041641776, 0.16731717263258275, 0.17786877740535045, 0.11172785633994688, 0.16558379145158877, 0.10653878276747082, 0.15763193669338382, 0.1687784240611138, 0.25596587948741456, 0.12093162900137326, 0.2736145534342335, 0.22191679525759914, 0.216194654724771, 0.17401132552373796, 0.2552799243600138, 0.37274427772048985, 0.31899429256877593, 1.9780469878065972, 13.735045021580113, 39.906311804248446, 89.10863307214554, 112.78533812492125, 132.0727462153281, 148.52912872068345, 135.86646264599216, 121.16335607344105, 123.8445314284294, 98.25344301039173, 100.0088684020504, 92.54447244828748, 96.34069919586183, 95.83818866360573, 100.60381350978729, 82.19450642985683, 86.92470442864203, 102.36069017840971, 98.95801836444487, 83.86051747106737, 90.7434142020441, 132.4036059841033, 82.11006564478721, 88.2747999314339, 95.77409713499009, 80.9695816040039, 117.17580395360147, 102.2264039131903, 106.5607641589257, 114.68825247979935, 110.48432673177412, 136.87047958374023, 112.98700286496071, 138.86878598120907, 120.8692410684401, 129.99029713292276, 120.9328305336737, 124.02871808698102, 134.8021981023973, 142.35097208330708, 147.4292019874819, 153.42543909626625, 157.63966498836396, 146.7158954374252, 112.1721383064024, 63.333432520589525, 30.97407275630582, 9.773299155696746, 0.12449740056669521, 0.2036785247224954, 0.4764254529389643, 0.12978114728485385, 0.1577898427363365, 0.1442315726871452, 0.17721504393604495, 0.18882852318065782, 0.19872982655802082, 0.19984244669397033, 0.1431730690021669, 0.10537814424042741, 0.25786286640551787, 0.13193318019470862, 0.1779792472840317, 0.1426233549512202, 0.23017723023170428, 0.17819536068747122, 0.1525578605792215, 0.18034400748870066, 0.1126864391769613, 0.15939772339357486, 0.0705383193769282, 0.11063227399943337, 0.09541167742422513, 0.12638792936359683, 0.23406771582461175, 0.07308773741486572, 0.18203444178065947, 0.17019443033683687, 0.1774376231215654, 0.20383943383011127, 0.12612667805965871, 0.24752116972400298, 0.05957415327429772, 0.1464070325657245, 0.26868860808111006, 0.19601337070907318, 0.24241899350477805, 0.1391690032136056, 0.18699550460423195, 0.2043026412326482, 0.2342013828456402, 0.16190604847525397, 0.0884394729209523, 0.12403577130528227, 0.13484316517508801, 0.16620636046413453, 0.15993507278542365, 0.10964713855496339, 0.1335192120243465, 0.16430767283083933, 0.1355610814906897, 0.26214269320330313, 0.10640096354989276, 0.17296921612033922, 0.17606560561445453, 0.07159317648338695, 0.1758100999699485, 0.11092441396847849, 0.17618140746508876, 0.10129393799410713, 0.07870842492388141, 0.20953600234802694, 0.0984165883593021, 0.15444346343077], [0.025705205043777827, 0.021297181092743433, 0.018519411396775997, 0.032067668676796945, 0.10726314954339497, 0.0502869536379172, 0.08585254721824201, 0.03059174283407629, 0.13034789913123654, 0.027741401629041762, 0.04025985479294773, 0.031492026380052975, 0.05367096701276399, 0.01843539836455978, 0.07369896832613215, 0.0905959491407679, 0.016922704131913283, 0.0531290402455676, 0.028145873070424123, 0.060932683803501635, 0.03511949675157666, 0.021733119595615615, 0.017229520430367802, 0.042763131355205854, 0.0400714622810483, 0.0524944742961276, 0.07735958157648003, 0.03284986551490522, 0.040346936007300695, 0.027177107009676196, 0.0384437246248126, 0.01987020443794468, 0.03586243349878538, 0.015184093443226191, 0.05791039033342273, 0.04163506305626324, 0.02761368136552553, 0.025812085800533815, 0.008875611238181591, 0.004056240685449373, 0.020793539569562963, 0.04174534141296341, 0.027295867874917966, 0.010910167437677663, 0.06170799159595083, 0.03179515971081152, 0.056750291898365945, 0.049176490039474545, 0.02119769499967656, 0.06502814771186921, 0.048893221368592595, 0.03687718207196843, 0.03879059391516832, 0.022665557766994162, 0.038693653149229866, 0.059482142284152016, 0.1162769323995998, 0.6023843730649641, 0.09091624284103032, 4.845615702290689, 34.5240629103876, 68.36293482011365, 89.80789753698534, 96.59977959048365, 98.49333517013058, 80.36283016204834, 97.38737583160402, 77.07362467242827, 69.76115780491983, 72.5704691486974, 69.4993317511774, 75.93456052964734, 64.67657366106587, 57.80105098601311, 59.81521552608859, 61.80157438401253, 40.47550262943391, 56.787208510983376, 33.47815898156936, 45.13245036525112, 42.38952121426983, 41.630542585926676, 42.72106739782518, 48.9274533333317, 44.64536651488274, 50.08028499541744, 50.78787272976291, 45.19932285431893, 62.05228051831646, 49.625184151434134, 29.681320344248128, 34.37493047406597, 61.8446655427256, 54.61901249424104, 51.59814027047927, 49.91960902367869, 61.830784274685776, 67.2007522275371, 76.85729811268469, 66.84665633786109, 57.8313865969258, 97.3306897378737, 57.31803071114325, 89.07526939145981, 94.11141226368566, 96.50889042885073, 112.57130222935831, 111.49998526419364, 112.9604405741538, 94.203062365132, 51.27020658985261, 25.568954483155284, 9.042187006242814, 0.5932305416753215, 0.3132652112793538, 0.048724463690192475, 0.02461959716803845, 0.08244668884623436, 0.046945435160230246, 0.023546915110801498, 0.08539841795760779, 0.05231094644254735, 0.10847145406108712, 0.01144008003100152, 0.07448541886743999, 0.07726929045372433, 0.00805860623762372, 0.0067737135161165035, 0.022948587035399773, 0.05748504299610373, 0.044367606751620776, 0.020512716634379282, 0.04994337852563589, 0.03822357393801212, 0.05749062394663211, 0.022055336176567984, 0.05431319001100717, 0.011398443152316877, 0.030034473240976373, 0.030783674672185898, 0.021200692318680308, 0.042070986237376935, 0.05981728659882661, 0.060930347235332576, 0.04512574268324722, 0.1914727829036213, 0.05091214650160363, 0.11029575455693469, 0.01101892319462833, 0.060324586191845525, 0.06567932244750761, 0.046930982911538695, 0.020717779219511057, 0.008491184487338028, 0.012008309469468171, 0.0285543913712665, 0.055943608974977854, 0.011099043542579299, 0.053733441482989065, 0.0651658290336209, 0.017976109501755527, 0.09306660567921016, 0.048406996854370644, 0.036113587763881495, 0.05509085735426315, 0.037673350438595786, 0.05093216437906508, 0.023536519297669013, 0.09079852577058539, 0.027834985014652053, 0.012719071481467016, 0.007966706809031988, 0.04977156415641789, 0.025309509139568098, 0.09838479571044446, 0.03000173064309263, 0.01792730970097886, 0.015143822116266577, 0.00037888877305968275, 0.02085105362047832, 0.022923325286096623, 0.03146027969647079, 0.06104449433605037, 0.04708260703351229, 0.11374219260629147, 0.03665767106858473, 0.027712014496266365, 0.04356783777174931, 0.01249809820775784, 0.06555369168880486, 0.10217160662455906, 0.040086791700413155, 0.03239816092255135, 0.08845254238094054, 0.03219957561081937, 0.044677661686775186, 0.04509877638831254, 0.06356988019580323, 0.017756054575945583, 0.02343455299494728, 0.03684980975043389, 0.05421943617083373, 0.023322514551241073, 0.02244167623200244, 0.13306386468391265, 0.018404839117260232, 0.11915238979723185, 0.07690656314333601, 0.0174861311567046, 0.05167455720384756, 0.040303092795394124, 0.0950806278495058, 0.004081184508263945, 0.0431275632112257, 0.07306400401097152, 0.00778210212311317, 0.035965441681084134, 0.01773523422138345, 0.05475826028193678, 0.11658543600670754, 0.08620212845984968, 0.02875087185642652, 0.03383133139821791, 0.023399921990330183, 0.0774408481834877, 0.049442686440963904, 0.050062700550282196, 0.020272429326489087, 0.025029980892976447, 0.12096300796275178, 0.08288378031143258, 0.10412380549936526, 0.07064734901031179, 0.4445655722050898, 0.16764717266684578, 9.178442301288728, 47.749749921983295, 88.38016263900265, 109.42808735755183, 115.6946385291315, 109.79518982671924, 95.5708634468817, 113.99800946635585, 94.73353939671671, 102.1294350777903, 103.03904056549074, 109.03628964577953, 101.47880800308721, 78.54318772592853, 75.29118199502268, 75.70198751265004, 96.27084178309288, 63.983341801551084, 72.37453891384986, 49.69169186007593, 64.50419333673292, 66.31235891772856, 58.8403731776822, 63.160142206376605, 65.57785195689048, 55.81640620385447, 55.93487747253911, 65.6198173953641, 51.307300444572206, 87.33515693295388, 66.51618096136278, 53.47218598088911, 57.63000818990893, 86.63355473549136, 93.10675990196967, 88.91566030440792, 95.3338973752914, 100.98798613394462, 103.39803941788213, 120.29466875137823, 111.45115960028865, 98.84477169282975, 131.99972737220028, 81.4415760963194, 110.22623477443572, 114.2903672495196, 114.15266067750993, 128.12896774661158, 133.80258990872292, 134.36821137705158, 118.96441259691794, 74.53674547133907, 45.07446988936394, 19.47311466740024, 2.7538259856162535, 0.11966938423293254, 0.04965373983366355, 0.07240801824316864, 0.028479764831342527, 0.014978270515829567, 0.025054895987493858, 0.05340747873208696, 0.009978019422100437, 0.04930062309628533, 0.04571139008828229, 0.04063328818207787, 0.02937439464843802, 0.09059209571850878, 0.0379576878021321, 0.058179536173420573, 0.04316758747482973, 0.017275966425997116, 0.013901633529683516, 0.07575946905079388, 0.037608623669873324, 0.09463995109282194, 0.04712771429049392, 0.022882188279782573, 0.038417972579237916, 0.050108968430469115, 0.024855950614437464, 0.0454711027803921, 0.012647301491890705, 0.04449471989045701, 0.05272632697597147, 0.03731482895091176, 0.08479776672057568, 0.06040278078627683, 0.046423154717852036, 0.02642620103283515, 0.05406864325425798, 0.06473367117465505, 0.05400043078548005, 0.04480267957513852, 0.03375311382114887, 0.006225583351953256, 0.04111139216430245, 0.025409154195879257, 0.06634364325192667, 0.09565294915509802, 0.054363943335990754, 0.07755763062666501, 0.05761913902636978, 0.06468726156820213, 0.08065549867047418, 0.03799953535499592, 0.0928403722542909, 0.09105842109889754, 0.0024236472287861213, 0.025475503155781377, 0.03124277201300908, 0.04798563700469752, 0.04408978879632008, 0.06369396345689893, 0.027457399428972316, 0.05822790313452002, 0.020913602784276012, 0.15102801363795035, 0.16706292337227255, 0.20046000549149132, 0.11379190405169803, 0.13553063715657881, 0.12449445112818673, 0.1715553089255287, 0.09787915469778162, 0.22805337403570453, 0.14543538792960106, 0.14148913113580597, 0.22493098351743915, 0.1547083613132277, 0.25547670170424447, 0.24786348845208847, 0.23024892073965844, 0.1748903960950913, 0.21402673315136664, 0.10510727853303957, 0.1305066785144229, 0.13725447288203624, 0.1350519394562129, 0.10886824164058893, 0.13848749139616567, 0.1692332657835176, 0.19518313058201345, 0.326923118723977, 0.1696903598044188, 0.2451781357728666, 0.12358014817319571, 0.21540426649153235, 0.17770812876762884, 0.12161478024697113, 0.08329424256038281, 0.12511616978313655, 0.20271063391720096, 0.08824130895757869, 0.0972797368623076, 0.22504131550029402, 0.11658555858077542, 0.1915753007896485, 0.1612986939688844, 0.11055086949659933, 0.2275130522227095, 0.15353725802513862, 0.19248826309077202, 0.16700178955591496, 0.14451753798752062, 0.26492641157200264, 0.14820750772712693, 0.11573696298704994, 0.17218268897023895, 0.1023778068502584, 0.21848813810896492, 0.1428992078909951, 0.18692254239032347, 0.182547077176071, 0.7525426317607203, 0.2972831769335655, 8.704468973221319, 52.45841410852248, 97.45584472533196, 123.23686999659385, 127.38723185754593, 122.67233110243275, 104.7388389033656, 119.64991738719326, 99.56725658908968, 92.80482369084513, 100.26943145259735, 95.93031729421308, 101.18514014828591, 87.28946132044639, 81.08770770411338, 82.47048439518099, 84.84158069856706, 54.363183744492076, 80.22165621480634, 51.37165084961922, 71.45112668314289, 65.8813218147524, 62.290289940372595, 63.79515432542371, 69.71725079321092, 63.93080557546308, 70.14829574092742, 70.64926085933563, 62.929793173267, 84.81301799897226, 70.72059308328937, 47.41265358463411, 50.94769754717427, 86.4356162471156, 80.24781057911535, 75.78725199545585, 69.37070154374646, 85.5294938241282, 89.55628533517161, 107.1620164378997, 98.08838182880034, 89.81957051061815, 132.94585012620496, 84.52236252446329, 120.9357487770819, 119.35730072759814, 122.13691188443093, 139.45761219147715, 148.4179844394807, 150.80088707708543, 130.2966813118227, 78.81230938819148, 46.498356942207586, 17.770672652029223, 2.5778277650956185, 0.3428914860611962, 0.16686921037973898, 0.17082329659212023, 0.23634894180201718, 0.11951962170461494, 0.1976940910061521, 0.3089676418852422, 0.09887711445410406, 0.161448203688187, 0.15787722272497995, 0.24541456582805804, 0.16179263681894349, 0.1376705199119545, 0.11778985645862357, 0.1875633749389841, 0.1427542946992382, 0.1326096971188822, 0.1323296000520068, 0.17457798543956973, 0.10291910159491724, 0.16656965467958681, 0.13073924748647597, 0.16179447542996178, 0.09309069914442879, 0.16357440411323504, 0.10519449764321889, 0.16081529248866344, 0.1093584229989398, 0.1329486297383424, 0.20447052174037506, 0.14144117403174603, 0.21666319409926094, 0.2876888143439447, 0.14597146561549557, 0.17777208178754778, 0.11212402338823003, 0.24074806381137143, 0.17027782666827404, 0.13899750677087616, 0.18098888498160148, 0.12286969355397648, 0.10612022296916093, 0.23976957034920496, 0.17705079468507923, 0.15429850427373765, 0.15803405624483863, 0.158060823356913, 0.15824836168077686, 0.11354408226907255, 0.19503640942275527, 0.14757337078692453, 0.2489669002111881, 0.16444176886110537, 0.1599047969906561, 0.20061800346499492, 0.07497680298383198, 0.09911920589905593, 0.3159281329041527, 0.1862108620304254, 0.2626305686370019, 0.17260451230310625, 0.09580258910934772], [0.0291399545066299, 0.015009721297950996, 0.02129886265573723, 0.03181119776150632, 0.03482945203300446, 0.04396869710856869, 0.00982372931415035, 0.03527134686948792, 0.02466515258645579, 0.030538325438336022, 0.01740036378314178, 0.03471577990679972, 0.08321659954925699, 0.03681625126891079, 0.04637234010583451, 0.024278889139813763, 0.025769945219038956, 0.048056251159118074, 0.06581740213497993, 0.050011759533757166, 0.05613399714592004, 0.019645639169480533, 0.010505427865521803, 0.047774997299476984, 0.07453590406165009, 0.0619957227289917, 0.026988559364972096, 0.01949037804508642, 0.05493675876829413, 0.03128639880507704, 0.05147382684592759, 0.07382108274126246, 0.054331648899542714, 0.047601681397927385, 0.023162413666385318, 0.01708551313758137, 0.01772271634470071, 0.06586201143481078, 0.02112183697341431, 0.031186416670079195, 0.026872223168010675, 0.08946893421272117, 0.0331826426178938, 0.05267032211826694, 0.026292196933120012, 0.04870597032770034, 0.03869138935941362, 0.07416622833378854, 0.02573395057791664, 0.049253485706304355, 0.06599652881343519, 0.03252877891364117, 0.026428690818589062, 0.07890540145097241, 0.036881518129619865, 0.3012715532414375, 0.10342658121859837, 10.687231998289786, 51.06240334049348, 84.12384971495598, 82.79711584891044, 85.9109757023473, 85.62265011572069, 64.70044520593459, 83.65191798056327, 67.99323574189218, 74.21502482506537, 77.69020557403564, 54.91012296368999, 56.39713664208689, 29.36876431588204, 59.32626854988837, 56.07018747637349, 56.23000052667434, 50.54355221409952, 28.246150593603815, 42.84568502056984, 46.67471062752509, 51.125459363383634, 33.16727584408176, 34.06521228051955, 47.724434944891165, 60.238753057295284, 50.91790714571553, 76.79082962774461, 55.91928605110415, 66.4221852825534, 64.44223165512085, 52.502658444066206, 58.40898698376071, 39.85370889786751, 62.27191755848547, 31.27107854812376, 29.63471278067558, 43.44939662564186, 25.856026872511833, 29.577916860580448, 31.438222508276667, 38.308914784462225, 42.65271225283223, 34.973237053040535, 41.832454435286984, 53.19532548227618, 41.89376500345046, 57.92251110076905, 54.14497836943596, 64.12501781217514, 87.23017077292167, 84.03477268834268, 89.65092428268926, 107.6171604279549, 105.56811424993701, 109.74585425469184, 76.56421861340924, 21.1689337607353, 1.6186778391561203, 0.12056481078146927, 0.2972077632382993, 0.06579913859886509, 0.06386625663106961, 0.03120128452146967, 0.030644691000962933, 0.030553511216215072, 0.07103534190044289, 0.05124968484104161, 0.022874161593555924, 0.04862224840889535, 0.06699046660815516, 0.04103676370915867, 0.04927190629044368, 0.0341126197318156, 0.03915127577079881, 0.06307852672292821, 0.06472181213358719, 0.024846050843235948, 0.026905226235788678, 0.008720946704758512, 0.0542486394425073, 0.07338517871234687, 0.04290736272871014, 0.11428834434839026, 0.02783564768070656, 0.02251658622445839, 0.009152953261359325, 0.05997105576698819, 0.01742918401085321, 0.0485798760858034, 0.03645196880003618, 0.017389663450059392, 0.02550224728521801, 0.03591923125749154, 0.037324956633270755, 0.04904253190503486, 0.012240125760135633, 0.06707308152990957, 0.047320033003005295, 0.061329670565863775, 0.05987589998591331, 0.013425681296916259, 0.0647992559618527, 0.00647537972620358, 0.06989599295681523, 0.03720829676416132, 0.09636082971889166, 0.0018922024596137027, 0.02677709611523296, 0.08426273091425819, 0.015192966656609169, 0.04462000207915422, 0.05251150443068436, 0.05861306149933127, 0.07577850633571226, 0.06332467843387878, 0.052683632895951314, 0.013459531849460497, 0.046036625055656324, 0.03236956669077758, 0.022815335617070238, 0.019952348215625654, 0.06930952200726156, 0.05249949217203164, 0.08114455387957635, 0.1018487312079918, 0.06527726418308674, 0.020531164031595956, 0.02935502411527259, 0.006672579855207475, 0.04534926415691453, 0.1260135651776387, 0.029300574416054354, 0.02902310886119883, 0.02657079055244404, 0.03599205940601326, 0.0017972493327350447, 0.052047599888136314, 0.013024572023911583, 0.04871308345407729, 0.025875203784615285, 0.038881287234084266, 0.05325262937995215, 0.04315513088518093, 0.08126364224740575, 0.04846164573644919, 0.03379488093478065, 0.062209756203716805, 0.02585383567718729, 0.01507454957332342, 0.08699373477288792, 0.058585095459655415, 0.02364210345061316, 0.07492043423436343, 0.06368958143397205, 0.0014838653864459165, 0.03377648716371867, 0.041734378694766955, 0.030055538743674278, 0.06806204741400096, 0.10844189072808913, 0.0467963965850011, 0.0591786565529483, 0.07999591995030642, 0.07513932087608884, 0.03103836443305256, 0.039601099617298574, 0.02737192125360091, 0.06841132988131816, 0.012008589091560534, 0.02774647504632031, 0.04415033272497597, 0.0685262737134772, 0.03649449051027337, 0.2558662727354996, 0.11020244504775732, 17.648865407513036, 71.33569917371197, 104.49583238170993, 101.80616901766871, 97.31674178954094, 103.39014760909542, 86.89913841985887, 117.19650622337096, 95.29039044534007, 107.49559048683413, 107.69176390863235, 61.296639826989946, 67.38376217503702, 31.151459986163726, 48.02427268797352, 53.473260710316325, 43.38521880488242, 36.079004195428666, 15.791987911347421, 21.27435922622681, 26.7772739548837, 25.65754317468213, 19.658442735671997, 17.90211323768862, 20.22450743183013, 29.13328286140196, 26.087136845434866, 35.319241093051055, 31.60951045251662, 32.22540690052894, 31.979652758567568, 36.50672297323904, 33.495315428703066, 20.116571649428337, 27.26415776437329, 25.322253088797293, 21.35538754924651, 29.445750636439172, 18.453474929255826, 26.646145197653002, 30.686721878667033, 38.27688863200527, 44.398810248221125, 43.314019941514545, 66.69767687397619, 68.63750073217577, 76.47303919638358, 88.4114396187567, 92.36177629040134, 105.56232483156266, 111.11256491753363, 100.2975783809539, 107.73960113525392, 118.10765712491929, 130.98974843179028, 132.47817808581937, 103.95363530805035, 38.36592643491684, 6.054076869641581, 0.06127469992685703, 0.17624146875835237, 0.17299987495906893, 0.09178965202262325, 0.06346018789636512, 0.102059880361682, 0.035726108152659676, 0.038683540788629366, 0.038305215928102695, 0.04659555514433211, 0.0724807812742168, 0.0777878400479113, 0.025916482517195326, 0.06070722029694627, 0.038793750197416356, 0.03326453358655976, 0.05704637338978149, 0.05245354604877291, 0.05382494685510474, 0.013446371416531265, 0.02552816212447661, 0.03969851152731046, 0.04122583420887109, 0.06643929699015233, 0.02885569949754544, 0.07223745642770683, 0.0682468431430959, 0.05743398706639006, 0.12522045733226886, 0.010928164758238821, 0.004169705489109601, 0.0621598034406141, 0.03920505897352292, 0.06505424832744945, 0.011944917608953774, 0.051585878696172476, 0.02030118826716658, 0.016352780681524067, 0.0423602189027494, 0.03187564682335623, 0.10817874718697802, 0.11633289512246849, 0.042154734969259276, 0.04460363844109159, 0.025687860813172116, 0.05719643852282917, 0.03288613211724066, 0.04070388701473994, 0.04283660301758398, 0.009301129987673655, 0.051738636628274, 0.02864740019093358, 0.04565621260553599, 0.008051152202120472, 0.04742003812064086, 0.06288814238242565, 0.04517243191179249, 0.08682839767706972, 0.02019895574889116, 0.025254479128747218, 0.07890586110372698, 0.0937744326168491, 0.1800685222711294, 0.24077814042327866, 0.09939540357839677, 0.20739598169682488, 0.250314939166269, 0.09045835208868788, 0.13513112230406654, 0.13827925337658775, 0.0748155874410464, 0.09946746180855459, 0.20716647707646896, 0.0992528575983259, 0.2072639387821959, 0.09544397569111279, 0.08406707971927621, 0.08182978122344903, 0.18386453390121463, 0.10835590501946789, 0.12911665794109145, 0.16006126278831115, 0.18517115814310892, 0.22044438958889057, 0.12127934864932492, 0.1377213115413343, 0.13342501385317695, 0.11141430421341812, 0.21041173277603042, 0.20333847361466578, 0.17219326098359403, 0.20959207998408427, 0.16385508340693292, 0.12995141798690443, 0.26333187616640524, 0.18820253741596976, 0.07286398611482113, 0.16608688139146374, 0.17876050374921293, 0.11276160006321247, 0.1942895656271327, 0.21189547654601837, 0.14626215001748455, 0.1481851992467719, 0.18050588186710112, 0.2226582917595102, 0.08433576207607986, 0.21555259643543154, 0.15800217166543007, 0.19276443778747515, 0.06398917926896004, 0.20816519525983643, 0.13502388531642576, 0.21807518607426077, 0.08234435482130897, 0.5045029430860474, 0.3073457724625065, 18.29923556696984, 78.278992560602, 118.16750464900848, 111.72726308145832, 108.25966035166095, 109.88858930526241, 88.24232270640712, 106.36199412807342, 93.81883482779227, 94.140579008287, 102.3082951576479, 75.51562001628261, 75.44544881389987, 44.430793254606186, 82.25722512891217, 90.8255486334524, 89.52010539270218, 83.11774607627623, 46.30332885249969, 69.29401920687768, 80.3179660920174, 79.75842429745583, 58.26702071774391, 54.27852722906298, 73.17528293978783, 92.97757271797427, 73.64759906645745, 113.96898392708071, 84.49103063152683, 97.21089270807083, 96.35754185338175, 80.41611163846909, 86.97405569015011, 61.63585032186201, 102.89793722091183, 57.776740135685095, 50.60518049424695, 63.45573594493251, 42.28924974318474, 45.309576757492565, 49.79663879640641, 53.92386259571199, 60.169240813101496, 52.63630536294753, 60.074464582627826, 80.47624941795104, 66.80264734452771, 83.57709484715616, 80.25070528830253, 91.3736214176301, 111.56009166471421, 106.15013122558595, 113.85127359820952, 132.93055288253294, 139.0870266575967, 149.94890120721632, 114.70115707766627, 42.14839743029687, 5.108857731665335, 0.2404168686799465, 0.5085357524935277, 0.19926929035254065, 0.2406912354091483, 0.22205496687562237, 0.17630739828511593, 0.2561545822649233, 0.18137761331613989, 0.12431930810693773, 0.11188248352658366, 0.2021684428496707, 0.1439032274027986, 0.08940718752602417, 0.17228713739783535, 0.17817875190127283, 0.11737806121668509, 0.1606937603003556, 0.1158341718837619, 0.09679150136728441, 0.10480416818491875, 0.12312428755385262, 0.16405403644086855, 0.11638757081762438, 0.1205512127208133, 0.2424843101612022, 0.14765264556532906, 0.19400194557684083, 0.18330999349634494, 0.30519717162655247, 0.16536619183757614, 0.1752636800970762, 0.14753877425626402, 0.16097379608019707, 0.2167496854259122, 0.22886890527461806, 0.1132218350446032, 0.22560757705040518, 0.08266190592680248, 0.20377987815487772, 0.11659979249440855, 0.20890630871778537, 0.20475641043195802, 0.13565281285874306, 0.124595046133524, 0.07293376140296459, 0.10188044724805702, 0.1754599211797599, 0.18505177100098905, 0.13165377260696504, 0.10231222972393998, 0.33040541734906936, 0.09628426689173906, 0.12609026590061764, 0.14004346193565478, 0.17159859289325055, 0.1542857872141946, 0.14649965259577, 0.18276699037561495, 0.06583630918495118, 0.13726136767335478], [0.03670319201304548, 0.06962012469528184, 0.029364648094821363, 0.04482392319327882, 0.1268461648555052, 0.10989338985734409, 0.0667572541222457, 0.08537675299110913, 0.10509582551857156, 0.026362742139627377, 0.0717294711859957, 0.06125198925034173, 0.05802198253091305, 0.048516286957648494, 0.07088689704335506, 0.0504694702554374, 0.06288083390362802, 0.03420659573748708, 0.05900162895540557, 0.08052317230331321, 0.041866214765656384, 0.06838147543490895, 0.03289768089269919, 0.06247681445412098, 0.04354211636969159, 0.08574295067979444, 0.09417613081994558, 0.0251555752625028, 0.06455357922541519, 0.014008182953412255, 0.030795024264784112, 0.05003486857599309, 0.052150711492304845, 0.05328045752380164, 0.04071635892614722, 0.04632036870105132, 0.01217758329960728, 0.040627990684081475, 0.037392284270496144, 0.07390012769328971, 0.015250693296923514, 0.04907076990592384, 0.017994294513858134, 0.08722690129352194, 0.020690537132923643, 0.05641967516332384, 0.05194722704829709, 0.015478872585170453, 0.05083465670806266, 0.0260370513499384, 0.04692736697653609, 0.054803260286609014, 0.07706455345596037, 0.1098835303057586, 0.47682957964078077, 13.725861772414177, 47.0881559002784, 90.04395361869567, 80.93861056912331, 72.95255507192304, 67.43385868687784, 80.71651028048608, 64.77557820658531, 69.0920171430034, 43.92844746189733, 37.955772030738096, 33.7284650341157, 24.927217460447743, 59.68216872984364, 42.5920057296753, 72.61570976626489, 55.21755833779612, 40.67655940209666, 49.398479000214614, 53.68988144782282, 87.8392364132789, 85.03001920638546, 70.83411432081654, 79.03168755192911, 95.50474797525715, 107.91456237916024, 103.67217386922529, 94.07560102401241, 80.01620246518044, 87.28212648822416, 80.2511053700601, 101.78282307040308, 83.89792119303058, 80.66219329833984, 84.42860218786424, 86.727260158908, 83.29224448050223, 84.2911466475456, 87.50082215955182, 104.54215557344499, 123.39468263810681, 103.44194642959103, 111.27249563893965, 94.30398494966569, 88.47045560036936, 93.15830769077425, 38.85282201151694, 45.034187147694254, 45.47384169793899, 46.96633492746661, 36.53382262875957, 45.63146998805385, 50.63670458332185, 61.43990047516362, 59.09321308135987, 63.47799931803058, 68.28380492425734, 80.49639471115606, 93.59054503902313, 104.94069976191368, 78.81524332108037, 46.330914881921586, 21.620402489939046, 1.0851982332045034, 0.2301999830430554, 0.25695126774089955, 0.08880097449066178, 0.024386283175479022, 0.0037525923999642296, 0.04031475648404129, 0.14565491808518288, 0.05797519754137724, 0.027704211890757568, 0.021939505597636588, 0.04084315413849489, 0.016914731071841334, 0.02514356108863027, 0.06910982586803936, 0.03305108616909674, 0.015193346827741594, 0.04188023417467072, 0.04629858499092441, 0.06301077773734447, 0.0575705498997723, 0.037517417072048115, 0.03250289663311935, 0.0549433930897184, 0.031752454139472495, 0.023323295960923838, 0.07177359785043425, 0.048793193268319296, 0.0839963851256236, 0.05109250658161698, 0.0412098536147706, 0.017650964549712597, 0.041997326883457364, 0.007807135482453892, 0.0010920267349349396, 0.023048345089679765, 0.04502438925086491, 0.013666343030279443, 0.08938459559313713, 0.05158016368025734, 0.04014747352489541, 0.07229934101023021, 0.03688360954965315, 0.028908295263986916, 0.050347524379650434, 0.028080922220983816, 0.03311683566519811, 0.010720913076863415, 0.07801806479091607, 0.055046768994220806, 0.01863457739443308, 0.0297529359288033, 0.06404748239043741, 0.030526736443261468, 0.03925205846767753, 0.04242830496701983, 0.0805797785400383, 0.039904972222904046, 0.0437216452443071, 0.028622262930918126, 0.05989488747511661, 0.05765675777389158, 0.036852782171580105, 0.07073455279873264, 0.07362791367115513, 0.02152440277108502, 0.042646092272573904, 0.1064108307623575, 0.040050168867192926, 0.02147100069710324, 0.039006691996849356, 0.06835413375689138, 0.04630629183544267, 0.04074174707995788, 0.039027334235969095, 0.04509196203622607, 0.09110236390223427, 0.06306631145097556, 0.03343964213385217, 0.04452137208934273, 0.05555460867922633, 0.041660309483807896, 0.07228247175413756, 0.043431133212101077, 0.13875934535697584, 0.06683043084077298, 0.020926543924536918, 0.09218357443328827, 0.017191401810475418, 0.01607136594341888, 0.014167397091495655, 0.05736264129800182, 0.059905325423084924, 0.06269100497687055, 0.04316127107989404, 0.17267882283176147, 0.07618156817531394, 0.027340858303491148, 0.11181786401017059, 0.0640794091046818, 0.012428788318028374, 0.07954128507164218, 0.02177196791425588, 0.01713896883771785, 0.026379168979943763, 0.037324956633270755, 0.04530140664428473, 0.03308220849102063, 0.07979584842800133, 0.03934209295097859, 0.1728496757606345, 0.012433031487518982, 2.138105799113551, 22.62728668028309, 64.49052779905259, 109.21010555759554, 93.46991646674373, 92.57545917264878, 92.66976864107194, 104.63169543973862, 100.1272455338509, 87.34623370632049, 67.42314277156707, 52.977833978591434, 29.281193479414913, 28.215781642544655, 45.041941673524924, 28.644171145654497, 39.7828120570029, 44.501768542874245, 40.082332088101296, 40.68463948465163, 47.79952087709981, 60.3839905800358, 65.61495757872059, 62.76843078674809, 67.29816821313673, 72.2995275066745, 76.74153327941895, 69.7914541921308, 72.39190716897288, 65.20084550303798, 70.36348481332102, 63.59418384490475, 70.85061965450164, 67.46334706583332, 56.90110629604709, 61.18672717002131, 58.99621286699849, 74.53592961834323, 55.38656542378088, 58.68001884029758, 68.14438819885254, 60.30553140947896, 51.66969214716266, 75.99370987184587, 49.87455667987947, 59.19380226442891, 50.47012152210359, 22.3973887197433, 35.93175057441958, 31.143058269254624, 34.580443059244466, 38.8490879151129, 62.2951497570161, 92.48034169597011, 102.91527409707348, 97.29713778341971, 100.69787194651943, 92.03899660418111, 97.63308094393824, 104.21585359881001, 126.07952933157645, 103.81701131020824, 71.08485575645201, 36.5053266094577, 4.019370141529268, 0.10001727545093145, 0.36258512446957253, 0.1759355085631532, 0.12707339419472602, 0.027937753794474468, 0.058391750189325506, 0.08657709019438875, 0.10128793186478077, 0.08351168895681059, 0.026725976983265533, 0.035497116811212995, 0.14815958126658393, 0.0792494208942498, 0.04064049323900573, 0.016863002899974104, 0.11292693715903068, 0.0325606060364554, 0.024592916240855574, 0.05233508587304143, 0.07648876943295041, 0.04915984677931955, 0.065213096658549, 0.0126730190635088, 0.03219964455873255, 0.04967512134763022, 0.04582941742433656, 0.0819237036029658, 0.02356221197142957, 0.054469157851511435, 0.015389726763861555, 0.0700184750941492, 0.03754133050660453, 0.05355271368077206, 0.0774394002773108, 0.06764248404051028, 0.030275951815588825, 0.039955338673485864, 0.11989596239741772, 0.0610685533273124, 0.03686533835265906, 0.06604947314988222, 0.023657176230523377, 0.026381524700310924, 0.06938897298588868, 0.02889759301568472, 0.05141203802439475, 0.008666531479496871, 0.040441375496166374, 0.09716175166108916, 0.03754737110988748, 0.07243330680554913, 0.023125641446019855, 0.06649588790511893, 0.02734217214428129, 0.041118987926071694, 0.14535096504034536, 0.026381112928051623, 0.14760145557022866, 0.14173481553312273, 0.17993978885633333, 0.13697699583586187, 0.2193809063324044, 0.1615149605899088, 0.29630954046883895, 0.17223839888409262, 0.13933768045277367, 0.2530482029842754, 0.14083717499048481, 0.11759575276124863, 0.12742035541563265, 0.09500366665663258, 0.1628620342742051, 0.1448199435347511, 0.13227914550131367, 0.20827496033762732, 0.1919898003219597, 0.12267838607752517, 0.15487921424210072, 0.14387731830919945, 0.08679817550845685, 0.11488176371541717, 0.22019256116642108, 0.2212527962101083, 0.24157795153798597, 0.12249244887742305, 0.14629579659911895, 0.1380897998329132, 0.09418003020748016, 0.18926318614713608, 0.13149258770769642, 0.40353978653588607, 0.17528122351054223, 0.13512301709382765, 0.13936515236573835, 0.2963801431319406, 0.17522275568016116, 0.1676632605132557, 0.20383096089766872, 0.1622173559641646, 0.21700516042690124, 0.16352931217801187, 0.12104716272123399, 0.15106593499020224, 0.07010538776915881, 0.1451738455122517, 0.224156039616754, 0.16718479263926708, 0.16587343397400073, 0.224469063142615, 0.2939828701557652, 0.09606339608228977, 1.5507128474212464, 22.837208009535267, 71.09516374526486, 124.70725674783031, 102.72657671282369, 92.4843817372476, 88.4032497098369, 105.73825882327174, 86.41271745004963, 92.11713021801364, 55.659919323459754, 56.10013477263912, 49.721988247286895, 36.8462315682442, 92.32463928960985, 65.89996091781124, 108.21617695593066, 81.85667268691525, 67.0376443862915, 70.46467411902644, 80.64481719847649, 126.98895439024895, 122.72274140388735, 103.69471180823543, 115.6923007965088, 132.62352543492472, 148.19153816469256, 136.27732307680193, 131.395031252215, 110.60925422176238, 121.6695144099574, 110.34270563433248, 141.4966171018539, 114.6696839794036, 111.89334407929452, 116.66204406369118, 120.47328564428516, 127.32936905276392, 116.68936729431154, 129.53485504273448, 157.3271619119952, 170.86509704589847, 145.42223499667261, 147.48391120664536, 124.2527795607044, 129.41814099588703, 132.62043460722893, 62.18275423972838, 69.6832359990766, 73.57147370615314, 68.37495296232163, 49.69496703916981, 61.51607682628017, 73.40541624253797, 89.0709783184913, 84.9294182562059, 87.1751791431058, 89.1490883981028, 100.33404857881608, 113.65178969598587, 140.1993167015814, 117.5127120171824, 73.25949622738746, 36.1417503510752, 2.8720376424251066, 0.27648438008562215, 0.7669577711532194, 0.31788686650895304, 0.2686496295275227, 0.11907095465088084, 0.17264021200037774, 0.30334397429420107, 0.22206996687717978, 0.22268800064921382, 0.08017266409531718, 0.1515276408604076, 0.28256077499639604, 0.22343760236136376, 0.14642030120857302, 0.12014612074821227, 0.18710044332809989, 0.09416974930753631, 0.1697117643010232, 0.15141507190081382, 0.158276952082111, 0.14009350279886879, 0.11488199354179444, 0.11469745062171452, 0.15522786085644077, 0.12484981633362272, 0.11076374234811914, 0.14796124110298772, 0.14535926943344457, 0.14788434119714847, 0.15637438804391893, 0.20660110418834995, 0.08816436308646396, 0.17821089695057563, 0.15805714613487645, 0.10620839968924561, 0.08536919936417572, 0.10036772237189355, 0.2050055881902095, 0.2651816414248559, 0.0785359095842127, 0.19937822805537334, 0.28470851781387485, 0.21146718743107012, 0.1597203843055233, 0.1462628548183749, 0.10231030684325004, 0.07853371857274925, 0.19081788498067087, 0.22514524298810193, 0.08162076179418834, 0.12839576920434354, 0.11477805073222808, 0.09684420821647491, 0.1435946625086569, 0.14819589383419485, 0.26230066053328976, 0.1869645699738495], [0.012316950972402289, 0.03501768366643979, 0.024155999060660124, 0.004002160384252127, 0.02184175660893802, 0.04821973432215953, 0.014613152053507586, 0.03870386893170015, 0.0431500249091656, 0.023650639585309455, 0.07188592932277149, 0.08164674749657994, 0.017430670221426317, 0.01628524620055912, 0.03813722050718723, 0.04875809495006839, 0.041296203215155876, 0.050637055819313374, 0.05786538266787126, 0.03762289971834229, 0.10534496497242682, 0.032101757674207615, 0.07811731148150661, 0.023730678536418467, 0.06288855606990476, 0.014387465423844276, 0.0362030400203601, 0.010676014578841146, 0.029480430793257493, 0.05800609769780309, 0.046556553608106996, 0.06312944092637589, 0.06910150615318168, 0.005154456932007546, 0.0214174090163602, 0.006380782710508474, 0.01782084454692179, 0.009775279998599042, 0.010688257621481054, 0.041501989753376094, 0.03184542656996318, 0.0719196678349568, 0.04203036442519196, 0.044900727338127555, 0.026068698442090425, 0.03853493122263782, 0.024541959902572057, 0.043831674622431885, 0.06769054073600039, 0.031058340175678174, 0.05456911317343193, 0.11931321463517605, 1.8333371464283237, 25.280224892400927, 75.61796249881868, 89.67700019959481, 83.64822310786094, 71.645613485767, 78.80512360603579, 55.63633803398379, 51.363104005013746, 45.20206851343955, 31.91314897229595, 51.7697008194462, 38.35575572906002, 59.61654747686079, 85.7969759356591, 58.13307569872949, 35.34943157626737, 60.56162688039965, 58.40443703436083, 54.07541121205976, 54.8516208125699, 44.286489255966686, 37.61840504984702, 38.693358052161436, 35.791082612929806, 37.02427971747614, 36.86848317423175, 36.13396836865333, 29.597156086275657, 19.8163495140691, 15.862702361999022, 12.373017668724062, 10.67122676680165, 12.597608662420704, 16.6399258951987, 20.530360129571733, 23.30960454479341, 26.3823305022332, 30.774531979714673, 22.237928682757964, 45.637934054097826, 45.16795566005092, 48.02768515002344, 55.08281315526655, 72.90514930602043, 77.42728910138531, 78.49309121408771, 61.72877519361435, 75.22097941367858, 98.01403722455426, 69.2204983003678, 82.00433423442226, 68.3386004355646, 61.845657902379195, 71.7836416921308, 25.778987599957375, 24.264444766506074, 29.23035760079661, 31.154794000810195, 64.54341311608592, 66.52917969611384, 91.3810739209575, 68.11160502895233, 89.6285040147843, 99.68585337361982, 101.05312101302609, 64.57852225149831, 29.947547297323908, 7.280012686406413, 0.5270748044694624, 0.17788820539511022, 0.12120103914170496, 0.019855955202553063, 0.031326804197423404, 0.17391447668835042, 0.06493586476051039, 0.04857610310277632, 0.06966049752889142, 0.020698548497391805, 0.0250665003043269, 0.08291482219412442, 0.04105005533464494, 0.11113478937336516, 0.04431486925891331, 0.07423396582805342, 0.021890225076687433, 0.04516912624239922, 0.090084531825156, 0.012767695082021097, 0.03523589232035222, 0.039034458853664904, 0.022249625650264566, 0.03781579682723649, 0.01436221133542037, 0.07494840410447891, 0.05676919128745795, 0.0698911359593753, 0.01821560773908371, 0.03954558122542597, 0.0394124313137464, 0.054261655276340824, 0.024432849829956412, 0.032719366267443664, 0.01106202904690778, 0.030756501533511667, 0.054151330954365196, 0.02273203313140379, 0.05130246829902453, 0.03679541750780998, 0.027754871369970423, 0.035015653533440445, 0.02575257800579552, 0.02528770053158364, 0.058865403200710015, 0.09064949868667511, 0.04749414946643576, 0.04080837757717218, 0.06770482827578822, 0.07626851915471977, 0.15682412762074702, 0.015042255136875377, 0.04070725397116715, 0.020142755538765943, 0.046428731837940794, 0.010807314388183577, 0.05329366487961623, 0.028071934094412193, 0.0523871262257378, 0.03844190516599244, 0.06554710333265605, 0.0421093519206249, 0.014336485145313126, 0.016596714567933834, 0.02908590125791248, 0.04230362032690356, 0.05412613049209599, 0.00917919177276593, 0.06432654140817542, 0.0196049886289984, 0.027328688996813955, 0.061149092150792006, 0.0429050644649373, 0.03240507103562836, 0.01792602267326607, 0.06290824452955877, 0.05809520138427616, 0.02239451777460354, 0.01275664426371335, 0.028215272975484693, 0.04356426780202216, 0.06367769174938721, 0.05430394332976111, 0.011789304084114492, 0.02961035164433622, 0.08093722750462833, 0.04359614472055147, 0.05375170884954353, 0.06287261761064011, 0.07657218108614607, 0.009064154094836165, 0.054922777663676016, 0.006998521538691656, 0.03827632675247808, 0.0816274114373711, 0.037576995729919405, 0.0061924931416738665, 0.04781010327860714, 0.04246036957709059, 0.031174212889445406, 0.05591626729696028, 0.007194158369525066, 0.030156319525333184, 0.08829538710415365, 0.03335868579245383, 0.0635612846892928, 0.05769767069948777, 5.322927457671012, 39.55720124706146, 97.15066863644509, 108.1559685737856, 96.43253757107644, 90.4381831999748, 99.77982551820817, 83.36123112709292, 82.04831184879427, 73.02307928762129, 33.52792993668587, 48.1966334004556, 20.053458752170688, 41.79604699534755, 64.01164562471452, 35.25790306829637, 39.0480540644738, 55.656867719465694, 63.9599762424346, 58.59140465336462, 55.64286093558035, 43.67674896793981, 41.54579585598361, 37.512089206326394, 37.80500396605461, 35.29251014032672, 37.72342258884061, 36.83958315080212, 31.450872152082383, 20.34249036542831, 16.17303244529232, 10.924743279334038, 9.872584150683496, 11.582569864488418, 16.932454301464944, 19.837361651082194, 21.99237262049029, 25.283772676221787, 29.080738790573616, 25.414165989045177, 44.30882323172785, 47.07685555181196, 48.84531105718305, 55.01135149309712, 70.9936135815036, 73.95562279608943, 80.17519181774509, 66.82323194319203, 77.10698835311398, 83.72710197202622, 65.73808470079976, 71.56875856461065, 60.84062114838631, 37.575874790068596, 31.547438944539717, 18.406073085723385, 31.2673326846092, 45.57938483453567, 49.141308799866714, 97.61950954314202, 105.07162063352524, 120.88279677975564, 80.08922915304862, 97.9936565891389, 118.23604414539953, 120.76430982159032, 91.30796094094553, 45.12906143742223, 16.247761441815285, 1.6748850360032053, 0.3641754923568618, 0.019871265469719807, 0.05621835108726256, 0.023190214997157458, 0.19791835558510598, 0.06169955313746488, 0.09776617205070873, 0.04070586735202421, 0.06617809165148966, 0.054248490055362066, 0.02142680316953169, 0.05562826037226666, 0.04568414034081563, 0.018801582646706415, 0.04956717572865948, 0.04461177046440783, 0.04259479885560371, 0.0939991338659198, 0.028354394542534026, 0.037258701519139355, 0.02787657209762162, 0.06799571952151676, 0.025859610064916556, 0.04762081061339667, 0.027352271098343116, 0.08519607115416758, 0.03680145045021369, 0.035807091307135365, 0.03565822127124956, 0.011526202677839227, 0.056887885120006344, 0.0442859456093321, 0.034551438725283073, 0.011914326760527349, 0.03251792727819374, 0.034756727306352514, 0.03239880443640775, 0.012834339943383972, 0.07834791926847351, 0.08633443950525216, 0.030664013653633096, 0.02054980869645313, 0.05070315771585992, 0.07191071992800122, 0.046438560746009314, 0.03833325474613136, 0.026902851363223408, 0.0277342674352469, 0.010674281304912462, 0.08551068048203185, 0.022794097744589372, 0.03833222052743358, 0.026032491211569118, 0.06955846993913574, 0.07981603484480612, 0.06398043437530437, 0.23118940091902213, 0.16606291816119226, 0.11613003504011901, 0.13459032551655847, 0.08407118595055035, 0.11784357454387412, 0.12867244951907666, 0.1387843045015489, 0.1689199358224869, 0.18659050456218182, 0.11964697616114733, 0.12461646595188688, 0.10383668340622418, 0.1925352396022889, 0.12339732129006617, 0.09857817928517058, 0.17386907831795756, 0.10157365201702041, 0.19872412686386418, 0.1147095471500389, 0.21215899547021236, 0.19955838129164713, 0.15811664052307606, 0.10482109872804535, 0.14152953461293252, 0.10403487801311478, 0.14770829419214881, 0.1940123184073356, 0.24067542335439115, 0.17419287304003395, 0.19095107702718628, 0.07789879256198484, 0.21882903191351125, 0.11824013229699866, 0.19108619961527087, 0.1270662848987887, 0.0984802655875683, 0.3520793930417107, 0.10495575400249613, 0.17545408358977688, 0.2029755164779002, 0.15651265159249306, 0.2196622138182002, 0.17396615697972237, 0.13413946745136093, 0.3250283687826126, 0.23702812471216728, 0.13745832887868728, 0.13064707178742657, 0.23950615867732034, 4.579928075113605, 40.9871248276003, 105.91552642083938, 117.99598724611344, 107.90742366544663, 89.6496848137148, 102.07679687007781, 76.36159681504773, 69.11866572595412, 62.04445146745252, 45.38603944163169, 75.11642471436532, 56.94581347127115, 76.75381814279865, 113.76457352792065, 88.37724439559445, 58.050992258133434, 92.37319823234313, 85.78614234924318, 83.13391408612652, 81.87198562006797, 69.46921579299435, 59.43474561937394, 54.275114767013065, 52.28636326328401, 54.38204642265074, 52.97670433598181, 52.93645689564367, 43.38949811074042, 30.581841622629476, 22.821728375650224, 18.831891475185273, 15.162656364902375, 18.235220524572558, 26.124662160873417, 30.21845167683017, 35.91795952089372, 39.32955472700058, 43.058689332777455, 34.32909757860246, 66.90808849949991, 67.08417154127552, 72.05126500898793, 80.23209756420505, 105.77707459849697, 103.21594730500253, 112.07031357672908, 90.01703046983289, 107.47406451932846, 133.60670674231747, 100.42496911941036, 127.37020877099808, 106.62120003854076, 96.55755919794883, 100.01756037435224, 43.04636132332587, 34.41158110095609, 40.9812020486401, 44.09143763203775, 87.02515632875505, 92.09514141082765, 116.82274356965097, 86.13147566395422, 108.99171583114132, 129.13041160952662, 135.5611139728177, 99.88260730620354, 45.90119569532333, 15.66533555907588, 1.9016873884585597, 0.7266744779002282, 0.21374780053813613, 0.11678205247247413, 0.09583245887751542, 0.2616685154216905, 0.17438813353017454, 0.18183271550843794, 0.23656903886266295, 0.11661565051444116, 0.1574442298301766, 0.19701067929066, 0.18948656206409778, 0.23852150586824264, 0.1765278477462069, 0.18106411481576581, 0.1341699577507473, 0.09983125398115766, 0.15748400511520524, 0.16618737680537088, 0.21318645727249885, 0.15094547532498837, 0.12801071043096243, 0.1027398523423941, 0.1142352314725999, 0.11123257283602031, 0.14058398293151012, 0.12050716266516717, 0.1072318701734466, 0.09818539834551274, 0.11178744265869742, 0.1468446219880735, 0.13673616843598504, 0.1162750171797891, 0.13800750666808698, 0.11534042055568389, 0.23347038174829177, 0.14306403936878329, 0.18975838538139098, 0.17934726581217783, 0.07343004082119273, 0.09386995612012763, 0.10089270710464447, 0.1732713152324, 0.16836196334371645, 0.18583560152159584, 0.12039085519650292, 0.10131660653578659, 0.15495395377999352, 0.23637739430752494, 0.22273169830441478, 0.13387084638159122, 0.10890535093964109, 0.10962578002363445, 0.11779019353731025], [0.0550609607730181, 0.016388172028406013, 0.09946466558763098, 0.05116190648667755, 0.004871184909490929, 0.023670000542375832, 0.013220369733209092, 0.036738734662292466, 0.05207674953365519, 0.04004945257498373, 0.039964780707152626, 0.042406268447877905, 0.08224710762020081, 0.06517926621581278, 0.026456748788815834, 0.03860430431462104, 0.0706053444094235, 0.013189796121760964, 0.005119551093347612, 0.0967652628558778, 0.019918209422499906, 0.04257545896595524, 0.03290279069915414, 0.05542542327255492, 0.05614916185638117, 0.06934161343040966, 0.03994688872368105, 0.039510593989924084, 0.014623146628089731, 0.004232827303630691, 0.015174299009114265, 0.03581335790635597, 0.004470022010331553, 0.07781151982565081, 0.02208534384056205, 0.10762660463731136, 0.07199641452321122, 0.031053015864604426, 0.043220282832701365, 0.038630764991525686, 0.06462854858968528, 0.04376209468670911, 0.017043441503999696, 0.04807038931176067, 0.005019747073792162, 0.027694892431158694, 0.02147881670915071, 0.11921841891542559, 0.026456448099305554, 0.027543850536007556, 0.06589843125473108, 18.02100419998169, 69.83825591302687, 102.12023319736605, 78.99378961132419, 84.31330019427885, 69.80523740091633, 54.69727162391909, 55.92414586774765, 47.8005563828253, 48.91507825543804, 30.697559387453143, 64.23048250136837, 35.163083691750806, 76.93879712012507, 94.37225772488503, 56.900486561559866, 50.45398096884451, 37.601887949051395, 28.692761467349147, 16.101004000632994, 6.782994943280374, 5.05987468265718, 4.696459241451756, 2.8768079799990502, 1.5547064331270035, 1.705088021774446, 0.9535150121777289, 0.7855789171111199, 0.27642336884333246, 0.05891982225641128, 0.1987071809989791, 0.23081322110468344, 0.22828300123012837, 0.16499735114555206, 0.2381611534304196, 0.33506914612747013, 0.19379281889527075, 0.15702536359669703, 0.32197783731164475, 0.1350371692810328, 0.4951430340447734, 0.27643296026414443, 1.1221765005780806, 2.9881439670439693, 3.377142577402054, 2.859603238682593, 3.1555835758486106, 4.55972247546719, 12.094029284292652, 16.2488293070947, 25.651134021820564, 34.41951605581468, 30.95674176369944, 37.8677854230327, 56.386750205870605, 76.98115087324574, 111.56864243168985, 77.64832250533566, 50.87024250338155, 54.46725599227413, 37.13948757417741, 32.50086711299035, 40.27558726649131, 68.06060637197187, 76.03095669900218, 69.27993789795907, 74.14275123227027, 85.18370551447715, 92.03370924918883, 85.83502292633058, 47.58681074265511, 3.7829071139135673, 0.26468457293606573, 0.1533929270602042, 0.015249818999079928, 0.06908700410877505, 0.11526447825974996, 0.01499486014982986, 0.016874532523234526, 0.0734992262216345, 0.026416408513943036, 0.050641851529719374, 0.08147279191161357, 0.02554343983290657, 0.04732089102148049, 0.019943373495592706, 0.0766357050968274, 0.06386282072672922, 0.0339863377983772, 0.022973504045136997, 0.012129294862520072, 0.012792467492662612, 0.008337255398322257, 0.06143454800269777, 0.02848889659939995, 0.057924214390016375, 0.02051902536843573, 0.07686743903304301, 0.08342610161390998, 0.09868373087937794, 0.03085683032329525, 0.01020163378392857, 0.0034522385319559687, 0.0608921769045053, 0.035737856110978516, 0.043379602307874354, 0.04258287086662266, 0.052165374415175575, 0.024477842173749403, 0.045068841502671285, 0.026808871527112303, 0.030951762023652275, 0.014030094983266487, 0.015872118923242296, 0.04980328785736234, 0.022372082889740987, 0.017874258112222437, 0.03680218972506062, 0.040381712568623405, 0.05151034625727804, 0.04966810398224381, 0.02598488650795433, 0.06347256404678188, 0.0395531923089537, 0.0054937371638633554, 0.06374306203196607, 0.03322025753497597, 0.03301642069052304, 0.059153126672871655, 0.04882237738779476, 0.024458295440361388, 0.012578229089417766, 0.04021462113145859, 0.04100472591216526, 0.04161108833467288, 0.04729559479822074, 0.05462358968572752, 0.020450077455250487, 0.0776905698641654, 0.03237881337202365, 0.058714460896989035, 0.05797669524326921, 0.05421296272787356, 0.01972708006149098, 0.06978297966622538, 0.01091827456313636, 0.030486105054977442, 0.03703465527524391, 0.075181731503577, 0.019261503532048196, 0.0635199963806137, 0.00645728568704198, 0.021136519048483144, 0.007038252294859699, 0.03136449189285838, 0.04786413162946702, 0.13506744507580035, 0.06256394546418902, 0.09439979018943925, 0.039539992614018346, 0.02786983243910776, 0.044557274799914136, 0.03790832875717071, 0.03218565196279557, 0.020651376633454236, 0.049172640447655035, 0.03139299419408124, 0.08458263390967924, 0.054365107789635665, 0.04420845581579112, 0.04919177732400356, 0.055601650308216774, 0.11434267530398023, 0.11640717500760672, 0.030922185284115618, 1.1033649358057207, 30.167372611261186, 90.64888508089128, 117.46885207391556, 90.39190707668182, 102.6910557285432, 96.49888838491133, 90.67300765745102, 84.80331405516594, 53.70852839562201, 39.00377442759853, 19.75256589151198, 45.04220839469664, 32.679752688254084, 61.4949195615707, 87.90632463270619, 66.15222423307358, 55.82936179253363, 37.75831599389353, 26.28606180990896, 16.596273837550996, 6.8388259603131205, 4.060682995665458, 3.4325450754934743, 1.7777043316633472, 1.1003447107730375, 1.2207300961017609, 0.9990719934144329, 0.4661859523865485, 0.13635490179782914, 0.07363340652157223, 0.317061789814503, 0.27154780143210966, 0.10893578761287274, 0.13863306342353746, 0.3849384975769828, 0.38464030551333583, 0.20118553672106038, 0.19012072964781718, 0.37324465570911286, 0.17496902735963946, 0.2916850966791953, 0.24466959128697074, 0.39997144091513853, 2.4838502272482845, 2.4649596022021387, 1.4729865472162924, 1.7782626565425628, 2.709741241508915, 9.584468410861108, 15.741736465884795, 24.007804086131436, 34.6927365949077, 34.47229546885337, 44.37411108324605, 55.51870615251603, 69.8059904959894, 66.30452986686461, 36.65423939304967, 22.889716779032064, 32.300943905307406, 29.738985069336433, 40.252343300850164, 66.86593086488786, 108.09342245901786, 109.67302368533228, 89.94137579394926, 92.35859917056177, 99.42108554224815, 107.72494716029014, 104.8482338074715, 68.2954308294481, 9.312007830988977, 0.0703774409128293, 0.2978147500224652, 0.028180454279326146, 0.11603979754351801, 0.08041680099502688, 0.06192497833962403, 0.08029590465969617, 0.024746664341599233, 0.01663128237029718, 0.0721170197451307, 0.054512889980668985, 0.06768490232887768, 0.030604597789445714, 0.037794817509430076, 0.04463337031343291, 0.03391234902665019, 0.05454982307949855, 0.08098834089093632, 0.05878354287556103, 0.04462742547114049, 0.048654064040390715, 0.10375222221257226, 0.047506046811899835, 0.06683448344589242, 0.019728985705202626, 0.050593434772904844, 0.05372673055277236, 0.04149333679027135, 0.04945587081414077, 0.0718372674178212, 0.09395279320738009, 0.06996013749871524, 0.0025705910323473116, 0.09573184855041966, 0.082987945286497, 0.09451291839321775, 0.05223916400404227, 0.03126735385927943, 0.017787301387157173, 0.0483323032817533, 0.012396296613939829, 0.10404557260053773, 0.03693605592894939, 0.04676954903369469, 0.011853423728156957, 0.026704289034129153, 0.05812938422745755, 0.013141366916017668, 0.04386236027423893, 0.04351182142272592, 0.026062874258646083, 0.044139661120190736, 0.017159906020688436, 0.1475530541351726, 0.12229397847887971, 0.19892007683313664, 0.2725807331021755, 0.1274216347824662, 0.10742258776219622, 0.07455288823093138, 0.1137250705411838, 0.16611636045479006, 0.18037033026977894, 0.16231854085720357, 0.16275377072874578, 0.09881414968760745, 0.20338833061677797, 0.10163848603805227, 0.14314201179771655, 0.1348063316676886, 0.11325770328121801, 0.2557542400374528, 0.15708992948695538, 0.13325581567422037, 0.10711939314440375, 0.11313493769135206, 0.11917472892110387, 0.15673968940973282, 0.23309850734808754, 0.14651949427300884, 0.19162658271529984, 0.07954313900441894, 0.1255913128355338, 0.21921572245417104, 0.22948378276440407, 0.21055937324079776, 0.18671651070396747, 0.12363225747380527, 0.1905739166203045, 0.10108976790140714, 0.0994429240123399, 0.13379350214475585, 0.12908586120653537, 0.18478267495670628, 0.15683679871501463, 0.1854987679830482, 0.2526029373609251, 0.10177162445841298, 0.1583350981555639, 0.0957197213785783, 0.17377615185274234, 0.146220168399234, 0.1510499084308263, 0.7767192021973672, 31.14385647158469, 101.00672721862794, 130.6019280033727, 100.5563057622602, 104.77526203278573, 90.99001361477761, 75.118511415297, 71.56973131241338, 63.17894212661251, 68.61591200674735, 47.420945475178385, 100.61146997636365, 57.29262944190734, 106.39018812487203, 125.90288146849602, 82.86988366034724, 79.66984933422458, 59.420978100069114, 43.25868706549368, 25.674064197847922, 11.973979261613662, 6.93533048514397, 7.5600351056744985, 4.477039892827311, 3.061040971548327, 3.377829972774752, 2.98022372107352, 1.8107846211041174, 1.0477319984666764, 0.27481810820679514, 0.5422227529268111, 0.4193375920576434, 0.42250842997624033, 0.31138713141122176, 0.4007614001391396, 0.5256775826696427, 0.33634121980397935, 0.2596596796666422, 0.5111957936277313, 0.2986676816738421, 1.6231338968200069, 0.41246100298820004, 2.300915540226044, 6.205786793462693, 6.049869147039229, 4.290237503667032, 6.553738780560033, 7.2523982198007655, 18.47130798524426, 27.091212618735533, 38.40464807325794, 53.42855353509226, 48.62038273965159, 59.954965652958045, 88.19623485688241, 116.1747758619247, 160.0976888595089, 109.12798681566792, 76.4154980259557, 78.02711363761657, 48.743203916857325, 41.16777743062666, 54.037199481841064, 91.78159498399305, 99.97100184040686, 88.68526812522643, 91.88025043856715, 108.47614380621143, 121.43770233277353, 116.72977555182673, 75.17286762114495, 9.922214881066354, 0.3153213912681226, 0.547228126275924, 0.13186993197568003, 0.27518114195235316, 0.21942365403857925, 0.19097709337309485, 0.1103313699845345, 0.19607551576149082, 0.1144111099382562, 0.12348522221849811, 0.07547191028753597, 0.10961654100326762, 0.10863391066631002, 0.10292183652880693, 0.11963122539342412, 0.14223432018151208, 0.12920458951304037, 0.14236832428122723, 0.08869118643023315, 0.21763943526293003, 0.19419780361556238, 0.20904081843553052, 0.1031274162232876, 0.19025136296066547, 0.10376048830127525, 0.14042966218004305, 0.2294484048240608, 0.2569891278061175, 0.12453354459496276, 0.17786559047958544, 0.23111001888830818, 0.15911750375263153, 0.15040677761839283, 0.179302373059815, 0.21506030833528889, 0.11048768256460467, 0.13896804302930832, 0.18689464146812118, 0.16678693253667126, 0.16548970053272863, 0.08038081784522341, 0.2075374781364395, 0.20804389289790587, 0.2143741999903033, 0.10207186963769699, 0.1296855854771791, 0.1345337575842296, 0.14522045430156494, 0.22503337882939847, 0.12360397350764084, 0.22947101973958556, 0.07511608542934542, 0.1559971050629693], [0.08945566556987264, 0.043034395428314325, 0.05476150466429611, 0.02891641579598429, 0.04542224169258149, 0.03417631994271952, 0.012270754912958272, 0.008783823371143832, 0.04449644741872626, 0.09178995079691372, 0.01568848094452293, 0.04998597301422589, 0.061502017366189154, 0.024379440095095385, 0.04116911305895737, 0.003626072021659404, 0.07606172904131875, 0.03668287919173318, 0.042761886462328896, 0.06685011163954774, 0.050524322150815884, 0.05782770263331552, 0.024147325030137456, 0.009814715332111285, 0.0455788990122176, 0.0412502647527764, 0.028898504660314614, 0.025606222653521166, 0.01699043396529892, 0.026491824124429016, 0.027458278514865427, 0.06449818340761047, 0.03665507403052142, 0.04002338643336008, 0.056252380712859096, 0.022678236522141005, 0.05079251421134799, 0.03829901061591603, 0.04014725135939737, 0.029224480817755385, 0.04445329751639117, 0.023467333897227244, 0.13063004931374905, 0.0013424547726190801, 0.06079154359477182, 0.03616066769726815, 0.04128744299974173, 0.15059028631977497, 0.1314031852469329, 6.089087455503403, 52.339852625323886, 93.35488903907039, 83.63608729454779, 73.8802505308582, 74.98424868429862, 55.977097865073915, 53.334251911409446, 33.44984731366558, 48.640782986917806, 51.54397626076975, 76.42401741396996, 77.9884704466789, 66.7390892582555, 54.48749934473346, 46.67352999410322, 26.28713457815109, 17.20491978429979, 8.490339921366784, 4.155604598983642, 1.1448042863799681, 0.17797946178865048, 0.3394825786592499, 0.22589064653842683, 0.1277639381887932, 0.1281520000268375, 0.10571646398954815, 0.08185341503591308, 0.0671981530444276, 0.03485402430317575, 0.2533697147643374, 0.08966281574459807, 0.10051670349052838, 0.1886644884343109, 0.1578835506112345, 0.3976599697864825, 0.09790181557858184, 0.2853225832504611, 0.2827966381465235, 0.20154958170267845, 0.3220202479391329, 0.21714123296401194, 0.029462213222418102, 0.13056104011352987, 0.041815040092314446, 0.08011960484568151, 0.05177430185158888, 0.048059710046096195, 0.07161352377865585, 0.06588579080398045, 0.09318154185048996, 0.09750478285094423, 0.1802557235163066, 0.21993613621640593, 1.987685967356928, 3.573408174899317, 10.146645057585932, 20.97229946044184, 36.48166295020811, 76.07999417089647, 97.22269119754915, 68.41973074020879, 68.87730659977083, 69.3618683661184, 51.40261796212966, 20.422440036650627, 30.94110719619259, 60.476346708113155, 58.86859463107202, 72.71659312709686, 71.07610887096774, 70.85840948166387, 90.26408487750639, 66.78468288913851, 20.5598916545991, 2.82839146833266, 0.11185012397266204, 0.31176585463746903, 0.12810710727447464, 0.0707031355329579, 0.11449459053936506, 0.014461110413615263, 0.01156195312843568, 0.04836693811681002, 0.08618517493408534, 0.03377528057523793, 0.03294533922246868, 0.01685493216369181, 0.023368424285323392, 0.023929428557054173, 0.028943991130818764, 0.029221858881834536, 0.009312853048134957, 0.032660105536060954, 0.05434647653131716, 0.06568306861745735, 0.043714122260890664, 0.052524596873310306, 0.009237474784435285, 0.035286902284790436, 0.011466753297305156, 0.039781379258079876, 0.042689824401731455, 0.015785074098065736, 0.07826718126213358, 0.024686361730639494, 0.006178440216312846, 0.035612344095904025, 0.03441048237765509, 0.011893141556591278, 0.022937660706379724, 0.0587742310768414, 0.05148856637759074, 0.05265167553818995, 0.0293215039381457, 0.05857462686817012, 0.022169891219105453, 0.06788793861144973, 0.020208236904093818, 0.01683772199847285, 0.03409689960760936, 0.02958173251470491, 0.08012495213939298, 0.053053163067107244, 0.06633410545726938, 0.010472227530103299, 0.013159448506250499, 0.030556874342202663, 0.030217501222186034, 0.049820026878507874, 0.059279864428625, 0.026310977578583746, 0.024311920935888926, 0.04020693343913844, 0.05152849871064386, 0.05416276481663508, 0.016089642886072397, 0.08579098439264683, 0.10219432113151397, 0.014333473462160799, 0.027553825000781688, 0.03197792722212692, 0.032827173990588036, 0.007964016404002905, 0.03555298760353077, 0.09063818356803349, 0.06254012779062314, 0.04537298223905025, 0.08446363747240075, 0.013406280120233855, 0.03006385845853196, 0.052096621854411024, 0.03369350068932099, 0.07783389725391904, 0.04467589585410972, 0.04019220156835453, 0.07431137135192271, 0.02953278332678301, 0.025632901665484233, 0.04595798613022893, 0.09703082723482963, 0.020218042829524607, 0.0863136325572287, 0.04404569660583812, 0.03790400802127777, 0.07013252260343683, 0.08226642835765116, 0.05422276482286473, 0.03999604475534251, 0.08461156138970007, 0.00795977754375687, 0.0907505456838877, 0.011188894164778534, 0.0954972571062465, 0.14589350850832078, 0.26412603355223135, 12.499935761574777, 73.42552231204125, 114.47475787132018, 93.81100577692833, 89.75519657135011, 99.76565791714577, 87.34573948767878, 83.5332819723314, 39.15291078629033, 39.80049017936953, 37.91971368174399, 52.89296173280286, 59.16221541743125, 73.67830338016634, 57.94052262460032, 49.817101801595385, 26.067801521670436, 18.383827363291097, 6.531999043879971, 2.8708293072638975, 0.847259781533672, 0.19066097485201974, 0.43218893149206716, 0.03157665611304824, 0.10369023037773949, 0.19353582704019165, 0.2523908076146918, 0.07799995447238607, 0.0883120418556275, 0.023383592826224143, 0.03866309390193032, 0.31069844901081056, 0.3632334493581326, 0.2879617255060904, 0.09986399657904141, 0.3092178462013122, 0.22943237826468485, 0.6251572252761933, 0.4758223578814538, 0.21221046125696552, 0.48890812022070734, 0.19569991817397459, 0.03178149844790178, 0.38674097988874684, 0.17288897607115009, 0.04742573398435789, 0.08942699855974606, 0.1795080676674843, 0.06402400945643745, 0.13073927812999295, 0.2411567257536996, 0.14569553606692823, 0.11876206799981096, 0.07702438746609035, 1.4124809229566206, 2.617451793724491, 7.566406015426883, 19.463061632648593, 39.13359311319167, 71.4934725915232, 71.89846515655518, 50.03021201779766, 41.637375354766846, 34.36202979856922, 33.85927607936244, 27.287189922025128, 57.538471837197584, 95.16775361953243, 95.37303478487077, 102.42517394404258, 92.54054223337482, 88.46184207547097, 104.24822884221231, 87.9833129144484, 36.15143860540083, 9.053312809236589, 0.022429351792520574, 0.4032784586231555, 0.09084944763491232, 0.12278628956166007, 0.0579988313538413, 0.025150758484678886, 0.054045239268171216, 0.05041774399878998, 0.05347877853519974, 0.04539265537694578, 0.07816437226269515, 0.029018776633987026, 0.012173177336432762, 0.02830474055372179, 0.017004043517273762, 0.029743256407880017, 0.0416592178085158, 0.05876595349681955, 0.04380414142243324, 0.03587456450106637, 0.06539999912943571, 0.014241568766714586, 0.04434463560521122, 0.04531282901523575, 0.03751871559107977, 0.07749681856723563, 0.031839351492723635, 0.01749574747537413, 0.0687881838530302, 0.022528449095965877, 0.02929233705564853, 0.08275566742785516, 0.05908426302935808, 0.09168892678233886, 0.04069397000656013, 0.05928682433741708, 0.02729273266008785, 0.03517658945413367, 0.017822845951623974, 0.024356267850605712, 0.023682688873621727, 0.023417009581481258, 0.06623004773451437, 0.03778348706902997, 0.05773137856815612, 0.05464865225217035, 0.03647525404249469, 0.032408437992055575, 0.024533925555466164, 0.02571281229686593, 0.012890853291948237, 0.19551875370164074, 0.09622312541450224, 0.13046002375983423, 0.16160316795351046, 0.10633867294076951, 0.08309272313190084, 0.10713220979537695, 0.09770372056312139, 0.12885027384806064, 0.14809581210776684, 0.1699612178509274, 0.27712231682192895, 0.15193985745070443, 0.17895436995933134, 0.11820414148631597, 0.12432624120265247, 0.11574131436645986, 0.13546141345174084, 0.15941453136263356, 0.1381989367186062, 0.10219743144848656, 0.19076268068484722, 0.0957713710264333, 0.10265132322186425, 0.11155598451413455, 0.09485057164584437, 0.1752600641620736, 0.12031063046907225, 0.09935355219509333, 0.22725630551576617, 0.13002793484878156, 0.16771820433918508, 0.22500046769217139, 0.21058512911681207, 0.18664432989974178, 0.15287872884542714, 0.12653416022658348, 0.227819180957252, 0.19471900387396737, 0.13597657693730247, 0.17789367526288957, 0.1656760590811891, 0.22164213741498612, 0.08882090043757232, 0.29547766091362127, 0.1402149583783842, 0.1829582825303078, 0.3905021345182773, 0.2931686412663229, 10.844838715368702, 81.85261695615708, 128.7022849052183, 103.19215420753726, 93.68437597828527, 99.48907590681507, 76.850339827999, 66.7898682625063, 46.75954364961194, 63.85260920370779, 75.36849975585938, 108.90703970386137, 109.32507022734612, 94.32679745458788, 82.2286702740577, 68.87601221761396, 40.68564753378592, 29.08748918964017, 12.387662818354945, 6.042014110472895, 2.0014224754225824, 0.5943761802008075, 0.6693927354870305, 0.3685926327541951, 0.24991775322104656, 0.3728978017405156, 0.4532526721877437, 0.2295187623390267, 0.2592034896294917, 0.17520289868116382, 0.4917360878279133, 0.513274404670923, 0.5620641237305057, 0.625707031257691, 0.9123523725617317, 0.9628952991577887, 0.6228442526152057, 1.062288159324277, 0.7888569766955992, 0.6013514413948983, 1.1071897370200003, 0.578010029369785, 0.08381729675156456, 0.6992933923198331, 0.4080548636134594, 0.15928184493414818, 0.18916846703617804, 0.1830988136991378, 0.2494409247752159, 0.19626447900889382, 0.5388186872005463, 0.3348601266982094, 0.6923258532920192, 0.709884220794324, 4.517317731534281, 6.787466935573086, 16.33039107245784, 32.04210473645118, 58.59475435749177, 114.61394709925499, 138.50240522815335, 98.0153472961918, 100.95043336191486, 101.38666368299916, 69.45297718048096, 28.36334513079736, 43.04512577672159, 81.86858884749874, 81.08438153420725, 94.39219121010073, 91.73716237468105, 90.99475968268611, 115.66734667747252, 98.83782909762476, 38.44515439002745, 7.566111347367687, 0.15474173210320935, 0.4993571917856894, 0.25663563951609597, 0.23233992708546503, 0.19041873785036226, 0.137417082704844, 0.17494711724500503, 0.19937620558325322, 0.20814728412416675, 0.1669663043632623, 0.23576553520416063, 0.17219326098359403, 0.1351633133186448, 0.0906364139049284, 0.11545184038339124, 0.13319216908947115, 0.12132262495616752, 0.14321408534963287, 0.19683812564659506, 0.13423835408062706, 0.13427334897700818, 0.15634529202455477, 0.1349318475132027, 0.09099823723156607, 0.09636601613413903, 0.19433582201600078, 0.1449558168890015, 0.05105337098000511, 0.20752125239420324, 0.08171400235545251, 0.15230109855051965, 0.21650924106999753, 0.13796440656146697, 0.17235631513739788, 0.07281428999117306, 0.11910998683062293, 0.1542338311311699, 0.11663395235495222, 0.08594574181423073, 0.13196753157723334, 0.07441991834991402, 0.1287980266516247, 0.10459311096177948, 0.12206062809714388, 0.15275819257142084, 0.11187645441461956, 0.16501909272084314, 0.10332221706067363, 0.2264347375040093, 0.09293289269290625, 0.07081622543234019], [0.032162481633525704, 0.007340981514238182, 0.02020079244468962, 0.04678710393847958, 0.02916677332963915, 0.01432442500616514, 0.017414440648750435, 0.06998229276148543, 0.021532550116159746, 0.08005266408285788, 0.04391599408981781, 0.012118469082540082, 0.012889255998626113, 0.03714511366260629, 0.008342528956071025, 0.029749065269565875, 0.026620739485107126, 0.02017027724744572, 0.09441035454191508, 0.00409281851100405, 0.03675518640046639, 0.02863710588445106, 0.023752605888031186, 0.09603324286159008, 0.04140850021353653, 0.03741276180071216, 0.07157991550141765, 0.04008394568377445, 0.052499082314992146, 0.05956698652176608, 0.039453183360878503, 0.05024708259189802, 0.025923551593516624, 0.06794226190616047, 0.005138838314451277, 0.043674595954437415, 0.07415129728014432, 0.047660999585904425, 0.060518502197679014, 0.10460218144280296, 0.13473526935183233, 0.0923471954921561, 0.04908937818160461, 0.051377970094401995, 0.16888152417396346, 0.13632245031335663, 0.06168664838638037, 6.805545629993563, 37.99607830662882, 86.27574828363235, 94.11742133478965, 64.688230945218, 72.26936448004939, 58.167196396858465, 42.74151471353347, 44.204750983945786, 32.456658078778176, 65.29147578823951, 80.75898170471191, 76.61265988503733, 54.36507040454496, 45.47421040073518, 19.630256583613736, 8.559189285001448, 2.599940617238322, 0.5406161133320101, 0.26597576816716506, 0.0740199821490434, 0.0626764991020243, 0.02972436276444745, 0.004973542874663948, 0.11454610229139367, 0.05787282138161602, 0.21355517539045504, 0.034423609294237635, 0.19946649670600894, 0.04637254311913445, 0.12053160853083096, 0.11872318903765372, 0.12801887692823527, 0.01742246158931765, 0.10530699765489948, 0.03939507559182183, 0.0642101151958829, 0.10834302708146074, 0.06193271965809888, 0.21558635026937534, 0.07996425753639591, 0.08553986843194693, 0.09220364593690442, 0.1969533605921653, 0.1750706872271915, 0.18550670465394375, 0.06546801241535334, 0.022437006926103946, 0.19046845695664807, 0.12431032955646516, 0.06955274726234137, 0.0016069643442601627, 0.22083121802537675, 0.03736313845541689, 0.03793927487887202, 0.0462930002099564, 0.21375101810741812, 0.15581114488022943, 0.07786398918758478, 0.1322744417214586, 2.7274348082080966, 8.661154239408432, 23.60540616896845, 44.53356327549104, 54.251811965819336, 50.326037176193736, 87.64399651558169, 78.11048753799932, 44.1652762505316, 21.925153001662224, 21.10914899456886, 31.06783897646012, 51.09690450852918, 62.9622390193324, 72.05386161804199, 74.85524192933114, 83.76797306922175, 76.95610261732533, 33.02196771867814, 4.2414402769457915, 0.2891959237956232, 0.07484957110136747, 0.07456750518852666, 0.10285227574528226, 0.032172161154448986, 0.045521802479220976, 0.04268760274675104, 0.10507987556798805, 0.04610929615615357, 0.038310122721257715, 0.05177369281168907, 0.07800238297110604, 0.020759025393354318, 0.0630225218652237, 0.017336962346528328, 0.09653856977820398, 0.04612187915030987, 0.09874663435884061, 0.026461933288843404, 0.04885339245740925, 0.04538564184199899, 0.07375862359279588, 0.03310892580737991, 0.03283670412436609, 0.05570889878717642, 0.08255703615084772, 0.022244734178868034, 0.04110874533052406, 0.0276533896178608, 0.059825866783578555, 0.020673585522379127, 0.0333802281848846, 0.06237631520977425, 0.056776775557908325, 0.041162915407649936, 0.010007797259717219, 0.012253030511220137, 0.035006008486473755, 0.08348558068035111, 0.05339122617677335, 0.04066670110689537, 0.06654088790979117, 0.03535829401845413, 0.0682796853324098, 0.021233065279140588, 0.0470564259787, 0.02884097145720115, 0.07621139963908542, 0.013689645509716245, 0.045104874448189815, 0.0183863457547681, 0.03699634704859026, 0.027365099240635193, 0.03285894365680795, 0.0032932937216584484, 0.05257447302762059, 0.011417113672641498, 0.037524982190300385, 0.05553051521400771, 0.06282266867797702, 0.03876977164538638, 0.01958660251881567, 0.04099157218250536, 0.01769112096348357, 0.06943650108071105, 0.05178155287379219, 0.0034856634268972783, 0.023269146951215885, 0.02790735925607864, 0.035437120635422974, 0.04089158238662828, 0.012281876594399013, 0.05171804801530896, 0.010537447467927012, 0.029406355836639003, 0.06700909786647366, 0.053276684540774555, 0.01290525574492471, 0.040132519488613454, 0.02577418551569985, 0.04429838304678279, 0.014301703795940887, 0.031159285666240804, 0.07045792611015421, 0.04045005527234847, 0.06100065878502304, 0.02334850982973172, 0.028080623446693345, 0.02422758806196432, 0.11934235661981568, 0.023120401404617776, 0.04618313554073534, 0.05807245623380427, 0.2648614473160236, 0.08313794530207112, 0.08319291977151748, 12.770649906127685, 53.89712772061748, 109.5827385687059, 107.44272478165166, 77.19862276507963, 98.49213492485785, 85.3600238984631, 71.97499059861707, 49.503006242936664, 21.104326440441994, 34.97326450963175, 59.32491533217892, 68.47171783447266, 53.32757211500599, 48.57977051888743, 20.752683993308775, 9.738446935530632, 1.591261819966378, 0.46055143699049955, 0.16346650828997936, 0.2628185972571373, 0.023772211993233334, 0.015616016687765239, 0.019157214067696084, 0.26652088569056603, 0.12062542365803836, 0.2667065241163777, 0.05080897744084078, 0.11537492515579348, 0.10958002159191717, 0.30667023613087596, 0.16399391386057102, 0.091574051898093, 0.25991754486195506, 0.5272772355425743, 0.3056271614566926, 0.10370575897996465, 0.29794523011772867, 0.3660588429099129, 0.4897246780174394, 0.0971365780118973, 0.10237019193629104, 0.43069968721078294, 0.07250283694555683, 0.06333322797511375, 0.3140587557948405, 0.16250594128524104, 0.2677195987874462, 0.2350092838488279, 0.04142898540463179, 0.05965774112771596, 0.029028249311170755, 0.18115828234341838, 0.15649307038514845, 0.10383263080110473, 0.1307449778241496, 0.16912229028680634, 0.1326558156119239, 0.15981533324285863, 0.07676254627445052, 1.460237128119315, 5.713208192779172, 21.71819502307523, 44.141926380895804, 55.76669408429054, 54.472919894802956, 67.19237404484903, 38.27608846849011, 23.920556845203524, 27.340845984797326, 37.984158223675145, 58.10271655359576, 82.42324336882561, 84.6761037457374, 90.38603921090403, 84.19777070322345, 99.12595856574275, 98.44246987373599, 52.97001669483801, 10.194197912370006, 0.05342860743703862, 0.0493908376102486, 0.05254328941866275, 0.11417681726837352, 0.0329639743112268, 0.11520995578217892, 0.07603293179624504, 0.017119175040974252, 0.027377758843583927, 0.03702786773623478, 0.041612210653481946, 0.05133741723013021, 0.021963150901419502, 0.07821953059324334, 0.020623897059610295, 0.058929884821296706, 0.021048844115988865, 0.10080955592134308, 0.013727309264903589, 0.055464060917016, 0.05178550588748148, 0.11594710856555931, 0.03246765275816283, 0.007888099963536427, 0.0818449727469875, 0.0489949501840578, 0.031096439643372453, 0.09843927222274004, 0.015540764828573073, 0.05135927754904955, 0.018520690763609546, 0.04321230785740961, 0.057322107585928136, 0.05077863652859965, 0.061151210383902636, 0.03551508157303737, 0.03193965538464968, 0.045932456250152284, 0.06518426110907909, 0.06897287232981575, 0.037566967638990575, 0.034892573847525546, 0.03469622934297208, 0.06864062765793455, 0.04739555012014124, 0.027658706268055305, 0.027876677434711207, 0.07497253587409373, 0.0183839115103887, 0.1465458630193626, 0.09224591866856621, 0.11688682265699872, 0.17018347527951966, 0.22102080946487768, 0.08429630854797941, 0.1386339674072881, 0.2135069118512254, 0.13429067788585541, 0.3110735256585383, 0.18344094856612145, 0.20032451518120306, 0.124878253517372, 0.10464937245893864, 0.2184402422919389, 0.11698859743773939, 0.13426049402163875, 0.09622482612969414, 0.12387621051241314, 0.08317179872744507, 0.1815161066910913, 0.1503331259253525, 0.07293230583590847, 0.13469717946023713, 0.16480604366910073, 0.20871328520438365, 0.25597150257277873, 0.14641329916494508, 0.2058132746887784, 0.12774543716542183, 0.1563196893661253, 0.2076110532206874, 0.1763878068736484, 0.12260355460908144, 0.11505689141490769, 0.2388650350152485, 0.2161121317335675, 0.1850037832534121, 0.10547844047147421, 0.14399368706489765, 0.23422264944641824, 0.15942513401950562, 0.2211517338911372, 0.12994268458456765, 0.43429591843197424, 0.28337013156663987, 0.2657569121689566, 11.731710145550391, 57.06090757923742, 119.88950360205867, 116.82597560267295, 82.06036136996362, 95.31069263335198, 80.08580884625836, 57.69484496885731, 58.11217338808122, 48.21832410750851, 90.9404113215785, 107.41845315502538, 103.79747006200977, 76.76036065624606, 67.45092884186776, 34.61906271596109, 16.509607107408588, 5.005183114159492, 1.5850317478179934, 0.5381422009198897, 0.7087229540751827, 0.18457904878643253, 0.08873988663957966, 0.34558906550368956, 0.4413155207951223, 0.5344871035025966, 0.6808133904011019, 0.2690115907499867, 0.5254063262574135, 0.5659465347566913, 0.8348373287627775, 0.7381507814411195, 0.7172812593560065, 0.40167016427843805, 0.46186864856750737, 0.3497353172109973, 0.2820216636023214, 0.2349127261268516, 0.16932818407733596, 0.41739019655412246, 0.26489889369376246, 0.2811816941586233, 0.3129357934719132, 0.3098413191976086, 0.46265551279629435, 0.5336488807393659, 0.46491289811749614, 0.6683171480413407, 0.4174434856301354, 0.2370168019326464, 0.695410613571444, 0.2249651050735866, 0.4688900895416737, 0.17543367500747406, 0.16534066578793913, 0.3443711082781515, 0.40504793786714155, 0.432156173572425, 0.3847638908172808, 0.9051261409636467, 4.1446754047947545, 12.491076107948059, 37.304282034597094, 70.52511784338182, 81.0206900873492, 77.68891119187879, 124.8179695683141, 112.49849519421979, 62.0851029119184, 31.850889190550777, 30.69200727247423, 42.81876187170706, 68.1144291354764, 83.92265565933721, 91.354566543333, 95.32442877369543, 112.70984818858486, 110.50714708143666, 56.561664381334865, 9.51304401120832, 0.37623273569249344, 0.2882477214499828, 0.10342150205566038, 0.30112863187828376, 0.15052314637409103, 0.29533005109237087, 0.1222273977773805, 0.18562008566673727, 0.1585018295314043, 0.18522571892507617, 0.12888502359630602, 0.10929175036688966, 0.15386716612885076, 0.1670557374675428, 0.12499541900451146, 0.20349176780831432, 0.22115064604628473, 0.20969599215013368, 0.1631220598374644, 0.26074249898233726, 0.11065164070215919, 0.21551508877065875, 0.09469428204841192, 0.08211813671814819, 0.1326872405385779, 0.15355843269536573, 0.1088776108959029, 0.26785041596139636, 0.12443804407432196, 0.1397304230880353, 0.08448596893539352, 0.16196899025911288, 0.28344162289173375, 0.20819718709155438, 0.2659414167846403, 0.15272892801271332, 0.0987611823685227, 0.17743969155896097, 0.1431347186406774, 0.27718853746210376, 0.1449283296542783, 0.11271456226466164, 0.10055918306592973, 0.15550182921992195, 0.14145496361438306, 0.13793906437293177, 0.13834899802121425, 0.2160453901536042, 0.11069307073710427], [0.04669323135467787, 0.0066608553583313145, 0.04970163182024995, 0.01438606156772303, 0.002188630845217455, 0.02678917157613943, 0.060713712892104546, 0.03729535499587655, 0.015128635380777623, 0.138333814158555, 0.023504569600786895, 0.004263022659166206, 0.060022383657914985, 0.057019510516716596, 0.02249281643138778, 0.011970688806726568, 0.02706460699799561, 0.0411852621924012, 0.07482582237571478, 0.04765234662279968, 0.07854289630608213, 0.05793692761911981, 0.06541232548413739, 0.05311657216459994, 0.013714988655861349, 0.08870958020129512, 0.03185834089714674, 0.05908772191633621, 0.020788692148222078, 0.031030151970504277, 0.06582402113464571, 0.06328027597778747, 0.03547178994443628, 0.0420081248927501, 0.09958591432340684, 0.025366065580578103, 0.04135114321064565, 0.08073072084375928, 0.007765445935224454, 0.024025135921434532, 0.045202339984356396, 0.07730976287876407, 0.10811512358486654, 0.018831710969548554, 0.33920899333973087, 1.1360062875093953, 29.758620454419045, 89.56395749122866, 101.56474713356265, 71.64783354728453, 68.46065675058674, 74.48204409691596, 46.2319613272144, 32.90355920791626, 43.03630044383388, 51.368811053614465, 72.80869822348319, 65.09756557403072, 41.7002470262589, 33.09732821679885, 15.805566176291435, 2.8347268316053578, 0.6796401114233079, 0.14442076576092552, 0.1344861682023733, 0.036070150578574794, 0.04925289964904228, 0.05908091139468936, 0.1411484978011539, 0.2258438079227363, 0.06648349260250408, 0.037396256436383536, 0.1373955096688963, 0.07971227589634158, 0.1255561110954131, 0.21659159552185767, 0.09314567361387516, 0.012091295943865854, 0.008645145177480676, 0.013101498742828207, 0.05032830706406986, 0.08850752451126614, 0.15010780414506314, 0.09465308950072336, 0.04225906465322741, 0.22108759701011643, 0.01174674406948109, 0.5674046758682497, 0.7560843481652199, 0.038300025682415695, 0.2365154280297218, 0.1139198637176906, 0.20394962791713978, 0.05290191432821655, 0.047066607287213694, 0.06990197610350386, 0.030750920582983284, 0.053870057942526, 0.055789839806816274, 0.17889950274219438, 0.07606091698811901, 0.0697041645405754, 0.06912445814739313, 0.21114232018589976, 0.1534567881495722, 0.2700868104734729, 0.05617300251258477, 0.10520021265913403, 0.13914381424265523, 0.3167536386078404, 5.110135443748967, 19.883831931698708, 35.84191653036302, 43.315859533125355, 60.193222184335035, 91.18558299156928, 75.91515264203473, 62.49246066616428, 28.868044345609604, 27.212123601667344, 49.83863169147123, 60.422257223436915, 80.83126314224737, 65.76504707336426, 77.29503462391516, 94.05312584292506, 73.49482274824574, 21.453813545165524, 0.9772424099426117, 0.3240105443664136, 0.10171020718952341, 0.08596598951806945, 0.031313640891664454, 0.03694511108821438, 0.09539095474587334, 0.03510150900711456, 0.007420447335818843, 0.033580629124997124, 0.047595001111227664, 0.0053720728253885625, 0.04106416667421018, 0.011637485567330113, 0.023556182859465483, 0.024851526456674742, 0.05628957428158291, 0.0422441182778247, 0.023215965127512332, 0.02834618399520555, 0.05036653102105183, 0.09299269351627558, 0.04487797835721605, 0.04248591860936534, 0.06848279822377429, 0.03950029393778213, 0.0449934431291636, 0.055806494558290135, 0.03762076233303355, 0.03011631824436688, 0.08461146945914916, 0.0024927404592745006, 0.026168479479008147, 0.04227329473642092, 0.016908458726961288, 0.007875149725981417, 0.016524909146791025, 0.054716370594237125, 0.043052881129927216, 0.0861829839226219, 0.018772364053274357, 0.018006758764386177, 0.06341355995485379, 0.00944334271949746, 0.044312203272936806, 0.024990646108504266, 0.044453240059796846, 0.0234345204362105, 0.052476888747825745, 0.029852184534613645, 0.028080539177021677, 0.07084655485326244, 0.059708165034892104, 0.0385053793809587, 0.031793081697316906, 0.024869592725149086, 0.03520265559575731, 0.04027738288465527, 0.04325348125290006, 0.10224502083034286, 0.013952733509452834, 0.044008426428321874, 0.04636408933889001, 0.06519674068136562, 0.03256156364636075, 0.03680124743691376, 0.01918760860609191, 0.06328866081011873, 0.04672054238917847, 0.09085344661387706, 0.0431729156163431, 0.02682173031292135, 0.023075322875933304, 0.02116723917424679, 0.023825615982434923, 0.07801766642519543, 0.025340393974235462, 0.049477485984924345, 0.061056062263707, 0.05851497926238564, 0.012289136235091475, 0.010178448132900222, 0.007956154426679978, 0.0787334070510922, 0.02483389494309743, 0.005035973773638328, 0.07662834299187507, 0.04585859005249316, 0.09034066566175993, 0.04571690975177673, 0.17790942603061277, 0.05381817080741448, 0.15281969410998208, 3.451441093798607, 48.35387729829358, 108.4801838474889, 116.9329700162334, 80.40900430371686, 96.63727744933098, 102.37872523646202, 74.40642864473405, 49.583995342254646, 35.86919269254131, 36.926106714433246, 46.272867725741484, 59.9836067999563, 45.27092179944439, 36.767403694891165, 16.10242291804283, 2.8076318338994057, 0.45101554223125984, 0.16693696319576234, 0.1862415208691551, 0.03678301454431588, 0.04051184409388131, 0.054784521775981115, 0.15131964798896544, 0.08541749354692237, 0.06641072191057668, 0.25128247757111827, 0.07394900410285882, 0.11319726660487153, 0.48011857896081866, 0.49459344256789456, 0.5518275343122021, 0.20049319242037114, 0.2293133894882856, 0.38006483006381225, 0.40234551674896674, 1.0762667511740038, 1.3059001968752955, 0.9053744760251815, 1.2236282373628309, 1.503236601429601, 1.3823676614030715, 0.9922138517422061, 1.737454317269787, 0.7756371796131135, 0.9469333976026505, 0.33297306827960477, 1.0223133237131181, 0.5285576442556997, 0.23053168379251035, 0.13571327251772727, 0.22882361415653463, 0.18965749160176326, 0.22121921091550784, 0.3362597693358699, 0.23716954454298944, 0.012456308111488339, 0.0469650240284541, 0.234955397224234, 0.271466504181585, 0.14291232331625878, 0.02836027618257269, 0.03220841626546556, 0.17250986980094066, 0.16750903169233955, 3.852453188550088, 15.80209291750385, 35.259342578149614, 46.86714603054909, 65.23304423978253, 68.85195239897698, 41.62252133892429, 36.471707974710775, 23.31822591443216, 38.42453449003158, 82.88860905554988, 88.05935198260893, 93.50698286487211, 82.52407966121551, 87.7457820215533, 106.67568176023423, 94.00976796304026, 38.308918706832394, 2.7172638572031453, 0.435854907357885, 0.13708456990218934, 0.01154918340034783, 0.04758038798407201, 0.016893786227991505, 0.021519549604084705, 0.05661958197672522, 0.043827062773127715, 0.10059155028073058, 0.018648163963770194, 0.07028247665373549, 0.039918148935201674, 0.024586990550761263, 0.060651629126720855, 0.03975802123726856, 0.03476140810356986, 0.05751011705386543, 0.04885918408211681, 0.01675756238851576, 0.06532596439243325, 0.011079131002207438, 0.019723079167306423, 0.04112920370854197, 0.13404499348853866, 0.016887962044547164, 0.008308942703860662, 0.020515541583600066, 0.05290797408369761, 0.009113527503946136, 0.03180400228067752, 0.02188051108180756, 0.013895602502499618, 0.07637904265955572, 0.07396926712845603, 0.016660548844224504, 0.06411885497190299, 0.023277972284103596, 0.020039000420741016, 0.04029386143590655, 0.0642261340943796, 0.011224765274223062, 0.08419755215366041, 0.04521086654295364, 0.041162769850944324, 0.028142699551197792, 0.05595062634036426, 0.015604764771377368, 0.1831202028739837, 0.0904584976453935, 0.1362711530659468, 0.12117234148806143, 0.09901913949438641, 0.12272818179260339, 0.10890303735410976, 0.20297285049192368, 0.17322993116273036, 0.16669811230273018, 0.108185435134557, 0.2148878313000164, 0.15918947005223844, 0.10646501616124185, 0.20869508295530276, 0.12839704091029783, 0.13323621914511727, 0.13666208773370714, 0.10758569554215479, 0.2034002356231213, 0.19000172554965944, 0.15923891336687152, 0.16743443005027311, 0.12448492865528792, 0.09224555094636257, 0.18301952359897478, 0.15654847386383242, 0.2864366895969837, 0.11940178206010212, 0.10531380051566709, 0.2317396665532743, 0.21623344941725656, 0.07811639983687671, 0.12880461500777354, 0.17982283787381265, 0.23354993231834906, 0.12343770944543424, 0.1778164382783636, 0.15054242114626593, 0.18969548956280757, 0.2592111505087345, 0.1343527463294806, 0.1698825406211038, 0.1913114754302848, 0.3766551872174586, 2.973574323038901, 53.874644694789765, 122.62142658233644, 130.5389896515877, 89.88646261153683, 90.08324792308193, 97.63615608215333, 62.333632130776685, 45.171607386681345, 61.925132966810665, 73.30552131898942, 104.70323947168167, 93.55519663903021, 67.56840382852863, 53.765002681363015, 25.704119359293294, 5.712884106943685, 1.4249182684767632, 0.4003598781362657, 0.3030580089938256, 0.1089041022163245, 0.20667955159179627, 0.18609944220271804, 0.47158794477581983, 0.5072796747328774, 0.2928859241787465, 0.3595498534700563, 0.4223619539651179, 0.28500428903968106, 0.5569497820350432, 0.5611701910534214, 0.5321574607683767, 0.25128921914485197, 0.21369218255483338, 0.22834202064381492, 0.32387684670186817, 0.5160777042469671, 0.6777309590289671, 0.390118140607111, 0.452908453561606, 0.5290962959970198, 0.4943230441741405, 1.08588109333669, 1.357342326833356, 0.3057899704623607, 0.6504875854138406, 0.2085837703799048, 0.6789093861176122, 0.343102527962577, 0.17375847054344995, 0.3380458573660543, 0.2234055185990949, 0.27996824153008004, 0.34849376447739144, 0.41067212639797124, 0.300064750256077, 0.3450597906785627, 0.20899673773636743, 0.6942160679928718, 0.6260676441654083, 0.524310207655353, 0.1598286478509826, 0.1872049990080057, 0.469265625842156, 1.085148468132942, 10.070889380670364, 34.027381020207564, 56.72120286572365, 67.06532847496771, 91.46767985436225, 126.97863855669577, 103.11442852020265, 84.29419825153967, 44.551076658310436, 39.57047454772457, 67.20244669145154, 79.2598282906317, 100.07038685583301, 84.29754011092648, 97.3108974579842, 116.14429904568581, 104.31596817508822, 41.42822673243862, 2.3497568936117235, 0.7221589105263834, 0.3155472033446835, 0.12511528878202363, 0.20945723318765241, 0.1382479050587262, 0.16978869485037942, 0.11647069135740881, 0.15334918343972775, 0.17218772982878072, 0.09441992298008935, 0.18306853790437022, 0.14289039787986588, 0.10308970937565451, 0.12345183610675797, 0.14879626161869497, 0.10140708151964412, 0.12335030647415308, 0.15169282473864096, 0.13593055037481172, 0.10899524369667615, 0.1838194113224745, 0.13114257745685118, 0.22411532970445774, 0.2271411471789883, 0.1560450008799953, 0.08386693924905793, 0.13368384431927435, 0.15461492922998246, 0.10186722457048394, 0.21369052780491693, 0.09677136091575508, 0.11822790553372715, 0.1335272712693099, 0.111218269974474, 0.09569581943534075, 0.10057468868551717, 0.11115051715845063, 0.14178811993089416, 0.16817402665413198, 0.1881158622282167, 0.08903100005080623, 0.17301551847448274, 0.2008834529307581, 0.14212694529804493, 0.1450805819683498, 0.29477365675472444, 0.08696256265524896], [0.04966660244991222, 0.044094783689586386, 0.06757622509593926, 0.04813416613145702, 0.025860343594104055, 0.012412071321910668, 0.01909525096116047, 0.0190144325155885, 0.04735943673539066, 0.05590390646830202, 0.03611518505720362, 0.014534251700576036, 0.08476620389809532, 0.052373570299917654, 0.0420209223915252, 0.013270495823704669, 0.04062248634234552, 0.04043247355448623, 0.04076496720494282, 0.08052112684855539, 0.028370549421637293, 0.04012615329796269, 0.0109900493407622, 0.042846780495658036, 0.028346224214821577, 0.009574277679465953, 0.0750786773560028, 0.036623357990456205, 0.04383018458141916, 0.01943703151247915, 0.09772465774609197, 0.04122147899902156, 0.05147466571220467, 0.16772071710757672, 0.053683500211205215, 0.01295734589333616, 0.013502447137368784, 0.07824134111644761, 0.10482561098591936, 0.11104459784203961, 0.06551178667934672, 0.0225043996808029, 0.2626375247153544, 0.7807464957717927, 20.038681222546487, 75.98351955413818, 97.86133935374599, 91.11059511861494, 63.39924596971082, 81.6826214328889, 45.93230793553014, 40.645666814619496, 40.450340624778505, 53.41259733323128, 75.13801343979375, 47.5541687780811, 45.620675625339636, 25.02620827767157, 9.917173654802385, 0.9333581970103326, 0.3919449232278332, 0.047631631605327136, 0.04378339576144372, 0.1442567310145786, 0.07180595740435586, 0.05419575639309422, 0.07137392978033713, 0.13225285336375237, 0.0506160841623862, 0.0577047263692704, 0.16072506265294167, 0.10959200320705291, 0.18450962589873424, 0.24348138891641172, 0.0800231007498599, 0.08286482729618588, 0.12474573562822996, 0.07654657842771662, 0.10228583799494852, 0.22213411907995903, 0.1683081686496735, 0.7423099034255551, 0.5309913523735539, 0.19774177231855933, 0.6110508499606964, 0.9011814623109756, 0.38765630174067717, 0.3441451123404888, 0.06917092138000074, 0.7680148499146585, 0.27109115174220455, 0.14967815139360968, 0.11807541573239912, 0.04232276486413133, 0.2219844561430716, 0.2589042250427508, 0.09810239271891695, 0.0317971266415571, 0.04784931931945105, 0.04478721225994729, 0.09963262270415023, 0.10154211217717779, 0.08464389796098394, 0.03552253560854062, 0.04075728334306229, 0.12364480599400499, 0.0599150930441195, 0.1984153321433452, 0.015349003445026616, 0.00990400383729608, 0.11105383686240643, 0.30163602723229316, 3.768001126666223, 21.25106623095851, 47.64060212719826, 64.71087871059295, 51.2595965785365, 69.92735647386121, 79.96529794508412, 49.38533513776718, 21.43359176574215, 27.260182442203647, 48.12055510859336, 49.36222845508207, 62.48770675351543, 69.30355841113676, 81.82424253033054, 87.90775237544891, 55.988578642568285, 3.402108218400709, 0.025150381186376178, 0.10984591538867644, 0.14460657272608052, 0.04616468048263942, 0.03212352223213642, 0.08407321608354969, 0.0736884729215695, 0.03007665404208726, 0.036986759458217895, 0.05095268404411693, 0.09586785213961717, 0.04628886716560491, 0.05488792449356087, 0.0544540812411616, 0.02342916548161978, 0.07048562784949619, 0.013049489991258711, 0.06938269106490959, 0.04529278815513657, 0.02846082139219488, 0.027096516475261703, 0.06833454488866753, 0.06461843622908478, 0.034644732912701946, 0.03424065600660059, 0.052855324691101435, 0.03331023073124309, 0.026753251628589728, 0.07440957616293624, 0.06010712447365927, 0.031095196665715308, 0.032248896351384546, 0.07108211156822021, 0.07655050845876818, 0.026433850420759093, 0.03807191917252156, 0.03888331353664398, 0.013837645078198084, 0.021826442511331652, 0.08181291962823561, 0.0824330218376652, 0.03585175423312091, 0.008389258404232321, 0.04337716231783552, 0.023486059001316468, 0.0570416504577283, 0.046641263780334306, 0.0876858339254414, 0.06842751731915821, 0.06103379591818779, 0.056328284704396804, 0.02277499534219744, 0.017872821697364413, 0.07988784026594893, 0.0004551899033803268, 0.08278339981071411, 0.030349461782363155, 0.002757480814902773, 0.028581183381198395, 0.04630087559381801, 0.057940217966754595, 0.0352268678046042, 0.03206546617401464, 0.06257291635378234, 0.06765481039521194, 0.056261880203120174, 0.01144040753358915, 0.04623411103121696, 0.010179691110557366, 0.06663047423165652, 0.029277766063328714, 0.07831703060336652, 0.07364041622607939, 0.027548326404705167, 0.07543972693383694, 0.04847298766816816, 0.051272234639092806, 0.07578553136197791, 0.05541292071763066, 0.11722773944418277, 0.0867249681464126, 0.03334707189952174, 0.057795561414452336, 0.05946932180273918, 0.14595389155851257, 0.023176724188810876, 0.14165641409495186, 0.0759800027815565, 0.14436145523382773, 3.512258669061046, 33.80647705447289, 96.62322751937374, 116.61128074892106, 102.16000603091334, 79.94749822924214, 111.80898174162834, 76.15243250323881, 61.03449606126355, 39.02427273411905, 29.24289937942259, 51.146793134750865, 38.553588313441125, 54.006805035375784, 29.53978946132045, 9.239120387261915, 0.5340465723026184, 0.2844012859127214, 0.05732591504291181, 0.025361951688424717, 0.11223173535038387, 0.15420087402866733, 0.13077283278107643, 0.14202387582871223, 0.2864066895938689, 0.29052603629327595, 0.09039437608613123, 0.5690913563293796, 0.4094285511922452, 1.0838381513472528, 1.3616260453577966, 0.6590323462601632, 1.0970524938837176, 1.029863273424487, 2.197161494724212, 2.7796123825734664, 1.5573553813080636, 2.4271283418901506, 5.0856485770594695, 3.2991989533747397, 2.428391590233772, 5.189932142534564, 5.540493486389037, 3.6702453657504055, 4.447429430100226, 4.257373434882011, 3.480557828180252, 2.3137613025403794, 1.8811830758087098, 1.6657428491500117, 0.9914955677044008, 2.2281945520831696, 0.9677079247851527, 0.8878303884017853, 1.553393051989617, 1.4268648672488429, 0.9673100493607983, 0.5112258242743631, 0.919084201657003, 0.8398165938354308, 0.19821584284786256, 0.2422915930829702, 0.22921542216452861, 0.09636771684933094, 0.2544678405167595, 0.09618446095696381, 0.05685736800754263, 0.18959692469046963, 0.22100070731774454, 1.599504558309432, 17.580692652733095, 41.847696765776604, 63.90157607293899, 46.00136518478394, 45.06261256433303, 35.04985663198656, 26.09317925668532, 21.472152586906187, 40.56595248560752, 81.58347960441344, 80.0494327852803, 88.47078507946384, 85.1209475917201, 91.47663854783582, 101.54118153356738, 79.73101477469169, 10.984998729921157, 0.01643989828505343, 0.060545805571300376, 0.11984333215701966, 0.08204376490245904, 0.030872820493494792, 0.035539446999469114, 0.02623338819361262, 0.03584550295565878, 0.057104948472471974, 0.01460103062732566, 0.10313175994181827, 0.01928019416218083, 0.022837730282316768, 0.012882862037288086, 0.019884645195317366, 0.07948268700631396, 0.005114921049455242, 0.014101725161796617, 0.02635362377810863, 0.04288717248146573, 0.027446884872211565, 0.046313634788196896, 0.0653451242514195, 0.03102898751685937, 0.11505512941268184, 0.08610860444605352, 0.03864682602485822, 0.06900520124022039, 0.09104877605193085, 0.04193872881812915, 0.022275421745894898, 0.02546296612690053, 0.03315194164432826, 0.05884508271851848, 0.040366310370905746, 0.04975240812787125, 0.07054239496468537, 0.034953087132664463, 0.014835969683894468, 0.038224370669453375, 0.011356525693929965, 0.030028198980876518, 0.06492487139879696, 0.09180855141171525, 0.03954078551501997, 0.016515043849546104, 0.25002246211853724, 0.1714827910426163, 0.11788997648944778, 0.14805589892691182, 0.09766235181521024, 0.09880900157675629, 0.1389819092207378, 0.13153582571014283, 0.1116864109832433, 0.18235103527624763, 0.1576007569148656, 0.08596291750549309, 0.18971718517282318, 0.14838972940079628, 0.258471691800702, 0.12597393544931568, 0.12598114433668314, 0.10939322637333986, 0.1519236010649512, 0.19923739045137362, 0.12234441770781433, 0.10212870570079935, 0.08271507242874754, 0.13855424829788748, 0.14580360042952722, 0.2653993329694194, 0.16540405190279409, 0.17930744456187372, 0.14589353915183775, 0.14607620515650319, 0.18937871220611757, 0.2177384904315395, 0.1446882376988088, 0.34696073061035526, 0.12046067644992184, 0.10962686786848692, 0.09753213985072029, 0.3102315030992031, 0.3828409794838198, 0.1781663106333825, 0.26081503218700813, 0.20047400957874714, 0.3129178057274511, 4.205915370295125, 34.00631397001205, 107.54531045113842, 125.15799199381183, 107.49792037471649, 82.5344111842494, 105.49602893091019, 62.2064688897902, 51.34435507559007, 55.05376408177038, 74.80123089205834, 109.3704128265381, 72.07671334666591, 71.99237454322078, 40.674406020872055, 16.72622980610017, 2.688838930860643, 0.6113852320178863, 0.2233077657799567, 0.17543355243340616, 0.28062490145525626, 0.6213761830041487, 0.48395242001260486, 0.23760816052315697, 0.5384371754142546, 0.28311174543153855, 0.171938797218665, 0.3568134486915604, 0.4411161847172245, 0.44682856528989734, 0.6312603719772831, 0.28854808920333463, 0.5691713971957084, 0.474848935921346, 0.781514912603363, 0.7571150735020639, 0.8859689786068855, 0.895077089869207, 2.772938960021542, 1.356725779271895, 0.991016180524903, 1.3056095737603404, 2.716870639593371, 1.5765438613391694, 2.135886718188563, 2.935034094318267, 1.297652432995458, 0.6984306547430255, 0.487575433667629, 0.5166233427101566, 0.31513192240268956, 1.1604554013859842, 0.7253570518186017, 0.40930738672614103, 0.6845506737309118, 0.44035956563968814, 0.2750580163011628, 0.473200774361049, 0.2993932895122036, 0.36188908762508826, 0.1444007708661018, 0.13618378839906187, 0.29666757932113064, 0.3564153587625873, 0.45080673730661797, 0.3160225455799411, 0.18582262399215854, 0.28604325748259024, 0.5344017919513487, 8.587941238957068, 35.67369391841274, 68.63382154895415, 84.9329170103996, 71.46491773666875, 102.18203406180106, 109.54710775806059, 71.52280407567179, 30.679536096511352, 37.97382670064127, 70.0651179590533, 65.36828756332397, 80.62993572604272, 86.28100425966325, 99.65132082662275, 113.1765631706484, 87.60653003569573, 10.852189237071622, 0.10408432132774785, 0.23001434461724377, 0.27385035529732704, 0.23489224093575634, 0.11708373789705577, 0.16228797394902478, 0.12289600867417552, 0.09549419275454937, 0.09946517886654024, 0.12029971371615127, 0.19534774755518283, 0.10851260064350021, 0.18172509547683502, 0.07390180542584389, 0.09054076016670273, 0.30122880553526266, 0.09413293878277464, 0.0743809168136889, 0.20270726313033413, 0.12245339371504323, 0.08093896652421645, 0.26470672819883595, 0.2714191599478645, 0.11045287919020462, 0.1887888398261801, 0.16362390871490204, 0.10611047066988484, 0.17106905759822938, 0.20682438817476073, 0.1091063417674553, 0.07676405546766135, 0.2795703048186918, 0.17315372073602292, 0.18850537197243786, 0.13432813958535272, 0.09148848753783012, 0.14941219630981648, 0.16324071153517694, 0.06524685815337204, 0.1855970723854919, 0.19654468332807865, 0.12329879472212446, 0.16610214186291541, 0.19986605752379666, 0.17561785786622958, 0.1862317455872413], [0.005387472150276506, 0.03565015436540689, 0.03392793125503006, 0.05163513431926409, 0.024950794214683197, 0.020811515822706204, 0.037005237498951536, 0.03839027850077518, 0.035835042025052735, 0.01986629930475066, 0.03177580449940457, 0.021505706395292958, 0.057109154295176275, 0.005350891451892113, 0.02341605388679572, 0.013195747667322717, 0.045426658189464966, 0.02180188364769903, 0.0587279134009394, 0.02325040077970874, 0.017831730656325817, 0.022320557731173696, 0.048870706044497995, 0.05244741351493905, 0.047005810549542795, 0.04944294691085816, 0.06135533451132717, 0.12405351390160861, 0.029220303723348245, 0.026074813738945993, 0.02644940966650123, 0.05423993668368748, 0.024225230426377347, 0.02724916523983402, 0.012378219811756526, 0.08501633160537289, 0.08817854337394239, 0.056557988507613066, 0.05908258146636429, 0.03985140352479873, 0.5577064930431305, 0.07672786547411835, 18.515246375914543, 69.35019539248559, 89.11942743485974, 81.88172094283566, 57.54572822201637, 77.49565601348877, 86.14023039417883, 31.864089927365704, 46.469884457126746, 45.184566897730676, 71.1979063095585, 79.1929832581551, 52.06370207571214, 33.30667688000587, 8.102973507296655, 0.9271818123036816, 0.3400561333664002, 0.1289629653817223, 0.15711559343241877, 0.10524682144844726, 0.15485160443330967, 0.116135367012072, 0.021671960881400495, 0.05860372671797391, 0.025851970253091668, 0.043064372448791424, 0.0497851315735569, 0.0462298400910391, 0.1094990077939245, 0.42879304758483366, 0.2108763038150726, 0.2084260635198124, 0.8282668071408427, 1.204101452904363, 0.7568098640730305, 1.0082945275691249, 1.9053307800523698, 1.8142681761134056, 3.9806313428186604, 4.257094946599776, 5.131692790216015, 4.728527559388069, 8.775393270677137, 9.575370473246421, 8.155634758933898, 1.2930606858384226, 4.193062253536717, 4.437716660961028, 3.3118956656225267, 1.8463841753621257, 1.6826656701103335, 1.3125820770379037, 1.3207656121061695, 0.7292674097322649, 0.7233052232092427, 0.46322683052670577, 0.14727640446395646, 0.8798462813419681, 0.42643610147699235, 0.07012352873120578, 0.037286908876511364, 0.08819405665440906, 0.3062731267944459, 0.23643049952243608, 0.05636190830339348, 0.030615493474948793, 0.04303769726726798, 0.03506633791051084, 0.08427992192727905, 0.05010874243453146, 0.03999866094560393, 0.45563851513208886, 2.4520770676674384, 22.396125716547814, 60.64451048451086, 66.91971440469065, 61.012887723984264, 59.83361144219676, 76.07014902176397, 45.37651200448313, 13.946787311184792, 26.244514103858705, 35.79488338962678, 58.467206724228404, 69.33193283696329, 78.82198979777675, 86.11685306795182, 76.96287262824275, 25.545384960789836, 1.3121710861882856, 0.2683376478812387, 0.044321346532313094, 0.0297537594733219, 0.01781665213075617, 0.05269912319378026, 0.05529302795748076, 0.02237225525952395, 0.05108891362925211, 0.022804556759975614, 0.033597184285040826, 0.11836044640550691, 0.014055906400655307, 0.010330922612469765, 0.02650554667437269, 0.02295032413976808, 0.06330081862547705, 0.053105923542452436, 0.07671873370606093, 0.023651892139065652, 0.05589632602829126, 0.09483604661880002, 0.04294151109793494, 0.036338388604382356, 0.011769299613191717, 0.029292762234446504, 0.01319392629328274, 0.0535442024439333, 0.011557021437423124, 0.036301260153132106, 0.03837427875447658, 0.024348379060205434, 0.0902913908864702, 0.0494027387861523, 0.07738837116067449, 0.07100598541118446, 0.029779766243131413, 0.09255434566688153, 0.08261774861884695, 0.04129993406334712, 0.03581981985799728, 0.00955820707003436, 0.04799013777125267, 0.06282017123134387, 0.03177991647633814, 0.04557601086074307, 0.028677501700698372, 0.01738512629432784, 0.024898627457479318, 0.016553444006750663, 0.05505546409216139, 0.01596041725978496, 0.061610985712538806, 0.01191289896415847, 0.03627941132553163, 0.05302673686415919, 0.0688515393243682, 0.019005042192856633, 0.04421412869687042, 0.05752991276582884, 0.0732382124049529, 0.0898343658134822, 0.03317879685651391, 0.03116705954345244, 0.02962991561470253, 0.014413849491956494, 0.022404174312889095, 0.02534661460818062, 0.09334422062121092, 0.014797674863779498, 0.009770962135535816, 0.013382877091756992, 0.08076187763963977, 0.012891133871650504, 0.06422295099905422, 0.03963232919153187, 0.02238553156325173, 0.01723194509864815, 0.05051305682788934, 0.05923760318828206, 0.041825876406003396, 0.077406466157446, 0.028303277325786413, 0.09904163183584329, 0.047108922153711326, 0.5370481047899492, 0.9349160521261154, 31.468640488962976, 93.33068017036685, 103.53584012677594, 92.96862971398139, 75.35725039820518, 119.59309008813675, 121.65824151808216, 48.3363050799216, 40.79728603363037, 29.745619758482906, 43.18766078641338, 58.98220216074298, 51.48565846104776, 30.49473362584268, 8.096153976455811, 0.3860012760325786, 0.3349109336493477, 0.1369651521165525, 0.2092243884239466, 0.014509713904361331, 0.19092673075295266, 0.31472488456676084, 0.2774954016410536, 0.26220928156568163, 0.38183967192326823, 0.1990844180146533, 1.002834527002227, 0.9929915842029357, 0.6003316251500961, 2.5893065814049017, 2.0136578188788508, 2.7110949495146355, 3.769390871447902, 5.926673873778313, 5.371454040850363, 6.375503828448634, 6.434064324825041, 3.230344931925497, 8.17577563947247, 5.464394602083392, 11.90220675160808, 8.457526353097732, 16.11045495156319, 13.387282779139857, 12.306760991773299, 14.015438595125753, 5.647426612915532, 7.389728244273894, 6.613641708127915, 6.436029922577643, 6.227946714047463, 6.24451284447024, 5.397756474633371, 4.428733452673882, 5.1251051695116105, 2.5028156224758398, 4.131146659774165, 3.000430301312478, 4.1199301519701566, 2.707369923591614, 0.39041712940219914, 0.8388147346915737, 0.4042527998887724, 0.37135493130453173, 0.40432989897747196, 0.09912023245687447, 0.21696425133174468, 0.1477161542542519, 0.09264389368435068, 0.05595408905778201, 0.03867195753921424, 0.2613365542023413, 1.023774284028238, 14.861826262166424, 47.9960512345837, 60.13104869473366, 58.7655225876839, 44.48668702956169, 32.008048757430046, 26.367586312755463, 27.087158849162442, 44.61605856495519, 62.50172138214112, 88.8061712634179, 94.03707550417994, 89.37264780844413, 96.76180485756167, 100.98546797229399, 47.04419397538709, 3.904998730267248, 0.46059988439083105, 0.08109202323060843, 0.034082619728700775, 0.09924916505453088, 0.07659594513355725, 0.11055711311318221, 0.10661272557392236, 0.03617266846460201, 0.019268298731936563, 0.06795340082457951, 0.05774435992803305, 0.04467704115555652, 0.022887763484651526, 0.041498174635513176, 0.018103801036974596, 0.028797984348549962, 0.06335361740521847, 0.025295309699891556, 0.07279495393196422, 0.03755431569692108, 0.11147701617089972, 0.050664872471844, 0.05657836644639892, 0.024527212710029656, 0.07339231865180117, 0.02446459076787916, 0.05973181416911464, 0.037766219447216684, 0.05035635737341739, 0.08943267527126497, 0.018378617842831922, 0.034844340951812845, 0.02833601800845035, 0.05123086206074204, 0.024891500924563697, 0.00015035367288228666, 0.0402462107670163, 0.05724480931436824, 0.034067167735268036, 0.032653141796829245, 0.07079277548097795, 0.02515273499152353, 0.03626614651312271, 0.06169498342299654, 0.13656079558835876, 0.12385855984663773, 0.11337768797191883, 0.15531295790306984, 0.06527123507112265, 0.15300395357753002, 0.09570687408408812, 0.09801067667262209, 0.11429529276586349, 0.10830921962136224, 0.20716517472699766, 0.2396722005740289, 0.16054886243035718, 0.10969436021461602, 0.152004208836344, 0.23102205667284229, 0.12132744364921125, 0.1177226935303019, 0.17120303105442755, 0.13784387028746067, 0.1238131691371241, 0.09242598763516835, 0.15579806009848274, 0.19238520894319783, 0.10852304242190816, 0.1331171537599256, 0.1017412184286983, 0.31709905233114, 0.06812799992340227, 0.1343635022039375, 0.17910895118069264, 0.12379665228147661, 0.1997745559821206, 0.1467962818400514, 0.1292187161743641, 0.12718423179561092, 0.3452492901875127, 0.25433140025744516, 0.25068114451583356, 0.13479169938833485, 0.7108752321331733, 0.7347511283812985, 34.35117660030242, 104.6929628618302, 120.00653143851989, 100.77513479417371, 76.12349325610747, 100.62364501337852, 108.25907984087544, 41.32683346348424, 56.8922221276068, 65.07034824740502, 96.86723032305318, 109.37241323532598, 75.51662414304673, 50.18249803973783, 13.157520140371016, 2.1706891732831157, 0.5347487991375308, 0.1530346124162597, 0.46405350068403833, 0.36993598325117943, 0.5078694092169885, 0.3766320207186284, 0.23166531005934363, 0.2523232539815288, 0.25457346871975933, 0.1696139195513341, 0.27380255141085197, 0.44385623607424, 0.21470750952439926, 1.0298901171453538, 0.4805839620530606, 0.8134927708775768, 2.465959071151672, 3.1313590176643866, 3.5546197766257874, 4.387957472955027, 4.452410840219067, 7.59834538544378, 9.29382372287012, 12.273726790182053, 17.949828870834843, 17.05580303745885, 22.982021916297175, 24.026625579403294, 20.008692741394043, 14.48211141170994, 11.574809455102491, 12.446708217743906, 11.229046640857574, 5.821554843456515, 7.433116032231239, 3.929146557084976, 2.1287560943634283, 3.023273204603503, 3.409890691118856, 1.46622609707617, 1.47225882497526, 1.6515495075333504, 2.1451925414223827, 0.8606760035599432, 0.45206063937756324, 0.8301670729152618, 0.7897730339919368, 0.5818902953497825, 0.47587114236047195, 0.1385035179555416, 0.3379565928011172, 0.2627503847883594, 0.49750108331922566, 0.26158626822213976, 0.1594262218643581, 0.7480905577540399, 4.988900374981665, 34.53983476085048, 80.28168416792347, 90.38261105937343, 82.93395165474185, 84.07951908726847, 106.46016320874615, 65.75870460079562, 21.164544628512477, 36.914257234142674, 47.08952480746854, 77.3765806997976, 92.67731528128348, 94.562712330972, 105.94543057103311, 112.61684879179924, 50.43553013955393, 3.652361809246002, 0.5150522495950423, 0.1606334998242317, 0.11913510685366009, 0.19369627649505294, 0.14656187425698006, 0.31926536511990333, 0.219726289412187, 0.13177916587841126, 0.15423047566606155, 0.15499342262985247, 0.3077863036624847, 0.1261309911346724, 0.08985659002416557, 0.11496511408157888, 0.08441308333027749, 0.18764773654120584, 0.14641251775526232, 0.20141628240385365, 0.13271978395360132, 0.14473187406697582, 0.14958775301854457, 0.1584878560876654, 0.07580253851389693, 0.12001135822145209, 0.18249377277829956, 0.062346403306770715, 0.14238407504895043, 0.1695214833823904, 0.22762523813834115, 0.11369210577780202, 0.1110160687277394, 0.19703698674997977, 0.266139741626478, 0.1407240850911025, 0.12030106969177724, 0.11083694204928414, 0.14153322715672756, 0.14561921838791142, 0.13176447231202357, 0.13916149555194762, 0.18306296078428147, 0.11653520362151247, 0.17045850084433634, 0.0734734703456202], [0.045803914357337265, 0.06118142106119664, 0.07561755126282092, 0.04306524961946472, 0.08254422716075376, 0.0317660387935898, 0.019375482093422644, 0.027407216839492324, 0.060503578804914034, 0.11738567613065244, 0.01883617917736692, 0.06379188481538046, 0.05020778228138244, 0.03202356499499612, 0.05216667293420723, 0.06893969306181516, 0.05513446307891319, 0.023437431570322766, 0.02519729066519968, 0.1052045946820609, 0.048992261215443575, 0.03496558202670948, 0.027495043074351647, 0.015498660636254618, 0.04475942625093364, 0.023977535048259363, 0.032981326202711755, 0.06521403128581663, 0.028792075895433946, 0.021705392958416093, 0.016354983184306372, 0.03282751106927472, 0.019596674659800147, 0.02193216456010217, 0.018657092718527685, 0.009535303913928088, 0.05587765263513692, 0.08219393345737651, 0.25758538935934344, 0.5518805475965624, 13.880665956004975, 51.705672048753314, 104.55641731139153, 91.96778205133255, 80.54791112099925, 70.03227203123032, 65.17786041382821, 30.556789444338893, 26.273725955717026, 58.31750162186162, 77.32779425959434, 79.11484179958221, 69.99680596013224, 33.93466403407435, 10.858244396025135, 0.3927200203461032, 0.421621851743229, 0.053731338571636915, 0.20350154309022814, 0.07529745674541882, 0.10369710984729952, 0.044713928289110624, 0.06293211199883973, 0.08637385472895638, 0.13569660244449494, 0.4881768433317062, 0.5103367945599941, 0.40260742688851975, 0.3109797258530894, 0.45531721785664564, 1.5763753219958276, 1.6421553083965856, 7.279503758876555, 5.568987054209556, 3.29392017856721, 2.985995243633947, 3.6686384197204345, 10.13303247190291, 19.075233359490674, 2.88954857376314, 11.005994196861021, 12.636605847266413, 10.974218095502547, 8.845817465935985, 30.924044885943015, 12.612213607757324, 12.45614936274867, 12.790401001130382, 7.342042028903962, 11.870063908638494, 10.130708467575813, 8.99544608208441, 11.399445187660957, 6.144580168108787, 7.03372412150906, 1.8308283004068562, 7.242917851094277, 3.9812765727120065, 6.87483576997634, 5.48423542130378, 0.37348974255784867, 5.080515665392722, 2.938756423611795, 1.4969679184498326, 1.4278145711268149, 1.184802411064025, 0.386089192282769, 0.5766705399559391, 0.09522839088834102, 0.11612257334373652, 0.12771472470053744, 0.10289480128595907, 0.11959434592074926, 0.24848572038594754, 0.28318170458078384, 0.4064180707979587, 2.2096760619071225, 25.654675922086163, 58.02357489062894, 72.06420883055657, 60.49291872209119, 54.35196184342908, 49.5104391344132, 43.25951468560004, 28.534946864651097, 22.84664130979969, 43.753682336499615, 59.64953853238014, 68.29050433251166, 75.63597402264996, 90.25365921758836, 61.85483232621224, 5.237221217924549, 0.14210658268101756, 0.16726795914432696, 0.03182072214962494, 0.12874839947588984, 0.04872599203560141, 0.024966859078455358, 0.03947017519103904, 0.042665321079473344, 0.03713512387607367, 0.055725932752172795, 0.014792082421932251, 0.1492287029301928, 0.060115865536875306, 0.03852169705374587, 0.0426353172459189, 0.12194114136359385, 0.007934815047549145, 0.1051435987615297, 0.054710935200414354, 0.07876607304018352, 0.05577663245100168, 0.01067476968596419, 0.05817549505961999, 0.07733066941821769, 0.04974340276432134, 0.06836934826306759, 0.10201411426908548, 0.053664788513654665, 0.030238055361194477, 0.02359302402774413, 0.0884858978491637, 0.04210132714961806, 0.007734050215672582, 0.025785473821264122, 0.05529927540450327, 0.027107611343625094, 0.0404205838699014, 0.059942806274780346, 0.049789306752744227, 0.018442480847419753, 0.05510290791731208, 0.021158411926139268, 0.006146543666780476, 0.0551073320750748, 0.005261645081543154, 0.03559437933407965, 0.03204403294911308, 0.06876753778347085, 0.05697365632400878, 0.036088800989091396, 0.027141401566745296, 0.06782392430449687, 0.11023763912699877, 0.06216214383922278, 0.028117767219702085, 0.017451069227630095, 0.035540799144655466, 0.05698206030853814, 0.03816688726205499, 0.045985833426276525, 0.04189845174551011, 0.07859259242973021, 0.05006741582145614, 0.05955045051392048, 0.05709673984036331, 0.0019229576578401332, 0.05566348509502508, 0.04734729807223043, 0.015718725138163615, 0.02860180838333984, 0.032195396601192416, 0.02486528348057501, 0.07258809487065, 0.018899268433151227, 0.01757850603861434, 0.012456636571685874, 0.0629788203795831, 0.046115210354929013, 0.023630133326796275, 0.07305825835153942, 0.04720088717858157, 0.32298089155266363, 2.007839105302288, 25.38089252287342, 75.43199508420884, 120.95069300743842, 106.2166860026698, 100.91018199920656, 103.55725626791678, 88.53236629116921, 36.4303191246525, 31.341877329734068, 32.00365766402214, 43.22019684699274, 54.73737001419068, 69.35221149075416, 34.6533912997092, 10.911799457765396, 0.141351756249224, 0.23823878878066618, 0.03231864099601104, 0.09581393487150631, 0.06183212465276161, 0.3315146513763936, 0.634439820724149, 0.30307109377557234, 0.3877779565030529, 0.5394131101427541, 2.192702740430832, 1.1210549478569338, 0.7514493323622212, 1.400185273058953, 2.275402238292079, 3.4881319249829943, 2.3313906404279896, 3.876873374946656, 1.770720919293742, 6.277759834643334, 5.8015688965397505, 9.399192313994131, 11.538941341061747, 18.661554705712106, 10.343333290469262, 13.60816909420875, 12.652607156384377, 11.634752096668368, 13.904927776705835, 18.326978491198634, 14.683056396822776, 10.116110386386996, 6.921145233415789, 5.5864234605143155, 5.360192916085643, 4.557339635587508, 5.700069233294457, 5.808821849284634, 10.977132416540577, 14.70085709325729, 11.09865725040436, 6.987067038013089, 6.94192006703346, 6.828465509799219, 7.2380614665246785, 3.6473470589806958, 0.3787495183848566, 1.4348964104729316, 0.6635402527547652, 0.3960472321318042, 1.0940283464808618, 0.5057920852015095, 0.20182544996421184, 0.859087688788291, 0.5544324784028916, 0.29725336079155246, 0.06526363547891378, 0.027169589771919196, 0.15112454071640968, 0.2925995911561674, 0.5872553623011035, 0.5240933128422307, 18.33253845091789, 54.988754718534416, 70.24901436221215, 56.44380892476728, 35.5102801322937, 17.344312975483557, 28.804701989696873, 23.425194832586474, 36.652772426605225, 75.34072153029904, 88.77545126022832, 89.78488891355454, 86.42158985137941, 102.75048748139413, 85.98928974520776, 14.094244895442841, 0.048193108936351155, 0.19318085253959705, 0.03735694080410946, 0.06492483309440075, 0.0368577387604502, 0.06231934508128513, 0.036639311771479346, 0.03700150282032067, 0.07622645326679753, 0.02168500544353118, 0.02425566709960901, 0.05834821341258865, 0.03175130500758608, 0.03230821070892196, 0.06057339622789334, 0.042657890026607824, 0.03857376804995922, 0.03539664437994361, 0.025191430092578935, 0.10015047515832609, 0.07954219671627207, 0.059820898703389594, 0.04704520662104891, 0.06291885484731005, 0.04025102179918078, 0.06924831158211155, 0.04771982747760992, 0.010951044931707364, 0.04992730217054487, 0.012588634478649306, 0.0876329661977868, 0.03953287565720178, 0.04010692066062362, 0.026804315219182643, 0.0543210155991537, 0.08563318560200353, 0.034624040877867135, 0.03633806301701454, 0.03969911290633102, 0.045659284618112354, 0.008677310336591497, 0.02074963698584226, 0.03638360311367339, 0.11268862252754551, 0.13172045289989442, 0.16322108436255686, 0.17570905297273592, 0.12487247721442293, 0.19508216019359328, 0.10125443083985199, 0.11429225905768334, 0.1291718775586736, 0.3593365439484197, 0.16831359255217737, 0.19493038285403483, 0.1709158400133733, 0.2023758381725319, 0.12098019897577264, 0.14417331936138292, 0.12018795680975723, 0.10004742867163113, 0.15105429045375318, 0.18618962607316433, 0.19770074064933485, 0.1638019628702633, 0.10827162002603855, 0.18107663269244856, 0.17095754583997114, 0.19442114888900713, 0.1762212746806683, 0.11280289220233118, 0.1338102794702976, 0.18137165315208897, 0.15652595087885857, 0.10979530762039846, 0.07421843722582826, 0.13251278699646074, 0.17722279674583868, 0.143129846321479, 0.22099955818585812, 0.11325516753018865, 0.4842669144272805, 2.126321528227099, 26.806354407341253, 82.56878683643957, 138.30261538105628, 113.58774523581229, 100.02931964012885, 92.96204797683224, 85.03551836936705, 38.30313321082823, 32.407502935778716, 77.79427389944755, 107.19235989355273, 107.06434157586868, 96.08519600283716, 49.24261969904746, 17.880130314057876, 0.8758028692776157, 0.5612267589857501, 0.13065212796772682, 0.4426210878356811, 0.2196375151435214, 0.2917469659399602, 0.28046285853751246, 0.28276528982866195, 0.2946809907594035, 0.512154384125625, 1.994175406232957, 1.1685604890508037, 1.28515453588578, 1.5760741575110344, 1.3096554985930844, 6.834894274511646, 5.620852064701819, 13.39127084901256, 13.212951075646187, 11.70756011239944, 11.64960022895567, 16.608939170837402, 22.90893247050624, 35.12893553703062, 15.152636670297193, 24.29262895737925, 29.772146747958278, 35.993359242716146, 22.40232110023499, 55.9060598188831, 39.151365372442434, 34.729877518069365, 34.36906260828818, 24.001612624814435, 30.01515130842886, 33.58217239379883, 36.27200834212765, 25.29975829585906, 18.565429179899155, 20.19322652970591, 12.24041606149366, 15.353545373485936, 14.133445062944967, 13.183509765132783, 19.903381024637532, 7.724201986866613, 15.635839335380064, 11.668215797793481, 5.833034640358341, 2.789647766659337, 2.67928697889851, 1.418811260692535, 1.1994009825491136, 0.7471176873772376, 0.7777527467377725, 0.4781796410679818, 0.2725818056252695, 0.32331128995264735, 0.5900581409373592, 0.5913495200295603, 0.9608366676876623, 4.076589187306743, 35.16022036152501, 77.85946369171143, 95.24471052231328, 84.8053458429152, 85.04787383540985, 68.30325988031203, 59.80113421716998, 37.71735075981387, 31.5400315484693, 58.8185687218943, 78.48208504338419, 87.88871319063249, 92.50251093218404, 115.67965507507326, 94.64187360578968, 12.908176049109429, 0.23720726671238102, 0.38444556596298374, 0.2605073099895831, 0.23842153139412406, 0.0989705082329531, 0.12783117006502806, 0.12384868497329375, 0.2757591093259473, 0.10792958475048504, 0.1014548087973268, 0.15060798295082586, 0.22136986976669681, 0.19328035203920257, 0.0956455181022325, 0.12247017870146422, 0.19785835557887632, 0.10968829279825573, 0.20861744760505616, 0.14390629175449574, 0.22334628468078954, 0.2692350432757409, 0.12631058512676147, 0.098706292168748, 0.17134719348001867, 0.18157515674829486, 0.1488217723465735, 0.1317162394163109, 0.18011563667847266, 0.17679361896889825, 0.0901149608375084, 0.27664547305433984, 0.10983017994271171, 0.17843159155980234, 0.2168309060676444, 0.20260223247591527, 0.15014898903187246, 0.19480820715187058, 0.18233798113801788, 0.20727584378853922, 0.16300316299161605, 0.1252132178013844, 0.1017119768526285, 0.11338869665539074], [0.02203519380981884, 0.053134808887637434, 0.02948815870519367, 0.035300251366871024, 0.046783411394684546, 0.03661129593608841, 0.05362595934721251, 0.045281660728036396, 0.010200776723063281, 0.06769840845898276, 0.023334779618908803, 0.0023657688073017787, 0.08199239870713604, 0.0034853098294397276, 0.0325097952548775, 0.03862873485852634, 0.10165475008468475, 0.042970155125423785, 0.02328383285672434, 0.07236147074088936, 0.027068291880911397, 0.04281192349510328, 0.10479262323989984, 0.026074595403887575, 0.006753469163912439, 0.024149065964945385, 0.05924409961387996, 0.01959185405153661, 0.06022835788767665, 0.00581565066128068, 0.013125663071179823, 0.056275616159602526, 0.04972194847200186, 0.08072823105800538, 0.012610853901283156, 0.018121503413684906, 0.08604168666586762, 0.047985257791175, 11.771804613451804, 62.25460029417469, 103.9916430750201, 97.9650938895441, 80.07316312482281, 71.83808419012254, 65.16636394685315, 42.72444848091372, 51.287547388384425, 62.74343352163992, 58.36721766379572, 71.31164719981533, 61.740914929297666, 46.73956309595416, 12.269720089051033, 0.9057968049760788, 0.5900370581976829, 0.05625446447201314, 0.156099071365691, 0.10686037881720452, 0.28440018274611045, 0.04844812811502526, 0.039408750261270234, 0.07959407619050435, 0.42461771517992025, 0.12666943603225295, 0.8437110784073031, 0.11360953682132306, 1.543312438072697, 1.0962507369056826, 8.024727125321666, 4.657495887048783, 3.206451323724562, 7.361438639702336, 15.792040863344747, 11.755767022409747, 5.462366736704304, 13.42551019883925, 10.042100164198107, 10.310623665009777, 12.797007253093104, 1.4606164948594187, 10.26850623469199, 4.749212178491778, 7.553896106058552, 6.641441016427933, 14.24580135653096, 9.125794287650816, 8.606085142781659, 15.446097620071905, 3.3923672572258985, 3.6266401313966323, 6.275458874240999, 9.451314730028953, 6.781511306762696, 10.640497938279184, 14.113286041444349, 8.596412577936727, 8.437730150838053, 6.155548095703126, 16.835461931843913, 9.36492060461352, 10.415944207099177, 15.049396945584206, 3.43399586216096, 11.595303839252843, 9.240758957401399, 7.0114578066333655, 2.5857161418084176, 1.0640170665517932, 1.8474862388064786, 0.22473674958511708, 0.07592968612668977, 0.037507760533762556, 0.0309932878195879, 0.168813357670461, 0.043897676927548264, 0.15899027187016704, 0.359742876983458, 0.9853964659475511, 2.356166291621424, 20.593082750997237, 55.56777892574188, 75.88364032007034, 76.15173432134813, 86.82964186514579, 103.51875428230532, 43.58764840710548, 22.659277531408495, 21.577203466046242, 47.46336590859198, 67.22791856335056, 57.82024706563642, 73.77600962115874, 75.60253189456078, 22.440877999028853, 0.6732723273096547, 0.200217553985215, 0.09214321692143718, 0.04346980916095838, 0.05849640929110109, 0.03523166351501019, 0.02675470144998643, 0.06911673598111638, 0.05923497550670178, 0.07172473676262364, 0.02652171687523444, 0.07542956094708174, 0.015521061047160578, 0.0366083771410969, 0.061192088835542245, 0.011944642774910938, 0.0035853309870412155, 0.09251228743983854, 0.03580177465694086, 0.04456464839618533, 0.029155224554180622, 0.02239410600234424, 0.07576635618123316, 0.046652080941825144, 0.04209558532062558, 0.02727356130978273, 0.010638005126477971, 0.0681928645879511, 0.026058067056921222, 0.052079614702492, 0.023958166430313742, 0.05163470531002649, 0.05112396215178794, 0.008221015919961275, 0.018632068456481063, 0.022315392383344235, 0.033986376102773413, 0.05451143058317323, 0.026529779950637492, 0.008612300115337056, 0.04456742546491085, 0.011552153906274227, 0.03237360780457816, 0.018920730386349945, 0.01658353977085602, 0.015282825897297552, 0.08766282830507525, 0.0705052090568408, 0.09137437874150854, 0.08624239404114985, 0.02226068029901193, 0.06811672310915685, 0.06671577812202516, 0.0511620405520643, 0.04580294908655267, 0.02047754170733594, 0.03816819727240551, 0.04387629158314198, 0.0380155848970096, 0.04896791877164956, 0.06530142659621854, 0.07369441010298268, 0.01435388395968344, 0.04056461606054537, 0.15484642567894152, 0.0178412665357633, 0.02755213003124922, 0.02280884302191196, 0.025562659063706958, 0.05340411177565975, 0.027411374781701355, 0.020381328724925558, 0.014098104438744487, 0.08409809095845108, 0.024536733267708652, 0.03279770641858059, 0.04897593971221678, 0.035633135722168995, 0.17888344553930147, 0.09584634805158262, 21.568183975835, 87.05270705684539, 125.29324316209363, 109.23065877729847, 100.3755158762778, 91.74528952567809, 101.35624962468302, 69.21110814617526, 59.10507040639078, 44.22002861576696, 24.725870432392245, 64.37701048389559, 64.42368668894615, 47.76545116978307, 11.520296354447643, 0.5297453869735042, 0.6744471384632973, 0.026198575243113503, 0.25741136482646393, 0.4945401228483647, 0.5099311663258461, 0.06515660533501257, 0.2843434615961967, 0.1520979013894835, 0.18094216893997886, 0.14528606207140032, 0.3929371296638443, 1.1985796137202172, 1.1396265126043752, 0.8505812323381825, 0.9380408941257385, 2.0723766809509647, 1.171719345354265, 0.6252042324312272, 2.1529333389574483, 3.1302860042741223, 1.9208186263999634, 3.1456528700167135, 5.723169542128041, 11.25804570413405, 18.013139847786196, 8.734995799679911, 13.1889549955245, 9.599611701503877, 11.980274665740229, 12.100647303365893, 15.127309926094549, 5.228250267044191, 2.493672822752307, 0.773353931163588, 1.092761420915204, 1.2032940575192053, 0.5169246297690177, 0.3113798382541826, 0.9019390313375382, 6.072935135133806, 6.83559000492096, 7.455162204081013, 4.121416730265464, 3.5760425367662987, 6.2714845326639, 1.1827215936876114, 0.5384512101450275, 4.809281806791983, 10.405565615623228, 19.515994018123997, 17.791518088309996, 13.561462490789353, 4.424182522681452, 1.7277710884809496, 2.291658011174971, 0.34559292658682794, 0.08776552239132505, 0.07399450206468183, 0.05936258277224918, 0.11864904704834185, 0.09875650157130535, 0.14138477463876048, 0.4799951468744586, 1.0100711773960822, 0.7352940702149946, 16.948094752527055, 50.12902828954881, 76.05004295226067, 50.253218373944684, 47.56028375317974, 47.26802795164047, 24.720267326601093, 25.528026511592252, 38.503154477765484, 75.59127469216624, 97.37185893520233, 77.51763697593444, 81.3043402087304, 94.58880393735825, 39.210659842337336, 2.1487577307608823, 0.18603525935642182, 0.0234740735557411, 0.03931598467451911, 0.0663012862505932, 0.02131964662112296, 0.1609854712601631, 0.015794602316623975, 0.030737918155688434, 0.015305114267844588, 0.03600394142971885, 0.019687578652895266, 0.014530066945289653, 0.036950324316539114, 0.029860046511936574, 0.03996084301522182, 0.038597306101432735, 0.03963246325691862, 0.037722793753228845, 0.07437437442281554, 0.012602771673681996, 0.12594720664163753, 0.02227291472316269, 0.04604004180779861, 0.040529284085477554, 0.012905672305233538, 0.011848173153045918, 0.06353754745495897, 0.02890491681624084, 0.039303616184981606, 0.01219557200167929, 0.04543945568824007, 0.03540657287944229, 0.07004991534256166, 0.054925278940748785, 0.008810648897422418, 0.023901971965847958, 0.04412385672631283, 0.01943784931133832, 0.0682232016697526, 0.019134024586228114, 0.06592084698739552, 0.08402152047041925, 0.14160068885933969, 0.11887218547804702, 0.11190518271178009, 0.09590329902787363, 0.19097956017621104, 0.21499817860462975, 0.2025481313467026, 0.0856018755885382, 0.17138807193165825, 0.12362989026211924, 0.2530864154499385, 0.1706659574542315, 0.09575441750066896, 0.08032375195574376, 0.08810866083348952, 0.1565804350520334, 0.16240550715836788, 0.08735875268616984, 0.18487854319955074, 0.11689107444497848, 0.22828015138305005, 0.17124265312187134, 0.09773604181264678, 0.07422602915715787, 0.1278553554607976, 0.09712284205541497, 0.15175683904559384, 0.13476701603541452, 0.15578537368245665, 0.08423886727541686, 0.13250978393179755, 0.12256295960997382, 0.1947105615850418, 0.1487153933774079, 0.18369201090066664, 0.2871525221534314, 0.1898551576079861, 23.629344394130094, 97.23680388542914, 140.26301599317983, 120.4880416008734, 98.58125901991322, 92.35433163181429, 84.08943483906408, 58.63237380981446, 64.28804720601728, 87.04847089705929, 92.22265766512965, 102.89674482037945, 88.17244175941714, 65.46420128114762, 19.26115566684354, 1.6919095934398714, 0.9014196850119099, 0.12952340466360893, 0.5853307042871753, 0.35370922977885894, 0.4044271921438556, 0.16732215220409055, 0.5256981138260134, 0.23423202636261142, 0.9573716826496587, 1.672375699685466, 2.555820081503161, 2.777953955434984, 8.459340449302427, 9.68928002542065, 20.394804977601577, 15.852426732740096, 21.345446302044778, 25.764190458482314, 30.438049493297456, 28.94633093187886, 21.46090519043707, 34.32675592360958, 27.8210303860326, 29.554900392409298, 29.905699529955466, 10.153163056219778, 25.652804951513968, 17.840247654145767, 25.84268689155579, 22.49108825960467, 35.079505828119096, 26.092845855220673, 26.548223226301133, 41.130628662724654, 15.126199895335784, 15.414657861955705, 18.38967169484785, 25.302747141930368, 20.4687318494243, 26.379590726667836, 38.87784281084615, 23.83481187205161, 25.188549295548473, 24.440584682649185, 33.783829289097945, 23.393747229729932, 24.545017788487097, 30.075851948030536, 9.849727519096868, 15.899867799974258, 11.591842347575772, 8.28990190259872, 3.5611762635169493, 2.6202736939153364, 4.473492109006451, 1.5421744604264538, 0.18924663864797164, 0.4034383258511944, 0.111642544788699, 0.39135567903999363, 0.4824054433453468, 0.39859974516495583, 0.8540096290169225, 1.666701868657143, 3.840087671433726, 32.366804422870764, 74.8730416451731, 97.21607808143862, 107.02711043819305, 115.9860392539732, 126.94598090264105, 57.085669502135254, 29.58224323488051, 29.473803427911577, 59.11496654633553, 89.81023526960804, 75.21067142486572, 92.53803191646453, 104.96399864073723, 37.66689338991719, 1.4894782751798632, 0.22683969158078396, 0.2581497510114024, 0.13528475357640174, 0.21029631396935833, 0.1248152734291169, 0.3337378385326555, 0.16317328047608176, 0.15683482220817, 0.17646878236724486, 0.1338233948955613, 0.16412827036073133, 0.09229947587535267, 0.09911457106711404, 0.15402179331548754, 0.13020382863619637, 0.08342075432019849, 0.20610158421820213, 0.08792937327657016, 0.13290983504585682, 0.09654849827770265, 0.23696594901623266, 0.13045692876462014, 0.17640916540497736, 0.17838381831684422, 0.2810135225374853, 0.13642840027328462, 0.17055890432769255, 0.06284396592227202, 0.11842862823076787, 0.19783731880447558, 0.1614531985814533, 0.20879930155652188, 0.2077766201428829, 0.13695784363775484, 0.06362121191716964, 0.09878811035906115, 0.16332812216733733, 0.18784264463090128, 0.12330870789986466, 0.10887591018071098, 0.11592398803200453], [0.04316334717816884, 0.0821148272183153, 0.008226629429226442, 0.014558130661175858, 0.038965802053890886, 0.01703323721284828, 0.06931526000581442, 0.05166288585432115, 0.05186802887868497, 0.06515500421125082, 0.04994877944550207, 0.053785259670187394, 0.024665357514975533, 0.037701929348611066, 0.028164092556483326, 0.06494770847981976, 0.05046816790596612, 0.024873898139283545, 0.014156654623577432, 0.07097870502020083, 0.011633618738532308, 0.05672977606375372, 0.02547430422817988, 0.05681310727771732, 0.025328538763607224, 0.04564839467826871, 0.037285361378904314, 0.07314944579716652, 0.021102407068434744, 0.06405863663061492, 0.002526523739722888, 0.014044990605344216, 0.08272253412513003, 0.06069913423890549, 0.053750762730957045, 0.09720365667054731, 1.1239258776749335, 43.65368543132659, 92.72142625624134, 101.959823946799, 81.88731424270138, 63.71766005792926, 66.19242852733981, 74.89551682626048, 44.3529930422383, 44.21488638847105, 46.19008218088458, 56.457227353126775, 80.15300689205047, 56.09304704973775, 25.375560060624156, 2.3585194685766777, 0.39818057249630656, 0.04835642739048889, 0.39964781473240546, 0.15458393331256606, 0.18435723568883636, 0.10952119370021167, 0.0668859339108871, 0.11280175839220324, 0.44871179326888055, 3.024758802306268, 1.8244607001543047, 4.277541281715516, 6.637706920023888, 11.32042609876202, 12.3362591766542, 10.052112994655486, 6.974610570938357, 17.22496113469524, 10.9924453496933, 10.850830135806914, 14.53605184631963, 9.676706867833293, 14.356217057474199, 4.870873314719047, 6.650767432105157, 6.802468040297109, 13.48321512822182, 8.86406139019997, 8.203627899769815, 5.599127527206175, 4.685090741803569, 10.575649392220283, 7.534254837420679, 7.204493332293726, 4.958335795710164, 2.6396038695689175, 1.6918676731086548, 2.012099902476034, 0.4763905193296171, 0.5690835115890349, 2.120422773784207, 8.952609877432547, 14.778894609020604, 11.278763663384224, 4.793816391498813, 4.640670880194634, 2.4357879546380814, 3.440930122329343, 10.549278316959258, 32.68580490542997, 65.74023808202436, 82.03683499367007, 86.64751052856447, 77.67763830000355, 53.126185863248764, 20.45093213358233, 2.9795037209987645, 0.14323443264490174, 0.2053290305118407, 0.1470657456065378, 0.1332590792087778, 0.048786945821296786, 0.12729242639315705, 0.06985555117529246, 0.21339144707927782, 0.2080018040273459, 0.2092855222403042, 0.5640859216932328, 0.41434355680980994, 15.583117777301421, 53.346179839103456, 77.6694562358241, 71.32878795746835, 59.26971189437374, 72.15487049471948, 43.16190650386196, 23.1032859125445, 30.025743669079198, 49.40346433270363, 74.84532617753553, 75.59004306793213, 85.93387449941328, 49.16526271450905, 4.420900969736038, 0.2976290503096196, 0.05438398802652956, 0.04726946353912354, 0.019955661545898166, 0.07662737772109048, 0.06705333944410086, 0.06907324516965498, 0.06944289791487879, 0.016587783897956534, 0.03183432404072054, 0.08238535584701646, 0.017271394796308973, 0.00443124886406886, 0.03257781620167437, 0.03719013281947663, 0.04943199185354095, 0.013625113135804574, 0.02345924400874684, 0.08944481010398558, 0.055926988697460586, 0.03477876382549444, 0.03116389560032516, 0.02822701710336391, 0.07986096590156518, 0.011419629313862853, 0.017677681866071878, 0.06340882553148174, 0.07726933641899979, 0.054718055987670544, 0.02499128579192104, 0.028231669172284105, 0.028608446535203728, 0.02780949343897162, 0.06337508701929642, 0.022624353727986737, 0.04218334835323115, 0.08520219985756182, 0.06938971609117524, 0.042751038657321085, 0.1099429097807696, 0.030132285431928696, 0.06672032868429538, 0.08754135740380134, 0.025595079904662508, 0.014828121113110215, 0.026094128730736917, 0.06292813600251271, 0.06394234448370915, 0.013798363919880603, 0.023942595693252744, 0.032030900286871104, 0.04097508980081447, 0.03338169141281997, 0.04027660147497251, 0.015796960909820853, 0.08959871716797353, 0.06038179763803079, 0.05672382739102168, 0.04686371273090763, 0.022805273052184813, 0.014675747182580733, 0.05611289908448535, 0.038015056296341845, 0.06707363311321506, 0.06887433810099479, 0.016644351830285405, 0.02394370269030333, 0.04424149718796534, 0.020215853733280977, 0.07264093961566687, 0.07378509193057976, 0.0407059746043336, 0.01622319116347259, 0.03370356708464604, 0.058379128890772986, 0.03263455267334658, 3.5004824880630743, 64.3506129326359, 113.38177373332363, 113.64972652927523, 98.29651063488376, 96.65157841097925, 102.74020302680232, 115.56999344979565, 51.51523705451719, 27.722135666877996, 30.048460075932166, 47.49433302110242, 87.36020518887429, 62.579925598636756, 24.005676200312955, 1.2274074410238576, 0.45267427580491193, 0.07450393521256986, 0.49847527136725767, 0.15865605835232044, 0.09199363059334217, 0.05706861675266297, 0.048898568662304076, 0.15334783512498104, 0.23509772103880686, 2.071551022029692, 3.822002358013584, 8.936813512156087, 13.621586541975699, 18.898320736423617, 21.119447177456273, 19.306466887074134, 14.265060194077032, 21.638800367232292, 17.183415389830067, 17.420991389982163, 19.21354397650688, 14.812463233547827, 16.15701250491604, 7.539600047373003, 2.5101516804387494, 4.176237246682567, 7.69473861302099, 8.501932486411064, 11.782450906692013, 9.079181821115556, 11.837004211641128, 11.959175255990798, 6.836366634215079, 2.1874210238456726, 0.7474913544231846, 0.9739618375897409, 2.0934667750712364, 2.2499551263547715, 1.9622672926033697, 1.5515431641570985, 0.1913345499985641, 0.6659150640330007, 0.7840187943750813, 0.7677195689851238, 2.956709847334893, 2.401749381134587, 1.8277538976361676, 4.6650533137782935, 17.298693849194436, 47.62289262587025, 83.14187649757632, 94.60141043509208, 99.63902811850272, 92.8981682562059, 69.95875112472042, 31.937544153582667, 5.939626030383572, 0.7151080211324077, 0.9310576656172354, 0.4934467315193146, 0.15046234963642013, 0.10820093309326519, 0.023122556026904814, 0.09731120009335781, 0.03245918748659953, 0.16618825014560454, 0.2552330704225648, 0.9130996453665918, 0.23436969236260463, 13.459888792807057, 49.7203722307759, 73.62249589735463, 71.68570795366841, 36.381783716140255, 30.9602189448572, 28.276327348524525, 35.28453988413657, 52.515621877485714, 73.73167114873087, 97.942806982225, 92.67098457582536, 96.63078200432562, 72.73650307809153, 12.411857958762878, 0.03792251670552838, 0.08306798615282582, 0.03654381891171779, 0.04625466900066503, 0.05475360629779678, 0.035167013355080164, 0.14720549536568506, 0.09522542612807405, 0.060653326011473135, 0.06932344182484573, 0.04531635685012706, 0.025473109131018003, 0.017178209776419307, 0.015360595312930886, 0.028123311781054063, 0.08499742455540166, 0.0367878868635143, 0.06274289211198207, 0.07062876371726876, 0.021076764190389265, 0.03446989632662266, 0.02876900515759424, 0.04226847221293757, 0.03857957116598564, 0.12357323039923945, 0.027806519102605603, 0.01627136468737116, 0.034170800279225075, 0.10045793688585682, 0.023058932424793323, 0.05254070770235793, 0.023213155500050035, 0.033056257262585625, 0.046030710856880874, 0.08237203357801323, 0.05808871644999712, 0.037738958208431164, 0.029825986242823066, 0.05234829705929565, 0.06690111777354633, 0.20803039442868004, 0.2003846530832591, 0.27473727060902503, 0.09876981617942934, 0.11024493994491716, 0.17088447637375326, 0.14597710402261826, 0.1449643357867195, 0.1160787760971054, 0.16426677905744122, 0.1473251276559407, 0.1388825935822341, 0.17397908854388422, 0.1375594371629338, 0.14268246629545767, 0.19276007108630674, 0.15609243704426676, 0.09000608442170967, 0.14810189484588562, 0.24869420355366123, 0.1556773399633746, 0.17827782239164078, 0.12696087120040772, 0.2068218754063691, 0.13211098920193412, 0.11188284358790807, 0.2045829834476594, 0.184821822049637, 0.14475238990158806, 0.1815720157878053, 0.12875701030415873, 0.0984151404531252, 0.09277172311539612, 0.11019564984786896, 0.15702370884678057, 0.22599762305617335, 2.8526113687023043, 70.70629996638145, 128.29367591488747, 126.1382079893543, 101.41556370642878, 84.90451905035204, 85.95948757663851, 92.48095358571699, 58.995204817864206, 59.66458866673132, 70.8768367767334, 81.4837964888542, 111.4502731446297, 74.9498494978874, 35.31556190982942, 3.080443220753824, 0.821250054624773, 0.21766954251835424, 0.9865899083595123, 0.35300694165691254, 0.2405351373336969, 0.296063564958111, 0.1479938458050451, 0.28489890598481704, 1.6539553913377947, 6.257186512793265, 5.616983136823101, 8.807850883853051, 10.540207835935778, 16.256111187319604, 16.949053772034183, 15.200819065493924, 14.076998233795168, 24.75759848471611, 16.500032601817963, 16.4670572357793, 19.984556436538696, 13.195395527347443, 18.316293954849243, 11.967884878958426, 20.724007544978974, 21.67553924745129, 35.44019914442493, 22.49303767758031, 22.424268722534183, 18.444335806754328, 20.169223585436423, 28.677891762025897, 22.761445468471898, 19.350691610766997, 13.385542227375893, 6.757933939656904, 4.9364519119262695, 5.405394800247685, 4.344089194651573, 3.174555835223967, 8.021122467133308, 22.092908851562008, 29.469851639962968, 24.624594834543046, 15.245758641150692, 15.430493450933888, 18.680360509503274, 13.163032051055664, 15.246873574872172, 35.590818159041866, 72.99058637311383, 87.89203936053862, 99.04314164192446, 89.78347686029251, 63.197330197980335, 25.938584919898744, 4.443935088572964, 0.5251085938465211, 0.874118211288606, 0.4175814733870568, 0.3053458846144138, 0.24782835565988096, 0.2848445443857101, 0.3431658681121565, 0.5003353022038937, 0.2896819606183037, 0.48727950922423796, 1.0556437868264414, 2.110683528646346, 24.262995450727402, 72.33856293462938, 99.77140026707804, 94.52212364442887, 83.59736565620669, 94.98665778867661, 54.75138856518654, 29.527110399738437, 36.74651707372358, 65.48023200804188, 95.44382572174074, 95.7976862692064, 113.61109902781826, 76.09108663374379, 11.857292671357433, 0.2900955561668642, 0.15569453097639546, 0.10526107834471811, 0.15391254917748515, 0.1838695441162394, 0.21369927652901222, 0.23786961100995543, 0.1758299110036704, 0.11713957038497734, 0.18956071937516814, 0.15965774895683413, 0.1590924220339906, 0.251066624637573, 0.11440298940625884, 0.15064697682617173, 0.16591855655274085, 0.07004363342158257, 0.2042441274369917, 0.2573840001658086, 0.12703149684614715, 0.17911831277512735, 0.20277486272877265, 0.20227158892779581, 0.12831400464018508, 0.19612270677762647, 0.09604330925691514, 0.1308562444342721, 0.2339254226535559, 0.20875264680193317, 0.1554460886625513, 0.17713765373393414, 0.1070565126475788, 0.10759960769885972, 0.13852289998002593, 0.19952081233984043, 0.12273646320306486, 0.14169376854213978, 0.13510228675459662, 0.14681361074889862, 0.21731551796678575], [0.01826876658014953, 0.06691871481316705, 0.018057659561295184, 0.030580791607198697, 0.05879227627789783, 0.12181776290338849, 0.06120190242185228, 0.0186347957294915, 0.05066067814045856, 0.0739166445489372, 0.016781115761747765, 0.024877786035499266, 0.047645670166539575, 0.04882279490571349, 0.018298102001990044, 0.047741415835316145, 0.0229483054980876, 0.01981967327845914, 0.0846819035829075, 0.01783550938501233, 0.035959079320872986, 0.04401483092336886, 0.029956654029627963, 0.02865097973675978, 0.02019093097788432, 0.004913788974179977, 0.021903177708267205, 0.04532956037550204, 0.05229989179379998, 0.12832083048359041, 0.04480684326300698, 0.021751930884596322, 0.04395604133605958, 0.033582532853488965, 0.022051526804364497, 3.2849480019461725, 67.10073963288339, 102.58431234667378, 85.67170327709567, 77.21398276667442, 88.26950473170128, 56.02984197678105, 42.59870513792961, 26.084095047366237, 70.70612738209387, 94.98216275245913, 77.57895931120842, 89.54826016579905, 42.000716270939, 7.995787878190318, 0.7043840772201938, 0.10529749050375917, 0.05290543833266824, 0.19291010174539783, 0.14324667472993174, 0.05408135648336142, 0.11457022640012926, 1.0535885874302158, 1.298604098058516, 0.3480824978361207, 2.6393239103978683, 10.535496088766283, 29.93361503847184, 59.976319036176136, 84.53165069703134, 99.06917049038796, 103.71568079917662, 100.68903092415103, 88.88323799256356, 72.68620260300176, 71.20269160116874, 64.7668509329519, 63.113430699994495, 45.57048105424451, 35.50389843602335, 15.683005836702163, 5.1744191685030545, 5.232889940661769, 12.933075254963292, 7.25646375648437, 10.382304979908852, 7.085547947114514, 8.700032772556428, 7.9705778245003, 10.085144254469103, 2.3131415680531533, 0.922178277565587, 4.427897007234635, 9.923543583962227, 14.577930012056905, 17.987103154582364, 18.172701866396014, 8.770964914752591, 3.4128562481172624, 2.5392098244159453, 2.7190840821112356, 2.9244549716672594, 3.724247822838445, 10.727317640858313, 26.221374081027125, 74.49767081968247, 103.1038930339198, 109.26530115066036, 103.9137291139172, 97.49329551573723, 96.4228100930491, 100.4609529433712, 90.58349132537843, 54.487001203721576, 30.442475888036913, 33.29035197534869, 34.2321091313516, 19.928323376563288, 2.885268777608872, 0.13407959001919917, 0.018020726462465622, 0.13166855810390365, 0.10533988580948885, 0.11291464144784598, 0.1140664776246394, 0.15132568476180877, 0.5084388576928647, 0.3614050119874939, 23.025305271148685, 67.31235934842017, 75.98755959541568, 65.65948040254655, 70.20337366288709, 54.688964043894124, 33.844174954199026, 34.43419356499949, 44.81440497982887, 57.51071714585828, 61.353600486632324, 86.51660534643358, 81.20275082126741, 20.69232656109718, 0.2579556856184237, 0.144963278585384, 0.022977999066032713, 0.07001381727956957, 0.04983563975040471, 0.04499797836967534, 0.07750299323590533, 0.08850446015956903, 0.05767054735652863, 0.023505931322072304, 0.02685276070429433, 0.0026922515403824832, 0.022034586685138847, 0.007577472856463565, 0.055979097998070146, 0.025402211524065466, 0.0031737330127432346, 0.03963795993777533, 0.10566209472956196, 0.019700314864636432, 0.013936731847934427, 0.08037812121572994, 0.010537640905127892, 0.05335675988105997, 0.017578845032520832, 0.0516439251781952, 0.04870703518991509, 0.05586714573925542, 0.019916058630652485, 0.02870669156583327, 0.04982618239497946, 0.03704121298787575, 0.04120649431922263, 0.05227384480437445, 0.00463875335445928, 0.08417230955655537, 0.022563733190538424, 0.053386242774825905, 0.09086541290725432, 0.004006138295798953, 0.07109601606404589, 0.0375130120664835, 0.026113248370107145, 0.03531848808990852, 0.1476728702865301, 0.05967961293795417, 0.05344690927754968, 0.07476776057193357, 0.014617296589177944, 0.0232016411985481, 0.0982651251157926, 0.0052330187698375556, 0.06110052217639262, 0.04020258972060777, 0.022364954441605557, 0.010887728722375489, 0.05099198435463252, 0.012774731599605613, 0.05561721721483816, 0.020916399005199635, 0.04486111293156301, 0.03468926943417999, 0.055199886987646746, 0.03295105040794419, 0.07814901986069257, 0.05397302398998892, 0.032722304214633284, 0.11917759408994068, 0.013603600429280872, 0.023868143438331546, 0.06322786407244783, 0.06833328084359247, 0.012310152899684205, 0.14065317599283111, 8.016415132630257, 93.34520078474476, 114.30049480930452, 101.77763769703527, 103.46938733131655, 116.41792358890658, 81.32934139620873, 58.88059708379931, 28.315935442524573, 49.623524988851244, 66.16047689991613, 68.69775618276289, 93.79283735829016, 42.8345258774296, 6.414726549579251, 0.568280651444389, 0.09106869433796214, 0.10461772536678661, 0.1955760570783769, 0.2418519811885011, 0.23749096439250056, 0.0676080177447969, 0.6087243941522414, 0.9119905339133356, 0.9898542396483884, 5.950933733294088, 17.602065647802046, 42.59454350317679, 75.76645558880222, 98.35595023247504, 111.95223454506167, 116.12920576526274, 112.31655213140674, 103.9322897695726, 87.63839537097563, 86.14183072120913, 80.81347127114573, 75.47629433293497, 56.70261083110687, 42.983572021607436, 21.666154976814024, 6.574686688761558, 2.8228248896137362, 3.3562628203822724, 3.5231743801024655, 7.51713663339615, 7.752193001008804, 8.12658715632654, 4.385445194859659, 1.5819235146045687, 0.8114142211214189, 1.444876513654186, 7.40232934874873, 16.333482880746168, 22.385782426403416, 30.02118979730914, 29.29925011050317, 15.88397631722112, 5.540258144178699, 0.8388576969023674, 1.1322084525900504, 3.6025668296121784, 8.006395438025075, 16.567701332030758, 39.99669498012912, 89.53730890827795, 109.12582951207315, 113.87284663415726, 108.78865472732052, 103.40069094011861, 104.64644355158653, 108.41661791647635, 104.30453054366573, 72.03985875652683, 43.67052024410617, 48.67996354256907, 53.241762422746234, 32.72761344909668, 6.834133334698216, 0.17995837414937635, 0.18664020834670914, 0.3155995731151873, 0.22040269908405122, 0.03270592142437254, 0.10653503659752109, 0.2904563222921664, 0.9858718694698427, 0.4101435257302177, 20.170653289364232, 71.36198689860683, 75.18812564111526, 58.329504074588904, 35.79210635154478, 26.616011588804184, 33.96069680490802, 51.1435571793587, 76.33384212370842, 84.17610353039157, 81.25720900873985, 97.76413517613565, 103.51759326073432, 38.26675714985017, 0.5947521761540444, 0.3218917903159896, 0.06291138549004832, 0.13010109624555036, 0.03723625514295794, 0.042922335917190205, 0.030910579052062768, 0.07262915718339144, 0.004892375859086432, 0.03233163001676721, 0.07113634293238003, 0.02381128247737164, 0.027659267427459843, 0.012610479475810163, 0.07500695620453166, 0.08821152345908266, 0.03857887019553492, 0.05758139770478011, 0.04150902627096061, 0.05357836613491659, 0.07002302565641942, 0.04499320181146745, 0.06053254075889146, 0.04402305104679639, 0.03511164818079241, 0.012964940697495497, 0.03822411786043837, 0.06502571155227001, 0.0620575038896453, 0.03240754933006341, 0.035904127834064346, 0.019787570363992167, 0.04971121174974307, 0.06322622081385025, 0.04356247515627935, 0.015388534539529394, 0.03884729591288394, 0.04268593267507611, 0.08727960814271243, 0.14402074529038322, 0.1596107418018003, 0.12789996476062845, 0.19956090938179724, 0.16040172758361987, 0.3933874974327703, 0.11633667959681443, 0.12530439758613227, 0.1308161014270398, 0.12622404017395553, 0.13224306276008008, 0.2960381921260588, 0.08531754971632073, 0.12861013592731568, 0.12780140754916977, 0.09820819712213932, 0.12443913958005368, 0.14130686349686117, 0.2014008840365756, 0.1264173471398892, 0.19444348801287914, 0.18504263923293163, 0.10545307530030128, 0.20765761604472516, 0.12124528071933216, 0.08915571150399985, 0.1669296547169647, 0.1118636301027671, 0.20421811109108312, 0.22467855754638874, 0.19202565323681603, 0.11975460385362949, 0.14024759372395856, 0.10514029692257605, 0.25387134913715625, 9.057100838230504, 102.63531884839459, 131.0503412062122, 108.12320893810643, 100.47646983977288, 112.67588830763295, 72.62334269862022, 53.86326589891988, 33.34316668971893, 93.61185135379915, 129.9360272192186, 104.55034548236479, 117.60222050451465, 54.77659371591384, 13.168122306946787, 1.0912965382299116, 0.19343899352656257, 0.15032520457621545, 0.35577267228114995, 0.317156539568978, 0.21268008847630795, 0.1842480375161094, 3.56933577406791, 3.5973177177290765, 1.9019168471136403, 5.332422535265646, 15.295919872099354, 35.50964863069596, 68.16428246036654, 94.12913353212419, 108.08827630935177, 116.25465100811375, 110.72911400948803, 98.64608010938092, 82.8496991434405, 85.30970773389264, 78.26579770734234, 74.81360989232218, 54.46171760559083, 42.268653377409905, 20.3879722087614, 7.755888854303668, 12.273732673737312, 26.661689550645892, 25.86488162317584, 26.593187316771477, 18.36403900577176, 19.101628949565274, 20.45924363597747, 24.139936970126247, 6.0888491715154345, 2.1759382851662177, 7.330731874512089, 16.639465016703454, 22.109449486578665, 31.760568772592855, 29.268604632346864, 13.717105081004481, 7.866151092513916, 9.592435725273626, 14.348403696090946, 7.938160415618651, 10.11853833352366, 15.132732602857775, 31.66002469678079, 84.50117388079244, 113.73506945948448, 122.48468491338916, 120.65167503972208, 113.79570930234848, 111.58200986923711, 115.15103724695022, 103.64445055684736, 63.475700809109604, 36.99491685436618, 37.13468659308649, 42.663349720739554, 24.36091938326436, 3.7242912140584763, 0.27617046789776895, 0.22660525335419565, 0.32945231204071357, 0.27238372593156757, 0.33779075008726894, 0.24296844708583049, 0.672729998346298, 1.3086345791816711, 1.8701047089792069, 34.15594846971574, 87.50826681813886, 97.30129549580236, 94.71468064092821, 103.1884514900946, 68.78289514972319, 45.60497829991002, 43.63477568472586, 57.47441168754332, 77.50672494211506, 79.49722582294096, 109.00597756908788, 116.33532631781794, 38.35682653611706, 0.6612016008265558, 0.45238910723597775, 0.15531171684063252, 0.2550522889941931, 0.20388683935086574, 0.14835401438176632, 0.14940494911805277, 0.15138003103915723, 0.19755732898990955, 0.09384592394194297, 0.14461498437148912, 0.0777113844730681, 0.10546421421872032, 0.08321616287914016, 0.15488102220960204, 0.21287390872115092, 0.1801423118599961, 0.21264487907530802, 0.19965406567338975, 0.11040570349582743, 0.2456699488984962, 0.18844846696142228, 0.15446483728385743, 0.16530289765327208, 0.10318081255160994, 0.232566214136539, 0.13480150531376564, 0.10851980186998846, 0.1932701017827757, 0.10575603243083724, 0.21984647328574813, 0.07759215820941233, 0.09820660365925682, 0.1661878824234009, 0.1642534797710757, 0.18740648013209144, 0.20942714125398668, 0.24022165415508134, 0.23779759874507306], [0.07320780637523822, 0.0718286948939485, 0.029669960945724484, 0.05419508223572085, 0.06299195878748452, 0.06787413370705421, 0.024551727523606633, 0.040496878566280495, 0.1291264179012468, 0.02245848611628096, 0.030468077090899312, 0.012394425444184773, 0.04935397345933223, 0.04957071888530928, 0.05366115725689358, 0.053748169523333354, 0.05767531242341765, 0.04516409687517632, 0.12502810031536127, 0.07884060573433677, 0.0639240809475943, 0.12247210924303341, 0.03159398119145584, 0.10205257188288436, 0.11377156441730839, 0.03286062905024136, 0.010123495688481678, 0.058867011985351006, 0.08021822334417412, 0.12247095245026773, 0.05782291458378877, 0.025585461670773166, 0.036323710359753146, 0.07290796722255408, 2.8808087975748125, 74.3972110748291, 95.31195563654747, 85.59094951998803, 69.2114297805294, 62.84161829179334, 41.560873446925996, 39.79408887124831, 55.33260145495015, 78.14753824664702, 69.48500725530809, 72.77125527781826, 80.29499669228831, 23.718478295110888, 1.4302906898721572, 0.2607676879532876, 0.14181461125131578, 0.24791579693555835, 0.2443705412048486, 0.03655618357081567, 0.05667660956180865, 0.4815159539782232, 0.22225739794873425, 1.5623342173714794, 1.1112854269243058, 4.828876497284059, 25.753080344969227, 56.46183613807925, 97.97456249114006, 109.4002228398477, 111.92235392908897, 104.46313550395351, 105.29867879806027, 105.02757241649013, 112.4233582711989, 111.96680222788166, 101.82532587359029, 101.75447217879757, 94.41488604391776, 84.56003296759822, 71.01430800653273, 45.79535838096373, 23.351164017954183, 10.52983218623746, 3.1945819864349985, 5.317513115944402, 7.918961884513979, 5.535078164069883, 6.234869207105329, 5.306800632707534, 2.028216798940013, 1.0818182532825777, 11.045610135601414, 27.33155977341437, 38.10194307757963, 44.90372911576302, 50.73768600340813, 46.69739369423159, 54.36012821812784, 40.00637146734422, 11.281582866945575, 3.3311299883550216, 12.98805315648356, 28.128907026783114, 42.75010862658101, 83.47698811561831, 99.35227147994503, 99.54534622930713, 97.76741427759971, 97.36063311176916, 92.4389999143539, 97.16598941433816, 99.94481609713648, 105.90346905492969, 110.73392283531928, 101.94134173854705, 112.11001580761327, 104.1494635612734, 96.05452306808965, 65.71859052104335, 12.445050035753559, 0.04994134073175731, 0.23618417161126293, 0.18603813984701711, 0.2233414123615911, 0.2206841291439149, 0.02677095400530004, 0.09880260474258855, 0.10434198734020034, 0.2233912693637033, 6.790820071774145, 51.545188273153, 79.39205923388081, 72.04225140233194, 79.7258686250256, 78.42195510864258, 34.88418748301845, 27.315864409169844, 40.31972177567021, 50.95045889577558, 60.08106593162783, 64.68476749235585, 81.30549338556106, 32.65483387054936, 0.7783098458763092, 0.1902287480451407, 0.1141405736486758, 0.00511370201204573, 0.011412495120067992, 0.040845682228645014, 0.0998070456027504, 0.02524214128272668, 0.014197484237111866, 0.148759474076571, 0.06325759594478915, 0.06449130393805043, 0.0262714704243286, 0.06665063766582359, 0.11749591618295639, 0.12011370756813597, 0.15943383677832543, 0.06617866621743287, 0.08065968917142, 0.0759443873539567, 0.07011905477772798, 0.07798400452180256, 0.07783065670199933, 0.04915031281510188, 0.0394455952599885, 0.04829581834435944, 0.033573355120156086, 0.08053562123208277, 0.06325897107261323, 0.014553113742881726, 0.06601302268644495, 0.015504148698622182, 0.045395290719405304, 0.014169420521225662, 0.0674015723709618, 0.05703769361359939, 0.01472677725682696, 0.030501660470279957, 0.06381533093630307, 0.09126698087540366, 0.043213568072045044, 0.03739577763143086, 0.04459783915550478, 0.06928490760225443, 0.0871492736041546, 0.0831424345773074, 0.06474674829552252, 0.040206190333851886, 0.06450957513504452, 0.02898173053718863, 0.056718131527304656, 0.0553751104481278, 0.05646076811958225, 0.07061851346084187, 0.011076216995265457, 0.029023602987909992, 0.05351352062256587, 0.06661184297333803, 0.06064093070885828, 0.05137968230091276, 0.07400910370051861, 0.12167462703561592, 0.2388009440995032, 0.1546981570220763, 0.05764875215508285, 0.026255734978363882, 0.024497877288189147, 0.034580971414764086, 0.02441891086017413, 0.013082449008981067, 0.04427253907065719, 0.12733849126004404, 9.610896360489631, 105.93109038568313, 110.89091177909606, 108.3216965583063, 95.16842042246174, 92.83434344876198, 74.3773481922765, 50.5860314830657, 31.435276808277255, 37.725983896563136, 55.215283363096184, 83.55819686766594, 85.38663325771209, 22.90871674014676, 0.6421972883324469, 0.433669105292328, 0.055632646225633166, 0.4317681040735014, 0.30065960220752225, 0.2936850458143219, 0.43022737868370553, 0.2496098011972443, 0.3691000587517216, 0.877230366872203, 0.7684968724366158, 6.2222813406298245, 30.855891743013938, 65.8545006475141, 103.34324390657487, 111.76532576161047, 114.51245969341649, 105.46287705821376, 107.60155723940943, 107.7560672452373, 113.39916552266767, 116.88514847909252, 107.31906029485889, 108.35541325230753, 103.20389778383317, 95.52201424875568, 81.83508396148682, 52.36832118803456, 29.030893310423824, 11.934052475037115, 2.897774519458894, 1.8416631125634717, 1.773160510966855, 3.2230583938860127, 3.6646341700707716, 3.2941216903348125, 0.5355184417097799, 1.5301416093303313, 15.986480597526798, 35.82779599774268, 47.645595304427616, 59.144231350191184, 63.76424212609569, 62.29843278085033, 74.72235987263342, 60.214238243718306, 19.691853484799786, 6.251165184282488, 19.46352251114384, 37.36817352233395, 56.06041685227425, 96.10547465662803, 106.22183999707623, 106.82519466646256, 104.89133281092491, 105.10594137253301, 100.58438993269398, 101.679319566296, 105.17431612937682, 112.22738881264965, 115.57052689213907, 109.90438861231651, 118.03111599337672, 111.53505909827449, 107.41754316514539, 82.27856282264956, 18.79366601667097, 0.434760412862224, 0.22382982405683688, 0.17092753051509782, 0.5328200348923283, 0.44252716545616433, 0.0662127647909426, 0.11765654949891953, 0.25724193682113006, 0.4678278013823494, 5.549624273853918, 50.09159318862423, 83.26236386452952, 71.83827246389082, 47.66466194583524, 33.31820080357213, 18.58105198029549, 38.59357295497772, 63.487628736803615, 83.52671592466294, 79.8005662425872, 73.58338986673664, 95.42488067380845, 55.48557781404065, 3.101368085030587, 0.1858278640335606, 0.15078396866879157, 0.12075588843154332, 0.02572371564324825, 0.024888892395181522, 0.10778848667659106, 0.056225142456711306, 0.01573673395004364, 0.20623195706115616, 0.057295796296168724, 0.03464244614024797, 0.06816831913085715, 0.020092325885930372, 0.05778248429358487, 0.10181766634266223, 0.07471912931050025, 0.1171094248251569, 0.04623363222626429, 0.046248888867276336, 0.04866724075268834, 0.0852964593157653, 0.048487053042457956, 0.06133930029107198, 0.014306741781652936, 0.07361763277121129, 0.04494593035609973, 0.029958904412905538, 0.08238010814473515, 0.06246946767092713, 0.017349269549031893, 0.0025605346919262725, 0.04670688687192817, 0.07686564638730019, 0.0449144096684552, 0.03920873236511985, 0.09059024944661126, 0.04268017552432515, 0.3253981441019043, 0.2013150821890562, 0.13741817054969652, 0.22630309295510093, 0.12719375426850973, 0.197449846854133, 0.14867915741858945, 0.14375756344487592, 0.13130978380720462, 0.13708709799233945, 0.1376943758899166, 0.07849634880380285, 0.09762148868532912, 0.1731702835569459, 0.1669371164133472, 0.17284457361505878, 0.12198119244027524, 0.17452226020395759, 0.18542577512562278, 0.1694405691758279, 0.1903076704231001, 0.20453726332033836, 0.2035611753742541, 0.14926535257649037, 0.292911940524655, 0.18117320573618337, 0.1447330691641377, 0.2201664682117201, 0.15986249361547733, 0.1807668880229035, 0.1060295488024431, 0.09540348028343532, 0.1675931021811501, 0.32665094300623865, 8.788020360854365, 124.46549753988944, 122.30081988919167, 112.53957809940462, 93.0047155195667, 82.76310889951645, 54.60623341221964, 56.66536400395056, 77.0641403813516, 106.86029203476446, 99.94833838555121, 98.5891116049982, 103.23046007464009, 31.594887856514227, 2.9555865785767956, 0.6438352456015926, 0.1706873466290774, 0.6355697697689456, 0.5485860630869865, 0.20636976095697573, 0.23314367589210314, 1.1910058846396785, 1.0555051555556636, 3.961657367406353, 1.7906947313777863, 6.167888852857775, 30.041758706492764, 64.92056077526462, 107.66582135231265, 120.88387150918285, 125.47496657217704, 114.51955133868803, 115.61094299439462, 114.60512176636728, 122.72616171067762, 122.08943551586522, 113.5994338989258, 114.67317488885696, 107.06215289331253, 98.01116604958811, 81.8727622493621, 52.195713366231615, 30.478183184900594, 15.907061426870285, 10.25167828606021, 12.497690204651127, 17.742892465283795, 16.291326226726657, 17.430673760752526, 17.643709451921527, 7.732359045936216, 2.341378220627385, 16.686947268824426, 38.451037945285925, 55.67864471866239, 68.99609165806925, 77.4622295748803, 79.00472517936461, 90.21033271666496, 68.60263086134388, 16.851027857872747, 4.047375374263333, 18.21690501705293, 34.54203521051715, 55.693934117594075, 98.8395941642023, 113.48701876978721, 115.12780897078977, 113.27033919672813, 111.53736545193581, 108.55878814574211, 108.94069363993984, 113.1787596979449, 116.99373537494291, 122.21018175924979, 112.57353798035653, 123.47848799920853, 120.43082206479966, 112.45567075667844, 78.74955931017476, 14.261720295875305, 0.5830910922058168, 0.44736105768430623, 0.3248556619209628, 0.5141916570644225, 0.5201176229503848, 0.31086542553478674, 0.3283568063089925, 0.455657514112611, 0.47567051925486137, 11.705181194889931, 69.19354377254363, 94.76529490563178, 94.06683060430711, 116.99193108466365, 99.68760275071668, 45.9702294103561, 33.86082149321033, 49.63653156834264, 66.83878806329542, 76.91819683198007, 80.05035846464096, 109.26614053787725, 60.74873962709981, 2.3860868667402575, 0.3766936448312575, 0.38257425831210234, 0.21003078789480273, 0.20630608372870954, 0.10179672915969165, 0.1941459394630886, 0.12962082040406045, 0.12755250558257103, 0.25841864787282487, 0.13536946757906868, 0.15170027111326495, 0.20573326446596654, 0.1342220364078399, 0.18808256804702744, 0.1453071448110765, 0.2661586486764493, 0.16716490499675277, 0.22156978807141706, 0.08729892121928354, 0.12690967354442806, 0.33591447818663817, 0.12550187207037403, 0.18078414032295828, 0.16406607934303824, 0.11664896001738888, 0.18265607616593763, 0.17256669820316378, 0.14780707356910552, 0.15071724241058673, 0.2076467222744419, 0.07843791161693874, 0.11427628612446208, 0.18040400749493032, 0.10855710269102167, 0.2858428182380815, 0.21634197343261014, 0.10238198969032496], [0.07041972130537033, 0.06194933610517652, 0.06196817420723458, 0.03495519387445623, 0.02328678229523282, 0.1800611831488148, 0.004062169248373398, 0.03043215139769018, 0.029935709185778137, 0.040435541736622976, 0.1380741563174994, 0.04383059060801903, 0.05627494583266878, 0.05025376670903737, 0.03848558749943491, 0.018478544436455257, 0.037843805001748186, 0.029271892084169294, 0.04284501466299257, 0.07370462971589259, 0.043691832932733723, 0.048631797694871505, 0.018032510809960867, 0.10018936944224181, 0.11381617371713924, 0.16205820885877456, 0.1396497080643331, 0.06350330715518325, 0.12382442296873178, 0.039745239060251944, 0.058035546117612434, 0.09716178996548538, 0.045707333652723225, 3.551580184890378, 80.73867951670002, 96.19601864968577, 82.01666616624402, 67.77410860984557, 60.40301015300136, 36.82210899168445, 27.76831373091667, 48.80001552643315, 68.5562135327247, 75.5294502935102, 105.59627686777424, 65.03296021492251, 9.466478613115127, 0.3437778497895887, 0.07171020407470004, 0.1622016051964414, 0.3298964591756944, 0.19908006663524336, 0.1718083784104355, 0.44210250759797715, 0.7247994623837933, 0.8787520013509259, 0.30857693704385913, 4.17302776728907, 18.319967254515618, 43.911349850316206, 79.3866071393413, 105.52322664568501, 110.2788180689658, 98.75015627953314, 98.38779987827425, 95.90612411499025, 93.81538314204063, 97.92492097423923, 99.67509823460733, 99.78018637626403, 98.10436940962269, 93.84057260328724, 98.13032765542307, 100.18258233224192, 105.832638894358, 77.74216128933814, 60.2246246799346, 30.182612980565718, 10.619848620507026, 2.2876660189320965, 1.0329970020440318, 3.60318043539601, 3.9416314613434578, 1.3830356900730443, 0.733742282515572, 8.093991769898324, 32.764420970793694, 47.796492807326786, 61.60616190202775, 73.13827145484187, 80.52729514337356, 82.56005564043599, 75.13336935350972, 72.16050301828693, 76.70508661577779, 65.16527352794525, 63.420058065845126, 66.45349364126882, 85.68390969307193, 98.7261199951172, 99.21803228316769, 104.2375207716419, 103.08067260249969, 95.28655436731155, 93.18873743857108, 92.1889566606091, 99.98294153521138, 104.79154771374118, 104.12773363051876, 104.56986319634223, 104.29027665045955, 95.15575116680515, 91.10049109305106, 98.80754839989447, 75.9350625930294, 12.030397653579714, 0.33217443694030085, 0.0662061074868806, 0.03268768087089543, 0.03587264545081604, 0.041937859308335095, 0.1662256658798264, 0.04747798884167306, 0.05816008137058347, 0.18481411520511876, 0.6358752243461148, 25.574961593074185, 82.80703944544639, 96.7392590738112, 74.54043249930106, 88.52401948744252, 58.74537337210871, 29.00404468659432, 21.44131883498161, 46.29376219164941, 59.42732449500792, 58.20503942428097, 79.60065872438493, 54.47219817869125, 4.593764726192721, 0.9880736061642248, 0.020100019323909958, 0.049039804632024425, 0.044896904559385394, 0.07117473159826572, 0.1028901358105002, 0.028293532687389565, 0.11835635549599126, 0.13048265399711748, 0.05574624557348509, 0.07410587592711372, 0.01671254323164542, 0.07741007443156935, 0.06268466176885752, 0.05275676747964275, 0.02802089923211644, 0.05626361156182905, 0.08547353287858349, 0.005403016553065109, 0.08102888992476849, 0.1085518626496196, 0.09785761996623009, 0.07714533742757575, 0.06427114559037071, 0.04098814393904421, 0.02572515971898552, 0.09052440418951935, 0.030792411904962316, 0.01858421285907107, 0.024710284741294962, 0.09140419488352153, 0.09466569164707776, 0.03459115272327777, 0.027090834018083352, 0.042981347669997526, 0.03414668383136873, 0.07893313383383137, 0.01716661312046551, 0.07696363669369491, 0.06252207492868747, 0.07130624591222695, 0.08001802158692191, 0.05030360838939106, 0.04845613373383399, 0.04139818867007571, 0.06436666143276999, 0.07729595031348929, 0.013778170799806476, 0.0869901494814023, 0.07232371792798081, 0.055354395430655255, 0.006163358339108528, 0.05702407257030568, 0.0636392456269072, 0.028266323159538934, 0.09422122275516873, 0.04482510296868221, 0.08176311625227814, 0.03720179267768418, 0.09726536505284811, 0.12418307469136293, 0.1671788171534577, 0.17733792443909954, 0.19355733878910544, 0.08108216367902295, 0.09977534488444367, 0.04411845963688628, 0.03710000257518503, 0.1791616120646077, 12.548127962696938, 109.71326720330023, 104.08642322786393, 101.84234896013814, 99.32888630897769, 92.94402076352029, 61.766782960584095, 28.44682493517476, 21.10508934144051, 46.36561609083607, 71.05058993062666, 118.28501885937108, 67.06370461371638, 7.626032415897616, 0.479666770946595, 0.029467983779707746, 0.212815793291215, 0.4417436720142442, 0.20313959718952257, 0.4157448541973868, 0.5530124578264453, 0.44312719616197777, 0.38571108192686115, 3.591381455621412, 9.426685187124438, 31.357078475336877, 58.89190135463592, 96.14588291414323, 112.48049151512885, 113.23362581191526, 103.81359100341798, 103.4020245459772, 101.6907258187571, 99.13664310209214, 102.19563684155865, 102.79901504516603, 104.93873857682752, 104.65435104985391, 97.63911354926326, 103.79821531234249, 107.38475215050482, 112.42502135615196, 87.21814478597334, 69.58954626514067, 38.3375245524991, 14.558605474810447, 3.11373409244322, 0.5802504381825847, 0.9995202467806878, 1.8587496924784876, 0.5449997297217769, 1.4953424637356114, 13.201878224649738, 42.69882363657798, 58.499460374155355, 79.56632229589647, 90.2683759504749, 98.70014605983611, 101.15269430222051, 90.89032265447801, 92.17722092905353, 100.36985197374898, 83.25424455827283, 79.1349635585662, 75.91496436826645, 97.24002022897044, 105.04487006895005, 105.80090691966396, 107.41029462506695, 108.99075092807894, 101.38518887181436, 96.16321979030486, 96.63451610072967, 103.40650389271399, 109.20909358609109, 110.58437070538922, 110.7741035953645, 109.68340227680822, 101.25167923588907, 97.68641733354139, 102.55949158822338, 91.28321078515823, 18.661038914034446, 0.15331490866599545, 0.18810965691603002, 0.06611750175755832, 0.11185125012191073, 0.1774083585628579, 0.15582196204172027, 0.10022680049822216, 0.04201497371879317, 0.4484989127564815, 0.2933377628364871, 21.9520055478619, 84.67955543148904, 97.35547911736273, 58.694657125780665, 47.19955905791252, 18.991273064767164, 26.907637849930797, 35.69745563691662, 76.24357269656274, 94.99367098654471, 74.45985917122134, 89.36181422202819, 79.77488256269886, 10.938923628099504, 0.9694620209836191, 0.041388417218601516, 0.019996651080286792, 0.03286835504695773, 0.09573917235097579, 0.19037396767206732, 0.10726353258735712, 0.07961531214776539, 0.17669522263590368, 0.05077950603839371, 0.07728794469468056, 0.04806926316251198, 0.12083664942052096, 0.09419362826813614, 0.12505869786705703, 0.06364436309424139, 0.07755805197502337, 0.10406944390025832, 0.0906567458784388, 0.053340568612780304, 0.08701072660304847, 0.03852872974089077, 0.10386468391985663, 0.008985631997817227, 0.08437326207997338, 0.022803150988634557, 0.0669005202249654, 0.023735501059901812, 0.0645986098736044, 0.03950602427545575, 0.1421790239551375, 0.034134005076221885, 0.06141230847025591, 0.03899280282278215, 0.026088402223502918, 0.01816417451106733, 0.1336188494197784, 0.15555680368936833, 0.19940524031558346, 0.15832930653085633, 0.13686476395495478, 0.2707141139093907, 0.152634484693408, 0.12447981884883297, 0.1292823780808718, 0.24958502591377307, 0.2556874218486971, 0.1733354061481453, 0.22798117790972033, 0.16021529242636698, 0.1376849070431725, 0.12372739027224242, 0.11856400362786748, 0.1247338229610074, 0.15396609872339234, 0.19762097557465877, 0.15211101681474717, 0.17091803102483674, 0.10765858880815007, 0.26707571720884693, 0.2794495387183082, 0.24331540830673712, 0.1709886490096969, 0.25468796822092227, 0.34921477578820725, 0.22267995672600888, 0.14085441196878112, 0.16558020616010313, 0.2869760154956772, 12.32712789889305, 125.81254928342759, 120.38475774949598, 108.13912591626568, 90.90200347285118, 77.49684841402116, 51.56456085943407, 38.07813821300384, 68.30783336393296, 101.99781602428806, 112.95651820398147, 135.9634236366518, 83.13650285044025, 12.834389402020363, 0.559408372688678, 0.1256567290833881, 0.6215585119301273, 0.5831351575832213, 0.351568044674012, 0.5070158646952722, 1.021428584091125, 2.043828199948034, 3.325057423883869, 3.58843011721488, 5.6597193210355705, 25.511854579371793, 52.578607297712765, 96.32999897003175, 115.29600804851903, 118.05577985702024, 106.7320619090911, 107.13033937638806, 105.79021453857423, 104.04478334611463, 106.13967418670656, 109.27228296956709, 111.09862481394123, 110.49434446519422, 103.56408119201662, 109.89627715080016, 113.97240423387098, 116.71537260855399, 87.49005917579898, 69.8556084786692, 37.58480210458079, 14.863108877212772, 5.725167989730836, 6.054972150633413, 9.380999380542386, 11.573552335462264, 3.5371586103593153, 1.6819894289778126, 13.568559039023615, 47.23714320890365, 68.37827913222775, 86.59137356665828, 96.98301869053995, 101.49444257059406, 102.1414924437, 98.310560564841, 101.83250381100564, 120.16936471385341, 94.2857773073258, 81.5060127935102, 87.31455664480887, 108.4233408589517, 117.26170386037519, 117.12478176239999, 121.09540493257585, 120.95473304871591, 111.0044094824022, 107.15977284216113, 103.64230109799294, 109.36882818898847, 114.66232561296033, 115.3092578149611, 115.7831193554786, 117.28211587475194, 109.49774865181216, 102.28352931237991, 109.01283387214907, 88.44480329944243, 15.375580268521464, 1.2879106138021716, 0.6058540772045813, 0.2377726396005, 0.23527032064814724, 0.27885870106758615, 0.4864056786942867, 0.3517089435650457, 0.13928635256184688, 1.057058291569833, 1.5025478577421558, 39.58650527461883, 101.57618476498513, 112.89922806524463, 107.2175258205783, 123.2773567015125, 74.05348593188872, 35.49941908928656, 26.679120563691665, 59.18140365231422, 82.0334303763605, 74.25397396087646, 101.44259668165638, 87.59215062664401, 10.627540388414937, 1.1524271676617286, 0.09289703211717068, 0.19976396864700705, 0.16363645723510176, 0.1812951975772458, 0.18853174071879159, 0.2181034393969082, 0.16153864802852755, 0.2272728683366891, 0.1876284158037555, 0.13579702124960963, 0.09177844415629104, 0.13904972332379512, 0.1224254698102032, 0.22215956852080362, 0.09220373020657609, 0.15493075663764633, 0.14946490315900696, 0.2008698012439474, 0.1433781200959798, 0.21007940383447757, 0.21739002767830126, 0.13629205194452118, 0.1551298628891668, 0.2036742959171534, 0.08850175586919631, 0.20484964333234296, 0.21714782132016075, 0.16864337808182164, 0.09872129217030541, 0.16053468980375799, 0.2350118579042535, 0.07252010456737011, 0.12451789341866971, 0.12978580509943347, 0.15481474028239328], [0.039735126699651444, 0.03833841051786177, 0.03958756667411616, 0.11642140892123985, 0.04584832064386818, 0.05567362809914255, 0.028600979093161803, 0.04011046381727342, 0.043591693749711405, 0.05450522910142618, 0.044697652751159285, 0.0739204903103171, 0.023660003094963973, 0.05177058632515612, 0.04114081377103444, 0.06291398635855125, 0.02626283469820215, 0.02142454129493525, 0.08773356886400331, 0.03397473156632435, 0.02551874498866739, 0.039178709379367294, 0.11595450131402862, 0.042533910187381896, 0.09988381527364255, 0.055596433249452425, 0.06723656469295103, 0.165623459484308, 0.035684432969578815, 0.045193801934440295, 0.05727302050217987, 0.06468051999446846, 1.549405594987254, 82.65738533389184, 95.86073444735621, 83.33429228874945, 85.40637846915953, 56.62407713551676, 33.9657292058391, 43.223401423423525, 91.07436810770344, 89.58530302970641, 70.2476336879115, 98.79886427233296, 34.435891951284106, 1.385956262388537, 0.11194233031522845, 0.12659128740309708, 0.23076708728988327, 0.1630799709669044, 0.050885471320080186, 0.17210258681687618, 0.46709569711839005, 1.0001936074226134, 6.015638622545428, 23.716846589119207, 65.84956630583733, 103.29828569965979, 123.69958416108163, 119.82879315653156, 113.8499164581299, 108.84805510121008, 108.47979161047168, 98.69023815278085, 88.77809493772446, 79.88339885588616, 79.76948538134175, 79.88975309556531, 86.43382764631703, 86.35112839360391, 85.26234119169175, 91.14770074044505, 97.46942397086852, 105.97620548740511, 107.89859833255892, 101.44166315755537, 91.30251669114637, 71.50919345117384, 41.55360921736687, 18.988927487404116, 4.6518545381484495, 2.366501001581069, 0.9307337023558157, 1.6545330829197362, 10.618380673470037, 24.55295470453078, 49.73322583783058, 70.39281629746961, 86.98543840839018, 99.64130309320267, 110.23844903515233, 118.43399047851564, 116.88215963302122, 105.8028994837115, 93.04244872062438, 87.34829687303113, 104.00010754985195, 97.93614679767241, 108.1490416680613, 109.1316895331106, 108.38195985363377, 107.63743123700543, 103.82734283324211, 95.54369711106824, 98.25287034434658, 97.36413186596286, 98.60349101404991, 102.76403534796931, 115.20078859021588, 107.00005392874442, 102.13152177872198, 90.63463903242543, 97.33372565238707, 101.84354920541088, 104.52273199635168, 62.83415009898525, 10.051651135567697, 0.28678191945918147, 0.4659221117054263, 0.011325908032426191, 0.08122441088480335, 0.018648455077181422, 0.14731951989233494, 0.06850894480462998, 0.20700504702906455, 0.03822869523578594, 0.48107333901909094, 5.608709877537144, 65.79333520704701, 89.24505310673868, 68.64291360301357, 89.2643747022075, 74.42377336563604, 50.1655847795548, 27.496434642422585, 19.2261936203126, 60.084148914583274, 57.523100068492276, 79.48272874278408, 56.731977616586995, 19.586761420772923, 1.2598162697207544, 0.3153941389774123, 0.042234086356456244, 0.23562121956098467, 0.025009281197262388, 0.29626483157757794, 0.058616183307622714, 0.05033735073201599, 0.0471849640410754, 0.05501373528292584, 0.0608699488633823, 0.05884405999113956, 0.08951070132635294, 0.04737704526633025, 0.0616749310715785, 0.016769881082338192, 0.0609922931048899, 0.06878259141118297, 0.03498850720784357, 0.07758235994486079, 0.04340391410815139, 0.05407774820923806, 0.04576091767258702, 0.03678194585166151, 0.02195118269282243, 0.009565148784238245, 0.021936831950780847, 0.02615013358844144, 0.04022687470780746, 0.01998901892934115, 0.05379253750546806, 0.07750315411436944, 0.05571263729624691, 0.017098157418771617, 0.045041384911465074, 0.04848408828219099, 0.03824740310289687, 0.04254825135332443, 0.15290541934870905, 0.11110563206696704, 0.08379381615668537, 0.04212504523175378, 0.03655454414265771, 0.029389798761375492, 0.04571195699334626, 0.04690280619768366, 0.10688069546895643, 0.018090572613742084, 0.04398484624201252, 0.017857379280030727, 0.07905708685997995, 0.026578729138559392, 0.03516274624534192, 0.04434789913976866, 0.037776688038701975, 0.10370005162492876, 0.05448025080465502, 0.04809034207174855, 0.05005454171388861, 0.08578824945875714, 0.06718489206245831, 0.10828809857728983, 0.26001272362566763, 0.08492022587527191, 0.12950754664357633, 0.10389773295291009, 0.0589040944713258, 5.444374334427619, 113.16446658103698, 105.54771792504096, 114.21699539307626, 117.3951272041567, 83.84827967612975, 52.189241455447295, 26.1872180815666, 30.224621565111224, 64.0864726804918, 74.32827149668049, 110.42555393711214, 36.85637873987998, 0.4808307036517128, 0.06038571234732386, 0.1266163078347041, 0.10316496985333581, 0.20643777424289336, 0.07320209902020232, 0.19125670014369875, 0.24555215521925883, 1.4359123043475615, 11.949715479727715, 37.81169945193876, 82.68246496877363, 119.77838285507696, 133.6120411657518, 125.3658619234639, 116.0534098840529, 111.36291411615188, 109.32757269951605, 99.41263675689699, 89.67700804433515, 80.81304765516713, 81.787764487728, 80.4440781377977, 86.3946274788149, 89.2282888966222, 87.96411683482509, 97.06987565563571, 102.48586085534866, 109.33340134159212, 109.50328703849547, 105.05957111235588, 98.84218292851602, 80.93033436805972, 52.162549726424686, 25.60140032922068, 7.488509214693501, 3.2369980071821525, 0.6654783326291269, 2.482277847105457, 16.34772010387913, 31.203113678962957, 61.47177365518386, 81.45723419804727, 98.16429538111534, 108.93722626470752, 116.77114871240433, 123.97691926648541, 123.48726626365416, 113.56577211810698, 105.00588955417757, 99.74006837414157, 103.84678209981611, 104.53470307011759, 112.26219592555877, 109.91830518168788, 109.03545025856265, 112.75067221733832, 106.6258127458634, 100.36125413833126, 101.98751588021557, 99.63298766843735, 102.21239320693478, 105.43649519643476, 115.81484348543229, 110.74211274423908, 103.34470302827897, 93.946162808326, 102.56563401991322, 109.35690418366464, 107.50707518669867, 75.06469649653282, 19.79465880701619, 2.1631913175505977, 0.47611524861666465, 0.07475556445217903, 0.06418306846171618, 0.015521063919990294, 0.06568819374567078, 0.1460164809419263, 0.1904050861635516, 0.10226457905504974, 0.7700321739239078, 2.6490808062015043, 64.3986423553959, 97.06572578799341, 76.64900456705402, 62.37941011305779, 30.176411713323287, 22.169122465195198, 24.159793969123598, 33.90765851543796, 90.47783051767658, 76.28458499908447, 88.1071892092305, 80.62361286532494, 35.93841860371251, 3.880453028025166, 0.31404392433262646, 0.03854399787322168, 0.24126771657216936, 0.02939446806727398, 0.20897799922573954, 0.12047396041452886, 0.11460732037742292, 0.04661512102991824, 0.10183728585440306, 0.014311948306708327, 0.08117205643605802, 0.1039034249861875, 0.05688136954221034, 0.11390212112136426, 0.17752146378399866, 0.11940135305086452, 0.12262056176100047, 0.034044610276337595, 0.06524572434324412, 0.03397397696971893, 0.08444612470245169, 0.048163817564566294, 0.03310252897321217, 0.08261437783198011, 0.025208877745054425, 0.13310285855925855, 0.020645743971990965, 0.04682432048984113, 0.05862498182743307, 0.012772117324564005, 0.06079278082676953, 0.04933299797196542, 0.07288804893652279, 0.031238637053437775, 0.21360524689718602, 0.14972160390067488, 0.12084459375229575, 0.2800722762701973, 0.16128686557133354, 0.180634324168486, 0.2904992538594431, 0.10455073863868752, 0.11123277967975986, 0.09045717997416373, 0.15704207963520483, 0.18923727705353693, 0.07076024738771301, 0.19412744610059648, 0.14757257405548327, 0.16928332196849008, 0.11722347999532377, 0.12796348111043054, 0.299221440669029, 0.26886486959072853, 0.17625309797304292, 0.20587670676890882, 0.2806281803115722, 0.10492121875886956, 0.1558975442763298, 0.1517713640726382, 0.1704605846034904, 0.42227746978882824, 0.2784294160383363, 0.21124744277086951, 0.22227376158679688, 0.2347129763614747, 5.180198780951962, 127.47391623835411, 122.43825189528928, 114.21854865166449, 109.57922412503152, 71.20999505442958, 41.99952779277679, 57.640406393235736, 120.54725370099469, 124.4384410304408, 95.92808154321487, 124.05876344250096, 47.35331596866731, 2.1234089232260183, 0.28181993733009986, 0.3187007583197086, 0.6087990417595833, 0.33728657230254144, 0.18713936059465333, 0.5693494973163451, 0.8522085256634221, 3.4277477716245963, 10.615680121606397, 28.438603647293586, 74.17751127673735, 119.04089097053775, 136.50530692069762, 124.54592181790261, 122.286236516891, 117.48664394501718, 116.25902837322606, 108.46711451007475, 98.52326285454535, 89.27900514295025, 88.88809388683688, 86.4506624590966, 93.68017119746055, 95.50360264316683, 93.37946661057012, 101.64059008321455, 107.48165038324173, 113.68975039451354, 115.70224008252545, 115.37619698432185, 102.81041345288678, 83.71298143940588, 52.07817562164799, 24.407797590378795, 7.535098637303999, 5.758762599960451, 3.4520193982508878, 3.050759949030415, 15.19580529582116, 35.799229375777706, 71.17203435590191, 90.35969657282676, 102.63564832748906, 112.23313116258191, 121.97092502347886, 128.56577857848137, 128.54340537901848, 116.28050727228965, 106.56681245373142, 113.15662184069234, 118.85046774341215, 116.55267269380631, 125.66340507999544, 120.08997594156574, 118.32001424604847, 119.20461070153021, 112.59950407089727, 104.52455197611164, 106.32976793473767, 105.4393114582185, 109.85528838249945, 112.59153381470712, 124.3563928911763, 117.07761133870771, 113.53177301345335, 100.76914141255041, 108.92127006284653, 115.78519821166994, 113.42680254290181, 73.62110737831362, 13.860779539231332, 1.3360960733505989, 1.5055318008507452, 0.46944176477770655, 0.2764658714013715, 0.24796802881023577, 0.4210872755896661, 0.31825851108278, 0.5280753152985727, 0.31338732569448413, 1.3160028741244347, 10.240557386029153, 85.9944123606528, 104.14737686034172, 92.85603415581488, 133.15853672642862, 98.61656819620441, 65.12955642515614, 33.04044208218975, 23.375841609893307, 75.53630659657141, 76.48935625630041, 98.48824393364691, 95.12518021368211, 36.2608217423962, 2.93899372700722, 0.44903731934966584, 0.3028185605522125, 0.5589870856173578, 0.24202173095076318, 0.3490695868047976, 0.16155361738656798, 0.24540263017819774, 0.16615061990676389, 0.3076037602318872, 0.1424155152973629, 0.29742787562070355, 0.23430417652332017, 0.1322276184275266, 0.20802118605183018, 0.1827864030436162, 0.18969516780587936, 0.2756311419990755, 0.09234311224351968, 0.18196354800414655, 0.10654861933641857, 0.12715757959672522, 0.10956602516554056, 0.12234563578761394, 0.21332225401795682, 0.12155504837151497, 0.38463454453214524, 0.18782525443502013, 0.20896899003174998, 0.16766332180028962, 0.07475829172518945, 0.16181165112122414, 0.12253063836044843, 0.11415299959480764, 0.13154641304525638], [0.060666832141578204, 0.06484011143085457, 0.057287553190103466, 0.02635357398239355, 0.09768865927453003, 0.07554789854874534, 0.10917652308219865, 0.054470916023297664, 0.04388967513917916, 0.052633404341195865, 0.05201154012954043, 0.036171959833272045, 0.056083048468515764, 0.02894744044169784, 0.02155272121120605, 0.0345550240167687, 0.055991363065737876, 0.013414109538820003, 0.029263403829968268, 0.06091375377089266, 0.04459044640703548, 0.11027905384018538, 0.05328067202842044, 0.036918512515483365, 0.05417517927144805, 0.06051472921465194, 0.10878897452306364, 0.062113470442953615, 0.03524466785752485, 0.0638699415139854, 0.028665939518701167, 0.14846748732511075, 50.90985451975177, 99.27064695665914, 92.10998365955969, 64.23762513745216, 45.00736598045596, 38.31901881002611, 58.97735803358017, 101.88340048636161, 86.45922891555294, 77.57566452026367, 91.5789653408912, 23.89102335899107, 0.5096527086871286, 0.031787684607890346, 0.1365919600451185, 0.26189353076681016, 0.0684749075181542, 0.09097165398059354, 0.17696174462476086, 0.14265211389189766, 4.66791223133764, 29.389348914546353, 71.85986118931925, 108.57731742243614, 107.30342572735204, 98.3415472892023, 96.32983423048451, 105.42385731973957, 108.39137354204732, 109.93819944320187, 96.52762366879372, 81.73516550371724, 78.9205668049474, 84.45649808452976, 89.22678270647603, 84.40186731276974, 78.22370283065304, 77.50732114238124, 89.61065723050027, 94.40893973073652, 107.31733445198306, 105.84470410500805, 96.49082399183705, 92.23073774768461, 92.39524979745188, 95.39969905730217, 87.77850243353075, 59.73281829587875, 35.23141138015255, 18.24954894281203, 6.104416568433085, 12.976822430087676, 43.652222387252316, 47.864902865502145, 65.07379208841633, 86.04652497076219, 98.05530055876702, 111.9708893376012, 113.57395418228643, 113.88344487836285, 117.65077944724791, 120.83303759174963, 128.67456159284038, 104.63240931110998, 87.49349517206993, 92.04681781030472, 103.64784732941659, 102.85668173143941, 99.2739809713056, 99.5477859435543, 93.41395993386546, 93.62892935352941, 91.19049379902502, 89.88757656466576, 88.48106168931531, 96.94626608202535, 99.04864080490606, 98.34125703380954, 85.10988650783416, 83.814664963753, 90.77122380656581, 102.18176734062934, 97.75829084457891, 97.07376664684665, 81.87879485468711, 35.923011533675655, 6.455592743812069, 0.45528323419632455, 0.1200233321757086, 0.12696663218159832, 0.03584189851197504, 0.14566070970989045, 0.1797140840320818, 0.12647019188490607, 0.09821909855330184, 0.3011084378005997, 0.30671963348023357, 38.23056936264038, 93.40882947368007, 66.20735706821566, 78.02521521045317, 106.90782331651258, 72.78612106077134, 43.03239376314225, 23.732930268010787, 43.57309249139602, 61.91785304777084, 70.101713672761, 75.85282617999663, 54.105605617646255, 3.4152273208864274, 0.11254380126633953, 0.0614157788485529, 0.2991716143104338, 0.06255227028422299, 0.05622971217117964, 0.06859153674374666, 0.07094202473038627, 0.010709893859682545, 0.04492110910735304, 0.11010395678421182, 0.033996534428649375, 0.07536170087874898, 0.08563804259944348, 0.14973422902966702, 0.08444354298614687, 0.08438843062087413, 0.02383937683677481, 0.07373098314048783, 0.037668198497304996, 0.050096691871482524, 0.024733558492434603, 0.040923566557466984, 0.03638422747533168, 0.0491712921329083, 0.03949341829866171, 0.019842987249214804, 0.04571214085444809, 0.035535731473036354, 0.025610303986937772, 0.005481404105892345, 0.04496672964324394, 0.034882951783196586, 0.032497782996224786, 0.03764742602323813, 0.06068545190857784, 0.06459788209007633, 0.02435401938254795, 0.054741689800134594, 0.12659668066208402, 0.053712113595177094, 0.04612092537084415, 0.05004060657454595, 0.11761093662390787, 0.050185408683553825, 0.011888638874816318, 0.03186218857374643, 0.010164149101793526, 0.024545778850874594, 0.04489230803183971, 0.0601667644185645, 0.062434445961468646, 0.025285601450671113, 0.05656538891696161, 0.12347820485311171, 0.049834482957639044, 0.09256958315569548, 0.0541353312080666, 0.06246172635245228, 0.04321699248506658, 0.05302400193026951, 0.06512855885610466, 0.15857756498359865, 0.09120115094007024, 0.024576150406632694, 0.22963002894914922, 78.31630214568108, 110.8216505665933, 112.80171794276085, 94.38262062688028, 76.11758616662796, 48.18001824040567, 23.60680841630505, 43.051303509742986, 79.06829111037716, 91.62924228175994, 101.98282472548946, 24.07996589137662, 0.3473757051171795, 0.024026457423103914, 0.17537140738098853, 0.3405379413837387, 0.10819313431819601, 0.1790715201247123, 0.2607670137959142, 0.32772239357713734, 9.737763462528106, 42.5699737764174, 85.51769533464986, 116.37454217480077, 111.55087409480926, 100.28068865499189, 101.24053185985935, 108.4661731412334, 112.37554457879837, 113.16026180021225, 97.85645992525163, 81.56815098178002, 81.78226532474642, 89.97985424533968, 94.43385462607108, 88.89739774888562, 83.4512181435862, 82.96472657111384, 95.40042077341388, 100.72925090789796, 110.80372533490582, 108.82802747911023, 99.53765053902903, 96.46506186454528, 94.04410439152872, 99.77093742739771, 97.2991381922076, 70.82823861029841, 47.767632007598884, 28.422810223794755, 13.774606047138093, 20.60507147542892, 58.715747710197206, 60.54087361981792, 72.93430036114108, 94.89600396925404, 106.14202760880994, 117.91974421470397, 116.50214472124654, 116.07352379829653, 118.81594304115542, 123.68139220822243, 131.1844862661054, 111.4785691230528, 97.83523205787905, 100.60680235585859, 106.40539123165993, 105.1814469983501, 103.48815979496126, 101.27986538794734, 93.9376747992731, 94.2912058676443, 92.9648171701739, 90.99461847735991, 90.13362684557515, 97.68336572954732, 100.23276513622653, 101.88311807570919, 90.86055970961048, 89.36958051496937, 95.37294064798664, 102.99936186882758, 104.24040763608872, 108.44869505974555, 91.16182127306539, 48.13449521218577, 12.461096452128503, 1.0411696280202558, 0.07513194344937801, 0.366782795998358, 0.2178621829877938, 0.05399053292949835, 0.14528819179582983, 0.1845868475615017, 0.20462991399390085, 0.40614632408945794, 0.5666795889696767, 34.59310839253087, 98.62292243588357, 75.2875106565414, 71.27344331433697, 67.96847774136451, 31.436971272191695, 13.93745501195231, 33.72249126434326, 76.33803121505245, 88.20462088431083, 82.00210632816439, 87.83561214323967, 78.51873567027431, 9.23673656678969, 0.19780043933180072, 0.15606467401789081, 0.3632930816421586, 0.04096549454956286, 0.08346223032041904, 0.08067750071565952, 0.08863803525004657, 0.024475572638273723, 0.047013191806693236, 0.13489194965410617, 0.039932666301366784, 0.0031998939577475073, 0.05434829982057695, 0.15545969438408652, 0.05648814427155641, 0.0586364233505822, 0.07410257408816008, 0.12340981618411119, 0.04001873244922008, 0.14389792607436258, 0.04594175272711343, 0.04994585298963132, 0.04997992858050331, 0.07779053667740476, 0.02155871010355411, 0.050072801419563835, 0.10341381819377984, 0.07246633285596486, 0.026420717758517114, 0.04023679171598727, 0.05302112143967421, 0.050417828268461654, 0.015709908423765052, 0.16585006829231017, 0.14784312566682217, 0.18658774664565442, 0.14212886051785562, 0.18695271093278162, 0.1542215737243814, 0.21326652878234464, 0.2960452094914452, 0.1916260770972698, 0.21160977171553721, 0.14470095475835187, 0.09903851385799148, 0.1317674140896528, 0.1207695247965955, 0.14431616411574427, 0.08219949525570677, 0.2142546289870816, 0.13289508019243518, 0.18219685242060693, 0.16438017539199323, 0.24067137841015096, 0.1256432152924038, 0.11828045150445354, 0.11859336777800515, 0.2698902935991364, 0.09452749704641682, 0.19325474938077314, 0.1649060794302533, 0.26432218270436414, 0.22563612148646386, 0.07411008941069727, 0.2371289265612441, 87.59210355820196, 129.59205104458718, 117.48333346459174, 84.8358226591541, 57.675903843295195, 50.82744552243141, 76.15579789684665, 139.77745794480848, 120.14477145287299, 102.44201660156251, 114.4191308175364, 35.618741512298584, 1.5111627309553086, 0.1279804729405911, 0.25629183457743737, 0.44597391760157007, 0.19695314608754652, 0.3957111340376639, 0.6944635450359314, 0.7400995865464212, 7.657491785864677, 35.157894396012836, 79.86614827186831, 125.39325575674735, 123.65268045856108, 106.11948182505947, 105.46214749736171, 112.33564622940557, 118.69788754370906, 122.83350129281322, 105.55585292077835, 86.95526753702472, 86.18875011321038, 93.75897161422238, 98.14955511400777, 93.13217686068629, 88.0006419458697, 87.09606493673017, 101.56903036179082, 106.27026557922365, 117.69184666295206, 114.52814917410575, 110.09933825462096, 106.27356037016838, 104.67633985703992, 107.38427362134381, 101.0969574220719, 73.40746371976792, 46.21812320524647, 23.909809550931378, 11.628444925431284, 16.644415047860917, 56.815912415904386, 70.38625809454149, 84.56977613510625, 102.32334921436926, 106.34188021382978, 121.09733473870062, 118.60157766649802, 118.22144508361818, 121.12113568090625, 126.62517809098767, 134.1156734958772, 116.63083768660023, 106.5979011597172, 108.42898907199984, 116.45802590154834, 111.30569458007814, 109.57625881318124, 107.46404678590837, 100.32528600385113, 102.28702022183327, 100.7132476375949, 97.12208240262925, 96.02258713014665, 105.21673264042025, 108.49940346133326, 109.1515681051439, 96.49511506480556, 93.51929910721319, 100.27875100412678, 110.3085574796123, 109.64081318147721, 110.77856725262059, 90.34738817522603, 41.44734044228831, 9.489211690041328, 1.3108262035154528, 0.5305182777585522, 0.5319887375639332, 0.24815372852308137, 0.2825487933812603, 0.4414853165226598, 0.4011945156080108, 0.2382197131913516, 0.8611125511027152, 1.6102856830243142, 54.311094668603715, 108.06876644011467, 82.2260501307826, 110.6903531474452, 149.83647038859706, 101.39315912800451, 55.648936686977265, 31.138274938829486, 57.857431134869984, 82.46114130943053, 85.78429883526218, 104.2041100225141, 85.65125203901722, 8.890652118190642, 0.4763037981765886, 0.30865529251675455, 0.32392664241694635, 0.06997174373076809, 0.20153499538860015, 0.18346924785404436, 0.13332165327043305, 0.17356311812275843, 0.21399703958342153, 0.15808308587199257, 0.16992720354708934, 0.1869598815157529, 0.096172540628862, 0.26055676862597466, 0.18783674575388434, 0.1287059582048847, 0.13116646407833024, 0.19123184825143508, 0.13016506458722776, 0.2909818892517398, 0.210650690921372, 0.18991907998438806, 0.24535088859979184, 0.27762232708834833, 0.11060278727522782, 0.13076204626310256, 0.18558027973819166, 0.16987791345004113, 0.09242915923917487, 0.10196287064783036, 0.16897685615526092, 0.11847184325057654, 0.20945050693567724], [0.022365651581616654, 0.08607546348244914, 0.008754273444684523, 0.02768605943739174, 0.044134409587469794, 0.07301557193239851, 0.14298914661330564, 0.039829282735985135, 0.027058734934056, 0.022051084388588226, 0.0355573772873369, 0.05980591402359067, 0.04105784644883487, 0.020033645466150298, 0.026288648030810782, 0.10882018494509882, 0.027862117933710257, 0.03618180789353867, 0.06906749184934363, 0.026770207069573865, 0.09385867164500299, 0.10297033755529313, 0.03495775643856295, 0.04182255924529126, 0.06756040538030286, 0.06925625591388634, 0.06971672838253361, 0.04456303961154434, 0.07309057194018558, 0.08570157427100406, 0.24603157304227355, 42.65010779903781, 92.54221316306823, 94.53121569848831, 83.64494400639688, 46.661001943772845, 54.6156745572244, 74.24172047645816, 91.53451704209851, 79.28529231779038, 79.75636897548553, 100.59988329487463, 16.06511921651902, 0.5115646189979969, 0.04739415584011905, 0.20551518987744086, 0.16321654912204514, 0.05249520974053491, 0.11949396542003078, 0.11496009620567484, 0.35201399977649417, 17.395754860293483, 65.6065950855132, 92.16878783318305, 96.75098696062642, 88.43434626056303, 87.45356544371575, 89.50992291973483, 96.28515058948149, 94.60956896505049, 96.64886413082, 87.09469210716986, 77.8625702088879, 79.26302109995197, 93.52950511440154, 94.00751652256136, 102.4463390534924, 98.8355698124055, 91.08137346083119, 91.5434600460914, 94.68271332402384, 103.42552738804972, 98.94875372609785, 100.87776753210254, 98.98417272875386, 86.23688543996504, 87.76587240157589, 94.40901817813997, 100.4092796387211, 94.72806376795616, 84.4138305417953, 72.73577351723948, 54.22670487434634, 58.63526851900163, 85.94815977158086, 68.49682100357549, 79.74647675791095, 94.91910672956898, 103.42284448685186, 109.64043663394068, 110.30710620264854, 109.12764949183311, 108.54603259794175, 112.99395330490606, 113.60780423687352, 106.28637867589151, 105.91256110898911, 101.01327757681571, 100.69472620564123, 104.81986722638531, 98.80375939030802, 89.78601071142381, 88.97441740958922, 88.36483401636924, 86.62525500020674, 84.03052083907589, 84.14907055516397, 85.06184531796364, 84.16396771707844, 81.7854267551053, 82.37880291477327, 81.76817617108746, 87.16060361554547, 96.51307952019476, 99.67243102289017, 102.63396955305531, 95.57647243622812, 80.68877912336781, 47.882055390265684, 6.658999506504306, 0.19670356996357444, 0.0983244356428904, 0.15614938802055775, 0.2789826540937347, 0.02478159220528699, 0.03361172080340405, 0.31121997102614374, 0.051385056407701586, 0.09643748447659517, 0.3836030224638601, 25.59619534400202, 96.70550315610825, 74.04969692230225, 126.1089627973495, 126.0928967691237, 127.74895283483691, 41.5531934461286, 17.35071820597495, 38.801968482232866, 54.33112229070356, 62.911405101899184, 78.67399877117526, 59.06829818602532, 2.119226205733515, 0.3532521817232332, 0.1403497438877821, 0.08528073919155905, 0.1431655919840259, 0.07961319008421514, 0.06531612016260624, 0.1059381468521972, 0.08441415585337148, 0.0761784655192206, 0.05616454490190072, 0.10611003399976801, 0.012461932154462464, 0.04517120234067402, 0.01561192577824958, 0.15682472516932797, 0.013895281703181326, 0.02233240528092269, 0.10920823912226385, 0.06318825349632291, 0.04129709953802728, 0.0638587374780928, 0.03145680165729456, 0.03879888681694865, 0.05666164020376821, 0.07564205841551866, 0.09667099573679509, 0.03981757308206251, 0.06444173038847024, 0.010145000734126136, 0.010878623767395415, 0.05044561810791493, 0.04931423647869979, 0.009028124022147348, 0.04316949886420081, 0.07583945629096801, 0.03732796352837355, 0.006153072172310204, 0.034303226237816196, 0.15624030733541136, 0.04816328513345892, 0.06507424322227318, 0.12083412899125008, 0.04142749536361906, 0.04073270724245137, 0.05493557899289074, 0.012699848420227007, 0.060328140839814186, 0.08186247019517807, 0.04087217354906663, 0.034293964234811646, 0.05783889517788926, 0.04000421508305496, 0.020411114223421584, 0.05195053271769036, 0.015542498102501757, 0.13002442616608836, 0.13118848144527406, 0.1220766316738821, 0.05322482038830077, 0.09593291598702632, 0.13662471796476072, 0.11195359946859461, 0.8971069777204145, 70.81901319565313, 108.32798019532235, 114.95309875857447, 108.53891741844916, 74.50765717414119, 49.54218287621775, 24.88312021378548, 58.38630783942438, 88.67158689806539, 95.13879083818006, 106.49653926972421, 15.366947131772196, 0.7319987889739775, 0.026071540628289504, 0.08222392579961209, 0.13533908453199173, 0.029120156879446683, 0.11149022352671432, 0.23564820117767782, 1.2186074809681986, 27.659567979074296, 79.43926103653448, 102.81071155301987, 101.47763129203551, 94.52475947718467, 92.93196339761057, 96.38957977294923, 102.08535548179381, 100.06014162494291, 96.21978036818966, 89.67783174207135, 81.38836522256175, 85.70311361743559, 97.10408656827866, 100.60257404081284, 106.92697232769382, 103.6704715605705, 97.91646434414773, 94.4430878854567, 98.86119073437106, 108.36947887174546, 101.6991981383293, 102.91073199241393, 103.2472635084583, 87.31091668528896, 89.07505758347051, 94.86233434369488, 102.06938359045215, 98.98706743794104, 90.38407802581789, 84.89680767059326, 70.59324156853461, 74.32410593955748, 97.61487330159834, 77.70438101983841, 89.14027090995543, 102.39406954857611, 107.83959804042694, 110.89605792876213, 109.84697295773415, 109.27464423641082, 109.83446844162481, 115.19834887596869, 117.50440443715742, 114.30199315471035, 110.89529698894872, 106.86369665207403, 111.09669500781645, 105.8366632461548, 102.34005851130333, 95.2710766946116, 95.48359071054767, 91.74308515364125, 91.48740153158866, 86.18212915235951, 86.073926648786, 88.29370575566446, 86.65699481964113, 86.9880428621846, 87.26723717105004, 83.42413025517618, 90.81539753944644, 101.33745362681728, 101.52124020361133, 102.8610747860324, 99.46334515848469, 90.67951879193707, 58.06887434374902, 11.637961576061866, 0.7433958483799812, 0.7036331271932972, 0.8650587619312349, 0.7123805642608674, 0.027856500594005473, 0.13726332885844095, 0.21410884245509104, 0.07818976807738505, 0.09889184632488797, 0.5087144654845038, 20.84833687351596, 100.84359584316131, 79.51988143305626, 119.1271831143287, 125.7977697926183, 98.6521048699656, 13.337191170261754, 22.747715211683705, 68.1086475618424, 80.57109232871764, 87.88315911446848, 89.849545263475, 81.93392768982919, 7.141220598451554, 0.47107984462092006, 0.10464220187596737, 0.1188800378792709, 0.04699083353062311, 0.026497426142375317, 0.0416169795508106, 0.06269203919556833, 0.13118785325317614, 0.04725431415042089, 0.06368492744983205, 0.1248670303292813, 0.06266549807943164, 0.1335361272457146, 0.06385784881610064, 0.08244668884623436, 0.08473195210700074, 0.036014892656596444, 0.02078921308801059, 0.06671513460816876, 0.06530252210195027, 0.005570768741064615, 0.06333625402241465, 0.013229864435420643, 0.14312126613672704, 0.03552854173786698, 0.05298143425475686, 0.03150871369026361, 0.004785802016305107, 0.045944361256495606, 0.04811715131865875, 0.006913579146062295, 0.021696437390581257, 0.17197742337180724, 0.2459534627175139, 0.12546187461984734, 0.09362175895441925, 0.15648596108921115, 0.1677943075135831, 0.23171317523285268, 0.1543380650541475, 0.0958794200672738, 0.12831009759177125, 0.23779421263644773, 0.1375049376680005, 0.1169257629061899, 0.11821319664558096, 0.14445450427311082, 0.221710380527281, 0.1287158407391079, 0.14915921875546057, 0.1373480122175909, 0.2106779483297179, 0.11693449630852669, 0.2074473861965441, 0.15129281958985716, 0.18673399283039957, 0.22147436415956867, 0.21309575246226406, 0.1132643759070385, 0.2108834437545269, 0.2980113894708695, 0.22348597315290283, 0.43930285460045265, 75.4859825872606, 127.86103064014067, 119.39378661494102, 108.70082501442202, 58.4981503025178, 72.12839449605634, 92.45525421634798, 135.18062837662237, 112.80400860694148, 98.04560445970105, 123.26147110231462, 23.57654536924055, 1.0924526568382018, 0.14530498444313003, 0.2594471055894129, 0.301839592115533, 0.2005067521766309, 0.29347047990848946, 0.48991181797558264, 1.1347105570377842, 23.01598964198943, 76.96064472198486, 111.68994565163891, 113.52843899880688, 101.85802275134672, 95.83119115521832, 100.6836494322746, 108.27745222276258, 107.28104468314879, 107.53640667084726, 98.0336255411948, 86.15623366448187, 91.66073891424364, 103.88631174641272, 106.43879413604738, 114.71930196208339, 108.4786541231217, 101.51093221479847, 98.944454808389, 105.37056799857848, 114.22641692623016, 105.9483801934027, 111.56148018375521, 110.90261613169025, 97.0427877672257, 98.10368691721271, 103.59473059254309, 111.13323580834174, 105.8285988530805, 103.69641411689021, 92.57648683363392, 71.12542875351446, 76.44034231862715, 105.56984793755316, 87.65540276804279, 96.43542443552326, 107.01218974205756, 109.65987590051468, 116.8725968945411, 114.101332541435, 114.84933637803601, 114.88397090665757, 120.9315126172958, 123.91223153760357, 121.12816456825503, 118.91163318387925, 112.90173053741456, 114.2465308404738, 113.45129382225775, 107.45223260694935, 98.59720737703385, 98.15847458377962, 96.43551857240739, 96.59701824188234, 92.04674720764162, 94.65864566064651, 94.52605385934153, 93.3762659565095, 91.88455720101634, 93.1928716167327, 88.954358408528, 96.77818467540126, 108.68216237714215, 107.80189621833064, 107.0374341164866, 108.28739935351958, 93.77156242247551, 56.12592043415193, 9.15645545528781, 2.2104563684232774, 1.3699593659370177, 0.7386571962025859, 0.5167182150386995, 0.13345930394866776, 0.3112021977863004, 0.4869273845707217, 0.19177212409915464, 0.2954166496713316, 0.757179792609907, 38.03171303964431, 114.94701124006703, 87.08761615137901, 138.01940456513438, 152.327363721786, 168.98122972057712, 58.39642363209879, 24.05850268179371, 49.6630467907075, 72.67158000699936, 81.30716431525447, 100.21657359215521, 93.80601652206914, 8.527045461439318, 0.6959633000435368, 0.29250720095249916, 0.23813285414249669, 0.23853578574715123, 0.15524984757986762, 0.1350005349564937, 0.14851650163050623, 0.2569360379129648, 0.2696692312677061, 0.08348084625697906, 0.19427300280620977, 0.10782438555672284, 0.22173368492193762, 0.21257799959951834, 0.2278992524670978, 0.17503612134004795, 0.06444589024589908, 0.23860746093334692, 0.16481053294433703, 0.2781690380746319, 0.07627636389506441, 0.14307813538659003, 0.1059633664666645, 0.1729466778136069, 0.18651593356363236, 0.1791965303521964, 0.103310901942032, 0.17149337837772985, 0.09527904462189445, 0.13147764899317296, 0.10175714539664407, 0.17641725529345775], [0.034881760516474326, 0.05862594709821767, 0.03821294829850236, 0.026523172442290573, 0.06901681513315247, 0.052477543753001, 0.039869701534870176, 0.015414926268520857, 0.08955556343519881, 0.02543524332014063, 0.022845912101348082, 0.0855957928504194, 0.07479420592707973, 0.015801136089008183, 0.0020080853479861795, 0.1028976894374336, 0.04413490371418096, 0.02821674003385969, 0.06671572449587046, 0.022356996703292095, 0.03510011855753199, 0.07274031654120454, 0.050670353830942226, 0.11336688613218647, 0.0559087175004665, 0.048779292602933226, 0.046982107789165554, 0.1683654413828927, 0.09891973958621103, 1.0462753282439325, 55.259072703699914, 104.43034448931294, 89.88168516466695, 75.86337735576015, 74.43961974113219, 34.55890140225811, 106.91482082489999, 117.09953738797097, 80.5259144690729, 106.94216758974137, 112.01504738100114, 16.32785329895635, 0.48800333973861515, 0.25786583882666403, 0.1832969546798737, 0.026972521314277288, 0.0621448417434529, 0.14487908552250556, 0.26679505323690755, 0.5527991176612916, 29.713903473269557, 77.45459664252498, 92.12022104570943, 89.55971348670222, 86.53822545082339, 85.13091041195779, 80.68478615053239, 80.58955100274856, 78.94854114901635, 80.82431270230202, 78.41891134938886, 79.8043474074333, 88.71009672841718, 99.88063827637704, 102.95630993381624, 106.70609581855037, 105.19537925720216, 106.76316630455756, 103.68380761915638, 95.38428414252498, 97.58147824195125, 104.19399815220987, 108.02849938792568, 102.99029334898918, 88.68412279313611, 81.01015460106635, 88.55585344376104, 91.36834190737818, 100.77393454890098, 96.63587324080929, 85.14619196614912, 87.22682891353485, 93.35885847768476, 83.85750509077504, 85.940150291689, 86.43891103806035, 86.65961496291622, 94.61153015013664, 97.34423760444888, 101.22272429927703, 96.61041705839096, 95.34172642615535, 96.97312647296538, 106.21128097657235, 113.13933203297277, 104.67194680244693, 91.07537223446755, 86.86196219536566, 100.65390217688777, 93.8675977337745, 97.57331971199282, 98.95444900758805, 103.23115041179042, 100.54813938756143, 95.69763445085096, 85.0607313648347, 82.27590345567273, 84.82176488445651, 89.28594773815524, 88.2111006398355, 86.55028281673309, 81.91940707545128, 78.44168463060933, 82.25698978670182, 86.53372256986557, 89.00185831131475, 90.50970369769682, 89.3516239043205, 73.51433261748284, 33.73313265462076, 2.9196571775021094, 0.238564268896176, 0.779068211634313, 0.2825096003230541, 0.05253691556713274, 0.07284827365149414, 0.026861111062668988, 0.3660258704856519, 0.08690368113738876, 0.059610389233116186, 0.7993870084324192, 18.045454294450824, 96.29319929307508, 82.16001310656148, 91.55357976113596, 86.60111673416631, 92.62279433588829, 69.70192217057752, 26.031870649706935, 17.896210070579283, 38.85991757915866, 64.95075910322129, 70.79962884226154, 56.81428070991271, 4.825654270187502, 0.8674865864938306, 0.049973010806547064, 0.08347071091374082, 0.13238118841282784, 0.017497149416275563, 0.007414623631179454, 0.03486668390612449, 0.09401108483753859, 0.12717433393962924, 0.03559611452322814, 0.052739741175525615, 0.06701899572245537, 0.13646543296354433, 0.019584384694274877, 0.029882906575597105, 0.08148859630549148, 0.056492032167772134, 0.11980529589157914, 0.01702487727837457, 0.057175780961950945, 0.004063687538878332, 0.01861816396065537, 0.04782308846892369, 0.0721330386436274, 0.031052573448828155, 0.09464938929604907, 0.04408757863265853, 0.059773803448244456, 0.03486590249644172, 0.07009676928001066, 0.025640884301655238, 0.026355311086761857, 0.10060878725902689, 0.04129242257124955, 0.0062534943290595574, 0.08149011315958155, 0.061551368750271306, 0.08160078988200234, 0.05520110123700673, 0.042239594528631824, 0.05915346758199796, 0.015211531839844201, 0.033924912868608395, 0.01995608672469614, 0.03569489773062449, 0.0770329140246876, 0.10189976798550737, 0.02793436194018972, 0.019413721372163104, 0.07946435452228592, 0.015454003455928497, 0.10759268226402421, 0.02591887462673889, 0.018212213969579148, 0.04824155633668265, 0.020104403262056654, 0.04695651279161534, 0.07101988990701015, 0.14922730865017061, 0.325618838711131, 4.327051399215575, 87.9324633075345, 114.67710510376962, 111.21808451990928, 110.21830374194731, 116.3533692206106, 29.081091803889123, 53.79078442050565, 93.65833928508144, 87.2316534288468, 120.49486652497323, 112.8560035459457, 16.474103773793868, 0.45640429662119963, 0.3068133719986485, 0.3906188556744207, 0.01929795591070527, 0.45531994512965607, 0.2791055958838232, 0.16355673812570112, 2.4758944347981484, 41.09030669735324, 88.56689883816628, 99.46012097020304, 97.60174120626142, 93.26291730326992, 90.14752772546585, 84.23738664196384, 85.60515634475216, 81.91716347971271, 87.13718706561674, 80.84644271481423, 84.76627903599893, 95.61334271584788, 105.72131418412732, 107.86154762391122, 110.61606345638153, 108.47761077265586, 109.12823784735896, 109.12542943031558, 102.18372068097516, 103.10306933618362, 107.67827095523958, 109.66961906802271, 101.69558171303042, 89.36465401803294, 82.85762233118858, 88.39113743074479, 93.3648204803467, 98.32602254806027, 99.2507605398855, 90.15999301787346, 90.0181208887408, 100.18352370108329, 96.60046992763397, 101.66328491703158, 95.36559797102406, 93.14369293951219, 99.07082573060067, 98.1818126863049, 102.89782739454701, 100.6479323294855, 97.7533329686811, 101.77141681794198, 112.14032788430492, 118.15625529135428, 111.67167525137626, 99.57746259627804, 95.2907826823573, 104.09168704863518, 102.59963312456685, 104.09222049097862, 105.04934157094648, 105.75828644537158, 103.40117731401998, 96.63533979846586, 88.7100653494558, 83.60909354302191, 87.1758145670737, 95.5485216263802, 96.02200661936115, 92.38169408613636, 87.73449344019737, 82.64471607823526, 83.67782915792158, 89.0208504276891, 92.76992244105186, 93.6157266555294, 94.37843153553625, 81.51948221268194, 42.06674937278994, 5.12248698742159, 0.5060843017793472, 0.7767690285559624, 0.794663003856136, 0.4402178393736963, 0.28273676071436177, 0.09231377873689899, 0.1249401074563784, 0.1861087578318773, 0.08500133926469473, 0.7170282051928583, 14.397540207832092, 100.38152494738179, 89.78359453139767, 92.83650075235676, 93.68078308720743, 77.62979322864165, 27.350969622212073, 27.331040059366536, 32.29807469152635, 61.27076002859301, 88.46528591648226, 77.90344915082379, 78.13348047194943, 14.50210177129315, 0.5221259990526784, 0.10380597860221902, 0.08841639835267298, 0.08150928067944704, 0.013322304434803946, 0.010250077353820447, 0.05143744149996389, 0.06135602399045902, 0.050408968461617354, 0.021400195020701618, 0.03448378550068986, 0.03527695463309365, 0.1277616322641411, 0.02071776006731295, 0.05916810369179134, 0.04848200835347657, 0.041916443320411834, 0.1042067651606856, 0.06513396743685007, 0.07193145792811148, 0.06578724891428026, 0.00812630255466267, 0.10851178859030047, 0.06600525455489274, 0.07964778661487565, 0.11545357940297936, 0.043083869386464364, 0.019914719892004808, 0.12173547739944152, 0.11966851089269885, 0.05749201439621468, 0.12870620335302047, 0.26166257057939807, 0.12625233946187844, 0.12553984704878063, 0.19598200706945312, 0.15822484278150145, 0.29480862100758864, 0.11203748609630332, 0.17217472165582642, 0.13012876734137535, 0.11314460572095648, 0.1788817754676265, 0.12556318974783345, 0.15606401518227594, 0.21681328604538597, 0.19216793108611338, 0.09377018082886936, 0.11050206203494342, 0.23334281278714059, 0.11001790978855665, 0.14284973393284506, 0.2676880053214489, 0.16856361300714556, 0.2192603700583981, 0.15588792221200082, 0.20297554712141716, 0.15420062888053157, 0.28421650550538496, 0.45652365311980253, 3.642733616213645, 99.7284895373929, 139.88245194958103, 111.7744178156699, 102.48148349023636, 88.04559230804445, 47.70436809908959, 127.48646782290552, 152.41431482376592, 105.20690318076842, 125.89014945491668, 134.10412603808987, 26.942882307114143, 0.7665653502748859, 0.5466814459331575, 0.4959016449509129, 0.21822279589551113, 0.44284665476410623, 0.6238168165568383, 0.5583034287537298, 2.1412831641012624, 37.01931007446782, 91.53075941147344, 108.46285481606762, 104.07028659697502, 99.50089793051444, 99.59990639840403, 93.11837796242007, 91.2960369356217, 87.02729794286913, 87.79211305802869, 85.7125194611088, 91.09023801742062, 99.35162821123677, 113.33679983692785, 113.58842772822227, 114.90572437163323, 109.57849456417946, 116.0421605263987, 115.05657088372016, 106.62253364439934, 108.00422776129939, 112.61767248953544, 117.14775900686942, 110.78150903024982, 97.98154431004679, 89.73410990930374, 96.55032634735109, 101.14317078744212, 107.72718291128837, 111.06850885575818, 98.464231183452, 96.03151444465884, 105.50199877831244, 100.33799448320943, 103.22547081978091, 100.13592181667205, 95.77082587826638, 107.42310508604973, 104.66006986556515, 109.54951609334638, 105.70398515270603, 106.16767990973689, 108.60720588314919, 120.37338287599626, 124.47242444561375, 117.80640340620472, 105.5120086669922, 105.67611279026156, 110.5126227101972, 102.93271295485958, 108.71822464850642, 110.2739151062504, 113.17693971818494, 109.8244663976854, 101.47192816580497, 94.1915149073447, 89.04219596616684, 91.06538588000883, 97.54008154715262, 97.169127310476, 96.1682874925675, 89.943737060793, 84.61689949035645, 91.34363882003292, 96.6145904602543, 100.1317641042894, 100.11981656474453, 99.76600308572093, 84.85773301893666, 39.65143226808117, 4.027029059586987, 1.1174080016151553, 3.5003768292165574, 1.198515875204917, 0.2876284466155114, 0.3067673147926408, 0.16531837262934254, 0.7350480027737156, 0.34665166009818354, 0.18395462584111, 1.0435443780114575, 29.249314415839414, 118.59533325318368, 96.41159211435627, 94.66853787822109, 97.6218943442068, 126.52774641590734, 94.90363690160936, 35.920214883742794, 25.484568611268077, 58.816317281415394, 83.53306231960174, 92.38349053167528, 91.04299699106525, 17.23998381245521, 0.7292982983973719, 0.24131624058129328, 0.2723114685185494, 0.22004243857677908, 0.060359462344598394, 0.13957110744330192, 0.16829198887271268, 0.24733816664065086, 0.14351396280671322, 0.11671497381382412, 0.22817231684682832, 0.14054929447029868, 0.2044706749579599, 0.09632804115573246, 0.16919517589192237, 0.1551366810716929, 0.137732251276893, 0.23763903386650548, 0.2067537395463836, 0.15229755922430946, 0.1846026136509834, 0.1192985823558223, 0.2984862720533725, 0.16105060405548544, 0.1371797027006265, 0.21386449105076252, 0.1381770112822133, 0.13915830862618264, 0.28891317606452976, 0.2185512637539256, 0.14935279385216776], [0.06289649274080031, 0.02910780562688747, 0.047320967630272916, 0.041653311270619595, 0.017487950615524765, 0.025453047203500907, 0.03366899353662326, 0.0844537855816945, 0.07370116699847483, 0.10230037834375136, 0.044138776288638194, 0.11077950077672159, 0.03846385358502308, 0.02993245139688013, 0.02509657883145396, 0.047300980396328435, 0.16089507288509802, 0.07473070489903612, 0.03608367969131759, 0.09255877365508387, 0.1967070939680261, 0.04788364771933806, 0.06528416663528451, 0.17379387912731017, 0.06290152210802322, 0.008874963893885575, 0.2210868002786752, 0.21723431264681203, 1.8928102067401333, 63.277291636313166, 97.96794937502955, 79.44723129272461, 65.94118502832228, 48.6165701958441, 28.868836664384414, 92.39849751995456, 83.37979962748867, 87.71091999546175, 124.08044630481352, 104.46861113271406, 16.20315428703062, 0.33310737881448965, 0.03797930297291568, 0.32873280226222934, 0.13392061145315248, 0.06779357190093688, 0.09810937944078639, 0.34729296762135725, 0.8364060929706021, 40.36766490628643, 93.1646619304534, 95.56388162797498, 99.08790373033094, 93.94674331911149, 92.91890974967711, 82.37303703061997, 86.10539974704866, 91.70648943993353, 90.53169250488283, 102.63043157515988, 98.05585753533148, 97.7789774248677, 104.13570388670891, 110.99123816336356, 111.91709795305806, 103.58625042823054, 110.74009664597051, 99.69797349745228, 102.2609443049277, 103.29678735425396, 100.85871265780543, 101.7422265391196, 102.83012728537284, 87.87141553817257, 76.68348220086868, 87.76973201382546, 98.21326225034653, 95.85649044282975, 91.91958396665513, 92.91186517284763, 75.67305611025903, 77.98657986425584, 94.45119150223272, 110.40875834803428, 102.89279107124575, 99.05813294072306, 103.27115858754804, 95.33705880565029, 100.55949072684012, 93.04048753553822, 97.95506046664332, 93.9030481153919, 103.13051023790914, 100.89005239548223, 100.86595335314351, 92.6938049254879, 101.26084189261161, 86.06608190844136, 87.78480176002749, 104.62970287569108, 101.51856514715381, 101.85359831779235, 104.80212242372575, 102.32539669159921, 100.55151262590962, 91.68664224686162, 85.77523031542378, 86.3075351715088, 93.4760981221353, 96.98715286870157, 99.61548605272847, 100.35888502674719, 91.05607417321976, 88.20061222199472, 85.82057291461577, 87.49701746048467, 87.92915282710906, 93.1740285504249, 90.79904125582789, 59.01414594342632, 13.339885838570135, 0.6864415013021039, 0.6139459881571032, 1.1324115578205356, 0.4260892781519121, 0.1533001691343323, 0.18044891556905163, 0.03948136390517316, 0.06818650605817957, 0.1115478486603787, 0.008565132081839106, 0.3970691934227944, 11.522576232110302, 83.71423659786102, 86.64636519647415, 83.30728284774288, 40.19730068022206, 92.64522244853359, 77.53899035915252, 46.209670497525124, 29.471946185634984, 36.442203906274614, 60.604533687714614, 68.47546762035739, 67.80271837788244, 18.796199867802283, 1.5589910096699193, 0.5350617307328409, 0.0806719848826047, 0.2502680239417861, 0.1264105442791216, 0.25896888286356007, 0.07592394046725766, 0.08277831298689689, 0.10862680903125195, 0.023722506293486205, 0.08524841794203367, 0.07973126721598449, 0.019583195342772433, 0.041436971871242415, 0.12630864692431304, 0.035119960234770854, 0.04124806991087333, 0.018606506017667633, 0.010538057465436719, 0.028885105782518947, 0.015596856828778984, 0.0612660507941919, 0.11434717990097501, 0.11478240211163798, 0.0704063990363671, 0.07978097866139106, 0.1308662495425632, 0.035843859697061206, 0.03667622188767118, 0.06346479208479006, 0.07419750004285768, 0.04619607859621606, 0.014814249176021307, 0.025128748778614308, 0.0237155617064526, 0.017394677495523807, 0.005292453786223046, 0.09903183357129175, 0.06799890644728177, 0.056534691773835695, 0.01961375650529179, 0.08028584592525037, 0.007859404703917643, 0.0077792608945239945, 0.06699184556641886, 0.0333851502997981, 0.15220452550678484, 0.07504074834287167, 0.01748345176418943, 0.014305471990918441, 0.10705542480272633, 0.036464394746168007, 0.021457950389313123, 0.0470620452336246, 0.10426914003948051, 0.10493522284612541, 0.09277948358606908, 0.02093133197406367, 10.511512756347656, 98.17042996806484, 105.11139346707253, 104.82078506100564, 105.86980727411087, 83.85304143351894, 24.75126385688782, 34.193893478762725, 72.73989200592041, 96.62380803015925, 133.09756740447014, 113.63890863233998, 15.779503987681483, 0.6512528153196459, 0.10996390825077412, 0.47040994669641223, 0.07632560036595791, 0.10513176270309957, 0.5095653440202437, 0.15523780467769793, 2.281911656741173, 52.924403452104144, 101.38189408086963, 102.55714601086032, 103.8969413695797, 99.34875703627064, 95.62765152223649, 88.49527635881978, 95.48365346847042, 103.11344008291923, 101.54901058443131, 110.4130337315221, 106.1212076679353, 105.17776781512846, 109.08194603458529, 113.66729090290686, 111.47991841839207, 103.67293480903872, 109.20313158342915, 102.62703480259066, 105.13465312219436, 108.97446524712348, 104.323224559907, 102.77309602306735, 104.60964387462985, 90.10086720989597, 77.67282162943195, 90.09066904744795, 102.17199279415993, 99.94966414666946, 95.31681153082079, 97.89239668077039, 84.97212502264208, 85.40543710031818, 100.09203049444385, 119.83387654827489, 111.49415662211757, 107.2298969761018, 112.0226332449144, 100.91804242903187, 106.13895247059484, 97.51914393517279, 101.55286235194053, 97.91157707091301, 103.18314844562163, 104.72461638912078, 103.7201758353941, 96.78545674970074, 105.45722884516563, 94.23672414595082, 95.86690825800743, 106.3590209714828, 106.76179347499725, 109.20259814108573, 107.88677630885955, 103.05404755377002, 101.30060688141855, 92.74519581948557, 87.41958987328314, 87.38867375158495, 95.9481248547954, 100.49677987252512, 103.59074546444802, 104.50985877744614, 99.28299457796159, 96.04896899192565, 89.32856821244764, 88.4571195417835, 90.59157925267374, 96.05561348699756, 94.93007367657077, 68.99871180134436, 17.802508569532826, 1.1700343196430516, 0.24191587292138608, 0.9110342110356978, 0.513179685559965, 0.36971623859097885, 0.3574939186294233, 0.08826118127833452, 0.11577211110101593, 0.17082988494826903, 0.049985532513669426, 0.49543862140947775, 7.9402471165503234, 87.87900140208583, 98.47661018371583, 89.59670143742716, 47.92529952141547, 79.40040603760751, 28.058004302363244, 21.93084632196734, 46.59441971009778, 65.93854135082614, 81.8050935191493, 77.51158868112873, 88.53613961127498, 35.801068967388524, 3.9278440850396312, 0.36404259142375767, 0.12492325352204424, 0.13610480473406855, 0.08280309593124736, 0.05186096171758348, 0.050852556352413474, 0.01792575262727276, 0.06440144948541157, 0.01702165396343316, 0.06338071010466065, 0.012781471258119471, 0.008877581999366804, 0.08738484564087085, 0.048941098033420505, 0.07657087107579555, 0.027213116972557, 0.00753289180612492, 0.07238665205096045, 0.12323885600292876, 0.024807171881078713, 0.04315613446036174, 0.027908786094837615, 0.017476721681774627, 0.10872987850058465, 0.1055373373110929, 0.06951815073168086, 0.0935571394380062, 0.027267175966933854, 0.023642296887814038, 0.22688919618245096, 0.1832808974769808, 0.14965449459850788, 0.2219565552208693, 0.1613065080657121, 0.15355496997794799, 0.1630204459351878, 0.31993207611864616, 0.2633713143727472, 0.1570968242782739, 0.16898968046711338, 0.17691970171947635, 0.11344668185037952, 0.12073516575319153, 0.13423363497901347, 0.1651146545285179, 0.2107180606934332, 0.2091663955680786, 0.12764686463220468, 0.14756750255342455, 0.26591815835525917, 0.15420810589867254, 0.12436711965429208, 0.31790090123972586, 0.1741046503546738, 0.25757368353586046, 0.31656297464524547, 0.20848650785703815, 10.456032791445333, 115.07348414390319, 125.72370759902464, 102.27553552196872, 97.45982200868669, 60.73643122949908, 39.9389341569716, 121.8814165361466, 116.38261441261538, 106.12940542159542, 146.11371747909055, 129.765976782768, 26.076358172201342, 0.8344741417996345, 0.4674343999114729, 0.522187163512553, 0.2765468009296925, 0.24688753840183061, 0.43711901371998174, 1.010376938408421, 2.14838289926129, 48.984457139045965, 108.86008893289875, 109.7736873934346, 110.59412171763759, 105.20316908436438, 106.91541702516618, 90.99529312502955, 96.51393459689234, 102.25829278269123, 102.33306100291591, 117.07102175681823, 108.5560973998039, 109.6786875878611, 114.39584762819352, 119.32469798672585, 117.92900885305097, 110.84168603343349, 116.60247110551404, 107.91322092856132, 112.03830703612297, 112.63282068314092, 106.80719098737164, 107.06438864431074, 112.01988758579378, 98.99277056417158, 85.30519700819447, 94.48991314057382, 106.85032136978643, 107.36772906395697, 105.16362374828708, 104.25003313249158, 90.41844583326771, 91.91362980873355, 106.13790912012901, 120.44760980913718, 118.51431277490433, 106.27323089107391, 111.6323652575093, 110.22515220026817, 110.90274949227612, 105.68646000277613, 107.82484992857903, 107.55714031957812, 109.09585475921632, 108.1505164792461, 108.10489146940171, 104.00395931736116, 109.9871349334717, 98.69834176955685, 105.25103768994732, 112.18235215833111, 109.84121491832119, 112.03013281668387, 111.37698758033015, 109.46129414343066, 106.66243983853249, 98.99346090132191, 94.16444270841538, 92.75200505410471, 101.59396094660606, 104.78748413824268, 107.1484293476228, 109.93536749193746, 101.68587776922412, 98.85972376792662, 92.80870683731573, 95.95672269021311, 95.82076549530031, 104.33696070025044, 102.1740794950916, 70.83327493359967, 17.620998928623816, 2.571194546837961, 3.0118676875868156, 3.5773587371072466, 0.6445209862243745, 0.27406032467561386, 0.29015953983030013, 0.18059540690193254, 0.2481619869509051, 0.3754147376504637, 0.21478649318939258, 0.7370981153461241, 19.41450268991532, 102.64653682708742, 103.46198974117156, 101.46807639829575, 57.264109888384425, 130.84953938761066, 101.02133412514964, 63.479858521492254, 43.05581031307098, 50.39802443596625, 83.58871290760656, 85.17324847559776, 104.46610081580378, 45.45186858023367, 5.480255196171423, 0.5472463285250049, 0.2586877592388661, 0.31463632480271403, 0.34679669586400835, 0.30345223783966035, 0.16017646709036443, 0.15160651727309152, 0.23433673526010207, 0.15260541931756083, 0.1301743036075946, 0.12589459938387718, 0.15489878012768685, 0.14838441275060177, 0.18306190358294597, 0.22943554986869136, 0.09656368980124112, 0.1107195620575259, 0.1393120624725857, 0.19558195595539388, 0.1010578833219986, 0.14517082712583004, 0.25614091525635413, 0.1879988499586621, 0.2634086994634521, 0.2167308396629749, 0.17928614731757872, 0.2058896230113122, 0.13035706154281093, 0.17205306689345068], [0.061861496463778524, 0.04575313038883671, 0.04976229066209448, 0.039466957621757066, 0.03643542130087172, 0.059216133574204105, 0.090821830165242, 0.03758028224711457, 0.02403375824102231, 0.05009170463909546, 0.06550641640299751, 0.028715666285866213, 0.03195655145381968, 0.012344864343533353, 0.05553432650143101, 0.017523374521143494, 0.027618352586643833, 0.09110207278882304, 0.0693347646043666, 0.024129120865836743, 0.02403564473253585, 0.12463724225639336, 0.04317332547338259, 0.0674906837183141, 0.030425852239732782, 0.022086006506616553, 0.20376346855153962, 19.98468783593947, 93.34657361430507, 96.37586716682681, 102.37570501142933, 55.47799195012739, 37.436281558006044, 47.74717684715025, 96.53683339395832, 99.31955891270792, 104.40328797986432, 131.28750339631114, 94.34206331929853, 9.642742083918664, 0.1641486482995172, 0.07877132840334408, 0.22293189240078773, 0.09460254301947933, 0.05331965441244745, 0.06461263694349798, 0.28362061167436264, 0.40771334161681516, 41.449482056402395, 112.05106258392335, 103.59303612862865, 102.47648639063682, 94.52273553417575, 99.73800520743094, 97.91036898089995, 103.02259014498804, 106.77483143345003, 103.429653721471, 105.42088416314895, 103.50515934728809, 107.6025378319525, 106.17068444528888, 103.24669084241314, 110.86645972344184, 106.82853652584939, 96.85889920880719, 99.43716725995465, 102.22957318828952, 97.090209222609, 106.4457759549541, 96.4287877851917, 99.81358928065147, 99.3140362155053, 87.9297725615963, 73.59507852985014, 92.44849989491125, 107.42186561707528, 102.76454525609171, 92.55423915001654, 88.47331108585482, 83.13831498545986, 78.20278090815391, 85.54763870854532, 118.98385186349194, 111.27503733481132, 97.63184147496378, 110.50047120740338, 97.00574490331836, 94.24709489268642, 92.80108174970074, 91.6715254322175, 98.646605706984, 97.24406811498828, 99.36527805943643, 89.62260477004513, 87.0295415386077, 84.03978547742291, 82.62395889528337, 79.04949511251142, 83.96235789022138, 88.91474246978761, 98.16457779176774, 100.9860877067812, 104.86437043836041, 100.04469533120432, 94.75378667154621, 85.23123679622528, 83.85255505961757, 88.40312419399139, 93.74569831355926, 96.83994631613456, 99.61317185432681, 96.11118562759893, 98.90191278150006, 97.72081651995259, 94.57993938076882, 96.64775017769107, 95.32428756836923, 97.56719296978366, 86.84810838391705, 42.37776194849322, 6.882759938316961, 0.2864893964461742, 0.23362733784221837, 0.8465479939214645, 0.281628170200894, 0.08016850423788832, 0.01492463670025069, 0.06727231035549795, 0.09083726683691626, 0.13286426813612062, 0.1007243516224046, 0.22072732118108582, 6.827079442239578, 73.75358935325377, 88.58946815613778, 83.77949699278801, 37.71476984024048, 68.71750139421033, 65.78034823940646, 28.587869444201072, 26.71186254870507, 42.11362954108946, 57.464390031753055, 71.92851835681547, 79.95568813816195, 67.08794486138129, 16.6827424879997, 0.6521623761903855, 0.024929916403526743, 0.05156380770307395, 0.06515433771475669, 0.08587806560699979, 0.03923243512549708, 0.08940187087582965, 0.061882288090043494, 0.033703348749587615, 0.020202964303954955, 0.05310771235775563, 0.05898880847399274, 0.024036669375134573, 0.1575533667158696, 0.06295393401336286, 0.055606017009385174, 0.020022623376139713, 0.08993190412800159, 0.07621247216217941, 0.030287318645165335, 0.1255530697263537, 0.06104161001501545, 0.06116061028273356, 0.03515505089214252, 0.006648370997995259, 0.11384912315876254, 0.0030209939934373385, 0.04848413424746645, 0.033993619464097485, 0.06173408455065182, 0.04312288241400834, 0.08017542201184458, 0.09971791127276036, 0.02861011852209847, 0.10413757209936458, 0.030226000967705925, 0.06255108667837997, 0.052234571306936206, 0.04565455785561954, 0.008032939898135562, 0.045293113742504394, 0.019809143399939905, 0.03491754448341747, 0.020634631866649277, 0.06306096415726409, 0.04610250478670482, 0.056479223177678166, 0.015376454290573396, 0.06836765520875493, 0.01633755276880918, 0.04145155818532071, 0.11300381408223223, 0.09397080393447992, 0.012980334276724006, 0.5251852639259831, 35.3870863299216, 124.23492493168001, 106.25245801864132, 121.98652036728399, 89.8977041244507, 63.57117522147394, 23.479739312202703, 52.746214097545995, 94.8079232246645, 117.03221382633333, 135.13487785093247, 99.24713626984628, 9.321641172132185, 0.4367373487161052, 0.1083418932713328, 0.09980194345717469, 0.14649309488313814, 0.0941161614572329, 0.23335986590433508, 0.5473009965592815, 0.9838584065437318, 55.74717244794292, 120.11579298203992, 106.10643602186634, 104.90991700080134, 97.98642373854115, 103.64143817655503, 103.18330534042852, 108.38771789304673, 110.39892888838246, 108.06526768592097, 108.19695734208631, 109.76000616627356, 115.26759439899077, 110.2709105706984, 107.0998311811878, 110.53168542923467, 105.65704222648375, 100.5004982794485, 101.32006183747323, 103.29437901896816, 101.28220312057003, 109.4143904409101, 99.50345531586679, 101.85624199528849, 102.92752758149179, 89.52937003104918, 76.44125230850713, 93.89958074015956, 107.54818947084489, 106.86324950187438, 98.81922921826764, 90.69171736317297, 91.12811242380451, 83.78115223300073, 90.8171469165433, 118.22730510465561, 119.52841020399525, 101.77097751248269, 110.9577960352744, 106.18205147404825, 95.90403741405856, 101.51933393170758, 95.31449733241912, 102.62193572136664, 97.39820157327961, 103.92724560153101, 93.7761123718754, 92.36017596337103, 87.38888555957426, 85.99238057290354, 86.582854178644, 92.5890148839643, 93.55569085767193, 101.11078769929948, 103.90693556877875, 107.0199481902584, 103.34894703280543, 95.53072191053822, 85.2305543038153, 85.77537936549034, 90.41666507720949, 95.98548150831654, 99.28996855212797, 102.4527011379119, 99.26540667010893, 100.76385405755813, 101.59777349041354, 100.20125281426215, 100.31064771836805, 99.87973613123741, 99.322861548393, 92.34929530851304, 52.47228753182196, 11.612863309921758, 0.7064166004138609, 0.6014766508052426, 0.27419555451600786, 0.2884763220865881, 0.1263226510115689, 0.4045776211686673, 0.2300048298052242, 0.10424032747264832, 0.14604087318143538, 0.125071506857151, 0.2718709066750542, 4.083123856013821, 71.46423524425876, 97.87407136732533, 88.4815872869184, 47.214875913435414, 64.95353614130329, 47.93375222913681, 20.383037867084628, 38.82495749381281, 62.37494645580169, 84.02237799859817, 81.95475547544419, 91.63008166897683, 88.44522691542103, 29.315188661698375, 0.5867050047363005, 0.0692103978907389, 0.022309436049732952, 0.05998537395029299, 0.013159228255972268, 0.028876473886832118, 0.047748241678721486, 0.07018159053498699, 0.018165218305864164, 0.012546960253178353, 0.08677039716032245, 0.12726479360172827, 0.02602397422907093, 0.03611240415803848, 0.03888700991087864, 0.013367491173407724, 0.03518365278479553, 0.04345035435812127, 0.06691318365835375, 0.02921471319672081, 0.08328653571586456, 0.032203344763406826, 0.09179837776408081, 0.04164428675487157, 0.07496913444370994, 0.06420137796310649, 0.07757789365226224, 0.033171116825072997, 0.13287050409182427, 0.1039084735056085, 0.16078708513129145, 0.21240451132818577, 0.17035768367350104, 0.18154546318034973, 0.24549558728692994, 0.14617444827191292, 0.18491113257984962, 0.19774601644565984, 0.14848322277107548, 0.13202791462742514, 0.151824270104689, 0.10129448191653337, 0.16347182494017387, 0.131852894180244, 0.13174291459783433, 0.17353163190907048, 0.17065175418411532, 0.22383345531359797, 0.09344052553417222, 0.194279162153121, 0.12022020911136944, 0.29405396311513843, 0.25747902571193637, 0.1333837370358167, 0.5010714207685764, 34.93473898979926, 148.41429741151873, 116.32889363073535, 130.88927299745623, 76.6884949899489, 48.590204023545795, 67.34719784029069, 133.6862837883734, 136.30754101660946, 125.48399586831371, 153.65074003896407, 114.53213430220082, 16.675182119492565, 0.6061078668121369, 0.20183096579726667, 0.46490036491905495, 0.18719586723994824, 0.45550702380076535, 0.275743450488775, 2.596103068320982, 1.9751582847487543, 49.76622866046045, 127.46497323436122, 112.136915422255, 110.57509822230186, 105.14373733151345, 107.8400138116652, 106.9772728027836, 115.79617300341206, 118.36565494537355, 115.94326188487392, 111.2449449108493, 112.44146393191431, 117.27872694692304, 115.09513562725438, 108.51863091991795, 117.35908846701346, 112.87729417124103, 105.9933070213564, 109.20404157330914, 109.99531699765114, 105.53345618709442, 116.14409508243685, 103.17708446133523, 104.90619074913764, 109.1587931110013, 93.96132669141217, 81.08402852089175, 102.61576191071542, 114.1041801821801, 108.98305523780085, 104.37980867201283, 99.1607342996905, 97.75028920942738, 91.98482867210143, 98.12276532573085, 123.32091854464625, 125.48760444887223, 112.71884610576015, 111.64478348147486, 108.21112494314872, 105.33435667714765, 107.32183733294087, 100.99397167082756, 106.8583308496783, 105.92444589061122, 110.40761301594397, 100.82641586180657, 100.97610135232249, 96.40683820170742, 93.30115256770965, 87.94590134774485, 97.90348129887735, 96.59606118356028, 103.59437757922758, 109.50797034848122, 112.30145885098366, 110.70892164784094, 102.68164204012965, 89.46773390616141, 89.96372545919111, 97.12661666254844, 101.25430722390452, 103.58338709800475, 108.3165111849385, 101.18172768623599, 102.92788059480729, 106.3394561890633, 103.85679198849587, 105.46018631227555, 105.38921494637768, 105.5068782068068, 97.44790584810319, 50.77553687557098, 10.453846070074267, 1.5997269076685754, 3.6792557854806227, 4.696114072876592, 1.814688360018115, 0.12211108264783699, 0.45648976139003233, 0.3881725837146083, 0.3699825307534587, 0.29240690472145237, 0.3050155475014641, 0.5840895805628069, 13.470187956287017, 89.5213919301187, 104.87318008176743, 102.17387553184264, 53.954817941111905, 100.4695821577503, 83.77606099651706, 42.0735703745196, 33.74041257366058, 56.617299279859, 80.63185768742716, 86.84259353145477, 103.7974935962308, 104.58981237103863, 35.03964278005785, 0.747238545408172, 0.12663250293342337, 0.10500631580549864, 0.21205679934111335, 0.2598978104370256, 0.22013254583843295, 0.236529064394774, 0.2545207618705688, 0.17415354208600137, 0.09775100350980798, 0.2377738959846958, 0.19510272199348097, 0.11959098279476167, 0.26379214179131294, 0.26706186633917595, 0.17413160132785, 0.10328090959979642, 0.18856817586047037, 0.15052397374904927, 0.1653736841774756, 0.28305628066582067, 0.18178520273537407, 0.18815824221218788, 0.19750551080271123, 0.12770401479135599, 0.24549598565265057, 0.2189651504158974, 0.19018695028799196], [0.050510210811250636, 0.03241800643022984, 0.06894291063109714, 0.057539063686084364, 0.040256606580148784, 0.059718066721313426, 0.0347592132616668, 0.05852968432009221, 0.08286957704131642, 0.04069170621674388, 0.1222009294395966, 0.04931504853189953, 0.029154230555098866, 0.05562961251745301, 0.08038840977655304, 0.09381667470499393, 0.03380425785097384, 0.060882949375457344, 0.0769081183018223, 0.0661299200428109, 0.04898678368678497, 0.09052045883670931, 0.2430148720140419, 0.09803405001519189, 0.6451279730085404, 10.274262312919864, 49.13866512237057, 97.6520416813512, 95.5033359219951, 58.08050809368011, 52.258643873276256, 46.753083505938136, 43.093896527444166, 120.02427624117945, 94.38906900344357, 99.88914197491061, 121.46109534848122, 88.97825348761775, 6.79262092997951, 0.38236830323453874, 0.042991647722139474, 0.09045842103660108, 0.07316124355120045, 0.28847800748002145, 0.23018245495134787, 0.8043691539956678, 2.0224634173416325, 19.89702090140312, 118.8258509482107, 94.31682678960985, 101.83886589542513, 90.6703326009935, 103.65394269266437, 101.848036396888, 108.5581684112549, 104.46964663843956, 104.97174924419772, 105.15384920181768, 109.46508315301712, 108.91367635419293, 109.35113829951133, 103.83126520341443, 106.84362980627246, 102.35894080131285, 96.83592196433776, 93.31075452989148, 90.95813259001702, 89.31906823189028, 94.12685855742424, 92.202316253416, 97.06123859651628, 99.6059468484694, 98.17792169509396, 81.81072604271674, 73.74699977136427, 80.5313979425738, 99.71152136402746, 102.63404800045876, 105.17241770221342, 85.38855521909653, 81.41374295757663, 70.83204330936556, 75.6184410279797, 95.87723193630096, 110.44941763724051, 56.32281164969168, 74.9367566262522, 109.05402660369874, 88.85675414916008, 94.6921819256198, 87.76373078746181, 94.25739503675892, 91.3830037270823, 85.47884818046325, 75.94717487212151, 75.19615865522816, 86.78993178952126, 89.02427073447936, 81.33081620739353, 80.2278692491593, 84.59531860966837, 89.43381324891122, 95.42386870230399, 99.34823928340789, 103.30122747728902, 98.20246004289197, 87.39403170924034, 82.67676968728343, 81.83330320542859, 85.01578100265996, 90.56710366279849, 95.46930543838009, 99.66343310571487, 100.03419906862321, 98.76746177673341, 99.03322589012885, 97.87200820061469, 97.99129532229517, 95.25189630446896, 94.4314698250063, 91.52315785807949, 59.851081678944254, 15.821869507912668, 1.4504050944120654, 1.4363698733429757, 1.3744197136932805, 0.8881662413477899, 0.06430140606337978, 0.10921970745849033, 0.16427813248047907, 0.053340235364533244, 0.206630322781782, 0.006822980630526981, 0.456788198601815, 3.5681232713883926, 63.57627430269795, 97.74850845336915, 96.5047876296505, 52.79959755559122, 66.32494188124134, 86.22584004555979, 51.63989782333375, 32.224365511248195, 39.45418803922592, 59.591538444642104, 69.61877576766476, 70.60194138557681, 83.02855137855776, 32.35001667853325, 0.852942254033781, 0.03280368956526922, 0.07481004862535386, 0.08585571882224853, 0.02891974827845491, 0.019642915726909717, 0.032414229616763136, 0.011391789678694501, 0.06317886508881085, 0.06636728472526997, 0.04888990037744084, 0.03705223699310615, 0.0066932805085314385, 0.02686275815170619, 0.0046845548786222935, 0.03945460062353842, 0.07270241817159039, 0.015601509855309082, 0.081155049284139, 0.06879482583533372, 0.07855058016796267, 0.03627152445035116, 0.0258756902504472, 0.06711869440492123, 0.06767956269604546, 0.058132322174647165, 0.036323898051294594, 0.06731865101403768, 0.016188638682867733, 0.1264107587837404, 0.1500527990320998, 0.029928827800998287, 0.0610802399985973, 0.032854373942339615, 0.08030751855262826, 0.052693967422049855, 0.04140905179684201, 0.01743720686664024, 0.02325260902815048, 0.02911264155690949, 0.039970131831303726, 0.022822130816958608, 0.02459962142541284, 0.030507861952027007, 0.01566680065626579, 0.10391879270994857, 0.06320247974907679, 0.12696362911693512, 0.012825012822905857, 0.2659652267973269, 0.004839735563784357, 4.020295575741799, 19.608432515974968, 73.69349864221388, 118.85169936764626, 112.3713868664157, 99.02111361103674, 93.8678252312445, 65.37424172124555, 19.93063561377987, 80.50288231142106, 91.01174354553224, 110.37231952913346, 125.72446853883805, 97.95001629860171, 6.445938319929185, 0.4529126210799141, 0.07709924957805103, 0.20382585875209303, 0.05161443845398965, 0.19250099547207358, 0.35650538941544874, 0.8898796429557185, 1.5128759487021355, 26.8923778687754, 128.61511415050876, 98.06733439045568, 107.30685387888263, 91.62412751105525, 108.12760199269941, 103.84256947425105, 110.66172768992763, 107.69199925084268, 108.90362724181145, 108.65904392734652, 114.79607059109597, 110.21806839973696, 111.0729411340529, 108.96765601250434, 108.57348134440761, 106.26398978694793, 101.80077968105194, 94.38619782847744, 92.03271296716507, 91.94638944441273, 96.58716524800947, 96.69579921230194, 104.75088057979461, 105.19987429341963, 100.26375970532818, 88.13547734291323, 77.43288240125104, 83.41415959019815, 101.42666401401644, 103.97425128567605, 108.18326827018493, 92.71907283413796, 90.07499525623938, 80.05966232668969, 83.64040974647769, 98.07484965170585, 113.46401799109675, 65.27475472419493, 72.19379609630954, 112.3963252959713, 98.59720737703385, 98.3549225714899, 95.3071468107162, 96.55763764535227, 95.72662861116471, 88.88645433610486, 80.73086615531676, 83.69419328628048, 92.63551850472727, 94.49262742073306, 85.42297793972878, 86.97979019534203, 91.1969421755883, 93.56196664994764, 94.93994235992433, 100.37153859292307, 105.5391122448829, 100.9087150327621, 89.64355807150565, 83.475842783528, 83.69911978321691, 86.09551537421443, 92.75515079498292, 99.25581255266744, 101.22749390140658, 102.43865120795466, 100.74106508685698, 100.7051597102996, 101.166453976785, 101.24694101272091, 99.8514715317757, 97.73612160836497, 98.23724362158008, 71.29410636040473, 26.056730631859075, 4.835798990341925, 1.2701399480142903, 0.7616017746829218, 0.4340510460878573, 0.23354954927438693, 0.25701128306888765, 0.3603403642773629, 0.009805418855150141, 0.13965553033255762, 0.02510143774411371, 0.5529823658927795, 1.5072913515952326, 63.69201952411283, 102.0013383127028, 104.52186123017343, 54.20726953014251, 65.2346053431111, 51.49784134280298, 28.928894035277832, 55.17802084645918, 65.07001484594038, 85.31949012510239, 86.22460057658535, 81.59334828776699, 95.32288335984754, 52.08629100553451, 0.6110615751916363, 0.048961173367476275, 0.08074480153980755, 0.05695927302323042, 0.01903097809953315, 0.10788520527703148, 0.0612208592675386, 0.0647239112144997, 0.06911782382596886, 0.04282235761263198, 0.031179588911454045, 0.08355610673466037, 0.06031709768238568, 0.02848253232396899, 0.016112165871046243, 0.044623706114268115, 0.018678780667664065, 0.0854930068336187, 0.056533412407002145, 0.03425904594722294, 0.011779696383934108, 0.013013945426791908, 0.037053987504013126, 0.04900302858121934, 0.058412143449869856, 0.04477747911286931, 0.029908097461767258, 0.2702104877079687, 0.2379236202086172, 0.09900139689806009, 0.17933330769019742, 0.07404471146723918, 0.1475090960100774, 0.14541231336132174, 0.2557592349307191, 0.14981935671981306, 0.08900178145737418, 0.22720179069907437, 0.13244645910397654, 0.21219428148000472, 0.11770210108689724, 0.17598230121356828, 0.18256200056883598, 0.17924310849799266, 0.16246811186354007, 0.20314741128635025, 0.1986249797647038, 0.27519631049325394, 0.2039775135175836, 0.41579057432470784, 0.30988829570912546, 6.686107006765182, 26.31195337541642, 85.1746448393791, 142.97648029942667, 119.38655376434328, 91.96022756638067, 73.84161518466088, 54.89012279818135, 65.95875724669426, 156.22602708878057, 119.8026466369629, 121.92935574439265, 141.4749969974641, 112.38002392553516, 12.846636022290877, 0.7969912982756092, 0.1806227102755539, 0.39271113372618155, 0.2267495843191301, 0.4300326697768704, 0.3337063369972091, 1.3995956917924266, 3.4934124158274744, 25.41954355855142, 136.3907423327046, 102.57153326465239, 115.58800497362691, 99.14877107066494, 113.38227579670568, 112.16488976632397, 119.23293021417435, 112.70594150789323, 114.15072302664481, 116.18758632290749, 118.68765015755932, 114.6617058784731, 111.61525587881766, 114.48219468516689, 113.38197769657259, 114.51072600580032, 110.45699565641343, 102.13705232066494, 99.34939246023856, 101.28096365159558, 102.62720738687824, 99.92882067157377, 106.48523499888759, 106.2293395688457, 103.47300375661543, 92.77448023519209, 83.10238607468145, 91.90351009368898, 109.43911706247638, 108.77238473584576, 111.50606493796073, 98.45630799570392, 93.89424631672522, 86.39198380131876, 92.56238983523463, 111.91483866783881, 121.07740125348492, 80.34864687150525, 83.99334461458268, 107.61033550385507, 103.42606083039315, 104.07231053998395, 101.54212290240874, 102.21278544395201, 101.81999929489629, 95.63255448495188, 91.82015188278692, 94.56104924601894, 97.64638562356272, 94.26538098242976, 86.9437671476795, 81.42833417461765, 91.04546808427381, 92.49690978757798, 97.6365718533916, 100.50981783097791, 108.29835061104068, 104.067486024672, 97.00605084819179, 90.19403134622883, 90.83157339403706, 89.51468467712404, 96.47311056813886, 104.3995068150182, 110.83602997564502, 108.25423179134246, 105.43469090615551, 106.00366207861133, 107.19871413323187, 107.1034711407077, 104.28338112369661, 103.87878864042221, 104.86901452464443, 71.20830843525549, 21.630118200855872, 3.533934176929536, 3.7089412635372536, 4.868888595411855, 3.3629168762314707, 0.22975916072966593, 0.2616704153197427, 0.7108155385621133, 0.12297038048986467, 0.36940002813935285, 0.15839031777314602, 0.8660411317982982, 8.277817080097815, 80.90477620401691, 114.02064154225012, 112.01338429604809, 67.40389962350169, 81.96041153323266, 103.01004640517696, 74.34218806605186, 44.653344615813225, 52.21059483866538, 83.56926579629221, 89.73120735537621, 88.63314767037669, 114.95482460145028, 61.73145809481221, 1.039818371495893, 0.37367424717353237, 0.16482867390638398, 0.24030924864834358, 0.18186299130320552, 0.28931757855799894, 0.19561613879857526, 0.13194776650878692, 0.21952903709344326, 0.1584534893833822, 0.14799482639758818, 0.12490084545025903, 0.13164631091058254, 0.09511818147955403, 0.12773399947271233, 0.12422133312230149, 0.1473091470618402, 0.14405361046233486, 0.15900190108485762, 0.18570706728966008, 0.0979795198767416, 0.19592796722727437, 0.12106859786135536, 0.2601027849220461, 0.16946267847332264, 0.26084205976897673, 0.14875135354457364], [0.043449829587893146, 0.030500415577403003, 0.06038804508505329, 0.006148167773179951, 0.03510317141791025, 0.0502677669658536, 0.02883639216663376, 0.01855462654343536, 0.06703103096374581, 0.04060361376633087, 0.09880183865466426, 0.05705664279840647, 0.08406534836056732, 0.03332994217353483, 0.012455619589966393, 0.12993742922140708, 0.10619238079074891, 0.06046574555277344, 0.09231749426333175, 0.06805149072240438, 0.04626535209676912, 0.043189344371879296, 3.265481523929104, 33.192524140880955, 77.11051848626907, 99.30856843148509, 110.21569144341254, 84.52663006321077, 73.8615486698766, 52.90612128473098, 43.30240972580449, 51.70635454116329, 150.08346988308816, 76.96623017711025, 101.08376256881222, 121.3762858606154, 95.63579436271422, 8.856665761240068, 0.6634410290468125, 0.05464824622557048, 0.09017505277428897, 0.09295320168377892, 0.2501941424223685, 0.027455737018176628, 0.14870192555169906, 0.7892124414924653, 0.25789930154719665, 62.99925050427837, 104.2483857370192, 98.1498061456988, 93.19099672379033, 84.34700904353973, 87.00849410026305, 93.01875760478359, 97.53806544888405, 104.48812100195117, 106.31082288680538, 99.57030819308375, 100.17720084036551, 103.0184716563071, 102.01174043839978, 102.408566628733, 102.86940590027841, 94.31816824020879, 84.21671575115573, 76.25673617086103, 77.01143941571637, 75.19715493725192, 77.0303766189083, 88.548887314335, 96.29254817962648, 99.26583028608754, 98.35973139732116, 84.9028951891007, 74.67475014348184, 77.54251264756726, 91.0087154757592, 101.78123843285346, 101.35814020710608, 93.40306358952677, 90.17056772785803, 79.13894084192093, 72.79144763946533, 65.21900215456563, 84.20563113304877, 62.49732048280778, 45.65699677313528, 82.88503969869306, 105.42529290722263, 92.48429544510381, 88.30435891305247, 80.41815127095869, 76.66685135133805, 68.3966044456728, 77.16519632647115, 78.00088867064446, 83.56545325248473, 95.53276938776817, 84.70460368740945, 99.41383700216971, 96.61084067436957, 97.46094380655597, 94.96561819507231, 98.5937007780998, 102.13760145248906, 99.35870416702764, 92.6201428136518, 87.77453299491637, 77.31146935493716, 76.02305704547514, 73.88803251328008, 77.70331413515153, 84.73042072788363, 90.37678241729738, 92.25934751572149, 97.20115738530313, 92.6444144402781, 93.72251710584088, 93.38169451682799, 95.17634361020981, 92.51560380381923, 93.79566146481423, 87.91224741166639, 67.94837951660156, 28.031808753167432, 3.917040651844394, 0.9498838167036734, 0.5641160749139325, 0.15604291712084126, 0.0582396587537181, 0.1845555605306741, 0.050691562975125934, 0.16147218224021698, 0.03730069845914841, 0.5012246996404663, 3.6878077781969503, 56.47770212542627, 87.52860038511216, 97.1955797749181, 44.358127424793864, 48.431304885495095, 69.50803941295993, 27.570585089345133, 25.114290983446185, 33.55526493441674, 34.00303094617782, 59.634594302023615, 73.09018319652927, 82.37501390518682, 28.39688139577066, 0.44244271192339163, 0.06414238536249726, 0.1109530350133296, 0.0073246451680578535, 0.03759043291211128, 0.04633324663905848, 0.04419015014484044, 0.015051373498394124, 0.08842125535011293, 0.022541518555954102, 0.052598846114931576, 0.07380303370976642, 0.04474123932361122, 0.02117893350641093, 0.01444898802982343, 0.021678240887159785, 0.04335979127415246, 0.017509937338951616, 0.03374431913177814, 0.07948709967275781, 0.026393291810827873, 0.03384471112381547, 0.027293326378229166, 0.03987980623459143, 0.028074843313304648, 0.026867879449480006, 0.01653668774862684, 0.028653333541907133, 0.03235693773134582, 0.07390503065600511, 0.1027929882008222, 0.02324832276621413, 0.07286000245761487, 0.0970398594114569, 0.05696238717064262, 0.04036382824603108, 0.0407465466208035, 0.008697594429606633, 0.08416497043424076, 0.02413883869115624, 0.022310981632120187, 0.05891147572847624, 0.027854311497761842, 0.040462113496276646, 0.09357313535386518, 0.01566258046941291, 0.119915091612887, 0.03144440443945989, 5.725824496438427, 48.0928082619944, 103.59490317683067, 121.61082006269886, 133.29213265449772, 99.53495194835048, 114.15551616299538, 60.25050447833154, 31.34667831082498, 33.41360853564355, 105.91830345892139, 87.64500848708614, 110.84581236685477, 130.0363379140054, 103.33081783786898, 9.511856513638651, 1.3554752786313335, 0.04627746011641237, 0.12538072292602834, 0.03425585902145794, 0.16675417461702902, 0.12698321798515896, 0.1521536725903711, 0.5986522991330393, 0.4196152223214027, 73.04465232356903, 106.0798345073577, 102.6796651655628, 94.7576541285361, 86.5271172984954, 88.9248151163901, 97.18225940581291, 100.44003886561241, 106.2492730540614, 108.30438321636571, 101.83900710075133, 101.9911793739565, 104.59177355612479, 107.2626252328196, 104.96753661863266, 104.71832490736439, 97.60766398522162, 86.6091654377599, 77.67889345845869, 78.10097186796128, 77.2260715115455, 79.8074225456484, 92.93816858722319, 101.57208981052523, 102.39457161195817, 101.84460040061705, 88.85753862319454, 76.14481526036417, 79.27838110154676, 93.7878167244696, 101.8967051659861, 104.11579393571424, 95.95200015652566, 94.65659818341656, 85.03944858427971, 80.45258183633128, 75.00515491731706, 86.50380273019114, 73.84426670689737, 54.09050057011267, 78.42325733553979, 108.27538905605194, 98.89397390427129, 94.95385108455535, 86.55205572805097, 80.94767124422135, 74.37196670040008, 83.9752075749059, 82.79826902574109, 90.3516870929349, 96.3776949913271, 87.88211576400265, 101.08301731847949, 96.95994730918639, 100.3537545665618, 97.30743008275186, 97.77716528984809, 101.6951894760132, 101.4699120675364, 96.94031192410378, 91.6611546854819, 80.7880856913905, 78.10762420777353, 77.09969274459347, 81.60433092424947, 88.95913585539788, 92.58934436305877, 95.68386693154612, 99.97248449633199, 96.63903467116818, 98.22448022903936, 97.08927569850799, 97.7753923785302, 96.111460193511, 95.13893204350626, 94.21705738190683, 81.80401878972208, 42.38933686287173, 9.05253617994247, 1.195108806413989, 0.23920963668534834, 0.17899134136255712, 0.15560263106899877, 0.27725288884774335, 0.2651156965763338, 0.12737627471646956, 0.063514357973491, 0.604011421242068, 1.3759637792264263, 59.95044316014936, 94.43590210330103, 105.20538914588191, 51.29697676627867, 54.20965433120728, 36.23135297529159, 19.936660374364546, 41.68507137606221, 58.29868601214502, 60.728296233761704, 79.557661702556, 81.19692217919135, 96.0491886446553, 45.11217955620059, 0.3046895311244073, 0.07682967089837597, 0.03691310393473795, 0.060096786117121104, 0.02278778326487349, 0.05319085971061742, 0.07791107295141106, 0.03612971008424798, 0.027612020869949655, 0.08342565728291389, 0.06436735091190185, 0.07123207327939811, 0.018530783972011942, 0.0400992214769846, 0.04113484977654392, 0.010757178721588948, 0.027212088499518654, 0.07791216079626354, 0.005584004346371419, 0.048229015477362185, 0.044334569209886175, 0.035490264154730305, 0.06256528994849613, 0.062145833827314846, 0.012210740542580045, 0.09821371295519414, 0.10876976103792269, 0.11280288454145194, 0.1457049283048799, 0.12160944061413889, 0.21395861261313964, 0.14382643474926873, 0.12176222152887814, 0.1578889745137384, 0.1784977509129432, 0.12511715803655887, 0.20191111391590488, 0.19384661358931374, 0.34334871797792377, 0.1278295153151116, 0.07118164171134272, 0.16394989444844185, 0.24532072005733369, 0.1490489940249151, 0.2646590775299457, 0.15658218173250077, 0.21525676392259138, 0.05544890003699449, 8.068026169653862, 61.039826562327725, 122.3130419946486, 143.51379794459191, 145.37555879162204, 105.45732298204976, 102.16944325354793, 66.38558956884569, 54.17860092655305, 69.2563722979638, 185.31692874047064, 103.23424908422656, 126.7530159796438, 141.12019508115708, 121.20894185958372, 17.881126596081643, 2.058892062594814, 0.4157182556246558, 0.2225340476199504, 0.3274887980472657, 0.48211960061903925, 0.37331440035373936, 0.564609496824203, 4.484745879327098, 0.7219926388032976, 76.59105547012823, 116.75805584076913, 109.24332018821471, 101.22917267584033, 91.55019867804744, 97.27088928222658, 102.3563991054412, 104.616908104189, 115.32070329112392, 117.15098319515106, 110.22485410013508, 109.87501005972587, 110.8349709356985, 113.66572979957827, 109.39315472879719, 111.74245049876552, 103.47154463491133, 91.24876453030495, 81.26515573070895, 83.83123305536087, 80.94887933423443, 85.21407250435122, 98.1885277840399, 107.27213305811729, 106.60333756477603, 106.23501131611486, 92.92289487777218, 82.83171115383026, 85.0464225584461, 100.14160140868157, 106.66362439432453, 105.93141202003726, 101.8506016269807, 99.34310882322251, 89.37096903401037, 89.68760628854075, 86.18923648711174, 99.61445054700299, 79.07656731144075, 64.06904166744602, 87.17387691620858, 107.06426312846523, 101.9132261891519, 97.88357134788268, 89.98103095639138, 88.12014872027983, 85.58774886592742, 95.77192414191462, 90.71343944918726, 95.88634752458142, 99.21906778889318, 86.65803032536661, 106.2345092527328, 101.2788926401446, 105.1660713072746, 102.60950180792041, 100.64326470898044, 105.69421845097696, 106.5867930073892, 100.81669622851958, 96.67114319339876, 84.23373883770358, 81.68549260785504, 81.91641038463962, 84.47692578838718, 91.22067251513081, 99.21696539848082, 102.71953213599421, 108.39106759717389, 103.42970863465341, 104.54549743283181, 104.78102791693904, 105.88610079980667, 103.84075733923144, 106.744260480327, 105.06756490276706, 82.67354549900179, 34.80071944575156, 5.457057318379802, 2.7531432480581346, 2.0522080986730518, 0.6019171820052209, 0.19797717581593222, 0.576124411196478, 0.33060230194560947, 0.31181761153763343, 0.29197081683143494, 1.1501019375939523, 6.289826516182193, 75.70130502024006, 101.40539692294215, 117.89067160698676, 64.22853308339273, 79.0345665716356, 92.998667224761, 37.9930620039663, 34.983345000974595, 45.368227958679206, 51.01525252865207, 84.23770827631797, 87.91113345853745, 109.56716675912182, 58.195311946253625, 0.5105888374870824, 0.14231005563370644, 0.18181301172702544, 0.2176699102405579, 0.17586882827022385, 0.1617520801242321, 0.15675838195508526, 0.12804182126156746, 0.1939715318862469, 0.16850417990597988, 0.15148645597359828, 0.1956479314474329, 0.11097792520998948, 0.12485238272816905, 0.1346336401277973, 0.09579223160061145, 0.12302607508195985, 0.18842456501818475, 0.17734815937376794, 0.1470759652194477, 0.19717819207618315, 0.14819777841048856, 0.13316503425519313, 0.10751369093815166, 0.07865745709427903, 0.1141905608857351], [0.09809759700851095, 0.008621579355319903, 0.03201197216948194, 0.07893489583605721, 0.03565536759373161, 0.03652462074833532, 0.07635269689583972, 0.07714120055278463, 0.047643862199038274, 0.060786786188762036, 0.014417836979602375, 0.016488146502524614, 0.08000875192303812, 0.10927178611558293, 0.038400318083022876, 0.03193856945501701, 0.08408725081432251, 0.013595898372812137, 0.059803834094876246, 0.0489837461481652, 0.34887233448605387, 29.44986128037976, 91.14272717506655, 107.02579252181515, 111.2297418040614, 86.29464626312257, 67.5681527968376, 77.7535753865396, 47.65851559177522, 170.83131759397446, 206.9025633412023, 150.269437297698, 86.27361451425861, 104.43254886134979, 122.31219476269139, 92.17635800761562, 10.71744699631968, 0.9530711714779178, 0.21132861744732628, 0.31723832711577415, 0.1013235702750183, 0.09806371293962003, 0.06874924360383904, 0.35791367352489506, 0.09999348076000329, 1.3549420814360342, 1.0137221685821012, 77.81026932501024, 99.68642603966498, 94.4020285144929, 91.51647413930586, 84.10186875251033, 80.84820778139176, 76.98170000506987, 81.70573203794419, 83.74563124872024, 85.80278888825448, 84.05651046383767, 87.36145250258907, 90.33584856217908, 91.10838290183776, 89.61525424834221, 83.81279791555097, 76.39556454073998, 72.0368306867538, 74.83748928193124, 73.50179672241211, 70.65192807105281, 72.47299824991535, 88.11267268273139, 93.61021964780747, 98.12780164903211, 95.9634691669095, 81.16992842766547, 72.9808432056058, 73.36438825053554, 86.43566331555768, 98.80188449736565, 95.0257481298139, 92.53522349942116, 90.77156113040064, 84.70231302322881, 78.71705070618661, 70.65141031819006, 68.29551712159189, 87.19338678544568, 68.10380735704976, 52.85198865398284, 89.57517546992149, 92.92254970919703, 93.03769480797553, 84.84927638884514, 72.5804005899737, 73.13442753207299, 71.02236455486667, 83.62570870307185, 83.14958003259476, 83.6698353675104, 96.94257905406337, 88.81545943598594, 88.73285432015696, 86.45842090729745, 88.6459110629174, 90.84618814529912, 96.64904455984794, 95.74129043086883, 96.88711673982682, 91.78641165456465, 90.55883530647525, 83.32417257370489, 80.02964050539079, 71.67665512331071, 76.29078234395674, 73.14353527561312, 75.52329217233967, 78.2299864676691, 82.97774099534558, 81.19119551873978, 82.45405750889933, 81.61206583822928, 85.30320444414693, 84.41296762035739, 90.82175177912559, 94.87091648963191, 105.03418553260066, 80.47316643499559, 31.228999360915157, 0.4284522916761137, 0.7200183995789098, 0.24562094991485922, 0.20613449535542921, 0.19468456056089173, 0.11461260638410047, 0.20822056809500342, 0.12299438202453238, 0.5353229360715036, 5.474260343659309, 50.974506947302054, 78.4602923547068, 96.4264343630883, 48.48886174540366, 54.39300944728237, 89.53987413837065, 47.18516395938012, 28.597387075424198, 34.96805952441308, 45.74223379934988, 56.678241145226266, 71.76264132222822, 81.37762577302995, 18.758433326598137, 1.2254749382695844, 0.14904678769169316, 0.24231655222754328, 0.030758299924913916, 0.15220633347428617, 0.041896341173278714, 0.08661395434530512, 0.011438182048169116, 0.014075243417474051, 0.02666153749751468, 0.031869809233373216, 0.06463763439246724, 0.022392591063473976, 0.05667936747833606, 0.0864712015214947, 0.015252241752140466, 0.02054759470235196, 0.036913295456719016, 0.00275628739355823, 0.049684471450746066, 0.05584933802545552, 0.06606552269189589, 0.012344111662147748, 0.027442677134287455, 0.05480342116507311, 0.04026587624403258, 0.03510291860889524, 0.03992963259318664, 0.021720142066178304, 0.050126446726461577, 0.022056753439227902, 0.07027577338439804, 0.06150253830597766, 0.03449391701348847, 0.1144943300694708, 0.02653599866936284, 0.032439636922771894, 0.05684010804660859, 0.08083940573757695, 0.09083785672461794, 0.0072403697507275695, 0.032620123407292756, 0.04799648097926571, 0.037355389476062796, 0.05999652052959127, 0.11930265794357947, 42.24712348753407, 113.93986425092145, 126.55027651017713, 121.44961064861668, 105.50281463130828, 100.33259730185233, 123.8750631578507, 74.45713704632175, 169.64156858382688, 163.92863642784857, 97.63053924806657, 95.92785404574488, 114.63053088034354, 129.79496309834144, 100.9387525435417, 10.26700592810108, 1.166511786080176, 0.18463178627914, 0.31374036965350954, 0.01291649904282343, 0.4761669748733121, 0.11671534153602778, 0.33523593879034447, 0.5592755023990909, 0.5790376903549318, 1.5419351958459424, 85.44520993386546, 105.93327906823929, 99.15025372659007, 96.66949579792639, 87.67721114620086, 85.23719095414685, 80.60459721472957, 85.50475151308122, 84.63079252550679, 86.20884833797332, 85.7895940349948, 90.27792299947431, 93.55590266566124, 92.80848718458607, 91.63682030093287, 85.70487868401312, 78.27334434755387, 75.18581144271359, 78.93344786859329, 76.8977455939016, 73.58078541294222, 79.3318037832937, 93.0673243922572, 101.16559105534708, 103.30469485252135, 100.98869216057562, 85.12123784711285, 75.3018351524107, 74.76290933547482, 87.35568661843577, 102.50754371766122, 97.52431361905991, 96.72103574199062, 95.38713962801042, 90.65804773761381, 88.17589344516878, 80.24950504302979, 74.76762402442195, 88.96356028895225, 77.94269638676798, 61.26035398052585, 90.29582469694077, 95.41296451322495, 98.17439156193888, 91.89956418929562, 81.32326172244164, 81.35499369713568, 79.5416505875126, 86.00045281071817, 89.28089572537331, 84.88051414489746, 97.00369742608841, 96.01048269579488, 93.81498306028305, 88.4325498150241, 94.27521828682193, 96.3628605873354, 97.73332103606194, 96.80989311587427, 99.29921750099429, 96.91928017523982, 95.73761909238755, 88.01645694240447, 83.00981813861479, 74.81454341642319, 78.41498897921655, 78.3796170450026, 78.45826056695755, 82.18000934969994, 87.0512322456606, 85.25230776879096, 88.0503148417319, 86.82621371361518, 91.25999819847846, 91.01201026670395, 92.33509632848924, 96.28693134553971, 109.56661762729769, 90.57883939435406, 43.648958975268954, 3.752235159758599, 0.27205948687849507, 0.222316769762866, 0.26346109987747285, 0.4646107836836769, 0.15808310119375107, 0.3367659389492004, 0.09942483667644764, 0.4009167627701837, 2.9865382467546775, 54.989080275258715, 83.04103236044608, 106.23125368548979, 53.0745086362285, 55.98560548597767, 43.008200583919404, 27.3056838973876, 34.33796997993223, 44.71128194562851, 68.79122626396918, 75.45731790604131, 82.47697984018635, 93.85376745654692, 33.097716531445904, 1.018452730871016, 0.049629018176347024, 0.21073093097056114, 0.06393494790480023, 0.11362979984692029, 0.057601725847850886, 0.14028599005072348, 0.017920058678775545, 0.09489309718652118, 0.0817182234999153, 0.02988063704012142, 0.04429663253587581, 0.058668070442734234, 0.09679520923283794, 0.046796339128406785, 0.055830189657788125, 0.025374488717305566, 0.02641295345740453, 0.10374911955647892, 0.030024671145985206, 0.05055400039700251, 0.031917000249508894, 0.02817457072406767, 0.013234685043684177, 0.04155695656194322, 0.1897891208289131, 0.1253865911595283, 0.23950602078149397, 0.11838698369120398, 0.19286663391657416, 0.11356564764414104, 0.10512372644077386, 0.14563971890076516, 0.0864219650506012, 0.19987312085445852, 0.2268709632898531, 0.12452049045673302, 0.1100486682187165, 0.18106373177180368, 0.18518355344572376, 0.17192465523558279, 0.10842851483293119, 0.1361051724562722, 0.14468874331683884, 0.19218673088377525, 0.4325300551229908, 54.44511813502158, 134.96809867120558, 148.29265686773485, 134.56442402255152, 109.73167880888909, 90.34837661250945, 109.76494835269068, 56.24274038499402, 180.62889622103785, 213.43396863629744, 174.76895363100115, 115.03977529464231, 122.26752681116905, 139.9229778782014, 117.13436803510113, 21.077417019874822, 1.8989834045210194, 0.9664306417107583, 0.6280614952406576, 0.19896880002512088, 0.9298445500673788, 0.2815396717238811, 0.9431017322405693, 4.469675642828788, 3.834267609542416, 1.9176613635593847, 94.11425205969041, 113.63657874445762, 103.78004689370434, 101.73102424990748, 91.89315503643405, 89.08036062794348, 85.95340790287142, 91.4891665981662, 91.6626294966667, 92.45681531967656, 90.98542444167599, 97.71127731569352, 100.1116031216037, 98.43746492939611, 101.0017458085091, 93.634656013981, 83.96951229341569, 80.21334079004104, 82.00004316145375, 81.96918195293796, 77.39365085478752, 82.47935679651077, 96.58762024294947, 105.063579774672, 104.22561245579874, 104.04861942414315, 89.89939858836513, 78.91500488404306, 79.00855341265279, 94.7777758875201, 106.42382637146981, 102.0445079188193, 101.621456761514, 100.52984545307775, 95.95211782763081, 93.62471672796434, 91.40431004185831, 89.78221385709702, 102.5150982026131, 87.25557988689792, 73.74418350958055, 96.30504485099547, 97.44382658312398, 96.08763571708434, 96.56530980140933, 90.42764771369197, 85.28905253256522, 84.87696832226169, 89.00055608441754, 88.81985249057894, 86.72872712535244, 99.01380231303554, 100.03917263400172, 96.5258978259179, 95.72942918346774, 98.09568528206118, 98.80601867552727, 97.93445233375796, 99.61797283541773, 102.55759316105997, 100.99510131343719, 99.37909264718333, 90.5173287853118, 87.34285262323196, 78.70566798794654, 84.57272575747582, 83.47233618459394, 83.16046068745275, 87.60567495899816, 94.12822354224421, 91.94637375493204, 95.57062810467136, 94.37818834858557, 97.32384912429318, 95.57983782983597, 100.351118733806, 105.45375362519296, 120.15012156578803, 92.99521553900935, 37.236393651654645, 2.9631991636368538, 1.4927924328273343, 1.184916527521226, 0.3068743219539043, 0.5709728682714125, 0.28425882420232224, 0.6338061127931841, 0.3848780685615155, 0.5027399909111762, 9.172440094332542, 71.96646336586245, 91.03911384459465, 114.9422416379375, 63.97675221966159, 83.97388181378766, 123.5037402183779, 59.89947195976012, 39.16034367776687, 46.89911334745346, 59.863366542323945, 81.37626863295033, 88.08325490643902, 109.34587447874009, 47.98211897573164, 1.030707808752214, 0.35878741212429544, 0.28659729226942987, 0.22955610146445615, 0.1761044003069401, 0.15473972495284774, 0.16155793812246094, 0.11467024683952333, 0.3027752919062492, 0.1893528184342769, 0.11387320130222267, 0.12073348035975812, 0.1210020631251316, 0.16630515516284974, 0.14677067918162193, 0.13555360447254874, 0.13290917621024195, 0.1048710246780707, 0.1651609568826614, 0.14518872293974125, 0.22618585085916906, 0.1544166350316617, 0.13729475378509493, 0.16713193257249173, 0.24547134826500572], [0.07434238259109759, 0.08054541183575507, 0.07230503304350762, 0.057992966950780926, 0.08683127816766502, 0.1008951279424852, 0.10037486231134785, 0.08611854826731068, 0.014270963560369228, 0.024319915063378793, 0.020329962529602553, 0.06626535672694445, 0.049066721131244016, 0.025307739476463007, 0.044412465030027014, 0.044146169037107504, 0.045907826523386666, 0.02010316603005894, 0.10674011833485096, 0.03025052344216214, 55.34072468357702, 118.86578067656487, 104.76965304343932, 91.3538291377406, 85.17819066201487, 88.683118666372, 67.99787198343586, 43.947259149243756, 35.57189272296044, 79.5786463829779, 102.21070658776068, 81.84022226641255, 116.61221427302208, 126.12241652704056, 102.19468762797695, 15.249334862155301, 0.6081905227995689, 0.4253428327220102, 0.29022416700759246, 0.09695142222147796, 0.12821456642761347, 0.1379612809227359, 0.043705545906578346, 0.22576696930393098, 0.6651817646718795, 0.43150925828564557, 4.0164626846390385, 85.11277337228098, 100.73028641362345, 105.67880353619977, 98.89332279082268, 98.15623098804106, 91.01413619133734, 86.81596848272508, 78.40788948920466, 79.89595828517791, 74.23168705355737, 73.85988558492353, 73.52695480469735, 73.76366984459662, 71.67896932171237, 71.92752991953205, 70.00727868849232, 72.64856353882821, 76.66655325120496, 75.85167300316596, 74.86637361588018, 71.2589854578818, 84.91416023623559, 90.94454549974012, 98.3264304745582, 103.03291382328158, 85.86342088637814, 79.74144827935004, 71.16258144378662, 74.50397799091955, 80.40173222941738, 92.98064785618936, 96.18982914955386, 93.00473120904739, 84.05246257781982, 91.4470874109576, 85.21500602845224, 80.19414471041772, 64.0545798886207, 70.25441154356926, 76.47336867547806, 61.907486223405414, 70.52853030543174, 88.0740059575727, 104.96355933527794, 87.63360223462506, 76.48155858439785, 85.42435861402943, 87.92301824015956, 89.22827320714151, 95.29138672736384, 89.18486825881466, 88.64261627197267, 90.27014101705244, 88.77142690843152, 80.14899038499402, 83.58444536885908, 87.1086008318009, 91.08276197987219, 95.02229644406228, 87.77992233153313, 96.51402088903613, 93.54087998790126, 90.23674595740535, 90.24386898163827, 87.85621243138468, 77.77625453087592, 77.34193832643571, 73.61646329202961, 73.61138774502662, 74.27119316593294, 73.00232994940974, 71.01801072397541, 73.6388364914925, 74.09438840804562, 78.27203427591633, 80.52119978012578, 85.4898778853878, 80.3972371931999, 94.8508967122724, 102.30443554539835, 62.025863355205914, 3.7786032932419933, 1.1471862682411749, 0.11383338771279781, 0.0598730156648784, 0.28611533103450654, 0.06824745601343532, 0.25864672756964163, 0.27350806721275855, 0.6623361463988982, 8.581051595749395, 43.69731787712344, 73.90374552819037, 104.26933903847973, 72.93000144343223, 75.1275642456547, 89.59798797484368, 82.92033318550357, 55.27659785362982, 24.418364455623013, 51.516711865701986, 56.05272900673651, 63.78119460998043, 74.47951024578464, 28.846979256599184, 0.6569349200975511, 0.1507071760152617, 0.05622122008653899, 0.07217603149793803, 0.14009506561823432, 0.04045791916489121, 0.09940115689870813, 0.006237751701020546, 0.05348616362278981, 0.022557920498412945, 0.06857458321798234, 0.036609836538592656, 0.013337480636583942, 0.08121152528591695, 0.04458223011404757, 0.09310901630669834, 0.03886091312573802, 0.050072759284728, 0.0709458934744039, 0.15304530700368268, 0.05005389820003221, 0.01946557403331803, 0.05860289934301569, 0.061256597269206285, 0.10759373180448048, 0.036052817839287946, 0.05396836234496967, 0.017526980880047047, 0.10217614186507079, 0.04437706410704602, 0.026556480030018478, 0.1012358378859297, 0.09755899889334556, 0.009460115256989676, 0.041248498920110926, 0.05847194810367881, 0.017962779571873047, 0.07200258153100168, 0.037985175036855286, 0.046160551268727555, 0.07995901749499383, 0.06500359459389603, 0.017920464705375415, 0.007581501521335374, 71.07817203767839, 143.75019135013704, 109.91332377156904, 102.43926309770154, 116.5440591689079, 121.29910146036457, 99.90272906518753, 73.95173964961883, 52.74407640580208, 84.86085522559382, 113.24169020498954, 93.11123140396612, 126.08588357125561, 132.254822638727, 111.2781987651702, 15.442743993574574, 0.5708707027858304, 0.4077764366182589, 0.22536993657629337, 0.22605203062055573, 0.35571058851576626, 0.3789470158517361, 0.1398847898047778, 0.3360372667591418, 1.0013079895607888, 0.10427902257370372, 7.942555921693002, 93.09510261781755, 106.80340982252552, 112.19696690959316, 103.41815333212577, 104.79303821440666, 96.43481254577638, 93.16022180741834, 82.27526803170481, 83.64874870546403, 77.8463472858552, 77.72014110319077, 73.7061914320915, 77.86106401874174, 74.56570825269146, 77.23699923484557, 74.84680098872032, 78.6769562382852, 81.37267574187248, 80.50602805229926, 77.77961207974342, 74.89863903291764, 88.65990607969223, 98.01526884878837, 101.32815760950889, 105.99144781789472, 86.5763508888983, 82.83295062280472, 75.03203884247812, 76.98111949428436, 85.23168394642492, 97.86756807757963, 97.48045367579307, 96.73057494624969, 86.16938144929948, 94.22294878190564, 90.78817629045056, 87.59175838962679, 73.39226845772036, 74.58102903058453, 84.52538274949598, 72.61813379103138, 77.45236873626709, 95.30553863894556, 106.32656728067707, 91.11178751914733, 83.46493859444895, 91.71569132035779, 93.62251235592751, 93.23681000740298, 96.58703188742362, 92.86936236966042, 92.27813566884687, 93.362255250254, 91.50274584370275, 85.71913257721933, 86.53519738105037, 92.16071559536843, 95.78066318265854, 95.7487900026383, 89.33968420951598, 98.38989442394626, 95.33337177768831, 95.17730066853186, 94.05158042907716, 91.83745737998717, 85.13122420157157, 83.09838525710568, 80.2052842417071, 79.5524763291882, 76.79465001629245, 75.25025598464474, 76.92256635235202, 78.62673421059885, 80.29402394448557, 82.04453068394815, 85.10855290197557, 89.6721129263601, 86.40235454805436, 95.15954802113195, 104.26165119294198, 78.16106257900115, 9.488785132285088, 0.8936934125038886, 0.062028381057203784, 0.19544154736063174, 0.4599456146599785, 0.19679833503980793, 0.5379464501334775, 0.17319979326378915, 0.6259063979791057, 6.386836536468999, 49.120131923306374, 78.19947042772847, 112.61546027275824, 83.80446680130498, 74.63744055840277, 44.25221166303081, 45.35435061300955, 64.72406964148244, 43.74776740227976, 67.94385310142272, 74.32634169055571, 69.66368690613778, 90.69112116290678, 44.429938177908625, 0.4400769404826626, 0.22526087629939281, 0.027276589272303448, 0.06419897244702424, 0.056402411371950185, 0.01682931418350387, 0.021728201311141736, 0.024590409218123364, 0.05675206922235028, 0.053874493591607585, 0.06766125319465514, 0.08280632882228783, 0.008379449605971815, 0.08507114519635517, 0.04702689328921899, 0.03486320203650863, 0.023928045768350847, 0.036747625112653746, 0.081045912398446, 0.1655999252632741, 0.007925735469231563, 0.09548490010802785, 0.03181749883468353, 0.04493170793378546, 0.22385462998382508, 0.22806252112552045, 0.1319046817239254, 0.17121827620412075, 0.1848972204231447, 0.18318204149123163, 0.1832563979851623, 0.31567697863905664, 0.31252474133526126, 0.10236952543979692, 0.1060316249007179, 0.2089813546908479, 0.11207696260704149, 0.23415036138988313, 0.09676839615548812, 0.1052121100045981, 0.36360500200140866, 0.2068859663221144, 0.2723126329721943, 0.32314296511392443, 88.13410451335292, 165.22319116900044, 127.56265594113259, 112.65803367860856, 111.07066615935295, 114.55202071897446, 86.25370456326394, 48.23789281229819, 47.23940641649308, 82.55873772405809, 113.36173826648344, 114.44728559063329, 132.32396618012461, 138.42362834561257, 126.15483099414458, 26.953447211173277, 0.9776866183646264, 1.0018457832836336, 0.6375736719177616, 0.4337491768021738, 0.60915824506552, 0.5253939462765571, 0.22100562560221843, 0.5273064694577648, 1.6502335523405385, 0.6390715883143487, 8.251771561561092, 100.24915279880648, 110.19535003169891, 119.01622710689422, 109.16521795334356, 111.46000846739739, 99.46772252359699, 98.67593719113259, 83.85690889050885, 88.24390734395674, 81.50348678711923, 83.9460329855642, 78.73693712296026, 83.30941661711663, 79.52489422213647, 81.25410249156337, 77.29136328543387, 79.07975227602067, 83.25911614202684, 83.7959631027714, 80.39833545684814, 78.70226337063697, 92.21994338497039, 101.64529692742133, 105.23887834241314, 106.82189987551783, 93.41417174185477, 85.97316880379954, 77.19233128332323, 81.71734225365424, 88.06015214612408, 102.07358837127687, 101.90377327703662, 101.60078587070589, 90.92245471092963, 97.42644263852029, 94.9985739492601, 95.55993572358163, 81.70250784966254, 84.91135966393256, 95.01996655617991, 82.14353915183776, 82.72799584173387, 91.07155184591971, 103.75922695282968, 95.63468040958529, 91.38276054013161, 96.99437787455898, 94.17152650894658, 93.69108323127993, 96.6070124410814, 96.74618597953551, 95.80196949743456, 95.74554228013562, 96.25850200653078, 88.74604917341664, 89.77652642034715, 95.11142053911763, 101.06056567161315, 97.28515102017312, 93.94409179687501, 102.34895444685414, 100.54886894841349, 102.80856993890579, 99.3161621401387, 95.17519043337916, 86.18433352439635, 84.01523928488456, 85.95139180460285, 82.4616119938512, 79.65818420533212, 81.1128265626969, 80.93766135554161, 83.53205034809729, 85.28613428915702, 87.77883191262522, 91.36397238700621, 96.9181505326302, 88.60113328503024, 101.6734124768165, 117.49394739827802, 74.1221195651639, 6.363858311407029, 3.0791775209288446, 0.8333882581322425, 0.32480304700232326, 1.040127135572895, 0.18675870682683685, 0.5392691469000233, 0.4035359254527477, 1.0161216172479814, 15.343042246757017, 67.46463360324984, 87.56049709935343, 133.92532871615504, 88.9344955259754, 104.67423746662756, 125.74080128823559, 97.94851795319589, 68.78802560990857, 36.818751442816954, 64.70586199914256, 77.75430494739165, 80.41133419159921, 103.78713853897588, 61.109032861648075, 0.7295747642074862, 0.40970054304888176, 0.24672033205147714, 0.24627281412962945, 0.20059166536215814, 0.22457076897544248, 0.13836998883033955, 0.18245398217151243, 0.29019594432846196, 0.18134759799126657, 0.13951579589516888, 0.20193320789164115, 0.13609976387552677, 0.17638720932506746, 0.16281991476012816, 0.20714021558242462, 0.1323286347812222, 0.17112882777808175, 0.14616003049717796, 0.250979857519269, 0.07222493089014484, 0.1633110230848674, 0.14066062236745513, 0.158046972487242], [0.044704796521053206, 0.07639899924998322, 0.038642344410501184, 0.05479884378972554, 0.04982203785930911, 0.05880608501273298, 0.027075987234110796, 0.05739873936099391, 0.049133252037028154, 0.042018853954129645, 0.03157494390653747, 0.08887661801230523, 0.052591480179539615, 0.11475407218019809, 0.1087520797286303, 0.024497206961255402, 0.04089955736192004, 0.1813924907436294, 0.20505412752109192, 41.070479116132184, 107.99105644226076, 86.57041242045742, 86.57049086786087, 80.02891878927909, 59.663443334641, 37.41332392538748, 35.30349669917938, 38.50739455992176, 59.855949340328095, 73.72898824753301, 68.56573704750308, 109.60854776443975, 120.8585016189083, 103.88194222604076, 19.76981059197457, 0.6577917128320664, 0.15629813165193604, 0.18649989168249792, 0.21284891893306088, 0.34883963785344557, 0.1506605365824315, 0.16656928695738318, 0.3624096290478784, 0.8200101566410835, 0.2289490533932563, 5.037869205397945, 68.14490595171529, 100.7355502343947, 109.97451274625718, 106.46647822472357, 104.62337217023297, 101.75645689810477, 102.83503809282857, 104.21892873702511, 90.09191636116275, 76.52060970183342, 78.00276356358683, 76.57331066746866, 76.94115054222846, 74.34287055846184, 74.20286547753119, 77.35521947183918, 80.02109758315548, 79.7405618236911, 83.64868594754128, 78.98305800653274, 81.05067268494638, 74.96382882518154, 79.02057939960112, 88.2110143476917, 97.29764769154211, 87.26451504615046, 87.62661257097798, 84.19010639190674, 74.78174455704229, 68.14092866836056, 77.86483733884751, 88.86100599842688, 94.76625196395382, 88.96225021731469, 84.69059298115393, 82.075438960906, 81.50875060789048, 75.02377833089521, 74.16781517767137, 60.31591000095491, 82.99817654394334, 61.59569701840801, 72.01695995946085, 118.32378756615424, 98.41412682687083, 79.95285618689753, 67.44775956676853, 82.65708723375874, 78.42284940904187, 86.33308549081126, 83.34878936890634, 84.28716936419087, 82.11514903653054, 86.7879862939158, 80.1927718808574, 81.6522858219762, 72.92244695848035, 80.61132800194525, 86.91442781879057, 91.5519480551443, 87.93491871126237, 84.41911789678758, 88.66341267862629, 94.72344321589317, 92.36158801663308, 93.9748510237663, 90.961364623039, 91.50800181973366, 88.08431394638555, 84.07508680897375, 77.79559966056578, 73.7828423899989, 69.95798234016665, 72.6461552035424, 70.25721211587229, 68.74071398089009, 71.92304272805491, 75.18232837800058, 84.84460876834008, 86.31762350759199, 85.25402576692643, 97.98639235957977, 89.53576349443006, 13.010328296692142, 0.35924966957780624, 0.12764413735919422, 0.12044896296555958, 0.17412456864070508, 0.1580550776974809, 0.2218495633813643, 0.06479907210075087, 0.37061176473094576, 12.094039090218084, 32.39183110575522, 50.130663917910674, 88.07264097275274, 78.71348919407015, 81.15347800716278, 60.52075186083394, 37.45941569728237, 34.09479479635916, 24.643196675085253, 45.29582100529825, 69.27963195308563, 73.1407033243487, 75.34768765972507, 21.5735399723053, 0.7536336022519297, 0.0703565726777719, 0.1278776026541187, 0.12127140431755012, 0.18469293541725607, 0.05843742435137111, 0.004120053894322125, 0.04927972038727134, 0.015739657533084674, 0.14672580175101757, 0.06471740712802257, 0.02281855701679184, 0.022972194034786477, 0.08063898947570594, 0.05780927055785733, 0.2651151143495114, 0.23585401835941502, 0.030537513385136283, 0.06372220911866715, 0.019579617712166042, 0.04186889224295174, 0.0854478153069654, 0.05450446684394152, 0.049634468891928275, 0.01011427198987334, 0.03383740264501783, 0.03658315369618997, 0.04521804095636453, 0.01569791148687082, 0.09284503772974977, 0.059041706845164306, 0.04375565571770553, 0.08370679622936635, 0.043165626289743575, 0.052142606282065955, 0.028453459287242546, 0.023017820316336812, 0.07179497170352167, 0.012595894119341769, 0.09370877122085902, 0.17164769912919692, 0.1574734331018502, 51.436079702069684, 125.04622013338151, 91.25994328529605, 116.5217016589257, 110.15489470574164, 89.28051133309641, 67.55977461414953, 56.07763605733072, 34.92874560817596, 10.993054297662551, 48.97422759763656, 82.1278339816678, 120.90295776244133, 123.07038891700007, 113.87973431617984, 19.210649267319713, 0.95773437931653, 0.06516097969706021, 0.2725703143064053, 0.19083335995674136, 0.4182430669184654, 0.4618439192493116, 0.7030949044612147, 0.7465521306280167, 1.7181197289497623, 0.09771947899172384, 9.158686303323316, 84.63888045280211, 103.63908475445163, 113.66978553033645, 107.95162093254828, 110.255809445535, 106.46341877598917, 108.10936297139814, 105.10935383458292, 96.45316139344247, 79.7095594098491, 80.48840876548522, 79.61744646872245, 80.6899009212371, 78.35100727696573, 78.31172081731981, 80.6317243268413, 83.73854744818904, 84.02630821351083, 89.18563704336844, 84.01177975439256, 83.92750370887019, 77.39890683081843, 81.71607925045876, 94.21158959788661, 104.5519301199144, 91.47874093824818, 92.65202383841239, 87.83436482952487, 78.41333373900383, 70.89598578791465, 80.91271508124568, 91.14747324297505, 96.75298736941431, 93.43073198872229, 90.6940080273536, 87.41551845304429, 83.9691985038019, 82.66683040126678, 81.68067593728343, 68.3072606978878, 89.14095340236541, 70.60365153897193, 80.61325780807003, 114.9817555950534, 99.87735133017264, 85.06645802528628, 73.15451006735526, 88.54419615960892, 84.04832055491786, 91.83900279383506, 90.21036409562635, 87.64481236857753, 85.96402968129804, 90.69538870165425, 84.61990402590844, 83.56919519362911, 74.39903889932941, 82.84388619084513, 90.94225483555948, 94.73677927447905, 92.15311404197448, 88.06092093067785, 91.11294069597798, 97.25811020020517, 95.62027746631254, 98.87059657804429, 96.27516423502277, 96.94154354833789, 92.89605017631285, 88.77268991162701, 82.47079034005442, 77.64847940014255, 75.68907507004278, 77.33305808036559, 75.17569172766902, 73.94771529782203, 74.5804092960973, 78.59420991713002, 88.98378402956071, 92.13407485715805, 88.85854274995866, 98.93451552237235, 99.29578934946369, 24.912757642807502, 0.13669745035229192, 0.1325547686147113, 0.6799597845923516, 0.5420663484161901, 0.15517656360903095, 0.30372462806201755, 0.11330202146763764, 0.6798074250259708, 10.369054232874225, 36.96000775983257, 54.87868124438871, 94.04655195051625, 89.5815924675234, 76.49935830023982, 43.183624667506066, 17.792020151692054, 40.57005136243759, 54.354487849820046, 64.84588669192406, 90.28229251984628, 77.45717756209835, 90.54877050461309, 35.59564659672399, 0.522505549653884, 0.07298331196990705, 0.07137892467360343, 0.03807779889734041, 0.050687219256595265, 0.06788571695646933, 0.023693096178073077, 0.07232882773443576, 0.012046098671553117, 0.04979353555808625, 0.04434977605518314, 0.11424682238289427, 0.05005535376708835, 0.046865834794457883, 0.05250835197887594, 0.10021877955765494, 0.10345934679911983, 0.054745390004808867, 0.11509642155180055, 0.046152580123875415, 0.045071032514134725, 0.05291422153072012, 0.03469513766767998, 0.1308700799821846, 0.09316210619985096, 0.24322847264908978, 0.16435244300913426, 0.09097296399094405, 0.16941924128801594, 0.18258610169493383, 0.1811846510897721, 0.17838076928690558, 0.25971373483057947, 0.1794747428427781, 0.1610921719862569, 0.21751689183856213, 0.1274055239534186, 0.21670365886342144, 0.1264461597067214, 0.2996029218118037, 0.3779446664116075, 0.24142528553643536, 66.32327879628828, 143.02197979342554, 105.28517799992716, 114.33399969531645, 112.82919806818809, 78.55593542898856, 48.3776350944273, 41.08815331612864, 55.19186289079728, 75.02792035379719, 103.72625550916119, 107.41352665808894, 124.93396189904983, 132.61249573000018, 131.09347158862698, 32.35977749670706, 1.0104618209504312, 0.4274222711401601, 0.38601187868945064, 0.5036054557609944, 0.9431826924124073, 0.4283735071939807, 0.4008090814515468, 0.6710887928643535, 3.766906540240011, 0.3184707174378057, 9.179795518998178, 82.86682421161284, 103.13542889010523, 119.32632969271754, 113.02741112247591, 117.7498192940989, 111.68829041142618, 112.61865308207851, 109.81837887917797, 100.7200490274737, 82.59441560314548, 86.48178254404377, 84.4366979598999, 85.92964618436753, 81.31612300872803, 82.75477778527045, 84.2308755074778, 85.59496602704449, 86.14725928152762, 93.83796030475249, 87.2512888139294, 87.25688995853548, 82.90581257112565, 88.47606458971578, 100.71656596276068, 104.64734569672616, 97.99200919366653, 96.48872944616504, 91.33236592815769, 82.12228775024414, 75.05246654633554, 84.5627550924978, 97.87061183683335, 102.70458006089734, 95.14178752899171, 92.82578483704599, 94.7024271565099, 91.39186043893137, 90.065244243991, 91.78994178771974, 79.33472987144225, 100.28510524380593, 84.86113763624623, 83.86542827852311, 106.70448764677971, 99.52593049695416, 90.16837904530188, 82.63232923323109, 93.72488621742495, 89.3615867245582, 94.94733210532897, 94.80400869923254, 91.55388570600941, 88.77672210816415, 94.61018085479738, 88.09691259937902, 87.273222707933, 78.86317468458607, 86.42339414165866, 95.73011167587774, 99.27894669194376, 93.6078505362234, 88.8375816037578, 96.48061013990834, 99.00911115830945, 98.30554777576079, 100.81442909855997, 100.76248122799782, 99.04986458439981, 96.43765234178113, 90.63828683668568, 86.36560978428011, 82.44117644525345, 78.98325412504136, 82.79404855543568, 81.80823141528715, 78.12193301416214, 78.82992083026518, 83.894971570661, 93.40091413067233, 98.84941577911378, 92.02964567369031, 107.80688547318982, 103.6609794247535, 19.233275459658717, 1.388214812163384, 1.1442390973529508, 0.719557153361459, 0.7082523309415387, 0.41405127894493843, 0.6075557117019931, 0.15899263142097383, 1.7206388711929324, 23.872246972976193, 54.39540601545765, 66.47441556376796, 110.2525931019937, 95.30874713774651, 107.14279682405534, 91.32369749007687, 50.24044321429346, 41.9472739773412, 37.113607775780466, 59.45440061630742, 92.9678060162452, 90.27935858695739, 107.06074868479084, 50.88735188207319, 1.076295556079957, 0.24034525478078475, 0.20673950563275045, 0.23859521884831691, 0.2820321436851256, 0.1816634713642059, 0.13935114827848252, 0.21936987466629476, 0.10043290113249134, 0.21683616143080497, 0.19685536262489137, 0.13809792036491056, 0.13265172470240824, 0.13131913007988086, 0.1572740050934015, 0.27347123370535914, 0.25631873958533813, 0.21622364349182577, 0.383575412655069, 0.1408437939901506, 0.1321054886906378, 0.1867572665815392, 0.1774799877837781], [0.05281556472783128, 0.1086478841100489, 0.09680911372866362, 0.018923817720684796, 0.036844588861229925, 0.04239630164398302, 0.014953877318710571, 0.09946537804940056, 0.07200739256316616, 0.02515238833673779, 0.1021560243961792, 0.11499078568792152, 0.07417326102093344, 0.0203580875325227, 0.012174018117929659, 0.1489199388531908, 0.19966774800371742, 0.6425556336199084, 10.603571764884457, 108.21709479055097, 96.17103315168812, 100.32720012049522, 49.53440481616605, 35.10564450294741, 36.01171985749276, 44.713835408610684, 55.3366336514873, 105.55056556578606, 193.66037491829167, 118.3816582156766, 134.60090206515406, 129.2376962784798, 104.03864091442478, 28.96172819599029, 0.4829954536211106, 0.22850086131403524, 0.07240243346220063, 0.1656288067780195, 0.3001172119571317, 0.16467734089782163, 0.37132971169006446, 0.3950979879065868, 1.0090755082426532, 0.3673620810431819, 7.801278521937709, 80.63006908662858, 107.93418207476216, 106.59557127183484, 103.73965432566982, 110.89561862330284, 111.85172773176625, 106.95533106403967, 110.48995925534157, 101.15700106466971, 94.49302750249063, 81.19968352779266, 79.5369202090848, 76.43685140917378, 76.21547283664827, 77.96004110766997, 79.49481748765515, 81.9546691833004, 83.27570776785575, 88.92109670946675, 86.93546741239487, 86.19983473131734, 80.53040166055003, 72.40215239986297, 77.65979151571952, 90.37691577788323, 105.98886689832135, 92.61980548981698, 97.44027291574787, 88.02857706623693, 72.95374747245543, 65.20905894617881, 74.2607988849763, 86.40432357788087, 93.14759962020382, 97.15483419356808, 100.4222313050301, 89.60858621904927, 80.96338425913166, 70.01953217291063, 74.8440553295997, 63.96595001220704, 72.19753803745394, 65.10526126430881, 90.54957851286858, 109.02874300556799, 83.84209802073818, 68.42253915725216, 59.80380535125733, 83.9434285317698, 80.98022691665157, 83.27860247704291, 79.88325765055995, 81.34662335918796, 69.42118244786417, 82.96122781692013, 79.11938390424176, 78.20882135821928, 68.07740980579008, 68.91567522479643, 75.90482896374118, 91.25919019022297, 91.94609918901998, 92.60328446665119, 87.14025435909149, 93.55656162385019, 88.61389667757096, 93.59271018735825, 91.0140577439339, 90.07899607381513, 89.4331072222802, 90.78281048805484, 83.92442072591474, 85.30846042017784, 77.793669854441, 81.30656027024793, 71.04803254527431, 75.27761843896683, 67.0056535351661, 65.61247864077168, 69.20374193499165, 82.55832979756018, 85.82204772580056, 84.489759783591, 87.70560910624843, 105.09189144257577, 14.158178548659048, 0.8379280338844947, 0.2448265780244143, 0.4245375517395235, 0.33959176151021836, 0.2027193366760208, 0.30534625233661744, 0.06984408283906599, 1.5394943784321509, 11.560176072582124, 15.322069333445642, 42.07203672778222, 79.69947891850626, 88.51606492073306, 79.00629412743353, 90.56236543963033, 59.50344593294206, 22.93518489406955, 22.186996706070442, 33.29110507042178, 78.03186755026542, 67.57045130575857, 83.53813002186438, 26.173842799279, 0.3955201329963823, 0.2130384184420109, 0.12659047534989734, 0.12821664252588827, 0.05249704835155318, 0.06136669176480463, 0.02460472740142817, 0.06486266505934539, 0.0840671869715856, 0.08054079232557167, 0.026775278571632602, 0.026193086223136035, 0.09225238445064715, 0.08295865774515175, 0.07025134284049273, 0.06949005062661825, 0.0469099729502153, 0.017360555939376354, 0.05408810571797433, 0.14252754799540968, 0.03911239680864158, 0.04433866011940184, 0.05085656682269708, 0.06975534687479658, 0.014639573468406115, 0.059387729608363686, 0.060821489971731944, 0.04374889116133413, 0.03198850498114142, 0.019727281159571102, 0.07953185452929429, 0.01776674916336854, 0.128905815222571, 0.018595144933750554, 0.04402986539888286, 0.04203843516147426, 0.08565615291797346, 0.17502312848885215, 0.07180554371687674, 0.8152775718800483, 14.869720032138211, 128.04944561373804, 102.06819118991976, 128.72918451986007, 65.97085383630568, 56.790758255989324, 57.43317973229193, 52.97509224184098, 23.204247720779914, 39.243733267630304, 133.63375540702575, 120.88931575898202, 139.2358413819344, 124.95048292221563, 116.55770901710757, 30.22151112556458, 0.47317307262170705, 0.13771493768980428, 0.0951059164118863, 0.19042770107907636, 0.352041854733421, 0.5369590547296309, 0.9353416905768457, 0.7087712482579294, 0.8912417472850893, 0.3805666789412499, 13.972476874628375, 96.02778819299515, 114.23571294353856, 111.96860651816093, 107.78494373444589, 112.6137108956614, 113.9417705228252, 111.82628723882861, 112.31224536895753, 102.36320834006034, 98.03550827887751, 83.30283487996748, 79.74635124206543, 77.76736644006546, 79.04617678734564, 81.69267839001071, 81.95127241073116, 86.7905907477102, 89.27021903376426, 94.95886387363558, 93.1873175405687, 88.86437923677506, 81.81104767707087, 76.79259469432216, 82.43625779305735, 95.42338232840262, 107.4137306213379, 95.23686578196865, 99.73987225563296, 90.41562957148399, 74.8824239546253, 69.7240992515318, 79.0743786288846, 90.66109149686753, 94.0899568988431, 100.1641393476917, 100.13436071334347, 92.40162757135208, 86.4939340468376, 77.00646585033786, 82.73264777275824, 74.24044962852233, 80.81125905436855, 74.05897725012996, 96.49149863950669, 105.16623604682185, 89.75278039132395, 73.11674548733619, 67.95816975255167, 89.86921202751898, 85.82992384510656, 88.8158202940418, 83.55198383331299, 84.35090003475067, 74.52025582713466, 85.62877685792985, 84.81400643625568, 80.4981440882529, 71.11317526909613, 71.58554630894815, 78.17385735050325, 92.42005486642161, 92.76534111269059, 92.98120483275383, 90.2614333552699, 94.69549240604525, 91.39398636356478, 97.7741450648154, 93.99218789992794, 93.09786396641886, 92.23102800307736, 93.25346439115464, 88.67652123974216, 88.39473032182264, 82.06804137076102, 86.91191750188028, 75.83039806735131, 79.31397268849035, 72.09240282735517, 71.91107949902936, 71.95084448783629, 83.21775867092995, 88.8414490607477, 92.23205566406251, 86.3774553422005, 113.25703451710363, 24.237403946538127, 0.5381295145038636, 0.5616427753721515, 0.9250094933855919, 0.976601102419438, 0.30243383119663886, 0.22864385928598144, 0.04605513757034656, 1.3113027714913892, 11.237824905303217, 17.96558503181704, 49.049403744359175, 87.32571971031928, 96.58599638169812, 85.05207861623457, 54.197298865164484, 19.62741482642389, 22.43380596560817, 41.01961381973759, 49.392418938298384, 92.93992580906038, 79.57984662825062, 95.34682550737935, 37.684391083255896, 0.466498454972621, 0.07310549533295055, 0.09009911047835505, 0.04523487190806097, 0.062305957694808324, 0.04118217868850597, 0.009407135488976155, 0.08400153323647477, 0.03909023005455252, 0.024747932217113917, 0.029511821245954886, 0.02214680132906764, 0.03339735024999226, 0.048459305337840514, 0.07234624091295466, 0.009248149262050228, 0.040694556063822204, 0.03405033678357159, 0.15629682930246477, 0.07157328117999338, 0.028048547345303723, 0.04758462061985366, 0.25204407622016245, 0.2141011049670558, 0.21721266300207187, 0.1301775058551181, 0.11997431020943389, 0.11683063776863199, 0.07377199948795381, 0.2375604485672328, 0.19308832444010243, 0.08740228180202746, 0.23368226634638928, 0.23045928848366584, 0.12247841414665023, 0.23726673045706367, 0.3426732429333272, 0.2727638587595955, 0.3392986256268717, 1.5880554049245774, 23.089347770137174, 151.75008496930525, 114.53507607983006, 133.01102422898816, 68.80939468260735, 50.718474234304125, 53.289595726997625, 59.25714069797147, 72.62627663150911, 126.77666002704252, 230.05942098556028, 152.32355117797852, 143.3863993613951, 140.86596273606824, 130.57127075810587, 46.4616592468754, 0.7739850650391271, 0.5153174998779451, 0.2165218508772312, 0.8137818618166832, 0.5906479060649872, 1.1751238400897672, 0.8641389048387929, 1.8970344768416498, 9.979162793005667, 1.0148823321346314, 13.67165461663277, 96.56378007704213, 116.96208969239267, 115.52828296538323, 111.75173867133357, 116.66484463599421, 118.62257019166024, 117.41590792132963, 118.78071231226768, 107.99142514505695, 101.06105204551451, 87.84508074483564, 87.56264655820786, 84.63418929807602, 84.02535899992913, 85.62904357910158, 88.45764513938659, 89.42371706808768, 91.32726684693368, 96.60552978515626, 94.43561969264861, 92.38424362674837, 88.2713560904226, 80.16325212294056, 86.97178856019052, 101.80139157079883, 112.6907148668843, 94.69398621589907, 105.01272232301774, 94.3763134556432, 78.44428123966341, 72.94549480561288, 81.73511059053483, 95.85712586679767, 100.80331310149163, 103.98656752801712, 105.51749214049309, 96.85423158830213, 90.73380439512192, 82.8843415168024, 89.28310009741014, 85.64712570559594, 89.19649416400541, 85.64743949520974, 91.67933094886043, 104.7699119198707, 86.8613346161381, 78.13359029831426, 77.3050602020756, 93.50141309922742, 90.1158820429156, 92.78682785649454, 87.67509306630781, 88.6013529377599, 75.78573796056932, 89.90645885467531, 90.25981733875891, 82.58981858530353, 73.62372752158873, 75.68847886977657, 82.83607282946187, 98.1882453733875, 97.09983471901187, 97.4225281130883, 93.40991204784763, 99.8283609267204, 95.71948205271076, 101.61556536151518, 98.68544501643028, 96.40200584165513, 97.74820250849571, 97.66762133567565, 90.04489498753702, 92.85326496247323, 84.94678651132892, 91.26632105919623, 78.33995403782015, 84.21161666993173, 76.42051865977626, 73.81706899212253, 78.27792567591514, 91.17636542166434, 97.43614658232659, 94.01492980218704, 94.38062806283274, 117.80974526559154, 18.835921710537328, 2.09132932847546, 0.9678381597322803, 0.8073217181428787, 2.003288420457994, 0.2930355871156339, 0.495793994275793, 0.18623021341139273, 5.962538555745156, 23.189228965390114, 38.5637786311488, 69.22469523645216, 99.13411709570117, 108.19446271465672, 100.44276883525234, 133.6925438911684, 78.87253345981722, 29.738808562678678, 29.23935159560173, 47.72173635421261, 104.61788869673207, 88.05380575118527, 113.65331157561272, 55.586931859293294, 0.6138568768097509, 0.362862509585196, 0.1173547261785115, 0.2642939906687506, 0.34693155798219866, 0.19415424385618782, 0.10718076444801786, 0.21024624246262738, 0.1478565168837386, 0.19299895262285588, 0.19231210883346297, 0.140339233161461, 0.1196061283530247, 0.10472451036255206, 0.167088495387185, 0.09273432270293275, 0.12771010519035403, 0.06487363543842109, 0.2030417217963165, 0.2613080250880411, 0.09338782634586097, 0.16964408809379225], [0.010225497422769908, 0.06338459800087637, 0.04532299117155133, 0.06168970124675863, 0.08245237321863252, 0.0362385290434524, 0.03681879851125902, 0.05285603332243139, 0.11701825270128828, 0.02784476987266493, 0.04237203197854181, 0.16177703926880516, 0.013326522706437015, 0.038372788713463855, 0.1352227464198105, 0.027611026870867902, 0.10790023592210586, 0.28692864061843965, 52.91403270536854, 107.15676830660914, 87.83973847666095, 53.76668930053712, 71.68402917923467, 104.11265603957638, 86.05269878141343, 85.62260304727863, 116.48370173669632, 119.51969469747236, 111.31113882987731, 130.1574371707055, 120.0211226555609, 103.78913110302341, 33.81996608549549, 1.1878768138347136, 0.1781390685467951, 0.08418411497146853, 0.04374714448086677, 0.32839857342262424, 0.08623023622579153, 0.6474030702825516, 0.8825384981689915, 1.8798576824126707, 0.8683585784127636, 9.076439103772564, 84.89597612811674, 102.63658185159008, 105.80756710421656, 100.49117088317873, 107.46273671427082, 100.79711575661936, 103.10802721208142, 100.39673589891004, 104.75623853745, 99.0449223979827, 90.10982590336954, 77.17774006628221, 75.24467052951937, 80.38426983741023, 80.97582601731824, 84.3448595846853, 90.54350668384184, 87.31403889194613, 93.44044377726894, 91.88493374855288, 90.26803078189974, 83.93902763243645, 72.55310089357438, 72.78345384905415, 79.9513578414917, 90.98107845552506, 91.20866221766319, 98.51428062685075, 93.4779102571549, 82.16903455795781, 74.08629263600996, 69.5794814632785, 68.83621584984564, 79.5491187803207, 84.56880338730352, 88.29208973915347, 82.70802313281645, 77.49804865929389, 93.63744089680334, 81.99500683815249, 80.27020731279927, 81.1208438873291, 70.86012747979933, 82.1892818327873, 87.88333169875607, 85.75572829092704, 88.42967079531762, 60.94307737965738, 64.83187206329839, 74.15438498220136, 80.6559253508045, 78.43346334272816, 74.34631439947313, 74.18446171668269, 76.65034601765295, 80.74954448207733, 77.33983593602335, 77.65573578496134, 71.69542758695542, 67.44938342801987, 67.22273318998276, 73.97801952977335, 78.82956781694966, 79.04769866697251, 89.00767910865046, 84.11351034718176, 84.3902257180983, 89.45651592746859, 90.42382732514413, 91.01204164566533, 91.35305250844648, 90.25492222078385, 89.67012820705291, 86.43491806522493, 85.74014079186225, 81.43373920071511, 82.73113373787173, 73.80051658999535, 70.9626817703247, 68.07879832483107, 72.15092459032613, 72.06967661457678, 70.74131104253954, 86.12378781841647, 85.08866648520194, 87.428281845585, 92.41586577507758, 3.762647091381012, 0.8847638303714415, 0.754369965964748, 0.2856227364991942, 0.13482834903463242, 0.04872118483387655, 0.047863154867363554, 0.04763369621228307, 1.9454931539873925, 3.0190784748523467, 3.6356027472403745, 35.04411428205429, 79.57947792545443, 90.77319283639231, 71.18411525603264, 104.86025979441982, 94.02452391962852, 29.746251260080648, 30.256641834012925, 39.67355835822321, 70.45042022582024, 61.97570408544233, 76.78977058779809, 11.425710358927327, 0.21348608958144344, 0.12283472164023308, 0.06849952958404057, 0.01774304257255168, 0.010352558850671255, 0.06703618673547622, 0.0424306798395851, 0.11457215694169845, 0.052843059623433705, 0.044793666550709356, 0.013170454316892692, 0.030749834653350617, 0.05005264947671564, 0.05366239065845167, 0.09023768812297814, 0.08436595360117574, 0.028640988035007354, 0.04810014799717934, 0.16436895986478176, 0.12888284790660107, 0.07100340369487963, 0.015095221498350223, 0.04595693275933305, 0.06573223614043767, 0.03797339260457985, 0.04005776845940179, 0.09112526993117026, 0.08239575932102819, 0.031109970671335058, 0.03513819695780835, 0.032716742416303006, 0.02588723136502649, 0.10573623671887383, 0.042985201092256654, 0.03067800241913046, 0.13687973331299522, 0.020942821377708067, 0.09164925108874038, 0.29465632272824166, 68.5724364557574, 118.1601933510073, 100.33790819106564, 75.31437104748142, 89.7085125215592, 76.47751854312035, 49.88794372927759, 51.499222017103634, 57.005300137304495, 110.5238328441497, 122.89621214712821, 131.142297252532, 120.48865349062028, 115.42729762292679, 37.12030718403478, 0.7310211994955618, 0.07352247699013642, 0.19071314543966325, 0.184299610555172, 0.5078219117656831, 0.13393282289466552, 1.82230633833716, 0.7880732381055433, 0.9794540138494585, 0.8068249254457412, 14.641731285279798, 98.71072076982068, 110.63507126223658, 108.25596547895863, 106.27226598801153, 112.05353367713191, 104.44797946560769, 107.02399607627623, 104.40689656042285, 107.00176408213954, 102.47472132405927, 91.70266120664536, 80.88687450655046, 77.65331176019485, 84.8233809009675, 85.05296507189351, 87.43035285703598, 93.32179207955637, 92.67540900937973, 96.90190407537646, 96.3294969066497, 95.16039525308918, 86.51956281354352, 74.8001875415925, 75.39949432496103, 83.36713037183209, 92.03030463187926, 93.66382275858234, 99.76739944950228, 96.17047617512365, 88.54730267678538, 77.61692785447644, 73.57103440069383, 75.18180278039749, 84.283552938892, 88.81726372626521, 91.29759019420993, 87.388469788336, 83.13538105257096, 98.2579694255706, 86.31705868628718, 87.6376344311622, 90.37122049639302, 81.2846891341671, 85.23547295601138, 88.51877135615196, 90.42956183033606, 91.71940188254081, 68.6457847779797, 71.06172946191603, 80.99784620346563, 85.94279396918513, 81.57043380122032, 79.25232871886223, 76.85365815316477, 83.03297581211214, 85.55327907685312, 82.14329596488707, 79.5543747563516, 75.87574851128363, 71.89787680102934, 72.12400144146335, 75.42000047622189, 81.71274523581229, 80.53524186534267, 91.09323470823227, 86.07605257341939, 88.06037179885372, 94.7833299636841, 92.96056532090711, 93.738339947116, 92.53178750315021, 91.97035512616559, 94.77896828805247, 90.59152433949133, 88.50552943445022, 84.69591955984794, 87.80005193525746, 81.24078996719854, 77.01220820027014, 70.95844561053862, 75.6457015006773, 75.12906259106052, 75.17078876495361, 85.72125850185272, 92.82154867725988, 85.29055087797104, 102.93072039081206, 7.301848521155696, 0.6373869916123729, 1.2319665834788354, 0.2895470678565964, 0.04202850666197558, 0.10744996774461, 0.037310872106782855, 0.05073517636065522, 1.1952535663881612, 3.5994929171377614, 4.756784804405705, 42.48753340013566, 85.1577002002347, 99.50618528550672, 81.61974583902668, 69.88203740889027, 38.2133383904734, 25.91370140352557, 48.54614796177034, 63.23192942527033, 83.453626478872, 71.12718597535165, 88.48434079077937, 18.477236647759717, 0.15322569006633374, 0.03246445434107896, 0.06446206236198064, 0.03382508012075578, 0.07679278376482188, 0.08331334113233513, 0.10168121842246863, 0.12678388956814043, 0.055472258057805805, 0.0068574881034662895, 0.017484673674428658, 0.04445928832395904, 0.09793808218091728, 0.0635404892325882, 0.03731427736760628, 0.09145648038435368, 0.0450073859293855, 0.04779250623898641, 0.0914905253317087, 0.03998298678667315, 0.10819158682058896, 0.15395396389067173, 0.1451843102732974, 0.17502869028718243, 0.09622068925490303, 0.17440143281654005, 0.18484062184729885, 0.14087855906015442, 0.15865679379672776, 0.36827375631659265, 0.10793195196217108, 0.11396815790043724, 0.22047422105266204, 0.1716386746134489, 0.13835865072906017, 0.28592239945165576, 0.21596320424108736, 0.2407236102848284, 0.5887958118992468, 90.50116862020185, 131.4484147102602, 111.49869872677712, 72.37144808615409, 91.24378312018611, 124.26885343367054, 95.56951415154242, 108.17751023077197, 148.22545882194274, 153.96959735501198, 121.96323717794111, 134.01695528338033, 136.3727935667961, 128.53271299792874, 53.24413937907065, 2.2327293022986385, 0.25335787104502805, 0.4584348279862635, 0.24854950486652314, 1.064347403664743, 0.7027606449780927, 1.6865891434492606, 2.278394026141013, 5.683784042635272, 4.222732042112659, 14.132889066973041, 101.45172795941754, 111.63354981330134, 112.5583113393476, 111.31813633826472, 119.38743237526187, 109.0305551405876, 112.464629450152, 111.96284847874796, 112.57074525279384, 108.91575521038426, 97.5558808542067, 85.18089709743377, 79.10300408640217, 89.38960813706922, 88.49803770742109, 92.87731693636988, 96.36752820784046, 95.50361048790717, 100.99029248760593, 100.65523578274636, 98.14385983251758, 92.17831134796144, 78.8494542337233, 81.44407856848933, 86.57395824309319, 98.36080612674837, 96.88174309269075, 101.95532891058154, 99.4712761909731, 91.45781901574905, 82.47912929904076, 77.69697558495307, 78.12594167647823, 87.75142238986108, 93.3824162329397, 93.79006032020816, 91.13794188345634, 94.55962934801656, 101.17775824762161, 94.01061519499748, 95.0044418150379, 96.06814938206827, 86.4863246487033, 90.10350304265177, 89.4533544971097, 86.70541255704819, 89.73694970530849, 77.02265739440918, 80.68018128795009, 82.82770249151415, 90.75328288539764, 84.86532672759026, 82.23249850734588, 82.0160307422761, 85.25051916799238, 86.8640253620763, 85.44869299857848, 83.90236131606564, 79.29811062351351, 73.693569244877, 75.71719061943793, 81.80052788026872, 87.44107661708709, 85.84613107865857, 95.0081523772209, 92.41046074898013, 94.1938683294481, 101.54733965473791, 99.39604513106808, 101.30274849553263, 95.66836572462513, 96.63980345572196, 99.12380126214798, 95.02441452395533, 92.95217144873835, 87.38339424133302, 92.6215862458752, 84.38049824007096, 79.93141651153564, 75.54663027486494, 81.76944701902329, 81.08262431237006, 76.53498911088514, 95.45952304717034, 98.32595979013752, 93.81998800462293, 107.87642909634499, 5.354349565121436, 4.003990037787346, 2.532029680667385, 0.39330347290923523, 0.7725736246474328, 0.24118436620600764, 0.2616528872280352, 0.25360465860895576, 4.471148983124764, 5.989554370603254, 15.868427061265516, 59.24331042074389, 97.29476867183563, 106.73266595409763, 89.76787367174703, 148.35621495400707, 125.5092167085217, 39.17833166737711, 45.52609551337458, 56.465358426493985, 94.0726278674218, 80.88303842852193, 103.90761021644839, 32.52178315193423, 0.4798874961993387, 0.30941111486284967, 0.35714914841998013, 0.15083777868459303, 0.18694414606978818, 0.1333180679789474, 0.2036389026550516, 0.26604943518196383, 0.1257754956942893, 0.13615941148131125, 0.09289841107543438, 0.17648759748666518, 0.13069027914635598, 0.2680608143489207, 0.1925898616712901, 0.24227789543088407, 0.1423483293864035, 0.15102373886733286, 0.24710797254116307, 0.20048887168447818, 0.17609865464750799], [0.034823871082476074, 0.07909114712909346, 0.09015133469215325, 0.025782771446111224, 0.07726912191438098, 0.05184386646555317, 0.06610790267586708, 0.01843659920738109, 0.045071526640845884, 0.027153017374897198, 0.12945309311391848, 0.07741440282834154, 0.052681993467793356, 0.03514027305608315, 0.05743664539148731, 0.17016954780105623, 0.3214881845539616, 6.368791182194987, 100.00413017888224, 90.34319123914166, 85.09614252275037, 92.72259512255269, 41.25501094325897, 112.01815389817762, 174.52131086780182, 111.33167636009955, 83.57366669562556, 70.1131748384045, 102.27937159999725, 112.97381585644139, 107.6576392881332, 48.63338931914299, 2.2627020939703915, 0.07795084057556045, 0.031554359124012055, 0.13136684203580504, 0.10965744243754495, 0.07677788335469461, 0.5813086201106349, 0.884574882445797, 1.8306437038606214, 0.9882616347843601, 3.1057067167374397, 68.79532121842908, 102.26347031131868, 105.8831197984757, 102.38926072274487, 95.9262066502725, 95.31724299153974, 98.36548159199377, 97.00303846789946, 93.67424057376002, 91.8490283719955, 84.18376784170829, 79.57271575927734, 75.96570414881553, 78.74050647981706, 81.33618985452961, 88.29764381531747, 89.61223402330953, 94.9619782355524, 93.87534049249466, 91.57147361386208, 89.23940489369055, 87.72846867961269, 80.33403996498355, 68.95500090814406, 70.6091820809149, 76.51783266375142, 89.96916186424994, 90.00241571857084, 94.15467600668632, 93.17684481220861, 82.50098474564092, 72.17724369418237, 66.93421932958788, 66.37004129348263, 72.13826317940989, 76.96679499841507, 83.67076104687106, 84.6961784362793, 64.13553368660712, 82.58537846226847, 83.41108445198306, 75.73137390998103, 83.87657565455284, 82.72567379859187, 81.12395040450558, 77.92877197265625, 73.64473573623165, 65.81254697615101, 47.36399266027635, 61.19289313593219, 76.89975384742984, 82.57008121859643, 75.22880846454252, 75.33281403203165, 73.28441112272202, 73.13430201622748, 83.71193024419969, 82.01021778968074, 79.380386260248, 73.2111490926435, 67.39010072523548, 63.580635978329575, 66.69912815093994, 67.44730457182854, 68.10277185132428, 71.34487751991519, 71.96440804389216, 75.31496724774762, 81.42086598180956, 78.46608961782148, 81.2952010862289, 86.8586830939016, 85.2850595597298, 89.5359988366404, 88.69814134413197, 90.07794487860896, 90.11718426981281, 87.04697255165347, 78.0559273689024, 74.88482444517075, 63.530649292853575, 63.87819874671198, 65.71460539294829, 72.09478762841994, 68.61824973937004, 84.65715085306476, 83.47026517314296, 97.65685050718247, 49.0368325479569, 0.3478655110924475, 1.7680353214663846, 1.331201568245888, 0.3941519612506513, 0.21336195269419303, 0.09859645048216467, 0.06334139830282619, 0.8265492993016398, 0.11447923047648323, 0.39892821302337034, 1.5968644354612598, 33.540975739878995, 80.98875414940619, 97.76317027307327, 78.56120709450015, 83.51221099976571, 64.8060393333435, 17.999015392795688, 26.64078723999762, 34.721075719402684, 70.27785162771903, 67.4206167651761, 71.21660817054011, 4.966948830312298, 0.24124675640656104, 0.15530381081325395, 0.05269008335627375, 0.05292469778308465, 0.039147954779647054, 0.013789455274931126, 0.10613644105051795, 0.06115199562402503, 0.06259527846029209, 0.03786083896674457, 0.027377831621936737, 0.0539311764371251, 0.07307683598370322, 0.050454458762561126, 0.015622009410552922, 0.043739338044918356, 0.08486095365257033, 0.048196958528170665, 0.09726888905729979, 0.037864470223505656, 0.05273355118509743, 0.041849782179680564, 0.04065319880722992, 0.031137634106280825, 0.02735662056253322, 0.020533217147233027, 0.023003136326048165, 0.014463758205003558, 0.08784279768024722, 0.11408103329520072, 0.04916826991604702, 0.08090254670429615, 0.04601297209099416, 0.07738634102767514, 0.0498713432781158, 0.19723143518692066, 0.5482966044256764, 9.21015662531699, 118.44498095973846, 100.61999720911827, 99.98826026916505, 95.28043546984273, 54.41892846938103, 126.34333225988574, 132.63179379124796, 65.79550035538213, 86.06064550338253, 77.32804529128536, 109.99102592468263, 120.8081619201168, 118.98219662327921, 55.77912799773678, 1.4565014382523875, 0.06570588271584242, 0.1995041269448496, 0.11896084483352401, 0.6792111021857108, 0.421450431909292, 1.4039986748849194, 1.2573441959196523, 1.3270309855861049, 1.0793400507780815, 7.130757185720629, 84.63778218915387, 110.60224886863463, 111.24853780192714, 106.43739777226602, 98.62082789021154, 99.44342736274966, 100.09221092347177, 99.92317245852564, 97.18123174482777, 93.62213580839096, 90.0311980708953, 84.35914485685288, 78.4228729432629, 82.35773978694793, 84.45769832980248, 90.46072113898494, 94.10526198725547, 98.16113395075645, 99.54861748603084, 94.06632854092507, 95.96958021963798, 92.24571335700251, 84.74092483520508, 73.35945390885877, 74.27467623064595, 81.32834511418497, 91.18273535082417, 92.15830726008262, 95.61031464607485, 97.77230939557477, 88.7928665837934, 77.51480502467003, 69.96668215720885, 70.83005859005836, 75.32010555267334, 79.53438635795348, 88.13277875223469, 91.12130318918537, 74.13480451030117, 86.39541195284936, 89.1997967996905, 81.10772748147288, 91.26894120247134, 87.8608565176687, 84.6187900727795, 85.47101128485896, 80.97122899947628, 72.89015800722184, 56.129117165842366, 67.33655252764302, 82.52389923218759, 86.89314503823557, 80.63256371405818, 81.28028039009341, 79.98296430034023, 77.97682100726713, 89.94808304694392, 86.26554227644398, 83.15348671328637, 75.57825242319416, 71.3323102458831, 70.1199762282833, 72.97186882265153, 70.36366524234896, 71.95044440607872, 73.51369719351493, 74.21684480482533, 77.45099590670678, 84.58034300035047, 80.59443043124291, 85.32681711258428, 90.23440822478264, 89.44273271868306, 92.29166784594136, 92.72401502055507, 91.4941401635447, 93.2147035291118, 90.45387268066408, 82.27003558989495, 78.14742842028218, 68.52463060809721, 69.42513619699787, 68.37744758975121, 74.70358740898871, 72.77597781150573, 84.92902601918867, 88.28674747097878, 97.9127694714454, 60.33523551879391, 0.3183999002700852, 1.4127999832553249, 1.6296666043419994, 0.7847673542076542, 0.15254396374427504, 0.11316151328144536, 0.01518999232024315, 1.0322303012494118, 0.39347014299804167, 0.4477561445486161, 1.075297680593306, 39.028983500696, 86.04330078248056, 100.88462383516374, 94.89757291732296, 68.02669355946203, 25.238465378361365, 29.387466176863644, 44.415052783104684, 50.40913258829425, 82.34818489320817, 75.64067302211639, 86.46151957973358, 9.124861744142349, 0.22354399665228783, 0.13824070383223797, 0.049062281651722814, 0.053782919271578716, 0.03906210696685218, 0.061540743110761534, 0.06573602061478362, 0.019847269680711533, 0.10753397694638661, 0.010715955530383415, 0.08687264691557615, 0.07781070011157183, 0.0715997878221735, 0.03175477155544345, 0.026160286168657967, 0.05256470157614639, 0.08415522579584392, 0.08922472070421904, 0.010227829202889435, 0.07626035265744695, 0.16102288699438497, 0.20119387175767653, 0.18584922256488956, 0.13438902825357454, 0.19217842649067604, 0.1153889981909625, 0.2559272686560308, 0.17405753594733056, 0.17594235738919628, 0.21667796427444105, 0.37351146881138125, 0.22278550832021624, 0.20484158408737954, 0.247091532294308, 0.09889684121815429, 0.3803455859663025, 0.7752192020416261, 13.642123091605402, 140.50453985891036, 111.44990444183351, 107.97341362122567, 114.26206342635618, 57.3667347815729, 121.25706934159803, 187.49221248011438, 141.00875269982123, 112.09995885049145, 89.50429824090774, 126.71704000042332, 131.65342915442685, 128.46225154015326, 76.24873453570952, 5.336846968820018, 0.19431051047098255, 0.31866656015476874, 0.26892241811560047, 0.6491480347129607, 1.1998646802479223, 1.9541266584588637, 3.323830702612477, 6.842057503038838, 4.1945189237594604, 6.798403974502318, 90.69819711869764, 114.79851030534314, 115.30545311589395, 112.71581803598713, 104.42536307919411, 105.32393886196999, 108.98995860930413, 106.39535780875914, 102.99037179639264, 100.38112486562422, 93.47600398525115, 86.33939266204835, 83.24730196306783, 86.6857457930042, 87.46709762081024, 96.44485381341751, 97.96650594280612, 104.79508569163661, 101.79216615615353, 96.77074786155455, 98.36192007987731, 93.33816405265563, 87.29563513109761, 79.55856384769564, 78.24435018724012, 85.11519739704748, 95.95917809394099, 100.39745761502175, 100.0309435013802, 101.80381559556531, 93.20184599968695, 81.15057545323526, 73.73255760438981, 73.60591996100642, 82.00594240619291, 84.4938547380509, 92.09874214664583, 94.99502028188398, 76.75985074812367, 90.16777500029534, 93.59309457963514, 86.05248697342412, 97.77507858891641, 95.48432811614006, 90.98841328774729, 83.32181915160149, 80.37676242090042, 76.99028999574723, 62.58584053285661, 75.77950923673569, 87.05199318547403, 88.9953471768287, 83.15995077933036, 83.28094020966562, 82.00749566478115, 82.36052466977029, 91.95392039514358, 87.9790767546623, 87.56008132811516, 79.38499896757065, 74.95243826220113, 71.90056754696754, 74.28924391346594, 72.82451322001796, 74.58077015415316, 79.83054099544403, 79.39145518887427, 82.46501661116078, 89.49686142706102, 84.95759656352382, 88.98215232356903, 97.70683719265847, 92.321728890942, 95.96690516318046, 96.02875309605753, 96.99080851770218, 95.99046291843538, 94.46317042073896, 84.18975337859123, 83.04768470025833, 71.60060036566951, 72.2249867839198, 73.71159645818895, 80.87955536380892, 75.94995191020351, 92.82616138458253, 94.58412847211285, 106.50081465321203, 60.587561591979004, 1.114151331205522, 6.277961346410937, 2.0362977395134587, 2.1672453322718224, 0.3476221402806621, 0.3634645934066465, 0.14619718576150556, 2.9744215549961215, 0.841107911640598, 0.9830429212700937, 4.717809192595944, 52.5457731370003, 97.97304061151321, 112.48967770607241, 97.70805312741189, 116.76666152092719, 89.34708964440131, 24.55450796311902, 39.94661415776899, 52.20799430724114, 93.52403733038133, 87.60522780879852, 106.32970517681491, 18.48255342052829, 0.4080924325652661, 0.4126225862531893, 0.20236920385110765, 0.10263612403744653, 0.18167756738201266, 0.1379655556933534, 0.2226724490643509, 0.12498430306873015, 0.16958906765907042, 0.13486032554459187, 0.1741783326912311, 0.13171931908976647, 0.21320878107461239, 0.19977461726915455, 0.1702530513848028, 0.14225118943760473, 0.2343386198363958, 0.271032101685001, 0.16258023649213776, 0.16417228977286047], [0.0489372675937991, 0.03638928365563193, 0.033661903392884045, 0.03169615625313694, 0.05634413123311055, 0.03505182820522497, 0.026691748174808683, 0.047987019793400844, 0.030610029352828864, 0.053789132244644634, 0.10435619827119574, 0.07108163659370716, 0.04393522672715687, 0.058710657270444985, 0.01471819515685521, 0.12423439492141047, 0.10683238596445131, 24.375679262222786, 106.77061096314462, 80.69423906264767, 71.4405127494566, 65.4349757009937, 66.16033569458993, 13.423104805331077, 36.139389084231475, 76.33379505526635, 97.6760152078444, 133.9205434245448, 116.80544591719105, 100.80229328524683, 41.304523021944114, 4.560483415280619, 0.03518174139542445, 0.01949512970543677, 0.06972720080445852, 0.05293690539415806, 0.15770918899966826, 0.6836841976450336, 0.19666086822267503, 3.006147400986764, 1.2900196232141987, 2.779306927996297, 56.41810955539827, 105.2176740092616, 101.06335839917584, 101.4040554723432, 92.60201361871536, 85.12470522234517, 87.13664577853295, 85.05342006683351, 82.54571545508601, 78.55337019889586, 74.90876659270256, 75.11251018893334, 73.98400506665631, 77.67854044514318, 82.18141355822164, 88.66690358807965, 90.75233367181595, 97.27139134560862, 99.73257664711245, 98.56298077491023, 89.78811310183617, 91.65191358135593, 83.7116321440666, 68.68071740673435, 65.60665784343597, 68.29866286247008, 78.41918591530093, 90.17532164050688, 87.9458385898221, 95.39929113080426, 91.69210218614148, 79.60065872438493, 69.84140949864542, 66.87656833279517, 67.6521699659286, 66.87433258179696, 69.72773136631136, 76.0266185575916, 85.01126243222146, 93.53267438950078, 80.70889303761145, 87.3193419364191, 80.37272237962293, 77.89682818997291, 80.04858555332308, 68.25510886407667, 63.01964290680424, 53.425482319247344, 53.211705300115774, 45.23810725058279, 69.05062044820478, 71.54597743864983, 76.22257232666016, 80.73485128341183, 73.46481661642753, 74.00948478329566, 79.31203503762522, 83.86387501993488, 85.74253343766736, 81.44718508566581, 77.24415363803988, 66.61813120688161, 69.75819249306956, 79.70360525192754, 70.92712156234249, 66.5114035144929, 62.24166431734639, 63.7068147044028, 67.19689261528754, 68.96161402425459, 70.84926251442202, 77.62634154289, 76.87413292546427, 80.50877371141988, 83.64058233076527, 84.32735796897643, 85.91318791912448, 88.52043444110502, 82.62433544281991, 78.76640981243503, 71.22269568904754, 68.02220636798491, 65.23259316721271, 65.98724934362596, 64.64502211539977, 76.02002113096177, 74.20117101361676, 83.22005717985093, 87.34448432922365, 90.31754678295505, 3.5268241455478058, 0.5521589745917629, 2.449400540321104, 0.1443593561529152, 0.1376922308437286, 0.11653084458122331, 0.042888287139395555, 0.5216420766326689, 1.3996886029358835, 0.08982794599667673, 0.3538463288737882, 0.31180612021876924, 26.040258638320434, 70.88572486754387, 84.10931341109738, 69.75384650691863, 70.74695141084733, 56.17798205344908, 23.316872696722708, 30.11312427059297, 51.07532755021126, 61.5508133365262, 76.94377068550357, 41.360130463877034, 2.324678484470614, 0.01641801498349636, 0.054449411935263106, 0.04445135548350312, 0.07219582720990143, 0.06283826622811538, 0.12598983177374448, 0.012736743214660355, 0.05642239860589466, 0.023612243258544517, 0.05142375533919662, 0.026256910923327652, 0.015568346866676885, 0.07822369811155143, 0.004611344643748336, 0.04513718420639635, 0.05859228519482478, 0.03555109919679742, 0.030789188590020906, 0.028747711743738864, 0.05009897481349688, 0.07656604472187258, 0.012566662119371037, 0.036558317125684796, 0.047034251563731706, 0.06309602417111879, 0.022676399826342543, 0.11176385481150881, 0.026522243560682383, 0.027585606158320463, 0.0435976347615642, 0.04024526847886943, 0.06533419217674002, 0.12381287802371288, 0.09223797433679143, 0.1538063540694214, 0.19442542365962462, 33.52531763815111, 124.04494885475405, 87.47069051188808, 90.87389576819636, 74.16846629111998, 40.52788980545537, 28.01857271502095, 46.22059037608486, 74.66311639355075, 98.88061431146438, 132.05829620361328, 122.90466877721973, 106.03370743413126, 48.74582406013243, 5.529333852952527, 0.06687140122296349, 0.04431983733910226, 0.07890789889760556, 0.18945935062102734, 0.34990425492005967, 0.9186760912979803, 0.6284769600437534, 2.4246795571619466, 0.8599104059319344, 5.24068319989789, 69.0312204053325, 115.52687875686155, 109.32713339405676, 107.0422350975775, 97.18491877278974, 88.44627811062722, 90.22582607884561, 87.61806964874269, 83.8628944273918, 81.19834992193407, 80.05085268328267, 78.4981353821293, 77.18892666601366, 81.08153389346215, 82.99935325499504, 93.97086589567124, 94.85212049176617, 102.0663006074967, 101.3237488654352, 100.72131987540953, 94.58593276239212, 95.87600031206685, 86.41468647987612, 70.93033006114345, 70.77426679672735, 72.68975627037787, 80.62972391805341, 93.58222961425783, 91.6684816729638, 97.76539033459079, 93.49728676580614, 87.26933956146242, 72.47829344964796, 73.02768415020358, 70.59397897412701, 71.74873259759718, 74.06278979393744, 83.40322402215774, 88.50247783045616, 94.28453783835135, 83.15472618226083, 89.68729249892696, 84.74648675610943, 82.42842874219342, 82.56469188197967, 74.80650255756994, 68.9656932892338, 63.793114692934104, 63.51867429671749, 57.85394414778679, 72.95024087352138, 76.3457896632533, 79.92801973896643, 83.66762315073322, 79.95669226492606, 79.18065917107367, 83.76639627641248, 89.38585050644414, 88.92316772091775, 84.9030363944269, 79.7204714436685, 70.00911435773297, 75.16714096069336, 85.3523595871464, 76.59796668637183, 70.20130265143611, 65.88350265256821, 66.04416293482628, 69.2195177078247, 72.20907765050089, 72.45405320198306, 82.70199052749142, 80.7766951284101, 83.16847801208496, 86.333830741144, 87.45019220536756, 88.29742416258782, 90.81343635436028, 85.70669081903274, 83.58890118137484, 73.71678183155676, 70.51028343939012, 67.11247536443895, 69.3610054446805, 69.5764926172072, 80.33691898469003, 75.46299749805083, 86.250041069523, 89.46676115835868, 94.64549787582891, 5.544670320326283, 0.5099552521301854, 2.33407084499636, 0.09321388608265309, 0.14806538309541442, 0.074536532253748, 0.0807509838693565, 0.8740338803299013, 1.9669219202572301, 0.18237944181647994, 0.3308697585617343, 0.09896031926356016, 29.154544068921, 79.63391257870583, 86.3999697469896, 77.89445907838883, 51.54296036689512, 24.58769121477681, 35.06292204703055, 47.75393509095716, 68.69672852177774, 72.10438174586143, 86.47219627134263, 55.39652824401856, 2.826578352720507, 0.07082797722109864, 0.014968414794683698, 0.014586923118200035, 0.05708815965561136, 0.027022696242878036, 0.13206154588730107, 0.09239200397484726, 0.057565271553974, 0.04199360369614536, 0.0012938766585355024, 0.056924297279047395, 0.012541666585621575, 0.045490902322795124, 0.006703360310395159, 0.009629710844056982, 0.04943617852404714, 0.05869505205942739, 0.0416422872653892, 0.044245898363090334, 0.18312919674621475, 0.20004176745010963, 0.06370167796229644, 0.15558317243572206, 0.12739525071435398, 0.15477551658067012, 0.12298933350511136, 0.16841491534104272, 0.14315085245236275, 0.2220827299019983, 0.2047993573209932, 0.19012722607341506, 0.16137593095341038, 0.22765517685442205, 0.1289095230881245, 0.21759049756632698, 0.41002018557440856, 47.6255206138857, 141.3710698773784, 98.79743652959024, 95.70429463540354, 84.80172157287598, 89.0982231017082, 23.769649536378925, 50.962449581392356, 100.12829672905707, 119.8882092199018, 154.36712172723585, 131.19061300831459, 117.05873689343854, 72.94966820747622, 14.52413764692122, 0.2408346470685736, 0.2796256470103418, 0.2501603732666662, 0.3994400516873406, 1.1795659243099152, 1.6842959052132023, 0.8949542706531863, 6.8105652832215835, 4.510503593952426, 4.309082531159924, 68.71728174148068, 121.08811716879569, 112.1676746491463, 112.9896386977165, 101.47072007579189, 92.38289433140909, 95.54801956299814, 93.64497969227453, 90.18241328577842, 86.7901514422509, 82.19083509137555, 82.00587964827015, 82.14555525010633, 85.20999323937201, 87.58901273050617, 98.29511427110242, 97.85952721872638, 105.25390102017312, 106.56428644734045, 104.9753813589773, 96.7111905928581, 96.78740224530621, 91.61593760213545, 75.28387069702148, 73.74692916870117, 75.67118121731666, 87.27121445440477, 98.23129730839884, 95.08204198652699, 102.17588378537087, 97.96023799527077, 91.14600627653061, 76.67774769567674, 75.80639316189674, 75.0570478746968, 76.69812833109211, 76.80542084478563, 84.315033881895, 92.16197075382357, 100.26901568135908, 87.22227111939462, 96.0442699924592, 91.2368405249811, 89.3759818230906, 89.07504973873016, 79.30399417877197, 75.0107874408845, 69.44380667901808, 67.34390304934594, 65.47833750324865, 81.67634564061319, 81.43165249978343, 85.57963740441107, 89.3088779141826, 82.57746311926073, 80.66448396252048, 89.57386539828393, 93.15065122419789, 89.64018483315745, 89.28073883056642, 85.36532694293608, 72.61996946027203, 76.84153802933233, 88.48945556148406, 79.0705817745578, 72.91078182958788, 67.69140935713246, 70.97710824781849, 73.96755464615362, 77.48417131362423, 77.83552938891997, 86.50749760289347, 85.40574304519161, 84.97094046685004, 90.50807983644548, 91.42403956382506, 93.25459403376426, 96.61011111351752, 89.82757214576968, 87.34457846610778, 77.28740953630017, 75.93108530967467, 73.91952914576378, 73.84237612447431, 72.82937695903163, 86.65854807822936, 81.42530610484462, 93.8617612469581, 95.57594683862503, 102.19759018190446, 5.897754728794099, 1.2552809066349462, 7.524451363471247, 0.30744965398503893, 0.6047989596282283, 0.187252052128315, 0.2674328367556295, 1.704683527350426, 2.9958820679495415, 0.2836953205687385, 0.644959127230029, 1.0396443163194964, 40.816764523906095, 88.9214026543402, 99.37339736569314, 88.14391043878372, 103.31532447568833, 74.53600022100633, 34.35171396501603, 43.68979084876276, 69.53799847633609, 83.37065266024682, 98.66888476956277, 82.30148515393658, 7.931642416984805, 0.3598779842497841, 0.13129453865751145, 0.1603877694616395, 0.1476028958155263, 0.17442260748676716, 0.30913811177015305, 0.15615787627475877, 0.18346891077535768, 0.1716169330381578, 0.14179778796049858, 0.17853181118205672, 0.16439327549549843, 0.1614397920427784, 0.16127119141240276, 0.1108460967999793, 0.19987718112045721, 0.17451325100996803, 0.13205869604022274, 0.12319369511979243], [0.030974645069950534, 0.03817804916311176, 0.013026770696254268, 0.06284689237814277, 0.06762022918630993, 0.023638926100947207, 0.03578723047769839, 0.03197257992841544, 0.017075479300993106, 0.013702222758213119, 0.058734880970610734, 0.14342365636219903, 0.07695795232129675, 0.025042102319158377, 0.04452188153781238, 0.05727765533412176, 0.23677556084529047, 72.91970914410007, 92.84873070255404, 86.34153427616243, 77.18993863751813, 74.90443629603233, 51.164051563509055, 43.42274412032097, 51.676752413472826, 87.23893334788661, 125.04956983750867, 109.63572194499355, 104.15294662598642, 27.360871645712084, 1.4553101408866145, 0.3399744683936719, 0.09670008409528003, 0.16720388355034013, 0.12438102415011776, 0.0956726529365105, 0.43279947292420173, 0.130207919545712, 1.4419255429698576, 1.6046798806036673, 2.924143388386696, 40.89487852588777, 102.93086159613826, 108.86837297870268, 102.69192649472146, 98.0605173110962, 86.78316177860384, 75.74318808894004, 75.82957436961513, 78.94536402917679, 79.74552754432925, 71.9132838710662, 76.67780260885917, 75.60828993397375, 79.72812791024485, 84.63458153509325, 90.43623770436933, 90.8786496808452, 97.38655997860818, 97.07821461462207, 96.90989002104729, 91.82557259836506, 91.3329464389432, 82.1930943765948, 68.95288282825102, 63.907318422871256, 62.78380647782357, 71.59427750495173, 79.39721322828724, 89.23516873390444, 92.6238141521331, 91.78330513738817, 91.63741650119906, 81.34816877303585, 74.07028936570691, 64.05643909208237, 66.83055893067392, 71.05415928748347, 71.82632492434594, 72.84108131162583, 79.79188211502569, 80.66627256331905, 73.87745780329551, 76.14451716023108, 78.0984458615703, 75.22443894417056, 77.68356107896375, 62.90768669497583, 42.08684367518271, 34.236200163441325, 44.161322501397905, 54.428118582694765, 63.78501499852827, 77.63937165660244, 83.28064995427286, 75.19225197453653, 76.97187054541804, 70.95944189256238, 70.6734775727795, 77.28974726892288, 86.05906086583292, 81.49662263931768, 75.05590254260649, 72.78009630018666, 74.16455961042836, 81.14101271475516, 81.55319890668316, 77.73717203447896, 66.325867560602, 63.46973488407751, 62.08837416864211, 63.03503036499024, 64.721555402202, 64.22137083545809, 69.65625009229107, 74.76280735385033, 75.778105028214, 83.42794279898368, 83.00173021131947, 81.79453449864542, 77.24591870461741, 76.89041076167938, 71.97135063909715, 63.59487418205508, 59.01327125487789, 69.79186211862873, 73.2488509147398, 76.76671489592522, 70.2794127310476, 81.14488017174506, 77.17738705296671, 107.02021491143012, 16.945706029092115, 0.9951492555199132, 0.09147233840438629, 0.40123937771685664, 0.15550645639098462, 0.19759301336542254, 0.22792620344027398, 0.31046614050865173, 0.22691366503075247, 0.5917429215004367, 0.1528410679630695, 0.2875055354689398, 0.148149422940708, 33.4372486606721, 55.0085352313134, 80.21956166913434, 82.8904055010888, 103.37144574811383, 46.44206308549451, 21.41990269384077, 26.986295100181337, 53.60262440096948, 72.21071720123291, 61.90804319996988, 37.27171067268618, 1.3210304946668687, 0.081859344556447, 0.01668862405142957, 0.03492405240033423, 0.033106424530307134, 0.06424840043989882, 0.040208086401464484, 0.073086389100119, 0.07374939223330829, 0.04737349061836158, 0.09473803332976757, 0.012880363633045027, 0.07874798570429126, 0.041341402402688424, 0.08576033321479637, 0.05277057621447791, 0.08205377767162939, 0.05059400550840844, 0.0186650236437638, 0.012178613687865438, 0.02584005950108892, 0.06840094172906491, 0.0673257066838203, 0.04664359651806374, 0.026253090059805303, 0.03340874197742632, 0.011860412365246204, 0.02701604468447547, 0.038820582426964276, 0.0903261099911986, 0.05466810705500746, 0.03501475338012942, 0.03599380608648062, 0.058508161079859546, 0.08670167907351449, 1.4032958351796674, 86.15667296994118, 104.39210138013287, 98.77237258418914, 89.5874289543398, 78.30865352384507, 68.6449218565418, 38.235852795262495, 43.73720838177589, 98.66043598421159, 132.07895924968105, 120.32031320756482, 108.95146446843302, 34.22134222522859, 1.328497952030551, 0.6499560429684578, 0.05501088160540789, 0.08955573197454215, 0.20180148673394036, 0.20139857045104428, 1.0841521861091739, 0.2671014577631028, 2.608941476191244, 1.0394035808501705, 5.064873743441797, 50.09501349541449, 106.60875043561383, 114.78086748430806, 104.85297203063966, 103.19589614868165, 90.50098034643358, 80.41995556123796, 78.58553363430885, 80.93713575793852, 82.9110057892338, 75.81605003726098, 81.7353851564469, 80.18127149151218, 82.22581478857225, 89.63940820386334, 94.36253809159803, 94.26565554834183, 99.55176322690903, 101.91943922350484, 99.51675999549128, 96.89107833370086, 92.90538541732296, 86.82448787073936, 73.76209305178735, 67.59019651720601, 66.9468964299848, 74.92962575727894, 85.36267542069959, 93.18265776480399, 93.55971520946872, 93.68898868560792, 95.96935272216798, 83.72015153208088, 78.53801019730108, 70.82137446249686, 70.71478797543433, 76.38729618441674, 76.03088609633907, 78.61371978636711, 84.774884716157, 86.30897860373221, 76.75821119739165, 77.24326718238093, 82.51387365402715, 79.05341748268374, 81.32236742204236, 69.86152341288906, 51.78475095379738, 47.10225682104788, 53.653340647297526, 61.54702432693974, 70.30664182478382, 84.91113216646256, 86.58276004175987, 81.14367208173199, 79.08682038707119, 78.56198372379427, 75.2994268171249, 80.37996307496103, 92.15697365422403, 87.1319938475086, 80.0569558912708, 75.28247433324015, 78.48548966069376, 84.2121579570155, 87.56673366792741, 84.44583708240141, 71.81235344179215, 67.9832572321738, 68.00118246386128, 67.29659142032747, 67.58103386048349, 66.67561746412709, 70.71350143801781, 78.06467425438666, 79.52462750096475, 86.2328532434279, 85.40541356609714, 83.41153944692304, 81.67148190159952, 77.5509378986974, 73.23174153604816, 68.96507355474657, 61.89552691675002, 71.96262728783393, 78.60079165427916, 81.54083559590002, 72.90609851960214, 87.19012337346231, 79.8702589158089, 109.32034769365865, 21.605407268770282, 0.9515619782670852, 0.21197328043560829, 0.309900522472397, 0.13967773156060329, 0.2002631515384682, 0.305109286019879, 0.7499575446690283, 0.4591571263247921, 0.45955466467045974, 0.07761217608687378, 0.2451287537452675, 0.16220172777050929, 38.425652365530695, 65.51632173599737, 86.30968463036322, 91.33941050498717, 65.2038892622917, 37.40003885761384, 33.293980167758086, 40.725122267200106, 68.18458464837843, 78.66307104787519, 76.0459872215025, 47.80043478934996, 1.6020847424384088, 0.04482054474553274, 0.02249422986360808, 0.008516127352542695, 0.013668717902844713, 0.03207432406563913, 0.01637884873836752, 0.045388687041498, 0.1155588398837755, 0.005887356490993332, 0.04625348539482202, 0.03832947793266466, 0.04709071224375118, 0.044103187674115744, 0.023039220982501586, 0.07207936652365231, 0.0668651193019844, 0.06191067547807771, 0.03722123598920242, 0.12667489823915307, 0.16129166128173952, 0.1891168633535985, 0.2760565965887039, 0.19264656749944534, 0.11184686809898385, 0.15744729418187373, 0.1776080010759254, 0.10406694645362516, 0.11557882711771997, 0.2953165066578696, 0.21369285671220672, 0.20050129763061003, 0.21543458825157535, 0.15941702880926673, 0.5529319266638448, 2.9721664372951757, 112.03225089657693, 117.0520688641456, 110.40806801088395, 98.14747625781645, 95.79937288838049, 62.447318107851096, 54.31959052239695, 76.36117319906913, 112.69575119018556, 145.50655026589672, 125.64799016521825, 127.35228353931059, 44.42429780960084, 5.986869508220304, 2.494167776838426, 0.11069822650883468, 0.3850775272134812, 0.46211569660132934, 1.4313399238932518, 1.5447437354633886, 0.9859830441494143, 4.773122947062216, 5.487712602461539, 5.154487644472431, 48.219681247588134, 112.36915896015783, 118.17297243302869, 111.1791902972806, 108.76302596061461, 96.0700164302703, 83.4507631486462, 83.05285438414543, 86.39222698826944, 88.92648604608353, 78.90153546487132, 84.62157495560186, 82.38977770651542, 86.66366284893405, 93.5929298400879, 100.68976832974343, 97.5110246289161, 104.35666668799617, 104.20268227977138, 104.73838390842562, 100.4330256677443, 98.31885245538528, 91.54796292704921, 77.12630210384246, 71.39939846531038, 69.7832799726917, 81.02538124207528, 87.82455105935374, 100.13127773038804, 99.40686302800333, 101.08561392753356, 98.58016860100531, 87.9740482761014, 81.22759511393886, 73.11774176935997, 73.25780176347303, 81.10440131156676, 79.56459645302066, 81.3223752667827, 85.92796740993377, 92.76170115317069, 82.74986697781472, 89.52328251254174, 87.90430853443762, 87.93523250087615, 87.64558899787166, 74.5409345626831, 56.499502658844, 51.216560333005845, 57.390347450010246, 68.52671730902888, 79.31231744827764, 88.74764950044694, 89.90387009036156, 83.39531652389034, 82.34554121571203, 80.54058413351737, 77.73482645711591, 88.24306011199953, 93.4840605335851, 89.20548423644036, 85.4332467048399, 79.47064784265335, 81.18295069663756, 89.3338869464013, 90.66582972003569, 84.91049674249466, 75.40025526477446, 71.36670158755395, 72.842814999242, 70.8038414678266, 73.37647699540662, 72.62755532418528, 77.93918194309359, 84.91508591559626, 82.8518250680739, 88.88071198617259, 90.33433452729257, 90.2869366061303, 83.63334163542717, 83.41350847674956, 79.7627624388664, 73.55225409230879, 66.78430634160196, 76.41214832182854, 84.14370475276824, 85.09869990810272, 79.17768601448306, 91.7676313461796, 85.23168394642492, 120.3029606419225, 23.8371084197875, 1.3980435363708006, 0.6929303273077935, 0.6135209625767124, 0.4114615340386668, 0.39263259439218434, 0.729798645742478, 1.1905342196264577, 2.5337675358018568, 1.1375694745971312, 0.4031156496174874, 0.2797565867583598, 0.6513649705917605, 51.994880168668686, 73.39419826384514, 95.95169421165221, 102.19363643277077, 142.43290255146644, 62.26758333944506, 29.748898859946962, 41.36388417213194, 75.56746590522029, 91.44873480642997, 86.456020416752, 69.41910359167284, 4.528133667284443, 0.40091155337229856, 0.07738730629845973, 0.15632099171559657, 0.12778286822140217, 0.1240501277929833, 0.14652874861513415, 0.14753520428653688, 0.19428218053954263, 0.12166632264251671, 0.3402723846656661, 0.16074468982556175, 0.1790750594509225, 0.22731350164019296, 0.14399230810663394, 0.1820249576121569, 0.1953308629773317, 0.1824919188455228, 0.13373115790947793], [0.09468031626555229, 0.03084274388158754, 0.06671189405624905, 0.04597431529433497, 0.054128053372785936, 0.03405046701851872, 0.06277209921409527, 0.04018328047447628, 0.039596863151077306, 0.09900375644886687, 0.0694055128241739, 0.03241146403935648, 0.0422370664384817, 0.03052376210689545, 0.1575871358715719, 0.3397416389517246, 19.646763878483927, 98.16552700534945, 81.91381377558555, 66.24589043278849, 58.88178948433169, 36.325909553035615, 17.958818943269794, 67.94297449050411, 78.9379507495511, 124.60586347887595, 109.35186001562305, 108.78234755608344, 20.560858518846576, 0.3645408550097097, 0.09785674662599642, 0.18016111165765794, 0.08187891810291237, 0.06801416691873344, 0.05142854721916299, 0.09705783183416052, 0.4132780510812037, 0.305378673177573, 1.1882452714827754, 1.1618643902963208, 26.154356464262932, 87.9485607147217, 104.16981281772738, 103.83625445827361, 94.11611910789244, 85.77322206189557, 74.85485753705426, 77.89220763790992, 79.65281055819604, 80.49534351594987, 81.28843107531148, 81.25243156186997, 84.0673440502536, 86.31085349667458, 89.64959067683067, 92.2392806699199, 92.52505671593451, 95.77616030170073, 96.23994135087537, 94.95873835779007, 95.4080693952499, 89.54033697805097, 80.91883397871449, 69.01564859574842, 67.58646242080196, 65.1082540327503, 64.92289066314697, 72.28288881240353, 86.22844449935421, 89.33685225825157, 87.54170894622804, 83.5292576205346, 88.95323661065872, 81.70118993328464, 75.15149070370582, 70.60777002765288, 69.71118680892452, 71.28101348876953, 73.04947683888098, 75.38202408821353, 81.34441114241078, 86.6796112060547, 69.90653653298655, 62.421810934620524, 72.95966240667528, 64.82569825264716, 73.55609017033731, 54.51541485324983, 28.992558025544692, 23.61889716117613, 46.68757600169028, 64.34896553716352, 75.27707715188303, 73.5612206305227, 76.8870218338505, 83.74171672328826, 76.74243542455858, 73.13503157707953, 74.08193096037834, 69.17958797947054, 78.91196112478934, 85.90261320913993, 79.49655117527132, 71.51687345197125, 74.79158186143445, 82.19267860535653, 83.05381144246748, 80.13412460204094, 74.6707179469447, 63.58133023785007, 64.16199007341939, 62.563722287454915, 63.03765443063552, 61.35443202910885, 62.03359434681555, 64.68572062830772, 67.75757974193942, 69.69164556072604, 69.02396402051373, 64.93503039883029, 68.08330905052924, 67.15935553273847, 65.3152100501522, 61.502964342794115, 67.54679156887916, 79.0344802794918, 77.42187623054751, 78.83076806222239, 70.8438967120263, 78.58345477811753, 79.57324135688044, 97.26608045639531, 39.94801836629068, 0.39853756946902125, 0.3154309111977777, 0.2515463182522405, 0.05585156351087555, 0.036804660358616424, 0.09877409095004683, 0.035567481987058155, 0.6360393510230127, 0.5547050831298674, 0.13206054997299949, 0.041986463756691066, 0.368857944324132, 1.0292701375099922, 66.72106988968389, 75.19842578518775, 90.51241013311571, 72.90700850948211, 81.15004985563218, 35.84810603049494, 22.712576658495014, 40.42329980481056, 57.985010147094734, 74.40427134113928, 65.36469074987596, 36.66960723938481, 3.8704345591606635, 0.07125730821562391, 0.07020301035334987, 0.04067867123071225, 0.03876227547504729, 0.029406024503611752, 0.02471139748400498, 0.11557492006930614, 0.02598363203897832, 0.04202467622235418, 0.07196033944285686, 0.08607559371739627, 0.07467979069558844, 0.02390232628151294, 0.08499184743531289, 0.027399977308607874, 0.0697904107190909, 0.058888788034598676, 0.06833669759573475, 0.015717411297373474, 0.040995061713000464, 0.012420604583777249, 0.10667658666329038, 0.027350959172772787, 0.08959065026213085, 0.056417656521643364, 0.04168943614668904, 0.015964506254080805, 0.11491583930628915, 0.05176622728486696, 0.10806016443717865, 0.03138739792179437, 0.2030533203674901, 0.30202519989782767, 24.737390433588338, 114.90004477962371, 88.70925734120031, 83.72997314699235, 64.84888338273572, 62.45379001863542, 27.91124882236604, 48.06028396852555, 86.11772383413008, 132.71454011240314, 112.43110102991905, 117.16973996931507, 26.003972791856338, 0.37362439017142024, 0.10556470197174819, 0.17359573814657428, 0.11431878868250117, 0.24842985725450903, 0.15284944896496114, 0.13608146969589496, 0.3444720786665717, 1.126296460147827, 2.062581296890013, 1.6931084903978533, 33.72382879257202, 94.24725963223366, 110.62442594958891, 108.3524714746783, 99.04825641262917, 87.54027335874497, 77.93197262671687, 80.16163610642957, 83.06016568214663, 84.01915381031652, 86.07836677182107, 87.41695404052736, 87.5230541536885, 91.05366583793395, 93.72202288719916, 94.61641742337136, 98.758848251835, 98.26108378748741, 97.91033760193856, 97.59016236951275, 97.23335219967751, 93.11847209930421, 82.66260993096137, 71.99150377704252, 69.11146425431775, 68.6391402829078, 68.9192916500953, 78.12216835637247, 91.16761853618007, 93.07710678346696, 91.11066572127804, 86.36098923221712, 92.29999111544703, 86.46634409504553, 79.1815613162133, 73.56108726993685, 73.33624916691934, 75.37448529274234, 76.32980992717128, 81.32406973069715, 87.41309442827779, 88.62067453322872, 76.4591069375315, 71.29936233643564, 79.32217828689083, 69.4484115416004, 75.3825653752973, 63.54777043865573, 37.147748085760306, 32.96679565983434, 53.68264075248472, 77.26301239382836, 82.9106527759183, 75.86056109397643, 79.37381236783921, 85.770750968687, 84.06825404013358, 78.18633833239156, 79.41050221843105, 74.78565908247425, 85.59994743716332, 91.21953502778085, 83.84020743831512, 75.47142274918096, 75.78911904365786, 88.17084927712718, 86.13154626661732, 85.09789189984723, 79.43027880883987, 67.84663323433169, 65.55072092240857, 67.93903643085112, 67.21365682540402, 66.0794250426754, 64.57184637746504, 67.798019378416, 71.3849013851535, 71.78067638028052, 72.93875617365684, 67.80844503833403, 71.6339248226535, 68.51390684804609, 67.8733524199455, 65.30887934469408, 73.09879672142768, 84.34639715379285, 79.98827518955355, 82.44718551635742, 74.8574149224066, 80.07636377888342, 82.27294598856281, 98.97198984699865, 42.86501446077901, 0.42633145386653565, 0.30344188033092406, 0.28033302195610543, 0.09848848571099582, 0.05131330461271348, 0.08454507261875176, 0.46431090622659654, 1.0116235166788101, 0.34643510236374797, 0.2361346976531129, 0.04635523719292495, 0.3102011660174016, 1.3436975041704795, 75.12330455164756, 81.86579611993606, 98.13591311054846, 78.44791335444297, 40.65892442580193, 29.969359597852154, 36.78053971259825, 54.61436448558685, 72.44072498813753, 80.64684898622575, 76.28848383503576, 47.26985969851094, 3.7190509275082624, 0.0678017920243644, 0.06570517025407284, 0.037554629792970036, 0.014486702538335757, 0.006181568249068674, 0.042156680832586946, 0.11797703472116303, 0.03950821528691919, 0.06264829557509193, 0.09254179714668183, 0.001820606395936451, 0.06672293338323794, 0.025175895744694338, 0.029998338788807876, 0.03956607024696085, 0.04119796009974615, 0.03977919207705606, 0.20210229881828834, 0.12142940229105374, 0.08331887994802768, 0.1771024596546927, 0.2391829615038249, 0.17015632512348314, 0.16126417404701635, 0.15828300417671282, 0.1382700449997379, 0.18001255188738147, 0.21424293848535708, 0.2890613987561195, 0.2262919693584404, 0.09155082411222881, 0.2861437682182558, 0.49058235941394684, 36.15645531685122, 133.45078468322754, 101.78528631887129, 95.60560780186808, 77.14078349451866, 49.130361464715776, 25.112161136442616, 102.66261070005356, 106.5146606199203, 145.13621576370733, 125.0876638966222, 132.4813630503993, 31.525126541814497, 0.4574134489220958, 0.4717096914687465, 0.5257115356864468, 0.24814237510004353, 0.2950990296179249, 0.4501900058840552, 0.5817896007530151, 1.2204692584853019, 1.7139587070672744, 4.483637809753418, 4.680866349127985, 33.066588601758404, 99.87248759115897, 114.7138184885825, 113.03811134830599, 103.49263914169805, 96.12936189097744, 80.87950829536685, 85.33225351764311, 87.61801473556027, 88.41548750477453, 88.65738007330125, 89.76908960650044, 90.84144207739061, 95.5056187414354, 97.56001503236833, 100.08265602973201, 101.23314211445471, 102.79083298098658, 101.34343131895989, 102.26947153768232, 102.36746803406747, 97.28339379833591, 87.57104827511696, 76.92791646526706, 72.1646293517082, 71.49882270443824, 72.28306139669111, 81.78014724485337, 94.40289928067116, 97.4604731221353, 93.642532133287, 94.84556228883805, 99.51173151693037, 90.95197446884649, 85.18171295042961, 77.33732561911307, 78.12382359658518, 81.57620753011396, 79.40826646743282, 85.15191078186037, 90.31015703755041, 95.02997644485967, 82.16399038991621, 80.46776140889814, 89.44481941961473, 80.44947531915481, 85.03849152595767, 70.49496266149706, 41.75747048470282, 34.7446217075471, 60.1157122273599, 83.53347809084, 88.74138155291158, 87.7984437634868, 87.86162530222248, 87.23601510447841, 84.13520889897501, 84.27744973090388, 83.33957964374174, 79.95657459382089, 89.22977155254733, 91.72802325217955, 87.46905096115606, 78.53784545775383, 81.8954727726598, 91.4047650367983, 87.60005812491141, 89.01131906817037, 81.92758129489037, 71.26883060701432, 71.4258352402718, 71.52803651748165, 71.96242332458496, 68.74089440991803, 66.92150300548923, 70.47725708253923, 76.05356524067541, 77.29421092617896, 76.94330784582323, 72.39519411517729, 74.020600780364, 74.55163478851318, 71.8031515613679, 69.73052409387404, 75.6090194948258, 87.49227139257616, 84.30918955033826, 88.63289663868566, 77.65350003396311, 85.91245835827243, 86.23443788097751, 106.98647468320786, 48.601080756033625, 0.6758726135857644, 0.8215467451560883, 0.5646253701659941, 0.2721387923004166, 0.17798007465898993, 0.21610283142616674, 1.6513832970972986, 2.5618593058278485, 0.967994012659596, 0.4678194357022163, 0.6090350581272956, 0.43330650055600756, 2.121346982256059, 86.77129268646242, 91.6752124601795, 106.46800794909078, 97.18456575947424, 110.2975905326105, 45.2212175246208, 33.46371289222471, 56.47048104193903, 80.7589973941926, 93.46276206354942, 85.52326510029455, 70.55011903086017, 8.867559163801133, 0.3069131166463898, 0.14039111263569326, 0.20654010826781874, 0.1368983645713137, 0.10671896664726158, 0.12482632807786427, 0.2528891478094363, 0.14830886115950925, 0.22545273535914961, 0.24775225248548294, 0.23488992735022501, 0.28044989632983364, 0.1425273947778248, 0.1805397735968713, 0.11133935783178577, 0.19019651106528698, 0.16084605857970255], [0.014539812541296406, 0.07969749039940296, 0.030773790222742868, 0.06366827652879781, 0.08855288457726279, 0.056598882281011155, 0.083411967291707, 0.03688198161281405, 0.035718274903633905, 0.04761987215568943, 0.03659418536229961, 0.04428036082836409, 0.028589840174742767, 0.04175262690912332, 0.09984438472817983, 0.3044422685859665, 69.47680165690761, 94.08249655077535, 85.88376229809177, 59.09908094713765, 47.821705802794426, 16.19110280467618, 58.03825239981375, 86.9222568696545, 105.68214539558657, 115.6867467203448, 111.09608311806957, 24.03486059558007, 0.36979842450349565, 0.3708150538225328, 0.11424864567215405, 0.05784092148044898, 0.02999903975925859, 0.2029570690806835, 0.12852018188324668, 0.038155909222100055, 0.7438105164516358, 0.35603062940701363, 1.3687735844042994, 6.841756951424384, 56.156718884744954, 92.8879387147965, 99.67065811157228, 94.17071850069108, 87.1476048807944, 83.41889781336631, 82.85213885768768, 78.14281571295955, 80.60750761339742, 89.9010616733182, 89.54538114609258, 94.09617777793639, 94.11219673772013, 92.32512566351122, 95.13198160356092, 97.5299539873677, 96.71805474065967, 93.57110577244913, 93.34248650458552, 91.38311355344712, 83.89550501300444, 79.34646560299781, 69.94496791593491, 65.83387682514807, 66.31028790627757, 66.63964932964694, 65.04593541545253, 76.42418999825755, 87.89394563244235, 90.62202468995126, 89.15410118718302, 78.0272783771638, 78.81174456688666, 85.75474769838395, 73.5196513514365, 65.28067750315513, 71.77307482688659, 70.78226843187886, 73.8659417244696, 80.90399957472279, 80.05017803561303, 76.00708515413346, 70.36335929747551, 71.67256801359116, 67.16209334711876, 56.132898330688484, 57.23954016162504, 52.01629630980953, 32.20360048355595, 23.907679703927812, 37.14471217124693, 72.73483999313848, 74.29787312784504, 53.81642103195191, 62.14339325504919, 65.58979557406518, 76.13579380896785, 76.89376046580654, 66.83109237301734, 75.12628555297852, 66.6416968068769, 84.64624666398572, 84.86276149749756, 73.72437554021036, 67.5121727297383, 76.00135849368188, 81.60935155807003, 83.32667504587482, 78.71468159460252, 72.34083006458899, 61.265511897302446, 64.27204001334407, 58.83163805930846, 62.01935222071987, 60.97647636167465, 61.90844328172746, 63.343520856672725, 63.44451796623969, 65.64193564076578, 62.23375289670883, 61.662240028381355, 62.793082883281095, 65.64810160667666, 64.2772214643417, 73.27854325694423, 77.16224670410156, 83.01845519773423, 72.94411413131222, 71.13696052182105, 74.48737067560997, 80.79777394571613, 88.79755773851949, 58.032219794488725, 0.34791708413151007, 0.29191216513995205, 0.41687544675603994, 0.535829289545936, 0.06756844164262857, 0.2002322475516027, 0.7144765195346648, 0.27591857818826554, 0.7816729105768666, 0.13653418169386927, 0.3637339192773066, 0.34337798253663127, 0.8065010847583894, 17.157178655747447, 58.72497312484249, 78.58798119329637, 92.67099242056571, 82.598479178644, 73.64716760573849, 22.066985907093173, 23.962037870960852, 30.065793029723633, 56.27824567979383, 64.70175919994232, 67.33688985147785, 56.03808287651309, 14.987257776721833, 0.30307581287718593, 0.049577303411018465, 0.1561975596292365, 0.10892464869445372, 0.1301289512024772, 0.028592619158688094, 0.04634247416810644, 0.0215475041524417, 0.020448924492924445, 0.0449308384239914, 0.04349688270820245, 0.0890707063879217, 0.05117634341361062, 0.013993742196039568, 0.04140380409456069, 0.01978776571641286, 0.01322714003523992, 0.04617165571319, 0.04974141476615783, 0.06230131137154757, 0.07753776596678842, 0.07128532405101484, 0.07345252550177037, 0.022338664219264063, 0.051850956609292384, 0.017521752329963832, 0.025295185210603862, 0.08430745512727769, 0.054504302135037805, 0.029909675602891275, 0.06827939421899858, 0.3428567975999848, 81.48374942041214, 103.49914243144374, 96.76252657367338, 76.08822330351799, 62.523004162696104, 26.059990121472268, 35.68549633026123, 79.00449768189462, 116.58595008234825, 121.69923028638287, 123.27864323892902, 30.235357092272853, 0.8937312266038311, 0.15751916855092973, 0.22256911912512398, 0.13610247582677873, 0.15959718204554052, 0.13410113241162994, 0.4495923960160825, 0.17337035507925097, 0.18791113289133196, 1.0868494284729804, 1.0986390926184193, 10.165113537542283, 63.201821311827636, 98.92443503102949, 101.81035810901274, 97.97084408421671, 89.98204292789583, 88.43331859957787, 88.48442708292316, 81.98709149514475, 85.4779617248043, 93.65112996870472, 95.98347325478831, 98.69865555917063, 99.46037200189407, 98.01476678540631, 99.03710903659945, 102.93061840918757, 100.96280451743834, 93.86655438330867, 96.5416108408282, 96.3266335764239, 86.9669169764365, 82.5488062827818, 71.18502524591261, 70.2078922333256, 71.59770565648233, 69.84228026482367, 68.57332291141634, 78.99098903902116, 92.02693139353107, 92.75582544265255, 95.26855853296097, 84.1084740238805, 83.72787860132034, 89.82369684403943, 78.18249440962269, 70.74523341271185, 75.39834114813036, 76.00968960792788, 76.07484017649006, 83.68835679946407, 83.4562623116278, 79.36730123335316, 74.40596580505371, 76.54885861181444, 74.47989463806152, 64.0452407252404, 64.19715019964403, 61.38339481046123, 40.57536225165091, 31.658675401441513, 44.81150242590135, 76.27532820547782, 73.79360537375175, 61.557430375006895, 65.7725231109127, 70.83039591389318, 78.81650632427585, 78.89877411627, 72.90009729323849, 78.33207007377379, 71.6301985709898, 90.36070854433122, 88.54488649675923, 79.35306302962765, 70.51073843433012, 80.26162516686225, 84.22401135967624, 88.11419456235825, 83.0454489492601, 77.95298084135979, 66.03626328129923, 64.7666391249626, 65.23706859157932, 66.07358071111864, 64.15815399539086, 66.19031044744676, 66.66145770780503, 67.03718154661118, 68.8319718453192, 64.78583128221574, 64.38321567350819, 65.46187923800561, 67.50031148233722, 69.80773987308626, 76.75475951164, 82.47692492700394, 86.4322037850657, 79.24094600062217, 75.65372667004986, 78.84885018871677, 83.26375238357052, 91.65676947562926, 63.12685305072416, 0.3132124124996124, 0.37788043760003587, 0.3125747515549583, 0.4220077761959645, 0.1404051014011906, 0.2227402938109252, 1.37214804849317, 0.141310234283728, 1.2863616453063105, 0.05774752004072071, 0.5586404461533793, 0.17518345536964555, 1.0329813125633425, 19.568981316781816, 69.6556931157266, 83.54745741813414, 102.66244596050632, 64.12433531976515, 41.591962152911776, 31.23479662402984, 35.9075338609757, 44.45755950866207, 73.83643765603343, 77.60825157165527, 78.16028594970703, 66.35272795154204, 14.934022388150616, 0.2304227307679192, 0.07027140668322963, 0.05537995212380925, 0.022918454882118012, 0.11714618172376387, 0.03634531020877823, 0.03925062588325912, 0.06320269042325598, 0.0466090114787221, 0.00979278702288866, 0.022432144183004578, 0.02658928583015598, 0.033468967979593624, 0.07157083735951493, 0.04099532218289472, 0.020407923467216954, 0.16032974596225447, 0.25650952612200095, 0.14717773233930911, 0.26406744314778235, 0.26530626860837786, 0.23980856422455082, 0.18463126533935148, 0.058610548730939634, 0.12391109815648488, 0.10354087387602176, 0.09433353124486824, 0.1867937630102519, 0.10303310313892942, 0.19643311028278646, 0.20581997029723662, 1.1300662256056264, 103.46597486926665, 113.4944869625953, 111.48984201492803, 78.96468562464561, 69.13000137575212, 28.508390457399432, 84.52471594656669, 116.90700392569266, 125.98864801468389, 133.406430521319, 133.52672176976358, 35.67638074198077, 1.1632298654125584, 0.46393742304175134, 0.6354255000910451, 0.5284706779545354, 0.3509797197916816, 0.6765551059957474, 0.7907432690262796, 0.2908052293764007, 2.114843937658495, 2.29593314951466, 4.361096591718735, 10.808597976161588, 64.92768772186773, 105.60807535725256, 109.44285900362077, 103.97586730218704, 95.46848958538425, 94.4862182678715, 91.97403430938722, 87.14858547333749, 89.69512154979091, 99.51990573636948, 99.69678894166024, 103.91363497703307, 104.12313661267682, 101.60548487017232, 103.5439202093309, 108.85835524528258, 106.89245547017744, 98.4496948795934, 100.51851764802011, 102.65153392668694, 90.7020410414665, 86.41414519279235, 75.60724658350792, 74.53239948518815, 73.9441930094073, 73.8654161268665, 72.86194047620221, 82.82161497300672, 96.75202246635192, 98.68944583400604, 98.24227210014098, 88.33657726164788, 87.20425175082299, 94.3747131286129, 81.77584048240416, 75.79385726682602, 79.2427973593435, 79.78450021436139, 79.92509365081787, 88.77438437554144, 90.02062336091073, 86.42609273233722, 81.80130450956284, 83.60091932358281, 81.5010549176124, 74.97179123663133, 71.55512440589168, 70.49029504099201, 44.382195088171194, 35.6013261887335, 51.09872056591896, 84.45920451994866, 81.67673787763043, 72.00283942684051, 79.55249201866889, 80.61667027011995, 81.22710089529716, 79.88957266653739, 80.31078815460205, 85.24283132245465, 78.45712307960757, 90.82782360815233, 90.3830268306117, 84.16249290589364, 73.45818781083631, 85.72356485551404, 87.70327921836608, 89.82482648664906, 89.49749685102894, 82.65220780526438, 69.59768910561839, 70.68587226252403, 66.35733281412433, 69.10671818640925, 68.66201554575275, 68.07399734374016, 69.83484345097696, 70.82149997834237, 72.50578141981556, 68.7670801531884, 66.43134009453559, 69.77203845977783, 72.13820826622748, 71.11646221530053, 82.12265645304035, 86.57429556692801, 89.52136839589765, 80.57796432125954, 80.55611671939974, 81.92048964961883, 89.31499681165143, 94.51423968038252, 72.92122317898658, 0.8779659338535801, 0.5815573228943733, 0.886876700866607, 0.8762654638098133, 0.25876305036006436, 0.49172300304616656, 2.1983602691081265, 1.4559874851857464, 2.517284755745242, 0.32528081007542153, 0.8661806823745851, 0.511342024490718, 1.2579133073168418, 23.085135144572106, 80.6382433060677, 97.02356030864101, 111.63867242874639, 117.48571042091616, 98.42558799251434, 31.65842829212066, 37.29710409718175, 49.31797235242782, 80.80075494704708, 87.9873529557259, 89.89568018144178, 88.46991431328559, 25.010881616223244, 0.3629688425890861, 0.15241403523231709, 0.22158244384392617, 0.2417184673850575, 0.30635659973467555, 0.11886071714182055, 0.20249059814358913, 0.1608537654242208, 0.12346783202261695, 0.16223903625242173, 0.13020252628672507, 0.1542846227605497, 0.3010555164467904, 0.19467066372594527, 0.16932263760076416, 0.16679909801290882], [0.10236109081175059, 0.025707823149259054, 0.018413697008884723, 0.012038450241239082, 0.03583052210629948, 0.0067337816618683365, 0.028927156348682703, 0.09208209076595884, 0.07361258425179028, 0.048907784700033166, 0.027693957803891073, 0.03308348402741455, 0.1557293113681578, 0.1806158154842354, 0.46026608456046353, 15.795124826892732, 94.41954581968247, 89.81097267520043, 57.91908687160861, 47.11959369720952, 27.178903087492916, 44.924309792057166, 77.07139676617038, 74.16548528978902, 117.48015634475217, 113.39812217220184, 47.950959667082756, 0.30844783590685937, 0.1185870398917506, 0.1747528679909245, 0.14552929498735936, 0.2158381786918448, 0.13694082116407735, 0.1458397291360363, 0.3291522507225314, 0.05463698090264394, 0.3511093418684698, 0.5656278421801906, 0.922172945593634, 12.277246136819164, 65.26850638851043, 100.74951387220814, 97.01166768227854, 91.20506932658535, 90.84459566300916, 93.94290724108296, 93.76421974551295, 91.75844515523603, 89.08763270224296, 91.90884451712333, 93.78622424217963, 97.14946839117236, 97.6214393492668, 97.06665146735408, 96.38855995670443, 95.78869619677144, 92.73102821842318, 93.68094782675468, 87.32793192709647, 85.0151377339517, 76.76638541683074, 69.5916094318513, 67.16237575777116, 68.29812942012664, 66.70985191099106, 66.55520069983699, 65.97370932179113, 72.08535040578535, 80.6692143409483, 84.47941257107644, 87.27181849941131, 86.58068903030889, 83.01659599427255, 80.7357926522532, 71.60304792465703, 71.26464151567029, 71.4917859723491, 76.61604096812587, 75.91537229476437, 78.36251551105131, 73.53643909577401, 74.25451524796026, 66.87816081508514, 72.62071471060477, 68.72537751351634, 64.78938494959186, 69.33172102897399, 65.9699438464257, 51.916169966420824, 41.876055502122455, 38.081574209274784, 50.2452402730142, 59.19078988413657, 56.702861862797896, 50.721215971054576, 56.778987223102206, 58.875772568487356, 73.09178352355957, 68.2528103551557, 64.02575439022434, 67.38588025493007, 74.96847291146555, 81.52187485848704, 74.82922877034834, 71.18177752340995, 72.04491076930877, 79.25252483737084, 82.23346341040828, 81.42444318340671, 74.22263422319966, 70.56210579410677, 68.10923591736825, 65.71959857017764, 64.53199509651431, 63.00703248670025, 64.26115543611589, 65.50682567781018, 63.6767928831039, 64.26755282186693, 61.94909864856351, 62.5733164048964, 64.61592205109136, 61.81909561157227, 72.24090376207906, 80.24817928191155, 80.56176493244787, 76.13134584119244, 77.69392398095901, 72.6699012325656, 73.66053504328575, 80.93785747405022, 83.80193295017366, 87.934659834831, 7.257722837309684, 0.428770340738758, 0.1364633492043903, 1.033136246185149, 0.45489994508604853, 0.36159377605203663, 0.798008356603884, 0.24442726235476234, 0.1170975581232098, 0.352250506440478, 0.11966570701089599, 0.08311806532043604, 0.03815415488075345, 0.3052463851148083, 12.586552481497488, 51.61978783146028, 92.98876716244607, 74.87161390243038, 91.46382808685304, 54.170697350655836, 21.69810268186754, 25.220828440881547, 44.023902262410815, 55.058878852475075, 62.575595301966516, 69.2239813650808, 67.38738644507625, 14.872927550346622, 0.19803708389161095, 0.035800219498454564, 0.03723511750239038, 0.045712845655338424, 0.03111096467041681, 0.0712716953468419, 0.029111919519040855, 0.04510967781947506, 0.06500848223485294, 0.04099965441010652, 0.04648893868791, 0.03323277541165871, 0.10013196647407548, 0.05274418448548644, 0.09286808931539137, 0.061252644255517, 0.01924050123160405, 0.08106376990796098, 0.05413634244412665, 0.019698495405816266, 0.024140119973209598, 0.1287022350175727, 0.06299824070846362, 0.02405941261038665, 0.010608410192353111, 0.05368161946535111, 0.09008346696294124, 0.010595802300339265, 0.20920122192511637, 0.49577055198531, 18.5116966309086, 112.28002702036213, 94.00156236463978, 79.99892050220122, 57.39560734841132, 49.12457989108179, 44.41951644036078, 62.98107424089986, 89.08063519385554, 126.31883313578945, 123.11550401872205, 57.95831449570195, 0.18992513207898987, 0.07969892298382136, 0.2977756795383269, 0.11408297149764915, 0.07425329422638302, 0.05672953857649719, 0.6115407785100322, 0.21621976708692892, 0.1783687417064944, 0.34833414239748833, 0.9125904114015642, 0.6932549034395526, 14.23684560483502, 70.99709664621662, 104.53497763602965, 103.71561804125386, 96.78169911907565, 95.51715835448235, 100.11712581880631, 98.89830420094152, 98.20442122797813, 96.63508876677483, 95.77128087320636, 100.60101293748426, 101.31635127529022, 102.82383580361645, 100.32586651463663, 100.5376745039417, 99.30235539713215, 98.07357095902967, 96.44621095349713, 91.17651447173088, 87.32498230472689, 78.00593283868606, 70.92382677139776, 70.97766522438296, 70.8804218230709, 68.50532470210906, 69.41423200791883, 68.57814742672828, 75.97234864388743, 83.17564026001962, 88.26307988935902, 90.92440805127545, 89.3181033288279, 87.26431892764184, 82.4655814324656, 73.63536127151983, 75.75278220638153, 76.39733745205787, 81.90997769755703, 79.58104687352335, 80.67258757929649, 79.83798565403109, 78.90496361640193, 72.6919057292323, 77.89548673937398, 74.63522834162559, 69.90110797266807, 72.79883738486998, 67.52011945170742, 55.85417862861387, 48.95207405090333, 48.321019603360085, 55.71765661239625, 64.34298784502091, 67.51154515051073, 61.324378828848566, 64.48818614405971, 65.60925837486022, 73.1067434433968, 72.95922310121598, 70.62110608623874, 71.28052711486816, 79.68916308495307, 85.45780858685895, 77.46222173013996, 76.19519418285739, 74.43532866816368, 81.02877016990416, 83.50173042666528, 85.3021610936811, 79.83328665456465, 75.5406290485013, 71.88044578798356, 70.93408769176853, 70.29340774782243, 67.21706928745394, 69.86619887813445, 67.95460039569487, 67.02950154581379, 67.26930741340884, 66.31003687458654, 66.48320951769429, 65.803282337804, 64.3773909538023, 77.66213709308256, 85.24989158876481, 86.72196495917537, 82.37573562129852, 79.57226076433736, 78.50820802873181, 73.58574328884002, 86.12392902374269, 86.3231618942753, 94.9449473042642, 8.511766849025603, 0.7008977642943782, 0.20919877044375867, 1.2482594963042968, 0.2643600887348575, 0.7230133130665749, 0.5098422694831125, 0.36525769880221737, 0.05838986561303178, 0.25448238086556235, 0.04192900333193041, 0.15042560805957164, 0.06844801017113271, 0.5767187115646178, 14.021230955277721, 60.29542346154491, 100.3457215524489, 83.92078076639484, 63.21326286562028, 36.4622825191867, 34.69264638039374, 41.246868102781235, 55.034524856075166, 62.60816274150726, 71.88180292806318, 79.08955820145147, 78.08797313321021, 14.32737292781953, 0.17352806193934334, 0.07123588073638178, 0.03361644373545724, 0.12943832293873833, 0.04223605903286127, 0.05714267064186354, 0.05847289805270492, 0.018526231494521903, 0.013293113612059145, 0.030700167257999702, 0.0994100281968713, 0.05861724433939784, 0.008523416679142224, 0.0930516669646867, 0.11055646193844658, 0.20077374914000112, 0.13090554985307878, 0.1462490958792548, 0.14818365174916484, 0.16996115656389346, 0.15821171203447928, 0.17798821051274577, 0.17252862363332705, 0.1396984925433513, 0.14175447334925975, 0.16856413394693406, 0.20845754973350034, 0.42960681682152135, 0.494334290344869, 0.7430313743891255, 28.668148594517863, 125.81643242989819, 111.45265794569447, 83.6553539768342, 63.85542938786169, 37.76440351240097, 61.58986837633195, 106.78790077086418, 94.95356867390295, 140.99318873497748, 128.9390862372614, 67.73210002530006, 0.5573903132350214, 0.18940131179988387, 0.46506663664214076, 0.3697557687278717, 0.475591060615355, 0.29699849866090283, 2.533713112915716, 0.9605528474334748, 0.31819336296569917, 0.9285057348109061, 3.732217343584184, 2.120884878020133, 16.11330847586355, 74.70821580579205, 111.71601372380411, 110.87006830400037, 102.3394936899985, 101.16012327132687, 102.6125769461355, 104.87268586312572, 99.13069678891091, 98.68355443400722, 98.05384143706291, 104.24112150746008, 105.01746839092624, 106.31487077282321, 103.67759458480343, 105.26747242096933, 103.52570472225067, 102.70073613812848, 100.00562067954772, 95.65892065725019, 93.92238540034141, 83.43330075663906, 75.13588751516035, 74.2971827906947, 74.75279746517059, 72.5836326229957, 74.90795858444707, 72.48078023233722, 80.97287639494866, 88.1849854992282, 92.51452907439202, 97.68651147042551, 93.24498422684209, 92.2618813668528, 89.05045647774973, 80.87353844796458, 79.41745265837639, 81.2344749512211, 84.52024444457024, 83.9597220574656, 86.9349967279742, 84.8406393297257, 84.11817012294647, 76.16968308725666, 84.55534965761247, 82.76426207634711, 74.53734951634561, 73.98539358569731, 71.53145682427191, 59.873062641389915, 51.378903312067834, 55.278362920207364, 64.06226381178826, 71.73127020559004, 71.5316294085595, 67.27177066187706, 68.90551628605013, 74.46351482022193, 81.57384626327023, 77.35351716318439, 76.08392438580914, 74.98148733569731, 82.2559856599377, 89.7304307260821, 80.99874050386491, 77.53849614051082, 78.57221326520367, 87.81105810596098, 88.98860070013231, 91.12875569251277, 83.57162706313595, 79.5753594367735, 75.17436596655077, 75.78325117788008, 73.94951174336096, 69.24185168358588, 72.1195613184283, 71.79771515630907, 70.91216164250528, 71.52700885649651, 68.14344683001119, 69.66863693729525, 70.08649487649241, 67.92581019863006, 78.5169941379178, 90.80942769204417, 88.76988933932397, 86.11249139232021, 84.26654554182484, 83.25663720407795, 78.20151790495842, 91.8144879802581, 86.89579656047206, 101.87481049568423, 10.32631608747667, 0.7032748431928697, 0.4019419109869388, 2.4000458467391232, 1.0834796221986895, 2.015807645455484, 2.0002225978720576, 0.9546610797124525, 0.2801485479839387, 1.028195040360574, 0.3950915527680228, 0.2710164428478287, 0.11061515193432571, 0.7015715539455415, 21.242242859255885, 71.94681229129915, 108.30930971330213, 97.95179705465995, 120.0901093021516, 72.73880943175286, 30.64377977002052, 41.28107509305401, 62.97211554742629, 74.02977128182688, 82.73218493307792, 86.62544327397501, 93.36876638474004, 21.465178612739813, 0.3419434675766576, 0.15311620078019558, 0.15699104285768925, 0.202460398957614, 0.10148930573655714, 0.12765074869798076, 0.10056920349597932, 0.2005565785352261, 0.1518432231199357, 0.19307936121138836, 0.16932603903114798, 0.09739310255334263, 0.1827884561592533, 0.14981178777112117, 0.3554245312848399], [0.044474215547163645, 0.033642846955767566, 0.056546343971164, 0.0032266165409612683, 0.007892604081726243, 0.08091987561314337, 0.026382731288791667, 0.0749289837755984, 0.05266013314887401, 0.03905329695572296, 0.016299928275627956, 0.025174028405378905, 0.03656880869980782, 0.07919452303359586, 0.19986659378534366, 39.386142761476584, 93.84473031566989, 78.33474513023131, 66.16152025038197, 41.22476554686024, 38.43544652385097, 59.63716345448648, 69.38730885905605, 109.24901546970491, 115.81849128969255, 74.76541180764475, 3.3740081133381015, 0.1287369388005426, 0.08562833626544283, 0.14104250187595047, 0.10746191105534954, 0.08598635979597608, 0.06499530552255531, 0.23503160765094144, 0.10004643275732956, 0.21726198374263703, 0.059624182646192854, 0.9976762425034278, 0.5037674680352211, 11.440706560688636, 67.8989968761321, 102.2203399289039, 97.91951594814178, 97.81991127998599, 99.81107896374118, 103.47500416540332, 99.14169511487408, 95.94387300552862, 91.41480630443942, 96.95229084261003, 95.67981120078795, 98.57102163376348, 96.83021883810721, 95.27870178222658, 93.10274339491322, 93.43951025316792, 88.28402534607919, 82.89086834076913, 79.44030438700031, 75.03177212130639, 68.28244778417772, 63.48443984985352, 68.6722372424218, 65.86133341635427, 66.8817223272016, 65.55933444730698, 67.47855017262121, 67.3957097145819, 72.43364903234666, 78.70798218634822, 77.94091563070975, 78.5562962870444, 74.81506901402628, 69.47597011443108, 66.83575214878206, 72.58061239796301, 74.6370953898276, 76.11060434772124, 79.74664149745819, 75.99606329394926, 72.58015740302302, 69.25392473897627, 69.61346487845145, 69.87725211728004, 65.73915943022698, 71.19829854657574, 70.9848274723176, 68.51152204698133, 64.42328660718857, 63.761092462847316, 57.79811313075405, 52.591158882264175, 47.9791340520305, 64.38519254807504, 63.56052206408594, 64.69595801445746, 63.74364968269103, 53.29713060009865, 59.53713909272225, 69.9792415865006, 71.69385863888648, 69.78645709253126, 77.33983593602335, 74.58871687612226, 71.72610836644327, 71.40943188821116, 70.91191061081426, 76.33213981505364, 76.48923858519524, 78.4681998529742, 73.40473375012799, 78.15921906502017, 73.33162077011602, 77.6339509410243, 72.64788889115857, 75.50550030123803, 70.53249974404612, 66.51824412807342, 60.49493089798958, 61.680463360201934, 60.30859870295371, 61.93703736028364, 63.337464717126664, 77.3499164273662, 80.45802608613046, 85.91335265867173, 81.32938061991047, 79.65947074274864, 70.81764821083316, 70.49589618559807, 76.7812119760821, 82.02899025332543, 97.17656412432271, 41.69880359403549, 0.50044258515681, 0.4238730777175196, 0.19850015339832153, 0.48237538205519803, 0.07285719091493277, 0.1351563112750169, 0.05792793374688876, 0.21046315259750814, 0.06057762886367499, 0.26385345946877237, 0.3076118194768506, 0.05652232711473781, 0.022588378239062526, 0.04302708311907707, 17.195812040759673, 72.49133140810075, 89.38866676822786, 87.33317221364668, 89.5690957961544, 34.11585400181432, 21.454447007948353, 41.78535461425781, 54.69856208370578, 69.10332925858037, 75.48445286289339, 58.260717468877, 68.71851336571478, 7.807299850448486, 0.31830064591861545, 0.023838394329011924, 0.06966934584441685, 0.048045116071138656, 0.024002725934429515, 0.0223056324231889, 0.04483149980284995, 0.022226053124834454, 0.010691378472162592, 0.02916612598534313, 0.049575100908236164, 0.083481980067107, 0.028716196801753777, 0.05945558967669645, 0.023573994403705004, 0.040544858652978175, 0.017310093727804, 0.05681949645100583, 0.06913154446069272, 0.03343023457414201, 0.0959802525598676, 0.06480965943586442, 0.02491365235689427, 0.06524852822504698, 0.013000641352376871, 0.05403150714212849, 0.06190887900189527, 0.1069972710683942, 0.2444953369277139, 49.31050808198991, 101.52202467764579, 89.83648377080118, 68.78622916436964, 55.99644691713395, 32.91644419393232, 30.342290709095618, 73.28496025454614, 113.93113305491786, 122.52577566331433, 88.80422576781243, 5.282576564819583, 0.23660175081702972, 0.09259519347500417, 0.05048040999099613, 0.23938327817426575, 0.2052638823947599, 0.16581006318090424, 0.25918078278341605, 0.08946177895150839, 0.23987369701987316, 0.5462029167721348, 1.3368187700548482, 0.5238799726770771, 12.795245128293192, 72.21194098072668, 106.38728557094451, 103.43204636727612, 105.40877188405683, 106.13891324689313, 107.79605973151423, 104.84904966046734, 97.6576114469959, 96.32908898015177, 100.94672279973184, 101.3422546079082, 101.69475801529424, 98.34046471503474, 97.18966484069826, 97.26279351019092, 97.87071381845783, 93.18720771420388, 86.60893009554955, 81.6134229783089, 76.48935625630041, 70.40047276404597, 68.95225524902344, 71.22877536281463, 71.14262442434989, 70.85013328060028, 69.28728057492164, 71.81827622075235, 70.95716691786244, 75.57850345488518, 81.16734750809209, 82.60408816799041, 81.60417402944258, 76.56228096254411, 72.44601234312981, 69.82886575883435, 76.42966562701811, 76.59001211966239, 78.68422046784433, 80.3056812286377, 79.58902497445384, 76.71774018195369, 74.41166108654392, 74.37390435126521, 76.33634459587836, 69.82234677960797, 71.84471299571376, 72.63363499795237, 71.8459681541689, 69.48524259751844, 67.45857746370378, 61.676984217859086, 57.095530340748454, 58.072404476904104, 69.95703312658495, 68.01011762311383, 69.24149082553002, 68.23384961774273, 57.931454104761926, 64.12619060085666, 76.29678357032039, 73.60276637538787, 75.13639742328276, 80.34958039560627, 78.28540171346357, 75.24484311380695, 73.91548910448628, 73.45224149765508, 81.05474410518524, 80.89722171906503, 85.11132994005757, 76.04375931524461, 82.73889218607258, 77.53870010375977, 82.16395901095483, 77.64255662118235, 81.09628200531006, 73.87719108212379, 69.97570360860517, 63.22124488892094, 65.10295098827731, 64.35293497577791, 64.84256836675829, 66.00926168503301, 81.97992140246977, 83.03967522036645, 88.48576853352209, 85.48058186807941, 82.66409258688651, 73.71937844061083, 73.9244556427002, 82.36618857229911, 83.89763878237817, 103.7975485094132, 46.31237383811705, 0.46143620725600953, 0.22593236768678313, 0.1361008057551038, 0.32938054492396696, 0.40593316778540617, 0.06462366094872837, 0.1727968616591346, 0.2992271097196687, 0.04189638713855417, 0.3746166272509483, 0.42012224995320846, 0.16156428133047399, 0.03912893664692679, 0.039075276018270565, 21.19035186306123, 82.59057168037661, 96.87048589029621, 87.6973250604445, 52.1337006938073, 22.845019409733435, 29.965837309437415, 60.71437574202015, 69.21879599171301, 79.28973244082543, 85.5912789990825, 69.50366204784763, 79.40074336144232, 8.080144822597504, 0.24877047526740262, 0.06180767112621858, 0.06374632939696312, 0.014763210483285931, 0.05439750564795348, 0.022755845059310238, 0.015500389122133775, 0.03127837977972964, 0.06123977397838908, 0.042214535792628606, 0.021885634294801184, 0.0976020683564486, 0.11277004235213804, 0.02069109446188856, 0.21113657452646764, 0.19094390644421502, 0.0634871733434979, 0.12188768374823755, 0.12598929551219748, 0.18685092849116172, 0.2318265562456462, 0.14098745079771166, 0.11723811227467754, 0.24380726739764216, 0.16965738738015776, 0.22246390460960327, 0.22400979343200886, 0.1478197599851316, 0.30225147162714316, 66.76980141670474, 116.94131681996008, 98.63200664520265, 81.67829898095901, 59.96757607306204, 50.10432520220357, 84.75205652175411, 89.79594999744047, 130.33768576960412, 130.9146978009132, 101.92691526105328, 6.847923897927807, 0.27297097829080397, 0.25353184961263214, 0.36810411380664, 0.28975247135085447, 0.7629641241604282, 0.7492919061933795, 0.44046697116667227, 0.6034345263915678, 0.9839448825486246, 0.757425798764152, 3.858111942968061, 1.3622530117150278, 14.432946462785045, 76.68407055639452, 111.94636667928388, 107.03124461635467, 109.82442717398368, 110.1017544346471, 114.06095566288118, 107.7624136401761, 102.65480518341066, 99.6336466266263, 106.42075123325472, 103.24129366105603, 106.10886789137318, 104.39886354630994, 104.68871885730375, 100.2855053255635, 102.57077232483896, 98.01164457874914, 93.02924602262436, 87.3772753438642, 82.39257827881845, 76.23488856900123, 72.70746969407605, 76.98643038349768, 74.7533779759561, 75.94716702738117, 72.52292217746859, 75.2653649545485, 74.28329760028471, 81.31362053655809, 85.38733928434311, 87.57759863330473, 86.29801950147076, 85.38570757835143, 76.71417082509687, 73.81181301609163, 81.85359754870015, 81.98480867570447, 81.83811203125985, 88.97134227137413, 86.44745396029565, 81.5843503705917, 76.68778111857753, 80.5647930022209, 81.9530688562701, 75.78600468174105, 72.26654821826567, 76.4308972512522, 74.50529590729745, 68.58056360675444, 69.89247091354864, 64.80903602415516, 62.31112164835777, 65.04582951145788, 74.31366459015878, 71.54657363891602, 72.56119666561004, 76.30593838230257, 67.22305482433688, 67.7250240695092, 79.39305551590459, 78.72402468035298, 83.03644318734446, 78.2476528229252, 83.49314043598791, 76.94009150228193, 82.20672853531377, 77.4872935202814, 83.47157524478051, 84.3664953785558, 89.18264819729714, 81.92648303124213, 87.89014877811556, 82.33619028522124, 86.25093536992227, 81.0058399938768, 83.86949185402163, 76.55036480196061, 72.74447333428168, 67.44176618514523, 68.73736427676293, 68.68328263682704, 68.22562048512121, 69.70701340706118, 85.4531958795363, 87.40563408021005, 90.8611245309153, 92.63038019980155, 85.59215761000111, 79.89829601780062, 76.89925178404778, 88.61649328662504, 86.68391012376355, 109.19648708835726, 51.39953497917422, 0.4957380085702866, 1.0358146121425014, 0.3533440816306299, 1.1511098641541697, 0.9859902147323856, 0.4660206306124888, 0.49183810009591045, 0.8111417389685108, 0.7625359116542725, 0.6431514048768628, 0.6124612484728137, 0.26047737127350223, 0.1944810109994104, 0.6322789011943726, 31.135027216326808, 94.63517419753536, 104.98178266709851, 111.89604266997307, 121.70383514896517, 46.809797056259654, 30.208547692145075, 53.392479496617476, 72.25190993278258, 89.37627207848334, 95.98015492962253, 77.50860767979776, 93.51036394796064, 12.029150339864916, 0.4972806338581347, 0.28722879386717276, 0.18466028474992324, 0.1619835306079157, 0.2309656113145813, 0.1709276684109242, 0.12299881767361395, 0.13045769485254444, 0.1280096838731439, 0.09864085293825596, 0.17461797522921718, 0.18171890548640685, 0.2696792210542387, 0.22418548803656335], [0.04655678343448428, 0.04694205288204455, 0.02363399632515446, 0.028375237879733888, 0.04499848398770537, 0.013996967426200789, 0.013916600972504146, 0.06320650937155851, 0.03540589106118968, 0.07084291593562211, 0.05851939958970874, 0.10265551372281007, 0.12346930291143157, 0.03171767183249036, 0.7486338673099395, 58.28019988152289, 93.02838310118645, 70.33212154142319, 73.72395192423176, 30.592979192733768, 51.51719039486301, 62.26400613784791, 79.59126072545206, 114.37977375522738, 94.78858593971499, 26.25890135765076, 0.1287164842529643, 0.11146933996989844, 0.048828207316898534, 0.15208002089733078, 0.48625687377587445, 0.1085800010590784, 0.20088530686353484, 0.08695988900839322, 0.23902896250928604, 0.25549398464781625, 0.2351103308460405, 0.7712497021402083, 0.37411784272520776, 9.949045854230082, 63.3229088014172, 100.27551112636444, 103.42762193372174, 100.25269077670191, 101.1239041051557, 99.2808686533282, 97.93757454041513, 100.11758865848665, 98.13411666500954, 95.32537798727714, 96.82610819416662, 94.91266619774603, 94.4591696031632, 89.74773622328236, 87.17013497506419, 82.07722756170458, 80.0470244499945, 72.54718595935454, 70.87303207766625, 66.05043872710198, 64.21395363346224, 65.5761065021638, 67.35291665600192, 65.85949774711364, 65.97957718756892, 63.76713291291268, 66.64026121939382, 66.53730684711088, 67.99076464868361, 67.34363632817423, 70.77045425291985, 68.32058106699299, 72.23168619217412, 69.00101031026533, 73.83409207867038, 74.03119902456962, 76.95985240321006, 74.243924848495, 72.68335496225666, 72.07602300951558, 72.25087442705708, 74.52196598052979, 69.50568599085655, 71.47414315131404, 64.26200266807311, 75.68931825699346, 61.30302936800065, 67.69645352517405, 82.15309404557752, 74.48575465909897, 71.98430230540615, 67.66922443143784, 62.04015254974366, 64.5109986489819, 70.13027637235581, 63.75669940825432, 64.29903768724012, 57.09293373169438, 62.61505826827019, 67.01411800999796, 66.58978031527612, 66.29296671959662, 70.26580210654967, 74.15768761788645, 72.39138157136979, 73.300822319523, 68.83707877128356, 73.96550716892366, 76.3775687063894, 72.82477209644934, 76.24694593491094, 76.69339010792395, 80.41933582675073, 75.33158240779754, 75.06914446430822, 75.81081759545111, 79.27051282698109, 74.50751596881499, 62.484886569361535, 63.135792132346864, 61.9818151381708, 61.11849754087387, 69.65997634395477, 76.22614168351697, 85.10623085883357, 73.19972715070172, 75.19450341501545, 78.6762031432121, 72.00143521831882, 66.72545509953653, 74.00130271911621, 80.99865421172112, 81.29131009501796, 80.15333637114495, 5.941438655699454, 0.04697985166022855, 0.11194645952914031, 0.19091853361216285, 0.3315132417746129, 0.059898028435606154, 0.1250126253392908, 0.3739138794762473, 0.051151828600033644, 0.22685947197098888, 0.23612622472067035, 0.28913034666930476, 0.029498372572444143, 0.13077920663260645, 0.9577967082300495, 31.901507377624515, 82.58358986146989, 87.42046848420175, 89.71739276762932, 90.89368804808586, 33.74247966274139, 9.682096204450055, 15.970291014640564, 35.16619805366763, 49.88597862182125, 62.280519316273356, 65.81540246163645, 59.15767723514188, 3.539804494188678, 0.12089491806804173, 0.1198802422732115, 0.05003010733954368, 0.0072582157689236836, 0.012423616266929576, 0.033602401343805176, 0.07221608257461941, 0.08274891819324225, 0.041681051314357793, 0.018462747703456593, 0.02325723236877351, 0.1317220616845354, 0.018595585434307015, 0.04516347634395765, 0.024307512099884694, 0.06499319878076354, 0.03881084161900705, 0.06715543598176972, 0.03767226642418293, 0.03215376355294739, 0.023135275001667684, 0.04000217345873675, 0.032658247772844574, 0.05931677837525645, 0.04412161591913431, 0.02453705119419723, 0.05057672256483667, 0.7438213642566436, 70.69516827983242, 101.15704028837143, 82.29031424368583, 87.12254878013366, 45.225857688534646, 56.08744982750186, 56.93736860829016, 92.3414348786877, 120.10887392105596, 109.23944488648446, 32.622386063298876, 0.26862284709368983, 0.07677715557116656, 0.1922326501939566, 0.01743527057941162, 0.3595733876910902, 0.15766222780990988, 0.259490650027029, 0.06185650540095183, 0.27029763787023486, 0.33053736833314745, 0.2421472161527603, 0.8911984786391259, 0.609504271659159, 10.361808634573414, 67.15646082355131, 101.44968832692793, 108.26078999427058, 106.46708226973011, 103.98204895757861, 102.53036406732376, 100.38005798093735, 104.44945427679248, 103.40885731481738, 99.1555489263227, 100.4479463638798, 100.26594054314398, 96.77234818858486, 94.3535872428648, 91.25108657344695, 83.95977697064801, 82.94345948003954, 74.05877328688099, 73.40012888754569, 68.56448973378828, 66.30076439149919, 65.73220899028163, 68.71066862537016, 67.82702922821045, 68.65362167358398, 68.4627591409991, 70.40408134460449, 72.56548773857855, 73.45957632987731, 72.98669538190289, 74.89412046247914, 71.005231641954, 75.14446181635704, 74.05900078435099, 76.66322708129883, 77.29956888383435, 81.28137865374165, 76.56297914443478, 77.70519687283424, 77.18220372353831, 76.76109021709811, 78.29329352225028, 75.03809498202416, 73.22018623352051, 68.39724771438107, 73.67187853782409, 66.38823324634184, 72.98798191931941, 84.02179748781266, 79.09923861103674, 75.36775450552665, 72.25609902412661, 67.93815781993251, 68.82939877048616, 73.58076972346153, 68.44266091623615, 69.66130994981336, 69.87019969571021, 71.72860299387287, 73.22486169876592, 71.40375229620165, 72.17373709524833, 78.07961064000284, 75.89920428491409, 76.91885579016902, 75.99582010699858, 70.08399240432247, 79.91547599915536, 77.4361458132344, 74.35983873182728, 80.34905479800317, 80.86435225702103, 83.54389590601768, 79.33785207809942, 79.5354453979, 78.88417505448865, 81.07662308600642, 78.21229657819195, 68.45435742408999, 66.6216770295174, 64.78357591936665, 64.76612529447003, 73.03828239440918, 79.61489692811044, 89.54691087045978, 80.07204132695352, 79.44897282508113, 80.83798608472271, 74.88393798951181, 68.32520946379631, 74.9294610177317, 86.8079040896508, 83.06255832795175, 92.84862872092955, 8.104446357296359, 0.2447971908916389, 0.3439158069029931, 0.6571835003072216, 0.26302096704321526, 0.11332973086785887, 0.10539198744921915, 0.757136094954706, 0.1213863711323469, 0.3051780807154794, 0.34239622553990734, 0.3970087031202932, 0.055199714617863785, 0.16534561471592996, 1.1794920121469807, 39.53666371683921, 93.27459027690273, 98.58460087930003, 82.3056193320982, 41.34013029836839, 32.41973876953125, 25.04814217167516, 32.60421176110545, 51.44950205279935, 61.49580993959981, 72.1207223399993, 75.09737768480855, 70.25729056327575, 3.576928011832699, 0.04976698678107031, 0.07386396834326368, 0.034676031434848424, 0.07726041915556116, 0.04183564785747759, 0.11175225624033522, 0.05312528258429901, 0.03056126402600879, 0.03187700854464164, 0.03329398966724834, 0.03190962665323769, 0.10766759800213961, 0.062447856330583175, 0.20358956659272795, 0.09090399309512108, 0.11999984391995015, 0.09112101048231126, 0.26571162105087315, 0.12211056936892772, 0.10281676756999186, 0.10592207432754579, 0.21077167152637438, 0.13665670979647868, 0.10198463520575916, 0.1829882825334226, 0.27651833310242624, 0.12747550608530162, 2.1068749072090274, 89.66189907443139, 114.0637876141456, 92.63149415293049, 95.7460835672194, 43.91936717494842, 66.39541902849751, 89.91121276732414, 105.41493000522738, 128.85444933368314, 117.0329826108871, 37.7736367717866, 0.44788907612523726, 0.368020027996071, 0.2981867010314619, 0.37100734189152723, 1.0903704911470413, 0.39816034777510556, 0.5278601978094347, 0.23646364048604043, 0.7967467630101789, 0.7652625105073376, 1.3343680241415579, 2.326124858471655, 1.0029810643003834, 12.598653974071627, 73.27180462498819, 109.40183101161834, 112.15386006139941, 111.4222909558204, 108.06513432533511, 107.56626375259893, 102.58599112110754, 109.33926136262956, 105.76499369836624, 103.6553704354071, 104.45867184669741, 104.17502957005655, 102.67957102867865, 99.1299750727992, 97.11435533338978, 91.06347960810508, 89.24207995014807, 80.25508265341483, 79.34674016890988, 72.95958395927184, 71.66683350839924, 70.66758617278069, 73.65360813756143, 71.88620382739653, 73.2639834188646, 71.94983251633184, 75.1664976919851, 76.50252757533904, 76.74886026690083, 75.72321538002261, 79.51282116674608, 77.08639590970932, 81.75091774232926, 79.18240854817053, 81.27647569102626, 81.60895932105281, 86.78782155436855, 82.47197489584647, 82.995391661121, 83.26031638729958, 82.19932310042843, 83.26638821632632, 78.47329108945786, 77.76010221050632, 69.61340996526903, 76.2567832393031, 71.19483901608375, 73.11997752035819, 85.5699569948258, 80.33776621664725, 76.2690681026828, 74.57942870355423, 71.13587010291316, 74.62416725773966, 78.42406534379529, 73.0481981462048, 74.30135619255805, 70.86737601987778, 72.17107772827148, 77.20296875123056, 77.18815788145989, 76.85694509936918, 78.22058062399589, 79.25735719742315, 80.85022387966033, 81.00791885006814, 75.2959986655943, 81.11350905510687, 81.83349147919687, 81.71385134420088, 83.14273941901423, 86.9984292984009, 89.1526734444403, 82.79827687048143, 81.68959540705528, 83.4893592711418, 85.19206016294419, 82.28491706232872, 69.15366111263153, 70.84407714105421, 69.79242693993353, 69.24627611714025, 75.91814933284637, 84.70171682296261, 91.5439699542138, 83.06193074872418, 81.42992665690761, 85.80871951195502, 80.41829247628489, 72.38761609600436, 78.06242281390776, 91.12823793965002, 86.26441263383435, 100.64080930525257, 9.838020224725048, 0.3941186211041866, 1.1027850378905575, 1.2741377012383555, 0.7989522382136315, 0.3464869205509463, 0.30676149252441626, 1.1561509678440711, 0.501336885556098, 1.2183468884998754, 0.8215624959238115, 0.37292305199849995, 0.3253189306105337, 0.21065105864357567, 1.990524660195074, 50.263306710027884, 101.56185242437549, 106.59694410139515, 115.91685648887389, 123.11559031086584, 44.600733864691954, 18.048888329536684, 26.60232447808789, 51.82481012036724, 66.44953204739478, 82.65045058342719, 82.57947137278896, 85.58757628163984, 5.44380461016009, 0.2948949744384135, 0.2360272614826118, 0.18828392659704532, 0.25670564463061674, 0.06537117124084504, 0.15546652788837112, 0.16147622718445717, 0.1476300459715628, 0.0755968209235899, 0.1798304374660215, 0.15073806468036868, 0.18890070398488354, 0.14151458057665056], [0.03409555512330225, 0.012032188430067994, 0.07105072494596243, 0.021581066464404428, 0.04736066247606951, 0.0805923960081512, 0.06029857367637658, 0.05000294569218832, 0.0322034290330785, 0.07069589600207345, 0.043741172825497006, 0.038236708515473915, 0.16808983359125354, 0.3684631026079578, 6.882100980128012, 84.53029355695172, 72.13002620204803, 78.68829188808319, 41.1101342785743, 34.78205680847168, 30.903295547731464, 37.06922223491054, 95.3935174019106, 107.9937001197569, 57.938565361884336, 1.6382456859273296, 0.11072049668479352, 0.15404017942567028, 0.07745472203579641, 0.044227742079284885, 0.2306122302768692, 0.2619780455866168, 0.3185735570807611, 0.10934387498925771, 0.1041809403367581, 0.09529314063970121, 0.36006867885589605, 0.9833636976057484, 0.24655957616144614, 12.862110753213207, 71.70508446231966, 100.86159952225225, 97.99681017475744, 100.06642526195895, 102.98893620890956, 98.0762303260065, 96.69083349166378, 93.09283548785795, 95.62798884607132, 99.22987784108808, 98.40657234191896, 94.84277740601571, 85.73176260917418, 81.63865950799759, 75.47765931775494, 73.35277803482549, 68.32491920840356, 63.89814399903821, 63.696361587893584, 62.560725596643266, 63.73046659654187, 63.08227923608596, 67.910261923267, 66.03532191245787, 65.92478952100201, 69.81008545044931, 65.77926566523891, 65.66554830920312, 66.95068543957126, 64.69676210034278, 68.21731290509625, 67.68534537284606, 71.25609859343498, 71.40451323601508, 74.97483499588506, 75.61681716672837, 76.36152621238463, 69.82132696336316, 67.79713292275706, 70.74677098181941, 74.1176715973885, 70.71032431817824, 69.49403655144476, 64.36787920613443, 69.2991182881017, 74.57787544496598, 61.15461080305038, 78.15001718459591, 79.4255719646331, 74.96360917245188, 81.82152040543096, 77.80298940597042, 73.8255334669544, 67.55217306075558, 65.53279569072109, 67.70845597790134, 67.54487745223507, 70.40231627802696, 76.71362169327276, 69.62810316393453, 74.58093489370039, 66.89468968299128, 64.55334847973239, 69.55776722200456, 72.73644816490912, 72.51383012340915, 72.75751129273446, 72.01642651711741, 65.79941880318427, 63.242080519276286, 66.30154886553365, 67.40394669194376, 73.10612370890956, 74.22104174090971, 75.59005091267248, 74.52858694138067, 78.9102509713942, 74.26319153078141, 68.74768011031613, 59.6450670303837, 58.527838722352065, 61.855530508102916, 68.58546656946983, 77.40159757675664, 75.89741568411551, 75.03226633994811, 83.06280935964277, 74.27756309509277, 72.57911405255719, 66.03157997131348, 68.21746979990314, 77.59993614688997, 81.09203015604328, 78.38805014087309, 41.090534194823235, 0.4759835121372054, 0.1896727520732149, 0.713147632777691, 0.24795521982014182, 0.18536500903146882, 0.15482620095774052, 0.18955866625953108, 0.06631844662009709, 0.349552528632264, 0.4379011282036382, 0.050214320841816165, 0.06855062764859007, 0.029649839646393256, 0.11644561729964711, 6.7776193349592155, 52.931655914552756, 86.5005942313902, 76.78125904452416, 75.50444910603186, 50.96872145129789, 36.48738568828952, 22.638006517964026, 20.457533482582342, 33.23077509480138, 59.10507432876095, 69.80508835084977, 70.83536163453134, 46.920957026943086, 0.32594779686581704, 0.14110054069709393, 0.038756414902426546, 0.04225216220102964, 0.02447523939002666, 0.03251348779867253, 0.042278959956620975, 0.11784286974298379, 0.03951111876015221, 0.05042540870847241, 0.1086370746094373, 0.020217772783531297, 0.015318045832006442, 0.04269284278815312, 0.025762809110024286, 0.003173130197307816, 0.04585757881643311, 0.0320002606003395, 0.023135663791289254, 0.05366858064887985, 0.06953720333835772, 0.04113452035873648, 0.029849664105342764, 0.06593227701922579, 0.06824997644270621, 0.1618017839087594, 0.6784856475649342, 8.681334833944998, 98.97435895858273, 81.37269143135318, 88.05808897941344, 53.90089711835308, 42.766394307536466, 34.179113987953436, 46.091877798880304, 104.87595711984943, 115.08743209223594, 71.18204424458166, 1.8399729387414072, 0.22728221460936532, 0.11658792579246145, 0.22952245488282175, 0.09610927708807493, 0.1627966716525055, 0.6459503224299801, 0.627967419643556, 0.5808036762379831, 0.17304063083664065, 0.07007707315947741, 0.291170101732977, 2.0344145115344756, 0.7313519656177491, 15.124917280289436, 75.96016576213222, 104.58113608821746, 103.4441900253296, 104.99849980877292, 106.87340844062068, 99.79177305775305, 99.84084975334906, 93.18471308677428, 97.23457597917127, 100.67392195424726, 99.47504951107888, 97.22082414934712, 89.95409996278825, 86.17528069403865, 77.96676405014531, 74.36451419707268, 72.68331573855492, 68.26906465714978, 66.00620223629859, 66.9713955540811, 67.42929304799726, 67.4908350360009, 68.96502648630451, 70.48803575577276, 70.74069130805232, 73.14119754299041, 69.07010678322085, 69.70298121052404, 71.97630067025462, 70.4128360748291, 73.30079878530195, 71.92828301460513, 75.3854130160424, 74.42300458108225, 79.45327958753033, 80.07183736370456, 79.3092893785046, 74.4541403555101, 73.16421401116156, 75.06888558787685, 80.15549367473972, 73.11940485431303, 73.49594454611503, 68.50512858360045, 71.77964087455504, 74.46930423859628, 63.67662814355666, 79.5701426844443, 81.00890728735155, 77.48930961854997, 85.03400433448054, 78.93959814502348, 77.56182639829575, 71.0745869913409, 70.04056392177459, 72.36212853462466, 73.99978083948936, 70.03583354334678, 76.82795878379576, 73.4963446278726, 79.18197708745157, 71.80452439092821, 75.78345514112904, 73.85557882247433, 74.87325345316242, 75.26582779422884, 74.09509443467664, 75.95604727345129, 70.87247510110178, 67.55269081361833, 65.10678706630584, 68.98779976752498, 73.67926828322872, 75.4372981286818, 80.26712432984384, 78.78516658659905, 80.51087610183224, 77.1721310769358, 71.87086736002277, 64.19952323359828, 63.13843580984301, 66.51673793792725, 72.33797457910353, 79.19265377906062, 77.37889489819928, 78.3196440050679, 87.2105432325794, 79.34043299767279, 75.58124126926546, 69.47023560923915, 71.00685550320533, 81.23123507345878, 86.34871221357777, 89.22890863110943, 51.71467781066895, 0.6151780414004481, 0.1184911103618722, 0.8173402482944151, 0.330279074128597, 0.17903041184669544, 0.04865159340683491, 0.1941576606083301, 0.17649274559751635, 0.40383929627076276, 0.5881031458416294, 0.3207835675247254, 0.33884890137180207, 0.13271382378955043, 0.19359979538186906, 7.303435119890398, 61.75897352157101, 94.86012212691769, 89.98379230499269, 71.12358523953345, 30.36875101827806, 30.970073899915143, 32.617914561302435, 31.887631993139948, 42.91876269925026, 72.02956645719468, 77.58353279482934, 82.72149255198818, 52.53553967322073, 0.28067760830444677, 0.08005443374596297, 0.04310028665068169, 0.029822839536674084, 0.07049762478639042, 0.036419310471824104, 0.04680433708633627, 0.00472471033478336, 0.05889572113031342, 0.10110287566579158, 0.11096151560665139, 0.028340503453247012, 0.030566383408562794, 0.18131876244179665, 0.1076130448810516, 0.19929758964046357, 0.16318264207051647, 0.26261362277211686, 0.18522297633030724, 0.20650284575118175, 0.23997311991068626, 0.10019284748141805, 0.16091264694208102, 0.12171719088068894, 0.2620218964594026, 0.32131560026637973, 0.8695245642335185, 12.60355301441685, 115.7635545730591, 91.13089730662685, 99.14787677026565, 56.692702924051595, 48.29769326794533, 41.077927697089414, 58.8093589967297, 115.61318659013318, 123.89890332375805, 80.24974038524013, 2.4981683492660522, 0.3088326878365009, 0.34592151701931034, 0.600042043914718, 0.3310047126104755, 0.8480377591425373, 1.7943679084700925, 1.6842875701765863, 0.8318776553196292, 0.32799135172559374, 0.22908164789119076, 1.1730940135255938, 2.968380859782619, 1.6657618481305339, 16.40954842490535, 83.19017656387823, 110.4004115443076, 110.62309234373032, 108.70042493266445, 110.21287518162882, 103.96986607582339, 102.86309088430097, 96.53961043204032, 102.04512765330654, 104.90378241385184, 107.14149459715813, 104.33731371356596, 95.05580133007419, 91.5270253150694, 82.61446675946637, 79.58412201173844, 76.23353142892161, 72.3212339032081, 69.53981061135569, 70.63463826333323, 72.27618155940887, 71.5091306932511, 73.40655372988793, 73.5550703540925, 74.15560876169513, 77.75210842009514, 73.64282946432792, 73.63705573543426, 75.39036304719987, 75.2797600530809, 78.56902830062374, 76.06428900072652, 80.99512407856604, 79.14967244671237, 84.61542467917167, 87.11426473432972, 87.3518583851476, 82.62981107158046, 79.53522574517035, 79.7378396987915, 85.06864670784243, 78.49957096961238, 78.5230032090218, 71.01417464594688, 72.63725142325126, 76.21202115089663, 64.11120714679842, 80.68486459793584, 86.13056567407425, 80.87353060322424, 89.8955781998173, 81.41907738101098, 80.80141390523603, 74.4103039464643, 72.90079547512916, 77.15653573313068, 75.26576503630608, 74.01016727570565, 84.13297314797678, 78.49553092833489, 83.610301633035, 75.4220401087115, 74.08745365758097, 76.21435888351934, 79.74224844286519, 80.54219230528801, 78.46150044471987, 80.09083732481926, 76.91798502399077, 72.75958230418544, 73.32150889981177, 73.55526647260113, 80.00329002257317, 80.49286457800096, 82.52033772007113, 80.72500613427933, 83.56708495847641, 81.23625570727934, 75.67669606977894, 67.44897550152194, 66.51316858107045, 69.66811133969215, 78.12356472015381, 84.78431409405124, 80.61627018836238, 81.82953773006317, 89.96323908528974, 82.29007890147548, 77.2369364769228, 74.52671989317864, 74.53075993445613, 84.96944212144422, 87.71445797335717, 97.03891246549546, 61.595010603627856, 0.4955663742317308, 0.29478239015706126, 1.878870470869926, 0.6605754924877998, 0.5179465910600078, 0.32846678589140216, 0.7599052270093273, 0.45625754481842445, 1.154909537684533, 1.8517751054417704, 0.40905313746583083, 0.25447164031286396, 0.29894114441929326, 0.4082590413670386, 11.879183419289129, 74.76302700657999, 104.63943035371842, 98.55810134641587, 102.38641308199976, 71.6918582300986, 49.25716384764641, 32.4171245098114, 31.566042746267012, 50.91680495969711, 81.23114093657463, 89.075865591726, 91.35189933161583, 65.79251150931081, 0.4188191037504904, 0.4244385731797065, 0.2938016750399144, 0.09632290070576054, 0.22919421685078453, 0.18583071388063893, 0.16534650337792214, 0.283051653494758, 0.17444295478203606, 0.19171239988457775, 0.33086899247380996, 0.11627193750633348, 0.13481316517197317], [0.07944236779885908, 0.011372967856004836, 0.10834796834857234, 0.0675849125330006, 0.04919382660920101, 0.06026770033302808, 0.07248654225540739, 0.02471093208559098, 0.04279775469894371, 0.033251866322731784, 0.03381139012954889, 0.05807588830770505, 0.1318368369773511, 0.2728933276187989, 29.689371009026807, 80.35499326644405, 67.28152167412543, 67.17469984485258, 46.327816209485455, 37.07232875208701, 64.77324831870295, 74.85899955995622, 101.33040904998781, 86.95372996791717, 11.38402242814341, 0.024493981731094183, 0.07817987022140334, 0.15170689011293073, 0.12159661630228644, 0.05090455840071363, 0.12152272712198958, 0.39253119499452654, 0.2522526359966686, 0.6117972647470813, 0.1504514252226199, 0.3117407882405866, 0.40637281032339223, 1.877356313409344, 0.46504959884670477, 27.555764413649037, 91.00139633301767, 97.87522454415598, 99.64302893607848, 97.41396165663197, 98.4641605807889, 94.87427403849941, 100.64470029646351, 92.85146067219397, 98.19536839762043, 92.16743069310343, 90.85185204782795, 83.42746426982265, 77.82860248319565, 70.72006748568627, 67.79662301463466, 68.07112616877403, 69.50556047501104, 67.39865933695148, 66.7630627847487, 65.62590491387152, 67.3061070903655, 72.12518599725539, 75.11714643047702, 73.92924093431043, 75.55480449430405, 72.75739362162929, 69.00004540720295, 67.24214892233572, 66.14005704079905, 66.48433131556358, 68.83099125277612, 71.43557840777983, 70.76878332322644, 72.28146891440116, 76.23533571920088, 73.13421572408369, 69.0967789003926, 64.07453690805744, 69.14640472781274, 74.48517414831346, 70.9019713247976, 68.19664985902848, 66.47383505298247, 69.19744260849492, 70.96594518230808, 73.7640699263542, 73.19711485216695, 75.85379108305901, 78.41781308574062, 76.39655297802341, 75.77958768413913, 76.53667573005923, 77.28515809582126, 72.22459454690257, 71.57311239550191, 65.35360220939883, 65.8563127825337, 61.03804972863967, 67.28841720088836, 73.48074143932712, 73.9279700863746, 75.62626223410331, 68.81407014785275, 74.13900144638555, 71.57606986261183, 73.21664041088474, 69.67633262757333, 68.87915795849216, 64.96115338417792, 61.64566801440332, 59.39614949687835, 67.2908333809145, 70.69599982230895, 74.17806825330182, 77.02854879440801, 82.41119384765625, 78.01712728315785, 75.4375962288149, 66.14492862455307, 62.57705050130045, 60.04442314947806, 59.63669277006581, 63.054587302669404, 68.07708817143595, 72.71933878621748, 78.09860275637719, 77.18921692140641, 76.91480790415119, 69.12436885218467, 66.94560204782795, 64.6055434596154, 70.31729498217183, 78.99042421771635, 72.08254983348232, 67.60745494596421, 15.093834457858918, 0.1763697271986354, 0.1902314140311172, 0.41078293335533916, 0.7788917662635927, 0.45220098668529146, 0.34431359039679654, 0.06330379104662327, 0.10170639973253974, 0.19648632275000696, 0.8717948811188821, 0.2019099341405015, 0.05454670127120711, 0.04000495052746227, 0.08637755493363065, 16.88856101805164, 70.0612897257651, 85.46664960922735, 73.55963599297309, 96.0803871770059, 79.35684419447377, 38.267408263298776, 27.006744377074707, 24.94367572569078, 30.6366842023788, 61.036457246349705, 60.54824767574188, 75.42588403148036, 8.161234922947424, 0.5696959529192217, 0.14226534674244543, 0.09324701172449897, 0.11400676107094174, 0.022991974424991398, 0.05834123435159845, 0.015411546863164875, 0.0378625818167723, 0.09093815295566475, 0.042011878723579074, 0.054868971478314175, 0.03133190634299911, 0.03834034488987058, 0.052735324678642136, 0.06369161539741101, 0.022000166354700926, 0.07196459123083661, 0.011411760633270587, 0.018523883435033986, 0.05977444696210085, 0.05914622805111351, 0.08616512641310693, 0.01607355887010213, 0.051245693522956104, 0.15998108402615593, 0.4059271922995968, 35.66226805410078, 91.59098348309918, 78.95516995460757, 79.96630991658857, 48.7786699879554, 45.119498698942124, 43.18240481038248, 74.08978354546332, 113.5823872781569, 98.27265477949574, 16.665982200253396, 0.04125675734793467, 0.045739011388392224, 0.28411768016315275, 0.08784362505520545, 0.1924981915902707, 0.13561954932107081, 1.2405064413624427, 0.1863633441708742, 0.847522825483353, 0.6360658883087097, 0.5636442260396096, 0.8626532458489942, 1.781074260511706, 0.7806779155808111, 33.169095823841715, 96.12818517992574, 105.07967718185918, 105.77949862326346, 100.9342182836225, 101.36412574398904, 99.41052652174427, 105.84078173483573, 97.97267975345736, 101.04985760104273, 95.49875459363385, 94.19440177179153, 86.54531709609493, 82.80623143719089, 73.51060636581914, 71.9285418910365, 70.55881100316202, 72.98715822158321, 73.9747247388286, 72.46222742142217, 70.3470108585973, 73.1886503773351, 75.95097957118865, 79.15054321289062, 78.84790881987541, 82.05253231909968, 77.53846476154943, 74.49116752993676, 73.74267731943439, 70.67653702151391, 73.66313165233981, 73.03435217949652, 76.00456699248284, 74.36446712863061, 77.48674438845727, 78.83283907367338, 76.37705095352666, 72.35054185313564, 71.13031602674916, 75.17896298439273, 77.3400712782337, 76.06129230991488, 74.1890508897843, 72.45816384592365, 69.97520938996347, 72.02438892856722, 71.05142147310319, 76.75102541523596, 78.59741057119062, 82.32638435979044, 79.66968459467735, 79.62377717418056, 78.01122019367834, 78.80677100150817, 77.80832382940477, 77.06497976856848, 71.91958319756293, 68.43712252955284, 66.51974247347924, 70.60826424629458, 76.9601583480835, 75.48398217847271, 78.59435112245622, 75.67163621225666, 77.40433539113691, 74.47710191049885, 75.93652955947384, 73.04993967856132, 72.83681377287834, 69.02586244767713, 65.52257399405202, 66.5675090974377, 72.82128903173631, 75.94577850834017, 79.01691590586017, 79.08101527921616, 83.94192234162362, 80.0875739128359, 78.79163065264302, 69.29761209795552, 65.55511397700157, 63.784077552057084, 63.791596735677416, 67.91427843032345, 71.21081090742543, 75.24829479955858, 79.34286486717963, 79.41665249486124, 81.16937929584135, 73.81101285257648, 68.86193090869536, 69.14247451290008, 74.75383297089608, 82.54044378957441, 80.75159980404763, 82.64888163535826, 20.085067172204297, 0.32737630569646436, 0.19002694516412674, 0.5815866180965977, 2.0753368446903844, 0.5452290658027895, 0.554505409973283, 0.2258183738036502, 0.15977575714069028, 0.6294106680058664, 0.28472874253507585, 0.7437024061237613, 0.13970737916327294, 0.1027040224101755, 0.09626865401984223, 20.946853083948938, 79.19473263525194, 91.79321304444345, 86.98183767257198, 61.8249281760185, 29.10429850701363, 18.5649839908846, 30.823579257534398, 36.3914405915045, 39.0938751928268, 80.13250074078961, 68.66320010154479, 91.23286324162638, 9.019367637172822, 0.40410825441921916, 0.10852672730482395, 0.00905316073312274, 0.03732536265987062, 0.061430051066582246, 0.07132070965223736, 0.026926820339154334, 0.0032429509719217858, 0.09220805860334828, 0.020951278988392125, 0.05149824589851403, 0.017246406923438755, 0.2601342864574925, 0.10787007504052694, 0.2749998549059514, 0.16981216778437938, 0.12372803378609881, 0.15633378538393206, 0.15005817696932824, 0.2340540334942841, 0.18000748038532274, 0.1630286737194946, 0.14811467319246263, 0.13312256234067102, 0.2743658711833339, 0.5366366236440597, 47.236958857505556, 106.10559663464947, 86.25859968123898, 89.95530805280133, 65.74607456884077, 51.70382853477232, 85.8230753867857, 104.35261880197834, 117.96533784558697, 110.06652370575937, 20.49838104555684, 0.2399386919193691, 0.17079150394326256, 0.32984010574798434, 0.31200487406984456, 0.4543615691363812, 0.532653211585937, 2.9060921505574258, 0.8002971208864643, 2.45068266507118, 1.5335865535082356, 0.8522266666254691, 1.451488404024032, 2.9900316076893962, 1.6726981920580712, 36.19288236864152, 108.54008628476052, 113.63554323873213, 112.57411849114203, 107.02570622967137, 108.94584763434626, 105.45805254290181, 111.04648082487046, 99.77115708012735, 104.24618920972271, 99.7623945051624, 97.71896516123127, 91.36434108980241, 85.68165825259301, 78.48862755683162, 75.95170128730037, 74.92694285608108, 76.86669611161756, 76.29298671599358, 75.01693771731469, 73.44153342708465, 73.98347162431287, 77.83393690663, 81.95045655773532, 83.66050797124063, 86.59589998183712, 81.25546747638334, 78.83265864464545, 77.5119338497039, 76.22250956873741, 78.08242690178656, 78.34524923755278, 79.12615391515916, 77.4602605450538, 81.83991632153912, 88.13504588219428, 84.60208862058579, 81.3989713115077, 77.30436986492526, 81.19780863485029, 82.53681167479485, 78.77899277594783, 77.01888407430341, 73.63154088297199, 71.66616670546993, 73.82219160756758, 72.27612664622646, 77.20416115176293, 80.31347105579992, 85.05958603274438, 82.69551077196675, 80.07908590378301, 83.14838763206237, 81.1516188037011, 80.5720180080783, 77.04679566044962, 72.95158232412031, 72.19837742467081, 69.53066364411386, 74.37918386151715, 82.91380636153683, 82.34240331957417, 81.06596208387806, 75.65787653769218, 79.55496311187744, 79.57280205142114, 78.83295674477854, 77.43355704892066, 77.68907593142602, 75.95218766120173, 69.11805383620724, 68.40766552955874, 76.44089145045128, 82.14939917287519, 84.07309424492621, 84.00933219540505, 87.57941076832434, 84.13498140150502, 81.39637470245361, 72.23767172905707, 69.18315733632734, 68.90572809403943, 70.41035713688021, 72.95245309029856, 76.82515036675238, 78.85104671601327, 85.6053916869625, 85.91539229116133, 85.79639542487361, 76.17323675463277, 72.62902229062973, 73.08527238907354, 77.48989797407582, 87.3709995515885, 82.75959445584206, 97.46462298977761, 22.865284335228708, 0.42404544750048273, 0.8196473986871782, 1.291439766364713, 3.651578070655946, 0.6308137733609446, 0.8177818213739704, 0.55758134491982, 0.5448866551441531, 1.0959462629210566, 2.216075408843256, 0.7332590342529359, 0.20879370911467462, 0.1329874703961034, 0.40059684445300414, 30.286781326417003, 91.24104530580583, 101.99477226503434, 96.38040927148636, 132.464967543079, 106.51019696266421, 52.937362963153475, 39.78345140334099, 39.547744412576, 49.37581554535897, 81.84939276787543, 79.39751917316069, 99.69759694991573, 11.001657036042984, 0.8203954682234795, 0.2925980283368019, 0.19532209893147792, 0.1963997394928048, 0.1677152012745219, 0.2004453119251036, 0.07836359342740429, 0.14420708851708522, 0.22613458425527622, 0.1804402281319903, 0.24772007679266317, 0.09831364146403729], [0.07526817686495281, 0.09299318381254712, 0.04063429175725868, 0.029400795953528538, 0.06517909001559019, 0.013059166639352278, 0.042627219696559256, 0.025917593344685533, 0.042200079713497436, 0.03807713623128591, 0.07570300070989518, 0.07164302582461989, 0.025625736828172402, 0.03744662671740498, 39.05741676207512, 84.86798609456709, 68.07044367636404, 81.87920278118503, 39.802965194948264, 43.28140935590191, 61.42591330312914, 75.66485835659888, 107.00334087494882, 45.51293988381663, 1.3111246713707525, 0.09079651095934453, 0.11027566773156006, 0.03767871305406575, 0.05210469642113294, 0.1769499775142439, 0.05347022899396477, 0.09246897282859973, 0.3163829133395226, 0.2659141440545359, 0.22058357244297383, 0.0861311350919066, 0.7545234899847739, 1.0057855589735893, 3.7056908444050825, 71.83631127880466, 100.61751827116936, 92.425640321547, 93.93288166292253, 93.7020815572431, 91.08083217374741, 92.69820582482123, 95.7573486143543, 96.23284186086347, 96.08167371442242, 93.47707871467837, 87.74907681249803, 76.17613146381994, 69.92493244909471, 69.05800234886908, 71.41913583201747, 70.56963674483761, 75.48801437500985, 76.2641808294481, 77.24564413870536, 77.77932966909101, 81.4536177727484, 82.08234233240928, 80.0038391543973, 83.56368818590718, 80.37664474979525, 78.82109549737747, 70.74404885691982, 69.93125530981249, 69.61244506220665, 68.38546491438343, 68.77459541443856, 71.24057385229295, 69.87172942007743, 77.93620094176262, 71.71133672037433, 68.52119461182626, 63.094501341542895, 67.90358604923372, 75.3798589398784, 75.32285121179397, 70.92297953944053, 73.45083728913339, 76.79903522614511, 68.24512250961797, 73.58696706833379, 73.47443426809004, 75.98624167903778, 78.13788921602311, 79.53705356967065, 79.27448226559547, 76.73082520884853, 71.20651983445691, 72.14864177088585, 72.79616232841246, 74.69708411924302, 74.30509813370244, 69.37514951152187, 71.21631791514736, 60.87836611655451, 65.89224169331213, 59.38564931192706, 71.0451299913468, 69.63944665847286, 69.61692440894343, 68.01691116825228, 71.29787183577015, 69.3638687749063, 70.17905496781873, 57.519479720823234, 55.717895876976755, 69.09295066710442, 65.56834805396296, 68.63886571699574, 72.18569247953354, 71.81000001968877, 71.6574433542067, 71.95335480474657, 72.08638591151085, 65.5650964090901, 59.4970916932629, 57.85216339172856, 57.82088248960434, 60.78333493201964, 69.64078810907179, 72.76960788234588, 77.24126677359305, 74.81799510217483, 76.55675042060115, 69.78910077002742, 64.1791622100338, 63.18166817388227, 70.47951636775848, 73.98000424908054, 78.01393447383758, 68.3434877087993, 48.20878490324944, 5.62564863312629, 0.34310044420342295, 0.20594121137213325, 0.21284727950490293, 0.6535519371109625, 0.5418824873143627, 0.052350342514053474, 0.34227264023596243, 0.18708938101847328, 0.5135185415706327, 0.8776409899996174, 0.4691285880342607, 0.22907676025023385, 0.09938448682547578, 1.8186577986324988, 34.81133337943785, 83.33794793775006, 88.17880384383663, 83.43241430098011, 75.90784134403353, 94.53449479995236, 32.724991344636486, 52.684848616200114, 76.54667777399864, 29.061909452561412, 59.65450033064812, 73.21929193312123, 26.853163972977672, 0.5100032092342454, 0.37464080498583857, 0.08832825993698451, 0.0656606528847929, 0.07933249546875877, 0.05740828864697007, 0.07639556717608245, 0.04286417835241845, 0.05652627246754785, 0.015438652011535823, 0.03574404227096708, 0.03787971920363846, 0.03149578787176119, 0.025048246344311104, 0.04619922338714523, 0.02005222692875372, 0.06325299941724347, 0.02223833159904086, 0.015962425367756477, 0.03517142602152402, 0.04262133614130078, 0.01685154605506649, 0.0742106614333968, 0.05501920898114482, 0.0792244540887975, 0.04047210328280926, 50.796682373169936, 93.8305627146075, 77.3791459298903, 86.42102503007459, 53.09217891385479, 34.502234920378655, 34.765998624986224, 87.16665975509152, 114.9431751620385, 56.92727242746661, 1.0735902238276698, 0.020710164305543708, 0.1349354634482053, 0.2084117223538699, 0.25601441881829695, 0.05232021993687076, 0.022200655394924745, 0.12161709383250245, 0.48817770135018135, 0.489306700445952, 0.6464289741650705, 0.7202962137037708, 1.6479028064397074, 1.2571649926324047, 6.115973832145815, 79.09393556656377, 108.95236661357265, 98.83144347898423, 99.79554637785881, 96.35208191410189, 93.80689513298773, 96.08157173279794, 98.55472026332733, 99.32005313134964, 99.42769081361833, 96.68392227542017, 92.2464507625949, 78.2841936234505, 73.15993862767374, 72.36801993462348, 73.83758298812374, 77.07000040238904, 80.88401902106501, 79.27136005893831, 81.67975810266311, 82.93819565926829, 86.68536924546765, 86.87896959243282, 85.30606777437272, 87.26802948982485, 86.04458731989708, 84.12275929604807, 77.64936585580149, 73.17034859811106, 74.11694203653644, 72.36813760572865, 74.32524342690745, 75.04174278628442, 75.38028255585702, 80.68187575186454, 74.73273061936902, 73.36214465479698, 69.1512841563071, 72.86631784131451, 78.72335003268334, 79.02364669307586, 74.95139491173529, 78.97547998735982, 79.22514669356808, 69.86203332101145, 74.8772934944399, 76.10904324439265, 76.96530449774959, 78.14491810337191, 84.19077319483604, 81.39318189313336, 79.87716228731217, 76.05578530219294, 76.02395134587442, 78.23034732572495, 80.12315765503915, 77.94765426266578, 73.51959643825408, 73.82994221102807, 65.69122022198093, 66.91400343371977, 64.11066978208481, 69.27170092059721, 72.92558485461821, 74.9850017793717, 73.19722467853178, 73.80414870477492, 68.46461834446077, 72.06114153708182, 61.9310635905112, 61.92276777759675, 77.00175116139074, 72.1927684353244, 74.07853418780913, 75.61945299948417, 77.2864995464202, 76.66953425253593, 73.86303917054208, 73.11714556909376, 67.86608819038638, 65.17560112860896, 60.66426746306881, 62.45870474846133, 64.88769523559078, 74.78333703933224, 76.67235835905998, 82.30216764634656, 80.14426000656621, 81.9257926940918, 74.02502521391838, 68.44528105951125, 67.41551768395209, 73.24814488810878, 77.68741284647297, 84.27041299881475, 77.39987957862117, 60.42786229041315, 7.638059873734751, 0.21088436306003602, 0.6715877918947128, 1.0201397177673157, 1.5596270465081739, 0.3957612361879118, 0.10719776393905764, 0.21294137042376304, 0.017611210332101872, 0.3563032034904726, 0.6392441726019306, 0.4221788895947318, 0.5223494515784326, 0.1809515152126551, 2.0588498971154614, 40.13367199128674, 92.61236867597027, 97.1377718833185, 92.01328154533141, 66.1483959997854, 55.095619693879165, 21.23367051924429, 48.56475960823798, 83.27892411139705, 39.44327600540654, 64.1595817381336, 85.86333459423435, 31.646286595252256, 0.6351619658450927, 0.24269421825245505, 0.09696747942437088, 0.08292443659757415, 0.01839934435162333, 0.012271476950826905, 0.06531029789438171, 0.05830140927085473, 0.01752685830597916, 0.08635510089657, 0.05949636470646628, 0.010923818166878436, 0.21168898520690782, 0.1876930276592893, 0.2016222528031757, 0.10659292220107972, 0.15540589969004356, 0.18786608692138426, 0.0955243000099736, 0.08591122189236265, 0.12437902466063538, 0.11042577499944357, 0.14818958126969878, 0.08649025412817156, 0.20887500636519926, 0.14699862098261235, 61.89547592593778, 106.4537383664039, 86.57995162471649, 98.14946097712364, 56.36941332970896, 58.373305182303156, 89.98294507303547, 99.1393103138093, 122.78349891785653, 69.21266924950385, 1.5379244497706814, 0.07403665222227573, 0.35024654300462815, 0.38028527952490315, 0.7006507775475902, 0.49203792647007977, 0.22654476305169446, 0.48248278758218216, 1.4083743239602735, 0.9094847522435651, 1.5802265992087703, 0.9325861029567258, 2.8496436053706757, 2.7992048667323206, 6.9122890118629705, 89.52709505634924, 115.47728430840277, 107.29241955664851, 105.98459151483353, 99.43744967060705, 98.59474412856564, 102.28592980292537, 103.21688867384388, 104.10807471121512, 101.58067980120259, 99.37036145117976, 96.41013299265217, 82.73287527022823, 77.36250723561933, 77.41844807901691, 78.48770187747094, 79.08751072422152, 82.71325557462632, 83.34980134041079, 84.4208594291441, 87.41441234465569, 91.43373566289102, 91.55403475607596, 86.72280434639224, 91.05084173140988, 88.85394573211671, 87.70401662395847, 80.7566753510506, 77.72378106271067, 79.08495333886917, 77.70727572902557, 76.84322464850642, 80.80732883945589, 80.8089997691493, 87.3918979398666, 81.23882093737203, 81.26759544495614, 77.63322138017224, 77.2631771333756, 84.18765883291923, 84.54255488611038, 77.82584897933468, 82.29075354914512, 83.77928518479871, 69.98470937052082, 75.4250446442635, 76.61136550288047, 79.85809172353437, 82.06320901070872, 86.88537090055405, 87.59821461093041, 82.87594764463364, 77.54568976740684, 78.0533072256273, 83.58672034355902, 82.06179695744669, 80.98119181971397, 77.56685487685665, 77.2001995578889, 71.58170238617929, 73.64348057777651, 68.3711168842931, 79.6321318226476, 76.69895987356864, 77.98818019128616, 77.34191479221468, 80.83717023172687, 75.62140633982997, 78.66287492936658, 67.10965125791489, 64.26015915409212, 81.40971076103949, 77.30263617730911, 78.45166314032771, 80.54483598278415, 81.45570447368007, 80.7530746152324, 78.3099086823002, 79.73590204792639, 71.90060677066927, 69.15526928440218, 63.74616392197148, 66.95987163051483, 69.36285680340183, 79.85033327533354, 80.57278679263207, 84.77653211162936, 83.53610607885545, 84.21753160415157, 78.1356377755442, 70.62592275681035, 70.75871067662393, 76.69323321311705, 82.65221565000473, 88.21769022172498, 86.36003217389508, 72.27760930215159, 7.5003175100972586, 0.5532490870644969, 1.0318804748596684, 3.2525195613984144, 3.3796352436465606, 1.1641944007527445, 0.19356234900413022, 0.9678360146860924, 0.8307565928947541, 1.1449545621871948, 2.0564373943113514, 1.1389691478783086, 0.6277018629254834, 0.23041229665039048, 4.155756590827819, 51.851666588937086, 101.87917217131584, 105.37734585423624, 108.70681839604532, 111.51845962770524, 126.70357058125158, 53.30355936481107, 70.19781958672309, 92.82784015901628, 44.43357029268819, 75.48306434385239, 97.97512731244488, 37.231059228220296, 1.0443208847315082, 0.5252913517817375, 0.23428047376294292, 0.341968625904091, 0.27065475741701744, 0.27381054936878146, 0.2997926664688895, 0.15570919389926619, 0.12362762264186337, 0.21631928190829294, 0.15472290166203054, 0.16359415385992299], [0.009741138332643577, 0.0673004181214398, 0.06096533830127409, 0.03630284595513537, 0.08251155351078318, 0.028672317200670802, 0.04314575396898774, 0.035734883689832304, 0.03140907054917226, 0.01817638786780017, 0.03666498337782199, 0.06944034684209094, 0.05001332618356232, 0.08364805260733252, 43.6093508812689, 76.75214721310523, 64.81742205158358, 53.65075580535397, 34.95864583599952, 57.43343860872331, 65.53948333186489, 99.73579299065375, 92.28382310559674, 13.126342200463819, 0.07875144076082977, 0.09450976211096972, 0.07975660174364045, 0.13256157147547892, 0.20725246278509019, 0.07427712722170739, 0.11369463386795214, 0.12457086839863371, 0.08215419647674407, 0.7343608525491531, 2.0678571299199136, 1.5479552986160403, 0.7591202013915586, 0.2954221961479033, 39.612294858501805, 107.07843072952764, 96.82126798937398, 98.17752161333638, 93.66417577189785, 85.93329398862778, 77.64150542597618, 87.02129671650549, 91.13181514124717, 97.22291869501915, 95.97055296744071, 94.3101038471345, 86.97202390240085, 76.75636768341064, 69.77235224939162, 66.39704288974886, 67.65579423596783, 71.75253729666434, 78.4540871650942, 84.3521551932058, 83.79520216295796, 86.84497833251955, 82.7696200340025, 86.5032849773284, 77.6196970478181, 84.83947046341436, 84.96032653316375, 80.51089963605328, 78.37094860692179, 74.0453274019303, 70.1287623374693, 70.588879892903, 69.44224557568951, 70.0968970021894, 69.37280393415882, 74.15285525783416, 72.69971909061556, 63.59033207739554, 60.85482405078027, 72.38909090718916, 75.31730498037031, 77.47886826915126, 76.44282910131639, 77.70727572902557, 78.37971118188675, 78.57816742312524, 81.58673517165646, 80.69216020645635, 74.7158016697053, 74.43279481703236, 80.50354126961001, 74.97066943876206, 78.64087827744024, 71.93118556853264, 67.73609299813548, 76.52498706694573, 73.68777198176231, 75.69028316005584, 72.5513985849196, 75.2237956754623, 60.978155136108406, 59.54257157541091, 61.131515887475786, 56.09460815306633, 55.87238627095377, 61.95331519649875, 72.40813009200558, 65.92941791780534, 60.5839490890503, 62.856440928674516, 59.43273736584572, 67.19573159371653, 71.96322348810011, 69.0112869201168, 69.00248512145012, 67.94799512432468, 67.74940552250033, 68.18908752933626, 64.93654835608699, 66.87061417487361, 64.25941782612955, 62.616152609548266, 61.626781802023615, 63.052622195213075, 65.57205077140563, 68.99009043170561, 73.30988299462103, 79.48619611801641, 75.40331471350886, 77.69581456338206, 71.61556813024706, 66.5216330559023, 66.19394256222633, 66.50158189958142, 72.03396735652801, 75.7839415150304, 74.36524375792473, 65.4006039711737, 38.435477902812345, 1.6157434159709563, 0.278989794033189, 0.33509914613058495, 0.4009229834041288, 0.08014469422520169, 0.24598346272062874, 0.0756758735364964, 0.22215046739626318, 0.2064622124476779, 0.8460081777264996, 0.3976876408823075, 0.2655861971359099, 0.07768252594096046, 0.015192605637674852, 8.391006877345424, 58.47416893128426, 77.28810771819084, 82.8173395895189, 23.789347679384296, 52.0699857127282, 65.77084041410878, 51.57384118726177, 49.00275891826999, 42.83876988195604, 64.60577487945557, 68.89653405835553, 38.80643213948896, 0.2837741356943884, 0.10097945890118999, 0.11391404144946607, 0.09295795908978871, 0.05861690343027154, 0.11118886751994012, 0.08619868106419042, 0.039983251087007024, 0.051854710440121354, 0.04390556380272873, 0.0605743385160402, 0.003436688144105457, 0.05572150859441008, 0.04040745312287923, 0.055474054533988244, 0.10975041486803563, 0.03889725250642627, 0.07901429318852964, 0.0352725955928045, 0.055714134998138876, 0.012274431177384913, 0.029314291220338597, 0.0367971220534415, 0.04613445448358694, 0.037102431073905005, 0.16288029781031996, 51.810999454990515, 85.75412796389672, 75.00199348695817, 66.66701178396902, 46.09937737064977, 37.8401013343565, 52.67387382445797, 113.43789500574913, 102.89132410480131, 19.003236293792725, 0.07935789894432792, 0.14148127107370284, 0.22442852176966208, 0.1019348165080432, 0.11024562942404902, 0.24537551066567823, 0.21745044137201003, 0.15559415813655625, 0.08543384952410575, 1.1509323769038724, 3.820914145438902, 1.9111742535906455, 1.6904632194388298, 0.15469827959614416, 46.790989291283395, 112.94106406550254, 102.57275704414614, 103.7778974348499, 99.05904293060304, 89.2270572723881, 82.14198589324951, 91.61158377124418, 96.82752024742865, 101.81598278783984, 98.62464043401904, 97.75191307067873, 91.08164802674325, 81.42937752508348, 72.71860922536543, 70.54147412700038, 70.87425585716002, 74.98289938895934, 81.34183806757774, 87.91947241752379, 88.24564887631325, 88.91843734248992, 87.28888080966088, 85.9438451643913, 82.99537597164031, 89.26292342524376, 87.93357726066344, 84.60471660860124, 82.94370266699022, 81.01307284447455, 75.80585971955331, 76.21033453172254, 74.23194592998874, 75.52767738219231, 74.54561002792852, 77.6291342704527, 74.52647670622795, 69.15090760877057, 69.72267935352941, 77.40288411417316, 80.27917385101318, 78.99236186858147, 79.98061087823685, 79.20020041927215, 77.59617067152455, 80.36559151064965, 85.39768649685769, 83.63766408735707, 78.19777596381404, 76.34514639454504, 81.48374157567179, 77.6616350297005, 81.76859978706607, 74.59319622285905, 67.89310547613329, 75.82878205084032, 78.28757470653903, 75.40810000511908, 75.63789598403439, 75.28245079901912, 65.85431237374583, 64.74569366824242, 66.95576098657423, 64.21209835237073, 59.480613816169004, 67.01285500680247, 73.4676093439902, 70.10899359180083, 66.87550929284865, 65.77660237589191, 63.42865982363301, 71.76162150598341, 74.03433692070746, 71.65873773636358, 74.3655026343561, 72.09729010058989, 69.30127559169647, 71.17048894205402, 70.56376887905982, 68.70405550925963, 66.62574844975626, 68.13637087422033, 68.32107528563469, 69.33496090673631, 70.95609218843522, 73.5905207357099, 77.62915780467372, 82.01111209008002, 79.17267322540283, 82.14049539258404, 77.18718513365715, 70.02965188795521, 68.50898819585001, 70.30788129375827, 75.74472565804759, 80.6972671324207, 84.85981971986833, 79.34371209913685, 46.393390394026234, 2.171168683036681, 0.13290660215481637, 0.7515990565861426, 0.15318213030695915, 0.11377558637891086, 0.19306232341595236, 0.3580076571914458, 0.11712579612409878, 0.328174170947844, 1.0490616819550915, 0.4095713499813311, 0.4572092098814826, 0.24139599033421089, 0.04717230826856629, 9.567187428474426, 68.2583801208004, 84.70783572043143, 94.14838452492991, 32.831444471113144, 57.24161509544619, 44.10187113669611, 45.40599646106843, 63.98094131100563, 42.68256541221373, 72.14317398686563, 76.45366268773233, 45.80561537896433, 0.307872258727589, 0.09586070453928364, 0.12140939973535077, 0.024512649378589085, 0.09256957549481623, 0.0859976749146177, 0.0857691279041671, 0.0839791864517235, 0.020297327184028203, 0.03885749254315611, 0.03279235529442949, 0.0868544523273745, 0.11167832875564215, 0.11460509106156327, 0.17154403211128327, 0.17416169326151573, 0.13025169380970542, 0.15781757511919545, 0.09864223955739891, 0.20258813645810853, 0.10578821578453626, 0.20555596107677107, 0.2516829576944151, 0.13516463098987458, 0.1185901195652062, 0.15627878027096873, 64.1069592199018, 95.70616952834591, 83.31641412550404, 70.14000385038315, 50.63477477719707, 74.23961024130546, 92.03930254905455, 118.59738073041363, 116.30198617135326, 22.888628321309245, 0.15243038354862123, 0.33480506029821216, 0.2280438439019265, 1.3511833476443447, 0.8216228636522448, 0.49423724232662114, 0.2654486690317431, 0.28877672048345693, 0.3180801658140075, 4.061482178588068, 7.7978783172945825, 2.862730348302472, 4.853004957399061, 0.4651264527872686, 50.81922815692041, 117.89734748102005, 108.42600807066887, 109.07521524736958, 102.95503124114006, 93.06330788520076, 84.35817210905014, 96.72403243280228, 101.62749721157937, 105.61707327442785, 103.66250130438037, 102.80095269603115, 95.41283115263909, 84.35665807416363, 77.17826566388531, 72.86431743252662, 75.98806950353807, 78.3045821036062, 85.13014947214435, 93.25180915094192, 94.19819862611833, 94.05892310603973, 93.18229690674814, 91.19209412605532, 87.97396982869795, 93.01958914726012, 90.77385179458126, 89.49922269390476, 86.47511451475083, 85.32550704094672, 79.0930648003855, 78.85132128192534, 77.90937192978399, 79.90061021620228, 78.18842503332323, 84.79064479950937, 84.15388722573557, 76.98123716538953, 76.34913936738046, 80.30534390480288, 83.63385154354958, 83.87703064949282, 83.50289929297664, 82.50547193711805, 79.21517602859005, 80.7011345894106, 88.86665421147501, 84.56136657345681, 80.54918196893509, 79.35035659420875, 87.80026374324676, 80.0681895594443, 86.1944846184023, 77.71111965179443, 70.26210723384735, 79.86404588145595, 80.07595585238549, 79.19258317639752, 77.97965295853155, 81.9876955401513, 67.30614631406723, 69.82584553380167, 70.13626190923875, 68.12410954506167, 65.30664751606604, 68.6730452506773, 78.13253910310807, 76.06875265798261, 71.39626056917253, 71.65509777684366, 65.58129579790177, 75.06066429999568, 79.43325981017082, 77.24496949103572, 77.90381785361998, 77.98454807650658, 74.20234772466844, 74.2986576018795, 72.34781972823605, 72.05775260925293, 70.23654906980454, 70.14120409565588, 69.16022716029998, 72.33786475273871, 75.08262957296064, 78.13430416968562, 81.94690289035921, 85.4681008861911, 81.73812297082718, 86.00331614094397, 82.63679289048719, 73.80584316868936, 72.0230317884876, 73.36285068142799, 77.32791977543985, 83.62865048070108, 89.13667801887759, 92.87072735448038, 56.403016274975194, 2.226010037045325, 0.9681226541438411, 1.9124124968244185, 0.5360551935530479, 0.41962337349691703, 0.35375136461469436, 1.2380043369147087, 1.0369577378995958, 0.719430411775266, 3.1166020804835908, 1.263597434566867, 0.9535215086033269, 0.3233629549222608, 0.31214690677100615, 16.10460767822881, 80.07992529099988, 93.77395506828063, 99.4209208027009, 46.18070379380257, 82.261979041561, 95.61947730279739, 64.67090975853705, 59.506124911769746, 61.24937918878371, 81.49064494717507, 90.29056872090986, 52.92594886595204, 0.4050574986444366, 0.27350371583334865, 0.414968439407887, 0.1554787852951596, 0.1332505603110598, 0.18250615275915594, 0.3015618086341889, 0.14836944339256133, 0.12641509484139182, 0.08920220538012444, 0.1643230405546004, 0.2649974738878589], [0.017950022292713967, 0.04424971348095325, 0.04706560371203288, 0.0650638320873822, 0.05438096197922865, 0.03728496684362331, 0.022098985951273672, 0.039177158051320625, 0.0671128721366967, 0.012404875841081865, 0.03503189842787481, 0.11005673512455919, 0.04573373304259393, 0.06337181199342012, 34.709198782520915, 76.02434358289166, 62.80399883947065, 58.362754006539625, 56.87719944984683, 55.7119103400938, 62.567040612620694, 100.13222694396974, 53.890102755638864, 1.4937248537617347, 0.0822475366294384, 0.2088281217842333, 0.1247453296016301, 0.2372097335154972, 0.1010310396011318, 0.2337431396928526, 0.11099130110514742, 0.22130789325362255, 0.031692898464238936, 0.033471905926783244, 0.562867658032525, 0.6541979637357497, 0.5255163364833402, 22.31164570777647, 111.30890307887908, 96.02600743693691, 94.3863311890633, 97.15471652246292, 93.40101611229682, 86.12833776781636, 77.4012916318832, 81.83640187786472, 94.66823193334764, 95.95850344627135, 93.54885808883175, 91.9050790417579, 91.24925090420632, 81.79721739984329, 70.31608689215876, 63.62613939469861, 65.55552974823983, 72.26806225315218, 81.95984671192785, 85.37996522841915, 86.85143455382317, 84.64264592816754, 87.37912670258554, 80.00460793895107, 80.28759125740298, 85.46038166169198, 81.85767681367936, 81.16414685403147, 77.12848294165828, 77.86759868744882, 78.32089916352304, 75.89608207825692, 74.229584663145, 68.26693873251638, 70.81898966143208, 74.563307762146, 66.05117613269438, 56.07052480020831, 73.5631347471668, 78.50708623086253, 76.3921206997287, 76.15028304438438, 77.30874723003757, 77.7833147971861, 78.82741835809524, 79.1638243582941, 78.08489799499512, 76.52295527919647, 71.63442688603556, 66.59135710808539, 70.78976800364833, 71.42366224719633, 69.88451634683918, 69.54023422733431, 66.85112783985754, 66.96879894502702, 76.73426120511948, 74.80234484518729, 74.91325378417969, 72.7236847723684, 72.82481132015106, 61.93746097626225, 61.94233256001627, 67.66111296992149, 58.79574837223176, 53.57732511335804, 58.37305022824196, 56.769502932025546, 61.6800711231847, 55.901270604902706, 61.20262845869988, 70.92568597485943, 72.04661307796356, 68.89317650948801, 65.68503464421919, 65.75002831797447, 62.54058422580842, 62.179737937065866, 63.25373780342841, 60.7070016860962, 66.93015575408936, 69.25590161354312, 68.51452658253332, 69.06883593528502, 72.1478965205531, 70.47309152541622, 74.71131447822818, 75.94078925348099, 80.98886397577103, 76.59353440807712, 75.71190326444565, 72.75792706397273, 65.38218452084449, 66.70510584308256, 67.64862414329284, 72.06702509234029, 76.56654850129159, 69.44470882415771, 64.0902263887467, 23.77536442971999, 0.1364750397061148, 0.27165802616265516, 0.14978474486739407, 0.2904310720341821, 0.0844859995789105, 0.15227011795486176, 0.06191981490701438, 0.07418446888726565, 0.5579782397516313, 0.05903507635417966, 0.7874864760425784, 0.14299605672638263, 0.184408716797348, 0.8536726729043069, 21.80826048697195, 80.09530882681571, 69.22205940369638, 80.84674865968766, 88.25652953117125, 54.18935606556555, 31.479354443088656, 22.955024242401127, 49.881801297587735, 54.75431073096491, 72.67572987464168, 42.00180276747673, 0.05567547820147969, 0.01403222183486627, 0.05691441474482418, 0.04668030362095564, 0.0625922026172761, 0.05303833160489317, 0.040823676353020054, 0.07178809989484088, 0.03751765455930464, 0.010882793200923311, 0.05879575431707406, 0.019624793917060863, 0.05580866641755547, 0.05562862043359107, 0.0546955521548948, 0.07406936417664252, 0.03896279132834846, 0.028966336000350215, 0.02971382139460935, 0.09036075248713456, 0.054454138697755915, 0.02242682178715064, 0.050806250167830344, 0.11520502217594655, 0.014563286432906266, 0.01876068695808851, 43.37857430981052, 83.91365774216192, 70.54363927533551, 52.59127263099917, 39.26634180930353, 41.958778289056596, 68.06036318502119, 113.13730808996387, 63.75101589387464, 1.797086601295779, 0.04987335042847742, 0.18330585662155383, 0.8809290393706292, 0.16508820917337172, 0.4180555285946016, 0.25072540907609847, 0.044205265059586496, 0.21377706509684363, 0.03814842454307983, 0.1980145762283956, 0.7421485346651847, 1.17068114299928, 0.12479241336545638, 29.85659145539807, 116.11220621293592, 100.68853670550932, 100.12830457379742, 103.97790693467664, 94.87396809362596, 91.27891971218972, 81.71171757482713, 84.69312683228524, 98.2968322692379, 101.47548183318108, 96.71181032734533, 96.28482111038701, 93.71832801449685, 85.17490371581047, 74.710035785552, 65.9401495225968, 69.40957223215412, 76.08179846117574, 84.16784301880868, 89.11070408359652, 89.53995258577409, 89.17001816534227, 90.10606042800411, 85.22785571313675, 85.64173636897918, 84.82214143199306, 85.65890066085323, 85.76693058013917, 82.44331021462718, 81.05266524899392, 82.38836565325337, 79.92261471286898, 78.06466640964632, 73.06752758641397, 75.26087776307138, 79.94505067025462, 70.2965142649989, 66.03496889914236, 79.10249417827976, 81.9838986858245, 81.89613173084875, 78.41834652808406, 80.44953807707756, 80.23550218151462, 80.8985004117412, 83.0885793316749, 79.94659608410251, 78.15864639897501, 72.53467359850484, 67.15003598120906, 72.31412656845586, 71.44379185092065, 70.03019317503899, 71.92709061407274, 71.89592346068352, 70.2137993228051, 77.47394177221483, 77.25621884868991, 75.91918483857187, 74.03485467357021, 76.36780200466033, 68.1239918739565, 65.41631306371382, 71.96504346786007, 65.94305207652431, 60.7366273480077, 62.86389735437209, 61.27718094856509, 64.54140094018751, 58.422193604130904, 64.16263726449782, 72.99541873316612, 75.59191011613416, 73.7997870291433, 68.89171738778391, 67.92857939197172, 66.26838914809689, 65.03428597604075, 66.65540156825897, 64.27534264902916, 69.92930196946668, 72.63019115694108, 71.68022448016752, 73.74167319267028, 74.75602949819258, 76.01427878102949, 75.60424989269626, 79.45402483786307, 83.88176102792063, 81.74891733354139, 76.62463880354359, 75.75570044978973, 69.9062619670745, 70.99155041479295, 70.87295363026281, 77.25050003297868, 80.75968773134294, 77.76276157748315, 77.69747764833512, 30.332067051241477, 0.5024835046741271, 0.11037359675092083, 0.28639112268724753, 0.1919592334137809, 0.2057977231039155, 0.20863462329631854, 0.050122597134642066, 0.041332803065738374, 0.6192539968798237, 0.10998031019323296, 0.9761874762273605, 1.0486780251226118, 0.2572311503031562, 0.6718054221522424, 27.959376304380356, 88.25928303503221, 83.92025516879174, 87.93607188809304, 96.55284450900172, 57.189412270822835, 35.45447264948199, 23.281694919832294, 45.98447153645177, 63.75276527097149, 80.01491592776391, 50.10535286318872, 0.0799688004377869, 0.08781958521614153, 0.1019883277495542, 0.010903337763832703, 0.09082822699940975, 0.01225672688545479, 0.059478714040690855, 0.011650739846030071, 0.03785045081449132, 0.05603082425471756, 0.06220063975741787, 0.047017964534461505, 0.11458660535995038, 0.11583610242533109, 0.15305750312343722, 0.16622326036374416, 0.15648475067029077, 0.12548707891255617, 0.07811692077666521, 0.1595224731511647, 0.18767488669724236, 0.053572601323286374, 0.13035989606813078, 0.3715002122184923, 0.1292045588695234, 0.19959348344033767, 53.707594871521, 95.38942244745071, 80.81587960643154, 74.65599336931783, 70.46345033953267, 75.83982744524556, 84.83358690815588, 118.82486251092728, 75.62795669801774, 3.0485626862895105, 0.13152396666907495, 0.629598574051934, 1.2637544519478277, 1.2518048286437988, 1.0262488093106978, 1.0554039093755907, 0.23373210802674296, 0.6126699308233877, 0.1435275991717654, 0.553153295430445, 1.2356928351425356, 3.6069196799109062, 0.8289246621631807, 30.19626282876538, 118.38785556054886, 104.92177040346208, 106.96594499772596, 106.0597990405175, 100.1596050877725, 95.15460583471483, 87.20137273111652, 90.06202790044969, 102.61911945958292, 105.01043950357746, 99.3852036999118, 99.6522072822817, 97.16909593151462, 90.37099299892303, 77.4943930102933, 69.41866428621354, 72.98969991745489, 81.38482724466633, 90.00138021284535, 92.95308928335868, 89.38250864705732, 94.06796024691675, 89.0831062870641, 94.69172693067982, 88.35296492422782, 83.82240772247314, 88.99259367296773, 88.03409976343956, 85.85021034363778, 85.87345430927893, 87.44701508552798, 85.34574647103587, 83.05696502808603, 78.74295403880458, 80.54597347013413, 87.50642330415788, 82.44549889718333, 72.54644855376213, 83.27011446799003, 86.37139920265444, 84.72064618141421, 83.21825288957166, 83.2728365928896, 79.7620407227547, 82.19193335502379, 84.47835353112991, 83.42064719046317, 81.22865415388539, 74.19076104317942, 70.45630378107872, 74.73100477649321, 75.56167648684594, 74.23138110868393, 75.92886524815714, 70.91799028458135, 72.6165726877028, 81.19598865509033, 80.48949918439313, 77.56403861507293, 77.42484938713812, 80.07475560711276, 72.11115175677885, 70.60848389902424, 75.54747750682216, 69.41128238554924, 65.8411253652265, 66.94528825821416, 67.91753399756648, 69.25812951980099, 64.77620186344271, 67.07062367470034, 76.50351601262247, 81.25901329901912, 77.9677838663901, 72.57942784217097, 73.37373918102634, 69.62089384755781, 70.2395143816548, 71.77712271290441, 66.75631630805232, 73.0123947512719, 76.38571154686713, 74.79682214798467, 76.69929719740345, 79.9171704630698, 78.86778739190872, 77.00282589081796, 84.86980607432704, 87.84386481008222, 85.03039575392201, 80.2902663138605, 80.05344929233675, 72.83667256755214, 73.67030958975516, 73.57028130562075, 80.46975397294568, 84.53246655002718, 83.49347775982272, 94.10617197713545, 34.619988395321755, 0.5987619416367623, 0.8188162239328508, 0.4967107870165379, 0.8017531782388688, 0.5911848417693569, 0.49557857035148534, 0.2855160051295834, 0.7171971735454375, 1.5532569947742647, 0.9668684149942092, 1.1153385836270548, 0.7539161967654383, 0.2546842603553688, 1.8266553888397834, 38.154396933894006, 95.73734452647548, 96.95806457150368, 104.28438525046073, 104.28386749759798, 89.19274437812068, 44.864372053454005, 31.779839377249445, 68.67743046052995, 72.21232537300357, 93.327769771699, 55.95576801607686, 0.21290764723333622, 0.14031819638706025, 0.1650581019179475, 0.15033974492501828, 0.17031516579370345, 0.16970054877381172, 0.11445228716418629, 0.14120454479369426, 0.13495711309294547, 0.13294354291452518, 0.24440268625415143, 0.12278938455687416], [0.06982057160066982, 0.06397230235198814, 0.017498932485919327, 0.04779109663720574, 0.10083538074527057, 0.03414478776375613, 0.038752687884674925, 0.029028992416457306, 0.11376056339471571, 0.009458922075047609, 0.020180636671401804, 0.03700254853033731, 0.011713768772390342, 0.04571008773881101, 30.25098773740953, 77.09452306070636, 71.80347319572203, 78.02310497530046, 66.91920449656826, 54.90261946955035, 74.86689921348326, 99.04280431808965, 21.84168496439534, 0.01644305839774109, 0.04146761538821363, 0.2444383859514229, 0.48150519810376635, 0.14971339143812656, 0.10580047319132475, 0.4015047812173444, 0.6427066448715426, 0.15293310576629254, 0.4370584927739636, 0.17258396582497706, 0.3755632667772232, 0.5727448602837901, 8.10869526478552, 103.5692822548651, 90.77677788272982, 77.7227298675045, 88.6886021398729, 100.52805685227918, 92.78372918405842, 91.9835578241656, 74.98415454741448, 78.59827349262854, 89.25401964495259, 92.14785022120323, 93.29759890033354, 93.20391701113795, 89.20280917998284, 87.94725848782448, 74.99811818522792, 67.97465155201574, 63.25398491274927, 68.95347118377686, 78.42718755045246, 88.1027961546375, 84.63114553882231, 86.15370765809091, 80.69132081923946, 99.1174077987671, 101.95438754174018, 78.22753890868157, 85.13334228146462, 81.6385575263731, 83.49966725995465, 79.11425344405636, 78.12352549645209, 73.94354974069904, 72.04358500819053, 66.42261674327236, 71.40539184693368, 67.99757388330275, 55.50127906184043, 64.97769794156476, 79.52585128045853, 74.7129540289602, 77.07797065857919, 77.02200628096058, 79.38721902908819, 80.11639548886208, 76.92098171480241, 79.11547722355013, 78.50564279863912, 77.74249861317297, 65.67545229388823, 65.20342642261137, 74.15717770976406, 70.76313511017831, 70.86370468139648, 68.86223685356879, 77.8802679431054, 71.91897130781605, 70.06654570179602, 67.51726396622198, 72.34756085180467, 69.14681265431066, 72.65282323283535, 67.51949187247985, 62.041246891021736, 66.73218588675222, 66.89275203212615, 61.76165642276887, 63.29106700035834, 58.54377138999201, 59.80964183807374, 50.08811404628139, 63.94123908012145, 73.00632292224516, 68.42415517376315, 67.72432588761853, 64.37196239348381, 64.89765805582847, 65.7032383641889, 63.009546725980705, 59.83516470078499, 61.41134169793899, 68.74865285811886, 69.79038730744394, 71.70302129560902, 71.97067599142753, 72.37141670719271, 74.28318777391988, 76.49791486801641, 77.99217316412157, 70.75303108461442, 73.64557512344854, 74.4027808404738, 72.9664324175927, 73.29923768197337, 67.7131235984064, 65.56122110735986, 72.84323077048026, 72.83360527407739, 77.2342457309846, 68.84443713772681, 59.46182566304361, 8.594296459228762, 0.10691009792349032, 0.3590136838536109, 0.2818296513249797, 0.12229139676257489, 0.2489220993893762, 0.7022564978368822, 0.24738437706424346, 1.040859760776643, 0.14236902908211754, 0.9344262461508475, 0.22218461959592758, 0.047426569020195354, 0.09748706323725563, 3.8459327384348843, 62.61136731793804, 72.94724418270972, 85.63797089361375, 90.97107641158566, 77.638610716789, 36.50425580240066, 30.856293785956602, 60.379366105602635, 58.71984658702728, 68.95986464715773, 33.56001100232525, 0.12333920586013025, 0.08303618584308894, 0.09902212723729112, 0.009823807838162588, 0.0240139089029042, 0.09362803321451911, 0.09214155451064149, 0.05857145909460322, 0.014399050588479206, 0.031970756639155655, 0.027027848184168823, 0.013256904466318028, 0.056892784252282114, 0.01278097713140831, 0.031164429946652347, 0.03269905727657099, 0.027743648181879715, 0.0805719950867276, 0.05219033739018825, 0.06509392402104794, 0.07645704573200596, 0.04222028528250033, 0.019856589140310403, 0.07958523553585814, 0.06527382444830672, 0.05206336214717838, 37.4030904616079, 87.15330016228461, 80.04396500126009, 88.28116986059374, 55.731835980569166, 47.302976269875806, 84.072474510439, 111.38496568126064, 27.314589638863843, 0.033639698334398775, 0.060670340824271404, 0.7875105618469177, 1.6193405971411736, 0.07518707113640924, 0.036582874074097604, 0.573283757173246, 0.3767578736428292, 0.06261793551065269, 0.7082120040732046, 0.34751908613308785, 0.7644312131789424, 0.2728603858380549, 10.93370589517778, 109.97947062215498, 94.01459247835221, 88.74401738566738, 93.7264394760132, 103.66569411370062, 98.3740637379308, 97.83507516307216, 80.15778433892035, 81.94432197078582, 93.23548424628474, 98.1869274570096, 96.01562100072061, 96.59298604534519, 91.88983671126827, 90.42618859198787, 77.11153045777353, 70.78283325318368, 66.23265635582709, 70.01378197823801, 79.27653758756577, 93.11069011688234, 86.34344839280652, 89.80510480942266, 84.0270063954015, 100.42210578918458, 102.41723506681382, 82.35953623248686, 87.49052986021965, 83.46803726688509, 86.63786149794056, 83.09637700357746, 84.99322737416914, 78.8418605250697, 75.42885718807098, 72.25813865661621, 77.26293394642492, 70.90176736154865, 64.32696104049683, 74.45823530997001, 82.69663256983604, 76.44351159372638, 79.68661354434106, 81.5263306710028, 82.12198965011105, 81.17386648731848, 79.51779473212459, 83.49335224397721, 81.61678837191674, 77.04754091078236, 66.66113607345089, 70.32256664768343, 79.63313594941171, 74.80480024891516, 73.87112709783739, 72.70553204321092, 80.14188305024179, 74.59812271979548, 72.50223559717979, 68.58927126853698, 73.99981221845074, 71.12587590371409, 74.5669634111466, 70.67350110700055, 67.96377089715773, 70.14864090950259, 70.79471019006544, 67.54421064930578, 65.84661668346774, 61.18757440197853, 60.67104531872658, 53.99707755734844, 66.66216373443604, 74.74325041617118, 70.99052275380781, 71.71319592383601, 68.65393546319777, 69.267849153088, 68.2834440662015, 68.57661770236108, 62.76241387090376, 64.3503854351659, 71.61597605674498, 72.4281890930668, 73.61258014555901, 77.93102341313516, 76.0343691610521, 77.77714098653486, 80.80750142374347, 81.00179210785898, 72.07324597143358, 76.96204893050655, 79.26608054868638, 78.64072922737368, 76.47563580543765, 73.54579002626481, 68.55053394071518, 76.05827208488219, 78.7308103807511, 83.76527447854319, 77.90944253244709, 72.59698437106225, 10.835821186342548, 0.2103098890473766, 0.32708108605396363, 0.6853417054780069, 0.9523786892814021, 1.317155928381028, 0.9237588701709625, 0.306619122744568, 1.2191399427190905, 0.15884414825948978, 1.063033287082949, 1.2256744888521012, 0.2905740546843698, 0.12877392552552686, 5.132955793411502, 68.82353874944872, 84.99630251238423, 95.04248880570935, 104.20104272903936, 92.10260175889539, 52.57574396748697, 28.18246306911592, 58.66509422179192, 64.91164522786295, 77.86858712473224, 39.64330511708414, 0.09343605924157367, 0.09326852347341277, 0.08493992965668441, 0.05436793082363663, 0.07387791114348559, 0.08059791950208527, 0.03644809239513932, 0.008911054295998429, 0.06110335287127284, 0.032251654267911954, 0.08174153555545115, 0.07403633812622679, 0.20963593085687007, 0.14178332422048817, 0.13812611240052408, 0.08822427116214268, 0.2084186324669469, 0.13016691852000453, 0.12374985197018232, 0.16377657471645266, 0.21562702953815463, 0.07870516138932399, 0.23690262418841165, 0.18940619944084078, 0.192874800413847, 0.0988327349806505, 45.13394086591659, 100.91482608549057, 88.47717069810437, 99.60664503036007, 78.9893259540681, 79.31187029807799, 96.75394442773636, 125.28799503080307, 34.02314486042146, 0.20158947956177498, 0.23555054028909053, 0.6407482177019119, 4.080584121327247, 0.49822105275046447, 0.4975850465557268, 1.9910940167403992, 1.6545643393070468, 0.7849225942646304, 1.2799048111323388, 1.1545072495937347, 2.658251552812515, 0.6441277073275659, 11.265431527168522, 113.76882537718743, 98.68866920471193, 94.17722179043679, 96.99015740425357, 111.12067637904998, 103.52380629508727, 99.51756800374677, 82.15853829537669, 85.99402796837592, 96.71575623173868, 102.08455531827866, 101.11788718931138, 101.00353440930768, 94.91121492078229, 95.5956449816304, 81.7814886954523, 73.99779612018217, 70.12239240830945, 76.00098194614534, 86.78919438392886, 98.72269968832694, 92.96870031664449, 93.86388717159149, 85.42431939032771, 104.10601938924482, 100.42755788372409, 86.60404282231485, 89.42511343186902, 88.19776458124961, 91.56965363410212, 89.42074391149706, 88.012416901127, 80.85785681201567, 79.87271431953677, 77.19721855655794, 83.98176577783401, 82.2871292791059, 73.34063437677199, 76.95331773450299, 85.60528186059769, 82.71542072296143, 83.8874484646705, 84.4855236238049, 84.23167567099296, 84.23306419003396, 80.8324633875201, 87.21488921873032, 83.80692220503285, 81.9393954738494, 66.16618002614668, 71.29110966959308, 79.8528749712052, 77.10931824099633, 76.9419663952243, 76.29508910640594, 85.5206528017598, 77.29974146812194, 74.62618335600823, 71.83138478186824, 76.9701603920229, 75.13463235670521, 76.53788382007231, 74.97065374928137, 72.83054582534298, 75.48766136169434, 74.31488836965254, 72.48607543206984, 67.27518312392696, 62.8513849935224, 63.50223564332532, 57.151741827687914, 69.70607988296017, 81.07663093074676, 74.04828486904022, 76.3789572254304, 70.28354690920922, 71.67091277337843, 71.12802536256852, 70.90299898578276, 65.69339713742657, 69.85968774364841, 76.14794531176167, 75.55426320722027, 75.8325553709461, 81.0555991818828, 80.04865615598618, 82.5707950899678, 83.3471498181743, 82.53898466787031, 72.12710795863983, 80.48060324884231, 78.09082077395531, 80.71502762456095, 77.2178816026257, 76.36687632529967, 71.4318992245582, 77.4397857727543, 85.02183714220601, 87.17599499610164, 84.63289491591915, 83.30936954867455, 12.440322599103375, 0.3587381986360396, 0.6981922481809893, 1.5337275136863033, 1.300242668198001, 3.4843169296941454, 1.516730780563047, 0.5563565848335144, 2.75721981640785, 0.5807659847121085, 3.086303241791264, 1.7124712707534915, 0.23667857411407658, 0.37406810829716347, 10.096537759227138, 77.38830858661284, 98.24394302983438, 96.68371046743086, 105.36313118473177, 97.27740041671261, 53.92116792740361, 44.22677509246334, 80.35250648375481, 74.49672160610076, 89.23490201273273, 47.92804518053609, 0.3908689987034567, 0.23590165370654678, 0.1773098856210709, 0.11017030765933376, 0.21246855627865563, 0.23995364595565105, 0.17894925249199714, 0.16580022661195648, 0.10767229412111545, 0.14696393252140091, 0.18372562683878407, 0.16140769295875104], [0.004359447273365673, 0.011002583496813333, 0.04620560872999411, 0.047038399929841684, 0.0351120580378319, 0.0062686609547405, 0.045905551242251555, 0.02751854090620914, 0.08150713563325905, 0.06884682788363389, 0.03213229393886943, 0.010469592187643774, 0.08118787615169441, 0.12701854229934756, 21.050433074274373, 76.58335193510979, 54.24486544824416, 53.3780804757149, 46.279978982863895, 51.9360093147524, 81.7078265836162, 65.00719024289039, 2.6283209266201144, 0.15000865704590274, 0.16417590570786308, 0.6012354863266791, 1.1157443037917538, 0.2632432551153245, 0.10620434708412617, 0.3355323228864901, 0.2755561879565639, 0.3439455311144552, 0.14109275724378326, 0.36242308155182873, 0.1074051516010396, 2.1865215753355334, 76.71707337902438, 89.38988270298128, 66.667921773849, 86.25494403223838, 90.62213451631608, 89.1842249901064, 93.50178964676397, 93.11784452007663, 80.32668159854028, 73.89105273831275, 84.31694015379875, 88.904144225582, 92.02919852349066, 91.71026276003931, 90.5624831107355, 84.04553567209553, 75.37546588528541, 66.68066947690903, 65.9068093761321, 63.86646693752658, 67.5906358226653, 77.0747386255572, 79.42241837901454, 83.40368686183807, 81.22850510381883, 89.10996667800411, 91.37532372628489, 80.6458919279037, 81.91838725920647, 78.17156668632262, 81.71766388800837, 78.7654370646323, 79.56297259176932, 76.58328917718704, 69.38644593761813, 67.97897400394564, 72.56823339769917, 58.82936308460852, 61.14582861623457, 72.04485585612636, 73.7840347905313, 75.08013494553106, 75.71232688042426, 76.59279700248473, 74.98482135034378, 75.02566891331827, 76.42283285817793, 77.72246314633277, 77.51329883452385, 63.350102593821866, 70.66568774561729, 75.90163615442093, 73.95846259209418, 73.33191102550876, 74.2240462764617, 73.83769281448858, 71.09747794366652, 72.04643264893564, 75.28816961473035, 72.27394580841064, 72.53855674497544, 71.76153521383964, 73.07072824047458, 68.1672320827361, 62.35107491093298, 69.52544689178467, 66.01594540380663, 67.77542652622347, 65.96486045468238, 64.18025655131187, 60.396836342350134, 58.04483805933307, 66.70620410673081, 68.39401568135908, 69.50300308965868, 65.0283710418209, 64.98951604289394, 68.1920842201479, 67.51530278113582, 67.95299222392421, 64.52703329824632, 59.88269206016295, 67.01006227923979, 69.9918794631958, 71.21330553485502, 72.95340230388027, 71.54448693798435, 76.44899506722727, 74.15555384851272, 74.88179637539771, 73.6507369625953, 73.87194295083323, 75.59096090255245, 77.04147692649596, 74.82317263080229, 73.06542519600161, 73.39628496477681, 72.26599124170119, 70.36287292357414, 74.10343339366298, 73.77213431942847, 74.47235584259033, 41.91726000078263, 1.4096568164325531, 0.16464790779977076, 0.33658845169890317, 0.9244334565535669, 0.9682383027768905, 0.19462632255688792, 1.514785530105714, 0.06870706280272815, 0.11095741703625649, 1.5819675186949393, 1.4787849134975866, 0.20322493938428743, 0.05409596578007745, 0.36398786210244705, 23.446911035045503, 72.68604570819487, 73.0606948175738, 110.36181542181201, 80.28180968376898, 30.085577464872795, 51.47118491511191, 61.9634388339135, 57.66087332079488, 69.65699534262382, 26.02475743139944, 0.15787516960934286, 0.1026623931923701, 0.05704586011087222, 0.08514486583730868, 0.022003604174261133, 0.023361215397955912, 0.05174289224669338, 0.0407321211851893, 0.06409293055654534, 0.009803959457654386, 0.021812139649785334, 0.013698760040795371, 0.04879683218595963, 0.009004311136630996, 0.06675696300883448, 0.07035634285139461, 0.056749874380447214, 0.04743421074724005, 0.03996381926680765, 0.03766857004994827, 0.05276944240434997, 0.01031916316283206, 0.027060447140566768, 0.07125237460939154, 0.042348340709483435, 0.1574887395385773, 28.155983148082612, 86.4905608084894, 63.07088867310555, 60.24410709258049, 50.237987810565585, 48.02525720288677, 92.04127157888105, 77.85445090263121, 3.20797614512905, 0.11009503185989396, 0.13066305238152706, 2.6073485036050124, 0.542923508872909, 0.17657661690346657, 0.1135166026952286, 0.4233262441571682, 0.4648507530650785, 0.5594633471581244, 1.7843879278629058, 0.7994853128348628, 0.059901203870052294, 2.9650907266524533, 84.51617302433138, 91.71100801037204, 81.73776995751166, 93.52328423530825, 97.64707596071305, 95.63782615046348, 99.14068314336963, 98.54653035440754, 86.13555492893343, 76.34282435140302, 87.48935314916795, 92.83355112998717, 97.45199295782275, 94.28679712357061, 93.17257727346113, 87.3696110325475, 78.74869638873686, 69.70354603182885, 69.1504212348692, 66.07529870925411, 70.42954537176317, 78.19380652519965, 80.72217418301491, 86.70258845052412, 84.67738243841356, 89.09492046602311, 91.8938845972861, 83.6960760239632, 82.75935126889138, 82.24793695634412, 82.85022474104359, 79.78624174671789, 79.07390794446393, 77.5692004542197, 74.25752762825259, 73.92500477452433, 75.56355137978831, 67.92003646973642, 68.73820366397982, 76.94300974569013, 75.62863919042772, 78.35987967829551, 79.31144668209937, 79.45196167115243, 76.64102646612352, 77.823283749242, 77.5818540203956, 79.00755713062902, 79.33283144427885, 63.489354579679436, 77.20407485961914, 77.83800832686886, 75.14411664778187, 74.2554723062823, 75.42105167142807, 75.89383063777801, 72.23311393491684, 74.300626631706, 75.65636250280565, 76.3905752858808, 75.39517187303113, 76.3602004512664, 76.09630338607296, 71.74532013554727, 66.676707883035, 72.05105320099862, 69.09226032995409, 67.9030212279289, 68.90841099523729, 68.43924060944589, 63.6316385576802, 58.82315397262574, 68.36939888615763, 71.82500700796805, 72.19151327686926, 68.69071160593342, 67.19224852900352, 72.59452896733438, 71.59820771986439, 71.1277037282144, 67.45506302002939, 64.01270466466104, 71.19683158013129, 73.94474214123142, 75.3618238818261, 76.58673301819833, 75.088897520496, 81.19368230142902, 80.16132231681578, 76.10823523613715, 78.19632468685028, 78.35677316111904, 78.9048381005564, 80.67335636385026, 78.07665317289292, 77.42732048034668, 76.22462764863046, 75.25490007092877, 76.7712099321427, 79.59371612917992, 82.13575716941588, 82.08892406955843, 51.88276706203338, 2.4164994541675817, 0.030473562280437162, 0.9437528456891737, 3.287507593631745, 1.3852534226832853, 1.167514809677678, 2.1283746438641704, 0.6014193474285064, 0.15274035804454358, 0.26153463389604326, 1.6822099397259376, 1.4621055246360841, 0.06545462119843691, 0.23833862535895842, 27.955763801451656, 83.88109422499134, 88.15337904037969, 113.07538955442368, 97.2143679280435, 39.8442599081224, 34.39310281507431, 68.71517935106831, 62.79401640738211, 79.59182554675688, 30.606491757977395, 0.2468991369730042, 0.16280589535111384, 0.08165987058272285, 0.028563119027943864, 0.07404468848460144, 0.06687327047749873, 0.14347294645924724, 0.04210859732401948, 0.04693738740658568, 0.030465577729046348, 0.022741714567546884, 0.016857293629718405, 0.10258222209109415, 0.09012932498608867, 0.11896514258677922, 0.17765600414526078, 0.11317931716480564, 0.3171062229141113, 0.07655544972587978, 0.08649474340340785, 0.2509152763072522, 0.29581081723013236, 0.096391067209263, 0.11438597459346057, 0.26172296895134833, 0.3161937815527762, 34.27394905397969, 101.15825622312485, 67.406433474633, 65.52918711016255, 54.27866843438918, 76.37394443635019, 101.54187971545805, 89.55106858284243, 4.589092693021221, 0.3775465764826344, 0.3290890637905367, 2.697824590629147, 2.9559788155940274, 0.829947665333748, 0.26552604391209544, 1.0623473625990654, 1.4202578798417123, 1.1553416112738273, 4.2876634482414495, 1.564022062286254, 0.33070986069017844, 3.5215769948497897, 88.99981867882514, 97.25028899408157, 87.13676344963812, 95.6556886242282, 100.20100962731146, 98.50911094296364, 102.33120179945423, 103.39368558699086, 90.62770428196077, 81.99545398835214, 94.027402939335, 95.968442732288, 101.37392382467948, 98.4350565941103, 97.78529244084513, 90.63845942097326, 82.07081840884301, 72.75991178327992, 73.06774723914363, 69.87619307733351, 74.30461175980108, 85.51356115648824, 85.46624952746977, 90.41833600690289, 92.21729970747425, 93.50217403904085, 99.02742078227382, 87.81101103751891, 86.65411579993464, 86.78080835650044, 89.44096765210553, 83.63312982743787, 88.26840646805303, 85.85283833165323, 79.96727481965097, 81.32013951578449, 86.69536344466671, 77.62012066379671, 75.40169085225752, 82.77682150563886, 79.22059674416819, 79.97878305373654, 83.21633877292757, 83.012736382023, 79.8923340151387, 80.22688865661621, 81.8360645540299, 82.03004929327196, 80.28596739615165, 64.97173201653266, 77.71685415698637, 82.04080443228446, 78.36783424500497, 77.93394950128372, 81.48805618286133, 80.77930742694487, 75.3067224256454, 78.41429864206623, 80.22630814583071, 77.46496738926058, 77.5903263399678, 78.23007275981288, 77.0317102247669, 74.01064580486667, 71.68008327484131, 77.48850945503482, 72.85889671694848, 73.52537801188808, 73.1149725760183, 73.01124157444124, 67.16321514498803, 60.453616572964584, 71.99450831259452, 77.33787475093719, 76.2668715753863, 71.93879496666693, 71.34111204454976, 75.30021913589971, 76.13238919165828, 74.16772104078724, 70.01233070127427, 65.55336852227488, 74.41656404925932, 74.79632792934295, 79.02901249547159, 82.0337284764936, 77.78728423580047, 84.38493051836568, 82.68186092376709, 79.7658375770815, 78.72881781670355, 79.84868587986116, 81.98013321045907, 82.5617265701294, 80.50857759291127, 80.3840737189016, 79.86216314377324, 78.33328600852721, 78.99555467790174, 84.20095566780337, 87.1813843327184, 87.94544635280486, 58.83879246250276, 2.4511749225278057, 0.34335423381097857, 1.7213629162119282, 7.323624539759852, 4.699248536940544, 3.961107990434093, 4.350844006384573, 1.3439229178813197, 0.4681168616779389, 3.8563015239854015, 5.880636034473296, 0.9772485999330398, 0.12162212703016498, 0.7175791143409668, 36.91510838847007, 94.10314390736242, 93.17173788624426, 118.37332710143059, 91.55472509322628, 43.424736684368504, 65.42688777369838, 82.092556184338, 72.44227040198543, 90.6676967682377, 37.171141101467995, 0.4210541805913372, 0.41213939927758714, 0.1585263137014643, 0.16869493579912573, 0.15053561828549833, 0.2245647781678746, 0.30391722256618164, 0.1894877111959842, 0.15092480627279128, 0.06893595455274468, 0.10667564437514353, 0.15126075114934676], [0.1177113477681433, 0.06584369427254123, 0.027700262707507903, 0.04948998087896936, 0.0824402000815157, 0.04984747580883484, 0.00854644432453619, 0.05670207815485136, 0.0943364423789805, 0.11409655423654665, 0.029628921615620776, 0.02898907157472305, 0.021173973087101214, 0.33668565293473585, 13.254254614153217, 70.32177432890862, 51.02437988404305, 80.8193705158849, 54.76912944547592, 65.05481958389282, 95.69325708573865, 34.34821128845215, 0.06379128726679953, 0.2056246025547866, 0.13042689811798835, 1.0341027427104212, 0.4179866113249333, 0.012059805899738305, 0.11286086973644073, 0.09495569423081414, 1.2159672355459583, 0.15591657390036892, 0.15150185434087632, 0.5551987501882738, 0.3844354229588663, 46.403565022253225, 83.09215653327205, 65.27588436680456, 94.72084660683909, 93.99501200645201, 98.03594758433681, 91.57124611639208, 94.82828032585883, 92.51578423284715, 84.01554522975799, 75.43824734226351, 80.11144545770462, 88.43121620916551, 90.09089654491794, 93.41757635916434, 89.93626102324455, 80.30135877670781, 76.03432993735038, 67.90779083005845, 64.5245151365957, 63.99563058730095, 62.46201522888676, 65.99521959981611, 67.3354777982158, 73.8156569388605, 75.85523451528242, 76.76042341416883, 74.21812349750151, 76.16772974691084, 71.06815430425829, 77.38815953654628, 73.85800284724083, 75.0860498797509, 66.03252918489518, 54.79402080658944, 60.99535080694384, 68.38606895938997, 64.66263355747347, 50.30036134104575, 70.13049602508545, 71.83019238133585, 75.10020179133262, 77.42322552588679, 77.9108859646705, 77.51529139857139, 76.02308057969617, 76.93808324875371, 72.02873491471814, 81.65206616924655, 67.72235685779204, 69.71883543076055, 77.25847813390916, 66.02241731459095, 69.71755673808437, 66.52267640636813, 67.38782575053554, 65.7824820087802, 72.2824259727232, 69.15139398267193, 70.05031493402296, 74.4113943653722, 73.92043129090341, 73.542675664348, 72.18639850616455, 74.49946726522138, 63.83287968174104, 63.83945749652002, 71.27301185361802, 67.31477552844633, 66.79084101030904, 63.56913166661417, 65.83683429225799, 59.50772131642988, 66.47163068094562, 67.92002078025573, 65.85537141369235, 65.87052745203819, 66.32503601812547, 68.04152011871338, 71.77122346816525, 70.42051607562651, 69.78776716416883, 66.14080229113179, 66.5311408812, 71.80702686309814, 73.12073061543127, 68.87489826448503, 71.05375136098554, 74.65083937491141, 70.90739988511609, 71.54334945063438, 73.55652163105627, 75.78879740930374, 74.36563599494197, 75.67907302610337, 76.94986604875135, 73.9061067950341, 73.74306171171128, 74.38058807003883, 75.4137089944655, 75.17398941901423, 72.1431661421253, 71.76901125138806, 71.16599390583654, 29.33443377094884, 0.24275021927971996, 0.14216538759008532, 0.24754219117664525, 0.11267944479421263, 0.03536096383487025, 0.13056320048147632, 0.2569023300442965, 0.06475526719324051, 0.4821758008291645, 1.5901774071878003, 2.540838098333728, 0.09896552100056603, 0.08722264950554218, 3.858590472129084, 50.14112095679007, 79.89759783590995, 76.96900721519225, 31.914213895797733, 42.70329121620425, 57.17495049199751, 50.95389096967636, 50.64716554457142, 65.81278231836134, 15.59905436731154, 0.2064863748608097, 0.176528797695233, 0.12043112843868234, 0.039458055680076924, 0.05085538704729369, 0.005995304982793788, 0.05472094413914508, 0.07869943105165036, 0.055568459548897324, 0.043692411329116554, 0.04563640923269334, 0.035393537893410654, 0.037191622860489354, 0.11048385212498327, 0.05050284104541906, 0.03521931034723117, 0.09643043646769178, 0.03392003671897035, 0.017867374812222777, 0.030618563572305347, 0.08065519223530447, 0.07662386137751803, 0.022452840048279014, 0.05547046924250261, 0.19825140464930766, 0.31598310737359914, 16.84830181060299, 81.95942309594925, 53.0325706543461, 82.04950424932665, 44.59594072834138, 59.47389479606383, 110.87340231864684, 40.479848615584835, 0.04083151343248544, 0.031166343251243237, 0.3511774011196629, 1.4910714929142308, 1.1183311069203963, 0.12418314363927611, 0.34303989261388784, 0.09301309443769917, 2.0572194168644566, 0.3566385048531717, 0.2047219517971239, 1.521453927120855, 0.5688261060464768, 54.64572383511452, 87.67997249480217, 78.55549612352925, 100.0920226497035, 96.34420579479587, 101.15187844922467, 96.72484044105776, 97.44822748245733, 95.7068520207559, 85.58557587285196, 79.097104841663, 82.51956893551736, 91.89437097118747, 93.81357885176136, 94.64822000072849, 92.90255346605855, 84.74147396702921, 78.54035577466412, 71.7305955579204, 66.15180846183532, 68.59979891007947, 66.75855990379088, 65.99219937478343, 70.00268167065036, 76.71413944613549, 77.62583163476761, 82.00578551138602, 78.57988542126071, 80.30605777617424, 75.20077136255081, 80.20385649896438, 77.56283052505987, 81.32308129341372, 70.17387743919127, 59.66053685834331, 65.15148247441938, 71.90769057120048, 67.35686256039527, 58.23523775223763, 75.21525275322699, 75.63047485966837, 80.59090814282818, 81.8185943172824, 78.07533525651502, 78.01356577104139, 80.63042994468444, 78.1289932804723, 76.82256160243865, 83.0004358291626, 68.05521703535511, 73.64750492957332, 76.14350518872662, 69.29892216959308, 72.75194937183012, 72.50337308452976, 70.68902584814256, 69.62309037485431, 74.01573704135033, 71.95051500874182, 72.2289405330535, 75.9279631030175, 76.95978180054696, 75.46750822374898, 76.21231925102973, 76.20692206967261, 68.52168098572763, 66.18538395051034, 75.2829763966222, 70.8981195572884, 69.97109090128254, 64.81904591283491, 68.92319833078693, 61.553684511492335, 69.43701313387963, 70.61905076426845, 70.17036299551688, 69.08086192223334, 68.9282738777899, 70.39156113901447, 74.76734945850988, 73.64896405127742, 74.41419493767523, 69.980433987033, 69.09325661197786, 74.26198344076835, 76.38645679719987, 74.1818101944462, 75.06756767149895, 75.49198381362423, 74.85452021321943, 76.68635337583481, 77.9662698315036, 79.4175075715588, 76.818403890056, 78.97140072238061, 81.6208048789732, 78.25085347698581, 76.14902788592924, 78.35765177203764, 78.11863037847704, 79.95126370460757, 79.66479732144265, 80.59130822458576, 78.69006479940107, 36.038446887846916, 1.0025401653782016, 0.11348486367252567, 0.05970660604596619, 0.22108635594767911, 0.3547137549086925, 0.2913966798974622, 0.2645860233854863, 0.13959510131709038, 0.5019188672304153, 2.094656724122263, 4.17642895252474, 0.8027710332985848, 0.15918225350399173, 4.223558681626474, 56.661112154683764, 90.92669871545608, 87.48254391454881, 40.40777506366853, 35.65817702201105, 54.85144038354197, 58.770103916045166, 56.81261762495964, 75.27400201366794, 20.98284279146502, 0.21740210122398793, 0.12279053368876058, 0.04315821821951578, 0.02932098682879681, 0.03354548867191038, 0.04076994677645065, 0.04734971891007116, 0.056984967612210786, 0.052091933396314426, 0.032232356513099324, 0.09618987719858847, 0.051161695812498374, 0.16784044132838327, 0.16618550755083564, 0.10217505402021831, 0.15330674216872262, 0.19015252229667481, 0.2018856644750603, 0.14362248682206677, 0.14190928439699835, 0.2131936278554701, 0.20767955680287656, 0.21460733586742034, 0.17659261281932556, 0.3813560559384285, 0.7373310673621394, 22.752131800497732, 94.42125597307759, 64.59933434763263, 95.06883144378664, 65.30753789409515, 88.31651826058665, 116.44833764722271, 51.20522076083768, 0.14046097985438763, 0.4481350209924483, 0.23624824720524976, 5.0876906610304315, 2.8844276743550457, 0.791821246666293, 1.067399743103212, 0.17570010506578032, 4.462524181412113, 0.5852782425861205, 0.8734341867027745, 2.8321437056987517, 0.7629924387701097, 58.415239241815385, 93.37642285131639, 85.9652848397532, 104.12306601001372, 101.4929756041496, 105.20631482524257, 99.31427155771564, 100.26635631438225, 102.94654323208718, 91.89346882604784, 84.59336526932256, 87.87457696853146, 97.71521537534653, 97.59193528083064, 97.6978078965218, 97.2782241144488, 87.5766964881651, 82.41124091609832, 76.73546929513255, 70.77269784865841, 72.40186998921057, 69.09404893075266, 71.07087642915788, 74.74105388887467, 82.94011762065273, 80.93484509375789, 85.47075240842759, 80.7423508551813, 85.43495685823503, 77.57116163930586, 85.65482924061438, 81.50081173066171, 85.03147832808956, 76.26130180974161, 68.92084490868353, 71.55754843065816, 77.99629949754285, 78.60072105161606, 67.57527582107052, 80.29364739694904, 78.84702236421647, 83.50994386980611, 84.64596425333332, 81.07106116510208, 82.26945507910945, 80.86694886607509, 84.08066441935878, 81.03150798428445, 86.90877960574242, 70.66088676452637, 74.45261847588324, 81.95867000087615, 72.31320873383554, 75.97630239302113, 75.05820105152746, 73.37892455439415, 70.48967530650478, 80.11378319032731, 74.17175323732438, 75.97474128969255, 80.4550999979819, 80.286908764993, 78.1915472399804, 78.68083154001545, 78.3436724447435, 71.516708712424, 71.11574834392917, 78.403731776822, 75.3116959910239, 75.39338327223255, 73.44121179273053, 72.99241419761412, 64.6629983378995, 74.5427780766641, 74.04633937343475, 73.78518796736195, 73.2062461299281, 73.56425654503607, 74.89908618311729, 78.2104609089513, 76.59670368317636, 77.29310481779038, 73.7875884579074, 74.06472744480257, 77.87246242646249, 79.98999318768902, 76.47244299611738, 79.36704235692179, 80.0347395866148, 79.25352111939462, 78.02920033854824, 81.84773752766272, 83.31465690366684, 80.05757562575802, 81.20368434536843, 86.43023475523918, 81.22248034323417, 79.99749275945848, 81.4170769722231, 83.81997585296631, 83.93361476159866, 84.61252212524414, 84.07508680897375, 86.04308897449125, 41.51388737463182, 1.2310956947265135, 0.2602946133382859, 1.1360977277640374, 0.5332318224733876, 0.6170761008416453, 0.4554343986655436, 1.1344548675321764, 0.4447539991909458, 0.9990863345803754, 5.6818601200657515, 3.9727395340319607, 0.48312746589222266, 0.14280375333562975, 6.927968686626804, 71.49548084505143, 89.60735459481516, 95.09052215083953, 46.820583574233524, 61.80537908307968, 71.51177437074723, 69.97075357744771, 65.41331637290217, 88.53130725122269, 27.82464877251656, 0.38233431957421765, 0.45958190675704713, 0.21530680478580538, 0.13728767513267456, 0.14311807921096203, 0.1206963787215852, 0.1401583138372629, 0.24756531171020002, 0.19521169033983063, 0.13361777689668441, 0.16505434808711852, 0.1473574872098623], [0.14721819710346962, 0.028104048500198032, 0.01770813960672146, 0.02280326781704301, 0.038899914661963145, 0.01586862651991748, 0.08540159722249355, 0.0540879754830272, 0.02297228979577701, 0.06585802011672529, 0.07558870039159253, 0.22093105460366896, 0.1956799845661848, 0.6468688312076754, 14.538227781172722, 66.44157748068532, 62.55950573951968, 42.525407806519546, 44.62648422487321, 79.07575145844491, 77.43121931629797, 8.268526946344684, 0.22785990619130675, 0.3236979804933071, 0.5715772810001527, 2.025847564781866, 0.19382298743772894, 0.03092732956452716, 0.22018614134961562, 0.1065864410972403, 0.07239877922280182, 0.24831537307510454, 0.07946632336825132, 0.387659641884027, 28.32202296103201, 81.14275424711167, 77.01374576937768, 96.49318525868078, 94.25551229907622, 97.42614453838718, 92.8751439432944, 95.43365109351375, 92.70812157661685, 88.52467060089113, 79.01744150346326, 73.27312254136609, 80.59054728477233, 85.86381312339537, 89.024717884679, 88.73795340138098, 88.67497582589426, 85.93866763576385, 78.50306972380608, 67.0651323564591, 63.0881392571234, 62.745139752664876, 62.61895710422147, 61.59648149244247, 64.42750707749398, 63.63842818044848, 67.53125898299679, 69.64412212371826, 70.56727547799387, 68.08049278874552, 72.2332472955027, 74.02409953455772, 76.33597589308216, 79.17478346055555, 69.08982061570691, 49.85135586031022, 64.54878284085181, 71.81314576056697, 50.963771420140425, 59.5596181961798, 75.59002737845145, 74.45141038587018, 77.73050400518602, 74.4478645632344, 79.81336101408928, 77.55471906354352, 73.84909122220932, 72.8756138586229, 79.5734453201294, 70.55633990995346, 70.52512568812217, 76.31546189708095, 64.36963642797163, 72.00379648516255, 69.95995136999315, 70.63001771127024, 74.4499198852047, 70.69330907637074, 66.8352500854, 68.02617580659928, 70.48574509159212, 69.52281105902888, 66.92973213811075, 66.9617465234572, 73.09633347295946, 71.04595368908298, 68.74146707596319, 61.87359302274643, 69.22905691208379, 70.87340078046246, 66.93688654130506, 67.21152305603027, 67.02073112610849, 63.65019529096542, 69.56753392373362, 66.6978180793024, 66.9948277934905, 63.43606133614818, 62.61121042313115, 65.47219114918863, 69.2641778146067, 72.08796270432012, 73.83579438732517, 70.43529556643578, 66.50210749718451, 67.9930631576046, 73.92097257798719, 73.79003601689493, 68.37158756871378, 71.41708835478752, 67.98127251286661, 71.17459174125426, 69.7175096696423, 71.45361346583213, 74.61396909529164, 75.89186160795151, 73.71589537589782, 75.21048315109746, 75.21561361128285, 72.68694785333449, 76.58311659289946, 74.85459866062288, 76.99111369348343, 71.78566563513972, 57.87638402754261, 68.00599128969255, 23.248872526230354, 0.2868964955691369, 0.32867142329773597, 0.38631049976233517, 0.13729915112978028, 0.14554861572480973, 0.11400390356298416, 0.06432936061173677, 0.10448130042923075, 0.932339912941379, 2.637943481245349, 0.5298393399965379, 0.03785611220425175, 0.3748233484164361, 16.33477334053286, 65.09962874074137, 63.20081718506352, 39.24504726163803, 50.96308892773044, 35.35150651008853, 56.67691538410803, 51.77084222916634, 67.74712270306003, 6.577864298897405, 0.04316442353170245, 0.08934944747917115, 0.10841307816125693, 0.008464960340080003, 0.03408225966737636, 0.07193027049182885, 0.06151869510030074, 0.049228817675142526, 0.01927730026504686, 0.048485310192430214, 0.03372070830195181, 0.04751762623087533, 0.03214411084510146, 0.03963497985574988, 0.016154421365729744, 0.045838802001408996, 0.03749866707010135, 0.05769704250738986, 0.03913655156089414, 0.024307446982411128, 0.03529226106982078, 0.05831871902750385, 0.039907285808435375, 0.20931708506278454, 0.08622092825751151, 0.8041261509060861, 19.32586104639115, 77.78479745311122, 65.23550356588056, 49.50073519060689, 34.065373097696614, 85.38319726144114, 91.41043678406747, 9.71527063077496, 0.2753608355358724, 0.22467374651422425, 2.3637636774970643, 1.860429447504782, 0.6801388653055315, 0.01433996701492898, 0.20658159958979777, 0.3362570420628594, 0.32020348574846025, 0.6252727513351749, 0.13993714425352313, 0.18079731703525592, 36.413601982978086, 86.87352534263366, 85.82893540782314, 103.56515592144382, 97.30531984759916, 101.72226951968287, 98.46197974297309, 100.60178172203803, 95.92829335120418, 93.97087374041158, 82.91476341985887, 78.64593029022217, 83.6254184476791, 91.0872805503107, 90.31272226764311, 92.35400999746015, 91.12858310822519, 87.92973333789458, 81.5385841554211, 71.21355656654605, 64.89210790203464, 66.92195015568888, 65.95245792019752, 66.01611014335387, 67.21406475190194, 66.62785868490896, 69.46119846836214, 73.44149420338293, 70.14849185943604, 71.40457599393784, 75.76545930677845, 76.00076229341569, 77.94686978863132, 81.88683571354036, 74.31620628603044, 57.0231233873675, 68.16294885450795, 71.8735973296627, 57.46826925585347, 67.14761195644256, 78.48795290916198, 80.02167024920064, 80.74572409352949, 75.77530445591097, 80.69176796943911, 79.85726018105784, 77.65526510054066, 75.49676910523446, 82.53640374829693, 70.27580415048908, 74.37572433102515, 76.55580120701944, 66.89548200176608, 76.67936371218774, 73.85030715696274, 74.3918844961351, 77.09734716723042, 74.28303872385334, 70.48392511183216, 71.47905395876977, 75.23128740249142, 72.7175501854189, 71.14982589598625, 70.75554140152471, 75.59530688870338, 74.8997216070852, 72.18497860816218, 66.94676306939894, 68.30562114715576, 71.95781846200266, 70.03020101977934, 70.118375901253, 68.06279505452802, 68.65771662804389, 70.99525313223563, 68.67031528103736, 68.2055457945793, 69.13848154006466, 65.3095853713251, 70.14726807994228, 72.47404160038118, 74.55558069290655, 76.5686430469636, 76.6141111620011, 70.40404996564313, 72.79185556596326, 75.69447225139987, 76.60483867891374, 72.7986648005824, 75.64793725167551, 73.42862098447739, 72.19909129604217, 74.37511244127828, 75.88554659197408, 78.45465198639901, 78.71763906171246, 78.19342997766311, 78.19864672999229, 79.46831011003064, 78.13901885863274, 79.28762220567273, 79.59032720135104, 80.7892074892598, 78.09293885384837, 68.47057250238234, 77.92551640541323, 28.847916703070368, 0.3669362280878329, 0.17897566720362634, 0.34955108838696636, 0.13336372681923453, 0.13009628521338587, 0.06396852936896105, 0.10644732719107021, 0.11918808183362407, 0.8019166307583933, 0.6573450529286939, 2.3113210979969274, 0.016487127605585322, 0.12256747952872708, 20.49594525367983, 72.33220869495024, 73.2690118974255, 41.53896308714344, 33.381237214611424, 37.23562878947104, 62.415711649002574, 59.43951522150348, 75.54828551507767, 9.176682137673902, 0.01760748906000968, 0.061413825324345986, 0.07302320982900358, 0.04061409767957465, 0.018521692423570543, 0.013041429788685374, 0.054863892315376195, 0.11028416364664033, 0.03471836545354417, 0.04879519275780167, 0.047824252922568596, 0.07724520464938495, 0.23720034127754552, 0.19866732910515802, 0.1788453862912232, 0.12893222993420017, 0.12433410126475558, 0.18488822655091364, 0.1343740435737756, 0.11624406722764816, 0.1620206858722433, 0.18348000372850126, 0.24409445843869643, 0.28061341013639207, 0.396197599869582, 1.244011079111407, 24.256770649263938, 89.2283045861029, 77.71671295166016, 53.16625287455898, 60.805311972095126, 101.66067261849682, 97.24371510167276, 14.284113107189057, 0.8428971865965474, 0.8595464222373501, 2.2524242583782446, 8.036046105046427, 0.8767653821456818, 0.19740650159937723, 0.7500369113779838, 1.182783738740029, 0.576406576700749, 1.5698394275480703, 0.3223910957815186, 0.7204610145380421, 40.50538716777679, 91.7749269547001, 89.8083996003674, 108.80882355474658, 101.55787514102076, 105.72063169171734, 99.93424138715191, 105.98361876703079, 100.74031199178388, 98.00734566104029, 85.14150865616338, 82.4541751800045, 88.9854000460717, 94.49481610328921, 93.11778176215388, 95.81640381966868, 96.56687874947825, 94.90825745367235, 84.39856467708465, 73.05977698295348, 67.63136571453464, 71.82630923486525, 69.74566444273918, 69.27225789716168, 69.43647184679585, 69.60354912665584, 72.6251156099381, 77.45341993147328, 76.81197904771375, 78.52032815256428, 79.65135928123229, 83.91213586253505, 82.55020264656314, 86.4318899954519, 78.02357565972113, 58.18276428407239, 72.82310116675593, 85.14856892247354, 69.05018114274549, 71.61090835448235, 81.56703702865109, 83.9059934308452, 86.04821943467664, 77.63565324967908, 83.62019385060957, 82.67044682656565, 79.7458334892027, 77.96674836066462, 85.11517386282645, 74.49578808199975, 73.7435245513916, 83.79102091635428, 70.7849827120381, 80.19466246328047, 75.44556648500505, 78.29096363436791, 78.64415737890428, 76.72694990711828, 72.3191785812378, 72.31966495513916, 76.78844482667985, 75.28627903230729, 75.44215402295514, 74.31603370174285, 79.93231081193494, 75.84673081674885, 74.9362624076105, 68.47632269705495, 72.74475574493408, 77.08659987295829, 74.13673431642594, 74.1425786479827, 72.30927067418253, 71.00404708616196, 76.07104332216325, 71.5447771933771, 70.42284596350886, 70.9610814432944, 69.0680593059909, 73.57645511627197, 75.93841229715656, 79.06230557349421, 80.46642780303955, 78.84518669497582, 72.42708298467821, 77.47381625636932, 79.3101836789039, 79.42561118833481, 76.03008593282392, 78.59683790514546, 74.67763700792867, 79.2642213452247, 77.15153078879081, 80.45316234711679, 79.76826944658833, 81.23006620714742, 80.86946702772572, 83.00868065126481, 82.15963655902495, 79.29082285973334, 80.94787520747032, 82.47928619384766, 82.09111275211458, 82.46271025749945, 73.33330738929011, 85.31428121751355, 33.169468449008086, 0.7298281248058043, 0.5340775835417932, 1.0894519210823121, 0.413754680344174, 0.6836336971290651, 0.2468135343083451, 0.27834863972760016, 0.26826054879253913, 3.1919741005666795, 6.683675627554617, 2.2463999880898387, 0.11060752935947911, 0.8503553896181045, 30.71633185109785, 88.79450613452543, 82.0701986743558, 58.54510891822077, 67.68828715047529, 47.040601084309245, 72.29398911999118, 65.75694345658826, 90.10094565729942, 14.026434959903842, 0.20344485258383138, 0.2839161071085161, 0.1893385385553683, 0.12824781464352725, 0.1351835380398458, 0.0933516976393519, 0.12744950506115152, 0.17827393066498542, 0.13103008510604983, 0.17001554880651737, 0.164671074298601, 0.17569984459588606], [0.049967992930643024, 0.01673912839783776, 0.05066795980617885, 0.04928974464776055, 0.010205105119835465, 0.03411126375618962, 0.04063240718096495, 0.10051040624779078, 0.04836749736099474, 0.01631094653519892, 0.053856509677585096, 0.1028659044494552, 0.22984667861413574, 0.5652755030220555, 21.341778885933664, 69.10722809453165, 42.81424330126855, 49.70938959429341, 45.528880396196925, 91.59652186978249, 50.602022986258234, 0.7794027162655708, 0.019477789305270683, 0.07839664246045774, 1.5536119692748593, 0.9320886973892489, 0.3331636403116488, 0.1647139905441192, 0.14608997941738175, 0.3556025394749257, 1.3846189793079131, 0.3142550275210412, 0.3265412698589987, 42.60132135883455, 90.87169924089986, 93.38440095224689, 94.64083810006419, 92.38887986829205, 97.53768105660716, 95.15949310794954, 95.76925693019744, 94.61653509447652, 86.57473487238731, 81.89557475428428, 77.28939425560736, 74.12914845251268, 79.98574133842223, 84.60569720114432, 87.21094331433697, 85.46107984358265, 84.62762325040757, 84.21557041906541, 76.0039629474763, 68.75848231777069, 61.40090427091045, 63.200770116621456, 60.21467754917761, 61.65200656460178, 61.45649210099251, 63.675141565261356, 63.04840564727784, 63.94389060235793, 63.373672116187315, 65.9243659050234, 67.38021635240125, 71.2541844767909, 71.2545374901064, 75.80363181329544, 70.73323880472492, 64.30112046580162, 69.32984613603162, 60.67182979276104, 49.939346390385786, 71.47965015903597, 74.42939804446313, 74.6732988665181, 74.66739177703857, 76.81364997740715, 77.11943011130057, 73.36435687157416, 71.60480514649423, 80.04594972056728, 68.99310281199794, 73.5812404078822, 76.93318813077866, 62.221601393914995, 74.38266692623016, 72.93448079016902, 73.59546292212703, 70.34635974514869, 74.885695211349, 72.66430008795955, 68.67535160433862, 68.66456508636475, 73.46819769951605, 73.36400385825866, 70.75121110485446, 68.42554369280415, 68.11313475331953, 67.9505838886384, 69.34344107104887, 69.15047614805161, 65.09851478761243, 66.0742082903462, 66.59094133684712, 66.88535444198116, 68.05993172430223, 64.92785246141496, 66.9022520126835, 69.69187305819604, 67.58683112359816, 64.6057435004942, 62.48546315777687, 62.78449289260372, 66.35726221146123, 72.41710447495984, 74.64184145773612, 73.24597973977366, 72.74498324240409, 71.95028751127182, 73.71461668322164, 71.52034082720357, 71.83951977760562, 73.83726135376962, 67.42454698008876, 67.11397370984479, 67.39179518914992, 69.05419764980194, 69.89705224190989, 72.39997156204717, 74.08998750871228, 70.65616423083891, 70.76923831816643, 74.19436962373796, 74.31681817577731, 71.86270883006435, 73.8571713047643, 75.7296480671052, 68.32635479588663, 49.48937992895804, 63.2527336766643, 22.224374932627526, 0.2839740233555917, 0.5141132709480102, 0.4905254237594143, 0.25546468944559175, 0.6064440874803452, 0.08145663511729048, 0.22320659620867622, 0.7921669668247624, 4.1468680097210795, 1.9189302503101289, 0.5215407691655621, 0.014301871377674323, 5.014278600292822, 41.58980092694683, 79.66242036511822, 43.10159221772225, 38.450681009600245, 61.03579828816076, 62.11472465145973, 47.57386692108647, 57.48858713334607, 2.090235722641791, 0.1446373541388781, 0.05554286072090749, 0.03867375018495706, 0.06029771565790139, 0.05316321925830938, 0.04308828205290822, 0.05249164360124738, 0.0420499686151743, 0.052730992451430335, 0.08211007747318476, 0.009963302873075008, 0.05481545640636356, 0.007542032192671492, 0.06636807379583198, 0.05440375692541561, 0.046791493622285706, 0.0189640871324246, 0.07919653784483671, 0.00768530308344071, 0.08129809322136064, 0.04014544339189607, 0.14115050495151552, 0.0735965347097766, 0.11455959309974026, 0.04986366707711451, 0.4988542397416407, 27.661323239726407, 80.4923076014365, 49.40130310673868, 44.33121212067143, 41.74840196486443, 101.94980621337892, 59.65462584649364, 1.1081905542842805, 0.07964379529679015, 0.19585987733256435, 1.0209286044682226, 0.739080689607128, 1.4103822097662957, 0.10728718938245889, 0.24274404461105026, 1.0791631763981235, 2.0358396802217733, 0.23932312495045124, 2.216121986989052, 52.83804855039043, 98.20696292384979, 101.55873806245866, 100.55146555746757, 96.92632475206929, 99.10458164830362, 100.04839020390665, 97.29247016291465, 98.90996148509365, 91.12738286295246, 84.2878047881588, 80.53275508265342, 77.27209660314745, 81.77707210663827, 90.84200689869543, 90.58694301113006, 89.32255129660331, 90.64316626518004, 87.83816168385168, 78.76009479645761, 72.35123219028597, 65.29832816893055, 65.17005097481513, 66.82532648886404, 66.25661419283959, 66.83434794026037, 68.3624170672509, 66.69449975413661, 67.37426219447967, 68.12613348807058, 69.43866837409236, 72.81834725410708, 74.92505227365803, 75.92669225508168, 79.51912833798318, 72.83946529511483, 69.53239733173002, 70.47801802235266, 66.90446422946069, 61.652794961006414, 77.0738443251579, 78.26753923969885, 78.52506637573242, 77.7477938129056, 81.10269115817162, 78.01857856012161, 76.07025100338844, 75.88742148491644, 83.06436261823102, 70.29842838164299, 77.32401309474822, 77.95946844162481, 66.28029746394004, 79.29722416785457, 75.31629300886586, 78.3560828239687, 72.83151857314571, 77.71634424886396, 73.48250650590467, 72.90425500562115, 70.72576276717648, 73.71899404833394, 76.98839941332417, 73.45677575757428, 71.30980368583434, 70.17685059578189, 70.23692561734107, 70.7146232358871, 72.73135692842546, 70.08521618381624, 70.2601852724629, 68.6411093127343, 69.0554214292957, 71.9233565176687, 66.31548112438571, 68.50625822621008, 74.65986867104807, 70.23108128578433, 67.48898367727956, 65.16737199598744, 65.69040044661492, 66.72708680552822, 74.58888946040985, 75.67664115659653, 77.68143515433036, 75.02524529733967, 75.51499243705504, 76.72307460538804, 74.40444392542686, 75.79739524472144, 76.12783139751804, 71.66273070919898, 70.4603281328755, 70.45321295338293, 71.88728640156408, 73.53031235356485, 74.41601491743519, 76.89734551214403, 75.61189851453229, 73.12970499838553, 78.2966196921564, 78.5745039293843, 76.57291058571109, 77.61636303317162, 77.52626619031354, 74.42258880984399, 61.230571423807454, 69.49721367128434, 27.30557603220786, 0.34964819769224814, 0.292762890458107, 0.3985263539418098, 0.29582384072484513, 1.3599551156643899, 0.1870033340228181, 0.06670639354495272, 0.6715626642107965, 2.2111675431651454, 3.168083924439646, 2.181131258126228, 0.3024210528500619, 5.2367917183906805, 49.022947357546904, 90.6155292449459, 46.43539897857174, 38.023629034719164, 67.51090188180247, 62.8432813767464, 54.526632831942656, 64.81108742375528, 2.4921320667189937, 0.1477870939960403, 0.05953318672254682, 0.06733899064842733, 0.06686569386792761, 0.05779849553120233, 0.02279758152942504, 0.028128911883780555, 0.03428272572496245, 0.01873110447289242, 0.042411033514766924, 0.019632889551200697, 0.0426087225036275, 0.13321153579219697, 0.23340345630722664, 0.08647489406528973, 0.11773111283658974, 0.11409581879213934, 0.20867508806047902, 0.1239483989775181, 0.11417843371389375, 0.15425037863033433, 0.2123282702579614, 0.19336610792144654, 0.33427492745461007, 0.3291061015859727, 0.8310922006926229, 34.245100021362305, 93.30431399806854, 56.23271480683358, 60.770371498600134, 62.42427418308874, 112.80363990414529, 70.77626720551523, 2.048933900171711, 0.1304600544033512, 0.22635792952872094, 6.015019378354473, 4.629649510306697, 1.8823858951368642, 0.30349657900871774, 0.7576569734561829, 1.2692243197271902, 4.067794497936003, 0.7621806307185082, 2.7284872291549562, 53.54756609086068, 98.36167689292662, 102.02894395397556, 106.60705597169938, 100.61498442003804, 105.5010966331728, 104.3033459878737, 102.59170993681877, 101.97794529699512, 95.10589784191501, 87.84519057120048, 84.93333278163787, 80.33984507283857, 88.73560782401793, 92.5975578061996, 93.40871964731525, 91.02711139186736, 96.63883855265956, 90.62304450619607, 83.4634167148221, 74.20794886927452, 68.65837558623284, 68.68177644668087, 67.85910637147965, 68.60897725628269, 70.81710692374938, 70.915205401759, 69.38391993122717, 72.53734081022202, 71.43819070631459, 73.65313745314076, 77.43996620178223, 79.62020781732376, 80.21202287366314, 84.47988325549711, 81.16482934644146, 74.27982238031204, 80.60893535614014, 80.09983524199455, 67.73623420346168, 78.48784308279716, 82.20854851507372, 82.64476314667733, 77.89848343018564, 80.97286070546797, 82.17751472227036, 80.81070207780408, 76.3755290738998, 87.09762604005876, 72.14726894132554, 77.80232260304113, 86.08963181895595, 69.64864853889712, 82.25236923463883, 78.9459131610009, 79.61946256699102, 76.3435225332937, 79.52999330336048, 77.62199555673908, 74.84064286754978, 71.69515302104335, 76.68280755319904, 80.40858853247859, 75.9544312569403, 73.72634457003686, 73.62599465154833, 73.35044814694312, 74.73514679939517, 75.76579663061327, 71.64816302637901, 72.16890473519602, 72.00806402391004, 72.90198003092121, 76.31162581905242, 70.60954293897076, 71.04445534367716, 78.27525061945762, 74.23803344849618, 70.69088505160424, 69.56936959297427, 72.33205964488369, 69.90949400009649, 78.95892758523264, 81.88455289410007, 80.4404067993164, 78.61660665081394, 78.40421815072337, 79.34462208901682, 77.075985939272, 77.09151852515437, 81.7663718808082, 75.89335995335733, 74.98539401638892, 75.98952862524217, 76.05669529207292, 77.00500672863376, 79.70144010359242, 79.6872881920107, 76.8524657526324, 76.34671534261396, 83.01681564700219, 79.7821311027773, 77.54710966540922, 78.42341423034668, 78.67290050752702, 76.72082316490912, 64.04920624148461, 75.76341967428885, 31.10796286213783, 0.4657306816549071, 1.013538123619172, 1.8672537587342726, 1.4175966742538637, 1.7755032691263386, 0.2836344931875506, 0.5576363806763004, 2.9036387080146424, 11.72566871489248, 5.513407068867838, 1.7080438954214898, 0.4225190939201463, 8.44907364537639, 59.81471738507671, 96.71978058353548, 62.040274143219, 56.36194905927105, 72.85646484744164, 75.99694190486785, 61.10959376058271, 78.51158126708, 4.170284069353535, 0.5899211644164978, 0.2209872548137942, 0.15333194646143145, 0.15327464308469527, 0.10779607860792069, 0.081130817923094, 0.2436652959835145, 0.1238281308342853, 0.09763687173084867, 0.16017243746788273, 0.17342470135659943, 0.18924461617585153], [0.049251712212759646, 0.035451465631805124, 0.04070697051863517, 0.09281751219063036, 0.03408890164967987, 0.09187766786424384, 0.045143412501220746, 0.05633312254963864, 0.03939977554123729, 0.030315972248753233, 0.04408542975603093, 0.03270268470289246, 0.03184920912908931, 0.06367568076858598, 35.586287821492846, 65.85304937055035, 55.5838567210782, 42.42709359815044, 54.074854235495295, 102.06864618485974, 20.446550846099854, 0.04652028317533193, 0.02956124540838984, 0.2802930934534919, 2.7764423720298277, 1.0372229881824986, 0.38609394202789954, 0.046972661925059174, 0.11550308400464636, 0.4528521614209299, 0.7772383033748597, 4.552003741264343, 71.95355876799553, 107.41828841547813, 97.66556601370536, 91.98336955039733, 92.07141107128513, 92.898693853809, 89.95730061684885, 87.53377791373961, 85.85435236653974, 83.64848982903266, 82.53911018371582, 76.00506121112456, 74.38697368867936, 73.95666614655526, 80.75389046822825, 86.75657595357588, 86.9911886030628, 86.60320343509798, 91.04112209812288, 84.27395882145052, 76.62450544295773, 65.82295694658833, 65.11103499320247, 63.2712511862478, 66.81713657994425, 68.97793892891177, 68.39841658069243, 66.08989777103548, 64.90098814810476, 66.2824155438331, 66.10887419792914, 65.08633975059756, 71.48645154891476, 71.94589445667883, 74.60341791952811, 67.10823920465285, 66.79379063267862, 66.02466875506987, 61.848329036466545, 50.9286936636894, 63.344870152012, 74.8684524720715, 74.56393534137358, 75.6893261017338, 77.80270699531802, 77.22618918265067, 71.0850989434027, 74.59822470141997, 76.55820954230525, 71.01236251092726, 75.30947592950638, 78.05936336517334, 60.64424376333914, 71.63374439362558, 72.4195598786877, 74.8130686052384, 67.57026303199031, 65.0829194438073, 71.1583766629619, 72.76553646210702, 68.54221067120953, 67.42814771590695, 67.86771205163771, 69.27319926600303, 72.32948657005065, 71.9775793629308, 70.63528153204149, 67.84254612461214, 66.01578850899973, 67.62306597925001, 70.04242312523627, 69.33898525853311, 67.5223316684846, 65.11227838454708, 66.8771174646193, 63.82659212235482, 65.73536257590017, 70.91814717938824, 68.45944081583332, 64.64979956226965, 62.48645943980064, 61.1552462270183, 61.91857476388255, 63.71853082410751, 71.57755251853698, 71.0278715625886, 71.14759798972838, 72.68002879235053, 73.77762563766973, 72.08720176450669, 72.42887943021714, 69.3517957195159, 66.27095437818959, 63.817503990665564, 58.727177496879335, 60.88095095849807, 69.08119924606817, 72.3164015431558, 73.06318160026305, 74.4510809067757, 68.28399319802561, 62.59200257639732, 67.86167160157235, 71.62512302398682, 72.03753671338482, 69.9055245614821, 71.69803988549018, 72.80691746742495, 49.47519663841494, 72.0405569384175, 28.73443861161509, 0.07854981408003839, 0.05746589845887596, 0.1659271214157343, 1.3508478624205436, 0.5174976635363795, 0.11059219227923502, 0.508689766809825, 0.28401539210350285, 4.123875075770963, 0.7423051230369077, 0.11425267529463577, 0.682799029013803, 24.245556592941288, 65.00297761732533, 48.499279560581336, 13.566220325808372, 27.97420874718697, 55.338512466799834, 45.898351976948405, 44.97053884690808, 1.3194343351548719, 0.09965699196102158, 0.03331480810659067, 0.08920563745402521, 0.0159461785581023, 0.013730969249961839, 0.016419453313574195, 0.1109472893538975, 0.030257839581839023, 0.04225428043414028, 0.032319207901075, 0.06721413363852809, 0.04211738435251098, 0.003953188453094974, 0.028559185166452682, 0.028157031141041268, 0.03680872445505473, 0.03219178449662943, 0.04185630541835581, 0.03627551959887628, 0.024803318458819584, 0.09737816383881916, 0.03861932346837656, 0.05235017397471013, 0.054210626159704504, 0.11173685021217793, 0.07899206131696701, 46.47240261877737, 71.94744771526706, 62.95483750681724, 43.23184628640452, 55.69347520028391, 113.69112322407385, 25.4105358354507, 0.05855140674318518, 0.3743583330463979, 0.7436531926355054, 1.3565040427830912, 2.2800066105781065, 1.523331026396444, 0.20599050146918144, 0.6618869124401001, 0.23206339998831674, 0.32473774566765756, 8.90911667577682, 79.99198575173655, 110.1173419337119, 99.85399753816667, 96.10044617806712, 96.08209733040103, 98.66427990698047, 94.93645929521131, 93.66587808055263, 91.28245769008514, 88.99130713555121, 86.37805938720705, 79.34621457130679, 77.06679190358808, 78.96618397005143, 83.44470700910016, 88.00281493894516, 89.02230170465286, 89.17765894243794, 94.3557837701613, 87.94870976478823, 80.01023261777817, 68.57326799823393, 71.00559250000985, 66.6306749466927, 70.83973899964364, 71.13685069545623, 71.4518327097739, 69.37098395439887, 69.87611462993007, 68.53258517480666, 68.79522708154494, 70.21139883225965, 75.31202547011837, 74.12460634785315, 78.67735632004278, 70.89218108884751, 71.94943243457426, 70.0678949971353, 66.45360346763366, 60.9189038122854, 69.97574283230689, 78.58991099942115, 79.51531579417568, 78.56712987346035, 78.8380479812622, 79.50530590549593, 76.50265309118456, 77.80223631089734, 76.21183287712836, 72.84857303865495, 78.18881727034046, 77.29174767771076, 64.12006778101768, 76.30350651279574, 76.60976517585017, 76.63046744561966, 67.39475265625985, 64.5315283344638, 70.30264100720807, 75.11946847361904, 71.67103828922396, 69.27239125774753, 69.52538413386192, 70.7908348883352, 73.19414169557633, 74.67578564920734, 72.61566269782283, 70.87568359990274, 71.04472990958922, 71.55923504983225, 74.20012766315092, 71.3622614645189, 70.44098300318565, 68.5816304914413, 69.65665017404865, 67.83078685883554, 70.81516142814391, 72.232525579391, 71.85967291555097, 67.42368405865085, 64.8359356387969, 64.13087391084241, 65.32051309462517, 66.24648663305467, 71.9337272644043, 74.60515160714426, 75.30630665440714, 75.36546384134601, 75.5656929939024, 72.70860718142602, 75.05030139800041, 72.52982554897186, 71.39757064081007, 66.45769842209356, 61.501273801249845, 65.68585049721503, 70.67996517304452, 73.93361045468238, 77.26191413018012, 75.81000958719562, 70.5756458159416, 66.53532997254403, 67.6070156405049, 72.9904608572683, 75.79115083140712, 72.9760814482166, 73.3556962782337, 77.28056892271965, 61.02708670400805, 77.6519153964135, 36.53915705219392, 0.22540330736627504, 0.21171038970351222, 0.36712630982360533, 1.8205557354996282, 0.7124857328111126, 0.13128539156769553, 0.7379592594600494, 0.5749155857389974, 1.9430648391285252, 3.857559379070036, 0.2439007914114383, 0.28612415636739424, 26.541621877301125, 74.23731173238447, 50.380044291096354, 17.703382430538056, 31.518760535024832, 54.7247007585341, 49.96179019251178, 55.982781379453606, 1.4314980444408234, 0.026485178311685884, 0.05468141783269183, 0.03674239273213091, 0.00829513971468494, 0.06053634055499589, 0.031405153924659375, 0.08128292468045989, 0.04868112226587631, 0.07060525247887259, 0.02464240552076409, 0.03972525565674709, 0.029195771672792976, 0.18078843041533427, 0.2016816552608244, 0.10303258986002016, 0.20757827997928668, 0.16798181519393, 0.1668839805549191, 0.2992719105414806, 0.09405896533280612, 0.14755383554485538, 0.10847385191629011, 0.12514430819259537, 0.18832765489576325, 0.22444068724589966, 0.14155835484064397, 56.78256442469936, 84.8892374961607, 69.95225567971507, 56.782305548267985, 72.50832311568722, 123.62183493952598, 31.977962217023297, 0.30091501592147735, 0.20270874934090724, 0.9189173170635778, 4.331877385416339, 3.2992217521513663, 3.5814345700125543, 1.3692036968085075, 0.8374340603909186, 1.736641773773778, 1.070553451295822, 8.575483791289791, 80.72536699233517, 113.47460839056201, 104.77996887699251, 99.19187007411834, 102.1654502807125, 105.47194557805216, 100.23290634155275, 97.69256760997158, 95.4001069838001, 92.61547519314675, 92.99998514113888, 82.11605902641051, 82.85989730588852, 83.37801102669009, 87.54826714915615, 93.64901973355202, 93.84449497345956, 91.1495913228681, 97.25243060819565, 92.09991885769753, 83.45893736808532, 72.36987129334481, 73.63570644009498, 69.3864380928778, 73.9436674118042, 74.93071617618685, 74.50108328173238, 72.97511654515421, 72.86132074171498, 73.24434018904164, 74.6113254177955, 72.7494155206988, 80.49354707041095, 78.50173611794749, 84.21921037858533, 75.48720636675435, 77.7297430653726, 76.75501054333103, 78.02893361737652, 73.21092943991385, 77.99538950766288, 82.60844984362203, 82.89967013943581, 82.15616133905228, 83.12115853832614, 85.80045900037213, 78.22595427113195, 79.35185493961458, 80.22204845182358, 74.9559840848369, 79.88139844709828, 84.6336244767712, 65.48418967954575, 77.83466646748205, 79.21375613058768, 80.60373429329165, 72.62220521127024, 68.15116605451031, 75.56387301414244, 78.41301994939005, 74.23659786101311, 74.13449856542772, 71.56044313984533, 73.14202908546694, 75.80050176189792, 76.25402973544213, 76.12801182654597, 74.75568432961741, 74.02979481604793, 76.55299278997606, 78.78642174505418, 74.66121796638735, 74.06140911963679, 71.98152526732414, 73.38367062230265, 72.54391470263081, 73.36248982337214, 76.49873856575259, 76.0324707338887, 69.64507133729997, 67.2491228965021, 67.88485280929073, 69.4426142784857, 68.4340944597798, 75.68411719414496, 78.86493975116362, 78.07855944479667, 77.37149730805429, 79.94366999595397, 76.52183348132719, 80.54302384776454, 73.49514438259986, 73.21488318904754, 71.77588324392997, 65.29624931273922, 67.44452753374654, 75.92507623857068, 78.48184970117386, 80.55431242912047, 78.91453419962238, 71.81954706868818, 66.87760383852067, 68.47181981609714, 73.82607475403817, 76.7062319478681, 74.08218199206938, 75.44988893693494, 77.66657721611762, 62.632979577587506, 81.6736941183767, 39.845715107456336, 0.25282285056046905, 0.5506706802595047, 0.9003637707041157, 3.250387017765353, 1.1704578130475938, 0.6166877861945861, 2.118976890079437, 1.4028258862033969, 9.004147860311694, 3.8591018511402995, 0.16997778067185035, 0.9616505594984178, 38.20479154586792, 80.0704723788846, 65.54672010483281, 21.65508016463249, 36.31086334105461, 66.62940409875685, 59.4136550349574, 67.5350558373236, 2.1085742740861835, 0.1404716591200521, 0.14199588297595903, 0.16906612072019808, 0.14470529081600328, 0.11572280568220925, 0.13325187798228957, 0.2795867910308223, 0.15877127797613222, 0.15011161926292604, 0.22561002853176287, 0.1051225160218535, 0.1227814632077371], [0.047972759066690365, 0.041825470379403526, 0.023508440260024323, 0.02930594086196394, 0.002323067066402385, 0.02231109463008902, 0.02916994110320605, 0.08445838977011942, 0.05027650802906963, 0.08004426775920777, 0.0307250976742756, 0.07601567183531101, 0.06692328835807501, 0.12361367218076222, 47.003479772998446, 59.70369861971948, 37.50064765253375, 40.9349573043085, 70.51247212194627, 84.14526585609683, 5.581354287362868, 0.19630715010627625, 0.08341979671029315, 1.1525105180278903, 0.3298805858339033, 0.5728362392513984, 1.006653567235316, 0.0782786189548431, 1.3312669002240705, 0.28714905943601365, 13.10935833761769, 95.84393885827835, 103.67471556509696, 91.77594677094491, 92.52068719556256, 91.06535450104745, 90.81096526115172, 87.13962677986392, 85.42751219964798, 82.04662522962018, 80.24202116074102, 79.1936892847861, 75.54299816008538, 70.87280458019626, 73.00749178855651, 72.91821079869425, 79.13963117907124, 84.33537529360864, 85.31875271950999, 85.37839628035023, 86.49854675416024, 77.65229978869039, 71.33661700833228, 67.74722468468451, 66.15976302854477, 67.98534393310547, 71.08120795219176, 73.12106793926608, 76.99716983302947, 72.27480872984856, 67.4735216940603, 64.6072026221983, 64.96733896193966, 66.69555094934279, 69.5067842545048, 72.63489800114786, 67.29481850900959, 67.37796491192233, 71.42805530178931, 66.983594125317, 54.80032013308618, 54.03961958423738, 70.70155389847295, 75.88482487586238, 72.44822455990699, 78.7431344678325, 75.26450203311059, 71.58422054782991, 73.94518929143106, 70.7355922268283, 70.64540124708607, 77.72509113434823, 73.16604183566186, 64.14021699659287, 72.21696161454724, 74.69478561032203, 74.53168561381679, 67.4002282850204, 61.326571433774895, 64.17440829738494, 65.47583895344889, 65.34706361832158, 72.19073664757514, 65.02703351359214, 67.43982068953976, 74.65036869049072, 70.54996998079362, 69.41107057755994, 71.09735242782101, 71.26150361953243, 72.02082741645076, 65.22293236947829, 67.44449615478516, 69.87976243419033, 66.64583098503851, 67.01101149282148, 64.53629401422316, 66.80194916263704, 67.0158830765755, 67.1790615204842, 66.51101912221601, 66.5909021131454, 64.51718030437347, 60.9269799724702, 59.14687110531715, 61.83689140504407, 64.16381397554952, 66.66318355068084, 70.02845164268248, 72.34192832823723, 69.43655813893965, 69.5599009913783, 68.97863711080244, 67.57311067273541, 61.44864736064788, 58.33409324769051, 57.152255658180486, 64.2784099425039, 66.00309571912213, 70.67814519328456, 69.45689955065328, 65.75388400785386, 63.07296752929688, 71.36930604134837, 76.71695570791923, 75.63718995740338, 76.44651612927838, 74.59765203537481, 76.01467101804673, 74.11946804292741, 84.08402196822628, 62.43464885219451, 74.0303517926124, 36.62611992128434, 0.15021697167427311, 0.10774832834760029, 0.11197810662129234, 0.08314633396484199, 0.10934744495898487, 0.29169079637335193, 0.688363156251369, 1.5908462938762482, 5.282356421793661, 0.18175158679725664, 0.04250061600619266, 6.663158689775775, 53.22783800863451, 52.83445565931259, 31.847413970578103, 43.44690199821226, 40.97055673599243, 52.08533394721247, 39.68737294597011, 1.9427512946628758, 0.17635198460230905, 0.13496633679155381, 0.0642318414494155, 0.11568201150024131, 0.09559150890357072, 0.16967185112016817, 0.027299903243059115, 0.029307024876376795, 0.08657242471892988, 0.07429355214680396, 0.03870058624494461, 0.002385556858385943, 0.030440559212659157, 0.041070640117170355, 0.024417175671025634, 0.04281601823505856, 0.033116609669260444, 0.031108494036861008, 0.01522038877385879, 0.041699464237617875, 0.08100596091319477, 0.05819207703274104, 0.040838262667098356, 0.06944546430942512, 0.12362189996506899, 0.695577682025971, 58.20478447021977, 69.23922369557043, 53.491821365971724, 28.43323000015751, 70.53141716987857, 97.6970548014487, 7.856135320278907, 0.18074326187131867, 0.43053163816371276, 1.4735422980400825, 0.5295226086051233, 1.8624061994975614, 1.3178152542921806, 0.5585406095750871, 2.50425513232908, 0.11755328850760577, 18.300924147329024, 106.29526676670199, 105.40684207793205, 97.02185799998622, 96.75558397846838, 96.31452914207213, 96.27485044540899, 90.8212967841856, 88.9034931121334, 86.68352573148667, 83.6503961009364, 83.97157546012633, 77.61603355407715, 74.94165958896761, 74.58686551740094, 75.73052667802381, 81.69876590851815, 86.89567888936689, 90.51251995948054, 89.12527961115684, 90.26585778882428, 81.3132518337619, 74.5194007504371, 69.84672038785874, 68.1249410875382, 70.58047033125355, 74.38732670199487, 78.85618502093901, 79.45123211030038, 78.03527216757499, 71.60668788417694, 68.56704711914062, 67.64084216087096, 70.80892485956993, 72.73999398754489, 72.98141587165095, 71.7733415480583, 72.10210677116149, 74.53445480715844, 69.4736872949908, 61.95990870075842, 64.23551097992929, 75.7385047789543, 79.47737862986904, 76.17509595809445, 81.26783863190683, 78.38292752542804, 75.41292452043103, 74.73193830059421, 69.82038559452181, 72.903227344636, 80.26451203130907, 74.00190676412275, 66.81458703933224, 75.65970436219247, 77.18743616534819, 76.63897114415323, 66.99320393223917, 64.85250765277495, 66.76008962815808, 65.88545599291402, 64.60957173378237, 74.25746487032983, 70.21499956807783, 67.9435000881072, 76.85990256647911, 71.63199501652872, 71.36431678648918, 70.40526590039654, 73.68130791571834, 72.44971506057247, 67.59633110415551, 70.24493509723295, 69.82502968080583, 68.77618005198818, 71.03862670160109, 67.63004779815674, 70.95481349575904, 68.62920099689116, 69.99579398862778, 69.41055282469719, 68.80200493720271, 66.72953436451574, 64.21218072214435, 61.2358783906506, 63.93651654643398, 66.08795227543001, 68.88410014490928, 73.7303061639109, 75.54108404344129, 72.52106297400691, 71.88670589077857, 73.45413208007812, 70.80298639112904, 64.97850987219041, 60.09699467689761, 61.20002400490546, 65.58052309097783, 70.02584718888806, 74.51604320156959, 71.3132239926246, 69.93083953857422, 65.78797332702145, 72.47506926136633, 79.40758397502285, 78.87109002759381, 79.74944206976122, 78.85242739031392, 79.4796222256076, 78.27197936273392, 87.13697525762743, 73.37983454427412, 80.0252317613171, 44.06738173577094, 0.5965476411004221, 0.031530114356428385, 0.06595650838027078, 0.22380039095878604, 0.4230936905068736, 1.0547820911292107, 2.7495616337945386, 1.9061720058802638, 5.129785537719727, 0.206751165490958, 0.09454077335014459, 5.912319960132723, 60.96097515475366, 62.937826187379905, 28.13478077611616, 40.51749160212856, 52.54143107321955, 55.97257537226523, 49.17467248055243, 1.9936105849281436, 0.18256753172364928, 0.08384164302579819, 0.029659400423688274, 0.06364735466758571, 0.01445614712147583, 0.05971021048964993, 0.026741875222914165, 0.01481956199577619, 0.06274888291954994, 0.08385528705172962, 0.036030651085198886, 0.10498530201373563, 0.08388717929201742, 0.11363205980629691, 0.13081858355191447, 0.21679370483804136, 0.053155129369828975, 0.139544386296503, 0.09087531076323602, 0.1933303775806581, 0.2417265725952964, 0.2076492656863505, 0.1559348987235177, 0.24459877411925027, 0.2553066608285712, 1.108095191659466, 69.5376846867223, 78.59484534109794, 52.72362516772363, 57.04452776139783, 89.48845186541158, 108.29199637136152, 11.80445050039599, 0.2932468128781165, 0.3828571592607806, 1.9109824251744056, 0.6498164923921709, 2.570101921596835, 4.575745847917372, 0.7932078658092407, 5.79868350298174, 0.6894965986571004, 17.848776848085468, 108.49717555507537, 110.91903517323156, 101.07046573392807, 101.19070991393059, 99.76608153312438, 100.09122248618834, 95.53298904049782, 91.68422606683548, 89.99701069247338, 89.64127525206536, 88.5900172879619, 83.10126427681216, 79.20912773378434, 81.10949254805043, 79.73851434646114, 86.6015560396256, 91.77438566761633, 93.68359150425081, 93.11400844204812, 93.4762393274615, 84.97552963995165, 78.57364885268673, 75.32074097664126, 74.45992977388444, 73.31610387371433, 77.20581639197566, 79.464858424279, 83.14425345390075, 80.61943161872126, 73.18975648572369, 71.11311251117338, 70.91417774077385, 72.5318181130194, 78.33172490519863, 79.18262820090018, 77.32564480073991, 76.7610509933964, 84.68098317423176, 82.35441361704181, 73.2551267070155, 70.39657392809468, 80.15265387873497, 83.15656185150146, 79.06387452156314, 85.22403532458891, 82.42634988600209, 77.9688193721156, 78.70886079726681, 70.79169780977311, 75.6243481174592, 83.67695054700299, 79.84834855602634, 71.47416668553507, 78.41804842795096, 81.54547968218404, 81.7008839884112, 70.09323350844845, 65.41944311511132, 68.05700563615369, 68.48392425044891, 68.98259870467648, 77.60670615780738, 71.28681075188422, 71.62000040854178, 81.49531256768012, 73.83106400889736, 73.1458886977165, 73.50404031815069, 77.13496269718294, 77.63579445500528, 69.73324621877363, 74.84279232640421, 74.26351316513555, 72.74466160804995, 74.34128592091223, 70.6034161967616, 74.28160313637026, 73.80356819398942, 72.40484314580118, 73.66016634048955, 72.59710204216742, 71.21940089810279, 68.53299310130458, 64.24319490309685, 67.90517068678334, 71.71645149107903, 73.56606868005568, 78.01612315639373, 79.97963028569376, 76.3929287079842, 76.7274284362793, 77.77488954605596, 74.4783256899926, 69.07417820345971, 63.52441272427959, 63.53039433879238, 70.31807945620629, 74.83330803532755, 78.86603801481186, 76.80943735184209, 71.33833500646776, 67.28822108237975, 74.70611341537969, 83.43111991882324, 81.55569353411275, 81.15603539251512, 81.70671263048726, 82.93819565926829, 81.5622595817812, 91.1845474858438, 73.55237176341396, 84.91599590547624, 46.74832174854894, 0.584212951362133, 0.5142485927189551, 0.39556487253116024, 0.2332172969416265, 0.5286363980943157, 1.4939397261027367, 5.428062667769771, 3.8234585379400565, 10.508363093099288, 0.7298009133627339, 0.18991613820675882, 10.77994506205282, 73.63418456046813, 66.54181757280904, 48.60800766175794, 58.03727180727067, 55.039106184436434, 66.80197269685807, 61.06019150826239, 2.9669170802639377, 0.3146567946720508, 0.25980937324704667, 0.12728125683122105, 0.2704037563695062, 0.1661177240912953, 0.2916740650130857, 0.1512718747460073, 0.08926110988062236, 0.2396953977163761, 0.1883420879922567, 0.1565695719252671, 0.2317303049588396], [0.05024853815895416, 0.017658416669996038, 0.025640332718349756, 0.02762463067718331, 0.04801241177765112, 0.014227845259161006, 0.04843861713344532, 0.0829670234252849, 0.04800916739529179, 0.03223471606390611, 0.0666219323513008, 0.11433442453703574, 0.3162548234385829, 4.97962445982041, 60.530455804640255, 42.48126937497047, 39.58525796090403, 36.755299260539395, 80.24922263237738, 51.57133479272166, 0.7500053485555034, 0.07416438206189102, 1.7304318037725266, 0.8063296036374185, 0.2429485441215577, 2.2682681823930433, 1.3444638372428956, 1.6910056096892205, 1.2635356572366532, 11.111116659256721, 101.7720522419099, 94.39623125137823, 92.7919896956413, 93.7398853609639, 94.98517513275148, 90.85924179323258, 89.88222645175073, 88.43956301289221, 84.7642864719514, 79.43403643946495, 75.93230908916843, 70.87565222094136, 67.44842636969783, 67.25367284590199, 68.65545734282463, 72.86426251934421, 79.86403803671561, 82.43062526948991, 85.66596877190375, 86.25086476725917, 83.56998751240393, 80.36727812982376, 71.06629510079661, 63.124629066836455, 64.82868709871846, 67.2843614701302, 75.41221849380001, 80.57615218623992, 76.83446207354146, 76.39435645072692, 68.69231977770406, 65.37283751272386, 68.57071061288157, 68.34397408270067, 72.11956916316863, 68.01216510034376, 67.92151912566155, 70.11618721869685, 65.52842617034912, 55.507146927618216, 51.50948685984458, 66.26086604210639, 75.88043966600972, 74.1871524626209, 75.34975082643571, 74.24624689163701, 73.25194958717593, 72.06232609287386, 64.35375475114392, 73.32211294481831, 78.53305232140326, 71.68873602344145, 62.67712193150675, 70.40924318375127, 71.29966828130907, 70.94798072691887, 63.85403694645051, 68.81643141469648, 71.29284335720924, 68.10642750032487, 73.90960554922782, 63.00154901319935, 63.883803813688225, 74.78301540497812, 65.49967519698605, 62.61493667479485, 65.76623555152648, 74.72623517436367, 70.21234804584135, 65.85897999425089, 66.19059285809918, 67.85482314325148, 69.35284691472208, 69.60605159882577, 69.53574703585717, 66.29942294090026, 66.48379787322014, 65.85344160756758, 65.6085954943011, 68.92963886260986, 65.60148423717868, 64.75979851138207, 62.54140400117444, 62.88662748952066, 60.50484272741503, 57.1593669153029, 58.58644677746681, 58.918400887520086, 62.86264219591695, 63.59550176128265, 66.26664761574038, 61.853392816359005, 62.32544222185689, 57.9325209894488, 54.887941960365545, 52.01150709582914, 55.75831590160247, 62.39134588549214, 66.04788134174963, 70.41099256084811, 72.06350280392554, 70.24357795715332, 71.22264862060547, 74.11409439579134, 72.60167552578834, 74.1237198921942, 70.77674573467624, 74.96769628217145, 73.54318557247039, 81.22448075202205, 69.24762541247954, 83.03058316630703, 70.55684981807586, 85.5239946611466, 45.539129549457186, 0.258689996215605, 0.14339243061840534, 0.028100287008489815, 0.08806500148268477, 0.39914084838763364, 0.6594666874697132, 0.9044054054444837, 4.482857258089127, 0.6184565912811988, 0.04637997417199997, 0.31535650873857163, 28.054886018076253, 57.99880512299077, 40.36390727566135, 36.165190435224964, 24.80910901100405, 42.708127498626716, 38.3403015905811, 0.5694189355258019, 0.10070138430643467, 0.0790462160723344, 0.03123978043966476, 0.014851474345872, 0.012097876639135424, 0.15374327438973612, 0.025913523502587795, 0.043798843924436844, 0.06386280923541035, 0.010555412229751388, 0.028165483006065892, 0.031235331384044503, 0.02761506798466848, 0.05410774438191326, 0.03636779105891624, 0.04567288650920795, 0.0458832772358531, 0.09291159544861124, 0.02593940769832942, 0.04470229907442005, 0.04632331047868056, 0.05391990345331931, 0.03619316131657651, 0.12509851145648188, 0.45746609448425235, 7.602239808728618, 71.27787559263169, 51.35416884576121, 39.32785241834579, 32.179689714985514, 94.2833532825593, 59.76829221171718, 0.7981026160620874, 0.01954112753963038, 2.997245581880693, 1.216115672742167, 0.6679709375865999, 2.547403165409642, 1.026180412980818, 1.801555284088658, 0.9964106039654825, 16.06845715353566, 111.62909400078559, 94.41039100770028, 95.38023625650715, 98.62591912669521, 98.44779645243, 92.92061990307224, 95.08652133326378, 94.98457108774494, 88.79518078219506, 84.72633361816406, 79.63506575553649, 75.23491167253064, 72.30707414688604, 69.78837120917537, 73.78109301290205, 75.04809702596357, 82.64317850912772, 86.8466414174726, 90.44712620396768, 90.71580856077134, 85.34562879993071, 83.19646804563462, 73.84224276388846, 67.21736738758703, 68.33065371359548, 70.64297722231957, 79.42450507994621, 82.5020202513664, 81.73741694419616, 79.16195731009208, 73.72853325259301, 71.1742465726791, 72.98974698589694, 69.99264040300923, 76.7219606522591, 71.43022829486479, 71.8382175507084, 73.22206897120323, 72.08143588035338, 61.926207696237874, 61.21046535430416, 72.59181468717514, 78.92762707125756, 77.64333325047647, 78.6111153325727, 76.11077693200882, 74.01095959448045, 74.05798096810618, 64.95863522252729, 77.53656633438604, 80.93879099815123, 71.39841002802696, 65.69748816951629, 73.07864358348232, 73.63903261000111, 74.0169765103248, 64.78172456064533, 69.33405091685634, 74.01821597929924, 72.7869761374689, 74.85064491148918, 64.96957471293788, 62.083628100733605, 76.27598716366676, 71.12549935617756, 65.7893265447309, 65.84300025816887, 75.23797112126505, 75.33697958915465, 67.72442786924302, 68.7987179909983, 70.9612226486206, 73.88864440302696, 71.65924764448597, 70.91022399164015, 69.62547517591908, 71.22537074550506, 67.23920714470648, 66.83530499858242, 68.86315468818911, 70.03900281844601, 69.25231656720563, 66.9050290507655, 64.49639566483037, 62.79125898115097, 60.17915264252694, 63.823618965764204, 62.14098491976338, 65.19451871995004, 65.93789808211788, 67.52594809378347, 63.73204338935114, 63.58357383358864, 60.21744282014909, 58.49451818773824, 56.614702670804924, 60.399028947276456, 66.27532389856154, 69.89796223178988, 73.0663194964009, 74.43461479679232, 72.87966174464073, 72.50528720117384, 77.36215422230383, 74.81333532641011, 76.24958961240708, 74.26455651560138, 79.10523199266004, 77.3813424571868, 83.07816151649722, 75.8876411376461, 85.7965523196805, 78.27863170254615, 90.47944653418757, 54.421933004933024, 0.6372347546200599, 0.0887966997200443, 0.11628491503577079, 0.31702933833003044, 1.0488827238159797, 1.2050971220577917, 1.8513062596321108, 4.359835549708336, 1.999657653993176, 0.09473410329871601, 0.23594326760259368, 28.488235358268987, 71.26172327226209, 32.851807455862726, 35.191505186019405, 42.76260137557984, 46.30749440962269, 49.91723206735427, 0.9685671077139917, 0.03780543931850022, 0.0537963028276159, 0.08703732517577949, 0.0378984117489909, 0.03766397735284221, 0.03548549525740166, 0.037785394627961426, 0.005298795079016277, 0.03315510941789516, 0.017350037552175984, 0.017233157432788325, 0.028479598207218994, 0.130779160667331, 0.21688551281488713, 0.14032950384482262, 0.1013538154262689, 0.1437594939864451, 0.2153893890640428, 0.1801776591568224, 0.19095815567960664, 0.187850397440695, 0.15222741621396235, 0.2543418190532154, 0.30608941891020347, 0.6838379055261613, 9.126717025233853, 86.61706509128695, 58.35877280081473, 50.21405743014429, 55.650003571664136, 100.1441038808515, 74.14107245783653, 1.0443370645084689, 0.3410811590090875, 3.8609497777877317, 3.205752161241347, 0.48327057111647825, 6.4637287201419955, 4.570210893307963, 3.504213397541354, 2.331280568915029, 17.193605707537746, 116.33629906562068, 99.01355912608486, 100.86654955340971, 102.6054931456043, 102.32680874486124, 97.51297012452157, 99.08375386268862, 97.20651534295853, 92.97477214567124, 89.67940853488061, 83.4453816567698, 79.49372706874725, 77.54671742839199, 76.20671026168331, 78.09059327648532, 78.29437609641784, 87.34377045785227, 89.04505145165228, 93.85143756866456, 94.54855257464995, 89.49907364383822, 86.00870547756072, 78.311155996015, 69.49621738926058, 71.10988047815138, 72.97721109082623, 84.3797843686996, 87.73376387934532, 86.93975064062303, 82.47475977866881, 76.52533223552089, 72.38244641211726, 78.08680426689887, 74.67096113389539, 81.11164200690486, 76.0777662646386, 77.02486961118638, 82.58533923856675, 83.63544402583953, 71.61437572971468, 69.97470732658141, 77.64116025740101, 83.63957035926082, 81.24483000847601, 82.18926614330661, 81.11742358053885, 77.0786766852102, 77.99182799554642, 65.23484460769161, 77.43032501589867, 84.04559843001827, 77.81798070476901, 67.54875275396532, 75.31613611405896, 76.06308091071345, 77.01536963062902, 66.8847974654167, 72.4137939945344, 79.2661040829074, 75.00942245606454, 77.33613321858068, 65.64780742891374, 66.7629058899418, 79.3742516732985, 72.09476409419891, 68.70596178116338, 70.9458940259872, 79.28837530074581, 75.19030647893106, 71.78683450145107, 71.67761218163275, 74.63687573709797, 77.714979264044, 76.6484397457492, 74.3168495547387, 73.15964837228098, 73.5093355178833, 72.59538404403195, 71.68650811718356, 74.32587100613502, 73.55205797380017, 70.82364943719679, 69.67045691705519, 68.84348792414512, 66.99560442278462, 64.7799006585152, 65.44213794892835, 65.18164942341467, 70.99775560440557, 70.90736066141437, 73.02841371105563, 68.78503676383727, 71.1552309220837, 65.020451776443, 62.9582852701987, 60.607702962813846, 64.91400257233651, 68.34047532850697, 71.2378752616144, 75.94941846786007, 76.20627095622402, 74.4190037635065, 75.37153567037275, 82.65374537437194, 78.28658626925561, 80.41240107628607, 75.84604832433885, 81.39957535651423, 79.89614655894619, 88.47433090209962, 78.73517205638271, 91.02905688747283, 81.48596163718932, 92.90970786925286, 56.079342288355676, 0.5696333788575665, 0.372874022371346, 0.5110107067852251, 0.48751635296690854, 1.3419584232953288, 1.5364840818989662, 1.9365197516256765, 9.737562441056776, 2.4698713902504217, 0.19328531628895193, 0.8633087106770085, 43.794914291751006, 73.40307066517492, 59.75560334420974, 46.582311353375836, 35.671493468746064, 55.61044646847633, 59.29156734097389, 1.4797581515965925, 0.2454408120003439, 0.1317387011142508, 0.18677490192555612, 0.11293914093966446, 0.1389607345505107, 0.2425100660372165, 0.09135324237567764, 0.17726859348195215, 0.1411883037296995, 0.13817448319206316, 0.1302375365048647, 0.10316985749429274], [0.0543211228514631, 0.031415350554931554, 0.03714924670695778, 0.06714705497987809, 0.07938608331906219, 0.05044310150908367, 0.026927502157406944, 0.09696359535859478, 0.07483958131483487, 0.04811097281954942, 0.01593053312746868, 0.17699732174796445, 0.4815755249752153, 22.170612965860677, 61.4669216832807, 34.752289941233975, 41.486815175702496, 36.40287037818663, 90.06090610258042, 19.89518915453265, 0.15730389784420692, 0.13599543802199826, 0.7311989931810288, 0.9632469028715165, 0.42384133103393745, 1.0748334925982261, 0.4141004005026433, 0.4112995830514739, 1.949792071696251, 81.18556299517232, 98.35341638134372, 96.5804030818324, 97.59506533222815, 89.64034172796434, 93.78329815403109, 91.70183750890916, 92.76975770150462, 87.66976648761381, 85.48476311468309, 81.89831256866455, 72.66162503150203, 66.60053545428862, 64.47621899266397, 62.52576943366759, 67.55571888339135, 73.01256733555948, 79.30674768263295, 84.81242179870605, 86.75532863986108, 82.87350008564611, 82.06179695744669, 75.00317019800987, 67.58564656780612, 62.392302943814194, 62.89027529378092, 66.28719299070298, 74.46015727135443, 80.31853875806256, 80.08719736529936, 78.36704192623016, 74.470731981339, 70.64342437251922, 68.04537973096295, 70.81285507448258, 70.68061628649312, 73.05448178322085, 69.49505636768957, 62.796487500590665, 57.275614200099824, 51.601588033860736, 60.256011486053474, 77.39970699433358, 75.65379727271296, 74.77449601696384, 73.74822355085804, 70.9330992544851, 74.0737488961989, 66.74250172030541, 74.66281829341766, 79.12084302594586, 66.31202943863408, 66.75812844307193, 74.05713373614897, 73.29918276879096, 75.10959979026549, 71.7907411821427, 63.18368819452102, 66.98004830268123, 61.96735728171564, 64.31937517658358, 64.5433032897211, 64.5080529489825, 61.144243978684955, 61.41014537503643, 72.5695748482981, 70.64298506705993, 61.796691033148, 59.73518740746283, 68.76248313534644, 70.48777687934138, 63.59704717513054, 66.25377439683484, 68.24769558445101, 69.50000639884703, 66.95325066966396, 68.24804075302617, 64.55591763219526, 65.27275431540706, 63.14521758787094, 66.71765742763397, 67.57925310442525, 64.42058017176967, 64.75824525279384, 63.026542355937345, 60.35905215048022, 59.0777079520687, 56.813488391137895, 56.1788292854063, 55.53254035211379, 55.504722902851725, 57.95103457666213, 54.609571349236276, 56.64125319450133, 58.54087668080484, 52.47974395751954, 53.210720785202525, 57.85592102235364, 64.71076496185796, 67.04799159880608, 70.22340128498693, 73.07084591157975, 70.46530169825401, 74.29288387298584, 72.17191711548837, 74.33621821864959, 71.670834325975, 72.74261413082, 69.36077794721051, 73.5409890451739, 70.01573531858384, 82.41488087561824, 70.50213275417205, 78.71527779486873, 71.81378902927523, 94.19384479522706, 39.64579974451373, 0.10769212047659582, 0.40117095074345993, 0.4236297069057342, 0.5466740914890843, 0.7506679226794551, 0.8946307364010042, 2.0641583348474195, 0.8063783881164367, 0.4212379497626136, 0.100901999751166, 9.819444860181502, 53.66193848271524, 46.41223738270421, 38.95424665943269, 27.181954691486975, 38.917372457442745, 51.93924919251473, 2.860169776024357, 0.09788039576021895, 0.08119697727623486, 0.013217002776781879, 0.11363800464858932, 0.05913384040937789, 0.0635395584357602, 0.05405846960662354, 0.06700443239101479, 0.0540407078580991, 0.08894342087930249, 0.0504095315362417, 0.026574534807173956, 0.023798663094038927, 0.01691816697618173, 0.032983160983290405, 0.06741697839911907, 0.08545101755448888, 0.022335086588657672, 0.059692257219144416, 0.04306861274545232, 0.0655983163103942, 0.022112338863793882, 0.062396444169984716, 0.18403285873993752, 0.40080157378988884, 28.86509080086985, 73.67255318549373, 41.515432788479714, 49.60126946049352, 39.142524350074034, 103.8052128207299, 24.677121254705614, 0.24760084286812814, 0.03618746162241986, 2.4789543738288264, 2.017456511816671, 0.7842835543617126, 2.2156640502714344, 0.38842058169745636, 0.14278001993173553, 5.094337607583692, 90.55564249715498, 98.00089728447699, 100.71805646342617, 99.85285220607635, 93.32183130325811, 94.74808354531565, 95.31794901817076, 95.67584176217356, 91.28981605652841, 90.3706713645689, 85.0997511033089, 74.97225407631167, 70.53387257360643, 66.8775567700786, 67.01176458789458, 72.25292190428704, 76.63947320753529, 83.38687558327952, 87.88789733763664, 89.68863394952591, 87.86360217678933, 82.48252607161, 79.46509376648935, 70.75155627342963, 66.72882049314438, 66.88349523851949, 70.37041956378569, 77.83243856122418, 81.82070455243512, 82.32524687244047, 81.24848565747662, 78.2887984860328, 74.55092091714182, 70.63570514802011, 74.70632522336899, 73.7829992848058, 76.82305582108037, 71.71055224633986, 65.58021714610439, 63.39587273136262, 61.61300643797844, 67.01454947071691, 81.59233631626253, 78.60493367718112, 79.98243870273714, 75.75719095045521, 72.95846216140255, 75.54965834463798, 67.65173850520965, 78.46282620583811, 78.31220719122118, 68.50337136176326, 71.21881254257696, 78.28984183649864, 76.45990710104667, 77.78447581875709, 73.22899587692754, 66.66985157997378, 69.40296696078393, 64.10353499074137, 65.0157057085345, 65.58343741201585, 64.46104334246728, 63.04636209241806, 60.155175193663574, 74.14752083439981, 76.71356678009033, 66.60380671101233, 63.61940076274257, 69.67373601851925, 73.74722726883428, 66.7100009610576, 69.45507957089332, 69.30331522418608, 72.42526300491826, 69.8565733817316, 71.85805689903998, 67.55489518565517, 70.0504247603878, 65.2648703513607, 66.55265900396532, 70.84016261562225, 67.08333999879899, 68.51442460090884, 65.33056220700665, 63.37100882684032, 61.876158252839126, 59.35897719475531, 59.620046231054495, 58.205686615359404, 61.023497735300374, 60.00591331912626, 58.0135924585404, 60.45840578694498, 60.4129219824268, 56.681845803414625, 58.05949987903718, 61.54915417394331, 67.76684438028644, 70.66138882790843, 72.95838371399911, 76.01690676904495, 74.55322727080315, 76.82783326795025, 74.03844756464805, 79.21142624270531, 74.525817748039, 74.87234346328243, 73.63302353889712, 76.49385913725823, 74.75347211284023, 83.33415108342325, 75.07354536364156, 83.68500709533691, 77.0987670652328, 97.50456056287213, 50.78983391484907, 0.31471737690510293, 0.44070415198802954, 0.0939057247653123, 1.583281635276733, 2.491993558022284, 1.843319701090936, 1.8837077338849346, 1.660217700466033, 0.8151819028200642, 0.09814302602242078, 9.5571598891289, 59.873701987728, 50.2096918321425, 26.51874073090092, 37.30924775523525, 48.17822571723692, 61.0298127512778, 4.66327500920142, 0.16617777006280038, 0.014907474415526997, 0.05194926101173605, 0.05256753227102661, 0.0023751050250739943, 0.08473032800060126, 0.04980026181006143, 0.011671222164295616, 0.043887978254426877, 0.07061551805705794, 0.03484620637590847, 0.009451456548225497, 0.12371771458175876, 0.11468159260168193, 0.15885617583990097, 0.10811568282905126, 0.1709124385829895, 0.16089407697079644, 0.11403960326025564, 0.2496593057989113, 0.24420387111604216, 0.1005128960335447, 0.1303290074030238, 0.3401455817924392, 0.6493804964327043, 34.661530217816754, 88.21164977165961, 49.141096991877404, 59.855553180940696, 55.028303976981874, 116.93218554219892, 32.73794497213056, 0.418613026098859, 0.3331136607354687, 2.934478588642613, 5.247479196517698, 1.0732553514742083, 3.794772038536687, 2.746449723359077, 1.461714758507667, 5.903693197234984, 95.83636868384578, 101.32759278820407, 107.84038251446141, 105.14349414456277, 101.02714707774501, 100.6360867715651, 101.76242674550703, 98.65803549366613, 95.70431816962459, 93.54549269522391, 90.72624991017004, 79.15542264138499, 74.0100888283022, 71.86945530676073, 70.18555041282409, 74.86302391175302, 81.14939874218356, 87.19464978864117, 91.88039948863369, 94.08092760270642, 89.84608573298301, 89.02475710838073, 82.79743748326456, 73.82367426349272, 72.11966330005278, 71.0574697679089, 73.57089319536763, 80.9768929020051, 85.5680742571431, 85.91811441606092, 84.70894182882002, 80.45204839398785, 77.76374217002623, 73.20947031820975, 78.32743383223011, 78.11403336063509, 82.91219034502583, 79.46583117208174, 77.84495092207386, 74.83756772933468, 70.07163693827968, 72.28080211147186, 87.58578854222452, 81.56979053251206, 83.87745426547143, 79.99536683482509, 74.2370371664724, 79.93269520421183, 69.69927064834103, 79.4108630764869, 82.90203140627953, 71.55474785835513, 74.22888648125434, 81.08044347455426, 80.19765130935177, 81.97523809248402, 77.02858801810973, 67.20891860223585, 71.39471515532463, 68.09880241270989, 67.52828582640618, 67.39183441285165, 68.03464028143114, 63.2271166770689, 63.360692993287124, 80.29716968536377, 78.34502174008277, 66.92278169816541, 67.36332662643926, 75.34495769008514, 74.36030941624796, 67.23601433538622, 70.3519687344951, 74.01142243416079, 75.2405285066174, 73.46898217355051, 74.66833314587994, 69.82946195910054, 72.53214759211387, 69.58413339430287, 69.86656758093065, 73.44806809579173, 71.14473465950259, 71.82692112461214, 69.72981806724303, 68.10780817462553, 65.00477798523443, 62.54445952753868, 63.37999497690509, 62.32707785021875, 63.489444794193396, 62.87675096142677, 60.38072324568226, 63.7748089913399, 65.17332223153883, 59.62780860162551, 59.845425621155776, 64.2408493257338, 72.68817163282826, 73.22681503911173, 75.65014162371236, 78.47220067054995, 76.69267623655259, 81.1896893285936, 78.89883687419277, 81.74497927388838, 78.22032174756451, 79.48296408499442, 76.15035364704748, 80.29531832664244, 76.968842475645, 87.29479574388074, 76.6827683294973, 88.37909575431578, 80.65318753642421, 102.85395960653983, 50.31166953425254, 0.4748151667656437, 1.2974072848596883, 1.4785113281780675, 1.5983504008862282, 4.3857276055120655, 4.770276777205929, 5.8248815036589106, 3.4323077720980493, 0.9536519886985902, 0.27106295970659106, 18.454124081519343, 70.267425967801, 63.04020004887735, 55.20490084925006, 37.80504711212651, 53.9559671955724, 71.95808518317439, 5.500840285132009, 0.3127817485120989, 0.16450215191129716, 0.1451899333586616, 0.2976910421444524, 0.2630822540771577, 0.2760898754481347, 0.2582079124066138, 0.16601761172135032, 0.16642486406189783, 0.19642863632930865, 0.10437079990703253, 0.08318750352989282], [0.014623850471370164, 0.0060297301012812365, 0.08347990396883219, 0.0394469550660541, 0.0040032554111788955, 0.025622685883013953, 0.06545081374145324, 0.035352904589906815, 0.06277787168660472, 0.12283014043444589, 0.037440999801601135, 0.046414559211341605, 0.08779992740000449, 35.3222809299346, 59.35930275147962, 43.380394289570475, 28.602317494730798, 41.92594412834414, 83.3350924522646, 5.42221833621302, 0.02065136131169575, 0.8025399198935879, 3.31759903700121, 1.7359359922908968, 1.366722307378246, 0.8924292448547579, 0.2976389481656013, 0.35634935262703127, 31.009938909161477, 106.11089967912244, 92.32092872742685, 97.24336208835726, 87.16345910103091, 92.70436394599177, 87.35197605625277, 93.62281830080094, 88.91573875181138, 92.42111390636813, 85.54929394875803, 81.23837378717239, 71.60037286819951, 65.56205264983639, 62.25588683159121, 68.35281510506907, 68.07853944839971, 75.44281298114409, 81.02590683967837, 83.03137548508184, 83.76715721622591, 83.4301628605012, 78.07881832122803, 72.97380647351666, 67.00493966379474, 64.08454679673719, 60.69159853842951, 69.57009130908598, 71.40801983494913, 80.62175366186327, 79.76454319492464, 80.18772771281581, 76.12663899698566, 73.66831702570762, 69.16870732461253, 71.95905008623677, 72.87917537073936, 70.87231820629489, 66.86924919005364, 57.07822876591837, 50.80696290539157, 57.79528902422998, 70.92623510668355, 74.27346814063289, 73.39883450538882, 75.27950902138987, 71.47567287568124, 75.34178057024556, 65.74569802130422, 74.9536620416949, 76.88881827938941, 65.99205032471689, 65.75996368162095, 73.60661029815674, 74.59995838903612, 68.11847702149423, 63.671450614929206, 59.65567704169982, 59.35013225001674, 61.79272159453362, 61.23752970849315, 60.20626798752816, 62.74109971138739, 61.357487555473085, 60.541693395183934, 59.5481413410556, 56.51215622501989, 66.24841643917945, 70.12439281709733, 69.20970393765357, 58.66893814456079, 66.20887110310217, 68.18986415863037, 69.19199835869574, 64.44480080758372, 64.25726836727512, 68.89293332253733, 67.572828262083, 66.06146058728619, 65.98950078410488, 60.03452308716313, 63.2583858120826, 66.42915925671979, 65.62441049083587, 65.73132645699286, 63.25221200143138, 59.55454657154699, 59.23728958252938, 57.45878888714699, 55.432072762520086, 55.78945952077066, 56.06472753709363, 58.40595499161751, 59.48990983347739, 59.1865498019803, 55.51501912455405, 52.153124270900605, 54.23645980896489, 56.034556665728175, 64.10882626810383, 68.0551072089903, 70.47643338480304, 71.4927508754115, 69.36539065453314, 71.50793044797837, 69.79863997428649, 69.18611480343726, 69.73243821051814, 65.53913816328972, 67.49739323892902, 66.89453278818439, 69.82210359265729, 66.81038225850752, 76.09192602096066, 72.95828173237463, 76.85733733638641, 71.20098929251395, 88.24380536233225, 24.222342045076434, 0.8405710372232622, 0.6132832914590836, 1.7651895193323013, 0.753258464317168, 2.947746986343015, 1.374511766818262, 1.9793752004061977, 0.15724369865511695, 0.19839374378563898, 1.829086522902212, 36.34135192440402, 58.83784717129123, 42.237898072888775, 49.505626386211766, 43.74206427604922, 51.9123338883923, 4.854427306882797, 0.20967725363950576, 0.1650835513587921, 0.05977412903561227, 0.04896557071216164, 0.027725298460873387, 0.033624702163280985, 0.02331084894737409, 0.07290216793696727, 0.07734226032851205, 0.03582864902132461, 0.04770404606636974, 0.018665529261793823, 0.004681728492986652, 0.004428208931424325, 0.027163284868302367, 0.02780596560408031, 0.07433116706388612, 0.052109331253074834, 0.08669630879716528, 0.035283680885068835, 0.008738824324081502, 0.023950413620520025, 0.03567829660530533, 0.10792783807001768, 0.008244191037280666, 42.62771891009423, 68.57742571061658, 56.45645072383266, 32.72974917965551, 49.01059973624445, 99.7118429983816, 6.932915285710366, 0.01625487272958121, 1.8865677546108923, 3.3227370967788086, 2.0103705049522462, 2.6582677325894757, 1.021275427793303, 0.10577680107446448, 0.490326669908339, 36.08879835374894, 111.90669582736109, 96.99500545378655, 102.448833680922, 91.34960082269485, 96.93111004367952, 92.7011005340084, 98.21038323064005, 94.32664840452134, 94.21046780001734, 87.71942369399532, 85.22697710221814, 73.63896985207835, 69.91384783098775, 65.19178482793993, 73.49284587367889, 70.5505661810598, 79.37131774040961, 83.02409556604202, 84.35321423315233, 86.24871530840474, 88.57907387518114, 83.87021357013334, 74.29415472092168, 70.7666495538527, 67.34869618569651, 64.9488724431684, 72.09023767902006, 76.20262315196376, 83.86585973924207, 80.90410155634727, 80.394303260311, 80.0755165469262, 76.77860752228769, 71.90295234803231, 74.8714413181428, 75.69496647004159, 74.92507580787905, 69.50095561242873, 63.348910193289484, 59.562528594847656, 66.52035436322613, 75.70959691078433, 78.51730792753159, 76.85687449670608, 76.33031199055334, 74.89787809310421, 77.21654799676712, 66.55054876881262, 78.93257710241502, 77.09411513420844, 67.929701189841, 70.07669679580196, 77.44981135091474, 77.09487607402187, 66.98384515700802, 63.65845188017815, 59.88657128426337, 59.74984530479678, 64.81995198034471, 62.22202108752344, 62.23471387740105, 63.01742284528671, 63.84327004032751, 61.992079980911754, 62.044369097678896, 58.32378525887766, 67.99126671206567, 69.57960697912401, 73.75281272395965, 63.507864244522594, 67.86816704657771, 72.06025508142287, 71.82466968413323, 68.79122626396918, 66.87550929284865, 69.59928943264869, 68.78262842855146, 68.20242358792213, 69.46466584359446, 65.02854362610849, 65.68598778017106, 68.98669365913638, 69.37333737650226, 70.91511126487487, 65.66226136299872, 62.98914255634431, 60.9658428161375, 59.83258770358179, 60.855016246918716, 59.82012241117416, 59.62867544543359, 62.21982456022694, 63.41118958688552, 62.38712541518673, 58.55735848026892, 56.26752191974271, 58.500511569361535, 60.34756745061567, 67.99110981725877, 72.63941657158637, 73.53480738978233, 73.63722831972184, 71.99196661672285, 75.70861631824125, 72.6518661745133, 71.20008714737432, 72.30505020387712, 67.68107783409857, 69.4729341999177, 70.10267073108305, 72.68080542164465, 73.32157950247489, 79.88162594456827, 77.14483922527683, 80.89590380268713, 77.64929525313839, 92.1111446811307, 33.14185496299498, 0.4331236506902403, 0.5457085142693212, 3.4964851025612127, 2.8778702068713407, 5.394401867543498, 3.377023190259934, 3.776077041702886, 1.207717142758831, 0.3330331295728684, 1.836585359227273, 37.64195888273178, 71.76664998454433, 30.775549834774388, 48.64494854404081, 53.14373454739971, 59.28255373431791, 7.72141122048901, 0.25658138516929846, 0.16076532823424186, 0.10247530686038156, 0.0506959603198113, 0.017860999045472954, 0.04763487215724684, 0.019975131670493754, 0.0491596054616234, 0.045258616803274046, 0.03748262518896692, 0.09609299005880471, 0.03295203483092689, 0.13969124535158758, 0.12775600151789765, 0.11932278307335031, 0.14510808452483148, 0.18660080078388416, 0.15637616536790327, 0.15674949533516364, 0.13779834934299992, 0.2021474520405454, 0.14729676708098383, 0.13024559574982814, 0.14702108268055225, 0.12743463529454124, 50.38704179948377, 81.8503890498992, 59.702200274313654, 40.71718731234151, 59.276215184119444, 113.70496919078212, 10.947731310321439, 0.09268078081790479, 2.3409717650182786, 8.872776896722856, 3.901501201814221, 4.631206200968835, 5.986035023966144, 0.91618710227551, 0.5950426766949316, 39.61348333666402, 116.02598467180806, 103.2909430226972, 106.51025972058697, 94.86700980894028, 100.61502364373978, 96.41303554657968, 103.58053945725965, 99.15991844669466, 100.09396814530896, 92.11979742973082, 89.9024501923592, 75.8980275738624, 75.17480527201008, 69.675414792953, 77.76343622515279, 75.55118022426483, 82.49381465296592, 88.50251705415788, 88.16393021614321, 90.85939868803948, 92.46390696494811, 87.06624707868023, 78.9323417602047, 74.31489621439289, 69.5560178449077, 66.57160405189761, 79.03120117802774, 79.87706030568769, 89.64168317856328, 85.34594258954449, 85.11443645723405, 83.19348704430365, 80.67407023522162, 73.79719042008924, 80.36652503475067, 78.59507283856793, 78.51075756934382, 79.26327997638334, 72.29100027391988, 66.90401707926105, 70.84189630323841, 79.66459335819368, 81.00294528468963, 79.3407154083252, 81.85529985735494, 78.50860811048939, 81.08863338347405, 67.62096358883765, 79.6267032623291, 81.51180221188454, 74.04302889300932, 73.55442708538425, 79.4498828149611, 80.47875189012098, 72.34182634661275, 66.13089438407653, 61.7298734572626, 59.81419963221396, 65.31839501473212, 63.629434185643355, 62.57608559823806, 64.38296464181715, 64.972194856213, 62.857315617222945, 60.330250186304895, 59.24094130915981, 73.31475457837506, 75.45662756889098, 73.96415787358438, 64.81126393041303, 72.43503755138767, 74.74302291870117, 74.92051016899848, 70.94444274902344, 68.54490141714773, 75.31690489861273, 72.07211632882395, 72.96951540054815, 73.84953052766862, 66.9571259713942, 68.90637136274769, 71.77127053660732, 73.99750586478942, 74.37741095019926, 69.65100980574086, 66.62094746866535, 65.03921247297718, 61.97530792605493, 65.01997716965215, 62.64002023204681, 62.72011110859533, 65.4352031984637, 67.3241735273792, 65.93167720302459, 61.8253400248866, 57.198610228876916, 60.833929584872344, 64.06785318928381, 71.99325315413937, 74.91450109789449, 77.56870623557799, 76.80712315344041, 75.13057662594703, 78.98774131651848, 76.88411927992298, 73.49129261509066, 75.90537025082496, 69.6401369956232, 74.18409301388648, 74.22537203757994, 75.45218744585591, 76.26048595674577, 81.80052788026872, 81.93388062138712, 84.8145555680798, 80.21417233251756, 95.49703659549837, 31.684151195710708, 1.76994392227742, 2.6922496768736073, 5.832203588178081, 6.128521494327053, 9.79156857536685, 4.645609634537851, 4.1112327864093166, 1.1182649169237384, 0.4106289190390418, 3.245135944697165, 55.244846267084924, 76.64136378995835, 59.272147686250754, 64.49668592022311, 57.592753518012266, 71.17932211968207, 9.875768134670874, 0.39101314580728935, 0.24905850900517357, 0.3003700516156612, 0.20723773857518551, 0.24445278840439938, 0.1024847450636087, 0.06943205777075022, 0.16724791828422778, 0.2636248588321671, 0.12683085075789882, 0.11336234323079548, 0.11576509373562953], [0.07849037331799347, 0.024229336657651493, 0.02951112219072398, 0.018840028769186428, 0.03571853154308854, 0.02130197871836924, 0.035588430661347606, 0.051062361021796544, 0.05331812223659889, 0.04066116612164244, 0.049923027399927385, 0.02946378561788269, 0.48777397301408554, 49.51568726570376, 44.6555450654799, 27.34319352334546, 31.567676413443785, 52.46823964580413, 55.9482252982355, 1.276397476753881, 0.08839059651138322, 0.11999732349067928, 3.686196419500536, 0.5970269057058519, 0.919543118967164, 1.495883750819391, 0.09078984599440329, 1.0667009483422003, 70.66690368037071, 101.94065924613707, 95.17884608237975, 90.75921350909819, 90.5478762042138, 85.59475421905519, 87.45292217500749, 89.96510613349177, 89.41777075490644, 86.92974075194329, 85.42926157674482, 79.193846179593, 70.36009588549214, 66.49542377841088, 66.19275800643429, 65.84840528426632, 69.50235197621008, 74.40026267882317, 79.34401019926995, 82.55586654909196, 85.18660022366433, 80.22178957539221, 77.13415468892744, 71.50808734278526, 62.956084820532034, 61.75560420559299, 61.708347489756925, 63.095929084285615, 68.13006370298325, 75.17384036894768, 77.09346402075984, 77.26860569369408, 78.13298625330772, 73.87012297107329, 69.2587806332496, 68.32292664435603, 69.67026079854658, 67.46508859818982, 60.70025520939981, 57.28775785815332, 54.85216209965368, 69.24538181674096, 74.78021483267509, 76.52484586161953, 71.5992118466285, 69.18199631475633, 75.47791034944596, 66.61209075681626, 70.91262448218562, 73.05674891318046, 67.89812610995385, 68.95430272625339, 71.68801430732974, 73.49941192134735, 63.83341312408448, 61.773294095070135, 61.87305173566265, 62.6744076513475, 65.50419768979474, 65.39806227530202, 66.73507275119906, 65.59011328604915, 66.77543394027218, 70.70796305133452, 68.9880351097353, 70.31145065061509, 65.90476189890217, 59.138936150458555, 58.924406036253906, 67.6430465329078, 69.26158905029297, 64.9513239245261, 61.26489216281522, 63.80734505191926, 67.20881662061139, 66.94560204782795, 65.24149694750386, 67.70111330093877, 65.95000251646965, 63.70557131305818, 60.845904581008426, 64.56504890995642, 64.68111968809559, 65.64059026779668, 66.35774074062225, 63.12312679906046, 61.0355511788399, 59.77085744180987, 58.569541362024125, 57.21778669664937, 54.93699119937036, 57.922185544044744, 61.05173095580071, 59.34112256573093, 57.62335977246685, 55.69797023650139, 53.36552889116349, 54.085409333628995, 59.905241766283595, 64.73533861098751, 69.46974923533779, 67.3220476027458, 68.64405893510389, 70.91116536048152, 72.16620614451747, 69.66360845873433, 69.79028532581945, 62.58647595682452, 66.15751943280621, 64.53095174604847, 67.3243147327054, 63.92240778092415, 72.42456482302758, 67.09495021450904, 74.25240501280754, 73.35178959754207, 78.29861225620394, 73.05585461278116, 79.38736023441439, 5.552783743027718, 0.5796709079896251, 1.5178485334880891, 1.5523759323743083, 0.8630775359849777, 1.090030102960525, 0.7763488446512531, 0.9687659841391348, 0.056948421387782985, 0.07255118475445817, 16.711062000643825, 53.49567705585111, 42.83372571391445, 37.12521014675018, 36.962910313760084, 51.56083460777037, 7.058033991244532, 0.27171597305324774, 0.20108375427944047, 0.05095502444272561, 0.09546017845071132, 0.03419805385713135, 0.028522321015536308, 0.06151222931821981, 0.04634892462842888, 0.0143859485697542, 0.04960839125898577, 0.022365057863475337, 0.029930223996240287, 0.028929433545037627, 0.010443572011295586, 0.049671915269667105, 0.052375611924235864, 0.020746723936510184, 0.004556023519516232, 0.0029862447239969287, 0.03357801676517533, 0.02106521924537036, 0.03332685100876036, 0.03225314047848506, 0.0873348354211738, 0.8176016987812135, 63.33118500248079, 54.160357982881614, 43.446356788758315, 29.2580867967298, 58.32613868098105, 68.05493462470271, 1.361984329358224, 0.08525731222283456, 1.2248458881531994, 2.2741720849467866, 2.245567955317036, 3.154804495073134, 1.2827332077487823, 0.14768066906159924, 1.7449845325562263, 76.72335701604044, 103.71891283219861, 98.79919375142744, 94.60090837171002, 95.67428850358533, 89.46811045369795, 90.37593518534015, 91.67589495258947, 92.6119685942127, 89.7155257194273, 87.55155409536054, 81.07541499599334, 74.82470235516949, 69.13502985431303, 69.86915634524438, 70.34634405566801, 73.45370846409952, 77.5419556710028, 81.79314597960442, 86.49542454750308, 88.33546330851894, 82.69314166038268, 79.5417211901757, 74.40355746976792, 66.75703017942368, 62.63957308184717, 65.88261619690927, 66.24120712280273, 72.8146759156258, 77.38182883108817, 80.73610644186698, 83.62899564927625, 81.44761654638475, 78.35882848308933, 72.05635624547159, 72.8599008437126, 74.66470887584072, 73.17964461541945, 69.5642234433082, 67.06338297936225, 64.16872870537543, 73.68619518895304, 77.61673958070817, 78.55984995442053, 74.95883957032235, 73.67907216472011, 78.60912276852515, 67.68733009215325, 73.2087407573577, 74.64028035440754, 70.05457462803011, 70.72540190912062, 74.47014362581315, 75.27881868423955, 66.40302058189147, 64.37904227164485, 63.63215238817277, 64.14521409619239, 69.8421625937185, 70.35189028709166, 66.99831085820352, 68.83055194731682, 70.6699788185858, 74.1937812682121, 72.07188098661362, 71.32776814122354, 68.62126996440273, 61.06782051824755, 61.23829457067675, 69.76963796923238, 72.3024457500827, 69.47345195278045, 63.71205891332319, 68.09866905212402, 71.5177599076302, 69.6257968102732, 67.26206671807074, 70.10313357076338, 68.92383375475484, 67.38248348236084, 63.64917939709079, 64.6809196472168, 67.44566502109652, 68.70997828821983, 67.20859696788173, 66.84278103613084, 64.55580780583044, 61.85047849532097, 63.24367300156624, 61.40570917437154, 58.556597540455485, 62.67607073630057, 63.11950252902124, 62.81801739046651, 58.83752945930728, 57.52344523706744, 56.73601765786448, 58.14841216610324, 62.959167803487475, 68.0062815450853, 72.00816600553452, 71.0457105021323, 73.5561764624811, 75.03429028295702, 75.52524551268547, 71.58901368418049, 73.03727042290473, 64.7605751406762, 69.43055691257601, 67.4624998338761, 71.25099166747063, 68.44564976230745, 75.76386682448849, 69.2090057557629, 77.48162177301224, 76.13071041722452, 85.6173941396898, 77.29239879115936, 86.33878077230146, 8.034309965948905, 0.3596792303987088, 0.8073208601244035, 3.172371565334259, 4.208542868014305, 2.6316669535252357, 1.7735046989494756, 1.8502181696314968, 0.18698408989416015, 0.10651241402111708, 20.547812715653453, 62.91936359097881, 42.544027297727524, 32.36193283911675, 43.552437290068596, 58.57623684790827, 9.95671702969459, 0.42595306771897506, 0.18279423246220236, 0.062143141028261, 0.0655245803476822, 0.06356362125746186, 0.04154449997229442, 0.10145998755169493, 0.04996304017221255, 0.056443485176010486, 0.02052874702419485, 0.05554933416386766, 0.05176910777546225, 0.18158358371546193, 0.153850925064856, 0.11789901632695429, 0.19773159867092488, 0.07634282202249573, 0.14031061211660986, 0.18276813950750137, 0.10815646935013995, 0.2167862124981419, 0.1025591781663318, 0.1564194493356251, 0.257385716202759, 1.23633120088808, 77.29605444015996, 64.6228293449648, 42.725476141898866, 47.644191095905924, 72.81142034838277, 81.45343734372048, 3.1490378754754222, 0.215300829299996, 1.1048697776371434, 8.458104902698148, 3.981337859745949, 4.3703808419166075, 5.613506445961614, 0.4544758081676499, 2.874605323999159, 82.66244519141414, 108.60349532096618, 103.5378013118621, 97.99700629326605, 100.28679970772036, 95.41472173506214, 96.84278611213931, 98.44349753472113, 97.5721194667201, 93.7362846251457, 90.45487680742818, 88.33825603608163, 76.70319603335473, 73.17467105004096, 74.43594840265091, 75.05015234793387, 77.35843581538047, 81.66906572157338, 85.68671811011531, 90.61745905107068, 92.81339799204181, 87.55013419735818, 84.41457579212805, 77.60970284861904, 69.9894868173907, 66.7624822739632, 67.80059245324904, 69.1724806447183, 76.24067014263522, 82.42581644365865, 85.28247864015641, 83.46430317048105, 86.24684041546237, 80.63068097637546, 74.71497012722877, 75.51368236541748, 77.37038335492535, 76.12866293999457, 70.82884265530494, 71.57570900455599, 72.1342388276131, 79.39071778328189, 81.98567944188272, 82.8213639413157, 78.71204576184674, 74.79261736715995, 82.39192716536984, 69.26610762073149, 73.63687530640634, 80.20227970615511, 74.16604226635349, 73.73378922862392, 77.87403137453141, 79.73728272222704, 67.85463486948322, 64.46018434339955, 65.16408504978304, 65.15056071742889, 69.69396760386806, 72.07211632882395, 72.73150597849201, 71.87691565482848, 69.75329737509452, 73.88065845735612, 73.80377215723838, 73.1987230239376, 70.5158688945155, 60.34655155674104, 61.560513357962336, 75.41950625758018, 77.54645070722027, 69.72860997722995, 66.5113878250122, 70.34392787564185, 72.69473768049671, 72.36941629840483, 70.77560824732628, 75.84113751688312, 73.46749167288505, 70.1231925718246, 68.95576184795749, 68.25943131600657, 70.69030454081874, 69.81775760650635, 70.78066026010822, 69.6589094592679, 68.5474274235387, 65.6381936996214, 65.64097073770338, 64.16532016569569, 62.68259363789713, 66.52717928732595, 68.28712324942312, 68.75299884426978, 63.20843442793816, 61.206178203705825, 58.92107986634778, 60.796823963042236, 67.32986880886939, 72.50320050024217, 77.3884105682373, 74.86430260442918, 75.16391677241172, 77.04456775419175, 77.71453211384436, 76.50133517480667, 78.34409606072211, 68.39145829600673, 73.68366918256207, 70.51224462447628, 75.54695975395941, 72.18692410376765, 79.50112465889224, 72.21270976528045, 82.63195268569454, 82.11403508340159, 89.75431011569115, 80.13150445876583, 90.50516159303727, 7.168759069135112, 1.9998255804661784, 8.379606508439588, 4.827652227494025, 6.627020912785684, 2.870588571794572, 2.329464511525247, 3.1570880499578293, 0.2870300706596144, 0.3214689097817867, 29.97960286755716, 73.23027456960371, 60.46634466417375, 51.028396391099506, 50.023104683045425, 71.03037403475854, 10.956790024234403, 0.4191724847882025, 0.27984487073075387, 0.23966594929656676, 0.26801552323083727, 0.12488266618381585, 0.14622870261871046, 0.15913740671690435, 0.15987790730451384, 0.12142593191275675, 0.15130401979531014, 0.10547712280024445, 0.12369013541648466], [0.04444697346057623, 0.014354285198233783, 0.061412040339482415, 0.014239461067312909, 0.026276225915118575, 0.07183404984853922, 0.027328225513619762, 0.016078796996284398, 0.048608746109229904, 0.09678202485966106, 0.045284487592476996, 0.2816923683689487, 3.3747820460027267, 61.49120899938769, 40.275748083668375, 29.353835775006203, 27.72510882346861, 69.22431084417528, 29.85769952497175, 0.3150355178982981, 0.12889836884794698, 1.9062212806555534, 2.2862787256317754, 0.8236373071708988, 2.613702252987893, 0.22465114692045798, 0.547493253984759, 10.421800305766444, 94.01640461337183, 92.37286090850831, 94.87519971786007, 88.47599398705268, 86.02811336517335, 79.41403235158613, 77.10060273447345, 75.6017787994877, 80.9159000458256, 84.04048365931358, 79.16138464404692, 75.58998031000938, 69.08378016564154, 66.9235191037578, 68.90379828791465, 71.65250901252993, 73.46381248966341, 75.76057203354375, 82.17311382293701, 83.13803257480745, 83.6355773864254, 80.66988898861794, 77.3511480516003, 68.14019910750851, 62.45193473754391, 59.30182041660432, 60.63973696001115, 60.851380209768976, 62.89370736768169, 74.27223651639878, 77.70700900785386, 81.29886457996984, 75.96665336239722, 74.95426608670142, 71.23099542433216, 69.53929285849296, 71.20764163232619, 69.61714406167307, 64.07031643775203, 60.94698406034901, 68.42768530691824, 65.17209452967491, 72.89829300295922, 72.59075564722862, 71.3048065862348, 75.63876675021264, 68.71553236438383, 75.76192917362337, 76.59558973004742, 65.56965420323034, 71.52648325889342, 72.66143675773375, 70.84056269737982, 64.37911287430795, 64.63989949995472, 67.46712038593908, 70.69152047557216, 69.47931197381789, 70.7368395405431, 68.57230309517153, 65.56316268059516, 67.81323817468459, 70.99677501186248, 67.84488385723483, 66.06646553162606, 66.16640752361667, 67.29875656866258, 68.44564976230745, 65.37976834081834, 62.43240525645595, 64.46048244353264, 70.457198081478, 68.47840939798664, 63.41584151790988, 61.66353833290839, 69.52340725929507, 64.0872218531947, 61.39245548555928, 65.32040326826035, 67.63577445860832, 64.66948986053467, 57.49574938128072, 62.362763574046475, 67.15205992421797, 63.06156127683578, 64.4824908625695, 60.93689572426581, 63.51133554212509, 59.41714594441076, 58.17031860351563, 57.84942165497811, 59.515326792194, 58.571753578801314, 58.22475325676703, 57.17709995085194, 53.69180733157743, 52.323398282451016, 54.69787174655546, 58.94481412826046, 64.24872544503981, 68.34617845473751, 69.6990353061307, 70.62412631127143, 69.90838004696754, 72.47947016069966, 68.30807655088364, 67.13354633700463, 65.25149899144327, 64.55467424085064, 61.831290260438, 64.85609269911244, 62.22786541908019, 64.30063801427042, 62.925721753028135, 67.98445747744653, 66.44712371210899, 77.20025447107132, 71.51885032653809, 88.0874518425234, 40.610416473880896, 0.1499572831897005, 2.2645063842496564, 3.014648893187123, 1.713842139128716, 4.392039679711865, 3.6702451206022695, 3.1382383646503573, 0.150140960430426, 0.10098677504086688, 7.686941431414697, 46.44267105287122, 44.17433300325948, 41.64531423199562, 37.77967722185197, 58.655790359743186, 9.773987531661987, 0.23496258312896376, 0.23040797591449755, 0.0759237336235181, 0.12404477283839258, 0.050697243517084475, 0.010524858728111272, 0.056503887378400376, 0.06916554344277229, 0.052479386194458896, 0.11846031362731611, 0.06421892137657251, 0.0334727754365773, 0.07509167020719859, 0.023511073687264038, 0.008261959489074447, 0.011497899559476684, 0.018184211540726886, 0.06059610307396901, 0.057719439087856206, 0.04204292443671054, 0.06020465512729942, 0.054755736022226276, 0.05093859568718941, 0.41695024758096666, 5.070650904409347, 73.90542430262413, 49.09858242157967, 43.32539089264409, 23.931704221233247, 80.2733922773792, 38.28603167687693, 0.18430314988138216, 0.1659569375577473, 3.509016339817355, 1.218964784376083, 1.6860510432912459, 5.117863003284701, 0.6075663756458991, 0.36921607510697463, 13.616846357622455, 98.01415489565943, 94.48158202632781, 100.43865034657141, 91.41372373027187, 89.85241643844113, 82.98615055699503, 79.89125144097113, 78.73253622362691, 84.49445878305744, 85.83077892180413, 83.15846812340521, 79.3533532850204, 74.06605320592081, 70.15289275876938, 73.34965582816832, 75.83719161248978, 77.34899074800553, 82.1350746770059, 84.66508188555318, 86.3869474780175, 85.56370473677113, 84.22008898950394, 79.24974779928885, 68.67436316705519, 64.7505417177754, 60.65024106733261, 62.99636363983155, 62.81867634865546, 66.09545184719947, 76.10006886143839, 81.22874829076952, 83.07857728773548, 79.75722405218309, 78.84426886035551, 76.03065859886908, 73.37019335839057, 74.24835712678971, 73.42055659140311, 72.11551343241047, 68.40415893062469, 75.19689606082055, 69.09426073874198, 73.39595548568234, 76.65870066611998, 74.56315871207946, 77.66095253729051, 70.27475295528289, 78.20244358431908, 76.88358583757955, 68.80827288473807, 73.56581764836466, 76.12259111096783, 73.30636855094664, 64.81437436995968, 67.73611653235652, 71.80580308360439, 73.10632767215853, 71.05172741797664, 73.57177180628624, 71.09260635991251, 68.96992160427955, 71.11647006004088, 73.87533187866211, 67.33824699155747, 66.010877701544, 69.50756872853925, 71.11193580012169, 70.33922103143507, 66.89930239031392, 65.25469964550388, 64.85689678499776, 71.9719546841037, 69.73806288934523, 68.22686779883601, 66.3335475613994, 70.56194105455953, 67.69834410759711, 65.96024774735974, 67.01108209548458, 68.94797986553561, 66.05090941152265, 59.282722396235314, 61.2579103439085, 68.51055714391893, 66.51727138027069, 67.37150084587836, 64.69717787158105, 65.61464771147698, 62.91823787073936, 60.66924495081748, 61.76215848615093, 61.37742888542914, 63.278217315673835, 60.09382540179838, 60.06146584787677, 56.34293340867566, 57.10022541784472, 57.46035391284574, 60.210712032933394, 67.21512379184847, 70.5937671661377, 72.52154934790828, 73.09118732329338, 73.28329716959308, 75.14554439052459, 70.66656635653588, 70.01065192684051, 68.4485601609753, 66.7940338196293, 64.5104181381964, 68.25025296980336, 67.04661092450543, 68.90420621441257, 67.16199136549427, 71.20896739344444, 70.4195668620448, 81.14760229664465, 77.27741533710112, 91.74918836162936, 48.39364620947069, 0.1978894740703606, 0.3814349323511124, 0.6912273444956349, 2.2372500790703684, 4.3886507518829845, 2.2934806875644194, 2.1085674099383818, 0.3042779886914838, 0.19385519377406568, 8.233910068388909, 58.467257715040645, 46.59064638999201, 34.724299907684326, 45.58851218992665, 67.24472199716877, 12.99594202349263, 0.35369430638609395, 0.2722797524784842, 0.06939045919646179, 0.13063576432966417, 0.06371059139529545, 0.021886182047667044, 0.07481613902435189, 0.03565672356935759, 0.02872103656221542, 0.022450407719119422, 0.042984040469051375, 0.015610847509496156, 0.1955734064141589, 0.1665801194406325, 0.1289459275862863, 0.14714745654454156, 0.17091492070786415, 0.21804225961527518, 0.1224092900332424, 0.25266175759175136, 0.12634518931830122, 0.35357167103117515, 0.16127462348630353, 0.5378988301081042, 6.949679986123116, 90.77019614558067, 56.837073602984034, 39.684305652495354, 42.47526422623665, 95.54408934808548, 48.869017862504535, 0.4817030326493325, 0.16653338807725138, 7.924117349809217, 5.20087702620414, 2.8480682834502193, 7.721998595422315, 1.0593178219372228, 1.7353399145987727, 16.68957917921005, 100.55387389275336, 100.57767483495898, 105.36123275756837, 95.29945896517847, 93.84032941633656, 88.44143006109422, 84.81523806048979, 83.27504096492645, 87.68861739866196, 91.56529195847051, 85.25297457172026, 84.16244583745157, 76.7529473766204, 76.57267524350074, 78.17578715662803, 77.78948860783731, 80.55596766933319, 86.15765356248426, 87.02736070079189, 89.42352094957906, 88.97158545832481, 88.27205427231328, 85.52979192426129, 72.5174779276694, 68.01741323163434, 62.39359732597106, 66.6935662300356, 66.49921278799734, 68.96827420880719, 80.66920649620795, 83.80244285829606, 88.35260406617196, 82.755154332807, 81.35142434027888, 79.59747375980501, 77.62185435141288, 75.72067368415095, 76.2908451018795, 76.00979158955236, 73.12875578480383, 78.54944782872354, 72.66203295799994, 77.78051422488305, 79.82655586734896, 77.23819163537796, 80.70030304693407, 72.71666372975996, 79.21480732579386, 82.69349467369818, 72.7469914959323, 76.97950347777336, 77.37937342736029, 74.78798112561627, 66.09971938594695, 68.76418544400123, 71.58778990468672, 75.61436176300049, 74.96589983663252, 78.07244054732784, 73.3522367477417, 69.37567510912496, 73.12641805218112, 77.30214980340774, 70.37009792943155, 68.16868335969987, 70.18629566315683, 73.45996856689453, 74.27375839602563, 69.10339986124347, 65.67278508217105, 68.97055702824747, 77.15808899171891, 73.27499743430846, 68.81914569485572, 68.58625888824463, 76.32629548349689, 69.76923004273446, 66.99896197165212, 72.6900073020689, 72.93172728630805, 69.93975900834607, 61.07027984434559, 66.0287872437508, 71.86222245616298, 71.09747009892618, 71.5623886354508, 66.50718304418749, 68.76666438195014, 67.3850408677132, 65.19347144711402, 65.18246919878068, 66.37201032330914, 67.5561503441103, 63.27305547652706, 63.739790070441465, 59.769233580558534, 59.41945622044226, 61.33331791047127, 64.56665315935689, 69.73264217376709, 73.94489119129797, 76.15108320789953, 78.46875682953866, 76.86859453878095, 79.95490366412749, 73.47439504438832, 73.06176170226067, 71.49814021202826, 70.8095367493168, 69.37215282071021, 71.92008526094499, 69.47023560923915, 70.331752838627, 70.8779271956413, 74.27560975474697, 73.39256655785346, 86.49525980795585, 83.54147188125118, 98.60762519221153, 49.63378198685185, 0.4027835658240703, 5.462121098272262, 8.268188641917321, 5.842869983565423, 12.263464889218731, 7.507582720248931, 5.967149792178985, 0.8294154487309918, 0.2456992287789622, 13.443137330393638, 69.23076706547891, 57.75247243142898, 58.07400088156424, 49.72657349801833, 79.29330179768225, 14.324947922460495, 0.5301634871190595, 0.3316267453614743, 0.18755405930982483, 0.21167438357107102, 0.15234594533760704, 0.14337752254739886, 0.13106195436369988, 0.14386121514103106, 0.14364902410776387, 0.20976471023694163, 0.23256995264560948, 0.11748917460922273], [0.032635119578410546, 0.06804717764739068, 0.04651398593259435, 0.03528358129363868, 0.02860391129469199, 0.009912581149218305, 0.0564387813961554, 0.014491419724729514, 0.10742520012201802, 0.07419984427190597, 0.10716092277077899, 0.3068557519826197, 8.672864475557882, 60.348967736767186, 34.770477971723004, 32.70511865615845, 36.1822723573254, 66.19638227647351, 12.292909141509766, 0.06663343133104425, 0.17079237728349625, 1.7751469463109972, 0.3432884421800414, 1.277566465639299, 2.862168468775288, 0.7476528457576229, 0.11917293627536106, 35.763751537569114, 98.0422547555739, 86.9484269234442, 93.05578477921026, 88.18643677619197, 88.11644600283715, 75.52258614570864, 72.88778105089742, 67.8483041640251, 71.14506413859706, 71.32897623123662, 74.16364177580803, 70.9779868587371, 70.12724830258277, 67.81257921649565, 70.28666911586639, 74.21070237313548, 77.3867396385439, 79.83822884098177, 83.98364067077637, 85.70324697802144, 82.61282720873433, 80.06784439086914, 78.56996182472476, 66.81691692721459, 61.29279982659125, 57.613863714279674, 60.08791831231887, 61.0691305898851, 61.56625963026478, 70.06242721311509, 73.31477811259609, 76.15665297354423, 76.09658579672538, 76.00671645133727, 74.43801156936154, 70.226680386451, 68.07088298182335, 72.25734633784141, 69.68841352770406, 65.81362955031857, 70.04966382057437, 68.65118980407715, 69.02419936272406, 77.57913974023636, 74.1567462490451, 69.85674596601918, 69.7997853063768, 75.20789438678374, 61.18342453433622, 69.41386330512263, 72.5947956885061, 69.37336091072329, 66.85635243692707, 68.19227249391618, 73.7300080637778, 75.50857543945312, 70.38484604127946, 68.67051924428633, 66.04224881818219, 68.2883156499555, 69.7449976398099, 66.67728054908015, 67.08316741451141, 67.0660109673777, 66.93122263877623, 66.27982677951937, 70.39029813581898, 70.53078174591064, 69.74507608721333, 66.55458096534976, 68.22984095542662, 67.02008785740023, 66.79338270618071, 69.02754906685122, 65.36493001445648, 63.249693839780754, 66.62572491553523, 67.70155260639807, 60.81700063520863, 62.415695959521884, 61.35574602311658, 57.8998907919853, 55.31406433351579, 59.753383282692205, 69.66519309628394, 64.77221281297746, 64.68820741099697, 64.31917513570478, 60.50170875364735, 57.76309420985561, 59.595229394974254, 57.4520424104506, 57.709746053141934, 56.591184139251716, 54.73533822644142, 52.549295425415046, 53.51215101057484, 53.00704386926467, 58.84065558833461, 63.79011015738211, 65.95551736893194, 68.9956445078696, 70.5545199301935, 70.2551018807196, 70.07242141231414, 68.66061133723106, 65.38435751391997, 62.37442478056877, 62.430063601463075, 61.786716445799804, 61.799926988540165, 60.93944526487782, 65.87210424484746, 64.18865042348062, 61.990899347489886, 67.55489518565517, 71.49243708579772, 77.39995018128427, 75.44287573906684, 78.44586587721302, 4.3896941023488205, 1.2602849929563462, 2.1796954254950247, 4.409654553859465, 4.620631000687999, 1.8002671532092558, 1.9172273287850043, 0.3178928113512455, 0.03384684084824497, 2.0353395780248027, 32.11934208869934, 51.71600749415737, 50.80288756278254, 26.98037036003605, 62.660436168793716, 10.342641972726392, 0.4141872135862228, 0.19155107708948274, 0.041187051007704395, 0.03730908329147966, 0.04185853473421547, 0.06995111298296722, 0.04545431779397111, 0.02460069777894645, 0.10084196910141938, 0.0555617256360429, 0.01686951464733049, 0.10847253424506034, 0.03840001547829278, 0.025570182047123392, 0.03999941554220934, 0.07558854717400766, 0.07653880263528517, 0.058015087739594524, 0.027750669377705747, 0.010553067043093185, 0.08740716178210513, 0.1445687739478965, 0.019704951611798138, 0.39259275782012176, 13.278217354128438, 70.66378147371354, 48.092765115922504, 37.081734595760224, 29.60190019299907, 81.65042661851453, 13.595549848771865, 0.047983189353779446, 0.41742451729313024, 1.6834878969577052, 1.7049094313575377, 3.668770064269343, 4.8436653037225055, 0.22899210753460086, 0.03063730782859268, 40.481092006929465, 100.70847803546538, 92.84711468604304, 96.87471420534196, 92.45363819983699, 90.90258398363667, 77.84509997214042, 75.95226610860517, 70.2133600173458, 74.07048548421552, 73.92931938171387, 77.53598582360053, 72.47369643180602, 72.38315243874827, 73.61774982944613, 73.63139183290544, 77.77993371409755, 79.96696103003718, 82.03282633135396, 87.44885075476863, 90.31282424926759, 85.03904850252214, 83.17166297666489, 81.54544045848232, 70.81790708726453, 63.76983542596141, 63.65236828404089, 64.67709925866896, 62.19632171815442, 63.92023478784869, 73.07847884393507, 79.18841761927452, 80.76337475930491, 80.74051518594065, 78.1658321811307, 79.84208060849099, 73.87396689384215, 72.1749294957807, 73.54906912772887, 73.66102926192745, 70.82815231815462, 73.13652207774501, 73.85523365389916, 73.19491832487046, 75.92562537039481, 77.62376062331661, 71.52390233932003, 72.86193263146185, 74.85244135702811, 65.88565995616298, 75.6361230727165, 73.59525895887806, 70.86489708192887, 68.17109953972601, 73.48289874292189, 75.1176171148977, 78.69928236930602, 72.00976633256482, 71.42015564826228, 68.37432538309406, 69.83918159238755, 70.93400924436509, 66.2238702466411, 66.84766830936556, 70.52106995736399, 70.74726520046111, 68.15677504385671, 72.14693946223106, 70.66972778689477, 71.20099713725429, 68.15075812801238, 72.12793950111636, 69.15016235843783, 68.336105808135, 71.10175332715436, 68.8868458040299, 66.80321216583252, 69.50484660363966, 70.39668375445952, 63.434147219504084, 65.36884846225863, 63.510484387797696, 59.130397150593424, 60.31310158391153, 62.58750754017984, 70.75083455731793, 67.4911880493164, 67.8430481879942, 67.0356047538019, 63.771545579356534, 61.7964792251587, 61.876107262026885, 60.606581164944565, 59.778380547800374, 58.30401259083902, 57.87491706109817, 55.417724732429754, 57.70556872890842, 56.72368964841289, 63.51237889259093, 66.71863802017705, 68.75639561683901, 70.70234621724775, 73.20266108359061, 71.61252437099334, 71.7770834892027, 70.32288828203755, 67.72972306897564, 66.87477188725626, 65.8751715383222, 64.55789450676211, 66.19450738353115, 67.7237924452751, 68.1990425048336, 68.12673753307712, 67.81297145351287, 70.73613351391208, 74.00955538595878, 80.80937631668584, 79.79216452567809, 86.2127628634053, 6.956145032759636, 0.6422679522825826, 1.2068832713750102, 4.350486090106349, 3.3421871498707807, 2.3812596547988156, 1.9767496638721036, 0.8238224553004388, 0.07732221946841286, 1.5975569789448094, 40.65727703032955, 59.175735827415224, 43.04430992372575, 29.175348320314964, 68.95864871240431, 13.760121714684272, 0.4494910272619417, 0.1498997193430701, 0.0367590359922859, 0.05435031846225743, 0.03596816512365495, 0.061226693027081995, 0.047873401293350805, 0.04349038245216493, 0.04178661439988402, 0.06709918980636904, 0.03352051420557884, 0.015337701732923668, 0.10770967921182033, 0.2887783139463394, 0.1997733762067172, 0.18780202664915593, 0.22957825672722634, 0.11306929927799972, 0.17431316416590445, 0.11898938160870345, 0.15813521049436063, 0.1549431366185027, 0.2947151582808264, 0.7262791152442656, 17.22327647670623, 89.03856385138728, 51.106506470711004, 43.91307569319203, 49.415145151076786, 94.10889410203504, 20.75819492340088, 0.14436635819654312, 0.5226370716287244, 5.727243413848262, 4.701332296094587, 4.703489599689361, 6.2407905151767125, 2.2171822526762566, 0.19795264568059676, 46.64980357693088, 106.4585550369755, 94.60046906625071, 101.02427590277888, 97.46408170269382, 97.2350545083323, 84.24456457937919, 79.49887321841332, 73.8955242403092, 77.9690311801049, 77.59955175461309, 81.62977141718711, 78.47172998612928, 78.75967902521934, 78.77467032401793, 77.38710049659976, 82.73693100098642, 84.276382846217, 85.98692063362368, 92.05462332694762, 92.15581263265302, 88.76789677527644, 87.82629259171026, 84.38043548214821, 73.64796776925364, 67.98568910168063, 66.5363262545678, 67.53578539817565, 65.17944112900766, 68.4218958885439, 77.24954297465663, 83.67172594993346, 84.18086528778076, 83.07698480544552, 81.61854559375395, 82.90473784169843, 78.24218503890499, 76.66325061551987, 80.10995495703914, 79.24311114895728, 73.79304055244693, 79.40074336144232, 75.9590204300419, 76.19290351867676, 79.77651426869055, 81.18109149317588, 76.08375180152156, 74.18960002160843, 81.41366451017319, 68.26358118364888, 76.4884227321994, 76.6629054469447, 73.48473441216254, 71.9585637123354, 74.27912419842136, 78.36328429560508, 80.92673363224154, 73.8484714877221, 74.31160926818848, 70.94569006273824, 75.24307020248906, 77.46517919724988, 72.05324188355478, 71.21069323632025, 70.81895043773036, 70.57615572406401, 69.19296326175814, 75.07140374952748, 74.29868898084088, 74.71542512216877, 70.79115652268933, 74.2942645472865, 69.69465009627804, 72.80109667008924, 75.74706339067029, 72.28539912931382, 68.604341014739, 74.70181449767082, 72.35626851358722, 66.3874879960091, 69.35663592430853, 67.96552027425459, 61.604836140909505, 62.70595919701361, 65.03341913223267, 74.05230922083702, 69.58451778657975, 70.52583955949353, 70.85649536501977, 66.00307218490109, 65.59123116154825, 67.6355940295804, 66.30412978510704, 65.18492068013838, 62.77594997036842, 59.93329063538582, 58.40724937377438, 62.15008089619299, 60.310281399757635, 66.08716780139555, 69.61641450082102, 71.76136262955205, 74.02761397823211, 75.64981998935824, 77.54984747978949, 77.32468774241786, 73.56934778151974, 70.07839125971641, 70.76610042202857, 68.80910442721459, 67.7245298508675, 69.95311075641264, 70.29522772758239, 73.37886179647138, 71.53471239151494, 70.26884586580339, 75.13625621795654, 80.09441452641641, 86.87249768164851, 85.6576298129174, 91.38382742481848, 6.5877383755099395, 3.9889188206964925, 7.4071278783582875, 10.265157511157375, 11.985228619267865, 7.050290742228109, 4.557425927731299, 1.8310751645795762, 0.24908141503410958, 3.3076406294299714, 52.910035810162945, 70.39919407136979, 70.39167881011963, 36.55768632888794, 83.2937506706484, 16.060561422378786, 0.5825880482312172, 0.37146969127558893, 0.19503245640906597, 0.24796845781947338, 0.11144698552426793, 0.20933217699489287, 0.140344534489897, 0.13313060626387596, 0.14921852928255835, 0.14038748137893217, 0.17082305144398444, 0.19844049047077858], [0.05488189921203641, 0.03254114740317868, 0.04261279426094505, 0.03202932214574709, 0.012471540812252751, 0.04872778468134423, 0.019909882046762976, 0.025827183478301572, 0.030173223255382433, 0.018735107282296787, 0.02777359838927946, 0.21028204941220824, 22.131389264137518, 65.93353640648627, 36.46123132398052, 58.809060896596606, 41.25235549865231, 59.031325924781065, 3.386996061571183, 0.17471581997890628, 0.5959699495184807, 1.6301179220599513, 0.5514558897383752, 1.9133047134645524, 3.462753454523702, 0.6665668516389786, 0.7670679652402479, 50.366920040499785, 99.00586343580677, 87.2897437310988, 95.50962740375151, 86.74644839379096, 84.63991595852761, 72.86929099790513, 73.333464284097, 72.50424385070801, 72.30560718044158, 68.06224592270391, 66.0711488416118, 65.19445988439745, 62.43060881091703, 66.24119143332204, 70.42315975312265, 75.10137065764397, 77.13934006229525, 80.6677552192442, 80.86567017339891, 81.09869034059587, 83.55546689802601, 80.2500149511522, 77.06642320079189, 73.50484048166584, 61.33708730820687, 60.87554201003044, 59.54716859325286, 59.01370271559685, 58.640089111943404, 64.9303823901761, 73.5384944177443, 76.43744760943999, 75.77061330118488, 77.3533602683775, 73.12788501862558, 67.36837863922119, 65.27050679729831, 67.542280843181, 70.69163814667733, 67.70687918509206, 67.33852940220987, 70.38803885059973, 67.04752875912574, 72.58467597346153, 72.18052279564643, 68.82332694145941, 71.85032198506018, 62.96790684423139, 73.37479822097286, 69.75626268694478, 64.60249577799152, 69.83554947760798, 72.73081564134168, 73.5556822438394, 62.71218792084725, 63.90307441834481, 69.27487019569644, 69.01653505140736, 67.20884015483242, 63.880485488522446, 60.55301335550124, 60.74178134241412, 61.297800848560954, 63.58558208711686, 66.03266254548105, 64.02868440074306, 58.45500423062233, 64.48662504073113, 67.98381420873827, 68.4686113172962, 65.8858403851909, 68.79186953267744, 67.80352638613793, 65.21318527960008, 68.53438946508592, 66.64218318077826, 61.70974777590845, 64.38192913609167, 67.80056107428767, 61.233705397575136, 58.871708992988836, 62.67387813137424, 66.14743894146335, 62.51879938187138, 57.98375498863959, 67.0672425916118, 66.28971899709394, 62.960144473660385, 66.33542245434177, 58.18437637821321, 58.99352604343046, 59.37161899382069, 57.35667390208091, 55.487146762109575, 53.220460030340384, 52.72096187837663, 52.50352528787429, 53.02152133757069, 57.98408839010424, 65.08176234460646, 68.45041936443698, 69.15447696562737, 71.74354722422939, 70.3674699414161, 68.96245341147147, 65.20836076428814, 64.74497195213073, 63.342544186499815, 61.761417158188365, 60.08098356185421, 58.98514001600204, 62.56475779318041, 62.81541293667209, 64.8899035299978, 62.5058045694905, 61.96926355361939, 68.59021263737833, 76.71915223521572, 74.19057276941116, 83.1708392789287, 29.194189425437685, 0.3903393255126092, 0.9715774042471763, 1.6487984551537422, 1.1479089649454242, 1.1948050678737703, 0.4272400341447323, 0.30781973573950033, 0.06261193704220556, 0.1434500863955867, 25.815122435169837, 43.03362930974653, 60.878020947979344, 32.005760054434504, 53.10121997710198, 13.161144410410236, 0.2552145157730387, 0.08971510890630946, 0.01687795310581644, 0.06541727441212823, 0.03450841522745548, 0.03721125003310942, 0.03691496552839395, 0.034209338332256006, 0.03992866349196242, 0.07601836080392523, 0.11067688329926423, 0.06452985348240023, 0.05494585223195534, 0.023896084580149864, 0.08443749089154505, 0.01819670451955209, 0.06998263750105135, 0.04143550098242779, 0.042849143876904444, 0.06233504222285363, 0.05386369941275447, 0.03370153312120707, 0.08118411465998619, 0.3513314460794772, 29.28317035398176, 75.88204783778038, 44.6866298490955, 42.94246950457173, 40.086328983306885, 70.98788692105201, 4.719373727998426, 0.18834648533694207, 1.4573153300631432, 2.3603115014491545, 1.4376358183160907, 2.1968003915202234, 4.417766015375815, 0.4425712308335689, 0.7230701261470396, 55.49134369819395, 100.10440949470767, 93.80767176228186, 97.21014745773809, 91.2165383369692, 88.64279670100059, 77.97962157957016, 76.41872221423735, 74.73036935252529, 73.71409108561855, 71.55898401814123, 69.8005933146323, 69.16306695630475, 66.67022028276998, 72.19259585103681, 73.2733343493554, 79.51835170868905, 79.89224772299491, 84.72313296410346, 82.09807888154062, 83.99507830219885, 86.36327989639776, 85.8973180094073, 79.36111173322125, 79.37589122403052, 63.841995270021506, 63.15430179719002, 63.638898864869155, 61.42789410006616, 61.205589848179976, 68.92910542026644, 75.65571923409739, 79.27441166293237, 81.57200274928924, 82.7872314760762, 78.16416909617763, 71.15246957348239, 68.04474430699503, 73.02848431371874, 73.53841597034086, 71.8951311419087, 73.28565059169647, 72.80863546556043, 70.56385517120361, 74.8323666664862, 74.7991834148284, 72.36373670639531, 75.01383120013823, 66.58621880315965, 75.77632427215576, 72.11259518900226, 65.85656381422474, 70.22220103971421, 76.52475956947573, 74.02424073988392, 64.81771230697632, 65.7362372644486, 68.14112478686918, 70.23661967246764, 69.6210507423647, 66.471434562437, 63.10019270066292, 63.08566816391484, 64.02057293922671, 66.80105486223775, 67.7802667310161, 64.64050746733143, 59.76162026005407, 63.40324286491641, 66.44535864553144, 72.70492015346404, 68.6331625907652, 70.03526872204196, 68.82266013853013, 64.55613728492492, 67.81679184206071, 69.69920789041828, 64.37884223076605, 65.45397958447857, 70.13549312468498, 63.329278730577045, 62.04718928183279, 65.80096029466199, 66.5855598449707, 67.45646722855108, 61.40392449594314, 67.46489247968121, 70.28716333450811, 65.41990203242149, 69.0069095550045, 60.99015758883569, 63.75622480146347, 60.76084013908141, 61.046067053271884, 58.89811831135904, 56.64684257199688, 53.80758393195368, 55.175208507045625, 55.49920805038945, 60.88938405436855, 68.33426229415402, 69.59360984063917, 71.94924416080599, 74.10067204506167, 75.10670508107832, 72.04382035040086, 67.76939392089844, 68.20842481428578, 65.52409979604906, 64.14147999978834, 62.201930707500836, 61.09841892796179, 65.26241102526265, 66.39232035606139, 68.69912116758286, 64.86831480456938, 66.7723431125764, 72.97259838350358, 81.92234100834017, 78.41728748813753, 86.97449499560942, 37.611587970487534, 0.5647709268716075, 0.2606467073482852, 2.644901765931037, 1.8998160501641614, 3.6030426621437077, 2.0815226676002627, 0.5997179580792305, 0.08105782506566855, 0.09035490723627229, 27.186053568317046, 51.28404863419072, 53.30603830275997, 37.44696609435543, 64.36714180054204, 18.082373603697746, 0.2792649115285566, 0.13929114827225286, 0.045530869129804835, 0.032352563369298176, 0.04042725649572188, 0.07255588853431326, 0.032088510098776994, 0.009708762499353579, 0.1394454996672369, 0.0384319115490202, 0.0592898695369161, 0.059002785748171235, 0.20409510801396064, 0.1324010300900667, 0.17775780190863918, 0.15196380535921744, 0.18686399795114997, 0.14513342671336668, 0.14825180293090884, 0.14514805899272043, 0.12627770463305135, 0.21538712144378694, 0.28018602500519446, 0.5152248951696581, 35.639702658499445, 92.31438621397942, 47.23332674272599, 73.63498472398328, 57.16932973554058, 85.57194955887334, 8.077583514874982, 0.27081070227488396, 3.315265226748682, 5.828759256870517, 2.7968933649601477, 6.244171598265249, 9.235661837362475, 1.6524255443965237, 1.4060552225958918, 59.550282955169685, 105.78579010501986, 97.00430147109493, 102.78163110056232, 97.37391425717263, 91.99916101271107, 79.67348144900414, 80.58009024589293, 78.06553717582457, 78.64944473389657, 74.53230534830402, 74.57803233977288, 71.66969683862501, 70.07395113668134, 74.2385825803203, 78.23830189243441, 84.72812221896264, 83.6963584346156, 88.35141951037993, 87.39472204639067, 86.99089834767004, 89.47776732906219, 89.25501592697637, 82.8494873354512, 82.39542591956355, 66.5015583653604, 67.31069626346712, 66.11360457635695, 64.61121912925475, 63.804740598124845, 71.50072113160165, 81.28786625400667, 82.23273384955623, 82.54742560848113, 84.02067568994339, 81.19157991101666, 74.19566400589483, 72.53339490582867, 75.74963646550333, 78.65538320233746, 74.15671487008372, 76.87330922772809, 77.37334082203527, 76.45026591516311, 79.65731343915387, 76.76065091163882, 71.95388824709, 78.16067818672427, 68.75834111244448, 76.19991671654486, 74.92703699296521, 67.16342695297735, 72.98699348203598, 79.09037405444731, 78.36446100665678, 69.26718235015869, 71.22827329943257, 71.78987041596444, 75.33484581978091, 71.05787769440683, 68.74924905838506, 65.78422354113671, 64.7306082325597, 64.28051625528644, 67.71520245459773, 73.29092225720807, 69.49445232268303, 64.22407727087698, 70.87096891095563, 71.22025597480037, 75.60344188444077, 71.5285542703444, 74.8290091176187, 71.97061323350476, 69.05504488175916, 72.36062234447849, 72.93390027938351, 64.90327096754505, 68.67755597637546, 74.26254041733281, 65.75068335379324, 65.54328803093203, 63.75604045006537, 70.91522109123969, 71.85291859411424, 66.90571154317549, 72.65152100593814, 71.89525665775423, 67.465912295926, 71.26641442698818, 64.1164238991276, 67.90475491554507, 65.51470179711619, 65.1941264829328, 61.55638310217089, 59.90764225682905, 57.451752155057854, 58.69322546066777, 58.836874423488496, 65.33533180913618, 72.7404332930042, 73.96778998836395, 76.08913329339798, 77.76719385577788, 78.14058780670166, 75.20693732846168, 71.0470127290295, 72.86095988365912, 70.83320433093657, 68.38686912290513, 65.64499508950018, 64.21773479830834, 67.22260767413725, 70.96096377218925, 72.99849387138121, 70.33884448389854, 69.86230788692352, 77.47955076156124, 85.05885647189233, 83.2413556498866, 91.28263811911307, 40.1087414064715, 0.8522452365967536, 3.1692032708275706, 7.496658919319031, 4.80196217375417, 4.2191484666639765, 3.3449992441361953, 0.7448729884720618, 0.2950990296179249, 0.14185853873289403, 38.11588318117204, 58.25622243265952, 77.12143052008845, 46.662500289178666, 70.685166235893, 22.342857968422678, 0.5802297231651122, 0.28364941658031556, 0.2256679141353215, 0.27213450220804064, 0.2099877031099412, 0.25252088934423467, 0.09628853400147731, 0.14450077598373737, 0.3012238412855133, 0.19413674640799725, 0.20462429090853662, 0.15455351962197214], [0.039788243405881434, 0.04041332135637922, 0.06959446841069768, 0.03757591937638579, 0.043063223316905, 0.013714832565446776, 0.02731731833679782, 0.03448779214053385, 0.032445394073522864, 0.045445051960526936, 0.019928773774975733, 0.039712921641166174, 37.02669981987246, 52.34510467898462, 38.38932729536487, 43.56544386956, 46.21613064119893, 42.68665644430345, 0.451277299153228, 0.02868392534794346, 0.5252969289018262, 0.8447112215142097, 0.33718425359937454, 4.158266907738102, 4.953945192598528, 0.5763265971214541, 2.467200746459346, 66.88304808831984, 93.8231808139432, 90.11057899844262, 90.21179183836907, 91.10886143099879, 85.79905479185044, 72.6387733028781, 67.7997766002532, 76.91651021280597, 73.90329837799072, 72.41530018468058, 66.29887380907613, 62.13279108847342, 61.00783178883215, 64.48802532688265, 67.28632265521635, 73.52380906381916, 75.70530583781581, 78.57506090594877, 81.92388642218806, 79.73404284446471, 81.04105503328385, 80.47525313592728, 78.6746734188449, 78.71817250405589, 66.29166449269941, 58.51344754618984, 60.06499205866168, 56.6384094761264, 59.82026753887054, 65.84296103446715, 73.08264440105808, 75.59284364023517, 79.02837707150367, 73.50234585423624, 73.88171749730265, 71.54679329164567, 67.58792154250607, 71.8651250100905, 70.87888425396335, 73.1629353184854, 73.73069840092813, 70.66219683616393, 62.93804584010955, 68.28249485261979, 73.35284079274824, 71.82660733499836, 64.75693125878611, 73.31008695787, 69.70478550080331, 65.74062247430125, 70.60509497119536, 72.17884402121268, 63.56462878565635, 57.289267970669655, 59.12906746710501, 58.70898946639031, 58.61982222526305, 62.737134195143184, 69.34150342018374, 65.16268868600169, 62.78643838820919, 64.54686087946739, 66.75630061857163, 67.73578705326204, 59.73818409827448, 54.3286237409038, 58.853666090196185, 55.218797806770574, 54.61667476161834, 59.87128188533168, 63.70945445952877, 65.32966006186702, 67.47522400271508, 63.37001254481655, 57.59250640869141, 63.574972075800744, 68.89559268951416, 64.87270001442202, 61.83465173167568, 61.37581679128832, 61.17095531955842, 57.352127875051195, 59.92646178891582, 66.03220755054106, 67.41079515026462, 57.26789497560071, 66.61771543564336, 64.16144486396544, 64.34822813157113, 63.772753669369614, 62.88859651934717, 57.49660053560811, 56.97460366833595, 54.080616197278424, 52.83596184945876, 52.052535087831565, 51.92400686202511, 50.05793140780542, 57.56746207514117, 63.66910503756616, 66.90799436261578, 66.85373229365196, 68.352995534097, 67.851010599444, 69.56363508778234, 65.53001080789875, 64.51679198972641, 58.033682838563, 61.32694405894126, 56.36807972385038, 60.60577315668906, 58.368174722117764, 68.27785861107611, 59.78534275485624, 61.66811181652931, 59.81978508733935, 73.9237339265885, 74.52883012833135, 77.263914538968, 71.55994892120361, 64.47541490677865, 2.996636143615169, 0.8572754311946131, 3.057515496207822, 1.506309288163339, 0.561220507708288, 0.30150527134537697, 0.9857825129743546, 0.1284999801446834, 0.6000211450361437, 12.585888620345825, 47.439988582364975, 49.61528408911921, 30.31663840816867, 50.12786726797781, 21.041833277671568, 0.5504950929072596, 0.13952341080913622, 0.14369428458233036, 0.2059751184236619, 0.03273292219326381, 0.11151351259961245, 0.06939022170920527, 0.0406011316414562, 0.03767558741533468, 0.06853621753473436, 0.11179731753204139, 0.14411748687346138, 0.02714690399326144, 0.10139529908736868, 0.014030775843909191, 0.05815864112528582, 0.03460616038571443, 0.004483464459377912, 0.02953505286225869, 0.10735072871489872, 0.04784501007487697, 0.03591642354524905, 0.030553549520611286, 0.06358311436469517, 46.85453561044509, 59.92207657906317, 45.83703748641476, 40.45763623329901, 51.19160621396957, 50.454157475502264, 0.5697805903130962, 0.05628781994023631, 2.5663026157886755, 1.6837421155744985, 2.1896295634008225, 2.058487568170794, 0.9793345041332707, 0.4749697939522805, 3.4597092049737133, 75.13977850637129, 97.43216145423152, 93.89401097451487, 93.34734239885884, 93.66325009253718, 90.54252609129875, 76.23963463690974, 71.8519615357922, 80.69400372043734, 79.13492433486446, 76.30541278469947, 69.52962813838836, 65.41114337982671, 63.69288244555074, 67.3144538940922, 72.96046257019043, 73.92905266054215, 79.13409279238793, 83.14910150343373, 84.52065237106817, 83.05920077908425, 82.63219587264523, 82.06846498673963, 82.07857685704386, 81.71378074153778, 69.00476009615006, 62.010868134037146, 62.92721225369362, 61.539461997247514, 62.196243270750976, 67.82147515204646, 75.55881315662016, 77.68953877110636, 79.41782920591294, 78.17935651348483, 75.97448241326117, 74.0336936519992, 71.5883155022898, 74.56421775202598, 73.65622828083654, 73.74786269280219, 74.5391930303266, 73.36401954773935, 66.36374981172624, 71.4196143611785, 77.56947502013176, 74.05994999793269, 67.3333832525438, 78.04600377236643, 70.97057357911142, 69.26700192113077, 75.20110868638562, 74.14107245783653, 64.44410262569305, 60.611397835516165, 63.16061681316745, 64.37539838975476, 60.361856645153416, 63.797178268432624, 72.78091999792284, 67.75256695285921, 65.98961845521005, 66.01774184934555, 68.86971289111723, 68.63356267252277, 59.34225220834056, 56.921384949837964, 62.34142588030908, 60.527604241524976, 57.87218709145823, 61.51160140191356, 64.45375557868712, 68.06557209261003, 71.00970314395043, 66.46067942342451, 59.74082385340045, 65.59797371587446, 70.60869570701354, 68.40568865499189, 62.30797982984974, 62.91936751334899, 63.0335202524739, 60.35669088363648, 61.91529958478866, 63.88222309850878, 73.05193224260884, 62.58751538492019, 66.22729055343136, 67.67990896778723, 66.09971154120662, 66.675091866524, 64.24677602706417, 62.57617189038185, 59.853101699583, 57.445566577296105, 55.65639703504501, 54.8378493708949, 53.36971013776718, 53.35527973790323, 60.99806116473291, 65.83417492528116, 68.53057692127844, 68.91107036221412, 73.53563108751851, 71.85024353765672, 71.04831495592671, 67.49869546582623, 65.61948007152927, 61.977763329782796, 62.84865502388247, 60.355490638363754, 62.16735893680204, 61.944568311014486, 71.9348176833122, 64.28354824742964, 65.96254625628072, 61.90709398638818, 78.97082021159511, 77.19959551288237, 83.53965190149124, 74.48401312674247, 71.79294555417954, 5.074407064145611, 1.1500781582247828, 0.4774003151443697, 1.8299482185994427, 3.3375320319206487, 0.9145688181442599, 0.9494216511807135, 0.21523699885414493, 0.6893611543120877, 11.284665849901016, 55.13044641863916, 51.113919750336684, 34.49293105832992, 59.794403429954286, 26.872487529631588, 0.5170806665574351, 0.26464743299349663, 0.0343100099463857, 0.17389615186520163, 0.028629586731474248, 0.10046400430221712, 0.04695521427258369, 0.017282407310220505, 0.086761548844797, 0.09153316578557415, 0.0258146426189811, 0.19981708918367663, 0.21328814778356783, 0.15679173742330846, 0.14222049995535804, 0.16864126367915064, 0.15363796794366452, 0.1521808380681661, 0.1488793668367209, 0.1721113048974545, 0.1457244175816736, 0.15177456632016167, 0.104047694664088, 0.22244276058289314, 57.54918383013818, 71.27284711407077, 54.7720790678455, 60.526553046318796, 63.06362444354642, 65.08211143555181, 1.4999671833169077, 0.14319375337612245, 2.9515134423009814, 2.240709609562351, 4.6704534369130295, 8.35622133747224, 10.754688920513278, 1.0737240747098, 4.615453472060542, 80.55894867066415, 101.85506528423679, 96.95773509240921, 97.19775276799356, 97.03469983993038, 92.84403954782795, 81.05282214380081, 74.92562493970318, 86.11764538672664, 83.19894698358353, 78.35773021944108, 72.27776619695848, 70.41675844500142, 67.7466755528604, 70.63310069422569, 75.8795218313894, 81.76288881609517, 80.9858908191804, 86.87168182865267, 88.64104732390373, 88.09375116902014, 86.77389714025682, 83.65137669347948, 84.99212911052089, 84.89350503490817, 73.04368742050664, 64.2522555781949, 67.35490137530913, 63.82549778107674, 66.0558045294977, 72.28866254129719, 79.44560743147328, 82.26466194275888, 83.5705444889684, 82.12537073319959, 78.41247081756592, 76.80748401149627, 77.05685261757144, 80.39355016523793, 76.85855327113983, 80.59664264802011, 79.02470573302239, 77.10910643300703, 69.61348841267248, 73.8027209620322, 80.43120491889216, 79.02992248535156, 69.46386568007931, 79.68739801837553, 74.34900514541134, 69.3505640952818, 75.17176151275635, 77.6952418973369, 70.05728106344901, 63.57982012533373, 65.60996440149123, 64.51432089651784, 64.60075816800519, 69.92525408344885, 75.8373720415177, 69.74982215512183, 66.66908279542001, 67.57522090788811, 70.78313919805711, 71.96355296719459, 63.897496807959776, 60.45731536803707, 63.31255374416229, 62.12652706330823, 61.353671089295425, 67.01677737697479, 69.66179632371473, 71.24907755082654, 72.59054383923932, 68.20820516155612, 62.292980686310806, 70.94154019509593, 73.97892951965332, 70.49064805430751, 66.10216694493448, 64.72253991711524, 65.24759231075164, 61.96418800661641, 66.39918450386294, 68.62903625734391, 76.88961059816423, 64.93828596607332, 70.57473582606163, 69.07697877576275, 72.7170402772965, 70.53763804897186, 67.78853508733934, 63.84555285976779, 63.98137277172458, 60.53351525337466, 58.46802257722425, 58.78052565359301, 57.5731534342612, 55.99842771407097, 63.71256882144559, 69.19483030996015, 72.36926724833828, 72.88539624983265, 75.8741952526954, 75.06894050105926, 77.2151045645437, 70.7518308393417, 70.1191682200278, 64.96083959456413, 67.3731403966104, 64.3514915435545, 67.81838432435067, 66.30146257338986, 77.37853404014342, 66.21510767167615, 69.47567201429798, 66.62778808224586, 86.50024121807468, 81.67167802010813, 87.52783160055839, 79.27842816998883, 79.17913729144682, 4.494484634168686, 2.311779034714545, 8.053143716627552, 4.758317960846809, 2.764277876384797, 1.8629523895440565, 2.3699950979601954, 0.3937930030928504, 0.9870513997250988, 18.976719110242783, 67.13454261902841, 68.17877169578307, 41.893404145394605, 65.56364120975618, 32.61541993387284, 1.0740334516571415, 0.5792238190770149, 0.29869936707039035, 0.43741904439464696, 0.18682811439277666, 0.24849140475834572, 0.16309886269511717, 0.1693805078825643, 0.25453862704096303, 0.3034875391712112, 0.1726140577586428, 0.35933997602232043], [0.02488184438627814, 0.007508799298516205, 0.05224772886703572, 0.020820886993239966, 0.013547742085891866, 0.01853550690406513, 0.017228978423161373, 0.036263978484296994, 0.06000934101100411, 0.1400407653061613, 0.08009148175798117, 1.0004161406428584, 52.82484193002024, 50.631778086385424, 45.10506829907818, 32.24081593175089, 53.31416545375701, 23.57005580779045, 0.1938643255421231, 0.19511006111579557, 0.28009066238038005, 1.514702547461756, 0.7432669004605663, 1.2407639694790686, 2.4682235044817773, 0.22159364404937915, 9.129116535186768, 77.43625563959922, 86.79605068699007, 90.48179211155062, 89.04441602768438, 88.45403655882805, 85.04379457043063, 73.5967259253225, 70.25949493531259, 75.7675067840084, 78.72850402708977, 80.44337211116668, 74.83897978259672, 65.5528429246718, 60.3334665298462, 61.932997319006155, 61.85001173327046, 65.87588540969357, 71.39781382776076, 76.37140274047852, 78.93375381346672, 79.6723831853559, 77.56769426407354, 78.81453729444935, 81.7964486152895, 79.62693860453945, 71.47235455051546, 58.25761095170052, 56.9709833206669, 58.90904995702929, 62.847313573283536, 66.5429001469766, 69.4106940300234, 74.82838153839111, 75.69223650040166, 73.92952334496283, 69.19604624471357, 71.31742092870897, 68.88685364877024, 69.46010020471388, 71.00276839348578, 72.09096723987211, 68.37884395353257, 61.52476879858202, 68.33223835114511, 80.31776997350877, 69.53783373678885, 64.33645709868401, 74.10705766370221, 68.55110660676034, 61.91030640755931, 73.33415462124732, 70.2830683800482, 57.00444113823676, 59.388457728970444, 64.87124481508809, 71.2150941356536, 73.18464171501898, 65.52601391269316, 57.232393603171076, 58.52963124552081, 64.77420145465483, 62.27302366687406, 65.03955371918218, 62.25146632040701, 60.435114752861764, 54.16744570578299, 61.607205252493586, 69.26391109343498, 70.48034791023501, 66.13571889938848, 57.57014105396887, 54.25429874850858, 63.60596664490239, 68.45635783287787, 68.43441609413394, 66.19445247034874, 59.396337770646625, 59.832128786271625, 66.63362456906226, 64.65461231047108, 61.13126093341459, 60.69243008090604, 54.911903719748224, 60.80258984719554, 55.79641780545635, 65.80438452382242, 66.57321222366826, 57.66352876540154, 66.12892535425001, 63.77532674420265, 64.34057950973511, 62.90396044331213, 60.643133732580374, 57.13849990598617, 53.246359440588186, 50.33407803504698, 51.914918730335856, 50.73891370527206, 50.64620064150903, 55.852837178014944, 61.32299815454791, 66.20703543386152, 68.97109831533125, 68.90276278218916, 69.31276813630136, 69.84972492341073, 63.11516830998083, 61.90372859278033, 58.27506549896733, 57.214052600245324, 53.93365283166209, 57.38375394575058, 61.65033955727855, 64.04622524015366, 63.62288774982576, 62.30308078950452, 55.737044888158, 75.67151854115149, 72.22384145182949, 80.20383296474334, 67.3874335135183, 74.5979501355079, 22.065909216480872, 0.4391064909437011, 1.056398230214273, 0.7983879684921235, 2.318427452156621, 2.0406286490540353, 0.611455895968022, 0.34346347794898097, 0.028397990691085017, 1.815896695179324, 50.63648100822203, 37.91279462076003, 42.79955010260306, 43.56944860950593, 31.64602379645071, 0.2853392839672104, 0.18852706758245347, 0.05829489752349835, 0.14059498395410278, 0.06888848008407701, 0.062374982216785994, 0.06674095943209625, 0.009593565858179524, 0.0636011595657516, 0.07510702260920117, 0.12778830744566458, 0.01604365462797784, 0.043259671243328246, 0.026202930452963038, 0.03397047594790498, 0.04886228290777053, 0.05541971591751903, 0.024428113491364548, 0.05759265536682741, 0.03729887516988862, 0.034405479823509534, 0.04675854418066241, 0.22562544222079942, 1.3848869262203094, 67.35115943416473, 58.651711094763975, 52.57294731755411, 25.07764820129641, 59.32593122605355, 29.945413527950166, 0.1746763051637719, 0.23998413625503742, 2.098995600977252, 2.3165062262165934, 1.6528475669122513, 1.5216257759640295, 1.4767525128779875, 0.3111391334283737, 11.528768674019846, 84.13660526275635, 91.30785895932107, 94.85248919456237, 95.08259896309146, 92.3350178810858, 88.01965759646508, 77.23543813151699, 73.34555302896808, 78.92339091147147, 81.83115374657416, 83.78052465377316, 75.59406741972893, 68.46938010184996, 63.89464916721467, 65.91798813112321, 66.14440302694997, 69.74672348268571, 73.93684248770438, 79.6290566844325, 83.1317489377914, 82.2155224892401, 81.06579734433083, 83.22967483151345, 81.56092597592263, 82.22761123411118, 74.11458861443305, 61.48518816117318, 59.180242630743216, 62.307262036108206, 68.90921115875244, 69.68909602011405, 72.81694304558539, 76.03555371684413, 79.14271416202669, 76.28298467205417, 70.20418951588293, 74.38215701810776, 70.27033636646887, 71.93877927718624, 74.32996596059492, 76.83276760962703, 70.28580619442847, 65.45403842003115, 72.7623358080464, 79.6605533169162, 70.58929566414126, 66.4813110905309, 77.01620117310556, 69.64406721053585, 65.77599833088537, 75.52097797393799, 73.84354499078566, 59.224922349376065, 64.52267946735506, 69.54094025396532, 74.75489985558295, 76.4673674491144, 69.00187323170324, 59.79569781211115, 61.14145125112226, 64.84333715131207, 65.5842258084205, 66.81122164572439, 63.218660046977384, 61.344273090362556, 58.030741060933764, 67.02665390506868, 72.59368173537716, 73.72830575512302, 70.52228589211741, 63.860806957367934, 56.810024938275745, 64.18402987141764, 67.78030595471783, 69.89314556121826, 69.3453473429526, 62.73320005786035, 62.14806872029459, 67.89685526201802, 67.41668655026344, 65.75388793022402, 62.53998410317206, 60.791336567171165, 64.92153744543752, 61.722801423841915, 64.26213602865896, 71.56902528578236, 61.60050584423927, 68.06895317569857, 69.3309679339009, 67.96992901832827, 68.31501130134829, 64.73600933628698, 61.00293274848693, 55.6747615721918, 53.39796689248855, 53.515571317365094, 52.977963416807114, 53.59348920083816, 60.0058231046123, 64.15037201296899, 68.4618648405998, 72.3556330896193, 73.03951401864329, 72.64800656226375, 72.73079995186099, 66.03607500753095, 65.7109615110582, 60.07994413375855, 59.07142823742282, 58.22890312440934, 61.271768077727295, 66.89846300309705, 67.5053164266771, 65.97372501127182, 64.26277929736723, 59.46660703228366, 77.48484596129387, 77.7602041921308, 84.35674436630742, 72.9857304788405, 78.63363758210214, 27.034320600571174, 1.3390545210530682, 0.8995305121906343, 2.056326097057712, 3.0635973763081337, 1.4647624401315567, 0.7924745664481194, 0.47117919090294075, 0.04349896263691687, 1.3431396695875353, 55.766976494942945, 43.41777839968282, 38.07637706879647, 53.88253650357647, 39.210338207983206, 0.12343299800469992, 0.1666199406909366, 0.01356660125536784, 0.032848850448405555, 0.026684027923751744, 0.033002202098648396, 0.04709435499183113, 0.029837132822121346, 0.015318744887237348, 0.03554843321082092, 0.0330069633350978, 0.061563472939474936, 0.2556265791457507, 0.1306714180616602, 0.14554115402842724, 0.1418026449579385, 0.19247045920741176, 0.1309370513885252, 0.1795439512258576, 0.08884996581341952, 0.22105437943771963, 0.13988284394145012, 0.3355834362727981, 1.7760118289339928, 80.63537213110155, 66.34178453876127, 58.283628033053496, 46.55359568134431, 74.91011588804184, 40.74930367931243, 0.5288866330539027, 0.4710206107026147, 4.895211131341996, 5.447604406264521, 3.2850227721275824, 1.941408373175129, 4.498388373082684, 0.7610603037380403, 14.289978031189213, 91.9403882180491, 94.48150357892438, 101.30849869020524, 99.33058077289213, 97.62251407869401, 92.92484037337765, 81.3273488321612, 78.36679873927947, 84.0524233541181, 84.49212889517509, 88.31321562490156, 80.17237555596137, 71.886760803961, 65.97847107918032, 68.99759000347507, 70.72741016264885, 73.51946307766822, 79.5664321222613, 82.34400364660448, 88.98216016830938, 85.95822457344302, 83.96080463163315, 84.70827502589073, 86.79510147340837, 85.6848196829519, 76.22998560628584, 63.803681558178326, 61.001975690164876, 65.25858279197448, 70.67149285347232, 72.32557988935902, 75.41748231457126, 81.50874276315012, 81.4577127272083, 80.11369689818352, 75.21110288558468, 77.4735495351976, 73.74812156923356, 77.1904093219388, 76.21926184623473, 80.25654961985927, 75.143504758035, 70.16760164691557, 73.85579847520398, 83.66641506072014, 76.06645414906164, 70.20072998539095, 78.52402302526659, 74.80657316023304, 66.94560989256829, 81.04176890465521, 77.92140576147264, 63.44547894693191, 65.10100549267185, 68.95007441120764, 76.71373151963758, 78.85946412240305, 70.11264139606108, 64.96208298590876, 64.10789666637298, 67.86527233739054, 69.44649742495629, 70.720334206858, 67.41020679473877, 64.28608209856095, 60.09225253135928, 69.03390330653038, 75.9742784500122, 75.42480930205315, 70.74541384173979, 61.9450625296562, 59.76182030093286, 69.44256721004363, 72.8492163073632, 73.9885550160562, 70.34952117550758, 65.7989324292829, 66.45711006656771, 72.50945275829685, 68.22496152693226, 68.7841973766204, 65.67741740134456, 62.01107994202645, 65.06689263928321, 64.97636433570617, 66.29374334889074, 72.31138090933524, 66.394132491081, 70.78731259992047, 71.6367724633986, 68.52924331541985, 69.85844042993361, 68.49349483366936, 64.33072259349208, 58.51516946669548, 56.16827810964277, 57.746522195877574, 56.981820829453014, 57.26108966335174, 62.38151250347015, 68.07227934560468, 72.1243073863368, 76.05428695678711, 76.38356993275305, 75.96790067611202, 75.93369760820943, 69.74251870186099, 69.4383938081803, 64.35270355593774, 63.5337636547704, 60.82499834798998, 63.25351815069876, 69.48612905317738, 72.19527090749433, 71.38308140539354, 69.07497052223452, 62.342041692426136, 82.211286329454, 81.21421198691093, 89.60469522783833, 78.30913989774643, 86.11864951349075, 27.469142790763613, 1.457542214662798, 5.359072589105176, 4.843850145416876, 10.350786774389206, 4.9653818434284585, 1.850757740678326, 0.7849634114292361, 0.18709802249025914, 2.65584223693417, 63.61264644130584, 54.73314954388527, 54.1700658490581, 56.48626465951243, 46.33228378911173, 0.4359953465961641, 0.40345732483171654, 0.12255402702477672, 0.19767084789852943, 0.10698575676689226, 0.1951004543732251, 0.20330498025061625, 0.14362582696541665, 0.06995574015402986, 0.3256055700682825, 0.20289484741947345, 0.10942675038090638], [0.13659134717477908, 0.0673773410099168, 0.028904309691560846, 0.03727692675085799, 0.009255409860352596, 0.03320315462206641, 0.023907528018518805, 0.06562745829503383, 0.0925283523036107, 0.03795415613680117, 0.22125304135824406, 6.493172482136758, 67.27938790475169, 39.32215321448542, 34.03181722087245, 43.91938678679928, 58.60738438944663, 12.167054991568289, 0.06304032574858397, 0.7583459622917638, 1.5909900732578772, 2.255059845985905, 0.831780025074559, 0.35629480716682255, 0.09705271436682633, 0.3152328621475928, 12.67243669879052, 87.74737450384325, 88.39637771729501, 92.42952346801759, 86.53162802419355, 91.12844190289898, 85.114867917953, 75.09690700038787, 69.49313440630513, 77.94064890953803, 80.97826573156541, 83.68187704393941, 84.73509619312902, 75.63403637178483, 65.51581575024512, 60.75666673721806, 59.84985397708032, 61.90627813339234, 62.50267451809299, 62.62744119090419, 71.80210036616172, 75.3989451931369, 78.0277882852862, 78.51608414803782, 75.55324339097547, 78.64731880926317, 73.40823250432169, 59.55763739924277, 58.34425610880698, 59.485085318165446, 72.92856585594916, 69.52173632960167, 66.4659667784168, 71.08660513354887, 74.22705865675404, 74.00142039022138, 67.67612780294111, 68.8692343619562, 69.71075534820557, 69.65425752824353, 69.46137889739006, 71.09682683021792, 61.83221986216884, 67.14507810531124, 80.74475919046711, 67.36624486984746, 68.94766607592183, 74.05733769939792, 69.4031552345522, 64.12955207209434, 72.31558569015996, 68.97159253397297, 59.19222547161964, 64.94979027778872, 75.40351083201747, 71.3188486714517, 68.83413699365431, 70.97617472371748, 69.09397048334922, 53.95805781887424, 53.98576151940131, 59.740208041283395, 63.426051447468424, 60.770336197268584, 57.884420964025686, 56.8000699627784, 65.04746121744957, 68.16919326782227, 67.08949027522918, 64.89634406182074, 66.36874691132577, 70.00272873909243, 61.94392111993606, 56.31962668511176, 59.269366725798584, 62.80530106636786, 66.75851283534881, 65.41270448315528, 61.2410637640184, 63.02020772810906, 62.07414773202712, 66.74144268035889, 64.2596531683399, 59.751025938218646, 63.246512797571, 64.32862804782006, 59.14010501676991, 67.43731821736982, 64.42252566737514, 59.162309554315385, 65.86065092394429, 64.82312910018429, 66.8434949075022, 60.600983942708666, 61.212971748844275, 52.14793105279246, 53.28773260116578, 48.89256777301912, 50.49133369999547, 50.73385384774978, 55.82007361996559, 61.66790000854, 65.1260772828133, 67.96315116267051, 69.57267222865936, 68.25782314423593, 68.25763487046765, 63.511390455307506, 60.60937389250725, 54.78257925279679, 54.15177583694459, 54.56127912767472, 58.05920177890409, 64.5521011660176, 64.22093152999878, 62.209830361027876, 57.5723179694145, 61.414181493943744, 72.86161884184807, 77.6549748451479, 75.47158748872819, 70.51823016135924, 75.53935820056547, 46.28284623545986, 5.39702348170742, 0.962263736273012, 1.392150910631303, 3.717591805804161, 1.420635040248594, 0.30884050193332857, 0.05320178412441766, 0.09085810442845668, 0.3584582088214736, 36.66980335789342, 47.84804844087171, 39.45764364734773, 48.10110015253867, 38.30778121948242, 0.12530795989498017, 0.07993017428464468, 0.12445744142056474, 0.04840449174685825, 0.058521950662496595, 0.007393578238289564, 0.043591314536188884, 0.026264891644278844, 0.11740692740967197, 0.061169688424636284, 0.08205445948988199, 0.03457492315060189, 0.10541745221182224, 0.0151258037282875, 0.027594732180718454, 0.049771962522138516, 0.02314340894020373, 0.008832243958397979, 0.027511117514222864, 0.03425375611010579, 0.09449931267168253, 0.12767959190832992, 0.3631014677305376, 9.629500162216926, 77.21341010062926, 49.67896769123693, 42.57228013007872, 34.669684825405, 68.8803425142842, 14.495788716500806, 0.05801414545144766, 0.5406458988305062, 2.1696330751142194, 2.1199312517719884, 1.1865191834588205, 0.4232196047181084, 0.30650862222236974, 0.3667427755651936, 15.310264960412058, 95.00550869972476, 92.01420722469207, 92.67094535212364, 91.08863769039031, 94.2252629803073, 89.92370943869315, 77.6799132747035, 72.71546348448723, 80.71871465252292, 84.49696125522738, 85.11338526202788, 86.95198843556066, 80.09825060444494, 67.88453117493661, 65.21356967187697, 64.9402863748612, 63.899834540582475, 65.60819933491369, 65.40171792430263, 72.49231984538417, 79.65020610440163, 80.59806254602249, 79.58736188950078, 77.13364478080504, 81.81331480703047, 76.91429799602878, 60.889160479268725, 59.090086952332534, 64.2139300992412, 75.54487305302774, 72.16869292720672, 70.42654868095153, 74.24149297898816, 77.23641087931972, 74.08950897955125, 71.19167758572486, 72.27495777991511, 73.4419099746212, 71.48295279472106, 72.28079426673152, 73.51961212773477, 65.57820104783582, 73.47531287900864, 82.25669168656873, 71.37012973908456, 71.65858868629702, 75.39057485518917, 70.55774411847516, 66.4992755459201, 76.07391449712938, 69.34787334934359, 60.37575752504411, 68.83377613559847, 76.56320664190477, 71.03426502596948, 71.6518892780427, 72.83755902321109, 71.4161705201672, 57.07644408748996, 58.09150249727311, 62.44642380745181, 64.37273117803758, 63.184762923948234, 59.25101003339214, 60.072989771443034, 68.27001387073149, 69.60921302918466, 69.11321363141461, 66.3009448205271, 67.92184076001568, 72.15871441748835, 67.03209815486785, 59.962131823262865, 61.628170321064616, 62.90823974917012, 67.30009801926153, 69.05735123542048, 64.63288237971645, 65.25490360875284, 63.06033357497185, 68.63480214149722, 66.90187546514696, 62.674238989430094, 66.4890460045107, 68.84058537021761, 63.07228895925707, 67.1174410850771, 72.81117716143208, 62.540988229936175, 68.01017253629624, 66.24592181174987, 69.3381929397583, 63.375366580101755, 63.45595559766216, 56.2789007156126, 55.83184465285271, 53.23075625204271, 53.74546927790488, 52.69844355121736, 59.067035182829834, 65.23435038904991, 68.57598227839317, 70.7428329221664, 71.07224141397785, 71.64682942052042, 69.04874555526241, 66.00030299155944, 62.66201296160298, 58.45747924620106, 58.763439809122396, 58.526913042991396, 60.29638051986695, 66.53951906388806, 67.77470481011176, 64.97073573450889, 61.177050682806204, 66.24045402772965, 76.65989306665237, 80.4298242445915, 79.51722991081976, 76.67080510047175, 82.19918189510223, 54.0889080878227, 7.251311232966762, 0.5384827729675078, 2.678435334274846, 2.381678612962846, 2.2073559799501976, 0.3649015292044609, 0.1044288540499345, 0.1673956660013045, 0.5447801995661952, 37.54496651311075, 58.476334079619384, 36.07281077292658, 59.495499210972945, 47.956556889318655, 0.2945954953470538, 0.04364007220212971, 0.03480007639154792, 0.03849628208685787, 0.044935097872850396, 0.10095958658043416, 0.044362332236262104, 0.014730930410986467, 0.06574794860376466, 0.06081163042014646, 0.04947044563690021, 0.05436968899542286, 0.20749555780522286, 0.20695373445989626, 0.1705547980964184, 0.1104362857257647, 0.09733493349725202, 0.11639075774338939, 0.1429117564111948, 0.13027614733624843, 0.22821049866897447, 0.19037107185971355, 0.6503214975518565, 10.70557790417825, 91.99816473068731, 56.26541952933035, 47.15567558042465, 61.91373455908991, 81.40165421270555, 23.069378983589914, 0.16586465460638847, 2.048808139178061, 7.448505941898593, 5.845668594683371, 2.6028870526821386, 1.0132525260410001, 1.443644644271943, 0.545929147591514, 21.054518222808838, 101.94793132043655, 98.94303491038661, 98.64062017010104, 97.67483065205236, 97.87664444215837, 93.96583741711032, 83.227980367599, 75.72588259173979, 85.6425992904171, 88.47967317027431, 90.20323322665307, 90.26373186419087, 82.73529929499473, 72.5383920054282, 68.13976764678955, 66.90988494503883, 67.71865414034936, 67.88115793658842, 67.12611736789827, 77.27500700181531, 84.12768579298451, 82.72507759832567, 84.581174542827, 81.67517677430185, 87.13124859717585, 81.99606587809902, 65.94574282246252, 64.59532176294636, 66.03336072737171, 79.96067739302113, 75.3630711955409, 72.94946424422726, 77.58678051733202, 81.30933730832993, 77.88146818837812, 75.00663757324219, 75.39727426344349, 76.64525478116929, 74.71723725718837, 77.36618641884097, 77.60138742385372, 70.3630925763038, 74.97962813223563, 86.20855023784023, 74.11718522348713, 73.92862904456355, 77.96958815666937, 73.70687392450148, 67.76729153048608, 77.16500805270287, 74.69924926757812, 65.01504282797536, 70.94192458737281, 81.07084935711276, 76.5731616174021, 74.26352885461624, 75.65581337098153, 76.80792331695557, 59.2583409432442, 60.72219694814375, 66.04687721498551, 69.90314760515767, 67.6795010412893, 63.159287129679036, 62.71677709394886, 69.2174231621527, 72.99408512730753, 73.05292067989227, 70.20825309138145, 74.27357012225737, 77.01881347164031, 67.66747505434098, 64.18411224119126, 64.56620600915724, 66.92214627419749, 73.0261936495381, 71.96101127132293, 67.2385246522965, 70.09896016890004, 67.6641567291752, 72.76944314279865, 71.06870343608242, 63.90291360116775, 68.3882890209075, 72.40494512742566, 67.42595118861045, 69.98549384455528, 72.09062991603729, 66.94089520362117, 72.68230376705047, 68.54945921128797, 73.80564705018075, 66.4055230540614, 65.4837582188268, 57.868503985866425, 58.899702948908654, 54.99050017326109, 57.49238791004304, 54.371710977246686, 61.35383975121283, 68.89836188285582, 70.37542450812556, 73.82655328319919, 75.62900004848358, 74.20334400669222, 72.86672576781243, 68.57464082779424, 67.52812108685895, 62.185084127610736, 61.02143456858974, 62.10633470166115, 65.07123470306396, 71.45469603999969, 70.71556460472846, 69.16425935683712, 66.03328227996826, 69.43131000764909, 81.98076078968664, 86.51963341620662, 87.30365245572983, 82.44863679332119, 88.36233938893965, 57.95813014430385, 7.7030667854893595, 1.3824519923617764, 7.383310266079442, 11.197319569126254, 5.800835413317527, 2.1869228828337888, 0.17742064661316334, 0.7308989931498805, 0.5905059652943766, 44.209955969164454, 70.8185346664921, 53.10353417550364, 63.78297536603866, 58.72492605640043, 0.6218821687563774, 0.1514125591324222, 0.18954228729970996, 0.0762251585782055, 0.17770471201548654, 0.24162364102179007, 0.1711072700638925, 0.1904778951598752, 0.21982301567350665, 0.14139631192290014, 0.20337225809212656, 0.11121168161832518], [0.04043079965237168, 0.03203672638553525, 0.005404977738151267, 0.06588260387821544, 0.04255321943351338, 0.07893157101446584, 0.09062971063559094, 0.07375772726992447, 0.05668123290243168, 0.1143778004353085, 0.392335873217352, 12.948090087982917, 67.40485668182373, 30.19505277756722, 28.041844137253303, 47.20282246989589, 49.082959621183335, 6.346903866337192, 0.08845554544560372, 0.44500463251625344, 1.8750209096939334, 1.0522162481661768, 1.3617385683521148, 1.0261256223724735, 0.763197566472715, 0.814801003904112, 36.25795448980024, 94.81439513544883, 85.04020952409314, 90.7078775282829, 83.25644108556932, 90.61854946997859, 80.75129385917418, 71.34890187171199, 70.7284927368164, 79.25337991406842, 79.803908101974, 87.01280870745259, 82.39646927002939, 81.78912947254797, 75.35916451484927, 64.86982099471554, 60.20423227740873, 61.47907318607454, 61.35177266213202, 60.30978325874575, 61.392180919647224, 69.8925885846538, 73.5262252438453, 76.50250404111802, 77.89030921074652, 80.69334476224839, 69.48997297594624, 56.2270587490451, 56.25103619790847, 65.5369024122915, 72.34821980999362, 70.45078892861643, 69.74789234899706, 68.49626402701101, 73.58415080655006, 72.7271992160428, 66.8917400606217, 66.90988494503883, 70.6857624361592, 74.86124315569478, 72.3478981756395, 62.093987080358694, 60.65877614482757, 74.11516912521856, 67.61307962479131, 67.55254176355177, 70.25535291241061, 67.18209743499756, 67.66314475767075, 72.63183855241346, 67.35629773909046, 58.33127306353662, 68.27171617938627, 74.60026433390956, 68.2660444321171, 64.55117156428676, 69.40908585825275, 74.15560091695478, 61.47498607635499, 52.63867447453161, 55.32864770581646, 54.06520128250123, 57.2829294204712, 55.0707910906884, 55.03287353823262, 54.35601365181708, 60.18760927261845, 69.03701766844719, 63.727936667780725, 63.16151111356674, 62.916508105493364, 64.12813217409196, 66.68961248090191, 64.78517232402679, 60.225326784195445, 58.44040909121114, 60.84005240471133, 59.52712135930216, 65.68403051745507, 64.14548473973429, 65.02380540294033, 59.71732885606828, 57.49328613281251, 60.075198065850046, 62.538297483997965, 61.13131192422683, 60.34499437578263, 59.109753716376524, 66.82824473227224, 66.67350722897437, 64.50318528759864, 66.99489055141326, 64.41332770932105, 64.88380816675001, 63.49549701136928, 61.55208418446203, 54.801347794071326, 52.801284174765314, 50.10035968595936, 51.38762274096089, 53.274102364816976, 59.38723394947668, 64.8611996250768, 68.07624878421908, 66.77509661643737, 68.0394491072624, 65.72656862197384, 61.51329194345782, 58.22624375743251, 56.52297804432531, 55.186297047522764, 54.57890233685894, 61.768944186549035, 67.06969799533968, 60.583890253497714, 63.351993176244925, 59.34675116692821, 60.841417389531294, 71.17256779824534, 73.42611851230745, 74.5374514979701, 74.5227582993046, 73.51852955356722, 57.76472199347712, 13.149812682982414, 0.8670554322100456, 1.6825422380239734, 0.882582686120464, 1.2385914666998772, 0.1508275897152001, 0.10073973466792416, 0.6346315265663209, 0.6539747563581313, 15.629483134515825, 59.3827820593311, 33.84404159361316, 27.578088583484774, 51.34624958038331, 1.1656331751615772, 0.18479801203695037, 0.04470887976968962, 0.03251075286478285, 0.026443313521843766, 0.008500781653809452, 0.03605247309972202, 0.02740660971481233, 0.030242688277916565, 0.025312899078633037, 0.029611353304297216, 0.02290280179060515, 0.013723793878941046, 0.09347063278959644, 0.0384441536340502, 0.02100354342180635, 0.053989552336955265, 0.13281821093011287, 0.015005431205575025, 0.10124303145153869, 0.0060723547545832495, 0.09680092424875307, 0.5093612581972153, 17.046860033465972, 76.76294942055979, 39.2016109343498, 32.858877528098326, 45.81485648309031, 60.37059568589734, 9.388340096319876, 0.12660552131673022, 0.2606787911105541, 1.8843077339472312, 1.6689180078045016, 0.817418021540488, 1.20740715294115, 0.16729313279351882, 1.0016532194229866, 41.2354108595079, 98.90610187284409, 85.5414648978941, 94.90522938389933, 88.47820620382987, 93.03727119199692, 83.1711373790618, 74.50606469185122, 72.29780166379868, 81.72458294899234, 82.00539327436879, 89.4835175237348, 85.26147827025383, 84.75948549086048, 80.73864813773864, 67.43369394733061, 62.777738571167, 64.0223301610639, 65.72095963262743, 64.2489254859186, 63.58096153505387, 72.7665170546501, 75.18969458918419, 78.87207846487723, 80.9473103861655, 82.99805102809783, 71.28286484749087, 61.23515275216872, 59.837922127016135, 67.24480828931256, 78.30670018349925, 75.75417072542253, 71.85504451874765, 70.14317312548238, 73.59987951094105, 75.52458655449652, 70.56945631580969, 71.15817269971295, 72.87206803598713, 76.03737369660409, 76.57132594816147, 65.79624168334469, 65.97643929143106, 75.59581679682579, 72.42439223874, 69.74754718042189, 73.76490931357108, 66.76540836211174, 71.65757671479257, 76.03373373708418, 67.71706950279975, 60.60116044936642, 71.31932720061272, 79.18594652606596, 71.6979928170481, 68.85931076542025, 74.75104808807373, 73.50746062494093, 64.62031902805452, 57.25298996894591, 58.854717285402366, 56.78894612096972, 63.19571810383951, 58.89071287647371, 56.10384141245196, 55.2822970574902, 61.21127336255966, 72.0816869120444, 68.57724528158866, 67.21379018598988, 63.75982161491149, 64.55680016548403, 69.31836928090742, 69.40221386571085, 62.51928183340258, 61.34298655294604, 63.48747184199672, 61.193697221817516, 65.63387909243184, 66.52018962367889, 69.5331661162838, 62.603942271201845, 60.916546467811834, 60.38344144821168, 66.17275391855549, 64.42145878268828, 63.04554623942222, 61.402539899272305, 68.3894500424785, 72.39628453408518, 67.15631177348476, 71.28250398943501, 66.31839936779392, 66.79921919299711, 68.42991321317612, 64.64305308557326, 57.38617012577673, 56.80178011617353, 54.488785882149976, 53.666943427055116, 56.21945719565115, 64.3221208357042, 67.6535035717872, 71.84209285243865, 69.28833961486816, 69.67672486459055, 68.20355323053175, 64.73114951964348, 61.14651110864455, 60.48393257202641, 58.66726329249721, 56.77138959207843, 63.1850649464515, 70.12418885384837, 64.29767270242014, 67.49616161469491, 60.778926187945956, 63.449424851325254, 75.05154086697486, 76.95208611026888, 80.08116475997433, 80.75200773054554, 78.11678686449605, 65.90984529064548, 15.86370844994822, 1.8630584161127768, 1.2713115109551338, 0.8628407228858241, 0.3716205493096383, 0.41148050237567196, 0.09728562041756608, 0.5699908048395188, 0.5652460239587292, 14.610936757056946, 69.77423498707434, 34.85602878755139, 34.49107969960859, 64.58925777865996, 3.2846168068147477, 0.29441592433760244, 0.12080740784445118, 0.08137428832630958, 0.02708293756680383, 0.045209108371167414, 0.05583966616541148, 0.02793695897825303, 0.027673118297130834, 0.09378675131067153, 0.020923257407341755, 0.02920323528439528, 0.0979767083340595, 0.20220147656096568, 0.12901637703180313, 0.09784177726795597, 0.22621867006584523, 0.36257587012744724, 0.16271149799708398, 0.2411667308619907, 0.1614369268739416, 0.2093753690320638, 0.6788636047032572, 19.696525027675015, 91.75868834218672, 42.0978969143283, 43.34392409170828, 62.14630365371705, 75.94034994802168, 14.535943000547348, 0.2458726404415023, 1.3030114938174526, 4.964933712636271, 3.64778146147728, 2.5110523546895673, 3.6087805994095343, 1.2444832344208996, 1.3130040995536314, 46.79305245799404, 106.25153233928066, 90.56999052724531, 101.63635392342846, 92.63980957769579, 98.57972145080568, 86.76518163373395, 78.439833271888, 75.33485366452125, 86.77854907128119, 84.81058612946542, 95.36988119925223, 89.45608446674963, 87.65346511717766, 84.49785555562666, 72.7889294778147, 67.05617366298553, 69.08603160612046, 68.86267615902808, 67.8797851070281, 67.0212959474133, 77.44092326010428, 79.77867941702567, 82.00863315213113, 82.54658622126426, 85.8620245225968, 74.196487703631, 66.38602102956465, 61.85301234645229, 70.15372430124592, 81.31922168116417, 79.68065938641949, 76.9758007603307, 75.60053933051326, 79.3828808876776, 80.37829999000796, 74.1458655941871, 74.26921629136609, 76.59606825920844, 78.84365697060862, 77.15721038080032, 69.25253621993527, 67.92592786973523, 77.63004426033267, 74.96052618949645, 72.62910858277353, 76.16878094211702, 72.7142632392145, 70.62301235814249, 79.72830833927279, 73.87766176654448, 64.5581220042321, 72.2768718965592, 84.06552407049364, 73.90842099343577, 69.89563234390752, 76.91309775075605, 80.10040790803971, 66.97709868031164, 58.2241766683517, 60.271022396702925, 60.16158434652514, 64.81005191802979, 62.72964246811406, 60.287617944901996, 59.54818840949767, 65.29765352126091, 74.19786837793167, 70.89280866807508, 67.83466216056578, 68.58263461820542, 69.66266708989298, 73.38206245053199, 70.79746369392642, 66.50115043886247, 64.28903172093054, 67.10936884726247, 65.66155141399753, 70.69296390779557, 69.17332787667551, 72.80796866263114, 65.4419614422706, 62.531264674279, 63.293353742168804, 68.32677841186523, 69.09216619306996, 66.88780200096869, 65.14285326004028, 68.34265616632277, 73.61057973677113, 68.18967588486211, 72.91716744822841, 69.67396351598924, 71.08036072023454, 70.97164046379828, 67.87046555549868, 63.10598996377761, 59.31977702725319, 56.16498331869803, 57.19104005444435, 60.5909191408465, 65.73860637603268, 70.43004743514523, 76.2993174214517, 71.14511905177947, 73.85721837320636, 71.87009857546899, 67.93181142499371, 63.803434448857466, 63.262586670537154, 62.64917504402899, 60.73873758316041, 68.2075148244058, 74.91181035195628, 68.04165347929924, 72.22118208485266, 64.36017174874583, 69.22606806601249, 76.95754604954874, 83.11555739372008, 83.84536927746188, 86.73874485877253, 84.98754778215962, 75.4712030964513, 16.635299459580455, 2.9397865360782993, 4.785447034143633, 4.71872849810508, 3.3852895853980898, 1.198550931388332, 0.18671951376863066, 1.2523739400409883, 0.9126700845456893, 18.027334905439808, 77.57053406007829, 47.5352394196295, 38.44700182637861, 69.81677701396328, 3.15599272808721, 0.5126417079760183, 0.2202963660801611, 0.1403656172295732, 0.11561129392395098, 0.12068625870010546, 0.13227415060804737, 0.09737659335857439, 0.1797709277560634, 0.20738003174624137, 0.15230525074706924, 0.21222852561022007], [0.05741846229460451, 0.03531284202190657, 0.027583951408404018, 0.029278233376962524, 0.027506679949921467, 0.005707822349523345, 0.03998207131160363, 0.030641852645203475, 0.03080228677830629, 0.13027988584531894, 0.1672448998978061, 26.096556417403686, 61.84112756483017, 27.746979959549446, 41.20856615804857, 54.33868854276596, 40.34742547619728, 5.102387782066099, 0.06872453726828098, 0.09047658498128576, 1.5607338903411743, 0.783460163060696, 2.0236737136879275, 0.7978088673084014, 0.3639681583210346, 7.5920941079816515, 78.49336577999976, 87.19046069729714, 92.40565976788922, 86.65141720925608, 88.2451311234505, 87.14838151008853, 77.7927912435224, 64.32743564728769, 71.96639276319935, 74.8114525887274, 84.56083313111337, 82.4310802644299, 82.30339142584032, 80.06176471710205, 80.26368048883255, 71.58500502186438, 63.00404364062894, 60.241839962620894, 59.26520116867558, 57.87368935923423, 61.36150798489971, 65.27863787066552, 70.67475626545568, 74.49326992034912, 74.75266410458472, 74.09738509885727, 65.8840282501713, 53.95113875789028, 58.56701927800333, 69.55489604703843, 72.64593555081275, 70.5899703118109, 68.45289830238589, 63.325587780244895, 65.61500464716266, 65.92981799956291, 67.11089857162969, 68.1646982316048, 68.69010756092688, 65.9193923396449, 64.62365696507116, 66.67920251046458, 71.2538157739947, 69.06507830465995, 66.44204032036566, 73.19539685403147, 65.69142026285972, 66.89526234903644, 71.03279021478468, 63.04990399268366, 60.23902370083717, 66.18041822987219, 74.33771656405541, 65.77465688028644, 70.16533451695597, 66.81131578260853, 68.1454864625008, 63.340798731773134, 63.271051145369015, 48.79652069460962, 57.6468155460973, 63.5554975078952, 64.20643444984191, 59.61375082692793, 56.07374114374961, 46.442769112125525, 53.53062145171627, 65.48562526702881, 70.57334730702063, 67.51038412893972, 64.97332842119279, 62.62389536826842, 63.315103284774295, 64.65838563057684, 64.72972177690076, 59.35029698956398, 66.0165729830342, 60.99747673157723, 62.21419203665949, 62.68184054282404, 65.15831524325957, 64.34568643569946, 60.73979662310693, 60.1588543768852, 63.89387646029073, 63.578055058756185, 60.24323632640224, 60.17690120204803, 59.1835884125002, 68.6048823018228, 66.78508297089608, 67.06365754527431, 65.69757838403025, 64.16080943999752, 64.35702600786763, 62.57414010263259, 58.16092452695293, 54.717789542290475, 49.62225021854524, 50.12078346744661, 54.83119703108265, 61.96969109196817, 65.72083411678192, 68.40563374180948, 67.73833659387404, 66.92311117725988, 63.034222356734745, 59.716426710928644, 57.48275064652967, 56.34367473663823, 52.061042708735314, 57.948979254691835, 62.79376537569108, 66.96674362305673, 65.70544273622575, 62.786697264640566, 56.0867634127217, 64.8572027298712, 73.00803307564028, 77.60132466593097, 74.93706257112565, 75.33290816891578, 69.98914949355587, 70.83631869285338, 25.570495974633005, 1.3733356686369067, 1.3753544635349706, 0.9476343986968842, 0.8961146180668186, 0.11888425902373369, 0.05227692064739043, 0.7109189297883742, 0.42865294542524124, 5.501526209615893, 66.11366733427971, 44.20506477355958, 30.695633503698534, 52.11839560539492, 10.385210475613995, 0.4502249088498854, 0.08976915640936745, 0.1520532844287734, 0.18791556087953432, 0.05637482837623647, 0.06889021910366512, 0.030076039256528023, 0.03350020521470616, 0.10745883138189394, 0.06366208270793, 0.0630926112494161, 0.03926310545554565, 0.06616127602155171, 0.021299649811079426, 0.033031397709442724, 0.04786588980125324, 0.03051480079340118, 0.04038873759488906, 0.02613789916429068, 0.06551845164428796, 0.08851458018104877, 0.18135061637768823, 36.37754755635416, 68.0335263283022, 39.41027710514684, 44.31578936115388, 57.160955475222686, 47.84539299626505, 6.140927460885817, 0.09821170580483253, 0.06700299214571714, 1.4083379194621117, 0.9101212180910573, 2.493890024000599, 2.202674140853267, 1.8836446082399738, 10.133557088913458, 88.24737471918907, 91.04422077055901, 97.99659836676814, 92.11449438525786, 93.45348173572172, 88.2574865894933, 81.15450566814792, 67.78394591423773, 75.71726122210103, 73.39905415811847, 84.7548492493168, 85.68414503528227, 86.72471061829599, 83.26526641845703, 83.67529530679026, 75.86898634510656, 66.76492198821038, 63.870310860295454, 63.57554866421608, 60.04619213842577, 63.331506636834916, 68.28240071573566, 71.96549061805972, 76.31104530826693, 78.7621344289472, 76.41611776044293, 69.32341344894903, 56.90896280350224, 62.53040959758144, 73.73229872795844, 76.68101110766011, 73.91617944163661, 71.22240543365479, 67.77364577016523, 69.75191670079386, 68.26373807845577, 68.00080591632475, 69.74083992742723, 71.72370003115746, 72.29154940574401, 66.95638856580182, 73.18897201168922, 72.15538040284189, 72.75366736996558, 71.96265082205497, 75.01376059747513, 65.97682368370795, 69.90110797266807, 73.76455630025556, 67.92924619490101, 63.40619248728599, 71.53345723305979, 74.90515801214403, 68.65766955960181, 71.83824892966979, 69.21323407080867, 70.16157688633089, 67.47916206236809, 64.50762148826354, 51.954483678264005, 60.5902680273979, 65.1260341367414, 66.51414132887318, 63.68654389535228, 58.448755894937825, 49.83832574659779, 54.31548772319671, 66.38613085592947, 72.07564646197905, 69.75588613940825, 69.1730768449845, 65.99554123417025, 65.38351420433291, 66.57797398105745, 67.3280958975515, 61.93648822845952, 67.73456327376827, 64.55832988985124, 64.83351161403041, 64.04564865173833, 65.69317748469692, 65.61216092878773, 63.607080598031324, 64.41579488015944, 66.88742545343214, 65.33666541499477, 64.66607739848476, 62.843814819089836, 62.66228360514488, 66.45501552089569, 68.2955720347743, 67.45001885198778, 68.77526221736785, 66.52783040077456, 67.10168100172474, 64.8075572906002, 62.38675279002037, 58.68306652192147, 52.86193970711001, 53.104844247141195, 54.87336251043505, 64.2074268094955, 68.0344049392208, 71.45130711217081, 69.2003216282014, 68.79060652948195, 64.9363757717994, 61.74874005779144, 59.31463479995728, 58.40153448043331, 55.29027908079086, 60.22156130883002, 65.49430547222015, 70.21713333745157, 68.1997642209453, 64.5882026610836, 58.781619994871086, 67.62487026952928, 76.2556065282514, 79.98656503615841, 79.13300237348004, 80.44381926136633, 77.65450416072723, 77.24973909316525, 30.526871565849554, 2.7669583261013035, 1.1645384661612974, 0.27163127437233925, 0.2398935540188705, 0.13316664303983414, 0.026176291660615997, 0.9201783590739774, 0.45861703433817436, 4.834880175129061, 75.54562614810082, 46.00800575748567, 30.371579047172304, 62.33870375540949, 15.08861574434465, 0.6414573699716599, 0.08184687264503972, 0.12279097035887743, 0.1347572407535007, 0.03773714641049024, 0.10120648139667127, 0.026469289648136305, 0.07299669552594423, 0.03844842457422807, 0.07695860349603238, 0.06797822973420543, 0.15642436762009898, 0.169786503838916, 0.18595272104345983, 0.10022008956800546, 0.15580152281590048, 0.1168511306206065, 0.10089073825867907, 0.13664060662831032, 0.16500283633508991, 0.22482716328194066, 0.32029483407255144, 38.72965174336588, 80.87592324902936, 41.8630842239626, 56.53263099731938, 70.11394362295829, 61.681177231573294, 11.310552512445758, 0.3116567943605685, 0.2501909861401204, 4.169713854789734, 1.902366448794642, 5.418602891506688, 1.7816526875380547, 2.4480563930926786, 14.021761455843526, 97.42805081029093, 97.80518670235911, 104.52573653190368, 98.79109013465144, 100.23241212291103, 94.25482196192588, 86.32466023968112, 70.76801453867267, 79.97147960047569, 80.59668971646218, 89.89793162192069, 89.11439111155849, 88.49275819716915, 88.14399673092751, 87.95216145053988, 79.99144446465277, 70.10871902588876, 67.53650711428735, 66.14882746050435, 63.12149901543895, 66.74332541804161, 72.903227344636, 76.94351180907219, 78.83793031015705, 83.33542193135908, 81.00283545832481, 73.59521973517634, 59.14106599746212, 66.21426043971893, 75.75487675205355, 77.87347439796694, 77.12204240983533, 74.08106019420009, 70.70579005825904, 73.0702732455346, 72.35943778868645, 72.93060548843877, 75.2473848096786, 78.37903653421711, 77.44319039006388, 73.34192091418852, 76.27794834875291, 72.68442184694352, 75.54455926341396, 73.30532520048081, 78.92402633543938, 67.89816533365558, 71.00496492078229, 77.79960047814154, 70.08349034094041, 67.3265112600019, 72.98981758856004, 81.11718039358817, 70.97374285421064, 73.71178473195722, 69.4665878049789, 73.92880947359147, 70.8417001847298, 68.94853684210008, 54.14168750086139, 62.75193329780333, 68.91558108791229, 66.27182514436784, 64.71226722963395, 59.733791043681485, 51.83691063234883, 59.069278778568396, 70.08187432442942, 74.92664475594798, 72.13155592641523, 70.84279844837805, 67.37775310393303, 68.49314182035386, 69.17984685590191, 72.14286019725185, 66.63147511020784, 71.97902279515421, 65.75172670425908, 67.7690330628426, 66.68557243962442, 67.71889732730004, 71.43184431137578, 62.4454471372789, 67.24579672659597, 71.38497983255695, 70.5216661576302, 68.97982951133483, 66.44317780771564, 66.1859566165555, 72.68311177530597, 72.97544602424868, 72.28856840441304, 71.26777941180815, 69.13865412435224, 69.93294977372693, 68.74770364453717, 64.38159181225684, 62.94515709723196, 55.9311943669473, 56.663818590102665, 60.423202514648445, 68.27345771174278, 72.9970661286385, 73.38144271604477, 72.72534001258113, 72.58070653484714, 69.25812167506065, 65.38649520566388, 63.0175522835024, 63.80117516363821, 57.2693266407136, 64.37579062677199, 69.40219033148982, 74.20757232173797, 72.71024673215805, 70.18710367141232, 63.413923478895626, 71.10660137668734, 79.63588160853233, 87.45662489245015, 82.34518820239653, 87.44833300190588, 82.15825588472428, 87.3981580426616, 31.46878169428918, 3.234537700491567, 3.7267848608955263, 5.143287316445382, 2.6957937834724306, 0.4750542168415362, 0.1697021728802112, 2.3026536405086517, 0.6845681405355853, 7.438937319863228, 82.98222818682271, 61.466007771030554, 41.300922286125925, 68.6662595502792, 17.601545933754213, 0.9181683895088012, 0.5202782562663478, 0.27684925244219843, 0.3495375439524651, 0.14887988777650943, 0.316220686560677, 0.20274794239911342, 0.16556272403367106, 0.17389144808534654, 0.2899694274510107, 0.20087499532007402], [0.035227767957915226, 0.0498926596746089, 0.06399972063879814, 0.05403150714212849, 0.03621288425018711, 0.03328599553975848, 0.04842548255598353, 0.01719725663743673, 0.09174645998545232, 0.01532784409655799, 0.033893212150301666, 41.38908540048907, 61.138752660443714, 31.935249567031864, 54.53742719465687, 56.579189531264774, 25.27147996810175, 2.723986064234088, 0.3106610945636227, 0.2892583752832105, 1.395644148991954, 0.697254617848704, 0.36188108966715876, 6.3676453598083995, 3.5263860658291852, 43.32144106588056, 96.99163221543836, 80.74135457315754, 89.942121044282, 84.43669011515956, 86.6972069586477, 79.09501029599097, 70.12600883360832, 64.91985082626343, 68.01765641858502, 70.14551085810508, 78.64220403855848, 81.9160181476224, 84.49082666827788, 80.90101857339182, 80.61303815534039, 79.92078688836868, 71.45166797022667, 62.0762893461412, 58.45156823435138, 57.60727021002001, 59.27814106787405, 63.770757182951904, 67.68636518909086, 73.13255263913062, 71.81028243034118, 69.3829236492034, 59.33147353510703, 55.98953177852016, 64.21097263213127, 71.07144909520304, 71.3748836517334, 72.72282969567084, 65.98744546213459, 63.58310707153813, 63.91113881141909, 63.04493042730517, 63.05928237976567, 66.42231864313926, 70.54356867267241, 68.22179225183302, 63.33020440993771, 60.12521220791725, 63.693490412927446, 68.49962942061886, 71.3627556831606, 68.86893626182311, 70.29245853424072, 68.91198819683444, 63.542377179668804, 64.91168445156467, 66.27622604370117, 73.84844795350106, 65.20887851715088, 68.41048179134246, 66.62734093204622, 67.6620464940225, 67.54835267220774, 66.18603506395894, 49.55809985437701, 55.096816016781716, 64.52457789451846, 65.56282143439016, 65.40558930366271, 65.00174991546139, 64.71488345053889, 58.141791205252375, 46.97177525489561, 50.25764672986923, 57.69070686832551, 61.77270181717412, 66.81781907235423, 65.24023394430837, 64.8335979061742, 62.68935972644437, 66.31281391266855, 62.65062632099275, 59.65881493783767, 67.49959761096586, 59.84544131063647, 63.346603839628166, 61.23680407001127, 62.31347114809098, 62.68335457771056, 58.77200626557874, 58.69148392831126, 61.147024939137125, 60.170574418960086, 59.65595945235222, 56.553674513293856, 59.68038405141523, 61.100352656456735, 65.08350779933315, 64.98616241639661, 66.6497298209898, 64.6907961753107, 62.460120724093535, 62.52432992381435, 59.828759470293605, 51.480127919104795, 49.67146027472712, 51.368916957609116, 60.37030543050459, 64.24997668112478, 68.30206747977965, 67.50412402614471, 69.0729465792256, 60.79622384040587, 58.973918114939046, 56.74002632018059, 53.824689388275154, 53.7540239672507, 62.01440611193257, 66.51272927561115, 68.52727428559335, 64.76543887968987, 60.93746054557062, 57.08666970652919, 65.38305136465257, 70.0650316669095, 75.57630692758869, 75.6667567837623, 75.13471080410865, 69.81127785098168, 66.18572127434516, 44.24542988500288, 7.145201313880182, 0.5115255485138586, 0.0537939585985676, 0.055934787472529765, 0.1497870584529254, 0.04511739232487256, 0.30185411714257737, 0.21352505281327233, 1.9803507674124934, 64.66215110594227, 45.05904320747622, 29.97696899598645, 48.23386453813123, 18.55193622650639, 0.7584173003992727, 0.16944167234243887, 0.05173445378820743, 0.05314050475135446, 0.11155470514730101, 0.01783905637210175, 0.07283589367063777, 0.010790841582591736, 0.014973432670587735, 0.029300055391485655, 0.02919531968091765, 0.025464369983021772, 0.0163140568521715, 0.046287629933607195, 0.08814045348234716, 0.030127225421188824, 0.014188942356756138, 0.0423089599597358, 0.050768462880965204, 0.02065365382980916, 0.03169479644707134, 0.048410930715861826, 50.285644608159224, 69.075300001329, 40.2662088794093, 43.312753015948886, 59.662600025053955, 31.401724853823264, 3.248508937897221, 0.31525373038265014, 0.28409874246966454, 3.0281803348372063, 1.4337400467165056, 2.7713680507675296, 7.818544305139973, 10.707661663332294, 49.11551921598373, 103.38206752654045, 82.43239033606746, 96.82743395528486, 86.00199822456607, 90.1352507068265, 83.01442300119709, 74.3936417179723, 67.06244161052089, 72.81395419951409, 74.67902552696967, 80.5822632389684, 84.81017035822715, 84.32384352530204, 85.2982936366912, 82.88324325315415, 81.16042060236778, 75.35035487144225, 65.99619234761884, 59.871423090657885, 62.301201974191976, 60.51715112501576, 65.75370357882592, 68.76130642429476, 75.86907263725035, 74.53048536854406, 73.72930988188713, 61.494052717762614, 59.06197532530754, 67.88962241142028, 73.40345505745181, 73.0433657861525, 76.66767504907425, 69.06048128681799, 66.74626719567084, 65.23751574177896, 66.44006344579881, 67.71698321065595, 71.82811352514452, 71.76297864606305, 73.2374603517594, 68.5505731644169, 63.39742991232104, 67.69290770253828, 71.08066666510798, 71.949016663336, 73.46201604412448, 72.21092116448187, 69.38956029953496, 63.86265047134892, 68.29669383264357, 67.15370731969034, 76.3575646185106, 66.41088885645713, 69.77699633567565, 69.1360104468561, 72.80461111376363, 70.65866670300885, 66.33624615207796, 50.22003119991672, 58.72957406505462, 66.42420922556232, 67.15093028160834, 66.56478697253813, 67.97885633284046, 67.74903681970412, 62.05070372550719, 48.43034782717305, 52.59726601262247, 59.871744725012014, 62.06274932430637, 70.01272293829149, 69.04641566738006, 66.92477426221295, 64.35689264728178, 66.32153726393177, 65.41346542296871, 62.43118539933236, 68.81996939259191, 62.87618614012196, 63.85473905071136, 65.37494774787658, 64.02234977291477, 64.47220248560753, 59.40872069328063, 63.70370034248599, 64.03098290966403, 61.92118314004714, 62.96350594489806, 59.43720886784216, 62.380641737291896, 63.61103042479485, 67.91805959516957, 66.22651392413725, 69.8918511790614, 68.50232801129742, 66.48369589159566, 65.86832308000135, 63.89064442726874, 53.81545612888952, 52.9022930514428, 53.561584641856534, 62.03188027105024, 66.96303306087371, 71.47942266156598, 70.96148152505198, 71.6703950205157, 63.08341672343593, 62.11860779793032, 59.66736962718349, 56.9939370309153, 55.28224998904813, 63.784395264041045, 70.27887144396382, 71.87347181381719, 67.61243635608305, 63.447710775559955, 60.666609118061686, 67.15875148773193, 73.12593952302011, 77.54955722439674, 79.23397987119614, 77.84127173885223, 76.7731632724885, 71.7913922955913, 48.65602139503726, 10.164273169732864, 1.275707629899825, 0.082118604031782, 0.06607533627820593, 0.11759061997215595, 0.11986068404850461, 0.40356739634467714, 0.3273254068147752, 1.7339556856501488, 70.75767517089844, 52.873667593925234, 26.07615617013747, 59.60219160203011, 25.818889871720348, 0.5373136615080218, 0.12303591931178687, 0.1896535232663155, 0.09441541838309458, 0.034401714501361695, 0.08816456226932426, 0.0946027345414604, 0.037395938509894956, 0.08537986330808171, 0.033332968220835736, 0.05128183755122366, 0.1465960877436784, 0.11055976377740023, 0.1576441941001723, 0.19225578604926988, 0.12570458659601788, 0.135217399126099, 0.15507691089184056, 0.1665651194390751, 0.21631871500322897, 0.136561622963317, 0.10061605743342832, 58.466975304388235, 77.69360234660488, 47.129689878033055, 70.0314091097924, 74.05552556437831, 43.13355953462663, 7.25540961950056, 0.5769951773747322, 0.4178159269354036, 5.801980255111571, 1.3400861044083874, 4.261196274911204, 19.752563930326893, 15.60865338771574, 50.814497778492594, 110.31882624472343, 86.65397459460844, 104.74495780083441, 90.99497933541575, 95.04280259532314, 87.73872175524312, 78.05726097476098, 71.73765582423057, 75.89630957572692, 78.78461745477493, 86.18814606820384, 89.54129403637302, 89.62211055140342, 88.8399193363805, 89.23172489289315, 86.8154271956413, 78.21012358511649, 69.95234981659921, 65.19621710623464, 64.74085738581996, 64.89310810642858, 69.73460335885325, 73.68871335060366, 79.94650979195872, 77.87885588984336, 76.99799353076567, 65.61160787459343, 60.52721592687792, 71.2354669263286, 76.34891186991047, 75.7129309254308, 80.50704786854406, 70.1659542514432, 70.29012080161803, 68.53176932181081, 71.23913042006954, 72.39614332875898, 73.36328214214694, 78.35285079094672, 78.14647920670049, 72.62306028796782, 69.54451745556247, 67.33892163922711, 75.56826606873544, 74.62242572538315, 74.96929660920175, 73.11916951210269, 74.46701357441565, 66.14225356809555, 70.94731392398958, 72.13127351576283, 79.71265023754489, 67.6065763350456, 72.20833240016815, 73.08746891637003, 75.02041293728736, 72.96411037445068, 71.88689416454685, 55.69306727378599, 61.57313554517685, 69.38442199460923, 71.66233847218176, 69.61912878098028, 70.45439750917497, 70.82979186888664, 63.471743137605735, 50.23648162041941, 54.45180185379521, 62.79963716383904, 66.50588081729028, 72.82321099312075, 71.1480059162263, 71.56234941174908, 64.71291834308256, 71.2879325497535, 67.78007845724782, 64.74572896957397, 72.23307471121512, 62.727292968380844, 68.26587969256987, 68.72331434680571, 66.73362931897564, 68.12547452988164, 65.03457230906334, 64.82291729219499, 68.19274317833685, 65.71163223635766, 66.05294119927191, 62.8558761073697, 66.4861826742849, 65.21642515736242, 69.80107968853366, 69.1238118756202, 72.78699182694959, 71.70040115233391, 69.21035505110218, 69.05561754780432, 67.09233791597428, 56.57000334032121, 56.92303234531034, 58.57593090303483, 68.67929750873198, 69.78667674526092, 75.51414520509782, 74.12280205757388, 75.26519237026092, 66.19640581069454, 65.38952719780707, 62.693525283567375, 60.7707872698384, 60.52961641742338, 68.05718606518161, 72.32076321878742, 77.24883694802561, 71.55337502879482, 69.45165926410307, 62.27874640495547, 73.38510620978572, 77.3554705035302, 83.58495527698149, 84.63527971698393, 86.81944370269777, 82.00619343788394, 83.18227691035118, 52.55495540557369, 10.438573341215811, 1.5127129251918487, 0.607958244940927, 0.1670851092785597, 0.3589157471733709, 0.19020979502989402, 1.2741749637549924, 0.8432577382172308, 3.147728539282276, 76.59007487758514, 64.76065751044982, 39.474749103669204, 66.277951886577, 31.248799485545007, 1.1526623872979995, 0.38173674034976196, 0.28909354380542235, 0.21375864834314395, 0.24185138363992018, 0.1191926477176528, 0.19863245678284477, 0.11624746099715272, 0.13998730769080503, 0.12462308495155267, 0.17973622397309352], [0.0908395651006891, 0.03465668388432072, 0.06001388008195547, 0.022016554890621095, 0.11866056901072303, 0.01999499824559016, 0.03811416892154563, 0.006494090466144225, 0.057911543295748776, 0.08066012584153684, 0.8200276234457571, 48.42138128895914, 47.88493048760199, 25.781346905616026, 60.04947908463017, 42.816761462919175, 8.168289305702332, 1.1926065793921872, 0.23918642422124264, 0.07710619033464501, 0.4594346340144835, 1.137984878113193, 3.2021026409441427, 6.722653690845736, 11.229716385564497, 99.63622754619968, 85.00465716085127, 91.27959435985935, 81.19867940102854, 82.63884036771714, 76.22841665821691, 74.21758221041772, 67.43344291563957, 67.6604304775115, 67.19617089917584, 71.84901191342261, 74.08874803973784, 83.96355813549411, 81.47639105396887, 82.25966484315934, 79.18717030555972, 79.91151440528132, 77.07326381437241, 73.66070762757333, 59.486030609376975, 60.017237201813735, 59.57436238565753, 61.734697972574544, 62.98197246366932, 67.53529902427428, 65.71934361611643, 64.90285127393662, 57.241199324207926, 57.44587252216955, 66.44592346683626, 72.71193335133215, 70.31473759681948, 72.6077316653344, 68.6424272291122, 65.87122563392886, 61.237129626735566, 60.6080206747978, 60.18638157075452, 65.27355055655202, 68.48767403633364, 68.28407164542907, 65.55021493665635, 68.04137106864684, 63.445361275826734, 68.53412274391421, 70.55185271847633, 71.45639050391414, 68.19266473093342, 64.05645870393323, 68.06948661804199, 68.11845348727319, 69.1922886140885, 64.75480533415272, 65.91035519876789, 66.80291406569943, 68.21317088219428, 70.53383334990471, 64.87085257807087, 50.19049575251918, 48.511121196131555, 64.65690297465171, 63.506722834802446, 64.64311584349602, 63.0230357570033, 64.73979834587344, 63.62891251041044, 60.12729498647875, 56.75524903881935, 51.82554360358946, 57.17910428200999, 57.83700735338273, 56.34245487951464, 61.09220981597901, 67.40937525226225, 61.67845118430353, 58.23077801735171, 65.9101120118172, 59.12483915205925, 60.884328119216434, 64.03096722018334, 63.66196240148237, 60.391470539954405, 61.84849377601378, 56.337673510274584, 56.515113692129816, 60.73630571365357, 63.07704287190592, 60.80630433174872, 57.7352963724444, 57.3278562484249, 56.13292578727969, 59.599759732523275, 63.83925745564123, 63.29850381420505, 64.44906442396103, 66.54945050516437, 65.71635084767496, 62.3122787475586, 63.56029064424577, 55.22971376296013, 49.17877527975267, 52.2184552684907, 56.517808360438195, 63.765567887213926, 66.76795790272375, 67.39171674174648, 62.9217876157453, 63.079259011053274, 60.47742535991054, 54.62805355748823, 52.47549995299309, 56.75726513708792, 66.38129849587718, 69.2726501341789, 65.51724741535803, 67.17263667814194, 59.964540158548665, 59.06736858429448, 67.73544972942722, 72.05536780818817, 73.89592432206678, 76.68893429540819, 72.27157669682657, 69.0689379169095, 67.38424854893839, 60.37186653383317, 19.913838063516927, 3.336886311731031, 0.030955010236451225, 0.09031692459698647, 0.11740529564239326, 0.06546153131151392, 0.018599390976070877, 0.16898931274490972, 0.08604799156948444, 58.35277157445108, 55.42832297663535, 34.00328590023902, 48.04373941113872, 33.49545663402927, 0.10735321850065263, 0.07024476214522316, 0.018946842493249044, 0.03728424289053486, 0.05898294024049275, 0.03886068329936074, 0.005567533934804341, 0.05438264354222244, 0.026864219464421756, 0.08393570330114135, 0.04642437279765164, 0.04959498088987124, 0.029959888835888238, 0.05218590940198591, 0.040222197741029725, 0.038015845366903854, 0.09101526736612282, 0.07593369276653375, 0.016197649792077082, 0.06290475116862405, 0.14081941707239998, 2.709859402910356, 57.97764001354095, 61.46514877196282, 34.311380232534106, 47.37452814655919, 53.811706343004786, 8.943033410656838, 2.834523358652669, 0.17701000816399054, 0.07921249545629948, 0.6532489953021849, 2.3599599590224605, 3.9581169380295664, 10.534719459472164, 13.33959754436247, 105.79515672499134, 86.3898657214257, 95.17497862538984, 83.61654604634931, 86.92255496978761, 79.52151313904794, 77.37693371311312, 70.3229824189217, 72.29052174475886, 70.27742801174041, 74.44885300051781, 76.64823578250024, 86.37310151130923, 84.4823072802636, 86.48868591554704, 81.58286771466656, 83.5276416040236, 81.28304958343506, 77.99990807810138, 63.094446428360484, 63.8976066343246, 61.138858564438365, 64.83603762042138, 65.80741651596563, 70.41682904766452, 68.47574218626946, 67.14834151729461, 59.249562678798554, 60.98573707765149, 69.82253505337623, 77.12400359492149, 73.24910979117118, 76.23297445235714, 71.32990975533762, 68.07766868222144, 64.6624021376333, 64.1143411205661, 63.31183987279093, 70.97282501959032, 70.92296384995984, 71.24226047146705, 69.19343394617881, 71.18129114950858, 68.22478109790434, 69.7986948874689, 71.95817932005852, 75.28980916546237, 68.37114826325448, 69.1758538830665, 69.72882178521925, 71.72137798801546, 68.47546762035739, 68.11860253733974, 67.35312846399123, 68.99664078989338, 73.37877550432759, 72.86700817846483, 66.15724486689415, 52.93435842760148, 51.8347768629751, 66.48768886443108, 65.73697859241118, 68.18878158446282, 65.27510773751044, 65.29769274496263, 65.98821424668836, 64.68200222138437, 60.683047771453865, 55.366216167326904, 57.99400414189985, 60.735230984226355, 57.81602267296084, 62.62418954603134, 70.61252394030171, 65.31451971300187, 58.56452072820356, 65.14545379146453, 61.64719773877052, 62.3784452099954, 65.61185890628447, 63.59834547965758, 63.78392065725019, 66.30389444289669, 59.13034615978118, 58.894670547977576, 62.274816190042806, 64.56520972713348, 63.04680532024753, 60.296356985645915, 59.39138773948916, 58.24028192027923, 62.91821041414815, 66.58148842473184, 64.30792577805059, 68.63788512445265, 67.25563403098815, 68.10088126890122, 66.97916184702228, 66.96067179402998, 57.94119727226996, 51.95648800942206, 52.36660711226925, 59.751135764583466, 67.39206191032164, 68.84198173399895, 69.90849771807271, 68.28491103264594, 62.18252674225838, 62.85623696542556, 56.43423441917666, 55.85450418533818, 60.12380407702539, 70.44670966363722, 72.68394331778251, 69.4148438976657, 67.8624011624244, 62.16323260338076, 60.68491089728571, 70.50095604312035, 76.17005179005285, 77.10667456350019, 79.76535120318013, 77.29741942497992, 75.92009482845184, 75.52781858751851, 64.41527320492652, 23.33057745810478, 5.07900212080248, 0.08839916137437667, 0.24677547506026684, 0.36103260132574266, 0.15521713562550085, 0.0361558260215867, 0.4120131786311827, 0.3566329890201169, 62.288650389640566, 65.1023430209006, 32.35092078485797, 56.751499252934615, 43.76065631066599, 0.0654344117989944, 0.08885416397524458, 0.033832380938674175, 0.06267811171710491, 0.049335805684207916, 0.031022803272090616, 0.026748907910059058, 0.005476784595708934, 0.012145738939814752, 0.0801419056651573, 0.03750726257661178, 0.18035513108536122, 0.16302712622188753, 0.15585818267878027, 0.09431889896551449, 0.27528710723403965, 0.17234672371658588, 0.12419887142436159, 0.07758106525626875, 0.18603617866193095, 0.2589788113630587, 2.8846791963423453, 72.50305929491597, 65.4010707332242, 40.969976225206935, 77.51943342147335, 59.92624998092652, 22.42446876341297, 5.682120467385938, 0.5955779576493848, 0.37233751567621387, 0.8465245209874646, 2.168587273167026, 2.844218231977955, 17.104601244772635, 14.839847260905852, 113.9705450304093, 90.38661972168954, 104.27350459560272, 88.21957295940769, 93.14291631021808, 83.08395093487155, 82.33480176618023, 74.95912198097476, 76.6916250413464, 74.12348454998386, 79.79035239065848, 81.9044706898351, 92.6701138096471, 86.74408712694722, 88.02289747422742, 85.23637510115101, 87.05862199106525, 84.65417769647415, 81.53716425741874, 66.25753202745992, 68.52399518412929, 66.14829401816091, 68.85115223546183, 70.77541212881766, 73.34863601192352, 71.71568270652526, 71.90310924283921, 63.17858911329701, 64.47075513101393, 72.49375543286725, 81.36283059273997, 74.30942058563232, 80.98643210626419, 75.31683429594963, 72.17612189631309, 68.44219807655581, 67.1913306943832, 67.49016823307161, 73.83840668585994, 74.7104750910113, 75.2179434991652, 73.54144404011389, 75.30451020886822, 69.85177240064068, 73.69750730452999, 74.07950693561186, 78.58231729076755, 72.55770575615668, 71.14081228933027, 72.36976931172033, 76.85004957260625, 71.87237355016893, 71.10485984433082, 68.10688249526486, 71.33359678329961, 74.4572860963883, 76.73449654732981, 71.89850438025691, 58.25359836701424, 54.28017462453535, 70.69112039381459, 68.7561994983304, 70.7099477706417, 67.5369385750063, 67.44858326450472, 70.28358613291095, 66.32955458856398, 63.45844630272158, 57.250867966682684, 60.15274332415674, 63.73063525845928, 61.68362479056082, 66.0542748051305, 74.6016606976909, 66.88497789444463, 60.80162886650332, 68.01817417144775, 64.17552617288405, 65.27535484683129, 67.95910327665268, 67.1365273383356, 66.12478333134806, 68.68954273962206, 64.46987652009534, 62.36283417670958, 66.34962143436556, 67.93124660368889, 66.97957761826055, 64.7778178799537, 63.39862231285342, 61.342331517127256, 65.39444977237333, 71.23785172739338, 67.14794143553704, 71.61515235900879, 71.3569741095266, 70.98876553197061, 68.88482186102098, 71.38259503149217, 60.38288447164721, 56.247462918681485, 57.11425181358092, 64.39256660399899, 70.20587613505703, 72.71397298382175, 73.15673797361313, 71.3813320282967, 67.71245679547711, 68.89717732706379, 61.78031121530841, 58.41688271491759, 61.76221339933334, 72.70230001018894, 76.28150201612904, 72.48570672927364, 73.2671134702621, 66.05330205732777, 65.6029119799214, 75.22628245815154, 80.76262950897217, 81.35843753814697, 83.86133332406321, 83.09036008773312, 83.89648560554751, 84.69692368661204, 68.81978896356398, 24.155159688765004, 6.364366748640615, 0.3218720252475431, 0.646257002747828, 1.0186769801282114, 0.3480913231690084, 0.22010705043231288, 0.9011410128685736, 0.9897665991898507, 68.6399326016826, 75.58605793983706, 46.09846345839962, 66.8052988667642, 46.52200883434665, 0.1687368101650669, 0.19116964191198352, 0.12719239829288376, 0.10405052152852859, 0.20349245728744617, 0.12110854168572735, 0.18988722604849648, 0.09838364657855804, 0.13714728185967093, 0.20992971025407317, 0.2028167677382308], [0.023438306825776255, 0.07718030934131916, 0.02485468465414259, 0.025471174759009195, 0.05876177831763222, 0.040801026963538704, 0.06692176384310569, 0.09394024468718037, 0.07951758997214418, 0.2677642463916733, 6.09391785437061, 65.04847318895402, 28.872694315448886, 24.886701337752807, 61.48013222602106, 25.56824257296901, 0.8820139424454783, 0.7490235302717455, 0.2631759313085387, 0.07549082499838645, 1.151151049040979, 2.5484337681724183, 2.57124847942783, 0.9973441280664938, 53.10000404234856, 98.01060907302364, 82.04041219526722, 88.25181484222414, 79.73023030065721, 77.50888224570983, 71.15752158626434, 69.31387424468994, 66.66736479728453, 67.76276511530723, 70.01848097770446, 75.56701875502064, 77.26615028996622, 81.30457555094074, 79.69209701784196, 77.07987693048294, 78.36934827989148, 78.2051186407766, 76.91592185728013, 77.90075056014523, 73.62177418124291, 61.72845748163039, 57.602845776465635, 60.7606283310921, 62.439783234750074, 62.76909366730721, 61.56533395090411, 59.898911060825476, 58.93127018405546, 59.94708953365203, 71.90274054004301, 74.6221354699904, 75.6589355776387, 68.36616685313564, 67.14211279346098, 64.23649549484253, 59.725871778303585, 59.89998971262286, 62.696341545351096, 65.556808440916, 65.21602899797502, 68.03962953629033, 65.74767881824125, 65.9725090765184, 69.35286260420277, 66.46238957681965, 69.48500725530809, 67.93135643005371, 64.88942500083678, 71.79902522794663, 65.27136187399587, 68.83799660590388, 65.49725117221956, 67.25974467492873, 66.19467212307838, 68.27591311547064, 69.88003700010239, 56.021361812468506, 53.074034029437655, 52.48815351916898, 61.34998798370362, 63.35960649674939, 67.67975991772067, 67.7661854220975, 65.9108337279289, 66.89532510695919, 67.93202323298301, 63.68167623396843, 64.8964342763347, 56.89537963559551, 52.981670056619954, 62.86871010257352, 61.70257768323345, 53.470946511914654, 62.375138651940134, 66.36782907670545, 57.90817091541906, 59.41769115386471, 64.72335969248127, 58.26341605955555, 61.307461646295366, 67.82109860450991, 60.988604330247455, 59.025924821053785, 57.73576313449491, 54.712635547884055, 60.588722613550004, 60.24730382427093, 60.17832110005041, 59.34301707052416, 57.73515908948837, 53.3800926516133, 54.20489649618826, 58.91521592294016, 61.50405476170202, 63.66156624209497, 62.98274517059327, 63.43812450285881, 64.60913635069325, 64.29662542958414, 56.36565962145406, 50.017789871461936, 50.89573398713143, 53.18351130331717, 60.188762449449115, 66.7254472547962, 66.82944497754498, 62.71980124135172, 60.38803846605363, 55.69109039921915, 54.451758707723315, 54.512908458709724, 63.77734676484139, 65.94143606001332, 69.07766126817273, 68.8650688048332, 64.52446806815364, 60.357632252477835, 60.854875041592514, 67.97158425854099, 73.36041881192115, 77.16271738852225, 77.2010781688075, 71.64961430334276, 67.94241751393965, 65.12625378947105, 69.79495294632451, 37.4087308299157, 8.628588761052779, 0.2080982544970128, 0.05917236314065034, 0.06485140356685846, 0.32710290423804717, 0.19669564861443736, 0.2397610054862115, 0.12280044686650077, 46.37972485634589, 65.61069396234328, 33.40058234430129, 36.129979318188084, 43.20149498601114, 0.253738509491086, 0.06406377325014723, 0.07581117232480357, 0.07332294939025756, 0.088742989295673, 0.0062751439737997235, 0.04851932832670789, 0.03890033984076112, 0.02552054146484983, 0.013988775073460514, 0.08553504207802397, 0.09120786953116618, 0.059988024614511005, 0.040786793049905574, 0.04918289453452153, 0.03177019865101865, 0.03958722576498985, 0.09339207047296148, 0.10502588169108476, 0.12545832763275794, 0.41979966565005244, 11.546258522618203, 73.68978808003088, 44.54061961943104, 23.923010287746308, 61.22351900223763, 31.07385785348954, 1.1243912914106924, 1.563585576030516, 0.34286991302524844, 0.172576580737387, 1.1284817106300786, 2.517506124511842, 1.9895815753167676, 1.1135776845678207, 56.99831831839777, 101.48241658364574, 85.16643924097862, 92.34088574686359, 82.35462542503112, 80.52820513325354, 73.99135558835923, 73.3629212840911, 69.26856302445935, 70.01882614627962, 71.98103104868244, 79.09336290051861, 77.51077282813289, 83.61420831372662, 82.72881169472971, 78.49056520769673, 79.86483820023076, 79.25894183497276, 79.77259974325858, 82.0058012008667, 77.78837465470838, 66.10599517822266, 58.48383365138885, 64.6424804195281, 62.459300948727524, 66.25397051534345, 63.800955510908565, 64.16061332148891, 61.014350768058534, 63.6160392915049, 72.71473392363518, 78.75618811576598, 75.57784449669623, 72.98852320640319, 67.48184496356596, 65.87438706428775, 65.38047436744937, 62.45398221477386, 65.83080953167331, 69.13582217308783, 68.45955848693848, 70.26078147272911, 69.72529165206417, 67.63619022984659, 71.83447560956402, 69.13550838347405, 70.50383506282684, 71.61856482105871, 67.92639070941557, 70.81847975330969, 67.06406547177222, 71.25041900142547, 65.75549610199468, 68.64070138623639, 70.41541699440249, 72.43434721423735, 70.80978778100783, 58.72494174588112, 57.27972092167024, 56.815802589539565, 65.60868570881506, 66.12439109433082, 68.92006043464907, 70.29620047538512, 67.47403944692304, 72.2427394313197, 69.59238606114542, 66.76189391843735, 67.22813821608021, 61.91549178092711, 52.559336693056174, 64.3973401284987, 66.8762388537007, 57.99711850381667, 62.632681477454405, 69.3224956143287, 58.35404242238691, 60.9585746642082, 65.95132043284755, 62.90956551028837, 61.5908097451733, 68.50020993140437, 64.05643909208237, 61.949898812078665, 61.13729353873961, 56.523495797188055, 64.62707727186142, 64.07789445692494, 63.17404308626729, 61.08379633195939, 58.96204902279762, 56.006174395161295, 56.35399057019142, 62.22337822760306, 64.64214309569329, 65.91108475961994, 65.23058883605465, 65.12548500491728, 66.16512098620015, 66.98240172478461, 61.00665115541028, 52.46897705139653, 53.466898625896825, 55.699554874051, 61.60724839856548, 68.55323253139373, 69.50499565370622, 65.51452529045844, 61.79369041996618, 56.446691866843935, 55.021910513601, 57.23575507440875, 66.37925101864722, 69.25382275735178, 71.71394901890909, 71.18104011781755, 66.56922709557318, 62.722570434693374, 64.85070336249568, 70.11130779020249, 74.12499074013003, 79.16792715749433, 79.43333825757428, 75.8733872444399, 74.79251538553547, 72.24724231227752, 74.200880758224, 41.770320169387325, 11.323312963208846, 0.43843104654262144, 0.1350418424173709, 0.30464525124238384, 0.38410088768409145, 0.4705465554950699, 0.267401427150734, 0.15517956667369412, 48.817764251462876, 78.76036936236967, 29.993080131469238, 44.05026058996878, 54.1760866872726, 0.8059362634535759, 0.16458902628191058, 0.036055476164385196, 0.007038913045694391, 0.053860546960946054, 0.0443834149759383, 0.038123852272908536, 0.047079829964786775, 0.0390658684585604, 0.0990487028273844, 0.045472818817342484, 0.2059588313943917, 0.12110871022507069, 0.0864680145957297, 0.21726786729789552, 0.1957622930527695, 0.22531948202560026, 0.31902876652536855, 0.18206267978154844, 0.1838920211359378, 0.534144876705062, 10.673305622992977, 91.22894871619441, 41.61518650670206, 38.079624791299146, 79.85335350036621, 37.65564795463316, 3.218485400561364, 5.327260696118878, 1.162395503732466, 0.2626050732308819, 3.3045762777328496, 5.494677260998757, 3.750935139194612, 1.8268582489221328, 61.234933099439075, 106.65010006197038, 90.7434691152265, 98.59328500686154, 87.59082486552578, 88.65200642616519, 80.36628184779998, 76.20896170216223, 72.79297736383253, 75.97991881832, 75.62736049775155, 83.06834774632608, 83.7379434031825, 87.92492451206331, 86.98124931704614, 81.86151289170789, 82.13985996861612, 82.52921012140091, 81.5660721255887, 85.96810110153692, 80.0080753141834, 70.12689528926727, 61.38702300287063, 68.37279565872686, 66.79411226703276, 70.142914249051, 67.96572423750355, 67.12326188241282, 66.22121872440462, 66.95272507206087, 77.04000211531117, 84.19169102945636, 78.45514620504072, 74.39870942023494, 73.48346356422671, 72.03729352643414, 68.1498795170938, 66.73437456930837, 71.10005886323991, 70.96589026912567, 71.14482879638672, 74.76035979486282, 72.81125560883554, 75.2832038940922, 73.22734848145517, 70.3940793006651, 75.63859416592506, 75.38749187223374, 69.08525497682633, 76.11614273440453, 69.56109339191069, 74.97915744781494, 69.15401412594703, 71.90325044816541, 72.19103474770823, 72.06238885079661, 75.26377247225854, 62.86707839658184, 60.66829181486561, 58.68945606293217, 66.9585850930983, 68.36346826245709, 71.20381339903801, 73.6075673564788, 69.77526264805948, 73.4553558595719, 73.42222752109652, 67.6337662050801, 70.91671159190517, 62.16833952934512, 57.83905483061268, 67.03340822650541, 66.00759075533959, 58.715324094218595, 66.18933769964403, 71.53592048152801, 60.78469991683961, 63.758240899732044, 68.97883322931105, 63.556944862488784, 63.050837516784675, 72.56218510289347, 65.13752668134629, 62.93697895542268, 66.48481768946495, 58.44955605845298, 67.4148508810228, 66.92733949230563, 66.88048285822715, 65.13431426017516, 65.28037548065186, 59.733092861790816, 59.901605729133856, 65.6986491910873, 66.98040131599673, 68.33515659455331, 67.75135886284613, 65.91646625149635, 70.39378904527234, 69.5512011743361, 61.36610108037149, 56.419003855797556, 56.51717685884046, 59.44903089154152, 66.30201954995432, 72.73454973774572, 74.27460562798285, 68.41509449866511, 68.13439399965348, 61.22684909451393, 60.73528981977894, 60.87185890443864, 70.49101675710371, 71.90617653631395, 75.97354104441982, 75.17340890822872, 71.15170863366896, 67.42725341550766, 68.1034621884746, 75.0863322904033, 80.07113918181389, 84.71313092016405, 84.33836413967995, 83.44860584505143, 83.99395650432956, 80.98386687617149, 81.2778014521445, 42.65620316228559, 13.680862380612282, 0.4529215383433527, 0.5681112540825721, 0.5862191824182388, 0.833806113129662, 0.7175029345577764, 1.294780767733051, 0.33303346665155503, 53.512107864502944, 86.10395631482525, 45.81301296910932, 52.531472175352036, 62.4542450135754, 0.8982900013366054, 0.2852149632188582, 0.18186849181450185, 0.1896863884382671, 0.19070759896309147, 0.10211788087842927, 0.2199673313166826, 0.14541752275920686, 0.19025562240952448, 0.32368357804033066, 0.16745076304481876], [0.025003261661397356, 0.0839281420133287, 0.008700309253688301, 0.032112854457790815, 0.0751340501911698, 0.05498939666957144, 0.052648228142530694, 0.031398301268176686, 0.050225674264854005, 0.1166701729920122, 28.936909398724957, 56.689298306742025, 29.297940038865615, 35.327156436058786, 50.34169920029179, 10.808085126261558, 0.3730159018549227, 0.483772328063365, 0.20618862712815886, 0.04570767839228915, 1.5995499107145494, 1.674172022650319, 0.5915523188248758, 2.0932559476744745, 74.21187123944684, 91.72792911529542, 90.44518070836222, 82.52777453391784, 75.75926980664654, 70.15262603759766, 69.45007462655344, 69.42346526730445, 67.78092568920505, 67.41416838861281, 70.59816806547104, 74.98539401638892, 78.73802754186815, 79.69397191078433, 80.70444506983604, 81.12575469478485, 77.60321524835403, 76.36927681584513, 81.69685179187407, 77.38582180392358, 74.36064674008277, 69.53994397194155, 58.054200756934385, 55.40989175919564, 58.83365023520685, 60.29167367566017, 57.025978872852946, 57.477282862509455, 56.075867068383005, 61.56633023292788, 72.43378239293253, 72.22462592586395, 70.74841837729178, 68.45609111170616, 63.363097406202755, 60.40563421864664, 58.10148885173183, 59.517786118292044, 60.107361501263036, 62.47078957096223, 64.8496090212176, 65.2615402590844, 66.06390030153337, 66.67968888436594, 67.78967257468932, 67.47906792548396, 66.07217650259695, 65.4656486357412, 68.99507184182444, 64.86733813439646, 67.06237885259813, 65.74938897163638, 65.65071390521142, 66.33712476299655, 68.32782960707142, 70.65799205533921, 57.98084851234191, 60.10635737449893, 58.79303801444269, 60.42970580439414, 68.39851071757656, 65.9903480160621, 68.004681218055, 65.31319002951345, 66.02025216625583, 67.22457670396375, 67.17138151968679, 68.69042135054066, 67.59658213584655, 66.8555679628926, 53.090590353935, 53.49113102882139, 68.08914553734564, 64.53538010197302, 56.95248542293426, 61.50067760098366, 63.953978938441125, 54.38765148962698, 61.607028745835834, 60.94941200748567, 61.88894910197105, 62.97381785608108, 61.36699538077078, 59.39353719834359, 57.69489988203972, 58.89129338725921, 63.17903626349665, 61.34610483723303, 61.202789275876945, 59.08374840213407, 53.71011303317163, 56.12171173095704, 53.38965146772323, 53.9742297510947, 59.04154762145012, 62.053778863722286, 63.51390469458796, 62.504800442726385, 62.787281697796246, 63.39747305839293, 59.924959521139826, 52.4096433577999, 51.04276011067053, 51.77091675419962, 52.997692938773866, 56.3125507293209, 60.324539215334006, 58.11186744320778, 52.83025872322821, 51.73532516725602, 52.60502053845314, 58.044041818188084, 69.02980835207048, 70.20600165090254, 69.53151872081142, 66.59458129636704, 64.28553688910701, 57.55057234917918, 62.86559966302688, 69.6218744401009, 75.56173140002836, 71.93554724416425, 74.94751176526471, 71.1420831372661, 64.80841628966793, 65.64235141200405, 73.72927065818541, 54.01040969356414, 17.08370677886471, 0.8521061150297042, 0.00344478449645272, 0.18588778743099782, 0.5668136849999428, 0.14653090898308063, 0.1814308257833604, 0.12850256186098824, 38.05390581007927, 76.96458278163787, 34.394122631319114, 28.257639215838527, 46.119581499407374, 2.197707929918843, 0.30756888790957393, 0.11838722117846051, 0.06672129395507997, 0.08362362972430645, 0.017690012051213174, 0.06204069592058659, 0.08036539649530765, 0.03985878478194918, 0.0926978032915823, 0.025676248835459835, 0.06211238259810114, 0.050388521574918306, 0.043161320875609116, 0.014764080950689894, 0.03574695723551897, 0.017405130765250614, 0.035272450036098885, 0.0102927541968623, 0.04116861510180658, 0.03909460441660016, 40.4420526566044, 63.7288898037326, 38.04646899623256, 32.53386993562022, 59.02965891745783, 11.906539009463403, 0.5885322163662603, 1.2424046233777077, 0.3421540498252838, 0.02832847587283581, 1.0549116519189652, 0.40601523112385507, 0.5639392005339746, 2.506793886423111, 75.74682020371961, 95.88904611525997, 93.27709274907266, 86.43213318240258, 79.8573229389806, 73.01088071638539, 72.74424583681169, 72.79878247168757, 71.6337836173273, 69.28426034988897, 71.65152841998686, 76.62391708743188, 80.49855985949117, 81.59159106592979, 83.06771232235818, 82.79845729950937, 80.64804923149848, 79.92526623510545, 83.02032224593624, 81.40665915704544, 78.38534370545419, 73.50400109444895, 60.77029697356686, 60.159681996991566, 60.94070434570313, 62.775141962112926, 58.74181185999225, 59.32140088850453, 57.88303636735486, 64.37903834927467, 72.84693348792293, 72.18803805689659, 75.6991163376839, 70.26504901147658, 65.91690555695565, 63.1374591396701, 60.72713128982052, 61.36229638130435, 62.96141924396638, 65.90593860995385, 66.83103745983493, 69.64128232771351, 69.18452232114731, 70.96522346619638, 67.96373951819636, 71.92357617039835, 68.43037605285645, 69.71402660492929, 72.13556458873134, 67.7529356556554, 67.33032380380939, 66.54421806335449, 66.25969717579504, 69.25252053045458, 72.81051820324313, 73.46099622787969, 62.3932364679152, 63.61204631866948, 60.05557444787795, 63.51527752414827, 69.91322025176018, 69.54915369710615, 70.4821757347353, 68.79507018673804, 68.52499146615305, 68.4896352214198, 69.69865091385381, 70.28931279336253, 69.19814863512593, 67.81518367029005, 59.205683123680856, 55.10091489361179, 68.69209228023406, 68.92438288657897, 60.84866200723956, 61.61664247512818, 66.5921494268602, 56.20300285277828, 63.088790370572006, 63.24703055043375, 63.52107086489278, 64.12119742362731, 62.99251971706268, 64.40622037456882, 59.46302590831634, 60.15132734852453, 65.1668110970528, 63.05790955020536, 65.73272282077421, 60.205750234665416, 58.03966053070561, 59.51959040857131, 57.615632703227384, 55.678083819727746, 62.88242270869594, 65.16845064778482, 65.13307086883053, 63.99877632817915, 65.2476982147463, 66.51342745750182, 63.37291117637389, 53.72979548669631, 54.9631690979004, 53.171912854717625, 55.639644592039055, 57.64659197099748, 64.65877002285373, 61.17279098879907, 55.44877421471381, 55.22646604045745, 55.441470761452955, 60.542489636328916, 71.87707254963537, 71.37937868795088, 71.00766351146083, 69.46057088913457, 66.0272575193836, 60.6254203088822, 64.7065915599946, 71.03835998042938, 77.15428429265177, 75.56269630309075, 77.39412938394855, 77.30619768942557, 71.89797878265381, 72.7094465686429, 79.84750916880947, 56.46920627163303, 21.487873446556833, 2.059722379330666, 0.07714605755022458, 0.3346298713116877, 0.8874233812093736, 0.355594786665132, 0.5012275188440277, 0.12307274515830702, 39.93532949878324, 89.36711726650115, 35.929197111437404, 32.4731045769107, 60.679764747619636, 3.9923803123735615, 0.317478081992557, 0.06810356171861773, 0.08967412320236046, 0.06455033101261624, 0.04602136841464428, 0.08221294775965714, 0.06959688158765917, 0.019919607532961715, 0.05198494155680941, 0.07244492069848123, 0.25394598142273966, 0.17647596827197462, 0.11744510157093888, 0.15454671676120452, 0.1302985477471544, 0.19162264502336904, 0.16792117167384396, 0.1407072005132514, 0.16004669179599132, 0.26673511451771187, 47.457529421775575, 77.82555087920159, 42.119732749077585, 49.58300690497122, 74.37063309454149, 14.771620573536044, 1.322408962634302, 3.4457869971952135, 1.3283182584470319, 0.09943059765763822, 4.474572721988925, 5.4095745759625595, 1.6258758787185916, 3.851472596007009, 80.94602384874898, 102.78007784197408, 101.14688919436549, 93.37608552748158, 85.98284136864447, 77.95069802191951, 77.26416557065903, 79.13305728666245, 75.06424934633317, 72.66904615586805, 75.85566597600138, 80.16836689364526, 85.59508369814965, 86.93683239721483, 85.53145500921434, 87.7549054545741, 84.07304717648415, 80.9395048695226, 87.92319082444715, 85.10520319784843, 79.8278659389865, 75.59810746100642, 64.60911673884239, 63.1993894423208, 65.71831595513129, 67.30968429196265, 62.82937265211537, 63.17621607934276, 61.09300997949416, 68.6044979095459, 78.09027948687154, 77.86476673618441, 78.5276629847865, 74.1538123161562, 69.86662249411307, 66.20243057127922, 64.77745309952768, 65.65453821612944, 67.80442853127757, 68.62806350954118, 71.0834986163724, 72.44627906430152, 73.02196533449235, 74.33021699228595, 74.5750670279226, 74.48078109372047, 68.95584814010128, 70.94368965395036, 75.63000417524769, 70.90506999723374, 69.98978491752379, 70.37167472224083, 68.70211001365416, 72.02423987850067, 76.53008614816974, 76.33185740440123, 67.75593234646705, 65.2052777813327, 63.440262194602724, 65.7214303170481, 75.3167401590655, 72.81848845943328, 76.5853915675994, 69.6841146099952, 71.1843192192816, 73.33800638875654, 72.85327203812139, 74.28358785567745, 72.95574003650297, 71.42687074599728, 59.394666840953214, 60.13300987981982, 74.78493736636254, 69.42948218314879, 61.549675849176225, 65.93182625309115, 68.74571892522997, 58.52322993739959, 64.19456535770048, 66.33341420081355, 67.26098414390319, 66.90018884597286, 66.48163272488502, 67.19424109305105, 65.89032757666804, 62.70754383456323, 68.35310536046183, 65.38007820806196, 67.78753880531558, 64.63610264562791, 60.815133587006606, 62.928804735983576, 60.31312511813257, 58.923390142379276, 66.07358855585899, 68.53655461342105, 68.48205720224689, 67.06684250985423, 69.30097749156337, 68.62776540940808, 65.88628753539055, 57.32722082445699, 57.827868230881236, 56.65156510568435, 60.287496351426654, 61.486545301252804, 68.7372858293595, 67.09456582223216, 58.28985675688713, 57.77341396577897, 58.97473396793489, 63.16082862115676, 76.40683743261522, 75.53585160163142, 76.44735551649525, 71.96888739062895, 71.38602318302279, 64.44648350438764, 69.77492532422467, 75.69274640852406, 83.82145850889145, 80.38812160491943, 83.53982448577881, 84.53587901207709, 81.92543183603595, 82.18880330362629, 89.10535397068148, 58.3977533155872, 26.993396551378314, 3.1054238157887615, 0.3785445438998361, 0.5900282328647952, 1.9549570977687838, 0.71771627472293, 1.3579398754142946, 0.23269346134076196, 48.395430887899096, 97.57842663795718, 49.08142205207579, 40.38905751320624, 67.69588085912889, 4.274657849342593, 0.5683989354198979, 0.35132951553790803, 0.2079674220013042, 0.2689404977906135, 0.13969371215470378, 0.25393547069641853, 0.18896965189806877, 0.08620740680564797, 0.16673499177540504, 0.2987729115111213], [0.018056163774623026, 0.041114349263690175, 0.01695077933911835, 0.028807481923591227, 0.010246893300885155, 0.08450568803856451, 0.04676112972740685, 0.02569996883281537, 0.04220891270726439, 1.7124168478673505, 51.26115375949491, 43.70948114702779, 30.119951155877885, 36.5826561374049, 43.75834211226433, 8.796793722337293, 0.5069533212771339, 0.6193160193581736, 0.1571001337781068, 0.13457151039713813, 1.058159006699439, 1.0031567742266962, 0.060158119116339, 3.2820630986844344, 78.55322114882931, 91.94614625746205, 87.02758035352154, 82.0319712546564, 77.43534564971924, 74.60901121939384, 79.56105847512522, 72.32884330134239, 67.7808629312823, 68.81355239499, 67.7102602681806, 77.49565601348877, 76.65688068636003, 81.30394012697282, 80.07255123507592, 79.95353867930751, 75.66539179894232, 77.88496694257184, 75.80986838186942, 80.91742192545246, 75.1127141521823, 76.17646878765476, 65.35655575413858, 55.27799421741117, 56.54557089651785, 57.79655594979563, 55.670882348091375, 53.897939651243156, 57.550642951842285, 66.36532660453551, 69.66499697777533, 70.21521922080748, 71.05431618229036, 67.13686466217041, 62.27263142985683, 58.90266826075893, 56.991662056215354, 59.03694275886782, 61.83435755391275, 60.83484741949267, 64.49002573567053, 66.4145915738998, 63.54844508632537, 66.15635056649485, 68.90406500908637, 62.383250113456484, 64.52537805803361, 70.39433817709647, 67.25528886241298, 66.37749379681003, 64.94731918458017, 66.0737140717045, 66.4136423603181, 68.21995658259239, 70.05006390233194, 56.25381323599047, 59.220160591986875, 62.30238260761384, 55.235718911693944, 61.70533510946459, 61.64455798364455, 64.98790787112328, 66.39810977443572, 64.69138060846637, 59.287586135248986, 62.09015884707051, 67.84089088439941, 64.80634135584678, 60.550785449243364, 61.99399801992602, 64.2238615405175, 51.80405685978552, 52.593214204234464, 66.06084085279896, 62.71045423323109, 55.85721062075708, 65.53931859231764, 57.37261049209103, 58.440820940079234, 62.164319099918494, 61.060670037423414, 59.697564032769975, 60.919951085121404, 58.770123527896025, 56.91590147633707, 60.25047309937016, 61.67264607644851, 60.90954111468408, 60.603160858154304, 57.037373358203524, 55.35525706506545, 53.298311233520515, 52.11121766797958, 51.77154041105702, 55.808208450194336, 59.04679183037051, 61.44610174240605, 64.14393148114605, 62.65301112205752, 63.54502870190529, 58.40292299947431, 49.3668568518854, 50.60862041288807, 53.49197433840845, 52.43253431012554, 51.48872183215234, 51.24420127561016, 50.73124547158518, 50.297286202830655, 49.896647468689956, 58.137351082217315, 66.5125645360639, 69.99795913696289, 69.43778976317375, 69.26488384123772, 66.63050236240511, 60.59774406494633, 55.97853737492716, 64.42669122449814, 70.24181289057579, 72.54450305815666, 74.59969951260474, 73.97394810953449, 68.11758272109493, 65.69695864954303, 61.46881226570376, 73.78809052128946, 68.27045317619078, 31.491300021448446, 2.4259678106154166, 0.06118760722118521, 0.10326490602305821, 1.1656397941612429, 0.333000524870811, 0.2634156861853215, 0.10515811612769481, 30.56876640166006, 79.16194946535173, 42.16113728861655, 26.40310729703596, 31.599435844729026, 6.9443818446128605, 0.25979778999763153, 0.2474050001511651, 0.07250803102168345, 0.10447607570958715, 0.05111582629803208, 0.1261224186107997, 0.018715675462097413, 0.020441085498239246, 0.04578757370191236, 0.045731557352888974, 0.029613910122744502, 0.054161244132105386, 0.0452032707811844, 0.058022024665748885, 0.03590577109266193, 0.061282824289294026, 0.06315222055080437, 0.025989000400107716, 0.012091505660435126, 4.746408664411114, 64.45851341370614, 53.59225757660405, 42.016613637247396, 37.356767269872854, 52.91484855836438, 8.65187587276582, 0.42685591765949804, 1.203315630555153, 0.6905101636244405, 0.1446457657842867, 0.7244490844107444, 0.07254850344672319, 0.13424955428608004, 3.3915249282313935, 82.01938044640326, 93.2439330316359, 87.98316386438186, 85.07520491077055, 79.53935992333197, 77.04110037895941, 80.5248789633474, 74.89827817486179, 71.62613499549128, 73.12212697921261, 68.61092275188815, 79.16489124298096, 80.67403885626024, 84.0924785983178, 82.05781967409196, 82.42740108120827, 78.96082601239605, 78.97464060014295, 78.72012584440171, 83.0266607961347, 78.53704529423868, 78.1957833997665, 68.17783032694172, 57.81807407256096, 59.27750956627631, 60.3637158486151, 56.96113032679404, 56.205015028676684, 61.00579607871271, 69.99406030101161, 71.49515136595696, 71.66200114834693, 73.92762491779943, 69.98749425334316, 66.73571601990731, 62.99294333304129, 59.6416663354443, 63.677906836232836, 65.89739568771856, 66.77068787236368, 69.52190891388925, 68.71792501018894, 68.15746538100704, 68.3800285093246, 71.54269833718577, 66.63590738850256, 68.85173274624732, 72.66695945493638, 68.98645831692603, 69.28189908304523, 67.16864370530652, 67.85359936375772, 67.55975107992849, 69.94787046986242, 70.98532953569966, 58.37190881852181, 62.587393791444846, 64.6253357395049, 58.41905963036322, 63.02275334635089, 63.90949926068706, 65.53304280004194, 67.32599350713915, 65.34420028809579, 63.026828688959924, 63.99727406040315, 70.20598596142185, 68.82196195663946, 61.65277927152572, 62.43391929134246, 66.56979976161834, 54.09916116345314, 54.1291751400117, 66.11205131776872, 65.50529595344298, 58.23508870217108, 64.46699750038886, 62.70215842031664, 59.886983133131466, 65.01917308376682, 62.2611310405116, 62.80763487662039, 61.38331636305779, 62.2277085242733, 59.686738291094386, 61.33058794083134, 63.584326928661724, 64.58426460143059, 63.074567856327185, 61.401398489552165, 55.875214299848004, 56.56985429025466, 54.47106069134128, 55.07688645393618, 57.58596781761416, 61.46292871044528, 63.44445128594676, 67.52493612227902, 65.67302434675156, 66.3833930415492, 63.735726494942945, 51.510400772094734, 53.828203831949544, 55.993371778918856, 55.57214060137349, 55.069128005735344, 53.46148575505903, 52.71753372684602, 51.88779161822412, 52.09606162963375, 61.034033221583215, 70.1123982091104, 71.93510793870496, 71.77282379519555, 71.53545764184767, 68.1147978382726, 63.13867507442352, 59.769657196537146, 67.74982129373859, 72.90216830468947, 75.31039376412669, 76.85254420003584, 76.01125071125647, 75.24806730208859, 72.21864823372134, 68.77752934732746, 77.14484707001718, 70.43632322742094, 38.120754764926055, 3.864509083570973, 0.013307548623772399, 0.15401741129256066, 1.904956929145321, 0.5256795438547288, 0.16479070658885664, 0.11466583417307948, 32.95254568899832, 89.72525319745465, 47.825377141275716, 28.085311843502907, 46.38929936193651, 11.657830342169731, 0.35004227332049803, 0.09576405488675642, 0.14686659338974184, 0.031230085596982992, 0.03919859319144199, 0.038152082612918276, 0.05878860671674052, 0.11145263159226988, 0.027889281496285435, 0.07321613375097513, 0.18280147965396606, 0.16036543033776746, 0.23234749603415691, 0.21211171252352579, 0.17050307183977098, 0.2390309236943722, 0.18304256752373713, 0.13677830327182047, 0.08681651565336412, 4.496438955107044, 80.8908910136069, 60.59734006081859, 46.182888553988555, 47.19562884299986, 66.65897092511578, 11.799554401828397, 0.8276959184196688, 4.493943347084907, 1.571187742294804, 0.5026221665884218, 2.8376664029013727, 2.0720469567083546, 0.2677273209537229, 4.797574022123891, 88.7817584314654, 96.65965849353422, 95.8996129805042, 91.12500590662803, 86.09123214598625, 81.70211561264531, 87.51200875928326, 80.16187929338025, 75.55462406527612, 76.50028397960048, 74.82631052694013, 84.85363806447675, 82.73956683374222, 87.30156575479816, 87.08051666136711, 84.80154898858841, 84.089842765562, 84.27357442917364, 83.57139172092562, 88.41584836283039, 83.24472888823479, 80.86960038831158, 72.29764476899179, 60.22740956275695, 64.9280878036253, 63.40581986211962, 59.759906184288766, 59.25787418119369, 63.186598593188876, 71.29813071220153, 76.12634089685257, 75.27716344402683, 75.69924185352941, 73.13257617335167, 67.23504158758348, 67.19923819265058, 63.40390574547553, 66.3173952410298, 70.45808453713694, 68.34170695274108, 73.13329788946336, 73.19668339144799, 72.53173966561594, 72.20863834504159, 72.98422428869432, 70.8801394124185, 71.26498668424546, 75.05831087789228, 72.70056632257277, 71.38754506264964, 70.6577096446868, 71.26749700115573, 69.33245058982604, 73.31790031925325, 74.54209558425411, 62.4883774788149, 62.956524125991336, 68.747358475962, 59.3172823998236, 65.50532733240436, 64.05370912244244, 66.6817363615959, 68.7979962748866, 68.31275986086938, 65.54673579431349, 65.85378677614274, 71.07464974926364, 72.09926697515672, 62.96978565954394, 65.69326377684071, 68.24298874024423, 57.34609919209635, 59.31843165428408, 69.07455475099626, 67.62935746100642, 60.81761644732568, 69.45879013307633, 61.67615659775273, 63.04481667857017, 67.66993045806885, 66.65390322285315, 65.21500133698987, 63.61706695249004, 64.95744282199492, 61.47429181683449, 66.04973270047095, 65.91252819184335, 66.576279517143, 67.21485707067674, 64.04777457637172, 59.73052763169812, 60.52269343406924, 57.944288099965746, 57.94028728238998, 61.67287749628867, 64.89956432773222, 67.32123174974996, 69.39261190352902, 68.67222155294111, 69.48301469126056, 66.0707252256332, 55.70787029881632, 57.571007897776944, 59.29372856693884, 58.08365775692848, 57.06303742624099, 56.60176669397662, 57.82369482901789, 56.61160399836879, 54.75787616545155, 64.36260361825266, 72.59471724110266, 77.04273992969145, 74.5784559557515, 75.37344978701684, 72.18755952773556, 66.5195934234127, 61.81869160744452, 71.98432583962718, 76.30342022065194, 79.58932307458694, 82.85588864357241, 84.20054774130546, 81.21823633870771, 82.60387636000111, 78.0124439731721, 86.54633691233974, 75.48221711189517, 43.486294361852835, 6.047294601317375, 0.2858504791173243, 0.4423731817833839, 3.138467578157302, 0.9587200586834262, 0.5687417750877719, 0.19101522922996553, 39.81803886352047, 99.03536750424294, 61.66473073344077, 37.50213030845889, 59.97164749330091, 17.128757161478845, 1.166062306973242, 0.5699351562126991, 0.34773769698316054, 0.2724486289005126, 0.2144205329879638, 0.23296340008176145, 0.23636979471531608, 0.23525421747997885, 0.16853463956184928, 0.1513051995707135], [0.020262717246829022, 0.05250731776017816, 0.05093047132475242, 0.05585314165199957, 0.07312991055509738, 0.014388655732956626, 0.06054277952399947, 0.05101432730894416, 0.27693205122505465, 16.064907408529713, 60.547663242586204, 27.29357554066566, 25.084539805689168, 44.91903812654557, 47.978969312483265, 7.973203361034394, 0.2609789137157702, 0.725148982338367, 0.25794538939672135, 0.07535266104124247, 0.020310168732858954, 0.06979688416205107, 0.21345327037476727, 3.1835566941768896, 71.20877911967617, 92.25298543130198, 82.01610918967955, 84.85288496940368, 82.05770984772714, 82.00449112922915, 81.45055047927364, 83.70818830305531, 77.00904676991125, 70.46581945111676, 67.75845050811768, 73.99709793829149, 78.33500400666269, 80.04706367369621, 80.71909120005947, 76.67793596944502, 76.56443042139854, 72.84892605197045, 74.3581207336918, 76.11668402148833, 78.07453509299987, 77.32813942816951, 68.94951743464317, 56.90826854398174, 57.01001482625162, 56.27453119524064, 56.823290394198516, 54.355001680312625, 59.3116420315158, 69.90757203871205, 69.50136353892665, 70.49772401009837, 68.8541881499752, 65.21247533059889, 62.33828013943088, 57.98334706214167, 55.183963237270234, 58.571271127270116, 60.019284679043686, 63.855088141656694, 63.91448851554625, 64.46100804113573, 67.80896279119676, 66.9515875847109, 65.37597540886172, 66.62096315814604, 63.45486517875426, 70.18994346741708, 68.94834072359147, 63.793326500923406, 65.3915629079265, 61.20156941875335, 65.18697600210866, 66.37004913822298, 58.7366892445472, 61.529777665292066, 66.35986666525564, 56.01217954389511, 61.584082880327784, 63.05308895726358, 63.4772030768856, 66.39680754753851, 65.3871698533335, 64.18832486675632, 61.90907870569537, 65.32971497504943, 64.0167054822368, 63.99768198690107, 60.17470467475153, 61.76048363408735, 61.96409386973228, 57.14864315525178, 52.99870491027833, 55.98760197239538, 64.09867909646803, 58.54344975563788, 58.17813196489888, 63.384866560659106, 56.063370397014005, 60.588793216213105, 61.03145622438001, 58.36452691785751, 60.995695975519, 55.72798029068978, 55.794091839944166, 58.82327948847125, 63.72733262277419, 61.18048275670698, 58.571141689054436, 52.67674892179428, 54.067899873179776, 51.98305422259916, 51.1711432087806, 53.01561817046135, 55.733122517985684, 57.91674129424557, 62.897621893113666, 65.0965065340842, 60.409709561255674, 60.56756142647036, 56.996478726786954, 47.38496165121756, 50.26389506555373, 50.87383539445939, 52.97313105675482, 51.26202844804334, 51.2126850312756, 50.14441182536464, 50.928991763822495, 54.71514194242416, 64.0331402132588, 66.11603644586378, 72.44100739878994, 70.23021051960608, 67.34035722671017, 63.718805390019575, 59.82187178827102, 59.8428015555105, 67.83815307001915, 70.07550439526959, 74.88822906248032, 74.85197067260742, 69.04215597337293, 66.82889584572085, 60.28138922106836, 59.42701070539413, 71.1650368475145, 73.78108516816171, 51.03157351093908, 8.535626626783802, 0.16919816363482706, 0.014292127696887381, 1.0373512006575063, 0.2884185897006143, 0.34871764601238314, 0.11641668215874704, 28.879860485753706, 78.2652642649989, 46.899513429211034, 31.907406622363677, 19.35083869964846, 8.714853448252525, 0.20757811143994334, 0.1523535296080574, 0.05555322206008339, 0.10404022530682626, 0.007501937065934463, 0.07960477843880653, 0.02340800038749172, 0.1058185222228208, 0.030743435903963064, 0.1481406895383712, 0.03855799429959828, 0.07150925155128203, 0.04660593180526649, 0.036691359785054965, 0.056181264770848144, 0.06801045905317991, 0.04547687525290155, 0.06184002301926094, 0.130639165760048, 25.18377773223385, 73.41649301590459, 36.80339536359234, 27.460852861404422, 42.80602201338738, 58.19267611349783, 8.075802268520478, 0.2981160064378093, 0.5631909471365714, 0.6250494213834886, 0.05859092538875919, 0.11705533135682346, 0.058643911860042044, 0.38461453431556303, 3.4304039516756615, 72.48031739265689, 92.6551538898099, 86.1425995057629, 88.12709131548482, 85.85180282592775, 82.17798540669104, 83.52502930548884, 84.03612198368197, 80.58533053244315, 71.00825971172702, 70.74183664014264, 76.79269667594664, 81.28401448649745, 81.11469361089891, 81.94076830340971, 81.38529008434665, 78.64155292510986, 77.07577413128269, 78.0707617728941, 78.4408373986521, 81.4287813248173, 80.9641295094644, 71.07410846217986, 60.26206762559953, 62.207316121747425, 58.47823250678278, 58.03769934561945, 56.98142467006561, 63.65597686459942, 71.66229924848004, 72.09278721963206, 71.82012757947369, 71.67461549082111, 67.70061123755671, 62.51439848253804, 60.819181473024436, 58.800788617903194, 62.14978279605989, 63.0094055206545, 66.50875983699676, 67.99931541565927, 69.41179229367164, 68.42300984167284, 70.24952427033456, 68.82312297821045, 70.05931285119826, 67.06215135512814, 72.4284165905368, 70.30417073157527, 67.70582798988589, 68.05067493069556, 65.37824253882131, 67.01170182997181, 69.24092600422522, 60.989690826785186, 67.0193112281061, 65.32524347305298, 59.13056973488101, 65.7413520351533, 65.70174394115325, 65.86874669597995, 67.26545564589962, 66.94610411121, 65.43785079833, 64.69391445959768, 66.03780085040678, 65.6862662684533, 66.22237974597563, 62.941591662745324, 64.48581703247564, 64.69144336638912, 62.0522883630568, 57.44304449327531, 55.974081562411406, 67.84926906708749, 62.50548293513637, 60.88021747527584, 66.32174907192108, 58.3227889768539, 62.33711127311953, 64.59525116028325, 63.68795594861431, 63.35847685413977, 58.69700662551388, 59.66833845261605, 61.3792488651891, 65.55457268991779, 65.03816912251135, 61.1962781413909, 56.83367683041481, 57.380263036297215, 55.080844125440045, 55.082789621045514, 56.5455355951863, 59.21715213406471, 60.178991825349875, 64.87481809431507, 65.8118252600393, 63.645386465134166, 63.26199047027096, 58.89081878046836, 50.344476238373794, 53.75164308855611, 54.98420476913453, 55.24814890277002, 53.505012296861224, 54.651183774394376, 52.97872043425038, 54.49266118388022, 57.91062631914693, 67.28044694469821, 68.56054382939493, 74.00297364880963, 71.48258409192486, 71.24931289303687, 66.1447403507848, 61.12756606071227, 62.26544957007132, 69.11134658321258, 72.82988686715403, 76.83279114384806, 76.9329135648666, 74.13844446982108, 72.41926177855461, 69.17201780503797, 68.45483595325102, 75.81255128306728, 76.56439904243716, 54.459850557388805, 13.552121366223982, 0.12773522521339117, 0.3010406236975424, 1.8343903028195905, 0.19604450452231592, 0.47016240836631873, 0.1232033554885176, 32.9392017856721, 88.65721533375402, 56.80310587729178, 31.412782015339022, 27.122619036705267, 15.161904250421832, 1.2983319836278118, 0.06747402896684024, 0.09241451929894187, 0.04227186598244213, 0.048986048242377664, 0.0935148667063444, 0.08356204391607354, 0.07052351089735186, 0.030302835756071636, 0.05218096047399506, 0.1138170087529767, 0.17882266412338904, 0.1756755442869279, 0.2029918954377213, 0.1641175451297914, 0.2653642767860044, 0.12037130463267527, 0.11181375777889645, 0.2768386191418094, 27.988474407503684, 93.81127249810004, 44.20930877808602, 37.14684594062067, 59.320016291833696, 71.24079350502261, 10.212180999017532, 0.7518907828677086, 1.9880773463556844, 1.8309761247327252, 0.32077679530747477, 0.1946010110118697, 0.24988357037786516, 0.6297298508786386, 4.8019994362708065, 78.45200830890288, 99.05040587148359, 92.12794027020855, 93.8417257801179, 92.65057256144863, 88.10969952614077, 89.31660498342207, 92.36036423713931, 87.24171038596862, 75.06139386084773, 73.65578897537725, 81.22036226334112, 85.38449164359801, 84.41983176815896, 86.562708885439, 85.07872719918528, 83.40410263307633, 78.88482616793725, 79.6004939848377, 83.06245634632727, 84.43788251569195, 83.77886941356044, 74.21149469191029, 62.80006077981765, 64.66382988037603, 62.348694032238384, 62.338637075116566, 59.18463960770638, 67.97349837518507, 77.09622536936115, 75.69335829827094, 75.37241428129136, 74.36294524900376, 72.04028237250544, 66.1138399185673, 65.43455208501508, 62.912205265414336, 64.78689424453243, 67.08445395192793, 70.19545047513901, 70.46875338400565, 71.20022835270052, 71.41874359500024, 74.57232921354233, 73.09778474992322, 71.76914461197393, 69.70891183422458, 75.67774726498511, 73.04381293635215, 69.19383402793639, 71.68767698349492, 66.7279811059275, 68.20287073812177, 72.8789557180097, 62.40081840945829, 69.7065427226405, 71.08330249786377, 61.75388620745752, 68.01063537597656, 68.0876079682381, 68.59426052339616, 70.43090251184279, 72.09084172402659, 70.75885972669049, 66.76286666624009, 70.10183918860652, 68.08720004174018, 69.52758066115841, 62.78178645718483, 65.57905220216321, 66.67337386838852, 64.7532481531943, 58.540394229273645, 59.96649349889448, 68.40778320066391, 64.13615734346452, 65.16876051502844, 67.90877926734187, 61.885948488789225, 64.10704158967542, 66.97594550348097, 65.15314948174262, 62.840088567426136, 62.584612830992675, 60.63878774642945, 63.97223757159326, 68.77442283015098, 67.50119793799617, 65.17090212914252, 57.739054003069484, 58.735806711258434, 58.7919319060541, 59.63749685595113, 60.00206155161704, 62.876531308697125, 62.35131025314332, 68.49682884831583, 70.57310412006994, 67.17200125417402, 66.74099553015925, 64.39254306977796, 54.120243903129335, 55.06269924102291, 56.556600601442405, 60.392682552337654, 57.46532747822424, 58.07810368076448, 55.02174577405376, 59.557986490188114, 61.486313881412634, 72.47730501236455, 71.16431513140279, 75.9678065392279, 76.53863691514539, 73.5242405245381, 68.36161690373575, 66.54468874777517, 65.90762522912794, 72.76408518514326, 77.51114153092908, 82.49212018905148, 80.96861670094152, 81.37838671284338, 81.77934708133822, 79.73944002582182, 77.84169535483085, 86.34461725911787, 82.45263761089694, 59.53027886729087, 16.019739354810408, 0.8007431679194974, 0.9444849805966501, 4.182736614058095, 0.6866879364655865, 0.8940535964023684, 0.31811160606242, 41.60994229778167, 99.03051160996961, 68.35099512530913, 45.25061568906231, 38.83510466544859, 32.84430592290817, 1.903284283414964, 0.20346189037926737, 0.18297856853854272, 0.1712294917313322, 0.13154681141097702, 0.21821986943964036, 0.1584729633384174, 0.25394880062630104, 0.2455538865779677, 0.18273533562258368], [0.41290309700754385, 0.10215853716457084, 0.02438528917639727, 0.06011675036842785, 0.03951506411296226, 0.014693151742610482, 0.03142032821121956, 0.09684435377318053, 0.19601736968803793, 39.01678885183027, 53.47952865785169, 26.804669749352243, 46.46707604008336, 34.98577687048143, 49.50215508860927, 7.220405897786541, 0.5135265088850453, 0.4939074567969769, 0.2703629392049005, 0.17711787334372922, 0.28276905898124943, 0.10699115768675843, 0.07090255588052735, 1.3197009337525214, 65.06070706152147, 93.8025648363175, 82.3293653611214, 87.65612448415449, 82.01563850525888, 86.05313808687272, 82.63570247157928, 84.81880741734659, 82.74611719192998, 75.87139468039237, 69.29776899276241, 71.06120386431294, 72.48515759744953, 82.73336948886995, 76.29941940307617, 77.73921951170891, 67.35819616625386, 67.86338175496748, 75.03829894527313, 75.32795029301798, 75.05301567815965, 73.85976006907802, 75.12650520570817, 58.86295426276423, 56.93121048711962, 55.63302755355836, 58.13987316623811, 57.64464647539201, 61.233493589585834, 67.09751544460174, 70.410443429024, 67.04519102650305, 66.5360987570978, 64.68659139448597, 60.421280553264005, 55.81772412023237, 55.90075677441013, 60.5350959685541, 59.977656564404896, 62.05639116225704, 64.21163943506056, 65.6804140921562, 68.44310022169545, 66.35614825833228, 65.85378677614274, 62.91540199710477, 68.7280761041949, 67.68545519921088, 64.53162247134794, 65.60983104090538, 64.71955107104394, 63.19714976895241, 68.25030003824543, 64.66120973710092, 59.54847474252025, 68.5569352488364, 56.01050076946136, 58.05893505773237, 63.98442045334847, 67.629075050354, 65.93910617213096, 62.648531775320734, 60.80717902029715, 59.448873996734626, 61.46081063055224, 58.71916801698747, 60.63051546773603, 58.685780802080714, 59.97596210049045, 65.42095322762766, 63.0973058362161, 60.17910949645504, 61.74142091504989, 53.94781651035432, 56.207580258769376, 64.72043752670288, 57.73287234767791, 62.55256706668485, 57.58830947260703, 57.87125748972739, 59.99049055960871, 63.40352919793899, 59.90323743512554, 56.03010477558259, 54.93786981028896, 60.54054021835328, 60.548765428604625, 58.92322148046186, 57.63847658711096, 57.85085724246118, 53.602851898439475, 51.305072538314334, 52.77959739008258, 53.16105965645083, 57.03315681026828, 60.073166278100786, 61.16211429719002, 62.964164903087, 60.97818259269961, 61.32752849209694, 50.14551793375323, 46.856575242934696, 49.779290153134255, 49.86300137735183, 50.757745004469356, 51.74278159295359, 51.914514726208104, 50.60797322180964, 51.34490028504403, 59.908324749239036, 65.98043226426648, 68.34915945606848, 67.6704482109316, 68.58486252446329, 66.48746136696109, 61.94086167120165, 57.902624683995406, 61.47312687289331, 68.81863578673332, 71.1539286951865, 72.41847730452015, 70.9277883652718, 68.21539878845215, 61.1638597519167, 56.24543897567257, 57.83774083660495, 66.06896015905565, 76.07807220951204, 63.98846441699613, 23.733073434522076, 0.36058918963516917, 0.13729323693100484, 0.9724840233402868, 0.07672338385976131, 0.23055966132350508, 0.23299776678604467, 24.627432669362715, 78.09832819046514, 47.688137331316554, 36.98440490230438, 16.951987704923077, 9.597488718648112, 2.8777875919495863, 0.21738057415331566, 0.08408397195800658, 0.01782695218289812, 0.09922286525609032, 0.10700035840272905, 0.10007579690746723, 0.37010516610837757, 1.1117038947920646, 0.9337606076751986, 0.09373129420583287, 0.05607329999967929, 0.07804729104522737, 0.035009206903557626, 0.022317606377445405, 0.030734784856078126, 0.03916867362755922, 0.09015575501947634, 0.8963527181936849, 54.291965269273334, 61.00858488390523, 38.732546452553045, 43.64526018019646, 35.69052088645197, 57.80764449027277, 7.547087852031955, 0.5954075184079909, 0.2043754961942473, 0.2548634023555825, 0.25388755955763403, 0.30440583344428773, 0.002489047915479469, 0.0980220990435731, 2.0904995020358794, 64.8119778017844, 96.56957734015681, 86.01062743894516, 88.87715831879648, 84.91358757019043, 87.51369537845736, 86.4193384109005, 85.89165410687848, 85.36655072242984, 78.13765387381278, 69.3314072393602, 73.23917834989487, 75.16704682380923, 83.30838111139114, 80.70569238355084, 80.35052176444762, 68.96104135820943, 70.34450054168701, 77.74415385338568, 78.941818206541, 75.75416288068219, 77.13493131822156, 78.1433883790047, 62.70337435507006, 59.51108671003773, 59.075291772042554, 60.14473384426486, 59.819953749256754, 65.24968293405348, 72.8896951675415, 71.22122087786275, 69.05302093875024, 69.2988907906317, 65.99220721952378, 62.09388509873421, 58.24314132813485, 59.38429217184744, 62.577662391047326, 64.60563759649953, 64.84580039978027, 66.14681136223578, 66.90284036820935, 70.18861770629883, 71.58294185515373, 67.59500534303727, 64.37361763369653, 69.33035604415402, 70.36975276085639, 69.11282923913771, 69.17586957254719, 65.88300843392649, 64.17409058540099, 69.20386745083717, 65.22116338053058, 63.76223779493763, 72.53441472207346, 57.99266269130092, 61.14587568467664, 68.01643263909125, 69.03802179521131, 68.54226558439194, 64.5534896850586, 60.61655967466293, 62.97799125794442, 63.279021401559156, 62.63753737172773, 62.320703998688735, 58.69511212072065, 62.05198634055353, 68.23167662466726, 64.233341909224, 64.84123476089971, 65.17574625630533, 56.57807165576566, 57.63351478884297, 64.80914192814981, 59.82811227921517, 63.88324291475358, 59.542332310830396, 60.89850748738935, 63.19580831835347, 63.686590963794345, 65.26336416121453, 58.42506870146721, 57.3222041130066, 61.68533494395595, 64.32276802678263, 61.98578065441501, 60.366849822382775, 60.322405445960264, 56.182904628015336, 56.35575955913913, 55.008354802285474, 56.81665374386696, 59.350057724983465, 63.71263157936835, 63.525530599778705, 64.81329179579213, 65.89749766934302, 63.381497244681086, 53.5275149345398, 51.21968646203318, 53.42536857051235, 52.76244486531904, 52.86510505983907, 54.293769559552594, 55.2087486943891, 52.850808020560976, 53.90349764977732, 62.64735506426904, 68.12454885052097, 72.38731015113093, 69.45307916210544, 69.46137889739006, 67.57278903838127, 64.61508658624464, 59.040488581503595, 63.497556255709746, 72.2002052491711, 72.5533676147461, 75.22773373511531, 74.44506399093136, 74.60332378264397, 68.41456890106201, 66.56161769743889, 66.56771306068667, 73.45970969046317, 77.77843536869173, 66.50130733366936, 28.938917652253185, 1.552511499293389, 0.42859760323359125, 1.6880306144875867, 0.2367982370478492, 0.4323647027054141, 0.2587657163460409, 28.830901461262858, 87.22591892365487, 56.55049739345428, 41.78935543183358, 32.69045095289908, 11.92859841931251, 5.501187414892259, 0.31776775515848593, 0.015015885432911737, 0.06487890612334013, 0.059246543434358416, 0.06322470395976017, 0.10452774067920063, 0.13841498883501177, 0.26002231504647966, 0.2596332343114961, 0.7699941146758296, 0.27725402265787125, 0.19171220070171743, 0.18729887542224702, 0.11873365379869939, 0.21346511409407665, 0.13580382411037722, 0.2424730180251983, 1.7260187696064673, 64.77794339579921, 74.65994711845153, 42.57475122328728, 59.410046454398866, 47.38613836226925, 71.39560945572393, 9.719172408503871, 0.8010912782722904, 1.5252960112787064, 0.9500713550275373, 0.4555942965370994, 0.6372732428773757, 0.5779615513259365, 0.36955851640912796, 3.89991803515342, 71.20072257134223, 106.07716729564052, 92.06207583027502, 95.07879426402431, 89.87544075135263, 92.18258673144926, 89.20905359329717, 90.41376252328196, 90.32049640532463, 83.58549656406527, 75.03093273408952, 80.03921108861124, 79.01232673275855, 88.16902929736723, 83.17387519344207, 85.49816977593207, 74.22621926953717, 73.80935761236375, 82.10470768713182, 82.8221562600905, 78.19419876221689, 80.88299920482021, 82.51069653418757, 64.65618125854, 62.97024457685409, 64.51212044685118, 65.20087688199936, 65.07540418255714, 67.41634922642862, 74.76956952002742, 73.6869639735068, 73.01928243329449, 72.51007249278408, 70.56250587586435, 65.24581155469342, 61.523199850513095, 62.360284636097575, 67.99470270833662, 64.90437315356347, 69.74279326777305, 70.7285633394795, 69.61892481773131, 75.13013732048773, 74.48801394431823, 68.73994519633632, 69.61020931120842, 72.40413711917016, 74.48108703859391, 72.50941353459513, 73.82773783899123, 69.08843994140625, 67.11517395511751, 72.07111220205985, 68.25052753571542, 65.16665027987573, 73.81695132101737, 60.8027506643726, 64.58702202766173, 68.04853331658148, 73.76676851703276, 70.90840401188021, 67.75783077363046, 64.41837187736266, 64.48032571423438, 65.98261310208228, 65.60208828218522, 66.48105221409952, 62.297259992168804, 67.60173613025297, 71.78001742209159, 68.06709397223689, 65.58253526687622, 68.06617613761657, 57.705674632903076, 60.96759219323436, 68.31490931972381, 59.324758437372026, 68.895020023469, 59.26682895229709, 62.85409535131147, 62.86669792667512, 66.08752081471106, 67.19449212474208, 60.29247383917532, 60.38550069255214, 65.85467323180168, 63.9540260068832, 65.02188344155589, 63.48202366982738, 64.6597388482863, 58.11733522722798, 60.68086301126788, 59.895329936858154, 61.250265644442656, 63.88265455922773, 66.59888805881624, 67.97527128650297, 70.01856726984825, 69.50352084252143, 68.72607569540702, 56.54445302101874, 52.89558972081831, 55.96485614776612, 54.66134271314068, 55.74923169228339, 56.66343812019595, 58.93503173705071, 55.921957185191495, 58.35747841865786, 66.24632973824778, 73.18752073472547, 75.2667691630702, 73.72014722516461, 74.28616877525084, 72.62652766320014, 67.86498992673813, 63.963427928186235, 67.4240606061874, 77.97935485839844, 77.81842001022832, 81.42107778979887, 79.85591088571857, 81.52753091627552, 78.24682912518902, 77.37375659327354, 77.56210880894815, 82.96941772583993, 84.67385230525848, 73.76789815964239, 32.662941409695534, 2.115068003054588, 1.0386156747418067, 3.3497060883429746, 0.44963952574518423, 0.5924866396573283, 0.3453264812067632, 35.33870389384609, 98.34683464419459, 68.19672046169158, 56.04730829115837, 47.756939626509144, 36.17594949660763, 6.77128961009364, 0.7112357224668227, 0.22272944600591738, 0.2063539489022186, 0.16613767302084356, 0.17751011036096082, 0.27153226516900525, 1.019782659507567, 1.925859362367661, 1.575905495593625], [2.8801468976082343, 0.8069261103387803, 0.09923565126354657, 0.11339464149768315, 0.04363840979133402, 0.03993468877348689, 0.041375573754550955, 0.03191904378904691, 8.490971422964527, 62.84396386915638, 49.9342433867916, 14.142174297763457, 29.505635423045007, 44.80414013708792, 53.81118466777187, 10.417942654701973, 0.7016454048214421, 0.4457953271846618, 0.14249167975879487, 0.18638445755406735, 0.092952320682666, 0.44956803442009036, 0.21263357161754565, 2.2819680408124, 60.476385931814875, 85.76457715803578, 79.87160821114817, 85.68084239959718, 82.7936641631588, 84.88151042692124, 81.66205252370527, 87.10704757321267, 82.45287295310729, 83.51817300242763, 72.82309332201558, 66.86370295862999, 68.09313851018106, 73.96757818037464, 73.892605996901, 68.73574826025194, 58.29825847379623, 64.22828205170171, 74.40668752116542, 77.54161050242763, 72.15385852321502, 73.8105421681558, 72.78868629086402, 59.262859513682706, 55.54873189618511, 55.770577230761134, 53.52643628274241, 60.85101935171313, 64.2171032967106, 67.4616055334768, 71.37900214041434, 67.06079421504852, 63.59697265009727, 62.5011291042451, 58.4354982837554, 56.31253896221038, 55.982130266005, 57.11951171198199, 59.41870704773934, 62.465929754318736, 62.377719571513516, 61.71059893023584, 66.76121142602736, 66.89240686355099, 60.27889851600894, 62.01198993190643, 64.1226996914033, 64.48087876842868, 67.71528874674152, 62.72197423442718, 63.454967160378736, 58.30706419483308, 65.26053613232028, 62.37346379987655, 66.17953961895358, 64.13880102096066, 54.322485231584125, 63.53925105064147, 67.57404419683641, 66.26323515369047, 65.07529827856249, 58.22917376795123, 58.35607813250635, 57.69810838084067, 58.67452752205634, 58.28769945329236, 58.67683779808783, 55.67600104116625, 58.44680255459201, 62.66393884535759, 61.46724331763483, 62.02337265014649, 57.145642542069965, 60.63845042259463, 56.01161864496047, 57.976698644699596, 61.87464814032278, 60.88768959045411, 60.47309898561048, 58.166392310973144, 62.64272274509553, 56.36391808909755, 55.24626224271713, 57.55944867287913, 56.13706388781148, 59.87609071116294, 62.646570590234575, 61.17119458413894, 56.90663291561989, 56.6488233689339, 53.01262540201987, 52.70003211113715, 53.35509146413496, 54.01298276839718, 56.89788603013562, 59.18376491915796, 58.7857973191046, 59.76940616484612, 59.0425988166563, 55.52640968753446, 48.45183064860683, 48.76647533908967, 51.25909059278427, 50.0602848299088, 49.46325302124024, 50.70691108703614, 50.008380105418546, 50.980723904025176, 55.19772683420489, 64.8803682481089, 65.77791244752946, 65.62990180907711, 68.82159325384325, 67.64860060907179, 61.88810187001383, 60.10962863122264, 57.90038501062701, 65.70933372743669, 67.37989471804711, 68.70476153589064, 72.89612785462411, 68.42956804460096, 65.55290568259456, 56.17587574066655, 55.78803570039811, 54.706238162133005, 62.699016601808616, 72.90143089909708, 71.90623929423671, 45.99330471407983, 4.376169769994674, 0.26024644172960715, 0.38218913059080806, 0.14891658338808245, 0.3794721231585549, 0.11936558440567986, 24.727886530660815, 78.443998829011, 50.03835878064556, 38.384769501224646, 12.253569729866522, 6.428002792019998, 10.424242961791254, 1.9873387150226103, 0.3629995167495743, 0.1152510793819543, 0.07103687407629145, 0.13384956445905472, 1.2809110216556059, 1.973938550199232, 3.8374135955687496, 4.071247899724591, 1.0419983512932256, 0.17977239864487804, 0.14757470377991277, 0.09971109309023428, 0.01758243798488571, 0.03536579784967246, 0.15528677301781793, 0.11968485154812375, 14.202142434735453, 74.35595558535668, 59.32367978557464, 28.65108628426829, 37.835610220509196, 48.85402656370594, 68.0685374044603, 12.493585444265797, 0.8383082586430735, 0.29342031647120753, 0.4405200763815834, 0.4129505331718153, 0.037990135456165, 0.22433876690845336, 0.04406292975369481, 3.370616488879727, 62.20752792973673, 93.97418422083702, 83.8125390391196, 88.33773828321888, 81.86806324989566, 88.75194057341545, 85.33983938155636, 89.16812758291923, 84.83703074916717, 83.96385623562722, 75.17417769278251, 69.10194858427971, 69.9078779835855, 74.22816476514264, 75.22851036440942, 70.69700394907306, 61.164981549785985, 66.41048877469956, 75.57436927672356, 79.59338665008545, 75.11158450957268, 76.57446384429932, 74.4223456228933, 63.398771362919966, 58.827570561439764, 58.91594940616239, 54.896661389258604, 62.750395728695786, 65.44002379140547, 70.08743624533378, 74.40369083035377, 70.1128924277521, 65.86174918759254, 68.04425793309366, 61.66721359375985, 58.292006215741566, 61.36578729075771, 61.82878386589789, 61.87296544351886, 62.35544835367511, 65.74291313848188, 64.84091312654557, 67.41333684613629, 71.43870061443698, 63.55131626129151, 64.61964045801471, 65.25478593764767, 69.59594757326188, 69.2016238550986, 66.28206253051758, 67.13440141370221, 61.98419209449523, 66.4084569869503, 64.24819200269638, 70.69800023109683, 64.06542524214714, 55.42700506025746, 66.78151361403927, 69.57182499670213, 66.03012084960938, 65.30540020235124, 60.3849672502087, 59.78437785179385, 59.8022089465972, 61.40070815240184, 61.55157035396945, 60.868481743720274, 58.404986166184955, 62.755887046937026, 65.9267036376461, 64.26985525315808, 66.1057912149737, 60.76947327583068, 62.0251847851661, 60.05115785906392, 59.98144949636152, 62.5091189722861, 62.694172474645804, 60.9786650442308, 59.89773042740361, 63.41644164054625, 58.53987255404073, 59.85369397747902, 61.53501402947211, 58.36352671346357, 62.6165723031567, 64.30251682958296, 62.86171259418611, 60.14150965598322, 59.15556307761901, 55.69701317817935, 54.27788788272489, 55.80538826604044, 58.32578566766555, 59.83068927641838, 63.692188186030236, 63.53705844571514, 62.61286958571404, 62.40997714381065, 59.43940539513866, 49.14842790172946, 53.39956721951885, 52.77446692989719, 52.50340369439895, 50.8201224573197, 52.77882468315863, 52.8152282007279, 54.29494627060429, 57.91258358186292, 67.2658557276572, 67.33488159794962, 69.55941461747693, 70.89559355089742, 67.89523924550703, 64.32337599415933, 61.819911464568115, 59.4974329394679, 65.77881067029892, 70.34442993902391, 73.61282333250969, 74.36290602530204, 74.38136469933295, 73.21738566121748, 66.4833507230205, 66.13828412948116, 64.41883079467281, 71.28139003630608, 77.92757957212388, 73.79761403606784, 51.61381798405802, 6.884421552381208, 0.4108818506281222, 1.3102184812868796, 0.23558601015998473, 0.5931514814015358, 0.19952255902030777, 29.094592602022235, 87.43396143759452, 63.67647517111994, 48.3293350281254, 20.512123069455548, 16.413543358925853, 11.913596333995944, 2.43612356243595, 0.2138822183253304, 0.13526941649615765, 0.07353355462152152, 0.021082825861090136, 0.435492946135421, 1.005434568130201, 2.0949251613309308, 1.3045885317748593, 4.037029632637578, 1.1902000827174033, 0.33401874765273065, 0.20315332548512569, 0.1119734641284712, 0.2035608842608429, 0.34515968854388884, 0.32458848109649074, 18.63999539805997, 84.46899475589876, 75.29217827704646, 26.98705996236494, 42.64940961714714, 63.26346920382593, 76.28289053517004, 15.321935972859784, 1.0759041770812006, 1.3461994860441455, 0.6396534474145982, 0.8337580640950512, 0.20591726346362024, 1.0187087268117936, 0.5011397558114221, 5.072521874981542, 68.31006127019083, 100.58317399794056, 89.96581216012278, 96.26733518415882, 88.66285570206182, 95.27926660353138, 89.0573206255513, 94.48582603085427, 89.91952819208946, 90.50190602579426, 78.85353349870252, 74.79648482414984, 75.27135049143146, 81.47287661029448, 79.31920513030022, 75.62286546153408, 63.458548284346065, 70.06808327090356, 79.60065087964459, 82.03074747516264, 78.72382071710403, 79.21433664137318, 77.46579893173711, 66.58253961993803, 62.61806672619235, 62.25763228631789, 59.50918043813398, 66.28204684103689, 68.5337697305987, 74.99682380307105, 78.84222138312556, 72.9505075946931, 69.94864709915655, 70.47580580557548, 65.234989735388, 62.94955407419513, 63.5685040873866, 66.24282313931373, 65.08997971011748, 66.3179208386329, 68.68751879661315, 68.3122891764487, 72.22846200389247, 75.89233229237219, 66.45782393793907, 68.85746725143926, 68.85635329831031, 73.39495920365857, 70.61080594216624, 68.80518205704229, 68.89749896141791, 65.10880708694458, 70.3578209107922, 69.05817493315666, 70.28967365141838, 70.34679120586765, 57.48515898181547, 67.6816975685858, 73.09831034752631, 70.5443766809279, 68.93742868977209, 63.60595487779187, 63.73247877244027, 64.52593111222791, 65.41518342110419, 65.65132187258813, 63.00183534622193, 61.68016918243901, 63.23336893512357, 70.66961011578961, 67.8270370729508, 68.62530216093987, 62.221848503235854, 66.26064638937673, 60.220584638657115, 64.32584708736789, 64.84054050137921, 66.92299350615471, 64.78128133281585, 60.46218302942092, 64.65325909276163, 62.64194219343124, 66.48052661649643, 62.116034723097286, 59.482320047193966, 63.90669476601386, 68.71142956518358, 66.64963568410566, 60.73938085186867, 61.86133561595794, 58.500150711305686, 58.51181191782798, 58.79694861750449, 61.953609374261674, 63.8613639339324, 66.52721066628733, 66.4815228985202, 65.24063794843613, 64.54325229890885, 63.97741117785054, 54.88452557594546, 58.47922878880655, 57.61244381627729, 55.67951548484064, 54.439438543012066, 56.843992663967995, 56.12932112909133, 56.978467202955684, 60.23020229031963, 73.15447868839388, 72.01845046012633, 72.52043539477934, 74.21379320083126, 72.10992797728508, 69.09022854220483, 65.1684388806743, 65.39321030339887, 70.91670374716483, 74.95447789469074, 77.71959981610699, 79.45721764718333, 79.5665733275875, 81.14781410463395, 76.1292826744818, 77.65445709228516, 77.44945833759924, 79.93158125108289, 86.0548560850082, 81.63166199961017, 57.84850382035779, 8.04415854715532, 0.8462107926607133, 3.3635091541274904, 0.483288957226661, 0.651177003258659, 0.3526938874875346, 34.729559806085405, 96.79163056035196, 74.08881079766059, 63.030225461529156, 33.79967174222393, 41.422719724716686, 13.341302794794883, 3.2095254813471152, 0.6531038063187754, 0.26872332718583847, 0.24196861041409357, 0.29381862090479943, 2.742521224483367, 5.066414254326975, 5.164679433068922, 6.309582023851334], [8.449800264450813, 4.30167023212679, 0.2600251955370749, 0.11170604581674261, 0.045075755446187915, 0.09289580637649184, 0.08285941871544046, 0.02623885040051274, 30.74202141454143, 59.05813532490885, 30.441363896093062, 12.28248053981412, 49.42467258822534, 43.55750499233123, 58.60339141661122, 16.954331321101037, 0.7251540691621843, 0.491431858991423, 0.7744405502753874, 0.8512537349616328, 0.38098254211006627, 0.40513248333046514, 0.16126832624356593, 4.668180913694443, 70.24973607832386, 65.52102858020415, 84.55273735907771, 87.48831764344247, 83.11682824165591, 81.70208423368393, 81.7963780126264, 81.50587943292435, 83.34187815266272, 81.74362997854911, 77.75356754179924, 73.87090744510775, 65.48922992521717, 67.38081255266744, 66.56422999597365, 65.41077859940069, 58.55476187121484, 65.44391870498657, 71.99959170433783, 75.46011063360399, 73.3881970374815, 72.43867751090758, 72.57860414443478, 59.22168639398391, 56.06843809927664, 54.47495560492239, 51.54197977435205, 59.98605435894382, 63.569300328531575, 65.50758661762362, 64.60563367412936, 67.2829572616085, 60.91032951108871, 56.879521492988836, 54.751180679567405, 55.02513470188264, 53.83310679466494, 54.967471937979425, 58.8366900720904, 61.124420319834066, 63.379379164788034, 66.58369279676869, 64.53625086815127, 65.81020139878797, 59.44279040059736, 59.407747945477894, 66.64665468277471, 67.78101982608919, 63.992469156942065, 66.89117523931688, 65.11673419706284, 62.06958209314654, 62.90078724584272, 62.56758582207465, 68.87140735503166, 55.13411775712044, 56.69770002365113, 66.14477957448652, 64.54103223739132, 65.01661962078464, 59.513753921754905, 57.42225985373221, 58.365464364328695, 57.25493938692155, 61.14587568467664, 59.50336356316844, 57.83155133647304, 57.47002647769067, 62.440457882419715, 56.116491056257686, 62.37077305393835, 62.83684476729363, 59.086435225702104, 55.81109923701133, 61.044152936627796, 57.09724833888393, 60.486297761240316, 61.410153219776774, 57.38470708170245, 57.612565409752634, 57.45420755878572, 56.08643001125705, 56.744399762922725, 53.2757850616209, 54.889969825744636, 59.754344263384425, 60.38578702557472, 60.11928550658688, 56.496380452186834, 55.72481101559055, 52.433024606397076, 52.69269727891492, 51.589346316552934, 54.84381921829716, 55.88213728320215, 57.19525268000942, 57.429273051600305, 60.48169289865802, 55.98096139969365, 47.17872342755718, 47.78988361358643, 50.687722852153165, 47.425546415390514, 48.00932061287665, 48.38709192891275, 51.71436402105516, 54.267062141049294, 58.40378199854205, 63.72843088642244, 64.51120261223086, 65.62015471919891, 66.2516406274611, 65.4710183605071, 66.59017255229335, 60.865873367555686, 57.94916752846011, 59.54612524278703, 63.06356953036401, 66.1010451470652, 68.968611532642, 71.98816976239605, 66.5800920609505, 64.56875554976925, 53.321668947896654, 55.128422475630245, 49.06287316353091, 59.38945401099421, 63.958862289305664, 75.82417718825802, 57.46366831564135, 20.01326426382988, 0.08452408180962648, 0.3418605155762165, 0.09231084462014899, 0.1385974250132999, 0.4246397478686225, 24.43564053504698, 76.62592534096011, 57.83265352249146, 40.133499406999164, 8.731799067989472, 8.828821835979339, 18.13818500887963, 6.19083667955091, 0.3185497164245575, 0.16865994090274458, 0.0578003686161772, 0.8079672544713944, 3.832750387730137, 5.26898310069115, 10.17542839050293, 10.220086536099835, 4.779270281714778, 1.1140325569337415, 0.08886931719438684, 0.036247729759423, 0.06383639069334154, 0.05169710317145913, 0.07034516562857936, 0.41314533400920134, 41.86213108801073, 67.04073521398729, 43.10336905141031, 14.647857046896412, 45.56502503733481, 50.47902138002458, 68.13960290724232, 18.451449025061823, 0.5684216116224566, 0.4980730139199765, 1.1806274157377983, 2.603172895408446, 0.13218663272357759, 0.3117805328820983, 0.1592123147941405, 5.74190866562628, 74.07859694573187, 79.40682303520941, 84.34468700039773, 90.32603479200795, 83.66224950359714, 87.95033362603958, 81.95279429035803, 85.7035372334142, 85.37613699513098, 85.02823060558688, 78.44991376323085, 76.68681621551514, 67.12828251623338, 71.22120518838206, 67.50072725357549, 65.56184868658742, 60.80120132815454, 67.67712408496489, 76.16303859218475, 76.29115104675293, 75.02479030239967, 74.65590707717404, 74.88257300469184, 63.105107430488836, 57.74988366711525, 57.58150023798789, 55.99552516014346, 62.90997343678629, 64.99248135474421, 66.58640707692793, 66.53012890969553, 69.36590056265555, 63.945079080520145, 61.32206855281707, 58.107635205791844, 56.17726425970755, 57.63494645395587, 58.36647241346298, 59.82431542488837, 63.279358725393976, 64.67281995281097, 68.41643594926404, 66.72526682576826, 69.82046404192525, 63.005161516128055, 62.77415744719967, 70.99586502198251, 70.81759329765075, 66.20944376914733, 70.20896696275281, 66.73686135199763, 63.138514257246456, 63.55124565862841, 68.11014590724822, 70.270203005883, 58.59233817746563, 63.045095166852406, 68.65392761845743, 66.0591620783652, 67.25135864750033, 61.18984153193813, 60.14281188288043, 58.94042107366747, 61.729846000671394, 63.982682843362134, 62.91029507114042, 61.60686008391842, 59.8166315017208, 63.989080229113185, 60.470859312242084, 64.38897763529133, 64.48086307894799, 62.59146521168371, 59.4387895830216, 62.82271246756277, 60.351834989363155, 60.49892779319518, 65.45293623401274, 59.335348836837284, 59.88470815843152, 60.20746823280089, 59.634021635978456, 59.638940288174545, 58.157119827885786, 56.740104767584036, 62.41053412037512, 63.78558374220326, 61.44908274373701, 59.79345421637259, 58.207557585931596, 54.786038783288774, 54.742767195547785, 55.17129398161366, 57.07699321931409, 56.996161014803, 58.64378006227555, 59.53287155397477, 62.85378940643803, 57.23582175470168, 50.162450805787124, 50.50076307788972, 54.092500978900546, 51.24546427880564, 52.022281846692486, 51.517139404050766, 54.89353526023127, 59.010074523187455, 61.0402697901572, 65.83315510903635, 66.23198170815745, 69.40238644999843, 69.0169978910877, 68.59272295428862, 67.58774895821848, 63.008495530774525, 58.635629377057484, 61.563494359293294, 66.38637404288015, 69.56499222786196, 71.5463932098881, 74.92236937246015, 71.82982367853965, 73.02036500746205, 62.22992858579082, 65.59469069204023, 60.49612329852197, 68.27288504569762, 71.2281556283274, 80.8815557725968, 57.99338048504245, 23.987676443592196, 0.44867747252987283, 0.4943468235433102, 0.008806125148229541, 0.24909574087829361, 0.48253285908891314, 29.297471315630023, 84.96017748309721, 68.12814958633916, 51.449592267313314, 25.50811459941249, 23.098437863011515, 17.85767866719154, 9.597356338654796, 0.5558155428978705, 0.1668384136451829, 0.09756537274487558, 0.8787384569164246, 3.3157565036127647, 4.559743558206867, 5.890367925167085, 6.374150120442914, 10.912354473144779, 6.492896445335881, 0.37480284790358237, 0.2361279714011377, 0.23612240960280742, 0.25059661437426844, 0.1974770889407204, 0.5221674290876235, 49.38374265547722, 80.71154455984794, 55.82265846190914, 22.90938746544623, 67.26038794363699, 60.91207496581539, 78.065843120698, 21.149382706611387, 0.7164669998230473, 0.8208559789965231, 1.9593404690104148, 4.442915272328162, 0.4615660438374166, 0.7944480702280999, 0.4334913728938949, 8.217428268924836, 82.73115727209276, 84.92925351665866, 85.83106133245653, 94.68075213893768, 87.03176160012522, 91.56518213210568, 85.46704184624457, 90.14531550868865, 89.8257992344518, 89.22309567851406, 82.97967864621071, 82.66275898102792, 70.88642304943454, 74.83282950616653, 73.23698182259837, 69.991087144421, 65.98165604376024, 70.60046657439202, 79.76813608600249, 78.93490699029739, 80.33739751385104, 77.87977372446369, 78.03342080885365, 68.75368918142011, 60.5758729288655, 61.47556658714049, 58.74510665093699, 66.59996278824346, 68.31576439642137, 70.7686185836792, 69.16312186948716, 74.55019135628977, 67.72202737869756, 66.01895778409897, 61.83020376390027, 62.934496095103604, 59.983438138038885, 62.64493888424289, 62.005721984371064, 67.09420496417631, 69.25977691527336, 74.07039919207173, 69.83929141875237, 75.25147976413851, 64.21093340842955, 66.28091719842726, 72.44437279239779, 75.55272563811272, 70.04731039847098, 74.2371077691355, 68.96170031639838, 65.42098460658904, 69.48877273067352, 69.90832513378513, 70.0671575915429, 61.50849880710725, 63.53539928313225, 71.34111204454976, 70.10762860698085, 70.47902999385711, 65.61889171600342, 62.34670931293119, 61.37003129528415, 65.36486333416354, 68.16758509605162, 64.63503183857088, 63.33427975254675, 62.23938542027628, 69.85581244191816, 63.06360875406573, 67.11576231064336, 68.07673515812044, 63.37496649834418, 62.594740390777595, 66.23862620322936, 63.98524415108466, 65.10099764793151, 65.76316041331138, 61.38616008143271, 60.57460600329984, 63.14512737335698, 62.415178206659135, 62.140373030016505, 62.324504775385705, 58.7837851432062, 66.07379251910795, 66.56092736028856, 65.29977160115396, 61.5707899678138, 61.94502722832465, 58.76745631617885, 59.666718513734885, 58.662085763869754, 62.63183032312701, 60.524717377078154, 61.64245559323219, 62.34589738230552, 66.7782502020559, 62.670567650948804, 52.30949740256033, 53.1273429624496, 56.44962579973283, 55.39608501618909, 54.71183146199873, 53.210720785202525, 57.18550951250138, 60.986945167664565, 65.68627411319365, 72.0609454185732, 70.30186437791394, 74.26534883437618, 73.70819968561973, 71.86413657280707, 70.93799437246015, 67.82919437654557, 63.45950534266811, 65.28848301979804, 68.1238506686303, 71.85827655176963, 75.95116784495693, 79.25709047625142, 78.94142596952378, 79.81849931901502, 72.96715413370441, 77.4887526419855, 71.3849013851535, 78.5727467075471, 81.79906091382428, 92.1532944710024, 66.26489039390319, 26.926467187943, 1.287077600436826, 1.194797958577833, 0.3894410414561149, 0.7739132979223806, 1.0030441899453442, 33.925564135274584, 94.21522171266618, 81.53272413438367, 65.06589243488928, 37.101381747953354, 42.268367044387325, 28.721614422336703, 12.766220569610597, 0.7313684518298795, 0.3211806462176385, 0.16007871427122625, 1.0875710220106187, 9.06373650796952, 14.188785783706175, 12.796158059950798, 15.583844396375842], [12.447135756092688, 7.1415422328056835, 0.7558583215840402, 0.1118941433847912, 0.022586487917109363, 0.037540483979448196, 0.031958813328416116, 3.3159889040454744, 46.357924322928156, 54.676232030314786, 31.551616268773234, 42.49545266551357, 100.19529865634058, 38.672302769076445, 62.16952800750733, 26.81026501040305, 0.3628545116272665, 0.6598573310240623, 0.6491374933431227, 1.1255113732430244, 0.2194924027689042, 0.36938023242738943, 0.3118887044970067, 10.12808342133799, 79.45360122188445, 60.031075323781664, 94.54608932618173, 78.86982702439832, 88.77062674491637, 79.64516193636003, 81.92346280620944, 76.323361550608, 79.89908049183508, 79.43874328367173, 80.41589198573944, 75.7942573485836, 71.6245738921627, 66.66360716665945, 61.61368500801825, 60.357043896951986, 57.074580961658114, 63.518666451977154, 72.04159244414299, 74.54743000768846, 73.76028091676774, 73.87730875322896, 70.8069166060417, 57.158637354450846, 54.88995021389377, 53.9062080075664, 53.19842807708248, 56.30828319057342, 62.588770543375325, 61.21346596748599, 62.07797988768547, 59.164961076551876, 56.806141791805146, 55.06599403196766, 56.00388765335084, 50.71640322285314, 54.423019501470755, 54.50949991902998, 58.09669571538126, 58.76356924733808, 63.84660405497398, 63.95919569077031, 65.35080948183614, 66.68434081539031, 59.15001684619535, 61.105663545670055, 63.74730533169162, 63.87818305723129, 63.910048392511186, 59.12048139879781, 63.95168435189032, 65.61335725169029, 61.55357468512751, 68.84491566688784, 64.31337395021993, 54.90181538366503, 65.19878233632734, 63.24215504430956, 64.20573626795124, 64.01119062977453, 62.452574083882, 60.17818773946455, 64.2741031800547, 64.4640164990579, 64.20179428592806, 63.445745668103626, 62.725010148940555, 61.57654016248642, 58.229126699509166, 59.92006440316478, 60.95069462253202, 61.67346192944435, 59.89356879265078, 57.02343717698128, 58.66765552951444, 58.28028617366668, 58.96388861440844, 59.39716931312316, 60.32934019642492, 55.673522103217344, 59.43856993029195, 60.11038172629572, 58.1480787646386, 55.32665121939875, 52.84470089020268, 64.146206455846, 70.01881045679893, 63.76140233009093, 57.32741302059543, 55.298755322733236, 55.11713389427432, 54.331863618666134, 52.0015246637406, 50.8823783166947, 54.49008418667702, 55.07394859867712, 53.77078033262684, 50.579061431269494, 46.633635567080596, 47.89618376762637, 48.546026368294996, 49.526038400588504, 47.717535495758064, 49.11548391465218, 53.006714390170195, 61.142800546461544, 61.31353347532211, 62.93908919057539, 63.30570136347125, 66.26865586926861, 65.49296009925105, 67.000028856339, 66.89985936687839, 63.35237364615164, 61.24423303911763, 56.384722340491514, 61.07932090759278, 65.75300147456508, 72.39647280785346, 70.94887502731817, 70.5741710047568, 64.67670702165174, 63.602730689510224, 53.9336802882533, 53.47943844333772, 48.98561031587663, 57.12357920985068, 59.1136250957366, 76.82977091881537, 65.27626875908145, 39.99644787080827, 1.8183947546828179, 0.030986142134474173, 0.07951703072795946, 0.3254546813907162, 0.2234185114502907, 29.28162886250404, 74.80200752135246, 57.02333127298663, 44.63690988479122, 19.16541845567765, 14.196307909104133, 18.623907796798214, 20.398597909558205, 0.7114537817335899, 0.3668084446220629, 0.2308867195801389, 5.426697192653533, 10.234032523247505, 9.372706509405567, 13.260289180663325, 14.384726805071677, 9.732902665292064, 5.975191141328504, 0.615583638991079, 0.04825510460162356, 0.03620178363616428, 0.0448047173690171, 0.04849195600517335, 6.169285216639119, 60.31511375980993, 62.527903203041326, 46.89218644172915, 49.39030085840533, 87.74978283912905, 44.913240863430886, 68.44330418494441, 30.654215235863965, 0.45568258050949345, 0.7935118494975952, 0.6853273643120643, 3.8719154990488485, 0.33099729687936846, 0.25204452055115856, 0.1107333439792837, 11.72407917438015, 84.94811227244716, 68.83573732068463, 92.32359593914401, 81.76427733513617, 88.70605668713971, 82.67058018715151, 84.22718063477548, 81.25805624069707, 85.78750733406314, 81.38317984919395, 80.97220959201937, 77.6515466936173, 74.88948422093546, 66.317991441296, 63.414174510586655, 61.27694952872492, 62.25751461521272, 65.78774582955145, 76.16449771388885, 74.07094832389586, 77.1742726910499, 76.93075626127182, 73.93745437745126, 61.02423906326295, 57.90225990356938, 56.59884452819825, 53.98889157079882, 60.13956023800758, 65.05709455859277, 64.0709714735708, 63.58257755156487, 62.656352981444336, 58.63293863111927, 59.335133106477805, 57.50689283494027, 55.75753534993818, 56.11966033135691, 58.54124146123087, 59.88344515523603, 62.36857260427168, 63.95742277945242, 66.55196082207465, 67.7202780016007, 71.09649735112345, 62.4946258144994, 64.92456551521056, 66.44368771583804, 66.01273690500568, 65.47483874905494, 59.77789809626918, 63.877461341119584, 67.67954026499103, 63.86849480290567, 70.57406902313232, 64.11933822016563, 57.36702503696565, 66.19348756728634, 66.48899893606863, 64.42556158188852, 65.80775383980044, 65.62967823397729, 63.66830487405101, 66.41852178881246, 66.62591318930349, 65.94048684643161, 65.45438358860632, 65.01261488083871, 64.96594652052849, 60.41425166591522, 63.92158800555814, 63.368894669317434, 62.48276848946849, 62.14855117182579, 61.985443330580196, 61.56701272533786, 62.14362467488935, 61.69102238070581, 62.65224625987392, 62.36632116379277, 59.20309435936713, 61.638599903352805, 62.447216126226614, 59.44314733628304, 58.419644063518895, 54.815484016172356, 68.43751476657006, 73.1839749120897, 66.57020768811627, 61.554021835327156, 58.23947783439391, 56.67657021553286, 56.677778305545935, 53.61691359550723, 53.11233597417032, 55.262457709158625, 55.95011588065855, 56.333303989902625, 52.9901933670044, 50.23890956755608, 51.27849848039689, 51.31917738145398, 51.651260929722945, 50.90906220097696, 51.49304820645241, 58.56229674431586, 64.63165467785251, 65.13999385218467, 67.13667638840215, 66.52955624365038, 67.6618895992156, 67.01512213676207, 69.46676038926648, 69.33983249049034, 63.15585505577826, 62.05111949674545, 57.11704061877344, 61.95485668797647, 67.53565203758978, 72.89028352306735, 72.98296128549885, 74.14369260111164, 69.69955305899344, 71.29732270394602, 64.79110687009751, 64.7798575124433, 60.5317658762778, 67.02051147337883, 68.61898714496245, 81.74834466749623, 70.05298999048048, 43.63096314091837, 2.6995153773215512, 0.07963757466284499, 0.09520790569724576, 0.5634387306148007, 0.3057988264387654, 34.51736350213328, 85.35964735092656, 70.53331559704196, 55.68356729322865, 33.73926724157026, 22.993885124883345, 31.028654498438684, 25.154075584103985, 0.5814786916298251, 0.2640501908477276, 0.3171487867591843, 2.768730747122919, 10.696463296490332, 10.696607443594164, 12.763921080097077, 11.974904940974328, 20.320119127150505, 13.135698033917336, 1.8958669588450465, 0.24354190986242988, 0.055432436807501706, 0.18796226159939844, 0.177110135855694, 7.4324271659697265, 71.28166460221814, 77.06931006523871, 55.67969591386857, 59.93675016587781, 109.69048607733943, 55.98876691633656, 79.73347802315989, 36.425373015865205, 0.49398369786720125, 1.4935814421023093, 1.4759234218828141, 7.160866770052142, 0.6683257895131266, 0.8389897091734795, 0.3157765394256961, 16.34950968527025, 92.08769675224059, 78.4804690268732, 98.21753763383435, 87.74543685297813, 94.30409477603052, 86.44031524658205, 88.25999690640359, 80.9890365600586, 89.39960233626827, 86.2551244612663, 85.40955558899911, 82.51853342979186, 80.75802464638987, 72.25773857485864, 67.43148957529377, 63.77538557975524, 65.97466638011318, 70.74968922522761, 80.7330862168343, 80.28393560840239, 81.16484503592216, 81.0860759981217, 76.15259724278604, 63.79963367216049, 60.56210540956067, 61.94499584936327, 58.552494741255245, 62.50183513087612, 69.75683535298994, 69.73997700598933, 66.93692576500678, 64.84042283027404, 62.46811843687489, 62.10829196437713, 62.477026139536214, 58.77022943189068, 60.181968904310665, 59.98644267359088, 63.59337975901943, 64.02259688223562, 70.30385694196148, 71.19502728985202, 72.26674433677428, 73.22769365003033, 66.57645210143059, 69.58029731627434, 70.61298677998205, 70.51962652514058, 67.97521637332055, 65.50122845557429, 69.82536700464064, 73.72733300732028, 66.44841024952551, 75.5514391006962, 70.3153024181243, 60.512326609703806, 70.84526169684626, 71.28706178357525, 67.73054676671183, 69.62585956819596, 67.11660954260057, 66.03817739794331, 70.9208300805861, 71.65084592757687, 71.02826379960584, 70.1396979055097, 69.34077385933169, 67.3379881151261, 64.46945290411672, 66.56975269317627, 67.14778454073014, 65.70684694474744, 65.55331360909247, 63.75112179786929, 65.27311125109273, 63.15208958041284, 62.51569678706508, 63.64712799749067, 64.17165479352398, 59.313862093033336, 61.78881491384199, 66.11736220698204, 63.23215692274032, 58.89175230456937, 58.93991508791524, 64.39015434634301, 72.57712148850965, 71.7066926340903, 64.69389484774682, 60.966619445431625, 59.29765485948133, 60.507819806375814, 56.97195606846964, 55.94289479717132, 61.31067798983667, 61.2844765570856, 60.00418355388027, 57.83578357388897, 53.329819633114724, 55.154753346597, 54.82174804133754, 53.61546231854347, 54.26038626701602, 55.60061700882451, 61.1993101335341, 67.30424788690382, 67.25295897453063, 68.4629709489884, 73.1598601802703, 70.39992363222184, 71.41217754733178, 72.67816958888885, 71.54890352679838, 67.74144311105051, 68.39858132023966, 61.63869404023694, 66.16637614465529, 71.76102530571723, 78.03330313774848, 78.3287831275694, 80.35303992609825, 76.47835793033724, 80.85317350202992, 74.22368541840585, 76.72425916118007, 71.55956452892673, 79.18080822114023, 76.7122253294914, 92.88483219762003, 77.64693398629466, 48.80130206384967, 3.5507684994128446, 0.1400050809306483, 0.3002287850024239, 1.1791757710518376, 0.5673918668781558, 40.77638764535227, 94.67092267928585, 81.20482967745873, 69.84057795616889, 47.036035445428666, 38.32229398911999, 48.885601643593084, 30.111112094694573, 0.7167561520491877, 0.42500514116498733, 0.6031971617091088, 6.053851333356673, 17.871169659399218, 22.715500785458474, 22.34545457747675, 23.857947972513017], [15.412190691117319, 11.838015202553043, 2.6068530592226216, 0.16837570696107804, 0.05804175142979911, 0.061206724945335626, 0.3459556232536993, 9.442938508525971, 57.683015100417606, 53.151088991472804, 19.809169615468672, 19.91292219008169, 69.02415229428199, 41.49264381777856, 63.046024768583244, 41.80395057124477, 0.29010928446246737, 0.5333593607910219, 0.12334855979368572, 0.5398611796479071, 0.3173219839171056, 0.06395704571097609, 0.07027343681622898, 12.296598130656827, 63.84621966269709, 62.00307438450476, 84.53435713245024, 78.52490163618519, 85.34373821750765, 79.63188079095657, 82.07006531376993, 82.82121489124914, 76.07981374186855, 78.05765321177822, 80.25035227498701, 78.3577694431428, 71.05100570186492, 70.85656596768287, 60.83248615264893, 58.91674564730737, 57.017098626782825, 64.22739167367259, 69.39975846198298, 72.60968500568022, 71.58289478671166, 71.13428546536353, 69.09729665325534, 55.39757943922474, 53.095446248208326, 51.69521108750374, 52.98410192612679, 56.17547565890897, 57.523245196188654, 57.884621004904474, 58.479475898127404, 57.66035164556196, 56.56431590357135, 52.593975144047896, 52.975711976328206, 55.325996183579974, 55.668097465269035, 59.784028760848514, 59.05083579401816, 59.386943694083925, 61.45543306104599, 63.81540944499355, 63.709944755800315, 65.93479940968176, 62.00619266879175, 57.7684364780303, 63.50486363134077, 61.023905661798295, 55.594709919345, 55.2864626146132, 62.33305554236136, 62.01215859382384, 65.39924683109408, 64.02959046825286, 55.86398455404467, 58.85777673413677, 62.16912400337958, 61.2927645252597, 64.14177809992145, 59.997680264134566, 60.289583052358324, 60.49895132741621, 62.05501833269673, 59.351391330842056, 55.81530009546588, 54.96560881214758, 57.54120572920769, 59.09530370466171, 60.79241521896855, 59.734379399207334, 57.574400747976, 62.69032462950676, 61.0538294238429, 56.88458919525147, 57.616766268207186, 62.58514235096594, 59.652421474456794, 59.292798965208, 59.85546296642673, 58.18357229232789, 57.3528927372348, 55.14955620611868, 56.89334392547608, 52.8627202587743, 61.8467483212871, 69.33481970141011, 60.36761860693655, 61.06664772956603, 55.635671231054495, 58.46288034992834, 51.918613603038175, 51.96555652926045, 48.64068885003367, 50.12842424454228, 46.489190363114886, 44.76786605773434, 44.31381640895721, 47.72616863250733, 47.10330801625406, 48.79175893722042, 47.69338154023694, 48.863310813903816, 45.69716576606997, 51.83844820145638, 58.03698155187792, 64.32223066206902, 64.15976216716152, 63.36601957198113, 65.03924777430873, 62.301806019198516, 64.324642919725, 64.25160054237612, 67.57110241920718, 59.36675917717719, 59.412399876502256, 55.65442408284834, 63.681331065393266, 64.33590796685988, 70.14307898859825, 68.07670377915906, 67.55911565596058, 65.68564653396606, 62.88855729564544, 55.9248754285997, 53.62440924490652, 51.58166631575554, 53.950307215413744, 60.07706511405207, 74.31010307804232, 73.2460895661385, 65.24532910316222, 9.285220984489689, 0.07813785029875656, 0.06895739735374529, 0.20625003673616918, 0.31347435328268236, 27.570604701195997, 72.72628138142248, 59.654849421593454, 47.56076228234076, 23.1599876957555, 23.34391155550557, 26.792963435572965, 38.06413535148867, 0.717242464663521, 0.22011829660304133, 0.5859210822851427, 9.20585378523796, 18.19121741479443, 7.692932361556639, 12.01337064466169, 15.863850635866966, 15.165751114968332, 9.749776701773367, 1.7182684112941067, 0.0838738953274104, 0.07863121858287243, 0.10100703040558486, 0.19368761970150858, 16.36828116832241, 73.20813671235116, 60.97244024276734, 35.84434447749969, 27.501667084232455, 76.58463062778597, 47.72512528204149, 69.27887885801255, 47.770856195880526, 0.27263347059488297, 0.8437515278497051, 0.3547961553258281, 0.6341537328497057, 0.7942539129045703, 0.2950763227718492, 0.08634100487876324, 15.448921726595973, 80.93347226419758, 74.4985886543028, 91.98580141990416, 83.63824459814256, 88.8204251566241, 82.25503644635602, 85.66132468561973, 82.81992050909227, 80.44883205044655, 80.90161477365803, 82.72537569845878, 77.38581395918324, 73.68228066352107, 72.28812909895375, 63.9379442891767, 61.43327951431275, 57.99738914735856, 66.79629310484856, 71.66065185300766, 75.3102917825022, 74.48763739678168, 74.18728582320675, 73.10661008281093, 59.51220066316667, 55.941086584521884, 55.899191748711374, 55.344592140566924, 58.7059025610647, 59.61970106247933, 60.33405880774222, 61.54216058792607, 59.20527911955311, 57.872814670685806, 56.93504264277797, 56.55952276722078, 59.729978499873994, 61.34264530674104, 61.94163830049577, 61.776965433551425, 62.461497476024014, 64.77915933055263, 67.66838504422095, 64.40050940359792, 68.63703789249544, 64.82966376889136, 59.6931121426244, 67.51167851109659, 63.88927159770843, 55.53987126196585, 55.31167168771067, 63.36742770287299, 66.52364915417087, 67.43811838088497, 65.60960354343538, 59.02981581226472, 61.68890822318293, 63.824062193593676, 65.85839163872504, 66.21488017420616, 62.94944032546013, 63.0548579462113, 62.55381830276982, 64.42853473847913, 62.34798016086702, 56.72077532737487, 59.56104986129269, 59.583364225203, 62.105201136681345, 63.609504622797814, 62.171163635869185, 61.97945387132707, 64.83087970364478, 63.36865540473693, 61.82640690957347, 60.58507480928975, 65.66763108776462, 61.705919542620265, 61.05889712610553, 61.669017884039114, 61.17458351196782, 59.21199029491794, 57.579880299106726, 60.16196481643185, 55.7946684283595, 68.05961008994811, 70.42751358401391, 58.89956174358245, 63.689356234765825, 58.71299420633624, 60.48648603500859, 54.80294419873146, 52.89555441948676, 50.73928240806826, 51.263566017150886, 49.35977697372437, 47.16842328348468, 45.69489079137003, 48.95149746248799, 50.83410178461383, 50.93416144770961, 51.99287583751064, 50.99698997312977, 48.47976184660389, 54.37875947644634, 62.283229674062426, 66.1630029063071, 67.02505357803838, 66.901898999368, 65.847487449646, 63.430860273299686, 66.3123510729882, 66.36714658429547, 69.19288481435468, 62.057242316584436, 62.37975135926278, 58.12183026344546, 66.619551104884, 66.91678047180176, 72.6510424767771, 72.30443046938989, 72.30884705820392, 70.52817729211623, 72.657435940158, 66.04930908449235, 64.91772490163004, 61.47367208234726, 65.07035609214537, 69.09576692888814, 79.89714284096995, 77.18322353978311, 68.9966643241144, 12.16699811720079, 0.07197147070039665, 0.1850756576224681, 0.17969827197732466, 0.3969351280360453, 31.308843128142822, 83.88144723830685, 71.51969755849531, 59.86353128187118, 38.71180495908184, 28.56920288455102, 37.36660457426502, 47.320183707821755, 0.8923931467917658, 0.1771922911246938, 0.34077634794577477, 7.037142467114234, 19.407036458292318, 15.951362636781509, 17.05071572334536, 18.786025239575295, 27.118588801353212, 18.091273461618734, 4.197633775972551, 0.38689845692246194, 0.28108884430220055, 0.21880788788680108, 0.36311544117427647, 21.959063852986983, 86.14780841335174, 73.24039428464829, 39.86355404700003, 25.868048937089984, 82.30534476618614, 59.716818947945875, 80.833781303898, 55.47380285878336, 0.42125213771097125, 1.1629237979650497, 0.6362888505381923, 1.1491034492369623, 3.1089174218716162, 0.4275067859599668, 0.18834481526526714, 20.70193244564918, 97.46803545182752, 85.01276862236762, 97.68132609705772, 88.24334252265193, 92.54299763710269, 84.6964765364124, 91.30870619127828, 87.37507097182736, 83.3218740647839, 84.2756611301053, 85.981123370509, 82.48007851262247, 77.20668715815391, 75.65391494381812, 67.54602278432539, 64.80783185651227, 62.58038843831709, 71.29816993590325, 75.66516430147233, 79.98369386119228, 78.48658007960167, 79.50807509883758, 76.37904351757419, 63.02006260041268, 59.708793778573316, 60.29059110149261, 58.17264456902781, 62.66465663909913, 63.824242622621604, 62.695847326709384, 66.5424451520366, 63.70268444861136, 61.879762911027484, 57.799736992005386, 57.696209953677275, 61.44251277369838, 64.16529270910448, 66.71730441431846, 66.2650159097487, 66.03860885866227, 66.3617572476787, 72.57416402139972, 67.0762405087871, 73.8822195606847, 65.94397775588497, 65.70616837470763, 70.44762749825755, 66.84601306915283, 58.92930115422895, 59.96569333537933, 65.50328769991475, 69.24760972299885, 70.63937648650139, 68.20572622360723, 61.09629692569856, 63.37220514974287, 65.07278403928204, 69.56403516953992, 68.29006502705236, 66.30842870281589, 66.70669832537251, 63.29943733830606, 66.43790614220404, 65.53598850004136, 59.190370190528135, 63.04128654541508, 61.11467322995586, 63.67027390387751, 67.62662749136648, 66.87526610589796, 65.08078959680373, 66.45867116989629, 65.83440242275115, 64.67211000380978, 62.77474580272552, 66.75060533708142, 63.19854221036358, 65.16293971769272, 63.761453320903165, 63.921015339512984, 62.94329397140011, 61.4543269526574, 63.44907183800975, 59.51153386023737, 62.10406364933137, 70.61353591180617, 67.93832255947974, 66.62008454722744, 61.72097359934161, 63.86042256509105, 58.6246741971662, 56.54606903752973, 54.77102395026915, 57.38650744961154, 53.885697933935354, 50.33512138551282, 51.29978518332205, 52.617309324203006, 54.40964029681299, 54.573701274010446, 54.58139696428853, 53.42586671152423, 51.83135263381466, 58.985563631980654, 65.26403880888417, 69.48481113679948, 71.56310250682216, 70.14037255317935, 69.90521861660865, 65.89544234737274, 72.13962031948951, 69.54850258365755, 75.21211485708915, 65.9169683148784, 65.40002346038818, 60.35669088363648, 69.4771860491845, 70.69711377543788, 78.26588399948614, 75.23985385894775, 75.9468375482867, 77.71113534127512, 78.6459695139239, 75.5586091933712, 75.62293606419718, 72.90837349430208, 73.63103097484958, 77.7030787929412, 89.5509195327759, 83.42317319685414, 75.7779638228878, 13.756424880796864, 0.2037906646728516, 0.41728619245752213, 0.31112981779921445, 0.5587414471853165, 36.82035569221743, 93.86106306506743, 84.66112029167914, 74.44340090597831, 53.84914144392937, 42.97566844571022, 50.72766826998804, 60.24246754184846, 0.7572012430717869, 0.18288993216570348, 0.7963336884014068, 14.654928099724556, 30.02585545662911, 23.61158782436002, 27.30384430577678, 29.326247784399218], [18.064305205498975, 9.062600981804634, 3.807421192046135, 0.04410133374133899, 0.10207479609356773, 0.05292930963238882, 0.1235400741138766, 29.42218307525881, 61.772866556721354, 50.35894586193947, 16.262051616945577, 31.11669601932649, 48.34102761360907, 49.97214132739652, 63.36624706945112, 55.75721371558405, 0.006910371631684323, 0.4004680497511741, 0.15869352005181775, 0.7021897562569188, 0.5182932918110202, 0.0851455323338028, 0.36903497192167467, 9.588782037458113, 25.790095752285374, 52.778589340948294, 75.95870664042812, 78.06312884053877, 78.14522404824534, 79.70264034886515, 79.5462554500949, 80.10411062548238, 78.84023666381836, 83.65712688815209, 77.91196069409771, 80.41537423287669, 76.1861962656821, 70.33819337044993, 61.50295649805377, 59.218681858431914, 56.34762456340175, 61.33521633763468, 68.51421279291954, 72.25602057672316, 67.35949054841073, 72.36428583821943, 63.96111372978457, 55.739825848610174, 50.39557687697872, 53.38423859688544, 53.050307612265314, 51.5195712735576, 53.738561984031435, 56.04599821952082, 56.396681647146906, 53.860645755644775, 54.662519424192375, 56.005087898623565, 60.46196337669127, 61.03991285447152, 60.91935096248504, 61.230947971344, 60.715548530701675, 58.36080458856399, 61.691457763794936, 60.53005964525285, 70.36916440533054, 69.226899608489, 55.50616241270497, 57.813002447928156, 59.61751630229335, 57.66982024715793, 51.84663418800601, 52.60223565563079, 62.213862557565015, 61.289026506485484, 63.753298713314926, 59.22153734391736, 59.92914861248386, 61.11291600811867, 61.25630609450802, 64.36737714275237, 65.42756634373819, 57.338576086105846, 61.80200192236132, 61.60990384317214, 60.244973936388575, 59.123944851659964, 57.5484307350651, 59.942680789578354, 60.170613642661806, 59.555421260095414, 58.061919981433505, 57.518538351981874, 59.27629363152289, 63.908659873470185, 61.58696582240444, 60.00741166453208, 56.14699532908779, 60.68047469662082, 56.76100707823231, 59.59202874091364, 59.20116063087218, 58.55256142154817, 55.394049306069654, 53.732478387894176, 55.084178140086514, 58.21108379671651, 61.039806950476866, 52.963187848368, 56.754315514718336, 57.829884329149806, 55.11561201464746, 56.134859515774636, 51.33724774083784, 50.00457148398123, 47.362812026854485, 46.52380527988557, 44.33429510362687, 46.48901385645713, 45.86386257602323, 49.656398373265425, 47.570274030008626, 47.96899864750524, 48.26311757487636, 48.389904268326305, 47.568810985934356, 56.19008256543068, 63.56669979710733, 60.38687352211245, 62.49747737761467, 61.12048226018106, 63.1783067026446, 61.22539389518, 67.39852597636562, 65.19900591142716, 65.0097123269112, 59.77318340732206, 51.808736247401086, 52.494264571897446, 63.92967201048329, 64.651082177316, 68.25943916074692, 65.35218623376662, 69.41572250858431, 63.568570767679525, 63.442380274495775, 57.840227619294204, 56.15481261284121, 51.04972624009656, 54.385847199347715, 59.9776840209961, 70.42302639253678, 71.51053490177279, 80.3889923710977, 30.77063510494848, 0.018962459195585504, 0.1868650245089685, 0.6067581835293001, 0.3476810064767638, 25.864373676238525, 72.51912532314178, 60.09137784281085, 48.88032997808149, 31.16251322530931, 28.151499878975656, 29.205805524703, 47.953897522341826, 1.320011168718338, 0.11422295108317368, 0.25553696218036837, 12.691631797821293, 17.62517233048716, 7.5475555946750035, 11.157555560911856, 10.842969705981593, 18.873192071914673, 13.483337702289706, 3.181073343561542, 0.052181086878502564, 0.08571771574356864, 0.008701494774751125, 0.30368234000859723, 39.24592195018646, 73.51137515037291, 60.140858542534616, 22.49153148743414, 29.779920885639807, 55.58134640416792, 58.787613376494384, 70.51847334830993, 60.7025380288401, 0.018681207251164223, 0.4366624253171106, 0.1387603565930359, 0.6781925116815876, 0.7642900078527389, 0.06893493565580538, 0.2095762985728441, 18.429560238315215, 65.07106996351673, 73.39054261484455, 84.40204774179767, 85.2080555885069, 82.43643037734493, 82.02244773987802, 80.80494403839111, 82.35915184020996, 82.0330616735643, 84.77166052787535, 79.0780342778852, 82.48731920796057, 76.98611659388389, 75.09059982915079, 64.28844728777486, 61.75075223368984, 58.30609144703035, 62.20861050390429, 69.52493698366227, 74.57787544496598, 70.37093731664842, 74.34389037470665, 67.22725176042127, 59.49533839379588, 53.24175457800589, 55.791240276828894, 56.48711581383982, 54.61545098212458, 59.05443260746618, 60.79653763001966, 57.71935586006411, 55.04574283476799, 56.5077631704269, 57.82598941556869, 66.0251159052695, 65.28587464363345, 64.9129552995005, 65.0039464427579, 63.253886853494954, 62.50314520251367, 65.84115674418788, 65.72162643555673, 73.63464740014845, 70.24126375875166, 55.759951529964326, 61.54094465317265, 62.340974807739265, 58.84174600724251, 55.9666722051559, 56.27060098032798, 64.82598850803991, 65.76951465299054, 66.62443837811871, 62.04547128369732, 63.59943589856548, 67.51250220883277, 62.68940679488644, 66.39382654620756, 69.57766932825889, 62.262154779126575, 63.43536707662768, 67.3458642344321, 65.87484205922773, 61.75082283635294, 60.179427208439, 60.87778168339884, 62.84771365504112, 62.76237072483186, 61.57637542293918, 61.89822942979875, 61.0278868675232, 65.05727890999087, 60.94423840122839, 61.691300868988044, 59.44209614107686, 62.34792524768461, 59.343515211536044, 61.230034059093846, 60.48038674939064, 59.81150888627576, 56.6086700654799, 56.07865195120535, 57.819419445530066, 63.68399827711044, 65.50253460484167, 56.46597423861104, 60.322452514402336, 60.17610103853288, 59.42697148169241, 57.35052754802089, 56.79240957383187, 53.275043733658336, 51.31830661527572, 49.03129416127359, 49.203042984008796, 48.98384524929909, 48.49191334939773, 50.270739601504424, 51.21722713593514, 51.56924416941982, 51.81521992529593, 50.83397626876832, 51.16185503621256, 58.44509240119689, 64.4588154362094, 64.63268626120784, 65.0158469138607, 63.157471072289255, 64.56946157640027, 64.55836911355296, 69.22266344870292, 66.28152908817415, 66.35684644022297, 62.5899080307253, 54.128708377961196, 54.294495198034475, 66.5575070534983, 67.22805976867676, 72.79189478966498, 69.25138304310461, 74.83438276475476, 70.18459335450204, 71.90032436001685, 66.49938537228492, 65.76292507110104, 61.159521610506125, 65.32682418823242, 69.01669979095459, 79.46824735210788, 75.6862666529994, 84.09382789365708, 35.25960929932133, 0.1894787786107871, 0.1288147733336495, 0.7445664307282818, 0.46822098834860715, 30.08612071314166, 82.17735782746347, 70.84293180896391, 61.46122247942033, 47.933509042186124, 38.10910532551427, 33.52753769966864, 62.7548986096536, 1.7517927865828238, 0.21998403203343192, 0.6419336927994606, 11.42409630360142, 26.496569533501905, 15.264331063916607, 18.70158249332059, 19.978794474755567, 29.394247954891576, 14.718484224811679, 6.815488348084112, 0.20679216651666552, 0.306290072659331, 0.16932170297349655, 0.5255428124820033, 48.1708045928709, 87.22980991486581, 70.45011428094679, 32.02866277387066, 43.47541370699483, 68.0178996055357, 67.95012104895808, 80.57473228823754, 69.2204276977047, 0.1825466634885919, 0.7976806548333938, 0.3261039255847854, 1.1701203666387068, 1.0061557939456356, 0.38571662840343296, 0.5084677545293685, 27.564913342075965, 85.23435900288244, 90.33437375099429, 94.52650100954118, 94.09971575583182, 90.01741486210977, 88.20870014929002, 83.88584029289984, 87.56614531240156, 86.75681914052656, 90.12905336195423, 82.0383882522583, 85.99995859207647, 79.70467998135476, 76.72833842615928, 64.90644808738463, 65.24005351528045, 61.749955992544855, 66.82712293440296, 74.0657001926053, 79.79606336162936, 75.66579972544025, 80.3303764712426, 70.16869991056382, 63.311486859475416, 57.03066218283869, 61.083019702665275, 59.59814371601228, 55.63878559297132, 61.311737029783195, 64.83837143067392, 61.44113994413807, 60.511130286801254, 59.20119593220373, 60.366755685498646, 67.58918454570156, 69.95729200301632, 67.66060306179908, 68.56656074523926, 66.90101254370906, 63.91742244843514, 67.64987145700763, 67.93216443830921, 73.10063239066832, 67.74226680878671, 60.31681214609454, 63.73637368602138, 66.35563050546955, 62.14906892468853, 55.976136884381695, 58.938652084719756, 66.886397792447, 67.59791574170514, 67.61473486500402, 63.84450950930196, 65.60871316540626, 69.83821668932515, 67.49958976622551, 67.43973439739597, 71.47346065890405, 63.99069232325401, 65.69937482956918, 67.22649866534819, 68.52313226269138, 62.06746009088332, 63.20708121022871, 65.10123299014184, 65.55466290443175, 64.89101748312673, 63.95337489343459, 63.90223110875776, 65.03292099122079, 66.9322189208, 66.22352507806593, 65.7191357304973, 62.07698752803188, 64.55317589544481, 60.63972127053046, 64.61789108091786, 61.97309570927774, 62.428329913846916, 58.757913189549605, 57.478620390738214, 65.69642912956976, 60.24289900256742, 63.83717467707973, 61.62697399816206, 60.691159232970215, 64.63218027545561, 61.50425480258081, 62.22779089404691, 57.95620426054924, 54.64732023977465, 53.79495389999882, 53.771098044610795, 52.06633790846794, 52.20758245837305, 52.5679188389932, 55.14040923887684, 54.807784403524096, 54.64912845242409, 55.28688623059181, 54.371318740229455, 55.62883061747397, 62.03371201792071, 69.91502454203945, 68.72533828981462, 70.99299384701636, 65.79090333754017, 67.74830725885207, 66.60912544496598, 72.58759421686973, 69.87070960383262, 71.03435131811327, 65.62608142052927, 56.8401526635693, 57.85255562874579, 70.35775815286945, 68.74334196890555, 76.18032055516397, 72.28743876180341, 80.24979529842254, 77.11790038693336, 79.01856330133255, 74.1798568541004, 76.59776272312288, 69.8620411657518, 76.93485906047206, 77.18775779970231, 88.93016522930515, 83.10740670850201, 92.02744914639382, 38.78214090101181, 0.354097789574054, 0.27356463514508744, 1.6216733042270908, 0.5704033278649854, 34.91865334972259, 94.7071575349377, 83.28149718623008, 76.86172254623906, 61.75440396032026, 50.58157959292012, 45.50624832030266, 75.49022659178704, 1.738688025263048, 0.20832359159906066, 0.782521061839596, 21.81106694283024, 34.7416877746582, 20.798054049091956, 27.110373397027296, 28.45455200441422], [23.339820523415845, 9.278984415915705, 3.092753089243366, 0.06288462220841358, 0.08195235529133389, 0.051984884100215095, 0.21105835694939862, 32.81415858576375, 66.53763632620534, 40.42213486086938, 26.087782075328214, 39.68967929963143, 58.980197829584924, 43.670622225730654, 67.26406712685862, 65.95361894176853, 0.3640757783526375, 0.058498630946081494, 0.12664549578461917, 0.21658584986242557, 0.027478078057268457, 0.1555765074707808, 0.3910136973905948, 6.554262416978037, 5.0889286591160685, 39.13635446179298, 66.74435307902675, 76.70562790286156, 74.74911828194895, 80.49440999184885, 76.70411386797505, 76.7012740719703, 77.6838513343565, 77.95413401819046, 78.98518393116613, 79.92056723563903, 76.18203855329945, 72.72562242323353, 61.49061672149166, 58.79714865838328, 56.35655972265429, 58.182474028679636, 62.39311879681003, 67.19947353486093, 68.84832028419741, 65.91620737506499, 61.361868842955566, 59.106788404526256, 52.77855011724657, 50.89285888979512, 52.36067256619854, 52.093061016451934, 52.59451643113167, 52.80659114160846, 52.77845598036244, 54.726614875178186, 56.89617195437032, 62.11922361004738, 64.63759706866357, 62.71536504068683, 65.71169891665059, 63.081632045007524, 62.93972069217313, 62.18762974585257, 63.15559225697672, 66.60214362605926, 65.21953951927924, 78.36566125192951, 68.7250009659798, 55.9387174729378, 61.413557837086344, 57.35943132831205, 47.86178850358533, 54.33660184183429, 64.64521823390838, 60.314305751554436, 62.606617327659364, 61.16288700411397, 64.57198366042107, 59.34095782618369, 61.60298870455835, 64.08341715412756, 60.222655650108095, 60.417107151400664, 66.41460726338049, 63.18095822488109, 61.60027834676928, 58.81251650471842, 60.756855010986335, 61.256313939248365, 59.707299355537664, 60.48052795471684, 58.74647163575696, 61.00210905075074, 63.57979266874252, 58.67609254775509, 57.17540156456732, 59.70504007031841, 57.527289159836315, 59.392038852937766, 61.48397222641976, 57.1295843585845, 56.84080769938808, 55.89172355590328, 51.05980673143941, 51.9867883190032, 54.53445011569608, 57.84105916177073, 42.92548171935543, 58.334760050619806, 59.1702562762845, 59.17166440717636, 58.06412827584052, 55.18618329878777, 52.41898252118019, 50.167997037210775, 47.0722310773788, 48.58598747561055, 47.528132084877264, 49.001962677125015, 52.48476851371027, 49.869230101185465, 50.2794982540992, 46.65550278079125, 45.97399096335135, 47.14470863342286, 47.72615686539681, 57.5053866447941, 59.2090642067694, 59.42770496491463, 61.45507220299014, 65.00621357271748, 66.76412182469522, 67.7834830745574, 63.483420033608716, 61.911032046041186, 59.60627871174967, 59.95873505069364, 52.31643999776533, 53.119659039282034, 62.3571781189211, 63.070151267513154, 69.390062362917, 67.97614989742156, 67.04970959694155, 62.85243618872858, 62.55326132620535, 59.2472327909162, 55.21498526296308, 52.389470608003684, 50.95102763945057, 54.053210596884455, 64.71422841472011, 71.26207628557759, 80.03310003588277, 64.29553501067623, 2.266189326201716, 0.3162916263024653, 0.3331104738097037, 0.49627004131194086, 14.300452720734382, 67.36298930260443, 62.531951089059156, 49.75623053889121, 28.27863370218585, 24.157130679776593, 30.179082847410637, 55.199790000915534, 2.9695453134275254, 0.44346087341827733, 0.7075814830680048, 17.546830831035493, 20.565492799205167, 6.263923183564217, 6.2108172332086875, 11.049872771386179, 24.385243961887976, 12.706917274382807, 3.976893814340715, 0.05214161036776439, 0.06687762185690865, 0.049272480856386885, 0.46427471623305355, 43.84220630891862, 76.4402638712237, 50.1947436794158, 31.78260268703584, 44.01722246600736, 61.50884005331225, 51.943889356428585, 74.27068325781053, 70.21717256115329, 0.1993198061902677, 0.08728369139134885, 0.21843867947257337, 0.2549376056319283, 0.3764207030255949, 0.10033719376811098, 1.480591410110074, 17.046897295982607, 36.560828147395966, 66.7952968228248, 75.90348751314225, 84.31814824381183, 79.46470152947211, 81.95480254388626, 78.80933623160087, 79.8290426500382, 78.2464761118735, 82.1330899576987, 82.24096298217773, 81.46431799857848, 78.85148602147257, 74.74908690298759, 63.77391861331079, 61.23382306868031, 59.54692540630218, 59.03327534275671, 61.32604975854198, 67.82462089292466, 70.14264752787929, 68.19840708086568, 63.19188987055133, 58.71455923203499, 56.87413607874225, 55.10174251371815, 54.264383162221606, 54.971574737179665, 56.99301919629497, 56.88999422134892, 56.38457329042497, 56.91512484704295, 60.58651431914299, 64.52438177600985, 64.99521916912448, 66.24347425276234, 68.21270804251394, 65.72584690586214, 66.75536709447061, 64.05390524095105, 64.88227059764247, 69.194257643915, 66.60364981620543, 78.99793163422616, 68.22522824810397, 56.36276883463706, 63.74047648522162, 58.897969261292495, 52.458873025832645, 58.64902819356611, 69.10563561224168, 65.30229368517476, 65.47606645091888, 62.14113004745976, 66.61398918397965, 64.74572896957397, 64.90885642267042, 67.0267088182511, 62.09737993055775, 63.83876323699952, 69.40978404014342, 63.97062939982261, 62.63179894416564, 63.44704397263066, 61.82535963673746, 62.151520406046224, 62.38218715113979, 65.93363838811075, 59.10269737243653, 63.82831012049029, 66.27257823944092, 62.00827152498307, 61.93822976081603, 59.52133586329799, 59.473533938007975, 59.80844943754135, 63.207598963091456, 62.36044937564481, 60.737957031496116, 58.55398524192072, 55.843494092264486, 55.126163190410985, 59.610134401629054, 61.924776031124985, 46.53386223700739, 61.617277899096095, 60.11868538395051, 60.857393203243134, 59.61770065369145, 58.69209974042831, 53.64458199470274, 52.943764271274695, 50.306876397901966, 52.19871790178361, 50.225189116693315, 50.71316726746098, 56.084209949739524, 51.59121728712513, 54.912703883263376, 50.5060229762908, 49.947638280930065, 48.10001365600094, 51.4891376033906, 59.41097997849988, 61.710712678970836, 62.54085094698014, 63.6110931827176, 67.12495634632727, 67.30941757079094, 67.70942872570407, 65.10544953807708, 66.08640686158212, 63.27926066613967, 61.134049738607104, 56.43457566538165, 54.33654692865188, 63.46978587488975, 67.00745782544537, 72.17051290696668, 71.30923886452952, 72.98974698589694, 71.62185176726311, 69.04175589161535, 67.47018767941383, 66.70456455599877, 62.9664751791185, 62.14915129446215, 65.15570686709496, 73.05121837123748, 76.9519841286444, 81.64037750613305, 68.78128697795253, 4.037303953401504, 0.5761698248886293, 0.4244402585731399, 0.4470500566305653, 23.494097148218465, 74.70467782789662, 76.24536914210167, 61.41497381271855, 45.70626174249957, 32.85361959088233, 38.674463995041386, 68.62365476546749, 3.2797815049848253, 0.4061517173484449, 1.5960712586679768, 18.680466413497925, 29.032801543512655, 12.24502484644613, 12.493194187841109, 19.581083789948497, 35.13713329069076, 17.023433677611813, 5.138812382375041, 0.22855912996155603, 0.2269055291769966, 0.14472022953052677, 0.9821091520209467, 61.3089168456293, 87.69780358960553, 61.9462666972991, 40.869940096332186, 55.66410057006344, 75.19764915589364, 63.299539319930545, 82.88405910614999, 80.79524009458481, 0.47715158171711436, 0.2765642677343661, 0.3460101380703911, 0.40224981704546564, 0.810785906449441, 0.2611477901377986, 2.6194978000656253, 27.897744101862756, 58.20864408246933, 91.7898319613549, 86.4914551088887, 92.91867440746677, 81.66973252450266, 87.50498771667482, 81.14258166282409, 83.37848955585112, 82.61118765800231, 86.1742530330535, 83.20428925175821, 86.67936017436367, 83.09363134445684, 80.45464500304192, 66.71735932750087, 66.56888977173837, 63.45460237995271, 62.37794706898352, 65.8362380919918, 74.33258610387003, 74.46694297175254, 71.50053285783338, 67.02860724541449, 63.21211753352996, 61.93117341687603, 58.27575975848783, 59.185361323818086, 59.12150513741278, 60.49217347175845, 58.151169592334384, 57.91187363286173, 58.735237967583444, 62.16728048939859, 66.69617852857037, 67.89826731528005, 70.2735762442312, 72.2007308467742, 68.1946651397213, 69.88521452872985, 65.80071318534114, 70.72464881404754, 71.61246945781093, 73.37069542177262, 82.06721767302483, 64.2826186456988, 62.27081537246705, 68.96521476007277, 61.82988997428649, 54.90183891788606, 62.40009277097641, 71.9469613413657, 67.51654225011026, 67.33426186346239, 65.09135646204795, 69.58699672452866, 67.23748130183067, 66.49727513713222, 71.32903114441903, 62.74809329740463, 65.59114879177463, 72.38594516631096, 69.0098984010758, 66.92159714237337, 67.68595726259294, 64.95337532412621, 63.69087811439269, 65.14241003221082, 65.27114222126623, 62.88017126821703, 65.23441314697266, 70.24313080695369, 64.22805063186154, 62.579819694642104, 63.95013109330208, 62.4895110437947, 63.63378801653462, 64.96298120867822, 64.16236269858577, 62.52873082314769, 61.011977734104285, 57.61490314237533, 58.22022291921801, 59.00776032478579, 59.51752724186067, 52.02457251087312, 63.79438161849976, 65.28534120129001, 64.73421681311824, 64.6814452448199, 60.67537169302664, 57.002162241166644, 54.80980442416284, 53.868102181342344, 55.39704991925148, 53.84421886936311, 55.08897912117743, 61.14070600078952, 59.12694154247161, 60.19603844611876, 53.90726704751292, 52.29936199803507, 52.36057450694423, 55.92422823752127, 60.81192116583548, 65.66223782877769, 67.32712314974877, 66.32517722345167, 70.99998351066344, 72.62699834762081, 74.42404008680775, 68.62185831992858, 71.01593971252441, 64.39974061904415, 65.91657607786118, 58.67275068836828, 58.42236226604831, 67.18040297108313, 70.8738479306621, 76.22856570828345, 74.46485627082087, 76.83974942853375, 77.06565441623812, 74.73346018022107, 74.86529104171261, 74.78397246330016, 71.09862327575684, 71.11000599399691, 76.98798364208591, 84.22972233064714, 89.29947991524973, 88.29705545979162, 76.35455223821825, 4.38454746238647, 0.717980299265154, 0.94824138548105, 0.7670873319429736, 34.035347354027536, 86.80926122973042, 86.71788569419616, 77.70941734313965, 59.5659645911186, 44.31535005569459, 51.80572778947892, 84.73408422162457, 3.768931954137741, 0.452926533236619, 1.5780255366717617, 30.275951662371238, 41.60882049991239, 21.2791778579835, 18.3309361627025, 25.08261392193456], [15.969676183116054, 10.609007189350745, 2.6653708998234045, 0.2690019686856578, 0.002959626520262851, 0.015112211413290954, 0.6307344679390231, 36.02473035935433, 66.28866780188777, 33.99885754431448, 10.704161928546045, 44.927271181537265, 44.691889747496575, 40.73129607785133, 78.94712125101398, 73.33158154641428, 1.3339200159234386, 0.09230616382293164, 0.2598044396408143, 0.06880870734852168, 0.38292825222015386, 0.15928772848940667, 1.5926580611736545, 7.653325248149134, 4.310102837700998, 33.92073569759246, 63.33582908876481, 77.66556524461316, 75.97765168836041, 79.3643908346853, 73.37061697436918, 76.30754655407321, 74.64260239754954, 77.5656154078822, 76.73250398328229, 75.52536318379065, 72.90112495422363, 63.09982007549655, 59.94497145375898, 57.88041230170958, 60.41105493422478, 57.03005813783216, 56.00189901167347, 60.97507999789331, 64.06254230007049, 62.56115705736222, 59.15577096323813, 57.53473774079354, 55.61423547806279, 51.636697169273134, 52.40208495047785, 53.6884537050801, 50.439680007196245, 50.59837518199798, 53.359963047888975, 57.803176910646506, 61.690249673781864, 62.05222168276387, 63.50292990284582, 63.50240038287256, 64.0236637669225, 62.334361691628736, 62.29595384290142, 65.03722383129981, 64.95692506913217, 60.53469196442635, 66.14457561123756, 51.194555836339156, 60.6466717104758, 69.22648383725074, 56.06861852830457, 54.4148099807001, 53.76852496977776, 53.04334932757963, 64.75331483348724, 62.57170431075558, 62.40007315912555, 61.76994439094298, 65.0388986833634, 60.53779455923266, 62.11335966663977, 60.19989805836832, 62.3177190749876, 62.284994740639966, 63.28679161687052, 55.701057141827, 57.31191573604461, 65.85319057587655, 62.28395923491448, 65.1435318300801, 63.10845321224582, 57.075738060858946, 43.41025137132214, 56.05233676971928, 66.78940542282598, 61.330317297289454, 59.170758339666556, 56.58630863312752, 54.779743379162205, 56.030120465063284, 59.484442049457186, 56.38183939841486, 58.463888399062625, 55.06664514541627, 53.27440046495008, 52.57386122980426, 58.24583207407306, 41.4018331035491, 47.71385631253643, 58.64494500621673, 57.273594179461085, 60.00527789515834, 54.62220530356131, 56.20820783799695, 52.9175236148219, 51.48204203574888, 46.059479021256976, 46.174526060781176, 50.6101736714763, 49.551282775017526, 49.40009893909578, 45.621977852236846, 47.32978174763341, 45.162766364312944, 46.38806773770241, 43.60642871549053, 50.08416029714769, 56.63606782113352, 58.31058256087765, 60.805629684079086, 61.984035199688336, 59.896420355766054, 62.21652584691202, 61.90895318984986, 62.89249535529845, 59.458915264375754, 58.777525040411184, 58.66063056453582, 56.42569541931153, 59.28187908664827, 62.998477797354425, 65.24444656987345, 72.54840189410795, 69.89220419237691, 66.71167973549136, 65.60990164356848, 64.6213702232607, 61.41090631484986, 58.7233845649227, 53.24555535470286, 51.54074815011794, 51.62376119244484, 54.12626474134384, 64.10368404080792, 68.47687967361944, 84.09323953813123, 12.490940786177113, 0.854385870118295, 0.9462804455430278, 0.041272707298518195, 41.670319341844134, 62.829431487667954, 64.0045500570728, 51.977127521268784, 36.33100078951928, 27.11335047598808, 26.4474908767208, 52.1085229996712, 3.811175390597313, 0.5153034651471723, 3.1243865143868232, 20.049314768083637, 26.470036660471273, 4.261947408799203, 3.378656121992296, 8.97503504830022, 24.504050593222342, 13.805134834781772, 3.11757801521209, 0.1245082253890653, 0.03424863481233197, 0.13657210304612113, 0.9056730051675151, 50.60062270010672, 75.69314649028163, 48.24853420257569, 19.44473239683336, 45.845941266705914, 48.56908206016787, 49.74893885274088, 80.63188906638854, 79.03621396710797, 1.2244904233563332, 0.021736423349789074, 0.2956070684857907, 0.13551698546976815, 0.442433764016436, 0.06456196022730681, 3.551817488285803, 6.4736194668277625, 19.329414713767267, 62.721982079167525, 75.0537609284924, 83.74680795977193, 82.04345595452094, 78.26886500081709, 76.6555392357611, 78.60334119489117, 79.05517470452094, 78.24857065754553, 79.9069409216604, 78.17236684983777, 77.35125003322479, 67.67776735367315, 62.866050735596694, 60.43749563155636, 61.188296118090236, 57.20129705244496, 58.991376584576024, 62.81696227289016, 64.62867367652156, 64.9942111199902, 60.48166936443698, 59.87899718746063, 55.934383253897394, 54.21389049099338, 55.346678841498594, 56.76123065333213, 53.11159464620775, 53.54076470098188, 56.09050927623626, 62.411785356460086, 65.23912391354962, 63.80713324392996, 66.36726425540063, 64.93382230881723, 66.6308161520189, 65.72908678362447, 65.96988108850294, 68.84258577900549, 67.53726805410078, 65.04362121705087, 67.10515622169741, 56.053313439892186, 61.92364246614518, 73.46115312268658, 54.62024804084532, 55.786443218108154, 58.669267623655266, 55.200252840595866, 67.41814567196754, 66.13841749006703, 64.30140287645402, 65.70089278682586, 67.38295416678152, 62.7161063686494, 65.51703560736873, 62.101545487680745, 66.0207934533396, 66.39163001891106, 66.21748462800058, 56.46975540345716, 56.729945828837735, 68.521484867219, 62.51075067827779, 68.87147795769476, 64.73230269647414, 57.240760018748624, 44.91635522534771, 58.835285863568714, 63.620675533048576, 65.72939272849791, 62.62897876001174, 59.915957681594364, 60.06946748302829, 58.154911533478774, 61.25163062926262, 60.80302915265484, 61.70345629415205, 57.06344535273891, 54.84090489725913, 58.31660732146233, 61.904136519278254, 41.59317024292485, 52.68205196626725, 60.662200373988, 61.495084301117934, 61.62948039270217, 57.03192910840435, 56.86342800817182, 54.75206321285617, 53.21403518799813, 51.23940029451924, 49.374964391031575, 52.72909295174384, 52.147668253990915, 51.75596075673258, 52.00102652272871, 51.81331365339218, 49.25605773925782, 51.34539058131557, 46.62358645469912, 50.95181995822538, 58.433921490946126, 61.51795956396288, 63.160142206376605, 63.63945976380379, 60.90952542520339, 62.37216157297935, 62.004286396888, 63.66879517032255, 61.464791836277136, 60.70889226851925, 60.70002771192982, 57.44256596411429, 59.29667034456807, 65.83154693726571, 68.03387934161772, 76.34381278868645, 74.6476230313701, 71.24178978704637, 72.96549889349168, 69.78011069759246, 69.8893016384494, 66.52677920556837, 63.545158140120975, 62.87073404558244, 64.71269869035291, 65.6531261628674, 73.91269637692359, 73.85206437879994, 91.21493800993889, 17.06444009657829, 0.808548990997576, 0.6022767530333611, 0.043188543809998425, 51.71289705461072, 71.73245476138207, 77.81474867174703, 63.752608376164595, 50.686636355615434, 35.924576559374415, 35.75662459096601, 70.37271022796631, 4.696072397693511, 0.4407109854923141, 2.532132888032544, 26.298870309706658, 29.736753240708385, 8.86604512891462, 9.085832199742718, 14.873879705705951, 31.5889689999242, 21.767832617605887, 3.07435104443181, 0.3805251569757539, 0.11540585212529668, 0.22872011567796433, 1.660362705588341, 64.84041498553368, 87.53412308231478, 58.29093148631435, 23.402688272537727, 59.28970029277187, 59.049455119717514, 61.601482514412176, 88.45976321927964, 89.4334759250764, 2.178965864642974, 0.16724454749736095, 0.6176954676066676, 0.2272364638385273, 0.5537124783281357, 0.18836036685013002, 6.0460512099727515, 20.600076337014478, 43.11867413982269, 86.67486513814619, 83.76910271183138, 92.62056642963041, 86.25112364369055, 82.15037976541828, 78.44912928919639, 82.39896389745897, 81.41500596077212, 84.96650818855532, 84.08306490990424, 84.64684286425191, 80.36451678122245, 72.27371831094065, 67.98499091978996, 65.33174284042852, 65.47910628780242, 63.094124794006355, 61.804684823559185, 65.60777964130526, 69.14649101995653, 69.19308877760365, 65.3945517539978, 64.57070889011507, 62.547695482930834, 55.95927853738108, 59.93138436348208, 60.372843204006074, 57.867856794788, 56.18539925544493, 58.82817852881647, 64.70122183522871, 69.00292442690942, 66.59208666893744, 70.9301104084138, 69.20808792114258, 70.86621499830677, 67.452482100456, 67.59484844823038, 68.9182561443698, 68.16671432987337, 65.38818182483797, 70.99362142624395, 64.08813184307468, 67.5826184980331, 64.62913259383171, 61.28413531088061, 60.20895873346637, 63.61755332639141, 59.71739161399103, 68.81844751296505, 67.4511641840781, 68.62149746187272, 67.89949893951416, 71.48805187594506, 66.23556675449495, 66.7941750249555, 65.24461915416103, 67.87063029504591, 66.31055462744929, 70.38102565273162, 59.078002129831624, 60.907203382061375, 72.17590224358344, 66.78001526863345, 73.2469367980957, 68.22303172080748, 60.3138703684653, 47.17140820718581, 61.110052677892874, 69.87679712234005, 69.49817072960639, 64.86792256755214, 59.08889847417032, 61.5166534146955, 60.79487062269642, 63.41171518448861, 62.26702244051042, 63.134631110775864, 60.24826872733332, 59.53975139125701, 58.302475021731475, 59.66334527538669, 47.55960126076975, 53.322312216604914, 63.20354715470345, 65.63667966473487, 63.74139039747177, 62.48152509812386, 60.442865356322265, 58.49212161956295, 57.42416220326578, 52.998214614006784, 52.77573777783302, 56.791326999664314, 55.221825876543605, 55.71471091239683, 54.443451127698346, 55.66506547312583, 51.6183404768667, 55.00866859189926, 50.632668464414536, 55.74298727896906, 63.09908659227433, 65.49332095730689, 68.38214658921765, 68.57380928531771, 66.71283291232201, 66.010877701544, 65.90202408452188, 68.99300867511381, 64.36283111572266, 65.70988678163098, 66.08646961950487, 62.33000786073747, 64.1618880917949, 69.9351070773217, 72.07912952669206, 80.84076312280472, 78.3395068876205, 76.9178516634049, 77.62561198203795, 76.62283451326432, 78.72961013547837, 75.49763987141272, 73.60436670241818, 72.05310852296891, 76.98542625673356, 74.96284038789811, 87.7986006582937, 80.47143274737944, 100.48459699076992, 18.577615984024543, 1.0468884437314927, 2.3362820811810034, 0.11942630453455834, 64.52267162261471, 83.81202128625686, 86.9265793215844, 75.69280132170647, 69.11494731903076, 48.598084065221975, 50.16290580072711, 89.23724759009578, 5.71595287130725, 0.7335934163101259, 3.35134637451941, 36.569602489471436, 58.438145883621715, 14.120747370104636, 11.83294063614261, 18.031480850711947], [16.172578430944874, 12.31496855135887, 1.0696537576375469, 0.1701884242075105, 0.06921901637988706, 0.04975950976292934, 0.9432741326670494, 39.36158087945754, 64.10833989420246, 37.89529300505115, 13.86965488233874, 40.11192244868125, 45.96343978758782, 45.00333378391881, 80.97984252437469, 80.1706418683452, 4.854057133197784, 0.07590825864744764, 0.1915061077283275, 0.07567664728529992, 0.17841368042413266, 0.28748445272926365, 4.036580276104712, 5.036648857978083, 7.0516733777138505, 35.46381573523245, 70.35352983782369, 78.94342637831166, 76.85110861255278, 80.55621085628387, 76.0972055312126, 74.85283359404534, 69.23206144763579, 73.89159402539654, 70.88436772746425, 70.24769644583426, 65.23703329024777, 60.16911137488581, 57.049313053008056, 54.1072569354888, 58.41964798588907, 57.528501172219556, 55.768647424636356, 57.110753059387214, 58.413540855530776, 58.79926673827633, 58.96859153624504, 55.782434555792044, 52.71555685227918, 52.37937442718014, 51.7572041480772, 48.55268263047742, 52.654771881718794, 53.67701215128745, 56.54352734165808, 60.7967298261581, 62.667461133772335, 64.12142884346747, 63.83832785391039, 65.67489923969393, 66.46031856536865, 66.21149909111762, 65.26179913551577, 63.96417710088915, 69.0174215070663, 73.22446161700834, 64.91296706661102, 60.58205458425707, 41.67628526687622, 50.20944864519181, 58.49590670677924, 57.351786628846206, 49.19604547562138, 55.158342315304665, 62.069307527234486, 61.51994820564025, 63.54648390123921, 61.994857018993756, 59.21415544325306, 60.91275353585521, 61.09577132809547, 62.294353515871116, 61.88654468905542, 58.41136394008514, 53.732443086562625, 47.30133279677361, 49.32229088198755, 60.17008804505872, 57.531890100048436, 54.62771231128324, 51.685385550222094, 45.66399428152269, 49.01884455834666, 48.92149917541012, 47.157483793074086, 50.771351706597116, 60.43730735778809, 61.42592114786948, 56.76320752789898, 57.96297034909649, 59.12673365685248, 58.93336865209765, 60.83494940111714, 54.05451674615183, 47.46138511165496, 54.249423242384395, 39.67320142253753, 43.43932397903935, 57.42335811738045, 55.273385432458696, 61.01865360813757, 53.90430565803282, 56.93436799510833, 54.43919535606138, 53.488895277823175, 53.01830107165922, 51.18480090172061, 48.758913009397446, 51.21468151769331, 51.00215965701688, 49.47489853828184, 46.90702084572085, 47.43938453735844, 44.61494461182625, 44.65736112286968, 44.99190791960686, 48.57920177521245, 53.39260501246299, 56.71736286532495, 57.04547697497953, 57.80888003687705, 59.63968161613711, 58.60246573725055, 55.9450795573573, 56.21004350723759, 55.485346394200484, 54.84252875851047, 55.25959045656266, 51.26879453659058, 58.78237701231434, 62.43000084354032, 70.84906639591341, 73.69880168668686, 67.69296261572069, 67.28301217479091, 69.09717113740983, 64.82037167395315, 62.804544048924605, 58.16888301603256, 53.91989707946778, 49.60501140163791, 49.02524194409771, 50.788182597006525, 61.43848842190158, 62.54152167227961, 75.0273084640503, 26.160159610932876, 0.288834146434261, 0.20737313695492285, 0.23761183774519354, 21.576177766246182, 63.52161607434673, 59.60069717899446, 56.29795166753954, 34.43685293197632, 31.93317267202562, 23.737217418609127, 42.643110290650405, 5.814796599649615, 0.5683564635053758, 4.384037554264069, 26.898357522103097, 18.677018650116462, 3.965470401510116, 5.402183359669102, 7.2577257790873135, 28.549771462717366, 13.418444048973823, 1.9415609778896457, 0.12224359287609979, 0.044741840702631784, 0.07397054649528957, 1.329593641623374, 52.05926587504726, 75.21082047493228, 47.292923235124164, 25.321529411500503, 42.928058716558645, 55.14557500039378, 51.940147415284194, 83.9926778116534, 88.59602635906589, 4.091777340058358, 0.1483308325611776, 0.1810270668037476, 0.18202098927670912, 0.11697302287023877, 0.4236733432739012, 4.987321130691036, 0.697190756759336, 14.359605004710538, 59.66369436633203, 79.21519171807074, 83.2830818237797, 84.49808305309665, 80.20984203584733, 79.60368679415795, 74.7811169778147, 73.43504582681965, 75.02174654314595, 76.60584280567785, 73.91358283258253, 67.49411413746496, 63.37852408809047, 59.49001965984222, 57.83672494273032, 59.70969592371295, 59.25879593818419, 58.30093353025375, 59.116382521967736, 59.981512254284276, 62.35235360360915, 60.49065551450176, 59.00059415448097, 53.85497008600543, 56.23640183479556, 53.48117213095389, 51.35947189023418, 56.362062808006044, 57.2329701915864, 59.74411472197502, 63.58958290469263, 65.67381666552636, 67.81244585590979, 68.05984543215844, 68.53215371408771, 69.27017119623, 71.27998582778439, 68.946395227986, 66.88682140842562, 68.90418268019154, 73.84385878039946, 65.2441837710719, 64.21894288832142, 45.948130776805264, 52.92127340070663, 65.36189017757293, 59.56347388605918, 52.48007343661401, 56.858089662367306, 63.87518636641964, 63.42897753561697, 67.48124876329976, 64.56981458971578, 62.68448029795001, 64.12718296051025, 63.51345754438832, 64.48204763474004, 65.18126895350795, 61.864912817555094, 55.02957874728788, 46.96236156648206, 49.75936843502907, 58.56266936948223, 58.892799577405384, 54.14651593854351, 51.47993572296635, 47.96080481621527, 52.18675467275804, 52.45573120732462, 50.98218694809945, 53.24358632487636, 62.88946728552542, 61.957351315406065, 60.7845155654415, 58.004672988768554, 59.70455761878722, 63.023204418920706, 61.605424496435354, 55.838822549389256, 52.04004626120291, 61.85037651369649, 41.11226804794804, 47.99862823178692, 57.29273926827216, 58.09502086331768, 62.75509865053239, 58.88424881042973, 60.715497539889434, 58.37907891119681, 57.10012343622024, 56.06465693443052, 51.97344441567698, 52.31582810801845, 55.17534579000166, 53.98351400129257, 52.521505432744185, 50.121520873039, 50.96460688498713, 48.29270009071597, 48.30421616954189, 48.33771713318364, 52.48065002502934, 56.7983558870131, 60.80689268727457, 59.1349353328828, 59.4331217581226, 61.554378771012836, 59.111173614378906, 55.4406705979378, 56.14319455239081, 57.39811374295143, 56.38195314714986, 57.06332768163374, 55.74184194687874, 61.563898363421046, 66.8187447517149, 73.7693259023851, 74.70168113708496, 72.04858210779005, 72.83227951295915, 72.45118987175726, 70.7508659362793, 68.89673017686414, 67.59635463837655, 65.37153528582665, 59.59127956821073, 61.56415723985242, 62.15948281749603, 74.9949489101287, 72.1081550659672, 87.15675184803625, 35.37849633924423, 0.4311905963526618, 0.11756549994911879, 0.28302511620906096, 27.128418261005034, 74.58659095148887, 71.37887662456882, 69.08685530385664, 49.386056853878884, 40.42387247085571, 29.227776681223226, 62.45613951836864, 7.155375451810899, 0.514927959490207, 3.426568363943408, 31.892417284750174, 35.53262195279522, 6.249933069752109, 5.903048947934182, 10.319171490207797, 31.109306273921845, 20.392151494180005, 1.3572370357090429, 0.3506689025990425, 0.19981761012346516, 0.143551439827969, 2.392945621282824, 66.02182111432477, 82.42878175550892, 60.3009775377089, 28.56218380312766, 54.396417986962106, 63.83704131649387, 64.56111477267358, 90.6066882225775, 100.21380439881356, 6.276552725222803, 0.2737185268873169, 0.31810449676648267, 0.5755183437178212, 0.37564487046291756, 0.6601109367705161, 8.457502818876698, 14.869203259868009, 50.968568478861165, 86.60925957464403, 87.01651142489526, 92.91650925913166, 83.88635020102225, 88.01247181430941, 82.64833250353414, 79.01768469041394, 77.26465978930074, 81.56912372958276, 79.32956018755513, 79.08094467655306, 72.37258557350405, 67.37143024321526, 64.55511746868011, 59.61638273731355, 64.0594514723747, 63.899865919543856, 63.67943656060004, 63.056775985225556, 65.39725426704653, 66.07748739181027, 65.7037914183832, 62.41294637803109, 59.136512125692065, 59.8294262732229, 58.318235105083836, 55.09719648668843, 59.79459562609273, 60.39253350227111, 63.695326082168094, 66.54635183272823, 67.85207748413086, 68.25090408325195, 70.37969989161338, 71.83388725403817, 74.43181422448929, 72.57390514496835, 71.97251950540851, 67.11675074792677, 71.80086089718726, 75.56703444450133, 68.50386558040496, 63.65500411679668, 52.52306653607277, 58.88710821828535, 58.81394816983131, 62.40672157656763, 59.53655858193675, 64.0037420488173, 66.36152190546836, 66.79161763960316, 71.12939819212883, 68.66380414655133, 64.67083131113361, 65.23010246215328, 65.42273790605607, 65.72907893888413, 67.20367831568565, 64.38897763529133, 58.84207156396682, 47.85527344672911, 50.64998572872531, 62.48465907189154, 63.11458387682515, 57.72686327657392, 56.719422109665416, 50.691068633910156, 51.137395135818, 52.09430440779656, 55.43551660353138, 54.57612922114711, 65.69699787324475, 64.40156844354445, 60.93864510136267, 62.13273617529101, 63.666335844224506, 65.84242759212371, 64.57622374257734, 60.30287596487231, 56.121845091542895, 55.076384390554125, 44.99260610149753, 48.67186777053341, 59.27510515336068, 59.210033032201956, 63.957026620065015, 61.22326012580626, 64.6097364733296, 59.91061541341967, 60.562658463754964, 60.10642405479186, 55.63098792106875, 54.83258947249382, 57.57539702999977, 57.10151980000158, 54.69936616959111, 55.09820845819289, 54.1878890991211, 49.939299321943714, 51.24349917134931, 51.14988396244665, 56.83590081430251, 60.52465854152557, 64.72698396252048, 62.52115280397477, 65.93569371008104, 65.20732133619248, 65.33387660980225, 60.34421774648852, 60.26619788139098, 62.70693586718652, 61.157901671624955, 61.362959261863466, 59.49531093720467, 64.20265328499579, 68.9882626072053, 77.87330181367936, 78.71584261617353, 77.10266590118408, 76.09049827821794, 77.79781972208332, 75.7869460505824, 75.8198155126264, 73.19269041861259, 71.5727593821864, 68.65583389036118, 72.71260799900179, 74.31670050467216, 87.28823754095262, 81.66526102250623, 96.88574391026651, 41.29913368532735, 0.3372599430862935, 1.2768386208241986, 0.3400731405183193, 36.17425111032302, 84.56673237585252, 82.10177375424294, 82.5541877746582, 64.75540545678908, 57.83686222568635, 47.380439158408876, 84.12660321881695, 8.309464723833146, 0.5476106799417927, 4.8140268941079425, 40.750762801016535, 47.72135980667607, 9.950148040248502, 7.569374759351054, 11.90338836562249], [19.377934432798817, 8.299683313215933, 0.1639788219284627, 0.013035931192608851, 0.0336337075268309, 0.05345367000348145, 0.4673902426035174, 38.66620348345849, 61.28390781341061, 34.83999806065714, 25.272101663774063, 36.57004963967108, 40.93927191149804, 55.37145253150694, 82.26128870441069, 78.91794666167229, 9.638578487980752, 0.575326944310819, 0.6414584731382709, 0.09415464205366951, 0.291487415351214, 0.3510135195909008, 2.7202777083842986, 5.449580790535097, 9.293263804528022, 46.67216108691308, 75.65949255420317, 75.90951227372693, 76.5116588531002, 79.18692711860903, 75.71724553262034, 75.06413951996835, 69.01495825859809, 69.13480235684302, 64.19485169072306, 61.62622482545915, 61.04113663396528, 58.84818261669528, 57.69333485634097, 55.55073230497299, 55.415994967183764, 52.96288190349456, 55.35596309169647, 55.10662978695285, 51.65045684383762, 55.13504735885128, 53.61327363598732, 52.233564238394464, 51.012051874591464, 50.98063368951121, 49.74398097684307, 50.399134466725016, 52.03013443177747, 53.92109340237033, 59.70038813929404, 60.07800256052325, 61.583827926266586, 62.436464909584295, 66.87603489045175, 66.36014907590805, 65.90546008079284, 65.61629118457918, 67.12511324113416, 61.65983169309555, 59.563568022943315, 60.40144512730261, 64.73453060273202, 68.07707248195526, 65.95401117878576, 43.60929989045666, 40.630349959096606, 53.45037760273103, 54.427812637821326, 45.54194581124091, 53.87639799425679, 58.771406142942375, 59.296552673462905, 57.25388819171537, 56.58169592580488, 60.14902099486321, 56.26451346182055, 60.31918910241897, 63.17685542568084, 56.398144691221184, 46.273028542918546, 45.04790759855702, 48.176342979554214, 46.40707554355745, 47.240685109169256, 45.48063524307744, 44.96208221681657, 45.833150417574, 50.75706251205937, 51.199960862436605, 51.35964055215159, 48.43084596818494, 52.136128640943966, 61.16049435830886, 59.77487002649615, 57.02847742265271, 58.16356820444907, 55.14967387722385, 56.66097879409791, 52.22249530976819, 56.04198171246437, 47.85332010638329, 40.77803111845448, 50.458256352332334, 53.05595582531345, 62.55610504458028, 57.539605402177386, 57.77273539573916, 55.99679208570912, 54.011637395428075, 53.11992183808358, 54.530861146988414, 51.8440140447309, 53.15274423168552, 52.78322950486214, 53.31824864110639, 49.16772596297726, 46.338316394436745, 46.1393424003355, 43.83018424434047, 46.93260254398469, 46.916093287929414, 48.389959181508715, 54.06668001605619, 58.262309951166955, 55.19887216629521, 56.553372490790586, 53.01940325767764, 52.43675478043095, 50.203827888734885, 51.61538693212694, 52.21557232641405, 53.29398878159062, 53.847172414102864, 53.09140620693084, 58.89327026182606, 63.3053836514873, 68.93960168284755, 69.518261109629, 70.47397798107517, 69.90064513298773, 66.34223168896091, 63.134666412107414, 63.08866485472649, 56.93445820962229, 56.37492818217124, 50.93336128419446, 51.36783830581173, 52.125612766511985, 60.78747303255143, 59.305703563074914, 71.5153907960461, 43.71991072931598, 0.37794766947627073, 0.3529361244891921, 0.16982693795955953, 27.89373347836156, 69.41300038368472, 54.722767030039144, 60.089408812984345, 34.56150193368235, 29.5338882553962, 25.324192700847505, 38.99995796142086, 5.5295446803492885, 0.622439390468982, 5.96177859652427, 20.9409499168396, 24.576985105391472, 5.945139411957034, 3.369854323325619, 8.723236533903307, 19.775125403558057, 13.369342838564227, 0.36953642243339174, 0.021008634076063192, 0.025136685449509852, 0.06200462084023222, 1.2033590217751842, 49.64782014969857, 69.81629064006191, 47.58868563559748, 30.00866763053402, 37.271993083338586, 43.56990360444592, 63.238942623138435, 85.01282353555003, 88.80454740216656, 10.655667704920615, 0.27892158156441105, 0.36020047662238924, 0.05914806283169216, 0.18256845102915842, 0.2331892734453563, 4.510134400859956, 2.645905157250743, 21.92754956983751, 68.66268234868204, 83.747082525684, 81.31661722736975, 85.0360361222298, 80.69931460965066, 78.41978211556712, 73.94951174336096, 72.94969174169725, 71.26465720515098, 67.17435467627742, 64.27652720482119, 64.68358685893398, 62.18084012308429, 61.163585186004646, 58.38734726752005, 55.48506398354807, 57.030399384037146, 57.78898577536307, 55.30894171807074, 53.424909653202185, 58.30314574703094, 57.48035407835438, 54.32578002252887, 53.2225114299405, 54.98170229696459, 53.1225537484692, 56.352001928514056, 53.65722379376812, 58.800361079554406, 65.28696114017119, 63.21593399970763, 63.63140713784003, 66.3729360026698, 67.60619194276872, 67.63021253770398, 67.51499683626237, 67.3408906690536, 69.67051967497795, 66.56186088438957, 63.35336992817541, 59.38502957743984, 65.26157163804578, 68.73474413348784, 67.63836322292205, 50.65346487106816, 43.37602084682834, 58.31062962931972, 62.635423214204856, 48.75253523549726, 55.33328394736014, 62.18306018460182, 60.776451172367224, 60.77355254080988, 60.2155718495769, 63.36973405653431, 59.573530843181, 63.62561379709552, 62.62771183444608, 53.63051637526482, 45.777797929702274, 48.19740218500937, 48.02320580328665, 46.729090367594075, 47.73449974675333, 45.329722050697576, 47.0008792415742, 48.74887958649666, 50.774634730431345, 52.853463465167636, 57.04490430893437, 48.575714788129254, 50.88407278060914, 62.72659086412, 61.50912246396465, 57.44941050006498, 59.55037709205382, 55.51885128021241, 60.35135253783196, 53.01743422785113, 63.80193218108147, 54.32736466007849, 42.63531261874784, 51.99448400928129, 58.460644598930116, 66.42451517043575, 60.592358650699744, 60.930149247569425, 58.61332285788752, 58.64470966400639, 56.579707284127515, 58.285573528658965, 54.054171577576675, 56.23478974065473, 55.23767225203976, 53.88306210117956, 51.74160880427207, 49.77113554554601, 50.2854916357225, 47.350382035778416, 50.635237616877404, 48.70627872405514, 51.22037679918351, 55.420435090218824, 60.236862474872225, 56.427809576834406, 58.42625325725925, 55.86243914019678, 52.89506412321522, 51.45419320752544, 54.286976014414144, 55.03095157684819, 56.636185492238695, 55.5776083853937, 56.755688344278646, 61.978045740435206, 66.09185111138129, 72.52317320915961, 74.27895945887413, 75.11183554126372, 73.84286249837568, 71.738416764044, 70.77243897222704, 68.80269527435303, 63.15381934565883, 63.27897433311709, 60.25188123026202, 64.64275106307, 64.84190940856934, 72.57458763737833, 72.10189496317219, 82.53070062206638, 54.23861319018949, 0.8942521663923418, 0.2000024058525601, 0.19254395768286722, 33.575574967169, 82.07383078913536, 66.55327873845255, 74.95295601506388, 47.89334397162161, 41.57298964838828, 31.670328763223466, 58.572894988521455, 7.980623504807872, 0.3914032990653669, 4.1107248394720015, 32.78590575341256, 31.90304102436189, 6.011177416770689, 5.765493877472417, 7.596622974641862, 29.22099686438038, 14.833623440034929, 0.2653893431828868, 0.0858590053394437, 0.18524078021366752, 0.16185539474170055, 1.9648317872516572, 65.70253625992807, 84.25538247631442, 57.07213340267059, 37.48144372817009, 51.41096868822652, 53.615368181659335, 77.82106368772446, 89.834271554024, 99.1008161729382, 13.596156835556032, 0.5310375015101125, 1.0045343841756544, 0.2924159139154419, 0.30503292237558677, 1.2087973880191003, 4.866708247892318, 24.985874545189645, 64.88224314105126, 82.98091811518516, 88.41752713726413, 88.12335721908077, 83.47894145596413, 85.14678816641532, 82.26068465940415, 78.6813336033975, 75.7265180157077, 75.95977352511498, 71.45824186263546, 66.96752025235084, 71.3984021832866, 67.49818555770382, 65.1840969824022, 61.60370257592971, 61.043780311461425, 59.18720876016925, 61.74919505273143, 60.178780017360566, 54.74268090340399, 63.322846043494444, 60.49046331836332, 58.684545255476436, 56.09784018608832, 59.152664446061664, 56.06933239967593, 58.49145089426349, 56.016035233774495, 59.96264565375544, 66.33629322052002, 63.93199013125513, 65.50353088686543, 66.91549393438524, 70.36914087110951, 72.02409082843413, 71.77604013873686, 69.94412852871802, 72.04237691817745, 68.71013518302672, 68.41301564247378, 67.16249342887633, 67.09664467842349, 74.53394489903604, 67.7665933485954, 54.444090474036436, 49.62023412027667, 57.368029163729766, 61.28434711886991, 52.53732827401931, 59.10210901691068, 64.1187890883415, 63.236840232726074, 61.44749418381722, 63.74804665965419, 64.32785926326629, 62.086565955992675, 68.86449613878804, 64.23352233825192, 59.07603310000513, 48.55196091436571, 47.77873231518654, 47.79835593315863, 47.358407205150975, 48.249597164892386, 45.708230772326075, 47.76519621572187, 48.71220542538551, 55.92672678732104, 53.91036179757888, 56.02231887079055, 49.39809460793772, 51.310865879058845, 67.15387205923757, 63.21873064964049, 60.374051294019154, 63.2941617504243, 60.00277150061823, 62.16949270617578, 57.79703840132683, 60.00016704682381, 55.88203137920749, 46.360870022927564, 53.59014734145134, 60.75175200739215, 66.45627067935082, 62.11350087196597, 62.61503473404915, 61.64060815688103, 61.634265684312396, 60.460143396931315, 60.26673524610458, 57.695892241693315, 57.437396280227176, 59.64093285222208, 60.20409891682287, 57.211032375212646, 53.25159580476823, 54.499038957780414, 50.47461655832107, 53.34535614136727, 52.66497788890716, 56.39055882730792, 60.521759909968225, 65.93601534443518, 60.992491399088216, 61.24583336614794, 59.07715097550423, 56.83078996596798, 54.788427506723714, 56.674267784241714, 57.154734596129394, 60.98592535141976, 58.168141688069994, 60.517053065761445, 63.73251407377182, 72.07519146703905, 77.70032528908023, 78.80074624092349, 79.43867268100863, 80.8736639638101, 74.39891338348389, 74.51128928892075, 72.89098170495802, 69.57107190162905, 69.35838530140539, 70.21172046661377, 72.81423661016649, 74.13973885197794, 80.86831385089506, 81.22778338770713, 90.40952636349587, 62.11038258767898, 1.5248350102093913, 0.4841803771353537, 0.38619911057814477, 38.772891952145486, 93.17377751873386, 75.85305367746662, 89.2080416217927, 63.02863297923919, 57.25579446361911, 48.52790109572872, 83.72313253341183, 10.964302343706931, 0.7252550089070875, 8.990861811945516, 33.27594510970577, 55.913057327270515, 8.374037723387442, 6.54454670606121, 17.203937230571626], [10.282257083923588, 4.669938135531641, 0.026362188641102086, 0.08012123661296022, 0.14274081155177087, 0.1357375421831685, 2.1879257838572226, 37.59926780577629, 61.29416873378139, 32.86922474061289, 32.34464891495244, 45.54531512721893, 67.53900174171694, 56.78211335212954, 79.80509265776604, 83.64273963436004, 17.63985376204214, 0.2198613047479622, 0.33161335414455784, 0.042079574083008116, 0.018346890311447844, 0.4789662907921499, 7.492295282502329, 8.514340904451187, 15.67101711227048, 62.35326359348913, 77.56426611254292, 73.61219575328212, 81.25467515760853, 76.95098000188028, 76.98908190573417, 74.70732935013311, 72.2775230100078, 68.3081236193257, 65.78304290771484, 63.64363316566714, 60.46566217176376, 59.12887527096657, 52.851059052252005, 56.63092559383762, 53.79101976271599, 54.263261364352324, 51.34516308384558, 53.9258159360578, 52.66910029995827, 54.09763143908594, 52.191010444395005, 49.633044581259455, 50.952627966480875, 47.97400359184512, 47.76133268110214, 51.4064658072687, 53.032727549152995, 58.559970778803674, 59.86510022994011, 62.98921708137759, 64.4680683074459, 63.52242016023206, 64.04679398382864, 66.43636072835615, 63.41641418395504, 64.40244705446305, 65.66666618470224, 67.10856083900698, 68.4174479207685, 59.63710069656373, 62.895841137055434, 61.56216467580488, 64.66470456892445, 68.00893306732178, 49.46940329767043, 41.45138832830614, 47.11655386032597, 52.39820572637743, 56.121849013913064, 61.824728135139715, 62.11469327249835, 56.206156438396825, 60.360628943289484, 60.639811485044426, 54.86964018114152, 59.70277686272899, 53.82171623168453, 49.2317468889298, 47.77033844301778, 53.39158911858836, 53.06602062717561, 44.446518036627005, 39.41785512431976, 40.947355916423184, 47.31798325815509, 53.00157216287429, 46.753318848148474, 44.693454773195334, 47.09230576792071, 46.01666635082614, 43.855463920101045, 54.70549291180026, 59.880268035396455, 60.773866330423665, 58.834521001385106, 55.25057292753651, 53.28819544084611, 51.91227897520989, 50.008344804086995, 39.88049476377426, 51.68644851253879, 50.684243709810325, 57.338187771458784, 59.05114566126178, 57.68220709216211, 58.69006010793871, 56.11084284320955, 55.24250068972188, 53.44399982883085, 55.39446115493775, 57.232448516353486, 54.761790690883515, 55.017815559141106, 52.84617962375764, 49.56270471695931, 49.41396844002509, 49.19678288121378, 44.42653748296922, 45.835221429024976, 45.91351978240475, 45.97373208691997, 50.38880294369113, 55.12625340492495, 55.23093362008372, 52.91207544265255, 53.435947202867084, 54.570261355369325, 52.45660589587305, 48.5273519639046, 53.355507235373224, 53.45615525399485, 49.36964957944809, 52.087016644016394, 59.263361577064764, 65.5599541817942, 69.16631467880742, 68.62724765654534, 68.75842740458828, 67.93906780981249, 66.95919698284519, 64.07015954294513, 61.48373688420942, 57.63049064144012, 56.20293617248536, 52.491409086412006, 53.617721603762725, 55.794358561115885, 61.77219975379206, 64.85710859298706, 71.51379831375615, 62.43959888335198, 1.0359765324861774, 0.48862099046668706, 0.03111240874615408, 37.32493331355434, 72.49544205204134, 55.17564781250493, 59.43437691657775, 35.29348681049962, 21.43125991667471, 23.239792239281442, 45.66210369909964, 2.782635794531915, 0.1482847293898944, 6.733860883020586, 21.795114663339433, 20.123843723727813, 4.349899205469317, 5.228927366195187, 12.48899725175673, 16.8581332314399, 8.636116770005996, 0.10581876737095657, 0.0799327560009495, 0.10952297868507524, 0.2270189561550656, 3.217572959200029, 52.35913107472082, 70.60568332672119, 40.14062635360226, 37.762230519325506, 49.31388916507844, 67.18249751675513, 68.89534950256348, 82.77511919698408, 95.10421906748127, 18.715959941187215, 0.21957838847752542, 1.2139997991823381, 0.04403491391830387, 0.0349336936168613, 0.4626360541630176, 4.116499548958195, 1.115563016745352, 32.70903318159042, 78.32868899068525, 87.35269777236446, 80.86192038751419, 83.55581206660118, 81.63889485020792, 79.9597595584008, 76.43399592368834, 76.80438533906015, 69.6988784113238, 68.63631617638373, 65.53318792773833, 62.81824488793651, 60.75468986265121, 57.64185767019949, 59.88595939451649, 56.1633712245572, 56.168678191400346, 54.854511599386896, 56.81845411177605, 57.76496910279798, 56.66673683351087, 53.97299028212025, 54.02091772325578, 53.204998047121116, 51.95022398425687, 50.940041080597915, 53.929071503300825, 58.63152657785724, 63.32593687119023, 63.52574240776801, 66.20252470816335, 65.49301501243346, 68.05604857783165, 63.82711771995791, 69.75153230851697, 64.84355680404171, 66.98267629069667, 68.35341130533527, 67.63549989269626, 68.97950003224035, 67.08939613834505, 63.519431314160755, 64.83232705823838, 65.25821801154845, 69.50398368220176, 53.37634286572857, 45.80449358109505, 50.49499327136625, 58.21515913932555, 60.792105351724935, 64.64495543510684, 62.55413601475378, 58.95391794943041, 62.888820094446984, 62.58791154430759, 52.63504628212222, 59.332410981578214, 55.26262637107603, 54.1288064372155, 49.53729560298305, 55.687995649153194, 54.39316241971908, 43.61284963546261, 40.52986668002221, 40.73821906120547, 46.7402808896957, 56.14162168195171, 48.03820494682559, 46.086817941358014, 45.13044603409306, 46.43228069428475, 43.290650460027884, 55.39230385134297, 60.75885934214438, 64.15869528247465, 60.92448142267043, 57.693836919723026, 52.9918368401066, 56.803537338010734, 57.422836442147535, 44.35662515701787, 54.76299485852642, 51.45942564933531, 58.99608735115298, 59.19596349039386, 60.00972978530392, 60.82034641696561, 59.633527417336744, 59.67051144569152, 57.88218521302747, 59.347398358006636, 56.298716529723144, 57.37053948064005, 57.750781889884706, 53.76439863635648, 52.33931133824011, 53.12578185912102, 51.706797768992764, 47.58331983320175, 48.683980049625525, 48.68204632113057, 48.67266401167839, 52.70507235680857, 57.97869120874713, 59.02975697671214, 57.623469598831676, 56.2662628389174, 57.05025834421958, 53.94860098438879, 50.5553428588375, 54.92704014624319, 57.43340330739176, 52.92807086821526, 54.738468277838926, 63.28137090129238, 67.71416694887223, 71.60980224609375, 71.90283467692714, 73.45051565477925, 71.60227129536291, 73.34867523562524, 70.25477240162512, 66.90318553678452, 63.4267064832872, 62.831890813765995, 62.49405314845424, 63.583471851964156, 66.2118834833945, 71.25282733671128, 75.7409837169032, 80.03072307955834, 72.07208494986259, 2.6433362499360116, 0.21442586495991678, 0.03369245880974397, 40.90595137688422, 86.17463742533039, 64.73067491285263, 74.2834544950916, 47.6772919777901, 37.30700415949668, 32.755019049490656, 62.506137970955145, 4.951459880798094, 0.37661482970560756, 5.160393263063123, 28.67805846275822, 30.20575692576747, 5.426704056801335, 6.239921710183544, 11.568771946814753, 19.720680944381222, 7.1262243966902465, 0.1612731679192474, 0.11630879399637062, 0.2766509276003607, 0.34602328413917177, 4.835356252808725, 65.44620544679704, 82.70242983295073, 53.927200532728634, 44.445160896547385, 61.586491215613584, 82.1271671787385, 80.98426695792907, 86.84275827100201, 104.18904027631207, 22.881048340951246, 0.5196868976758373, 1.3990792872444278, 0.16770970076322558, 0.1439703213832071, 0.7073910642535456, 10.885559781905144, 44.52796997562532, 69.78654338467506, 86.99884506963915, 87.82106799464073, 82.32597643329252, 83.04824952156314, 87.30381719527706, 81.18812038052468, 81.42627100790702, 80.70917544826385, 73.16779905749907, 72.67343921046104, 70.80032702415221, 68.57618624164213, 64.52581344112274, 60.62616948158511, 64.65912695853942, 60.09261338941513, 58.619849681854255, 58.279866480058246, 58.375858645285334, 61.780028804656006, 59.263526316612, 57.72574147870464, 58.212123224812174, 57.190679196388494, 52.20950441975748, 53.157270646864376, 56.429719771108324, 63.58575074903427, 66.05481609221428, 66.38058462450581, 68.41955815592121, 68.45833470744472, 67.92551209849697, 68.53938656468546, 72.58915532019832, 67.02137439481675, 70.25629428125197, 71.07638343687981, 69.67047260653588, 70.97755539801814, 66.86622896502095, 65.79956000851047, 64.8238076702241, 70.1470092035109, 68.70428300672963, 55.047237257803644, 51.36760296360139, 55.32253665308799, 56.318112650225245, 59.455596939209975, 69.06561959174373, 65.7181433708437, 62.09663075785484, 63.630179435976096, 68.26817820149084, 56.206827163696296, 61.1556423864057, 58.94542209563717, 55.95379898625036, 48.722529103679044, 57.570058684195246, 54.68153899715793, 46.00296158944407, 39.875399604920425, 42.35487884090793, 49.88419786576302, 56.88401260683614, 49.119716152068115, 47.326510490909705, 47.169533314243445, 48.35663080215455, 43.53749305971208, 55.351064051351244, 64.81038139712426, 66.19108707674089, 65.6782607109316, 59.83678071729599, 59.23981951129053, 57.65708431120842, 56.65095321593746, 48.421393056069654, 56.65735452405868, 56.287074935051706, 61.99346457758258, 65.61684423877348, 62.63243829050372, 62.28124103238506, 63.54568766009424, 63.21758139518, 60.354211945687574, 63.403658636154674, 60.12714201404203, 60.071024663986705, 60.99542533197711, 57.978322505950935, 55.89113912274761, 56.529916717160134, 55.25053762620496, 49.26629512540756, 50.53397378613872, 52.54499650770619, 54.00167065282022, 57.016172947422156, 61.579713359955825, 64.08380154640444, 60.08964415519469, 60.16139215038669, 62.66204826293453, 57.33776415548017, 54.19751851789413, 58.48400623567643, 60.66764070141701, 57.11715044513826, 58.186200280343336, 66.94669246673584, 71.53748942959693, 75.68966342556861, 76.83416397340837, 74.51175212860107, 75.5178165435791, 77.20856989583662, 74.86348675143334, 69.66691893915977, 69.71981602330362, 68.58548225895052, 70.5798819757277, 70.18981795157157, 77.64376471119543, 78.15297465170585, 86.40068361836096, 86.40776741889216, 78.74778639885687, 3.53324604611243, 1.7146132525897797, 0.19302738980660517, 48.65777469450428, 94.97289026937177, 76.22577298072078, 86.62784376452046, 60.987537445560584, 48.44234243515999, 51.60003869764267, 91.24910185413977, 7.514990606615621, 0.5115067640379553, 10.208275298918448, 29.223709183354533, 44.84865119380336, 7.291121819326955, 8.09984443649169, 23.570795174567934], [5.769870752288449, 0.6114939552161002, 0.038534211099988995, 0.10351524823495459, 0.08109644355793154, 0.13530807329281686, 3.1638215338030173, 35.87338962862569, 56.534760844322946, 42.416875823851555, 26.064549876797585, 31.163640906733853, 54.77577001817765, 57.64019066287626, 79.21799229037377, 82.50522090542702, 23.44227675468691, 0.5152486132517938, 0.6954208485061123, 0.0826689615965851, 0.22779184694011367, 0.9542582400383489, 10.046185312732574, 14.769853545773415, 42.064321425653276, 70.7091397623862, 74.9419733785814, 76.17351916528519, 80.46865570929744, 76.13538588246992, 78.45380475444179, 72.7977155870007, 75.21424078172254, 68.6859655380249, 70.08094864506876, 63.39435477410594, 60.53888105577039, 55.03361878856536, 58.330551347424915, 55.25078081315564, 54.44738526498118, 52.238628018286924, 52.79169790206417, 52.33683632266138, 51.31698869889783, 55.14722239586615, 51.33734972246232, 52.40275959814749, 48.80731505732383, 47.54208003321002, 49.838317901857444, 50.55728050970262, 53.697145677381954, 59.1346372327497, 60.737690310324396, 63.80152033221338, 62.28308062399588, 65.29830463470952, 68.07459354400635, 69.2867785115396, 65.61825236966534, 62.13474442881923, 64.66567339435701, 60.180882407772934, 63.81325214139877, 71.22585711940643, 65.43978844919513, 58.52198654605497, 64.64309230927499, 59.15871666323755, 71.42007720085883, 64.46360072781964, 40.40078932239164, 43.29019938745807, 57.40672334547966, 58.75756802097444, 58.77577174094416, 56.475058447930124, 63.60676288604737, 52.34157454582953, 51.35398449436311, 52.4568530051939, 50.18698915358513, 49.12883174034857, 49.13169507057437, 56.31580237419375, 61.0142566311744, 40.192939004590436, 34.53589670119747, 31.333771751772975, 42.60665970463907, 62.75258441125194, 49.391524637899096, 44.826901651197865, 44.068617282375214, 45.80712941385085, 41.01341255249516, 50.851846587273386, 62.55907035643055, 60.272661947434955, 55.612313516678356, 58.41415666764783, 52.841233514970355, 59.01353797604961, 41.94370462048439, 43.26591991609143, 56.06378616825227, 52.2101673003166, 54.55984746256183, 57.24850277746878, 55.73085146565592, 57.524794532406716, 60.143051147460945, 60.19344575943486, 57.947163197302054, 54.59308954977221, 54.438638379496915, 57.76801286205169, 54.85049509233045, 57.03968363423502, 53.409314309397054, 50.23517547115203, 48.819670523366625, 46.038788518598004, 46.621154585192286, 44.98063895010179, 45.873605743531265, 50.526411456446496, 52.47116573395268, 54.988774330385276, 51.99664131287606, 52.385709055008434, 54.48205117256411, 52.69927901606406, 53.26951711408554, 50.60224656135806, 51.95069466867755, 49.00819140095865, 54.15830266091132, 58.01716966013755, 66.84665633786109, 67.73046047456803, 69.16904464844735, 68.24999409337198, 70.13995678194108, 66.28759307246055, 66.7941750249555, 60.7881437578509, 58.4698425569842, 57.24270943672427, 57.461110930288996, 58.86157358846357, 63.578266866745494, 64.09026169007825, 70.3932712924096, 65.0918742149107, 81.02347497017153, 10.396191150911394, 0.4587231528374457, 0.10809764145843445, 30.976243788196197, 81.43751252082087, 49.245549709566184, 60.74350718528994, 38.48847304621051, 18.894790603268532, 17.4681245511578, 40.074754068928385, 1.3460570549772632, 0.034530440255278544, 7.698433976019583, 19.422449411884433, 13.530450271021936, 5.935919880867005, 5.289817260157678, 13.120787143707277, 14.506357542930113, 2.868797519514638, 0.030391736429244764, 0.03465797474247313, 0.03342558442044162, 0.006905613746869588, 4.205948710441589, 50.25549334864463, 68.88343334197998, 50.6275458489695, 27.542928457260135, 42.51207174793367, 60.851635163830174, 68.49369095217797, 82.89532415328488, 88.87823304822369, 32.00529917593926, 0.5124644352303398, 0.999072912719942, 0.10322010520124629, 0.29274603652377285, 1.8801592146196675, 12.317155272729936, 13.258246606396092, 54.72213160607123, 84.09316109072778, 84.08828950697377, 80.61407366106587, 83.14506930689659, 79.10785213593515, 80.53210396920481, 78.07448017981746, 78.1966620106851, 71.66790823782645, 71.17171272154778, 65.97155201819636, 65.29783002791866, 56.89805076968286, 60.66434591047226, 57.464429255454775, 59.375372702075595, 54.54408345683929, 56.43534444993543, 55.25664083419308, 55.317920023395175, 57.818387862174745, 54.50849579226587, 52.92266584211781, 50.43729520613148, 50.995452404022224, 51.3278458195348, 53.75793064794233, 56.35694803730134, 62.074606649337284, 64.86558091255927, 66.92522141241258, 64.18681867661016, 66.39976501464844, 70.77057976876536, 69.81216430664062, 66.25581402932444, 62.78453211630545, 68.80032616276895, 64.1579931782138, 65.31303705707674, 69.50626650164205, 66.71338988888648, 61.03075804248933, 67.27417899716285, 63.77671526324365, 71.52642834571101, 67.49385526103359, 44.896264845325106, 44.56469512754872, 61.47687665877804, 63.684951413062315, 61.2706619693387, 61.94674522646012, 65.12824243114841, 54.2631789945787, 53.65707866607174, 54.95812885222897, 52.64112595588931, 50.72635035361014, 50.07720593483218, 57.43937315479402, 62.4717583963948, 40.21387269420009, 33.614692764897505, 31.448646207009595, 44.091296426711544, 63.666606487766394, 51.72568790374264, 48.0187499907709, 48.160229882886334, 49.58215575064383, 41.7215141173332, 50.63075042540028, 60.92048844983501, 63.792596940071356, 60.98034774103473, 60.94031603105607, 53.29717374617054, 62.33766432731383, 47.2378453131645, 48.44651583702334, 56.04220920993436, 55.929229259490974, 55.98726857093073, 58.66584339449483, 58.156158847193566, 58.07797816491897, 63.26193555708855, 60.89629919298234, 62.11353617329752, 57.79720314087407, 56.09527495599563, 62.695274660664225, 56.85918792601555, 60.263181578728464, 56.82840124253304, 53.80984321717293, 51.07318985846735, 49.27829757813485, 50.19537518101354, 47.32895804989723, 48.750374009532315, 51.77894192357218, 54.40806742637388, 57.9444214605516, 56.68740772431897, 54.9509548371838, 58.43150138854981, 54.96803675928424, 56.04932046705677, 53.76524194594353, 52.26142091135825, 52.744551012592936, 58.83159099086639, 61.87290660796627, 69.37319617117606, 70.66603291419246, 73.3697775871523, 71.19286214151691, 75.27419028743621, 71.48568276436099, 71.84112010463592, 66.0517252645185, 65.30882835388184, 65.86727972953551, 66.83535991176483, 67.28495767039638, 75.517973438386, 71.10617776070872, 80.17845522972846, 70.98247405021422, 87.9235673719837, 13.694112147054366, 0.6230596152524794, 0.04459027403725251, 35.75132154649304, 92.79072669244583, 59.97646024150234, 72.944427920926, 50.91448683892527, 28.217370202464444, 25.03464725709731, 57.64975732372653, 2.312657645633144, 0.058615467015413515, 8.208980464166212, 26.82200662551388, 29.205423093611195, 6.390192614447686, 6.397613248517437, 17.486579302818544, 15.026017658172117, 1.5217200354222329, 0.12299964504857218, 0.21375461872066223, 0.1632256196030686, 0.321651759647554, 6.336457613975772, 66.8177092459894, 80.38867073674356, 65.75288380345991, 34.51959533076133, 41.95384394737982, 67.46421783201157, 81.32953751471736, 88.23516045847248, 96.76693531774707, 39.08439874649048, 0.605605129272707, 2.7422226340539995, 0.20290356550005176, 0.4027069570316423, 4.232078069640744, 44.29385938952046, 60.10859704786732, 80.78307290231028, 83.70781175551876, 86.7349950728878, 80.7824767020441, 86.1264471853933, 83.1912277590844, 84.57561262192266, 81.26959585374402, 79.40862732548868, 76.34068273728894, 75.225678413145, 69.47815095224689, 68.79143022721814, 59.32104787518902, 63.627061151689105, 60.63344547825476, 62.59163387360112, 59.60022649457378, 59.5426304109635, 59.77123398934642, 59.44439857236801, 62.531197993986076, 61.71059893023584, 58.02458293976323, 54.26134332533806, 52.85489513028053, 54.62759464017807, 55.80649045205886, 59.36866152671076, 64.36931871598767, 66.50492375896823, 67.40167956198415, 68.33190102731028, 69.19546573392807, 72.35150675619803, 74.18765452600296, 70.738157456921, 67.1059799194336, 71.66457422317998, 66.47774173367408, 67.80617006363408, 72.2235276622157, 68.67259810047766, 63.69763635819959, 69.50045354904668, 65.94741375215592, 73.83109538785874, 67.0145102470152, 50.026901537372225, 52.37536184249386, 60.55153854431645, 63.89611613365912, 64.50038079292544, 62.34979229588663, 68.67365714042418, 57.806126533016084, 54.38193267391574, 60.07295054774131, 55.54120879019461, 54.360457697222316, 55.60364507859754, 58.4875952043841, 65.29712792365783, 40.096382018058534, 36.33546836914555, 31.101128132112567, 41.55950846210603, 65.44991208660987, 55.22836446762086, 48.32898201480989, 48.64831001527848, 48.66560766773839, 43.011671881521906, 51.22819016056677, 63.35058896772323, 66.32951536486226, 59.2962271167386, 66.52985434378347, 55.92540887094314, 62.02921305933307, 52.06511412897418, 51.96401111541256, 58.97332191467286, 56.3753164968183, 56.6051556218055, 63.76633274939753, 60.55696318226477, 61.378503614856356, 66.53672633632537, 66.31413182904645, 65.46354232295867, 58.5838697802636, 59.08417986285303, 66.18643514571652, 61.02230533476799, 63.03836437963671, 61.073555023439475, 57.61893926128265, 55.10406063448999, 50.671119459213756, 52.52661235870854, 50.308159012948316, 51.37445142192226, 55.98326775335497, 58.09550331484888, 61.42057103495444, 60.13106830658452, 59.41909144001623, 62.17189711909141, 58.49821306044056, 60.05285232297836, 57.21659037374682, 56.67815877545265, 58.01674604415894, 61.13951360025714, 67.55240840296592, 72.27487933251166, 73.2239281746649, 75.55027023438485, 74.304564691359, 77.93586361792781, 72.3752841641826, 76.68154455000355, 70.0449255974062, 70.45873565058555, 71.47584545996882, 74.98455462917205, 73.90966830715057, 83.71673907003095, 78.33523150413268, 86.00876039074313, 74.49388181009601, 90.00447104054113, 14.33849382785059, 1.2303224975062956, 0.362296064173983, 38.79962682723999, 99.7047435083697, 71.08294163980793, 85.79331244191816, 65.52484112401163, 42.24062804252871, 37.16285705566406, 86.91243525474303, 4.8658041415676, 0.14001142413866136, 10.160718521764203, 29.44448174968843, 37.82936972956504, 15.699704347118256, 12.658682907781294, 29.053792107489805], [4.69754328650813, 0.04488049495604731, 0.05546734360377154, 0.05959785986511458, 0.1904545907652186, 0.05475477075144168, 4.832808183085534, 43.29235669105284, 56.69684886932374, 33.069977529587284, 33.78514720547584, 37.451363071318596, 63.044848057531546, 60.82647315917477, 78.62092125800349, 78.41418097096106, 45.422945022583015, 0.788353503711762, 0.45962039501436297, 0.14925571519040293, 0.08868367110769595, 0.44969073106204316, 13.661156392866566, 22.77369503052004, 57.293888522732644, 73.00999426072644, 73.44493804439422, 76.11527981296663, 76.76877806263586, 75.12805846429642, 76.43416066323557, 72.06024723668253, 72.7616297814154, 71.56569127113589, 68.84180914971137, 64.70022947557511, 62.158376709107436, 58.02145288836572, 55.615988777529815, 54.46150187523135, 53.33096104283487, 53.333577263739805, 51.930823941384595, 51.96048490462765, 51.99315824816304, 52.816703011912686, 50.0044342010252, 50.52232042435677, 48.68748664855958, 45.24585393167312, 50.52812945458197, 52.861896561038115, 54.23163921602311, 61.66702924236175, 63.12814743288102, 65.24050458785027, 65.86673059771138, 63.375758817118985, 62.02000333416847, 64.18708932015204, 61.94423883192001, 60.793368354920425, 60.86498298952657, 62.31035678617416, 61.06976993622319, 63.360477262927645, 59.92380634430916, 58.53082756842337, 60.69357541299636, 66.60579143031951, 62.4841413190288, 63.294856009944795, 53.2756438562947, 44.49040543648505, 48.48254280705606, 50.51471102622248, 61.86958828280049, 61.81813855325023, 61.48509010191887, 53.74781093289776, 48.1858939509238, 49.80768026844148, 51.53579027422013, 45.962714149105935, 47.285878658294685, 55.52520944226173, 61.761848618907315, 57.1816106765501, 36.317386242651175, 35.59868643360753, 57.98691249662831, 60.796274831218106, 49.748213214258996, 41.835211861518125, 47.76209362091557, 52.35808380188481, 46.4565444761707, 46.63421215549592, 49.41075601885396, 54.4415173992034, 63.51429693160519, 53.580906237325365, 59.591683572338475, 52.00296809596401, 32.92455565544867, 51.37133706000544, 55.33635908557523, 56.19429126862557, 53.425890245745265, 56.17906070524647, 57.120292263646284, 58.34975919415874, 58.548843014624815, 57.15427567881923, 56.81889341723535, 58.71724213323286, 60.82745767408802, 61.406885885423236, 58.69244883137365, 54.72464976772186, 53.30518322606241, 53.38140664562103, 48.87567804705713, 50.849673594197924, 47.29695935403147, 47.72969092092207, 46.2801907908532, 47.50257392083445, 50.750621980236424, 53.10704077443769, 51.510188964105424, 54.143778124163234, 56.3169280944332, 53.1226674972042, 55.17116454339797, 51.35364717052829, 50.122034703531575, 49.342412640971524, 52.785127932025546, 61.82603820677727, 66.29408851746591, 68.2289231208063, 70.43137319626348, 68.15354301083472, 67.26038794363699, 64.8497659160245, 64.26373243331909, 61.68104387098744, 59.86320964751705, 59.37492555187595, 62.84831770004765, 62.96081912133002, 68.19173905157274, 68.10350925691667, 73.80894184112549, 70.71448987530124, 88.49002822752922, 39.0213466459705, 0.1867415004920575, 0.10007673153473486, 34.95156595783849, 79.83491051581599, 51.726421386964866, 55.3144879494944, 37.814931484960745, 21.21151108895579, 22.314634553847775, 42.38678339988955, 1.1268675327301025, 0.3591444090970101, 6.2279658356020535, 15.939337630425731, 16.449900788645593, 9.391023978110283, 6.212088571440789, 11.892252756703286, 6.451845409408693, 0.4299748761038627, 0.023994553691497254, 0.06477211346669544, 0.2407529667740868, 0.14444881990071268, 8.709844581542477, 58.89439205969534, 68.31088496792701, 42.13250790872882, 34.28034643973074, 35.93835192341959, 69.5129188414543, 67.62337976886381, 84.25621401879096, 85.29484195093956, 49.720489901881066, 0.8048668659983144, 0.38823871242423214, 0.330863660501857, 0.07820272262418464, 0.8255949376090881, 14.75722743618873, 35.66247593971991, 74.00028290287142, 83.74943594778739, 79.78078180743803, 79.86731713817966, 81.29996284361809, 79.73103046417236, 79.80932881755214, 77.29847846492645, 75.91290120155581, 74.59212933817219, 70.87638962653376, 67.9058139554916, 64.59307816720778, 63.280574660147394, 57.162614637805575, 57.21311123140397, 55.6836025945602, 54.9892097134744, 57.169514086938676, 54.487467965772076, 54.19163496263566, 54.713522003543, 54.13533718355241, 52.73398806971889, 52.06487486439367, 50.07439359541863, 53.75244325207126, 55.07199133596113, 59.32421322791808, 65.14690899079847, 66.40885706870787, 67.39527825386294, 65.97070478623914, 66.6134165179345, 65.803396086539, 65.63817408777052, 64.88634594025152, 64.92501658778038, 66.2986384668658, 64.76092423162153, 67.73271975978729, 64.42385142849338, 62.48601228960099, 60.06225032191123, 60.71330885733328, 67.08082183714836, 63.79924143514326, 65.41698378901329, 56.61893883059102, 47.87209649239817, 48.94575903492589, 53.84792158680578, 62.06334944694274, 65.77746529732981, 60.95308334596696, 54.12250318834859, 52.698698505278564, 52.14188668035692, 50.98567393518264, 49.35058293804046, 48.066877472785215, 55.82129347708918, 63.544981633463216, 61.043482211328325, 37.02387179097822, 38.435830916127856, 61.32794034096503, 63.39013430380053, 52.20074968953287, 44.46980907071022, 50.066623380107266, 53.895860795051824, 49.464214001932454, 47.20424629026844, 49.7723279460784, 54.89952079711422, 67.60085751933437, 59.189711232339185, 61.59345342266945, 57.83100612701909, 36.39616312519197, 52.34714823384439, 59.39780473709107, 59.354819482372655, 53.65064205661897, 58.512298291729344, 57.50994443893433, 58.580021935124556, 58.98168440788024, 61.29606716094479, 60.552899606766246, 61.08623604620657, 65.05348597803425, 61.77347844646823, 61.441296838944965, 58.27073520229709, 56.50467626510128, 57.52006807634908, 54.32821973677605, 53.57709761588804, 50.332783652890114, 49.80072982849614, 50.095362586359826, 49.77132381931428, 52.49795944459977, 55.95647796507805, 54.70165291140157, 55.76666270532916, 60.14210193387924, 57.492933119496996, 56.312750770199685, 54.464325981755415, 53.36335589808803, 53.351851586372625, 56.68806668250792, 64.39383352956465, 70.13801913107596, 69.48172815384405, 74.86038023425688, 71.92394487319454, 73.10930867348948, 69.63507713810091, 69.76363674286874, 66.78240006969821, 66.75899920925018, 66.6411162960914, 71.91169138877623, 70.86284175995858, 80.10242400630828, 76.59926891326904, 83.53369774356966, 77.77851381609517, 93.31262942283385, 43.87409910078972, 0.11533826018773741, 0.07517437705950392, 39.349437221404045, 90.08470704478603, 63.90034052633471, 67.39886330020043, 51.94737634351177, 26.83550350127682, 29.084355215872492, 54.87965399219144, 1.7583726851209518, 0.22886372652024994, 6.7864495708096415, 24.540826735957978, 20.188772678375244, 11.122343463282432, 10.057457224015268, 16.23935874431364, 6.797493494326069, 0.2336794624645864, 0.22789836380510564, 0.37156860854837204, 0.438277185443909, 0.3154002063937726, 13.539439362864341, 78.41204720158731, 80.91145992279053, 52.83060781417355, 44.56032952954693, 49.49619700831752, 81.37031447502875, 75.84308301248859, 89.05415919519241, 88.57497892072125, 69.8105953585717, 1.3361002408689069, 1.6257156744118662, 0.6169592264679171, 0.257544357690119, 10.675235429117757, 66.03315676412275, 65.18037857547884, 81.86082255455756, 86.96235133755593, 80.73202717688777, 81.11582325350854, 84.74065811403337, 83.22385403417772, 83.43326937767768, 79.94613324442219, 77.28238105773926, 78.50004165403305, 76.34193789574408, 71.22278198119133, 67.39694918355634, 67.69224874434933, 62.29210992013255, 62.701605366122344, 59.02471673104071, 60.81731050245224, 60.340691535703606, 57.403561915120775, 57.89658815630021, 59.47766027142925, 57.44061654613864, 58.37252855300904, 55.73977485779793, 52.17853730724704, 57.90473491914811, 58.19934414279077, 61.04270165966403, 66.05263525439848, 69.97191459901872, 68.02328109741211, 69.86043299398115, 65.32161920301377, 66.7704995985954, 68.56376801767658, 66.7791288129745, 66.84286732827464, 67.88255430036976, 66.40043181757774, 68.87103865223547, 66.6032418897075, 66.02613572151431, 62.40871414061516, 65.1288111748234, 70.65815679488644, 67.4030210125831, 68.70066658143075, 59.221141184529955, 49.90779876708985, 49.56039051855765, 54.44725190439532, 66.98247232744771, 67.6507108442245, 65.63438507818407, 53.43995978755336, 54.92826000336678, 55.438972211653194, 54.71453789741763, 51.58380792986963, 50.605925744579686, 57.76354136005525, 66.59723281860352, 61.37290247025029, 36.34190497859832, 37.51708238355575, 62.79696210738152, 69.66573438336773, 53.37658213030908, 48.030811279050766, 51.33413730129119, 58.754222239217455, 48.49496103102162, 49.7073656512845, 53.353797081978094, 58.690919107006444, 69.15660289026076, 62.02913068955945, 58.24530647646997, 58.55121997094924, 42.78403320620137, 53.47313519447081, 63.877457418749415, 60.67854489049604, 56.47845129812918, 63.39177777690273, 61.06343923076507, 61.725531393481845, 64.45974503794025, 65.18163373393398, 63.44643600525395, 63.39510394680885, 67.96519863990046, 64.44930368854155, 63.533696974477465, 62.19435661069809, 58.99266312199255, 60.01587221699377, 54.697095117261334, 56.09287054308, 54.35775518417359, 52.913707148644235, 53.1545602890753, 53.39120472631147, 57.35071189941899, 58.54902736602291, 59.271610321537146, 58.62276400289228, 63.69128604089061, 62.804222414570475, 58.58728616468368, 56.99031668324625, 57.10556768601941, 53.288850476664884, 58.62390541261243, 67.17657473779494, 74.29278189136137, 73.60861070694463, 79.34163324294552, 75.75894032755207, 73.98456204322078, 71.83012962341309, 71.95774785933956, 70.93183625128962, 68.08310508728027, 71.93519423084875, 78.04826305758569, 75.55237262479721, 84.80371413692352, 80.58697792791551, 88.21951804622528, 81.93450035587435, 94.79718377513271, 45.19146242449361, 0.23894282358307994, 0.2861969040766839, 44.78529707078011, 97.65808997615692, 73.33458608196628, 81.69032496790733, 65.51847903959214, 47.94322867547312, 45.19483174047163, 82.96226332264563, 3.8655274289269603, 0.788787844921312, 8.51562842246025, 24.366946105034124, 29.017278763555712, 25.514884610329908, 22.171399401080226, 25.242254387947824], [1.017329584686987, 0.08174427048934084, 0.09443672328826883, 0.04012831749634878, 0.04159724512588113, 0.08228582570389395, 9.752667488590363, 47.21952784445978, 60.70243212484545, 29.590358618767034, 25.731736767676573, 56.62553625722086, 50.161509436945764, 64.46081584499728, 80.64703725999402, 75.12203370371174, 72.87769271481422, 6.789660521091954, 0.7448010987812473, 0.3553624168759392, 0.25847610446714586, 7.186960337623474, 20.491420799686065, 23.654122006508615, 58.306573898561545, 69.96284607918032, 74.40962929879466, 74.04640213135751, 70.5238313059653, 74.30329384342318, 72.74058234307074, 72.05317128089168, 72.10282848727319, 70.14762893799814, 69.96898066612982, 67.65001266233384, 66.19181663759294, 59.57382502094392, 58.32634264423002, 53.18680217189174, 51.43875868089738, 51.61809336754584, 50.6276164516326, 49.29523829490908, 48.77246087597263, 51.806986870304236, 51.13162925166469, 50.74605241898568, 47.79311956897859, 47.91621923446656, 49.50146475145894, 49.91714577521048, 61.251583560820556, 66.42294622236683, 60.09930103055893, 64.67197664322393, 64.27767645928168, 65.31545323710289, 64.13241540232013, 62.93188771893902, 61.896040747242594, 62.335467800017334, 60.72462097291024, 58.54768199305381, 61.329372006077925, 62.67034799821916, 58.57548767520536, 55.35671618676955, 59.10738852716262, 60.666165890232215, 62.7394130922133, 62.00665943084225, 52.30292351015153, 43.949969507032826, 52.111547147074056, 53.47660649207331, 58.06242204481556, 62.297832658213956, 59.56977713492609, 47.10283340946321, 50.40366088190387, 48.04293924762357, 46.349746181118874, 44.93121708593061, 44.14460143735332, 52.230300826411096, 60.44403030026344, 63.79727240531676, 54.51187295298423, 54.33891604023596, 62.53854067094865, 57.47647093188379, 51.435412899140395, 43.30115848971952, 43.338122906223425, 45.4608468855581, 47.41830179768224, 48.324102586315526, 42.114029622847035, 44.25789125504033, 54.84417615398284, 52.88477574625323, 62.800802107780214, 43.38233586280577, 41.76451113916213, 48.84326750232328, 51.31938134470294, 52.7378829833, 50.75078671978366, 55.291247906223425, 51.76572353609147, 55.53670198686662, 56.65304383923931, 58.926135801499896, 60.397173666184955, 59.243428091849054, 58.77653268075759, 57.821721876821215, 55.77199320639334, 56.72787089501658, 57.38592301645587, 56.61329846228323, 54.25848783985261, 54.80227347343199, 47.79064455339986, 48.69002049969089, 45.489389973302046, 48.979805208021595, 48.133236131360455, 49.08046891612392, 51.7046247759173, 53.36813334495791, 54.343556204149806, 56.55753412554341, 54.22794434332079, 51.39178045334355, 51.41770732018256, 51.63766207233552, 55.824576500923406, 63.7018999745769, 65.62829755967664, 71.69882435952464, 67.18000288932555, 69.10547087269445, 67.50780320936634, 65.9843546344388, 63.0083857044097, 62.429726277628255, 59.839314568427305, 61.29723210488597, 65.70838059148481, 67.97432207292127, 70.78099758394303, 72.81833156462639, 74.74553323561146, 75.26836164536016, 82.82084618845295, 70.60333774935815, 1.469757578546001, 0.1890280737631744, 34.64023174778108, 75.3288681276383, 57.91869071222121, 53.3150597541563, 38.4124182885693, 26.640279293060306, 19.891302085691883, 42.540654059379335, 1.5272215273111098, 0.6485723043161055, 4.252213556920329, 12.193914401915766, 7.410132413910282, 18.298990418834073, 7.916464315306756, 9.146719151927579, 2.7636544646755343, 0.07481098325262148, 0.047233319510855985, 0.10656623169779779, 0.2124797564841086, 0.16077654376145334, 16.5983703444081, 64.14827746729698, 71.5659579923076, 41.93642862381474, 29.299144206508515, 50.5380569734881, 58.92584946847732, 70.38312804314398, 88.36457513993787, 80.56764848770635, 87.11399801315801, 7.615469473023569, 0.7437355011220902, 0.4574692507665004, 0.27486361382949737, 7.7583604378084985, 35.55950587795627, 46.57610224139306, 75.4121635806176, 81.87619824563303, 81.01808563355478, 78.9768998853622, 76.17426441561791, 79.65182996565296, 76.73181364613195, 78.55107953471523, 76.29363782944219, 72.07769393920898, 72.53886268984887, 71.91954397386121, 67.96565363484045, 63.75398905046525, 60.97864543237994, 57.502417410573656, 54.483741714108376, 55.47504232775781, 54.10377387077578, 52.878441118424945, 53.952680249367994, 52.98324292705905, 54.772612510188935, 53.66800638937182, 51.00382666434012, 51.35947581260435, 51.56697703946022, 54.664233499957675, 64.3486007567375, 68.70855839021745, 63.038360457266535, 67.73670488788237, 66.86330287687241, 64.93879979656589, 65.93809420062651, 68.0673606934086, 66.24799282320085, 65.753181903593, 63.79673896297332, 62.54715419584706, 63.04432638229863, 63.7984844177, 61.08965243062666, 60.51616268773233, 60.40354751771497, 61.368238772115404, 65.37184907544044, 65.24178328052645, 57.99918167052731, 46.16311980832008, 53.28492810649257, 57.46765736610659, 62.446929793204035, 65.11896602569088, 59.74764877750028, 50.02477561273883, 51.42328100819742, 50.97117685502576, 48.01105037812264, 47.6391508502345, 48.994137548631244, 53.96041908571797, 62.227088789786066, 62.85356583133821, 59.41005037676904, 57.66026535341817, 64.34707887711065, 58.48910923927062, 53.47561021004954, 46.0047423455023, 47.075686685500614, 47.21206749639204, 49.299192044042776, 49.379635933906805, 45.285830728469364, 45.68670088245023, 56.337708811606134, 52.4689378276948, 67.38481337024321, 45.84372512755856, 48.78159215373378, 51.36654784602504, 53.92955787720219, 55.246305388789025, 54.454700485352554, 59.751704508258456, 53.42669040926042, 58.593569801699736, 58.89275643133349, 60.5154017479189, 62.11403039193923, 60.66153749342888, 59.62059144050845, 60.0458626593313, 59.39834602417485, 60.6438672158026, 60.33634947192285, 60.38200978309878, 59.34611182059012, 55.92917826867873, 50.72436563430294, 51.29959690955378, 50.15564157116798, 49.49687165598716, 50.12617672643354, 52.0063413343122, 53.16591555072416, 55.320983394499756, 57.77587721424719, 58.71517504415205, 55.33942637904998, 56.069038221913004, 53.46428240499189, 53.47886577729256, 58.61069486987207, 66.54473581621724, 70.02765147916733, 75.25176217479091, 71.38607025146484, 72.60690012285787, 73.32800434481713, 70.59313174216979, 69.98277956439604, 68.0802417570545, 67.42004409913095, 68.20338849098452, 72.44227040198543, 77.90570843604304, 78.90789754929082, 78.84664581667992, 81.91413540993968, 81.89233487652194, 87.14003470636185, 77.58746300974201, 2.1530983236528214, 0.3489750515549414, 40.37324251667146, 84.32960940945534, 68.8416757891255, 66.03895402723744, 52.93285223745531, 34.69758072207051, 25.07738148012469, 54.19725179672242, 3.5323541971944996, 0.7466287394204448, 5.91433507780875, 19.778430000428234, 17.44636324144179, 12.575952276106804, 9.116010915848518, 11.868512611235342, 1.7119687170751634, 0.1789894414645049, 0.19078480530410044, 0.2742080877144491, 0.3037828813877798, 0.41571755082376544, 23.653268890996134, 82.03956496331, 82.16962291348366, 49.02322584582914, 37.82122688908731, 71.6966905901509, 70.49107167028612, 76.48468079105501, 95.40132291855352, 83.4507788381269, 99.46671839683287, 8.85499483154666, 1.2947496339198084, 0.8621169230149639, 0.530717521905899, 24.05432143519002, 65.07098367137294, 68.35578826165968, 82.76781574372323, 82.63152906971594, 81.81848449091758, 81.31107884068643, 78.34156220959079, 82.26845879708567, 79.89518165588379, 78.67632081431728, 78.43690718373945, 75.93366622924805, 75.84786045935847, 75.61087085354713, 71.94919709236392, 66.95525892319219, 63.3128361548147, 61.36162957837505, 57.190267347520404, 60.039865355337824, 58.0315294573384, 56.75241316518476, 56.048324185033, 58.09906090459516, 58.17243276103851, 57.7024269104004, 53.001866340637214, 54.18033069179904, 55.50679783667288, 57.529034614562995, 65.08043266111805, 72.47364151862361, 65.50550776143228, 69.72016903661913, 70.70262078315982, 69.85472202301025, 69.6860836398217, 68.7363915289602, 69.51888868885656, 66.94414292612385, 65.80873443234351, 64.00889212085356, 65.45880017742034, 65.61018013185071, 63.19350196469215, 62.604514937247004, 64.73109852883124, 65.96427209915655, 67.66337225514074, 65.63703267805039, 63.56384823399206, 48.612938081064534, 53.049095599882065, 57.94210726214994, 63.81602917948077, 67.85210886309224, 60.291991387644124, 52.91376990656699, 54.748866481165734, 53.94325479384392, 53.919838243915194, 48.23707303693218, 50.34413106979863, 56.49799646869783, 65.1299290503225, 66.29119380827873, 58.457879327958636, 58.77136299687048, 66.66503490940218, 61.46401520698302, 55.84725172288957, 48.53770309878934, 49.239222926478234, 50.27529347327448, 52.77467481551632, 53.22369598573255, 47.40936271605953, 46.299751650902536, 58.15755521097491, 53.952515509820756, 60.94976894317135, 50.02257908544233, 52.98567087419572, 53.00811467632171, 55.45812906757478, 57.02777531839187, 56.27336232892929, 60.47134568614345, 56.39066473130257, 63.363897569717906, 63.36219526106312, 64.56413892007643, 66.73078167823054, 60.65913308051325, 63.30314790048907, 64.42087827190277, 62.44099916950349, 63.57642335276451, 62.9038937630192, 62.932334869138664, 61.431526214845725, 58.97187456007927, 54.2285523106975, 55.34559234496086, 53.33985697838568, 53.85094181183846, 53.24533570197321, 54.98279663824267, 56.00790023803712, 59.84599044246059, 60.33218391479985, 63.353683717789195, 59.65202531506939, 60.27530954730127, 57.08186088069793, 59.0408141382279, 63.13437223434449, 70.6765527109946, 72.28703868004584, 77.76230658254316, 74.11086236276935, 75.62998064102666, 75.74692218534409, 73.86067790369835, 72.46955440890405, 70.49436646123087, 71.4691460517145, 71.97970528756419, 74.58845799969089, 81.57896103397493, 83.69916685165899, 84.73916761336788, 84.96994418482628, 85.39292473946848, 90.14090676461497, 79.42092787834906, 1.9630114397694989, 0.4181886133888076, 43.59046074651903, 94.30731896431216, 76.26116844915575, 83.61266289987873, 65.60980750668433, 58.55882544671336, 42.750077247619636, 85.23380202631797, 5.396066913681646, 1.124884529459861, 6.061809822436302, 19.631864755384385, 17.814132513538485, 31.017024670877767, 21.250109172636463, 14.698169289096711], [0.03150877880773718, 0.10894432949322848, 0.03177250266045092, 0.07183685373034208, 0.08134396656626657, 0.1214924666489805, 8.855598876553199, 58.36672344515401, 62.93268003771382, 28.238203871634703, 30.952089832675075, 47.21447190930767, 53.905686332333474, 63.64858711919477, 76.1136402622346, 75.92953205108643, 47.245250748049834, 1.9843041488239843, 0.44134070976607265, 0.2972792239198762, 0.34751838133219753, 19.280192890474876, 24.491196986167665, 31.721682394704512, 59.774399342075476, 72.58017309250371, 72.91230370921474, 76.7770621084398, 72.23672251547538, 72.57221852579426, 71.23814198278612, 70.91041226540843, 72.89281737419867, 74.14384949591853, 70.37038034008395, 69.88834458012735, 67.96173910940847, 63.70143321252639, 57.4019851223115, 51.054444851413855, 52.14475001058271, 50.46464981571321, 49.74833088536417, 49.03217277219219, 50.1360728663783, 48.23889693906231, 49.176394401058076, 50.66543986720424, 45.96150998146304, 46.450598162989465, 47.926158520483206, 51.02126159975606, 63.766638694270966, 64.19083910603678, 62.5365637963818, 62.46068554539835, 63.639259722925004, 65.38960564521052, 62.11212412003548, 60.07002053722259, 60.716925282632154, 60.08207005839194, 58.68454133310626, 60.62948388438071, 57.61262032293505, 58.4912508533847, 54.74971371312296, 55.108598816779356, 57.62625840402419, 58.52125306283274, 60.31943621173982, 61.33520457052416, 57.52731661642752, 49.83820415312245, 47.957933641249134, 65.53691417940202, 62.13178303933913, 61.34111166000367, 53.218902849381976, 46.23253007088938, 47.831366600528845, 45.86035205471901, 45.614121344781694, 43.22093425258514, 43.66576240908715, 48.78198439075101, 55.52648813493791, 52.91250298100134, 57.72825179561492, 56.251667699506214, 55.59166223772111, 53.90967930516889, 49.90391169824908, 42.52057544646725, 43.57765420790642, 46.00651133445002, 43.476060898073264, 48.428257203871205, 47.348899379853286, 48.71132681446691, 48.96237419497583, 51.06547455633841, 47.938992515687026, 35.46032874814926, 58.21038169245566, 59.08900437816497, 55.71755070840159, 53.22625729345506, 56.645740385978456, 59.48863114080122, 60.32337427139283, 59.88922672887003, 60.362747023182536, 54.52844888933244, 52.42486215406849, 53.003686320397165, 54.52719373087729, 56.847342368095156, 58.24925238086332, 57.204831107970215, 57.84734672115695, 58.64380751886676, 59.77386982210221, 57.719226421848425, 50.30156943105882, 46.84801270884853, 47.37090779889015, 49.636398207756784, 47.635114731327185, 50.62690258026124, 51.372733423786784, 53.56487551043111, 53.88965168306905, 54.98893906993251, 53.94579256734541, 52.64554254470333, 50.38648874528947, 50.08530170686784, 55.01688595741026, 64.750259307123, 63.6694815851027, 67.67939905966482, 67.51658931855233, 66.7111776721093, 64.60925009942824, 65.69964155074089, 59.345315579445135, 61.97308394216723, 58.19451570510865, 58.85890245437623, 65.88864095749395, 69.95538573111259, 70.32863847671017, 73.03954539760467, 73.22304171900596, 75.72057954726681, 72.49184131622314, 88.775239452239, 9.336672675225044, 0.5368409546152239, 44.09507759155766, 69.39706771604477, 60.35327449921639, 53.56573843186902, 33.90174750358828, 17.96710495025881, 24.999394955173617, 41.787719803471724, 2.442373859305536, 0.19386959622704214, 0.641713856208709, 7.170228977357188, 5.447516643231915, 8.874748868326988, 5.719461921722659, 0.655711692187094, 0.23126824668818907, 0.05177191165726512, 0.09250778284284378, 0.08605902323559408, 0.09610733888562649, 0.21773990003332017, 18.731610198174756, 74.1105721073766, 72.90453741627356, 38.66621525056901, 34.34626187047651, 51.013561987107806, 60.8638023561047, 72.66403336678782, 82.85171524170907, 84.04883830778061, 61.04201524488388, 2.5607534425873912, 0.510739389085962, 0.38513498380780226, 0.6009093780190714, 24.671592673947735, 37.33106397813366, 49.30207106374925, 74.52894779943651, 82.33041655632758, 82.79618232480942, 81.49299052453811, 74.2114790024296, 78.06707474493211, 76.8805342335855, 75.4440289158975, 73.90038797932287, 76.11120839272776, 74.04762591085127, 73.67774640360187, 70.84654823426278, 66.68389366519067, 59.08512515406455, 55.61932671454645, 54.63338405855241, 55.502942146793494, 53.34551695854434, 53.32613652752292, 53.835083669231786, 52.476492312646684, 51.76099708003383, 51.18605998254592, 49.14490561331473, 48.4274217390245, 52.23396039778187, 55.45119039473995, 66.90608809071203, 65.65717404888522, 64.85055431242913, 64.21748376661732, 65.9468646203318, 67.32725651033464, 66.07237262110557, 62.09042949061241, 63.94904067439418, 60.21170439258699, 61.11326902143417, 59.94195907346664, 61.47222472775368, 60.09030703575381, 56.729785011660674, 56.947696208953865, 58.25860331135412, 59.6834356554093, 62.34188087524907, 63.7816378378099, 62.06360047863376, 53.44651014574113, 49.397125782505164, 65.18329289651686, 64.74103389247772, 64.30900050747779, 52.3278776291878, 48.364569679383315, 53.91086386096094, 49.22002292448475, 47.82399254460489, 45.52675447156353, 47.249781085598855, 52.425430897743475, 57.729942337159194, 55.03188902331937, 57.138723481086, 57.756751737286976, 55.199629183738466, 54.72901536572365, 52.07501419128911, 46.526617619299124, 46.08395461113223, 49.465959456659135, 47.300552245109316, 50.961774933722715, 47.24418386336296, 49.30045112486809, 53.40263843536378, 50.03900597172399, 58.78360863654845, 42.89104723161267, 54.4184930862919, 66.20473692494055, 60.24733520323231, 57.78766001424482, 56.77377831551337, 60.256580229728456, 59.96675629769603, 61.38013532084804, 60.55206806428971, 60.32882636593234, 57.93030877267161, 57.698900699615486, 59.20146657574562, 60.27903187659479, 62.8378410493174, 61.751756360453946, 59.90853655722834, 61.78693609852945, 62.63012016973188, 59.27406180289484, 53.55500682707756, 49.86172268467565, 49.37005358357584, 51.026058658476806, 48.854152079551454, 52.013119189969956, 52.31527897619432, 55.43930953548801, 55.41054287264424, 56.740626442816954, 57.03159178456953, 56.17617384079964, 52.858119318562174, 53.639369164743734, 59.207232459898925, 67.48919548526888, 68.29561125847601, 72.5842680469636, 70.8441085200156, 73.24981581780219, 67.7532337557885, 70.47973602048813, 64.61256842459402, 68.14245839272776, 64.7605751406762, 65.88823303099602, 70.88609357034007, 75.12222982222035, 77.20489071261498, 81.58540941053822, 78.86217840256231, 82.91717175514468, 77.64993852184665, 96.2776117940103, 12.32472054419979, 0.6899962105577992, 49.13420146511447, 79.5314367355839, 73.95057862804782, 65.44096516024682, 47.85857216004403, 24.869531162323494, 29.729428214411584, 52.402885113993, 3.1342331344081513, 0.8252194932391568, 2.528021018351278, 11.734427367487262, 8.583848245682256, 13.992660410942571, 6.6910688050331615, 4.657485590827081, 0.23014768988134401, 0.19331159310475474, 0.22991792479109383, 0.19789374884097807, 0.3050191327929497, 0.3532695872408729, 32.01548557127676, 92.2341972781766, 83.33289592496811, 46.57063837974302, 42.32914809257754, 62.04529085466939, 70.51073843433012, 79.0553786677699, 89.945831606465, 88.05689657888105, 70.30720664608863, 2.429783296200537, 0.7165218517184259, 0.7700869032452184, 1.8327559001984137, 40.40887724968695, 66.56659126281738, 70.43243223621, 81.02567149746804, 84.81775622214042, 82.18373560136365, 82.491084683326, 76.08868614319833, 81.07795669186501, 79.64782130333685, 77.01443610652801, 77.35539205612676, 80.66887701711347, 76.53877812047159, 74.83424155942856, 74.65669939594885, 70.39032167004001, 62.081823810454345, 57.541550897782855, 57.944539131656775, 57.38023557970601, 54.60705318758565, 56.376465751278786, 56.904459922544426, 55.57729459577992, 55.42412604055097, 55.866098711567545, 52.27540416102256, 52.09115866691836, 54.00755813044887, 57.007673171258745, 69.12215663540748, 69.32016572644635, 64.92037250149635, 66.36710736059374, 69.309049729378, 69.34248401272681, 69.19528530490014, 63.57406208592077, 66.58676009024343, 64.36462756126159, 64.29324042412543, 65.36813459088727, 63.169375465762236, 64.72202216425251, 60.0038383853051, 59.85240351769232, 63.47938391470141, 62.78768962429416, 68.17736748726138, 64.46120023727417, 64.74499156398159, 53.438849756794596, 50.00517945135794, 70.02392522750363, 66.97243890454693, 64.37897166898175, 56.10209595772528, 49.24760895390665, 53.34762719369704, 51.21056302901238, 50.321867696700565, 50.3611227773851, 48.84083955518661, 57.50494341696463, 59.906045852168916, 58.36959462012015, 59.164961076551876, 62.500234803845814, 61.41590341444939, 58.03443985600626, 54.47656769906321, 48.94710048552483, 49.61545667340679, 50.986791810681744, 48.65104390728859, 54.67565151952929, 46.82048943734939, 48.44196196525328, 52.34203346313969, 51.16049397376276, 53.401881417920514, 46.44207093023485, 55.93283391767933, 68.02771337570684, 59.589310538384225, 57.9565219725332, 59.46954488754273, 62.794075242934696, 63.17243883686682, 64.08774745079779, 65.03368193103422, 63.69925629708075, 60.048686765855365, 60.93408338485226, 61.759389292809274, 62.8607790700851, 64.9780313430294, 66.76938564546647, 62.706924100076, 65.65897833916449, 65.93638404723137, 63.900222855229536, 57.65291875408542, 53.550672608037154, 52.265280523607814, 54.8667807732859, 51.61417099737352, 57.80057245685209, 55.57150909977575, 61.75105817856328, 59.22799356522099, 60.23873344544442, 61.00332498550416, 60.64845246653403, 56.0273983401637, 56.91668595037153, 61.40328122723488, 71.1241029923962, 69.79956565364715, 74.08644168607651, 71.58713879123812, 75.11299656283471, 69.84555936628773, 75.41090842216246, 66.18067710630356, 70.08656547915551, 66.3306136285105, 68.21671670483005, 74.67944129820793, 79.26614330660912, 78.80120908060383, 83.75911635737266, 83.06594725578063, 85.70124656923356, 78.0393357430735, 100.82392907911732, 11.68519966063961, 0.7255636504100216, 53.38914940434118, 88.33212929387247, 80.4301929473877, 79.11969769385554, 61.56512214291481, 44.65653742513349, 51.45802536318379, 80.90271303730627, 5.363539678435172, 1.18474823332602, 1.6783433407545092, 10.729366098680805, 8.213527471788469, 15.883082997414375, 9.67494768481101, 2.1578561586718408], [0.0560280203729147, 0.1311031392505092, 0.03181207684739944, 0.049856427546230056, 0.15050344259267853, 0.16316606392783506, 23.133578377385295, 59.83858892994543, 65.2829760120761, 30.57273191790427, 27.68676765503422, 63.03912924182031, 51.23107702501359, 62.22888523532499, 79.54607502106698, 70.00261106798726, 72.76137090498402, 1.8612242177609477, 0.18790132696590117, 0.8131159169058647, 1.662102154185695, 29.329020900111047, 31.42664759389816, 43.2331249790807, 62.60225957439792, 71.58019619603311, 71.3802965225712, 77.039656946736, 70.22797476860785, 76.36993577403408, 73.02346367989817, 76.00265287583875, 68.85189748579457, 71.68480580852878, 70.0073100674537, 71.38779609434067, 67.10332839719712, 65.78808707575645, 56.81290788035239, 51.62641271468132, 48.36916277485509, 50.66649498478059, 50.1022659578631, 50.30007500802317, 47.95232072953255, 49.89549821422946, 48.50946595591884, 48.806138346272135, 48.81742692762806, 48.530140769097116, 46.35195447552589, 51.846944055249615, 64.63649880501532, 65.41248483042564, 64.56606480383104, 60.34282530507734, 63.58147144317628, 62.46282323714226, 59.435953709387014, 55.443055399002574, 55.70291242291851, 53.42219537304294, 54.986636638641365, 56.63824081420899, 55.494203106049575, 52.5321154440603, 51.9180017132913, 51.69944332491968, 54.16431173201531, 52.41711155060799, 60.66345161007297, 60.49775500451366, 60.521344138729965, 51.660729531318914, 55.11395677443474, 57.759928857126546, 55.41355917530676, 58.62594504510203, 42.13890137210969, 53.80541486124839, 54.3798145940227, 49.5661642474513, 43.970828671609205, 46.24773317767728, 44.76738360620315, 44.3720204599442, 52.9358293164161, 48.715731636170425, 51.77924394607545, 52.27645143385857, 49.31943931887227, 51.43665236811484, 46.06783759209418, 42.59663412647863, 41.20019974247102, 44.37630761054255, 47.19860592196065, 50.727833009535274, 45.67278039070868, 41.636284935858946, 41.47783687037807, 51.47519749979819, 39.1032261233176, 40.6928607725328, 55.85832065151584, 64.53226181768602, 64.14672813107892, 59.74018058469219, 56.67734684482698, 54.832373742134344, 52.47828091344526, 54.33458182119555, 55.24499531715147, 57.55780127740676, 58.27723849204279, 60.77103437915925, 59.53643698846141, 62.2629863216031, 59.95487151607391, 58.25971726448306, 57.62708210176038, 58.14085768115137, 60.544682241255245, 58.47744803274832, 53.14117323967719, 47.71053798737065, 47.90689183819679, 48.4233424740453, 49.08638777271394, 50.267460500040364, 49.787417304131296, 54.02305541499969, 55.24274779904274, 55.97995335055936, 54.227144179805634, 50.128471312984345, 51.32347629916284, 50.74915109142181, 56.64218671860234, 65.83437104378977, 64.2659564172068, 68.71618347783243, 70.43938267615535, 66.79949375890916, 65.80501602542016, 64.38077203689083, 60.597869580791844, 59.036719183768, 57.46591583375008, 58.78549529660133, 60.729116009127715, 63.5815812695411, 67.37697647463891, 69.10880488734092, 69.83947969252064, 77.19170370409566, 73.72508156684138, 94.56388119728335, 17.784659824063702, 0.379000366214783, 46.85483763294835, 69.63639505447881, 56.41797619481241, 41.953165377340014, 38.63765647334438, 19.95491312396142, 19.965580009645034, 26.532582775239025, 0.948444735859671, 0.25341788637301615, 0.501628611837664, 3.829112389395314, 2.582399532679589, 1.5785188972949984, 1.2167936299116382, 0.044926326166117386, 0.14888050064684885, 0.03979516117983768, 0.06073108010534799, 0.11653168727794003, 0.04354469425555679, 0.08166872655912753, 29.6060480994563, 74.2884986631332, 74.15280818939209, 39.75315109375985, 22.849367357069447, 60.148236520828746, 62.689571534433675, 68.66337268583237, 88.97114615286551, 78.97418560520296, 79.72513906417355, 2.0558369039527835, 0.4302925574443033, 1.4457270551112391, 1.4604143702214765, 38.787130155871, 45.31534656401604, 59.05112212704074, 76.04996450485723, 82.53816881487447, 77.51347141881143, 80.76403371749386, 74.19633080882411, 80.36035906883978, 75.57364756061186, 77.47889180337229, 73.2238575720018, 75.17304020543253, 71.88283843378868, 75.54979170522383, 68.51599354897776, 66.727628092612, 57.24907152114376, 53.89027533992645, 53.10773111158802, 54.37122460334532, 52.57539095417146, 54.4855656162385, 52.94906731574766, 52.59939978199621, 49.28398893725488, 52.7006479232542, 50.94037448206256, 51.26323653805641, 50.023924458411436, 53.60961798698672, 66.86635448086646, 67.14757273274084, 67.39985958222421, 62.12526798248292, 64.2923814250577, 61.30048374975882, 62.43005183435256, 57.6966178801752, 58.1219950029927, 54.825113434945386, 57.25177011182232, 57.168713923423525, 57.37577976719026, 51.66847229003907, 55.914206581731, 54.182519374355195, 55.95336360316123, 57.70024999495476, 61.46554885372039, 64.15608298393988, 61.51359788833126, 50.75895309448243, 57.045559344753144, 57.5402408261453, 56.735986278903106, 60.89572260456701, 44.580921972951586, 55.00591508803829, 57.433673950933645, 51.57046794891358, 45.673913955688484, 47.903891225014966, 46.820136424033876, 49.678398947561945, 55.045542793889204, 50.79841213841593, 55.07044984448341, 54.93405334411129, 49.60279134012038, 52.3612020861718, 48.49643191983623, 44.92104245770363, 45.67176841920423, 49.46566135652604, 49.40184047145229, 53.875656666294226, 48.5538475744186, 38.6108470732166, 42.456381936227125, 50.680858704351614, 52.15417938847696, 50.38466484315934, 58.49738151796403, 65.27907325375465, 60.89853102161039, 60.91209457766626, 56.961353901893865, 57.26639663019488, 53.55967836995279, 56.857042389531294, 61.24273469371181, 59.98044536959741, 62.74468475772489, 62.930734542108354, 61.11153925618818, 63.47427306636688, 60.681725932705795, 62.132547901522734, 60.306943462740996, 61.6918735350332, 61.543929576873786, 62.81230641949562, 55.50039652855166, 49.689165853684955, 51.01406012811969, 49.81953759347239, 53.822422258315555, 53.072641588026485, 54.61605110476094, 56.487233484944994, 58.87642760430613, 60.2021965672893, 58.336368222390455, 54.690905617129424, 54.61307402580015, 54.64334687879009, 59.995899508076334, 71.65652551958638, 69.62511431786322, 74.37614010226342, 73.63809124115976, 73.67460850746401, 71.14693903153943, 67.74122345832087, 63.71715407217703, 64.89752077287244, 62.77286698741298, 64.99017500108289, 64.72587393176171, 70.28451965701196, 71.35393035027289, 75.51070920882687, 73.01384602823566, 82.43981930517381, 77.30726457411244, 98.79641671334544, 19.815676827584547, 0.34372924917167236, 54.34889454995432, 78.00256744507821, 67.48221366636216, 55.12343714314123, 58.548874393586196, 26.676006201774847, 25.22265822656693, 30.299566291993667, 2.708138708145388, 0.3471123547323289, 1.1862245153996254, 7.007472678538292, 5.565694224449897, 7.4543277198268525, 3.60190321360865, 0.625494058814741, 0.22613257710491458, 0.22219496178290538, 0.1580452564502916, 0.17420416517603785, 0.23922563260120733, 0.32036647861523015, 39.12512863835981, 88.3450182022587, 86.4122389208886, 46.30343867886452, 39.206255020633826, 75.67739425166961, 71.2269240040933, 77.98741140673238, 95.63727701863935, 83.76522741010113, 90.07393621629285, 2.8542428295458517, 1.3900710738474324, 6.8025494294781845, 2.45069541277424, 49.88659051156814, 72.74139819606658, 74.78791052295317, 79.1044161396642, 81.16717492380451, 79.40112775371921, 83.50272670868905, 76.8900106799218, 82.39297051583567, 80.15036321455433, 78.79603939671671, 74.46298922261884, 77.15528841941588, 76.36573883794969, 76.59344027119299, 71.79435760744157, 71.50195275583576, 61.4533777390757, 56.88687593706193, 55.156094797195934, 57.33266115188599, 55.00824105355048, 59.15164462981686, 55.540789096586174, 58.708118700212054, 54.1579653370765, 57.0480461274424, 54.57281874072168, 54.40860086871732, 51.028384623988984, 55.976791920200476, 70.84121381082844, 70.74462936770531, 69.76085970478674, 63.12961832169564, 68.91429455049577, 67.21580628425845, 65.51982049019107, 60.91200436315229, 59.15086407815257, 57.92599024311189, 60.377667719318026, 63.359516282235425, 61.01690423104071, 56.37854852984029, 58.308860640372004, 57.55778951029624, 60.1254593172381, 60.75975756491385, 65.33042884642079, 64.67503609195833, 67.62119108630766, 54.79732344227453, 54.12538613042524, 61.678211919723026, 58.998844777384114, 60.71737635520197, 44.88024588554136, 58.310304072595414, 59.60256422719648, 53.17625099612821, 49.037495428516024, 49.90598270970006, 49.99424780568769, 52.06484740780246, 58.36864932890862, 53.44807124906971, 56.964687916540335, 58.0110703745196, 53.1305593059909, 56.489335875357355, 51.9279331545676, 46.7657684510754, 47.3204896526952, 51.38527716359785, 51.66566387299569, 56.933544297372144, 48.722921340696274, 40.14534888728973, 42.698007783582135, 52.02934603537283, 46.94858228006671, 49.591416466620664, 61.46132446104481, 67.47778138806744, 64.34430968376898, 66.08870537050309, 61.23205407973259, 57.89417982101441, 56.738324011525805, 59.11038521797427, 62.74115854693998, 61.32717155641126, 62.58865287227016, 64.93442243145358, 63.71022324408255, 66.11988036863266, 65.63227484303137, 65.59222352120184, 62.18974782574562, 64.01272035414173, 65.5106068426563, 65.28292502126386, 59.14774971623575, 53.077528861261186, 53.847403833943034, 54.67232142725299, 55.14311175192557, 55.57118746542162, 56.192922361435436, 58.11324027276809, 60.2484844576928, 64.60379016014838, 60.96957299017138, 56.425475766581876, 56.5448844817377, 56.66477564842471, 64.33539021399714, 72.96037627804664, 70.95048319908881, 77.76664472395375, 77.09299333633916, 76.34435407577023, 73.01430886791599, 71.51312366608651, 66.72395675413071, 67.2895154645366, 63.88905194497878, 67.39102640459615, 67.39472127729847, 72.68263324614495, 74.54077766787621, 77.62018342171946, 75.94970087851249, 85.6097847415555, 79.5358141006962, 100.46525186108005, 20.587850309187367, 0.40616100233408714, 58.54045306482623, 85.27794438023722, 74.23451116008144, 68.15957561615976, 71.17877298785795, 44.90201503999772, 45.200009269099084, 71.8718557973062, 6.337687277024792, 0.9187015254170665, 0.7371829978881345, 7.218399605443401, 4.114237321961311, 3.7179543798969643, 1.9799131779901444, 0.2189883475582446], [0.08213953355387335, 0.06693174596875906, 0.0733744994466824, 0.007377312755242231, 0.03595280506077313, 0.18843081629564687, 21.865066212992517, 57.423515012187345, 66.42223235099547, 21.03731470723306, 50.74706046811996, 52.725241184234626, 44.57003739572341, 59.313422787574034, 78.77350930244693, 68.97005496486541, 75.63344017151864, 2.5264023052107905, 0.21306808136643904, 0.6550964316533459, 2.0161154289399428, 39.754708274718254, 52.946706048903934, 55.179609406378965, 67.38674317636799, 71.70909312463576, 72.02143930619764, 74.20133575316399, 71.34679163655927, 73.90282769357005, 71.25379223977366, 71.85184386468703, 68.11948899299868, 72.69773437130836, 70.03354287916615, 72.7365501465336, 63.01557933130572, 62.95379023398123, 52.652740093969534, 53.79874290958528, 49.54988641123618, 50.981669195236705, 50.15120537050309, 51.985607685581336, 46.47270856365081, 48.14237133149178, 47.394308659338186, 47.03845947019516, 47.64032756128619, 49.72570273184007, 47.79872071358466, 50.88840307727937, 65.10071915964927, 61.59091957153813, 61.902261626335886, 59.58014003692135, 63.01925459215718, 55.968684381054295, 56.30364694902974, 54.27677785196612, 51.93487967214277, 52.98601212040071, 53.71396087831067, 52.7908585148473, 54.35007518337619, 50.88387273973035, 52.37959407990979, 50.242102376876346, 51.462406650666274, 51.39962127131801, 56.06070710766701, 54.6786246761199, 57.642689212676025, 54.40409014301916, 56.892594752773164, 50.501218072829715, 59.39248208076724, 44.8349307429406, 43.24888114006289, 50.49976679586595, 52.62049036641275, 47.14864277070569, 43.5314957557186, 42.62992720450125, 42.956123275141564, 46.064174098353234, 50.5365272491209, 52.783100066646455, 52.01511959875784, 52.38855277338336, 52.113155318844704, 48.679312429120465, 47.48166376544584, 44.54788777136034, 45.08933959468719, 44.78526176944856, 45.83132259307369, 51.15352392196656, 47.68450521653699, 37.27364047881096, 34.83054122617168, 44.36932579163582, 35.0373403487667, 46.45088841838222, 54.27033339777301, 57.01811452065745, 55.041349780175, 57.98102501899966, 57.621065185916045, 60.18216502281928, 57.726361213191865, 56.61696195602418, 61.86776830304054, 58.708601151743245, 58.630695035380704, 60.3995898462111, 58.66368216852988, 57.3424082417642, 57.713958678707, 59.867320291457645, 58.48841497975012, 57.138884298263065, 56.905530729601466, 61.61909003411571, 53.91168755869712, 48.85985128341183, 47.44557795986053, 48.75449642058342, 51.20750750264814, 53.07734450986309, 52.28379018845097, 53.954370790912265, 53.73029755007837, 54.51186118587371, 52.492981956851104, 49.49791108408282, 50.04557594176262, 51.672924180184644, 59.73712898069813, 67.46018563547443, 65.3372420034101, 69.1227214567123, 67.43458040298955, 66.74691830911945, 61.60197673305389, 63.13024197855304, 58.1573590924663, 57.374520686364946, 57.05508285953153, 60.246295775136645, 57.139527566971324, 58.5131416013164, 57.87993769491873, 62.74186457357099, 66.67191474668442, 77.69596361344861, 73.21217675362864, 95.41793807860344, 18.27682902736049, 0.20740209507846064, 55.36845584069529, 68.79449752069289, 56.00233047239242, 40.39810642119377, 39.13717031478882, 16.648713965569776, 13.357963062101796, 6.271697321245748, 5.140320533706296, 0.18205051430531088, 0.3254087161152594, 0.6112076221935211, 1.1591318466009632, 0.7064520243194796, 0.009626540197660367, 0.051146132736316616, 0.07150551304221153, 0.046691515317727486, 0.06811830891116012, 0.08562002421146439, 0.08982277490318784, 0.14624181804397415, 28.239049142406834, 71.71799690492692, 72.53006873592254, 27.97018635657526, 42.861347044667895, 58.26713838884908, 54.14918315026068, 67.94324121167584, 86.40422944099673, 77.81517228772564, 84.07009755411457, 3.206556982571079, 0.38891820176955194, 1.8865464267230805, 2.6505019299445616, 51.07668861266106, 62.427549362182624, 69.35554550540063, 78.48792937494095, 80.76389251216766, 76.78402823786583, 82.10768868846279, 75.27582983816825, 79.41732714253088, 75.47787897048458, 75.60357524502662, 72.04287898155951, 77.01346335872528, 72.54182800169914, 76.29139423370361, 67.20993841848066, 66.60968242153045, 55.19705218653525, 57.76535349507486, 53.27280798266011, 54.55244987241684, 52.6635697580153, 55.515815365699034, 51.29611384484076, 51.31991870941655, 50.38823420001615, 48.96307629923667, 50.00792511047856, 51.462281134820756, 50.83293684067265, 54.22051537421442, 66.01276043922671, 64.06206377090948, 64.0641269376201, 62.369306087493904, 62.391910706796956, 58.282937695903165, 59.496001274355, 55.12201724513885, 57.248847946043945, 56.131062661447835, 56.97802005275604, 55.18728548480619, 57.22237194738081, 52.474103589211744, 55.44768771817608, 52.56954662261471, 53.64049880735336, 54.130065518040816, 60.450321782019834, 57.27752439437374, 60.97390720921179, 59.808865208779615, 58.75009590579618, 52.515817995994325, 62.2085948144236, 46.831103371035674, 45.13615700506395, 51.57880298552975, 55.61389815422797, 48.007312359348425, 45.61414095663255, 45.20392379453106, 46.68470874909432, 48.06175093497, 52.38015890121461, 54.58613910982686, 53.714796343157374, 55.56524507461056, 54.7293762237795, 50.5041520057186, 49.978625005291356, 46.0290414287198, 49.15595493009014, 48.38475027391988, 50.91093317154915, 53.000901437574825, 51.567306518554695, 36.035469808886134, 34.73619253404679, 42.129499450806655, 43.9317108738807, 57.84014524952058, 54.71895056386148, 62.99491628523796, 56.06577088755947, 59.12391347269858, 58.97374945302164, 64.36436476246004, 60.401201940351925, 61.30746556866554, 63.092555845937426, 62.544432070947465, 60.80812823387885, 60.39263548389558, 61.22592733752344, 58.86139708180582, 59.59484892506754, 62.23059538872012, 61.73045789041827, 60.88539108153313, 60.26901806554487, 65.76189741011589, 54.54762927947506, 51.030859639567716, 50.93495768885459, 52.81170591231316, 51.99715122099846, 56.07978551618515, 56.35623416592998, 57.90546055762999, 58.16875750018705, 57.19928095417639, 55.36148186652891, 54.15228966743716, 51.68619355847759, 54.56711169212095, 62.91241315103347, 70.59113133338191, 69.32746133496686, 71.89990074403825, 71.90440362499606, 71.01772831332299, 67.62195987086143, 66.56511645163259, 63.31427174229776, 63.2543771497665, 61.94664324483564, 65.85996843153431, 60.98852196047383, 64.3816545701796, 62.260946689113496, 69.45762911150533, 71.27141937132805, 85.2029251283215, 77.94863485520887, 100.56605677450858, 19.172098252081103, 0.058714928210622845, 63.53707413519583, 77.17189573472547, 67.92201334430327, 51.81347054819907, 57.957749674397135, 20.530195390024495, 21.128788302021643, 22.324289468026933, 5.536575038586894, 0.2426195400015962, 0.329420963722852, 2.767478530445407, 2.182802187819635, 2.333775196344622, 0.309487447863625, 0.01232200906792235, 0.18893490214982342, 0.2735249517906097, 0.1475524259430747, 0.26214704458271304, 0.17175306686230246, 0.39736297281999744, 34.54925237163421, 85.0396054790866, 86.74016475677492, 35.49107620793004, 67.2177125561622, 68.80205200564477, 61.849505747518236, 77.05343231078118, 93.88251842991, 83.56979139389531, 88.36645003288024, 4.245686242657324, 0.6736549422625573, 3.9904850721359257, 2.9561786113246797, 63.83412699545584, 74.43174362182617, 76.90076581893429, 79.34901514360982, 82.06047904106879, 78.52080668172529, 83.14199416868149, 76.79338701309698, 78.06411727782219, 75.87738806201567, 76.63047529036, 74.9657900102677, 80.62901004668205, 76.81902362454322, 77.89764404296875, 68.09910051284298, 68.37201118469238, 56.53470200877036, 59.95957443791052, 57.2136878198193, 57.66137930654711, 55.70488929748536, 61.37620902830555, 53.580835634662265, 54.19686348207536, 53.51641462695215, 51.766327581098004, 52.282962568344615, 56.08219777384112, 52.04960115494267, 57.1421241760254, 67.75364168228643, 67.86931237866803, 65.6242222170676, 62.59704674443891, 68.07880616957142, 62.39723728549097, 61.91770792007447, 59.93295331155101, 57.83719954952117, 59.81792980624784, 58.9567812796562, 58.49218829985588, 58.11443659567065, 56.297198572466456, 58.66704756213773, 55.27120067227272, 55.41661862404116, 58.5043711816111, 64.2315415413149, 61.268006524732044, 62.73540050752702, 62.92959313238821, 60.27177941414618, 53.61592908059397, 60.347881240229455, 46.54256205404959, 45.58721780776978, 54.378398618390484, 56.729765399809814, 50.04193990461288, 48.30690299310992, 46.82132490219609, 48.295967425069506, 49.72189018803258, 53.988852347097094, 58.42957158242503, 56.13868774906282, 57.299446521266816, 57.47749074812859, 55.62538677646268, 53.09319088535925, 49.2380658272774, 51.43126695386825, 50.6613645245952, 50.943484921609205, 57.10968617470034, 52.16646032948648, 37.62220190417382, 34.21601172416441, 41.90578314565843, 37.035380025063795, 53.49479060019217, 59.53737051256242, 64.61546313378119, 59.35651786865727, 61.60424386301349, 61.71778079002135, 66.78588313441124, 60.10460015266173, 62.04603610500213, 65.52698273812571, 63.98941363057783, 64.0240873829011, 64.22663465622934, 65.56181730762606, 62.49262932808169, 63.108437522765136, 66.28842461493709, 64.33795544408983, 62.801833691135535, 62.063961336689616, 68.8543293553014, 58.72376111245925, 54.9331315871208, 54.20488080670757, 55.442788677830855, 56.175628631345695, 59.11471159227433, 58.35525835714033, 60.97638614716069, 59.1668281247539, 62.896001954232496, 57.981425100757235, 55.863054952313824, 53.9066747696169, 59.14802035977764, 64.96947665368357, 74.79493156556161, 69.98609004482147, 74.98665701958441, 72.77077674865723, 74.17052945783063, 69.56689065502536, 68.418028431554, 64.44111377962174, 63.004859493624785, 63.51867429671749, 68.56470154177758, 62.34927846539406, 64.52904939651489, 63.933990540043006, 71.32918019448557, 71.51351590310374, 86.53510324416622, 81.25887993843325, 102.4252837704074, 20.62232009826168, 0.24293472389540366, 69.85266670103996, 85.88711984695928, 78.58032472672002, 63.929519038046564, 73.94056089462774, 37.80276429268622, 45.82510563635057, 60.577649762553555, 8.839583839139632, 0.3643888938090494, 0.5404438967666318, 1.5860374680449887, 2.0464227252429534, 1.631876124489692, 0.1371939366142596, 0.10671648452238691], [0.020858607247411724, 0.08640947781743542, 0.04451106437632153, 0.18614488653838637, 0.10826152298719653, 0.2005185805741818, 17.908516506994925, 58.91405882373933, 64.58741426467896, 34.52561224660566, 34.13672493350121, 48.16778829020839, 51.77389775553058, 54.60318180822558, 77.87914614523612, 69.39228242443454, 81.38038712163126, 4.975798187717315, 0.1757647628865896, 0.6806111431890919, 2.6859959479301208, 50.74360878236833, 63.50489893267232, 68.13677095597791, 69.67626202491023, 73.18708927400651, 72.62502931779431, 72.74445764480099, 70.36617555925923, 76.88764156833773, 72.44564364033361, 75.04685755698912, 67.25348457213371, 68.95755829349642, 72.21735385156447, 70.55244891874253, 64.32274841493177, 58.48791683873823, 50.988019512545684, 53.94439228119389, 52.06792646838773, 50.13727311165103, 47.83821898121988, 48.543563119826786, 49.497977764375754, 46.444145864056004, 46.31527246967439, 46.64833661048643, 47.94222062633884, 47.26583534671415, 47.55279987089096, 51.236042745651744, 58.24593013332736, 61.84213561396446, 59.588879077665275, 59.982061386108406, 59.29902376667146, 58.1404419099131, 55.703277203344534, 56.108705151465635, 54.72291608010569, 54.15858507156373, 54.07387756532239, 53.35040423177904, 56.228027574477665, 51.5926097285363, 51.86861515045167, 51.03981441067111, 49.90959913499894, 48.94362134318198, 50.58301518040319, 57.3035297086162, 59.77407378535117, 59.997997976118526, 52.802978638679754, 58.73175098050026, 52.82519102096558, 38.64990995776269, 45.73445181692801, 46.20477537955008, 55.031084937434045, 45.164919745537546, 44.78444591645272, 43.57854850830571, 45.500090199132124, 47.805977098403446, 47.434924802472516, 50.626659393310554, 52.92368173599244, 53.58986493079893, 48.694484156946984, 48.362165266467684, 46.93092769192111, 43.09312382052022, 43.351404051626886, 41.72038839709374, 46.4641381848243, 51.17075097176337, 42.689072624329604, 44.63693341901226, 34.797569782503196, 41.06543887046076, 36.49218666938044, 49.68377259469802, 57.650588866203066, 58.812057587408255, 57.932670039515344, 52.94192467966388, 54.32674884796143, 57.92800634138046, 57.63136140761837, 58.17076575371527, 58.53329081689158, 59.21119797614313, 57.284435610617365, 57.31535957705591, 55.63135270149478, 55.102754485222604, 52.81927608674573, 56.829444592998875, 58.321710325056515, 59.07312662370744, 57.07321597683815, 59.54884344531644, 51.97701377253379, 46.79540588009743, 45.82275613661736, 46.197899464638006, 50.55728835444297, 56.23099288632793, 52.41830395114038, 57.2765673360517, 53.576450424809615, 54.239958563158595, 50.71461069968439, 51.03976734222905, 48.819399879824736, 51.42381837291103, 56.69590750048238, 68.26148663797687, 65.2308359453755, 66.41289710998535, 62.64255016080795, 65.31523358437323, 62.734851375702895, 61.11069594660113, 59.380860097946666, 57.07735015499977, 56.200931841327304, 59.06870219015307, 59.03661327977335, 62.119141240273755, 61.57034673998433, 69.33508642258184, 69.79316434552594, 79.65537578828874, 72.43573573327834, 96.89317287937288, 14.694896071187912, 0.0787370766122495, 62.970715261274776, 65.17896259984663, 53.673701670862016, 42.64994698186075, 37.597804761702015, 16.642638214172855, 8.59190381342365, 8.342401846762627, 3.230008343535085, 0.136006883375587, 0.05619850557958407, 0.25871659478833603, 0.0370078077239375, 0.020300606040344126, 0.030292807665142803, 0.057555028958426374, 0.06665048444823873, 0.012324879024808687, 0.035336295803708416, 0.1821236144150457, 0.06668589303209897, 0.25245007217651416, 21.94868133914086, 74.40566770492062, 78.02075155319707, 31.731011752159368, 36.52877061597763, 60.18212187674738, 59.62664365768433, 63.045761969781694, 84.824643904163, 75.39353232229911, 91.15080725762152, 5.723739756691841, 0.5564096594049085, 0.702557968756845, 2.2865572139140102, 63.19035622381396, 73.7414143162389, 78.53844165802002, 77.65353925766485, 81.61208937245031, 77.14191313712828, 77.63064830533921, 74.72129298794654, 79.0454315370129, 74.9734543215844, 79.0531821404734, 72.61160696706465, 74.17259262454125, 73.03806274167954, 74.75908894692698, 66.82255729552239, 61.40572094148206, 51.178615323958866, 57.05660473915839, 52.98144255914996, 53.41189522897044, 51.578826519750784, 53.68930485940749, 53.878943612498624, 50.91733447967037, 48.367962529582364, 50.281063279797955, 48.69429588317872, 50.10688258755592, 49.14775717643, 53.24925807214553, 60.25175963678668, 62.289560379520545, 63.114732926891705, 61.38560702723842, 61.1967880495133, 60.687146648283935, 59.86315865670482, 57.97862060608403, 56.75175420699581, 57.25841068452405, 56.63815844443537, 58.62884367665937, 57.703395735832956, 56.06693975387081, 55.19229042914606, 55.30385832632742, 53.58323220283755, 50.40827358922651, 55.693079040896514, 60.280188975795625, 60.98574884476201, 62.33236128284086, 56.47450539373583, 58.67224470261605, 54.054297093422186, 39.43403490128056, 48.27579467527328, 47.037659306680005, 55.57253283839072, 47.43292831605481, 47.320842666010705, 45.524499108714444, 46.57732209851665, 50.30615860416044, 50.1672007960658, 52.489055664308616, 55.31443695868216, 54.5838249114252, 51.393200351345925, 48.19550375784598, 50.29131635542839, 45.22155877082579, 45.27526386322514, 45.2003897390058, 48.580790335132235, 53.56577765557074, 45.34852589330366, 44.496685151130926, 34.66124780716435, 41.78397786232733, 38.83137449141472, 63.36131665014452, 63.13369366430468, 58.78088651164886, 59.9425317395118, 56.402353394416075, 56.42678583821943, 60.459500128223056, 61.23890646042363, 60.679090099949995, 61.095465383222034, 60.39260802730438, 57.865613199049434, 58.873081822549146, 55.41502221938103, 56.0449666361655, 56.41000201625209, 60.956444817204634, 61.87798607733942, 60.96812955794796, 60.48334421650056, 62.61563877905569, 54.56886499158798, 50.1165198510693, 49.23310010663925, 50.14190150845436, 51.600729034793, 58.08166127051077, 54.719644823381984, 59.12453712955598, 57.92290333778628, 57.369135272118356, 52.786767482757575, 52.75854210699759, 51.20078456017279, 54.29655836474512, 61.06521606445313, 72.7931107244184, 68.85712992760443, 72.49418689358619, 68.48700723340436, 68.42319027070077, 65.3345787140631, 67.02780708189934, 62.48632607921478, 62.981152688303304, 59.9288740465718, 64.3806779000067, 61.155226615167436, 66.21625300376647, 65.89551295003584, 74.93172030295096, 74.0604991297568, 86.2381249089395, 74.54026775975382, 104.35272862834316, 13.134315398431594, 0.09239676904173628, 72.74741511191093, 75.47843594704905, 63.572348010155466, 54.69253732312111, 54.607488570674775, 24.905395353994063, 16.87715868796072, 21.911308996139034, 7.6092873273357275, 0.21844316874780964, 0.07775934157712806, 0.7194008101378718, 0.2111552364283031, 0.07656356259699791, 0.10916658692182073, 0.04936222422627672, 0.21436765759942994, 0.2120131016859124, 0.21855613607312405, 0.3336317813204181, 0.32688579492030606, 0.43381343625726243, 28.516133216119584, 87.46848613985124, 90.10311080563454, 50.295517213882945, 48.79054692483718, 60.64850737971645, 69.88253162753198, 71.16701372208135, 91.85521787212741, 80.33061965819329, 95.91483177677279, 7.623085735305664, 0.8640869947210436, 1.3881759561838642, 2.916503101587296, 69.13404141702961, 74.33761458243094, 83.44793904212214, 73.83500206855037, 83.06094231144075, 76.86067919577323, 76.32515015140658, 75.21056944324125, 82.80274837247788, 78.00975322723389, 83.09176429625481, 73.2162638633482, 77.44624199405794, 76.49022702247866, 76.99088619601342, 68.05699779141334, 62.786018694600756, 53.841410452319735, 61.48956160391531, 57.03286263250536, 56.976808040372795, 54.58193432900214, 56.407040626771995, 59.548623792586795, 54.073512784896366, 51.131660630626065, 54.7797865252341, 50.564278018090036, 51.53465278687016, 52.056708489694905, 55.55685904718215, 63.0382937769736, 65.32068175654258, 64.97979248723676, 65.3424705228498, 65.30216032458891, 63.754746067908506, 61.029004743022305, 62.58823710103189, 59.255960064549605, 60.03760999248874, 59.09945357230402, 61.82926239505891, 60.93983750189505, 57.710812937828806, 56.45357954886652, 57.57156879671159, 54.98658172545895, 52.83575004146945, 58.6387005929024, 62.15084968074676, 65.38294938302809, 65.05938914514357, 58.06355168742519, 61.125616642736624, 51.31246620608915, 40.96352784864364, 46.91568143906132, 51.30374677719609, 59.688577882705204, 48.41225001119798, 48.12816450672765, 48.12691719301286, 51.34763417705413, 53.179345746194166, 53.260605489054036, 56.13509878035515, 57.99327065867763, 60.18463611602784, 54.95182952573223, 53.43299365812733, 53.58652699378229, 48.55762089452436, 46.49302644114341, 47.219237589067035, 52.26111496648481, 55.16809724992322, 47.156056050331365, 46.13042685293382, 34.81701689381754, 43.33995073072372, 32.409924999360115, 52.47970081144764, 65.4499669997923, 60.715030777838926, 64.0840918017972, 58.55307917441092, 59.892137127537886, 63.16689260544316, 62.46964816124209, 63.43987387995567, 65.16945477454894, 64.10712003707886, 63.04122378749233, 63.844305546053, 61.22089101422218, 60.64252968757384, 58.793657748929924, 64.38282735886114, 64.91405356314876, 62.70285267983714, 64.01637600314233, 64.6926514564022, 55.812613271897845, 53.70565722065588, 52.73452151206232, 52.01084813764019, 53.310878507552616, 61.962501387442316, 56.48868476190875, 64.57650223085957, 58.78874694147418, 61.22934764431369, 55.826773028219904, 57.319285869598396, 53.78775242836245, 58.39367012823782, 63.30233204749323, 76.0755854268228, 69.84433558679396, 74.42569532702046, 69.5736292869814, 69.6888057647213, 69.32091097677909, 69.35183494321763, 65.31710063257526, 63.857418029539055, 62.97124478124804, 66.33809751079929, 64.51253621808945, 69.73869831331315, 66.82152963453724, 76.54392427013767, 76.0505214814217, 87.67422230012956, 76.22365490082773, 106.33291367561587, 16.274089371004415, 0.16617793860214372, 77.58708646220546, 83.38776988367881, 76.21478249949794, 69.06004982609903, 69.81263499106132, 39.28684403819423, 44.50905630665441, 53.865372211702415, 12.074423316986332, 0.5154630565835584, 0.13232949279969738, 0.4747916325446098, 0.1914105918859282, 0.24561016339688535, 0.09729505095991398, 0.2661907937257521], [0.04010043955678421, 0.04421142057605809, 0.01697003687431495, 0.039150279856497244, 0.07244777820643879, 0.417311933011778, 10.321105218702748, 59.25009612114199, 58.95079966514342, 39.98868942260742, 37.71171431387625, 24.50517042990654, 48.07350235600626, 54.24544203665949, 73.99911403656006, 63.9788193087424, 80.20002042093586, 7.205342035139761, 0.20271195158843072, 0.22491713264776816, 3.460169593172689, 55.552093367422785, 68.47291023500505, 72.27278478683965, 75.18387379184847, 75.72882436936902, 75.54047999843475, 76.15816700843074, 73.34381934135192, 73.03964737922915, 69.69352829840876, 72.80776469938218, 70.96456450800743, 72.96438494036275, 67.92452366121354, 71.14948857215144, 63.29610724602977, 55.472955626826135, 51.773454527701105, 53.65342693944132, 49.358239404616825, 48.53008193354453, 49.07975896712273, 51.59170758339667, 47.88712309252831, 45.34834546427573, 43.77893063329881, 47.48163630885463, 47.68259502226307, 48.62993763339136, 47.39251613616944, 48.57871932368125, 57.1132908328887, 61.64487177325834, 59.58868295915666, 60.54095206722137, 59.42329229847078, 58.43348218548683, 57.334512510607325, 54.903505925209295, 54.179750181013546, 55.53367783946376, 55.604629593510786, 56.25060865955969, 54.62686115695585, 57.64093983557917, 53.696753440364716, 50.30679795049852, 49.13851607230402, 49.78114543422576, 50.622682109955825, 53.63875335262668, 59.913655250303215, 62.49214295418032, 47.91722336123067, 55.91520678612494, 45.3974574612033, 45.748737089095584, 46.18464185345558, 43.69905940947994, 48.266141722279215, 47.4654173081921, 46.91481067288307, 43.167350753661125, 44.11048466159452, 43.85575809786397, 44.45373519774407, 46.99545068125571, 46.37576718484202, 46.14190763042819, 44.83443652429889, 43.96866352327409, 44.16058509580551, 45.87351945138747, 42.72320116719892, 43.206519542201875, 45.0109157254619, 52.15434020565402, 41.196108710381296, 43.81534984034877, 40.20938550272296, 38.0098379811933, 26.841220355802967, 41.30987705722932, 63.65379602678361, 53.90625899837863, 52.40547387830673, 49.73504189522036, 50.278352922008885, 51.15404559719948, 55.212537703975556, 53.64291890974968, 50.71907043457032, 50.17876786570395, 51.14612633182157, 50.54293247961229, 51.42681506372268, 49.1178059577942, 51.43083941551947, 54.59165003991897, 57.33363389968873, 57.90114202807027, 57.44082835412795, 60.34723404915103, 50.72504028197258, 47.610572461159, 46.51303445139239, 48.9878382221345, 49.49727173774473, 53.13274014380671, 55.541628483803045, 57.17770399585847, 51.93443252194313, 53.13978864300636, 49.976785413680545, 47.84105093248429, 46.18643045425416, 50.3406636945663, 57.07141953129923, 66.98398636233422, 64.44363586364254, 69.20989221142185, 64.17712649991437, 65.54968541668308, 63.30007276227398, 62.0955168047259, 59.90886603632281, 61.235560678666644, 57.459349786081624, 59.328771022058305, 55.313213179188395, 63.483239604580795, 66.8469544379942, 73.49244579192131, 72.02241989874071, 81.1805658955728, 72.61983609968617, 92.19163171706661, 4.949313854017566, 1.1320711696340193, 70.59162555202361, 62.321311966065444, 56.36803657777848, 42.99807694650466, 36.871876024430804, 13.883780317921794, 10.191338504514388, 6.660930293221628, 2.7944109949373432, 0.22832041696435024, 0.025443417478292703, 0.167514378986051, 0.17437227551014195, 0.09695431803383174, 0.06828792843847506, 0.057819290987906925, 0.09630137363508826, 0.026529812509374275, 0.007912287753330725, 0.18836611250956214, 0.09899593469115997, 0.3856917458676523, 12.8424459503543, 72.29746433996385, 71.29363567598405, 39.58565019792126, 39.901518667897875, 30.980758436264534, 55.661429435976096, 62.446639537811286, 81.87837908344885, 73.90769143258372, 88.4353974557692, 9.548512043491487, 0.8943496740633442, 0.4247884302129669, 4.333793953541787, 67.27758361447242, 76.15283258499639, 81.53982362439557, 78.96751757591002, 81.19094448704874, 81.42988743320589, 81.77567574285692, 76.04743849846625, 78.76533508300781, 74.51466252726894, 76.41860454313218, 74.01339930872764, 74.5750670279226, 72.08224388860887, 74.79358227022233, 66.22751805090135, 58.38754338602866, 54.24041748046876, 58.35446603836552, 52.19678809565883, 52.726853278375444, 52.8268031151064, 56.23799823945569, 52.115489129097234, 47.529912840935495, 47.39123744349326, 50.07420532165035, 49.2749047279358, 51.724640630906634, 47.63755444557437, 51.96816490542505, 58.45876578361758, 65.36246284361809, 62.965655403752486, 62.30115490574991, 60.61668519050845, 61.479606628417976, 58.95059177952429, 59.73814487457276, 57.85403043993058, 57.93284262380293, 59.996311356944425, 58.92691243079401, 59.616963248099054, 56.65435783324703, 54.37253467498287, 52.390557104541415, 51.0196691174661, 52.76595146425309, 52.75869900180448, 54.983000601491625, 63.941427353889715, 66.45751799306562, 48.66944374576692, 54.92088594744283, 49.832704990140854, 45.47683054401029, 48.33516759257163, 48.98348831361341, 51.00676059722901, 50.64720084590297, 47.143810410653394, 45.52836264333418, 46.30268166142125, 48.54907012754872, 43.71050488564276, 48.05716568423856, 47.510261766372196, 47.303533246440274, 49.14195599094514, 46.97104177167339, 47.93326977760562, 48.02647706001036, 43.3562050327178, 46.895410630010794, 49.65958333784535, 51.907360323013805, 42.24327172002485, 45.138412367913034, 36.59765920331402, 38.49858491651474, 29.084796482516875, 47.38479691167032, 70.80110365344633, 56.00677844016783, 56.31985418258175, 49.67532773171702, 52.13280639340801, 53.80294769041, 56.405424610261, 54.38361537071967, 53.92483534351472, 53.903721224877145, 51.454616823504054, 51.66312217712403, 54.60145596534976, 51.88865061729185, 53.395782132302564, 57.26408243179322, 61.01303677405081, 61.18011013154061, 59.01996281839187, 62.82357146663051, 52.44289328975063, 48.52125267828665, 48.550019341130415, 53.264920096243586, 51.3937573279104, 55.985068121264064, 57.55332977541032, 59.938366182388805, 55.227960463493105, 56.23760992480863, 50.2638715313327, 51.571158286063906, 50.331869740639966, 54.06148679794804, 60.20516972387991, 72.5891004070159, 66.45945564393075, 73.10996763167843, 69.70916286591562, 70.26724553877308, 66.89102618925034, 68.20083895037251, 63.34769818090624, 65.41928622030443, 60.625181044301684, 64.43732869240546, 59.67327279429282, 69.32443326519382, 68.94654427805256, 79.73857710438391, 77.20102325562509, 87.81340368332403, 75.52118193718695, 100.41164875030519, 4.546648725386589, 1.6602776391852287, 81.29655038156818, 72.19903638285976, 66.69127556585497, 55.48182410578574, 49.03209040241857, 22.68490629811441, 20.811894132244973, 16.63962387269543, 5.879237219210594, 0.26746253032357464, 0.06482711857965877, 0.20160630285259218, 0.23015319039264034, 0.09953451748456686, 0.02062426669703376, 0.05954461675437708, 0.15633963829567357, 0.15465772290143276, 0.09921782439754856, 0.28831673065020197, 0.301251910747059, 0.7231243651720786, 16.968394979353874, 85.78998627201204, 85.15857096641295, 58.59867672766409, 54.44219596924321, 36.80085366772067, 64.70834485946163, 69.33004225454023, 87.01355395778533, 76.05339265638783, 92.60814820566486, 11.19168116200355, 1.1319059397905105, 2.6692866509960544, 5.220541338766775, 75.40252239473405, 74.53980492007348, 84.3235218909479, 77.04199467935871, 82.7657368875319, 79.65745464448007, 82.9421180294406, 77.17763023991739, 81.72327287735479, 74.22264991268035, 79.99997954214774, 76.18170122946464, 76.04470852882632, 74.62342985214727, 78.9886042379564, 67.6520993632655, 60.748386613784305, 57.28354915495842, 63.89980708399127, 54.28278692307011, 53.96732637959143, 56.038832049216, 59.024497078311065, 54.433609900936005, 50.74273017144973, 51.01436215062296, 54.194655187668346, 52.86814881909279, 54.486608966704345, 50.78419746891145, 52.787410751465835, 63.089814109186975, 66.63308328197849, 66.07631852549892, 65.97934184535858, 63.386043271710804, 66.3270442716537, 60.70601717118294, 61.84628548160676, 60.43922147443218, 61.14755053674022, 64.69827221285912, 62.087142544408, 61.5707625112226, 59.84225242368637, 59.99452275614585, 53.53367697808051, 55.49094753880655, 56.04862620753627, 55.66464577951739, 60.102870387415734, 60.6793019079393, 68.0572723573254, 51.51293854559622, 52.53911295244771, 48.32052538471837, 47.09293334714828, 48.99471413704657, 49.32201239370531, 52.66187137173068, 52.510613010775664, 52.37349087192167, 47.436936978370916, 48.598099754702666, 50.42663420400312, 49.25766591102847, 52.6864097195287, 51.973291443240264, 50.333297483382694, 52.77203898276053, 49.51212183121712, 50.10074015586607, 50.41412184315343, 46.79907721857871, 49.23291967761133, 51.8832181346032, 55.13401969786614, 44.15404650472826, 46.12270762843471, 38.633992979603434, 40.01556158065796, 31.142603274314638, 41.38914031367148, 68.62159159875685, 59.91964863192651, 57.768185446339274, 54.449134642078036, 53.61136736408357, 57.42984571764546, 59.95549517293131, 57.38180452777494, 56.98520583491172, 56.245336994048095, 55.00502863237935, 55.95719575881959, 59.24960582487045, 55.28612529077838, 59.405214094346576, 60.56430978159751, 63.946879448429236, 62.574449969876206, 64.72340283855316, 66.54043689850839, 56.50857902342274, 51.7498653934848, 52.46852597882671, 56.331413407479566, 53.53956837807932, 59.56605088326239, 61.42418746025332, 63.102667716241655, 58.72676172564107, 59.84112278107674, 54.03257108503773, 55.148783499194735, 52.12931156158448, 58.222442980735536, 62.90922426408338, 75.12601098706646, 70.60995871020903, 74.94626445154991, 70.18122796089419, 74.71859439726799, 68.81762381522887, 70.73848693601548, 64.05717257530459, 68.40299790905368, 60.191794441592315, 66.85432849391815, 60.17903889379194, 71.10511087602185, 70.95311903184461, 81.07502275897612, 75.70133639920142, 89.2284457914291, 77.48146487820533, 102.51439217598208, 6.625265652133573, 1.4381769828258024, 86.63837140606296, 79.50764363811862, 74.71348747130364, 67.53627177207701, 67.42219355798537, 33.39566761447538, 47.63692294397662, 43.88645064446234, 9.67195491636953, 0.36166637054374146, 0.12966373664957861, 0.17787541172677473, 0.3278328634558186, 0.2350529355387534, 0.15067176743140145, 0.1710387051946694], [0.09061603596614254, 0.04748647709587409, 0.01582300789924639, 0.08955871971744685, 0.07303851626573071, 0.2631859823821053, 5.323607988895909, 53.16621757322743, 68.07265589314123, 35.79103162211757, 23.28805112069653, 39.84212221637849, 51.567306518554695, 51.04152848643642, 71.43353877529022, 64.43814062303113, 87.57353505780621, 11.245213670115318, 0.44602524549249684, 0.07372268640826787, 4.729308601348631, 62.88184219791044, 73.44524398926767, 75.75410012275943, 77.39100717729139, 73.81317015617125, 73.48301641402706, 76.44886170664142, 72.62102850021856, 72.41546492422782, 72.40083448348507, 76.08596401829874, 72.31575827444755, 70.5060786585654, 66.39191242956346, 70.33619296166205, 56.355179048353634, 53.43206405639649, 51.41078041445825, 50.43555367377497, 49.437843907263975, 49.672535004154334, 47.76453725753292, 50.69895652032668, 48.80021556731194, 44.39193433330905, 42.23672528420725, 48.09018419634912, 45.54930417768417, 47.81905428055794, 49.45595349034956, 49.266922704635135, 51.61153516461773, 60.5067882230205, 60.31410963304582, 57.651851869398556, 55.167736391867365, 57.3208861966287, 56.58184105350126, 55.16844241849838, 54.57638809757849, 55.606273066612985, 54.522820288135165, 58.60785115149714, 56.32942868817238, 57.32389465455086, 52.35292588510821, 51.079151861129276, 49.465547607791045, 48.95239176288728, 49.01645191254155, 53.797071979891875, 94.53668348250851, 56.54266834259034, 44.36008468750985, 51.92371660663236, 42.47133008895382, 49.49298066477622, 46.770200729370124, 43.227449309441354, 47.255233180138376, 48.247745806171054, 47.09936211186071, 45.768831391488355, 41.92967822474819, 44.59417566176384, 43.771897823579856, 43.8189584209073, 41.565635204315186, 43.305802576003536, 44.79897437557098, 41.863951067770685, 41.8102655872222, 44.95126039751115, 43.923493508369695, 41.84862244513727, 46.26871785809917, 49.15116179373957, 40.311174931064734, 45.07352067578224, 42.39279639336371, 41.708613441836455, 37.15175674807641, 28.364914078866285, 62.55073531981438, 56.45452091770788, 54.777691979562086, 46.241206353710545, 44.99627743997882, 47.65635828818045, 46.932010266088675, 48.35939215075586, 48.98805003012381, 46.455305007196245, 50.526858606646144, 50.41258819641606, 51.1138609147841, 52.08653027011503, 52.19353252841581, 53.3194096626774, 55.113646907191125, 56.455121040344245, 55.850887760039306, 54.16938727901828, 51.218176349516845, 49.75568532943726, 42.98499584197999, 46.71789984549246, 48.837160371964984, 52.49116589946132, 53.30208455362628, 53.603157843312914, 48.00856751780356, 46.12253504414713, 49.03538911573349, 45.667249848765714, 48.039993547624164, 48.59414600556897, 57.72789485992924, 66.1999830122917, 67.05362412237352, 67.28574214443084, 63.777852750593624, 65.38174913775536, 63.48308663214407, 63.89854015842561, 64.381230954201, 64.50256163074125, 61.927702119273526, 61.192751930605986, 58.59019264098137, 65.05330947137648, 67.94375896453857, 76.87610195529076, 76.10153582788284, 80.08740132854831, 74.63415361219838, 81.91939138597058, 0.9262037938160281, 3.911176708436782, 75.2791638528147, 63.132599323026604, 50.36752016313615, 37.062832693899836, 42.352195939710064, 16.686319689596854, 10.500610528453704, 12.295928385949905, 1.4302421505412748, 0.3419836105838899, 0.18043604529192372, 0.06891215986181652, 0.12537613405936188, 0.08134280211262165, 0.05276453178075533, 0.011722841168633633, 0.029071600311585975, 0.01114216375900733, 0.004323539295939789, 0.056555039069104585, 0.06338395448701997, 0.12752262049264487, 6.398564913580495, 67.78309868228051, 76.35885900066745, 41.408265790631695, 21.749799520738666, 33.73608227699034, 61.65097105887629, 58.78943727862451, 81.7779036491148, 70.366238317182, 97.8090149356473, 14.18645981819399, 1.2558525920875612, 1.4788578450679781, 6.104344004584897, 72.28748583024549, 75.40519745119157, 84.10804256316155, 80.31682860466742, 80.33834672743275, 78.48458751555413, 81.21704393817534, 76.01009753442581, 78.08088933267902, 75.6893104122531, 78.4161029323455, 74.42160821730091, 74.70427774613904, 69.23151231581166, 72.2936047277143, 57.78288648974512, 55.58289181801581, 53.57022170097598, 53.580317881799516, 51.27121071661673, 52.39311056752359, 51.534625330278956, 53.32990984762869, 49.859694819296564, 47.1382131884175, 44.864109254652455, 50.73484620740337, 49.116433128233886, 51.4636500420109, 50.944696933992454, 52.02024613657306, 52.91955148020099, 62.97592024649344, 62.76652059247417, 60.55302904498193, 59.23036659917524, 59.13847723314839, 58.876364846383375, 57.11922930132959, 54.99607386127595, 59.8635155923905, 56.71302864628454, 62.22740650177003, 61.10584005232781, 59.313830714071955, 55.06355824009065, 53.60764111241987, 51.07730050240794, 52.26637878725606, 52.35240028750513, 63.14822604579311, 97.86512051859211, 58.82304414626091, 45.29281254737608, 54.14306817516204, 45.37881443577428, 51.57020907248221, 49.4417231313644, 45.786356541418264, 53.03051141000564, 51.68607196500225, 49.8672414595081, 48.13807241378292, 46.231325903246486, 44.79020395586568, 45.06930020547683, 46.53011637349283, 44.117054631633145, 46.31487631028699, 45.975281423138036, 43.17390503421907, 43.9493223159544, 47.18743893408006, 46.72307345174974, 45.33020842459894, 50.53131049679172, 50.953879202565844, 42.78175430913126, 47.67506407153222, 42.04524301713513, 44.464164780032256, 41.164302210653986, 35.45525712351645, 72.03427330140146, 61.22120480383597, 54.28896073372134, 51.07162875513877, 47.48749632989207, 50.692068838304095, 50.7227849191235, 50.99485228138586, 50.986783965941406, 48.70968334136471, 51.63716785369381, 52.74035015413838, 53.546640411500015, 54.6682539293843, 55.48828032708938, 54.85255041430074, 55.35388423550514, 57.563535782598684, 58.112977473966545, 58.64541961300758, 53.69577284782164, 51.028455226652085, 47.02557056180893, 49.9657831653472, 51.05753567910964, 55.44840551191761, 56.0364237139302, 57.3756464066044, 51.37785211686165, 51.027682519728145, 50.85716924359722, 49.726224407073, 50.782832484091486, 53.943960820474935, 60.7202632196488, 69.30134619435957, 69.35729488249748, 71.34799972657235, 68.26819389097153, 70.02370557477398, 67.95036423590876, 70.1659385619625, 67.98043312564974, 69.0735584689725, 65.23114581261912, 67.01436904168898, 62.60675068824523, 72.55783911674254, 73.0311829043973, 81.9456869556058, 77.35805926784393, 84.96737895473358, 78.28757470653903, 85.65834368428877, 0.5917060267060035, 5.1163249438808815, 84.4522148563016, 74.25476627965128, 59.428516895540305, 47.93005735643449, 59.22941738559354, 25.211563802534535, 24.668413592923073, 19.714405152105517, 5.347544743168739, 0.4259789921343327, 0.0834586067245372, 0.11609940684490627, 0.07565871316699252, 0.056825035266698375, 0.05700152660269411, 0.0528199544116374, 0.238404018624175, 0.19534273734015806, 0.1611458287844735, 0.22798519221044358, 0.14118893192179743, 0.29717270705488424, 7.315087010783534, 80.78194325970065, 90.21780875421341, 55.52906905451129, 36.24631681749898, 50.57966155390586, 73.5181765402517, 63.897622323805294, 89.7068965050482, 73.08688840558453, 106.70804131415584, 16.00019908720447, 2.740781653311945, 2.6675257519368203, 7.908838737395502, 77.80433085656936, 72.80527791669293, 84.95896939308413, 77.4486267951227, 81.5688648531514, 76.26698140175112, 84.33116266804358, 77.84552358811902, 78.50777656801286, 76.91209362399194, 81.35850814081009, 74.29876742824432, 78.38291968068769, 70.9211987833823, 77.4031900590466, 61.53315874838061, 60.389203409994806, 54.99085710894678, 56.574804321412124, 53.16438190398678, 54.63770258811213, 53.238840256967855, 56.96680207406321, 55.07519983476209, 48.67129118211808, 47.205191581479966, 52.80792866983722, 51.55064821243287, 54.567802029271284, 54.50936655844412, 55.911794324075025, 57.054718079105506, 67.0166204821679, 66.15049839019775, 62.8178487285491, 61.555806513755556, 62.49526908320766, 59.58773374557496, 59.80627644446589, 59.40869715905959, 63.84932225750339, 60.463814735412605, 65.39906247969597, 64.48392645005258, 62.21314084145331, 59.652884314137125, 55.348385072523556, 54.37537447098763, 53.09381846458682, 56.53713780064737, 63.36786700833229, 88.40814482781195, 64.51733719918036, 44.58201631422966, 52.66241265881447, 47.52599831550352, 55.43491648089502, 51.786982782425426, 46.72991406533026, 53.16857491770099, 55.663892684444306, 53.71517681306409, 50.34880261267386, 47.93577224977555, 49.32654665362451, 47.92158895923246, 50.38068363743444, 47.97964788252308, 48.37966688217656, 49.91207807294784, 47.67183988325058, 46.64597926601287, 50.46627367696455, 48.94870081255513, 47.64489712253694, 52.08890722643945, 52.72577854894823, 47.10848946725169, 49.00327274876256, 43.5056669481339, 42.20512274772891, 39.76775407791138, 35.4302010228557, 63.51944308127127, 64.03499157198014, 57.80553817749024, 52.42796867124496, 51.454761951200425, 53.263119728334495, 54.44627131185224, 52.23785531136298, 57.26053660915744, 52.13492839567123, 55.214785222084295, 57.84365969319498, 55.870272113430886, 59.42599088914933, 60.18267493094168, 58.91382348152899, 59.773673703593595, 61.461010671431026, 61.227645335658906, 60.10133281830819, 57.3722888577369, 56.22842765623524, 49.849622172694055, 53.186319720360544, 54.93377485582906, 59.12924005139259, 59.34445265800723, 61.454452468502915, 53.03890528217439, 52.47759842103528, 50.9785666004304, 51.91954712713919, 52.99401767792241, 56.43883535938879, 64.45195521077802, 74.13654604265767, 73.65185876046458, 74.27044007085985, 70.89274591015231, 72.04746815466112, 68.55822178625291, 72.62074608956614, 68.84600608579575, 70.16826844984486, 65.31879117411953, 68.8809230250697, 64.54755513898789, 75.89579182286417, 75.15253405417167, 84.97097184581142, 79.80677927694013, 90.679244226025, 78.27537613530313, 92.1131843136203, 1.79845477304151, 4.980582498734997, 89.84394411886893, 79.39455386131041, 70.36701494647612, 61.21459168772544, 71.60135346074259, 38.23378178381151, 56.02449186386601, 40.04343394310244, 8.558592104142713, 0.504835486532219, 0.3642869734716031, 0.17427204056612908, 0.2820288648288096, 0.2969260267432659, 0.20588395396067252, 0.25297698745083425], [0.07498189746852844, 0.051031357443500916, 0.08160066730793446, 0.07094813045114279, 0.039467329174400344, 0.024590192798284755, 1.3636023070543044, 39.162261716781124, 55.97525042872275, 53.36764304868637, 39.32680122313961, 39.971532975473714, 50.40216253649805, 47.816822451929895, 59.90988977493779, 65.62137849869268, 82.14431578113188, 20.01850062800992, 1.0223391255544079, 0.3511994338083652, 5.8505087994760085, 62.80888219033519, 67.90262114617133, 77.26465978930074, 77.34337391391878, 77.4200797850086, 75.96003240154636, 73.8270631913216, 73.25747228437855, 75.39855295611967, 72.69978969327866, 74.70023770486155, 68.16800086728989, 68.95110207219278, 65.78339199866018, 61.796487069899044, 52.73121103163689, 53.66720230348649, 47.88274572741601, 53.045585078577844, 50.41279608203519, 50.19053889859108, 48.15556226238128, 48.63671548904912, 44.5269658488612, 43.966761173740515, 43.11155111558976, 47.05807916579708, 49.4256414136579, 48.26008558273316, 48.454372344478486, 47.13619709014893, 48.128101748804895, 58.8472451702241, 58.091741761853626, 57.61410297886018, 58.12309326664094, 57.70828693143783, 55.351487667329856, 53.27690293712001, 54.39693181745468, 53.30801125495665, 56.27900269723708, 57.53162337887672, 56.04997550287555, 56.27727293199109, 54.948754387517134, 53.55362615277691, 49.24288249784901, 53.34987471180578, 48.98568876328007, 67.57987283891248, 90.90258398363667, 47.79266849640877, 50.920856768085116, 46.25360496582524, 42.370219230651855, 44.828717708587654, 44.94658885463592, 43.10483601785476, 48.696868958011756, 46.77140097464285, 46.03052408464494, 43.10226686539189, 43.435483978640654, 44.466431909991854, 42.053429003684755, 42.731575427516816, 40.12527027437764, 40.89177593108147, 43.109707601608775, 41.847677153925744, 41.55821407994917, 42.736976531244096, 46.15944454746862, 42.23437578447404, 48.68451349196896, 45.81706085512715, 44.207641770762784, 45.713686789235766, 43.202879582681966, 47.307581132458104, 51.329748169068374, 27.389212731392156, 44.34627794450329, 70.31036807644752, 51.06032056193198, 48.68051659676337, 46.488856961650235, 46.342340746233546, 47.914622829806426, 49.11305596751552, 45.819767290546054, 49.45035234574349, 52.265190309093846, 51.73507413556499, 52.87656622548258, 52.63664660915252, 48.85250468407908, 52.595493101304584, 50.33151672732446, 53.34463442525556, 55.60396671295167, 53.589625666218424, 49.91741249638219, 44.57375188027659, 43.72894394782282, 45.776221136893, 45.900795613565755, 48.10619531139251, 49.05709158989691, 48.60781546561949, 47.66186921827255, 48.275626013355875, 48.14754886011924, 47.55512583640314, 48.39676449375768, 49.12041041158861, 55.83278209932389, 64.57856147520005, 63.67056415927026, 67.20970307627033, 64.71675442111108, 63.12492716696955, 65.83491233087355, 68.67703822351271, 67.17884186775454, 70.12698942615141, 64.23631898818478, 63.65855386180263, 59.33642356626449, 66.50604555683752, 68.76993563867384, 77.41618879379766, 74.12020544851981, 76.94001305487849, 77.68740500173261, 64.48122001463368, 0.17718939531234004, 7.260806310561396, 73.43671675651305, 66.19951232787102, 43.90526625417894, 42.267598259833555, 42.78617874268563, 14.537218751445895, 10.001524225358041, 9.780821281094706, 1.3625084560724998, 0.14238721600943996, 0.048283377076469125, 0.03696966420618757, 0.04845385079181964, 0.04533806012102193, 0.03750394541589964, 0.05898066112891801, 0.049795473760534684, 0.04797095492962868, 0.026269501578363202, 0.09113987922788629, 0.03566485559267383, 0.016470746730544394, 1.7145411790378633, 50.876090757308475, 71.7969463717553, 59.9899531948951, 32.27438357568557, 44.56653471915953, 62.6585965771829, 58.03483209302349, 69.30158153656991, 69.88626572393602, 92.66102175558768, 22.163313434969997, 0.6618042362313117, 1.4434776983914839, 8.377347223220333, 72.03506562017625, 73.9191290640062, 81.54333022332962, 80.13139463240101, 83.02969671064808, 79.19206542353477, 75.93565094855525, 73.74306955645162, 78.40625778321298, 75.59708764476161, 78.72657422096499, 74.0581770866148, 73.27826084629183, 70.65421873523344, 63.51641108912807, 55.51854925770914, 55.447138586351954, 51.029020047956905, 55.30192459783247, 53.60640948818576, 52.04994632351784, 51.35508668038153, 53.086279669115626, 47.9096531867981, 48.05454946333363, 45.61775345956126, 49.629671342911266, 49.089266792420425, 51.8395229308836, 50.47093737509943, 48.24159945211103, 50.36080114303097, 61.49680229925341, 58.691040700481786, 60.90904297367219, 58.67231530527915, 59.80544882435953, 55.87325311476185, 57.042899977776315, 57.409265041351325, 56.24669021175754, 59.49808797528667, 59.9134865883858, 59.791536177358324, 57.67580186167071, 56.24389356182468, 53.9752495673395, 53.90533724138814, 54.38172086592644, 55.227921239791385, 69.51500554238596, 88.73141088793355, 52.888658892723825, 50.838314410178896, 49.102085098143554, 44.71664382565407, 45.82642355272847, 47.218382512369466, 48.33318679563461, 51.890529432604396, 49.47556534121114, 47.72223841759467, 47.05704758244176, 44.65365056068667, 47.64921172972649, 42.517763107053696, 44.92005794279037, 42.57468454299435, 42.92920404864896, 44.09195930727067, 43.65344224437591, 43.294070766818145, 46.2757271335971, 46.70824689249839, 46.64541836707823, 50.62938544058031, 48.27499843412831, 43.36330060035952, 48.12663085999028, 47.84574993195073, 46.828122369704715, 51.445269815383426, 29.9148190406061, 50.48493631424443, 77.26570313976657, 52.27851852293938, 52.69351313191076, 50.129055746140025, 49.71217447711576, 50.44765026338639, 52.371196285370864, 48.97715368578511, 52.491362017969934, 53.79458127483245, 54.25066271135884, 54.963404440110736, 55.8682167914606, 52.01596290834489, 55.03606242518271, 52.97281334477087, 56.52677882102228, 56.35388858856694, 57.998381507012155, 49.5854897652903, 48.34580506047895, 46.2678353248104, 47.147269941145375, 49.44424913775537, 51.06419194129206, 51.30634730862033, 53.570300148379424, 48.36998255022111, 53.3640540799787, 50.67166074629753, 52.07640271033011, 52.15860382203133, 52.69115186506703, 58.8118536241593, 68.856596485261, 68.01950777730634, 72.10434252215971, 68.85014026395737, 67.30964506826093, 70.39523247749575, 72.8182452724826, 70.07938754174018, 73.67641279774328, 67.46474342961466, 68.80582532575055, 63.07664671251851, 71.95854017811438, 71.85653501941313, 80.51769318119173, 75.25885382006246, 82.89702646193966, 79.09867378973192, 69.16373375923403, 0.1880376752946646, 8.75075392184719, 81.50894672639909, 77.16114844045332, 53.05114699948219, 53.45027562110655, 54.595293921809045, 20.73771426754613, 27.33417207194913, 21.05241975476665, 2.5047123336022903, 0.18620824200972436, 0.15895457217289558, 0.08658722553762697, 0.03314993066352702, 0.07269465770091742, 0.04971707998324306, 0.012824195024046688, 0.12360496176106316, 0.09526462684715949, 0.12394717323683924, 0.2241385728120804, 0.10810835136761589, 0.0869594906426726, 1.796286928076898, 57.1465446872096, 89.36692114799254, 71.51102912041449, 58.032196260267696, 52.77821671578192, 69.74120863022344, 68.12423506090718, 79.05563754420128, 75.22931052792457, 95.05932361848893, 24.31777331136888, 2.670463116899614, 2.2190546941372657, 11.130086222002584, 73.40230188062115, 72.67653788289716, 82.99689000652683, 79.58241185834332, 85.18785538211947, 80.235306063006, 76.50264524644422, 76.51954281714656, 80.01314301644602, 77.96031567358202, 81.36982810112738, 76.50511633965277, 74.7327619983304, 70.3188168617987, 68.11575489659464, 58.25936425116755, 58.760286223503854, 51.558339980340776, 56.7893736593185, 56.5893445476409, 55.069998771913596, 53.54522443586781, 56.14741502269622, 52.079987756667606, 50.2077071128353, 48.786777527101584, 53.81580129746468, 55.485758243068574, 55.24306551102669, 54.46631462343278, 50.874878744925226, 53.199189016895915, 63.86039118612967, 62.575450174270145, 61.92839637879403, 62.544592888124534, 65.84762865497221, 59.28770772872433, 58.071690605532744, 61.0286517297068, 59.69375933370283, 62.488130369494044, 63.3697928920869, 62.56864878439135, 62.49720281170261, 59.878177412094615, 59.03363620081256, 58.48082127109651, 54.499093870962824, 60.11217424946447, 69.6166576877717, 84.72165030817833, 54.77040421578192, 48.18965158154888, 48.16047306983702, 47.58287268300211, 47.61267877394154, 50.14545517583048, 50.51682910611553, 53.82004530199113, 53.75598515233686, 51.01292656313989, 49.699403239834695, 48.90881423027285, 52.24420170630179, 47.55831864572341, 48.87949059086461, 46.39622626766082, 45.38182681606662, 48.3432202185354, 49.06023733077511, 45.88631422288957, 49.523131924290816, 52.34572441347184, 47.651039554226784, 54.06263213003836, 52.521450519561775, 46.40025846419796, 50.99426392586001, 47.18551697269563, 49.402330767723825, 56.6788608797135, 31.845497892748927, 49.430120760394686, 69.77318379186815, 57.518805073153594, 52.763452914453325, 52.65794900155837, 52.45033010359734, 54.34636462119318, 53.697969375118134, 51.01023581720168, 54.65616910688339, 58.323742112805775, 55.58315461681735, 58.97336113837458, 59.263428257357695, 53.07311619481733, 56.61506745123095, 56.5009343239569, 58.28618934077602, 59.67981138537007, 60.044909523379424, 54.51885084952078, 50.316180259950706, 49.06964317444832, 51.60716564424577, 51.231265298781864, 53.76383773742184, 55.43079799221408, 55.12622202596357, 50.78701765306535, 56.56516313552857, 52.313004001494384, 53.66075000455303, 53.54627563107399, 54.71283558876284, 59.93785235189623, 71.22981086854013, 70.22799045808854, 75.29436695960261, 70.60964492059523, 69.05422902876332, 70.65475217757687, 74.16046465596845, 70.72459390086513, 76.99434572650541, 67.3569174735777, 72.1397066116333, 62.0300446018096, 74.9304808339765, 72.4414231700282, 84.9251271832374, 75.61467555261429, 86.21836400801136, 82.88738527605611, 75.60160621520012, 0.41144219797945797, 9.408329475310541, 89.08211000504033, 82.60495893416866, 60.642400249358154, 61.79104282009987, 69.0696753225019, 30.180806729101366, 51.342354666802194, 39.02264102812737, 5.357730648209972, 0.35313852491878694, 0.3161815854330217, 0.16459702423984007, 0.254109587159849, 0.11192264951645367, 0.21456486395289823, 0.31003765221084323], [0.09288724917437761, 0.06494600776462786, 0.06198101384084552, 0.05982080294239906, 0.09406566094126433, 0.13541059117884408, 0.29927099123597145, 19.85195286812321, 51.32466477732505, 55.3714878328385, 43.10253358656361, 27.435288813806352, 49.53820167049285, 56.57825600716376, 53.484384552125015, 61.764143205458126, 84.43826690796884, 28.67204546928406, 0.19857072541790627, 1.5625499477309566, 6.774273062905958, 64.6798566849001, 63.46915045092183, 78.66489887237549, 75.99871481618574, 77.32660185906195, 70.40500702396517, 74.63887614588585, 73.65484760653588, 73.03800782849713, 72.53222603951731, 71.20154626907842, 70.33265498376662, 68.3538741450156, 63.25713065362746, 55.22601889025781, 51.862025568562174, 52.21255210138137, 48.894834902978715, 51.04481935501099, 48.51572998108403, 49.13392297683224, 48.60867054231706, 48.30864060309626, 43.50267417969243, 41.22665612928329, 42.39308272638629, 47.00323658604776, 48.419196528773156, 49.704408184174575, 46.63788349397721, 47.783929455664854, 51.38913677584741, 55.39821094082248, 57.28615753112301, 58.124015023631436, 56.194926692593484, 55.921274692781516, 54.6219228929089, 56.803913885547274, 53.51623419792422, 57.97491004390102, 59.35736902298466, 56.16160615797966, 56.906978084195046, 58.28126676620976, 55.213663424215014, 53.94686337440245, 53.25092115709859, 52.4414655470079, 60.7857628791563, 59.89647526894847, 53.30700712819254, 42.0502636509557, 51.976907868539136, 46.19160013814127, 42.72932790940808, 41.98299892487065, 42.162372835220836, 45.908283418224705, 43.08916614901635, 48.10133157237884, 45.235000733406316, 45.49740337556409, 44.15806301178471, 43.223789738070586, 39.80658946498748, 43.74828515514251, 40.236583217497795, 40.91256449299474, 41.47214943362821, 39.62357951748756, 39.91692181556456, 40.19741835132722, 41.6120486105642, 47.29883032460367, 46.802383776633974, 47.06368031040315, 43.065816279380556, 45.677071463677194, 41.33965176920737, 42.85313360152706, 39.5339023682379, 39.97278421155868, 26.890504937018118, 60.152680566233975, 70.49082848333543, 45.9078598022461, 47.25716690863333, 43.81918591837729, 44.0405095777204, 46.620640754699714, 47.786635891083755, 49.27626971275576, 52.98154454077444, 57.726270998677904, 52.26384493612474, 52.80969373641476, 51.15032719027612, 47.97575296894197, 50.351764002153956, 51.73749031559114, 53.14795894007529, 51.60668319271457, 47.309126546306, 44.63766297986431, 45.10953587870444, 46.02426005947975, 43.589609592191636, 47.302442827532374, 48.67375050821612, 44.34081800522343, 44.98290608006139, 48.55439670624272, 48.25376272201539, 49.14358769693683, 49.90942262834119, 50.16242727156609, 53.90024992727465, 65.52640222734021, 64.92671105169481, 65.29185625814623, 64.24823907113844, 64.59286635921848, 65.31228788437383, 68.00916840953212, 70.08185079020839, 70.82335918180405, 66.7005245147213, 65.98892811805972, 63.38783187250938, 65.35764225067632, 67.50840725437288, 74.24314821920088, 78.20966859017649, 75.4348035012522, 74.29147181972381, 57.433642571972264, 0.10577942109516553, 7.925649525657778, 74.93015919962238, 70.19756855503206, 51.54292506556357, 42.76905759688347, 42.584349263098936, 27.450870429315877, 16.187283396720886, 12.135332822799684, 0.49906255437001107, 0.05313495061390343, 0.06993099551407561, 0.02579858350086837, 0.07228538288824982, 0.014688590646631297, 0.09333987690268025, 0.0770418466098847, 0.04881497314800659, 0.0500930184798856, 0.0478953420515022, 0.05564385792240501, 0.045514532304819555, 0.16406770344943772, 0.16159276447949872, 29.58876417529199, 67.7458518551242, 61.96616880355343, 41.912976772554465, 31.074763920999345, 65.22588591421804, 64.08201686797604, 59.96430089396816, 68.50034329199022, 94.16183040988062, 32.00283592747104, 0.24879183379873154, 2.0621236053205307, 8.574159010764092, 73.16266075257333, 65.85881525470366, 84.21850435195431, 78.66983321405228, 82.05405419872653, 74.52682187480312, 79.72077738854193, 76.9597190426242, 77.77290482674876, 73.46058045664142, 74.35708522796631, 75.32377689115464, 74.66222993789181, 66.46759063966813, 60.49311876296998, 55.469209763311575, 55.41325715280349, 51.27115972580449, 53.22139355444139, 52.11630105972291, 53.46951092443159, 51.372141145890765, 51.645820602293945, 47.629482207759736, 46.73660170647406, 44.468181287088704, 47.812503922370176, 51.02181073158018, 52.13796431018461, 48.0835553907579, 50.164180571033114, 52.61912145922261, 55.72758805367255, 58.9334039534292, 60.59499448345554, 59.26482462113904, 57.756488938485425, 57.72814981399044, 60.186711049848995, 57.37831754069175, 61.0380026601976, 59.80280906923356, 59.20543993673017, 57.30961330475346, 59.446861820836226, 58.42955981531451, 54.84138342642016, 55.915218553235455, 57.29981914643319, 62.1428951140373, 60.278066973532404, 61.79993483328051, 45.28320274045391, 52.127271929094874, 51.370913444026826, 43.290630848177024, 46.03902778317852, 45.60118144558322, 48.10509312537409, 46.01871775042626, 50.29912579444147, 48.42876318962344, 46.34825960282357, 46.194153601123446, 47.32799706920501, 42.408191696290054, 45.60207574598251, 42.90959612015755, 43.802013781762895, 42.999461543175485, 41.366155224461714, 41.82227588468983, 44.10406766399261, 43.52940513241676, 50.19059381177349, 48.05274517305436, 47.705842910274384, 46.565625590662805, 47.28653761648363, 42.69407756866948, 42.580838741794715, 41.37480797306184, 44.466573115318056, 29.880870926764707, 65.17323201702487, 70.47449573393791, 48.95034428565733, 48.76407877091439, 46.075635263996745, 48.270562233463416, 49.91752232274702, 50.27889813146284, 53.55023722494803, 55.36621224495673, 58.002092069195164, 55.69158854023103, 57.52667334771926, 55.280379018475934, 52.46475265872095, 51.7557450263731, 53.47283709433771, 53.970632937646684, 54.657796890504905, 49.38191090860675, 48.79605785492928, 48.22161105371291, 48.82934308821156, 46.527955147527884, 48.73674377318352, 50.5403241034477, 48.65093408092376, 48.219504740930375, 50.99832750135853, 49.93597707440777, 51.006811588041245, 53.00838139749343, 54.380144073117165, 56.92302842294016, 69.22052967932918, 67.5564484442434, 70.29000313051286, 67.75368090598815, 68.36437040759672, 69.06764353475263, 73.86416096841135, 73.17905625989361, 74.50797880849531, 71.18730806535291, 70.5786503514936, 66.78695786383845, 70.22046735209804, 70.58332581673899, 81.0849698897331, 79.74675132382302, 84.5127840965025, 74.26655692438926, 62.166401878479995, 0.17077818933513858, 8.969040686084378, 80.34969022197109, 79.11414361769154, 60.675414839098536, 51.64499298218758, 53.1113749934781, 35.64252676502351, 34.77447486692859, 14.984944558912709, 1.1461005071478507, 0.12065323264968973, 0.10321567721304395, 0.03169453023151765, 0.01897141284820053, 0.046149531093936776, 0.052302033009548346, 0.04134135643741296, 0.14608382007047055, 0.18179972776241843, 0.28672026470303535, 0.1539633561286234, 0.206185823246356, 0.2613627544093517, 0.2818871692063347, 35.57685059885825, 81.22852863803988, 74.1210840594384, 61.88062191009522, 38.60479877841088, 67.243270720205, 72.47788552315005, 69.04595282769972, 73.7233635687059, 100.24753678229548, 35.005200447574744, 0.9685455959650778, 7.357100007995483, 10.830448519799019, 76.8838054903092, 66.17991616649013, 85.92047568290465, 79.15293585869574, 85.19332316613968, 74.78824000204764, 79.74368403034826, 77.02004509587442, 80.31609119907503, 76.24096824276832, 77.28394216106784, 76.78387918779927, 74.63942527770996, 68.83955770923247, 62.015163129375836, 58.26944866488057, 58.87000668433405, 54.64090324217274, 56.224285633333274, 55.00592293277864, 55.61392561081917, 54.872731008837306, 55.33608451966317, 49.774442103601274, 47.93397188186646, 47.64509324104556, 53.07754455074188, 54.257056174739716, 56.824949556781405, 50.39830684661866, 51.49376992256411, 56.653604738173954, 59.56088119937528, 63.18133085004745, 63.14909681197136, 63.54688398299679, 61.968404554551654, 59.58132851508356, 61.52954232308173, 56.910971057030466, 64.79768468487647, 61.2161567134242, 60.53447623406688, 62.93984620801864, 63.615188137177505, 59.56698440736341, 59.393788230034616, 60.815490522692286, 62.759205372102805, 64.5337680078322, 58.90193869990688, 61.38057854867751, 46.1588797261638, 49.88428415790681, 56.47171658854331, 47.29975992633451, 47.6262854760693, 46.74303831592683, 49.847872795597205, 47.732244383904245, 51.972095120337706, 52.22529195970105, 51.343190131648896, 48.89703927501556, 49.721023344224506, 46.96391874744047, 51.75727867311048, 46.67235328305153, 46.242457589795514, 46.935771819083925, 43.67128902865995, 44.25529072361608, 46.11717316412157, 46.118938230699115, 52.63393625136345, 52.6391294694716, 52.58257673632715, 50.32081257912421, 50.62304689038185, 46.56062849106328, 45.68803841067899, 44.06304751673053, 44.064530172655665, 35.769674316529304, 61.93879458212084, 66.89373262466924, 53.7054846363683, 51.410435245883086, 48.03069753031577, 49.08107688350063, 51.87851129039642, 52.38831350880285, 55.71398135154478, 59.060527970713956, 63.172336855242335, 58.43498445326283, 61.176423103578635, 55.72749391678841, 55.53710206862419, 54.125252769839385, 58.47583986097767, 58.89068934225268, 58.241697895911436, 51.913443919151064, 51.62092139644008, 51.35380798770536, 52.42249304248441, 49.32131421181464, 54.39410771093061, 54.52329489492602, 50.09174223869078, 49.565528823483376, 54.60298568971696, 53.81684072556035, 54.40191322757352, 53.71104263490247, 55.857598935404134, 58.99760138603949, 72.22828941960489, 72.24572827739101, 72.88611796594435, 68.52008065869732, 71.43200120618268, 69.13780689239502, 75.2297184544225, 73.71410677509924, 77.45981339485415, 71.3600492477417, 72.7543027939335, 68.66009358436831, 74.69930418076055, 73.40122715119394, 83.37106843148509, 80.61383831885554, 86.52846659383466, 78.22926475155738, 68.48332020544237, 0.2493868389677617, 10.312165156487497, 87.04340319479667, 83.8894880971601, 67.73440637896138, 62.04709906731883, 62.4616975169028, 50.80828082176947, 61.347646328710745, 36.12504889888149, 1.7869057217913291, 0.36958591171330024, 0.2981688971481016, 0.20133598106763057, 0.26804172343784766, 0.13375225597091261, 0.18807800216299875, 0.10150634353199314], [0.04648382505101543, 0.03857042024573011, 0.021289204202231862, 0.008491415271325218, 0.1386835792612645, 0.26693301035031197, 0.3284916684271828, 9.00164048517904, 44.349474676193736, 62.70278599954421, 34.288242170887614, 29.91172625172523, 43.67770994863203, 56.657507496495406, 52.05885402617916, 61.639243172061065, 84.20954565848075, 37.62435528539842, 0.26603304090038427, 0.8744608670953782, 4.003420803816089, 58.71964654614849, 65.6232455468947, 73.07087729054113, 73.68239833462623, 79.18009434976886, 73.69189047044324, 73.41025644733061, 68.40335876710954, 71.7881602625693, 69.50505841162898, 70.09890525571763, 67.553388995509, 66.93126186247795, 58.65851640701295, 52.16073759140507, 50.5677963841346, 49.86095782249205, 49.321714293572214, 51.42101780060799, 46.23180443240751, 47.70738832412228, 48.6785004984948, 49.795309112918, 43.11394376139487, 40.90649658633817, 42.97622149990451, 46.73665661965647, 48.488030202927135, 49.942323469346576, 47.614169274607015, 49.77193570906117, 49.25866219305223, 54.095889906729425, 54.27831542107367, 57.14454035605154, 54.69101936586442, 55.78005367709745, 56.52132280411259, 57.57732683612455, 60.57437458345967, 59.00653654529203, 60.15071153640748, 58.73539094002017, 55.19985668120846, 58.037032542690156, 53.94084645855812, 54.14881444746449, 55.3198145281884, 60.70941394375217, 56.01313660221716, 51.87488309798702, 60.923653802564075, 55.618059788980794, 53.19035976163803, 42.706774280917266, 43.1020393679219, 45.25019599545387, 45.63876167420418, 45.39275061699652, 46.57039519279234, 49.27427714870822, 45.837182614111136, 46.44628747817009, 42.26025558287098, 41.140968030498875, 40.46487692863711, 42.40943508763468, 40.23619882522091, 41.26213788986206, 37.32573739943966, 39.467547632032826, 39.95442751915225, 41.689664471533995, 41.91120386123657, 46.53930648680657, 45.63540804770685, 46.83649663002261, 43.25348208027501, 45.4199993225836, 43.81855049440938, 43.87618187935122, 41.64343933905325, 45.930299682001916, 37.22390090265582, 36.09213629076558, 72.35639402943274, 55.8520213250191, 51.70866481719479, 46.51425430851598, 47.42214964282128, 45.251333482803844, 51.353247088770715, 53.625209408421675, 55.55919677980485, 56.30447064676593, 55.45586193761518, 53.76023307923348, 53.175584193198915, 52.30293919963222, 52.8113882003292, 50.608616490517896, 51.37622041086997, 48.23042854186028, 46.830389499664314, 46.3710524958949, 43.48131295173399, 45.15834585312874, 43.57309641376619, 44.039109291568884, 44.37259704835954, 42.96146554331626, 43.551578291000865, 49.48509670072987, 46.964240381794596, 48.46346832090809, 49.757877934363584, 51.4613397659794, 53.082290618650376, 59.05993569281794, 63.16384492381927, 65.27647272233041, 63.96058028744113, 62.309866489902625, 67.02505357803838, 65.69130259175455, 66.45752583780597, 69.19168456908196, 69.52542335756364, 66.25249570415866, 63.91122902593305, 64.7735817201676, 66.49485111236572, 71.13193204326015, 75.40956697156354, 77.29170060926869, 68.49479706056657, 56.27095007127332, 0.40059908142974304, 6.18326993719224, 72.61089309569329, 65.45183404799431, 54.28694071308259, 41.57964983294087, 50.65195083618165, 21.351414188261955, 18.581116699403335, 5.220643320391256, 0.26477549225091934, 0.11222415874081274, 0.050614762660716815, 0.11980688935446164, 0.06477511653135862, 0.024534011740357648, 0.08577717182737205, 0.015981170581653714, 0.08231616278569545, 0.02379337134170196, 0.026560538380797354, 0.03376199661063091, 0.14320820179437438, 0.19901372342100068, 0.2421734316815292, 13.821401884478908, 61.53482575570384, 71.92352910195628, 32.73355780109283, 25.862661561658307, 54.82525464027159, 65.70932588269635, 59.50818023374004, 73.2928285291118, 90.84937310987904, 43.03818318151659, 0.2186085671306618, 1.1322839582158675, 4.901537424133671, 67.02747760280486, 70.01335836225941, 79.55649283624466, 75.61749181439801, 82.89082127232706, 79.20301668105587, 78.11363327887751, 70.90520335781959, 76.44891661982383, 72.57719993591309, 73.58855955062374, 72.14214632588049, 68.93818962958552, 62.746759691546046, 56.52243283487136, 53.59598382826775, 53.33130621141004, 51.97642149463777, 53.37704889235958, 48.76913078369633, 51.46365788675124, 51.236846831537065, 52.81783265452231, 46.122487975705056, 44.65894576041929, 47.28608654391381, 47.06069930907219, 50.91821309058897, 52.11294743322557, 49.83142629746468, 51.505125184212964, 52.480912823830884, 57.15959049040272, 57.211965899313654, 59.347025732840265, 58.22383934451688, 58.331390734641786, 59.02614839615361, 62.61854917772355, 62.43661395965084, 63.74244159267795, 64.11541192762314, 61.67969849801833, 59.05945324128675, 62.36324994794784, 56.777241768375525, 57.941436536850475, 59.18915817814489, 61.84114325431086, 56.63735043617987, 54.462203979492195, 59.023210540894546, 62.65237569808961, 54.34326987112723, 45.64163284917032, 45.00537341640842, 44.32021771707843, 48.104995066119784, 47.42424026612313, 49.98706986827236, 51.31550996534286, 47.81378261504635, 49.8119556519293, 45.85488819306897, 44.48507493542087, 42.38213539123535, 44.93066403173631, 42.93160846156459, 44.04973106999552, 40.210570058514996, 42.38094299070297, 42.55664948494204, 43.85540508454846, 45.598412252241566, 48.31077437247, 48.641689054427616, 47.72922023650139, 47.70062223557503, 46.52476626057779, 43.960061765486195, 46.1928278400052, 44.13144973016555, 46.48727232410062, 40.15293867357316, 41.380220843899636, 68.7272524064587, 57.70431749282345, 55.43992142523489, 51.174571360311205, 50.19597530364991, 48.009881511811294, 55.246662324474705, 55.65783262252808, 56.34730685141779, 56.24538014011999, 57.45108927449873, 59.48631302002938, 55.13687126098141, 55.44502835119925, 53.82729776443974, 54.634231290509625, 52.876075929211034, 50.98728602932346, 48.898545465161725, 50.69890552951444, 46.510159354056086, 46.75418961432673, 46.88756588966616, 47.42387940806728, 45.719735084041474, 46.461027745277654, 46.87768936157227, 51.79707111850862, 49.51417715318742, 53.94669079011487, 52.80572822017055, 55.40077617091518, 53.90649434058897, 64.07755321071994, 67.96209996746433, 67.3647229902206, 65.05288977776804, 67.39642358595326, 67.37891412550404, 69.17601077787339, 71.70309974301246, 73.37897162283622, 72.00305123482981, 73.2098311762656, 67.24206263019194, 70.63330465747465, 69.77387412901848, 77.37679250778692, 78.40985067429082, 82.05211654786142, 73.54673923984652, 64.5355526862606, 0.16853370493458164, 6.909831646950015, 78.4407118828066, 76.24925228857225, 59.07750791118991, 52.33607146047777, 57.26603184976886, 31.85663546285322, 45.76421476179554, 7.773447344380041, 0.5254354375985362, 0.20842937301964531, 0.07815120321127676, 0.14496018359016988, 0.029983243026259928, 0.03839184898101995, 0.017957095199474887, 0.019830570879182028, 0.15469999563309456, 0.10412560580598731, 0.14087140379894164, 0.07590053648117089, 0.37240707645973853, 0.2847763012734152, 0.48679901887812926, 15.083005774405697, 77.17362157760128, 82.55126953125, 50.84193083547777, 42.78603361498925, 57.42659015040244, 73.18502610729587, 68.0188331296367, 78.34801843089443, 95.74292213686051, 46.23718592428392, 0.639605766102191, 3.8484967427869, 6.632046939865236, 69.30609226226807, 70.41747231637278, 82.46367516056185, 76.43039518787016, 82.60262904628631, 79.63050011665591, 79.28765358463411, 72.97265329668599, 74.35992502397107, 73.64282946432792, 76.78721320244574, 72.94425533663842, 70.9532759266515, 64.4189053197061, 57.809527227955485, 55.82108951384022, 56.895964068751184, 55.553054348115005, 57.02282920960457, 51.357938243496804, 54.96355349017728, 54.2699803844575, 55.43987435679282, 48.21489203360773, 47.74291715314312, 48.407519632770175, 51.1723199198323, 53.70697905940395, 57.35784669076243, 53.205394206508515, 55.07088914994271, 53.58601708565989, 59.63326069616503, 60.78337415572136, 64.91157070282968, 60.89765633306196, 61.64903733038134, 61.780530868038056, 63.18370388400171, 66.79064489180043, 64.29681370335241, 65.76008527509629, 63.535728762226725, 59.03767624209004, 67.3651466061992, 60.280204665276315, 60.614359224996264, 63.3457487629306, 64.93162970389089, 59.22269836548836, 56.70051628543485, 64.46545208654096, 61.08394538202594, 60.33307821519914, 51.63140981428085, 46.822458467175885, 48.116530756796564, 52.08715000460225, 49.466351693676366, 53.565503089658684, 54.385776596684615, 49.605195753036014, 50.85811453480875, 46.27130270004273, 47.2861728360576, 45.26884294325306, 48.86669189699235, 46.536490225022845, 44.62966134471279, 41.738403843295195, 44.439461692687004, 44.34047283664827, 47.26801226215978, 46.82023056091801, 50.0091802689337, 51.300451986251346, 52.6459151698697, 49.02361023810602, 50.60281922740322, 47.63198860229985, 49.38510371792702, 47.124194637421645, 47.021114749293176, 42.391913860074936, 44.94033267421108, 66.63756262871527, 60.40745027603642, 56.98726115688201, 53.0751322930859, 52.08073692937052, 48.26668693173317, 57.73105236791796, 60.39470649534657, 60.03441718316848, 61.44769422469601, 59.561979463023526, 61.14850367269209, 57.82069421583607, 58.11413457316738, 59.49168666716545, 57.96438632472869, 55.700476631041504, 53.424109489687034, 52.4743938446045, 51.576155385663434, 49.5824146270752, 50.653453103957645, 48.20610200205157, 51.62445152959516, 49.27388491169099, 50.14591017077046, 50.177465638806744, 54.449491577763716, 51.238302030871, 56.04391936332949, 54.092096974772794, 56.71573900407361, 55.67393787445561, 67.92670449902936, 68.88165258592176, 69.52733747420773, 69.37103886758128, 69.3683873453448, 70.29327438723656, 72.63172088130828, 73.25589549156928, 75.86875100289622, 73.30776491472798, 73.41066437382852, 67.4721331750193, 73.39001701724145, 71.04286286138719, 80.0732651064473, 80.58104730421498, 85.15188724763932, 74.07802427968672, 70.26774760215514, 0.6605586385534656, 7.908624968221111, 87.2749799297702, 80.46567470796647, 65.86719343739172, 63.784465866704146, 68.56188527999386, 42.4485646524737, 66.7690404768913, 18.900623167714766, 0.8841474053840485, 0.35295757495107194, 0.31441608984624186, 0.2981206029653549, 0.21962144261886998, 0.23595587740982735, 0.13392508540663028, 0.11590014737580093], [0.03284675136749302, 0.03352458596289639, 0.026197837883486386, 0.04306846335830708, 0.054404205086851315, 0.17496095279291754, 0.43239179157441665, 2.2876576838954805, 20.826852090897102, 48.850798453054125, 45.12579410306869, 29.70167156188719, 41.526215384083415, 59.659677859275575, 50.48466567070254, 56.42088659348027, 80.18589988831552, 43.40246154415993, 0.15141954585429163, 0.4227245587014383, 2.043940110072013, 50.98808227046844, 64.06544093162783, 76.28091366060319, 70.99768500174247, 74.36289818056169, 67.61298548790717, 73.79271891809279, 69.81494134472263, 71.30428098863172, 68.01837028995638, 69.21059039331251, 67.14496827894642, 64.33594719056161, 52.67293245561662, 52.30242144676947, 50.87683600764121, 49.27905851794828, 49.165109742072325, 49.5687843907264, 49.78521685446463, 47.62357119591006, 46.93690146169355, 47.58689311242873, 45.041980897226644, 43.00793778511786, 43.08347478989632, 45.28623081022694, 48.62222625363258, 47.043738980447095, 50.20863671456614, 52.47977141411074, 52.51895196976201, 53.5798668092297, 53.789960722769464, 53.6613069811175, 55.1761184969256, 58.35092413809992, 58.04686200234198, 60.41276900999008, 60.75561946438205, 63.099208185749674, 59.84870080024966, 59.09212658482214, 57.99796181340372, 58.572157582929066, 55.037427410002685, 54.49407323714226, 61.41677810299782, 55.82351353860671, 55.016478030912346, 48.23862237315024, 42.892204330813506, 77.74378515058949, 50.5817953232796, 42.03825335348807, 45.44693816092707, 41.43670689675116, 46.4408746073323, 44.289450645446784, 48.870837842264486, 48.93414881921584, 47.17642884100638, 46.42201192917363, 42.49803750745712, 42.26960651336178, 41.10965967178345, 42.1468912401507, 42.92560331283077, 42.47031419507919, 39.428449446155184, 39.9585146288718, 40.832614821772424, 41.39578088637322, 45.81767274487404, 44.88208155478201, 44.311988584456905, 45.804450435023156, 45.501729749864154, 40.92971701775828, 44.71134862592144, 42.97675494224795, 40.44173102225027, 41.82897921531431, 43.81301603009624, 43.62648771655175, 64.07796113721787, 48.27805788286271, 48.18330518661007, 51.255529080667806, 49.044590996157744, 48.568991845653905, 51.52014393960276, 56.17480101123933, 53.49288432828842, 55.957682132720954, 58.026104819390085, 58.69151530727264, 57.307361864274554, 57.61137300922025, 57.188215947920284, 55.88844445443923, 51.589966051040165, 48.0446494010187, 46.1478147199077, 45.63770655662783, 47.43434821405719, 46.69772709569624, 43.79507903129824, 41.21140203168316, 42.779267526442005, 43.15273600239908, 45.165884648599935, 45.65835783558507, 48.80513421950802, 47.971748228996034, 50.46437524980115, 49.7269892692566, 51.720129905208466, 58.01362775987195, 60.891851225206935, 62.62844139529813, 62.75404745532621, 58.7844088000636, 61.8620926334012, 63.523800834532715, 68.2612983642086, 67.30321238117834, 67.98354748756655, 66.15165941176876, 62.60207914537, 63.993838064132206, 66.25927355981642, 72.62697481339978, 73.56046753544962, 75.2641176408337, 70.19798432627033, 56.01426232245661, 0.2758155546842083, 3.8550100836061665, 71.20964988585442, 67.82642518320392, 59.69359459415559, 43.172626341542895, 44.26846596502489, 27.111736420662176, 38.50930867656585, 2.095674579181979, 0.19079353870643725, 0.08149748292541312, 0.0635722550683685, 0.0590524627196212, 0.012745899880575317, 0.060162217686733896, 0.01806811283102199, 0.09391692497076527, 0.041520180511138136, 0.026891913542884494, 0.06202872962720933, 0.031022623241428408, 0.10031669325525723, 0.19874321777493725, 0.5028411758042152, 3.2084181472178432, 31.721803988179854, 61.76980318561677, 45.195012169499556, 15.669324609541125, 45.0649542193259, 71.06165885925293, 58.449410930756606, 69.41174522522958, 85.89485476093908, 50.13084826930877, 0.13164451826483975, 0.44798103731966793, 3.3552447201744204, 61.84828589039465, 66.26264679816462, 80.65837290979202, 74.39022141118204, 81.55555232878655, 69.78792405897572, 78.68322418582055, 73.80575687654557, 74.27056558670537, 72.58800214336765, 73.7696240025182, 70.88829794237691, 68.27921575115573, 54.56329914831347, 57.00884595994027, 52.81542431923651, 55.05596060906687, 52.19881988340809, 52.849917642531864, 51.944889560822524, 51.99151477506084, 50.30309915542603, 51.901406165092226, 46.24440308540098, 46.48207126125213, 45.369479194764175, 48.42291101332634, 50.55351895670737, 51.49673131204421, 53.28119008771835, 54.07431294841152, 55.50573095198601, 55.06834745407105, 56.43371666631391, 55.223504650977354, 58.543030062029445, 61.93951237586237, 60.61346884696715, 62.21268976888349, 62.113595008850105, 64.12972465638192, 64.08150695985364, 59.13216613954114, 60.708880501408736, 61.967227843499955, 55.88266680317541, 58.53931557747626, 60.57398626881262, 57.590455009091286, 56.44378146817608, 50.93605595250284, 47.30028944630777, 70.85632278073219, 53.14389928694695, 46.77117739954303, 45.26690137001776, 43.522576285946755, 46.89472029286046, 46.15924058421966, 49.89581592621342, 49.767766229568, 47.353021790904386, 49.10108097137944, 46.47473250665973, 44.313518308824115, 44.13474059874012, 44.1527089764995, 45.41926976173155, 45.405082548818285, 41.30237748545986, 42.25437987235285, 41.602105402177386, 45.93279038706134, 45.37528038024903, 47.804969049269154, 47.43921195307086, 47.67016895355717, 47.35176271007907, 43.23610990278183, 45.99726630795387, 45.90698903606784, 43.41060046226748, 42.97267175489857, 45.862462289871715, 45.07092798909834, 65.80489050957465, 54.32019064503332, 48.197841490468676, 54.43941893116121, 50.72402046572778, 51.95755489410893, 53.58886864877517, 58.15866524173368, 57.97979731713572, 61.16595037521855, 60.66178460274974, 62.98275693770378, 60.05502531605383, 58.999127188036525, 57.84720159346058, 58.62194814989644, 55.28254024444088, 51.662223954354566, 47.61604808991956, 49.300015741778964, 48.8316180629115, 50.330053683250185, 46.37599860468219, 45.45077031658542, 45.60459390763314, 46.729266874251834, 47.30564348159298, 50.90653619458599, 50.23186106835642, 50.86756352455386, 50.337290456218106, 52.33605184862691, 54.37716699415638, 61.25821628878194, 63.64543353357623, 65.29039321407195, 64.46532657069545, 61.76219378748248, 63.39126002403998, 67.25296681927097, 68.41262340545654, 70.95420945075251, 71.20147566641532, 70.49351922927364, 63.7871644573827, 70.29339990308209, 68.79245788820329, 77.1554139352614, 75.63485222478067, 82.29460531665434, 72.75587958674278, 65.85823474391815, 0.46952339910691787, 3.7255098454413877, 74.46742934565391, 78.0120046677128, 61.75407055885562, 56.29517462945754, 55.670254768863806, 36.829553650271514, 65.3899625808962, 5.813696865112552, 0.3103714520412107, 0.035158387205052766, 0.0057209842188674365, 0.09189163364710347, 0.06633708553929483, 0.013582857641121073, 0.03660031023525423, 0.0795582385974065, 0.11469211864976153, 0.15555635935837225, 0.18331466663268306, 0.15939856609029157, 0.18977661827398887, 0.23201927332387817, 0.5823347489199331, 2.7061821808738094, 46.921863094452895, 82.40679294832292, 61.10789929666827, 44.04820919036866, 52.33859746686874, 78.6357399725145, 65.1462657220902, 73.22431256694179, 91.55784729988345, 53.50185086650234, 0.7069713093580738, 1.3239321905759074, 3.8597480616261883, 67.66656506446101, 65.60847390082576, 78.7992008270756, 73.58622966274139, 83.91634064335977, 72.35198528535905, 83.58158988337364, 76.15189906089537, 76.14621162414551, 76.44521390238117, 75.96788498663133, 72.4821138381958, 70.45468776456772, 56.12093902403309, 58.66191710195234, 56.723313100876354, 58.5349460571043, 54.61365061421549, 57.08238255593085, 54.603762319011075, 54.057489902742454, 51.575814139458444, 54.38066967072026, 52.19648999552573, 49.87303480025261, 48.352006327721384, 51.7536622478116, 53.32440676227693, 55.2155775408591, 54.263673213220414, 57.24904406455256, 57.860533729676284, 57.8381448407327, 59.362821117524184, 57.71153857631069, 60.25900033212478, 63.4268908346853, 62.80779569379745, 65.89141799557594, 66.46653944446196, 66.01126209382089, 66.88507203132876, 63.7600883360832, 63.032265094018754, 65.84949570317423, 59.90166064231627, 62.79039998208324, 60.88443010084091, 61.032997715857725, 55.423945611523045, 54.72948997251449, 54.142103272099654, 72.27646397006127, 62.698322342288115, 47.62745434238065, 49.81885510106241, 45.08978674488683, 52.82486546424128, 47.76594146605461, 53.30662665828582, 53.979807361479736, 50.75796857956917, 53.176600087073545, 49.843593489739206, 46.81345270526025, 46.12361369594451, 46.193784898327245, 50.2698217668841, 50.375031502016135, 44.77617363775931, 45.19491803261542, 46.12579061139015, 48.56823482821065, 49.898239950979914, 50.337898423594815, 49.46407279660625, 51.53891640324747, 50.68288264736053, 45.651062227064564, 50.07231866159747, 47.64281042160527, 44.81422847317111, 46.27747651069395, 48.136283812984345, 45.28783898199759, 70.15677590523997, 60.1120565783593, 53.76781502077657, 56.44976308268886, 52.7811820276322, 53.81088656763877, 58.19242900417697, 61.857872163095784, 57.94638264563776, 62.8105805766198, 63.79829614393173, 63.183068460033795, 61.85871939505301, 60.583709824469786, 60.8723884244119, 59.98617595241916, 59.0700710973432, 54.253114192716545, 49.88909690610824, 49.355991886508086, 49.7622670665864, 54.70082529129521, 50.078374801143525, 48.32913890961678, 50.178226578620176, 51.084627489889826, 49.05897432757963, 51.86538703979985, 53.79825653568391, 54.54022384458973, 53.623781665678955, 55.36141910860616, 57.51537692162299, 63.30292432538925, 65.21084362460722, 69.53734736288749, 68.90098202613093, 64.25475412799467, 67.15685306056854, 71.11756047894879, 72.33428755114156, 73.1217190527147, 73.689176190284, 72.5724224890432, 66.98961888590168, 71.92520787639003, 70.47474676562895, 80.55933306294104, 78.62944849075811, 85.54646984223398, 77.29768614615165, 70.2586006349133, 0.6773396413172446, 4.810326628146633, 82.36782812303113, 83.07596498920073, 75.68612544767319, 71.01390792477515, 62.112347695135306, 42.065643264401345, 84.9520032636581, 10.039561410104076, 0.6049848432021757, 0.32901714345620525, 0.12901613188366737, 0.20665350460237075, 0.17927589706115185, 0.19716906030812573, 0.18273322121991267, 0.25381527150109895], [0.056929135124289224, 0.04550490641005097, 0.08247951571378978, 0.07651999517674409, 0.043085654371327935, 0.030423745497941013, 0.09567306662398962, 0.27346908865917113, 8.308979330524322, 33.836942103601274, 46.1573931478685, 39.60852546076621, 42.87775824146886, 53.649186857285045, 50.025277676120886, 48.706000235772905, 76.48006808373236, 46.64087234004852, 0.11343525181854926, 0.6673847271069404, 6.793122012769023, 51.33497668850807, 66.93923996340844, 75.32165096652123, 71.16231472261491, 70.21111642160724, 70.02882034547868, 72.38850255166331, 72.7291682458693, 67.54948231481737, 70.76419415012484, 67.9565223570793, 64.43917220638644, 56.14948211177703, 50.041739863734094, 51.746390173512125, 50.07582133816135, 50.07991237025107, 45.97471660183322, 49.539535276351444, 46.58850477587792, 47.19120440944549, 46.73612709968321, 48.84815085318781, 45.134168363386586, 42.197227016572036, 41.18327863754765, 44.81758602203862, 48.16281864720006, 51.83192137748965, 52.193901231212, 47.97178745269776, 50.081226364258804, 52.64294593564926, 52.830058682349424, 51.086914231700284, 57.84291052049207, 61.4421283814215, 61.21042613060244, 59.18606342807893, 57.9784401770561, 57.91751792353969, 60.031106702743045, 59.70028615766957, 57.087520860856586, 55.02982585660873, 55.47716433002103, 53.96455718624977, 58.26252960389661, 55.06726487990349, 52.48686698175246, 60.82739491616527, 52.58600096548758, 53.350584660806966, 44.15067718875024, 42.111315342687796, 45.39350763443978, 42.69567789569978, 41.92406139066143, 45.53991010112148, 48.70075602685252, 49.04506560294859, 47.108116842085316, 47.63838991042107, 44.46106218522595, 45.12751994594451, 42.67991781234742, 42.96383465490034, 43.91267953380462, 42.81011696784727, 39.61671929205618, 40.3712107289222, 40.16320743868428, 45.211737155914314, 47.166203221967145, 48.16786281524166, 46.787800404333304, 46.210953112571474, 43.61459901255947, 40.4529333114624, 40.65715151448404, 42.118481512992616, 40.69877962912283, 41.34762202539752, 46.73997494482225, 51.13118602383522, 62.74621055972192, 63.55042196089222, 49.65165230535692, 51.67162587565761, 49.25837978239983, 52.586153937924294, 52.61437931368428, 58.10880014973303, 56.66427750741282, 59.28716251927038, 57.86373046136672, 59.054126662592736, 58.60221078318935, 58.240666312556115, 59.95041962592833, 57.120272651795425, 54.927502985923525, 50.016205233912316, 46.17004671404439, 49.514667449458955, 49.44780672750166, 47.51713768128426, 42.6503784425797, 40.278462363827614, 43.007643607354936, 40.33122216501544, 45.93842683299896, 47.96364068984986, 49.1085530865577, 46.47378329307803, 47.12552824328023, 51.351517323524725, 49.64790644184236, 52.446164546474336, 56.239527963822894, 57.96004426094794, 57.18437202515141, 53.954708114747085, 56.04288777997417, 58.5103214171625, 63.19077591742239, 67.60645866394043, 67.05123147656842, 64.36135630453786, 63.7113921103939, 63.916987065346014, 66.05169388555711, 72.01147648595995, 68.57697856041693, 77.219481929656, 71.50775786369078, 60.11760673215313, 0.5937091321233781, 3.4121129589696086, 72.50928801874961, 64.17616944159231, 52.42281467683854, 52.73041871286208, 36.56126353048509, 26.605956592867454, 49.095115046347345, 3.256344117464558, 0.37562672950087056, 0.06861528546939935, 0.19316265029051613, 0.08871708020207383, 0.08098610391419742, 0.02402526424116185, 0.09185758869974844, 0.09087139605394295, 0.09439355423373562, 0.04877624357299459, 0.0628926431489808, 0.05555657752519173, 0.09487918502981625, 0.06071648996083006, 0.0259428225352519, 0.5205254881612716, 11.635657183585629, 48.74328236426077, 56.34498480827578, 25.19421123689221, 40.3450563646132, 68.17436295170938, 55.79718266763995, 59.05830790919643, 80.98673020639728, 54.45674404021233, 0.12541260750543687, 0.6949363745027973, 9.98475609287139, 59.59346825076688, 70.8229120316044, 78.98107328722554, 73.81708468160322, 75.44966928420529, 76.7828279925931, 77.75654069838986, 75.0341804565922, 72.3779905996015, 73.63095252744614, 70.51473925190588, 69.27314435282062, 61.66007488004623, 53.469601138945556, 54.47667360305787, 52.740789459597686, 54.48090191810362, 51.45593081751178, 53.304449742840184, 52.16147891936764, 51.76602555859474, 49.820773140076675, 52.406783949944284, 48.0704076059403, 44.631234215151885, 44.91408809538811, 47.684234572995095, 50.03208691074003, 54.584421111691384, 54.01676001087312, 52.06072499675136, 52.30897180495724, 54.92096439484627, 54.974426300294944, 54.57793351142637, 58.99562451147265, 64.01510907757667, 63.277915293170565, 61.98119540368358, 60.79769080685031, 61.788214791205625, 62.25434141774332, 62.767979714178274, 59.135586446331395, 61.386211072244954, 57.9771222606782, 57.7714684701735, 60.19466169418828, 54.52322429226291, 54.647045673862586, 60.562658463754964, 52.61301040649415, 55.381638926844445, 45.573018827746, 43.935382212361986, 44.32909011840821, 44.92026975077968, 45.543891306846376, 46.110556125640876, 51.81858924127395, 50.41683220094251, 47.779273602270315, 49.82170274180751, 45.98385964670489, 46.6834653577497, 43.82918011757636, 45.199150270031346, 45.68219800149241, 46.50722542116719, 42.017574617939616, 41.84884209786692, 41.778070772847826, 47.94100076921525, 48.4431347539348, 50.42892094581358, 51.6210312228049, 48.13868038115963, 45.31830403112596, 43.415354374916326, 44.08602476119996, 45.26617180916571, 45.150712920773415, 40.633150531399636, 46.72845886599633, 50.406586970052416, 55.78718846844089, 69.15171561702606, 58.146839295664144, 55.75395422597086, 51.509741813905784, 53.128072523301654, 55.27619777187225, 60.16550671669745, 59.452619860249186, 61.12003903235159, 61.53451588846023, 60.04896917650777, 62.7703566705027, 60.81595336237262, 62.11629752189883, 61.32415133137857, 55.43766214001564, 52.72856735414075, 47.38412618637086, 51.82277441024781, 50.80063612230363, 49.893336988264515, 45.93479864058956, 44.88314843946888, 44.280217386061146, 45.05982768151068, 49.184988314105624, 51.353192175588305, 50.94841141854563, 51.006827277521936, 50.099359481565415, 55.7416497507403, 52.78961904587285, 56.120813508187574, 59.34196587531798, 60.75767478635235, 62.205233343185924, 58.00562612472042, 57.24661219504572, 62.86569772228118, 65.72185001065655, 70.27344288364534, 70.53413929477816, 70.95770036020588, 65.92358143098893, 69.03743343968546, 68.12756907555365, 76.97332182238179, 70.8996492816556, 84.29210370586765, 74.90508740948093, 69.47569554851901, 0.7986353229611152, 3.9936982287514597, 76.8319203776698, 73.0814520005257, 56.29236621241416, 60.879013307632945, 43.256827862032004, 28.3978247257971, 65.72349348375874, 3.690453907174449, 0.4443837948624165, 0.16038064484394368, 0.09096254519517384, 0.1374480939440189, 0.05100509211901696, 0.0675332245807494, 0.05296495187306597, 0.011730381389028363, 0.16949223414544137, 0.2184628265639467, 0.1657673154747294, 0.15077738031264276, 0.17494484962474915, 0.13550112744973553, 0.2615938678143486, 0.6025794496940029, 16.151422146827944, 70.77732624546175, 68.04951390912457, 61.10483592556369, 58.29523824876355, 74.85210403319329, 63.42536503268827, 63.79282443754135, 84.7491539678266, 59.914122012353715, 0.36493076311965145, 1.9642810619646505, 12.744887778835913, 64.17796196476107, 70.52824005003899, 80.56858201180735, 74.47443469878166, 78.5163979376516, 77.32373068409582, 80.15153992560603, 77.38797910751836, 74.11759314998504, 75.00207977910196, 71.9669105160621, 71.89592346068352, 63.808160904915106, 55.256087779998786, 56.93982401201802, 54.223021768754535, 58.253500307759936, 54.83585288447719, 55.33441751233993, 53.64061255608836, 54.378410385501006, 51.879385978944846, 54.44766375326342, 51.333811744566894, 48.697955454549486, 48.53388271024151, 50.741494624845444, 52.854428368230025, 58.79740753481465, 57.65373852945144, 52.82929382016582, 53.95838729796871, 56.523440884005645, 56.51627079133065, 54.76756834214734, 62.40122633595621, 65.43366955172631, 65.77241720691805, 64.17275305717223, 62.89410744943927, 64.57506272100633, 65.28233274336785, 67.01547515007758, 64.13157601510325, 61.813137531280525, 59.92060176787838, 59.51491494332591, 65.08449623661657, 59.49577377688501, 59.263946010220444, 64.64882289209675, 58.12099087622858, 56.979612535045995, 48.876505667163485, 47.22792956136888, 47.25531162754182, 48.611365210625436, 48.70486274842293, 50.30524076954011, 54.56242445976504, 53.080113703204745, 52.30440224370649, 51.74738253316572, 48.94249562294253, 50.60094825683102, 48.5591741531126, 48.890983135469504, 49.181795504785356, 49.38487229808685, 44.85530353361561, 44.524337860845755, 43.04189766606977, 49.76077264355075, 50.86666922415457, 52.021407158144065, 53.60577014184768, 50.36657094955445, 47.99463133658133, 45.122593449008086, 46.920941337462395, 47.7012498148026, 46.6605547935732, 42.84655970911826, 49.17338594313591, 52.985321783250384, 64.30369746300482, 65.70665867097917, 59.41253715945829, 57.613651906290364, 52.133849743873846, 55.73740182384368, 57.18109684605753, 62.38345015433527, 61.29390201260967, 63.36608232990388, 61.57112729164862, 62.96705961227418, 65.11449452369445, 63.664896334371264, 65.6963546045365, 61.44324233455043, 57.59593063785184, 52.71469785321144, 49.07556203103835, 52.93678637473814, 55.33040885002383, 54.74088838023525, 47.630066640915416, 47.191926125557195, 47.36165492765365, 48.07220012910905, 50.05348736240018, 53.51839150151899, 52.49883805551837, 51.15617152183287, 51.792725132357695, 59.57133039351433, 55.56273083533011, 60.482751938604544, 62.40718833861813, 65.6232886929666, 63.64486478990125, 59.71793682344499, 59.9291996032961, 66.78938973334529, 68.20887980922576, 73.10750438321021, 71.74332757149973, 73.03346572383758, 69.17221392354658, 72.6929412349578, 69.72140850559359, 80.66242864055019, 72.18873623878726, 86.1348645917831, 78.99984575087025, 75.42400129379766, 1.0216258670533858, 4.678484489840846, 84.67811199926561, 79.57844241972893, 67.5324906072309, 72.14925366063272, 50.628867687717566, 36.97398316475653, 87.51780602239793, 6.122475651002699, 0.8261831092738336, 0.3147083677111134, 0.2123255889502264, 0.41706362859376017, 0.2285051820499282, 0.13822668442322364, 0.21938274494342266, 0.21266090563468396], [0.1030209300018126, 0.08791995805598075, 0.0514719499305131, 0.036540566868479216, 0.10416250060042066, 0.0380535637058558, 0.21009706982201148, 0.12261860057591431, 0.9646085169046157, 27.335003614425663, 53.48531415385585, 33.891157104123025, 33.15780332011561, 56.29803795968333, 53.13027297296832, 51.95270684457595, 72.56881390848469, 53.305446024863954, 0.6105443739121961, 0.19170035698240806, 6.833387594069205, 49.49438095092774, 63.61145011840328, 68.36752399321526, 69.85989955163771, 78.54681199596774, 72.27764852585332, 72.89047179683563, 71.14242046110093, 71.48806756542575, 69.79816928986581, 64.7978219678325, 61.00127750827421, 52.72502153150497, 47.679845440772276, 46.89303367368637, 50.856890755314986, 49.502045262244444, 49.85453690251997, 47.575694745586766, 48.93734947327645, 46.665124354823945, 47.495376371568256, 49.39864373976185, 46.24375981669272, 44.83184383761498, 42.707703882648104, 46.86424739899174, 47.79958755739274, 50.90275895211005, 52.739024393020145, 47.90167900823778, 48.876486055312625, 54.911401656366166, 51.81983655498874, 53.66261705275505, 55.06067137564383, 57.762851022904925, 62.10652689779959, 61.659710099620206, 59.031341614261756, 58.09536210952267, 56.02081660301455, 55.633655132785925, 56.88966081988428, 58.38706485686764, 59.31263831353957, 56.90674274198471, 54.96793085528959, 51.888481955374445, 45.57131651909121, 48.12931768355831, 38.912610700053555, 54.73483224068919, 44.62013390756423, 41.099516422517844, 43.54802070125457, 43.16944529933315, 44.05478700514763, 45.520537514840406, 46.05029283031341, 52.766249564386186, 52.27179558046403, 49.06880770960162, 47.06681428417083, 47.212161633276175, 43.44980455213978, 45.94965265643212, 47.73203649828511, 48.86971996676538, 41.645859441449566, 41.024230449430405, 43.43434649129068, 46.26886690816572, 52.02945586173765, 53.007443951022246, 55.65859356234151, 49.3737994470904, 47.15620902276809, 41.96125330463533, 43.18882180798439, 43.157097678030695, 41.33428596681164, 40.664851127132295, 43.26048743340277, 48.1846897832809, 29.16575420287348, 56.79479437489664, 64.41366895552605, 55.132811607853064, 52.40609753516413, 51.017986420662176, 54.20489649618826, 57.34563243004584, 57.95706325961698, 57.29080553977721, 58.553973474810206, 56.900435570747625, 58.79252026157995, 60.06918899474606, 58.243910112688624, 56.263062184856786, 57.18110861316804, 53.41044787437686, 45.43053480886644, 49.22204294512349, 50.94965480989026, 45.04678580068773, 43.32886219024659, 39.05257263491231, 41.7208904604758, 39.26520432195356, 44.039148515270604, 48.490167894671046, 49.515271494465495, 47.754084141023704, 48.11140421898135, 49.503437703655614, 48.29870131707961, 49.951470436588416, 51.55978341256419, 53.794094900931086, 52.12920565758982, 51.95472294284452, 52.79520842336839, 55.98730387226228, 61.3854815113929, 64.8720645904541, 67.66562369561964, 66.24292512093821, 62.35722910973334, 64.42181964074412, 64.13913050005513, 70.20489554251395, 71.72435114460608, 79.80979165723248, 72.67539255080685, 65.64899982944613, 1.089124280598856, 4.306316279595898, 82.66209217809862, 56.51891054645662, 55.44195713535432, 47.213997302516816, 34.29370603253765, 41.18494172250071, 54.34854153663882, 1.417315366768068, 0.1412313425492856, 0.018831274299431714, 0.11772204235556627, 0.07499971667364722, 0.12893929326486203, 0.04054894573205421, 0.05418513841446369, 0.04553767965145169, 0.07488098836714223, 0.0550014165891034, 0.03365852877557759, 0.032286591707698764, 0.027279029262342283, 0.12620719390050059, 0.09963345007910844, 0.18325782290870146, 1.0523247262162547, 38.43323430707378, 66.61167498557799, 27.887132129361554, 35.2621784517842, 70.9672317197246, 58.98357106793312, 59.103725033421675, 78.67503427690076, 62.240389547040394, 0.6219094414864818, 0.3286630269740859, 8.228768821685545, 58.70900123350082, 67.88595891767933, 70.22366800615865, 75.05160362489762, 81.035595094004, 74.65509906891855, 77.52854116501348, 75.6748604005383, 76.35681936817785, 75.72068152889129, 69.72431890426144, 65.24031239171183, 56.23677053759175, 52.24683753905758, 52.915507516553326, 53.38131250873689, 52.89391486875473, 53.614760214282626, 52.02519616773052, 51.93422071395382, 50.41121144448557, 51.35474543417654, 54.2813434908467, 48.76908371525426, 46.559934231542776, 45.623303613355084, 50.70609915641047, 52.726386516324936, 53.96817753391882, 54.45749321291524, 52.16849211723574, 49.72345913610151, 55.415261483961544, 53.73951904235348, 57.66258347419001, 56.46102028508341, 59.68790715740573, 63.77820576390913, 64.25563666128343, 62.32870171147009, 62.761252849332756, 59.00609723983273, 59.8023070058515, 59.103619129427024, 61.384426393816554, 60.65742292711812, 57.51373737089096, 57.02390001666162, 51.788324233024355, 45.381760135773696, 49.02246098364554, 41.989137434190326, 57.802733682817035, 47.49103823015767, 43.37738975401848, 46.724418824718846, 45.43422575919859, 45.50778196704003, 47.28611400050502, 49.10476407697124, 55.42739729727469, 54.940964560354914, 52.398335164593114, 49.75223364368562, 49.59202835636754, 46.286576409493726, 47.97601969011369, 50.6157002910491, 52.03380184788858, 44.10750366026356, 43.558340457177934, 46.627147966815585, 48.6205239449778, 51.20951967854654, 52.56483585603776, 58.07023932856899, 53.172124662706935, 46.701578863205455, 44.57234374938473, 45.27811542634041, 45.94537335057413, 42.941394775144516, 43.904364109039314, 44.46463546445293, 45.687532424926765, 31.864274278763805, 48.68094413511215, 62.402928644610995, 60.2440639465086, 54.425070901070875, 53.973715920602125, 57.45251309487128, 59.938864323400686, 59.358777153876524, 61.016504149283136, 59.78628804606777, 60.23494443585796, 60.79580022442726, 63.40248584747315, 60.11297049060945, 60.09563361444781, 60.36415123170423, 57.138315554588075, 46.43994500560146, 52.047275189430486, 52.973221271268784, 50.00548539623138, 46.07190508996287, 43.62293404917563, 43.76349218430058, 43.490448151865316, 47.380301875452844, 52.33740898870653, 51.313701752693426, 51.085608082432906, 50.692304180514434, 52.916668538124334, 49.559394236533876, 54.14840259859639, 54.67089760688044, 57.62237133518342, 53.92733781568466, 55.257699874139604, 57.01629061852732, 60.915612943710826, 62.86909449485041, 70.02935378782212, 67.96930928384104, 71.88048501168528, 66.24946763438564, 70.04420388129451, 67.06398702436879, 74.5989699517527, 74.40857810358848, 84.56844252924766, 75.33999981418734, 75.92863775068714, 1.3556208966239807, 5.062662507257154, 88.77533358912315, 65.61879757911929, 59.97196520528486, 55.61979739896713, 38.56479452502343, 45.88481587748374, 69.7151013343565, 2.4601571502224093, 0.15974600228571123, 0.11874282387115302, 0.12905578459462813, 0.1023033737475353, 0.047187373387597265, 0.0545371787983083, 0.03361849685109431, 0.021167310037379785, 0.24590834013877377, 0.264536319600959, 0.11883151387014698, 0.25072660417326037, 0.23639366601503667, 0.2127740414993417, 0.37237287829479865, 0.3310321692016817, 1.627371527494923, 57.82622868014921, 75.63809210254301, 50.26624064291678, 46.85056224946053, 77.71054698574927, 68.75987868155204, 67.19826544484785, 82.86941297592656, 66.12374782562256, 0.9254877161114448, 0.6275371846652801, 12.299332022666933, 65.77867338734289, 67.68750267644083, 71.989056218055, 75.60416360055247, 83.08246043420608, 76.53302792579898, 80.6829426365514, 74.99461943103422, 77.00536758668962, 79.26615115134948, 71.51392382960167, 68.50530901262837, 58.680701332707564, 54.92503189271497, 56.534529424482784, 57.70828693143783, 56.07679667011384, 57.26239189024895, 55.20491653873075, 54.45424941278274, 52.23740423879316, 53.8009080579204, 55.86425127521638, 52.541148662567146, 50.102724875173266, 46.95723895103701, 53.64129897086851, 57.07903285180369, 56.3921630767084, 58.25953683545513, 53.63122632426601, 52.60356141674904, 58.17679051429995, 56.84483597355505, 59.961276746565304, 57.64520737432665, 62.76727760991743, 68.5445091801305, 67.40837897023847, 65.28252493950629, 65.49775715797179, 60.90194740603047, 61.67623112278601, 61.82178635751048, 64.39284509228122, 64.42982519826582, 62.15340706609911, 60.24722929923766, 53.27136062806653, 45.06794698776738, 51.501732334013916, 47.765400178970836, 58.95147823518323, 52.497563285212365, 45.644908028264204, 50.0229242540175, 47.52425286077684, 49.04477142518567, 49.08296746592368, 52.23619614878009, 58.02165292924451, 56.963315086980025, 53.7708430905496, 53.129410051530414, 53.37764509262578, 48.57228271422848, 50.30527999324184, 54.38996961039882, 55.19089014299455, 46.80319178488947, 45.699017124791304, 49.02698347645421, 50.45740912037511, 56.6238300261959, 55.69826049189414, 62.3415788527458, 55.68956851959229, 50.635896575066354, 43.844269475629254, 49.758944819050456, 47.58057025171096, 43.27409413553054, 47.11730695539906, 45.446341960660874, 52.85250640684559, 41.952502496780895, 52.025278537504136, 62.50987206735919, 60.980496791101274, 58.45104655911846, 55.353080149619814, 58.58337948399206, 62.10786050365817, 62.5719004292642, 62.08848007263676, 62.57577965336462, 61.22672357866841, 63.43650456397765, 67.63639419309555, 62.05040562537409, 63.18416280131187, 63.197636142853774, 57.365624750814135, 47.18873331623693, 52.877711557572894, 55.72208889069096, 52.5239686812124, 48.593718467220185, 46.409931029042895, 46.804862714582875, 45.50200039340604, 49.97862892766153, 56.23770013932259, 53.76379066897977, 53.394923133234826, 53.19472143726965, 58.19196616449664, 52.74380968463037, 55.64148810602004, 56.297857530655406, 61.51438236236573, 57.31360627758888, 57.57611090137113, 58.062665231766246, 64.50383640104725, 67.41599621311312, 72.46365516416489, 72.2826377807125, 74.73490361244448, 69.82743017135128, 72.1066802547824, 68.313889503479, 78.47802931262602, 75.95385859089514, 90.76893314238518, 76.44666517934492, 78.86934065049695, 1.6447622136723612, 5.875247188152806, 94.77360248565675, 72.50627563845727, 70.76018548780873, 67.69322933689241, 45.28306545749788, 60.48460721969605, 81.18496679490613, 3.5944583098734584, 0.48037573935524114, 0.2973204088066855, 0.36075656452486593, 0.2190854568635264, 0.15992463866789497, 0.21167191676795485, 0.155214301100181, 0.16487299975368286], [0.006779430447251446, 0.05441983328050664, 0.08635792776101059, 0.018231582587524768, 0.041872205573224255, 0.04768204402118441, 0.02393529296011454, 0.057595857614350904, 0.1994947193851394, 12.183623083176153, 55.59658088991719, 32.03103384663982, 22.516440499213434, 45.489389973302046, 52.84043727382537, 54.58490748559275, 69.08739659094041, 62.43784558388495, 2.4578723695970353, 0.6332775734124646, 4.835664158867252, 35.71077208365164, 62.588750931524466, 72.4612154499177, 76.75868188181232, 70.55967392459993, 73.87795986667757, 70.52888331874725, 68.27286151147658, 69.62151358204504, 66.02918732550837, 62.31383592851701, 54.876849497518236, 51.14113315459221, 49.832450036079656, 50.421099739689986, 49.20121908187867, 48.9318738445159, 47.30176033512239, 48.898188529476045, 48.48949716937158, 46.29755120123587, 47.08376676805558, 50.91940941349153, 48.496110285482104, 45.09935340573711, 43.30384923565773, 44.38177539456276, 47.08120938270323, 51.59860703252977, 49.86663741450156, 48.524829879883804, 48.70101098091372, 49.167588680021225, 52.64694675322502, 52.60287892433905, 55.809353782284646, 56.987151330517186, 56.02793178250713, 59.03525221732355, 59.165965203315984, 60.04861224082209, 58.537930980805434, 55.39188415773454, 55.40270989941013, 57.77304526298278, 52.01793586054156, 54.58732758798907, 57.11679350945258, 61.35975860780286, 53.988511100892104, 52.51826555498185, 40.56808625498126, 41.34963420129592, 45.886620167763006, 42.64160017813406, 43.98599255469538, 42.67009227506576, 44.48851093169182, 44.057132582510675, 45.28348515110631, 50.500986652989546, 57.871124129141535, 53.96250970901982, 49.768680141818145, 46.35823811254194, 46.65289832699684, 45.77590342490904, 52.38762709402269, 53.36059847185689, 49.14745515392673, 43.209598602787146, 48.27100546129289, 48.49429815046249, 51.655842258084206, 53.84980432448849, 56.571485996246345, 48.82399297529652, 46.8697504843435, 43.27975019331902, 43.38544630235241, 41.454565448145715, 45.05457562784995, 41.31196375816099, 43.15070421464982, 35.7377815246582, 30.075928434248898, 34.96562373253607, 45.41952079342258, 55.407918806998964, 50.888320707505756, 58.70428262218353, 56.123202231622514, 59.113213246868504, 55.66227274556314, 57.76330994021509, 58.121159538145996, 59.84239362901258, 57.639661142902995, 60.57674369504375, 58.472070463242076, 58.5232142479189, 60.35887564382246, 58.60639595216321, 48.811613975032685, 46.69929212139499, 49.72122338510329, 46.19749546051026, 44.91668470444218, 40.69755977199924, 38.58427301529915, 42.73649015734273, 46.63682445403069, 47.628713423205966, 48.89384646569529, 47.37526162978142, 48.14609758315548, 50.392682167791556, 47.00418972199964, 48.14804307876095, 49.138743569774014, 48.85787048647481, 50.503893129287235, 49.71659891067013, 51.76162073689123, 54.08373448156542, 57.92769647413685, 63.776354405187796, 63.64732019362911, 64.74403058328937, 60.01545252338533, 64.82460391136908, 63.462333371562345, 70.810587944523, 71.50352954864502, 77.4718786055042, 69.84963863126694, 76.24592611866613, 1.8503916119375539, 5.649160790827967, 85.34180056664252, 56.2567275570285, 53.22392348320254, 45.32406991527927, 43.075783021988414, 39.8227810090588, 63.098247205057454, 1.9748042908407029, 0.2425591722731629, 0.010572629098239686, 0.10434519724860307, 0.08266446466046957, 0.060234306560408686, 0.017845907113364628, 0.1178419044721992, 0.016127309514089458, 0.019470174391303333, 0.02171617373073053, 0.00787335324979898, 0.059339408612539696, 0.04730171967117537, 0.050191177325623657, 0.05764122151078717, 0.04187792058913939, 0.3663864833933692, 12.590129683094641, 74.2200376141456, 32.617004571422456, 31.982525894718787, 63.28856845055858, 56.83085664626091, 59.91571841701385, 77.64287825553649, 69.61293928084835, 2.519915685538323, 0.693186323248571, 5.7527064604143945, 44.59303817441387, 66.90635481188374, 75.2876518618676, 79.84378291714577, 75.61745259069627, 77.8194555159538, 74.94984165314706, 72.96311409242692, 73.97541507597893, 71.69727894567674, 67.49193329964915, 57.47682394519929, 54.308596118803955, 52.93178143039827, 55.892837509032226, 53.75869551012593, 52.34876032798521, 50.697454252550685, 51.551797466893355, 50.40688507018551, 49.803961861518125, 51.31545505216045, 53.24782248466246, 50.70873498916627, 47.90438152128651, 45.59987137394567, 49.30851551794237, 49.08226536166284, 55.13847551038189, 53.50261965105611, 51.34952868184736, 49.50675210645122, 50.212284518826394, 52.76089552910098, 55.945985624867106, 58.37558407937327, 60.5231523513794, 58.32854701626686, 62.5925007174092, 64.30489770827755, 62.61395608225177, 60.34495907445108, 60.235422965018984, 58.89362719751174, 59.64898940055602, 54.47822293927593, 56.784639358520515, 62.528103243920114, 62.79214151443974, 59.62951875502064, 52.782350893943544, 45.26587763140279, 47.96256203805247, 47.78760471651631, 45.07268128856536, 47.10242156059512, 44.59417566176384, 48.34907239483249, 46.083676122849994, 49.05553048656833, 52.864606918827185, 58.88314662441131, 55.9036946296692, 54.17176423534271, 46.89500270351287, 49.38007131699593, 49.257563929403986, 53.85681752235659, 55.459956892075084, 51.12093294820478, 45.92187835324196, 50.27131226754958, 51.1203642045298, 53.82193588441419, 55.083891807063935, 55.239813866153845, 50.38605728457051, 48.895842952113, 45.729254676449685, 43.89860214725618, 45.034544083379934, 46.86460825704759, 42.48086929321289, 45.717754287104455, 38.01905555109824, 33.268594588002856, 36.49527357470605, 43.47870849793957, 56.351221376849765, 54.047809493157175, 61.22775908439391, 57.754100215050485, 61.77578480012956, 57.06231963249945, 60.63005655042587, 59.048635344351496, 60.1091383349511, 60.548447716620664, 64.06668040060228, 60.58150545243294, 60.66296915854178, 62.173799468624985, 62.18928106369511, 51.29013615269815, 50.26513061215801, 52.07362959461828, 49.46360995692592, 46.874159228417184, 44.477947988817775, 42.42319868456933, 46.896195104045255, 48.72547480367845, 51.011443907214755, 52.28622205795781, 51.9850742432379, 51.86373179958713, 53.39655483922651, 51.326790701958444, 53.55326921709123, 51.567914485931404, 52.747865415388546, 54.06277725773474, 54.90285088939052, 54.42254881705008, 58.88359377461096, 61.0636471163842, 68.0813164864817, 65.94618212792182, 70.58562432565998, 63.7038964609946, 70.00172461232832, 66.24718481494536, 74.95064966140255, 73.56887709709906, 81.33228317383798, 73.8004538320726, 85.1682984444403, 1.8557829097394023, 6.651413152294775, 93.62117090532857, 60.85228235490861, 59.30302066187705, 54.1368825974003, 44.73731471646217, 43.79174893902194, 72.64613951406172, 2.71451206937913, 0.13249104542116966, 0.021304447436705235, 0.1253702351823449, 0.01145225029528862, 0.023804849254027493, 0.04041848478898887, 0.0620254124664972, 0.019028066965420882, 0.1366927772159538, 0.20021239055260537, 0.15875805529855913, 0.167245558733421, 0.15146756424538552, 0.14290009655298727, 0.23546633190445362, 0.20473712033802466, 0.7851741162519302, 25.010365824545584, 86.0511298333445, 50.14041100778888, 36.271694552513864, 60.81661232056157, 69.78266808294481, 66.78040750565069, 84.97563162157613, 72.85597847354028, 3.153770460236457, 0.7959944646685355, 7.440106676470849, 49.003100164474986, 66.55892695150068, 76.25733237112723, 81.27940962391516, 76.30658949575117, 78.28084391932335, 76.55892341367661, 74.96187548483573, 75.74987965245401, 72.13808275038197, 67.96344141806325, 59.670272181111, 56.69358153497019, 54.26290050629647, 60.17654426636235, 57.10746611318281, 55.96011400222779, 53.15801197482694, 55.05290116033247, 51.77146588602374, 51.95161250329787, 54.00520863071565, 57.070191829435295, 53.81385972422939, 53.46109744041197, 48.851473100723766, 49.576193747981904, 50.95416161321825, 58.78420483681464, 55.53090080138176, 52.27128567234163, 52.498900813441125, 52.4453055474066, 55.66316704596243, 58.65495881726665, 59.48896846463604, 61.52164266955469, 60.10278801764212, 63.79077303794123, 67.88519013312556, 66.24253288392099, 64.42452999853319, 60.930776826797, 59.7362542921497, 61.493017212037124, 57.5916434872535, 57.75470033768685, 62.36350490200905, 61.82273949346235, 58.22726357367731, 53.2668028339263, 44.82666238661736, 45.99602683897942, 48.81190815279561, 48.84945308008502, 49.183293850191184, 48.24602388566541, 50.50809791011196, 48.758179526175226, 52.02795751633183, 57.25721828399166, 63.15559617934689, 58.44124455605784, 55.67873493317635, 51.31580022073562, 52.53854028640255, 52.15213583361719, 55.545695981671734, 59.54911801122851, 53.20076973207536, 47.81135859027986, 54.8336406677, 51.9664704415106, 57.55769929578228, 58.01841697385235, 59.89423559558008, 53.308917322466456, 51.66883314809492, 48.389315912800456, 47.649380391643895, 46.51568989599905, 50.411882169785045, 44.39746095288185, 48.10566186904908, 45.85473522063225, 37.681186506825114, 38.85351627103744, 44.63441133499146, 56.21338536662441, 57.64553293105095, 64.7782414959323, 60.88651287940241, 63.779347173629276, 59.93347106441375, 61.19525440277592, 64.11756923121791, 63.93154298105548, 62.173250336800855, 67.18274070370582, 63.78761552995252, 61.87511490237329, 63.795252384678015, 64.26031997126918, 52.64174176800636, 50.66549870275682, 54.42057978722357, 52.43654297244165, 48.912199235731556, 48.16622718687981, 45.21718532808366, 49.562708639329486, 50.837137699127204, 54.703543493824625, 54.74364580646638, 53.36992586812666, 53.614713145840554, 56.319807114139685, 51.978802373332364, 57.10580695059992, 54.748078084761104, 54.68006810834331, 56.80030138261857, 57.20718845244377, 57.1201628254306, 61.468345503653254, 64.34333693596625, 72.30143377857824, 67.18560403393161, 75.06872084832962, 67.24869143578314, 73.79155005178144, 69.5703580302577, 78.83385888991818, 76.76335734705772, 82.85214670242803, 75.53934251108478, 89.69006953700897, 2.477527121382375, 7.7114621285469305, 101.63422015405472, 67.44229178274831, 68.53029451062604, 61.10833075738723, 57.71705735114313, 57.29360218971007, 86.18063865169403, 3.310872172155688, 0.6529650524739297, 0.14525079138336644, 0.31034019565390003, 0.27886302180347905, 0.19102426906747205, 0.10298916033559269, 0.3028823909980636, 0.13764643410761512], [0.006368851369892758, 0.02345621030056669, 0.023963136425722512, 0.06795283391951554, 0.12700112912082864, 0.042594546046588695, 0.05835995754046787, 0.07179235168282064, 0.18097288906574252, 1.3362197505850948, 53.699271602015344, 50.60660823698967, 22.77639558238368, 32.03308720742503, 60.060649994880926, 50.998343190839215, 70.12378877209079, 63.24514389038087, 3.4889651834964757, 0.8291099941538227, 6.175513940472757, 56.33779118137976, 70.62843307372063, 75.47598838806152, 72.69868358489006, 73.19676968359178, 73.62104462039086, 71.4095260250953, 67.01366301505797, 68.40519443635019, 65.29490001739995, 58.559303975874386, 48.29956423851752, 51.74761395300589, 48.139186366911865, 48.193099344930346, 46.34387047060075, 47.83025264739991, 48.759571967586396, 47.86773089439639, 47.30821655642602, 47.713668038768155, 47.56803435664023, 48.527806958844586, 47.59616951788626, 45.62528833266228, 44.236714378479995, 42.71862376120783, 46.953085161024525, 49.68738509762672, 52.99439422545895, 49.648663459285615, 47.31439428944742, 47.99533736321234, 48.01871861180952, 54.088072622976, 59.09953986444781, 57.36848415866975, 60.16152551097255, 59.17981117002426, 57.82031766829952, 59.25754077972905, 57.98742632712088, 58.65722594722625, 56.75553144947175, 55.9617692424405, 52.65113976693923, 59.82213458707256, 62.00638878730036, 65.95479565282022, 63.46077619060394, 51.84603406536964, 49.38417411619618, 43.72338202691848, 48.31333568019252, 41.652405877267164, 43.058956053949174, 44.12231845240439, 43.46072443069951, 44.03428085388676, 49.46369624906971, 52.791795961318485, 53.355169911538404, 55.19061165471231, 54.715632238695704, 47.878023193728545, 48.58557954911263, 51.27729039038382, 53.93059338292768, 52.830341093001834, 53.9934415201987, 50.18511426064276, 49.60270504797659, 52.79229410233037, 54.37198946552893, 55.11272907257081, 56.73683351086032, 50.1437803237669, 45.96593049264724, 42.77153653483237, 39.65739034837292, 40.178053609786495, 41.64950724570982, 40.397922069795676, 42.4094311652645, 36.62557078946021, 33.38173927799348, 43.76974836472542, 50.97779389350645, 46.27229113732615, 50.14883625891901, 55.35677894469231, 55.45600706531156, 54.543836347518436, 58.36408369002804, 58.920899437319854, 58.622563962013494, 59.29209293857698, 58.690597472652314, 59.711680643020145, 58.041021593155406, 58.6654511574776, 59.996130927916504, 57.65250690521733, 52.20659402108962, 47.752283773114605, 48.21009497488699, 46.01528959889566, 45.891950668827185, 41.0095529402456, 40.80809216345511, 42.42772117737801, 43.682883554889315, 47.597444288192264, 46.226654360371256, 46.382548962869954, 46.89458300990444, 49.742596380172245, 50.19881509965467, 47.66275175156132, 49.30295359703803, 50.0793985397585, 50.997393977257516, 52.28638287513487, 52.51482563634073, 53.0636279813705, 55.67961354409495, 63.30303807412425, 62.14066720777943, 63.10251474380494, 60.79762804892756, 64.24537574091266, 63.72862308256088, 70.78241748194542, 69.38432001298474, 80.1943878973684, 70.898770670737, 81.34099868036087, 2.2889233837204594, 7.592498602405672, 86.03305555159046, 51.87248652981174, 55.75637432836718, 49.06763884329027, 35.015822226001376, 44.36448166447301, 63.943992583982414, 2.4694389489389237, 0.19169747649181276, 0.028853010528931217, 0.0598656075946506, 0.013055940451581153, 0.013117282069288196, 0.06906261186926596, 0.023613198953230056, 0.05618112687502177, 0.0361833170867495, 0.023554733038068782, 0.056233056144969124, 0.04203549338384502, 0.05306703308897634, 0.03010072260944834, 0.03871188987226736, 0.12363071763707746, 0.19194919766197283, 1.0728769653266477, 65.16231606083532, 52.323700304954286, 19.772399356288297, 44.23446293800108, 67.77800744579685, 57.78482806298041, 77.83670609997165, 70.15720736595893, 4.1493587147805, 1.1753520730041689, 9.570848961030284, 67.23709690955378, 78.52880831687682, 77.68505942436957, 77.65260573356383, 77.12980870277651, 75.63506403276998, 74.16671691402313, 71.55701498831473, 73.41353554879466, 70.09214308954054, 61.43640956571026, 54.03641893017677, 53.85344036163823, 52.908521775276434, 51.70899821865944, 51.961900880259854, 52.42965921278923, 52.87460111802625, 52.413624563524806, 50.65934842632663, 49.083920601875555, 51.09977568349531, 52.00218362192954, 53.20037357268795, 48.76221564508254, 47.783325410658314, 45.991061118341264, 48.79227669008317, 53.11956098002773, 56.88689554891279, 50.74040028356737, 48.635683905693796, 50.21283757302069, 49.281827711289935, 56.97096370881604, 60.94183791068293, 62.38794911292292, 63.77676233168572, 62.24528466501544, 62.50904052488266, 60.32107184010168, 61.22959867600472, 61.53772046489101, 59.12311330918343, 57.82777017162692, 56.1303880137782, 61.87214566815285, 63.239660416879964, 68.63478645201653, 64.74295977623233, 53.86315607255506, 50.25300656595538, 49.442566440951445, 51.82788918095251, 43.24258965830649, 47.06923830893732, 46.57337227175313, 48.31169220709032, 46.83487669114144, 51.781977838085545, 56.692487193692116, 57.07442798922139, 59.763773641278675, 55.818445836344075, 51.33280761780278, 51.66866448617751, 52.66125555961363, 55.8107776026572, 54.808160951060636, 57.060299611860714, 51.97126357786117, 52.05955613044001, 57.60115915729154, 56.63734259143953, 56.363823952213416, 56.04002052737821, 52.17866282309256, 47.31641431008616, 45.86700047216108, 41.9483212501772, 43.431722425645404, 44.20752409965762, 42.6348929251394, 44.241205492327296, 38.30127008499638, 34.840468745077814, 42.41800154409101, 52.86266142322172, 50.10206199461415, 51.88020183194069, 54.98036476873583, 59.29623888384912, 58.23158602560721, 58.874187930937744, 61.92509374310894, 62.51474757348338, 61.86275159159015, 60.33352536539878, 62.057724768115634, 61.63408525528447, 61.6592158809785, 61.64768411267189, 60.91120419963714, 51.32778306161204, 49.488654290476155, 53.82708987882061, 49.434270628037, 48.62353632527013, 44.67405473032306, 42.43949221026513, 46.488374510119044, 46.04020057186004, 49.76757403342955, 50.20826408939977, 51.021622457811915, 50.52517590984222, 54.38627081532633, 52.488651660180864, 51.274376069345784, 53.920320695446385, 54.60747680356426, 54.08189881232477, 54.117004025367, 56.063350785163145, 55.85583386882659, 59.77029262050506, 66.64319515228271, 64.81428415544572, 68.05353041618102, 64.29793942359187, 68.10113230059224, 64.8288243816745, 76.29502634848319, 74.69771169847058, 85.94135838170206, 72.23251773465064, 85.34289883029076, 2.3711519520128927, 9.032661530279345, 91.64453168069163, 55.815896295732074, 64.00601310114708, 57.87299117734356, 42.892133728150405, 48.72975803190663, 75.03312141664567, 1.5528685575531376, 0.14460003033520716, 0.03591890567012372, 0.008740789339607282, 0.034924596322760466, 0.018342240157747464, 0.034162296703265566, 0.01575769028521233, 0.04633159955002127, 0.12658049322424397, 0.125328085024751, 0.15382340718661586, 0.13777820123059137, 0.3101111353645402, 0.12203948407043373, 0.2764901717103297, 0.2896630229248155, 0.5575006298961178, 4.2395938211871735, 77.37861248754686, 64.94951571187666, 35.95972884085871, 40.72608324789232, 82.32566264367874, 61.729951904666045, 83.83019754963537, 75.65825308522871, 5.198306402852459, 1.373173503145095, 11.309623891307462, 70.58303556134625, 79.35603618621826, 80.77599694651943, 79.47264825144123, 77.45278450750536, 76.83838444371378, 76.71331574839931, 72.9105229531565, 76.7500997358753, 72.23907593757876, 64.68615208902668, 55.96815878345121, 59.29829028344924, 55.88225887667749, 54.84366232349027, 53.60112997793383, 54.618059358289166, 54.069821834564216, 55.45868212176908, 53.24246452700708, 52.81708740418958, 52.32797568844211, 54.873444880208666, 54.90973857141311, 51.95106337147375, 50.955055913617535, 47.29212307160901, 52.44230493422478, 56.300807153024984, 59.315254534444506, 53.995049691969356, 50.879589511502175, 49.83661167083248, 50.88266464971727, 59.406449640950854, 63.338445309669744, 61.30270381127635, 66.15288319126253, 63.9017290453757, 62.910408819875414, 63.96755426160751, 62.715812190886474, 64.57095599943592, 61.59815242213588, 61.82537532621815, 59.931643239913456, 64.1316113164348, 64.89743840309882, 70.81346696422946, 65.82553786616172, 56.99976567299136, 55.109814751532774, 48.50034644526821, 54.02250628317557, 45.170983729823945, 47.23844543580086, 48.35764669602918, 50.19897199446156, 49.598974873942716, 54.72164523216986, 58.846178285537235, 61.488416271824995, 61.33086250674341, 60.14637339499689, 53.57288106795281, 54.009244749622965, 54.84919678780341, 58.98360636926467, 57.0268770956224, 60.88191586156046, 54.98329477925455, 54.70075468863211, 59.47234938221594, 61.40977274987006, 60.778910498465265, 61.818217000653675, 55.95268503312142, 49.974078978261645, 46.09093643003895, 44.73968775041642, 44.285496896313084, 47.10944260320356, 43.738953836502574, 46.375845632245465, 41.95282805350519, 38.318987431064734, 41.28441695244082, 53.275655623405214, 52.866587715764204, 53.79411843515212, 61.10301594580374, 59.907987425404215, 59.4859835409349, 61.54971899524812, 61.67899247138732, 62.964729724391816, 64.38883250759494, 63.43635943628127, 65.46121243507632, 64.26522293398457, 65.32367844735423, 63.460352574625325, 62.27042705781999, 53.60125549377934, 49.551192560503566, 52.18587998420962, 51.39020758290445, 52.68533891247165, 48.92693558046895, 46.722065402615456, 48.88569578047722, 48.15233807409964, 52.69898483830114, 52.04079151153565, 52.40755273449806, 52.637317334451986, 57.34919001979213, 56.03561962804487, 54.180785686739036, 55.38489449408747, 58.92477866142028, 57.083080737821525, 57.72611802624118, 57.55769929578228, 58.440499305725105, 62.43753571664134, 71.03654000066942, 67.23112706215151, 70.64824104309082, 68.01469110673474, 72.85834758512436, 68.29247336233816, 79.82752861515169, 75.9705678878292, 92.26101844541489, 75.08635582462435, 90.0835930916571, 3.4793467963895495, 9.491722987544152, 100.62158184666788, 63.32315198836788, 74.0073117902202, 65.14208055311634, 51.94616433112852, 60.804943269298924, 88.36647356710127, 4.011264563568177, 0.38360997854221257, 0.14756791624090365, 0.13910463650620755, 0.10057130257689184, 0.1455015932480174, 0.11567659525861664, 0.13096095333176275, 0.1270314202373547], [0.019615200581029058, 0.03573218322989922, 0.03546492962707435, 0.01444415593024103, 0.05744175136750264, 0.035035606293428334, 0.08720919700159181, 0.07016538011450922, 0.08210728891314038, 0.17651444120753199, 38.52694757523076, 60.49122818054692, 43.46381525839529, 23.69344376748608, 53.52551844812209, 47.721312738234, 63.493653497388294, 68.27719965288716, 5.909658141674535, 1.0511238680731867, 29.025205873673965, 80.00297623295938, 68.56544679211032, 73.81986171968522, 70.60935466520249, 71.03745783528974, 69.91836640142625, 70.06330582403368, 65.14789742808189, 66.33636382318312, 58.28977830948369, 52.05347253430275, 50.577770971482806, 49.055824664331254, 48.920612719751176, 47.49208942536385, 48.60739969438123, 48.05456515281431, 47.20628200038787, 46.97453268112675, 47.849605621830115, 49.7297937639298, 49.7872329527332, 49.08143381918631, 48.826766091008345, 46.9694963578255, 43.2565023053077, 44.603856071349114, 46.1432804599885, 47.889951121422556, 52.55071140104725, 51.2081939174283, 49.66640826194517, 46.6564598391133, 49.95512216321884, 55.04061629695278, 60.39893088802215, 60.26311097606536, 59.638602964339725, 60.352784202944854, 59.033322411198775, 56.80046612216581, 61.99244476133778, 60.99520567924746, 59.32448779383014, 52.81119992656093, 55.2360091670867, 62.376848805335264, 59.27619949463875, 62.54853879251788, 64.18854844185614, 50.78053789754068, 48.170710455986764, 41.19251581930345, 43.74407645194761, 40.966606909228915, 42.932338022416644, 42.80733992976528, 44.93733598339943, 42.601925403841086, 49.28270239983836, 53.7333099303707, 52.04252519915181, 54.34568997352354, 54.89986988805956, 51.76449583422754, 50.88108393453783, 51.790799248603086, 48.706141441099106, 47.1189308166504, 52.50118755525159, 54.66443354083646, 52.77383542829945, 53.30941154110817, 49.71140961493216, 53.09288886285598, 51.218925522219756, 51.06373694635207, 42.19312421737179, 43.87704480078913, 43.15661130412933, 41.48851356198711, 41.94430082075058, 39.55338478088379, 41.85686334486931, 36.86441567636306, 38.58526145258258, 46.15380025679066, 48.6834740638733, 51.879303609171224, 50.265495392584036, 52.622643747637355, 51.61861504277876, 55.92822121035669, 56.51394482581847, 58.96854446780298, 57.800419484415364, 58.94597907220164, 59.60532165342762, 60.85959365290981, 60.031608766125096, 58.5506159259427, 58.829688641332815, 59.227114954302394, 49.80777048295545, 51.01937101733301, 53.40708640313918, 44.60282841036397, 45.34927506600657, 41.942716183200965, 40.05577764203472, 44.44059133529664, 47.39938420634116, 47.55447472295454, 47.482844398867705, 47.742709267523985, 48.14107302696475, 46.81007946691206, 48.19449963108186, 48.80689536371539, 48.84649169060492, 48.05982112884522, 48.39385409508982, 50.85673778287826, 51.06391737538, 52.36340253583847, 53.162640371630275, 60.093566525367, 60.10540031617688, 62.4812936782837, 60.36888553250221, 63.18879904285554, 60.68548356333087, 70.34673629268524, 70.36487333236202, 79.84914871954149, 73.1080613597747, 83.54161308657739, 2.3108271245033514, 9.528979620625897, 84.03561992029991, 47.73646485420966, 55.84460020065308, 48.115369735225556, 36.09082229675786, 45.90657718719975, 53.93186030849334, 1.044889750980562, 0.039382668797888105, 0.03629932195068367, 0.05154708783412653, 0.036161958555420565, 0.010719243005188483, 0.04979534735602718, 0.05605437762794956, 0.05969360170345153, 0.044862101184985334, 0.025974278105422858, 0.04965104320417008, 0.043671186863174366, 0.03731613130038304, 0.03097638600475846, 0.061886137681863004, 0.05357797926051482, 0.08305007501715615, 0.03496117702114486, 44.552700519561775, 67.45837350045481, 27.186147705201183, 29.867058300202896, 62.779240838943, 54.765375737221014, 73.21271019597208, 73.35766530806019, 7.4842505012789085, 1.363965861739651, 37.93540316243326, 86.36113043754332, 74.13813068020728, 77.77568970957111, 76.22251741347775, 74.5482458606843, 74.13878963839623, 71.50505927301222, 70.4097766260947, 68.27019429975941, 62.34108855647426, 55.64213529709847, 54.3943783544725, 52.11060185586253, 52.791160537350564, 50.59370756149293, 53.99613226613691, 53.17705900438371, 51.31146600169521, 50.186949929883404, 52.798926830291755, 51.2722776013036, 53.80563451397804, 52.61275545243294, 50.948117240782715, 49.71433178071053, 46.58642199731643, 46.636275322206565, 49.30298889836958, 50.796290136152706, 54.961910017075084, 53.18960666656495, 52.82336319646528, 49.11758238269437, 51.644145750230365, 57.6862039873677, 62.67212090953704, 62.0354417831667, 63.40418815612794, 64.11527072229694, 62.18861426076582, 58.78582869806598, 62.43218168135613, 61.376287475709, 61.87809982607442, 57.88042799119027, 59.90237451368763, 63.4323311621143, 60.41930760106733, 62.88135582400907, 65.54934024810791, 54.14637081084713, 49.65539032413114, 48.85023363174931, 49.1508872278275, 42.82548481418241, 46.43258271678802, 44.14142823988392, 46.3126640935098, 44.447518241020944, 49.705675109740234, 56.68672130953882, 55.514634732277166, 57.74008950879497, 56.35521042731501, 55.528523845057336, 55.20477925577472, 54.49846236936508, 49.962507986253314, 47.28035988346223, 56.951155739445845, 56.48406028747559, 55.014822790699625, 57.55994289152084, 53.537262024418006, 54.16553551150907, 54.86136005770776, 54.04915094375611, 45.60100493892547, 45.66445319883285, 44.04136073204779, 43.44228536851945, 44.59466203566521, 41.029898274329405, 43.79402391372189, 41.725840491633264, 40.04095892752371, 46.917144483135594, 49.709613169393236, 56.31528854370118, 54.46579687057003, 54.097509845610595, 50.54511723979827, 57.24812622993224, 59.86490803380167, 60.305131327721384, 60.51303263633483, 62.11281445718581, 60.52814945097893, 61.20872774431783, 60.61539473072175, 60.4445323636455, 60.591821285986136, 62.667782768126465, 52.66954745015791, 54.43468463036322, 56.68212036932669, 49.210126784539995, 48.36976681986163, 44.353153859415364, 44.51062917709351, 48.41439554768224, 50.68120779529695, 50.421656716254454, 49.35800406240648, 50.09442906225882, 53.18465271303731, 52.233705443720666, 51.35616533217892, 52.554257223683024, 52.806724502194314, 54.591779478134654, 52.07351192351311, 55.371044605009025, 53.86301486722885, 57.653314913472826, 56.71959861632317, 63.3228656553453, 63.21485142554007, 65.49872206103417, 63.75141989800238, 66.32614997125441, 64.4620906153033, 75.1024296975905, 73.03746654141334, 85.48989357486849, 77.23473210488596, 87.84490031580772, 2.573288847361842, 11.73003529348681, 93.14593653525077, 53.298275932188965, 63.58762171960647, 57.42897495146721, 42.420598153145086, 50.85321157209335, 60.467235042202866, 0.5719331135192226, 0.03494070715180809, 0.026396256571094838, 0.06637229494029476, 0.12684738293530481, 0.07920222221723489, 0.012063881487495477, 0.0400467291324129, 0.010825108695444802, 0.050730327024094524, 0.09719513777282932, 0.1698443128336822, 0.10707522051468973, 0.2075410787496836, 0.1346002999813326, 0.2717140425116785, 0.10572420913846263, 0.25197233974693284, 0.24338211924318345, 61.28812436134585, 74.70328930885562, 60.36143302917481, 32.99778238419564, 71.39659789300734, 60.83941305837324, 75.71726122210103, 78.40688536244055, 7.628999198636702, 1.4850755372355062, 37.34887938345633, 87.6572698162448, 77.38360174240606, 79.11111554791852, 78.73941606090915, 77.30451107025146, 76.58226151620188, 76.21234278525077, 73.16165662580921, 71.01175062118038, 65.80668695511358, 58.48388856457126, 58.79758796384258, 54.61248959264448, 56.95339541281424, 54.3761864016133, 56.33999555341659, 55.22799968719483, 53.84224983953661, 52.726904269187685, 56.11138413029333, 54.684559222190614, 57.45261899886593, 54.68063292964813, 53.61994166528025, 50.97513060415945, 50.62823226374965, 51.30426845242901, 52.46811412995862, 51.77996566218715, 57.62880794463619, 54.304210908951305, 54.923490401237245, 49.57933948886011, 53.991719599693056, 60.15842683853642, 66.09374169380435, 64.02161236732238, 65.15205121809437, 67.14319536762854, 63.86605508865849, 63.05352434035271, 65.1089051461989, 65.84650685710292, 62.09775647809429, 59.19486914911578, 60.84453959618846, 66.99412961159983, 62.545765676806056, 65.3343669060738, 69.91549522646012, 56.78281153402021, 52.38276335500902, 48.0480069498862, 49.784440225170506, 45.34546252219908, 49.753065186162154, 46.34385478112006, 47.34538493617889, 49.59823746835032, 52.115485206727065, 60.735838951603064, 57.34132958996681, 62.750525166911466, 61.60078041015133, 59.30933175548431, 57.852865495989406, 56.36727956033523, 50.82090300898398, 49.01698535488498, 62.00481591686126, 61.93095376414638, 59.57619805489818, 60.06862417344124, 57.03727922131939, 59.92600679397584, 58.29435571547478, 57.032576299482784, 48.43516842011483, 49.29080601661436, 46.684983315006384, 45.87087577389133, 47.72779249375867, 42.02305809144051, 46.8217485181747, 43.69328175821612, 40.07799394669072, 46.85067599819553, 54.62377425163023, 55.278111888516335, 57.066610705467966, 55.49176731417256, 54.34590178151285, 59.98018257079586, 60.360483815593106, 62.63172834150253, 63.34320706705894, 62.267897129058845, 63.49410456995811, 64.2961508227933, 63.943474831119666, 62.64781005920903, 62.377574443817146, 63.006248012665786, 52.765378798207934, 55.41248836824971, 58.81665460525021, 52.89556618659727, 52.76173099394768, 47.70704707791729, 46.55336818387432, 52.414640457399436, 53.06032926805558, 52.56709906362718, 51.96422292340187, 53.9779128566865, 55.43736403988254, 53.862732456576445, 53.87041245737384, 54.45532021983978, 55.41422205586588, 56.283956650764715, 54.19418842561784, 58.21100927168324, 56.3003090120131, 59.205934155371885, 58.05440472018335, 66.98160156126946, 65.77809679892756, 67.68911869295182, 68.2346184022965, 71.3902436533282, 66.52731264791181, 79.15161794231784, 76.3875001476657, 90.8699655532837, 79.3358281350905, 94.45678480209844, 3.253357477726475, 11.95451646081863, 99.55447750706827, 61.810199676021455, 72.40529029600083, 63.6756161720522, 52.53249591396701, 65.84222362887475, 79.325072996078, 1.5837433717904554, 0.2592964314164654, 0.06272080579712506, 0.10326973237698117, 0.20458574136418683, 0.18356286379839146, 0.1960277118750157, 0.16261828041845755, 0.12304495148841413], [0.03904701503474386, 0.009337491393389722, 0.06923600054916836, 0.031329385913728226, 0.0711904593833512, 0.00799720955734712, 0.10676235020641359, 0.18153257758146335, 0.056307381995382814, 0.2584885457350362, 17.943870790543095, 69.26260886653778, 51.30652773764826, 30.79913308543544, 48.15153006584414, 50.634935594374134, 50.59316235203897, 76.56275949170514, 8.608496419845089, 0.12059377656588632, 64.21347902667138, 74.11975829832016, 71.7892663709579, 71.11548162275746, 69.89695026028541, 70.4894870327365, 67.52436345623386, 65.16719548932969, 64.27435028937556, 58.52196301183393, 53.16853569399927, 49.736857952610144, 50.75679579088765, 48.364287268730905, 48.75894438835883, 46.11276834241806, 47.26586672567552, 46.95233991069179, 48.44058129095262, 49.72570273184007, 50.81330930033038, 49.45333334707445, 48.7418467767777, 47.06857150600803, 48.08040180513936, 48.488849978293146, 45.94193735430318, 42.725746785440755, 45.889295224220525, 47.638946886985536, 51.26293843792331, 51.48851394653321, 48.836960331086196, 50.25774478912354, 46.33693179776592, 54.657836114206624, 59.38308015946419, 57.816658096928755, 58.13817870232367, 55.70655630480859, 58.034926229907626, 58.410049946077415, 59.12876152223157, 60.94907076128068, 60.57798316401821, 54.39817128642913, 58.64140310595113, 59.458628931353175, 62.75196467676471, 62.279432819735625, 64.92335742519748, 49.995451973330596, 46.41872498296922, 42.62065079904372, 43.36304564629832, 43.24093834046395, 41.43838959355509, 42.21175547569029, 38.535619935681744, 44.586272085866625, 45.67721659137357, 49.07278107058618, 53.21934999958162, 53.21971085763747, 53.946435836053666, 50.29144971601425, 53.62570754943356, 48.591984779604026, 46.524283809046594, 44.66435078651675, 45.58797874758321, 52.12305930352981, 49.50403782629198, 53.38276770807082, 49.980747007554584, 51.40489685919977, 50.26225943719187, 49.6764926756582, 44.37909641573506, 42.43589147444695, 41.90919168533818, 42.58200760810606, 39.70742802466116, 41.727617325321326, 42.29392520843014, 40.89562377622051, 44.46529442264188, 51.18485973727319, 60.045031116854766, 60.82261354692521, 53.94586317000851, 53.71140349295832, 46.935108938524806, 49.9824297043585, 59.13373508761006, 57.61549149790118, 57.738952021445, 60.51175002128848, 60.08834585066765, 62.33470293783373, 56.14112354093983, 58.61354643298734, 57.60929023065875, 62.669190899018325, 47.96271501048919, 50.33461932213076, 50.75747043855729, 47.22417977548415, 45.00847601121472, 40.058033004883804, 42.326394588716575, 45.15094826298375, 47.60004481961651, 46.71687218450731, 47.724862483239946, 47.840639083616196, 49.964680979328776, 49.90997568253548, 49.73130779881632, 47.97731407227055, 51.11455909667477, 50.52613296816426, 50.395325845287694, 51.14409454407231, 51.35610257425616, 54.66493952658869, 53.74781093289776, 57.59361643945017, 60.15241384506226, 58.94414732533117, 59.09902603395524, 61.76012669840167, 62.59770570262786, 70.74167974533574, 68.39899709147792, 80.08551074612527, 75.36977060379522, 82.32078321518438, 2.238927137467169, 17.88451748509561, 80.5023096453759, 42.90751334159605, 48.40331877431562, 39.8068993322311, 33.81700469601539, 52.509597116901034, 39.925907965629335, 0.1340496359813598, 0.046517153706161246, 0.07504783465617126, 0.0158043067354048, 0.03377308956377449, 0.013556465912129612, 0.02183997736973388, 0.013785828806219563, 0.08165357333998527, 0.08575973566621543, 0.06635790780907677, 0.07150748188817693, 0.030280222755766688, 0.09741686660075381, 0.01545104539893087, 0.052791061405573166, 0.10392901232285846, 0.06491570898722257, 0.5460847553706939, 16.80952525907947, 80.82949023092948, 45.60284453053629, 35.694878639713416, 58.857980697385734, 51.66758191200995, 57.30649502046647, 84.22328964356454, 9.48346051477617, 0.20555916332429458, 73.10916746816328, 77.18286268172726, 80.16304031495126, 75.06894834579961, 75.53020338858329, 74.46856683300388, 71.17115574498331, 66.20836903972011, 69.15626556642594, 61.59430849936701, 55.59417255463139, 53.397900212195616, 54.836523609776656, 51.168421083881015, 52.91030645370484, 48.842596777023815, 51.46460317796277, 50.229856737198375, 52.137560306056855, 51.79832627696376, 54.707916936566754, 51.20879404006466, 52.06992687717561, 51.15333172582811, 51.438535105797556, 51.088016417718705, 48.355014785643554, 45.482494446539114, 48.486143542874245, 50.366621940366684, 52.86506191376717, 54.34201863504226, 50.68870736706642, 52.06570248450003, 49.257814961095015, 58.87156386529246, 61.39626802936677, 58.93748714077858, 62.500019073486335, 60.25690970882293, 62.931142468606275, 61.07486509507703, 61.612586744370006, 63.31165552139283, 63.80201455085509, 58.230699569948264, 60.923944057956824, 61.96658849716187, 63.77795080984793, 64.16419052308606, 67.30542459795552, 54.30748216567501, 48.65049477546446, 50.21314744026431, 50.357169028251406, 44.48692237177203, 44.48297254500851, 43.907521617028024, 41.87795392928585, 47.62245724278112, 48.964578567012666, 50.894137582471295, 56.37712078709757, 55.49803133933775, 56.39584225993003, 53.96713810582315, 57.603147798968905, 51.13133507390177, 47.21882181782877, 45.600012579271876, 46.779422221645234, 53.994735902355565, 53.496343858780406, 53.04419655953684, 55.700315813864435, 54.08653897623862, 53.379892610734515, 51.12812265273064, 44.661432543108546, 45.78960426392094, 42.36805015994657, 42.10366672085178, 43.140678636489376, 42.63415551954701, 44.540972632746545, 43.50905195359261, 43.38070807918426, 54.4222624840275, 61.335502670657256, 62.19085001176404, 57.32543222365841, 55.45563444014519, 48.49974240026167, 51.244566056036184, 59.83604723407377, 59.814160408512244, 60.25243820682649, 63.406580801933046, 62.157651070625555, 63.10264025965045, 57.91279146748205, 62.140125920695645, 59.20593807774206, 64.68533623603084, 50.565137017157774, 52.00307399995866, 55.54327587927542, 49.54808212095692, 47.03394089975665, 43.32710104603922, 45.57030062521658, 48.86887273480816, 50.71290446865944, 49.881730694924634, 51.20540903460596, 50.31132436567738, 52.517532071759625, 53.91382132807086, 51.39088615294426, 52.55583009412212, 53.56144735890051, 53.5003682105772, 54.26180616501839, 54.637635907819195, 54.82911817489132, 57.706784663661836, 57.92090685136857, 61.277153491973884, 62.44503528841081, 63.48369459952078, 62.85269114278979, 68.00657180047804, 65.56625350829094, 75.56628919416859, 72.51412822354224, 83.15109406748127, 77.61439400334513, 86.38067953048214, 2.7869388797590813, 21.787144407149285, 84.92049878643405, 49.670675800692656, 53.986192980120265, 46.916858150113015, 34.405870129985196, 61.5155629957876, 47.92625265736734, 0.03271184328402723, 0.01745840643472489, 0.034886805205455715, 0.035603855841702996, 0.08672545844268414, 0.06149692671193231, 0.037629499565809965, 0.0356638481870534, 0.0022775030294958985, 0.13363384942133583, 0.12914722484927024, 0.13485487099857102, 0.10461985509121612, 0.2822518577018092, 0.17241424670623196, 0.15991431180267565, 0.3487215990260724, 0.2170637661531087, 0.9231848558110576, 28.019810222810317, 88.2620208494125, 71.55613637739613, 42.33015221934165, 64.02277338889338, 66.97268209149762, 60.76475074214321, 90.64204446731075, 9.98935801367606, 0.4112439650681711, 75.8744933528285, 82.05392083814068, 81.58877480414607, 79.2411813428325, 78.46189268173711, 77.52071995888987, 72.9295229142712, 67.70035236112534, 71.94713392565328, 63.540470907765055, 60.708135251075994, 57.45735722203409, 58.43347041837631, 55.178542521692094, 57.36817429142614, 50.58061468985773, 52.19019459139917, 53.59289300057196, 55.34717306014031, 56.26692571947652, 56.46864537269839, 55.86266663766677, 54.950303723735196, 53.61992597579957, 53.968310894504675, 54.831142117900235, 51.7373255760439, 48.01457658890755, 52.69740804549187, 51.668425221597, 56.088399041083555, 57.22497247880506, 54.28425388951456, 55.566304114557084, 50.03007081247146, 60.75332487783125, 63.52110224385416, 61.96531372685587, 64.75800598821333, 61.02884784821541, 62.972362656747144, 63.08665267882809, 62.434966564178474, 65.96886127225815, 64.42673044819986, 59.870105174279985, 63.98544811433362, 64.86912281282487, 66.78720889552947, 69.49955924864739, 69.57854793917748, 55.84115243727162, 54.19216056023875, 49.971674565346014, 49.693660889902425, 49.87720427974578, 46.79805740233391, 45.757209408667784, 42.238804140398585, 52.139305760783536, 52.27527472280687, 54.867635849983465, 61.81600086150631, 60.24877863545572, 60.4240301347548, 59.32077330927695, 59.91287469863892, 51.465991697003766, 48.299572083257864, 47.89167696429838, 48.738485305540024, 57.240846310892415, 56.76329382004277, 60.61018190076275, 59.407857771842714, 60.294289896565104, 57.020667983639626, 55.08329952916792, 49.1758099679024, 46.179966388210175, 45.31484450063398, 46.35590430228941, 44.92751436848795, 44.807234887153875, 47.954309371209916, 43.59253960271036, 44.54960969186599, 56.27766909137849, 63.67317645780502, 63.93948578065442, 60.68561692391673, 58.99896244848929, 51.63142942613172, 52.854553884075536, 62.887459031997196, 61.208315895449736, 61.472797393798835, 65.47447396862891, 64.74735283082532, 67.6319383805798, 59.338537723787375, 65.00185581945604, 61.69061837657806, 68.90054272067162, 50.884151228012584, 54.29418533079086, 55.77334642410279, 53.46982863641555, 48.983029396303245, 45.76056695753529, 48.64797269144366, 52.90565452268047, 52.73901262590962, 52.175034630683164, 53.43994409807267, 53.40952611738636, 55.91437524364841, 57.26827544550742, 55.65942510481804, 54.1318109727675, 57.29367279237317, 56.908762762623454, 56.03717680900328, 57.357474065596065, 57.95303498545001, 62.76542232882593, 59.303934574127204, 64.3902131818956, 67.19884595563336, 68.70040770499938, 65.83320217747843, 70.6101312944966, 67.10602698787567, 78.43125112595098, 73.78586261503159, 88.68544855425435, 79.38454397263067, 90.64745733814856, 3.967754201542947, 21.72927179644185, 94.58646620473554, 55.81792416111116, 63.18810870570522, 53.7665912412828, 45.987672190512384, 71.40276385891822, 59.39103080380348, 0.2793934304387339, 0.07719031444961026, 0.1589063239554244, 0.11049503700867777, 0.3046304197801698, 0.1825184408094614, 0.14136248148016392, 0.11964435614044629, 0.15717570069095782], [0.04754945718412919, 0.013516195542779903, 0.04898019533063616, 0.03150057017562851, 0.0022674172425702697, 0.07419699442482765, 0.031550534430050084, 0.06556379638852612, 0.18910641391431132, 0.3310057851335695, 7.1514334697877215, 63.47947412921537, 40.708495340039654, 26.98395540637355, 36.10386809995098, 50.602379921943914, 37.23453837056314, 81.74885457561862, 8.67205548670984, 1.032892323790058, 80.0970111354705, 70.75257608967443, 74.14034289698448, 67.52135107594152, 70.25001848897627, 62.319707716664965, 63.883270371344786, 57.666686273390255, 56.98589617206205, 51.816745727292954, 51.592535203503026, 49.24523199758222, 48.53830322142571, 44.67513730449062, 48.2728881989756, 47.20377168347759, 49.60479959364861, 48.34752305861443, 48.28153702520555, 52.385599228643606, 55.029963139564764, 54.89047973386703, 51.24555449331961, 47.28553348971952, 47.944009227137414, 48.101963073976584, 45.300147379598315, 44.24917182614727, 43.86427748587824, 46.35608080894717, 48.281619394979174, 51.47464836797407, 47.85969395791331, 51.45815087902931, 47.08054650214411, 52.569927092521425, 60.81689865358415, 61.12447131064631, 58.670679676917295, 57.93119915070073, 60.527121789993785, 60.951165306952696, 60.30035780322168, 59.668718922522764, 58.74317684481221, 57.698888932504964, 57.8568192451231, 58.20412551203082, 58.16945568207772, 58.37514869628414, 60.49688031596523, 54.332718695363695, 49.116311534758545, 36.30410901961788, 42.428980258203325, 43.022387796832675, 39.06422991906443, 42.73132047345562, 41.261023936733125, 44.30823879857218, 45.66672032879245, 47.41682306412728, 50.508654886676425, 48.73885008596605, 52.150308009116884, 50.05718615747268, 48.88133410484561, 45.85085207416166, 45.66199387273481, 48.8820009077749, 41.69859178604619, 47.63222002214002, 52.81504777169997, 50.458719192012666, 45.4333040022081, 48.0483756526824, 46.8043488840903, 47.9499202389871, 42.632629717549975, 42.83243917649792, 42.938896225344756, 41.19780709666591, 40.2989096795359, 42.35889142559421, 42.82869723535354, 45.659138387249364, 51.06914197244952, 58.20539635996665, 62.147543122691495, 59.61240545395882, 53.172532589204856, 58.93481600669123, 53.659137910412205, 46.92206705770185, 58.610534052695, 58.88859871895083, 57.51260772828133, 60.285480253158084, 58.47893068867346, 61.12682865511987, 58.795818974894864, 55.68930572079074, 56.60866614310973, 58.301117881651855, 49.37033207185807, 48.18847487049718, 50.24007843386743, 44.28473987886983, 45.34801990755143, 40.37029681667205, 42.38599108111474, 44.80995701205346, 47.631176671674176, 46.907248343190844, 48.98056614783503, 50.97795863305369, 49.651605236914854, 50.26976685370169, 51.62711481894217, 50.06598011139901, 50.62818519530758, 49.380683206742816, 49.29234358572191, 52.371533609205684, 52.19400713520666, 49.91105825670304, 52.14278490312638, 55.94572674843573, 54.70023693576936, 59.18897382674679, 59.307056780784364, 63.75842917350031, 65.13072529146748, 69.15823459625244, 72.87665720908873, 78.43522056456536, 77.55697050402242, 74.2336953070856, 2.8666073660696707, 28.902757321634603, 67.9615665251209, 37.416689318995324, 40.03604812006797, 47.47895340765677, 53.09130030293619, 62.17215207315261, 37.59519638553743, 0.0210583359453707, 0.04308867658818922, 0.017624699225228642, 0.023782372234329104, 0.04561940591121393, 0.10445701544203105, 0.036064638575959596, 0.021117466441806287, 0.0636601674881193, 0.04686736697030645, 0.04163004134991958, 0.0290816992656478, 0.019407133016014294, 0.04290002743683515, 0.0785530010058034, 0.04177187869866048, 0.026238946161503275, 0.04125042180080087, 0.21525593654763317, 6.712911503930246, 71.49856382800688, 39.97510233233052, 30.63819431489514, 44.25510244984781, 55.00677408710603, 43.735333488833525, 92.54484899582403, 9.165897580885119, 1.407565825408505, 87.6662677334201, 74.98506453729446, 78.49499748599145, 71.568083916941, 74.42033736936509, 64.83640632321759, 68.71697579660724, 61.34829744215935, 59.50188482961347, 55.06846120280605, 57.29583009596794, 54.3739624177256, 54.141138369037265, 48.39398353330551, 51.892635745386926, 50.45857014194612, 52.154673607118674, 50.82320936264531, 52.39352241639168, 57.304690730187204, 57.46499407675959, 56.2410576881901, 54.714937979175204, 50.954036097372736, 51.27051253472605, 50.60626699078468, 49.298815496506236, 49.105203382430545, 47.72614117591612, 48.026175037507095, 52.18535438660653, 52.33362782386042, 53.108499896141794, 53.34221040048907, 49.85622352169406, 56.87851344385455, 62.28166464836367, 61.895538683860536, 60.494962276950965, 59.74022765313426, 62.62398950515255, 62.36217129615046, 62.87274622148084, 61.65512484888877, 60.85720100710469, 59.64745575381864, 58.946732167274725, 59.49459314346314, 60.31274857059602, 61.25807900582591, 60.48535639239896, 58.96583411001391, 51.0777162736462, 43.57801506596227, 50.260310019216234, 43.484996057325795, 44.987495253163004, 43.065714297756074, 43.32818362020677, 46.87471228261148, 45.653607845306404, 49.7689547077302, 53.62295404557259, 50.96301048032699, 54.052284917523785, 50.5291884945285, 49.20863236150434, 45.24559897761191, 43.35458509383663, 48.67217371540685, 43.259997137131236, 47.11128611718455, 55.80823590678554, 52.55660672341624, 49.26657361368979, 52.3603666213251, 48.59513836522257, 48.567615093723425, 44.286046028137214, 46.52878669000442, 43.31438472194057, 42.026690206220074, 42.77352909887991, 45.04727609695927, 43.798911186956595, 45.17017572156845, 53.4665338454708, 60.802872257847945, 61.932389351629446, 61.71766311891618, 58.66991873710387, 60.27187747340049, 55.9052949566995, 49.322141831920995, 60.16219623627202, 62.581196446572584, 58.574318808894006, 62.10337331218105, 60.2564468691426, 62.05901130553215, 60.80906175797986, 57.30594196627217, 60.620544802758005, 60.44829391664075, 50.74242814894646, 52.0065531423015, 52.06505921579177, 48.246565172749186, 48.01771448504541, 43.45564103895619, 45.984353865346606, 48.18860430871287, 50.02357928983627, 49.81272835885325, 51.57467665210847, 52.50039915884695, 52.92336010163831, 55.02833143357308, 54.16913232495708, 54.57285011968305, 52.579697716620664, 52.370254916529504, 52.98885583877564, 55.402407876906864, 56.08127601685063, 55.83929715618011, 55.69902535407774, 59.79079877176593, 59.37035206825503, 63.05747416711623, 66.19021631056263, 68.53446006774902, 71.27451804376417, 72.56698608398438, 77.05703304659936, 82.37844990145776, 81.58020050294938, 76.52887021341633, 3.485756684695521, 35.377594194104596, 73.24486578664472, 45.188202934880415, 47.61260817127843, 61.80337475192163, 50.444990896409564, 71.01708504461473, 44.75429465693813, 0.010332790909395104, 0.057264735261278774, 0.03993527483074896, 0.03690446629339168, 0.05935800156646198, 0.06038943553463586, 0.03557244240636787, 0.018743162696820595, 0.029382764159010786, 0.12335730851778101, 0.10596429343305289, 0.13476280255183098, 0.0981469483925931, 0.2153144656650482, 0.223993674942082, 0.11309186056736978, 0.3288850392545423, 0.35776067044465776, 0.7624524387140429, 12.349413825619607, 84.4319675814721, 52.915130969016786, 42.15596760472944, 49.97599701727591, 68.3626445647209, 46.15875028794812, 101.1029351142145, 10.022174523722741, 1.95029977348543, 89.8363817891767, 77.48161392827188, 80.5336493830527, 75.11304363127678, 79.44891006715837, 68.5908245271252, 71.77011735977666, 63.82488589132986, 62.61309316081386, 57.649518059146025, 61.83546366230134, 56.59146654990412, 54.53823912528254, 50.74183979342061, 55.089791051803104, 52.401041600012014, 55.575019621079974, 53.621553759421076, 54.242994477671964, 58.30920580894717, 60.847014611767186, 61.22131855257096, 57.308165950159875, 52.427458763122566, 54.88866367647725, 53.812553574962, 49.892226957505756, 50.019449034044825, 51.093131188423406, 51.807614449531805, 53.76647749254781, 55.66191973224763, 53.89479783273513, 56.887366233333466, 47.94182054458126, 58.68871865733978, 65.07807139427432, 66.84194164891397, 64.89404947526994, 61.07141340932539, 66.287216524924, 63.67254887857745, 65.08400594034504, 64.83834005171254, 62.527765920085294, 63.006287236367505, 61.58115286980907, 62.21693769578011, 62.993947459805405, 63.558960960757354, 62.61911792139854, 60.267951180858, 55.71129845034692, 44.70226833897252, 47.654408870204804, 45.00507923864549, 45.10273056645548, 45.61822414398194, 45.337817822733236, 50.578759408766224, 50.57910457734139, 53.17359162915138, 57.646376240638, 55.98557410701629, 59.525273922950994, 55.216354170153224, 51.998449525525494, 45.96857417014338, 45.051174932910556, 48.340682445033906, 44.13478766718219, 50.575762717954575, 59.77491317256805, 58.36263241306428, 54.531292607707364, 59.550765406700876, 52.82516356437437, 53.98887195894795, 46.9188585589009, 49.12833752170686, 46.098416389957556, 45.73535788443781, 44.05394761793075, 47.327938233652425, 47.27696311089301, 47.77707315260365, 57.94456266587781, 62.70514726638795, 67.6455254708567, 62.04222356119464, 58.2185519895246, 63.15048925338253, 58.869390872217, 50.29260289284491, 60.837530320690526, 64.20171976089478, 60.06383888183102, 65.72695301425073, 63.140781387206054, 66.11404388181626, 62.515657563363355, 59.27351659344089, 62.18849658966065, 61.34294732924431, 51.690233599755075, 53.780150874968506, 54.192019354912546, 49.908861729406546, 50.24736227527742, 45.29391865576468, 48.22357223879907, 49.08608967258085, 54.30188494343912, 52.03037761872815, 54.82845921670237, 56.11424353814895, 54.16179357036468, 56.98484497685587, 56.08382163509246, 57.417019567181995, 55.438077911253906, 55.88764429092408, 57.303066868935865, 59.0949938374181, 58.23494749684488, 57.12859984367125, 58.84529575224846, 64.47627782821655, 61.66375406326787, 66.80815435224964, 67.48068394199495, 71.7110856886833, 71.33268679341963, 77.4943773208126, 78.53404860342704, 88.49457033218877, 82.00832720725768, 85.05695804472893, 3.9981278104166833, 36.587747373888575, 84.97319975206929, 50.56121856935563, 55.24814890277002, 61.80459068667505, 72.10733921297135, 83.69496207083426, 55.53268940218034, 0.19171598517606336, 0.20077411686220478, 0.06418697167969038, 0.16287562467398184, 0.12915263343001568, 0.19542300803286416, 0.17426015088154426, 0.191342118947256, 0.15832418906352214], [0.029330352253671137, 0.09495742558952301, 0.05711308432622783, 0.01398467746067552, 0.07040728003748002, 0.0434369363281275, 0.0651441181018468, 0.131941806344736, 0.048439475151920514, 0.13026798083897562, 2.7823698088046047, 61.181847741526944, 46.55802795963903, 34.00415666641728, 31.615680340797674, 52.51867740384994, 40.73919965374855, 79.7301753874748, 11.524310900319009, 1.8296715689282266, 82.94872330081078, 69.42064116078039, 74.49949079944243, 63.655568938101496, 62.66672765055011, 55.87607329891574, 57.61781746341337, 56.28070108352169, 52.99458249922722, 51.161631461112734, 50.458754493344216, 47.91985527161629, 51.49741380445419, 47.848891750458755, 49.95598116228658, 47.17984130305629, 49.847213837408255, 52.34886230960969, 58.14001437156432, 59.34143243297454, 62.12265960631832, 58.248044290850245, 53.57236331509006, 51.17946255591608, 49.751049087893584, 48.11481275866109, 47.94180877747075, 44.77246307557629, 43.18593102116739, 44.41320142438335, 48.23290355743901, 50.34302103903986, 50.17028770139141, 50.15164467596239, 51.75811806032735, 53.005431775123846, 60.47334609493133, 57.81537940425258, 57.41631746292115, 60.69512474921442, 60.61709703937654, 58.81568185744747, 61.34619897411716, 58.53513825324274, 56.90332635756462, 54.04745647984167, 56.42223588881954, 54.988189897229596, 58.38260512198172, 55.0950627173147, 60.01844529182681, 52.45202456751178, 46.850570094200876, 40.1368373440158, 37.938019383338194, 43.91030649985037, 39.585140289798865, 42.551566093198716, 41.76768433663153, 41.9211039235515, 42.115720164391306, 43.748477351280954, 44.314604805361846, 49.99167080848448, 50.62454523578767, 47.94995554031865, 47.90018066283196, 43.89888063553841, 45.16710058335335, 50.85834595464891, 42.35958176274454, 46.18872504080496, 50.523575582811915, 47.38997444029778, 42.641364835923724, 42.608562054172644, 43.352247361213934, 44.8178292089893, 39.51865219300793, 40.798807913257235, 42.92218300604051, 40.71244124443301, 40.05764861260691, 41.84023641770886, 41.610844442921305, 45.8504206134427, 55.447942672237275, 56.85963115384502, 58.81047687222881, 57.280442637781945, 55.758457106928674, 57.71237011878722, 56.25196187726913, 52.24632370856501, 56.070250234296246, 56.48521346430625, 53.151571443003995, 58.01547127385294, 57.71328403103737, 59.97793505268713, 57.022950803079915, 55.606928102431766, 56.28715338245515, 57.321949158945394, 53.315287251626295, 48.04986615334788, 49.0302586555481, 46.52349541264196, 44.13914149807346, 41.23368109426191, 43.30339031834757, 45.894696327947806, 46.03023382925218, 48.25392353919245, 50.46109614833709, 51.295411740579915, 55.40113702897103, 56.23120861668741, 56.22309715517106, 57.67306012492026, 54.3519304644677, 52.35212572159306, 50.60857726681618, 51.23533279665055, 51.81311361251339, 52.005486257614635, 51.38894457970896, 54.34300707232568, 59.09611955765755, 60.992973850619414, 63.55346572014594, 66.45114021916544, 70.37718172996276, 71.01928941665157, 74.7436426531884, 74.78694561989077, 84.7279731688961, 53.32326535255679, 3.007094163087107, 41.95954707361037, 61.576363655828665, 44.36887079669584, 32.708929238780854, 22.727163953165856, 39.171047825967115, 55.34690241659842, 35.96480831023186, 0.05848758395821337, 0.057883508308159734, 0.09815191264234244, 0.1385056783234881, 0.12735932885158446, 0.027546062614888917, 0.035451059605205254, 0.030152416307358976, 0.023819261283103018, 0.04252226182049321, 0.02566033718927253, 0.04766247047471905, 0.041015504769259886, 0.03173762076203862, 0.0448552944937781, 0.011728803247904346, 0.03905657581203888, 0.05172516880256515, 0.1336622099962927, 3.235969855900734, 74.18699556781401, 48.291480233592374, 32.93581285784322, 43.1356462355583, 62.13343043481151, 46.007303653224824, 88.45199692633845, 13.43246259996968, 1.975197998746749, 89.10721317414315, 71.927506385311, 80.86506612839239, 67.19756726295718, 67.01819727497717, 62.03877972018335, 61.65187320401592, 57.86360886789138, 56.3031997988301, 54.920419185392326, 55.75533097790134, 51.51798663600799, 55.283775791045166, 53.008071530249815, 53.64865733731178, 52.06048180980068, 53.00723606540311, 55.07516453343054, 63.67923651972125, 63.73146680093581, 65.59916219403668, 62.134599301122854, 56.32544748244747, 53.87440935257943, 52.36648159642374, 50.331320608815844, 48.05127036186957, 50.357686781114154, 46.667513078258885, 46.05752960328133, 51.72882187751032, 51.98448196534188, 53.86725494938513, 52.899551314692346, 52.55720292368243, 54.68831293044552, 61.85391449159192, 60.914922606560495, 60.660015613802024, 61.420276857191524, 63.27396154403687, 62.385744740886075, 63.534395156368134, 61.16520512488581, 58.179285141729544, 57.781607797068936, 58.61458978345318, 56.218578584732555, 60.73180283269575, 57.86282047148674, 61.74609245792512, 56.23390328499579, 50.01066684722901, 48.00293499423612, 51.91612682034893, 46.23185150084957, 42.32210351574806, 43.63217515330161, 45.458944536024525, 43.61643468180011, 44.32430090442781, 46.72576027531778, 47.819870133553785, 54.14992055585308, 53.69482363423994, 51.88049600970361, 48.78283162270823, 44.61183024990944, 44.527691487343084, 50.31125376301427, 42.4453483089324, 46.28653718579201, 51.3567066192627, 51.735513441024295, 48.32027435302735, 45.826270580291755, 46.61661640290291, 45.347855168004195, 43.508279246668664, 43.28393536229288, 46.241830010567945, 42.34685367153537, 42.71794519116802, 43.778801195083126, 43.19871402555897, 48.97750277673045, 57.587528920942745, 58.83746670138452, 62.051052816452525, 59.23407716135825, 58.00775204935382, 58.86282090217837, 57.609886430924945, 54.63013241367956, 57.42597433828539, 56.641233582650464, 55.97454047972157, 58.8023457988616, 58.693554939762244, 59.92946632446782, 59.55493488619405, 58.72110566785259, 59.866308319953184, 57.626109353957645, 55.166504767633256, 53.38000635946951, 51.40671683895973, 48.48888135725453, 46.63954657893027, 44.722193979447894, 47.147905365113296, 50.299690615746286, 48.715535517661806, 52.54663213606804, 53.47659080259262, 55.38814221659015, 57.450912767840975, 60.564184265752, 58.58457188452444, 62.497646039532086, 58.315030528653054, 57.06287268669375, 54.821140073960834, 54.24288072893697, 56.438560793476725, 56.10797951298376, 54.60418201261952, 58.06685040074011, 61.98695344309654, 64.16456314825243, 68.57560573085662, 70.02473323575913, 72.14260132082048, 76.6395281207177, 78.27797274435721, 77.32477403456166, 88.22078104942076, 55.44621682936146, 2.8918456117953024, 48.54515952448691, 66.63900606093868, 51.01306384609592, 36.30136728286743, 23.43605979796379, 44.3352835409103, 69.72243616657873, 40.827907977565644, 0.03784675444025667, 0.014672794871242538, 0.05365585209801794, 0.07540061814530243, 0.02723094575377482, 0.039552690521363294, 0.01643729550133069, 0.021634786464874784, 0.07607837613191336, 0.1263368236381681, 0.1556980090155717, 0.13616482006205669, 0.11780385288500017, 0.16566620719048286, 0.0944028238976194, 0.2350658211376398, 0.20986948042146622, 0.10979645675228489, 0.4503643062085875, 4.97278384623989, 84.99741646551317, 59.266405336318485, 48.094228159996774, 45.55239500537996, 71.89585285802042, 52.324559304022024, 96.21519119508805, 14.07148632311052, 2.7437952593449624, 92.65567164267264, 73.99315203389814, 82.86833824649935, 69.35769496425506, 71.67721994461553, 63.193662781869214, 64.20240617567494, 61.72459786938083, 58.8328932177636, 56.59395333259337, 57.83346153074696, 54.37450370480938, 56.55847941675494, 55.58333504584528, 57.505684744927194, 53.49308044679704, 56.429382447273504, 56.497000186674065, 64.40683618668588, 66.1736717531758, 69.71701545100059, 65.67866863742952, 57.80852310119137, 56.81603400937973, 55.34435287598641, 53.993076739772675, 51.60587518445907, 51.72051429748536, 47.48084399007982, 50.03654664562595, 54.93801101561516, 55.457925104325824, 56.42656226311961, 54.65938545042469, 54.49760729266752, 56.656452378919056, 64.04279316625288, 62.980560410407286, 63.60489976021552, 64.65718146293395, 63.51528536888861, 64.68626583776167, 66.84126700124433, 63.70849347883656, 62.323080955013154, 58.93039549550703, 60.06747099661059, 60.95500530735139, 64.2797984615449, 60.73286971738262, 65.1869446231473, 57.17601345431421, 56.64799574882754, 48.57757791396111, 43.19160276843656, 49.69581034875686, 45.348635719668486, 47.98649241847377, 47.52494319792717, 46.721331919393236, 48.926892434397054, 51.17774848015078, 51.20292617428688, 57.850492462035156, 59.075997798673576, 55.56393892534318, 50.55732365577452, 45.922972694520034, 46.07725128050774, 53.62439355542583, 43.1887629724318, 50.19833264812347, 55.31726890994657, 57.201265673483576, 50.60015593805621, 48.52630076869842, 50.6705036470967, 51.530777485139915, 45.088433527177386, 45.471386294211115, 48.06648131339781, 44.77761314761254, 45.669583659018244, 46.00709576760569, 44.13783927117625, 51.51907313254572, 57.86173397494901, 60.59214684271044, 63.6714937610011, 61.39289086864841, 58.582857808759144, 61.11059788734683, 59.92814840808992, 55.82428232316048, 58.27282190322877, 58.472007705319314, 57.00340563251127, 64.08486058635097, 61.654289384042066, 64.538612134995, 61.4974259561108, 59.21757182767315, 62.03734413270028, 62.273815985648866, 58.62794153151974, 54.81934362842191, 53.396139067988244, 51.50138716543875, 50.443672980031664, 46.39683031266736, 49.13532718535393, 51.538747741330056, 50.072436332702644, 54.948146420140425, 56.49310135072278, 57.26558469956922, 61.136575744998076, 62.31836234369586, 61.485941256246264, 65.67367938257033, 59.88248417454382, 60.22540915396906, 55.49122210471861, 56.62289257972472, 59.36423709315639, 60.11009539327314, 56.732279639090265, 61.75233687123945, 63.84813377934118, 67.97770315600981, 68.36050295060681, 75.17823342354068, 74.68046895919308, 80.63468963869157, 77.82298564910889, 82.2856544679211, 88.35029771251064, 67.0051436270437, 4.529021593832201, 50.33256400016047, 77.04884313767957, 58.24441609844085, 50.03794300940729, 34.55424162649339, 56.94241277633175, 74.12623805384483, 54.24659521349015, 0.1545321610906432, 0.2444151734873172, 0.20410502119170082, 0.2548939539420028, 0.18857278770977454, 0.16455147265186235, 0.1076988084241748, 0.10437891277815066, 0.15655284056500082], [0.09529021418383045, 0.023492279635261626, 0.03863220906726295, 0.008751595967389163, 0.060752354367005254, 0.07154000998144189, 0.009706727578304708, 0.02060730359517038, 0.04367628900875007, 0.03738564611863225, 1.2867874676181426, 52.64079255442466, 48.99940136940249, 49.97786406547793, 22.69336292820592, 45.238232766428304, 41.64714990123626, 78.16209808472665, 20.94065573907668, 0.5163026889485698, 77.0241008266326, 71.43428402562296, 75.52531611534857, 67.55773498165992, 65.201551529669, 57.99121925907751, 60.80713195185508, 54.23454961469097, 55.889326987728, 49.6234033953759, 52.35114512904998, 51.3412211018224, 50.902535377010224, 48.44472331385459, 48.43733356844995, 49.91469821622295, 56.51557260943998, 61.72036955433508, 65.40346730139949, 62.548123021279615, 63.7144241025371, 61.9938725040805, 57.75566131837907, 53.43823394467754, 50.56285812008766, 45.87721040171962, 46.31027537007486, 43.821198094275694, 42.98521157233946, 43.729916695625555, 48.52496716283983, 48.15149868688276, 49.48033494334067, 52.19786674745622, 51.85503982728528, 52.743770460928644, 59.25024517120854, 58.28065487646288, 59.052683230369325, 60.1124252811555, 61.97752798757246, 56.1427709364122, 59.16720859466061, 58.53746421875493, 57.487712444797644, 53.989205360412605, 54.19410213347405, 54.62797511008478, 53.227324178141934, 54.63232501860588, 59.81553716044272, 58.181779769159135, 51.60139191535212, 40.3914148576798, 34.357126835853826, 45.442329375974595, 39.24627496350197, 41.923873116893155, 39.82064331731489, 41.64341188246205, 41.15335095313288, 43.11528913436398, 42.84755206877186, 45.17024240186138, 45.90850699332453, 47.3222468745324, 44.01503378345121, 48.24370184252339, 46.74009261592742, 51.072346548880304, 43.30845017586985, 46.32017543238979, 48.09979008090112, 42.240855539998705, 41.97868824005127, 40.308213541584635, 44.76170009182346, 41.87623985352055, 43.039712905883796, 40.517656341675796, 42.32117391401722, 42.51838284154093, 41.48860377650107, 39.28561633633029, 42.263675889661236, 53.32470486241003, 56.32682815674813, 55.78802001091742, 62.307956295628706, 56.9899126791185, 54.44764414141255, 53.62578991920718, 54.56316971009778, 53.358911852682795, 51.13693229613766, 56.25740220469814, 55.0023731877727, 59.2836598427065, 56.87188071589316, 58.91967958019626, 59.747625243279245, 57.19751196522867, 56.0155959283152, 54.8011242189715, 51.20501679758872, 50.626478964282626, 47.53517666170674, 44.988440544374534, 43.791580277104536, 41.82009112450385, 42.797757579434304, 45.78369325207126, 46.428844698013805, 48.178147269833474, 52.8008605587867, 53.78315933289067, 57.876187909033995, 58.856392137465946, 59.755756316646455, 59.78602132489605, 59.53287547634494, 59.300102418468846, 57.07072134940856, 54.91699495623189, 52.71931056053408, 51.96736081953972, 52.411114246614524, 53.01393155128726, 60.17092350990542, 65.44813525292182, 68.54949059024935, 70.56041133019232, 71.89019680023193, 74.07702799766295, 79.61598734701835, 73.33268765480288, 84.21162451467207, 34.00267401049214, 0.5432479624306003, 56.760893329497314, 59.565705714687226, 41.36498243578019, 37.40346700914445, 70.92243825235676, 38.88958246477189, 67.21997184138145, 25.28184679246718, 0.031890782805520206, 0.10667526133118138, 0.06252099857515385, 0.07231581190060224, 0.026774705920909202, 0.0320619689826403, 0.03580516842644542, 0.011558162908430302, 0.007527542597193632, 0.04564731066385585, 0.04985835425735963, 0.05692461137509635, 0.013603574573813428, 0.02382410295878447, 0.017491915120532917, 0.03052502040631108, 0.03280662751245884, 0.005307752562070927, 0.02694475254224193, 1.0357897296067209, 59.905206464952045, 51.2259034187563, 52.592245378801906, 37.1370792388916, 49.648875267274924, 47.92946507853847, 85.16049292779739, 25.351223714890022, 0.7122068155196406, 80.6903951398788, 73.91366912472633, 79.31959736731746, 71.17860824831071, 70.56512601913946, 63.95856418917256, 67.206008203568, 57.59133362000989, 57.82017646297332, 54.62542949184295, 57.173813004647535, 56.43635249906971, 54.06252622604371, 52.46964777669599, 51.96317172819569, 51.088600850874386, 60.19745442175097, 64.88571836102393, 69.39640091311547, 65.63628350534748, 66.66589783084008, 64.69972741219306, 60.79407045918127, 56.74587457410751, 52.15155140046151, 50.17759899939261, 50.263730326006495, 47.88029032368814, 45.71494587006108, 48.10479110287082, 51.89804469385455, 51.31073644084316, 52.32127235781763, 54.19666344119657, 52.659674844434186, 56.1650146976594, 62.25171735209804, 60.2068288864628, 60.29424282812304, 61.56059572773596, 64.48930009718865, 59.5592769499748, 61.88474039877615, 59.996789886105454, 58.537075904107866, 56.76658468861734, 56.58517114577755, 56.95878867180117, 57.684764477514456, 58.18200726662913, 59.59017738219231, 58.60426218278947, 53.325461879853286, 46.4405333611273, 51.25852969384963, 46.92085504531861, 41.43420050221105, 44.98308258671915, 41.04833341413929, 46.077741576779275, 43.75747526845625, 46.19267094519831, 46.30559598245929, 48.21930470005159, 46.920458885931204, 49.7711512350267, 43.905560431941865, 48.51927188134963, 47.190090456316554, 48.94048344704413, 44.84901989659956, 44.693278266537575, 50.569326108501805, 44.29768370043847, 43.87804500518307, 45.1321404980075, 47.09857371545608, 43.68594300362372, 44.72986221313477, 42.44061400813442, 43.7613074241146, 44.980576192179036, 43.96511377826814, 41.64280391508534, 43.59617171748992, 55.77828468814973, 59.16369415098622, 57.53103894572104, 62.04167442937052, 60.572142754831624, 58.07525996238955, 56.765353064383234, 55.5947805220081, 54.041047326980106, 55.11812625392791, 58.363801279375636, 58.19713192601358, 58.76967245532621, 59.63555136034566, 59.433298264780355, 61.18553084711875, 60.78005583055558, 59.45118427276612, 56.09726359767299, 52.00226599170316, 53.08979803516019, 49.198198856845984, 48.288197209758145, 47.11082719987439, 44.89134619312902, 47.50918703694498, 50.04229291792839, 48.213621185671904, 51.32507270382297, 55.25709975150324, 59.04827448629565, 60.220141410827644, 63.549935586990856, 64.35507266752182, 64.49455999558973, 65.03152462743944, 63.9587995313829, 61.276137598099254, 59.16758121982698, 56.92102016941194, 55.05978099761471, 56.66324200168733, 57.62106126354587, 65.11966420758155, 69.2739131373744, 72.55311658305507, 74.88106681454566, 76.90935580961167, 74.89340659110778, 82.62552784335229, 78.25198311959544, 89.33411444387129, 36.87783802709272, 1.2430659104739468, 64.76992999353718, 63.38411346558602, 46.07925168929562, 40.88799476623535, 81.44490226622551, 44.32638368298931, 72.97262191772461, 28.683998892384192, 0.2316120209833307, 0.07383197651154573, 0.03386706556944597, 0.08487206958835164, 0.021907569307293144, 0.10480608340472945, 0.037835355051943374, 0.07764703308742854, 0.058876622558361104, 0.14848264054425303, 0.12683422154476567, 0.11695178691297771, 0.18941959065775718, 0.21457816323926374, 0.17726367519747827, 0.09288088298372685, 0.0988952324335133, 0.16060360707342625, 0.24275544399936355, 2.2792052213222753, 76.31462250986408, 61.65779990534629, 68.47047052075787, 34.55246479280534, 61.60868790841872, 52.80085271404636, 97.13487717413135, 25.877878396741806, 0.9494322538375856, 86.05362446077409, 77.97980200859809, 81.1380160239435, 73.92858982086182, 71.14569171782463, 64.51134773992723, 69.67445773463096, 61.801660676156324, 60.94685462213332, 56.95900440216065, 59.3102966585467, 59.07191068895402, 57.657700123325476, 55.94744082420103, 53.19250922049246, 55.553058270485174, 62.85242049924789, 66.9024795101535, 70.70997130486273, 66.89337176661338, 67.5264972256076, 64.57003032007526, 62.57893716135333, 60.40749342210832, 56.9747527184025, 52.11332790313229, 51.599273835459066, 49.57397760883455, 49.16707484952865, 49.99063530275899, 55.03632914635443, 54.54413444765153, 56.25469576927924, 56.37409271732454, 54.76550909780688, 57.08701095273418, 63.71018009801065, 63.91514355136503, 65.84416127973988, 64.00459712551486, 69.50592917780723, 60.72027890912948, 64.78459181324129, 61.6834992747153, 59.08137536817982, 58.75576765306535, 59.822307171360144, 60.26169107806299, 58.53143553580008, 59.912317722074455, 64.54341311608592, 60.915503117346, 59.072546112921934, 48.4969888964007, 42.54570607216128, 49.11138111545194, 43.43675874894665, 45.741123768591116, 43.97977559797226, 47.520765873693655, 46.17157643841159, 49.00785015475366, 49.77256328828874, 53.03352379029798, 51.37600860288067, 52.14105121551022, 45.55235578167824, 50.65927782366353, 48.23309967594762, 48.797030602732015, 44.57842342315182, 48.14784303788216, 52.51143670851185, 47.287271099705855, 49.0794373327686, 50.35245041693411, 50.72889989422214, 46.832852748132524, 46.562613210370465, 45.568943485136955, 48.118601768247544, 46.69672296893212, 47.769840302005896, 44.09561887864144, 47.811421348202614, 56.42166714514456, 61.618274181119865, 60.15520265025478, 66.2143781108241, 61.183212726346916, 58.96608514170493, 59.679787851149044, 57.894728952838534, 55.81699063701015, 56.962083462745916, 61.88002570982903, 59.740525753267356, 63.67405114635345, 62.05790911951373, 62.23937757553593, 64.92443607699487, 63.61763569616503, 59.15564152502245, 60.54355259864562, 55.27451115269815, 56.6812966715905, 52.17590147449125, 52.667296009679, 49.11887676485124, 48.001252297432195, 48.860408259976296, 51.98157156667402, 51.82575933394894, 55.002290817999075, 58.35336777471728, 59.40482970206969, 62.68730048210391, 65.861600137526, 67.23792060728996, 66.57454582952684, 66.80305527102563, 65.09947969067481, 64.0297277512089, 63.21192533739152, 58.837356875019694, 57.913481804632376, 58.74875445519724, 61.64727618617397, 68.89745973771619, 73.79464087947723, 75.26229766107376, 76.77219836942612, 79.00922806032243, 80.18506050109863, 85.00784997017153, 82.84082674211072, 90.46863648199266, 52.68474271220546, 3.0378006831292184, 67.43104242509412, 73.47530503426829, 56.964993861413774, 49.033929994029386, 85.67373506484493, 53.797075902262044, 86.86071488165086, 37.99239127866684, 0.3197212793654011, 0.27109703529746304, 0.1524857870273052, 0.17268300567182804, 0.10132104984574741, 0.227512531282921, 0.16295917422300385, 0.16708480284338997, 0.2041014359002152], [0.029377460915354953, 0.03103914967317495, 0.07874312104597207, 0.05818587172055437, 0.09130224390255828, 0.01529640576336533, 0.08613822906608544, 0.049727184682964325, 0.027605438259460276, 0.03244602609606039, 0.01015563594973496, 34.542415680423865, 58.642156201024214, 29.631519971355317, 20.399405917813702, 35.475308279837336, 48.879878905511674, 68.68927601845034, 47.23441323926372, 0.2557167170509215, 57.160904484410445, 75.95504314668717, 70.08693418195172, 71.47788509245842, 70.48067738932949, 69.85882482221051, 66.99595743610014, 61.07012687190887, 57.16799220731182, 53.14129091078236, 54.24299840004214, 49.51791909433181, 49.48645384080949, 50.330410618935865, 49.038193610406694, 53.70498257298624, 61.53321366156302, 64.04373061272406, 63.42600830139653, 62.10035700951854, 65.71819828402612, 60.536680606103715, 58.13203234826365, 53.08998238655829, 48.66676476693923, 49.22291763367192, 48.985790744904556, 46.680951118469245, 43.15731340839017, 40.86369568301786, 48.07721291818927, 43.99605343418737, 47.646634732523275, 48.60776839717742, 53.76169612330776, 53.47320187476374, 56.79201733681464, 57.77094287257041, 54.699374014331454, 59.392646820314475, 62.08529903042702, 55.86601634179392, 55.6522903134746, 58.59145956654703, 58.21942667807303, 57.10089614314418, 56.03502342777868, 55.31276995135892, 56.27390361601307, 53.932801677334695, 57.93419584151238, 61.27061490089663, 47.1408058751014, 44.359374738508656, 30.144960188096572, 44.96845606834658, 39.28401993167016, 42.51913985898418, 41.25244963553644, 41.51294600579047, 38.71279731873543, 42.18062362363262, 40.155272483825684, 42.841448860783736, 43.03749676673643, 47.765313886827045, 43.17181441091722, 44.801508226702296, 49.50877212708997, 44.80647394734044, 43.73261920867428, 43.83302404034523, 49.54132387715001, 45.129069282162575, 42.86023701390913, 39.79256699162145, 41.65426508072884, 43.4033715340399, 39.12251241745488, 40.04606193111789, 40.126847067186915, 41.94062163752895, 39.54299049992716, 38.97238369910948, 46.81313891564646, 57.473486008182654, 55.67002727139381, 56.14659916970038, 54.28392048804991, 57.143610754320704, 50.09369165666642, 54.936575428132095, 55.509731769561775, 56.38724050214214, 58.207698791257805, 57.95869104323849, 56.377265914793945, 57.40914737024615, 57.49793806383687, 57.96997177985407, 60.67751330714072, 53.665786327854285, 52.435927160324596, 52.45762178974768, 49.163399588677194, 46.193494642934496, 45.757527120651744, 44.60102019771453, 42.72687642805038, 42.51296997070313, 46.224602960771136, 45.75203188004033, 48.16440328474968, 48.92049897101618, 54.73817802244618, 56.142900374627885, 59.00658753610427, 60.39602441172446, 61.60475769350606, 62.924082202296105, 62.39866895060386, 64.08018904347574, 61.86932548399895, 60.975444778319336, 59.454565355854655, 53.594383501237445, 51.16382798840923, 51.9150403238112, 62.11655247596003, 65.50456247022076, 72.29096105021816, 69.86830911328717, 84.58522242884483, 75.46763373959449, 81.2285678617416, 69.4757112379997, 89.33187869287308, 17.949675898398123, 1.165352235397985, 59.540175007235625, 61.1657032658977, 35.61170085783928, 68.35170115194013, 92.51181479423278, 29.70252271621458, 73.92224342592301, 16.895874277237926, 0.03436248696919891, 0.048325841330111995, 0.07006046437327901, 0.046688860823069854, 0.02714256218995058, 0.043871557159769925, 0.07070448384770463, 0.03973474748612892, 0.07852817209617746, 0.09159927151256031, 0.10650104527632076, 0.02793744927452457, 0.027652751849663836, 0.01451618543210169, 0.019066534155318816, 0.03726385346043014, 0.06265325982484125, 0.0272857976491533, 0.061793138438294974, 0.1675752982977898, 39.88056144406719, 66.19920638299757, 35.82939632477299, 30.821892638360303, 44.9454160659544, 55.87579088826334, 76.003523642017, 52.75731440513365, 0.3197801762050198, 57.791519626494384, 80.61359513190486, 75.66477206445511, 74.5069040790681, 73.57100302173247, 73.79700214632096, 70.1409452192245, 67.17753964085733, 61.17686240903793, 58.92915602653258, 56.51834964752198, 53.458426306324625, 54.248179851039765, 54.98673469789567, 52.63073167493267, 58.47265881876792, 66.11405957129695, 66.47828302075787, 68.58967919503489, 66.04929339501166, 66.07529086451378, 63.903145021007916, 59.137222074693256, 56.627983816208385, 51.844908345130186, 51.72355805673907, 53.28106849424301, 49.82503675645398, 45.89056999452653, 44.510860596933675, 52.26083647820258, 47.59126263280069, 50.18395716144193, 54.79921794706776, 56.73257773922336, 55.073587740621264, 58.644580225790705, 59.54086534438595, 57.71251132411342, 60.63001732672415, 61.13949398840628, 61.481014759309836, 58.620210539910104, 60.11886973534862, 62.61416789024108, 60.2910460964326, 58.21507676955193, 58.0640459060669, 57.96025999130742, 57.59988830935571, 58.951650819470814, 61.31158405734647, 50.92261398992231, 48.1168798477419, 47.85490082156274, 51.33955801686933, 40.26584409898327, 44.36623104156987, 42.92957275144516, 43.164675697203606, 41.950757042054214, 45.06492676273469, 43.62056493759156, 45.306674203565045, 45.71076070108722, 47.18204567509313, 42.70925714123634, 43.37336540222169, 46.97907086341612, 44.254741591791955, 44.99431233252249, 42.98232078552247, 50.03355779955464, 47.235460512099735, 46.35601412865424, 44.00656538624918, 43.34335142566312, 47.02657468857304, 41.306484207030266, 42.90086492415398, 44.307850483925115, 42.40717972478559, 41.450090023779104, 42.29295638299758, 48.70005784496185, 59.79581940558649, 57.783337562314934, 56.53232505244594, 58.27328866527927, 58.63810047026604, 54.415531696811804, 58.0752678071299, 56.13547140552152, 56.87890175850161, 61.11117839813233, 58.461644803324056, 60.573707780530384, 57.88523681702153, 57.57920957380726, 61.467733613906375, 61.83414574592345, 55.54235019991475, 56.3294953684653, 54.362152161136756, 52.63278307453279, 49.90317821502686, 48.75578688037012, 47.3842046337743, 44.14353455266645, 46.468123312919374, 47.87859978214387, 49.39367017438335, 49.60798455822853, 51.09401764408235, 59.133711553389034, 60.169511456643384, 61.588150378196474, 62.947239875793464, 65.25292281181582, 64.71316545240342, 66.33914086126512, 65.29298590075585, 64.40318446005544, 65.39855649394374, 65.08934036377939, 58.22282345064225, 55.9766742490953, 54.810459459981615, 66.17014162002071, 68.87002668073102, 76.20442744224303, 74.4692022569718, 85.46727718845491, 77.8564356219384, 83.83135857120638, 72.24079393571424, 93.13520493045931, 17.94647132196734, 1.729438953822659, 65.3515939558706, 64.52186361435922, 43.8596647785556, 74.89605811334427, 100.05163792640933, 34.31806395130773, 77.63275069575157, 24.13715797085916, 0.08968320134426318, 0.0824093267381672, 0.05783544012135076, 0.029955976041814977, 0.03996554296463728, 0.03760818316931686, 0.047661849943500374, 0.08651505239428052, 0.10368454600534133, 0.24655438208531952, 0.1734226022756869, 0.2358593350096095, 0.1835064644054059, 0.15746057814648076, 0.17655611639061283, 0.16724701430047714, 0.2121122487850728, 0.14586021432713156, 0.16657348511920822, 0.24617700717381893, 50.52887078254454, 77.52685454583938, 41.27579950517224, 29.95066362042581, 54.483831928622344, 61.32480636719735, 82.97109650027367, 54.10378171551613, 0.49093767099322816, 67.20306642593877, 81.1603735339257, 78.32735538482666, 77.33083017410772, 75.96540604868244, 77.4520000334709, 73.14081315071353, 66.38991986551594, 64.01364995587257, 61.06645161105741, 58.826907680880645, 56.68943951206823, 54.87242114159369, 57.920859782926506, 54.531292607707364, 61.5782856172131, 66.82017249445762, 69.81592978200605, 69.82826171382781, 69.07488423009073, 70.2694106871082, 66.66629791259766, 61.13842710371941, 60.11159373867897, 53.24082889864522, 55.53110084226055, 56.0439036738488, 52.39876662531207, 48.12348904148225, 45.78484642890192, 55.404247468517674, 47.9392082460465, 54.483922143136304, 57.29918372246527, 59.81963995964297, 56.95975749723373, 61.594653667942175, 61.21843953286449, 57.92313083525627, 64.38527491784865, 64.71622097876765, 62.80825853347779, 60.17809360258041, 63.051567077636726, 65.61798564849362, 63.53727025370445, 59.78976718841061, 60.29122652546052, 61.2054015744117, 58.4958831725582, 63.894911966016224, 63.487413006444136, 56.52309571543048, 49.559017688997336, 34.79679707557925, 50.1925471521193, 43.176638926229174, 46.471845642212905, 46.27458964624713, 46.6043629184846, 46.5000553284922, 49.008795445965184, 45.365082217801, 48.46842619680589, 51.231386892257206, 49.219501249251834, 41.871674214639974, 43.59401441389515, 48.45954987310594, 45.70628527672061, 45.74838407578007, 45.2354557283463, 53.59947473772111, 52.59608930157077, 51.53686892601752, 46.20432822935043, 48.56946645244476, 49.39661195201259, 43.378805729650686, 45.125578372709214, 45.79007494834162, 45.98433033112557, 42.1872288950028, 42.380895922260905, 52.46996156630978, 63.21921702354186, 59.71226507617582, 58.06506964468188, 60.74786493855139, 60.840170075816495, 54.77267134574152, 60.78398212309807, 60.22681336249075, 59.6605250912328, 63.52669946609005, 63.76560318854548, 62.47757919373051, 62.057348220579094, 58.86382502894248, 64.54510758000036, 64.74597215652466, 56.36767571972263, 59.69031157032136, 56.32027387619019, 54.978901724661554, 53.08840559374902, 52.69503501153762, 50.16734592376217, 46.525990040071555, 49.23160176123343, 50.593036836193455, 52.357150277783795, 51.38427695920391, 54.900442554104714, 60.80204856011176, 63.41825377556586, 65.76291330399053, 66.35093935074346, 65.41135518781601, 66.87420706595144, 68.27504234929239, 68.7908967848747, 68.56935347280195, 69.58372546780494, 67.60862381227555, 57.96880683591289, 58.032290397151826, 57.7632942507344, 68.9711061600716, 73.12692011556318, 79.1073343830724, 77.72519311597271, 90.0688842035109, 80.07124116343837, 89.66434663341892, 75.42734315318447, 97.02915360850673, 33.26120484259821, 2.566667151066565, 68.67003287038496, 74.64681502311461, 53.85703717508624, 77.29445411312965, 101.04914372967136, 43.77481606698806, 93.90089081179713, 29.118730868062666, 0.14182182779956248, 0.15028121580760326, 0.1170990443337829, 0.24491087833960212, 0.23582248618045162, 0.23132328244466938, 0.21684979779585717, 0.25221534283651464, 0.21863728010606384], [0.026429106421287984, 0.0925760642595349, 0.10764077726391055, 0.08492920442574448, 0.0487774808049923, 0.06496802513157168, 0.05231242116180159, 0.11114784351159489, 0.12185918527745432, 0.036883942797900214, 0.1168908292968427, 20.760103156489713, 57.099272281892844, 41.073632701750725, 33.34460619957217, 29.286694603581584, 49.11913564128261, 54.1441232927384, 73.02491495686193, 0.9514207729408819, 27.002570975211363, 85.35885503215175, 69.89109808398833, 74.33718312171199, 73.25693884203511, 71.33296920407203, 66.85530908646123, 67.25630083391744, 63.76018247296734, 57.94005194017964, 51.61996826048821, 51.357632298623365, 50.90820712427939, 48.71952064575688, 53.772133550336285, 63.82405042648316, 63.99567373337285, 65.28336040435299, 60.744770188485425, 62.424301639679946, 62.254737577130726, 62.53950557401104, 54.73117266931842, 50.89512601975472, 48.571878710100734, 49.69619474103374, 47.48267181458012, 46.51059473714521, 42.743275857740834, 41.03782538444766, 44.424215439827215, 44.983486590846894, 45.027534807882006, 45.73958619948357, 51.96039861248386, 55.94105128319033, 54.54588382474838, 58.98368089429794, 57.37796452737624, 55.60921092187205, 59.09065177363735, 60.15386904439619, 58.806993807515795, 57.4687046389426, 58.506736370825, 59.31091247066375, 56.80044258794477, 56.681163311004646, 52.01140119183449, 51.85429849932271, 52.56476525337466, 61.248469198903734, 46.8871775750191, 46.26839230137487, 29.804618089429795, 42.351819392173525, 42.12512993043469, 39.0334746145433, 40.71757170461839, 39.258010695057536, 39.50593979127946, 42.03988898184992, 41.84846555033038, 41.14102686605146, 47.15747594833375, 49.04719937232233, 43.13280643955354, 45.7593745570029, 46.77551161858344, 43.39459326959426, 42.62535372088033, 41.63672031894807, 44.6253232033022, 45.08492300587316, 39.91631384818785, 38.184116732689645, 41.15786167883104, 43.567412899386504, 39.229236187473425, 41.53163217729138, 40.15759060459752, 42.23380704079905, 41.240859031677246, 43.30605753006474, 52.44956524141374, 55.25260471528577, 56.92420513399186, 53.82963549706244, 52.568091423280784, 56.652039712475194, 53.953476490512976, 53.78010772889661, 57.546116536663426, 57.557185465289706, 57.478906723760794, 59.164286428882235, 55.7914520848182, 53.52605973520587, 57.43993405372866, 57.11218472450011, 57.508120536804206, 51.889886163896136, 50.791979451333326, 51.79889109826858, 50.2319355933897, 49.05571091559626, 44.98868373132522, 46.06951244415776, 41.754469871520996, 45.11096362144717, 44.972625547839755, 45.70805034329815, 47.38941354136313, 49.38279344189552, 57.25474719078311, 56.974101604953894, 58.53413020410846, 59.56048896235805, 58.95463966554212, 61.31547112618724, 60.03206768343526, 63.08435024753694, 61.61375168831118, 63.48208250537996, 61.465117393001435, 59.15128769413118, 55.682774974453835, 52.093806266784675, 57.90127538865613, 68.07827272722798, 72.26401436713435, 71.74633210705173, 73.1386636918591, 81.66456284061556, 79.44242246689336, 71.69570999760782, 77.39538454240369, 6.531497470794186, 2.0732788260905974, 73.63092114848476, 50.02554047492243, 49.11580162663614, 33.40142565388834, 38.97467436329011, 52.72903411619125, 67.50086061416134, 22.750190227262436, 0.40623978681622014, 0.06824302036435374, 0.13159786351025105, 0.060828269849861824, 0.028108585655929583, 0.07824394581539017, 0.048853718044777075, 0.02067160326987505, 0.013785820187730415, 0.08416901537848097, 0.029429191002441995, 0.08386907663436667, 0.04647726733838359, 0.010752021992248634, 0.05846226092187628, 0.08838032327231862, 0.04490608995359752, 0.06784835484840217, 0.02222323009083348, 0.10683821589355508, 25.871367262255763, 66.43025752036803, 33.6092798940597, 31.829057278171664, 37.798959593619074, 56.57845997041272, 59.23256312647174, 80.6256446530742, 1.3490184444573619, 25.412706867341075, 89.65758446724185, 72.09452090724822, 80.41378175058674, 75.69249537683304, 74.94013770934075, 69.81293309119441, 72.25953502039756, 64.60920303098618, 61.04414509188745, 52.67287362006403, 55.53963984212568, 53.53592057381907, 53.3601866229888, 57.1408768623106, 66.86583672800373, 68.23619519510578, 69.02534469481438, 63.398449728565836, 66.26175249776533, 65.5673086258673, 63.84838873340238, 55.150795675093136, 52.56626752115066, 51.79829882037256, 50.844982439471835, 50.06326190886959, 50.02681132285826, 45.846651215707105, 45.21506332582043, 47.3984153809086, 46.874527931213386, 45.585433129341375, 49.67441381946687, 54.09247744467951, 56.488390584145826, 57.61819008857974, 61.3086618915681, 59.73297519068564, 60.014597446687766, 59.63075822399509, 61.521575989261756, 62.365415096282966, 58.857713976214015, 61.73053633782172, 60.980547781913515, 61.02093250520768, 58.9403740052254, 55.10352326977638, 54.37720229548793, 57.60104148618637, 60.541650249112045, 54.085264205932624, 46.43211203236734, 48.820294180224025, 52.68931227345621, 41.84750456963816, 43.877695914237734, 42.48669401291878, 43.44783552231328, 42.88388498367802, 45.7198174538151, 43.89691945045225, 42.77950286865235, 49.34257738051876, 47.15727590745496, 41.83292511970767, 44.827380180358894, 46.107888913923695, 43.805414476702296, 44.92425487887475, 42.66735838305566, 45.675839839443086, 47.872979025686945, 44.29152557926793, 41.0703496779165, 42.17848200951853, 43.85680537069998, 41.2118491818828, 43.16345191770985, 44.0026940068891, 44.4511228992093, 44.60544070889873, 44.327787891511, 52.935456691249726, 56.77634354560607, 58.06950192297659, 55.791985527161636, 56.94315802666449, 56.9207848272016, 57.9728586443009, 58.70870313336773, 58.97527917738884, 58.390830332233065, 60.22843722374209, 60.68358513616747, 57.015388473387695, 59.94255135136267, 60.28859069270473, 59.44248053335375, 58.10093971990771, 53.00722822066277, 54.394013574046475, 56.057628047081735, 51.30972839170887, 50.62776157932897, 48.121625915650405, 46.995011375796416, 45.97208076907743, 48.45780049600909, 46.58210739012688, 50.20255704079905, 50.056872367858894, 52.857083812836684, 59.57303662453929, 60.61316682446388, 62.956739856350815, 62.93843807712678, 63.71970753515921, 63.61450172239735, 64.76824729673325, 67.33432462138515, 65.4683707606408, 67.02687355779833, 68.08424257463025, 64.54008302380963, 62.05346899647867, 56.02791217065627, 61.84593246829126, 73.18424163326141, 77.05767631530762, 75.01348603156306, 78.74612331390381, 79.79512983752836, 85.23575536666378, 71.72997582343318, 78.97822564648044, 5.769541273193975, 2.8598437290037833, 81.30721138369653, 54.40113267590923, 53.215125606906035, 42.017555006088756, 56.797085039077274, 55.790922564844934, 74.3478205896193, 27.899148310384444, 0.46257528806886367, 0.14900708901545695, 0.06844591875109943, 0.06483166148104975, 0.07266373073141422, 0.03935990066477849, 0.05701294514320551, 0.01476834710281823, 0.024041639370543343, 0.18066101467176793, 0.31204305589199066, 0.29658131782085667, 0.1785002023943009, 0.17979640784042497, 0.17164267359241364, 0.16416401602327824, 0.285625065406484, 0.3024876718559573, 0.09783725734920272, 0.5112048334652378, 36.74422248717278, 75.67977120799404, 53.27288250769339, 44.83140845452586, 43.44084193629604, 65.50458208207162, 66.02290368849232, 84.33072336258428, 0.9874859247957507, 33.85727174820439, 93.63148673888176, 75.31966624721404, 81.42470990457844, 78.97555843476327, 78.09026379739085, 71.35482465067219, 72.29169061107021, 68.22775425449495, 65.60341796567364, 55.61870698005923, 55.79518225885207, 55.84343133434173, 56.45640365539059, 58.633111215406856, 70.47067534539008, 71.15942785816809, 69.35447077597343, 64.57926357946089, 68.08282267662787, 68.25800357326385, 68.6718685396256, 58.60392485895465, 54.06987282537646, 53.78309265259774, 55.12410002370035, 52.927290316550966, 53.604562051834606, 47.247000125146684, 46.650556672003965, 48.84530321244271, 49.031933507611676, 49.248099250178186, 51.678321361541755, 57.20617255856914, 59.4584406575849, 59.52879228899556, 63.4044195759681, 62.131371190471036, 60.965266227722175, 63.0349087715149, 63.53878821096113, 64.67771114841585, 62.1294923751585, 63.870628572279415, 64.06658626371815, 61.682957987631525, 61.024992158336026, 56.22643116981753, 58.11222045652328, 58.43895389187721, 62.48298814219814, 55.43487725719329, 53.163424845664736, 35.632320757835146, 47.33297063458351, 45.189524773628484, 43.87411479027041, 45.43613203110234, 42.92015121829125, 43.455186044016195, 47.841443169501524, 46.347714393369614, 47.56824616462954, 52.70470365401238, 51.35877763071368, 45.118188627304576, 46.806463041613185, 47.86536962755265, 44.48804416964131, 42.810964199804495, 41.29878851675218, 46.718841214333814, 50.87957382202149, 47.1798256135756, 43.27896571928456, 46.221574890998106, 49.197324168297556, 44.80784677690075, 46.1191814176498, 45.34343073444982, 47.23240106336532, 44.77500477144795, 48.3393802181367, 55.704363699882265, 58.56998066748343, 60.64228257825298, 58.20812240723641, 58.58684293685421, 60.75253648142661, 58.37581157684327, 61.29409813111829, 61.71471741891677, 62.17032032628214, 62.013900126180346, 64.64204503643897, 58.01201566573113, 59.648695222793094, 61.98688284043343, 61.74818700359714, 61.38337912098054, 55.696624863532286, 54.91537109498055, 58.36899449748378, 53.50785993760633, 55.50043182988321, 49.55585233626827, 49.23967399904805, 49.18756923367901, 51.98206970768591, 49.96321401288433, 52.25470581362325, 51.99583722699074, 53.84905122941541, 64.7152364638544, 62.48070924512802, 66.60472454563265, 63.68565351732316, 67.22879717426916, 66.87175950696393, 67.52706989165276, 72.4773677702873, 66.58173945642287, 71.3046810703893, 69.48980823639901, 65.63031758031538, 63.54343621961532, 57.90227951542024, 66.06062904480966, 75.76614179918843, 81.08834312808129, 77.70453006990495, 84.9708620194466, 84.35111184273997, 86.9413274334323, 75.49776538725823, 91.03461096363684, 15.259146671141348, 2.465538396950691, 89.64129094154605, 60.68697406399635, 66.58800740395823, 47.078502947284335, 54.24870937101303, 64.58959510249477, 88.24074591359785, 33.98501549997638, 0.7110016672841964, 0.19635644020332446, 0.24930941812213392, 0.24625337081811122, 0.1764894973847174, 0.1595521667191098, 0.16382097717254393, 0.17136965517795857, 0.15106878483728056], [0.14496522444871165, 0.05827909696006006, 0.012007672658881113, 0.06921975182429438, 0.03935924565960323, 0.1157275401055813, 0.03579680274631228, 0.05927982612422878, 0.12121294414804828, 0.08457254453171646, 0.26852711674667173, 16.0855665322273, 58.301141415872884, 55.279053257357695, 60.47416979266752, 39.68487439617034, 45.367823954551454, 46.82154847729591, 83.79298210144043, 7.133050301382619, 5.042004364152109, 76.24827954076952, 65.80341177601969, 74.5368709871846, 70.0950534882084, 74.55474915043001, 66.94510782918623, 70.99467262145012, 64.77417007569345, 60.10503553575086, 52.471534436748875, 52.18538968793808, 49.45541220326578, 55.774691797071895, 61.73347027071061, 63.89481390676191, 66.15323620457804, 58.09315773748583, 62.687861381038545, 62.673936966926824, 61.655662213602376, 54.39280940640358, 49.25944274471652, 50.17681060298797, 49.32375392606182, 49.30203968478788, 45.837845494670255, 46.773911291553134, 43.36271616720384, 42.56428241729737, 43.39993946013912, 45.35089500488774, 43.402967529912154, 43.898711973621005, 49.13134597962903, 55.41741486518614, 50.55990065297773, 55.3509856039478, 55.43036653149513, 58.850332075549716, 57.56169619098787, 56.4043185018724, 57.25076206268803, 60.78952050978138, 58.877823968087476, 57.06218234954342, 55.99591347479052, 58.044767456669966, 49.54860771856001, 47.197221325289824, 53.28949374537314, 62.83424031349921, 50.42419448975594, 45.678456060348026, 30.781580478914325, 42.94851779937745, 46.79017736065773, 40.14263852950066, 43.94305829078921, 39.839192205859774, 39.044198374594416, 38.71856320288874, 38.9536504591665, 41.766233059667776, 45.635815974204775, 44.7133098110076, 39.42624507411834, 44.354632592970326, 43.94912227507561, 44.05665013097948, 40.77707406013243, 41.332748397704094, 42.51584506803944, 45.24342206216628, 44.650528354029504, 40.378706378321496, 41.07666469389393, 41.07297374356178, 40.99658166208575, 43.856052275626894, 41.19550858774493, 42.1011132578696, 42.93883346742199, 49.645380435451386, 54.49724251224149, 55.27492692393642, 56.316849647029755, 53.523929888202304, 50.88118199379214, 55.77664905978788, 56.45005333808161, 54.061071026709776, 57.73718695486746, 57.389959135363185, 58.83073199179865, 55.75966127457158, 57.294116020202644, 55.84185061916229, 54.540435652579035, 54.781367240413545, 53.5461187362671, 50.19007998128092, 46.005746472266416, 48.73000514122748, 45.99062181288197, 44.446906351274066, 45.86223871477189, 43.623640075806655, 43.107730727041925, 44.29919773532499, 47.15190618268905, 46.27610368113364, 46.38270193530668, 49.000648683117284, 58.48304525498421, 58.10337551178471, 59.71015091865294, 61.29763218664355, 60.10437265519173, 58.927775352231926, 61.17453644352575, 57.737112429834184, 62.55935668945313, 61.76014631025253, 65.64446556952693, 61.53724193572999, 61.13123739919355, 54.89224480044458, 60.10942466797368, 66.24037558032622, 69.61042896393808, 70.65221832644555, 77.00689731105682, 70.274368563006, 79.68989264580512, 74.22966311054846, 53.31232978451637, 0.4787039822868763, 7.762788793733043, 71.11192795538133, 48.005868927125015, 47.96339750289918, 39.84993557776175, 56.291605272600734, 39.068787713204664, 72.18075813785677, 19.335515960570305, 0.22918916067048428, 0.03635572900454845, 0.0788224800940483, 0.015864825766203145, 0.0646870394027041, 0.037796763372757745, 0.028926951420162956, 0.0631137093108508, 0.01043768271037768, 0.029088392958886204, 0.022979123300061594, 0.02862282217510285, 0.08677428122609855, 0.028816221071587458, 0.04961978681685944, 0.030221496370711157, 0.04786523479607798, 0.09730619753921226, 0.0414662325995103, 0.2783132771090154, 22.251788377761844, 70.57983490728563, 45.94359651688607, 54.80133994933098, 45.48582453881541, 54.06732720713462, 52.4835172776253, 93.14131598318778, 10.028483656144912, 4.321604207638772, 79.21887090129238, 67.32053356785929, 77.87049339663598, 71.00621223449707, 78.14571826688706, 70.32728133663055, 75.20160290502733, 68.15596703560122, 62.64368764815792, 56.06020112191477, 55.35522568610407, 51.37032116613081, 57.81500677908621, 65.20852550383538, 66.74935017862629, 66.4074920838879, 61.64821363264515, 63.97498715308405, 65.32794598610171, 65.20251251036122, 57.576565896311116, 51.20938239559051, 52.76912466172249, 52.42994554581181, 50.5191001584453, 48.04972494802168, 49.22519653074203, 47.31436291048604, 46.085515714460804, 47.10566536072762, 49.3006903894486, 45.62825756688272, 46.82275264493881, 53.26908173099641, 56.18389698766894, 52.82241790525375, 58.082155489152484, 58.349971002148045, 60.50611749772103, 60.22723305609919, 60.82247626396918, 60.35149374315816, 62.68055008303735, 60.1507782167004, 58.81242236783428, 58.758301504196666, 61.00037536313457, 50.33737282599173, 47.79451201038976, 59.14903625365227, 60.80931671204106, 56.3666166797761, 45.87730846097393, 46.14655171671222, 61.76517086644327, 44.476990930495724, 44.86903967395906, 43.79876998163039, 40.76914695001418, 43.601286488194624, 42.714599409411036, 40.43121514781829, 46.96246747047671, 48.85371669646233, 45.42928749515165, 39.50331964800435, 45.018744776325846, 42.812352718845496, 42.52527444593368, 41.27944730943249, 42.442512435297814, 42.92459526369649, 47.44377366958126, 47.68567800521851, 43.76290775114491, 44.06422030541205, 42.56940503274241, 44.752357006073005, 47.22323056190245, 43.156528934355705, 43.13090409001997, 44.922544725479625, 51.40919969927881, 55.70479516060122, 57.912073673740515, 58.74512234041768, 55.54129900470857, 55.4224080424155, 57.34696603590443, 58.721952899809814, 58.22047395090903, 61.42214390539355, 58.95835022772513, 59.41208608688847, 60.69475604641823, 58.85581162668044, 57.47201119699786, 58.20083464345625, 59.50401467661704, 58.24147432081161, 52.158007621765144, 50.83066971071305, 51.76084018522694, 48.11973141085718, 46.98979462346723, 48.589937302374075, 45.15012456524757, 46.61350596335627, 47.708176720526914, 47.9039853618991, 50.22905265131305, 51.071397335298606, 52.73890672191497, 60.8633355940542, 61.67712150081512, 63.91141337733116, 61.72898307923348, 63.46478877529022, 64.25011004171064, 63.2493604383161, 63.302539933112364, 66.20428193000056, 64.48218884006624, 69.77859666270595, 64.66151568197435, 64.60613181514125, 58.78076099580335, 62.24093867886452, 69.91397334683326, 75.30024267012074, 73.34198367211127, 79.64008638935705, 72.19658882387223, 83.11667134684902, 77.07170271104383, 58.04637955081079, 0.639828238035402, 10.602235217248241, 79.40268101230745, 51.01135369270079, 58.30717009882773, 46.607143878936775, 62.36685852850638, 44.69270560049242, 80.5040511777324, 22.237248151533066, 0.29939705866479105, 0.11402895463810814, 0.0037567208956686723, 0.044048826075008804, 0.006423712362565341, 0.08302966643485331, 0.05132131023152221, 0.05374417054436861, 0.07076245372093494, 0.1880591870435784, 0.13697192433380312, 0.18609935027216712, 0.19959126178535724, 0.1287557539199629, 0.17215319458515416, 0.20198338665068152, 0.26392939410382704, 0.4001092141674411, 0.17380753081412087, 0.7769959131556173, 29.330403535596787, 79.65532871984666, 71.48037187514767, 78.65053515280448, 53.474241302859404, 65.83212744805121, 57.219449781602435, 103.55545982237786, 9.49588462229698, 7.021653027303758, 87.2349952882336, 71.49496309218868, 80.99223721411921, 75.05416885499032, 81.83452698492235, 71.26871293590915, 76.82890015263712, 71.0037725202499, 65.44768810272217, 58.87737289551766, 57.682748379245886, 54.058329289959325, 60.7559254092555, 65.6400332912322, 69.77934975777903, 71.05591650932067, 61.77405111251339, 66.40223610785701, 68.56776883525234, 68.13807318287512, 62.9883933836414, 53.591014185259425, 57.09409867563556, 53.66213852359403, 52.55352766283097, 49.5069403802195, 52.08692642950243, 49.35224602299352, 47.56250381469727, 49.64006170149773, 50.65574769050845, 48.873905135739236, 48.528967980415594, 56.36285120441068, 60.59865405482631, 52.006945379318736, 59.69419863916213, 60.769767453593595, 63.37141675333824, 61.62633857419414, 61.19796476056499, 63.51523437807637, 66.24020299603863, 62.574167559223795, 60.2486531196102, 60.36974060919977, 62.53165298892606, 52.63862348371937, 50.53323245817616, 61.42806276198357, 63.85472336123067, 58.226259446913204, 52.633928406623106, 38.76405877451743, 48.13744483455535, 50.99329902279762, 46.22220639259585, 47.897364401048236, 42.95594676848381, 46.15907976704259, 46.36849118817238, 42.351815469803356, 49.08477175620295, 52.47223654100972, 45.99616804430562, 40.71455932432606, 44.80654847237372, 42.61831698879119, 44.11266157704015, 40.84771594693584, 44.18570395438902, 44.27012120523761, 48.77482998755671, 49.60934169830815, 44.58073762155349, 48.19772774173368, 44.83119272416638, 47.01458400295627, 48.92662571322534, 45.07238318843227, 48.46610807603406, 47.732899419723026, 52.91483679125386, 57.42801789314517, 59.21908194018949, 61.37087852724137, 58.931164280060806, 56.716660761064105, 61.16703687175628, 60.81537677395729, 60.35808724741782, 65.16171986056914, 62.60953557106757, 64.68830547025128, 62.11180640805153, 61.5866873341222, 63.313040118063654, 60.125239664508456, 58.72467894707957, 60.30362513757522, 55.10755546631352, 51.910129516355454, 53.37133399901852, 51.70180851413358, 49.8399103841474, 50.803193507655976, 48.62506604963734, 48.89275996915756, 49.9793271095522, 50.0490080156634, 52.01305250967703, 52.273144875803304, 54.64121310941635, 64.26189284170827, 64.71175732151156, 68.12377222122686, 65.87477145656463, 66.445280198128, 67.87984786495086, 67.16717673886207, 66.45670998481013, 69.91755839317076, 68.42608497988793, 74.21577792013846, 66.21017332999938, 69.36787743722239, 60.81718106423656, 67.64532935234809, 76.41262685098957, 76.9833944689843, 75.5170242248043, 81.93857962085356, 77.30342065134357, 88.82911712892594, 76.4258687726913, 74.15025080403974, 2.670696743073002, 9.254227395980589, 87.77802390436973, 57.65362870308661, 66.14008841976043, 52.42665075486707, 72.26700321320565, 50.496766182684134, 92.24717247870662, 29.754372527522428, 0.5119170500866829, 0.23503741459740748, 0.16194960823462856, 0.1846830988483083, 0.12709270727129715, 0.11051961310928869, 0.1947367311485352, 0.16416550223385135, 0.11141834149677908], [0.05632710875943304, 0.025832804648445982, 0.025978999122256236, 0.036919657816930164, 0.028922770495316195, 0.10507632858089863, 0.03223722117141851, 0.038926007616664135, 0.06887160316710511, 0.0361916023276506, 0.21440640632664004, 11.66328243670925, 57.9731842010252, 44.97648908245949, 40.68216839144307, 37.93802722807854, 31.82180677690814, 39.268761911699855, 72.91407662053263, 23.798173012272006, 0.10325094024019857, 55.56390362401163, 62.69350567171651, 71.88990654483919, 71.96986013843168, 71.62919444422569, 70.12922517714962, 66.61271833604383, 61.64008255927794, 57.46012249300557, 51.9177467592301, 53.26470828825428, 50.80343669460666, 62.122047716571444, 63.054065627436486, 64.8791366238748, 59.5464272652903, 59.51635445317915, 62.54006647294568, 59.56646665450066, 59.81496449439757, 55.28990645562449, 50.46486554607269, 49.80928059547178, 51.23739596336119, 51.127436237950484, 47.35923874762751, 45.00893492852488, 46.61455323619228, 42.258117891127064, 42.511059776429214, 44.05042140714584, 42.697897957217315, 41.14980120812693, 48.42302868443151, 50.898126632936545, 50.047831304611705, 53.93065221848027, 55.9471623359188, 57.919455574404815, 57.138154737411014, 59.505289446923044, 54.237248205369525, 55.53269332455051, 57.458718284483886, 57.791998155655406, 59.09592343914894, 56.86750335078086, 45.41691241725799, 45.79087511185677, 52.85047461909633, 59.462641516039454, 55.16763833261306, 43.791509674441436, 24.65148464325936, 40.645572677735366, 46.24436386169926, 42.388599457279334, 45.01296320269185, 37.88916234047183, 38.80101142391082, 38.6680156184781, 44.116360372112645, 44.925078576610936, 50.403060759267504, 45.930637005836736, 46.61913456455354, 43.06961705607753, 41.75230080081571, 43.76777541252875, 40.88102079206898, 40.16773777623331, 43.44201864734773, 35.79101593263688, 38.12037429501934, 37.54472332616007, 42.19324188847696, 48.04163702072636, 43.856852439142045, 44.410757787766, 43.43098502005301, 44.661471766810266, 50.3671867616715, 55.94178868878273, 57.935321561751834, 58.11720186664213, 53.79669543235533, 51.45159659847137, 53.893774094120154, 56.468296281753055, 58.18394883986443, 50.45441635193364, 56.498569134742986, 58.07636214840797, 59.34625302591632, 56.69173409861904, 55.68146098044611, 56.923628545576534, 54.7340948350968, 54.08384430793024, 51.518669128417976, 52.28741053612002, 45.42547102897398, 44.62498980183756, 44.4237918238486, 44.008032352693625, 45.62819480895997, 42.60184695643764, 47.13626377044186, 46.81728093854843, 44.802437828433135, 48.23684161709201, 47.04317808151246, 56.55320382887318, 57.22252491981753, 58.99749548204484, 58.63624126680436, 59.151307305982044, 60.373639445151056, 61.25518037426857, 59.61317031614242, 56.76275645532916, 58.358961074583, 61.242350301434925, 63.13023413381269, 63.565111237187544, 61.72356236365534, 59.48481075225338, 53.987816841371604, 66.17151444958103, 73.85815189730737, 72.6446960818383, 74.5144271850586, 73.66024478789299, 68.42122908561461, 72.0692765328192, 43.4686593855581, 0.13471820091287937, 20.13508523664167, 67.6193867960284, 47.50200517715947, 44.063922205278956, 36.137055273978945, 39.188969135284424, 36.63521589771394, 68.58987531354352, 13.146613990106891, 0.35417436772296507, 0.048104832624836315, 0.03346876496629369, 0.04869535234906981, 0.0951751247949658, 0.0928419657171734, 0.11514233320110268, 0.011773958385381247, 0.04601910462482803, 0.05396447444875395, 0.08627038689390307, 0.09235608211207776, 0.02287507515340563, 0.02110266562310919, 0.03221278296663396, 0.017987053067753875, 0.07435889944674508, 0.06984641940723504, 0.04746665074039371, 0.17066163671833856, 12.893387732967255, 68.7106764701105, 48.8469623750256, 48.36511881120744, 44.125075878635535, 40.54501879599787, 43.76284891559232, 81.25240018290859, 29.672383223810506, 0.036022250931109154, 56.43053562410417, 66.63633100448116, 73.9387801385695, 79.33170964640956, 75.14716825177594, 73.31611171845468, 70.03391158196234, 66.69900263509443, 60.32784577338927, 55.314942944434385, 54.658506839506096, 54.43428062623548, 66.42355811211371, 65.64088444555959, 69.34983453442975, 62.29632254569762, 62.51511235390941, 66.75938360152706, 64.04652334028675, 64.43600293128722, 58.91215647420576, 53.962784274931884, 52.648103852425855, 53.02667533197711, 53.56518537767472, 49.77744663915327, 47.32815788638207, 48.855913223758826, 44.47447669121527, 47.62467730429865, 46.560153884272424, 44.32272803398871, 44.201683690471036, 50.496656356319306, 51.609417084724676, 50.5051443653722, 57.43321503362348, 58.163717254515625, 60.83507883933283, 60.03309926679058, 61.82564596976004, 56.4822167734946, 57.51408253946612, 59.82684535364951, 63.024596860331876, 62.65999686333441, 59.579575215616536, 47.797175299736764, 44.68078551753875, 56.42884900493007, 61.14147086297313, 58.363040339562204, 48.47843216311548, 35.30713273632911, 61.37616588223366, 48.138029267711026, 43.12915863529329, 47.65430296621015, 41.393109752285866, 42.480877137953236, 42.60438472993913, 45.84769456617294, 45.597110025344364, 50.90593214957945, 45.43770097917127, 44.40844751173451, 45.530935718167214, 40.011341110352554, 41.40081720967447, 39.814893122642275, 41.711770949825166, 44.64289934404435, 37.82205843156384, 41.3373101142145, 40.42856362558181, 44.98878179057952, 47.36584794136786, 45.10832778869137, 45.35964581274217, 42.12587518076743, 46.5282650147715, 53.49726169340072, 59.81913789626091, 58.373148287496264, 60.190813849049235, 55.947181947769664, 53.70757918204031, 53.694313726117535, 58.77806240512479, 56.563260785995, 54.947483539581306, 58.40069901558661, 58.0079952363045, 57.622135992973085, 59.34975962485037, 56.56728906016196, 60.73520352763515, 57.60947458205685, 56.72741590007659, 53.21388221556141, 50.52514453088084, 48.30287471894295, 49.26997038625902, 47.44108684601323, 44.73923275547643, 46.982891251963956, 46.68545399942706, 49.43632987237746, 49.616037184192294, 46.72680362578362, 49.59502112480902, 51.609079760889855, 56.36217655674104, 62.22420977007959, 61.20718625284011, 61.20093399478544, 64.09816526597547, 63.122189352589274, 64.71673480926022, 62.437186625696, 64.3010655526192, 64.49770965883809, 64.4757326187626, 67.79110816217238, 64.79963018048194, 66.3588233147898, 64.25962571174868, 58.39856524621287, 68.02742312031408, 78.69091987609863, 75.41138695132348, 78.45669946362896, 76.70738512469877, 70.62676214402723, 75.59978623544016, 48.717873250284505, 0.08329776656483451, 26.287163995927383, 75.62897651426255, 49.43289779847669, 53.147719675494784, 39.84577394300892, 48.159653294471006, 37.81226819561374, 77.0161227257021, 16.50373531926063, 0.433964018499659, 0.05368205613546795, 0.08820206993409703, 0.08864012667007985, 0.043595386293506434, 0.1368919907197837, 0.04490957565365299, 0.035321104280169935, 0.03373203108147268, 0.1672378978541782, 0.12063670047228375, 0.2455018385643921, 0.08279196467370757, 0.08828363531539518, 0.20058584309393362, 0.11833639124468451, 0.12343592446057067, 0.21085698307762224, 0.09196550750564184, 0.6301885843276978, 18.520027745154596, 84.00209934480729, 55.60617892972885, 58.267730666745095, 52.96733771601031, 50.373435097356, 50.392093812265706, 88.65326158462032, 28.272924692400043, 0.3217809220715877, 64.163574710969, 65.57574172173777, 77.41975030591412, 79.40082180884578, 76.13151058073967, 74.79373916502922, 73.12371161676222, 70.63305362578362, 63.95056255402104, 59.01762900813934, 59.48181013907156, 56.10747352723153, 67.59608791720483, 68.79667051376836, 71.54567933851673, 64.82636505557646, 64.46755447695332, 65.96326012765208, 64.91745033571797, 66.47170912834906, 60.214540266221576, 56.78518849034464, 54.174780538005216, 56.41947061784806, 57.0572401631263, 52.491734643136304, 50.40669287404707, 51.270932228334495, 46.39156256952594, 48.66328954696656, 51.31873807599468, 48.45684343768705, 45.15620423901466, 53.72391977617818, 58.05642474082209, 53.57838415330457, 60.5940217356528, 59.13317026630525, 62.98601250494681, 62.005702372520204, 64.4490840358119, 56.89743103519563, 58.26707170855615, 60.232567479533536, 64.61307441034626, 63.597929708419315, 62.0150258464198, 49.200979817298155, 47.343537499827725, 57.50556315145185, 64.90786406301683, 56.98489989003828, 51.93887264497819, 33.83563203196372, 45.797907921575735, 48.49940899879702, 45.43693611698766, 51.17975281130884, 43.142278963519686, 45.18514348614601, 44.66219740529215, 47.0770908940223, 48.51762056350709, 51.056711981373454, 48.44462133223011, 46.234091174217966, 45.94642846815048, 40.8093394771699, 43.47935176664784, 40.432282032505164, 39.42708053896504, 44.957544034527196, 37.90200025804582, 44.33942164144209, 44.47382950013684, 48.695464749490064, 50.55817481010191, 47.827036303858605, 48.80891538435414, 46.26596043186803, 45.167206487348004, 52.824265341604914, 60.71211253443072, 63.029425298014, 64.57824768558626, 61.12467527389527, 56.90575822707146, 58.67109544815556, 62.02681649115778, 61.27027365469164, 53.92245054244996, 60.70727232963809, 62.08001167543473, 63.57402678458922, 63.66983852078838, 59.86563759465372, 63.10724119986258, 59.95329864563481, 58.59449155869023, 56.301246458484286, 55.392743156802275, 50.336062754354174, 51.312991803692235, 50.23346139538673, 47.13058417843234, 49.27417124471357, 47.69804131600165, 53.48897372522662, 53.53198251416607, 48.29037020283361, 50.76726459687757, 53.31853497412897, 59.75293221012239, 63.860983464025686, 65.07333709347633, 61.6783570474194, 67.76028617735832, 67.38017712869953, 69.88572443685224, 65.07726338601881, 64.91627362466627, 66.97094840388145, 67.57482082613053, 71.28370423470774, 67.75725026284495, 68.15520609578779, 66.6146481421686, 61.56325117234261, 71.42080676171088, 83.4252755872665, 75.99247824761176, 82.80007331602036, 80.06750706703433, 78.92774474236273, 77.65204091225901, 57.4289631843567, 0.3684200178230963, 24.639699882076634, 83.86935064869543, 59.59833591215072, 57.40951215067218, 49.08387745580366, 55.183268977749734, 44.30046466089065, 91.74457565430673, 20.464999714205344, 0.36919738256162216, 0.11586162081408886, 0.15016762029019096, 0.23354622445279555, 0.13231328237921963, 0.3013324725531763, 0.1548165176063776, 0.12388695106511155, 0.11275943203438675], [0.019017364717118682, 0.05953433202399362, 0.14094378378602768, 0.016813546178802367, 0.12985152012157825, 0.09864820738232906, 0.09839098570087264, 0.03649521446336181, 0.06734655193623997, 0.03480412899666736, 0.476750488723478, 4.23379949985012, 52.36272396579866, 44.524679107050744, 37.82120335486628, 36.22188829606579, 32.83114637098005, 31.495467539756532, 68.04323027210852, 39.678669206557736, 0.05162718232661005, 35.75497719549364, 80.3646501418083, 70.49974010836694, 77.14755350543608, 67.90936762286772, 67.78357721144154, 62.23772233532321, 58.51606376709477, 55.24162207880328, 54.712349214861476, 51.0466314900306, 58.914764850370354, 64.45441845924624, 62.877264791919345, 62.327497543827185, 63.0067422313075, 63.91902277546545, 61.493174106844016, 60.500398682009795, 57.96368814283802, 56.41184945260325, 53.608931572206565, 52.27997372227331, 52.8866506391956, 49.37538408464002, 47.45136737823487, 44.51586554127355, 46.56298191316667, 43.38473243098105, 41.91416917308685, 39.088827102415024, 42.772081744286325, 40.93633013386881, 44.62404451062603, 44.43912436885219, 48.38746847644929, 53.37625265121461, 56.311071995765936, 56.634828352159076, 56.72378378529703, 58.83765105278262, 56.92016901508455, 58.88476656329248, 57.965417908084014, 59.35931059621996, 59.42237446385046, 57.60100226248465, 50.926155890187914, 51.28354264843849, 56.58880326055712, 58.12634098914362, 57.13310272462907, 47.9193728200851, 25.46793580055237, 31.38785143052378, 58.13115765971523, 41.278156849645804, 44.50326688828007, 39.855897580423665, 42.26129893333682, 36.87006388941119, 48.17479756570632, 43.30522598758821, 39.88513100531794, 41.12725542437646, 40.48508105739471, 39.88891217016405, 43.117038511460834, 41.2685509650938, 41.58149334692186, 38.64521488066643, 42.574225625684186, 47.92103590503816, 41.40238615774339, 34.163459808595725, 36.09870233843404, 42.49570369720459, 44.03089192605788, 45.27002357667493, 56.025091986502375, 58.695994654009425, 56.496749154983036, 55.770738047938195, 59.83232882715041, 51.25301091901718, 53.31952733378257, 50.58021068572999, 55.129242250996256, 52.19921604279549, 53.69522763836769, 54.83688446783251, 55.010366978183875, 58.30016866807015, 57.48716331297352, 57.21298963792863, 52.67157923790717, 54.57958090689875, 56.52606494965092, 52.275533599238244, 52.21763549312469, 48.594236220082934, 42.371733265538374, 41.659925060887495, 40.49403190612793, 44.765893105537664, 46.711741724321925, 46.87243338554136, 45.15355663914835, 46.35758307672317, 46.51400327682496, 47.79215074354603, 48.39876098017539, 54.5220789601726, 58.890803090987674, 62.27596152213312, 59.41687922323904, 60.66190619622508, 58.68269781912527, 61.78331967323058, 56.926425195509395, 64.07339549833729, 59.0389863137276, 61.10325521038425, 63.87022456815166, 61.71341519201956, 61.217325579735544, 63.15685918254238, 52.389521598815925, 58.48533984153502, 70.89655060921946, 74.14752867914017, 71.67245034248599, 76.84616642613565, 68.970227549153, 70.20228324397918, 34.53899929600377, 0.20020806981671244, 37.5924664158975, 65.27823778890794, 52.72762206292922, 40.57937875870736, 32.37811653844772, 49.832665766439135, 56.53857338813044, 63.16403711995771, 13.603905477831441, 0.3805806217414718, 0.22367795478672753, 0.05879252142603359, 0.152699448949387, 0.057554868079962275, 0.1111233976459311, 0.27348912951927035, 0.0366763865965749, 0.027584198471759597, 0.05565849020175877, 0.03642318304628134, 0.02943221321930328, 0.006696075293040204, 0.11646400340982985, 0.03694242211960016, 0.08622432202701608, 0.024145440453843727, 0.06799018070582422, 0.009968059321474886, 0.18013074393233947, 6.15153354983176, 64.94393417912146, 51.19637189372894, 40.70217640169206, 48.045178920991965, 40.26779743932909, 38.98732400709583, 74.24911806660315, 48.767279424975, 0.04658534702274107, 38.077847957611084, 83.99488218369024, 73.61079154476043, 78.29731787404707, 71.31280037664598, 67.76023910891625, 65.6989904372923, 62.91339374357655, 60.50223827362061, 56.471112543536776, 53.9664791476342, 63.2317215396512, 68.52603481661889, 67.92282135255876, 64.4976939693574, 66.04957580566406, 65.38536948542442, 65.33846970527404, 63.63813792505572, 60.740934110456905, 58.31219857738864, 58.194201915494865, 57.16278329972298, 55.76341498282648, 51.6699549459642, 50.87995821429838, 48.295096658891254, 47.96210312074231, 45.80025742130895, 46.3059058497029, 46.289965337322606, 46.48886088402041, 44.78200620220554, 46.43316714994369, 49.95212155003702, 50.02443828890401, 55.92245924857355, 58.95968775595389, 60.30798289083666, 57.48729667355938, 60.14326687782042, 58.96717556061284, 61.72872420280211, 57.74736550546462, 61.4855960876711, 59.37689850407263, 59.64511802119594, 51.92446970170545, 55.547311998182735, 57.63811180668493, 62.66829267624886, 55.968252920335345, 60.80396267675585, 28.39682452140316, 56.82381206943143, 68.45396518707275, 40.063022259742986, 50.36753977498701, 38.140774542285556, 45.527899803653845, 40.5721184515184, 51.0884282665868, 46.06551554895217, 40.658802832326586, 41.38814403164772, 40.74585199356079, 39.273864915294034, 43.187511736346835, 41.822711267778956, 39.73691640361663, 39.77036245407597, 43.322135325401064, 49.60311689684468, 46.07951448809716, 39.49704777809882, 40.03328284909649, 44.88419571230489, 45.698766093100275, 48.19822588274556, 57.64757256354056, 60.4686745520561, 60.26742950562508, 59.44612049287366, 60.347896929710146, 56.10691262829689, 55.07447811865038, 53.1340737496653, 53.66946943344609, 56.23128314172068, 56.75464107144264, 54.316421247297725, 60.75651376478134, 58.682533079578036, 59.23701501661732, 60.04152844029089, 55.32144623418009, 57.47953822535854, 60.63076257705689, 56.77062472989483, 55.46895480925038, 49.446418208460656, 44.38944362824963, 46.3397676714005, 45.628971438254084, 47.368142527918664, 49.14885936244842, 48.08868192857312, 48.24876954478603, 48.95608271321943, 49.55338908780006, 47.311374064414736, 51.39394952404884, 58.57130642860167, 64.01056305054696, 66.63648789928806, 62.130582794066406, 67.29029993857107, 61.052307544216035, 66.5412841304656, 63.53074735210788, 64.9854250108042, 65.59282756620838, 64.87514365103938, 66.08708150925176, 66.61441279995826, 63.92128990542505, 65.05037946085777, 57.52879142761231, 61.42603097423431, 71.56297699097665, 77.3684064803585, 72.3391277559342, 79.88127293125277, 69.68912739907542, 77.34193832643571, 36.57254818947085, 0.24216888111925897, 44.4289497406252, 71.63752555847168, 59.15490411943006, 48.10620315613286, 32.402070453090055, 52.48823981131277, 56.55893048932476, 72.92753819496401, 15.73236494295059, 0.3366185436325689, 0.22272719370742, 0.06660327044946533, 0.10579966113812501, 0.09599096246904905, 0.11343902097113671, 0.06757984103094186, 0.03689073799778858, 0.025272281096887686, 0.1424312660650861, 0.09128505288953744, 0.20506197226143655, 0.10265944375386162, 0.3348517610180763, 0.20163539887195636, 0.13849890610623744, 0.2407622670814876, 0.16919869989637407, 0.11966858750149129, 0.8412882180944566, 8.425730639888394, 77.44274323986423, 59.31134000901253, 50.02266145521595, 50.02235943271268, 47.399945105275805, 45.315460312751036, 81.46573789658086, 49.93024256921584, 0.08671569848252882, 40.28924103706114, 83.06431554978894, 75.11176493860061, 83.6132041869625, 73.05972991451141, 71.56835063811272, 67.99114119622016, 64.54227170636578, 64.05400722257554, 58.83525448460733, 56.42485603209465, 63.50882914758498, 70.65385003243723, 69.23144171314856, 69.58793024862968, 67.79345373953542, 68.80358957475232, 66.83296726595971, 66.1659211497153, 62.20930476342479, 61.83502043447187, 60.32073451626686, 58.34153006153723, 57.70927536872126, 52.724480244421194, 52.85565999246413, 49.0474739382344, 50.82279751377722, 47.23224809092861, 47.0063195690032, 47.89224570797336, 48.86075342855146, 44.98875433398832, 48.15018469287504, 51.28245615190076, 52.40005316272859, 58.722184319649976, 62.49296665191651, 61.36170018103815, 60.19782704691733, 63.10251082143476, 61.37571480966384, 64.8413210530435, 62.27213721121512, 64.01117101792367, 60.86515165144398, 62.97597123730568, 53.303520141109345, 56.21519750164401, 60.55657094524753, 64.39795201824558, 57.98452377319337, 61.22424464071951, 31.82960052644053, 46.533513146062056, 58.75763862363754, 42.75839267238494, 50.067886383302756, 42.21801950085548, 46.96700173039591, 41.84856360958469, 52.0090046236592, 49.982229663479714, 44.05630888477449, 43.19231663980792, 42.114261042687204, 40.281474744119954, 43.13450090346798, 43.7175690743231, 41.704851888841205, 37.98296974551293, 42.15945459181263, 46.66441832819293, 44.096018960399014, 39.26074458706764, 44.32179843225787, 48.58962351276029, 48.58725440117621, 50.964948131192116, 54.32436012452649, 56.453391275098255, 61.600235200697384, 62.746814604728456, 63.93122134670135, 59.43641262669718, 59.14912254579606, 55.6958717684592, 56.83179017036193, 58.71207244934575, 59.87788323433169, 56.340987913070194, 61.781868396266816, 62.193536835332075, 62.506883221287886, 63.722908189219815, 57.04901887524513, 57.719242111329116, 63.72941540133569, 58.45384320905132, 59.738211554865686, 53.78946258175758, 46.36292534489786, 48.57827609585178, 48.206509928549494, 50.02947853457544, 52.33233736407373, 50.86700654798939, 52.07501026891893, 50.99524451840309, 51.99392703271682, 49.53822128234371, 53.81340865165957, 61.50550603866578, 63.900062038052475, 70.46076743833481, 65.7550960202371, 68.87929916381836, 62.03232349887971, 69.18751901195895, 65.44949239300144, 70.90569757646131, 67.18578446295955, 67.05203164008357, 71.53741882693383, 69.18386336295836, 66.58086084550428, 70.12077639179846, 61.3021586018224, 66.00966961153092, 78.84350792054208, 79.7197183485954, 75.73116994673207, 84.22325041986282, 75.49813409005442, 77.39022270325692, 43.489679367311545, 0.4078609820815825, 45.87448827682003, 79.80528877627465, 63.23267467560307, 53.535426355177364, 43.52377653121949, 64.3395479263798, 72.00261192937052, 84.44463683712868, 20.209055254536292, 0.5758226951283794, 0.34030983104340495, 0.21822861816373565, 0.29516987742916234, 0.21145696781816023, 0.3992507360394924, 0.296783258597697, 0.18319650523124204, 0.12804452555194018], [0.0487668858089995, 0.13204175017533765, 0.05236772121861578, 0.08259170162942141, 0.08789158982014464, 0.2912554132842249, 0.03298641302652898, 0.10191240077537876, 0.04840119756878384, 0.1557932031010428, 0.47732863995817404, 3.271589144583672, 50.163250969302275, 44.02370222153203, 33.0322600180103, 21.235910192612682, 30.45628655341364, 34.40581129443261, 65.44680949180358, 62.18775133932791, 0.9349285546810397, 23.58097568635018, 87.85298824310304, 71.7954715605705, 75.5444808160105, 64.76579189300537, 66.67393868969333, 58.189196971154985, 57.68668643889889, 51.0644978861655, 54.18426875145205, 57.82215725991034, 65.33826966439524, 63.42212123255577, 64.57137569304436, 62.30631282252651, 64.5837546933082, 61.86397144871374, 62.61465034177227, 57.71296239668324, 58.47392574433358, 56.09179581365278, 58.52366139811855, 59.159171658177534, 55.334339064936486, 49.196343575754476, 49.39693358636672, 46.66176680595645, 46.63100365669497, 45.36635306573684, 42.742683579844815, 39.94912839704945, 40.39068529682775, 41.92130004206012, 46.744222871718875, 45.60986949551491, 45.610167595648, 51.56781642667709, 56.13454572616085, 56.3054669287897, 60.31815751906365, 57.878968869486165, 57.03120739229264, 49.24344731915382, 48.24363123986029, 50.510792578420336, 57.34644828304168, 53.90048526948499, 56.40093741878387, 58.22435709737963, 62.510111331939704, 58.536362032736506, 61.22906131129111, 57.87830206655688, 39.049615167802386, 16.544886865923484, 59.720953126107496, 52.16220848021969, 36.23437320032428, 42.91766835797218, 36.9751637981784, 44.70341367106284, 41.82148356591502, 24.852247238159183, 24.42058255595546, 41.77852576778781, 43.504498081822554, 46.766317582899525, 39.73566908990183, 42.914491238132605, 41.16025040226598, 39.501617339349565, 34.4502870498165, 48.62721943086194, 53.01044848657424, 56.242093193915586, 50.09351515000867, 52.50175629892657, 53.5595214751459, 58.04391630234257, 48.95589443945116, 48.189302490603545, 59.04307734581732, 59.690323337431884, 54.471904000928326, 52.2165999873992, 52.500861998527284, 53.8732091073067, 52.83157663960611, 52.76588870633034, 51.694312864734286, 47.8840361872027, 50.4930438533906, 55.579153799241595, 60.12566328048707, 57.451873748533195, 54.5878335737413, 53.38020247797812, 56.69731563137424, 52.54816578280542, 49.01247462918682, 49.053522233040106, 45.40360773763349, 42.54332127109651, 40.70332565615254, 41.91147058240829, 46.2979434382531, 45.29250268013247, 46.218240876351636, 46.69481669702838, 45.70967028217931, 44.54509504379765, 50.39990717364896, 59.707652368853175, 61.835600945257376, 66.09194524826543, 62.302786611741595, 64.7809047852793, 58.51263953793434, 63.31470320301672, 59.60134044770272, 60.81188586450393, 59.11689243009014, 61.539811088192856, 60.66237295827558, 63.654819765398585, 55.844082447790335, 61.468447485277736, 50.10463114707701, 54.09799621951196, 63.25428693525253, 72.99258678190171, 70.0835923225649, 82.10650413267075, 65.37892110886114, 78.95795483742991, 21.75286485302833, 0.5351019350271071, 52.9798226202688, 60.699933575045684, 45.2641047200849, 51.12236461331768, 47.58657932281495, 42.60926415843349, 51.289971413150916, 60.197321061165106, 12.050946950912477, 0.14524054112693957, 0.1747699823951529, 0.01803705179613204, 0.05046323429973376, 0.17599940029603822, 0.07383287283441714, 0.16203047647591562, 0.04368760795783132, 0.026306639605712508, 0.06515264466044403, 0.04581015797392015, 0.09704561273176825, 0.11376262417123204, 0.018969792572240678, 0.26773945578644354, 0.06182331847207201, 0.10191042426853411, 0.055753538730524244, 0.22437707130466739, 0.4068725141546419, 4.218736127499612, 61.62855863571168, 50.97047082839474, 33.20008647057318, 25.46621191886164, 34.2791618839387, 43.14748787110852, 65.38726791258782, 73.85248799477854, 1.256132796406746, 25.012378000443984, 92.96675482103902, 75.00065203635924, 79.08354128560713, 67.576766321736, 69.1360967389999, 60.38926616791756, 62.63923183564217, 55.62931306900517, 56.0355451030116, 59.09578223382274, 70.0943317720967, 65.72477217643493, 70.09324919792914, 63.845690142723825, 66.80175304412842, 65.24722360795545, 64.7578255591854, 59.90965443272745, 60.26852384690316, 59.357561219123106, 63.23135675922517, 61.50623167714765, 59.65330400774556, 53.699856035171024, 50.64932284816619, 47.62083338152978, 49.83853755458709, 49.771355198275664, 44.53599514499788, 44.2344472485204, 44.94334113213324, 45.3233991899798, 47.59693830244003, 47.839768317437944, 49.11516620266823, 52.20255005744196, 58.553569470682454, 59.09792384793682, 62.35202412451468, 59.136833760046194, 56.60317482486848, 50.41394141412551, 51.46981993029195, 52.06306272937406, 58.38799445859848, 59.25874494737195, 59.028882288163715, 59.89034852673931, 61.88650938772387, 62.737989271840746, 62.11297919673305, 59.17061321197018, 46.010367024329405, 26.46589267638422, 82.2295488849763, 50.56910253340199, 37.16497905792729, 47.400678588498025, 37.885781257383286, 48.282635288853804, 42.34580639869937, 28.526039161989768, 31.75006662645648, 40.06824293444234, 40.87139529566611, 47.91065731356221, 41.97977473658901, 42.32754776554723, 43.09409656832295, 38.63610321475614, 35.349125631393925, 47.665477798831084, 52.16420104426723, 56.94285600416122, 52.28051500935709, 56.61645989264212, 56.900651301107104, 57.209930189194225, 57.70552558283652, 55.44496559327649, 59.92001733472271, 60.97968093810543, 56.761324790216264, 54.61729841847574, 55.55188940417383, 54.61184632393622, 54.48489489093904, 55.90471052354383, 56.747592572242986, 48.32680509936426, 51.126506636219645, 61.896217253900346, 60.5381711067692, 56.608160157357496, 57.00849294662476, 56.14087643161897, 58.568933394647416, 56.495376325422725, 51.09485310892905, 51.99050672592656, 46.69363214123634, 44.886733485806374, 46.65831904257498, 47.9852843284607, 47.10757555500154, 48.144022649334325, 49.123979768445416, 50.38912850041544, 47.74294460973432, 47.93877286295737, 51.88841919745169, 65.40758186771025, 63.82863175484442, 66.64880414162913, 65.28420371394004, 66.28442379736131, 64.36151712171494, 65.49545472668063, 66.45959684925695, 64.56825348638719, 63.02610305047805, 67.21912460942423, 62.24501794384372, 68.15495506409677, 59.50754480977213, 62.53030369358679, 54.57207349038894, 59.66041918723815, 65.07699274247693, 76.05894673255183, 71.80968623007499, 85.66973424726918, 69.30104809422647, 86.62573352936776, 21.721003440118608, 0.5047337194123577, 61.52545913573235, 66.1509455403974, 54.6762163408341, 58.84080856077133, 40.82726863122756, 41.474212600338845, 53.8214377434023, 68.49851546748992, 17.29874680119176, 0.4208285830193951, 0.11264264193033019, 0.10284020986047485, 0.09683752026889594, 0.07196709633834901, 0.18508894158707512, 0.1638892815718728, 0.14331850313371228, 0.10247847846438808, 0.29678013295896594, 0.27931602491486457, 0.35722961829554656, 0.28445405404894586, 0.13733740956071885, 0.475026790893847, 0.15622331550525081, 0.20383476069377315, 0.184366152952275, 0.40016575145625305, 0.9786515827140502, 6.050854642545024, 73.9981020650556, 60.071295307528594, 42.9853763118867, 32.095870625588205, 44.76559892777474, 51.03442115168418, 74.54348410329511, 77.69740704567202, 1.3262965217713387, 29.770077697692383, 96.45629144483998, 78.30044008070423, 81.26856034801853, 69.73192045765539, 71.48558862747686, 61.89189087960028, 65.48404455184937, 59.81117156244094, 59.61831254343833, 61.40802729514338, 71.84730176002749, 66.87703901721586, 72.60120484136766, 64.47116305751186, 68.92531641067998, 66.6167583773213, 69.33674950753489, 62.54780530929566, 62.9944573679278, 60.52492134032711, 66.8797689868558, 64.17547518207182, 61.27083063125611, 57.200500811299975, 55.338296736440356, 50.528031395327666, 51.21079052648237, 51.93658590316773, 46.23760169552219, 43.404552167461766, 47.60683444238479, 48.2352138334705, 49.82655863608084, 49.724125939030806, 53.58196527727189, 55.55442325530514, 59.2579447838568, 59.767590107456336, 65.11184692382812, 61.74069919893819, 60.79867139939339, 51.803582252994666, 53.54395358793197, 51.07633559934555, 60.86293943466679, 56.83666959885628, 60.146204733079486, 64.12803019246748, 65.38899375546363, 64.15279211536532, 62.92821245808756, 60.409635036222404, 49.38191090860675, 29.24572348594666, 61.349427084768976, 47.548293067562966, 41.79603130586686, 45.48421244467459, 40.42067966153545, 45.46269039953909, 49.46231557476906, 30.787675842162106, 29.456947042096047, 42.41481265714092, 42.07463333683629, 49.491627447066776, 43.55884252055999, 43.14348705353276, 43.57610487168835, 38.3636357707362, 36.38515695448845, 46.726038763600016, 51.72859438004033, 55.565319599643836, 48.13469133069439, 57.59177684783936, 61.06707526791481, 62.45661804752966, 62.125024795532234, 60.96960436913275, 62.59778022766114, 63.692654948080744, 61.35482034375591, 56.78318808155676, 58.98610099669426, 57.61881374543714, 57.59049815516318, 57.23326044697916, 59.5972062695411, 49.46884239873579, 52.51313509479646, 63.00645982065509, 66.19948879364999, 60.391078302937174, 60.3485127418272, 55.80791819480158, 61.7957418195663, 59.17411588853406, 55.07869858895579, 54.61967537480017, 50.35667480960969, 47.00397791401033, 48.50387265605312, 49.77463037736955, 52.1869311794158, 51.04350536100326, 51.15917605738486, 53.732513689225726, 48.72606708157448, 50.087784567186915, 53.35033362911594, 67.81017088120984, 67.79045704872378, 73.55692955755418, 68.27420296207552, 70.38428121997465, 64.97467771653207, 67.84190285590388, 68.67723434202134, 66.33743855261034, 64.37653587710473, 69.28088711154076, 65.56182907473656, 72.1819583831295, 61.96162277652372, 67.02506142277872, 57.95785950076196, 64.34225828416886, 70.46110476216963, 79.67389722024241, 75.55008980535692, 91.50892749909433, 73.92150602033063, 87.27665870420395, 26.18531769321811, 0.6524312424082911, 63.657177109872144, 74.5814448018228, 57.80067443847657, 67.37756483016476, 64.10970095665225, 57.15071024433259, 63.04380862943588, 83.88188654376616, 22.360624344118182, 0.6215719950775946, 0.3047800214300233, 0.23794548435797616, 0.2634009772971753, 0.3265659072466435, 0.34857123128829465, 0.43255993255203773, 0.15803339740922376, 0.14699443814254579], [0.2280070870033195, 0.015693740138123115, 0.05866419020739775, 0.11667105399312512, 0.07345375890332846, 0.4743245334154176, 0.12203153973865895, 0.14948351909556698, 0.04706479165883315, 0.0992871476938167, 0.0805045563667532, 2.5171918446017854, 41.96687798346243, 53.98971919090518, 31.96775620983493, 62.57046484178113, 45.830479283486646, 26.909251905256703, 54.52270653940017, 71.1994360339257, 7.579413575510825, 8.247632480436756, 91.65066626764114, 67.1184059881395, 77.8733959505635, 64.22666603519072, 66.62068859223398, 54.65757723777525, 55.902541452838534, 49.69224491427022, 55.77914368721747, 59.8440331797446, 68.9492585582118, 63.07328916365101, 64.90892310296336, 62.32967445927282, 65.05430183103009, 59.9202879782646, 63.27582466986872, 57.57292593679121, 62.295051697761785, 60.75991838209091, 64.56257781674786, 60.03322086026592, 64.13410202149423, 54.13708656064926, 47.126928529431744, 44.401646121855705, 48.640351526198856, 45.09932202677573, 43.27493744511759, 42.57557099865329, 44.69478445668375, 40.961456837192664, 40.01171373551892, 44.23392949565765, 43.56744035597771, 44.28319838739211, 57.899184765354285, 60.480418128352014, 54.03259069688859, 53.57870186528852, 50.491023832751864, 48.92129913453133, 53.44533343468943, 54.42551020653018, 56.88691123839348, 54.550916225679465, 61.691732329706994, 57.28345894044446, 58.148561216169796, 60.704459990224535, 62.468232185609885, 58.21011497128395, 52.47270330306023, 24.563386248004054, 24.2547643569208, 76.60514462378718, 56.44792741344821, 49.46668117277084, 40.34089865223054, 35.59558383880123, 18.03327141269561, 30.1283509116019, 48.25884219138853, 43.24906549146099, 45.26025295257569, 47.98756714790098, 49.183113421163256, 49.39975377052061, 45.18060530385664, 45.12069894421486, 42.55954419412921, 42.068334010339555, 44.360657353555005, 44.64864169397662, 45.413817667192035, 46.68287307985368, 44.719283580780036, 44.066601184106645, 47.42988063443092, 53.90643942740656, 56.63343198837773, 59.61498637353221, 54.370247933172415, 54.36501941373272, 56.88413027794131, 53.43347218728835, 55.54559007767708, 56.264948844909675, 51.75508214581398, 53.21077177601477, 52.730971767056374, 54.950821476597945, 53.41135001951649, 48.39044555541008, 53.13299902023808, 57.77847382330126, 53.927804577735166, 53.390714430039935, 51.79288594953476, 46.982734357157064, 45.606429576873786, 43.0559632855077, 43.12114131066107, 45.92806000863352, 43.04714579736033, 46.29371512320734, 48.251597573680264, 48.127117233891646, 45.17207414873185, 45.74797614928215, 48.357583938106416, 64.92307893691525, 59.93936246441257, 58.92848137886294, 60.18113736183413, 61.43423265026462, 60.72557018649194, 62.74890915040047, 61.64759389815792, 65.45407764373287, 62.2639786812567, 63.27380464922998, 54.61685519064627, 64.60242517532842, 58.37473684741605, 58.51938209226055, 53.10830770000335, 55.81951272103095, 52.845940359177135, 73.79998314765193, 63.157043533940474, 79.74038923940351, 64.91032338911488, 79.00195598602295, 7.795829859472091, 2.940852685320762, 64.28574477472614, 50.97321256514519, 42.21156327955185, 39.09863695021599, 56.5774989897205, 53.835244486408854, 56.1802609505192, 51.99257773737754, 18.335339023220925, 0.1647256963676022, 0.37382078447168876, 0.2330258362475903, 0.21276100268287046, 0.16159317816697782, 0.0931478646253386, 0.4037020133147317, 0.05561611021778757, 0.0630512501623842, 0.16868820954715052, 0.05108669963515094, 0.029865734714774356, 0.14125306880281818, 0.09223170007669157, 0.320457183425465, 0.07729565153919882, 0.09698930526933364, 0.07577806966559542, 0.20693021556062086, 0.7153571529253837, 4.333295812529903, 55.54109504145961, 63.00894660334434, 33.09985030081965, 58.052788703672356, 52.70346418503792, 36.01316328971617, 54.82716091217534, 77.4619314747472, 10.231835995951007, 6.616420217098729, 97.78082878358903, 70.06138386264925, 84.4510381452499, 66.7973207658337, 69.16505952035227, 56.97675312719038, 60.844963212167066, 54.03649345521004, 62.89538221974527, 64.01069248876264, 71.4035483329527, 66.0940319491971, 66.90806496527888, 65.75802210838565, 68.11823383454355, 64.27261267938923, 65.36081937051588, 61.445415327625895, 63.15600410584481, 63.08120842902892, 70.11290811723279, 62.07663451471637, 68.78278532335835, 57.32849951713317, 49.517464099391816, 46.486252507855816, 50.010698226190385, 49.22381585644138, 48.52129190198837, 44.27831895889775, 48.622492974804295, 43.291807559228715, 44.837594032287605, 45.48818580565914, 47.186823121963016, 48.29991332946285, 58.85698833773213, 58.591361507292724, 57.55055665969849, 54.89819895836615, 52.329121020532426, 49.82693518361738, 57.66727070654593, 56.43803911824381, 59.04491693742814, 56.68695272937898, 63.67229000214608, 61.34268060807259, 61.646460333178126, 61.388913585293686, 65.85447711329307, 57.189106325949396, 59.69420648390248, 27.745620858284738, 39.69704551081504, 88.34239805898359, 48.335854007351784, 47.22119877415319, 43.889670910373816, 34.99377850563296, 25.67493300284109, 48.26383929098807, 52.62020795576034, 42.711414444831114, 42.46983566591817, 45.6701288684722, 47.851692322761785, 47.705125116532855, 45.59817691003123, 43.792917805333296, 40.09674287611439, 44.76180599581811, 43.69505074716384, 42.10397658809539, 43.93410351968581, 46.006656462146395, 44.87997916436965, 43.31549083032916, 46.340987528524096, 55.3066235972989, 59.89281961994787, 57.9078532034351, 53.79735439054428, 57.42172641138877, 57.52811677994267, 57.868072525147475, 57.629513971267215, 56.37198640454201, 54.25738173146402, 57.01450594009892, 52.01686505348452, 56.948535596170736, 57.87632126961985, 51.4156323863614, 51.057904381905836, 60.12968370991369, 56.05952255187496, 57.49444715438351, 57.09380449787263, 50.47458910172986, 45.71945267338907, 45.49377126078452, 44.471299571375695, 49.19562185964277, 47.767329985095614, 50.29086136048841, 49.81321081038445, 49.60101450643232, 47.05881657138948, 48.71380183004564, 50.97797432253438, 64.06457801018992, 64.04020047956898, 60.15122928927022, 62.82209665544572, 63.91977194816836, 64.19877406089537, 67.9471008239254, 64.85858340417185, 70.87492266008931, 65.94039270954748, 65.63529114569387, 59.162203650320734, 67.04902710453158, 60.0423482156569, 63.910840711286, 55.07772976352323, 60.006117282375214, 57.57177668233072, 76.94280578244117, 66.46430369346373, 83.73450740691155, 67.75406529826503, 87.65887014327511, 6.880083410970627, 3.9098801199466955, 71.02747932557138, 54.04273786852437, 54.96556958844585, 52.01788094735915, 60.136900871030754, 54.27161601281936, 62.42327790106497, 61.65872950707713, 25.68162064398489, 0.27721167331741703, 0.2083042861833688, 0.17269851129141547, 0.13145696461921738, 0.14809089382329296, 0.091037169819878, 0.3470942444137989, 0.09314856942622893, 0.05635785952871365, 0.28743634240761884, 0.15630070570736163, 0.20965004219643532, 0.1928687329974867, 0.27198186685000697, 0.47104806729382087, 0.3092958645955209, 0.25223192097919606, 0.2017109351412904, 0.273445799586273, 1.4980685110053709, 5.392757904145026, 66.93869083158432, 74.12117819632255, 47.33076234017649, 80.40458771490282, 60.98469372718566, 41.69223362399686, 65.20466196921565, 83.89698766892957, 9.547447119989704, 9.18140467136137, 101.07980881967853, 72.4706526725523, 87.90081762498426, 67.79642689612605, 74.65892730220672, 58.803640181018466, 61.09688528122441, 55.20103339226016, 68.17997978579614, 67.40346816278273, 75.3827065806235, 69.8086969314083, 71.06682854314005, 65.18871361209501, 73.23469115841773, 68.47022733380719, 71.02889922357375, 63.53416373652797, 67.4223033843502, 64.64206464828985, 71.66759444821265, 64.66282183124174, 70.02128155000749, 59.76774307989306, 53.11248502423687, 48.333516274729085, 52.82569700671781, 51.93601323712257, 49.67544932519236, 45.949554597177816, 50.599630340453125, 46.23455009152813, 47.623135812820934, 46.47587391637987, 50.97891961374591, 50.055730958138746, 60.11821077715967, 60.49757065311555, 61.27280750582295, 56.187078029878684, 54.35768458151049, 48.09280433962422, 61.035296224778705, 57.06804237058086, 61.102721768040816, 55.59047768192907, 63.97495577412268, 61.8309215576418, 66.97041496153801, 63.900046348571784, 69.45172986676617, 58.51648738307338, 63.37428792830437, 29.714454566278768, 47.12075079641035, 70.2675122599448, 42.08267419568954, 50.92259437807145, 45.174619766973684, 40.21849324626308, 30.32801720403856, 41.40726166386759, 47.82888766257994, 42.65015878985005, 45.112046195614724, 45.571226304577245, 47.604610458497085, 51.57842643799321, 48.720795416062884, 47.32030922366727, 42.705119040704545, 44.86415632309453, 43.98454127773162, 45.43657918130198, 44.3001587160172, 45.9513981111588, 46.033461939904, 44.66713174696892, 50.046458475051395, 58.06375172830398, 62.65135195947463, 62.53120583872642, 57.61900986394575, 58.8271116441296, 60.751312701932854, 61.06434529827487, 60.340428736902055, 60.28334648378434, 56.79754395638743, 60.37943278589557, 55.80969502848964, 60.298620193235344, 60.25525839098039, 52.850451084875296, 56.01488990168418, 64.32457623943206, 60.22984143226378, 60.89376534185102, 59.45165103481662, 54.999580460210005, 49.18514128654234, 46.35396272905412, 46.64225301434917, 52.91767266488845, 50.1970108093754, 53.30871335921749, 50.909340689259196, 51.581940881667606, 48.489885484018636, 51.09665347683815, 53.05080967564737, 68.27863524037024, 66.74764002523115, 63.746564003729056, 66.72310952217349, 67.73002901384908, 66.64764312005812, 68.56689806907409, 67.5765545137467, 71.85436202633765, 70.05022079713883, 70.19490918805523, 60.931769186450595, 69.23088473658409, 67.13327961583292, 66.77763046756868, 57.9320816839895, 63.211686072811005, 60.49746082675073, 81.95574391272761, 67.42198959473642, 89.54327875568022, 72.1397066116333, 91.09608234897738, 11.061452588727398, 3.0355617452052335, 78.93481285341325, 61.42616825719034, 57.27668500715687, 51.59730872800274, 76.43808303340789, 71.2724470323132, 73.27394623910227, 72.14411535570699, 29.917411727290002, 0.4409767260714885, 0.7179119029352743, 0.3101261200443391, 0.3229539559012459, 0.32050746943681474, 0.2875986611170154, 0.42981062685289695, 0.2825511529320671, 0.16624863319579633], [0.03794581343930575, 0.1427319555753662, 0.05423643949231314, 0.2784954528174093, 0.15723603777587414, 0.06096658319415105, 0.13831886012227307, 0.11186538444411372, 0.19496560757679327, 0.16968223927242143, 0.35983591070098264, 5.123367559525275, 55.21664442554597, 50.68123917425833, 38.6295763907894, 87.45295355396887, 65.2262467722739, 29.417678233115907, 47.1057398857609, 69.85451021502095, 29.945811648522657, 1.5958083372923637, 76.96903859415363, 71.0308054954775, 75.3121352964832, 63.637329916800226, 63.05876462690292, 55.54770031282979, 59.906383176003736, 50.880852514697665, 57.93189341022123, 63.63276035554948, 63.808341333943034, 63.71694226418773, 67.59816677339616, 64.95802725515058, 64.82708284931799, 61.17147307242117, 61.66551128510506, 62.01009934948337, 63.269462585449226, 59.90701075523131, 60.81394510884439, 62.30324552905176, 60.620419286912494, 51.14837777230048, 45.188952107583326, 49.6890599496903, 47.72500368856615, 46.03098692432527, 46.14637128768429, 46.72742336027084, 44.33547573704874, 44.74752072365054, 40.918863819491484, 41.275999546051025, 44.67308198252032, 48.664940864809104, 56.594875089583866, 57.31685792246173, 58.09025126118814, 54.03823106519638, 55.91765042274229, 55.88192155284267, 58.62975758890952, 58.28917426447715, 52.943497550102975, 56.765796292212706, 59.475475511243275, 63.82419555417953, 59.332352146025634, 57.8340498862728, 57.962817376659764, 59.81673348334528, 60.62399256613947, 49.18510598521079, 26.330821937130345, 27.687832578536007, 59.274842354559134, 65.38556168156286, 49.199014709841826, 36.484310550074426, 53.435782463319846, 60.523826999049035, 44.40512918656872, 41.444673230571134, 48.33601874689902, 49.87234446310228, 39.787295326109856, 43.452459996746434, 49.84129105844806, 47.076561374049035, 43.282876322346354, 41.41219208317418, 46.46848417097523, 40.684137421269575, 38.73166784163445, 38.288694966223936, 31.17495890586607, 46.64459466934205, 59.53926109498548, 60.004654238300944, 52.77796960646107, 47.62310443385955, 54.812903096598966, 55.28758833485266, 56.27375064357635, 53.628668938913655, 51.40470466306133, 54.33952400761267, 53.610712328264796, 55.647101017736624, 54.66131917891964, 52.41006305140834, 57.12543841331237, 53.36553281353366, 49.888841952047045, 55.904573240587794, 54.067150700476866, 50.84478239859305, 51.70316173184303, 45.246410908237586, 42.37880529895906, 43.77578881479079, 44.532162989339525, 46.99127727939237, 47.40114927291871, 47.751997440092026, 48.54896422355406, 47.05424701013873, 47.06823810454338, 45.715698965134166, 49.45863246917725, 59.63784594689647, 62.06448301192253, 58.35004944955149, 51.27363081901304, 61.969526352420935, 65.16224153580205, 67.24978969943139, 63.06145537284113, 64.16175080883887, 62.57022557720062, 62.19074410776939, 61.958830048961026, 61.04994235500213, 58.28328286447833, 61.3475247352354, 53.101404328500074, 58.21642998726138, 55.0590318249118, 69.24197719943139, 65.78274872995192, 77.10225797468617, 65.17727205830236, 69.2402748907766, 1.0218185534881008, 10.961187981790113, 59.157186938870346, 51.697348779247655, 28.712253685920473, 27.316188004709062, 53.2591659792008, 31.59751976689985, 43.79398076764999, 59.14150922529159, 22.649965824619418, 0.42325484476262526, 0.13200209746437688, 0.1345838903779945, 0.140296608029354, 0.19302069419814696, 0.07163386341304549, 0.05620893969711277, 0.06563907984884516, 0.07495234945728894, 0.053596254287948536, 0.26221222334331085, 0.05641468793093678, 0.23010935484161302, 0.04234564024955035, 0.014409267328559391, 0.1469298722522874, 0.1296887724029441, 0.1619362629829876, 0.2645415596423611, 0.47291836370864226, 10.161088205152943, 68.0110276129938, 58.31181418511176, 43.50400778555101, 91.1640727135443, 69.21286536801246, 38.0183103007655, 53.92701618133053, 78.8688385871149, 36.46343569601736, 1.1925701748940254, 74.06085214307232, 76.56843908371465, 82.18501429403983, 69.08063442476335, 65.75602169959777, 58.88400954584922, 60.84366098526986, 53.02481220614526, 63.51399098673175, 68.58321512899091, 70.17824695956323, 66.77339430778258, 70.18601325250441, 68.47031362595098, 69.00970228256719, 63.893025305963334, 65.11482008041875, 64.38398445806196, 63.28457940009333, 61.8240927111718, 65.93663507892241, 66.12243775398501, 63.69293343636298, 54.72022141179731, 49.33650555149202, 50.74406377730831, 50.128792947338475, 47.75200920720255, 51.04077539136333, 48.19114208221436, 46.71873531033916, 47.44395409860919, 46.183975050526286, 42.39267872225854, 44.98463976767756, 50.99421685741794, 57.799030965374364, 58.18288587754773, 59.66327075035342, 55.815327552057084, 58.723290428038574, 59.09599796418221, 61.414071667578916, 61.764735483354144, 56.958643544104795, 59.636002432915475, 60.88157853772564, 64.07822785838958, 60.644286909411036, 63.22157436801542, 57.489869748392415, 62.11995317089943, 60.857048034667976, 52.4584964782961, 27.987817410499822, 42.90141797834828, 74.36774623009467, 59.819577201720215, 47.28309377547234, 44.242597933738466, 68.47680122621598, 69.18085882740637, 43.18759410612045, 41.73286937898205, 49.207024189733694, 48.26971892387637, 37.39412000102382, 43.090727252344934, 47.240332095853745, 44.889887071424916, 42.873773113373794, 40.063186999290224, 48.92387220936437, 40.18818509194159, 38.46344440214096, 38.08215079769012, 32.21797008668223, 46.76302279195478, 58.35757647791217, 62.58033352513468, 56.426687778965125, 52.37641303770004, 54.96388689164193, 55.8446119677636, 57.16944740664575, 53.35849215907436, 53.675023509610085, 56.781344567575765, 54.36296016939225, 56.9230519571612, 58.89284664584745, 54.50605607801869, 58.77430869686989, 58.835125046391646, 54.45104875872212, 57.64271666926723, 59.97695838251422, 53.423983973841516, 53.44290548755277, 48.20466641456851, 45.39469611260199, 47.74861635700349, 46.385879055146255, 49.58862373905797, 50.25256726049608, 53.52382398420765, 50.203223843728345, 50.45546754713982, 45.17746348534861, 47.99758880369125, 52.73031280886743, 62.07226107197424, 62.740589803264996, 62.93310757606261, 54.840218482478974, 61.404732504198634, 66.1398530775501, 71.10039618707472, 67.07229460439375, 69.78908508054673, 66.45736894299908, 65.98630797478461, 66.10370451404204, 66.08806210179483, 62.54962136668544, 65.9942860757151, 56.11628709300872, 62.89129903239589, 59.36489997371551, 73.62147608110982, 72.92084663145005, 80.1333087490451, 69.72158893462151, 73.64282946432792, 0.8735190692447847, 14.454282195337358, 65.473018769295, 56.09087797903246, 39.59613469339187, 37.238350914370635, 57.67154216766358, 31.987079766488847, 53.007498864204656, 69.5194927338631, 32.22289266124849, 0.3687763099949206, 0.15965056305210437, 0.08118935470138827, 0.08340025380734475, 0.07431748473355848, 0.008559124994902842, 0.020646617312224644, 0.2186853291406747, 0.12827612925320864, 0.24955373888294546, 0.3005142293630108, 0.22631692850301344, 0.4000011651266006, 0.2517078095866788, 0.24981175729584312, 0.3383619758871294, 0.2677342770320754, 0.37590687253302146, 0.27255759724686224, 0.8998922282649625, 10.339327569930784, 78.14874633666008, 64.05002601685064, 52.630453186650435, 99.189085191296, 74.13012120031541, 45.45131944840955, 59.15269582502304, 82.75866877648139, 32.701768952031294, 2.9338718470065825, 84.73093063600602, 77.428920807377, 87.12235266162504, 71.70988544341057, 69.79106979985391, 60.883680928138, 63.96539303564257, 56.03710620634018, 65.6152949025554, 71.9519349067442, 75.10002920704504, 67.3853232783656, 72.19179568752166, 69.709194244877, 71.01353137723862, 68.047497810856, 70.66394621326079, 69.28990071819675, 68.7450756565217, 64.45729747895273, 64.86590646928357, 67.47222731190344, 66.2259961712745, 56.25224428792154, 50.79665491657873, 54.564754347647394, 54.60742189038185, 50.157155606054495, 51.66738579350134, 50.88130750963765, 47.93754516109344, 48.94046775756344, 49.07607193916075, 45.55354818221062, 47.40501672990861, 53.263425673207934, 63.65836558803436, 61.786790970833074, 62.340045206008426, 56.647952602755645, 58.55577776508947, 60.66589132432015, 62.30532830761325, 61.22362490623229, 58.13049870152628, 61.56503585077102, 63.63763978404384, 67.31708188210764, 62.21830660297025, 66.31336304449266, 62.912542589249156, 64.0839780530622, 61.557324471012244, 52.679659320462136, 32.29870227075393, 53.99899167399253, 67.97928779355942, 56.69352269941761, 47.20195954845798, 46.94785271921466, 55.9040476429847, 55.007405588703776, 43.3918672223245, 42.35935426527455, 49.136707859654585, 50.484979460316325, 41.462963242684644, 40.797458617917954, 46.866083068232385, 46.3714486552823, 43.858652807051136, 42.76526466492684, 51.06015974475492, 40.55337736683507, 39.21621391850133, 39.294453436328524, 32.05034171381305, 49.861726607045824, 61.58057235902356, 65.54368811268961, 57.87184584525324, 53.2864539084896, 58.46010331184634, 58.18089723587037, 61.647731181113954, 58.18798103640157, 54.70139403497019, 59.0045008351726, 56.35177443104406, 56.996514028118504, 62.07826622070805, 54.26784661508376, 61.45387195771741, 61.069522826902336, 55.7442855834961, 61.14407531676754, 63.960694036176136, 58.3246442579454, 58.793120384216316, 50.09590779581378, 49.00087225821711, 49.96155485030144, 48.70600808051325, 51.19941565298265, 54.31766856101252, 59.145121728220296, 55.273334441646455, 52.22328370617282, 48.50761851956768, 49.62446243532243, 55.42409073921942, 64.4095230102539, 64.22190427780151, 63.21247446921564, 55.93619146654683, 64.78490560285508, 70.33789527031684, 76.1773552433137, 70.34690103223248, 74.09933843920308, 72.5724381785239, 70.8061242872669, 69.99252273190406, 67.8641583842616, 62.7882230666376, 68.90619877846011, 57.11360070013232, 63.386451198208725, 61.357432642290675, 79.4466821609005, 76.89385460269067, 85.26998981352776, 72.48012911888861, 83.92925308596703, 2.7824315861348183, 13.068704931966721, 73.32863192404471, 62.31630702172557, 44.63139110995878, 40.62032045856599, 74.22599961680751, 40.49308661491641, 54.85655907661685, 80.63952984348421, 36.07803144762593, 0.7474095975199054, 0.4798976085599392, 0.2863613371887515, 0.28627035658686395, 0.31231023671646274, 0.17546188236484606, 0.23912561216181327, 0.29943082782049335, 0.4265352026108773], [0.16068127306718982, 0.017972141166307756, 0.0824373195909204, 0.3597776267317034, 0.05064212349093249, 0.03990928529791775, 0.03587447640095507, 0.04598049762388391, 0.10634886957104168, 0.09741277569123814, 0.10609163256782679, 11.82262872495959, 64.14317838607296, 36.975532500974595, 42.089228476247484, 79.47144016142815, 61.51010305650773, 28.41288858844388, 40.05354973577684, 59.115543134750865, 52.24120109311996, 0.8381233556616692, 43.3845990703952, 86.44659888359809, 68.79583112655148, 73.58129532106462, 63.02499301971928, 59.85199951356458, 52.17570143361246, 56.4307435097233, 63.72997630027033, 65.30451766906246, 63.251223564147956, 63.922725492908114, 64.14200951976161, 63.19618878826019, 58.658802740035526, 61.85561287787653, 63.82723146869291, 61.35391427624611, 61.48418011203889, 58.622167802626095, 61.09059379946802, 59.34070679449267, 60.04493697997063, 52.945462657559304, 46.35536301520563, 47.0370787958945, 47.491936452927135, 51.85085073594124, 50.44401422623665, 46.01216346986833, 45.06204774302822, 44.10146713256837, 45.229834971889375, 44.643005248039, 43.585118478344334, 47.75577468256797, 51.35006996893114, 55.04442491839009, 56.54097780104607, 58.597248984921364, 55.068629864723455, 56.99847913557484, 57.59350269071518, 56.81138992309571, 61.613908583118075, 59.6335195725964, 59.31353653630903, 58.08208488648938, 57.08215113609069, 58.978111128653254, 58.47036815458729, 60.54786720583516, 57.055365270183934, 49.653993960349794, 46.16381406784058, 36.5352072254304, 30.36632699351157, 42.36166454130604, 62.88584693785637, 78.36573185459261, 70.7879009554463, 44.75917800780266, 39.16072414767358, 43.30057013419367, 46.050622309407885, 46.97754506141909, 62.56342418732182, 42.792634963989265, 40.44342940853488, 45.3280040525621, 48.51497688601094, 43.82162955499465, 45.89023267069171, 46.93548156369118, 39.44768082711005, 46.053760205545736, 47.03210915288618, 58.02390436972342, 56.656997588373, 57.17569181996008, 56.70168122937603, 55.96690754736624, 56.084421757728826, 54.87292712734592, 58.011807780111994, 55.45105311178393, 53.47670847369779, 55.29344051114975, 54.158698820298724, 53.74379834821148, 52.786449770773615, 55.17801300171883, 53.72552010320849, 55.65580867951917, 54.51049227868357, 51.00590159816127, 58.46240574313749, 50.78979469114735, 41.036778111611646, 43.336463743640536, 43.685221287512014, 45.305909341381444, 46.899191794856904, 46.84671440432149, 50.08461921445785, 51.48703913534842, 48.00814390182496, 48.73842254761727, 47.287969281596524, 49.30729173844861, 45.79504459134994, 56.75660617889897, 62.780135139342285, 64.66969382378363, 63.26300244177542, 57.096346193744296, 57.058746353272475, 61.87428728226693, 63.33369531939107, 65.38127060859435, 61.54940128326417, 61.93785713564966, 64.2918283708634, 63.611532488176906, 62.11614062709194, 64.54575084870862, 56.99232493677447, 59.05884135153986, 58.28770337566253, 71.47630045490881, 70.97293484595515, 71.80400663806547, 72.37522925100019, 46.86963281323833, 0.24722104711878687, 21.88457412104453, 67.19129931542182, 48.56612851542812, 22.026222675077378, 39.804479229834776, 44.46893438216179, 53.894468353640654, 58.14674908115018, 51.664632289640366, 44.9573596831291, 0.8329939373558568, 0.10172144569937261, 0.03740604704005584, 0.019639552600922126, 0.14225805358540627, 0.043810679982866974, 0.04320456653893475, 0.14750790091291552, 0.4091173049903685, 0.0686385975249352, 0.04674823646764121, 0.19040504019827614, 0.18970829855290153, 0.07034441486241357, 0.01990039021738114, 0.13033265398154337, 0.08081255435583093, 0.05370062993719213, 0.10782288402439126, 0.058296636543086464, 19.40897018678727, 74.9195295764554, 42.94756858579574, 52.85518146330311, 81.99477149594216, 67.83299907561272, 38.09305890913933, 46.89030370404644, 62.22275849311583, 62.503819850183305, 1.060398312345628, 40.116115462395456, 89.31009384893602, 72.593791561742, 80.85533865036504, 65.24957703005883, 63.189269727276226, 52.174407051455596, 61.073484420776374, 67.48095066316667, 67.9999194606658, 69.45631903986778, 66.29437092811831, 64.49583476589572, 68.7480801920737, 63.72783860852642, 64.02303618769493, 65.52099327887258, 65.52799863200035, 63.575956590714, 62.43687675845239, 63.82836503367271, 62.26428462613014, 63.62937535009077, 56.41637586778211, 49.93358050623248, 47.77470011864939, 51.60724016927904, 55.000937600289625, 52.41316172384447, 50.23225330537366, 47.022401286709695, 47.75064422238258, 47.01811805848153, 49.13220890106694, 46.06739828663488, 47.75167188336773, 52.962768154759566, 57.92361720915764, 59.5429128216159, 58.78837039393764, 58.240305454500266, 56.34047800494779, 59.773006900664306, 58.60369343911448, 62.82562286623063, 58.83984365770894, 63.96276112525695, 58.91258009018437, 59.86894807507915, 61.62459311946746, 60.784617547065984, 60.679407811933956, 59.17013860517933, 51.60876989364625, 51.65355159390358, 40.020950917274725, 39.713797953821, 54.28575223492038, 66.15190259871945, 78.22396955182477, 67.43643176171088, 41.31368960103681, 40.32674281827865, 42.40415557738274, 48.036698756679414, 46.345270756752264, 59.64602801107592, 43.16815483954645, 42.62310228040142, 47.04488431253741, 48.41363068549864, 41.953181066820704, 44.22914420404742, 45.89539843220865, 37.56373897675545, 47.22241863127678, 44.789313577836566, 59.31270891620267, 59.087109873371745, 57.83037854779152, 58.16424285211871, 58.53201604658558, 57.80057637922226, 54.9869151269236, 58.6353861901068, 60.1259417687693, 56.72113226306055, 56.59955839956961, 53.56483236435921, 53.31303188877722, 54.52471087055822, 57.35166111300069, 54.14158944160708, 55.86780102022233, 57.08983113688808, 55.72872161865235, 59.27985122126918, 56.518679126616455, 44.630469352968284, 44.88893393547305, 45.92696566735545, 48.125301176501864, 48.819996080090924, 49.51576571310721, 53.65819654157085, 54.173301804450254, 53.832086978420136, 54.73045095320671, 52.07546134148875, 51.58938554025466, 45.826698118640536, 57.362628060002486, 65.41878415692237, 66.28014056913315, 64.28685872785508, 60.25539567393642, 60.83790686822707, 64.1886111997789, 63.784842414240686, 66.5648732646819, 67.9814294076735, 66.64765880953881, 68.41299210825275, 67.33796458090505, 66.83252011576008, 67.33591710367511, 64.0244129396254, 60.26193818738384, 62.13373637968495, 71.99349634109005, 77.30927282764067, 76.08445782815257, 77.35155597809823, 47.47763941364904, 0.2082437805591091, 28.054378071138938, 72.407730010248, 51.0394770868363, 32.5467098143793, 47.44978274068525, 58.275214549033876, 52.06196054335564, 62.99212355767528, 60.274019087514574, 57.9620760486972, 1.2557838280354778, 0.23506032062634347, 0.08005545264290226, 0.021418404930661765, 0.018053811884695486, 0.1008322014803848, 0.021946172477797638, 0.1777390480762528, 0.3042111551809696, 0.146203636221828, 0.10510013093270602, 0.24466775267595248, 0.3583580351644947, 0.28215511611873106, 0.08797370678474827, 0.20872833117121653, 0.14139165410832052, 0.2073826670887009, 0.22855931382265784, 0.4167441699293352, 24.3911490901824, 89.84277525255757, 48.97132504370905, 58.77651306890673, 83.7451134958575, 73.96038455347862, 42.96536830163772, 56.19746838846515, 66.30497701706426, 69.1833063863939, 1.1735762199086528, 49.093279377106704, 86.9208134374311, 74.16120206156086, 80.06544390032369, 69.81312136496268, 65.6355421773849, 55.3532801904986, 62.78785044147123, 70.07070341417867, 72.03162177916496, 74.19480892919725, 70.77510618394422, 65.08332344793504, 72.49523024405204, 67.20276832580566, 68.20548303665655, 69.4364953810169, 70.48812204791655, 67.51070576329386, 65.06717112756544, 66.19498591269216, 66.16078284478957, 66.1402217803463, 58.303137902290594, 51.27065766242243, 50.84724564706126, 53.75534972836895, 57.7971992185039, 55.90544008439588, 52.981972079123224, 50.400260186964466, 48.89842387168638, 47.61986455609722, 52.91874739431566, 48.24664362015263, 49.86884963127875, 55.16977994672714, 61.89249492460682, 60.24953173052881, 60.569644205031864, 60.65387318211218, 61.634128401356364, 63.5625107057633, 60.536621770551136, 63.955045823127996, 62.99927011612923, 65.2911933775871, 63.2223000064973, 62.20472343506352, 65.25220501807429, 64.79119708461147, 63.88776148519209, 59.900252511424405, 54.47652847536149, 55.582527037589784, 43.16852354234265, 53.3846975141956, 61.80617532422466, 64.98714300893968, 68.10168143241637, 56.53317228440316, 42.6388741308643, 44.23214481722924, 43.57032722042453, 49.1787439007913, 44.184727284216116, 60.624251442570845, 49.14598034274194, 44.723311854947, 52.10978992523686, 50.39659669322353, 42.562352611172585, 46.6124665352606, 47.44660562084567, 39.27037400584067, 47.64473630535988, 47.97124616561398, 62.829486400850364, 62.12560138394756, 60.54164632674187, 59.985254195428666, 61.47568033587549, 60.95634675795033, 56.58936415949176, 59.12346240012877, 64.87707737953433, 58.274857613348196, 60.045588093419234, 57.50587694106564, 59.13021279919533, 57.40089862577377, 59.34735913430492, 56.12071544893327, 58.622967966141246, 58.70274505307598, 57.037549864861276, 60.98813364582678, 61.185977997318396, 50.0606260761138, 46.339630388444476, 46.779116276771795, 50.9757189596853, 52.4358840142527, 51.51986545132053, 56.913571588454715, 56.669596241366484, 55.767384421440866, 57.88755493779337, 56.013003241631296, 55.53799636902348, 48.5041158430038, 62.00212124855288, 71.92337220714938, 71.53796795875796, 64.73633489301129, 62.53994487947034, 60.88230025383734, 68.25665427792457, 71.66989295713364, 73.79336218680106, 69.74323257323235, 71.72492381065123, 69.35710660872921, 67.84082812647667, 66.85074344758065, 67.18627868160125, 64.29484859589608, 63.015273386432284, 63.29286344589726, 75.01351741052444, 77.3517599413472, 83.26455254708567, 75.77630858267509, 60.75736099673856, 0.2280787621895152, 26.0428415190789, 80.84312438964844, 63.3566725638605, 34.62451481050061, 51.916915216753566, 64.1101324173712, 66.78141947715514, 71.67644331532141, 66.4263665291571, 67.95678907825102, 1.7700783860298896, 0.31766117700646, 0.18398260337210473, 0.20557655352017573, 0.23634141881860074, 0.24973119548972578, 0.10188292171205245, 0.45322150773098396, 0.34231854422438535], [0.13006522800893555, 0.04066372485530954, 0.12283431561363321, 0.1651686177619042, 0.040144941604305664, 0.181803910602485, 0.05796561761188412, 0.14867354965498372, 0.06926279830475969, 0.15501571578844903, 0.05842152419650267, 15.80485720788279, 58.411461999339444, 38.71164806427495, 26.780231421993626, 32.037597933123195, 45.58050271003477, 27.728364390711633, 31.393633004157778, 46.664712505955855, 67.77851735391926, 6.268412826522705, 12.657107095564566, 97.83321595961048, 66.69471940686627, 78.44284565218034, 63.18812047281573, 60.940661199631236, 53.21928724165886, 63.20295879917761, 65.47721962774953, 68.3901874480709, 62.60294598917808, 61.85680527840892, 64.25629169710221, 62.21600024930893, 63.10424058668075, 61.88474039877615, 60.56854986375379, 61.39077671112553, 59.099943868575565, 56.424722671508796, 58.9848066145374, 62.00811463017618, 58.65590410847818, 47.70295996819773, 45.34449761913669, 46.16136258648288, 49.405484353342366, 51.22501304072719, 51.82495524806362, 50.24495393999162, 51.01232251813335, 47.64231228059339, 45.67146639670096, 44.554822521824995, 45.50849191604122, 41.989714022605654, 45.682829503090154, 59.060829993217226, 54.92361199471259, 56.97681588511313, 59.26205150542721, 57.493399881547504, 58.463570687078665, 59.73973343449255, 59.42152330952307, 57.81957241796679, 56.73328376585438, 58.24286676222279, 57.77355517110517, 57.38039639688308, 56.56079753752678, 54.71701683536653, 51.143796443939216, 49.43169755320395, 43.18142814020957, 49.97920551607686, 52.81778166371008, 44.896555100717855, 46.65645199437296, 43.67702745622204, 37.39522610941241, 40.32942571947652, 52.64850785655361, 44.951017210560465, 49.81353244473858, 43.72906946366833, 43.11057052304668, 54.42279200400076, 51.07666507844002, 55.026268266862445, 42.564647197723396, 48.496824156853464, 43.40383437372024, 46.668454447100245, 47.61902909125052, 44.61965145603303, 55.400768326174834, 54.18940705637778, 59.78683717789189, 58.20935403147052, 55.72692125074325, 57.72763598349787, 58.4692189001268, 56.95514478991109, 57.270299388516335, 55.31883393564532, 54.80066137929117, 53.86581151716171, 55.06516248949113, 54.51336345364971, 56.295688459950114, 53.65265423251737, 52.81722860951578, 52.560760513428725, 53.44830659128005, 51.00396394729615, 54.01726599662535, 50.19688137115971, 45.76963155500351, 41.77843555327385, 47.00457411427652, 48.361576910941835, 49.16869871077999, 50.35377225568218, 50.027191792764974, 50.95939405502812, 52.684950597824596, 52.81266689300538, 51.48812955425632, 46.52451522888676, 47.30539244990195, 51.15755219613352, 61.628201700026, 61.26190331674392, 64.10451950565462, 62.06207467663673, 59.8271591432633, 54.89342935623662, 51.92754091755037, 59.61712014290595, 64.9007998743365, 65.09723217256608, 65.99564321579473, 64.3206617140001, 66.18919649431783, 61.57553211335213, 61.50389786689513, 55.177252061905406, 64.43885057203232, 63.785713180418945, 78.15023683732556, 65.24611357719668, 82.6840574510636, 23.40222151048722, 0.07119405233571607, 41.09731597285117, 64.58785357013826, 35.62014964319045, 20.32857575724202, 32.3028717502471, 40.82259708835233, 30.150504458335142, 36.51273988908337, 57.185666407308275, 51.42175520620039, 2.532301549949954, 0.038396472321642984, 0.004612355401003433, 0.048643423079122464, 0.10545908909050689, 0.14285947857124193, 0.045512280006322174, 0.09476485406799663, 0.20741226872609508, 0.06315077264462748, 0.10280773539336459, 0.07831002855973859, 0.10927447508419715, 0.059657503640459436, 0.037935019260452646, 0.0645392457203519, 0.03173567872915057, 0.06974384789505313, 0.03793356369339651, 0.12844749546099093, 23.046678266217633, 70.6924775338942, 44.83658598315331, 38.189074608587454, 41.63673993079893, 52.45660197350287, 32.560565587013, 38.644171530200595, 48.66416815788516, 77.0140281800301, 9.30895426580983, 9.885984928377214, 95.60195215286748, 67.79958048174458, 80.10245538526966, 64.72437950872606, 64.21821724983954, 55.725324846083126, 66.82843300604051, 67.66061875127977, 70.31035238696684, 64.39406102703464, 65.9327676219325, 65.84466334312194, 66.14768997315439, 65.6782607109316, 65.15079213726905, 63.70242949455016, 65.67971198789536, 62.87099292201381, 58.59595068039433, 61.75132097736482, 63.00483595940375, 59.81847501570179, 49.29083739557574, 47.96626867786531, 50.00182974723078, 51.70627609375985, 54.538062618624785, 52.684970209675456, 52.82901925425376, 53.464254948400686, 50.538841447522564, 49.22001115737423, 46.93565022560858, 46.12342149980607, 44.54179633048273, 49.204231462171, 59.10061459387503, 55.65972712732131, 59.177853907308275, 59.72185134887696, 58.3630834856341, 64.07901625479421, 61.24155798266011, 59.20063503326909, 61.16678191769508, 57.78744036151517, 60.15962316143898, 59.311069365470644, 60.393161081498675, 58.819439488072554, 60.369450353807025, 52.30905417473086, 52.64794695761896, 43.138874346210116, 53.701997649285104, 54.07979249954224, 46.5008201906758, 48.12624254534322, 41.79115579974267, 36.457567830239576, 40.19847346890358, 51.85370622142669, 44.65940860009963, 48.46910476684571, 41.23304174792382, 41.50955707796159, 54.35579399908743, 51.61841500189997, 53.64917509017452, 42.15612057716616, 47.920416170550936, 43.70940662199452, 47.77112291705224, 47.54341363906861, 45.12508023169733, 55.34229755401612, 53.10128273502473, 60.527517949381185, 61.27178376720798, 58.13649992788992, 59.34503316879273, 59.50792135730867, 57.46556282043458, 58.68154071992444, 57.8395765058456, 57.67791209682342, 58.30426362253005, 56.925468137187345, 57.131059169769294, 59.5064857698256, 52.82425749686457, 52.74532371951688, 53.741221351008264, 54.762324133226954, 53.12736257430046, 56.162543604450846, 54.200256332274414, 50.36534717006069, 44.68861849077287, 49.69382955181984, 50.79343857303743, 50.64316472699566, 52.403410711596095, 54.03734853190761, 53.42552154294906, 57.112878984020604, 58.88977543000252, 53.380575103144494, 49.24858954644973, 50.854039192199714, 54.11566257476807, 63.94370232858966, 64.92336134756765, 64.72936876358526, 63.954814403287834, 62.00716541659448, 55.12836364007766, 56.56009151089577, 61.559779874740116, 68.42893262063303, 68.60896941154235, 69.75843568002024, 66.89896506647911, 69.13821481889295, 63.659530531975534, 64.48921772741502, 57.29479851261262, 67.34020817664363, 68.66373354388823, 80.9270081981536, 71.1843192192816, 89.37072584705969, 21.248402941611506, 0.20128961742645313, 48.42334639641547, 68.3440995985462, 40.028685831254535, 27.8570181323636, 31.113787581843717, 49.9079752737476, 31.22928373275265, 42.662063183323035, 63.45402579153738, 61.648566645960656, 4.187456205967934, 0.1528461547868867, 0.11599427659905727, 0.06335255254300372, 0.1753665657053071, 0.046587036246614116, 0.05853095985648613, 0.06038965770013391, 0.22057054894826106, 0.17038138643387826, 0.20127984214453928, 0.37136436950775886, 0.19756371816319807, 0.16716363329079845, 0.34050291584384057, 0.1283682896304996, 0.19219630698282875, 0.13938888576963257, 0.5103636076373439, 0.24334265039332453, 31.154603765856837, 80.00589447636759, 55.084425249407374, 41.743114609872144, 43.737404500284505, 63.20065244551628, 38.33375123239333, 50.20423189286263, 55.711106254208474, 88.73302690444454, 8.090794547911614, 15.77299383378798, 103.33632484559091, 68.12965577648532, 84.52358630395706, 66.28923262319258, 67.43392928954094, 58.07938237344065, 67.1682200893279, 70.27778886979627, 73.6561341439524, 67.75417512462985, 69.12997784153109, 70.34431226791875, 68.58759249410322, 69.58894222013413, 69.11938744206583, 65.45592508008404, 69.17563423033684, 64.52107914032476, 60.61866598744547, 63.618561375525694, 67.0442496576617, 64.93854092013451, 55.32596480461859, 48.90718644665134, 52.635822911416334, 54.73278476345924, 59.189283693990404, 56.27976363705051, 56.14991357249599, 56.57578099158503, 52.25232885729883, 49.74280426579137, 49.28736609797324, 50.74909225586922, 48.009202941771484, 48.897400133071415, 59.278278350830085, 57.99617713497531, 59.50355183693671, 59.30503283777545, 60.609381737247595, 64.22013921122398, 66.6118005014235, 61.86285357321463, 63.145845167098514, 60.64083914602957, 63.59558413105627, 60.65681103737124, 62.282394209215724, 60.97971623943698, 62.682170021918516, 57.55696189018988, 52.01040490981072, 46.36201143264771, 53.27522808505643, 53.515587006845784, 48.09420462577574, 48.82357328168808, 43.50434118701566, 38.2781163338692, 41.2314727998549, 54.37603342917658, 46.75768444615026, 49.52252003454393, 46.50398554340486, 37.49407376012495, 54.341261617599, 54.54665260930216, 51.55749274838356, 43.298922738721295, 49.19786937775151, 46.00310671714045, 49.992066967871885, 50.33842402119791, 46.93877243226575, 57.33018613630726, 54.42737333236202, 65.46934350844353, 65.29028338770713, 61.34298263057586, 65.03544307524159, 62.018803088895744, 60.79739270671722, 61.26518241820797, 59.99612700554633, 59.665075040632686, 61.88595633352957, 59.10046554380848, 59.84698672448436, 64.1094656144419, 57.371775027244325, 56.10082903215962, 56.397842668717914, 56.87382228912846, 56.2920916465021, 61.28441379916284, 56.104939676100216, 52.68280506134034, 45.96105890889322, 49.704553311870946, 50.683372943632065, 52.19547017928093, 57.304525990639966, 56.56628885576802, 57.730138455667806, 57.87170856229721, 59.449803598465465, 55.71471483476701, 49.79321456724598, 52.02391747505435, 55.939145011286584, 66.60519523005333, 66.89206953971618, 68.24298089550388, 65.49992622867708, 63.96087838757423, 56.557455678139966, 57.63912770055956, 64.94849981800203, 70.38620318135908, 73.12232309772124, 74.27341322745048, 70.23876913132207, 73.26910603430964, 69.11002866683468, 67.22132113672072, 60.44318306830622, 70.04828314627372, 70.80799133546891, 83.16286902273856, 74.23867671720444, 93.45083021348523, 30.001754453105313, 0.32687678572631657, 52.41002382770662, 75.67664115659653, 49.278207363620886, 28.130448518260835, 40.7919123864943, 57.903499372543834, 39.603842150780466, 50.22365154758577, 71.75821688867384, 73.91192759236982, 4.680927636161928, 0.24686821766438025, 0.22500288853001213, 0.1847048097800824, 0.2794435938760158, 0.31837992069702, 0.23608580592178532, 0.30411606834780786, 0.29879531192202724], [0.14410578104997837, 0.07432674673656303, 0.09592848033794472, 0.05037804915299339, 0.036151945786250216, 0.06739816327969875, 0.15408308034942997, 0.15983428625810533, 0.11353135754865025, 0.12179421336059609, 0.22887393081140137, 26.529780241750903, 56.12221379433909, 46.508464890141646, 30.626646857107843, 25.063494328529607, 45.58560963599913, 26.962290194726762, 25.770613339639482, 53.953676531391764, 71.0762579210343, 20.953440704653342, 1.6743609092889296, 72.85833974038401, 76.56056296440863, 70.58429856454173, 67.22290577427034, 59.62224668072116, 56.491281370962824, 62.363955974578865, 68.80446034093058, 65.81522203260853, 61.01585695820471, 61.46417994653026, 63.12549591064454, 60.4214374480709, 60.833980575684585, 59.04693695806689, 62.06914278768725, 59.78497405206004, 60.16840927062496, 57.91546652393957, 62.007055590229655, 58.33441095967447, 52.839095823226444, 47.886899517428496, 48.17683327582575, 50.16861284932783, 55.7051520962869, 56.63332608438308, 56.36903285980225, 53.41991255360266, 52.8859563796751, 50.51622898347917, 49.32913934030841, 46.441074648211085, 45.86171703953897, 43.878409785609094, 46.98824528724917, 52.77797352883124, 54.60888493445612, 57.48663771537043, 57.02080526659566, 57.2320641240766, 59.35453707172025, 59.16083866550077, 60.989992849288456, 57.84582876390027, 57.38265568210233, 55.7185273785745, 56.34907191799533, 58.97070177139775, 56.41332818615822, 55.43276309967042, 53.22171126642535, 49.42934805347074, 51.411435450277025, 46.32265437033869, 43.877888110376176, 44.15167347077401, 43.27745168439804, 41.84328409933275, 46.37901098497453, 46.92358501495854, 47.13087835619527, 44.57319098134195, 40.81339913029825, 46.77725707331012, 44.64363674963675, 42.95652727926932, 42.23696847115794, 44.2681247188199, 52.27594937047651, 39.08901929855347, 48.10085696558799, 41.1626430480711, 47.448335386091664, 42.764240926311864, 49.2062867841413, 57.76949551797683, 56.594325957759736, 57.61734677899269, 56.49157947109592, 55.79864178934405, 56.73990472670525, 60.07672386784708, 57.59074526448404, 52.77099955466486, 55.009421686972345, 52.46861619334067, 53.30379470702141, 52.46725905326105, 54.27636600309803, 50.85857345211891, 53.650775417204834, 54.85755143627044, 56.21899435597082, 51.181917959643954, 54.7372680325662, 46.32042254171064, 45.33785704643496, 46.490692630890884, 48.184062204053326, 48.02251154376615, 52.09034281392252, 50.16656537209788, 52.799248464645885, 53.204896065496634, 56.8242984433328, 52.789105215380275, 53.9312994095587, 48.442162006132065, 49.21699093234155, 46.0599850070092, 50.601803333528586, 59.94730134164134, 63.596988339577955, 61.920834049101806, 64.34605906086584, 58.46315099347023, 65.34405123802924, 58.76726804241058, 63.28596399676416, 62.98107031852969, 68.65590449302428, 62.88497224930794, 67.5235632927187, 61.2012791633606, 63.31012187465545, 54.129245742674804, 65.45234003374654, 66.68464676026376, 75.05610650585544, 65.15174527322093, 79.0035092446112, 4.559214038233604, 3.208526502693853, 65.57360402999386, 66.31719912252119, 23.423312094903764, 24.06921663591939, 39.43100290913736, 32.9489488755503, 51.69361468284361, 51.929859038322206, 54.622962321004565, 56.67838235055247, 7.720626746454547, 0.2727604573292117, 0.25375447476342805, 0.0327816185721707, 0.1386818785460726, 0.10539142054415519, 0.034213314328583024, 0.056067512205411354, 0.02545378647834784, 0.06540307880289133, 0.1005660855181275, 0.06518816049661368, 0.05111884085401412, 0.0052880564415376755, 0.06414919588414413, 0.21740628406405452, 0.14315705776454943, 0.09800301579337928, 0.15568987316181584, 0.19951043950934566, 35.05828972785704, 68.11868882948353, 49.06041383743287, 38.953101327342374, 33.92869026430192, 52.341511787906775, 28.256680196331395, 32.33716307147857, 60.808524393266254, 75.72654154992874, 26.384109297106345, 0.941311170256907, 68.43234508268296, 79.12070182061966, 72.97971356299617, 69.921888689841, 63.97908210754395, 58.03637750687138, 64.48852346789452, 71.5401880202755, 68.4340238571167, 64.48997866722846, 64.05293249314832, 67.67606504501836, 62.78171585452173, 64.40394539986887, 63.69113306845389, 63.4262671778279, 63.81045156909574, 61.16172206017279, 60.65622660421557, 62.94480408391645, 59.92635588492117, 55.46562863934425, 48.57949987534554, 49.151008821302845, 54.15078739966116, 59.66356100574617, 60.80137391244212, 60.01886890780542, 56.11177636731056, 53.09039423542639, 50.779945619644664, 53.28651666641236, 47.64883910456012, 48.825554078625096, 44.98957018698416, 47.94840228173041, 55.211702239128854, 58.27224531481343, 60.15843468327677, 57.257641899970274, 60.48303827162712, 61.14672683900403, 60.95566426554034, 64.21538529857513, 60.75516839181224, 61.98700835627895, 59.897432327270515, 60.32542567099295, 61.52483155650478, 57.7397874862917, 58.59396203871697, 55.98935919423258, 51.22476593140633, 54.21960930670462, 49.30161999117944, 46.188630903920824, 42.72649988051384, 42.126220349342596, 42.509526129691835, 47.14338679467478, 45.64131513718636, 44.51339052569482, 43.547267606181485, 39.88955543887231, 46.36827938018307, 43.907537306508715, 40.52843501490932, 43.164832592010505, 43.803280707328554, 53.08979019041985, 39.26523570091494, 48.668168975460915, 41.68365932280018, 49.56387750564083, 41.70450672026604, 52.827065913907944, 59.18781280517579, 60.37542804594963, 59.04408147258144, 57.36413032777848, 57.578460401104344, 59.43335710033294, 61.27671810888476, 58.66503538623933, 54.715706763728974, 58.24383166528518, 53.75682453955374, 55.14515922915552, 54.47828177482852, 57.765275047671416, 53.6535995237289, 55.737790138490745, 55.73394621572187, 56.91707426501859, 54.77236540086808, 56.555263073213645, 48.97239585076609, 47.62524997034381, 47.86361632808563, 50.70123933976697, 48.42958296498945, 53.70521791519658, 50.74911186772009, 55.5897363539665, 55.77853179747059, 57.17743727468676, 54.85120504133163, 58.28070978964529, 52.85775061576597, 52.22969285903439, 50.562885576678866, 52.98905587965443, 61.01527252504903, 66.47978136616369, 65.28937339782715, 67.74330231451219, 63.15649440211635, 64.51166152954102, 58.827939264235965, 61.121243199994495, 63.782292873628684, 74.09022285092261, 67.15306405098208, 69.15747365643902, 65.12952504619476, 65.41324969260924, 56.97507435275663, 70.20804128339215, 70.8114508659609, 81.94948380993259, 68.66197632205102, 80.9983874905494, 3.1682006149522723, 5.461636685555981, 75.7134957467356, 65.70730193968743, 30.58658572935289, 26.869808550803896, 35.40304253178258, 44.841143777293546, 49.55578173360517, 55.30025759050923, 67.52514008552798, 63.52295752494567, 15.104778851232222, 0.46650872055080633, 0.10112392010107156, 0.11957759923872449, 0.1700254006972236, 0.043574226945037806, 0.09931000775747723, 0.055554359700650945, 0.06928171301561017, 0.24746884591877463, 0.14058097986684692, 0.17680000814218677, 0.16072693190747694, 0.08485771310065063, 0.2300488951826288, 0.4368978901015174, 0.3225163664788969, 0.2651188528585819, 0.38052304257308284, 0.22215760733571746, 41.11116586192962, 77.17174668465891, 61.70974385353827, 43.60937049311977, 39.49242330366565, 64.00585228397001, 39.57939401749642, 43.156811345008116, 68.20680095303443, 87.02777647203015, 27.790569259274392, 2.672008775895642, 78.72295779566612, 83.10295089598625, 75.4736271212178, 70.17812144371771, 66.75588484733336, 59.82456253420923, 68.84897924238636, 74.1934439443773, 70.66525628489833, 69.41394175252607, 65.96278159849106, 68.98291249429026, 64.31477815874162, 67.07670334846743, 64.94845667193013, 64.71728786345452, 65.12757170584895, 65.53996578339608, 61.84455963873095, 66.76914245851579, 62.69501578423285, 57.05972302344538, 52.124028128962365, 54.51184157402285, 53.624872084586855, 61.728563385625044, 64.15124277914724, 64.090551945471, 58.888504582066695, 54.76582288742066, 54.30513658831197, 54.44629876844345, 50.63666535962013, 50.560908702112016, 48.38239685181649, 49.455133714983546, 57.732260457931034, 59.16549059652514, 64.04049857970207, 59.330481175453436, 63.32442283630372, 63.8719190320661, 62.983753219727554, 67.71939154594176, 64.49431680863904, 63.91655168225689, 63.294153905683956, 61.437319555590236, 64.77466821670532, 59.20273742368145, 60.75717272297029, 58.07526388475972, 52.29119170096613, 55.23109051489062, 49.0043592453003, 49.14695309054468, 45.03198277565741, 42.60583208453271, 41.30932400303502, 48.166215419769294, 46.24663883639921, 45.902576369623986, 44.33825669750091, 39.88867682795371, 46.2144910904669, 47.92930818373158, 42.79384305400234, 42.645267594245176, 49.33210465215868, 56.655154074392016, 39.29093507028396, 50.564811460433475, 43.17450123448526, 51.49457400844943, 40.82566438182708, 56.029924346554665, 61.984396057744185, 63.99235933057724, 62.839488444789765, 62.464898170963416, 60.51832783606745, 61.135202915437766, 64.60281741234564, 62.891098991517104, 57.35317122551703, 60.907309286056034, 56.49121076829972, 57.00133069869011, 57.777971759919204, 61.22464472247709, 55.60646526275143, 56.00534677505494, 56.383369122782064, 58.27666974836781, 54.27026671748008, 58.52395949825164, 54.37543330654022, 51.74070665913244, 50.64752640262727, 51.24867669997677, 50.31700395768689, 55.100063739284394, 52.962324926930094, 60.093150754128736, 56.01768262924687, 58.94235480216242, 56.59230201475082, 60.98307378830449, 52.38847824835008, 54.52165534419399, 52.74757908236597, 56.8875741189526, 62.909765551167155, 68.52502284511444, 68.15834399192565, 71.65814938083773, 64.70654841392272, 64.53439950942993, 57.76039954154723, 65.83406509891634, 66.31475940827401, 77.63173087950676, 69.80025599079748, 73.52968477433728, 69.41196487795922, 69.45910392269012, 59.79139497203212, 72.23668329177364, 72.28897633091097, 85.93357639928018, 70.60575392938429, 90.4869931743991, 6.270946187357749, 4.174600147431897, 78.16906421415268, 76.45568663074125, 39.03624380788496, 32.11623949389304, 54.6204637712048, 51.89075300770422, 64.99642725913756, 66.54985058692195, 67.5994219318513, 78.57207205987747, 15.921331009557171, 0.7023096949823442, 0.3591931935760283, 0.20645672725814007, 0.24132469819197733, 0.24292625096296114, 0.13622184764714013, 0.23411331337786492, 0.19099020879835854], [0.030509905491565025, 0.16183805051109484, 0.04006359838850556, 0.08950925342017606, 0.10277880791334376, 0.017850072716452905, 0.11486455738063782, 0.030513015808537606, 0.19101725170208564, 0.15972171729851156, 0.33686890116622376, 30.67887321595223, 54.255514683262, 54.240209594849624, 31.920634815769812, 28.577863477891494, 40.14293662963375, 34.97231137367987, 22.40567864910249, 54.6438410974318, 69.36287249288252, 42.87272976290795, 0.15276700258255005, 32.44841325667597, 87.30817102616834, 67.02409651971632, 75.47108542534613, 56.872053300180745, 62.335267759138546, 60.94069650096279, 70.11972519659227, 61.185887782804436, 64.31882604475945, 63.08489545699089, 60.020269193956935, 59.44576747955815, 64.17552225051388, 59.944230125796416, 63.9262124799913, 58.689059903544766, 59.632574281384876, 61.24466449983659, 59.628746048096694, 55.291585230058246, 51.19633659239739, 45.86970690757998, 47.95063411035846, 52.38226129162697, 57.311519576657204, 55.4080129438831, 58.0160439398981, 56.83683041603335, 51.5857808820663, 53.28669709544028, 53.14542901131415, 51.717670579110425, 49.317431065344046, 46.688870383847146, 49.82598597003568, 52.257659358363, 55.37538666878977, 57.360149122053585, 60.704620807401604, 56.24573707580567, 54.1568317720967, 56.29702598817887, 57.13844891517394, 59.83185422035956, 56.266788436520486, 60.44545412063599, 56.87439495517362, 57.90011828945529, 58.47965632715533, 55.82677695059008, 51.69472863597255, 47.83956435418899, 47.79848144900414, 48.77876412483954, 40.46115067697341, 43.88879622182539, 46.910150897118356, 51.34390792539043, 46.64942310702416, 44.49904641797466, 45.742480908670736, 40.1478042910176, 39.78796212903915, 40.219964135077696, 40.741294199420565, 44.98425537540067, 49.91869511142854, 54.20024064279372, 49.80831961477957, 42.06900081326885, 45.27833900144024, 39.312959178801506, 43.48350555666032, 45.56531137035739, 43.09804639508648, 51.94031215483143, 59.86510022994011, 62.28939171760314, 54.5451307296753, 55.55140695264263, 54.5870687115577, 54.663288208746145, 54.41724969494728, 56.400337296147505, 52.92255993812315, 53.56048245583811, 54.36742382664835, 55.811244364707704, 51.82796370598578, 52.83384769193588, 50.77220286092451, 54.32035146221038, 55.52429160764141, 54.10659797729985, 49.67263306340864, 49.00546535368889, 47.35530853271485, 48.59859789571455, 52.5124918260882, 52.52114065231816, 52.282378135188935, 49.10923950133785, 53.02093298204484, 54.28133172373618, 58.32216139762633, 57.9103752874559, 59.43220392350228, 54.64277421274493, 48.225584414697465, 48.33228072812481, 47.89474033540296, 50.85450987662039, 60.255187788317286, 61.799107213174146, 63.56132614997126, 63.45954456636983, 62.334216563932365, 59.985167903284875, 58.64637274895945, 60.825943639201505, 67.35001410207441, 63.36239922431208, 66.70876149208316, 60.709253126575106, 60.60112514803487, 55.3620231536127, 67.78781337122764, 69.4855877660936, 70.18160450843074, 71.55111574357556, 57.72469028349846, 0.41409133002161985, 19.833421630244104, 73.40649097196518, 48.03329806174002, 16.283288309651038, 34.10767193763487, 29.0083122253418, 30.391557639644994, 35.57573272335914, 32.91879761603571, 37.85200965019965, 60.868783766223544, 18.787052900560443, 0.16657412863306462, 0.07631195634002648, 0.08371445710860914, 0.065019590509755, 0.06978744595882393, 0.11828392954362978, 0.1114861402780779, 0.09722601111617782, 0.06858782887819313, 0.09966033210437145, 0.07815968380459855, 0.14918779383503622, 0.049624406327042854, 0.0862275472571773, 0.1702115140975483, 0.11705049734202125, 0.007614662115942808, 0.14194133751575025, 0.2177062074864103, 42.54781238494381, 65.02990861092844, 61.779424759649466, 34.57480661330685, 33.37442013525194, 51.31585121154786, 46.893516125217566, 30.088784002488662, 61.98607875454811, 73.76334036550215, 53.52423191070557, 0.3210216676515918, 27.751798591306134, 92.73568014944755, 67.59196158378356, 76.76897418114447, 60.99901037831461, 65.16363789958339, 63.20470817627446, 72.64336247597971, 65.59127822999032, 67.03893092370802, 64.3704052125254, 65.10236263275146, 63.791596735677416, 66.45602749240014, 63.13267777043005, 67.22378438518894, 61.083415862052675, 63.443270652524895, 60.30012246101134, 63.255255760685095, 60.96645078351421, 51.52048518580776, 48.78354157170942, 50.279007957827666, 54.463380690543886, 58.51449874139602, 58.72688331911641, 62.52136853433425, 59.39448641192529, 54.67117609516267, 55.11103068628619, 54.30745863145398, 52.77335689913843, 51.364461145093365, 49.80541313848188, 53.55530100484049, 54.570186830336056, 57.956482748831476, 60.34418244515697, 64.81489996756277, 59.767805837815814, 56.95785122532999, 61.56599683146323, 60.61652437333138, 59.851779860834924, 58.93443161441434, 63.43559457409767, 59.91354934630856, 59.07309132237589, 60.40282187923309, 58.12129289873185, 56.55425502407936, 53.434307652135054, 50.4054416379621, 51.608993468746064, 42.52409773488199, 44.80327329327984, 45.88020709253127, 47.510371592737016, 45.249034973882864, 41.65984269111387, 45.14707296125351, 39.912254195059504, 39.89473296749977, 39.21191500079247, 42.32810081974153, 44.31406744064824, 46.84618096197806, 52.85805656063942, 49.07835868097121, 41.66183133279124, 45.15628660878828, 39.17640186125232, 44.024420015273556, 43.4860864762337, 44.411557951281154, 53.15461127988754, 58.18053245544434, 66.05833053588867, 57.87496805191041, 56.65469907945203, 59.55659404877694, 57.26116418838502, 55.95374799543812, 57.60894898445376, 55.30697661061441, 55.243826450840125, 55.6356280849826, 55.78481151211647, 52.852125936938876, 55.35794781100366, 50.3179374817879, 54.91184096182547, 58.431854401865316, 55.20065292235344, 52.65185756068076, 51.971004701429806, 52.186213385674264, 52.69330524629163, 52.442740317313906, 52.86847045344692, 53.528672033740634, 50.98153583465084, 53.258573701304776, 57.86824903180523, 59.84662978879867, 60.49914352355465, 63.163083984005844, 56.24125380669871, 51.352443002885394, 51.18274557975031, 49.8200318121141, 53.16693144459879, 60.896020704700106, 66.76467880125969, 65.94691168877387, 65.29258974136846, 67.64937723836591, 64.13986006090718, 60.50686274805377, 60.523109205307506, 69.8614449654856, 66.86138091548797, 71.12138871223696, 62.43044407136979, 63.53787037634081, 60.12971901124524, 70.48576078107281, 72.6597422938193, 75.60879199735581, 77.84995586641374, 55.05676077258203, 0.26000699328799404, 27.868551861855295, 77.24096082871961, 51.42191210100728, 20.086353709620816, 33.0504088247976, 22.64284868394175, 36.84471753335769, 39.66390932759931, 31.2385993619119, 53.0718884929534, 72.53769382353752, 30.90414866324394, 0.08939505269330356, 0.05942272450474482, 0.029689442561638933, 0.09144780826905081, 0.06106123718763552, 0.1309819901061635, 0.09863565886212934, 0.04368564677274516, 0.10651257489958119, 0.16551734098503668, 0.10291404541461699, 0.18387121418791433, 0.2157342818475539, 0.24305078621593215, 0.19352520906156112, 0.26985367459635584, 0.2845702542653007, 0.24711362627004427, 0.32794967654251284, 52.29970324424006, 74.9407103753859, 68.91664797259916, 45.804313152067124, 44.13494063961891, 54.15521575558571, 48.380882816929976, 39.74670271719656, 71.01702228669198, 81.89153471300679, 57.555389019750784, 0.38815778289591113, 40.12090467637585, 94.40862594112274, 72.27591483823716, 79.19494444324125, 63.05729766045848, 68.05563280659338, 64.66603033004269, 77.26383609156456, 66.07832677902715, 67.89879291288315, 68.05539746438303, 66.67051838290307, 66.24150522293584, 69.83733023366621, 65.48972022148871, 69.41198841218026, 63.144150703184074, 67.10095928561303, 65.4277075490644, 65.48352679898663, 60.90959995023666, 54.31558186008085, 51.784884314383234, 53.92110516948085, 56.965240970734634, 61.56913080523091, 59.56983204810851, 66.0139528397591, 62.21249757274505, 55.22378313925959, 57.10983130239672, 56.75147179634341, 54.641291556819795, 52.51906964086717, 52.55108402621362, 56.45805497323313, 55.736950751273866, 59.96125713471444, 63.89714771701444, 65.22751762020972, 62.419453590146965, 58.30945291826802, 62.12381670551916, 64.99034758537047, 62.6729053835715, 61.73356832996492, 69.02391695207166, 64.95847440535023, 62.01877170993436, 62.81289477502147, 63.600679289910104, 58.975840076323486, 54.8234542723625, 50.80147158715033, 51.406230465058364, 43.11772884861116, 42.30561779391381, 46.070018429909986, 49.508889798195135, 47.88969224499118, 41.861244632351784, 47.09758527817265, 41.05780593810543, 41.49635437996157, 39.84717030679026, 42.734819227649325, 45.077811748750754, 51.389148542957926, 54.55525828946022, 50.353125064603745, 43.38631706853067, 47.62721115542997, 39.98890123059673, 44.49476711211666, 44.99968597965856, 44.678016324197095, 53.772969015182994, 62.5258949495131, 68.93879367459205, 60.20066292055192, 59.773885511582904, 62.29796994116999, 57.333127913936494, 58.058566354936175, 59.743738174438484, 59.26837044377481, 58.252041186055834, 59.85240351769232, 58.92283708818498, 56.28519611973917, 61.21135573233328, 51.351784044696444, 55.13322737909133, 61.56631062107702, 57.227898566953606, 53.29325529836839, 52.51588075391708, 52.84281815251997, 55.10708085952267, 56.71248735920076, 54.36145005687591, 55.277111684122396, 51.73083405340872, 55.18180985604563, 59.302651959080855, 61.17175940544375, 65.57949542999268, 66.1102548722298, 57.824785247925796, 53.5890059317312, 52.062164506604596, 51.57404515051073, 56.457246964977635, 63.18274682567966, 67.19493927494173, 70.21089676887759, 67.01611841878584, 69.88119017693305, 64.99615661559567, 59.96715245708343, 62.4320718549913, 75.84215733312791, 70.90915710695329, 74.91188095461938, 65.84280413966026, 65.57858936248287, 61.29228599609868, 75.14409311356084, 74.9595848206551, 78.50801975496354, 77.78591140624016, 72.20190755782589, 0.5327718019966157, 24.964540773822417, 85.86262072286299, 61.29764395375406, 28.68729368332894, 42.5767320202243, 40.0448420739943, 43.681851971533995, 49.87861241063764, 48.27489253013365, 51.979743742173724, 81.4687502768732, 35.92786350557881, 0.4412047138377544, 0.17308089641794083, 0.2456369305089597, 0.12006919019885602, 0.12126231851476817, 0.25391726844733764, 0.2155221980665961, 0.21564982831478122], [0.11029092054213248, 0.06691338284121406, 0.10381432129971443, 0.08393317521099122, 0.03253008126311245, 0.15874443425526544, 0.02337776289712037, 0.07198938949694557, 0.060131872944053144, 0.12960090211802913, 0.07264696106675171, 38.70350914616739, 56.6759700928965, 52.04334497451783, 31.160128424244544, 35.94293717415103, 32.89755405918245, 18.10265225748862, 19.87203344222038, 52.43267159308157, 60.9052304298647, 67.19199749731249, 16.027518395454653, 4.6143002952298815, 86.52823125162433, 64.83790466862341, 75.77491221889373, 61.14275347801947, 61.32109580501434, 59.41495726185461, 70.5204188439154, 62.11321846131356, 65.73851616151872, 60.22867256595243, 65.58788930216144, 60.375867351408935, 64.07747868568667, 58.864491831871774, 59.76719002569876, 55.61343531454764, 63.65539635381391, 58.2336413475775, 60.94723509204004, 50.39661238270421, 49.05822123250654, 47.83799148374989, 51.55888518979473, 55.749678842483036, 58.897882969148704, 57.735437577770604, 60.554868636592744, 57.575903015752, 50.472463177096465, 51.981563721933675, 55.6235707190729, 51.97217356774115, 49.743420077908425, 52.91517411508868, 56.42894706418438, 54.69316097997851, 54.01180605734549, 55.93800752393661, 54.56148309092368, 53.13214786591069, 54.60689237040859, 53.69920099935224, 59.19628512474799, 58.19234663440336, 56.321556491236535, 55.01732526286956, 55.130936714910696, 57.26299593525549, 55.90214137108096, 54.923812035591375, 51.3720509313768, 51.16553029706402, 51.270685119013635, 44.845407393670854, 37.92472647082421, 45.69027416167721, 49.42701032084804, 45.829035851263235, 43.1250479913527, 40.652546651901744, 38.867170041607274, 41.75849030094762, 40.47067026938162, 38.63585610543528, 37.961228047647786, 37.7238069811175, 44.510287930888516, 45.801673396941155, 48.023056753220104, 45.24623047920966, 47.45575651045769, 42.60103502581197, 40.53152192023493, 45.84796128734466, 39.83132785366428, 45.84339564846408, 51.25354043899044, 53.52904073653683, 54.86188173294068, 53.92870280050463, 54.60448011275261, 58.12913763907648, 56.87314764145882, 53.90512543339884, 53.08550696219168, 55.42236881871378, 51.8961109653596, 51.18451456869803, 51.38408476306547, 51.66320062452748, 52.48862028121949, 54.314479674062426, 52.24095790616928, 51.204753998787176, 53.67219155834567, 53.771168647273896, 53.86732555204823, 51.505513498860026, 49.64845165129631, 54.886231806970414, 52.45726093169182, 48.76148608423049, 52.0876246113931, 59.06582709281676, 61.44689013881069, 58.84953975677491, 61.10111359627017, 56.45543482995803, 51.89801331489317, 46.52256188854095, 47.72261104276104, 47.784211866317264, 52.22629608646516, 57.5849558461097, 60.53308771502588, 61.28715945828346, 63.73544408429054, 64.56116576348582, 64.11738487981981, 59.293775635380904, 66.99413745634018, 65.10497100891607, 66.56325724817091, 63.94076055096042, 60.59457871221728, 60.48416399186658, 64.32845154116231, 74.34019550200432, 66.67926526838734, 79.51113454757198, 23.717942891582368, 0.11006318558488162, 45.877775223024436, 63.89201333445888, 38.822239291283395, 13.684585690498354, 34.685005603298066, 42.92396768446892, 34.93164816210347, 44.70040521314068, 40.41426266393354, 42.31624741708079, 58.88403308007025, 43.15217510346444, 0.5399447751622046, 0.058914042123022585, 0.0426855726137517, 0.050626020322764115, 0.04228447962011542, 0.18041546817027754, 0.06478563491855899, 0.06775500703482859, 0.026987684109518607, 0.12503835823266737, 0.14373559204320754, 0.02360356731280204, 0.007886650620944678, 0.09516098281188358, 0.032429018944141366, 0.0820121867582202, 0.06730966480268587, 0.14152129150686726, 0.02305195527902294, 50.635661232856016, 65.87457533805602, 56.67579358623874, 29.690769333993238, 42.74994780940395, 46.45326145233647, 32.00668377261008, 26.816515307272635, 58.436933871238466, 66.76354915865006, 73.59342328963741, 23.64683032035828, 2.7133718853996647, 80.9365003339706, 68.4959973058393, 78.28921425727107, 64.94591497605848, 64.27776275142547, 61.568554216815585, 73.08600979466593, 65.80698505524667, 68.21257468192809, 62.38043385167276, 68.6155354592108, 63.20124864578248, 66.00315847704488, 60.03840623363372, 61.4113534650495, 59.535452473548155, 66.88648408459079, 61.75111309174569, 63.93966620968234, 52.91214996768583, 52.248481012159786, 49.21890504898564, 55.020239583907596, 59.654849421593454, 61.34699129289197, 57.606979954627256, 63.9323627564215, 59.204792745651744, 55.25162412274269, 54.30699971414382, 58.985261609477384, 56.24801989524596, 52.00303085388676, 53.75199610187162, 59.633452892303474, 56.23732751415622, 57.41170475559851, 56.527151446188654, 58.25982709084788, 56.369833023317405, 56.29652000242665, 57.507037962636645, 65.01107731173116, 61.94963601327712, 62.14846095731182, 57.57666003319525, 59.75988265006774, 60.45416570478871, 56.66468151154057, 58.92909326860982, 55.12226435445971, 53.59850983465872, 57.869123720353656, 46.32765146993822, 38.66572495429747, 44.61343057693974, 50.261969181799124, 45.64375877380372, 44.433323183367335, 38.56554762009652, 38.09205870474539, 39.80974305060602, 36.337982608426, 38.30580434491558, 35.63959283213462, 36.34980070975519, 45.888208727682795, 47.42414220686882, 46.22410089738908, 42.414498867527136, 44.34988652506183, 42.410399990697066, 42.50574104247555, 45.142083706394324, 39.28025445630474, 48.998612972997854, 54.44377276205248, 56.41808209880706, 53.999081888506495, 53.17704723727319, 56.3294247658022, 57.25915201248662, 56.721728463326734, 57.380463077176, 58.180336336935724, 55.389926895018554, 54.009605607678814, 54.88924810963293, 53.693846964067035, 54.63027754137593, 54.62446851115073, 55.995713433911725, 54.194945443061094, 55.5101671526509, 55.68645415767547, 55.550183173148866, 55.915249932196836, 55.12032670359458, 49.000699673929525, 56.84043899659188, 52.98047765608757, 48.531411617032944, 54.420897499207534, 61.609256652093705, 64.7774491771575, 61.87157300210769, 63.0604394789665, 57.30490646054668, 52.98508251866987, 49.98044890742148, 50.44300617710237, 48.51703613035141, 53.006000518798835, 59.8798091180863, 63.53111997727425, 64.38079164874169, 67.94996415415119, 69.63088020201653, 65.98686495134908, 61.53014636808827, 67.97607145001813, 70.24826911187941, 68.84282112121582, 69.86767368931925, 60.95750777952133, 64.32311711772796, 66.7589678302888, 77.5966021322435, 70.782362568763, 85.47603191867952, 20.23902608502296, 0.03436192389457457, 51.166746231817434, 68.62489423444195, 42.3811234197309, 16.845701279178744, 30.734694427059544, 39.24827144991967, 48.33167668311827, 53.10566402250721, 43.72161696034093, 53.15096739799746, 65.8144610927951, 60.25050447833154, 2.7416124603440686, 0.07866019968904796, 0.026098629497292063, 0.04006501565116548, 0.03890076884999871, 0.05933069436240101, 0.029504332736495043, 0.04461056387592708, 0.24308817130663704, 0.1959951531382338, 0.27052078396081924, 0.14707006634243075, 0.11054566009871422, 0.3276614129783646, 0.12349060015572656, 0.18007360909494663, 0.13578209785684464, 0.20592406632438784, 0.2034570793471029, 62.623875756417554, 72.97379862877631, 64.51044951715778, 46.847110563708895, 54.80015931590911, 47.029669438639, 26.227667523968606, 36.91397874586044, 67.1905932887908, 69.81304291755923, 83.48062023039788, 18.399671777602165, 5.500385780488291, 93.54263720973846, 65.0571612388857, 81.4551631865963, 65.17191802301716, 66.16764699259113, 64.37756746046006, 77.42063676157306, 67.5334555102933, 71.35191425200432, 62.29489480295489, 71.79683654539048, 67.11451499692856, 68.06408159194454, 61.773721633418916, 65.3959991085914, 60.097057434820364, 70.13027637235581, 64.38187814527943, 70.73248570965183, 56.73610787237845, 54.51148463833717, 50.01393810395272, 58.36310309748496, 63.509303754375836, 63.84607061263054, 61.32452003417477, 66.26727519496795, 61.599752749166186, 55.838395011040475, 59.172040954712905, 61.71740816485498, 59.1579871023855, 54.296099447434955, 55.74414437816989, 63.8964024666817, 59.46215121976791, 59.724855884428955, 60.5845727459077, 60.898625158494525, 56.74146583003383, 59.48526966956354, 58.12002989553637, 68.48898410797119, 67.26874259210402, 63.17359985843782, 57.57626779617802, 63.00199616339899, 62.96849127738707, 62.56887628186134, 61.858295779074396, 59.18891499119421, 56.79238603961084, 58.406684552469564, 47.64506186208418, 39.686686531189956, 46.23395781363211, 50.881225139864036, 44.86668625185567, 45.82509779161023, 40.47562422290925, 38.47718446485458, 41.86160941277781, 39.13898637217861, 39.77041344488821, 36.37112663638207, 37.25356578826904, 45.67917777645973, 47.91377952021938, 48.113212431630785, 43.53843442855343, 48.70618850954118, 44.51344151650706, 44.34698004876414, 47.27633553166544, 39.957428132334066, 49.61381320030459, 56.46010637283326, 58.22001503359888, 56.89348513080228, 54.97015876154746, 60.38564582024852, 61.417248787418494, 60.66263575707713, 60.7291748446803, 59.04659963423207, 61.64455798364455, 55.40161555813205, 58.29364184410342, 57.80933503181704, 60.94373633784633, 56.02770428503714, 57.492917430016306, 56.88573060497161, 57.240438384394494, 55.980059254554014, 59.20775805750201, 59.038346967389515, 58.00876402085828, 52.769563967181796, 60.3671440001457, 56.7756296742347, 52.04227024509061, 57.07510263689103, 63.4814666932629, 66.37145334674467, 64.36288995127525, 63.44506709806381, 60.07415863775439, 56.538844031672326, 51.13081339866885, 53.57153961735388, 53.02747157312209, 55.479996281285445, 62.52313360091179, 67.06307703448881, 66.60130423884239, 70.77683987156038, 73.17516526868268, 68.01487938050302, 64.20748564504808, 72.92727931853264, 73.01523454727666, 75.41923953640845, 73.23440874776533, 66.8722458808653, 68.96842325887373, 72.58247160142469, 78.38730489054035, 75.35656006105485, 88.7756395339966, 32.13065812664647, 0.1928870271771185, 53.98984470675069, 72.56459343817927, 52.49368406111195, 22.716516679333104, 44.110135570649184, 55.18786991796186, 51.20686031156971, 61.8886157005064, 55.43832109820459, 55.410362443616314, 73.49176329951133, 69.77094019612959, 2.878261708444165, 0.28236312431193167, 0.144357456254863, 0.11905900367926206, 0.1641868607651803, 0.33076799144187286, 0.16960167746630408, 0.1906510463525211], [0.04872234162664221, 0.013236235414120941, 0.05857205281274454, 0.014994510622214408, 0.03420216391884512, 0.0593271856797078, 0.0852255885218901, 0.08952328815094887, 0.04415240882325076, 0.039468880502447005, 0.05197145840934208, 46.440007763524214, 58.57027484524635, 51.97078897107033, 32.891433200528546, 40.665898399968306, 31.951450917028616, 18.262067187216974, 18.561138106930642, 39.94595519958004, 75.75953652781826, 54.41035809055452, 69.95460125707811, 1.17142001948049, 32.81876540953113, 82.71402435918009, 67.78751527109455, 69.93140435987904, 61.07104470652919, 61.84226505218014, 63.96970372046194, 66.10662275745024, 62.62584086387389, 60.94131623545001, 63.56467193172824, 61.4234108309592, 62.825097268627545, 60.76378583908082, 56.60230013632006, 62.013915815661036, 60.12519651843656, 59.082085317181004, 56.1429552878103, 49.569043267157774, 44.98362387380293, 46.50968866963541, 52.24892031761908, 57.37137494548675, 56.954293635583696, 56.58745396521784, 62.22025209857572, 58.403950660459465, 55.46889597369779, 51.51890054825814, 51.128612949002175, 53.66190318138369, 50.6620587841157, 48.84331849313552, 53.90458806868523, 54.68080159156553, 56.93116341867755, 54.34066541733281, 55.32005379276892, 56.79303323068927, 55.59605136994393, 54.71249042018768, 55.2041438318068, 56.11822082150368, 57.28298825602378, 54.32264212639102, 55.60310379151375, 56.09083091059039, 51.480143608585486, 50.895027960500414, 52.58796999531408, 51.70332647139027, 38.58577136070498, 35.271372487468106, 46.793966370244185, 50.43610280559909, 46.53583911157424, 44.86120670072494, 44.926667136530725, 40.87715333507907, 40.759301800881666, 41.791175411593535, 40.50980375659081, 38.50289167896394, 35.458732343489125, 39.4506069152586, 47.869005664702385, 47.402082797019716, 50.78418177943076, 44.761507895685014, 45.68683424303609, 42.71567021646808, 39.82507951797978, 44.42954201852122, 41.16370601038779, 40.7515041289791, 47.22489364685551, 53.52072923414169, 48.957086839983546, 53.63987122812579, 53.26047605083835, 52.754341248543035, 55.898634772146906, 55.04277360054755, 50.42212740067513, 52.86596798127698, 54.177651712971354, 52.45913190226401, 52.43779420852662, 49.4027739955533, 50.2207568383986, 51.845908549524125, 54.04596597917619, 51.753611256999356, 52.095626246544626, 52.82302587263046, 52.687649188503144, 50.165286679421705, 51.280793066947695, 52.273517500969675, 49.44352742164366, 49.60554484398135, 51.62751097832957, 59.65340598937004, 61.60458903158865, 58.218202898579264, 60.030149644420995, 61.813172832612075, 54.02312601766279, 49.521119748392415, 47.797708742080204, 47.250459655638664, 46.46802133129489, 52.01445279582855, 58.21443350084367, 60.78995589287051, 59.699270263794936, 65.32935803936374, 66.37661518589144, 57.344549855878284, 64.3708602074654, 67.34427959688249, 64.84284685504052, 66.63356181113951, 62.7813510740957, 65.70718819095244, 67.83095944312312, 71.62731955128332, 69.33472556452598, 74.40035681570731, 3.531404983612799, 0.9413543776158364, 61.70018503742834, 61.84887032355032, 33.72613122386317, 9.9531025655808, 75.9069235094132, 111.46287179762318, 34.085785112073346, 36.52621715299545, 42.25949856542772, 63.923651172268784, 49.076472020918324, 60.32883421067269, 15.075619951371225, 0.15869915845894045, 0.08049150988940271, 0.11325424822467951, 0.053737467275031155, 0.08454414565236339, 0.09371169767672978, 0.030874266484451872, 0.07131271935518711, 0.07876466343840284, 0.02636122337031749, 0.011095697653570004, 0.015744216713844048, 0.021961028837869247, 0.05915570455873686, 0.06408502069872714, 0.04828564852716462, 0.10147068979999713, 0.10945421463299183, 58.30453426607194, 66.73460991151872, 59.34746896066974, 31.954549589464744, 45.27993932847054, 41.90301002994661, 24.70409147201046, 26.647655310169345, 44.16229132683047, 81.60145974928334, 58.027563941094186, 79.81079578399658, 2.9794706260004356, 27.888534376698157, 87.73899632115518, 71.11108072342412, 74.55798902819234, 64.3416150154606, 65.91663099104359, 64.53750602660641, 69.26579383111769, 65.15334167788106, 64.48894316150297, 64.8187360455913, 65.86142755323841, 65.57020725742464, 63.69113306845389, 59.300977107017275, 64.26854518152052, 65.23273437253891, 63.33777850674045, 55.873053073883064, 51.82240178508144, 44.82088865772371, 50.70349470261605, 56.676460389168035, 61.664628751816295, 62.13338728873961, 58.68144266067013, 61.87124352301321, 60.97415039616247, 58.921609386321045, 52.45843372037334, 49.81070833821451, 56.829730926021455, 52.283641138384425, 49.12942009587442, 56.34562807698404, 58.15582544572892, 58.46068382263184, 57.51498468460576, 58.392493417186124, 60.564776543648016, 59.48297508301274, 58.31102578870712, 57.79827394793111, 58.58866683898434, 58.36735886912192, 57.636272215074115, 58.41054024234895, 58.05909587490944, 55.108583127298665, 53.244931697845466, 55.416814742549775, 55.457140630291356, 39.4913681860893, 37.65783271481914, 45.760755231303555, 49.43563953522713, 46.49507391837336, 45.07765485394386, 44.1713833808899, 38.71517035268968, 38.12256297757549, 38.68528973671698, 39.53417693414996, 37.446958249615086, 31.42116608158235, 38.9090334984564, 46.21477742348948, 47.264093814357636, 50.90364540776899, 43.723319268995716, 45.00129807379938, 41.7192195307824, 40.14520768196353, 44.53754448121594, 42.499916322769664, 39.23787716896304, 45.73882918204031, 54.32471706021217, 52.80163326571065, 54.64879112858927, 57.40161641951531, 57.149529610910726, 56.77217014374272, 58.20569053772957, 53.06207864515243, 56.14649326570573, 56.99625515168714, 55.39045641499182, 56.12068014760172, 52.37627183237384, 50.86456291137203, 53.852306796658425, 56.07844014321604, 55.75461710652998, 53.69419997738254, 52.853769410041075, 54.99688186953145, 53.784308587351155, 54.17437653387747, 54.52942163713517, 51.80596313168926, 51.792352507191325, 54.24632064757809, 61.94274440888436, 64.66077827638196, 62.22167984131844, 64.22021765862742, 62.985941902283706, 56.8430003043144, 52.74294676319246, 50.82807702402915, 50.407461658600845, 50.285075864484234, 54.573328648844075, 59.43625180952011, 62.38255977630616, 62.02587119994625, 67.74659710545694, 69.3968794422765, 61.279934452426055, 64.18587730776879, 72.5226240773355, 67.01170182997181, 69.15192742501536, 64.93717985768473, 69.46173191070557, 70.23503503491803, 73.26074354110226, 73.316802055605, 73.12422936962497, 2.0546354329393757, 1.8459125103489047, 68.81986741096743, 65.92558183977681, 39.114208759800086, 10.665515795830759, 61.267790794372566, 106.34926995923443, 40.38282094463226, 42.57735175471152, 42.016860746568256, 67.22911880862328, 59.002500426384714, 73.30275212564777, 29.194877801402924, 0.25015755406310486, 0.043666513726836255, 0.06768272663917273, 0.06546242763438533, 0.17476368515241533, 0.03504948780661629, 0.08508029994705031, 0.13217661229352798, 0.20439425002663367, 0.20081645088090053, 0.26855279601389365, 0.16740061492929537, 0.14227043356626265, 0.13107310860387741, 0.1792711932812968, 0.11890456035372712, 0.20869201860360562, 0.16792146278725517, 72.63714944162678, 74.78409013440533, 69.75856119586577, 47.920420092921105, 53.88707860823601, 46.07552936000209, 25.01818899185427, 35.944619870954945, 55.329043865203865, 86.01703659180673, 65.89496381821172, 81.512814183389, 2.6924024041621917, 41.32869266694592, 86.9866543431436, 72.18689272480627, 76.41913014073526, 66.75993273335119, 66.05581237423804, 69.0411675360895, 73.61552192318824, 65.53519225889637, 67.29812898943501, 68.92477512359619, 66.3678918346282, 70.00761601232713, 66.99342358496882, 60.93504436554448, 65.08293121091782, 68.75278703628048, 67.91373714323967, 59.700705851278, 54.77547584041473, 48.21830449565765, 52.08734220074069, 57.68973019815261, 62.873628754769605, 61.999281452548125, 62.513570862431685, 64.8290911028462, 63.63960489150017, 62.42581175219629, 54.900352339590754, 50.87478460804109, 58.874882190458244, 56.19819402694703, 51.81698499187347, 58.21743803639566, 63.01404568456835, 62.67055980620846, 62.52928387734198, 59.47122758434665, 64.64561047092562, 60.71988667211225, 60.48214789359801, 60.68293402271887, 61.860131448315045, 60.7346857747724, 62.095038275564875, 61.6429223552827, 61.29046209396855, 54.684912235506125, 58.654652872393214, 60.19069617794406, 55.32428210781467, 40.37874952439339, 41.49864112177203, 46.53880442342451, 50.21037824692265, 46.1401778651822, 46.870483967565725, 46.20068826983052, 38.54603775085942, 38.571344883211204, 40.14074402470743, 41.02431281920403, 39.973654977736935, 34.5471852825534, 41.56629024013397, 48.65717849423809, 49.34010236494003, 54.259907737854995, 45.5148853794221, 47.62216698738837, 42.344617920537154, 43.55907394040016, 46.284407338788434, 43.289132502771196, 41.61488840656896, 45.79886105752761, 53.877586472419004, 53.915845271079775, 56.404420483496885, 59.630118877657004, 59.94165705096338, 58.920664095109515, 60.709253126575106, 55.010688612538004, 57.224125246847834, 60.14024273041756, 60.313650715735655, 60.35540434621996, 55.84295672755088, 52.14445583281979, 53.714278590294626, 59.1279495916059, 56.222626470750384, 56.49865150451661, 54.76246926092333, 58.83257550577964, 56.975403831851104, 56.20388538606706, 56.84272181603217, 53.16420539732903, 53.809588263111735, 54.82462313867385, 64.50480914884999, 64.96847644928964, 63.38026954281715, 67.07927642330047, 64.84379214625206, 59.204792745651744, 52.91981035663236, 53.358182291830744, 54.05371266026651, 52.93459769218199, 58.47664394686299, 63.687340136497255, 65.4398786637091, 68.45109401210662, 72.4962265260758, 72.0458992065922, 63.30750565375052, 68.03269478582567, 75.10902712422033, 68.2940423104071, 73.07331700478831, 68.51623673592844, 73.04902184394099, 73.20007231927687, 76.58257530581567, 73.20625397466844, 84.73479809299593, 5.977844624750077, 1.2870546790861315, 75.11913899452456, 72.56085149703488, 48.136691739482266, 17.147198184843987, 86.00509689700219, 121.11298499568817, 47.74295637684484, 48.664070098630845, 55.16772854712702, 75.38085522190218, 65.23994368891563, 85.88424867199313, 31.383931021536554, 0.3632173921552397, 0.2170612227412001, 0.16593193244789878, 0.19590588857329663, 0.2459517773240805, 0.3021354552718901, 0.12367041631331369], [0.07360935902162906, 0.05120692181310827, 0.0499472089652573, 0.03898662432367283, 0.035086068505000685, 0.10145711472197887, 0.1251879828651586, 0.09480866663638624, 0.12304937181573723, 0.023846894074531815, 3.1831649474559294, 68.65095446186682, 60.6345162853118, 54.46038399973224, 37.79497054315383, 49.00126449523434, 34.49810858695738, 31.51824474334717, 15.614288853060817, 25.57570488222184, 70.30319013903218, 57.239457791851414, 75.37569338275541, 23.152745039232318, 3.357074751007942, 73.12321739812052, 67.49443577181908, 74.41903514246788, 62.96588290122248, 60.810983719364295, 60.06854180366763, 62.32894882079094, 63.359394688760084, 64.10547656397667, 60.22562096195837, 59.3512148241843, 58.05410662005025, 56.81386886104461, 60.57094643192907, 61.915703588916415, 63.38013225986112, 56.64372036533972, 50.36639052052652, 47.28316045576527, 47.12790127723448, 50.8878892467868, 54.52670343460576, 60.36459053716352, 62.9372888226663, 54.95036648165796, 60.78685329806421, 59.62594155342349, 54.939713324269945, 48.48229962010538, 49.72860528576759, 51.463085220706084, 54.775821008989894, 53.73878163676108, 52.848403607645345, 53.895594073880105, 57.77979566204933, 56.54780664751607, 56.542303562164314, 54.97428509496874, 56.770793391812234, 52.30642226434524, 53.98552617719097, 53.408365095815356, 56.41022559135192, 56.053811580904075, 52.37207881865963, 55.84434132422171, 53.714192298150834, 56.600029083990286, 56.674691400220325, 55.261104491449174, 59.53994750976563, 58.87433698100429, 43.5845144333378, 47.38087061912783, 50.526285940600985, 48.54573611290225, 49.49448685492239, 43.50543160592356, 42.665507024334325, 38.13076857597598, 39.493827512187345, 41.016691653959214, 42.47548780133648, 44.04161176373882, 46.37113094329835, 45.59679623573057, 50.09556654960879, 45.48418106571321, 45.51612484839655, 48.818383985950106, 38.19025916437949, 42.05247194536271, 38.748820366397986, 36.33041635636361, 35.350729880794404, 33.88697977988951, 46.17773063721196, 46.36369020708146, 52.72146001938851, 54.60003998971755, 53.344967826720215, 53.553253527610536, 53.6936390784479, 53.246951718484205, 49.9275988917197, 49.58449348326653, 48.41048886699062, 51.509428024292, 51.561320981671734, 52.223381765427135, 54.1527368176368, 52.731968049080145, 54.401717109064904, 52.8753306788783, 51.68283993198026, 52.5984231118233, 50.63069551221786, 52.87285174092939, 52.760954364653564, 49.46916011071975, 52.67381891127556, 59.287174286380896, 61.56089775023922, 56.961051879390595, 58.080233527768044, 63.199542414757516, 59.27892946427869, 53.3367661506899, 46.355159051956676, 46.38509458111179, 45.402442793692316, 47.61201981575259, 52.00171685987904, 58.4623900536568, 61.58897015356249, 64.54485654830933, 64.4851972979884, 64.46736228081488, 60.72440132018059, 63.91524945535968, 63.7033865528722, 68.86329589351531, 67.73162149613904, 68.59694342459403, 66.0101402959516, 70.51501381781794, 77.84184440489739, 43.406442749884825, 0.33052606087538505, 10.833411870464202, 62.73084663575696, 61.908282464550396, 26.564742288281842, 11.965691293439559, 39.038067710015085, 52.505651212507686, 36.816821636692175, 39.042484298829116, 36.80182641552341, 65.08281746218282, 69.25605066360967, 57.380804323381, 41.586153122686575, 0.22382772497592435, 0.06832073232339275, 0.07462794952575239, 0.11319031052651907, 0.11184665359436505, 0.06662639098302012, 0.07992050625504026, 0.1643373970423014, 0.0687933549465191, 0.07543662427774361, 0.04567611940024842, 0.094126166565524, 0.035887151325662295, 0.13249041722907176, 0.06259746947175553, 0.06114035491801559, 0.08411455418794386, 3.985738513931152, 84.63599358835529, 66.41769024633592, 64.34513338150518, 40.04116289077267, 52.22212268460182, 45.23666381835938, 30.62902773580244, 22.16368802132145, 27.946595261173865, 76.39925941344231, 59.83304269852177, 84.6994810719644, 29.85297699128428, 2.0693446888077647, 66.6661802414925, 75.01214458096412, 75.36740149221113, 68.92518305009412, 63.89586510196809, 63.934104288778, 66.92433495675364, 67.71308437470468, 67.02666959454938, 65.93293236147973, 62.028718840691354, 61.06440413382746, 58.21473944571711, 60.669888219525745, 62.12652706330823, 65.94214208664434, 59.9963152793146, 53.68580218284361, 48.15237337543119, 47.71786889722271, 54.55028472408172, 57.110133324899984, 62.60916686827137, 63.475379174755474, 57.424440691548014, 63.55316762001284, 61.76729679107667, 57.46118937769244, 49.36069088597452, 51.83851488174931, 54.2367696762085, 59.1661613218246, 54.2506117205466, 54.881611254907426, 55.616365325066354, 60.089601009122795, 60.74641366158763, 61.423826602197465, 59.13641798880793, 61.71871431412236, 56.42815474540957, 60.67787416519658, 58.68904029169391, 62.72491993442659, 58.25807379138086, 57.339591979980476, 57.71834781092983, 55.32313285335418, 58.60408175376154, 58.94633208551715, 58.29904687020087, 60.131962606983805, 52.07233913483159, 40.37013992186516, 46.04279325854394, 49.17948915112404, 48.26464337687339, 49.65692789323869, 41.64164289351433, 38.246674614567915, 36.56391505272158, 35.39797090714978, 41.020484585915845, 39.212319004920225, 41.645255396443034, 44.81761347862982, 43.85149055911649, 47.82461620146229, 43.39823322911417, 44.07292012245425, 47.46230294627529, 37.26369727042414, 43.791403770446784, 34.73976581327377, 37.06724536034369, 38.111058665860085, 34.08416909556235, 44.80613270113545, 46.65143528292256, 52.11774841431649, 52.61108844510971, 53.83850397602205, 56.04136197797714, 55.656067555950536, 55.340297145228234, 52.9675377568891, 52.52349799679172, 53.325410889041045, 55.19187858027797, 53.072041465390114, 53.42468607810236, 56.420357073507006, 56.404581300673954, 59.45984878847676, 55.472900713643725, 55.03735680733958, 55.32382711287468, 53.417351245880134, 52.98116407086773, 52.62347136774371, 50.39661238270421, 56.07673783456126, 63.3175390766513, 64.41562621824204, 58.88516272267988, 62.7466812441426, 66.5865953506962, 61.34533997504943, 58.43574931544643, 50.49672303661224, 49.211193669226866, 49.881836598919286, 50.23464595117877, 54.936630341314505, 61.606420778459125, 65.88590314311367, 67.69155056245866, 67.69075824368385, 65.79678689279865, 62.91517449963478, 66.22698460855793, 68.72449890259774, 67.94524946520406, 67.71795595845869, 67.23956015802199, 70.67045734774682, 72.6110186115388, 80.31613042277675, 39.6221282405238, 0.4940093158473892, 15.725541980035844, 67.40831621231573, 64.08808085226244, 32.1349472384299, 12.102173105362924, 36.60177376962478, 50.12848308009487, 47.04598257618566, 49.17792412542528, 36.517450655660326, 56.68547399582402, 77.73939994073685, 63.347729559867616, 57.946967078793435, 0.6760502846971636, 0.06219513541568191, 0.06560265236804563, 0.023469272099675673, 0.07584671880449019, 0.056222549249087615, 0.05475473627748509, 0.2156024534375437, 0.12245163937369663, 0.1432917666651549, 0.16389611507615737, 0.24833356000242696, 0.14706597543291508, 0.21374971575794682, 0.24817675712608525, 0.30236387204739357, 0.17294424165400768, 4.3943465236694585, 95.92441020473358, 77.84002442513743, 71.17394062780565, 52.51422551370437, 66.36864492970129, 53.181275552318944, 40.64106979677754, 27.144605882706184, 38.07583578171269, 83.13298056202551, 64.85926589658185, 93.58624612131428, 27.20130374354701, 4.9772754503834635, 81.83818263392295, 69.31227391765964, 82.15329800882648, 67.85182645243984, 71.45873608127718, 64.2674586849828, 69.54006164304673, 70.05033846824401, 70.3503684074648, 67.12783536603375, 65.70935333928755, 63.31329114975468, 61.49998334146316, 60.60020731341455, 66.37637199894075, 67.80140830624488, 63.433947178625296, 57.44309548408755, 51.93733899824081, 49.39611773337088, 58.01468679981848, 59.45074104493665, 65.81346481077134, 64.91199431880828, 61.48878105225102, 66.06509270206575, 63.82655682102327, 58.24684012320734, 52.35275722319081, 53.66882224236765, 57.8935718536377, 60.83240770524549, 57.71768100800053, 54.85667674772201, 59.11273471770748, 61.38306533136676, 64.68693264069097, 63.92296083511845, 61.140517727021255, 67.03088222011444, 59.410905453466604, 62.87504865277199, 60.9826619394364, 64.7954999246905, 62.87053400470365, 61.51309582494921, 60.751614724436116, 55.44681302962765, 60.7773611622472, 62.9386773417073, 65.69602120307185, 62.7837319527903, 49.52674834958969, 41.03356176807035, 50.17674000032487, 49.53704849366219, 49.23885814605221, 50.45229434967042, 42.25769819751863, 40.76643659222511, 37.71585633677822, 38.541409354056086, 42.16015669607347, 41.47798592044462, 42.911192524817686, 49.031180412538596, 45.981572904894435, 50.19813652961485, 44.375860460342906, 45.452127456665046, 49.323832373465265, 39.05172932532526, 44.3005980214765, 38.35002906860844, 36.94007427461686, 41.08905546126827, 37.04122043425037, 46.640464413550596, 47.255790156702844, 53.36508958570419, 55.63621251813827, 56.88004709059193, 59.71896056205996, 60.01090257398544, 59.63985812279486, 55.091999346210116, 53.94819698026104, 55.468621407785726, 58.47651843101748, 54.52619744885353, 54.329671013739805, 60.32093847951582, 58.667949707277366, 61.301523177854484, 56.813429555585316, 59.7704142139804, 58.03394171499438, 57.45710619034306, 55.485201266504106, 56.869237038397024, 52.838632983546105, 56.39045684568344, 62.533002284265336, 64.27027102439635, 61.0223327913592, 64.21778578912058, 70.09871698194935, 66.1532989625008, 62.46036783341439, 54.43537496751355, 53.458441995805316, 49.9872620644108, 53.15713728627851, 57.474874527223655, 65.6927970147902, 67.37770603549096, 69.52869461428735, 69.25834917253064, 66.66921615600586, 61.5357945811364, 69.39679315013271, 71.03359037829985, 74.25984182665425, 73.19614210436421, 73.03342650013586, 70.96469002385294, 75.3461971590596, 81.32656435812675, 54.48675801677089, 0.3672450840953858, 12.619449400132703, 73.51113196342223, 71.77363964819139, 39.2981404642905, 18.576741295476115, 47.38261999622468, 58.604289639380674, 50.66690291127851, 52.31853846580752, 48.08699530939902, 69.51982221295758, 81.20976401913552, 71.0524255998673, 70.11527722881686, 0.8729588444675169, 0.2485315630873365, 0.15247849387026605, 0.14876955579365456, 0.13871699601652163, 0.3352367968088196, 0.14730599077959217], [0.1386303514722855, 0.42321191319534857, 0.12644983692875794, 0.1482580082430955, 0.2370653719070458, 0.08765838499511443, 0.09305484622957245, 0.16796422581518852, 0.10280862405535676, 0.2938303880153164, 2.7748224331486613, 67.99012137997535, 59.5122241973877, 50.666753861211966, 25.993296100247292, 52.29115247726441, 30.606077947924216, 37.854829834353545, 7.2819135650511715, 17.038077846650157, 75.20344641900833, 69.84712046961631, 61.20403658959174, 63.379500758263376, 1.7155795039669162, 12.3871382013444, 89.56169036126907, 61.43401691990515, 73.5203024648851, 58.88360946409164, 67.4098773156443, 59.75579946271835, 65.6003349827182, 59.59143254064745, 62.32846636925975, 53.46715357995803, 54.71480461858935, 55.259108005031464, 60.79254465718424, 59.342550308473655, 61.36570099861392, 56.25816706688174, 49.521688492067405, 45.25922136922037, 50.51838628707394, 53.42812599674348, 58.30772315302203, 61.44547808554865, 64.71278890486687, 59.36582957544635, 61.44696466384396, 66.11445965305452, 55.67202768018169, 46.77566851339033, 51.40939581778742, 56.5665751887906, 54.293126290844334, 51.15478692516204, 51.67522661147579, 51.31504712566253, 56.07531401418871, 62.13008465305452, 62.39084382211009, 57.57809169830815, 53.127892094273726, 51.9211749107607, 55.493885394065614, 60.602286169605875, 58.38420152664185, 54.653109658148985, 49.81445812409925, 51.15370435099448, 53.76850928029707, 55.28689407533216, 49.95599685176727, 59.35148939009636, 99.0672093053018, 137.25367946009484, 116.4179471231276, 68.9002210863175, 53.65387016727079, 52.50415286710186, 45.45902298342797, 46.73804906106765, 41.77232057817521, 35.30197089718234, 40.31617987540461, 43.28015811981694, 49.08097490187615, 50.436648015053045, 50.202474671025435, 50.72950786159885, 47.24053998147288, 47.809711194807484, 45.07436790773946, 48.776077301271506, 44.068260346689534, 39.239355902518, 40.99835065103347, 39.603700945454264, 58.54605028706213, 75.0727608896071, 86.23576364209576, 74.40834276137814, 52.29663202839514, 50.447144277634166, 45.96717388399186, 50.91535760510353, 52.77115644947175, 54.988778252755445, 52.48718077136625, 51.05556272691297, 50.96390870309646, 54.34654505022111, 54.081679159595126, 50.107396418048495, 50.64417277612994, 53.177294346594046, 53.15977704140448, 54.80974166624008, 55.483828436943796, 47.88177690198345, 48.8905438300102, 52.298652049033876, 52.338503329984604, 48.9013264256139, 53.77596178362447, 59.64693015621555, 62.60432274110856, 56.33689295861029, 57.907225624207534, 65.20730172434162, 63.94045852845716, 57.94846934656943, 49.8505360849442, 45.99147688957953, 44.128468728834584, 46.91840356396091, 50.695795089967795, 54.710321349482385, 60.22389511908255, 62.069362440416896, 63.62135018071821, 65.81951310557704, 69.6598586728496, 71.68264066019367, 68.42835995458788, 65.10017002782514, 63.16609636429818, 63.86616491502332, 72.26422617512365, 70.24425260482296, 80.53701477666056, 9.999088433481033, 0.09255026241824513, 27.180934875242173, 59.94490085109588, 64.41339438961398, 25.61072772549045, 12.269099373971263, 19.90185130027033, 12.102962482360102, 10.80858522845853, 44.53119416390696, 58.936996844507036, 40.381667767801595, 43.68675101187922, 57.935074452430975, 51.83793044859364, 2.208233855424389, 0.3335885126744548, 0.03863932602407952, 0.17901772543066935, 0.497600858610484, 0.09580780616811208, 0.0687731838514728, 0.04542404966008279, 0.4039583769777129, 0.05597919375906068, 0.173313879077473, 0.10686073121764969, 0.18884179182350638, 0.04549985022975072, 0.15586619595846823, 0.18033473782481688, 0.23770484081920118, 3.160165639654283, 80.08800537355485, 68.71654433588829, 58.64769066533735, 27.582234528756914, 53.939234364417295, 42.00785106228244, 38.07762438251127, 16.0603682456478, 21.18662561139753, 75.77891303646949, 71.87886115043395, 58.75571666225311, 73.6209269492857, 3.4865075734353836, 6.826985795651713, 87.67143741730722, 68.96132376886183, 77.39404309180476, 66.97070521693077, 72.44070929865684, 64.72033162270823, 71.71333712916221, 63.250619519141416, 66.95662390801215, 59.396337770646625, 60.46400300918087, 58.71624192883892, 64.15943661043721, 63.108319851659964, 63.65825576166954, 56.15372611630348, 53.92718876561811, 49.22236065710745, 51.48386201550884, 55.208936968157374, 61.39450688515941, 62.964227661009765, 63.91223315269717, 60.0773867484062, 59.70953510653589, 64.19942517434397, 57.632298854089555, 53.79139238788236, 52.765590606197236, 55.759135676968484, 54.03786236240018, 54.67999750568021, 55.64875233557917, 56.510383313702, 58.04723854987853, 61.48872613906861, 64.74998866358112, 59.601450274067545, 58.41746322570309, 58.87473706276187, 58.53374973420174, 61.48482730311733, 61.84201402048912, 58.39025766618791, 52.88556414265787, 55.804839134216316, 56.73599412364345, 55.86915423793178, 57.3105429064843, 77.32555066385578, 111.05842836441533, 124.14624798682429, 90.63307792909684, 58.883511404837336, 53.79690724034464, 53.284500568143784, 43.04924426540252, 44.2400287812756, 38.93585074332453, 32.59232501829825, 37.03485050509053, 39.52828161178097, 44.10041201499201, 48.17563303055302, 44.67273681394516, 46.617377342716345, 47.71322873330886, 49.09735471971574, 46.394080731176565, 48.43981250639885, 43.14677399973716, 38.70903968811035, 42.181435554258286, 35.345375845509196, 43.596599255838704, 55.2914361799917, 75.94110304309477, 74.30036775527462, 57.631887005221465, 54.12842988967896, 52.1215727252345, 55.66605783277943, 55.98630366786834, 57.07682063502651, 57.200767532471694, 53.9958223988933, 53.82156325924782, 54.627382832188765, 55.7535227652519, 53.91568837627288, 54.88088561642555, 55.06198929202173, 54.91293138073337, 54.9353555710085, 57.215656849645804, 53.62717843824818, 52.23438009139031, 52.345720491101666, 53.58630341868247, 52.910282919483805, 59.14452945032428, 63.44841680219097, 64.97578382492065, 60.42241804061398, 61.41235366944344, 67.02227653995638, 65.7770848274231, 63.98090993204425, 56.98832019682854, 51.94227726228776, 51.35948757971487, 50.1683618176368, 50.136543550798976, 54.16770850458453, 62.0698292024674, 61.11067633475027, 66.90928874477264, 66.14570525384718, 70.5714096561555, 72.77002365358415, 70.6629656207177, 68.29348533384263, 69.47623683560279, 70.03588061178885, 76.86697067752962, 72.59554878357919, 79.59264139975272, 6.05196173152616, 0.3378725376340651, 33.3936946622787, 62.485918152716856, 67.3938112874185, 28.42680515781526, 11.340788102919056, 26.911650434617076, 23.275950608714936, 24.625075324889153, 55.98915915335379, 49.56623092774422, 41.271877134999926, 61.26377036494594, 65.27943803418067, 69.34853230753254, 4.646810370106851, 0.24703321768151176, 0.18202979928783833, 0.01376089360189414, 0.3683684447840337, 0.0846001849840245, 0.04364766413345934, 0.1655395728565993, 0.42422746999129174, 0.16693987432987462, 0.3415458066569221, 0.32420549842138446, 0.2377705098760705, 0.1455374614846322, 0.24281973409796917, 0.3461584526925318, 0.7137356205813347, 4.638119378397542, 92.14282958738266, 75.73716332835536, 69.25456016294419, 36.16098565440024, 71.69364683089718, 41.31144992766842, 56.20812546822333, 16.193148320721043, 26.85625283948837, 82.32839261331867, 75.3467619803644, 67.78039224686162, 77.2392192963631, 2.373789255657504, 17.67937948626857, 97.8467873604067, 70.08341973827731, 84.62235942963632, 65.77472748294954, 75.82908799571376, 69.56569040975263, 75.82766025297104, 66.82556967581472, 71.71808319707071, 62.07662274760585, 62.704115683032626, 62.48038761077389, 70.6319788963564, 67.89476856108635, 67.96650086679767, 60.657517064002256, 57.927268935788064, 51.251465505169286, 57.232307311027284, 55.93091980103524, 64.46409886883151, 67.28203942698818, 69.46716047102406, 61.552417585926676, 65.91860002087009, 68.95200421733242, 61.04285070973059, 54.93604590815883, 55.84578867881529, 58.558397908364576, 56.71726480607064, 55.648183591904186, 57.802039423296534, 57.03213307165331, 60.74245991245393, 64.3806072973436, 68.1059411264235, 64.39344913728776, 60.36888945487238, 60.30065590335477, 63.29865678664177, 64.41394352143811, 63.559180613487, 57.64862375874674, 55.13971890172651, 59.00879975288146, 62.10276926717451, 62.86884346315938, 65.10224888401648, 79.85496951687722, 105.49422464063092, 114.89583999879899, 83.4240282735517, 55.40389445520217, 54.97105306194675, 55.54646476622551, 46.23361656742711, 47.356371495031546, 39.807189587623846, 34.28756752321797, 40.65184062527072, 41.21650111290717, 45.89412366190265, 50.149310865709865, 45.28815277161137, 46.94970015556582, 49.70882085061843, 54.27252208032916, 48.80371039913547, 51.129821039015255, 45.23390246975807, 41.859546246067175, 43.2224835888032, 37.94400884259132, 39.78664813503143, 46.02592314443281, 70.99187989388743, 75.83857228679042, 63.55479540363435, 57.473505620033514, 54.1344742621145, 59.746930983758745, 60.38769721984864, 58.37512908443328, 58.95105069683444, 54.82038305651758, 58.88617469418434, 57.809236972562736, 57.46863795864967, 53.90217188865908, 57.02537090547624, 55.31521751034645, 55.87996429012668, 57.69684145527502, 62.06545575972527, 57.29544570369106, 55.24102980090726, 56.73523318383002, 54.99698385115593, 54.317692095233554, 59.097484542477524, 65.24600767320203, 65.60810519802955, 59.85459612261865, 64.30313264170002, 68.08308939779958, 69.05491936591365, 66.93502733784338, 58.246102717614946, 54.82967515145579, 56.99608648976972, 52.67419938118228, 50.54639593247445, 56.37665402504706, 62.12333425398796, 62.809996143464126, 67.99889179968065, 70.21872581974154, 68.6121779103433, 68.86365675157117, 73.17998978399461, 72.91328430175781, 72.92121533424624, 71.51419839551373, 80.52766384616976, 72.41715154340191, 84.72762800032093, 13.941250885686568, 0.6925050565792669, 34.55753249506797, 72.92244695848035, 72.7325257947368, 36.73913125068911, 19.901274711855, 27.15208584262479, 17.617564893537953, 18.47783088684082, 65.04870853116437, 78.42339069612565, 51.737623676177, 63.967722923524924, 75.23892817958709, 82.94851933756183, 5.365120393614616, 0.23870175103506736, 0.23831656202673915, 0.37079767894841015, 0.4940583148310262, 0.17564270975849322, 0.3204722600358148], [0.4399730283166132, 0.30081226820907286, 0.1248157024383545, 0.06421174696316162, 0.1523815224608106, 0.12261938198559708, 0.033055655883565065, 0.03149839257070374, 0.10326713533891786, 0.8776219910190952, 2.3528138908647724, 59.78672735152706, 58.038978038295625, 59.20602436988585, 37.70686234197309, 46.74498773390248, 37.45676025267571, 28.773662313338253, 26.694047143382413, 2.6310241751132475, 31.018709328866777, 67.9063081741333, 53.3848818655937, 59.66965244662378, 45.04849203171269, 0.4229679908002577, 30.56022740179493, 78.03244806105091, 67.66107374621977, 63.96571859236687, 65.46904540831044, 60.84861101642732, 64.31701783211001, 61.75071693235829, 57.59385962640086, 51.70248316180322, 60.120407304456165, 57.71404889322097, 56.07161129674604, 61.04869111891716, 63.6137290154734, 49.533314397258145, 47.40850763936197, 47.695283889770515, 54.869514665296, 54.41545717177853, 64.71496189794233, 64.90001932267221, 64.80606286756455, 64.63477296213951, 62.86603896848617, 62.434378208652625, 54.48309060065977, 54.441756663783906, 54.64144452925652, 57.0555692334329, 49.7584702122596, 54.60083230849236, 53.27631850396433, 53.715600429042695, 62.86855320776663, 62.73434146758049, 58.770927613781346, 57.89913769691222, 56.47071638414937, 52.41836278669296, 59.592699466213105, 61.93502126201507, 55.38045044868223, 48.90638236076602, 50.86339012269051, 47.687231263806744, 50.566278426877915, 55.0738662289035, 65.57725183425411, 85.50933284144249, 84.85950593025454, 69.38709705106675, 71.23068163471838, 76.89990289749639, 51.17548919493153, 37.7017750278596, 41.77403073157034, 37.37150361461025, 36.48310246006135, 40.390442109877064, 42.635712700505415, 54.94214911614695, 60.25280690962269, 54.46851507309945, 55.660362551289225, 46.244556057837706, 46.67906053604619, 47.37909378543977, 45.262049398114605, 40.737175710739635, 36.3147896335971, 34.585098912639005, 38.79758719475039, 75.3985058876776, 124.309677462424, 100.2741696757655, 82.91447316446613, 74.28888305541008, 63.95989387266098, 52.66185568225, 47.318720663747484, 47.15039214780254, 54.12639025718936, 53.6139835849885, 53.02789126673053, 54.30010810975106, 56.05988340993082, 57.93309757786413, 51.47489155492475, 51.820464134216316, 55.7162602486149, 55.59618473052979, 57.13623669839675, 53.88135194778443, 54.01459094016783, 52.63024137866113, 44.859653442136704, 47.00767670908282, 47.461683211788056, 48.58798396202826, 58.46249595765145, 59.48361442935083, 64.62799510648175, 60.60989556774017, 55.52040061643047, 65.77779477642429, 66.14310864479312, 65.87630902567219, 55.08829662876745, 49.39137951020272, 44.949683604701875, 47.20470128520843, 48.305757661019605, 53.30618343045635, 61.829113344992365, 61.76467664780156, 64.48482859519221, 59.58035576728083, 56.40850759321644, 61.38812126651887, 66.54687743033132, 75.29067993164062, 66.10962729300222, 64.05638810127013, 67.2272046919792, 78.60389817145564, 47.87865469532628, 0.1709575611617296, 3.0890594422817235, 47.30757328771776, 66.53702443645847, 57.980424896363296, 20.618397728089366, 6.4355965006736024, 26.461025015000377, 15.490421383611618, 21.27808547789051, 67.9562948596093, 78.40485357469129, 31.32284010610273, 53.63272859204201, 56.62029204830047, 56.91442274278211, 5.7889060147347, 0.3731422144318781, 0.08511261353569646, 0.19141230792287858, 0.5770552386679958, 0.027019852141459143, 0.14640689466989812, 0.2430239118515484, 0.13314223547856655, 0.06584482042178993, 0.06334382680154617, 0.05263405168549188, 0.09955630502513341, 0.004648157562534776, 0.08693351260116024, 0.005954727220664462, 0.5030053331246299, 1.8233878093381084, 67.34031800300845, 66.03512579394926, 61.781103534083215, 40.84680987942604, 57.19025165803971, 44.54511857801869, 34.13344583203716, 34.59503035391531, 8.570560236130992, 25.04972484803969, 64.99004948523738, 58.57675852314119, 60.97584878244708, 53.954743416078635, 0.21739103891436132, 18.015473658038726, 80.30586950240597, 77.36723761404716, 72.78628580031857, 70.30257040454497, 69.23923938505112, 68.60255241394043, 67.8114652633667, 61.275176617407034, 56.93408166208575, 62.10188673388574, 60.87431823053668, 62.59565430302774, 63.115215378422896, 63.09272843022501, 56.29849295462332, 52.86708977914626, 51.82944636191092, 61.38584236944876, 58.914564809491566, 64.95180637605729, 66.03227030846381, 65.74194039067915, 63.70244910640102, 60.45050221104776, 62.30735617299234, 60.957135154354965, 59.79830226590557, 56.7619719812947, 56.723473918053415, 50.701502138568515, 56.560770080935576, 58.73148425932854, 55.438187737618726, 61.46043800538587, 60.74833954534223, 57.22563143699401, 58.963261035180864, 59.54991817474366, 57.01947950547742, 63.60151867712698, 63.55460320749591, 58.05493424015661, 52.87548757368519, 54.298488170869895, 52.89636635011243, 55.61541218911448, 61.858205564560436, 78.19229249031314, 87.86123306520524, 83.92559743696644, 74.96346796712568, 68.58407020568848, 74.69010230033629, 49.93509454111899, 39.23835962049423, 42.993934923602694, 37.0012475598243, 32.6308270039097, 37.198503555790076, 39.2358140022524, 50.70647962631718, 54.10242065306633, 51.18591485484954, 50.51299695045718, 43.987745854162405, 46.11243494095341, 47.23500159478957, 44.78355161605343, 38.8205526721093, 37.7400299041502, 35.65858887087914, 32.58093249413275, 53.542918082206484, 100.57117154521328, 100.04841373812769, 81.45694394265452, 71.00940504381734, 70.60649917971703, 58.88556672680763, 53.3872195982164, 51.799397084020804, 57.533208016426336, 58.288942844636985, 57.54628519858084, 55.85409233647009, 57.19689615311162, 58.52923508613341, 59.85909900357647, 57.83663080584619, 57.98602211859919, 52.75670251538677, 53.5798236631578, 51.0355233377026, 55.643410067404474, 55.463004573698974, 50.90537909538516, 54.302590970070135, 51.22414227454893, 51.62847195902179, 58.44808124726819, 61.626173834646906, 65.7498949573886, 64.78012031124484, 54.731211893020145, 64.83281735450991, 68.58290133937713, 65.4587217300169, 61.2148387970463, 53.89777491169592, 49.46191549301148, 48.92493909405124, 48.69834376919655, 51.791979882024954, 59.644361003752685, 58.829382696459376, 63.504545919356815, 59.4217311951422, 52.76195064667733, 60.43485587643039, 68.033612620446, 76.67260939075102, 69.47156921509774, 69.64083517751386, 71.75874248627694, 80.5261262770622, 38.88323999220325, 0.29313836547155536, 4.64227169752121, 54.444784733556936, 65.56353530576153, 61.77872265538862, 18.106101982055172, 11.344950718264426, 35.01197045849216, 22.74741122799535, 34.17154381352086, 91.1704897111462, 99.6299203749626, 37.518094355060214, 67.97607929475846, 62.55340645390173, 78.28715893530077, 12.786595321470692, 0.4799554328764639, 0.4370513528345093, 0.11223557345088452, 0.18876732807726632, 0.05454799212935952, 0.14450114370594103, 0.29850297277012183, 0.43977890163660055, 0.2681497418351712, 0.36897947651243984, 0.34978309045395545, 0.331623803583845, 0.07553842970200124, 0.2993224723444831, 0.23360338993370536, 1.0275512200690087, 2.2682372937279363, 78.74375420231974, 73.9265815673336, 72.5931953614758, 50.47968818295387, 69.94019831380537, 54.018387794494636, 39.49672222137451, 38.71882600169028, 8.581309491588224, 39.22768292888519, 71.9311777237923, 65.34784416998586, 72.70408861098751, 53.51634794665922, 0.33434837996479005, 38.9556900916561, 85.29061363589379, 76.2534256904356, 77.80735108160204, 77.78394237641366, 72.29033347099059, 73.97760375853508, 71.93644154456355, 64.39716754421111, 59.53927286209599, 66.24779670469223, 65.8485229553715, 67.44542967888617, 68.35088529894429, 69.92615622858848, 60.35707527591337, 55.5265038244186, 52.11708161138719, 63.22437494031845, 62.15977699525895, 68.68434952151391, 66.92242084010955, 69.28090280102145, 67.35108098676129, 65.30829098916823, 67.03427899268367, 61.048557758331306, 59.78220485871839, 60.319389143297755, 58.92039345156763, 52.46720806244881, 58.114852366908906, 57.63834714889527, 57.3011919759935, 65.36680490739884, 65.51092847701042, 62.18887705956737, 62.390020124373905, 61.88399907081359, 59.758176419042776, 61.229465315418864, 62.04067422497658, 58.81355201044391, 55.370264053344734, 57.35618360580937, 54.959999822801166, 60.67125712671588, 64.78043410085863, 68.75998850791686, 77.69591654500654, 82.64171938742362, 78.14993089245212, 79.68119282876292, 76.6867377681117, 50.965410970872455, 41.4818141537328, 43.92912210956697, 39.25387259452574, 36.18504547303723, 39.931418895721436, 43.59919194252261, 54.41730460812969, 59.44388866424561, 52.57218245537051, 55.005628755015714, 44.34738405289189, 49.90466087095199, 50.91821309058897, 48.53073696936331, 43.91077718427105, 40.06616015588084, 35.953959034335234, 34.94104223866617, 48.70417241127261, 86.42331569425522, 90.6585733352169, 81.86112065469065, 74.51134420210316, 72.18206820949432, 58.74025860140401, 56.21459737900765, 52.17865105598204, 58.769017419507435, 61.519167653975956, 60.77796128488357, 57.77382189227689, 59.49336936396938, 63.36980073682724, 64.00831553243822, 61.37835064241963, 58.721988201141365, 54.85135016902801, 57.2819370608176, 53.350141432977495, 57.87061422101913, 58.38152647018433, 53.8052148203696, 54.93695589803881, 51.39887994335544, 54.10009076518398, 61.088463952464444, 62.68499805081276, 68.64355687172183, 67.99040379062777, 56.403651698943115, 71.50010139711442, 71.9375947213942, 66.45925952542213, 60.98977711892898, 55.46030206065024, 52.238322073413485, 50.90745010683614, 47.914265894120746, 51.371431196889574, 60.829669890865205, 60.287943501626295, 65.11805211344074, 61.61498331254529, 58.46420611104658, 65.3284715837048, 74.75073429845995, 74.68666630406534, 71.58913135528564, 70.93918677299254, 75.33933301125803, 80.12947267101657, 54.649881547497166, 0.554973888060739, 3.283646265345235, 60.87790719924435, 75.93535284842216, 63.46005447449223, 30.858001978166644, 13.71140685773665, 35.78823889455488, 23.433682841639367, 33.61980361323203, 91.20586164536016, 109.42617324090774, 50.237776002576275, 71.9776499655939, 75.05110940625592, 89.5976584957492, 13.584617222509078, 1.2190736301483647, 0.4185415347737651, 0.557173540995967, 0.6860215625455303, 0.15655596620373188, 0.3253720971124788], [0.08677212085815207, 0.1555422326970485, 0.039544202267162265, 0.11113142624737755, 0.05049511887914231, 0.02575818002374182, 0.15762496529327286, 0.09579339605425635, 0.2660266976923712, 0.3226197883486748, 1.3548579956254652, 44.56187886576499, 60.04201481419226, 46.93211224771316, 30.319897897781868, 37.291977559366536, 53.42190904002036, 28.44745839795759, 32.876573301130726, 30.627333271888, 3.294503631130342, 29.401257230389504, 65.93246167705905, 47.7641999336981, 66.92061654983029, 9.813418138411738, 0.16395415389730086, 31.1294888296435, 64.60979923125237, 68.42479844247141, 56.51453318134431, 61.88445798812374, 57.34555398264239, 56.40858996299006, 52.71112065161429, 62.79508329206898, 61.39429115479993, 59.200191805439616, 58.977448248094134, 58.158402442932136, 51.53615505464616, 50.36541385035361, 49.64831044597011, 51.26543306535291, 53.44039517064249, 55.78205016351516, 57.989999401953916, 61.615618736513206, 61.098889612382465, 62.549429170547, 61.765076729559134, 59.69086070214549, 59.95092953405073, 54.78619960046584, 52.69454863763625, 56.974156518136304, 57.4877752027204, 59.878181334464784, 60.5658983415173, 58.81249297049738, 53.74914061638617, 54.825737091802786, 57.17924156496602, 60.070401007129306, 52.99045224343577, 55.67033713863742, 58.5743344983747, 54.99500697658908, 53.61566235942226, 50.59641399691182, 46.53395637389153, 50.77115166571833, 52.46490563115766, 55.27114968146048, 56.43158681931035, 54.574521049376465, 34.87075336517827, 26.661703278941495, 29.406005259483095, 33.14665986645606, 51.99984196693667, 40.37350923784318, 36.018266293310354, 37.851409527563284, 36.41938747898225, 40.6260157400562, 44.043212090769124, 51.63619118352091, 51.024885869795284, 47.08935222318096, 58.56665057520713, 45.331898966143214, 48.55485562355288, 46.59262326455886, 42.93732727727583, 39.182152055924945, 36.0500963272587, 34.73379204350133, 58.98574406100858, 71.89731197972452, 49.27533618865475, 38.90298128128052, 41.96130037307739, 51.277529654964326, 59.24049415896016, 54.16847728913831, 51.35312941766555, 53.38084966905656, 53.27960937253891, 52.8402058539852, 51.81024635991743, 54.35886129256218, 54.865313806841456, 48.31428489377422, 53.687535870459776, 53.64185202506281, 57.32323177399174, 57.070913545547, 56.93363843425628, 53.201260028346894, 57.42967313335788, 52.90428953786051, 51.60421994424636, 50.59990490636518, 52.570801781069854, 48.19939082668674, 54.01462231912921, 58.338380398288855, 65.28837319343322, 61.93607245722125, 54.821245977955485, 54.46248246777443, 69.59393147499331, 78.66643644148304, 58.01460835241503, 54.26133940296789, 44.895033221091, 47.489637944006155, 48.92475474265314, 51.43016476784983, 59.648467725323094, 61.316216376519975, 65.94089477292954, 63.24523410489483, 59.5302317988488, 53.031421399885616, 56.56433159305204, 61.404426559325195, 76.34825291172152, 63.72266892463931, 69.43909983481132, 52.21603124372421, 5.980002908937394, 0.5972618801939873, 24.689009958697905, 63.8791597274042, 57.862369398916925, 49.04246507152435, 5.009385933799129, 10.376196868958013, 30.56060787170164, 30.47021096752536, 31.79453649828511, 46.66044888957855, 74.56866571980139, 39.827813409989886, 53.40745902830555, 55.25611915896016, 61.641416165136526, 15.638426138508706, 0.7773168733523739, 0.22259279124198422, 0.0695029821907801, 0.06212435272191802, 0.12106100593002574, 0.05106400044995451, 0.0845836834501355, 0.11448853078388399, 0.02899496279086077, 0.10006217586417353, 0.09677447123272766, 0.06040921592484079, 0.07756071796099986, 0.07092207580083801, 0.1972077171047849, 0.1286325056947047, 1.1745031250099982, 59.39040714694608, 69.71230076205346, 54.343775856879454, 36.55155174193844, 52.39691526659074, 49.90463341436079, 18.9645323061174, 35.99450849717663, 32.46993137944129, 5.858835991351835, 27.348565209296446, 69.80448430584323, 53.457771270505845, 69.03191858722319, 15.046431633733935, 0.1819450852851714, 25.254437269703036, 65.26603529530188, 75.73125623887586, 65.16501465151387, 65.1742636003802, 62.321633600419574, 60.921680850367395, 56.45200667842742, 68.57678244190832, 67.71996421198692, 67.76501655578613, 66.35088443756104, 62.629347462807935, 57.605571823735396, 55.19884078733383, 53.80976084739932, 54.843372068097516, 54.298445024798, 58.33626624076598, 60.270951794039824, 61.943889740974676, 62.00560823563607, 61.72808093409385, 64.94116890814998, 64.89402594104891, 65.54720647873418, 59.955734437511815, 56.45117905832107, 59.68620092638078, 59.12614530132663, 60.72466804135231, 64.93576388205251, 62.54292980317147, 56.68901589608962, 56.458176566708474, 61.603996753692634, 59.108023951130534, 55.471971111912886, 59.14777325045679, 63.693404120783654, 59.01193372664913, 56.637860344302275, 52.10684422523745, 48.476674941278276, 52.30951701441119, 56.814720015372004, 60.68230644349129, 59.029968784701445, 57.93135604550762, 44.51120576550884, 36.59743955058437, 33.092025172325876, 37.416363762271025, 54.950927380592596, 41.3228012669471, 35.54417725532286, 35.49795996758246, 33.58734992242629, 41.00823110149753, 40.303137994581654, 48.857144847992934, 48.70851447505336, 45.502388708053104, 57.37845482364778, 44.425498054873565, 45.02658559430031, 44.30763867593581, 41.76496613410212, 37.08124037711851, 35.211062123698575, 30.797150327313332, 44.621145879068685, 68.74906078461679, 56.964315291373964, 46.91733275690387, 49.028799533844, 53.959556164280066, 59.42067999993602, 53.42967533296155, 55.2752838596221, 56.68743518091018, 56.900325744382805, 57.997597032977694, 55.72758413130238, 54.83998706263881, 56.72196772790725, 51.60222345782865, 56.429449127566436, 56.72083024055728, 60.71318726385794, 56.036925777312256, 55.00615435261881, 54.638902833384854, 58.05727981751966, 54.178220456646336, 53.3581313010185, 55.17675392089352, 55.11117189161239, 49.04636390747563, 51.96107718252367, 59.52374812095397, 64.86197625437092, 61.00576469975134, 56.04584916945427, 58.31692111107611, 69.09767320079189, 71.43648055291945, 65.00597430813697, 58.40855944541193, 48.70092468876993, 48.10051179701283, 49.49781302482852, 50.98621129989625, 58.48847773767287, 57.78031733728225, 65.28139137452649, 63.23597731128816, 58.70146243802963, 51.64054893678235, 54.71446729475453, 62.7853322798206, 79.17058652447116, 64.64475147185787, 77.55176159643358, 46.352382013874674, 4.087286226211056, 0.7694446764165356, 31.091102553952126, 67.12247740837836, 64.81803001896029, 49.13921033182452, 5.604078538956181, 18.78273044863055, 27.736750418140044, 29.16739767597568, 35.57556013907156, 53.8807322132972, 81.51217875942108, 49.12756873715309, 51.301099177329775, 61.63561890202185, 77.93190986879411, 21.808538975254184, 0.3583592915486905, 0.6376165115544874, 0.14154762960970402, 0.12588519948504626, 0.1834160813520993, 0.07446377688357908, 0.2536099905809087, 0.536127450966066, 0.18294758794288482, 0.41030265751384926, 0.25795164067418347, 0.16803560988797298, 0.24364862591028216, 0.18152575939893725, 0.3017500517589431, 0.30859461835315155, 1.876618417520677, 72.1217970694265, 80.17123022387105, 64.79704141616821, 45.798284469112275, 55.92016858439292, 72.88526288924679, 38.81292366212414, 39.31350438825546, 39.17050653888334, 11.090442826670985, 40.941009521484375, 73.47102965078047, 58.23332755796371, 76.38374251704063, 12.966241836547853, 0.17233279623812245, 48.81849381231493, 69.53275818978587, 77.89336081474059, 69.27918480288598, 73.22177871581047, 63.11450935179188, 65.15715814405873, 58.74560479194888, 66.45059893208166, 69.01240087324574, 71.1050324286184, 68.23358289657101, 66.23695527353595, 62.22932454078429, 60.53603341502529, 56.41341840067218, 58.26731097313666, 58.9870305984251, 62.39808451744818, 63.34428179648615, 65.3359946896953, 64.37674768509405, 64.96597789948987, 68.42350406031456, 65.22577608785322, 66.98382162278699, 62.99081740840789, 58.93912276914043, 61.48530190990817, 61.277616331654215, 64.39521028149512, 64.26870992106777, 63.704276930901315, 59.32509183883668, 60.82723017661803, 64.88214900416713, 64.03580742497599, 57.58908610190115, 60.678713552413456, 64.95990607046312, 60.84893265078145, 56.120487951463275, 54.797621542407626, 50.61740259970389, 54.06478551126296, 57.50000123054751, 58.24263142001245, 53.78761514540642, 55.89608915390507, 53.95970913671679, 50.190283944529874, 46.54939090051959, 45.986283671471384, 57.54223731256301, 44.65736504523985, 39.342533849900775, 37.74195186553463, 35.211097425030125, 40.388426011608495, 42.644789065084154, 51.08296440493677, 55.92879779877202, 53.110551295741914, 63.17080320850496, 46.717786096757465, 49.268217086792, 47.19942177495649, 48.73285670434275, 41.88419442023001, 38.627717187327725, 32.00268883858958, 45.988719463348396, 71.1266839119696, 66.3859582716419, 52.737867293819306, 55.76073208162862, 59.7192665069334, 59.892996126605624, 52.46365831744287, 54.35563318191036, 59.34331124828708, 59.8356746089074, 63.85570003140358, 59.33024191087293, 58.91086993678924, 61.11405349546864, 56.393845773512325, 60.35200757365073, 59.723267324509166, 64.05481130846086, 57.15590738481092, 57.11389880026541, 58.601700875066946, 60.063274060526204, 57.42194606411842, 54.99552472945183, 55.540934224282545, 54.99279868218207, 49.26764442074684, 55.07285817976921, 60.82127209632628, 68.27443830428585, 65.57479250815608, 60.910890410023356, 61.459018107383486, 69.57381756074967, 71.68233471532022, 64.68988226306054, 59.618634177792465, 50.600775672543435, 49.64348200828799, 51.72603699468797, 53.315655954422496, 61.15492851503434, 60.91225539484332, 67.13879446829519, 65.5882344707366, 59.221101960828236, 53.43324861218853, 59.4647752854132, 66.73850090272965, 75.84473040796097, 69.55745343239077, 78.44776430437642, 59.03873528203657, 10.150807672931302, 1.2321584118950752, 28.04843960269805, 72.18291544145154, 69.6922182267712, 60.00530927411972, 14.884692699678483, 17.71694402540884, 43.39278897931499, 41.308978834459865, 47.06013841013755, 56.652424104752086, 79.30291944934477, 59.34025572192285, 68.07239701670986, 71.41953591377505, 85.55045497032904, 26.620606645461052, 1.245454756482955, 0.6684655239505153, 0.3642024586517965, 0.19614248716783142, 0.24241599044011486, 0.3083361402874993], [0.02281312928384831, 0.14294390146049762, 0.04641810619843103, 0.036401533401541175, 0.017889520498893915, 0.0770720228132221, 0.07785056732715138, 0.03434508528199888, 0.16607670774382932, 0.08544788425487858, 0.09173643955540273, 49.70857374129757, 51.538551622821444, 53.80863120478969, 28.257119501790694, 34.621286699848795, 44.56479318680302, 60.355188615860484, 38.61666394818214, 22.36512330270583, 10.806605412114052, 12.789092890677914, 59.39360780100669, 41.59375467608052, 61.76151913981285, 46.885012426683986, 0.3245088079523656, 0.7078752931087249, 22.783247963074718, 44.456802491218816, 54.21634981709143, 39.266000563098544, 44.02343550036031, 45.03114338844053, 59.689025032904844, 62.53094696229505, 60.445948339277706, 63.43373537063599, 62.28810125781644, 54.435802505862334, 51.16555383128505, 47.942938420080374, 51.3354120715972, 50.935298935059585, 63.10116152609549, 66.55949961754584, 66.09616571857084, 59.41192919208158, 59.14097186057799, 56.87464206449447, 59.72305551651986, 60.490612368429865, 60.43290645845475, 56.265662716281035, 52.12009399167953, 53.07518328389814, 55.51403853201098, 57.40782945386825, 60.78913219513432, 56.90066306821762, 58.4805545499248, 54.01701104256415, 55.75856301092333, 51.54768290058259, 57.014039178048414, 54.19473363507179, 46.400195706275206, 49.211103454712905, 48.934360627205145, 52.2013262779482, 50.45884863022835, 50.78463285200058, 47.098860048478656, 43.214540789204264, 40.143430848275464, 42.484136627566436, 36.247681802318944, 18.289233523030436, 24.173928230039536, 30.13959634688593, 35.56748005651659, 43.00827510895268, 39.15809223728795, 43.06407866939422, 39.62964350177396, 39.85676834660192, 40.620814677207704, 43.74301741200109, 47.514046853588475, 44.099741289692545, 42.898162411105254, 42.29989897820258, 46.81253094826975, 44.78520685626615, 43.545839863438765, 40.85695705106182, 37.197205251263036, 42.494213196539114, 43.906168399318574, 29.64807825703775, 24.74779648165549, 18.0089174162957, 22.392332784591183, 36.92383566210347, 44.41921834022769, 44.532433632881414, 50.76820204334875, 54.09762359434559, 50.20440447715021, 52.211242029743815, 51.78751230239869, 50.269915903768236, 49.11277747923329, 51.05223263463667, 55.52941030071628, 52.84253181949739, 50.56132839572046, 51.72035740267847, 61.73545106764763, 56.532709444722826, 55.763536576301824, 53.84258716337143, 53.147452954323064, 53.03029960201633, 52.774345336421845, 46.1861127422702, 54.258217196310724, 58.6783871343059, 64.21053724904215, 54.477889537811286, 55.19456932621618, 53.109817812519694, 79.89880592592301, 85.99323564960112, 56.150548996463904, 57.94440184870074, 44.66556672127017, 44.91305651203279, 46.81779869141118, 47.10746180626654, 55.40736967517484, 62.34795270427581, 63.23241972154187, 62.4341977796247, 64.87995247687063, 61.8706080990453, 58.612169681056855, 52.16710752056491, 62.03455532750776, 63.690266224645804, 51.86331995071904, 11.21573901945545, 0.2219270608357845, 0.21909602887688145, 41.54567818487845, 58.06369681512156, 63.713796523309526, 22.247165864513768, 3.2569023197697056, 23.24469324081175, 34.9398616052443, 29.743884109681655, 39.37692126920147, 44.033119832315755, 28.815619907071515, 25.169029620385942, 49.819953364710656, 50.412898063659675, 61.807799185476, 10.914598068883343, 0.47317871102882975, 0.16583037983265617, 0.15847809612751007, 0.040150036089002125, 0.034725459427723, 0.2475963382711334, 0.05207124519191923, 0.04550445441817565, 0.023986595953183792, 0.03369034057663333, 0.07060349047664674, 0.12703860614208445, 0.1684288887847816, 0.06143975740058288, 0.17776169363529454, 0.034899453317085584, 0.2962909092105204, 62.996767643959295, 60.86830915943269, 63.27304370941655, 35.48498476705244, 43.472299345078014, 42.038504385179095, 21.173642566127164, 32.5769159870763, 21.80429889309791, 11.722753413261907, 16.475994356216923, 59.74665641784669, 51.51749241736628, 65.38155301924675, 56.980840236909934, 0.750238974728892, 0.4895502857623562, 17.029733004108554, 39.29888963699341, 57.72519626925069, 46.4805023131832, 51.473459889811856, 49.05640125274659, 64.58009904430759, 67.49158813107398, 67.64988714648833, 64.91775235822125, 65.0534624438132, 56.94960248085761, 53.98582427732406, 49.67229181720365, 54.94006241521528, 55.08198945753036, 70.88756838152486, 67.81011596802743, 67.6705737267771, 63.513139832404356, 60.38959564701204, 58.43973052117133, 64.64175478104623, 62.58457360729095, 63.341775401946045, 59.218179795049856, 55.461474849331765, 55.8651847993174, 59.400028720978774, 61.60454588551676, 64.12789290951144, 58.320145299357755, 59.61074236900576, 54.92557317979875, 58.9797624464958, 54.58176566708473, 63.56767254491007, 57.312190301956676, 51.97031828664964, 54.49512050997827, 52.57488104604906, 53.21396458533503, 52.921908824674546, 50.864202053316184, 47.062766398153, 43.5898135554406, 40.87419194559897, 40.86617069859659, 37.96689195017661, 21.094540126862068, 22.604856606452696, 31.092883310010357, 38.99225050403226, 42.865077218701764, 38.012187480926514, 40.632311144182765, 37.624418043321185, 40.133040489689, 39.16649395419706, 43.828132844740345, 45.51891757595924, 44.825203264913256, 42.42757604968163, 40.22307457462434, 43.302217529666045, 41.81907523062922, 42.4039908378355, 39.7099304968311, 37.396791135111165, 41.24902148400584, 47.34212152419552, 35.14073402650895, 30.620851555178245, 25.853526361526985, 28.103982325523134, 38.36087834450507, 44.73234899582402, 46.328149610950106, 52.315808496167584, 56.57203120570029, 53.96475722712856, 54.76311645200176, 54.70068800833918, 53.56129046409361, 51.157599264575595, 54.150375550793065, 57.60556790136523, 54.56147916855351, 55.10457838735273, 54.64988546986734, 63.10258534646804, 57.13522080452212, 55.81877923780873, 54.644696174129365, 54.1765534493231, 54.1703482597105, 55.34185432618665, 47.73040479229343, 56.881643495252064, 56.733134715787834, 63.603491629323656, 57.45630994919808, 58.40048720759731, 54.85475086396741, 72.3071055258474, 79.08183897695234, 61.6809928801752, 58.79971781084615, 50.10794947224279, 48.95571008805306, 50.53447584952078, 48.4900188446045, 55.623205938646876, 62.14640563534152, 63.838665177745206, 63.60703352958926, 63.89012275203582, 59.82193454619377, 58.81832161257344, 55.35411957771548, 67.85808655523485, 65.99197972205378, 49.96590868119271, 8.099161944081708, 0.028071466780778383, 1.0660332873944314, 54.37517835247902, 61.848434940461196, 71.84240664205244, 21.908808485154186, 8.83838261327436, 17.944592506654804, 22.285626665238414, 29.91979652835477, 41.78510750493696, 54.032265140164284, 35.606299754112, 33.91096115112305, 53.34444222911712, 56.22694892268027, 71.37177713455694, 14.270687814681763, 0.4693221324874509, 0.3170329236215161, 0.1764338334361392, 0.13362945207665045, 0.11990943022312657, 0.07680406057906729, 0.18279659201300916, 0.24452279351892012, 0.14939581734999535, 0.17039831697700486, 0.1678146701306105, 0.23135717417443954, 0.2821252693332011, 0.19251360527930722, 0.3537002512283864, 0.19667939222868414, 0.4528993217935486, 77.29381084442139, 70.90360303078928, 74.98578625340616, 43.237929882541785, 49.625945091247566, 65.94331879769602, 75.64384229721563, 47.20925907934866, 29.7286751193385, 21.15906507738175, 22.17958538762985, 70.6496766305739, 53.116968293343824, 71.69833798562327, 62.38366196232458, 0.5039904609082207, 1.7729988357713147, 31.04767603258933, 51.2588317163529, 68.0833012057889, 54.901203493918146, 59.408481428700114, 55.55360347993913, 65.70435623968801, 72.0105194276379, 72.31511500573927, 71.1358779476535, 70.17129651961788, 58.820541674090975, 56.79204479340584, 52.17924333387806, 59.42123697650049, 55.4141475308326, 68.63244871939384, 69.25427775229178, 69.83357260304113, 65.07479229281026, 63.63831835408365, 59.879303132334066, 65.9829661153978, 64.87072313985517, 66.57255326547931, 62.26091531015212, 55.64414747299687, 59.40267632084509, 63.004628073784616, 63.22504174324774, 67.47847172521776, 61.73062262996551, 64.60710064057382, 62.01251945187969, 63.080361197071696, 58.55647986935031, 64.52404445217502, 60.806472993666134, 56.28044612946049, 57.720258005203746, 57.640394626125214, 59.37714953576366, 54.63988734829811, 52.346304924257346, 49.475639866244414, 45.33412295003092, 42.719149358810924, 44.60794710343884, 42.31130915303385, 26.273237620630574, 35.74983496819773, 38.88260456823534, 41.25710941130116, 44.21243882948353, 41.73274778550671, 45.36344658943915, 41.214006485477576, 42.06925576733005, 39.098166265795314, 45.673768827992106, 52.080348614723455, 51.52183840351721, 44.76812101179554, 41.635841708029474, 48.97074453292355, 47.07398437684583, 46.92079228739585, 42.58567894658735, 39.98598298718853, 40.43373723183909, 53.100494338620095, 43.49395475079937, 39.106167900946836, 34.86972962656329, 38.06017375761463, 41.36009908491566, 46.92166697594428, 46.85835599899293, 56.122951199931485, 60.942951863811864, 59.426645924968106, 59.00852910933956, 60.61806978717927, 55.719837450212054, 54.562330322880904, 57.18257165724232, 59.54040250470562, 57.0838063763034, 58.74811510885916, 57.541962746650945, 65.83240201396328, 59.181187921954745, 58.18342716463151, 55.48604457609115, 57.60033545955535, 56.70252846133325, 60.84659491815875, 51.351587926187825, 58.08921967783282, 59.928309225266986, 69.47395401616251, 61.29830683431318, 62.48188203380954, 55.7435207213125, 77.88335092606084, 88.34505742596042, 60.516943239396625, 62.99179015621063, 51.58460809338478, 51.82151140705232, 53.52887599698959, 53.38660770846952, 61.34001731872559, 66.46169139492896, 67.63535084262972, 67.42069521257955, 67.64974594116211, 63.098706122367616, 60.400578283494525, 56.262262021341634, 72.55291261980611, 66.85445400976366, 59.590918710154874, 14.47482462852232, 0.311414557358911, 0.7484003024235849, 53.75669510133805, 70.76132297515869, 74.8387836640881, 33.092919472725164, 12.516921585605992, 30.1630070132594, 45.60040089391893, 38.50562164860387, 51.95855902087305, 56.90223986102689, 41.068153150620006, 36.46141959774879, 65.61034094902777, 65.73544886804396, 85.87438783337994, 25.424603416073708, 0.797683719185091, 0.3960968746292976, 0.2846671490659637, 0.27124041631337137, 0.29144071463134985, 0.31798112596715655], [0.17410382297971558, 0.021280440156378096, 0.024038630560220733, 0.038347458016247525, 0.12183572766521286, 0.054461347585123394, 0.02158588515744815, 0.054002652440460465, 0.015995803818617378, 0.10837704138529879, 0.09664132515148771, 47.460255469045336, 58.82504455504879, 47.26544310969692, 32.099124231646144, 40.325813216547814, 48.05731865667528, 124.3843044773225, 150.70063129548106, 18.07009070150314, 5.6351795023487465, 28.307388597919097, 52.27985605116814, 55.22680728666244, 45.34508205229237, 66.4914543397965, 13.075229794748369, 0.20938266218910295, 0.8968559460293863, 5.002485994369754, 11.397551663460272, 8.577487141855302, 7.29575070642656, 27.637137905243907, 56.927856860622285, 55.78428199214321, 62.972413647559385, 56.97793768298242, 56.99013625421832, 55.963906934184415, 54.20846193067489, 50.273838273940555, 54.34541932998165, 63.39086778702275, 56.40578546831685, 43.254886288796705, 45.23720902781333, 53.86180285484561, 56.32295285501788, 52.718526086499615, 60.14714217955067, 62.283355189907944, 62.99367681626351, 57.64587417725594, 53.07295145527009, 57.563500481267134, 56.67840980714368, 53.1120692529986, 56.18553261603079, 56.3779523295741, 52.48026171038228, 55.51226954306326, 53.4937943181684, 51.2486021749435, 47.739143833037346, 29.782168403748546, 33.63509301216372, 44.9380341652901, 48.74151729768323, 50.234030139061716, 45.55928268740254, 48.1575430593183, 48.48594350199546, 48.473305625300256, 41.37298799330189, 44.423521180306714, 47.98995587133592, 45.356821706218106, 34.384759933717795, 33.198890147670625, 33.82058189761254, 46.09382329448577, 41.864574724628085, 42.927670401911584, 41.460354866520056, 42.72154984935638, 40.812700948407574, 45.98734271141791, 43.52228210818383, 44.135364255597516, 43.965733512755364, 42.34863834996378, 45.36277194176951, 43.872989070030954, 43.40167314775529, 41.11673562757431, 41.006116943974654, 36.56118116071148, 29.117309008875203, 23.431488275527958, 16.138227293568274, 22.463353180116226, 38.935450661566954, 37.36261944616995, 41.6899468821864, 46.23236925371232, 50.67412791713592, 50.057876494623, 49.401977754408314, 47.15371439533849, 49.81833734819966, 50.37938925527757, 49.293332023005334, 53.08510295806393, 49.92930904511483, 54.38224646352953, 53.88791407308271, 49.55237319392543, 48.21099319765645, 59.22653052114672, 57.2809878472359, 52.39348319268996, 55.953744073067945, 52.25825163625902, 49.529784264103064, 51.530561754780436, 53.855174049254394, 58.768378073169345, 58.19988935224472, 56.54695157081851, 47.72867502704744, 66.21802591508435, 73.44998221243583, 55.92944891222062, 60.80577481177546, 58.640583330585116, 49.28986857014318, 46.23406371762676, 45.829286882954264, 47.05878911479827, 48.45776519467754, 61.39853515932637, 60.10978552602953, 67.12814915564753, 60.956931191106, 61.93082040356052, 59.97100422459265, 59.26805273179085, 45.728505503746774, 50.79992617330244, 13.578587558961685, 0.15689042486971425, 0.14857739029872805, 6.891210684853216, 57.5797704727419, 56.6805318094069, 59.94599519237396, 19.823613743628226, 11.231036263127482, 13.4996675099096, 23.899823196472664, 26.226479045806396, 32.3146447443193, 46.55082256563249, 65.86499691009521, 17.445488552893362, 43.16444819973361, 49.42193085147489, 51.217627217692716, 6.987722073831867, 0.20951703401102176, 0.08042466871800923, 0.0134591564663776, 0.014323873422859658, 0.008278121071447047, 0.05269220158938439, 0.018798763443145062, 0.030041934937358867, 0.052928984045021, 0.020586012096534816, 0.05005166505373294, 0.012202541486570432, 0.033149907680889296, 0.05078461967528828, 0.04291550241290562, 0.07382266088238648, 0.3264068673935629, 58.614464267607666, 68.04040616558444, 50.63132701381561, 28.28223836037421, 42.999779255159446, 53.29649125376056, 130.47361158555555, 161.89793125275645, 23.354092067287816, 6.491536853774902, 35.64231495703421, 58.190157951847205, 59.56489378406156, 53.44368603921706, 72.64913620487337, 20.314339514701597, 0.1330048299484676, 0.27788530975099535, 2.8859718624622595, 9.162011492636896, 10.940379808025977, 15.830833104348953, 37.65542830190351, 61.554112049841116, 62.86570556702153, 66.55725602180728, 59.16490224099929, 61.18583286962202, 57.1630931669666, 54.95807001667639, 51.172449358047984, 53.62662930642405, 64.25405986847417, 50.92081754438339, 39.28097225004627, 47.42320868276781, 53.3824029276448, 57.31291594043855, 51.33468251074515, 60.24007489604335, 63.864191962826645, 64.9878490355707, 60.35582796219857, 56.13927610458867, 60.53358585603776, 60.23908645875993, 56.89248884877851, 60.69780372804212, 57.05887579148816, 56.80142318048785, 57.812594521430235, 58.90079729018673, 57.105528462317686, 49.19863423993511, 33.944371900250836, 39.449234085698286, 47.88113755564536, 53.12890014340801, 52.73125810007895, 48.91907515064363, 48.07311011898903, 52.01453124323199, 48.63061620343117, 39.098076051281346, 42.92167309791812, 47.58894058965868, 42.43933531545824, 33.08360384356591, 30.294906516228956, 33.17592074794154, 42.73887888077767, 39.5397388550543, 41.18343945472471, 40.99601684078094, 41.53920627409413, 39.780682209999334, 42.137379492482836, 40.9275754036442, 43.39139653790382, 44.063820223654474, 41.867571415439734, 45.62245245902769, 43.855781632085005, 43.05925415408227, 39.89776888201314, 38.69436610129572, 38.17409115452921, 28.308349578611313, 28.053409245706376, 18.27567388934474, 21.201420791687507, 37.47638779301798, 36.67679302154049, 39.488457787421446, 46.4225257596662, 52.6042752881204, 50.34404085528467, 52.032126995825, 49.9406054712111, 52.78178607263873, 51.544058630543375, 49.908759747782064, 52.54677726376442, 51.49834340618503, 55.18080965165169, 55.891754934864665, 52.55218621223204, 52.36172376140472, 60.59858737453338, 60.47582503288024, 54.54734294645248, 57.319219189305464, 55.76673330799226, 50.55805321662657, 53.86396015844038, 55.92971563339234, 61.00109315687611, 60.62094096214541, 61.52194076968778, 51.72353452251804, 69.18324362847113, 67.4789188754174, 55.048912109867224, 66.08162941471224, 61.6438990254556, 53.432130736689416, 48.46531183488908, 48.658684684384255, 50.46139817084036, 50.093668122445386, 61.21712161648659, 62.79274948181645, 67.13270694978776, 62.19943215770107, 62.948377363143436, 61.13591286443896, 61.063074450339045, 53.232509551509736, 52.05298616040138, 10.008700201588294, 0.09365581922353276, 0.35844763680811853, 12.52342781712932, 69.1536375784105, 62.80574037182716, 67.30121197239046, 26.5296253081291, 17.1822347564082, 11.756461281930248, 21.62821977369247, 27.74818216600726, 27.84697098116721, 42.87347893561087, 75.13739370530652, 17.072141670411636, 44.584401115294426, 57.81606581903274, 65.00819044728433, 12.005181716334436, 0.24101518334880953, 0.09993065388933306, 0.10126381541692442, 0.0510831143436653, 0.07238990792463865, 0.11022709009628143, 0.3587406807609143, 0.17131103412999263, 0.16851879686357515, 0.21990160097277936, 0.13796652096413797, 0.2567075598504274, 0.14355767578367265, 0.19498063822186765, 0.15559190583805885, 0.15847602769011454, 0.70874281107418, 73.02502478322675, 78.1759205172139, 64.07151276065458, 43.55677935384935, 54.54706445817025, 63.32736069156278, 128.97840407586867, 155.5014084231469, 26.604619064638694, 14.01829113883357, 40.54381855072514, 63.60093424397131, 68.62031290608068, 58.75708164707307, 84.40012578041323, 18.093983819407804, 0.3711612336337567, 2.0618429107050744, 7.673559775275569, 17.865372396284535, 22.207504818516394, 31.75253575847995, 47.46412292603524, 69.2835464785176, 68.40961886990455, 71.35535809301561, 62.67763183962915, 64.08324456983998, 60.84569669538929, 61.913667878796986, 54.33228723464474, 57.67985759242889, 67.4624135417323, 61.79925626324069, 49.09847259521485, 50.885935906440984, 58.85383475211359, 60.5193986431245, 56.49185403700798, 63.59411716461182, 65.57076423398911, 68.39898924673757, 63.88310563179755, 56.85261403360675, 63.29880191433815, 63.680350472850186, 59.04976106459095, 66.21535085862683, 63.354844739360196, 61.26020100808913, 62.85409535131147, 61.78533184912897, 60.069738126570186, 53.35353428317655, 42.72393465042115, 47.30009725016933, 52.06553774495279, 57.730601295348144, 53.86630573580342, 51.41704836199361, 48.02146427093014, 53.697377097222116, 51.78917538735175, 43.33316503032562, 46.55004985870854, 50.74793123429822, 45.82774146910637, 36.560992886943204, 35.01825801787838, 34.34475175796017, 45.30701937214021, 42.85053699247299, 46.47314002436977, 44.059489926984234, 46.263720758499645, 42.92175154532156, 47.689172837042044, 43.386956414868756, 47.707337333310036, 46.886063621890166, 43.81305525379796, 48.8117394908782, 49.67340184796242, 47.31253900835591, 44.16063216424758, 42.57617896603, 42.05864967838411, 34.803025799412886, 36.09868272658318, 30.380827996038622, 29.25863592855392, 38.67031804976925, 37.74101049669328, 40.26827204611994, 49.28232192993165, 55.98809619103709, 52.102007942814986, 56.71276192511282, 55.31626870555263, 58.13517416677168, 54.32279509882773, 54.04373022817797, 55.40234904135428, 53.26133112753592, 58.056177631501235, 58.3022867479632, 55.65989578923872, 57.820333357780214, 59.781730251927534, 60.0255722384299, 56.79593186224661, 59.5663332939148, 56.97736109456709, 54.02223956200385, 55.4482368500002, 59.21950947853827, 62.517705040593306, 62.156042898854906, 61.0681107736403, 60.914585282725675, 63.796272200922814, 77.62478043956142, 75.81526556322652, 65.6326396234574, 67.38060074467813, 54.752875143481845, 54.92822077966506, 53.824367753921024, 56.88912345517067, 54.22663819405341, 66.57958999756845, 64.02171434894686, 70.44014361596876, 64.18628915663689, 66.9037974265314, 64.62260969223516, 62.71121909541469, 54.51478727402226, 62.61743130222444, 17.789955023796328, 0.6239145080889426, 0.2655321113284557, 9.596844469347309, 73.75605260172199, 65.55429027926537, 73.23611890116047, 29.63857239292514, 21.55562258535816, 21.26392964393862, 34.36843502906061, 34.034974728861165, 47.58026430683751, 62.80474801217357, 89.26385694934477, 25.77496717053075, 58.81119858834052, 67.9460653181999, 85.58548958070817, 19.726962620212188, 0.5299991765810598, 0.4843745038153664, 0.30289247271514713, 0.1788367754629543, 0.14431133776182128, 0.2110112118985384], [0.09270085998240019, 0.18469581590785136, 0.07969760531259161, 0.06064650399850742, 0.0385037859180762, 0.05513540536706006, 0.0897838423148759, 0.08578069583182374, 0.11342565273685802, 0.0056572428307375845, 0.13564383430827048, 44.09299873536633, 61.47527240937757, 49.222552853245894, 42.06684743204425, 36.55178708414878, 36.34089692946404, 20.822288413201612, 49.17166010026009, 15.792590975761415, 1.5299127635455902, 35.15144994181972, 65.44014930725098, 45.69917009722802, 46.47900789014755, 60.56082279451432, 41.47223964814217, 0.21571854640158916, 0.09153131185279739, 0.03605205941224291, 1.9088204637650523, 3.6037812934767817, 9.754595333530057, 6.545856777698764, 52.151037569968935, 52.30028767739573, 61.23342298692273, 55.97535633271741, 60.852148994322754, 54.03914497744653, 51.791069892144975, 46.11759678010018, 56.75386444214852, 46.628505106895204, 27.31882775983503, 34.77028577558456, 39.70743586940151, 44.423219157803445, 47.36103519316643, 42.08077184615597, 45.472672831627634, 56.66301058184717, 57.869413975746404, 57.63748814982753, 54.37072646233344, 54.426835967648415, 56.316563314007176, 55.08047542264385, 54.706308764796105, 54.20652427980977, 55.92820944324617, 55.504993546393614, 45.83768859986336, 32.978068551709576, 25.74776161101557, 29.69305999817387, 21.590541485817205, 37.568743921095326, 44.76510470913303, 44.98406317926223, 44.62435830023981, 50.17326085798202, 52.1289546258988, 50.65783439144012, 51.96406602859498, 50.3025225670107, 46.072050217659246, 47.29119739224834, 51.82816374686457, 46.68787410182338, 46.612925452570764, 46.504954368837424, 48.00666516826999, 44.7822101654545, 45.60352702294627, 46.46199264834004, 44.73708721899217, 46.3049566361212, 46.96975915662704, 45.48199630552723, 42.87749544266732, 42.714371911941036, 44.379751451553844, 43.46416434934063, 40.033196556952696, 40.84595872509865, 43.54774613534251, 35.549688185414965, 30.616433005179132, 27.717297423270445, 33.7017576156124, 44.4555865564654, 43.68582925488872, 38.619801844319994, 43.943497596248505, 49.067980089495265, 48.27936403213009, 46.89063318314091, 49.45754989500969, 47.14542642716439, 49.22959743007537, 51.29337210809031, 46.36208203531081, 48.7927826758354, 49.10037886711859, 51.513805389404304, 46.10969320420296, 46.729733636302335, 44.40139901253485, 53.33715446533696, 61.06221152890114, 52.98160337632703, 53.7404094203826, 50.28724101281936, 49.07798997817501, 54.92700484491164, 52.00734938344648, 60.90548538392591, 54.870075564230646, 55.9703984568196, 46.977011619075654, 75.20285021874213, 52.30946994596913, 30.241819197131743, 68.56793357479957, 57.6901420470207, 57.19546448799872, 42.5710210492534, 47.219684739266675, 43.68100473957677, 51.9958842954328, 53.949663946705485, 62.77763266717235, 59.50441868074479, 64.72697219540997, 59.15172699959048, 65.70468571878249, 55.09842418855237, 50.449858557793405, 16.59823502263715, 0.5963267013430595, 0.3012227074753854, 0.18110666333908038, 18.370775676542713, 57.162614637805575, 53.93460988998414, 58.30497749390141, 37.21145522209906, 19.437287738246305, 9.914396616720385, 18.21346313722672, 24.47353063091155, 45.487091464381066, 52.573637654704434, 56.96360926474295, 29.387234757023474, 44.906376715629335, 55.104833341413936, 52.223024829741455, 4.827397273432824, 0.233913057994458, 0.18847947820059716, 0.048496835985251015, 0.09394554601561639, 0.07233682569236526, 0.036335262965651295, 0.10834724056504427, 0.007885447384098606, 0.07733453050135605, 0.036036408235949856, 0.06962305881203183, 0.008524368543388143, 0.01838115742430091, 0.2106744396470247, 0.06397283861353513, 0.032012288180750706, 0.10524617793459086, 48.82581295505647, 69.38200581458308, 56.39747788829189, 40.83120669088056, 47.413889131238385, 45.78478367097917, 38.063315576122655, 66.15041994279431, 21.5173480972167, 3.8410082026835415, 40.64702787706929, 73.03847066817745, 47.272044458696925, 53.462886041210545, 66.98342154102941, 46.706289629782404, 0.996147008432496, 0.07798219655430125, 0.0688117870219773, 0.9810108883726982, 3.118743694597675, 7.961944197454761, 19.744579945841146, 59.80712367642311, 57.65628414769327, 66.15741745118173, 59.044587458333666, 62.1362074728935, 52.628774412216686, 51.763205374440844, 48.323729961149155, 58.88467634877851, 48.41392878563174, 40.55716245405136, 44.30357902280746, 44.02003872779108, 45.06755082837997, 48.06426909662063, 44.506204743539136, 50.38200155381234, 59.487866278617616, 60.9551896587495, 57.26691438305763, 59.650872138238725, 60.387155932764855, 58.622936587179865, 55.123095896936235, 57.86523665151289, 58.336952655546135, 59.48341438847204, 57.58361831788094, 50.451196086022165, 37.52236581617786, 28.80588262311874, 33.85638529254545, 28.56661019786712, 42.12480437371039, 49.95900923205961, 47.26310929944439, 46.281038022810414, 49.16932236763739, 53.151842086545884, 49.53576195624567, 50.5492788745511, 49.37059094828945, 45.21346299879013, 44.774773351607784, 47.46365616398473, 43.64590737127489, 43.67966721134801, 44.06901736413279, 45.47594408835135, 42.51412314753379, 43.473064207261615, 44.90155220031739, 42.87504788367979, 45.21161556243897, 48.23598261802427, 43.6056677756771, 41.14766351638302, 42.9490198627595, 43.2607110085026, 44.41104412078858, 41.46077456012849, 43.17432865019768, 42.305504045178814, 34.091347032977694, 29.97303878107379, 27.623484134674076, 30.69480000003692, 40.70260001767067, 39.73183693424348, 36.0370897477673, 41.25539533553585, 47.21595064286263, 49.45726356198711, 49.62976940216557, 51.210759147520996, 48.21922625264814, 51.676685733179895, 49.27799947800175, 46.55252879665744, 49.820577021568056, 50.261949569948264, 52.743429214723655, 50.632225236585064, 45.721766871790734, 48.18289333774198, 55.7329224771069, 60.58686341008833, 55.96703306321175, 55.10755938868369, 54.52959029905258, 55.5626759221477, 56.89081007434476, 58.60911023232245, 61.61364578431653, 58.13954760951381, 61.192277323815134, 56.043793847483975, 79.37706009034189, 55.67163936553463, 33.419190068398755, 71.14889237188524, 61.735780546742106, 59.67070364182996, 45.93517911049628, 50.94396345077023, 47.207172378416985, 54.38381933396863, 56.36058015208091, 62.789085988075506, 60.38550853729249, 66.9813975980205, 62.18381327967491, 68.20800119830717, 58.5557738427193, 58.343856027049405, 16.264111841878584, 0.4438868183041773, 0.08034450527761253, 0.7805674763456468, 25.638692263633978, 63.002953221721036, 62.669900848019516, 67.11918261743361, 47.146501156591604, 25.968614585937996, 13.04875183490015, 19.441910251494377, 22.659028460902555, 42.440088410531324, 60.19776036662441, 60.122799950261275, 32.079953647428944, 52.94805142187303, 63.731427577234086, 63.95604994989211, 7.736607953425377, 0.3071285405706975, 0.07901901995102245, 0.1016074747988774, 0.08841806842434792, 0.010896351041963265, 0.052030784258198355, 0.21059531808620502, 0.25772169172283144, 0.20314456143927193, 0.10179846051840052, 0.2714855031621072, 0.2548517271756165, 0.19178960622558672, 0.28631911042236513, 0.23339748082141723, 0.15162504127910062, 0.214477805721183, 60.74229909527687, 77.42347655757781, 64.93418708924325, 58.8078998750256, 53.67997354076755, 49.924410004769605, 27.967405396123088, 58.57162414058563, 22.258601534751154, 6.147474386999685, 47.373947635773696, 77.45659705131285, 55.91219832820278, 58.16154033906999, 74.32001098509758, 51.178670237141276, 1.0665197838698666, 0.17854624427855018, 0.1849860253353273, 2.1259172789512144, 5.120425291599767, 10.64330537473002, 34.68435056747929, 68.98248887831166, 62.808219309776064, 67.74675400026383, 60.46047679839596, 66.3309980207874, 57.668823965134166, 54.611516844841745, 51.52650602402226, 61.1557129890688, 53.60990824237947, 38.03876546121413, 35.72351586434149, 41.39825590195195, 44.73970736226728, 47.87171994486163, 43.52367062722483, 52.100674336956395, 62.046314593284364, 65.4325516762272, 61.511970104709754, 60.03106747904132, 63.29334589742846, 62.03134682870681, 59.03554639508648, 59.990212071326475, 62.4786853021191, 60.21419509764641, 59.65786964662614, 52.173336244398556, 46.83421381058232, 38.89069249553066, 38.80307066825129, 33.57852851190875, 47.52861845877863, 52.51061693314583, 50.863323442397586, 48.15606040339316, 50.65632035655361, 58.969352476058475, 54.0378741295107, 55.03037891080303, 52.40916090626871, 46.33454699670115, 48.88293443187591, 51.25785504617999, 48.38071023264239, 46.88962513400663, 43.3020959361907, 49.79607005273142, 45.41269586932275, 48.91953406795379, 49.318807817274525, 44.85954753814205, 49.80894719400714, 52.24315051109561, 46.19360446929932, 45.416955563329886, 47.812433319707075, 49.36723732179212, 50.07597431059807, 43.84710927163401, 45.85133452569285, 47.113682685359834, 38.20253226064867, 35.94916197561449, 35.084161681513635, 35.18582559400989, 42.21187314679546, 41.993495187451764, 36.18190757689938, 42.86302974147182, 49.873740826883626, 53.69574146886026, 54.69246672045801, 52.960010728528424, 53.26370416149017, 56.63457339809787, 55.15695379626367, 48.88720589299356, 50.73124939395536, 54.30298712945754, 55.66564598391133, 56.20322250550794, 50.647663685583304, 50.10456838915425, 60.63868576480497, 60.85724023080642, 56.180727712569706, 57.62500324556905, 57.21446837148359, 56.577534291052054, 60.05196978968959, 60.75652553189186, 64.11677299007293, 59.892548976405976, 66.40109862050703, 59.20938191875335, 86.73344181429955, 60.56588265203661, 41.88455527828586, 71.93392338291292, 64.89551644171438, 62.79864088181527, 49.83414057762393, 55.65484769882695, 48.89807478074105, 57.454250704857614, 61.817828686006614, 67.26834251034644, 62.69145034974622, 71.41521346184516, 65.59833849630049, 73.0419772671115, 62.84191639192643, 59.57500565436579, 27.51268502204649, 0.7933642090328279, 0.4591246441968026, 1.04715111995897, 24.16782109968124, 72.66106805493756, 65.99719647438296, 72.78743897714924, 49.89905188160558, 29.213824810520297, 18.256417012983754, 24.94347764599708, 31.489440817986768, 62.35305570787, 73.50214973572763, 73.62732825740692, 41.44915257730792, 64.45386540505194, 72.64553546905518, 82.57940077012586, 17.156678553550474, 0.6166589200015992, 0.3826634003029716, 0.48415573974770887, 0.17332383822048866, 0.20893247828127878, 0.1643187657839829], [0.07365465013971252, 0.12842811343650665, 0.23775587759671674, 0.033929812000884164, 0.11082880619552829, 0.09691643498597607, 0.09558866671737164, 0.0220971473402554, 0.20687901024376193, 0.3892037074171728, 0.18920896244385552, 41.01950791574294, 58.371771535565784, 56.5463436034418, 39.73927374809019, 19.921414121504753, 41.96120231382309, 22.272447501459432, 43.304519960957194, 9.516306442599143, 6.159663642606428, 24.532474048676033, 67.81936491689375, 51.32655143737794, 48.957035849171305, 52.40463056871968, 54.40426664967691, 0.7507616918413871, 0.08495782547059559, 0.12573234962239382, 0.4153799818408105, 0.22187528861386163, 1.6543357386704416, 6.40462399490418, 43.09293162438178, 53.22204859026017, 62.940018792306226, 60.01161644535681, 57.47586688687725, 56.037282712997936, 51.15455942769205, 48.10384581165929, 58.397427758862904, 65.00680192824333, 73.096937517966, 116.56828372709214, 67.20645535376765, 46.10431563469672, 51.32519429729831, 47.917443013960316, 52.03073455441383, 50.39321168776482, 57.54888180763491, 55.059196564459036, 58.34771956166914, 55.13156821650844, 56.08914036904612, 49.36837873151226, 54.711945210733724, 56.348475717729144, 54.043494885967625, 39.61225171242991, 31.48037425933346, 23.733855947371453, 37.63835030217325, 34.77099572458575, 51.200851240465724, 47.16444600012995, 43.41340103457051, 42.98531355396394, 42.45111811545588, 48.03493369010187, 49.23906210930117, 51.76463703955374, 62.37187523995677, 54.804093453191946, 57.715217759532315, 49.91682021848617, 53.121796731025945, 49.970995995306204, 51.88060583606843, 49.72462408004269, 52.15912549726425, 51.55795166569372, 47.89739578000961, 48.207306169694476, 46.49765876031692, 45.08158114648635, 42.525070482684725, 39.787542435430716, 44.11504245573475, 42.04241498824089, 42.93407955477315, 43.4942763851535, 42.24250685784125, 42.11989356625465, 41.76729994435465, 40.2498722076416, 44.06051366559921, 46.58699074099141, 55.26510138665476, 53.68658665687808, 52.69286594083233, 47.43062196239349, 48.49425892676077, 43.55382188673943, 50.87694583400604, 47.98186794404061, 49.42072668383199, 48.75430422444498, 48.49335678162114, 46.01174769863006, 46.019443388908144, 44.57053945910546, 44.775463688758116, 46.67076864550191, 49.33136724656629, 34.10390646226945, 28.53206000020427, 40.15480179940501, 55.78664325898694, 60.2149756493107, 56.85645795637562, 53.98831890475366, 50.64172913951259, 52.069009042555294, 53.3842150626644, 54.7406255814337, 59.94379474270729, 50.16460026464155, 50.381448499618045, 47.79504153036302, 42.50657258495208, 51.20349099559169, 63.191952628474084, 60.727692188755164, 57.660308499490064, 46.44527550666563, 45.65885597659696, 47.05864790947207, 51.35806768171249, 49.56923938566639, 56.2091217502471, 58.04424578143705, 64.01597592138475, 60.76617456251576, 64.4508961708315, 61.24956746255199, 40.29224949498331, 1.7779768138162553, 0.0057681852899071195, 0.2949906128548807, 1.195086497933634, 28.812727159069432, 60.08938135639314, 56.087367457728234, 65.17242400876938, 59.99899033577212, 37.185685250066946, 12.209484250314775, 15.502668984474676, 27.273257663173062, 65.58740292826008, 55.592937008027114, 56.85894473906487, 20.547530305001047, 42.57861868027718, 54.99110029589746, 45.55642327954693, 1.6991325155381234, 0.17192073286541049, 0.18450573417207888, 0.03803916125287933, 0.019075001342101924, 0.028761530054673076, 0.01687778839691272, 0.11777452703925873, 0.10964160740015008, 0.1787449981296255, 0.05076792278897859, 0.15474812127649784, 0.05568138856981551, 0.10765140290342032, 0.1016633685738329, 0.18298174014254925, 0.22627153013262058, 0.23764433519494152, 45.05293607711793, 68.32421318177255, 61.49984998087729, 41.38841467518961, 35.535265630291356, 46.997007862214126, 30.1208984082745, 52.073535457734145, 12.278097291146556, 9.92681876305611, 28.308033827812444, 75.11975088427144, 54.828094436276345, 52.596987524340236, 59.44498692789386, 64.99470926100209, 1.508237500825236, 0.11617437620917637, 0.034031778303605896, 0.229409855279711, 0.14927878975868225, 1.4357729376323762, 12.21739959332251, 56.74889087677003, 59.067498022510165, 67.54886258033015, 62.18347595584009, 59.68714229522213, 55.51223816410188, 54.205728038664795, 50.144298076629646, 61.08392577017508, 69.60744011786677, 83.38941727915119, 98.42355620476508, 59.30463667838805, 47.50024011058193, 53.31313387040169, 49.83533690052648, 52.219373103111025, 53.4062195593311, 58.88868108872445, 60.137434313374186, 62.034598473579656, 58.198324326545965, 60.57949719890472, 51.628566095905924, 57.52832074319163, 58.53134924365629, 57.21436638985911, 42.995409734787486, 37.593313647854714, 30.48021105027968, 40.87614528594479, 32.582430839538574, 64.70789770926199, 56.44216545166508, 45.302571404364805, 45.6370162194775, 41.56460362095987, 49.53076093427597, 52.119835115248165, 53.7068300093374, 57.45893009247319, 54.75051387663811, 54.7638342457433, 46.58187597028671, 49.955149619810044, 48.364942304549686, 49.15622165126186, 46.121738803002145, 51.242228323413485, 48.01141908091884, 47.3266673857166, 49.222674446721236, 47.22279125644315, 44.61548197653986, 43.55315116143996, 40.04517155308878, 41.83256033928164, 39.82936666857812, 45.622409312955796, 44.22358620551325, 40.70804426746984, 42.43842140320809, 42.17004891364805, 39.075542034641394, 41.08994976166756, 44.85785699659779, 46.499890588944965, 45.723069098687944, 48.519373862974106, 44.45727317563949, 43.290403350707024, 42.880676484877064, 49.77997264554424, 48.64634098545198, 51.63623825196297, 49.00490837712442, 49.78321644567674, 47.60350042773832, 46.60002085470384, 47.85452035165603, 45.935826301574714, 46.50430717775899, 51.128483510786495, 39.43215216359785, 26.529217381631177, 42.92581904319025, 58.02171176479709, 61.36876044734832, 58.75106080885857, 55.49255963294737, 57.212405204772956, 56.53694560450893, 57.554012267820305, 57.25922653751989, 64.12069143787508, 53.764943845810436, 56.76512948928341, 49.23347273180562, 51.81785575805172, 59.246063924604854, 59.032730133302756, 64.49881968959686, 59.790430068969734, 48.0397895843752, 48.21951258567072, 47.948551331796956, 54.804238580888324, 55.10991281078708, 57.247196628201394, 60.43354972716301, 67.04493999481201, 64.8165552077755, 67.12772553966892, 66.34926842105004, 46.174882996466856, 1.1163599933347395, 0.09324178700485537, 0.11825530083789942, 1.756345187464068, 36.15112873815721, 69.59372751174435, 65.17952349878126, 72.88535702613093, 71.92786724336686, 43.95886152021347, 14.425656737819796, 19.659470396657145, 28.233473493206887, 66.78603218447778, 61.20337763140279, 66.41440330013153, 19.83650657438463, 44.17289741577641, 63.71474573689123, 55.83828126230548, 3.5284872305008674, 0.1088527360210015, 0.19825235459833376, 0.04769908947749965, 0.1200281815122693, 0.09658265047736707, 0.039779100146505146, 0.18211454393402224, 0.21303334693995216, 0.36525772944573437, 0.28590321661003176, 0.331013813735016, 0.21267129378693722, 0.2512147400768534, 0.2999950975420014, 0.29350973425372956, 0.42789516189405996, 0.332337184658935, 58.39071266112789, 80.28209209442139, 73.84611022087836, 51.89777797268283, 32.02996696195295, 58.12457984493625, 28.314044860101518, 50.937742571676935, 13.902540033863438, 15.54158870250948, 33.50459183416059, 80.34244952663299, 62.47215847815237, 60.88125690337151, 66.44445650039181, 68.97988442451724, 1.6188072773718065, 0.4969228095104618, 0.23769941691669727, 0.5564150526638955, 0.2592450115949877, 3.350971543019818, 26.71592808538868, 65.94149097319573, 61.47491547369189, 73.04785297762963, 64.1162238582488, 62.70212311898509, 57.177931493328465, 60.697580152942294, 51.7372549733808, 65.91746253352012, 59.096398045939786, 64.90822099870252, 90.56666435733919, 56.820172109911525, 49.20459232022686, 50.198395406046224, 51.145832154058645, 53.210971816893554, 54.57845910902947, 58.98191190535023, 65.30146606506841, 66.969481437437, 60.20980596542359, 62.903058298172496, 54.48072933381604, 62.95921094955937, 62.07257486158802, 62.29693835781467, 53.06102352757608, 46.328706587514574, 38.32218808512534, 48.60507765123921, 36.82445849141767, 62.952711582183845, 62.21666312986805, 50.07267951965333, 47.81410424940048, 44.13925524680845, 53.59058272454047, 54.9969877735261, 59.299266953622144, 66.37840378669001, 59.49429504333004, 61.14682097588817, 52.64244779463738, 55.11152882729807, 50.950921735455914, 52.80904262296615, 48.32118434290732, 54.907212565022135, 53.10726042716734, 50.39184278057468, 52.48788679799726, 50.766699775572754, 49.86127553447601, 47.610191991252286, 43.7216365721918, 49.41934208716116, 46.324442971137266, 49.28226701674923, 47.627450420010476, 45.63318014144898, 46.11005406225882, 45.81076937337076, 43.9162096669597, 47.97619227440127, 49.72318064781928, 51.51641376556889, 51.34163295069049, 52.586487339388945, 45.54907275784401, 47.22295599599039, 44.10551109621602, 51.43911169421289, 52.19725485770933, 55.39556334095617, 52.92587434091876, 54.12342494533908, 50.14685153961182, 48.42709225993003, 50.75452866092805, 48.7227487564087, 51.40572055693596, 51.553617446653305, 45.317421497837195, 33.53789667929373, 48.36107484755978, 61.6424124471603, 65.0074883430235, 61.519312781672326, 58.585321057227354, 58.874952793121345, 58.928814780327585, 59.86836364192348, 63.334805350149836, 66.42098503728067, 62.45864983527892, 59.210637077208496, 57.74946789587698, 55.90019195310531, 53.928949909825484, 67.74523996537732, 64.9380035554209, 65.5980678527586, 48.88327175571073, 52.306371273532996, 49.141144060319476, 59.48691706503592, 55.930723682526626, 61.23802784950503, 63.120761609846554, 71.38847858675065, 67.7630396812193, 73.96307529941683, 63.56005137966525, 55.600785670741914, 4.98169449067885, 0.37483376721220635, 0.7775168529441281, 1.849126402408846, 42.56720066070557, 76.32090614688012, 67.20388227893461, 77.79730196922057, 73.62161728643602, 48.692071899291015, 22.093167727993382, 23.76293836101409, 35.899944074692264, 79.92762750194919, 70.83490663959135, 76.76513810311594, 27.840646159264352, 59.864719760033395, 72.56909631913709, 78.1270399401265, 8.069492155505765, 0.5164592160332588, 0.37601424741648865, 0.12066592672659505, 0.3643314065712114, 0.2519692753952357, 0.11107511112406371], [0.09593461670221821, 0.04423934448089811, 0.05602938017898029, 0.03601193172676909, 0.008238419522381118, 0.27873753660148193, 0.05679176789858649, 0.09781702496712247, 0.0909623766558305, 0.11778403419039904, 0.4906300713698711, 18.26941967010498, 65.59895038604736, 45.60830446981615, 44.245543633737874, 23.18590475666908, 48.28115655529884, 31.291857304111605, 45.19333339506581, 29.176848626905873, 3.902468066061697, 19.503314956541985, 64.61532192845499, 58.53587173646497, 61.17495613713419, 44.38669796912901, 52.70508804628926, 4.494733214378357, 0.17559296000869046, 0.01837688839934286, 0.09470840870973565, 0.06993186119343005, 2.1467877203418366, 3.4347967611205195, 36.33386804211524, 61.16636614645682, 59.66874637911397, 60.213826394850216, 59.44354349567045, 58.95251766327889, 52.92074388073337, 53.17555673660771, 56.824894643598995, 74.48319727374663, 69.90047254870015, 53.625833065279075, 75.42094184506324, 52.7015265341728, 51.822197821832475, 47.5825196696866, 50.84447253134943, 46.61241554444837, 48.247067236131244, 54.08677431844897, 55.48437756876792, 54.50755442342451, 50.31969078125493, 52.427800009327555, 50.36166014209871, 41.08665104835264, 32.78558215787334, 31.642579955439416, 35.54244749007687, 52.4852038967994, 52.901743919618674, 50.28927280056862, 78.99456624061831, 58.63509985708422, 47.50386045825097, 45.37589226999591, 52.46387012543217, 50.38677115594187, 52.34084106260731, 62.59298316894039, 59.45694623454925, 57.74458454501245, 57.875866274679865, 55.57394881402293, 54.58292668865573, 50.7861743434783, 53.39469955813501, 57.191369533538825, 49.71890134196128, 51.121391865514944, 48.054631833107244, 50.072593227509536, 46.45272408762286, 46.26273624358639, 42.632578726737734, 44.65001060116676, 44.0907786738488, 41.328288662818174, 43.1167600231786, 40.49268653315883, 40.925410255309075, 43.65158304091423, 44.05286896613337, 44.63651372540382, 45.77401284248599, 51.38898772578086, 51.919715789056596, 46.55311715218329, 47.10053097817206, 45.86502359759423, 52.62946474936701, 49.662619252358716, 50.811148074365434, 46.404102386966834, 47.66057875848586, 43.56480452322191, 46.62629681248819, 45.62487256142401, 52.050573902745406, 49.54396363227598, 48.37265760667863, 39.88633909533101, 47.11996240000571, 41.70908412625713, 11.923036498408164, 22.04165327933527, 49.121751862187544, 62.431738453526656, 54.53381076935799, 54.661025001156716, 51.79492165965419, 55.72344603077058, 54.44936213954803, 58.56789788892193, 53.84092015604819, 47.12732468881915, 53.07299067897182, 44.39229126899473, 32.46927438243743, 54.98231418671147, 60.471910507448264, 63.477752208709724, 58.46258224979524, 51.368112871723795, 45.824332929426625, 46.9015726735515, 48.56557153886365, 50.969121533055464, 53.48662422549341, 58.66849883910149, 59.61666514796596, 62.83691536995673, 58.52251606602823, 74.24298347965365, 22.849696836163922, 0.1538361548896759, 0.10648979144471307, 0.19668290091137733, 1.3100333944443734, 35.33243986868089, 60.57365678971814, 62.07503026531589, 62.721017176105136, 67.18263872208135, 40.81264995759533, 5.387384257008953, 14.651484258713262, 22.805623123722693, 28.28401715524735, 35.46961692071731, 50.90413178167036, 29.95557442788155, 50.443382724638916, 48.08883490100984, 45.507311282619355, 1.2183358568337657, 0.1819528687384821, 0.5072482957714989, 0.1304438899481489, 0.0971863124399416, 0.059629323096164775, 0.01962624373845756, 0.14720252294453884, 0.0904698970337068, 0.12000832451327194, 0.07342138402764836, 0.026533822979657885, 0.18281264921590207, 0.1445459904930284, 0.1522729371584231, 0.06435274161518582, 0.189302149378965, 0.3758114486211731, 19.8839182238425, 76.98482221172702, 50.723145777179354, 42.03709233191706, 35.519007405927105, 52.724837180106874, 32.60619059685738, 51.16545184966057, 24.152255173652406, 7.814836194438319, 18.185131857472083, 76.78133749192762, 60.855659515626975, 66.82651104465609, 49.67744973398025, 63.96831520142094, 6.7620494865602065, 0.10381022272931953, 0.03452129316546264, 0.027931514008331205, 0.1447664093106024, 3.2509859146610385, 13.805834977857529, 49.68465512798679, 63.733314237286976, 62.665092022188254, 62.95473944756293, 61.05613969987439, 59.76933556218302, 55.85512784219558, 53.661989473527484, 59.053020554204146, 70.81036829179334, 65.23995545602614, 53.71165452464935, 73.06182446018343, 50.18906016503611, 50.80490366105111, 47.82141554740168, 49.97390247160389, 46.32336824171005, 51.292340524734996, 58.99997834236392, 58.97218050495271, 56.993713455815474, 53.55938419218987, 57.3675427898284, 52.47104021810716, 40.53993540425455, 38.049089139507664, 36.20614390219412, 45.22892890437957, 53.48935811750351, 51.69470510175152, 48.13306746944305, 69.18900951262444, 61.529844345585, 46.67552648052093, 49.02516349669426, 50.57076561835505, 52.89054555277671, 54.90654576209284, 60.74957116957634, 59.524685567425145, 60.93027868578511, 58.02150780154813, 50.40139767431444, 50.91917014891102, 47.98347611581126, 47.00108712719333, 55.737876430634536, 53.61385806914299, 51.07880669255411, 48.434725192285356, 50.7754623505377, 46.26825894078901, 43.539132610444106, 43.81128234248008, 44.73307855667607, 46.40938974195912, 42.13061732630576, 45.51914115105906, 45.00596177193427, 41.19362192769205, 40.97212960643154, 45.222684491065245, 46.27492697008195, 47.297198618611986, 46.344537273530044, 48.90772773373512, 46.76907500913067, 48.67704922153104, 49.849633939804576, 51.28533909397741, 43.7818802556684, 50.12317219088155, 47.227086251781834, 50.885543669423754, 47.6892355949648, 49.259187790655325, 48.57689542155112, 54.61849081900812, 49.13916326338246, 47.62496363732123, 41.8724783005253, 44.84116731151458, 44.63626661608296, 18.632117317568873, 22.827551134171028, 51.27875343445809, 62.74539470672608, 56.88400476209579, 55.23091400823286, 58.505128199054354, 59.32273841673329, 61.42686251671084, 60.85724023080642, 58.14356411657026, 53.43944595706079, 54.13450956344605, 44.8683964052508, 43.00776520083028, 63.599765377659956, 59.113119109984375, 67.46220957848334, 61.59487332067182, 53.44062266811248, 47.64224167793028, 48.421459736362586, 51.167601308514996, 57.510117023221916, 54.6060686726724, 61.4963786832748, 62.8606378647589, 66.51611820344003, 63.98289857372161, 78.94691728776502, 23.050545723207538, 0.32202778624430783, 0.05824923102233199, 0.38800977470894016, 3.1916240290288007, 44.69678486547163, 66.59767212406283, 71.08408697189824, 67.18995786482289, 81.52184347952567, 40.65676712220715, 9.333443583980683, 21.117954715605705, 29.046922076132994, 31.660248271880615, 36.30920810084189, 61.34714034295852, 27.006244274877734, 56.443855993209354, 56.54672015097834, 59.85705152634652, 2.184335344260739, 0.02187175086639341, 0.30089010274217975, 0.0607702961461919, 0.06768884768168773, 0.13063326688303104, 0.08174253146975272, 0.3034247506049372, 0.2421226400521494, 0.1661058803719859, 0.17406337353731358, 0.10510371622419167, 0.4869507962176877, 0.3718792418799093, 0.21334276985256903, 0.2554247302994613, 0.36583214217135984, 0.8504851955559947, 28.925501185078776, 87.37980135025518, 58.50230017016011, 61.05030321305799, 31.562832286280972, 67.26967611620503, 38.25898301216864, 52.42226554501442, 34.42315993770477, 12.44692002573321, 28.96887867681442, 81.37171868355044, 68.28843332106068, 72.98959009109005, 56.13875442935575, 66.32086261626213, 6.543063069543531, 0.33326295595015254, 0.1624208289168535, 0.19830423407256606, 0.2688793946177729, 6.19377943777269, 23.150368082907892, 55.68419095008604, 73.01896864368071, 68.23031948458764, 66.4957061890633, 64.37067977843746, 64.6165378632084, 57.25984234963694, 59.302024379853286, 62.201934629871005, 75.3791529132474, 69.98596452897596, 72.32965915433823, 69.57974033970987, 46.456960247408965, 51.42504999714514, 46.08300539755052, 52.33777769150273, 47.4926777808897, 53.13879628335276, 63.822744277215776, 66.25938338618126, 61.61137473198676, 58.34455813131025, 61.62882143451322, 58.553993086661066, 52.197388218295195, 45.99770561341317, 46.950672903368556, 54.200146505909586, 59.22002723140102, 53.849235580813506, 52.71008122351862, 72.2388013716667, 67.85578020157354, 53.47115439753379, 52.918127659828436, 57.150133655917266, 57.37351263723066, 59.350983404344134, 66.69180116345807, 63.64163667924943, 66.05206258835332, 64.40381203928303, 53.88899664725027, 52.649472759615996, 54.59041449331469, 51.452051593411355, 60.76347204946703, 54.28626998778313, 54.48321219413511, 49.5256422412011, 55.76761191891086, 50.6853380510884, 49.95055260196809, 47.974489965746486, 48.92404871602213, 49.86531165338332, 46.923969407235425, 50.413168707201564, 49.08150834421958, 45.752749673781864, 46.38417674649147, 50.65328836441041, 47.48795524720223, 51.80573171184909, 50.4222176151891, 55.739229648343986, 51.620913551699736, 55.402549082233065, 55.99417194243401, 52.463011126364435, 47.19632310252036, 50.2800513082935, 49.6427720592868, 55.67373783357682, 51.16527142063264, 50.8592402550482, 52.9632309944399, 58.345389673786784, 52.055033637631325, 52.218035574882265, 44.4446902121267, 48.05185871739542, 51.97761389517015, 31.570437762045096, 31.152185624645604, 54.7516199850267, 62.71464332457512, 58.96142144357005, 58.34864524102981, 60.00662719049762, 61.351604000214614, 61.75664755605883, 62.29573419017177, 63.370640124044115, 57.47255248408164, 54.22148419964699, 48.97430604504001, 40.97957818738876, 56.72950652337844, 65.46613893201275, 69.36143690539946, 64.19452221162858, 55.34168958663941, 50.64625555469144, 50.28206740656207, 54.73553826732021, 57.284741555490804, 56.81718718621039, 66.28869918084914, 67.35654877078149, 68.01748383429744, 66.90533499563894, 75.1565113375264, 30.808844873982093, 0.6797159847713287, 0.2848333288584986, 0.6452843775191616, 2.8331671991655907, 49.31404998225551, 75.84842528066328, 73.33078138289913, 74.10503372069329, 78.85937783025926, 53.91858308546005, 13.712151127476847, 22.63360954100086, 30.65952024152202, 40.18432155732186, 48.36431472532211, 68.05631529900336, 43.15300664594097, 72.05437937090474, 63.771114118637584, 78.008662808326, 5.552175285354738, 0.38494125549351016, 0.7022942506497907, 0.191713732877566, 0.18193756230175498, 0.2974424006477479, 0.17421478315466837], [0.0743153779917667, 0.09917239538363873, 0.06050135714993362, 0.02065988403985337, 0.05454665147549203, 0.11259104590862991, 0.08415494234331193, 0.3529747046770588, 0.125952301126334, 0.08224474040851479, 0.31812548757560793, 10.255881105699848, 65.57854229404082, 50.96427348352248, 39.30564395843014, 23.056484191648423, 45.938662175209295, 41.15360590719408, 18.511549542027137, 28.867728594810735, 10.457291872270646, 3.150989744932421, 54.823046345864576, 60.74349149580925, 57.8754779600328, 56.65270651540449, 49.25992519624772, 16.49411374522794, 0.29494277832488863, 0.019222739483079603, 0.11093641090537272, 0.08696360453482598, 0.9645167089277699, 12.353751967030188, 40.09949245760518, 60.14744812442411, 62.042478515255844, 61.30384129862632, 62.947294788975874, 63.10053786923809, 55.39990148236675, 52.02865177585233, 54.88940892680999, 53.96317258957894, 62.40184607044343, 45.9328806015753, 34.166848736424605, 84.98317826178767, 51.540014666895715, 44.766940378373675, 47.83828958388298, 48.26320386702015, 49.16982835338962, 51.19673667415496, 48.329895927060036, 45.15959708921371, 46.69640917931834, 43.17391680132958, 30.40912397446171, 32.56051067383059, 36.548064754855254, 48.576263919953384, 69.6855031290362, 76.74782476117535, 67.19384101129347, 55.81995594886042, 53.36545044376005, 52.87451090351228, 51.45564056211903, 51.323825390108176, 55.32222678584438, 53.26649688905286, 60.47610352116247, 60.142176458912516, 47.40114535054853, 44.44528249002273, 44.337319251029726, 52.889317850912775, 56.90360876821703, 53.83007088015157, 53.673113315336174, 57.39193208755986, 54.60760624177995, 55.88930345350697, 55.89231191142913, 56.61667954537177, 56.164579314570275, 43.16682907842821, 43.81582444713962, 36.43185669376005, 37.83205655313308, 40.91719681216825, 44.53378292822069, 40.392952426787346, 43.0473772172005, 50.52790195711198, 50.68790328118109, 47.13038805992373, 48.5631553588375, 48.648855224732436, 51.591413405633745, 37.50823351644701, 36.905176947193766, 29.379699883922456, 38.95704330936555, 55.33217783897154, 54.008781909942634, 45.887157532476614, 47.23293842807893, 42.45165155779931, 44.57026881556357, 46.43017830387239, 49.51174528368058, 51.86758356709635, 54.47455552316482, 50.37673773304109, 39.947677120085686, 63.71079983249788, 36.011578652166556, 22.87750840187073, 35.837990237820534, 53.818056660313765, 63.38410954321585, 56.4780237597804, 55.31145203498102, 57.89154791062879, 52.107699301935014, 47.72608234036354, 40.65781047267299, 54.75145916784964, 44.45582189867574, 52.47058130079701, 32.46184149096089, 42.89197291097334, 67.83055151662519, 61.404697202867084, 57.84023154166437, 53.6279825241335, 50.06537998876264, 47.068547971787, 45.93675198093538, 49.01163131959977, 51.41196497025029, 59.51750370763964, 59.5001236854061, 63.17681620197912, 64.17408666303082, 67.64455272305396, 7.172062685412746, 0.2099390258832324, 0.08208219187274095, 0.2777545232205622, 5.334773015591407, 49.153287718372965, 55.038733559270064, 64.05503880593085, 60.34666138310587, 70.19709787061139, 13.55215568696299, 9.291433038250092, 31.55902170365857, 20.314417962105047, 57.73419418642598, 53.22506489292268, 40.49860538974885, 39.98339814524497, 65.28268183431318, 48.072725726712136, 47.03199148178101, 0.4817936761725334, 0.2887171188429479, 0.3527442347859183, 0.20860255485580814, 0.06846142437068686, 0.04463033277481314, 0.09117706513573086, 0.07543847821052037, 0.048304436833507595, 0.016260593491155776, 0.1260314303480329, 0.08390298368589533, 0.07942383613197074, 0.09246767047912845, 0.28957381964691226, 0.0941268637055351, 0.16709110008612757, 0.7246488188543628, 12.071746299343726, 75.61704466419836, 56.527241660702614, 38.07879324882261, 18.942235592872866, 57.62902759736585, 25.334973335266117, 9.89093005657196, 29.498837955536384, 15.024208464930135, 4.481455991345068, 57.03214091639365, 70.35169416858305, 65.19777820956323, 62.04166266226, 54.174011753451445, 19.44861554330395, 0.4110802367569939, 0.03523268241194948, 0.20575676804348347, 0.13144741916368086, 1.1844998982644852, 21.529130897214337, 48.08488115187615, 63.01264147604666, 66.12026476090955, 62.601443721402084, 64.3436977940221, 63.93558694470314, 56.88976672387893, 52.30304902599704, 57.64353252226307, 56.15528721963206, 69.10066204686319, 54.10857877423687, 41.3096534821295, 77.9763424781061, 48.77323358289657, 46.074619370122115, 46.31092648352347, 48.40745687484742, 51.66975490508541, 53.01703022372339, 50.34930075368574, 50.43554582903462, 51.120372049270145, 45.759955067788404, 38.19259297463202, 40.41001865940709, 44.54692286829795, 56.1190955100521, 71.10689947682043, 69.4012568073888, 64.9342380800555, 61.706311779637495, 57.09163150479717, 56.35451616779451, 56.50918699079945, 52.80551641218124, 52.47569999387188, 53.05759537604548, 57.94344871274887, 59.18577317268618, 57.84391072488601, 54.05242220047982, 50.17973276876634, 53.41299349261869, 54.82849451803393, 50.66614197146509, 51.49051435532109, 56.29446468045635, 55.62375899284117, 55.00562091027537, 56.034662569722826, 55.050320240759085, 50.17021709872831, 47.67497385701826, 46.27460925809799, 44.23814996596306, 44.52304347868889, 44.76395937704271, 46.04533887678578, 46.53446628201393, 42.7557921409607, 44.279593729203754, 48.725239461468114, 48.82855861417709, 46.440968744216434, 45.63604347167477, 50.320710597499726, 47.086367299479825, 47.528214454650886, 44.45823415633171, 49.57414627075196, 52.71689045813776, 50.16388247090001, 45.74830562837663, 47.15072947163736, 46.982036175266394, 46.268521739590554, 49.655276575396144, 53.15564678561304, 55.648866084314164, 54.04296144362419, 52.13382228728264, 40.5235359745641, 58.739995802602465, 48.9919331765944, 26.268515086943104, 41.675081099233324, 54.30203399350567, 62.28646170708441, 59.74467954327984, 60.1092795402773, 60.16294148660476, 56.63122369397072, 50.15018947662846, 47.635189256360455, 55.67849959096601, 46.795664756528794, 52.09989378529211, 42.38392399203393, 51.65387715062788, 64.89640289737333, 61.01817900134672, 61.34477907611478, 57.07761687617148, 51.84186850824664, 48.7973012462739, 49.460699558258064, 53.84399529426329, 53.71345489255844, 61.904171820609804, 63.036309057666415, 64.66421819502308, 66.85750561375772, 72.32435610986525, 7.893547867575, 0.5807986507011998, 0.24774790110607303, 0.2561085557024325, 9.72969122471348, 55.399430797946074, 61.63810960708126, 69.15834442261728, 72.73829952363046, 75.66598799920853, 12.75918677929909, 16.18498488779991, 32.99415811415642, 24.325904384736095, 56.55485906908589, 58.53134139891594, 53.272980566947695, 40.36393473225255, 62.031138943087676, 56.53343116083453, 57.112227870572, 0.9574518460900554, 0.2523462825845326, 0.16184145194147864, 0.03739668544562113, 0.09590755847673263, 0.12756752090588694, 0.1881953668329985, 0.12798748264509824, 0.26048809650444216, 0.14682361585718973, 0.18999965711226388, 0.1353006728834683, 0.511314230820825, 0.32962137232384375, 0.5771168321371078, 0.20140802397602992, 0.24919081238969681, 0.9606211211892867, 16.8652033036755, 91.21583231033819, 64.76355614200716, 59.7568977263666, 30.226674925896432, 67.8151209123673, 57.20339159811697, 27.749625598230672, 34.39411478657877, 19.241230026368175, 9.298610975665431, 69.31275244682067, 72.42057969493251, 71.92874585428547, 66.15162018806704, 64.97455220068655, 22.566182036553663, 0.29195037760561515, 0.19574755352110634, 0.42735185233816025, 0.4978220435159822, 2.39158455883303, 32.71153369257527, 58.58344224191482, 67.37017508476012, 74.01085761285597, 68.23615597140405, 69.25538386068037, 64.3892639683139, 60.60325499503844, 54.779190324967914, 62.12766062828803, 57.96140140102756, 69.5242388017716, 54.434586571108916, 54.16872832082934, 69.97810409915063, 44.87416621177427, 46.284760352103945, 46.792628842015425, 50.76622909115207, 52.13588937636345, 52.82132748634585, 49.42624545866444, 48.66735312246507, 52.77495722616873, 51.28497039118121, 47.81226858015984, 45.73664442185433, 46.2418927684907, 50.81033222136959, 65.16347316003615, 70.87638178179341, 66.26053656301191, 64.9453148534221, 61.33147047412012, 58.65046378104918, 58.923323462086344, 57.1711693271514, 58.903229159693566, 56.625665695436545, 64.04629976518693, 66.76156443934288, 64.51913364471929, 59.981939792633064, 60.09968542283582, 59.14810665192143, 57.367997784768384, 55.582813370612364, 54.98209453398182, 60.625981207816835, 59.51820581190048, 60.628605273462114, 60.08463528848464, 63.765764005722545, 59.92992524177798, 52.26710834810811, 51.331156299960234, 46.701347443365286, 48.64351687892791, 51.55126402454992, 51.67357529363325, 52.72874778316867, 47.369887982645345, 53.27222747187461, 53.390428097017356, 52.62831157253635, 49.25851706535586, 52.029914779047814, 58.57402070876091, 55.71333416046635, 58.80247131470711, 52.03509230767527, 57.44858680232879, 57.90761001648442, 54.43500626471735, 50.84004809779506, 52.300115093108154, 53.57522272294568, 50.87638885744157, 53.73673415953114, 56.948806239712624, 58.04949783509778, 56.990022505483324, 56.439007943676366, 42.32453146288472, 58.78593460206063, 55.52640968753446, 41.990439661087535, 43.53902278407928, 61.437966746668664, 65.6125178644734, 59.75018655100177, 58.756559971840154, 61.626777879653446, 59.94528916574294, 58.04239050034554, 46.740873167591715, 56.672945945493645, 47.720869510404526, 52.828293615771884, 36.12811619235624, 46.225285453181115, 69.785813823823, 64.33248373769945, 62.230834653300626, 59.5527736602291, 53.57397933160105, 52.26460587593817, 53.98333749463482, 55.19493802901238, 54.58482119344897, 65.86121574524911, 65.41321831364786, 70.59087245695054, 69.7607655679026, 72.54740561208418, 12.742381384295802, 0.8553403543849146, 0.42170792938240115, 0.4489034071805016, 9.47741614234063, 63.73689928362447, 68.40641821584394, 76.24888358577606, 70.96365451812744, 81.85925360648864, 24.02047138060293, 17.93108778615152, 40.508481917842744, 29.41909028637794, 76.9450964466218, 73.5238875112226, 56.41213578562583, 56.360419334903845, 84.52020522086852, 64.92806426940426, 77.31452880367156, 2.101610105845236, 0.7513524988485921, 0.46658588092653985, 0.5461395459790384, 0.3043355985033897, 0.24689054146649378, 0.24845573570459123], [0.22786203591573626, 0.028666479610687787, 0.12186437935358095, 0.13848232796355603, 0.05595773946674121, 0.06323026958853006, 0.10923999346672528, 0.07813786562051504, 0.06651726175820635, 0.05207593748045545, 0.25451199782471506, 3.678213170459194, 67.34799800380584, 48.06578313150714, 45.68449258804322, 42.30427634331488, 41.83581590652466, 52.80871314387168, 117.09373228011594, 24.259981109249978, 10.197271089400015, 15.91766163226097, 39.513423673568234, 66.06433176225232, 60.749441731360655, 57.240042225007095, 65.43822342349638, 42.38464963051581, 1.2241233140230179, 0.0666145779072277, 0.18466535625198197, 0.4443167162037665, 0.752593009702621, 17.404603727402225, 43.71518035088816, 60.95689196740428, 54.57616452247866, 66.81628934798702, 61.26730834284137, 63.05247314514653, 52.39267518443447, 52.98241138458253, 50.42155865700015, 59.4844969626396, 61.56778543226181, 70.89260470482611, 39.701222835048554, 55.49287342256116, 97.3381265517204, 48.88888074505714, 46.77015758329823, 47.662500719870295, 49.89148562954318, 47.569779811366914, 37.82077189414732, 33.41340849476476, 29.832919951408144, 33.41629535921159, 49.36230298011534, 62.749368067710634, 70.89741353065737, 74.4763723496468, 70.02194835293677, 63.3535699690542, 56.161884646261896, 56.566175107033025, 60.280898924796816, 53.4286476719764, 55.212110165626775, 54.56264019012452, 53.68879102891492, 64.10752011883643, 58.767095458122995, 48.82256915492397, 35.50755408502395, 31.881375812715103, 33.33385498292985, 44.9170651743489, 53.385987973982296, 57.01081498976677, 52.58498507161295, 57.15742141969743, 60.04417996252737, 59.39991497224378, 57.200516500780665, 53.491566411910526, 52.90096729032455, 39.561468785808934, 35.18523723848405, 28.434695005416874, 27.313691416094382, 24.40090794717112, 32.65385327800628, 45.12816713702294, 51.53454688287551, 50.65847373777821, 51.70928847405219, 53.46330965718916, 55.64506138524702, 51.0385553298458, 41.25499917614845, 24.49252666965608, 19.415540156825898, 14.628135369670007, 24.575596586350475, 44.650598956692605, 61.50881651909121, 53.94984045336324, 49.580288702441806, 47.25784547867314, 45.277554527405776, 48.09731898769256, 49.2005052105073, 51.99089111820344, 53.00185065115652, 58.84012606836135, 51.14190978388633, 62.55426545296947, 85.99250608874907, 46.52469565791469, 39.201155939409816, 34.9824938466472, 46.169964344270774, 53.64916332306401, 47.985347086383456, 48.700473616200114, 46.77963402963454, 47.15326724513885, 48.17912001763621, 49.46593200006793, 47.22039468826787, 50.41445916698825, 40.805640682097405, 36.52988849147674, 66.36214163995558, 61.135242139139486, 63.49354367102347, 51.6169519578257, 50.848300764637614, 49.32546407945695, 46.51307759746429, 50.01396556054392, 51.95729209530739, 62.87948485343688, 61.15856847455425, 63.582095100033676, 60.44150037150229, 50.286378091381444, 1.698243976120026, 0.4380430689742489, 0.0640665962841482, 0.583612522290599, 7.719042108904931, 50.206577470225675, 56.55932272634199, 60.32406853091333, 44.64972426814418, 42.381770610809326, 3.3635500938661638, 32.446357934705674, 20.575224199602683, 32.85229775213426, 37.20171205459103, 38.723454398493615, 36.060035613275346, 32.03889819883531, 53.39880627970542, 51.199854958441954, 39.34539325775639, 0.2545734533980008, 0.3759153607872225, 0.12184158057695436, 0.17043390942196693, 0.23320070347718655, 0.07355505104867682, 0.22544023280422534, 0.16251792290037678, 0.09995177493340547, 0.1403550605379766, 0.07909737542391786, 0.07937261549335334, 0.13588821635611598, 0.03031022467410132, 0.04688088459173038, 0.07717976541889292, 0.10143384863171848, 0.3459771043590961, 4.099333541047189, 78.49841779278171, 54.81323257569344, 45.94902507720455, 37.017266519608036, 48.431571606666814, 46.75230687664401, 110.39314731474846, 29.374167380794404, 10.90143753636268, 22.58837284580354, 48.28907974304692, 67.70655755073794, 68.70793865573022, 60.127004731086, 68.86277814065257, 43.895044557509884, 1.8004071327947804, 0.12554773009352146, 0.438783937284062, 0.5261815459497514, 0.7107159471319568, 30.391459580390688, 54.18536309273013, 58.64946749902541, 57.51134472508585, 65.69914733209919, 65.04952046179002, 65.51552549485238, 57.224462570682654, 53.30175899690198, 55.74849428669099, 61.4527540822183, 62.662832736969, 70.42640747562533, 44.15450149966825, 53.634019051828695, 85.08743486096783, 47.508841868369814, 50.40910120933287, 46.245222860767, 50.6803644857099, 48.8802436859377, 44.02814626693726, 41.57908108926589, 36.67830313405683, 41.38044441899946, 62.957277221064416, 67.00136246219759, 68.50095518173711, 69.76978701929893, 66.12202982748708, 63.869240053238414, 56.57518871368901, 61.71922814461493, 61.13401835964572, 56.87796038966025, 54.9117938933834, 53.492868638807735, 54.65695358091786, 61.70924571252639, 63.3497299686555, 60.257686338117054, 51.94643497467042, 45.439171867985884, 49.579861164093025, 50.709378257874526, 54.45426117989325, 53.96954644110895, 54.93228827753375, 55.49639963334607, 56.318151873926965, 57.47130124799667, 63.48781701057189, 58.17069515105217, 59.79507807762393, 47.30776548385621, 46.1113170654543, 40.86673159753123, 33.58687139326526, 34.9128992326798, 41.24428326083768, 44.32106494903565, 48.511117273761386, 53.39609199954618, 51.01735491906443, 54.15082270099271, 51.46874912323491, 48.77073503309681, 50.075860561863074, 39.51355311178392, 35.08668376553443, 28.19491267204285, 42.8743810807505, 56.695389747619636, 60.80686130831319, 52.08863658289756, 50.05413847584879, 48.42510361825266, 46.941157233330514, 52.34981544556157, 52.56363168839486, 55.81892828787527, 54.224826059033795, 58.60226177400159, 53.3238301738616, 58.146517661310014, 78.58128178504207, 54.22900338326731, 43.31276086068923, 43.49765746824203, 50.969992299233716, 53.92712600769536, 50.628851998236875, 52.16207511963383, 53.93408821475122, 53.29380050782235, 49.752904368985085, 49.65773197912401, 48.01598471979941, 51.55638663999496, 48.32144714170887, 43.501481779160045, 65.35217838902628, 61.09166068415488, 63.850055740725615, 54.261139362089104, 51.775435324638124, 54.7926950454712, 49.308593965345814, 51.837118517967966, 56.353519885770744, 66.09584408421671, 61.88173978559433, 65.15016063567131, 60.015276016727576, 57.55971539405085, 2.9747240677956612, 0.5234216682372556, 0.1295607131455214, 0.6392509141756643, 11.223094444121084, 58.79411274386991, 62.63692155961068, 68.10526647875386, 48.59079237907164, 44.81182798262566, 6.323751586098825, 33.5588695926051, 23.607149662510043, 36.36733762679562, 36.601981655243904, 45.054563860739435, 45.73740536166776, 31.502753342351607, 58.025496852013376, 62.20499407860541, 44.81149065879084, 0.3754358203901399, 0.21234622735890651, 0.1653634798863242, 0.17075278585956943, 0.11233762402327792, 0.1129525704609771, 0.1440996676683426, 0.388646638922153, 0.16559658511992426, 0.2379330737336028, 0.3287543446546601, 0.18623448818201022, 0.14288299747051733, 0.1609143783007899, 0.23275010588188327, 0.18472950845476122, 0.2517014510569073, 0.47771624980434296, 6.718458715946444, 94.24998175713324, 58.93185461721113, 66.29801088763823, 60.197175933468735, 61.592892523734804, 66.57827208119055, 127.98769966248544, 28.962383231809063, 17.45823625595339, 23.744854273334628, 54.36294840228174, 75.99906782950126, 74.97300717138475, 69.41005860605549, 77.19831682020619, 49.35908271420387, 1.5469488429446376, 0.364765134910422, 0.9051233830471194, 1.1571707840888732, 0.9884604499224694, 40.2332531252215, 57.73840288962088, 62.93396265276017, 60.8438531814083, 69.4750601245511, 68.10844359859344, 67.2826748509561, 57.97048561034664, 56.170231449988584, 58.61852784310618, 64.45143745791528, 67.08084537136939, 72.23179601853894, 42.87839366543678, 66.52756367960285, 75.33577149914157, 46.3711937012211, 53.27227454031668, 46.16518689740089, 50.51644079146847, 48.687670999957675, 47.29307228519071, 45.05869019416071, 45.56976718287314, 51.66165913304975, 60.98063015168714, 56.841101877151004, 58.376513681104115, 64.12138961976575, 65.92226351461103, 68.92564588977446, 64.1474380800801, 65.37125287517425, 67.48376692495039, 59.97986878118208, 59.638995201356956, 57.028889271520804, 57.464017406586684, 68.73791340858706, 67.06989411384829, 65.55593375236758, 60.456107278024, 52.957743598568825, 56.29459411867204, 57.61690747353339, 60.037296202874955, 59.0211905202558, 57.82187484925794, 57.47707105452015, 61.72897915686331, 65.22897674191383, 66.15824114891791, 65.06801835952267, 66.9985697346349, 50.90831302827405, 52.008961477587306, 45.33880233764649, 38.64341451275734, 39.7118995266576, 47.40303985534176, 56.916230955431544, 59.822448376686346, 57.28891495735415, 54.104126884091286, 60.07029118076448, 57.21696692128336, 56.83459466503513, 60.162768902317175, 47.61508710922734, 46.872496143464126, 35.40862014216762, 49.12502704128143, 60.83720084159606, 62.14457388847106, 57.68047340454594, 58.39966743223129, 54.72417908330118, 52.99404513451361, 58.36558203543387, 56.478565046864176, 59.742879175370746, 59.64649477312642, 63.331381120989406, 59.0114434303776, 56.06530804787913, 74.45152805697533, 67.9958401956866, 45.78234003436181, 44.17421533215431, 56.431841773371545, 59.8076061279543, 56.209506142523985, 57.43145781178629, 54.473080711980025, 53.24042881688764, 51.741687251675515, 51.46690953162409, 47.41410878396804, 56.06183282790646, 38.04088354110718, 40.471666551405384, 71.22118949890137, 62.54578136628675, 67.59904538431476, 55.38429829382128, 56.51272889106505, 58.079786377568404, 52.35109806060792, 54.7432888707807, 59.33925943989908, 70.21646653452228, 66.53387869558027, 68.88480617154029, 64.4843069199593, 57.97042285242389, 7.560259661366863, 0.6179837618143328, 0.26137458280690257, 0.817517000100305, 15.374463373614898, 67.08690151091545, 66.46841433740431, 71.69968728096255, 52.664683711144235, 53.945831791047134, 10.020676178316917, 42.11184094029088, 27.175316079970333, 47.4117906631962, 54.19580444212883, 53.113736260321836, 49.45286658502395, 44.567699663100704, 71.56180812466529, 69.39052520259735, 65.08424520492554, 0.4655443690717221, 0.3321180835125908, 0.22901866014205643, 0.49689507712760284, 0.22239157058779271, 0.33123316002949593, 0.40514792766301866], [0.11733293097706572, 0.03805855859912211, 0.19473011214886943, 0.1482768540060328, 0.26710755582298, 0.07230326338040252, 0.24643615939684455, 0.07169573267381038, 0.039254904484316226, 0.1746953501095695, 0.05727818776522914, 0.6223472760569665, 52.99021690122543, 54.295389498433764, 32.4779781218498, 22.04372429078625, 43.98523553725212, 26.52715225373545, 17.547177960795743, 38.23400143654116, 8.27521360689594, 22.963937828617713, 69.39451033069243, 63.98109036107218, 66.94440180255522, 60.77854571803924, 59.38642201885101, 44.798017317248934, 4.427926425010928, 0.31620291332083367, 0.28816596454670357, 0.09668729042694454, 0.1561900213240616, 23.331779664562596, 56.00794730647918, 53.543286785002685, 64.59308208957796, 63.98546772618448, 66.34133738856163, 58.9106777406508, 53.51060167435677, 46.76367390540339, 53.151908766838815, 51.81962082462927, 62.65556066266952, 63.08041218788394, 70.91568393092003, 37.98670384191698, 49.04178650148454, 69.93585232765444, 48.473219333156464, 54.250745081132465, 52.206554797387895, 45.82714919121035, 45.49190813495267, 55.22630522328039, 65.03878101225823, 73.08651970278832, 74.50159318985479, 67.17736705656975, 65.08135441810855, 57.34750732298821, 57.12689753501647, 57.171063423156745, 61.9263881252658, 59.165996582277366, 52.453797478829664, 53.00732627991707, 53.837350799191384, 59.26495405935473, 57.389747327373875, 65.22747055176767, 53.021603707344305, 36.628614548713934, 28.831619255004394, 27.355837283595918, 30.146560515126875, 40.441107365392874, 50.24130221336119, 57.457243473299094, 51.49673915678456, 56.871374730140936, 58.03225901819045, 55.199825302247085, 48.04167232205791, 45.996834847234915, 37.82339203742243, 33.93693116403396, 25.929012375493205, 19.480053340235067, 19.546019761793076, 10.36859433497152, 11.89543576009812, 35.806540673778905, 45.915641784667976, 50.12742796251851, 58.1449761698323, 57.81755631969821, 57.17347960318289, 48.557883693325905, 30.631134048584972, 15.513381958007814, 13.453308036250453, 13.25286707570476, 13.916221261024477, 30.883968068707375, 56.534564725814334, 58.07922155626359, 53.536536385936124, 50.59843009518039, 49.92194283393122, 45.668759961282056, 49.54211619592483, 51.83047402289606, 52.8570955799472, 52.35394177898284, 55.58053839591242, 51.63553222533196, 91.13994229224421, 91.31149891884097, 45.28914905363514, 44.297354221344, 39.448112287829005, 43.97879108305901, 42.75632558330413, 52.45641762210477, 50.9096230999116, 53.05715607058618, 46.23809199179373, 57.686670749418205, 39.104657788430494, 73.23889593924247, 56.71859056718888, 38.53656914926345, 72.53119837853217, 56.73853581951511, 62.165170254245886, 48.932293538124334, 48.92438603985695, 49.058782131441184, 51.16536163514661, 47.19924919066891, 54.8318991353435, 59.560175172744266, 61.437907911116085, 60.03835524282148, 58.18755742042296, 43.58796219671927, 0.362548413536241, 0.6490610071247624, 0.26670401134798605, 0.2261568314485973, 17.365627134999922, 60.38439850653372, 56.65611113271406, 58.64008126720306, 41.82138550666071, 51.99364462206441, 4.357178634212864, 26.743031663279382, 21.243513707191717, 33.01348755436559, 49.00366106340962, 52.36929785820746, 27.59911640997856, 51.86804248440651, 54.596345117015225, 63.03953324594806, 25.39767634484076, 0.6748106318616098, 0.12364089128471191, 0.10951773098279392, 0.09787187686250096, 0.15666456682787788, 0.13029880821704865, 0.05866678724546106, 0.04562027159056837, 0.05800035586881061, 0.10424416557314897, 0.1061134890563065, 0.1129873968180149, 0.03656811539023634, 0.07509525549868423, 0.02296927715501478, 0.08814209291050512, 0.17528983433881115, 0.06779810714144861, 1.0724760255505963, 59.12781623102004, 63.88294089225031, 31.40083839816432, 25.030079657031646, 56.68369716213596, 30.977187118222638, 29.049836397171024, 37.14806187537409, 15.925479896606939, 19.41221987047503, 75.5570088663409, 69.4627752611714, 71.64133025753883, 66.23460969617291, 63.64662985647879, 49.474623972369784, 4.4829156033454405, 0.26466309183066894, 0.4228254371593076, 0.13610734814597716, 0.13178386965826636, 27.93694034699471, 63.035489282300404, 55.86358839465726, 66.41054368788197, 67.5050889292071, 69.01153010706749, 61.81711873700542, 58.74765226917883, 49.79809399574034, 54.16410384639617, 53.89442520756876, 64.05776485320061, 65.82223523047664, 69.96592906213576, 42.41773874528947, 50.370399182842625, 65.02465655726772, 48.972937137849875, 54.563820823546386, 55.43010373269358, 51.690982772457986, 52.02974219476023, 56.64841936480615, 66.63148295494818, 67.46052295930924, 70.5991094343124, 61.5417173600966, 61.80177442489132, 55.75848456351988, 56.14177073201826, 59.7553680019994, 61.27735353285267, 58.733649407663655, 57.37347341352894, 55.03652526486305, 53.754478962190696, 61.53233505064442, 57.346977803014944, 62.66664528077649, 57.79256297696022, 52.008145624591464, 42.00091238944761, 39.90339356084024, 37.19349076670986, 50.5691143005125, 54.209226792858495, 59.84521381316647, 56.43430894420993, 60.39987617923368, 59.282110506488436, 59.47372613414642, 58.255375200702304, 56.877093545852176, 54.609163422738355, 50.65067606587564, 43.50703977769421, 34.99251942480765, 33.47070255587178, 29.64212998267143, 29.035690369144564, 44.95093876315702, 52.82242182762393, 54.01534795761109, 53.5275855372029, 53.31470281847062, 54.46587531797348, 52.090562466652166, 44.33476971041772, 35.030001594174294, 26.362669621744466, 19.01369333267212, 25.958235994462047, 43.24362124166181, 60.909843137187345, 54.350706684973936, 51.450392430828465, 49.89345465936969, 52.01446456293906, 49.58103395277455, 53.04310221825877, 54.661205430184644, 57.65579385142173, 53.2046881798775, 55.58836352440619, 52.90864729112195, 74.43405782022785, 82.34578440266272, 49.006508704154726, 46.87553598034767, 46.10608070127426, 48.63692337466825, 43.91354245524253, 53.35940214895433, 50.56270907002111, 52.14522069500339, 45.21696959772418, 55.9974314320472, 41.35766329303865, 68.24798583984375, 63.431205441874845, 42.622553148577296, 70.91208319510184, 57.81379476670296, 63.90622408159318, 50.798663170106956, 52.05608875520768, 53.23904029784664, 51.3976247849003, 49.22662427348476, 56.56706156269197, 61.92865133285523, 64.54370337147867, 63.45805014333418, 63.22560264218239, 46.50587220345774, 1.816410035375626, 0.5196908813330435, 0.7892754445633581, 0.0860961631781632, 19.63295909666246, 69.08360758135396, 61.772254666974476, 62.63186170208839, 41.67325327473302, 56.411872986824285, 5.083782999746261, 33.68591516248642, 24.524576356334073, 34.31060752561016, 40.489670230496316, 56.57645956162484, 35.04376126873878, 48.00318210355697, 56.39437921585576, 70.36073130946006, 25.714211617746663, 0.8040177954300758, 0.08149387465128977, 0.04013335452445092, 0.05806822359802262, 0.017120816384352023, 0.10188476798394996, 0.06778616383070908, 0.1407988552725123, 0.1604187347355389, 0.28234581072484294, 0.15334204350027347, 0.3756911115300271, 0.22034879713769884, 0.29677461712591113, 0.21153489428181804, 0.21855897059844387, 0.24040867153915668, 0.22988938035503512, 1.8996104934523184, 78.94475998417025, 70.54588287107407, 50.761800735227524, 35.62091450537405, 68.18372172694053, 38.47786695726457, 22.53496781472237, 45.298111669478885, 18.032916438195016, 31.567697986479732, 82.38982477495748, 75.25063253218129, 77.50496772027786, 71.04824435326361, 69.82708500277612, 54.38687093796269, 5.7301194917771126, 0.34647598081538755, 0.9071502678336636, 0.9905173040686116, 0.32739839967220064, 35.67521187566942, 63.77117687656034, 57.84149454485986, 69.16367100131127, 70.07990529460292, 73.26464237705355, 64.72699965200117, 60.7961061693007, 51.430976698475504, 57.36445196213261, 57.6664666206606, 63.86683564032278, 68.928571977923, 72.51882722300869, 51.45738993921588, 70.44078688467704, 60.300134228121856, 46.89912903693415, 52.002116941636615, 57.78469862476472, 54.792914698200846, 57.936408058289565, 65.0671789723058, 69.1563283243487, 64.36793019694667, 63.55392071508593, 60.75828667609923, 64.29695883104878, 60.424512586286, 60.97349928271387, 63.187955733268495, 65.0781302298269, 64.18237463120492, 60.15712853400939, 57.59533443758565, 60.0458626593313, 65.49953399165985, 63.885588492116625, 66.87630161162346, 64.5577689909166, 61.84181397961032, 51.85497706936252, 50.1399403233682, 49.797721370573974, 61.252250363749845, 60.06783969940678, 66.54176265962663, 61.98356451526765, 64.13034046849897, 65.02517823250064, 65.22433265562981, 60.93184371148387, 63.344222960933564, 61.34261000540949, 60.442904580023985, 55.78739243168985, 45.52613081470613, 39.26864031822451, 36.58827297149166, 36.153097767983716, 51.526086330413825, 56.410103997876575, 61.0752377202434, 63.343756198883064, 62.793863434945386, 60.278565114544286, 58.71038975254182, 54.75306341725012, 43.375295208346465, 37.22406171983288, 29.38809963964647, 33.719255308951105, 52.11157852603544, 65.04173063462781, 60.38126453276604, 59.88208409278624, 55.93486962779876, 58.408120139952636, 54.01932524096582, 56.87562265703755, 60.938951046236106, 57.81612465458532, 54.902415506301395, 61.519559890993186, 56.624296788246404, 68.06623105079898, 82.7970060225456, 55.067951294683645, 43.99440996108517, 46.31831622892811, 47.8771798841415, 48.69698270674675, 54.579961376805464, 50.572871931137584, 52.81962125532089, 49.955820345109515, 55.303889705288796, 45.03601889456473, 53.67410959735994, 54.14285636717274, 42.49958292130501, 73.80727875617244, 63.06459326897899, 68.29470126859604, 53.92450978679042, 54.0663387698512, 54.35282084249682, 54.79920225758707, 51.767967131830034, 58.57712330356721, 63.35508008157054, 65.95559581633538, 66.53081140210553, 66.68782388010334, 53.70230359415854, 3.2677861615534756, 1.1933081933567602, 0.8244140590390852, 0.28732418713550417, 23.548931883227443, 79.94994578822967, 64.42808758827948, 73.64764613489952, 50.37698091999177, 62.31163940122051, 11.821783454187456, 36.1530153982101, 28.64430646742544, 46.7068858300486, 64.64891702898088, 68.29705469069943, 40.33316766062091, 65.71012212384132, 68.00697188223562, 83.06069912449007, 43.03895981081071, 0.8911756185754653, 0.3302399423574248, 0.128106203290724, 0.30008794739842415, 0.20258877997196492, 0.23338353802119535, 0.2582262985167965], [0.11016032553368038, 0.2011264100550644, 0.11987710897360118, 0.11339989686084372, 0.1721620812050758, 0.08280006222306721, 0.10547455640569811, 0.06517686836060978, 0.05758139770478011, 0.1187744096762711, 0.010799748312321403, 0.07769987783244542, 39.580860983940866, 55.209560625014774, 46.31431541135235, 32.78971829722005, 36.153937155200595, 42.78106397198093, 32.286625292993364, 41.96317526601976, 30.536055795608032, 0.1795676846297518, 35.98165489012195, 62.123094989407456, 63.69792661359234, 60.460461108915275, 58.49470646150651, 39.18474866497902, 2.710943202818594, 0.07598980104610806, 0.1416691464762534, 0.23836254262395445, 0.13383592809400252, 20.875214915121756, 60.54655321182744, 61.75778896577897, 67.65118152864518, 64.27282448737853, 63.27491467998874, 58.889183152106504, 51.500398728155325, 48.536863711572465, 49.67090329816265, 51.579340350243356, 59.683337596154985, 61.43172233335434, 67.28303570901194, 64.38643201704949, 30.13659965607428, 42.5774968824079, 51.41979402111423, 53.38817273416827, 57.95900483285227, 61.9927820851726, 69.43131785238944, 74.29522160560855, 66.65911213044198, 58.07733097384053, 57.76111341291859, 54.56753923046974, 56.33768135501493, 55.69159246260121, 57.425868434290734, 56.62064898398615, 54.48775822116483, 50.17131928474673, 51.9005314765438, 52.90722739311957, 52.97090707286712, 60.80840279979091, 59.03179660920174, 62.94020314370433, 44.334251957554976, 30.61336571170438, 25.054757248970773, 27.238428977227983, 26.83339914967937, 37.12249978896111, 46.70689759715911, 52.377115141960886, 52.35347109456217, 52.014064481181485, 53.88666283699774, 46.878987666099306, 36.954312478342366, 31.724526113079442, 26.580100328691547, 25.39962968518657, 16.942022923500307, 12.462490854724763, 11.541848797951976, 10.10006397001205, 6.968184257707288, 15.421976024104705, 37.327137685591175, 48.9200282865955, 54.38165418563351, 51.1143708229065, 50.56026151103359, 45.897638105577045, 32.32888883160007, 21.400367329197547, 11.329623076223559, 12.040621311433855, 10.550134374249367, 20.483940839767456, 45.56106736583095, 57.21202865723641, 54.547546909701445, 51.50260702256234, 47.65853128125591, 47.73084409775273, 48.595283492918945, 49.51078038061819, 51.179686131015906, 52.21286196862498, 53.64652749030821, 52.275510065017215, 59.745503241016024, 83.83903072726342, 56.082837120179214, 45.00993121054865, 49.81555246537732, 48.61497771355414, 40.19328809553578, 43.639741405364006, 51.946332993045935, 49.07617392078523, 52.96689448818084, 41.63669286235687, 75.3197446946175, 101.26571347636562, 42.29177967194588, 45.48174135146603, 61.26826147879324, 59.4306428201737, 64.23616209337789, 52.491467921964585, 50.49562869533416, 52.26827721441946, 53.355220902350645, 45.51310854573404, 53.570476655037176, 55.52764131176857, 62.652183501951164, 55.782979765246, 66.00490000940138, 32.20902904387444, 0.48426250176083663, 0.16538751972538812, 0.06203626793238425, 0.39049208344471076, 31.645668821950114, 58.57983366135628, 53.095803183894006, 55.59314489364625, 73.85183688132994, 30.230220748532204, 2.0862653034348644, 43.247453397320164, 19.45637006913462, 37.77895158337009, 52.9457333011012, 45.611814991120376, 36.65723216149115, 60.84743038300545, 41.60600031575849, 57.74906781411941, 9.185165243764079, 0.32846350703508626, 0.019026529043912888, 0.01827479569211362, 0.1477489581391696, 0.06904254802652905, 0.12909775089112022, 0.046037709070069176, 0.07708210453030563, 0.08397056030169611, 0.09414815328895085, 0.06116148745340686, 0.02933718958839534, 0.07921286317850314, 0.07210115406421885, 0.029237195962078633, 0.012288582736566182, 0.02890794094832194, 0.041409948119713415, 0.048960855440987695, 45.5399767814144, 66.12323007275982, 48.72128571233442, 33.68040423239432, 55.06029090573711, 37.345694418876406, 43.18713518881029, 40.781549484499045, 37.07908307352374, 2.0873777856749873, 31.66104647421068, 71.55264546794277, 70.2450841472995, 68.32979079215758, 62.66656683337305, 47.93892191302392, 3.8679195844358016, 0.0859704711324265, 0.13842327790635248, 0.1992127837072457, 0.10667852486573881, 25.618182190002937, 65.22853743645453, 65.89654845576133, 67.80125141143799, 64.20892515490132, 67.22429429331135, 63.42987575838643, 53.42450564907443, 52.32121352226504, 52.982360393770286, 54.83555478434409, 60.287155105221665, 62.533304306768606, 68.60465480435279, 67.95384730062177, 38.866189449064194, 45.76884315859887, 51.89876248759609, 55.300077161481305, 60.342833149817686, 61.64686433730587, 66.51090145111084, 65.24651758132443, 55.392711777840894, 52.041783871189246, 54.0761290058013, 56.530199127812544, 58.805926922828924, 57.617727248899406, 59.13322125711749, 59.831881676950765, 57.070874321845274, 51.64673451454409, 54.32930623331378, 53.40916133696034, 56.667207517931544, 60.09608468701763, 59.78731570705291, 63.97434780674597, 56.34957005900722, 48.30713833532026, 39.421746115530695, 35.54003915479107, 39.418608219392844, 49.864880192664366, 54.00853872299195, 56.99525886966337, 58.55182401595577, 61.32745788943384, 61.14686019958989, 55.0894654950788, 50.2691275073636, 51.139717178960005, 47.61659722174368, 45.097176490291474, 34.847564312719534, 29.207539212319162, 28.139564106541297, 30.480236545685802, 23.32621382128808, 37.47588965200609, 48.30664411667855, 51.22038856629403, 55.09459987763436, 56.35955249109576, 56.11591446784235, 54.96437718791347, 44.2846731985769, 28.71005911980906, 23.885722275703188, 17.478524715669696, 19.16911921193523, 36.112293351081114, 56.67079256426904, 58.30065896434169, 56.13868774906282, 51.51445258048273, 49.11997895086966, 52.35300041014149, 51.38543405840474, 51.11599468415784, 53.74751283276466, 52.936700082594356, 52.25304272867019, 55.34679259023359, 54.44425521358367, 70.47631571369787, 55.71890392611104, 46.93548156369118, 47.04184447565387, 46.44602075699837, 42.369470057948945, 44.28295127807125, 47.45801579567694, 48.4397772050673, 51.840381929951334, 44.48862075805665, 64.44567157376197, 98.32777976989748, 49.21261748959942, 47.12727369800691, 62.38867867377497, 63.28073939969463, 64.81257792442076, 56.167183768364694, 52.398064521051225, 51.396318635632916, 55.3950063643917, 49.4098303394933, 54.840642098457586, 59.41572212403821, 64.26017484357281, 60.24410709258049, 70.72516656691029, 36.93208048420568, 0.7634486594507772, 0.3179905335268667, 0.12151248452644195, 0.98340678239061, 36.70970170728622, 68.17462182814076, 60.74488001485025, 56.62640702339911, 76.96318641785653, 29.15050991119877, 3.393251996847891, 48.402440163397024, 23.508082359067856, 39.75697932704803, 34.88150065945041, 53.62868070602418, 40.19497471470987, 55.26991805722637, 48.849119678620376, 65.62049204303374, 8.14774344044347, 0.32237721426833066, 0.06880510673527757, 0.042438808032461715, 0.02008618186077764, 0.10195204582546027, 0.28943469807986294, 0.035484717678158514, 0.19225370229011585, 0.3153435465308928, 0.22915312389452613, 0.24334383016872793, 0.24688885607306035, 0.33617127085885695, 0.22178495152583047, 0.17932638225536193, 0.141500270054225, 0.2141534747375596, 0.12926834335009899, 0.11450385254236961, 62.678655578244125, 72.69726368688768, 62.61628597013412, 46.677319003689675, 55.09238766085718, 63.303857849490264, 44.24278620750674, 52.059348244820875, 40.78775075174148, 6.035186244595436, 45.88313318067982, 73.01741538509246, 73.9247537428333, 73.73399319187288, 70.09523391723633, 50.386818224383944, 4.527869887890355, 0.2106646490433524, 0.3886218483169233, 0.8340635186722203, 0.148351164534688, 32.36673970376292, 66.25958734943022, 69.58837739882931, 73.94785650314824, 68.88937965516122, 69.31986762631324, 67.48528880457725, 56.126622538412775, 52.82341026490735, 54.53794886988979, 55.70610523223878, 63.596325459018836, 66.34461649002569, 70.87439706248622, 67.67296637258222, 42.40651684422647, 51.389399574648955, 52.46346219893425, 55.79521363781345, 59.859248053643014, 62.629288627255356, 63.693808124911406, 65.30108167279151, 58.3583374177256, 52.454260318509995, 57.86988466016708, 62.464611837940836, 63.11292471424226, 59.1164021338186, 60.720271064389145, 59.80389556577129, 59.119555719437145, 57.72037175393874, 58.02082138676798, 59.75387357896375, 58.56235165749827, 63.54443642400927, 63.523620405504786, 69.8641670903852, 65.60400632119948, 58.51758564672163, 50.17048381990003, 51.572480124811975, 50.68585580395114, 57.23610808772426, 57.110133324899984, 58.52722683260518, 60.906148264485026, 65.81072699639105, 66.22097553745394, 63.31558965867566, 57.3755052012782, 60.76043613495366, 54.8965201839324, 56.74005769914197, 48.58106490104429, 41.941429645784446, 35.904019417301306, 40.205776922164425, 28.92992954100332, 41.81265431065714, 60.177285594324914, 56.83289627875052, 62.76478690485801, 60.59830496388098, 61.2547371464391, 62.034049341755534, 56.16118646437123, 43.30173507813485, 37.01301074797107, 29.07605548058787, 29.90432866158024, 45.4471891926181, 60.90890961308634, 58.61435051887267, 59.13309966364215, 58.4298736049283, 53.65343478418166, 56.79735960498933, 53.87202062914449, 56.02754739023025, 58.057675976907056, 56.29699853158767, 55.143790321965376, 59.427481389814815, 57.76064665086808, 64.8575714326674, 57.546081235331876, 47.31086023392216, 47.30143477839809, 50.38899906219975, 42.06647480687788, 49.28902133818596, 54.48589509533298, 50.97881370975126, 51.62857394064627, 48.91128140111124, 49.6125501971091, 89.9234034938197, 66.19486039684665, 47.95296399824081, 67.38230305333292, 63.43356278634841, 71.6044678226594, 59.118986975762155, 56.53860868946199, 54.23675398672781, 59.97862931220763, 52.188613876219726, 59.17369619492562, 60.985588027584946, 67.57593477925947, 63.35217360527285, 73.63643600094703, 41.60101498326948, 1.2022953240140792, 1.0933414414044351, 0.18997272146084618, 0.7119669993558239, 40.967536510959754, 75.30903662404707, 66.27328426607194, 64.12920690351918, 85.73193519346177, 43.790925241285755, 6.575911448847863, 58.4896779829456, 26.344381570816044, 54.23174904238794, 68.72187875932264, 65.3777208635884, 47.72652949056318, 79.6140104724515, 56.926091794044744, 83.50515857819589, 18.324211259042066, 0.45559910756926386, 0.26885797479941004, 0.18229552454525427, 0.2107865489538639, 0.30986206485859813, 0.3367144271971718, 0.14949088886139855], [0.0666875784255324, 0.09044535157661285, 0.10620860653298517, 0.021283784130167578, 0.04205939915752219, 0.104066057791633, 0.24648105214920737, 0.09068569634109737, 0.01342091910285695, 0.0944956737540422, 0.20379164526539467, 0.3505594133129043, 24.330560238130634, 62.68663760154479, 52.038826404079316, 32.1281321202555, 25.105832392169585, 44.689085252823375, 33.11308437778104, 28.084311639108968, 64.50327550211261, 10.975615439876433, 11.432140104232296, 56.60789735855595, 57.166984158177534, 67.33736053589853, 56.85430457515102, 48.441051975373306, 3.857470880593023, 0.15286834069317387, 0.1414210718846129, 0.2282996866251192, 0.26755660592067626, 18.934018227361864, 66.80575386170419, 58.802337954121256, 65.11019560598558, 63.134701713438965, 63.22153122194352, 55.44862908701743, 52.21047324519004, 51.127310722104966, 55.54616666609242, 52.284374621606645, 52.14671904040922, 58.88248374385219, 65.42970011311193, 64.46233380225398, 63.424341294073294, 59.04784694794686, 51.60839726847988, 49.181756281083636, 51.411615879304954, 52.61477939544186, 50.0179781452302, 44.753769059335035, 48.152847982222035, 50.72144346852457, 53.39054576812252, 56.66079836506998, 60.841986133206284, 57.67572733663744, 56.274503738649436, 52.26928918592392, 55.266556585988695, 51.804637370571015, 50.89364728619976, 50.918777911893784, 61.23276010636361, 62.031762599945075, 59.11226795565698, 50.723432110201934, 41.864523733815844, 28.883996625100416, 24.964460365233887, 27.04666037713328, 30.796485485569125, 37.645049710427564, 47.549485468095355, 52.438351185091086, 50.957601531859375, 49.69684977685252, 49.386194136834916, 36.26448131376697, 25.547010783226263, 24.442514488773963, 20.784674844434186, 16.698816360965854, 9.467693567276001, 8.081215139358275, 5.511564535479392, 14.947103492675291, 16.70221313353508, 7.616954090133791, 27.33833762907213, 36.44279618417063, 45.98915484643752, 52.81608327742546, 47.905479784934755, 47.236088091327304, 36.71858587572652, 29.281713193462743, 15.56163005290493, 12.284963400133195, 12.41044786668593, 14.107623119508068, 33.33820096908077, 50.14920496171521, 57.87865507987238, 56.60244918638661, 48.91606277035129, 48.723470472520404, 46.29195397899997, 48.98013468711607, 50.438711181763686, 51.985270361746515, 51.67949807259345, 52.58630298799085, 49.73146077125303, 55.61048176980788, 51.77799270999048, 40.97658149657711, 45.38388998277726, 43.29306664005403, 49.19308016377111, 41.86563768694478, 46.53280711943104, 49.636519801232126, 49.81980431464411, 73.37635932430145, 89.59674850586923, 31.245804755918442, 35.95197431502804, 55.240829760028475, 62.69103850087812, 60.650064560674856, 61.20611544578307, 52.522505637138124, 51.9523302970394, 51.77797702050979, 56.764368549469985, 51.930059079200994, 56.592007836987904, 56.25447611654959, 61.10651077762727, 54.74220629661314, 67.1323617812126, 25.00665330117749, 0.22743872637229584, 0.382115708724145, 0.3653877192447263, 4.683025613907845, 47.554925795524355, 55.01190454729142, 57.725321785096206, 60.88372799658007, 62.761452890211544, 13.871498396319728, 10.269497613753042, 46.87596351869645, 12.18311611683138, 35.28485759612053, 43.425038706871774, 48.83704270085981, 25.79272177911574, 42.95575849471554, 47.328914903825336, 56.97744738671088, 2.230398924120011, 0.03529549396086124, 0.12128877153079357, 0.050682224363328955, 0.05866820067768136, 0.04616828492632316, 0.036896724974916834, 0.06594497875701036, 0.022569166669141383, 0.12314742340916589, 0.06045289825828326, 0.06266446769117348, 0.09403335501349742, 0.03665524640030438, 0.0849615486579076, 0.03656415471566781, 0.09109372243044839, 0.13081899723939358, 0.3916731458758155, 0.3921743512393967, 29.050012903828776, 71.14974744858281, 58.29784270255797, 29.606860030081968, 31.268044594795477, 47.99899693458311, 34.0529784079521, 32.26261058161336, 62.175866557705795, 18.973124257979855, 13.446756697470143, 57.123983213978434, 63.97873693896879, 75.1082661844069, 62.60855105615432, 55.811934701858036, 4.844555681751621, 0.08803567563694331, 0.4846719297910891, 0.2546203226572083, 0.37491748530057173, 23.16732252797773, 73.38764790565737, 63.18470016602547, 66.98151526912567, 65.40875465639176, 65.52466461735388, 57.556365689923695, 53.891487352309696, 55.818108512509255, 59.52533275850358, 55.42066258768882, 55.08362116352205, 61.67537212371827, 66.47116784126528, 65.66858030134632, 70.95024785687848, 64.87633212920159, 51.29966751221688, 52.790889893808675, 52.22987721043249, 50.99576619363601, 50.02446966786539, 46.06660596786007, 49.36458579955563, 55.66504586127497, 57.00852040321597, 58.70919342963927, 62.748046228962565, 61.30568873497748, 58.30938231560492, 55.607787101499504, 57.57472238233013, 52.50741235671505, 50.91429072041666, 51.80134257962627, 61.25724746334938, 62.56252988692253, 62.00596517132175, 58.80518167249618, 50.67164505681684, 42.107557712062714, 36.47291214235368, 37.656977638121575, 41.149063802534535, 50.71283386599634, 53.883042489328695, 58.17412330258278, 57.29086045295962, 60.42337117656585, 58.6581398594764, 52.4521775399485, 47.65051003425352, 42.01621355548982, 36.466071528773156, 34.67916519411149, 28.610711366899555, 24.966913807776667, 19.187964239428123, 29.881365145406416, 18.878428436094715, 27.381993609090006, 49.70775004356138, 48.6229597368548, 53.440187285023356, 54.94019969817131, 54.55960819798132, 54.0139437490894, 45.57699218873055, 35.550351065974084, 27.29133782848235, 18.62665737828901, 19.28955166570602, 27.4500879164665, 46.23859797754596, 55.99692544629497, 55.99524274949105, 53.85595067854851, 51.366077161604366, 49.79491687590077, 50.84087179553125, 50.03120437745125, 54.40289774248677, 54.97231998751241, 53.41784154215167, 51.782170034223995, 52.524588415699625, 47.83581456830425, 48.10023723110076, 42.84393956584316, 44.66076574017925, 43.35405557386337, 47.52514716117613, 42.99016944823727, 46.74738430207776, 48.181230252788914, 48.891481276481386, 62.52742859625048, 77.61903808962914, 39.74592216553227, 39.35686226814024, 57.16583882608722, 63.884501995578894, 62.41358572436918, 60.45302037269839, 52.98330176261164, 54.508378121160696, 55.688317283507324, 58.68000707318706, 53.719660082171046, 58.321926055415986, 58.57317347680369, 64.14898349392799, 59.598096647570216, 70.94923588537401, 27.635392450517227, 0.8111711567448032, 0.7447809353470803, 0.5001676515225442, 7.668959325359714, 55.955469915943766, 62.898229860490375, 64.20797201894945, 67.91241922686177, 66.95148560308641, 18.901527274039484, 11.379817647318687, 50.89079572308449, 18.305070092601163, 37.17252177576865, 38.76891859116093, 57.76938961398218, 28.404790855223133, 44.74708926293158, 56.822631436009566, 64.94248290215769, 3.167507581172451, 0.09440397302950583, 0.11400841582085817, 0.021458007845907442, 0.01576085805877923, 0.03988882691989984, 0.10887738873040485, 0.02869798497657382, 0.22244815384188008, 0.15933269785056192, 0.19536233386926113, 0.15460953597099553, 0.2686916417892902, 0.11869918750298601, 0.3547442145645619, 0.2018261394433437, 0.14880022995414274, 0.14665277825007517, 0.6207141604635024, 0.4924622778930972, 41.88184492049679, 82.84951086967223, 68.94816813930389, 48.386644778713105, 35.528350491677564, 68.23267290669104, 43.008357478726296, 36.5867942379367, 70.226452888981, 20.10149209730087, 18.93887608282028, 66.97512965048513, 66.37859206045827, 81.81252248825567, 64.95836457898541, 62.15236371563327, 5.095407434048192, 0.31962983911075904, 0.7702518879405914, 0.6470297096717743, 0.5257684713409794, 29.338358102306245, 75.08326499692856, 66.79142936583489, 69.25708616933515, 71.42083029593192, 69.39196079008042, 62.78193158488121, 57.76011320852465, 56.63136097692675, 58.75853292403683, 56.50397023847027, 54.016375618596236, 65.6705963996149, 70.92922395275485, 70.27209358830606, 67.86378183672505, 57.594216562086544, 50.98651332239951, 51.669017499493016, 50.6665224413718, 52.18569563281152, 52.874361853445734, 49.177982960977864, 53.30821521820561, 59.96147678744409, 57.80569114992696, 61.697184424246515, 66.02049535320651, 61.5801134417134, 62.626511589173354, 61.841519801847404, 62.612340065740774, 56.23791586968207, 58.787613376494384, 55.93406946428361, 64.09172865652269, 62.65423882392145, 67.1777436041063, 61.382449519249704, 61.32813645947365, 51.52120297954929, 49.84211083381407, 51.47893159620224, 52.36750141266854, 57.59877435622677, 60.198764493388516, 66.61168283031833, 62.21737700123941, 66.40257343169182, 64.77294629619968, 61.789391502257324, 56.746145217649406, 54.721535405805035, 46.69608362259404, 47.80649877363636, 38.78250960380801, 39.35709761035058, 27.463192555212206, 35.367023406490205, 32.63624183593258, 33.884073303591826, 60.619277877192346, 56.706556735500214, 60.21475207421088, 63.676734047551314, 60.15718736956197, 59.41804024481005, 58.81657223547659, 54.58053012048045, 43.947761212625814, 35.2874267485834, 32.16825796711829, 37.834610016115256, 51.5263020607733, 57.300285908483694, 61.539069760230284, 57.97243502832229, 53.514214177285474, 53.09849785220239, 55.35881073244157, 53.8300944143726, 58.872654284200365, 57.95250546547675, 59.675226134638635, 55.769937884423044, 58.218665738259595, 50.24491471628989, 47.58825417487852, 45.94167063313146, 47.74061864422214, 45.58490360936811, 48.26565534837785, 44.05155497212564, 46.9565603809972, 49.52335549939064, 50.57410747774186, 55.0086489800484, 85.64263066937848, 68.48131979665449, 44.07428902964438, 59.10332102929393, 64.4800550706925, 65.73998705033334, 65.28277204882714, 58.16658450711159, 58.45710662103469, 58.93586720189741, 61.22925350742956, 55.22461860410629, 60.826751647457, 63.42530619713568, 66.0356278573313, 62.298366100557395, 76.5182876586914, 32.33322697301065, 0.6393629468737111, 1.159920120431531, 1.141741037849457, 8.216874724434268, 61.06602407270863, 68.06541519780313, 65.73464478215864, 70.94106166593491, 76.55895479263799, 24.253228748998335, 17.48261182538925, 59.29619181540705, 16.634146282749793, 48.958534194577126, 63.511355153975956, 64.33269554568876, 37.81318995260423, 62.11358324173958, 62.6695909807759, 85.38282071390461, 6.057334888365961, 0.2885664446700004, 0.2947510724827167, 0.1259877250319527, 0.1622772793616018, 0.2590437143320038, 0.1634825654928723, 0.11809310470257076], [0.08476172228373828, 0.06316227928525017, 0.01201032428070903, 0.04275588799388178, 0.03285709738491043, 0.01925853685656142, 0.0797668826435843, 0.14222195552241418, 0.06588033625795957, 0.09416691478221648, 0.060695001194553996, 0.24852111364804932, 9.91538211222618, 62.88569396541965, 46.6578915042262, 43.250944306773526, 41.467403365719704, 38.778453873049834, 40.88532755451818, 26.122340117731405, 89.66986933062154, 74.60771683723696, 11.635262004790768, 62.66400552565052, 53.12847260505923, 66.1501532216226, 55.566590447579664, 58.621830478791274, 6.866721856978632, 0.08902141629087348, 0.12491667282677467, 0.16937528316292072, 0.3483129370837443, 18.99069059279657, 72.08548376637121, 59.005916810804806, 65.45024156570435, 59.61661023478354, 57.38488751073038, 49.59843358685894, 56.3517822757844, 64.50964543127245, 65.59325510455717, 61.19099863113896, 54.13212476238128, 53.020140663270034, 60.974895646495206, 65.26302291500953, 59.11921055086198, 60.63518701061126, 68.37905576152187, 55.11488245379541, 49.87528231836135, 48.864707177685155, 50.217061965696274, 48.909398663428526, 54.519415670825595, 55.49590933707453, 52.098607247875584, 53.81822532223117, 60.48671745484876, 55.96503265442387, 54.58024770982804, 52.41550730120752, 50.89991915610529, 54.72473998223582, 49.74471053769512, 52.83789557795371, 59.68052917911161, 59.80248743487943, 60.2084017569019, 49.94484555336737, 37.202269031155495, 32.38929529343882, 30.971635003243726, 30.02162910276844, 36.28792924265708, 39.904499669228834, 47.635863904030096, 48.1144283663842, 47.08295483742991, 46.53838865218624, 37.02278137207031, 29.428017600890133, 21.567111207592873, 19.028159033867624, 14.400964436992524, 11.555752619620293, 9.568082709466259, 10.196473867662492, 3.7186957078595317, 10.736017457900509, 21.486024049020585, 12.138265775096032, 19.93429910752081, 27.99896674771463, 36.323826774474114, 46.149728836551795, 44.90055199592344, 48.969995360220636, 41.89121938520863, 36.239248706448464, 21.7303837883857, 16.367603578875144, 16.480807104418357, 17.01932107248614, 28.304740998052782, 42.78070703629525, 55.85957188760081, 56.05201121299498, 50.9177698627595, 50.631938903562485, 47.970763714082786, 47.89546205151466, 51.02415238657306, 51.38486139235958, 55.18808172595117, 51.57907755144181, 56.070089417119185, 46.053583698887984, 37.9108569698949, 40.92092698620212, 44.22096998460832, 45.18859124952748, 47.516255147995494, 44.299327173540675, 44.52959383687666, 47.092015512527965, 59.45605193414996, 50.2652875069649, 17.580061151135354, 28.54551176871023, 56.80676152629238, 59.69305722944198, 63.54609558659216, 56.85624614838631, 57.22945574791201, 51.954248336053666, 55.961839845103604, 55.08331129627844, 62.23950309138145, 55.22170036069809, 59.40740277690273, 51.651402135049146, 62.311204018131384, 54.235965590323175, 69.63193924196305, 10.799101917974411, 0.5812801829268855, 0.7253291662181578, 0.5403439989013057, 18.599734229426232, 47.5825902723497, 40.68056806441277, 53.43330352537094, 54.59104599491243, 65.93972590661818, 17.191134614329187, 12.412061922011837, 33.95680973606725, 17.248873864450765, 38.772782125780665, 30.78181385993958, 45.35067927452826, 29.239708531287413, 49.459491468244984, 48.304380909089126, 46.442074852605025, 0.4583356042783107, 0.08115007737351042, 0.08843851531104696, 0.09630611571933954, 0.05059626546778506, 0.07126309217945223, 0.035132987559923244, 0.08454987599003701, 0.07285820215099281, 0.06829998666240324, 0.09564780104424685, 0.009129303169526882, 0.017077806293063106, 0.03734089892297503, 0.1112898072648433, 0.06526509870684917, 0.17225658581141504, 0.03977051230087396, 0.07076183318971627, 0.4547436325059783, 13.611561944407802, 74.20288901175223, 52.482874008917044, 38.151619895812004, 47.378658402350645, 43.602690696716316, 34.47654731812016, 39.19343279254052, 84.89607026500087, 78.88945456474059, 14.408983722809824, 62.7218722528027, 57.622508618139456, 73.917371842169, 60.38590469667989, 64.2507533104189, 8.53848897641705, 0.11012513145443895, 0.23233241942380709, 0.18193578497777063, 0.24791014320667715, 24.013926905970422, 75.57920163677585, 63.99445779861943, 68.72781722776352, 62.385030869514715, 59.27037085256269, 51.65189243132069, 58.69277046572778, 68.7523869545229, 66.31163720161685, 63.33609580993653, 55.6833044944271, 54.778601969442065, 62.290380154886556, 67.28650308424427, 60.63235113697668, 67.76292985485446, 68.86593957101145, 54.94286690988849, 51.75798862211166, 51.26646072633805, 50.6593680381775, 51.152966945402085, 57.1060932836225, 55.962765524464274, 54.16024031177644, 53.13744698801349, 62.467271204917665, 57.41011227330854, 58.114154185018236, 52.854110656246064, 55.22666215896607, 53.93394308705484, 53.850251474688136, 55.61833827726303, 60.52708256629206, 61.35693842364896, 60.20680927461194, 57.95489418891169, 49.898255640460604, 42.904720614033366, 39.93516868160617, 40.64717692713584, 47.0989384958821, 48.086187301143525, 57.31193534789547, 56.210145488862075, 56.419576521842714, 56.58625371994511, 54.50797411703295, 45.521800518035896, 42.028435660946755, 32.46354772198585, 29.009836066153746, 27.48747398776393, 22.00985070197813, 20.491048174519694, 12.943551905693548, 19.892153240019276, 17.474388576322987, 21.682030770086474, 40.70850318478, 44.50894648028959, 50.162662613776426, 51.82694388974098, 52.391267053542606, 52.83940176809988, 49.92315092394429, 41.50069252137215, 33.47213814335485, 24.07343318385463, 21.682466153175604, 26.56439123615142, 38.52225249813449, 53.6921799567438, 57.02186822891236, 56.238527759428955, 54.576003705301595, 49.32883731780514, 52.82213941697152, 48.64623508145733, 51.23496017148418, 52.33657744623, 56.85849758886523, 53.5449420252154, 56.423247860324004, 48.49914619999547, 38.98946169883975, 41.26990418280325, 41.70508330868137, 43.90327369013141, 45.93435541276009, 45.01311617512857, 42.48441119347849, 44.857955055852095, 55.45288878102457, 47.02927720162177, 25.310160421556045, 33.27182662102484, 57.17909251489947, 60.583725513950476, 63.67425118723224, 58.16032440431657, 58.419283205463046, 52.54931111489573, 60.25414443785145, 57.95828703911074, 65.52289955077633, 58.80548761736963, 61.42032000326342, 55.43248853375835, 67.05709149760585, 56.11250592816261, 73.11874589612408, 10.34353627312568, 0.7965983258139703, 1.5796133611471423, 0.45096206929414506, 24.055931568145756, 55.591615169279045, 46.97744700216478, 58.42328402303881, 62.234772712953635, 71.65279926792269, 19.068100529332316, 14.358785229344523, 39.966398592918154, 22.580279034952966, 38.750495218461566, 30.404915271266816, 57.15269888600996, 34.63944335137644, 51.6024431105583, 57.720473735563225, 53.177921925821614, 0.04429219688679423, 0.012308416752925804, 0.022836742028894446, 0.026117067318409685, 0.05881411361417944, 0.09272493046498106, 0.049087451470475045, 0.04202623904171971, 0.13008595834816658, 0.2568143831505891, 0.2301427869186286, 0.25767079284114225, 0.10847398981211648, 0.1291289613131554, 0.2914606329173811, 0.17939301658301585, 0.3064074373293308, 0.19779115434615843, 0.12605931594847672, 0.63423432529934, 21.143791367930753, 90.22834424049624, 57.68716496805991, 61.58088614863735, 54.428706938220614, 59.223192584130075, 54.27087076248662, 39.8368505508669, 89.15328533418717, 85.46109553306334, 19.601870390676684, 73.195522369877, 65.64773290388047, 78.89577742545836, 63.37576273948916, 71.23373323871245, 8.66102578178529, 0.27356003861754175, 0.8528926728233215, 0.694932452132625, 0.5416784014913344, 29.659566879272464, 79.10145082781392, 67.47229006982619, 73.87487688372212, 67.69245270759829, 62.301076458346465, 55.60089549710674, 62.839005993258574, 72.09860017222744, 69.13223712675034, 66.3267618610013, 61.28434711886991, 57.94912830475838, 65.57388644064626, 69.7596045463316, 64.73876676251813, 72.02541658955236, 64.48475407015893, 54.718342596484774, 51.137614788547644, 51.92259480876308, 52.546522309703214, 51.64001941680909, 56.72171669621622, 62.688841973581624, 56.09418061471755, 56.494132934078095, 67.65636690201299, 60.718294189822295, 59.988466616599794, 59.0463956709831, 58.17618646929341, 59.28193007746051, 59.172021342862045, 57.81321033354729, 62.675325485967825, 62.049719210593935, 63.726061774838364, 64.86654189325148, 60.21840772321148, 54.90811863253194, 53.83972383314564, 52.74911272910334, 57.03210953743228, 55.049947615592714, 62.33151797325381, 59.11130305259459, 60.2269192664854, 64.7033203032709, 61.786771358982215, 58.10312448009368, 54.45007601091939, 49.82944942289784, 41.92638735617361, 41.73411669269685, 37.183155321305804, 37.553662407782774, 27.26694460838072, 30.476118057004868, 28.20671900626152, 28.014691529735444, 51.338428374259706, 55.58752021481914, 59.213367046848425, 60.05569996372346, 57.76814622263755, 63.942282430587284, 59.29980039596558, 54.8971438407898, 45.40352536785988, 43.917182414762436, 36.78697632205102, 42.22985721403553, 45.14267598429034, 57.40717441804948, 59.36332710327641, 58.481876388672866, 58.542833943520826, 55.49526606836627, 55.517580432276574, 52.20818258100941, 55.831213151254964, 56.25508016155612, 62.81582478554019, 60.63811702112998, 61.093417905992084, 52.68861409156553, 43.46298763828893, 43.04195650162236, 43.535072957315755, 46.40225495061567, 48.13640540645969, 45.184802239941014, 43.8816535857416, 49.451070139485026, 55.50542892948274, 59.009219446489894, 47.31542979517291, 36.9779408362604, 59.8462297070411, 62.624570015938055, 69.98930638836276, 63.343171765727384, 59.95391053538169, 57.176844996790734, 62.754251418575166, 59.488901784343106, 69.84069562727406, 63.37443305600075, 66.56743065003427, 57.35486961180165, 69.17628534378545, 59.09672360266409, 75.89012792033535, 15.635041133049997, 1.6379044397223381, 2.1235557669593446, 1.6509894666171845, 24.334878767690352, 58.93825200296218, 53.44298393495622, 66.33976844049269, 68.69464966558641, 76.94743417924451, 27.39486682799555, 20.0415131738109, 42.420888408537834, 26.11723319176705, 52.96220333345475, 45.07577211626115, 67.30737009356099, 41.46207286465553, 68.27952169602918, 63.89299784937213, 72.36325817723429, 1.6849504507357076, 0.10350377223784886, 0.2904186001227748, 0.18723565784673538, 0.18001109632032533, 0.23472972304349948, 0.1838913623003229, 0.12148023222482975], [0.10470621618292025, 0.036181493797489715, 0.014484464603986953, 0.04276765893483835, 0.0053350329530545545, 0.07268233900709499, 0.028869883615463495, 0.16971226991905322, 0.16688434827712276, 0.12220351115590143, 0.10459144855098379, 0.28346482003408097, 4.086692477426221, 59.631511319068174, 51.26672744750977, 49.932874479601466, 28.27447402861811, 53.57779579777872, 44.35506797605946, 23.160609391427812, 35.82533667164464, 44.06197670967349, 13.537293826380084, 40.350751646103404, 60.89940571015882, 55.342379923789736, 64.11546684080555, 62.8730482439841, 14.233846952838284, 0.06821593149535118, 0.9196087573805164, 0.3114505328478352, 0.05126756916363394, 15.925812317479043, 76.46294301556003, 58.683925520989206, 64.6813746421568, 57.53676168380245, 52.37146692891275, 53.77007430599582, 66.5909178026261, 63.09774121930523, 66.92655501827117, 63.07035523076212, 57.782588389612016, 50.16983662882159, 59.414733686754786, 62.19515285184307, 67.97180391127064, 52.341241144364886, 47.12574397363971, 51.106573151003936, 50.19690490538075, 50.876271186336396, 51.55722210484167, 50.38251538430491, 50.83274464453421, 56.15157273507888, 55.919976388254476, 55.772126566979196, 62.41277379374351, 58.61768845588931, 55.235397277339814, 54.01531265627954, 55.8414662268854, 54.820943955452215, 48.45341920852662, 56.695232852812744, 60.34370391599594, 60.74292275213427, 59.476259985277736, 50.48188863262054, 38.28234072654478, 34.403073480052335, 34.54912293341852, 36.56193817815473, 40.67351172047277, 43.70365250495173, 48.600453176806056, 43.17155945685602, 46.046327314069195, 41.278925634199574, 33.512232611256266, 23.672631671351773, 16.56432613249748, 16.148129317068285, 12.310543137211955, 10.499848608047733, 7.8196685544906135, 9.879928788831158, 2.805044540474492, 9.950025466180618, 21.299291772227136, 13.89727327131456, 17.806995761009958, 24.173981182036865, 28.914924513909128, 41.44671678543091, 45.06490715088383, 45.7727772958817, 40.48641074088312, 40.770194222850186, 31.936381170826575, 28.045572350102088, 21.84749007225037, 21.519177882902085, 25.16122606492812, 36.66204883206275, 48.797669949070105, 54.44748724660566, 51.12532208042761, 52.642239909018244, 47.07048954502229, 45.83772782356509, 48.06250010767291, 52.18537792082756, 52.472197317308, 52.953193649168945, 52.43409541345412, 53.13350500599031, 50.83849091683665, 42.58704785377749, 46.92700924411897, 45.21880526696482, 48.53289035058791, 46.55288573234312, 46.99077521601031, 45.08565256672521, 40.856753087812855, 27.05923745709081, 43.07155078457248, 62.09649347489881, 59.194112131672526, 58.01686371526411, 59.23881930689658, 58.13179700605331, 54.06177313097062, 52.31758140748548, 59.63397456753639, 59.180513274285104, 59.55597431428971, 59.115578436082416, 60.85690682934177, 58.59911211075322, 59.47607563387964, 57.986559483312796, 57.1725853027836, 1.6709891418295524, 0.8475307315107315, 0.5295170927720686, 0.28540976405624424, 33.598273723356186, 72.88601598431988, 50.564972277610536, 61.54744794291835, 54.92935826701503, 59.14869892981745, 8.086422085762024, 20.10645781793902, 24.24527025991871, 22.50741904781711, 38.44877081532633, 40.3494062731343, 33.87164723488593, 26.9271614474635, 50.41260388589675, 53.88299542088663, 29.811474392491004, 0.13349566248155412, 0.05740885555203404, 0.09284774968100172, 0.05664598902747516, 0.07313228542766265, 0.026854346506297592, 0.10249762300161586, 0.03643821369135573, 0.042137616734591224, 0.03950846043505496, 0.06851729516300463, 0.014172967508315079, 0.061869210969176025, 0.02435781917865238, 0.03402045552408503, 0.05234547019485505, 0.009359837220531077, 0.09229396770317709, 0.15404241640240918, 0.2053025238696606, 5.287574154715385, 70.34084489268642, 57.58367715343353, 44.911169851979906, 35.56711919846074, 61.52905987155054, 27.73593652632929, 37.59723209565686, 49.204670767630304, 44.671615016075876, 12.528560238499796, 44.04938590142035, 64.37863826751709, 61.44781189580118, 67.548995940916, 66.67768063083773, 16.09252481691299, 0.06737082160168117, 1.3249944174481978, 1.0875351078087285, 0.40844535395022363, 19.07645517779935, 78.11559446396367, 63.028232897481615, 69.92075904723137, 60.087996759722316, 56.21637421269571, 55.486821205385276, 69.99391125094506, 66.12786631430349, 67.78289471903156, 64.07285813362368, 62.6399927754556, 53.487506758782175, 63.41373520512735, 61.907266570675766, 71.02081914101878, 54.089684717116825, 54.63702009570215, 56.033223059869584, 53.009726770462535, 52.786822395939986, 52.73859293230119, 51.663792902423495, 55.83430005658058, 58.58507787027667, 59.01185920161586, 58.516663889731134, 63.8512755978492, 58.06911360832953, 56.66421867186024, 53.9300246392527, 58.36995155580583, 56.307361433582926, 50.22177273227323, 57.54428871216313, 59.8304460894677, 60.332227060871745, 61.01700229029502, 58.27892118884672, 47.99822815002934, 44.107233016721665, 44.40081457937918, 45.750525689894154, 50.44353569707563, 52.73083840647052, 54.198401051182906, 51.94304604684153, 53.98333357226465, 54.881540652244325, 47.152365099999216, 38.26900859032908, 32.74465810868048, 30.49394326825296, 25.449592836441536, 25.431108667004494, 19.35092106942208, 19.274548599796912, 11.040261003278918, 14.56289948955659, 17.10515037659676, 21.06786800969032, 34.28652025038196, 41.69042148897725, 43.67966328897784, 51.15673242076751, 53.011436923857666, 51.83369036643736, 48.796277507658935, 47.93188910330496, 42.344131546635786, 34.875067972367816, 26.086713229456258, 27.44376309456364, 35.21421963168729, 49.94621053818734, 55.38139573989376, 53.01344909975606, 51.645859825995664, 52.26393122826853, 50.369630398288855, 50.13057762576688, 50.85973839606009, 55.6341689632785, 56.99742794036866, 56.37031155247843, 55.40081147224673, 56.33504552225913, 53.25464740876229, 43.509275528692434, 45.07088484302644, 43.02812622439477, 48.89823167554794, 45.89300970877371, 48.56154718706685, 43.66925724091069, 41.509102083021595, 32.01784879930558, 44.90208956503099, 57.1624695101092, 63.34980449368877, 58.842510869426114, 62.03469653283397, 59.03839795820175, 56.266964943178245, 56.24894557460662, 62.2284733864569, 61.34945061899001, 63.717381569647024, 62.893146468747055, 67.04195114874071, 60.942591005756015, 64.15713417914607, 60.496460622356786, 61.477594452519575, 1.9570051878690722, 1.134740832832552, 1.5072960094098122, 0.4156728419325044, 40.66806354830342, 73.16837172354423, 54.788035269706484, 68.91298447885822, 59.749566816514545, 65.6206097141389, 9.283646152865503, 25.702454313155144, 29.723472095304924, 28.637983606707667, 31.393270184916837, 39.71696330655006, 46.25708410816808, 26.687059440920432, 56.843243491265085, 64.91685021308162, 33.90363024127099, 0.2561108233226884, 0.03828262782565529, 0.14416443274146126, 0.12106286752368174, 0.01547277452529318, 0.022716115739557053, 0.05965119107596337, 0.08283319552579234, 0.18891666925722556, 0.19505885579893667, 0.12060799515776097, 0.1868542686345116, 0.2028456952182516, 0.2531706085128169, 0.14825051590319605, 0.21182182485297804, 0.31372578333943124, 0.224575013102543, 0.3607231630913673, 0.5023294290707958, 8.28436645769304, 88.55938357691612, 65.50411924239128, 69.21216718612179, 37.69141212586434, 76.44242117481848, 57.784518195736794, 32.89750110718512, 47.32295290116341, 54.24749343625961, 20.68045158540049, 50.908254192721465, 69.51816697274485, 70.86870178099602, 71.50499651508947, 76.60436799449306, 17.127762840640163, 0.08385065221978773, 2.755295158393922, 2.1463258612540463, 0.750586104489142, 24.511681564392585, 81.0938109121015, 65.26094798118838, 73.13409805297852, 65.33341769249209, 57.82797805724606, 60.49927296177034, 73.09675708893808, 69.36220568995323, 71.28500646160495, 66.30856990814209, 62.12223991270989, 56.46405227722661, 66.34383986073156, 68.45422406350413, 72.04963330299624, 58.33951788563883, 60.311528713472434, 58.24077613892094, 54.57247749451668, 52.21865138699932, 54.612226793842936, 54.7416179410873, 58.48356300784696, 62.675325485967825, 60.86777179471908, 62.15691366503316, 69.06605105246268, 61.927682507422666, 60.89886834544521, 59.407445922974624, 64.1621587353368, 61.695168325977946, 55.24096312061433, 64.08327594880136, 63.00007420201456, 63.981698328448886, 65.11391401290894, 65.65048248537126, 58.57636236375379, 54.29956682266728, 56.271777691379675, 53.709210888032, 55.18411228733679, 60.60753037852626, 64.3898719356906, 59.74070225992511, 61.33822087318667, 66.17986125330772, 59.70525580067789, 51.75481542464226, 46.58406465284286, 46.64347287147276, 39.91221497135778, 41.56204623560752, 40.49380048628777, 39.440734309534875, 25.437051057815555, 29.67234988366404, 26.217632139882735, 30.205317620308172, 48.84869998501193, 50.48970983874414, 52.67205776706819, 59.851364089596665, 59.863935285998934, 57.43210892523489, 52.739706885430124, 58.356921442093395, 52.015433388371626, 54.60138144031648, 43.14541293728737, 41.95808010716593, 44.65756116374847, 56.0308970943574, 56.87137865251111, 56.88497358752836, 54.907518509895574, 56.45251658654983, 54.84028908514208, 52.35088233024844, 55.17702848680558, 57.85532482208745, 60.07089522577102, 59.92817586468112, 58.99867219309653, 58.997915175653276, 57.78431031011767, 41.8867321937315, 48.60538359611265, 44.78613645799699, 47.671631997631444, 45.54467578088084, 49.16799660651915, 46.32826728205527, 45.32978873099051, 34.883308872099846, 43.51002862376552, 58.766754211918006, 62.35369897657826, 64.32219536073747, 63.51059421416252, 63.40425091405069, 58.524540009037146, 58.850657632274014, 64.65460446573073, 62.51602626615956, 68.19073492480864, 65.96275021952968, 70.11825038540748, 63.041047280834576, 66.14733695983887, 62.20590799085556, 68.01828399781259, 5.663461752476231, 4.36802496833186, 3.7496311962604527, 0.29395648608765296, 42.13433965559929, 80.90968701147264, 60.78414294027514, 72.50001553566226, 63.26952142100181, 73.75176937349381, 15.743105373074933, 27.520233623443115, 31.726457880389308, 34.456790339562204, 51.50672551124327, 60.58509049877044, 49.26639710703204, 35.88041459360431, 68.97187494462537, 72.6717290570659, 54.17722809699274, 0.24569170579554575, 0.20396177807161886, 0.2577363393239437, 0.2879494680993019, 0.16352456243288133, 0.13695419705923528, 0.2811281599344746, 0.2061866812648312], [0.010460427860849568, 0.020485164282182534, 0.049215771197792024, 0.04064628869415291, 0.06270731115833887, 0.020573907907331185, 0.07536206860095263, 0.0940670169168903, 0.08892210065236977, 0.10605119844718326, 0.07327130740328182, 0.11060454927745367, 0.14201330381535715, 42.804421686357074, 57.09242774594215, 31.75235729063711, 20.21641165979447, 38.24566656543363, 56.14822303095172, 17.79732123497994, 32.72688388824463, 19.139695552087602, 2.448410632148866, 41.887893215302505, 64.90854655542682, 55.131525070436545, 55.03570548949703, 67.37095955879458, 30.891038140942975, 0.17172392487766283, 0.49003662902020645, 0.36390236669009735, 0.2405133038278549, 10.526571716031722, 69.95918258543938, 61.79152527163106, 62.87332673226634, 57.013737155545144, 53.875107534470104, 56.7432269742412, 66.86254978179932, 64.68767004628336, 65.5509719540996, 65.35954852258006, 62.30067637658889, 54.12711197330106, 58.839188621890166, 60.55929307014712, 65.88964508425805, 56.51152472342215, 59.212264860830004, 59.74467169853949, 54.08376193815663, 55.187367854579804, 53.88033997627997, 52.989726604953894, 54.107696240948094, 56.810083773828325, 58.68088568410566, 57.974082423794655, 58.90976775077082, 58.02375531965687, 54.91687336275655, 56.5330389238173, 53.746814650873986, 54.75677397943313, 50.17497101137715, 53.18577451090659, 60.569538301037205, 61.13868990252095, 57.84929221676242, 48.314567304426625, 39.86458563035534, 37.53022624600319, 38.14941160140499, 40.12677254215364, 41.63813629458028, 48.34542066820207, 44.20169937995173, 43.96942446308751, 40.014137760285415, 35.86568609360726, 30.090374523593535, 21.034576892852783, 15.130424288011367, 14.618344153127364, 11.985637526358328, 13.466657823131932, 9.441887313319791, 10.048059225082397, 3.8865050000529138, 5.729280104560237, 17.255359503530688, 15.332195912638019, 16.751999778132287, 21.6467902352733, 26.20010698995283, 37.67460084730579, 43.57940358500327, 45.4028271859692, 41.61006781362718, 43.063117688702, 43.32242950316399, 38.441467362065474, 30.488053829439227, 23.13959333204454, 25.926419688809304, 33.71913763784593, 44.64623335869082, 51.593229463023526, 52.31640469643378, 50.140626738148356, 46.48590341691048, 44.95418256328952, 45.83111078508439, 52.78728523562032, 48.658363050030125, 53.22430003073908, 49.96447309370964, 58.41399585047076, 58.584552272673584, 46.043099203417384, 47.93524272980229, 45.81547621757754, 42.48040645353256, 41.007270120805316, 42.55570419373051, 45.61435668699203, 48.92025186169533, 59.559759401506, 53.79243181597803, 47.23938680464222, 64.15887571150257, 56.88740937940536, 60.13246074799569, 53.082216093617106, 51.56426668167115, 53.57141410150836, 60.26720200815509, 60.84795205823837, 60.62568703005391, 58.675849360804406, 61.2926507765247, 56.7885381944718, 58.60315607440088, 61.036080698813166, 38.463354187627, 0.7630727860716082, 0.7994519114013642, 1.3241525787499644, 5.584250467438852, 37.03119093371976, 40.903943123355994, 58.43228586258427, 63.296758359478375, 58.84322866316765, 52.31427877180038, 4.998437618055652, 22.924331695802753, 21.120508178587883, 27.266332718633837, 44.54613447189332, 44.66925767160232, 29.137666110069524, 24.83574386565916, 44.69404312872118, 56.28530202373382, 17.78774084583406, 0.22272510994826594, 0.11694726699422445, 0.042659414541577144, 0.06365372085823648, 0.07466364922302385, 0.025212685202038097, 0.048486957281467416, 0.06080513399454856, 0.04199575640321259, 0.036973732133065505, 0.06518144190551774, 0.08462813187150225, 0.049700946171557715, 0.08442979170790604, 0.06795975935435103, 0.06987782901213055, 0.08735345901861306, 0.04764981853264955, 0.038369467722312096, 0.04384910312270926, 0.2333087371962686, 48.432301167518865, 69.9885219143283, 32.45389869136195, 24.120191758678807, 55.87094283873036, 36.103605301149436, 27.491621894221154, 49.3862255157963, 23.636530176285778, 4.700068312306558, 44.47132310559673, 71.74311576351043, 60.44972558175365, 56.49923593767228, 71.92966368890578, 34.5245296724381, 0.764565738218446, 0.8260991460373326, 3.251838539877246, 0.48949616931138507, 12.966504635349398, 75.14388915031188, 63.42128184533889, 67.3067895827755, 60.85164300857052, 55.44507934201149, 59.64281558990479, 67.95143112059563, 66.68881231738676, 69.16913878533148, 65.76968331490794, 61.908733537120206, 55.933457574536725, 61.683365914129446, 62.58368322926184, 66.08448490019768, 59.29432084483486, 63.1926311985139, 61.057014388422814, 56.74363097836895, 56.968755414409024, 55.50649973653979, 56.27738275835591, 58.4850025177002, 60.55772804444837, 61.01255040014944, 59.20429852701003, 61.10445937802715, 59.6734453785804, 55.84491791263704, 56.82280402029715, 55.10777511904317, 56.884444067555094, 50.52210469399729, 53.88347395004765, 59.21965068386447, 61.423806990346606, 61.22440938026675, 52.37466758297336, 51.294607654694595, 47.260257736329116, 47.46229902390511, 49.915619973213445, 55.119404946604085, 55.363737229377996, 53.817382012644124, 54.36383485794068, 53.60232630083638, 51.938919713420255, 43.6153442628922, 35.994912501304384, 29.638156621686875, 25.3902748323256, 25.422701066540135, 25.0713018063576, 21.7681287565539, 16.611614227294922, 12.694629469225484, 13.069584523477863, 14.042334287397324, 22.514965688028646, 32.23237695232515, 34.8370837396191, 39.37461099316997, 48.47504323528659, 51.83694593368038, 51.96629393485285, 47.298787178531775, 48.26458061895063, 49.53379684878934, 44.01848939157302, 34.59575207002702, 34.635536670684814, 33.80071117031959, 44.73156844415973, 49.33475617439517, 52.27979721561555, 52.8038650943387, 51.920590477605025, 50.33237964876237, 47.717409979912546, 49.66616507499449, 55.760555574970866, 53.86511333527104, 54.17552971070813, 54.76429708542363, 58.85332092162102, 57.999130679715066, 47.7871104978746, 47.451645866517104, 46.50273822969007, 42.03907312885408, 39.135675891753166, 40.400620660474225, 45.95911341328775, 48.84930403001847, 60.047337470516084, 54.92098400669714, 47.600315463158395, 65.53728288219821, 57.994996501553445, 61.855157882936545, 54.584291673475704, 53.88618038546655, 57.98420998357958, 64.68301419288882, 62.70498644921088, 65.68589364328693, 63.723119997209125, 65.83197839798467, 62.35368328709757, 63.26750140036307, 67.44510804453205, 38.29354301575692, 1.9479245331979569, 3.091750433368068, 1.9034346817962586, 9.535292675418239, 45.63002655583043, 48.88777855903872, 62.628880700757435, 69.12305093580677, 64.27582902293052, 62.249803235453946, 4.489330639762263, 29.75736333477882, 26.43217206001282, 33.19766636817686, 31.43672808524101, 45.46517325985817, 39.35359885615688, 24.30929118587125, 51.270504689985714, 67.32028253616826, 23.653984723552583, 0.26933619752526283, 0.1362182317121375, 0.043976564831551046, 0.08730000140325678, 0.05545127490955976, 0.09601766829408946, 0.054441145846560124, 0.05485418981181518, 0.15051118008071376, 0.12389154759265723, 0.2220487615634357, 0.2871334618858753, 0.15037215044421537, 0.1568837752265315, 0.27152086578069196, 0.2826024808229939, 0.20792107368188523, 0.17918926783867423, 0.19407319175379892, 0.21020128842323058, 1.0035429438275676, 66.87714099884033, 73.64565357085198, 46.247905761964866, 29.89920408495011, 56.20883541722452, 80.13679181375812, 26.27272771250817, 41.73279877631895, 29.147583823050226, 7.892005885801009, 50.58596872514295, 75.97992666306035, 64.40642433781778, 64.22572858871953, 74.63263173257151, 37.27236570850496, 1.070098946652105, 1.6722229723968816, 2.4167127330457014, 0.851185522492855, 16.044581686296773, 78.22829200375465, 66.9154860896449, 71.99872093815958, 63.56333832586966, 57.7112679327688, 62.89264048299482, 75.3290799356276, 68.24866048751339, 70.48850644019343, 68.45423190824448, 67.47082310338175, 59.46692474426762, 65.33771268783077, 66.91002615036504, 69.56043443372174, 60.069047789419855, 62.76623818182177, 61.14445578667426, 55.93107669584213, 58.10304211032007, 58.11045931231592, 55.9513278930418, 58.576601628334295, 65.3800585962111, 64.2545070186738, 65.23098107307189, 65.72818071611466, 62.78302984852945, 60.20811150150915, 61.55992892480666, 60.42267691704535, 62.96208604689568, 55.64628124237061, 57.92172270436441, 63.535764063558275, 64.50368342861053, 63.77962958428168, 59.84711224032987, 58.09136521431708, 57.004378380314, 57.47882827635735, 54.50265146070912, 60.53766904338714, 61.23953011728103, 58.99125891347086, 60.048259227506584, 59.05131824554936, 62.84943949791693, 58.12917294040803, 51.620831181926114, 44.152069630161414, 43.1859584777586, 41.4212998267143, 45.45549285027289, 42.06888314216368, 42.44134749135664, 28.120140529447987, 26.05031559544225, 25.11078046214196, 31.627129739330663, 50.81233655252765, 46.78697278422695, 50.03557389782321, 58.74444377037787, 58.76168650965537, 58.52756415644, 51.631311755026545, 52.92789043918733, 55.96407559610183, 53.218534146585775, 47.84372598894181, 46.38943664489254, 45.12574311225645, 49.11084375073833, 50.9028648561047, 55.38235672058598, 55.65343564556491, 55.22465390543784, 54.5853546357924, 51.365096569061286, 51.65501463797785, 58.356670410402366, 55.77220893675282, 57.65841007232667, 58.55453437374484, 63.59704717513054, 60.3576087182568, 49.29239065416398, 47.9743173814589, 49.51520873654274, 43.614602934929636, 43.283072440854966, 46.78700024081815, 49.607298143448375, 48.67068321474137, 55.88174896855509, 57.65871209482993, 53.42739251352126, 68.47741311596286, 61.085749672305205, 66.79635586277132, 58.214206003373675, 55.638663999495975, 61.79956220811414, 67.39262673162645, 65.93512104403588, 68.81586659339168, 68.22086657247236, 70.23599993798041, 63.99547761486423, 67.257383408085, 68.69297089115267, 47.24163824512113, 2.23444166202699, 4.930942943019252, 3.104110557225443, 10.508638639603893, 46.51346983448152, 52.76074647903443, 68.16303514665174, 75.16397953033447, 68.37602769174885, 69.06445857017272, 10.163597541470683, 30.157815756336337, 30.12662506872608, 40.36172643784554, 59.517856720955145, 66.34757395713561, 42.42104138097456, 36.292800826411096, 59.45448298608104, 79.35759728954685, 34.534927875764915, 0.3095931373536587, 0.2387116948563245, 0.1763639662174448, 0.3655124996458331, 0.217239139000735, 0.2313524091075505, 0.1533937697569209, 0.09946323300321257], [0.037748530477045045, 0.03206269485094855, 0.032115206347718354, 0.035415061133643316, 0.05485628889272771, 0.09027246851474048, 0.06258757544621345, 0.12104347017743897, 0.029868373887673504, 0.03706426457351735, 0.1568296894190773, 0.18163095859269943, 0.1780839255380054, 27.166545660265033, 62.726528106197236, 49.16169335765224, 24.421478817539832, 30.731719309283843, 59.142646712641564, 29.419406037176813, 18.30987499606225, 26.6157684018535, 1.9263009967342501, 30.97818143906132, 72.7894550754178, 67.59658998058688, 61.81455350691273, 60.68541296066777, 46.05592927625103, 2.0061798201453303, 0.9144401766600148, 0.9722084768356817, 0.07292135077859126, 4.5661134873667075, 59.84801046309933, 63.67627513024115, 62.97868551746492, 58.87549408020512, 55.699068500149636, 63.371601104736335, 69.85585951036023, 64.98615457165626, 66.85348126196092, 63.481564752517215, 61.81851117841659, 55.405349654536096, 60.96142622732348, 64.22555600443195, 63.65369404515913, 60.73920434521091, 63.080059174568426, 59.552655989123934, 56.47328553661224, 57.138154737411014, 52.55621448639901, 47.2927192718752, 58.57942573485836, 56.754350816049886, 58.01040749396048, 57.90452311115881, 57.86601720317718, 54.10868467823152, 53.16187550944667, 56.41543449894075, 55.282210765346406, 54.3055288253292, 46.39596739122945, 47.24201479265767, 59.3928272493424, 60.42882327110537, 52.478861424230764, 50.433294388555716, 44.75834646532613, 43.99358234097881, 45.56772362801337, 44.064620387169626, 43.77241165407243, 48.17690387848885, 47.15973915592317, 45.87018151437083, 36.56630769852669, 34.17581919700869, 27.625035432077226, 21.773123894968343, 17.55722118962196, 15.717195176309156, 13.324442486609183, 15.156330562406971, 15.170201043928824, 10.509920274057697, 7.496983005154518, 3.809290936877651, 11.166965326955243, 16.22038918156778, 15.102557809122148, 22.106419455620554, 25.539568085824293, 35.90237202182893, 40.74779356679609, 46.517772674560554, 43.5505388629052, 45.52955112149639, 47.409786332038145, 41.623043014157204, 38.25475861949306, 33.154728181900516, 30.943670465100197, 34.645197468419234, 43.89306768294304, 49.80660946138444, 49.45155259101622, 48.2881893650178, 44.82178688049317, 43.3242416381836, 47.33348446507608, 50.73857638143724, 51.21100233447168, 53.61179490243235, 51.84774814113494, 50.50622301716959, 51.93901385030439, 47.80850702716459, 46.184692844267815, 46.80696902736541, 46.748400195952385, 44.28052725330476, 42.21119457675565, 45.2031393204966, 45.29279293552522, 44.708112670529275, 45.60663354012274, 39.98200178146362, 57.59911168006159, 58.98797196726645, 60.229323679401034, 53.56731130230812, 48.5579974420609, 56.93205379670667, 57.70578838163807, 60.18837805717223, 56.812809821098085, 62.04678920007522, 58.27476347646406, 62.97452388271209, 58.235924167017785, 61.519402996186294, 10.709636576714056, 0.8638517137977385, 1.3071156413324418, 0.692224913547116, 13.94620680039929, 58.344871920924035, 58.595228964282626, 58.66170137159286, 54.773589180361846, 64.68097848276939, 25.38501297273944, 6.688400612723443, 45.302877349238244, 13.105468326999297, 31.17043249068722, 39.19784938135455, 51.03270315354871, 26.0956758453, 48.060154530309866, 48.48844989653557, 52.3640222703257, 10.752872863123494, 0.36948218340835265, 0.15353296793276264, 0.024994212247791792, 0.11175219495330127, 0.03141194529410812, 0.035943860984257156, 0.0038158123695006176, 0.09970247460108611, 0.03839059259682413, 0.02068976146890031, 0.0034928806933514295, 0.038469074474227045, 0.03044138658761738, 0.12700142023423988, 0.054952996001849254, 0.16161789216341513, 0.06633168461942865, 0.0292920095530609, 0.10637385935913171, 0.2007487593519111, 0.29975013326733346, 30.38681157173649, 72.27616586992818, 55.11827138162429, 19.440762958218976, 45.33748442126859, 54.958148464079834, 26.992310054840583, 29.60703653673972, 30.088772235378144, 3.7545478872714506, 33.98745521422356, 79.61170411879017, 73.51698413971933, 70.17939229165354, 65.107700978556, 52.811513716174716, 2.903224407665191, 1.301173127947315, 6.1495042135638585, 0.11332721809946722, 4.236098499067368, 63.12540569613057, 69.08434498694636, 68.64325092684838, 64.53306982594152, 58.77710534680275, 66.1376565502536, 72.62700619236116, 66.26249774809807, 68.96151988737046, 66.82407917514925, 64.6545103288466, 59.15771253647343, 61.955213623662154, 64.65276487411992, 66.07132927063974, 64.54737863233014, 63.192340943121145, 61.583549437984345, 56.31866962678971, 58.413183919845096, 53.46696138381959, 50.36308004010109, 62.913919341179636, 62.48299990930865, 59.215296852973204, 58.43061101052069, 61.632755571796054, 55.10157385180074, 54.27391452174033, 57.4692851497281, 58.81130449233517, 57.82274953780636, 49.16720428774434, 50.20153722455425, 61.61291622346448, 62.10192203521729, 56.79243703042307, 54.00729140927715, 50.77749806065714, 50.44606954820695, 51.4979080230959, 51.575900431602236, 54.90217624172088, 56.71248735920076, 58.12367377742645, 56.525770771888, 51.39384754242436, 49.0349772668654, 42.265958709101525, 31.80535831759053, 27.803840598752423, 26.785924742298743, 25.350464736261678, 26.17904386212749, 24.11822469003739, 20.328805215897102, 14.956574055456347, 10.00745386846604, 11.207618732606212, 27.63339988646969, 30.30311211462944, 36.99762328978508, 40.22650664852512, 45.500074509651434, 50.04259886280183, 51.932514482928866, 47.62894092067596, 49.782659469112275, 52.923815096578295, 49.8205848663084, 42.98002227660149, 37.38774614949381, 39.45145414721581, 43.88990233021398, 46.76102630553707, 49.645576553960005, 50.15169566677463, 50.42076633822534, 47.58355517541209, 46.78891435746224, 48.66512913857737, 52.820911715107584, 55.00878626300443, 57.92759841488254, 56.919937595244384, 54.546762435666984, 55.409679951206336, 49.73304933117282, 46.80418806691324, 46.8704015977921, 46.64997223884829, 44.89927330324727, 43.48982841737809, 44.884607561172984, 48.678524032715835, 48.08606570766818, 49.77431266538559, 47.71128716007356, 58.42912050985522, 62.14261662575507, 60.58212126455, 56.87302604798348, 49.46088783202633, 60.039912423779896, 61.33715006612963, 63.3894008205783, 61.364618424446356, 66.93885557113155, 61.84812115084741, 65.99313289888444, 61.00111276872697, 64.48488743074479, 7.764957864438334, 2.7447817354433, 6.833746981236243, 1.4894966612900458, 18.9838009495889, 64.3869693817631, 63.40659649141374, 64.58320948385423, 60.62213728504797, 73.81080104458717, 27.30734305997049, 10.004569945796844, 59.74982569294592, 16.879410128439627, 36.292337986730764, 25.50289784708331, 55.290090807022594, 34.421237976320334, 46.44504016445529, 58.111710548400886, 62.32203760454732, 12.025739839000087, 0.22460020207349332, 0.1974137487911409, 0.025646775517792954, 0.032155479589897784, 0.05030191150463877, 0.06397648136161509, 0.06450582130421555, 0.0720737970644428, 0.155809490130313, 0.25251993939520856, 0.127773207852677, 0.2795198043027232, 0.13902594395462545, 0.35745267245558004, 0.18172010058356872, 0.2581674323206948, 0.13253212305566958, 0.11989547210114619, 0.4758778839342056, 0.3572179737590975, 0.4644734087970949, 43.96851447320754, 82.77184794026037, 66.6883965461485, 36.0698180044851, 43.99712031887424, 83.13480054178547, 39.37586615162511, 24.927982322631348, 34.73040311567245, 8.11219156749787, 40.57069070877568, 82.19289825808617, 79.12164318946101, 71.67344662450975, 72.87398999737155, 55.67370645461544, 5.141397714614868, 1.7845111148011301, 4.584914878491433, 0.28645734332742234, 7.655441366857098, 72.18752030403384, 71.2243038608182, 75.14889409465175, 65.14779936882758, 62.520576215559444, 70.26245240242251, 76.03831506544545, 70.9222892022902, 70.57535556054884, 66.34864084182247, 66.80663247262278, 62.28086840721869, 66.53430231155889, 68.52225365177279, 67.25445731993645, 63.40658864667339, 66.20554493319604, 62.84929437022056, 58.1703225258858, 60.8813431955153, 57.71718286698865, 49.76020389987577, 65.87364965869536, 64.24518354477422, 63.77481683608025, 62.907784754230136, 64.33579814049506, 58.242611808161584, 59.340428306210434, 63.690599626110455, 65.18219071049845, 62.00700852178759, 53.52928000111734, 52.12394968155892, 66.3840441549978, 64.20413201855075, 56.81262939207016, 59.23790931701661, 55.442470965846894, 56.1721141876713, 60.355086634236, 57.73230360400293, 55.41796007464009, 62.22561790097145, 65.325949499684, 64.3185632459579, 58.29074713491625, 61.28850090888239, 57.717053428772964, 47.07032872784523, 45.54568383001512, 42.639423262688425, 44.761217640292266, 46.85195469087171, 48.36891958790441, 42.56121904619279, 35.087621212005615, 22.473684703150106, 16.458022056087373, 36.723206427789506, 44.33390678897981, 51.018488484044234, 50.60293297613821, 52.546573300515455, 56.626677666941, 58.49365134393015, 51.75119115460304, 55.7133420052067, 57.62183789283999, 55.45556775985226, 49.58590945889873, 48.38373438004525, 47.42118866212907, 50.458221051000784, 48.57805252075196, 51.199709830745576, 52.7123091297765, 54.40208188949093, 52.150323698597575, 51.2593690810665, 53.08455774860998, 53.73033677378009, 56.908547032263975, 62.68631204482048, 59.06082214847688, 58.08057477397304, 56.72705896439091, 52.77709491791264, 49.95085462447136, 47.970375399435724, 46.58801055723622, 42.91962169831799, 43.87447957069644, 48.15301272176927, 51.875236111302534, 53.03632044023084, 52.33660098045103, 47.41442649595199, 63.097192087481105, 63.2747930865134, 65.58722642160231, 58.13158127569384, 53.570688463026485, 63.62038135528565, 64.03588979474961, 64.73551511764526, 65.4585373786188, 70.93342088883924, 64.39873256990987, 69.43233766863423, 60.99815530161704, 68.65375503416985, 15.762800574302675, 2.16515054145167, 6.936026705849556, 2.306610821716247, 21.89288954580984, 70.86392433412614, 70.72512734320857, 67.45289787169426, 68.41238806324621, 74.64373204015916, 37.97859238040063, 11.559618115425112, 58.53179639385593, 19.702218347980132, 43.49785358675065, 55.95330868997882, 73.0936505717616, 37.69631901094991, 63.85375845816828, 66.98721839535621, 78.46179070011263, 23.785754788306452, 0.6179564890842284, 0.34430933094793753, 0.17568656063127905, 0.32078810276523717, 0.20800044039084067, 0.2512098524358965, 0.12124394006546467, 0.2195450942963362], [0.018419435007437583, 0.09171885017666126, 0.05599422057369544, 0.033449946016433744, 0.024695005117645188, 0.17367682089248013, 0.06091201092086493, 0.1525352916289722, 0.07103257632303624, 0.08455169927929679, 0.14662339111729977, 0.19568718579267302, 0.32999240402733127, 13.369067292059622, 62.55661887507286, 44.667104290377715, 41.58064219259447, 25.74482179457142, 36.30948266675396, 46.919854840924664, 20.77411190156014, 29.577718780886745, 4.203774246477312, 15.300661037045142, 66.48023636110368, 61.36875652497815, 59.69402605487455, 35.14263245367235, 63.701727390289314, 7.391882115794767, 1.4258786362986413, 3.4404891008330933, 0.5057903078775252, 1.0438022738502872, 40.085242486769154, 70.28836357978084, 59.48946660564792, 62.101294455989716, 62.98306288257722, 63.58082817446802, 62.65174811886203, 68.08095562842585, 63.3524638606656, 65.48081644119756, 60.27814149856568, 57.741870264853205, 60.06218756398847, 64.03752542311146, 59.47232977036507, 67.92535520369007, 59.22865252340994, 58.14381514826129, 58.923856904429776, 58.20143868846279, 53.30743074417115, 52.01965385867704, 59.51832348300565, 56.24566647314257, 58.32455404343144, 56.77743396451397, 52.50425877109651, 54.83290718447778, 57.13200446098082, 54.79666840645575, 54.81497410804995, 52.19481514346216, 48.73562589768441, 43.86843127589072, 48.586850397048465, 52.10419270300096, 52.59233951568604, 47.58660285703598, 44.50118410971857, 44.943176392586004, 44.02318054629911, 46.388393294426706, 45.27134933779317, 51.916507290255645, 45.81579785193167, 43.1992906139743, 40.85524297529652, 32.86960913288978, 26.41613741074839, 19.64521650345095, 14.989168951588294, 17.5231259868991, 18.032200605638568, 20.29177019673009, 17.05659535623366, 18.868510723114014, 4.785536758361324, 1.860715045082954, 11.206633237100418, 19.311095283877467, 18.01124926536314, 24.32673200484245, 24.068194858489502, 34.290415163963075, 43.11657959415067, 43.89823344445998, 44.448334094016786, 49.105438724640884, 49.76285934448243, 45.71018803504206, 42.99085586301742, 39.889304407181285, 39.35233193059122, 42.792191736159786, 45.09137138243645, 44.674964720203036, 42.900586435871745, 42.00556039810181, 41.200548833416356, 41.58530196835918, 47.75375073955905, 48.378031253814704, 52.1549677848816, 51.74809640453708, 51.35664386133994, 55.44843296850882, 55.39738332071612, 54.55752934178999, 45.33529573871244, 45.7844816484759, 48.02656335215415, 47.834669236213934, 51.363621757876494, 44.857264718701764, 47.27724159917524, 50.341228515871116, 54.96385159031038, 61.05762235579952, 58.55030605869909, 59.0953899968055, 58.10408153841573, 54.16784970991073, 53.0498133936236, 58.517448363765595, 56.797602791940015, 61.46989483987132, 60.71827065560126, 59.788213929822376, 61.137544570430634, 59.386320037226525, 63.3439915410934, 31.201685936220233, 0.5694819998837287, 0.743653682931777, 1.1572971579528626, 0.656201498162362, 22.862456306334465, 62.48730274938769, 51.46585441404774, 62.37507589401738, 60.191492419089045, 63.613579965406856, 16.29262943421641, 15.23835026448773, 26.26997224746212, 13.902037970481382, 36.97749760843093, 38.064884524191584, 46.46231428269417, 19.679170500847604, 37.08653949922131, 48.135107101932654, 48.753260873979144, 1.8224890962723763, 0.03416347264822933, 0.08977704711498753, 0.044061114125314264, 0.1295862391951584, 0.013241317449888636, 0.11794020887464286, 0.013573748855701378, 0.031059811064492793, 0.07856512817764476, 0.049106504077151905, 0.09747610817993842, 0.07013721872241267, 0.06626148798292683, 0.1724569024818559, 0.016089602666456374, 0.21458657488467234, 0.04419391163654866, 0.06938827584587759, 0.22545579971084673, 0.29752127706043185, 0.4842708061539358, 15.997580905114452, 70.78535925957465, 53.89280134631742, 35.16229529534617, 31.213047081424346, 38.06557486134191, 36.01618351474885, 33.64518527061709, 39.55820929619574, 8.080768969751174, 15.15008418790756, 74.06693966157975, 64.5769258468382, 64.94567963384813, 41.95598948386408, 73.13176816509616, 10.169261443999506, 0.7184261624370852, 5.1296051086918, 2.192702740430832, 0.04199717749631213, 45.121295144481046, 73.57659632159819, 64.91081760775658, 65.38318472523844, 65.90426768026045, 64.31833574848791, 65.45297153534429, 68.54632131515011, 66.96630431759742, 67.58632121547576, 63.669458050881666, 59.098571039015255, 61.505278541195786, 64.35855573223483, 64.54711975589876, 71.1282842389999, 60.87511839405183, 59.700823522383175, 57.77965053435295, 58.459185477226015, 57.47727109539894, 57.88684891116235, 62.61983571514007, 59.5114593352041, 60.67131203989829, 58.149239786209606, 52.857958501385106, 55.58908131814773, 57.106152119175086, 57.373822504474276, 56.88678964491814, 56.31696339576476, 51.69945509203019, 45.290859207030266, 48.88209896702921, 55.1464928350141, 53.04777768350417, 53.83152215711532, 49.108647223441835, 49.444849260391734, 51.10970712477162, 52.29754201827511, 53.27238044431133, 59.95204740954984, 57.1072974512654, 56.12290805385959, 53.155650707983206, 47.80920128668509, 40.16742006424935, 31.793432351081606, 28.11359017126022, 24.61901330178784, 27.747705598031324, 30.09182187818712, 30.199165382692893, 21.89532533768685, 18.65787748367556, 7.558778966626814, 14.688129982640667, 34.359088020939986, 27.880128737418886, 37.787976957136586, 36.60341724272698, 43.82280234367617, 51.332297709680375, 50.67431226853402, 50.150985717773445, 52.83657766157582, 53.133603065244614, 49.82295790026265, 46.65971148398615, 44.51804637908936, 45.86303495591687, 47.716711798021876, 47.248063087463386, 47.23676666136711, 45.5047264406758, 44.65060287906278, 44.21555711377052, 45.338512082253736, 48.6518636826546, 50.569612441524384, 54.98216121427475, 55.519239594859464, 56.924181599770826, 59.497138761704974, 56.351417495358376, 55.20068822368499, 45.84035581158054, 46.69572276453818, 47.45848648009762, 46.83304886664114, 48.703788018995716, 46.96251846128895, 48.43891036125922, 49.75788185673375, 53.474009883019235, 65.99552554468956, 61.58331801814418, 61.44168123122185, 59.183557033538825, 55.754852448740316, 56.02953995427778, 60.885092981400035, 61.225542945246545, 67.54596002640264, 61.84000968933106, 62.55226896655176, 63.095466244605284, 60.627569767736624, 62.4946258144994, 30.301062676214404, 0.5473366656130361, 2.468377947807312, 3.0814113107419785, 1.6186294223993056, 30.59177306390578, 66.23937929830244, 58.65241319902482, 66.02703786665394, 63.61409379589943, 69.37277255519744, 17.36432294691763, 21.373312780933997, 35.67807128352504, 19.156695104414418, 35.656357042251095, 26.20852831871279, 55.87008776203279, 19.946848730887137, 39.00077773678688, 57.813665328487275, 60.30404483118365, 2.7590782844251205, 0.09099497369700864, 0.14635999476717365, 0.09664502535616198, 0.09373030595241055, 0.026099828424893563, 0.017896729386261395, 0.053114733553581664, 0.043795814046696316, 0.13529670454802054, 0.24051506583008075, 0.2503889126162375, 0.28370705703573845, 0.17905419121586508, 0.29597577128198843, 0.11804566087742006, 0.48511411574098373, 0.22581154029936562, 0.22243810276831352, 0.34423186413703427, 0.4083743835649183, 0.48350058135486423, 24.746957094438617, 82.71323204040527, 56.72522329515027, 57.242466249773585, 37.01896490589265, 54.82004965505293, 63.36166181871968, 30.912805334214244, 37.87161365632088, 9.702440557941314, 22.84748854175691, 79.30876378090151, 67.3651466061992, 69.99326013749646, 45.102275571515484, 76.77959595957111, 11.23873293399811, 2.335872438646132, 8.352084217532989, 2.16079376878277, 2.227766033141844, 55.07449773050124, 79.34585371325093, 72.31637800893476, 66.54628907480549, 71.92394487319454, 70.37588734780589, 71.95183292511972, 70.04458827357139, 70.73528628195487, 67.68417650653471, 68.89356874650525, 61.899480665883715, 64.71192598342896, 65.65912346686086, 64.41479859813568, 68.18085839671474, 62.47624166550175, 59.46386529553322, 58.91551794544343, 61.415715140681115, 56.53254078280542, 58.57939435589699, 65.57809514384117, 61.4302828235011, 64.01350875054636, 64.40386695246544, 57.42264816837927, 59.797757056451616, 60.14964465172061, 59.01674647485057, 62.20342513053649, 58.997130701618815, 57.512388075551684, 49.1633838991965, 50.540994828747166, 56.1607510812821, 54.06761746252737, 56.80734203707788, 48.99225481094853, 52.263440931996996, 54.160122640671275, 56.75737104108257, 57.919541866548606, 67.36341291858305, 64.33276614835187, 62.196890461829405, 62.667567037766986, 56.719657451875754, 52.14785260538901, 42.99918305489325, 42.108200980770974, 40.42275851772678, 47.841031320633434, 46.55641978786838, 49.32543270049557, 43.57648534159507, 28.995415472215225, 13.267066055728545, 14.912965143880538, 49.110628020378854, 46.56848499851842, 48.29200975356564, 46.48271060759022, 50.887897091527144, 60.12277249367007, 57.458314280356134, 52.417621458730395, 56.021044100484545, 55.88978590503816, 50.33038708471483, 49.048140741163685, 49.45676542097523, 50.398385294022106, 51.54706316609537, 49.21914039119598, 47.3572422612098, 47.465283947606245, 48.01420396374118, 49.20728698853524, 51.36652038943384, 52.41912764887656, 53.854601383209236, 59.37921270247429, 57.65495054183468, 57.860321921686975, 60.71233218716037, 59.74819006458406, 56.56897960170623, 48.05306680740849, 47.255931362029045, 47.36251392672139, 50.07250301299557, 52.43680969361336, 46.86685969752651, 50.73850577877414, 51.756247089755156, 57.51028568513932, 61.20901799971058, 63.78836078028526, 66.51380400503835, 62.975461329183275, 58.88863402028238, 58.55717412887081, 65.45070048301451, 63.026150118920114, 68.89210962480115, 67.39528609860328, 66.52657524231942, 69.98590961579355, 63.9797842118048, 67.71739113715388, 42.01422883618263, 1.8199836823248097, 2.1266603229507326, 4.5207321547692825, 4.486911027662216, 28.99944570756728, 71.78648148813556, 63.76533254500359, 72.14412320044734, 67.80096900078559, 77.17458648066368, 24.1237062023532, 21.562671084557813, 38.29043257621027, 20.51816155833583, 49.39088921393118, 56.43033558322538, 66.1266190005887, 27.28466783800433, 52.02709851726409, 63.029554736229684, 76.19422927979501, 5.862066553485009, 0.22464524804344102, 0.27161494137779363, 0.18105738856379064, 0.4000851896501357, 0.10037759724523752, 0.13659681704255844, 0.12044805898180894, 0.1096410941212408], [0.07251425931650786, 0.020358441848187678, 0.08448414564613374, 0.082120212816423, 0.007015159053187217, 0.08986422025989141, 0.03974793185930579, 0.0467073924899582, 0.045476446243663954, 0.12760745706937968, 0.13465974840425676, 0.0740619867499317, 0.35804020060646924, 4.406446545354782, 64.86314512068226, 58.27211979896792, 45.12811222384053, 43.328426807157456, 50.868159724820046, 43.68486042945616, 21.196490372380904, 31.391769878325928, 16.999018884474232, 7.263117567185433, 58.046320715258204, 68.37406650666269, 73.37089154028124, 47.518286935744754, 61.14716222209316, 27.62752417595156, 0.30891753973499425, 6.283381081396534, 0.4635399153396007, 0.25793150788353336, 16.996343828016713, 65.34496122790922, 60.357773457804036, 64.18249622468026, 60.765323408188365, 68.11651583640807, 66.36868415340301, 68.40547684700259, 63.860555925676906, 65.57734597113826, 61.935201691043, 62.91426843212497, 63.677247878043886, 66.44790818614345, 60.84646940231324, 65.66172399828511, 69.52881228539252, 59.867928258834354, 53.2403072234123, 56.40656601998114, 59.14955792888519, 61.66930421706169, 59.425610419242616, 55.623123568873254, 58.315987586975105, 51.38557134136077, 47.99896163325156, 51.673865549026004, 55.01661923623855, 54.008138641234375, 56.90892750217069, 53.7279402056048, 46.957580197242, 45.34087334909747, 46.42437711838753, 46.72206932498563, 49.6230346925797, 49.936624265486195, 50.926814848376864, 49.281168753100985, 45.05977276832827, 44.12300094481438, 45.63507072387203, 49.04223365168418, 46.7523657121966, 41.73419121773013, 36.63876172034971, 32.99310299658006, 24.74032436647723, 19.29480568055184, 17.46707139476653, 20.380486365287535, 22.665716102046353, 25.668841561963482, 23.774364225326046, 23.629487560641383, 9.431824472642715, 2.6550334932342654, 16.646091861109582, 17.03388483293595, 22.550902443547404, 25.623993181413223, 25.42440337519492, 32.29362672375095, 43.39700552725023, 41.9661876463121, 47.33263331074869, 47.84126666284377, 49.85782384872437, 45.46683242244106, 46.58713979105796, 44.696882924725934, 45.35954775348787, 46.79256216172249, 48.68188158158333, 42.44134356898647, 42.60237255404073, 39.93916165444159, 41.60582380910074, 44.80515603096255, 43.978940133125555, 49.679042216270204, 47.65163967686315, 52.700443960005245, 52.3475012471599, 51.103490168048495, 52.907254849710775, 58.153609306581565, 52.56329044218987, 46.56182089159566, 49.49556550671978, 54.61363100236463, 45.88234086190501, 50.8236212115134, 54.26002148658999, 51.584368828804266, 53.744018000941125, 60.537300340590946, 60.63231583564513, 60.38341791399064, 61.497810348387695, 54.85417819792225, 51.72173023223878, 58.706463459999334, 56.284097856090916, 59.37638467358005, 55.34691026133876, 57.44108330818915, 54.522251544460175, 59.990855340034734, 35.11369712891118, 5.421714311645878, 0.2901790291070938, 4.560593241645444, 2.2555851984408597, 4.759494671898504, 50.8529919193637, 56.49060672329318, 59.3247623597422, 62.99160580481253, 51.466242728694795, 63.36570578236734, 9.977784079890098, 18.590514698336204, 22.411511213548724, 18.553556165387555, 38.62681111981792, 42.62370632540795, 34.89071822935535, 26.33232028253617, 47.19207517562374, 54.34677647006128, 48.5233001555166, 0.2907517564392859, 0.059716523054146, 0.02765008394846753, 0.08857672523346641, 0.04504488593327903, 0.03221113587759676, 0.009907375581772819, 0.07192713719221853, 0.052741533821268435, 0.048949674387732824, 0.034496598321223454, 0.05665516293036842, 0.13955532603206175, 0.021941037773485147, 0.07486505373831719, 0.08349855054890917, 0.10558600687692243, 0.06838790291259367, 0.2730308863664827, 0.04244761804359094, 0.2177274128001544, 0.17634795497982733, 5.122596813786415, 71.29470256067091, 69.41747188568115, 47.16268093355241, 49.66945202119889, 60.145369268232784, 31.014533965818345, 31.05371452146961, 39.97064651981477, 23.233963597205378, 8.425379587757973, 64.23609149071478, 73.54348367260349, 79.5561319781888, 52.01787310261881, 65.17982159891437, 33.065262840640166, 0.24223641943066354, 2.2625371092750184, 2.731623164107723, 0.6941049546003343, 20.665927048652403, 68.35601575912969, 65.24607827586513, 69.8703565905171, 63.89534734910535, 67.49210588393673, 69.26708821327456, 69.62720101879489, 66.55207064843947, 66.16752932148596, 63.59087728684949, 64.73681734454247, 66.6065445253926, 69.42940373574534, 65.99700820061469, 68.3130265820411, 70.22065562586631, 61.67146936539681, 55.80298385312481, 60.48112023261286, 60.72669982910157, 64.97607408031341, 64.73442862110754, 59.052220390688994, 61.76734778188891, 51.30432728798159, 49.578296138394265, 55.589014637854795, 57.8143713551183, 60.351568268191436, 59.90444944750879, 58.15926928674021, 49.66898133677822, 45.43648896678802, 48.853312692334576, 50.552475606241536, 51.2769099204771, 53.48718904679822, 53.74784623422931, 51.563042902177386, 51.54250144958497, 50.74243207131663, 52.87415004545643, 58.581641874005726, 57.847837017428496, 53.18082447974913, 49.7280796881645, 44.85694700671781, 37.54375057835733, 30.859155154997307, 28.47600736925679, 28.701635829864014, 33.54305459607032, 34.93528419925321, 34.073551239505896, 31.605244874954227, 15.882757440690073, 7.770512430898606, 32.05315797559677, 35.66971663505801, 30.007898845980247, 37.69622487406577, 35.747226592033144, 43.45710016066029, 52.14444798807944, 50.189530849456794, 50.1964577551811, 53.62420528165756, 54.289737363015455, 49.40388402631206, 49.92252726708689, 51.308583059618556, 51.30675523511825, 50.300184834388, 52.07368843017086, 44.605793722214244, 43.573869120690134, 44.26431609738258, 43.56724815983927, 46.502440129556966, 49.69986215714486, 51.66437733557917, 51.70040038324172, 53.391679333102324, 54.54937081183157, 54.43732830785937, 54.177345768097915, 58.35689006313201, 53.70492765980383, 45.685857572863185, 48.16648606331118, 55.69880177897792, 46.662751320869695, 52.015221580382324, 52.40063759588426, 53.48626336743755, 51.94644281941076, 61.80823064619496, 61.732340628100985, 60.61482990941694, 60.920751248636556, 54.504263554849935, 53.97001320315946, 61.42909826770906, 61.695725302542414, 63.77723301610639, 60.14703235318584, 57.742368405865086, 59.46017042283089, 60.172488535604174, 35.040568459418516, 5.017827855002496, 0.22180865428620772, 2.1570704588966985, 0.7077864881965422, 9.390038482604488, 56.739963562257834, 60.1199209305548, 66.2323425662133, 67.48473182801278, 58.49297669626052, 63.85115008200369, 9.630232664846606, 28.42494007079832, 21.782453252423196, 25.431153774261478, 32.37595727366786, 36.87211528901131, 50.41693810493716, 25.711795437720518, 48.98493174583682, 65.83927400650518, 48.92500969671434, 0.44155588854224453, 0.009093722215883676, 0.03435739248450245, 0.09087170248911267, 0.014041127606986031, 0.04432572472480036, 0.06610693740508249, 0.07496088367676543, 0.01082585850400069, 0.1403863935340797, 0.2015982895729042, 0.1842113419045364, 0.24250078105157424, 0.12175126647156094, 0.29026081665389003, 0.23377382917509926, 0.22076772465821237, 0.1510915376486317, 0.5198463052511215, 0.18761146993887043, 0.3860841973895027, 0.646509321466569, 9.711492407706476, 89.19789052778675, 73.51561915489935, 59.95251809397052, 57.12993737190001, 71.65725508043843, 59.3163174967612, 30.49706155253995, 39.55831520019039, 25.623375408111084, 13.060995513393035, 69.05255025432956, 73.80091667175293, 83.44470700910016, 54.855405899786184, 72.6889874858241, 32.704977450832246, 1.391126804294125, 14.38743127930549, 1.5152690848035197, 0.4926735955861307, 30.789425219258955, 70.77255664333221, 71.09510098734211, 76.26684019642492, 67.0425630384876, 73.24590913711056, 74.77654349419379, 73.67387110187163, 69.80838314179452, 68.32982217111896, 68.56008098971459, 68.0261601171186, 70.02905568768902, 70.17445794997677, 67.7887390505883, 69.18769944098689, 70.45379346416843, 62.873660133730986, 61.10696969493743, 63.7269913765692, 61.20878657987041, 64.1488109096404, 69.14794229692029, 59.94499498798002, 66.45969883088144, 54.83214624466435, 52.446180235955026, 58.97966046487132, 60.6979763123297, 63.192984211829405, 65.33913650820332, 61.623000637177505, 53.223252757903076, 49.29029218612179, 52.5347787334073, 51.7262605697878, 53.903277997047674, 55.98122027612502, 53.09481866898076, 53.5313117888666, 55.60653586541453, 52.84242591550274, 54.016356006745376, 62.12180845199093, 63.124613377355764, 62.6379099968941, 60.743970024970274, 56.823984653719016, 50.249900048778905, 41.43324736625918, 42.927238941192634, 44.200969819099676, 51.189441065634455, 51.35227041859781, 53.862344141929384, 48.86803334759128, 26.302574988334413, 7.638927698135377, 29.74042457918967, 51.56467460816907, 45.99514822806082, 49.845268341802786, 43.74454321399812, 48.065218310202326, 60.73471715373378, 52.80918382829236, 55.13793422329811, 57.55868381069553, 56.75337806824715, 49.36702551380281, 50.193759164502545, 49.147141364312944, 50.110357807528594, 53.401253838692945, 52.818268037611446, 44.26142138819541, 48.3982353825723, 46.29489575662921, 47.80824815073321, 52.81592638261857, 52.19451312095889, 56.21812358979256, 55.27313832313784, 57.91721197866625, 57.657864862872714, 56.89837632640716, 57.72154062025009, 64.46551484446373, 56.65616604589648, 46.69629935295352, 49.546521017628336, 58.4207344824268, 48.75519852484427, 51.706472212268466, 54.437944119976414, 55.79992048202023, 53.82291647695727, 62.22275457074566, 64.60380584962907, 66.0962990791567, 63.54055719990885, 57.98694779795986, 56.39522644781298, 65.80769108187768, 63.258605464812256, 66.19367584105461, 64.95945892026349, 60.04106952298073, 63.22828554338025, 62.436535512247396, 43.17019054966588, 9.397778299547012, 0.5073697053857389, 14.386676223047319, 7.7889475707084905, 7.591702361260691, 60.44530114819927, 67.1853373127599, 68.04588963908535, 74.25175389935895, 62.92195235529254, 77.8044093039728, 15.29442839084133, 27.726813093308483, 31.93892286669824, 25.19981630386845, 51.36956807105772, 64.38008954448085, 52.53577501543107, 36.823972117516306, 68.01818986092844, 72.46754615537583, 73.27027490062099, 1.576403759179577, 0.15826296331661363, 0.1539326053593428, 0.285364197146508, 0.09057639857694026, 0.2240590528855401, 0.21706732080107738, 0.1565035504679526, 0.1883132371210283], [0.05202979600477604, 0.01176287692355653, 0.04033408871281051, 0.08384628551861933, 0.0339071243070066, 0.06458610731868014, 0.08447765688141508, 0.103228930534134, 0.042871544287810405, 0.02879689267325786, 0.041330071962288314, 0.012609198193756804, 0.0885852058267882, 0.176928588339398, 46.41940747537921, 62.83924133546891, 44.06242385987313, 22.57917292656437, 44.92556887288248, 50.63438254017984, 32.640026923148866, 19.278365065974576, 25.99625748972739, 5.195099374940319, 37.507358827898585, 70.46057131982619, 78.84590841108754, 78.15803450922813, 57.638092194834066, 60.99564106233659, 8.483762106587811, 2.747726699998302, 5.257143916622286, 0.32069549805695013, 3.291472374431549, 40.00534380635908, 58.73569296252344, 55.78101073541949, 65.96921428557366, 61.565737955031864, 62.61255579610025, 64.64456712045978, 67.04978019960465, 63.511143345986646, 65.28628649250155, 63.21869534830894, 65.91505419823432, 63.72037041571833, 65.7431367135817, 62.509840688397816, 61.34927411233226, 67.05844863768547, 63.94897007173108, 60.75692169127926, 58.532047425546956, 60.14104289393271, 59.613539018938624, 56.833704287006015, 56.73719436891618, 49.701431105213786, 51.8987036520435, 51.84224897815336, 54.14042057529573, 56.07795769168485, 53.99244916054511, 51.54210136782739, 43.07638706699495, 42.68658584164035, 45.38327417066021, 46.69527561433854, 49.84832386816702, 50.87393737608387, 52.58947226309007, 51.994468319800596, 43.18326380945022, 43.800229103334495, 50.84791637236073, 51.572833138127486, 44.023208002890314, 42.2453623433267, 35.54180029899844, 31.95773651522975, 24.406683637249856, 18.85889699382167, 19.664840121423047, 24.986413871088338, 26.267403094999253, 29.395928690510413, 28.34937757061374, 28.61753825218447, 12.0372853356023, 2.9884342224367204, 12.93341257879811, 25.722040668610607, 27.17171338296706, 27.18270386418989, 26.394589870206772, 31.55604462469778, 42.40103729309575, 43.17552889547041, 46.48152212942801, 50.87681639579035, 49.47629490206319, 47.26931056668682, 42.866340221897254, 43.816240218377885, 46.417399221850985, 50.089173086227916, 47.86336137402443, 43.5809019304091, 41.22246703793926, 40.24329439286263, 41.08074003650297, 41.30213429850917, 43.26206422621205, 46.673984989043205, 46.352523219200876, 49.39399573110765, 50.836529731750495, 55.069249599210686, 52.828395597396366, 58.303153591771284, 58.35400712105536, 53.044953576980106, 51.73149693396784, 57.18605079958516, 48.430924415588386, 53.71188202211934, 53.96507886148269, 56.39136291319325, 57.784212250863355, 60.940986756355535, 58.52777596442931, 58.476318390138694, 57.254986455363614, 53.122691031425234, 53.74728533529467, 56.94719414557181, 56.329205113072554, 61.632559453287435, 57.541229263428725, 50.00803493684339, 53.18456249852335, 38.36427903944446, 15.922672460156104, 0.18695730746032732, 0.14319724673705717, 1.703532434278919, 11.403847067586838, 31.782465404079808, 56.32434137405888, 53.512786434542754, 60.82416288314327, 48.45977737057594, 67.08081399240803, 25.52902279361602, 5.408595944604566, 54.45228822769658, 23.984513052048225, 25.94884191789935, 40.012839455758375, 44.25401987568025, 23.485722887900568, 36.869342173299486, 43.63912167087678, 58.5548246291376, 17.346840943059615, 0.590569336087473, 0.15557830011652363, 0.07457247709915524, 0.047745732740769466, 0.03913560927274727, 0.04585129306501439, 0.03299332697004561, 0.042892086935499986, 0.011197822919536022, 0.01689172162103557, 0.022567347210321217, 0.03224734119289825, 0.04423114350966869, 0.04985512519675878, 0.15396490362623047, 0.07368005361528167, 0.0651216947083031, 0.03366527034931126, 0.03275940202236657, 0.009194447456168072, 0.04272235632543603, 0.07714240331082575, 0.4333273687910649, 53.5018273322813, 74.23395418351697, 47.81877579227571, 28.73665082839228, 60.20016870191021, 37.741532171926195, 38.018961414214104, 26.561453380892356, 40.90602197954732, 6.5418329161982385, 37.782505250746205, 78.1465341198829, 77.80529575963175, 78.61392374961608, 65.04933218802175, 72.29327524861982, 13.455583010950397, 1.8324620901576936, 1.408976530355792, 0.1486950920474145, 2.039884624461974, 46.79785736145512, 64.31077341879568, 58.17417037102484, 68.8303009156258, 65.31565720035185, 66.00265641366282, 69.18219243326496, 68.94867804742628, 67.38987322776549, 65.24378368931433, 64.83278597554853, 67.27766206187587, 68.96707396353446, 69.2171407515003, 65.99973032551428, 63.224057228334495, 69.55948522014003, 67.13267557082638, 63.99905873883156, 63.1632879472548, 64.17551440577354, 62.89746892067694, 61.779746394003595, 56.116122353461485, 52.255384383663056, 52.70892412431779, 55.22996479465116, 54.643052701027166, 59.495565891265876, 58.32464033557523, 54.429083485757154, 46.87228041310465, 43.39030219662575, 44.931068035864065, 48.82344384347239, 52.19627426516626, 52.412149752340014, 54.107084351201216, 53.39192644242318, 49.021025396162464, 51.25202248173376, 56.560381766288515, 58.62142255229335, 56.56516313552857, 55.80907137163224, 49.90897940051172, 45.564468060770345, 36.06075340701688, 31.38475864164291, 29.616767937137237, 34.90798842522406, 35.5561718633098, 40.71312373684299, 35.9816195887904, 38.26093243014428, 21.576668062517722, 20.750583564081502, 47.123771021443034, 32.75661545415079, 37.38740490328881, 39.587030872221916, 36.433253057541386, 41.33558819370885, 50.6190578399166, 48.7792936448128, 53.6714659198638, 52.61372035549533, 55.316335385845555, 49.772496607995805, 47.41740749728295, 48.98369619923253, 51.70152610348117, 52.90982400217364, 50.96523838658487, 47.09400415420533, 46.280124110560266, 42.70426004163681, 42.91440102361864, 43.72290349775746, 46.62314714923982, 47.72896920481036, 52.198227605512066, 53.98385132512739, 54.1186474984692, 58.472572526624134, 55.9011293995765, 57.775347694273925, 57.592400504696755, 53.17143824792678, 50.63310776987384, 56.88050600790209, 48.28165861868089, 56.30851853278376, 57.07230990932834, 56.6211667368489, 57.57047445543351, 62.246575124802135, 60.519316273350874, 59.96374391740369, 56.51900860571093, 55.29611948997744, 54.673717791034335, 58.68259191513062, 58.151004852787146, 66.78140378767445, 58.968517011211766, 51.36097808038035, 53.67558048617456, 38.0662848103431, 18.62718689826227, 0.18125362964647432, 0.23575389066771155, 3.5579020650156084, 17.436953475398404, 40.27112753160539, 60.38901905859671, 61.152763366699226, 64.14631628221082, 55.44838590006675, 69.69671326298868, 21.2529803476026, 15.1770975512843, 61.32075063643917, 24.063431139915224, 29.330742820616695, 26.81981205940247, 43.487451461053666, 42.352427359550234, 32.119153814931074, 46.185277277423495, 66.83313200550695, 21.193260300544, 0.641858738756949, 0.17195577372706708, 0.13706019298443872, 0.03344357982578297, 0.026368799979888627, 0.006838303346622496, 0.05215093748824251, 0.013315879829948949, 0.018711147882464915, 0.15329230907222918, 0.07349813071590278, 0.12193796975958733, 0.12838197196082723, 0.11763065572707884, 0.16109698301842137, 0.1724002579407346, 0.2461930184114364, 0.2688070759177208, 0.186736183841863, 0.20470699776084195, 0.11850138360093679, 0.32778604016188656, 1.4115132006906694, 72.15308973866125, 79.18441680169876, 61.62318106620543, 31.812916724912583, 59.43719317836147, 74.59001910301947, 46.18766207848826, 26.035026196510564, 35.03790124770134, 9.96199752053907, 46.09331338636337, 72.95424169109714, 79.51624931827669, 83.09884809678601, 73.50535038978823, 73.38073668941375, 9.889505255606867, 10.863356224952206, 14.505708390666594, 0.302180256093702, 5.8227168456200635, 60.216932912026685, 65.29526479782598, 65.74809066710934, 74.27133437125914, 69.86446519051829, 68.26482065262334, 70.15738779498686, 72.41355080758372, 70.81000743373748, 70.93862195168772, 69.68129834821148, 68.02124146492251, 69.36962681431925, 68.60197190315493, 69.04993011105445, 67.23613200649139, 75.34714637264129, 68.8164000357351, 65.1973428264741, 65.07785174154466, 67.52270821602114, 64.30634898524131, 61.48193651630033, 61.11167653914421, 55.82490598001788, 57.998275603017504, 58.25996045143374, 59.68766397045505, 63.526209169818515, 62.61021414110738, 58.160795088737245, 50.252928118551935, 47.81574772250268, 49.42827332404352, 51.842096005716634, 55.75597816897977, 53.224860929673724, 57.75480624168151, 57.6797987568763, 50.4836654663086, 54.11673730419528, 59.96739564403411, 64.44982928614463, 61.48355645518149, 63.618667279520345, 59.184627840595866, 57.70304272251745, 46.268466826408144, 40.6944061863807, 43.678800367539935, 50.737768373181744, 49.62279150562902, 54.304924780322665, 48.33928215888239, 53.84218708161385, 27.508199791754446, 13.346251845359804, 51.60766378525765, 50.356882695228826, 53.19842023234214, 50.15991303228563, 42.7851903054022, 48.899933984202725, 57.76331386258526, 53.30374371620917, 55.21836634605162, 55.13168980998378, 56.63535394976216, 52.558446315027055, 46.83799105305826, 48.14101026904199, 51.946262390382834, 55.363599946421964, 50.93196099804294, 48.10898411658503, 47.61972335077102, 47.12568121571695, 46.88959375504525, 47.87812517535302, 50.35614136726626, 52.597026748041955, 55.43322986172092, 57.57296123812276, 57.05743628163492, 59.96171212965443, 57.470528541072724, 61.43952392762708, 62.36757239987774, 56.07997771232359, 51.97972020795269, 59.35478810341128, 50.087749265855365, 58.03744831392842, 60.768143592342255, 58.96483390561996, 59.971274868134536, 64.00509918889692, 63.14585301183886, 63.1371335829458, 62.834303071421964, 58.50122936310307, 58.65731616174021, 62.477112431680005, 60.20789969351984, 71.94874994216427, 62.39597820466565, 58.661446417531664, 58.09997481684531, 45.15419598548643, 26.87367012423854, 0.3859100196390383, 0.5147731484424684, 4.927309847647145, 13.918360913953475, 38.90588383520804, 65.97368578757009, 63.80405418334469, 74.53188957706575, 59.941464854824936, 77.3610245796942, 34.283586317493075, 9.905752693453143, 67.49623221735801, 32.48089440407292, 34.70430758691604, 55.798335844470614, 63.693808124911406, 36.85180917862923, 51.689198094029585, 60.320797274189616, 74.74587840418663, 40.38110294649678, 0.7095579899126484, 0.2880831964073643, 0.23143235804332843, 0.19826271210707005, 0.19507391708752803, 0.14904534744639553, 0.18344022844347263, 0.15208167564724723, 0.11929732597162647], [0.04236858841332217, 0.038586063761143916, 0.06103668790010195, 0.04541793244800741, 0.029776571656487165, 0.0662058010517109, 0.0781269948328695, 0.05028603050196844, 0.08687951106337771, 0.07450882285352677, 0.011075057329670077, 0.21196986368346601, 0.24629814099640618, 0.08968182238599948, 27.27887841962999, 68.97385181919222, 49.426896572113044, 31.764093022192682, 29.195228853533347, 47.28852625816099, 40.56341471210603, 25.94867325598194, 20.155558047756074, 1.5453946037638573, 11.64137109633415, 48.34237298657818, 63.262386629658366, 68.0914597357473, 60.6183639649422, 48.63014944138066, 40.093746185302734, 4.240754352461908, 2.8453535129947047, 1.3135659790808156, 0.13340003938684541, 6.5899030335487865, 32.94291627022528, 44.618404142318234, 55.32812210821337, 66.63676246520012, 69.34555915094191, 59.63869710122386, 65.78397643181586, 62.764575096868704, 66.55510656295284, 67.2437806283274, 67.79778403620567, 65.02726885580248, 65.69798631052818, 62.94204665768532, 67.52921150576684, 62.852640151977546, 60.8985427887209, 58.57707623512515, 61.89400111475299, 59.43816200379403, 57.886437062294256, 56.06850477956957, 56.75696311458465, 51.77907920652821, 51.90626598173573, 51.20615428493869, 57.29482204683366, 54.95504194690336, 54.22453972601122, 46.6019114371269, 42.80723010340045, 44.72847761646394, 45.81918285739037, 44.300613710957194, 51.8916473081035, 52.76702619368031, 54.23514189258699, 51.41999013962285, 47.44448754095262, 46.8797250716917, 53.804187159384455, 49.37203045814268, 44.94223502374465, 40.87505094466671, 34.6759763071614, 30.833040014390026, 23.721141584457893, 22.279576409247614, 25.44722176367237, 27.589067297597087, 31.021217684591974, 33.35400812087521, 29.46859059795257, 28.906242347532704, 15.360565435501838, 7.748206892321187, 28.791971937302623, 29.78095050781004, 32.129008769989014, 29.849556684494022, 26.96637534326123, 30.46090514429154, 41.072903140898674, 44.873573933878255, 47.23839052261845, 50.42945438815702, 53.358037164134366, 48.98375111241495, 44.000936785051906, 45.285614998109885, 48.73554745028096, 49.397266987831365, 48.75380216106292, 45.0144576257275, 43.74218979189473, 41.40874039742255, 41.24051778547226, 41.91223544459189, 41.68900943571522, 45.46704815280053, 48.52485733647501, 45.136023644478094, 47.234428928744414, 51.562301574214814, 49.227059656573886, 56.69307947158814, 58.22667914052164, 56.88033734598468, 46.63167045962426, 50.43073700320337, 51.092938992284964, 54.51935291290284, 54.49645803820703, 56.00085566120764, 55.351205256677446, 57.57249055370208, 61.12571470199093, 59.60272112200337, 58.946441911881976, 56.63703664656609, 53.59590145849413, 55.7356289125258, 56.456686066043, 60.604035546702725, 50.109730228301025, 51.108942262588016, 33.12669500227898, 36.42716946140413, 3.7836106890632264, 0.5029817376165621, 5.0265276720446925, 21.973121627684563, 51.63619902826125, 61.67159095887215, 53.982823664142245, 49.38662951992404, 51.835071040738015, 54.39818697590982, 27.47903108596802, 1.106574782921422, 30.999246528071744, 47.58774034438595, 12.009520838337561, 28.249384587810887, 44.06262782312209, 39.325565676535334, 18.27473448168847, 21.523574859865253, 45.75953537417997, 53.701566188566154, 4.644604036884924, 0.2210632660576413, 0.0682143610151064, 0.11489078823116519, 0.1413997899620764, 0.08250263624734457, 0.04945230084441362, 0.03261836523550653, 0.03703794179243907, 0.04378828340240064, 0.04661263124416432, 0.02339368794984635, 0.022210409609420646, 0.03368445702137486, 0.09708556421701947, 0.09583690218747624, 0.16424039498932902, 0.08343546320834468, 0.11496951908714349, 0.053416369182448235, 0.038343807607288324, 0.08333537382103744, 0.23282312938282568, 0.09760499481231937, 32.59841645917585, 81.33022785186768, 54.524444149386504, 27.64673790624065, 45.31944936321628, 42.359966155021425, 32.33018713612711, 36.66882276535034, 30.404609326393377, 8.933831530232585, 8.508458329785256, 47.62747787660169, 66.81573237142256, 74.6206763482863, 66.25395482586276, 54.772286953464636, 51.09848522370862, 8.481004680356673, 0.885103850835754, 1.5724622674526707, 0.16304765737825827, 6.795278335771253, 39.90198542994838, 54.15896946384061, 58.4600091749622, 69.8560477841285, 69.2191803839899, 60.218246906034416, 68.68947213695895, 64.9391528098814, 67.04491646059098, 69.23334014031195, 69.2674098476287, 66.39458748602098, 67.59335010282456, 64.5294180993111, 67.78275351370534, 63.60882997512818, 62.37910416818435, 61.3611118255123, 68.00760730620354, 66.7904644627725, 62.61315591873662, 59.96285746174475, 56.33158206939698, 52.88654081283077, 52.229943890725416, 52.26940685702909, 57.76836979773737, 56.67016890741164, 57.054290540756725, 51.461214250133885, 44.03252363204957, 46.57797713433543, 46.91170023333642, 46.39142920894008, 53.81355770172612, 54.308258794969134, 55.85344906776182, 53.17163436643539, 51.18581287322506, 52.39990411266204, 60.59764600569203, 58.06321436359037, 54.519023433808364, 52.88771752388247, 50.148828414178666, 44.05498704602642, 36.128873209799494, 31.612991556044552, 33.65820753958918, 39.25500615950554, 38.23166370391846, 41.698152480586884, 40.2498447510504, 40.824393533891254, 22.074846336918494, 30.451607165798066, 40.95269426222771, 37.03481128138881, 41.72848416912941, 38.59732274086245, 38.499459605063166, 40.67009141368251, 50.85773406490203, 51.70548769735521, 51.625177168077045, 55.62968961654171, 55.102056303331935, 49.284898927134854, 47.28412535882766, 50.91080765570364, 52.279644243178836, 51.67143367951917, 51.69186138337659, 49.18813013261365, 47.55489833893315, 44.44703971185992, 42.92746251629245, 44.37375414756037, 43.44113219168879, 45.977615233390566, 50.01437740941202, 49.197163351120494, 50.513699054718025, 54.77437365439631, 52.031464115265884, 58.123195248265425, 58.93568677286948, 56.36485161319856, 45.940085995581846, 49.2177204931936, 52.0153235620068, 57.588650718812026, 56.023593641096554, 57.1270622745637, 55.36531794455744, 57.1035005969386, 61.016025620122115, 61.40317532324023, 57.24727115323467, 58.7517511460089, 55.23051392647528, 60.92984722506616, 59.88522983366444, 64.61880499316801, 52.37292997298702, 56.92972390882431, 36.52267133035968, 43.88991801969467, 1.5696212457072352, 0.6194953452194891, 8.80992679826675, 32.40462783844241, 57.13281246923632, 69.3470339621267, 59.3789420589324, 57.154503176289225, 57.43277965053436, 59.15484528387747, 19.547318066320113, 5.833459727225765, 43.397633106477805, 46.69345955694876, 16.36696325194451, 26.09774293438081, 28.217762439481675, 48.20254048993511, 22.597460977492794, 18.82192277139233, 56.1156242124496, 61.2882734114124, 7.031011312238633, 0.3631622338246915, 0.24182988721276485, 0.10529291695885121, 0.03695313585922122, 0.007996978773359932, 0.07395976763819495, 0.07054833214609854, 0.11392765483188053, 0.024107174362025918, 0.17815340971273763, 0.07036879944104342, 0.1326856317539369, 0.1188913836414295, 0.15586245744939775, 0.1913067869721882, 0.2430162509723056, 0.1777372401087515, 0.215833704738367, 0.18183017209652932, 0.09391645765713147, 0.20305581781412327, 0.37376007966456876, 0.25864062950976435, 45.15774180812221, 90.3884397014495, 64.28936120002501, 45.83592353328582, 43.28990128732497, 74.52056177200811, 53.8299532090464, 33.405677503155125, 28.85251372091232, 6.24758945357415, 16.156564374123853, 59.39121123283141, 65.75980678681405, 77.42979157355525, 69.12833829079905, 66.41724309613629, 55.233487083065896, 6.196129427802179, 9.213412192560012, 3.077259236766446, 0.17779402254569918, 13.355055605211566, 51.029365216532064, 59.630189480320105, 66.49083460530927, 72.72373184081047, 71.2851555116715, 62.16651954958516, 70.82673242015224, 66.57193353099208, 69.49212243480068, 71.32707780407321, 72.06684466331237, 67.12031226004324, 69.40433979034424, 68.08455636424404, 72.20051903878489, 66.83252011576008, 67.59223614969562, 65.05623555952504, 71.64096939948298, 67.0452537844258, 64.33408406472975, 62.936916197499926, 64.08225221018638, 58.74176479155018, 56.30653773584674, 56.30980507020028, 64.76956129074097, 59.96360663444766, 61.157580037270826, 52.28231145489601, 44.48225867363715, 50.36835562798285, 49.75763866978307, 48.963441079662694, 59.083771936355106, 54.68378651526667, 57.32301996600244, 55.70384986938969, 53.37707242658062, 55.28978486214915, 64.77005943175286, 61.80417491543678, 60.860068259700654, 61.53438645024454, 59.6488638847105, 54.75062370300294, 48.28027794438024, 44.634925165484034, 48.39620751719321, 54.86142673800069, 50.07877880527128, 55.815362853388635, 50.332673826525294, 49.8319048266257, 28.784637105080392, 35.187029761652795, 57.98324900288736, 48.59222404418453, 55.268925697572776, 50.7087153773154, 43.70911636660176, 48.006229785180864, 58.1973986471853, 55.45146103828184, 54.82250113641062, 58.04237088849468, 60.33137590654435, 50.9785234543585, 47.130937191747854, 51.355777017531864, 52.34341021507017, 53.08801727910196, 53.7889212946738, 51.78136594833867, 50.30284027899466, 49.400954015793346, 46.64600280023391, 47.835128153524096, 46.938105629336455, 50.44132740266862, 54.01344560807752, 50.31216375289425, 52.16404414946034, 56.39838787817187, 53.92134835643154, 61.07821479920418, 62.59470116707587, 57.38366373123662, 46.3518407267909, 51.7020752353053, 53.09073548163138, 59.702568977109856, 57.17604483327558, 59.215987190123535, 56.27491166514736, 62.11228885958272, 63.25458503538563, 66.73627299647178, 60.605333851229766, 62.892522811889656, 59.44667354706795, 61.4550212121779, 60.325755150087424, 68.71660709381104, 53.549688093123905, 62.27546730349141, 42.32686919550742, 53.30953313458351, 6.236709289012417, 1.2539486490911054, 7.022289922160487, 29.835710717785744, 62.01884623496764, 73.166135972546, 66.44487227163008, 63.57001419990294, 63.536281816421024, 65.18211618546518, 35.002968618946696, 4.2227300809275725, 38.72931049716088, 59.0765469304977, 17.970389935278124, 38.981730707230106, 62.43878695272631, 60.16986054758872, 24.960392867365194, 33.28400165803971, 63.08114174873599, 80.90713747086065, 13.063932388059555, 0.4610075044535822, 0.33100912527691934, 0.43848764511846733, 0.29790171632362955, 0.13822124519896123, 0.28829469796149965, 0.1777194668689082, 0.1916419504390609, 0.1403238960812169], [0.03529405371556359, 0.04530178968824687, 0.03699040986717709, 0.0382938701659441, 0.03785814616769072, 0.06264500139701752, 0.017543884610096296, 0.11659115868350191, 0.06352826246931668, 0.026693489109616608, 0.013252556917347736, 0.036378945299093766, 0.14216618432152656, 0.38857729264324714, 9.159406058249935, 67.79244176803097, 51.11245670626241, 42.624228000640876, 26.70326667447244, 46.50598202982257, 60.15950549033381, 19.637377646661577, 33.84599101158881, 22.556066243879258, 0.722912005599468, 12.324294967036094, 55.94750750449396, 67.86441726069297, 62.738546248405214, 51.931875136590776, 74.98027140094389, 64.50894332701161, 29.7067137687437, 4.081745388046388, 0.3512744491379107, 0.036365282120964224, 8.635711785285704, 24.66970209152468, 39.071262728783395, 41.58518037488384, 50.436844133561664, 59.90603016268823, 66.57385549237652, 71.15576436442714, 66.91266982786118, 66.64569762445265, 64.87258234331685, 66.63662125987392, 64.29850032252651, 64.70592475706532, 61.15994522648474, 60.701804545617875, 58.557507530335464, 58.54390867294804, 59.02204559695337, 59.93110587519985, 58.78018440738801, 56.10891695945494, 54.12954776517807, 52.46725120852071, 49.21207228014546, 51.798487094140825, 56.70681168956142, 52.46183833768291, 52.37821340560914, 43.125487296812, 44.98768744930145, 44.41468800267866, 44.59472871595814, 50.010537409013324, 54.02483617105792, 54.88140336928829, 52.22666871163153, 53.558658553707986, 47.63995885849, 49.96607734311012, 52.459857540745894, 46.78623930100472, 41.95580905483615, 38.78796169834752, 34.977653641854566, 32.074191685645815, 25.390676875268262, 23.62761070651393, 28.688601793781405, 33.04885556620936, 34.5929632648345, 34.10120002685055, 36.01856047107328, 34.051911523265225, 23.529333760661466, 29.481146104874153, 36.785022981705204, 34.82676790606591, 34.517775351001376, 31.922313590203565, 27.945404821826568, 31.59243049160127, 39.26813433247228, 44.143083480096635, 46.43771317697341, 49.345209290904386, 51.730755606005275, 48.16200279420423, 43.37715833417831, 47.60182949804491, 51.71746661586147, 51.20007068880143, 49.002676548496375, 48.306844157557336, 46.534140725289625, 44.37343251320624, 44.18481357635991, 40.05525988917197, 38.81268047517346, 43.74010701333323, 43.35700911860312, 44.29846425210276, 46.77985760473436, 48.19081652549006, 53.416511858663256, 55.040051475647964, 54.893931419618674, 58.33650550534649, 55.24563858585974, 56.397913271381015, 57.403224591285955, 57.542315759966456, 55.0377647338375, 54.020674536305094, 54.60003998971755, 53.97415130369125, 57.7955125993298, 58.18390569379253, 57.27610057400119, 53.61281471867716, 58.11620950698853, 54.23122736715502, 59.04610933796052, 56.458811990676395, 66.7404228641141, 34.0368966902456, 30.269605267432432, 9.393450944654404, 0.5368256941437721, 6.985840316741698, 42.095790601545765, 54.654502099560155, 50.83452932296261, 54.81317766251103, 51.335325779453406, 57.433552357458304, 57.54117042787614, 38.0563102229949, 2.173599081654703, 13.707929676578892, 73.27469148943501, 33.1671856295678, 16.82955680354949, 35.86187354979977, 46.666885499031316, 31.080035586510938, 38.356053829193115, 48.915439113493896, 46.638950378664084, 40.57830402928014, 1.3427018350170505, 0.11337310676613163, 0.06924596735306325, 0.07656257434357559, 0.07520177236367619, 0.04580191103741527, 0.11786628905082903, 0.030651662401073886, 0.09354284423733912, 0.02713958210792513, 0.017424869020619703, 0.05208344131167378, 0.032353413726894126, 0.023001111938708255, 0.021730924753712553, 0.017949941853481918, 0.0477734076670341, 0.0824765662752813, 0.040616181438728687, 0.044239647085628206, 0.04371326807285509, 0.11264870168581126, 0.17024778069988375, 0.35999688109563244, 11.440640860988248, 73.29321292138869, 61.784861164708296, 34.28164866662795, 30.117393770525535, 56.456442879092315, 29.482283592224125, 26.447092756148308, 26.383097325601888, 33.02269727953019, 4.896606514530798, 8.350285810808982, 58.89805163106611, 76.88999499044111, 68.54430521688154, 60.434432260451786, 78.51182445403069, 66.06199402962962, 39.102782895488126, 6.500497508433558, 0.34269944314033757, 0.7326284519607021, 7.9934991751947715, 27.77005526327318, 46.91465377807618, 46.59598081342636, 51.04717277711438, 59.76255378415508, 68.54017888346027, 70.22908872173679, 67.50165293293615, 67.98551651739305, 66.57595003804853, 68.6216151329779, 66.32069003197455, 67.57784105116322, 64.0240756157906, 62.02722049528553, 62.870043708432114, 62.94872645408877, 64.03878450393677, 64.43692861064788, 63.48047433360931, 57.690502905076556, 53.98174108997468, 53.40103026359312, 51.13724216338127, 55.80880465046052, 54.79702141977126, 56.49726690784578, 55.78332101145099, 46.90544797528175, 46.108528260261785, 45.983702751898, 47.04291136034074, 52.259432269680886, 53.64603719403667, 56.55582004977811, 55.364239292760054, 56.222042037594704, 51.15862300319057, 53.766316675370746, 60.91365960336501, 59.67774821865944, 54.49483809932586, 52.6196902028976, 48.80178059301069, 43.30848939957158, 34.431902900818855, 33.47082414934712, 39.181104783088934, 43.6993496648727, 42.95253038406373, 44.76074303350141, 41.80830047976586, 39.67279349603961, 28.297902345657352, 28.516474462324574, 42.51092641584335, 45.351334310347035, 43.22818279266358, 41.6696290046938, 38.49620796019031, 42.04882021873228, 50.1484832456035, 52.439010143280036, 52.726853278375444, 54.821194987143244, 55.774083829695186, 51.15279828348468, 48.14436781790949, 52.40206926099716, 54.81710787742369, 52.93369554704236, 52.54086232954457, 51.36277452591927, 49.52574814519575, 45.4970464398784, 45.95778372979934, 41.73971391493275, 41.10998915087792, 43.86130040691745, 47.04465289269724, 48.27724595223704, 49.05831144702051, 52.03989328876619, 55.187689488933934, 54.52429117694978, 55.91057446695144, 58.64521172738845, 59.01451856859269, 56.833614072492054, 58.657735855348655, 57.478259532682365, 55.69391058337305, 54.55980823886011, 53.43135802976547, 53.57525802427723, 57.8835266636264, 58.72136062191379, 59.2567680728051, 55.46571885385821, 59.59238175422915, 56.52160913713517, 61.29310577146469, 63.62193853624406, 64.24680348365538, 34.41285194889192, 32.08143041979882, 7.102324904934053, 0.6652235624290282, 9.720941397451586, 51.66703278018583, 58.90113069165138, 57.38643684694844, 58.90491185649749, 57.59929210908952, 64.03135553483041, 63.13107352102957, 36.80345027677475, 4.612662215386668, 20.591109798800563, 66.28732635128883, 36.46662066059728, 22.97296320238421, 30.23017760246031, 35.23248610957977, 45.809392621440274, 31.33280096515533, 41.93094122794367, 57.51830693214171, 44.162212879427024, 1.815642476562531, 0.11577741242945196, 0.14223001476737762, 0.05850413528781745, 0.033954748162819494, 0.06521301238887733, 0.016754681897920468, 0.06834163886284636, 0.048615510665601304, 0.03499159837261804, 0.07202413924519094, 0.1457281560907441, 0.09735413166063447, 0.14729521958337677, 0.1180744274789768, 0.2286684047430754, 0.11138110196277981, 0.1714313712211386, 0.27552287845361617, 0.12718450758726368, 0.1855044063901709, 0.2236964021839442, 0.42107624392355647, 0.5836872311849749, 19.493656119992657, 88.45806875536519, 70.11791306157266, 59.74974724554247, 36.04534241460985, 72.06370676717451, 79.53249577553042, 24.73738062766291, 42.21778023627497, 31.079913993035596, 3.3308009995568186, 19.63077041410631, 67.61935541706701, 81.49779150562902, 73.56912028404975, 69.90987839237337, 81.90713005681192, 78.72090247369583, 38.85691304360667, 5.766821109479474, 0.6739508973494653, 0.450688514618143, 13.865143176048035, 38.36518902932444, 56.21304804278959, 55.715864089227495, 58.34238513823479, 62.944760937844556, 70.95375445581251, 75.9348507850401, 71.4241486210977, 72.83614696994906, 68.35671394102036, 67.69335485273793, 69.31114427505001, 70.30068766686225, 68.0246853059338, 68.09557822442824, 64.61119167266354, 64.57309761355, 65.764403804656, 65.7820858493928, 65.82840904112786, 61.41913936984155, 58.948101074464866, 60.10094450366113, 54.41506885713147, 61.821605928482555, 60.49676656723023, 61.492377865699034, 61.43681356983801, 51.05835937684583, 49.64629827007171, 51.56025409698487, 51.407713120983495, 54.70266096053585, 59.2243928294028, 58.28604813544982, 57.46992449606619, 59.325809632578206, 53.885305696918124, 60.44137093328661, 66.57535383778234, 62.108656744803156, 57.68288566220192, 60.74642150632797, 58.07280455866168, 53.06967235380604, 42.99128732373638, 44.810447308325, 50.2422357374622, 56.0394557060734, 55.72861179228752, 54.49733272675545, 50.92375932201263, 49.984614464544485, 35.374138585982784, 41.50087295040008, 53.914739162691184, 55.73551908616097, 52.82252380924841, 50.34609617725496, 44.43406843370007, 48.803176956792036, 54.412585996812396, 59.06301475340321, 59.231994382796756, 58.42644153102752, 58.08179070872646, 54.45768148668351, 48.22389779552337, 52.83154526064473, 56.72900838236655, 54.37404870986939, 53.9115345862604, 55.04585266113282, 54.28972951827511, 50.746966331235825, 51.32148765748548, 46.04246770181964, 44.56673868240849, 47.401623879709554, 51.13180968069261, 50.21034686796127, 52.03484519835442, 55.917266030465406, 59.21725803805936, 59.25411655056862, 57.42808849580827, 61.24271900423112, 61.19838445417343, 58.99388690148631, 61.35880154948081, 60.60719305469144, 58.524520397186286, 57.3325042570791, 56.84244332774993, 57.01190933104485, 62.17094006076936, 63.93475932459678, 64.16648903200704, 59.43572621191702, 61.80051142169584, 59.86275465257707, 63.68187627484722, 65.61661674130347, 67.43672201710363, 38.85926646571006, 47.87058637988183, 14.192406131375222, 0.5103924738303308, 7.764934820513572, 52.78613598115983, 64.8826353780685, 61.53862261003064, 62.10410679540327, 62.43636685032999, 67.58118291055003, 69.32471567584624, 47.31026403365597, 6.627346469509987, 19.216823077970936, 82.81589615729548, 43.07007597338769, 22.777756644833474, 47.220488825152, 66.23793586607903, 45.56965735650832, 50.18070943893925, 66.27861084476595, 64.16468474172777, 66.20530174624535, 3.764529583915588, 0.3147472236906329, 0.31787375108368937, 0.2119227952413982, 0.14781398368218254, 0.22600986514120336, 0.15462075149820698, 0.2152618507464086, 0.17943934958067634, 0.09394837288005699], [0.019995478965762644, 0.03159873859746562, 0.08637226892695313, 0.057107246736244816, 0.03684252808471361, 0.07270289314610344, 0.06396987002282854, 0.04766986322318835, 0.06818367153285973, 0.06723718522416969, 0.0534515479399312, 0.12948583571180222, 0.05938086929100175, 0.10964307828896469, 0.2425551120071642, 47.965472436720326, 54.443345223703695, 52.87869999485632, 40.828935638550796, 30.864322877699333, 59.513859825749556, 40.61294248027187, 45.22064485857564, 60.148154151055124, 14.274771982623687, 0.2299152741268758, 21.73245676102177, 57.073349337424006, 63.34009270514212, 59.725252043816354, 50.93688749497937, 62.290964588042236, 59.89940135709701, 57.87847857321463, 5.226520011501928, 0.5482571355758176, 0.266953173784479, 4.264065488692253, 13.890109062194826, 30.68964992800067, 68.14242701376638, 59.37570610354024, 60.14835419193391, 64.48938246696227, 68.67333550607005, 70.34614009241905, 65.78723592142906, 64.47453629586005, 66.39249294034897, 66.00306434016075, 61.063396084693174, 59.92506934750465, 54.01550093004781, 52.69216775894166, 57.98840299729378, 58.11541718821372, 57.01702410174955, 55.32521563191568, 51.65719547579366, 46.49507391837336, 50.29980436448128, 52.18876684865644, 55.208344690261356, 49.64457242719589, 46.96032585636262, 40.59987706522788, 42.68025513618223, 45.98475002473401, 50.311065489246005, 52.71724347145327, 54.66201343844014, 56.95474863052369, 54.670721100222686, 50.27015909071892, 41.40028376733103, 50.239395941457445, 53.563577205904075, 46.52369937589092, 42.32950502826322, 37.34012857560189, 32.856730030428984, 30.766751958477883, 25.48002846779362, 28.765980351355772, 32.86416292190552, 36.90711459805889, 37.92484806429955, 36.670579987187544, 39.17193035925589, 37.0001571409164, 28.624953492995235, 32.76560748777082, 35.12622125687138, 38.440220048350675, 37.50349921564902, 38.12812489847983, 30.315993178275328, 32.94554425824073, 39.40097324309811, 43.20499374020485, 46.81621405386156, 49.00759520069246, 51.48352469167402, 49.93165854484805, 43.2451823449904, 45.76147694741526, 50.253857720282774, 52.248516313491336, 48.248169422149665, 48.88060062162338, 48.299356352898386, 46.097012181435865, 46.60929726016137, 45.62484902720298, 41.85597296684019, 42.8284618931432, 41.62452567008234, 43.43555065893358, 44.71966797305692, 47.245839103575676, 47.49760427782613, 51.65421839683287, 53.05431235221125, 54.8693028573067, 55.0016357821803, 56.23371108885735, 52.92159895743094, 56.55665943699499, 52.629080357090125, 53.75597338522635, 49.78951577217349, 47.85079409999233, 60.005509314998505, 58.80684083507907, 56.62386140515728, 54.92228623359434, 50.586298204237416, 55.995407489038286, 54.952535552363244, 60.266280251164595, 33.723660130654615, 36.705238050030125, 10.59589078349452, 0.6929774570368952, 1.6126907088102835, 31.13413291592752, 54.61265825456189, 49.090925955003314, 62.0880211553266, 55.62741856421194, 62.88791010456701, 54.412503627038774, 58.55768011462305, 24.439225581384477, 4.958624580214101, 37.60018171802644, 76.75839162641957, 21.29403187382606, 13.129118257953277, 30.975873124214914, 39.16807859174667, 27.47504791905803, 27.968597796655473, 30.397198007952785, 56.313778431184836, 17.936449666177076, 0.4992116350800761, 0.12256727268498753, 0.035931634220985637, 0.021468556876624786, 0.06517591841158367, 0.050352331581375295, 0.02327282991891186, 0.008647237555123866, 0.01719312359308524, 0.0770255978850107, 0.033200814223457734, 0.07965341736111911, 0.03867052495479584, 0.09965931320743215, 0.008743992544740679, 0.07836050609306944, 0.02838781321301095, 0.02848509871851533, 0.03851011763477037, 0.1271833278118603, 0.041335434577758276, 0.028221457220253446, 0.06872066086338413, 0.109864738168976, 0.5389310876207968, 53.078454540621856, 66.03086609994212, 49.29927049144622, 33.933856025818855, 48.202442430680804, 42.40122948923419, 36.89290777329476, 43.73617679842057, 51.8666696548462, 22.908901091544863, 0.5323916385250708, 23.124080358013032, 63.57714899124638, 68.30599769469231, 67.18255242993756, 55.62494747100338, 68.11619420205393, 65.50805337967412, 65.82781284086167, 8.741838374445516, 0.6009159357317033, 0.6898565374074445, 5.026496783379586, 16.312434461808976, 38.04661804629911, 70.78596330458119, 60.885540131599676, 60.1525785846095, 64.79373093574279, 68.45957417641917, 71.30237471672797, 63.62146785182338, 64.30524679922289, 68.37166601611723, 66.51516898985832, 63.761449398532996, 63.35964964282129, 56.270636281659534, 57.00521776753088, 62.029393488360995, 62.5079579507151, 60.2246246799346, 57.98669676626883, 53.800813921036266, 49.925123876140965, 50.457240458457704, 54.137094405389604, 55.630697665675996, 55.38762054135723, 51.48586242429672, 44.18430759060768, 45.921046810765425, 49.086736863659276, 55.65823270428566, 53.59486987513881, 55.43969785013507, 61.02438419095932, 58.43799683355517, 54.27171799444384, 47.72973798936414, 56.64126103924167, 61.08044662783223, 56.571454617284964, 54.61457237120598, 50.992777347564704, 45.56845318886542, 41.70129429909491, 35.27549489851921, 35.47186051645587, 42.591127118756695, 44.60785688892488, 47.027429765270604, 44.19206211643834, 44.83980232669462, 42.20093365638487, 33.64845260497063, 39.24293310411515, 46.496556574298495, 47.3599486966287, 45.89078964725618, 44.75863279834871, 39.40646063896918, 39.81807416485202, 49.61092633585776, 49.944359179466005, 54.41167600693242, 53.85522111769646, 54.86839286742672, 52.670833987574426, 44.38692938896918, 48.80543231964112, 52.52474138813635, 54.48571074393488, 51.286143179862734, 51.91439313273276, 50.87824413853308, 49.302545670540106, 50.728370374248875, 47.148623158854825, 43.86860778254848, 44.54288282702046, 44.72183312139204, 47.06417452904486, 46.6731926702684, 49.84489963900659, 51.70034939242948, 52.32752069350212, 55.55154423559866, 57.826554236873505, 57.88789618399836, 57.194099503178755, 56.10213910379718, 57.74941298269457, 54.14229939060827, 54.659852212475194, 52.3306272106786, 47.1627672256962, 61.3704784454838, 57.85392453593593, 58.14907112429219, 56.624332089577955, 54.307172298431404, 59.207605085065296, 58.4954595565796, 58.808829476756436, 36.13550986013105, 48.13717026864329, 10.23676053170235, 1.7628320522846717, 3.1093246129251297, 36.96724845517066, 61.35857797438099, 55.83617102715277, 70.08803244559996, 63.01923498030632, 68.37209747683617, 56.74724740366782, 63.47651273973527, 24.255085991274928, 10.508377801987434, 44.25084275584067, 71.83521301515641, 27.80193824921885, 20.28351556870245, 26.806542681109523, 36.92676175025202, 41.99788824204476, 22.956336275223766, 32.844962919912035, 65.78671032382597, 20.379792105767038, 0.33247584657322976, 0.04688417110892554, 0.04687239250708972, 0.03634763528562842, 0.03587528462371519, 0.09786594734196702, 0.020989977919887153, 0.029170442890796452, 0.03839031297473177, 0.06323527214267562, 0.10023719631135465, 0.1539980905551103, 0.12433246183659762, 0.17818115741735507, 0.19562576086290423, 0.1927328596432363, 0.11198313215807562, 0.12824560064942608, 0.2728718771569191, 0.16881504306389442, 0.195463610692851, 0.18419127040092023, 0.25265618047166255, 0.19522984662363607, 1.9467893747552751, 75.46827700830276, 70.43436204233478, 69.96941212684878, 51.60387869804136, 54.93102919670844, 84.98793217443651, 50.58367021622197, 55.80798487509451, 69.62397683051326, 21.512415716725013, 2.3944692169466326, 28.410941131653328, 67.48210383999732, 74.95198326726114, 72.3600967468754, 61.76351562623055, 75.8048555927892, 72.22985836767381, 70.50567857680782, 7.30162690724096, 0.5880778955836451, 0.26998197900191434, 8.244489681336189, 25.97405295218191, 49.34627225322109, 75.8185838883923, 64.19800135397142, 64.286811659413, 68.86415097021288, 73.90580869490101, 73.88384342193604, 64.78831022016465, 67.57989637313351, 69.24046316454488, 69.25765883538031, 67.4977227180235, 66.27653983331496, 58.91896178645473, 60.909964730662686, 64.97306954476142, 65.03995772330993, 62.76880341191446, 59.6492757335786, 57.66302670201948, 52.05657120673887, 57.83173176550097, 58.114350303526855, 61.89871972607028, 59.2985217032894, 56.23526042507541, 46.05758843883392, 49.25547330610214, 52.590696042583836, 60.03700202511203, 58.255783127200225, 58.580912313153675, 63.2983547641385, 58.66197201513476, 55.55584707567769, 48.80937037929412, 63.23280019144859, 65.23901016481462, 62.083824219242224, 62.54956645350303, 59.343319093027425, 56.20310875677294, 50.50387351743637, 45.95868587493897, 46.31461351148544, 53.284492723403446, 53.48990332695746, 55.299896732453384, 53.33545215668217, 55.13989933075444, 46.71164758743779, 42.14730308901879, 45.08586829708469, 52.95797894077917, 54.23878969684724, 52.94365444490987, 55.58826154278171, 46.84564751963462, 46.477893937018614, 54.93002506994433, 56.886220901243156, 60.2039812457177, 58.93896195196337, 58.33349312505415, 53.86750205870598, 47.91522295244279, 49.62700805356426, 56.04381738170501, 59.412666597673976, 53.74057023755966, 54.15865567422683, 55.720178696417044, 54.25574610310217, 56.37235902970838, 52.78091922883065, 46.02598982472574, 48.10106485120712, 47.20504253141342, 51.306229637515166, 51.013993447826756, 52.394730506404755, 54.88620042800904, 56.17758589406168, 59.26795859490672, 60.314913718931145, 58.349186528113584, 61.59970960309429, 58.23790888632498, 60.43552660172986, 56.2746214097546, 56.163230019231, 53.64094203518283, 57.44122059114518, 66.26349403012183, 62.27009757872551, 60.332976233574655, 61.320903608875895, 61.00295236033779, 65.09912275498914, 61.355738178376235, 61.86023342993952, 40.821200724570986, 54.001560826455396, 17.072577053500762, 1.2613611932723754, 2.3305539498406076, 36.79025934588525, 66.45117159812682, 58.133820949062226, 72.4401052536503, 66.06735983202535, 71.97434732990881, 63.09477590745496, 71.19262679930657, 31.60178730564733, 10.182556317698571, 42.45358920866444, 87.75245005084624, 27.371244353632775, 17.77718182533018, 40.49761303009526, 57.710436390292266, 42.85809147742487, 42.50062234940068, 45.89905800357942, 79.32805399740897, 38.895422873958466, 0.8063134851474917, 0.1605012424049839, 0.10194414745896094, 0.13274553982961562, 0.11639307132892071, 0.13490558601915836, 0.17407520193486445, 0.08445933971914553, 0.13913233824554952, 0.18291018753042146], [0.04244908893240556, 0.042935723303667, 0.05225343622207161, 0.09138964687383945, 0.026511217640232176, 0.08317375991253123, 0.03986396353631731, 0.052876510852647406, 0.06595061716413306, 0.08923782846860348, 0.06495347712188959, 0.060852980015859495, 0.11446188624587753, 0.09231737168926386, 0.3225210855805105, 17.341904640197754, 61.26532362353418, 50.57408002115066, 44.45045609628001, 39.914678219825994, 46.29708443918536, 35.456198492357814, 17.211413268120058, 35.42164633350988, 61.45300511390933, 4.996295023349024, 11.070401476275537, 62.67385067478303, 67.2597760538901, 63.553293135858354, 54.5357366531126, 54.355111506677446, 59.180917278412856, 56.635832478923184, 40.53264371810421, 0.8737762909262412, 0.37875016189871297, 0.22395947677714212, 0.8994745571286449, 12.488473615338727, 26.0976311468309, 53.23355290197557, 56.68329315800821, 63.851040255638864, 61.67268137778006, 66.90884159457299, 62.05672064135152, 66.18132821975216, 65.20372060037428, 64.89527717713388, 61.49503723267586, 56.25144804677656, 52.89485623759609, 48.410069173382176, 50.0503259320413, 51.63230411468014, 53.55878014718333, 53.23542387254777, 48.648023682255904, 46.444891114388746, 46.937874209496286, 50.671154760545306, 50.60144247547273, 49.12846303755238, 40.65020499690887, 45.38287408890263, 51.89136881982127, 53.3797239488171, 52.081988165455485, 54.379073266060125, 57.517412631742424, 56.41137876818257, 55.465377607653224, 49.25040560383951, 46.05357585414764, 53.26380222074447, 48.70817715121854, 46.154486671570815, 38.23196180405156, 37.22543454939319, 33.36554773392216, 30.937582946592766, 28.313403552578343, 30.753547299292784, 37.03588601081602, 38.39891749043619, 39.806656145280414, 39.21249551157798, 43.044831598958666, 35.9822863917197, 39.78106267990605, 40.35851793904459, 37.214126356186405, 42.054393906747144, 41.41670280887235, 40.13566847770445, 32.89060558042219, 32.262065372159405, 40.54459518001926, 44.24699883307181, 46.30503508352464, 49.85754928281231, 49.78134547510455, 52.449192616247366, 44.90155220031739, 42.99995183944703, 51.99191485681842, 52.16159659047281, 50.56856909105855, 45.06003164475964, 45.38384683670537, 47.51831831470613, 45.40114841153545, 46.05027714083272, 43.61945490683279, 40.070404160407286, 43.0770460251839, 44.7058141616083, 45.17256052263322, 43.759711019454464, 48.58479507507817, 50.06517210314351, 55.23264377347885, 54.034293005543375, 53.66206792093093, 51.84621841676774, 53.670881486708126, 49.23738725723759, 52.73926365760065, 48.89497218593475, 53.28621464390909, 51.33612594296856, 46.9846563185415, 52.212685461967226, 48.063241435635476, 46.272742209895966, 50.98081804090931, 43.24649241662795, 48.799791951333326, 31.00169408705927, 47.69904152039559, 37.65825240842758, 2.7369860247258218, 5.038538950104868, 12.371143756374238, 52.044725648818485, 51.52568232628607, 48.819262596868704, 48.10506174641271, 56.3730493668587, 52.44501529201385, 63.61672570628505, 48.54248446802939, 6.543984826534025, 6.363723970228627, 61.87861757893717, 48.3925401010821, 12.06401824951172, 20.186444751677975, 36.544338503191554, 37.024930830924745, 28.62898372834729, 20.52456286645705, 39.82144348083004, 47.15042352676392, 3.9570510339352394, 0.1533620077515802, 0.08801225632909807, 0.04419725177989853, 0.02539935593132771, 0.04606240391430836, 0.07784800859348429, 0.030211223131646554, 0.017167007655746514, 0.04557247919541213, 0.033788487931052526, 0.05442937873604317, 0.06802051012674648, 0.06428740963700318, 0.16561029809376887, 0.12339145305656618, 0.07702069492229531, 0.048060116072696064, 0.09267980788624094, 0.09431237955727885, 0.09397862569218683, 0.06857053827374213, 0.10783201579244868, 0.04775949167988954, 0.19345437657208214, 0.30460755971650927, 21.237308517579113, 73.09826327908424, 57.850531685736875, 39.65221674211564, 54.08951213282924, 53.64670007459579, 31.887588847068052, 33.2927446211538, 32.79576659202576, 65.58804619696834, 9.717420089629389, 9.358625200486953, 68.22523609284433, 78.00907073482391, 67.37580760832756, 60.75048508182649, 60.84771279365786, 66.6869374244444, 61.872832082933, 47.518730163574226, 1.8728638512472955, 0.8287270727657503, 0.9139899621086737, 2.674900788453318, 20.747063236851847, 34.05688116627355, 58.27144122892811, 60.67457545188166, 65.26629809410342, 62.83112987395256, 66.92481348591467, 62.979791625853515, 66.18761970150855, 66.10346917183169, 67.33918051565847, 64.60579841367661, 59.08448188535629, 55.86903656682661, 51.324182325793856, 53.89087154019264, 55.1175888892143, 57.242791806497884, 54.082997075973026, 49.07429902784286, 49.93947975097164, 50.41862864648142, 54.44112516218617, 53.61696458631947, 53.29103131448069, 45.24074700570876, 47.066272997087054, 54.0428045488173, 55.50116531310543, 57.21693554232198, 56.801646755587676, 59.8657395762782, 59.09269532849712, 57.16991809106643, 54.28859203092514, 51.90699946495795, 59.4086108669158, 59.35469788889731, 57.0096068997537, 52.799017044805716, 51.010125990836855, 46.344741236779, 40.81020632097798, 36.5455073695029, 37.796268847680864, 46.23137297168855, 48.32983316913728, 47.7941668418146, 48.72507864429105, 47.07088178203952, 42.746249014331454, 38.676746814481675, 46.04927301406861, 44.26869346249489, 50.95443225676014, 48.690757905283284, 49.848535676156324, 39.786279432235226, 40.86649233295072, 48.30791496461438, 51.381252811801055, 54.038003567726385, 52.70065184562437, 54.53435990118212, 55.387055720052416, 47.703430652618415, 46.988539465012096, 52.90476022228118, 52.7623938745068, 52.86003343520626, 47.97040285602693, 49.39334461765905, 52.26780260762861, 49.032396347292014, 49.49594205425632, 45.73721316552932, 42.554774591999674, 46.325423563680346, 47.401314012465946, 45.684021903622536, 49.201799592664166, 51.36572022591868, 51.943661858958585, 56.218951209898925, 55.74615655406829, 57.68623928869925, 57.56516748859037, 56.99956955448274, 54.82004181031258, 57.448986884086366, 53.35353820554672, 55.19149418800108, 51.70871580800703, 49.98463799876552, 54.2092973955216, 52.75342733629289, 50.88619086050218, 57.053792399744836, 46.97569370269776, 51.817024215575195, 34.352063055961366, 56.10447291404971, 29.582251079620857, 6.792446874803113, 11.19767552421939, 16.294975011579453, 58.8787418027078, 55.670113563537605, 52.64983754004202, 52.70584506373252, 64.58593160875382, 56.922114510690015, 71.60413049882459, 48.360470802553245, 5.663230332636065, 15.104000260753018, 59.363248655872965, 50.957338733057824, 19.26663717915935, 25.578827088879002, 22.266728685748195, 45.57249715251308, 35.26062519319596, 15.849472207407798, 45.043369416267645, 54.79929247210103, 4.313676116927978, 0.42259579464312524, 0.036955798014758096, 0.04211614329007365, 0.050085901523069035, 0.012223336943275025, 0.020153348619538932, 0.13092025874122498, 0.014534990017813061, 0.09370785191534989, 0.0280924633355631, 0.19531217043197927, 0.2056276975500007, 0.1921324458934607, 0.28359312443963947, 0.15642867303423344, 0.27382908869654904, 0.09452293116238811, 0.248934019717478, 0.1898124711888452, 0.20872837713649198, 0.2430217974488774, 0.1750210447296981, 0.19913790627352654, 0.35337107856908156, 0.40062322852111637, 35.460081638828406, 85.75332780038157, 71.3793473089895, 61.93799834097586, 55.33269559183429, 67.40120887756348, 48.328095559150945, 26.072078866343347, 42.84534377436484, 73.87282940649217, 8.702490137469384, 17.107133134718865, 73.18948976455196, 80.08236500524706, 75.0331449508667, 69.74475445285921, 65.63033719216624, 69.81374894419025, 66.48594733207457, 49.17258577962076, 1.6744022167498067, 1.1593159528509265, 0.5245658971609608, 7.029301158843502, 29.42943161533725, 42.91628376130135, 63.9868954689272, 66.35082167963829, 68.1454864625008, 67.77186501410701, 71.26926991247362, 64.00692701339722, 68.30025534476003, 65.78733005831319, 70.61879188783708, 68.1759318997783, 61.83604809545702, 59.434208254660334, 52.263691963688025, 55.70040210600823, 57.490187460376376, 60.957441099228404, 57.62718800575503, 54.54016108666697, 52.485388248197495, 54.728344640424176, 57.25321354404573, 57.684638961668945, 58.24719705889302, 47.60875640376922, 50.944783226136245, 59.91864058279223, 59.46384568368236, 59.23120206402194, 62.4043446202432, 62.667535658805605, 63.25114511674451, 61.00505475075015, 56.08192320792906, 58.42319773089502, 64.55687861288747, 64.30546645195254, 62.371483002939534, 58.46020921584099, 60.231108357829434, 53.83635451716762, 50.705534335105654, 45.306921312885905, 46.28629792121149, 54.12999099300754, 54.633854742973085, 57.306420495433194, 55.748733551271506, 56.61913887146981, 47.059930524518414, 47.33831682512837, 49.687243892300515, 46.98400912746307, 57.406986144281205, 56.10008770419706, 56.539754021552305, 46.664194753093106, 46.65150980795584, 53.89269936469294, 55.91022929837627, 59.479864643466094, 57.9930627730585, 57.9102340821297, 60.62105863325058, 51.01812370361821, 45.8664317284861, 54.54657808426888, 55.66698743451027, 54.62239749969975, 49.91992673566265, 52.690441916065836, 55.797531758585286, 54.225681135731364, 54.14656692935575, 49.427339799942516, 46.05899656972578, 49.420962026042325, 50.57011450490644, 50.59691998266405, 51.63275910962013, 55.17972315511396, 54.93020157660208, 61.19163797747705, 60.81844406743204, 58.59158900476272, 58.074722597675944, 61.80079775471842, 58.40420953689083, 61.34777576692643, 56.80815789007372, 60.94016305861935, 59.40374320553195, 55.91276707187776, 60.29945173571187, 62.49912477308705, 57.26187805975638, 63.70706965846401, 51.67859984982399, 57.016584796290246, 40.95372192321285, 63.844419294788, 42.78918327823762, 5.912907335066027, 13.54905995630449, 15.806756615638735, 61.5497935202814, 59.96588553151777, 57.59137676608179, 56.678131318861446, 66.71108353522517, 61.28400979503509, 72.74231603068691, 57.33270037558771, 9.883413814729261, 10.032039284706116, 70.85560106462049, 59.09512327563379, 17.536632668587472, 26.952497997591575, 49.70975045234927, 56.83073505278557, 39.89554097575527, 34.20972024240802, 51.178936958312995, 73.49526989844539, 14.49472967655428, 0.629741188979918, 0.22908845075195838, 0.18518759838996396, 0.13029608094403822, 0.19028016786661842, 0.24833069483359016, 0.22624699999728512, 0.09305945807887663, 0.2102861403217239, 0.1536629424099961], [0.07148152682930231, 0.005682274274858496, 0.02355855198637132, 0.030414213448943152, 0.07544953285926774, 0.04382188018831996, 0.04035173554814631, 0.060157816511608904, 0.04939143515882954, 0.04766242067900397, 0.06806085997771832, 0.06138734549524323, 0.08492619370020206, 0.022921195561667124, 0.0881154943377741, 1.1695517455377888, 45.698962211608894, 43.049848310409054, 42.36181359137259, 30.60924722302345, 42.57324895551128, 39.13235364421722, 11.294218782455692, 19.287251195599957, 60.331936805478996, 15.56961109561305, 0.8809393355923315, 13.293245915443668, 55.00814691666634, 66.82297306676065, 64.90307092666626, 53.37601338663409, 62.30516356806602, 60.31671016447006, 55.91635604058543, 8.811609495070673, 0.7982082136215702, 1.5315374828154042, 0.10710901265302974, 17.13892786733566, 11.355793130013252, 17.221815393817042, 37.838716737685665, 45.54739398341025, 52.93678245236797, 50.98473256634128, 56.66431280874438, 56.33261365275229, 60.44257117855934, 63.98926065814111, 62.324485163534845, 57.33104121300482, 51.726029149947635, 49.111769430099, 46.77445650100709, 49.08120239934614, 52.40629365367275, 52.01861835295155, 48.141296602064564, 46.47352049427648, 46.855563271430235, 48.747255725245324, 48.89355228793237, 46.3026895061616, 43.53782253880655, 49.22448658174085, 54.637490780122825, 54.53948251662716, 53.67026567459107, 57.99742052631994, 56.62720326454409, 57.711436594686205, 56.41163372224378, 48.0089597548208, 46.191713886876265, 51.53009499272993, 49.82730388641358, 46.98280888219034, 39.10045692997594, 39.20304652183287, 33.62698547301754, 32.35007747527092, 30.012038907697125, 33.71614094703428, 40.1363980385565, 41.258223364430094, 42.24981423347227, 45.223739608641594, 44.54057255098897, 39.746235955146055, 42.91241630431145, 37.684414617476925, 42.44548166951826, 40.455384792820105, 40.57405610238352, 42.73957314029817, 34.15952567131289, 35.08206321347144, 39.62705081509006, 45.55217143028013, 45.73842517791256, 49.707848102815696, 54.64379010661956, 51.30127568398753, 45.49124525439355, 43.73778497019122, 46.636742084257065, 53.350725866133175, 51.68860581613357, 48.61683299464565, 45.23196874126312, 44.86331693587765, 48.02912858224685, 46.1981975647711, 46.436438406667406, 41.7050793863112, 42.341727133720156, 45.326533163747484, 44.34208885315926, 45.073603045555856, 46.763924937094416, 47.54801065691056, 52.220745932671335, 51.82544554433515, 55.239064693450935, 52.58532631781794, 51.37376108477193, 48.11796634427963, 45.0306099460971, 43.20242458774198, 36.10309147065686, 45.357692472396366, 31.148541742755523, 25.873363748673473, 28.193010322509277, 33.48672151565552, 29.377136615014848, 27.612678004849343, 22.381520771211196, 13.56337856861853, 13.06443052907144, 1.3139071027117393, 2.029708893068375, 9.761936049307547, 34.856158225767075, 52.81694619886337, 49.79867058415567, 49.49918585438883, 58.606996074799575, 59.35640804229244, 63.356719632302564, 56.71247951446041, 18.246844468578217, 2.8864881444361905, 26.620816492265273, 57.11218864687028, 22.561453619310935, 12.867437331907212, 30.640096664428714, 45.754871676045084, 36.73623261913177, 23.312224688068515, 32.85843233908377, 49.34307552153065, 38.87717993028703, 0.12875521765841594, 0.0745574004888054, 0.029802643543770237, 0.047814278457794464, 0.06979813288536764, 0.13236853264031873, 0.061265051049450715, 0.01904965915356673, 0.10012080457301871, 0.00877957062555417, 0.04883348949313645, 0.04085490592725335, 0.0488668602831181, 0.03438560367231408, 0.04941304649917349, 0.07168470866857998, 0.08000856806193629, 0.05342683011305429, 0.026082520583464254, 0.08239905349910259, 0.09532512481053991, 0.05369803289912882, 0.07702002842580119, 0.018397206966314587, 0.058576741270841136, 0.054463611374939644, 1.4895703283048447, 53.23005807015204, 54.76028057836718, 44.17095192017094, 37.19353783515192, 50.08183825400568, 26.851718579569173, 22.841210788296117, 25.798064047290435, 63.10955539826424, 31.23360618468254, 4.250023893771633, 9.427089191252186, 58.79181031257876, 71.90905555602043, 74.67595823349492, 60.966086003088186, 66.48651215337938, 65.88338498146304, 62.50430622408467, 12.314228203988845, 0.4480730598011325, 4.335728662629282, 2.9395749732371304, 30.950358106243996, 19.36887375770077, 22.281500331817135, 43.45554690207205, 50.17787748767484, 58.660199103816865, 57.23263286775159, 59.42048780379757, 61.42408155625867, 63.82178721889373, 66.313825884173, 63.603366113478145, 61.6906693673903, 57.41446610419982, 51.617763888451364, 50.400079757936545, 53.15273638694517, 54.33181262785389, 56.46066334939773, 51.991938391039454, 48.76273732031546, 49.687169367267245, 51.090797378170876, 52.98263888205252, 50.037354653881444, 45.69294137339438, 51.20884110850673, 57.823024103718424, 56.80183110698577, 59.440927274765514, 60.013942410868985, 60.10833424906577, 58.536020786531516, 56.66400294150076, 50.503665631817235, 51.02116746287192, 59.30255389982655, 60.550126491054414, 58.01365521646316, 51.99939481673702, 49.957891356560495, 44.2279714153659, 42.88117462588895, 38.50111092290571, 42.769265482502604, 48.13717026864329, 49.69013860148769, 51.39740120980048, 52.5030702929343, 53.0963287814971, 45.85236610904817, 47.324141379325624, 47.884479415032175, 49.80040819414201, 51.09273502903601, 51.414487054271085, 49.402703392890196, 41.47059617503997, 41.28278132407896, 48.43990664328299, 51.76105983795659, 51.18499309785905, 53.96107804390692, 56.90224378339706, 56.85671291043682, 47.91481502594487, 44.715184703949966, 51.42011173309819, 54.70330815161429, 53.9968422151381, 51.02803553304365, 47.48580971071797, 47.22374439239503, 49.6663337369119, 49.67582979509908, 48.85570533813969, 45.62105609524635, 44.96501614970546, 46.66937620409074, 46.32840848738148, 48.830084416174124, 46.947342811092255, 49.06943921119937, 51.947297896108324, 53.7740437446102, 58.38308365114274, 57.40328342683854, 55.42121956425329, 52.439763238353116, 47.67083967885664, 48.96165640123429, 41.194202438477554, 49.077433001610544, 36.9984273756704, 30.821412148014193, 32.918452447460545, 37.914661668962054, 32.2147870832874, 31.022327715350738, 25.5599977508668, 15.060728673012028, 12.452141681025106, 4.127575341732272, 5.908537814694067, 8.428832254102154, 40.000625195041785, 58.04165701712332, 54.956665808154696, 55.73646045500233, 68.48066083846554, 67.27537924243559, 74.44876670837402, 61.75601213209091, 13.06130930300682, 9.04203893676881, 34.32506538206531, 51.49976330418741, 27.315701630807695, 18.830516684439875, 29.37779949557397, 29.860498136089696, 52.71019104988345, 24.12116058411137, 28.129934687768262, 59.89252544218495, 41.96564243685815, 0.4907497036601267, 0.11094621683080351, 0.05031717963696969, 0.06974981571998327, 0.07476003840565681, 0.11157257031769523, 0.04351706529456762, 0.050261619110261245, 0.09356706027662562, 0.021198030163143432, 0.02033465481813877, 0.17303732133680777, 0.22826420143246653, 0.16336621205893256, 0.12087656260137597, 0.20336458189112527, 0.16111477158002316, 0.1489201686795681, 0.13876115332447714, 0.1601604405309885, 0.2672049409199146, 0.23675588770739495, 0.20285628255336516, 0.22787446186186808, 0.22151141217158687, 0.19016029042822702, 4.775365071911966, 81.87764167785645, 58.31830963011711, 65.34640073776245, 41.95265939158779, 64.46162385325279, 53.87326009811894, 14.572163147311057, 26.716689025202108, 69.49275001402825, 22.678026460832168, 2.2375111618349632, 18.25398906584709, 66.76936211124544, 76.91263491107573, 75.75357452515634, 63.30203002498996, 73.57491754716443, 71.04138020546206, 68.45460845578101, 11.161769167069467, 1.0316256433725357, 4.839861585247902, 6.164803908717248, 48.79250810992334, 30.54047238442206, 32.9798218511766, 52.450016313983554, 56.35683428856635, 63.369298673445186, 62.36063372704291, 62.44495291863719, 63.5153010583693, 65.4570351108428, 70.45128314725815, 69.11756746230587, 64.00130233457013, 59.250504047639915, 55.390338743886645, 52.460693005592596, 55.56658260283932, 59.582093377267164, 60.34535131146831, 54.194710100850756, 51.70346767671647, 51.81142307096913, 57.07436915366881, 57.910669465218824, 53.88936535004647, 50.39064253530195, 55.417148144014426, 64.22639931401899, 60.305558866070164, 61.70677069694766, 62.20462145343904, 61.88540327933527, 61.513342934270064, 58.91789490176786, 53.94945213871618, 54.84957725771012, 62.73022297889956, 63.905059137652, 65.83841108506726, 59.419852379829656, 60.39962906991283, 51.716258525848396, 50.290759378863925, 46.03599579103532, 48.49511792582851, 54.738668318717714, 54.20167623027679, 56.4824442709646, 59.451211729357325, 57.762745118910274, 50.6198658481721, 48.599688314622455, 47.65535808378651, 52.781656634423044, 55.676981633709325, 56.3625648713881, 58.09227520419706, 46.48918251837454, 48.742191945352864, 55.7176919137278, 56.061566106734745, 54.8842078639615, 58.430979713316894, 62.521007676278394, 58.09854707410259, 50.58878498692667, 45.776589839689194, 53.208402664430686, 56.515384335671705, 57.111235510918405, 54.13321910365936, 51.646820806687884, 50.49735846058015, 56.568524606766246, 55.086880653135246, 52.73787513855965, 46.28697256888113, 46.66145301634266, 51.47760975745417, 47.33586926614085, 52.75554149381576, 51.70092598084481, 53.13573291224819, 56.4366662886835, 56.772228979295306, 61.36945078449865, 59.183235399184696, 57.76280395446285, 53.046561748750754, 51.14915832396477, 53.722731298015965, 47.45023381325507, 51.498453232549856, 45.043043859543346, 38.362380612281065, 40.313708782196045, 43.50379989993188, 42.14243542763495, 40.0930715376331, 36.50911169667398, 25.36093354225159, 26.801953508007912, 2.4444725724958607, 6.421319563542643, 11.387743776844395, 42.28125203040339, 62.53935260157432, 58.89942053825625, 58.50490854632471, 69.841809580403, 68.08195975518996, 72.29755063210764, 64.13457662828507, 25.079568201495757, 4.891484389382025, 31.180542399806363, 68.53689193725586, 30.78831126613002, 17.686159303111417, 40.69999556387625, 64.98241655288204, 55.78463500545871, 32.49762135167276, 47.37507335601315, 68.02215145480248, 64.14848927528628, 1.9352793020586816, 0.31558608996772, 0.21546307140060011, 0.14468073003715085, 0.2258456158902376, 0.2905347696956127, 0.1712817848930436, 0.09708298250071465, 0.15546255955292335, 0.07396930543285224, 0.2665822340115424], [0.05947367318214909, 0.0688266414668291, 0.08546765698420425, 0.043201732013614914, 0.02993976370611739, 0.09174675109886354, 0.0038045295701933006, 0.10079416521494428, 0.05569384515946431, 0.09915204808836985, 0.03462795941759983, 0.06254645950731731, 0.020197391014305816, 0.07922878248556968, 0.0699077830499699, 0.06878809958335853, 13.033581087666175, 54.007016843365086, 40.38087152665661, 26.300005835871545, 35.12003567910964, 56.9467273835213, 25.61540319073585, 12.172839506979912, 44.3359346543589, 65.76272110785207, 4.591105359215891, 0.38722337013290775, 10.132511777262534, 56.79464924720026, 46.67410266014838, 39.185317408654, 61.35977821965372, 61.46558023268177, 59.952059176660356, 27.713843776333718, 0.7881607559900131, 3.046578702426726, 17.066097297976096, 4.176288727791079, 14.97724396567191, 6.006233759464757, 35.65021068819108, 51.45234184880411, 57.35685825347901, 50.75893740500174, 52.74568849994291, 60.06420366225704, 61.52640442694388, 59.28702523631435, 59.47345156823436, 60.34181333357289, 52.5986780658845, 47.79443356298631, 46.473202782292525, 48.887625586602, 47.84022331237794, 45.69625577618999, 49.552957627081106, 43.81633435526202, 45.306066236188336, 46.50009062982375, 47.924416988126694, 41.935322515426144, 47.91445416788901, 54.582989446578495, 56.91714486768169, 56.818179545863984, 55.182998334207845, 54.37237385780581, 58.08473640872587, 58.12525057023572, 53.171857941535215, 47.195954399724165, 44.20747703121555, 50.8608562715592, 48.54532426403415, 44.89328384399415, 40.93584768233761, 40.20426680964809, 35.39389948691092, 33.15057046951787, 31.295991482273227, 34.794828045752745, 40.34660962320144, 41.55632349752611, 44.63398771901285, 46.14530048062725, 45.540219968365086, 45.526228873960434, 43.707880819997484, 39.73758320654593, 45.37488029849145, 45.37824961446947, 42.73264231220369, 43.10083912264916, 36.44354143450337, 34.920661603250814, 41.3159449638859, 45.85801824446648, 49.48384938701507, 49.323440136448035, 52.7891012930101, 52.73711419874623, 45.89918744179511, 42.905791421090406, 42.50739628268827, 51.72686461479434, 51.89782896349507, 53.10512273542343, 48.67455851647162, 46.61924046854819, 44.968244260357274, 47.98584130502517, 47.886923051649525, 46.62062114284885, 45.30789406068864, 45.94348276815107, 43.932656165092226, 48.65956721767303, 46.58038154725106, 47.670341537844756, 50.15631621883762, 50.58452529291953, 52.002387585178504, 52.31010536993704, 53.363383354679236, 51.22469140637306, 43.33401226228283, 37.88207069520028, 27.745132523198283, 22.27247888042081, 19.80809488604146, 15.824340601121227, 16.874852334299398, 10.97408865728686, 11.245459798843632, 6.628371679013775, 4.833464689793126, 2.5447134000639764, 4.148197693209495, 2.7515696421746285, 2.4106190858348726, 23.365696399442612, 48.200869560241706, 54.6688775862417, 54.05343417198428, 49.987328744703724, 48.199928191400346, 52.02286627984817, 36.10043210368003, 15.953445415343008, 1.762692072699147, 4.859630330916374, 61.35542438876245, 60.44806249680058, 19.491998918594856, 18.8896522983428, 37.23730364153462, 40.463570779369725, 32.627283142459014, 29.623788979745683, 35.46277238476661, 54.63873809383762, 20.123692712476178, 0.233655407303764, 0.2151497414395694, 0.03832133441802956, 0.07948261039752154, 0.02958612411373085, 0.03865465927388399, 0.05009017629368652, 0.049930159678502437, 0.015980371934992653, 0.07673276843683374, 0.032176895577821045, 0.029874916278546857, 0.06213011370310861, 0.09977450984860621, 0.09891026307858768, 0.04297900727138885, 0.051738184636398676, 0.03242603503167629, 0.035845276959721124, 0.04342759771633052, 0.03525186525357347, 0.052749370900733825, 0.02031056518335977, 0.08193553966139594, 0.03827634973511581, 0.10281152752858978, 0.05554127874934385, 17.741911872740715, 72.40147775219333, 45.350922461478945, 25.495023688962384, 42.34997980056271, 37.50626056425033, 24.633763374820834, 22.025820632134717, 43.480857956794004, 63.932707924996656, 14.643709140439189, 3.2701160494358312, 8.120008360955024, 61.684546547551314, 52.87260463160854, 50.17547307475921, 64.82775749698763, 66.31107238031203, 64.65834640687513, 31.43889323357613, 0.9952846385778921, 5.19359318479415, 22.459079757813488, 7.231806756988649, 20.166095495224, 10.191539525985718, 42.45409519441667, 56.22227345743487, 62.649312326985026, 54.54679381462836, 57.527595104709754, 62.4861103488553, 66.01770262564382, 59.620724801094305, 65.69265188709383, 62.210956081267334, 57.75426495459772, 52.24525682387814, 52.56813849172285, 52.673363916335575, 52.30078189603744, 49.36895139755742, 51.628511182723514, 46.686285541903594, 48.124371574771025, 50.62705555269795, 51.150644902260076, 44.73477302059051, 52.55342568120649, 58.03761305347566, 59.69444967085316, 59.49851943600563, 56.35329631067092, 55.98721365774832, 59.51843330937048, 61.647778249556026, 55.91406929877497, 48.57947634112451, 48.3302410956352, 58.25412004224716, 59.16695756296958, 53.9888366576164, 51.58054844025643, 49.77583846738262, 44.577089817293235, 41.56443495904246, 40.84190691671064, 43.60149829618393, 48.91388585490566, 49.633079882591005, 51.96716862340128, 55.62279408977878, 53.18188744206583, 51.054178130242136, 53.82738405658353, 47.77033452064761, 50.57074208413401, 53.15553695924821, 53.293267065478915, 50.394623741026855, 45.306313345509196, 40.359043536647675, 47.76319580693399, 52.8661209537137, 54.445412312784505, 53.34807826626686, 57.13538162169918, 56.723705337893584, 47.57372179339009, 44.20251523294757, 45.28382247494113, 53.60519355343234, 53.14806484406995, 56.19405592641523, 51.73317570840159, 48.280226953568004, 49.94639881195561, 51.722753970853745, 50.5252778914667, 48.97710661734305, 46.81175039660546, 46.5690694316741, 46.48329896311606, 49.69092307552215, 48.21903797887987, 50.04010423537224, 51.328183143369614, 52.014064481181485, 56.134396676094305, 57.02268800427837, 57.234696034462225, 56.15349077409314, 47.66211240522323, 40.6379593572309, 31.38738859084345, 23.177589331903768, 22.972323856046124, 17.73913875702889, 17.150485131048388, 13.094470981628666, 13.27992162396831, 7.336568361328495, 4.996302377793097, 5.27236859644613, 3.035414901471907, 4.538910379332881, 4.597403705120087, 26.36281671062593, 52.47342894154211, 58.842934485404726, 59.52617214572046, 56.26609417699999, 52.82808573015275, 56.18658381123697, 41.183223724365234, 16.518944309603786, 3.9921586984588258, 11.937004058591782, 53.79772309334048, 61.269218537115286, 24.968455299254387, 27.873839216847575, 28.410915636247207, 35.753196439435406, 47.061942700416814, 20.311591894395892, 33.4089683717297, 66.91113225875363, 20.230671436555927, 0.39270295190715027, 0.08736583899946944, 0.08769015466133434, 0.024808979848580017, 0.05304094396471497, 0.06614048439528673, 0.06019844598467312, 0.009032600848454862, 0.01752232306546742, 0.05281437346110902, 0.1420982170008844, 0.1902905100535962, 0.22752676519655415, 0.14941921367520286, 0.10103858556718597, 0.11391100008040668, 0.23648791015148166, 0.11306926097360351, 0.17065187675818322, 0.09239856934835834, 0.23170116297419996, 0.13526742466755454, 0.2044629068264077, 0.22477765868027366, 0.1683632044061538, 0.1293524444824265, 0.16537428172605653, 34.68266002593502, 83.49671763758506, 55.723351893886445, 41.08510563450475, 50.30447198498634, 85.70057192156392, 30.38221455389454, 16.946280656322358, 50.98179863345239, 78.45481672594624, 9.473811484152272, 2.023109382679386, 14.3220571356435, 68.2455147466352, 58.177359257974935, 54.48545971224385, 70.45761385271626, 73.53379541827788, 68.74997077449676, 34.34556761095601, 1.7865946288070373, 6.631365918344067, 23.40957203219014, 16.233340847876764, 35.38054773884435, 18.532700923181352, 56.22912583812591, 62.70918730766543, 71.02330592370802, 59.41495726185461, 63.347196117524184, 63.808109914102864, 70.26427238218247, 63.3305181995515, 68.53599763685658, 65.48529971030452, 61.314380707279334, 54.87010694319203, 53.29632651421332, 54.395072613993, 56.981907121596805, 51.8559145158337, 53.83708407801967, 48.754417973179976, 50.90064479458717, 54.498627108912316, 54.44397672530144, 49.0841402546052, 56.24525462427447, 62.603938348831676, 64.49632506216726, 64.10896355105986, 59.502006423088815, 58.904778495911636, 61.261071774267386, 62.55983914098432, 56.3513155137339, 52.654626754022416, 51.55223677235266, 62.56009409504553, 62.45549624966037, 60.49584873260991, 58.96439067779049, 57.689094774184696, 51.34920312512306, 49.53848408114526, 45.08188316898961, 48.26814605343727, 53.56425969831405, 52.39307918856221, 56.67934333124469, 58.05745240180724, 58.618225820602916, 52.080332925242764, 53.660636255818034, 50.13721035372827, 53.45856358928066, 57.98500230235439, 55.75386008908672, 55.351205256677446, 49.82012594899824, 45.78105349694529, 52.17005322056433, 59.144941299192375, 58.31083359256868, 57.69682184342415, 61.45193038448211, 59.85833414139287, 50.80758656224897, 47.26894970863096, 46.5265783955974, 57.075993014920144, 56.200112065961285, 59.89876201075893, 54.460870373633604, 51.40189232364778, 53.61394828365695, 56.87883900057886, 54.517026947390654, 53.41908885586647, 51.5739510136266, 52.04227416746078, 48.36153376486994, 53.77258854527628, 50.72602479688583, 52.857527040666156, 54.1193849040616, 55.93456760529549, 59.16467082115912, 60.18402814865113, 59.82955178906841, 59.75513658215923, 50.61407642979776, 43.34914084403746, 33.74422903983824, 26.32223783000823, 25.562588476365615, 20.337801171887307, 21.37563874644618, 19.571717169977006, 18.153472446626235, 11.688331673222205, 6.898561696852408, 8.280992238752305, 3.7466827996315497, 7.7398669527423, 6.416824037028897, 28.969951445056548, 57.892834448045306, 62.635062356149, 63.474790819229625, 60.05597452963553, 57.49836560218566, 62.80200235305294, 45.748337007338, 24.061277758690622, 3.362779102979168, 7.770013309294178, 69.41260030192714, 72.3870434299592, 25.28753815158721, 26.0816631778594, 50.04288519582441, 57.80991162023237, 45.16347239094396, 37.42408298677014, 47.725431226914935, 72.45373941236927, 39.16658024634085, 0.3797895287073428, 0.26118548166367317, 0.18469969231274821, 0.14812784990476024, 0.14489857479929924, 0.22610288353696947, 0.12012994863213071, 0.2760687314214245, 0.21087014446816138, 0.18440352272122137, 0.1824678330411834], [0.031451617157266985, 0.02257792879977534, 0.09926127690461375, 0.04988016478056389, 0.10107340426334452, 0.025936305042236082, 0.08279000348862141, 0.04362874176172961, 0.06489480244776895, 0.0958626120982151, 0.03628421086637724, 0.04191065552614389, 0.05579797183013251, 0.04199684807850469, 0.09622174645623854, 0.15927968456620173, 3.4238278529336377, 56.04220136519402, 47.9633229778659, 37.39457107359363, 32.00588360909493, 51.971436162148755, 45.21891901569982, 17.008226648453746, 28.607934328817553, 88.56054459848713, 56.980820625059074, 3.31722003798331, 6.580785484083238, 49.47669890619094, 65.09665558415075, 44.76430846798805, 61.13054706204323, 61.412573322173095, 54.93167638778687, 52.3554636586097, 4.131444759907262, 2.406521679893617, 20.040728699776437, 15.72239035560239, 3.679284467812508, 2.5775978161442668, 4.821739254459258, 27.6192440525178, 51.9059012013097, 54.32359918471306, 46.30236787180747, 54.85719057821459, 62.74512014081402, 60.60757744696833, 59.76273421318301, 58.7094013152584, 50.67937997079665, 50.167926434547674, 48.537491290800034, 45.99810569517074, 46.74903169755013, 46.74059860167965, 46.08839473416729, 48.052490218993164, 42.72260496693273, 46.040161348158314, 43.35853099822999, 47.81669301371421, 53.2558790329964, 56.17352231856316, 56.07977374907463, 55.78137551584552, 56.07780079687796, 57.77828162716281, 60.21465793732674, 60.732379421111084, 52.419637556998964, 45.217389291332616, 43.56011336849582, 53.14296576284593, 49.78068259454543, 46.428883921715524, 44.124683641618304, 43.72142476420249, 37.18184917203842, 33.749371267134144, 34.769583671323716, 35.86334836098456, 40.54986292316068, 42.95522505237211, 44.537085563905784, 47.947143200905096, 48.17333452163204, 49.52089617329259, 46.6823317927699, 43.049863999889745, 48.849978677688114, 45.40490211979036, 46.90195706582839, 44.20642975837954, 38.63585218306511, 35.70168002959221, 42.75684333616688, 48.6408967356528, 46.219225391264885, 46.36016007392637, 52.584173140987275, 54.2467442635567, 47.29220544138263, 43.598611431737105, 42.97379747513802, 45.82184222436721, 51.96099481275005, 53.67342318257978, 52.92488982600551, 49.99628351580713, 50.86305279885569, 50.204879083941066, 49.763400631566206, 50.10322301618515, 48.94971670642976, 46.99019470522481, 43.24290344792028, 46.56353104499079, 47.50032248035554, 48.80145895865656, 48.62419136108891, 53.16485651077763, 53.12426390186433, 55.94337724870252, 53.218192900380785, 53.792882888547844, 43.99384906215053, 34.645017039391306, 28.038106118479085, 19.0701852690789, 17.831212474453835, 11.810947906586433, 6.840885694949859, 6.398581583653727, 3.264343546282861, 1.459705892109102, 5.922613240057423, 0.50294563955357, 0.7070142715688675, 1.3698290697028561, 6.0387766841919195, 30.394787711481897, 54.24991353865593, 55.52166754199613, 50.81642758461737, 49.91070916575771, 44.78200620220554, 41.54216766357422, 46.4870487490008, 6.691369356647615, 2.0222567574631785, 38.90051018807196, 76.61047120248118, 41.92421828546832, 12.889039785631242, 20.06143096954592, 39.67642561081917, 38.49921641811248, 27.77297546786647, 34.820499958530554, 43.92293260943505, 59.632256569400916, 8.799689412117004, 0.27767926274288085, 0.17659308779383862, 0.07294172871737711, 0.04921847165772512, 0.03231417470341248, 0.022595087254059412, 0.06646091599137553, 0.1179703008083086, 0.049456047014363354, 0.04124811587614879, 0.05570527136085495, 0.04400246626427097, 0.027982543124967528, 0.010857162771806603, 0.024985538217269128, 0.030499163023646803, 0.013237256226280044, 0.10584132099944739, 0.0715606637118805, 0.04290489975603358, 0.07318804130679177, 0.09122064021686394, 0.09289075019619158, 0.00876984513935543, 0.015508387080063264, 0.20163362154797201, 0.08418677329656579, 3.3871147132688955, 64.86474544771256, 59.03924519015897, 31.199118744942453, 35.043012096035866, 48.25219769631663, 28.761371566403298, 27.387082884388587, 32.87918952203567, 86.29555625300254, 46.98721762626402, 9.4109849199172, 7.603125283795019, 54.9676602117477, 65.07896177230343, 49.042272875385905, 66.25804193558233, 68.1486165138983, 58.81048471696916, 56.36705990760558, 6.739487032736502, 2.7156679428392843, 22.56370309860476, 20.249388987018218, 4.7464071935223, 2.6609320025290213, 6.257745940839091, 30.628972822620025, 54.784038374500895, 59.95810747146607, 52.68442892259168, 58.018671927913545, 67.22972285362982, 62.258503052496145, 63.774036284415956, 63.649826588169226, 53.320919775193744, 54.430754415450565, 51.037868915065644, 50.755842654935776, 52.71365058037543, 49.17506471756966, 49.196625986406886, 49.05825653383809, 49.81663111717471, 50.54817276616251, 47.05432153517201, 50.00333593737695, 56.58117425057196, 59.03804102251607, 58.46576721437516, 57.725714022113436, 60.146973517633256, 59.896134022743475, 63.549045208961736, 61.5440825493105, 55.52446419192899, 48.110109836824485, 50.049937617394235, 58.59973968998079, 57.21477039398686, 56.039620445620635, 53.204394002114576, 52.58928398932181, 44.198526182482325, 44.300146948906686, 41.951506214757124, 43.622055438257036, 48.87265782202444, 49.91192117814095, 54.22367680457331, 55.34080705335064, 54.55704296788862, 59.77847076231434, 51.14836992756013, 50.18376104293331, 56.48211086949995, 52.692140302350445, 55.63081141441099, 52.08997018875615, 44.83069850552467, 41.91016443314091, 49.50497135039299, 53.96773038371917, 51.98813761434248, 52.33962905022406, 56.577157743515514, 57.160210224889944, 48.99134874343873, 45.33779036614203, 45.57207745890464, 51.249041480402795, 53.56625618473176, 54.72101373057212, 55.34183471433578, 53.27221962713426, 51.62577729071341, 52.56461620330811, 51.287943547771825, 52.668268757481734, 48.997040102558756, 48.35925486779983, 45.34354448318482, 48.294829937719534, 48.59118853845904, 50.19975646849602, 50.164910131885165, 56.146787443468654, 55.96197712805964, 59.38337433722712, 58.9344512262652, 57.24554531035885, 46.45941172876666, 37.394971155351215, 28.70332637140828, 22.348959215225715, 18.28812937582693, 13.626559126761652, 11.42481605852804, 9.044434524351551, 4.1641891964020274, 3.1330201414323624, 7.278303513603826, 0.7136795429452774, 0.9820359753024195, 1.4652558007547933, 5.294347107410431, 33.68558960576212, 57.028281304144095, 61.36680318463234, 53.85505245577905, 56.29057761161559, 50.43990358229607, 47.80992300279679, 45.75130231918828, 6.854523285742729, 6.032144936823077, 38.15991570872646, 65.89537174470964, 47.895442439663796, 19.566551408460064, 28.374694508890954, 25.440338004019956, 45.200009269099084, 31.07517969223761, 21.261536998133508, 49.32455801194715, 67.33123379368936, 9.657110706452402, 0.510859726177108, 0.18155292487673222, 0.05072775679910856, 0.07362199181150045, 0.11465505531598484, 0.014353262470854868, 0.02623866270897129, 0.03873496444054669, 0.03740816144272685, 0.05186712872537394, 0.05743068522743641, 0.13957594911898338, 0.15971319840079354, 0.21874261719565238, 0.15031657842618806, 0.17536412954570788, 0.10031727548207968, 0.2539595565007579, 0.18228530493234435, 0.20709875490396254, 0.1622968758907049, 0.2197269482478019, 0.16995283684903578, 0.1279027456597936, 0.12198624095969623, 0.3739576690619992, 0.18521392117104224, 8.83497799596479, 85.61337763263334, 61.66008664715675, 57.4883282569147, 43.86978057123, 77.02370074487503, 57.61035711534562, 23.53268542597371, 34.14639749834615, 101.91200240965813, 67.1287218216927, 9.501328872096154, 8.64716608678141, 59.347739604211625, 75.59289855341758, 59.47425565411968, 74.15058812787457, 74.18748194171538, 65.36343559142082, 61.11408879680019, 7.11441659158276, 5.745029401394629, 30.142808768057055, 26.20645142370655, 8.15573379878075, 3.1846878076753313, 7.959793758007788, 35.02226668019449, 60.63775616307413, 64.44482434180476, 59.30126736241003, 62.30930951333816, 66.37048844368228, 64.7511653746328, 65.92322057293308, 66.17830799471948, 55.23083556082941, 57.20086951409617, 54.863909598319765, 54.76621904680806, 53.784932244208555, 51.20271828866775, 54.18051504319715, 50.994220779788115, 51.67865868537657, 55.05922009868007, 50.57336222740912, 53.60994354371102, 59.5656821804662, 63.735546065915024, 61.99298212605139, 58.97149801254273, 62.87140084851173, 64.6172478122096, 67.25005642060312, 62.162750151849565, 58.74862501698156, 53.41679426931566, 51.55111497448337, 62.417209994408395, 62.265245606822354, 61.85304372541366, 61.005258713999105, 59.42419836598059, 51.58113679578228, 49.246404786263746, 47.842137429022024, 47.505849099928334, 52.318856177791474, 52.957657306425034, 55.89427701888546, 59.43500057343514, 56.86271805917063, 59.38668089528238, 55.85106034432688, 49.5507061866022, 57.08963894074964, 57.386374089025686, 59.753402894543065, 56.07899711978052, 48.863299046793294, 46.40897397072085, 54.33506035035657, 59.406088782895004, 55.60333521135392, 53.70900692478303, 60.99133822225756, 60.47793134566277, 50.994648318136896, 47.14607361824282, 46.54929676363545, 52.31371395049557, 55.293228703160445, 58.493074755514826, 56.386809041423184, 54.18801853733679, 54.19583974346038, 55.99543102325932, 55.540204663430494, 55.79694732542961, 52.946882555561686, 52.51245260238648, 48.53165480398363, 52.15026486304499, 52.49975981250886, 52.260075538389145, 53.04767570187969, 58.537236721284934, 58.29410076141358, 61.16175343913417, 60.99451141972696, 60.78770837476177, 50.242106299246515, 40.809649344413515, 31.15481165147597, 24.258941681154315, 21.93325661843823, 16.820137231580674, 15.846688305177997, 12.454890281923356, 5.334893138177934, 3.4669256306463674, 11.144426407352572, 2.7932097690720714, 2.0400673823971904, 2.6615789484593178, 11.387533930040176, 33.066572912277714, 62.392377468847464, 64.73519348329114, 59.44634406797348, 60.056084356000355, 56.529395041927216, 50.794619206459295, 56.34735391985986, 11.269757901468585, 3.660823097152095, 48.80569904081283, 82.8259531144173, 50.680627284511445, 15.071821135859336, 29.325939878340694, 53.75406319095243, 56.72797287664106, 36.26353210018527, 50.939048720944314, 60.23530137154364, 83.31139349168348, 18.52819411985336, 0.6045663140473828, 0.3887512865326097, 0.16377594652435473, 0.12496957885882548, 0.15570634405218786, 0.12858293980600374, 0.12818795253312396, 0.22400754113351146, 0.12265311283690315, 0.2580269317953818, 0.17259250004445353], [0.02479784284538079, 0.033780677664664485, 0.04342712274181747, 0.06341198947460902, 0.05688189814287809, 0.015183224891042037, 0.049747348117131385, 0.05715058433012136, 0.07014603639442114, 0.023026574786091526, 0.06642866368976331, 0.03242574391826507, 0.07262001009357553, 0.03654714373330917, 0.07358813838612649, 0.025593444306944168, 0.02911035095401589, 25.8720419099254, 58.65930088104741, 44.22004430524765, 41.3923684243233, 45.52089837289626, 53.28677554284373, 26.655421603110533, 15.55570923512982, 37.819924662190104, 85.23395107638451, 21.317162090732207, 2.006859370777684, 34.67661957586966, 65.71145965207008, 59.9462579911755, 59.066180106132265, 60.029757407403764, 50.12946367263795, 62.800103925889545, 15.493022895628407, 1.054850119736887, 2.3421357283669137, 5.948872527768535, 8.73177553376844, 4.354178021031042, 20.042550640721476, 21.98363357974637, 42.62662849118633, 55.19533026602961, 55.5362940603687, 50.01456960555046, 60.60310202260172, 59.719564607066495, 58.32295371640114, 56.021773661336596, 55.32335250608383, 49.73891719695061, 51.47537792882612, 48.55063515324747, 47.637844700967115, 44.82209674773678, 47.81959556764173, 44.26498682268205, 46.12692025399978, 43.59953711109777, 45.853013300126605, 53.70151127538374, 55.53789046502883, 57.88759023912492, 58.075181514986106, 60.46403831051242, 57.277053709953066, 57.17139290225122, 57.424652499537316, 54.81398174839636, 46.4125943183899, 44.101541657601636, 43.25951468560004, 52.6406591938388, 51.83422773115097, 47.29580225483064, 45.86682396550333, 45.35231882526029, 38.535651314643125, 36.133846775177986, 33.92172021250571, 37.51135964547434, 40.85553715305944, 43.88280284020209, 44.68658670302361, 49.7933949962739, 51.47246360778809, 50.64151340915311, 46.85070345478673, 47.55930316063666, 51.27415641661614, 47.352166714206824, 48.25385293652935, 42.820201381560295, 37.00290280003702, 39.263698131807395, 43.86964328827397, 47.47322674720518, 50.70613445774202, 48.602484964555316, 51.54087758833363, 53.62053394317628, 46.700264869197724, 41.83155229014736, 42.78128754708075, 44.501697940211145, 47.41888623083792, 50.86833230910763, 51.70333039376044, 52.72072261379611, 51.644608589910696, 52.87926481616113, 51.37837771446475, 52.14647585345853, 54.03041378144295, 52.62534626068608, 50.43372977164484, 50.567615955106675, 48.94506085303522, 51.025972366333015, 47.04184447565387, 51.8707214632342, 50.253626300442605, 54.59679226721487, 55.299308376927534, 54.66399423537716, 46.88505949512605, 40.93142717115341, 34.27589847195533, 25.860192429634836, 21.733741337253203, 10.296220721737033, 11.527135006843075, 4.201420334077651, 0.63915322264356, 5.5132168339144805, 1.410318961547267, 0.05110937200727002, 0.5542836734844793, 0.3606050936204772, 9.332813062975484, 43.639239341981956, 53.608303992978996, 52.37045495740829, 46.57295650051486, 53.9733079941042, 57.83576396203811, 58.87337600031207, 35.90583155232091, 2.6542583348289615, 12.654039802089816, 64.43184129653439, 66.90738247286889, 23.434934077724336, 14.27470334114567, 36.24426934026903, 44.76545772244854, 39.03199588098834, 29.850427450672274, 28.430237231716035, 43.267453562828806, 47.9306221777393, 1.3959730152160892, 0.08293547592456303, 0.0659123587331945, 0.07925311343804484, 0.024266725578796, 0.03796882672055114, 0.06861733858503642, 0.039117311262675834, 0.04201939021567664, 0.023385282050097184, 0.04770562420749376, 0.04420157251579147, 0.01981378206232142, 0.028092061139402852, 0.010916345936786986, 0.09809198924490521, 0.01005379509391083, 0.01013968408393163, 0.017471851277796012, 0.09193596715528159, 0.081277217325424, 0.043194963626803896, 0.047881996799861236, 0.047613168886351975, 0.01750907165959718, 0.11168622712214148, 0.12976052419793221, 0.09745261992417997, 0.2198627143497429, 25.893128571971772, 71.93597870488321, 44.99805427366688, 39.06738742705315, 58.10077498036047, 31.829994724642848, 28.597036023293775, 22.758287960483184, 43.22941833926786, 80.12773113866007, 24.097932307950913, 3.976315509888434, 35.92443927641838, 70.93734325901156, 64.72011981471893, 64.23769181774509, 65.85920749172088, 56.042828944421586, 66.34256901279574, 16.38731937254629, 1.6196377166817266, 1.6737056283220169, 9.447198202533107, 11.265943396476008, 5.041420421292705, 24.284943073026596, 24.570936810585764, 46.14346088901643, 59.261023844442065, 61.583082675933845, 52.93078907074467, 63.43620254147438, 64.56314656042284, 62.67463907118767, 62.08505192110616, 59.44799538581603, 54.04267903297178, 54.61387811168548, 52.48141880958311, 53.552006213895744, 49.649965686182824, 49.424307807799316, 47.22190872315438, 49.928422589455884, 49.723737624383745, 50.32048702239991, 55.58797520975913, 58.459542412911695, 60.89987639457949, 60.39358077510711, 60.434522474965746, 58.44217023541851, 58.40475866871496, 59.97566792272753, 57.54755604651667, 48.44807301798175, 48.75223321299399, 48.51734599759502, 59.956711107684725, 59.2591058054278, 56.064719692353286, 54.34916127112604, 54.43935617323845, 47.269800862958355, 44.715223927651685, 43.30354329078428, 44.422626879907426, 48.05041136280183, 49.54319484772221, 52.2473160682186, 56.81325304892756, 57.211354009566776, 56.90130633692588, 52.62423230755714, 55.433390678897986, 57.820760896128995, 55.60750861321726, 54.881164104707786, 49.92379811502273, 44.57708197255289, 44.67561975602181, 49.50645400631813, 52.77139571405227, 54.82474865451936, 51.7380198355644, 56.54338613633187, 57.83395574938867, 50.19359442495531, 44.60057696988506, 43.78540254408314, 49.09694287084764, 50.18859340298561, 54.29936678178849, 55.32689048397926, 54.463223795736994, 55.14615158880911, 54.979148833982414, 53.621165444774014, 54.721441268920906, 54.099561245210715, 53.15523101437477, 52.1653816776891, 50.74410692338021, 50.60099140290291, 53.8981318473816, 49.647627953560125, 53.46856171084989, 53.38574478703161, 57.68668251652872, 58.798933336811686, 57.74656534194947, 50.18679695744669, 45.440595688358435, 36.350977420806885, 27.564213199000207, 21.73526517806515, 13.56206947757352, 18.225734272310813, 5.863195215502094, 1.5759146886487163, 7.785245833858368, 1.7299134380394414, 0.11716635281881017, 1.3319096786360587, 0.8248752439695021, 11.777439098204336, 48.37357936366912, 58.782981057320875, 57.14668981490597, 51.27343470050443, 60.92417547779699, 64.04593890713107, 64.91892514690277, 35.30591680157569, 4.093484551675858, 19.316668971892327, 57.89341888120098, 63.971857101686545, 34.49934805593183, 21.779517358349217, 33.353247181061775, 30.941066011305782, 48.38194577924667, 26.47633206459784, 26.617672712572162, 51.65443804956252, 51.25432883539508, 0.9958235354673479, 0.13504843077351972, 0.03193589389294146, 0.041962944857415654, 0.01433462450926703, 0.060957888096210465, 0.061720693333735394, 0.16022344360188132, 0.007492937448043978, 0.031688198514823476, 0.06928290045189281, 0.014415200679532945, 0.10335740347903583, 0.09572283935643013, 0.24985502594180647, 0.22218605984122525, 0.1044861421049122, 0.128160250793782, 0.2519288719181092, 0.24938765102096144, 0.1598243117933312, 0.1963946220254706, 0.14158464697820528, 0.13509065753990604, 0.14464591900187154, 0.21568353618344954, 0.32282172912551516, 0.2719641548971976, 0.21007735071884048, 51.590413201239805, 79.85402030329551, 62.915076440380474, 57.82281229572912, 65.1168244115768, 74.75904187848492, 31.18697704807405, 20.79641449835993, 46.20876050764515, 94.3970549491144, 27.059857191578036, 5.233987714013746, 42.097571357604, 78.4526123539094, 72.09554072349303, 69.37722052297285, 71.5992118466285, 61.28934421846944, 73.27466011047363, 20.643153767431937, 4.584787401460833, 3.628733696476106, 18.29787842689022, 13.965799039410008, 7.849048577970075, 28.950180738202988, 29.27673766689916, 50.56283066349645, 60.2481863575597, 66.94048727712324, 58.701074123382575, 67.19488436175932, 66.27253117099886, 66.19583314464938, 63.42743212176908, 60.9259444667447, 57.06067223702708, 58.231680162491344, 53.79665228628344, 57.30634989277009, 51.07362131918631, 53.89647268479871, 49.374854564666755, 52.377009237966234, 52.91149885423722, 53.3739149185919, 60.69962370780207, 61.91062804191344, 65.35192343496507, 63.26107263565064, 64.416763705592, 62.796785600723766, 62.05646176492015, 63.82459171356694, 59.054589502273075, 50.562818896385934, 49.472607874101215, 50.51576222142866, 62.86538785503757, 60.56017952580606, 61.31698908344392, 58.596837136053274, 61.2305086658847, 53.24570440476941, 49.1615011615138, 45.72330836326846, 48.41048102225027, 52.17891777715376, 50.62660055775797, 53.0295386622029, 58.98712473530924, 59.37400771725563, 56.35897198031026, 56.294762780589444, 55.73964934195242, 57.95869104323849, 60.87856223506313, 57.52291571709418, 55.407985487291896, 48.33791325169225, 50.407465580971014, 55.700280512532885, 59.58863981308476, 58.7340691012721, 55.08626876338836, 58.29239060801845, 60.34293905381234, 52.92973003079815, 46.61101918066702, 45.788741342483036, 50.97043160469302, 51.356565413936494, 57.53150570777155, 57.920612673605646, 56.39299461918493, 58.24031722161078, 58.79731732030069, 55.173619947125836, 57.88462492727465, 57.73626519787697, 55.94126701354981, 55.09876543475736, 52.728920367456254, 53.57492854518276, 58.00172728876914, 51.744272093619074, 58.3355680588753, 56.26312494277955, 61.87621708839171, 61.264833327262636, 60.58380003898375, 53.40170491126276, 46.20156688074912, 38.757292685970185, 30.03765590729252, 23.674998821750766, 21.85809223882614, 24.70325404597867, 7.905200248764408, 2.119675317118245, 11.290996555359134, 3.5143500278072977, 0.5145386642506046, 2.398298675975492, 1.656050549880151, 14.95062578109003, 50.59112271954937, 63.259962604891875, 60.55500199717861, 56.800595560381495, 65.22062601581698, 67.8290061027773, 66.25168769590317, 42.577485115297385, 5.553321107741326, 17.579417882427094, 73.90503206560689, 74.15495764824652, 29.834990962859127, 18.973881275423114, 47.744133087896536, 64.66777578476938, 56.42280463249453, 38.81494760513306, 44.14619391964328, 57.57324364877517, 72.69567904933807, 4.6203250558145585, 0.5351884723190339, 0.19377300786154886, 0.27130063082421985, 0.1026636112721697, 0.1375125066166924, 0.14210112813499667, 0.2774755752855732, 0.16555356162209667, 0.09352340092582088, 0.17634407857493048, 0.13882717478179163], [0.10945373199759953, 0.0323043879301798, 0.034024014002493316, 0.03791064617314166, 0.08128752120800557, 0.030885367098474698, 0.06157442799679214, 0.009229501724363336, 0.0763158633884403, 0.04569824018906202, 0.0360510022109074, 0.0607238175918258, 0.03822929278436688, 0.08923868648707868, 0.01905021073687221, 0.055937533897738305, 0.09826128701529196, 4.62918863181145, 61.13335940145678, 46.118067464520855, 42.2696888831354, 41.48626604387837, 52.816200948530636, 38.923448208839666, 16.872867614992206, 30.73649871733881, 71.20422917027628, 45.479858613783314, 4.488630006390234, 13.401772014556395, 54.44895421305011, 61.41561315905664, 59.462249279022224, 67.2951558328444, 62.3389155633988, 55.109991258190526, 21.344142113962484, 3.395642681467918, 0.6440462568594564, 0.8822541876185326, 3.7776366741426535, 3.702870905399323, 19.4551404060856, 29.490198935231856, 35.24954449745917, 47.79359417576944, 55.49712527182795, 51.37177636546474, 60.39458097950105, 62.78510478235061, 62.94707121387605, 55.183033635539395, 54.68463374722389, 47.8579955716287, 52.24857122667375, 46.7914991994058, 49.42330760340537, 46.143221624435924, 47.010987189508256, 45.69751485701531, 45.546887997658025, 45.658781451563684, 50.2590823173523, 54.93948582679995, 60.481590917033536, 59.70964101053054, 59.80960261437201, 57.71939116139566, 57.010967962203495, 57.12906660572175, 52.45833566111904, 47.521405220031745, 48.03882860368299, 47.43419916399064, 43.41555833816529, 54.434853292280636, 53.26551629650978, 49.60559975716376, 48.246529871417636, 46.51002207110005, 39.96039736655451, 37.3562220604189, 36.93740314052951, 39.70804383677822, 40.50579901664488, 44.96040344238282, 46.77700604161909, 51.16298075645201, 52.993950997629476, 55.69051773317399, 46.75296975720314, 56.379407528908025, 54.96118045622303, 49.280011653900154, 47.70278738391015, 43.661063409620716, 37.79426451652281, 39.18821996258151, 44.51770905525454, 48.68607459529754, 47.08134274328909, 46.4263932166561, 51.576877101775146, 54.38489014102567, 46.60062097734021, 41.663011966213105, 45.39571985121697, 42.37238830135715, 45.356696190372595, 50.78179305599582, 53.134187498400294, 53.83110246350689, 57.22436058905817, 54.4408231396829, 55.50481703973586, 53.70104451333323, 53.193305461637436, 52.890957401644805, 53.35294985002088, 54.63943627572829, 52.708971192759854, 50.459287935687655, 50.594998021279615, 49.67347245062552, 52.586773672411525, 55.76794532037551, 56.65347137758809, 55.49287734493133, 52.13493624041158, 49.40841436386109, 36.92780902308803, 37.31860260809622, 29.607509182345485, 17.104432582855225, 8.777542729531566, 4.095542570275645, 6.818771862214612, 3.5516760378114642, 0.5498787292069005, 0.28173680146855695, 0.27699922181425557, 1.4695856071287587, 14.181178346756967, 44.22993652282223, 57.90844155896095, 55.30261101261262, 56.62049208917926, 57.728981356466974, 57.59645231308476, 61.072205728100194, 23.812064086237264, 3.875475540276497, 25.644140435803322, 55.42329842044462, 43.20024767229634, 8.211784958839417, 25.32035662281898, 35.11143392132175, 44.433895849412494, 30.26949347988252, 29.987900641656694, 36.153388023376465, 53.92076784564603, 23.515201460930612, 0.19811727797552464, 0.22281601394136108, 0.041601247935285496, 0.061134072997036486, 0.02677104210541133, 0.033918604134551944, 0.06364779133770256, 0.033035377536209366, 0.04076654151562722, 0.06363977039713534, 0.07289369500452474, 0.040721323175896565, 0.01763935831765975, 0.07545241334986302, 0.05521339311775181, 0.04979381901061824, 0.030371258899028745, 0.020321585358150547, 0.028554824210943717, 0.032545923961386565, 0.034465410881825996, 0.039934003124794656, 0.03732598319108929, 0.06005137242496975, 0.07110233628942121, 0.12467966820564001, 0.07394992340836795, 0.18582803257290395, 0.2681358296784663, 7.009801585828105, 74.729475052126, 54.64191913604737, 41.97537383725567, 53.119086373236875, 44.0890645980835, 30.06580871920432, 23.92778773461619, 31.50035873536141, 74.96545268643287, 51.95163211514873, 8.18542270891128, 14.35316643407268, 58.57237723565871, 64.31767679029896, 65.05503139188214, 68.7235418442757, 67.46610056969428, 60.357416522118356, 24.586559610982096, 2.4786415648075844, 0.15556838693878344, 1.9958979396089434, 4.427719029688067, 5.1902841752575295, 25.300878132543257, 38.47251292197935, 42.09381372697892, 49.83354437735773, 61.30787741753363, 57.939475351764315, 65.06146015659456, 66.5972641975649, 68.53852364324754, 60.38737950786468, 59.93900552872689, 52.3682152840399, 53.93353908292709, 51.73113607591199, 52.43935923422537, 48.669165257484686, 50.794583905127745, 47.72938105367845, 48.54788949412685, 48.53564777681905, 52.86646612228886, 58.375336970052416, 62.103840074231556, 61.76039734194356, 57.48664948248095, 60.95305196700558, 59.681552917726584, 58.588882569343816, 57.77115075818954, 50.034271670926, 49.25644997627505, 48.54713247668359, 49.45802057943037, 61.04163869734734, 59.29537204004104, 57.7308758612602, 56.34858946646414, 51.96735689716955, 48.863118617765366, 46.24877260577294, 43.38043743564237, 46.13968364654049, 46.7010767998234, 51.15181376857143, 50.7790473968752, 57.154915025157315, 57.89101054591518, 59.22439675177298, 52.16811949206937, 59.31454850781349, 60.483426586274184, 52.486600260580744, 55.09288580186906, 48.3526692082805, 42.82783431391562, 45.74294374835107, 49.856737352186634, 54.93470837993007, 53.99381414536507, 52.8191388037897, 55.37784991725799, 57.851888825816495, 48.18067327622445, 43.94966748452956, 45.09235197497953, 45.48961354840187, 47.74444687751032, 54.434586571108916, 55.053136502542806, 55.5494418451863, 58.84811201403218, 56.11326294560587, 56.49277187162831, 55.19115686416627, 56.59889551901049, 55.0377215877656, 55.24852545030656, 55.30283458771245, 55.806568899462306, 52.22600190870224, 52.126416852397305, 52.427513676304976, 56.9302495064274, 60.71743126838439, 60.73370125985915, 58.6785008830409, 54.276436605761134, 52.74395873469692, 40.81965138835292, 39.82846844580866, 32.103583966532064, 17.662266185206754, 11.357383651118125, 4.809617659737987, 7.369399089967051, 3.291418196693544, 0.37158359322817097, 0.35669182457270165, 1.2516519787811464, 1.7689721550672286, 18.675504615229947, 50.28155749843967, 61.27976186813847, 60.082168117646255, 61.923171781724506, 61.399041145078606, 61.89846869437926, 66.34416149508569, 26.524802754002234, 7.5000213711492485, 27.73334383964539, 53.72780292264877, 48.42182843915878, 12.970282858417882, 32.228786022432395, 24.800560205213486, 43.53044063814225, 40.61584895656955, 25.689092759163152, 39.00434709364368, 63.78170844047301, 26.830033756071522, 0.5437761340891162, 0.08707900801973958, 0.07516470136902026, 0.039510950220808874, 0.05848451960651625, 0.02717779648880805, 0.039309656788264556, 0.008150733098567975, 0.01873680799748869, 0.052018124655249624, 0.023308972031959606, 0.01643421008221565, 0.18690211848626215, 0.23405630111453996, 0.18212336926690995, 0.19353319169773212, 0.1823807441659512, 0.2268444413259145, 0.10687528688821102, 0.1509679370229283, 0.23223246027144695, 0.14972548030557173, 0.1045062595738038, 0.12394489795570413, 0.10675806011403761, 0.2593135917859693, 0.14918439240465242, 0.37907057051216403, 0.522592822390218, 13.81859935099079, 91.11915373033094, 60.52554891955469, 59.512079069691325, 57.55022718060402, 79.02964007469916, 47.56865016875729, 20.752591817609726, 36.101251879046046, 80.20678258711293, 52.38407342664657, 8.350591755682423, 18.366308096916445, 65.01960454448577, 72.37172265206614, 70.46963199492424, 77.4367263240199, 76.25225682412425, 67.41146979793426, 25.978665659504554, 6.835220321532219, 0.8589617439335393, 3.2870587273951504, 8.493190503889515, 8.318746032253388, 29.103172786774177, 45.70504973011632, 50.98180647819273, 52.78935232470113, 65.47497603201097, 59.30871986573743, 68.4247592187697, 68.00451647850775, 72.04930382390177, 61.31249404722645, 62.76168038768154, 55.63049762479721, 60.35628295713856, 53.61384630203248, 55.24940013885499, 51.02209314223259, 53.982396125793464, 51.38420243417063, 52.96807904397288, 51.07760644728138, 55.27930036667855, 60.33436083024549, 68.4692467412641, 64.62179776160949, 61.65027287698562, 62.678977212598255, 63.72846618775399, 61.19785101183, 58.68947959715321, 52.34952519016882, 50.83325847502678, 51.27556062513783, 49.64061083332185, 63.41812433735017, 61.73343104700889, 62.3436184852354, 60.67373214229461, 59.05448752064859, 54.722210053474676, 51.25749418812414, 46.79463709554365, 51.32147981274513, 49.1101259569968, 54.425047366849846, 53.34372835774576, 58.01108606400029, 59.19022506283176, 60.15430834985549, 53.34809787811772, 62.690214803141934, 61.78437479080693, 55.936360128464244, 55.47219468701271, 50.54325411396642, 45.27637389398391, 49.7802903575282, 55.5754550041691, 57.98136234283448, 57.081335283094845, 55.47745066304361, 59.37720052657589, 62.848878598982296, 52.44941619134719, 45.771647653272076, 49.14931827975858, 47.00054976247972, 50.57666094072404, 57.40781768675774, 56.25042823053176, 59.423504106460086, 60.98818463663901, 57.729675615987475, 59.32549584296442, 58.510313572422156, 56.80014448781168, 56.882871197115996, 57.647117568600564, 59.96543445894795, 58.219999344118186, 55.20721112528155, 54.028852678114376, 55.61437668338899, 58.21920702534338, 61.35961348010648, 61.077163603998, 60.89898993892055, 56.64072367452807, 53.724264944753344, 43.165938700399096, 42.26207948500111, 36.475430304004306, 22.623028947461037, 11.518359684175062, 5.220424157957877, 10.364717072056187, 5.899603145737802, 1.1526256150776342, 0.712633434562914, 2.0456973319092104, 2.483412147529664, 19.18126286998872, 51.61286877047632, 66.99507882518154, 65.09430608441754, 66.4891166071738, 66.57582452220302, 68.46366128613873, 71.78105292781707, 27.85374687563989, 6.744635633883938, 31.871583615579915, 61.74773593102733, 53.46425102603052, 10.865184049452505, 32.73452270415522, 46.60771262261176, 65.70692931452106, 41.875447534745746, 41.80468013209682, 52.777283191680915, 72.26208456100957, 45.561687100318174, 0.638892385027101, 0.271300416319601, 0.14721415215922942, 0.12893529428589728, 0.1200752882587333, 0.1281130214732501, 0.12530242874016687, 0.1666321980977251, 0.1609627031270535, 0.1955920376724774, 0.09431382746345575, 0.14953054157235932], [0.0559534800178822, 0.025161958690131866, 0.08304019248293293, 0.049997242167592056, 0.06666618925068649, 0.05215300592563806, 0.04330663626352626, 0.0684632936252221, 0.03989939510281529, 0.04352305610213549, 0.05009763032918976, 0.017612767405807972, 0.014975638046199757, 0.03222355416284935, 0.04692075180730993, 0.10757601219079188, 0.042543800382484356, 0.40506773357910497, 61.50801635557606, 47.75567662331366, 54.61997347493326, 49.750492111329116, 40.71565366560414, 49.74555384728217, 25.372465310558198, 21.882765908395093, 43.727206337836485, 48.55580875950475, 8.902042681171048, 15.391995387692607, 52.89456990457351, 60.86240991469353, 59.236775752036806, 62.12767239539855, 58.007489250552275, 58.394183958730395, 28.116176974388864, 3.744426456189925, 0.23062329258649583, 2.0097577571868896, 0.817807745789328, 0.717862137863713, 8.972210941776153, 20.65189673054603, 38.19953164746685, 51.13108796458091, 55.7776806431432, 62.08072554680609, 62.85687238939347, 63.35314243070541, 62.76211577077066, 61.910012229796386, 59.05923751092727, 51.03842589163011, 49.0531260736527, 47.863188789736846, 48.54584593926707, 46.49895314247378, 46.852637183281686, 46.8259415318889, 48.55786015910488, 49.673139049160866, 54.21004656822451, 56.939263113083385, 58.138100254920225, 62.02765195600448, 58.177355335604766, 58.30547563491329, 55.65848373597669, 50.99023957406321, 48.39091231746059, 49.52321429406443, 48.532996254582564, 46.397148024651315, 44.70626523417812, 52.830235189007176, 55.02677425261467, 52.40966689202094, 50.81673745186099, 45.32069667693108, 42.670257014613, 38.266035433738466, 37.64774437873594, 39.764439675115774, 40.50622655499367, 46.12724973309425, 47.22974561875867, 54.66880306120842, 55.84207419426211, 54.88584741469353, 49.240882089061124, 61.97472349289925, 52.192881414967204, 53.36006110714328, 51.347081122859834, 46.72215953949959, 39.81648168256206, 41.01753888591644, 43.852718260980424, 50.04386578836749, 53.024419969128026, 50.3779693572752, 49.261545135128884, 54.014700766532656, 42.56121904619279, 43.38932944882301, 44.29268267846877, 44.117446868650376, 43.779817088957756, 48.37687807698404, 51.930412092516505, 53.9874912846473, 55.76361502370527, 58.93104660895563, 57.865040533004276, 54.63858904377107, 55.54131861655943, 59.00333981360159, 57.56180993972286, 58.28840547992338, 54.88567875277612, 54.211235046386726, 52.54406298360517, 50.96076296221826, 51.769104619180005, 53.67526669656077, 55.43114708315942, 50.363601715334006, 53.64468397632722, 48.28292554424655, 52.11702277583461, 48.533062934875495, 43.43820610354024, 29.61127858008108, 16.341978734539403, 8.28780637633416, 3.8251515309656825, 1.0587213765228949, 0.19539021946970495, 0.272003194737819, 0.22552082525385966, 3.845200235805204, 25.281121153985303, 54.03511278090939, 52.40727424621583, 56.0632017350966, 55.07234434927664, 56.07816165493381, 54.24418687820435, 44.58742134032711, 9.34675806953061, 10.12433167426817, 54.871256197652514, 71.95589650061824, 35.60072214372697, 17.005210345791234, 28.238409796068748, 39.641995045446585, 36.7600884745198, 34.16729980899442, 36.23156870565107, 30.461750415063676, 55.56604523812571, 9.53703224658966, 0.35936069103979296, 0.05712559071159171, 0.09007725398987533, 0.058842642728479645, 0.05548247767071571, 0.01460711240783454, 0.07103352627206234, 0.028513302245447715, 0.022211765585046624, 0.027907456932288986, 0.0871242531725476, 0.028543788714394457, 0.03572449553757906, 0.11711849530618038, 0.05410880924412801, 0.0389201125700868, 0.04004167295211265, 0.0319760637132511, 0.02625928005023349, 0.012358482513997343, 0.0009784764047400395, 0.05738753149466169, 0.03545956701160439, 0.03288621638691233, 0.017391881274600184, 0.023454641735541727, 0.05067299300384137, 0.03952120430767536, 0.09225121999700224, 1.8238057869095958, 72.08374223401471, 56.18582287142354, 54.30432858005647, 58.0607158137906, 45.78931400852819, 29.899937568172334, 30.71168384244365, 27.7695139761894, 46.088575163195216, 43.72028335448235, 11.173038136574531, 17.633993741004698, 58.67249573430708, 67.40866922563123, 66.66255597145327, 68.49108649838355, 64.80163451164, 62.33683670720747, 30.41211674290319, 4.72682083806684, 0.6087146495138446, 2.16880202293396, 1.2551295276611083, 0.7960828405714805, 9.903861130437544, 25.05579863825152, 40.55423244353264, 53.18155404060118, 60.381966637026885, 65.76223081158054, 66.4636996484572, 64.46944505937638, 65.11405914060532, 64.40141154873756, 62.71762432590608, 54.46965256044942, 53.77251009787283, 50.11328389567714, 50.14686722909251, 50.753399018318426, 47.62758770296651, 48.19597444226665, 50.888661953710745, 52.21143030351209, 56.445907392809474, 57.779862342342255, 60.11559063388456, 62.6345955940985, 57.75659876485025, 59.651884109743186, 56.21442871709024, 53.09212400067238, 49.89239561942316, 51.044176086302734, 49.66680049896241, 51.02784333690521, 50.3554706419668, 58.0437986312374, 61.606369787646884, 57.79146471331197, 56.76256818156089, 52.301895849166385, 49.279156577202585, 45.80147335606237, 45.80377578735352, 46.38482001519973, 47.50302891577444, 50.378455731176565, 53.615442706692605, 57.662355976720015, 58.11726070219471, 59.07045548962009, 53.6610520270563, 62.79984897182834, 57.40338148609285, 57.254554994644664, 57.401836072244954, 51.48689793002222, 43.85217305152647, 45.754977580039736, 48.89555269672025, 54.48050575871622, 56.166450285142474, 54.328870850224654, 55.44235329474173, 58.39390154807799, 46.85511219886042, 45.59373678699617, 45.741892553144886, 45.86206613048431, 46.70582679010207, 50.95483626088789, 55.131034774165, 57.74155255286925, 56.087700859192886, 59.31329334935835, 56.120491873833444, 55.04997114981375, 58.22301956915087, 60.174802734005844, 58.47285101490637, 59.24922927733391, 56.69250680554298, 56.09337652883222, 52.236933554372484, 52.74677107411047, 54.559600353240974, 57.67664124888759, 59.92470064470845, 55.36506691286641, 57.83112379812426, 50.98200651907152, 52.37461659216112, 50.241380660764634, 46.23125137821321, 32.76299518923606, 18.01518928620123, 8.985240074896044, 4.376804213370047, 0.5416172370314598, 0.43863323246759756, 0.42666510047931827, 0.6119903801910339, 5.3778215185288465, 28.16301791898666, 56.28621593598397, 56.34300401133876, 58.63461740555302, 60.90039806981241, 62.31516561200542, 61.53388046449231, 48.31368084876768, 10.588889352736935, 14.486849634878098, 52.006255042168405, 67.91179949237456, 41.07883376459922, 22.39184052713456, 31.73708946474137, 26.183013300741873, 44.726077125918486, 39.23884991676577, 32.33682182527358, 37.10869696832473, 63.60553910655361, 12.274497535920913, 0.5359193814858314, 0.10041828417489607, 0.12960076422220276, 0.031706530998851505, 0.01568254089028004, 0.024109577962888346, 0.030717704925806295, 0.01600535980786287, 0.011885740189632822, 0.04269997506672817, 0.058765846244510145, 0.018644507809151566, 0.176406346201416, 0.14765909602565153, 0.2109414519321534, 0.09768457602589362, 0.17612364443559803, 0.16701156483782878, 0.18407287917310194, 0.14479161360331122, 0.08301442894603937, 0.15088415764752897, 0.1305738797471408, 0.12634517399654274, 0.11274994786588416, 0.0956576529349531, 0.13563854830159297, 0.22972727615025737, 0.3023135860360438, 4.781269219613844, 92.98574693741338, 60.21026880510392, 72.2922162086733, 64.33785346246535, 63.64265649549423, 63.35348759928058, 32.36721431055377, 26.55388516764487, 49.30228679410873, 54.83404074945758, 12.442879984455725, 20.86648960267344, 65.72878083875104, 72.26850155861148, 71.07215512183406, 73.70532066591325, 71.98103889342278, 69.68648372157928, 34.685699862818566, 7.0377548471573865, 1.2662116942867156, 3.5498325238304758, 2.2238066456010266, 1.2184580631794468, 11.057183088794833, 26.62411912795036, 45.509233244003795, 57.37708199408747, 64.65043106386739, 69.15726969319006, 71.12276938653761, 67.14833367255427, 68.40852845099666, 69.7473196829519, 66.798921092864, 56.5391735107668, 55.04753143556657, 52.44443870359852, 54.24868191442182, 54.860469679678644, 50.82397030245874, 52.27418430389897, 54.8230149669032, 56.76955000046761, 59.62791450562016, 59.18913856629403, 62.38387377031388, 67.84973975150817, 61.820676326751716, 63.69230193476524, 60.80552378008443, 55.160887933546505, 52.0174769432314, 55.05984375553747, 52.835883402055316, 52.396334755805235, 51.37574972644929, 59.54406992081673, 63.99000590847385, 61.136238421163256, 59.55622926835091, 56.21467974878127, 53.29564402180334, 48.40298537285098, 48.23461763320431, 49.36384447159306, 47.902381112498624, 53.66474297738845, 55.5926271407835, 60.173520118959495, 59.616319979390795, 60.883508343850416, 57.34110209249682, 62.42662760519213, 58.23810500483359, 59.88343338812552, 60.449639289609856, 55.777817926099225, 46.76574491685437, 49.26778954844321, 53.857025407975726, 60.52772191263015, 61.412608623504646, 58.24879738592333, 56.59798552913051, 61.482819049589104, 48.830260922831876, 48.559413417693115, 47.931885180934785, 48.31703447526502, 50.109679237488784, 53.36038666386759, 58.04335148103776, 59.55904553013464, 59.85901663380285, 65.15592651982462, 58.44493158401982, 56.59002311768071, 57.31657158943915, 63.15141885511337, 60.88979590323664, 62.00686339409121, 57.78856608175463, 59.405857363054835, 57.6678551397016, 55.87751673113916, 58.09833134374311, 60.22729973639212, 62.324716583375015, 58.05035683416552, 60.20329875330771, 52.6910420387022, 54.4388384203757, 54.72814459954539, 49.11175766298848, 33.59968185424805, 18.702839612960815, 11.031466068760043, 6.336570382118226, 2.7201960740550875, 1.174910193489444, 0.7495678817072223, 1.1277227320017353, 5.997873227442465, 29.1862387810984, 62.95629662852134, 63.191360350578066, 63.6986679415549, 65.43621909233832, 64.89263742200791, 65.88215335722893, 54.31971603824247, 13.076888957331258, 14.012654692895952, 63.66653980747346, 78.91914690694502, 45.52937461483864, 22.541694679567893, 37.20529317855835, 56.25762577979796, 55.9098998192818, 43.03366068870791, 51.594994529601074, 42.61058991955173, 76.16968308725666, 21.940105076759092, 0.6875612766992661, 0.20043337627524332, 0.21965389410334252, 0.15000321782164036, 0.2509639075686855, 0.28812205238688376, 0.12309505363866208, 0.1255876662570142, 0.1785194924882343, 0.1496441677332886, 0.10362423190306272, 0.14100170003310328], [0.055947742019329345, 0.056470340388196136, 0.019711547628826192, 0.04253593648994162, 0.06061470368877054, 0.018800056216517286, 0.08563357630684491, 0.04764147966559376, 0.03754169439836856, 0.03630551194111186, 0.04406612817077868, 0.02992665211129333, 0.04588631094403325, 0.018901557120825016, 0.03576371923930222, 0.06567811968946649, 0.03054233973905925, 0.033559910277084964, 43.875468007979855, 66.05556134254702, 48.68013612685665, 56.800258236546675, 37.79406447564402, 48.477282908654985, 27.64641627188652, 16.417266668811923, 38.829350548405806, 100.21108227391397, 42.71417187106225, 9.774877909691105, 32.77613512931332, 55.17662840504801, 62.03587324388566, 64.97734492824924, 63.311004407944225, 60.57168383752147, 34.00621198838757, 4.602985728171564, 0.08352106587300379, 0.8314419045082985, 0.285882777384212, 2.128523693930718, 11.299074676729019, 30.177810038289717, 42.5522211290175, 54.11976929633848, 56.06129154082268, 68.04617204973775, 63.637922194696245, 63.00590284409062, 68.61934015827795, 61.88001002034834, 58.58561523499028, 50.23295148726433, 49.04092358004663, 47.50637469753143, 48.41002210494011, 49.32546800182712, 50.525964306246856, 49.17013037589289, 50.063006954808394, 52.29597699257636, 58.24131742600472, 60.41026261544997, 60.29381136740408, 64.29888471480339, 60.81384704959009, 58.89166209005541, 56.957376618539136, 48.64962793165638, 47.27027939211938, 50.25314777128158, 47.85462625565068, 48.18574097848708, 44.11914525493499, 51.6609295721977, 55.58713974491243, 52.625157986917806, 49.321694681721354, 45.09012014635148, 43.40299498650336, 41.08887895461052, 40.04033919303648, 42.29558437101303, 43.23118732821557, 46.29577044517764, 49.26810726042717, 55.39075843749508, 58.07096496705086, 53.61511322759814, 56.85863879419143, 62.37199291106194, 52.65670953258392, 55.16118211130942, 52.05400989901636, 49.99928020661878, 40.20765965984714, 42.56769095697711, 43.913656203977524, 48.52723037042926, 49.27725422766901, 49.812163537548436, 50.83677684107135, 54.160126563041445, 46.29228738046462, 41.4243749649294, 43.564506423088815, 43.417248879709554, 43.36273970142488, 45.612211150507775, 49.72171368137483, 52.904897505237216, 54.356362742762414, 57.30227062779089, 59.58396434783936, 55.32429387492519, 54.958183765411384, 54.728846703806234, 55.34748292738392, 55.94036094604, 55.951053327129735, 54.6982757506832, 51.07229555806806, 51.37132137052475, 52.872349677547334, 56.957239335583104, 55.54005561336395, 54.21094871336415, 57.526022234270656, 52.313094216008345, 52.122208149202415, 42.87911930391866, 43.383818518730905, 28.862056847541567, 20.183230369321763, 10.899801908000823, 7.823910107535701, 2.805351956236747, 0.5783115615767818, 0.2010880750153334, 0.27653245976374996, 5.322102289046011, 24.705723178002145, 53.059846816524384, 53.05344943077334, 58.237940265286355, 57.276304537250155, 53.33277317785448, 61.401720123906294, 33.463477550014375, 5.324771461948272, 38.47829449561335, 66.61648381140925, 43.76752045846755, 14.664788938337757, 19.40901921641442, 34.35861341414913, 42.03293069716423, 28.51761587204472, 23.210233257662868, 22.99759372588127, 40.704482755353375, 56.146301069567286, 2.2292329995862903, 0.03999945384660556, 0.052189659402375264, 0.035516881879659436, 0.02074701504992141, 0.010741357090732744, 0.056715588115396044, 0.046694602652062336, 0.020258894468086864, 0.029131918244304198, 0.029696492485762126, 0.04911431051310032, 0.04211590580281712, 0.07011931524762223, 0.05759519877873602, 0.02221844395652654, 0.02889786497689784, 0.029467619887943712, 0.047681308576777104, 0.06959892704241699, 0.01562261940806263, 0.06441311700449837, 0.033389666388111736, 0.0061538966744387105, 0.03705568438876541, 0.09216039261269955, 0.03522482234984636, 0.04869233779308777, 0.01183540725539769, 0.05356188758366531, 0.09447361042182292, 48.89015159299297, 73.28109279755624, 54.54875892208469, 53.82138675259006, 48.23353898140692, 36.74256332458989, 28.453553761205367, 23.735238582857196, 36.8516287496013, 81.92574562564974, 44.63236385776151, 13.57804136891519, 35.5715593214958, 59.81578034739341, 64.49055133327361, 69.95395798836985, 67.76649921171128, 66.4840175259498, 38.45402679135723, 5.240511105906579, 0.3776398553482948, 0.886083524073324, 0.5894483349496319, 3.294186899738927, 12.758336605564242, 33.930341582144464, 46.81082863961497, 60.52492526269729, 62.54508318439607, 71.52835815183579, 66.43148914460214, 66.24027359870173, 71.17634896309146, 65.0792912513979, 60.673100640696866, 53.69269770960654, 52.69384653337541, 50.148636218040224, 50.02840772751839, 50.52658011836391, 49.99476555855044, 51.72475437964163, 52.93682559843987, 53.31987250235773, 57.144144196664136, 62.845819150247884, 60.917487836653194, 63.69825609268681, 61.16436966003911, 59.64535728577645, 58.28743273212064, 49.68701639483052, 49.17211117282991, 51.195787460573264, 49.349131661076704, 49.016530359944994, 48.31574793784849, 56.682485149752715, 60.38905435992826, 56.70527804282404, 57.47110512948806, 52.79629491990613, 48.95002657367338, 45.60549605277277, 46.50886889426939, 47.01012819044052, 48.42768453782605, 50.812928830423665, 51.77641983955137, 59.05541320000926, 61.58118424877044, 57.36076493417063, 57.420443796342425, 63.98673465175014, 58.32494628044867, 59.80928882475823, 58.0199819995511, 53.364116837901456, 44.06166684242987, 46.31633543199109, 51.00315593904065, 55.365321866927616, 56.17955100151801, 54.476771662312174, 54.54565632727839, 57.45858492389802, 47.632765231593964, 44.55845463660456, 44.35202029443557, 45.52865289872693, 46.256111360365345, 48.407197998416045, 53.10677797563615, 55.96132209224086, 58.55848812287854, 57.536134104574884, 58.94926601840604, 57.718814572980335, 55.685053871523955, 56.081766313122166, 57.80558132356214, 56.58957204511089, 58.1058426826231, 56.399215498278224, 54.08650367490707, 53.44802418062764, 57.192424651115175, 60.05574310979536, 59.1803446123677, 57.4631937088505, 57.383793169452304, 55.32286613218246, 56.665567967199514, 45.273153628072436, 48.14411286384829, 31.572022399594708, 20.7255764930479, 12.114316763416415, 9.545207446621312, 2.915438178085512, 0.6321888092544772, 0.33323651059500636, 0.6052139341350525, 5.699585801170719, 25.705829512688425, 56.436297585887296, 58.19477065916985, 61.678659069922666, 61.93216577652962, 59.739494169912035, 66.78024276610344, 37.68991378045852, 7.770803176587629, 42.040559707149384, 54.30542292133455, 43.86143768987348, 20.578497417511482, 24.326763383803833, 29.436784098225257, 28.821917272383168, 39.89773750305176, 21.631730294996693, 26.43085610482001, 49.075895432502996, 60.515570409836315, 2.569243657973505, 0.07280200960174685, 0.04859202240984287, 0.037414933659977494, 0.03438927323347138, 0.02617100182349884, 0.016028290734656395, 0.07687807999431126, 0.03900722825839635, 0.003174636278286456, 0.02399273231745728, 0.060222964628689715, 0.05195488026666065, 0.1725653958536925, 0.24413789562400312, 0.09341051787017815, 0.12561886901817015, 0.26026093611313456, 0.16182678901860792, 0.18047761322269518, 0.22594120834142933, 0.1037699111827439, 0.15137695136570162, 0.164651922100494, 0.2265426946142989, 0.3704703142566066, 0.08238619088285393, 0.10972954663297824, 0.12087656260137597, 0.13984472340633794, 0.1927488402373368, 66.16977291722452, 82.58193462125718, 66.92701001321116, 70.0169434085969, 55.28853362606418, 66.35866641998291, 34.96814581655687, 21.13417175508315, 46.58164062807637, 107.12266722033101, 47.70316000907652, 16.045712309498942, 43.199812289207216, 68.48717197295159, 71.13474830504387, 73.84968742247551, 74.90491482519334, 74.12601840111518, 43.54344329526348, 7.159006095701649, 0.6552866053196692, 1.9352998945020863, 1.5733216342426117, 5.181735369466967, 15.490267430582355, 36.57624698454334, 49.66751829270394, 63.56786081867834, 64.1255473321484, 75.8247184753418, 67.2665931332496, 67.50996051296111, 74.26410936540174, 68.30723716366676, 64.01064542032057, 55.87927003060618, 54.574379844050256, 54.4868560760252, 51.68456577485608, 55.16685385857859, 54.99495206340667, 55.24274779904274, 55.35133861726331, 57.60059041361655, 61.55420618672525, 66.13256531376993, 62.85074956955449, 68.03518941325527, 63.67494936912291, 62.11698785904915, 63.09227735765519, 53.421771757064334, 50.15386473747992, 53.90781225696687, 52.60234548199562, 50.85987960138629, 49.41549424202212, 59.86209177201795, 61.416993833357296, 61.84787011915638, 60.97498978337934, 55.58590419830815, 54.20136636303317, 49.25543408240042, 50.29244599803802, 51.1137471660491, 50.72744861725838, 52.50321934300085, 51.953342268543864, 62.991629339033565, 60.8136470087113, 58.69088772804507, 61.46626272509175, 62.434680231155895, 58.95262748964372, 63.3020104131391, 59.66697739016626, 56.31846174117058, 48.65130670609013, 48.898474862498624, 53.4576222204393, 56.773519439081994, 61.28224865082772, 58.0363892739819, 59.421405638417895, 60.104168691942775, 51.64370252240089, 46.087186644154215, 47.18805474619712, 47.423977467321585, 47.9649233048962, 51.24180862980505, 54.15827128194994, 59.030576752078154, 60.91855472134006, 60.05559405972881, 61.72265237377536, 59.15104842955067, 57.697210158071215, 56.101217346806685, 58.50632452195691, 58.03438886519402, 60.423328030493956, 59.0189665363681, 55.98954746800085, 55.84657315284976, 58.013659138833326, 61.39180829448085, 61.292540950159875, 59.4934791903342, 61.831396164432654, 58.43668283954744, 61.43169095439296, 50.82045585878434, 51.46224191111904, 33.98206587760679, 22.195598463858328, 12.027549032242069, 9.284261964982557, 3.0258342671778897, 1.2467827239344198, 1.1456257777829324, 2.051779579731726, 8.525521620627373, 28.822180071184714, 62.66221692485195, 62.64318558477587, 68.10721981909968, 67.35341087464364, 64.1946320379934, 70.03431166371992, 40.102779403809585, 8.347220478519317, 49.45354123269358, 74.72672154826503, 54.118922064381266, 20.212683446945686, 25.847595737826442, 45.40907159928353, 59.996538854414425, 41.99402078505486, 32.84885391112297, 38.62588936282743, 52.68247950461603, 79.27532949755269, 8.703529565565049, 0.5916011645909279, 0.25282976067354607, 0.11654828074237994, 0.13082794514634918, 0.1303801973981242, 0.22894174491445865, 0.17349501290628988, 0.2222552069372708, 0.10409788108400761, 0.14536308455130748, 0.11932981576049521, 0.28550981513915524], [0.03745227661584655, 0.016889476983417428, 0.02846314263860545, 0.05627529440267433, 0.07520189493774407, 0.07304590135332077, 0.0707660083689036, 0.10398391784439165, 0.03720024134963751, 0.04358024456568303, 0.03381742690239222, 0.030966637535921993, 0.040466541484478986, 0.03777317935600877, 0.09920231111708189, 0.10272709697845483, 0.046388037247403015, 0.15677010310032677, 17.921732933290546, 71.6185962000201, 40.56561123940253, 40.85788273042248, 36.45838368323542, 41.29889834311701, 41.37930300927932, 23.27716850465344, 42.61111551715482, 83.88838198877151, 72.64167585680562, 22.857933813525786, 15.135519446865207, 42.70063577159759, 64.40696562490156, 67.4600052064465, 60.32878321986045, 60.20589536236179, 42.63240614245015, 9.108523111189566, 0.7019407470380107, 0.44405112884217696, 0.9440780346912723, 3.655488428569609, 17.56845485779547, 32.79930849229136, 48.27584566608552, 57.663105149422925, 59.72666801944856, 65.36506729741251, 69.81050122168757, 71.62242443330827, 66.37499132464009, 60.7763688025936, 60.97797470708048, 54.23793462014968, 48.788738712187744, 51.97212257692891, 53.557246500445956, 54.720162576244725, 55.90993119824318, 57.4222049405498, 54.31053376966908, 56.62219439783404, 61.26398609530542, 60.15581454000166, 60.382358874044115, 60.88036260297222, 59.866033754041126, 59.61135033638247, 56.65033740382041, 51.843484524757635, 49.99289066560807, 47.55478851256832, 47.40322420673986, 43.960716801304976, 45.70041348857265, 46.31816325649139, 54.03076679475846, 50.65353939610143, 47.51801236983269, 47.34093304603331, 40.65250350582985, 42.61999576322494, 41.57011455105197, 43.32166071861021, 46.992179424532004, 45.85483720225673, 53.44165817383797, 55.280445698768865, 58.89618066049392, 51.39249040234474, 60.62081936867007, 56.93868652466805, 55.59834987886491, 54.83244826716762, 52.96896549963182, 54.318456957417155, 42.29924002001363, 40.29184156848539, 41.80716299241589, 48.478655738215295, 52.115736238418094, 50.99068672426286, 51.364743555745775, 52.956955202164195, 42.097873380107266, 41.94841146469116, 44.08536580301101, 46.8891897509175, 47.96034197653494, 46.424934094952, 48.08680311326058, 50.750210131368334, 53.909283145781494, 55.943259577597345, 57.46051865239298, 56.506770810773304, 51.82491994673207, 52.83617757981824, 48.76273732031546, 52.83172961204283, 58.02566551393079, 57.561001931467366, 53.88543513513381, 51.926328905167125, 54.678730580114554, 57.60144941268429, 54.13711401724047, 55.623370678194114, 47.91287345270957, 52.29213306980749, 49.92052685829901, 48.74905609315442, 46.57487453952913, 33.20160835020004, 25.874632635424216, 17.80492671074406, 13.885737580637779, 7.553915717909414, 1.882201788886901, 0.27968432934534165, 0.5505566250893378, 6.581753819219529, 27.70356716648225, 52.70619807704803, 55.23369496868503, 55.020117990432254, 57.38595831778742, 51.29452920729115, 56.79625741897091, 29.37846825968835, 19.154633898888868, 49.73927413263629, 49.986277549497544, 31.674508048642068, 11.129015414945542, 26.522392457531346, 39.453462400744044, 34.45506841905656, 24.9410379317499, 39.91523127402029, 25.25917353168611, 56.734366340021936, 28.73200478092317, 0.07091095220417747, 0.036545362578885215, 0.03941648008842622, 0.011684475485385667, 0.052510569803416736, 0.026924282672905156, 0.02657722186056837, 0.03014874291576205, 0.057259135158552285, 0.010117558507068504, 0.08629554522133644, 0.04750223552447654, 0.055418574446511853, 0.048329556856544754, 0.03159365943452764, 0.01645816756682771, 0.04020855754553791, 0.07002838061101015, 0.05898379442852832, 0.04065743527345119, 0.07818320270387397, 0.0923649151058447, 0.029299256744824594, 0.05264638953151242, 0.0946582682550915, 0.08066125965166478, 0.11108102532283914, 0.03419898848439898, 0.05766679735613927, 0.11179326492692195, 0.23897267036860992, 18.43824044350655, 79.46403472654282, 51.578771606568374, 40.668698972271336, 40.966249973543235, 36.98163963133289, 29.389446973800663, 33.2175253283593, 41.215045913573235, 80.4217363172962, 69.15733245111281, 37.13705570467057, 19.742991385921357, 42.52121479280534, 67.3473939587993, 71.9780029789094, 65.8844518661499, 63.82981238826629, 48.52355118720762, 10.51576852798462, 0.817009237024092, 0.564243306796397, 1.0573981894600777, 4.219071980445616, 18.3611717531758, 36.42756169842136, 50.89542411988782, 62.57832527160645, 64.03517984574842, 69.79632577588482, 70.98490591972106, 73.74045725791686, 68.89876980935374, 64.02123581978583, 62.91982250828897, 54.9060280092301, 51.78419397723291, 51.54476465717439, 55.20929782621322, 57.56437516981556, 54.5869275062315, 55.97095543338407, 55.64974469523276, 58.4829197391387, 62.704119605402795, 62.17137544385849, 60.736160585957194, 61.01168355634136, 61.823014059374415, 60.09462556531353, 57.92260523765319, 51.53390753653742, 51.360676057877086, 49.03691884010069, 49.062920231972974, 47.96925752393661, 47.615538181797156, 52.615548179995635, 59.88138983326574, 55.81338597882179, 54.78536413561914, 50.86263702761743, 48.22550204492385, 47.69484458431121, 45.09183814448696, 46.92324769112372, 50.7656446579964, 49.89315263686642, 54.550618125546364, 57.492183946794086, 62.48397657948156, 56.30077969643378, 60.69324201153171, 61.9667689261898, 59.95454203697943, 58.437788947936035, 56.4259542957429, 57.0825590625886, 46.9785491881832, 46.27496619378367, 48.75178606279435, 53.6957650030813, 58.16984399672478, 55.998333577186834, 55.89750512953728, 56.27979893838206, 45.832048231555575, 45.49582266038465, 45.13081081451909, 48.10334374827724, 49.832704990140854, 49.950850702101185, 51.737635443287516, 53.141730216241655, 56.39880364941013, 59.28273024097566, 58.75841525293166, 57.510085644260535, 55.027962730776885, 53.84826283301077, 51.285017459623276, 52.86100226063883, 58.64029307519236, 57.19952414112707, 55.231004222746826, 55.37297048876363, 59.29322650355678, 60.60873454616916, 58.57679382447274, 58.69625745281097, 51.54289760897237, 53.02699696633124, 54.11286984720538, 51.80504921943911, 51.32295854630009, 35.982415829935384, 26.43565316354075, 16.332039448522753, 14.45202781308082, 9.009633294997677, 2.5105296988641066, 0.4095765287356992, 1.053276268705245, 8.20819010657649, 30.54265714460804, 57.66935348510743, 59.047333117454286, 59.808782839006, 62.266634125863355, 56.58003284085182, 63.46809925571565, 35.3783865128794, 22.252563045870875, 51.5132954812819, 59.32526834549443, 39.57619336343581, 17.520713729243127, 31.11568012545186, 23.964087309375888, 38.374963575793856, 32.90207066843587, 38.24170497155959, 32.81162277344735, 61.839593918092795, 34.31069381775395, 0.39122093949587117, 0.025078246347425927, 0.05356281071961407, 0.05880113225430251, 0.042105383585177125, 0.022507439134642485, 0.06267049297269794, 0.023048293378744877, 0.05465637058800748, 0.09972045468466897, 0.017748443492417856, 0.019355579129149838, 0.13307008531785783, 0.15016493898245598, 0.14422248688436326, 0.14911153744305336, 0.2745986086947303, 0.1711404876362893, 0.1120613573960239, 0.1257109221431517, 0.2231989659729504, 0.13907704201917495, 0.1201126580276797, 0.20432733990732702, 0.2460048059301992, 0.2733231642313542, 0.22029203002250966, 0.228397332191948, 0.19401412637483692, 0.18123012606895741, 0.39713811069246263, 29.72452917406636, 99.12135370316045, 58.721992123511534, 59.52639964319045, 48.95817333652128, 58.67502174069805, 50.64496117253458, 32.07055760968116, 48.825373649597175, 92.5187260104764, 78.9886591511388, 31.740437207683442, 21.17885539608617, 53.101827944478686, 74.95057905873945, 80.01063269953575, 70.7337800918087, 70.65838429235643, 54.36598823916528, 11.981977954987558, 1.564906924482315, 1.5390007726607786, 1.8658306738061292, 5.463757707226661, 19.89419287250888, 39.08393198443998, 55.15441602276218, 67.52605007540795, 67.73435146577897, 71.98124285667174, 71.37385599074825, 76.34542880519744, 70.55068385216498, 67.31849393536969, 64.25812344397268, 59.80412698561146, 54.986762154486875, 56.75256221525131, 58.50537138600504, 60.661388443362334, 60.3234056503542, 59.712308222247714, 57.89425042367751, 61.10745214646863, 68.14219167155605, 63.932225473465465, 63.74725041850921, 62.870934086461226, 65.85821120969712, 62.41258551997524, 61.3642301097993, 55.316331463475386, 54.947950301631806, 50.43783257084508, 52.86284969698999, 48.297626587652395, 48.25213493839387, 53.77431831052227, 62.15749809818884, 59.04305381159629, 56.903698982730994, 54.90202326928416, 49.165094052591634, 51.51156963840608, 47.83960750026088, 50.911250883533114, 52.76331170912712, 53.29420058957992, 57.83308106084024, 61.195732931936945, 63.319990558008996, 59.790484982152144, 62.99768547857962, 59.78922197895666, 61.31622029889015, 61.68320117458221, 59.71559124608194, 59.61086004011093, 49.782996792947095, 49.35801975188717, 51.24521716948479, 58.201046451445556, 61.33031337491928, 59.864715837663226, 60.24054165809386, 58.86014976809102, 46.25142412800943, 48.28560844544442, 48.398137323318, 52.55152333167292, 52.92299924358245, 51.906489556835545, 52.91590367594073, 52.98707900508758, 60.44102576471145, 60.15000943214663, 61.48146975424982, 60.38284917031566, 56.40593059601323, 55.52245201603059, 53.20408805724114, 53.39034964961391, 63.79571914672852, 59.47770733987132, 58.4404718491339, 57.045198486697295, 61.80326884792697, 62.75170972270351, 60.48393649439658, 59.591962060620716, 54.6342783589517, 57.663622902285674, 57.724199987226925, 54.49427327802105, 53.75826797177715, 35.17049697137649, 28.438380072193763, 18.823309329248247, 15.930958467145121, 10.623962206225242, 2.807605357900743, 0.7511937041436473, 1.9272493522974754, 9.949378275102186, 34.16574262803601, 63.42117201897406, 65.69743717870405, 61.78229985698577, 67.32534239369055, 58.585246532194084, 66.0234292860954, 37.07163057019634, 24.728931842311738, 62.99028396606446, 68.83758083466562, 41.1560260095904, 16.59121201884362, 34.05475916401033, 54.15205824759699, 51.289135948304214, 35.732839338241085, 51.714214970988614, 38.81408076132498, 71.35495801125803, 51.72888071306291, 0.4423851327550027, 0.21093176858079052, 0.18089572869000897, 0.13613538696400582, 0.13002749051778548, 0.13240869096930952, 0.18517345640688174, 0.18304186272284678, 0.19279128150834193, 0.23062985029912766, 0.1574081624107015, 0.22447866988518547, 0.19723354958959166], [0.0521640912179024, 0.02963600026804113, 0.023749736888754754, 0.04905274385706552, 0.0440642167814076, 0.059088135603815324, 0.05165498748782182, 0.009575441175500953, 0.14623774245621698, 0.02659959354317717, 0.033336882930128806, 0.010868552584020842, 0.03928257558014124, 0.05046260227719623, 0.013104614805460218, 0.07402155262928817, 0.08950094902707685, 0.09835907813882637, 1.6444572493914635, 54.615529429528024, 58.62636473871047, 38.05523157119751, 58.17305249552573, 44.20710832841935, 47.889911897720836, 22.949905549326253, 24.477731489366104, 67.20651026695006, 78.55705722685784, 37.65547537034558, 4.8814254710751195, 24.460567197492047, 53.706433849949995, 70.94491343344413, 54.988382093368045, 60.14911905411751, 47.064994304410874, 15.51504013999816, 2.1113868586478697, 0.2917997647197016, 0.3495043263800683, 6.434951761076528, 23.59944416630653, 40.78819397957095, 50.67510458730882, 59.30018871061264, 58.198575358236994, 64.56078921594928, 66.73696333362211, 69.98545462085356, 64.33782992824432, 62.70288013642835, 56.00130673377745, 54.51973338280955, 56.44515822010656, 57.742211511058194, 59.55292663266582, 63.47860336303712, 59.090655696007516, 60.357898973649554, 58.30676217232981, 62.969028642100675, 55.71007859322333, 64.24102191002139, 54.948150342510594, 55.83804592009514, 63.295938584112356, 60.99308367698424, 57.66123025648056, 52.38799971918906, 48.75688906638853, 50.49739768428188, 48.295900744776574, 47.30562779211229, 44.960195556763686, 45.362775864139685, 52.721287435100926, 50.922304122678696, 49.072063276844645, 46.08848102631108, 42.371039006017874, 41.01987269616897, 42.97209124411307, 44.42384673703102, 44.84642720991566, 47.31419032619846, 52.647672391706905, 58.13958291084536, 57.57547547740322, 58.55489915417087, 62.797730891935295, 58.86112643826393, 56.424636379365005, 53.24547690729941, 53.95675166960686, 51.97934758278632, 44.65529403378887, 40.53234169560094, 41.12876161452263, 48.85402264133577, 50.707954437501975, 51.260483034195445, 52.22263651509439, 53.16576650065761, 43.19296383088635, 43.974233288918775, 43.43580953536495, 48.197861102319536, 50.104701749740116, 50.232339597517445, 47.36195695015692, 51.21613671702724, 49.54193968926707, 54.66644963910503, 54.78654084667083, 56.73619416452224, 54.57006131449054, 52.89779409285515, 54.14974012682515, 45.802599076301824, 50.33038316234466, 55.07716494221842, 55.99085361726823, 55.24982767720377, 57.806479546331595, 54.654372661344475, 53.95180948318974, 52.243436844118186, 46.633815996108524, 48.63246363978232, 50.894031678476644, 52.693634725386104, 46.94174166648619, 37.452932019387525, 31.124289727980095, 23.878295267781905, 19.010739787932366, 11.901813533998306, 4.206320355015417, 0.6633648492636219, 1.0367005775051734, 7.323034223048919, 33.57481794972574, 50.59143650916315, 55.87510055111301, 55.06708052850539, 59.59666106008715, 55.34566686999414, 51.35694588384321, 36.28027669845089, 21.098046725796117, 39.937851582804036, 38.67684487373599, 18.020521748450495, 12.21279178896258, 32.102403333110196, 41.929184006106475, 27.292863630479385, 30.77273161180558, 38.972442534662065, 36.62594341462658, 60.90927831588253, 10.018670866566321, 0.2081506395892751, 0.11623538745146607, 0.03230269870630676, 0.05681613715545786, 0.04752534456671246, 0.04197629776993587, 0.029831910017697565, 0.037271667557257804, 0.028136915587369474, 0.06216847555591695, 0.02223458734431094, 0.05153080080485633, 0.03557172994459829, 0.04848802214368217, 0.02733108876723676, 0.019209407637977315, 0.008320560427232376, 0.0350364413292658, 0.014566186075699667, 0.17216798008209275, 0.018019860783111186, 0.08807065521156596, 0.02598100435739804, 0.0408651523532406, 0.015449633881930384, 0.01620878871049612, 0.05215258074684009, 0.04386735516750524, 0.09508501753331193, 0.08192812393028891, 0.07118197112915016, 1.599346192613725, 62.96069752785468, 67.46222526796403, 41.630244485793575, 55.91923898266208, 41.719046946494814, 30.681773808694658, 28.923328192003314, 30.944847176151892, 73.93743868797057, 77.97207493935862, 49.448022457861136, 9.579375213192357, 26.840694758199877, 57.34831925361388, 76.41357606457126, 60.096037618575565, 65.73321311704575, 53.05013895034791, 19.913736081892445, 2.4184883409930817, 0.3081755376150531, 0.5261241199989473, 7.158511877059937, 24.852078576241773, 43.71453315980973, 57.531513552511896, 64.02215757677632, 62.04918184588033, 69.63233147898029, 70.00918496039607, 72.68998376784786, 68.35500378762522, 66.67753942551153, 57.232197484662464, 58.25845426128757, 58.09731152749831, 60.25498382506832, 59.93375347506616, 61.77820490252588, 60.61725001181326, 62.679997028843054, 59.48834480777864, 64.2517731266637, 59.05624082011562, 66.31938780507734, 57.728534206267334, 57.8201803853435, 64.49373629785353, 62.886552964487386, 60.514425077746, 54.48981354313513, 51.42599528835666, 50.74481295001123, 48.14549353814895, 48.48723396178215, 48.00772028584635, 49.50068419979465, 55.822423119698804, 56.66675252299155, 54.663966778785955, 51.157403146066976, 48.20508218580677, 46.16262558967837, 47.58922300031109, 48.42985360853134, 51.41329857610887, 52.59986262167654, 56.80019547862392, 59.736979930631584, 61.00558427072341, 58.41673366485104, 61.245433284390366, 61.662349854746175, 59.38159750353906, 57.9388399277964, 57.84105131703039, 57.730687587491936, 48.48304879280829, 44.641463756561286, 47.82123511837375, 53.46231729753556, 55.30088124736663, 55.3614700994184, 55.68720725274856, 55.995105466535016, 45.134293879232104, 46.703559660142474, 46.017446902490434, 51.5001751530555, 52.29812645143079, 51.690284590567316, 50.570553810365745, 51.79419994354249, 53.57907449045489, 55.4544851856847, 58.08023745013822, 59.2032120304723, 56.300430605488444, 52.99942270401986, 52.50107772888676, 47.16319868641515, 51.271595108893614, 58.84793158500426, 57.51902864825342, 57.01640044489215, 60.5017440549789, 57.157248835409845, 56.431806472039995, 54.035293209937315, 50.047835226981874, 51.54223080604307, 53.959203150964555, 54.73234938037012, 50.29816481374925, 39.075043893629505, 34.24250733467841, 26.2672971910046, 20.33128023147583, 11.711647222118994, 5.161920535948969, 0.5891504799646716, 1.612611280814294, 8.568751042889012, 37.47502673056818, 53.84375602968278, 60.56745552247571, 60.291344196565696, 63.783147950326246, 60.533632924479825, 55.8825687439211, 38.163528211655155, 25.030042394515007, 41.11069125513877, 52.03437843630391, 26.68174070696677, 20.195791759798606, 28.957707766563665, 26.024796655101163, 38.79159381312709, 30.597095720229614, 41.02677214530207, 42.15191971871161, 69.53744149977162, 11.449801556525692, 0.37058964011169254, 0.048112914852437474, 0.0441830906446182, 0.03273651897606831, 0.016757127633618734, 0.0281799448308565, 0.03004538807867756, 0.03145804271973189, 0.02262013066830414, 0.042959682703498876, 0.07412390963685128, 0.058810842418742765, 0.04724092676394409, 0.15099513314424023, 0.09598507891379057, 0.16357535406226115, 0.12201532165730193, 0.10864832078016574, 0.12014724689746097, 0.24008078590756465, 0.1762973165680324, 0.19449660854954876, 0.09029876831318102, 0.16550679961519857, 0.05995152052491904, 0.08872619664837277, 0.17006964993573007, 0.15106902998541633, 0.18329864007330712, 0.2000112158636893, 0.3370918021086724, 4.078407941326018, 83.38199615478516, 74.84168621801561, 56.443710865512976, 73.36542375626104, 60.02245787651309, 62.397543230364406, 29.111841224854995, 30.549003539546845, 81.07697609932193, 85.62537224062028, 44.60191449811382, 10.922375148342503, 32.37851269783513, 64.04509559754403, 82.42740108120827, 67.82059654112786, 73.41423373068534, 58.64870263684181, 24.126191023857366, 2.601463967753995, 0.7350818945034858, 0.8864424822311249, 8.198023323089846, 28.419134962943296, 47.1341613800295, 58.13427202163204, 69.34114256212789, 65.3053923576109, 73.4352341005879, 72.66622204934397, 72.26551271254017, 70.8935146947061, 68.7198705057944, 61.09754816178353, 62.06327884427963, 61.78830500571959, 61.53519053612987, 63.8079216403346, 65.7534800037261, 64.05896117610317, 66.11566774306759, 63.076278009722316, 66.1912675057688, 61.36135109009282, 70.04810271724578, 62.08613449527372, 59.52148883573471, 67.6269099020189, 65.11449452369445, 63.62007541041221, 57.7070592295739, 54.550543600513095, 53.9537000656128, 52.11624222417032, 50.00846639756234, 49.66533745488813, 50.24846053892567, 58.4216130933454, 57.75380603728756, 57.30797767639161, 53.37623303936374, 51.255011327805065, 49.83367381557342, 51.05194237924392, 51.92558757720455, 52.79850713668331, 54.086299711658114, 58.57396971794867, 62.024792548148866, 60.60375705842049, 63.6668182957557, 61.32406111686461, 64.80650217302384, 58.00069178304365, 59.732347611458074, 59.145674782414595, 59.261270953762924, 52.20367970005159, 48.720724813399784, 50.305056418142016, 55.90469091169296, 59.3026598038212, 59.75437171997563, 58.76456160699168, 60.551562078537486, 48.47308597257061, 48.47139543102634, 48.42724523236675, 51.843715944597804, 55.26997297040878, 54.493296607848144, 52.94006155383203, 53.96873451048329, 54.23813858339864, 57.831155177085634, 59.59833591215072, 61.92577231314875, 59.37689458170245, 57.17230681450137, 61.24713951541532, 48.938353600040564, 53.05197069721838, 61.31839721433578, 61.34809740128056, 59.192135257105676, 60.876648118419034, 59.92302971501505, 58.02590870088147, 56.81979556237498, 51.94472089890511, 54.05582289541922, 56.232161752639286, 56.57529461768366, 52.162518347463305, 40.749656692627944, 36.77964148982879, 27.778980616600286, 20.51503739049358, 12.618936550232673, 6.117417264369227, 1.590322534884176, 2.565002104928417, 10.25445140177204, 39.861514414510424, 60.98441916127359, 66.36876260080646, 65.27576669569939, 68.97387535341325, 64.24798803944742, 60.80690837675526, 44.790423608595326, 27.940862717167025, 49.33052393697923, 54.41352344328358, 24.80012482212436, 17.378980844251572, 41.035032656884965, 59.79506631051341, 39.35684657865955, 42.102862634966456, 54.21495345331008, 46.48665258961339, 84.7269376631706, 22.642081860573064, 0.5569355634431685, 0.17740782230131089, 0.10172585070493723, 0.2017069974493596, 0.09502158545318151, 0.12377566913323057, 0.13079935474501503, 0.12440740821822999, 0.16751370482867764, 0.21134622214782625, 0.21388024181848575, 0.10388081773154198, 0.11807760674386256], [0.09062397263703809, 0.10061955079436304, 0.008702095196161781, 0.03321686376547141, 0.02718328359356571, 0.10217910662533776, 0.05139029261866405, 0.00412638321699154, 0.03174133820369119, 0.034913204595326416, 0.017295742985762416, 0.038603407991749626, 0.027209188856725252, 0.04152240216611855, 0.08359992696392922, 0.059425474760392984, 0.009357402018541771, 0.039055890163346645, 0.01437321618845266, 19.51706090281087, 70.86556388485816, 32.91576562389251, 50.192935466766365, 94.7749831599574, 43.61090413985714, 40.373167991638184, 12.935401220475475, 40.30269476675218, 53.716255464861476, 40.20039935265818, 25.10190413844201, 22.015730334866433, 59.19725395018055, 68.83323484851469, 65.59451418538248, 60.82076611057405, 53.84867075950869, 30.404140603157785, 4.53914228946932, 0.6817253414661654, 1.3464377700321137, 7.784017641698161, 24.898317437018118, 44.219459872091974, 57.067128458330714, 62.51245298693257, 61.79652629360076, 65.54353514025289, 69.57687700948408, 69.01133398855887, 63.70471623636062, 62.96308625128962, 61.40916086012318, 62.5696332993046, 62.5981253962363, 62.619074775326645, 64.75093395479264, 64.228607608426, 63.28315950209095, 65.08193100652387, 63.421662315245605, 59.35336036066855, 62.66327596479847, 58.94392375023135, 56.406926878037, 61.38972943828952, 63.187257551377826, 58.778309514445645, 58.040221429640255, 48.67304448158511, 50.86224871297037, 50.63041702393563, 46.608767740188114, 45.663629501096665, 45.85302114486695, 44.69991491686913, 49.66575714849657, 48.49064642383207, 48.361561221461145, 44.78228469048777, 43.251273785868, 42.31285456688174, 45.07410903130808, 44.908765439064275, 45.537403706581365, 49.93709887227705, 53.841390840468875, 57.92569998771914, 59.21726588279971, 60.27725896527691, 61.14523633833855, 57.76641253502139, 58.0699686850271, 55.8509740521831, 55.197546405176965, 51.40706200753489, 45.96176885789441, 39.96842645829724, 41.804374187223374, 44.421163835833156, 49.993781043637185, 46.67492243551439, 52.03247608677034, 48.951630823073856, 42.31172492427211, 43.41932381353071, 44.103757796748994, 51.678309594431234, 55.76440734248008, 52.62789580129808, 51.648903585249386, 50.416663539025095, 52.245743197779504, 50.52767053727181, 54.29053360416044, 56.00739817465506, 55.405530083564024, 53.84838834885628, 54.39883808935843, 49.4776677316235, 43.78002497457689, 46.871233140268636, 50.90225296635782, 54.41510023609285, 56.42987666591522, 51.046686403213016, 53.29102739211052, 48.28424738299463, 49.552941937600416, 50.6140999640188, 53.63211670229512, 54.31835497579267, 49.99425957279821, 40.553440124757834, 33.26435450584658, 29.902714606254335, 28.057921932589625, 15.739592890585623, 7.814871495769871, 1.391792136334604, 1.232027625364642, 10.071771913959134, 31.74005673777673, 50.79952216917469, 56.95159896727532, 55.92358889118318, 58.79078265159362, 47.68610162119712, 59.34724930794009, 21.05451430043867, 33.77660428324054, 47.301960376001176, 33.75067741640153, 12.310456845068163, 15.244206363154998, 39.20472921863679, 34.172304753334295, 27.385574733057332, 43.66781773105745, 34.31427886409145, 48.97815781254923, 30.808740931172526, 0.7652516627023298, 0.03450289939440066, 0.03474887107468901, 0.04799137883369, 0.02932202104749459, 0.08980861759834713, 0.03799948938972047, 0.05817968939100543, 0.028374412419995474, 0.054419825619627396, 0.05008284483225115, 0.13311986571117757, 0.031817728661060814, 0.06092226883817104, 0.06024952872746414, 0.019078469805179105, 0.06637096960818575, 0.015863485112335655, 0.039352864147193974, 0.010024847504081986, 0.021469119951249133, 0.06608805333774898, 0.0098617521730522, 0.08937777741061104, 0.05712164535878166, 0.03398643738980736, 0.07612087868995245, 0.025548635824253003, 0.04868026041696149, 0.031852528205021255, 0.07416496428871348, 0.0851292453045326, 0.07553819221474471, 24.87420270519872, 81.57521909283054, 42.3446963679406, 46.88147837115873, 102.62218675305768, 37.34316056774509, 33.03612355263003, 24.48321104049683, 45.622515216950454, 60.098536168375325, 36.6044056800104, 25.643191222221624, 26.840337822514197, 64.33832022451585, 75.24882824190202, 70.11180985358455, 67.7016467432822, 60.532362076544, 34.85230253588769, 5.988655167241251, 0.5573110691001338, 1.8883542716503146, 9.568741667655207, 27.01580309098767, 46.16403372057023, 61.01489989988266, 64.16797168793218, 65.04375065526655, 69.14585559598862, 71.96312150647564, 69.55318589364329, 66.89345805875718, 66.70558437224358, 62.91025976980887, 62.89970467167517, 62.653320989301136, 64.3290908875004, 65.11387086683705, 64.17998590776998, 63.63641992692025, 66.98779106140137, 65.33306467917659, 62.74395519687284, 65.2661882677386, 60.91849980815765, 56.98409188178278, 61.322688287304295, 63.46950346423734, 61.3797156272396, 58.75681884827153, 51.77771814407841, 51.76464096192391, 53.915841348709606, 50.81896143574869, 47.76618073063512, 49.62876919777163, 47.448045130698915, 54.85189145611179, 54.27585609497563, 52.52747920251662, 49.65676707606162, 47.64895677566529, 45.19480036151025, 48.540197726218935, 48.94565705330142, 50.81008511204874, 53.60828045875796, 55.687321001483554, 58.93548673199069, 62.97140167605493, 61.92914162912677, 63.010707747551706, 61.027969237296816, 61.90670567174112, 60.990439999488096, 60.35855008709816, 57.55597345290646, 50.77316384161673, 43.7270768996208, 45.80777660492928, 51.86328857175766, 54.97435569763184, 52.513480263371626, 54.956524602828495, 52.33790320734824, 43.28418247161373, 45.50643267170076, 46.258460860098566, 54.51454800944175, 54.852158177283506, 54.29737814011113, 53.29313370489305, 51.91878226495559, 53.61986714024698, 53.82496787655739, 56.475446762577185, 58.409336074706054, 55.67581276739798, 53.396919619652536, 55.56715526888448, 50.44266885326755, 46.02479742419335, 49.36556246972854, 54.683884574520974, 55.569316494849424, 58.48160574513098, 55.585880664087114, 54.07263025160759, 53.45480988102575, 50.38046006233462, 53.849435621692294, 55.78028117456744, 56.6662504596095, 53.597839109359256, 43.36706999809512, 35.8579158782959, 32.23631501197815, 30.56004893395209, 15.619621315310079, 8.664392155985679, 1.1039091646671295, 1.6015186953929164, 11.9730035720333, 34.750258153484715, 55.58062468805621, 59.39089744321762, 60.378652234231275, 62.439245870036466, 52.956084435985936, 62.1853155474509, 24.280116596529563, 38.39579528377902, 48.2430350395941, 39.71691231573782, 17.27240808548466, 23.36995020989449, 25.105065568800896, 32.8296519479444, 36.05757236480713, 39.35433626174927, 40.45054066565729, 55.42917805333292, 40.27978812494586, 2.0394201913187584, 0.10662370361387731, 0.12982224024111225, 0.06031035993909163, 0.06539315030339264, 0.052019465309117115, 0.038097981483705586, 0.11332373239941175, 0.014979247277933023, 0.04065391509943912, 0.01822112165691872, 0.019627457987817547, 0.02202779723090991, 0.0724393665610302, 0.1412966132404343, 0.15385867787464974, 0.09390144999469481, 0.13339614766019006, 0.15055578171966538, 0.14817746175873667, 0.18007526384486308, 0.1878226344143191, 0.19221493824114724, 0.18373026933160522, 0.2317722406118147, 0.13997195528880244, 0.13073831285920837, 0.1963597803466743, 0.1572143728093755, 0.08154439814989606, 0.13792918183870856, 0.25937055808401877, 0.17184896574866387, 43.64713507313883, 96.45675428452031, 51.063968366192235, 65.74177172876173, 106.37936238319644, 64.16670868473669, 50.130381507258264, 18.311090930815666, 49.987646456687685, 73.84366266189083, 49.92120542833882, 30.690018630796867, 30.080974563475582, 68.25935286860313, 82.23216118351107, 75.13913523766303, 73.93296718597412, 67.64357213051089, 40.04069612872216, 7.246090067971138, 1.288758826351935, 3.4840710461139683, 11.097439354465855, 29.41951782472672, 48.65238143551735, 65.86580491835072, 67.67378222557807, 68.58665112526187, 72.77476187675231, 73.66614403263216, 71.0497897671115, 68.19934844970703, 69.10660836004442, 66.12638365837836, 67.66325458403557, 66.49752616882324, 66.20094791535409, 70.14645222694644, 66.74949922869283, 66.95893026167347, 68.32934364195793, 68.97582084901872, 68.46507333940076, 67.24887970955142, 63.461725404185636, 58.64197969436646, 62.794667520830714, 67.12201456869802, 64.12150729087092, 63.40837724747197, 53.55458713346913, 55.279822041911466, 56.953885709085775, 51.74453097005045, 50.39210165700605, 49.73970559335525, 48.263878514689786, 57.258014525136645, 56.499836060308645, 56.58350806082449, 50.450945054331136, 51.06823198256954, 47.647097572203606, 52.994931590172556, 51.16334945924821, 53.21967163393575, 53.65090877779069, 57.297128400494984, 60.27055563465242, 65.63732293344313, 62.21737700123941, 62.150551580613666, 62.14131439885786, 62.692011248680856, 61.88568568998768, 60.72484847038024, 58.069996141618304, 53.758636674573346, 44.77519304521623, 50.14485113082394, 56.23772367354363, 58.1264429707681, 56.417682017049486, 58.345530879112985, 57.38786066732099, 46.24733309591971, 48.49025418681484, 47.609446740919545, 56.344412142230624, 58.9279910825914, 57.88086729664957, 55.055380098281375, 56.51771030118389, 56.295684537579945, 54.752553509127715, 60.100940581290956, 61.61830163771107, 59.415557384490974, 56.34245487951464, 59.79871411477367, 54.06642506199499, 47.47426617530085, 51.505172252655036, 56.79300577409806, 60.58180355256604, 62.0921161097865, 59.61613170562252, 57.841063084140906, 56.503899635807166, 55.08876339081795, 57.20756499998031, 60.08831447170627, 60.30332703744212, 56.077863554800714, 45.767423260596495, 37.269910304777085, 33.127577535567745, 31.909734549060946, 16.2098095686205, 9.791175357757076, 2.681038317180449, 2.181916222456963, 14.126575031588155, 38.91381094532628, 61.72529212890133, 66.2395832615514, 66.22224638538977, 67.49993493480068, 56.966382380454775, 67.5925656287901, 28.729341491576168, 42.27685505344022, 56.46700582196636, 44.82528955705705, 15.387656265689483, 20.89715469268061, 52.7667712396191, 49.1879379364752, 39.63544076488864, 59.50785075464557, 47.485605747469016, 62.53076653326712, 60.9763979142712, 2.6930150293534805, 0.23494157699808, 0.2581004455925957, 0.15869068552649793, 0.21145096168883387, 0.10519034544666929, 0.14166372257374948, 0.24801685925452943, 0.15303646634903648, 0.11446272128171499, 0.12113605190308825, 0.23861979494892785, 0.12784491368238965, 0.1368724861212315], [0.047072686194892854, 0.02162139333273855, 0.019786321640675588, 0.04579261839089375, 0.08977424323318467, 0.020160270223934806, 0.029761278626298713, 0.050995600289635123, 0.019446377785155372, 0.08536952878198317, 0.07620625152823425, 0.03223457816807974, 0.03792837727814913, 0.029870076518085216, 0.05200447296843894, 0.08271476599357783, 0.020560780990748637, 0.029379686400774988, 0.04000877713664405, 3.676753313310685, 62.77299642562867, 52.487631843936065, 34.8803121812882, 37.97991814151887, 38.882871289407056, 54.69577720088344, 12.919139073741052, 30.758834654285064, 68.6121779103433, 72.77875484958773, 53.230407161097375, 16.563939779035508, 57.65129881520426, 70.90496801560926, 64.72943544387817, 63.017983744221354, 56.821509638140284, 41.62886381149292, 13.357329599318966, 1.5437246546629937, 2.0986136601817225, 12.585044330166234, 33.37990360875284, 52.85026281110702, 60.983218916000865, 65.93783532419513, 61.06738121278825, 66.0609193002024, 65.84819347627702, 65.08353917829453, 66.14707023866715, 66.31109591453307, 61.30721453697451, 66.0341844251079, 65.52939499578169, 68.36253473835608, 68.27078265528526, 68.29390110508089, 64.01683099808233, 62.28321790695191, 58.46742637695805, 61.08842080639255, 52.86319094319498, 57.78587925818659, 62.5059457748167, 62.51671268093971, 59.93995474230859, 60.33123862358832, 55.57181896701936, 52.24133053133565, 51.217878249383745, 49.691342769130586, 51.062928938096576, 46.85374329167028, 46.30956542107367, 44.11992972896945, 44.47229193102929, 46.83634757995606, 46.41997229668402, 45.58062822588029, 43.7930158645876, 44.45064044767811, 44.15865528968073, 46.3777401370387, 48.910022320285925, 49.69791273916922, 54.19327451336769, 56.4366231426116, 57.931238374402454, 59.45851910498835, 56.33844229482836, 59.555703670747825, 59.00035096753029, 57.06214704821187, 56.41164548935429, 56.377571859667384, 48.16442681897072, 40.820969304730816, 41.387940068398755, 46.45224948083201, 47.42950016452421, 47.13415353528915, 52.26660628472605, 45.959325221277055, 42.17983914959816, 44.87418974599531, 48.044253241631296, 53.28728152859596, 55.241418115554325, 54.43433161704771, 54.240295886993415, 52.72224449342298, 53.44631010486234, 53.728595241423584, 52.52251740424864, 53.55086088180543, 52.065565201544, 49.93874626774942, 53.77189820812595, 50.325668473397535, 46.24559548593337, 36.392138773395175, 36.03682302659558, 34.6751682989059, 33.75369371906404, 31.11509765348127, 33.96948683646418, 34.46137559029364, 40.08142994296166, 45.986746511151715, 50.89727940097932, 47.554729677015736, 43.10478110467234, 43.01503727512975, 35.94437276163409, 34.4887262775052, 30.63315210803863, 19.18031365640702, 10.558739073814886, 1.70927882915543, 1.328525653769893, 11.928149307927779, 34.79077231499457, 51.2526539833315, 54.48924087708997, 56.385538193487356, 52.37512257791335, 58.80251446077901, 37.40472216759959, 30.155334857202348, 54.78774109194356, 57.02304493996405, 33.79908338669808, 10.66786333437889, 29.010740172478464, 42.31135229910574, 30.79624425980353, 40.49119603249335, 40.80310290859592, 41.44718746985159, 59.38439023110175, 18.295909397063717, 0.4337248764932156, 0.21407999158386262, 0.02004540300056819, 0.06561310946821206, 0.010834014467564563, 0.03777226388093926, 0.001293732298842271, 0.04806394268187785, 0.07404824313257011, 0.06928587287303901, 0.03179283463396132, 0.012864409852021886, 0.07116369227127683, 0.04796733133374684, 0.07000795670694883, 0.014615066315708383, 0.032322574857502215, 0.08115118820100062, 0.013339727189421896, 0.032278241349324104, 0.04347571569885458, 0.06380554416307038, 0.03538224958784638, 0.03388026526438133, 0.039375977019869515, 0.05451209707966736, 0.06088703645453338, 0.07316398614596936, 0.019014127995638598, 0.021285065412220937, 0.04998342577187766, 0.10939812167517601, 0.23150175028750974, 7.081842287894219, 77.61881059215915, 59.85177201609458, 39.39221066813315, 42.58043081529679, 45.38904789955386, 32.45003907911239, 22.353650369951804, 39.03160364397111, 78.388685564841, 71.82255160424018, 53.469483467840384, 20.574524056526926, 61.89783327041134, 75.47155610976681, 69.27005352512484, 69.00701938136932, 64.77918678714384, 46.51525451290993, 15.276309001830318, 1.8411617846258226, 2.887492761496575, 14.458920398066121, 34.24574721244074, 53.567358370750185, 63.760166783486646, 67.48169591349941, 64.42668337975779, 69.07683757043654, 69.9273015606788, 66.65992798343783, 69.4456894167008, 69.03893962983163, 64.62943461633498, 68.58333280009609, 65.9297787758612, 69.98083406879057, 67.72331391611408, 67.60603504796183, 66.86258900550105, 66.57915853684949, 62.59836858318698, 65.28954205974456, 57.78918973861202, 58.449003004258685, 61.710693067119976, 64.16712445597496, 61.270536453493186, 62.46473343141618, 58.289370382985766, 53.49874434932586, 53.419563462657315, 51.29253664324361, 51.107894989752005, 47.65919416181503, 50.153856892739576, 47.11958977483934, 49.957550110355506, 53.25043086082705, 52.6363798879808, 49.14219525552566, 49.05945677911082, 48.02382946014405, 49.98313180861935, 50.84941079539638, 53.805865933818204, 53.97602619663362, 57.59998636861002, 58.67326059649068, 62.19643154451924, 60.267311834519916, 59.94709345602221, 60.92990213824857, 63.947507027656805, 61.23836909571002, 60.94875304929672, 60.111982053326024, 53.99708147971861, 46.51208131544052, 47.63029806075558, 52.71978516732493, 52.847564220428474, 52.78062505106772, 55.68525391240274, 51.03668043690344, 43.33332192513251, 44.63021047653691, 51.70472283517161, 56.990410820130386, 56.9305044604886, 56.050528557069846, 54.53900398746614, 55.15597320372059, 54.51623462861585, 56.343055002151004, 54.682558813402736, 56.25534296035767, 53.73418461891913, 49.27788572926676, 52.71287787345148, 51.06262299322313, 46.30208153878489, 36.66646934324695, 40.23302562775151, 39.824538230895996, 38.815139801271506, 39.962652729403594, 36.45808166073215, 38.318046062223374, 42.329250074202015, 48.49968356470908, 54.76121018009802, 52.32078990628643, 46.079169319522, 45.81343266271776, 40.52027256258073, 37.321642444979766, 32.83412344994084, 18.806060706415487, 12.04269330347738, 2.264523299471025, 1.7697116444187782, 12.600927968179027, 38.30291355809858, 56.180696333608324, 59.19120173300467, 60.44137485565678, 57.757202809856786, 66.17474648260301, 40.34484847899407, 36.0813654622724, 56.43339895432996, 63.6180083213314, 38.4121633345081, 17.757164009155765, 24.477886422987908, 27.28748606097314, 37.69145919430641, 39.67614320016677, 43.035614029053725, 43.77540834488408, 66.66377975094703, 25.640192570224887, 0.41413291327414975, 0.12572705595483705, 0.06834428952706438, 0.09793161639883634, 0.009303182145700821, 0.04954448803478191, 0.03160474089635236, 0.057381157643131675, 0.046937870041977976, 0.03944888177718367, 0.03747293800716439, 0.03444991675355742, 0.06852053571492434, 0.026300263838962685, 0.11638762444377908, 0.12278494890779258, 0.14970871830178847, 0.18252038667278905, 0.16575300495230383, 0.08871771605505098, 0.08686518521919366, 0.2084762116353358, 0.13964131174068298, 0.2350531347216137, 0.17221163177201826, 0.11564550741064934, 0.12593676486322958, 0.19295473402786642, 0.1455052857918124, 0.12623320258552992, 0.13049544766545296, 0.20405828982831972, 0.4006519414965184, 14.113445878028871, 98.74391186621882, 68.4778759556432, 56.39267690720097, 50.188052115901826, 58.91789097939768, 70.98905578736337, 15.846457865930374, 40.30664067114554, 83.6092504378288, 84.65644482643374, 60.32205243264476, 22.330981031540905, 69.36250379008632, 81.53471669843121, 76.4893719457811, 75.14196718892744, 71.272078329517, 53.799127301862164, 18.51750958350397, 2.520250557891784, 3.5787874604425127, 16.96746929999321, 38.458368855137984, 56.769506854395715, 67.91364300635554, 73.1027896942631, 66.6557388920938, 73.11694160584481, 71.22500204270887, 65.21964934564406, 70.5296128795993, 69.95995136999315, 65.46458959579468, 70.91174587126702, 70.4257014489943, 70.37719741944345, 69.3012991259175, 71.92913024656235, 70.29969922957882, 72.02911930699503, 66.42551145245953, 66.49348612754576, 57.549987916023504, 61.13974502009731, 63.7955661742918, 68.05102794401108, 63.68447680627147, 66.6094627688008, 60.45217706311134, 57.15738611836588, 56.317775326390425, 54.149426337211366, 52.12278081524757, 50.37050900920745, 52.5152688641702, 47.84976251663701, 52.43647236977854, 53.47443349899785, 56.616503038714015, 52.92663528073219, 51.38386118796564, 52.52229382914882, 50.95545599537512, 54.09703916118991, 54.79749210419194, 56.059655912460826, 61.560760467283195, 58.42708872210596, 61.90920422154089, 60.56554925057196, 60.98539975381667, 63.32811378663587, 63.11728638987388, 62.588413607689645, 61.89256160489975, 63.70303353955669, 57.91254043579102, 49.342816645099276, 50.16622412589289, 56.39413995127524, 55.89466533353252, 59.11986558668075, 61.21328553845806, 52.98995018005372, 46.06973209688741, 48.94431952507266, 54.505777589736454, 57.86777834738455, 59.09526448095999, 59.14222309666296, 58.05290245240735, 59.010305943027625, 57.55256099085654, 60.327716335173584, 56.22177531642299, 57.95977753977622, 54.48636970212383, 53.33317718198223, 57.676350993494836, 55.941565113682906, 49.90422548786287, 38.9178039181617, 40.083273456942656, 40.9692858880566, 39.45903216638873, 43.47412716957831, 39.01975024131037, 40.920287639864036, 43.50439610019807, 53.12810390226303, 59.30660570821455, 55.85311174392701, 49.98164915269422, 50.96733293225689, 43.04819307019634, 39.68953809430523, 35.557960464108376, 20.688647377875544, 12.993403269398598, 3.1513832076903316, 2.387174834166804, 15.385629380902937, 43.89313436323597, 64.31599409349504, 63.3887771637209, 66.25855184370472, 61.19858057268205, 70.49467240610431, 45.20480632781983, 39.779717306936945, 63.84812593460084, 69.54035974317982, 42.33455704104516, 14.625829016008685, 34.76258616293631, 59.818188682679214, 42.674669681056855, 52.216894165162124, 57.45632563867877, 53.62507604783582, 78.42150011370259, 36.6365965720146, 0.45838690152572054, 0.26367747375080663, 0.1402761841252927, 0.11520941952063192, 0.1837996922193035, 0.20743897455113552, 0.14324607718135082, 0.18018662238553648, 0.3270207796125643, 0.15954802984431868, 0.1100733285889991, 0.09337857200373566, 0.25339508759638957, 0.09905682335938178], [0.051651486466007854, 0.026619921686247956, 0.03183036336615201, 0.058292844407861276, 0.09829861847984214, 0.028091984530610424, 0.102535268562215, 0.06639251200061652, 0.08073511818844466, 0.05944093824514459, 0.08225378790690054, 0.028157155630328966, 0.023242793526620637, 0.04026424447675386, 0.04687094077047321, 0.10424535300943161, 0.04271433155442919, 0.04024616097130122, 0.09477839084161867, 1.2458313040194975, 50.74080821006529, 55.37126818010884, 69.97285596786007, 41.66476526568013, 37.40136069636191, 52.91155768978981, 27.94028416756661, 17.10825493258815, 59.86349990290981, 56.696997919390284, 68.22211388618716, 30.790680377714096, 44.92945201935307, 73.64596736046576, 66.66005349928334, 66.0207934533396, 64.40907193768409, 56.47605080758372, 25.782298080382812, 5.463634642862505, 3.665426979141851, 16.334297753149464, 34.139125424046675, 52.074872985962905, 64.40560848482194, 66.02120922457787, 64.29901415301909, 62.67509798849783, 67.32276147411716, 64.72603867130896, 62.51291582661291, 67.1004964459327, 68.58292487359816, 69.54818879404377, 69.53613927287441, 69.86801101315406, 65.86445562301144, 66.24931073957875, 56.42826064940422, 51.75392896898332, 46.476948645807084, 43.83791131357993, 47.05810662238829, 60.9024965378546, 61.317502913936494, 61.439531772367424, 60.74252659274686, 57.773033495872255, 50.79247366997504, 53.5427886439908, 53.0984547061305, 51.43256525839529, 51.67274767352689, 46.53583911157424, 45.26617180916571, 45.57124983879828, 41.48193574720814, 44.876672606314386, 45.12660211132419, 46.11313312284408, 45.72224147858159, 44.894754732808764, 45.66678308671521, 47.31644176667737, 48.33544608085386, 48.80160408635294, 55.31434674416819, 58.40414677896808, 58.789417666773645, 59.09743747403545, 57.27810098278908, 60.86532815810173, 59.092973816779356, 60.06860848396056, 56.76432148102791, 53.87900244805121, 51.17801912369267, 40.714645616469845, 40.63489990849649, 45.7815202589958, 50.0162640694649, 48.317454168873454, 50.36110708790441, 42.42509711173273, 42.931357429873565, 41.703373155286236, 48.00166414630029, 55.86824032568163, 58.64265041966593, 55.82175631676951, 57.88788441688784, 57.82593842475646, 55.19650305471113, 53.781186380693995, 52.74565319861136, 50.262055473942915, 54.169304909244666, 50.288245139583466, 47.49454875146189, 50.163376485147786, 45.527723296996086, 39.317218872808645, 26.07194942812766, 20.654524718561483, 15.402680904634538, 14.237109384229107, 11.696628466729196, 16.392025236160524, 27.902211681489025, 38.09862475241385, 41.58965187688028, 40.05092567013156, 35.888977127690474, 35.484761191952614, 44.478732462852236, 38.61378100610549, 33.974056397714925, 23.9267522288907, 14.057153982500877, 1.8193076863404245, 1.121950351422833, 12.46428926144877, 40.21776368541103, 53.83239292329358, 56.3827690001457, 56.56860305416969, 55.58277806928081, 58.75748172883065, 46.45275546658424, 60.708205853739095, 55.13850296697309, 45.805360424903135, 17.24461220925854, 15.271238357790056, 39.74039946832965, 31.508536877170688, 28.19013326398788, 35.09511293903474, 35.60768042841266, 42.73755311965943, 46.795680446009484, 4.88976639124655, 0.13996429440955963, 0.1241554878652096, 0.10008735717424463, 0.020306039518947085, 0.017741655953408732, 0.07499868245494944, 0.04230288105205663, 0.03868508828623641, 0.055847694766857935, 0.0411464253650798, 0.00728834696459554, 0.0297253740005075, 0.04875206200766468, 0.020881693307009917, 0.06082807449744113, 0.004587029970641579, 0.03008504462007794, 0.04570130071031951, 0.04209632459547251, 0.03436616419123546, 0.028890485634967208, 0.048362609720037836, 0.04623228774195717, 0.02619432728557337, 0.11324714658962143, 0.15391965847342245, 0.030531943925926765, 0.06911733352969732, 0.039761215823912816, 0.0993337871266469, 0.03817985713061306, 0.061113714210448734, 0.041059696551172004, 2.114972395281638, 69.11449232409078, 63.32186937332154, 80.22725735941242, 40.70281574803014, 44.886000002584154, 33.819522857666016, 28.184188911991736, 29.46042226206872, 67.39390542430263, 57.4003416492093, 67.19319774258521, 36.85383312163815, 48.5470461845398, 79.17993745496197, 74.19030604823944, 73.40350212589388, 69.78828491703158, 62.14061621696719, 29.595206668300015, 5.7440821489980145, 4.270233906084492, 18.191562583369596, 35.63878482387912, 54.03418317917855, 65.97254045547979, 69.77783572289252, 67.13347573434153, 68.15872053946218, 70.10966823947045, 69.86732852074408, 62.778978040141446, 69.30047542818131, 69.7479158832181, 70.00572542990409, 70.80058590058358, 70.26050690681704, 67.8047501656317, 65.61305130681684, 63.338084451613895, 58.42802616857714, 52.385152078443966, 49.09453061319167, 53.6760707824461, 62.50558883913102, 63.45914448461225, 63.225108423540675, 63.18080133007419, 59.84216613154258, 51.34787344163465, 56.85318669965191, 55.54176576675908, 52.38890578669887, 52.04324299289335, 49.68942473011632, 48.9366199124244, 50.65011124457083, 46.842760655187796, 51.24621737387873, 50.619422620342625, 49.29939600729173, 49.42826155693301, 49.57343632175077, 50.06321091805735, 51.6248712232036, 53.45820665359498, 53.4011322452176, 55.919654753900346, 59.54820802134853, 62.21510594890964, 61.6551915291817, 59.1228622774924, 64.90559301068707, 63.001811812000895, 61.0367278898916, 61.98301538344353, 59.42521425985522, 54.540023803710945, 44.756153860399806, 45.99144158824798, 51.20718979066419, 54.41668095127229, 54.33154590668217, 55.68444198177707, 49.24072127188406, 47.12340231864683, 45.14829674074727, 51.32832434869582, 57.8475820633673, 60.09080517676569, 60.06197967836934, 59.02255942744594, 58.9191069141511, 56.668384228983236, 55.8729903159603, 56.023809371456025, 53.513590520428075, 56.623045552161436, 51.94942774311189, 49.79368132929648, 51.0479494064085, 46.14963077729749, 40.12623517744003, 26.509340770782966, 23.522716722180768, 20.018406491125784, 15.36341013446931, 14.94115717949406, 17.787556494435957, 30.392704932920395, 40.06779970661287, 43.87587201210761, 40.97731890216951, 39.71073066034625, 40.488638647141, 48.07434174322313, 40.90509237781648, 36.212772707785334, 27.03765657640273, 14.894932047013315, 2.6974120063166467, 1.8090524043767684, 14.401695959029661, 44.1334109152517, 59.887340068817146, 60.82002478261148, 59.70368293023879, 61.379307700741684, 60.34440994262696, 54.21478479139267, 62.2374556141515, 61.59273955129809, 52.595920639653365, 22.34038491402903, 18.504708928446618, 24.65283589978372, 31.995328510961226, 35.97694804591518, 35.637419839059156, 39.111953396951, 48.72888726572837, 58.986112763804776, 6.679469866137351, 0.08086467131731973, 0.10282084315774903, 0.05758378406866424, 0.012158466533066766, 0.038844361796133944, 0.05486573092639447, 0.08943848987861026, 0.04570843681933419, 0.03389382502064109, 0.057236933930506634, 0.022528611889649785, 0.023802681225201777, 0.0670086228919606, 0.014114064923036965, 0.15052550592489783, 0.13303532024785397, 0.0870840029130059, 0.15573329502536407, 0.20941332102783267, 0.19020014232204807, 0.1365495953829058, 0.1455999436157365, 0.1299180165534058, 0.22787631579464485, 0.13627037165626404, 0.27759318510370873, 0.1681215955965942, 0.14722326860552834, 0.189331965520978, 0.18483653093778318, 0.1785781441797172, 0.19958615963978155, 0.19513206316098092, 4.1752738145089925, 85.85159101793843, 74.07953046983289, 86.98955689707111, 54.27726030349732, 54.2356361112287, 72.72175496624362, 33.56104650805074, 22.820598733040597, 73.38349803801506, 65.39256703469061, 77.46524195517264, 40.13588028569376, 53.28594792273737, 86.76972373839348, 78.93469518230808, 76.76859763360794, 76.55270253458332, 67.95973870062059, 33.61486534918509, 7.883734587700137, 4.972367584705353, 20.174599193757583, 38.66937275855772, 57.92677471714636, 70.58833860581922, 71.83129848972445, 68.88796760189918, 72.235302617473, 72.59329734310028, 70.71532141777777, 62.81876264079925, 69.61071137459048, 72.17269374478248, 72.01678737517327, 72.8241680514428, 72.20954049018123, 71.65166962531306, 72.46136449998426, 66.59440871207946, 63.28707010515275, 51.43758589221586, 49.747679771915564, 55.763889589617335, 66.0861244509297, 65.03972238109958, 67.17059704565233, 66.22071666102256, 62.6810246898282, 52.21985947701239, 58.39637264128655, 58.25787375050207, 55.44255333562052, 55.48259289033952, 50.4226412311677, 48.6219830666819, 52.155156058649865, 48.93931458073278, 52.611092367479884, 54.05470894229028, 52.17279495731477, 54.39230734302152, 53.84537596856394, 52.71135207145445, 54.578333593183956, 53.91212686415642, 56.02537047478461, 58.232696056365974, 61.16061987415437, 62.35502081532633, 60.16056060791016, 59.18041129266063, 64.50440514472224, 61.8505883216858, 63.58258147393504, 62.83709187661449, 59.70278470746933, 56.97551365821593, 49.25492809664819, 48.7467065934212, 55.33994413191273, 58.28036462107013, 58.81857656663465, 58.67952462165587, 51.11176636911208, 50.09044785653391, 47.24702758173789, 52.230512634400405, 59.89048973206551, 62.65847106133739, 62.41233841065438, 60.69527379928097, 62.03968186532298, 60.36854820866739, 58.293936021866344, 58.02655196958973, 56.07407062284408, 59.28752729969641, 54.98999810987904, 52.507741835809526, 56.49057142196163, 50.63898740276214, 42.46314802477437, 30.10496574063455, 25.56301405352931, 24.622272791401034, 21.45819091027783, 17.095873971139234, 19.95271855785001, 34.94712583480343, 42.05514700182023, 45.49184929940009, 42.22609958341045, 42.36398658444805, 43.02817329283684, 52.98162691054806, 44.09621115653746, 37.97011613845825, 27.921001795799505, 16.039913085199174, 3.5907031307297372, 2.585564885408648, 18.162584112536525, 50.44699914993779, 66.0239548836985, 65.37700306984686, 65.87516369358187, 64.477631045926, 66.51116032754221, 56.33489254982241, 70.19754502081102, 66.50039734378939, 57.9572162320537, 21.676104068756107, 18.66238428700355, 51.962681431924146, 46.76172448742775, 39.58908227182204, 48.4385024347613, 52.90532112121583, 54.48005860851657, 75.71279756484493, 11.253784048941828, 0.3375720779501623, 0.27145933359861374, 0.20309916306887904, 0.09794743611447274, 0.08326179873678954, 0.16578868932781682, 0.18868100528995838, 0.15666010819615858, 0.11978738475590946, 0.23287073408644046, 0.0913037684175276, 0.15061732922350207, 0.12430246949436204, 0.17693958936199067], [0.04582585894592828, 0.0484366099830837, 0.03240758763445962, 0.024984494422472296, 0.16141415874083198, 0.00969040894790763, 0.042518818255273566, 0.019350053719995965, 0.04600101728893576, 0.01231475325766951, 0.05524559562364894, 0.006358521631843741, 0.0324265904454214, 0.01683684865823917, 0.03824186811764394, 0.07631287564553561, 0.033650166925884066, 0.030610086809423183, 0.08708551976709597, 0.1821790178937297, 34.38328904490317, 71.00184271412512, 42.38768162265901, 41.387638045895486, 42.220710246793686, 44.40032820547781, 51.324825594502116, 10.514413349090084, 37.65655794451314, 85.1219830974456, 72.42854210638231, 51.05459782385057, 36.248587869828754, 64.22653659697502, 58.56411280170564, 56.57384726309008, 62.30647363970357, 59.801518609446866, 39.82759767963041, 8.149442807320627, 4.541759000670526, 16.7909038066864, 34.10546364322786, 56.25065572800175, 62.05455941538658, 64.64975249382758, 62.46827533168178, 63.24055079490908, 62.44435279600082, 67.5465326924478, 64.96542876766574, 67.38573904960387, 67.15206776895832, 67.42351931910362, 63.29948440674813, 64.02989641312631, 62.33172193650277, 58.31618762785389, 48.22758482348535, 38.66961986787858, 28.416346157750777, 31.603375865567116, 51.133872847403254, 60.39600087750343, 60.98732563757128, 60.067906379699714, 58.1200102836855, 58.160708796593454, 52.79403955705705, 53.56768784984466, 56.341395839568115, 59.95416548944289, 60.72393848050026, 54.48761701583863, 47.267984805568574, 43.96709065283499, 44.49910525352725, 44.77934291285854, 45.990402160152314, 43.646358443844704, 45.68405328258392, 45.218868024887584, 46.472135897605654, 48.47967947683027, 48.679865483314764, 48.983707966343054, 53.746296898011245, 58.053502575043716, 57.326671692632864, 58.66945197505336, 57.500973978350245, 60.4084308685795, 58.99715815821002, 59.60238772053873, 57.77992902263519, 56.70934554069274, 49.780961082827666, 42.358667850494385, 42.25623123107418, 43.89264406696443, 45.01803874969483, 46.05248935760991, 48.55529492901218, 42.11387665041032, 42.11212727331346, 43.22764935032014, 50.003265334713845, 58.43770657816241, 57.60651319257675, 56.31555134250272, 55.678707476585146, 55.35241334669052, 53.60798235862486, 52.050467998750754, 49.80266355699109, 46.81991284893405, 48.83810174080634, 51.69179078071348, 46.31632758725075, 45.77353039095479, 44.962129285258634, 36.42177228004702, 33.01941033332579, 21.086409053494855, 13.823619004218811, 5.55624621529733, 3.6771381958838436, 4.794665094344847, 10.826225107715977, 24.702442115353, 25.889239541945923, 24.89220638428965, 30.933713528417776, 37.38708719130486, 41.773583581370694, 43.03969329403293, 34.61334390024985, 30.314951788994577, 16.816271735775857, 5.291494073406343, 3.034147975906249, 16.56533222044668, 44.8548093149739, 55.47323411510837, 56.399160585095814, 52.75391763256442, 54.18150740285074, 63.099992659784135, 62.6471628681306, 55.89087240157589, 51.703302937169234, 39.965414078004905, 9.639891501395933, 26.313149698318977, 29.054627572336507, 25.664399477743334, 32.41101737945311, 39.62021412387971, 41.83279568149198, 45.69467898338072, 22.325636802181123, 0.47988311417641183, 0.015963131126256722, 0.01776189025070879, 0.013704201180277573, 0.04007315150492134, 0.13948026473724073, 0.0668096928406627, 0.05341129384994988, 0.014797987044608642, 0.03304976849786697, 0.04195598877906319, 0.03872335437805422, 0.05492601821559572, 0.07366413430821511, 0.10160959686242765, 0.06519799706556144, 0.032806137216187296, 0.030288303068148035, 0.027676232444543033, 0.08007964569955103, 0.034884886155205394, 0.027008529361938278, 0.06415888306594665, 0.0551410322828639, 0.04160907735387164, 0.0536979218163798, 0.029395048378876625, 0.041191850548550006, 0.0627917378780342, 0.09689656266522023, 0.12842796787980104, 0.040130719181991396, 0.09405974674248889, 0.07483329939385576, 0.21067770318158213, 40.49943300985521, 83.17146685815628, 54.5357366531126, 38.90336567355741, 41.06636454982143, 44.596113312628965, 32.1183987586729, 22.065305171474336, 45.115054653536895, 82.27031015580701, 72.71819345412716, 50.859565811772505, 41.69768571853638, 69.59893641933319, 65.94137330209055, 66.05676158781975, 66.12786631430349, 66.36360860640004, 43.65862369537354, 9.3211430311203, 4.138697712652145, 17.352624477878695, 35.44056000248079, 57.62153587033672, 64.43629318667998, 68.7875392360072, 65.63440861240511, 67.79579931689848, 66.67249525746992, 69.98845915640555, 66.67196181512648, 68.76817841683665, 69.24595448278612, 69.71723510373023, 67.58857265595468, 65.76340752263224, 65.18282613446637, 64.50405997614708, 54.34346206726567, 44.53608143714167, 34.90066143774217, 36.82490564161731, 52.90374825077673, 62.80713673560851, 60.24817851281936, 62.12307145518642, 59.55296977873772, 60.971753827987186, 55.61667519230997, 56.21762937115085, 56.772409408323234, 59.44664216810658, 59.725624668982725, 54.46663233541674, 49.261203888923895, 47.991163961349, 48.26841669697916, 51.72568790374264, 51.30193856454665, 49.2394974923903, 50.43961332690332, 48.233409543191236, 51.042054084039506, 54.7609003128544, 52.65403055375623, 53.257091045379646, 58.56657605017386, 60.09588072376867, 60.79873023494598, 61.92167343631868, 61.23317587760187, 63.004612384303925, 64.22797610682827, 61.82003305804346, 61.25716117120559, 61.17388925244732, 54.13621187210084, 46.007888086380504, 47.6815712836481, 50.04845103909893, 52.26464902201007, 53.160216346863784, 53.66596283451204, 46.05636858171033, 45.960694128467196, 45.54242434040193, 54.12912414919946, 61.44851007769185, 61.65026895461544, 57.785816500263834, 60.23104167753651, 60.00722731313398, 59.61420582186792, 53.77993122223885, 53.33386751913255, 48.61239679398076, 51.86154703940115, 54.4903979762908, 48.08305724974602, 47.2273608176939, 46.41271591186524, 36.70642260582217, 32.59584730671298, 23.19562831232625, 16.210783297015777, 8.283721227799694, 5.622779909641513, 6.08576814974508, 12.728522669884468, 28.210994389749345, 29.023819315818052, 25.46089122372289, 32.21003120945346, 39.58068055491294, 43.25545111010152, 44.72555937305574, 37.28821208400112, 32.44451638190977, 17.95962106797003, 6.157453387014328, 3.4966589125894734, 19.18564219628611, 50.67587729423277, 58.687239923784816, 60.83968370191513, 58.60098308132541, 59.76000424354308, 68.31745886033582, 67.44542967888617, 60.47155749413275, 57.76439643675282, 43.89406396496681, 15.659422586041114, 24.269047667903287, 20.541450631233957, 28.660935355770974, 35.185386288550596, 37.85133500253001, 48.77541442071238, 55.386020214326926, 27.944712523491155, 0.7023594600539054, 0.06474892398522747, 0.010656092462370233, 0.03957671120822911, 0.028937762835994366, 0.06464015482173813, 0.029023480413842107, 0.04357966233886058, 0.030070992652326826, 0.021669810089553078, 0.05127572800002752, 0.03093808352376425, 0.10258878746460523, 0.047597544523136276, 0.01841661388865642, 0.20385492412794023, 0.11993832705963044, 0.0755833071326056, 0.12066031896298933, 0.15038119028172187, 0.1524560628158431, 0.13128908411149057, 0.29489696626701667, 0.11032242973845814, 0.11899780857587054, 0.12812688000380032, 0.1270622016501523, 0.15371007213909782, 0.16219949079377038, 0.39213325828313833, 0.22777654050338655, 0.09477262986042807, 0.1507012158512108, 0.16365640616465002, 0.2960793157258342, 54.88718494292229, 93.89584664375552, 67.12702735777825, 60.31579625221991, 57.50353136370259, 63.87522166775119, 65.73666480279738, 14.420226216316225, 47.908652982404156, 94.46204862286969, 82.31079686072566, 59.11711992756013, 46.99896120255994, 75.26891862192463, 70.51775947693856, 66.67673926199636, 73.86299210210001, 72.25001935035952, 47.06413138297297, 11.805864514843112, 5.941128298159569, 19.348069506306803, 38.782929297416445, 60.31658072625438, 65.53348995024159, 70.76581801137617, 67.95076431766634, 71.05046441478115, 72.78672510577788, 72.3082822368991, 65.6792805271764, 68.01592273096885, 67.73782668575164, 68.96041377898186, 68.44324927176199, 68.12513720604682, 65.25562140249437, 63.676216294688565, 58.02817975321124, 47.68445030335457, 36.35111470376292, 41.18389052729453, 58.703447157336825, 64.59581990395823, 65.18587381609025, 65.73745319920202, 61.80010349519792, 63.066742727833415, 57.36543255467569, 57.55460454571632, 60.70098084788169, 61.77190949839931, 64.95360674396639, 59.89187825110651, 50.66244709876276, 47.38162763657109, 50.99963365062591, 54.28212404251099, 54.488052398927756, 53.134881757920795, 56.92193408166209, 52.66947292512464, 55.257519445111676, 55.68246510721023, 53.905698099443995, 55.59552969471101, 60.63297479383407, 61.39701720206969, 61.997218285837484, 61.37155709728118, 61.901261421941946, 64.66709721472957, 63.58928088218936, 64.11394496117869, 62.70120920673494, 64.17744813426849, 56.01096753151187, 50.02698782951602, 51.56730259618452, 52.6844956028846, 55.48577785491944, 57.773374742077245, 56.03898894402289, 49.84504868907314, 47.526166977420935, 50.002908399028165, 53.863022711969194, 65.61298070415374, 61.89161239131805, 60.487811796126834, 61.47025962029735, 61.41415011498236, 59.816690337273386, 57.94904201261459, 56.88838604957827, 51.586843844383, 54.12375834680373, 59.7015844621966, 51.16798570079189, 51.675669839305264, 52.10721685040382, 42.53112269986061, 37.35130340822282, 26.72184301960853, 19.133115776123542, 11.58523609561305, 8.196491637537557, 9.59015682820351, 14.360155117127205, 33.747637579517985, 31.99605218825802, 26.28555582415673, 35.74174704090242, 42.800358110858554, 47.75915968802668, 47.020651909612845, 39.85361083861321, 33.359483749635764, 20.107650218471406, 6.770457087024567, 6.060220772220243, 22.133809366533836, 55.00716632412326, 64.38278421278923, 67.06478718788394, 62.306583466068396, 65.98202474655645, 74.5510935014294, 72.90209770202637, 67.65302504262617, 61.15698775937481, 49.59336196222613, 12.875525259202528, 35.094108812270626, 39.98973669544343, 34.23083043867542, 44.46687121545115, 56.24515656502017, 56.26907910070112, 67.63360146553286, 42.0236268351155, 0.8976059767507738, 0.10393645103660323, 0.1604914518013116, 0.13307295048669462, 0.1501062260039391, 0.18488301715302854, 0.11770702703225037, 0.15620264645305373, 0.201984474495534, 0.15415541437124053, 0.10629150490727156, 0.1660920601458319, 0.14775933096966437, 0.1355720825132824, 0.1393400859688559], [0.06685960346892958, 0.012569860536454907, 0.04430264249564179, 0.0215728291039986, 0.03956579828574773, 0.08212117808720759, 0.045765916396292954, 0.08472072125803079, 0.04862608267895637, 0.02729784438176261, 0.03186282059628397, 0.10677869086183849, 0.01238390131132497, 0.08437142346895511, 0.12144829401926649, 0.04740110425759227, 0.035691124747597405, 0.08041562888050273, 0.093277869746089, 0.08515812681927797, 4.724415444558667, 59.5214339225523, 52.98400778924265, 44.60529950357253, 44.54433018161405, 33.21193595086375, 55.408989614056004, 23.919484076961396, 16.947522086481897, 58.77829382496496, 67.30284367838215, 75.16019052074802, 48.25012276249547, 58.778858646269775, 69.46404610910724, 52.635105117674804, 62.10990013614778, 63.285603138708304, 46.450202003602065, 13.600337101567177, 4.448728715219806, 15.377715018487747, 35.291768812364154, 54.430828940483835, 65.46185178141441, 64.44639328987368, 62.23861271335233, 67.97124693470617, 65.97835340807515, 58.519354635669345, 51.65850554743121, 50.254261724410526, 54.30250860029652, 51.80318609360726, 51.691555438503144, 51.82260967070057, 50.69798769489412, 45.0731009821738, 41.87031315219018, 28.709251111553563, 19.225807266850627, 40.083614703147646, 62.792023843334576, 61.87147886522355, 62.76751687449794, 58.670985621790734, 58.3280880989567, 54.398936148612734, 55.15814227442588, 55.32133640781526, 61.29740468917355, 63.329674889964444, 61.37364772058303, 55.36282331712785, 50.553103185469105, 45.90235671689434, 44.564918702648534, 42.6156380099635, 44.210489411507886, 44.11377945253926, 46.31085195849019, 45.83660994806598, 48.253915694452104, 45.79497791105702, 48.244180371684415, 49.10070834621307, 56.08532390286846, 56.847930723621005, 59.993616688636045, 59.521331940927816, 57.40549172124555, 60.1951402233493, 60.79702792629119, 60.86155876036614, 60.616995057752064, 54.22557915410688, 50.03922562445364, 44.59658791941982, 39.61236938353508, 44.01431598970967, 46.328047629325624, 46.493348075497536, 46.236409294989805, 41.68373384783345, 43.939273203572924, 45.707003070462136, 51.049777230908795, 58.17943811416627, 56.779540277296505, 52.05407265693911, 50.22061955544257, 53.30225713791386, 50.216669728679044, 52.62338507559992, 47.08987389841388, 45.92439259252241, 46.99917301054924, 50.76389528089955, 48.868876657178326, 42.97286002866684, 43.910286887999504, 41.038864812543316, 28.9233301531884, 29.20173214327905, 19.31955779752424, 8.614351537919815, 5.254638502674719, 4.149442065146662, 3.922618997673835, 17.16115790028726, 10.772249371774736, 9.932336557296015, 14.666596170394653, 35.114218804144095, 46.25050237101894, 45.23583227588285, 39.57031373054751, 32.82965390912948, 21.803761528384303, 5.498393216440755, 3.3818464798312036, 18.879726740621752, 49.047673979113185, 57.26986008305704, 58.72688724148659, 53.22851657867432, 58.11487197875977, 60.58001495176747, 58.19340959672005, 48.47338799507388, 51.96015542553317, 20.808946471060477, 9.48985888111976, 21.348572431072114, 23.91396922449912, 30.669275176140573, 38.205407357984974, 42.06991080314883, 49.64364674783523, 26.31315165950406, 4.552366070209011, 0.35179943387066165, 0.26921616686928657, 0.10432832799251042, 0.057045630284494935, 0.0668830534202918, 0.041958329177671866, 0.05780304992391218, 0.026049159369581652, 0.04429914530426745, 0.02408088222446461, 0.0369896782532094, 0.006753530450946382, 0.016125340668124058, 0.0376947051394851, 0.02318167120158192, 0.07216870003650266, 0.021453281083414634, 0.036870792898679935, 0.013689438665976689, 0.05701471097587098, 0.0234155137948091, 0.03758394797783225, 0.02108718107093967, 0.006508206593758998, 0.02448529046359322, 0.035210611418850964, 0.06505539745933588, 0.10327601429796028, 0.025414380830742662, 0.031118922408730276, 0.032734630569334955, 0.049670019202054515, 0.06296311557713537, 0.12431277337694362, 0.1313746561326327, 5.941322455483099, 68.97639351506388, 63.299684447626916, 46.663782904225016, 36.852405378895426, 43.59370454665154, 35.17972630839194, 28.624112144593273, 29.76952072112791, 63.54593476941509, 74.44864903726886, 77.53065924490653, 52.61569330769201, 64.69524022071593, 74.68210066518476, 56.90590335476784, 70.14776229858398, 70.64551891819124, 53.102114277501265, 16.38808325413735, 5.521558734678454, 16.0020229893346, 36.59918892768122, 57.26214085855792, 68.59753962486022, 67.92493943245181, 68.25150028351815, 69.14980150038197, 70.32360215340891, 62.793345682082645, 53.591414267017, 54.51995695790937, 58.481076225157715, 57.09947232277163, 55.1440138970652, 56.28685528232206, 55.44921352017311, 49.076115085232644, 44.046950109543346, 33.92138681104107, 25.694364424674745, 43.797483444213874, 62.041337105535696, 61.91998681714458, 63.900332681594364, 61.110409613578554, 59.21563809917819, 54.740684416986284, 57.30706768651163, 57.02188784076322, 63.06329104208178, 64.80256411337083, 64.21264356182468, 59.4845244192308, 51.75404664008848, 47.655350239046165, 46.96012973785401, 46.24292042947585, 50.89290988060736, 48.01621221726941, 52.13913317649595, 49.45804803602157, 52.81785226637318, 50.16005423761184, 52.038324340697265, 52.813937740941206, 59.345386182108236, 60.66285933217695, 61.38681119488132, 64.30456038444274, 60.6101034533593, 63.684543486564394, 63.26155508718183, 64.35416660001202, 63.18812831755608, 57.549379948646795, 55.399089551741085, 50.19471230045442, 47.040993321326475, 49.51051758181665, 52.34182165515039, 53.776514837818766, 51.74825329934397, 45.92023880250993, 44.95291563772386, 47.572964775946836, 53.08564816751788, 62.59422263791485, 59.209272092388524, 56.9594358628796, 54.036968062000895, 57.578044629866085, 54.612246405693796, 54.271714072073664, 49.9761539120828, 48.535777215034734, 48.6270978373866, 53.59508952786846, 52.44003780426518, 45.19152518241636, 46.59743601276029, 41.47199646119149, 30.87638024360903, 32.83368022211137, 23.15327455920558, 16.49684763723804, 9.123109425267867, 2.8599172734445144, 6.164560231470293, 21.770172311413674, 14.147783287109869, 10.357269471691502, 16.588758576300837, 38.04000493018858, 47.409696117524184, 48.38351864968577, 41.86209578667918, 35.4960419285682, 21.958812821295954, 6.843589678887398, 5.714185843544622, 21.562002320443433, 51.50391709419989, 61.9202260817251, 63.61362311147875, 57.80477723767681, 60.78020095825196, 65.66658773729878, 62.75698923295545, 56.38485570107737, 56.497121780149406, 27.753575424994192, 13.36317785324589, 21.02985828153549, 24.07662403198981, 34.57276698081724, 39.37499538544686, 42.99118141974173, 57.0328430206545, 41.52544267715947, 6.166348341972598, 0.4354522821884002, 0.23610033094882968, 0.21407465961190963, 0.06254926338912019, 0.06929468288416825, 0.05484864333524339, 0.09699508923316195, 0.06775795647333707, 0.05028701875539077, 0.05691298216040577, 0.044415621312275055, 0.04904759957665398, 0.04003243393174583, 0.0074203831759551845, 0.012634068280608665, 0.18566068832672414, 0.13832589280941796, 0.18542784356301834, 0.18281701591707047, 0.06630342363590194, 0.23028192380743645, 0.122362612296016, 0.18132069298336584, 0.1842567862402047, 0.09560773464580698, 0.16121689110032975, 0.24529289574392382, 0.21759086528853064, 0.20242831519534513, 0.19739284991256653, 0.21960445078870944, 0.17300097812567988, 0.23679474368691447, 0.2634380559527105, 0.3832798559338816, 11.98413133621216, 91.16804999689903, 74.45111228573707, 65.94535843018564, 58.552875211161954, 49.35474065042312, 75.44833567834671, 29.99038350197577, 24.51747686632218, 71.3784686980709, 78.91470678390996, 87.85652622099846, 57.058534545283166, 70.67156345613542, 80.22213474396737, 63.97810543737104, 74.331174050608, 73.61275272984659, 55.12374308801467, 19.0618404265373, 8.034145716697939, 17.882515115122644, 39.48098174987301, 62.83902952747961, 72.62655904216152, 71.30588916040236, 70.67393256771949, 75.88630753178751, 72.57614874070691, 65.23575067520142, 55.14724200771701, 54.44871887083977, 58.66507068757088, 56.32539649163523, 56.82860128341183, 58.57759398798789, 58.58712926987679, 49.453137228565836, 48.63041616255238, 39.112071068056174, 33.00922001561811, 51.14694610718758, 65.8810943172824, 64.86691451841786, 65.5752435807259, 62.773698529889515, 60.693908814461004, 56.73897904734458, 60.4285212486021, 60.091923052264804, 66.77814822043142, 66.09911534094041, 65.9799772693265, 59.83488621250276, 52.6835895353748, 51.462230144008515, 50.39932666286346, 49.83801980172434, 54.01580295255108, 50.724036155208466, 56.65513054017098, 52.280573844909675, 54.14213072869086, 53.127735199466834, 55.088955586956395, 53.09910974194927, 60.72196160593341, 61.860276576011415, 63.632838802952925, 63.85363294232277, 59.59705329710438, 64.85575145290744, 62.5938186337871, 64.43220215459024, 63.838092511700054, 58.21811660643547, 56.318755918933505, 55.11153274966825, 47.89587390038275, 53.80918425898398, 57.25612002034342, 58.40208753462761, 54.96134911814044, 49.01266682532526, 47.656487726396136, 52.05035032764558, 53.840006243798044, 64.74353244227748, 61.923744447769664, 56.97373290215769, 56.15505187742172, 58.54019811076503, 58.939275741577156, 58.30706811720326, 52.818789712844364, 50.132515276632006, 51.31014024057696, 54.412982156199796, 54.60975962300455, 49.20983260677707, 51.74527229801301, 45.41331560380998, 36.83674727716754, 37.57313697568832, 28.833066609597978, 21.940962114641746, 12.580681673942074, 8.997357256950872, 10.487298004088863, 26.887731821306293, 18.52352453816322, 10.782939791679384, 20.257847578294818, 39.44133443217124, 51.47616632523076, 51.575865130270685, 44.5850992971851, 37.88989190132388, 23.4730379427633, 7.042641139799549, 8.204631536237656, 25.913662179823845, 60.69648188929404, 66.82336530377789, 70.62098057039323, 62.54802496202531, 67.79352434219854, 70.46146562022548, 67.76129030412244, 58.68130930008427, 62.00108966519756, 28.36165458925309, 15.588927788119163, 32.80930661386059, 33.52019894507624, 44.07939203323857, 51.98502717479583, 62.055045789287945, 63.43752830259262, 61.11615196351082, 9.17329320984502, 0.6196978988666689, 0.30664244246098304, 0.2628814164669283, 0.2138827545868774, 0.2067407466951878, 0.11575436084381036, 0.2110138778845149, 0.2208906511265424, 0.21079558879137042, 0.17918926783867423, 0.09270991514166517, 0.1551678914937281, 0.14193956019176593, 0.11800351071982615, 0.21032901060196663], [0.16268903629914408, 0.022021992199663675, 0.09293316082367975, 0.01128517896793182, 0.032850758007337014, 0.10781756737419676, 0.057850539714338324, 0.08256368579403048, 0.039992363702866345, 0.04229675234866239, 0.04961187312860162, 0.039904393826521216, 0.03703629853384149, 0.07404981361281487, 0.021346109213247415, 0.0073478830088260436, 0.02938580552807018, 0.02386966220764143, 0.02383604243908438, 0.0602231408289123, 0.29398060253550934, 26.449730550089193, 69.07713567056965, 40.1006377896955, 42.7143915237919, 31.865507864182998, 44.69280365974673, 43.1246086858934, 10.654365478023406, 39.45939302444458, 67.56717220429452, 66.01967950021067, 81.93365312391713, 70.08802460085961, 76.24365114396619, 68.52804307014712, 63.60657853464927, 63.89301353885282, 56.26253266488352, 18.533191219452892, 4.747972709517326, 12.606672279296383, 34.26120919566001, 58.483770893466094, 62.987012709340746, 67.00024850906865, 64.278594293902, 72.07757626810383, 65.30019521713257, 48.675762684114524, 38.22683526623634, 32.27289895857535, 33.17481071718278, 39.94113852900844, 43.02632977885585, 46.31162074304397, 49.58224204278762, 49.77420283902077, 47.61268661868188, 40.74665215707595, 36.819822249873994, 52.817809120301284, 60.011090847753714, 59.779820057653616, 61.770509212247795, 58.029136811533284, 58.134428916438935, 59.147722259644546, 58.433011501066154, 60.09316252123926, 61.04606313090171, 64.08205609167776, 63.26417523045694, 61.75984036537909, 51.763095548076016, 45.76383429188883, 43.69221487352925, 42.62374162673951, 44.45520216418851, 45.43670861951767, 45.10711185393795, 47.01139511600618, 45.35494289090557, 48.78360040726201, 48.48378227603052, 50.05478174455705, 55.14582995445498, 60.278439598698775, 59.16522387535342, 59.71267692504391, 58.216614338659475, 56.82196463308027, 62.11290859406995, 62.006106376647956, 57.7734806460719, 54.24945462134577, 48.092337577573716, 43.36294366467384, 42.33953060642366, 45.06350294236214, 42.25266971895772, 45.58829645956717, 45.412393846819484, 39.86123984859836, 44.13048482710316, 48.944307757962136, 60.530204772949226, 56.537275083603404, 54.80754121657341, 48.599421593450735, 38.35119401254962, 44.704668829517985, 51.37431413896623, 48.843275347063624, 46.33021277766074, 43.267771274812766, 44.0254633657394, 48.84681724732923, 50.117880913519095, 43.32845426374867, 33.69248905489522, 40.703819874794256, 30.24359210844963, 21.998644490395826, 22.25461248428591, 16.704021346184515, 10.255661452970198, 6.2564662675703735, 1.5244555208952197, 5.152848584036674, 1.8428355335227906, 5.833227326793056, 16.493527350887177, 33.300369708768784, 43.40328916426628, 49.946049721010276, 45.41541799422234, 38.7292516616083, 23.15164677558407, 8.972807142042345, 5.076543285000709, 26.01097422261392, 47.7107850966915, 57.0016719448951, 56.18497563946632, 56.30936968711115, 63.10012994274017, 61.96892622978457, 58.8967925502408, 55.31749640741656, 45.30678795230004, 9.271636835990414, 15.142204146231375, 23.97164963906811, 28.483667758203325, 37.925950250317975, 54.62106389384116, 36.179667903530984, 47.51522748701034, 15.187957613698899, 1.4750157609101266, 0.03211732266560918, 0.07517186429111228, 0.08277825936074219, 0.0853367478797032, 0.062276899979840365, 0.05161843360251477, 0.022720267936106653, 0.04873584009586804, 0.02943601301540771, 0.07418306694636423, 0.013898481077875101, 0.11572608453852516, 0.04860455177784447, 0.018963765375496402, 0.0669512046020358, 0.04635009291251341, 0.03529589232658187, 0.030686705177950285, 0.02553726707945668, 0.03148740303942994, 0.028659816560966354, 0.055426706469828085, 0.055736474122010896, 0.03529313824049408, 0.05802772435990553, 0.028799997244571007, 0.021011428381767006, 0.0577932823028776, 0.026993477649445978, 0.075377918960106, 0.06172972167992304, 0.034143699918903654, 0.020525366661228964, 0.21356199357298114, 0.09627367189574627, 0.34508268138574016, 35.54516177023611, 80.17054773146107, 47.76501970906412, 42.47072604394729, 38.705533089176306, 39.71748498178298, 29.36523222154187, 21.294561393799324, 52.689308351086034, 72.25912709389964, 69.25987105215751, 87.4356637462493, 76.1810108923143, 79.96435657624276, 71.77309051636728, 71.13190850903912, 69.82517873087238, 61.6735403768478, 20.744552919941565, 5.763532692386258, 13.81478386540567, 34.50551009947254, 59.54401108526415, 67.13414253727083, 68.92359056780415, 66.55456527586907, 73.12801837921143, 69.0522050857544, 52.29427860629175, 44.72590846400107, 36.61978529345605, 37.50916704054802, 43.46362306225685, 47.29902644311228, 49.73607347857568, 48.61945313792075, 50.488007530089355, 48.95057178312733, 42.145420351336085, 39.087720994026434, 54.17929518607355, 61.549244388457275, 63.31940612485332, 62.36102204168997, 60.49475439133183, 62.456374860578975, 60.284181948631044, 60.25418758392335, 62.357982204806426, 64.10502549140685, 66.7648200065859, 63.74383011171895, 63.016987462197584, 54.15075602069978, 48.272562642251295, 47.79457869068269, 47.545123792463734, 49.109933760858354, 49.53070209872339, 51.38958392604705, 51.0859767852291, 50.29071231042185, 52.54061914259388, 52.55457493566698, 54.170556145329634, 58.52295537148753, 63.74601487190493, 63.099831842607074, 65.37343371299006, 62.89881037127588, 62.51675190464143, 65.8323549455212, 64.62882664895827, 61.514551024283136, 57.943915474799375, 53.32524614949381, 48.31505760069817, 46.5507637300799, 50.07265598543229, 49.47789130672332, 52.21603124372421, 49.19805765151978, 43.83564418362033, 45.41828132444813, 50.17881101177585, 60.42885465006675, 61.419064844808275, 57.89039081142795, 51.30561382539811, 46.50721757642685, 50.965250153695386, 56.180641420425914, 54.53998065763905, 49.06244170281195, 45.30061806401899, 45.779986612258426, 51.527196361172585, 51.011247788706136, 46.6893018445661, 35.255329993463334, 40.59589585950298, 32.28421499652247, 27.773840350489465, 27.810424297086655, 22.29751733041579, 17.408322134325584, 13.6063059683769, 3.2639799915975143, 8.089533996197487, 3.5441374874884084, 6.650212907022046, 19.198162401876143, 35.246222249923214, 46.800434358658336, 50.34160898577783, 47.045539348356186, 38.07660848863664, 24.827340187564975, 10.747325651107296, 9.514275635442427, 28.382507870274207, 53.01233514662712, 60.395659631298436, 62.808627236273985, 61.872165280003706, 67.47117611669725, 68.22701684890255, 67.3067738932948, 60.72009848010156, 51.00378744063839, 16.410479987821272, 24.410302023733816, 23.74036119830224, 28.570809095136582, 35.599894523620605, 54.62300154470629, 43.30925426175518, 58.69543375507478, 24.534635274640976, 2.1214528862507116, 0.0980342491980522, 0.10827708989381792, 0.060745608962831966, 0.1015424722385022, 0.039210655245809786, 0.06623754007441383, 0.06138686669029056, 0.03163218982667933, 0.03851288704261665, 0.02831938432439441, 0.0054729632533816325, 0.07185102635694128, 0.009423819926357078, 0.05537050242926325, 0.03770933358839924, 0.3103526675653073, 0.11200662041383405, 0.22129293921734058, 0.09228506576149695, 0.17074169290642585, 0.17103809232432998, 0.14811039842184515, 0.11096734553575517, 0.14736943818148107, 0.13198021799325943, 0.1697401708412555, 0.10007354460896985, 0.1523288462551371, 0.14877943832787777, 0.16035626792619306, 0.1691798081681613, 0.12625151974779944, 0.10524326680047859, 0.2604107829111238, 0.12465929026685416, 0.32076242349801526, 54.39163269535188, 96.24425595806491, 61.276796556288204, 62.96633789616247, 42.67285754603725, 63.67318822491554, 52.89551127341486, 13.830238003884594, 53.408133675975186, 76.62809833403557, 79.8713493347168, 91.30973385226343, 82.37888136217671, 87.15789718012657, 79.47716682187973, 76.21089935302734, 75.07152926537299, 65.37843473495977, 24.0182375907898, 7.500028725593322, 14.783413179459112, 37.86932299214025, 63.842944483603205, 68.0654073530628, 75.37963144240841, 70.0947161643736, 78.74375420231974, 72.8906600706039, 57.965504200227805, 46.349761870599565, 40.35245003238801, 40.44530037910708, 47.86778188520863, 51.787951607857984, 53.8613360927951, 53.23422362727504, 56.250436075272106, 53.77989199853713, 47.89077874152891, 46.61055634098668, 60.819950257578206, 67.06344573728501, 67.44669268208166, 65.50509983493437, 64.13288216437063, 62.50130953327302, 63.617882805485884, 62.874574045981134, 67.68274876379198, 66.94824572532409, 70.2339759949715, 66.89912980602634, 65.55042674464565, 53.48437670738467, 49.94244898519209, 51.002034141171364, 52.20365616583055, 52.51102878201393, 52.856499379681004, 54.36793765714092, 55.69574625261369, 52.71829858902962, 56.017086428980676, 54.36310529708863, 54.060929821383574, 60.674383255743216, 64.23792715995543, 63.02703265220889, 64.25593868378671, 59.62154849883049, 61.30100150262157, 66.33150008416945, 65.71025156205701, 62.070221439484634, 60.41452623182728, 53.62576638498614, 50.99913158724385, 51.287692516080796, 55.692506374851355, 53.11643877337056, 58.16206593667307, 55.83504530691332, 47.13725220772528, 50.334599710279896, 53.82301453621157, 66.12650917422387, 62.861108549179576, 62.07992930566112, 51.667523076457364, 47.26556078080208, 50.876894843193796, 56.406769983230106, 56.751338435757546, 52.544933749783425, 49.54018638980005, 51.05299749682027, 54.25536563319545, 53.063549533967056, 48.86623690205236, 39.34780551541237, 45.311396737252515, 36.57680788347798, 33.14373377830752, 36.246909095395, 30.682811275605236, 23.21513229800809, 16.676829514964936, 6.045631026068042, 13.427071302167832, 8.368354209007757, 7.687845537739416, 21.64764923434104, 38.71053411114601, 50.157387025894664, 54.93983099537512, 52.62120816015428, 41.374713836177705, 27.290508247190907, 12.673730100354842, 13.808306071066088, 34.33180009165118, 59.46313573468117, 65.38523612483856, 67.99983316852202, 64.74124570046702, 73.49522283000331, 73.58361736420663, 68.74409506397863, 66.08999190791961, 53.95541021900793, 15.49833868780444, 26.12228520454899, 30.771707873190607, 41.29197928213304, 51.004846480584916, 72.19272136688232, 54.73269847131545, 68.90853651108281, 41.99535831328362, 3.1566151592039295, 0.2968861595276864, 0.17254504855842362, 0.18308533055167045, 0.16282590556769602, 0.21128714144710573, 0.13732931967223846, 0.14603995387592625, 0.13958459059076925, 0.1431269505091252, 0.1329132671197576, 0.1466281255406718, 0.3391457451207023, 0.12114188949307128, 0.18079504941500005, 0.2146088680432689], [0.03177193575538695, 0.043010194710786306, 0.1578280705237581, 0.04113981019585364, 0.02514909990432282, 0.014104851758137587, 0.03433887996981221, 0.05228407207816359, 0.0214971415322995, 0.059883231447348674, 0.05341799711928733, 0.034829946159715616, 0.09424725442283577, 0.044847656597173026, 0.04044826645704527, 0.020300301520394224, 0.14803274774984007, 0.03973665121462076, 0.08481889542552733, 0.08503584386480433, 0.12684599631616186, 5.924260635529795, 58.81324606557047, 47.40389100966915, 40.8033892416185, 36.92582038141067, 31.640257912297404, 53.02614581200385, 22.85254643809411, 11.630437489478819, 57.84312625085154, 65.40643653561993, 69.32777512458064, 72.6731332655876, 73.40059957196637, 75.63624858856201, 64.59729863751319, 64.01657212165095, 56.76594926464943, 28.803954778179047, 6.7899247907823135, 9.323788669801528, 34.53725776364727, 52.73434500540457, 67.1108122794859, 67.7679112649733, 65.47584679818922, 71.32146096998646, 62.68558640633861, 45.226751988933934, 28.37679493811823, 22.879789260125932, 27.285444467298447, 34.67866313072943, 42.26413088460123, 48.02547293324625, 48.472787872437515, 48.56395159998248, 48.00173474896339, 43.281377976940526, 46.11497663682508, 53.87535856616113, 58.38356218030376, 56.04349182498071, 58.658379124056914, 59.61696717046923, 58.520370529543975, 58.26035268845097, 60.94928649164016, 59.00851734222905, 60.40329648602394, 61.84596776962281, 63.46501627276021, 61.27243488065658, 50.47318489320817, 46.90269054905061, 44.981772515081595, 42.456648657398844, 42.90138267701672, 45.29810382473854, 43.78184495433685, 45.82264238788236, 44.092057366524976, 48.37180645235124, 47.60093127527545, 52.076602751208895, 54.568225645249896, 60.78603352269819, 57.515875062634876, 60.88975667953492, 61.65001792292441, 58.30743289762928, 62.767140326961396, 60.843158921887806, 59.47942533800679, 54.159165582349225, 48.12960793895107, 46.626842021942146, 43.04792242665445, 45.08757845047982, 45.489982251198064, 44.284857549975, 39.31250026149135, 40.50194724913567, 42.62682460969494, 52.77732633775281, 57.886064437127885, 57.37925890953311, 53.78844276551278, 39.02807351081602, 20.999616807506932, 35.79899403356737, 44.96706754930558, 46.30079892373855, 45.154384259254705, 39.88738636816702, 38.014658574135076, 35.88154031384376, 41.08071650228193, 35.313553656301195, 27.314054235335323, 28.923322308448057, 32.086080389638106, 20.85716416758876, 17.9782425203631, 15.430368915680917, 10.251588071546248, 10.06823883902642, 3.907200405674596, 5.819228877944331, 1.2677047690076213, 6.412131411413993, 22.192193846548758, 39.59399700164795, 46.575086347518436, 51.30085599037909, 50.292489144109915, 41.78568017098212, 21.62877675025694, 11.935393925636046, 11.408319550175822, 31.765932613803496, 45.858222207715436, 52.45160879627351, 52.291434887916814, 51.604408218014626, 57.574388980865486, 60.11172317689466, 51.7248289046749, 60.752081486486624, 32.3122089524423, 9.42211268409606, 17.4560103108806, 33.38100971714143, 32.203129799135276, 57.02372743237404, 41.5611715470591, 36.89862266663582, 38.17278500526182, 10.357271432876587, 0.34489597043683456, 0.09660585528059353, 0.03739978427127485, 0.03030644786063462, 0.03799765843958144, 0.06295154764947873, 0.08340452857796224, 0.04434409551322461, 0.03954305313527584, 0.008838907965729314, 0.04725917114786083, 0.022188043672471278, 0.032147075605368426, 0.07249027310359864, 0.047825336936981454, 0.05075083519782751, 0.052397874439315456, 0.0277358781351077, 0.08275339214672005, 0.017971373163163662, 0.07257150906708933, 0.06944935603608048, 0.022194758433127598, 0.04615890034925073, 0.03168724473535774, 0.10222989825471755, 0.0029355907510410276, 0.049780132849850965, 0.029594742602879004, 0.028927439801214688, 0.0327640981413424, 0.08616017748511608, 0.05987144518463362, 0.04714523472132222, 0.08453012624334905, 0.14116722099002332, 0.09726759436870776, 7.281937099272206, 71.48389416356241, 60.37900132517661, 47.53615725424982, 33.76832808217695, 34.305159353440814, 38.25866922255486, 27.4686485721219, 26.48685774495525, 65.21329118359473, 73.234879432186, 76.31244951678862, 78.67409290805941, 81.15737684311406, 78.45649550038, 66.58239841461182, 69.81530220277848, 62.00868337385116, 32.30696082115173, 7.988195150129258, 10.086368033962867, 34.73910685508482, 59.13402534300282, 69.7558626051872, 71.84335585563414, 70.84500282041489, 71.58838610495292, 65.89103360329905, 49.7445144191865, 32.458825188298384, 24.66617391955468, 31.829451476373983, 36.98940592427408, 43.19951418907412, 49.47061923242385, 49.51343974759502, 49.53875472468715, 48.75454741139566, 44.935096310031035, 46.35379798950688, 55.36989535054853, 59.69215116193218, 58.03571462631226, 59.88009937347905, 63.771506355654815, 63.05805467790174, 60.395086965253284, 61.84340253953011, 62.18816711056618, 63.65062675168438, 63.8882557038338, 65.75059313927927, 65.25565278145575, 52.57908190450361, 48.99307066394437, 48.369013724788545, 46.476572098270545, 47.67602505222444, 50.465775535952666, 50.51208303820703, 50.0393589850395, 48.221003086336204, 51.47557796970491, 51.60187044451314, 54.19967974385908, 59.324970245361335, 62.315357808143865, 61.25001461275163, 62.381802758862904, 66.30764422878143, 61.16400095724291, 66.27746551267563, 63.667085016927416, 62.75599687330185, 58.57400501928022, 51.607757922141786, 50.64584762819352, 48.38135350135065, 49.47516918182374, 51.213740148851954, 51.77451356764763, 47.49263855718797, 43.27312923246815, 45.02968034436626, 54.699852543492476, 63.10249905432425, 61.15509325458158, 60.54928710383754, 46.89912511456398, 29.078773683117284, 39.688973273000414, 49.339714050292976, 51.5468317462552, 48.79689331977598, 42.50148919320876, 39.67433498751733, 41.73766251533262, 45.115662620913604, 40.14438790659751, 31.016412781130885, 30.678671213888354, 32.10462143344264, 23.130005098158314, 20.239896851201213, 18.68634016283097, 14.659014228851566, 16.105224470938406, 11.021210051351979, 4.911150663129745, 0.9293611179436407, 6.5511044186930505, 22.421246536316414, 40.62686689438359, 48.37059443996799, 51.32546101847003, 49.89711030837029, 42.69817644549955, 22.55430509967189, 14.198702516094333, 16.18958582801204, 38.343533623603086, 51.97540560076314, 60.72976320020614, 59.94894481474354, 59.287441007552616, 61.76739877270114, 67.04001349787559, 60.515656701980106, 65.96741784003474, 36.853997861185384, 17.589927873303814, 24.756692417206306, 26.451623093697336, 28.088351680386452, 55.06157352078346, 46.08906938183693, 42.41895468004289, 54.59519194018457, 15.090668124537315, 0.5481243878602982, 0.05404880157701912, 0.03075896642140804, 0.041498825810248816, 0.019460833864286542, 0.1322821945312523, 0.07990103230000505, 0.04933953270195954, 0.028341001410397793, 0.03209640271961689, 0.016998309349160523, 0.03563465640669869, 0.030295343416172172, 0.019492032795002865, 0.05478945155177386, 0.03500838718947864, 0.1968829111466485, 0.11033268765576425, 0.29733441289394136, 0.16191490445165865, 0.14331645001807522, 0.09625302582618692, 0.18077212806430557, 0.1250418515936021, 0.11092324951483358, 0.2154905586353233, 0.09719585789547813, 0.2648757884819662, 0.18531279247854987, 0.12474061050001653, 0.15357375445385135, 0.22067893506778827, 0.24853533223992397, 0.1255266167103283, 0.26183368397816537, 0.21059280531781338, 0.22166585549712184, 12.342103508210952, 93.85935291167229, 68.88777148339057, 63.03484993596231, 50.140505144673014, 42.96514080416772, 72.59973003018287, 29.005056658098777, 19.166524564066243, 67.964186668396, 80.71214860485446, 82.02797828182098, 85.38288347182736, 87.2617458528088, 86.96599129707583, 72.47022905657369, 73.65243142650974, 64.98642521519815, 34.41217730122228, 9.520753429782006, 11.74626802244494, 38.52873225365916, 61.510487448784616, 73.63431007631364, 75.79861117947486, 74.5217227935791, 75.56990561946746, 70.48681197627899, 54.50366735458375, 37.32333298652403, 30.53346899247939, 38.87414009340348, 41.48928234654088, 50.32906524596676, 55.75113404181696, 55.95740364443872, 52.90633701509046, 53.02535741559921, 49.20522774419477, 52.20812766782699, 58.96131946194557, 64.10453519513531, 61.12019984952865, 62.43729645206083, 67.16097939398982, 63.31500130314981, 63.383458429767245, 64.65774628423875, 64.23414991747948, 65.8853461665492, 63.79248319133636, 65.1387700726909, 66.01927157371276, 51.61675583931708, 51.98711779809768, 50.17770882575743, 49.21241352635045, 49.74748757577712, 52.56263540637109, 52.25205429138676, 54.955704827462476, 51.20006284406109, 55.015089511871345, 54.368981007606756, 56.39370064581595, 58.85383082974342, 63.591120473800174, 60.54882818652738, 63.25533813045871, 61.063415696544034, 61.34371219142791, 66.81119811150336, 65.00412687178581, 63.72534005872665, 59.752971433824115, 54.2572287590273, 53.25907968705701, 52.46554889986592, 52.495476584280695, 56.38121966392764, 55.720888645418235, 49.48968195146131, 47.381564878648334, 48.87525443107852, 60.19906259352162, 65.42122779353973, 62.824403009107044, 61.95338972153203, 48.25620243626256, 30.535200718910467, 40.77817232378068, 49.63970476581205, 55.821136582282286, 53.243237233931026, 46.003075338179066, 42.678372398499526, 44.90922827874461, 47.91925122660976, 44.182307181819795, 33.30844979132376, 35.38732167213194, 39.03945230668591, 29.695309477467692, 27.60146983208195, 27.054852247238163, 22.78079648171702, 23.233792974102883, 13.592229562421, 9.140202133886277, 4.315327925066795, 7.517361189088515, 25.484182257806104, 43.39678195215041, 52.12717386984056, 55.33158556107552, 54.414943341285955, 46.08514701166461, 25.134261731178533, 16.125672767239234, 20.72339173286192, 42.518120042739376, 57.208290638462195, 63.86883604911066, 63.436869344403675, 61.85638166243031, 66.94544515302105, 72.38694929307508, 63.13256794406522, 69.94470119476318, 38.6930089612161, 13.915001403900886, 21.776495172131447, 42.4406296976151, 48.9305833847292, 67.90290355682373, 61.70314642690844, 50.8173454192377, 71.79524406310051, 24.968068945792414, 0.7149497780107683, 0.11090495533520177, 0.10573049105944173, 0.12522410391078842, 0.1275400030276468, 0.26201794344571333, 0.18333078512260992, 0.16113703409510274, 0.11823801789432765, 0.1801714691663942, 0.12331145049463357, 0.1266398803601342, 0.13132381853797745, 0.1477987998195233, 0.1590617478735024, 0.1347437269625164], [0.11582987413050667, 0.05229580471472395, 0.02001418300243395, 0.06375246193079699, 0.03494519259660475, 0.04990156927716829, 0.07018128409981728, 0.06100311409682036, 0.044749493920995344, 0.020021054811114748, 0.052033365974503185, 0.007072346080319897, 0.01947325214953913, 0.0632104087590931, 0.05379221191810024, 0.06034421719490521, 0.069100380003933, 0.0275000992546519, 0.05098127444545108, 0.07470379223025615, 0.016947621141650507, 0.1839526952995408, 21.946480889474195, 52.97288394743397, 45.9556774170168, 51.26409161475397, 43.21443880757978, 34.9202379872722, 42.14484376292075, 9.790699770373683, 41.26527578599992, 70.00056359075731, 61.8479093428581, 79.33849534680768, 69.81625141636019, 78.53294249503844, 76.12501513573432, 71.54516943039434, 57.85694476096862, 35.551100238676995, 9.755499439854777, 7.0279087174323305, 31.146708034699966, 52.347681676187825, 65.0056173724513, 69.41958212083387, 67.88128345243393, 68.24146686061736, 62.12868828927318, 37.602880308705, 23.73681929803664, 19.70205949198815, 26.336328944852276, 31.87449597543286, 33.722342214276715, 38.19616233148883, 39.61473849511916, 44.13503477650304, 44.43752404182188, 41.545791933613444, 51.35803630275112, 55.38421984641783, 53.1035969334264, 54.68205282765051, 55.36668685174758, 59.086411691481075, 63.1941609228811, 63.49189235318092, 60.285197842505674, 60.311528713472434, 56.95692554596932, 63.22579483832083, 66.4541918231595, 59.5569392173521, 49.37195593310941, 44.57090423953149, 44.157568793143, 44.05383779156593, 46.05216772325578, 45.775287612791985, 44.65779258358864, 44.52114112915532, 44.446588639290106, 47.77760659494708, 45.27877438452936, 49.478385525365034, 57.00330757325696, 60.10343128635038, 59.86572388679751, 59.37220342697636, 64.41167246910834, 58.32401667871783, 61.58339254317745, 60.996394157409675, 59.46599906490695, 55.222021995052216, 48.579131172549346, 46.85042104413433, 43.201416538607695, 43.00435273878036, 43.03684173091766, 43.47340937583677, 41.78258934328633, 41.578147565164876, 46.106567075175626, 55.35488443989908, 59.896702766418464, 57.52153504279352, 51.29516463125906, 29.569326869903076, 11.871835839363838, 20.266133585283836, 34.98005413240002, 36.46954674874583, 32.93736219406128, 24.320779808105964, 21.132122316668113, 20.371808121281287, 24.4318829044219, 29.168531240955478, 27.234200662182225, 18.573442582161196, 25.703507469546413, 23.789128026654645, 14.49954144416317, 15.57764607091104, 9.309895634651184, 9.36816930770874, 9.15390689526835, 2.5756633522049075, 0.5413487998227919, 8.892397572917323, 22.7820320283213, 37.35129948585264, 40.70356884310323, 47.802952951000584, 46.63444749770626, 41.27240665497319, 24.459353223923717, 14.83242613653983, 18.339685009371852, 38.77418241193218, 47.951100872408965, 46.70512468584123, 37.38006614869641, 59.02843513796407, 66.05397670499741, 61.60147466967183, 51.83378058095133, 59.79376800598637, 17.040162586396743, 13.156242428287385, 28.940137509376775, 40.0938363998167, 44.72537502165764, 57.059118978438846, 58.60299133485364, 48.8567526109757, 25.107593536376957, 4.678158933116544, 0.21173390860278762, 0.05885492694834548, 0.08689576744913094, 0.022779302671551708, 0.07787793964868592, 0.016814463569091696, 0.11411919979558838, 0.045348321868767666, 0.06477716964699569, 0.01213602590254478, 0.049300182595728874, 0.03572085661993873, 0.0408579396354335, 0.013754035199752018, 0.03309643857421414, 0.029465779361705628, 0.025110845303823872, 0.03718446759927658, 0.04101692969279905, 0.02379159401771763, 0.03535684228183762, 0.04977228044862709, 0.10401744185195816, 0.06203957360177752, 0.058962930023910544, 0.017539293828210043, 0.03311318142579929, 0.031063608945377415, 0.0484068283150273, 0.07603496959012362, 0.03156600557568093, 0.017699400458725232, 0.06508000420346376, 0.0665489854591508, 0.09602067901963189, 0.024397035219496297, 0.04936431947674963, 0.28068686264657206, 30.99100955070988, 66.14703101496544, 54.596988385723485, 47.09833052850539, 43.24453907628214, 30.067907187246508, 35.8770295881456, 16.53961520041189, 49.62506648032896, 73.31873970647013, 67.22129760249969, 86.40834792967766, 73.45611679938533, 84.27124454129128, 78.58492174456197, 77.06410900239023, 61.664044318660615, 41.429905506872366, 11.130847161816014, 8.525969751419561, 32.70628360009963, 57.14243012089884, 70.11574791323754, 73.27409528916883, 68.16839310430711, 71.3386566408219, 65.73622941970825, 42.333529380060014, 25.17928465720146, 22.456896958812592, 29.214534759521488, 34.54694209560272, 39.09155707205496, 42.4853172609883, 42.798416537623254, 48.1346324951418, 45.21622042502127, 44.82712130392752, 53.819723667637, 59.488078086606926, 54.90989546622, 56.28756523132325, 57.07758157483993, 60.66229451087214, 64.2717929040232, 66.16821965863629, 63.95899172752135, 63.12648042555779, 63.56095744717506, 67.0865249633789, 69.73235191837435, 62.56883313578945, 53.15715689812937, 48.870053368230025, 50.03726443936748, 48.025465088505904, 49.25882693259947, 50.76421691525368, 51.25224605683358, 49.994349787312174, 51.23874525870047, 52.94566662080827, 52.433683564586026, 53.484847391805346, 57.73781061172486, 62.96377266606977, 62.05994090726299, 63.72159811758227, 69.65741895860242, 62.631018392501346, 63.03215134528376, 64.83457457634711, 61.95186784190517, 59.08590962809902, 54.89519442281416, 50.67373568011869, 46.31019300030124, 48.46464895432996, 50.60783986122378, 50.828402580753455, 46.84687522149856, 44.72966217225598, 48.859231548924605, 59.084109260189926, 62.892644405365, 60.823590217098115, 56.43552095659318, 34.774588615663596, 18.46375350029238, 27.572563925097068, 40.48033891185638, 43.348019046168176, 39.76662835767193, 27.741145433918124, 26.17014596539159, 21.418427882655976, 30.995769346913985, 32.54943586164905, 31.627914213365127, 21.513576738296017, 28.47764103643356, 24.088277393771758, 15.909184409726052, 17.16115397791709, 10.888412325612961, 13.00070966443708, 12.814495140506377, 6.009002952806412, 2.096059952051409, 10.178193661474413, 24.420311912413567, 38.11291394695159, 44.00008170835434, 50.04727040567706, 48.445829422243186, 42.55836356070734, 26.725859526664983, 18.001845382875015, 22.357309941322576, 44.80030798142956, 53.87109887215399, 51.16724829519949, 44.16090673015964, 62.36547393183555, 70.93678628244709, 66.54774819650959, 58.707389139360004, 63.264720439910896, 24.63019205677894, 23.901254861585556, 29.957888626283218, 29.475841099216094, 43.40856867451822, 65.0764593001335, 65.2333305728051, 54.19156435997256, 42.135206499407374, 7.755986913557976, 0.5949566296992764, 0.08551442665198157, 0.1949892030848611, 0.03631547874500675, 0.11591787465036878, 0.014372655986658028, 0.08323939066500434, 0.08857672523346641, 0.04509386959515753, 0.00935981423789335, 0.02845745826620729, 0.013264553854241969, 0.01679836040092332, 0.022203242856889002, 0.020156420632115295, 0.061990210726376505, 0.21186205979076125, 0.10752897439224106, 0.08983758338276418, 0.16961693793775576, 0.13726918177018244, 0.08467285608452174, 0.2386232423445871, 0.14724753827096956, 0.1960532532464112, 0.1130957676157836, 0.16539769337302254, 0.08123695940500306, 0.19769681827916255, 0.2076667171692656, 0.181236392668178, 0.1365715054975402, 0.14429587810750932, 0.124037655881576, 0.12630132312375691, 0.25873590020402787, 0.15845629326518507, 0.34091476471193377, 53.78270433795068, 84.27711240706905, 66.51706741702172, 69.99309539794922, 55.602531125468595, 50.929525206165934, 50.318965142773045, 14.258675556029043, 50.30548787886097, 83.41714059152912, 73.19234525003742, 93.25312706731981, 80.43508806536275, 90.34827463088497, 86.3179059182444, 81.13904368492865, 64.89003689058366, 41.88229991543678, 13.422169320044981, 10.192461282976213, 34.34786611987699, 59.60569035622382, 74.0784792746267, 78.29443885434058, 72.49352793539725, 74.81693606222831, 71.04460439374371, 46.88011338633876, 34.88714887249854, 30.41151858145191, 35.381034112745716, 41.46625018888905, 45.3162016407136, 47.447135140818936, 47.38695813763527, 51.89266320197813, 49.39651389275828, 50.05959449275848, 57.97371764336863, 61.942461998231956, 59.29242634004163, 59.41374524947136, 60.884775269416075, 63.64925392212407, 66.94160907499253, 67.1894322672198, 64.96256543743995, 66.64273231260239, 67.28491060195431, 66.46568436776438, 71.10867238813832, 63.635760968731304, 55.612352740380075, 50.80252670472669, 50.30124779670469, 49.96856804816954, 53.09324187617148, 55.23188283366542, 54.78278713841593, 53.897912194651944, 54.49332014206917, 56.75803784401187, 52.88981991429483, 55.13253311957083, 59.58696496102118, 64.24592095036661, 61.864002827675115, 64.88957012853315, 64.80137171283846, 62.60074553951141, 64.45873698880597, 65.36923677690568, 63.47486926663307, 61.850968791592514, 57.36178082804526, 54.137769053059245, 49.639430199899984, 51.39613428423482, 55.33054613297986, 54.855762835471864, 50.95005096927766, 46.72213600527856, 51.71167719748713, 61.09310803874847, 65.5140624507781, 63.55611332001225, 57.20621178227087, 37.85682239840108, 25.998234364294238, 30.02902080935817, 36.79624096039803, 44.88244633520804, 43.94693359251946, 30.933111444596324, 27.9691606567752, 27.684837848909442, 35.68454711667953, 38.4915481844256, 35.21213685312579, 25.09576366793725, 35.2722942444586, 31.097090052020167, 23.37732622700353, 23.010684636331376, 18.89627718156384, 19.81829304848948, 17.882830865921512, 12.283812184487621, 4.222017680445026, 11.585779343881915, 25.70476851155681, 39.70341151760471, 45.130477413054436, 50.662298048696215, 51.808363622234715, 45.6967225382405, 28.720665208755005, 22.671142701179754, 26.156751071253133, 49.46333931338403, 58.08978057676747, 55.355178617662006, 45.83633538215391, 68.35519990613385, 77.00309261198967, 70.15270448500111, 60.81311356636786, 67.10379123687744, 24.917956744470906, 19.98564293307643, 37.8066631286375, 55.65024675861482, 64.17831890044674, 67.95587908837103, 78.11851270737188, 61.84009598147485, 60.851913652112415, 11.23038613027142, 0.6936664458724761, 0.1792670104412302, 0.27062938458496527, 0.11668770874459898, 0.19415540830983272, 0.08156392573108596, 0.18867144451266338, 0.21273650319105197, 0.1349829608995107, 0.09637473421471734, 0.10982051957398654, 0.08466090511290297, 0.1425070628043144, 0.10809702092721578, 0.0971988762818998, 0.2530318240244543], [0.0795429551433171, 0.011511931417419786, 0.11134928633128444, 0.04280843396460818, 0.004979990462156674, 0.038624540527140906, 0.060385739160401214, 0.0784753809773153, 0.03670454415823183, 0.08468083872069275, 0.04276539897546173, 0.01906911204118402, 0.011806502758014587, 0.03071263916940699, 0.06902454496030846, 0.05512650725581954, 0.01778637059032917, 0.032592766407516696, 0.04443796809702631, 0.022989065206098943, 0.045983079340188734, 0.08941402103030875, 3.6258725725835372, 46.58636316176384, 53.34453244363108, 46.90042341909101, 43.21913388467605, 46.454928459659705, 40.76407532538138, 25.383177303498794, 26.114983712473226, 73.40827957276376, 54.254204611624445, 69.64266300201416, 75.57272972599154, 71.22598263525194, 72.11280699699157, 70.2615031888408, 57.5534749031067, 32.65837184844479, 13.533305756507383, 11.563302201609458, 30.239634436945764, 46.91697582121819, 62.84504644332394, 69.20666802314021, 65.57995826967301, 66.89897291121945, 60.170915665165076, 31.89502762209985, 21.512992305140344, 16.075098706829934, 19.77056368704765, 23.763595358017955, 27.644794371820268, 30.76811302092768, 31.040600076798473, 36.385451132251376, 36.71570685602004, 42.474424839019775, 56.86954298327046, 51.76648839827507, 52.20229902575093, 54.1858063205596, 55.08779848775556, 61.41759787836383, 60.09977171497961, 56.24119104877595, 59.10984393089049, 56.1701294683641, 64.04830409634498, 66.43667451796993, 62.38612913316297, 57.7853968066554, 47.18433633927376, 48.00222112286476, 45.79271862583776, 43.40390889875351, 43.7215228234568, 43.395530716065444, 42.97538603505781, 43.93498605297458, 45.121314756331905, 42.52363881757183, 46.89857206036968, 49.64954991494456, 57.41855321391937, 59.43775799966628, 60.93532285382671, 57.687729789364724, 65.84927605044457, 63.47042914359801, 57.47786729566513, 59.55535457980249, 56.73985373589301, 53.79736223528462, 47.19431877136231, 47.59549487021662, 44.66120112326838, 44.237910701382546, 43.809964426102184, 41.97385195762881, 40.30805664677774, 43.47531957011069, 47.34366301567324, 55.77364844660605, 58.62618823205271, 60.00021019289571, 50.42791681904947, 45.53738017236033, 39.53836602549399, 21.81740745421379, 21.192544467987556, 24.26400742223186, 21.916021723901075, 12.71424328127215, 8.876981677547578, 8.867897468228495, 11.716797294155246, 18.885055280500843, 26.70642222127607, 17.54633661239378, 15.089024651435116, 21.162497151282526, 13.403587091353632, 10.6657648663367, 7.540936104712948, 4.947097714870207, 5.962884214616591, 4.685931109612988, 1.8892652421228349, 8.138769057489212, 22.895115921574256, 35.44698876719321, 41.08874167165449, 44.8888554880696, 42.20335768115136, 40.24317279938729, 25.982723351447817, 9.414569966254696, 20.34105673913033, 39.86528773461619, 52.5728924043717, 31.933355062238633, 44.17717672163441, 61.48669827368952, 62.3031396250571, 50.671747038441325, 64.91647366554507, 46.809781366778964, 10.095027646710797, 23.786403940569972, 45.407490884104085, 41.57138539898781, 44.413162200681626, 45.53048856796757, 35.973288474544404, 50.57380545523859, 22.37620988199788, 1.1578070660752635, 0.16778137594942125, 0.06429978961785955, 0.04228605393079981, 0.016437138453306212, 0.04911267491538198, 0.06438495561240182, 0.057405710761104865, 0.07180907538220768, 0.03524861321033489, 0.06947125848983565, 0.06547155940244276, 0.0748475179857304, 0.019128774968726982, 0.02307509496477583, 0.04332065184210097, 0.1292604526444789, 0.07735235736735406, 0.026034027217857303, 0.04426296297160368, 0.02420447327406897, 0.029957148156339125, 0.03449336926062261, 0.10533166568606131, 0.0802262519456206, 0.017079572125728575, 0.006770783708611083, 0.051784368246913924, 0.04135698463106829, 0.02215354864846074, 0.056599483660031716, 0.05132875660614622, 0.040446799398670276, 0.02196707518681163, 0.04439817365979956, 0.04440473137243141, 0.052394369587061874, 0.16537676385093122, 0.07026689442535562, 5.364652650971567, 63.24624999876946, 63.79644870758057, 48.367652662338756, 48.037016468663374, 39.3026315781378, 32.70972547992584, 30.002723278537875, 32.80824561272898, 83.58196643091019, 58.42389199041552, 79.62043531479375, 79.73586282422467, 80.01664961538008, 77.01006658615606, 75.01295258921962, 62.75032512603268, 36.76116712631718, 16.592133775834117, 12.3631509465556, 31.840685144547496, 51.22099261130057, 65.24457208571896, 71.61596821200463, 67.6171745792512, 69.13204885298207, 59.60503924277521, 37.36660065189485, 23.801638426319247, 20.77118189104142, 22.967444427551765, 30.401647936913278, 30.422991514205936, 34.354455701766476, 33.678682311888664, 39.14677227697065, 39.56717583440965, 45.15416460652506, 59.160242465234575, 53.666143263539965, 53.421112798875384, 53.70883434049545, 57.62481889417095, 63.15520001995949, 63.879759850040564, 59.472129729486284, 64.33005186819261, 58.670428645226266, 63.9310016939717, 67.25216665575581, 67.31217891939225, 60.802566312974506, 51.354278672126036, 49.75303380720077, 48.67646871074554, 48.72889903283889, 47.98249160089801, 49.18030500411988, 48.35368902452531, 48.90224033786405, 49.67285271613829, 48.69989310541461, 50.489113638477946, 53.53219432215537, 59.52164180817143, 61.58820921374906, 63.787799881350615, 62.3526438590019, 69.21887443911645, 68.6975835984753, 60.61206463844546, 64.59092870835336, 60.3687168705848, 57.57700912414059, 50.394666887098744, 52.540011175217174, 49.7608510909542, 50.47092560798892, 49.720097664863836, 51.02703532864971, 45.62614340935984, 46.96395404877202, 50.252877127739694, 60.2803772495639, 61.6685942680605, 64.09695325359222, 54.358676941164084, 47.924766079072036, 41.67512816767539, 25.63645455145067, 26.265030061045003, 29.183499005533037, 27.64313520923738, 15.45966607909049, 12.191648252548712, 9.89046133333637, 13.80971420195795, 23.640931075619115, 30.320180308434274, 22.43192715029563, 17.634997867768814, 23.78095184603045, 13.824097533379833, 11.996719202687665, 8.825877116572473, 7.52811142513829, 9.734876598081282, 8.70307751240269, 2.6140469312667847, 10.849775018230563, 25.497182953742247, 38.49183843981835, 41.32462516907723, 48.049689646690126, 42.16399669647217, 43.571637292062086, 26.537768148606826, 10.594366942682575, 24.195775831899336, 43.339087809285815, 58.79172794280514, 37.37996416707193, 48.53303940065446, 64.32755331839284, 69.23272040582472, 58.4284419398154, 67.98953302444951, 53.90184633193478, 21.444427313343173, 27.788686521591682, 33.803456829440215, 31.02941151588194, 49.288946813152684, 52.906344859830796, 38.96612751868464, 63.645621807344504, 35.57222220205492, 1.593364700675011, 0.09034020600900536, 0.048740306388466596, 0.028715752470757694, 0.015931720563751316, 0.06252862498044007, 0.08312157400312924, 0.1162796903161272, 0.05885764273003705, 0.019971419974500616, 0.08009097613995114, 0.040612833634499586, 0.04488911727563508, 0.06525513190295427, 0.03821966305915867, 0.05526120466510615, 0.0062809059126002174, 0.16144418938746377, 0.12047945326494595, 0.21050257548209161, 0.07307260717836118, 0.12720927520985567, 0.10519496495685271, 0.19636699689492104, 0.23688302765930855, 0.1503100360353147, 0.17703807762553617, 0.08748455964509519, 0.11769878392618512, 0.12524891749865588, 0.16561063517245556, 0.14924710436213404, 0.17024028835998428, 0.24071219557475662, 0.12608040634903217, 0.19844455073677725, 0.1021846607627888, 0.4512844390926823, 0.47663189831279945, 9.081746070615708, 86.5574921331098, 74.81037001455985, 69.0512009589903, 53.315910908483694, 67.46348827115952, 52.6190665460402, 32.02333227280648, 33.471942024846236, 88.28491964647847, 65.9297787758612, 82.61925989581694, 88.03722981483706, 85.30278867290866, 81.17287805003505, 80.69572171857281, 66.48039325591057, 40.32663299191383, 17.191989691026752, 14.571349255500303, 35.65773771655175, 56.46422093914401, 70.84149622148084, 74.6856386430802, 70.48026946283156, 72.67248999687934, 64.28908271174278, 44.736063480377204, 29.227862973367017, 27.73671119443832, 29.524417692615142, 37.17930747616676, 34.44838077791276, 40.55856666257305, 36.271055206175774, 42.89280053107969, 42.31543548645512, 48.866346728417184, 64.63443171593451, 58.31172004822762, 57.283811953759965, 57.20959678772957, 57.40850410153789, 64.2182094050992, 66.37693682024556, 62.095661932422274, 62.55375162247689, 60.534252658967056, 66.11817805997788, 69.01783727830457, 67.75002525698754, 62.07099414640858, 53.34828222951582, 53.41352693496212, 49.96221380849039, 49.8894577641641, 51.28003604950444, 50.73613666719007, 49.467630386352546, 52.284123589915616, 51.04110487045781, 48.73977576532672, 53.18641777961485, 55.84737331636491, 60.49409151077271, 62.805971791667325, 64.96918247592065, 61.22144799078665, 68.6128447132726, 66.48217401196881, 61.58855045995405, 63.5806320559594, 60.362696032370295, 59.64173301573723, 51.410082232567575, 56.56429236935031, 55.06274238709481, 53.051856948483376, 54.77791555466191, 54.64908922872236, 50.5596221646955, 51.47380113601685, 53.51223730271863, 61.99008741686421, 63.93741084683327, 64.16860711190009, 55.50214590564851, 52.82646579127158, 49.899075415826616, 31.224288594338205, 26.56945109367371, 30.060907717674013, 31.46089969142791, 17.309133237408055, 14.038346217524621, 13.253281866350482, 18.649197278484223, 26.187833893683653, 35.16034587737053, 26.78699751054087, 22.22135078522467, 30.174903561992032, 20.727629853833108, 17.880159731834166, 14.536652949548538, 13.018867296557273, 14.858189244424144, 12.273092346806681, 6.965628343243753, 13.13086175149487, 29.909892543669674, 41.51306759926581, 45.61087754464919, 51.217842948052194, 43.01611592692714, 47.15494209720243, 28.11098179509563, 12.125090533687223, 28.760343905418154, 47.25398978879375, 63.441415371433386, 41.93659336336198, 54.60115002047632, 69.78751613247779, 76.18117563186154, 60.55360171102709, 74.20605044211112, 56.503511321160104, 16.914178017647036, 31.25539298980467, 56.433763734755985, 60.857640312563994, 58.62338765974968, 62.20480580483714, 51.54425082668182, 76.3056795058712, 50.9233945415866, 2.151293052781013, 0.378989763557911, 0.16342636528274707, 0.09144862032225055, 0.10847328501122613, 0.12443083518695448, 0.19170841622737148, 0.1060290125408961, 0.22096203519932686, 0.12199551828445927, 0.1582181778165602, 0.1274753069024413, 0.21705658024837896, 0.22686874163487267, 0.10728076190477419, 0.2169258703267382, 0.2515350107944781], [0.04796075829935651, 0.013353570398213643, 0.05875412509926866, 0.03888084290308818, 0.022063539063017217, 0.05461362671227225, 0.05872846498424488, 0.05608025224759214, 0.04515991786554937, 0.03163678252378539, 0.04572845469679564, 0.07979853739661556, 0.03276782515909403, 0.02344815488604288, 0.0587423388365536, 0.004663561196667293, 0.08502033824521689, 0.056164943267621344, 0.05443761418122919, 0.047695776147227135, 0.07843218894014437, 0.05008179146135527, 0.12404261247044611, 38.432414531707764, 64.49526209985056, 40.286981751841886, 40.54759579320108, 48.295987036920366, 44.29076856182468, 26.86826902051126, 13.99432937945089, 64.76203034001013, 70.6862723442816, 57.153789304917865, 80.75360021283551, 73.67816217484014, 78.66934684015091, 72.46094872874599, 61.9977831071423, 37.16815617776687, 22.011962898315925, 8.34621144879249, 21.385201484926288, 44.1567333282963, 55.48662900924683, 68.11654721536945, 64.47110422195928, 67.10577595618464, 52.172661596728915, 24.314031370224495, 14.220733488759688, 18.051120158164732, 19.40912904277925, 20.368260337460427, 17.78832527898973, 19.953281417969738, 23.345184364626487, 24.696744872677712, 29.771415225921142, 49.2802313066298, 50.576813913160755, 47.396579711667954, 47.12580673156246, 49.75009987431188, 53.515386965967, 58.95305110562233, 51.86094299439461, 52.29295676754367, 46.77408387584072, 57.742921460059385, 71.46865967781314, 62.234541293113466, 64.30879262185866, 51.242875514491914, 47.54894810338175, 48.07420053789693, 46.39260984236195, 43.880880878817656, 43.466576606996604, 46.45212004261632, 43.28347644498272, 43.332953222336315, 44.5750541071738, 46.763979850276826, 46.93649745756581, 53.76272770666308, 54.54285183260518, 58.22541613732615, 60.36954841306133, 62.350474788296616, 61.883489162691184, 65.78951481849917, 58.63190312539378, 59.89181157081359, 54.715381207004675, 52.71671395148001, 48.73877948330295, 47.27750832034696, 46.22459511603079, 43.589786098849395, 43.205589940471036, 42.57612405284759, 41.27295578679731, 41.99526809876965, 47.61534206328854, 54.12813571191604, 59.50738399259506, 55.764870182160415, 55.934485235521876, 62.75525162296911, 62.09656799993208, 36.48880166392173, 22.079029544707268, 14.14488269436744, 10.911665116586994, 9.484885315741263, 6.152603376296259, 6.494033442389581, 4.4635302693613115, 11.891042705505125, 25.068252163548625, 26.26974278880704, 9.85843518087941, 12.69815666060294, 11.269235245643124, 7.240347718038867, 4.043775373889554, 2.940947802797441, 3.219624113652014, 4.121953604682799, 2.087493985891342, 5.215159846890358, 24.208288192749027, 28.934752095130186, 37.671808119743105, 35.73489466021138, 39.0224096082872, 38.668898151766875, 21.048162021944602, 7.198065057877572, 17.843467920057236, 48.804322288882354, 49.762796586559666, 41.937617101976954, 59.55043200523623, 63.25946838625016, 56.09773820446384, 44.40029682651643, 78.5842078731906, 21.65593328014497, 13.955995075164305, 37.15948381731587, 42.816416294344016, 34.11231994628906, 48.83680735864947, 33.113617820124475, 35.86701577709567, 17.268497482422863, 6.170343275993101, 0.16065429145049664, 0.10167724242614162, 0.028697025451448657, 0.013926557242690075, 0.04842162147284516, 0.07504834027420129, 0.0354029416226812, 0.03332891561571629, 0.04198331896576189, 0.042894733769278375, 0.0305455343257035, 0.028459750784320698, 0.050340001396234, 0.05933859272890034, 0.03583000116651097, 0.04926204290841857, 0.027635428686476046, 0.06391885239751109, 0.020148872750841325, 0.04541781370437915, 0.02714731193508112, 0.00579235392750331, 0.0639741026586102, 0.012990251284903817, 0.04460500590803643, 0.05234000415751531, 0.13006435466870186, 0.050671916650307756, 0.07699273271305908, 0.019507660988658186, 0.07083596751814888, 0.011068467058301454, 0.050317838472584565, 0.031977379469261054, 0.08074643330708628, 0.114632785140026, 0.03512752918346274, 0.08547156403261809, 0.07147982611411041, 0.16825377640704955, 47.13387896937709, 77.49505196848224, 47.3558105960969, 32.01129059637747, 40.64634538465931, 30.70012461754584, 30.69717303399117, 22.73974495549356, 70.85199248406195, 72.37377012929609, 61.66647618816745, 86.63029132350799, 81.16202092939808, 84.26586304941486, 78.54601967719294, 64.53322279837825, 38.87339876544091, 23.871378167983025, 11.11393488222553, 23.713004627535422, 46.64564586454823, 59.40470810859435, 71.53940354624103, 66.95746329522902, 66.20293263466128, 52.099548616716945, 30.116730889966412, 16.246553351802213, 20.14497353184608, 23.60668093927445, 26.227643989747573, 22.787011477255053, 22.817558896157053, 25.041013263886978, 26.364987742516306, 33.29300741995535, 53.48603586996756, 56.08868929647631, 48.15938265092912, 48.10075890633368, 52.45892401664488, 54.653160648961226, 60.538371147647986, 55.0691907636581, 58.534169427810184, 53.468322446269376, 60.91804873558783, 71.62085548523935, 64.76206564134168, 67.47935033613636, 55.703347806007635, 50.51647609280002, 50.43854251984627, 50.88022101309992, 47.9416597274042, 46.840238571167, 51.349948375455796, 49.8470804768224, 48.584504819685414, 48.703058458143666, 48.331464875128965, 51.5955711180164, 55.93440678811843, 57.97925995242212, 62.073104381561286, 63.58453873665103, 65.84148622328236, 65.67948841279554, 72.52562861288749, 63.02428307071809, 63.28820759250272, 58.89994613585934, 57.34459300195017, 52.18391487675329, 51.261573453103345, 51.00301865608462, 49.27013120343609, 52.00353291726882, 47.619907702169115, 46.66625399743357, 45.16065612916024, 49.40494306625859, 58.35581925607497, 61.78722243155203, 61.47806905931043, 58.85596459911716, 62.09342618142406, 60.4668192709646, 40.086340750417406, 24.198150827038674, 16.340670624086936, 13.339482815034929, 11.312864749662339, 8.55092877341855, 8.079384863376617, 7.185649285393377, 14.11306344693707, 26.18742204481556, 27.31671948586741, 13.352544307708742, 14.398250156833281, 11.528932432974539, 8.545006975050896, 4.977274960087192, 2.4272239496631007, 3.637656108025582, 6.590838028538612, 4.845336233415912, 8.366646997390255, 26.609272956848148, 33.34984648612238, 37.346745614082586, 39.55323573081724, 39.75473573130947, 41.58694544146138, 21.11406764676494, 8.02111364180042, 19.206064016588275, 52.006521763340125, 54.47166865871799, 49.394486027379195, 61.3213703709264, 66.93887126061225, 61.43183608208934, 51.77064218828755, 78.14050151455787, 32.05559768984395, 22.573469800333825, 32.5196474213754, 32.822448515122936, 30.942007380147135, 60.175281263166866, 36.44856991306428, 44.4117070013477, 33.96552916496031, 10.738404220150365, 0.1809531086755376, 0.04318698865151213, 0.0818052587489928, 0.05242679042801742, 0.05958672477713516, 0.03235926663863563, 0.04381820679672303, 0.050000750850285255, 0.017107086173529108, 0.03141292205621158, 0.039792154284734885, 0.018360373458915183, 0.008246202018081902, 0.143390683937938, 0.05458953707749325, 0.03224317367459017, 0.04123106275895431, 0.12301931052558845, 0.11356508839995631, 0.22458233690309912, 0.16614585483987487, 0.1423269248897991, 0.17560723988759905, 0.16843202974527113, 0.14820550057676532, 0.20684695712501006, 0.15843942400909242, 0.12444555939685915, 0.181733078113006, 0.20728502152187211, 0.11844784171590883, 0.0838772967577942, 0.10477038370745798, 0.15122181856103484, 0.24080414144742876, 0.1734426124922691, 0.1189004388006945, 0.15642416843723866, 0.20913512385900945, 0.33556036170451875, 67.71149189241471, 89.11464214324953, 61.569958425337276, 53.197922091330256, 63.31211443870299, 66.15047485597673, 32.3552804993045, 20.3192699340082, 76.16927516075873, 81.05942741517099, 69.7822601564469, 90.63136777570172, 87.26309514814808, 89.74254300517421, 82.50684476667836, 69.65115101106706, 41.90967413686937, 25.972658549585653, 13.061935901641847, 24.58639487143486, 50.79858864507368, 62.887353128002545, 75.77573591662993, 72.1868456563642, 71.84427369025447, 59.50885488140968, 38.21386791044666, 25.83978237644319, 27.24901741550815, 30.1296119536123, 35.02217646568052, 27.35826523073258, 24.959747637471846, 27.79342474475984, 30.91039699892844, 37.693079133187574, 57.374771718055975, 60.75425840193226, 55.30263454683366, 51.197462312636844, 55.20338289199337, 57.456831624431, 62.99042517139066, 57.115193182422274, 58.55671521156066, 51.23932969185614, 63.51237889259093, 77.47480469365274, 69.13200962928035, 68.95252197019516, 59.25978045309744, 52.65445809210501, 51.74816308483001, 52.58700116988152, 50.96162980602634, 49.29549324897028, 53.63226575236167, 52.72294267531365, 49.12296779694096, 52.53423352395335, 51.91457356176069, 54.36189720707556, 60.283213123198486, 58.95531039084158, 63.17114445470995, 64.99856887325164, 67.90369587559854, 65.46067899273288, 68.83185417421403, 64.0865275936742, 63.21631054724417, 58.335136598156346, 58.6830625995513, 54.79328340099704, 54.7913339830214, 58.13438184799687, 53.70454326752694, 53.15295211730465, 50.9613238611529, 50.703180913002264, 46.361936907614435, 50.58714543619464, 59.23395164551274, 65.40626395133235, 61.03710051505797, 59.574283938254084, 65.52821043998965, 67.4432017726283, 47.71308752798265, 28.98000251862311, 17.67614745324658, 15.49393484669347, 14.684796948586742, 10.39765811735584, 11.621133627430087, 10.171938461642112, 20.759891348500407, 32.22090009720095, 36.303159806036184, 18.434904467674997, 21.652332544326786, 17.617180501261068, 14.748502123740414, 11.535765201814714, 8.299752935286492, 9.471227622801258, 11.325150593634575, 8.568442156237941, 11.378631130341562, 29.765680720729215, 37.226160187875074, 41.35942443724602, 40.87644338607788, 42.28127948699459, 45.36977729489727, 23.250837633686682, 9.681791240169156, 22.350230063161543, 56.30059534503568, 57.46020878514936, 51.870152719559215, 66.01183475986605, 71.86996521488314, 64.54766496535271, 53.05699525340911, 87.27853359714632, 29.448445304747555, 19.036376399378625, 44.94108576928416, 56.50952823700444, 47.35258248544509, 62.434060496668664, 50.34557057965187, 56.75238178622339, 60.07160125240203, 15.474809369733258, 0.5113363860835952, 0.10893972530480354, 0.16625353615851174, 0.14739332480296014, 0.1671058855830662, 0.18455163816050177, 0.11399566811779815, 0.21749185608519664, 0.11844403425892515, 0.12079532663788527, 0.0720718282184774, 0.16112802490111322, 0.1773888539643057, 0.3561839695659376, 0.13619831342610622, 0.21409911313845267, 0.12644842732697725], [0.007718252046259061, 0.019915062716350924, 0.05195138690572593, 0.02902591465822151, 0.013922633914907855, 0.04811795188053962, 0.025589458734518098, 0.028956466872665673, 0.05837156760296034, 0.06903517826069748, 0.05864656252426006, 0.04804212449779434, 0.032253079191451116, 0.03373407270579088, 0.060594291276028084, 0.12690929816134516, 0.04961992471268581, 0.0106315671150843, 0.027817989354051893, 0.053990115411579616, 0.06900405210833396, 0.09325138608654661, 0.17744877736174292, 9.756075047677564, 78.64826017810454, 40.37956929975941, 99.77944897067164, 123.18677348475303, 48.67267185641874, 47.072995939562404, 9.950364751200523, 35.151814722245746, 76.50685787200928, 90.27257288655927, 75.7161472689721, 62.39093795899422, 76.94637513929798, 72.65858911698865, 61.875040377340014, 49.040688237836285, 26.890720667377597, 9.214533990429295, 17.106821306290165, 36.1184867735832, 57.09770725619409, 63.18005215737128, 65.6768015892275, 56.847361979946015, 46.95849803186233, 21.16905535421064, 13.82048503045113, 16.178034447854568, 16.30759817938651, 14.930829578830352, 15.234936821845272, 12.94182017926247, 17.223872676972423, 18.193572798082908, 30.127531136235884, 47.009955606152936, 42.50883579254151, 39.08166485448038, 40.798450977571555, 42.86394757609214, 52.96170519244287, 45.89367258933283, 38.25964981509794, 25.53638312124437, 29.36142752247472, 62.3807829426181, 64.3999328151826, 60.66287502165764, 57.453230888612815, 50.686008776387865, 48.78567926345333, 46.08655906492665, 45.954657600772, 43.83281223235592, 43.09212753849645, 43.775898641155614, 45.01845844330327, 42.155583212452555, 43.63319104717624, 46.50696262236565, 52.30546520602319, 55.07074009987616, 57.76966810226441, 61.64477371400403, 57.484770667168405, 59.58250914850543, 62.87260501615463, 62.90996166967577, 63.487985672489295, 55.46434994666807, 56.74489790393461, 52.32899158231674, 48.98793628138881, 46.50499751490932, 45.344556454689275, 45.37240528291272, 44.029342589839814, 41.93083140157884, 39.547489458514804, 44.26580659804806, 46.320379395638746, 49.85672166270595, 54.974587117472005, 56.13447120112758, 58.70254108982702, 62.58445985855595, 59.58206199830579, 43.94250131422474, 24.87491265419991, 10.60101536012465, 4.67462242610993, 7.1834037284697265, 2.3245328664779663, 4.669600321400551, 4.073368185950864, 9.549542646254263, 16.675801853979788, 25.747963613079442, 12.985728171563919, 6.474678506774287, 6.054895664415052, 3.8719709025275324, 4.8156831149132024, 0.851827442886368, 1.4104936295940032, 4.018290999435609, 1.6402605584552212, 2.3353747879305193, 15.122451090043592, 30.34318893186508, 33.75530973557503, 31.767056372857866, 31.18146807916703, 35.823920696012436, 15.138892685213397, 4.661847756754968, 11.300387690144202, 49.07155336872224, 44.97691269843809, 38.30159171935051, 62.81480889166556, 52.27024624424597, 50.494444139542125, 65.3559595538724, 57.6916443147967, 12.08349673978744, 28.62351202195691, 41.39009344962336, 36.68573994790354, 37.192388580691436, 40.95765998286586, 25.251905379756806, 36.894355127888346, 6.833079688010677, 2.9663191639607955, 0.064606485257466, 0.11417883974049362, 0.049662109344236316, 0.07340895042063729, 0.014284675576603942, 0.05786439441444893, 0.03840194985030159, 0.03749290991935038, 0.031040040250386924, 0.047148153516313726, 0.0147868471685797, 0.01719690615221137, 0.01591893551390498, 0.05178046119850009, 0.017870015900341735, 0.03244228375655028, 0.03507544669593054, 0.0687307655631054, 0.010290977830487874, 0.07343140445769795, 0.03639109162313323, 0.03641137763136818, 0.0364960533296389, 0.02088909563157828, 0.057396632619202144, 0.012594698064569986, 0.014713390827960065, 0.02071357531202657, 0.10728584106771216, 0.012517312650508698, 0.02542942679757553, 0.05729012724552905, 0.031592309204561096, 0.037579255689296036, 0.06768791305442011, 0.10105727811253841, 0.04941776560078706, 0.025066597980537245, 0.10624789152174227, 0.49418257429234447, 11.977015176127034, 92.4176779100972, 50.48454015485702, 90.4754457166118, 129.26119912055233, 48.665121293837025, 32.036833070939586, 17.45282142393051, 46.90812695410944, 85.4868733498358, 89.63456015433036, 87.6108995560677, 69.69629749175041, 81.7618219314083, 77.50525013093026, 66.81979594692108, 50.84661022309334, 28.881311762717466, 10.270845928499776, 19.203689021448938, 39.06655980694679, 59.09920254061299, 64.120530620698, 68.38462552716656, 58.183831168759255, 49.284251736056426, 22.44719301500628, 15.249399581263143, 19.84415323503556, 21.22175043629062, 20.244570355261526, 18.070394685191495, 16.67230506097117, 18.800891022528372, 21.61089466464135, 33.610413459039506, 51.16158047030049, 44.983215947305005, 42.289210519483014, 43.03278600015948, 43.43813157850697, 56.05777317477811, 51.746872625043316, 44.20995204679428, 32.39858150482178, 34.224774299129365, 63.83100478879867, 66.3091504189276, 64.60133867879068, 61.18946890677176, 55.47901961111254, 49.72593415168024, 50.975303188447036, 49.26464772993519, 46.83515910179385, 45.542110550788145, 48.606556384794175, 48.84485213987289, 46.54472328001454, 48.51471800957957, 49.24029373353528, 54.58276587147867, 58.242658876603656, 62.72997194720853, 65.7711620484629, 63.38185810273694, 63.161126721289854, 65.55851467194097, 66.81451643666914, 68.24149823957875, 60.16872698260892, 61.34033503070955, 56.74232090673139, 53.72725379082465, 49.889465608904445, 50.348575115203865, 49.409995079040534, 50.68277674336588, 45.8798776134368, 44.9870990937756, 47.84847990159066, 50.571020572416245, 54.18103279605989, 58.34365206380045, 58.34296957139046, 61.17748606589533, 63.86621590583556, 65.39519894507625, 49.28912724218061, 29.924026804585612, 11.499671551489062, 6.848398014422386, 9.706203091529108, 4.351605436494274, 6.531851954998509, 6.382372879212903, 10.634174096968867, 16.28647719660113, 28.345210052305653, 15.194861965794718, 7.184542196412241, 4.479387431375442, 4.52981097082938, 5.947274652219588, 0.9034184390498746, 2.1253085761300983, 3.410747729001507, 1.8206834576783644, 3.1113169318245304, 17.481215461607903, 33.4891180838308, 34.427392175120694, 32.612905694592385, 30.41740605908056, 37.603774609104285, 13.401614139156958, 3.826273819131236, 12.18460367571923, 55.39441016412551, 49.25602243792627, 45.1727762529927, 64.88209016861455, 58.41059515553137, 56.160088200722974, 68.52133581715246, 65.7049838189156, 21.490521046423144, 32.00153762294401, 35.13330897977276, 30.239516765840595, 39.979499309293686, 52.5318879465903, 28.781785541965117, 51.747943432100364, 12.038486561467572, 3.885981853931181, 0.0820144237349591, 0.05705517957047109, 0.01673139090980253, 0.08169815199629915, 0.03955062974484698, 0.16777245868598262, 0.03357853770496384, 0.03654033704210193, 0.057575927837000745, 0.006126678049293978, 0.0320423188273825, 0.09144591603187785, 0.07118426173204376, 0.044328957615840825, 0.020174002349977533, 0.050643069609518976, 0.04922200715349567, 0.17348491586744788, 0.12342443314170647, 0.234109498260002, 0.18471191907601972, 0.13223192384166102, 0.12916726570936943, 0.2292327970386513, 0.13006455385156218, 0.14316180750967997, 0.15188704334920453, 0.1044483969528829, 0.28033170428487564, 0.19194524464828355, 0.15141704840765846, 0.14332084736276057, 0.19155959598720076, 0.12705763576612358, 0.1952173593904703, 0.3288712803154223, 0.20424512335129325, 0.20447282000414788, 0.21622540549405161, 0.8305238860268748, 19.97205780398461, 112.46444117638373, 58.57205167893441, 119.97399145557036, 130.60802336662047, 73.14294692008727, 59.57447221202236, 13.306605508250575, 43.59689343360163, 91.79057721168765, 95.51827230761128, 85.37541527901926, 73.82238772607619, 87.91101578743228, 82.24513638404109, 71.32843494415283, 55.54446435743763, 33.92002967096145, 11.754266715818837, 22.102883438910208, 43.07677145927183, 65.23124387187343, 67.1437680336737, 74.54535899623748, 61.671351694291644, 53.81032566870413, 27.417695022398426, 21.28658917642409, 23.93973135179089, 29.099407311408754, 27.81379165187959, 23.055727174205167, 20.665240633872248, 23.709194044913016, 24.663553776279574, 38.85961555665539, 58.305546237576394, 49.43865191551947, 43.98255263605426, 45.92697743446597, 45.79982596059, 59.13796340265582, 55.212643607970215, 41.83329774487404, 30.498697180901807, 35.12696650720412, 65.95337575481784, 67.96303349156534, 66.87028469577913, 62.257683277130134, 57.64190866101173, 51.98219130116125, 51.518320037472634, 52.009534143632465, 48.87727837408743, 45.2300154009173, 50.12421554134738, 51.39123916625977, 49.62436829843829, 50.8321366771575, 51.628546484055065, 57.787989493339296, 61.18504055084721, 64.38957775792768, 67.16389763739802, 62.62390321300876, 63.221746952303, 66.14288899206346, 65.06702599986907, 68.37976178815289, 61.63192010694935, 62.649563358676055, 57.305451670000636, 58.715767322048066, 52.393196859667384, 54.4114367423519, 53.38290106865668, 54.17750266290481, 48.03353340395036, 46.616043736857755, 51.296659054294715, 52.83678946956512, 55.27167920143374, 59.54416405770087, 60.55389196641984, 63.31670753417477, 65.91525031674293, 69.25366586254489, 60.15372391669982, 35.33836264764109, 12.65620691161002, 8.383717152380175, 13.351682366863376, 6.654639792057776, 8.695996653649116, 9.552727610834184, 15.0854915765024, 24.51757492557649, 34.630484657902876, 24.678150876875847, 14.937511336418892, 11.000934339338734, 10.281807972538857, 11.910036783064566, 9.099749749706639, 9.244158671748254, 8.629864511951324, 7.621265755545709, 7.714458819358581, 23.572411191078928, 38.42705265168221, 37.438011323252034, 35.13575261639011, 33.9719775415236, 42.703424576790106, 14.39587712287903, 4.760213936528852, 14.47207602762407, 57.8275191399359, 51.64680119483702, 46.20706996610088, 68.68894653935587, 62.40649407909763, 61.074947464850645, 73.8441490357922, 69.41223159913095, 16.137881144400566, 37.55874579952609, 51.61536339790591, 53.587915512823294, 51.07057755993259, 59.995166024854115, 43.78757945952877, 71.28920339768933, 26.699650249173565, 4.024357680351504, 0.2756748090107595, 0.18942401864595954, 0.19629032681545905, 0.15440184953472308, 0.08088813659044043, 0.28756063251245406, 0.10362007204563388, 0.1442679925070655, 0.1915778442015571, 0.10981626012512755, 0.1966801736383669, 0.19405529593988774, 0.21922649365038643, 0.0955269506741916, 0.1600303128361702, 0.22504480886122874, 0.1480580592948583], [0.06429311699203907, 0.05791901265301051, 0.009045988234931664, 0.03177685595508064, 0.015115169470288582, 0.026799419917346492, 0.07274095239418168, 0.07925281466375436, 0.05970553735331182, 0.03903671881304153, 0.005674926534054742, 0.01150535646780965, 0.024864831488699685, 0.028125217424765713, 0.05149702781871442, 0.05712617676885379, 0.06790851573309592, 0.05596310591265079, 0.10782325174659492, 0.09249574760155332, 0.10259958164345834, 0.01802538619226506, 0.08305411230051711, 0.8581208245408151, 51.981096959883175, 51.735301633034986, 40.93753822388188, 40.23941516876221, 38.470755700142156, 55.92907236468408, 23.68300634045755, 14.258905014684125, 62.55073139744421, 73.52969261907762, 49.46158601391701, 70.8365854140251, 76.9767499739124, 78.08496859765823, 77.51551889604139, 59.73331643689064, 28.561654283154397, 8.279953791249184, 11.919586773841612, 26.532055216450846, 47.51667484160393, 50.52459932142689, 52.836259949591856, 47.70472895714545, 35.469856185297814, 17.835656519859068, 12.478357822664323, 10.904521499910663, 12.834848319330524, 10.165368491603482, 13.278779233655623, 13.047253489494326, 10.863414079912248, 13.001098959676682, 31.68184876441956, 42.74702564362557, 29.30458453393752, 29.330603576475575, 34.044408029125584, 38.52289576684275, 37.05219522599251, 28.068320135916434, 18.228419134693763, 15.299202895933583, 36.891185852789114, 61.82452024952058, 61.03065606086486, 61.54137219152143, 56.918333345843905, 52.200012283940474, 48.78263550419962, 48.54841116935977, 45.32547804617113, 44.59170064618511, 45.08589967604607, 44.74662642325125, 44.9700681624874, 44.97253141095562, 45.583754354907626, 54.56515442940497, 55.57250930416969, 59.86197802328295, 58.76930375253001, 62.338213459137954, 51.36022890767744, 58.95862871600736, 64.3673889098629, 62.555304881065126, 62.37139671079574, 57.71329187577771, 56.13968403108659, 50.20822094332788, 48.556812886268865, 46.68739557266236, 45.413550946020315, 46.31241698418894, 42.98096364544284, 41.1056000186551, 42.227770513103856, 43.13086878868842, 45.65509442360171, 48.806138346272135, 51.731473399746804, 54.63560412006994, 59.141662197728316, 64.8087457687624, 66.02228395400509, 48.600421797844675, 24.75920665648676, 12.954987575930934, 5.862063121411109, 6.091999325060076, 2.690431658298739, 2.3266345214459205, 2.419541007088077, 6.862562183410891, 11.417880327470842, 18.077535360090195, 14.66423196177329, 7.533980271508617, 5.3744629890688005, 2.1273212423247676, 1.9148626298673692, 2.7265662483630644, 3.070094292202304, 6.201309898207265, 3.925395790607699, 7.488519510915203, 3.9259485996538594, 21.794924428386075, 26.70763815602949, 25.077354023533484, 24.92605055532148, 29.970655941194106, 12.531793252114328, 1.4198879513048357, 7.694581718214097, 48.26303520510274, 41.98015128412555, 48.44519792064544, 67.72693034141295, 51.54752992814588, 49.73782285567253, 75.06901110372236, 28.741357672599058, 12.466793694803792, 42.794972696611964, 37.00348723319269, 37.188344617043775, 37.108277274716286, 42.501053810119636, 30.3350676644233, 22.410677709887107, 2.1127520886159714, 0.08185104016334781, 0.017482423291151083, 0.06560047667834067, 0.08221478637067542, 0.03127483470786003, 0.05243012674092766, 0.0870388650125073, 0.11022572645977621, 0.06419657076138162, 0.022998248685091253, 0.007549788832904832, 0.10927285097779767, 0.015394686225561366, 0.028712858573623726, 0.05353901985912554, 0.048724302811728376, 0.015751592225335058, 0.06791105148412528, 0.018067904072062626, 0.04573310485049602, 0.022717383615071737, 0.056600161647844704, 0.07324826347851947, 0.00747644740547384, 0.06681752992012809, 0.0338791506064515, 0.03732407563215783, 0.010100384731025947, 0.027136316658147884, 0.032911010822581674, 0.025646551437075102, 0.04623234902899112, 0.03813910508348096, 0.02972149951083045, 0.05359439269429254, 0.055416348961091814, 0.030725045963340712, 0.06480866352156286, 0.10071079952702408, 0.05730429987212824, 0.06818580891816847, 1.2270208424137485, 68.0528793027324, 62.98363554862238, 51.09784587737053, 53.050464507072206, 43.32506925828996, 39.94939119585099, 24.176573868720766, 26.62818466463397, 70.81868371655865, 80.77591849911599, 57.51129765664378, 75.48822618299916, 83.59795401173254, 83.07667886057209, 79.73012047429239, 63.93968974390338, 33.127985462065666, 10.015723205381825, 13.700644854576359, 29.153026111664314, 50.840687444133145, 56.14234732043359, 55.11506288282333, 49.73059000507478, 37.488460848408366, 20.930139864644698, 15.62480963045551, 13.797777448931049, 16.924595832824707, 13.5594650237791, 16.02836758859696, 15.172083781611535, 13.908946244947373, 16.48686912751967, 38.58673626376737, 47.46402486678093, 29.18336956731735, 30.845197400739117, 34.96903619458599, 41.42415923456992, 42.27743164185555, 33.30244072021977, 23.185696871049945, 18.889960204401326, 40.04728963298183, 63.129120180683756, 64.56304850116854, 64.92011754743515, 59.233669234860336, 53.8850821218183, 51.83352562689012, 51.55779477088682, 49.61933981987738, 49.71404544768795, 48.09403596385833, 50.69480665268437, 49.21016993061189, 48.953701834524836, 50.126368922571984, 55.83189956603512, 60.5298399925232, 61.03553548935921, 60.670904113400375, 64.9299273952361, 55.89960751994964, 60.5764259830598, 69.12202327482163, 64.40897780079996, 67.63058124050018, 62.808933181147424, 59.53651151349468, 54.162817308979655, 52.126381551065755, 52.68010254829161, 48.95303110922537, 51.409313448013805, 47.38257292778262, 46.18470068900816, 44.768372043486565, 46.899846830675685, 49.126121382559504, 52.27465498831965, 53.97617916907034, 58.30372625781644, 61.80674406789965, 66.2831215704641, 66.55080764524399, 54.71047039954893, 28.79033434775568, 13.606477572071938, 8.570636722349352, 8.6113215069617, 3.8985819778134747, 3.119610293257621, 4.520491419299956, 6.526617552003553, 10.759653660558886, 18.490668804414813, 16.07224027956686, 7.0662552791257065, 4.212982500753095, 2.676412371858474, 3.19690574561396, 4.824839888080474, 3.8370907354739408, 6.088817792554056, 3.083780912622329, 4.949864947026776, 5.440931474008869, 23.94195729686368, 31.669773747844083, 25.931693315505985, 26.466410429246967, 30.84614661432082, 13.921896930663818, 1.3714872516932026, 7.716559738882127, 53.67037157858572, 45.881736816898474, 50.769567028168716, 70.07587309806578, 60.99833573064497, 55.41707361898115, 77.87931088478335, 40.35244218764767, 21.60990622735793, 37.68047655782392, 32.68044890895967, 27.96006271916051, 44.997693415611025, 50.90947797221523, 40.225118129484116, 42.5735862793461, 5.852578830334449, 0.6112360593772704, 0.018996170894693465, 0.06283330963924527, 0.03810758056539682, 0.08316944683751754, 0.043796618439016805, 0.07308344732248977, 0.1114785866511445, 0.0370266534868748, 0.03667445222456609, 0.03841314622531495, 0.02861156259783574, 0.023299775146428617, 0.02393646890507831, 0.03035897467916291, 0.03135637710652044, 0.03803421998576772, 0.019929624132571683, 0.1521938462411204, 0.14825448423864382, 0.2112520239766567, 0.16361676877544773, 0.10724254943911107, 0.07721845285906907, 0.21062072156177414, 0.16847027285445124, 0.16343385762264653, 0.12925444651515255, 0.12065497933015709, 0.17105845494135735, 0.13516584140879495, 0.1299800083882386, 0.21712938924470257, 0.17449714784179965, 0.17151754079086168, 0.15029695125356798, 0.2827302336452469, 0.1510410677761801, 0.23755804305115055, 0.14816266094003955, 0.25611230953326153, 2.5296686589717865, 92.53738864775627, 73.92163938091647, 65.35640278170186, 55.47781544346964, 52.93768067513743, 75.42179692176082, 31.941641069227654, 21.512915818921982, 75.04613584087741, 82.98075337563792, 59.17465717561784, 82.55236779489826, 87.72393441969349, 88.4473999084965, 85.62457207710513, 69.03580957843413, 36.75785272352157, 11.848663456978338, 14.419231895477543, 33.113990445290845, 53.16835526497134, 57.760532902133086, 58.71644589208788, 55.36301551326629, 41.03921390348866, 27.242614146201845, 21.68102272095219, 19.401092106296172, 24.712701074538696, 21.611449680020733, 23.41415532173649, 20.188517724314046, 18.670331008972664, 19.526298084566672, 45.69127436607115, 55.88669899971255, 34.52776955020043, 35.72994462905392, 39.78318468216927, 42.72526825627973, 48.65497019983108, 32.985983894717315, 23.049453343114546, 21.74943474031264, 46.972999034389375, 67.31121401632986, 68.71186887064289, 68.2262166853874, 63.71414169188469, 56.02950073057606, 53.78665024234403, 54.01113925441619, 53.13175170652328, 51.075041217188684, 51.18191403727378, 51.422794634296054, 51.75534494461552, 50.90018979964718, 50.50454816510601, 59.65051912492322, 61.2824918377784, 64.7866863589133, 61.2402989018348, 63.20224492780624, 56.806337910313765, 59.74804885925786, 66.91918096234723, 65.99393306239959, 65.7919035419341, 63.908926594641905, 58.88257395836615, 54.85262886170418, 54.73245136199459, 53.79685232716223, 52.59752881142401, 54.15798102655719, 51.65318289110738, 49.973059162016845, 49.076075861530924, 48.048693364666356, 50.75456788462978, 53.787089547803326, 54.823579788208015, 58.99525973104662, 61.80933283221338, 64.8888405676811, 70.10293745225476, 59.899821050705455, 36.07093980235439, 16.526755709801954, 10.65590795009367, 12.29006346194975, 8.157589570168527, 6.267813194182612, 7.928335858929542, 11.408410745282328, 17.052855376274355, 26.699820872276064, 24.19505607697272, 17.054157603171564, 14.419982048772997, 8.365235924720764, 8.409125285763896, 10.778907595142242, 9.250468784762967, 11.826353996030747, 8.653330091507204, 11.892649896683233, 13.217400024014136, 30.081190293835057, 32.89494372183277, 28.313342755840672, 28.48956111938723, 36.27446766822569, 16.096477585454142, 1.9637434521029073, 9.554191635501, 57.247545719146736, 48.05736572511735, 54.74805455054007, 74.38271399467223, 64.26939633584792, 59.76624865685741, 86.01628349673364, 36.110328243624785, 18.541173242753555, 54.44791086258427, 49.476494942941976, 50.14447066091722, 52.52840880424746, 62.342045614796305, 54.506240429416785, 65.04187183995401, 11.595243042515172, 0.8664296915934933, 0.17574360353812096, 0.1393662861758663, 0.2470474515951449, 0.16744631973485793, 0.10645433689557737, 0.24368115400354712, 0.19845435666220806, 0.16771324008943575, 0.07592200992568847, 0.14106212904857052, 0.14409159310162067, 0.14702353416190994, 0.150647773557613, 0.2038148117642249, 0.12327420329975507, 0.15270482688661546, 0.1452399895436341], [0.03627513272447452, 0.06067709771976356, 0.0869508491708867, 0.020710581823462443, 0.056467364136610305, 0.01611827733746219, 0.02720145136869002, 0.06991755833188373, 0.07139285981294609, 0.010427550239969167, 0.0817481315724792, 0.07923407615312646, 0.013681391869942027, 0.046725211695076964, 0.013819656376126073, 0.04651477883359598, 0.028705724379828865, 0.08538667382972856, 0.06591523922378979, 0.005279077891065109, 0.03504512110544789, 0.05186470405709359, 0.09931961450004771, 0.08981453179712258, 17.363895408568844, 69.43491074346727, 35.38681568637971, 44.97910530336442, 53.03469265660932, 41.34719840941891, 41.36242505042784, 11.947264978962561, 40.98531661495086, 80.43640598174065, 67.6615365859001, 80.095748132275, 63.05450885526596, 76.72198418648013, 72.55894522513114, 62.82192014878797, 31.650916953240674, 5.129661002466756, 8.054794544173825, 26.00102120830167, 41.160219023304606, 41.85415298708024, 40.28708765583654, 37.840697534622684, 27.999774755970126, 13.385212748281418, 8.47704210589009, 10.335827835144537, 10.954720973968508, 10.646052995035726, 11.110284136187646, 8.800563120072889, 9.817106146966259, 16.650822239537394, 33.851235220509196, 22.662048685935236, 18.74950601208595, 20.78487684649806, 24.748628024132024, 23.705091245712776, 17.75598925928916, 12.019057100819005, 8.986234395734726, 26.477685282307288, 46.50002787190099, 55.46112183601626, 59.50818023374004, 63.504259586334236, 61.8698432368617, 54.270804082193685, 51.75825534328338, 47.43864713176605, 49.50996452762235, 44.392769798155754, 43.46376818995322, 42.32899119777065, 45.36656487372614, 45.0838129751144, 52.54647131889097, 60.26870819830126, 57.77131549773678, 61.83029790078441, 60.100069815112704, 58.182725060370664, 53.36876092418548, 62.63859248930409, 65.21328726122456, 59.69568129508727, 61.98344292179231, 53.81100031637377, 53.29664422619728, 50.829363561445675, 50.0020533223306, 44.78798389434815, 46.55699245391354, 45.970452985455914, 45.06973166619578, 39.69728869776572, 43.5125389406758, 42.49828853914815, 45.19482781810146, 46.77910843203145, 52.06941304668304, 55.86623991689375, 60.93247521308161, 62.34114739202685, 65.84110183100547, 55.26057104910574, 30.374554164948005, 16.633697171365064, 7.432647308995647, 4.814637312966009, 5.024749857764091, 2.361514933647648, 1.2229176754913023, 4.351690748045522, 7.18109590391959, 13.514980443062322, 10.413092643983903, 7.77462846809818, 5.0656327220701405, 2.84320552502909, 2.3579490088647415, 1.1520927856045386, 3.181783292562731, 3.5106799150666887, 4.2426008082205255, 4.012226279704802, 4.612672021312099, 9.868770626283462, 21.25620649706933, 20.603759442606282, 13.9852814520559, 14.002170197425352, 6.384128630161286, 0.879090550926424, 2.803262313527446, 38.85321424853417, 38.59540470184819, 65.21445220516574, 60.40976839680826, 42.182341621768096, 66.09744441124701, 69.20265151608375, 13.48968311663597, 33.05203268604894, 53.67596095608127, 36.56296191676971, 43.41069852152179, 41.54947503920525, 35.747206980182284, 24.278451550391413, 17.202687955671742, 0.7640479240686663, 0.07830288095940506, 0.03397111180088213, 0.04034850265710585, 0.04543492427816795, 0.012488459864060485, 0.034056408030371514, 0.0706610773059149, 0.06801026753119885, 0.06604084699985481, 0.02880532730130419, 0.040957737909329515, 0.08013959974050522, 0.013267903573690884, 0.04738822631958512, 0.018464119000841054, 0.11535122239541624, 0.16005752427924066, 0.01330320873568135, 0.026027048156867107, 0.06258618499663088, 0.040913955984456886, 0.009834588610477025, 0.19545647075339673, 0.1172076985840836, 0.1118563446066072, 0.04390764373144315, 0.02291290840554622, 0.059271184652442896, 0.06470831366436136, 0.020016197813674808, 0.09006252211909141, 0.05116192180843604, 0.006546234719515328, 0.034600690517935066, 0.08375414812396612, 0.02938977194829814, 0.11821561748342169, 0.12785209192624017, 0.03363348536133286, 0.031983318565894044, 0.0988970404010146, 0.018737531950577133, 24.605575261577485, 87.14318044724004, 41.74875105580976, 43.39343224802325, 46.53416818188083, 41.23385760091966, 33.00421507127824, 24.214969950337565, 57.015427697089414, 81.5974118632655, 67.99873490487376, 81.12456229425247, 73.29178517864597, 79.6983257416756, 78.9121650880383, 67.46144079392957, 36.30436789604926, 6.265801508580485, 9.843646864737234, 27.79133216027291, 42.73835328317458, 44.13482689088391, 42.85250209992932, 39.95374894911244, 31.501341289089574, 15.882443651076287, 8.78035310776003, 13.157773133247131, 12.5977792855232, 11.498137904751687, 13.513319319294347, 13.005283148058, 13.402747704136758, 20.20664299688032, 38.59802484512329, 24.105159274993408, 16.902773726371027, 20.354726199180853, 25.069774043175485, 27.714836135987316, 20.4554703158717, 15.481568594132701, 13.5233498004175, 27.379616652765584, 46.717091837236964, 59.74336947164228, 62.626582191836455, 65.54170339338242, 61.63397935128982, 56.92536615556287, 53.59283024264921, 50.386618183505156, 52.698929925118726, 46.965852475935414, 47.469276920441665, 46.12160152004611, 49.789131379896595, 50.05134182591593, 54.56013771795458, 64.140424882212, 61.240726440183586, 63.03923514581496, 63.208936491320216, 62.72839515439926, 53.827737069899044, 63.032229792687204, 66.5675247869184, 62.74374338888354, 63.582048031591604, 59.13065994939497, 57.331680559342914, 52.90954551389141, 53.33240839742845, 50.18868753986974, 50.45191780213387, 50.466599233688854, 49.77670923356087, 44.13366194694273, 46.5886499035743, 46.6651165100836, 49.61492323106336, 51.3276614681367, 53.922705496511156, 57.246686720079, 63.97864280208465, 67.97491042844712, 68.67596349408551, 60.017880470521995, 34.917253063571074, 18.329092648721513, 9.439951623639754, 6.3826013572754405, 6.015572922845041, 2.7425040641138634, 2.0943355800644046, 3.027026422562138, 6.106024740203735, 13.577755035892611, 10.11073281688075, 6.863742816832758, 5.298285167063437, 2.789635018956277, 2.870552289870478, 3.3016685756944844, 4.369052139020735, 6.109091053085943, 4.680065695316562, 3.7806196366586997, 3.4322214799542583, 11.286244603895373, 19.958045136544015, 21.196031455070745, 15.683789330144084, 13.87428229854953, 7.415839952807273, 1.3476175454355057, 2.848876291705716, 41.17655961744247, 44.59728217894032, 62.951162245965776, 63.52470297967235, 50.52675662502166, 70.54670656881025, 74.25880632092877, 23.708872410558886, 29.90864326876979, 43.73776928071053, 27.97089630557645, 39.619053102308705, 52.8497136792829, 43.521219145867136, 42.68825677133376, 32.85147209321299, 0.9301705970879525, 0.2974143311862023, 0.06779368681412551, 0.16165354589541114, 0.016667077828559185, 0.03322616024243255, 0.03372228644307583, 0.05599569146251006, 0.0503758313284526, 0.04118636535901216, 0.03293383641228561, 0.10931924526249209, 0.04469028681576733, 0.03639808217544229, 0.005343085015943695, 0.02639110079936443, 0.044299141473827824, 0.03708822780378884, 0.03395507375018732, 0.09302968024125985, 0.20489787622805566, 0.098695122606812, 0.08285933444576879, 0.24828175713698714, 0.2444224053573224, 0.15469478623520944, 0.15012619025524587, 0.19290363596331692, 0.16629479765411348, 0.20835138526895355, 0.17405206607955118, 0.17058809227760763, 0.16810497148863732, 0.11866332692725044, 0.1277011496225192, 0.16658096213734921, 0.10222218374932006, 0.2209706153840788, 0.28930924352138276, 0.13470565239267965, 0.2216717543741388, 0.18043143344261955, 0.15465985262586227, 38.876399378622736, 105.33138352055704, 54.59172064258207, 65.74670214806834, 68.60270930874732, 58.425594299070305, 51.96199109477382, 19.15925641213694, 51.241228119019546, 90.5087152604134, 73.51492881774902, 90.34199099386893, 75.76316079785748, 88.03131488061722, 83.80430990649809, 71.93813600847798, 37.901521728884795, 7.639764633870895, 11.637988052060528, 32.31843963746102, 47.29328409318001, 51.81936979293824, 46.429809601076194, 45.087727500546364, 34.7046802120824, 23.8041389373041, 13.955473399931385, 18.942667053591823, 19.236848738885698, 20.50169740953753, 19.151221436838952, 17.670903244326194, 16.358119287798484, 25.666444993788197, 47.11090564727784, 31.73334360122681, 22.04463428066623, 25.205193873374697, 31.203005813783218, 33.58721263947026, 22.305726851186446, 15.803140190339859, 15.742694504799383, 32.58976174939063, 52.09182154747748, 62.90081470243393, 66.18936907860541, 68.4004875921434, 65.29779864895728, 57.77304526298278, 53.895786270018554, 52.29252922919489, 54.39981083716116, 50.772300920178814, 48.714645139632694, 49.20077977641937, 51.60051330443352, 52.60795054897186, 59.06462684754403, 67.52768178139964, 63.812436288402935, 64.88651067979875, 63.080616151132894, 63.28529327146469, 56.25609997780093, 63.29305956440588, 64.37188394608037, 62.022548952410304, 62.94371758737872, 56.41113165886172, 58.06107667184646, 55.86003080491097, 56.322501782448064, 52.800731120571015, 53.14125953182098, 54.131277530424065, 51.88542642901021, 46.2870902399863, 48.33953711294359, 48.94403319205008, 51.18943322089411, 53.20050301090364, 54.7097251492162, 58.23018573945569, 65.06631605086788, 67.87241105110415, 67.45751057901691, 61.95886927266275, 39.85214779453893, 20.963509428885676, 12.476438803057517, 9.461959062084075, 10.803717567074685, 8.740168425344653, 7.59623367940226, 9.90328356142967, 12.890826425244732, 19.514299554209558, 17.274059403327204, 17.836097786503455, 14.816029648627005, 10.72588401456033, 8.7476356375602, 6.191062706132089, 8.890351076279918, 10.000847616503316, 8.990034191839158, 9.447287436454527, 10.50408967079655, 21.311231467031664, 29.339062167752175, 24.48751780294603, 17.300541285545595, 18.059506185593143, 10.31858705705212, 1.9393861462031643, 4.806711673736572, 46.81851648515271, 44.829235461450395, 69.44150032535677, 68.35767884408274, 49.87788284978559, 76.62735308370283, 81.17621990942186, 18.377686892786336, 42.42216317884384, 69.15024080584126, 48.330060666607274, 58.25414749883837, 58.80203985398816, 60.54980877907046, 58.09198494880431, 57.01962855554397, 1.7954580822298605, 0.4528354607041805, 0.2836162909384697, 0.2675063199093265, 0.10656275365862156, 0.06680826791712353, 0.1118647026258611, 0.18510901309069128, 0.1695114935958578, 0.11735259645408201, 0.06398813738938301, 0.15963461310152086, 0.16766428707107423, 0.1287023575916406, 0.123561478610481, 0.1507694742852642, 0.21444313258173006, 0.32309828686618036, 0.1321778839994823], [0.08393109911271641, 0.05862319301212988, 0.06417008710183925, 0.02129145841594906, 0.034908776607124076, 0.11037865293122108, 0.03701902325114897, 0.020931826100774834, 0.049535995950141264, 0.082140437537624, 0.04754738491629401, 0.03543699040047584, 0.007579558530837418, 0.04322363829780971, 0.03889695756257542, 0.04049933004763819, 0.04679095353029909, 0.030239399845501592, 0.09597989249854319, 0.048202738661559365, 0.04958370024518621, 0.07100538786260352, 0.1529016655178801, 0.06671506566025558, 2.897350903480284, 55.34171312086044, 53.94418439557476, 54.36583918909873, 72.74170414094003, 40.68652222233434, 40.26794648939564, 24.4171759774608, 9.76916301635004, 66.21955563945156, 71.99637536079653, 79.11022124751922, 75.35907822270548, 79.46590961948519, 77.28986494002804, 69.19771717440698, 31.12624110714082, 1.7029434658827323, 5.194901295246617, 20.18937868456687, 34.954892127744614, 31.202307631892545, 28.331942635197795, 29.026970940251505, 22.76455394683346, 17.86886722810807, 11.088911141118697, 7.353439456032169, 6.635371148586274, 6.211647795092675, 6.645101568391246, 6.555312631591675, 9.531556617829109, 23.977427290331935, 27.15547869282384, 11.704281010935384, 7.163219701859259, 6.311021533704573, 8.838361040238413, 10.308461458452287, 6.921465396881104, 6.465538403680248, 13.864572471187962, 36.08375810807751, 42.53100110638527, 52.237878845584014, 60.22509144198511, 62.98313348524032, 66.40280092916181, 58.72017606612175, 56.12104100565757, 50.962951644774414, 50.288833495109316, 45.5791102686236, 46.730408283971975, 45.44386302271197, 44.93694374638219, 49.241682252576275, 58.11926895572294, 61.0161550583378, 60.15165682761901, 62.158972909373624, 59.28440509303924, 57.27792447613132, 54.631909247367616, 58.119076759584495, 64.66856810354417, 61.82584208826866, 60.757568882357695, 53.29984095788772, 53.2269044845335, 48.62796860356485, 48.71167590541225, 45.97430475296513, 49.851045993066606, 43.97508444324617, 43.16964141784176, 41.946085499178984, 43.664628844107355, 46.98266375449396, 46.985480016277684, 49.00765011387487, 52.2546979688829, 54.9364616793971, 59.783471784284046, 62.354758016524784, 64.07599602976154, 57.041935074713926, 26.606546909578388, 19.223853926504813, 9.555746855274323, 3.481089064190465, 2.526357933398216, 2.5324010800930763, 2.203601045954612, 1.6189247033288403, 4.710210580979624, 5.712186905645556, 12.371210436667166, 3.7917959401684427, 5.683716381749799, 5.167704070768049, 3.7796770420766648, 5.825712065542898, 3.9656062135773325, 2.9191791386373582, 3.4234841552472886, 3.569221780184777, 2.325637503977745, 2.7804118106442117, 12.524786918394028, 11.510566915235213, 9.553702319822005, 3.6847873080161313, 1.2446218656916774, 0.5365623437589215, 2.2120677271196922, 32.65918377907046, 43.08202743530274, 73.78223050025203, 52.304610129325624, 49.30773104390791, 81.97809357796946, 48.1465486557253, 19.95405020252351, 70.49068727800923, 44.56034521902762, 42.36419839243735, 40.336756629328576, 51.42166499168643, 35.130582932502996, 25.76908361527228, 11.578591600541147, 1.2789383146070665, 0.24025871748885802, 0.1657422950431224, 0.02115003666990707, 0.008730603243044067, 0.17657367512583735, 0.06959400875794311, 0.06929837542796327, 0.034047057927255674, 0.02004578412931052, 0.05913199796792, 0.07638988280368429, 0.034553736989055915, 0.046098524959938186, 0.015414723255220922, 0.031050392013463764, 0.1002901636304394, 0.07190046967157433, 0.05657966113499096, 0.04652126759831463, 0.03905630002038614, 0.0491743526541658, 0.01744729049894358, 0.10882019260597807, 0.07563388425736658, 0.0756189608646016, 0.06224696892463873, 0.040327400765231544, 0.04233249035033007, 0.03479821479789192, 0.06379652347776198, 0.008661211956472648, 0.06794259898484716, 0.016977194050747543, 0.05621385032070741, 0.03845892763966995, 0.0351898389447841, 0.03740921864406236, 0.04196376074105502, 0.06485062981805494, 0.06550000424707128, 0.01996293938117883, 0.049623261025596055, 4.733905619190586, 73.0893438093124, 63.563114750769834, 55.79736701903805, 72.46384343793316, 33.247276506116314, 37.48324409607918, 24.984486026148645, 28.613007914635446, 78.19741510575818, 78.120450358237, 84.81763855103524, 76.22543565688595, 83.5659396263861, 79.55624180455362, 72.79559750710764, 34.192504959721724, 2.036543868241772, 6.485990132054975, 20.958820235344675, 37.64962711641866, 35.08247898470971, 31.22872087263292, 32.531310589082786, 25.319495662566155, 17.23311770346857, 10.50304239796054, 8.257518814456079, 6.578921377658845, 8.628587780460235, 7.578196169868593, 9.0488766085717, 14.565500020980837, 25.589246865241762, 32.967493841725016, 12.411889337724256, 7.271652644680393, 7.155093531454764, 10.37152728726787, 11.354491883708585, 7.277560714752444, 9.795466430725591, 14.817097513906418, 38.35177060096495, 46.58639846309539, 57.35843504628828, 62.99562231186898, 65.02582542357906, 66.90917107366747, 62.82243005691036, 58.980515541568884, 53.27913476574806, 53.20643755697435, 48.438753466452326, 51.18877034033499, 49.48876411684098, 48.90293851975472, 53.07593245660105, 62.07182961125528, 64.03069265427129, 64.03527398263255, 67.15944182488226, 62.69948336385912, 58.93914630336147, 56.826714623358946, 61.87766444298529, 67.14882004645564, 65.55141518192907, 63.63631010055543, 57.16785492435579, 56.50819463114585, 52.56540852208292, 54.258197584459865, 49.700450512670706, 55.08499791545253, 51.490024059049546, 48.40289515833701, 45.66729299483761, 45.9346809694844, 48.38298128497217, 49.06413224435622, 50.35368204116822, 55.172870774422925, 59.283702988778394, 63.75681707935949, 63.49757978993078, 66.4120969464702, 58.68646721686087, 30.066279403625, 21.767677683984083, 10.688339087270922, 5.964057003298114, 3.549867334865755, 3.205110608570038, 2.7206537656245695, 1.1532808960445466, 3.5682340783457605, 5.648081158438037, 12.55708763676305, 5.021610490737423, 6.881442512235334, 6.09529362570855, 6.311829051663799, 5.962432161454232, 6.1931332272868005, 5.114763350256029, 4.35152453760947, 4.776899699241885, 3.057109776043123, 1.4525144715462963, 10.158324895366546, 9.679704539237484, 11.112348283490828, 3.528150151814184, 2.0289092198494942, 1.4265869918369478, 3.1467131357039175, 35.64144026848578, 46.52216965152372, 71.59672506393926, 56.33281369363108, 53.253976683462824, 80.75283142828172, 56.512336654047814, 23.419936895370487, 53.54916641789099, 39.78753459069037, 29.3640378598244, 44.26812079644973, 58.55705253539547, 47.33335110449022, 44.23376475611041, 19.593476518507927, 1.792334649832018, 0.19831946390050076, 0.11333965936735754, 0.09833270939247263, 0.05459204984588489, 0.260015542829229, 0.05559637962329773, 0.0871131755411625, 0.04530192375363362, 0.11479734082616146, 0.015426732641043923, 0.05519792580256059, 0.07866890244786778, 0.021093857527199774, 0.08634144920975932, 0.07888212003895352, 0.04243019337375318, 0.020221528529580084, 0.02205393998132598, 0.13340593826386238, 0.13432296083098458, 0.19203745099084993, 0.09223076544942395, 0.2210911669798436, 0.1435413274673685, 0.19779029632768325, 0.13071615759643818, 0.1297659787439531, 0.19179012716537525, 0.14496703241621295, 0.17171396573464717, 0.1780085424862562, 0.10826588202748569, 0.10156737009604132, 0.16290870435055227, 0.1456541519972586, 0.13041329239645313, 0.1391539725685312, 0.15578784048557281, 0.18846435562497188, 0.13610241453974478, 0.3000252201191841, 0.293236731161033, 7.78480064484381, 92.59227045120733, 81.2137883709323, 75.69450363036125, 89.53937207498859, 54.306227007219874, 54.61732195269678, 32.6298640620324, 16.821816006014426, 80.28486128776305, 85.41226202441801, 93.55321191972303, 84.17680171228226, 93.01725141463741, 85.84987301980296, 79.88892939782913, 36.345945019875806, 3.347251420059512, 7.032057604482097, 24.31964820431125, 41.39488658597393, 39.26557694711993, 35.11198305314587, 37.39324923484556, 29.576553836945568, 24.144696766330352, 18.132109257482714, 14.253479396143268, 14.248476412988479, 16.585053897673085, 15.627425851360446, 16.009189159639423, 18.042396806901504, 33.10501606233659, 40.32578575995661, 18.71844672387646, 10.957501934420678, 11.662924520431027, 17.642407225024318, 15.070912126571903, 9.333914268401362, 11.452254999068476, 19.826861466130904, 42.21900401576873, 49.2180460499179, 58.88019307967156, 63.997532936834524, 68.40797147443219, 70.1113627033849, 65.87481068026635, 61.0542961858934, 55.00367149229973, 55.61321566181799, 49.90417057468046, 53.74566147404333, 52.074590575310495, 50.454941949536725, 57.164112983211396, 66.20301108206472, 65.36402786931684, 63.98260047358852, 68.52493655297064, 62.91622569484096, 59.73050409747709, 55.42773069873933, 58.40542154927408, 67.38427208315942, 64.33584128656696, 63.56913166661417, 56.75858305346582, 57.53330607568064, 54.26484207953177, 56.108297224967714, 51.65262591454291, 57.77714413981284, 54.8922840241463, 50.948211377666844, 50.355454952486106, 49.61499383372646, 52.43729606751473, 52.46626277123728, 53.59759984477874, 56.909260903635335, 59.30546037612423, 63.79987685911117, 61.58385538285779, 64.76086931843912, 58.45748316857123, 32.526582171840055, 22.96606375325111, 15.865691208070325, 9.928173941950645, 7.38251990848972, 9.322754144668579, 8.908964683932643, 9.1519231565537, 10.504264216269217, 11.505676700222878, 20.38430675383537, 13.698449307872405, 14.450105851696385, 15.036323685799877, 11.61817321854253, 12.407918918517328, 9.730582583335138, 8.04676398154228, 5.921789542321236, 6.501706088742902, 4.0074449104647485, 11.444492628497462, 17.65624926936242, 13.700499726879983, 12.972312684982056, 4.657779768590005, 2.6282586589936288, 2.3323454924168128, 3.8307340443134312, 40.98891735076904, 48.66017910741991, 82.88849922918504, 60.22296943972188, 58.841487130811146, 89.25870295493834, 57.27195855109923, 29.15284960500656, 82.84077967366865, 54.58864550436697, 55.57697296142579, 56.839391723755874, 67.71600261811288, 60.08932252084056, 62.21224261868385, 28.370836857826482, 1.9819519524612736, 0.3303417401208032, 0.23746608185671994, 0.3240815147517189, 0.19527406521862556, 0.3585523763491262, 0.15769049645431582, 0.2098761147428905, 0.19648593970604483, 0.2870750246990112, 0.16628421031899993, 0.3036228302986391, 0.17175040087632595, 0.08996063242516211, 0.28341857896697137, 0.1429766134148644, 0.3250302993241818, 0.15206800863867806, 0.14646733900712383], [0.011890520578280333, 0.07884406845175451, 0.06706831646302054, 0.0910611330501495, 0.02468540029029452, 0.08169050643881483, 0.04613451194018126, 0.04067415514239862, 0.04098802902585557, 0.03716055033428054, 0.06803765517449187, 0.032269370051160935, 0.027030240293712388, 0.05385216978949405, 0.08597532046898719, 0.10262635641641195, 0.056958123891344, 0.06860784675565458, 0.0409964828061, 0.06363644174510433, 0.08715423785390393, 0.0138409411714923, 0.03882828544104292, 0.09134719028107582, 0.046597619751288046, 31.003739603104133, 68.27665052106305, 34.667715795578495, 59.369967675978145, 75.33154318409582, 33.63745427900745, 54.83573521337202, 17.14045955288795, 22.69642237694033, 69.0837017182381, 74.39278664127474, 82.75895118713379, 74.03021058728619, 77.16223101462089, 69.7068408227736, 40.23327273707236, 2.211072670836603, 0.6482221714911923, 11.838789870662074, 20.662612645856797, 18.473659446162564, 21.744886752097838, 22.05813115642917, 16.416376290782807, 9.119992121573418, 3.8552265494100513, 5.210563319344675, 1.529786144533465, 1.9212508225633254, 4.540438142514998, 4.308701570956938, 11.089621090119886, 30.4258587668019, 21.49821085314597, 4.768785786244178, 1.7827125855030554, 2.6715684898437995, 1.3018480207650893, 2.356049110812526, 1.7371136839351349, 6.2398197285590635, 17.70648894771453, 32.10054020727835, 41.68024293838009, 39.42865340940414, 45.20674005631478, 63.06276152210852, 62.11455598954232, 65.34419244335544, 60.34777925860498, 54.67488665734568, 48.77849348129765, 47.34117623298399, 46.92694256382604, 45.21747558347641, 43.73304674702306, 51.64979788564867, 58.18462348753407, 59.55466424265216, 60.41739348442324, 60.431619921038234, 58.21140543107064, 58.01604001752792, 53.96065050555814, 61.31670667279152, 64.70818796465474, 63.33599775068222, 59.38889311205957, 52.60680521688154, 50.801499043741536, 49.01134498657719, 49.17778292009908, 47.19910406297254, 48.5908551369944, 44.44203868989022, 41.460162670381614, 41.98443843472389, 44.38205388284499, 47.577279383136386, 49.281866934991655, 52.00123440834784, 55.70346547711281, 60.86883083466561, 57.878541331137384, 59.909270040450565, 64.85480223932575, 49.64621197792792, 27.480248981906524, 15.012281517828665, 10.050109644089977, 1.7226200358521555, 1.9030922098505882, 2.4164974929824954, 4.4358501030552775, 1.1766333397357696, 4.093324224795065, 4.352836080135838, 7.268638303202968, 5.8804595278155425, 1.2587822348840776, 7.708415917811855, 4.614333145080074, 8.395819625546856, 5.390442234854545, 5.962500802932247, 4.231441174784015, 3.9907500772706928, 5.254926306586112, 1.4992144559660268, 3.25412332050262, 6.045115234390383, 5.343874385279994, 1.3998692771119456, 1.3793373852968218, 0.3989994898438454, 0.554606594866322, 30.74408458125207, 49.68573377978418, 71.06825628588277, 58.54968240184169, 49.886614045789166, 87.2039536506899, 26.36116147041321, 51.14206667869322, 66.46153450012207, 38.29173480310748, 42.36112717659243, 57.01580816699613, 77.9312744448262, 38.534996278824345, 30.21845167683017, 10.464007950598194, 0.9295854897749041, 0.08343727117584598, 0.07741722969278213, 0.031023870049525174, 0.08572565241446418, 0.06711642678466535, 0.010568915487026737, 0.024895402227318095, 0.03314533796642096, 0.10825107354790935, 0.01295673015016702, 0.014993376812086472, 0.01629558838753691, 0.011436208414154188, 0.03313510303175257, 0.048668715471942584, 0.006071123268244969, 0.027035909344352065, 0.05655363712820315, 0.03372731581029873, 0.04430338943136796, 0.07113435110377689, 0.028544570124077222, 0.0640716984297239, 0.03608726881324284, 0.0286405130604943, 0.06570625043804608, 0.04897716928333525, 0.03938906946249547, 0.06283715157018555, 0.08747797128894637, 0.03425217030810253, 0.03188886375526988, 0.07903853987133311, 0.053172067573834816, 0.03576564595043179, 0.053835855947146495, 0.08020912221963368, 0.014045248202408754, 0.08015825398146145, 0.044254114656078244, 0.043019445222471996, 0.1146401395840991, 0.22008391457699963, 42.09381372697892, 88.53116604589647, 37.434818513931766, 70.55173504737117, 60.15865825837659, 30.53386711305188, 48.625968194776966, 22.329102216228364, 41.15172709188154, 70.65519932777651, 84.845244192308, 83.70807847669049, 84.83995683731573, 85.62076737803798, 74.22830597046884, 45.036556259278335, 2.5979147130443208, 0.9432105167258171, 15.229107199176667, 22.576348820040305, 20.40727419237937, 23.495685708138254, 21.441671848297123, 17.248587531428186, 10.207930130343284, 4.988912632388454, 4.4502702066975255, 3.000400148091778, 2.3667954244921288, 5.348699390888215, 7.838602815904926, 15.522396545256338, 32.92941939446234, 24.878852675038, 5.704063677018689, 0.4757264130298169, 0.3920756791147494, 1.1319821808607349, 3.6307127773761754, 3.6982898221861933, 10.806722102626678, 21.903795696073963, 35.88281508414976, 44.060415606344904, 44.34559937446348, 53.498967924425685, 66.08670496171521, 66.57319653418757, 65.3663420677185, 64.09723566424462, 56.57352562873595, 50.92430453146658, 49.914910024212254, 49.73479870826968, 50.671193984247026, 48.582218077874955, 56.25638238845333, 63.26987835668749, 62.596760411416334, 63.864035068019746, 61.87297721062938, 62.265135780457534, 60.171539322022475, 58.37524283316828, 61.27905584150746, 67.1857060155561, 65.90386759850287, 61.19777256442655, 55.48588375891409, 54.494865555917066, 53.27383172127509, 51.59442970829626, 52.94368974624142, 52.06196446572581, 51.861707856578214, 48.74914238529821, 46.863427623625725, 48.98637125569005, 50.51660945338588, 51.85116060318486, 55.0221654676622, 56.62042148651616, 59.3842411810352, 61.90444638652187, 64.96154169882497, 66.77895622868692, 53.898712358167096, 28.40272572732741, 18.117767110947643, 12.50908959296442, 4.849152699593575, 3.7837062968361765, 3.8756826904512223, 2.138937831886353, 2.6409109994288418, 2.901205122470856, 4.457261831529679, 6.99082221715681, 7.563004830191213, 5.459177359457939, 9.503088055118438, 6.218273168609989, 10.768464284558451, 8.077480062361687, 7.699941146758295, 6.77440103023283, 5.7427882571374225, 5.886910846156459, 1.4843791939558522, 2.3951382262091485, 4.944844313206212, 5.51947791730204, 0.3483799850988773, 1.7809172431307456, 1.0194191661092544, 0.6399058274203732, 33.192414314516135, 52.70375836280085, 71.4170491310858, 62.50232934951783, 51.63390836408062, 87.55429975448116, 35.83437773489183, 39.23850474819061, 67.3545640514743, 32.05703719969719, 34.75243114656018, 60.097073124301055, 80.9592971494121, 54.721107867456254, 45.50495001577562, 13.177122185307166, 1.1857706236262475, 0.08042959466336236, 0.11088732765206408, 0.05332882831534071, 0.010490455634651646, 0.07437707105230901, 0.02654610145386429, 0.04964373472537245, 0.05060779509104548, 0.053535472872036124, 0.03526639411105745, 0.03837888677334113, 0.03661910620247645, 0.05638250457723776, 0.07709501311182976, 0.05465579985250389, 0.1071993344193024, 0.052514974808981346, 0.01807936283219005, 0.09424176923329793, 0.14562527048251322, 0.19354774736829344, 0.18780191939684654, 0.18066962550003685, 0.1876503565619069, 0.14952183881353948, 0.15548279959588282, 0.19392423361780184, 0.14846103686478831, 0.14956584290391015, 0.2039412928805236, 0.10547444149250947, 0.16067505243324465, 0.12273709905604202, 0.21146490448905578, 0.19276089846126496, 0.14184275732165383, 0.1344118576737181, 0.21162279521025, 0.22226711194361412, 0.29216215495140324, 0.1329152742701192, 0.18455148494291693, 0.4610426525675482, 58.13114981497488, 101.41335933439194, 54.49275139839419, 78.59031892591908, 93.72785937401557, 46.53208540331933, 74.62195504096248, 23.719121563819147, 30.13585440574154, 76.90892434889271, 88.8902041219896, 94.5567346388294, 86.96481458602413, 87.36844216623615, 78.9245911567442, 50.8059391667766, 2.4844554979955, 1.5712991621225112, 16.348263352147995, 26.0570954122851, 24.59271380978246, 27.011429648245535, 27.88592403934848, 23.736136805626657, 16.90290120340163, 10.464676714712574, 11.981148373696113, 9.7490991123261, 9.718819395188364, 13.333001098325177, 15.479807449925332, 23.516517416123424, 40.30845672853532, 32.44562837385362, 9.776164447107623, 5.807071491595238, 4.4147134307892095, 6.217135681260017, 6.804495415379924, 5.072863611482806, 12.232267337460673, 25.429486766938243, 39.34123946774391, 46.904926300048835, 46.34314875448904, 50.022198615535615, 67.64722777951148, 65.69162814847886, 67.85912990570068, 65.28883603311354, 59.234692973475305, 52.38885087351645, 50.997876428788715, 51.50006532669068, 52.197678473687944, 48.33434389483545, 58.86205603999477, 65.31370386000603, 65.21124762873497, 64.7231831858235, 61.92519572473342, 62.36579948855985, 60.48792554486183, 56.07070522923624, 60.1577639579773, 70.29757330494543, 66.31399846846058, 62.58925299490652, 55.126641719572014, 54.27661703478906, 54.37797500241188, 53.325516793035696, 55.95392842446604, 56.31348817579208, 54.983643870199884, 53.24430411861789, 52.130072501397905, 51.95721364790394, 55.99707449636152, 56.92192623692175, 59.47430272256175, 60.241800738919174, 63.08692724474015, 63.64539823224468, 65.77659845352173, 66.28315294942549, 52.710987291028424, 30.066844224929813, 20.72854376608326, 15.641554228721128, 7.785168857343736, 8.20251541752969, 9.534750407741917, 11.672719659343844, 8.94195475885945, 10.62699027599827, 12.366804634371112, 13.298660747466549, 17.484694603950746, 10.727888345718386, 18.62356851177831, 10.02808161320225, 15.633161337144914, 10.902691714225277, 11.834262474890679, 9.049245311367898, 7.892443230075221, 7.297905068243704, 3.6302641562877165, 8.35573692475596, 8.845279120629835, 7.682252728169964, 1.689210022168775, 2.4299311205264065, 0.8346031510060834, 2.142220610572446, 37.50822174933649, 58.37989868656282, 77.14060306549072, 66.87055926169118, 59.72971177870228, 95.92747749820833, 35.49708135666386, 61.21152439425069, 72.45162917721656, 46.787780792482444, 61.88584650716474, 68.54687829171458, 85.75816016043387, 62.180612625614295, 62.199455691922104, 18.871179896016276, 1.1907353636718567, 0.14621785481370267, 0.21869783169559895, 0.19765227792724488, 0.19615587838474782, 0.1362281448898777, 0.15798550159219774, 0.10777497288560677, 0.17016600847484606, 0.164278760672577, 0.11403600264701153, 0.08602529238428801, 0.1054708868445408, 0.1395291717903268, 0.17176337840576328, 0.13684516742585168, 0.1581154607476727, 0.14951333523757998, 0.25329471475655035], [0.03571594599634409, 0.07819186715829758, 0.06899836007505655, 0.036112913606508125, 0.025341025996772994, 0.04752332592503198, 0.029877940410627957, 0.03383978134802273, 0.08266721491611774, 0.0747653320732136, 0.07312002802087415, 0.046994752070355805, 0.020163872752398736, 0.026931516458130172, 0.034057503536103234, 0.024259710128629403, 0.0444517461883445, 0.02227856270638445, 0.030013631818996325, 0.022756909921524987, 0.02524663821884221, 0.05870210006833077, 0.08046928567871933, 0.2805797329112407, 0.26351579855526647, 8.492550176958884, 64.3755905858932, 57.692413099350475, 38.69639788904498, 73.1607937043713, 58.369171004141535, 33.67101015583162, 55.04005539801813, 6.63458324247791, 48.46829675859021, 84.63826856305523, 72.91620254516602, 72.98373791479295, 67.04815633835332, 64.35233485314154, 50.21035863507179, 2.9290755237302477, 0.33845893197482635, 5.113241960925441, 5.092966739208468, 11.670000476221885, 12.613163801931567, 10.449478510887394, 7.904548645019532, 0.9077605028306285, 1.6660795601144915, 1.1440260636229669, 2.5530849637523776, 2.9955945091862834, 1.6359253588222689, 2.784948031748495, 15.33368347152587, 27.455210531911543, 15.09992785992161, 1.8089691765846747, 1.4241172469431356, 2.1244245719525123, 0.6911525743142252, 0.9970511147572149, 0.6101521368949645, 4.717631705345647, 15.580248563520371, 27.953455486605247, 32.662937487325365, 34.62893924405498, 23.64546141316814, 39.056769570996686, 63.50993525597357, 60.939096173932484, 66.76197236584079, 57.16381880544848, 49.52706606157365, 48.41820809148973, 47.853743722361905, 46.690168688374186, 46.51291678028722, 57.1602729828127, 59.00125703504009, 59.449587868105986, 62.48864812235679, 62.24173099763932, 61.953962387577185, 61.35822103869531, 52.48467829919631, 42.82155852163992, 67.64423893344018, 61.9560569332492, 62.938022305888516, 50.507321280817834, 50.20470257728331, 48.381883021323915, 49.51954295558315, 50.303934620272734, 46.8556103398723, 42.50089691531274, 40.688200996768096, 43.5504682602421, 46.740269122585175, 50.930611702703665, 52.61537951807822, 57.601472946905325, 63.72734831225488, 64.39802654327886, 66.3567836823002, 61.28898336041359, 59.297784297697014, 35.803132134099165, 23.701319886792092, 13.622143518540168, 7.4755629416435, 1.6190149178428035, 0.9337256127788175, 1.6357136734070319, 3.457884567399179, 1.1892171612670346, 1.2857792959097893, 5.260619136594958, 4.578459637780344, 3.64655057268758, 3.189697654977922, 6.870168639767555, 8.200099727799817, 8.533913531611043, 8.886067848051749, 7.170791347180644, 4.824860480523879, 6.276825820246051, 3.884603631111884, 3.8385537795482145, 0.6578324687096381, 0.23328230716288093, 1.0577670148303433, 0.35234078224147525, 0.2413295398676588, 1.773264698924557, 0.3144177752396753, 16.282224366741797, 55.21424393500052, 63.52542077341388, 77.91168612818565, 60.800228580351806, 71.15359921609202, 23.70955490296887, 54.43852463076192, 37.897207121695246, 42.443222384299006, 46.83507280965006, 71.2544668874433, 61.32530058583906, 40.92116625078263, 42.881135402187226, 2.7858425772959188, 0.30469765165640467, 0.12671877975545584, 0.06926275233948423, 0.017219561287352157, 0.05892040448323373, 0.046711510212551204, 0.11602291296566687, 0.025386081542819742, 0.0642306233696159, 0.04460990120987258, 0.09659306161225804, 0.0813675620743344, 0.02890154985981363, 0.031785874725169236, 0.07884645098519903, 0.0571102153269514, 0.03915978317719795, 0.1322028891093308, 0.043455517790730924, 0.034857724507850026, 0.10392644592831213, 0.046379978002439586, 0.03451995251159515, 0.05837495371158566, 0.06553999403671873, 0.019805106116578947, 0.06406136390362537, 0.0662508700042963, 0.09030408496337552, 0.0050691056399486, 0.07165405749072952, 0.053115997598656726, 0.02631530789057574, 0.054321390982236595, 0.028175377031607975, 0.07780430327740409, 0.012595178784742471, 0.05729643981002512, 0.04328787093982101, 0.07819379003898752, 0.0798774521136957, 0.07875304188459151, 0.23870826278242374, 0.32872161737853484, 13.267590672739091, 81.1302105073006, 66.73078167823054, 47.65655832905924, 80.85091421681066, 34.36093153492097, 37.111807407871375, 49.775865923973825, 17.75106864590799, 63.106409657386045, 88.08911492747646, 81.45141340071156, 77.03665241118401, 79.40783500671387, 73.91934871673584, 57.17014558853642, 2.480635109447664, 0.3932106230528124, 6.877490724286726, 6.43168148494536, 13.475573370533606, 13.133601527060232, 11.115355760820451, 6.809380237133273, 1.1564059219052716, 1.9162482071307398, 3.1375688650915703, 2.389643721042141, 2.4548518994162163, 5.0397563557471, 6.133194508091097, 17.0632202394547, 31.39983231021512, 20.506196368125178, 3.237419907123812, 0.7741976697598735, 2.4204505066717825, 3.811648281351213, 3.6150475663523522, 3.4295209280906187, 7.735096860316492, 19.5519954927506, 33.26127152289114, 39.233358598524525, 41.544470094865375, 31.27715037715051, 47.437203699542636, 67.34478950500488, 64.2949035090785, 71.66106762424593, 59.723890981366566, 51.753968192685036, 52.79314917902793, 52.68785315175211, 48.988807047567065, 50.39831076898883, 59.738725385358265, 63.97792500834312, 63.25064697573262, 65.01406615780246, 64.2106431530368, 63.782700800126605, 62.0603645232416, 53.952605724334724, 49.337701874394575, 70.99968541053035, 66.20929471908077, 64.72704672044324, 52.92627050030617, 52.8493881225586, 55.014430553682395, 54.02282399515952, 52.43933962237451, 53.162428563640965, 50.43123514421525, 48.406574341558645, 46.98712348937989, 49.84100472542548, 55.12466092263499, 55.560812796315844, 57.979554130185036, 66.23284462959536, 66.86213401056105, 65.7518796766958, 61.26187193778254, 60.56644747334143, 39.26625551715974, 26.768717304352794, 16.20909961961931, 10.33487371860012, 2.645162113251225, 4.020311265222488, 3.792757656305067, 6.217493597538241, 3.745559285725317, 1.323551598095125, 4.83874321945252, 3.558281799477916, 5.408513084534676, 6.555050813382672, 11.255757981731046, 8.078444475127805, 9.683556306746699, 11.152877153888827, 9.423032479901469, 8.204465325801603, 7.64854682068671, 6.677525841420697, 3.778995530259225, 0.6299406782754007, 0.2711057993433168, 1.2274694635022072, 0.5435943567464429, 1.6243569408693623, 3.7314152188839453, 0.9291422006583984, 15.141409866271482, 55.715201208668375, 66.75943851470947, 79.39923717129615, 59.90819531102335, 80.23634941347184, 28.12129370627865, 52.21473293919718, 39.8518261601848, 33.47082414934712, 49.639477268342056, 74.88362419989802, 70.06521994067778, 54.602330653898186, 57.00850079136511, 4.202364154400365, 0.2133703796613601, 0.055925268830070575, 0.06719477459668152, 0.012472687071309456, 0.0417296442713949, 0.04354108981187305, 0.1050549547278112, 0.05827280737820172, 0.016768479141436757, 0.08349146423560959, 0.03228707817353068, 0.023988225805242697, 0.05887783297728147, 0.01752347219735384, 0.07330658575219494, 0.019516532286821354, 0.04570353768705841, 0.06604922800174644, 0.016251637923320936, 0.10255036815520256, 0.2345959640919201, 0.13278488610540667, 0.09538252777870625, 0.12150654734502878, 0.26032629873483415, 0.08959458029318242, 0.21536796924567994, 0.23865865092844735, 0.16856031882907116, 0.22481337369930363, 0.14379352361204165, 0.1301181800062618, 0.10994474839178786, 0.12001746394220861, 0.18926257327679666, 0.20288026110539514, 0.13114145896848173, 0.1539119516289042, 0.10222914748855176, 0.17739294487382137, 0.15744043003407218, 0.22963565203451344, 0.5211366424637457, 0.4825142278305946, 19.56637097943214, 97.48669808910739, 82.71382039593112, 56.56664186908353, 92.7546722658219, 74.53826735096594, 45.70805034329815, 70.0994622322821, 10.22776653689723, 61.52149754185831, 96.38704592181791, 86.4179342023788, 83.52688066421017, 82.421658731276, 74.46787649585356, 62.20307996196132, 4.137432257975302, 1.0266992690101748, 9.010919832414197, 6.549468300034923, 17.29239256151261, 17.913254730163082, 15.819127771162218, 13.749336177302947, 5.0095075272744705, 7.0751526855653335, 6.930950178254036, 7.787146712503127, 9.011285593432765, 11.885267996018934, 12.799133177726501, 25.504260870718188, 38.35243348152407, 27.166804536696407, 5.531415650921484, 4.125442062654804, 3.9954841329205424, 5.028578581348543, 3.4418548210974667, 4.291224470061641, 10.613003103963791, 22.448330502356253, 36.679138598903535, 40.250774352781235, 44.729062049619614, 32.43166473604018, 46.947915477137414, 67.92666527532762, 68.61688475455009, 72.29216914023124, 62.63619984349897, 54.39013042757588, 54.40516879481655, 54.830765570363695, 52.76115440553235, 51.76822208589124, 62.52043893260341, 65.5884188221347, 64.36693783729308, 66.21894374970468, 65.74219926711052, 65.62698748803908, 63.2697920645437, 51.207072119559015, 47.422357528440415, 70.4345424713627, 65.91935311594318, 65.09881288774552, 53.52253352442096, 52.75417258662563, 55.235040341654134, 54.89829701762046, 55.0364899635315, 56.18900783600346, 52.00802403111612, 51.33491393058531, 50.55334637241979, 57.82636204073506, 61.43448368195565, 60.850238800048835, 62.7806999606471, 70.9735938041441, 72.65124644002607, 69.77975768427696, 66.66944365347585, 59.450054630156494, 37.80707889987577, 28.377875551100704, 18.970586484478368, 13.893847080969042, 6.868597240217271, 6.993132983484577, 9.008907656515799, 10.66766917705536, 11.800636975995957, 8.30771730792138, 11.75862446908028, 9.820472521166648, 15.234186668549816, 14.495691637839041, 19.501336120790054, 16.239623504300273, 12.374038465561407, 14.443783971571154, 11.47893201920294, 10.016207618098106, 8.73445745437376, 7.493973076343537, 6.227504957106806, 4.162719778476223, 1.8658832580812517, 2.515949188701568, 1.2044491955349523, 2.5678857824494763, 5.016026996797131, 2.5879972452117554, 19.921665153195782, 62.81149448886995, 72.23437693811232, 78.11703005144673, 69.48816868566698, 83.85753646973642, 33.53296625998713, 60.72393848050026, 40.89967558460851, 62.364277608932994, 64.19280029112294, 80.10458130990305, 76.16377599777715, 62.61287350808421, 69.84909734418316, 5.778308260825373, 0.5490324778422233, 0.24062717513691997, 0.15955055793446882, 0.09497658544850927, 0.1960638252597663, 0.10409385912240514, 0.12968656606972218, 0.21816184594025537, 0.18773811959451248, 0.10142017396227007, 0.20703271812488958, 0.16865517583585557, 0.15835120132373226, 0.08742173277442494, 0.13513901300968664, 0.21039262654319887, 0.15731586413758417, 0.22236058999213482, 0.20349512327342265], [0.02001223713910628, 0.07735909128020849, 0.03521943675173867, 0.10309321039746847, 0.052705267218933, 0.048867078618176525, 0.030917261253982305, 0.033758361523430196, 0.02568719048623837, 0.01210088640706794, 0.05445038103648732, 0.10889852509623575, 0.040002820803032774, 0.034865423691489046, 0.05751333079270779, 0.013890188176094765, 0.05588624431120773, 0.027257368126283252, 0.04832148995070208, 0.020150021882727742, 0.05775449527127128, 0.09907022223717744, 0.06062756247457959, 0.0818511474156572, 0.32612096338022145, 0.2562654045440497, 65.28792604323357, 68.88606917473578, 63.22141355083835, 50.229805746386134, 86.75289677035424, 44.657227762283824, 51.98205794057539, 27.520614093349828, 20.92207939394059, 83.85264135176136, 68.25672488058767, 84.97700445113644, 55.59029333053097, 64.60728891434209, 33.40666201806838, 0.635052997498743, 0.37039137655688875, 2.08217304560446, 2.75870565925875, 2.487451208214606, 4.061354211261196, 3.912144308128665, 0.8893180085766701, 1.1761023488736924, 1.9428746041751679, 3.182116694027378, 5.022880848376982, 4.356879553487224, 3.423457188952354, 1.9735651895884547, 14.910009637955698, 28.994562356702744, 7.724080393391271, 1.2421716100746587, 3.0607016865284216, 4.494344899731298, 3.9682592067026325, 4.397160333971824, 2.5997042944354396, 1.584970093061847, 11.733579154937498, 19.850858526845133, 25.919998768837225, 29.045517867611302, 15.982897512374388, 19.82707131293512, 51.529922408442346, 68.85446271588727, 67.38947314600792, 64.20473214118712, 53.82561899000599, 49.87651394259546, 46.958043036922334, 46.14833247277045, 47.82939364833217, 55.4464521715718, 57.26130147134104, 61.62931565315493, 59.69980370613837, 63.51433223293674, 61.46175984413394, 61.56593799591065, 50.7531479866274, 32.79905157704508, 64.30183825954315, 58.656759185175744, 65.45439143334666, 51.04056358337403, 50.49400875645299, 49.46429637170608, 51.409262457201564, 49.65922247978949, 48.24647103586505, 43.41930420167985, 42.02211280022898, 44.262476505771765, 49.486869612047755, 50.27552097074447, 52.35152952132687, 54.45431609307566, 52.69606659489294, 42.271697136663626, 47.28807910796135, 57.91869855696156, 50.67728542512464, 24.748080853492986, 18.24271813515694, 13.521217992228847, 7.026098543597806, 1.2783386822669738, 1.2104642727682668, 2.7415168525711184, 3.4860393404960637, 2.1490445540797327, 2.9542350769042973, 2.7822685626245316, 5.449516561723525, 2.7529174666250906, 4.870909106346869, 6.355116328885479, 13.796767438611678, 13.64889310252282, 10.158214088409178, 8.662698672663781, 9.918440580368042, 8.04669681095308, 6.845166961992941, 3.826417966235069, 2.2293386584328068, 0.47138379766575755, 0.3546164617423089, 0.04833467815431857, 1.8986978069428477, 2.1617611233265173, 1.0041727293883602, 7.36880632177476, 54.883878384867025, 57.85423048080937, 88.86780738830568, 68.70527928875339, 60.783993890208585, 21.727267465283795, 25.60334582482615, 39.89673729865782, 44.44469805686705, 49.365017260274584, 54.54982580677156, 36.19172526944068, 56.377003115992395, 15.02948993636716, 0.27770984497281814, 0.005687312260570546, 0.030363854659240574, 0.036976417271240104, 0.04373358472460701, 0.013217813872371711, 0.013527591100653574, 0.048369527493994084, 0.04519443395697782, 0.025520499330013994, 0.06214871814834976, 0.06646208044502043, 0.04433610521617436, 0.029900143553893414, 0.07059344706395942, 0.07569503339548266, 0.04410931637750999, 0.009931515012266896, 0.03588713217346418, 0.052577935745038336, 0.03685573161008858, 0.03766370156118947, 0.047526677559700706, 0.028104195972123457, 0.05659667594778923, 0.04374309570618695, 0.024227984512465137, 0.02365183468247133, 0.04194903653115035, 0.01388690644694913, 0.12063381998168847, 0.04335560843408589, 0.035760482517822136, 0.0747149158269167, 0.04581508008883365, 0.04525760556721399, 0.027325862132373358, 0.015575232081896356, 0.04565968298383298, 0.045003398441739624, 0.06423600130684434, 0.05576475042729609, 0.02404364652090496, 0.06686147272346482, 0.09711547995046263, 0.8053224738086424, 77.91767950980895, 83.85274333338585, 63.11003392742526, 66.5160789797383, 74.63940174348893, 30.113989153215964, 49.885453024218165, 27.02513833199778, 34.923191532011955, 87.61872860693163, 80.66071848715507, 88.02836525824763, 70.29209767618488, 70.60924483883765, 41.296184062957764, 0.5411806282016539, 1.498138745946269, 3.0368980476933145, 4.173556796966061, 3.9573356509208684, 6.13534837961197, 3.480420545224221, 0.566604880075301, 1.6726529622270216, 3.135330907760128, 3.6849341517494576, 6.460087780029544, 4.744020921568717, 2.2079845397703113, 6.745753509383048, 18.72052558006779, 31.82406213975722, 12.352067309041178, 1.9788264363042771, 3.424999661022617, 8.235515298381928, 6.218486447488108, 5.190860273376589, 2.9839372250341603, 4.707360979049437, 11.316566486512462, 22.64827528307515, 30.33273973772603, 36.212219653591035, 22.509356698682232, 25.655005401180638, 57.118986114378906, 68.2878214313138, 69.61545744249898, 64.98749209988502, 55.8403326619056, 52.32515158191804, 50.50553268001926, 49.09649964301817, 51.026046891366285, 60.204193053707, 61.86818407427881, 66.31534776379986, 63.68774414062501, 64.68456745147705, 66.29832467725201, 65.37504580713087, 53.39491136612431, 35.683095839715776, 67.31212400620984, 61.34103713497039, 66.52295881702055, 52.19176746183827, 52.05909329075968, 50.20311009499335, 54.48498118308283, 54.238515130935184, 52.41538963010235, 47.620570582728234, 48.85903150804582, 49.05664443969727, 56.408452680034024, 56.54170736189812, 58.605874276930294, 61.04967171146024, 65.04645709068545, 62.22383714491322, 65.85082146429247, 60.76631969021213, 52.4297062812313, 28.622217639800045, 22.05728196328686, 16.331912952084696, 8.430654195047195, 2.5590290706003866, 2.5015935590190272, 6.4347262247916195, 4.335739939443527, 5.238977949465475, 2.076444669115928, 2.5776863146212796, 4.588363622465442, 5.510727109447603, 8.25801597487542, 9.882765643058285, 11.828686825690731, 11.68584292934787, 10.798644961849337, 12.930432558059694, 13.03187289545613, 11.178555930814436, 8.042628822788116, 5.95434864682536, 2.661871410185291, 1.2431308747299257, 1.4070435373052474, 0.95745533945099, 3.031074553728104, 3.037379763780102, 0.8711038085241473, 6.148178942741887, 56.07403532151253, 60.418264250601496, 89.04972691689768, 68.40232326138404, 72.46846398999615, 26.137111763800345, 31.906988889940326, 37.49893357676845, 42.17683069167599, 53.95216641887542, 61.54681251895044, 43.48148945839175, 68.6738375694521, 20.47839068597363, 0.44024256869189204, 0.01961809830860265, 0.029204079896331798, 0.052952104578575784, 0.07901077684495719, 0.03885694862072987, 0.0741035087154277, 0.024665520308659445, 0.011475279855902397, 0.06222148117939792, 0.03609483776193473, 0.0060090203506631724, 0.08667478938737223, 0.009800075391878285, 0.020520789285881386, 0.06326760105308026, 0.02526923015172924, 0.014177689482758363, 0.09129226177690491, 0.0849505246526772, 0.10030148640996027, 0.1555562827495798, 0.1531405623761877, 0.19248490762566367, 0.18757949342891095, 0.1642817177719647, 0.20309579228201222, 0.10990796084966391, 0.23558585694239986, 0.08259754688028367, 0.16213723848904335, 0.25683787140634756, 0.123916560363385, 0.29576966298684, 0.1589073658350014, 0.12056540066917097, 0.1213751326224977, 0.09739075832429434, 0.2446046729962672, 0.14397390667469273, 0.21744575291391344, 0.2170442921980735, 0.20004968879924667, 0.16626075270675844, 0.5781003051707821, 1.6213427219660053, 94.85188514955583, 91.1531214560232, 84.93303468150478, 66.88117319537749, 112.46379790767547, 60.915828674070305, 67.74694227403211, 37.2265955709642, 25.943019159378547, 102.0334860586351, 84.7176730248236, 100.26703880679224, 69.54438409497662, 74.65563251126197, 41.87720867895311, 0.976575545726284, 1.2731122465864306, 5.930935038674263, 5.771537269315412, 5.197632735775364, 10.447593812019596, 7.442232601104244, 6.903941717840011, 5.151659125281919, 4.795851121025701, 8.903698901976309, 9.884656225481342, 7.762328405534068, 5.285170232096027, 12.700914086834079, 27.943194566234467, 40.137315873176824, 18.373344829005582, 7.05522116153471, 7.38205804940193, 9.599357728035221, 7.486662268638612, 6.264899363440852, 3.6053308748429824, 8.828534522364217, 18.501359224319458, 26.38690398585412, 33.2748782250189, 39.68314070855418, 27.33144602467937, 28.550573587417606, 53.78594029334284, 72.75656992389311, 74.44079645218389, 70.82052723053964, 59.83763187162338, 55.29038498478552, 51.85039574100126, 51.4427085076609, 54.98788395235616, 61.53142506076444, 64.6933457159227, 66.80816219698998, 64.62857953963741, 67.19751234977477, 66.4514853877406, 64.2284389465086, 53.557572057170255, 35.73816199456492, 64.41175876125213, 60.06612954601165, 66.17713912840813, 52.61554033525529, 53.18359759546096, 50.41780887111541, 56.45636835405904, 55.037039095355624, 53.66342506101055, 50.38274288177491, 53.617666690580315, 53.033425731043664, 60.93371075968589, 61.067279231163766, 65.0557452632535, 68.11692376290598, 73.43333567342451, 71.92424297332764, 72.55018265016618, 64.85426879698231, 49.46217436944285, 28.88409664553981, 24.234995611252327, 20.017820096785023, 13.874577456904998, 8.608463079698625, 7.4355003429997355, 9.532806873321533, 8.934122766217879, 9.646064331454616, 7.231543467890832, 9.298735510918403, 11.446979411186712, 14.57580702920114, 17.140690972728116, 18.353107360101518, 23.05336786854652, 19.29340735558541, 14.238023296479257, 15.31555917955214, 13.389807804938286, 13.885815047448682, 9.502749750691077, 6.716790237734395, 3.7858577168756917, 1.4830414205789568, 1.6122970009042372, 1.5444245525906164, 5.823852371784949, 5.26490334541567, 1.0580038279294968, 10.01856594316421, 65.5512975108239, 64.02904133642873, 91.93494396824991, 75.76732635498047, 73.29038881486463, 29.089554317535896, 26.620712549455707, 53.63799633518342, 63.09613304753458, 63.25335341115152, 69.64977818150675, 54.64254279290476, 79.4852469044347, 34.035653298900975, 0.5633938072189209, 0.10857801689135452, 0.12723008215787912, 0.13964016260879655, 0.17812131062871028, 0.1490579266101122, 0.16265724365028644, 0.15505952069595938, 0.11749981557049098, 0.21625154441402805, 0.2014629831237178, 0.1719416777092603, 0.13155199016534513, 0.24990154280056878, 0.1764598038167723, 0.10861996786608812, 0.2596704968281331, 0.09846697396208202, 0.24407348295132963, 0.28304402325903216], [0.05878762612419744, 0.05774092019325303, 0.01854474783965176, 0.06100993610978608, 0.05560550373047591, 0.03746758688301329, 0.09401254806547396, 0.018935651863895116, 0.01310443094435839, 0.0553148154980473, 0.028198899761323008, 0.062446921703315554, 0.09017866870929157, 0.030413740389649908, 0.013916880594596509, 0.016907966515469938, 0.11665715715817868, 0.01036206121376205, 0.02674273898704879, 0.08202616786283833, 0.023952428431760882, 0.226329124622768, 0.07700203302045984, 0.08235485022587162, 0.13833919209578346, 0.22085115163316651, 32.25708396204057, 78.53206388411984, 52.90212831189556, 58.85117538513676, 61.58473007140621, 78.14836978912354, 42.45765670653313, 69.78538236310406, 18.66547315351425, 66.31190392278856, 79.38565008101925, 72.71098413775044, 64.1122583420046, 76.57065130049183, 21.860018122580744, 0.12730861383099712, 1.962696056692831, 0.9753680072965162, 0.34048667477984584, 1.4883122280720742, 0.19081537221227923, 0.5476034480717875, 1.5096798298820373, 3.179586274969963, 3.786720393165466, 4.283888166950596, 7.230488840610751, 8.508094529951773, 7.525701618963673, 4.1486811253332325, 19.135677083846062, 23.45061375248817, 4.953750054682455, 1.589899899498109, 3.5590542612537264, 5.897684616427268, 8.237081304673227, 7.1841342699143205, 4.625687426136387, 0.5912222881470958, 4.334794157935727, 12.523605304379618, 21.85779609987813, 28.536547191681404, 16.980218964238322, 12.776991398103776, 26.868369040950654, 67.2547632648099, 68.35346621851768, 67.12786674499512, 59.30811582073089, 53.81831945911531, 49.79693297416934, 49.41754956399241, 48.83206913548131, 57.65059278857324, 58.296791507351784, 61.087091122904134, 64.74589370912122, 65.20540721954839, 62.21000686768563, 64.7403553224379, 50.80222468222342, 45.71507138590659, 67.88115793658842, 61.24358192566903, 64.31240120241719, 53.91421748745827, 49.59887681468841, 51.31246228371897, 50.66753833524643, 48.611577018614746, 45.224041631144864, 44.03125278411373, 43.24631983234037, 46.584578483335434, 49.02513211773288, 50.83145810711769, 51.83457289972613, 45.52429122309531, 25.896629287350564, 12.40583025640057, 10.497767790671318, 29.050562035652902, 32.44319650434679, 19.496593975251724, 17.189685298550515, 12.616826315079967, 5.6971397130720085, 3.2372691410203136, 1.665247527341689, 4.240596967358743, 4.213065360822986, 3.970776878056988, 2.9667506246797504, 2.8492001323930682, 5.342053424927497, 5.824024956072531, 4.968834509772639, 9.143214514178615, 13.643402764874121, 20.474825251486994, 13.483979990405421, 12.987870766270547, 15.122902162613409, 11.692057924885905, 10.004709189937962, 5.337493669602179, 2.698182506907371, 1.704829267917141, 1.0505255840478405, 0.27114364408677627, 1.3098321278249065, 1.6892406656857462, 0.24333560238442115, 0.3711039302570205, 45.496650280491004, 58.66473728610624, 65.11178808827555, 60.83517689858714, 47.01714531067879, 11.141866080222592, 28.85376887936746, 38.61564413193734, 47.81659103208973, 43.980650286520685, 28.833398049877538, 52.47963413115471, 45.57278740790583, 0.3915776913204501, 0.029247421320647966, 0.07630635623729999, 0.1166886433718666, 0.04530626747216429, 0.029288470226850723, 0.06692829091222056, 0.04053030681285647, 0.0786297630158163, 0.025200626978109923, 0.027604373397245526, 0.0429005905114595, 0.11134407693339933, 0.03756226002869587, 0.03348418631620946, 0.03924583400329275, 0.06776418476816147, 0.05997337701339876, 0.07181054627102229, 0.014815389689418578, 0.06886482328897522, 0.02857662898848855, 0.019830896466549848, 0.030261037998922893, 0.06644357942164907, 0.04189114326671247, 0.01176716318549288, 0.06808646263614779, 0.05450693747749733, 0.06699327815083728, 0.06812323485651324, 0.05176471809165613, 0.06655595685926176, 0.058780371271554506, 0.1293871482653964, 0.03699015322772246, 0.03275416198096449, 0.018103651649829362, 0.017763602457219557, 0.0526016078618986, 0.11376210323144352, 0.03679074820191149, 0.2300833997827384, 0.05847766311959394, 0.03819953792938783, 0.16399172284910757, 0.20124657860686704, 43.03455106673702, 91.56129898563509, 62.2650691001646, 61.79951513967207, 75.3797883372153, 51.16401233980733, 42.056868922325876, 46.80849090699227, 28.943985354515817, 85.37581536077684, 81.1415304676179, 85.661512959388, 67.37728241951235, 82.42598118320589, 23.06866707340364, 0.10863945714288181, 5.421678520018055, 2.8428444218251014, 1.4129389822483065, 1.7202152552143222, 0.47988786392154237, 0.2472823494744878, 2.1630255974108175, 4.713888293312443, 6.490609703525421, 7.099583168183604, 8.047800467860315, 9.11207579797314, 5.925021085046954, 7.49060130888416, 19.370507424877538, 26.770350971529563, 7.368533717047784, 3.4108707933656635, 6.129188787552619, 7.198874046725612, 8.91868039484947, 7.113394814152872, 3.6170514072141344, 2.55021795630455, 3.9375924006585157, 14.362557568857747, 23.424349561814342, 29.3861404157454, 22.01547734199032, 17.25655778761833, 34.21784739340506, 68.50762321103004, 70.1011174724948, 69.59513172026604, 61.745515869509795, 55.54013798313757, 53.94903244510774, 51.29356822659893, 53.18644523620606, 60.146475376621375, 61.888498029401234, 62.640432080914906, 66.36211026099421, 66.3143201028147, 62.72060140486687, 65.04405660014, 52.256329674874586, 47.01068124463482, 69.2514693352484, 64.04624092963435, 66.67531151925364, 57.02989732065509, 51.84546924406483, 53.80483435046289, 55.184512369094364, 54.791149631623306, 50.14220353095762, 48.79776800832441, 46.81487260326263, 50.28426785622874, 55.07548224541449, 57.07694615087202, 59.58387805569557, 60.15074683773903, 51.32749280621929, 38.296065099777714, 29.45166164828885, 40.16563538582095, 35.904239070030954, 23.923945773032404, 20.563468856196252, 14.081560930898114, 6.124801126218611, 3.5032715384037267, 2.211107236723746, 7.0256832626558126, 6.202785199688328, 7.508685886859895, 5.375371508059963, 2.5323758298350922, 3.7011389338201095, 6.289619611155603, 8.937041009626082, 10.70252041662893, 14.658040500456288, 14.996558696992937, 11.460421373767238, 14.482627203387601, 17.382226605569166, 14.356515157607294, 11.931823588186695, 6.977989202545536, 4.5868932239470945, 2.197258573385977, 2.577952055200454, 1.6601002745089994, 3.703770353909462, 4.1806513840152375, 1.5161734362763744, 0.10389610118563138, 43.427925571318596, 60.78992451390913, 65.22441502540343, 63.65991100188225, 62.54578921102709, 14.986116367001689, 27.170679838426654, 42.3537491982983, 48.50716352462769, 53.98310215242448, 37.751965676584554, 64.04324031645253, 53.89932817028415, 1.1455201189364157, 0.19862884084784216, 0.10096734705110712, 0.054624083812438676, 0.017367071517172362, 0.027100733789284865, 0.02808186450913068, 0.026788562536239627, 0.052060087121302084, 0.021345029029274182, 0.03394230306448956, 0.015423089892963971, 0.08157740121767407, 0.07287271951715793, 0.07622013304142222, 0.09764316131270702, 0.047404092000496965, 0.04371699509060672, 0.019813797384079908, 0.06963965227647174, 0.028938500195621487, 0.12864958945541613, 0.18406048387048707, 0.19854414216693372, 0.3158849561887403, 0.08636732765984151, 0.13384545822778057, 0.17115318937407387, 0.14826335553680697, 0.1722912436291095, 0.20237343265644966, 0.1486761083886508, 0.13922011659991357, 0.217867836716675, 0.17827039133877526, 0.10092574081593945, 0.08815283346320353, 0.15457498540561046, 0.21435323982469498, 0.18054495235123943, 0.22217105983966784, 0.13747908986143528, 0.2790699574735857, 0.12746371599214693, 0.19507708869153456, 0.24719941279580518, 0.30706605843959317, 51.266656844846665, 106.62656584093648, 74.574643411944, 74.29826536486226, 85.60768235114314, 100.93704239014657, 57.432748271572976, 81.97001349541449, 25.84412051785377, 82.28136339495259, 93.27844988915228, 88.93810410653391, 77.01893114274549, 87.83759686254686, 26.831820395685014, 0.23746991229634132, 5.046653843695118, 3.89729862732272, 3.688428002980448, 3.0264182100372934, 2.1733426567046874, 3.7716378992603676, 4.015940028813578, 5.866664551919507, 8.127799168709787, 12.574278404635768, 11.472000210515915, 12.90196889831174, 10.159490819900267, 18.172760701948597, 29.2258959047256, 34.80753652511105, 13.9741026970648, 9.26201722314281, 7.954218108807841, 9.90639792334649, 12.338990126886676, 8.080790542787122, 5.047282893811503, 7.819093927260369, 9.939420357827219, 21.370057213690973, 30.30070181815855, 35.26112725657802, 25.680110531468546, 18.6798329507151, 33.05620216554211, 72.4525313223562, 76.02981136691186, 73.09234050012404, 66.62903539596066, 58.491705848324685, 56.29676318937733, 56.00647249529439, 55.46034520672214, 64.04169490260463, 64.4111978623175, 64.1658849870005, 68.02634839088687, 64.65549484375985, 63.40810660393008, 65.60004080495527, 52.68981825920844, 51.200619820625555, 69.11126029106879, 63.57095164637413, 65.33198994974937, 57.31692852512483, 52.31506324583485, 55.305780287711855, 55.63482399909727, 55.70919605993456, 51.38140970660795, 51.032193245426306, 49.82943373341715, 53.129229622502486, 59.90372380902691, 62.40170094274706, 69.04101848602295, 71.45813203627064, 61.040520821848226, 52.097536440818544, 36.81781399634577, 40.671585836718165, 36.44472206792524, 25.746996748831968, 24.68385596429148, 19.03756291635575, 13.26726217423716, 11.113700520607734, 7.5540319181257685, 9.822446453955866, 11.341048940535515, 11.176924224822752, 8.56823819298898, 6.655172253808668, 10.138100174165542, 15.378062148247997, 17.93919728648278, 20.309150218963623, 25.06015443032788, 29.662814601775143, 18.811265691634148, 16.892459854002922, 20.035041263026578, 15.34619289059793, 14.36325575074842, 9.34077057146257, 5.60993169584582, 2.3583157504758527, 3.016251671698786, 1.4513527145308833, 8.080745925826411, 6.470753194824343, 1.3452016105574947, 0.7464902920107688, 59.65682237379013, 63.33626839422411, 72.79773912122174, 67.28127848717475, 62.944760937844556, 11.906792002339518, 36.57567039612801, 57.332500334708925, 64.17501626476165, 61.760295360319084, 49.026155856347856, 72.491041152708, 70.09256670551916, 3.4405555359778868, 0.40717803001884495, 0.21035387781598877, 0.20176522013160492, 0.12240715264793366, 0.14024454469401992, 0.29761890730550217, 0.2496566551346933, 0.2237257739949611, 0.17156238757794903, 0.21951864894119003, 0.09672014027713768, 0.29526205312821174, 0.1421691260991558, 0.18348600985782762, 0.22811835361344202, 0.14354600060370662, 0.16369849503520997, 0.0904961891712681, 0.19615391719966166, 0.17030548244234056], [0.05589028542500831, 0.022703942602440234, 0.06270003332305821, 0.0341264016535734, 0.01435892194539549, 0.012247880485149161, 0.04760615152096556, 0.02515833892468964, 0.10284104489631231, 0.05328207396932187, 0.028940848255109404, 0.09048270602380076, 0.1003994996989927, 0.06191116960478887, 0.04466427430029839, 0.12669775064193434, 0.0786880010198201, 0.08258064698067405, 0.06454840813192629, 0.0492434001587812, 0.061882307242241606, 0.03630200708885828, 0.06093063068786456, 0.054512985741659525, 0.033044041990632975, 0.06477376821661188, 0.41970926727498736, 79.53237810442525, 63.444357149062625, 51.508133642135135, 63.677192964861476, 70.75285850032684, 39.47271339354977, 47.739606672717684, 33.173928183894006, 34.71621590275919, 90.80018658791819, 67.63214234382876, 79.48214823199858, 76.01027796345373, 22.282731956051244, 0.4099493071196541, 3.8438636881689874, 0.18941153141279377, 2.9416940337227238, 0.5638116009293065, 0.44667749275122925, 1.650810018181801, 4.249805221634527, 5.296229845093143, 5.012978824876971, 7.577619091156991, 10.314674492805235, 8.424153847079124, 9.23918902873993, 6.451876788370072, 16.561256877837643, 14.599209850834264, 5.681074175142474, 1.8438384345462246, 6.7374576964686, 8.995791250659574, 8.415250066787966, 8.668476323927603, 6.044861260921725, 3.172802780905078, 1.1169261629542997, 5.74342760347551, 11.968221222200702, 20.67062997048901, 11.66574372399238, 8.84688631180794, 5.809661236501509, 31.759629364936586, 65.69085151918473, 65.26935362046765, 63.020317554473884, 60.58224285802534, 51.26966138039866, 48.823090830156886, 48.52982697948333, 56.090466130164366, 57.942703462416134, 63.40318010699365, 60.4780686286188, 65.59212546194753, 60.35924826898883, 64.9757642130698, 49.339949392503314, 44.22338224226429, 67.55919410336402, 60.073805624438876, 60.933585243840376, 51.09231925779774, 48.084473225378225, 50.407500882302564, 49.370492889035134, 48.68741604589647, 47.583021733068655, 45.18245666257797, 44.92278791243031, 46.992552049698375, 48.31291990895426, 50.85267420737974, 51.17412421011156, 38.80311773669335, 19.19595018509896, 7.080282655454452, 8.418301670782029, 20.844659651479414, 18.470574502022036, 19.109979675662135, 19.324205806178433, 11.985686555985483, 3.743588294713728, 4.126519733859647, 3.661914251504406, 8.37899854106288, 6.065791028161203, 6.003310613093838, 1.375283738297801, 2.731994563533414, 4.761465662910092, 4.535773954083843, 9.577333619517665, 11.123032819840217, 12.940964121972362, 15.258724035755282, 21.94165833534733, 15.39691992344395, 17.287122857186105, 15.892719280335212, 13.549316871550776, 7.969210878495248, 3.8731755604667053, 3.011443091015662, 2.1443222655404, 0.5290838547291294, 2.048342480294166, 1.4641674656060435, 1.8807555374599274, 0.1736394664452922, 23.47621702378796, 67.93760868810838, 55.42288657157652, 67.89771033871558, 21.401038054497015, 22.617661183880223, 47.70708630161901, 34.404889537442116, 51.18514999266594, 28.18356525513434, 42.46564657457414, 59.58953411348405, 9.883821741227182, 0.4305007188550888, 0.1329726848991648, 0.046766630238703186, 0.069855252401002, 0.03523653583420861, 0.09384419258323409, 0.03527432312107375, 0.09478790565363823, 0.032763833841008526, 0.08222168116199394, 0.09026475400934297, 0.07697413209825754, 0.09752260971694224, 0.07875202298765221, 0.11378674827996763, 0.04988541631328483, 0.04655212945034427, 0.03838974223922818, 0.030761362361391226, 0.0744069025160805, 0.06443769310510929, 0.03871133828896188, 0.008630470763291083, 0.04870541874439486, 0.05285584946132956, 0.021216887417399598, 0.09308605665160764, 0.025430453355394067, 0.06810868684683116, 0.0970539094639882, 0.0373108261415074, 0.012130831826418158, 0.04450718031054543, 0.09901341681759204, 0.04635126119659794, 0.0880488983145164, 0.028326206337360126, 0.09356425639482276, 0.06853503775933097, 0.08226428331146318, 0.013536788943794467, 0.10780785337931688, 0.03037924345041956, 0.09313346217236212, 0.10792910211509275, 0.049707883097712076, 0.1579721256970398, 2.564054362235531, 95.35251294412922, 74.81160163879395, 55.88622047055153, 73.47807422760995, 64.05975741724815, 33.36253535362982, 53.68004022106048, 25.834153775245916, 56.156106994998076, 95.40109542108353, 78.85747155835553, 82.41368063034551, 84.23520580414804, 19.544444930168893, 0.23817209316597832, 7.101445313422912, 1.7368016103583, 3.887950883757684, 0.495197732722567, 0.9507572795114211, 2.172873933469096, 4.366608992699654, 7.474978018191553, 8.441845697741355, 9.615185472273058, 13.25767590153602, 10.30875857799284, 9.28807548938259, 8.412880955203887, 19.05758269371525, 17.186433653677664, 6.890292359936622, 2.338235176378681, 6.585382011628921, 8.790457133323915, 9.8936306084356, 6.608500951720822, 4.74818108543273, 4.609338987258173, 2.176087825529037, 5.9044972831203095, 11.076948892685676, 20.417546879860666, 13.021829666629916, 12.668091693232137, 12.582739937689997, 46.08689246639129, 66.47789862848097, 68.84368404265373, 66.79161763960316, 60.351623181373846, 53.91685332021406, 52.556963659101925, 52.28104845170052, 59.13147580239081, 60.15485748167961, 66.73337044254427, 62.770544944270966, 67.9081516881143, 61.637317288306456, 64.63712246187272, 53.06425556059807, 48.2182691943261, 70.3633043842931, 64.05091247250958, 66.27541019070533, 54.661578055351015, 52.6828952758543, 53.3520398601409, 52.9800344282581, 52.352619940234774, 51.117363591347974, 48.65451912726126, 49.50473993055282, 54.774275595142, 54.1413462546564, 56.84189419592581, 58.54554037893973, 55.7541464221093, 39.651785281396684, 18.486044329981652, 6.031454599672749, 24.223601125901748, 23.20877805832894, 23.13474528251156, 20.993743058173887, 12.544757666126376, 3.8073959417881507, 1.1091164787930827, 3.5766679096606473, 8.760405894248716, 8.467285210086454, 8.743433798513106, 7.759774452255619, 2.7949289929482246, 1.941426514137176, 5.6934296411852685, 12.558664429572321, 12.455277615977872, 14.787656203393015, 15.81968867009686, 17.393656392251295, 15.206662416458132, 17.606966649332357, 17.235137724107314, 13.602919982325647, 9.643261797966497, 7.354114103701807, 5.408088487963523, 3.6950232232770617, 2.6053625585571414, 6.096881205035794, 5.6833270865101975, 3.766708705694445, 0.32920416084028065, 23.814038999619026, 70.55463760129868, 60.70737823363274, 67.1998893060992, 32.87395904141088, 19.423073068741832, 45.430185717921105, 38.70896908544725, 53.00538470668178, 36.461564725445164, 45.35544103191745, 74.15766408366542, 10.9534256112191, 0.34596674685035983, 0.22407845023178288, 0.021517756958341887, 0.09078608450269507, 0.03456392978888846, 0.012870569198933101, 0.038228170465557806, 0.08025812120327065, 0.02850875168317749, 0.019418390678061594, 0.07500958388611194, 0.019989398142863667, 0.029748383451313264, 0.04561778180481446, 0.03894600634192748, 0.01776883292252258, 0.09282910310092474, 0.023308286383267374, 0.07067292102522428, 0.08776644935771342, 0.047133808519931576, 0.10881730445450354, 0.16219022112988657, 0.17013383278202626, 0.09016363040333794, 0.10839024108023414, 0.11682227974937809, 0.08458683973238354, 0.21026928638738973, 0.23154313435717938, 0.175356529953499, 0.1355054175421115, 0.10440217886841106, 0.21920631489446088, 0.1385934107125767, 0.14212729769849008, 0.16979018106095253, 0.21811440977598393, 0.20530745747589296, 0.31288483330319006, 0.11693176137463701, 0.11993154718150055, 0.24767824839199745, 0.25619379064488795, 0.18379307321963773, 0.22645398163266722, 0.2692115703417409, 3.9030838781787507, 115.91421281137775, 83.98648046678113, 72.92758526340609, 77.80847287947132, 98.46051277652865, 51.690288512937485, 64.66400638703378, 41.10835352251607, 43.76479441119779, 109.79184796733242, 83.27208349781652, 95.34935935851067, 87.87158812246015, 26.867737539352913, 1.01096780670266, 8.891706255174453, 2.8516413175290634, 5.26931748274834, 0.9794434111925864, 1.495387448418525, 2.693346469633041, 6.887815383172805, 8.80009831920747, 11.929406427568006, 12.395598753806084, 17.61117535252725, 13.135206757053254, 13.543109720753087, 16.913368048206454, 28.628134535204982, 24.255107564310876, 15.853173944257922, 7.423714110928198, 10.394885982236556, 15.255458662586829, 13.121568675964111, 9.735137435697741, 7.8600003257874524, 10.394787922982248, 8.183375721977603, 11.792499038480944, 18.70194531256153, 25.87403839634311, 15.526416974682963, 14.52516628849891, 14.399981883264358, 46.546994332344305, 73.90471043125277, 73.35232303988549, 71.49193502241566, 64.32985182731383, 57.92562938505604, 55.18667751742948, 55.77389947829708, 60.01398163457071, 65.81882276842671, 66.99660854954874, 63.48622452828192, 66.84221621482604, 62.78440267808976, 63.907887166546246, 53.100690457128714, 47.612902349041356, 70.41821756670552, 62.51896804378879, 63.644998150487105, 54.56532701369255, 52.83372609846054, 55.167073511308246, 53.0699037736462, 54.07978857717207, 54.79747249234108, 51.96947105469243, 52.828379907915675, 58.97394949390043, 57.936176638449396, 63.42231735106438, 66.75477873894476, 68.86727317687004, 56.75567265479796, 36.82981252670288, 15.077327162988725, 27.57758063654746, 25.558130702664776, 27.056699683589322, 25.350376482932802, 17.598602194939893, 11.329526978154338, 11.020488335240273, 10.380469310668207, 13.42985422380509, 13.86378211359824, 13.633573305222297, 11.279454981127094, 7.35681220408409, 7.051336053879031, 12.39096055107732, 23.66958006735771, 24.23890425312904, 25.618458717100083, 25.88072015393165, 33.224848393471014, 22.270172526759488, 21.959769879618, 21.86745689761254, 18.0654917224761, 11.762522324439018, 7.765829611209131, 4.1907205985438445, 3.7501871922323784, 4.045644628424799, 7.5832633818349535, 7.014151004052932, 4.465117848688557, 0.20487667091431158, 29.950090954380652, 81.70538686936902, 61.33458875840711, 73.31435449661748, 29.04890875662527, 25.017216244051536, 67.05193750319943, 48.1302119839576, 71.62370312598445, 47.32733418864589, 57.55332193066997, 86.4775699184787, 22.863574181833577, 1.1919951799415773, 0.341404294895549, 0.23904281337895703, 0.12073169537489453, 0.2494134681840097, 0.175428940584102, 0.11028777958164293, 0.1567171511030005, 0.1496819665114726, 0.12045843181230369, 0.25316127756189916, 0.15281578706156823, 0.2216489709192707, 0.1552976821098597, 0.2923333296372045, 0.21272631422165902, 0.4031918600441948, 0.13317598931251035, 0.1861317404696057, 0.20540373940621653, 0.17193340395967807], [0.04572055633029631, 0.06008152947610906, 0.06897865629364407, 0.03820115437490806, 0.003591497755429197, 0.07769485229566213, 0.03170848452305842, 0.07788773791323747, 0.058181079840588, 0.017664051246679118, 0.020583778950235537, 0.04715042496700922, 0.08388238358161143, 0.05026304020336078, 0.06456841068762927, 0.043185494780059785, 0.053026748355478055, 0.058279954978535255, 0.007433369323881644, 0.0319514722908817, 0.10658702332406275, 0.04379694402638463, 0.10515208701573073, 0.06414040885565263, 0.10437341992773357, 0.1287754577013754, 0.09991912426607263, 19.775982441440707, 92.3305699133104, 46.447103331165934, 56.62668943405152, 70.68204402923584, 53.76981150719428, 27.41988958850984, 48.06394353989632, 27.40944039437079, 64.52703329824632, 79.4686709680865, 58.79006878022225, 72.75510295744866, 11.657210607682506, 0.6960400314100328, 7.766996516335396, 1.5674871086112916, 1.2424983925396398, 0.07702634099029726, 1.5758090298021994, 2.88242579467835, 6.000844913144266, 9.145154126228826, 9.505864112607895, 8.803072456390627, 10.677862436540666, 10.524372246957595, 10.447010359456463, 7.126233222023134, 13.034906848784416, 12.179628149155649, 6.527518226254371, 3.1699882351583053, 7.487142268688449, 7.586641032849589, 12.840226869429312, 11.599877322873763, 9.23580010091105, 5.772979720946282, 2.684639543294907, 0.7818512558456391, 5.532950768547674, 7.493167029273126, 5.481706963431451, 5.34249076920171, 2.1091947440178167, 7.218336357224373, 48.14593284360824, 73.1678225917201, 64.86973078020158, 64.24395584291028, 59.61548451454409, 53.987581499161266, 48.47201124314339, 56.98141290295509, 58.873387767422585, 66.34625604075771, 63.80070055684736, 68.50330075910016, 60.12485527223157, 65.15244737748178, 47.72704332105575, 43.61700342547509, 74.37491632276966, 60.01092218583631, 59.772885307188965, 50.601736653235655, 51.616747994576734, 50.46243759893602, 49.047748504146455, 48.95515311148859, 48.099272328038374, 49.965308558556345, 46.635047620342625, 49.79258306564824, 54.70191571020312, 56.30560421174573, 56.75646105120259, 45.67240384317214, 24.773276198294855, 9.291805663416463, 10.736370471216018, 22.861850300142844, 25.319962424616662, 22.213247168448664, 18.130822720066195, 10.559174456904012, 3.9547436996813747, 8.231724327610385, 5.127607641681548, 10.669555837108243, 10.274041679597671, 7.5161428028537385, 1.616943783817753, 3.1964419253410834, 4.90712974340685, 3.8949868804024117, 8.219915051614086, 12.453931262416225, 12.9408170330909, 12.935690495275683, 13.53543266173332, 18.973559641068984, 19.6198760309527, 18.257729045806393, 13.874926547850333, 8.44814012127538, 7.078715668570611, 3.7875595352342053, 1.9489882309590618, 3.1497213484779483, 2.4502740031288517, 3.5121645321769104, 2.597422455587695, 0.18709653627968606, 10.465504334818933, 73.32872606092884, 56.37441827404884, 64.31242473663823, 18.816764854615737, 39.05847580202165, 29.28756340857475, 54.86312904665547, 48.4449625784351, 35.829235507595925, 53.6801931934972, 16.71902048972345, 0.07688711217093853, 0.08033666053726789, 0.07997200268531039, 0.032298623118549585, 0.026945874861051, 0.039805380792747584, 0.04859466158274201, 0.07555346800795487, 0.055217123965943055, 0.06909965988128416, 0.04476113462700479, 0.024817123363215118, 0.06691156721283352, 0.07001833719832283, 0.013515267618781617, 0.030025810701772574, 0.059177951752057964, 0.056554249998542576, 0.06925637848795423, 0.03614748715453091, 0.035968073193104036, 0.027969431530143467, 0.006640486995644507, 0.06314238781229624, 0.007414643740987466, 0.053751007879092816, 0.018722215937750957, 0.014050808085519222, 0.02479281347815789, 0.038172269029723066, 0.032541702816923784, 0.021513811605531844, 0.04795710405995769, 0.02510288373507079, 0.03487693416255136, 0.010597503973141072, 0.022521533237229434, 0.05459804831433201, 0.046367958082907626, 0.09496985919653408, 0.0032126469276620136, 0.033062995005879676, 0.09805825073271991, 0.07806180841139249, 0.22798958955512894, 0.0914008240966547, 0.21081279512614975, 0.3481138155104653, 0.16664447082627207, 34.7866028355014, 104.52252018836238, 55.8116562135758, 60.69076699595298, 78.56263483724287, 41.38770080381825, 33.3979308220648, 30.370588648703794, 36.713620155088364, 83.70912967189666, 89.38416388727005, 70.33084284874701, 74.19469910283243, 11.458252303061947, 0.6653436237285215, 8.74584605616908, 3.965031586347088, 3.470817602449848, 1.0563798441040901, 2.16242277814496, 3.5241436958312993, 8.353393308578, 10.308598741408318, 11.385569803176388, 14.614362947402464, 14.200343047418903, 12.403821022279802, 11.695371347088969, 9.762746999340674, 17.426131656092984, 14.570479469914591, 10.3057393335527, 5.347651627755934, 7.389577233022259, 8.382973863232522, 11.794526903860032, 9.148169448298793, 9.297669606824076, 5.948810750438321, 3.028978292019137, 1.3818602047620283, 4.080300730082297, 7.997765243053437, 6.412167693338087, 4.806139988283958, 2.465114780972081, 14.126730945802505, 57.09161189294631, 71.76415535711473, 66.68970661778604, 66.42273441437753, 61.505176559571304, 56.67318128770398, 51.564690297649754, 60.251355632658935, 61.49302897914764, 67.6768808980142, 66.36199258988904, 69.80904994472381, 62.377754872845074, 65.25160097306775, 49.40316623257053, 46.570901178544574, 74.66792521938201, 64.02009048769551, 62.74828941591325, 53.76404562304097, 53.84355991117416, 54.663892253752685, 53.43830454734064, 51.10210949374784, 54.02558926613101, 53.61481120509487, 50.838902765704745, 53.75245501918178, 58.956267449163626, 63.58147144317628, 64.78875344799411, 54.47259041570849, 40.95848368060204, 10.74243445550242, 8.50062535655114, 25.00947544651647, 27.391371996172015, 22.978121119160807, 19.997325712634673, 12.475826913310636, 5.169711343703732, 4.139419428763851, 5.138904067777819, 10.351612433310478, 11.258483048408262, 9.111850261688232, 8.300674692276987, 3.507731028141514, 2.6422806420633873, 3.4967415275112277, 9.765093557296261, 14.194737980442664, 15.681585938699785, 14.950069785118105, 14.412664867216542, 17.29192776064719, 19.585035577897106, 19.22765470320179, 14.878185487562611, 12.239007930601797, 7.813839912414552, 5.803706097987391, 2.512127084116782, 4.07979695066329, 7.010244813657577, 7.730664091725504, 4.7578065818355935, 0.2140374583823066, 10.498120803986827, 78.48629766894926, 59.99672320581252, 72.05536780818817, 23.34730636688971, 31.23470444833079, 38.55171342049876, 48.20143830391669, 56.48276198294855, 35.8867060753607, 69.38446121831095, 18.878922654736428, 0.2448435238892994, 0.11714128642192773, 0.009263531349959874, 0.022923984121711507, 0.019398257887411504, 0.06817846213497462, 0.10662937266451698, 0.08494824937154209, 0.037723199779828714, 0.024660038949561217, 0.04691248571860695, 0.07380237487415153, 0.028583851282394705, 0.02005872143913181, 0.062071546281297366, 0.05920203372595772, 0.06828893967453512, 0.05621968024981119, 0.009828825714066625, 0.020297013087979248, 0.0301152303995144, 0.0853173122290642, 0.1534516860039965, 0.0995845813304186, 0.09466246641691654, 0.14834134328749873, 0.12745223233416197, 0.25240056757484713, 0.1627906961666961, 0.15009295736109057, 0.23310353288487082, 0.11877136830721172, 0.13948625554480862, 0.16529123779506455, 0.14067379907975275, 0.13777150562213314, 0.08442128813194652, 0.2667767897007927, 0.15518653807380509, 0.14589900901961714, 0.14534891192470828, 0.0960363225350457, 0.24307975966122844, 0.1223405642855552, 0.29130438162434485, 0.2800326848462705, 0.26592879165564814, 0.42870981979273987, 0.38624565808042405, 50.73242218263688, 117.2834651700912, 70.18187122960245, 74.7838940158967, 92.2227910257155, 73.70566583448841, 40.08730173110962, 58.97284338551184, 37.70527770442348, 81.36045363641556, 95.98962353121851, 76.02313549287858, 86.07936305384483, 15.093690310755084, 1.4885469574120738, 16.91017523888619, 5.852292987608141, 2.2042364699225274, 1.214099206751393, 2.4342930413061574, 3.5585995114618734, 9.94150411698126, 11.700106628479498, 12.166032233545858, 17.843403200949393, 15.949475976728625, 16.879243427707305, 16.950595263511904, 16.942442617108746, 22.72325727247423, 22.490729362733905, 17.349739574616958, 11.26647880000453, 16.18815122112151, 14.972502800726122, 17.86366028170432, 13.358469047854024, 13.871802380008083, 10.956629207057338, 8.451012276834058, 9.184144446926734, 12.125910309053237, 10.816661388643327, 6.945113856946269, 6.12142788787042, 3.6768474501948205, 14.863264791427122, 61.048189055535104, 78.11215062295237, 72.50818975510137, 68.53783330609723, 69.80657885151525, 60.09182891538067, 55.131513303326024, 62.74545354227867, 64.94036874463482, 69.11766944393035, 67.65869678989534, 68.78581339313139, 62.252584195906124, 63.10317762436406, 51.82985428840884, 48.45834178309287, 75.89223815548804, 61.81433777655325, 63.28372432339577, 54.01371232924923, 54.143613384615996, 53.981576350427446, 53.220259989461596, 51.18025095232072, 55.350722805146255, 55.15469058867424, 53.29914277599704, 56.29153074756746, 63.517827064760276, 69.62707550294938, 75.23243273458174, 65.68752142690843, 65.09738122263263, 34.14254180846676, 16.442930736849387, 31.922717594331314, 28.486976277443674, 27.761445660744947, 24.151343222587343, 18.154451077984227, 14.007815468695856, 16.434585894307784, 10.632863044738771, 16.021686811600965, 18.693902492523193, 16.94854974746704, 13.18893930604381, 8.307677103627114, 8.571589858301225, 9.267973342249471, 22.914535576297393, 24.292697598857266, 26.629535921158332, 25.587356282818703, 26.407096347501202, 30.9455688922636, 27.526515299274077, 25.044649301036713, 18.216630451140865, 13.909811127570368, 8.9077026613297, 6.8471487395225035, 5.804302298253583, 8.048595728412751, 11.518603851718288, 12.738578646413742, 8.026298034575678, 0.2870696927270582, 13.126136276029772, 84.52768125841695, 60.83147418114447, 79.84355541967577, 21.754886834852158, 50.8814134136323, 45.50216905532345, 71.30944282777848, 72.34294814448204, 52.789442539215095, 85.91176802112211, 42.527494507451216, 0.3064523300816936, 0.23910751716504175, 0.17903880817034554, 0.14892056704528872, 0.094235303451217, 0.20794139033363712, 0.2253413614967177, 0.3260746610260779, 0.1338216788586109, 0.17486574338568797, 0.14801669054694716, 0.1572200112164982, 0.1947217311469778, 0.18928417695626137, 0.11631300747995416, 0.15805376002625113, 0.17988852225244048, 0.1544866707896994, 0.11517311461390027, 0.19934030670312144, 0.09420449905578168, 0.21659078346865795], [0.03120951230577644, 0.06781764238351776, 0.0031571342814488397, 0.043285430949782176, 0.008316158294497479, 0.03583683467079555, 0.03231715095499831, 0.045987285162893035, 0.04981652585669391, 0.09730346260532256, 0.08188651769512123, 0.1088724934285687, 0.033246331337478854, 0.029255591648360415, 0.10002047003757569, 0.02207305579025659, 0.10899735809934717, 0.03305006344171782, 0.025881738514609398, 0.051171497907489545, 0.04252228097269132, 0.13692908469707737, 0.016046016094004436, 0.00921015896188516, 0.06273007163056923, 0.10611905085463678, 0.2668505792896594, 1.2282246423344458, 53.36900803350633, 68.53046709491362, 52.84543829579508, 73.843780332996, 55.46802128514936, 41.29458373592746, 26.827960783435454, 27.50988248855837, 39.80664045579972, 71.55078626448109, 66.1192370999244, 85.01153699813351, 2.5400793648535207, 0.6534411301535945, 4.065535948161156, 2.468801073489651, 2.2742882851631414, 0.5215912083944967, 2.6208664621076276, 4.53477620117126, 9.356884648722987, 11.869779536801001, 15.257270797606438, 11.949234008789064, 16.036507487297058, 11.576021467485736, 10.82865305485264, 10.322652593735727, 9.278901065549544, 11.099148527268442, 5.1655894229489, 5.588680784548483, 7.281070745760395, 10.025473237037659, 15.508004388501568, 12.690580602615112, 9.388987287398308, 7.13340086321677, 6.793599071041231, 1.9641545655265933, 0.5855254131940104, 0.737201567859419, 0.9585911107640114, 1.1287801784853781, 1.2146563058899296, 6.740292589510641, 29.76236435674852, 62.15655672934748, 71.6604478897587, 67.45711834199967, 62.54336910863077, 55.50161638567525, 51.28657464058169, 54.64692800275741, 60.26967310136365, 62.60476204656786, 61.251567871339866, 66.1699611909928, 57.5452849941869, 61.5378067570348, 43.84730146777245, 33.88629336510935, 74.08637108341341, 60.286143133717204, 62.87853956222535, 47.84546752129832, 50.863970633476015, 49.485179070503484, 50.6600191516261, 48.12361455732777, 51.284625222606046, 49.28155314537787, 52.76293516159058, 57.3232239292514, 63.19678498852638, 62.448534042604514, 54.75833508276171, 47.96730026122063, 27.813768117658555, 7.786416171058533, 11.279309853430718, 26.920689536679177, 33.58824814519575, 25.997696999580633, 19.36005823073849, 6.84344357059848, 2.7557168131874454, 4.816598988348439, 7.355843378651527, 10.16964779746148, 10.428151603667967, 10.187298463236901, 3.777685948917943, 1.8428534293367018, 4.298861815083412, 3.3071366048628286, 6.651551415843349, 9.389195173017441, 11.169455051422121, 14.82531782119505, 10.27134701128929, 15.556331911394674, 17.090763122804706, 21.305371445994226, 15.596217513084413, 10.798471396969212, 10.075023558831985, 11.297236065710745, 4.883860282359585, 2.6592897551675, 6.447335664303073, 6.712258919592827, 4.296371110023991, 1.2952618709494992, 6.542482068461757, 49.50806610045895, 72.97325734169253, 39.08133145301573, 24.817047888232818, 36.05472080169186, 38.68785888917985, 69.44677983560871, 27.298170597322528, 43.910961535669145, 21.156013473387688, 0.8531709159574202, 0.16979146808866533, 0.10880723039829925, 0.05723041835271063, 0.05700046174047936, 0.09651312033735937, 0.11818931002410189, 0.018355995266427918, 0.06396120556840493, 0.032124137017695654, 0.07616107532333943, 0.037839292743874174, 0.05650491393621891, 0.06186216296027265, 0.06155200460324846, 0.04602665059088219, 0.0028304315374923813, 0.03969980238546287, 0.1030620919059842, 0.03215346477865692, 0.06787087783337602, 0.013306942456702312, 0.05582407627615237, 0.039105685878424876, 0.03799624500736114, 0.07223473681557564, 0.012445625972994154, 0.1317936142966632, 0.0675883139633844, 0.017147008930483175, 0.03353721109188853, 0.04746793010722726, 0.043852221100561084, 0.027522834829024734, 0.013053875844625216, 0.06495038978755474, 0.04027723732794966, 0.019805876034942847, 0.09812404236365711, 0.0758689506760528, 0.026887845616006566, 0.029572336446313612, 0.04947701101041129, 0.09014544347601552, 0.12766767924110736, 0.04208665656586809, 0.041655142220758626, 0.08755884719111266, 0.06194189739143176, 0.01449221549856086, 1.1351459401269113, 71.10360468587568, 77.06803921730288, 60.06447430579894, 84.11229441242834, 52.19831389765586, 39.54336312509353, 28.387603029128048, 33.87687183195545, 55.03554467231997, 76.77759555078323, 72.83080470177435, 83.58745774915143, 3.031358680417461, 1.599238327433986, 7.920591629320576, 5.317403779875848, 4.866371414353771, 1.2256716696485397, 3.9622020865640337, 5.585919435947172, 11.138963526295079, 15.44110248165746, 18.070216217348655, 15.560831850574864, 18.572728710789836, 14.040997739761108, 14.9746738326165, 12.802353443637973, 17.743261168079993, 12.696807365263663, 9.799097564912612, 7.9195178804859045, 7.720150668774882, 10.01538097858429, 13.256619803367123, 11.267398595809938, 8.914541313725135, 6.188505811076011, 5.352980167635026, 3.0417409491154457, 2.395231137352605, 1.8694374157536415, 1.118619768850265, 1.3141227104971487, 1.5691972620064214, 7.662674707751121, 34.896731222829516, 68.66159977451449, 70.80985053893059, 68.1950181530368, 62.85449543306905, 61.57139793519051, 52.836816926156324, 58.38618232357887, 61.97979903990223, 65.79687710731261, 63.16697889758695, 68.30735483477193, 60.586706515281435, 64.6875209962168, 46.63168614910495, 38.562303819964015, 75.39831761390933, 65.20927859890845, 66.29960336992818, 52.96388603025868, 53.42415263575893, 53.260872210225756, 54.42005026725031, 51.89954303926038, 55.787996476696385, 51.85444362701909, 54.67279995641401, 62.80986278287826, 69.85756181901502, 69.53422515623032, 65.15739348626906, 59.56947119005265, 46.811687638682706, 12.103315495675611, 13.893393066621597, 28.140936936101607, 35.18387617603425, 27.669826938259988, 22.883958739619104, 9.547979581740595, 3.4049536528125888, 4.711212746558651, 6.008497457350455, 9.720501111399743, 8.156901194203286, 9.325004604554946, 7.489124046218011, 4.959840514967519, 2.9225381583936754, 5.241467673932353, 11.548507021319482, 13.034208666893745, 11.817846375126994, 14.30550669470141, 13.101318459356985, 16.28018375365965, 15.994547932378708, 18.935304764778383, 16.363247786798787, 11.762517421476304, 12.03035842987799, 7.936720415469139, 3.351102697272455, 4.261125672248102, 6.547927789149746, 7.351023766302294, 5.042376989318479, 0.8485360227284894, 4.883455787935565, 58.82743327848373, 75.50415100589876, 57.19273451835879, 28.257231289340606, 37.12301754182385, 39.51841292842742, 70.59583817758869, 37.522589391277684, 47.52323696690221, 35.89180515658471, 1.0908666709738395, 0.2860979255168669, 0.1568935658302038, 0.14058361520930646, 0.06507605885065372, 0.12528425713460292, 0.01598822337860662, 0.04086992508100887, 0.09170368929663975, 0.055814258859402714, 0.04282736399721715, 0.04872030383276363, 0.01741164634304662, 0.023746084564575748, 0.0520736736906392, 0.01622506807888708, 0.01901118430278955, 0.06003462191250536, 0.12008671829056357, 0.03339665310998117, 0.03116727979373067, 0.024701551338958166, 0.07625550332088625, 0.08934614564021749, 0.15515972499645528, 0.08872644945738778, 0.1256373470589038, 0.2502616500902561, 0.17777241886623446, 0.24848624132573607, 0.2418373948744228, 0.20589676295076648, 0.21772160585368835, 0.15504914786546461, 0.1666386792015645, 0.1766728375467562, 0.19087410051255457, 0.2737415401685623, 0.14234069915067765, 0.1972408274248723, 0.11796080131804752, 0.10456110380830304, 0.1768711930321109, 0.1468801837895186, 0.15081402995894033, 0.06590610745573236, 0.07860269712945146, 0.17477218872837483, 0.16493453193576108, 0.2629393940010379, 3.3789390229409744, 95.22396118410173, 87.86120953098421, 76.50634011914654, 89.63368154341175, 81.0863740982548, 58.93811079763598, 38.20323044253934, 42.15440650140086, 53.2477597267397, 89.3396528305546, 80.90413293530865, 98.20880643783077, 3.638493779205507, 3.0914694936044755, 13.669650285474717, 10.418422164455539, 4.450953189403781, 1.6927871011918592, 3.2396500197149094, 5.850867206050504, 11.157301587443198, 16.521148681640625, 20.88459526338885, 17.883085819982714, 21.65871031822697, 19.14664206966277, 19.51315422211924, 19.92168672623173, 25.095496946765532, 18.89482786578517, 16.717039692786432, 16.076830433261012, 16.03254883520065, 19.354408056505267, 21.22360375619704, 17.45000123977661, 15.815977127321306, 12.588762737089588, 11.130425507022489, 7.593489491170453, 5.3665868697627905, 2.62656468537546, 0.884799499425196, 1.5736707251879478, 1.8723989278078081, 10.934990471409215, 37.175506699469786, 72.34172436498827, 75.39121812389743, 71.969389454011, 65.88968430795978, 65.31115431939402, 57.03491403210548, 59.38078165054322, 63.805003396926395, 64.57369773618638, 65.58419442945912, 68.61246032099571, 59.61471965236049, 62.65900842605099, 47.78817738256147, 40.13593519887617, 76.72097221497567, 64.71900586158999, 67.35724695267217, 51.783990013983946, 52.659282607416955, 53.747261801073634, 55.47822729233773, 50.26806846741707, 56.166791531347464, 53.044686855808386, 58.060656978238015, 65.82130955111596, 72.03404580393146, 73.10704154352989, 70.45034962315714, 69.34509631126159, 60.85205093506844, 32.61735954592305, 24.58296868108934, 32.69832511102, 35.76276310028569, 30.788752532774406, 26.680350226740686, 15.666584833975762, 11.722211145585584, 9.728562562696396, 13.624634223599589, 15.665517949288892, 17.89174641332319, 18.233002424240112, 17.495863553016417, 11.515362012770868, 9.289900372105262, 10.469583599798142, 22.184474622049642, 21.09635422306676, 23.273854101857832, 26.080115802826423, 26.72651848485393, 27.841548304403982, 28.240008161913966, 27.338284677074803, 23.166279177511893, 15.319377606914891, 19.408119032459876, 16.87138888143724, 10.33176524023856, 6.1353071947251605, 13.816631301756829, 15.094065877699084, 13.095349592547263, 1.3144232621116023, 8.562758641858256, 65.56435115875738, 87.73218708653604, 47.122755127568404, 32.16900713982121, 52.15934122762373, 56.19621323001001, 92.63453006744386, 50.25166903772662, 66.79928195091986, 65.48815911816013, 3.3363918479411834, 0.8150634962704875, 0.5133211666778211, 0.2684440728156798, 0.26027855613539297, 0.4041139234698588, 0.17405008957270654, 0.2500071097165346, 0.17737658123575872, 0.11191777719725525, 0.12221150145295168, 0.2827165666366777, 0.14706997441187983, 0.11170423018836206, 0.25252053694378945, 0.12232937940186071, 0.14460971368657005, 0.11940976469627312, 0.27808164276423, 0.15887459259360068, 0.11180638801306488, 0.103159990281828, 0.19815807981837183], [0.01194142712084877, 0.061369281141988696, 0.012657498122162878, 0.02520403032371354, 0.02447770427792303, 0.025778123207630652, 0.06306339265598405, 0.03910907581748982, 0.042616394874189174, 0.04502733102849415, 0.061731862895671404, 0.054937689565122134, 0.04211521632368526, 0.021963863363189083, 0.027415034766759605, 0.05683007612524014, 0.0680215903107197, 0.011466131808476583, 0.04410772291462749, 0.056811295479776404, 0.010094368067990628, 0.021553224914016265, 0.018213409066741026, 0.010302362854652589, 0.04177429953650121, 0.08637819844748705, 0.17237341421986782, 0.2150614574671753, 15.588563988285681, 92.4097547223491, 52.95500970655873, 62.711532885028475, 67.9272065624114, 47.30922852793048, 32.42774432705295, 26.063847772536743, 34.304610221616684, 76.81184568712789, 88.87841347725161, 63.50091380457725, 0.6796065874157414, 0.5694655136715981, 2.4638181924819946, 7.842912029835486, 4.587695838943604, 0.5726451462795658, 3.7026924375564825, 7.865823084308256, 13.127959197567357, 16.662648185606926, 18.335756755644276, 20.937386443538053, 18.510743494956724, 15.23985351285627, 15.291102220935208, 10.447322187885161, 12.501188958844832, 8.784045038684722, 6.113616977968524, 4.565473160436077, 8.50161869679728, 10.25720980859572, 15.914452152867472, 14.165608498357958, 14.436059844109321, 9.661958755985383, 7.13622251825948, 5.433506427272674, 2.7872188389301304, 1.2056512794186993, 0.1017482357940847, 0.31266809170765264, 0.14553183839926798, 7.621973253065541, 30.875760509121804, 49.374089702483154, 69.77327008401194, 69.9326987420359, 69.60944052665465, 62.1211612609125, 56.222304836396255, 56.04253084428849, 61.97951662924982, 63.01763465327602, 62.86665085823306, 67.76071763807728, 53.292945431124785, 64.59060315162905, 41.24879790890602, 21.922693675564183, 69.72460131491385, 61.55946608512633, 66.45453699173467, 59.597421999900575, 57.13458145818403, 49.462499926167155, 50.75029250114195, 48.26474535849787, 50.294403260754, 56.31490415142429, 63.15165027495354, 67.30411452631797, 66.09527141817155, 67.46301758673884, 61.63688190521733, 55.838983366566325, 27.897396972102506, 17.051253088058964, 25.708667347508094, 36.7603002825091, 36.98139252201204, 26.442517311342304, 20.47730811180607, 8.418575256101548, 0.9029571315453899, 4.665887798032453, 9.59250436675164, 11.685105523755475, 9.895844786397873, 10.25033683546128, 7.3315565528408175, 3.1705084395024086, 3.0412577621398436, 2.556164759782053, 8.836385146264108, 6.867290110357347, 9.993006798528857, 12.33708679676056, 10.998924124625422, 13.358071907874077, 16.882128330969042, 20.035329557234242, 16.034079540160395, 15.666551493829298, 12.58405295110518, 6.8538099046676395, 1.7043095538693092, 2.9886325472785584, 4.63481919419381, 5.166393999130496, 3.114576666585861, 0.57361384913806, 3.2303785172200974, 56.130262497932684, 78.20105506527808, 25.89045547669934, 26.108976602554325, 36.5913284978559, 67.57198103012578, 35.01017793532341, 25.03961297773546, 30.31950369957955, 4.331139979823943, 0.27507799587422804, 0.06781805607099688, 0.02684864106648151, 0.024930598221779354, 0.10141291910962713, 0.020993842833465146, 0.020321321057816668, 0.03178603177319371, 0.03457467034158688, 0.02785739500165707, 0.037532796287128044, 0.03605299786995015, 0.01774635207238457, 0.03841276318135281, 0.05503960607212879, 0.026894533563585534, 0.09185753507359375, 0.07182095740591327, 0.057074278142423406, 0.04824285102527469, 0.033420593357614936, 0.051891601404115084, 0.10738984516431248, 0.04060048046672056, 0.009584653382790426, 0.02980699300796034, 0.02083722573344506, 0.0232783668193846, 0.03680940244286772, 0.07438506134935925, 0.04516007874401347, 0.05280103203990767, 0.10872001894899916, 0.03989255776809108, 0.021640434448096543, 0.053726814822444034, 0.007230320113575868, 0.036012038979078495, 0.07857111132433338, 0.08632601253808507, 0.04695049900140974, 0.09126252224368435, 0.019883218356558395, 0.0413860883113117, 0.0554408829268669, 0.01565781444491398, 0.012344875834852219, 0.060847410556649974, 0.048220439123049866, 0.1109960585111572, 0.35450265172027773, 25.33500667541258, 107.7934003645374, 59.74602491624894, 72.9579444085398, 67.2211956208752, 49.69807355634628, 31.859241877832723, 22.04050990843004, 46.41515170374225, 79.00835729414418, 91.91489281192904, 70.62033730168497, 0.6613627244387904, 0.4468294539518895, 6.7878552502201455, 7.842659036959372, 5.6723709260263755, 1.9316435100570803, 4.275104999542236, 10.182552395328399, 13.120226244772635, 18.596502196404245, 20.156158170392438, 24.174051784699966, 21.94384897908857, 17.708446210430516, 18.337739513766383, 14.780628296636767, 19.495744782109416, 12.354820812902144, 11.719413515060179, 6.916391320766942, 7.329456123613543, 9.160671022630508, 13.347071620725817, 13.498340768198814, 11.53182420038408, 8.797847859321102, 8.912707605669576, 4.2484573971840645, 2.8920061838242317, 0.9920069467156165, 0.1650801499284083, 0.8625215400130519, 2.9979114042174433, 8.417930026208202, 32.3857416260627, 55.3004184076863, 73.3832077826223, 74.12817570470995, 70.53038166415307, 64.306478423457, 58.87543132228237, 59.44109593668292, 64.53163423845845, 68.95875853876915, 64.27995927872198, 69.07300149240803, 55.53845920870381, 66.30485934595909, 44.38630180974161, 26.67858712134823, 76.57498944190242, 64.42262372662945, 69.47855103400447, 61.22512325163811, 59.468077921098285, 52.77988764547533, 54.87741824119322, 52.79804429700298, 54.5043263127727, 57.76956219826975, 65.6759504349001, 74.1510509675549, 72.48386321529266, 72.3543151732414, 66.46036563381072, 67.08400680172828, 42.53244453860868, 22.02266900770126, 29.30079552435106, 40.35117133971184, 40.824797538019, 29.461716644225586, 21.596242650862663, 10.899239047881096, 2.359831746547453, 4.052990002016868, 5.9489803929482745, 11.385913010566465, 7.750073450226938, 9.288271607891206, 9.869300146256725, 6.324717960050029, 4.432849489873456, 3.288941465077862, 13.965817670668326, 10.59044849488043, 11.621846518208905, 13.944555482556744, 12.204679346853688, 14.440965748602345, 15.340144595792218, 18.57322096824646, 16.471507164739794, 13.087489162721942, 10.326527895465976, 6.275722653635087, 2.0982939870126787, 5.119330460025418, 8.157233124779117, 4.305872561470155, 5.096517464806957, 0.494830470171667, 2.5520516643601083, 65.22394434098275, 87.97378155492967, 37.86112916085028, 20.933481724031513, 35.58052585970971, 63.64781048990066, 52.7679479506708, 28.118785350553452, 51.566843678874356, 5.995259458018888, 0.45434833113704964, 0.1689071574759099, 0.12288945862242293, 0.06170632918515514, 0.11275580077762566, 0.025695663418680913, 0.012245511358243324, 0.02225192965969684, 0.0794507488007507, 0.01490959935190697, 0.043009976375727885, 0.023672067064551577, 0.024405201716769128, 0.05754318906955662, 0.07983019214964683, 0.04098430200810394, 0.0788343467959954, 0.052079423180510925, 0.07655394053266895, 0.04831092559822625, 0.0364359001058244, 0.013209116859211317, 0.07131755336998932, 0.10832397447478388, 0.10454965079383505, 0.13232708728361514, 0.14599205805890023, 0.14636168016060708, 0.10849332587132532, 0.20377753392582942, 0.14113866123220614, 0.1570481470515651, 0.18573804788531798, 0.16975938432639645, 0.13714332884598163, 0.1532487646346131, 0.14808101128906975, 0.11004366566457095, 0.24206636323323175, 0.18142788400573118, 0.13327928860822033, 0.19094874811989648, 0.15420315697068168, 0.11578593898804919, 0.2541291683671936, 0.1345694266379841, 0.08177498295422524, 0.09484985918407479, 0.1629286839236175, 0.31395603872595296, 0.4479215276097098, 39.00056592879757, 121.15904931099185, 71.60173000827913, 81.62513517564344, 86.56624686333441, 70.2539094801872, 48.084206504206506, 38.40318502918367, 48.06722656373055, 93.20044963590561, 106.43274584124165, 79.11139011383057, 1.329542405662998, 2.572079776756225, 11.02491080760956, 16.764808277929983, 11.107197230862035, 1.6696589680448657, 3.8289299991823014, 9.568336682934916, 14.799592956419914, 20.725609833194365, 24.7668238993614, 29.299971826614875, 27.14340367624837, 23.052563782661196, 25.529960240087203, 20.612343549728394, 26.337423286130353, 18.18268233729947, 19.392098111491052, 13.797990237512897, 16.083498462553948, 18.82887713370785, 23.140193454680904, 19.60071917503111, 20.44340902759183, 15.156719857646575, 15.205408238595533, 11.81787677349583, 8.258898508164192, 3.7735556931264944, 0.12868504400455183, 1.6717882021780939, 3.3168775660376397, 13.341717585440605, 38.26567457568261, 57.65295405541697, 77.93620878650297, 77.79569379744991, 76.32616996765137, 67.85525460397044, 62.26737153145575, 62.3732598366276, 66.47316040531283, 69.36176638449393, 67.21586119744086, 70.77832252748551, 57.15208699626308, 65.33941499648556, 44.308560432926306, 28.66812506029683, 74.62341416266658, 66.63192226040748, 68.74695839420443, 62.1340540916689, 61.40889021658129, 53.9682638260626, 56.88763687687536, 52.38056290534235, 54.34260699056811, 59.42732057263775, 66.03088963416316, 72.35354638868763, 73.27253418584024, 73.9245262453633, 71.51995643492668, 73.84858131408691, 59.4486504216348, 39.62045338846023, 37.407558041234175, 39.41931032365368, 39.80431841265771, 30.912519001191665, 25.908527797268285, 15.94594878535117, 8.930504379733916, 10.364465059772616, 15.949744659085429, 17.241546876968876, 18.134339124925678, 21.584442200199252, 21.582337848601803, 14.316766838873587, 11.646401536080146, 10.326689693235583, 23.279135573294855, 19.542558270116007, 23.94564824719583, 26.922636993469734, 26.52397317271079, 25.749697300695605, 26.870451819512155, 26.321474929009717, 22.389365511555827, 21.030650600310295, 16.25005995073626, 11.268006563186647, 4.332850623515345, 8.029669802035055, 15.958011054223585, 12.471868261214226, 8.71628511336542, 0.9189540892839433, 3.6588138630313263, 74.21166727619787, 92.06937928353587, 32.390885814543694, 34.38829791161322, 57.80926442915394, 87.44673267487558, 66.2783048998925, 43.271093522348714, 79.95059690167828, 26.43399988451312, 1.0787306125125578, 0.4296377667736623, 0.2233932611923064, 0.18849515235952793, 0.21443009376525882, 0.1372937272272764, 0.05733344568720749, 0.1431416287537544, 0.1653417536327916, 0.1668358855550328, 0.2940698058134125, 0.15627969957647786, 0.09386539023609893, 0.15379446438483654, 0.16986914940418738, 0.12631804682314396, 0.2029796533526913, 0.21787339851500528, 0.19145822723305997, 0.11234662555638822, 0.24244188421195556, 0.24627646070814904, 0.25029149687578606], [0.08225484510823604, 0.010402989461116735, 0.041794903471224734, 0.07418238512811161, 0.05675176278718057, 0.05345566183208458, 0.027462744807463982, 0.008716834727824937, 0.0229247348878773, 0.05767577973705146, 0.0674505943372365, 0.023316627165542978, 0.11862301538067481, 0.030560329398741166, 0.04331009132006476, 0.09612728781517475, 0.07546819476110321, 0.10016378210557085, 0.039933585606875925, 0.11702875576673016, 0.021846471880111965, 0.02107207190185305, 0.007482372137958245, 0.05568239980587556, 0.026535309190230987, 0.0961202627889091, 0.07843005155483562, 0.315883148221239, 1.9806732597850987, 81.65563552610337, 76.10912169179609, 45.9417216239437, 70.522003481465, 60.29953802785566, 42.90177491403396, 33.9948881057001, 27.404745317274525, 65.01101847617858, 105.72798221342026, 40.72479278810563, 0.054617663995633205, 0.572369170765723, 5.378883500253001, 3.3191030208141576, 4.293641630680331, 0.7635801814256177, 5.865175522142842, 14.222801558433043, 18.971569038206532, 21.971874313969767, 23.267201762045584, 24.481420478513165, 22.647149562835697, 18.840689351481778, 14.235342356466479, 15.539650071051815, 16.814506669198316, 8.808899137281603, 3.405840108471532, 9.945232329830047, 10.181424713903859, 10.751895212358045, 14.35129056053777, 15.362216753344383, 13.539178525247882, 11.41150059238557, 8.841461673859628, 7.055495237150501, 5.740293629707829, 1.3166635483503342, 0.15889840260628732, 0.08719317810309511, 1.7505807741995782, 6.523811586441533, 33.51522145732757, 42.21889811177408, 57.63214195928266, 70.57843854350429, 65.75400167895903, 60.99748849868775, 57.57798971668367, 56.36328658749981, 60.026046845220755, 63.864905834198005, 67.03255314980784, 61.730414744346376, 58.675115877582186, 60.599344391976636, 49.07607978390109, 17.01625377901139, 59.47484008727535, 60.043893629504794, 64.95447751014464, 63.025863785897535, 64.18146856369512, 51.45212611844463, 48.2892523273345, 48.21860259579074, 52.272391780730224, 61.26306041594475, 67.66846349162441, 69.62189012958159, 68.0127142321679, 69.15060166389712, 61.55321774944183, 53.151343945534, 34.84976868475638, 35.341900625536525, 42.76859867957331, 42.83649098488593, 38.794892526442005, 30.870033848670225, 21.672322903909993, 11.948717236518862, 3.7730379402637486, 4.115751847144097, 8.425858116918995, 12.437322966514095, 10.610160366181406, 8.3225134688039, 7.129015163067849, 2.025810057117093, 4.980723704061201, 2.8231810898550096, 4.974596471555772, 7.953748895275978, 8.193662628050774, 6.8832865165125945, 8.483276713278986, 15.73244829331675, 16.665650759973836, 19.515244845421083, 18.370459925743845, 14.733078383630323, 11.112264933124667, 6.65780024182412, 1.318659176749568, 5.094678853788684, 3.8760018733239945, 5.368952058976697, 2.0166167568775917, 0.29480399383652595, 0.44478378468944185, 65.33898745813678, 66.25847339630127, 25.963821449587424, 49.78374204327984, 59.70893106152935, 61.479288916434015, 22.232241246008105, 36.44793056672619, 19.26461127496535, 1.0384408841210029, 0.011150786078595107, 0.05517513085637362, 0.018175359394761826, 0.06089638655764922, 0.06281653231370353, 0.0404660243751301, 0.030497604034720894, 0.05719112570307428, 0.08768775680613133, 0.08469427590288463, 0.06842095194564712, 0.04526923478190457, 0.05337966974043558, 0.0011147041345060233, 0.021431985754339446, 0.09175481800470622, 0.06049612859985041, 0.013184453616099013, 0.05014512778049515, 0.049281976516208345, 0.07450025799053331, 0.0992750664872508, 0.09093073722455772, 0.04098353592017966, 0.0887842967565502, 0.07168067904609828, 0.06416604598803867, 0.09416195819334638, 0.06589207272495955, 0.034288931037149126, 0.03966617112558696, 0.03439150637977066, 0.022617683017386064, 0.05509019851864827, 0.08277969194516059, 0.07516335305427352, 0.08366013381389842, 0.05178992238436496, 0.06412777223534162, 0.012459108162851585, 0.0160406764611722, 0.01475666521958286, 0.033557891635404485, 0.01191706169441703, 0.09186262189741097, 0.042645736041689114, 0.032011612108157526, 0.05898245377466083, 0.02070700036241643, 0.08676778480050065, 0.01893981172132396, 1.9627570985786378, 98.3712710103681, 82.82348986594909, 52.081886183831, 79.95189128383514, 56.82810314239995, 46.8425331577178, 28.169066213792373, 36.64822639957551, 76.13247548380207, 108.7718120698006, 44.5665817876016, 0.06918317878678923, 2.128858075987908, 6.5551876060424314, 7.786544138385405, 4.274831904518989, 2.3779484389289736, 5.9452315876560835, 15.635587323096493, 18.20347286039783, 23.215010704532748, 21.98200579612486, 27.235573491742535, 25.49753792824284, 24.213249991017005, 18.98116707801819, 17.807691981715543, 24.771444451424387, 13.773174382025196, 5.032516150705276, 9.755197417351509, 8.440905309492543, 9.958006508888738, 13.33590071047506, 14.471446487211413, 10.68383816749819, 10.485042641239783, 8.297580922803572, 5.671074092388154, 4.783319148325152, 1.0333684014697229, 0.14864742605676576, 0.3939902247680772, 2.164075812024455, 13.671694820927037, 42.91243199379214, 45.85892431197628, 61.77008559626918, 67.92435892166631, 70.03828110233431, 63.01785822837584, 61.19761566961966, 57.80298079213789, 62.304998828518784, 66.73766151551278, 69.64323566805932, 64.60358227452924, 61.02949503929385, 63.42054443974649, 52.30820302040347, 19.816171046226255, 67.31067272924608, 64.4134493027964, 67.49206666023501, 67.02491237271217, 70.59188442845499, 57.339650815533055, 53.74350809281873, 54.43517100426459, 56.240273214155636, 65.61929964250135, 72.75343987249559, 73.91170793964018, 71.16175774605044, 75.22120691114857, 67.61627243411156, 66.33877215846893, 45.252757303176395, 43.99609658025926, 47.53156023640787, 49.12241474274666, 40.272504283535866, 34.75752630541402, 23.30338170451503, 13.535574847652068, 3.9943738570136413, 4.569924560285384, 4.771286297229029, 9.30861400019738, 7.855316035209164, 4.997041254274307, 7.238765531970609, 3.6870858169371084, 5.194821867250628, 6.237272149132145, 10.102848852834395, 10.541391411135274, 10.35477484426191, 10.551000237464905, 11.5624108429878, 16.26680749077951, 16.249625548239678, 19.779361563344157, 16.283267717207632, 13.322050821396614, 8.207115377149275, 4.591780006885529, 2.3017990541073585, 6.184579518533522, 6.320659287514226, 5.641070902347566, 3.147824392203362, 0.35436849440297774, 0.7010787449056103, 65.75313483515095, 87.4111803116337, 23.470508014002156, 36.84216407037551, 57.68973019815261, 68.5589905708067, 33.046725719205796, 44.79653073895363, 22.216875360858058, 1.0305781253883917, 0.19578121542449922, 0.030259653294999755, 0.0556816911745456, 0.0661831631535484, 0.03310247151661785, 0.054624382586729144, 0.059542081003347715, 0.03694555541921047, 0.0819880626494846, 0.044628873377317385, 0.037406606284240564, 0.038199434507518046, 0.03542161501583553, 0.046001898290048686, 0.026933180784145673, 0.05934704267870515, 0.026333402887347247, 0.05469119694504527, 0.046860579431297324, 0.08248248047405675, 0.05823827213457516, 0.04113799456747309, 0.04289559561819319, 0.17865012580108258, 0.14074740480751763, 0.09911008179187776, 0.20878290727494225, 0.19458423368632796, 0.30172072591320165, 0.1353045339666067, 0.23240205681612416, 0.09123612285381363, 0.15360023045251447, 0.20388605794118297, 0.1860106066470185, 0.18972055595969, 0.2204440065449284, 0.13216600963665595, 0.29650639442186205, 0.20541691611851418, 0.1323455806461073, 0.17208082991982662, 0.19656336055167262, 0.2154782246197424, 0.19205148572162276, 0.13056241907179356, 0.12455032958138375, 0.19521454018690895, 0.21408953703939917, 0.24329778828447868, 0.4230061726224038, 4.3482900531061235, 110.65383588114094, 95.40256238752796, 65.15200022728213, 85.92432745041387, 83.59392965993574, 60.25965144557338, 48.707706466797866, 39.25194278840096, 85.41418398580244, 116.0546571977677, 51.65943514916205, 0.3477920892257845, 1.8321904660232606, 16.4907895365069, 13.615300943774562, 11.058168584300626, 2.8250704465373873, 7.7071945897994505, 16.134517711977807, 23.657465827080514, 29.467653151481386, 27.224539864447813, 33.862131564847886, 31.825413396281583, 29.519663779966294, 28.381892058157153, 24.1916867609947, 32.743230365937755, 18.406298622008293, 12.237523313491577, 19.47044941686815, 18.674371050250148, 19.88136083849015, 20.676525292858003, 22.5474742920168, 20.233575951668527, 18.31598016523546, 19.55211904741103, 12.31003519027464, 9.564499624313848, 3.8005293425052398, 0.35623014934601327, 0.36661208096531134, 4.04337112461367, 22.464435754283784, 53.141741983352176, 47.7062939828442, 62.60209483485069, 73.07723153022029, 75.02000501078945, 68.05691149926955, 66.73422551924183, 59.65426891080795, 66.19431910976287, 66.97932658656951, 70.73154434081047, 66.22758080882411, 64.38350592890095, 62.44742793421592, 54.84430166982836, 23.547082485691195, 64.346290480706, 64.68286906519245, 69.85580459717782, 66.14162598886799, 70.1596627696868, 59.560037889788234, 54.3326049466287, 53.22281345244377, 58.75341423096196, 66.02854405680011, 73.12708485511043, 73.00635430120653, 71.60208302159464, 76.92468443224507, 69.68813896179199, 72.31479337138515, 61.64709575714604, 50.56605092940792, 50.51314207815355, 45.904717983738074, 41.31768257387223, 35.21796157283168, 27.136433624452163, 19.652816095659812, 11.481079516872285, 11.090342806231591, 15.163488887971448, 17.63700023774178, 16.537020552542902, 17.004010100518506, 19.35800486995328, 12.994618223559472, 11.395295320018647, 12.917127878435197, 18.98111608720595, 23.00716430910172, 21.00656528626719, 23.087463071269376, 23.140975967530284, 27.61648662628666, 25.54559284640897, 28.390060394041, 23.909089796004757, 22.51467739382098, 15.864901831073148, 13.160892398126665, 4.5964098745776765, 12.296696189911136, 11.516920174321822, 13.688779684805102, 5.305871030976696, 1.2491096700391462, 0.6772499783865867, 73.66684221452283, 80.54548709623276, 35.105036535570704, 69.24015721967145, 80.1271741620956, 88.84759149243756, 46.64757174830283, 66.16865896409558, 49.67159363531297, 2.5627781210407137, 0.4745719491714432, 0.19362003542482856, 0.1060524395096206, 0.34811013828842874, 0.21677841372307272, 0.16027175310638644, 0.11568545123502133, 0.15060235986546164, 0.2186380615157466, 0.2779614588906688, 0.16231782073455472, 0.09603066880616451, 0.11071420710293517, 0.15379565948199841, 0.12572402224665688, 0.12045883783890356, 0.14567547988507057, 0.10584054725064386, 0.24094372266723266, 0.19674302349167486, 0.19458328373730185, 0.17706525842508963, 0.20064498508168807], [0.062071266659205, 0.04825145802310398, 0.04468094054309111, 0.04415339324623347, 0.03766933996831218, 0.1062164512733298, 0.1904164702301064, 0.05864414551685895, 0.04990607004372343, 0.08971975906000984, 0.041591311774907574, 0.02458009767466255, 0.023709641762017727, 0.08553276679688886, 0.0213369429712334, 0.029647510739103444, 0.07578849612224488, 0.05943171837697587, 0.03743300950455089, 0.018448615296473427, 0.026671322355527553, 0.06979462420267445, 0.07882418847011943, 0.07386063586079306, 0.08634267495043817, 0.07276864647264443, 0.025910311678965247, 0.1393323025155452, 0.027215024531488458, 39.00875976008754, 88.84199819257184, 62.946294584581935, 39.85444630345991, 70.78191541856336, 47.30557287892988, 35.24906204592797, 26.10262432406026, 40.78413824881277, 101.68553260064895, 21.789652762874482, 0.36948656543127956, 0.8974731677482206, 5.601657455967319, 4.842229225943166, 3.1841296053701833, 3.062996763375498, 7.792341891796359, 17.236396804932628, 24.245389892208962, 24.577085125830866, 30.716992770471883, 25.33847797301508, 28.264852454585416, 19.597883301396525, 18.311230174956783, 14.197960207539221, 22.778476399760095, 10.810885698564592, 1.9835064367901896, 10.918973472810562, 8.28438901132153, 10.88592162055354, 12.410070338556844, 18.185957516393355, 14.568109377737969, 10.933650981995369, 8.752842583963949, 7.620336644111141, 4.740131891542866, 0.6350102804360852, 0.4075905224007945, 0.16834452718255982, 1.1426917223199722, 6.256263284913956, 15.130574318670458, 22.58937305019748, 47.432873402872396, 63.910942692910474, 65.40349475799069, 67.5114353241459, 61.17568962035641, 57.06270402477634, 59.704141847548954, 65.37037426425566, 70.97406448856478, 61.07991710785897, 63.64784186886203, 57.98904626600204, 53.04709911346436, 17.128276671132735, 54.6014638100901, 58.2213996302697, 59.32778258477489, 60.93009825675719, 63.42656920033117, 56.01103028943462, 47.6778450319844, 50.844966749991144, 58.08569346704791, 62.81327132255801, 68.91142337552964, 72.11183424918883, 68.3538035423525, 71.25383930821573, 63.54381668952204, 58.76758967676471, 45.51048448008876, 43.92634507148497, 49.67551600548529, 47.93358748958957, 36.01310053179341, 28.61706952894888, 20.323625726084558, 14.274348366645075, 5.209693533758964, 3.9658881339334675, 4.54239099256454, 11.48698954812942, 10.430504045178814, 9.356987610940012, 8.12348505181651, 0.5163826072408307, 4.038427467307737, 4.905326433720128, 5.778927014720056, 10.120611306159727, 7.9684018896472075, 9.277122270676399, 12.763299384424764, 16.052801993585405, 17.74737181202058, 19.789606794234246, 19.781454147831088, 15.333022552151835, 9.484414631320584, 4.290816053267449, 1.4377509153658345, 4.049503750378086, 4.95231544779193, 1.493496498273265, 2.5360155442068657, 0.5185362949006019, 0.4645934394530712, 72.07271252909015, 29.470944020055956, 39.626125135729396, 53.115681755927305, 60.756819709654785, 39.33574030476232, 26.948330479283488, 15.23893960060612, 9.81182957849195, 0.3885886307445265, 0.05449295637287921, 0.02942406970466818, 0.09841933861495027, 0.04157102576667263, 0.02419803047462577, 0.028952734109254617, 0.03826739799772059, 0.12579375923040415, 0.05580252622284236, 0.037162369793100704, 0.06818413884649355, 0.019486382896561297, 0.07011229022135658, 0.04169984345114039, 0.04165294354841594, 0.036286355912565224, 0.09018690415447758, 0.036225769849073504, 0.11561229749913178, 0.03551519265578639, 0.035971995563276356, 0.03176350495778024, 0.06667621734161532, 0.013368704465157805, 0.06903973648384695, 0.00890027352368399, 0.011693606295833185, 0.03394833217645365, 0.10942403076877517, 0.05148690779723468, 0.07937020997727111, 0.08693661525725357, 0.10447151748643768, 0.015035563358856786, 0.015215391965372669, 0.016592165920883417, 0.09081338787631643, 0.019244069286111384, 0.0663586279317256, 0.03828240566015725, 0.036302577824361866, 0.064231573318642, 0.059577608330836224, 0.034469337082437934, 0.024538569963507117, 0.02861902429421823, 0.07950039895912332, 0.04120632194943967, 0.014451219260902896, 0.13502714885098321, 0.07376344994671884, 0.041139392677934906, 45.24721107175274, 103.38631937580725, 65.07114056617984, 48.73177020780502, 70.63311638370638, 50.485779623831476, 33.35019165469755, 28.018462888656128, 56.763101623904326, 103.96165263268256, 25.890514312251923, 0.6152211261853096, 2.642906014957736, 9.922189385660234, 8.394548777611025, 5.341141964158704, 3.7018025498236384, 7.581951839308585, 14.48059247386071, 24.332637133136874, 20.862424065989835, 28.966435040197066, 29.123961348687452, 30.35297524544501, 25.366868088322303, 22.23224909074845, 17.72744421036013, 23.698923318616806, 17.238324649872318, 2.377497856655429, 10.288388729095459, 8.22008567471658, 9.212816972886364, 12.05639414248928, 14.4577544735324, 11.974211662046372, 11.627170155125281, 8.242180385897237, 6.367205564052829, 3.710318505764008, 0.5287183388586968, 0.2634304870040186, 1.0722812553567271, 1.6030774698142083, 12.596534913586034, 22.342905036864742, 32.82402530793221, 50.65645763950963, 67.74025071051814, 69.04489378775321, 68.74658969140822, 63.9917278289795, 60.561568044847064, 62.29220405701668, 68.81724726769232, 72.32342258576425, 65.32591027598228, 66.04951304774131, 60.913102626800544, 59.59840651481383, 20.44234214290496, 58.81559164293351, 65.53078743719286, 64.56746901235273, 65.71446418762207, 68.94064503331339, 60.2414712598247, 52.62562474896831, 54.05008446785712, 62.110853272099654, 66.82961756183256, 71.93095807106265, 75.03553759667182, 71.97062892298545, 74.3666244322254, 71.68144041492094, 66.93760041267642, 56.97043418884278, 55.31393881767027, 55.68349276819537, 52.76011105506651, 42.56120727908227, 32.09858294456236, 23.16136052531581, 15.850773453712465, 6.889920225066524, 4.270209881567186, 2.8622258334390582, 6.054434785919805, 9.6160650637842, 5.120102676653094, 8.817832335349053, 1.450792060744378, 5.405665443789575, 9.168488306383933, 8.907454571416302, 11.661386951323479, 8.265453769314675, 9.812453235349349, 10.825135669400616, 14.217709341356832, 15.59009567383797, 18.10463305442564, 13.684685710937748, 11.93161472197502, 6.863668782095756, 4.858617378819374, 3.3570141994184066, 4.300211110422689, 5.353813671296643, 3.6702593391941445, 1.571558038553884, 0.2543020897334622, 0.4244420665406412, 78.67049217224121, 34.07069575402045, 28.079753844968735, 50.06115559608706, 63.87229950197282, 57.70667091492684, 32.12170923909834, 34.75479241340391, 2.5600633505851995, 0.8179297682739074, 0.02727855428782923, 0.03866207117455141, 0.07148712693202881, 0.013665580772794785, 0.06983200929337932, 0.051681068951203946, 0.03736504601434835, 0.11422204709942303, 0.05417612155959491, 0.05219816297833478, 0.044447965544438174, 0.07426997962137384, 0.05669147166753969, 0.0653278719513647, 0.04697949159890414, 0.05141762663580237, 0.043374151592293096, 0.023103214222036546, 0.05631428444758058, 0.05203575999926656, 0.030656086558836605, 0.06844167462399892, 0.029295575692348426, 0.16167611484566044, 0.13135349678416408, 0.07170425923240763, 0.190687864538162, 0.13456650018211336, 0.20729165584329637, 0.24993425475493555, 0.3286935785605062, 0.14248561234243456, 0.2557818651680024, 0.1000803704523752, 0.10421651745996169, 0.17890583062844892, 0.1679700021181376, 0.12842285807334608, 0.15053307487358972, 0.12631736500489135, 0.2527983051033751, 0.1395392688291688, 0.15488033273047017, 0.07219068675992951, 0.1257088996710316, 0.19466502531882257, 0.17187233143035444, 0.11178313724456296, 0.1037951461189697, 0.22452071279046998, 0.2847770367178225, 0.1453697648380072, 56.86701697687949, 119.0622914221979, 83.4535558762089, 64.25344013398694, 92.57156033669749, 67.55944513505506, 48.9061156395943, 36.82663540686331, 55.39626544521701, 122.28369482101934, 30.13909624468896, 0.9623136852056751, 3.715650477717, 17.447663507153912, 10.757090391651278, 10.498696411809615, 9.9447008486717, 10.57261053592928, 22.829898672719157, 31.6175611172953, 31.29477946988998, 40.17766921750961, 34.69818868944722, 39.55780136969782, 31.604976192597423, 32.266662390001365, 27.232633675298384, 34.2131797729, 24.303841052516816, 16.02263406399758, 24.087698844171342, 15.67480710244948, 18.99661925531203, 19.1264908929025, 24.93201844153866, 21.675405886865434, 19.559685299473426, 16.38350094518354, 12.656477555151909, 8.805778891809526, 2.1882412895079586, 0.6804576191690661, 1.5970425355818965, 3.9451454147215816, 18.295768191737515, 20.138089772193663, 33.64034506582445, 54.14558633681267, 74.89645819510184, 75.14452457427979, 78.81627098206552, 70.70709228515625, 62.98168613064674, 64.47606602022725, 71.18262475536716, 74.11433758274202, 67.15038899452456, 65.55884807340561, 60.139521014305856, 60.94727039337159, 23.90694622070559, 58.11812362363262, 63.605099801094305, 64.97969050561228, 64.24597978591919, 68.80333854306129, 61.99998747917914, 53.154779941804954, 54.57248533925703, 63.472810022292606, 67.70708314834103, 72.25869563318068, 74.83063297887003, 74.51494493792134, 76.17425657087757, 73.95265748423915, 73.34665913735667, 65.21129077480686, 61.32333547838273, 55.737507727838334, 50.67175488318167, 43.90961224032987, 33.97565672474523, 26.159163328909106, 18.882144881832986, 11.849700923888914, 10.00099568597732, 10.845983066866475, 17.458193109881496, 18.20551641525761, 19.339202988532282, 21.204239014656316, 10.667279881815757, 12.430533343745816, 14.73490228576045, 19.517919901878603, 22.28079430518612, 20.870200164856453, 22.062149624670706, 22.135507752818448, 24.610460573627105, 23.721261216748147, 24.188739099810203, 24.57189779127798, 21.550503892283288, 15.105179913582342, 7.023625979500433, 5.432469450658368, 8.418939055935029, 18.893329520379346, 7.666222491571981, 6.665640569502308, 1.039070914829931, 0.7016696744868833, 87.99592725692257, 37.165881203066924, 55.978380480120265, 72.83078116755333, 82.31060858695739, 75.43568995691116, 55.36526303137503, 67.82716258879631, 15.405339291018826, 1.6168278287495337, 0.2993262108535536, 0.15125494420288071, 0.2512162262874265, 0.2578079532231054, 0.17291680038455995, 0.17782651999544713, 0.1784925415150581, 0.1944664400070906, 0.16977332712661836, 0.2230791804651099, 0.17121787783840012, 0.09513082959118391, 0.16384772896285982, 0.1838783847708856, 0.21461680471416444, 0.1594480400484416, 0.19090593912668768, 0.2270542881301334, 0.2796874856275897, 0.14462832962313008, 0.14243256841455737, 0.13088773064796003, 0.15059224750486114], [0.03487764279388132, 0.10273687226036865, 0.0012269786290539009, 0.07204114639710996, 0.03580265565805378, 0.024616548138099815, 0.03874195116241613, 0.014836038631807654, 0.08922957770165899, 0.05439316575986244, 0.0782115249744346, 0.057848693442440806, 0.020549440974249475, 0.057530291979351354, 0.08939220284622523, 0.007475977697815266, 0.09181432771466433, 0.031348057391662756, 0.05347214038333586, 0.012850292766797207, 0.10858006234611235, 0.0770587618312528, 0.04250483332021583, 0.02449676071503951, 0.13027400229006045, 0.06633508604981246, 0.03736016220383106, 0.07348257147016064, 0.09646894770764536, 1.2970586842106235, 55.39872869368523, 74.80159959485455, 47.01744733318206, 55.89381417920513, 82.20777973051995, 34.74059343338013, 38.8623769052567, 23.17189208922848, 100.38812237401163, 12.494556230883445, 0.27813318515977553, 2.632662009808325, 4.447362749807296, 4.922296077974381, 2.3372219791335445, 1.8179327730209598, 9.023545941998883, 16.015265891628882, 24.30272121583262, 28.606641907845777, 30.588146832681474, 26.529815543082456, 29.48800829149062, 23.846965336030532, 20.872635956733458, 18.346166726081602, 22.27115704167274, 12.043443456772836, 2.330373765960817, 10.159357459314409, 12.257042988654106, 11.951212844540997, 13.486228489106702, 15.915554338885894, 12.58145438086602, 10.793336033821108, 8.756606098144285, 6.5663006613331465, 2.674177356304661, 0.7303038960502994, 0.7950720948077018, 1.0593362080474054, 2.6631755982675864, 7.177654024093383, 8.393832945054578, 7.712520678197184, 20.29034833754263, 41.490843449869466, 53.53564600790701, 58.64519211553759, 57.92952037626698, 58.91238789404593, 58.71810505467077, 64.08552346691009, 68.09171076743834, 61.80447693794005, 63.37686100313741, 56.33715967978201, 52.27669462080925, 15.132038343337276, 54.08613497211088, 57.01421568470617, 57.82229454286637, 59.026473952877915, 62.56625613858623, 55.53878476542812, 46.347632023596, 54.27942545183244, 60.22239285130655, 64.25365194197624, 65.68753319401895, 66.28983666819911, 70.08610263947519, 68.31239115807318, 64.02843336905202, 56.07261542351016, 44.39533895061862, 52.21870237781156, 57.86539354631978, 51.96752948145713, 42.47913560559673, 33.771599338900664, 19.293960409779704, 13.84117651370264, 8.436921161990012, 3.971078410263985, 4.246557499131849, 10.011909680981791, 10.037106986968748, 9.656443903523108, 8.01919952515633, 3.087079380789111, 4.525091869215812, 7.684164883628969, 8.788901913550593, 10.056376611032794, 9.093219983962275, 12.066932570549751, 13.358694584138933, 19.24221061891125, 20.275917937678678, 20.72819663632301, 17.25898181238482, 13.447594123501933, 8.243809150111291, 3.3354933800235873, 1.9409552168461586, 2.9667003693119174, 5.84023218962454, 2.2828878366178085, 2.4426690176610024, 0.09228941714090687, 1.4594656469360476, 44.97975249444285, 44.34957273544804, 50.39136817378383, 59.46316711364254, 59.750884732892445, 21.444764637177993, 20.94993998927455, 14.802807338776129, 0.0854613137761912, 0.147712875397936, 0.07604512025512035, 0.038046056044197855, 0.00873875058811879, 0.15674528185158007, 0.1456327475006542, 0.06654882458068671, 0.004103778835175739, 0.006826831658761348, 0.08799772364117446, 0.11197359436341833, 0.05688257613069108, 0.07324101628675576, 0.025514290187387698, 0.033540091582483826, 0.06822944528633548, 0.06021430783514535, 0.02707648710648139, 0.012043324475657317, 0.08560205178876078, 0.02159237966782624, 0.016029164074890075, 0.026204205989356966, 0.13291060113378111, 0.02873775643116284, 0.07137104928974183, 0.05696662363686389, 0.026913655118175575, 0.061633236736299536, 0.033866027520308574, 0.06726373783162526, 0.04458564303575024, 0.08691787674662568, 0.05368032094631946, 0.07467859559842656, 0.06894935343054033, 0.032309482414876266, 0.003831093668967726, 0.021254600010692112, 0.03329733747147745, 0.04091538856887529, 0.059353960452661406, 0.08064773053892198, 0.057385191096053015, 0.0044746850917656575, 0.08672827764624551, 0.023275208621916753, 0.03682506128004001, 0.034284342170482686, 0.056036941466792944, 0.07478240051216657, 0.13786176610137188, 0.07332677216899973, 2.26175582216632, 73.64221757458103, 94.40398185483872, 49.78583658895185, 66.09491840485605, 76.1720286646197, 39.136927127838135, 35.43627285188244, 40.6680674706736, 113.44986607951503, 11.235918633399471, 0.344300321753948, 3.987817615270615, 7.350290773376343, 7.609911474489397, 4.995867485000241, 1.5939693585518868, 5.871045349105712, 11.30058773102299, 23.588277178425944, 27.99274390743625, 28.23526405519055, 27.97134541696118, 30.477300651611824, 26.04249438931865, 24.01009867268224, 19.58996991957388, 22.42207415642277, 13.220556551410308, 1.3143635685405424, 5.280245206048412, 11.711371675614389, 10.00860998707433, 13.05574247913976, 9.894626890459369, 7.229755357388528, 8.855372359675746, 7.02302634716034, 4.14586829562341, 2.1752994291244017, 0.7711735836440518, 0.6376923849025081, 1.2885055883276848, 1.874389162948055, 10.970265326961394, 13.590714546941943, 23.003614564095777, 40.509442898534964, 56.318540188574026, 64.35935981812017, 65.3662596979449, 61.174763940995746, 59.97309484789449, 61.06281557390767, 69.66880952158283, 70.94257570082142, 67.57860983571699, 65.78107780025852, 61.3200249979573, 57.54730109245547, 18.931594202595374, 58.3639189504808, 62.65497622951385, 64.54635097134498, 66.66003780980265, 67.51511450736754, 58.54481866282802, 49.991333484649665, 58.122806933618364, 65.98710813829976, 69.6642360379619, 70.42907468734249, 71.85488762394075, 73.1442177680231, 71.90845935575425, 71.35979037131034, 67.64322696193572, 56.78988748981107, 57.64289709829516, 64.98931992438533, 58.93198405542682, 47.310232654694595, 38.124928166789395, 23.93448125931525, 15.422209405129957, 10.166766816569913, 3.0639842200663785, 3.7975919775424467, 1.2502863810908411, 6.363777902818496, 4.457184364718776, 8.352200908045615, 4.454743669879052, 5.263821261544382, 14.453816413879396, 12.365221958006583, 8.917158515222612, 8.109574856296662, 10.533888897588177, 12.516355783708635, 17.247049962320638, 18.583191633224487, 15.296360158151197, 10.404167290656797, 8.880247050716031, 6.03385312903312, 3.7175305187702183, 5.275554051322322, 4.987562356456634, 8.181328735043927, 3.2805304325396016, 1.3578750337323835, 0.21308040006026147, 1.8550556777946412, 52.01198170261999, 39.31232375483359, 56.97164227885585, 62.88570181015999, 73.77413472821637, 32.65089581089635, 31.96753263473511, 3.6350063018260466, 2.037594695725749, 0.16860671311376557, 0.07227103406142804, 0.051814950476851196, 0.01579376919600632, 0.09041558139987531, 0.018105934591843717, 0.0228970657072721, 0.058816576586856004, 0.03814032699372019, 0.10915897200785338, 0.04715628937006958, 0.06378289860402865, 0.04177517287673489, 0.08981265488170809, 0.07462835555235225, 0.030716538556941578, 0.0342286131044309, 0.038243817811411236, 0.04227972987498488, 0.033519119925556645, 0.004411337760111858, 0.0063701690411225205, 0.08029068760093182, 0.15543168620957484, 0.20796834130681333, 0.20933329548326232, 0.29934744681081465, 0.18298941634355054, 0.09256368427867852, 0.10962776419135833, 0.17369490056749315, 0.1121095902917366, 0.1965979724040916, 0.25922025163327495, 0.16294777483469056, 0.16612362296831223, 0.183594212116253, 0.15731782532267033, 0.20745020540010548, 0.1394875425725214, 0.24977637935549984, 0.13150568781120162, 0.14404745111542364, 0.1860612603805719, 0.18380456453850194, 0.16773593161375294, 0.10444257468465837, 0.14561915710087747, 0.16639587529484304, 0.14784148623866422, 0.11983691234021418, 0.3178488685479087, 0.2250933022268357, 3.2972149695119555, 96.37822843367054, 110.37858747666883, 74.24316390868157, 79.97253079568186, 102.24414871584986, 54.60992044018161, 55.45579917969243, 35.60558588274064, 122.27479888546853, 15.679079544159675, 0.3832159335574796, 5.690418241485473, 13.394593096548512, 18.85915587025304, 8.641767924831761, 5.98003673938013, 14.914021242049435, 18.976985831414503, 30.84439135366871, 37.56576684213454, 37.74101834143362, 37.20396741744011, 42.67788602459816, 35.94474538680046, 35.1717560522018, 31.099015935774776, 37.650482193116225, 28.305713745855517, 15.833513063769187, 21.26225479187504, 19.750271304961174, 20.571205731361143, 20.927819782687774, 24.82263138217311, 20.0927883578885, 17.92370588548722, 14.291082178392719, 11.521764301484632, 5.748129544719573, 1.7195033450280468, 1.2842277533585027, 2.4716805834924025, 4.954938042548395, 20.669070828345514, 20.433642325862763, 25.700606876803985, 45.05877256393433, 63.52089043586486, 72.0674643977996, 71.60209086633498, 65.25340134097685, 61.569248476336085, 64.2554993783274, 69.51893575729864, 72.34599190373575, 66.93687085182437, 68.2359520081551, 60.13796775571762, 59.53690767288209, 22.4683581244561, 59.995381755213586, 61.39629548595798, 66.09700510578772, 64.82611010151525, 67.8678689464446, 60.12195271830405, 52.104733990084746, 58.51240811809417, 67.23177033085977, 69.26620175761562, 69.62301977219121, 68.9594724101405, 72.48769144858085, 70.99853223369968, 71.31895065307617, 70.44577613953622, 64.01077878090643, 61.63030016806818, 64.02074160114412, 57.06023293156778, 47.32361185935236, 38.15584036611742, 25.372700652768536, 19.03678824824672, 17.40746509644293, 12.625588890044922, 13.839027054848211, 17.273692661716094, 15.930293625400914, 19.424685162882653, 20.884281473775065, 16.770509442975445, 12.341842670594493, 20.213289453137307, 23.65849348806566, 19.776233473131736, 19.366773328473492, 23.130807222858554, 23.28558591104323, 27.56417985885374, 28.011384971680183, 26.226830097936816, 23.06101452919745, 17.35818639878304, 13.96587258385074, 8.108588870494597, 5.6575541727004515, 10.670848258080023, 12.774979222205378, 7.386602115246558, 7.293779715414971, 0.38628776227274253, 2.496192455291748, 56.70939653150497, 58.24714606808078, 71.79090592168993, 76.43343894712388, 91.02613079932429, 49.493788673031716, 59.74410687723468, 32.768815986571774, 2.1832240877612947, 0.3790822456921301, 0.2032905624758813, 0.1627742099545656, 0.17429499256034053, 0.2108222026858599, 0.21486399064381279, 0.18722140861134376, 0.2015142956928861, 0.1327299422794773, 0.1720138738352445, 0.18384358905736478, 0.16524643697325261, 0.16997228016055402, 0.1804202025936496, 0.15160403514821685, 0.15015102682575104, 0.19078791562107303, 0.23741093884793021, 0.1565334891840335, 0.12723801882877467, 0.1643091743631709, 0.12529214017934379, 0.2302844365758281, 0.3284819850758199], [0.055486288958139, 0.060893073227376714, 0.08362637997995462, 0.0170368914522471, 0.026365358329888795, 0.05402278140067093, 0.0912930125430707, 0.054195001796488805, 0.2044358639226806, 0.10894646687853722, 0.08656277201108395, 0.043136668166205774, 0.025309848133474592, 0.12427269165674526, 0.052466925774370475, 0.007455001252838561, 0.04693224695661376, 0.09323977219361453, 0.0782427353964698, 0.014653015438647521, 0.03930260494892155, 0.10431669877781984, 0.0595935506205405, 0.031646239879210634, 0.04843422361919957, 0.017253623471685478, 0.30808596661494625, 0.13306515171162545, 0.3783316021004031, 0.038781128898863836, 4.60757980423589, 39.95486290224137, 59.26316938092632, 35.342186958559104, 72.53158277080905, 58.80375785212363, 35.53638350579047, 27.029592183328447, 58.3705359889615, 10.832442064439098, 1.0287609648319984, 4.108933296895796, 4.991924522384521, 9.995805409646804, 3.4425191725454027, 1.9060277362023632, 7.058727270172489, 15.630970693403675, 24.059253815681707, 22.092659781056067, 31.35209118166278, 29.270079443531653, 33.01866116062288, 27.792854039899765, 25.43567822825524, 18.05783525589974, 16.90562136711613, 19.35482578892862, 5.524802044514687, 9.625843532623785, 11.91154787617345, 12.309584117704823, 15.207463560565827, 16.10290340838894, 12.800890399563698, 10.246730216087835, 7.409519543570857, 5.259739545083815, 2.112235071197633, 0.4425327425762531, 1.3338261241874387, 3.6136725304588198, 5.287151519329318, 9.8744963061425, 14.863462871120824, 17.085658158025435, 12.666404093465498, 22.530631634496874, 37.162833521443034, 49.81416394633632, 59.495232489801225, 57.77527316924065, 63.1322306202304, 65.13371021516862, 67.1173155692316, 65.36480842098113, 59.97583266227477, 56.248976953568004, 51.71758820933681, 21.98061335471369, 52.81434174506895, 57.08918786817982, 58.782227962247795, 58.61140874124343, 57.86139272874402, 46.524974146196925, 49.52452044333182, 57.548246383667, 59.60463523864747, 62.42319553129135, 65.73007914327806, 67.21490413911881, 62.16558994785432, 65.58678711614301, 60.28586856780514, 45.54531512721893, 45.806058606793805, 58.349931778446326, 62.95253115315592, 53.826556436477176, 40.59030648200743, 31.26374959945679, 21.86909644834457, 13.88859502730831, 9.696087298854705, 7.716628870656414, 8.66950398491275, 10.267507991483136, 14.456237496868258, 11.348848573623165, 11.77923946611343, 9.513038127653061, 3.128441019404319, 10.284507543809953, 10.128528610352548, 10.6028716218087, 11.988722470498855, 11.38900972181751, 14.72519834195414, 19.59035627303585, 18.091449968276486, 20.275725741540235, 14.585779655364252, 11.009985208511354, 4.947178613755011, 4.468047368911005, 3.9728863777652865, 2.5839871120068336, 1.5149007497295257, 2.041108403955737, 0.5712981185605449, 0.23270452365038857, 0.640369157396978, 27.128265288568315, 49.9176949070346, 32.59307811337133, 62.61397569410263, 29.523335118447584, 18.878906965255737, 13.164259752919598, 3.3972138358700663, 1.4773922269382787, 0.12672730631405307, 0.07168597271365505, 0.03194811682577335, 0.006839399331159169, 0.09630655238945639, 0.036419494332925934, 0.04726431542827238, 0.03774104579802483, 0.09822683604133707, 0.1423971904742141, 0.07638714020891536, 0.1105181498813533, 0.04107015365133843, 0.049704010523254835, 0.0666781478831845, 0.020321035690064874, 0.04936435778114585, 0.05224998882641235, 0.05580667841939196, 0.027532996985340313, 0.014777795839754325, 0.04589682167035438, 0.1021533430884442, 0.023506678257798477, 0.0739561440423131, 0.05128007937943743, 0.10136202022793794, 0.06734265254870539, 0.08086610390173812, 0.04420384779692658, 0.018645923156591675, 0.11748558165685785, 0.08389919155067013, 0.043208952392301256, 0.046053406211637685, 0.03328296183157833, 0.039729032470213796, 0.13368798119406547, 0.07460578660210294, 0.017888614599923455, 0.07009807162948194, 0.09661345487280239, 0.06891422063833283, 0.026386739843855464, 0.09506591130048038, 0.11987893226286096, 0.1093264235063426, 0.09601251252235905, 0.0329553290090013, 0.03200417722485239, 0.20588006223401717, 0.06686481286681469, 0.40448526160851606, 0.01846774451194271, 11.08830709611216, 71.26213904350035, 67.120147520496, 43.687613933317124, 82.23096878297868, 55.67613832412228, 38.419431486437404, 31.97159032667837, 85.16788267320203, 8.115813876352004, 0.44036949413918686, 3.907496544622606, 5.4641876970568015, 8.223193172485598, 7.648389435583546, 2.7519635952288106, 0.4563964825243719, 10.793431151297785, 17.574401170976703, 21.237347741280836, 29.79795986606229, 29.246394211246123, 31.225524140942483, 27.34839850856412, 24.593055055987453, 19.96797069426506, 22.39067558319338, 14.972606743535689, 2.9679493990636643, 0.9397161139115211, 9.375230554611454, 9.289261025767173, 12.892281624578661, 5.234780523084826, 4.219726525968121, 7.748037740107506, 4.829650184800548, 1.9984658663311314, 0.5874804695767741, 0.24171310476958754, 1.9598069859127847, 3.3819616994550152, 6.350375163939692, 14.57948523183023, 20.86286141026405, 23.929590063710368, 28.086702323728993, 40.737246313402736, 56.99995394675963, 61.900833883593165, 66.16203800324472, 59.83266615098523, 64.61664376720306, 69.23024931261617, 70.04178770126836, 69.92184162139893, 64.75820602909212, 61.92945541874055, 57.71560215180921, 28.296594235204882, 58.5240497127656, 63.468056109643754, 65.6109881401062, 64.71603270499938, 62.360708252076186, 51.03750021226945, 54.2103172117664, 62.14997891456851, 65.32887558783254, 66.04085245440083, 69.91781726960214, 70.00771799395162, 67.31010790794127, 68.49263191223145, 68.45641274606028, 58.76403993175876, 56.106724354528616, 66.05276077024399, 66.40418944820281, 63.71191770799699, 49.50436730538645, 37.1644809169154, 26.54527556511664, 18.118112279522805, 11.077460761993162, 6.24728694077461, 9.158573535180862, 9.437111827634997, 4.911790499764105, 1.336944531048498, 5.228566508139334, 9.892261701245463, 5.965345011603448, 11.782840201931617, 6.124115692030999, 7.803742260702196, 7.193205241234073, 11.238075936994246, 13.373835913596617, 17.407882828866285, 14.669575210540527, 14.073073902437764, 11.11190897803153, 6.096289417436046, 3.110163264697598, 3.005697063861355, 5.588551836629068, 3.813391284596536, 2.322862181932696, 0.5116682553723936, 1.0960760688589466, 0.15483418359391152, 0.9439561960677948, 23.523299194151356, 62.06234139780845, 41.91247470917241, 69.25602712938863, 48.947516256763095, 25.95835758793739, 18.924420187550208, 3.3258004678833872, 2.16369999993232, 0.1678007886174225, 0.06761064542637718, 0.009388878656130646, 0.02990578962189536, 0.07867402757608122, 0.03266420793689547, 0.012490734187585693, 0.02652283153316427, 0.04972442293599729, 0.10230261532049026, 0.08262434463587501, 0.03033497505971501, 0.05063955326594653, 0.04314566586887644, 0.08521769015539078, 0.012192920379851376, 0.027321152606858846, 0.00930927062947904, 0.1303440380480982, 0.038597589553964716, 0.03248901895037101, 0.029683842458912445, 0.11036996549415974, 0.024036615748979875, 0.2163955689437928, 0.12204709898440108, 0.3020594593498015, 0.16978026788321235, 0.16514292317292384, 0.18354578003768, 0.2741754830123917, 0.2391320626221357, 0.23738663853897204, 0.18904558653312345, 0.15096038339599488, 0.15492686491099097, 0.11050098951184943, 0.16848948633959218, 0.18658641365266618, 0.10978195470787826, 0.16262912822346534, 0.31980622319444535, 0.1425304897730389, 0.19412094967499857, 0.14979516366316428, 0.18923626581747688, 0.13351763388322246, 0.25361644104123116, 0.1246848929252836, 0.13602153097669925, 0.4540448990320006, 0.2559904862315424, 0.5351973589389555, 0.09224418730985734, 20.64338910964228, 95.50810552412464, 86.91141543849822, 63.766509256055286, 100.9186621635191, 81.11437982128513, 54.263296665683875, 38.4530815001457, 82.85554347499725, 13.91408553046565, 1.0282976348553936, 8.31549144560291, 14.95239967300046, 21.293743579618393, 10.779925450201958, 6.056621997587143, 12.42621579477864, 18.580995105927993, 28.86628712377241, 31.461658670056252, 43.04444720668178, 41.27119072021977, 45.67557311827137, 40.937852013495664, 36.9773877820661, 29.26674739007027, 32.19205302576865, 36.21232163521552, 21.86781579448331, 22.06245556954415, 20.94244630106034, 18.712198388191965, 24.28786719999006, 25.145699362601004, 20.28292917436169, 14.85359811013745, 13.927877564584056, 8.825432908150459, 4.612378333845447, 0.3756014792428863, 1.9351025502527914, 5.521529807198433, 7.944724992398293, 20.868313504803567, 35.04269046168174, 36.22810917515909, 37.41491640767744, 50.38268404622232, 65.63179239150017, 71.97681842311736, 73.5086844044347, 64.00083557251962, 66.98491988643524, 70.6139438383041, 72.97837995713758, 70.77548273148076, 66.95347816713395, 63.82259130477906, 59.86294684871551, 32.38899327093555, 58.72919751751808, 66.95502358098184, 68.83724351083079, 65.77293888215097, 64.16310794891851, 52.83632662988479, 57.649149356349824, 62.51728926935504, 67.12038286270635, 66.55070566361951, 69.50116742041804, 69.89422029064548, 67.14066151649722, 70.42301854779645, 70.83223158313383, 67.85878473712553, 63.6132897100141, 66.35326923862581, 63.01116666486187, 58.783781220836026, 47.862600434211, 37.29307190064461, 28.93111017442519, 21.592612497268185, 14.278265833854677, 14.398696326440382, 17.568941231696837, 19.980628182811124, 23.130856252485707, 17.49483000847601, 23.906512798801547, 21.637384391600087, 13.878688100845585, 24.732469820207168, 21.15416015348127, 22.992608393392256, 20.611588493470226, 20.449588721798314, 21.646902022823213, 26.07662097100289, 24.447929320796845, 24.90908238195604, 20.024170414094005, 17.68378234678699, 6.331016305954226, 7.484644699481226, 11.39858618859322, 9.871672199618432, 4.5662306681756055, 4.594038801808511, 2.4689287956683867, 0.2626109874296573, 0.8778710615250372, 42.712481329517985, 68.60366636706938, 49.92355100570187, 90.3255170391452, 65.94391499796222, 43.58195704798545, 54.99260256367346, 3.490372333795794, 3.088672843671614, 0.2559681624294289, 0.20547676290715897, 0.4049243219196797, 0.06980899601213394, 0.21268033362444372, 0.23140591268818225, 0.1703774947072229, 0.15591838186787021, 0.22783614214389558, 0.2952127170658881, 0.24765980099478077, 0.12495002829499784, 0.2723040221439254, 0.24963615462183955, 0.16966893998605592, 0.25110871350813296, 0.24957943347192582, 0.17359285765597898, 0.28236903851070716, 0.15681496520917262, 0.14432471365697924, 0.10325276352945836, 0.23936015764071097, 0.1674788631498814], [0.08508695725111232, 0.030558094337222078, 0.06747159280724103, 0.0557482680456052, 0.04250659532244167, 0.017240477402904825, 0.06349197288434352, 0.033072333617676655, 0.17574009485542777, 0.08135101457516994, 0.013815540568752876, 0.047526589459589416, 0.08065757476874898, 0.056027491772246946, 0.09540769376701887, 0.04683834372929508, 0.14758162921474827, 0.030868938342938503, 0.07179926179589764, 0.020050395978614688, 0.08154816730248352, 0.1396531094947169, 0.02620921811960157, 0.08883326509667021, 0.008933754438804764, 0.10590432407034021, 0.039419942805843974, 0.2782518368574881, 0.08076773821226052, 0.384499590483404, 1.2424440922275668, 7.184623095297045, 64.21306325543311, 43.0993603890942, 43.26229564605221, 77.02210826258506, 55.88010157308271, 40.91235660737561, 40.80106327610631, 3.61479677980946, 0.3456219153538827, 3.0996084117120315, 3.339999693055307, 4.244647304857931, 5.51197148138477, 1.3024396857907696, 3.467910881004026, 10.853388501751809, 21.81486575834213, 22.513981173115393, 31.30910396575928, 29.70658825289819, 34.69028903592017, 27.581248052658577, 24.88977255359773, 23.12057964263424, 7.184763810326976, 18.151828973524033, 5.730277367176549, 6.487383063762419, 12.933117420442644, 12.855463316363673, 14.706114049880737, 15.028607403078388, 9.607950660490221, 9.651795894868913, 6.297273135954335, 4.397762417793274, 1.2941997666512768, 0.6475728353665722, 2.8851780727986367, 4.6541192166266905, 8.497045213176358, 14.325117564970448, 20.97122080864445, 20.26983238035633, 22.25187663109072, 24.710200563553844, 33.064890215473795, 46.25123585424116, 56.465017180288996, 57.87221847041961, 57.617715481788885, 66.42490740745299, 66.54284523379418, 65.06652393648702, 66.85968645157354, 56.036219750681234, 51.6733987869755, 33.379327020337506, 50.271775107229914, 56.553964768686605, 54.092038139220215, 56.54078168253745, 46.71374997785015, 46.39792465394544, 55.67776610774379, 58.03296504482147, 56.86860161442911, 61.36296318423364, 61.836208912634085, 65.00069479788503, 65.18966674804688, 74.21824116860667, 64.07016738768547, 47.2016300693635, 49.30646411834225, 61.03049524368779, 64.45007639546549, 58.48317077082973, 42.84294720618956, 24.576004512848396, 20.637633031414403, 17.47124283544479, 15.234475943350024, 9.74002274774736, 7.2673267606766, 5.020333268950063, 7.313589155673982, 9.424372949907857, 9.206349965064756, 8.570746548714178, 8.783602791447795, 9.108821211322661, 11.693188548088076, 11.114168263250782, 12.732100852074163, 14.495453353851074, 17.922552708656557, 18.11591967459648, 20.989457868760635, 17.403223053101573, 8.8564274772521, 7.49790721362637, 2.7139335197787133, 1.8002590633207753, 6.856748740519247, 2.8403863214677383, 4.075815499790253, 1.9337622028204704, 0.0692455843091011, 0.04510027409020451, 0.2416057145643619, 13.473655331519343, 32.90841902455976, 49.11605658069734, 50.393290135168264, 14.246844706996797, 16.381932977707155, 9.121490466979242, 1.2780361694674338, 0.09963882801633689, 0.06395125791670815, 0.07222575826510307, 0.08351358119398357, 0.02727572359294901, 0.06466272377198742, 0.031242195531846057, 0.08803596675035455, 0.01944746946044747, 0.03677547623914096, 0.15302624673612658, 0.10988956707860194, 0.0636350934303576, 0.05856580153528241, 0.02256156707693252, 0.04729418136600045, 0.05156052501631841, 0.046265903680074605, 0.058500350813471505, 0.02515907245387714, 0.017286883178918112, 0.06642995071747611, 0.012672743271856059, 0.06499710582917737, 0.06993517069326294, 0.07012332954834546, 0.04525208973415917, 0.01959013226892679, 0.10226508467307976, 0.017786705753796043, 0.0665940314290985, 0.0637274989557843, 0.03903338250013129, 0.09299678442579123, 0.0264906041294096, 0.11025006507313061, 0.07140867186770325, 0.10451883873752049, 0.012767153074814668, 0.04399486667206211, 0.036001359713414026, 0.052155116497869455, 0.010418404107763162, 0.05486206902611641, 0.047236724771679416, 0.05365191057564751, 0.10747431401884365, 0.04647328368117733, 0.12702571288231881, 0.023793218124117103, 0.13370063696657458, 0.0624903665495015, 0.32978896171815936, 0.07523354969077534, 0.4705618772535555, 1.7659054744628169, 22.827343248551895, 91.03625051436886, 49.75445762757332, 58.88597073093538, 74.61571062764814, 52.2889010367855, 39.27897184125839, 51.24133010064402, 5.30780230799029, 0.644060414164297, 1.0716367609077886, 1.1576695379710968, 5.932674609845685, 6.378498067778926, 5.137845027831293, 2.9189874327951864, 5.2488412395600355, 15.171270870393323, 19.18705228836306, 25.941269782281694, 25.948655605316166, 32.23893711643834, 26.976151850915727, 26.30148260824142, 21.717245809493527, 13.591103842181544, 18.47741903797273, 8.13305857681459, 3.2371725526548203, 6.916749727341437, 10.367478420657497, 9.511832979417617, 4.864504366151748, 2.9259812639605616, 5.365793570395439, 1.6479030515878432, 1.1887638823639963, 1.1010600530332135, 0.6672951867503505, 3.436897190347795, 5.653161608403729, 10.967542221469264, 14.96106909167382, 25.083904381721254, 25.158376462997932, 29.2082844626519, 37.00540527220696, 46.99582722879226, 57.39840007597401, 63.15077558640511, 60.385783103204545, 59.164659054048606, 70.8407509711481, 72.63294466080205, 70.23317583145635, 74.7445369535877, 61.14515004619476, 58.39486645114038, 40.62698848785893, 58.437255505592596, 64.95075125848093, 61.2387260313957, 65.33241356572798, 54.38769855806905, 53.11084155113467, 62.257483236251346, 66.45434087322604, 66.97353716819518, 69.27176367851996, 66.29516324689313, 69.66200813170403, 68.00325347531226, 74.48699412807342, 71.87799822899603, 58.07604835879419, 58.39620790173931, 68.96150419788977, 70.6154029600082, 64.41357874101209, 49.65151502240089, 32.59380571303829, 27.161587784367224, 21.444160592171457, 15.967942495499889, 6.391287446022035, 6.802284179195282, 2.663761502312076, 4.215689426468265, 2.9719450685285755, 3.4076505274541917, 8.85007715994312, 9.43395039727611, 11.363276031709487, 3.835247711789224, 5.1130664348602295, 8.650549131055033, 10.919380418715939, 14.114118564513422, 13.992909481448512, 15.16029803983627, 12.548335848316071, 5.800262256976097, 5.163954284883315, 3.235983339048201, 4.390754122887889, 5.706269519944345, 4.268971883481549, 5.070246900281599, 2.157864003412185, 0.565038689922902, 0.1145912095483753, 0.209431063624159, 18.66991327654931, 50.56697660876859, 44.00080342446604, 72.3082273237167, 26.587876427558164, 26.651514922418905, 1.5120654889652807, 1.0309938966266572, 0.3078844854908605, 0.04563670417654418, 0.1421610208889169, 0.04086618274149876, 0.014860861795774151, 0.15677992434751603, 0.09882593211988289, 0.04653051811000032, 0.08591459267922948, 0.09394302558634551, 0.11198785125968919, 0.16936556916804085, 0.028589677381058855, 0.0038699910651156383, 0.01527399864919003, 0.05032772483724741, 0.05337675094544407, 0.019456704650374673, 0.07657405800156056, 0.04976184633109839, 0.0840165179162737, 0.012304557585007241, 0.027722530968246922, 0.020696349825049122, 0.045534634451952674, 0.28617885504518786, 0.17806481930517382, 0.14705512762790726, 0.3006189076169845, 0.0680919784692026, 0.10190761272585201, 0.2538894134904108, 0.18306840000854385, 0.29977351427078247, 0.13788864046575564, 0.1420625785906469, 0.15627269753284995, 0.24323337561180516, 0.16929214730137782, 0.2163930868189181, 0.1405227571846016, 0.19477152686205604, 0.1207489783184663, 0.1906785795525197, 0.10538772800036016, 0.16721171296892628, 0.1410954691950352, 0.09982180045617205, 0.2061841072094056, 0.09214229761592804, 0.48530916172650557, 0.12310063075875083, 0.49049686400159714, 0.2031027177168477, 0.5824673740613846, 1.8741968442355434, 42.62302775536814, 111.97705530351209, 71.07446932023572, 73.06216178401824, 100.79762566474177, 82.24658766100484, 62.85418164345526, 61.07945034580847, 5.6842812030546135, 1.1222963780164719, 4.375366174405621, 11.486267832017715, 15.217014531935416, 13.383399632669265, 4.92412047040078, 8.247285350676506, 16.624481562645204, 27.86426078888678, 29.454844651683686, 36.76145345933976, 38.15058831245669, 45.2647715230142, 36.370926595503285, 35.79150622890842, 34.95607276116648, 18.72282801135894, 36.77869227624709, 19.85241178543337, 18.771604645636774, 20.79464158704204, 17.980215472559777, 24.358560077605713, 22.9707549079772, 15.283542833020611, 13.828480782047397, 12.41661089081918, 7.193758785724641, 3.941998448102705, 0.7323695142422953, 3.1762870713587734, 6.130654773404522, 10.727710858468088, 18.18458664801813, 35.00198018166327, 37.80347816405758, 40.29559527674029, 51.3832296863679, 59.87760474604946, 67.15226388746693, 68.33495263130435, 64.60803416467482, 60.95505629816363, 73.09612166497016, 74.67238887663811, 73.4905787437193, 76.35099857084214, 67.09892749786377, 60.575402244444824, 46.23830772215321, 62.44098348002281, 68.53496213113108, 65.72094786551692, 68.49016081902289, 54.9245886648855, 56.04896745374126, 63.16679846855902, 68.3948629133163, 66.35727005620157, 70.0675812075215, 64.97454827831638, 68.34186384754797, 66.61746440395233, 76.85071637553554, 74.04590791271579, 65.48735895464498, 65.79820679080102, 69.1571912457866, 66.46702581836333, 64.60034239676692, 51.07335459801459, 32.44018608523954, 26.6624818694207, 22.019999834799, 20.03407635996419, 12.626863660350924, 15.434550162284607, 14.630174021567068, 18.874610008731967, 15.856707999783179, 16.001974940299988, 15.835373247823409, 20.259500857322447, 23.10219745482168, 23.18652056878613, 23.06939075070043, 18.928438655791744, 19.683355669821463, 23.393353031527614, 23.81361342245533, 25.53021323296332, 24.625948052252493, 13.21019463000759, 10.246115384563323, 6.8594331126059265, 6.686050622693955, 13.760007965949274, 11.380666840460993, 16.584924459457397, 4.047932350827802, 1.273392941201887, 0.28218579027921925, 0.40255183954873397, 17.98851913021457, 53.65340732759046, 62.55706210290233, 91.18139390022525, 41.8739805683013, 53.9493501570917, 27.048117537652296, 2.025748402360947, 0.33839283390871944, 0.10557555743763525, 0.21332050733748945, 0.224083092724604, 0.1180508396317882, 0.36235465457843197, 0.19635573540243412, 0.26209295877525884, 0.24478569957277468, 0.16591688648106592, 0.29836587367519257, 0.22590733193341764, 0.15264396886191062, 0.1939518281048344, 0.16118327516221231, 0.21805581937153495, 0.1931557861427146, 0.18167605052792257, 0.25568788150145166, 0.12002240520932021, 0.14000972342346946, 0.14578274751622833, 0.12680898660853987, 0.14951008702478102, 0.15472878521728903], [0.054114202503114946, 0.1497203934817545, 0.03439263252901935, 0.1058828276431849, 0.03464066881626364, 0.07663361367679412, 0.03168963109924188, 0.025510544017437967, 0.13089215863616238, 0.05590962531465677, 0.11111809631749509, 0.0915684134909703, 0.06532397256383012, 0.06182376280306809, 0.1544256748691682, 0.012415889312603302, 0.08550127292232168, 0.05614660695315369, 0.075969354159409, 0.09586917747172619, 0.05652878140549987, 0.05288965692142806, 0.028712919860657667, 0.029848413466806376, 0.10164510503771806, 0.11862656236776423, 0.12211152697883307, 0.10179700495134439, 0.017068940740559372, 0.28060878296532943, 0.11691415667413704, 2.1683078042922483, 39.91589023220924, 50.522257666434015, 51.62807579963438, 67.12053191277289, 82.69980184493527, 54.76150828023111, 45.367874945363695, 1.6006452325851688, 0.11117598958193295, 0.5317687171120797, 1.816691097713286, 2.2217829477402473, 6.467854563267001, 3.894633867086903, 0.9502254919179025, 7.561646219222777, 15.744903779798939, 19.565700254132672, 29.633559603844922, 30.962272305642408, 28.35700854178398, 32.97294201389436, 22.345130981937533, 28.394847646836315, 10.529037906277566, 18.360402968622026, 6.072786085067257, 2.054725892601475, 10.367318584072976, 12.133883507021013, 13.374863574581763, 8.558167507571559, 5.2980488442605544, 8.335771079986326, 4.666333967639554, 3.47309846070505, 0.750510476289257, 2.0706768237775375, 4.1421096844057885, 4.701250906913511, 7.8171190138786075, 12.38073689322318, 17.890257873842796, 27.23363191850724, 29.1320590819082, 33.44856469861923, 37.90031756124189, 52.305998648366625, 61.62888811480615, 61.89527588505899, 58.04895262564383, 60.73530550925963, 69.31174047531621, 62.18970860204389, 65.3925552675801, 59.223549519815755, 51.435503113654356, 40.61327980410668, 44.101078817921305, 49.346440915138494, 48.45388597057712, 45.50596198728008, 42.77054809754895, 51.65710133890952, 55.618503016810266, 59.11535486098259, 62.169076934937515, 61.24535091461674, 64.51600359332177, 65.02710019388508, 72.90575335102697, 74.32026201678862, 64.15890316809377, 44.53547346976496, 51.61499077273954, 64.1582638217557, 60.37754220347251, 50.984736488711455, 42.0267294299218, 29.35484970769575, 22.807511744960664, 17.079231354498095, 10.855081004481162, 8.836929375125516, 7.929459617983911, 6.673889313974689, 5.610177334277861, 1.070062664728011, 1.3579567906356629, 1.1356048574370723, 5.334518061530206, 9.18819135235202, 9.324135799561779, 9.738396925310935, 11.240480349909875, 13.443502110819663, 16.573788850538193, 17.143269931116414, 14.209642987097464, 10.864709442661656, 7.928607973360247, 2.4440786194416786, 0.21155427630630233, 3.260101502941501, 2.999579637281357, 2.3912276231473495, 0.9338970326127546, 0.1557477281218575, 0.7486403637355374, 0.07131260444199847, 1.0729328591016032, 27.440631081981046, 38.36602449417114, 67.10957281051144, 24.653728238997925, 18.201739172781668, 16.130109948496667, 1.78906204479356, 0.7781384873294062, 0.1815628380544724, 0.13158517709422496, 0.09752838601989132, 0.07595758704889206, 0.04392092003517094, 0.06301818963801188, 0.2066661144096044, 0.06075968965888024, 0.015982099463261904, 0.07681994158173762, 0.08929693981284097, 0.06829680739751748, 0.08906535909421022, 0.10634867804906062, 0.08814881150160106, 0.04028635377424859, 0.07462206597049391, 0.1016458481430046, 0.03481132639271598, 0.05029911145327553, 0.023886230774223808, 0.017130193300545216, 0.05590733471176317, 0.0427885003568184, 0.004730126097603071, 0.03404153060288199, 0.08786764191163164, 0.017851053308995984, 0.0631413612544777, 0.05425001073989177, 0.03403176298184741, 0.0351276287748929, 0.06794870470560367, 0.05287700497935857, 0.08008544498513784, 0.03023264869566887, 0.1273544641932653, 0.03507348168040476, 0.07056569169846273, 0.13036305235037882, 0.061775395841968644, 0.05460640250314629, 0.018890600148287993, 0.08635201356223515, 0.00776912842411548, 0.06957675645788831, 0.021017378969718854, 0.046965698185827465, 0.06268943066618617, 0.08324879056383526, 0.16522604371270827, 0.08878093363056261, 0.023304415724029946, 0.05470155445378154, 0.2925863838003528, 0.11833653680139011, 7.1029054157195555, 71.14382466962262, 70.43399333953857, 63.68536326193041, 83.15692270955732, 76.64603925520375, 57.84322038773568, 49.658732183517955, 2.7762391442252747, 0.19824783467958051, 0.13522866061858593, 2.3037754383779343, 3.8604070198151375, 6.829591720334946, 4.020807445049286, 2.7853554679501444, 7.229394989628946, 7.249802591339235, 16.31082727063087, 22.729650735855106, 25.319177950582198, 27.254496966638875, 26.450426770794778, 26.5959192475965, 30.000856230335852, 19.364672899246216, 33.072091687110166, 8.932124318615083, 5.5074764451672955, 5.056661771189782, 8.898190913661834, 6.071094072634175, 2.240874349109588, 0.4670186899602414, 1.9616327266539297, 0.6261644163920034, 1.619486215133821, 0.6459953071128938, 2.7936181858662636, 6.222280360037281, 6.037865223423128, 9.952034700301386, 18.66465926170349, 30.10999618038055, 31.466840121053885, 37.11146223929621, 43.965745279865885, 49.26099600330476, 60.398205249540275, 66.61763698823991, 67.10594069573187, 62.26467686314737, 66.27913644236904, 75.37050016464727, 67.50879164664977, 72.33587218869117, 68.54965532979658, 60.38923871132636, 48.23844194412232, 56.39068434315344, 61.047188851141165, 57.65921023584182, 54.12616668208953, 50.228291711499615, 57.803910393868726, 62.927400527461884, 65.04854379161712, 67.70374128895422, 67.10630939852807, 68.11202080019059, 69.07974012436406, 74.44098472595215, 76.60577220301475, 73.35053443908691, 56.394528265922304, 59.86986590969948, 69.74225198068928, 69.28194615148729, 59.71076673076999, 49.148616175497736, 35.98271393006848, 28.003453939191758, 18.236197194745465, 10.521517742064692, 6.936874428103048, 7.133486665064289, 1.5708581406262614, 3.0213970859204573, 3.4091231323057607, 3.1104341533876236, 6.1957720018202265, 2.937957976133593, 3.690997890887722, 0.8804198666926354, 2.3060504130778776, 5.210302481728216, 8.652069049496806, 13.545847535133364, 12.244318819815113, 8.899596102776067, 6.865594175554092, 2.8322927557653, 3.7585996956594534, 3.0758886135393575, 4.0743279409024025, 6.338044212710473, 1.589684904583039, 2.402142353596226, 0.45170514393718014, 0.3835878845664763, 0.14099523425102234, 2.1336999968174966, 51.54510590337938, 38.156052174106726, 77.10800816935878, 46.21927245970696, 25.993874649847708, 18.721692485194055, 2.384024190325891, 1.06789592293001, 0.07136691241495072, 0.018813813240417553, 0.08177124444515475, 0.03478770024113117, 0.12693406578393715, 0.07778982421563518, 0.06373177755684142, 0.06340339779853821, 0.027560283121983373, 0.011894961973021348, 0.1028052302858522, 0.05322554051094959, 0.06114163045440951, 0.07076285208665556, 0.11280609444985468, 0.059748108859264085, 0.06926541066458149, 0.040293964857776324, 0.057160757977755806, 0.05820264521565649, 0.05773148965090514, 0.06092442537567789, 0.05542782878863716, 0.029103448501818126, 0.042655404071293535, 0.21570540033280852, 0.31278370969718505, 0.14633305911575595, 0.19382637354635424, 0.2028613540554239, 0.18435895172578676, 0.16895929742003643, 0.3007043723858172, 0.16554591606461233, 0.128747173735211, 0.17068616685367402, 0.3448159295705057, 0.10984204664465883, 0.2641205790062105, 0.16456775968113255, 0.1093323453659973, 0.2449684115427156, 0.12441621056847996, 0.1893609389662743, 0.20993934764016062, 0.17232652963890185, 0.13408109155153075, 0.18348322129778324, 0.21310565031824574, 0.34691899414024047, 0.24827659370437746, 0.2390768276827951, 0.3345261430067401, 0.17879932908521545, 0.42928634692103634, 0.1558242909490101, 11.728498704971807, 99.1038050190095, 96.92757991052444, 93.27988547663536, 97.77103854763894, 106.39289456029093, 72.96800136566162, 73.06665682023572, 4.277529514605, 0.45626211070245315, 1.7275813438238639, 3.8694189104341694, 7.120155019144859, 17.52453019542079, 10.83923560957755, 3.930475505128984, 11.883824563795521, 19.250049475700624, 25.5349906798332, 36.211913708717596, 36.99340674184984, 35.979403449643044, 41.87383151823475, 31.801263363130634, 38.649466729933216, 21.91088734134551, 35.46326660340832, 19.298875139605617, 9.326366647597283, 20.124445807549264, 14.993880698757788, 18.335982291929184, 19.062579793314782, 13.077780315952918, 12.348060607910158, 9.213872090462717, 5.758052650959262, 2.4390447476217827, 3.8327734316549, 6.073160181122442, 5.613709918914303, 8.638083838647413, 18.66374142708317, 31.462717710002778, 37.108920543424546, 47.12642646604969, 56.176311123755674, 64.46388706084221, 71.24855195322345, 73.29814726306547, 70.9474237503544, 64.34321534249091, 68.4750283148981, 77.16560425296908, 70.27389787858533, 73.12400187215498, 70.7385810728996, 63.562804883526226, 55.02982977897891, 62.541223572146514, 65.56100537700038, 62.64113810754592, 59.762887185619725, 55.47698782336328, 60.58177609597484, 65.7558177363488, 67.43206224133893, 70.24147556674096, 68.49112572208529, 67.07331442063855, 70.41816265352311, 75.28095245361328, 76.81332834305303, 79.8390603834583, 67.7564500993298, 67.86461337920159, 68.0539148084579, 66.79647353387648, 60.84806580697337, 50.46379081664547, 37.14974064980784, 29.008318108897058, 20.970226487805768, 16.835916926783902, 14.92981662673335, 15.659452003817405, 8.603427736989914, 7.306350421520972, 5.932598123627325, 9.820601959382335, 9.911432285462658, 12.22227902181687, 14.445477454893052, 18.33417211809466, 14.261214310123076, 14.159046373059674, 18.985162012038693, 20.746131673935924, 21.34329095963509, 18.34342302814607, 13.012907255080439, 13.027412179977665, 4.688727759545849, 3.468536744194646, 9.581552128637991, 10.629740838081608, 6.331615938294319, 1.7898867231222892, 0.9470156448022012, 1.458124686633387, 0.20597836663646085, 1.5761974670233265, 52.25826732573971, 56.3306014768539, 97.49715512798679, 65.38608727916595, 45.43986220513621, 49.514541933613444, 5.636480748653413, 1.7110181551787162, 0.2649535004410052, 0.20269842247568792, 0.3223397372470748, 0.1841955911368132, 0.22995255196527128, 0.20381974537045727, 0.2977301126285907, 0.192030479590739, 0.10645757744749708, 0.1332922048506237, 0.23292849711593122, 0.101493971212016, 0.20729331059321282, 0.17974759271788984, 0.3511394950891695, 0.17105347536984952, 0.22513123890084608, 0.14346081162652663, 0.0842599576759723, 0.18898045373780115, 0.1427351425011312, 0.28025037639083406, 0.08840059395879508, 0.11640217245346117, 0.08765237120490882], [0.10529167589641387, 0.11725420778196667, 0.03506144643911431, 0.04724258917473978, 0.02691320121108044, 0.013159706103315037, 0.1337393550502677, 0.040799942949125846, 0.020344826550553405, 0.0646190490994242, 0.06871720580684562, 0.13415724069120424, 0.10791368842605623, 0.08027036328830066, 0.07201182821224775, 0.06956661345377084, 0.0907249506863375, 0.07378311542373511, 0.026384449240961866, 0.09130828833628087, 0.05844282144079766, 0.051115381967035994, 0.04426781230816438, 0.02971084514302352, 0.08941510121428198, 0.03211067876808586, 0.09445019877485691, 0.03994391247209522, 0.1992237847298384, 0.06569177903715642, 0.22689268954338568, 0.42006920602533127, 12.065493060696511, 38.861513983818796, 44.347034961946555, 39.47926767410771, 71.11282225578063, 49.764114502937566, 33.39122356907014, 1.6649956376321855, 0.13518448798887192, 0.6964778046934836, 0.2434829057705018, 2.320794847703749, 3.5676263561171875, 2.4717707980063657, 2.723135400202967, 1.1983758956193924, 9.186199768897026, 13.796249685748933, 18.404517865950062, 29.655062037129557, 27.88694973914854, 34.69813377626481, 26.772796569332, 28.094097952688895, 17.63537637649044, 6.462993766030958, 15.105074990180233, 2.7831128528041225, 5.6789256968805875, 11.777006656892839, 10.954401300799463, 2.3430337059882382, 2.2958238134461064, 4.158500288763355, 3.386515080928803, 1.9602623485749768, 2.6064941623518547, 1.3795598572300327, 1.941832111727807, 5.201571776020912, 8.842653093799468, 12.839523784575924, 18.557758985027192, 26.704949371276367, 30.315893157835934, 39.392920617134344, 48.42626856219385, 54.47924275552073, 60.89881343226279, 64.7973983518539, 59.688452366859686, 56.04740635041268, 61.80781487495669, 63.53718003919048, 60.31991474090084, 55.143096062444876, 51.635069385651626, 31.62598244605526, 39.43774546346357, 45.827396300531205, 44.70422167931834, 43.37307122445876, 45.31882178398871, 51.14354148987801, 56.412924182030466, 57.96671621261105, 58.49694221250473, 64.37839900293659, 64.95189659057125, 71.29108613537204, 79.36344946584394, 82.04723711936705, 67.70355301518595, 53.76541845260128, 57.19022812381868, 60.57475505336639, 55.016109328116144, 39.64525453505978, 33.38641866560906, 27.29906293653673, 17.270482201730054, 13.485035107981775, 7.813168696818813, 5.51329626191047, 3.7162268209841947, 1.074952757166278, 0.4457356642571188, 1.5043533737621002, 2.0772872432585685, 2.056550407601941, 1.9170772981259132, 4.7622923024239086, 3.638135372631012, 9.553141420887364, 11.50450195035627, 11.750043303735795, 11.553973824747148, 12.500907528784968, 8.031007820560086, 9.115512774836633, 1.5681970576124808, 2.176650195352493, 3.6881536822165217, 3.039139682246793, 4.657376254758527, 0.9497412630627233, 3.5737128940320786, 1.5381110075020021, 0.2794638798842507, 0.3310728637922195, 23.895253635221913, 32.663721961359826, 52.96951463145595, 35.301680641789595, 7.066123879724934, 8.897852609234473, 15.374185865925206, 0.7446784021392946, 0.23379705696096345, 0.04139125174392135, 0.14315010168619696, 0.06640614836566872, 0.06014609536636741, 0.01673275263108794, 0.018080161478851112, 0.10108751560290975, 0.032341937729788404, 0.07053284950914883, 0.03424733246286069, 0.07942598117815872, 0.0931111766746448, 0.15323112929059615, 0.038893617419225555, 0.12885730653520555, 0.07719457389846926, 0.10291777626280824, 0.11415435557043362, 0.0522786328539012, 0.051996559280181126, 0.027693827568943945, 0.07954837138494177, 0.06999399092408919, 0.08138350436403867, 0.09371113077166582, 0.0013272795284489892, 0.01464398230441035, 0.0708585747727944, 0.10635468417838698, 0.19107378899089753, 0.12412736477750926, 0.023899618160700607, 0.12358260731543265, 0.029049596351180828, 0.09489788523604793, 0.09768799277803591, 0.020233611651365797, 0.09274427418506916, 0.029841692960490624, 0.04249784276790677, 0.0663566054596055, 0.06297289851992842, 0.019962757435296814, 0.07613400177609536, 0.08430309608698854, 0.05267505271119937, 0.04876177217210493, 0.0351052207031077, 0.05234161677259592, 0.06999230553065577, 0.01281697560297025, 0.12360354449840323, 0.08925704961462368, 0.10400253378095166, 0.050221464611710086, 0.2629093020673721, 1.06296427788273, 31.213139257123395, 74.6104468068769, 63.22453575749552, 62.43468807589624, 85.14759617467081, 53.05115876659271, 48.484660886949115, 1.7267755419015887, 0.07639077912655569, 0.8180455394810247, 0.26605219309849126, 4.531176936241889, 3.4081057675423163, 5.729880717492873, 4.554608195058761, 3.986802947136664, 3.7327978543696867, 7.054731845855714, 14.965984802092276, 22.55006305633053, 23.599803063177294, 27.513636196813277, 22.609877240273264, 24.354439627739694, 18.21260021578881, 25.817334651947025, 25.04158789111722, 6.184066668633492, 13.024527276715926, 7.431069045297562, 6.41278007338124, 1.5220866544592766, 1.454624093828663, 2.8135783922287727, 2.9262249412075167, 1.2478789038235143, 0.9313681457311878, 1.4516966573653685, 2.307208247723118, 6.3278092780420865, 10.540113699051643, 13.564997526907153, 24.899584362583777, 34.30415130430652, 40.429344177246094, 46.327474963280466, 55.49914137009652, 63.03591289827901, 67.72593405938917, 70.76886177062988, 64.91546953878095, 61.75682798508675, 66.94267595967939, 70.21475638112715, 66.24325460003269, 64.99214403090939, 61.928882752695394, 41.91569889745405, 49.48393960152903, 58.226702674742675, 56.234876032798525, 53.10136902716852, 54.29966095955142, 60.727135212190696, 65.33361773337087, 67.33900008663055, 66.17988478752875, 69.2609614710654, 70.21653713718538, 74.52594326388451, 77.454620176746, 82.89523001640075, 75.54582226660945, 61.69234421945388, 66.4409734356788, 69.66196890800231, 60.59838733365459, 45.99657989317372, 39.42205598277431, 30.58687206237547, 18.815076274256555, 12.044168114662172, 6.427675764406882, 3.5591702163219456, 2.6095847448995038, 1.027390096456774, 1.637354082157535, 2.9323507028241313, 2.6706153538919266, 2.316030393685064, 1.6728818080117627, 4.0272349840210335, 1.5861238827628474, 4.512927128422645, 7.595054026572936, 8.000774681568146, 7.4771828805246665, 5.6633337851493595, 5.3826641748028425, 5.225113351498881, 2.6908685122766807, 4.977698576065802, 4.01293279663209, 3.3944186568260197, 2.2837747825730235, 2.053368997669989, 0.9618581386823809, 0.1439349587646223, 0.0877370545640588, 0.38021403334794507, 46.92547951975177, 40.89054822921753, 53.32934894869405, 61.76207219400714, 20.547485197744063, 23.370732722743867, 2.041386647089835, 3.2763376639735315, 0.6339927318115389, 0.18135962557167778, 0.1535416400480655, 0.12692370827520086, 0.06980380193600733, 0.042671851979027835, 0.07777576650222463, 0.09051010898885228, 0.04541533924038372, 0.0658366002983624, 0.052401800639927394, 0.17008783686305248, 0.047439236284023335, 0.1582930246067624, 0.013800468746452563, 0.08588843843749455, 0.0796972988774219, 0.09998501548844, 0.047294583562160694, 0.0945432631358985, 0.07515360075499743, 0.02492766410502936, 0.09116155951614342, 0.04872208115674796, 0.10664107848799999, 0.06939741527481426, 0.24339031638397327, 0.2274049112513181, 0.1552550876212697, 0.19465089865749885, 0.26938835279114787, 0.18259380853945212, 0.16077631393507605, 0.2589680861321188, 0.16765201434252724, 0.1906110872063906, 0.22703369568672874, 0.2659333575396769, 0.27875613721628345, 0.15270835089106716, 0.17258650923688568, 0.15926313706703726, 0.25069626709145887, 0.17826317479052853, 0.20360073615466395, 0.14298845713417377, 0.18709834424718735, 0.19699338102532973, 0.12226374098850835, 0.1247833811888291, 0.1797071585972463, 0.18630096929207926, 0.3398315163870012, 0.23042757244360065, 0.363841998961664, 0.19272002000962535, 0.4831181809065804, 1.2639271588094774, 50.13854788195703, 103.28758547382971, 89.80469688292473, 75.16887464830953, 107.29429444959088, 72.82462304638278, 51.36822269808862, 3.7482385097011446, 0.17135376651440898, 1.194505129129656, 1.199649930480988, 6.121341595726629, 9.347326813205596, 12.369275727579671, 7.033965837570929, 4.171904008234701, 14.170721307877573, 21.26279607895882, 17.770431426263627, 35.32542274844262, 32.46976467870897, 40.50333184580649, 30.569178250528154, 33.380558644571614, 24.27149130452064, 19.6215763784224, 29.386897433188658, 9.47179146351353, 18.44448485682088, 21.445070582051432, 18.549743621580063, 10.140315332720357, 6.491633932436667, 5.912978918321672, 6.728198941676848, 3.987377574366908, 3.583872077926513, 1.1722146671625877, 2.443141418118631, 7.24469566537488, 9.990569045466762, 15.429551101499989, 29.85141392677061, 39.902836584275775, 46.13385500446443, 55.75413073262861, 64.24055907034105, 67.1278981239565, 73.58746913171584, 75.68640001358526, 66.24898910522461, 62.65543122445384, 68.06477977383521, 73.96656620887019, 72.19909914078252, 67.75870153980871, 66.9362432725968, 50.79293650965537, 58.24614978605702, 64.38019937084567, 61.820986193995324, 58.11253816850724, 58.3777335382277, 66.61266342286142, 68.99817051426058, 71.2096812648158, 69.17932125829881, 71.66368776752104, 70.84339464864424, 77.87159950502458, 79.34879549088018, 81.82937299051594, 78.58994237838253, 70.90291269363897, 66.74804010698873, 66.62325382232666, 62.9599718893728, 52.90976516662106, 47.58809728007163, 35.65570200643232, 24.380711663153864, 18.435037828260853, 13.156433643833285, 11.85900184416002, 6.178007587309807, 2.8969263069091307, 3.6725982975575233, 7.69010482295867, 3.713102653141945, 1.973366742172549, 2.101277930121268, 7.016615233113689, 7.156416350795377, 13.499789103384941, 17.12597620102667, 15.914688475670355, 13.215859513128958, 17.50375340061803, 11.377024919755998, 15.049569529871787, 2.777674731708342, 4.900486719223761, 6.246701036730121, 8.965170287316846, 13.624087052960551, 6.065273275298457, 9.356054086839, 5.630832535605277, 0.4176580208924509, 0.3708686493337155, 48.21450764133085, 51.53847709778817, 76.37978876790693, 82.02406375638901, 39.48712810393303, 49.8325990861462, 25.256296473164713, 3.978854754278737, 0.9045879795185982, 0.30799706977221275, 0.2328924296964561, 0.1899301269722562, 0.21309172283978234, 0.13116097888879238, 0.24732039340080755, 0.17545265866623772, 0.23330619378436, 0.20550817251205447, 0.09421450416407279, 0.29157079636089267, 0.17420381277559266, 0.2773869848780094, 0.14231537228390095, 0.2503846531673785, 0.2371622667077088, 0.18473232765832256, 0.13126155091149191, 0.1603156652662062, 0.10870527175645675, 0.12816740605499477, 0.2440991622185515, 0.1910952241310189, 0.2183930665975617, 0.14620616431197814], [0.1858698456518112, 0.07519977287419381, 0.05191274543082522, 0.03346429867369514, 0.04007506672473204, 0.05192265477812579, 0.060103650264922655, 0.05466065301950421, 0.050292434997015426, 0.05548955249269644, 0.012253515061832244, 0.009137827812904313, 0.05963600721330412, 0.0181528402402276, 0.029743915243494897, 0.05960580802732899, 0.06014654735824274, 0.0240853006365679, 0.0844503152033975, 0.0779844948180741, 0.00845402826540052, 0.08053471724833212, 0.08256253666214405, 0.0659231529120476, 0.08323438044997954, 0.10548802423140696, 0.05430205492302776, 0.23531683750690954, 0.13565604574978352, 0.20753335658340685, 0.09208132467803457, 0.11424036426169258, 2.297794069013288, 4.733236364779934, 31.866719876566243, 25.001101186198575, 44.005129798766106, 60.5994071498994, 32.33818288772337, 8.23447096732355, 1.026024008470197, 0.12959299609065056, 1.0521337558184902, 3.6041352873848336, 1.678443728916107, 2.8697967433160354, 1.2840948830689154, 5.079324245452881, 3.0081801693285666, 8.648224146135393, 11.4604978599856, 15.931624289481872, 22.696787157366355, 28.560083373900387, 29.843816295746837, 20.170657211734405, 25.58266120572244, 6.1657825400752415, 9.57730616292646, 12.566996524410865, 6.410382524613412, 5.439950391169518, 3.9769320574498948, 4.634653964350301, 4.362697409045312, 3.199731077878706, 2.1076640390580703, 0.4824354739919786, 0.10509884390499323, 0.6407551431367475, 2.8741179695052486, 3.964504763003319, 7.79746990050039, 13.36538124469019, 18.76050433804912, 29.117501205013646, 37.47414027490924, 46.7372057514806, 55.62517496847338, 65.6265050365079, 67.89792999144524, 72.8477022724767, 68.1047095021894, 62.542129639656316, 55.156647851390225, 54.34590178151285, 55.86120751596267, 47.756610147414676, 46.59346657414591, 30.837193804402506, 30.428902526055616, 44.748634676779474, 40.31491294983895, 44.69797726600401, 46.21331437941521, 52.81527134679979, 55.3881343718498, 58.14493694613057, 61.532825346915956, 60.08470196877757, 63.111418524096095, 69.0056622412897, 77.24621680475052, 77.63919122757451, 71.70349982477003, 58.57280869637766, 63.2946010558836, 58.652495568798436, 44.59319899159093, 29.865148105928977, 21.620990845464892, 20.54602607603996, 12.53781310973629, 5.246558910416019, 1.968349662999953, 0.25410984762974326, 0.21492533896478916, 0.10351538613078096, 0.148100990862135, 0.24524067919100487, 0.5680480671505774, 0.11592846964636158, 0.423447868276027, 2.6919562345550907, 1.2990061410011784, 4.327414218456515, 6.033112781663095, 9.456417733623136, 12.46675447110207, 8.156005913211454, 6.298694504845527, 2.5909963875047626, 0.7429631619203476, 3.8655046301503337, 5.238107183287221, 2.5963146311621514, 1.6355979634869484, 0.8161271940315924, 2.8889776237549323, 0.28456400298783857, 0.08391624466786463, 18.934008421436435, 30.718257734852454, 43.69453299430109, 55.64877979217037, 14.435825482491525, 8.896516061598255, 11.388623368355537, 3.659590247177309, 1.1274677779405349, 0.04989272862252209, 0.09280687122936211, 0.06912722372479978, 0.07484037804627612, 0.06974619212410144, 0.10583792722994283, 0.005063691313543748, 0.03949757432565093, 0.011120536139294987, 0.012725280624093309, 0.12642952793788526, 0.10231681092972718, 0.0787551869307795, 0.05965429756249632, 0.18462221018008648, 0.05974341657072787, 0.154227304062055, 0.06840996624481294, 0.05213713641428659, 0.09934438978351894, 0.009462306268453118, 0.046164883495939356, 0.011441420684869011, 0.0386967558053232, 0.037347506431321946, 0.11822789021196867, 0.0375715182012608, 0.028816351306534586, 0.06365066033697898, 0.02692852871522548, 0.025723125755546555, 0.018888817078644232, 0.046366789798823096, 0.04213115478294992, 0.07705370565095256, 0.03950000665481052, 0.02939033885336211, 0.013259276466053582, 0.01013150705294984, 0.01481805663300498, 0.04057741355932048, 0.061266035472433415, 0.07760039365459835, 0.055775448845158664, 0.04647383526448281, 0.07130819177555461, 0.08971150829306535, 0.13757750151618836, 0.07113430513850144, 0.10306285799390848, 0.015757427900098264, 0.009060801502557532, 0.01985101202022164, 0.0863974808805412, 0.19214024466852989, 0.10616001357594806, 0.14559796710889186, 0.15960018511020369, 3.7505679072872287, 37.14886596125942, 65.36696964694609, 43.46009292910176, 66.26884414303687, 62.00292925680838, 46.168701341075284, 15.2207290164886, 1.2254717513438196, 0.43087490684082436, 0.9804256584855818, 0.8454651133187356, 2.9612401848839176, 1.2869454655916461, 2.7989592283002795, 5.728773138215465, 2.940163328762978, 4.594821314657889, 3.815022500291948, 11.01401936623358, 13.059388322214927, 17.751568748104958, 19.021479237464167, 18.55742166119237, 18.30232835585071, 12.355727861004492, 23.49006691286641, 18.6245334148407, 13.537599771253525, 2.1865218204836694, 5.322306742591243, 4.080273763787362, 4.691552356366189, 4.746088991242071, 1.796291218169274, 1.0916171919914985, 0.108051814078804, 1.0135619029883416, 4.172503640574794, 5.073825572767566, 9.152687038144759, 13.077413574341806, 23.867228300340717, 32.59358213793847, 41.27973364245507, 51.982881638311575, 61.4912207664982, 71.72926979680216, 75.34701301205543, 79.79473760051113, 74.06600613747874, 66.91339938871323, 59.045391544218994, 61.32172730661208, 66.24277607087167, 58.4728314030555, 60.54418017787319, 41.80063616844916, 41.115990377241566, 60.5921664545613, 51.84686560784617, 56.35983882411834, 54.93537518285937, 62.014060943357414, 63.65572191053822, 65.76169736923711, 65.76317610279207, 66.91407403638287, 70.76310373121693, 71.40742363468294, 76.68974230366369, 81.92117214202881, 79.12169810264342, 67.21784591674805, 67.3123279694588, 66.96315073197889, 54.59396423832063, 37.0303633136134, 25.43915737059809, 18.758923622869677, 12.481285871997958, 5.736228583320495, 0.9998553029952512, 0.2342605707986701, 0.31528737696428455, 0.23838379390297398, 0.7754852490559702, 0.597459101869214, 2.206019922610252, 2.0929218107654206, 1.4667266895694118, 5.416792227375892, 1.2552509985623823, 3.761784660239374, 3.0770638537022377, 3.8594131892727273, 4.623230551519702, 2.511412722449149, 3.277285896962689, 2.1547381195329853, 1.8461148801349827, 5.902819489279102, 5.408932287846842, 1.7322846333826742, 5.185111059296516, 0.5532530094346693, 0.5821331145782626, 0.3988457513192008, 0.1486100103225439, 40.04988231966573, 48.783604329632176, 43.00465476128363, 78.4711180963824, 36.48895855872862, 22.792428270463024, 9.644974893139256, 3.7716996765905813, 1.60063763299296, 0.06871958834029014, 0.07394151942383859, 0.08045416310309403, 0.04274042067869056, 0.042803726354313475, 0.012644214157555855, 0.029984466851718967, 0.08366310623504462, 0.1597811810431942, 0.06115112994467059, 0.15273039890152795, 0.07416460422738906, 0.06403318718977033, 0.10360340963328078, 0.15692240137967373, 0.10002437708598953, 0.15365085354255092, 0.13841863541353133, 0.012312082483643487, 0.13358567781265707, 0.035016737547853304, 0.029634330196366198, 0.05480214945911881, 0.03684837333557587, 0.0698602472942683, 0.10363403782849351, 0.38608879391704837, 0.3851328081180973, 0.14657102134679595, 0.14192376345876725, 0.1322078073938047, 0.31496595711477343, 0.17372574326732468, 0.15890181935842962, 0.20185790144868437, 0.2168921318145529, 0.16423969018843868, 0.11090615043236364, 0.1572342910954068, 0.05670214327232492, 0.1168396776061385, 0.18481354830005478, 0.20374322850858012, 0.11272750148970274, 0.14383268602673085, 0.21538528283276867, 0.10183787574210476, 0.21564469552568852, 0.1296060655506388, 0.20152028650045398, 0.16064100748588964, 0.16673232578942854, 0.21796347513314218, 0.37234851669880653, 0.2919701426740616, 0.38549198078051694, 0.38123758810181774, 0.2808758105722166, 5.700903227252345, 71.28273933164536, 93.58686585580149, 70.31720869002804, 79.62500879841467, 90.31421276830858, 60.439213629691835, 17.4546786662071, 1.37711389170539, 0.7169116372542997, 2.1118058168119003, 7.620187103748322, 8.375259541696119, 9.894948524813499, 8.62934087553332, 12.362821467461126, 5.198732960608698, 14.321541343965839, 22.791192723858742, 20.489832239766276, 28.22228885466053, 33.581301627620576, 36.70786996041575, 27.944006496860137, 32.41716961706839, 11.490929568967513, 23.407663799101307, 22.453511953353885, 16.80858192905303, 15.654101890902366, 9.662917775492515, 5.090288250677047, 5.4056134723847915, 8.747914125842433, 5.018750592585533, 1.568966577610662, 0.20759842809169524, 1.6297977585946362, 5.252744978474033, 5.957295817713584, 10.03206281892715, 15.443549060052442, 26.250787934949322, 35.340563097307765, 48.04568098437402, 56.375932308935354, 65.27027145508798, 78.19776811907369, 78.93924513170796, 81.32366180419922, 77.61443322704685, 68.9903336186563, 64.53581548506214, 63.18322143247051, 69.64364359455725, 61.72325249641173, 69.4472897437311, 51.399507522583015, 53.10476579973775, 68.35317596312493, 59.31027312432567, 64.13421184785905, 61.95830837372811, 69.48068480337821, 68.01112959461828, 72.3569510059972, 68.52251252820416, 71.57053932066887, 73.62335881879254, 75.94431154189571, 78.77923596289851, 79.31377656998174, 77.20507114164292, 69.71405013915032, 71.03689301398494, 68.96690922398722, 60.03004374042634, 52.003544684379335, 43.591939480074, 32.7692513696609, 20.161074861403435, 11.950962793442512, 7.859815484093082, 1.4542910600862196, 0.7655918670277443, 0.40725436301962026, 1.3134487982719176, 1.1815301737477704, 4.286841711690349, 4.378674203349698, 2.106384610937488, 6.52636799120134, 2.0352420090667667, 8.66509622143161, 7.597156907281569, 12.663227954218465, 16.306176320199047, 13.195609296521834, 10.980236972531966, 5.8992315011639755, 1.5842743626525326, 9.195291822956456, 13.361705983838728, 7.510538716470042, 7.416478318552818, 3.86572158625049, 7.39217286148379, 0.5556883110154061, 0.13597640839795913, 37.452967320719075, 54.50647577162712, 63.85579024591754, 101.5874105884183, 52.49688863754273, 46.459494098540276, 39.951473974412494, 5.764419148045202, 1.6884192968568497, 0.1518176511050232, 0.24465809996810653, 0.16490686083993605, 0.13654907444311729, 0.16979666216479194, 0.10169366735123819, 0.11016593329728612, 0.15210134878514275, 0.20429625205935972, 0.17423419582266964, 0.24433758410234607, 0.14911857013019825, 0.1658240519464016, 0.1858873737435187, 0.3348705761374966, 0.17666876195899903, 0.16487684551506274, 0.16383993018779064, 0.14281939685104356, 0.1655278517113578, 0.10301056483219709, 0.14723059240608447, 0.15279706387269884, 0.17483019690600135, 0.1992740247759127, 0.24352291088190772], [0.12791968386379943, 0.10266779411223628, 0.058898590129589846, 0.028662038215946768, 0.0658417713918513, 0.06264705068221496, 0.06996270389326158, 0.032660883115304094, 0.09430422838176451, 0.06040297996913714, 0.07493946385840256, 0.023279730455889817, 0.0838834867482224, 0.028286865807228515, 0.0917692204576827, 0.041418838570074695, 0.02946868475015846, 0.05039437448665981, 0.05427932509431436, 0.04335812503291715, 0.06442700617856557, 0.06965757107302066, 0.062084156088531024, 0.072513033575829, 0.05734712801753514, 0.08160979907599189, 0.06250794826736374, 0.09600326584111299, 0.10538297059435038, 0.1393899123274511, 0.11269925582793452, 0.15594966889869782, 0.09289569146330319, 18.743069402633175, 34.91753155185331, 35.44515702032274, 38.57588306550057, 55.72042972810807, 51.38038596799297, 29.94398774639253, 9.089250545347891, 1.6631108161903199, 0.6774692633940328, 1.2641731649637222, 1.161437219669742, 1.034106052210254, 4.346610298079829, 1.5436225504644456, 0.4677544714462373, 0.6073506452864217, 5.649003896021075, 12.521022423621147, 14.33893999745769, 13.283359581424346, 18.74365383578885, 20.14698963011465, 20.837809231973466, 14.841785892363518, 7.863488293463185, 8.123632630994244, 14.386869399778305, 3.4422921653716796, 2.680793414192815, 1.538828923817604, 1.6238921400039428, 0.13895854353904724, 0.40166578225551114, 0.23265334897704665, 0.578854258262342, 0.572400120717864, 0.8092012076127915, 2.3210510275056286, 7.004523546464982, 14.283580645438164, 19.44223580821868, 29.009188875075314, 37.340242324336884, 47.78964827137609, 53.829945364306056, 59.511059253446525, 68.34409175380584, 73.11487843913417, 76.70144665625789, 72.55223797213647, 65.42656613934425, 57.59568745090116, 49.99426349516838, 45.59263852334792, 38.05014817945419, 27.959346886604067, 7.317086438978873, 40.32560925329886, 46.706375921926195, 53.297295339645885, 55.86550643367153, 54.207783360635084, 59.60463916101764, 60.2229106041693, 63.71045466392272, 64.43143729240664, 64.77153816530782, 74.16186101974981, 68.46439084699078, 50.589879328204745, 43.247147452446725, 46.120205156264774, 51.7496104394236, 49.45312938382549, 35.211399447533395, 17.66484122122488, 11.088132550639491, 7.374316761570593, 7.128456225318294, 1.1305165627310354, 0.16865137603975114, 0.17544626949294923, 0.2856132676524501, 0.10130351409316064, 1.0446730400285413, 0.8054155075261671, 0.6111682146306961, 0.4108578567543338, 0.8343801887766008, 0.9703272100417846, 0.015219899435197155, 0.0771544385521162, 2.441988486436106, 2.9651299503541764, 3.2439660977932716, 1.1384750518106646, 1.1020757017597076, 1.0537160644608161, 3.1457894175283374, 6.925624089856302, 2.674254332819293, 1.8077982265141703, 1.0593811927303192, 0.642736981953344, 0.2249306157952355, 0.09524076320831815, 23.05772169943779, 28.171092117986372, 36.16846169194868, 63.93984663871027, 26.311206163898593, 8.41623850407139, 8.150469487713229, 14.040978127910247, 1.0827723698269938, 0.02586803320164402, 0.009296342895756806, 0.20079535281946584, 0.09886021455449444, 0.024002141792387254, 0.015348566774909776, 0.028968680229398514, 0.057669509307391224, 0.07968629019394999, 0.08791998103861848, 0.03712167903300255, 0.03747820486164382, 0.10912875750011976, 0.04292258106532597, 0.05628366774368671, 0.14509769637257824, 0.12435502312596768, 0.08627055543324641, 0.0544378669902442, 0.08550379335159257, 0.14425167483427834, 0.06381573696290294, 0.0686315112116356, 0.016566888849821784, 0.07888906079554751, 0.12656111119975968, 0.25360963818046356, 0.1206405921989391, 0.031100258591674992, 0.06634085469188229, 0.033023250364368005, 0.082223228659601, 0.028100513004427476, 0.07932985246542, 0.10754323128851191, 0.13546231743549147, 0.10844077990059892, 0.14799499493693152, 0.026421954990514827, 0.03710899261697646, 0.008085994838526653, 0.025718284079865105, 0.04164354364958502, 0.03463826713062102, 0.037140632048249245, 0.02880016003825492, 0.039346045964667876, 0.040258609900070776, 0.012913428945466878, 0.019825053130907398, 0.11261065775949149, 0.07088145781909266, 0.05694541449268019, 0.09788565112337952, 0.10698408669521732, 0.07249005093810058, 0.11788229262756726, 0.11064657686097969, 0.283247526855238, 0.22144209653619798, 37.546974766638975, 55.49525037888558, 59.90933279837332, 59.59518232653218, 74.93760385820943, 51.81558470572195, 56.82536532801967, 12.87383177588063, 1.8600307140619525, 0.9111816676393633, 0.9758434721058415, 1.0902731673371409, 1.1639860248373401, 2.0551298967292233, 0.8065690520790316, 2.2802696545277876, 2.6560618896638197, 4.928287008116323, 3.6118022953310325, 7.7945374385003126, 6.072001611032794, 11.37257302961042, 15.24988889694214, 18.9883489378037, 10.840652565802298, 13.328407022260851, 10.587755787757136, 11.607301389017413, 13.883718540591579, 3.1834086247028845, 2.442244911386121, 2.2764482853874086, 0.3616622949559843, 1.0268844784267488, 0.9021943531209423, 2.8173009666704365, 0.13673774657710908, 0.6521515896724117, 3.890043958540886, 9.928773083994466, 17.45455511154667, 24.881923890882923, 31.597817867032944, 42.662114174135276, 53.216925974815126, 60.74585276265299, 67.53967638938659, 76.7626513204267, 81.41930487848099, 80.84070036488195, 77.40783414533063, 73.5560509466356, 63.78284200545281, 59.49223972135975, 56.36498889615459, 51.85174895871071, 40.05850368930448, 9.143251776695251, 55.967507670002604, 57.152455699059274, 62.45936370665028, 64.97372850295037, 64.88762071055751, 64.74723123734998, 66.51101912221601, 69.43300447156354, 69.28928882844987, 69.92258687173167, 73.03507389560824, 72.01242569954165, 55.17873079546037, 48.242948747450306, 49.054220414930775, 54.90907176848381, 54.38902431918729, 43.00889876581008, 27.181874282898445, 16.245902238353608, 9.212161937067586, 4.051928510588985, 1.1111681235413398, 0.09063281329168428, 0.10540838173079876, 0.20402671168408087, 0.2121507676859056, 0.7568184442577824, 1.3171795851761297, 2.092445242789484, 1.6694405410558948, 1.1119116578371295, 3.1830487472395745, 0.3106318606484321, 0.690605526249255, 3.7238337676371303, 2.687888001241992, 0.9973924222492403, 2.4828527194838372, 1.9774141378941077, 1.7656534621792457, 4.037175740926497, 9.944842053997903, 4.3457856197511, 0.44589458153613154, 0.9297505970443449, 0.4396762764982639, 0.22840140777970516, 0.0650050578218314, 35.805309049544796, 46.26052010443903, 32.0243638561618, 79.39773882589033, 48.915835272881296, 26.41014991268035, 20.707912098976877, 25.483670388498616, 3.5730473168434638, 0.6270788189384245, 0.02087980873071619, 0.042371334838530714, 0.08978535150808674, 0.03734873983288004, 0.05422287973605337, 0.04930573290274028, 0.04535680246208945, 0.046193925889148835, 0.11415337497789053, 0.03933065142782946, 0.019432153447621295, 0.10307877730097502, 0.03180520886915826, 0.14367582186335517, 0.23450113772865266, 0.08232982979426462, 0.11990165443069513, 0.08568307324763268, 0.12149057441180754, 0.023184170563434883, 0.05110071904416527, 0.03031065751377854, 0.06456831109619911, 0.07776432114863589, 0.06395319994959621, 0.12652924960298886, 0.28778702681583745, 0.15479966367204345, 0.29755415755414194, 0.10689262345793749, 0.13659127056598663, 0.11322863024449158, 0.1839286401387184, 0.226395667019871, 0.29751478063483394, 0.19775559254471334, 0.35507185504801814, 0.1404982883363001, 0.19965788079125268, 0.17726615732235296, 0.2405981710481067, 0.07515986735421805, 0.1554249906011166, 0.16731095199863757, 0.1269680494442582, 0.13569243492618685, 0.17701333298558192, 0.2987616040533589, 0.12826158124352657, 0.17719544740694185, 0.15543124187857876, 0.10830742697561942, 0.31638668249211005, 0.15026400947282392, 0.20402128778157697, 0.1634065389272667, 0.19260884533005376, 0.5308578079265933, 0.5250982363377849, 50.266087670480054, 73.58918712985131, 88.2164821317119, 84.21899857059603, 91.29854725253199, 75.73423724020682, 61.48136385025517, 19.341454429011193, 2.243443991868727, 1.985133975263565, 3.0727725355855884, 3.764468542029781, 3.972687072330906, 10.545346140861511, 7.105174506864241, 5.145275467826474, 2.8841109429636314, 8.483793485549189, 21.575446244209044, 25.18752947930367, 19.00694489479065, 25.859772736026397, 25.583033830888812, 30.224143035950203, 18.985160050853608, 17.488244348956695, 17.034432003574988, 21.38151053459414, 18.774546423266013, 2.620628913564067, 1.112222015377014, 0.7327048768920283, 0.18664184777486711, 1.5023844665096653, 1.102627897935529, 4.368625090968225, 1.9754938925466232, 3.4964833865242624, 8.09782196437159, 12.696904443925428, 22.291147401255948, 26.918857789808705, 33.22202428694695, 44.99656769537157, 55.40784035959552, 59.02434018350417, 64.78368574573149, 77.95724053536692, 82.6530001240392, 82.38602792063068, 78.51424063405683, 74.32685944341844, 67.15502523606824, 65.16362613247287, 64.23313402360486, 65.71801001025786, 47.58589290803479, 14.370110092624543, 68.90977598005726, 66.43973396670434, 72.75372228314801, 69.90310053671561, 70.89119265156408, 68.60813786906581, 75.49065805250599, 75.16356375909622, 79.36140198861399, 77.09989670784243, 81.97268855187201, 72.14087547794466, 55.25962968026438, 50.191084108045025, 55.17509083594046, 58.961668552890906, 59.971851456549864, 53.110386556194676, 35.99174322620515, 29.278334071559293, 22.02920171522325, 15.050858028473394, 6.615462668480412, 0.4636587815419321, 0.26185096692173715, 0.4793877310810551, 0.6537687093500169, 1.9374225096356485, 2.1888833324755392, 2.4966577464534394, 2.2871997471778625, 1.6358721616768068, 3.1460066187766293, 0.21661908275658087, 0.5602438375353813, 6.600639051006687, 7.136823621488388, 7.274480183278361, 3.6134313046932225, 2.758879714435147, 2.892980157367645, 7.838057606450974, 13.573098201905529, 9.03361858860139, 4.911838058502444, 5.512709377273437, 3.8540741080237977, 0.5805681501665424, 0.14195642944785858, 40.685525940310576, 49.10184583356304, 53.89065973220333, 100.68003300697573, 66.61212213577764, 42.31742412813249, 43.00913018565024, 36.774322755875126, 3.2155590672646803, 0.7094445476128209, 0.08631396963591538, 0.24197892195755438, 0.3760742167792013, 0.21076183495742662, 0.14677204281812714, 0.1429100710177614, 0.11532495324049266, 0.1634422845898136, 0.32021442548401896, 0.20917174286179005, 0.25528115010069263, 0.2356792890256451, 0.1398328490435116, 0.2024434684144874, 0.24293103135160862, 0.16589584970666518, 0.236226137907755, 0.2466968437957187, 0.2502184733748436, 0.2034640813907308, 0.14622327871620655, 0.16101639056878705, 0.2422206686629403, 0.22251817427815931, 0.24959558260536965, 0.3216967749739847], [0.09986641741688214, 0.046696448923959855, 0.0337837228641635, 0.06685719795284734, 0.026361719412248463, 0.08542175299578136, 0.05832339599428158, 0.06028071233642198, 0.017296443956213135, 0.033604887299119465, 0.08953452666079806, 0.147790051095428, 0.0769403322990383, 0.06750402896995507, 0.070934065076853, 0.02878680712573471, 0.05795528308578557, 0.06406931972671902, 0.05880571729052932, 0.016375809284527938, 0.06848348770290613, 0.05422014863260331, 0.017491193082664284, 0.0535572144473272, 0.0459541327079698, 0.1579079122072266, 0.062172447721804344, 0.03800681702071621, 0.09530525248978408, 0.13100474291751463, 0.1540446227356311, 0.08596277960966672, 0.07204671585631948, 2.1629871091535016, 29.457458911403535, 28.55009505825658, 32.300967439528435, 28.898203449864543, 64.27474252639279, 37.69720154423868, 35.45724576519382, 14.23819293898921, 1.3422923150562471, 0.5710199980005142, 0.8319008831054935, 0.19551916738911984, 0.3007337901621096, 1.8876683471664306, 1.67631498507915, 0.9894314816882535, 0.5687271887736937, 1.7884193889556395, 3.9056981378985993, 6.323272566641531, 8.008902322861458, 7.555594982639437, 8.360900725087813, 11.776488904030094, 8.518809464669998, 10.371985223985488, 2.1387049411573718, 1.4512096705936617, 0.4951231464022591, 0.40910228966705264, 0.22152563076346155, 1.2153410046331345, 0.2129132090316665, 0.19479139918281188, 1.0324245811470094, 0.5503309662303617, 0.631169973602218, 0.38031000884309896, 1.8757257105842715, 4.115725371145433, 8.382250185935728, 15.387935734564259, 24.14381031067141, 37.77582545434275, 46.77953204801006, 57.44262479966687, 71.93297416933122, 75.2498951265889, 79.61551666259766, 74.88294955222838, 70.1876449584961, 64.188909299912, 52.981419024928925, 46.37332747059484, 35.80716825300647, 32.599695151852025, 2.124292682255468, 16.827115128117224, 51.571762331070445, 55.783254331158055, 64.43323373794556, 63.339869130042295, 70.48074799199259, 71.03560647656842, 68.31958478496921, 69.92946670901391, 66.63564066733083, 56.698476652945246, 28.695985655630793, 9.527342031078955, 4.8284695513786815, 7.949880457693531, 16.527922614928215, 22.248322963714603, 19.471290765270112, 14.39128206622216, 5.288836667614599, 0.9347406486349722, 0.24707028101528847, 0.185789636246139, 0.6680090581217121, 0.37866972266666354, 0.22016501264466395, 0.16742221860876008, 0.7812915826516768, 1.1021070807210862, 0.2788327766522285, 0.3187858860098547, 0.4418189324919255, 0.3154901757596001, 0.06395173672166082, 0.44780315170365, 0.220104277194027, 0.9999461303795538, 0.4558602209773756, 1.1255498615003403, 1.3549355850104363, 2.6669391124479236, 3.2803178891058895, 4.627767753216529, 1.9941112999954533, 0.8090932811460188, 2.445293083306282, 0.32706309830950153, 0.1213205641796512, 30.640957624681537, 36.45144108803042, 33.143106199079945, 69.84632030610116, 38.06690454483032, 8.134619189846902, 11.486519844301286, 22.221176239752, 3.8074944913387303, 0.46607422612367144, 0.23388610702128182, 0.0486906792127317, 0.022730372635827913, 0.06851518076033362, 0.04002308765906961, 0.05658516930716653, 0.015220243217153175, 0.10333936976929826, 0.030236931127165596, 0.02040637980004953, 0.09259210614066932, 0.08615023366385892, 0.11442712117587367, 0.09639678222517814, 0.06700440940837707, 0.07596825099279804, 0.11024300940334798, 0.15235408119136287, 0.09363934067228148, 0.05182110216288317, 0.018843137170939196, 0.02430709458196596, 0.005240511109737019, 0.06882944534863196, 0.049811822076838826, 0.1392668479632947, 0.02649087609062272, 0.07499669828722555, 0.036934332231119756, 0.03246954882577543, 0.023353525790415948, 0.032162205841872966, 0.09273357193676696, 0.01648930138007047, 0.04701385447274774, 0.055671126822069775, 0.008261789034511293, 0.10709738343833916, 0.04214822705234251, 0.011279851784028355, 0.014376676990650596, 0.062349574910777236, 0.015198659647496478, 0.027891225444393295, 0.033078102259746486, 0.03613047617217226, 0.060693882706184546, 0.036311020113287434, 0.009825908834294928, 0.008306534314948705, 0.010644105101575055, 0.07619718104721078, 0.0865298149085814, 0.08209431904458231, 0.036332236918350386, 0.17511582512769008, 0.09048642921111277, 0.2864828080900254, 0.05024720516596591, 0.06918713180047852, 6.991088938328528, 48.86162811709989, 51.42612080420218, 55.64048005688576, 49.66605917099984, 76.29356722677909, 43.116811013990834, 66.65424839142831, 14.960618999696548, 1.8788173962985317, 0.9406778300481459, 0.6624839707247673, 0.7083228110305725, 0.705981094750666, 0.8980372536086267, 0.43821834989132424, 1.3381426925620725, 2.5504285385531764, 2.3778266003054958, 0.37277418579305377, 2.0809203386306763, 2.374473464104437, 4.960078798955487, 8.400057746518044, 9.22470763806374, 6.614291350687704, 12.974698466639365, 3.106871415530482, 3.373634752727324, 1.7122196261921239, 1.1838688869630138, 0.619779717056982, 2.4684083461761475, 1.71228128094827, 1.2054187564119216, 1.7629459235937366, 1.3487186282873156, 1.0876862416344306, 0.3231635269138121, 1.6552480574577086, 4.968364315648233, 10.831305557681668, 19.542424909530148, 31.042629903362645, 44.72679099728985, 54.659652171596406, 63.00943689961588, 80.94540411426176, 82.77813942201676, 83.0023499458067, 79.37334952815887, 74.04109908688453, 73.32787882897162, 61.88176331981536, 61.27884011114798, 46.938752820414884, 48.200787190468084, 2.957881655423872, 26.443323358412712, 66.62431286227319, 63.19836178133565, 72.19787536128875, 68.59038522166591, 72.18584152960008, 72.90349406580772, 70.73353690485801, 72.09488176530408, 67.17272297028573, 57.13385189733198, 29.547155672504058, 10.514891878251108, 6.757843725142941, 6.765319762691376, 16.31686870128878, 25.123951781180597, 21.310323438336773, 12.409160348676867, 4.780703417716488, 3.2791142117592598, 0.13026493180903698, 0.13254654083040454, 0.33978512210230677, 0.0515701700632851, 0.15571219696392938, 0.22262931831421393, 1.4778750461916772, 1.0868490607507768, 0.5907611645037129, 0.7180979703703235, 0.7161958659848859, 1.5044125770368886, 0.3104172028120487, 0.5338388092575536, 0.3165127192774127, 1.0368534273678258, 1.210296836591536, 2.298053680889068, 3.339861429506733, 5.232348163281718, 6.828263017439074, 2.509672906129591, 2.135918097149941, 0.3148094913171184, 1.062525340145634, 0.09353349030378366, 0.045480774640436136, 42.57561806709536, 58.18452935064993, 28.45470693803603, 74.59618506893035, 60.234438450105735, 29.321058488661244, 22.691658658366052, 27.964463618493852, 11.749349044215295, 0.6325235590338707, 0.05443164252585942, 0.1155354665412057, 0.007051661706364324, 0.014993631536321295, 0.2886000299646009, 0.017524295741872444, 0.04186447191562864, 0.046356233107226516, 0.06674949365157275, 0.01674851489013001, 0.06463553531155472, 0.060880819651027845, 0.06136685647370835, 0.14479935109134645, 0.08928986882129986, 0.10836472269147636, 0.09660328122516794, 0.1567138569249261, 0.16246785139364583, 0.05735193521926, 0.029051546044948123, 0.00637767143592599, 0.025768755867536512, 0.07796147387594947, 0.08681455446827797, 0.06657733071234918, 0.07400529624353494, 0.23177386471821418, 0.21081259594328944, 0.15000825868018214, 0.2257138028019859, 0.17521187723163636, 0.1519678043381822, 0.10125479856205565, 0.16725836772351496, 0.17286677484310445, 0.17983478884543144, 0.34424819713157995, 0.23709031572986036, 0.1550864257038601, 0.12617504119031853, 0.14819206339457344, 0.10039776834028383, 0.16204055819299915, 0.1703448287181316, 0.08921143673961202, 0.20319049607121176, 0.17105082470563152, 0.13452883929975573, 0.0986762768438747, 0.12300361338401995, 0.2643254002736461, 0.2796059738724463, 0.20933340273557172, 0.1589810481715587, 0.291133911739434, 0.18706478959610387, 0.5711512748272188, 0.15900760077901427, 0.2551953329314148, 8.25292964135447, 65.17821734951389, 85.03859350758215, 85.42691599938178, 65.67528363197081, 98.1268524354504, 62.866442972613925, 67.46450808740431, 26.08604838771205, 1.6077028022658442, 1.9923383886775665, 2.9640363445205073, 1.4952501654624941, 2.2279121414307625, 5.918043188510403, 5.551732547821538, 3.1971094637147845, 3.5747792884226772, 3.8045733061528977, 5.795642685505652, 11.357589575552172, 15.671974170592526, 13.252773919413167, 13.772839999968006, 15.834344606245718, 12.42648938009816, 17.601751858188262, 10.05371920524105, 2.1950659684596525, 0.6520243577899472, 0.5105793073533044, 0.2885429104489665, 1.8610207448082587, 2.0378587202679728, 1.1309488814684654, 2.901823631217403, 2.8626416046773238, 2.6410463211997866, 0.9465200778457427, 2.4144502609006824, 4.657486571419624, 10.266952976103752, 19.679990276213616, 30.6643977088313, 44.40532922744752, 52.71686300154656, 60.668499700484745, 80.07374363560831, 83.59652626898982, 84.25977553090742, 80.94367827138593, 75.9861240079326, 78.3137918287708, 70.10744033321258, 71.68168360187163, 59.360828553476644, 62.22973246728221, 3.1116780350285196, 38.166826924970074, 83.77718279438635, 70.00683153829267, 80.75327857848137, 74.16179826182704, 80.36504237882554, 81.64724165393461, 76.59322846320369, 78.89655405475249, 74.06851645438903, 60.45334200705252, 28.713924615613877, 10.438949888752354, 7.155282785815578, 8.516533509377512, 24.77988931440538, 35.77243958750079, 35.26357089319537, 30.43558232245907, 16.40678805689658, 9.802337442674945, 2.348380877125648, 0.373127352326147, 0.8992194804933764, 0.7984285405085934, 1.44453146765309, 0.8402492802950644, 1.5800146686453975, 1.6203256023506967, 0.6739197022491886, 2.0309303436548483, 1.292674822672721, 1.6120421694171045, 0.17793607056861926, 1.3394471257925036, 0.25074886668833996, 1.2621769236941494, 0.8685491198012907, 2.402852547745551, 4.044436538411725, 7.935753060925392, 11.144272454323309, 12.174339813570823, 5.246271106504626, 3.0218258500099187, 9.325065401292617, 0.5514921103754352, 0.22520430836706395, 51.28245615190076, 63.52126306103122, 51.29075588718538, 102.87161027231525, 78.6817729088568, 43.875303268432624, 50.955605045441665, 49.40248374016055, 15.16303095125383, 1.2853520027091427, 0.26955251011156267, 0.19310606703642877, 0.1801934252463041, 0.07658961724730269, 0.3798414081815751, 0.16631082421348942, 0.18144748053483425, 0.24978744166512645, 0.12784014861550064, 0.12891215843058404, 0.34322393757681696, 0.2169675301880606, 0.3221980416245999, 0.1616957420182805, 0.17879453337480947, 0.17740379267882916, 0.22179085040284743, 0.2412786256642111, 0.17596221438819365, 0.13171106066194274, 0.14935821775467167, 0.13705050963307583, 0.10898463337892488, 0.2752731644338177, 0.1917777012192434, 0.14899860076125593, 0.13610881903479177], [0.009180451987401373, 0.0875342251252263, 0.0145575474767435, 0.02654419772537245, 0.057733588731817664, 0.015746637551684775, 0.05967237723750934, 0.028541189761111335, 0.036341736408611464, 0.04278278151046365, 0.05138320630536445, 0.046168648818087195, 0.05661891931067071, 0.04402368306933392, 0.050725772631384676, 0.07497657315745469, 0.017750425744921933, 0.02475526367854928, 0.04679413279518486, 0.08944048936809264, 0.08747934258633083, 0.037744899220283956, 0.054154667267275435, 0.06770924094223207, 0.02713851916093019, 0.06529553538008083, 0.02229003295783074, 0.04772840766236187, 0.029390601238476175, 0.06359645961633613, 0.008087765459241647, 0.07522939749422573, 0.23392074951721778, 0.1042298703724819, 1.583319878385913, 18.862370252609253, 31.586772472627704, 29.025292165817756, 33.27816517122331, 72.06088266065045, 33.61122931203535, 40.63406444364979, 24.17375368456687, 0.30279619078482356, 0.8173199009991462, 0.36693763768961357, 0.09422228761738348, 0.3527146331485241, 0.3919455360981726, 1.8898184188911993, 3.0898323943538055, 1.3011774180396911, 0.8272024352223644, 0.5878630845296768, 3.593332834782139, 6.594034269932778, 7.0174992372912754, 6.039341995793005, 4.209696044844966, 5.981941050098789, 1.9459405493351722, 0.0906434848964695, 0.6465918138142556, 1.241667830655652, 1.5958471932718832, 0.387006965616057, 0.7241693091007971, 0.25907867858486794, 0.24010045904546018, 0.12820606285165395, 0.08791528491964264, 0.07556204053182757, 0.8824806432089499, 0.3879565775634781, 0.21318262683287745, 0.16027294820354832, 3.6994214259809066, 10.258562045712626, 13.906474171146272, 18.676316545855617, 22.219632787089196, 41.31048110223586, 70.52749479970625, 85.57850776180145, 75.8462836665492, 75.29330791965609, 53.46340771644346, 50.68247079849244, 30.40848266693854, 41.965893468549176, 4.681745940639127, 9.008241834179048, 74.60814829795592, 69.9867097793087, 73.23915481567383, 78.31021462717365, 82.5582278159357, 75.60279077099216, 67.1404104848062, 53.34948639715872, 35.93728111636254, 18.00252983647008, 5.616363892632147, 1.8129529563650009, 0.29836703812883747, 0.5541394038065788, 0.1574675495465917, 1.374059345933699, 2.1638755259975313, 1.8751304909106226, 0.8478277897642506, 0.31648602877413073, 0.15835965893441634, 0.22861787358358984, 0.13649935533683147, 0.27651269469530354, 0.04305707163087303, 0.24217626620684904, 0.20740866811285097, 0.20760814208657513, 0.4808453206093081, 0.39649278886856576, 0.40099104265532187, 0.05138181202534226, 0.1133789903213901, 0.29648932598290906, 0.1662793379998015, 0.5826805916524703, 3.6082098945494625, 6.161605706137996, 4.094873070716858, 1.872124361895746, 2.91684361234788, 6.27036371538716, 2.2917781337614986, 0.2551017016653092, 0.08753208773991755, 0.4177663150814272, 36.61248576256537, 36.26723481762794, 24.62512435451631, 65.69914733209919, 46.45934504847373, 12.20758484255883, 10.40041946595715, 24.9493121716284, 12.594723759158967, 0.6897330440340504, 0.1154850502949088, 0.06043166996190145, 0.0634632101132264, 0.031660065851024086, 0.036457335245945764, 0.05447306106948564, 0.026933326340851285, 0.039053070959785295, 0.10617044003259753, 0.06120961309681016, 0.014996726531535389, 0.031580837037895, 0.016117760228113304, 0.07831185950987762, 0.08497668655529138, 0.022306963500957337, 0.03719058481135196, 0.008799698628154735, 0.1036896251682793, 0.014510739504569962, 0.11742319145630445, 0.08108871373077554, 0.08659493238214525, 0.06656089046549413, 0.10331748263730157, 0.03739553248329509, 0.1436577115448252, 0.056459013778235645, 0.14616986706612572, 0.059390376442142075, 0.07553238526827867, 0.04233464688783692, 0.009598542556857631, 0.03266737954090199, 0.031693195323309595, 0.03182575343206766, 0.01486731704414612, 0.05932854931621302, 0.08179372912573238, 0.02983316065623395, 0.02976227645582009, 0.01248366223843468, 0.02092228639089773, 0.038361435290426016, 0.06913185089586243, 0.06935099800748211, 0.025899622837201725, 0.03879256276113372, 0.05261638186751835, 0.076473233169846, 0.03705460803523179, 0.033266268775708256, 0.07163046198266168, 0.04117822567481668, 0.03212943451569206, 0.05906389275145146, 0.07676974750093876, 0.02336874987269121, 0.07364672879057546, 0.06642238942966347, 0.35351697235338153, 0.09721417505774768, 15.67317931882797, 52.95322110576015, 54.08096136585359, 47.610176301771595, 58.44910106351299, 78.19621486048545, 36.3135148632911, 74.99641587657314, 24.309165670025735, 0.7551247157877492, 0.7023161914079421, 0.2957042084345895, 0.42925836939004164, 0.3099070495415119, 0.8190675620590487, 1.6591646666488342, 1.6127602083067742, 2.7677957521330927, 1.9916356715463825, 1.4871396845386875, 1.6399901600614673, 2.4010369806520404, 1.8984430980297828, 2.5112575436792066, 3.8636973980934393, 5.005877863976264, 0.3595048075001086, 0.6385157149164908, 1.1115648957990831, 0.48771320691993164, 1.328960301414613, 0.7684456364762399, 1.7910001859549554, 1.4212384723847913, 0.8087419225804268, 0.14140853868617168, 0.06068812172499396, 1.042469403436107, 1.2704615823684202, 1.126494539841529, 0.6195326077361262, 2.0209588206583455, 6.7193966527138995, 14.116432762915089, 18.526074078775224, 24.830060351279474, 30.660545941322084, 48.96631225462883, 76.82311857900312, 91.10737877507364, 78.66349466385381, 81.00938581651258, 62.62938668650966, 63.36062239062402, 44.70668100541638, 57.031736912265906, 4.749842209200706, 10.69187020101855, 82.91725020254813, 72.96179617604902, 78.72179677409511, 80.48944427121071, 84.00621783348822, 76.70632608475225, 69.13730482901298, 58.2671776125508, 41.77066533796249, 24.164292927711244, 8.631193214847196, 2.2362775764157696, 0.4389446012435421, 0.8625985165276836, 0.8786175988854901, 2.5986454996370503, 0.9620122755727462, 2.432017331161807, 0.9286469401371096, 0.2977176713607004, 0.1738915093723805, 0.18068537626776005, 0.013149533413290499, 0.51082672310933, 0.6267714644632032, 0.39562888683811315, 0.33850020879218656, 0.4077239442736872, 0.11701966996394819, 0.7208207694272841, 0.8726475063350894, 0.04719788028347877, 0.2807245235289297, 0.598967804783775, 0.8159424136242559, 2.1019716993454964, 3.747743065318754, 3.936611317819165, 6.108754219547396, 3.7415697449638, 2.293883465951489, 1.1353437746724775, 0.5137465599804155, 0.21622007352209863, 0.48893931532098406, 0.5336765824787079, 47.50219737329791, 65.5301441684846, 29.397750631455455, 67.78793104233281, 67.41393304640248, 34.032672297570016, 29.189933653800722, 27.647836169888897, 20.165124708606353, 1.195120573524506, 0.20909875000436462, 0.029667423279475302, 0.04171442210433945, 0.08183221738304823, 0.08192024854642731, 0.07062566872205465, 0.056890788593239365, 0.033829416178407214, 0.062231811875056844, 0.053350125559635704, 0.0424183305022457, 0.05900861184683539, 0.16679660056627568, 0.052697127534737515, 0.015827595808302924, 0.08023882344845804, 0.03427438302746704, 0.009825719227533667, 0.15006220659180997, 0.01543212781525067, 0.18108201062967702, 0.15314468392922034, 0.03907733679478688, 0.046429134034101045, 0.04484513999834176, 0.05728718929833943, 0.09389540556097224, 0.02419869122546046, 0.3107946696541002, 0.16288754500208363, 0.25344888229043255, 0.1456060110320968, 0.11885456545578858, 0.1971987845195878, 0.09098441700541204, 0.11042696243572621, 0.13673250653570698, 0.24059184316185214, 0.2219026992397924, 0.13132479913052053, 0.09856197652557204, 0.08274301165534605, 0.11909333974002831, 0.20489755447112745, 0.09581939707840643, 0.121658569832723, 0.177079783452134, 0.15724340754170574, 0.14006083680977746, 0.12906393577014247, 0.127282107188817, 0.11775637075545327, 0.2324284255624779, 0.2098495927789519, 0.1072308129721111, 0.10116292929817593, 0.1396287172552078, 0.1367632726267461, 0.32666819530629343, 0.2170588785121518, 0.35603010846722516, 0.2308214488889902, 24.02669422088131, 83.49932209137948, 83.72529768174695, 75.70696892276888, 65.23158511807843, 105.2402433272331, 54.50977448494204, 71.01673203129923, 37.15323548163138, 0.2946684882044792, 2.060252879896472, 1.0208829456279356, 1.0587815603902264, 0.6135909523694747, 4.049296845351496, 9.549397518557887, 6.35838758560919, 2.931248026509439, 3.3425058424472813, 2.6015826194517078, 5.120162002501949, 12.500289755482829, 11.10947024437689, 10.285736226266431, 7.079586434748865, 11.021774872656792, 6.728756408537588, 0.42889346638994835, 1.8069343244837177, 1.5628495187528673, 1.6553656059888102, 0.8560139601749759, 2.2278631118036087, 1.4789648522292416, 0.7000708796324269, 0.2363210102362979, 0.24206493830969258, 1.5207503519711958, 1.529675582724233, 1.5074405242358486, 0.937055459906978, 2.88861382392145, 6.612577274922402, 12.790603983786799, 17.84334240421172, 24.913548000397224, 27.89907378535117, 47.28589434777537, 74.48228728386664, 89.52198028564455, 82.09237575531006, 85.3939994688957, 68.63728892418646, 74.04517835186374, 55.74147324408255, 67.7041962838942, 5.6183991124553065, 12.209571523051109, 90.58325598316809, 78.54475667399745, 86.99256927736344, 85.96123695373537, 90.17385467406243, 83.13426709944203, 75.58216694862612, 62.640220272925596, 44.03233928065146, 25.086850081720662, 8.795040422870267, 2.3628009807678962, 0.5023154862705739, 1.3084276741550815, 0.9293366031300638, 5.531445068697776, 10.154814374062324, 5.589825626342527, 1.734082182088206, 0.4395866442111231, 0.45775515477984186, 0.5535153179399429, 0.3648510899755263, 0.5884511336203545, 0.5947104396839297, 0.6337918329142755, 0.9953022892436675, 0.7162945993965673, 0.48734404447097934, 1.0223415157487317, 1.5049065505304646, 0.15178734466673868, 0.4156984599126924, 1.6051353658399277, 1.2880396842956543, 1.863789938149914, 8.776077724272206, 13.362571847054268, 13.808691443935519, 9.100398901970156, 8.850423309110827, 9.636261347801456, 11.098754329066123, 0.6160940374097517, 1.1247548460960388, 0.8890024416389004, 60.696654473581624, 59.93985276068411, 39.34788004044564, 98.2825783760317, 85.9551102115262, 43.97991288092829, 49.08741935606926, 53.031797947422156, 24.57926792483176, 1.232114040082501, 0.267683562011488, 0.13185828743923095, 0.1643890160466394, 0.10817368334579854, 0.1848554992747884, 0.25149906594907084, 0.18259834377996384, 0.22700268444755387, 0.15214835594017662, 0.15071146610763766, 0.13687012657042474, 0.32991046326295026, 0.3230473879844912, 0.20347759518171513, 0.18977353860053325, 0.20678904087793445, 0.16875369474291804, 0.22208977791090168, 0.20704272323318068, 0.1287168060098925, 0.3098576215486373, 0.4596338168747964, 0.18792126057369096, 0.18029736805587046, 0.18462862999689195, 0.23200436525287169, 0.21314901089476002, 0.19669500510058097], [0.03897258576246039, 0.03810999757279793, 0.051878106765328884, 0.04258094415549309, 0.037477975035266536, 0.06254996052913128, 0.017971149082445813, 0.06610918970357987, 0.07232947124829216, 0.05162555822021058, 0.09737025781144058, 0.062022980137337605, 0.06778958824373062, 0.028774346705646287, 0.07928009505473799, 0.08562492717417979, 0.06802692994355194, 0.05227784761377881, 0.023528094245721737, 0.0532621058875755, 0.1202645349586683, 0.05495980652349611, 0.04193061594701102, 0.016453375686861334, 0.013469107948514003, 0.07694496713098019, 0.019778337089284774, 0.03409159827917334, 0.08324248566021843, 0.061263710395583225, 0.043976097517917236, 0.09432069927213654, 0.06089155637328664, 0.2999256286890276, 0.5382167259531637, 3.524410171854881, 9.691453018496114, 29.925336876223167, 30.869339589149725, 46.806839589149725, 73.3937511136455, 37.547743551192745, 39.08179429269607, 34.70416245921966, 1.472537803553766, 0.8758463217846809, 0.2994308891075273, 0.4443366344897978, 0.030715684368906003, 0.4128388375524552, 0.6879592134106545, 4.852282260694812, 0.9424795462719856, 0.5162347216279276, 0.7848803674982441, 0.4803450958382699, 1.8126721391754768, 3.1501170175690807, 4.553482965115578, 5.874264634424641, 0.37982951849699026, 0.24622147091694419, 0.9536513758282509, 1.0806664247666637, 0.42167216839809574, 0.23584148516097378, 0.44061638895542393, 0.48048087726196936, 0.13469117333091077, 0.31156351549490807, 0.008384796899683293, 0.30297864228487015, 0.8052763246720838, 0.6283702593176597, 0.5200434043522805, 1.1544745223176096, 0.5895713380267543, 1.3277600561418843, 1.1683109282485902, 1.0580873008697265, 2.1967378787456022, 7.517860800989213, 16.30037513471419, 35.2447513611086, 50.850791469697036, 75.25347232818604, 61.55961905756305, 54.16193085332071, 43.56608321589809, 33.63135891575968, 0.543038483348585, 5.074941977377861, 48.876509589533654, 75.24809083630963, 81.63716116259175, 79.15546970982706, 69.48910220976799, 56.39990191305838, 40.56790974832351, 21.912381764381163, 6.2292935579053825, 0.2749249315069568, 0.40360291218084676, 0.19201190961945444, 1.2610888336935353, 0.36216003760214777, 0.4744376386365583, 0.6314783699570164, 0.1019721479725934, 1.2148703202124567, 0.4644119991890846, 0.1678102574641666, 0.1123003232022447, 0.06496961093357494, 0.09533789549623767, 0.06890835240483284, 0.028792910931271412, 0.23923105650371124, 0.22656563128675186, 0.2615069934437352, 0.37710779196312355, 0.37876860929592965, 0.19810564876083406, 0.2939749028413527, 0.21994516073215395, 0.2641206709367614, 0.1250314174760734, 1.2810231769277205, 2.4791566210408367, 1.9347253898459098, 3.6863864093057575, 4.055625589624528, 4.893491662317707, 0.47794923246387516, 0.9584656562055311, 0.6508750420424246, 1.9171812409354796, 46.360936703220496, 33.5007792903531, 21.166596028112597, 54.98888807912027, 46.2439049443891, 22.363209186061738, 15.990805010641775, 22.055189378799934, 23.956405347393407, 6.111231686607485, 0.4291000343378513, 0.015183715187313577, 0.05320876701584747, 0.018183910851216605, 0.038604158757915424, 0.007726070931136249, 0.038508401597819986, 0.07256497433709522, 0.024242725959348104, 0.017857568886791988, 0.07929709454577777, 0.07860880285020798, 0.028604621841241757, 0.04543652157149008, 0.09051264473988165, 0.03557643372445338, 0.09813731100650565, 0.0706226350138745, 0.10292496982841723, 0.06058840389032999, 0.041318006077480894, 0.049756770998600035, 0.07055729537481262, 0.044386640206099524, 0.03916248363713103, 0.035945056081419034, 0.035081640516798344, 0.04327435331839708, 0.08511320342339816, 0.09922514053722543, 0.002747998322217515, 0.06766006575837251, 0.04450733735856991, 0.04768147711612044, 0.10305598618522768, 0.11974958597772545, 0.06478047148594934, 0.03857440773337599, 0.035333771543997916, 0.08671611217000792, 0.06909662617310401, 0.040239308314818534, 0.050489618367845976, 0.07684624904105741, 0.06762527004485169, 0.06851963939205294, 0.0606919598254946, 0.022979536987540704, 0.04181990475063363, 0.04193129393482401, 0.050486465916037566, 0.021866321218230074, 0.04739538924167714, 0.02873341654307179, 0.03742221149525816, 0.03526568164928787, 0.10334877732900843, 0.08535116565443816, 0.09877027583218391, 0.08392535345328432, 0.18518456468178382, 0.07673561062303282, 0.44097393751144415, 3.2378464648800516, 33.86381426165181, 50.28413057327271, 51.619470119476325, 47.2027361777521, 72.12371903081095, 78.62227839808311, 37.81431959521386, 70.82095084651824, 43.2708974038401, 1.9384594862499547, 1.0816633196607714, 0.4392595246674553, 0.6427542036098819, 0.09155676129364199, 0.3313589516666628, 1.7730962821552831, 3.6029203332239583, 0.9725592225309342, 1.8036693190374684, 1.8180641724217323, 2.187741187310988, 3.096651434898377, 3.621162786599129, 2.826312366993197, 1.4848683870607808, 0.12193171082124596, 0.4707464737997901, 1.117298665546602, 0.2590359308786931, 0.4133817487426343, 0.28859206265018833, 0.4809690284873209, 0.6119369991844701, 0.7956575698429539, 0.7224950086205237, 0.04512984891452136, 0.5591795881909709, 1.2322512004644641, 1.428798228021591, 0.7985203484854391, 1.436215062295237, 1.480258131219495, 2.038656800023971, 2.0670966804027557, 1.561231418482719, 2.819347218159707, 9.01761531829834, 20.591680503660633, 37.2805634621651, 52.65456791846983, 76.78955093506845, 71.12105138840215, 64.14843436210387, 58.323173369130785, 38.46655876405778, 0.47652954896611555, 5.997319192655626, 54.29372249111053, 74.83193520576724, 84.11577747714135, 78.78773966143208, 75.16704682380923, 59.586278546241026, 45.942776741520056, 26.389071095374327, 10.132957946869636, 3.830962032079697, 1.5762849849077964, 1.4466698948414096, 1.737028249809819, 0.61428374100116, 0.658046605606233, 1.304794333634838, 0.8265322615062037, 0.2098913445708252, 0.25010700758186083, 0.4682559526014713, 0.15440214064813432, 0.08822057861834766, 0.07771392022409747, 0.08697440637455833, 0.17268715786837763, 0.43256900303306123, 0.3317200855141686, 0.30792545587305103, 0.4069714927144589, 0.7558939293507607, 0.40628483278616784, 0.4254723628682475, 0.12318238766203005, 0.1794172402831816, 0.5985709099519638, 3.0097069519181407, 2.2041055608180264, 1.6374379228199683, 1.5568148296686912, 1.72151233400068, 0.8332987177756526, 0.5923090298329631, 0.2704306920209239, 0.4455262158186205, 0.8655232563614846, 56.54165244871571, 64.14016208341046, 22.843928990825532, 52.263958684859745, 69.26028682339576, 40.990925604297274, 28.816578926578647, 26.581659470835042, 39.44538231818907, 9.041723185969937, 0.5072838422511855, 0.009755925744802002, 0.07322092946138113, 0.0270853660655238, 0.04766578763543118, 0.0222804147239414, 0.11045124742292589, 0.03106180097787611, 0.028418389697288795, 0.06695346456141242, 0.0019039255200750047, 0.1304547377531567, 0.06921511699235247, 0.13299333862960339, 0.05425587514295213, 0.023753312604141333, 0.061739512283595345, 0.07363027322196192, 0.07744714542622529, 0.05799097895261742, 0.06275706856902089, 0.023024219065724362, 0.10686591763289706, 0.13414138267117162, 0.06629016265393266, 0.03328473149468342, 0.03431200177498883, 0.06472991734382606, 0.013745665689179254, 0.27564909910002067, 0.0912799813874787, 0.15689782527906282, 0.13083470204184133, 0.21824914932010636, 0.19181543871039347, 0.16247329061790822, 0.18435407940658832, 0.19165885033867053, 0.1805753353983164, 0.24841203804939027, 0.15654280481319274, 0.09809337586404816, 0.12999120859369157, 0.14016217492040128, 0.13416202107985176, 0.1366325167398299, 0.20792829023013193, 0.08076461257352945, 0.22975969699121293, 0.21300661047139477, 0.1413056530779408, 0.13058915554035094, 0.172084154741418, 0.21995390945624924, 0.15515643081838085, 0.16202503725165324, 0.08759281552967527, 0.15107462242726358, 0.3169417898020437, 0.3365927724347961, 0.2790713670753664, 0.15134564901311554, 0.42176989057371694, 3.245853738438699, 58.348633473919286, 82.6293090081984, 73.72614060678791, 69.80383319239463, 83.08386464272776, 107.56590289454307, 55.034081628245694, 70.95147948111259, 57.206953110233435, 2.8831492268270065, 2.0223707513463114, 1.0479695470102373, 1.1007879386025092, 0.10846440605218373, 0.9075298184348691, 4.141370807924579, 12.945195378795749, 4.5829659508120635, 5.993477721368113, 4.012140723005418, 3.0131811912982696, 3.636573043561751, 8.839708374392602, 8.835706576224297, 10.573607798545591, 3.9245242889850376, 0.4996308996792763, 1.9347756452137426, 2.7557668234071424, 0.5757859229080139, 0.483632838774112, 0.5920124005886817, 0.6929938206749578, 1.3040379290619206, 0.8700845438626506, 0.19576586302249663, 0.8197800851156636, 1.8141436408604346, 2.2090109750147793, 1.7643866591876554, 3.0427771902853444, 2.609095674368643, 3.195859943666766, 2.498356377886188, 1.942484818639294, 2.696106102197401, 9.369204813434232, 20.350074268156483, 38.19651926717451, 53.96797749304003, 83.10184478759766, 77.7264404296875, 74.55798902819234, 68.0743189780943, 46.18368087276336, 1.2866574165321167, 7.459412092162718, 63.633246729450846, 87.24206339928412, 92.99125394513531, 86.99184756125175, 81.88827914576378, 63.85360548573156, 47.1341613800295, 26.037399230464814, 10.250242698577143, 4.285005061857162, 2.4848330261245852, 2.9618984076284596, 2.7913566943137877, 1.1213472870088395, 1.815344253855367, 3.6462814000345047, 2.1895295429614285, 1.8679351479776445, 0.8601869330290826, 1.3604742168418824, 0.32526597861320744, 0.2044236371594091, 0.1748963562591422, 0.27358577917179755, 0.08840083144605161, 0.6866540447358163, 0.4658411821771053, 0.5994249447699517, 0.47842892607854265, 1.4381150829215206, 1.0740764751549692, 0.6464802101254463, 0.21771987449497948, 0.492044085816991, 1.1615208151840395, 7.779054372541367, 7.046866513067677, 7.755819722529381, 10.225391541757892, 8.24638810849959, 9.800438034919, 2.426355144669933, 1.168227087586157, 2.2681424213993937, 2.112355438932296, 75.82126678959017, 52.576449994117986, 34.08591847265921, 82.48323994298136, 85.43794570430633, 50.78870819460962, 53.43411545599661, 53.7523530375573, 48.02456294336627, 8.382030533206079, 0.8648171071563998, 0.13343330292451766, 0.2030933714441715, 0.13559109681556303, 0.1881090440456906, 0.15622072612806676, 0.19032453967919274, 0.17570329199154533, 0.18070659690326263, 0.15223878495875867, 0.2156652726473347, 0.21317793837478086, 0.13168781755432007, 0.19537587830376243, 0.22666485499470468, 0.08593824181345203, 0.20580057295099383, 0.1432095807526381, 0.2750794361195257, 0.21116507299725087, 0.1539745716558349, 0.1160803695599879, 0.2028826819432359, 0.2581366662296557, 0.20189277377099762, 0.20332436227510053, 0.13489095373980461, 0.11105336188789337, 0.09335017312438258], [0.06674744053593566, 0.026472039903784474, 0.018378771060416778, 0.01397898446978821, 0.04663778574115807, 0.07352571754205613, 0.04988227152235566, 0.0451963798203055, 0.04797915207041849, 0.03954615579136918, 0.0226984420911439, 0.11382817065403347, 0.035697594360117955, 0.016148497590855244, 0.107136944218749, 0.047255681617365736, 0.04430032891011046, 0.05926552326268247, 0.09231433032020446, 0.02914951528392492, 0.10772252650631052, 0.04665931664226998, 0.024570035109777125, 0.03155090598269336, 0.04692764276818884, 0.03956775180995464, 0.02714144178636132, 0.07173008405633512, 0.061784585066620386, 0.04848869630105553, 0.09342304340774014, 0.05286790768525774, 0.17855202058149924, 0.13023027399134252, 0.0848337268877414, 1.2852610527507722, 13.315169022929284, 18.436640116476244, 36.902470511774865, 29.534141248272313, 50.86151915211832, 70.0841885228311, 41.49231433868408, 39.844055944873446, 44.10003938982564, 5.774381477986613, 0.5277301467234089, 0.47563849677962644, 0.467276739016656, 0.21918259681232516, 0.6442986368652314, 2.219423151785328, 1.4188477877647647, 0.22415171888086105, 2.4072907095955265, 1.8914120043477707, 2.437592244917347, 0.43012076988816267, 2.5986773688947005, 0.43182448814472846, 1.5255716803573793, 0.09947509970515968, 0.41892819467090797, 0.21727770386684328, 0.36777258159652837, 0.2479347959160805, 0.17843125448111566, 0.10686260813306417, 0.07449593725464038, 0.09198704223719337, 0.04801050804915929, 0.008175969950013585, 0.08432553480229071, 0.10091967339957915, 0.22944521789829578, 0.44810312109128125, 1.3075181745713758, 0.5499129273718404, 1.4684263015947034, 3.201680005558076, 2.140212602192356, 1.8944156818812894, 4.960319534424813, 9.845890460475799, 15.8427208277487, 45.283622434062345, 55.33568443790559, 41.58697682042276, 30.471199404808786, 3.886177972439797, 0.9351272472450811, 1.1923827591442293, 14.500167062205655, 41.681925635184015, 61.627409381251184, 58.29594427539457, 49.56350488047446, 38.21669201697073, 19.0081569071739, 8.462990214747768, 3.2438219506894392, 0.38409690402688523, 0.19617533701802456, 0.5010237088126521, 0.23432377305242325, 0.1275624647255867, 0.23153453885066896, 0.302986272520596, 0.16741012974131494, 0.07563219120305392, 0.13880537191946662, 0.12174400395803875, 0.03047880423705905, 0.0195275831051291, 0.17904112175587686, 0.05704284172445055, 0.15440402522442803, 0.028091961547972697, 0.24406491808833616, 0.0208997844733418, 0.20811247308888745, 0.11480893173645582, 0.425569839895733, 0.19710933609354883, 0.30356862191711703, 0.1301711013600711, 0.7550265339593735, 1.7217417926557603, 1.7347546234246225, 1.2138212087654299, 2.0909559678646827, 0.6632255438354708, 0.22057928235059787, 0.2814899372958368, 0.918949002460126, 6.222414701215683, 52.977582946900405, 25.159988557138753, 22.571330147404826, 66.78895042788598, 66.09684821098082, 18.09979481081809, 9.733658702142778, 21.38741566288856, 22.062333976068807, 6.690306884627189, 0.260717218080836, 0.08325301936917728, 0.16334367375220024, 0.04564934079685519, 0.04158538608481327, 0.09384770126592729, 0.07076633012583179, 0.1070661576945455, 0.02930827168447356, 0.04418613967455683, 0.044609311322170886, 0.024958790257392872, 0.004940154847703995, 0.07086963708242101, 0.049388225250426805, 0.07786308520383413, 0.06718436346179055, 0.034919972982137434, 0.07085970858292234, 0.025373510039982297, 0.02789648272277367, 0.0413762977076394, 0.03946887667200739, 0.07402216549962759, 0.045498107379722985, 0.05116861741689425, 0.01740964493834444, 0.03300250470337849, 0.05558582293170114, 0.04059584180433904, 0.0731043768445811, 0.03838012400533884, 0.03370922464396685, 0.11488616106010253, 0.065813081399087, 0.13167773583723655, 0.07842630538488589, 0.015142045749892152, 0.04349624302478568, 0.10092518157175473, 0.06007540843359405, 0.055699272892407836, 0.06629528012126684, 0.07131592926358984, 0.08014191332603655, 0.08036043990643756, 0.08168991655111313, 0.10883550670358444, 0.04047003101497408, 0.041056800738818226, 0.12962918608419358, 0.07242045951105895, 0.09215362805632815, 0.07588720655128842, 0.0664091514303319, 0.037383010776172725, 0.054235918552524624, 0.08853308886529938, 0.05177402605993613, 0.028264258552582997, 0.10293158882808301, 0.10491355021874751, 0.14817122580303302, 0.18508420716370308, 0.21250359714031222, 9.31496725928399, 36.69292180768905, 51.46086515918855, 55.87912882527998, 49.46704987556704, 75.89926704283684, 70.20353840243432, 43.95020484924317, 68.04240657437232, 56.885122637594904, 4.786606094529552, 0.6832757808508412, 0.44197984159954135, 0.376665452795644, 0.2263827967427431, 0.950811641110528, 1.9596849021411713, 2.122637196894615, 2.0481039511580623, 2.8685175603435886, 2.629892571318534, 4.348612668052796, 5.677130722230481, 6.519600922061551, 3.8945833665709344, 3.726859631076936, 0.8097325661970723, 0.2599888523259471, 0.34997559302756864, 0.042772466136563214, 0.5290049170294117, 0.2636553491315534, 0.16122145698435847, 0.8551462583484188, 0.5001736576518705, 0.296227507773907, 0.06853812509366582, 0.0843640843466405, 0.11392360988764033, 0.23479450343837663, 1.0131119948721703, 2.2512723072882626, 1.0217628435742472, 2.7683953844731857, 4.506533174745498, 2.5262606095883156, 2.876487816533735, 6.714967806493083, 10.688630323256216, 16.04490920420616, 45.079616039030014, 56.64413221420781, 41.58944006889097, 29.050897398302634, 3.0950525787568863, 1.7085562550252484, 1.0764155560924162, 16.73335086914801, 49.164089925827525, 66.50949724258916, 66.25155433531731, 56.084943432961744, 42.88192379859186, 22.045761962090772, 12.206780756673506, 4.111659834461828, 0.2671518969920374, 0.17168627931706368, 0.6474205983742591, 0.4619066465285517, 0.1084200342396094, 0.46483319432985404, 0.27499145858230134, 0.07420161393501105, 0.06867743818269623, 0.22134748467754936, 0.2521643520242745, 0.09954918806831684, 0.14259868692005837, 0.07035398330058783, 0.12090665453504171, 0.17129600348491825, 0.37990177591000834, 0.18090956423792148, 0.03393189959047783, 0.36978181571729724, 0.26515829106492383, 0.298623095356649, 0.24243365642764877, 0.41354587541953214, 0.18257543775102786, 0.9285261433932089, 2.631872387663011, 3.376540003284332, 0.7297378490048071, 1.87983512878418, 0.09432231571765677, 0.8178936089238813, 0.45856297917423716, 0.16227799948425065, 4.457758011356477, 72.33726070773217, 58.57909233339372, 20.258616362848592, 53.7621432735074, 84.45873383552798, 38.349562306557935, 24.044107583261308, 36.998117508426795, 30.992502012560447, 12.724189431436601, 1.068777475626238, 0.06190955315926864, 0.0769724237221864, 0.08982819880569175, 0.03285141301251227, 0.08442034584379966, 0.013617817105935707, 0.049238895561786435, 0.05579929716224152, 0.04177700765731354, 0.016734949388210813, 0.046861920085164814, 0.06659472090823036, 0.06969377638832217, 0.055420711831820596, 0.046969769943145015, 0.020616414295809887, 0.02509049417811536, 0.08671364536689175, 0.05658242671239761, 0.031356191330198804, 0.032326853458559325, 0.022401546631308816, 0.045843869673028115, 0.02543914270767522, 0.05841282143768284, 0.09170073985813126, 0.09091716214653947, 0.04906522342935205, 0.028190103156732458, 0.13629078023856686, 0.20297790667222393, 0.07256901162045618, 0.18943955490906395, 0.21886370505296418, 0.28191318555224326, 0.16547986396378087, 0.12582778885600068, 0.14857832492599565, 0.19703447398158813, 0.10842971759097231, 0.17523193341349402, 0.2172792513644503, 0.14090506570233455, 0.10325781970975861, 0.15709680895651543, 0.12254456583891185, 0.17098032929483922, 0.16630975169039544, 0.11246607398554204, 0.202321982191455, 0.16771569157079344, 0.10847633404116477, 0.18556774653975042, 0.14703133293697912, 0.16413395473312947, 0.16262189635346014, 0.1759626740409482, 0.10729154076186881, 0.19211934578995551, 0.19856006147400027, 0.20452909682306553, 0.28836238949048904, 0.22391844510791764, 0.5661450434596308, 8.70743134329396, 62.721358422310125, 83.57611425461309, 79.13615595909857, 66.72375279088175, 85.64593330506356, 108.84692545860045, 61.359480119520626, 65.41615616890692, 76.57320868584418, 9.99106228351593, 0.9226431397180405, 0.7293000757213562, 1.8447745327026615, 0.3493932129875306, 1.159889109192356, 4.8850796491869035, 7.843244941003862, 4.314366454078305, 7.573578069286962, 5.1878518154544215, 5.22232650749145, 5.65317778818069, 5.551164294442823, 6.514863189189665, 7.160499047848487, 0.41609222910577254, 1.0516245831404964, 0.44871957672219126, 0.9926861909128005, 0.5576329486023995, 0.29196061254028355, 0.2620053183167212, 0.899862994349772, 0.38994353384740893, 0.3408314143457721, 0.24099284422493752, 0.26957530888818926, 0.2738836035132408, 0.6370648056749375, 1.3359835503562805, 2.7370919287204747, 2.55661289057424, 4.106500446796417, 7.428526859129629, 4.010978230545598, 5.058742098269924, 8.978589696268882, 12.213972422384447, 19.43856054736722, 51.73940050986506, 61.97562956040906, 48.27707336794946, 34.05542204456945, 4.631628836354902, 2.4348308963160363, 2.739836116952281, 18.88371971345717, 54.13594515092912, 70.00091660407283, 68.68221575214018, 54.98598944756293, 43.09099005114648, 22.23361211438333, 11.879816882071957, 5.740698124131849, 1.427980536414731, 0.961223388871839, 0.6973537189825889, 0.35282347892080584, 0.18272885451874427, 0.8202654171374537, 0.6301945904570242, 0.20116305970136197, 0.19626657808980635, 0.3386431914423743, 0.3587027747304209, 0.1937356074490855, 0.2744559631232293, 0.26429585992328586, 0.1533114459485777, 0.3190183783731153, 0.2881696417687401, 0.29635749757289886, 0.040472375244022384, 0.7547830405735201, 0.5488274727136858, 0.9900194694918971, 0.4578480046362646, 0.7622895377778238, 0.3149551399532826, 1.1852750566697892, 10.637765026861622, 7.858094053883707, 3.8148094665619636, 6.832110862578116, 5.868628678783294, 2.5535299076188, 0.6495978815420982, 1.5964156917987333, 9.954755844608432, 84.37729758601036, 43.27594941662204, 38.23302476636825, 90.03086074706047, 99.77600512966033, 42.922747827345326, 37.00982970576133, 66.00584922298309, 49.81595646950507, 11.42260874471357, 0.8712475266187423, 0.1884370828948675, 0.3186872751722413, 0.20989604835068026, 0.17510833278779062, 0.16137433749052787, 0.16403755022873803, 0.23130923239213808, 0.1694429134048762, 0.13722913069350107, 0.20661814198378595, 0.1972486415217, 0.13465559620770717, 0.1493558428821064, 0.17138862351496376, 0.2621372999443162, 0.1620204713676245, 0.21872806152509106, 0.2155899968478949, 0.13107543751116724, 0.17125417508425253, 0.12825146888292607, 0.19718755367061785, 0.17060486960314936, 0.3246146506599842, 0.18339889033907847, 0.27766777142401666, 0.17571403254424373, 0.1809030678123236, 0.20270065945242682], [0.007692216548152389, 0.060561123499346364, 0.04645993076865712, 0.07319911127729763, 0.039092853905693184, 0.01540619478140387, 0.0839742451846119, 0.012739072121950168, 0.03734548395920185, 0.04616723155542728, 0.10363796019866582, 0.06437217726582481, 0.032193872086223096, 0.038903603375318556, 0.019963412440472075, 0.04934056309021769, 0.04169949871157447, 0.058941410614117506, 0.024408739127759493, 0.01490811026850415, 0.10220997996868626, 0.04879736844750662, 0.0685795704503694, 0.039543842205837856, 0.023568672007851066, 0.029771795098279274, 0.07985398684057497, 0.036620760952392896, 0.03076972421108475, 0.0681465469120491, 0.057829721274996, 0.038816560465361805, 0.11912289541214706, 0.08659661777557866, 0.30457529209313855, 0.10627285066631534, 0.6579227445106353, 17.988238680747248, 36.329012147841915, 33.832874605732584, 25.671702931004187, 62.23738893385857, 69.16371806975334, 45.183052862844164, 33.54248193002517, 40.73265714030112, 8.904639290225122, 0.6531840923332399, 0.6470658077347664, 0.12897123913130454, 1.01068037051347, 0.4091760792559193, 0.5251866122407298, 1.990476733734531, 3.232700805510244, 4.6456567029799185, 7.152732754907301, 6.517866253852845, 4.7874459720427, 1.0686202130971416, 0.4057117377317721, 1.112022832516701, 0.6845545961010842, 0.22684684684199674, 0.21004659994955988, 0.22189727533728848, 0.15414093530947162, 0.056749307475383245, 0.2606803232864026, 0.14877816662192345, 0.05997939463404398, 0.06427624773594641, 0.039666703556694334, 0.13358751642367533, 0.044331884071711576, 0.027991527421099525, 0.02183108117371317, 0.1893885947403408, 0.3584470545812961, 0.8680314282255789, 0.3346143350485833, 0.9664438184230559, 1.0840003168390644, 2.7224708036068948, 2.0193747959790693, 8.321931977425853, 13.613093629960092, 5.83913343568002, 0.5576164623902691, 0.5999989591298566, 0.30228389246809867, 0.7024281628189549, 2.4853652427273416, 21.888961292082264, 38.091074189832135, 37.71088277139972, 31.38884379017738, 15.625845136181002, 5.024223279568457, 0.2978742290889063, 0.26676765793273527, 0.33439848211503803, 0.21049615566528615, 0.08306239371097858, 0.03237407128777235, 0.06566586228267801, 0.026059666265463157, 0.05502472098376002, 0.03233472118154168, 0.04265020233428767, 0.15206039372471072, 0.049139610566799684, 0.07189689204096794, 0.05333167433197941, 0.022989090103956483, 0.01402500528661955, 0.021587041950213815, 0.21111768279825488, 0.04932827503991224, 0.1402155865704821, 0.03832930939332132, 0.07844457658187998, 0.037007244649313153, 0.13418610688419114, 0.17785800620913508, 0.5099580406902299, 1.6733262615819133, 1.0986349251001113, 0.30931017511794645, 0.5860775480827978, 0.7665885167737162, 0.3313083898636603, 0.1902413272088574, 0.4656751249586383, 16.849978623851655, 47.89864701609458, 18.37511185676821, 24.195128640820904, 86.94621470666702, 62.615262231519154, 40.46022107524257, 17.67967562521658, 20.36865649684783, 21.97071917595402, 11.312905934549148, 0.2573900675821689, 0.0821634354971109, 0.05457410423625862, 0.048393513706903306, 0.10538274076797309, 0.032351406576532515, 0.11232859184665066, 0.05302630402448197, 0.027344698319211606, 0.0642089890466342, 0.024023333699592662, 0.038342834675624486, 0.028747418715107827, 0.08133308045686254, 0.01468585667035152, 0.02332507711534779, 0.022820380306051626, 0.03763656672691146, 0.05659644995185156, 0.046454916723192706, 0.01387520732673546, 0.06168612744659186, 0.037546352212948185, 0.08394440605996117, 0.05810945828054702, 0.04725271302665915, 0.015812408115204065, 0.042675345339962555, 0.012363588490012673, 0.03807587218621085, 0.045588869646552115, 0.06833693508299128, 0.037370167312122164, 0.04463411724915908, 0.053526800756733266, 0.04853471903310669, 0.02833190028585734, 0.09442776772043399, 0.04734653581474577, 0.028689552263747302, 0.0323896496857126, 0.12481328926139301, 0.03409274741105976, 0.04769777180626989, 0.041766657809456514, 0.12369193572310672, 0.030046406975616852, 0.026043674180043802, 0.039749123126028046, 0.09258987682480967, 0.040604801202613505, 0.0789842548810186, 0.05279167427591259, 0.029149584231838107, 0.11729540032965523, 0.05277485481553501, 0.07244749475390681, 0.06771700141290504, 0.06543147002136515, 0.06709269338077115, 0.036197290530488375, 0.019537180271600525, 0.06315987376916794, 0.0673979564359592, 0.03372460385904678, 0.6189318722294224, 0.18003141297207725, 11.162979218267626, 49.22273328227382, 56.98235819416662, 51.70956696233442, 45.924329834599654, 80.43031061849287, 70.22040459417528, 45.23430255151565, 65.06753590799147, 65.45570542735439, 8.08135977675838, 0.8689495692810706, 0.1576825291399033, 0.20431506717878006, 0.2766915302603476, 1.0003033725004042, 0.8182692984419485, 2.165350337182322, 1.5354551951731406, 2.8749720656102706, 3.8391617469249235, 2.288822872984794, 5.178018433432426, 5.215882543594607, 4.8395590724483615, 3.9272027775164577, 1.7008028323611908, 0.2887700708402742, 0.15847429633140564, 0.6387766751070177, 0.6933660168320902, 0.22917250591901042, 0.3745659428738779, 0.29047381974035696, 0.03751629092279942, 0.03985870434271713, 0.03798988647758961, 0.006071792637568809, 0.09360794638914448, 0.0330854069081045, 0.0661832704058578, 0.11370148269399522, 0.7021957623862451, 0.3854215313350001, 1.1734383240822823, 1.6143546517818206, 1.55828338957602, 3.6289991919071447, 2.296337889086816, 9.387487961399941, 15.382367930104657, 5.912677386114675, 1.1414766455850294, 0.23854314019122433, 0.9064187457965267, 0.6106834341922115, 2.211692160175693, 25.22197573415695, 42.73531344629104, 39.744757221591094, 37.19698559853339, 19.855616361864154, 6.673878527456715, 1.1023244045434462, 0.44239947392094525, 0.738487737553735, 0.40973271874170153, 0.16066792781554884, 0.12674222970681806, 0.18421189348784187, 0.04344740108917317, 0.09063003239251914, 0.03329642582684755, 0.03167224090336071, 0.045281626254079804, 0.08175699520976314, 0.09135395483744722, 0.057149209202297276, 0.03993889842663081, 0.0682483829798237, 0.022341464270627307, 0.08645920458460048, 0.11401773145001744, 0.10545001094860416, 0.08878983557224275, 0.07052496646440799, 0.09433066607603142, 0.28048746528164037, 0.1545643980704969, 0.884521562726267, 2.471576885830972, 0.922395601387947, 1.4706952701653204, 0.7159372959886828, 0.25148164510967275, 0.14425357473233055, 0.5369927625982993, 0.7110108603392878, 12.173051314969218, 74.91889415248748, 43.115167540888635, 15.50417713580593, 66.43455643807688, 87.19215516121157, 56.235554602838334, 33.32075426655431, 30.363838249637237, 40.145784270378854, 15.239900581298338, 1.5199671036774114, 0.0147072582941262, 0.15052267139957798, 0.13722997339021775, 0.1086367681742676, 0.053785343939859065, 0.06871078599004016, 0.11035721013022047, 0.08866885496724038, 0.09078331126440918, 0.024313315215911117, 0.04558657138277927, 0.05592807654231306, 0.0362226901756179, 0.03808868883718406, 0.053970691252259485, 0.06044324555043733, 0.02863721696720008, 0.04387921420857311, 0.04659805642140489, 0.04220218262484959, 0.03758417397376992, 0.09639352635149995, 0.0882146797413307, 0.10460914518203467, 0.04797160993480394, 0.008666380177131824, 0.05512859101497358, 0.05290280682064834, 0.07578329438523901, 0.15987138023539899, 0.2004100565588282, 0.22487329709674084, 0.1924320935241638, 0.2751037977155178, 0.22496849118221193, 0.11487535155949094, 0.20329742662368283, 0.27210241844577177, 0.11677731804910207, 0.12677668068077297, 0.29990050100511123, 0.08980281065188109, 0.16547994057257331, 0.10992648485567301, 0.19409156254222318, 0.1987235752805587, 0.09874098062995942, 0.11736371238986332, 0.16402854103474848, 0.09469288776838973, 0.1709759013066369, 0.13847056085303908, 0.18690383452321255, 0.12001492819117925, 0.18246941118230744, 0.21457807130871281, 0.1828413775130626, 0.16728456793052537, 0.13733066798698518, 0.16171953670920866, 0.10485290669866147, 0.11715028029415878, 0.33657089296367865, 0.25311966366585226, 0.6245865204161214, 0.31574224933020534, 11.48869283737675, 75.6416771488805, 93.42686453173238, 73.10546475072061, 61.86961181702153, 94.36278127854871, 108.97361017042591, 65.81038967255624, 58.49212161956295, 78.63911321086269, 16.827636803350142, 1.2418987601995468, 0.937460015618032, 0.6340747951499878, 2.122734520704516, 1.4233556942593668, 2.0961724750457273, 7.051287514548148, 6.3192075202541975, 11.056852629107814, 13.000946967832505, 14.620019005190942, 11.63250457855963, 6.997831982951011, 6.107498570795983, 3.832124524539517, 1.9408802015166131, 0.4009471304955021, 0.47244066192257794, 0.7155392979902606, 0.3434050714056338, 0.2772172504375058, 0.6748813570987794, 0.2705984652763413, 0.17755127992601166, 0.2825148710079732, 0.15027867239569465, 0.23219745005330733, 0.1381822360018569, 0.14712928493897762, 0.15241915269965126, 0.3116555992634066, 1.017129359947097, 2.4349010086828664, 3.0321590890807495, 1.8789041787385943, 2.4034823333063433, 4.251488899030994, 3.38992509149736, 11.893895249212942, 18.791987242237216, 7.470507006491385, 1.8443074029299522, 0.8478214159127205, 3.0577510835662967, 1.955197465515906, 3.227879967420332, 30.008446016619285, 43.77829128696073, 38.082193943762014, 37.62541432534495, 22.08496016840781, 10.163321014373533, 2.490450595655749, 1.3941580609929178, 0.973827496411339, 0.4908470274700273, 0.21175456233322623, 0.20065849887267237, 0.19875847824638893, 0.1867128641254479, 0.14770112360917753, 0.13586586191048547, 0.10571367542950377, 0.16110833644145922, 0.1628778922942377, 0.1743879649908312, 0.1109416509467748, 0.12032367694642275, 0.10339486517853315, 0.1323484458149441, 0.25579427579237574, 0.17090871539567748, 0.301152840256691, 0.09668684609594846, 0.22011083490665884, 0.1522037287753436, 0.3025317372333619, 0.25599511340260506, 1.3007828521151699, 3.7023379533521594, 7.48121899943198, 4.4740515370522775, 2.9196473715766786, 3.6544553743254755, 0.838323764262661, 0.787297405542866, 0.5799205913659066, 26.98487912454913, 76.68061887064289, 30.676649232064527, 40.94548494585099, 106.46057897998442, 101.01640762821322, 66.20667457580566, 49.540374663568315, 57.85989830570837, 60.37640079375237, 18.265891498134984, 1.2266536105063655, 0.12208010971305833, 0.31456078853338, 0.2555814565670106, 0.1940420272970392, 0.1827024244853566, 0.2660345730762328, 0.21930719335233012, 0.1817473579919146, 0.3414891774375593, 0.1895132832108967, 0.13696213373013083, 0.09448258897229549, 0.1833433642863266, 0.13843696023668015, 0.1750237107156746, 0.18514921738495752, 0.1921188401719255, 0.17198243358683202, 0.2073796793457962, 0.13478840521026042, 0.20063170111708103, 0.26028808626917105, 0.24041300759680811, 0.17454291393439617, 0.12980747006593213, 0.1192060542563277, 0.21213244286275681, 0.19335121517219853, 0.130446954299846, 0.2488628961145878], [0.01827796346568052, 0.09281839319174329, 0.0542595025692736, 0.007189482360357239, 0.05490049216595869, 0.00865551034709619, 0.031073221433607322, 0.08139329496771097, 0.01851299349519034, 0.05681304599068338, 0.017359203794190002, 0.06667366626882745, 0.05502754784820061, 0.11066718462614283, 0.03750128326036277, 0.09454424372844158, 0.038767768325464386, 0.013696248230013638, 0.03284548349197834, 0.06411672524747349, 0.025851062438901395, 0.06350074459107653, 0.06746090588069732, 0.05155102552605733, 0.03399828493955635, 0.03912901708615884, 0.0743880950575394, 0.006700510942121788, 0.11331040246952927, 0.031046243647353786, 0.07045086277949233, 0.03484493850039379, 0.08622920200709375, 0.11715008877217771, 0.0757511493359362, 0.19961104217556216, 0.08471885200349555, 7.705891872605971, 10.574728615822332, 33.54955396344585, 41.304111173076016, 27.01421060869771, 60.968015809212964, 87.52807478750907, 40.51246704593782, 25.1151813614753, 40.756556141761045, 10.729540644153472, 1.1684097229473054, 0.5325988499868302, 0.7483624883236424, 0.6813593965864951, 0.5377614245780054, 0.7517054508770666, 0.8044083776973909, 1.0260808215506616, 2.6914840792455985, 4.228150306209441, 7.853254829683612, 6.560162152013471, 4.5337524625562855, 2.8519975177703367, 0.782691378506922, 0.5296898609207523, 0.25900366325532237, 0.4880417360653801, 0.2405234161884554, 0.3433160519888324, 0.5283249373878203, 0.3469547551245459, 0.07487331216614093, 0.072080239863886, 0.09572378930545623, 0.05652805745241143, 0.026908763646779042, 0.09712979813376743, 0.006795693536274016, 0.06905268336976729, 0.10437938775266371, 0.07874280694992312, 0.2512241169930466, 0.07992476570389925, 0.1844353613353545, 0.4617665443689593, 0.6429880749314063, 1.0868385193809387, 0.9357605874538423, 0.5846470474235473, 0.6252917503156971, 2.9663816767354168, 1.3050924337679342, 0.8508331220476859, 0.7568455331267849, 5.75331344719856, 17.82565055354949, 11.35419672535312, 7.478112482255505, 0.4784059434408142, 0.14494273210725478, 0.033603374275469014, 0.12715773281431006, 0.03633481480421559, 0.03209093668227715, 0.1168088578889447, 0.06258018269774414, 0.018659444608455224, 0.031806911499569976, 0.04735009046271444, 0.04355703593201695, 0.030312787238208037, 0.010072348785826997, 0.06037876009941102, 0.06062206196328325, 0.02735776394876021, 0.1033271889713022, 0.0705927116195521, 0.023515842584592682, 0.20206140504489023, 0.05320986635201881, 0.05018727410764945, 0.08492272332190506, 0.01579444335337969, 0.3261513311055399, 0.5150523108820761, 0.2393836612182279, 0.5589025707975511, 1.2285597598360432, 1.0808887741258069, 1.7961055184564285, 0.1523510781266997, 1.0457405375857507, 0.6312366538951475, 0.2845984769444312, 32.57509404613126, 40.14288563882151, 15.533737098017047, 46.09718476572345, 89.78710897507207, 59.06458370147213, 22.714665320611772, 16.495364981312907, 23.891144952466412, 23.43194523165303, 9.906756820217256, 0.47912830306637677, 0.0950754184516207, 0.12348003580325073, 0.061856252591936826, 0.07204342933912432, 0.017818180476165107, 0.06624650330312791, 0.17273247962997806, 0.007856292950530207, 0.055332818564267895, 0.11846652660038202, 0.033915106943177606, 0.0517581450572658, 0.08645320611615336, 0.04063225396338009, 0.05301788471819413, 0.09269273178952356, 0.06205327508430328, 0.0800208101469663, 0.05482734992138801, 0.07924423447900242, 0.037150863152478016, 0.046737626149889924, 0.011854353567375051, 0.04828730327708106, 0.026416866251477794, 0.029582929527086597, 0.01902565761889902, 0.07137071987193438, 0.06469958026202456, 0.06630803548520611, 0.05907168769608102, 0.053480605654899156, 0.031756491422833454, 0.028811289380574902, 0.06573175350504537, 0.038566279540499376, 0.021917402045801285, 0.053174285398375605, 0.018277894517767335, 0.032152786790843935, 0.03342161991543347, 0.002122259860287511, 0.03747988259419799, 0.11538086999808589, 0.08333726605821042, 0.0778789738673837, 0.02009192177455031, 0.047879698536088394, 0.09047588018039543, 0.03885688733369593, 0.027145768267913695, 0.019522231980978, 0.00816343579396245, 0.08141084604205624, 0.046040746608688954, 0.012270007019622192, 0.07554805942720945, 0.03745891859815006, 0.029567732257888685, 0.024273040058511882, 0.060449205714488224, 0.05551286454823229, 0.052534720725229675, 0.11174837983543835, 0.16207192183261918, 0.04199084577961795, 0.42582506974858625, 0.14388335508204278, 25.801250973055442, 66.80370638447424, 53.049982055541015, 61.102976722102014, 52.77736163908436, 81.8648547510947, 75.57887215768137, 41.75341083157448, 49.16081474673364, 67.01633807151549, 17.857270740693618, 0.633767930971038, 0.4016070692769943, 0.6341362047579981, 0.5044849246980683, 0.506575302851777, 0.537262364260612, 0.9153651818633081, 2.1677027786931684, 4.256677214176425, 3.694926880059704, 7.084711011378997, 3.9254879663067483, 6.29538647590145, 5.489116810983227, 1.6703924512670887, 0.5804952798831848, 0.1253988485663168, 1.2475441540441206, 0.47146353209691666, 1.8322256447807437, 3.878204529323886, 1.9717528094207089, 0.025655777050903248, 0.09898039842805556, 0.07912871608090016, 0.01879360001053541, 0.024733637016446843, 0.1114560560052914, 0.054098287026488015, 0.08988061454147102, 0.06976786475147932, 0.09376310983732825, 0.19459417750758512, 0.03735495663638558, 0.062019659146185846, 0.566895503190256, 1.0704154328953837, 1.3717632884940794, 1.19357883689865, 0.8090190012608806, 1.168078772964016, 3.8744848966598515, 2.3471524398173056, 1.2522333475851244, 1.964554156987898, 7.030060627768117, 20.02061282434771, 13.8637379869338, 7.87162377949684, 0.3346371951122438, 1.2597622145568173, 0.286310775385749, 0.18544956981655092, 0.07266063573620013, 0.09038212634022198, 0.046703179006374655, 0.06301390337607553, 0.022204083638385903, 0.08575006763661101, 0.004230649219900971, 0.03554325828689241, 0.035865880894444646, 0.1016467597876345, 0.19294619980838992, 0.012728621725053077, 0.05537126468674791, 0.08710141609152479, 0.012573871006738516, 0.022325334289381583, 0.037029706347253055, 0.1343605297827913, 0.0358750011711832, 0.09236692225620632, 0.012606543699099172, 0.186945402453984, 0.2840849835305445, 0.13124927818294496, 0.8296863374210174, 1.8056496256782164, 0.15396404560775528, 0.23339162790967574, 0.25745625757882673, 0.400524556396469, 0.5418327835298354, 1.0365558175310012, 30.8946761392778, 77.64043069654896, 33.226805656187, 22.779478565339122, 73.7179506978681, 85.27991341006371, 44.353616699095696, 36.4966267924155, 36.95636780031266, 40.502414011186175, 24.427352566872877, 2.873313883619924, 0.12260194582444046, 0.13491519276172886, 0.16030613513242814, 0.020391588557451483, 0.044287416498146714, 0.07896599134490376, 0.1325940536034684, 0.013369420757367006, 0.05943234273863416, 0.06268514823468943, 0.027724526627289674, 0.01150306203447643, 0.01680923693422829, 0.03902432351042667, 0.029970154414073597, 0.07691485987555596, 0.04094130149291408, 0.06903413638112045, 0.07835903520425481, 0.02423691901288206, 0.019471593569183064, 0.04223332792941121, 0.00940881896718976, 0.0073331966245126345, 0.01933193191014711, 0.01274677896646843, 0.053548427418835705, 0.016272092470899224, 0.09731814084995179, 0.03052637829715687, 0.03000941258975335, 0.144179601282362, 0.1466865167622605, 0.1092111272737384, 0.1414558982416507, 0.11658178942818796, 0.07181907282961954, 0.12128255855772765, 0.09255384004885152, 0.07031400117181963, 0.14873246181636088, 0.06730785683518456, 0.188266153357202, 0.2883019298315048, 0.19690914199717585, 0.1767551613550994, 0.17256974723310242, 0.08786204180890515, 0.1705187000334263, 0.136111791455938, 0.15291790658187482, 0.1249923852963313, 0.30725234037926125, 0.17191104951404756, 0.12962780712592986, 0.21610306125254403, 0.1104020492564286, 0.1463907455364543, 0.07579221164867764, 0.19397320195792184, 0.17347560023828862, 0.13414878308052017, 0.10729897181473433, 0.19316242046413884, 0.35112187506691106, 0.24140214968112209, 0.622414936942439, 0.1925620833231557, 32.06298155169333, 91.621868225836, 85.92353513163906, 86.63157001618417, 63.623303521064024, 89.59756435886507, 124.39698157771942, 63.54386768033428, 42.74172652152277, 84.30197238922119, 33.17330060466644, 0.8682263209935158, 1.265372552217976, 1.930075420006629, 4.5375684384376775, 1.4000466417881752, 3.747737917207903, 2.9247552781335773, 2.9822944873763673, 8.526077616599299, 7.984635599197881, 16.30704120282204, 13.92699699248037, 17.58801571784481, 11.002021816469009, 1.5879241280978726, 2.3902948344907453, 0.3717029190832569, 0.9610204062154217, 0.4786182723699078, 0.9682800392470053, 1.9555555043681978, 0.8553173717471861, 0.23453057082670353, 0.18526543292307085, 0.25308381075099595, 0.11313895965295453, 0.10818748058931482, 0.23881369180256323, 0.11010172746835217, 0.2162327752598832, 0.22251071258177682, 0.1971973136307732, 0.5286817504994331, 0.2679214476337356, 0.2157803696970786, 0.7818230638100255, 1.3763370172631357, 1.9520251260649775, 1.5524852684428616, 1.2872304502994785, 1.5738734626962294, 5.274861262690637, 4.909966597633978, 4.253226509017329, 6.7208631288620735, 9.37601306746083, 21.118801947562925, 15.368373893922376, 9.192018605047657, 1.069719825060137, 2.547059222575157, 0.5992613696763592, 0.3440187997635334, 0.20392215600417507, 0.23637345661559414, 0.19577147078610238, 0.37183958916894855, 0.09496171568189898, 0.1464499028459672, 0.22789618811540066, 0.16077511883791418, 0.18527638798038806, 0.16664626347201486, 0.27368429807886, 0.21265538980162915, 0.11903967528093247, 0.1819936246160538, 0.17144997183594013, 0.16285984326274167, 0.30587583359691406, 0.21792823508862527, 0.19835344756082182, 0.27401218371045205, 0.15892167635742696, 0.40347411747901674, 0.7731989975417815, 0.9592874540436653, 2.0130003315787164, 4.192503806083433, 2.9365657798705564, 2.6072014147235505, 1.7266958687574634, 3.7323124610608627, 1.874919295791657, 0.8016086634128325, 51.751042104536495, 63.606860945301676, 27.903741405856227, 67.39644712017429, 113.08750183351579, 94.611310497407, 48.6807676284544, 43.78797954128635, 66.07945642163678, 62.96840498524328, 30.129957122187463, 1.9490257386238345, 0.1793308868523567, 0.23375375767148313, 0.21878804620956221, 0.245641956045743, 0.13524654111073864, 0.17247918031869397, 0.26174533871873734, 0.19155628648736786, 0.13473050428494332, 0.19405264527566973, 0.1381811328352459, 0.13277984524686492, 0.11200788445890912, 0.1665551909395764, 0.17008731592326395, 0.2860528795469192, 0.2203355131730918, 0.1588656446866451, 0.18622944732346844, 0.17369776573632995, 0.16312877076768106, 0.10341959449672893, 0.08017090209309133, 0.062372346874326474, 0.1629500884202219, 0.15041004115295026, 0.18739030035513063, 0.22276721414058442, 0.18660027984409563, 0.15123668066676588, 0.08844687333030087], [0.03825211837407082, 0.0750733070796536, 0.09619396044722489, 0.024683969621095928, 0.04479599545799917, 0.06808535946953682, 0.03002725477750984, 0.047964948800302325, 0.06424579191051664, 0.05992914692709043, 0.033512121712368344, 0.0791404448870209, 0.04321341102402057, 0.017053841147571802, 0.13544339506376174, 0.05398980514597028, 0.037666474799475366, 0.061228523977221026, 0.07440882539677043, 0.049260265584434235, 0.05348353211076991, 0.021811476983730833, 0.026216444243947347, 0.08096216366656366, 0.11041336437507022, 0.0555977164467256, 0.002629554904659369, 0.052953924037395954, 0.038233437320037235, 0.07064293634386794, 0.11200860458155794, 0.0446589959545001, 0.051662851380364555, 0.04401481560161037, 0.2147143736722008, 0.08576858398174086, 0.18689553013011334, 0.8662572911670132, 12.142239136080589, 20.414718850966423, 38.88044334227039, 35.03847783611667, 35.31646797733922, 79.95850439994567, 94.95910706058626, 56.81595556197628, 24.425187418537757, 44.176490306854255, 24.599260245600057, 1.718564182519913, 1.6165183292281244, 0.21777019114984622, 0.19422075560977384, 0.21008421486664206, 1.0245944271164558, 0.7983785915759303, 1.432810322411599, 0.6622657275968983, 2.866243321088053, 4.298972131744508, 6.990448611397897, 4.562212690230339, 0.49048451466425774, 0.41542698899584435, 0.1417379258500953, 0.9177536601501127, 0.7621873110052079, 0.8149924033111142, 3.480039094724963, 3.2573176007116995, 0.07567124636543375, 0.09970517889145883, 0.04613446980534543, 0.06910062515206876, 0.05194993899954904, 0.02986385205370044, 0.07309253312527172, 0.06016918908684485, 0.046954735467631015, 0.08492245519113156, 0.045696719504532315, 0.06307186941886622, 0.040490297871010925, 0.1552118496188233, 0.04803141841905252, 0.17964102988762243, 0.062049525083913926, 0.045738865831686605, 0.14837995411888247, 0.029273533427547065, 0.5553452874864302, 0.5809831246733665, 2.8675926164273293, 1.7759135245315492, 1.665265790877804, 0.3415238658987707, 0.3808065257485836, 0.22396563612405332, 0.14429794654490488, 0.07966014361309429, 0.07553553388964745, 0.027499815802119916, 0.029089815967205553, 0.06840491006451269, 0.06979905219087679, 0.011347311571420682, 0.07300154486250493, 0.10865745254822316, 0.061951963786756804, 0.0626776597252296, 0.02888517089999251, 0.020270502615359523, 0.16627737681471533, 0.04065935432370152, 0.08269657140537616, 0.05779057418206527, 0.06779462910227238, 0.0498790922574699, 0.00883063134331737, 0.05755008003043552, 0.017531627203307806, 0.047799431673821904, 0.15928777445468212, 0.4074770188139331, 0.5943745867379251, 0.26116197808615627, 1.1338524159885224, 0.75573286702556, 0.6137778165359652, 0.18422667898478048, 0.0696106864920547, 9.624404022770545, 46.17988794080673, 28.022924584727136, 19.89553040073764, 68.20272953279557, 86.16472951827511, 57.63175756700578, 27.928228762841997, 23.122164280183856, 27.105280199358543, 24.034846867284468, 11.76219480652963, 0.7737136247657961, 0.13610871178248238, 0.10116263052388545, 0.10799466391965266, 0.06875836771101722, 0.0857960635555848, 0.010967580939552957, 0.05003496816742325, 0.07123642465880803, 0.07048233367142177, 0.0395199747365569, 0.048258873754211014, 0.03427627143420039, 0.029808031057097742, 0.08461826465903752, 0.015545723332662978, 0.06320417280338946, 0.04915932583953104, 0.06186246939544236, 0.05256510760274626, 0.05706750975561239, 0.01800782745704055, 0.005007959853467202, 0.02624073114636685, 0.04212260524171495, 0.10626139765184735, 0.10531946956630676, 0.015833340510125124, 0.03460945839422845, 0.06945246635305305, 0.0306499827532999, 0.040920632440716996, 0.017338887142438083, 0.012353303759629208, 0.11416331879914769, 0.04642498566799107, 0.021319418709965485, 0.02874160793820216, 0.03492487594485283, 0.053101851785134886, 0.0628307355838197, 0.01664054437330173, 0.04368648946946187, 0.06527333415203518, 0.030015114199129805, 0.02618649212132779, 0.06320122719532059, 0.11550990218717246, 0.03116234044183887, 0.05690041448800795, 0.07172570969428747, 0.12281444329287737, 0.042388445412319516, 0.03945972192131224, 0.03592169039972848, 0.12658415512452204, 0.05151313864776204, 0.03117310589239482, 0.06155416880163455, 0.07176599059734615, 0.014332118444144728, 0.01782056684004924, 0.08046332551466842, 0.05604149585950279, 0.02994869054565507, 0.01586200273220217, 0.06272955835165997, 0.17454194866361158, 0.10499620344489814, 0.41969805174777586, 4.297189904797462, 26.989111361965058, 65.31322140847483, 59.92678342326995, 55.413374823908654, 59.2835186373803, 102.34103125910606, 79.2094885918402, 42.538943905984205, 49.08510515766759, 69.46097881563249, 27.094936909214145, 2.7612412264270167, 0.7850319303331837, 0.23298849712216088, 0.4273292680661525, 0.24118436620600764, 0.5303964391350746, 0.5986917066958644, 0.8199445182277311, 0.7611382608452152, 2.494748532772064, 3.154473299941709, 1.9599137479259123, 2.8923265924376826, 1.2879895515018895, 0.27329625922345346, 0.4264374497917391, 1.3394825496981222, 1.651939660791428, 1.0215401877799342, 1.2292494841160313, 1.7512120306491854, 0.027794556639667962, 0.16556476182754964, 0.01085007167045748, 0.039606783989696734, 0.040061916825511766, 0.050661275689039505, 0.06073312172966619, 0.03413844072530347, 0.046723599079996354, 0.05518269214418627, 0.08182933689245293, 0.07393070992322699, 0.05201509094706947, 0.11314171756948195, 0.031640792994069, 0.17427145833930663, 0.1610539595205938, 0.1687857785051869, 0.1380942584646325, 0.020269682901280544, 0.2643196392924555, 1.0066017184046008, 3.940403759479523, 2.0145092183543793, 2.770018510280117, 1.0852873445518556, 0.8315596369005019, 0.5268426491848884, 0.4092091436107313, 0.1639541998625763, 0.07013662117383174, 0.045962915906021674, 0.10621262849458765, 0.01218664995019114, 0.057724594859586614, 0.07593612126525372, 0.019004910042689695, 0.06308418428224903, 0.07520805428465528, 0.024487140565930356, 0.021989178738646933, 0.09751596007375948, 0.03420726606442082, 0.021249852180781386, 0.08829843613409227, 0.12214500502112413, 0.02938545312762501, 0.023121839734695615, 0.03247038003117327, 0.0793685092620792, 0.07761745443267208, 0.08239642581752232, 0.36612825047585273, 0.5396349692056256, 0.5044407367465958, 0.7947944032569086, 0.994745864262504, 0.450138065122789, 0.15321429067802045, 0.3125243429695407, 0.6211614332372143, 4.5231591213134035, 55.36681628996327, 64.33762988736554, 23.846120065258397, 35.99182559597877, 81.86701989942982, 82.30082619574763, 47.00356214277206, 36.507578049936605, 40.49977033369003, 47.43951005320395, 26.541739548406294, 3.506041957486061, 0.42097741858132426, 0.09578065601207557, 0.06060602391258844, 0.038975201952721805, 0.06060586303412434, 0.004307542422470907, 0.05778283669403004, 0.05356710464242966, 0.045859704710422985, 0.021096971674611973, 0.06824430739206654, 0.024990230505805344, 0.04429515781662157, 0.07023232087733285, 0.03257485910228664, 0.03360204128248077, 0.05800307931138143, 0.02278230956665451, 0.06378002960475222, 0.023589023133559574, 0.10448572075655384, 0.024988702160396406, 0.00348527894652028, 0.04980846661173048, 0.03996756160631776, 0.07844654542784538, 0.02933481280061026, 0.018709952785303036, 0.049415781433063174, 0.0263602944887093, 0.06372435799529476, 0.05506445413395282, 0.05052989927090464, 0.18226753169250104, 0.15511812642216682, 0.13560674033097683, 0.16481212640721954, 0.16801604400238684, 0.13658604584634304, 0.12608287315214836, 0.10082868513681235, 0.11449997613747274, 0.19106025987815475, 0.18623525426993448, 0.0957890906401219, 0.14747592440295607, 0.3386404335258469, 0.18916935569817023, 0.14435940211819065, 0.2126094551696893, 0.23841771627626113, 0.18441302221148245, 0.08957581113903754, 0.10452698225215559, 0.16405671774860353, 0.2064789131644272, 0.3091259769374325, 0.30070005164992425, 0.14098717500605892, 0.16551865865626644, 0.11348782077191338, 0.2241311264374564, 0.14371976466669192, 0.13414858389765988, 0.13769581613521423, 0.12195012757494567, 0.27595614714007227, 0.26540586003853434, 0.38064892614080065, 2.9029643054931396, 33.946992043525945, 99.89447639834498, 88.15990586434641, 83.47627424424695, 71.5127000501079, 111.94590383960356, 126.08397729935186, 89.5384620851086, 42.16280821830996, 76.83154383013326, 65.97367794282975, 3.659287489229633, 2.5294813657960584, 0.757903837628903, 0.6273706065070245, 0.34551766610914664, 2.132138648340779, 1.8316432953842225, 3.460155864877086, 3.3341605096094074, 9.125117678796093, 12.242833222112349, 13.530889576481236, 10.25931219900808, 2.478734475951041, 0.7192317804982586, 0.41750627419640945, 2.9072019361680557, 1.1573649414124028, 0.45653578795252314, 4.258823731253225, 10.414637077239252, 0.23815101042630213, 0.14555894259002902, 0.18013950797819323, 0.15093026081881217, 0.26553909805032516, 0.13618551975777074, 0.2256929652104455, 0.1273770714479108, 0.167179016336318, 0.23893516270383713, 0.20150091979772816, 0.15026767137310199, 0.07094296701853314, 0.32755906363168075, 0.22499850650708522, 0.32881550911453467, 0.3648236027408031, 0.3285717705805456, 0.24180973910035627, 0.167979133886195, 1.5407407115544043, 2.15516320640041, 6.054055296605633, 2.958233933294973, 3.479230105876923, 1.8996201768036813, 1.384713851636456, 1.4188849277073339, 0.755154746434381, 0.28767545377054526, 0.20104957143625907, 0.11768622774510615, 0.22355988531583743, 0.17102122306823733, 0.17490225513615917, 0.13880819112302797, 0.19415505590938753, 0.21385287715783044, 0.19456642980296768, 0.17237658582387433, 0.26895888390079625, 0.1811004580268937, 0.22100584010683724, 0.172526539874173, 0.21713099802934357, 0.3036814207030881, 0.18612361993760834, 0.1861507088066109, 0.06985758130829181, 0.23956363059339986, 0.17084980323430032, 0.24839215040687593, 0.6124488684919573, 1.5520677811676458, 2.039630160697045, 3.7296572616023407, 5.5457117096070325, 1.0847303679873868, 1.5077130063887567, 1.0671311833204762, 1.0243492789806858, 15.534572562863751, 67.32409507997575, 48.20829852934807, 30.974590509168564, 90.40008914086127, 106.37762869558027, 88.99183273315431, 49.06008043596822, 55.37319406386345, 68.07638214480492, 70.4775865616337, 34.17427770553097, 2.419161027477634, 0.4164113813350278, 0.28934629153340097, 0.27347843493184737, 0.1269553936717491, 0.2705152068407305, 0.09090951658905515, 0.13804959553864696, 0.20051603716227318, 0.0935526118583737, 0.1938738097106257, 0.12681549835589626, 0.16191658984509208, 0.177251739547618, 0.2245982102448902, 0.20879865804266548, 0.10147259735892858, 0.18510138285496544, 0.11930803588080792, 0.18738925847555363, 0.16872887349417134, 0.22960016684186077, 0.07607397112634874, 0.11784801785383495, 0.19300377897677884, 0.1857743451311704, 0.287730029874271, 0.10603989865030013, 0.1803575059579265, 0.146284029488602, 0.07636486237207729, 0.1851960713224065, 0.07764203053328299], [0.01874107702244674, 0.08380772065251105, 0.06454796380093021, 0.028061065221986467, 0.02503233278290399, 0.020424513101217248, 0.046707545707543055, 0.016278964279580022, 0.027950694934735378, 0.036050297410017064, 0.05014459534938778, 0.07549015084101308, 0.04521057159910279, 0.023709534509708325, 0.050880453444176146, 0.04392688786010108, 0.05755307926465908, 0.05312114570950789, 0.04481620102700207, 0.0387352517235183, 0.030602634689139745, 0.12584532460858747, 0.05117304157465697, 0.02452019534464325, 0.029076430495948564, 0.06704122759401798, 0.06439050974985285, 0.07248519394066065, 0.08387224057749396, 0.05229062212991619, 0.08435107617368622, 0.07137206818668113, 0.036055843886588855, 0.05864580792765464, 0.02441252934776487, 0.19557679252278423, 0.014129827182079035, 0.331635570694362, 0.6892033401996859, 13.026808134971127, 14.88941131099578, 29.23922411857113, 42.98566656727945, 51.44768599540957, 57.63484054996122, 106.7364392742034, 57.565975496845866, 17.008705177614768, 25.307373577548613, 39.91156385790917, 11.05028462025427, 0.2498521148076942, 1.9606523792589865, 0.30743684499494495, 0.5370625685299597, 1.0929668550529787, 1.8788511041672, 1.9784661911187635, 2.2119159804236506, 1.1630202637564753, 2.598192220734012, 3.13115309323034, 2.9251318256701193, 1.2009843943580505, 2.377655241758593, 1.3883224321949867, 4.34532376066331, 7.763574738656321, 4.128478957760719, 0.888295005406103, 0.03521688567895082, 0.07389025281994574, 0.08895347195286905, 0.09315927167453113, 0.02339095301595667, 0.0719271295313393, 0.05723041835271063, 0.07286002544025261, 0.02488596019365134, 0.013525236337896318, 0.049514932362663175, 0.050354794554051854, 0.043210587990019596, 0.034632188222941854, 0.035933212362109654, 0.06685651613459473, 0.029395624860039646, 0.09479176673677661, 0.03886115827387379, 0.026908164182978294, 0.01259139143756681, 0.034351669807708075, 0.14511442773284453, 0.08231499833205054, 0.2855783340431029, 0.8539694860096901, 0.5139509522386136, 0.07650564634992231, 0.036718349062627366, 0.029080527151123654, 0.05244791530252946, 0.038897922833360014, 0.03518212826982622, 0.014542865401674664, 0.028616601541157694, 0.038756564289571784, 0.028486316798314936, 0.05157083272933961, 0.09063540266886835, 0.1136170061785848, 0.037391227069160635, 0.03358273969722852, 0.054943029197954366, 0.03137628773167249, 0.053040748612294276, 0.0659503183898426, 0.09727685637171231, 0.0295775784029355, 0.07626203039000112, 0.07783044985825978, 0.05258211092422566, 0.10835134679631842, 0.40185019494064395, 0.8392994538430245, 0.42738571342441345, 0.3974044334984595, 0.28021685238326755, 0.04985015711656982, 0.24200564310435327, 2.0579536355310872, 26.023364989988266, 39.714786391104425, 21.394401404165453, 36.328937622808645, 88.94139889747866, 83.11822460543725, 60.571585778267156, 29.81263541406201, 32.600656132544245, 48.7978543004682, 43.744052917726584, 20.200924181169082, 1.5311364204652849, 0.13828550465404987, 0.0991611338911518, 0.14606443804598626, 0.05829223536796147, 0.015817437482426967, 0.04981747963615964, 0.05866597519226133, 0.05918884552234124, 0.014856830258072625, 0.014052455174556423, 0.03193656805031483, 0.05086896212531194, 0.050641552755428906, 0.05063775678976409, 0.06253361221282713, 0.02989139482979813, 0.022415991219121124, 0.0975534753994115, 0.024399427329039863, 0.04779853918139012, 0.01337150451652105, 0.00781570417588697, 0.06379942312055538, 0.005483049279709737, 0.026312505923992684, 0.048951823264360435, 0.07591215037410298, 0.022059674149439223, 0.03809857903228652, 0.11450074222539702, 0.041315382226340236, 0.05752589463466599, 0.003494177775968227, 0.016722372139713938, 0.0785918033591682, 0.012170896309638217, 0.036772319956892924, 0.013112434647947311, 0.022973149729472016, 0.008913059531140232, 0.024889984070473624, 0.048836312527137424, 0.037797391564855655, 0.042253951016332836, 0.06035505733903378, 0.07626877196373479, 0.06186765964112936, 0.03245316220507507, 0.024477683210505113, 0.03012986842452759, 0.09330669763467966, 0.04554024604599803, 0.08595953905774702, 0.06688338283809923, 0.032786088695208875, 0.07632494153034303, 0.013581535181841783, 0.06397042543657365, 0.03798149398437912, 0.05503554963656972, 0.08311584366545563, 0.045652098713382605, 0.10048751554061329, 0.02767664038636271, 0.09558420808565232, 0.04580068529673642, 0.06466496074872632, 0.1311569186227937, 0.13986756814823997, 0.15655777417123318, 0.17810513085174948, 4.30485813848434, 39.66318368911743, 68.04996890406456, 59.48348499113514, 60.99508408577212, 80.24821850561327, 86.98892931784354, 92.12548486648068, 41.552016735076904, 38.85013518794891, 63.83865341063469, 41.12045795686784, 8.089397693833998, 0.40196593550424425, 1.3858874983364537, 0.412928469839596, 0.26546558425311123, 0.1270444513929467, 0.4860196010239663, 1.9066227107278764, 2.412935735717897, 0.6722882414056409, 0.5931221861993113, 1.9323277185040137, 1.6029764687822712, 0.5763137268443261, 1.340857463017587, 1.5195219146628536, 1.177219611502463, 3.1489045148895634, 1.411534896300685, 0.49180316648656325, 0.052529174248657884, 0.07135990271044355, 0.04236142549123015, 0.05304211990967874, 0.02478383875812494, 0.04696421197525436, 0.02933445082406604, 0.07909346071462478, 0.026975955303397872, 0.045936945525388566, 0.07896159400021838, 0.0945632886742392, 0.022242307595367876, 0.022559169221729524, 0.05102141362224376, 0.07406279114225219, 0.02801125226992994, 0.06134560902512843, 0.030576405753832192, 0.03967540631551416, 0.11314989172763402, 0.10234098866461747, 0.264039097894584, 0.3571190258427974, 0.4024460274846323, 0.7683165659827571, 0.5946199800218306, 0.1329940893957692, 0.04609865902532493, 0.04970317548741737, 0.10822029213511175, 0.04070740718875201, 0.023917098371912877, 0.0600614388202948, 0.06484433257531735, 0.00847182544549146, 0.05795894115562401, 0.03297163902090923, 0.04704669283162202, 0.045699607656006856, 0.058226393941309185, 0.1828758514696552, 0.016252827274823384, 0.03899202141309938, 0.03845366844606977, 0.019740486600165887, 0.1174966669491222, 0.0234500375471168, 0.050654495810909625, 0.06547104612353348, 0.04158054057869219, 0.030632483389889522, 0.610940594586634, 0.22751622382671605, 0.26311072190442397, 0.10205239568266178, 0.44479432605927993, 0.11315133963381091, 0.3140598283179345, 1.1558373008043537, 23.50812158276958, 69.67932147364463, 47.63214941947691, 25.60792519200233, 56.75957933548958, 94.96773627496536, 78.88713252159857, 49.323765693172334, 43.43580953536495, 58.41724749534362, 58.943307938114295, 29.546163312850464, 4.2888460428484025, 0.7369891469997745, 0.061391229561019334, 0.19483266067841362, 0.054254986480959964, 0.05431036314656658, 0.029733096166784247, 0.023881222474418824, 0.05312744295224548, 0.07357165217399597, 0.0411677953877276, 0.09889630495660728, 0.029583004220659216, 0.09149548958145803, 0.029005502245479056, 0.030028568618299983, 0.0773943849508801, 0.026334331768955437, 0.02135838002657458, 0.01932048464133855, 0.023045456938205228, 0.03880591567365393, 0.026368981925770644, 0.03444923876574443, 0.02006118058136875, 0.010865384810453942, 0.07808761791356149, 0.05020649142323002, 0.04819830301247778, 0.028487027344864704, 0.046107568627884316, 0.05162380387886398, 0.05833383777268952, 0.02887151538274221, 0.10856559860610193, 0.24943778381472637, 0.07449324828602615, 0.1902116029973953, 0.12246753569812545, 0.11229813219078126, 0.2161774024247162, 0.04930968591642957, 0.1575118447503736, 0.12919374170803255, 0.14618848300268575, 0.2331398607742402, 0.10890148219562347, 0.1327992579148662, 0.18317666355400317, 0.16018786647867772, 0.1718507583944067, 0.15662140543422393, 0.183377547129508, 0.17041783689731554, 0.1685843280246181, 0.19419009677104412, 0.17765208177508848, 0.14304709350389821, 0.10868475592184453, 0.12047248952571424, 0.25507488858795935, 0.15179767153195797, 0.2196852117776871, 0.1540820691133699, 0.2101740463366432, 0.1742311314709725, 0.19498263005047076, 0.16544707540062167, 0.24354567901501734, 0.24651108279583916, 0.2006028962111281, 0.5021701747130963, 3.183495161994811, 56.01340332338887, 104.0776292739376, 81.03841920052805, 84.79037807833764, 93.73046382780998, 88.00705109873127, 136.5597337292087, 91.26232024162047, 35.34039443539035, 50.641348669605875, 81.59605472318589, 26.90993832003686, 0.3333382470713508, 4.664263936781115, 0.8041222898229476, 0.7806953823854847, 1.550165921930344, 2.284305283138829, 5.360674387024296, 8.21511750259707, 5.452067573224345, 5.746101189044214, 7.485335036631554, 9.81582941547517, 4.558247173986127, 8.336026034047528, 5.279246962839558, 6.52351789897488, 16.032710632970257, 13.543500977177775, 2.2860882455302827, 0.14020172037905262, 0.21821678976618478, 0.1545176513853573, 0.1846824553344519, 0.12094379447761083, 0.16611977720693236, 0.15489681894260068, 0.25192222227492644, 0.12264798770868972, 0.17416932349724157, 0.20732087443672842, 0.292164575789244, 0.16629796925812, 0.11166706726315523, 0.13854839538614597, 0.19414000994255468, 0.09294046164159814, 0.32814867554172394, 0.09108461364502869, 0.10638948755278703, 0.398850807499501, 0.21748224934262617, 0.4469422527378606, 0.6228956111496495, 0.771313869664746, 1.1253599942691865, 1.1657509688408145, 0.5005404911935329, 0.19255987698993376, 0.18029782770862504, 0.14792577123209355, 0.13620085683801483, 0.1024787312734031, 0.14377919776785758, 0.15596751874733358, 0.1988330186014214, 0.2123282702579614, 0.24657178760295917, 0.24831685928567765, 0.1678650021072357, 0.1308434660876951, 0.19892775303413793, 0.2322222866238125, 0.13913999912479233, 0.11986531121956727, 0.1318400239031161, 0.4231998702931789, 0.11177758310711193, 0.16322617118637409, 0.09673446612132174, 0.17994881337208135, 0.20245034788404742, 0.7109648337767971, 1.4208301781646668, 0.39573387152725653, 2.112264734122061, 0.8769861993289764, 0.5981020028552702, 0.7366843665799787, 3.238500765254421, 38.11719717517976, 60.41960570120043, 36.76223793337422, 47.65184364011211, 112.46211128850138, 108.44371364962672, 87.4513610716789, 51.971040002761356, 63.297531066402314, 80.57415177745204, 83.0502813093124, 39.84515420852169, 3.0564628301128267, 0.5929815324564135, 0.3305617912161735, 0.307739143289866, 0.1572920847684145, 0.08561394913422485, 0.1651970549456535, 0.22851872648442947, 0.28874874295246217, 0.1534984326891361, 0.19894833015578411, 0.15658717662576707, 0.2360613217517253, 0.1413723027273532, 0.19696929522099035, 0.15457587406760262, 0.0837288748833441, 0.12009772697403548, 0.20418709985190825, 0.14189793097396053, 0.16033069591128057, 0.13659232776732216, 0.08274937018511758, 0.10001126932160509, 0.05646482838558094, 0.09760940747876322, 0.1252588383372753, 0.1687469991344598, 0.13330101486175291, 0.13637089771368813, 0.2873324302415694, 0.23969142938092833, 0.0844159868035105, 0.1640139393989117], [0.08852859192918386, 0.04686250614242689, 0.05635123669860825, 0.06323121187667693, 0.014821684059326448, 0.055175517730775385, 0.0398513613899629, 0.03965045483182034, 0.04216222730915874, 0.04565810101226934, 0.03414879823403974, 0.018519187316058144, 0.02189919979672038, 0.015079223667271437, 0.013654495480530446, 0.0808117269808727, 0.004417120287525318, 0.03372514012059377, 0.044765237027839314, 0.013138836910647732, 0.06755138086455484, 0.0983779851887976, 0.03070354187530616, 0.033941720837667104, 0.04355219042589588, 0.028686150833363497, 0.08130455134256233, 0.0606968091620553, 0.08274519500593025, 0.03771825085183786, 0.04912272598894854, 0.0035269031368736783, 0.014672313193460147, 0.03664054900347706, 0.07771238038736968, 0.020960406926009926, 0.04395617540144632, 0.17975404317821228, 0.10516115749675421, 2.372697856157057, 16.83450487352187, 7.246650966905779, 25.315957684670728, 27.664433679273053, 31.77635435135134, 48.17260103840982, 96.30484873248686, 98.56644030540221, 33.36459459797029, 14.953306721102807, 38.25604515690958, 37.39688919436547, 10.353483403882674, 0.23182670946323106, 1.1147076948996515, 0.36959124368525326, 0.53105938098123, 0.7574557068367159, 0.26843800539931945, 0.8418762058981004, 0.862775881203913, 0.43633184305602507, 0.7441093520291391, 0.33525732796519037, 0.07390095506824794, 0.08501756500693099, 0.19007039767119194, 0.26557694279378463, 0.521911371859812, 0.14166834974481216, 0.07067698129122296, 0.1354907392974823, 0.048894929744663744, 0.041686992326210585, 0.019682872957820376, 0.01859666370306044, 0.027570832152700717, 0.07275721644081416, 0.049656700763490894, 0.028927116129066677, 0.06675645739080445, 0.0013903224598541255, 0.131608052479644, 0.008314161677844822, 0.0403845739070206, 0.03421628291928961, 0.059146752821341644, 0.01024364221525649, 0.054823335620664784, 0.08376472013732118, 0.11778525227019865, 0.05468436727120031, 0.04720521940579338, 0.030282513358660286, 0.03117151625995194, 0.012074877722038618, 0.03895872340147053, 0.052182917828641595, 0.06587440673742564, 0.10997504716919315, 0.08537093838376385, 0.040356297601735404, 0.022674626332797834, 0.06392877706657014, 0.03941333146705743, 0.050297969982268355, 0.0542871353607024, 0.03841055684813088, 0.013781208338426247, 0.09316301784448086, 0.06099226629181255, 0.010876044923920306, 0.05255158998132233, 0.04277196434897281, 0.05811870113135346, 0.061333186909436226, 0.11269151067902004, 0.04393092897390166, 0.06914622270532193, 0.10814480183105316, 0.0159036549326453, 0.004224613883472499, 0.1836883336786301, 0.911234068053384, 0.07487163443358676, 0.5364811997259817, 0.39502091946140416, 1.4658540847801393, 15.783072363945747, 43.21274042129517, 40.81497200073735, 31.3451878101595, 70.65619560980028, 108.10882952905472, 77.90271174523139, 42.86800330685031, 29.587705135345463, 31.98939004252034, 57.56158636462305, 61.118858398929724, 31.7093583076231, 1.1362573192004235, 0.05751424243733768, 0.1349599629400238, 0.03785637650458563, 0.11754758881344912, 0.03528640815807927, 0.03453812411715908, 0.14083904424502006, 0.06313847693344278, 0.027874856060671232, 0.05573769603225012, 0.05814877391282109, 0.028836204475092313, 0.018176317004667177, 0.028499870808915268, 0.03147961575567963, 0.011368936318303309, 0.054772206912598306, 0.0526767036306762, 0.05731285707424245, 0.02849264276934968, 0.038191279501564084, 0.04033190919266593, 0.032997908175832806, 0.021697234122022506, 0.05558198100076087, 0.024558664449760993, 0.09737621031461224, 0.002366717559315505, 0.050831151855809074, 0.022551443225013155, 0.07640836850529717, 0.044884919113810026, 0.020962157436916908, 0.01249694045738227, 0.061714170095060146, 0.007618868896257013, 0.11597163104001554, 0.020643817260861397, 0.02961128244116422, 0.027371821662170753, 0.006810586285522028, 0.019680122702172207, 0.029870017146271084, 0.028464240059556983, 0.026232145215955474, 0.006833804495287158, 0.01725234410485193, 0.05669431002329915, 0.03237800131882391, 0.027455558902734233, 0.01836891916971053, 0.03276936499582183, 0.04211161188000152, 0.09877308737486602, 0.04106839164911259, 0.09248041818218847, 0.04412335493872243, 0.02000305557533378, 0.04832772973684534, 0.026909204147335504, 0.027312218106441924, 0.09218348250273736, 0.12154852896327935, 0.054041378185032844, 0.05015173528884208, 0.07758573839260686, 0.07708737521522468, 0.0469440293888892, 0.13799007050693035, 0.034903425482972976, 0.028143653330663522, 0.11021139295471293, 0.17783270998587533, 9.432910969180446, 26.61101645038974, 46.83410790658767, 55.94170239663894, 53.4053409484125, 54.427102688820135, 86.50276722446566, 95.86442932005852, 46.519682868834465, 36.25727591976043, 53.049668265927224, 66.53967595869496, 17.243635539085634, 5.0845444298559626, 0.3506988106716064, 0.5530723965456409, 0.0971613456344893, 0.24018552544857227, 0.32499095304839076, 0.7603501708757493, 1.1159543957441085, 1.1358686368311606, 1.0364385141480355, 0.2046502000021358, 0.588694443145106, 0.6178399824327039, 0.22736067733457013, 0.2349552899719246, 0.5538819369769866, 0.1583714107231748, 0.1925104336753007, 0.057250574125998446, 0.25116966346338876, 0.014583277497290364, 0.059612603227217356, 0.06261753714493205, 0.0345434445977932, 0.038757338038375305, 0.032938957710059426, 0.006322065422747044, 0.021848511589210362, 0.030994339275263974, 0.01923311231357436, 0.0680100606874593, 0.057472789419754866, 0.0483585954193146, 0.060477424563179095, 0.11950519626900075, 0.03743174162903621, 0.020163543334591295, 0.09052124024639208, 0.04577212170847962, 0.018965146248979915, 0.10579113457952777, 0.013692863078998222, 0.03521860171590121, 0.02948629711153767, 0.02621371697093691, 0.028658920238094947, 0.03296678585390891, 0.1089307314325725, 0.10380845306621445, 0.05553832548039575, 0.054341738277505484, 0.020907987359791033, 0.07060040314231189, 0.03339062016757746, 0.03485022450707132, 0.07688579449970877, 0.04461881464287158, 0.11286360467033041, 0.057225932907913966, 0.12434008441144422, 0.021059475501158068, 0.04423657124261222, 0.02782970475363395, 0.017379510869842865, 0.08465837702275285, 0.07202684353556364, 0.02545729133060142, 0.02226998635207213, 0.14647385075448022, 0.06302950092621389, 0.5845143609950619, 0.9150666527209744, 0.09378260677500118, 0.23770012171758761, 0.446008023835959, 0.8094288889438876, 14.427882682892585, 48.83131604040823, 67.10270081796955, 34.521489835554554, 35.6950080779291, 81.89557475428428, 95.47154903411867, 67.6443644492857, 52.22768460550616, 44.890918654780236, 69.18752685669931, 72.04440870592671, 49.41028533443328, 5.1622691365980335, 0.6189854370970881, 0.03588276930273541, 0.1741952785561162, 0.09254068631919161, 0.06161141089133679, 0.04198168336804356, 0.10017908854229797, 0.058571244589984424, 0.04581499581916198, 0.058838168775001844, 0.049334825091664834, 0.03067640129536871, 0.04749763899693086, 0.02384387377289034, 0.019844944603861343, 0.050160989630967386, 0.045247006740781574, 0.02790413402591742, 0.012212449876261095, 0.051389806152832125, 0.04781878305478923, 0.034738548039909334, 0.03985140352479873, 0.06377558246435178, 0.09018594654457224, 0.0635771580310839, 0.029777716957933964, 0.029145014517369772, 0.01672849509744875, 0.07024372026564614, 0.024577044814284292, 0.026854084121183525, 0.02221689071326006, 0.015024709808189544, 0.29332296201779, 0.14430926932442573, 0.23990861530746185, 0.15492856562618287, 0.11971508137761586, 0.1203677116803104, 0.18398396700860994, 0.128454091478019, 0.095486072222552, 0.10520444146447605, 0.21156619663440415, 0.11783670273519332, 0.1448745502819938, 0.14702598564326763, 0.1514869615916283, 0.12078565094740161, 0.10847261851473201, 0.14683455559274844, 0.24212095465871597, 0.14628617453478998, 0.1803095794973835, 0.2316758054639063, 0.18568768526517576, 0.15840234535355724, 0.19861888170482653, 0.14712148616390844, 0.13856606137367988, 0.16412736637698067, 0.2646904871348412, 0.2682943485917584, 0.20000507183853658, 0.13699369655261118, 0.24361422856248197, 0.21992783182330672, 0.3282645693229091, 0.17649536561821738, 0.22910967138746094, 0.31493261696830877, 0.23739164875399685, 6.25591419396862, 34.72870080701767, 75.33498702510711, 84.02484124706638, 67.98843476080125, 65.1059006106469, 75.6259641339702, 128.706466151822, 132.0357817988242, 63.02170215114471, 35.0920299560793, 74.39368094167402, 65.92001207413213, 19.19997649808084, 0.3110545573215331, 2.0205662159189104, 1.2868193368757925, 1.3353734992204176, 1.2845151895476927, 1.9068708006412753, 1.6323078303567826, 2.2863216265555355, 3.1551874164612066, 1.5705106431438078, 2.145716177840387, 1.1206160101198381, 0.2231724593307703, 0.4295579097684353, 0.9155084709486655, 1.0742316539249113, 0.48227952913411204, 0.17505041654071501, 0.2934294788827819, 0.23536304793050214, 0.1458184472134998, 0.22942229654760132, 0.12305458121362234, 0.07552005891357699, 0.2527735911069378, 0.14656336046755314, 0.2251183379802012, 0.15726660468405293, 0.23975541304436424, 0.286609917398422, 0.1612939289019954, 0.22833785312550686, 0.17229375639750114, 0.24446121537156645, 0.0531965479134552, 0.09282544120064667, 0.2277521942291529, 0.5260027716717413, 0.11765460363559185, 0.2503336776768969, 0.1698943536968962, 0.14476034189424208, 0.08759212605054341, 0.11665201670820675, 0.1527464101391454, 0.15761180390273372, 0.2261790786419184, 0.32127012528719445, 0.12322207867738702, 0.14963267641442438, 0.20425785573259478, 0.157585971417927, 0.16038122707076613, 0.20871267233404422, 0.16133712093916633, 0.1223029263858353, 0.16304306085071257, 0.09895399903818484, 0.2635360845635014, 0.0913812275675516, 0.19129429973902243, 0.0982015551398358, 0.15210625174785816, 0.3231888997458643, 0.16314432235254397, 0.18508973831851638, 0.18104099428221104, 0.21860669787612655, 0.18315957979329173, 0.8833124308336167, 2.895630453863452, 0.20579200808800038, 0.6236984712942955, 1.355598220421422, 2.789526173183995, 26.94720279785895, 65.2869729072817, 62.8444855443893, 45.81627638109269, 90.35353845165622, 128.01227723398517, 105.57766914367677, 64.95396760202223, 52.173944211775265, 59.32758646626627, 86.75255160177909, 87.63416705592986, 57.30486331447479, 2.3635771197657434, 0.6298362451695627, 0.25099291165749876, 0.2840882623868604, 0.2146000427103812, 0.30649627288503034, 0.12966111662887758, 0.20631809598736225, 0.1312136704162244, 0.14408855939344054, 0.11336854854298216, 0.14252759396068512, 0.10158488286599036, 0.16203196268648873, 0.23795625555419156, 0.10197181089390671, 0.1748191958834087, 0.09338674616188773, 0.09154194515318641, 0.22286211711264428, 0.14852172635014982, 0.10783147187002244, 0.10023961714919537, 0.12685958671593858, 0.11012540724609168, 0.20415556767294485, 0.15887353539226517, 0.18120933444269244, 0.12234390442890507, 0.23047707704526765, 0.277064768297057, 0.10973571364076869, 0.13579892114766184, 0.1916911486055582, 0.12695504893218318], [0.02900781200057076, 0.006393641975122474, 0.04870511997010439, 0.04049899296895151, 0.040632751920530875, 0.06428835958602928, 0.02128302378790273, 0.045143933441009254, 0.038208933997779124, 0.08602767491773253, 0.06305789214468772, 0.025636724444226395, 0.012330238767448935, 0.036375616647062764, 0.03298758514105313, 0.0576135044496867, 0.038941739232189236, 0.04461941985233177, 0.03914916519856742, 0.04517683308691748, 0.038830373030636585, 0.03519337827099427, 0.02504949315240787, 0.03983481389079844, 0.05995255857405644, 0.08956864821694552, 0.04584000475945012, 0.054681827689731316, 0.07012350574856804, 0.10982149250565038, 0.023260156909424453, 0.06258584791794419, 0.05610348769433557, 0.1052485834506731, 0.07456113133699664, 0.11415992502964313, 0.021770096744500825, 0.0807835196235007, 0.06720790534370369, 0.044578066426179105, 2.0597079155906557, 19.47848831453631, 8.90074045427384, 46.82967955066312, 32.79121860381096, 26.669810818087672, 41.93859377214986, 85.99868774414064, 117.13832178423482, 72.14523715357628, 31.44228216140501, 40.720988089038485, 50.01588752192836, 41.45325537650816, 11.15844495834843, 0.41561327093551237, 0.43247719505621546, 0.31923796981573105, 0.9019546595311935, 0.4239172350254751, 0.3303718626979859, 0.021070941922164733, 0.19207066856324675, 0.008000439096752915, 0.17113094218075278, 0.003908672041424941, 0.13248695451165401, 0.2463770020873316, 0.18422390574649458, 0.06127350482969515, 0.010267737595694921, 0.047901068558736194, 0.030741327246951482, 0.044797577429562814, 0.01764506184225602, 0.23493521846830848, 0.02141697617668298, 0.07260821233954161, 0.042302072829296516, 0.03178200598115162, 0.035526480961350665, 0.008917337174587434, 0.0440310183612089, 0.009973992672448438, 0.05988092169225697, 0.04956679268469734, 0.02235313370493391, 0.030969847444324728, 0.06769706014423602, 0.08815401323860692, 0.050179651532802856, 0.20160981153528537, 0.0977564120905534, 0.06912634272368685, 0.03888255510959895, 0.02310880091822436, 0.022079711179098776, 0.056500911126814546, 0.029022867543502685, 0.08549064728281192, 0.01888834976501042, 0.08117683682470553, 0.04284974142548539, 0.028625421128385974, 0.0745173647338825, 0.016885177314942403, 0.012002042870247557, 0.038842013736646024, 0.16296085961643728, 0.4015088874486185, 0.08978670748371272, 0.20042174706055274, 0.04105822566235739, 0.06385284243151546, 0.07349754848908033, 0.07743690283067765, 0.02449892299820579, 0.06131959267921987, 0.013610217513726845, 0.07135703754160674, 0.1612390770066169, 0.1529825644026841, 0.3222660089452421, 0.18405538172491137, 0.14977956611302592, 0.9260117202516526, 15.879882343353765, 49.743722100411695, 67.90656705056468, 41.44995666319325, 54.933543435988895, 92.8926298695226, 99.738507270813, 64.25782142146942, 34.29549071096605, 25.99433356715787, 35.00045437966624, 58.99967631986065, 56.00195784722605, 24.833741495686194, 0.567131825993138, 0.18191746015462185, 0.0688086384006085, 0.17525701513213499, 0.05744896791574936, 0.06709575773246827, 0.13829698065115562, 0.10567193895938898, 0.03496674264991476, 0.007239725279261268, 0.02532611984098631, 0.03667100482890683, 0.03000286062278094, 0.007395115202187651, 0.013110208204917371, 0.08178781492695694, 0.02537706851839058, 0.022265035508861466, 0.014638663738996032, 0.025625317395033858, 0.02251076587145367, 0.09578860034385035, 0.030430358751947363, 0.01956171615259542, 0.03755997325624189, 0.04523106062063768, 0.005436907325225372, 0.02032410578742143, 0.025304671294326266, 0.04032286935515943, 0.014889845774779397, 0.027690108212071563, 0.007872229973380005, 0.0191454220593216, 0.03920124768609962, 0.021885944560410518, 0.02180343689096551, 0.03691442926684695, 0.027474159517535762, 0.04114713782684938, 0.07767607548063801, 0.0608904225631587, 0.06262389950514322, 0.040181748298627716, 0.09403091885389821, 0.08554946751363816, 0.04225788487782402, 0.01874339060797807, 0.04392960364179265, 0.019533516456102653, 0.03928659754174371, 0.052163566447674274, 0.0372917122477966, 0.06488364054671218, 0.011425339541728459, 0.03357282651948833, 0.04592379945660791, 0.03877440264688865, 0.07591126937299006, 0.032946450049958886, 0.05747870361853031, 0.07872242901113727, 0.005083855705320715, 0.0292008412596319, 0.08249106065880868, 0.033837287731829195, 0.02689935417184907, 0.04656626377254725, 0.07953684942256059, 0.07002402157072099, 0.021801194168567177, 0.13227415060804737, 0.033770504017030044, 0.10404553429614152, 0.05527921539220599, 0.3036491530797174, 8.423546860294959, 11.39345572840783, 58.80429129446707, 67.28236890608265, 53.44703966571439, 50.2614906526381, 80.13329305956441, 115.29817319685414, 79.1492017622917, 35.762519913335005, 45.252812216358805, 74.492948285995, 60.48238323580835, 16.95893422249825, 2.5513409799145115, 0.32131750016443195, 0.6138488482083044, 0.5239371534797453, 0.08699172762252631, 0.14712603672617866, 0.31095750930328525, 0.5890600815896065, 0.08890846428731758, 0.09643313309718525, 0.4504545820095847, 0.06916245610843744, 0.07235108258863611, 0.153624668657299, 0.21997004326793457, 0.1216515907717328, 0.07225824039309256, 0.11107525668076931, 0.048443175356594786, 0.08341137740400531, 0.024996424326673154, 0.04633043126593675, 0.01621846631619959, 0.10777249842161134, 0.04987221278790986, 0.0321675646269033, 0.04266886423612314, 0.05218327022908677, 0.06139472675239367, 0.023799888834717776, 0.012447186877139875, 0.06589719019229374, 0.015851817593248864, 0.05675517953932286, 0.054341044967934016, 0.03687404494191851, 0.08701289463187419, 0.06611245323813732, 0.14331615890466398, 0.046558572249787475, 0.04640049766749144, 0.04423482073170524, 0.03420225201895641, 0.03976214662074082, 0.03835653232771062, 0.047440431381185214, 0.023155076459290522, 0.062257192367988254, 0.053406934809660724, 0.12813191320146286, 0.040488095368228616, 0.010656534878146506, 0.06170223444519986, 0.02438278406888487, 0.19285109765346975, 1.4134734051842845, 0.16334810174040257, 0.04029573452088141, 0.10294618280304056, 0.023499906040547837, 0.03561562295221994, 0.042330858583051356, 0.05518432774190461, 0.03165662803146387, 0.1359621898060845, 0.05824717407625529, 0.016810499064083544, 0.11770455256825495, 0.7645575870429316, 0.39474004098484594, 0.38642568874263, 1.6087641711196594, 15.698953213230258, 45.12868488988569, 69.60973078204741, 62.218675305766446, 45.461243044945505, 62.12202025998024, 100.60026768715151, 95.5164287936303, 58.04196296199676, 41.36297810462214, 45.36508614017118, 61.88150444338399, 68.45103125418386, 47.864581231148016, 4.500776115925082, 0.5090301549963413, 0.021254605756351547, 0.199484545737505, 0.014518276852134977, 0.03907111999128134, 0.21913030365061378, 0.04719653962961128, 0.08812294071239811, 0.03537881751394561, 0.03928678523328516, 0.015659834044204367, 0.0304806390176377, 0.010456735317054535, 0.04004086472935254, 0.06061481860195918, 0.05097016617054901, 0.052625666853160634, 0.034825836098001856, 0.03375101090979672, 0.021495350801776496, 0.12198838600588423, 0.09547527804369889, 0.008322448833965728, 0.06240115178027942, 0.01087603151738163, 0.04673092288055247, 0.03483216781469603, 0.08476903076253592, 0.06481514462540228, 0.014983174436154866, 0.018870796775445342, 0.051654585291661566, 0.06255464132634864, 0.021468782872562448, 0.05905982865501316, 0.17076534970152765, 0.23850066827670222, 0.14267054596735587, 0.18062434970371186, 0.17385875145273824, 0.11192111734060511, 0.15420727852371433, 0.1660638527884599, 0.19449280875344432, 0.18903826273256735, 0.1597756652101394, 0.06962620743340062, 0.17981749058010119, 0.0719537434258288, 0.14180983086266827, 0.18008405853423382, 0.06890682788986353, 0.1881808877712296, 0.100662964997032, 0.1290449521113788, 0.20488617040457266, 0.15930927088183744, 0.14925694093108177, 0.15234240601139684, 0.2756701818396968, 0.13213558062430353, 0.18366070854808056, 0.1658715340759485, 0.19179501480633215, 0.18640344121283103, 0.07199132003851476, 0.18597622462097677, 0.15126384614456087, 0.18061198504461398, 0.20998416378373103, 0.3555335302747065, 0.06944038514648715, 0.2310331189824689, 0.2554156751401963, 0.5281221998795387, 5.495028803425451, 24.151986491295602, 87.59250363995953, 108.92984436404322, 72.01956441325527, 55.865012215029815, 71.95168387505316, 122.51395363961498, 146.92790738997923, 103.33764276196881, 51.93384808878745, 64.0467155364252, 74.66616015280448, 58.45573771384455, 16.93818292310161, 0.7418878809098275, 2.130371375430015, 1.6434577804419304, 2.522026901283572, 2.012839882123855, 2.3642029829563636, 1.253182438592757, 0.6229904221911585, 0.2122776778114419, 0.800103699007342, 0.11083331079252305, 0.5935919513144802, 0.3907298771364074, 0.9925619620949993, 0.19053152131457485, 0.12620550084618792, 0.24553602140757347, 0.11297886259853841, 0.24620205824894292, 0.08065283268449769, 0.28037313431982075, 0.0884649913097101, 0.2926302346731386, 0.14347101591767805, 0.11422109715039692, 0.1279887620119318, 0.15519329496929724, 0.17631695906241096, 0.11396268803265788, 0.13909991740459396, 0.13813574978661153, 0.18658086717609437, 0.12176415207044733, 0.1792864997180239, 0.15482290677966612, 0.21582492537075476, 0.37021989543591777, 0.4426257456502607, 0.15233617005569322, 0.11321820378784211, 0.14399572485877624, 0.17779958434402945, 0.16022051714601057, 0.11849344693004124, 0.1578952564347175, 0.10925867069031923, 0.22451657591567886, 0.15478475560103694, 0.26343876075360084, 0.1690806763907594, 0.14247519354666435, 0.19197195047332397, 0.18445328779278264, 0.3359105251729489, 1.4736874257364583, 0.12790909652868587, 0.33568299705943755, 0.1653755993972863, 0.1793354680581439, 0.09958124884794797, 0.26177003739341614, 0.2561167681649808, 0.13434271057767255, 0.18568489670513139, 0.32912712303861497, 0.3810119905298756, 0.5333798919473925, 1.5184823639931218, 0.5712934607459653, 0.7190856722093398, 2.218998064917903, 25.82156885054804, 65.44716250511908, 84.7197675704956, 63.12991642182874, 68.97556197258734, 110.50243239248954, 118.78261858417143, 90.45698704258089, 51.3000048360517, 47.50805739433535, 61.34301400953724, 78.67742692270588, 82.96521294501521, 44.629288719546416, 1.5447203238164227, 0.5014196536954373, 0.21883292364016657, 0.3015934327437032, 0.10151912953944937, 0.1918446879473425, 0.4083926777445501, 0.21805304613324905, 0.193823462412242, 0.15807511855758008, 0.13508033067468675, 0.17685821550267358, 0.09490736940455052, 0.07643304419733825, 0.13224294018601218, 0.23978061733707307, 0.19281757364590324, 0.16420425096106145, 0.1056606161798681, 0.114723558898174, 0.20475458714269823, 0.24221728255431502, 0.1853981653168317, 0.1388194372937564, 0.20125229362278216, 0.10740217917989339, 0.2249852378642367, 0.14055021377580781, 0.11914836783562938, 0.21754603382320176, 0.1350856932901567, 0.12091125106258739, 0.16444253494902966, 0.13493419174225102, 0.07817632323431392, 0.1523677022346566], [0.03971806592157772, 0.038481990716630415, 0.0519511494184694, 0.017836114594472513, 0.05822201574882192, 0.05789174375334575, 0.03609294935520138, 0.03225820048922493, 0.04683331053163256, 0.022081065239504944, 0.025175439922379392, 0.009558343050640919, 0.018270526667155566, 0.06538851547145075, 0.0584199192423013, 0.08138952581512351, 0.07353099588785442, 0.0234518627515964, 0.06964909047969887, 0.016844178204454722, 0.055610774415394956, 0.04312738318056349, 0.06643567339427049, 0.05100557858484888, 0.0523846211182254, 0.033708381947250135, 0.02563111093496123, 0.026276359980505322, 0.04406510927383939, 0.1754611162769218, 0.00981882730904486, 0.03454927452689698, 0.08452156138035559, 0.03398640674629039, 0.07562954819971517, 0.13770888559520245, 0.05740433563328078, 0.06647400843400149, 0.07768239570601333, 0.07546560538391914, 0.3936719918443311, 2.041364461183548, 9.667180411277279, 44.512339330488636, 52.82674820192399, 54.46640091557657, 30.574353817970525, 42.429443097883656, 76.75738749965545, 116.64702923067155, 119.60491995657645, 77.36531565266272, 40.36013787792575, 42.598826731404955, 51.89514606229721, 47.86865265138688, 15.139139794534254, 1.0934931881004766, 0.0777579702797436, 0.14822699700392064, 1.162023001140164, 0.6404783708914634, 0.056877899163913344, 0.11126630368732637, 0.5855471700910599, 0.2383967561106528, 0.05910302452262371, 0.08098546040034102, 0.07990464057412841, 0.06446473600883638, 0.05431700129843047, 0.020730283689655123, 0.09724659589870323, 0.03856239930516289, 0.09354462156132345, 0.07231798759030719, 0.04797651672795896, 0.04023923936690535, 0.06524521106433484, 0.11977202469302763, 0.13724063733412376, 0.054064912406066735, 0.0349496397370052, 0.0636269690679206, 0.037870671705252705, 0.023819883729541497, 0.03574550166846283, 0.02158137098435433, 0.007332566038389961, 0.012089228464080202, 0.051204861036591956, 0.41136405701118134, 0.034980938259151675, 0.027889237446229787, 0.03185802680109778, 0.047860113498304165, 0.06947885042116528, 0.07087149867607702, 0.03835760102036499, 0.0724444687066059, 0.08746716178833477, 0.027501146879888354, 0.053566315571867654, 0.07639933632866991, 0.006868298561687792, 0.10459358593629253, 0.06322006912781827, 0.06744061987246237, 0.019012781596111677, 1.0254593710264852, 1.0388190251204277, 0.07586711972591377, 0.11700486148437185, 0.02332157609353383, 0.06240196766391878, 0.14966296753095043, 0.07364102909641881, 0.028758126709069458, 0.03885876424911042, 0.03291384917834113, 0.24382292623481444, 0.28286871169843986, 1.2405403943792468, 0.1708674845435927, 4.555194589399523, 22.53070223715998, 38.53713004819809, 59.544473924944484, 57.68078719415973, 67.96443770008703, 98.48035996960056, 76.36908069733651, 42.24480536676223, 19.045562590322188, 35.21088169467065, 58.60254810702417, 67.41707878728067, 71.0175714185161, 15.04691408526513, 0.39929406597248973, 0.06793873790170878, 0.061139646286685626, 0.06919909809385577, 0.01976556640358702, 0.04618136970806987, 0.10704711274874788, 0.046907372081712376, 0.05199738282469973, 0.16402541539601742, 0.04533973019269686, 0.05386711999533638, 0.07809740851723379, 0.06305561686355261, 0.037267940539506175, 0.04932452120908326, 0.03911462229406161, 0.0772545202785442, 0.05182466064129145, 0.04007585962573367, 0.047620994474498496, 0.06439362772770467, 0.03327415948132834, 0.026976108520982728, 0.01639576012929601, 0.05215897375056821, 0.031625128411237276, 0.06815891923202623, 0.035115348385466684, 0.05719168494725901, 0.04866176705446936, 0.059707870091041254, 0.07373122828862361, 0.0306849182778669, 0.06410046503128064, 0.0377925498891742, 0.06170161774442081, 0.031104774679988626, 0.0336604822997845, 0.04832837325070174, 0.03418808705323646, 0.06774851060923069, 0.0626217123241194, 0.05407255413311143, 0.051003276490636414, 0.038396763435054215, 0.05592571316106666, 0.017259305928863825, 0.10016781938893181, 0.03691610699940113, 0.06649628627083956, 0.04327215081561477, 0.0019382746282762158, 0.07627386644843125, 0.07986773045793658, 0.08300613221381942, 0.08642055544882052, 0.0984852068546799, 0.0501086428431013, 0.1065776157643526, 0.06697858458444958, 0.04964073549114889, 0.013950750299338854, 0.02754794910640246, 0.029605801082065994, 0.039569678521084214, 0.017865808162417625, 0.018936569254184445, 0.11076286900788547, 0.051543402951210744, 0.03585865285487906, 0.08491550677365835, 0.10128659121091328, 0.061591251287609346, 0.07216351362125528, 0.04362623665421721, 0.07418777838709854, 0.6908472423111239, 6.586690122081388, 29.82906622271384, 73.49649367793914, 61.35645989448794, 57.76170569081461, 51.00771373318088, 71.42528610844766, 110.58539836637436, 102.53654572271533, 73.06237359200755, 52.33180392173029, 58.104920925632605, 73.50284007287794, 59.93374170795564, 22.27871152662462, 3.1579281726191124, 0.5565110281590493, 0.82000108616006, 0.9102363151408012, 0.592204719301193, 0.23323753698458596, 0.06005440230271029, 0.05696645126708093, 0.8609749004244805, 0.10906459763646127, 0.12596294208760225, 0.10315720172178361, 0.11294266494411616, 0.044512167542932496, 0.03566882009768198, 0.04464444411437839, 0.10414269722757802, 0.032695387715413686, 0.05067929407701858, 0.06692673575373427, 0.0355258068039773, 0.043187341051957304, 0.014243347048308822, 0.10514235003821312, 0.05360162073385812, 0.01492854374866452, 0.002662208684224395, 0.038483959562595815, 0.02416099395392643, 0.058433835229445855, 0.022819769350932013, 0.04353503771727124, 0.03891156685929145, 0.06139332481149224, 0.08682219236488305, 0.43305222065218035, 0.0856885890806875, 0.06480423553336052, 0.0167427328415215, 0.04220135141945174, 0.019020453966673345, 0.05231205727003756, 0.06497546384531645, 0.07479274269914435, 0.08074647161148249, 0.07489368244404755, 0.04228296276602534, 0.055909606162458665, 0.059088997452730135, 0.20055875422493105, 0.09878015836640712, 0.055905120717662, 0.04608775759416242, 0.2353859999247136, 0.7849593664849959, 0.20117638963124446, 0.03880938605195092, 0.045424336943054394, 0.12712884363868546, 0.08180512085316644, 0.1136446389700136, 0.05894804876598139, 0.0337623528415157, 0.06040540080697787, 0.10167882822814489, 0.7212257541475758, 1.167062021070911, 0.17696952807807154, 5.812207835335886, 28.48305194608627, 51.286570718211514, 83.93585051259687, 76.93517285008585, 59.090640006526826, 89.67317981104698, 98.98847164646273, 75.9809543240455, 41.35681606108143, 42.61044086948518, 54.76741536971062, 66.33501452784385, 83.18054322273501, 36.890279785279304, 1.710463630095605, 0.3267945998137997, 0.09784352394842333, 0.0933003850701836, 0.03500199418575053, 0.05343157985818483, 0.1004056207415077, 0.07241911885719146, 0.0701336257700478, 0.07776988294696616, 0.03832134590934842, 0.058072069359402505, 0.007239294354803861, 0.042912702361542376, 0.042446350168076255, 0.020300588803365827, 0.052489326185276436, 0.07317915468687013, 0.026753768737938617, 0.07882775843984659, 0.05862018611702708, 0.01188207445891514, 0.04379534290262288, 0.0605771309065242, 0.03487045305871195, 0.026671877769272656, 0.02953952681573649, 0.02465982636016223, 0.09634717803208098, 0.031372786709858526, 0.03819884845025597, 0.051638516597449786, 0.01450236137550805, 0.08619440629357293, 0.10893362724492628, 0.043660806371800365, 0.010271666669136575, 0.1617973252770401, 0.12412534230538916, 0.15615994471215433, 0.14924695114454917, 0.17357185152509522, 0.21644115117528748, 0.2058471204532731, 0.08832705717894339, 0.15262781972846678, 0.14885094497473011, 0.07341613632536705, 0.19169032123059998, 0.14112810454060956, 0.31414124814252703, 0.09956565129780963, 0.14679139419909448, 0.22898064685925362, 0.22053805149851308, 0.20248727332199776, 0.17470063611624703, 0.18305382901622405, 0.1522405776045015, 0.282630029344751, 0.16880116155070646, 0.24445003048787195, 0.11599727200284121, 0.13499691902149108, 0.13475849713769653, 0.1464720581087374, 0.32311143293496103, 0.22444923678713463, 0.20054841203795326, 0.14103891658446482, 0.1405280891565546, 0.1442639628845838, 0.16651362300880496, 0.2116932446557668, 0.14661871798096165, 0.1919305817254128, 0.23382109680002738, 0.6914681412519947, 3.9478925447310176, 38.8259929995383, 89.57434392744496, 99.65974607775289, 95.40540218353273, 62.581012095174486, 66.41776869373938, 106.48818462125718, 141.10662368036085, 145.79572308448056, 97.58867186884727, 60.02855323976087, 67.74815036404517, 75.85162593472388, 68.42033478521532, 22.202896033563924, 1.547621406855122, 1.4013507072964024, 3.287612271885718, 3.891789903563838, 2.2774798687427276, 0.20782054762446112, 0.3441763687277994, 1.6790563541073955, 0.6291902185447755, 0.2222818361535188, 0.19697931565103993, 0.3874434212282781, 0.13981893688680666, 0.13480801706112203, 0.20887546601795384, 0.25593923494940807, 0.2333119088002751, 0.12668124910804535, 0.12856951794557034, 0.1436564245171124, 0.14324411599626466, 0.11154781035598248, 0.2599395469071404, 0.20562346874465867, 0.13463135718578292, 0.12692197691649199, 0.27533999794433195, 0.11004492970964602, 0.26264919989532043, 0.13621001924958923, 0.07640254623707264, 0.1860450806036111, 0.23254886990593326, 0.2121649403125048, 1.1216793401587395, 0.24329450942816275, 0.1648040671622561, 0.09789183345292846, 0.1767728120208748, 0.20135738556423496, 0.18458762897118447, 0.18848632702664023, 0.15734770275171728, 0.2731862489975268, 0.2183433321695174, 0.0836995950028781, 0.21801221364688492, 0.20667550664755607, 0.3311686860697885, 0.17939670912681088, 0.24795233932954652, 0.11095850488110898, 1.308106775245359, 3.5007994646026246, 0.7342865113769809, 0.24328087306311055, 0.15477294252524454, 0.159310266796139, 0.24157672579730713, 0.17354627951018273, 0.21864279593911864, 0.13580065250637072, 0.1682505435160091, 0.5161625867889774, 0.7843654951260937, 1.2921049758311243, 0.4455283915083255, 8.097571422976833, 38.291726958367136, 50.59033824551491, 80.92390168097712, 85.5847913988175, 87.26759018436556, 113.41428233731179, 97.40103352454402, 65.57322748245733, 38.26179927395236, 57.74479635300175, 76.11351474638909, 86.60952629581575, 96.40147239931169, 29.968320169756492, 0.5988867833249031, 0.28060550410901347, 0.1657078210865298, 0.1955443410383117, 0.18136854283511641, 0.1418179820381826, 0.2840568527819649, 0.08084932657619638, 0.13824320127887113, 0.3724158711491093, 0.12338630494571502, 0.17152353159842954, 0.31108155425998474, 0.17808568754023124, 0.1678116670659473, 0.12114699163864698, 0.3228573981792696, 0.2413835337445621, 0.11579422805938991, 0.24177016299818796, 0.1325616021189959, 0.14809835551967546, 0.1060598322580899, 0.1189517513698628, 0.09991280404069733, 0.17367455327222425, 0.12012306150169143, 0.12944578463512083, 0.16163713629207305, 0.13199264393939128, 0.17765341476807672, 0.19136634264742175, 0.1976693004009224, 0.201157697085892, 0.185971214405952, 0.13970817589471418, 0.18143134672314892], [0.04723911879644279, 0.036151306102833444, 0.024470813317044128, 0.022181418927146063, 0.08274042993904122, 0.06490222583975523, 0.08452995004312647, 0.06443230750700159, 0.07358737995908146, 0.02614442240296593, 0.0445795871107088, 0.09122092366939591, 0.036766018883715716, 0.02959997689862165, 0.07592018663642869, 0.05376263326334377, 0.022207567423221566, 0.026534140906146458, 0.0604801097013537, 0.04777439975089604, 0.08610141088044451, 0.0449025965926628, 0.024456410864067656, 0.025026742256276553, 0.06551210077539568, 0.001972900006935121, 0.018857736891556173, 0.056525452753468874, 0.092614812986745, 0.008194603123551896, 0.02776586090124423, 0.05656331281868681, 0.032363575883209705, 0.026277516773270986, 0.04551284308094652, 0.10780189321526598, 0.07945458690125136, 0.07299979818203757, 0.014974821204950493, 0.04481035577613981, 0.1542186932337861, 0.3629756454498537, 0.27942741409905497, 26.395593996970888, 63.21438074111939, 72.82844343493062, 68.31182633676838, 47.48658241764192, 50.35330941600185, 64.05346985786193, 91.22460273004349, 116.48009315613778, 111.1949033121909, 74.88362419989802, 48.36513450068813, 61.76030320505943, 69.84177035670128, 43.27121903819423, 15.780627746735851, 1.180100469819961, 0.16607269344310607, 0.3488102200771532, 0.2326501160860062, 0.07978177539283231, 0.24427468828376264, 0.09813584777857028, 0.03335542991877564, 0.0698936410668877, 0.15253000562229466, 0.049075236198522394, 0.06966953736639793, 0.042503676527450164, 0.018477584911330093, 0.03945495302398359, 0.053595775482995864, 0.09372514251980091, 0.10230220929389039, 0.01650061458349228, 0.019994793317070412, 0.05869159700288888, 0.021687117930982384, 0.08178485782756921, 0.11952406501457577, 0.097014463596767, 0.08589531024617535, 0.053501420263801856, 0.007377496616344058, 0.07320268124702477, 0.03547313825918302, 0.06107089755636069, 0.3137657118420447, 0.2773229092840226, 0.051097750453458685, 0.11771432018928951, 0.11391833920272128, 0.01192333116646736, 0.07891117775392148, 0.021090396725001837, 0.007189903229910641, 0.04230098498444404, 0.09335990244102094, 0.0731749641859243, 0.04324923712579955, 0.0037481567508826454, 0.018134932934997544, 0.07509360074876778, 0.010854174071292003, 0.007998006288788372, 0.059270472190673315, 0.24382885575534838, 0.6702405803145901, 0.8016061506444409, 0.07729283233563747, 0.0882543784175669, 0.03086057649324498, 0.1364756832199712, 0.012259570029263776, 0.043839527023655754, 0.16638732575360807, 0.23675170486732838, 0.6025785303884937, 0.9412717014070481, 0.917523404763591, 10.483075572598366, 33.41334965921218, 55.442820056792236, 61.883987303703066, 65.88892336814635, 81.13598423619425, 80.7557261374689, 48.45985189560921, 23.77677256061185, 27.448365995960852, 44.41591962691277, 67.15645297881096, 80.27134480014925, 56.945072143308586, 2.9142599961450024, 0.4841890492506566, 0.054141931055534276, 0.06959113592822706, 0.22628489070602004, 0.015910195408298845, 0.02165326450560843, 0.042986074432490334, 0.040033268967583295, 0.030799425439909104, 0.06792096466186547, 0.025583077222108844, 0.03713428884023621, 0.018672853062349944, 0.025386227099525354, 0.0958333858439038, 0.036809360308031884, 0.06629970810946918, 0.013043988522352471, 0.05919783556413266, 0.04828306298042017, 0.05921605313497205, 0.06073089241380654, 0.06239650545701866, 0.05072944219254198, 0.03360361559316516, 0.03469732867914342, 0.11432321667070351, 0.05218208662324375, 0.03851807728830365, 0.01899588552694167, 0.03284379043766568, 0.040685673274340174, 0.0334617859053035, 0.0954415625141513, 0.052352583321231994, 0.057682080810228666, 0.058636281624316215, 0.039686139207333326, 0.04472105290680643, 0.03953287565720178, 0.006737386584357029, 0.011864239932037892, 0.03698235445265328, 0.10270275836510044, 0.08899572936277236, 0.037497253637881055, 0.1191201451564989, 0.02536426144351642, 0.011676399961053845, 0.03217722499562848, 0.07584210695518602, 0.02749409695576516, 0.041781209649578224, 0.02367933915417281, 0.006416760593457449, 0.018502308483866435, 0.009672635708064323, 0.033945715986192226, 0.017729590068601312, 0.03668355334910654, 0.0392050551430833, 0.024156560220064658, 0.0032636777201156706, 0.056686618500539375, 0.01929792335196849, 0.07051807933396871, 0.019345062657169277, 0.014242257288236533, 0.09254410307133391, 0.12612072555648704, 0.041934760482681376, 0.10066672648874023, 0.061584463748600216, 0.028472502317820347, 0.04618059595926635, 0.07615519176808096, 0.06656170251869387, 0.03172841046996896, 0.18734491730649627, 0.6391321399038838, 1.6142174913998575, 43.9527936135569, 87.92268876106509, 88.03361338953819, 64.7388412875514, 63.80950627788421, 78.85585554184453, 97.54822438763034, 117.14918674961214, 106.09597898298695, 71.46593755291354, 57.60780757473361, 60.9549621612795, 85.26059965933524, 70.51626897627308, 34.33782485223586, 9.665923291637052, 0.20276707927546195, 0.4137999408187405, 0.14839472429406259, 0.1835520313151421, 0.14580513260537578, 0.17730689787816617, 0.12079318925257652, 0.020190252990071333, 0.19993252331210723, 0.04274353099566314, 0.08021436226103576, 0.009765714433254495, 0.05066270827345791, 0.03350411992399924, 0.06671903399570335, 0.020393670401385715, 0.03278962802141905, 0.017827486529225306, 0.07891799593644758, 0.014820044631168488, 0.05461210602774255, 0.0375955005837304, 0.014648931232401201, 0.0422433138855042, 0.08449740662810304, 0.04836440619622027, 0.0653724889120748, 0.008399622616237931, 0.018302949423330928, 0.032986665835543987, 0.02414864653180684, 0.5304489621231633, 0.9595354213829964, 0.1455274410545826, 0.07089150889265923, 0.06183404753345156, 0.046465929237104235, 0.055917975673031424, 0.03523417628340183, 0.06609466467653552, 0.03921129875966618, 0.0689553595598667, 0.027713247897824454, 0.020623966007523482, 0.0533685231611373, 0.032537937494775945, 0.0717472980519937, 0.009859138855620498, 0.04164650074897274, 0.060737224130500714, 0.08860402860708776, 0.23374087207259672, 0.5099585309865013, 0.4457324773313538, 0.15901912274139543, 0.008189342972341805, 0.04324670137477018, 0.16232272369727013, 0.18002226588226136, 0.19267085248664503, 0.17890201551058602, 0.560109006060708, 0.43988235414989535, 0.8520333673204146, 14.361595607572987, 43.396778029780236, 68.55842574950188, 64.28923960654967, 68.89563975795623, 77.24100789716168, 95.16646708211591, 78.66113339701008, 50.69588922685193, 39.525543797400694, 42.03350728557956, 65.42298893774709, 85.40895154399257, 79.22003976760372, 18.047087961627593, 1.3955329743123825, 0.036194360244178006, 0.010191341392665861, 0.05247823706257248, 0.05063308365342598, 0.019017290023546067, 0.029613117221742872, 0.022731822457224615, 0.056820718361245054, 0.05061833646088358, 0.0734103830050557, 0.03827759462799277, 0.017586090309064717, 0.048946426174933874, 0.03164405269818681, 0.0397039775646502, 0.045977555846254674, 0.05162971041676018, 0.05929396427687138, 0.017959845455123052, 0.054400282716679, 0.10775660975806176, 0.06769493808068576, 0.04151814271725955, 0.02429059879373639, 0.027693777773228866, 0.052898493745634635, 0.037808783292289705, 0.01298282980813735, 0.04382050889093549, 0.0751721554045235, 0.05996917502113408, 0.11127058611882311, 0.08065480153046309, 0.04831973177891585, 0.06806815313475748, 0.01862656794518473, 0.05162815525827389, 0.1907108624976489, 0.10674739617013163, 0.11914565588437742, 0.10777178595984176, 0.14522904980807536, 0.26170617630404813, 0.17614745444828467, 0.20234003122295105, 0.18524041249146386, 0.08433983766383703, 0.06346432094071662, 0.23812894709408286, 0.24644804908142937, 0.21099354591100447, 0.14125833948773725, 0.11904453993925165, 0.11902464463585809, 0.09827154493259807, 0.17195257147954357, 0.175347505437751, 0.13186938039237453, 0.12109327355339644, 0.17376754102447342, 0.12001493585205848, 0.19737354449687466, 0.1250708097171399, 0.12644564642781211, 0.15604155348433604, 0.2866507039195107, 0.11531333168668133, 0.1480756486735998, 0.3806392121459208, 0.10158479093543946, 0.17265948677255263, 0.12430600882057222, 0.14417523458119363, 0.12207903718996434, 0.1473848671922761, 0.08700356368095645, 0.22873384397356744, 0.2166713146312583, 0.6005444750189781, 0.4256264078280618, 45.18839513101886, 110.9727010419292, 114.21520679227768, 104.90060529401227, 79.07391578920426, 78.21171606740644, 85.70829899080339, 115.10919340195196, 135.47537096085088, 131.91539641349547, 90.84229715408819, 70.07148004347279, 88.56499256626253, 91.66648910891627, 66.12072760058989, 26.716675296906505, 3.3103257369610573, 1.2847078759824078, 1.1312838763959947, 0.35001349905806206, 0.31245628371834755, 0.36602145781920803, 0.20302747256092488, 0.13136163263791992, 0.23435198040979527, 0.3949265374291328, 0.16955765805417494, 0.09557654720640953, 0.190979054558181, 0.10784362968538078, 0.16019946504985133, 0.22039427211688412, 0.114293952111996, 0.1065541887956281, 0.2519466451579525, 0.24055929974682871, 0.21510828076110733, 0.06733549728749261, 0.19364430509026975, 0.1429113580454742, 0.11985489242379704, 0.13967154157017508, 0.16668017052354353, 0.1054625441470454, 0.19594270675893755, 0.09020588781324126, 0.14703327880030678, 0.6718542066312606, 2.6216014162186654, 0.12787050867993988, 0.2124344194007497, 0.21695200924671468, 0.10206760252795874, 0.23271428361054391, 0.08478324935441056, 0.1749970048906342, 0.11146432975487364, 0.18824888573538875, 0.22678195919481017, 0.12954949761830992, 0.18442034601203858, 0.11549102578071818, 0.2060576260931069, 0.11644053813670913, 0.149671409819876, 0.14826968342306154, 0.21718880702410975, 1.3583796711698657, 1.5133022613102391, 0.42319619307114237, 0.11787078598694456, 0.174435539050929, 0.34865430586280366, 0.21161907202293798, 0.32597283261918253, 0.31179266771481884, 0.37349584061772595, 1.3450124787707485, 1.7891940570646718, 1.870651879618245, 19.562889875904208, 54.79267935599051, 72.71012906105288, 88.40427737082206, 86.64755759700653, 95.44706559950306, 101.16230410914268, 68.14594930218112, 39.61147116076562, 46.836861410448634, 63.50206305903774, 85.21288794855919, 105.26431099061044, 83.85115869583623, 9.273139103766411, 1.2352444592022127, 0.20886618103231155, 0.1999790708143865, 0.357039597846808, 0.18262420690828757, 0.16324369927808163, 0.22702061090498205, 0.10685857084970321, 0.15250677783643046, 0.25724156909892637, 0.09883953784141811, 0.12407289592609291, 0.11449691178577562, 0.10843666600844554, 0.12748920373738776, 0.15646553718514983, 0.17205777067330577, 0.1339008157411891, 0.23997167966538863, 0.0911206427601076, 0.13306193414234346, 0.21341386281194227, 0.13293655619265574, 0.10526952829452292, 0.1276646761764442, 0.0804291196888493, 0.16121834666738588, 0.1688261206952795, 0.11941980044808119, 0.12780872368884663, 0.09197647022383829, 0.20233276870942887, 0.1496768490441384, 0.2386908725865426, 0.09566250993239303, 0.17683653521441645, 0.16507664124571508, 0.07931698984917133], [0.01752349517999157, 0.03135787480841241, 0.013373628495291117, 0.0479153331158863, 0.12737101169242976, 0.06843360771815624, 0.03147193380901891, 0.04853503312915564, 0.02032604782030948, 0.08883416141954162, 0.07706485223025084, 0.037461174727087064, 0.04529666456003343, 0.06730846970552398, 0.0703790880018665, 0.013817402162408877, 0.018698668310178385, 0.013490696306220226, 0.07317012251024285, 0.016120562194696358, 0.08930240968062032, 0.014180224276177827, 0.036839164958726016, 0.06493646996997057, 0.01812915088638904, 0.07585561308529108, 0.06285415872210456, 0.02173458090833118, 0.023769195522031477, 0.05396186591937177, 0.027457236635288405, 0.06798748407633075, 0.1093943448617093, 0.054113735189481135, 0.058979266848895824, 0.043278348466922203, 0.031425485898169785, 0.07685038591584853, 0.0625675039425973, 0.05384855768493107, 0.10545819276763548, 0.21269148786462125, 0.16134406169576032, 0.07221421332008417, 17.049333087859615, 62.05314736212454, 92.13317271201842, 89.15902768411945, 63.73814659733927, 40.30167102813721, 45.641609314949285, 70.0569280501335, 105.94237112229871, 119.40458097765524, 103.83951787025698, 85.1286825056999, 61.20315405630297, 51.14402394140921, 54.722778797149665, 33.99348781954858, 13.104726018444186, 1.670225995682901, 0.6731546562044852, 0.2163933166452954, 0.24159334990526402, 0.1892238858366205, 0.0664021723693417, 0.1338361579203798, 0.1537209352658641, 0.1731822804938401, 0.04659216520526717, 0.07688373372319245, 0.0645940822939719, 0.009545485222441776, 0.08569752166588461, 0.04781994750843414, 0.11682539006635068, 0.08816244786665325, 0.15761739634458097, 0.1146482830987342, 0.05646701939704438, 0.09110337513829432, 0.0850610404966339, 0.16445172800412103, 0.03445843948171504, 0.04625915827590131, 0.04868499100989392, 0.05721404322332913, 0.07741785788488004, 0.04137733192633718, 0.40911120693049124, 1.0964294498966587, 0.3262152228384249, 0.01763236776535069, 0.07767991358113867, 0.0895168147079887, 0.02483887642982506, 0.05242877076530168, 0.018559383949445143, 0.04329667329007099, 0.058901102897981485, 0.06870652654118116, 0.07542746186616921, 0.005768464433194529, 0.10843263638596382, 0.009586788852879358, 0.03656424281577911, 0.05160733298849195, 0.09959854711327823, 0.19838556196660767, 0.04464985269512381, 0.2539519722303075, 0.8988282240686879, 0.5599813451690059, 0.2097875243353267, 0.030176490620379488, 0.03413521549514225, 0.056490208878512346, 0.40260528184233174, 0.602802902219757, 1.2327840299375596, 2.6573810317823967, 9.892712773815278, 14.058383645549899, 37.18359070439493, 57.3292447674659, 70.95775527338829, 76.31948624887775, 68.12146586756553, 34.48822421412314, 11.809197548897037, 39.86553876630722, 64.51781572834139, 66.32295716193416, 78.41913884685886, 32.08114212559116, 0.5305035075833721, 0.7627536644858699, 0.08842630386953393, 0.107661584211934, 0.08260084105835808, 0.058125458026845614, 0.0492485367783135, 0.029038062897480788, 0.07934486778873591, 0.02918956061494687, 0.06995972381123612, 0.061771718619932095, 0.059870223274394396, 0.051594294172020695, 0.01920600620759351, 0.08925904910410605, 0.022473106904315854, 0.056099029062616254, 0.04342926778800545, 0.03739932461852028, 0.0153799093471119, 0.038664200898980906, 0.0322784022277882, 0.0059516216917414105, 0.027813877377118316, 0.10423093523469665, 0.04574106067358967, 0.06176044946656593, 0.004232776550305707, 0.04354433036379276, 0.03370735155899198, 0.025797336692771605, 0.00931039294828811, 0.053003857648300554, 0.06608737918037562, 0.07336850863911452, 0.013218024546550888, 0.034621037813203956, 0.06717756060102294, 0.017495113537616788, 0.0457846817199982, 0.014126405641887219, 0.06329138042224992, 0.053664049238807736, 0.06241044059636132, 0.0653033877813047, 0.031990491064085115, 0.049030803098914125, 0.06051374096122961, 0.06324934134740504, 0.041156901617444334, 0.03846418683327014, 0.04501570564424319, 0.06319547004456963, 0.005864386302193688, 0.03924758834463935, 0.06761329609059519, 0.09630266832368028, 0.05979483639220557, 0.00921104858148723, 0.08416856338660564, 0.036194115096042236, 0.04496680625203637, 0.06260191661215599, 0.07605508705901523, 0.03895002447309033, 0.058220403133741314, 0.027066859296492995, 0.035011053175455144, 0.0277625092665755, 0.03783686041471459, 0.0898421875711891, 0.07101517846627582, 0.019021740994386135, 0.11345827276067388, 0.052478562649940295, 0.0887767431296168, 0.025495026906531666, 0.04454169640197389, 0.03686333503273707, 0.030237442490855054, 0.14470034188801242, 0.30585361704710995, 1.269702726314145, 43.245723632074174, 87.0880005436559, 101.15514970594838, 79.13324556043072, 71.41595086743756, 67.73974080239573, 80.25633781186997, 101.19817026199834, 121.18089691285165, 106.35361594538536, 80.51760688904794, 79.92674104629025, 77.87366267173522, 76.84392283039709, 65.56272337513586, 33.526698312451764, 10.024816240033797, 0.9761106222867967, 0.9801584470175928, 0.1822718371066355, 0.2397316183534361, 0.10784068790775155, 0.02196392848066265, 0.28406788444807457, 0.22215040610922923, 0.03486580290501157, 0.06840610516167457, 0.16757145253640993, 0.08546555790329173, 0.0415194948624459, 0.05063940770924092, 0.11907707569339585, 0.1292792984074162, 0.11549274181766857, 0.03244175898632215, 0.07529926471292012, 0.04134239448655037, 0.05682801534872382, 0.10327402246935714, 0.07295103668565713, 0.055855934042483575, 0.06468523143520279, 0.09077873005862198, 0.04990067295429688, 0.024501774760503924, 0.08104311617752237, 0.29102767066609475, 1.8765646075048756, 0.43983448897638633, 0.012890979696455742, 0.03787337216518579, 0.1059327076279348, 0.04920420710057501, 0.03234060856723978, 0.04790376518822966, 0.03254177559527659, 0.1401353311995345, 0.09887392752833905, 0.020688608506574266, 0.09119659271692077, 0.02134947808489444, 0.03394099688457866, 0.04206514864739391, 0.04310206780510564, 0.05221519311289153, 0.06841467002466803, 0.026854200949591976, 0.30609306548872306, 0.6125425763668553, 0.8091153444782381, 0.5637932761061577, 0.23995009130768238, 0.5126417692630522, 0.2319295950714619, 0.6540271567721522, 0.9486574631544852, 0.9740033289117198, 5.419077008001266, 25.59486762169869, 49.5754720318702, 66.45663153740668, 77.23409668091806, 79.527341781124, 86.2818750258415, 90.99720724167364, 61.322915784774295, 32.85849705819161, 38.00650004417666, 56.99153261799967, 69.34807731259254, 91.40445909192486, 60.628566049760394, 5.361445132763156, 0.49472186954752095, 0.21202309147244502, 0.04203458173921512, 0.08135168107166406, 0.03982811828234023, 0.023613336849056428, 0.031223822828202002, 0.08055124942573809, 0.1045860093267214, 0.022355353444694512, 0.04577722385405533, 0.10434558029256522, 0.10988893888650403, 0.10216763828911128, 0.08816767258629685, 0.061054802049071565, 0.012949758750056068, 0.08179763617414622, 0.016535666936467734, 0.019111599277464614, 0.061253203499701724, 0.05204447807984487, 0.009822065945744756, 0.06377894175989975, 0.1579638366256991, 0.061583847047821175, 0.09259827314845978, 0.04569525244615732, 0.029670983673103397, 0.07668393033166086, 0.05016824448361032, 0.02013924877129255, 0.05794129815072783, 0.020789107750921, 0.010775612712266945, 0.027229846417603475, 0.019930129750601707, 0.035886860212251064, 0.04161480003066602, 0.12580578681081533, 0.24500685383475598, 0.12226439982412324, 0.20589530738371037, 0.21168397499188302, 0.20398701300784466, 0.17096137627959254, 0.13428240413627318, 0.12843274826844855, 0.19715640453561661, 0.15587414795112225, 0.1730650537196667, 0.22513981908559802, 0.14380726722940324, 0.24695052615096494, 0.23066654591070068, 0.1377619908101136, 0.11981235156136176, 0.19494184352938207, 0.202386410185887, 0.1520519974010606, 0.1257235932374193, 0.09768361075510902, 0.24103111797763457, 0.17326935404731383, 0.18200220480080576, 0.16432746854280272, 0.13115932413887593, 0.1757127761600479, 0.20136968893629892, 0.12816257970107178, 0.24671841683166645, 0.21050263676912556, 0.28030881357769816, 0.25851526688183507, 0.18824192965703626, 0.2767154628471021, 0.16590890384489493, 0.11883039538177753, 0.2596304151079347, 0.1992262362111961, 0.21150536925321628, 0.41217356679901, 0.3252061011810457, 31.349059189519576, 100.19405134262578, 126.9284479079708, 112.05895439271005, 92.54577467518469, 67.12895716390302, 66.60462256400817, 90.87440567631876, 130.5889920265444, 143.07050735719744, 122.96761497374504, 105.55961055140342, 75.09723647948235, 76.21072676873978, 79.39457739553144, 51.87451047282065, 21.546530531298732, 2.4199386373642953, 1.3297301891349977, 0.27643155066236375, 0.2459783758968115, 0.24885676741119356, 0.12438843988122479, 0.20374662993896395, 0.3169406559919158, 0.6774129406098397, 0.20876697264611724, 0.21386564018264895, 0.28092039688940973, 0.1408546571169169, 0.15953796344899362, 0.22925861420169955, 0.24413455548065327, 0.2389457500389507, 0.2821487116236841, 0.26758930255328456, 0.18914867132421465, 0.19704634834441448, 0.23312567282588254, 0.40076388226401427, 0.2472106896100506, 0.18065908413019874, 0.2251995739436919, 0.17068258156218838, 0.1897662607652526, 0.1863306475382659, 0.4145251502913814, 2.922028005123139, 0.616610012948513, 0.11257689626466845, 0.07729564387831958, 0.1861640080929764, 0.13323422731651416, 0.20369185465237788, 0.13356479425584117, 0.08639621683546612, 0.2159516822787062, 0.22285471670329574, 0.17430138173362902, 0.30132781473859666, 0.18327985559740376, 0.1520925694175305, 0.17884615237914747, 0.1063369875473361, 0.16365516510221267, 0.24574931560745164, 0.17615523790159535, 1.1136544159343167, 2.8805325156258, 0.9709650242040235, 0.2716931129895872, 0.14172943759589426, 0.2991170075631911, 0.4666217951284301, 1.1840355876953372, 1.0735295496640669, 2.181172197864902, 8.829027760413386, 28.14574968430304, 54.69841695600941, 74.83665773945471, 90.80356767100673, 85.36939836317494, 97.80283328025573, 96.26742147630262, 51.55069528087493, 26.75411628138635, 60.24441695982411, 81.26432418823242, 87.8954282883675, 110.2072661922824, 50.18908762162732, 1.6757893874760599, 1.0755780074865589, 0.24021417713694035, 0.17415250020642437, 0.2179835619585168, 0.15968002679367221, 0.2624559618772999, 0.14833251795461103, 0.14812699188628506, 0.22464333282363033, 0.16088684510079124, 0.11726580635314027, 0.19712972935409317, 0.20413724284979606, 0.1411954589909123, 0.22773172435981615, 0.20861629847316973, 0.21025411784648898, 0.14886038317795725, 0.1586164822501521, 0.11032961564318788, 0.10612889508446378, 0.1528418034074768, 0.07048504562267373, 0.10160746713799816, 0.23653143926733927, 0.11777754542568039, 0.2740503655325982, 0.08585460799475832, 0.15190418839694994, 0.14138584716185448, 0.10871130852930008, 0.132329921808935, 0.1905136867876976, 0.12140217552622481, 0.14516538790156766, 0.0893337273549649, 0.08859271348844613, 0.27086598317950006, 0.08220497278436538], [0.0269564698570438, 0.0891945215182439, 0.07497602923502845, 0.019572826342717297, 0.04458710243324599, 0.04823459642789057, 0.05747646664179141, 0.051495970617378914, 0.03411020655485411, 0.03443467543430386, 0.018482798139654824, 0.048668864859087814, 0.029529789838218884, 0.03311095594037925, 0.034659533731399045, 0.04162480896939674, 0.01648337952041578, 0.029095475441746177, 0.044225390189357346, 0.04889412918278287, 0.08517288933357886, 0.040020030968251734, 0.01670218763812896, 0.034529321766909093, 0.07022483619831263, 0.03498144770762132, 0.07525215796645611, 0.029395109665910565, 0.03489050541012999, 0.0727540908020831, 0.040414753940797625, 0.06629828318593002, 0.13464997312234295, 0.05400033119404989, 0.013758781114442935, 0.009125233327429141, 0.060429283598017317, 0.054851723008699, 0.07531085562321448, 0.09212352080090393, 0.049948564940883275, 0.08893235856967588, 0.08969838520692242, 0.043925118196995995, 0.1577442758266003, 2.9603757925571936, 52.67275202658869, 110.0321166746078, 99.68703792941187, 86.2583408048076, 48.519338561642556, 35.09533259176439, 43.20734323993806, 76.93299201227005, 102.10129599417411, 107.31149012042631, 115.25657253880655, 101.78330944430445, 77.27885092458418, 59.5585120877912, 47.94624497813564, 32.5838723105769, 7.046636564116325, 0.8283581248214169, 0.583282491612819, 0.1076718191466024, 0.21018611988232982, 0.22417307741219, 0.01759079791935942, 0.3007609096746291, 0.21186579829983174, 0.05146775559912767, 0.2165735924556371, 0.04909933732462026, 0.013264307748496294, 0.07069501500096052, 0.030236473389630838, 0.04331996619340874, 0.10311088404588162, 0.05703215096746722, 0.0704272672714245, 0.0559473934493238, 0.05421713790706089, 0.041440687397675174, 0.13286244484686083, 0.06835352088655196, 0.042546251863842054, 0.009452904454402385, 0.027020955308070107, 0.0903258418604251, 0.1381063013668022, 0.3893430741323579, 0.3949632177189473, 0.057376319797889846, 0.05181951636087991, 0.017323843090825023, 0.0359369432103009, 0.09417341120781438, 0.008401727442809892, 0.06625568869734003, 0.05915987590748457, 0.012799488688488642, 0.02412138337780151, 0.030905928898362384, 0.0400525092658016, 0.033626230508689924, 0.043662786709084626, 0.05587039395205437, 0.08903346685392242, 0.04095815159680863, 0.04249332284915351, 0.1461365728849365, 0.1225119841194922, 0.4663917848900442, 3.5455090913080403, 1.3631867809641747, 1.4885768654846376, 0.20650037894806555, 0.9248285127743598, 1.6406534083427924, 6.521991606681578, 8.383945630442712, 13.998318429916138, 22.441609521065992, 35.94945615337741, 39.39252445774694, 51.04153240880659, 49.329249166673236, 25.541113499672186, 22.235518386287076, 52.25179541495539, 69.42494007848924, 65.52127176715483, 49.05379679895217, 8.455488681793213, 0.47780223551296425, 0.005074273381802824, 0.0632231871056701, 0.03059477654225644, 0.09513829128756639, 0.05550032368891182, 0.017746365478923245, 0.04170758093917563, 0.06430940402130927, 0.08823772366609305, 0.10499465594729109, 0.04973572656332005, 0.04560935866808699, 0.014988892324899715, 0.026114975898376396, 0.008889523394886524, 0.03942409117195395, 0.011050696691287862, 0.06901738969909568, 0.031023601918751677, 0.027227304920914675, 0.0661042560973475, 0.08697816786626655, 0.02121260690112268, 0.017137645420828657, 0.1063143649709321, 0.07539026063656615, 0.05769816482619894, 0.05434780952430541, 0.03981016884227434, 0.028939607192672072, 0.05406033886115878, 0.10817592798341667, 0.04791822892824008, 0.024500866946313652, 0.09610994358456905, 0.002245609831598197, 0.0026909003528060335, 0.028991371753715703, 0.04082434284951418, 0.03780420208650251, 0.07682905802803655, 0.07989631319839148, 0.0633245405380524, 0.007060400854360553, 0.040491075450254065, 0.0591619405144405, 0.03234808175494114, 0.027739796674840396, 0.03317414670281353, 0.03192991649191226, 0.02841706244995998, 0.05187029266850122, 0.08873956488265146, 0.02697096998623062, 0.05621255563211538, 0.060104412522407315, 0.057416719444576776, 0.04072654406510053, 0.020775005987454808, 0.03585395673590322, 0.05114713631149742, 0.05667837922491374, 0.09156328070187762, 0.12217592432974808, 0.01250631833118537, 0.018288952996954322, 0.04774537267944506, 0.00701012154628012, 0.036466290813780604, 0.05168518284335733, 0.06372814630008032, 0.05219542038356585, 0.10151264843560996, 0.04778622431800731, 0.020747961168507897, 0.07181220868181798, 0.028697559797775843, 0.044964423718591856, 0.05009206470041987, 0.051263822993684205, 0.017988064303813923, 0.060368111477263516, 0.070221503715842, 0.06025686018889951, 1.6409012531080556, 22.20828733136577, 88.61988221445392, 120.576169413905, 92.3401326517905, 66.06009560246622, 57.70831046565887, 67.16865155004686, 86.33232455099784, 110.82484337591357, 113.34321683452977, 109.09008103032266, 89.43519392321187, 78.3853986186366, 82.55282278983825, 74.7675455770185, 61.56938183692194, 34.14137294215541, 7.746505073962673, 0.9004531271996037, 1.4262203727999043, 0.5424652657201213, 0.3240757231270114, 0.3200669995238704, 0.14686011228590243, 1.044309117620991, 0.10996090518611093, 0.11640902127950423, 0.08157606822468581, 0.1292466017748079, 0.03842964009832471, 0.0051453227699253595, 0.03775444850626011, 0.04957750259387878, 0.012489038260443317, 0.013441869692366212, 0.06133270427404393, 0.016294791656095656, 0.06183168798264477, 0.06597727702389802, 0.1237046757652875, 0.015991339441238633, 0.043845257361329375, 0.10666314948109851, 0.009301803187437115, 0.09780072261609378, 0.23784359466404686, 3.8015719575266687, 0.5619249408764224, 0.09277888603748814, 0.07076653696957134, 0.03917340422049165, 0.05769167606148028, 0.06025666483647882, 0.0647108800589077, 0.07877903524786234, 0.056901575111213236, 0.012692898087533972, 0.011366294272574446, 0.09346416700751552, 0.0293952590530558, 0.09922032950506096, 0.033226462847162644, 0.03262785323444874, 0.06602051502634441, 0.03821368374290966, 0.024174712673430482, 0.0927600326136716, 0.3896537687509291, 2.7353234300690317, 0.7309390135830449, 1.2282066239464668, 2.172656732220804, 1.6062781238748183, 0.4016607260752109, 3.041790714187007, 16.842577111336492, 22.907812633822044, 30.189159416383315, 40.75162964482462, 50.75029250114195, 49.998397673330004, 65.3187244938266, 76.58251254789292, 57.91466636042441, 36.73485978957146, 35.55839192482733, 67.31224167731501, 86.28747617044758, 79.28267217451527, 27.538719754065237, 1.6276827430532825, 0.5141511463349866, 0.1003197499460751, 0.0011830821500963442, 0.1510564814652166, 0.0384220673191932, 0.05138177755138567, 0.05280974245960674, 0.010412393190387276, 0.13274207711219788, 0.060666008597059604, 0.06268097688594172, 0.07212711678397271, 0.032652329743629506, 0.048836867940882524, 0.016560449880818208, 0.07743674195221356, 0.009452565460495893, 0.043881290306847905, 0.05868698515358472, 0.01892087402783575, 0.01846444267298906, 0.04705425794987429, 0.05178018923728697, 0.06648340833283241, 0.014166608020933646, 0.14972906559705734, 0.03855003847650463, 0.020776327489124193, 0.03108965785002276, 0.0532177379054408, 0.029386286248242664, 0.05629714323027481, 0.021528968655113733, 0.06739024193056169, 0.052373704365304405, 0.03325763879524123, 0.03137828722115486, 0.0394075091988329, 0.005136697098702914, 0.013412909653608598, 0.23008908415513657, 0.32731281232930004, 0.2208204927944368, 0.1135720674609465, 0.06725038491910504, 0.23203981980200739, 0.15075076641815324, 0.10411330243392337, 0.15842551185238749, 0.12414064874211628, 0.09991180046551651, 0.15069553147881262, 0.22953555498632694, 0.10810331816995337, 0.23177711293101314, 0.24572644022203263, 0.19063644471668428, 0.1494324976398099, 0.07992764619449455, 0.12128765304242412, 0.1984081155950985, 0.08828746575501659, 0.1561456954767627, 0.272403491000014, 0.14791614916776458, 0.15643031246239142, 0.189322910361713, 0.13358368598405393, 0.13430831322987236, 0.2180336334652478, 0.27976902802625014, 0.14062414126050088, 0.2245796862388811, 0.17964155082741093, 0.0847605808127311, 0.23308100989989697, 0.11516769837227561, 0.21283738164892121, 0.24613026048867936, 0.17400878211182935, 0.13281053472911158, 0.2292684660924058, 0.21107533345780066, 0.3448616190543098, 0.33758776743085156, 9.354434147957834, 83.08591996469806, 148.98655553017895, 125.6094724901261, 105.02379125164401, 71.43955569113456, 62.57738782513527, 64.03867859994212, 98.28037400399485, 123.34536275556012, 127.41180942904566, 130.86691548747402, 122.72336113837459, 106.67164171895674, 83.80813813978627, 74.21865693984493, 51.34118972286102, 15.738667211224957, 5.120722411140319, 2.014543539093387, 0.5734401616838671, 0.6629458298125576, 0.30764476125759466, 0.4966985602532664, 0.7387483913090922, 0.6058806144902783, 0.24793280408747737, 0.28049481972571344, 0.16308623756612503, 0.13414550422420427, 0.11960255838329754, 0.1321812854298661, 0.17533408357731758, 0.22559781709024984, 0.2519403172716979, 0.1887460308329713, 0.24973324860536286, 0.09670921586333744, 0.16605435329819881, 0.28399090793344284, 0.12629935427779151, 0.13766301225029653, 0.09154669489831695, 0.12286269151034857, 0.1636024429312637, 0.6995146997993993, 5.609623299491021, 0.40489839750432205, 0.33252524392258737, 0.20444092010298084, 0.1101765436150374, 0.18475368618965152, 0.169005002225599, 0.14255376352417853, 0.13368002920141145, 0.2032744593077129, 0.19085078079613949, 0.0710169481293809, 0.20301507725831003, 0.14483437663124454, 0.1510162465274334, 0.15521410191732068, 0.2003732536949458, 0.14455452471250488, 0.18874984595083422, 0.170511023832425, 0.20091621085040032, 1.260667424048147, 4.683299199227364, 6.699810787554711, 4.094244510896744, 2.6267443789589793, 2.6541590498339747, 2.0701264662127343, 3.3709354266043636, 18.054675786725937, 34.056990992638376, 52.71960866066718, 55.43009196558307, 59.47238860591766, 52.650512187711655, 78.67319860766011, 74.5885129128733, 45.593473988194624, 40.16139530366467, 69.60138397832071, 91.58619819148895, 100.37626112661054, 82.94820554794805, 14.717474214492308, 0.5076747615971874, 0.4594433367733033, 0.1925621599319481, 0.27047267363917443, 0.26138080344084774, 0.19970254371723822, 0.11981686381923577, 0.1495884884629519, 0.19080377364110565, 0.23806209826181013, 0.1824417707299994, 0.11271243254023214, 0.16250250921134027, 0.1501402096642602, 0.16151427111077696, 0.07923781466219695, 0.19852399405452514, 0.06429902352993527, 0.15078160911798477, 0.18445520301259336, 0.10239590950790914, 0.19242869209377997, 0.16738818898316354, 0.09412524726001487, 0.16702190702480657, 0.1984451636071167, 0.2555886577934988, 0.1689726426716774, 0.15552145639254203, 0.11300114043537648, 0.15751869357641668, 0.1971800613307184, 0.25306677295555996, 0.17685102959794385, 0.18609388040438776, 0.21485082925327365, 0.1165179206779407, 0.12394752563728441, 0.17498476280560418, 0.12494125658826483, 0.18900536691709874], [0.022830111537909797, 0.017525010118861834, 0.030920139829357787, 0.017906723003233635, 0.023918211114622896, 0.04072484718034825, 0.11525495578685116, 0.022735459459645134, 0.031128948584439296, 0.041343911340640443, 0.13794398265740565, 0.08316963069861935, 0.08229164797211848, 0.020107530816007527, 0.04848677725080521, 0.05686552684393622, 0.010924601491781013, 0.039749529152627916, 0.020662663023798697, 0.06049756501470843, 0.00908122540661885, 0.046671279105207616, 0.022973904326077432, 0.00619861466299382, 0.022580887814382875, 0.03753173142491329, 0.045761718234467896, 0.02811564707137164, 0.11069399770349266, 0.034952926254200364, 0.018991367523408225, 0.03892523386786061, 0.06516985099522338, 0.027023098439038284, 0.050166022828629905, 0.05583210870803845, 0.08699456214784615, 0.05995062803248725, 0.06332089012909321, 0.045086044007011, 0.1288942166513974, 0.10653253149000869, 0.18460693438687634, 0.07951144594699144, 0.04351639113719425, 0.22525572818854164, 0.09674160606077603, 14.931414992578569, 72.5003920831988, 101.86099590793734, 96.59741832363991, 75.7323545025241, 58.553867570815555, 38.6406139404543, 35.202699630491196, 60.37594972118255, 68.1545392928585, 97.82891704190163, 107.62222028547718, 104.6208304743613, 96.21105701692643, 67.92241342606084, 26.755991174328713, 11.51229569988866, 2.4662400109152642, 0.3502427125650068, 1.179168048885561, 1.376271685284953, 0.2791393650395255, 0.6373418843553913, 1.1685254328673886, 0.1417851934750234, 0.33848448866798037, 0.17712616241506993, 0.15429890263945828, 0.05287689389660955, 0.13806989686864038, 0.024469599067684145, 0.0158910192699442, 0.029638363649287534, 0.08782467203995875, 0.11852381465535973, 0.10014704308442532, 0.05308578309092311, 0.06978152409916924, 0.12405409612843107, 0.09483213957038619, 0.12425881780443654, 0.16804900110488938, 0.07294630992316431, 0.2124863601620159, 2.282841258472012, 0.5728560962503957, 0.11747921546620708, 0.041260040034690214, 0.08962503228817256, 0.0845985378949873, 0.08863807355444278, 0.051520596513704914, 0.049426705846863414, 0.01931048527870688, 0.04479226844024755, 0.036510490256571965, 0.042364754143261144, 0.04444286339886246, 0.0647000169321414, 0.040678058360372825, 0.07495082494231962, 0.12162069444574657, 0.1494352708780958, 0.15604342273887128, 0.12057640169176365, 0.20846326474941548, 1.301874987060024, 0.24298545423774953, 1.4291973291866242, 1.3493031840170584, 0.36638121270845014, 6.968281826665325, 15.243763135325525, 13.527337870290204, 33.23288925232426, 45.28318705097322, 37.57482751723259, 42.600109346451305, 57.71605714674919, 27.126727719460767, 14.602870402797578, 41.56150494852374, 73.64196654289, 72.8712364935106, 61.58504778339017, 10.918589080533675, 0.10380260015447294, 0.4061635457459958, 0.030457999204255404, 0.010220560943707824, 0.13377788927285902, 0.047819974321511485, 0.10623390275624492, 0.030669000886020162, 0.06481410274582525, 0.10546176273736263, 0.045791197297794205, 0.02399964626097391, 0.025702688444946564, 0.042280856024233565, 0.03549431292941013, 0.0323942500436979, 0.07718998503180281, 0.03553962703013132, 0.06960363082227207, 0.05974894772554117, 0.07154632254593796, 0.029158819421765306, 0.10516687251266935, 0.030821977153180108, 0.03636389550182127, 0.04036568217880784, 0.004690559571533795, 0.02394780892157747, 0.07311792127908238, 0.09476917480388958, 0.03013033765338121, 0.11179093601963214, 0.031762367317212686, 0.04728909071174361, 0.04325816205011741, 0.07715339667253918, 0.06488386271221024, 0.050928494817907774, 0.06858241263656847, 0.10945407673716546, 0.013945303414197219, 0.033505058381706476, 0.024872116984859593, 0.08366384167945193, 0.021140776582122333, 0.044951607067618644, 0.05586172183675151, 0.03768932720225665, 0.11919480808559926, 0.025865566398527835, 0.04575491154326066, 0.036094201908957575, 0.0309399183043429, 0.028705590314442114, 0.03138713936711992, 0.05522043729621557, 0.024470549016710252, 0.02994858712378529, 0.07889744945831838, 0.0023379873469351765, 0.0051785652401796995, 0.04321843656080385, 0.05817047718371596, 0.01507864814371832, 0.06487906700180424, 0.05173607023372766, 0.06932773957810096, 0.027406272636125648, 0.06969199906433783, 0.060030086671993624, 0.023965513213507594, 0.10848285344940041, 0.04004357285016487, 0.11000272592589741, 0.06923050003787203, 0.021615050124725508, 0.04725004704068265, 0.01050708644587787, 0.05092633061952168, 0.02020838246079943, 0.046965181076478575, 0.043523285928512775, 0.038419979729599534, 0.03395931787728783, 0.04877364653493128, 0.1744239558015139, 0.12888419622134778, 0.1466174156314904, 0.6659219894678362, 4.493571702511081, 53.46418042336741, 109.1751023261778, 110.5865829221664, 75.68145782716813, 61.65739590121854, 62.47877943900324, 70.08444739926246, 79.74361342768516, 87.28774332231092, 103.1230498898414, 112.10315950455205, 102.24165408842026, 87.61058576645391, 87.73454835337978, 85.83106917719688, 46.02569564696282, 19.79707302585725, 5.30042972295515, 0.5228656109782958, 1.2099413717946699, 1.8539945540889617, 0.5733596918083007, 0.10598320814390337, 2.4874070815501677, 0.9704955655240244, 0.3531358282892935, 0.3381286561489106, 0.04204861263954832, 0.1047236217005599, 0.08351536617884714, 0.04373765265148494, 0.10940103280928828, 0.05675861161322363, 0.06416776202498906, 0.13424956960783851, 0.10480947717423401, 0.05380828061231202, 0.053820047722828966, 0.11405749141328758, 0.030505090628960924, 0.10550610390641998, 0.09642338845878841, 0.09828857506715483, 0.03332955529913306, 3.569075917043994, 0.34073942250782446, 0.06024205170932317, 0.08854284116457548, 0.055316236591146845, 0.04665628293408983, 0.05150754620591479, 0.02739150246094552, 0.05230348857660448, 0.06490244034437403, 0.03767923016341464, 0.014465200365521015, 0.03234230928243168, 0.05890811643292827, 0.10822896425041462, 0.07605739298366732, 0.04780634561733854, 0.18660152090653298, 0.0802698500093914, 0.10019163706249769, 0.24926958155007134, 0.21692369463703326, 1.6023502378694474, 0.14422313039821966, 0.8296409850159, 0.9046207680817574, 1.3679645955562594, 15.114505348667024, 32.40610657199737, 39.94086004072621, 58.45942474180653, 61.29818524083784, 50.13693186544603, 55.85313135577787, 68.25536774050805, 63.61721208018642, 39.34049421741117, 32.75962587325804, 53.142887315442486, 81.90483939263129, 89.86448949383151, 40.733163126053356, 1.5947159571993736, 0.40374975591417284, 0.053272907727307854, 0.10003170088654566, 0.33046771561907184, 0.13348081569758155, 0.1009206846356392, 0.08376217672541257, 0.03890929540859596, 0.03782552997431448, 0.07712763313564562, 0.06033721898171691, 0.0464475431269215, 0.0236342721168072, 0.04651712306264428, 0.040582350995992465, 0.09547694811537381, 0.038962013749105316, 0.05716559199255802, 0.03571193169562086, 0.03903703673953011, 0.04110741616797544, 0.05436348368323619, 0.048273303020264835, 0.07567539856198334, 0.025374297195324497, 0.03020383421361687, 0.030184727980785316, 0.020671783300537257, 0.09073127857259206, 0.0254590954676631, 0.03243682154965016, 0.04718885576773075, 0.04383753902549225, 0.01566556246665817, 0.037469762572718245, 0.02103124324592852, 0.004907948511367243, 0.04517330908246579, 0.022510608823429194, 0.01800190751260567, 0.05787840616258402, 0.07097140420228243, 0.1136805608327831, 0.1647810845245277, 0.07159614890453316, 0.11753936102914235, 0.07566568456710347, 0.19019231290346195, 0.15421693123156024, 0.11127620920418732, 0.12539318717655637, 0.19033304325515227, 0.30640679381547437, 0.15307153785421004, 0.18691832890673993, 0.10696767709187924, 0.13294890552999514, 0.20715877023195067, 0.20602773334230148, 0.14449167485919692, 0.10468655070590396, 0.24341311516059985, 0.09171322709129703, 0.1569710786063825, 0.09909972428314148, 0.14344513746759585, 0.09242902900422774, 0.16017625258574564, 0.1856472971098077, 0.09592358503610858, 0.2436907454243591, 0.1047520435625507, 0.35933804548075127, 0.13964091337496234, 0.20152485238448267, 0.10855897960643615, 0.13984748132286534, 0.1293527662393547, 0.09167421023331343, 0.17783931366378264, 0.0946416594688931, 0.17301743369429343, 0.1582325343042612, 0.15118892274556622, 0.36424857714483816, 0.21656075282202614, 0.2128495318034003, 0.4990289997189276, 0.6508323249797667, 28.825282665991015, 111.49155216832315, 134.02511381333875, 115.82339425240795, 93.97014417955953, 82.00774669647217, 57.39645850273871, 56.26033613758703, 76.5509610022268, 94.52151959942233, 121.85577992470034, 119.4565131587367, 121.57718181610109, 112.87337180106871, 106.73476834451, 55.37803819102626, 26.237200844672422, 9.034252051384218, 1.2030024538117072, 3.013632263868086, 5.996688671650426, 2.0253413338815016, 1.2199269908089792, 2.7971610667244082, 0.42047958400460983, 0.5110177241506115, 0.4825147794139001, 0.2648316618175276, 0.20157409651625544, 0.22297028872755267, 0.13205249072803607, 0.3469665835220968, 0.3534095668263974, 0.5474555011718505, 0.42278042183287684, 0.32123329177979504, 0.2768089868608983, 0.16895934338531188, 0.20095027111951383, 0.1402292229355343, 0.23109362460672858, 0.27960269501613033, 0.27873113210643496, 0.2836171489569449, 6.953253755646368, 1.2792043003343767, 0.2223304827367106, 0.24861195635411049, 0.14575110808495553, 0.21301356654974724, 0.24465333490121752, 0.12993597365435094, 0.14464230306686895, 0.15628872409222588, 0.16422383216840608, 0.15492254417509804, 0.15856068040574753, 0.15132623634511425, 0.3160757120818861, 0.18369107627339903, 0.1286853044744461, 0.304535424877559, 0.20205714559603125, 0.24256228259013546, 0.3078278256279807, 0.26711821976688604, 1.6909884493197165, 0.29816178785216424, 2.1973399625670527, 2.8056137744457494, 1.1815413279879479, 15.993298657478826, 47.073545071386526, 67.71545348628875, 88.17880384383663, 78.6745479029994, 61.922136275999016, 70.92450926380774, 92.13798938259002, 50.721290496087846, 35.718899234648674, 58.53735047001993, 90.47786189663796, 104.27417924327236, 106.18032563117244, 29.84695811425486, 0.3232450080254386, 0.5855150556852741, 0.17011028323923388, 0.19843425451507493, 0.5312743758963001, 0.19392958091151333, 0.2261958253239432, 0.183970085495422, 0.12218007652629768, 0.1812984764335617, 0.13561332868712564, 0.16638416947136003, 0.050065642327911435, 0.1212810263818791, 0.19318797715729286, 0.0665888220312134, 0.2043793266338687, 0.20665793259057308, 0.080274002205941, 0.13935235869740287, 0.14385355426178825, 0.14885206346309957, 0.1717623978132202, 0.20921519536885524, 0.2934816647921839, 0.14267201685617048, 0.19289807416498664, 0.1634859516014976, 0.20423315705791598, 0.1955208221390363, 0.07661519692309442, 0.17100341918487705, 0.16740432279484888, 0.1450256687859374, 0.10208408107921, 0.08124802937550892, 0.18685523390529618, 0.1661796699608526, 0.12514865957200527, 0.18214520277275195, 0.14101763466192832, 0.14289658787029405, 0.1107167351930853], [0.021700394234710166, 0.04529705526487482, 0.043322387031249465, 0.0671730253605112, 0.007366472611113662, 0.05469955113385955, 0.08869731513362739, 0.073913135866244, 0.027329868772217346, 0.05660326047349842, 0.02722647946117626, 0.08240162755452818, 0.02626693135337724, 0.027546960852980137, 0.05488256187809091, 0.021576268838778622, 0.04274684432593565, 0.049294157314204404, 0.0025852515611932765, 0.015405174926854672, 0.028218389038116704, 0.056988292433802164, 0.047703586413615176, 0.029053679599817243, 0.04891139297415653, 0.07035288779485611, 0.0016193798763842714, 0.09664468061659606, 0.043460436075204806, 0.04501298986255162, 0.04301060839826542, 0.06270748735856145, 0.045382680912171645, 0.040073320044264685, 0.05417308402097514, 0.06264089133530375, 0.043157214644334974, 0.0223576057431919, 0.04738093699298559, 0.02391764803999855, 0.02772728071337746, 0.11861921558457038, 0.025741098178250175, 0.07836184674693693, 0.13907204712590865, 0.04130570653585657, 0.02837890552567138, 0.6126581637128707, 0.9937937089031743, 32.54839447236831, 111.16605820194368, 106.71311686115881, 96.08503126328992, 84.88536219443046, 52.95880656088553, 28.522018732563144, 43.76792054022513, 68.39540420040008, 81.37189911257836, 87.90530481646138, 82.061781267966, 90.78109248991936, 73.18845425882648, 37.07963612771804, 27.838577108998454, 15.475570309546688, 4.754764293470691, 0.6922192138529594, 0.31485012462062223, 0.22586335848656394, 0.8946727793062887, 4.719690459389841, 1.912111700061829, 0.32141016615975293, 0.3744033177293116, 0.03402895910004455, 0.24448306419916693, 0.28843700645431397, 0.10212183389211855, 0.24737100116908553, 0.10539584853235753, 0.23425085680379024, 0.06233907567577497, 0.1148905047786332, 0.16155256018523248, 0.13407758286883756, 0.06285911148053504, 0.07008787499920976, 0.06368249512067245, 0.09448035965643584, 0.17091677464064092, 1.077772328449834, 0.27312658606998386, 0.030222275865174113, 0.06368557479412806, 0.007670869986947266, 0.03042027511964402, 0.0981483426726153, 0.02243106399903134, 0.03888761512033882, 0.06183712337646754, 0.05821268862834381, 0.009892653287087959, 0.051374859777429414, 0.12005546956413216, 0.1160701652688365, 0.10226058773696424, 0.03691872318966254, 0.194087486954466, 0.1594399195164442, 0.18896182247948265, 0.3368162249605502, 0.08117134397428843, 2.0258321204493126, 0.08550133420935563, 1.1810852298813483, 8.500451791671015, 22.57896896331541, 25.43580178291567, 41.64839721495106, 47.286643520478286, 41.555844968365086, 52.62596991754348, 58.857462944522986, 46.4559914219764, 21.228412582028298, 22.788972662341212, 53.46020706238286, 74.2680238908337, 68.75719578035417, 31.7535771477607, 0.40196054224525735, 0.673170835981446, 0.02925843958021893, 0.0856591483217574, 0.05347543073097064, 0.07532465286673078, 0.041158602332636234, 0.014346062201976538, 0.10291746982763852, 0.07103683577189523, 0.06809632218773327, 0.15486756970565166, 0.07372799539758314, 0.07361061540582488, 0.04556309078790007, 0.09351577835097429, 0.019031899320262096, 0.025417548604309562, 0.022202448040667563, 0.025309696831109545, 0.02414749739992042, 0.09104331384503073, 0.0538326881735796, 0.021085750401741075, 0.061614245416656624, 0.008007684373296797, 0.1536819873557937, 0.05539756831562808, 0.07534843223590044, 0.02064313544260879, 0.0719874972597726, 0.13446791998801694, 0.011569782547021826, 0.08063581787169942, 0.03369112964719534, 0.024722771974460735, 0.060644209565174204, 0.01056327324946441, 0.03212786020500766, 0.030641065489861275, 0.02130301676750664, 0.07665618262704342, 0.05272572176651128, 0.03518252663554684, 0.02792065279678472, 0.06617300482767244, 0.07669621072108708, 0.03679536005121566, 0.029060290938603784, 0.022429234964112123, 0.09316220579128112, 0.04814688319100007, 0.11418997099803341, 0.05805523457726645, 0.021730377000846693, 0.0042652754364685425, 0.023498440897392652, 0.0684174049585577, 0.031738367697764794, 0.06008841277610871, 0.020979932591980024, 0.038383981258037596, 0.08413251894976824, 0.01753373586031939, 0.022044522845516765, 0.03190126288832436, 0.044453623103758985, 0.07319000249187793, 0.07351176708095497, 0.04609223154764022, 0.04150339935515677, 0.04372230407992198, 0.06302997207028732, 0.11130658459038505, 0.06146064478783839, 0.036078872489592725, 0.0708788148157539, 0.04917560903836162, 0.07688876692085497, 0.05606851195015254, 0.024310302575148886, 0.0862699272411485, 0.011845670918363237, 0.10288547799592057, 0.04548260942101479, 0.038123522855101094, 0.11637668470822035, 0.10455725804692316, 0.068913247706669, 0.06392713380797256, 0.059428830225501335, 0.017680357428147428, 2.465636456204999, 12.12851672403274, 75.9905013730449, 120.24377207602225, 101.70872165310769, 79.14403207840459, 59.664043457277366, 51.93860984617665, 58.62377205202657, 65.2091883843945, 90.83360518178633, 102.99121902834986, 105.5922289817564, 96.4703570642779, 88.17400286274572, 84.9008555566111, 65.37572045480051, 44.074642042959894, 27.70745227413793, 10.203604736635763, 1.6389063601532292, 0.1442098770771296, 0.7035746593629161, 2.4540181506064633, 7.477901654858743, 5.132202208042145, 0.7097420961626115, 0.15824931162980296, 0.06332383956760168, 0.16499114583336538, 0.07453654757550648, 0.11479754000902177, 0.31318170769560727, 0.16874554356740368, 0.08290637224431961, 0.043827503273684176, 0.11775844685372808, 0.16884004817374293, 0.10826952094512601, 0.1422677369367692, 0.057071351686552654, 0.06854460619750523, 0.020208706132947438, 0.3740836752037848, 1.827298902696179, 0.2327420926021953, 0.11752462149747919, 0.05010370540642931, 0.07838802397130959, 0.07599919328405973, 0.034490013795514265, 0.04588680507074441, 0.11894490254381973, 0.13032053447058126, 0.033019450568263574, 0.02074064885927064, 0.10766726092345293, 0.044045589353528716, 0.15875667634029544, 0.09783419299750559, 0.015657831681892276, 0.14964450481197528, 0.22114926708802102, 0.23403281285878152, 0.5980725237919439, 0.15548450031107472, 1.285233473585498, 0.09488175142436259, 2.2451614997079297, 15.296537645401495, 39.70507852492794, 54.92811487567041, 72.36794148722004, 75.42611152895036, 63.935308456420906, 71.59873331746748, 85.2724922856977, 77.3489829032652, 62.67507837664697, 31.13138529562181, 41.84704172995783, 79.20315004164173, 95.69186072195731, 66.57284352087206, 11.957375868674248, 1.377832666039467, 0.17156992588312397, 0.07329902446438229, 0.04640839220355115, 0.12780208936742238, 0.04092728974477899, 0.028793385905784466, 0.024454087702437274, 0.09416768853102, 0.036190338282575535, 0.06945104142951389, 0.06567557627755789, 0.02935475406927928, 0.04096864317093165, 0.0447770654253902, 0.08268101982051328, 0.005785348053435765, 0.081752605525957, 0.02463376404897821, 0.067408015170405, 0.1001936442128593, 0.03094465081249514, 0.035771747840748686, 0.01871875513555302, 0.0693392921839991, 0.10110453807658727, 0.040846072933486396, 0.042791235290708086, 0.021378011029634266, 0.028453018786686084, 0.07129427961884968, 0.05799302440737525, 0.06541378105119353, 0.0437884021460289, 0.05043995288771488, 0.010082060865487063, 0.020741231086093093, 0.07920858840788565, 0.013017929083998165, 0.01918135349819016, 0.05444762311995991, 0.01820339438235087, 0.0390105645713066, 0.01738490029839018, 0.12117346763731011, 0.1578762114889199, 0.09561552575999692, 0.10849252147900482, 0.1095870619399413, 0.18950090323004032, 0.09916181570940441, 0.1742700793810429, 0.17139384823460735, 0.1376472001955394, 0.11999733115155851, 0.19098922820581546, 0.13237916594070773, 0.14854922890663147, 0.18545136246229374, 0.10091724490085918, 0.15731480693624866, 0.14267760929801773, 0.07310241565949495, 0.1630217482846591, 0.08735169701638722, 0.17966476329151662, 0.21579248920804073, 0.15428105279082252, 0.10248404792359761, 0.214933505462062, 0.12400680552086524, 0.13098798091373137, 0.2160293023071943, 0.2142562377717226, 0.10669590740074074, 0.15561534812854183, 0.17973355798711702, 0.1931201017672016, 0.20236575645544838, 0.09932355985285775, 0.11551158758060587, 0.13767131664339574, 0.10721065719882328, 0.20606669657413038, 0.1633860843796884, 0.2808322661346005, 0.13846548935098035, 0.13469765443475018, 0.25494019500911236, 0.21334626321350375, 0.11472653898019945, 0.8504246439664596, 3.0417664445215657, 58.997840650620006, 146.51474060550814, 130.76328646752143, 112.66103036942022, 102.77327645209529, 76.55334580329158, 52.75648286265712, 64.59157982180196, 92.516827583313, 104.39839286188926, 125.11951354242142, 106.9625246909357, 102.82081557858376, 110.33997566469255, 91.57518417604508, 55.51523485491353, 31.418667531782585, 8.507170811776193, 0.8524932652231186, 0.3006136675755824, 1.0721433595303567, 8.091403495880867, 14.837327138070139, 3.201175980990933, 0.6205700746467037, 0.45336121152485576, 0.17874895114331477, 0.39830164503185983, 0.5460521506686364, 0.36442214202496315, 0.39439625136794587, 1.1423296385234403, 0.4909366597571681, 0.12346547247181017, 0.31774740786321704, 0.3916337996000244, 0.19651762510259307, 0.23829667438422483, 0.19140660822872194, 0.2194060340163208, 0.16321458793695898, 0.6356298923492432, 6.27487640227041, 0.7686125823566992, 0.18280029987856267, 0.20887796346458698, 0.132550846244539, 0.14460746138807268, 0.1817764080460033, 0.13160114236656698, 0.14544412133193788, 0.4152306253390928, 0.0905188653738268, 0.13058114226066297, 0.26869780113620145, 0.1771478120598101, 0.22723914514626228, 0.1679115649312735, 0.1656290212826383, 0.16502600283392016, 0.19894900431315746, 0.3039154145986803, 0.37947101999194394, 0.20335407116480414, 6.964045666879223, 0.1427079004145438, 1.5005483069727499, 13.08341480070545, 46.09773389754757, 79.30906188103461, 99.3404023878036, 88.8251006218695, 64.6088304058198, 88.88086888097948, 100.02515408300586, 72.53740356814477, 46.7707145598627, 40.356850931721354, 72.46725589998307, 104.06164953785559, 114.49058855733564, 61.621627807617195, 3.9632473982149556, 1.2414616610734694, 0.18809189899794518, 0.24146381975902667, 0.15137258466453324, 0.2380917611862383, 0.16935594710371188, 0.12408002054378872, 0.18342257777769722, 0.22194140200172702, 0.2298129401019504, 0.28432841562936384, 0.17457073824780603, 0.18226958480813812, 0.1475522114384559, 0.266514511839036, 0.11540222852941483, 0.16278349494020786, 0.23536994272182066, 0.10977289188773402, 0.18910984598821212, 0.16323982287318478, 0.1273479524459089, 0.1340892580488036, 0.0928996674596302, 0.19837088372197845, 0.2675960747705352, 0.1786838489915094, 0.1757757026221483, 0.10199816431850196, 0.27868887469653164, 0.23186260834336284, 0.20585802954531487, 0.15884310637991275, 0.13916848227381706, 0.10702488853806451, 0.23753178155710622, 0.12421321259030413, 0.12770913991956942, 0.05965218699026493, 0.1261751101382317, 0.1219729723168477, 0.15752479163629396, 0.09331333961698318, 0.0910580916810901], [0.008638737809603975, 0.055496332370826316, 0.03582091153328938, 0.020344690569946845, 0.043757670528946385, 0.05537046795530666, 0.01961883758344958, 0.027700923458342592, 0.034433143258455305, 0.0641190694765218, 0.03278304349570986, 0.010668649601059095, 0.024445300673945777, 0.026973285486981757, 0.05647147419832407, 0.03054201223647162, 0.011937005835915766, 0.02378667956368337, 0.09704244878864098, 0.014779391217856638, 0.019806626801108642, 0.09599062539036236, 0.08446228149677477, 0.10784319301526393, 0.02797520400265292, 0.10261228338124291, 0.05092813092614374, 0.028834846584246527, 0.056239219322319955, 0.04119005024192795, 0.055365825462485516, 0.059525644586932276, 0.04095684158645811, 0.09009537196928456, 0.08399560371594084, 0.05249995948566545, 0.013348346636179956, 0.04567213574304216, 0.061386491307207657, 0.02736137413810338, 0.08101864732922086, 0.027211002569885987, 0.01973076685962658, 0.04149802141792832, 0.08334688812253938, 0.040228272818269274, 0.15908957218691228, 0.12374729323651522, 0.06186665606594855, 0.027221869527091904, 6.456017340383222, 61.52557680683752, 119.622892256706, 109.40875791734265, 95.25450860300373, 78.62757359781574, 53.44292509940363, 31.680952502835183, 40.49448297869775, 62.71782436678487, 97.47706474796419, 82.31657843435966, 68.69474380247055, 89.39498178420529, 79.39411455585112, 55.16859931330527, 23.783175829918157, 13.608277939981031, 4.281732334244636, 0.7683622861100782, 0.14148039773346918, 2.457534065169673, 5.795458334107553, 1.0146108918613004, 0.3845751267527381, 0.7321435489481496, 0.36030279532555615, 0.3119465594570483, 0.08998147767758177, 0.4573520086705685, 0.324767071513399, 0.23436947785798581, 0.0483442772360098, 0.03114884388783286, 0.15311247759288357, 0.4552366254070113, 0.23000156627066676, 0.15108098095703512, 0.13879556599403584, 0.17752389994359788, 0.04971080955358283, 0.9925211449303936, 0.3046692451161723, 0.07128455796309056, 0.07410317929762025, 0.1744725257759133, 0.022556413220421925, 0.0451743318098447, 0.05297975652220269, 0.05974035987990999, 0.0380991114633939, 0.10445798071281565, 0.05206336214717838, 0.05186777606966996, 0.1848679558644372, 0.12313363382652884, 0.09581221883455593, 0.14135593908929056, 0.30681744758640567, 0.6237946919375851, 0.3115065185533416, 0.575498364144756, 2.785934998143104, 0.34403464246180754, 6.901419633819211, 27.39074049457427, 43.11808578429684, 52.5314917872029, 63.74224155179916, 54.381054062997144, 55.450237258788086, 67.28174917159542, 38.094117949085856, 16.158902106746552, 18.279943389277307, 38.846624666644686, 63.18859115723641, 73.19684028625488, 57.92615106028896, 10.019655381479572, 0.43813340606228, 0.2137433572281753, 0.060110070081728126, 0.041728939470504565, 0.06153636874871389, 0.04550144752307285, 0.08285533546680406, 0.02205108630380804, 0.028548923418706948, 0.007658634126381649, 0.05442809936920962, 0.03136899840507296, 0.02769810617000105, 0.12461093479707358, 0.06582428926541921, 0.03707300946717301, 0.044245147596924536, 0.08168679091238207, 0.00338752229694247, 0.06151232124877073, 0.07016477490504903, 0.009190492527258974, 0.051106089320514476, 0.09483332700666883, 0.04292440818502538, 0.04515737445364076, 0.04763889028840969, 0.09503719832507834, 0.061657165492614435, 0.12018315343847198, 0.037350605256975665, 0.02866990976936875, 0.060041516703823884, 0.021340911306681174, 0.021054695112510555, 0.029986759369832375, 0.02710350319713114, 0.07105480053371961, 0.016606924604744683, 0.04245672682901064, 0.08703572405201775, 0.028407243117990515, 0.03209135994585532, 0.08306894376273118, 0.06439319871846708, 0.04957220126544276, 0.09579310494084513, 0.037863512613600304, 0.034391479566693306, 0.08493940105601665, 0.006745410397753961, 0.011570484475082448, 0.019539829020598726, 0.05932432051087099, 0.03861024149603421, 0.03226710243090507, 0.03714568439810988, 0.048878937659244386, 0.020288038367946303, 0.03898983040163594, 0.015571061690758555, 0.017402640979496703, 0.04999312827543867, 0.020028485863980268, 0.07257276545128516, 0.029739286157212434, 0.04681666727147756, 0.05920612463547338, 0.05531575012531492, 0.04862044427183367, 0.11221387784086889, 0.1280914560981816, 0.030644397972331896, 0.026804765295838157, 0.08417839229467415, 0.09041644707922974, 0.06077319961942493, 0.035678920966963616, 0.04956774646416307, 0.08245286351490407, 0.05187747091235173, 0.04516707695720177, 0.020624138377306443, 0.022864731051208034, 0.0291922859727375, 0.02257426498427747, 0.041313267823669224, 0.0841297380506031, 0.030904293300644047, 0.1451376555187087, 0.0454932427214038, 0.035646936796124906, 0.030371944547720978, 0.31819017603993416, 0.2155217537356, 0.7379101072588276, 36.104534902880275, 96.62299217716341, 127.0487940695978, 108.28285724886003, 77.28721341779156, 55.44308677796395, 59.87594558346657, 66.4439622817501, 73.82117963606312, 88.02085784173782, 100.84868707964498, 93.65484053088774, 83.77650030197637, 91.42235294465097, 89.55043315887453, 79.722212976025, 43.33784441794119, 25.579754729424756, 7.4892098480655305, 1.1913326671046596, 0.49064931549852897, 0.7544313755727584, 4.751065988694468, 0.31727221884554435, 0.85947630987052, 0.4090183570740685, 0.16480530822469344, 0.18466884961291669, 0.19624776297038604, 0.2636982500553131, 0.23126070838301416, 0.1798998909972368, 0.08798425581546561, 0.2594747766852379, 0.39731581244737874, 0.48267424827621835, 0.41108256566428375, 0.19458380467709036, 0.3472094333940937, 0.23942643956791973, 0.16086597686573384, 4.530512584793953, 0.9505634899100951, 0.05489871101153474, 0.01834934179280554, 0.11432287959201683, 0.08191513107909311, 0.12962166310077713, 0.07491723198683993, 0.13526575459587958, 0.10136700746032501, 0.04941443694875606, 0.12769947955084424, 0.05900925153025216, 0.08558463094936264, 0.1325766021205533, 0.261863867842382, 0.1462151275406922, 0.5388665523740553, 0.9984099708737867, 0.3322784410369012, 0.5285281651923733, 2.1792688677387853, 0.9443340919190838, 15.78385683798021, 47.706858804149014, 66.07656955718994, 77.3860885250953, 90.67753407262987, 76.48813247680664, 69.71428548136066, 75.41388942349342, 68.976487651948, 48.506073105719786, 36.837629810456306, 32.4037923735957, 56.425405163918775, 86.95005078469553, 82.52443267453103, 32.913267074092744, 2.2294742253518876, 0.38122631128757234, 0.08034351702419021, 0.025840950078300895, 0.07311418277001189, 0.05482688643819383, 0.1357207035705928, 0.029435890441339825, 0.12099437160237182, 0.05714792600502411, 0.06724673067970623, 0.04875811410226649, 0.021961438694908735, 0.10294219148495506, 0.03440639912901867, 0.060515142902131044, 0.05093438986448511, 0.017457412435643135, 0.034136598283845576, 0.0447393738995156, 0.04470951945310639, 0.06309107524312793, 0.033278782821951375, 0.041963373866653254, 0.03632237736676489, 0.09304130179507118, 0.05404475663277892, 0.05899772573743136, 0.040434411756934664, 0.032128474990566896, 0.0390628079373029, 0.028447771084404765, 0.032092137525098464, 0.056505350606335755, 0.08157481950136923, 0.020313851700554934, 0.027693138089812094, 0.011442921259590696, 0.02089281498845066, 0.040019257219448205, 0.029498843716517575, 0.042237675478381496, 0.04794051059551778, 0.05107036281016566, 0.05078798663171549, 0.01013912771257662, 0.17719417570098756, 0.13221565213414932, 0.16512015503981423, 0.23323310899638364, 0.13262998312711716, 0.16324124779672394, 0.08886908736800955, 0.15736855566501617, 0.14620081701826665, 0.2487682689341807, 0.12200069703882742, 0.1757018211027307, 0.11343250922378033, 0.1532306543160831, 0.15056160398788992, 0.10063408348228663, 0.12511635364423837, 0.15414675757769616, 0.24648937186406505, 0.16401332652857228, 0.17483542162564494, 0.18787877333741035, 0.25960035381778596, 0.21894342416236479, 0.17299363900336528, 0.26999362353836337, 0.11855905469987663, 0.12235302853608325, 0.16380947053192124, 0.31869070724614207, 0.1487333964436285, 0.13984610236460163, 0.21856748949616187, 0.17676893561597795, 0.2545526004847019, 0.18973209324382967, 0.1618958135405856, 0.1532225337840857, 0.20457078732790487, 0.10404566453108866, 0.19303950931756728, 0.19025853354363673, 0.154647350070938, 0.21881761720343945, 0.15462186998657643, 0.19320879942707478, 0.299495087275582, 0.34952605263360087, 0.28972798718079446, 0.12392943064051291, 13.80161548814466, 83.42523636356478, 156.10987786323795, 138.73021648776148, 117.59027296496977, 98.33652665538173, 78.78496262335008, 55.25005125230359, 64.94875084969306, 82.54310315655124, 125.89633111030825, 124.24415819106565, 89.59905485953055, 99.98556167848649, 116.03537482600059, 108.30071972262476, 53.46296448861399, 28.310952071220647, 6.360924868814408, 0.5039253740781738, 0.6904274261286182, 3.9466687652372547, 11.773206860788408, 5.181811365389056, 1.8975158252062339, 1.0598429292440414, 0.7947989997844543, 0.9952530757554117, 1.0171555295105905, 2.259741194786564, 1.1975127290333472, 0.3437777272155208, 0.16175640086012502, 0.3516549190446254, 0.4823048100356133, 0.7135517594795073, 0.3275325263459837, 0.30042527123324336, 0.27631136678880264, 0.6138919942801999, 0.21181134477017388, 2.888410350968761, 2.21188876898058, 0.15581966377794743, 0.37514648430289765, 0.3487503732885084, 0.14382876365655853, 0.3054824014825206, 0.12054591905325653, 0.1954415013953563, 0.17381925195936235, 0.16000513918697834, 0.33647810439428977, 0.2115014009177685, 0.28567391117253615, 0.19010317091259266, 0.4524646435053118, 0.21150241215382853, 0.3611211917333065, 0.5635301708694428, 0.274120814978115, 0.8126555287068891, 5.206791960423993, 0.4618715290581027, 12.558821324379215, 55.81340166830248, 89.90191675001576, 109.5077742299726, 106.59513196637555, 84.42566041023501, 88.54627501580023, 100.04864123559769, 64.51585454325523, 35.02927595569242, 38.56350798760691, 55.933649770675174, 88.10654594052224, 110.78758870401691, 90.85437805421891, 19.257851069973363, 0.5144705743558946, 0.3831653104674432, 0.4134780000294409, 0.12539835060916601, 0.2553361398918975, 0.14173829357229895, 0.12294660878157425, 0.09551280869110938, 0.3107555685264449, 0.1236734806650108, 0.13491100992166227, 0.08075619326724161, 0.14798984682608038, 0.320545498041376, 0.18254310884062322, 0.23210507517139758, 0.1758996556482969, 0.18135207194474437, 0.12103526537576992, 0.13381665332182763, 0.13995317081289907, 0.157661538330778, 0.1567479171940396, 0.2232484858963759, 0.13995010646120196, 0.17587613674902147, 0.19233182793663395, 0.11441090309451665, 0.09560250992616338, 0.16909491030439255, 0.12428556959475241, 0.24201673605749685, 0.1720185776150996, 0.14490229798661125, 0.19422190474166026, 0.15644528182043185, 0.1051484480980904, 0.15932753441795228, 0.06777996617940164, 0.13484693432767547, 0.19387544913878366, 0.1645276779609342, 0.12944155582977881, 0.25633320332534854, 0.15114920874757154, 0.20423755440260136], [0.04723306670184097, 0.050529412805072726, 0.0938095654090566, 0.053493881958626935, 0.03656175686046481, 0.006123445158253514, 0.03978454703164678, 0.08258712042363421, 0.05717283535388209, 0.017733437745201013, 0.04410604135163369, 0.037499176518570994, 0.02707979086065485, 0.06393204826200682, 0.02549667016512925, 0.03604675808380689, 0.022735264107224443, 0.032307417807920326, 0.0816131315584625, 0.03165099153956098, 0.015528709477474614, 0.02936270031627388, 0.005527278887213118, 0.07582739806703984, 0.030630803742115537, 0.03264787494234982, 0.0090834537648686, 0.05668575282118494, 0.09975446132762779, 0.015536952583539872, 0.05330277749547555, 0.05377789756523506, 0.04991597173014476, 0.014708065559276411, 0.0806891299303501, 0.033204319075711315, 0.09324010161142196, 0.07335954541040045, 0.013250751822676151, 0.014985335761711243, 0.06860092898169834, 0.04441442621511318, 0.03234116398098488, 0.11149526438525609, 0.08008702312626186, 0.12520481381685505, 0.10052453290911452, 0.24563964246021164, 0.05640596218947923, 0.07063148332939995, 0.22799266922858455, 0.15560635425631078, 8.398628042590234, 52.18496999432964, 108.47736758570518, 104.89840876671576, 84.33651278095861, 72.59401905921199, 48.27442576808315, 33.83572224647769, 39.85539551704161, 81.82836886375182, 95.77724287586828, 88.21996519642492, 90.73261199458953, 84.24779661240117, 58.114475819372366, 48.720175681575654, 41.80761406498571, 25.488847917126073, 12.557289638826925, 2.958213095703433, 0.7626379545657866, 1.9134290035693877, 0.5820587121190564, 0.7130701659667877, 0.3607558597239756, 0.1712340882588779, 0.5627433066406559, 0.7300631605809735, 0.3891845245755488, 0.6581742664979351, 0.137628446363153, 0.09607563816731977, 0.3083072434509954, 1.929345123710171, 0.7328587686342578, 0.2385863935154292, 0.2815870159576016, 1.3568059427122916, 0.2116846185057394, 5.5074823287225545, 0.28866453456782526, 0.6772949630695005, 0.23501319089724174, 0.12273974972026003, 0.07904188001468297, 0.04473259402138572, 0.15493820301227032, 0.0644391639939239, 0.04019824983251672, 0.09382084988418127, 0.17766639229751405, 0.05066868758970692, 0.2284182770357978, 0.4125957425323225, 0.22393559015566306, 0.18289644391305987, 0.58343687365132, 3.4618596444206857, 3.041521786682068, 0.3073544445778093, 6.975977516943409, 19.541456084097586, 52.29816175276234, 70.4291452900056, 79.90064159516366, 65.56266846195345, 53.789568485752234, 58.625376301427046, 65.55529832839966, 25.776614566003126, 12.322945671696818, 30.563337841341575, 55.42433392617011, 65.01638427857431, 86.51971186361006, 27.906141896401685, 0.4684249515975676, 0.7224323732718345, 0.06348282196408798, 0.05325932881884998, 0.08867334424247665, 0.061678654258890506, 0.08500878563931874, 0.019452046835795045, 0.007602556969129271, 0.02211056345502936, 0.006719242749480351, 0.02163802510157468, 0.06578444503247738, 0.06463082387082039, 0.06577249406085861, 0.014682869885056732, 0.11570120200274453, 0.044296739788185206, 0.0970106331571456, 0.0899860971877652, 0.07590373872869438, 0.01725718386531357, 0.032668348642126206, 0.15050350387971248, 0.03870143660254056, 0.02395056109244545, 0.07065147822422367, 0.05287896616444473, 0.09027736381657663, 0.06256724730314267, 0.06324754870166222, 0.028553364813447963, 0.06989456803327607, 0.061045773702883915, 0.03228964456807702, 0.01808897723563977, 0.004840167445851671, 0.015783860806315657, 0.004803486198427216, 0.03745110450132239, 0.04281117655937711, 0.01846064096166482, 0.07504560534031161, 0.009176201157031522, 0.07579450991245047, 0.11317597702145578, 0.01636541155617564, 0.04009406953569382, 0.025770027573490818, 0.059539434169569326, 0.04658582965813337, 0.05387436335666045, 0.056211762731113744, 0.047252766652813846, 0.0306842019856577, 0.024942070388445453, 0.040320168895226334, 0.07149375359257383, 0.04401081662264563, 0.06708442729206816, 0.03716994257223222, 0.01478291713752814, 0.05036637780346698, 0.018008842523540222, 0.03716403603433602, 0.027728623282464764, 0.05276938111731603, 0.01170748302097162, 0.017369542150728164, 0.021762952974606908, 0.029089578479949026, 0.09842722932057035, 0.005443249575628509, 0.1040632309271924, 0.04031782083573841, 0.07451427739954765, 0.06618823465560714, 0.02747172718837617, 0.03078950268606986, 0.04992773117978246, 0.04314285049575471, 0.09073671779685444, 0.1201039246253429, 0.04971621813432825, 0.05801069039490916, 0.017573216201497183, 0.030302152022599217, 0.021246356904626857, 0.01029080163026529, 0.09964371565729381, 0.018594361608847976, 0.08438446228542636, 0.030012672293871164, 0.03012953709150034, 0.06442696021329011, 0.06141480591688907, 0.06015721896302797, 0.03466321478387521, 1.1921948530981619, 3.42355304187344, 40.40315451160554, 92.26566253169891, 120.72607455715057, 108.78925877232706, 72.39338982489802, 47.76300361079555, 55.93665822859734, 66.44948497895273, 82.55005359649658, 103.98416703747165, 95.76021978932043, 84.64499935027092, 94.08280249564879, 95.9055357594644, 73.85954041634837, 65.00336985434255, 63.180738572151434, 41.63246062494094, 19.59364910279551, 6.581282154206307, 1.2699927365587604, 2.4783272848975275, 1.3035969075656708, 1.5596944622455107, 0.9220606677474515, 1.294860686025312, 1.0385847860766997, 0.9884604499224694, 0.8180042320201475, 0.9055846905516041, 1.3529404469074742, 0.12553888177799602, 1.9398989961031947, 4.20691067172635, 1.6434381685910688, 0.7078746802383854, 0.7494604455367212, 3.5344784057909444, 4.965266623804647, 4.928729255353251, 0.1375103922140214, 0.5238520257895993, 0.5830859440949656, 0.29906215566781263, 0.7033290822179087, 0.294177916141287, 0.27804012079873397, 0.024791026578074502, 0.020967782437500936, 0.06769519855058001, 0.2361560868279588, 0.3571102617969436, 0.668804441248217, 0.7598945630654212, 0.23473583642513524, 0.171507076029816, 0.46335066097878647, 2.1136218742016823, 3.0049804958605, 2.1690376102924347, 16.34678363800049, 44.002490043640144, 89.18991242685627, 98.45062055895406, 89.32953311551003, 79.40988248394382, 67.47274506476619, 70.3827436508671, 84.33153921558012, 68.34944971146123, 38.3811491535556, 30.33291820556887, 47.077522354741255, 77.39260750432169, 102.31140951956473, 58.11868844493743, 6.1588649499800905, 2.0300941433637374, 0.13933115338365878, 0.044821268698621186, 0.07238017094712104, 0.08629883939941084, 0.05724313541225368, 0.03390605178391261, 0.024980047282071847, 0.06531320136761473, 0.11337333659250891, 0.06130140958233707, 0.070136598191194, 0.03288355040093584, 0.07214043905297596, 0.03947716191290848, 0.05590811229100632, 0.04775486450882689, 0.06029498455445133, 0.09888815378109295, 0.012483774278793606, 0.0314229118427442, 0.03464730313768791, 0.1224051531584513, 0.1064733128934618, 0.029670355481005488, 0.04640220221312297, 0.048396367384421254, 0.05606369325710882, 0.13804671504805166, 0.03825492225587368, 0.024506671977559888, 0.08691495029075492, 0.026293089425551797, 0.06541568861012498, 0.026594686750022155, 0.08145199262446935, 0.016888948382749673, 0.025007574736411055, 0.05095160002970407, 0.005125187106445553, 0.03946986109499009, 0.017687125814958446, 0.014053540146579186, 0.024157891297833096, 0.06618730002833952, 0.020526962039331277, 0.010819654149423924, 0.13116090227999996, 0.1726706869780056, 0.2047150416840469, 0.16173965417810027, 0.19593823280545974, 0.121759440629713, 0.11225812707937534, 0.14271376864804378, 0.11499139855826095, 0.21537285688663685, 0.07900135396348854, 0.15600459740286873, 0.1103151212596605, 0.14273570940619515, 0.12461204562456378, 0.12545915500771615, 0.19866421878818544, 0.16533363310079421, 0.10759378543063518, 0.11478272386856618, 0.09783772466283652, 0.22063581963940976, 0.18355048381753508, 0.15598800393842882, 0.1314253098661861, 0.2085555477007743, 0.09945925700688556, 0.15423888731147015, 0.20001924446513578, 0.13145373172817693, 0.12171879200445068, 0.13830234326662558, 0.19082743043620742, 0.19600010206622465, 0.24626097041032008, 0.08037230660838467, 0.2636916616991643, 0.10858913282713584, 0.09163097223086704, 0.19783192554548865, 0.28783182763764936, 0.1856057751443117, 0.18581761377713374, 0.2100843834059854, 0.16294051232116838, 0.2485705416409239, 0.11960470342948554, 0.3883920832266731, 0.2102887756641834, 0.15041590938645025, 0.5559414877526222, 0.37400011033300434, 16.047319500677048, 78.95173395833662, 144.8550602697557, 142.59477092373757, 108.54474606052523, 91.29704890712615, 72.54636226161834, 68.26631115328881, 67.64189335607713, 106.11651651320919, 127.45582626711939, 117.50417693968743, 115.29705139898486, 109.09391710835119, 90.35284026976555, 84.43840026855469, 70.85243178952125, 45.70792090508246, 17.32043750824467, 5.3682156339768445, 2.7265905180285057, 6.43062734796155, 2.0609929821183606, 1.1200271642977193, 0.8563382911585993, 1.5067230982165185, 2.527827596472156, 3.7797101370749937, 1.8939344560907734, 1.37342992809511, 0.9698871691380778, 0.24814268153521324, 3.6792893707752232, 3.3106140311687224, 0.7045141895932536, 0.3046470898534021, 0.25496895394978986, 2.103006224478445, 2.6861636292549873, 8.627600323769355, 0.39759273791024763, 1.216743864840077, 0.5681473521455642, 0.34612226269898877, 0.5430471248203709, 0.3332018527773119, 0.5781316841321608, 0.11998315852495933, 0.16896723409093198, 0.15732556281070556, 0.25225301904063074, 0.2773994567894167, 0.44722929056133, 0.6021105425973093, 0.3588827134620759, 0.23954565817069626, 0.833087461369653, 3.826447874307633, 3.575758900373213, 0.576163818759303, 11.660775061576597, 46.784125143481845, 107.0868089122157, 119.65081953233289, 109.78189299183508, 91.96147488009547, 78.3382595739057, 86.29910992037865, 92.96106738428917, 58.79942363308322, 43.12686012637231, 53.98559677985407, 85.17027531900715, 103.0004365982548, 130.1926051416705, 44.79722107610395, 1.1319420991405365, 1.3192629766079689, 0.1434397748521259, 0.1735568515235378, 0.29136413648243875, 0.17263748472736729, 0.402539061202157, 0.0872888011978038, 0.19637451987833748, 0.2738690171991625, 0.1555045564929324, 0.15671520523967283, 0.2354601878793009, 0.12756134623721724, 0.16833931778467473, 0.21122997596619592, 0.2654792206181634, 0.15976901556695663, 0.18716808889181386, 0.18423659216252067, 0.16825291838857437, 0.07920861139052338, 0.1587310583601075, 0.25430385173568804, 0.31528841884386155, 0.09286009135746187, 0.17918096344557502, 0.1616120392516736, 0.2190708705494481, 0.28900311478684027, 0.1305818777050703, 0.09238831909193147, 0.2719900180255213, 0.15516616013501922, 0.11359399289733942, 0.09933288314289625, 0.18454111211242216, 0.19102278285689894, 0.0826894008224049, 0.10372978349727008, 0.17463294458725762, 0.08712239923977083, 0.1747360140565903, 0.1143252927689783, 0.23081266952137794, 0.19644984164305274, 0.05665957559681228, 0.10867291986341439], [0.04736779858508418, 0.042415534281322075, 0.022134216419691523, 0.06234786270426647, 0.05421526482208602, 0.03638679770031764, 0.05036118755777998, 0.013341862659510827, 0.02989573663310899, 0.04559898583759223, 0.05498813262449638, 0.08335870885921103, 0.05035422381854827, 0.062218554723527164, 0.007300546914789706, 0.026462530837424343, 0.015925126461943072, 0.04012330728132398, 0.04378376348364738, 0.04354934440925718, 0.05202496198997383, 0.015220160862701315, 0.07050792866897199, 0.01887969105624624, 0.02250156515548306, 0.03045537152267512, 0.06425224237083908, 0.051798062068560434, 0.025908114921842373, 0.009724998775298798, 0.09827978803866333, 0.06016199169079623, 0.049325624375694224, 0.03564307954342615, 0.1218278063160758, 0.03646436410265104, 0.05834774226851522, 0.04914271322289302, 0.05114290367571577, 0.06686865096731533, 0.04015897633507848, 0.05968604041563888, 0.0486275190938144, 0.07690249521645807, 0.05133232657587336, 0.05525583055831733, 0.08570268509849426, 0.07020855682992166, 0.09135965453160387, 0.015094939961038051, 0.010677288200015263, 0.07228019647300243, 0.11825557662955216, 0.09041827802936878, 5.8629039795167985, 39.2930962962489, 93.60622667497205, 99.94261172509964, 87.33864784240724, 72.30176325767272, 50.07521337078464, 36.06823728930566, 36.49825065366684, 49.356564552553245, 68.56225398279005, 82.33555486125331, 76.29444583769768, 93.19682536586639, 93.02897930145265, 81.92427865920529, 56.46800210399013, 34.037077119273526, 20.097746233786307, 5.594837434830205, 0.14826189996975084, 0.33951882993982685, 0.2719546247634196, 0.9102219126878247, 0.4490656952463812, 1.2778443410511942, 1.1620042473077774, 0.801723025018169, 1.800158184862906, 0.1427328902026338, 0.06173307714503139, 1.7774487647318074, 2.5458405911922455, 5.468376298104563, 6.8253648761780035, 7.044420424968966, 5.131546681927097, 4.266258093618577, 0.261386901500725, 0.46027978221254967, 0.16678394479376657, 0.22029540080937648, 0.3260498397773312, 0.21084509339303742, 0.885679887667779, 0.4298635788502232, 0.6980224830969688, 1.9611467204747663, 2.542245738929318, 2.404064314980661, 0.300352186445267, 2.8695719424755346, 1.7325088213528357, 1.2194067864648759, 0.9099751710891725, 1.8828563344094063, 9.59673660416757, 16.5740143868231, 30.062762998765518, 54.848451537470666, 78.19915663811469, 86.69126849020682, 76.51557337853217, 64.98077700215002, 52.150308009116884, 35.710477905888716, 37.68057461707823, 38.367907231853856, 43.97017363579043, 61.01894386353032, 77.5108277413153, 52.16416966530585, 5.691476791135727, 0.329483782932643, 0.08173183688232977, 0.2647263094061806, 0.012800392672239293, 0.038237532059992516, 0.09506685358862724, 0.058474024201953606, 0.03549248580971072, 0.07046014010425537, 0.002798394698108877, 0.053115419202273896, 0.04390920655080869, 0.0470550470204363, 0.03762600237443563, 0.06876560724190167, 0.009052051820852345, 0.04212713665178707, 0.01617393554038098, 0.06494470541515658, 0.0975403216697516, 0.060134600217063586, 0.0357074998769789, 0.022371142516813936, 0.03396830791907926, 0.06532809411686274, 0.03229558941036944, 0.07508674426184547, 0.06491754759824084, 0.03625799150716874, 0.025266975938012044, 0.046859966560957894, 0.037943817780263005, 0.07462783461256374, 0.027443288089407068, 0.05474404552050176, 0.09404504551522194, 0.17067795439112574, 0.0097535451265773, 0.05387326019004949, 0.02166990585054361, 0.05869428980194273, 0.048290670233508276, 0.0589434139340395, 0.02543179975492099, 0.015847403011585198, 0.045067991145075335, 0.014219744836971646, 0.018474917010133787, 0.038935235145712094, 0.047037243137076024, 0.06264547254109094, 0.02772263630533651, 0.07099189705425693, 0.07108478521507594, 0.01624609910762839, 0.021438516653893937, 0.025838082994244276, 0.019100071569424004, 0.011556237154910642, 0.05613182911709432, 0.10029810796221418, 0.004422580579205627, 0.06560051498273689, 0.007674724366816302, 0.05902954136892673, 0.02222106397722758, 0.07355905002764157, 0.016249422013999957, 0.03362133903729339, 0.01214845376389642, 0.06676260907683643, 0.05861189321524674, 0.04831698152326769, 0.05121405409168332, 0.027974799891272863, 0.024430164691781806, 0.06749508106299947, 0.0761728271120979, 0.053360529033647436, 0.04365999814904025, 0.02146901269893973, 0.027678641791064895, 0.05176326635503962, 0.05797065080954664, 0.042213528387008176, 0.0849389797076583, 0.06371521090547885, 0.02216644382344619, 0.09542611052071857, 0.05226082897054092, 0.13130944672851794, 0.059558931107242266, 0.03434772828533765, 0.040921643676777045, 0.01897575465151139, 0.09880673395650041, 0.05736769364786245, 0.05726003148142369, 0.010436392809835174, 0.11383423040951453, 0.14872781932353973, 1.9178124973850867, 2.365689806399807, 28.558202597402758, 77.70252181637672, 113.56964741983722, 109.42577315915017, 78.15535945277061, 57.5781269996397, 51.30457831967262, 70.77156820604878, 84.85711328444943, 94.84135750801333, 96.045517306174, 89.5927712225145, 81.15723563778786, 92.4295783812, 92.75747283812493, 89.77225103685933, 75.56915252439438, 60.19160616782404, 42.87674234759423, 15.421642622640057, 3.690878994041874, 1.7291353378565082, 1.5160682677261292, 2.434803684872966, 0.8267259898204958, 1.9188378294629438, 0.6693132462040071, 0.6098943023431687, 0.610116406554176, 0.24557696114624702, 0.23872147013823833, 0.10011492101776023, 0.9821872317021894, 3.5585166513919835, 6.514645987941373, 6.214258622738623, 4.447447571062273, 2.205329585459925, 0.2585769216379812, 0.4462888716690002, 0.25520599687532075, 0.2739453501999378, 0.16903871009426732, 1.298306243073556, 1.600849440982265, 1.3256997086348072, 2.0059827210441714, 1.7380458597213992, 1.5782260678468214, 2.0339374532622676, 1.8775729017872966, 2.6202006397708772, 3.2822810353771334, 2.627415349406581, 1.7634391616429053, 6.145583314280357, 24.637111117762906, 44.99563809364073, 67.13746086243661, 86.75263789392288, 94.04608126609557, 94.78292203718617, 89.56463998363864, 82.6141921935543, 75.53569470682453, 69.37045835679578, 66.14590137235581, 40.73431630288401, 42.91496192255328, 69.21744669637373, 95.7980392825219, 80.01948941138484, 21.524206361462994, 2.649734861427738, 0.18331108134119742, 0.2864840951177382, 0.04577677186218001, 0.039621960191476735, 0.1051175747547419, 0.04041055194853295, 0.043130493497536074, 0.10119767138554205, 0.014193109875064225, 0.09266816334979189, 0.10504272796453969, 0.08247078231145298, 0.02980250564794387, 0.01615200627354845, 0.021538209590700366, 0.030362016048222303, 0.02836237526348522, 0.04342402774660338, 0.08033253132335602, 0.05367767794298069, 0.050431652325055296, 0.05730423092421505, 0.07091841390055996, 0.06009269137716582, 0.026891607107714783, 0.011428735226452833, 0.07377483401327364, 0.058431973635789856, 0.013266678790621942, 0.09029624788391014, 0.034702626177139824, 0.08056637200136339, 0.04095560052402077, 0.06036426571588363, 0.027565184169478958, 0.08961200879345979, 0.012766585212140795, 0.07076639907374498, 0.04469535831782607, 0.012941310715471065, 0.0627651622879409, 0.043583871992004496, 0.01953607902020937, 0.037842809087446624, 0.043156536656521985, 0.04043907723239353, 0.04200280441211597, 0.043274916393021425, 0.13685800705946263, 0.13894506039157992, 0.11958560485753322, 0.2703162078415194, 0.13976537201914097, 0.13305496274223252, 0.1613536684383308, 0.1131359795709291, 0.14046340069222835, 0.10575670658821061, 0.1927017564735105, 0.1487847090127968, 0.1909418992938534, 0.14718557707965374, 0.08178000849100851, 0.2012910423499923, 0.12756440292803511, 0.15193709953417703, 0.08601280515112224, 0.15149171133675884, 0.08913638310567026, 0.14260604136413144, 0.2769757795237726, 0.08731086453002307, 0.16090069597046222, 0.11645752996686967, 0.13210777163265214, 0.14607444315427734, 0.12677962245840219, 0.17061525775540262, 0.18090458466641365, 0.15185669094564455, 0.10979059617966415, 0.13269879314447605, 0.21447530827454983, 0.09734412655234338, 0.1370869447747546, 0.18570231754452954, 0.09201056113646877, 0.27342376689757075, 0.1616862425280194, 0.17784706647357634, 0.10348055211286392, 0.1771358917317083, 0.2062309611468546, 0.14541966780539484, 0.28324581081828765, 0.16490833172875066, 0.15480274334549904, 0.22811204104894595, 0.11963191487255598, 0.24787755382637827, 0.9964775294065477, 0.3183653956699756, 8.515492120096761, 56.32682423437796, 136.2446105095648, 148.9318306215348, 119.35798322000812, 95.6082122556625, 81.96300029754639, 66.46992052755049, 68.74814294999646, 79.7459746945289, 93.62804289787047, 107.81494202152376, 103.50039758989888, 112.80559324449109, 122.85282288828205, 117.27958986836096, 95.04277121636176, 64.76348553934406, 43.11817207644063, 10.850086846659261, 2.095319114385113, 4.503525207119604, 6.427151637692606, 6.83582240535367, 5.237021177045761, 4.812411858189491, 4.802129364782765, 3.3342605300488013, 3.2150891182884096, 0.3901932785107244, 0.3299585122975611, 3.109783530235291, 4.438794822462143, 8.325104194302714, 11.934179952067714, 15.438095004327836, 22.23130379953692, 10.621456792277675, 0.4995932081534017, 1.4211532834076113, 1.0430394954258397, 1.022664804852778, 2.0896020147108265, 2.1766229839094224, 2.726919016530437, 1.4015970811728509, 2.8604507157879495, 3.4512680192147536, 4.0815151939469, 5.974808710236704, 6.486805985050817, 5.981954778394392, 4.635555619193662, 1.7769079679442992, 0.5743203047783144, 2.427227381737002, 20.408596031127438, 52.97828505116125, 85.01934251477643, 107.52109373769453, 117.38667057406519, 116.67413280856226, 105.82222107918032, 93.09314927747174, 83.99574510512814, 71.91333093950826, 78.59835978477233, 63.05470105140441, 66.0422174392208, 93.93691385945966, 126.07847029162993, 80.04968381697132, 6.668119997747484, 0.6197688079649403, 0.2473497345683075, 0.2969389276639108, 0.1525391067468351, 0.15237726301195162, 0.21672366908000362, 0.17034645282453106, 0.1505340401443743, 0.3238113308625837, 0.23487814491794956, 0.24004779816154512, 0.3234771020229786, 0.22783246492185902, 0.07440478811340948, 0.15396513345260776, 0.08283038398311024, 0.09372469818880481, 0.08600584907276977, 0.14040494818360577, 0.1877364801663545, 0.13788982024115903, 0.08944757568139224, 0.11127150542433224, 0.30556136982575544, 0.2476640298001228, 0.11727001217584457, 0.1332105245561369, 0.14185018837451935, 0.2731963613581273, 0.0991127937431297, 0.12597726027090705, 0.10288239066158572, 0.2548322072553058, 0.24454545439972034, 0.16457008858842237, 0.17267649392447165, 0.2634508342992875, 0.21405898545297886, 0.2004049544132525, 0.16064739665917813, 0.18665214399656943, 0.12772267669319146, 0.2149827955591102, 0.08582083883905604, 0.15615502642768045, 0.2979531667886242, 0.08728034358711974, 0.11449819115260917, 0.1300023628338691], [0.01176938962852282, 0.042041231382397876, 0.027238307858727155, 0.07317298767907966, 0.026247055202181784, 0.007379044113951105, 0.02918570336224812, 0.014741610634260842, 0.04180584320678346, 0.03271682285553506, 0.05440252352385752, 0.028035619611581488, 0.058963906786014, 0.04503951182649021, 0.04990125901155895, 0.028681941180219574, 0.02558096281943783, 0.0407143670975441, 0.06466931212813624, 0.009881803566860336, 0.011900103380603176, 0.08651872195543782, 0.11370571916021648, 0.057977013169757785, 0.035668563458227345, 0.050805587501775835, 0.02180095093565122, 0.09856645047904984, 0.06740425367869678, 0.037174006668670524, 0.03220619461048515, 0.03566118986195615, 0.05682000589947547, 0.0242447120422918, 0.028323224340114864, 0.0306630119936721, 0.07938933153186115, 0.028034784575744022, 0.08031495726637303, 0.10755785590698642, 0.061353928739986116, 0.028624195387707125, 0.03621049405586335, 0.07767955351981425, 0.015965839247069052, 0.0785845178630083, 0.07095771421107554, 0.10066643537532899, 0.0531789738564722, 0.05611898565304376, 0.20234217626913903, 0.14478202218249922, 0.054499433646279, 0.13047321579389035, 0.3423494328894923, 0.10258638194852299, 1.031602109151502, 28.241983075295728, 76.68217997397147, 107.61889411557107, 80.29232163583079, 64.36930694887715, 53.292647330991684, 48.27531222374209, 26.192444639821208, 34.14546397424514, 70.99315858656361, 83.301571876772, 91.32000261737456, 107.34068039924868, 102.78196842439714, 77.80969665896508, 44.72976023151029, 29.724134975864043, 27.080704589043897, 22.265922638677782, 11.264876511789138, 4.94287577367598, 1.2008738325488184, 1.860724605860249, 0.48508696558494724, 0.21163712105443402, 0.31381713166352243, 0.31537029832120866, 0.1780182411593776, 0.055264655891205036, 0.10430053432261753, 0.21455513463625986, 1.1060904927792088, 2.2631178652086565, 1.3832620843764276, 0.7803122771363106, 0.3920380488759087, 0.7292905762310952, 0.3172299307921241, 0.21608731048482083, 0.0785850388027968, 0.5229909429627081, 0.59160104201686, 0.7157121887130122, 0.6609072392025303, 1.1580378730450909, 1.113675376099925, 0.521755947941734, 0.24713567428050504, 1.7969946707448654, 5.819102871802546, 10.138462993406481, 21.401853907492853, 29.361258860557314, 42.602560827809, 58.83214012269051, 71.92830654882616, 84.1517299221408, 88.95293851052561, 71.09106094606462, 54.80519956158054, 38.18245364773659, 41.556311730415594, 41.086737340496434, 52.71451742418351, 60.827547888601984, 74.24724317366078, 61.09932891784176, 14.118182140011942, 0.6739012548519719, 0.2598094958211145, 0.09727710151984807, 0.052943332871842774, 0.055472196770771864, 0.01142023548093294, 0.033627421775412177, 0.024417010962121913, 0.04361263859356123, 0.06722213159645758, 0.04307823480978128, 0.04997791376926246, 0.024640415607380773, 0.04797341790230525, 0.07264355197548866, 0.028957181249655066, 0.09534879692740018, 0.03623790468179411, 0.012233550810525495, 0.02513705700215313, 0.038108587971017245, 0.04223593262835376, 0.11035130359232427, 0.050407432455329165, 0.05499346076600975, 0.06743220822705377, 0.019017031468871622, 0.02228421835048545, 0.044745663481373946, 0.09934046741334662, 0.0863119318420368, 0.04425275868045227, 0.04509398067790655, 0.06499604862784186, 0.04733345869387831, 0.014862974283225356, 0.03807393781420204, 0.041771281150079546, 0.05674556130543352, 0.1571418702482216, 0.029161565846973853, 0.009187644595400462, 0.0226193358520827, 0.04714327736667568, 0.04335180863798146, 0.033722106412413626, 0.03242784682961722, 0.011553258988105003, 0.009804534981207503, 0.0908642637753679, 0.0737333043868984, 0.04636590879771017, 0.026456011429188714, 0.006172648591605286, 0.0734939631975947, 0.05241838644348806, 0.06491664361449019, 0.05310033493104482, 0.06838795653874837, 0.028075626638207226, 0.01592941463909923, 0.05139788071955404, 0.02975208557120735, 0.04658789426508931, 0.019215750845990354, 0.009624997488102846, 0.04194588790978155, 0.04480151895193323, 0.010528771522184534, 0.054236546744622534, 0.025513792230236917, 0.15826020540008623, 0.05272811196083504, 0.06333895831278737, 0.08266952084076983, 0.013715843801506826, 0.03360298357062763, 0.03247078222733352, 0.05658896144239172, 0.05579401115556398, 0.028567058635094476, 0.01068188185473123, 0.08112867287690602, 0.0292097719296092, 0.027529578317978212, 0.04519556393666614, 0.04143739705004039, 0.052319381070593675, 0.055480539468267275, 0.06580924329858634, 0.13920407471877916, 0.06606341595010412, 0.015795012173663466, 0.0806975952019134, 0.10214161428232348, 0.032888238859032436, 0.019540110557910897, 0.02324463405285872, 0.16104795339126743, 0.054347958911450646, 0.047232162718090324, 0.08159489866586463, 0.12358586318911084, 0.08364293513999832, 0.2861897334937127, 1.3121821178543953, 1.717442874946902, 14.444505687682861, 64.20060580776584, 106.61196677915513, 114.26819016856533, 83.52127951960411, 58.29178656301191, 47.323392206622714, 52.41971208203224, 63.532732071415076, 79.16381651355375, 94.97060744993149, 98.62316562283425, 99.29886448767878, 110.6140002896709, 113.9301367728941, 98.17659593397572, 76.5299214086225, 60.74826502030896, 47.480898903262236, 42.29712586249075, 25.491477866326612, 11.533318623419731, 6.113006068814186, 6.344656838524727, 2.762481675994012, 1.6138855608240252, 1.6323826005381923, 1.6038708917556272, 1.9999871330876506, 1.292936518307655, 0.7697617142431198, 0.671634492614577, 5.724007458456102, 6.55747385755662, 3.0284862797106467, 3.9523228618406483, 4.417069304373957, 2.9222282911500628, 1.4490539604617705, 1.0605704063369383, 0.6136689094766494, 1.239804337101598, 1.8286251541106933, 2.3634994078067044, 2.3945417807948206, 1.9876480919699517, 2.143573092837488, 1.8299282390263774, 1.185578550061872, 5.545063537936057, 15.001478329781564, 26.165137098681544, 45.9476444029039, 65.02563714981079, 79.43475031083631, 102.86318502118512, 101.49980052824944, 96.60010906957812, 92.29653158495503, 88.79517293745472, 83.1685878384498, 71.49788918033724, 67.13360125018706, 53.2454651401889, 60.050400841620664, 73.27039257172616, 86.69806203534527, 84.47534899557792, 39.114585307336625, 3.5346755048921032, 0.575012848261864, 0.1359684410835466, 0.018105599428376844, 0.07794103465012966, 0.060045860422354554, 0.08444668394663642, 0.04567131219852356, 0.028841500057868903, 0.03778332619056587, 0.09281096979975702, 0.04555818399474506, 0.10081890219401929, 0.11012261102516806, 0.08818776707255072, 0.006982283826331578, 0.046212070681635416, 0.01448295541077612, 0.14955960694820652, 0.02394469668938508, 0.02959224515624585, 0.042902632135777705, 0.07241444572085336, 0.037887031512875716, 0.07331357247406438, 0.06345441925429529, 0.07421465275148231, 0.03569638394119759, 0.01467958528308138, 0.02428289194921813, 0.029797562465612448, 0.07381206588639368, 0.11010142103318246, 0.21243181470180714, 0.06728963926434517, 0.03243131720791421, 0.043759218026553436, 0.07448653735580944, 0.06115089245741406, 0.12977164779459277, 0.0789184632500814, 0.015598877385679274, 0.04300176008273998, 0.010382389356832831, 0.03567596386757589, 0.10536003392189743, 0.029163042481447903, 0.03475849313901798, 0.0720091009392373, 0.04250164639445082, 0.02603413063972708, 0.12310384066715357, 0.1724098493615466, 0.15879122690568048, 0.1473963431893818, 0.14167769601748836, 0.12958159670233727, 0.12161674909293653, 0.13088080521312453, 0.1566993931849157, 0.11804043615777647, 0.1048155752341113, 0.14724671089601132, 0.1237962385939975, 0.13506928368681861, 0.2036986575131455, 0.1232898161716519, 0.12347175439278926, 0.13441394143287214, 0.19648983143270018, 0.12484027087808618, 0.27721547311352146, 0.17760714305745018, 0.1605012424049839, 0.13838399291759537, 0.09560029593206222, 0.11290105104806925, 0.08438184226472532, 0.24490379968718176, 0.16565234099905338, 0.1580837140640905, 0.1010863434883856, 0.17119069703884665, 0.17313798529005822, 0.15817339231650676, 0.08522764163752718, 0.15919504717232721, 0.1541743980300042, 0.11736258624061463, 0.11958422589926951, 0.2208497879966613, 0.24592464248980248, 0.1392487376447647, 0.14390909563629858, 0.13930922794726588, 0.20071569499709915, 0.19554055656396574, 0.1705210442624746, 0.3221437719560439, 0.13250800660781323, 0.1756165401949998, 0.5620965445714613, 0.264976084713013, 0.1582368090748787, 0.23878500947067816, 0.6597432145668615, 0.21124704440514888, 2.515632457310154, 39.89870632848432, 119.38265492839199, 159.74028248940746, 120.99312520796254, 94.82536992719098, 82.226105043965, 76.13766085716986, 63.088762913980794, 72.31533465846893, 96.80317801813926, 108.43095810182633, 108.22784208482312, 132.03667609922348, 139.2466514341293, 123.13222900513681, 103.98222938660653, 79.38515586237754, 50.191099797525716, 40.375929340239495, 17.69738708772967, 6.670037056169202, 4.088921609424776, 5.692528966934451, 2.3620841676189057, 0.8486760023140139, 0.7024098379958061, 0.6162517289480856, 0.6196504627023974, 0.29260716010485927, 0.23723913597003107, 0.12889438519074073, 1.467830836772919, 2.043899660629611, 0.6103741185319039, 1.0264385539677836, 1.3870762216468013, 1.286346200973757, 0.5105574891692208, 0.4455715988672549, 0.3819912654017249, 0.68212291045535, 1.1209217098451432, 2.1297423253136296, 2.322563836651464, 2.1530446362110878, 1.6156611687714055, 0.7686641247522447, 0.29621518908008454, 1.8524238899830852, 9.785644815814111, 20.940249773763842, 45.94266299278506, 71.2666654586792, 96.60795380992275, 124.42268879182878, 128.26218712714413, 115.01410730423467, 106.16792309668757, 92.35666151969664, 86.62069720606651, 74.21664868631672, 77.27142195547782, 70.63142976453229, 79.37484787356469, 103.46759873051798, 125.06093686626805, 93.7148057260821, 21.564171391148722, 0.5274813826526366, 0.3063421666381821, 0.27175758694929464, 0.11845972373961441, 0.5031794189445434, 0.11723312504229047, 0.17079066124654588, 0.0788692114574294, 0.14051281336334445, 0.1630018299986278, 0.21947542626050212, 0.17745820024321157, 0.1882371186248718, 0.17666350659583846, 0.2361902543493817, 0.20926384195204706, 0.18961509629603357, 0.11408811960850032, 0.22339177498173332, 0.06339991592892236, 0.13401032034908572, 0.12125672607292091, 0.3544669213794893, 0.10140695128469698, 0.10237569244758737, 0.1607518757302915, 0.13461229691822685, 0.18558680680730652, 0.10009562326294762, 0.11127925823412596, 0.2629802111656435, 0.19383225710161273, 0.12352315123162924, 0.20032459178999548, 0.18530166888188931, 0.1301013567154446, 0.1384762911907127, 0.12659207647365908, 0.28881471844450124, 0.30922327010381606, 0.28600109200323787, 0.07555441795698098, 0.17493020202363693, 0.13031340985288545, 0.10372505673477728, 0.2344449834838029, 0.18995081134621175, 0.14661032165731155, 0.12166773224429739, 0.10893654603991779, 0.2242713205275997], [0.05594757731042563, 0.15622523072506153, 0.12283174921908688, 0.10469132343367224, 0.13550246044272377, 0.01727431167608067, 0.05404479493717513, 0.06681872501728997, 0.058662324783302126, 0.06571221060209698, 0.019124030969255877, 0.03279491785853621, 0.016144829944917755, 0.047558451056360244, 0.11219479459067506, 0.035140418612788764, 0.044490391493684826, 0.07231930526153696, 0.05573001217036959, 0.04121485999935577, 0.10914325188364714, 0.09444105168504101, 0.08971590563775071, 0.07522989545137652, 0.02198158680731731, 0.03461344588187433, 0.080713200412931, 0.060346523119557294, 0.07474180551305895, 0.06826287736335108, 0.053105211080682856, 0.06945237442250214, 0.03738496813081926, 0.09639599315461614, 0.09649814331843969, 0.04616707833784242, 0.06620349512705881, 0.10618238334333706, 0.09009747871107633, 0.03564596386446107, 0.15663081299393408, 0.15088634865899242, 0.08328939322382213, 0.07990723761219172, 0.03510596763883387, 0.11531988939931316, 0.06373389578995205, 0.10752292995851849, 0.14563608764400407, 0.004244838125868551, 0.05882958092937066, 0.0073115436281378, 0.2088505988039317, 0.25531125735611687, 0.11003218966746524, 0.20389995477612943, 0.10727825679726179, 0.4843303465074109, 0.3847126242133879, 18.579977250868275, 61.01924588603359, 97.16454598211475, 74.62222176213419, 59.68849159056141, 55.79855941957044, 50.92846224384924, 48.401424269522394, 60.81826756077429, 71.45473526370141, 76.75245315797868, 72.11393663960119, 70.92434452426049, 64.20748564504808, 58.804907106584125, 57.277320431124785, 41.26930798253706, 38.895387572626916, 47.44657816425447, 55.37271553470243, 53.05908195434078, 53.89970079545052, 48.33302205608737, 52.07873652058264, 53.90228563739408, 53.72291957178424, 49.7169009331734, 44.88608237235777, 39.643920929201194, 36.485577475640085, 32.3991600544222, 31.629598871354137, 23.329590982006444, 17.49238637185866, 13.499050717200003, 13.135203815275624, 13.89754391485645, 13.18828328963249, 12.3447815064461, 14.434067280061784, 18.2274365809656, 24.746127513147172, 31.76464411520189, 31.05239660509171, 37.689117539313536, 41.16442380412933, 41.210903890671275, 51.99823771753619, 50.3904228825723, 56.13184321311213, 69.35155253256522, 78.49131830276983, 71.00462759694746, 68.60015192339498, 77.77637220198109, 69.04763160213348, 57.565281237325365, 52.6216160866522, 50.119273354930264, 53.48327059899607, 73.90086650848389, 76.18658065795898, 45.11372889241865, 13.885338479472747, 0.38801492281979133, 0.6316222106256794, 0.1183681226065082, 0.11112852277414453, 0.06113655129147153, 0.01017300699341802, 0.05906392722540806, 0.08635364532951387, 0.020189845048251654, 0.1088659433768161, 0.030739931051709482, 0.11722313525575785, 0.05167528498737563, 0.017202169176251177, 0.01788142486475408, 0.042593787619543653, 0.08602997318150536, 0.08429994746561974, 0.033496114305190505, 0.05843624840640734, 0.015516499951181394, 0.05525157110945833, 0.10919185250156349, 0.07731368524893638, 0.0718454109324563, 0.02768911995864924, 0.08813259342024404, 0.05215649545613316, 0.08230194419382081, 0.08927254757333188, 0.09412273449162323, 0.05142538327603571, 0.1005218439405003, 0.0687018993701185, 0.0778631694735058, 0.0371118271422963, 0.08963269316741536, 0.0952911871154943, 0.02106855172784098, 0.08433144900106615, 0.0861721361176141, 0.16405982806557612, 0.11329860471549535, 0.07745786299628597, 0.019422962307749737, 0.05991165330933948, 0.12007386333519414, 0.12057929750411742, 0.06777185330828352, 0.017905855408659386, 0.039824984982729926, 0.04548225319013, 0.03658640956986816, 0.22770233722704075, 0.0981381613641016, 0.06888605924623628, 0.146893069388405, 0.10980034081806099, 0.05826250732605977, 0.11461455990830738, 0.03874268277638382, 0.048492063257482745, 0.026569940194848086, 0.07058172591871793, 0.041466891435125185, 0.024866945891370697, 0.04739073908797676, 0.04955783328642288, 0.008805217334039269, 0.04165929824774785, 0.06419754369304546, 0.1314216020006326, 0.12709605507552624, 0.19019652638704548, 0.04171736771240831, 0.0961474665711003, 0.03341191358143284, 0.009335310915635239, 0.023361822522635904, 0.023884225539082003, 0.03824235841391548, 0.05205704958268231, 0.03557281012857153, 0.05957793008776442, 0.019312948251383442, 0.14106712394183682, 0.11777914654944213, 0.0613360099434372, 0.07629828167057807, 0.05187020839882955, 0.028337429525450836, 0.07884815170039093, 0.06593043074732827, 0.11232932729105796, 0.10629766425418277, 0.053805530356663855, 0.009850828716861866, 0.04201203194116393, 0.04612439191870151, 0.043531862282825094, 0.0966281331174316, 0.02055995936144985, 0.10381047553833454, 0.03145407438428412, 0.05080010231223799, 0.06626617644102344, 0.026551634523897406, 0.20004097071866836, 0.18892503493735868, 0.24265405992346428, 3.5126018764511233, 7.337000802639992, 57.71213869894705, 99.72995650383734, 110.64611665664181, 84.93337985007994, 68.94774452332528, 47.247655160965465, 50.36201707778439, 72.03643844973656, 91.28873348236085, 100.60473134440761, 111.02796723765712, 99.81555046573763, 94.85285005261822, 95.90249984495102, 93.9956788093813, 89.38505034292899, 78.03767265812044, 72.1262764161633, 77.69129599294355, 80.63476024135467, 79.29959327943864, 78.45304381462836, 68.25628557512837, 71.28602627784976, 79.49596281974547, 76.92593174595987, 88.22391894555862, 90.52995881726666, 82.44063515816966, 71.95610046386719, 68.56908675163024, 62.608613814077074, 47.63205920496295, 34.53965040945238, 35.68692015063378, 39.57933910431401, 40.46262156578803, 40.3509359975015, 38.20726656144665, 39.49005419208158, 43.5122133839515, 47.82436516977126, 50.908505224412494, 53.83567986949798, 61.96485088717554, 65.76345066870412, 70.84406145157354, 79.84630107879639, 84.12173163506293, 85.2677305283085, 102.80810709922545, 108.65103444745465, 93.1298077491022, 93.65322451437675, 101.18175906519737, 96.19794061107021, 84.65176936118834, 66.51596130863314, 52.74826941951629, 56.25543709724181, 77.95321618357013, 96.47825671780495, 84.53694589676397, 43.696631462343284, 4.677986348828962, 1.853720846195375, 0.1863043247571876, 0.019282505832492344, 0.05922044281877818, 0.016377538728017, 0.03362582065165043, 0.03549947253158016, 0.026270246598869566, 0.08563651042359491, 0.05441061724277754, 0.08289901780024653, 0.03828882164652309, 0.04847612096777847, 0.05863770654785538, 0.10540782248661404, 0.006454286452818422, 0.06474012163497748, 0.043333974111104206, 0.05476165788188096, 0.10708982215052652, 0.04533998683215149, 0.11465689392700312, 0.01642710461671795, 0.12756043459258734, 0.13278813431820563, 0.11515440674678934, 0.06854006329611426, 0.024695183233087583, 0.10972138779658465, 0.08387097653241889, 0.0560105880421977, 0.048565550241619355, 0.05563314418278395, 0.07003689950872814, 0.0631337003752349, 0.023980107188465136, 0.04365852342978601, 0.02032793622704283, 0.09690398605720651, 0.15097834049694, 0.11952987962192106, 0.10474524836266234, 0.10699416841230086, 0.09081277500597701, 0.06764325012843456, 0.1358524247282936, 0.052824079795109655, 0.04528585122898222, 0.015700613862023722, 0.01578615715486869, 0.024036621494639306, 0.02700362256878326, 0.42470222999972684, 0.24464294674896428, 0.37611439042995054, 0.22984218933889944, 0.23061273589489922, 0.11869862825880129, 0.18600046364290101, 0.1068109431634507, 0.12105463207849573, 0.11563288994253644, 0.15296992395193348, 0.1399255763258665, 0.09399444540782322, 0.1869130582218209, 0.2632248996486587, 0.10061190523687871, 0.17055651413336878, 0.1661687149035354, 0.31159572183124484, 0.14260199641989124, 0.2889559237707046, 0.13702585692367247, 0.16549276488442577, 0.1526385449594067, 0.17308979835962096, 0.08182087162088963, 0.23121797599859778, 0.14099664385280303, 0.20417571578535343, 0.10364864712520953, 0.18108908928209738, 0.1682510644557976, 0.19769617476530615, 0.2800916429729231, 0.20063334054523901, 0.18973039252863777, 0.15131373379019, 0.1985561850691034, 0.2032841733025928, 0.21022322918138198, 0.29092136830572163, 0.45276804496684386, 0.15733588967592488, 0.18513726641333875, 0.107184870679292, 0.15142054176859318, 0.20367950531503848, 0.23751037706050182, 0.17743258226302364, 0.165843878301882, 0.1416119503518266, 0.11280367361201395, 0.267945533438075, 0.3124929946516791, 0.16434070654213428, 0.3950392749280699, 0.1366102848682673, 0.6081082756000181, 0.9334633655605779, 32.02911580762556, 105.35938139884703, 154.7945345601728, 117.83381292896887, 94.18979690920924, 75.72405476723948, 77.52403043931531, 82.632737159729, 100.41074660516556, 117.89027936996953, 115.36566934277936, 101.69865685124552, 100.97330078001946, 109.9663620610391, 113.90990518754529, 118.37437045189643, 114.0123967201479, 96.84053467166041, 96.29239128481959, 95.06970220996489, 83.16729345629292, 79.54679673717868, 69.62662835274973, 71.80803883460261, 80.14553085450204, 87.62110556325605, 97.32701839939241, 103.18336809835127, 92.96730395286315, 85.59980623183712, 79.15303784032022, 70.86644249577677, 51.21244968906526, 36.373346697899606, 38.542338955786924, 44.28249236076109, 46.83628089966313, 42.959849526805264, 41.31423481049077, 38.5192754191737, 41.59960685237762, 44.59275184139129, 44.69831066746866, 49.487206935882575, 61.07664977350543, 65.09493366364511, 80.1848957615514, 97.3787779961863, 109.44336106700283, 120.61815446422948, 136.15817716044765, 126.9475341612293, 97.85294548157724, 92.13485933119252, 108.66394689006191, 111.02219350876348, 98.7835434944399, 83.33398634387602, 72.71809931724303, 79.95797880234258, 113.79548180487849, 132.66830321281188, 88.43287144937824, 25.993362780540224, 0.6554469934874966, 0.8011583875744575, 0.18662056585233058, 0.15034961213748302, 0.24622044435912566, 0.07913889738941386, 0.1322875418249638, 0.10832958223838961, 0.13625077512716094, 0.37037326623835876, 0.1159613501400717, 0.1728645991533995, 0.12842363948302885, 0.0912607602414585, 0.14900975500143346, 0.17882142306095172, 0.18097679611415635, 0.2556455321609974, 0.13403364006550084, 0.18803105629499883, 0.18791321665048602, 0.14040125563981073, 0.20887312178890552, 0.2644988425797032, 0.24120739480901152, 0.1845193398936141, 0.24223157775498208, 0.15270527121761154, 0.18355299658592672, 0.2315737931959091, 0.16275637542768834, 0.09750534209512896, 0.2120444040384985, 0.11491498128781397, 0.13794822678450616, 0.19712819717824462, 0.12936917584269278, 0.1376122819079507, 0.10651948501265819, 0.31948756126146166, 0.29419149121930527, 0.17758904806067868, 0.1957162052032448, 0.13950369170596524, 0.10642914792462703, 0.19173700662870563, 0.19769191531644714, 0.24307102625889165, 0.12840948217818815, 0.12376506647635853, 0.13536182202158437, 0.21307136022275497, 0.14915456094088095], [0.04506884916355053, 0.03711711314897384, 0.022369288584037174, 0.05812549633124183, 0.02690096678692968, 0.057424361171621474, 0.044706052905249025, 0.05142826376663101, 0.03952968490099715, 0.07281874862289237, 0.08007341740472664, 0.031105785916048675, 0.058683484131770755, 0.048922091392019106, 0.07214040074857973, 0.023579171242853327, 0.0643346619401728, 0.04704742444558971, 0.03854487121345536, 0.057261280204740264, 0.06402948315465642, 0.0607912716335587, 0.04365701040613555, 0.051375189195236856, 0.0688527190997716, 0.012591483368117724, 0.08337849691029518, 0.05600167460919869, 0.08042322847271159, 0.07633968106200618, 0.041145843138257344, 0.061795731645918665, 0.015234967427057846, 0.020602228262672023, 0.06686414637032055, 0.10762105049986033, 0.12256967820106976, 0.0644640771732215, 0.10001360588977415, 0.02138645714899946, 0.05268921001604008, 0.07145372549853019, 0.07772492124669014, 0.042456952824948296, 0.02143385309365488, 0.05819013499985299, 0.01649973932803879, 0.08271751624922599, 0.05493565943212279, 0.012952463998038684, 0.01900940506358541, 0.04039352947485544, 0.02860691818979479, 0.06936193774304084, 0.06857557913228389, 0.09713369752130202, 0.02128070637193178, 0.280184400898795, 0.04568054738845076, 0.22044607498232396, 0.5687727250399128, 14.960672932286418, 70.02174438968783, 101.647383628353, 98.23403512277912, 78.3341646194458, 67.99274152325046, 68.63429223337482, 67.65126782078897, 64.24028058205882, 75.12794079319124, 75.5846066628733, 74.97056745713758, 56.85205313467211, 56.28418022586454, 63.35773944854737, 62.393209011324, 70.86804282280707, 77.17734782926499, 80.79837799072266, 89.73283121662756, 110.20555603888728, 103.97578885478359, 96.00698394160118, 104.50666596812587, 83.17327114843553, 62.85113396183137, 71.20222091674805, 90.05175913533857, 87.35552972362888, 82.42843658693376, 64.52429156149587, 42.58138787361884, 46.74046131872362, 47.42288704841368, 25.67587829405262, 33.92413247016169, 56.413924386424405, 64.5526267636207, 76.42861443181192, 82.83763393279045, 87.90438698184106, 85.69005212476178, 87.0414576991912, 83.5160078540925, 74.96293452478226, 93.77564953219508, 76.5620848440355, 81.50387902413645, 79.74109526603453, 76.33318316551947, 72.08768813840805, 54.67154479795887, 61.677984422253026, 59.08485843289284, 56.68472090075093, 76.22541996740526, 90.76020979112195, 81.69742445791923, 49.4952085710341, 6.852796952570639, 0.6049899913130269, 0.08142993695312932, 0.023441087724941394, 0.037633004418063554, 0.19091618938311455, 0.05693507996658164, 0.06487945004576637, 0.055615007051176606, 0.060192271316003416, 0.05842169656628563, 0.05351486127643336, 0.04806127286546173, 0.14008201148000457, 0.009528985603772586, 0.053850212434847514, 0.023982399706578544, 0.012969709594824142, 0.024100149335760265, 0.02491554076362762, 0.036841390444146055, 0.03380206300907078, 0.02243858889766759, 0.05206589789820775, 0.07024384283971402, 0.05594137199823895, 0.05928731846412825, 0.007975055252186834, 0.032784859124090404, 0.06167146452372113, 0.01943842387728153, 0.01213576639026043, 0.04261936729533538, 0.07567333778546703, 0.05860812023221966, 0.01939248733012186, 0.0362785839505734, 0.11097547372863178, 0.12723415008475705, 0.033058103534483144, 0.08225152794752391, 0.08178894107620563, 0.09928041378096228, 0.07631336594180715, 0.07867820275526854, 0.05925992315995598, 0.04797378945494852, 0.06785898048791193, 0.1485698519935531, 0.0670876372004709, 0.07340502038958573, 0.03611048510778816, 0.040291233754326264, 0.059691617535727645, 0.04192785420004399, 0.008585282109467494, 0.02661539793705508, 0.07150222652501638, 0.07336637891468502, 0.04364504028231867, 0.04209342495267911, 0.0183488151073576, 0.09716561274422754, 0.08493637500871574, 0.009887824060335275, 0.052396572089844176, 0.11607756567818504, 0.03766210426786735, 0.03816749247151517, 0.0380600409792556, 0.04148315165131804, 0.05609930102382937, 0.05487228863902631, 0.11551985366930885, 0.09075203955534006, 0.053670568647043365, 0.11214456986635925, 0.051258694035031145, 0.0674991489898774, 0.04414644482876024, 0.08189124445761405, 0.012342260602200705, 0.042223947182778394, 0.024542101628838048, 0.06885704749654378, 0.06160379214692981, 0.0642630901758469, 0.14690652189235534, 0.06208360833566516, 0.025216165156434142, 0.029221173233142304, 0.036476977740324316, 0.11976843174066275, 0.02663801859823927, 0.07938528658762094, 0.03904223081565673, 0.058923526291525176, 0.016287904525656375, 0.04633248821201344, 0.04114580866430075, 0.04003968495394915, 0.012935739341041735, 0.07077598283367773, 0.036673153705534436, 0.14439258904707047, 0.02858927135445899, 0.041449949400679725, 0.07789575885380469, 0.013004329108122378, 0.016003438842392737, 0.2202902833420423, 0.02199689707448406, 0.029395350983606714, 0.21588074253691783, 0.11643153660359884, 2.3677367933334845, 7.0520185462890135, 53.079403754203554, 97.90979631485479, 108.6935450953822, 95.13743369810044, 81.58679008483887, 65.36425144441667, 69.7773728832122, 79.6612201198455, 79.50580012413764, 89.80572454390988, 100.65986417954969, 108.36530546988212, 89.37572294665922, 90.07426569538733, 108.13241866327103, 100.39908147627308, 105.2410513354886, 106.19008448816116, 108.26721483661284, 116.43289135348414, 132.13155038895147, 135.65562740448985, 126.01715580109628, 129.8399369947372, 109.28919622975012, 84.81992137047553, 91.57112060054656, 106.95955937908543, 110.92979031224405, 116.41523284296836, 100.17118392452117, 65.91365783445298, 85.97104287916615, 88.8156790887156, 73.9939365079326, 78.83497284304711, 105.5964102283601, 105.61426485738447, 111.48254640640752, 114.99646448319959, 127.53468944180398, 113.90237423681445, 121.65466431648501, 113.96157849219539, 98.13879213025494, 115.2736819174982, 106.62034496184319, 106.65932547661566, 98.40447779624694, 93.39758796076622, 79.0331623631139, 63.493045530011585, 82.02953154040922, 73.75334616630309, 65.39821132536858, 77.92819146187075, 99.28989794946487, 106.0145898019114, 86.95304747550719, 35.906592492134344, 3.976229462892779, 1.2999166211774273, 0.05064547895604084, 0.11648968267705172, 0.00960021741658209, 0.09294898053931613, 0.12315144537076836, 0.06561431222625318, 0.02367908826037761, 0.07085760950200981, 0.06300102160762876, 0.06893157252981778, 0.12232534211849976, 0.0669473205362597, 0.02529099854009767, 0.07889914251263104, 0.053995910866726796, 0.04206892546086062, 0.029367854172784476, 0.02515565953217447, 0.01687703188508749, 0.02294622365415337, 0.08877947040262724, 0.042551614479312015, 0.07270040336034952, 0.0721475177053963, 0.03675820095644843, 0.0688655357507448, 0.1167739932275107, 0.06931675387726677, 0.0809694568236028, 0.030225127627472245, 0.03015484097563932, 0.0664783598134114, 0.014168758812781065, 0.050915168718464916, 0.020554686761310986, 0.06401868897580332, 0.03588436276561791, 0.08176702330069197, 0.037540729127583966, 0.13305709246666203, 0.0622316969618682, 0.0483582545101883, 0.11497737148836737, 0.061040568135438435, 0.06067590262260168, 0.07941728608021814, 0.08564972544028875, 0.05788614748105888, 0.031233232303131974, 0.06196568442148067, 0.10716571848118499, 0.056517435643341274, 0.0389806067030276, 0.23248946744828458, 0.2408482681118673, 0.20244498526857746, 0.13184978386327145, 0.14171334974948438, 0.22863249054118512, 0.13637661272960325, 0.24457992835631295, 0.08526777698388023, 0.1501694895447262, 0.27422963010687984, 0.19062552030288404, 0.09013500169760759, 0.2300363313406706, 0.14027382457448592, 0.15995212590261815, 0.20550164544293958, 0.23053134671382366, 0.17336672382248988, 0.15472282505323812, 0.21961479297568723, 0.10841799644573082, 0.10328113942617372, 0.1284159479602691, 0.16643784159133512, 0.21621461897607774, 0.2501568799057315, 0.07684036548579894, 0.1366097639284788, 0.17736049338934884, 0.10176219391606509, 0.1534428606711088, 0.10981765440514973, 0.10411696433420144, 0.19183731818151092, 0.3262146099680855, 0.24853001558972945, 0.12550892774015665, 0.21440017037093642, 0.1563632491254999, 0.18468674542682786, 0.09785054131380974, 0.19946592980094496, 0.08311337686233944, 0.11848787747083173, 0.14615226236562576, 0.15968090013390587, 0.16118687577545643, 0.26586189685809997, 0.08820151835079156, 0.21092657450466387, 0.1679099255031155, 0.20307241127856318, 0.1278500924367578, 0.36251764744520193, 0.24443352895398296, 0.09946385353443124, 0.26611075285942326, 0.19066941714094532, 0.4913553114860289, 1.2084364073891793, 29.313615791259277, 109.09633328837734, 150.51486784412018, 145.96250226420742, 114.39970724044309, 89.22258577039166, 94.57990800180744, 95.13071860036543, 99.45222131667599, 114.91577348401471, 117.31363604145666, 112.92392330784952, 81.89035015721475, 79.43446005544355, 97.90199079821187, 97.42353223985242, 118.8425837793658, 118.99335184404929, 124.38964674549719, 130.39749406999158, 150.52801562893777, 136.26820748852145, 133.83150562163323, 142.50273643001435, 108.40467822167182, 90.42803210596885, 107.07941916681106, 126.71542398391233, 128.42596961605935, 132.79910641331827, 110.75309538072156, 69.77256405738093, 102.4202552918465, 108.58635456331315, 83.44524045144358, 92.73966527754261, 118.39507272166591, 116.10138831600067, 124.21909424566455, 122.76849192957725, 143.87763700177595, 126.83928458921372, 127.51736825512303, 122.56142216344034, 106.74579804943454, 123.42933285620906, 97.2118889900946, 105.26534649633594, 100.5139990775816, 104.37237970290646, 96.29290119294198, 82.06140472042946, 95.54972187165292, 83.76061470277848, 79.52889503971224, 105.44795636207827, 137.4109665040047, 136.23445941555886, 87.85236066387546, 21.32015093680351, 0.954951212531136, 0.7105345987985212, 0.05046561300273865, 0.13173810356566984, 0.23231250113777577, 0.1618699197687449, 0.28035925280663276, 0.16671084468403172, 0.26794176428548755, 0.14934087352406594, 0.14779109297500503, 0.1465580897826341, 0.21609992029205446, 0.2106244907143616, 0.16564596714752336, 0.1922090240423718, 0.08694802996732535, 0.13755707761212704, 0.22092374612487134, 0.11367326001486472, 0.15093612905231216, 0.10132321787457313, 0.24940337114516767, 0.13118633639908608, 0.17404224483236191, 0.26747144758701324, 0.05993445208596607, 0.12491841184636279, 0.16300414358415913, 0.09403022171388711, 0.13383592809400252, 0.1424116848577415, 0.13644913061251565, 0.1869855454612163, 0.13628445235231232, 0.19709686418214153, 0.15581292220421378, 0.15663876498658813, 0.15694619607060187, 0.23112224565157968, 0.159913944080472, 0.2500525387304445, 0.19353486176940704, 0.2840937782199152, 0.1431028034177519, 0.14646574554424133, 0.1561242143713659, 0.21631041061012976, 0.11815233862087612, 0.0943233575972338, 0.10993198536696935, 0.20068379509593212, 0.17200575330324713, 0.16200306584998486, 0.20170086874596535], [0.04310201034851132, 0.026182387805273457, 0.04201143822302261, 0.023494955197337176, 0.032807749831267906, 0.0255503537764232, 0.041633415967226035, 0.04970422502787364, 0.0655307013901972, 0.05338386407182102, 0.017541379502583897, 0.024149414534950932, 0.017552468625287858, 0.0065083885396410145, 0.014821925377022597, 0.03649995271717349, 0.029590293547258745, 0.04533754301167304, 0.11755904948879635, 0.06974513492276592, 0.02408937239388545, 0.0020723353466770103, 0.039071621778871746, 0.11608619948909168, 0.05858316874852585, 0.01590296162307383, 0.053668281874589385, 0.034088204509668776, 0.07777464801385518, 0.015112182684993793, 0.029521431818964983, 0.036448571200092, 0.03537653840237087, 0.0512444218170018, 0.01142555979200669, 0.0061319798565349515, 0.01688199421961702, 0.04229176894671494, 0.04610129819822408, 0.08264743452591282, 0.03469483506294989, 0.11074753192764138, 0.04929496936740414, 0.044532059015886444, 0.001448490797737313, 0.06955336779356003, 0.0409876766254104, 0.04954694717701885, 0.027314091191416787, 0.007235915907057784, 0.024489159207610835, 0.08454141071847371, 0.031131030428373528, 0.043770199896948, 0.024557965394530087, 0.07555001295141636, 0.06372027857709797, 0.06464245308551096, 0.05642273951502097, 0.10074921883642675, 0.022136382533297427, 0.139365520087942, 0.2439719456578455, 10.848002106912675, 45.14523336964269, 82.94855071652321, 111.10998399796026, 115.63492436562817, 87.92032749422135, 77.99425986505325, 75.8860408106158, 63.11725893328267, 70.89411873971262, 75.95370169608825, 81.1038992481847, 68.60689055535101, 65.12894845777943, 69.8910431708059, 60.326822034774295, 67.71137422130954, 59.648138246228626, 63.350726250679266, 49.72267858443722, 54.57772170343707, 73.17049764817762, 62.80108059606245, 73.73008651118126, 69.8280812847999, 76.99219626765098, 85.78570304378387, 69.95777053217735, 44.56073745604485, 45.92097228573215, 61.93218538838049, 61.45936327595865, 140.83914941357028, 54.889938446783255, 39.3914811072811, 62.98064670255108, 52.295926001764116, 65.75481753195486, 70.34439071532219, 78.17257081308674, 60.74023200619606, 48.22876545690721, 83.05389773461127, 78.86049178338821, 72.99864292144775, 77.11046357308665, 82.8287301524993, 72.25732280362037, 64.64452397438788, 73.97274786426176, 85.34071014773461, 99.80994147639122, 107.2531174075219, 79.55818730015909, 31.026320688186157, 4.415211081504822, 0.1386060664850858, 0.12660241099975764, 0.015278619116983347, 0.037987772074918595, 0.06483513952022599, 0.09676455805498747, 0.05785757240148322, 0.07740166278616076, 0.08203510810891468, 0.03129782692168749, 0.019117302802060882, 0.06258300573174512, 0.06303924173417111, 0.06584927905350924, 0.04685287641721868, 0.022314009594640905, 0.03974885116481493, 0.030001726812653007, 0.09409509403931518, 0.09024785410973335, 0.0658330379895145, 0.09172484098422913, 0.09202249678632907, 0.06362339143731421, 0.062073538109900496, 0.03338173737809543, 0.02084062141816943, 0.07852552143195946, 0.050606190136844115, 0.07483194341822978, 0.052232813135149984, 0.08871556334798375, 0.07497709409724321, 0.08279510563419712, 0.08326113224029542, 0.04707209247675154, 0.026177946410532442, 0.15488135928828872, 0.059888777923920465, 0.05150180437692231, 0.01974213751964271, 0.15234807506203651, 0.08627756513775357, 0.017122888652187203, 0.045858226160729126, 0.08063598641104276, 0.04276410045643007, 0.08992906194180252, 0.039465839133387616, 0.09213869700268393, 0.041385034940415816, 0.029032794127781546, 0.038460080601995995, 0.04745550416109543, 0.024654873601731755, 0.06689354882485445, 0.03575396310958651, 0.010814669789866576, 0.06081215902081421, 0.046659496672932184, 0.021788731833258947, 0.020820385205649564, 0.048656044377674984, 0.05625276758726086, 0.010953551954439571, 0.020913499362406232, 0.021995259561545907, 0.0400644104417053, 0.011253535706219415, 0.04690879317481191, 0.01771294680844632, 0.09459915691085401, 0.06283893655504912, 0.03101216231082236, 0.005609518425884627, 0.09159404679291672, 0.08936566556052816, 0.025134096072325786, 0.030206165036126494, 0.007578140789372547, 0.05095361867138455, 0.010094872728410748, 0.011270908665122285, 0.01008147863866461, 0.022514238164970474, 0.056208721362054355, 0.01845427094057443, 0.01936314807784173, 0.021026606498766812, 0.039778403006494045, 0.06140428369924907, 0.07028051546864933, 0.021879923109325673, 0.049727862670777306, 0.015685997862038354, 0.022594893816858534, 0.08178969184237142, 0.01741495201243989, 0.07206543904518889, 0.049296076364454725, 0.04219149186786625, 0.012241575581532334, 0.030474722903642445, 0.08379701074332961, 0.023404491704798514, 0.06385394942856605, 0.03701248469071523, 0.07785527110700646, 0.03939506410050296, 0.06971639130384692, 0.0382734309401243, 0.008927800020413294, 0.00273251807929257, 0.07543126166227364, 0.14071332921664562, 0.04766304887110188, 0.11176344112402971, 0.04689567008866899, 2.794135693580874, 4.309980263633113, 40.71429260315434, 81.18707703005883, 107.94543143241637, 113.01340826096074, 112.77710114755939, 95.40174653453212, 83.33313126717844, 84.87485808710899, 78.46573660450598, 79.25433697239046, 76.39077140438941, 77.02799181784354, 68.3612403561992, 66.5186285203503, 86.50798397679483, 78.07925762668734, 87.70008640904581, 74.7031637930101, 89.93822220833071, 67.28200020328646, 66.12665822429042, 90.94613013728973, 58.339470817196755, 63.884482383728034, 63.74334766018776, 75.93718067292245, 83.02222851783999, 70.00904375506987, 48.4055898266454, 47.45840018795383, 74.78272514958536, 73.50398540496826, 155.61463940528134, 63.241084237252515, 46.76973004494944, 64.11010888315016, 53.91775546535369, 57.8531204500506, 76.03211772057318, 77.76059642914804, 60.48779218427597, 54.839661505914506, 78.21704264610045, 71.37817059793781, 66.89531726221885, 77.44017016503119, 81.64824578069872, 79.6959723195722, 81.11321879971413, 80.77609892814391, 91.5394200048139, 99.73450645323723, 114.04655271960844, 109.43095068777762, 71.37037292603524, 21.84049060267787, 1.1919829225347889, 0.8615824387919518, 0.06347841312808376, 0.08799401577562095, 0.032994135192805724, 0.06507136273167788, 0.049264164971968824, 0.04014387674209091, 0.11585410549155167, 0.10616267190104532, 0.02408910617833176, 0.022247183745005922, 0.06365023898862063, 0.061763598087934725, 0.07444552866922272, 0.024326834752554857, 0.03296260684428196, 0.03391992946666095, 0.09154962135418769, 0.027098293799246033, 0.05707198370909018, 0.023825424460453853, 0.051533857495674205, 0.046212541825708844, 0.02623303004750802, 0.05370133090764285, 0.02756497349529978, 0.004699228814006934, 0.05782586019185763, 0.01377027722135667, 0.0247909901888981, 0.07079563298893553, 0.08513718197542815, 0.02417025212649136, 0.06845272161186704, 0.07873823340501516, 0.006420093554733021, 0.04954163435726397, 0.07692185425830465, 0.08204135172549756, 0.10133305444352089, 0.03852632422480853, 0.11355920484469784, 0.02099928588816716, 0.09010222079532762, 0.039175327101181594, 0.09598301047639501, 0.06001648861133765, 0.03364659695615692, 0.07551995932214683, 0.022053204536918673, 0.020571937146145972, 0.04372485515270983, 0.053955511220039866, 0.0431855139322579, 0.03321452719730235, 0.027507237278886383, 0.17430819991615512, 0.12151414693723764, 0.11736183547444883, 0.13410909972604246, 0.19068984104500664, 0.18437280259545774, 0.17247698930723054, 0.1470178497895118, 0.1481187487802198, 0.21213103326097613, 0.20115501577815703, 0.05827938807347129, 0.18410931431478073, 0.10075100382129032, 0.12098920050888293, 0.15867445978426165, 0.07968249039784556, 0.14461761971394863, 0.36607796446450297, 0.16058932719451768, 0.12430993119074453, 0.12913243935233162, 0.1393988602344067, 0.19578450960257363, 0.07689139460243526, 0.08263857088862889, 0.07456372837505995, 0.13652077515519437, 0.15126131805441073, 0.20551437782424115, 0.15581381086620594, 0.1193498412988359, 0.06876127118425024, 0.15275868286769237, 0.15524664533234414, 0.07212654987890875, 0.12777597343008365, 0.11741992792174702, 0.1248618592357924, 0.13564196505373524, 0.14619861068504472, 0.1864381756393179, 0.1767833380689544, 0.13188652544011994, 0.0941982018130441, 0.1611500882333325, 0.12728403773038618, 0.11771995093553297, 0.14869066405921214, 0.06940475439712887, 0.17147571239019596, 0.16738135547887895, 0.24983961225276996, 0.133294012818125, 0.11394560427194643, 0.146722155172498, 0.25943745288156694, 0.23815340062062587, 0.1757236392868142, 0.2027329577193145, 0.14642970876828318, 1.174068109643075, 0.49901046039116004, 18.812067816334388, 64.78879267169584, 124.5523545049852, 159.83677279564643, 159.95409873224077, 129.6420063511018, 111.05016785283243, 102.33784629452614, 85.18097554483722, 98.08716589404692, 105.07176183885144, 108.78675630015712, 93.02467253900345, 87.39269810338175, 98.85274979376025, 87.56329767165646, 94.76083124837568, 85.93898142537763, 93.87324594682264, 80.49251156468546, 79.36805432842624, 112.712946861021, 89.18602928038567, 93.86634257531936, 82.81744157114338, 100.94302792702952, 110.66063727101972, 101.43603847872828, 72.99433615899855, 74.3703899075908, 92.8441729084138, 101.23829610886114, 180.419096485261, 82.77923768566501, 79.99852042044364, 95.7579840383222, 80.81366738965436, 87.04829046803137, 98.32943501011019, 104.71885834970783, 82.51757637146981, 68.87875003199424, 98.5784427581295, 99.81708019010483, 87.82686525775541, 99.12360514363935, 99.76506956161992, 92.22116716446416, 91.44553415236935, 100.51996108024352, 120.94789243513539, 138.83062916417276, 149.43299970319197, 119.13631439208986, 56.859450724817094, 9.646236915742199, 0.26337254011342603, 0.7442513540867837, 0.19258334992393372, 0.16523918978148894, 0.1287343800668755, 0.243366108005566, 0.16064270820108154, 0.11703786455214986, 0.29867552641418676, 0.27947420674947004, 0.08581572903260108, 0.1494977530092001, 0.23333927346093042, 0.20893833119302027, 0.1519872782932174, 0.08253368579091565, 0.09586001506015178, 0.11782236923013004, 0.16414279538777568, 0.13745861999209852, 0.18429282301616284, 0.24990554177953353, 0.14201131198675404, 0.2475138918887223, 0.08909154397946212, 0.10479992405781824, 0.17110857241336377, 0.16314986882911575, 0.2752475158101128, 0.14008132200087273, 0.17222154494975844, 0.28617600519810954, 0.18035220462949048, 0.18053194417828516, 0.14752935137479536, 0.1372764749272216, 0.08461984280016153, 0.2788974038295208, 0.2730743695170649, 0.15204680332493398, 0.1430616798179765, 0.22918628017988898, 0.22334971675469031, 0.1447683092086546, 0.25917817808447347, 0.1550076258999686, 0.15511500078343576, 0.14835369262483813, 0.1361875728734078, 0.2672292718723897, 0.1277357691358174, 0.16965547216034707, 0.12863252101646316, 0.14829429016718942, 0.1602191994747808, 0.1386809285970465, 0.15906963857912249], [0.013803824211560912, 0.06377933246474113, 0.05765364362647938, 0.0372758197538074, 0.03412249460515957, 0.03385088196204555, 0.02952211172199778, 0.012199890822352422, 0.01414586906321347, 0.04703492572110507, 0.022902843925440987, 0.03324994727248146, 0.030319281748586127, 0.06509286681971242, 0.013411665718341547, 0.05624503009922563, 0.059142470389844916, 0.03820238777646615, 0.04903350355884722, 0.03987897119875397, 0.04271340075760119, 0.021191215811056957, 0.017598286428819263, 0.029409221005475814, 0.04204102453865832, 0.025690122687768553, 0.05758136323082352, 0.018994910680058024, 0.07350261999113906, 0.025834174030610633, 0.035532605834305286, 0.05260806981353991, 0.014315940582403734, 0.034138459877501574, 0.046507631233262445, 0.13814086725394573, 0.025261837403259935, 0.022626910546434023, 0.03839435791897197, 0.08683866325525508, 0.018331873072912137, 0.07621388176396009, 0.06406923162660773, 0.03321382239641201, 0.07155972142373362, 0.030921139574098973, 0.04193231666220292, 0.015520192494976427, 0.02357366307067775, 0.012293516342798549, 0.05371775583273942, 0.056063995861838904, 0.10958316255240672, 0.024482222281456478, 0.033421600763235366, 0.039340193052926374, 0.06902670532825493, 0.081310220393202, 0.055912509635691686, 0.019064404430889317, 0.04531377513382224, 0.07228576593221196, 0.09074645477437204, 0.18405590266469987, 0.1697772341750322, 1.5310428964514888, 14.392310707799851, 46.09754170140913, 82.0149560128489, 111.13704050740888, 123.46614822264641, 116.57969782429358, 101.33978351469963, 85.65801420519429, 70.84555979697936, 68.68507908236596, 74.95441513676798, 79.34186074041551, 77.14783591608848, 69.09346057522681, 81.08966104445919, 78.38226072249874, 96.61757146158527, 72.12852785664221, 71.49249984372047, 82.72481087715396, 93.90860219155589, 102.78178015062886, 86.58042230913716, 82.51304995629096, 75.91685495068951, 75.13893127441406, 71.9773518654608, 70.09869344772832, 85.3426399538594, 77.49037650323685, 69.48904729658558, 71.86692145562941, 73.64681459242298, 75.39913346690517, 83.86911530648509, 77.42195467795096, 85.75866222381593, 72.57264214177286, 85.3623616310858, 78.45284769611975, 89.86884332472279, 74.5690030436362, 83.64717975739511, 96.43675804138185, 105.16618897837978, 122.25375144712388, 82.74105733440769, 55.94221622713151, 31.633325123017837, 12.18098528923527, 0.9444161552575328, 0.41110217751514533, 0.16611046157777312, 0.03895899536268365, 0.07330234162509441, 0.07309924405548843, 0.1297437468723905, 0.045070120869504834, 0.08943243012312921, 0.024068423719596, 0.009138731796654963, 0.033333822408871304, 0.04361191464047279, 0.0995211186067712, 0.037004463750148014, 0.0910644808543786, 0.020515212165792624, 0.035646592056558984, 0.021943309224180637, 0.02476635663169286, 0.03971415887316389, 0.06040967174715573, 0.09626136852368232, 0.05782188419553061, 0.07244688954444663, 0.027839568135659062, 0.011351763499870656, 0.018694433759176926, 0.02440064157839985, 0.020828838985893997, 0.050835108699937986, 0.04619330152749054, 0.056880764332750154, 0.06550464673989242, 0.07110107990522539, 0.09018664368458333, 0.025894459404592073, 0.07187402431642817, 0.056846045228021766, 0.026273605894417535, 0.038637728730757395, 0.0091087068956826, 0.06090235438257937, 0.11164061424712982, 0.04079358824979394, 0.03490891833339007, 0.040014668352781765, 0.019923568207530246, 0.051640316904071844, 0.09704283183260311, 0.08814842079675968, 0.05548017557650324, 0.04771858641517259, 0.01020712280390604, 0.0048014972426538025, 0.048591853870499524, 0.06298645061530894, 0.027820595968214255, 0.06039000243969983, 0.02841171324102869, 0.0202012003865093, 0.014876705451658177, 0.029953382834191286, 0.022078715264797214, 0.041733888398495414, 0.007225498068897475, 0.04642603137800771, 0.04424665679013537, 0.0288026804675258, 0.010017977610621, 0.007690809819201429, 0.01449575003672151, 0.05576741641327258, 0.09649695588215705, 0.029340646560153658, 0.02061259726272716, 0.07098071983144169, 0.07972994954475472, 0.047788507260021665, 0.02073000215234295, 0.04256520487908875, 0.03882470781043653, 0.04205801636881886, 0.01628092546466618, 0.03853878081445733, 0.009889292076320179, 0.0682519606104301, 0.014598506367615154, 0.05650944534629103, 0.03946735981791731, 0.06908767826614842, 0.03431345734204497, 0.08701219749186309, 0.020591254053156705, 0.06221903352847984, 0.03877685412824635, 0.09065653903469925, 0.02241291537610514, 0.028647852182808905, 0.0908174098379189, 0.05446104498039331, 0.06258073428104963, 0.0427925989272133, 0.056277722901394295, 0.023655188232359868, 0.011692090399353015, 0.057319453091270504, 0.031171227061760523, 0.0271544135701392, 0.08324457708025172, 0.10622409683081413, 0.04604325937708059, 0.07413563078209277, 0.1101028229740839, 0.02890511025344172, 0.010862462185022813, 0.0498072715145686, 0.06294402849650191, 0.10520394350732527, 0.0018545816771708612, 0.03940978831040763, 0.36845507400651134, 0.07659590682916104, 1.0158267653276845, 1.4540325513770505, 11.582552213822643, 43.68173430042882, 83.84763640742149, 109.98340083706765, 127.30017877394154, 132.05661742917954, 113.39586288698258, 105.51855902517997, 98.08108622027983, 84.4070291519165, 84.14769772560366, 81.88839681686895, 88.87030201573526, 79.24741791140649, 73.45744256050357, 84.30240384994015, 74.82688319298529, 88.63685038781936, 72.8316205547702, 78.05535470285724, 95.9371579077936, 113.61611966163882, 119.63329438240298, 99.2456300797001, 91.67699321623772, 82.74290869312902, 76.18942045396375, 79.70344835712065, 73.25961389849263, 85.28079986572267, 70.66916296558996, 68.8688813486407, 77.93158823443999, 78.60594564868559, 85.8398788206039, 90.3098903163787, 79.6826127267653, 88.90745470600744, 77.3266097038023, 82.85889317912441, 87.05004768986856, 94.84257344276675, 84.20920833464592, 94.96484156577819, 104.3818247702814, 115.43795862505513, 128.38484748717278, 115.1678877492105, 95.56389731745567, 69.74560952955677, 35.81288314634754, 8.234846534267549, 1.7782784685973199, 0.1550464972012466, 0.04461047194537617, 0.03378128670456429, 0.021674228501656366, 0.07104546192192263, 0.03549450062095158, 0.032981326202711755, 0.06528206755437198, 0.08458205168285678, 0.03795902462555997, 0.051889720658260974, 0.028667762807960954, 0.019278466633911577, 0.04321464825601828, 0.006436483048263096, 0.051118576553680246, 0.025511639523169687, 0.06125672750415341, 0.003692281888722773, 0.034130684085070126, 0.04875939729953966, 0.04743449419977204, 0.06862325278381187, 0.06673217240360475, 0.04239940430007635, 0.0622794472221886, 0.05551265387405312, 0.005700543077827822, 0.045683738144655386, 0.05329509746403464, 0.028971775224612608, 0.04322516281277903, 0.03081793220893991, 0.06153265322228113, 0.02954963151545775, 0.02977186596141227, 0.06562214930571857, 0.014564444183281835, 0.0357946232261677, 0.03559075190775818, 0.062489730696524345, 0.01609055070026267, 0.006615806036748954, 0.015436819146176981, 0.01577257345836129, 0.014616993984447853, 0.04973875644106058, 0.02654020640728695, 0.027221678005110835, 0.12006765036212823, 0.055394795077342185, 0.03984926613948999, 0.056101572474524866, 0.02057114616036415, 0.029787206872095986, 0.015763974121411242, 0.0562239435291098, 0.019899580079401215, 0.08043010794227162, 0.2113914213353588, 0.12245907808744139, 0.19346790568482494, 0.07539592968720583, 0.07262318169758206, 0.1745708761436324, 0.14290890656411648, 0.11857121251523496, 0.11860993825980734, 0.07237750496114455, 0.10333396884943209, 0.10304507709318593, 0.21856968050762532, 0.08513417891076497, 0.11528165395101232, 0.21981895540750798, 0.17435568204570204, 0.15111059791618778, 0.10113134349305784, 0.19503817142498112, 0.2510833406760808, 0.12892833820754482, 0.12049258401196812, 0.12689594524882494, 0.12344388411410394, 0.22018332214605427, 0.1687593944370747, 0.11502574227990643, 0.1476901991953773, 0.17235354189911198, 0.09429689692032915, 0.15041195637276097, 0.06704311217031172, 0.16534464944514538, 0.24973953052634196, 0.17200955309935156, 0.141357593839207, 0.14112514744122184, 0.20667765169374405, 0.13247883397965662, 0.15026215554004715, 0.11461469014325451, 0.24265015287505043, 0.17281170844310717, 0.12473995166440165, 0.2607586174722641, 0.09650319949873994, 0.11439727439034371, 0.1710577654622255, 0.2938587945555487, 0.1358413164533915, 0.19413648593810298, 0.17069080934649514, 0.09244641153922967, 0.1362070621502015, 0.19929251813840484, 0.19843793173711147, 0.21093541515931008, 0.20492415304385847, 0.15868596642488436, 0.46739934372805786, 0.15266471452290012, 0.677656433995693, 0.21207570639108458, 2.8215415391229817, 21.292706112707815, 61.55524561482092, 109.51460699881278, 148.58468517180413, 167.06006849965743, 159.1413208746141, 137.19318082255703, 112.72846375742267, 94.61886498235887, 96.3675517420615, 104.02698363027265, 103.87062226572345, 99.31011384533298, 91.9244320161881, 103.17371122298702, 96.71338712015461, 113.90453938514956, 92.04569601243543, 90.09430900696786, 105.6227057979953, 133.04331318024668, 142.5803993594262, 113.97911148686563, 102.90043969308178, 92.22814113863053, 89.31231391045355, 95.16769870635002, 89.41815514718333, 104.20569466006373, 87.09291135111164, 81.83538206161992, 85.86447208158432, 87.50933370282574, 95.04800365817164, 105.20019592777376, 88.50736510369086, 96.67749743307792, 88.7789813933834, 99.41498233426003, 99.1998246408278, 111.27140522003175, 100.67714614252891, 115.75392123191588, 131.41887926286267, 153.6414989348381, 159.383331114246, 134.72775151652675, 91.08994776202788, 51.36125656866258, 18.01294961283284, 2.377488050729998, 0.5772982417575775, 0.3157826681290904, 0.12135812547057868, 0.22725319519879358, 0.21808828617776596, 0.3651973310737841, 0.23625675078120925, 0.15885473559460334, 0.14239138352774805, 0.28612829324218536, 0.10383923447901204, 0.2606066869151208, 0.2068553994139356, 0.17421982401321012, 0.17002034451692336, 0.13931276727347605, 0.08845756791772381, 0.18706278244574226, 0.12783480898266839, 0.12642211220677824, 0.1849878179810701, 0.15314411702415637, 0.12891906854366103, 0.2617394245199619, 0.17276903734572474, 0.1555504604813553, 0.1194467207777404, 0.10968790209341435, 0.05275411298498512, 0.14352812011155391, 0.2154420039826824, 0.13556051458562576, 0.17525312340547963, 0.1628624479616842, 0.18873418711366194, 0.12180229558819726, 0.12558222703275182, 0.1897052495229629, 0.11971544909981952, 0.16675089576071309, 0.11248599227157333, 0.14725619506451393, 0.12619982413466901, 0.1539229066862214, 0.16352722841885783, 0.09089688379918376, 0.11996693278272307, 0.15530923471575783, 0.191366066855769, 0.1492752351107136, 0.20441111928272634, 0.16569098247395408, 0.11465792814570089, 0.1630671006897765, 0.1722281026623903, 0.2034427994681943, 0.0985276251430473, 0.17377195369091727, 0.07834758218978682], [0.04007156570291808, 0.010191414171018669, 0.03433999462774204, 0.09370489481596217, 0.04512652026249036, 0.0786461036712412, 0.008059963170859602, 0.008373935688136807, 0.005056426884801758, 0.06683153400738394, 0.0443582681398238, 0.035440759553063306, 0.042232990850724524, 0.01311418132841467, 0.0697475480997274, 0.02632633572624576, 0.04798138904715738, 0.09451658029349581, 0.04968178631257146, 0.009207181752689425, 0.04233165531449261, 0.06786447333832903, 0.139313364822057, 0.04032590306333957, 0.07337524255196895, 0.06619385774097135, 0.05205169079765197, 0.04442312514349338, 0.012604927253578941, 0.009127684808786838, 0.03160778801107118, 0.07828385899624518, 0.05566544628011123, 0.062398056785065326, 0.01609724247828126, 0.04670835009986355, 0.08756929663039985, 0.0093070441864491, 0.03525561525396282, 0.05980435886510438, 0.04511345846338138, 0.03778892246285274, 0.01903813719118555, 0.01733505287237706, 0.05134884343152085, 0.08816448566053184, 0.0722763047463471, 0.03480602506427996, 0.03930488406049629, 0.03856971161440015, 0.0584319468227125, 0.09201437625433169, 0.05929631616679892, 0.055468975371050264, 0.07071213706606819, 0.03138625070512776, 0.045171401523534334, 0.08611192160676565, 0.08828476912552312, 0.06437690402831762, 0.052409427045213605, 0.06530110483929034, 0.0793733432768814, 0.16706496116615113, 0.05407502859710686, 0.027881283538355946, 0.6313922003872934, 0.3894740445238929, 0.15403287094687262, 3.970041188501543, 17.024524096519716, 37.536192171035275, 74.75736310405117, 104.65353519685807, 125.10041159968223, 113.35026141135924, 114.25501100478635, 104.45427094736408, 106.42061787266886, 105.16987600634175, 111.0045506877284, 103.51082324981691, 109.53781958549254, 113.48468888190486, 106.90391663582095, 139.016878989435, 87.40600278300624, 58.495624296126834, 94.70352542015814, 105.61377063874276, 124.94880414778187, 104.80312655048986, 113.59251483794182, 104.29397152316187, 111.95973411683114, 111.82449863803004, 125.71707879343342, 116.73754184476792, 123.6807175605528, 100.76721945116597, 90.92555338336577, 122.86850452423097, 117.50769138336183, 110.99818075856855, 109.92159212789228, 114.46491272218766, 115.40614035821731, 109.69583619025447, 101.11148588119015, 81.70096243581465, 35.62056149205854, 13.882811492489232, 1.41891471320583, 0.2868112453049229, 0.18471905901547403, 0.3440194432773898, 0.05149305948326665, 0.05359911562634572, 0.01725130797093434, 0.13905790514282643, 0.037558552163142356, 0.05508271767006767, 0.08271177058979388, 0.044776958173080805, 0.10763664804999867, 0.11049636234078677, 0.030798812569569678, 0.041456867174635974, 0.039834139733425075, 0.03972864176537241, 0.0632440017145728, 0.01682005026527951, 0.024850687590397658, 0.05635013736243691, 0.07613236234793741, 0.04269188517824777, 0.023879646248514616, 0.04323212655201074, 0.026954878309381106, 0.06489007568527615, 0.0688835541387239, 0.03558815103925524, 0.04367583701687475, 0.032192309266857566, 0.038032450322662635, 0.016551576667435227, 0.020166084831280094, 0.04403500201841516, 0.041567540066617156, 0.06534796643761859, 0.04484489868064562, 0.04848033062092239, 0.052449152534527164, 0.01763346518630222, 0.03393245117378331, 0.02998715390511338, 0.022688798959397023, 0.054421032208108136, 0.028894905962290305, 0.06525307112643797, 0.03293739489069389, 0.007591320374499887, 0.026241221442638386, 0.02852617635301525, 0.00537584868124536, 0.02602228308997808, 0.0832805832126929, 0.06430531311179362, 0.016318096050752268, 0.10957268246960257, 0.0655210180388343, 0.024045377879613833, 0.08112241393856465, 0.07351692285268538, 0.045104943396103, 0.020173600153817285, 0.019587906783506758, 0.09228273685420714, 0.0302481179260799, 0.0733643334599272, 0.043186417916008545, 0.042788852757263574, 0.008869699912235863, 0.028705052137675307, 0.050998699115288836, 0.01725661312980998, 0.019726461445492123, 0.01624776343364389, 0.021210551870265798, 0.06200077124841272, 0.021943491170062654, 0.06966564563974258, 0.046324654962987676, 0.0931209289739209, 0.02557211450391239, 0.06738173835460218, 0.02787332580004248, 0.007908092464335383, 0.05165921629316384, 0.05658172574194689, 0.061731418564675324, 0.011945714340395024, 0.030129805222273837, 0.04022850264464656, 0.008386441115890781, 0.028173873584056576, 0.11839933302854339, 0.06892994842341832, 0.0395565745871394, 0.034001678709060915, 0.007619999354750279, 0.02298493216174745, 0.025475484003583272, 0.06543106399476528, 0.051583974967680635, 0.03732827379398289, 0.008388968248431002, 0.034759063874521566, 0.06593967742857433, 0.0328902728224714, 0.046862988777819185, 0.07610290626724882, 0.025439703867079753, 0.02661578289623703, 0.03256428708893157, 0.006053267195144849, 0.04387745220634726, 0.04197860752502757, 0.148503432170518, 0.07830703315595466, 0.04959452123711667, 0.0064977049647319705, 0.04341067483408317, 0.1032577277792077, 0.054937260555884534, 0.006969085567811084, 0.042925622434385365, 0.03707297882365604, 0.08850121194677008, 0.19293679224867977, 0.26491945549365015, 0.2517053887488381, 1.0239875629063577, 1.8451836849412613, 4.384192978182147, 20.70696092421009, 45.00069402879284, 75.9707953852992, 109.19015638289913, 126.93004823500111, 133.48178709706954, 135.3278741528911, 137.0704420151249, 125.22780233813872, 121.55179623634585, 120.92887678454001, 124.86623825565462, 118.33057326655235, 126.75158039216073, 133.93585635769753, 122.37973013231833, 154.04873509560863, 106.56867950193345, 76.44351159372638, 119.35835192280432, 130.6415282526324, 142.5916644065611, 127.07247734069826, 131.42548453423285, 122.99737007387223, 129.32916595089821, 138.43843921538323, 146.3546137655935, 135.0755088560043, 144.5873192817934, 131.78145531685124, 123.59211906310051, 138.95228539743732, 135.315761873799, 127.55683514379687, 126.34519146334742, 130.8926619252851, 132.52756857102918, 132.57437029192525, 125.42436015221381, 109.50788405633743, 63.879846142184356, 36.43878359948435, 8.941948875304192, 0.8252905861985299, 0.9832697445827147, 0.17761477329317601, 0.19339535715839556, 0.1952945504097208, 0.0187711727865521, 0.0693898693087601, 0.06627033629845228, 0.019710942419366013, 0.07594224996864796, 0.036985813339631406, 0.014529010701564052, 0.01755242840567183, 0.009503900054692021, 0.024252349938896876, 0.04091434285885865, 0.052300914521178896, 0.03933093871080107, 0.04598739241520244, 0.0667106836373287, 0.042380167832297665, 0.015614153178889426, 0.018325813317431078, 0.05849344836127374, 0.05259311194681833, 0.01555948131417315, 0.03826738650640173, 0.08401664815122083, 0.07413271198710127, 0.011167867924086751, 0.04977674674122565, 0.03320475191538853, 0.035935265477746725, 0.034709712490439415, 0.03314356447287625, 0.015230473363772036, 0.07263121029902851, 0.05068134719265565, 0.06424855365748368, 0.02136510819376957, 0.017296367347420707, 0.022067719987863978, 0.01558289296113916, 0.029949640494681178, 0.017551827026651274, 0.04509999829855177, 0.02285139920610574, 0.039919489589069164, 0.048757899597647696, 0.08024673713671585, 0.0959418255895857, 0.054993564187879526, 0.04953344870779303, 0.0985185853055408, 0.01751453578171711, 0.022357207377471273, 0.05811600450185999, 0.02573296615493394, 0.07348182070399485, 0.06712261677509354, 0.036994362880866376, 0.03471017214319399, 0.01944675508345808, 0.14810535756330337, 0.11247133700958184, 0.08302429615850411, 0.1503506080517846, 0.10873056031883725, 0.1410602444722768, 0.11110084401744028, 0.21430879140332823, 0.16029530264917882, 0.19552126647003237, 0.12954928311369113, 0.1657900989295975, 0.11238883700101607, 0.10576686491408657, 0.13695153107325878, 0.11591991244424736, 0.10177686449981506, 0.3185206050834348, 0.17318680041259335, 0.1032503886568931, 0.12947748535342757, 0.20994795846842954, 0.2661258294697731, 0.13964083676616992, 0.1728365909788878, 0.2109915081171259, 0.1801098450537651, 0.1426958421906156, 0.17362674938574915, 0.1133470980811023, 0.2660270654145749, 0.1789727407477556, 0.1550373654331892, 0.18285600979241634, 0.08419954398226354, 0.08755007548437965, 0.15162948458906145, 0.15068433127335965, 0.14574565353893465, 0.26530930231655797, 0.09592380720160662, 0.13779778243793597, 0.14879379481557878, 0.1777294719771993, 0.18757193980197753, 0.2254393288204747, 0.12640394826209353, 0.15293661444898576, 0.11418005782029322, 0.12771490090076001, 0.13991302780566678, 0.16054806569891591, 0.22749705630685055, 0.24809103188735826, 0.10524574892535325, 0.09413833204176157, 0.20163233452025922, 0.275727546503467, 0.22409271478893297, 0.1510509503104033, 0.24293625607125222, 0.11772227218194355, 0.12623054426043265, 0.44463406046552045, 0.23313494248976632, 0.2188263199622593, 0.6900716548965824, 0.41397053327771927, 0.6934141271537351, 7.5013883171543005, 23.312342359173684, 57.33017829156692, 103.59724875419371, 142.79682005605392, 172.7001073283534, 175.2315422796434, 173.39571614419262, 160.84559071448544, 158.58098676127773, 159.03852339713805, 162.0958383621708, 157.37106107896375, 167.81926678073023, 170.93119682804232, 161.0911310872724, 187.86239008749686, 125.83331431111984, 86.09594683493339, 135.90041468220375, 156.01061051891696, 171.74148005823938, 158.43535700151998, 161.7166079244306, 154.10291087242865, 163.00708340060328, 170.2989892036684, 183.91689362064486, 166.9338466275123, 183.99433689732706, 160.77272876616448, 152.91923369130782, 173.96717409933768, 170.41645634558895, 160.61953667671452, 162.19610983325592, 158.05645604287426, 156.56586124051003, 146.885859581732, 132.87854225404803, 103.08191207147415, 47.03378792731993, 20.261342410118353, 3.017747320475117, 0.17953272037688764, 0.5361173998924994, 0.3979570280400015, 0.2710400996429305, 0.1735532355885352, 0.18799512677135008, 0.2193145937616787, 0.319503128168083, 0.17160265315924922, 0.26010450095899645, 0.19832212988647724, 0.24682455065269626, 0.1326838391081941, 0.20414289657867726, 0.19903894303546799, 0.18346924785404436, 0.14733861080340802, 0.10133631031719909, 0.14609299780380341, 0.14338423347761556, 0.12071387616977577, 0.12456147616068203, 0.10381594540611391, 0.11436850012790774, 0.15861870390513252, 0.12913115232461883, 0.15117592989437043, 0.147862461726031, 0.15801971507889612, 0.10511045013704609, 0.16800913388930983, 0.10101428525822778, 0.10758954130353467, 0.12076227760483181, 0.13181947742498692, 0.08873352810980813, 0.2101236683947425, 0.1377037374843513, 0.18748336471617225, 0.15811409711116747, 0.22196832233138625, 0.1862790898209618, 0.09409823499980474, 0.12123890686780216, 0.16744313280909293, 0.14871867223372384, 0.19880988274610814, 0.0997986339573418, 0.12511972443110522, 0.19960129753716532, 0.1813819646955498, 0.1523983610733863, 0.1209997188960833, 0.2180002013882322, 0.13951504512900306, 0.08442379323945892, 0.14718995910258065, 0.22970334356350286, 0.1719772395107054, 0.11157185785592565, 0.20187743669075353, 0.07591033474572244, 0.06943397299056092], [0.02369795892117245, 0.05229020844243708, 0.023968941456968748, 0.07866858835181884, 0.032264716067020936, 0.036444012976942525, 0.05147232914403562, 0.013849587431327711, 0.006608544959641633, 0.009539114243741478, 0.03358858494809078, 0.053563285694127126, 0.043932449658431356, 0.07909949748746811, 0.034792109077135404, 0.0643347691924822, 0.021813719706129164, 0.033783642424931454, 0.10646795027799184, 0.011741590212970492, 0.024061314423658678, 0.031041599239312836, 0.0473134829512527, 0.030420914803060795, 0.0453345476078891, 0.05841620371586854, 0.04550288010749125, 0.056187305374131094, 0.027917580784208355, 0.014115956202600033, 0.0017311797555228097, 0.045970124793389154, 0.09664907030040219, 0.07396864659723736, 0.03710455313745526, 0.011712116895303612, 0.05066594116449837, 0.04825639162933634, 0.028666362782279332, 0.03815863266467087, 0.035730245027450785, 0.07539357013639904, 0.016687459597784667, 0.09213888086378576, 0.04007362264899477, 0.044788204343809236, 0.003791853209071222, 0.06899805363988684, 0.01799823986666818, 0.011810947983195225, 0.021483729247965162, 0.13141047840397205, 0.029907630148133444, 0.013804393989454596, 0.025874571762077754, 0.05567187375779595, 0.05427021247845504, 0.051660480338238904, 0.13766282838919472, 0.04114873895061113, 0.008487101238701613, 0.057870848705210996, 0.07570274790088016, 0.03291690969959863, 0.19844786023661015, 0.0543509045195195, 0.18967903399419403, 0.03544932824649638, 0.023804694121222825, 0.1651544604570635, 0.40169041964315605, 0.5518274730251682, 0.1141053336041589, 0.5616554617881775, 8.608968084858311, 9.620436545341246, 15.780205111349783, 28.524760469313595, 31.832538381699596, 55.244916869748025, 47.537310431080485, 57.81992935365247, 46.09233671619047, 31.02500669417843, 32.3636959445092, 13.641044439808017, 0.5914706844956644, 0.8043371008769159, 1.9256840814505856, 6.956832918428606, 25.29824818334272, 22.555240584957986, 26.788890054149014, 49.810775018507435, 39.37523857239754, 31.31388729618442, 32.36303698632025, 18.298253013241677, 10.794002836750401, 2.321010578063227, 1.0536145731326074, 11.847758370061076, 13.321490903054515, 15.268631942810552, 15.524758792692616, 8.125040761886105, 4.428424566022811, 1.6317305064970449, 0.3243129958789195, 0.2614839801624898, 0.8783326754646917, 0.7881638203417102, 0.11966622795068449, 0.18722035141000826, 0.10078659626625239, 0.12646710455057122, 0.033931336515853484, 0.033156109162636345, 0.06190944590695924, 0.02474698801374724, 0.07089952983322644, 0.0302803146863176, 0.031049407590481064, 0.02994085538140949, 0.09077489195812134, 0.021022929276730266, 0.02165539423003793, 0.012955378004980665, 0.02143906057632018, 0.08405835397781865, 0.037784314443988186, 0.08542025146344978, 0.04166253113878831, 0.00879228481226751, 0.04572152543152052, 0.03798539337191371, 0.05466526103836875, 0.024249524989676093, 0.002667030010695359, 0.06858268842822121, 0.029680952392218095, 0.05071035511190853, 0.009492932548446041, 0.017843959334817146, 0.03876317562835832, 0.11478581120290103, 0.06736404938443054, 0.03827684769226659, 0.04360213552811935, 0.04740458995764775, 0.06731045387324787, 0.08012951802342169, 0.01518077340968434, 0.04473507614626039, 0.04185290398797201, 0.023982859359333114, 0.042343322833579396, 0.055045995245417284, 0.09384643722085223, 0.01993330135460823, 0.007023877612570482, 0.06433592598524786, 0.03564243986000938, 0.09607546196709718, 0.04067144702158628, 0.09713854685786272, 0.027586081132833517, 0.03194654634552858, 0.10671401005839148, 0.07157767086379951, 0.0745043718826867, 0.07320639677345753, 0.035917427120429855, 0.02539197850461689, 0.028507294200901544, 0.028014385569540244, 0.016275727558099938, 0.08960745823118957, 0.08157724800008921, 0.0643268938086206, 0.05070211200584328, 0.030886236608268756, 0.017032164689754287, 0.034668033476918936, 0.023583949716281027, 0.02938790652420252, 0.045561803760187286, 0.027512490726827134, 0.059129297507986914, 0.03878315520142356, 0.03107987873766932, 0.04853112991118143, 0.04499454629577456, 0.020683383786930673, 0.0512410740127727, 0.03203948238684285, 0.049703504905224814, 0.016461593895069054, 0.07725592988032488, 0.04495386702699527, 0.04807005989395323, 0.01796655255490013, 0.05774542862068742, 0.07485714005005938, 0.011899115127180854, 0.032188091952834404, 0.03548956318427959, 0.07970565689667579, 0.04901912025806885, 0.04162335340234061, 0.11675742274570851, 0.038164006771459695, 0.03659254593414165, 0.005821398714737546, 0.0100598213330452, 0.019689445992210702, 0.018998766017536965, 0.06737872762905975, 0.02789353902992462, 0.04098453949536047, 0.03796695363557628, 0.0342556904821146, 0.06179653603823916, 0.08273499837565808, 0.007147280013023486, 0.015520943261142221, 0.058230549968298406, 0.07421076102482696, 0.11651717757265415, 0.10827770276415734, 0.051103323743107824, 0.05281672152059694, 0.0264665681207853, 0.0719826096188157, 0.15423407627930566, 0.05200916525697516, 0.027543092108962518, 0.019832489929432352, 0.04041788724040793, 0.015532184643821131, 0.15171357039963046, 0.022601351938060215, 0.1121587195103207, 0.3487483814599053, 0.25087133350391544, 0.18540640842289696, 0.6303570010969717, 1.2481003951641823, 0.744839770899665, 7.384610531791565, 26.808445030643096, 30.343567440586707, 42.09695162311677, 64.4694999725588, 68.7502924088509, 88.54066602645382, 76.97576153662898, 87.95583278902116, 78.65699921884845, 56.66739579169982, 48.53759719479469, 23.541161667916086, 1.311074048280716, 0.25806995529320936, 2.8799951509121926, 11.667758841668407, 34.205515461583296, 33.23346584073959, 42.62727175989459, 67.15216975058279, 60.72011809195242, 56.51474498933362, 53.780974572704686, 33.012381445977, 24.424893240774832, 8.152481663611628, 3.8142730824408995, 24.671451468621534, 27.234365401729463, 31.28917440291374, 33.69755675715785, 20.364924361628873, 12.661688423925831, 6.065295338630677, 1.9367027547090285, 1.2113130981883695, 0.7138139454107131, 0.5846357706093019, 0.18392539192591945, 0.2203690831459338, 0.05155238916256255, 0.010217965820864325, 0.09171472096274938, 0.08368774362268948, 0.053326441951456575, 0.07157335778878582, 0.12484981633362272, 0.04504147301157636, 0.024950227309619228, 0.034335126138983235, 0.09050613299252526, 0.005303569243199403, 0.04384010925047821, 0.02689876428414737, 0.022190374494980902, 0.06073128311864792, 0.09142567598891836, 0.10858160218284016, 0.002692056666766744, 0.04613249329850078, 0.05300941944663083, 0.04628417870750831, 0.13222058574038167, 0.11292608680143473, 0.036414487948340755, 0.01804057771580354, 0.06538794090550754, 0.015082981328540032, 0.007763400001661673, 0.08125366778263161, 0.019829599862738002, 0.019061780579748656, 0.00841469539614815, 0.02176259865894193, 0.026010046750607512, 0.08340392336850205, 0.03284035836376491, 0.025263622388123505, 0.03622498460895112, 0.043810848522210316, 0.045192499584969015, 0.030168663117013154, 0.05877307045363611, 0.07238330424673135, 0.06708064281772222, 0.03260200542788352, 0.08046825912090079, 0.015938367334104354, 0.06067695216305795, 0.06937877635561651, 0.01108100504479221, 0.026491414267389525, 0.03278235784701763, 0.013120879809702597, 0.07361753317978113, 0.015070175211275778, 0.07737810558248913, 0.09428214972778674, 0.01602307559111186, 0.01945972303679634, 0.01442208493714251, 0.01546679137860455, 0.12835849902682728, 0.21024926084904902, 0.20014088390575302, 0.15467839195362984, 0.10234209949210768, 0.11784661591293351, 0.14821587340726008, 0.09825143512458571, 0.08560518508837109, 0.08958099755428492, 0.11660798197431911, 0.14565121021962937, 0.21921538537548435, 0.18034690330105443, 0.21389205489427815, 0.24142133252274608, 0.17451246960028527, 0.1653513144100866, 0.23181832846133943, 0.10748255712490891, 0.16065462852918333, 0.14316386062531702, 0.24993975526623188, 0.13555988639352784, 0.1649800528802218, 0.1879082370789782, 0.09421703225422291, 0.0844630552455783, 0.11455756296674091, 0.1345169342934124, 0.1627808902412653, 0.1540769822895527, 0.1471745454135441, 0.15178034262311074, 0.25611728910476933, 0.07909007460599946, 0.11771315573564461, 0.14316511700951284, 0.1422321598135656, 0.07479327129981211, 0.1292370256757544, 0.19964032205602816, 0.0772325412159966, 0.20684516447926724, 0.12867350672041217, 0.22060502290485368, 0.12504155281931162, 0.3118639138917769, 0.08915204960372179, 0.08546466924129956, 0.21568494578523023, 0.24970291152356133, 0.2785613363788974, 0.1716716623594684, 0.12320672627538444, 0.09899391987991911, 0.21271393424080265, 0.17397888936102393, 0.20251102204765045, 0.2314591098336443, 0.08631572397726198, 0.09649070460469493, 0.1790285272704017, 0.35063347869342376, 0.24563570476828084, 0.12556534245490067, 0.2897950351959275, 0.2752086904741103, 0.25728517482357643, 0.6459990456219643, 0.4941036365926266, 0.7174083073773693, 0.10646424241243832, 1.8347478513756108, 11.880031631838891, 18.089500550300844, 30.590094289472027, 52.447305956194484, 62.69358804149013, 80.00023057383876, 65.0973302318204, 80.61913351858817, 73.01592488442698, 53.79323197949318, 40.88523341763405, 18.914875099735877, 0.9839137487353818, 0.7034476726285873, 1.8680406842500934, 9.56495559984638, 31.42089543804046, 35.15797284341628, 49.50153143175187, 72.00414165373772, 63.68181743929463, 60.46602302981962, 50.230574530939904, 29.30112108107536, 21.5404704693825, 6.940966931081588, 2.5336285368088753, 17.918502861453643, 19.09113464816924, 21.798840915003133, 21.74709308531977, 10.90695042763987, 6.067072172318736, 1.9287153381493785, 0.3993064765968631, 0.4737566477589069, 1.0160766325650676, 1.011788562661217, 0.16710763226353353, 0.1682913147153393, 0.20313038881267273, 0.29373952998749675, 0.11283552754790553, 0.16882656502627558, 0.16931925149213883, 0.14732097545939107, 0.2003795356159249, 0.13114173476013447, 0.22148876661254516, 0.10439890767297438, 0.13986131687077785, 0.12572066678154853, 0.09104414121998895, 0.19654840651539066, 0.20004199727648692, 0.3646866875069757, 0.16970401149122946, 0.19916674182299646, 0.13401150012448912, 0.15067283995449543, 0.17139200962358908, 0.16904419528380518, 0.28137716915338273, 0.18398111716153162, 0.15909122693682873, 0.1426316440225609, 0.1028414202793952, 0.19439920813085573, 0.1329317911257667, 0.1239678729325533, 0.11813483351180631, 0.13646477412792946, 0.13522458503082876, 0.098081570449135, 0.0670986612057013, 0.14434579639665543, 0.12537922905457596, 0.11357595918760185, 0.2017083917293818, 0.1487605619214235, 0.14639865156383286, 0.14085320154986075, 0.1836979097776836, 0.1360634513079159, 0.14379173096629883, 0.09345446833439412, 0.12521629747484, 0.13358793011115444, 0.1953602347883486, 0.21393918462337988, 0.1858328742485854, 0.2682059420452964, 0.2509923294306763, 0.0721983093347761, 0.19925439760329264, 0.16323409253551116, 0.19372727241246931, 0.21785462936086042, 0.19957615453149044, 0.15478998032068053, 0.08883845917279683, 0.10060702525680104], [0.00709817425588206, 0.017833050242775393, 0.03709692673216905, 0.029106150876971024, 0.043889062268839735, 0.031021410907288233, 0.03692207099389165, 0.01247783326694081, 0.09797231098937412, 0.036793525270637006, 0.07700743394032603, 0.08666872963189118, 0.05122752574783179, 0.024016672565091043, 0.023714169341650222, 0.106554027917164, 0.01534682775532166, 0.07209799778197082, 0.0372444101489119, 0.08504860688962283, 0.09805185389855216, 0.052594594326951814, 0.02128283418114147, 0.0634186084742748, 0.08266403565123197, 0.003991778456463269, 0.028713260769783974, 0.03137286714909058, 0.055478727670326355, 0.03684769534776288, 0.016036018646592577, 0.030855614158715454, 0.06007063953626541, 0.0247959295407899, 0.05650556511095455, 0.0262246145716598, 0.05773491406392667, 0.024474948276615432, 0.01565207836158093, 0.06177803501486779, 0.027399134611891165, 0.02233224057201897, 0.040459792249866074, 0.034624573308974504, 0.023957482696841323, 0.06132545325184061, 0.018648135235473033, 0.02444836119520328, 0.03268435604930405, 0.011087378896322223, 0.0828402741782127, 0.038069996291831616, 0.011416259484605925, 0.052642153065291145, 0.0350715741214733, 0.08317100199600382, 0.02974291549875371, 0.01571506228027565, 0.11652733589853011, 0.05998812037550154, 0.06575518047376987, 0.029271920812466455, 0.04587355558009398, 0.06513551493445713, 0.056538430282906185, 0.027530470810409997, 0.08048340467916382, 0.1297155088715015, 0.04193599771467909, 0.02180794340318009, 0.06819204487387212, 0.18871949354727424, 0.2603737348991056, 0.10242669858158597, 0.17282015073203272, 0.4709960039584868, 0.519046264310037, 0.5511213238200834, 0.7367589529002867, 0.6754598454121621, 0.6430387593084766, 0.6742302436501749, 0.6992660583026948, 0.503351298431235, 0.8069364065604826, 0.4948773853961499, 0.036138968256812905, 0.23742782342578136, 0.17603992634723264, 0.4574991894825813, 0.7068880202789461, 0.6090057016380372, 0.3709954215634254, 0.3349811379467288, 0.5456093518484024, 0.7062267331827072, 0.6378920580590925, 0.6688508968199454, 0.2706550638521871, 0.1286829602453978, 0.07175499723563272, 0.35144681892087387, 0.4065240054361282, 0.5861852294014347, 0.7074110438266109, 0.4466339789571301, 0.38319420730394704, 0.07155468056519186, 0.02055319863551807, 0.26632838311695284, 0.34062806396715106, 0.3673009472268243, 0.04519520770578135, 0.10520275607104264, 0.055471652848345626, 0.05734276897724598, 0.0910305661419707, 0.04812260203424001, 0.017308745413057266, 0.035933124261998364, 0.06195907691313375, 0.05866057427239515, 0.03356759030852587, 0.031642587555031625, 0.010086536734184672, 0.025126827813144174, 0.03248782768364876, 0.025630586164733096, 0.00717514694007414, 0.030232702321823568, 0.04404524844440241, 0.01753857753600084, 0.0402252889058042, 0.036925767368126305, 0.07781039367640212, 0.02467764365006118, 0.06753782110829508, 0.056455788548074426, 0.039709776850237, 0.04549487831912214, 0.025814351505569877, 0.056831321018117095, 0.03231464584748591, 0.009571740970826678, 0.0714372086428827, 0.020273492273484028, 0.04291881191273851, 0.01836413112018378, 0.014389644943988852, 0.016092555935404474, 0.04528798861429096, 0.032049872454315904, 0.04432281359068809, 0.08820930180410225, 0.011986978708826488, 0.008580523745847807, 0.09433701694492372, 0.021399668335253676, 0.04060846310289156, 0.04709325948609941, 0.0313679488646167, 0.04965088998658523, 0.015820500876514182, 0.02697821909321412, 0.028478577395059892, 0.026889492705043767, 0.054699597099135, 0.07672236496282202, 0.0271074868543374, 0.03461287514637074, 0.01694224895008149, 0.05046922510730163, 0.014210800760455672, 0.03465502530396466, 0.06042697767336523, 0.06659935574017226, 0.02780257374979556, 0.04022900443223696, 0.008938112521484014, 0.020746325570789557, 0.06279181448682662, 0.03524506239280586, 0.01648018301855172, 0.025873227277770642, 0.08892515734318765, 0.014328744784448177, 0.027242770320886088, 0.008191809775457989, 0.03138425696130482, 0.037294623381908865, 0.021778286224411383, 0.023045778695133426, 0.021003859433075114, 0.031283376588215756, 0.028706900324792634, 0.04403981688101927, 0.02555384139169849, 0.035831621442470825, 0.03614566769571074, 0.04688908939339942, 0.03889722569334892, 0.0046789145562797785, 0.030735543283123164, 0.01330730347563663, 0.0754185829071268, 0.03266261830445259, 0.046684789065752304, 0.03822587603222459, 0.019074599145941677, 0.0685003569589988, 0.034318862092350765, 0.039712898658528444, 0.07284628948377025, 0.056146583970515966, 0.011131775606754086, 0.021674010166597944, 0.009773661637859, 0.05858882630784666, 0.03878268405735012, 0.048331575498225234, 0.03649896829419079, 0.00836562842220789, 0.07125733119826164, 0.07990339951169106, 0.05879933960855969, 0.02988007971115651, 0.030337359508379336, 0.04484401001865345, 0.10776196471265248, 0.03784917527809739, 0.019476381618709817, 0.037816865519890865, 0.05281942581096965, 0.037795039674928116, 0.07158963715717678, 0.0712930998434463, 0.023257755223781835, 0.024866574338727424, 0.0319727331460003, 0.05883213200215852, 0.08070015393558048, 0.018231626637580416, 0.08400783814009159, 0.11416955475485134, 0.05654830515625016, 0.03039683665960066, 0.0749208402609633, 0.1299445538391029, 0.30084551642498664, 0.25142064918914153, 0.0770953425296372, 0.4254334456016941, 0.42626606060131905, 0.866777005214845, 1.2096142216074852, 0.7687781799224116, 0.6087467026325964, 0.4894082530611946, 0.19212536724104037, 0.415029205502041, 0.39829968384677367, 0.5659997931891873, 0.05040953919712094, 0.12202692022847554, 0.03074126212947792, 0.45136978128744715, 0.3000281925403303, 0.4548246846083672, 0.44101512239825347, 0.11396783614350904, 0.22145384832495646, 0.4035437089060584, 0.41035836742770293, 0.3921245248808015, 0.3515108638713437, 0.12558976533792673, 0.09437912113724217, 0.3687335316452288, 0.2093560942598889, 0.3267008919389017, 0.3029781213450817, 0.37957713849121527, 0.3997713387493165, 0.0906528618126627, 0.09983674683157476, 0.20895645683330877, 0.08825830844861847, 0.19610591413032627, 0.0605278944356307, 0.09880088104475891, 0.03625575069999022, 0.08440378302287671, 0.056456194574674295, 0.11760132222045815, 0.02999682001949799, 0.035663262129791325, 0.027188960305084626, 0.028566503221349373, 0.10376164509404091, 0.05403069891936837, 0.06385885239128145, 0.039076972903022845, 0.06175420584998304, 0.10667526899206062, 0.08756069346301018, 0.03424275891795274, 0.04058941432665433, 0.03481692649544247, 0.03314762473887494, 0.0263602408625546, 0.07889154292042218, 0.030976368767780163, 0.06405609321870631, 0.010442851888646763, 0.07996185202031367, 0.03579219089700811, 0.037690675517003384, 0.06530292046767089, 0.00997369581337778, 0.007665934465495089, 0.043042830056360656, 0.008159414789969883, 0.01582594680404591, 0.022792006324556087, 0.022301870931480682, 0.05526336120261301, 0.03595581195587593, 0.015953763786162582, 0.04149179312310392, 0.03473092163462312, 0.11063940627800842, 0.026111055443423892, 0.06967039538487312, 0.03580785356462002, 0.02013853439430316, 0.019721817037451173, 0.03946280542520746, 0.014526355249296515, 0.12292629212982233, 0.03981029524678185, 0.004433529412058453, 0.033660846191548535, 0.038173280265783115, 0.058940813065536564, 0.04110120319490952, 0.02943344279042175, 0.06630849513796068, 0.0521794819243012, 0.031970302732060515, 0.014262418807183784, 0.026174600521523147, 0.07531487758481696, 0.09204617656406858, 0.18278836422870237, 0.1370711633635144, 0.12464953030669883, 0.16594417453292878, 0.115054156481018, 0.11610047936800028, 0.10587096860211705, 0.21839675914135673, 0.06429290248742027, 0.13270400254236114, 0.1769673370666081, 0.09559558449132789, 0.14195164905921107, 0.09152661573382155, 0.21881669789793032, 0.08437429629867116, 0.10293030180037023, 0.1564321051081342, 0.13723049433000628, 0.15068217090541317, 0.13984185823750112, 0.10608738077984703, 0.14908313090282102, 0.21586338298455363, 0.1469405208744349, 0.14258305872640303, 0.07564097057066618, 0.1913717205846502, 0.12894770491027063, 0.10709903052737636, 0.16839678970075425, 0.09304268075333488, 0.14631968322059802, 0.12123566631588245, 0.12874501336726452, 0.1444611385945351, 0.111623392590592, 0.14166186864097274, 0.09889886369027438, 0.1049063872966555, 0.12606156824697412, 0.12120215763007441, 0.23155248062985562, 0.16604476187738682, 0.17913374178592237, 0.19693436161164316, 0.13618562701008013, 0.17126611073411283, 0.1445023541248614, 0.22098036002247567, 0.09699042375770309, 0.18205409959679653, 0.12593611368849394, 0.11212643656519153, 0.16952961923614626, 0.10611111418374124, 0.2315708054530044, 0.2266295689849123, 0.25006053668837397, 0.16723647293063904, 0.20717565480980182, 0.17568622355259236, 0.3365782474077517, 0.2057129937794901, 0.13907244549162928, 0.2180420451106564, 0.20630148720116387, 0.13501505998353805, 0.11486381427535128, 0.1827431956846868, 0.2738880774667186, 0.3642854412957546, 0.16048844873664841, 0.28137790459779005, 0.5152932914995378, 0.7303512709275369, 0.8429188209195292, 1.1769641671449909, 0.8773332065151584, 0.7383587896343201, 0.8510622129805627, 0.6939754550976138, 0.8175255189980231, 1.0137162237398087, 0.8715102641332535, 0.18035667858296828, 0.37592446191176293, 0.24539856991219908, 0.62524811394753, 0.6767870774192195, 0.7809462302154111, 0.7403033659342797, 0.4384892692248668, 0.5792595494178034, 0.6735277103800928, 0.7340367054266315, 0.9128755186834644, 0.5743699472758078, 0.1819337012186166, 0.15839201848833792, 0.45661880123999815, 0.5406913738096915, 0.792377120064151, 0.6774263011832392, 0.6427282791945242, 0.6077470498219614, 0.09304275736212732, 0.151422334414336, 0.24280520907092482, 0.3302840077348294, 0.4419415984903613, 0.13556448292107354, 0.18658610721749647, 0.34526813595045003, 0.18608237376376507, 0.23270864520342122, 0.31219841852303476, 0.11878129680671039, 0.23263922231572293, 0.16000783581647182, 0.14229064296570518, 0.1428787686651753, 0.1347738648614576, 0.20005495948416574, 0.28931497385905636, 0.15942562431577714, 0.09930905780845112, 0.1341166227094589, 0.20834329538047316, 0.14256407506763935, 0.1270746199354049, 0.07778374147751639, 0.22372571270792718, 0.23560192946705127, 0.15301023549850912, 0.20045565411208138, 0.13138456931037287, 0.12217764036669848, 0.13419916102242085, 0.1808549115254033, 0.20402006204089812, 0.11144957490145199, 0.07036090107454408, 0.12168718321669487, 0.10642436753597953, 0.1500431310024954, 0.15597461272151242, 0.12832615479466417, 0.1216428190649998, 0.22062199941325575, 0.14981181841463814, 0.10497891284044712, 0.18459506002405, 0.17632440543703495, 0.13532737870850872, 0.18198432430865305, 0.1633449761016715, 0.13487828264553703, 0.12055587819627217, 0.11598479243055468, 0.14556945331635016, 0.19294783923654787, 0.12654995695958215, 0.10414612164059955, 0.11655691455328658, 0.2513463386604863, 0.20399971474562922, 0.20333231426775458, 0.1465282736406211, 0.1266904957892914, 0.16472776480499776, 0.10331716088037338, 0.1353326187499108, 0.12842279678631213, 0.2008578809158456], [0.05677712795835349, 0.02738456361957135, 0.02832017914061585, 0.06188303119533005, 0.02575258183623514, 0.018957253628140016, 0.08778331095292684, 0.007738118621355464, 0.00632690949245326, 0.031131700755307273, 0.04756826081223065, 0.021842187533395428, 0.030728342056634928, 0.04074799069654077, 0.04937695992750026, 0.02805213838244879, 0.0644075398844096, 0.023023983493687648, 0.013735811883253197, 0.08295332577319876, 0.017580737269693808, 0.05053410892404857, 0.010556879288126386, 0.06293696133540043, 0.018594499504674348, 0.037305543965269486, 0.03361306911815078, 0.0142951556594081, 0.013046777082396852, 0.06330516617444736, 0.10511869324311134, 0.013765193270369163, 0.12255961180574472, 0.03759017627265665, 0.021759997790438995, 0.03655925558339204, 0.009788528531639567, 0.08497009053826333, 0.0076158385397115304, 0.05785411351450509, 0.03329056142378719, 0.057810385215787165, 0.006429989016689962, 0.040572031791652405, 0.020676262999674486, 0.0640236072602772, 0.022422773012470816, 0.05303291153282889, 0.03715270176349628, 0.02106232151779677, 0.033072226365367254, 0.014284822090919462, 0.08100253650017324, 0.06988221103505743, 0.06645135521408051, 0.026399439666420225, 0.06211439740934199, 0.06448013437611443, 0.045375560124915455, 0.053327430204878894, 0.005759251268295151, 0.02569809000218107, 0.03406102754055493, 0.03103322781352026, 0.15607702335523022, 0.010415235376586358, 0.09217000701614926, 0.02185628355120219, 0.02900754003935764, 0.057746922492139766, 0.09465169522070116, 0.17471843999960732, 0.15289233456696236, 0.10625971991929317, 0.052585688554832054, 0.09790819709099109, 0.2896504590828573, 0.2469081002017183, 0.35184129291484434, 0.38459005014550307, 0.35013567476022633, 0.43574606158560325, 0.2862933392245924, 0.3205437513609087, 0.25305825405784194, 0.09780978543623801, 0.031234481026448553, 0.25879951614526014, 0.03670019660926154, 0.07302753822577578, 0.21673899083848924, 0.2167598131082712, 0.062111601188418374, 0.27400017145179933, 0.2332937371947112, 0.3666159420484497, 0.16228126301880808, 0.0884938958070932, 0.05447671147844484, 0.038597443997259104, 0.05225182743743063, 0.16605709589296774, 0.11150982005581742, 0.24453328892348275, 0.2581529072936504, 0.1386417355388403, 0.0753877095637783, 0.01921529502367541, 0.1483657508487663, 0.23401788946601654, 0.26361998651296864, 0.2221568412477932, 0.047618274862367305, 0.03910113914659427, 0.05706572477074881, 0.023855200382850827, 0.03505691502904219, 0.041082610240987236, 0.044592323322449966, 0.068920157819746, 0.06368494660203015, 0.05696706030698073, 0.0133006404259152, 0.06661624031802339, 0.024326629824035113, 0.07801785028629726, 0.021800807294165416, 0.04060744420595227, 0.02208996143552565, 0.01254664998756902, 0.05856957068786987, 0.035923291523490226, 0.12608832769816922, 0.07822449484299268, 0.028869674856504126, 0.027793032124698646, 0.026530773949719248, 0.05670852478473418, 0.06787272410527354, 0.04579005965722665, 0.027916705528754863, 0.03322911351138065, 0.053734762984658443, 0.06427990963622447, 0.05777850829725785, 0.08665877048887553, 0.042389479631017295, 0.02893122619078044, 0.00791603105045074, 0.022269427107887405, 0.05588499941833078, 0.004950190120707116, 0.02280058459408822, 0.03446644127008415, 0.03636715520593909, 0.025146378376971812, 0.038144421733675465, 0.03812577515359848, 0.05536389492091633, 0.03740374494584338, 0.028423660382207845, 0.026388850416086858, 0.051594382272131985, 0.014759544752568248, 0.03752832616408987, 0.05527329736299092, 0.030499762487447554, 0.05559535689591881, 0.02571130884931453, 0.025453232979822545, 0.03551903458672666, 0.005563200271177677, 0.033179516979162736, 0.031726165832350814, 0.03023767040201253, 0.01551911039578338, 0.023257954406642148, 0.039615774031488166, 0.03675176581788448, 0.06729569901982624, 0.011934316867301542, 0.032737522551249114, 0.08839076505072656, 0.06397427885883278, 0.08366722778807725, 0.03221439558171457, 0.016318774038565256, 0.016962946730575735, 0.07345454031301123, 0.018982048063809355, 0.02025522682214937, 0.1470436056655261, 0.05642020759443122, 0.024831315142012415, 0.025010470548764836, 0.022691926513347897, 0.029751666138068806, 0.056906669595909704, 0.05275661043161827, 0.022663188640088327, 0.05731985145699113, 0.0864524093847121, 0.03525738874750753, 0.042667864491381956, 0.02574697407262941, 0.0338583359975488, 0.046911960948378816, 0.06944259147970908, 0.04776264030125834, 0.041087042059629195, 0.10553656356228937, 0.017059581061344475, 0.01875814737661952, 0.05124531430943359, 0.014049652250363462, 0.10116011009461458, 0.05722817754553211, 0.018584639953088858, 0.026910462446751136, 0.0416561572872583, 0.03375949916399775, 0.010982369309321288, 0.0460352077929964, 0.05515961757590694, 0.059364455857224045, 0.007483672093404758, 0.013652067939420382, 0.007711034061597481, 0.11722152647111686, 0.12798806487192071, 0.019587489265588023, 0.06031823149251361, 0.03909368511109103, 0.06906667213526464, 0.019473208099483483, 0.031964311924492644, 0.06252995797342832, 0.06471749905857348, 0.04958002685358928, 0.04325778666703452, 0.07609699206847338, 0.0663547974921042, 0.09051898794789469, 0.02675214080109952, 0.05288597969939152, 0.09655088081114716, 0.06000809611812715, 0.08040719425245639, 0.12691482931615847, 0.036017497355539, 0.05733955906884325, 0.09901052100523826, 0.06246064233803942, 0.07597880768439463, 0.176216279787402, 0.15377517429090318, 0.13419448788608276, 0.18428033578299707, 0.07852324615082434, 0.17669039628198072, 0.1490531308997062, 0.1506968644718009, 0.06574772643826662, 0.12555294715228582, 0.04396904184813461, 0.07249751263448308, 0.12771163736620258, 0.1438299740754789, 0.09194174345823065, 0.13912647001204953, 0.15177779921120213, 0.3351510256048172, 0.17713276609297723, 0.16237209040311076, 0.06774870213121176, 0.021594744964292454, 0.05205136137984453, 0.13527844101190567, 0.11439574221449514, 0.17107104942683252, 0.15706546063865387, 0.14944234953051613, 0.1236837539040754, 0.06517992505142767, 0.11348277991337162, 0.08897332129098716, 0.05059394039093487, 0.18428205181994747, 0.03976185933776921, 0.056494380227260055, 0.05136635237103028, 0.028750199614272966, 0.009065715956591792, 0.07771173687351328, 0.05021758820681323, 0.13469117333091077, 0.06261908464253911, 0.04086410664322396, 0.017632662709201538, 0.04775950700164803, 0.05548495979559037, 0.07997415539237761, 0.019122862685171348, 0.05475134250798053, 0.02939381306209872, 0.008387437030192344, 0.08390837694488226, 0.029946846188977364, 0.061185052317957726, 0.08833477934522015, 0.056426669546072526, 0.03145837596797895, 0.03201450792051131, 0.03275347250183264, 0.06187697527028861, 0.10059263812558306, 0.028928721083268046, 0.03464442264709262, 0.011954577020069045, 0.02351948724789245, 0.011803529379258474, 0.005438990126769509, 0.06398463636756906, 0.02055950928479433, 0.01612032470743983, 0.018013580777351896, 0.06855584470735443, 0.03383138885481223, 0.018659816161098502, 0.041142322964245276, 0.048318115333395625, 0.020267034152282343, 0.02978677211719896, 0.023411081976167137, 0.048341795111135136, 0.021870383399448568, 0.07160587056029229, 0.04815562808465573, 0.05307121209860329, 0.056927223734918146, 0.041398395513815266, 0.017385580201422977, 0.03249906236305833, 0.024627778987069766, 0.0683519197627902, 0.03274974165364139, 0.03020803620588155, 0.023687375416498513, 0.010507728044514456, 0.024525942919295163, 0.0368216943236128, 0.038459157466047236, 0.14156541817130583, 0.1734447422166986, 0.09060626834510796, 0.11362033100017618, 0.07867639478776725, 0.08924619414873662, 0.24567232377106146, 0.20641172725346782, 0.161006860435009, 0.11466515235482685, 0.06281032700151687, 0.10185459178061256, 0.09038213400110122, 0.15283000565344287, 0.16107003204524517, 0.25824753447405757, 0.15055945894170195, 0.19807423915593855, 0.08363179622157928, 0.16841068653570068, 0.08608903089958815, 0.13126613211727914, 0.1151943275885236, 0.1129545929330972, 0.10899158179639809, 0.1531192651318927, 0.151922773689993, 0.24439383027774675, 0.08179768213942167, 0.1044293903114815, 0.20350751857603752, 0.14368967273302619, 0.2615917534116776, 0.11384206748897992, 0.08297109135216282, 0.11634313005713687, 0.13804126050203078, 0.2446691163124577, 0.1300128735601902, 0.1433274203971509, 0.16308456749445008, 0.2496928451282363, 0.11374039229966941, 0.15823395922780037, 0.11880356698266922, 0.07755382316968135, 0.11599039253328117, 0.20878295324021773, 0.19015120462544505, 0.11045401300033254, 0.12742345041084674, 0.12993321573782352, 0.23648768032510437, 0.18683623492477403, 0.09003105122716197, 0.1569968651259138, 0.13747660773656062, 0.1463439528860392, 0.12974895627027558, 0.1718728983354184, 0.1644413245301093, 0.22459968113370482, 0.21592577318510703, 0.18503611216381674, 0.24700574576854709, 0.2288835528757303, 0.2381196467866821, 0.15088599625854723, 0.08830977423537163, 0.2175439500640477, 0.17031838336298544, 0.28605018291742573, 0.3162409419253949, 0.19254054093072492, 0.14100853353738785, 0.18520975365273415, 0.34338950449901245, 0.3950715425514406, 0.5099431172974649, 0.6092266413953997, 0.5334862249512826, 0.47839984538093694, 0.3800966993214623, 0.5198947832949701, 0.2698899871639667, 0.2604752262273143, 0.11942542353344542, 0.5270279811755304, 0.17075277053781096, 0.2459946782478402, 0.3893686614690289, 0.19777453023820155, 0.21283160534597215, 0.4068597358080649, 0.5531228357745755, 0.4915708579844045, 0.2310058462523645, 0.2766244516016976, 0.15871811147418716, 0.13619000903300701, 0.1802565662130233, 0.15833181929924797, 0.10255275834952632, 0.3287387471045217, 0.2191123925149441, 0.2741600386798382, 0.2056687905062591, 0.11619154423955949, 0.24576829926621532, 0.31272450642239663, 0.35551701341905906, 0.42446425244692837, 0.1311631086132219, 0.1387917661979314, 0.17217107507730686, 0.0995146221811733, 0.08524203642962441, 0.17938223006504198, 0.358730353895695, 0.23619039224520808, 0.17688896627195422, 0.16890158035582112, 0.17368319474401014, 0.15028636391845443, 0.14049248138983406, 0.17644949227331147, 0.06396657201431452, 0.10437850675155079, 0.16419136536217507, 0.1433766338854067, 0.19130382987280048, 0.19276813033127016, 0.32316600903868675, 0.21823873052433615, 0.12421065385663703, 0.07342574306793752, 0.14902978053977414, 0.16556630932515667, 0.18725753731785283, 0.14422020394234888, 0.15059298294926846, 0.09342132737078974, 0.10168483435747125, 0.1523836675069986, 0.11215789213536248, 0.09044681480454822, 0.12049256869020963, 0.08553134953422893, 0.10351550870484884, 0.10401513592730607, 0.14215832425942346, 0.11674200139579274, 0.10950039441306746, 0.10363433660278398, 0.14023080107665833, 0.11174006012058067, 0.16381714673292253, 0.10377787849715642, 0.09742482625428708, 0.1842358107528379, 0.16757050258738382, 0.07244846768557064, 0.1934094838197193, 0.13000155078066936, 0.0829603124950682, 0.12429136888033922, 0.13033435469673527, 0.14808369259680473, 0.20770348938963107, 0.09437830908404243, 0.10672426031481837, 0.13511682710339948, 0.2769621125152034, 0.14361113339902895, 0.18971680212886105, 0.08146215095034531], [0.03487062159805529, 0.07038857217036909, 0.015861452106506597, 0.026814092416316274, 0.048180230998344, 0.018340531781676318, 0.06390686695193572, 0.0860861427481136, 0.05168644305799277, 0.03691557456829375, 0.07210484660801388, 0.03553644776524555, 0.006090906531279606, 0.039913288107322115, 0.10235194372193468, 0.023706043063993418, 0.06527036939176821, 0.08896546888976328, 0.05490549088966462, 0.044907652772963054, 0.09617400385679738, 0.04322312118846082, 0.02497458890561135, 0.013703817178705528, 0.024933804299742467, 0.050809758850523544, 0.025733939086597775, 0.01112411951556081, 0.0643880123032197, 0.018046405729687503, 0.016690518203822356, 0.036510467273934234, 0.06726018318365659, 0.056616360577003616, 0.05762375470611358, 0.049220923139082814, 0.0035217476045457468, 0.03732640453944764, 0.0365798135528401, 0.017889658394720287, 0.06054383289489535, 0.02118999198559792, 0.015186557373512658, 0.04802583363808451, 0.022282322282872857, 0.02670807542369491, 0.013146063992603412, 0.057059098110203786, 0.04637185364000259, 0.037321195141562534, 0.02175634546625999, 0.0356823185669078, 0.057092288869523236, 0.012267893574561083, 0.05292180197073087, 0.02097918374103404, 0.03470297091670575, 0.1435858371757692, 0.03234183047747901, 0.04978213233933334, 0.03487352507128831, 0.06894769101974464, 0.005662134780939068, 0.1592736477933584, 0.0313987858187888, 0.03378279589777512, 0.051392744100021745, 0.08077407375939431, 0.0603926990691933, 0.06845065317447148, 0.03797324704787424, 0.0855236120461937, 0.10449152004214064, 0.056674575598369685, 0.019553044037292563, 0.08670717958481082, 0.17042793393615754, 0.08670372452827231, 0.21604523693601932, 0.3726912031490957, 0.32306035019217, 0.26694048736845294, 0.2619006400627475, 0.17449129493005816, 0.24319399869249714, 0.11498641132587388, 0.05740207950434378, 0.11393959048174082, 0.06433632435096849, 0.12843415020934998, 0.1448148107456584, 0.13245252652033684, 0.12355944847748165, 0.17006258660506818, 0.09758785742545321, 0.1415651270578946, 0.05253183257375514, 0.07011396029303152, 0.04532220210098932, 0.02330404608660648, 0.015692822747833787, 0.14584123066836788, 0.07694774036926609, 0.23251729176169444, 0.2379854741476236, 0.12354408075372059, 0.07883800869627346, 0.034752939001566945, 0.02726075231968876, 0.08034718658534751, 0.1282263871642851, 0.12442413191761702, 0.03482085269605441, 0.057336096351425496, 0.05823220854865448, 0.059517290398118004, 0.05449709707810994, 0.04677076328305468, 0.08724878842551863, 0.07149012999669199, 0.018300157032846924, 0.0866360329992829, 0.04464833584103373, 0.03617938322525832, 0.13374733768643873, 0.0063417213236642705, 0.03316045671160663, 0.0942190164219468, 0.025712703129336722, 0.022757224017573942, 0.041497400886709654, 0.0366566636629643, 0.031250789123136676, 0.06293103564530611, 0.020491425135743715, 0.01999806259728728, 0.015272749925873455, 0.07517058492427872, 0.010177934853990954, 0.018296577487020724, 0.040591505746687614, 0.022416341704346483, 0.10243249786717278, 0.016351401723260363, 0.04538104148401369, 0.05562076803236719, 0.045240736311121334, 0.057472793250194484, 0.0437400619980068, 0.03267589460818037, 0.005363664052809679, 0.0669819017451617, 0.029940321035082304, 0.026366281465837554, 0.033662248132449966, 0.05504398426461605, 0.030645413038831566, 0.004401476772111511, 0.008340693217882467, 0.01802984099354475, 0.019082997384811604, 0.04043506676210992, 0.045863653893672654, 0.041998567945894696, 0.02264090888803044, 0.020115036562445666, 0.04251477714147299, 0.05111519044505493, 0.08011668605069, 0.046886733673032255, 0.04369892307647294, 0.035606609927790786, 0.04928704035738784, 0.07639268668548715, 0.06181529753150479, 0.09128605646471824, 0.030106609995146433, 0.073670377924798, 0.05092864420505301, 0.025432784177903688, 0.05460184811043644, 0.03304609127583043, 0.027197360459174362, 0.08166694157426396, 0.05025480475817477, 0.027054050306399024, 0.01323827033516981, 0.017989324518449364, 0.03223417980235911, 0.05541596208669006, 0.05686649594516043, 0.04893576223102789, 0.034626159110977765, 0.03868026576275307, 0.0589991276783328, 0.037833642845432607, 0.046852937704252626, 0.036933910882761406, 0.04675332712189806, 0.07097213964668975, 0.04487337416879112, 0.05061410765554156, 0.045328123960644014, 0.03257221609894787, 0.06095227650216511, 0.038937226974315224, 0.019762525034527627, 0.03463566243167847, 0.04438561364828099, 0.015728325177464756, 0.07140275000804855, 0.03213001291207489, 0.04206149823843472, 0.056653872072216005, 0.04983194337617006, 0.02067637599764332, 0.061318868726131424, 0.020928660242427743, 0.014110242144294806, 0.022862338941664468, 0.009465050778441854, 0.050463981235459934, 0.008261823508467886, 0.03269921049415585, 0.04417414656810222, 0.044144778587524934, 0.06967921305688159, 0.016152919833398154, 0.09867505110319584, 0.07771077160272868, 0.029120693140993678, 0.07224543140299859, 0.009667598679962178, 0.1145807371264504, 0.04219546020331402, 0.00951282880944951, 0.05165339785537893, 0.03260738719555159, 0.07440145563093886, 0.03735913947645215, 0.09317713684492535, 0.030944704438649842, 0.047974812182327436, 0.08231036350010865, 0.06419918312120342, 0.022632742390757608, 0.03665828776936378, 0.04036418447691587, 0.10036238273906131, 0.06418105365047533, 0.0466369315531225, 0.03646076731984654, 0.08924884481295463, 0.11290724869937667, 0.20771364771550704, 0.11325136007320498, 0.12271999231269284, 0.2432347086047934, 0.2376645905596595, 0.20708706440223804, 0.2716378320849711, 0.07849513072400324, 0.008125315258850255, 0.07327855459504551, 0.02549505946526845, 0.08508612221527485, 0.22542270471251782, 0.11885507873469785, 0.09480417736114995, 0.06187393773166884, 0.12198739009158266, 0.19899875406296025, 0.18357319066361075, 0.09259526242291735, 0.1352608516331642, 0.06942890148850218, 0.07017985151539888, 0.10291533244232978, 0.16154191156308498, 0.07675002073688854, 0.1738246145748323, 0.07330532170711987, 0.09140315300394451, 0.08238153306827431, 0.1055689997250034, 0.0706618280720807, 0.030930978058266546, 0.09224584205977379, 0.016610530963648232, 0.0497215079714454, 0.03225282255199648, 0.07215949932053205, 0.05457609989530137, 0.050455447015983444, 0.05261627461520895, 0.041778765829099763, 0.04423960112035275, 0.027716032627429214, 0.015384844868564078, 0.0683481965754782, 0.044185756630594694, 0.04039437217157214, 0.0445565355250672, 0.00342415350924937, 0.0243550842447627, 0.09778986715020672, 0.006610889667494884, 0.02791104413899443, 0.04214036315979977, 0.1352982214021106, 0.01565608500142492, 0.05667030848863144, 0.05251410912962691, 0.02477528347123054, 0.07657143798085951, 0.09288197848945857, 0.05193767393188131, 0.08419448780196329, 0.13920297155216818, 0.06085460029181935, 0.02063996766904189, 0.023754708799383333, 0.03837294193104871, 0.008464416417653763, 0.05137198311727374, 0.05130680052623634, 0.04719205418481462, 0.044250793664926485, 0.013295781513255452, 0.038760720316561005, 0.06798978234010358, 0.03450259678967057, 0.06292935408231232, 0.02666852230416431, 0.014170090848159407, 0.00274891379728703, 0.05687160192117576, 0.01663615085905598, 0.05302674069459881, 0.04200827811033495, 0.03489164305069754, 0.0555088387561902, 0.04895494507265188, 0.12461998229545933, 0.06137198543236141, 0.016120408977111502, 0.046697927473653714, 0.009483389965739221, 0.016118725498897896, 0.08495316765601597, 0.044095706825535146, 0.055123753169731754, 0.13982740981924918, 0.14119466225947105, 0.14580487213548154, 0.1729286900691448, 0.13316354804462002, 0.17029466528084972, 0.11444581372122611, 0.19396987713633046, 0.14128525981739645, 0.1106927183366591, 0.1200666084825512, 0.11134417652482949, 0.13301236825364252, 0.12196021695290843, 0.26210543068666614, 0.23986432010367995, 0.13938690926278793, 0.1727801456206268, 0.1641004154038045, 0.15427467893929253, 0.1357873378982467, 0.10597843541613511, 0.13025259779345605, 0.12058934091680473, 0.22824797569023025, 0.12981533012803526, 0.12403843729125878, 0.11913662370775016, 0.14965271727452356, 0.10543946191788682, 0.19162190957896172, 0.10636032258550968, 0.13761620427812302, 0.07355335799436416, 0.1706504058693686, 0.17060629452668852, 0.09768049277725721, 0.14709061282055994, 0.1914629769781905, 0.08807989423193278, 0.1779128121392381, 0.10150652739309496, 0.12541564121361704, 0.21881089095146428, 0.08121818258997895, 0.136308231721482, 0.08344601223906202, 0.14118355398456897, 0.12137991301114522, 0.14964622084892568, 0.36507279582081303, 0.10688869342688592, 0.11917784689895569, 0.14383332954058725, 0.1963557660459511, 0.10534751604521468, 0.1425555102046459, 0.3063421359946651, 0.12082701969531276, 0.06460027228440009, 0.16416786178465814, 0.10121293185699372, 0.1555324574151347, 0.2762825005958157, 0.21972866428475227, 0.14370962166257445, 0.2998509504381688, 0.15120560814055706, 0.15270033761137916, 0.21911030875579005, 0.19336468299790738, 0.16911652930561574, 0.20492697224741985, 0.18960840068757537, 0.15050408610653493, 0.23105758783077043, 0.3593195980835346, 0.4766910096570369, 0.5445006081173497, 0.7310409339204912, 0.47748869104731473, 0.5426127223237869, 0.37103954822786395, 0.5179628321240025, 0.40014423970733926, 0.2325455450843419, 0.09006515746155093, 0.178466034872878, 0.19094842636296827, 0.3729428477104633, 0.38995052056927837, 0.2782555753665586, 0.42163171895569374, 0.2591023353799697, 0.4135637099464094, 0.21236911806608402, 0.290080847278718, 0.24054774714093055, 0.2560709714288673, 0.1321030372092801, 0.10266461484735051, 0.2719934500994221, 0.3357814240359491, 0.3505238055461838, 0.36494939437796997, 0.2674060236782797, 0.22960644876283987, 0.13158543756411922, 0.18263965124084106, 0.24793752318909093, 0.16025564993821806, 0.15487035826569603, 0.0784317829135445, 0.1114887526378997, 0.22144585036702696, 0.197066557743857, 0.1535914970501777, 0.12724349635743326, 0.1933897647165483, 0.19088404433381176, 0.23861032610218372, 0.22953290432210893, 0.18311715384404506, 0.15858833617981405, 0.2807257492696085, 0.17236124874363024, 0.12077109527684028, 0.21566556376074592, 0.13929326267492387, 0.20349173716479735, 0.08649107384225053, 0.20629465369687927, 0.10217742123190435, 0.27891796562940846, 0.11111496301788477, 0.15833140561176887, 0.0788318953146377, 0.14869619521402544, 0.163398755473956, 0.11651766020804645, 0.11066336950827992, 0.19897837612417438, 0.20354357067375414, 0.10386954091729657, 0.1077556674699149, 0.07772000296221626, 0.1675352472211084, 0.16428914882483023, 0.15386868298294085, 0.12194894013866303, 0.09580193793461209, 0.20054686454034623, 0.1479698059659812, 0.13135006471026328, 0.12673775575334026, 0.18459211824642074, 0.13614234304235828, 0.11639831137032279, 0.14845558231876743, 0.12834150719666673, 0.14840407056673882, 0.12899583055367395, 0.09732280632541065, 0.11714308672854978, 0.15280956642762308, 0.13094028427956567, 0.11202567302051092, 0.22517702031520107, 0.14469030613620437, 0.2296234252712419, 0.2195414630395751, 0.14143696054816246, 0.11998715750392407, 0.13767663329359026, 0.16136264698880334, 0.15578590994400365], [0.004516800775402977, 0.0289964183579169, 0.013611550506715094, 0.03050008041393613, 0.026481880303171855, 0.046622379713000796, 0.04221594539440928, 0.03551520797754488, 0.04093232677288113, 0.04559536607215001, 0.021299806859103904, 0.008772863525777094, 0.09298583702935327, 0.0881261965860763, 0.017900006327357505, 0.038965840358287096, 0.05597521776273366, 0.04742826207450802, 0.015084250161664621, 0.11442985610976336, 0.01687137432576668, 0.0038274090254544132, 0.02497737938087554, 0.04063372868263433, 0.05932473802878972, 0.020587314446006092, 0.043074239661256154, 0.043798882228833054, 0.0473213583351143, 0.042801474055816094, 0.05310683901752195, 0.050736363796937856, 0.09756325834220457, 0.04146718254853641, 0.048726788767042666, 0.05063083901580784, 0.07639173673646105, 0.022350912049953497, 0.020712018238320466, 0.012148663480465692, 0.04459428450753612, 0.11824687387073234, 0.039421417525098215, 0.009250194716808057, 0.07989642811158011, 0.01839541432057177, 0.04396422315509089, 0.019358055508365075, 0.04221917062457051, 0.06108782426904767, 0.07767687221207926, 0.0361156830143544, 0.014154646515605912, 0.06514321411809613, 0.06543116358619544, 0.09313733091637974, 0.09078989962055799, 0.05214304678262242, 0.04299173965269039, 0.10552822086479395, 0.0452394224703312, 0.10840477376815774, 0.062206642056304606, 0.04321357190248467, 0.031111250038168607, 0.03486654984073774, 0.09340206792037334, 0.04055599374095759, 0.05100671239497681, 0.021366188377742807, 0.07313830687874749, 0.03733239151657589, 0.1279407053164417, 0.030896149786008947, 0.04945169180451382, 0.06013592171873297, 0.10248606273483846, 0.18433075969017323, 0.06104287406009051, 0.10985380609429653, 0.18660475379757344, 0.1170447976478646, 0.17261600362197047, 0.06651176890778927, 0.1821066225848852, 0.026549908910847964, 0.0714723414350902, 0.1421791312074469, 0.07335329413293831, 0.05704304090731087, 0.06020556294148969, 0.021383609217140945, 0.10015609058281107, 0.071295267872272, 0.026055939247711532, 0.06126837587104209, 0.046830636884776816, 0.0520386481507411, 0.005046760291612197, 0.03646779617655181, 0.048920145528691436, 0.11561427400597643, 0.06627271883189678, 0.05802882369607688, 0.05419110623939384, 0.08007402261418682, 0.09121838791836655, 0.038580712636992816, 0.029615359944141204, 0.11178227922608776, 0.1128092124277065, 0.056921148657678604, 0.05260331240753013, 0.08373369357638782, 0.04433949132479968, 0.006949769618410257, 0.031999582612526514, 0.15230488302486558, 0.02539733920486704, 0.024427588721136415, 0.04540832570543693, 0.043354505267474926, 0.012028806151882296, 0.08432604042032073, 0.05046775421848701, 0.021716259915622014, 0.037301744169165055, 0.0522870444993098, 0.051761485200615666, 0.055058015164949244, 0.028754698465608304, 0.05397412332616026, 0.03872091055757577, 0.01607808836495444, 0.0342077257171754, 0.09219554072666554, 0.035984582387872284, 0.020343370983497273, 0.036211647018189394, 0.030777574697088812, 0.016297928786145586, 0.042745626246136044, 0.06315382167456612, 0.0530601344672182, 0.02648896470125164, 0.032552443369622194, 0.057355865250311555, 0.06592038733464095, 0.04050841585042016, 0.03854068454294916, 0.06458924827916969, 0.023038230813859452, 0.06329468992208281, 0.030974296499944987, 0.03814232648320256, 0.05935563052433634, 0.05689431642813068, 0.030989047522927006, 0.025854879471984123, 0.04209277377794347, 0.040715098711511785, 0.016886236431497722, 0.03336021030742315, 0.03130957488000634, 0.05221005266291961, 0.015098597073266584, 0.06779824503727498, 0.020304078333860925, 0.05573381196647402, 0.10062105998757387, 0.02653823564610174, 0.03268378148336084, 0.05762859638179502, 0.006941756338722283, 0.046096954479693406, 0.06305306579076475, 0.027435608057966156, 0.026744276908556783, 0.05181762412370694, 0.02346188318164599, 0.049108350349049416, 0.011628549151693382, 0.013699415045970631, 0.05012058232340121, 0.022802298715818795, 0.020537024604216702, 0.019458981846729596, 0.012938561417432803, 0.00863279871297099, 0.045045763103952335, 0.013740636321956353, 0.011687113700674908, 0.013910724120515009, 0.0561703939832026, 0.02150307105283343, 0.01203163301632289, 0.06302292789182355, 0.017499070381745696, 0.012084803348707577, 0.026951515183393514, 0.05042324834052594, 0.025039827038023262, 0.009071930844877518, 0.06346592206447836, 0.05249681086429665, 0.023944901617904826, 0.04104981401694879, 0.02895418967631075, 0.03492147834490865, 0.022502804302700588, 0.02662365444965901, 0.03953723469749093, 0.020409970837194594, 0.06480641122306548, 0.030801334914060372, 0.07974043728843813, 0.05356374534688169, 0.10975006246759046, 0.015556965672951794, 0.033230055799527515, 0.07969460990880767, 0.01125116370648386, 0.064782953610824, 0.007224813377815149, 0.06039950959084015, 0.05419196042742941, 0.028225551960208727, 0.08877245303724082, 0.05849664294791799, 0.09482060228624652, 0.049257618750655846, 0.08377561390760445, 0.07548229077890997, 0.023782272642898946, 0.0892881604452287, 0.055641134479834195, 0.05767119853126426, 0.08457031521585681, 0.09134182000472661, 0.03686630745388327, 0.013495397213245592, 0.035660373978316784, 0.0644980991379388, 0.06175904369522488, 0.017905937763111248, 0.027246939754413984, 0.019285271409898996, 0.016806546050394257, 0.12365639690429935, 0.032269910143147555, 0.07500501034120399, 0.015952178941769226, 0.09263647029236441, 0.06442070127494874, 0.06173836315170892, 0.028405492607083534, 0.11788009395522457, 0.032735626483636523, 0.07983762320251235, 0.10419912726408052, 0.15602931139930604, 0.04239497248143439, 0.049147715777038574, 0.21743421562977377, 0.027681035815828273, 0.13399659205348263, 0.09745006119051287, 0.08436524113940616, 0.07616173415895432, 0.13536120915124494, 0.09266613321679254, 0.0958979593950414, 0.09203892171142564, 0.050955997374389446, 0.048992483380941615, 0.04740897964145388, 0.029074850439604734, 0.038907284427794724, 0.2045644747634088, 0.04877828902775242, 0.03064018448874835, 0.05646210877344974, 0.005141239042483992, 0.0711604823628741, 0.07651349109026694, 0.11232682984442481, 0.03326706550714951, 0.1009447551182201, 0.05622982708436828, 0.01847273748998921, 0.031214170120356065, 0.03922887281664918, 0.041132137825291966, 0.07824665010576287, 0.06337682220844493, 0.04747002152726055, 0.023653870561130108, 0.028664112399001757, 0.010787983117024265, 0.07254674910537659, 0.040239603258669376, 0.03623799661234502, 0.03906267004147653, 0.07322760208720162, 0.12932915540952838, 0.025731093069959073, 0.033017209761085055, 0.04313037858434743, 0.05016208130625948, 0.05725794006139041, 0.038592521882345604, 0.05202690019242225, 0.06943316093736118, 0.07971908641798843, 0.010695356383709418, 0.02875417369538017, 0.013253446536949806, 0.043210833138155366, 0.08215251108331066, 0.01936170400210446, 0.04002087366496844, 0.050933279036994905, 0.012574438869412388, 0.09117148035476286, 0.015092498055779406, 0.045949271880090244, 0.03809960942054468, 0.02953221067605961, 0.0571001029663509, 0.037650026891741066, 0.051998711987248356, 0.020412728753722003, 0.022873615755909876, 0.028862783895625226, 0.030855506906406056, 0.042023082759471676, 0.0454411602338716, 0.04173142159537923, 0.02318869431262776, 0.014064029805482397, 0.0615809703876655, 0.010180786616289088, 0.04246728352060722, 0.058241439908142054, 0.022231959662730658, 0.033338296362349105, 0.03807484562839231, 0.05274496972560883, 0.03966237899036177, 0.06839004795878165, 0.007258441286056393, 0.06117808091784678, 0.13699504486735792, 0.15139048047844442, 0.15474314170499004, 0.11391725901874805, 0.15856844853729973, 0.1353231192596497, 0.14417849811575106, 0.11199468476397377, 0.08450456955019506, 0.11014262124175027, 0.07418880494491709, 0.11501783625252786, 0.1468382174930265, 0.2704987819156339, 0.0720718282184774, 0.10749504435807468, 0.20602220218748818, 0.19236184326150726, 0.14521253295242786, 0.18220131105232626, 0.09926756648647209, 0.10444889491003369, 0.26115514458187167, 0.1516224825454335, 0.20295979635369396, 0.22028691255517546, 0.10047494403777585, 0.1812095949125867, 0.15955138530942703, 0.12237428747598203, 0.13274682685732841, 0.1380296466090987, 0.18094535586574387, 0.1572762267483819, 0.09632383533302816, 0.13735475379132456, 0.15708609904733398, 0.15752698264775739, 0.17886893583401559, 0.12882592757382702, 0.26322018054704516, 0.224853961037532, 0.15032543440259274, 0.17049352638423446, 0.28417118374378453, 0.08766214648682265, 0.15790523089949163, 0.1635998841975966, 0.1568831470344336, 0.23395418159423337, 0.2032683918913526, 0.16722793871116254, 0.10068212485601825, 0.18679269048715794, 0.21178868388937366, 0.21052434770089967, 0.17192781151783082, 0.079424885672427, 0.19892781432117188, 0.22379461465583694, 0.16518593134899295, 0.16879060485910985, 0.1970688866511468, 0.14330474419459222, 0.14852181828070074, 0.1875517457242935, 0.1588685098554819, 0.13727480485554666, 0.10759544784143087, 0.19884107784638483, 0.09254026497083326, 0.20804340260163431, 0.21196358176248692, 0.12573739048093557, 0.1194086691905414, 0.16154938858122597, 0.21238814769012315, 0.4876038095643444, 0.3583179228007794, 0.26766266313291365, 0.3151055076910604, 0.12340009452835207, 0.3337542328142351, 0.28255185773295743, 0.2833883338157208, 0.16030207486642947, 0.21670866907844621, 0.28284290985715005, 0.16114317812025547, 0.25464195698019, 0.24528724201504262, 0.15633415310613571, 0.2220538637090114, 0.3161989296636274, 0.22771284795336186, 0.10584699005008706, 0.18324642352038817, 0.21985447124367763, 0.1119551546270809, 0.11794292082589482, 0.24827584293821167, 0.2151505841362861, 0.24851492365762112, 0.16863505836696396, 0.1888624302321865, 0.22445113668518685, 0.15417360129856295, 0.13588961063613816, 0.11074845889402975, 0.18740690914132904, 0.15288306490307854, 0.313446008029484, 0.1378901726416042, 0.21722798476055746, 0.10186114183236515, 0.11606874800617657, 0.10813095096138217, 0.3240330060643535, 0.14878061810328116, 0.0748080721185092, 0.3009486318595948, 0.10472555990300833, 0.05946292113813181, 0.1709589554417518, 0.09600361824155816, 0.1304289971989009, 0.12156504581892684, 0.16844653945055701, 0.2912075787542328, 0.16690207555169062, 0.1855785483794828, 0.10904063440618977, 0.11763527523726226, 0.1350507903243265, 0.11495710846277014, 0.14700971393575593, 0.15099177767913188, 0.09498371772708432, 0.09989819474398129, 0.13366135197781748, 0.07203952229071049, 0.14193842638163798, 0.15742900000224191, 0.10837836671740779, 0.16799528301963884, 0.1526347145197853, 0.13843904399583418, 0.2504261138458406, 0.12323633557365787, 0.13627204172793897, 0.11224810664932575, 0.15270465834727212, 0.0903643224568617, 0.1350451672389623, 0.12551517135673954, 0.11356151076934992, 0.18910255283117297, 0.1660319988525683, 0.13181595342053523, 0.12060916727228511, 0.19022064283490184, 0.12491017640117677, 0.06692075260704564, 0.17093934359089022, 0.14449503032430527, 0.07352915727683614, 0.21600766798421261, 0.17224402196945685, 0.1299725313700976, 0.1725381384453466, 0.13030433937186195, 0.16661796418409194, 0.1372140694049097, 0.1489789123016019, 0.1408703925628816, 0.24351004060477982], [0.005890561132541588, 0.02401658829541937, 0.0172923396401588, 0.03729626664050645, 0.02083830017175886, 0.028216299533303228, 0.0677683599473488, 0.032926217667878635, 0.05555767303092345, 0.03827403231914486, 0.08418570077347179, 0.045566480726965015, 0.013050400678278699, 0.08789306836983851, 0.03380130458202574, 0.043724035438630855, 0.009204693882155323, 0.10879551691393699, 0.038469101287304394, 0.02797170681127858, 0.057277751095112295, 0.04520004555102318, 0.008737146591527328, 0.018870151346369136, 0.03753376921879188, 0.0306839338548842, 0.05532568245525322, 0.017927282887901512, 0.015867825000426702, 0.028907136556001443, 0.033336476903528936, 0.028087234785479885, 0.04487759148281428, 0.031093465307006435, 0.04136911946378889, 0.04906080693246857, 0.04050771871040906, 0.015104413595831683, 0.03590935255370794, 0.025366758890149575, 0.00206389760639849, 0.057567282534775235, 0.03506350338519101, 0.07053268096980549, 0.04407540166510209, 0.032250685166687734, 0.017652083038082047, 0.04101664240982744, 0.02881800222601141, 0.008281004434872058, 0.01166656434971599, 0.036448536726135405, 0.07312870779705626, 0.024745871440597603, 0.03720736596733332, 0.049003809990902106, 0.06904244077421966, 0.03437282149529746, 0.03756651181667563, 0.03374468685398179, 0.05190387030222243, 0.08570134444462676, 0.03988007819580455, 0.009332140269238622, 0.042019198693695574, 0.052698307310140906, 0.10495681120383163, 0.05155733042967416, 0.026126361880151015, 0.05200527736075944, 0.016457058654557315, 0.06517904405031474, 0.07319927215576172, 0.026950902313054092, 0.04059731269315366, 0.04426227349247183, 0.08724825216397163, 0.07429444846967537, 0.059507817720934275, 0.056011503517267205, 0.05592449891170668, 0.1527725030938464, 0.08332528444307466, 0.08999627083539964, 0.12506013045147543, 0.041685808720367576, 0.031731626124031125, 0.04631516313360584, 0.016753640018343445, 0.0936450710099551, 0.08289046825901156, 0.04409317107450578, 0.030848681063000715, 0.045273478909005085, 0.04944507663528766, 0.08204014896745644, 0.027745888989058234, 0.019851883445235512, 0.0642294091202559, 0.08239799629776709, 0.019802750396211783, 0.04811314467881476, 0.0653877187400095, 0.04491979909700252, 0.03036927856174448, 0.15756623699299752, 0.033328923276595535, 0.01970126481366254, 0.10756632883942897, 0.08684833894573873, 0.05187090170840102, 0.050680060164942864, 0.045278784067880724, 0.014294252633267354, 0.05254332389261934, 0.026605659044317664, 0.04115625427314832, 0.014328085948833296, 0.015486459728450546, 0.039735812348343676, 0.04834005609154702, 0.016961328369835695, 0.04826686405126126, 0.04587155609061161, 0.09316274205282812, 0.03380074533784101, 0.023007621770844828, 0.06115763403114773, 0.06896642186949331, 0.003277627463009389, 0.03182734881016997, 0.04113166668121854, 0.039030130456892714, 0.053615398825176304, 0.04986847427883937, 0.015670064190823226, 0.04475028682199698, 0.05783537883431681, 0.03778920974582434, 0.10381201537506235, 0.040332100714647004, 0.03103271261939118, 0.06836723386039657, 0.03656944455278497, 0.03948156691847309, 0.03702714761358596, 0.043470831888337294, 0.05971575696622172, 0.010351578258128177, 0.0847954071697689, 0.020857921598719496, 0.019832959158285972, 0.046997460191168135, 0.03871846290665769, 0.07358206330888695, 0.057984283344159206, 0.06166975614764999, 0.020736963976354852, 0.030472154593876297, 0.013794252900556933, 0.07340621548674761, 0.04258264870112462, 0.03602093709031901, 0.024835147496853626, 0.04063829073622342, 0.026183634613370223, 0.049888216364648075, 0.017846744064421907, 0.04043105629182631, 0.041311766291337634, 0.054865788382988785, 0.019796140972645055, 0.03949786926950178, 0.03720689482325989, 0.023112895658179637, 0.04677738611316008, 0.04439633121834167, 0.013220801615276405, 0.026718932804801775, 0.01965903421683658, 0.04320123405646413, 0.008167970076864286, 0.01679409903684451, 0.058454917969122056, 0.04933318183306725, 0.009116203066021686, 0.016340682237979867, 0.0308834882678404, 0.05590364599840776, 0.08014180607372716, 0.029187134031446713, 0.0737601327860067, 0.03060766788680227, 0.026533713812128674, 0.011313757877947103, 0.0051908906372714675, 0.013813095790664516, 0.04769482619820103, 0.07783189010355743, 0.023170239254531842, 0.012849600414835639, 0.020890782940231507, 0.10894193163802547, 0.041760088605505806, 0.03685986465444008, 0.03748611088902239, 0.024724514824488474, 0.04546041202340876, 0.00881066900723043, 0.06669590580126931, 0.05128418561071158, 0.03167113390631013, 0.013628270375662515, 0.012701339418849638, 0.030062134760702332, 0.026568739352026777, 0.044570305955506144, 0.061067377382348624, 0.031773119361229965, 0.0641821223431297, 0.05398056612560346, 0.05880362970093566, 0.07286677467486552, 0.05980610171513212, 0.008698378712119115, 0.061975103472509695, 0.012137217169267037, 0.01816526618635943, 0.02011586776784351, 0.013235323769491047, 0.02954791547850736, 0.01720375114781482, 0.061436007400193525, 0.03298092783699113, 0.02537450212384424, 0.043960817894267465, 0.045603915613384984, 0.03957309144278688, 0.02217848672561588, 0.02994438513152061, 0.05511254530339953, 0.05464719668511422, 0.04216452557293158, 0.09930869008624747, 0.011495933586341, 0.0410117126340347, 0.06939898575505904, 0.05113291771962278, 0.09385746888696186, 0.06004414438540417, 0.04608119605109096, 0.010747297144975635, 0.04359000452583836, 0.06615813506106216, 0.07417661648604178, 0.04686224567253263, 0.02836066305697445, 0.0790941272111189, 0.14110852333326496, 0.05380349639322489, 0.07974901747319006, 0.030742970505549066, 0.07431316399766554, 0.0355501645695298, 0.03499427968035302, 0.06573106402591353, 0.014608866749181142, 0.03985549060387477, 0.0610660482198, 0.02910534839987034, 0.09418530089239921, 0.03501121022347962, 0.025361756336004026, 0.031594153561238805, 0.05234599113464356, 0.10521666822774757, 0.03522113363649096, 0.03497356466288048, 0.03411243970115339, 0.039253257395279025, 0.05293933389287803, 0.05769813801312159, 0.061711772239857146, 0.03678279237881784, 0.020722534710301027, 0.059987863736046906, 0.019657873593631293, 0.046931484699129104, 0.05020121690787135, 0.03045400022529066, 0.045790825745150934, 0.023545831096388643, 0.03208219561906111, 0.01726433912652635, 0.012749216083677547, 0.09047509110983341, 0.029916760000971057, 0.03033557260829595, 0.0155020936677653, 0.048435759625487754, 0.08841891878194387, 0.03927784881764843, 0.049481756925102205, 0.10303865727638045, 0.05923360803975694, 0.011239500975446596, 0.054408177252738714, 0.10650841504215233, 0.04305784154923693, 0.025741419935178374, 0.018369595242303707, 0.04799442786362864, 0.04002502586151804, 0.06917792342362866, 0.07917684938518271, 0.06956797709027607, 0.008287647374785476, 0.05945693033056394, 0.03136098512538499, 0.04231008993942411, 0.04206535549113347, 0.009244714315319735, 0.0560699368736917, 0.02068317885841093, 0.02812916469279557, 0.026939271183143702, 0.0210359106366072, 0.06669511673070731, 0.021814187019762975, 0.016641877366289977, 0.06399494791102987, 0.022823810464732593, 0.013613301017622073, 0.04021123119239365, 0.01957825407566082, 0.012336017943227725, 0.011490363169521576, 0.04945611596227654, 0.037060955073684454, 0.05911430516730874, 0.04462008634882589, 0.08747915106434977, 0.05915166344493628, 0.01159059428309481, 0.015590217719305188, 0.10474464315320216, 0.05234329067471047, 0.05836631990067902, 0.04432732967900173, 0.02827999782898734, 0.02132973408386592, 0.05891083604505947, 0.1447214399494471, 0.154504137594373, 0.1357534002032011, 0.11863647554550441, 0.18782117884726296, 0.0758034271758891, 0.1523224264383316, 0.14485047979941293, 0.09316065063279483, 0.20797292251260052, 0.1677261716535976, 0.10851256999998324, 0.11633088797210686, 0.15905399506370868, 0.10404843010849531, 0.15375102719952985, 0.23215358385876303, 0.17180516084115352, 0.1553054502414119, 0.09610244358379035, 0.09905224215359458, 0.1603407929501226, 0.14014358962735823, 0.10302777882785567, 0.10675937012438813, 0.11264154642459848, 0.1570188058840652, 0.29385723173618317, 0.11927560737897312, 0.10946636478747092, 0.1055488822561118, 0.10986319067136896, 0.14769810522275587, 0.17095998199957033, 0.08888545866695144, 0.09167037213281279, 0.12256802345115332, 0.11904914412767657, 0.10238761277568918, 0.10232489315732833, 0.1038604014883599, 0.1713607992015539, 0.14011319125852278, 0.16467113558563495, 0.16556019594352092, 0.18384562685124337, 0.15665970983043795, 0.13852441683411598, 0.1143747054400944, 0.16251662055090552, 0.0714644660512286, 0.18277082081523635, 0.19892559266619145, 0.1623564009224215, 0.1290925414932351, 0.13247580027147648, 0.2398329871075769, 0.1665273206608911, 0.06831762966729941, 0.12693411941009183, 0.1771938233005424, 0.1839882724227444, 0.161805430487279, 0.1944688608449313, 0.13010558552078663, 0.13649759333460562, 0.11884072990787607, 0.1549088465230119, 0.20113872874888683, 0.14801764049597327, 0.1354323787194106, 0.11120919949345051, 0.16880327595337746, 0.09664251258777035, 0.1280958457819877, 0.11021927599945378, 0.17666191313295596, 0.33097118860290897, 0.18980759886964677, 0.26388998654100204, 0.17561307747758206, 0.2532484583676823, 0.22399896094875954, 0.15501185470531065, 0.2445183502089593, 0.13500954415048325, 0.12113278070765159, 0.12479994400975206, 0.14194453976327373, 0.14424225195280968, 0.1600937908815761, 0.09668139921080682, 0.1564235096016238, 0.132159574498092, 0.22533086609215508, 0.21912351611160466, 0.13783017263537453, 0.16867572231398476, 0.2814712141069674, 0.1833872151591124, 0.11984506351572853, 0.10175349115724526, 0.15941453136263356, 0.06993763749637912, 0.2234814225906326, 0.3107890312469775, 0.19089650092346055, 0.16617389365790353, 0.2518319005086537, 0.14548671582052786, 0.12649996972252286, 0.11272054541135028, 0.18355964622910947, 0.07580462227305097, 0.1393457396977371, 0.1528920740970681, 0.1342007085200279, 0.06274167020174284, 0.1281291476240562, 0.17431926222578173, 0.10108957637942607, 0.12848765378998173, 0.08463652819515237, 0.14312776256232493, 0.2695417542371058, 0.13976762431763834, 0.08440445718025008, 0.19333641435350143, 0.17231928244713815, 0.050604221290878715, 0.13753104594446, 0.1458449232121629, 0.19380786486210363, 0.12416195364729052, 0.2001097041272348, 0.17840775090359873, 0.2118686021816346, 0.1087313570502785, 0.1187555256089376, 0.12868159660889258, 0.09709523990750314, 0.11367417932037385, 0.20637002142687, 0.1573524831403648, 0.17496512031122563, 0.2048900468094695, 0.26458501214942626, 0.16199653878087, 0.11775821702735079, 0.15660294271524877, 0.1128080862784578, 0.10768990648249466, 0.21773691229041547, 0.16086214642611243, 0.17457276071992614, 0.16094791763011487, 0.14227984112597283, 0.10491344296643812, 0.1494619767031362, 0.07932922427332209, 0.271991427627302, 0.1643890466901564, 0.07970521256567971, 0.1419882374184747, 0.1783679756185701, 0.22523368017808085, 0.16335240715453703, 0.0891989954717217, 0.13005289399335462, 0.15980425561147352, 0.11172215664579023, 0.1488064505880879, 0.1169756428909398, 0.13572799672763194, 0.1266898139710388, 0.11833891933483463], [0.07043587043881416, 0.015213053481983803, 0.025697178357551177, 0.018233074543757305, 0.059829877253862164, 0.03474930391436623, 0.021267878229639704, 0.056126286470962156, 0.09954742606609099, 0.051480874854830966, 0.05674488714806015, 0.029397375370946624, 0.05106997976620352, 0.02952295058827487, 0.058140071154001265, 0.015967652002619882, 0.013155050203955222, 0.014027115858850941, 0.06955316094982048, 0.011593716091386253, 0.04794680783825536, 0.017316136246306763, 0.01542109806436084, 0.03455845226022986, 0.041755511230158235, 0.06914812260337415, 0.030880138548391483, 0.009984048534064524, 0.018410086819541552, 0.026619596098880136, 0.028847954348630966, 0.08529547872322221, 0.05146433501654575, 0.022548597208374453, 0.056028426399514566, 0.028623486756377166, 0.027411014720376943, 0.02820059473085548, 0.054851654060785814, 0.0294509727973491, 0.030412778949304938, 0.05609396905187638, 0.11551243027732258, 0.04176913610389156, 0.033293579810208855, 0.06414417417780047, 0.0953210415619035, 0.057335322602621974, 0.06916186622073574, 0.017170445475306724, 0.034128408803935015, 0.02659348782242066, 0.02529512583878973, 0.028888702565323443, 0.03167821830438991, 0.05050228563167396, 0.03390976347990575, 0.042719816743967035, 0.03259144490584731, 0.044126928738889196, 0.04203690298562569, 0.024719966177438057, 0.00576964756023259, 0.05701047834008933, 0.06863035441886994, 0.04139417053891286, 0.027331094512896194, 0.01973036274824652, 0.04100104102924947, 0.02333359984350541, 0.04661238609602855, 0.010154918699915852, 0.04865088477550496, 0.014024935381096459, 0.03566136989261835, 0.031295040276862925, 0.0760648163756536, 0.04851223052208943, 0.1476134218636059, 0.04914033068944851, 0.20052832521257863, 0.18796728713618172, 0.05617467641469933, 0.012141366492986921, 0.028706879257374716, 0.025612634809447393, 0.07374523237587945, 0.03228293363786033, 0.017573744802164937, 0.049330726521269935, 0.05924492698883819, 0.04566717149329282, 0.05713360016084006, 0.08181224547086224, 0.054628990605593696, 0.14486685875923405, 0.05394209319004609, 0.024905451385664846, 0.02485614022119872, 0.010523779501747942, 0.03608440747484565, 0.09042678160532829, 0.01774473754208415, 0.01920890776560672, 0.05835284824453055, 0.04713278196211304, 0.02458618232800115, 0.10218679048721829, 0.0590695005150572, 0.059229984443875096, 0.015590858360331868, 0.03691417645783194, 0.019550548505879218, 0.01670159008954802, 0.01783638272524601, 0.02753454065250774, 0.008877771606128062, 0.07178795433813526, 0.010798001631854043, 0.04544038648506807, 0.03332826061054103, 0.02876272515183495, 0.05112768533909994, 0.03429033297805056, 0.028102577611383413, 0.07939025849824952, 0.010619825860034796, 0.030369797586313182, 0.05362299458694555, 0.08239927566460065, 0.034330131245716926, 0.044139450446011565, 0.033584428921101556, 0.06075383291669911, 0.03738449315630621, 0.11272730230684243, 0.1281932921659562, 0.056834875666085756, 0.04253655319072066, 0.03422122801684084, 0.037195912952865326, 0.04799702873213157, 0.025290362687120517, 0.027303071016626015, 0.028392735327924454, 0.024763491462856054, 0.0764621555384609, 0.07514996949823634, 0.02773866094949265, 0.0570555396317955, 0.06611041544425873, 0.024977678155166008, 0.032885752903718146, 0.008337719839126354, 0.012244908064002953, 0.04964930035414235, 0.022439134735313636, 0.02457335035526945, 0.07509588369078214, 0.054046851883251826, 0.0457904618533869, 0.051454008151326454, 0.0278252748502118, 0.0552005228406239, 0.03598734413483932, 0.0551769158412372, 0.03372136330712707, 0.06265533592311606, 0.06772918987178034, 0.11333985088933861, 0.016507901994872, 0.041238597233689604, 0.09180374804043001, 0.03451200817982036, 0.022408588894552762, 0.035085241130042466, 0.012688128232595422, 0.03260741017818932, 0.020711935883868608, 0.05548135535190663, 0.035553998839590824, 0.08170585884081741, 0.0249235368063373, 0.07756361377335365, 0.044706052905249025, 0.047569796818518834, 0.07854495708259844, 0.07324919810578709, 0.05501853865421107, 0.033114954919344, 0.07159997168327532, 0.09722044931784754, 0.057767537918182156, 0.046171513986924005, 0.04464755060091134, 0.051219416707153284, 0.08014336889309269, 0.034146465496310306, 0.052582880842589566, 0.02227957011200488, 0.06603572187164138, 0.04097171518350801, 0.05343926372006536, 0.043760742541522755, 0.030040259120024504, 0.00999205319526335, 0.023325170961118514, 0.09253147794234176, 0.020633099690800714, 0.06320422259910453, 0.006585429692941328, 0.03266942499565982, 0.03653693178127851, 0.024181768343213107, 0.04649087305991881, 0.013695981056850045, 0.07864867772666678, 0.03594100730673921, 0.016571221077033592, 0.022025977772089745, 0.035155054722582145, 0.04379045143122635, 0.05353351168694997, 0.062232662232652794, 0.02859711992524324, 0.0309520703740418, 0.018623637658874356, 0.08938804298879639, 0.08307537124041589, 0.07053188423836423, 0.07430618493667535, 0.03152646011702957, 0.046647158826911644, 0.035626233269971226, 0.013342973487001034, 0.011544345555105999, 0.02766447874056476, 0.04199892800721911, 0.02590515207679522, 0.0771363971814994, 0.037502842249288675, 0.12665672663358912, 0.03180393907842377, 0.07575373105224102, 0.0844427079503094, 0.03658289322629571, 0.02619552238273525, 0.06498932237586667, 0.07466670591384172, 0.026725678208975062, 0.1166200248764888, 0.029433241692341627, 0.058160062218385364, 0.05596990494297878, 0.10212673685483395, 0.04302435967650625, 0.05780741662508058, 0.07531408851425495, 0.04608618711391765, 0.12342478554215162, 0.04788935890481357, 0.03076480784183068, 0.06878724156488335, 0.00984739664296109, 0.039130047474417, 0.04789222407365038, 0.03627617843449116, 0.01298723768653168, 0.04637820067845526, 0.10036399918458155, 0.04923128830869833, 0.020881587969920328, 0.09847257406480851, 0.07776992125136238, 0.05063930045693152, 0.1017186724610867, 0.025675134177530007, 0.06711210604877242, 0.0006002298288231325, 0.035839990953043584, 0.02484711762067051, 0.05940558328743904, 0.04045851671347215, 0.06932244591054416, 0.08878356897302213, 0.08411431670068734, 0.0030923682507202634, 0.009421321522114019, 0.042651887727721084, 0.05692643083391651, 0.013054712795682493, 0.018312387626558062, 0.02994705686315654, 0.006611032351370782, 0.08946244544800251, 0.07304154997391087, 0.04841241692643493, 0.07652830723072253, 0.029467822901243647, 0.05952494744692118, 0.022367313992412343, 0.03578509692282927, 0.059134131522789124, 0.07466398630171053, 0.10528799867437733, 0.04569026521377025, 0.08518129331810821, 0.030192354386071527, 0.05210254754450533, 0.028811655187558745, 0.08259026138412376, 0.016690192616454536, 0.061762073572965405, 0.09989660128109878, 0.0709307172726239, 0.059774925767053524, 0.06183050054636213, 0.034323872307375554, 0.0360712077799103, 0.027648207033053044, 0.021818547975271944, 0.02613885485897622, 0.08377556028144975, 0.03729692930656095, 0.04983947019002611, 0.07762451776333394, 0.05132542795411522, 0.04142204464803781, 0.0498765871499575, 0.05501354759138438, 0.018777738160063184, 0.020715461803540107, 0.01969514568636735, 0.01689507708614392, 0.051355676935805436, 0.025821096909743164, 0.04083635127772728, 0.045442286383120284, 0.046264072729935574, 0.08262163268462305, 0.014696289830270314, 0.020794399503257968, 0.01491816325729052, 0.021041721413512866, 0.0703601886127745, 0.09006749402971999, 0.017424445757041537, 0.0399244002126638, 0.046541917498313615, 0.02469262832986011, 0.05281641125498761, 0.01920082553800556, 0.1770799979567528, 0.17134388398018577, 0.13454391591010556, 0.1591853791427228, 0.18262676564195465, 0.1219251684303726, 0.17236419052125948, 0.15589696204950734, 0.11762883243781906, 0.09247603615926159, 0.1391403515252375, 0.12030552066261731, 0.18511768520599414, 0.14955182349489582, 0.14538720099916383, 0.2983764763320646, 0.15554885169671429, 0.1299295231940285, 0.1770320714962098, 0.12329176969585881, 0.14906523508890984, 0.08266046568150483, 0.19464622552116073, 0.1415229615785422, 0.21538640132113812, 0.17797681112443248, 0.17778191835649554, 0.21417049721123713, 0.14146548966246267, 0.16190735082472527, 0.13577368621143604, 0.2580026927734575, 0.13364295054587627, 0.13971883983862016, 0.11675268832233646, 0.11279766748268759, 0.15102640485330937, 0.11695306627981125, 0.21677611545929987, 0.09180719543608928, 0.16035701869235885, 0.14415346236238558, 0.2505720076301406, 0.22638998264747284, 0.10908558844558655, 0.15559374444907711, 0.20463193646602093, 0.21409785675425685, 0.11090576738840151, 0.12243603416267904, 0.047749115018955166, 0.14679205303470935, 0.1547334889971441, 0.1910920372052539, 0.15149416281811653, 0.16907011969916283, 0.13302162259576783, 0.15876393885381762, 0.07645094767212868, 0.12891540664338297, 0.12969810335386184, 0.08537504461503799, 0.14925583776447082, 0.1490884781965325, 0.13691089776975496, 0.26635639129146454, 0.17255762772214028, 0.16186161537564572, 0.20358924483579977, 0.15342223758418716, 0.16962395530314217, 0.17588035023260504, 0.1516341117601241, 0.10203777106418725, 0.2202976071425984, 0.16381057369853222, 0.12246927471771357, 0.21628719814602407, 0.515836110759166, 0.179983256685157, 0.20707327481960097, 0.35053106805970596, 0.20134256942377937, 0.15284705877063737, 0.14073746098626044, 0.22438912952859558, 0.18301627538617582, 0.16314263695911055, 0.06754701416338645, 0.1381117405910646, 0.1556681162647663, 0.18387931939815322, 0.16026277455591387, 0.19890423413486252, 0.15397873917414298, 0.25057884113442513, 0.22423338385358935, 0.2529037034799976, 0.18320756754086864, 0.18318034077603973, 0.13529788432342393, 0.1365534105007687, 0.0842500444982321, 0.15098583283683947, 0.16530606925727862, 0.17477557483700015, 0.13780931972207563, 0.21832942001281247, 0.14960316670758111, 0.1981303014702374, 0.261614736049406, 0.19621592435625293, 0.17930238838157347, 0.13599137775599957, 0.1119213471669824, 0.17358456858463828, 0.062190772544953137, 0.14041211876657703, 0.12658236247877921, 0.138634059337839, 0.1691940880470699, 0.1422204539900826, 0.2420535542431378, 0.18032425774201272, 0.06444804295296631, 0.22173149391047417, 0.14305293109388123, 0.11183927616765423, 0.19542418780826754, 0.10588070557963465, 0.22130567159864212, 0.08419814204136211, 0.1373694013924368, 0.17038127918156887, 0.16621745341727812, 0.22719575392623104, 0.13596631135911713, 0.3292018625765078, 0.17471071783333056, 0.13446798127505089, 0.15789692650639242, 0.13280760827324084, 0.10266580228363315, 0.11330949848577862, 0.13220720984522374, 0.10716197231123525, 0.22267882291588093, 0.23108951837545444, 0.270867086346111, 0.21648527783972604, 0.18071100956970648, 0.08526703387859368, 0.14238813531494912, 0.10307291672835428, 0.10805243461002266, 0.0938073284323177, 0.12612593495437216, 0.11468289495115319, 0.1626057472200163, 0.13082129550316643, 0.1563564309429738, 0.226601131801163, 0.08654669948643254, 0.15365779429914492, 0.21656013995168671, 0.15689563426759937, 0.0837185480181248, 0.1630822079436433, 0.18739137287822463, 0.2510938514024019, 0.11075130874110807, 0.08358015423460353, 0.1790212954003965, 0.14482074026619235, 0.11586242520640935, 0.10393900977027032], [0.050681289736061334, 0.016365308134305864, 0.06119973439302656, 0.033647769070681066, 0.06288847563067271, 0.024734811046190804, 0.04095997871650804, 0.056730450221127084, 0.02274033752450299, 0.026090913076674747, 0.05865331558931259, 0.07218219084484924, 0.021040539722889665, 0.04141446803846667, 0.04293336375286022, 0.006196849787938259, 0.05397227705426274, 0.044419915235090646, 0.12135471637931564, 0.01982975691076248, 0.04066551367061273, 0.04231718774404257, 0.0374067020452311, 0.03531428226720422, 0.03142234110724061, 0.05297997485726111, 0.020074152365146626, 0.02193216647532198, 0.023857519714041583, 0.06222125135302063, 0.035466251128743735, 0.08301435999812619, 0.017728634373915773, 0.04012979221560302, 0.03847882294306352, 0.04561669395996198, 0.06601846191070734, 0.08443490917524023, 0.058156653127122315, 0.05910360291900654, 0.14076022911937008, 0.06597716211070938, 0.03891648131332571, 0.023459550443916552, 0.03551959383091138, 0.06342642257110247, 0.01988984884754304, 0.03295577333999738, 0.03284788517762096, 0.0511461480580751, 0.015628027988808052, 0.02021930687459967, 0.004046368684935114, 0.0768804855103935, 0.010216027618415896, 0.044170182063094074, 0.018013726334057508, 0.05946882001514878, 0.054197093216522094, 0.03969123752246942, 0.03693735061754142, 0.06842324254854072, 0.02862715440231466, 0.07648794971887143, 0.06854911845537924, 0.07456580447333475, 0.060921797694097606, 0.04031563748515422, 0.12973386433816728, 0.024677756648030014, 0.06732924601003047, 0.03264229016138181, 0.046360956039279706, 0.013717720716921313, 0.05332126319708844, 0.05927910217114034, 0.08132112182436452, 0.10879534071371441, 0.04625461920494995, 0.03174202576760323, 0.16921990521011815, 0.06017217682974954, 0.03562711044064453, 0.07929475031672947, 0.10306097341761475, 0.03697590399233084, 0.10209217862856966, 0.015868796974480633, 0.09508215236447512, 0.10782851477063472, 0.041620243085368026, 0.010828535981296052, 0.08168636956402371, 0.06708405190898527, 0.04179189274568231, 0.10547716110464066, 0.06854706533974217, 0.04122038349328984, 0.05345342868578531, 0.026828144384067387, 0.04054645977673992, 0.040848892137047746, 0.02923580168205644, 0.045712466441815904, 0.03983191424800504, 0.11113781542066606, 0.008953864246817126, 0.05297578052587567, 0.004784579148455974, 0.056143584736292405, 0.035838696264451554, 0.05389723874207947, 0.02620233098916229, 0.03704808862699616, 0.035510117323288036, 0.030723174793585658, 0.05902975587354553, 0.03717054012081316, 0.03608692024323729, 0.038588683781844955, 0.06810126345484488, 0.007602748491110341, 0.028194787784389434, 0.010030179476034979, 0.06544889852164254, 0.01141991851205427, 0.054839350688721866, 0.04931930798075853, 0.08599958247354916, 0.05096874124700985, 0.021457814408706564, 0.023836029032545707, 0.024535779488242926, 0.0468599129348032, 0.017878749302678534, 0.029258391699723663, 0.050733559915134986, 0.038368544586363344, 0.044926621109968236, 0.06386503855127, 0.06485675852144919, 0.04406149333883678, 0.004058729034788426, 0.025117950769321575, 0.018662012918221376, 0.03610425681296376, 0.09734011225162015, 0.014841267181890867, 0.027210970011149204, 0.038777489981223504, 0.025757946366924914, 0.05181682356182606, 0.056351229037729, 0.0584300660768584, 0.06759648812153647, 0.03091086441981456, 0.0994344970451728, 0.0499798366499524, 0.059763323365440296, 0.05165820122666417, 0.05027142886613166, 0.02835565667238928, 0.09448936885042537, 0.0589839514765528, 0.04069563241735582, 0.04579625730853408, 0.010981098560976886, 0.031586984893487345, 0.033932209856087164, 0.01002988070174451, 0.045047942624096914, 0.03224497781165185, 0.029148973276718494, 0.034934965322815606, 0.026970851242602355, 0.03322678460409084, 0.021060641870022784, 0.030076073730484616, 0.05649680872598002, 0.02686141941305851, 0.02735361749787004, 0.022375164478416407, 0.05146793179935025, 0.029301309860461665, 0.021815064190436276, 0.015810817525151278, 0.028909197332517757, 0.037955293777368726, 0.04511693267211799, 0.011331306079462653, 0.06189121301436137, 0.021743523069627343, 0.020960207743149613, 0.056066366903964555, 0.03231116397787006, 0.05330003873114625, 0.015092521038417135, 0.042690904585704695, 0.01358220742399534, 0.046093261935898376, 0.019185287359681343, 0.0614840028086497, 0.03185681446695761, 0.016694369710861676, 0.04010176871933284, 0.04326399580966081, 0.051841031940233324, 0.009507501625546045, 0.03025251144032565, 0.0201702734170061, 0.06994951952008471, 0.00781452870972815, 0.046712812562022483, 0.03784443702428572, 0.07255402694065725, 0.0064027589002263645, 0.04094654536475578, 0.06881757098580561, 0.022067271826428272, 0.031540113719060056, 0.13082310347066772, 0.08771078540913521, 0.05291099630055889, 0.01694626516602453, 0.041798664962932955, 0.03858001932742135, 0.06112474204611875, 0.00710126685707139, 0.03435138252473647, 0.030387321847581097, 0.04655796320988767, 0.04989372070638403, 0.02609146274476042, 0.05161343487880884, 0.028327068186274944, 0.038736121233312354, 0.03207150103163815, 0.06105080307010682, 0.08977817326423623, 0.055852417698911125, 0.021850894122654875, 0.02311658245631524, 0.01910216298945729, 0.014139805477292789, 0.013435037145691534, 0.037640362692576264, 0.05093669961957682, 0.09541859519818137, 0.08249190335552539, 0.036071958546076095, 0.07089577600239746, 0.028091701078078443, 0.00498163802999883, 0.040951046131310925, 0.005764045063481336, 0.023775136533884272, 0.0476926734911338, 0.04073321669092102, 0.03434119738578316, 0.0315736070831096, 0.05745521153233225, 0.03665427729908017, 0.10265559033160249, 0.027935915183456197, 0.06371345656413226, 0.13126032517081307, 0.0256892359409962, 0.023629892009100126, 0.020230091477353728, 0.06313548152965885, 0.08550062174758605, 0.10116398649951143, 0.053216565790916645, 0.029969064654001308, 0.03923853701581398, 0.04109274558422547, 0.03773094492874319, 0.08694485836331883, 0.03175077066125889, 0.04496818137986045, 0.05400035417668762, 0.0636114711092124, 0.05693455902679313, 0.06079699431035308, 0.04568202976858424, 0.0646350679979209, 0.012893009829455087, 0.06313570369515689, 0.07287135588065272, 0.07179193799534152, 0.09103176890001183, 0.056821469127410845, 0.02472450907882904, 0.030277413128304387, 0.03873743890454212, 0.031533603886923486, 0.04660470223414802, 0.057694774887133995, 0.01529494540825967, 0.016085396843752073, 0.051217421048110535, 0.030025873904026328, 0.029400435892204126, 0.0345427091533859, 0.05776141687566715, 0.0237968149069216, 0.04343749940275185, 0.03431578241889516, 0.03495850720472875, 0.03127876090847197, 0.029923599250915072, 0.024395604550297705, 0.06228002561857143, 0.03533903456803772, 0.039251077875134446, 0.05457680469619171, 0.042218730124014045, 0.013968138580000209, 0.013812313423371844, 0.03367721749049041, 0.01476953166627115, 0.0523957523757652, 0.03807225625120825, 0.024521982244726633, 0.02003892381194859, 0.051611994633511196, 0.03022462009422241, 0.06221683868657678, 0.010420439986421937, 0.021378520478103912, 0.0052136338725235435, 0.05081498740060676, 0.019461758915455114, 0.01500145520924801, 0.04947466295092337, 0.04177020096610631, 0.03680240422967942, 0.03134153223776769, 0.012188073916120395, 0.04499931902354283, 0.005062539787632564, 0.015497160061532933, 0.04253920768537829, 0.026930193041240977, 0.035708445995565385, 0.012137482427210819, 0.04571832701443665, 0.04925873340858568, 0.04870415852975942, 0.0733695428578123, 0.02364857497835352, 0.06187342445275957, 0.1289663821338646, 0.11500589294178833, 0.15205310056767157, 0.1828126338941436, 0.17666715317435805, 0.09339234626461422, 0.15752663024731223, 0.10746177315952317, 0.1004012157359431, 0.08777509849037855, 0.07644817443384279, 0.14873365691352278, 0.11563090577481255, 0.10624474290037349, 0.14462569428067054, 0.09938811808223687, 0.14891606244829395, 0.11250109952544013, 0.15605451569201487, 0.13383058080029103, 0.15494402528049486, 0.1628093274250146, 0.06654247371179443, 0.1428541465992889, 0.14261750203947868, 0.09176233332724341, 0.1950358425176913, 0.11241812454236132, 0.24515103158210558, 0.1526001179891248, 0.1450632377377441, 0.1521774213160238, 0.11966710895179741, 0.206358315603387, 0.1494618847725853, 0.1791542422987761, 0.17456221935008803, 0.15488276889006938, 0.1701428419760158, 0.11815340348309088, 0.18502892625908698, 0.1772374596687094, 0.14039264481154182, 0.13532223059765755, 0.1963095556223585, 0.2090550983144391, 0.10661113211103987, 0.0901301370392884, 0.11855536215608159, 0.1417251475035183, 0.14163606679968296, 0.11997491541889407, 0.0802198474505736, 0.11726312504540529, 0.08756832369873602, 0.136672337990134, 0.12802530440591997, 0.13784388560921917, 0.18128222004780847, 0.09704598811485114, 0.1668764269279857, 0.15003445888719252, 0.16349811707773518, 0.21782611556831868, 0.12310352657110461, 0.2065993421861241, 0.12440966051672736, 0.08646569334931913, 0.24191715994909888, 0.13713562200146337, 0.2840059539002757, 0.2437972010023171, 0.16045661012251533, 0.10768278186479885, 0.17443222955109614, 0.1340971334326652, 0.2041461601132347, 0.25568097138837464, 0.17736816959035012, 0.12953702570690265, 0.23098742949866483, 0.22698552407804998, 0.11549871730347795, 0.2040520385508576, 0.27368080471792533, 0.15250607303554012, 0.17168661639575036, 0.1647194144466231, 0.2139117893192076, 0.180416586658647, 0.0727801684350256, 0.10694208975520827, 0.19816419320000758, 0.33620246595913367, 0.22309500784162553, 0.28958616898425166, 0.14299559707362808, 0.09471540309248433, 0.20639922469854358, 0.1182769887870358, 0.08839223593954118, 0.11366102559071396, 0.12210022718194993, 0.1741750385131567, 0.20453208456597022, 0.21065223841897904, 0.13426288421596252, 0.13778120429525453, 0.1032755546452057, 0.13290234270595735, 0.12962039139482284, 0.09940150163827405, 0.1278197553549563, 0.1251079266770713, 0.19659250253631225, 0.13705737378087737, 0.10880989638427574, 0.1433671650386626, 0.17287679527315403, 0.15637331552082495, 0.10253309287251004, 0.07091361819015396, 0.12547753345701965, 0.1233991522402052, 0.15518981693012102, 0.1317558155184792, 0.23421898754614018, 0.09850908581527973, 0.1353969241702749, 0.11718220317796355, 0.130679078940903, 0.1538714868647437, 0.10590786339655038, 0.16983257636668223, 0.1349545543592784, 0.08815234316693199, 0.1271388027817011, 0.12017171574576248, 0.14545529089387388, 0.15775653323338878, 0.1624871568093377, 0.10742965875373733, 0.1007414277222368, 0.08125908402425629, 0.11774331661722354, 0.1433219045640961, 0.19916899412149386, 0.12645590434511825, 0.13560033583592984, 0.2561507518253019, 0.1180322083734697, 0.15761489889794783, 0.18047251107711948, 0.19017259380029095, 0.1529176001467051, 0.13487092820146393, 0.1999468185127743, 0.11205483032690902, 0.20343633368611339, 0.14472205281978653, 0.14976539348642673, 0.12469807729846048, 0.15648879561453097, 0.10495835104055944, 0.1498935446744004, 0.1179117946735313, 0.21118716697298714, 0.16908530356182208, 0.09407311497676758, 0.10961012118646216, 0.15878474580184107, 0.1612112067279316, 0.12738525326694214, 0.17723591217110235, 0.16186729974804387, 0.14904367737472057], [0.021143909881732637, 0.05912169025489881, 0.013704890659409425, 0.02192466647454327, 0.006670501362907911, 0.03703350997379711, 0.05016210428889721, 0.005865935236215592, 0.013960354169079614, 0.060342830575762264, 0.04485110782327191, 0.10281685183966353, 0.07623887921292936, 0.029783512413081144, 0.03134728747329885, 0.0690461716224109, 0.006789077888242901, 0.013704271085800664, 0.020704772961776585, 0.022506981397107727, 0.019612067281418753, 0.06327441540516673, 0.06656995328563838, 0.05823865900897692, 0.0821837138444666, 0.056616176715901786, 0.043576046403857975, 0.06162746043335046, 0.02493397475430562, 0.026211874529479012, 0.011147555102774454, 0.03743189101618144, 0.10112213511620799, 0.05375693356918712, 0.0380384219780324, 0.005884717796899138, 0.03600153208319699, 0.02668862828173705, 0.08019631322953971, 0.022516321924124515, 0.02066078227794459, 0.012719149047869348, 0.022011772586753773, 0.0567834826576854, 0.04801206703808519, 0.07646747218865542, 0.014469600583036101, 0.0828999983927896, 0.06019610558606445, 0.01783137059500141, 0.028018231330920133, 0.012983951169336516, 0.017561671256478277, 0.0517720687052896, 0.010497909670154895, 0.0237199820337757, 0.04589540057725484, 0.013503838544561258, 0.033286554783943205, 0.033137129334312294, 0.04473757359289354, 0.02662843292308671, 0.03764580191683866, 0.019554309997587435, 0.014344680370883116, 0.035775750650153045, 0.09828145811033827, 0.004645092253227749, 0.056267809723654104, 0.015572572799189197, 0.06850021140229318, 0.03434351097131449, 0.04821278207424668, 0.02860279280632254, 0.014834790866100981, 0.029365146051972147, 0.03237417087920251, 0.020788144395356218, 0.010662124447164037, 0.07183874596751506, 0.03910421115917064, 0.03026103608370308, 0.08856961593752907, 0.028296974337389393, 0.08667072146049432, 0.041257998410372004, 0.043859824523209565, 0.01971930426905953, 0.038717516788071206, 0.07945356034343282, 0.00671723990836331, 0.0495469203639415, 0.044113273221638896, 0.0069692397430058456, 0.047059218369184, 0.03650336180843654, 0.026302527628778934, 0.017840772409052137, 0.01383759240965329, 0.0629493757902134, 0.023428744133261424, 0.014670021632956642, 0.07291207345382822, 0.07481033207788583, 0.1153905533494488, 0.03645847288651332, 0.004416124373223753, 0.025501006222780676, 0.05163662052983719, 0.04792467172768328, 0.062000039634445024, 0.036506858999810876, 0.006062869149665799, 0.04755571612247056, 0.04527065587500411, 0.015073657080891634, 0.057478389522481355, 0.07311169298425799, 0.02408672747532687, 0.04714310499689272, 0.04468808431298502, 0.035124951297597545, 0.056130063284428856, 0.036963386115648096, 0.007243086968834002, 0.036804338601688226, 0.03704212080206602, 0.03666155896480045, 0.05479147402389396, 0.022233842323804577, 0.01831100675307455, 0.02848671133359594, 0.007240925164472673, 0.009894360705549199, 0.06926829115517678, 0.07647392264897786, 0.0057383954821665206, 0.021153112512923056, 0.036949424163228085, 0.022397631922015743, 0.04471390913691252, 0.027272979082960277, 0.06177400922282569, 0.05167061951191676, 0.07874377222070772, 0.018203509295539513, 0.028838156084079417, 0.04641778827194245, 0.07996816458480974, 0.041697744370227864, 0.06342009085440828, 0.024858417417553645, 0.027248989039611433, 0.03619685002993192, 0.03204309832184546, 0.06705130165022227, 0.09312122008733212, 0.03472410728253665, 0.03640922875474057, 0.022896268975830848, 0.05538754788557849, 0.0243921494937592, 0.043800835753039974, 0.030296555750312346, 0.038406385499383175, 0.028953994323890057, 0.0588956828259172, 0.07643537310462806, 0.021644236159420783, 0.009529800529802039, 0.024373439711428458, 0.027425807878194798, 0.06669408251200953, 0.06052298764247568, 0.018776380269217397, 0.008564264487264859, 0.03726739661707994, 0.03578195596233972, 0.02253624021015581, 0.03400805639103055, 0.022659685703054554, 0.018789622098988584, 0.02942934996568628, 0.020962059760706562, 0.020440212158005566, 0.09597066113905561, 0.04488139893979796, 0.04507770513995521, 0.04843409338425245, 0.03383670167456712, 0.022115897342202165, 0.018588864927991264, 0.06063171467112918, 0.04489130062621929, 0.017542653123758013, 0.017331402463417862, 0.025876887262828892, 0.023483366202262622, 0.06034428614281839, 0.025301808040709268, 0.0296123702860167, 0.03659395936636194, 0.04511890534852301, 0.056001598000406265, 0.08539528465799748, 0.017265459530115608, 0.01576759388685347, 0.05658182916381667, 0.025257495599949074, 0.04199513970243354, 0.033998403683184616, 0.04971701869620912, 0.02292836422941858, 0.0436422172483177, 0.04923532559205929, 0.04768133155941483, 0.03366241284135369, 0.05499275979555904, 0.057361905853594505, 0.024853516370058063, 0.07548350885870957, 0.07160382510553445, 0.049461325360161644, 0.04446782637387515, 0.08647438844725971, 0.02779440725252273, 0.040464147459715605, 0.04077094269075221, 0.0372402924263189, 0.060884546668779474, 0.007225862918271413, 0.023096311769838777, 0.09996452263646549, 0.02887284454529084, 0.04694317903129324, 0.015337630869790673, 0.029323775388841188, 0.021273099118843678, 0.012056391062815825, 0.03435655744866498, 0.046380790055639325, 0.04321016664166124, 0.10106236493635563, 0.02928990472648894, 0.03387196087128213, 0.03638503186765217, 0.027284878343644164, 0.006064865287513503, 0.01489081966405314, 0.027794424489501025, 0.045037347628104116, 0.04160386029510729, 0.05712947094692819, 0.022622760265104236, 0.08864563484225543, 0.06711271891911184, 0.022490972074710076, 0.04745207208719465, 0.09923260223360793, 0.10679758259005125, 0.031015286034333612, 0.04016163849061535, 0.021178956489048658, 0.02701407775372988, 0.013908445008940274, 0.015971222929956935, 0.050651201632835215, 0.04432973136464435, 0.034793913214197086, 0.04496605165543095, 0.026122269055415547, 0.12363089383730005, 0.02453346973315122, 0.0752955032212119, 0.054285518915182164, 0.045840820643089475, 0.04826560383662582, 0.020517642579732404, 0.0797712340229942, 0.05871778571858041, 0.07524962221542675, 0.026509455638006333, 0.12553142008161353, 0.05733492423690135, 0.07455922377806518, 0.015540224736586455, 0.039294955560997616, 0.04444355287799432, 0.04667913533687111, 0.03535363237343488, 0.03850279766465387, 0.022867167210807244, 0.08273851471923052, 0.020972084021195773, 0.0891160587930391, 0.037275149426873655, 0.0386632509499548, 0.0192362149696677, 0.04902239528394515, 0.03822241714524646, 0.029431973816826943, 0.022619705489506165, 0.07538407064613796, 0.04836498076216348, 0.04773961169825447, 0.05855750097262283, 0.026464614596578385, 0.09734448661366779, 0.06055522079188978, 0.05279974118175526, 0.03147693636316446, 0.08571316518129841, 0.045046142317474856, 0.016112993246004466, 0.0399698943440472, 0.043247406175660516, 0.026051472955112977, 0.051507630475586465, 0.00327545847657377, 0.031127945009258487, 0.059441202545478466, 0.029196583725992712, 0.03877942818367193, 0.07119723926148108, 0.0577642705531851, 0.021976429120367093, 0.05252372736351625, 0.038719669495138435, 0.04021903762834207, 0.01938281355485801, 0.0037901163441053927, 0.05169330720579432, 0.10519703339424827, 0.08259374708417924, 0.04833480455882607, 0.017330159485760718, 0.010169560555368662, 0.008188449522300113, 0.08401642598572277, 0.05062437323372691, 0.023383213612701625, 0.004723163315981266, 0.07189989510563112, 0.06102717691852201, 0.026525390266831365, 0.03440150382718252, 0.02101974426618507, 0.010101617174974133, 0.0715231713688662, 0.09659793393145646, 0.03400945833193199, 0.02850132063031197, 0.11678404430107725, 0.19764455576096812, 0.09932869264195043, 0.0924672338090116, 0.18252273090183738, 0.10096656564142435, 0.1772049928624784, 0.1798921228656846, 0.1160578695576518, 0.21877324539086512, 0.12122888643775256, 0.19713547501352527, 0.13814488155466897, 0.11980386330716072, 0.12657448709491761, 0.13245870118900654, 0.09739861838639745, 0.1378066843796161, 0.09982366971070729, 0.07694333536370147, 0.08442560886783947, 0.10307565166224396, 0.14755872318581228, 0.14605729810653195, 0.15180312607797886, 0.19882937202290182, 0.16759760677814486, 0.13060590222237572, 0.1932259291530617, 0.11257331097318281, 0.08885027990946848, 0.16553229502131864, 0.1521786010914272, 0.13679056067860898, 0.14495713456023127, 0.20584791718471437, 0.09527588067876716, 0.0859357673494566, 0.18215874720725322, 0.12841483713277888, 0.18715912566309978, 0.12985266925346467, 0.16919512992664693, 0.10832922983794444, 0.17286122836653264, 0.196145566841287, 0.12897949755912827, 0.2108425499811288, 0.2560179887880241, 0.08164882359485473, 0.13433926318201328, 0.10215768680697489, 0.16040986343737573, 0.1275117803485163, 0.13043224541169982, 0.12177516841479849, 0.21708703990424835, 0.24377182817026494, 0.07476209918217314, 0.06501140102984444, 0.13353084123903705, 0.10131337364474613, 0.12849777381146146, 0.11998280612451416, 0.13615496817135042, 0.1939608832640994, 0.22877977860550727, 0.08582208756237261, 0.15805374470449265, 0.13715223078766178, 0.15010843233716104, 0.10189179301021561, 0.15067591962795104, 0.11515161818674496, 0.1609808900543759, 0.10752231708817905, 0.19127248155493892, 0.12911570799206534, 0.1611547460479121, 0.1906456071282587, 0.12681929049112145, 0.33411073949067827, 0.2897755765626508, 0.25448060354157803, 0.120519052349752, 0.1112107163475406, 0.13795858429324243, 0.16574514489020073, 0.11338383199707155, 0.1855127414267871, 0.23900139866577041, 0.17444154518025537, 0.15584667603815758, 0.09455180501625424, 0.1235712155879986, 0.22292740312555145, 0.14622369240368568, 0.17103557955593834, 0.142652282431241, 0.2634796392052405, 0.10712192123455387, 0.1361927056625005, 0.12474034236924303, 0.15999219230105802, 0.24751280404386983, 0.12028194813718719, 0.28079016194228207, 0.1403610513455445, 0.21901701456837117, 0.15361624169013194, 0.1795623679795573, 0.13269514656595646, 0.14132731804443946, 0.14085162340873672, 0.07842314910263785, 0.08820512662491492, 0.14513854418070088, 0.10029393278302685, 0.30762910242042235, 0.1031563207206707, 0.12956003898814802, 0.0986809116758166, 0.16281427635300547, 0.1051037775112256, 0.10280777369776081, 0.11419003994594659, 0.16195279516039357, 0.12117237979245764, 0.1832364643773725, 0.1540083101680202, 0.11239835181303563, 0.16800986933371714, 0.22267034998343838, 0.15283961239601337, 0.19666201735456146, 0.19463615912583568, 0.12346389433068615, 0.27201235714939337, 0.07027036480365262, 0.28730865087239976, 0.07292172616167415, 0.06667123777010749, 0.12330137643842928, 0.13400432954151786, 0.16945112586742447, 0.08615350485929558, 0.132743532679254, 0.15201775327084527, 0.22499168832455912, 0.08813559648490722, 0.1624774581362163, 0.06736160556395208, 0.3217215042921805, 0.15613185992885023, 0.14721968331404273, 0.15108632825074658, 0.21877362843482726, 0.18082964594566053, 0.0997194204659712, 0.10786465113802303, 0.09195726439957658, 0.13156541202577854, 0.2731273828014251, 0.130902684684242, 0.10314253113803365, 0.09326321448409751, 0.16896121263984712, 0.12325163434950576, 0.08042538117977881, 0.08471890562965025, 0.12182914696994329, 0.10906359406128045, 0.21640797956816613, 0.28808239967592303, 0.1129336174457304, 0.09331457301854126], [0.05178432611207809, 0.05279940410306858, 0.07327264039627007, 0.06353944352257156, 0.029643829686627276, 0.05356108702178444, 0.0548552125391941, 0.0034689141114452675, 0.022960252639266755, 0.024596660495585492, 0.015161948714164958, 0.018113112835694226, 0.05584823868928417, 0.035773042529340715, 0.03531726617966929, 0.05902189198100279, 0.08259206935162507, 0.011942483364574373, 0.03614960155720192, 0.057966521595634764, 0.06985583462782445, 0.04756743343727243, 0.027114226512851256, 0.04342896518327537, 0.05599069656924375, 0.0333427166896722, 0.02943308655953696, 0.043175520315285654, 0.019798900804392273, 0.026427440180052674, 0.05325996850226676, 0.03608125119259761, 0.016657702827585802, 0.16744694792695586, 0.011843977864050578, 0.01492616887609925, 0.03046181432211832, 0.06512924067435727, 0.02772926679632116, 0.06972586015059103, 0.023384081207275875, 0.013617624626344731, 0.04049481012888494, 0.060786012439958514, 0.041601592674851424, 0.02069314949274544, 0.0013943593841113692, 0.041160417961016785, 0.06341622211039066, 0.037152119536673835, 0.017122488371246768, 0.008701265905983746, 0.042520752627282374, 0.005835954864103828, 0.07064351857069039, 0.039471684384249875, 0.04290902896994545, 0.013241662189454563, 0.03687488380819559, 0.015413755111606612, 0.1538194082076511, 0.015161184541460489, 0.02592667723224769, 0.07752796770223687, 0.07011691739241924, 0.03315240895796207, 0.02314822188758802, 0.04350882601894198, 0.009646409645586485, 0.051996275827649145, 0.025487260690199274, 0.03663754593881388, 0.054448454325357755, 0.04138969275499544, 0.06982109254045833, 0.034890287075071566, 0.02996926575208143, 0.03039729822757504, 0.03670788430158169, 0.042242520984502575, 0.1280496660019121, 0.1271523855205986, 0.02220050026212008, 0.022788072463064905, 0.0800137774598214, 0.020113324355934898, 0.06676732817844999, 0.04440544766464061, 0.08239418117990417, 0.05098007168740996, 0.097673797168799, 0.11416896486714964, 0.03338921822667603, 0.05959071226478104, 0.03244644361397913, 0.05651018079069834, 0.03559867325689524, 0.019552911887125626, 0.025404063541622415, 0.06864860263322631, 0.036551295929858764, 0.03731673650984322, 0.04835189214997715, 0.10138976793255537, 0.011510682694103208, 0.10543004669729741, 0.027038600228186098, 0.061078998936159964, 0.026834169665591854, 0.04862015315842244, 0.03988684275217595, 0.035279314183900436, 0.09528874329501584, 0.05013040740103011, 0.0363678561763898, 0.06921416704332636, 0.07084906762165409, 0.06555169219932248, 0.043787597753708406, 0.024411728785883997, 0.06252815383636663, 0.018135568787974697, 0.03183274015393709, 0.022770372001574408, 0.06189729958291977, 0.03940238407061946, 0.07439662161613665, 0.018523659354316133, 0.029557125770577022, 0.03595244499944872, 0.053670200924839706, 0.02580054660117434, 0.04212507587527076, 0.02647509084894292, 0.08198350442633515, 0.060771606156542424, 0.04333939418316849, 0.025085591215399966, 0.04424095709597872, 0.0371140104928805, 0.035602308344095945, 0.10249433648442069, 0.12676273021967183, 0.025474323380377986, 0.04980169822491946, 0.029505271194202286, 0.18829494294139648, 0.04627066874696363, 0.05836252776545383, 0.036512348019788345, 0.0562219555309463, 0.044964167079137224, 0.021139663839412313, 0.05425242008641363, 0.07525443324759122, 0.02152458854740666, 0.07178016322394533, 0.08839344635846154, 0.031118108440310727, 0.02996997438341139, 0.08812903877227538, 0.08394355570236522, 0.03588948789383135, 0.02579562640148065, 0.015594384280003369, 0.044435428515557325, 0.03658323413542202, 0.008352083987706612, 0.02168566044870644, 0.06865011948731638, 0.12547507431478272, 0.020605397951458732, 0.06683341092279842, 0.03675543154860216, 0.04572596874148135, 0.03970410396915771, 0.06955935860112791, 0.023998669498870452, 0.01856266089054125, 0.06431410780116435, 0.03612631248430379, 0.031339105654267535, 0.06666376841284576, 0.04746171713416134, 0.033359038192898996, 0.0696497033500383, 0.07607901964576975, 0.030759774644168156, 0.02495615491493335, 0.08611896961566903, 0.01795002995359321, 0.055064300916367964, 0.03196113265960688, 0.10811561388113808, 0.04443371630904656, 0.10920512880529128, 0.01419658121097112, 0.02874854486435652, 0.03762830063820847, 0.02006640147057272, 0.03299953228223228, 0.030911360461745533, 0.035247808818014405, 0.042367469924952716, 0.024972915003496795, 0.049141859034857446, 0.036424121503988584, 0.00790482557814328, 0.023680084174679174, 0.05258455857514374, 0.026526646651027184, 0.015658386138027475, 0.04632857733315999, 0.06135893895501091, 0.042268525839092276, 0.048016491195847916, 0.04800439849796315, 0.07910237797806341, 0.0642206029395663, 0.020158542695665554, 0.07916643825029174, 0.005465387601420404, 0.04277412088647966, 0.040422675289934686, 0.05588364727314442, 0.04825190235410006, 0.05064868120356433, 0.05031323045372002, 0.05288140998492318, 0.040200203356723634, 0.03995707769307398, 0.005000517788087769, 0.0370870212153081, 0.008658811228439934, 0.018974300999675068, 0.02365964111841975, 0.012900414069243258, 0.029918849505784533, 0.028868163748073484, 0.07411145304720249, 0.05519801390267188, 0.06588414371494325, 0.030240018461500446, 0.034362659338981874, 0.0767993567992122, 0.053812356200069196, 0.010942769266905324, 0.030995543948524905, 0.007603779358173451, 0.07175065351710205, 0.011947760752762758, 0.04652406764967788, 0.029047504931147543, 0.08155142317616171, 0.015740651532166427, 0.02691446142571588, 0.06202406032131084, 0.07398095763018055, 0.10256634108842382, 0.07078142205794012, 0.07879799592398828, 0.044225439985072425, 0.033153129080610896, 0.04429433427210297, 0.0555706199168438, 0.015316421725606967, 0.038895390912770264, 0.0422039216444377, 0.05536613189765523, 0.036071284388702725, 0.021224329961583983, 0.08146431897917102, 0.04935792264258189, 0.06497324985121528, 0.01362831251049835, 0.023874536442059665, 0.02954745008009336, 0.04800124604615474, 0.03444069305494909, 0.0071484803770398425, 0.04692962693591272, 0.09662269389316921, 0.08947595923898682, 0.06159724592561684, 0.05086387913193434, 0.0029746760781328646, 0.02838657598101324, 0.0648410460581222, 0.055904699369303645, 0.06979771919788853, 0.023537530533729062, 0.0627065642226127, 0.019925987130151163, 0.036775441765184366, 0.014631656907318581, 0.017018836675091617, 0.01745693746113008, 0.07773049070589966, 0.009152038743899716, 0.01057239544142278, 0.09952124884171833, 0.028164194063133294, 0.02080892644552214, 0.03801931574520084, 0.05246679553942335, 0.03943856257284361, 0.034115798996701356, 0.0532079128278119, 0.021864490268091043, 0.014224354771056004, 0.0423729780971283, 0.049573147384029244, 0.01839093462143454, 0.057603844080961523, 0.032926784572942604, 0.017095495263234745, 0.030005790909091314, 0.05780837806542555, 0.08939813236675917, 0.0204020973685528, 0.06087798512570801, 0.04299080502542277, 0.042148671383338596, 0.028116077995829047, 0.07797229869831955, 0.008804783536752146, 0.06931333712512447, 0.05097691540516192, 0.04197257075218424, 0.042674740130502375, 0.08956982033146967, 0.03208519485328467, 0.026074894178178043, 0.04432976200816132, 0.0396049875135143, 0.026165258079286546, 0.02853017341676018, 0.1377839162465065, 0.07139307431756489, 0.03147878455028179, 0.027352144693835612, 0.05718953224019178, 0.030849066022182667, 0.026349448598921302, 0.05162353191765086, 0.048604452186414314, 0.06742552027947481, 0.017781354629644947, 0.04609369860601522, 0.017947402272012927, 0.053360065550453244, 0.06153836440775664, 0.1641138219424794, 0.18461246554168964, 0.14662763524440028, 0.19245746635621597, 0.14924820752874499, 0.13388400777213036, 0.15450775352937562, 0.16982882253585324, 0.06154013407086173, 0.18466452887702375, 0.14915903489435875, 0.10233610868453981, 0.17346340411853406, 0.2360281348228455, 0.09939300572319378, 0.11011100479311521, 0.09769681811092362, 0.12011737712929327, 0.16997756616723153, 0.2082800011961691, 0.1815499677773445, 0.1258382612779256, 0.17844487552440938, 0.14439206810728197, 0.16348133975219342, 0.11126238131715406, 0.09332385800418355, 0.17595185687945736, 0.2498415887596146, 0.14595756878054914, 0.19535415205022982, 0.14014594917816503, 0.06834848768888943, 0.3738551664977305, 0.11687965207402745, 0.07906514610494338, 0.1309220360652093, 0.23786950375764604, 0.12972842511390487, 0.18364877289822026, 0.09594728779648581, 0.1942433705252986, 0.1985719511585851, 0.157232467806147, 0.15418542969611385, 0.11583994052583173, 0.21524277515709403, 0.08742470519557115, 0.1585662268823193, 0.10897110426618208, 0.23361359422485675, 0.18160233754784832, 0.13535958504484547, 0.09933200980266256, 0.18838241486059082, 0.119702149813454, 0.12007415444860536, 0.1381188652087604, 0.15150444371806038, 0.16306429680797363, 0.2566996997883243, 0.07607477551866924, 0.08649665862321855, 0.1513495100962539, 0.1156102980096494, 0.1645321365926535, 0.12288021194117686, 0.2283938081874963, 0.16095753969444385, 0.13114668368812532, 0.06428482792069835, 0.11298789477516567, 0.1350200242332874, 0.15339455116660367, 0.10110024032333206, 0.09438240765443734, 0.1235036159895601, 0.22600652499785348, 0.17121596261858943, 0.1483778090726945, 0.2520123142148218, 0.19435161874899942, 0.16825685608050517, 0.18244238360033882, 0.23208434483216656, 0.2003993466496468, 0.20217968902039915, 0.13569464125940878, 0.17584604481535573, 0.19918587869934498, 0.21615831151364312, 0.16176714141282345, 0.11589164379984142, 0.09757549276635533, 0.08381541217527083, 0.14057400846673598, 0.16052713617682457, 0.25592170685770055, 0.15033251305501308, 0.1816306828010467, 0.09630948650620638, 0.13469425300436635, 0.1814603201684452, 0.15818082336937228, 0.2158594912578983, 0.23348697521273168, 0.2104561658756387, 0.18906009623840933, 0.07483990307176307, 0.18141162761997792, 0.09833991061896087, 0.18923266520423276, 0.19921604724180317, 0.18313082085261423, 0.07885684679833152, 0.1937491212400698, 0.15346814157261005, 0.1759994156177967, 0.1502069512442235, 0.09378324262797834, 0.15668241667651361, 0.13431781272013343, 0.14031384500765032, 0.0791653044401638, 0.19352775247346973, 0.15286611903819347, 0.12594642523195476, 0.11930007622727465, 0.13524530004830132, 0.1089372278581704, 0.10774350199367731, 0.28055295047740786, 0.09829975995084933, 0.10185389464060146, 0.1873559336508474, 0.13404085661374754, 0.1556100774436228, 0.07987315436044047, 0.17322959408404368, 0.07779976803689234, 0.2090278562278517, 0.21861970604908085, 0.28579774162461685, 0.12147942017163, 0.1992244129219363, 0.09021253745642402, 0.2014401843470912, 0.15102142528180154, 0.16553172811625466, 0.1682193484157324, 0.19940027606583413, 0.13084158151140138, 0.14533843184190412, 0.17069676951054605, 0.17392112633153317, 0.1545563388255335, 0.16195143152388836, 0.1745502530567108, 0.11347563997391732, 0.14241989732028978, 0.18588256271135423, 0.3324192479973839, 0.18746769055724147, 0.1430589219014491, 0.12420810278384917, 0.12233176193530522, 0.2168518968767697, 0.1334548759604654, 0.14733216034308558, 0.2070533258900527, 0.25059108321945517, 0.10055631023621368, 0.2536197198975471, 0.07107307939159294, 0.11954880965453003, 0.16241701379899057], [0.023167707333942095, 0.057615837187416134, 0.033676370963334076, 0.017508108304032398, 0.049923126991357536, 0.07798024303009433, 0.002821256676989217, 0.05507191583033531, 0.06289734692883588, 0.02043307221855127, 0.07345112356086893, 0.04712430519923087, 0.03212388229346083, 0.028557716192857876, 0.06924733098956846, 0.03310108106703528, 0.024477543399458932, 0.033430288200296705, 0.04399072213639175, 0.015097208538903825, 0.006524037321909301, 0.0230903918254039, 0.06384168436089832, 0.027481328185287215, 0.03272067627779419, 0.04430493692897501, 0.040638129857759324, 0.046468526275167545, 0.029867887421841585, 0.07254691764471993, 0.06491344902784595, 0.01914248219691217, 0.08681411013728188, 0.026083591191338438, 0.06271461197625726, 0.08235272816232136, 0.07315208113962605, 0.03144125390287129, 0.012071505977561878, 0.06812447591895057, 0.0032663611824729393, 0.017386149021706754, 0.032918185235992554, 0.018414959138739976, 0.03623492459976866, 0.07429209657974782, 0.056525402957753795, 0.0440366912422882, 0.03848300961356971, 0.019697288817335522, 0.09949496436503627, 0.09183583946357812, 0.029689827520820885, 0.023212519647072882, 0.0331059533862337, 0.055713740462857875, 0.031914575581228545, 0.09705156523493991, 0.028933719806973974, 0.05439986519876027, 0.020154993793356325, 0.03651458116608762, 0.0365077936270785, 0.03510497172453231, 0.06294978564725288, 0.08835486617059478, 0.026724829766598922, 0.006051693842070358, 0.017063317655195153, 0.050337507780040466, 0.01022515076798417, 0.03399450046521041, 0.0440002522701698, 0.03369975962766236, 0.04385206788297623, 0.07645577402605165, 0.06271458516317992, 0.08080917590808484, 0.012334158264791534, 0.03568720620786471, 0.03273201820951316, 0.08090943383473544, 0.06993094188792091, 0.04577106067670449, 0.036609713964524775, 0.022709037087136702, 0.0027758599824136906, 0.006879149718330272, 0.018492648115141258, 0.021093290622135805, 0.14299274722654975, 0.04217916168272496, 0.02228759871345134, 0.03645702881077605, 0.042492185208585956, 0.08147158915357244, 0.03306456548612445, 0.09367900870500073, 0.019578866946000247, 0.05695640785439361, 0.02988239904234727, 0.00899066711069956, 0.02381563194156174, 0.03902757172322562, 0.06425541780528522, 0.005229041815900635, 0.04802053614008812, 0.02226037960950165, 0.026575346860373696, 0.09985961455611453, 0.0703686002581831, 0.04020171254993447, 0.06847287738515485, 0.07710137930248054, 0.10806780233378373, 0.022551971825680906, 0.07093180511747638, 0.012202949428390111, 0.010540138351761047, 0.003533095042521675, 0.02879831185113759, 0.021527955503833872, 0.01996184579066692, 0.0178849718518435, 0.024487360816208587, 0.06365787305478608, 0.050317938064014724, 0.07212295692654387, 0.019908022368326783, 0.0278404874411682, 0.0321187035390927, 0.044055356974563295, 0.020634357990216345, 0.02145474814178963, 0.02132142394510729, 0.008289634415339078, 0.014532369039502117, 0.052290997512999086, 0.030276802173184774, 0.002466443294261192, 0.07899557766053947, 0.029867088775180524, 0.025524467665461764, 0.041570493335565256, 0.02993314853689123, 0.08215107083801301, 0.03679154110291312, 0.04560676163002368, 0.008738086964454382, 0.06226173526937924, 0.022925834224048643, 0.020890294559179776, 0.022337472952541806, 0.0183721712129491, 0.012324341805651786, 0.06629172547329819, 0.08684339001774789, 0.06724184303874932, 0.054545326143383026, 0.019147814168865164, 0.029434231860983758, 0.06075847157908063, 0.06454481517956143, 0.004925080152573966, 0.052669843313314264, 0.02314649435931877, 0.03450347012990425, 0.0727316291041432, 0.05548411326843405, 0.014651190234167923, 0.01194096172243477, 0.029029735521743857, 0.05040239542722703, 0.028227733395573114, 0.05820861687102626, 0.041552168512416464, 0.026489037479604446, 0.04078444115997803, 0.06838162099161456, 0.04031169596278379, 0.03501511727189345, 0.07316705049766649, 0.051225752254287084, 0.07909134631195376, 0.02858744998041901, 0.046646614904485406, 0.03782448809473746, 0.007666129817915781, 0.02895069248493641, 0.042036014323633526, 0.031413565570067976, 0.019204880058344816, 0.0225245880128275, 0.03760208127899997, 0.02874589420013851, 0.02414891849301996, 0.03539291736219199, 0.04936584016127933, 0.06499999398065191, 0.021592255178538543, 0.010913249983962987, 0.02067744469029769, 0.06915703986681278, 0.024925632056810205, 0.031220643563316237, 0.05572435461104878, 0.06517446284452755, 0.019036363697640838, 0.03924169712850163, 0.05507518702577199, 0.05555123406191988, 0.05894901403676599, 0.010307358705528803, 0.02783294913599328, 0.11889051030119581, 0.06290611097468965, 0.042864852509791815, 0.021338004003008528, 0.0066345306620332264, 0.022460345794717153, 0.04958584912181382, 0.06970047965765962, 0.08320026655471133, 0.04245510272261116, 0.059481690292276686, 0.0374383453069435, 0.06071847795899357, 0.055997675630233945, 0.07082832196066458, 0.05303525959231681, 0.019987731901628357, 0.030214938658079317, 0.012107379002226217, 0.036852808984657454, 0.03650142743642773, 0.07661280672877066, 0.052316956402313326, 0.12406747968446825, 0.05186953424145618, 0.07463839896503957, 0.031570831929603894, 0.051282301034417846, 0.021343159774738937, 0.03991252201939783, 0.04131742002021882, 0.016048479066681, 0.04940459271892906, 0.04694726227992966, 0.06559950374667683, 0.029023085878561103, 0.024505928872273337, 0.1447826963398726, 0.04317254406369982, 0.04858304768980992, 0.018197951327648856, 0.04781154352390478, 0.026072900434355104, 0.08870771860763912, 0.04158853470618206, 0.06527364058720489, 0.03799588877647635, 0.03133914395866375, 0.01648714867300324, 0.01902221405367938, 0.02955078064734417, 0.04304361146604342, 0.07356389170332302, 0.034192660598144416, 0.005389542024086921, 0.15333548578764164, 0.09413033408383209, 0.015553901321254672, 0.07950489589523885, 0.03314483234839093, 0.04961656158669822, 0.033586298175636804, 0.015622544714490013, 0.05334295114622482, 0.027637133232107567, 0.004643885185942054, 0.04642931023432363, 0.019232168110207688, 0.06282433491921233, 0.03584603155632654, 0.00025946554101650575, 0.029827487775154655, 0.04866661256059043, 0.07555634083767092, 0.042419652003915086, 0.07224363875725577, 0.04675850204582657, 0.06352119913865482, 0.03698319714936999, 0.07102644761964198, 0.013534729124888057, 0.02342933785140274, 0.024939752972474503, 0.023655088640929713, 0.04607543890033999, 0.021066088755164417, 0.05895508528356591, 0.004245971457191533, 0.02223286939214074, 0.07350358526192366, 0.017644155943285555, 0.025701328638880968, 0.043413788981495366, 0.024873329318999767, 0.004871193049175124, 0.01352475370250402, 0.04040161170245659, 0.029777780160187717, 0.03187005246628917, 0.03506292115836855, 0.03589365158169981, 0.011217226011438236, 0.09370297193527223, 0.02984083494201543, 0.030254154698923234, 0.037935279730346896, 0.039303175684425144, 0.010671429542614328, 0.0414896595682348, 0.023953853355300044, 0.08460157160316745, 0.016955628675679048, 0.02737421185649451, 0.058389915408746856, 0.08430069057090629, 0.08057695933647695, 0.024387853655723796, 0.11714423586043621, 0.03444054366780385, 0.060351996817776275, 0.05034092453218276, 0.07314008420273181, 0.051566592432678714, 0.03342260816885579, 0.05149574079100163, 0.014131254978447914, 0.0715753955826644, 0.03117987236398603, 0.08176817243257839, 0.06254987625945961, 0.03276232847823732, 0.041042570655624715, 0.017599460458563223, 0.02877074992284179, 0.07900360626198592, 0.0378474400889489, 0.046340478509063684, 0.014541220227857272, 0.21004215663959905, 0.13057211774491495, 0.10987350221482978, 0.19096868172768625, 0.10366528655492491, 0.1839506881491792, 0.11033148489772313, 0.14191984108859493, 0.36015775955973134, 0.134244789219191, 0.19344190466067485, 0.10880459505583971, 0.13751442183650311, 0.12697424709556565, 0.1443177116133513, 0.1391705813547296, 0.1480231256855111, 0.12810615732544853, 0.1431039372278798, 0.11571149056356762, 0.09233987935247923, 0.1507054446565528, 0.14580963720237056, 0.13678283851233222, 0.10242970930712839, 0.18086320059674402, 0.14536575053728398, 0.1389238091125604, 0.11898686117943257, 0.18328993731448728, 0.260629884057468, 0.11971603898752121, 0.1646436023856363, 0.15077586345855268, 0.1402335896367027, 0.2102396081412031, 0.1689048132468616, 0.14371087804677027, 0.3271805549100522, 0.13395917631926077, 0.12545563866414372, 0.08843390346174279, 0.14195881964218232, 0.10107561059656645, 0.16185878085032587, 0.25308207939228705, 0.264045533033148, 0.12022644506707308, 0.17056016071188837, 0.12822803425332233, 0.20864675812903913, 0.26310339810386785, 0.14247753777571265, 0.14362568906959028, 0.13360369620063614, 0.10262025835653467, 0.17063978789073808, 0.16265928144416503, 0.14022373774599645, 0.1275587262165162, 0.14711168023847765, 0.24740290107025256, 0.2086269011300418, 0.1733553244341766, 0.10912357874575163, 0.20126479617770643, 0.15129257444172137, 0.19098814036096298, 0.12521244405258086, 0.14555382512269482, 0.14573480573392686, 0.2134014981528444, 0.1511412567549175, 0.11536543332641164, 0.1426420628183311, 0.23711179683525718, 0.1556299804078956, 0.19104282371699813, 0.12341480341649826, 0.19823427492332077, 0.29467369760236434, 0.24164680752062032, 0.18346010076422847, 0.31899928746204226, 0.16392948586613904, 0.11210912297810278, 0.12438113140242717, 0.052516993450661825, 0.1621178104992836, 0.13284457967646662, 0.2208629953524759, 0.11987216004561033, 0.12297398876398803, 0.24832174692663456, 0.1627074224093268, 0.15974819329717468, 0.20757613493309868, 0.19425032660365107, 0.1262921224077863, 0.11025117590062081, 0.12632267399420663, 0.1343968576721607, 0.09208078075560833, 0.09973543936446791, 0.17467898647150687, 0.16638796926746446, 0.10739189827994955, 0.11073051711484311, 0.12799223239022878, 0.14434962683627683, 0.14883983669982803, 0.18622607653660161, 0.12431288062925301, 0.1000263918972304, 0.21256678407230686, 0.1532697094784629, 0.2137341794948424, 0.16102356115175834, 0.07665591449626992, 0.16296062979005999, 0.11752216235524225, 0.08882467725103901, 0.09883779116095075, 0.15295331516573507, 0.18201135189062168, 0.12288657813182763, 0.06364913199157005, 0.12995840470877387, 0.09491817890516213, 0.06706550492033844, 0.11739846213810867, 0.14385173097252846, 0.12994342002897494, 0.1817089156998742, 0.19084059182674656, 0.11199870672557624, 0.11359170995532505, 0.17224466548331324, 0.11859568902441572, 0.09603008657934205, 0.2745278221705268, 0.1346752540238442, 0.11720841104585318, 0.12143626643885529, 0.09819844482286323, 0.16835246385345537, 0.18251070332142616, 0.08073555485856149, 0.11111367599017198, 0.14631681805176122, 0.12497597569299322, 0.10194929556981211, 0.15429084339449484, 0.09540258396056392, 0.1592711809902422, 0.14437985666576894, 0.16136362758134642, 0.15437774840862523, 0.12394042400222634, 0.124977546173238, 0.1845492632879365, 0.1704499359813429, 0.15097103201814238, 0.050715143161435286, 0.13963688375248065, 0.1459984778757057, 0.14085726181585945, 0.2026166808941672, 0.11210664851410736, 0.08352382378953119, 0.04035801363868579, 0.07889664506599789, 0.16912210642570452, 0.11269110465242017, 0.10380938769348207, 0.12042962690635074], [0.023797948717049534, 0.10413652255890832, 0.05784551034711542, 0.04314720953604387, 0.030783534861139716, 0.006077982627996995, 0.02097926418026609, 0.052515897944930105, 0.04316144728011662, 0.0307343864903575, 0.0247482692958006, 0.05094296621879743, 0.01795117525504001, 0.10047560287339073, 0.07329948411713685, 0.04329930097165127, 0.05961334633250391, 0.02091311057278466, 0.05063590668742696, 0.09129074492281483, 0.025247540287373048, 0.06180954038075382, 0.0509535190799544, 0.03278528047244876, 0.05773344317511205, 0.04223055852156493, 0.05400547930490106, 0.0057491025185182456, 0.024393430775812557, 0.031292763080508, 0.035028496997491006, 0.027230715927397533, 0.06176691524864686, 0.0570552523488239, 0.015639668694817494, 0.06966646535382157, 0.0646335664655893, 0.06764089057762777, 0.05079656681646744, 0.09539607221320753, 0.11950601598307972, 0.03338591255728276, 0.029864252334640875, 0.03668371422757064, 0.030765369001235214, 0.03979819105757822, 0.04061363036594084, 0.03244141424675623, 0.0639591218092509, 0.027016925685588392, 0.06301946134396619, 0.06320370932019527, 0.06916657000059082, 0.017947747011578852, 0.04621204386855807, 0.05262828304342205, 0.043903874578855695, 0.032515303427053076, 0.029418810511067994, 0.011481973549140798, 0.07490409357893853, 0.01697683973508256, 0.030750522217262658, 0.019123207424737273, 0.07404846529806815, 0.032058787802534724, 0.0024306279655936505, 0.048071802743980964, 0.01715724386515156, 0.0634737476526249, 0.005896295300654827, 0.03321052438789799, 0.035807290489995675, 0.039673372352075194, 0.017460693207178867, 0.04807722664648487, 0.13250380844598816, 0.11441618144031494, 0.04347822846724622, 0.027918434972243927, 0.025729409591745467, 0.009233757342782714, 0.01630490784713578, 0.044228665215233644, 0.02522847618937733, 0.08919279015953503, 0.01182131506803055, 0.022431316808046355, 0.016896046187368133, 0.04381582426327852, 0.10188596308111184, 0.028231839626847256, 0.011172031611955215, 0.03167268140391717, 0.02616939112363804, 0.057338593798058654, 0.017697004518742045, 0.05967363745214478, 0.027785101199462533, 0.02422264296441309, 0.01940242157527997, 0.023764022513322776, 0.030411771543684508, 0.09257934311585081, 0.09880516347625563, 0.04890593459769603, 0.06525745314936485, 0.0405969794449066, 0.04204762055568638, 0.041527071472017035, 0.01994780531423467, 0.03485509682626974, 0.06581790009213072, 0.07085005587507641, 0.040702561682630936, 0.05751739105870647, 0.028301090144762592, 0.041804288048297174, 0.017457546501029885, 0.023039077341015783, 0.013774701379119389, 0.05806289928694887, 0.06314476651530113, 0.01600310463653577, 0.06042598175906366, 0.05305412833789184, 0.05671442749219076, 0.022934058177915793, 0.030944271598972624, 0.054328856509058714, 0.023250960023893465, 0.04768171843381659, 0.0074389991125152, 0.0405923254607666, 0.03036799727969112, 0.01898441527549538, 0.04502438158998567, 0.04989614537466438, 0.027887435224387917, 0.049488532972792466, 0.09313286462378118, 0.13442819066826375, 0.026175123376531467, 0.030526207842593713, 0.041517292359663595, 0.028019767337208314, 0.03261712034262958, 0.035205968926029826, 0.018106832829934937, 0.0785769489143164, 0.04860027700722699, 0.04391045910456488, 0.044620323836082415, 0.012925657623958205, 0.07404221402060601, 0.02524382859137991, 0.012804208747712115, 0.013054341243039216, 0.06174948291792985, 0.05656133631184217, 0.05321447437088336, 0.03780553890993038, 0.033533292552155834, 0.015745159001990913, 0.06066001395905211, 0.061817002077136314, 0.06120367208495737, 0.052701616809973796, 0.031364087781478325, 0.02712074209064726, 0.024870044717024413, 0.047706501378167065, 0.015997058287593388, 0.045965941953322584, 0.040151181390448924, 0.03988709173075134, 0.044612708922115066, 0.05434122499859622, 0.02036962098622274, 0.03298957313921663, 0.031027721556564494, 0.042623825927054694, 0.007233177621533434, 0.09307656482222582, 0.059441635385155685, 0.08053829487893852, 0.06488136526557707, 0.09630004830297925, 0.04164341341463789, 0.061160449404269464, 0.0709437101238197, 0.11503079079932745, 0.11579500946907267, 0.02735872730432499, 0.016580107696955244, 0.04948197142972101, 0.020336993301527637, 0.06921364610353786, 0.015404001854720618, 0.05262692706779607, 0.0760384706119376, 0.07838427014048062, 0.058251881686549996, 0.03892957758639128, 0.03518206315235265, 0.01242992787381574, 0.02449761107263546, 0.013942367382227414, 0.014318425580108119, 0.012828152825785501, 0.008646244513652018, 0.048693207302881826, 0.05023530399006221, 0.0547785769336887, 0.016941277933637464, 0.017528534123313524, 0.038956383002861854, 0.054787180101078366, 0.014636216088077955, 0.011526940037466345, 0.04701742061203526, 0.03106460485967898, 0.05892824539313874, 0.030205789653043595, 0.0375806997650333, 0.04990385604962226, 0.08850010878015911, 0.05415264479515534, 0.04491251743128223, 0.043128796612783786, 0.031916362481311925, 0.060210860439486084, 0.07458957618162518, 0.016582789004690224, 0.038952357210819764, 0.015967743933170794, 0.0266195539640443, 0.028925143452661655, 0.03549622431878121, 0.05671848392774982, 0.020219262824544025, 0.009951593219152382, 0.04345281733079784, 0.025546423745371645, 0.03602474837774231, 0.06193907435743078, 0.0427121328820865, 0.021701690838522008, 0.0544050975792831, 0.10239478335866045, 0.043830016042075814, 0.04339510792746179, 0.05281729608654015, 0.07722952282957493, 0.02814258463800915, 0.031151347080125447, 0.07636130772410862, 0.03489763385826542, 0.012392434573191549, 0.09938182850037852, 0.033367220011930314, 0.11729737683649986, 0.06154592569556929, 0.13190154076343583, 0.0724777552269159, 0.044679971441866896, 0.02041760298814024, 0.015077176297293797, 0.0026163255238169504, 0.04494959991725703, 0.05262848988716161, 0.015870491944013104, 0.05833507883512686, 0.06649997115375535, 0.06850970323167502, 0.009201267553913978, 0.017535972837058288, 0.05513237165887991, 0.027194930045234583, 0.03256006211402916, 0.08599475611962619, 0.03849530915519403, 0.08631688077002765, 0.03116881771523866, 0.013789348980231632, 0.05778482852263316, 0.01733546655985617, 0.03914192949812259, 0.018943638330505743, 0.06087014804624262, 0.06628760392026556, 0.001710990465888303, 0.027542092364221334, 0.02007644871369966, 0.08831216442969539, 0.049511416019090725, 0.035454319309323065, 0.0953754491262859, 0.03214174746385506, 0.04604304104202217, 0.0316555938127661, 0.028619231137957786, 0.012659166278617998, 0.027200290745484735, 0.02648115251964379, 0.03252611292766468, 0.02209635060881415, 0.02722830275043605, 0.033295908717498664, 0.0293735136473251, 0.046925298539140535, 0.0315595570305783, 0.028494805052515962, 0.019452899108610807, 0.05777222254583913, 0.0727114963134931, 0.06609700890558382, 0.0638511838511594, 0.026200013573191343, 0.06593282094165202, 0.01984893209150722, 0.008509187553558619, 0.012856809302203119, 0.007419533297164186, 0.037976353534407196, 0.024084145759022044, 0.028350701998738993, 0.06364273132696267, 0.0427913808474137, 0.01651735551985762, 0.027788039146652146, 0.03124973958268041, 0.03750538183075767, 0.029470197773808916, 0.08436194696133176, 0.03924088890574152, 0.017796846842693708, 0.003771461384941734, 0.07768300091547352, 0.036791985433909206, 0.028753530181523775, 0.06293200474653034, 0.0940283218158349, 0.0881332675776174, 0.045074464588035504, 0.023217395796710928, 0.04449224159602196, 0.054035287786034815, 0.02697548415932444, 0.0589829670535701, 0.04673161235968432, 0.07164276535472563, 0.18498358917572807, 0.19332576573135393, 0.13041445685009803, 0.14332417218435195, 0.20283362167256497, 0.10815187282259427, 0.08986420493813292, 0.1414649380791572, 0.10244517662231961, 0.16578389361741083, 0.11381618903889773, 0.16593087524656328, 0.11421194239970177, 0.1517275744868863, 0.14269378907497854, 0.15006720148507627, 0.22590872621343983, 0.1049389613551959, 0.15872359666372501, 0.17396373614188165, 0.12507183627495844, 0.25413869850097165, 0.1324378942409831, 0.14458388120176333, 0.19803869267625196, 0.15857257009033235, 0.21585753007281214, 0.2786790687711008, 0.0993087130688852, 0.10313153011544098, 0.09032180457706414, 0.15978560903139655, 0.17901368048642913, 0.09773486969812263, 0.09145210602230604, 0.13519351250461994, 0.15285462771932926, 0.15095624652120376, 0.16612445034327047, 0.11608517293127314, 0.1642019833408056, 0.13123319033653508, 0.07161648087804356, 0.10858596122312932, 0.20381946957880454, 0.11782116647208891, 0.14120184816420078, 0.14058700131793178, 0.21760866917189092, 0.10322084830653283, 0.2336725217079924, 0.20779204915367788, 0.09063279030904656, 0.18998347733530307, 0.1353434818766771, 0.1811210045050229, 0.1702765856058367, 0.11010447772400034, 0.12187485177550586, 0.09200703713201708, 0.10009553899327595, 0.13057810855248284, 0.16307335196723863, 0.13694201626123922, 0.1358255656856683, 0.24078872775839222, 0.1562788109144857, 0.13535759321624233, 0.10821228651630302, 0.2344905503935391, 0.16462034395625516, 0.12731431352515377, 0.16950927194087737, 0.13041425766723772, 0.08518520802740129, 0.19463680263969207, 0.35238708459561874, 0.21302108953316368, 0.16684179975380822, 0.1574341481130931, 0.18172089731500995, 0.1777782258127005, 0.09435774728415475, 0.1665089039071914, 0.18338565233974688, 0.21523211121318803, 0.2059072889988461, 0.23602051990887812, 0.31040856134026285, 0.09780773232060094, 0.25663974574737014, 0.13273003421002819, 0.11430057877254103, 0.08674567550300591, 0.11391689895742363, 0.16556761167462797, 0.1310039461860734, 0.1394413474706873, 0.0971506433861871, 0.07263405248522758, 0.1013450820239321, 0.136795325745498, 0.16357437346971807, 0.24748203795283075, 0.15688425020104454, 0.18317502412584521, 0.2209395581796285, 0.11426910021973234, 0.1602359461568056, 0.21414840323550088, 0.10759475070141977, 0.12796169612556696, 0.15738438304153182, 0.1364548303066723, 0.11589597985749284, 0.13600987111849172, 0.19128593405888927, 0.1084149320940337, 0.10048918561228823, 0.0685020576741907, 0.07567104718257343, 0.12451131272340014, 0.12602858050095458, 0.12574554165644994, 0.11069225868390453, 0.1220524539389918, 0.1327644009143114, 0.207293126732111, 0.14943864166496262, 0.15486517951132792, 0.09599608759726248, 0.11664170516474594, 0.09812650916677329, 0.126150855794549, 0.1163654538592504, 0.14345736423086736, 0.15358216609925995, 0.11440993016285282, 0.13904092863442438, 0.17809621358831085, 0.1786766324432627, 0.20227742651777886, 0.05714786088755054, 0.15281831515171837, 0.11687864849884665, 0.18751756288111213, 0.08184526386039873, 0.07996595825158781, 0.08561931174969481, 0.2194076121574448, 0.09067767540053015, 0.14143404941405022, 0.09634091909373961, 0.06487870694047983, 0.1621515643332274, 0.1591975139754434, 0.10693212295131338, 0.07522748227441504, 0.29968213530317434, 0.1370846924762572, 0.160732171948879, 0.11070550434411534, 0.18496278222770463, 0.10311436208505785, 0.22009454787738864, 0.1609070238567168, 0.1989040349520022, 0.16323462879705816, 0.11199185789953317, 0.10624205393175926, 0.20794678359262406, 0.14466030613308953, 0.11360051230557504, 0.1603038675121723, 0.12200366179909437, 0.23279262376168083], [0.055080576454319304, 0.022981480935648568, 0.01734876776144149, 0.061756082765397534, 0.0240418998404376, 0.0598867975866362, 0.06082391464001229, 0.05554452313170318, 0.05108011893988137, 0.021163707508915858, 0.008842749896669581, 0.025452819292343436, 0.01479583529515132, 0.0208236851293834, 0.02615321709233667, 0.06788976956158876, 0.0041497029334066375, 0.058902822765371496, 0.05890346627922789, 0.0355591316286835, 0.03637181685095833, 0.046404347259310946, 0.023924985247093345, 0.054592678037982796, 0.04544129429925834, 0.041678810507179274, 0.07390961952267155, 0.03850375910499885, 0.049326470902850555, 0.03140702892485405, 0.04207854369474996, 0.0833599039563729, 0.028517555948647282, 0.04939534603768299, 0.01951512460026049, 0.017587398404195424, 0.010105656373554902, 0.019045259893661546, 0.03714752300912815, 0.07115787766393154, 0.06818930227910319, 0.047338721717918114, 0.004782446072391805, 0.04571091894420885, 0.020621815215676062, 0.06323637913972621, 0.02037456416855416, 0.04969760602820785, 0.06031170442339875, 0.006869587025815442, 0.09107282355187402, 0.017967196068756523, 0.041573913918147166, 0.025783713734258088, 0.0035944285205445226, 0.002659585311888687, 0.02935628624512784, 0.06580150581055111, 0.04808577618771984, 0.04254179323212274, 0.046849911656951716, 0.059380792682209325, 0.018848298688329036, 0.03826495800768176, 0.06715898296885914, 0.026189215563898607, 0.002767253223986876, 0.023254282930265033, 0.040416232490491484, 0.08660563463044745, 0.02004799812341169, 0.048284522377915924, 0.07656691040122703, 0.07517453793796801, 0.008873603130210071, 0.030879560152008653, 0.0038106676102841216, 0.05448986903854436, 0.03324522434042827, 0.04857428747439577, 0.07002890155079865, 0.0330441722255801, 0.07962173196457087, 0.013994356023988897, 0.058304370200682076, 0.03458536109857021, 0.053167578298598535, 0.05600728620324404, 0.06814905968044074, 0.05612425633796281, 0.048925944814278234, 0.015391085612317248, 0.012237300810914849, 0.10962604815440793, 0.06721874548783226, 0.022863390397340543, 0.08669459276021489, 0.0480126224518303, 0.06550851548391004, 0.09172010656085708, 0.04791226876418918, 0.06784765004751182, 0.02419538364084738, 0.029858025955036286, 0.043138502946784424, 0.016343108821480025, 0.08701331598023254, 0.024082973644497897, 0.019381208600656643, 0.04039966966956854, 0.032895608624864014, 0.025032344274222854, 0.022912724544444395, 0.032248750794678926, 0.06471637290932479, 0.06563629128880079, 0.03050955883677929, 0.09114046911558799, 0.053196402356749585, 0.045927262174025665, 0.038178535628943674, 0.028388472048625834, 0.03234757230647149, 0.023035398203759425, 0.03650542641539247, 0.02506918735772131, 0.038601044610503225, 0.06497818345744764, 0.01782709007872449, 0.04137412967881368, 0.02090169394749307, 0.05527358081552291, 0.08739606882896155, 0.03551893116485688, 0.05675514123492664, 0.02969295315955195, 0.0234716393113617, 0.016245166395580577, 0.01875093465881242, 0.03506711932019361, 0.026238264343250665, 0.009600743144420127, 0.06561211355391049, 0.04091261150014978, 0.02388705431874241, 0.038649836750400644, 0.005877560141661595, 0.024369576713070277, 0.053832630716985276, 0.010656731188177102, 0.05070341435531455, 0.03546070848261157, 0.05324159005296327, 0.037743091252782655, 0.18250066756961808, 0.044028586032049316, 0.035456579268699696, 0.07028139646976225, 0.06334021086654355, 0.044529438995185404, 0.03137953977491106, 0.036217733586747805, 0.03748803760015196, 0.03800371819506249, 0.02941950573585928, 0.027010492462244247, 0.04205058531595334, 0.05371621599601162, 0.02030659876313181, 0.02812578624504949, 0.02490850233082329, 0.020704173497975837, 0.01817170707058282, 0.06949932795138129, 0.03274300007990772, 0.045491120657853545, 0.03230540299667947, 0.028724520347051086, 0.12379966300701904, 0.032078003202895486, 0.03489728145782025, 0.02293604234563968, 0.017196132403407848, 0.011413892272919899, 0.040124571326399044, 0.032776884148798646, 0.03954602172598243, 0.02471366893470047, 0.043806742290936174, 0.045110313672452204, 0.0337830793503071, 0.03020088860554801, 0.031399052034342484, 0.03242529575682936, 0.02683255130485181, 0.029048226969016176, 0.04626035337306319, 0.032367030939748215, 0.03418197750204033, 0.03605004077056243, 0.07231150648646778, 0.009461650305667953, 0.016555474139750004, 0.03294894749659204, 0.04173657736710964, 0.02868429690058674, 0.043092997324082165, 0.06200196634557459, 0.04760756495318586, 0.04796427847336858, 0.019707782306678353, 0.04918209014220103, 0.004771866876962445, 0.06880087792993554, 0.06635129647029024, 0.03925513431069352, 0.04819530377825422, 0.07806463527583307, 0.04759793522797766, 0.019224761955199704, 0.0524148126433213, 0.06245669315478975, 0.009378014571754443, 0.03171057594309171, 0.02466965909867037, 0.02794051171100188, 0.07298994629133133, 0.10403480140432235, 0.023605582124042897, 0.05856809979905525, 0.03908146217825913, 0.03145762520181316, 0.05666718668034, 0.00685289588516518, 0.007583612093566767, 0.09119005798692666, 0.018952300869709542, 0.0368419535187704, 0.02204355565951236, 0.06777926137851131, 0.030300648575047814, 0.044954020244580124, 0.0445107004845575, 0.06055835409150009, 0.07212933077807389, 0.08829671243626265, 0.015102241736566348, 0.059249374129238634, 0.013231081557610344, 0.024245654330438664, 0.032771559837724895, 0.03495442012565271, 0.016436330230546095, 0.006575889983064225, 0.022088264550773368, 0.016625370086741545, 0.021898035343075474, 0.030167412478476766, 0.062284354015343615, 0.061970376710016886, 0.02503438206810144, 0.04108864701383057, 0.04302469292475332, 0.034634103442752556, 0.03470228526801352, 0.04299530196153829, 0.028213216029408, 0.035523650266470454, 0.038407998114463784, 0.07453294696226236, 0.03879831225100545, 0.08183135936457304, 0.04358476448443629, 0.03326765156441158, 0.029980155691925078, 0.03461379062144026, 0.027375684660528938, 0.07199970104040639, 0.07062864114320086, 0.024977934794620644, 0.021367021498360464, 0.020929330569361488, 0.05295071795943284, 0.09976112629256903, 0.051250562011714906, 0.03916484701837744, 0.06703047938044034, 0.04988178888696337, 0.04484349673974418, 0.03273670283717013, 0.04382948744140806, 0.03163908461799785, 0.027886941097676757, 0.027950940082871148, 0.03782673656279522, 0.024024710742636554, 0.008269181782980601, 0.08334099690640166, 0.03675586438827938, 0.021847950429805828, 0.02277606403485181, 0.020969144158786344, 0.008137986353117852, 0.06550765746543485, 0.031029445254394127, 0.05031382034142172, 0.06606610491871834, 0.06415450104301976, 0.10054510236988146, 0.031634394244681445, 0.030652336558447252, 0.012042318027646793, 0.044282800818402926, 0.022834256073580157, 0.044491965804369225, 0.04901921984949901, 0.026817231461586013, 0.01501183570062201, 0.07480677742991718, 0.0218173950129459, 0.07478020950070313, 0.02329789823101413, 0.03728343849821437, 0.040319490907413345, 0.0505406474844823, 0.0742512334498667, 0.029172601343523112, 0.012368345896022455, 0.03008280764333904, 0.03017876207107498, 0.10000669577669713, 0.0750516727566719, 0.044646428282102274, 0.016713246117315946, 0.05097964650861198, 0.05375077805271553, 0.01913802548041267, 0.020911338994459763, 0.04056044854223728, 0.037502470696645404, 0.02383491437461588, 0.03953988919214856, 0.03511064077517198, 0.012724458994794519, 0.017277483280087193, 0.04980612238268218, 0.01594528032001108, 0.03203698685542951, 0.044096641452802766, 0.014890526635422102, 0.04574476087826394, 0.03650197901973321, 0.2151645422582665, 0.08905602048241323, 0.17411598845595316, 0.1451227474477022, 0.12815267418421086, 0.23314140827184726, 0.18790399295187768, 0.1528220996260643, 0.14864137396216393, 0.07047441232228471, 0.10272162711067546, 0.19242406492271732, 0.09214072713568326, 0.15446905076744097, 0.14322179219415113, 0.1884527110885228, 0.0852060609407002, 0.17295819977598806, 0.16040335169001935, 0.10043828673059903, 0.12299663432302976, 0.13136396154520974, 0.12243170576590685, 0.17669794990891413, 0.1235281001596201, 0.16729860266129817, 0.14938948946374078, 0.12674165514087485, 0.2045659916174989, 0.1628672283503317, 0.14775018387984845, 0.21638447599064922, 0.11386053020795507, 0.1507679727529326, 0.0800512008549225, 0.15960205436473893, 0.12433109053921317, 0.1731691037815425, 0.1502139992531269, 0.12368950722438675, 0.22630021246450566, 0.17574144317017448, 0.12901430859440757, 0.12557403755284127, 0.17983054471833093, 0.14210911077116767, 0.07542720139627496, 0.0731807251671149, 0.2145084645599127, 0.0999412565462051, 0.19770431061906202, 0.19062976442998458, 0.13320209758896984, 0.08687798654840839, 0.21690103375623304, 0.134753747392566, 0.2029631364970438, 0.1267142981410988, 0.087124076972325, 0.1523825796621461, 0.22478118268472536, 0.12177552081524365, 0.13235434469196106, 0.21736129938114077, 0.15630088956846347, 0.12519873107873625, 0.11094393388878916, 0.17461546246082554, 0.2095036734376223, 0.20605071598002989, 0.08269827978144731, 0.14701702241455356, 0.15059872860870055, 0.14360161858700937, 0.24559117973812167, 0.1602634793568042, 0.1372858211998978, 0.11879467270186833, 0.1435276144935239, 0.18557176084047367, 0.12034171065616033, 0.09579154978235883, 0.1250612872442411, 0.1502161289775564, 0.13580183228177412, 0.16448217233823192, 0.12453157574899736, 0.1265574646212401, 0.18890407477175036, 0.251349893308455, 0.18491974340811854, 0.050805131679460894, 0.1270720305582208, 0.1902878593893782, 0.09700337830450266, 0.11864695562830857, 0.22425800591947573, 0.11104032307142213, 0.13875626568352023, 0.09585638380339069, 0.23155582077320547, 0.16194810670229698, 0.1824812702233753, 0.1154701422239023, 0.15609084358138425, 0.1731727043947866, 0.13361477383202122, 0.2686011821271912, 0.12243410362110985, 0.15017601661384106, 0.17031253045124395, 0.15422384134463726, 0.07765493145392788, 0.12195383544049918, 0.17722815936130865, 0.10729583851512402, 0.15028343746258369, 0.182140882036859, 0.13609168930880486, 0.1425920219551171, 0.12134802077085742, 0.12082884298457254, 0.08184403045884064, 0.13128562139407282, 0.1498925640818573, 0.09607235165012461, 0.08710189872691709, 0.3986900209659531, 0.19144682784474668, 0.13909242506469452, 0.1335331395028099, 0.13782920736458995, 0.1668628978152429, 0.13299540706699894, 0.1366027005978169, 0.13505209267379778, 0.0980666623781285, 0.11731940186432294, 0.07402759706301075, 0.13855268547852195, 0.22648454854084601, 0.14115700137711343, 0.18771340559807517, 0.13250221498310566, 0.18849216461662324, 0.14104184304033557, 0.07518130249433941, 0.18701819612854914, 0.22403864430323725, 0.10978485818111128, 0.09649256619835093, 0.21420250436471355, 0.1614569370905238, 0.07312420320006148, 0.28695805839473204, 0.1735851661332192, 0.18401048897254854, 0.14499329391025728, 0.1666750683779678, 0.18020689307201296, 0.1291361012526097, 0.08834440907042834, 0.14289853373362174, 0.16884361814347007, 0.1084175444538555, 0.10180354734221775, 0.12303044178312826, 0.12615110860356402, 0.08134576687288862, 0.18003849162449762, 0.0812814231481283, 0.11262230229594054, 0.12644271997194137, 0.14853859560624247, 0.1438087994052518, 0.1427582477129275], [0.022158162412984718, 0.013659074771097832, 0.012964561483972977, 0.029239003929579933, 0.044887588930226145, 0.017157944835602276, 0.06327874763237853, 0.016280044463553255, 0.05124279771060233, 0.057811112999315226, 0.049367717076693816, 0.004725277239847328, 0.05016776567865765, 0.027911928970546975, 0.047814856854177294, 0.026630930369719866, 0.03321608235578864, 0.041657766071899284, 0.05370633729222802, 0.0452847748754486, 0.052629332583878315, 0.01253368011901095, 0.03572283312678337, 0.12366942039901212, 0.03645477268183905, 0.09286789013253105, 0.026150853711090265, 0.014739021257076775, 0.11228211329228456, 0.028455117867598613, 0.027650677666608846, 0.051928752838003064, 0.03711119128931915, 0.06545264469159227, 0.03070728613003608, 0.010059558947931134, 0.03231260422316771, 0.03666869507381513, 0.005492353896355076, 0.05986960657361535, 0.06049815873284975, 0.018454359040685722, 0.02596405274685352, 0.010064048223167418, 0.08672905905592827, 0.0801010961614309, 0.06960484124119244, 0.07062029844570546, 0.032040187187733195, 0.03369324021942673, 0.03563528076835698, 0.04561602746346786, 0.049000504321508834, 0.019594378311247117, 0.008009570386005386, 0.012327284540890927, 0.027691425883301327, 0.008081651119995982, 0.05875075814284145, 0.04679039428611437, 0.004936700269970442, 0.09161696048273195, 0.027234220779651118, 0.03642989780693766, 0.08154060601467088, 0.10600180875870491, 0.02897726999024951, 0.042367102202749064, 0.028695941437035802, 0.023357587971634442, 0.04222472859246116, 0.037597772034425894, 0.05627379670078236, 0.025615896428785017, 0.05087208010316376, 0.029052674109416626, 0.02914869556984594, 0.018976696939658255, 0.0650599480216061, 0.058867306929201856, 0.004583746326276132, 0.023326900404607578, 0.020467036726674246, 0.03185629735760872, 0.059963877523137685, 0.07367779365590504, 0.03498382258018659, 0.035649878573754144, 0.03729427481190332, 0.014550398918800058, 0.023540805559605364, 0.021174055441553076, 0.060669291283815145, 0.03796380501420748, 0.03630578007188536, 0.10247880022131628, 0.029291720354869485, 0.04953759707390301, 0.050207100463129824, 0.07509649656112156, 0.044021392466440316, 0.018973464048617793, 0.06039194064214826, 0.013779337168671192, 0.08811813734111287, 0.07253742581533809, 0.026115397246734753, 0.02768974432030753, 0.036995619265062195, 0.04218719411461104, 0.04847941131541326, 0.0060174391781460616, 0.023572603954122435, 0.03444635444470952, 0.03329785841126596, 0.050975915660420736, 0.005547364754977847, 0.03432213328778744, 0.04479501486545609, 0.05512740357869095, 0.012070109782319878, 0.02321942976014989, 0.02234936838278607, 0.03998552636814214, 0.017003392342538122, 0.04733913540539723, 0.02907729809052281, 0.028633443984173, 0.08889006285537636, 0.019908102807558833, 0.029082720077806906, 0.014898938280830701, 0.058116904655171026, 0.016076464258554964, 0.1334871589055946, 0.042307044739925095, 0.06929632997320545, 0.017908504157657587, 0.03987701384410743, 0.01853439033091549, 0.040568661004785574, 0.011564425677211295, 0.00976521073044428, 0.05008458768227889, 0.04695087055405302, 0.011814024783821117, 0.03424418001105228, 0.03942462360306133, 0.05935826203635624, 0.04013255013213043, 0.011148451425645863, 0.05660263611184013, 0.016118319472298026, 0.027728376219109185, 0.013662931066186679, 0.0400312464954632, 0.09782572006506306, 0.02257220995342059, 0.016365034257872932, 0.03609743096955842, 0.02045210950346964, 0.020266896256455974, 0.12337788563942718, 0.0389511467918994, 0.0986533325105425, 0.07261619497571262, 0.030522932816717415, 0.06819268838772852, 0.004613632852617171, 0.06528281832053777, 0.01283014082394901, 0.11820371247707837, 0.04230593008199527, 0.05828534440708257, 0.03874599227621671, 0.0718900278931664, 0.03518877025212973, 0.036557110537204056, 0.04023014973368376, 0.05187710319014807, 0.015244490857566557, 0.09625006872679918, 0.057170590716263944, 0.038635564532371304, 0.0421971379358682, 0.044976677294940724, 0.031030720790788054, 0.02490332549167497, 0.04288559817078133, 0.022947585375438777, 0.09558700430657595, 0.016466161694317576, 0.00780195385525604, 0.05619741007385235, 0.03293343804656498, 0.019341801037831653, 0.026717697488023873, 0.04915264555283132, 0.03455839480363554, 0.04164560059566171, 0.013018590792442762, 0.06362625660615102, 0.014741779173604183, 0.024039327700231827, 0.05521341226994992, 0.05775075676220079, 0.014924645318739839, 0.03573672996172982, 0.018562699194937464, 0.035808064238799196, 0.006220998315726437, 0.0049303240244156655, 0.04629572748296684, 0.04363144988254194, 0.0067461779220931, 0.08099936489616671, 0.02875422540631506, 0.04042542171514323, 0.04978206722185977, 0.026012651449550065, 0.057313113713697086, 0.006077891176251034, 0.04327688906942645, 0.006082979436483115, 0.03682235315922768, 0.04796520160931734, 0.07736548811437623, 0.027281762281012152, 0.035648093588890574, 0.02411895870952116, 0.024944506548044663, 0.03618343199993815, 0.03498433585909586, 0.015358398555808011, 0.03840754612258846, 0.0516419563322298, 0.04746457464211891, 0.04504110528937271, 0.03282102996543531, 0.03477511341653524, 0.04733185373967694, 0.006274098742588033, 0.015468652972260551, 0.037772125985112884, 0.027578968006456574, 0.07541073816678218, 0.011182116201868462, 0.003987635117805293, 0.05164436950919129, 0.018704452274006703, 0.03542915715145008, 0.03614416616337915, 0.0307370352393557, 0.04244652636829884, 0.02670351337010582, 0.05357346700264081, 0.02902326782444312, 0.023140957458846034, 0.059257529135192596, 0.033100307318231756, 0.04094481400604691, 0.0934172211395156, 0.06278184385249211, 0.06906255058223201, 0.06629187869088304, 0.05533773301830215, 0.01769794680688891, 0.07351459394539557, 0.02492805289465093, 0.025806395682476224, 0.030281094180780555, 0.1286095996657687, 0.03204923660133875, 0.05305940285325051, 0.052426614227794835, 0.09816279109086722, 0.05260971690257711, 0.03337608364921424, 0.02868153515361971, 0.01341291731448784, 0.003762970976118419, 0.06607851554309169, 0.039321037024379744, 0.08539985054202619, 0.008549482820765867, 0.03224504292912541, 0.02201743589173402, 0.06025574553096968, 0.07112275253260328, 0.029821485476267916, 0.08498643119368823, 0.0680553977708182, 0.04235721583808622, 0.03572277183974943, 0.045666466692402485, 0.06406748111570074, 0.03440308579874616, 0.0646220368423289, 0.07001048479709895, 0.08175675772250661, 0.034698772754880695, 0.05497112930301697, 0.021759888622909788, 0.04272481546767297, 0.037596676528694174, 0.06301625526600307, 0.057947882676437024, 0.054033985436563535, 0.05874282530238552, 0.057678277183684616, 0.024148223268228675, 0.049579391000612136, 0.0489874693354772, 0.03171938978466055, 0.0416300451803592, 0.01872536264389994, 0.03433576965283963, 0.0382572703153616, 0.04939549159438861, 0.046892486993343606, 0.03274480804740902, 0.020456979907448256, 0.049615596315913627, 0.013955216591937408, 0.04234321558127, 0.02786040955763911, 0.06656544102776436, 0.0666977444122876, 0.01760453770628139, 0.048379256810632446, 0.013980839360174874, 0.06747355399232718, 0.06420333531775302, 0.06669337005023995, 0.10733497794717552, 0.012048498441975926, 0.028372353558698972, 0.027732285182742823, 0.05432679956298202, 0.030655757141029163, 0.049015289818447445, 0.04803597281176237, 0.08414585654052996, 0.06083627163823094, 0.05304405045124793, 0.016112424425720688, 0.01301669664004998, 0.026244337505270398, 0.03774756520626046, 0.025147318749898867, 0.04869814473955382, 0.036988655525830486, 0.21054046619082653, 0.0696273489044078, 0.1652009007070334, 0.20178306998024065, 0.08346187025909463, 0.18877098997754438, 0.17361629994646197, 0.17881624430658358, 0.18588371184324065, 0.1771146098091718, 0.13299317009026004, 0.135515529902712, 0.15467229389375256, 0.1543980037733432, 0.20171429060639876, 0.06562450119564611, 0.13079210755325135, 0.21568129920671064, 0.13971015240155882, 0.1408543200382302, 0.10836184220088106, 0.1412264395865702, 0.10067797265946866, 0.18479952889104045, 0.13353493214855272, 0.14746573543356312, 0.13026503906134637, 0.15345304964050172, 0.24015501982742743, 0.11343485345282864, 0.09383404957911662, 0.24767667025087342, 0.14832144032322592, 0.11855479525101763, 0.09015627595926486, 0.11449548686223646, 0.15109513826187582, 0.07921765122802989, 0.14995688482397987, 0.18257151538085553, 0.2101228256980258, 0.09326359752805964, 0.09244432778007562, 0.11982690723192309, 0.21054599734563983, 0.12180794165619921, 0.24846040884092932, 0.17023702482542685, 0.14812222681939602, 0.1337962140960078, 0.14310433559360045, 0.09167405701572857, 0.08918789485769887, 0.0739050459777636, 0.13111702076369716, 0.07412004855371292, 0.07907974774078017, 0.09106822702432833, 0.11578431488164972, 0.11983590110415414, 0.08555715903639795, 0.14309201689977802, 0.07735470159640236, 0.13415400780016376, 0.13391840511993056, 0.18148851220405873, 0.10041126680950965, 0.10007993378225835, 0.18203703115784353, 0.1429463989071308, 0.12892184178194693, 0.16553332157913717, 0.12205614648278683, 0.10143727304474001, 0.16672956787290114, 0.1050094031398335, 0.12995223004010417, 0.09669690483039427, 0.11047604568903485, 0.2345983236427269, 0.061874853206738356, 0.12609077917952694, 0.22432444106426933, 0.09740087834577407, 0.10776394888037637, 0.16870405224542465, 0.12341250515272542, 0.19017844671203246, 0.19813388676172305, 0.190923176104984, 0.1492066702414905, 0.2067764157489423, 0.17556433896383933, 0.13321515172719955, 0.17497716321339532, 0.2789407031190011, 0.14085310961930983, 0.17043729553059225, 0.08648925821386999, 0.18913831381547838, 0.24185118445705986, 0.10648219951338346, 0.0965990141154297, 0.09431642450151906, 0.13808555570581268, 0.228338236169469, 0.2610520291472635, 0.1098492555320263, 0.1579931011844066, 0.16128111991190142, 0.11369273396989993, 0.12820901229016243, 0.24527594987903875, 0.16917415443928013, 0.1812351516057407, 0.17674379261030307, 0.18488681694913298, 0.12961679078157873, 0.11989407782112399, 0.22083366950673444, 0.09614982612190709, 0.16399702417754358, 0.1819887216533384, 0.13691535640147426, 0.09218329864163553, 0.16753546172572722, 0.10399948475101303, 0.14048213920285627, 0.18723588767311267, 0.17854448227632433, 0.11825075793650844, 0.1733880210667849, 0.18326765947764923, 0.13805811443636495, 0.17334130502516226, 0.16628857702016833, 0.22352478316714688, 0.08033030200749636, 0.12866275084595527, 0.08702104580738852, 0.11550411822334414, 0.16048504730626462, 0.08812158473677213, 0.16797649854373548, 0.13082797578986616, 0.09704300803282569, 0.15776212567523604, 0.15034532204510706, 0.09555693535554795, 0.13127123426285484, 0.12444731373820575, 0.2764951053165621, 0.09494202722224498, 0.18200926813146762, 0.11791648313162789, 0.2280598857830609, 0.2834802337231175, 0.10540524843118845, 0.1711828676202605, 0.14771411646037333, 0.24170797198049485, 0.18835235357044205, 0.19120547950508135, 0.07354970375496535, 0.12856672938552596, 0.2299722251031668, 0.10371974774546201, 0.19069045391534606, 0.07614462741560514, 0.08470651032703538, 0.10379182129737832, 0.18442336439846024, 0.13204565722375147, 0.1580120541996533, 0.17498013563454154, 0.1663189294237283], [0.02408653212290618, 0.07431155521302454, 0.012880769659644895, 0.10782218688438017, 0.026117297144786968, 0.05868421574573844, 0.0495106231180891, 0.05349331122312335, 0.05426078576654677, 0.045685128594237956, 0.017966544894020886, 0.049641371344126044, 0.048043262138361895, 0.028296568310789527, 0.03705674159010092, 0.003468013958134238, 0.029140571207408945, 0.031023835575568582, 0.03266770129783019, 0.04194762309893005, 0.06516366100479519, 0.014296145828050232, 0.08155986546508728, 0.021847174765782493, 0.055054506482256044, 0.020401450024256786, 0.06814072464382456, 0.05512242017674351, 0.05156538584419797, 0.06915838052068027, 0.05237637801216014, 0.05000407950231626, 0.027617237928714004, 0.025431891685471903, 0.0686988043749044, 0.04098385001622862, 0.03135820805665947, 0.022538115210350484, 0.05534500319270357, 0.047571700547010674, 0.028059450691686045, 0.05504819008732035, 0.031539497018281015, 0.0587201988955419, 0.04181438508713919, 0.017781628506077875, 0.013482713670049225, 0.021405578703589497, 0.06710396253413732, 0.02728478832831306, 0.08100434446767454, 0.09919535503872942, 0.015695986690961065, 0.07223502026810762, 0.03950368387684707, 0.03561097662895918, 0.02141961918002175, 0.07149117953714824, 0.0710263250455741, 0.021437995714105425, 0.04524429478952962, 0.03757680420793834, 0.057994518278827595, 0.016099494776778644, 0.020398282250689886, 0.006800494034729538, 0.010586609245247899, 0.031590832570087046, 0.02997125183502513, 0.05448701153058679, 0.05225723984861567, 0.046048032104848854, 0.09830946628484996, 0.08085104261314677, 0.0047288835987508784, 0.046405454256361535, 0.01150946940235313, 0.02394177214873414, 0.06512415385054005, 0.04614036102148314, 0.04611996010005955, 0.06891227477500517, 0.05130039986162897, 0.07454760222425384, 0.03548876645283834, 0.03666437816836181, 0.03891725123168961, 0.08608991190070107, 0.04928981742611335, 0.019457878680118633, 0.0769536852115585, 0.04356263220430382, 0.08369354290827628, 0.04648962433660223, 0.03241376996400856, 0.05736857464897537, 0.046880865439532265, 0.03134946507822362, 0.07333210414095272, 0.02923232747331983, 0.030874601647918744, 0.04196711620616336, 0.04349312887737348, 0.0822422199792439, 0.030427388246020967, 0.021985300418530262, 0.05787035457849984, 0.014406044013617982, 0.04909505872356315, 0.046837366967191624, 0.07711235734243548, 0.058174441688724106, 0.021348847977576718, 0.03535613365050766, 0.02941729557219773, 0.03556129582706959, 0.016416523027263822, 0.03333779840519832, 0.02151016502701227, 0.0235848039043166, 0.05318039111913212, 0.019035373528998707, 0.055387138028539, 0.04460431259846495, 0.02122006476706555, 0.03150040546672479, 0.03885882170570474, 0.037172145075014526, 0.009002945584905966, 0.05321920113337617, 0.02240022321441962, 0.03897676094164772, 0.005941979517604435, 0.05269258463334653, 0.044022043641175956, 0.03429266188534037, 0.005195191263356397, 0.032792512342453964, 0.032592099911022576, 0.08606384192863781, 0.08264930378044806, 0.01696481023945155, 0.020838001397468393, 0.03225672576997069, 0.0399231476589076, 0.05783965743537392, 0.06332948180516401, 0.023581339271679044, 0.0005260012356654531, 0.026280872238379334, 0.12178641458552693, 0.022950647811916088, 0.0707355640347927, 0.06696601308161212, 0.04589985154809491, 0.099975171258613, 0.014383020198663637, 0.04328695163431187, 0.009853422882095461, 0.019094316333892847, 0.012710174327836403, 0.015133663790390618, 0.028122930652311737, 0.041486549251262224, 0.044019818155755924, 0.05702578477681645, 0.03922071398025559, 0.05613683933211912, 0.02307064016349614, 0.003471217402670112, 0.017144086305052042, 0.008017218816319421, 0.03482972016377795, 0.022816172568127516, 0.004959809312206363, 0.04501968164057021, 0.07226480576660364, 0.033487848216487516, 0.07005740768246113, 0.0683054029040279, 0.008131725499556671, 0.05484832540875482, 0.09447901134168911, 0.044456220141822295, 0.08118229137072641, 0.05604561741253542, 0.02569672636567585, 0.06107056430811363, 0.06519460329605688, 0.031081891633690368, 0.06532827031708534, 0.030066532105387702, 0.016449409266633373, 0.022914402276998567, 0.03891789474554601, 0.0645214035325954, 0.07220987726243273, 0.06273208261137048, 0.01541240871207969, 0.05553856296765228, 0.035717558611424706, 0.03508124981195696, 0.08978364313201559, 0.024825176862519116, 0.05265049959322619, 0.04857191643227012, 0.08025146389920866, 0.1604398021534566, 0.026134716068965294, 0.031242300868935646, 0.0530373701645482, 0.057348644871625214, 0.03572551443451836, 0.032670712023372614, 0.01887515773095431, 0.04354277520530647, 0.01548959781611038, 0.03489452737173246, 0.04374352088498493, 0.05432342494567556, 0.036146226939895464, 0.05871990778213067, 0.018175301938167503, 0.02868597463314091, 0.14429938679020252, 0.049616190034054944, 0.04623577344201265, 0.06308983801113022, 0.050401280769297195, 0.05744160964123665, 0.06608485109022548, 0.03550627922278739, 0.019002948857603535, 0.011494820843630982, 0.05562473253737535, 0.04379640393439801, 0.03942019561485898, 0.049988868826579665, 0.048212410521603404, 0.041373290812536594, 0.038960217272922884, 0.014477846561931075, 0.019593112350952242, 0.01700125304200957, 0.008461233322328378, 0.011593202812476985, 0.03911384471481846, 0.05271837498331743, 0.10625257997983888, 0.058728606710510875, 0.01116220174627679, 0.02504049928017682, 0.016738389122990832, 0.045568288694466316, 0.009388721608106167, 0.08101479390696173, 0.028847172938948198, 0.016288477176379774, 0.015041462235873746, 0.08849614810559059, 0.0843459357237143, 0.01929384776421132, 0.047531044260869106, 0.049618737276403174, 0.057434435227825764, 0.03663525533592028, 0.11033335415225838, 0.045016720710742864, 0.04848916744512897, 0.08673031544012409, 0.05788914671528244, 0.03210635228653348, 0.027654165281884135, 0.07534695368620657, 0.012988157949650721, 0.05801928973185921, 0.05171387283612163, 0.011881654068166691, 0.04594022821214411, 0.04361058930836378, 0.017619794347293435, 0.023920147401851513, 0.02431305283079705, 0.029956874279906193, 0.05521131701947701, 0.04660759421606218, 0.050930375563761884, 0.08447910478759198, 0.042325695150441704, 0.020010249140942772, 0.011263678710336887, 0.046729026812939875, 0.028566780928221923, 0.03424275891795274, 0.03244508763835315, 0.06797476701678769, 0.06046718196763147, 0.026933194190684347, 0.03477442776784301, 0.04539670798206522, 0.039472829685696674, 0.016071938594142278, 0.03803977412321875, 0.04527515664155926, 0.020366922441509464, 0.015850765179962884, 0.04191220685419056, 0.029924489828127048, 0.0722058093355548, 0.08969698326602098, 0.02969126010523929, 0.023799505790755637, 0.08237253919604325, 0.010684979722775038, 0.041705998967611985, 0.04438928703987791, 0.04421115244528459, 0.0316122830319669, 0.07173005341281814, 0.05097890723376505, 0.019573552211025552, 0.020815742712828423, 0.02817473160253177, 0.02230281513484736, 0.007085213963423045, 0.04848504589209634, 0.0023669435552531675, 0.08077801145132511, 0.04372876986200291, 0.029881169471228798, 0.03865129231745678, 0.06261408591883318, 0.0461780640386766, 0.022083635464490905, 0.05677143209463647, 0.03445482354671244, 0.04785708362056364, 0.04450911851299386, 0.05474031467231051, 0.03985593493487086, 0.05172019689193657, 0.031944136999006716, 0.035875269301956704, 0.07874549591853734, 0.07907437746443095, 0.012614155740236804, 0.057672274884797876, 0.046173126602004615, 0.034254843954958265, 0.050028111680500933, 0.04616787506928367, 0.062075962778180845, 0.16803139640438944, 0.18448212334225256, 0.15579450545051407, 0.17785157107057112, 0.08523872692979152, 0.13857419722743575, 0.11844938921351587, 0.14617832467680977, 0.1848864645486878, 0.12584315657976175, 0.09332811745304255, 0.1928764858072804, 0.22530374657963553, 0.15130006678162083, 0.17980265911788712, 0.10204098863346923, 0.09272731299842558, 0.14871876416427476, 0.10936802208063104, 0.18152231200327798, 0.2296911474437483, 0.16349945007072342, 0.18827154661618895, 0.1441821906595461, 0.17566918575715634, 0.08552854565242607, 0.17443745427073973, 0.1262708021808536, 0.12918384385205087, 0.1868611940693471, 0.13061878782126213, 0.17148413935736304, 0.06381404390859027, 0.08428336932293831, 0.17792807261068977, 0.20044955605220413, 0.1943985186517239, 0.07760725014152066, 0.10716205658090693, 0.1830342937741549, 0.11836499696777714, 0.15961133935038122, 0.16369279534105333, 0.1688562585942207, 0.10937172228530531, 0.3763030932074593, 0.15389074631516012, 0.13462398741995135, 0.21793977237276493, 0.15447222237144748, 0.26416075265695976, 0.1779510399266597, 0.11752639882146351, 0.1487818285222015, 0.13233367563976398, 0.118668329481396, 0.19295972892113272, 0.1583821359541147, 0.17861756706430068, 0.14291097500151204, 0.14638873838609265, 0.2655569325772024, 0.15952549153758636, 0.16446052269349176, 0.10033035260294715, 0.10925515434674679, 0.11624781339759789, 0.12773650458022473, 0.08862904903869476, 0.12668445901644806, 0.13709403874893344, 0.15205098616500057, 0.19529098043999366, 0.2065060786422222, 0.08896393671391473, 0.10265314651112403, 0.10984800680870972, 0.24140847756737666, 0.16617484360692963, 0.22748139746967824, 0.16239358683026608, 0.11646269339947932, 0.2465728141607777, 0.18627147490699447, 0.17711716854283888, 0.11852260423643936, 0.169950446654712, 0.2411372211551474, 0.13399957979638732, 0.10734613218735303, 0.17232801584947496, 0.1784520614291391, 0.28269474845259424, 0.15160257958116072, 0.1485020378904958, 0.2045927893730902, 0.1378496006251343, 0.14418969832120404, 0.16611568629741671, 0.08421477381019823, 0.12052734142109273, 0.16615304074460463, 0.13636665358658762, 0.19502579144412474, 0.08216663008375515, 0.11818279061586627, 0.11650541046213721, 0.12193216281312129, 0.1084634331205199, 0.14743991827051486, 0.16686337278975596, 0.09351734883121907, 0.1126747333534783, 0.11886664666235448, 0.13316232230394118, 0.15673901525235948, 0.1378705914342596, 0.19227997910591865, 0.093760704321246, 0.12451180301967169, 0.15344307517572758, 0.1654440570142, 0.1342379863584234, 0.14151174605133074, 0.18634025428083636, 0.07054440211504698, 0.10742536100048213, 0.11094802479830482, 0.11092671989313058, 0.15897056808875454, 0.12146412139578212, 0.15018531692124185, 0.17609765873320643, 0.18623762914249975, 0.11845864355564119, 0.07569693329353487, 0.12741433396454782, 0.1074342169768868, 0.12879850162613776, 0.17507554422463142, 0.13305749083238264, 0.11549594406519206, 0.20694140044431533, 0.12236972159195332, 0.09404956543397519, 0.20833486841330606, 0.12376587852955827, 0.08429718188821309, 0.13268779212188336, 0.07710966071294201, 0.354830292203734, 0.1463543103947755, 0.15032541908083424, 0.16541603351792983, 0.157345327879152, 0.15702908678400904, 0.13792738919296574, 0.15694035848061885, 0.15258622115417836, 0.09339020121842624, 0.0900068964749094, 0.17652603977870557, 0.16603759129441556, 0.09767775018248828, 0.2451455770360847, 0.13996354364339383, 0.13839405931292043, 0.18929793589538146, 0.1594462167591818, 0.05963131109432829, 0.25080348875734115, 0.2210599872013254, 0.23648565785298425, 0.157221298244211, 0.12605301870573915, 0.1407862761087956], [0.03259535961514039, 0.01494155287922871, 0.07190242319578125, 0.01741582152223395, 0.07054485410692231, 0.07499670594810479, 0.06363048541149305, 0.08349704901657759, 0.009124536187418047, 0.03211327963658879, 0.036093650325652094, 0.022286744525415764, 0.0411521173983572, 0.02518106300774361, 0.08658819846929082, 0.059819443136333465, 0.04140172033540664, 0.011852295663688454, 0.05267529785933514, 0.01685481916572298, 0.027225567816546368, 0.03914189885460562, 0.05012404887125858, 0.021414166549220685, 0.02101548864776569, 0.005025931318560916, 0.028910518834187143, 0.007498383854380659, 0.06551046900811695, 0.011436954392270457, 0.030534125361291152, 0.03074113189453079, 0.01697781458196621, 0.06021693551672563, 0.040237645904022845, 0.05235500415907272, 0.02518696188476057, 0.03390605178391261, 0.025282134902813745, 0.05652922190605633, 0.030787798140438336, 0.014710378187197833, 0.04522511960878488, 0.04511414028163399, 0.05101659109876041, 0.03190214771987691, 0.013242955920436691, 0.05319764341918692, 0.028807388077820503, 0.08124897932453502, 0.028986129797093814, 0.0678363349288702, 0.010644172134268428, 0.08818626554021913, 0.07804044988006353, 0.017842814033370347, 0.038392323955533006, 0.06265284230692253, 0.11974986943025744, 0.019993475645840652, 0.03074487040360128, 0.036993956854266506, 0.02654241848616831, 0.07670466833177113, 0.06438228196554607, 0.02772322810825802, 0.010396937366514918, 0.04249221968254255, 0.06259513290358648, 0.01947626095986174, 0.01955516801606263, 0.015898909017954384, 0.10557830769328341, 0.019579960536512158, 0.055665752715280944, 0.027474921775020422, 0.03386487838842216, 0.037955565738581845, 0.04428308810137453, 0.006814110768778671, 0.03453586415778245, 0.05105805560766209, 0.0102700425627371, 0.009435881980724875, 0.06593861256635959, 0.018127431018999027, 0.01673679949054795, 0.023368483657137524, 0.03956414736627091, 0.07209029093745255, 0.03670869635478143, 0.04070386020166259, 0.07605947674282136, 0.031035097068055507, 0.08284675528205211, 0.038354188098662326, 0.0610436593002129, 0.03309048607104248, 0.021223977561138814, 0.0349634025065649, 0.007804311490843013, 0.021416958939704685, 0.039563342973950415, 0.08593877807499901, 0.0260837807980997, 0.1122236148183865, 0.014561401856612536, 0.027644918600638068, 0.12210237988901716, 0.051733331469398354, 0.01820017489784908, 0.04217679064059931, 0.02583430426555776, 0.012966361790595037, 0.0738651174751501, 0.03395087558836226, 0.028227974713269263, 0.06362921753597837, 0.01847312244917116, 0.1265255877027108, 0.023220260965547735, 0.037291536047574014, 0.017306454810163668, 0.07533325603412044, 0.024390172986914555, 0.08665340021252634, 0.021504716226650823, 0.04873677089269604, 0.03364718301341899, 0.0533777583510645, 0.01094614388421178, 0.023686427382692218, 0.04765680525451899, 0.09918311295369941, 0.023889530697957646, 0.012546447931878991, 0.039082201453106064, 0.02361244244140483, 0.05340269451299983, 0.012042770019522118, 0.008759568069851207, 0.028402328663956256, 0.057490003415413445, 0.02569459281080673, 0.033160698029302785, 0.03759874879652935, 0.023078119096856926, 0.022365301096391295, 0.02357944894972588, 0.026635580523420247, 0.052486778942928206, 0.030305712416227308, 0.05914131359707925, 0.026401630677883665, 0.09251441716426805, 0.040102523315938256, 0.03635419299826026, 0.009420294964295483, 0.01871883557478507, 0.09043697057472122, 0.047675857861195846, 0.048592359488529545, 0.007187399558813101, 0.035487854808208444, 0.0352220184680435, 0.020083376063754963, 0.054241047511177684, 0.02266951461112307, 0.10483376982231295, 0.03569970876278897, 0.0784514713731985, 0.05457878503347597, 0.016638177161615704, 0.02068017004808832, 0.019146820169783408, 0.01903980726286048, 0.021469866886975306, 0.04965221148825461, 0.011376781058647941, 0.04613354283895704, 0.06847756584325145, 0.03738754218624484, 0.034181540831923485, 0.041303879416157166, 0.0055221748264176, 0.11239904895304673, 0.03191473262925302, 0.10301744430175713, 0.02395081773190008, 0.035277962038714084, 0.09700009944818674, 0.05842994350279051, 0.06782479764473054, 0.07694040124695148, 0.05662570684967984, 0.029262312154676166, 0.05175549822348741, 0.04910617848978408, 0.05388180973128446, 0.059068209656904784, 0.038300542791764584, 0.07306848562532857, 0.059520638202347105, 0.031185016644397573, 0.09728030376737157, 0.020812098049528657, 0.09494192763081483, 0.06216638796632329, 0.03956795482325458, 0.052041777619911786, 0.021833634161720836, 0.030558801053332228, 0.033771549727046685, 0.02713480171927762, 0.019256834226149707, 0.016965162639896718, 0.022458773399252566, 0.02862096249666666, 0.02169786997499966, 0.04931986339450364, 0.01523022534280655, 0.02502419501392832, 0.031155173689307227, 0.03607455175369978, 0.02165744926089481, 0.010539173080976452, 0.059528276098952185, 0.014111645042806143, 0.05182494409382344, 0.01128809105965399, 0.013980047416783149, 0.049221685396567474, 0.08381226355390203, 0.05750295796221303, 0.06536742507089531, 0.05688269104387972, 0.06406923162660773, 0.11406188875797296, 0.034775105755656, 0.09531783165350076, 0.06650789250289241, 0.023214063314240307, 0.09643923881794177, 0.026147561448235667, 0.04446078985629063, 0.022781811609503724, 0.0353015537163423, 0.033981488461816506, 0.1258149951876652, 0.017621460588528745, 0.01697702359618439, 0.03166265331298834, 0.04467037236017566, 0.04746935503076642, 0.048205335699622674, 0.03781969238433146, 0.026849026025663462, 0.10445778919083458, 0.059879293755417874, 0.017553964411960016, 0.0249582578262855, 0.054286832755972306, 0.10556571320780825, 0.05667688152302177, 0.056938125166080655, 0.020613905357857867, 0.036112273923091354, 0.0640410740649508, 0.014041077811270954, 0.036328191974110184, 0.031481557788567684, 0.04547255068656899, 0.01721724770182083, 0.036026812984698245, 0.016859724043658184, 0.04362455509122341, 0.021645429341362852, 0.04293583821685564, 0.03129905457758615, 0.08452981980817934, 0.060618855885320136, 0.008518450514173076, 0.023729935431131916, 0.03957535906304275, 0.036043678410351276, 0.031663609007673885, 0.03939642007612894, 0.016767174876745672, 0.039570885109564954, 0.005370155690358051, 0.054683179834917675, 0.03124288118053829, 0.05105489549497443, 0.027274030538636352, 0.07309467051058047, 0.0347665332317833, 0.0321344887807725, 0.05961693928486878, 0.03581126265588307, 0.03734701996549003, 0.03424840498595469, 0.07889182637295417, 0.00698525864150255, 0.01710573019790313, 0.07504074834287167, 0.055439955960478515, 0.04736012621452251, 0.051853687712742444, 0.033425649537915186, 0.06734251465287901, 0.02521061484942273, 0.05365851042311519, 0.05827825043290373, 0.040709575217577725, 0.019177789274122448, 0.0397342227159008, 0.021050839775031614, 0.04247977841465224, 0.04269514488236558, 0.007264655695537166, 0.06160746936896636, 0.08402706694699104, 0.036722114384775205, 0.04299447075614045, 0.010174898272981087, 0.049318032444364605, 0.05975282413043803, 0.031531190709962, 0.06762935329348811, 0.041829530645402214, 0.047397227852695414, 0.09125394971981164, 0.033583616867901823, 0.04012928659757299, 0.017079562549629522, 0.009913306059916655, 0.06508319879010802, 0.043970685106732195, 0.02148929487673506, 0.034952068235725164, 0.030907955200922106, 0.05062028232421126, 0.016302128863190452, 0.031356390513059114, 0.1666772440676728, 0.039198033947257266, 0.042374828199465434, 0.013360985171710773, 0.009699892158800317, 0.09918295207523531, 0.04500511064825039, 0.04276425750445455, 0.09818724461741025, 0.22312148384028868, 0.1432502293779004, 0.13515773619855606, 0.16865787246534902, 0.13736498872599295, 0.15983033324441603, 0.19492836038191474, 0.07166857485689464, 0.1872938958507392, 0.2198128573476307, 0.14586464231533391, 0.11145877561742261, 0.12088333481862662, 0.3318246411940744, 0.12697357293819228, 0.13974822697139558, 0.14822154245789976, 0.16192610465711163, 0.1558008639802856, 0.2491747398650454, 0.1280402737639604, 0.2199803394896369, 0.11525880154823104, 0.09876001025399855, 0.15826965892507186, 0.09632899110475857, 0.05895964350671538, 0.18903110747135457, 0.15230662970533296, 0.1554851897902066, 0.2206078880736905, 0.15199539882521476, 0.1285335731001631, 0.2012389636928997, 0.22127352654933932, 0.09374431003966639, 0.16542891911681623, 0.11501117128758662, 0.13070776127278805, 0.13478048386112337, 0.16990802070546537, 0.09933200214178332, 0.14720642999295266, 0.10629107589803397, 0.134279937333157, 0.11007046342016229, 0.14231299741133568, 0.18781730244236608, 0.13292535598720276, 0.20927087463919194, 0.06953959353268147, 0.1522367165213631, 0.18783524422155273, 0.08649416117658539, 0.1754370151508239, 0.15421320804424826, 0.20970094107812454, 0.17767704091966155, 0.13222317511756576, 0.1543592550461331, 0.1276087134535755, 0.0972700535109447, 0.15537065964552665, 0.2314143856206248, 0.12216773484983753, 0.2739942572530239, 0.11428570900593074, 0.1853335228177809, 0.22139807712406884, 0.10403935196659259, 0.11286686820488785, 0.2735252582257794, 0.1630246287752544, 0.1199444787456624, 0.21399265756049465, 0.14500833987709016, 0.16814819416932522, 0.21916459374610456, 0.13062954369571902, 0.12127333485911931, 0.1395045803679574, 0.17216830183902096, 0.17805170387991015, 0.1692067591413375, 0.1191550481223291, 0.1463555821007298, 0.16800315840350044, 0.19077392685557568, 0.11325650818405614, 0.21466301513775704, 0.17937688277133051, 0.17627634108066562, 0.1328048656784719, 0.17075491558399894, 0.18563837984636908, 0.2369864648508449, 0.12313948673827034, 0.14186054588325564, 0.11100270049346071, 0.08937646740026052, 0.13385454403056254, 0.14124710863876727, 0.2304145183053709, 0.16010523623516484, 0.17902209213183773, 0.17034657539859896, 0.12800093514904862, 0.22224586066459456, 0.1379202952187869, 0.09052182247321452, 0.10757629564332385, 0.15942672748238812, 0.0925732373950943, 0.20511175265475629, 0.1600129686055645, 0.12488137915610306, 0.14583988235362116, 0.14452867690593968, 0.17601000295291025, 0.07082649867140478, 0.20957153350595506, 0.10545203342072426, 0.15873000115877198, 0.0933785260384602, 0.20961201359187404, 0.15183173180107148, 0.1192908678504248, 0.15204298820707107, 0.17123111583773168, 0.1362450907547628, 0.12891654045351092, 0.1367128946848454, 0.21539616128129346, 0.1298063209340457, 0.086477805199402, 0.1564270336060755, 0.11218589264899494, 0.23225855322614794, 0.0792692702323679, 0.10177792170115056, 0.14742991316222376, 0.1094049551794606, 0.08230467912771049, 0.13955357935159438, 0.13052334858765527, 0.1025141321963841, 0.11276373744852121, 0.16359527234829244, 0.09157080368529405, 0.12501866977301337, 0.06409240578631721, 0.14391572995772287, 0.1964461490992577, 0.11682946565410784, 0.16369521617889404, 0.10700013623723101, 0.11771982070058586, 0.10477964571046253, 0.17587275064039617, 0.32356658109253456, 0.12421780911784981, 0.11662018575495291, 0.15194373385560128, 0.12824434426523026, 0.12508320501975476, 0.12414250267489303, 0.08064293482851598, 0.24584515320677913, 0.16479367901000286, 0.2049539385423545, 0.08253136454450508, 0.14217451935814274, 0.14186138857997235, 0.1977386160363113, 0.12056634295731784], [0.03563974323051591, 0.0681085336292463, 0.02804900699805829, 0.031171859084298054, 0.01975436811335385, 0.04985342448156688, 0.016331064004090526, 0.0691550020729342, 0.025742547999646877, 0.048589808415741696, 0.016874634029884494, 0.02799576771776042, 0.009951452450496296, 0.05679621503898694, 0.03260053070862928, 0.07198986447145862, 0.027313560675529223, 0.019825194857173392, 0.04889482632279397, 0.03923824973284237, 0.04823856476333834, 0.07083687150189955, 0.08810378085341185, 0.08423060118671387, 0.018937584320684115, 0.014153593144710026, 0.044474192564525915, 0.058130487394068515, 0.06229471535451951, 0.031117526213488275, 0.03327754175951404, 0.045972028521880995, 0.033381047898963574, 0.05429810957021771, 0.056140302049536864, 0.031782580547094826, 0.04632239883405067, 0.019862625913153735, 0.033931554850911906, 0.05704208329740552, 0.08160737057727191, 0.04544274603587486, 0.0319573060504251, 0.006628474258186837, 0.08748822920625249, 0.07907944130561045, 0.04389458193233417, 0.03661823286224277, 0.03962613920110368, 0.022960202843551675, 0.08547125759744838, 0.03850043811384709, 0.009069377856869853, 0.007547325381423317, 0.04203197704027257, 0.07930134633375753, 0.009491711595816719, 0.0436806250664015, 0.03514689205574893, 0.02910613747043235, 0.03199448429739043, 0.02097087934793484, 0.1232190143256899, 0.052284688778942635, 0.05457991884360391, 0.08201699779038468, 0.03861955329475384, 0.08437297096656216, 0.07887049848514219, 0.008144335306790328, 0.04017583793029189, 0.05319610358245912, 0.04858967051991532, 0.03619578516771717, 0.025759940110747854, 0.08727051467905123, 0.039493816664382335, 0.06191526817518377, 0.057797553243055466, 0.026991275146663673, 0.062326350955352675, 0.03354877135866592, 0.06562828566999206, 0.0017588091953169376, 0.03489505214196059, 0.03108364597503697, 0.007338059367612005, 0.03059925815661348, 0.03656240803520045, 0.031116411555558447, 0.03522261218618482, 0.010365059490375703, 0.04196804317255174, 0.04633331175653204, 0.06263878459351198, 0.007640753634228943, 0.03613215007428681, 0.056372568416859836, 0.05959881747501993, 0.019892782964293036, 0.06315626549504458, 0.01764113181120446, 0.026480796288759, 0.023725589797381434, 0.011238987696537328, 0.06447058125969864, 0.04167115728881571, 0.08060984749106631, 0.032370539622441415, 0.028460580074498733, 0.06941577074148002, 0.10346027376550822, 0.06004872942163099, 0.05768779199570418, 0.02168773271654162, 0.02545087151379595, 0.11148905907306941, 0.08962179173625286, 0.03260699266027058, 0.012492307540660184, 0.11504282604061788, 0.0351265370996008, 0.03613706452832107, 0.00499878355654918, 0.01434126266113092, 0.050720088258986516, 0.031225866367740017, 0.02447529876184079, 0.007961190497172217, 0.026117630393034028, 0.062774914587217, 0.01556147314277628, 0.04754265049292196, 0.10134913462905154, 0.006463154878151874, 0.027848504551295793, 0.10057527091233961, 0.011771884202326258, 0.009209511617589141, 0.037420173701379573, 0.008666701934060023, 0.02294171522671898, 0.11078900792786192, 0.03948371962554032, 0.06910828603131157, 0.013009380500373102, 0.03309697866620075, 0.028020678981838208, 0.07226428482681513, 0.02866097143851221, 0.01441350858283019, 0.014507068985802753, 0.04343477212974141, 0.03818069216645053, 0.03774029120141941, 0.033845078846019123, 0.02607600883610787, 0.0059936492752674375, 0.004060092671293645, 0.02612770444923832, 0.025573194687885624, 0.021542436480822585, 0.019216712286335327, 0.018790489693562833, 0.05930057561565792, 0.0320909634953545, 0.043418649809374925, 0.023455729580394203, 0.047463226327372175, 0.0505796988164225, 0.026708456552437237, 0.016224738661079638, 0.03564733899228516, 0.039981711250279224, 0.019125888732472257, 0.05064342967084339, 0.014659640183972736, 0.07591323821895546, 0.029864166149749394, 0.023389361468293977, 0.018764603582601395, 0.03697981870162391, 0.04853407934968991, 0.027854491528424046, 0.05142753981354256, 0.07440347044217972, 0.044634829710928664, 0.09135737925046876, 0.021033869012288993, 0.028497042029254863, 0.07763004891814725, 0.031888595624496384, 0.047983633684775526, 0.0379901163039669, 0.02891882131206653, 0.02836923558084715, 0.019657909982807694, 0.048717967264594576, 0.06358261257710476, 0.03791159229172814, 0.07837813377620713, 0.02417525659585672, 0.026972659210103656, 0.02961625626701261, 0.08425693928955064, 0.025861519539067825, 0.15761433199288385, 0.004350672214997992, 0.05750955397924108, 0.042935129585525686, 0.04572906373669544, 0.054591678293241616, 0.04692962693591272, 0.05000481877716319, 0.021085235207611998, 0.03783323298839312, 0.06241617859491418, 0.04538604403815923, 0.05754334611758109, 0.015598279837098335, 0.03421063685128766, 0.06590196292006201, 0.021478286193263148, 0.06920741014783421, 0.009664522836946193, 0.09125464685982274, 0.058994837585956826, 0.03453527810052037, 0.10301038863197451, 0.03137033331328102, 0.03179710174369956, 0.08293993455628235, 0.012040651786411482, 0.032839427566936905, 0.016638152263758164, 0.05894330285129048, 0.016132605096866048, 0.055154396686702974, 0.04742147836593851, 0.12324300053859912, 0.07769106782131618, 0.028286208886833444, 0.050066193911216916, 0.0665944068121814, 0.04935125384720103, 0.09347249438325245, 0.05027715154292603, 0.028323113257365844, 0.07115375611089891, 0.03182027781862886, 0.06565992510126484, 0.02152409825113512, 0.04894276810509544, 0.04000322299919302, 0.030161597871131478, 0.003769120028723152, 0.0351477807177411, 0.04704364380168338, 0.01804795131207474, 0.03875197925334496, 0.020928612361932476, 0.045487343844386845, 0.010042007873585869, 0.04074474248374182, 0.0523498828612989, 0.03430142210075452, 0.09265540032497338, 0.0047010822679787395, 0.029187716258269165, 0.014440969004476023, 0.025067122750765374, 0.012641943664470268, 0.09273429205941577, 0.04702722270702643, 0.02479306437195309, 0.024949756165545796, 0.045895726164622654, 0.03804335558426477, 0.05468139868049372, 0.016729820429557757, 0.01833884447302309, 0.043092372962423874, 0.012038851479789423, 0.01884276370307611, 0.048689346219743454, 0.09170178939858753, 0.01742961493531062, 0.03674794303914232, 0.0200063344316497, 0.042120552126077876, 0.047697902041217016, 0.0776591602592699, 0.02898262302962042, 0.0032433759113172853, 0.006884324642258787, 0.057280934190437685, 0.03945042927479071, 0.012939271963982573, 0.012790189338697782, 0.02723075614701356, 0.024518958112645536, 0.07521691026105996, 0.06088012251101675, 0.0360867248908166, 0.028863827690422058, 0.03402200302169208, 0.021833984646946195, 0.013734978762635542, 0.024609902325356682, 0.03497388641980868, 0.018208726354303862, 0.043611807388163386, 0.10267425989431721, 0.019678431563079357, 0.003931164382881816, 0.07234115408913744, 0.017905411077663302, 0.09240839825642687, 0.008012341709071471, 0.04926461696384415, 0.014696723627557438, 0.0012819626745993213, 0.014284288702202181, 0.049986382871265375, 0.021088416387717572, 0.07675022758062809, 0.0506330338577109, 0.03719502429087316, 0.039831902756686174, 0.036718532923729195, 0.03162999498477626, 0.0432317971342033, 0.023021306016392285, 0.04259435835504725, 0.009964621501914676, 0.012705038665914008, 0.03387205280183304, 0.040334644126555616, 0.04205763332485672, 0.013690354141046204, 0.06067628566656382, 0.048581530835719845, 0.016748549364086603, 0.04228873523853479, 0.051387481075981935, 0.07324956582799073, 0.04286107952676473, 0.019957955979231386, 0.011766702575128407, 0.08693940381729796, 0.053331191696587114, 0.01957056829856048, 0.09856533199068039, 0.19435883529724615, 0.11833328858859117, 0.11247622465053875, 0.16869819933368316, 0.09464352872342834, 0.1683495680411016, 0.12946024837513126, 0.15418018965471178, 0.15066154781849156, 0.13920212885545147, 0.17857791435333992, 0.09803846268163574, 0.1891270982882669, 0.16146571645813604, 0.1456020886619245, 0.15973201352021388, 0.12406050062347805, 0.10880060373775421, 0.12146397583907652, 0.14206922823382964, 0.19406451963849608, 0.1407831811135815, 0.159512544651666, 0.1469407660225707, 0.07715641505896084, 0.1750835575043194, 0.1395636610686779, 0.19348426932288756, 0.10785807044275346, 0.30040513844259326, 0.12998370093203362, 0.18737349238607193, 0.08868905670580365, 0.12492644044780925, 0.12200009949024647, 0.2634397719896609, 0.1594990155389232, 0.0867434921524217, 0.13892923301506427, 0.16930264270594045, 0.19017198092995152, 0.0981074488992172, 0.09456936375147874, 0.1840485328988683, 0.22743986018242376, 0.19396711921980306, 0.16968047727019558, 0.09978678257715318, 0.12258254847819768, 0.22858870095543324, 0.13760881919053294, 0.17179578392496034, 0.05939151408270963, 0.11872426156074771, 0.15483596091789587, 0.05175343361653147, 0.09246379407423158, 0.1527994387452641, 0.14800234938100462, 0.1361035636716312, 0.14829312571354453, 0.14205874815102548, 0.218302239213259, 0.22639667825593104, 0.16535160552349784, 0.13195122922620467, 0.15178716080563684, 0.21719052306106015, 0.16692970068224017, 0.15999127299554888, 0.1811289871411939, 0.14197863067590422, 0.062495399747164025, 0.11950120495091524, 0.18066211783837888, 0.11892944288950776, 0.1379985587611314, 0.18964788485919276, 0.0960743358178485, 0.16945818919808636, 0.08364997548802246, 0.1072057389143494, 0.17259590147483736, 0.07916618544127672, 0.15437911204513044, 0.0978721909585499, 0.15312642039310548, 0.12246824049901579, 0.11636399829219427, 0.2593555427607029, 0.10305079210910106, 0.1824382620473062, 0.11653206266102292, 0.20428655338623833, 0.15747165577786584, 0.15813931672563478, 0.08186178071604622, 0.14421413652598858, 0.15524681387168748, 0.17249585039192633, 0.16985532917803334, 0.17855050372740916, 0.1405567255231642, 0.16392933264855417, 0.13309965631173504, 0.18440620402895636, 0.1281955827688498, 0.15104970924796599, 0.1744927504971143, 0.1356291254201243, 0.20580251881432152, 0.12970217894161903, 0.2101238675776028, 0.08841879620787599, 0.10981179383252898, 0.3052416966567117, 0.2714919995877051, 0.15190921393373322, 0.13103678071450803, 0.27112927227731676, 0.19779192043408272, 0.12097983891444823, 0.18250350209493793, 0.10843678092163418, 0.2182847724085854, 0.11455511914626246, 0.12123490788883741, 0.07122551556676626, 0.09562759164480433, 0.16405840314203696, 0.08047194400381658, 0.11267873233244305, 0.2250332409335721, 0.09706060507244642, 0.12818425232844968, 0.17373375654701265, 0.09557811002577506, 0.19934776839950394, 0.1351787576511983, 0.15593220209402425, 0.1898391770138856, 0.1545252356558077, 0.11811712921987619, 0.17206806689500811, 0.0995495557905205, 0.1060291734193602, 0.1492307254023129, 0.123407885642542, 0.1211733910285177, 0.20222991374471497, 0.11110506516190306, 0.11395691939058805, 0.11748753518106476, 0.13098267958529536, 0.0878354738796911, 0.10413491377426733, 0.10311090702851934, 0.08787894170851478, 0.09538277292684202, 0.1598686836059055, 0.14162094422405766, 0.21902703499842077, 0.1164078874693763, 0.12175743347935139, 0.14670795190238184, 0.1517136470084229, 0.22151573290747983, 0.14779438715307944, 0.27471015109650554, 0.12000336792440185, 0.0780689713334845, 0.1381423841080358, 0.200711588765825, 0.15353987804583966, 0.10307434931277268], [0.04980144158546483, 0.07953420641922182, 0.028035797727023883, 0.03754663183504055, 0.021745602998341766, 0.10680325930157017, 0.20269538876750778, 0.045721073439645196, 0.0580364884057593, 0.04327273304243723, 0.05286076774580344, 0.020653780234316667, 0.07116199155608494, 0.03518962827060492, 0.005648986318133651, 0.05517568627011873, 0.03299734127076884, 0.03847498484256287, 0.008235690334150869, 0.01727084895866292, 0.02120365324850765, 0.01592226129310626, 0.04615444937841066, 0.03564013010491768, 0.04644354414795676, 0.04891292515000509, 0.09331605922911437, 0.015080606455974763, 0.026568572727903247, 0.027978134288963293, 0.014913350309906228, 0.03594486072899834, 0.04218891781244067, 0.06876129416688796, 0.04324434948484263, 0.04447135420876645, 0.05913633785601105, 0.035761834663008495, 0.05177146732626904, 0.05007346791605796, 0.06557102825853132, 0.07452389180299736, 0.03794536527787005, 0.017317283462973374, 0.08472314209587152, 0.061425205560461174, 0.05932009170552897, 0.01169016177300364, 0.007897844123128321, 0.03252718545075867, 0.03366609389382986, 0.02673998298574119, 0.06863894992538037, 0.07717947430548168, 0.03405048617071683, 0.09068596447187086, 0.06263526441949992, 0.033735248650754654, 0.08658117344302517, 0.0988703728803704, 0.023111168129910386, 0.08813499893632629, 0.02365767610289397, 0.007554697062474706, 0.01831685391915662, 0.02363039571191034, 0.037389208427480156, 0.03902787432795571, 0.011717827123169218, 0.039773580483010704, 0.07075688426172541, 0.11290920222358358, 0.0294096308625153, 0.07608357786891923, 0.06911668235496168, 0.0075476533628159, 0.07555950478079819, 0.11628100798735697, 0.02675240701665321, 0.1468325790859038, 0.05105196903910368, 0.02244208991948155, 0.09498020904439111, 0.03237549238087189, 0.02543018713984038, 0.06709770359579595, 0.06295804790551625, 0.07521591434675841, 0.08326408933968314, 0.024412240149573456, 0.052151646119572466, 0.09215358209105269, 0.04508931520244768, 0.0965165447503809, 0.024880557358565352, 0.05548397537260767, 0.07163191754971782, 0.01847568309805807, 0.04305874170254796, 0.015375878767020281, 0.052340157375100164, 0.002337800613003633, 0.04708299390791405, 0.05020660250597904, 0.025395376104561072, 0.05939669283707777, 0.014408874708498198, 0.04066909896209836, 0.06429698573605669, 0.03716976637200963, 0.10963231475362856, 0.011005071367347434, 0.026289088531367244, 0.09442399856784651, 0.030865883567340435, 0.04652767975424086, 0.025157609225941763, 0.063818468066353, 0.043637544111979586, 0.03936695250412149, 0.059659116255540046, 0.030404035970869086, 0.023867714429093946, 0.06025458107732477, 0.03660604057292785, 0.04370236281125296, 0.02014635232157044, 0.023667390097773845, 0.04682423622016946, 0.02404395487129448, 0.021379841979773297, 0.03338215872645378, 0.04799927336974971, 0.05570822079936343, 0.06161836313924963, 0.0961882913965852, 0.01004325755451235, 0.034089376624192924, 0.08376914046464429, 0.009461158094176603, 0.052900378321928364, 0.041574457840573405, 0.06226718598496049, 0.012705356592402585, 0.007173599921272047, 0.031061326003363057, 0.03250661598999174, 0.04834186788948794, 0.04310446949074826, 0.03266114741563797, 0.03010547810023831, 0.05925499338416323, 0.026630283025423848, 0.040644365813462965, 0.025168049089129896, 0.030120874552296537, 0.02788997863629653, 0.05002700085301073, 0.055068445452038324, 0.019333716895010684, 0.03163897545046864, 0.06635062231291687, 0.05138727423224238, 0.035356554998866016, 0.01281920204600019, 0.020991257286720702, 0.0708562994916593, 0.03776909227693274, 0.05369265496190037, 0.046777466552392136, 0.01710660545335662, 0.017326516737680764, 0.04488123806133386, 0.008669953019688688, 0.0761844793094262, 0.061770354983426874, 0.03392890418669389, 0.15302040914614357, 0.026086814506279848, 0.05262043064219817, 0.0137335394749478, 0.0053750332764109544, 0.03878056199379987, 0.028857166555920438, 0.03583377414953805, 0.03408119480516161, 0.03414014910137461, 0.04369234238120337, 0.02593363905625959, 0.034542165230959654, 0.061276316372377265, 0.06056912145727585, 0.11722673586900197, 0.025530042870330717, 0.004900053975307533, 0.016111982009944417, 0.02592255950965468, 0.052537907650994684, 0.046060159276690216, 0.02133849429928007, 0.035322824147559946, 0.04830028463695799, 0.07277276802567706, 0.013488426770744546, 0.062026167063102614, 0.008145768848818638, 0.021087721162926287, 0.06543114826443695, 0.05084151319498497, 0.11620306620194067, 0.02686229275329219, 0.005862335580581379, 0.05956088463144918, 0.0073771614528771855, 0.03693560776751369, 0.06268587218777788, 0.02770375415322281, 0.01226560201405758, 0.04723209377017714, 0.017612688881795735, 0.07217580933243999, 0.03613755865503223, 0.020662029086041356, 0.005352232584564557, 0.05325848229169365, 0.04112700120575967, 0.0239768972800624, 0.06265277335900934, 0.05008246178828901, 0.030036166295289036, 0.0654037376385062, 0.12000056404259898, 0.05172888815943753, 0.0674872822879303, 0.07891904547690384, 0.006067925808771003, 0.06575768558128227, 0.05432508735647125, 0.03559276671899903, 0.04109112913870523, 0.06085895167122926, 0.05584457295856649, 0.044520606001418446, 0.053085208524979895, 0.015934760975200805, 0.05787028180014703, 0.06306974735531597, 0.06038612220436335, 0.027510039245469436, 0.020712860935037176, 0.027029828521453088, 0.03572055401520864, 0.07782330991880548, 0.0783706107927907, 0.01804961946852986, 0.10245842228253042, 0.07473006138517972, 0.1008975257976882, 0.014752089759455094, 0.03891099229334824, 0.06664070916632492, 0.06271504481593448, 0.016068908716401747, 0.07152395277854896, 0.15737529723874985, 0.057455805250473564, 0.012706310371868314, 0.03917909242332943, 0.029636446514257023, 0.06006873197733395, 0.04223154294454763, 0.07606473210598193, 0.03164373860213786, 0.048033126795123664, 0.04168639860806927, 0.047986092827012466, 0.040597642110961105, 0.0660757423048058, 0.050795808389422395, 0.026621568775285157, 0.023526500782839233, 0.06264435788316113, 0.02534570487877054, 0.0820629783876, 0.07130642211244953, 0.008587324691395606, 0.029770515731445728, 0.02929368153995564, 0.05265788851125587, 0.08110440321146481, 0.032195913710541306, 0.050233867575204184, 0.03889450991165735, 0.10337485496195094, 0.0353573402389884, 0.031527298983306654, 0.08563053493778552, 0.03548204403130278, 0.010807126696642128, 0.007379666560389583, 0.030252986414838704, 0.07615930566023435, 0.04161877602699303, 0.07047397565216788, 0.047155301116647265, 0.028191876650277167, 0.06197364407501394, 0.052345608090681416, 0.05618307656878906, 0.028095215506431077, 0.05060195367062285, 0.024724465028773394, 0.03180394099364358, 0.06741171537507927, 0.06191903732777123, 0.06433020330845349, 0.06041498839735024, 0.05368957145800514, 0.07915609606331395, 0.03582510969511444, 0.00919191840840804, 0.036059153386421745, 0.06227223833482112, 0.04695345227035785, 0.013374753686929903, 0.010228441115618955, 0.026729638883543592, 0.020509744213233073, 0.03374842536305228, 0.030269035956852382, 0.04386542845637568, 0.04299363188986336, 0.0245263968263903, 0.03935461848854058, 0.030011092237527334, 0.023169423370892485, 0.020517784305998397, 0.06451002712691985, 0.021088730483766527, 0.04039761272349185, 0.06457064766436815, 0.035310191357688564, 0.06390743768743931, 0.04708968185549302, 0.08909179678847713, 0.0037593145820973145, 0.036444330903431105, 0.03321139772813166, 0.07017867940087473, 0.023392098317403468, 0.031447214066922184, 0.046197457554479765, 0.133086908608675, 0.2824558822378036, 0.164625323527763, 0.13166644370123265, 0.09679643497351678, 0.1513927480987003, 0.3715647168217167, 0.12956362427963367, 0.14427913142548454, 0.1410230738861907, 0.16421117639589697, 0.1474114504432486, 0.16576736144000487, 0.13629678636789322, 0.1810914028676287, 0.1488197651962119, 0.1332245746086682, 0.08122821834178702, 0.08721302744121322, 0.12435470902991873, 0.1433886461440594, 0.13232420679301987, 0.18212428857241908, 0.12183374349748897, 0.1158807423686789, 0.1864815055723152, 0.25055976554511056, 0.14084494312203702, 0.11047865038797741, 0.1067741479604475, 0.12570031948627966, 0.25865935269863377, 0.12844781721791915, 0.14553913155630713, 0.12681232675188972, 0.11791207812606327, 0.09937401440355087, 0.08290433445044103, 0.20894744763931922, 0.2016759096013923, 0.2531768291467621, 0.14447713451039407, 0.13773765985763844, 0.1186352038395501, 0.28915360509868593, 0.1206747214159658, 0.14247926913442152, 0.10362294487534993, 0.11052123721568816, 0.14101944262942961, 0.08896333916533379, 0.17476757687907066, 0.11424612524288316, 0.26157998630116064, 0.11995189447676945, 0.2445546474548117, 0.11435527745033465, 0.12403757927278358, 0.23250161760276367, 0.21881335775458047, 0.22817239345562076, 0.250205832924093, 0.10500243940060178, 0.18501244004695647, 0.15202257962476823, 0.15594741660020045, 0.1557400672426147, 0.15039930060025186, 0.11948680249793876, 0.11705870214369028, 0.10242375680395674, 0.1733633990008985, 0.09014981017718393, 0.08954603330142076, 0.12589289100780604, 0.1276569846536844, 0.1734728729652782, 0.2158442461082051, 0.16000682458041177, 0.17630614190092012, 0.14514864121954288, 0.2326856472439343, 0.21897178473732165, 0.11999653442011726, 0.1434479566711572, 0.15116106778863939, 0.10485057779137166, 0.26197893424860896, 0.24129711902670323, 0.11930164670751942, 0.22291355225588047, 0.16271902098050042, 0.11487005789193416, 0.1813860249615485, 0.08985959308882875, 0.2031203070955892, 0.16720848007788583, 0.11587128884369328, 0.1224106843132646, 0.12641439770138072, 0.14196634262559876, 0.1177112558375924, 0.1496650512901045, 0.11548508859930501, 0.08039275349508371, 0.22071443558219941, 0.1267549084619649, 0.19921287563779663, 0.13581381389690986, 0.09024904920689522, 0.17851602977081654, 0.1540235553177134, 0.2268387875970333, 0.21322886789998702, 0.08826322673309235, 0.11926312014580735, 0.12758818995808402, 0.243564693317298, 0.09587234141485346, 0.10608626995235683, 0.21147288712522677, 0.1397946978648824, 0.17380529383738197, 0.15084628226055255, 0.173445355087038, 0.1656262174008354, 0.13214619860293406, 0.19115959083841694, 0.11410879632157665, 0.1311366939015927, 0.14964504107352228, 0.19519981597700428, 0.22269454304008718, 0.15030712490120243, 0.16367125294862256, 0.1284176027101855, 0.08397490402022678, 0.20531148709837468, 0.14424919270940367, 0.12023778316835243, 0.13169701060941144, 0.18373011611402038, 0.21522805094718936, 0.13445474327571932, 0.11982185871250207, 0.1121944421902299, 0.21206000158863686, 0.1467090703907513, 0.1070479554454646, 0.0780562619348207, 0.2298343599203133, 0.10554113710719733, 0.09362028806560463, 0.1375245648406206, 0.12219768888767689, 0.10133280929538513, 0.08915263949142349, 0.10061994149920442, 0.1356071080531805, 0.16529315301487524, 0.20976274905185546, 0.2420436104218806, 0.18487016219765912, 0.1358484870363628, 0.10119345024107926, 0.11609722349432208, 0.11358457767675001, 0.1660108088605827, 0.17666244939450296, 0.119568528757701, 0.12702496977703226, 0.16401331120681378, 0.11953315847823698, 0.12297825587372627, 0.09155766527739265, 0.12855842499242676], [0.05477445155021645, 0.059456719656384764, 0.020291131447940584, 0.026364670765976754, 0.021428980774456458, 0.043309321401700865, 0.05065066537128822, 0.0356769674427567, 0.06527311198653714, 0.10171792935580017, 0.05657176659893125, 0.06990294137428846, 0.022341018024411415, 0.02033864039056484, 0.13491372187291423, 0.04108269451065891, 0.1873354024944767, 0.04067780555135781, 0.08506788932267698, 0.022902357459609068, 0.03592077492465896, 0.06108879720071151, 0.01563714826554661, 0.02624293939480859, 0.025568705412649342, 0.021224362520320762, 0.02667267833115353, 0.0662890594873217, 0.027774544507865945, 0.03161315828742039, 0.028182064979186947, 0.016663586382844275, 0.05283647509772451, 0.01601639530441213, 0.09297566338171882, 0.04867179514539819, 0.00978773084258841, 0.028199633290510506, 0.07890884884663167, 0.06646322957690685, 0.02043735273482819, 0.022205278735547777, 0.03481829013194769, 0.07063375861053506, 0.13182272563778585, 0.015735693028076522, 0.007422565090124526, 0.08933325238045185, 0.04846697387796256, 0.058452952953596274, 0.028278477144457644, 0.07550258444802416, 0.021149580847592126, 0.030265929470319423, 0.0511978168581282, 0.03473441116511822, 0.08202652792416273, 0.057911504991352565, 0.004717056637614845, 0.021307806732253205, 0.005194336596515871, 0.0416168914506993, 0.04975326231590683, 0.03147396585723806, 0.022379481383869727, 0.049540841456262336, 0.12030197367552789, 0.0023200924906338896, 0.03282516684022642, 0.016958932429852507, 0.02602867034804677, 0.08018217890733674, 0.011233014125947752, 0.021859372800756848, 0.03504497171830266, 0.047158476551093405, 0.0038990499770959783, 0.045956090062616334, 0.06670712898936003, 0.03751834786887612, 0.03452281001955271, 0.026934174783227426, 0.0846506548564761, 0.03955906820333293, 0.009291263732818827, 0.01773834453835603, 0.032460964810583866, 0.05176402861252428, 0.06044516460068765, 0.009356950026666446, 0.026856535602541223, 0.02563065319742647, 0.010935744240639672, 0.06594394453831258, 0.09046181480610564, 0.04238684811899739, 0.024599755490799586, 0.046288097247241006, 0.020878429772452484, 0.016492643438640143, 0.03304028432936438, 0.03359009031086199, 0.047653323384903135, 0.15641021031525829, 0.03781868114827141, 0.054396023267820004, 0.06597264219195613, 0.04574487579145259, 0.07426824826266497, 0.09099429187875602, 0.02336188955532928, 0.06257383565929148, 0.06556113040254963, 0.035480730190512635, 0.02883660284081294, 0.10131741858898632, 0.031099184153361187, 0.04293111145436283, 0.040544965905287576, 0.07869338661792778, 0.04620208855598204, 0.042100511265978705, 0.03763644415284357, 0.018212913024810054, 0.09012868913311152, 0.07502024016913868, 0.06011807187009723, 0.08457711041574517, 0.048312358182644656, 0.08913669720171921, 0.023953121741332357, 0.033134237352398135, 0.04138993407269159, 0.05760649091473991, 0.05268613417302409, 0.02205459307128143, 0.02662094824406649, 0.0020522607308286695, 0.06904167468629538, 0.012661747037312918, 0.04764571613181503, 0.03841450986182017, 0.042298556485724066, 0.06952833204019455, 0.035909099744692925, 0.05304429942982332, 0.027619591733861356, 0.032155402981105356, 0.05501326796929202, 0.17178467565005826, 0.07020626622702807, 0.09634452736786298, 0.034859065161717516, 0.037600185211387374, 0.10373174468235624, 0.023892889993505615, 0.03415300788718366, 0.028320458762708212, 0.011892022110611923, 0.04008414103619514, 0.02731993835749886, 0.035591234543150475, 0.00916015065740794, 0.035681284348210024, 0.04659287383659713, 0.0287168632982479, 0.029960396369138075, 0.09193903916785795, 0.039963198735588984, 0.02018320115072833, 0.05462245587559958, 0.0808759787750821, 0.047626996773385236, 0.022772338932319995, 0.06415090809065489, 0.02851279279697807, 0.06393743002967489, 0.019073388727021315, 0.0068730712894560595, 0.0262898143996755, 0.038347251172507965, 0.018189191112234708, 0.058107163847213796, 0.053244930196313135, 0.03127496685802696, 0.05785219446425477, 0.03496330291513474, 0.12868790917338865, 0.02166732987989822, 0.00921726059694324, 0.03532840509808833, 0.05042740053707554, 0.06530056857774336, 0.043078901306275404, 0.02694770389597022, 0.04759474447177303, 0.08346927832932242, 0.06845177166284093, 0.007248669834582196, 0.051551707344309944, 0.065947491525402, 0.04774500878768102, 0.050042035328524734, 0.04822027824458577, 0.05321529408496234, 0.03138139562290763, 0.062314859636488466, 0.014769188841925034, 0.07511089901409804, 0.019224346352500782, 0.0797505802925556, 0.05471988310736995, 0.016464298185441765, 0.030202995347339782, 0.07340142743722086, 0.030758380364145965, 0.01023797412222672, 0.00898367272795088, 0.010161529081092488, 0.07184718825644063, 0.07870136925409879, 0.04505575672092457, 0.03292094698295959, 0.025575575306110328, 0.052893238382474075, 0.14352859508606697, 0.03042777895086235, 0.06696701665679294, 0.05045008823095311, 0.04049384102766072, 0.048828981065702055, 0.00864850543063855, 0.015142729483364571, 0.019253438541425333, 0.01399389445601452, 0.0351915932861307, 0.0318477937816492, 0.11774083449234886, 0.010995149571118096, 0.04679265807593062, 0.016619356296535943, 0.03134135986798473, 0.08482064210599469, 0.008658889752452173, 0.0401913014150435, 0.021889462819202773, 0.05708859249528858, 0.061874853206738356, 0.03838984183065834, 0.04991594874750703, 0.05482219414965761, 0.02723755326212174, 0.041350702710089185, 0.04817812042611261, 0.03338560229167342, 0.008446810759543892, 0.051945507180907076, 0.04579138498933566, 0.03767568317632522, 0.02753973472863436, 0.023949375571382624, 0.07881388458753787, 0.03808351391325555, 0.07877192595192502, 0.005680301119648522, 0.04093761277955867, 0.023225663800633723, 0.023026894627799912, 0.03418403827855664, 0.1266048931246323, 0.02567784995922158, 0.009568037893322688, 0.0031368224177464486, 0.05900132635067548, 0.023702764207677498, 0.023842173057698438, 0.04467563538421546, 0.026915846129639015, 0.026907865408687826, 0.07078748181342118, 0.029211606710187854, 0.04848649379827323, 0.05545515514489624, 0.058742767845791195, 0.05832109390006912, 0.07828059546168774, 0.012724481977432246, 0.010741281439550223, 0.05378669608504542, 0.03930320632794211, 0.0823396893458501, 0.06658787208218729, 0.03892030792250749, 0.07267102388845337, 0.01879279944865454, 0.056380746405451536, 0.014412424568417332, 0.06978093421146755, 0.009310911015246906, 0.0302574776052948, 0.017909821828887347, 0.08815528494456122, 0.09136696301040151, 0.06558194501145233, 0.051692437696000265, 0.03941335444969516, 0.03130810973685115, 0.050455998599288926, 0.017244995406438268, 0.018482941781140624, 0.09249800756092995, 0.023592062587399158, 0.04713400387235227, 0.01192560261716285, 0.017365640847973766, 0.018346016971214164, 0.04702539941776664, 0.026615798217995514, 0.016664900223634416, 0.03139210936252869, 0.03496558202670948, 0.027437377721071247, 0.05841982731175038, 0.026508737430577318, 0.0238099513996032, 0.058108416400969996, 0.0641051113545414, 0.043921908288593256, 0.02785562342333217, 0.07829944122462504, 0.023341835288691427, 0.06411058122232076, 0.011909283986765773, 0.02726284565494186, 0.023237333234940327, 0.06789971338284594, 0.04270690433200329, 0.03042660875155801, 0.045585487368366415, 0.057020498770138914, 0.051676039583981044, 0.03841739801329471, 0.026688459742393707, 0.02242155110223159, 0.027650666175289985, 0.024755824837953817, 0.0852441278496577, 0.07059435104771007, 0.02773305893154635, 0.021418316830550472, 0.08477704404222389, 0.09005967227201309, 0.13868829836287808, 0.1574513697696309, 0.14431709874301188, 0.13863657210623065, 0.14108796153337727, 0.11422976160482054, 0.1780798499502482, 0.0794692728067598, 0.10585044510662557, 0.17980494205990147, 0.17471130006015304, 0.24866300845338454, 0.1072883538361038, 0.06937247145199968, 0.18894251706379075, 0.16397917432890785, 0.22805380304494213, 0.10699819037390333, 0.19440682304482307, 0.16251144179653737, 0.19084209335907815, 0.10910182184870205, 0.09068185824059671, 0.12594248754002396, 0.22786477851050518, 0.08576430155024414, 0.11954975194267689, 0.2161598283677332, 0.1014445738626584, 0.12872632082191207, 0.1540422785065828, 0.09022520088981237, 0.18313897202812857, 0.15073371330095878, 0.13893479481339455, 0.16353936325157845, 0.15121521488312753, 0.1187496573754376, 0.16105104838648152, 0.17586000293733614, 0.19946799823834052, 0.05030528229150561, 0.08567440879320906, 0.12020342412494844, 0.2872276600570448, 0.13096124444517399, 0.15077656825944302, 0.10270739319704233, 0.22140294944326724, 0.3163895936262223, 0.18662692438210213, 0.1506474364789263, 0.13767589784918294, 0.12836494948714972, 0.20625314705314177, 0.06579126321500348, 0.12407505629403938, 0.10720786863877889, 0.1801756366847023, 0.1606287960443766, 0.0991440577913196, 0.17951767441005478, 0.1757267189602698, 0.1311339206633068, 0.1569411858555771, 0.11818995353795829, 0.2847191817577808, 0.08113000586989426, 0.18207384934348447, 0.1288483126629745, 0.11770258372228955, 0.19216347245439408, 0.15065666017753465, 0.1587179735783608, 0.10289581252201911, 0.1478270378204123, 0.14156442225700425, 0.11839823752281167, 0.2915153009516578, 0.10238044985359716, 0.137935632299031, 0.11146650544457859, 0.1475775689487496, 0.11705311736272228, 0.11895626362773681, 0.16872599300357605, 0.12278835799905563, 0.16749536468377038, 0.11382298423878609, 0.13760762409337107, 0.11832673087595932, 0.15463429593270825, 0.06517776468348119, 0.21332787710332105, 0.13201862964178288, 0.1359153358686355, 0.20418475562285995, 0.13841523398314753, 0.0951226324503941, 0.14556160857600553, 0.1253951253790048, 0.1267023395086008, 0.2488265988687354, 0.2649717026900861, 0.1921742130070925, 0.14679217560877725, 0.17554610607124146, 0.17098304124609118, 0.22863760800851932, 0.32302624395778107, 0.13777096936058614, 0.13591581084314855, 0.16504654931204935, 0.10635783279975576, 0.13588145946062383, 0.17825090206198155, 0.15929923513002936, 0.22085550301257642, 0.10427063391093286, 0.24799988274612736, 0.129829426145842, 0.18290487088022694, 0.20380722749377453, 0.16864399095216107, 0.17370617738173855, 0.21405645736282874, 0.2287828276354459, 0.15835739131416046, 0.1609549349955013, 0.20691435754058823, 0.1330590230082312, 0.16013186545141284, 0.1325154989477127, 0.14569020409497524, 0.26537046677643256, 0.24106318641814495, 0.10840031513643843, 0.07489608029925054, 0.12057323008775712, 0.09448052819577918, 0.15772760575336797, 0.11543004518194545, 0.10800587178598489, 0.1653302469921689, 0.14796859554706082, 0.16542697325348854, 0.09363210880227628, 0.07975672431770833, 0.16291976666017888, 0.29025661849206497, 0.12300207354729215, 0.09825060008874825, 0.17693652501029355, 0.12902690307988277, 0.18433819074303875, 0.1193956763393456, 0.14180524965688107, 0.20619651783377896, 0.1349903153435838, 0.12007218560263996, 0.1121302823265714, 0.2137510334291766, 0.09168675875351315, 0.21526094676265795, 0.2769341349842087, 0.14858770184218884, 0.13150852233652147, 0.17816160685352742, 0.1890365926608924, 0.15619158414342713, 0.1542430701515367, 0.15374705886408208, 0.14884311555614396, 0.0473841430709487, 0.19472012236233682, 0.23409082103640805], [0.09341086260974409, 0.01898247324260733, 0.08154404574945089, 0.020575560742027817, 0.03611019782481655, 0.07387330695506066, 0.02361506246210587, 0.06641671271814455, 0.050955468773721695, 0.04075505019676301, 0.05187826764379298, 0.06577463910704659, 0.08723276186614268, 0.055138293518534595, 0.06928620229084646, 0.022768958569354108, 0.008192188031370602, 0.006295406041787036, 0.018116665568443078, 0.010557046869859822, 0.02798235543342608, 0.014659321299874255, 0.03390974432770764, 0.02604315132503548, 0.059819358866661794, 0.03184569278551686, 0.048174554286825086, 0.03711793669349244, 0.06160786773468699, 0.03857935283092722, 0.02867681605200614, 0.029666092201706865, 0.03746028223465528, 0.10441203841999655, 0.02391937173782818, 0.09508322488756911, 0.0264006520005604, 0.05759830143482936, 0.0285306062564374, 0.04300799603844362, 0.04096624531572865, 0.029718069352149486, 0.015620058759175723, 0.07328780893717082, 0.02389588539728955, 0.03628120014083482, 0.05560371874561233, 0.02694595721550286, 0.025339953473679004, 0.027011270041487394, 0.05530999297456396, 0.07219842424796474, 0.006046691287924806, 0.017161459263954914, 0.024496802849875345, 0.02227741740493765, 0.05701759529690589, 0.009575544597370731, 0.031004947677795446, 0.030710465394921845, 0.024988830480123722, 0.03294656879358715, 0.04353550503090505, 0.0550939983147527, 0.025396303070949453, 0.03085986211625559, 0.013102090545749713, 0.0248240104936544, 0.014242663314836401, 0.04667828114883554, 0.0457113747665238, 0.028092208611328277, 0.05803631603597634, 0.05072055174218071, 0.017104345493979992, 0.00832944896237384, 0.02919128239755669, 0.010198940984874724, 0.0754224669729029, 0.03509541094723729, 0.00390676400368853, 0.0117502182782177, 0.06806203209224247, 0.03985489688573345, 0.047511708201660265, 0.040006815951557896, 0.029863373248747764, 0.06044783441710377, 0.11759851833865528, 0.02375177659785315, 0.05029170721348736, 0.060457153876702634, 0.037995720237133004, 0.07045678463914702, 0.05315845802185997, 0.05347117511255126, 0.03980467599185725, 0.028403025803967353, 0.002008660033630628, 0.03450702477787291, 0.0018878113393927176, 0.022511761785755237, 0.025334759397552382, 0.036249893957809094, 0.019074258236815373, 0.10887541988443945, 0.019825173789755474, 0.0253300019915426, 0.01814260147511959, 0.02894195908259961, 0.021932118594826713, 0.057137940048931114, 0.0173109345093009, 0.04837893888414387, 0.028398065384657636, 0.03743073422341578, 0.05408543973199783, 0.021126142387548764, 0.01630882255642885, 0.02632097502599561, 0.04790235941688861, 0.0115231019369657, 0.03202961708959793, 0.04373240877964324, 0.028564275820709528, 0.02963884245424021, 0.01626565541711546, 0.04255089435666319, 0.050378470501351746, 0.031194885772082116, 0.08026110894617536, 0.08261698253092267, 0.04762888901055821, 0.031369032879029556, 0.040575636235336145, 0.01955073811264048, 0.04705480187230053, 0.013285451775206434, 0.04934196503111913, 0.07006048735591673, 0.05318226420410699, 0.013226375862535451, 0.025777102395471548, 0.07491419827865978, 0.03450558453257527, 0.07495326110191884, 0.0031638775309998425, 0.03664103163886936, 0.03694169433607209, 0.05172998749560887, 0.042159840945274606, 0.0050042433694245355, 0.04399353750951348, 0.07741878485126842, 0.030119114465290503, 0.04918556052049802, 0.08257245750076349, 0.061227428471489306, 0.054753116001525236, 0.020806545827297435, 0.03376615646805975, 0.07142806155306679, 0.03047926197459381, 0.009261455251685074, 0.03475198522210121, 0.032743670406841466, 0.0222575604059403, 0.09497217278206542, 0.03151893713361314, 0.024068772289601546, 0.03490451715826508, 0.06662207024712717, 0.03389640673694592, 0.02233619741614788, 0.04746062162842962, 0.13527275663950752, 0.04555178716057732, 0.03687929647463945, 0.07378414198155366, 0.04467795280018642, 0.011962679357478216, 0.060902890644126365, 0.012639249907806517, 0.014391656882399994, 0.041056632199474884, 0.03262070946455483, 0.014914014891180542, 0.06451846175496617, 0.08029872386325752, 0.012246377995207667, 0.03872554155907804, 0.056891501055008946, 0.10561519482683752, 0.029484454670079777, 0.009032475401557261, 0.02017714139524727, 0.08980814262383408, 0.013848089729435744, 0.0320550971739595, 0.024536059110335285, 0.030801223831311352, 0.01699538097806996, 0.050381940879648736, 0.015284284337183401, 0.06200245281140651, 0.041223984106533954, 0.05722847631982258, 0.021951355062605395, 0.01969490628389101, 0.032719010036558874, 0.04505522045937758, 0.06275528741459693, 0.01224481613345204, 0.09890867727658442, 0.015457261244826501, 0.06547148279365032, 0.02147738987039174, 0.06873615116121308, 0.026885943802734538, 0.023989756065871448, 0.10096995175004968, 0.03962305952764807, 0.015890886162167356, 0.04333156859502197, 0.021941953248554663, 0.005791559111281869, 0.04505202970317295, 0.0561015073570513, 0.031209433781764204, 0.022521787961464257, 0.029455011995929866, 0.0557988106964096, 0.021372114067837115, 0.008693614602839995, 0.009796094607501742, 0.02810694622777162, 0.01426672613653805, 0.06908154190187493, 0.014470888568358797, 0.014061624289400155, 0.03278728379237075, 0.032050657694438295, 0.029926839802834778, 0.03968641499898607, 0.026060313609759175, 0.03872135105813223, 0.05280565921097033, 0.038510086991253405, 0.09749527569980392, 0.08532922489628678, 0.03353567125516073, 0.05150303394804078, 0.03815431958965717, 0.008353315474044892, 0.02410778531714553, 0.07019102873821413, 0.023998713548926097, 0.028474925070880886, 0.028638777871345802, 0.027955902417400674, 0.04146475404981644, 0.03944468744579823, 0.030986814376627727, 0.03761240814421927, 0.05095720013243057, 0.05128607018700531, 0.05529831779459792, 0.04511550774857883, 0.029526112616182338, 0.028552395712223747, 0.011305288775944182, 0.037405005160478816, 0.06346566542502373, 0.059682390006679686, 0.06910022678634814, 0.03728941015358414, 0.021703941221799583, 0.0639199823771994, 0.03558168525717432, 0.02139234261947774, 0.048382662071455876, 0.04490637723656912, 0.017805292962058898, 0.0032658366516472833, 0.012355715978980787, 0.052959730983861995, 0.04288697329860541, 0.07210589614847014, 0.016447545757757562, 0.05895608119786747, 0.027012459392989838, 0.062322543498369, 0.016807586014751467, 0.035395173491128994, 0.020675274746252165, 0.019042469418397354, 0.02686355105270782, 0.016581919494896166, 0.019978063872023936, 0.052015837882795644, 0.02777199151985828, 0.047394937249801816, 0.1213842950340721, 0.008843220083133109, 0.06311494654284851, 0.0156412803522882, 0.06510822688259425, 0.0419734402619783, 0.03242620740145926, 0.017078106982573386, 0.061058678453968424, 0.06445322170733445, 0.036760162141534596, 0.03635341924945674, 0.054392357537102316, 0.04153294353595665, 0.043130037675221125, 0.07614593742595566, 0.05148630258777449, 0.07060625605405339, 0.1606728767435397, 0.03934767390150697, 0.07218174651385316, 0.05670200154605893, 0.04923147600023978, 0.018106445955533176, 0.06427217214818924, 0.0201302912882379, 0.08681532055620225, 0.027055366062408975, 0.03972574212257901, 0.022506575370507858, 0.06266210047948746, 0.06918294896041194, 0.05742691990528857, 0.0901994526746773, 0.06367330206558108, 0.03202981244201862, 0.022281958391108823, 0.010778045041426536, 0.02873600975069548, 0.020285671156260277, 0.021534373405419534, 0.05536613955853447, 0.04527403815318981, 0.010300749281962073, 0.03326638751933652, 0.03842638422464652, 0.01539697587084506, 0.023631878092043826, 0.027353692191442656, 0.020221271890125448, 0.16916601858552427, 0.07970701287230177, 0.20272126721758998, 0.11562165143268725, 0.0855496896791362, 0.14707898360586938, 0.15368407111494772, 0.1673068764108804, 0.14330063796331807, 0.0746723213383267, 0.17761872630686532, 0.20324779944794796, 0.11761976961767483, 0.08388713332674197, 0.160496891025574, 0.10075138686525245, 0.16207464910562963, 0.10376768186688425, 0.09812343715419693, 0.10906601489912118, 0.15254106793192126, 0.14383847765143842, 0.13801345151037941, 0.14143899834204104, 0.2024138820988517, 0.08948038722718916, 0.12188718579108677, 0.1543139792498081, 0.15677270779926933, 0.14350521408261793, 0.12478975504035912, 0.08804546624061563, 0.15611753408466617, 0.1545040150203051, 0.17825886937639407, 0.17761673447826218, 0.11196506780482109, 0.2738654931947109, 0.14450497414556243, 0.28084927328651954, 0.14686904487109956, 0.16384449607181936, 0.11042537663372294, 0.14966425455866322, 0.1726107482588099, 0.15491440832134218, 0.1597209205670703, 0.10516935463754401, 0.13183649989866442, 0.13691832882262048, 0.15324131825998907, 0.178564538458182, 0.10588599158631218, 0.11923124322727804, 0.12844959454190347, 0.14869461707290144, 0.26008734058949257, 0.12198919805908397, 0.08970972330820176, 0.1396313985629428, 0.08009701291279447, 0.14656688447200483, 0.11035933219377073, 0.13961020857095718, 0.10010396596044303, 0.1403899022167729, 0.12510842463422206, 0.11292033348112337, 0.1459596218961862, 0.12822217368070157, 0.10829110930283224, 0.1454932735331597, 0.24474209384812465, 0.2462411287330812, 0.08982891892834056, 0.16039585935011988, 0.110532054377179, 0.2098136172900277, 0.17409084545027825, 0.1669195423563642, 0.12448787043291716, 0.11207664851099254, 0.14132646002596425, 0.17239478807295525, 0.1784394209783885, 0.09907736983751098, 0.07356937689286086, 0.27245794452967187, 0.23460068319353367, 0.12250409341387211, 0.1680006609568673, 0.11894123298266243, 0.09429945565399625, 0.15504142569918788, 0.14531618464858304, 0.18535668931661115, 0.1159742357389581, 0.09963053128411693, 0.14806691527126298, 0.20038808515715986, 0.126962142906362, 0.1602898021378825, 0.0990641471599379, 0.06943878402272541, 0.12689651981476816, 0.22690392039235563, 0.11665406982384383, 0.08409480444125592, 0.09064239705161703, 0.12299138662074843, 0.20056255402103548, 0.16411080355605773, 0.08682618368296854, 0.1724330465038938, 0.07831764347370594, 0.1313043599047007, 0.16924510950282698, 0.17545293445789045, 0.12377360835671426, 0.15144782982045604, 0.13494007529750948, 0.08762752697352441, 0.055694132442435915, 0.13680900807582563, 0.18685966189349854, 0.07938410681221755, 0.1790688847822528, 0.07792424200282944, 0.1554342755867589, 0.08603243998462155, 0.10836216395780926, 0.18588084667440385, 0.1918798054177915, 0.24590985699286386, 0.14524003550890954, 0.13066335881669677, 0.11218737885956803, 0.19286942247661854, 0.1578425342637685, 0.16108135482476604, 0.11674152642127969, 0.17371504867990173, 0.14139396769385185, 0.14997640474429055, 0.2991635857089874, 0.13531256256805313, 0.12678523022200794, 0.11244046366623334, 0.20887853036965096, 0.09899739025821609, 0.1505643925479343, 0.15764822372265402, 0.21551787733070313, 0.14835615942795433, 0.055205644138397715, 0.12082497424055492, 0.14963449970368417, 0.22479396103130234, 0.18513925824194186, 0.1905871392978776, 0.13900571923342445, 0.15207645092760363, 0.10735969960449204, 0.08497682445111775, 0.10838348418474199, 0.13348919669947318, 0.06033891586646919, 0.21901298494588947, 0.13035778166545978, 0.10660383895400072, 0.10872303733542081, 0.111838195983681, 0.14382238980502854, 0.10876491170136199, 0.16215297393500805, 0.19295790563187293], [0.0032140852577398505, 0.05714683816017163, 0.06408310930935607, 0.04431989862613621, 0.00574135018752948, 0.05047593603751833, 0.017230162029004386, 0.06945241272689835, 0.032046352280303836, 0.014114176005785985, 0.03191136950326543, 0.07088792360117359, 0.022109251529459032, 0.17806416046955895, 0.05226954322067961, 0.0036887238891194427, 0.012960379601516312, 0.0954771779417511, 0.023304228032488498, 0.015586369085095584, 0.04881281278006012, 0.029921013704170624, 0.041594858761997, 0.06868130692671384, 0.09005654663328203, 0.06229364666186514, 0.012704140427822789, 0.04741484787495387, 0.03237695560880727, 0.10947498327661907, 0.03666852270403216, 0.06485435300536695, 0.021927083481944377, 0.01493057866971339, 0.027032634318475763, 0.1110261964100984, 0.049933093795252424, 0.06468065022941559, 0.06870946831881039, 0.05559385536358722, 0.046476642976725296, 0.037001950981756376, 0.015919670000702383, 0.033527225135795535, 0.03806842964202647, 0.07600414221205058, 0.08119480924740916, 0.030009395352775053, 0.03105045904615714, 0.02415060963211281, 0.08070260541693819, 0.041463781118152604, 0.01578744609780129, 0.02335123710274216, 0.03643503825690958, 0.01798562239855528, 0.06162728040268826, 0.08091684190496322, 0.020228994056402196, 0.025198809434509566, 0.020884027959959164, 0.04685330542645628, 0.018056203994239052, 0.11475785665454404, 0.07823680587593587, 0.025474756220055204, 0.004542403912637383, 0.0618775460057922, 0.06690938386224932, 0.062370527415506305, 0.003803475481089986, 0.04318232700649289, 0.04919570735505512, 0.03714763409187717, 0.019827111992203904, 0.0523236635020904, 0.08281320063096863, 0.013977801821555101, 0.01986067430416663, 0.032057973834115176, 0.027318176355273015, 0.023510445495166128, 0.04338971849891447, 0.039218626390661926, 0.03704382534769755, 0.057827660498479684, 0.06401525307146293, 0.02437148044156211, 0.03520563567778276, 0.017054122684883977, 0.0024882789547254723, 0.02746286929675168, 0.019833010869220864, 0.004496550198734528, 0.019134700658821294, 0.06760316074735696, 0.026603525489448544, 0.022549853592570272, 0.04913940755349975, 0.047516270255249356, 0.028395271078953822, 0.09996754102288716, 0.05426319894350825, 0.06485076005300207, 0.04438158019535965, 0.027864833715401834, 0.04372735259934299, 0.06455349495574352, 0.05108812838912972, 0.10556575151220446, 0.031153001830041892, 0.027035886361714334, 0.02717714531407241, 0.054814625200965715, 0.008494568680743537, 0.01818575520789431, 0.05104404002908738, 0.04588237708254207, 0.041012628109104214, 0.06158035751732607, 0.03995066553714775, 0.008466066379520682, 0.07817325888261681, 0.054842081792171926, 0.05676380568935026, 0.012958037287687824, 0.11002251397698157, 0.06569162581957157, 0.02763883011685985, 0.07176662645032329, 0.05963935118709361, 0.07126382762385954, 0.04967782563800293, 0.05502792706172313, 0.03998623882991172, 0.02920422928347703, 0.021523274706616517, 0.043855664665780725, 0.051358668509149746, 0.14779564353727526, 0.04120776219473731, 0.04423225050671928, 0.03265538643444738, 0.019002270869790547, 0.025991287172561692, 0.03658981866113121, 0.04869471266565304, 0.02795813173326033, 0.05762970337884561, 0.07029072742067999, 0.0423733917846074, 0.03492487211441321, 0.013425951342909567, 0.051693667267118736, 0.0235093308372363, 0.059004260467425476, 0.031791658688997554, 0.009337910826528266, 0.010048821268062438, 0.0068817831455699864, 0.04097927264088104, 0.06973817884441345, 0.012667514721772844, 0.05941204140864073, 0.016060612941791695, 0.012532396921737781, 0.04391921931997903, 0.03199858095256552, 0.027760013735162157, 0.055924667451050014, 0.049099632268471104, 0.015692673360688553, 0.016546899700657498, 0.0176983930531048, 0.05031140716446023, 0.020631759036933223, 0.08098560595704664, 0.00650163691100334, 0.01952471793629229, 0.06900075793025956, 0.09173954987237531, 0.07347876401317698, 0.031702053214934085, 0.10661859380742235, 0.03686634958871911, 0.0676799840444038, 0.04933535752277221, 0.04109282602345751, 0.05692211009802357, 0.049042646818223505, 0.0550607271162012, 0.06362432989502145, 0.03400740138585529, 0.049879245475054755, 0.03688488125560745, 0.020011126311616074, 0.05314630020650164, 0.06986721869437926, 0.04190885904996146, 0.04349532371927654, 0.10460484742877946, 0.01973123800370001, 0.044023054877236005, 0.008750443005063122, 0.02735657076681814, 0.05392764477179416, 0.0733448441831335, 0.03512210528095884, 0.04738671329593466, 0.021759725829225876, 0.04678210904521327, 0.09369269869620762, 0.021879361949921138, 0.07129075561439799, 0.05575733086574943, 0.01774189344066526, 0.039995623406984156, 0.024815211973844037, 0.05809874071048633, 0.04234114331343482, 0.05247526847186589, 0.05272986630218164, 0.07889863689460101, 0.009382054727945116, 0.047696231969542084, 0.05439640631178214, 0.02334408375674919, 0.04291466737706815, 0.014210937698672136, 0.05288157086338728, 0.029129254173547513, 0.06580823972340553, 0.033642234085428144, 0.007760686613994861, 0.03543807058444908, 0.076848286834936, 0.053465770362245466, 0.07520536531604106, 0.00520772541940753, 0.0008441754459542403, 0.04130944504492706, 0.07077811255810723, 0.0416576971239861, 0.03521694696598476, 0.04490710502009719, 0.06045988881059232, 0.038923337800248016, 0.04135865853318284, 0.04577063549790652, 0.055399150287191716, 0.04335199249908329, 0.07809769963064501, 0.0755318183632147, 0.049734382079012936, 0.05030637013635809, 0.07713855754944586, 0.038749121745387395, 0.12164771436683594, 0.0402836877882721, 0.040561206969282323, 0.0636183237656951, 0.025256451805152243, 0.049640543969167825, 0.0323922811977325, 0.016518680851966623, 0.02441717375580582, 0.0714505079292482, 0.009238763727367887, 0.0803321865837901, 0.036398534167317614, 0.03609022591263056, 0.023191381366022175, 0.024706444725574508, 0.016825397558990988, 0.015141249976060806, 0.0445611167308544, 0.05328788857666716, 0.04342797692985304, 0.03733287032152857, 0.013863656636057122, 0.08914723091067807, 0.06640968003099965, 0.023305698921303117, 0.023543896724379832, 0.08017703845736482, 0.044371460173879905, 0.02849539302499785, 0.03559552080508682, 0.0835688008115657, 0.0833822584020034, 0.03211373545890374, 0.049849452315679485, 0.025718042762168956, 0.048462476941847035, 0.059365401975810535, 0.034059495364706364, 0.0641881016593787, 0.016891005328826366, 0.039951021768032544, 0.015154909323750725, 0.0591503419432669, 0.03669509446368583, 0.031558676029465375, 0.022835843790803226, 0.011653648107312621, 0.08749189876740979, 0.0901810359209776, 0.06565955737906118, 0.029596686550986864, 0.054939585632734725, 0.02536305677025549, 0.039138589354772726, 0.009506132243381394, 0.05473063898182685, 0.026443662091849313, 0.021830703875410463, 0.06447943723610332, 0.022830195807581468, 0.05887407148557325, 0.03783832747308958, 0.03404674383120672, 0.07212363108391724, 0.08736914083842309, 0.013498129274305559, 0.06381234319339837, 0.03808174041971084, 0.0240878421332567, 0.025472076827540033, 0.019415358885101253, 0.03294011067238546, 0.025374067368947213, 0.11589997883645758, 0.03242528809595012, 0.051478465508309104, 0.026791506229088675, 0.04994366963904712, 0.098560429027965, 0.06515128868481805, 0.029663656042107654, 0.0313581065500095, 0.03269618827729456, 0.0447951948961183, 0.025409301667804682, 0.030135947332206755, 0.04500007745058787, 0.020125497493051717, 0.06330112123020715, 0.026552536592428243, 0.07109544149810268, 0.04353991386690929, 0.0792134300835671, 0.02325624411535119, 0.14587751259246182, 0.2244692776472338, 0.11109757282200361, 0.21590253007748436, 0.17676591722955629, 0.17728075895818973, 0.08146784298362271, 0.2242648547455188, 0.14403484130819, 0.15349282492553035, 0.1278662339093224, 0.1689487866937153, 0.1094677207630969, 0.23470025930193164, 0.1488589276109011, 0.14017061720932686, 0.11352537440196162, 0.14175150092811356, 0.13549124491551232, 0.10544413505422492, 0.12429578920766232, 0.11043279236482997, 0.0990190092594393, 0.09822567158769216, 0.20979323935124183, 0.20054205350818174, 0.22790099914756515, 0.1089248248946763, 0.1134270623386387, 0.2002664610383011, 0.1055439256672417, 0.21921167750993084, 0.08729068577409753, 0.10530106047348631, 0.1616319575377049, 0.2059365688793121, 0.07988466866194241, 0.2649714881854673, 0.12898631574165437, 0.09991386890291207, 0.1578508539786262, 0.08261263881239199, 0.0724678956753304, 0.12919043220819967, 0.117661896792631, 0.1343184715557483, 0.16983993081075532, 0.1906989421695471, 0.11481365849894863, 0.0869264186269814, 0.17994444667091294, 0.22964585632566484, 0.15909663551757414, 0.23947571434320944, 0.09402938667804965, 0.1175042742022103, 0.14705244632017228, 0.1353086555196393, 0.13143301671070437, 0.1776826027179918, 0.14619766073601861, 0.23544863527340276, 0.11565281588944698, 0.22560671903193, 0.3038890611740851, 0.11836727224891225, 0.1618316000507724, 0.11088428628300467, 0.13344801181266386, 0.28439184770949427, 0.19874805945061869, 0.14064842624770058, 0.1911106378200554, 0.26470271389811273, 0.10934146181229623, 0.10148078683883914, 0.18389985055452396, 0.11625106161039685, 0.10642459736235681, 0.1720756205219415, 0.14281878398070413, 0.24010427416332308, 0.22306490058620132, 0.152554122070151, 0.23027063167143255, 0.12084644002419327, 0.14158807905210605, 0.11185031549464311, 0.12889562625317805, 0.24839562844605217, 0.14827285502706805, 0.1243591446790003, 0.11505778007689985, 0.13147648453952807, 0.1795756672659228, 0.14011660801066508, 0.09458310736884033, 0.07714029656903398, 0.2581134690873085, 0.15518145124998786, 0.21496344417814287, 0.16854622281126438, 0.10355472474569276, 0.09016857167044956, 0.14372334995817754, 0.14862850368503602, 0.09273454486843079, 0.14452899866286786, 0.19294117427160665, 0.3019645563777416, 0.0989045020973971, 0.08360438559564852, 0.14040929956301568, 0.2170482298900043, 0.13086799622303055, 0.1420052752139107, 0.08272137733236437, 0.13896577540905247, 0.1673500990915683, 0.22009722918512362, 0.1822961220938352, 0.11071311159720344, 0.17496447679736923, 0.222120835115352, 0.22038379203407998, 0.07337236206137365, 0.1670024024262544, 0.11203791510554091, 0.07273513012595716, 0.25445120108704417, 0.19758300825713143, 0.20194105263198578, 0.15039360090609522, 0.2027000619038459, 0.11734553312342014, 0.11757273948000324, 0.09829758426114436, 0.13148276646050716, 0.1596718296528824, 0.20605044018837715, 0.16916562021980364, 0.07595771728383918, 0.1825900853521401, 0.12590910908916306, 0.08448625238792551, 0.1583567171567871, 0.17828433413899716, 0.2292390789596304, 0.2040949547963758, 0.1647699915713841, 0.2016444999964968, 0.12179999732442441, 0.1741384041886176, 0.11716119704707978, 0.23085629056778648, 0.20671791727504424, 0.05886293256715421, 0.13355941631861273, 0.2046619977561697, 0.2137271774512145, 0.15535503145187132, 0.18244800668570305, 0.15511801916985743, 0.14419375858720274, 0.11717668734490873, 0.1882791462083978, 0.07563592205124517, 0.12974638221485, 0.1540412059834888, 0.1365253870044985, 0.11627402892636678, 0.23905304831362542, 0.12845166297929902, 0.11553745836980882, 0.21941505853206883, 0.07539667279249238], [0.07727587880987315, 0.08952373248194495, 0.03672196116719035, 0.0330695144141153, 0.0852308132415337, 0.03713560651146597, 0.05885864247477824, 0.04953517623606229, 0.04784847279229472, 0.0358730859513725, 0.03601093198202791, 0.046429785208836685, 0.01788098819463724, 0.07203638899110018, 0.03661585032879826, 0.060856362294045195, 0.09105252988275983, 0.04307500957962006, 0.018169314961039254, 0.02939263137147552, 0.017048298501439633, 0.024957102948739648, 0.01534316777026341, 0.029868178535252813, 0.02602814557781864, 0.05895881613175716, 0.02947102323354733, 0.06364053265462, 0.006868453215687506, 0.04648038148579579, 0.08480712065413114, 0.04733356977662733, 0.053643284425620115, 0.02813348734390832, 0.027659211886085333, 0.038982100574479955, 0.07054253286051174, 0.014244974027538012, 0.045563033331305756, 0.10522603748306152, 0.045353132900932146, 0.0442977050589698, 0.03169140459278659, 0.055303048387530356, 0.04674381997075774, 0.025486881476676753, 0.09421431264209171, 0.052916048650419524, 0.0392533608171488, 0.06523843118620497, 0.06813052035267315, 0.0426086497252747, 0.02128780417655024, 0.009708804634189414, 0.036739140688892336, 0.00264769131805928, 0.017878299226023017, 0.04026443216829531, 0.055515005763980656, 0.043401324730967326, 0.053385246860524344, 0.026610939305335767, 0.03215517698516769, 0.032143042152447086, 0.026200636019629818, 0.03811373608186841, 0.023045056657264792, 0.07153588076753002, 0.08133366268368498, 0.018584350754897443, 0.03605426574546484, 0.03057899704623607, 0.059631820542797934, 0.08527589751587761, 0.05284815793856979, 0.07605291903018951, 0.04596185104380693, 0.045310323907723354, 0.007125412512029852, 0.044634753102136236, 0.07840438760937223, 0.034301651927131804, 0.01104972088679431, 0.05656899719108498, 0.07038442763469874, 0.027952483750038573, 0.05361451782406338, 0.014369071652782301, 0.06559544348067815, 0.052663798879591696, 0.06791173330237789, 0.024862134859206218, 0.02309058717782459, 0.004823047295963813, 0.029179540184897282, 0.04700037898615964, 0.014580696738595444, 0.015330556047809942, 0.04464989866039926, 0.03934934780362152, 0.03374599686433231, 0.048530049727208195, 0.030584844212318142, 0.03270945308970348, 0.026615164280238173, 0.06618700891492829, 0.031332670515703584, 0.04155613301742462, 0.03526230703198141, 0.03528897838306523, 0.020548395264232834, 0.017743492649207195, 0.0753655159966119, 0.06795907753609842, 0.07675681593677691, 0.018274046841167638, 0.03234908533012194, 0.09234776239722006, 0.012202665975858128, 0.012468522425831087, 0.051004728227252924, 0.06667658506381897, 0.04512044518525082, 0.017532628863268805, 0.02782489563668928, 0.06545437605030115, 0.05365741874782309, 0.040215122919048996, 0.031245763586353392, 0.013026316789159132, 0.003963652735335692, 0.10769454131443655, 0.030813632540464885, 0.0324293100575526, 0.03785269545210946, 0.06120897341339339, 0.026857663667009726, 0.03603603668330658, 0.03582737348493069, 0.06713128122951716, 0.04669544534877904, 0.07717087113809201, 0.04110999022340102, 0.021935667497135942, 0.09148297936565454, 0.026949960024907228, 0.036689724187336625, 0.036621722392737865, 0.03905320119473242, 0.04821034591464747, 0.03948496451841728, 0.04156621090406853, 0.01936948937063496, 0.07708693854510784, 0.06172824313022918, 0.05292729482114796, 0.026984924277771386, 0.02460648365799458, 0.03167913952511886, 0.018110793504503467, 0.01964199833662039, 0.03598873458442188, 0.06151949183174199, 0.10402460477405018, 0.026644281367020264, 0.06169818567052003, 0.0226650808772613, 0.043660695289051345, 0.021606291824531172, 0.05267832390663605, 0.02735408098106423, 0.05770741533788462, 0.014420764393083032, 0.031369073098645575, 0.02327085532728703, 0.06859208832705213, 0.06668037719904416, 0.04948414328898634, 0.013000058167944513, 0.01889018071514945, 0.07496166508644819, 0.08067224535249895, 0.06378705080057825, 0.06180592444575122, 0.054400818978226, 0.030441175913438204, 0.11574008096490176, 0.017205637639328357, 0.06975917731441798, 0.07294157549979226, 0.07113160850900797, 0.08663175822866541, 0.044241493357525724, 0.03144473385726733, 0.041304040294621265, 0.043640302028507, 0.02930211616800197, 0.024758825987397183, 0.02301839679749983, 0.021472703327514955, 0.04520273835007702, 0.06227963491373005, 0.04615901143199975, 0.10050915752447422, 0.007409888729002448, 0.022300752443111232, 0.02082449909780295, 0.02854699287713776, 0.010789117884762105, 0.01310429496375183, 0.0530310346174144, 0.048237220279031226, 0.009608850269878825, 0.05391057250240157, 0.08807559647867758, 0.019861785131656838, 0.01676053289444216, 0.008439038797552067, 0.029773919077049342, 0.02062066225335002, 0.016707307020682963, 0.01744247755155929, 0.07179348549294857, 0.05573879153798184, 0.04749397326621318, 0.08351057812932038, 0.011693800690643972, 0.04758223425596953, 0.0319705689476142, 0.01590794310980146, 0.13512059625598694, 0.027770507224504987, 0.050758840816636244, 0.061427691515775464, 0.0730909703059062, 0.0014394519178407088, 0.026765947620714867, 0.04020778379673439, 0.037136667543241096, 0.07303482372193568, 0.0626953257127635, 0.025856995789874947, 0.08273128284922532, 0.08118359372019768, 0.05589797694776809, 0.048354914366838433, 0.038941517066691196, 0.040504198536396994, 0.08024135153860816, 0.020537340615485466, 0.03810697152549702, 0.034739237519041184, 0.03481069053973883, 0.058929088089855454, 0.02978018950670958, 0.023590026708740382, 0.16935099817572102, 0.030003590321528818, 0.010163333218154168, 0.03496719081135046, 0.059834037111291004, 0.02423484482982707, 0.035326750348171884, 0.027447384744582158, 0.057378181391545845, 0.029100979783482132, 0.037410578450127956, 0.027386432874106595, 0.11164795336944443, 0.015178123703076234, 0.05696557792684725, 0.0139001808354571, 0.02865122488489555, 0.03619377801735555, 0.03796415741465265, 0.005118617902494847, 0.0334758895839895, 0.05209163462202396, 0.004517578833451074, 0.08347378292631719, 0.02424902894774512, 0.026222306731787902, 0.02468519727699459, 0.021359871982807116, 0.02834986313246191, 0.008165585628199962, 0.050769987395934524, 0.049161850099241546, 0.08105158910996492, 0.07029017583737451, 0.055181742195160165, 0.04085864826676346, 0.06875994585214124, 0.010604119142367235, 0.07832854490486846, 0.045394566766316855, 0.019361093046984846, 0.11806872778482015, 0.04490384531597938, 0.03147401756817295, 0.09814923133460746, 0.03437630719535294, 0.046370761964710495, 0.02956301507149493, 0.08686581341129157, 0.04228566705639805, 0.017252585422548077, 0.028182861710628195, 0.02430398043455376, 0.012276016021778267, 0.010685114745771693, 0.04077067455997871, 0.03352742048821623, 0.02408205433898876, 0.024776417281358473, 0.01647318863580304, 0.06883188916911041, 0.04531179479653797, 0.008267224428334064, 0.10493238065992633, 0.06260608413046406, 0.04593088576990751, 0.021940428733585343, 0.019129906863635106, 0.029652354330004706, 0.034546417018939415, 0.038634074491358576, 0.006910103022105873, 0.02870022578375234, 0.05037580834581487, 0.04158326019082339, 0.022730299857475107, 0.0670824124808273, 0.04800475472884794, 0.0752303014779764, 0.025573960775809906, 0.0353050432468374, 0.024577918154517972, 0.025441986809094107, 0.08524418147581239, 0.06814088552228867, 0.06615549971860263, 0.04015551361766073, 0.024555722672131755, 0.04822329280056781, 0.02458324629603134, 0.012651616482124215, 0.016854503154454213, 0.030428830406538425, 0.036505594954735814, 0.03953253474807547, 0.06387818845049029, 0.12272844226249766, 0.21637070172977066, 0.10831705670082763, 0.08263551419781101, 0.2901527676130495, 0.14532150129877752, 0.14171376343696349, 0.08945859968662263, 0.1013493414727911, 0.15977322905054017, 0.24509198152490203, 0.1864357394797187, 0.12607984710484743, 0.12268785492426927, 0.11231185282550513, 0.34931470429705036, 0.19459777812082923, 0.14713498463313426, 0.08601269023793359, 0.15393596082445116, 0.10433320031170884, 0.13061068261102324, 0.09421282643151861, 0.20111407603948347, 0.16205863786801217, 0.2341342122564393, 0.16367080861762648, 0.3379541413197595, 0.08360365781212047, 0.163350323395383, 0.2027688565994463, 0.2058082644737536, 0.11762567615557103, 0.12042268614975676, 0.10938686018268909, 0.17533949215806302, 0.11496405688024337, 0.11483202928737288, 0.14136234358433755, 0.21185974620522993, 0.12688835331749532, 0.10292976553882323, 0.15777619104952584, 0.12810903781604382, 0.13409374732403986, 0.21792933825523625, 0.11565496859651421, 0.2496474927231189, 0.10990261355595243, 0.167671442332287, 0.10838738357227658, 0.12271145809321635, 0.058786032661314935, 0.0718287485201032, 0.1870615873485804, 0.11342268031571182, 0.1504546274701434, 0.16418030305254847, 0.16549469542599496, 0.16037681440432228, 0.14920067943392262, 0.15918401550621758, 0.18071497790515426, 0.0985908350576797, 0.2710462896333587, 0.13763575484195065, 0.22734777641392526, 0.2214456971494421, 0.11574879904548008, 0.1415207246018033, 0.14087095946794556, 0.20968571125018984, 0.15836099192740458, 0.16618800499746877, 0.11004713604286795, 0.14314069412648678, 0.10072297266414089, 0.14454966771506494, 0.16202742744597698, 0.16000624235358932, 0.2548625596588658, 0.22431408355553306, 0.10429578457748699, 0.11804084984525559, 0.21407963918341746, 0.13773211338106664, 0.2011490862576231, 0.17671817463011513, 0.2520570997148752, 0.21470446049446062, 0.21168189123272899, 0.11360399034475127, 0.3534240305664078, 0.10253067969554856, 0.15004757431245622, 0.09573096754930674, 0.10231766128732313, 0.15713214093158323, 0.10809165065086658, 0.1522370536000498, 0.1379193299480023, 0.255809429011518, 0.07490988520364608, 0.20945442930584957, 0.1032811547479322, 0.14270656742155552, 0.20393346346193747, 0.20241634890196786, 0.1022415734346836, 0.17631453822457022, 0.1813435377252679, 0.10998644655750645, 0.1421847696145696, 0.21168281053823812, 0.14955828927697676, 0.1585919214712997, 0.15685622670477437, 0.13370845106340226, 0.13459345115528953, 0.21469428684682618, 0.20677318285790183, 0.1958012409628399, 0.19869584289769973, 0.07494158592195281, 0.3502099240018476, 0.1371710612288406, 0.19248971865782816, 0.12194497180321526, 0.12047910852538002, 0.12899730144248855, 0.08617312437103641, 0.18650081098800708, 0.07066492306729479, 0.11537018307154218, 0.14341886065179302, 0.16950749461689305, 0.1671461051990909, 0.1006295329200164, 0.13031213814693113, 0.20928543030975327, 0.22020149375161818, 0.16960979799830145, 0.11499106147957426, 0.18781013185939482, 0.1309012750824613, 0.12327233404521981, 0.13996746601356616, 0.11643916683932466, 0.1494359143919522, 0.11146191657791216, 0.1433685133534093, 0.16484327554222078, 0.14653907548035347, 0.16771864867018116, 0.08134719179642778, 0.19238773703334794, 0.12390530653177731, 0.11510432757917913, 0.12078604931312224, 0.11124999367541845, 0.08537097668816006, 0.17452566163434138, 0.14944662430113362, 0.181949237481721, 0.11171352283488359, 0.2572433770664277, 0.11880677689107196, 0.12323011493971273, 0.21036731499818065, 0.09870119002317229, 0.22755625958163894, 0.1824196154672292, 0.18227543771987964, 0.08975384231176108, 0.10492781477589762, 0.1342269087270383]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03657652703564494, 0.02492554587191872, 0.0432239217503417, 0.020837899890818426, 0.00745317556955401, 0.0508571069146837, 0.03053485314481922, 0.029866035404284636, 0.03456585650001803, 0.015337589692564742, 0.03425299768306075, 0.06074573153689985, 0.026566082942149332, 0.10225782215955759, 0.03607198918959306, 0.02954826596373272, 0.049594402493488406, 0.06017257136503055, 0.053267851547007604, 0.02661884724793415, 0.0313076539145362, 0.006784975966213332, 0.03786708258332745, 0.030734528216623494, 0.03778337215584132, 0.025674421715760426, 0.022360549436040947, 0.01431706385882271, 0.08253074401328642, 0.023616096680803646, 0.037494231421019764, 0.020233745716752547, 0.046036268824771534, 0.03829591945114155, 0.06189682843884634, 0.027495472083589243, 0.03513369236081358, 0.04732915711018348, 0.012504468228848232, 0.030981618385281295, 0.004539940939960821, 0.02163990393220898, 0.038708614846391064, 0.09902839383651173, 0.03857853694728786, 0.03719135856015548, 0.017316806573240508, 0.04876829158034056, 0.036107903391483336, 0.03559843576963871, 0.06864997393061077, 0.01890203401055788, 0.04994733153932518, 0.04056794471257637, 0.0019333557452961443, 0.01595627751216413, 0.03121013666743473, 0.01769390377786852, 0.06494518805054889, 0.030281009911108884, 0.03124808291754415, 0.07879795761959207, 0.022036092047910058, 0.030789765071183927, 0.04166969023044071, 0.05816946594765591, 0.052273580504040566, 0.016369757189926122, 0.0466923235404876, 0.042952328259425784, 0.028163736325598536, 0.0565033013211383, 0.0324921484195417, 0.03159720259117744, 0.08320798106010883, 0.031238196552881313, 0.04936645686205837, 0.10267588400071669, 0.06266269419762878, 0.015512615885405291, 0.03346255199322778, 0.014771837590923233, 0.030325172964723843, 0.06176890707724999, 0.04447643720214406, 0.03213015655356069, 0.009980936301872134, 0.03478571990384691, 0.03824035892443311, 0.021405890884418643, 0.017528723730074785, 0.06865810212348739, 0.03027479693804297, 0.021635445300489668, 0.0037178158386415175, 0.029008062894365964, 0.04286191073216258, 0.01985750270016011, 0.009002331756956635, 0.06071686151347334, 0.10569437767469114, 0.01655650069756854, 0.04850599456638579, 0.0205396733532149, 0.013707989485063141, 0.01748738945612023, 0.02850681922638849, 0.052274051648114, 0.05301092097896242, 0.06669061979459179, 0.02607168618499512, 0.07498656294398731, 0.027983297721572944, 0.019849981631963484, 0.06107531022280455, 0.025577536491196484, 0.06546391384495844, 0.023318086563038732, 0.06462097198011414, 0.05654339453265552, 0.03460319945588708, 0.10609331030038097, 0.08567974076516206, 0.02787034571801703, 0.055467918169714754, 0.030538388640589775, 0.025208831779778968, 0.03134389178857448, 0.01457447323182057, 0.0663506452955546, 0.0031738038758762303, 0.05570667330175639, 0.07050943020130358, 0.02775354795308123, 0.06829533650870286, 0.039402253835672335, 0.033020584378391504, 0.010327822829206145, 0.0742984474486401, 0.029620335685209404, 0.047937304517554666, 0.048342055581029386, 0.023086779720840916, 0.03892615317336975, 0.030314809710328138, 0.008270374007312762, 0.04551995237688384, 0.029034590603963985, 0.057358435475297516, 0.10144123371930854, 0.055926743549324816, 0.026024273003361402, 0.08331652805810014, 0.05686215222662976, 0.06824493558416445, 0.02760876116583184, 0.0058176190284411275, 0.005839410399447286, 0.07943271509101314, 0.05647841495491805, 0.031152143811566696, 0.032109301725041964, 0.03898992233218686, 0.055382530009674455, 0.037184766373567046, 0.02866881809407665, 0.021245370566424344, 0.021649863075224623, 0.027168059511290445, 0.04866835158017855, 0.029646848073048942, 0.06723405192455939, 0.03510345487044223, 0.036973238006354346, 0.09127572959949894, 0.03935318590412217, 0.03753481875924814, 0.011902096166816211, 0.07981263341442232, 0.04156058398826469, 0.023139601483220057, 0.021828005330697186, 0.02638923729048862, 0.036559856962412596, 0.06037568425639503, 0.042922029482020486, 0.08113054213144126, 0.08138116013499037, 0.019311400753776395, 0.015617406179737902, 0.07415954804708881, 0.03168076363151833, 0.06633450382299001, 0.058923242838993195, 0.0502765195203885, 0.046471253548177986, 0.05952579780451714, 0.025948968475624442, 0.03040205371836501, 0.013216358305315578, 0.051863198694322384, 0.10054641238023197, 0.012332294755915721, 0.0066571264253598795, 0.009682342999674862, 0.07595600890776805, 0.04850706325904016, 0.051994015868272514, 0.04531949014973737, 0.013971668330111332, 0.013477442985130175, 0.02217774362032933, 0.017141548638802864, 0.037034356500953436, 0.09424422837553487, 0.017415459545689727, 0.05084299940555807, 0.061669120294672836, 0.012607779015877075, 0.04360487812288827, 0.04063792684445939, 0.0886633467950648, 0.02008673152886331, 0.05884443537422246, 0.0458371012862171, 0.0064892861372490805, 0.054723824629740375, 0.019021388593940966, 0.033210447779105555, 0.05242995820158432, 0.025138439790856455, 0.0719567311687335, 0.03915590677230109, 0.03556799526596743, 0.0642500590202549, 0.02733452658679697, 0.03078417071411687, 0.019684290220480294, 0.052058191053689494, 0.049498633842074105, 0.05897955413186743, 0.08420421711860165, 0.04266913619733626, 0.049121021443317016, 0.03179126223849674, 0.03486152813439408, 0.043201797131088474, 0.023370848953603737, 0.07525386634252726, 0.034058779072497165, 0.08068377497575938, 0.07952828455956713, 0.054602039632417505, 0.052249211247169206, 0.042178085329191345, 0.05001211576464196, 0.03698961313573584, 0.015218526222592881, 0.08031353234283387, 0.03112928183268636, 0.03595088984096243, 0.06730673834681511, 0.042991337456530145, 0.03358413780769033, 0.04987123985624602, 0.08402312159418099, 0.06929456031010037, 0.04778687549274295, 0.04364050504180693, 0.008205090867235296, 0.01937899652177528, 0.007120076709637239, 0.01778035488490376, 0.049898547060307, 0.02552330321181686, 0.05298541025108388, 0.09149012696598807, 0.16203335696651092, 0.04420056127973142, 0.01056922575263607, 0.013752585378355317, 0.03274611422731992, 0.06050559744659451, 0.032150660896854054, 0.03913221550324271, 0.039106938432181076, 0.03428952475529044, 0.012940165414024266, 0.03543309484338088, 0.0322816044753117, 0.08412171711003588, 0.014582456825601478, 0.012499542283495108, 0.03386359902158861, 0.0948048668402818, 0.032528725287486474, 0.026997321495606054, 0.029649284232648152, 0.030529289431269133, 0.04081182114239182, 0.034279017859408935, 0.04947742086745078, 0.07644982152287999, 0.055478616587577335, 0.03309345083130944, 0.04211096836614513, 0.022686791809035406, 0.04842469348542152, 0.06091124866338027, 0.028500470272716016, 0.05621551656194272, 0.04763358895997367, 0.00905559114706252, 0.0698277268618826, 0.04366778926323018, 0.060486341826617725, 0.0733670377502999, 0.02885741170405621, 0.02556550316512585, 0.055750041539149905, 0.022119923134244258, 0.07239350853788276, 0.05689168108567115, 0.03191391291517404, 0.03803024398944071, 0.06935117420770469, 0.04051189388959639, 0.025304152269757567, 0.05052518016929108, 0.04155479619399675, 0.02176284955273713, 0.04363118558220806, 0.02664555690341419, 0.027975058445947307, 0.09552064577057477, 0.0565166159292623, 0.055880257334079475, 0.06369559522417766, 0.0182587921153754, 0.02742938550880119, 0.05894095096136293, 0.030823712342328606, 0.03276684456655095, 0.0791487492801201, 0.02658926284751825, 0.01619180262599501, 0.0468420707470467, 0.008796782705992942, 0.02826555324117503, 0.04587850450808483, 0.0400289558925696, 0.1203092055455331, 0.11542459829680382, 0.1723214734586016, 0.11737986918418639, 0.12408027335280374, 0.11729482576371202, 0.15476491392379807, 0.17546355243652098, 0.11055919687233626, 0.1209477781348171, 0.12914491126373892, 0.16350429174640488, 0.27212543172701714, 0.10502742152781257, 0.20471315710775315, 0.18936643947757062, 0.11906319418020787, 0.16323514973684666, 0.10134127456694843, 0.1276922553417183, 0.167415936687781, 0.16190448565588844, 0.0801804552095071, 0.08579294557773298, 0.09950522228234238, 0.2150018405049078, 0.2191182454266856, 0.17264692293059442, 0.13510653088169713, 0.14866559766232967, 0.24567420834735518, 0.14370536221371544, 0.08421734020474457, 0.17487521223243208, 0.10998655380981584, 0.16714189171550736, 0.12376941785576845, 0.12166392478731372, 0.11232951115215979, 0.16910942000967844, 0.1434799025375997, 0.09111582406706388, 0.13065801152298528, 0.14795819207304908, 0.22898276126192463, 0.13654198046893845, 0.09871458890096796, 0.10526544504588652, 0.27076060012463604, 0.11272059903750498, 0.10183048299363545, 0.16523122246707642, 0.12125500237509129, 0.1659193686059406, 0.18991716476457735, 0.1343128178268671, 0.14949792154854344, 0.13282833861247187, 0.0820165534593886, 0.14423891180945983, 0.09214684051731903, 0.11044397724852448, 0.10429923197314625, 0.13612694467508024, 0.15372491892307036, 0.19365264012688593, 0.1365891868068326, 0.18573614798726576, 0.14714163427631702, 0.16821389386971153, 0.1714250893001595, 0.08508363242952094, 0.11800419253807877, 0.21900648852029156, 0.1439758372162619, 0.25544918382600434, 0.13899503996775997, 0.1526039484287462, 0.22163295968165322, 0.1646086840980476, 0.08892175591280384, 0.10688969700206673, 0.11712283136383181, 0.20986980217839443, 0.177773445424053, 0.1876555812815505, 0.12480906045605099, 0.10402527893142355, 0.16315466453952177, 0.1839513316630356, 0.1318091658815261, 0.1122011531204466, 0.23007451316281674, 0.07623829698610692, 0.07817439269274473, 0.0872647843413776, 0.15198672670991192, 0.19670606741020757, 0.14201253772743289, 0.09138561725135773, 0.08861449336813343, 0.1905508114085082, 0.22667116755920075, 0.14028744561777962, 0.13298302708614257, 0.0758327070563551, 0.20698111444231004, 0.14850056700168118, 0.12011653443257655, 0.12001436894699452, 0.1616333671394856, 0.14626570466545322, 0.10895810375410704, 0.11235214905032229, 0.11890228507259201, 0.13835668954397404, 0.13966660796394273, 0.13221111689363757, 0.09653011216751992, 0.23378473826714102, 0.12363248730018256, 0.21826105432644968, 0.11903268089818379, 0.2754746455579035, 0.13028838942127843, 0.25829334653192954, 0.14460602114277502, 0.1472997854674055, 0.09638056414382112, 0.112444271123217, 0.15815234022034755, 0.12341644284465622, 0.14522203244268894, 0.1335706012023072, 0.21107683499013224, 0.16129749887172254, 0.12262029363022697, 0.09364609756777365, 0.12527700228195998, 0.15469095579558803, 0.13691471288761786, 0.12334089125356368, 0.13911303282985765, 0.1840758056289727, 0.13977355383817228, 0.10534234495172579, 0.12893267426519625, 0.13095853249392203, 0.1577324627508079, 0.1843152387488273, 0.10101811569784919, 0.2556441685244922, 0.15227267668852884, 0.22945431902283625, 0.16989492060196015, 0.3324877669013316, 0.20959102278274877, 0.07599091187359826, 0.1214148466204924, 0.2324209791878539, 0.1453324869996117, 0.11154820872170311, 0.1437005052162755, 0.1346266993712033, 0.12973369579882393, 0.1280772604889447, 0.11777664910280898, 0.09492570188857856, 0.12951496237468335, 0.22666315427951275, 0.09918037035893049, 0.19917965806539983, 0.15726136464265086, 0.11088421733509149, 0.12792546782762776, 0.1481996629867823, 0.21056079816433693], [0.046278996122700554, 0.04199032867026906, 0.01905535310206394, 0.0723875024085564, 0.025471174759009195, 0.029342994619641575, 0.0317706736255317, 0.04250628505683234, 0.038846683042544516, 0.02975134821158023, 0.01254307044174282, 0.03475668134107705, 0.022474914871817155, 0.05490193241125634, 0.017377026829748385, 0.023936179706886895, 0.05842225581047036, 0.02224089416314758, 0.02474985318258405, 0.02135494220701437, 0.013507066647552196, 0.0760792418112678, 0.031575321204840176, 0.013164851341336487, 0.04219443747593511, 0.032557717884980866, 0.05591956913591393, 0.05219503733960371, 0.01152327526435857, 0.016139559259998704, 0.018850934030788562, 0.022898931131367723, 0.04965521455291779, 0.01881219487967751, 0.06503553279945928, 0.04539041073932763, 0.04334214826925628, 0.03697236083568104, 0.048934873569035725, 0.03573862602934241, 0.025434647686779503, 0.02904205996122572, 0.027221754613903262, 0.021121231763954126, 0.04518790688786296, 0.03419793128306347, 0.02142488794972099, 0.02456100101793005, 0.054835033783268546, 0.05363160924565408, 0.05326734209853796, 0.03183300828471059, 0.10112857791565119, 0.09190610504799313, 0.05452770229068495, 0.07086851093317233, 0.05542865616359538, 0.023790875810288617, 0.08438845360351187, 0.030321602994996696, 0.02757885500848774, 0.03813414083373162, 0.10289386665869145, 0.05646970453521898, 0.02009912683147817, 0.03536711552090222, 0.03060862741192743, 0.02317514987812648, 0.1029221199813389, 0.05334865850126071, 0.020296564926543546, 0.04373261562338279, 0.042380052919109026, 0.037599066723017924, 0.0466704708824475, 0.06932410066046062, 0.027911302693668875, 0.06456560680582639, 0.05161178395933202, 0.016094268141915242, 0.016192834929472977, 0.018722478322865024, 0.06133154365083864, 0.027899884153157476, 0.02521662672440852, 0.005646158017278199, 0.049974768978333285, 0.10925085659349158, 0.0539211368548774, 0.025442168754976124, 0.01725898608715544, 0.04641292744406289, 0.05666238713949438, 0.025629697502740932, 0.004691127434207668, 0.04546953613058694, 0.06482369416663725, 0.10068053139313575, 0.02411532745276007, 0.1139569117297088, 0.08372927324906473, 0.07832099127793506, 0.03189869840899783, 0.03664452499980408, 0.030344725443771293, 0.07874444637808108, 0.0676005560484144, 0.04525694290115949, 0.02804553853498111, 0.03728391347272742, 0.04906986592217319, 0.02342572383161995, 0.01253399134223019, 0.038234712856431166, 0.008417866042544766, 0.04299448224745932, 0.019731921737172434, 0.008676588298722861, 0.04681158810853959, 0.049508953046414166, 0.023595611489708387, 0.03726493364440338, 0.06999291074011596, 0.12462205073285489, 0.04978708126732419, 0.06126733016102545, 0.07597002831678237, 0.015177711930816934, 0.01544695736224493, 0.07029353130248285, 0.0025826550019349185, 0.05055907955994049, 0.004687393713186706, 0.0927287302610855, 0.007998505203549059, 0.06434331873371717, 0.025076871219601844, 0.012457402659610156, 0.02855051879680926, 0.07924431108779485, 0.05552173967683508, 0.008318410592994863, 0.032967609398427515, 0.01553884960876237, 0.025200875956685315, 0.005273722936474388, 0.003318025673281462, 0.07876568999622138, 0.08348264656360112, 0.07240864643526655, 0.09326301530123719, 0.04208846070292977, 0.08878904650168074, 0.04327631067304362, 0.018404486716815063, 0.03357819679583754, 0.01041048754667563, 0.05536363062058246, 0.039412032948025776, 0.03202455707885806, 0.01376820112308187, 0.043392495567639994, 0.006163320034712313, 0.042663214337681575, 0.04490078096428225, 0.008827056585540696, 0.013720729527243925, 0.03312935737232047, 0.05096897490382676, 0.03542364131839525, 0.023999726700205958, 0.03157555103121746, 0.043961308190539, 0.07152627402495954, 0.050991773680453344, 0.06531383722059189, 0.013916242826399545, 0.02086555183444533, 0.02111793567065991, 0.043873480040459864, 0.04915946756579703, 0.025052762432624737, 0.06644691190411968, 0.05656001481017279, 0.007879239199082217, 0.015524555365705203, 0.009761200260160672, 0.022242173529981125, 0.04913574565322169, 0.016580046409921303, 0.061709190523552324, 0.02109961276273093, 0.05589695422038917, 0.0169306714463258, 0.08054921929273876, 0.010241275003570463, 0.03618466540149624, 0.042100093748059966, 0.01578245599258451, 0.02867007447827247, 0.06622856152394126, 0.01759255034548621, 0.03088296541283208, 0.08554280254869692, 0.03718075973372306, 0.040875157461531704, 0.04993488261055562, 0.0056537025469175035, 0.026502478492235946, 0.007808792626395101, 0.03459801687107932, 0.012996289015357054, 0.07790208674005925, 0.04770263263414945, 0.0501955516876713, 0.08050035820492814, 0.03324279201126868, 0.016746371759161834, 0.021740975827279112, 0.03930717083295027, 0.03750134454739671, 0.07745728076946351, 0.009009462120311876, 0.07099876886293774, 0.018431338098561092, 0.04795983899384738, 0.022006565104088476, 0.019989139588189223, 0.04783133157498894, 0.029246685876240654, 0.03187537677736292, 0.02201772317470562, 0.0627260918038026, 0.025760261867676052, 0.06537857931107283, 0.061148996389801466, 0.01318940158647996, 0.023602019815194993, 0.11309242747243374, 0.03512969338184884, 0.009390084287001482, 0.03314005962062267, 0.06259448555929047, 0.02055624958067652, 0.025514395524477287, 0.07610479084354255, 0.024723459538372777, 0.08108279187112086, 0.010750176677961024, 0.12169138903939918, 0.0523438154449386, 0.04067472204746258, 0.022477839412468097, 0.013398852897807957, 0.14883478051952778, 0.03772655141449744, 0.05882620631206421, 0.02417134380178346, 0.09254227212119488, 0.07315893762654836, 0.033427361744425954, 0.023945246357470754, 0.02828572816666096, 0.044465639192851326, 0.026988969222011588, 0.013744862254468665, 0.028244390062266783, 0.0647507549353665, 0.038232832110577056, 0.09960128204716791, 0.031337184688797405, 0.027125233281103354, 0.033130583112999316, 0.05345751959530096, 0.03030475672154177, 0.039947413493909185, 0.15485298339157336, 0.02839976993028916, 0.019800149527708852, 0.041288120987554716, 0.04263103098398255, 0.039386667776852846, 0.08441665330000463, 0.017561150316689766, 0.06329655917661806, 0.008133809258710713, 0.032954854034488244, 0.04795975089373608, 0.06612854874542644, 0.0852587524681322, 0.0062608813318694315, 0.04201481667076869, 0.08012433926905356, 0.03541170949897459, 0.031575420796270334, 0.016326986501113545, 0.024899791911124222, 0.048238120432342255, 0.011974839088056358, 0.04592625859884485, 0.043331093620508916, 0.035546334129908395, 0.0845471027517511, 0.06437249902275301, 0.022652756437779437, 0.027532322827966946, 0.04214519717460198, 0.021440820663326213, 0.042466069271247235, 0.08596262639208187, 0.016265866091294635, 0.06104334520416395, 0.07892168081936338, 0.056214221873350685, 0.025641947248650175, 0.023161502021755424, 0.040494369628328475, 0.053909270152930296, 0.01516766373008009, 0.018293921077143283, 0.019585141206100103, 0.05225217217699655, 0.027219931324643475, 0.07761531704736334, 0.036304374300544305, 0.03867419451595314, 0.05293722715108626, 0.06001522456626258, 0.056767107528303905, 0.11434357162685164, 0.023373237232707685, 0.09337782123756987, 0.06333682858835786, 0.020922219358204354, 0.046048461114086454, 0.07179458865955954, 0.0004668393176548454, 0.07979765639550264, 0.021044264825421478, 0.008142845265777602, 0.015646623815560055, 0.03802167912644725, 0.015011326252152363, 0.034127340111280643, 0.008067898884145244, 0.013609732005504832, 0.055471166382513704, 0.03227797321855061, 0.07628758708315511, 0.013091544387862088, 0.03053253189840865, 0.04656516443637591, 0.11322536670993413, 0.25020799329203947, 0.11932352617863687, 0.17364171874378959, 0.1409445039086765, 0.07956612164214735, 0.13732430945721366, 0.11677821437197348, 0.06833199381587968, 0.07126376633682559, 0.11270798156939207, 0.10919569826294338, 0.06437007052403304, 0.14071066323066914, 0.13049713305888638, 0.09244402900578515, 0.10939144138847628, 0.13517592312587848, 0.12421417786108872, 0.11057828012253008, 0.12400193320166682, 0.15819159456558768, 0.15946618101048857, 0.15484578216508513, 0.15197263069210515, 0.10263811586604965, 0.1238820557632754, 0.18013621380011882, 0.13196477366070594, 0.11721714444818998, 0.09211451926779363, 0.11124869132594717, 0.1450147750156541, 0.10085649412846374, 0.19838162427467687, 0.10428302921354772, 0.1792227458809653, 0.15590577206063658, 0.11083591549146561, 0.2098738777661516, 0.08104721474791728, 0.12345251792501058, 0.1253364200613672, 0.16078550699016741, 0.15167108316334987, 0.1632128412564916, 0.05004683486937035, 0.11512419989993496, 0.08342444686399353, 0.1801987418964986, 0.12216421084538584, 0.15384255938472288, 0.09554517590591023, 0.19076321694639423, 0.10952415846047864, 0.10845667622502773, 0.16823771920415664, 0.10640637213063818, 0.21389108962349354, 0.18168476860850089, 0.09291391669502182, 0.11438537704487962, 0.22813857833464302, 0.18892885005522161, 0.06290043809361036, 0.14977339144435622, 0.14766706334006402, 0.112413665910642, 0.17232683607407157, 0.17326164720279558, 0.09685780627713089, 0.09603529597722715, 0.18091054483046456, 0.32674517182092516, 0.16538249418860482, 0.10874757513163552, 0.07065563808165251, 0.25186620592590303, 0.2381968224841741, 0.14733482632906209, 0.10493099404078339, 0.17222727528743206, 0.33294297634593906, 0.1538362774637438, 0.12176633542103153, 0.09134940427517699, 0.15052929039924376, 0.1949109395425166, 0.09575992567284454, 0.1075644902284107, 0.09582720351435485, 0.16793791835586871, 0.12524108808006973, 0.1721085469809271, 0.09527976474454326, 0.16368821413526613, 0.09455176671185801, 0.2593929891384417, 0.132595018874253, 0.12735752088408317, 0.29886082776131173, 0.17761602967737183, 0.13612568829088442, 0.17492606514884582, 0.10622360653454259, 0.2031080496888007, 0.10389058535257656, 0.13890136273637896, 0.1770533534187463, 0.12496835311814664, 0.1169119120365189, 0.1204625303826986, 0.134107981237673, 0.2169232196625202, 0.05119352676575223, 0.23140277172769272, 0.21553099275596682, 0.13567008048055634, 0.11015472543095389, 0.12492695372671851, 0.1489185445731686, 0.2407899534990711, 0.13784285905140062, 0.21300431220762192, 0.15842776415088486, 0.17208006383190233, 0.1797470717781013, 0.1771258866234172, 0.08090592515204223, 0.19935564378336554, 0.08326857095404018, 0.09335637077569, 0.08314303978676758, 0.27815610651047, 0.18518093342502273, 0.1655657577418512, 0.13987844659676477, 0.19523239003554468, 0.07593170859880986, 0.21442067088379016, 0.15706086411110817, 0.2223828525072144, 0.0539477852233235, 0.1566901235210319, 0.11828179981920028, 0.1998425845897967, 0.07509082751048189, 0.2027909812186995, 0.20341580252974265, 0.10901721509834451, 0.1428637380201009, 0.1322344978970866, 0.3085703486877103, 0.17657592742433473, 0.282675841402623, 0.21413173316226852, 0.11288785901401313, 0.0955955691695694, 0.11630248143187455, 0.1574281726272837, 0.11412079325847088, 0.10565539146022451, 0.08321230945688102, 0.09860218848071753, 0.07332222160672949, 0.10998430151131847, 0.05288067454051587, 0.08082269735994839, 0.11609256567974245, 0.10584590220523458, 0.17790179579488694, 0.1074767578393221, 0.16467453701601875, 0.11769212662212311, 0.06741679453801724, 0.19232003018260005], [0.0296379097421924, 0.04245861140530437, 0.026222063498871944, 0.014796027774742294, 0.03406341007399944, 0.04183263713193517, 0.006456538751315807, 0.015335399638711205, 0.05204746965318919, 0.022245274270854654, 0.09076050482690336, 0.04362042204687192, 0.01728681231578512, 0.019338799888388287, 0.046269803067609194, 0.03391090878135255, 0.07847464553290799, 0.02312863684980379, 0.016264399032919638, 0.03762906672613275, 0.052464995232801286, 0.06122953904372069, 0.04147651732989377, 0.018309392222774126, 0.04708750999622768, 0.055394772094704454, 0.03627109544111356, 0.030208480536877632, 0.036387303318347664, 0.05311933774200659, 0.00876789448797823, 0.023717913596380143, 0.06570025196959896, 0.07722494162378774, 0.041583390425770514, 0.03229201177976305, 0.03846034873276949, 0.024557559367930217, 0.009309224664203582, 0.02105797971448591, 0.03806477540262765, 0.028824038998854738, 0.037974966915264245, 0.02175186768234257, 0.03862362505207139, 0.05708209606969068, 0.06261645313051921, 0.07382838355918085, 0.012106911688592407, 0.022455852689041246, 0.007564401960060482, 0.08174471482033692, 0.04831694321887148, 0.023647875923122612, 0.004028296670801337, 0.09364557662798513, 0.04239961114381591, 0.03674318563313254, 0.07131563815017862, 0.03763603429580408, 0.022206033332153194, 0.037648713050950924, 0.024167128402980107, 0.041370559709086534, 0.022727183794843096, 0.09260129919576068, 0.023360947267182415, 0.0433341694635249, 0.03762857642986121, 0.02036645129743603, 0.06169543158443225, 0.03728706975497546, 0.038070946240857724, 0.05379388965065441, 0.003333206902513461, 0.007269867487447037, 0.0078406585324105, 0.028887771768495444, 0.050796593629544785, 0.03555064337448247, 0.0023454263000824162, 0.03029927536244354, 0.0313869746582162, 0.03608345752581954, 0.09734259437649481, 0.04249269848749523, 0.06451822426770965, 0.010465703333818145, 0.009214290091016842, 0.04917189351192886, 0.019153768587256634, 0.04661424385924493, 0.009577537383583766, 0.05833113348231681, 0.02268141578702677, 0.06589926629056854, 0.04980982641779608, 0.061474622062016884, 0.05302410152169967, 0.03787693830447332, 0.02555595196392988, 0.11167868115608731, 0.04013901591421135, 0.038401969002499696, 0.03159171548641978, 0.03829014314819248, 0.03496129959521275, 0.01676135643896076, 0.04320661199369258, 0.014517968501745453, 0.02102491152923434, 0.09784645806517332, 0.06226581085713641, 0.0961860161154501, 0.017533006161571513, 0.08554491695136794, 0.036730863108870485, 0.09055897007666289, 0.05304157215681288, 0.049173847036135775, 0.020384598005142425, 0.08046320294060054, 0.009748147079540838, 0.0459018548680169, 0.06117042003860397, 0.0389459565462124, 0.07377576864054126, 0.034576976266238964, 0.03641808473114525, 0.022240472814789223, 0.06727781086679428, 0.019570200576356823, 0.027358449597452438, 0.009471417926702528, 0.04161986387184551, 0.09374718286938245, 0.03234691347085661, 0.010997493800166394, 0.027226883572556322, 0.03785902716880364, 0.08081043229228066, 0.00534125693863438, 0.09965490820186754, 0.039926920641934684, 0.045103939820922194, 0.06942875593179657, 0.024883457001358755, 0.06942045919957661, 0.05753909049916172, 0.057618100977232384, 0.03698276814013239, 0.03662851759262624, 0.06067979434925703, 0.07664755647701603, 0.04700668005933685, 0.04215555468333825, 0.03474464226934699, 0.03976273267800289, 0.028182413549192493, 0.035988987393436894, 0.010476660306355166, 0.015461469940360517, 0.05624674230573639, 0.034282128176381516, 0.026608723396014784, 0.07132639402463552, 0.019450644894893614, 0.023601318844744278, 0.03647444198929495, 0.03201839773194685, 0.027455807881309625, 0.061098656752297, 0.01861610892979849, 0.04976933867099786, 0.0075938939511205165, 0.020814894270452283, 0.0414180341777542, 0.031899050809443, 0.021001158973142024, 0.030657170573249463, 0.04467481183969686, 0.07178029345889246, 0.13559249109558522, 0.037088235464668086, 0.028692698969896284, 0.03322055630926644, 0.04144439909366831, 0.03828698303550482, 0.021574830508700783, 0.03862250273326232, 0.060003844330147396, 0.02087561248411094, 0.02444106612294432, 0.0509091702500178, 0.050986568113007856, 0.07187557181403523, 0.04728313820857195, 0.05703537619762844, 0.03162941850361324, 0.03094507790651293, 0.01038132928266761, 0.0323266351235009, 0.027559871349724072, 0.0878225882808047, 0.03891286537832311, 0.041213055862294096, 0.021497587778515393, 0.030301542982699412, 0.08478831319559006, 0.037527257471435496, 0.012180084576680055, 0.03938021731653041, 0.018440519662333593, 0.038326352293933594, 0.020697866679139195, 0.036054679432943944, 0.08273463065345442, 0.05428100665730815, 0.02198422598021646, 0.07393547499011602, 0.018065232340426698, 0.05652271398913957, 0.01848980401372237, 0.058897938954854206, 0.0004943356197468201, 0.02692402028779109, 0.03375602112482152, 0.06958625594814939, 0.03353078744464344, 0.029649864544250795, 0.027547286440347953, 0.04249171406451253, 0.09794418024079454, 0.010396605075877762, 0.03743790097594742, 0.00630944173016976, 0.01546083696021308, 0.04394253137551489, 0.02493537669520705, 0.03122106299645478, 0.020000981392278787, 0.011295606382191183, 0.0402512937603939, 0.03859962734784331, 0.03942515220372908, 0.037068815135787574, 0.057271415547978495, 0.0721096116749029, 0.03294805883459988, 0.06313220267334292, 0.02749322361553148, 0.027246346036272667, 0.008903227750241997, 0.03309474551990148, 0.048706418489136045, 0.05105867613888076, 0.03325301162417858, 0.047778712825909744, 0.07041194551293889, 0.07455817423760891, 0.06956443010318665, 0.026533212024538268, 0.04436688662897195, 0.039273895803959145, 0.020202259503064618, 0.029788616473876664, 0.058723546699771, 0.017533500288282673, 0.030408155608681903, 0.019377201960812655, 0.023807561205279444, 0.025558932045955333, 0.07946352714732771, 0.1007814634771597, 0.06627661055855213, 0.023247623710983226, 0.023694532592931104, 0.04138192079300362, 0.02138320510576089, 0.036493069417173826, 0.057598159708563364, 0.01720750114820417, 0.023419572145587975, 0.02437556560541834, 0.02177656061136194, 0.044470450225015806, 0.059892110406391086, 0.08541425299500266, 0.07680702533933424, 0.030149491766708034, 0.042040970912503625, 0.03626078772809237, 0.016042796609502648, 0.04437612181889915, 0.0947226656060065, 0.050982814282178886, 0.04757304886175741, 0.018453474209133177, 0.048405299969618364, 0.03409970348941223, 0.02723184973752547, 0.04356540927302934, 0.020589990008081642, 0.03500924903839346, 0.03896543433168723, 0.020448169896319028, 0.024850580338088256, 0.04524242553499438, 0.026227244168459892, 0.02538239857512376, 0.028572660653040777, 0.03966460447578181, 0.03131854768481947, 0.028149617325154044, 0.03779551847988079, 0.03464904598771565, 0.013957734148378574, 0.025697040461724805, 0.09491862323615821, 0.05083030532865275, 0.0366418436920691, 0.058937143504379265, 0.05201918568702475, 0.04065471566132, 0.0798256415873766, 0.0455053584019263, 0.015297471583189984, 0.0571944581855449, 0.03899822672528606, 0.02013993441998478, 0.043021843077674995, 0.05502769340490622, 0.03626156147689589, 0.06755700394991906, 0.03417726223086638, 0.006315073434023127, 0.04805045187353127, 0.03875759467782994, 0.00713435898257059, 0.02986232945395093, 0.04395349409371134, 0.07407068184787229, 0.07735634102456032, 0.01317697564034813, 0.041245151115881826, 0.004361337595318835, 0.06201076869582457, 0.03531831955056518, 0.012818815171598427, 0.017428544327436436, 0.04757893241701588, 0.04632562406421189, 0.15230047035842173, 0.13800727684170971, 0.09163793597009876, 0.12284524002743345, 0.0973117899810595, 0.1923423080194381, 0.19582868223228764, 0.1875232166099933, 0.17963493182774515, 0.11200054533659451, 0.17205666750669482, 0.10617350438429464, 0.07873497753133697, 0.15375888726163298, 0.09566791851313845, 0.0924831071508027, 0.14946456608032027, 0.17569327156149572, 0.09780682067597106, 0.14420537248013482, 0.14888122076949767, 0.11331336722979624, 0.10529493177009207, 0.16910672338018495, 0.13566307843692843, 0.17697829212392532, 0.13086845587578513, 0.15254328958690166, 0.1919125939809507, 0.16882552314669858, 0.11086816779307782, 0.1313241709384226, 0.2018862773453997, 0.13963496853266993, 0.10920389540373318, 0.18097933952606496, 0.15257272268495253, 0.1252765579509639, 0.12080690988730039, 0.1095727054522403, 0.13057299108514864, 0.12639029657528286, 0.1772345025693217, 0.12420897612408285, 0.09997319475176836, 0.17472161160361382, 0.11450106398232522, 0.18590312451124194, 0.0901069398969412, 0.1717367185459983, 0.13116054987955478, 0.25406441861583345, 0.21405483325642927, 0.1251612463966012, 0.12691339673174004, 0.20515594060622877, 0.12658605502257425, 0.1585748683541052, 0.13647284869465137, 0.09028966718864057, 0.13979947825352992, 0.16041753963837702, 0.17272342447071307, 0.11170021588763884, 0.06587894197793738, 0.1614230606825121, 0.1443626503309896, 0.1306990125486928, 0.1627066869649195, 0.07682344260355158, 0.11088256258517505, 0.29325009173443245, 0.1430576501954948, 0.19765774779502424, 0.20297309564005947, 0.07674311828469077, 0.11760002753186612, 0.24170264000854186, 0.17287593725467884, 0.11208590285311784, 0.17519445639223824, 0.15825229937270766, 0.20800155887921012, 0.1835335226308915, 0.12570506157053093, 0.27962632116771513, 0.13064504931530646, 0.14838933103507565, 0.124554849500137, 0.19531809995251317, 0.13516127552476623, 0.1592047305236901, 0.09746122309156964, 0.13640480476521677, 0.070426999140651, 0.12381899906622788, 0.3289266837941062, 0.29146201187564486, 0.1421632578656558, 0.06558560691173039, 0.10251041666995134, 0.23609360469685448, 0.07005172331006297, 0.09187648808884044, 0.14104135274406404, 0.09981632292751344, 0.14120849780738354, 0.09137751970199809, 0.17653989064837658, 0.14449608752564078, 0.20171490347673818, 0.20231810578655815, 0.29416826343344105, 0.22451204067516714, 0.15829107874343473, 0.20010732925466954, 0.10547488582350555, 0.14203601066143284, 0.2342154328981715, 0.1675872186258916, 0.1311157184142259, 0.18950192978785885, 0.10190817197003674, 0.1586190256620607, 0.1621625193905446, 0.1547191018659261, 0.08754785382939924, 0.17204863890524835, 0.12183131499876901, 0.09564622290312283, 0.11434992249574392, 0.12938393069611442, 0.14836752817275065, 0.21704979270936983, 0.13305189839053538, 0.14833640968126638, 0.1096953025027629, 0.1433414091626483, 0.11803675127486069, 0.11027228162293473, 0.19870788579986942, 0.25255547055313665, 0.11899318906568712, 0.196011976429051, 0.09226640385966148, 0.1469234984007574, 0.1446955768211234, 0.20374548080707752, 0.14549377915118972, 0.09198413876396033, 0.13913324222930018, 0.09417214716273932, 0.11457736633958356, 0.14119306879658855, 0.13705126039924162, 0.09964782188856795, 0.13037737819456285, 0.0925558242165754, 0.31845420058215823, 0.13571955443870637, 0.07984173709466573, 0.12126623322406124, 0.1514688512730983, 0.14090209328118833, 0.15012096553560228, 0.19776222686613762, 0.2673510185653164, 0.08933502970443619, 0.21005323427098416, 0.1386903974437906, 0.1285525414371683, 0.15913621161974248, 0.16444596702293043, 0.11604750438803628, 0.1595151187070916, 0.2147045830685285], [0.024569598439660285, 0.044295732382564776, 0.05572281094388135, 0.0651394143219917, 0.02085667670584254, 0.015128775191823802, 0.0735528830198511, 0.009987243120708774, 0.07305146315165105, 0.01692819315189075, 0.05772114363348773, 0.04649388761590085, 0.028585389203902696, 0.031927399893081, 0.05468183152017094, 0.03572303230964369, 0.039484072025985494, 0.020869481865496888, 0.027182101902942506, 0.054721426774537375, 0.044210060769992496, 0.007171605698644154, 0.0475091188244762, 0.04484708586166944, 0.04033080219561535, 0.03330766050625713, 0.011198678065181501, 0.08137243439353282, 0.04471138870764164, 0.028021452730641733, 0.058669246387698, 0.035819888805910464, 0.082373604058258, 0.05374831124959935, 0.06637686082432348, 0.01182418215208717, 0.038955038518554745, 0.014254703344176374, 0.09424400621003683, 0.11392626055185834, 0.048878738476384076, 0.008714435915012033, 0.017250043925859274, 0.034577309514486024, 0.036529853128858154, 0.021464939026402372, 0.015375381767479403, 0.08100545529516474, 0.025205922560886513, 0.06106774510455228, 0.07117791086315148, 0.050424581333514185, 0.02641265085267444, 0.04842027698853805, 0.041153025212547475, 0.035466668646662466, 0.04629024229342899, 0.02820696283672606, 0.00907946627722272, 0.03098858787017244, 0.009446903113125554, 0.04626313810266795, 0.05310149172381048, 0.06749540281992766, 0.014659203513855896, 0.07107773720617257, 0.07335801323455188, 0.028215747949997746, 0.03569223557508761, 0.04291306625330641, 0.008709490817460802, 0.022860439043612252, 0.032593712526103186, 0.05098038578345891, 0.05033575726913349, 0.04264621101620217, 0.029973507963962136, 0.0164765460161312, 0.013816422527475704, 0.054599871603591796, 0.05242569875272532, 0.01729048379216223, 0.057497798360043, 0.043367597710100875, 0.09608283173292877, 0.04234911828872658, 0.03714298776861641, 0.0756119434992152, 0.011080991638253533, 0.030330200416726932, 0.013801510626029585, 0.026189776723303144, 0.035602948027512724, 0.0817644186017494, 0.1258520048952872, 0.002930288225592625, 0.03230737184264487, 0.08898810678792578, 0.029831693597858953, 0.01313091173107105, 0.03826596924374181, 0.02707465998678198, 0.031618107215411244, 0.034916847343406374, 0.061462196115885055, 0.045381405375777714, 0.03796048402305573, 0.07058139650091048, 0.056752578670819925, 0.04246798449105794, 0.01152097029731639, 0.04173322956288054, 0.04935258300974966, 0.014870511630790369, 0.028713842996606426, 0.002965177545481692, 0.049463635115253354, 0.0350869839800702, 0.07353378444789879, 0.04959043415804064, 0.08504997052612805, 0.03279405217918177, 0.03818533082883205, 0.021538307266910712, 0.03892997978255153, 0.042803699541236126, 0.03763924420420681, 0.04164856535592868, 0.02368463665216921, 0.021068680047568296, 0.03157748923366589, 0.06232566913710006, 0.05314449223900034, 0.0491435865631267, 0.04874976374389184, 0.05044960559556081, 0.028138524372010466, 0.03845899275714352, 0.06775283900600287, 0.031347952054573164, 0.04104448587543542, 0.00310045718159076, 0.043755207556269826, 0.0418746110893065, 0.03617463731056741, 0.04667328242512961, 0.05648698364835113, 0.022846254925694198, 0.041959903488356265, 0.032322758718604044, 0.0033544296926383173, 0.02062095719720087, 0.023864131052828124, 0.016700343281451254, 0.010886855382141809, 0.021212650951178327, 0.029934918199996316, 0.010325467108838983, 0.05067931322921669, 0.026082759985940594, 0.03879230995211871, 0.03598356349093299, 0.042025300584012465, 0.029873537320283153, 0.03240619335443743, 0.06617329594108366, 0.021766699144556638, 0.05497831520774672, 0.040586016726710146, 0.01763116692252938, 0.01774785935037559, 0.04740983382948945, 0.05530798965464196, 0.11197885738745814, 0.06017347151834158, 0.027689786455143365, 0.03243104524670109, 0.1410246673490732, 0.05700510040286088, 0.027689434054698196, 0.051062357191356926, 0.009882257473955472, 0.020364710362628102, 0.023643482408876863, 0.04108819119151562, 0.023408812440691457, 0.02332761095115735, 0.028287091803166176, 0.026056544457171715, 0.062356760815506986, 0.03448511466323849, 0.03392536486048372, 0.013807647947912977, 0.022763241638219165, 0.01679008665134109, 0.01684927843481062, 0.03485504703055467, 0.022976696716561433, 0.03552430910208533, 0.02410939793222614, 0.025414422965578498, 0.047860653590290785, 0.01067020571715529, 0.029810109070592353, 0.016963996271032, 0.07428831210540188, 0.027145178380211996, 0.022602763455060702, 0.022902428322742065, 0.017629757320748705, 0.044143522203329115, 0.028409889951768904, 0.07185997426389687, 0.01847995212301612, 0.04691023342010956, 0.05552007726603939, 0.0790253631590355, 0.012935308416584327, 0.07516178257402874, 0.010872312160509249, 0.01551328142428951, 0.018832936710227403, 0.016976688432717518, 0.025341364990679488, 0.05099657322129896, 0.023342461565569527, 0.01925842385859259, 0.04540456421372872, 0.07790958674083795, 0.010337049400644198, 0.0681345193316379, 0.04004640354504509, 0.03586406143562448, 0.023751056475204327, 0.017652194120831067, 0.02077048223826193, 0.014305255571079832, 0.06405154648687571, 0.062041653530491944, 0.016550720564179843, 0.060790218262662815, 0.04029701771815458, 0.04050976799560651, 0.018475920585314595, 0.0330746510336476, 0.08604544049669659, 0.012821860371097442, 0.029171572870484767, 0.036912717060336185, 0.05289952030345317, 0.02235772831725978, 0.041933025293532884, 0.01396927526295786, 0.0199112112093116, 0.010478307395392369, 0.03905393280870011, 0.03776900034638182, 0.04240677789634755, 0.024406820077509172, 0.036211152891478235, 0.032942956689024167, 0.01891003388370718, 0.020616444939326857, 0.036664519894627795, 0.013667051661609402, 0.00946097136024506, 0.017433160007180228, 0.017389521723793402, 0.07603195120370196, 0.01470710411893144, 0.01541375798443633, 0.03419442643080989, 0.04034519698771258, 0.06341026194633977, 0.047015949723220644, 0.0516281207843173, 0.01107901321618908, 0.023261235178177877, 0.03245679346183616, 0.07826846828984638, 0.03376945064613416, 0.04318734871283655, 0.05109279003414897, 0.0603414056522231, 0.06404386262499517, 0.04821293529183154, 0.01730610624015812, 0.033806042835837415, 0.04508367296488536, 0.10284618534628423, 0.012523673095500037, 0.05851502905810072, 0.12961780201763878, 0.03389327343733561, 0.057024248770528266, 0.05615451298053226, 0.04844071621435785, 0.013685974990949036, 0.0317577152482925, 0.08859108172116742, 0.015768003743892957, 0.06658384245970557, 0.11377144950411974, 0.018464770175576694, 0.14621019393445986, 0.06043997052456103, 0.023018934974266637, 0.05013468217164759, 0.022248198811505592, 0.1267589151018089, 0.025666109661781983, 0.018105436634692936, 0.046112230272903565, 0.013052748737766618, 0.03219080007364673, 0.04864914575591684, 0.03364467407546697, 0.0939642309000896, 0.005023255277680414, 0.0794487263286306, 0.04874611333493264, 0.056797417797028064, 0.06584938630581864, 0.015667605048586285, 0.03702515195454321, 0.018680824207202084, 0.05708160960385877, 0.020427663637805852, 0.03463972269767716, 0.08623596656346515, 0.09011353591396924, 0.01646114190319373, 0.03237194539378247, 0.04584511073546545, 0.1318625009228145, 0.0552788591613212, 0.06826656990714612, 0.007372947969293643, 0.008873967021974105, 0.10426267425739959, 0.04229649570920775, 0.053822200429896196, 0.011494520154120702, 0.012724307692429472, 0.04908657429980175, 0.0816509839628012, 0.08092657122160159, 0.031190699101575924, 0.032430792437686075, 0.03458781641036753, 0.03127996366651308, 0.03390546189621091, 0.11017730204208244, 0.18700557099955697, 0.12377812061458827, 0.18446358401448498, 0.1727914377566307, 0.10645648194176537, 0.13316360933165397, 0.06848488198292833, 0.3208129546575008, 0.13737530026945377, 0.13253203112511866, 0.11671881957520401, 0.15343215076192734, 0.26255227445114043, 0.140272660120841, 0.10863843058506328, 0.18611641871112009, 0.0939022007608606, 0.15772754446633402, 0.1208512050910823, 0.16973332201521243, 0.08919238413293516, 0.19334297206613327, 0.13172180121464114, 0.08765859183885398, 0.0885785332009677, 0.08662006772694089, 0.14990626173394342, 0.12609202024196425, 0.18314113239607505, 0.11736270115380326, 0.12054796450801435, 0.10297167820916062, 0.1656943685825794, 0.1850048404547476, 0.13103402279798063, 0.21206338769726216, 0.06917992291311104, 0.21176625283495074, 0.15481648696286066, 0.16500501202479487, 0.1608020238458149, 0.1479522165872397, 0.12704857294597935, 0.09094985111826852, 0.14154432010987114, 0.14241565319318927, 0.1341203305750124, 0.10291635133926907, 0.09239946567122975, 0.13441581068740738, 0.26454456270702426, 0.12163321232242931, 0.16128165617344842, 0.1852020621299744, 0.20733564461190856, 0.13502292004564118, 0.10947242454295197, 0.148121215583336, 0.094878388298375, 0.14780636876821518, 0.14390806907848006, 0.1893615365148552, 0.1753571734673554, 0.14571690992001565, 0.20450254421560995, 0.13383055015677406, 0.13512779748247516, 0.14387062270074122, 0.22435191297723403, 0.14025761415400814, 0.11578282867107662, 0.1793509123906974, 0.1395658980454168, 0.10738334107783534, 0.11282613530995385, 0.13064094308403232, 0.10401940303704432, 0.1914922568586565, 0.15072583791709718, 0.10529379795996413, 0.12664763316992791, 0.14095176642219867, 0.1422512047593632, 0.20303517940544313, 0.09083579594810164, 0.147376976486656, 0.20129067462778863, 0.14492606203402245, 0.07721079964070551, 0.138429130818094, 0.10804891060557097, 0.2692491392935476, 0.19492118979894346, 0.16730436364248877, 0.1250629343332783, 0.12004131225929146, 0.20030291150173835, 0.09818601887673141, 0.20556939825896295, 0.1126430709395678, 0.20162317210868483, 0.0967030871599432, 0.08919682744289599, 0.08507794039624353, 0.2089755783878988, 0.15693655868451442, 0.12178603920244402, 0.2090851289610709, 0.12632681086899775, 0.22234120796765053, 0.10700803460373033, 0.1894854742192453, 0.14374028050130414, 0.18032891555659233, 0.15347624678284894, 0.19570667506946673, 0.11306614299575168, 0.18098677057893048, 0.19002516784014242, 0.13287977375570806, 0.11780775227253476, 0.15169901472906913, 0.15041123625011216, 0.09780010974575436, 0.12953797565592876, 0.18652869658845087, 0.12777264094761304, 0.24444705806672576, 0.10200422407398302, 0.07951983460976232, 0.21416427657729198, 0.12250109801008818, 0.25247063397640185, 0.17413036026541265, 0.09155770358178886, 0.10239092227552207, 0.15680479156153818, 0.12620394568770163, 0.16584910302152558, 0.15425050120440223, 0.16320203941675926, 0.10614126740444092, 0.15978847420023334, 0.1784598295606913, 0.11661210352735174, 0.18038189819743558, 0.1893519604158017, 0.12397554913355459, 0.16393625808338966, 0.0835063569848576, 0.054751024581491954, 0.09582978523065967, 0.18125054997301873, 0.14036886544237215, 0.18903729746178274, 0.1276087134535755, 0.09129689660884681, 0.14243714962034457, 0.11538604109157478, 0.12976571827405883, 0.08104179850629262, 0.10880283305361386, 0.16080835173206945, 0.11189489415095699, 0.14937171622389747, 0.08313731710997321, 0.1284739408161371, 0.13568719488478478, 0.1353542224293755, 0.1350288495661751, 0.17934418613872222, 0.15150879509747028, 0.1642120957014061, 0.14047604114297899, 0.11688938905154506], [0.024533485054909706, 0.00973450975687874, 0.043149890843778856, 0.026977521953203028, 0.020533130962341543, 0.021402242390679258, 0.08407505469456797, 0.05898540321316931, 0.05172168693294929, 0.02892433906034116, 0.08157295024683399, 0.06243167272318275, 0.031065903378710635, 0.03678648109217325, 0.025711538675691814, 0.02595477925253011, 0.06159791242211096, 0.020882482377571926, 0.032582791942742564, 0.07641577657552497, 0.022152056692228205, 0.02612973075179804, 0.01757500884724, 0.05343210845885258, 0.052137350918905395, 0.012964154499763203, 0.04991557719486375, 0.058059432739091504, 0.06865128394096129, 0.07165101612167013, 0.023655044590874065, 0.012650405105593945, 0.0529312746479146, 0.0315909493984955, 0.038688068368261865, 0.07809478849653276, 0.07826713529685814, 0.024438645285103592, 0.0023830591723503127, 0.020829080303590146, 0.026719626114373247, 0.0379157176752004, 0.039097833477201006, 0.04506668113472481, 0.017583849501886198, 0.01802317219816389, 0.05106335693609811, 0.04727913539916758, 0.04185458172052618, 0.018280817143198465, 0.043386910786671985, 0.04788944700492486, 0.029615689361948642, 0.04860572389236862, 0.07909022782358431, 0.04648968945407579, 0.061864890233283086, 0.06483606648661437, 0.021918803986702717, 0.029100968292163267, 0.03373208087718776, 0.017617913601439328, 0.07090118458314289, 0.02674374639266922, 0.02195656063005088, 0.012635625354314764, 0.028781026992346012, 0.03526535606192004, 0.02664102166290245, 0.03911463378538047, 0.036102406710626624, 0.031366058542663534, 0.03481476995793562, 0.030959350124542272, 0.034966125949135715, 0.042945613498769464, 0.01537034856981688, 0.01799796982067487, 0.056827448443659855, 0.010446727335933718, 0.0466474729229606, 0.013021888800956791, 0.05179889327395828, 0.039607235981572064, 0.010392978607166198, 0.0512795890831659, 0.02305395476850531, 0.029322750746242465, 0.07106321984000745, 0.04282148044195868, 0.048903046446221496, 0.1661457169440485, 0.04318101316570275, 0.017733734604271672, 0.0531184797235314, 0.041018369938096697, 0.027454338907714815, 0.04496406365726744, 0.022181886240779873, 0.05639385416983597, 0.07091768611703189, 0.05528231038742008, 0.021336607807766528, 0.0772505825866134, 0.05404664503951227, 0.008714547955370959, 0.04496844951063395, 0.06807829613887495, 0.05044760227563882, 0.032870833341392784, 0.04153128112516096, 0.01579758622908905, 0.056131924878084855, 0.13783155159363825, 0.051309229024956306, 0.041175425623453436, 0.024606301712112564, 0.029936438884526014, 0.05250316939406818, 0.01020864061560602, 0.05394807633673472, 0.02103168374648498, 0.018980607818511706, 0.1032920178746985, 0.011844781298761167, 0.024071329108048833, 0.037751211784780025, 0.016963163150414344, 0.005705971768381255, 0.018679081357174346, 0.03960676483749863, 0.06737246102983914, 0.01409811593006335, 0.03775070233631038, 0.05689689431399588, 0.03731869003405014, 0.09386874570120728, 0.014681400911461924, 0.038530372999488346, 0.01074340541832029, 0.019863210055196, 0.03198976519577686, 0.0021975210561762538, 0.015421247451506076, 0.06316098842709776, 0.03151678825698553, 0.028154608387980732, 0.03259141809276996, 0.02758723409515956, 0.042696918375910296, 0.016581473248680274, 0.11585720814764501, 0.036145621730435284, 0.03664081713425056, 0.042327146887058215, 0.014853472877744467, 0.0409066551665385, 0.017130457600879095, 0.041360332435297395, 0.027276328802409194, 0.007444023212883622, 0.014215097556100979, 0.06377703420096828, 0.015596087868024987, 0.025769261485566537, 0.005772674565143403, 0.022112026682964737, 0.011456175538290654, 0.02379907295107842, 0.04119586484927324, 0.04271668727479635, 0.0025279031767915456, 0.035911248621320536, 0.0405359682026169, 0.02088052502292539, 0.017929673082225265, 0.027185926596904476, 0.0554969375802865, 0.01728974643253511, 0.026320404290492018, 0.015042795228861995, 0.029660042022324862, 0.04720582078481394, 0.0007303922370004829, 0.02349291548823878, 0.03284636066265164, 0.02364301318002324, 0.01333523408374599, 0.04306677796487366, 0.036195455749909726, 0.04483846354208166, 0.03225072730152357, 0.04758134176353774, 0.03287271791768651, 0.018290598170771714, 0.11878872785957591, 0.021691544003964915, 0.033249997068196535, 0.032730091498383594, 0.014923214649541244, 0.0233589937429755, 0.026507638094405976, 0.0677267307295434, 0.0462517463752339, 0.04253694389556204, 0.010115573381734713, 0.05102275427611125, 0.021124133321967338, 0.06989747916738834, 0.06426682485447777, 0.027332946530453144, 0.008309382246807218, 0.07891716856148936, 0.031006803525792017, 0.010690423735086958, 0.014599569314610095, 0.0019971386697556406, 0.01744575640787521, 0.06931476204866363, 0.04429373289308241, 0.04753029732514293, 0.02313196550183479, 0.03148841236027018, 0.0390714340873303, 0.03583793017652727, 0.023748426878404234, 0.04978745665040709, 0.014710175173897898, 0.040825568590193026, 0.08212343804658422, 0.015436370027131371, 0.09516701958472691, 0.04837747565620849, 0.04041009995665762, 0.059049884833756, 0.037205987009069616, 0.04492717269327372, 0.01442938862789062, 0.10652065712718234, 0.020065817328530456, 0.030657951982932228, 0.028628592732392495, 0.025146573729392503, 0.017819754786849502, 0.03619680023421684, 0.03757392371734304, 0.042255724509877544, 0.04001947555450663, 0.03390891312230979, 0.015170208099598606, 0.022909809579892505, 0.026485599660044237, 0.023791921520305258, 0.0433845512358652, 0.05314416665163252, 0.024847108044571457, 0.031305914894948085, 0.013759973338775098, 0.021636671041168516, 0.04816610050658065, 0.05026455322701124, 0.02882898026596635, 0.05830076192655872, 0.039421015328937964, 0.02439343460625218, 0.037578753901705626, 0.034936455363828334, 0.053632739225342396, 0.038146080314031536, 0.0253511211203952, 0.14178611278053255, 0.009639106912448282, 0.07761605249177064, 0.07189775005944314, 0.03027528723431451, 0.03491487083656173, 0.0205076374714413, 0.09148911572992803, 0.046521325054908955, 0.05225697171784217, 0.027201595010175824, 0.056283725200281035, 0.04126834825822904, 0.03323472510542601, 0.055200476875348445, 0.026457758109656074, 0.005636043741457886, 0.029031744587325284, 0.046193263223094326, 0.11545589298851068, 0.009760418850477907, 0.04848512633132839, 0.04213999543759612, 0.057500789933387315, 0.010659585823304953, 0.026965145802786274, 0.02569218537950468, 0.039080577346706585, 0.05379867386974154, 0.022358195630893595, 0.05076907958174425, 0.013004372200568118, 0.009641284517373049, 0.0466127691399907, 0.06319713628580494, 0.04336773560592725, 0.0407714598001011, 0.048412225404453856, 0.04981215149464627, 0.05619413887841567, 0.012315251214820291, 0.07485953790526237, 0.10608787107611857, 0.061442522977989536, 0.056085262462616935, 0.04485551282883652, 0.06631316061341955, 0.03297071971540009, 0.035958769055263656, 0.03723967572553985, 0.02966394524029907, 0.03280488083199148, 0.07713694110392563, 0.0491480068904498, 0.07790372616821721, 0.022863534038826343, 0.019128119963551724, 0.03966447041039506, 0.028286049923589154, 0.05256363288349202, 0.054387695892083074, 0.07117737460160448, 0.018482449569649274, 0.07081972645415414, 0.01080657224050693, 0.03607468198864691, 0.0345088480671327, 0.005986292437169582, 0.06009877411528461, 0.04045506165693364, 0.029732515855181604, 0.038025302722329096, 0.020135106150842002, 0.012091191564386171, 0.02937397521529948, 0.10420933921611118, 0.029806202022178523, 0.07051213449167629, 0.007378445128955308, 0.017456753600028255, 0.045634375269254374, 0.014620657799945725, 0.16719346475456992, 0.10005404001041766, 0.209897396665427, 0.08492649247449252, 0.09327580896957267, 0.16324573707196022, 0.14791709911679068, 0.07303450962588673, 0.1355848455381009, 0.05993629452742397, 0.18481229191585896, 0.09417063030864924, 0.12097161113014146, 0.14618115920212962, 0.15830713594632764, 0.1111831754866627, 0.16572147277334046, 0.06940964969896501, 0.14201908011830625, 0.12559665246836602, 0.12068443541084567, 0.1392617304959605, 0.08625872703569551, 0.08569326987790485, 0.16144406681339588, 0.11269457503071717, 0.1290563361779336, 0.14473067896981395, 0.17507457895384682, 0.1794125671468435, 0.14218942742914925, 0.1717155285540127, 0.13621107645092473, 0.3622701397586254, 0.16141066537989726, 0.13967266005854453, 0.16867944550129677, 0.1595758081924531, 0.15003779903054237, 0.30365276901472, 0.13517500382036934, 0.16715384268712613, 0.11064757277528126, 0.15069047529851237, 0.14514369229155202, 0.1647597872802327, 0.16973162130002054, 0.22312362888647666, 0.10837723290727985, 0.08383608888834716, 0.16244954189225552, 0.11508266261268048, 0.14635011223295044, 0.19271965228742172, 0.199555853201497, 0.16841108490142132, 0.16525789764859986, 0.1438342182025794, 0.2319043754569946, 0.1305876080427439, 0.18121359389155142, 0.09525197873552961, 0.25612278961606566, 0.1565289079782463, 0.12944131068164302, 0.0890177850341124, 0.12451014826975523, 0.09683984917618575, 0.18009417089483432, 0.17031829143243452, 0.07500836580631233, 0.07463938721846189, 0.14725811028432462, 0.1915453773953261, 0.09872860064910305, 0.10823452604874488, 0.09558286743178483, 0.17455890985025516, 0.11269914091474588, 0.07385957865945755, 0.0920978874989575, 0.11859757360070945, 0.09704182059654305, 0.20086722718852185, 0.10596499823394323, 0.146248912018153, 0.21277330605493439, 0.0744323902613213, 0.10347558020223534, 0.23635707765577302, 0.1626320700010946, 0.17750919105545168, 0.1708775969041932, 0.17393894553665193, 0.19380890674168066, 0.11358496838159139, 0.19752814103999447, 0.15205523029210108, 0.15426190059271552, 0.1410406479431737, 0.1800585171628383, 0.18891545883830518, 0.15787041986421232, 0.11335564762233727, 0.12490105995487784, 0.2276608765485787, 0.17324519163418203, 0.1739989302211231, 0.12300488508997426, 0.16199987892421985, 0.07714871587532182, 0.1465596832455166, 0.2257020969785029, 0.23662975899154143, 0.14376637345600513, 0.13478512635394452, 0.11978110283493035, 0.15247771246058328, 0.1150794450433985, 0.09656218060803029, 0.14016838023258796, 0.11605104371424645, 0.21656501227088515, 0.1738070864831248, 0.17732119307883326, 0.09839287027716638, 0.15973152322394235, 0.05776929608996838, 0.21006677870548543, 0.11798952961520803, 0.1475820122587104, 0.1921899637748157, 0.2164296445346648, 0.11794570172505996, 0.13812528502556587, 0.22661345049498544, 0.20927979190263057, 0.11190750395819066, 0.2006136674073435, 0.18066412498874052, 0.12104307181171833, 0.16035844361589802, 0.08934226923532064, 0.09202481037186039, 0.18272283306765943, 0.11969240517505716, 0.206866170610151, 0.131818849232889, 0.17112721899344077, 0.1487820736703373, 0.09596745889153212, 0.2319076543133105, 0.12631544978508066, 0.18318155119496007, 0.07969428815187947, 0.16025307588279247, 0.15578908154801016, 0.19001211370191268, 0.15833474575511872, 0.09936117476993993, 0.15493890781316066, 0.11466532855504945, 0.21599931762583796, 0.1719866164268986, 0.06372920350141584, 0.12535060800972486, 0.1616360178037036, 0.1422352701305382, 0.14120249167805718, 0.17099650907180003, 0.1729642365488314, 0.1135154765459799, 0.1367428334009263, 0.10095622345444658, 0.13708358930964626, 0.0959854236533565], [0.024841659244210012, 0.04706818542833771, 0.027373426616372123, 0.03583213089094047, 0.0198794970844662, 0.043126793292861794, 0.03963440528980667, 0.035890326760108435, 0.04958224467813008, 0.0679338196172349, 0.085148504754949, 0.03971130136520632, 0.014450851538699242, 0.041052215702591405, 0.05036717070446861, 0.01575918990232411, 0.016987245124314102, 0.037274030938504205, 0.0460350813884889, 0.10201507187899082, 0.00881375634156528, 0.03239994590741492, 0.03182125266551251, 0.048552120720306714, 0.06327930304612364, 0.05852133013127793, 0.03549890562651619, 0.02006064431982175, 0.05854837686544465, 0.026345420891659397, 0.019541388009524634, 0.06590408498361226, 0.02507712785905648, 0.028995125584544677, 0.01296612430333851, 0.06108213223577027, 0.041641965508461005, 0.025563637741030227, 0.013677938728623334, 0.06793460868779691, 0.07123782659970945, 0.025760248461137378, 0.05090640850305077, 0.06579513195902109, 0.03730407690689449, 0.025131098753322038, 0.06241113007549317, 0.003973870911830736, 0.039823464298200224, 0.09494923610961246, 0.03372347770979808, 0.030398326700613387, 0.053371859474047545, 0.09578115396922636, 0.042977509569496884, 0.01920679910859514, 0.05282826646561584, 0.04999014053253397, 0.04724683330184029, 0.001230178602253868, 0.041122086751725406, 0.08878531565348949, 0.015380645749129116, 0.07761922409577716, 0.017574183387501587, 0.02415913044505062, 0.011237557027338734, 0.07752360866194771, 0.026839796581395695, 0.01397041673396504, 0.012755620578724532, 0.024730402210186568, 0.05383917310785863, 0.0172866839960578, 0.03459009935238189, 0.0344815370326321, 0.04025055448554697, 0.04709900131509189, 0.004739646655282066, 0.03569820340001776, 0.033744043340125394, 0.061355307698249824, 0.0979501327439662, 0.05600188911381749, 0.041787767362210064, 0.018519943827883373, 0.01439519812382998, 0.044388670339098865, 0.03306706676319723, 0.08839346168022003, 0.009341746054199195, 0.05057915872443588, 0.026592444027623823, 0.054678273041762655, 0.11064122190638898, 0.06790545904227803, 0.050320669167464784, 0.0436006071827104, 0.056368213207010305, 0.00810639192951062, 0.019262671816132722, 0.029919967994153984, 0.0611639465956438, 0.050898203701381727, 0.019381377139999982, 0.04350577315856372, 0.024937594519747842, 0.006789131035592648, 0.028277136490590153, 0.0793083943426609, 0.06416769690751549, 0.04597856708231472, 0.017015385448992733, 0.048437628880023, 0.03627636612603261, 0.020870154107650443, 0.008724773313940294, 0.04612960897746586, 0.011174733029498209, 0.14114194008852207, 0.05650112563143334, 0.011270461461296486, 0.06706051002707213, 0.028998563404104886, 0.04151575635337541, 0.00946224210858946, 0.022353106891856562, 0.04683448264615671, 0.046835099346935756, 0.031080493523228555, 0.021957405241987398, 0.09162206262830766, 0.04663212818183726, 0.058724006352525566, 0.04169185698452977, 0.030841445362555887, 0.013822391310015754, 0.024763608291264505, 0.09443391174558671, 0.06472747352334761, 0.01510726918856944, 0.026705120239526998, 0.10499910691813116, 0.011605257205965539, 0.028984712534433896, 0.06565980252719696, 0.028784776992735364, 0.01695186909919064, 0.03145044504274284, 0.00911902801524247, 0.022176910499711672, 0.03718540988742344, 0.048275628097115025, 0.04763087700872172, 0.03507409072030456, 0.019618632654929836, 0.09949069725529802, 0.038833843408933574, 0.03120081720783586, 0.015519692622605833, 0.07941923960442505, 0.011870918303517806, 0.0469299640145994, 0.014867725943575704, 0.0359225522486433, 0.02652826884220685, 0.04600678976144522, 0.08318890547079426, 0.028604121968871164, 0.13419788931646656, 0.05045907827274454, 0.04985394159091577, 0.023045828490848505, 0.0853131753542731, 0.030998928141930414, 0.05691829881060028, 0.021394774948637334, 0.035070310076398235, 0.020200888205680157, 0.015577693139353107, 0.009504955340807718, 0.03838481246343544, 0.022430885883588946, 0.016750602479723674, 0.07024186633286938, 0.025576387359310063, 0.011862388872090849, 0.043444566563853336, 0.015458640203090205, 0.01762467049693148, 0.065903035443156, 0.023785731529877074, 0.04810195979512027, 0.022813330381928433, 0.06018050420548647, 0.0731275893086868, 0.06850814807318872, 0.017263833508496324, 0.02832897382998659, 0.0484564401690037, 0.025779661129138647, 0.06180918414986903, 0.01879423203307294, 0.011841902723385683, 0.04746762750249717, 0.09877967573101483, 0.1142195343310314, 0.031051897376234976, 0.06439309912703692, 0.06080883419922283, 0.03601837835665192, 0.05673822984399815, 0.02084203485038973, 0.03570796336017309, 0.04258390891576006, 0.04546026263626353, 0.04494790686294437, 0.017468966956761096, 0.03397962303772088, 0.035441004701199076, 0.021238029528889927, 0.03320475957626778, 0.05114500658706792, 0.014574278837009786, 0.02754663909605194, 0.03819558874613816, 0.013612374051233694, 0.030485746908872843, 0.03629392869169674, 0.04183336491546324, 0.07132847778378956, 0.0074324476243477445, 0.07453285503171145, 0.03005161445828215, 0.013679957370303813, 0.0718447137924452, 0.001622548966664791, 0.040138272808924805, 0.06675968262096567, 0.020077645726081346, 0.016888856452198762, 0.04186666675753171, 0.06873675637067327, 0.04005393801978038, 0.027024373975432208, 0.10491200272114047, 0.055312670451859315, 0.01961910762944289, 0.04790024884465722, 0.029945099508510004, 0.026596023573450027, 0.038394258327541814, 0.012576324403316025, 0.0072028501158309804, 0.01566321919521978, 0.028844731033689557, 0.07251443551673044, 0.06439086981117725, 0.03482375616928743, 0.03440475970086071, 0.038418807615075386, 0.047905519529576265, 0.024213859766361215, 0.04288209714896737, 0.06335902215552426, 0.055335009575731335, 0.015784848102128074, 0.05675272422752554, 0.00420820044969479, 0.02511050822513719, 0.06734324243640707, 0.0743194382577654, 0.04926227273479585, 0.09150554831590384, 0.06579893941600477, 0.020654714861584288, 0.008914953683533015, 0.058991286768427784, 0.07180801051999293, 0.05043137653340256, 0.029078698116204435, 0.06515301238264769, 0.07333820986170923, 0.009205905258685592, 0.06041732113507967, 0.014258784677592978, 0.016074891863090378, 0.06210075338341056, 0.03878690520181291, 0.04030040765721952, 0.06591562992863118, 0.009311800634848976, 0.0076056624980523225, 0.03055583437784545, 0.009008629957304127, 0.021804218300648277, 0.024703956855040406, 0.036109849254811005, 0.016977199796406973, 0.01750718516808364, 0.05308805837205822, 0.06442895204189324, 0.03258758382270894, 0.02480375321371661, 0.0335642846391326, 0.024069754797364437, 0.005028758183001511, 0.06889849285324735, 0.014265251417283811, 0.06645827298803676, 0.06389863150674971, 0.03929851020896628, 0.060177485819064805, 0.056247592663332346, 0.08437771305081346, 0.07176863360068492, 0.029252753292600957, 0.04748568419487246, 0.04668149871811752, 0.04306684308234723, 0.03265309966199341, 0.03548452998661707, 0.024110074004819317, 0.02277519069461813, 0.023532504996945782, 0.06429092598057563, 0.01857193630008448, 0.0820200774638403, 0.023072120628409812, 0.020666688815840793, 0.015433602534504908, 0.08934738670265482, 0.037282297027207194, 0.013882454518499154, 0.015129931026979562, 0.06599011665750897, 0.06196088488063505, 0.023423092319600047, 0.01734926188815265, 0.061792866477081855, 0.038038513908583316, 0.0023433992793152653, 0.07200018367579869, 0.053780693786158684, 0.0487796450033784, 0.06184897475665616, 0.02089912755294673, 0.06793204995412981, 0.04393887713611607, 0.05627193127668673, 0.04380465470134251, 0.050689471555092645, 0.07732775828410542, 0.16499037974544112, 0.14137870722240017, 0.11499044094835559, 0.07623940781359712, 0.1366294064228573, 0.09036614574612149, 0.08346203879843797, 0.26608700413377057, 0.17437906304915107, 0.12642531445430172, 0.13752180692409316, 0.12048965755609736, 0.06898892953270866, 0.11073797881122559, 0.10918820592304392, 0.11481061712988924, 0.13538324183994724, 0.27939364494335267, 0.2243926075677718, 0.16344565537668046, 0.10264217613204833, 0.11021988120891395, 0.1507813792916075, 0.17701068232136388, 0.13864840050378155, 0.11331143668822705, 0.1579264362132357, 0.14731515319116656, 0.2179903035322505, 0.16772560474853362, 0.09605806411033678, 0.1545419516943155, 0.11914566354525667, 0.16527182512706326, 0.13061730161068902, 0.17304418548460931, 0.1268110473850562, 0.14769453525302872, 0.187823798867964, 0.1113836760182054, 0.18982106669535562, 0.10296942591066323, 0.1351674808369529, 0.1997873190069391, 0.1277816731242403, 0.14773806436888634, 0.14763761492025468, 0.14583059736797888, 0.1838772356389992, 0.11869666707371512, 0.13958270601447553, 0.08511338728449999, 0.13314958992263964, 0.18931216980901458, 0.10803905105398548, 0.19155322213567075, 0.14639042377952607, 0.16275133456914656, 0.2774137979553592, 0.06891141675652997, 0.13674148508617956, 0.08268078233325675, 0.17646392536980493, 0.12156886093678976, 0.1745175564241025, 0.16453657990261433, 0.1390231247510641, 0.10307197444020741, 0.17245655008141073, 0.16854934844999545, 0.11548911822178673, 0.1464166852735704, 0.13686286405690257, 0.16019347424228347, 0.14668973433154245, 0.10049781942319486, 0.18133354793873527, 0.09524380457737754, 0.19657541877560078, 0.15896097666794257, 0.13674307854906206, 0.20058872358452892, 0.2783122965164723, 0.14851915229472423, 0.21628016545887918, 0.06469571917888618, 0.15040215044733019, 0.1797208868928494, 0.19857028108691016, 0.11239549430507807, 0.1913385336557704, 0.15074820768448616, 0.17003008915532022, 0.20839347413951353, 0.15537222246489218, 0.14244045912017747, 0.22748205630529314, 0.1878648918242224, 0.1044532462894436, 0.09259148560945066, 0.12212376906386307, 0.1717969024133298, 0.13449560640560043, 0.11325258581388382, 0.19882226272696452, 0.21970870003344553, 0.117924090384716, 0.12120577356507703, 0.15879510331057733, 0.18109143351114568, 0.16117834155597996, 0.09743129969724725, 0.12458186176034713, 0.12843702303906604, 0.0828784866438758, 0.07561393532781832, 0.1301936703103204, 0.08903644693594787, 0.22493110609150704, 0.12994653034594753, 0.20006026081260175, 0.16716354136024753, 0.11122013156813, 0.18579398762554894, 0.1235049413216691, 0.18746991221222187, 0.0797952891838166, 0.1350873173965562, 0.1499295201633246, 0.1065773859379753, 0.22772274580934357, 0.15837755474832751, 0.18726616346788022, 0.13027562639645993, 0.08467612727995842, 0.09049016772018326, 0.1611856347130191, 0.26220376573262677, 0.15352262574578487, 0.16914222389459613, 0.13651777209053118, 0.19561590897219797, 0.13957334442004082, 0.10252481912292781, 0.2004758635115239, 0.06274903996757443, 0.15719816238889772, 0.11798918487564211, 0.10414907107910804, 0.11893903431031974, 0.14614792630797432, 0.13585856875344632, 0.1268060371700314, 0.22978703100835124, 0.1354655809700489, 0.28602505523350935, 0.13487652064331118, 0.09153933279336461, 0.13237116798277826, 0.17104504840268245, 0.10520490877810987, 0.14804802354305022, 0.1533382896694445, 0.10218393297926073, 0.13130239871961455, 0.16376424070087173, 0.15395523559662605, 0.12551667288907115, 0.17898888988119943, 0.1729796808813849, 0.203269571666756, 0.13323318543693713, 0.18477450845943344, 0.10833217927645292, 0.10343447958509769], [0.04176012690990202, 0.010766960706772103, 0.060213181685896656, 0.025529768993897785, 0.037433595561812964, 0.03401046573755241, 0.00663823230312236, 0.05109785770576808, 0.019475282282538472, 0.03652760466080039, 0.12255254081420361, 0.022251923914037408, 0.04323191204739194, 0.06598846956847176, 0.02246099122379336, 0.02914800609071409, 0.028112772326435775, 0.022698620206586296, 0.06386236873485389, 0.03451696093825083, 0.07709616224371618, 0.060595088007469336, 0.011786689809072885, 0.01731705746703571, 0.061737386389605464, 0.019763532440148054, 0.05894310749886979, 0.07373397088339252, 0.04080067456309353, 0.029341447122034528, 0.020769455680443395, 0.052732482492443056, 0.07138257891300225, 0.02327683464353604, 0.02185844966480809, 0.04366572082583462, 0.023339613633711013, 0.076498253601453, 0.04060006294880183, 0.06349305689875638, 0.019177911848190333, 0.052991741967778054, 0.02130697744207517, 0.017084681932183526, 0.021260889592550455, 0.040990695011832064, 0.04009432234470883, 0.029687603950620662, 0.014885484819270432, 0.040197912753830035, 0.03362097514552936, 0.021474189538088058, 0.03337255964476255, 0.08032896901450812, 0.02166588963460057, 0.04671763125506621, 0.03671097929679579, 0.03989907334588709, 0.05771311503204127, 0.04136627344715019, 0.027267775430734602, 0.018522941146887118, 0.05252501056078942, 0.028032524616367398, 0.06880846220038592, 0.03533755601834386, 0.01604304558807804, 0.0037605690510733236, 0.009299265521187938, 0.040348609909415245, 0.024816970145630262, 0.03759015329001892, 0.06858390650802082, 0.021368155308488398, 0.05110099483581801, 0.01598551334257448, 0.0629619243104131, 0.029768399413554903, 0.029182604536594405, 0.028432803641584133, 0.090097562980748, 0.02111834935813902, 0.03140967001297301, 0.020968186548880993, 0.05547632215424411, 0.048747737441332116, 0.03441679111171154, 0.029608126158916184, 0.020714008151703787, 0.022957050391743263, 0.03382995627039383, 0.005660914785919652, 0.030379818016362768, 0.019305344828734958, 0.04948128195058915, 0.047529615506890326, 0.04341098126925288, 0.02421818433269378, 0.02961977644102468, 0.023527337733896512, 0.051989779402051246, 0.0272629605681305, 0.019770883053781527, 0.025625143110031084, 0.022152608275533687, 0.058460736406906966, 0.05413172676438286, 0.0323320398738067, 0.007915683438055097, 0.08543694451931985, 0.012629569429273327, 0.03639111843621058, 0.058496658269676476, 0.04327167584110172, 0.01769956133718933, 0.01935440318418607, 0.03298246767371893, 0.01823385403822026, 0.0298506370370066, 0.05546057904740015, 0.04764271306715185, 0.04874912406047506, 0.03396429361835603, 0.024168821457292766, 0.04713716398503992, 0.07152317902974545, 0.028413624630399772, 0.02551789846151106, 0.10748235028116934, 0.08590610442502845, 0.08182343801543598, 0.07653728578119509, 0.007376500223237541, 0.010098168821704966, 0.0496067863047844, 0.05421994561930338, 0.07710478839374359, 0.024969994293285475, 0.03748785756948975, 0.05970402816010099, 0.04927986594397695, 0.02328063443964047, 0.04900218971494225, 0.11126605087831137, 0.05056094498403611, 0.0600405705852374, 0.05871081048802984, 0.0306406403110633, 0.03163780908160393, 0.01364881206574219, 0.0055269135590342265, 0.05190146478614019, 0.02783043828282145, 0.06160395302539391, 0.053429580368702455, 0.0665689726930953, 0.0357254684692429, 0.04153211999143805, 0.07045447871449494, 0.04867980076420692, 0.04455635166396538, 0.04967159734317853, 0.05334572821495034, 0.06992375598319116, 0.041535349052038886, 0.022087636358675458, 0.040970566051621596, 0.043867278558712815, 0.08325265930785287, 0.011807903741306115, 0.05766294010344052, 0.0014443002967914989, 0.025382978886726405, 0.03723928502069847, 0.02805432747869242, 0.02680289029564348, 0.037851653572532444, 0.031084366097685792, 0.0414074391817614, 0.05659657252591945, 0.08434771304769863, 0.025212057009940187, 0.050481903862448475, 0.027117878837030263, 0.04956892240912684, 0.0433287110870644, 0.017445149283195217, 0.03378128287412467, 0.031801635068991495, 0.017991785575906118, 0.021105163069742344, 0.05926940732845857, 0.009678534585081283, 0.013751167158085494, 0.09046070397861543, 0.04439904700003324, 0.05030164337386528, 0.008717568257012436, 0.024067423974854812, 0.011480292943756909, 0.025128737287295443, 0.06352811308217145, 0.024277335896547285, 0.02901506876843351, 0.0547104602259013, 0.012462581413978291, 0.003643490706435255, 0.07937200262301392, 0.05560219806108264, 0.04682311007092076, 0.05495116505171022, 0.017628769067326383, 0.05902251251222146, 0.02484430224754878, 0.05244279400475564, 0.042654798861833355, 0.022209662673694473, 0.03368619604096298, 0.06866528036733789, 0.0350378547614861, 0.09178050493280734, 0.0412799927946781, 0.030020049720581983, 0.0028041544822870845, 0.031773831822999546, 0.10970096389252333, 0.018403848948618098, 0.04138575506306464, 0.02441632722864949, 0.06338424176999158, 0.012978670908318413, 0.017605661940310272, 0.02127084682034629, 0.08772239930206731, 0.024047894478445093, 0.05876516825669716, 0.04302368551913289, 0.027686725933885867, 0.009707284907269622, 0.02832512232294727, 0.02163807681250957, 0.012094109401767774, 0.05625629159171255, 0.024780649917140126, 0.04045475139132431, 0.0608009358327235, 0.011086115808857065, 0.048172118127225876, 0.04751328634278429, 0.03434554876519307, 0.02107986301604298, 0.11425384740915992, 0.03615610947411868, 0.027811443132738915, 0.025922766353394237, 0.04461529829929914, 0.08294109134904801, 0.032017861470399846, 0.01484803269587217, 0.07742705860085065, 0.015300050426665095, 0.02367226433219208, 0.023695869416358973, 0.04589302187424995, 0.039027560231906754, 0.048219063995225776, 0.021965744109043193, 0.02225198520107135, 0.07161753041849983, 0.0604012179669113, 0.015614159882158763, 0.07552954308207958, 0.07476307211383697, 0.03404660593538034, 0.012404058042222695, 0.013629868626594545, 0.014854209279761681, 0.027356932743362365, 0.032511798574799494, 0.024885174953528953, 0.06900861033148344, 0.03791741072951305, 0.03657980589196086, 0.047462674744066694, 0.028713260769783974, 0.056024224407249884, 0.038155503195500186, 0.03870245549947985, 0.05429291166365147, 0.029666657191551024, 0.021361735491682927, 0.0331152958284703, 0.05066108799749806, 0.03584093707163007, 0.024733702133920406, 0.05867181661268396, 0.07751229354330609, 0.0866965079800256, 0.025984175961404562, 0.04801611964320464, 0.07563442051891359, 0.02509843659467034, 0.05096346290121156, 0.04824224581581451, 0.026752445321049423, 0.028163527566639167, 0.0261028774548322, 0.045058361419867125, 0.04850190748730975, 0.024958788342173063, 0.031393231681337765, 0.027181379865073872, 0.03436596883881477, 0.007235568294662141, 0.02357636736105046, 0.04679352375528505, 0.006635776991325041, 0.02993014164178843, 0.08390365018238945, 0.053263726163535356, 0.0483202412273855, 0.039187109533457026, 0.0242423678132435, 0.02129793760456866, 0.05825355558866455, 0.05141021856557458, 0.038462478457198995, 0.011899204184902052, 0.03095658454713562, 0.08653276434708988, 0.02704010942139693, 0.029073684070740017, 0.055888473627067385, 0.08626393643358062, 0.023525190772488717, 0.02550140650372111, 0.050900026990641514, 0.05716524725299209, 0.0424713782605625, 0.04046525445676619, 0.023721935557982615, 0.0471893115900457, 0.0316068782816611, 0.03452398596451648, 0.08642881387664426, 0.05234266248261256, 0.039995378258848385, 0.01630061392432019, 0.03436155617237091, 0.02952601302475218, 0.01140836973659574, 0.04253243929856727, 0.1484396630117009, 0.12276033450278545, 0.11325011901076763, 0.08500301699724891, 0.17022145791880547, 0.0825568905941421, 0.1678510746287723, 0.15339763084005925, 0.12524370810077076, 0.0776594283900434, 0.13205322617244336, 0.10035911920450388, 0.13301149491340886, 0.1521426102807445, 0.1627507676640826, 0.15186776857702963, 0.16799922071156964, 0.1265603451118354, 0.16497220813987717, 0.11332119664838237, 0.16708835749135864, 0.1150826855953182, 0.12558601150709775, 0.14069679703923965, 0.15891905633672593, 0.14953336077592067, 0.13542595890260514, 0.1542298781174806, 0.21383432250830436, 0.11988266311105221, 0.08232160967083708, 0.22684082539091188, 0.1021337618810996, 0.16554407745359406, 0.18198893615795722, 0.11000228159490133, 0.15198150199026833, 0.1300833689709825, 0.20009007695461475, 0.13475092818900464, 0.06597335465372571, 0.16407030814838025, 0.3014620639864476, 0.11147361474051593, 0.19681074566418127, 0.12763630794060807, 0.10474511812771521, 0.15730323900859203, 0.07949280702779371, 0.16940335262446635, 0.10992101498789365, 0.07908944641390155, 0.06825021392996274, 0.1581042605422197, 0.04720697374713998, 0.17453120811091316, 0.1904735437804653, 0.15039045994560565, 0.11723714700389294, 0.09923375902637359, 0.21225786677772002, 0.11127198805972455, 0.10557606305566528, 0.17783244951598107, 0.15812944951317004, 0.1387800450526899, 0.12874665279542247, 0.17199550304682026, 0.09172491759302155, 0.17773866503229066, 0.09418946074982805, 0.09410610272278709, 0.15878754968364395, 0.0942617564672424, 0.14931968353208036, 0.1833939720546046, 0.2401430382122917, 0.12011864883524757, 0.09171924854238188, 0.1652991744659601, 0.19571269652055157, 0.12696756680886592, 0.09961669573620444, 0.15247058784288747, 0.18766601539907918, 0.07428592191107812, 0.14641536760234064, 0.17913004924212733, 0.11991450938606456, 0.12091590121628777, 0.1337440741518813, 0.08830773644149305, 0.14886805937895853, 0.10212101417803958, 0.16638763218877778, 0.13432784847194149, 0.16784154449499425, 0.13074673982637544, 0.10622015147800408, 0.11152912547150928, 0.15674949533516364, 0.12765622622663939, 0.14061513206651136, 0.130489043170406, 0.09920972684818892, 0.1952216035175708, 0.16824522686581458, 0.18799935557669212, 0.13093274597439075, 0.20649003676108776, 0.08686422760928832, 0.14180013218954687, 0.09902481620590534, 0.15529935218153462, 0.15389109871560527, 0.09428845463140358, 0.13744262407623953, 0.13645761886671667, 0.08772720267335254, 0.16212062970284494, 0.13349495768066377, 0.18402194964789576, 0.19073784411434205, 0.19322591383130322, 0.15618845850469606, 0.25769932195544243, 0.09685289565353625, 0.11091633174087732, 0.25302545017292427, 0.20776112984505393, 0.20797578768143732, 0.09387849800048337, 0.13018083067670946, 0.09809186667083733, 0.11400134482931708, 0.12097915709619561, 0.1592977029541808, 0.13537473826398774, 0.09037685565530293, 0.1325595643251173, 0.1252169026843002, 0.07554802112281322, 0.12334731107036914, 0.29317421838641167, 0.16048811165796173, 0.2163922594439599, 0.16242056844695923, 0.12835277635003292, 0.21813946085110789, 0.07641298801548059, 0.1022735039793676, 0.20664071093403524, 0.19499067397367573, 0.11689560968549022, 0.19987468367382405, 0.1261993568210352, 0.25495174761501055, 0.22223207108195753, 0.29377985685583086, 0.08877602300696796, 0.15557794771607847, 0.09007415899466123, 0.13361627536435283, 0.1003427096011658, 0.13924525960558845, 0.13922767022684698, 0.16275557869624707, 0.15267004649485313, 0.24692067936543496, 0.18402663810599237, 0.22846496243390346, 0.10810391571853431, 0.09559255078314774, 0.13121112700431578, 0.10820308580033242, 0.1322053405906885], [0.05006497200097769, 0.03038487611188283, 0.0017927388703796053, 0.020783764287649144, 0.02126851599783667, 0.018143957450745568, 0.035708396199850306, 0.05259012803435326, 0.04697184604141982, 0.03838043044050855, 0.029807046634115042, 0.10352453322059686, 0.021782955530309872, 0.08725529251199576, 0.038294291514302456, 0.04478498677452726, 0.031412483470874934, 0.048786195055130994, 0.0596565498609937, 0.027986000096725843, 0.04519542987127939, 0.054038796468728015, 0.03325488853959307, 0.0787248881533742, 0.021193600259721283, 0.08418999086584776, 0.05224452278907261, 0.014242775355195327, 0.04136778647080064, 0.030543506107923966, 0.0638931003519364, 0.033314723836919, 0.0969677705377821, 0.029902983824872685, 0.05465927023080088, 0.02964291421155776, 0.10196213520342305, 0.027275846167016896, 0.0655753183509073, 0.03260274853317007, 0.0347718307297797, 0.011036008870559595, 0.03132082105073477, 0.03558141712640082, 0.03169037037408881, 0.04411245350755992, 0.017272869515563213, 0.03679190499467715, 0.027133405524035616, 0.07396373597364272, 0.04736319056621963, 0.029645718093360626, 0.03600564597535037, 0.012539693909216554, 0.018934573595141693, 0.05042082367224559, 0.029526047498708772, 0.05813317253224312, 0.022697189537387703, 0.030734256255410375, 0.06675814278423786, 0.034353527570924455, 0.08093584854636462, 0.05180088510256141, 0.05608241261553861, 0.01942479708832839, 0.10337934423718723, 0.022188669949349378, 0.04802512117631493, 0.12243404999495515, 0.07304893506150092, 0.08478702616787727, 0.05593461127230718, 0.025325596985977986, 0.03429664171210701, 0.05696329498483289, 0.0572972058979494, 0.052919787159490014, 0.01800204157799242, 0.10709664799393186, 0.03791668294598499, 0.027719805610456297, 0.04016243905249623, 0.07898715069337238, 0.10154666273944801, 0.08430903326840171, 0.010022665111107693, 0.006130081394897594, 0.027666374808177355, 0.007863561209711817, 0.02975754969332728, 0.04941255620290195, 0.022703774063096895, 0.020181416165864757, 0.11570785930680653, 0.06024319701076997, 0.10710155095664725, 0.020146940294052326, 0.11265729719232168, 0.07032982088745603, 0.10236584055688112, 0.023955163365650563, 0.022321653236905416, 0.028324836955195474, 0.005224812531753654, 0.04083921644656409, 0.05455350413197472, 0.03087837846138545, 0.04783633029869488, 0.02368053425133469, 0.05544332674734535, 0.07839664246045774, 0.03442425663853365, 0.01945219430772047, 0.03953847575992827, 0.05604156097697635, 0.0741452451855425, 0.06057074939411494, 0.025473967149493196, 0.0613572190876209, 0.0824191709679942, 0.029664870291467638, 0.06131439477265362, 0.024501228922857873, 0.02010133507991991, 0.03376053338269553, 0.044812301639467485, 0.06784322205930948, 0.05536084589097769, 0.021014948555779074, 0.10646703863336195, 0.07033674632229152, 0.027676314798994895, 0.024409482233046044, 0.05076516487245118, 0.02762916400247524, 0.05993994876682278, 0.06509852054859362, 0.02401895933754502, 0.08414306031960635, 0.10639768469357684, 0.08684845385892738, 0.03216835752790494, 0.050233277687502485, 0.023592188991906664, 0.03221827198661143, 0.0776405826271061, 0.07326330178447309, 0.0482880617041261, 0.10682618831314387, 0.0547669975147132, 0.017043552586748716, 0.03915343230830566, 0.02764380777314786, 0.01929361027695479, 0.01034374692432222, 0.04543420415551913, 0.04924317799328316, 0.06554706502825984, 0.01654212888810904, 0.03455335011465415, 0.03949193591852823, 0.020856441133805824, 0.026300415141327728, 0.01997694538365449, 0.09333942491080492, 0.020214380929246545, 0.04383703340746222, 0.050396737867906216, 0.031784463208168745, 0.06906509399414062, 0.04213569002346166, 0.03275149216454837, 0.03250038769516734, 0.02719202657200156, 0.034158339859136654, 0.01982546298794689, 0.04612899227668682, 0.034417695095462185, 0.040034433421228206, 0.0403470624118082, 0.03499890302097605, 0.01567797596386123, 0.046670777317617214, 0.15095040893122075, 0.0047109054303878265, 0.02807317707206934, 0.10666563926685242, 0.0524554765903421, 0.07686789102491833, 0.017233364276527878, 0.056959123636085185, 0.020158332021486376, 0.07879309296127289, 0.023274260588110458, 0.0387719588264102, 0.06519274936328012, 0.042775346627158504, 0.08301216132578351, 0.03585568809461209, 0.010445487231106288, 0.06567644961779157, 0.08012316715452941, 0.12843745970918288, 0.05150930820814064, 0.042639867808189125, 0.07044058954042774, 0.03503749470016168, 0.07954441071037324, 0.02425754976068293, 0.05685374058122116, 0.021645601711145813, 0.05443637694923147, 0.028292247574896585, 0.045475435007603905, 0.019637750379080256, 0.07720322303113437, 0.03858515977739327, 0.01907651436575238, 0.06144395939284756, 0.010473978998620185, 0.02988707409390519, 0.019981668315707676, 0.02733764264942898, 0.02307400137426392, 0.02778824215995208, 0.03712460931931292, 0.06757604123483743, 0.0939065827837875, 0.04069418068073931, 0.06093385591802578, 0.032161604462852406, 0.048569181498380444, 0.02960095366072511, 0.02933942656513424, 0.03838237630383622, 0.03483603272827403, 0.040846321912061785, 0.0757243745629826, 0.045498747063139756, 0.02223516191025415, 0.012982215980188021, 0.03655647851466652, 0.011462568542018775, 0.07091398591235762, 0.0669164318711527, 0.1285447579838576, 0.04749296203015312, 0.09807425430945813, 0.015666919399894053, 0.053009381142234614, 0.03912044073184652, 0.06301457370300928, 0.07302374609055058, 0.026550056382773385, 0.06903817366448141, 0.039712538597204035, 0.031030259222813675, 0.03623545703087603, 0.027053531281830325, 0.048213429418542696, 0.09852646835028164, 0.03514273602875971, 0.010686814503353691, 0.0290167675684056, 0.016364653129130602, 0.049775015382516774, 0.04484787110179182, 0.02528791312098263, 0.0566523858616429, 0.040400830292773825, 0.10712061122420335, 0.029942770601220192, 0.01998817240218482, 0.007111037350935682, 0.056332601609850125, 0.06623144201453655, 0.03617692025258176, 0.02802819813481502, 0.004191129616717058, 0.007458425665860095, 0.09228108976516994, 0.055474927874221924, 0.02787406507488941, 0.005914568412868727, 0.04284798325369916, 0.053493843654230724, 0.07894753628680784, 0.02049597569801394, 0.015349457352121752, 0.016303071151337317, 0.02764438042387126, 0.020153030693050356, 0.07256441509291049, 0.035719787927284356, 0.028598190533117424, 0.026493955764078328, 0.04383587278425694, 0.09027514982247546, 0.06801298714333004, 0.039260332217259754, 0.05945513768482113, 0.013004232389521937, 0.005460657008487972, 0.016692927550344218, 0.06962726463473613, 0.04846489394924814, 0.04903421219017717, 0.05075378080589637, 0.028159015308765155, 0.04960272220834609, 0.028261335927151868, 0.04595137862188201, 0.0686447721936049, 0.02201113098811719, 0.026068964657644113, 0.16725231562891316, 0.00448462029453367, 0.04404227602325621, 0.0060491106893506745, 0.032998007767262964, 0.038104673261724176, 0.07530932344736592, 0.04471951307007863, 0.003893172646301889, 0.07436373346154729, 0.0442757451486203, 0.026904892987541618, 0.015767316179980916, 0.06331664983243232, 0.037117155283809676, 0.010019907194580282, 0.022732981165210088, 0.022924905342440453, 0.046013201917371446, 0.06304093478848377, 0.0323553059640671, 0.05615608729121666, 0.01894101256414527, 0.03589215387980785, 0.06721639359790473, 0.04946101892499193, 0.015515145890775229, 0.027406264975246404, 0.04905101632879627, 0.014402633964745028, 0.03743382921862987, 0.05355757450865162, 0.025253458316588116, 0.03018291043718496, 0.05309130275441755, 0.029083273576332197, 0.08672448551102031, 0.21587989984020112, 0.16853847000147068, 0.09545832451793457, 0.08364289683560211, 0.1281095664167116, 0.1241827452735555, 0.24226416713528096, 0.21275853587975427, 0.11819216753205947, 0.08774571135760316, 0.2521712314938345, 0.26844119232508445, 0.1743086442471512, 0.04214210600982751, 0.229426893075147, 0.1303776539862156, 0.16667451679466233, 0.22046236201159417, 0.12295721143844629, 0.20713632385576927, 0.13480193432300322, 0.2083110890441364, 0.13459403338211198, 0.11125511114275265, 0.14294544895810468, 0.13596332361621244, 0.22019974707115084, 0.20216700260437306, 0.1579814106826821, 0.2556350367564348, 0.09644617957453575, 0.2771702739259889, 0.10344322830919297, 0.1303720921878853, 0.088826822297227, 0.2404541311965835, 0.09039475913009337, 0.15761764149271673, 0.13632292528786968, 0.1629038779966293, 0.16411362275961908, 0.12930568247552843, 0.15204415266071597, 0.09603096758045497, 0.13244045297465018, 0.0756011876247583, 0.11192245033359337, 0.16551974650111892, 0.13738055563261434, 0.11193938087671997, 0.1635096850053918, 0.16168046622507035, 0.13433436021929787, 0.3250323830833358, 0.11576306360263018, 0.09665283945298965, 0.14984247725336783, 0.12134739257875951, 0.1044497222849919, 0.13154747024659189, 0.2039829374200875, 0.1425407400294658, 0.21875749462314192, 0.12140935377007532, 0.13379477385071017, 0.23834699103909157, 0.07406524262360989, 0.11401829069420216, 0.3124649558336504, 0.25054496472641347, 0.18380373716354373, 0.18840657727372265, 0.1267886239915125, 0.10229429560563258, 0.15443299866972432, 0.12413006140700272, 0.14108008614951564, 0.15098051618664496, 0.18459533581570273, 0.14116633232803116, 0.1584177130773183, 0.11550768053219204, 0.1309125672184652, 0.22563357807455525, 0.13512484038308745, 0.10970965132958467, 0.08639840018605033, 0.1367156832448898, 0.13928690414515235, 0.1722898340273288, 0.15187127725972285, 0.1291934659163798, 0.14385013750964595, 0.1665947057547108, 0.193728145752703, 0.1676910235396316, 0.1350590947174257, 0.14919317177226468, 0.20644626249709438, 0.1916874100964877, 0.10987380864999949, 0.10526171419769527, 0.18807855374630422, 0.0802013770707192, 0.14060054575243305, 0.1729791292980794, 0.11505732042414528, 0.12108748958956812, 0.08418105061977141, 0.1826900751480172, 0.2547994340139051, 0.12812888715416193, 0.0797729347381861, 0.11261710055893469, 0.1379419142200101, 0.15996277452476565, 0.15081882566934632, 0.14991753854818884, 0.2803624703759148, 0.18107390541943813, 0.1187134673818946, 0.20895659472913514, 0.23460230729993314, 0.12636361373288016, 0.20049762040857347, 0.084663525133604, 0.18301858897170714, 0.13203163781473715, 0.17431825098972167, 0.11313322165440168, 0.1685556916580085, 0.1400255507999851, 0.22656435958079754, 0.12802339684698852, 0.18175786871823574, 0.12781386413881857, 0.11120132410958891, 0.09837747190988834, 0.12649962498295692, 0.2354639110666129, 0.15617710508165822, 0.15392937246830235, 0.15241055719314084, 0.1309183128778973, 0.21712269363624437, 0.12627922148714144, 0.23382923265378322, 0.22746170901002424, 0.15088268675871436, 0.11369965174385618, 0.1764340326189995, 0.08958537191633256, 0.19528544928518035, 0.14332771151056214, 0.11341801484025295, 0.1888839113375833, 0.104228958727852, 0.17541452280936704, 0.08530712325967128, 0.10286684673760207, 0.21747259663478022, 0.11135161523857426, 0.13526169432988092, 0.1330396409837469, 0.15906951600505462, 0.08675614792493083, 0.07705719135100804, 0.14095673067194803, 0.08815720016437192, 0.13341896175857515, 0.1287872707771678, 0.09819094482208453, 0.14933670600575788, 0.13673561685267957, 0.2386116131298965], [0.07492421870870937, 0.014882472178508199, 0.015575451374564682, 0.07778764086505098, 0.032562149703622825, 0.042258551374318144, 0.038786407244662126, 0.040369604548980156, 0.07300617969444684, 0.032213177501914964, 0.006562583514624426, 0.01686053418163811, 0.031485062640821265, 0.04770633283882372, 0.05918489633909157, 0.0158604686411338, 0.03041852077829742, 0.050914038738776604, 0.03528342041517458, 0.07762353717079086, 0.04102169092924845, 0.024384890810676643, 0.01894532180871935, 0.04449971861416294, 0.05102676091595523, 0.09355321706783387, 0.03770275672356929, 0.010618501485535696, 0.07974874168153732, 0.05521740358803542, 0.0214144021212574, 0.0403427838107511, 0.07102165957011523, 0.022842414909973744, 0.057516387483525666, 0.008289598026162675, 0.041941747204550815, 0.06550584183705431, 0.004290665026694056, 0.10555150227681284, 0.03418099307905763, 0.053530861022731954, 0.04416974156253761, 0.039828677526524955, 0.07435195102927185, 0.016827441098529006, 0.03383509672036575, 0.05080329306844262, 0.04332065184210097, 0.024717503204761494, 0.04699327352066194, 0.022363470146252264, 0.01595454040779582, 0.02995801000525394, 0.0324192168491502, 0.008084925188262376, 0.08758245036005975, 0.05445645994416649, 0.11435792045367342, 0.05316708417188737, 0.08967705731911045, 0.036789947640030615, 0.018451830950535594, 0.04344032626719244, 0.05567807140910337, 0.02518502368231214, 0.05236130906268955, 0.07170091908905776, 0.028551924568150314, 0.045137314441343473, 0.03824631908848401, 0.04194255159687131, 0.062331640792469827, 0.039345781664334, 0.030401544269895366, 0.07297647846562248, 0.04131405689423123, 0.04615044656900629, 0.07262794676447108, 0.0411789266452674, 0.07518397614119515, 0.07225834764540195, 0.05049249119756203, 0.005895263954786765, 0.0817533562921228, 0.056390690226708694, 0.03245743314525293, 0.024569232632676442, 0.05662230924973565, 0.03763036907560403, 0.1037792344727824, 0.06889574259759919, 0.03332438803608379, 0.039089199666294365, 0.05492325646862869, 0.04683938943931172, 0.011124633752079982, 0.06118418663860329, 0.017800832415119778, 0.049976971481115594, 0.0324173744076923, 0.009978432151969644, 0.044153684359644695, 0.05218883202741704, 0.0595887357579364, 0.00991437187974131, 0.03300228253788045, 0.06659089046860896, 0.08548147721035827, 0.008355881868591233, 0.015343732760107566, 0.08436191631781478, 0.024386355953831828, 0.03963598726137031, 0.020850599713383183, 0.06382624002834482, 0.022126199309563926, 0.06606112534721052, 0.009789678621135894, 0.08650748344558863, 0.03619715646510163, 0.021853081303678697, 0.013518898875542707, 0.02048245041571077, 0.05682536085406619, 0.03161812636760935, 0.03497231977000352, 0.034359185130245266, 0.025758197260720116, 0.02676251363159428, 0.0319714997444422, 0.03092572461032579, 0.10277995704523019, 0.004417567012546164, 0.0006496423203873659, 0.025271269860827637, 0.028817521505838925, 0.017159308472107497, 0.0255186396515778, 0.03376036101291257, 0.029790529778467554, 0.01845932520565487, 0.006103229055541658, 0.07390206589573815, 0.04284008488719983, 0.03148685145612446, 0.007981658451289179, 0.038266145443964394, 0.045180468174118193, 0.005644459217306106, 0.023183550032216216, 0.002871057419519451, 0.06315847565870612, 0.026179735225835638, 0.05443037465034474, 0.035882244532507275, 0.019665423390125076, 0.05785044778378741, 0.04645168383215224, 0.012382158461297232, 0.01815289003594268, 0.06965880447457876, 0.09889477278075873, 0.06087986970200174, 0.015316854565284185, 0.020103016642913706, 0.0843381522704036, 0.010983935001516535, 0.06438000668441096, 0.03871822924984079, 0.00836588410405262, 0.05952465633350996, 0.009015731592362207, 0.03643767359936911, 0.10300571549563639, 0.030793097553654548, 0.013765538967544995, 0.020733696611357794, 0.043299274158573924, 0.12894172942446125, 0.0029787423291934598, 0.05652582813655177, 0.044018856715410955, 0.09165931748406542, 0.010845903194539491, 0.028292255235775828, 0.0688101782373363, 0.01968073365729182, 0.06842190955555247, 0.06771095697918246, 0.05995625494829109, 0.05286647893127896, 0.012978018775972868, 0.025974768401694395, 0.054867152019494006, 0.029767830593271122, 0.017910042079165578, 0.03165038441488099, 0.03131377878749082, 0.025018238680317037, 0.009464395773266594, 0.027310584423943397, 0.03763034992340592, 0.03478773471508776, 0.04441015527493531, 0.05101784748295623, 0.0261377593532445, 0.00927435138428043, 0.014061651102477505, 0.024196758768671466, 0.09019044348068776, 0.06714243546969469, 0.0570478979047508, 0.036764593960176555, 0.09483987705842142, 0.04204742137282606, 0.02743777417157206, 0.05505393574675245, 0.04277711245982398, 0.03533640305601782, 0.1062824191044896, 0.03644402063782177, 0.028421289340082197, 0.01802224906221513, 0.051013051772550236, 0.030391171439400608, 0.020954293544374166, 0.034183915704488754, 0.04989723704995648, 0.04464496122372728, 0.04556453103319772, 0.04656385442602538, 0.03788590536362702, 0.0929440699157215, 0.099405822374167, 0.04164102705075376, 0.009964688534608052, 0.07096534444680137, 0.02526712340993747, 0.017467852298831268, 0.0352395580510699, 0.060046572884124134, 0.021753955271936232, 0.04781227513787247, 0.03721251407818448, 0.06173427990307251, 0.0047921131443863195, 0.034499831212263916, 0.021557758239308195, 0.012984303569781684, 0.024992613039249857, 0.17786850161369772, 0.11104308098794953, 0.08780629359065525, 0.08697498860138078, 0.042815447499554966, 0.04409048593633118, 0.012264191454666997, 0.028541651329085715, 0.04726310883979163, 0.07946161192751701, 0.023179102891815767, 0.06843310976100546, 0.07132049514761857, 0.04669000995495627, 0.018483267368508444, 0.029207642205179702, 0.059297472959564584, 0.06951985144687277, 0.045859149296677885, 0.02190739693751018, 0.08314592793824212, 0.010531329298241725, 0.11509210847678686, 0.05186876049265266, 0.05920849184715941, 0.03827573303433676, 0.0006044572576009218, 0.039110692263010054, 0.022954131596751755, 0.061853521488486767, 0.01909871942423765, 0.020163296271235715, 0.022442275695803187, 0.08617146196024073, 0.0035748303156240935, 0.009014258788327777, 0.06416680824552333, 0.014610175801921758, 0.016328543574819644, 0.03084136683854365, 0.03814548276545059, 0.029753242363973014, 0.047374616767610275, 0.020440568388890357, 0.064237552634891, 0.012155795759040744, 0.0632150627432331, 0.023569909239848776, 0.009714642224172431, 0.023825340190782182, 0.039185680779478246, 0.056158040815423575, 0.08481139542474862, 0.04352032499868543, 0.015497635036045987, 0.07333804898324513, 0.025340897677045678, 0.08712660506247513, 0.03946087488363828, 0.022390287054041703, 0.013584806377278462, 0.012552268284883712, 0.03117200655622348, 0.02860913409911577, 0.02265926626991601, 0.06566921774778636, 0.02285150454319533, 0.01637354357949188, 0.08918991732981899, 0.03882004233497766, 0.05287980120028219, 0.030395078487814437, 0.052803977647976535, 0.039354978549864986, 0.032943979416403084, 0.032801241914351145, 0.05345404155612473, 0.039552161920695536, 0.028390802871135455, 0.05287926876917482, 0.04731581951942175, 0.07086207579460836, 0.06782916434589895, 0.05140655666529652, 0.041080557125350164, 0.02848878934709055, 0.043281581357962666, 0.07365175432735875, 0.030753735956105015, 0.07821118023486869, 0.07796476039314464, 0.035514939846771384, 0.026669386068298936, 0.056947276086336186, 0.04711305519806282, 0.05559947844895144, 0.021424916678018147, 0.02980742010197813, 0.01810427601148765, 0.13202875732414185, 0.027136889308871284, 0.1501243363224691, 0.12852629526488243, 0.10734075425012458, 0.23241754711395313, 0.21150121705666666, 0.20533925012475063, 0.17487585574628847, 0.12977402266715804, 0.15510137974014207, 0.18420987101572175, 0.1720241853787053, 0.11208735842017398, 0.2396723997568892, 0.11818112054419135, 0.14217464193221063, 0.09468517326299222, 0.09160587519046762, 0.1582768601515601, 0.167229057199532, 0.15256026609530374, 0.132414007619504, 0.13338911497304518, 0.1649643021124986, 0.13833479475109808, 0.14534298240417434, 0.15531819794447194, 0.1136372462215443, 0.11448723609529196, 0.12041768359561121, 0.15966628317631062, 0.1462426147754154, 0.125723363411042, 0.22000031906270215, 0.11963698637461471, 0.2201421832245204, 0.25560745759116066, 0.19757841172958576, 0.1857046924170948, 0.2566241328754733, 0.1912849534663462, 0.08640239916501508, 0.1702682812127375, 0.12785176250843272, 0.161552544863474, 0.1717193743153926, 0.11148233282109422, 0.12767790651489652, 0.10600184706310112, 0.08200313925983445, 0.1772140480217434, 0.08261961021250294, 0.15175723741131444, 0.12122510962428586, 0.11876690201461317, 0.1865012246754862, 0.13323392088134445, 0.12074712438568955, 0.17985528935828518, 0.2616103846699961, 0.17934021780327444, 0.21644174872386843, 0.157197319692181, 0.12351170587804049, 0.18997368673163076, 0.2840619089622652, 0.10072933885479167, 0.09635239509084532, 0.16259725896581528, 0.10248335078358652, 0.16802571203199126, 0.13819674570714274, 0.13300392596471694, 0.09322811233540697, 0.12027028827897965, 0.1610887705558731, 0.2017288309552016, 0.17671304184102243, 0.18163553979848662, 0.27268875149949906, 0.191348523442303, 0.12905078970136183, 0.09658159327603157, 0.14910117993431707, 0.18461827248815568, 0.22680022273092504, 0.12435006653709758, 0.17757620842706773, 0.13825331363947163, 0.11221256783051838, 0.13990525967411457, 0.21302020087117152, 0.12351760475505745, 0.14470286997816256, 0.22254137142050653, 0.1579535863692722, 0.16630803565344504, 0.15068601666679307, 0.1492219919999761, 0.11840307153761388, 0.1341945338513582, 0.12887393064316244, 0.08749422767469961, 0.08658249111425492, 0.1626228922677617, 0.2583869011892427, 0.15447513350555975, 0.08421661242121652, 0.13662788956876726, 0.15693652804099745, 0.09024624532509236, 0.1569509458157324, 0.16548476692649627, 0.15273220686902925, 0.15734338201582432, 0.09974043425773421, 0.10971755735696324, 0.07303080942121244, 0.1385830685255989, 0.12392292655403576, 0.2257463002517339, 0.12869907873532466, 0.16093733029500132, 0.0974045862113276, 0.14956490827664254, 0.13631134203845455, 0.12444701496391528, 0.19032116889232592, 0.16070059380464016, 0.274846974399782, 0.07755768425281971, 0.1275290326485711, 0.1961626199584815, 0.24416406518749653, 0.1375035587097368, 0.09811808986048545, 0.16763796428999594, 0.07143867953169732, 0.1148612785243219, 0.20913903090742328, 0.10378208431986072, 0.1508625080027888, 0.15007573570455277, 0.07936892294955832, 0.2090961299836636, 0.07141701456519865, 0.1700176478874299, 0.12130059226746522, 0.18992050490792722, 0.18236816500223454, 0.0795743111220579, 0.11177159229954405, 0.08229753918825619, 0.14287830901242074, 0.12894491635022626, 0.1598584639929956, 0.16577491506693826, 0.24962826391621945, 0.17825764363571522, 0.21211085450505057, 0.13164013624191284, 0.14089066324935806, 0.11775165931471895, 0.2089664159763244, 0.10376945152998933, 0.17834413496236648, 0.22695606033648216, 0.2002868849423624, 0.13836818086283822, 0.1662009672051476, 0.15192720167819532, 0.1000940987479783, 0.11004076219133793, 0.10249196927273467, 0.15802466400688694, 0.17701192338380123, 0.19792797764943493], [0.017031559480294105, 0.04137063248743934, 0.03729812057328321, 0.005999066474502005, 0.07821632834571986, 0.02633051856631233, 0.05987436781006475, 0.007309394751510193, 0.016938175277544126, 0.010928737408962223, 0.05408162461413492, 0.09240794626455154, 0.016052959723428132, 0.012666384742084532, 0.011526082976601057, 0.08699674549843035, 0.023452399013143395, 0.08671295588775989, 0.027878096612590938, 0.02318421461349053, 0.04467446710013094, 0.04671450178589552, 0.026360514738987532, 0.15524345840657913, 0.024227890666694413, 0.0029241571281736177, 0.07250896564895108, 0.04482256721765284, 0.07568554156610081, 0.02868981847930099, 0.02406694133946252, 0.04803969216863475, 0.0015574438223284822, 0.03219011059451488, 0.020518628917934916, 0.03653554899257518, 0.008712705513913064, 0.06920780851355485, 0.03297380704973494, 0.047622902033429955, 0.03473190988804545, 0.03816053256272309, 0.03182136374826153, 0.0762994844286192, 0.007388167742324332, 0.02778829387088697, 0.04778831956848022, 0.033338690897630106, 0.0499207214752753, 0.03463669665037625, 0.02332895543546446, 0.01600788981323281, 0.03769008945974131, 0.04215222220086763, 0.06622247878582248, 0.007452754221195656, 0.03005773167035753, 0.023918940813370773, 0.023028407651450367, 0.05076359056176678, 0.05398983578948725, 0.019716521454674583, 0.04020540126328988, 0.057612995001217054, 0.05692219053725562, 0.020664894254878163, 0.03285799370778184, 0.03908153495661194, 0.03924665371737173, 0.03224967776106731, 0.07279430275722858, 0.030305951818703648, 0.06626246857546991, 0.10109519946479029, 0.03202409359566387, 0.07111037255174692, 0.03616952750411245, 0.024820287306342396, 0.022220288313204245, 0.009205200457795253, 0.03125085998626967, 0.02682050074180288, 0.01213628541482913, 0.06250644673503215, 0.016639868300708554, 0.05289799578848386, 0.05365643815528001, 0.021857762100896048, 0.042381202050995444, 0.03318572612178903, 0.107799464716546, 0.05829458342744939, 0.018024509021591757, 0.06192580188414263, 0.05451700387282237, 0.0653836737957693, 0.03409959240666321, 0.013143564630750448, 0.04062041024407072, 0.0379305912722503, 0.03474567265760514, 0.029082890532370058, 0.02521119707624518, 0.02799630780974704, 0.043244812968036825, 0.016323768931831566, 0.08357591010750302, 0.0545278899822264, 0.028388056445926912, 0.004168048345168392, 0.02284010898532166, 0.03332344957837655, 0.09440101593011811, 0.10674188799795606, 0.04608376627607692, 0.01037216974392293, 0.06527648277340398, 0.028125299779217572, 0.04681119357325858, 0.061076378915458925, 0.033776245846022526, 0.013280828434583402, 0.030072746993673426, 0.02273870001156484, 0.05052266740089944, 0.10594048342036624, 0.06493737395372122, 0.04344269347887847, 0.057821508812447714, 0.014078377674694264, 0.038498844650964585, 0.062185176272666266, 0.017250264176137505, 0.027507706507740003, 0.0756162029480742, 0.0736780004996446, 0.026537268460097335, 0.057350364739015225, 0.06980357977050929, 0.029998497752052163, 0.07042987197036706, 0.048419886283696666, 0.02575350880262352, 0.027756983857421626, 0.046956616213485125, 0.009081708042011147, 0.08197111678459952, 0.04982160885007151, 0.08952292042874521, 0.05416034397879436, 0.02604415490021629, 0.04794794930926254, 0.019799496437753403, 0.04193169230054464, 0.09014270088124661, 0.006672396951715552, 0.011425166214335591, 0.012852583369690807, 0.03130821315872093, 0.02781506481340095, 0.028343113897848996, 0.03050761871911105, 0.05147348593680128, 0.03035305281950822, 0.02702235724897154, 0.0943770680216051, 0.027778332812651515, 0.04911518002289438, 0.04149876835365449, 0.034601985206527096, 0.0598619188812952, 0.04737243341702608, 0.021594279565878456, 0.07654682357585238, 0.08735265462629258, 0.035528572381383954, 0.011740125069815305, 0.018717485344818523, 0.03697316139756191, 0.04340226701911419, 0.04085237017622398, 0.06633129391458727, 0.01609581563952229, 0.04274893957640856, 0.06448077022909157, 0.030359328994827888, 0.07778636915909667, 0.07237096257027119, 0.022862999692499157, 0.05430487795702873, 0.036622289297801834, 0.06103866823738622, 0.06641665909198985, 0.014374296372425894, 0.061556635604750734, 0.05599762200407925, 0.042394681368023164, 0.06445574213660533, 0.03464678985877864, 0.04841294552710268, 0.028421745162397146, 0.018437053114476225, 0.028416771336548755, 0.022119120657143575, 0.01305952670067669, 0.01588159830369536, 0.024273838705172943, 0.02692612511436305, 0.02799077473971392, 0.016969090755728465, 0.07874053932966725, 0.02755491667607379, 0.02515986535487877, 0.06517459307947467, 0.05698932665249994, 0.031288618544837644, 0.04876179132430304, 0.03466677709272312, 0.07469839131038997, 0.09104738943278791, 0.04647611054561792, 0.06555811201612796, 0.013947169795902747, 0.05450754268695751, 0.04524743191957955, 0.06628465448175708, 0.03626785488919385, 0.05047504354508654, 0.054665946687060984, 0.05135649664988441, 0.04213806106558731, 0.0254194887219778, 0.00623820512931073, 0.02352897141639504, 0.03925032327852903, 0.062073614718692924, 0.04117681224259638, 0.018781327281988437, 0.03661563965461908, 0.0695716543123126, 0.06358814756235769, 0.06546707012720647, 0.04887704542207141, 0.005574916149564689, 0.022692738566547636, 0.05309980249993744, 0.012924222166710084, 0.031759377659088185, 0.056016142179648724, 0.040041236281995816, 0.06806422310370593, 0.02753861624026491, 0.032665468151530916, 0.037884189326676636, 0.03988035015701767, 0.02206816623407987, 0.06400937717708369, 0.0826933385143357, 0.04635995629453852, 0.004718980475914695, 0.052292476062692946, 0.023558758830110875, 0.024625859936819445, 0.06293660510451564, 0.0504243515071369, 0.07733126696679862, 0.1198318484990347, 0.045148606577347365, 0.02928357109457495, 0.06329956224128123, 0.06186947143907028, 0.033639587251649755, 0.03720175054284834, 0.024154593289319067, 0.04458804855183248, 0.009433290688320994, 0.023989024451903762, 0.06286300703763001, 0.014421410779769142, 0.05496465969049642, 0.013855044850178305, 0.09667251259088518, 0.00620517764248014, 0.02389197260321629, 0.015824347595503975, 0.02176705729066124, 0.018021885170451096, 0.0653230762409587, 0.04400700150478271, 0.08685901055052396, 0.02493091231782831, 0.05699203477331227, 0.05576159797548767, 0.013491741058626964, 0.028364012776423368, 0.06132633042251391, 0.041789525533996286, 0.02230995507430165, 0.033149551450004505, 0.01157219572398331, 0.03928582379294019, 0.019907097317158215, 0.033891994070502064, 0.01751928361162784, 0.023611387155289133, 0.04234824877893252, 0.09341298467329434, 0.02142984453859108, 0.013490595757180165, 0.08064894861872159, 0.0639594627183772, 0.013457627163358755, 0.03079473889703232, 0.05554718528724006, 0.01322666027267734, 0.04329224913230827, 0.04386314934480094, 0.016375619677766677, 0.033430200100185416, 0.011361958214923019, 0.015408481553857847, 0.03204311172838413, 0.06359112764438314, 0.07507614926585267, 0.04310582546637424, 0.047214473747918685, 0.02296300097969511, 0.04175688635798232, 0.01699164438421928, 0.012783671845681967, 0.0870346055636483, 0.05772057672842376, 0.008718449258125358, 0.009775281913818852, 0.03505507641802392, 0.01968843475615065, 0.07599939246692004, 0.037023098838906136, 0.005815710990704717, 0.024863241856256803, 0.0749079929664731, 0.052435765148050366, 0.04145273413028448, 0.045052443390652064, 0.036916704547982064, 0.04633609265569718, 0.02993908380308459, 0.054101669304673715, 0.08937896484689367, 0.07356367719870421, 0.016436751578904448, 0.04697784450986693, 0.1628000577611308, 0.11656698860949087, 0.11326415374154046, 0.13744836973567165, 0.17943176531022598, 0.14738305922477477, 0.11538889859953236, 0.11961342917094309, 0.09887329933624114, 0.15118357545185476, 0.18907627601537014, 0.1772553708043791, 0.07745197178014825, 0.13031832813735933, 0.1600320441948791, 0.15991754469371613, 0.15856141585015482, 0.19365464727724754, 0.15682068022508777, 0.2326607647081537, 0.1447418944970254, 0.12762653265869425, 0.08882293057057167, 0.22643436978180564, 0.07951081775489353, 0.1338586196183197, 0.11085682203091922, 0.09264452187644859, 0.1289758356588502, 0.12444670086786633, 0.12172731856304793, 0.25811132404112047, 0.24555607758943113, 0.10114547015438158, 0.18445264427892624, 0.1778542523783061, 0.08205978380095574, 0.23345035620995108, 0.11073036389725824, 0.13427933978457607, 0.16112891356310538, 0.2409904080653383, 0.27853329756086875, 0.23275511609690808, 0.10918877282810789, 0.2027644898982779, 0.13608513159617303, 0.20677016447148017, 0.12448479075946155, 0.19233075541353997, 0.1723534040032856, 0.12617158613378002, 0.18600677620739708, 0.11538253240888158, 0.18784639846173026, 0.1429268789868201, 0.12425210687421984, 0.10806987843205852, 0.11901062522684375, 0.1415270065227824, 0.18172609139113657, 0.08178498806251634, 0.16891164675114617, 0.1749964533073287, 0.16922842410783615, 0.14137141406536102, 0.14354587802963872, 0.13124483487298413, 0.09884043416428952, 0.19214562260575835, 0.09229970570172995, 0.11852384529887669, 0.11998171827966168, 0.1644636942974983, 0.14158139876540632, 0.1370438293463761, 0.11765315572941497, 0.09928542399598707, 0.11989046954700064, 0.151298841040942, 0.13371886985917247, 0.21276474119194094, 0.1639721876070384, 0.10915745515376331, 0.20300311096493276, 0.15716169660370197, 0.103027158296637, 0.17418994658416317, 0.14386259409929478, 0.21403480771808855, 0.28714256301041574, 0.1567423860392263, 0.07745300599884603, 0.20761488366030878, 0.1608261096501543, 0.16532600286506838, 0.1349501723363515, 0.21099657961918464, 0.14811392242629684, 0.20963406160233483, 0.12559281436786537, 0.13899312474794928, 0.07991046284235294, 0.15566823883883416, 0.1506457357637344, 0.1487771707076219, 0.08501127542507264, 0.14879460686877852, 0.10798189323395492, 0.06903393719826015, 0.11468254255070803, 0.10696453613138969, 0.1651063501354187, 0.19740132284500908, 0.13962427394524698, 0.11914712677319204, 0.2177116620324312, 0.0903580405358826, 0.08802387022203015, 0.23523227672182748, 0.13352720998227596, 0.1579817171178518, 0.16144593606793112, 0.1045179653972868, 0.24671342193840012, 0.22306365952376397, 0.2019226205565276, 0.1456866188034896, 0.1843584614295152, 0.14502586796879768, 0.2080470338583954, 0.1929801987904695, 0.09842918284477727, 0.1574530858065813, 0.18984276230537123, 0.0901654460317185, 0.12404126415569937, 0.15119191048847092, 0.14718350864225818, 0.10850942137861445, 0.2208776735971051, 0.20467396404954696, 0.11624758357122061, 0.11860833713604559, 0.15581306010004015, 0.10211787321755003, 0.20484650237185342, 0.197828340254003, 0.08809910771707374, 0.1266252404199012, 0.11102569845294762, 0.18002693901859945, 0.16372463395518644, 0.13500218970641015, 0.24245985663465916, 0.081457692318626, 0.10056875150410399, 0.10674426287052133, 0.08863788969334095, 0.09306467513764098, 0.27343314381376393, 0.1189446650565632, 0.09707337575814418, 0.18583952389176817, 0.1347996360592304, 0.1616013906295261, 0.09183360248683922, 0.1264851612429465, 0.11048990421958509, 0.14727525533207003, 0.11363378350412655, 0.1691695885552514, 0.19746435655941888, 0.2673452575841258, 0.10191316686330304, 0.11823431768965338], [0.043211239164755236, 0.02069003151489362, 0.014086843903867469, 0.06333742230649918, 0.022403781692827904, 0.028274083630211895, 0.09047938886308864, 0.014940490889843675, 0.013766302182639559, 0.014183862236208253, 0.04286581395013679, 0.06726589819957172, 0.05871334623905921, 0.0644751931090028, 0.028136377410602667, 0.03797229709884813, 0.005278794917338078, 0.018197891955834725, 0.01891883240351754, 0.044495892004981163, 0.019689084015666478, 0.01847167837343389, 0.019976908994478085, 0.007825794511459648, 0.022574389473565167, 0.02169742564400358, 0.037679479141990026, 0.040612427607899716, 0.05554667966921003, 0.016190199587013454, 0.02720702465833916, 0.018573024144936955, 0.032849233492367694, 0.036822165467686234, 0.04623341006076625, 0.039192154222438415, 0.013346694759093227, 0.040410337443914146, 0.023527734184397325, 0.08822923541189202, 0.027319292928422653, 0.05341605508639928, 0.01562674096109526, 0.018341916485599453, 0.09038614830182445, 0.009697666673380281, 0.022969790433924046, 0.03150750327134325, 0.0031495296617879746, 0.05855309596705822, 0.04770349065262464, 0.03834968350166756, 0.04279250316622277, 0.022215559635491624, 0.08419189842477923, 0.03938178013589594, 0.03496002788925844, 0.004808040591137063, 0.02089566292030917, 0.007524546714604743, 0.038410101025815935, 0.025118766652960933, 0.03462868720112789, 0.033170661002758055, 0.06525423558008286, 0.06784596465407841, 0.030645623713010745, 0.01853006959502255, 0.02193227564285119, 0.08064964575873268, 0.03682366700001782, 0.02384466667389197, 0.07083411358537213, 0.020153994048615138, 0.02618126548646439, 0.0068392078091780995, 0.04837567918002606, 0.002527597938634215, 0.06996192248357881, 0.07745206371069917, 0.06663894716409907, 0.036414422830867196, 0.034533033462902235, 0.02770110540422461, 0.012695470227739744, 0.04528122022747994, 0.04482647809650629, 0.07539050578470192, 0.04616640418046906, 0.04691114123429983, 0.022155281922389424, 0.034394823540482795, 0.023838334957197792, 0.03628797235808546, 0.05055109692376949, 0.014755626212835554, 0.04038643167023698, 0.017232996554324226, 0.12800550869395658, 0.06073971391625463, 0.02168825557154994, 0.018039007235558766, 0.05036427489211483, 0.08631756258828026, 0.026676736681932406, 0.05611725046389526, 0.07580173412157644, 0.0621961543126212, 0.0751408530519374, 0.018723740452720274, 0.028060352760216886, 0.02128173484497013, 0.0325760158950523, 0.032786333843344645, 0.013090008381573905, 0.05678301917449121, 0.07119003803499284, 0.01211823063767365, 0.016304951897191427, 0.05238886524532592, 0.026518068381495057, 0.05998085020110012, 0.042742941107961445, 0.006441657493386659, 0.03462830415716575, 0.01338827992684298, 0.035706304779817025, 0.008742567621201517, 0.1118681193780034, 0.00699792973577015, 0.021800962426970084, 0.08230339976087694, 0.04048415001541857, 0.02810978075309146, 0.08338206688002234, 0.023765491486917582, 0.07440565379276391, 0.01096098971057443, 0.02017057985217581, 0.049653916033886136, 0.07526950219706183, 0.030248215602290247, 0.05397412715659988, 0.07166170304821384, 0.03975063998011812, 0.03303219061044436, 0.05028277462829025, 0.018048928074178197, 0.016182506149033868, 0.021568881835968747, 0.10605774849893586, 0.0684511051663468, 0.014240904185440273, 0.023072072747914542, 0.055728196541989045, 0.11828952198547703, 0.06006224704305491, 0.02365456004026196, 0.03199740883804137, 0.0824982389026592, 0.06212283586782794, 0.012554495685523557, 0.036024671768949884, 0.07346823796509735, 0.04586648075811325, 0.03218056896941797, 0.016318630397079453, 0.028363620156362176, 0.05803236302228705, 0.031075065790285027, 0.05988005984334215, 0.030341867935813727, 0.07441999495870645, 0.06714455753324494, 0.06535796388503044, 0.061637737502854686, 0.02428784662286841, 0.025501021544539162, 0.014843164207113367, 0.043839710884757584, 0.048717208837549535, 0.02959755031512149, 0.021065583137134393, 0.0023649924250710155, 0.028200579409096992, 0.007492766514675873, 0.0650971032859337, 0.018462245915866187, 0.031112868398908648, 0.021215901079197085, 0.0375217454688203, 0.09038001193755096, 0.007132612780908184, 0.034462752556728746, 0.015377634065976788, 0.04006156825550622, 0.04471218543908289, 0.05616145373712625, 0.029754722828886686, 0.08712868882162918, 0.019427848033486836, 0.0043401605310669595, 0.010228064774926151, 0.039126979292280255, 0.09894075337797405, 0.03646264423526103, 0.025455314823756778, 0.05874449537406045, 0.07648927505098044, 0.0483704429690636, 0.003697630140044156, 0.059656925244076606, 0.014257399016059937, 0.09986024274821244, 0.050876615343675505, 0.03673132659206468, 0.057250501347645644, 0.04403036335603364, 0.0338627218509153, 0.09148469540260493, 0.02830687985425034, 0.015079127906280902, 0.03720990937924193, 0.014111998400861218, 0.011147666185523474, 0.02780157017461475, 0.08184650492283606, 0.04161611770189578, 0.04518235658085154, 0.0453710402061622, 0.03924479978459497, 0.10895416606217624, 0.012522614936554625, 0.014976836973801257, 0.02880702801649609, 0.06014284715356846, 0.025769883932005015, 0.029983863557478594, 0.05118927114733285, 0.02218449477016205, 0.07524744652572178, 0.02304603341936825, 0.1284984020035594, 0.03145083383236441, 0.01620466141180406, 0.03583399248459647, 0.004029693823653244, 0.0405452570186988, 0.059111041632751306, 0.060368467708148306, 0.048964509680386514, 0.07034765541433327, 0.028227451858260942, 0.023991387833150166, 0.03363641181720361, 0.09794425684958698, 0.07771258723110923, 0.00589801037999531, 0.02061267770195921, 0.012151380219767171, 0.027171713750689264, 0.011093496108397601, 0.05256583921671395, 0.058904534971882264, 0.07498179787709829, 0.045347291480509505, 0.038674918469041586, 0.0797418622119773, 0.019037051261552883, 0.011129744516144837, 0.014331231697372371, 0.03220313025878803, 0.04744861703065615, 0.0009055522558253048, 0.056389165711739374, 0.06288216689661627, 0.035005702051304044, 0.07048867687943482, 0.02422143254549273, 0.030584137496207992, 0.08704484049831668, 0.07173589866368041, 0.04206990988384332, 0.042573685472410534, 0.029475194582295035, 0.0323276731726383, 0.046893176472475456, 0.05123217590153218, 0.028406944343700048, 0.0427210807890421, 0.012207601497310304, 0.07780193606571806, 0.0126742179911103, 0.0561202458676792, 0.03863542663654493, 0.07984158387708087, 0.019821956220473495, 0.056222637349198905, 0.03724686929114884, 0.04132980766195444, 0.029904764979296637, 0.012289136235091475, 0.047521717140390995, 0.04447182918327951, 0.03642086179987077, 0.07045421824460069, 0.06317492739688005, 0.027410363545641307, 0.05571121237270775, 0.090993249999179, 0.05356253875840095, 0.010591886633436286, 0.02021865953030365, 0.03689227783451638, 0.07940712775434218, 0.07877320531875857, 0.030541452992286895, 0.02677519430196093, 0.02608575347450472, 0.039090088328286525, 0.0314431001747688, 0.05435005799236317, 0.014424401395503553, 0.025946310150527188, 0.03277252893894911, 0.03432553854861087, 0.027526423950949987, 0.05048566535415669, 0.03697838994764513, 0.018348309489327575, 0.05291609461569498, 0.1124793119848736, 0.015302608202722286, 0.030045426383073774, 0.02159812149681872, 0.03142078594875432, 0.08537391846578929, 0.035558292762406414, 0.015104526593800516, 0.08476192912747783, 0.03525526285351765, 0.07525318452427465, 0.024689562062943177, 0.0496089505031705, 0.03549180399145811, 0.06439525183410415, 0.06400807099717279, 0.014276820302550352, 0.07937925747565686, 0.02977281591043838, 0.03465089225961316, 0.0473870771876987, 0.16312507822388606, 0.15954373975194272, 0.10843048367889659, 0.16698433807299984, 0.17478248495007717, 0.08751900295817083, 0.1612917991775659, 0.09138691193994977, 0.1652969221674627, 0.12323175436787068, 0.08191905344926542, 0.1510474263059516, 0.13984270093421783, 0.12032424385148673, 0.12248430536278795, 0.18459991702148992, 0.04190993923393469, 0.22021263267003724, 0.08569765190083174, 0.15462458193782838, 0.10471330249621984, 0.22363614170782029, 0.08896673293483835, 0.23187544797697376, 0.08240307546070508, 0.10528737048227942, 0.12031709625115318, 0.1382075628686336, 0.21568851575495737, 0.12507405792993884, 0.0682440162786553, 0.12254395296857243, 0.11134025415465718, 0.10002083775977935, 0.14035990221365807, 0.17388740314110634, 0.08765135996884878, 0.2527808995857354, 0.22019824553881923, 0.2377825527782402, 0.253392007922934, 0.10088686185378222, 0.17208476761175742, 0.1447855768304679, 0.25581627783756106, 0.14489857479929924, 0.09501606195924744, 0.14674498459264157, 0.07563071265336006, 0.11577169741353682, 0.11159317042197912, 0.10381452814345399, 0.16815645259714898, 0.18059890026286726, 0.21216276462279984, 0.2171002012947875, 0.10811738354424316, 0.06432091066193196, 0.13379938570001434, 0.12842920894223836, 0.11941950933466997, 0.1494962821203855, 0.17280384838100404, 0.10965080045524145, 0.18270714358697016, 0.08078569531320565, 0.23594735851210935, 0.11184593347171623, 0.12438785765440234, 0.15332318241557769, 0.10385974265274503, 0.0956026018567143, 0.1785779296750984, 0.17803537088536447, 0.31215864323800613, 0.1630516716789815, 0.13583276691215654, 0.1725571833911442, 0.1509968645029491, 0.20291807520533764, 0.21241292297359438, 0.08092732198776738, 0.14677037274645222, 0.17281046738066982, 0.22863376224713944, 0.11013509059745459, 0.06357218229001568, 0.21729221357212913, 0.12812095814414565, 0.13496517233790892, 0.16594775982441443, 0.11823905211302543, 0.08685434507506509, 0.1075651873684218, 0.15597691098528524, 0.17828505426164598, 0.11059628318875067, 0.12456158341299142, 0.2088357673417176, 0.1434246216329836, 0.235280157217095, 0.1063688797876239, 0.161842156742369, 0.22966064182260346, 0.14719142999139526, 0.15562247274623764, 0.1631071364446994, 0.17789379783695747, 0.15802172222925773, 0.07935340966909163, 0.2066205474998682, 0.09823950713560467, 0.12544817696776123, 0.23127477375730393, 0.09493870240065361, 0.09372041575730809, 0.186978405521762, 0.1756268670602191, 0.1450285339547742, 0.2497712159228902, 0.09585817644913351, 0.18850333417855925, 0.1367790387162278, 0.1286498499253104, 0.10231673432093474, 0.1613716408610344, 0.1267699774114355, 0.12306873851846303, 0.396310459942587, 0.12004159571182345, 0.1328236041890998, 0.17627344526831182, 0.09771848307742227, 0.1740511008087666, 0.13543738893443538, 0.1555196484250407, 0.12257930792627797, 0.07592194097777528, 0.16943966519207726, 0.1315541811768086, 0.2517818443236813, 0.12448512783814823, 0.11264540750773684, 0.12900643321054597, 0.12841816195437025, 0.21676197347621765, 0.15507838178065517, 0.166409756808031, 0.26556980285433035, 0.18719842597361536, 0.15307046533111604, 0.19144151119455216, 0.17480909884456666, 0.07878562360401116, 0.19196309449691928, 0.2338221540013629, 0.12843959709449163, 0.11700333696940254, 0.051389005590951255, 0.13039588687881348, 0.150482191313659, 0.16273541526208002, 0.14353371255340117, 0.2080234077068106, 0.08553328007579812, 0.1671636945778324, 0.18226042239656373, 0.12516463250522653, 0.07947909405394908, 0.12116632769785582, 0.22944471228026578, 0.14625364644152505, 0.17690465575264347, 0.3085545059894362, 0.1590886988466786, 0.2669502013633328], [0.03501323269559972, 0.0160378486391217, 0.09229834206522473, 0.0528248037481981, 0.0716934650535545, 0.03285522813037519, 0.0474658425176336, 0.044168523482738004, 0.01901041438442565, 0.04818867328726957, 0.058932730837935404, 0.0405728361839729, 0.03198134780470883, 0.03203571897991483, 0.031626913396100846, 0.0441632604586982, 0.03219891294476486, 0.05584148562423164, 0.041440047714258396, 0.05742815330684666, 0.09542771164448031, 0.025429365510541587, 0.009871880813021093, 0.015884197256978483, 0.030211610006048318, 0.015888979560845805, 0.0710442591638815, 0.04408199768213015, 0.05656589453499164, 0.01014572468721458, 0.03656271447037016, 0.02958594025262902, 0.026373306492103205, 0.054327278367934696, 0.06240774396686785, 0.042043897368374376, 0.005771879270117009, 0.03162729260962337, 0.015080374714377669, 0.049495753351478815, 0.0077687271855651375, 0.05804744729351613, 0.009855953845075302, 0.043689519347202395, 0.06405847575215083, 0.05964523091191246, 0.032310332772472215, 0.07372523748105572, 0.005530869924358183, 0.05016931317626469, 0.06895249439102989, 0.004639463422204098, 0.057497296572452596, 0.020533458464929176, 0.014959662240148794, 0.058122860988782304, 0.029753194483477744, 0.015680384352773188, 0.027294230361979817, 0.03689662155304705, 0.08393724313786916, 0.08264762604789389, 0.09029818608635858, 0.015117026275895057, 0.065882021651393, 0.03139226641055317, 0.02856132829742086, 0.055938246359507886, 0.019723075336866805, 0.031423915417925004, 0.020839809364969694, 0.035897558630113645, 0.054762921926956025, 0.03811941279338733, 0.008272430953389455, 0.048266756798951864, 0.08648828528220616, 0.07760237782232224, 0.055679308641101086, 0.01870968848496916, 0.021519384895180984, 0.058109270589005564, 0.028852627484969078, 0.020985500135969733, 0.020669343310498425, 0.0746665373744984, 0.022168313077981436, 0.013641871309148209, 0.1099579634084817, 0.05018854964404337, 0.03616760079298289, 0.02209567262100116, 0.06231843343665523, 0.008302049827761948, 0.04295191840238629, 0.058991210159635356, 0.005832310679609017, 0.03104543350937386, 0.09000787706745249, 0.050028107850061315, 0.03607965772971511, 0.03776616582106199, 0.08162067752451667, 0.042794659703729615, 0.025173145489046173, 0.02458337653097847, 0.030719792515399958, 0.016777582181197022, 0.049670195402277094, 0.020277112038926254, 0.05991673247227746, 0.0706559215341845, 0.04284095439699389, 0.08337463582715682, 0.009114510011709025, 0.046181499943017, 0.039050155995233406, 0.04206909783064358, 0.046219413634389646, 0.055185124473345865, 0.0226361055167452, 0.02800440727432649, 0.06688260142841647, 0.02477697844076301, 0.03857627315747161, 0.013128600060759534, 0.07794883342519884, 0.020775879327688488, 0.033731199876074834, 0.019203263612824584, 0.053231856905885284, 0.008774002123954556, 0.020579596110168966, 0.08020264111579427, 0.020588164803602045, 0.011466806923459855, 0.05345069375189562, 0.05636015013160725, 0.05892156510643902, 0.10017450733651077, 0.07158018363219115, 0.0469599410350765, 0.06317198561925082, 0.037333149943620934, 0.07935276615523523, 0.1282566859416904, 0.031997257535676324, 0.07267399630959957, 0.018774240968688842, 0.02860738741864841, 0.03571244497453013, 0.040289927574415366, 0.06850686870635518, 0.08988053793267858, 0.015491371309655088, 0.0547434632936793, 0.06872701173227641, 0.019318636454221223, 0.04378130434141044, 0.07543178260206215, 0.02075367809964284, 0.004457626707716695, 0.03597954535977014, 0.00883116664725446, 0.05646482072470169, 0.016245919076966184, 0.05027545082773413, 0.036166325256588965, 0.03953899669971678, 0.029822220920675227, 0.03880970014799987, 0.004711988008385825, 0.05186215681474536, 0.033817901876905275, 0.09982832752528692, 0.01771201984205794, 0.025742957856686368, 0.044082568417633736, 0.011181420977077177, 0.06476773144376856, 0.020891104697159702, 0.022944871508967013, 0.022331914984651154, 0.05612777268153526, 0.0359921743192019, 0.05585499941521595, 0.04929588101203403, 0.028461729206385154, 0.03876470014332764, 0.039434299293544986, 0.060291115810433706, 0.0365645990466639, 0.018752892013458956, 0.048620294884688435, 0.05516888340935112, 0.05087270063438243, 0.05452342368962784, 0.010905324804386305, 0.06888218284133943, 0.05306075499843686, 0.047303795769450166, 0.0684240622626197, 0.041862154499657696, 0.020787313189958374, 0.08078571829584338, 0.01575465657703218, 0.021919125743630915, 0.04944186672688492, 0.024804452268947518, 0.03369514011747895, 0.04846241182437347, 0.04648003291579024, 0.05129525558121743, 0.09548224944380984, 0.007186876224999827, 0.08035464828173, 0.022082436536889405, 0.01757678808644414, 0.05608739984792568, 0.04406642311462953, 0.09561959368687484, 0.027978494350287705, 0.04013316300246985, 0.04413184702336308, 0.012261629848170185, 0.07968188518838537, 0.027811628909060554, 0.050151850202030716, 0.0632405313362758, 0.027919118705716346, 0.06333751040661047, 0.035325470981338335, 0.016555234737273668, 0.029796759988511765, 0.010888550351674279, 0.0462639693080658, 0.011406939067397148, 0.03659441135823727, 0.04737679628775485, 0.0844943039720097, 0.028704341591125535, 0.0325284609871526, 0.03287922583460327, 0.0665954640135169, 0.036692899621782765, 0.09208906982694903, 0.04121585591365734, 0.0063142632960432, 0.0735981817988138, 0.022528393554591367, 0.032146478056787484, 0.04225993799346109, 0.022088526935887434, 0.03613804129042453, 0.05214370944867692, 0.022651118924841288, 0.0379088458665196, 0.020798026929579435, 0.03449610802495191, 0.07114291596677035, 0.024747685153758334, 0.022299262402098508, 0.05141056713558013, 0.0445541721438208, 0.08078508244286622, 0.019661411004621657, 0.054894436240917256, 0.0474357582448471, 0.032131872590511076, 0.03931282839227108, 0.01872310268452331, 0.03673340269033948, 0.025387577329491897, 0.014013571424349664, 0.013295741293639427, 0.07282404995132839, 0.0121719132913577, 0.023667001308152275, 0.03620308598563556, 0.022907112950399038, 0.027246537558253736, 0.11019914320880368, 0.09042316567032568, 0.04706412516233902, 0.039770305457134406, 0.03809969752065597, 0.03908829568254371, 0.0696697671927752, 0.011589295764063156, 0.012836697578970945, 0.016232556588346922, 0.06097628952815168, 0.04702407408565764, 0.010815413852763033, 0.018106742814603834, 0.08297260054537366, 0.01562971146702166, 0.024901345154390703, 0.05120632809496695, 0.1419222312829187, 0.02840480121273187, 0.061830040893607566, 0.008158177557972171, 0.022149656921805396, 0.03631357118607529, 0.030959294583167762, 0.04612215111152299, 0.03851196773710751, 0.0688719938719465, 0.017250112873772462, 0.0076624875486407795, 0.0367261057028607, 0.08616061415523292, 0.0447030958058613, 0.044323200465089856, 0.036204794361706705, 0.116272994707669, 0.02279826334767765, 0.042763299894549196, 0.03317590104416013, 0.10900233767085499, 0.07182069693601902, 0.0449988134055128, 0.024953331880932374, 0.012864473054275639, 0.04883110312925232, 0.01178060036768476, 0.03818975881703439, 0.026395343011245135, 0.02042427561396072, 0.036677079906146375, 0.010038858294607171, 0.06915641167471487, 0.014443335258552145, 0.032817111425702615, 0.05244737138010321, 0.023675368903505228, 0.04601034057897426, 0.0149886031267083, 0.006140607442977208, 0.03373388884468906, 0.02821865142323077, 0.049850413756024455, 0.032571978611691345, 0.01707473045004712, 0.034353343709822626, 0.02553474856540561, 0.03310989873904375, 0.07006040308624506, 0.07499614670392006, 0.06803630685974514, 0.022925749954376972, 0.08756180429050038, 0.13154206166584648, 0.12333123854571774, 0.21538100806215119, 0.13334701078072672, 0.1560759661538947, 0.16278827532885537, 0.16629482829763045, 0.12335521709774772, 0.19754435146047225, 0.11368441425504223, 0.09999055430413255, 0.11325054035912599, 0.1713153395441271, 0.23659906950929474, 0.23117305260271798, 0.13364535606195851, 0.14154176137620403, 0.17399080968912572, 0.10864175540665466, 0.22259285252901817, 0.08363044790683255, 0.11124358918037146, 0.10444563137547624, 0.1658844349965934, 0.1429932222010628, 0.10343753627591556, 0.1553085605583845, 0.18188845606580858, 0.12054934346627806, 0.16022840785163064, 0.12670199476903485, 0.11943462424941602, 0.11928525242593982, 0.12330825590798933, 0.17408226526552634, 0.18679149538999607, 0.1663723870390846, 0.10938853791524326, 0.12110556926458113, 0.14050096964403508, 0.10906243726851479, 0.22124292899764356, 0.14394030605833377, 0.20307539902146787, 0.1326255704606733, 0.11147896969510664, 0.15022745175707727, 0.05893141699714526, 0.23999443247673974, 0.11407770081273011, 0.133256750301488, 0.1984132943494666, 0.13545818056070036, 0.0893425143834564, 0.14311599545180798, 0.1464579008038967, 0.13213303721239492, 0.1437231967405927, 0.1583033821154987, 0.14390010176406753, 0.16688549740900918, 0.18227341524775953, 0.1309855907194076, 0.12553885113447905, 0.14057403911025296, 0.12193725729781775, 0.27636572838790957, 0.1373319396929395, 0.1975445199998156, 0.0862234486867824, 0.1469404136221255, 0.17454974743868076, 0.0732670249717851, 0.10075935417966497, 0.1106062576535248, 0.2699992006584522, 0.18412163300860315, 0.14352894748651213, 0.10887076973073906, 0.07779658111112733, 0.17844774069324618, 0.132798399896391, 0.1159459058075182, 0.10578086900134241, 0.15981062946300353, 0.08231353510411517, 0.12343159606379848, 0.19025917705749312, 0.09377673088062195, 0.1404192740277898, 0.18423021831099065, 0.11067201864094504, 0.08510656144109466, 0.16812098272625478, 0.16743875078616605, 0.08624129853541813, 0.10983158954449239, 0.21115609444677833, 0.2923387535397084, 0.12859168853009903, 0.17640728082868362, 0.2167155332262478, 0.16282982793786835, 0.10838719971117475, 0.14952712482021702, 0.16780045153873582, 0.10793755206489757, 0.13479703136028784, 0.13041840986378733, 0.16643678438999962, 0.2050323246587669, 0.11708011430117393, 0.17913888989677354, 0.12833381567390698, 0.15402403029222644, 0.15624383133986305, 0.08335248822526586, 0.07053822744637728, 0.14830478557175206, 0.15421578209967385, 0.3090227389287564, 0.14459422338874112, 0.13020611157821071, 0.09282285948434184, 0.1440576094412996, 0.12013470603814048, 0.11432472586391434, 0.16875859770563342, 0.1836667453209239, 0.15750816752833707, 0.06954108740413381, 0.1755051510108094, 0.09581325305325371, 0.10341671400613363, 0.07942878505996159, 0.22057105456629109, 0.13988259879331436, 0.12301338866593377, 0.15124584307834027, 0.23022914034945352, 0.1286864842498495, 0.18626842587705583, 0.1664143533355767, 0.2161088528772516, 0.23953119443068582, 0.15643175270768905, 0.11113638283624766, 0.13464329283564322, 0.17547502843362672, 0.19398288530928476, 0.10195837371171483, 0.21668881207944887, 0.22354658602947192, 0.0916433675334819, 0.11075947523838091, 0.1151150604709983, 0.07218445080422586, 0.1318902792709489, 0.1476387640521411, 0.08208885683768219, 0.12206836558517911, 0.1283890506132476, 0.10309850406502524, 0.16305360222055068, 0.1004578066509097, 0.15306858075482233, 0.10278944887461201, 0.2161849407298911, 0.1028232180303143, 0.13790455977282218, 0.0860092351813951, 0.15808267218451347, 0.21148770326568236, 0.14204598512620698, 0.12129018879345349], [0.03378106836950587, 0.05016382798672684, 0.021406936594435287, 0.061987441318530234, 0.03647328136608966, 0.018278823399375525, 0.03959246963683156, 0.032892126755248156, 0.030814563337292884, 0.044281130746727994, 0.055833683018722845, 0.04575418375973259, 0.004104234657490686, 0.010944659588858487, 0.08252646924266893, 0.04816149631815572, 0.04502245104841648, 0.055913053558117924, 0.022715818880486394, 0.11283836207322537, 0.06842685082266409, 0.12771050355607463, 0.05519964950039022, 0.11876124062485273, 0.06188572016394427, 0.027380646995058464, 0.05249017271243277, 0.026611349162375255, 0.07363059497889012, 0.035233456160753004, 0.022848022673579476, 0.026226878361476046, 0.04892645426274789, 0.028567275054933085, 0.028278050050439856, 0.05730967780935669, 0.03056552155964798, 0.03520281647422141, 0.07418931822382635, 0.06050013523969439, 0.05402118410734881, 0.03983393288968552, 0.011851231759083609, 0.031567397940483306, 0.02485334208505529, 0.04077968758440787, 0.046215701938396504, 0.029114296306825937, 0.041950430811172536, 0.03323794650514761, 0.03420575304077037, 0.01593092670513978, 0.06855972111225128, 0.01820435390747603, 0.023103191239398815, 0.013471175428299655, 0.05222505649491664, 0.02398063387391308, 0.05158664095365713, 0.02084842593889804, 0.008043609108896026, 0.026355778400395668, 0.016809870871985634, 0.03621537403594102, 0.06748560455537612, 0.06991980296950187, 0.03095516345403608, 0.019878849740170186, 0.059204446902919206, 0.1016324952304844, 0.09005339801191323, 0.04565545417849095, 0.03605856732915967, 0.03188635290209805, 0.07995717122309631, 0.09738437681188507, 0.02092812972654018, 0.024120737948725303, 0.015540232397465697, 0.043847693520928585, 0.026229088525137594, 0.044355839641103824, 0.05414609857384236, 0.010522685911236031, 0.04060069114089974, 0.015920894783771327, 0.027112368749634876, 0.022145202120525703, 0.052701249087770144, 0.06630834192037582, 0.02831263892022112, 0.052535839213599125, 0.051940121582799384, 0.06080050299304628, 0.02441924219320138, 0.029514475740612518, 0.017788728225916144, 0.05642091622576118, 0.030762693439159664, 0.031006192570672404, 0.030752718974385532, 0.06702124802095276, 0.04077844652197054, 0.04523227870043728, 0.06807071952930382, 0.08983785151353768, 0.025356152402837912, 0.06887526506738317, 0.012020407913012371, 0.017246604191079255, 0.03701101380190061, 0.059430917815095, 0.07308714752716404, 0.06213992345897902, 0.004839262504491114, 0.027087610703141942, 0.013542216676737995, 0.05134594378872745, 0.04691635829306418, 0.012555565335787834, 0.05595532628977972, 0.03174183807606178, 0.03248275618159002, 0.019506538669849117, 0.11258422772610381, 0.018497746430277344, 0.020474889127898122, 0.029103720463031245, 0.04105678158662012, 0.04302530962553236, 0.010672382364470151, 0.06527592352921925, 0.024337941112237114, 0.043677748406245824, 0.016510550743870197, 0.08963294597643037, 0.030531666219054215, 0.043899419777576006, 0.030273655467035792, 0.06303684387896812, 0.028158931039093484, 0.03788440000085581, 0.03970444104784439, 0.03523597659002389, 0.009048912775582604, 0.04653540192051761, 0.017609948202246622, 0.03203816088517347, 0.04542199654444572, 0.015736994419937894, 0.08306970218977622, 0.02838305580700117, 0.08907412314006398, 0.03388998308970082, 0.04043429684374602, 0.08896188359827766, 0.011276145833694648, 0.03629887378924797, 0.02911242130663126, 0.02491927927269811, 0.016870200296022722, 0.01379502186131093, 0.049934235266259605, 0.010689141495423693, 0.0221362886875267, 0.07284917763524479, 0.08422884684536727, 0.07706523527421298, 0.12124889665433478, 0.02804821409705666, 0.04273807644964226, 0.034773324601232045, 0.011052304518318946, 0.02449198224161181, 0.0358612192494254, 0.03268180114607657, 0.10816879570484163, 0.06835149075355261, 0.04519856700132932, 0.017418920347887664, 0.01729588471202841, 0.03858875272975814, 0.04330386685567998, 0.0035316978896697687, 0.04190847983643894, 0.06142440882901992, 0.044857546792275486, 0.04964939228469326, 0.022608329083830602, 0.03923430438003233, 0.06512724884575413, 0.012086121977547245, 0.052239298069429015, 0.04353981810591875, 0.02461024898014242, 0.03510163541162207, 0.062461868078718265, 0.041039613556236997, 0.04757594084367157, 0.03793196256963476, 0.06510569113156488, 0.04276536067106551, 0.059080447911495165, 0.01634599314251494, 0.03279682158702805, 0.020807327236980203, 0.07858583553423805, 0.04961502558041004, 0.026404055346164013, 0.04166010647050796, 0.029653857777556105, 0.0855494215483627, 0.021129331228533582, 0.03185579173957869, 0.044835169364007256, 0.03844531808769511, 0.009840728805190133, 0.010789010632452706, 0.016472824744039005, 0.03876399151199768, 0.02778206557606257, 0.009921497455047024, 0.03760868112646765, 0.019103679843547366, 0.008892533162819042, 0.07374243615495582, 0.006679529709095557, 0.01787073410777075, 0.0320032311062659, 0.02608588945511128, 0.021386455233779647, 0.006996530188893479, 0.024562138658497604, 0.0928217409959724, 0.0386763702056581, 0.02410948411711762, 0.017926394225909345, 0.009893180930145807, 0.03622365544640249, 0.025501082831573103, 0.028117338210464488, 0.03472624466784539, 0.020941176203890674, 0.07948113184782767, 0.019844954179960395, 0.006966608230985942, 0.023602512026686343, 0.0025341362596654725, 0.07028620750192674, 0.006431154427944773, 0.007551430655087555, 0.08044185207015084, 0.0951748566641923, 0.033639648538683696, 0.011278018918669513, 0.03320562525562221, 0.06098483906938665, 0.034968772782914104, 0.03722526178124451, 0.02120209809002136, 0.0695854515558289, 0.03210331474791371, 0.03843378463399507, 0.0566900773875175, 0.019482142599900405, 0.11984068915368089, 0.016958740907871438, 0.0213988141472181, 0.1498931922739552, 0.047356288114021865, 0.0314941254609655, 0.02227719523943961, 0.03633482246509483, 0.03855257039709437, 0.03426671065690537, 0.02463942735395845, 0.038825316850336335, 0.03738394157300073, 0.04069024681924813, 0.04943882918826515, 0.07615913712089101, 0.04798459129468088, 0.036622695324401704, 0.006179077026899905, 0.052207559046726075, 0.02118572679107949, 0.08861441675934101, 0.019219113971977946, 0.03588169294920179, 0.042544727348872734, 0.038917726206202666, 0.03979968492903056, 0.06047981475750285, 0.016895833597969145, 0.07662425974323865, 0.05945325310852739, 0.04400408654023082, 0.061681818202017784, 0.0033088421942891496, 0.05503351184269113, 0.10257969400094402, 0.06413940528047181, 0.03216837668010304, 0.07448842193210319, 0.025380828094878988, 0.03710307841820102, 0.05598565188026237, 0.07864366751164198, 0.025927676976988875, 0.01222848505412619, 0.021593431123502312, 0.016478411440226822, 0.05049074451709467, 0.010783605882146908, 0.034088032139885815, 0.035937724619983666, 0.01875817227447706, 0.07677238284339828, 0.03368570191425181, 0.05868708474501487, 0.08423149750958528, 0.03366476856172085, 0.031066882056033904, 0.05465601435712269, 0.06499396486868782, 0.02998302660642132, 0.07882301635559529, 0.053746679482320626, 0.015123927770482918, 0.03898117360809157, 0.061396948407374086, 0.005468940812974207, 0.03681054774431452, 0.021352860363080137, 0.008812031686125744, 0.07803239829597935, 0.024481998200738625, 0.038424495817913164, 0.047763582589405204, 0.055249157932496844, 0.02145927955186175, 0.053118223084076766, 0.1268315632196684, 0.04583056655622298, 0.07719849626864157, 0.03905808500524971, 0.00830222890081425, 0.04026820898176201, 0.026799025382065488, 0.028536620046643, 0.013813164738577702, 0.008937864500518528, 0.13870597967217047, 0.20613507758225166, 0.15919786637588856, 0.21650012462369858, 0.14312431516666568, 0.16935524230282153, 0.09250951420155265, 0.0834213825122964, 0.17537871585978618, 0.1852973328242379, 0.21548027773537945, 0.22635599898715175, 0.1659360846444484, 0.13712478951821405, 0.16848109001594205, 0.10146739562192272, 0.12086346249787078, 0.1990287234225581, 0.16221301990651316, 0.1534919056200212, 0.14372206293046474, 0.19048932519170547, 0.1834463111815914, 0.3119823204413537, 0.19295703229163924, 0.09306026247119711, 0.10626841501723375, 0.14673315619509067, 0.1907179105065523, 0.14382761452467213, 0.13325298114890052, 0.1328984663010605, 0.1395152136683464, 0.11821926406194126, 0.13888309920026412, 0.23176750618844266, 0.08485149246670547, 0.21535517557734446, 0.17658156583145743, 0.15917191131701394, 0.10470321311825707, 0.14217124050182683, 0.0777844922436822, 0.08818569097427592, 0.2176649153472916, 0.1594908337198919, 0.27339894564882405, 0.13151239874141832, 0.0849963213887907, 0.1690687867061746, 0.09392176664644673, 0.1386728080650491, 0.15036678782874538, 0.08551647976761864, 0.11400278507461471, 0.1530179270212689, 0.14676445854767678, 0.1730847575010792, 0.1367369498456678, 0.2457970735286513, 0.09509109261055147, 0.1518997450869891, 0.08830458782012425, 0.12741405817289508, 0.11945723916494078, 0.22256348071800125, 0.11236748613056638, 0.21924733124192686, 0.12312977274339046, 0.1550137239598459, 0.18849996339169242, 0.0853401646318455, 0.20891752424499682, 0.12573717597631678, 0.1314300136460412, 0.2109529738945346, 0.13059995738008331, 0.09397970587616006, 0.12607410910629457, 0.25631903069874934, 0.1736059424377257, 0.20594004691848833, 0.12052217798848307, 0.12435826367788738, 0.11751318380476967, 0.15084430575370789, 0.09264682780110067, 0.13470036638600213, 0.11223669960013322, 0.22605435952784556, 0.09072842872551373, 0.19873643023592813, 0.29422332983343835, 0.19043102590066774, 0.13161724553473536, 0.11898354401872044, 0.15911902060672162, 0.13278756741314166, 0.11520787202302488, 0.10385673958808185, 0.1464244534051226, 0.20733423501012788, 0.14684848307121187, 0.11604745076188158, 0.2168781124055386, 0.2571144904340467, 0.12572350896774762, 0.10610039661368055, 0.0934977752847537, 0.06538764213121707, 0.18447386491442883, 0.10273402241329033, 0.3245071838459661, 0.11828215221964544, 0.14992314631179457, 0.10854872168913003, 0.17909295526483368, 0.13760233808669353, 0.22721459968916832, 0.12306247958012166, 0.2274230215698481, 0.11616814025347272, 0.14572621022741641, 0.15428457679527421, 0.2154883982673768, 0.15294436725877947, 0.13817950872884643, 0.13268362460357527, 0.10138536292699077, 0.10967306297032103, 0.15236958681095034, 0.22287670342672258, 0.12348896072756861, 0.10708100447851805, 0.09891112109706288, 0.16849014517520705, 0.14130419751088466, 0.09423050007993176, 0.1428240240221062, 0.12559127453113758, 0.17385703541578787, 0.22241493626948328, 0.1392461635893391, 0.12210879970582263, 0.1716981996451655, 0.1308401719096207, 0.06492914616941445, 0.10009169323189605, 0.17274292906926525, 0.12158019137718987, 0.25599270788652284, 0.1825948963843046, 0.18720450871173414, 0.13999512178763268, 0.20324065950849365, 0.10457981167541397, 0.1564709917311707, 0.09652436650808781, 0.12299777579403694, 0.1688277294799205, 0.19755562827471765, 0.24703934638490602, 0.2565328918036915, 0.1135656936094165, 0.17081575828694529, 0.15086286040323396, 0.27028136616272314, 0.17807459458708766, 0.21449562492630175, 0.14915063857070862, 0.14489889655622745, 0.23469514183459744, 0.07845038352834602, 0.09434704503585255, 0.16068389308789086, 0.11155720259393416], [0.02798391442235199, 0.05248170361042984, 0.035772992733625636, 0.021743385173800974, 0.033370636764072606, 0.031049679551694184, 0.028087361189987392, 0.05046652081692892, 0.06928868441572113, 0.07518501035989293, 0.016216700483534126, 0.038066269274079995, 0.037434219923471256, 0.007024460318197887, 0.08390138256213359, 0.03550260966163009, 0.06743117400835599, 0.03671592439434702, 0.08162877507387631, 0.024444440740250775, 0.013887777871962999, 0.08180453862634399, 0.024889076256283352, 0.03096835548809219, 0.012285606484980354, 0.04355846468599574, 0.006657306934827038, 0.05012124881989533, 0.08156297578205986, 0.030275162745026812, 0.05524567223244137, 0.034690154265732534, 0.023306836561870672, 0.07033693784427258, 0.038392852556200764, 0.04580244346852264, 0.04444038893486704, 0.052428985269920486, 0.04764965382374583, 0.05720892958643456, 0.038450807107672576, 0.027922094957302176, 0.0523874135087094, 0.051494798502854766, 0.019506808715842424, 0.09537983114921278, 0.011196108797805445, 0.0475170286822944, 0.03668582096936242, 0.060174559363194054, 0.0633268119887479, 0.021470797683803305, 0.03006524124723529, 0.04036025444586431, 0.06226474982536128, 0.035583692407535936, 0.036103329846575376, 0.04702384042884073, 0.13245962049451568, 0.04114207015523026, 0.02562264757861774, 0.037551477341161626, 0.017274648754767353, 0.08601568564171753, 0.15899528208519184, 0.025371631209348, 0.01490095692251118, 0.05294229482270537, 0.061274680774658925, 0.0367006907359727, 0.017869161712306163, 0.03260657131191223, 0.02616853885082228, 0.06864477985448415, 0.055220061913132674, 0.02504561291707139, 0.04785038035122618, 0.03129652457221622, 0.04516113594534897, 0.044408282189960444, 0.1077481521473777, 0.05804458212467933, 0.04998459405596218, 0.041208654687169104, 0.016924891312937104, 0.04388905460796049, 0.05065469882420955, 0.012067675537940477, 0.0328395692932029, 0.009353127247924286, 0.10751314701572542, 0.011194882099516692, 0.054317587355692545, 0.031431038120401, 0.04771071486175061, 0.06016120262023422, 0.057374959991824244, 0.05506889744391365, 0.040810423031930006, 0.026242140748147524, 0.03488160346844985, 0.026797213584124565, 0.030301138871319355, 0.046604522203485814, 0.010965114136436775, 0.031913604564784516, 0.008547984161263993, 0.05661209729770499, 0.016751833966061953, 0.02849724887299442, 0.052712587189049497, 0.020118294351343668, 0.025108525972633113, 0.027101203018138488, 0.029758545607628844, 0.0781049085180125, 0.03675289962801241, 0.054698375188895774, 0.0552434046121855, 0.039334998976799755, 0.020207689151227958, 0.042621558306798826, 0.044266651684959094, 0.08507753436964366, 0.015041841449396265, 0.07595792412757874, 0.015903021952497865, 0.022753414645370458, 0.07088394760484658, 0.037275233696545326, 0.04123977317865338, 0.0616330873491543, 0.033874661331215215, 0.021637329876783396, 0.06897321706938167, 0.02202421768508371, 0.03308026645813258, 0.08016353232725974, 0.024133257740627856, 0.038654559682453835, 0.00845579314045608, 0.04535703611890635, 0.01916747006978239, 0.0477087460157852, 0.08056990366669432, 0.04295109485786769, 0.01405635073165139, 0.05979867832314584, 0.08928456749286383, 0.04121398282868247, 0.041076190424181765, 0.03540013391043871, 0.021407446042904933, 0.018670390089673382, 0.06574778772530056, 0.03462366549478423, 0.005601827381929804, 0.033637928671293685, 0.08997210076138859, 0.03910400814587071, 0.02928127474602192, 0.04919256256412595, 0.04360788501799107, 0.022314714395531246, 0.023104880463271853, 0.044516986235976226, 0.12419379992230285, 0.05578506324860839, 0.019509964998090462, 0.07697574854377778, 0.06307801727445857, 0.015907534210371877, 0.04142993152321827, 0.08130511824762629, 0.034742841962724924, 0.050976049725807486, 0.015017679993874364, 0.015076629502037841, 0.028570904396474365, 0.02215455413886136, 0.03238344437352592, 0.009221898301714852, 0.027605798320784688, 0.021627711642894055, 0.0384183632840793, 0.02093824017192087, 0.10918422226583767, 0.026882193802345185, 0.06991693780066506, 0.05012205321221583, 0.015073214665115362, 0.020514831037050294, 0.026230237657024015, 0.050499669441412535, 0.06948130190252297, 0.06849614347541524, 0.01433115604618985, 0.04936649899689421, 0.09258827570104793, 0.04542460124338827, 0.06805793352184758, 0.07842452040002232, 0.03266962034808051, 0.07990392045147958, 0.1496548010336776, 0.04681502018244036, 0.03403348284923742, 0.023261553104666453, 0.03428482480587498, 0.0629738599602734, 0.05088477418006909, 0.04886981355206621, 0.012576448892603719, 0.06794279050682822, 0.04455153680136127, 0.0334228418256727, 0.04260837010318234, 0.04208942214327474, 0.006517398691240458, 0.03041483206494201, 0.03113936738020951, 0.12350091936006663, 0.10541994199757615, 0.0449550353110798, 0.043645021130120566, 0.009079147393124239, 0.03567936146752008, 0.040498280507181926, 0.016062153736129403, 0.02680386897296675, 0.04706477250663504, 0.05754236169459839, 0.00983331498930291, 0.020896903982746507, 0.022813219299179413, 0.05237450109674566, 0.028848329731713862, 0.06288232777508036, 0.03971984324556205, 0.061773132052152395, 0.08860212870903554, 0.02848595099133109, 0.03629757910065594, 0.0708322290090784, 0.07618011260825781, 0.04323864212980674, 0.007992425338259989, 0.04312825652079717, 0.038227530782141035, 0.12307913433159552, 0.02983593964017928, 0.03982819106069304, 0.019370625095982707, 0.011940358428194398, 0.030385255325405352, 0.04593412249138759, 0.14999453038457902, 0.02160710770817053, 0.02839308198271019, 0.02540607452242365, 0.06419983429593906, 0.04955026816817061, 0.056075372267514474, 0.05381831636412009, 0.03627458880204828, 0.061496271706757054, 0.04044787958264351, 0.021676574645924474, 0.05461014101221677, 0.030236944533704273, 0.051428026279374484, 0.02400044299241516, 0.020083240083148404, 0.04947851254274288, 0.03215513101989224, 0.035667973570525646, 0.06282374886195026, 0.017994514764136365, 0.03609643505525685, 0.03302605041573125, 0.028272327373645482, 0.05720876104709122, 0.038246625523653724, 0.05938765683001088, 0.023395869385210738, 0.03023170257708238, 0.05769786988234809, 0.044912279944025704, 0.028108233255484415, 0.024184177689734968, 0.13436578514595188, 0.011091837528041534, 0.027458305327942776, 0.041615569949029915, 0.023213697507256464, 0.09283820422546518, 0.022941872274743456, 0.021396990857958313, 0.052284133365197535, 0.042739892078022805, 0.04219225029491129, 0.020688275258327206, 0.06875173338959295, 0.03313634792462953, 0.04035806343440087, 0.04624346496477243, 0.03930313354958931, 0.029517882916655754, 0.028820442216050242, 0.03709392749794549, 0.04058596310055545, 0.04174302782743208, 0.033674585978470506, 0.07990241125826875, 0.032348051111424164, 0.07670033993499895, 0.06186436929349458, 0.024590483911695982, 0.05350345805768044, 0.06065495777875186, 0.052134658119851546, 0.048811682800371806, 0.023799185949047248, 0.06543036685475419, 0.014792140836136477, 0.03868969630510096, 0.016153030916147174, 0.023094249078102654, 0.10149574087512109, 0.02627200860109541, 0.067920129626028, 0.03411168510454797, 0.02134951447407084, 0.03457276278265542, 0.019450131615984346, 0.021869328113332875, 0.020118334570959694, 0.04304295646086816, 0.03201921744602582, 0.0080154252129667, 0.02623112823423599, 0.047928735824121584, 0.06415518286127238, 0.04169661439053955, 0.010129861879132448, 0.04030462497124269, 0.05168895199594479, 0.021484974140842116, 0.010122835895256891, 0.011039908258094182, 0.04579396287520086, 0.07851556228894381, 0.08497712322540822, 0.08560216670194942, 0.1361312500892147, 0.09437562777630745, 0.1590985813809018, 0.19128296163774308, 0.20399220708397128, 0.1094058668240905, 0.18811241483255742, 0.1449438659173827, 0.16727733606052014, 0.14388494854492528, 0.10504273562541894, 0.11939710892376401, 0.10374564151730269, 0.13870054044790808, 0.15792757002336366, 0.1491419358118888, 0.16365398532680928, 0.14172732319322326, 0.18799315026450544, 0.24272458597777352, 0.18915311463417547, 0.13265397700090564, 0.1876381144768769, 0.1390785741950235, 0.08619218463859252, 0.22358846039541308, 0.27647635148417565, 0.13451429895095288, 0.21456164638361624, 0.12417902208624348, 0.08009279942921094, 0.21109204949630847, 0.18728729217283188, 0.21665426151406383, 0.10414824370414981, 0.1892157040175892, 0.12757128239759516, 0.10684723274842386, 0.16088882160763587, 0.12324843976286151, 0.11807688662121374, 0.13170275626884353, 0.11950822997718089, 0.2266617293559736, 0.1310826080941385, 0.18022002381903512, 0.12713010002288128, 0.1353086555196393, 0.12738239575898455, 0.08807181200433163, 0.10344884373367795, 0.14471967794722126, 0.15809240150115184, 0.07657090171931252, 0.062190355027034405, 0.10232404279973238, 0.23715805322412523, 0.12416906294322784, 0.1142692534373172, 0.20133284010714103, 0.1283902533712887, 0.17680071294307712, 0.279086688833852, 0.09678387113155858, 0.1063805856111069, 0.15600665051850582, 0.10792482734447527, 0.20590615518871816, 0.120059376612546, 0.10185645337426856, 0.11148957235197868, 0.16907670805531164, 0.18600976395030178, 0.16673339831252254, 0.10033880255275196, 0.10838547601334511, 0.11716252237918878, 0.14309572476533153, 0.21427309170605677, 0.10580311619466352, 0.09376362311623751, 0.13461932960537173, 0.16754747398437994, 0.25308125201732884, 0.13062346095760025, 0.08428290967018374, 0.12829083814135483, 0.10948041484000222, 0.1430012048372338, 0.07903175999320323, 0.1650902622890088, 0.17519566681115858, 0.1794101309872443, 0.16531196813429558, 0.10255563884012162, 0.11846127889810071, 0.19020081647942144, 0.07999928307629402, 0.3186972343152569, 0.17431967591326084, 0.09144060704256259, 0.1854470110828838, 0.1318418318706174, 0.2736825207548757, 0.11416548682797341, 0.1399501524264774, 0.06533855121702918, 0.0830204657188827, 0.09749778080731632, 0.12042240269722478, 0.10455121361320058, 0.10588736288369664, 0.2672693535925881, 0.09165077560370968, 0.10543819787281175, 0.21318377596476387, 0.07464931571796056, 0.09313734623813823, 0.08803916899787803, 0.10982477902284554, 0.12742547288296685, 0.11102159222167347, 0.09577707838146918, 0.17817420133900258, 0.14298531617368423, 0.09658117958855245, 0.1768875873136905, 0.11409988671901727, 0.12019938684158749, 0.1889906273854356, 0.1409679155556425, 0.18013587672143214, 0.164025338787225, 0.11384651079894074, 0.12105557436664259, 0.24823786029892586, 0.14965337611013843, 0.24146031107633348, 0.08603844611394791, 0.18411984036286033, 0.10265636408040602, 0.16594923071322903, 0.22360562076491697, 0.1352576647073992, 0.11832485396054485, 0.1048709863736745, 0.13897273148740494, 0.14310301792237068, 0.11611636037067061, 0.15858642096000333, 0.14098530575152368, 0.152138335510127, 0.21823033420068605, 0.09911029629649655, 0.11470107421759637, 0.10595490885598045, 0.1841348863296932, 0.15782718186176595, 0.14882184895536593, 0.08572412023861563, 0.2076004045985399, 0.10054760747739386, 0.08346522572420298, 0.14755878447284623, 0.3262212902547852, 0.17780134634625527, 0.14959375914787093, 0.1769926639333848, 0.1719768258232263, 0.12444542150103277, 0.09457890154613603, 0.12649543448201112, 0.15766694691152344, 0.1703202219740037], [0.01964306702927476, 0.031359305477611, 0.026144414742086685, 0.01816834394459523, 0.008378742889861667, 0.03218650615083114, 0.05653200663566109, 0.05462737032963384, 0.02994674851276702, 0.043520911055947506, 0.05327174327366295, 0.01960982647424023, 0.045569962596580874, 0.07326054386794567, 0.016780866783172373, 0.05948180903590495, 0.05034851646351238, 0.05309568477734443, 0.02014525107017929, 0.06510576774035731, 0.018456345123629418, 0.11945107215715033, 0.02882513258936665, 0.035803931194447705, 0.01816166174267569, 0.07807824865824754, 0.06300937579644304, 0.012173118922228535, 0.04174602706165564, 0.03332411607487067, 0.011882670092276268, 0.03990204193659368, 0.013390225790170653, 0.016541847350796866, 0.0328498425322675, 0.027357175976278323, 0.022811932271466624, 0.024161938157293106, 0.05988069952675893, 0.04803308082984821, 0.05140015983112878, 0.02875941565200206, 0.02509311228359659, 0.06307984056371836, 0.020618961538158117, 0.04360276372021726, 0.023818726936775832, 0.021487092373952753, 0.03569724579011241, 0.006859986507709349, 0.06996860277027854, 0.05358955867949033, 0.06821954743035379, 0.0309858433601837, 0.019108305099390207, 0.02799263441815011, 0.03780469621321367, 0.019484869872910843, 0.013289977439619122, 0.021650113969019825, 0.007686713642831291, 0.042857804500888434, 0.038716720056629954, 0.0408128745132877, 0.019927944484797698, 0.05386479108804657, 0.003808513706204512, 0.026182320772580085, 0.11715309949772013, 0.01571678789332509, 0.0537972872505986, 0.0741117594823722, 0.03645226374388703, 0.053670668238473516, 0.0689724892858536, 0.023282417509284233, 0.022226436168796593, 0.05242411295072206, 0.02045715993811046, 0.03870664983086529, 0.035750442935574445, 0.03654235951422203, 0.09215034920001224, 0.02713638369084126, 0.04935057968982766, 0.04150093255204059, 0.050001329246668086, 0.006078368065983899, 0.02091097893313535, 0.05533535814573688, 0.022830023437798507, 0.045143355044626424, 0.09910884072944041, 0.015860001327499988, 0.004912417197990562, 0.05103087863854824, 0.012141311909222316, 0.01740642162340303, 0.014082910999986193, 0.07785150961529824, 0.024690377946582534, 0.028681314903341477, 0.08951686067326416, 0.02899424075299213, 0.07068869477558522, 0.035037437243567365, 0.04870974714116705, 0.04190990859041772, 0.06775784156014843, 0.00657364295142132, 0.03541283181778366, 0.061216113352847684, 0.09072034649791257, 0.05655746756782455, 0.0345681777464286, 0.03786134841521421, 0.025219235253790696, 0.06599467488065844, 0.02574198300980272, 0.02398974074411296, 0.051171674107712124, 0.03665483271282527, 0.06029180912000518, 0.021818524992634213, 0.10467798584291052, 0.08163306516625228, 0.0970763711619281, 0.01910639562523894, 0.11636836499336267, 0.05572956783937351, 0.01422871572656497, 0.046852914721614895, 0.046109342121429024, 0.0394946861741764, 0.04630680511435194, 0.08739950856374157, 0.028010198899034052, 0.08964662830675803, 0.016985552070001443, 0.028625993779109373, 0.08008808798847661, 0.04438348775429111, 0.017155144784239032, 0.05875911999253496, 0.10227630020029123, 0.036381285697702444, 0.025793052346055067, 0.03775533716825228, 0.03721536775570243, 0.03322283925128079, 0.022395756921821067, 0.03317249961377632, 0.02530667269902845, 0.06743107441692583, 0.05708033789790446, 0.008404199991585507, 0.022953867296417876, 0.04647870375324161, 0.025185609739574216, 0.035400363736815994, 0.009564939067668973, 0.05751230423488925, 0.09472804354323495, 0.043655838291611404, 0.021787889136542237, 0.02897959315187989, 0.04805817787024764, 0.10993662785979048, 0.030622867071219993, 0.038774758877773444, 0.06369415497888001, 0.04230929703842248, 0.011809750970813536, 0.020026405935265848, 0.05189451636866697, 0.0359742938270492, 0.05575303694293384, 0.021332752470287587, 0.034287429504817536, 0.030587778329068137, 0.04888974715985599, 0.03554411630536761, 0.018588127568364143, 0.020639908297227758, 0.0025415151227911516, 0.02796736309274791, 0.06548308136482393, 0.016595837397260532, 0.051667911391104424, 0.09038892154011036, 0.06075686279443964, 0.04458581923597282, 0.026147752970216737, 0.0708041825301705, 0.011032806623036103, 0.08106846602693682, 0.057613975593760136, 0.03158531482181242, 0.011332640030060806, 0.05448397399196702, 0.015048241156393723, 0.05644351581952745, 0.0538705405779183, 0.005590063623047524, 0.017587917428764126, 0.016173397363614173, 0.011615130164089703, 0.021295413344858155, 0.053625384781269304, 0.035517008284166936, 0.018059352615607843, 0.03930108043395224, 0.03994544081750416, 0.05238166018839806, 0.022253638035767985, 0.060929485386417764, 0.032713570812296484, 0.029521763151992234, 0.063668062024179, 0.02347876775949713, 0.02298903073214235, 0.04164796397690812, 0.04324885025139778, 0.004721604805860308, 0.0282907651947631, 0.06353508831272203, 0.050323978667297674, 0.05402073977635272, 0.050224984785722154, 0.06259234051310247, 0.022600991876735803, 0.0021968780211248104, 0.01988192366796636, 0.013396221385788054, 0.015448128519159172, 0.03895514194042452, 0.028910777388861584, 0.05525438648258006, 0.019035589948837316, 0.06160164710074183, 0.05084795599442817, 0.04588013244492393, 0.028732275072064613, 0.04688137105756229, 0.030866733924936385, 0.02950123199562152, 0.03882762277498841, 0.061885731655263135, 0.05297804431569192, 0.05501957670334847, 0.04664487971533691, 0.032957895403547634, 0.009573451262117635, 0.017535691299746116, 0.05623149332560359, 0.04045647508915394, 0.018088463956730503, 0.09719171335980778, 0.02517436548406559, 0.010652866274599108, 0.002221464416042211, 0.019753759073454048, 0.124540209559904, 0.07404509451120131, 0.028571668569178834, 0.016976703754476002, 0.0319819338619709, 0.005431763523618781, 0.05479900466818964, 0.022418212874101538, 0.015026534055059236, 0.029879440027739734, 0.029659092073298754, 0.038394392392928564, 0.02288270155869184, 0.009435945182978626, 0.032357937476087006, 0.02333932826595922, 0.05259182108866592, 0.047914819836977034, 0.03551398223686603, 0.017540931341148192, 0.03922494278559762, 0.03657756125434272, 0.05193626049966101, 0.05404767159733081, 0.050718173039175814, 0.03891233294721573, 0.03202358797763384, 0.010257112913795058, 0.006446248754077862, 0.039393187185088475, 0.058130180958898804, 0.030229854389965057, 0.04699024364292141, 0.04779355194900305, 0.04187096451078692, 0.05989684482976314, 0.05456912466475079, 0.042663386707464536, 0.025272139370621696, 0.06906130185891544, 0.08462426312748464, 0.014224183358882946, 0.06274046744370172, 0.030571437673643235, 0.02510207551231067, 0.05584353873986871, 0.02148654270586708, 0.049078055402083744, 0.039895622119788206, 0.11045796601402183, 0.08639445483324029, 0.06219436166687839, 0.02094462551476975, 0.05182236237751861, 0.09763339369167244, 0.013526521450389298, 0.014169531603974682, 0.032807776644345255, 0.0453772148748319, 0.041877824828148856, 0.04181854111412841, 0.09653398857241678, 0.024383370126146945, 0.039132192520604986, 0.016676636690634395, 0.08072907375472207, 0.026968472539597464, 0.07787325885146856, 0.03689370658849517, 0.022574060055757725, 0.052275365488904144, 0.07341756124890621, 0.013123543880459283, 0.041214285433412566, 0.03581882011325609, 0.073263393715024, 0.050662260112022205, 0.013156615896150472, 0.07681419592230551, 0.062427443917840726, 0.019483017855353897, 0.05730928327407568, 0.025710259308858265, 0.06748922815125796, 0.07184276026823828, 0.015444441721023572, 0.0336226298954458, 0.05886196729636962, 0.0663495344680644, 0.05023115179351261, 0.12285295453283096, 0.13195391053393965, 0.17691289885870873, 0.1871172206536416, 0.10278482170354936, 0.1929785900058285, 0.12899017682479275, 0.1160235258360063, 0.15127884614611828, 0.1389829817438318, 0.2543851336644542, 0.17699382838702973, 0.11383083664000997, 0.2549832644722154, 0.16682716747445447, 0.12308699439369863, 0.0938890087268045, 0.16254300461901774, 0.12577207128126777, 0.22350883321656337, 0.24757294194592586, 0.17724665272380077, 0.1947775483131409, 0.15979595121837434, 0.07251857239152155, 0.12457295981866699, 0.17499490580972166, 0.14637749221536422, 0.12248106481086825, 0.16368799963064734, 0.06884547190800791, 0.1245222754415966, 0.13223201577221194, 0.157210664943822, 0.09972871311249272, 0.10039947671635498, 0.11322365067298375, 0.10812977118597877, 0.13921441690575692, 0.2439090958045375, 0.14002326785797073, 0.14641823277117746, 0.1316943905887104, 0.18728039738151336, 0.1686339398785945, 0.19862533216514897, 0.16088532824670115, 0.13214311892947844, 0.11148669186138338, 0.0912964829213677, 0.28934356426039054, 0.09714155758340513, 0.10398793980599412, 0.12387234176839552, 0.10421390510013989, 0.13201237836432073, 0.11782205513408107, 0.17757645357520352, 0.22327969631841108, 0.16843904711065755, 0.2056206648628558, 0.159044602825757, 0.12583091449473174, 0.15942703391755783, 0.15294709453178992, 0.11341920227653558, 0.14644535228369698, 0.09847813586313879, 0.25146088412692474, 0.14726258423780242, 0.19770795719758158, 0.12287579161385376, 0.15555016936794405, 0.1165799508171697, 0.18440053497831668, 0.1903829462225399, 0.1422579310113384, 0.0786138896740252, 0.24876020968921725, 0.09476208082971074, 0.09626999467370972, 0.1753094768331897, 0.24686973451847033, 0.08263834872313085, 0.12054225715297846, 0.1138631655504146, 0.2019935143330405, 0.2178590113837873, 0.21155214658187282, 0.22615297036545895, 0.1404231351109282, 0.1470780949438772, 0.1624478564988221, 0.10922669418035977, 0.11895718293324595, 0.16353744803176773, 0.093714386645344, 0.20731840763361226, 0.15096363160879384, 0.18259480445375367, 0.13560027454889592, 0.17232151942387705, 0.19124447338042722, 0.1618676981137645, 0.14097310963176912, 0.11808822472249308, 0.16413691183251722, 0.11067333631217481, 0.1531763386822516, 0.189622083017903, 0.15739103268471458, 0.15622510815099364, 0.17309836322261443, 0.2520973040091415, 0.14994585315787023, 0.21338223870242798, 0.16405293327425757, 0.13229927829196378, 0.12442603947654848, 0.13046999822460836, 0.11011611459957016, 0.13836632693006148, 0.1926220067205929, 0.08769209286378277, 0.3276007388147616, 0.14130363060582068, 0.14547298752492474, 0.11532581125896786, 0.19690826865694216, 0.18784013186250964, 0.13134401261566148, 0.19877517896313823, 0.13039404826779522, 0.1469302093309741, 0.13416719983421987, 0.19579408570162712, 0.20089149685396304, 0.17365196900021646, 0.10433286323302216, 0.1204364910541523, 0.18131554487251467, 0.10201389976446668, 0.11789759140341513, 0.2119792405996592, 0.21589506838110187, 0.14452907527166028, 0.1534575542374965, 0.20151253369066024, 0.15872397970768715, 0.10953672230243684, 0.16070005754309316, 0.27220485972300656, 0.11488602316427617, 0.1439591058559956, 0.13796157203614712, 0.12494448181842605, 0.1187307733081041, 0.15322121611285597, 0.10997978925344445, 0.13457020804766687, 0.1432051067991603, 0.20784498582924568, 0.12411640972019204, 0.16578184050177375, 0.15090836602593624, 0.1053753863239, 0.10583179852654857, 0.21401096706188497, 0.12057461670690006, 0.19139695552087602, 0.10713740387150358, 0.13717941158721525, 0.07469559508946634, 0.13683379868105536, 0.11222789724988323, 0.10613728374723466], [0.006360796912978854, 0.03924941546433876, 0.03044319263989887, 0.035461489892294334, 0.008188607527934497, 0.048575739211012284, 0.046618591408215226, 0.04781195721138389, 0.0274944436105509, 0.05087905533371433, 0.039850193105878375, 0.05297774554140145, 0.030986831613606027, 0.0154055378610088, 0.0645863141624197, 0.07876117007746812, 0.00633994399967994, 0.023484212729418953, 0.026888751514977025, 0.04178724642242155, 0.06297915362783017, 0.0724511260106679, 0.06016430144588794, 0.05243806341182321, 0.07360419558901941, 0.04232250056379745, 0.06156362232662017, 0.05704066986518522, 0.022886528167873624, 0.020203370330554825, 0.030319440711830414, 0.032336387422776995, 0.08899776715665095, 0.03412985287967228, 0.0768766550707721, 0.048597105403220466, 0.02722756730602874, 0.02764702534242984, 0.03337497282172403, 0.10412948221088418, 0.06443298166437496, 0.004661247611135966, 0.0706998413548835, 0.029528640706332463, 0.039411297503618464, 0.05674233607527229, 0.05583013986207305, 0.04819174529984594, 0.014124365932788822, 0.05587760283942184, 0.04530140281384511, 0.005658043871423411, 0.02363872500286708, 0.024372721503999446, 0.052697077739022435, 0.04027456368109392, 0.08283104281872511, 0.011587573981453336, 0.015627063675633362, 0.02816883272551481, 0.021100907451322964, 0.0496417926924844, 0.017093716024030602, 0.026476753259738608, 0.03320208975985166, 0.04318168349263649, 0.07586946395496208, 0.024299219198104356, 0.03410592412335738, 0.018252854933962226, 0.0163016538886774, 0.036696281899968465, 0.07201840890751732, 0.03411618587110312, 0.06567893940354548, 0.021862084752008803, 0.022470465816196897, 0.06605645987175165, 0.030978588507540768, 0.061296502789182056, 0.018100466639284166, 0.06378255003402311, 0.043389936833972895, 0.039508552365605874, 0.03331730555322382, 0.013156210827160508, 0.05821182294898938, 0.05704803197013755, 0.04276323477707563, 0.0188397912819299, 0.018179136208228527, 0.06126654492090307, 0.025668825443473556, 0.024340105310623205, 0.026764689321299235, 0.03025753506188912, 0.007914983904019238, 0.0017146196877283436, 0.028095294030443318, 0.042154489821123506, 0.041748401934220906, 0.038193355599838885, 0.019991765354549693, 0.05318445138513081, 0.032803298860427835, 0.07558680815441955, 0.0056457567787278565, 0.06128181305323398, 0.018429564605016383, 0.053404004523350354, 0.039358471910799706, 0.04785054889056952, 0.05907542237471189, 0.014508178855683056, 0.04294773556231972, 0.14395526009461573, 0.04371468150507539, 0.021265451646139546, 0.11950648329671353, 0.033801293090706876, 0.05911580669964033, 0.022641554317106644, 0.05794427057187404, 0.04926102018103965, 0.0381610726547097, 0.060213809877994566, 0.02906584890649444, 0.06214220257055375, 0.01729209257680322, 0.08437019006739702, 0.03735039458279649, 0.06122840140315314, 0.06835699126484894, 0.04694928475204976, 0.02200801301026537, 0.0007736699802579449, 0.02648608804109597, 0.028775798442262798, 0.019963033226949554, 0.031673807553165866, 0.026347190554764484, 0.03248691603901886, 0.06151011874598842, 0.021418791805063526, 0.055361087208673845, 0.01046638610968066, 0.04027669723596304, 0.01934389245786494, 0.0764670048750216, 0.020770704403759974, 0.024183350314776746, 0.009459064758923507, 0.027778696704415545, 0.008879482855028924, 0.05980635835458675, 0.04423259524628521, 0.06384234702695282, 0.03854364164233689, 0.041749313578850804, 0.04153111641625724, 0.02780173296829866, 0.017025022835080183, 0.03185925254177663, 0.0566164295249168, 0.016020034222052466, 0.02610377760814323, 0.06114184495902831, 0.039176100849985115, 0.03796890715978319, 0.02401890379617051, 0.07006592658017913, 0.04863546725602881, 0.13215289421139226, 0.011511275454634621, 0.026922626007768898, 0.00672384933193004, 0.062141210486691814, 0.04991204935997244, 0.045434966413003784, 0.061763230365731066, 0.044657463778651534, 0.01839626659338753, 0.015223578572453511, 0.07246612601222531, 0.05699015785789779, 0.02188057428406131, 0.11399595157033014, 0.023829854363876007, 0.01647315990750588, 0.06398934014742413, 0.04001407846508007, 0.05194419717055656, 0.026861614765479203, 0.010955194255427248, 0.04042773913111418, 0.09377703731579166, 0.06503559408649322, 0.06238206469964597, 0.06266186299223094, 0.018495610960188414, 0.044255849845226736, 0.03351041716673682, 0.04382525863606603, 0.007357496454665859, 0.016520864202550823, 0.024573449946699605, 0.045068485271786494, 0.0970481638045561, 0.0627055453256734, 0.008307441171529073, 0.07113731586404386, 0.0454906648355386, 0.030668045191334623, 0.03619873843666527, 0.07408441014347539, 0.05570152902134484, 0.03835410765943028, 0.012784300037779877, 0.08538160232766982, 0.04529479147505857, 0.07026886327132102, 0.049702237029710127, 0.01592959850020106, 0.06714628123107456, 0.02270138386877314, 0.047582927565541, 0.0169088551774621, 0.04226169233480769, 0.03572126647697822, 0.05553230019887129, 0.04543362958957592, 0.029319634683610454, 0.03610185512732114, 0.007941043342373545, 0.04257552025298919, 0.04394527013984419, 0.06000399754773225, 0.13442555532580422, 0.008090373988623821, 0.059382428279927665, 0.042708731451702696, 0.029757017262219906, 0.05561909796069226, 0.05399398798603685, 0.04473018467486386, 0.0476142299181271, 0.04244209071921726, 0.0661196621255048, 0.041430180501793666, 0.026372837263249585, 0.17350187705409142, 0.03539210147855263, 0.023208557057284543, 0.037396310062538234, 0.03433892210464805, 0.03612268888842195, 0.02379408954913097, 0.006458439128172975, 0.05333678413843436, 0.04927078780207423, 0.033715219281974344, 0.05639102730539538, 0.044694121085828355, 0.026628917473698818, 0.02337828192168907, 0.03002085411290248, 0.01562462368559453, 0.07765646362977643, 0.018928998390272744, 0.02488462528544328, 0.020841174916694724, 0.032534827177803365, 0.008822963760805227, 0.009783466605679884, 0.028691609209823995, 0.06573400580354276, 0.034228590121793176, 0.11186781294283368, 0.026809007507718863, 0.027127629221086542, 0.05236030165706912, 0.04778569954777918, 0.0490698314482166, 0.031617344957926584, 0.02538323935662066, 0.05151142644125128, 0.054598642032473325, 0.03442372420742627, 0.0662892050440273, 0.011669904493065852, 0.05346493149596838, 0.05672220328462221, 0.04369562123751929, 0.02098680631588063, 0.07653815146054953, 0.04963704677779348, 0.024966012551299026, 0.05646838686398922, 0.01925318381719051, 0.03106277773997957, 0.006693556300184179, 0.07562271469543058, 0.035339406120681, 0.06555060435447001, 0.04304464185430158, 0.09088492516668574, 0.05435505288562948, 0.0626448366881138, 0.05433393567199669, 0.1050332821004333, 0.05161372599222007, 0.03347810357809067, 0.05541383236226055, 0.03913748618816176, 0.06208121048046216, 0.048074284868855635, 0.007224863173530227, 0.05908794025139463, 0.044006495886752685, 0.047794471254512194, 0.0524069564116578, 0.06980307415247926, 0.015704682746511555, 0.044161444830317656, 0.013691890147334386, 0.07744267147274748, 0.05245921509941259, 0.012899827054371277, 0.0315513062636338, 0.019761492731049657, 0.04311964569252826, 0.07462843982202393, 0.02813701326357982, 0.03000343901916377, 0.07618536797141837, 0.014508898978331878, 0.014410336021213763, 0.04965082103867204, 0.025714874988602057, 0.021928761214498552, 0.06208237110366745, 0.026831352377250314, 0.027754919250465693, 0.08826657453732145, 0.0363977795707122, 0.0367522522837164, 0.02883430840747972, 0.054014867712413116, 0.08208979146494981, 0.08429800926317131, 0.016891537759933743, 0.026830480952236443, 0.164271819915983, 0.12543758963264767, 0.13443174531623242, 0.1433389270377736, 0.11685123021203665, 0.14106314028463057, 0.15699363223487334, 0.18764047402768366, 0.16036763667098938, 0.24005245597612476, 0.17349420085309014, 0.18941199106554832, 0.13561073930994158, 0.2604894448191889, 0.1734452784782456, 0.1615878768385418, 0.12572550845723, 0.06116578137622245, 0.15895670189732508, 0.1266815785258528, 0.14171072972878335, 0.15932586434627735, 0.13366211806574177, 0.13674781297243413, 0.11881699650398186, 0.1415907756815995, 0.18175028444778535, 0.146778064269212, 0.10112572806857287, 0.07211571739565942, 0.09087743282678629, 0.1604416254427164, 0.27094167266641894, 0.21886134550215738, 0.23964891150113077, 0.11745207297104983, 0.1192278724404112, 0.17211216291592968, 0.135779585088453, 0.25658720743752295, 0.18637779258912612, 0.08208413007518939, 0.1917691976432839, 0.21623530335003333, 0.20537946974077534, 0.17897531480318118, 0.2336824502074911, 0.18031137214312631, 0.08640448292416912, 0.1408708368938777, 0.1430470015733473, 0.1300209940921876, 0.1567799703127915, 0.15714706432434822, 0.13264207199456232, 0.1285128657435698, 0.1952730539825655, 0.095230535934529, 0.09566129185259344, 0.08529524889684494, 0.09862297244610325, 0.2721781692197246, 0.1476231205367273, 0.13849100007885887, 0.1607386683744769, 0.13590850236435092, 0.12718619298069708, 0.14532660344435325, 0.14839601132177538, 0.11072513917761465, 0.08134995737383444, 0.2656466261513772, 0.18876651602406658, 0.15653207958225282, 0.32308029912171826, 0.3126439752597963, 0.13651643909754294, 0.0957775839994992, 0.13608435018649026, 0.14630433081859542, 0.09283325529747433, 0.19688677222978687, 0.13519604059477008, 0.18719606642280856, 0.15496968922595825, 0.16498397525039413, 0.11784941213385713, 0.15750220736428616, 0.16351677897957065, 0.09317110773296126, 0.09611981845791302, 0.17634331248700622, 0.17686230641218925, 0.10973493989196517, 0.22962894110429674, 0.10578816215838156, 0.11815785445393094, 0.07927468647399256, 0.18441824693112605, 0.24105842135125594, 0.22066669298275826, 0.20035400956628785, 0.09433080397185781, 0.11260053773801174, 0.15308682896917866, 0.2129638934087369, 0.09837842951979368, 0.1564102869240507, 0.13821536164370277, 0.19319261965011397, 0.16686996114590477, 0.21011735583024643, 0.255640659841799, 0.08430147198058906, 0.15890047104368288, 0.19789621564409426, 0.17211545709400408, 0.15675524099459573, 0.19209550513375193, 0.14234063786364373, 0.09879055417953961, 0.1398376294321591, 0.1390726446744896, 0.1629341384696384, 0.09716120007778369, 0.1744380058540452, 0.20367346854219515, 0.24148330903582035, 0.15954945476785784, 0.3272153659453315, 0.1564345872330089, 0.18840024938746808, 0.15865968960908153, 0.1816731700373273, 0.13276984013857382, 0.09765186407152684, 0.08933081622085265, 0.09417521151443643, 0.10938456957979549, 0.14042917188377152, 0.08259849682930978, 0.20612349433283653, 0.1397191156302729, 0.09971983415345032, 0.16577108462731685, 0.11120943698070704, 0.09702916482403394, 0.2145114523028174, 0.12046268360028345, 0.10876093570503498, 0.1565177230945518, 0.19875726782746855, 0.1824931905514771, 0.10016996443511979, 0.248299453768038, 0.12840989586566726, 0.16107723327173343, 0.1485635853943325, 0.16740508888277317, 0.13301242954067646, 0.11502410285174848, 0.12839082027635268, 0.1005203041037725, 0.1844142632739198, 0.14942324329768458, 0.16289011905750922, 0.11702130939210616, 0.12080100334940419, 0.12448937196524874, 0.1110130426804385, 0.15970923006534576, 0.19138547952377027, 0.20706595101904487, 0.16771109504324777, 0.11263030791474928, 0.16119121183310786], [0.016339929556594263, 0.05040581600980894, 0.004760751419986088, 0.011068511108357099, 0.03917212868409772, 0.014759021897559926, 0.022384558631587895, 0.05932252786512818, 0.057701811404718514, 0.0743404673712869, 0.06684050489697727, 0.028148223045131857, 0.0338852716489665, 0.03491956312509795, 0.07274236965684161, 0.04514084993711403, 0.0461943319157487, 0.024734228819368348, 0.018811281319827806, 0.03868156811222434, 0.019256839971809138, 0.055757422796300346, 0.019150505052699197, 0.04789321998795194, 0.06550290005942506, 0.03984653120560031, 0.05590720064637642, 0.10183977564015698, 0.012918940948082075, 0.025603520278368267, 0.044052871019249006, 0.021690726205105745, 0.014756105975398134, 0.04602024226539558, 0.045944610235070994, 0.06343769938534786, 0.04204326534583684, 0.041025689908213196, 0.08957771103708975, 0.038831801784615365, 0.0446449305802103, 0.02446494125310452, 0.03159424932222934, 0.009906451488214155, 0.10803820069638953, 0.0206549140444446, 0.08659458764257931, 0.05862344965158452, 0.020942922884358034, 0.01504702690703374, 0.02787583282277469, 0.04587498433407276, 0.0320069542935779, 0.02261892791026302, 0.03156240879287643, 0.021993041737005118, 0.009028382576821793, 0.00601666925978216, 0.02034109953280178, 0.06775961122325352, 0.13101376743326265, 0.04772609407683054, 0.04901645427209236, 0.03289758513170866, 0.03325243322779575, 0.06854120476712143, 0.06290226521330976, 0.07308737735354132, 0.06884899591245959, 0.026063540755140207, 0.010782758397380672, 0.031616632496157, 0.09073291033987077, 0.05136690012389614, 0.046223707557205236, 0.07036543631505582, 0.04892890191366596, 0.029784247857488455, 0.03760161779580578, 0.014054026612411103, 0.03465035982850579, 0.06164465910725056, 0.037985960276977676, 0.059806614994041385, 0.07609225764510132, 0.0376475102929098, 0.03900855742094498, 0.06698623780281314, 0.023513446644609495, 0.08619904112551482, 0.02035942818639019, 0.012872759252786638, 0.029902300091400266, 0.10524196445100731, 0.014628849195076093, 0.03507378811557447, 0.07713466582279052, 0.021523127234691096, 0.06759011427000647, 0.048277041529335325, 0.05496652894503167, 0.07449271202447914, 0.014115873848148172, 0.020851260464217876, 0.060117317273491816, 0.006489413978171445, 0.047209877220373, 0.09031097975469406, 0.0029767897625964496, 0.03844702646376626, 0.018108774862822988, 0.07957765892628701, 0.085609253015249, 0.029123154198450428, 0.07115203241306929, 0.025294700659991756, 0.09440065586879369, 0.03472428348275923, 0.011331457381827698, 0.09361089582765296, 0.09179565815194961, 0.02588156422960662, 0.051658756640409274, 0.03989281057710609, 0.030297555495053533, 0.0954484879489868, 0.012909954736730265, 0.05401643819265789, 0.037768310867249966, 0.02738592725607657, 0.017759532615121816, 0.04734940481402221, 0.020663308452874906, 0.01220223696662053, 0.05171937717785759, 0.076942247518849, 0.07965697200908776, 0.05461326282050821, 0.07335338606348923, 0.07805868277266141, 0.0366047612060943, 0.01046319152303641, 0.029637298787072785, 0.049671444125593676, 0.039787370065647754, 0.03919632940162574, 0.02415660043968068, 0.04083398406604125, 0.02602866268716753, 0.08153237056948485, 0.011233417279717904, 0.07413945356083494, 0.014881229200851054, 0.06545767022837555, 0.08235509537400738, 0.08920314766827131, 0.027688110637809002, 0.06200803759237451, 0.035069302670777805, 0.03351783289784386, 0.025924865434306766, 0.02269930968571815, 0.04350905967575889, 0.01157427373747792, 0.038338356891707066, 0.026343530569706234, 0.029327048499497677, 0.04911834779646128, 0.049286036782207034, 0.030829281801538124, 0.0707121906922229, 0.03719564865253145, 0.067925714406996, 0.022473737011633577, 0.025222450907852863, 0.045878178920717015, 0.03495437032993763, 0.10449821565059886, 0.008127454559378808, 0.036875075330176664, 0.04901612868472453, 0.012463202902806864, 0.16327448069087921, 0.022056303362572388, 0.04780192145957582, 0.046900228311818455, 0.05004978813831845, 0.04855248078163113, 0.012922509002589412, 0.027467586483145436, 0.04615762098241718, 0.06677882715819344, 0.006297242258780546, 0.039433893266945116, 0.03684500254870903, 0.1361470008569379, 0.05356815418288593, 0.03561838852962659, 0.0609554251235339, 0.06265706345138532, 0.017891458701342344, 0.04159243409371665, 0.05003520948511939, 0.04351810717414464, 0.025897420334419417, 0.03467823776807036, 0.02602863778930999, 0.0331826426178938, 0.06839718789823594, 0.02260461164217803, 0.02257025834443348, 0.03779054656925221, 0.02132587874638698, 0.05496598119216581, 0.02570526441559196, 0.024014498790605895, 0.022160690503134843, 0.0296513335178456, 0.009474538777384066, 0.0358769700171486, 0.05769303586754588, 0.02264478337770749, 0.08388725590080985, 0.034688135624052055, 0.07933860118951529, 0.038048013398844394, 0.048377176881918026, 0.08050107066669772, 0.04521925903616413, 0.015674202023224247, 0.07445216299064698, 0.03364135691475484, 0.028339021073113528, 0.033432237894064, 0.04752002791651795, 0.01705727322147258, 0.07287271951715793, 0.03723699441780487, 0.03398451067867779, 0.02033792984401507, 0.0036426305333377737, 0.03427951964699934, 0.036808483137358586, 0.05548890897884004, 0.07948128506541252, 0.01883159222592029, 0.06025823914716321, 0.04953116193533905, 0.03896503213552698, 0.05289192071124431, 0.1134938192403605, 0.06674081387539064, 0.07651932101937071, 0.07534836328798726, 0.05388809548270318, 0.12882762828901892, 0.04031012548253902, 0.12545616726481146, 0.06278489671287037, 0.03540603278745567, 0.03383315085703808, 0.02541549165823287, 0.04473087032355609, 0.05944980954330775, 0.0534847118861733, 0.051788662169729514, 0.06266624884559743, 0.02992101944983006, 0.0392467379870434, 0.06916917469953338, 0.006881594496418632, 0.05562411200615668, 0.06908850564110665, 0.07771467099026327, 0.051570970625165975, 0.01669711422085041, 0.050642537178411606, 0.0417230214412895, 0.016082179274470094, 0.06218066784523188, 0.04308520620989223, 0.011226529191668716, 0.03645808984255118, 0.02327991814743127, 0.06481267782228609, 0.050489679654879924, 0.07477670847888916, 0.038216223324378656, 0.026488326933054675, 0.11873821202184885, 0.10396181620777616, 0.04780287140860193, 0.019293981829598066, 0.026076587232490702, 0.015000990768443915, 0.08635817290914637, 0.014474963198506064, 0.04687693157804109, 0.05002768267126334, 0.0455835338441595, 0.03434595096135332, 0.04271635019610967, 0.012218139994318688, 0.031002348724512324, 0.05156533221804327, 0.025079148415956768, 0.03166229133644412, 0.04816288676773829, 0.042832990913020993, 0.03054845695113463, 0.024871530927597515, 0.02388725158638291, 0.0500496540729317, 0.03632630356737683, 0.0690925965506223, 0.026383077943577405, 0.12714835589811688, 0.012148443230187461, 0.014029444766140754, 0.07096850838992866, 0.030580885452969424, 0.061278852123406634, 0.09847448928461922, 0.0386614621346516, 0.023508829049645893, 0.02191394890448259, 0.04530849295758432, 0.03458490527625527, 0.08227064184123471, 0.041348239737412626, 0.08524733009718119, 0.04305315692157995, 0.061653829179704196, 0.06215287034489936, 0.023723253229212378, 0.03234220203012228, 0.04139867513590763, 0.05160488150713425, 0.06935599290074841, 0.055559071141385266, 0.04286368805614691, 0.010684047968337133, 0.04371247134141384, 0.02359037527874593, 0.047168121598060095, 0.033437914605582916, 0.026686155732961434, 0.022511231269867673, 0.04687666344726759, 0.049193094995233326, 0.025086702042890173, 0.05354093890937586, 0.11907629428371308, 0.1845701468447524, 0.0962154032482255, 0.08614942161065918, 0.16569286705024783, 0.11473141129939787, 0.22808695933030498, 0.12009178213174306, 0.10651137214154006, 0.17388240824784004, 0.22907977863665552, 0.23516277722533674, 0.19259065840273135, 0.11059265193198958, 0.15985297880345778, 0.25737106860164677, 0.228081091096805, 0.10193320006252297, 0.1488711850176896, 0.2294896969631795, 0.12266648107118185, 0.12690421133752794, 0.17691096831713954, 0.1652532551557787, 0.24299024994815552, 0.15447606813282738, 0.14691353925774175, 0.1685839909459314, 0.10522974534861504, 0.17690159140094636, 0.08634302735088334, 0.12373026310195848, 0.13446183724989816, 0.11187309894951121, 0.10380931874556888, 0.10829477886398954, 0.09571158552482244, 0.1978909756026922, 0.15320601692843824, 0.11316424821533504, 0.12276454032548975, 0.18070901774110334, 0.08288929614448741, 0.09446119213657034, 0.16038170204527918, 0.16637241768260158, 0.24872040376067164, 0.2871776498373478, 0.18698375281547347, 0.09826507148963791, 0.3258930675445065, 0.19406819686053262, 0.10483487298892391, 0.13779663330604955, 0.11575677402077184, 0.10783082835616604, 0.1239361415707296, 0.15428188016578076, 0.10519740111645191, 0.24368650129725858, 0.15438197721396724, 0.18624377316765248, 0.17176129464660922, 0.0767501739544734, 0.10317417056930643, 0.1452416749370675, 0.20268362165699083, 0.17605897129303025, 0.26113761649016415, 0.17104078895382344, 0.10870187798695219, 0.09473237194000714, 0.1683949051244605, 0.1249611901960546, 0.20587189573674433, 0.17486865451980024, 0.2911308780312538, 0.18045199524250724, 0.12432920596291944, 0.12121327356585573, 0.14009696551628653, 0.2968153117164489, 0.2250492215276726, 0.1877313626990203, 0.12816921402249606, 0.1317447532088526, 0.1893882729834126, 0.15965079287848166, 0.1443371242813526, 0.22716155576129116, 0.1624573253455662, 0.20565768223135703, 0.15214713019949777, 0.20075805965931187, 0.10281391006203429, 0.14029840067509683, 0.21180172270584494, 0.15433192102899476, 0.19635432580065346, 0.08427468188587697, 0.17479337872036044, 0.1682361410630326, 0.10596741907178395, 0.12965576933516612, 0.17393059517827728, 0.13915999401961604, 0.10146803147489987, 0.23906864586376378, 0.16291032845695175, 0.14954105229868045, 0.20020886654815367, 0.22315131530406015, 0.1424406123377623, 0.2085352157272639, 0.2258394412215679, 0.08036876728217449, 0.13507219482093089, 0.13272369100201514, 0.11799669253730005, 0.23163688819735284, 0.16257504241601115, 0.10364195917763057, 0.10911567271837305, 0.11988922082368406, 0.17848160177949937, 0.18196258273336197, 0.10007995676489607, 0.1331486706171305, 0.12147375112099033, 0.09960646846241529, 0.09726245391873584, 0.1387739776363296, 0.12006007375255709, 0.13294912003461393, 0.1457312510859582, 0.14941458650414022, 0.1394937019194326, 0.12280570989054058, 0.14314938156354812, 0.12371078148604402, 0.20835912275698878, 0.15114649679631958, 0.16515985371605044, 0.19953138435319548, 0.09645266067837516, 0.08849681460208471, 0.18996460092884881, 0.17362537042748544, 0.05731805498080869, 0.2737951969667789, 0.08227185226015507, 0.083765976521517, 0.14296024977680177, 0.12491541644257885, 0.17596463522603437, 0.18693628600768505, 0.1320548809223598, 0.1997264303387173, 0.10353292954424698, 0.11578459067330246, 0.1074042552781682, 0.19251020384892342, 0.17041066631434426, 0.14537502020116777, 0.12427440003281641, 0.1499131871687789, 0.12088278323532113, 0.10684413775320976, 0.11474484082071051, 0.15361418857449485, 0.08429504450290434, 0.11883450161305167, 0.20692770279222922, 0.15957150277831864, 0.08528927341103555, 0.20395753394451835], [0.12961731172136723, 0.02899371789798381, 0.060654521108635014, 0.03277501106382378, 0.023734313623619177, 0.013066985524229467, 0.030939156046858242, 0.04561961658539311, 0.04470104269022423, 0.03990148269240895, 0.03736866194935095, 0.01349160220519069, 0.04124492511994416, 0.04675049642701784, 0.008950410147888527, 0.0111659795173534, 0.034600690517935066, 0.03312856447131884, 0.04390175251530544, 0.0320578531752671, 0.04881508806119523, 0.0349940958192512, 0.024585502424968347, 0.026622022682380293, 0.01578486150866675, 0.03644173003492817, 0.026952332982252684, 0.020000920105244846, 0.030152192226641124, 0.04625953748942383, 0.06907070175774636, 0.017228480466010592, 0.028666012297053973, 0.11454811710263453, 0.018069053203949047, 0.049585002594657486, 0.014968007810473924, 0.056584246171217774, 0.08554503186455659, 0.05044359946623445, 0.017218188074747884, 0.05737158154407817, 0.05049871949238643, 0.015561880126986054, 0.02024650682635125, 0.030491168896156936, 0.02794594518960484, 0.018689571016077555, 0.04384404694240901, 0.013407745263389042, 0.021167319613478838, 0.005313187477088744, 0.013852958218194546, 0.017878802928833232, 0.02486361340890008, 0.06891649591946794, 0.043366107669088154, 0.045289631872888536, 0.017489431080438437, 0.05318184285574863, 0.04248928556579255, 0.03551367963213594, 0.026544040677347974, 0.04745370768491299, 0.024207989617641416, 0.018357623203267014, 0.04699770916974352, 0.023366532048150417, 0.005721817339485091, 0.04052044343083136, 0.022745430093979644, 0.022185814356611624, 0.006973257874168697, 0.03184595325541112, 0.05322669730371526, 0.031947902321154555, 0.01664687992043553, 0.04539038775668991, 0.017499824978351113, 0.031790955803327026, 0.0465895758280831, 0.05652404315168819, 0.07886910420512, 0.009136847220361233, 0.01506173675278983, 0.06618942209188977, 0.07000681523594164, 0.06418517520350796, 0.01437532293024443, 0.029303408941374193, 0.023365808095061974, 0.05741216888230655, 0.04924657559322734, 0.04859186153137877, 0.008081076554052772, 0.06286587220646682, 0.03541968447426635, 0.035981778506069415, 0.021948097273707393, 0.013291471311071468, 0.04033323835521456, 0.016922466644656756, 0.012138297353240271, 0.06966101080780068, 0.06098061409448424, 0.07572044453193104, 0.0968714273204246, 0.04799269267448014, 0.04237034658510839, 0.05393188889889468, 0.02806077602379505, 0.05986365024000407, 0.03744092319280871, 0.034938102452865535, 0.1309569696745565, 0.05540186223844367, 0.06735228993479284, 0.05671934960710426, 0.028430327262368896, 0.01727261479132839, 0.020122687865589416, 0.01831582736133808, 0.03469791856684512, 0.0050138481967752025, 0.023980413623634848, 0.018201745378093857, 0.03815177617774856, 0.04108970421516607, 0.03397374714334165, 0.026945974452481158, 0.02034194222951849, 0.048639500708950144, 0.00929855018658864, 0.02014209287271144, 0.026746132756553354, 0.011096135281296748, 0.04137464295772295, 0.0856201850899285, 0.07122478012235896, 0.02196052130461941, 0.009018004000667603, 0.05046257163367925, 0.05748859764407239, 0.03652798770476253, 0.008561979630030692, 0.03012159275972555, 0.03913297776072737, 0.02605486480939773, 0.05440851816186502, 0.049038034968919335, 0.014061805277672267, 0.045526490937317574, 0.08017212783377017, 0.04338855021482995, 0.029836324599361228, 0.08824079567866941, 0.021408459194184794, 0.013706572222403221, 0.060928991259706605, 0.04703848036907373, 0.03405145144150142, 0.05654606817951126, 0.06759851825453582, 0.0232714049953727, 0.008406986636410077, 0.026970818683865572, 0.01789247759828164, 0.09208812753880218, 0.018448661261748885, 0.08764167661748587, 0.06843542334653678, 0.0250116637307069, 0.027302385367933783, 0.029265780617753347, 0.025775639167536172, 0.028940310078342597, 0.0477638507201787, 0.048235389328892195, 0.03230240376245591, 0.07982960226194513, 0.04871024126787821, 0.054991426802570784, 0.009244079419952488, 0.04948079165431762, 0.02968166676920749, 0.03213351584910866, 0.011221854140110796, 0.029476387764237104, 0.04843176447696263, 0.08040273562073708, 0.05935039048293426, 0.07008556141367844, 0.0420222285714361, 0.05445394334533522, 0.06338186689742631, 0.0046375079827773715, 0.06970850059822684, 0.04053840819265574, 0.03763461320270454, 0.037236496460654085, 0.029164496133284225, 0.014460985924327567, 0.03797546487241503, 0.03925239171592459, 0.043122388287297184, 0.05268369035254564, 0.026056808757505594, 0.03714295712509944, 0.04090526471695593, 0.04840593582259552, 0.033291810147103765, 0.027326059400013862, 0.0583308270471471, 0.042336592751164595, 0.028310658582936854, 0.04631798233716719, 0.0635318439303627, 0.026135713898486672, 0.07199462187746841, 0.02885157219885338, 0.049747459199880405, 0.03403879566899231, 0.01967729009207218, 0.01930046293343748, 0.008539065940215463, 0.04926199311270349, 0.01983484181935989, 0.032883109900379376, 0.02593130057287072, 0.026301631305907524, 0.053074701629098386, 0.027829733481931112, 0.04078364442853678, 0.03866582883582, 0.005792976852746741, 0.029947426500580007, 0.049402999256046555, 0.022506533235672022, 0.03261798219154439, 0.041963412171049465, 0.03869497082045963, 0.013263677641178572, 0.09336439937713648, 0.06962666708615518, 0.044227048769713416, 0.0007134022622091336, 0.022346790496920867, 0.043785985138627796, 0.03018228032986724, 0.04550259665495927, 0.1201691953164916, 0.029354480192846352, 0.022733239719884533, 0.019375269504023657, 0.020165288099838842, 0.03656242335695894, 0.029264365270313238, 0.06800507345507223, 0.05088701881768723, 0.02220498187647712, 0.02654047262284064, 0.053285896748064034, 0.036601915189455596, 0.03411246268379112, 0.032823266942174203, 0.050106781249445294, 0.022177791500824596, 0.023023012477243622, 0.04655817388406685, 0.02011414023957426, 0.018893932630758614, 0.0481454927414175, 0.03506748321195764, 0.031045035143653234, 0.05733416197941669, 0.09417705012545471, 0.0687708396224245, 0.025861253323514136, 0.07817742640092488, 0.008174256785892913, 0.046047047681866154, 0.11560361006207044, 0.04858802343087812, 0.049550226033334775, 0.08758507804164002, 0.05423404546754976, 0.06178594870312561, 0.07401815119890437, 0.037073488272125685, 0.025591753167851318, 0.03975301868312302, 0.041306158527731895, 0.038877870481941974, 0.004910793091591087, 0.06598252472617934, 0.07283427722511754, 0.047040460706358, 0.07218631239788187, 0.0191769753057029, 0.020574620369100766, 0.041619519132279584, 0.02735697104775858, 0.03849894424239474, 0.04862926960472138, 0.06561837249225186, 0.05603052931086672, 0.045749897497796246, 0.016112686810834755, 0.0017308796645187203, 0.005300840533774106, 0.03875282961094091, 0.05847159187279402, 0.04289916941835996, 0.04700216397102322, 0.018193877655111493, 0.009852910560796098, 0.024425162137636257, 0.028551658352596626, 0.06326500784545656, 0.05786959998189442, 0.006502176045380052, 0.02869544539510483, 0.05295270978803596, 0.018143926807228598, 0.04846906529799585, 0.04223262695896049, 0.017322515843496207, 0.016729795531700217, 0.052954180676850586, 0.01569952889000096, 0.05366382324287007, 0.05431243158396214, 0.03129627559364083, 0.04771872814143858, 0.1203758551949455, 0.10028492358903732, 0.05745298221647259, 0.014933188156705472, 0.0164759733654078, 0.001988262104737993, 0.024054664780475923, 0.03208454559376884, 0.06782037731740745, 0.04202231284110777, 0.035914768795332605, 0.0153472107992838, 0.06044118094348139, 0.04857193558446823, 0.02111447295324216, 0.030252287359607798, 0.013212721302895056, 0.0699282759019444, 0.2801272507396437, 0.15200022517913772, 0.14847609815337967, 0.24706383055496603, 0.11494573971797382, 0.10224174197402694, 0.10802033552599531, 0.15273144078110495, 0.08734916126535786, 0.11511845424050286, 0.0714603521590752, 0.10911990918459431, 0.1003867749785704, 0.10078330974905722, 0.11424116099313383, 0.12434877184850555, 0.18292131112708201, 0.1776753708479866, 0.11850440198735845, 0.11673566584865894, 0.22622231664436482, 0.10952780503899821, 0.1582616303236254, 0.12179225983638918, 0.17670703571169608, 0.13608703149422524, 0.08664305802554854, 0.12542470403376127, 0.17510698447304388, 0.10950710534328416, 0.23748344140908412, 0.10376680086577132, 0.13613121944569773, 0.14058042828354145, 0.11620609224924158, 0.12705398152672476, 0.17241884323377765, 0.14176849275827408, 0.10059933373404127, 0.15082490840746512, 0.16708798976915498, 0.14969967846428195, 0.12649957135680223, 0.11947419269070511, 0.15998598698887134, 0.07805265366069733, 0.17381729077427618, 0.11791680488855609, 0.09803285491803, 0.1324942936339686, 0.10176703559174653, 0.1169909263450292, 0.14143561223341575, 0.08735130631154583, 0.13864852307784942, 0.08190940840229874, 0.11508592614723791, 0.2069726415098675, 0.08655586189800694, 0.1707098083270173, 0.1813991097432952, 0.10684866533284226, 0.1309258665048307, 0.1215720018972793, 0.16738497141388156, 0.16083116583045454, 0.17069748963319487, 0.14606264540024344, 0.18510469235479834, 0.09513960895879615, 0.14823513285767648, 0.20612073641630912, 0.0710467642713939, 0.13706515723418805, 0.16245856640800355, 0.1312803047438783, 0.09097506307185659, 0.18195853778912177, 0.11241483036428691, 0.12631286806877584, 0.1232231665222395, 0.27645762829530623, 0.23814655179458283, 0.11746147286988075, 0.1451055104694059, 0.16767406235298804, 0.15904785103855595, 0.23348604058546407, 0.14915489801956763, 0.14634957597140344, 0.09654148091231624, 0.1853739875819414, 0.21803531885868122, 0.05424965067856735, 0.10904559099505987, 0.19694286518760268, 0.1569702359096658, 0.17750370586591382, 0.0943113836429773, 0.11961519117316893, 0.10635719694677861, 0.12177114645319602, 0.19439951456602544, 0.11516579081334415, 0.188861373030851, 0.27013577881359285, 0.20779125242223664, 0.11816986671258366, 0.12456833264760434, 0.10794431662126895, 0.1773934351700929, 0.21307960332882023, 0.13829174060975352, 0.08331207708726007, 0.20909974591866617, 0.19240031619706463, 0.15356160429937227, 0.09768415467753526, 0.11356246071837603, 0.1760673522949219, 0.1390640032027037, 0.13915562731844766, 0.1130677211368757, 0.13101997274544933, 0.11112895178338213, 0.06542873508747547, 0.12066900640005067, 0.11337368899295408, 0.15920030253548778, 0.12920783772583933, 0.1405610922243326, 0.13158519241598346, 0.040744279000547626, 0.12317841932658227, 0.16779153427529722, 0.12431471157939204, 0.10705174758068978, 0.1643253694618902, 0.1601536223484624, 0.0712453495831259, 0.08294026397408978, 0.2225918719364751, 0.15372251340698811, 0.20271636425487458, 0.05109012787861209, 0.1251956207617637, 0.19380434085765194, 0.18412298132334987, 0.16469313763082027, 0.15836805525806644, 0.092431151067778, 0.17699191316721902, 0.13169037628798716, 0.2255913666299274, 0.11808841624447416, 0.13906648532757837, 0.09058212125373465, 0.1639986329621846, 0.3006702355079113, 0.15626302950324553, 0.12948058034864166, 0.10172523783459779, 0.20099191565907773, 0.12432134590081631, 0.14494109267909683, 0.16885648842059797, 0.21918077352306536, 0.14399952465488067, 0.1596310737753107, 0.17926834343421846, 0.17370239290739262, 0.12749068994796084, 0.10984311916775281, 0.14294431514797673, 0.11272265215314205, 0.17766924214459237], [0.01969258695270025, 0.09346389887674202, 0.04093845547627538, 0.074770487844944, 0.03267870232042286, 0.010475719933428112, 0.02312040715027721, 0.03182512715518956, 0.03512939843799799, 0.07643853704775534, 0.013533815565038354, 0.041581628423544674, 0.033859469807676734, 0.014668940491373501, 0.0741966113808655, 0.05772977744439437, 0.08835541009302102, 0.01192304675632547, 0.017080748070692344, 0.043645109230231856, 0.024120693898669655, 0.030700766721800454, 0.0762766320258379, 0.07303125375220854, 0.0345376989383611, 0.03192753970412718, 0.06369176095411663, 0.05611668738927092, 0.07940633868378016, 0.04204221197494096, 0.053146051227926254, 0.031194891517741546, 0.02780596751930012, 0.04243963540741994, 0.0671335258671353, 0.050874707784744046, 0.019920092083573825, 0.016618789391471975, 0.07882520736705872, 0.09181531596808665, 0.01722894586442459, 0.023123350843126257, 0.03350122794208508, 0.025605289941473354, 0.02569205705977736, 0.06125743613548337, 0.05242103710770608, 0.018285180013927243, 0.031852612474692926, 0.0033557212689981587, 0.0501120978996398, 0.02606936876902417, 0.054203945873004776, 0.05930714481960862, 0.041816231359036705, 0.058774541342450734, 0.007684782622457152, 0.07885733709460305, 0.085396058406801, 0.07065875605950434, 0.04849579410567399, 0.025805010978553086, 0.06064100731765071, 0.030164415159473018, 0.043480488426622846, 0.020357694912461505, 0.04393364858603285, 0.05299562220311454, 0.05106218865201358, 0.043411586478713064, 0.03848880506871689, 0.03477159324252317, 0.03336969830636536, 0.11682614083251647, 0.08441818547585318, 0.01763772846560084, 0.10829755210227544, 0.025114859604547103, 0.02675175392669776, 0.03829894549844246, 0.06650665144045508, 0.037051244909244205, 0.042237786561130516, 0.04878071752647239, 0.012426324387741907, 0.02803966264060188, 0.0983415270644811, 0.1022556234872149, 0.04621798104997124, 0.032884228388748826, 0.01768532933877601, 0.040062533526290814, 0.04335925118216584, 0.03180111412920299, 0.03978656567332726, 0.09755338346886058, 0.008988960649848225, 0.0418238730860814, 0.023568704566587845, 0.03337647435405562, 0.02233417302880797, 0.08641313205683425, 0.01876639239790459, 0.05727718802048795, 0.05085169067305904, 0.02887713080722719, 0.04173131051263021, 0.06502791022461268, 0.0024609834813858356, 0.021047534105638345, 0.017988853374375932, 0.06745657748392514, 0.03399968688045779, 0.10197649169112406, 0.02274405113571594, 0.04139458422639197, 0.01258224051731128, 0.0161180819850415, 0.04144631814391863, 0.0386805760283624, 0.02051751809044471, 0.0174336560491112, 0.03509478275513938, 0.011090611787362686, 0.06063008290385047, 0.038260560662996386, 0.023807023028512637, 0.06006246920855296, 0.02719722639378761, 0.053233197559752775, 0.03657927346085349, 0.02467872766447404, 0.06109550047004896, 0.12022796958204239, 0.020439139634911573, 0.07965589182511454, 0.06835831659695796, 0.03375262352487734, 0.04179255924217644, 0.0444845347515037, 0.029789413205317916, 0.028486732401013858, 0.06338809136181109, 0.046689155766920704, 0.03459510190652744, 0.03463298112394349, 0.04141647518882829, 0.006982325961167414, 0.049553045236896125, 0.02617957817781116, 0.02581263929905911, 0.011244502571982243, 0.05301053410456066, 0.031577694162185636, 0.019251961906951283, 0.06366905793848057, 0.03196817875329045, 0.05591978747097235, 0.09820978292414258, 0.048055795336803125, 0.03676829416485083, 0.014067598817599638, 0.03396442768374278, 0.007757363707623295, 0.04062477311479949, 0.0102840380315038, 0.031104646360261307, 0.01593004953446648, 0.03597805531875741, 0.060909938653029745, 0.05161714657480198, 0.03500814204134288, 0.08432960272916863, 0.0025204946277588005, 0.09563673873462024, 0.008318186512277012, 0.06151461951254357, 0.06029820978461255, 0.04493420538041861, 0.020760716532447168, 0.08630317545706227, 0.05933179752901197, 0.03946510751941993, 0.04226844923029985, 0.0230663021906249, 0.05773950676103273, 0.039804197186904575, 0.03397732094350842, 0.0696073769922218, 0.04447691600709673, 0.06674470560204598, 0.11271750404229088, 0.08049734747938572, 0.04597727622416231, 0.03626675555302251, 0.0394028015885382, 0.034182755081283475, 0.03334904074548714, 0.05527886299176082, 0.024869619538226438, 0.07571336587951069, 0.07505804660820192, 0.07962272021799319, 0.02727001623791312, 0.01000502497904123, 0.03295515663921833, 0.08362811899954274, 0.046391369729873635, 0.011144452446681118, 0.026592419129766287, 0.13482329285433217, 0.03231041321170426, 0.02777438554462166, 0.04345720318416434, 0.02864248765211913, 0.04756338849303223, 0.03449686262155733, 0.05166992237190566, 0.059713684698386546, 0.03729173906087395, 0.07439282948091146, 0.046014630671350226, 0.010923484918631373, 0.0272472289526054, 0.02989062491143423, 0.03835834412565155, 0.03451782278716564, 0.018912096575443304, 0.004367560623288756, 0.07287019908788704, 0.06892552809609521, 0.01926654247537015, 0.03534491046241695, 0.0361145913390623, 0.0702278545847343, 0.11319041777882846, 0.039691455857527834, 0.03143618814647198, 0.034875708421872514, 0.05463556363998402, 0.04590190466373198, 0.03058104633143352, 0.033963293873614846, 0.031228884754161683, 0.0384506500596481, 0.016496339812874794, 0.014055215006303644, 0.043970118201668226, 0.00793274517373873, 0.020226098244048415, 0.13288354290829552, 0.04217386035428893, 0.07417865427992038, 0.06534182241246586, 0.006916020093711034, 0.10108409885076747, 0.009367188791774455, 0.05130031176151768, 0.055736324734865665, 0.05688435728511503, 0.029722742488487598, 0.004710610486536978, 0.005748393408383333, 0.0836328534229148, 0.01106889415231924, 0.07018524477438581, 0.028789386926819722, 0.07216454017907381, 0.03828283083895522, 0.046479423875890435, 0.06005909842168612, 0.0401268542684134, 0.04281646256605464, 0.04911319202473087, 0.012950547820618077, 0.01802855779627158, 0.03409367820788776, 0.01649441884740466, 0.03341881986407023, 0.09864860574804968, 0.04916478804643116, 0.09019949863995276, 0.02585184384858416, 0.021415091600389253, 0.05501484227997642, 0.05052262909650322, 0.0200649305817581, 0.030485314069195624, 0.04302783388524287, 0.038305399789204525, 0.08718080578311797, 0.004808007074790377, 0.018886689269434542, 0.057258434188101566, 0.04870068432102281, 0.0627443285268401, 0.031207395987885616, 0.03504216783649979, 0.03688300050975334, 0.07256753307076232, 0.14568994362508098, 0.05222175848640261, 0.022261616841499365, 0.06273168041521023, 0.03454167493468812, 0.029087194031284704, 0.02552786718062576, 0.04628520143488723, 0.04227882972167384, 0.11351035907864572, 0.031922341797560934, 0.09726317404138465, 0.06267305553680466, 0.05107859442491205, 0.059113983410380544, 0.05116810030754536, 0.023699448962185173, 0.07642749772076646, 0.09584459371023601, 0.07853785544754037, 0.03537172353976677, 0.12420131524484004, 0.05872472264473477, 0.012705189968279053, 0.015544440135389808, 0.03458680517430748, 0.029482110441031478, 0.03053504849723991, 0.014510592032644539, 0.05550129662057566, 0.019201080262240384, 0.035415555260354475, 0.03844947411468433, 0.035791949579311956, 0.06047761225472055, 0.029969478341480418, 0.03023374420140059, 0.008289225515909493, 0.04554827847788411, 0.016772623677107117, 0.031941972800620624, 0.09217832673100695, 0.03739071762069099, 0.023126430516581864, 0.07484325087599217, 0.06570621213364987, 0.058071958276653485, 0.0071587100448537505, 0.08086962790618982, 0.02188175214424489, 0.05802091383825868, 0.03085672307098585, 0.1575293115550472, 0.2549949549739399, 0.1100588342054717, 0.17320045209940405, 0.11932378664853112, 0.152142089340956, 0.11819906998425724, 0.0782550311076545, 0.09104016522366194, 0.30676759058429354, 0.07161816627147698, 0.12197072767922956, 0.1637863193548495, 0.12059032917022706, 0.13939050987603205, 0.17464492620239336, 0.18236949799522278, 0.17325774015438172, 0.10497035563833292, 0.10959809360605095, 0.07731176236824644, 0.09730150908111565, 0.16789861804535314, 0.2078437754103253, 0.14736272725126437, 0.2351987986795364, 0.17243148368452826, 0.13393584128108718, 0.16915897057662088, 0.16363251954317093, 0.14666273739309083, 0.15392188012840288, 0.13497756764052377, 0.0808143929668492, 0.21148100765722416, 0.1256497500223979, 0.21576097235083583, 0.09258727978674636, 0.1491690859679253, 0.16581571690978544, 0.1307811831394511, 0.11696454227691698, 0.12253283703279112, 0.08401200565839968, 0.18921211872610355, 0.1332357748141212, 0.13883622994105663, 0.08334931662125934, 0.17306365943964452, 0.1018105723684834, 0.16872036991821182, 0.13388851236912513, 0.1899006019436544, 0.20032181855170958, 0.16452122750061174, 0.15005508197411416, 0.0969559574619897, 0.23426245537496385, 0.1843582775684134, 0.2905873846142523, 0.1712063865195359, 0.126202221989872, 0.135891908899911, 0.13883322687639346, 0.13225089217866623, 0.07644003091920769, 0.15536983227056844, 0.1769197476847518, 0.14585082208917988, 0.06647512692237093, 0.12172459895091674, 0.09841942288462194, 0.23693723604083064, 0.2950959652662277, 0.383999151207747, 0.07319683599616252, 0.24164409556936836, 0.16740599286652383, 0.09758951217536965, 0.15924639038501248, 0.1491254342779998, 0.11511044096081488, 0.20386897418047153, 0.1556871458888054, 0.19335343682717895, 0.1469337026919088, 0.22597695400397624, 0.15689413273526778, 0.12089615146959982, 0.21938855188988873, 0.21471558409112118, 0.14495318154654196, 0.13191863984590577, 0.13982575506933276, 0.11691620212889488, 0.1348439006194953, 0.14843312062082753, 0.10145585833778305, 0.1148790670859237, 0.09613111825479616, 0.1286782564655427, 0.16099817299794766, 0.1281394208631208, 0.17601213267733976, 0.25094299336835263, 0.15361300879909148, 0.21917420048867503, 0.14911262528790584, 0.16678310209704986, 0.11314091317716146, 0.10188835327543559, 0.1489462309907521, 0.15498513355851173, 0.2240977862909917, 0.1316087572805343, 0.18318979430102533, 0.10492851191590871, 0.1137571772860904, 0.11533704976881705, 0.15029883582986173, 0.10328408120380295, 0.13230353774082276, 0.19426201710537558, 0.2575164720896752, 0.18058310352986862, 0.11633208306926875, 0.11521708806075397, 0.16325568089321738, 0.08746302491354366, 0.133372261038711, 0.16520349008421745, 0.18649252191666635, 0.15524019487202168, 0.20572679868388563, 0.14123049985256889, 0.15284080749317525, 0.15887235561686178, 0.14974487765181452, 0.13080917599220432, 0.08009987042075203, 0.1925229975172589, 0.23204366556338726, 0.1653357934687407, 0.2570324424173563, 0.11333830339173157, 0.2552745770663023, 0.11789642694977023, 0.06982509918030232, 0.09178753761995224, 0.06751444010484604, 0.12069819434996575, 0.09185486908761725, 0.10837976099742998, 0.1025675898117404, 0.1136006118970052, 0.1199388403385397, 0.09180813772423614, 0.11702304075081503, 0.12535564120738737, 0.09790071241197087, 0.1425725633218404, 0.13775874259731463, 0.20877921473114722, 0.11248494273111706, 0.11867052815373867, 0.1549015993312482, 0.06416455977746556, 0.08146612694667232, 0.1926339423704532, 0.15786625234590423, 0.19768290612245762, 0.08502769268928997, 0.24400065863324752, 0.10817310877985532, 0.15258283504555303, 0.13973888069871934], [0.017988861035255176, 0.019565347409356507, 0.06098024637228059, 0.10439585098215651, 0.047322982441513776, 0.025423943523257494, 0.051366287253556714, 0.055458062448568886, 0.035775306319156965, 0.08069626986980438, 0.013179911672317935, 0.08197103251492785, 0.04750015942620174, 0.019661930029190356, 0.050037350700867754, 0.04770229938590238, 0.10561721729895762, 0.02257262555611951, 0.0627482470665728, 0.025486617176342877, 0.019741315890343922, 0.02811750291936821, 0.027228287428677566, 0.04039322303968572, 0.02161926169308924, 0.044121382262317405, 0.021797792738183372, 0.012732652305144698, 0.018764624650019313, 0.050739183000499205, 0.024276031631856196, 0.036486021408270446, 0.02515446060457297, 0.030650375373361093, 0.05936305774676223, 0.04763637368957843, 0.07323029871669508, 0.004881009029509921, 0.02488091550466995, 0.05784250345201262, 0.029677522233537132, 0.03517685758490716, 0.04695534450753082, 0.0034152362458107453, 0.020829606989038088, 0.04816095622616911, 0.02143752073959237, 0.07223326592676102, 0.04854678108747448, 0.042337443108760545, 0.01618997742151541, 0.02247503170022561, 0.00811069255559555, 0.04002161293981537, 0.08119318514100968, 0.07081113860852296, 0.06497014719512194, 0.032144899915663466, 0.025110081131119403, 0.051789707879746155, 0.04904785621610861, 0.09582153446371518, 0.08254218936687516, 0.040001909158402876, 0.08155402787510427, 0.08883065273684841, 0.0430577994144011, 0.039562603699103485, 0.041701812297105796, 0.042054676225469004, 0.07738804174286705, 0.02706372982732231, 0.0385985892987059, 0.01344324960823982, 0.07534385869099249, 0.12584694105410768, 0.05557851828334313, 0.05230276462351603, 0.04358039395282826, 0.013051200282549667, 0.020355042333023685, 0.020901743743208148, 0.0333016773595685, 0.04155302270045204, 0.03708391089833552, 0.0077748276394671734, 0.09751235946051537, 0.054053788809406186, 0.06263635992523163, 0.03198531230971698, 0.05639370861313036, 0.004962579677662542, 0.058016363275988456, 0.041276779055835745, 0.042821388511407765, 0.060330243751166336, 0.05501385785699372, 0.05407518564513134, 0.03588348942538423, 0.026437113955316525, 0.030521818158787586, 0.07262875115679157, 0.03326783159507379, 0.0225314962106847, 0.03448941624693332, 0.04129266771938532, 0.04806067531688079, 0.033846886813520424, 0.03938472957440442, 0.03792614413184985, 0.056708045979781505, 0.026782805385488658, 0.04003079067314825, 0.03501492191947276, 0.025352109373817523, 0.040777986869215965, 0.05102456990449179, 0.05996674269197449, 0.042621339971740405, 0.05123237125395287, 0.03951630900583921, 0.05981759303399633, 0.013760184012954275, 0.07047950680698119, 0.017623117253665003, 0.031718524105306116, 0.04680405746424391, 0.08282928847737851, 0.04442303704338209, 0.08408788666729966, 0.09269869195357447, 0.07339593458680377, 0.058412453715479186, 0.011984833662638502, 0.07917229882291249, 0.04338395368728427, 0.10681192375599377, 0.03861451243621208, 0.021654317876504316, 0.020070501956187432, 0.014685839433373224, 0.0331871893497244, 0.023394714507664886, 0.03755412034450039, 0.07078687660396099, 0.04253005293468314, 0.049428487001287366, 0.03348536226117323, 0.024648942165978016, 0.028779362666330514, 0.16382522129964444, 0.028908595953497197, 0.04265158129255137, 0.05194268031646648, 0.03561474195110702, 0.018759248628010674, 0.024919834686443213, 0.07922449239319371, 0.01721899438228819, 0.10229184412427487, 0.0492685278426976, 0.029930840697019335, 0.060663066819430365, 0.023811529540727218, 0.030445410464439663, 0.01791174279435748, 0.02542857643997958, 0.02767699278680788, 0.040049835618945866, 0.013674198304333035, 0.06054170700090547, 0.016891351983612104, 0.0011739376937076752, 0.08297035590775552, 0.014446058701122961, 0.027310291395312356, 0.09811875635697957, 0.027499570653984146, 0.027292644559976556, 0.0458015050108154, 0.0366711963508879, 0.03517977254945905, 0.05443920381367207, 0.003113540287520136, 0.00995400543850396, 0.06261471028049147, 0.021012269163263902, 0.057707890312397675, 0.03496598422286972, 0.019703762260295694, 0.038765297691908576, 0.04572703743413572, 0.026565812896156026, 0.028245156150191065, 0.02146034632929631, 0.037877807814267375, 0.007531653616517302, 0.008965550918102024, 0.0768919385248615, 0.06132554518239153, 0.016311863925488248, 0.01070284297794945, 0.013019011183191213, 0.034990407105895786, 0.046873104968859304, 0.042955614776620944, 0.06581012429969926, 0.02041845143051638, 0.03162435274721394, 0.039536257935387474, 0.04739936906844378, 0.06866194022398803, 0.0509158275540798, 0.04617340622409698, 0.024572781534985672, 0.0908659644905598, 0.05272431599517023, 0.04532801670833461, 0.03839852926771968, 0.015928614077218357, 0.012951486278325321, 0.06577066311071958, 0.05358400071159967, 0.0544403376238, 0.050059168884951266, 0.017035916605363452, 0.04166719661424718, 0.057832050182285814, 0.08803914601524031, 0.07273663165828875, 0.01667916669600433, 0.012351090723137942, 0.028988431891306277, 0.0491880617975708, 0.03544151414966872, 0.01541483721079966, 0.05793322358400591, 0.031015161545045918, 0.038142429905072335, 0.06939991272144741, 0.01760679766565802, 0.08873119154163907, 0.04504184456421964, 0.0407227442689961, 0.01768918276103514, 0.01978634845375294, 0.02920223362443428, 0.017241266473466833, 0.02895077866982789, 0.022864539529226964, 0.040941780297866756, 0.029330595486587095, 0.05435865732931322, 0.03356025118621127, 0.07843508475249814, 0.06530108951753186, 0.06107145680054542, 0.037220577153587536, 0.047062547021215005, 0.018960687617260604, 0.041485955533120907, 0.03255806645498641, 0.06582304820298188, 0.07749656575822061, 0.02181805384856078, 0.07238145031395458, 0.019316751877927495, 0.02436191008816804, 0.04729148473650698, 0.01749618606071078, 0.046586718320125536, 0.07277109029312288, 0.02726861429701169, 0.11572323469144684, 0.0545571162365377, 0.058159583413432685, 0.04840572897885596, 0.028256492336250605, 0.02140078107796369, 0.029815218877047304, 0.009519963960854277, 0.05249965688093536, 0.035635127550772125, 0.036341709595534115, 0.04553510942646573, 0.0810317550936053, 0.11442662321872289, 0.06052774121804584, 0.07353612101606785, 0.023449683231451822, 0.02038777727002819, 0.03862735590026264, 0.024011099275441903, 0.06135450330592933, 0.08434557566238989, 0.023423442804825403, 0.04189398545291155, 0.011857988654575762, 0.0435408829681335, 0.009887951422452686, 0.0007540670471386083, 0.07700906570760474, 0.06112966416103225, 0.09246137323639086, 0.0181665493836326, 0.06673535932936976, 0.0396921836410559, 0.016677104004268205, 0.06553270087967958, 0.04763392603866035, 0.09760163934721101, 0.05337703822841568, 0.04495895385081249, 0.06629168716890198, 0.07976502104992829, 0.046429417486633026, 0.10104388689562198, 0.03450731589128414, 0.06311459414240334, 0.02614675131025574, 0.046555481085013, 0.016948350840398384, 0.03817916765148121, 0.008842367810317346, 0.04076247741918891, 0.02137720472209396, 0.07608811310943096, 0.01367529093723504, 0.0024559905033393376, 0.07774906067718422, 0.04093368274850711, 0.024559317539716442, 0.014794407498782441, 0.06924798216430411, 0.00999023469405309, 0.07777278642019919, 0.05927565477548107, 0.01608229993331817, 0.06581485106219208, 0.0697717794607724, 0.02283967614564444, 0.028996627116876266, 0.05115311179730681, 0.03458852121125787, 0.0791401384518512, 0.06958106187202277, 0.04643962560822407, 0.011148791377162261, 0.02578024718640072, 0.05545233211089527, 0.040976078054236795, 0.05969157923133143, 0.15651508775209227, 0.13103172453420778, 0.18334926316334357, 0.19737984173961226, 0.10333569254726173, 0.16234569101324006, 0.12525407327038626, 0.0921869988463098, 0.10077302884911338, 0.19882765598595145, 0.1230373059309298, 0.14651420826633132, 0.13533586696270974, 0.12495799560941036, 0.15874674784079676, 0.20565115516224217, 0.17073507390676007, 0.19579950960413103, 0.18024173475080923, 0.10716783288385599, 0.11387639588886693, 0.1554933562874794, 0.23867824745755042, 0.12636912190505575, 0.13020105539791046, 0.12551642774093535, 0.09485250218741356, 0.10219580734208708, 0.11165132415631127, 0.15188131301153093, 0.1458605054405428, 0.13772262921256406, 0.13140050393919792, 0.10276435183421259, 0.11608277507607015, 0.1701632812018356, 0.16833465997009509, 0.14670110307633877, 0.16324429682666258, 0.18521263414332945, 0.1441851630806923, 0.1558303430436119, 0.1372527262015689, 0.20168789121652805, 0.11728306631407431, 0.12110325567904981, 0.11392299701730091, 0.23141495252568878, 0.10489649710155304, 0.17487150436687857, 0.08869937591014371, 0.13858015739148663, 0.17682263837947002, 0.15719378036597084, 0.16422551756183948, 0.13998398286921365, 0.12526219380238365, 0.15071214026501104, 0.1569362522493447, 0.2145196188000902, 0.21466750441299332, 0.13031244458210084, 0.29973894838363896, 0.13715446776440068, 0.15301933662304956, 0.1868060357387989, 0.17701477323087955, 0.08338774359154125, 0.10944252413126732, 0.12947664265671086, 0.13091751614645605, 0.19494950440862488, 0.15955069583029519, 0.15026495942185003, 0.20443895891789468, 0.18729077021200813, 0.1692483883591429, 0.0885708186955702, 0.15018050588907736, 0.14277171553863635, 0.2742761469656422, 0.15794137492775917, 0.1458726249515049, 0.1052974445384837, 0.1447190191116064, 0.14342364104044053, 0.26522052804789237, 0.10892877790836558, 0.18444498339968343, 0.17889199508053644, 0.19394508653110076, 0.14193366131474897, 0.1829004582137831, 0.23622672013457746, 0.10726963064723438, 0.15841049652907158, 0.158035266663759, 0.2510308636532676, 0.158535169677869, 0.25315904058516026, 0.11907086272032992, 0.14645701214190454, 0.1476166241111294, 0.09163983586815097, 0.09641195076607889, 0.2684709778235805, 0.1381388907471011, 0.15431583318258488, 0.12709191053985588, 0.10768125734982953, 0.17228039582410168, 0.14172197589951177, 0.1467996985921937, 0.21798216767849463, 0.13847051488776363, 0.20018795234782083, 0.18595943197367654, 0.10971941128974, 0.11295276198295817, 0.1561159099782667, 0.08807790240332966, 0.17192863889278906, 0.0818131341328544, 0.14683749737037768, 0.10518408650832792, 0.14998363661429576, 0.11363872477123815, 0.22997947229493051, 0.18283066760388114, 0.22098748464017148, 0.16743418490213735, 0.17269598320126536, 0.14859124116839903, 0.13248707708572188, 0.30223201299386643, 0.10349290145020332, 0.2619661559020319, 0.1994061596210926, 0.1585887039020177, 0.14888500524384363, 0.09047141388779686, 0.1337432314551646, 0.11611969285314122, 0.10196818729802486, 0.17072915970798463, 0.11540686336135673, 0.13701672515561505, 0.1350791049340079, 0.07741174450324428, 0.11556728217270106, 0.16573737675864852, 0.20667368335829628, 0.12969131581485271, 0.22700375697064787, 0.165069792419672, 0.11943121515815297, 0.1552326106015713, 0.14313130188853512, 0.11050778471173779, 0.13196592279259237, 0.1352549067908718, 0.089947440391106, 0.09505174633476043, 0.20704912772822767, 0.08826047647744419, 0.1284906185502487, 0.1059906238750104, 0.18409034597777552, 0.11100008047275967, 0.150588141273587, 0.20871343842196852, 0.13226714856441946, 0.07557567689687976, 0.2598576061427593, 0.1349846769364611, 0.15859547611926833], [0.0347887076467516, 0.05115245296169193, 0.02557656738997227, 0.01907143328759459, 0.017711157993143125, 0.052626440601964156, 0.030308129423628413, 0.012045527936049528, 0.010596935152857295, 0.026823691498007507, 0.007811025293889426, 0.08110521526466455, 0.06481113798555828, 0.03714332867774271, 0.048190722572467024, 0.029207573257266518, 0.02765156058294158, 0.04840631120567841, 0.022860772291859312, 0.0453351911217455, 0.03823016995504018, 0.028414101520132636, 0.02409041810390209, 0.01744095686702959, 0.03360536227363252, 0.13348804756758675, 0.01829362230285281, 0.0096970796585083, 0.0335795144670673, 0.034604164726671674, 0.052705972019823334, 0.01872238639231411, 0.027717340722559925, 0.02768491222072513, 0.023264998585105907, 0.04366841362488847, 0.016066508945978938, 0.020268326925654567, 0.01215779620613302, 0.058460556376244754, 0.03255636957023413, 0.03153090534221021, 0.017476830849303834, 0.033788265765554486, 0.022402364430167986, 0.022672929448045553, 0.020214647144800233, 0.06712845436507656, 0.03969090427422235, 0.06082903976822573, 0.02315889732281287, 0.03995121329001362, 0.017747162210364497, 0.00877420322203468, 0.00896956809165497, 0.08598328012252048, 0.07203729297485083, 0.09840029366915265, 0.03497402048519543, 0.029445253950994343, 0.007533260007133528, 0.02745002774792093, 0.03673850483591518, 0.07417895305421084, 0.055295877804559086, 0.03249555368036513, 0.04384518841341619, 0.035806639315260035, 0.025353432790706718, 0.057097532741364934, 0.054394943083846764, 0.016372587884806337, 0.02476512131491496, 0.0580008193520048, 0.022077411000106125, 0.038399188103334564, 0.03684189223173646, 0.03429429365261909, 0.06732716225087643, 0.06532903640500962, 0.0802811804497915, 0.017048827102107388, 0.05945570075944547, 0.01449711558844654, 0.008240508069584688, 0.035130317743507125, 0.04265265381564537, 0.03133295013779595, 0.0277065982546417, 0.024609741446892583, 0.03622479308697005, 0.05326490593893875, 0.10623017956893291, 0.03690887512939592, 0.04127709698232432, 0.04490839970868923, 0.02979944895712599, 0.03366003030790918, 0.029328370001167062, 0.012923663880135263, 0.06380905284576359, 0.03805051467591717, 0.06873820427685015, 0.0896610843858892, 0.050806177389477535, 0.02895536945171414, 0.07006387346454206, 0.0368567734896656, 0.04821914826489745, 0.04449582305706797, 0.009369176789937962, 0.018261881364930063, 0.0756824772144037, 0.018831023405636513, 0.026478432907512593, 0.03407092539653663, 0.0209891275622912, 0.053203438874334104, 0.0795190072348041, 0.01828033642302598, 0.023681805957288995, 0.060941773436723225, 0.012484567179795236, 0.015856765563629808, 0.020886577117527207, 0.03906037177770369, 0.049874457425528, 0.08256873431345148, 0.027492126194579948, 0.04816170316189528, 0.08749253462038695, 0.0814613618797833, 0.0598055616231455, 0.01872665158683254, 0.08735967965255823, 0.037150866982917634, 0.04544711273704325, 0.03246467267613738, 0.028853274829265092, 0.01616599120860619, 0.06918991269964365, 0.023217635199187264, 0.013019960174607414, 0.06317596161557783, 0.04507479017540332, 0.015515985714662221, 0.05057938855081316, 0.04976091553427039, 0.04883404107644193, 0.013529498659585033, 0.034745385374633536, 0.027221653107253295, 0.040198747789667505, 0.06845225429823322, 0.04762316633376384, 0.008429422478882537, 0.03703041114814339, 0.031763487720801946, 0.04834048510078461, 0.027932743579449675, 0.02266070843043347, 0.059671480914637934, 0.019234156108371193, 0.10012039854641884, 0.02067798861272393, 0.02021693391725421, 0.01626571861936921, 0.1404526141742545, 0.015370309307810762, 0.04127024049540201, 0.014202099916855655, 0.039129721887049176, 0.016646506452572443, 0.03696195353122969, 0.059841766938447, 0.03990912824989327, 0.04995566657594135, 0.024524878057080413, 0.030015845813097495, 0.026614844438529787, 0.10307837127437515, 0.03948274669387648, 0.016525179192784335, 0.03276199522999025, 0.041377875848763415, 0.020446925003442074, 0.08890323190679474, 0.030456128034500346, 0.03888912048311003, 0.0338178712333883, 0.048106491205192385, 0.017090642096234426, 0.07387094740425387, 0.03278513491574315, 0.03690876787708652, 0.015924356543579172, 0.08707664080805357, 0.03120450783641108, 0.052426369079659065, 0.027947488856772264, 0.1008099542870637, 0.08111924999543736, 0.07059292612417091, 0.028135360428883184, 0.05915808326174175, 0.06237474472952947, 0.0016066188864868076, 0.018022946202226223, 0.022187022860312176, 0.018745508841088703, 0.024080640906768463, 0.05004760478773425, 0.09129281336021039, 0.031594977105757406, 0.029688712862891056, 0.08096532760969094, 0.028188130480327436, 0.08738738905277946, 0.028552043311778578, 0.05134109828260638, 0.047874860690846566, 0.03489657282649029, 0.08475622943332119, 0.048850335766591375, 0.029291201330300783, 0.03828411403622839, 0.02462781537624617, 0.012979131518682886, 0.013552430543988464, 0.03441419407364822, 0.0411497731693089, 0.06632315039995217, 0.017622437350632205, 0.05366956890230218, 0.0176930055397773, 0.025582751634741024, 0.023605578293603276, 0.04829674531074782, 0.030551358509147843, 0.04647537127077099, 0.013374601426954954, 0.09584383528319099, 0.011231822859225495, 0.058964749482730706, 0.03341438421498864, 0.01841483464945228, 0.06835365878237833, 0.00931041784614565, 0.019011741631754467, 0.04439381078907079, 0.035609858140589735, 0.007466269448594822, 0.07010967786153478, 0.08218764387551816, 0.06430605621708017, 0.06521791535159273, 0.027128722811598453, 0.08064562379713021, 0.020369115368192716, 0.08129461518218441, 0.02887828759999285, 0.014992024666900116, 0.0038813861441843577, 0.028635753739264705, 0.056228149351814104, 0.03401264142725737, 0.024240697741568572, 0.02229421962833693, 0.0331863658052058, 0.02631856184903412, 0.009257162286479388, 0.10449107571114456, 0.023863659908754692, 0.036740703508257866, 0.02079333464104322, 0.03233140785126917, 0.021392189401892886, 0.10376124672832028, 0.025432479657953786, 0.03510190737283519, 0.013451839369090815, 0.04918206715956331, 0.032216149923061176, 0.021471797428544492, 0.028060138255598086, 0.05851847645375998, 0.014286491204984488, 0.015126961478663069, 0.10582082048659364, 0.01923772416287853, 0.03716736851680664, 0.015965465779205965, 0.04785788035200489, 0.05261118396095211, 0.13096553453754994, 0.04418439299408947, 0.055529523130145766, 0.0445578953311328, 0.03142059634199306, 0.025939809894489668, 0.032445317464730436, 0.026351068874881155, 0.04991938465184743, 0.01196006891287623, 0.04733870639615963, 0.04484580649483589, 0.04316088420549228, 0.059023933605320995, 0.006330962576377656, 0.06614877346662745, 0.045628859436199556, 0.028598788081698363, 0.042501412737633915, 0.029023451685544946, 0.07616763303597128, 0.047655066234930876, 0.013760180182514653, 0.01149372533789926, 0.04370990111642788, 0.04003096304293122, 0.0114988686607009, 0.02644250721430346, 0.029543309374862624, 0.05429471580071315, 0.02007662491392224, 0.0398148687916898, 0.03944586722120162, 0.022469492884533062, 0.01266165606437191, 0.06719320411643676, 0.024922376183132013, 0.057700014928536075, 0.02819246079231943, 0.07089716262154042, 0.03679372445349732, 0.020056398277501428, 0.008377498954594617, 0.09833909856576113, 0.011442853269287416, 0.06065245650167908, 0.04648850584823278, 0.029216798871094664, 0.03684533196651647, 0.056577577375836914, 0.028640421129943385, 0.056695953281896735, 0.013711115123794205, 0.03253418366394697, 0.03537830423503634, 0.023529063346945954, 0.0320196426248238, 0.02780066810608391, 0.13671563727961433, 0.14289658787029405, 0.09087414630959112, 0.06868542081886722, 0.16714780591428283, 0.14498681280641787, 0.10027386127941071, 0.07981290154519581, 0.1398696672291525, 0.16040207998406503, 0.12572302633235533, 0.168900630406795, 0.2736251560911056, 0.07428807461814535, 0.1191491032800367, 0.1215508808532069, 0.13473355331488196, 0.10332045505844778, 0.058778896552300265, 0.1027299544864124, 0.14041470814376109, 0.20440522040570938, 0.12269456585448597, 0.08055121878222113, 0.16850368960970835, 0.20505064948191568, 0.1192788785744098, 0.08865284372962291, 0.11189698557099027, 0.18419028980837715, 0.12256180281720816, 0.10880143877359168, 0.17536419083274182, 0.13756513685709046, 0.11540938379062761, 0.14292269614675354, 0.17809005424139962, 0.0874282751652983, 0.15443007221385358, 0.23603766495662354, 0.12593003095037517, 0.16347259102809816, 0.10339714045966826, 0.1934474971025221, 0.08529727136896503, 0.15400196696000715, 0.15741105822305526, 0.17101955299656238, 0.08766039214547604, 0.12768876198078358, 0.21336296393025309, 0.11509848232831686, 0.07829038606536004, 0.20340067995411737, 0.11514728212909353, 0.16144110971400816, 0.1729654163242348, 0.15916884696531683, 0.10579845071920466, 0.19881700736380395, 0.08892419973328229, 0.14882544956861005, 0.10710725831168313, 0.16802053327762312, 0.12532837613816225, 0.1449920068825445, 0.08734547638244207, 0.18410577498857053, 0.13930040261437818, 0.17854029943625774, 0.46054880164804, 0.1345723071285794, 0.2025841068356268, 0.11293030028501827, 0.14506070964759396, 0.07429687696839533, 0.16846212167893687, 0.1389431604935277, 0.16241937334979736, 0.16640177417186, 0.1826323580838019, 0.273040171352125, 0.1880599531315027, 0.1074530627398241, 0.1184094990152986, 0.1204491621484199, 0.18436881893825147, 0.11844155213405048, 0.1382994321325133, 0.2031977892282509, 0.1441426911661702, 0.19424602118951662, 0.1377819857049373, 0.18767919211137682, 0.1507514712190436, 0.14524503040217585, 0.08744661531020557, 0.18049779197862073, 0.11923441483128457, 0.07632465807781105, 0.195312446223632, 0.21938427711927125, 0.1788330369538838, 0.17383486483125918, 0.15186782986406358, 0.16835079378178044, 0.2136665032876115, 0.17653714805360765, 0.13796578551973068, 0.1286439663700519, 0.14157410560836717, 0.22684468647405026, 0.17626376191694892, 0.1835943040468039, 0.10998477648583152, 0.1055885962541065, 0.0932372977296191, 0.12208629970348651, 0.1745900436634979, 0.10211193603613686, 0.14931214522690545, 0.13454986075239797, 0.20095468378595768, 0.10378334070405654, 0.09225439160100876, 0.17846525346319522, 0.11920662882227091, 0.165000630001868, 0.11719963167824092, 0.1897072566733245, 0.10122711980535139, 0.16033661011005604, 0.08684560401184906, 0.13133989106262886, 0.14546466781006706, 0.093847218630535, 0.18158545296999717, 0.08186868316824399, 0.15012851916253567, 0.13782928397338237, 0.16103460813962645, 0.09145867905669636, 0.13506597418698574, 0.22346338888089504, 0.20694843313146025, 0.11384519312771098, 0.14378043883029493, 0.2123294040680893, 0.12058321987428974, 0.13307601483839174, 0.13270772572967315, 0.09161814791901458, 0.06786981297116126, 0.13361468190147033, 0.15784832588847608, 0.18136169400907334, 0.10610788895358002, 0.22914629039024154, 0.1477063789723381, 0.09338566597791449, 0.07838596319479328, 0.15656496007596293, 0.14058850285026336, 0.1893972208903682, 0.18218077989595552, 0.16511019589679857, 0.09075941698205087, 0.2118625347652743, 0.10317476045700813, 0.191631730826151, 0.10581558810607081, 0.10526719172635388, 0.19150626094591236, 0.15201960720362204, 0.17094715768771787, 0.1375722308312693], [0.04829164699561173, 0.014646873328714602, 0.043884182288762064, 0.07207215763628483, 0.022666607307450428, 0.026571255950858037, 0.05421893438324333, 0.02644258382309589, 0.03355442125710749, 0.031499493822094896, 0.025227206398642836, 0.024183074523124005, 0.048508411573786894, 0.019845448306671554, 0.015776804178923128, 0.06055831578710388, 0.03088460867142966, 0.03468610932149234, 0.013204130584434157, 0.034899993409072204, 0.012759331317107766, 0.03385987966471622, 0.008775120612324007, 0.041388861549597596, 0.058053537692514166, 0.04512370105892901, 0.053088640598880674, 0.06614478980942119, 0.04297725676048187, 0.030196996878892667, 0.05387304568543069, 0.012740001003558358, 0.04272716735760051, 0.04603875861052544, 0.04353058674643117, 0.054713394342651295, 0.04256311345905547, 0.054643691832860636, 0.04780505858962575, 0.005459221551239852, 0.0381870047309466, 0.016073932337965217, 0.053481099781610315, 0.025566851479872584, 0.05434783250694314, 0.04661231331767575, 0.037037849861888156, 0.035008900468387914, 0.02832012168402153, 0.11520760389225138, 0.027419928153375947, 0.02667330843847125, 0.015026404777722014, 0.06781979509058499, 0.050714246838563876, 0.05960379321608813, 0.06398587743000639, 0.029035299235293945, 0.032041813209352475, 0.07402388919745723, 0.12571651458499894, 0.07777067201752817, 0.04418508247322133, 0.019805186555810997, 0.08890327021119096, 0.022145085292117252, 0.024828919202029228, 0.08480307570989094, 0.060648020852597496, 0.08901817573895378, 0.045961414373690085, 0.027290932353465792, 0.03628619886454075, 0.015143546324613837, 0.047287803684030814, 0.011926273901706502, 0.012409375650027107, 0.007463123700055745, 0.059132289081331224, 0.05705424877364309, 0.0392003666849867, 0.07473869519608636, 0.021113279771300095, 0.030058191323112098, 0.02737341320983345, 0.014218202127414125, 0.0669950018486669, 0.04578718299707098, 0.10716616281218107, 0.05593538885155032, 0.031937062177025986, 0.0708999358598263, 0.030522657025064674, 0.07047517074932975, 0.06882864861719071, 0.020046973480812965, 0.02891750555605658, 0.041811175178736455, 0.005562522762169641, 0.04473242548204238, 0.010015214906044064, 0.018536592833697796, 0.07360196627315975, 0.012906690244562926, 0.10945442147673139, 0.05836363093206479, 0.06204660245848279, 0.03401411231607199, 0.050045026901869044, 0.05219273524539125, 0.05046204686345113, 0.06375720784548791, 0.06524376315815796, 0.008451427396897589, 0.010227529470989061, 0.04450539915612148, 0.06183210167012388, 0.05649271398602475, 0.08325143356717403, 0.05198589916671476, 0.05067193197206624, 0.061976811848580844, 0.04119799840414236, 0.06119754721200275, 0.04417519610855849, 0.023254384436915, 0.05993870770438545, 0.057218628259555954, 0.059514214555102016, 0.08886530289366361, 0.03476221632632998, 0.02507109874709239, 0.010488731936822015, 0.03046883743316416, 0.03706194332710678, 0.017657376705638824, 0.03316580017487849, 0.012726383790704272, 0.05413762564139982, 0.020746622429860216, 0.05648048722275323, 0.009318685850068446, 0.03205136058010882, 0.014439940531437677, 0.026972153592073632, 0.03667526427776583, 0.057306004417759765, 0.035050441586082025, 0.013118382363069444, 0.02784056979562006, 0.04355662990541708, 0.005105062455479657, 0.06004096895095803, 0.0677923614820165, 0.03667823286847242, 0.19326270137342716, 0.018948177401457104, 0.05461081516959014, 0.06883916700439108, 0.03123487939216918, 0.0800631211830243, 0.02460772088999229, 0.016521300872667663, 0.053797451959502314, 0.055331294049298575, 0.016115686045058312, 0.022894491651846517, 0.046623808466979576, 0.023142566243487022, 0.08101464835025611, 0.06588422032373567, 0.04696389787920541, 0.003107551395172073, 0.04689108122200255, 0.03117913500435891, 0.0041878263413485505, 0.052489866277263056, 0.04565815080798442, 0.11493876831786287, 0.037922486062011415, 0.008217740894084977, 0.05689229395601058, 0.08726773377988609, 0.08144714328790865, 0.04880380358607058, 0.06492877844721079, 0.009707478344470504, 0.05713307539061193, 0.051216980547554074, 0.013951056734508565, 0.019546377157131513, 0.05216513309747942, 0.04167160545025141, 0.05407844151880953, 0.04332038371132747, 0.04672698901906129, 0.017883956785343828, 0.08665677099939316, 0.022042580812628713, 0.04498500084023803, 0.12386533206388836, 0.049509803404010115, 0.04842837070745807, 0.07724197175834449, 0.06208760348419028, 0.016539790404720173, 0.021086376678619175, 0.03234432026323292, 0.01425292697780195, 0.05483233332333546, 0.06710563260581225, 0.02206685430850954, 0.022724257338972344, 0.06533841332120281, 0.06366923796914278, 0.04743486192197569, 0.05567565823214189, 0.02817948517810193, 0.011139091746430966, 0.018700277094819376, 0.04769668396141741, 0.0007054136409762226, 0.04759223553382101, 0.012159971895837977, 0.04549492811483722, 0.014083761357582145, 0.02285973424272191, 0.04918925306429306, 0.03276293751813712, 0.06970344441792659, 0.03609605201129471, 0.04226316705406193, 0.04237913744403951, 0.014613652883488086, 0.039346528600060174, 0.0607758081488071, 0.020657547471684315, 0.08327089220045075, 0.03864420600415718, 0.042933900014407216, 0.02192697814485479, 0.022346591314060554, 0.029966572953027584, 0.01672406710924641, 0.022420528374852675, 0.050038541967590014, 0.042846880087088195, 0.055881755035971446, 0.05973637239226411, 0.00595048883922338, 0.049613213782469114, 0.029626481625581944, 0.039586260494205265, 0.04547284563041983, 0.07114404977689828, 0.01538807201394511, 0.007757176494886799, 0.0190235240640299, 0.03338831041248576, 0.03787808360592012, 0.02731682995574609, 0.05733776642310043, 0.024244202593822154, 0.024966378358282873, 0.06727111525833607, 0.040845755006997816, 0.04099061074216039, 0.052387260291124546, 0.05540622893961207, 0.03999014204788593, 0.06317357525169369, 0.013498193434169217, 0.058608323245519595, 0.048295002460720084, 0.056459220621975205, 0.038616718769434004, 0.03682978038165358, 0.016197063734815005, 0.0422892906522799, 0.032148504359347206, 0.012793993922851741, 0.049961213052513144, 0.024049622006714347, 0.04633030486142924, 0.0336553993064069, 0.008249676226818515, 0.010915160415724162, 0.07011810482870187, 0.08297195703151726, 0.07080814320473902, 0.03739437952096905, 0.07092857222643591, 0.0208410274447693, 0.06901041829898473, 0.017073213595957044, 0.08853704187898867, 0.03490812160194882, 0.04247745716824167, 0.03094696439802647, 0.04852266463961813, 0.03760935528384101, 0.0333627077540563, 0.04818638268437597, 0.01432658537411161, 0.032727961773954095, 0.06884906486037277, 0.12093612593748879, 0.040101454623283884, 0.034601284236076384, 0.038857412103924065, 0.054694280448940494, 0.08301989115293949, 0.03182185787497269, 0.01975904124969196, 0.01544780963506069, 0.028855825902052948, 0.01216235825972211, 0.012996412547034843, 0.07158676432746072, 0.062432860159465385, 0.0352618933445023, 0.04686881870692296, 0.11093873215178329, 0.03746596660705344, 0.016786597120845993, 0.03755351513504021, 0.08717597942919501, 0.06984241276739106, 0.054345009472942164, 0.013311024747728823, 0.0216162835262836, 0.08324045552721909, 0.0249981690919207, 0.054517750808548544, 0.007953622506090231, 0.028521112511835756, 0.042170363162914594, 0.01870024070564297, 0.05355115086140652, 0.012201484285234925, 0.052829986333005854, 0.03813758822939089, 0.07062779078560491, 0.039336094482531475, 0.04779311527888622, 0.06828120218649988, 0.08209527665448767, 0.06619655437046482, 0.09953403484917457, 0.06306275297256728, 0.03411654210198791, 0.07817906582908285, 0.2634988220468644, 0.15885504202977305, 0.2527838107198477, 0.10457984997981018, 0.14359492297855117, 0.16709451683826987, 0.20085572054789913, 0.11560537972517552, 0.19793992862105372, 0.12934174989500355, 0.16070324446885817, 0.1533639536149079, 0.18530306316191153, 0.1920344938914622, 0.13334049903337034, 0.20713450056650948, 0.09648492830174585, 0.13961172542504727, 0.08588456969347694, 0.16508168210425686, 0.07449904757161295, 0.20947203400634953, 0.13198862963866803, 0.1344465461349295, 0.22096194326877597, 0.1343048505124546, 0.10641378786174521, 0.18482804268358216, 0.11123510092617044, 0.11883299241984084, 0.1747864992508004, 0.14113930474606254, 0.1569475443853486, 0.12614474241291324, 0.18092698507731964, 0.14952091950803034, 0.1113051979712421, 0.11585032867808497, 0.16808436372347418, 0.14172808928114755, 0.09312714960786606, 0.10248061584969682, 0.10151051105030122, 0.1011961775140897, 0.18127385436767535, 0.15120415257350092, 0.1705577705175646, 0.10045284240116036, 0.1615332547695406, 0.22065829665910816, 0.1646585411001598, 0.16942239757026398, 0.15061150695527756, 0.16084683998938532, 0.13486026425755795, 0.1956272623952358, 0.1694795630511738, 0.11405924575463419, 0.11272629873166162, 0.14463997415957913, 0.15707666084410685, 0.16284769310826258, 0.07826665266146583, 0.16390233571010251, 0.17599975269648338, 0.16857481321259854, 0.1320391607981536, 0.18354671466494762, 0.14517508657468906, 0.15648453616567198, 0.16017277454656942, 0.1671649816055452, 0.1826318218222549, 0.12885376720899536, 0.19831436175492503, 0.12160973938842937, 0.13933354357798255, 0.29714187967681116, 0.20512532773277453, 0.1401731299777185, 0.22398541651425824, 0.15376371361555594, 0.19228236930024242, 0.19518470872313748, 0.1901459186187675, 0.12208426957048717, 0.16040790225228957, 0.1700347929351753, 0.1356977056111059, 0.15928186025590668, 0.17742726561282912, 0.1391289521369242, 0.0902373587051707, 0.09821541367038604, 0.3060921768267309, 0.1542525543200393, 0.1414254232640228, 0.1724265500782959, 0.08753745801626675, 0.13523535622704413, 0.14629513776350409, 0.10683435481041671, 0.14193107193756488, 0.13524215908781176, 0.20550703870192652, 0.14054125054709374, 0.08176926027743087, 0.10370781209560172, 0.1477946476229737, 0.17070767860258781, 0.17863322590147296, 0.22332840418863684, 0.18953940680911466, 0.13188914546082098, 0.16031712083326233, 0.12713820523312017, 0.15300750822549866, 0.24060088299935867, 0.11050508808224432, 0.24981151214770733, 0.058207421773864385, 0.10599096861457634, 0.12068471886337766, 0.1716778523498966, 0.16320289743523445, 0.12315357509519785, 0.09425017321782728, 0.13544288944573174, 0.1636647258795077, 0.17752564662406523, 0.20025287063852434, 0.09467668500879119, 0.08821848719831436, 0.0953353750669668, 0.23559547900672884, 0.11692699630774799, 0.11538868409491355, 0.08575791237695564, 0.1199505997881774, 0.10671181904692804, 0.08190716376468059, 0.09702565614134075, 0.2029766502880281, 0.10438047559751619, 0.12574119027704, 0.2194933527179303, 0.15027156309975734, 0.18583118885515199, 0.14199939165865222, 0.14317343672437055, 0.14764677733182907, 0.18152307809120227, 0.1437846216703615, 0.09349749949310096, 0.17561424193122696, 0.39887740607223204, 0.09817877934584696, 0.1652631836552774, 0.15220167565970652, 0.23197808843706888, 0.13332629576325417, 0.10105798291342874, 0.11369369924068452, 0.09450275240646255, 0.13344738362056593, 0.10622398957850472, 0.11085859935490355, 0.18040935478864178, 0.16995041601119504, 0.18151647441329496, 0.1798424956899497, 0.18398600480248853, 0.28966532118858834, 0.10058404261907263, 0.12519733679871406, 0.08286634415027597], [0.019903895069634723, 0.039930720438039115, 0.022356311054599863, 0.01287910437601949, 0.12092989764266437, 0.029120413518901316, 0.0421169055475583, 0.015132009040474173, 0.042040614681618835, 0.041758441516468604, 0.008526718518095873, 0.03353942125555008, 0.042445392558170904, 0.01146554958165413, 0.04248304961008891, 0.004529020356600203, 0.025863141730247487, 0.06048747946718528, 0.04820190745616152, 0.0345146473527195, 0.015433958765389699, 0.04340445420013801, 0.0193016656914786, 0.08090145885944366, 0.019570968579500914, 0.026423230526908755, 0.03626665213115273, 0.05914448520108577, 0.03793066788104273, 0.02491169117180811, 0.043005900787970716, 0.03361955788286944, 0.09936341174667883, 0.01103775267819724, 0.01625612719855722, 0.02898155433696605, 0.06146926327698654, 0.033958927172446446, 0.028398492478675423, 0.055972161071915785, 0.062277440071826985, 0.019258431519471833, 0.031422881199227225, 0.04329339443375507, 0.03383477113299793, 0.03521315100031995, 0.05571626472256838, 0.014022765437050933, 0.02004248229035687, 0.017169600863370205, 0.028284159601635994, 0.07516799554709466, 0.018023415431079846, 0.012209606732452109, 0.0470259816445891, 0.0808158791774223, 0.028895156856085506, 0.007263653556771217, 0.01776707666595617, 0.03686922624887478, 0.023984496872271263, 0.07704415253453678, 0.028915747384270354, 0.03683859422322243, 0.05505049984241205, 0.0393021836005632, 0.047963451098410353, 0.03539380219374453, 0.01712001199203153, 0.08059218916441165, 0.01994715030905941, 0.13918362017120087, 0.01091849289819478, 0.005156730297922848, 0.015083812533937877, 0.02127259350081365, 0.01682054822243029, 0.027774808808199825, 0.027221655022473108, 0.023596452271205284, 0.06485827537553926, 0.024311196982800484, 0.031218912204607364, 0.03023524764895199, 0.08998080352020842, 0.03109479255433525, 0.05590237046201384, 0.039786063885736855, 0.01817083373034914, 0.048848370751065594, 0.020990611857644493, 0.07422798268136478, 0.09431218803529778, 0.06277070493407308, 0.032949073901099545, 0.016977916088616176, 0.0447606711438106, 0.028410142760783918, 0.02300454975826846, 0.09576160340539872, 0.018359174531313683, 0.008653104831013949, 0.06216112111184386, 0.037737812906984365, 0.02573225369316436, 0.06364956100080764, 0.050527271589324366, 0.0774834426720777, 0.036525386836259596, 0.017930690063944748, 0.05097472056325886, 0.025261563526827003, 0.05814502391243174, 0.017922536973210595, 0.047645018991803935, 0.08281966641304955, 0.01956652526954009, 0.023841295887025136, 0.05873349435146778, 0.05041904634826126, 0.061208831687127395, 0.025459106958981965, 0.04259603991804104, 0.08051726576541701, 0.024444525009922446, 0.056443439210735025, 0.010450970505424326, 0.025033280816710284, 0.02668259533933334, 0.025593685624640317, 0.042270609598246314, 0.019165868946020643, 0.045467241697253725, 0.008687998220745114, 0.02828680452019457, 0.06093297108647324, 0.03418249078094959, 0.015176702609976694, 0.020916150026624242, 0.041350480544591145, 0.059276095276037534, 0.02478844486176968, 0.009186925430361544, 0.023848230897959684, 0.03872708522624547, 0.021916649364415678, 0.048488615861823486, 0.014981292732690853, 0.02710599298288505, 0.008641353999865393, 0.04015141504726583, 0.06386285903112543, 0.030879596541185054, 0.039183823016261866, 0.04339835614026074, 0.06470860477777259, 0.04306355273471244, 0.02090603958124355, 0.02306365152640689, 0.11765582171539146, 0.06267555681387744, 0.03204633121288592, 0.05521277641697277, 0.026496186995157794, 0.01821467885747552, 0.044718291159839406, 0.03290357976971615, 0.03786004989618256, 0.06082677597840948, 0.03238984120769366, 0.05376758219133462, 0.05266117502845103, 0.1001796477864827, 0.036753497176593354, 0.033591170494835225, 0.0728845249320711, 0.029221853136175105, 0.028410489415569652, 0.057321713050647136, 0.03945400307495748, 0.02345348111233644, 0.05892582838573764, 0.03754368239653207, 0.06981050520534478, 0.04129308523730405, 0.030250768590297912, 0.019240183305115472, 0.046383850576896826, 0.03031383486344449, 0.019180210111963174, 0.07357879977432952, 0.019134746624096748, 0.029022181894810452, 0.04810682062299983, 0.032997245509778304, 0.01819345247631352, 0.013602485771351045, 0.028168905503867615, 0.04492135425548881, 0.032826488341895804, 0.021243798170959758, 0.03472725590390544, 0.039364229061550675, 0.09183128124042865, 0.04947483149026671, 0.02368899760767818, 0.03132469554041182, 0.02640100823144519, 0.04328004152123486, 0.06329001678574471, 0.03598169806683737, 0.03275057668947885, 0.016472359345625007, 0.04336935205144748, 0.09213250701225574, 0.039862251329806545, 0.026938451469064723, 0.03436865397698937, 0.02521904756224925, 0.017003562797101277, 0.05855318406716951, 0.013645451812584315, 0.04581495368432614, 0.008422188693657517, 0.0063733416027389475, 0.06490530551321085, 0.020800447767420162, 0.13367310376657596, 0.033730230774850614, 0.020926147474036105, 0.04852087965475456, 0.03762487622518693, 0.00447284743835729, 0.04459549492645649, 0.06973867680156423, 0.017250882792136362, 0.052830426833562316, 0.037652869077940146, 0.08976230758332437, 0.03584832215922014, 0.068739430017529, 0.05031467452945729, 0.03686279494075045, 0.036409653933538545, 0.01616691242933514, 0.03646098182446534, 0.01092537619819444, 0.016781198116199627, 0.0331363785681465, 0.09636768620581397, 0.03456225205633429, 0.04402259905492106, 0.03410946728000718, 0.03338327338438361, 0.03636608651328472, 0.05959835016138612, 0.04323778028089193, 0.01148858871836696, 0.053466103610492526, 0.05280572049800427, 0.021990913927795428, 0.037185639713800726, 0.02651722951521797, 0.11578775461642973, 0.02489365554685074, 0.08104327705598648, 0.034425727527348265, 0.02805304619663906, 0.06066697769828382, 0.06306317432092563, 0.07876456384697268, 0.04893672367137286, 0.0627027184612328, 0.009985870865714407, 0.021188919462503928, 0.0881750193694907, 0.012875178175407552, 0.028535857789158344, 0.018950856793972275, 0.035244981953573805, 0.02808128802796766, 0.05718237314853938, 0.03921594125248733, 0.007027486365498796, 0.037508572586962295, 0.07159671580959713, 0.03500725720979033, 0.03438827348873019, 0.03383452598486216, 0.03818935662087414, 0.009685311590381449, 0.027656900215773817, 0.05601328850213078, 0.08709901057544255, 0.020795832087676373, 0.0783746021108762, 0.008058709659493499, 0.022277264187352794, 0.0680084135984221, 0.041882145564041795, 0.004845800586119896, 0.04677706818667151, 0.009937775865828079, 0.00417470229759572, 0.0424797899059711, 0.03044105716980994, 0.013789093298386904, 0.0542575337233082, 0.02460435584878489, 0.04432769740120538, 0.02356254713489644, 0.017056474574811516, 0.04045389337284912, 0.04715272323078206, 0.041283064807254466, 0.01346583579546742, 0.07724076133942412, 0.028292467825174816, 0.06766102336827787, 0.03521606213443222, 0.07674582257506347, 0.05561493810326342, 0.0439890482342772, 0.08902569872237022, 0.03541562037782804, 0.04829819321692471, 0.06903811237744747, 0.06135400917921817, 0.016277669590987986, 0.013184811762203614, 0.024723289083809625, 0.07191114893723881, 0.1136722717614424, 0.031526067496968374, 0.020125853723936507, 0.0533835921106079, 0.027088001407983325, 0.03453499464798839, 0.02031247848795066, 0.06218042269709611, 0.04711880085749492, 0.0316519070146305, 0.02930564591811309, 0.05817888882912456, 0.04939500895899631, 0.030745657558943477, 0.06255946384983198, 0.04093389342268629, 0.05294709819399061, 0.02841009104984903, 0.04930818438409798, 0.008294589088989363, 0.202659489887376, 0.14220350812519753, 0.1255060855539576, 0.15840778457781962, 0.16776128912404661, 0.12260595246428445, 0.12786999540103058, 0.12435246439230059, 0.1569919468414399, 0.11002445984030924, 0.15419840722555114, 0.1394655252055776, 0.12611713260412216, 0.19708656796043922, 0.1094853331244761, 0.1425992844686393, 0.16894590620312, 0.14552466781629672, 0.1410702342588094, 0.09367533148296418, 0.06612043587430831, 0.09390156490788346, 0.13346448270303587, 0.09791300046227633, 0.15183006172939656, 0.10145679296505067, 0.13115454375022842, 0.09609341906804232, 0.15128750293966264, 0.2427637943577382, 0.10307003623775898, 0.10972085153503765, 0.128140562334128, 0.10862827992006656, 0.12175469088458246, 0.14313455010133405, 0.13422065744957618, 0.1772845434325357, 0.15886993477902106, 0.1372482675698496, 0.12513036539237346, 0.10943943679693247, 0.0770678706166725, 0.1255176688033727, 0.1441281967826428, 0.0710698158570355, 0.14121701670510156, 0.08498787909986512, 0.10796616544886943, 0.2133459108130586, 0.13044723009149875, 0.30977684523790117, 0.16152608418656936, 0.11365638309789282, 0.10737250093370677, 0.17482402223733165, 0.21272885763356764, 0.18581687833272642, 0.10205572816513239, 0.21758276007829175, 0.15661570574006728, 0.1554174522959417, 0.20451854013146895, 0.11384084940918031, 0.23961175623680317, 0.28348973321337856, 0.2198943078157402, 0.24335178216138195, 0.11767744071661465, 0.2032012059803932, 0.1886467151944676, 0.2778098654122122, 0.0870564773738865, 0.21951981339483492, 0.19601346263962408, 0.11335657458872565, 0.08760987630774898, 0.17255891474985308, 0.19952628220761978, 0.26278629899024963, 0.12141539054291865, 0.13896048940237493, 0.07662535524897038, 0.13294829265965571, 0.17713625945391195, 0.2731031131359839, 0.13659315514228038, 0.40928538468095566, 0.17183983398060645, 0.18126723536800954, 0.09222157239433258, 0.2798844621546807, 0.31145592610682216, 0.15196308523656862, 0.22367223977081238, 0.11074087462357937, 0.20997729963592945, 0.1266747833259644, 0.10827362717640017, 0.17236029879460413, 0.1574701389237758, 0.13869867119337284, 0.14773170583911482, 0.15998316778531, 0.09714921846264794, 0.16749220840152235, 0.15989603294480234, 0.20188080747762036, 0.16881818402438395, 0.19290299244946052, 0.13370367067475475, 0.09720223940788739, 0.13836900823779646, 0.112289889084716, 0.13807780289601895, 0.12865564155001796, 0.14789069972691998, 0.14352006086659047, 0.13970138835570506, 0.16579228994106093, 0.11830264507161996, 0.2328633796423674, 0.14281801789277984, 0.1447569098203413, 0.13389283310501807, 0.1000931871033484, 0.07878128754635973, 0.19663733400164113, 0.13631250649209947, 0.09476633261769049, 0.12830771505832672, 0.08650601255677401, 0.08624180415344816, 0.12077913920004522, 0.0997062667363113, 0.10565702322750323, 0.11228415108616314, 0.140858793991708, 0.1142650476146129, 0.1570872481792204, 0.12961565697145078, 0.16621912348895304, 0.16139961839202913, 0.16473467491807478, 0.16339360736310482, 0.10617644616192388, 0.1533470230717813, 0.1337652794656254, 0.09457527795025418, 0.13617677103367545, 0.056127332180978796, 0.19150422315203375, 0.10201491866140597, 0.08957835455094615, 0.121585370131558, 0.14935115442400979, 0.19401748183994524, 0.10697992683778848, 0.0745669612661004, 0.24999043964330228, 0.12844416297852032, 0.13018487562094966, 0.07446861089838129, 0.19579639928715845, 0.13910817583241772, 0.11416466711389442, 0.12131724701893908, 0.14191469297774378, 0.08679173270901365, 0.19707703782666117, 0.15426815187017764, 0.14874625139899794, 0.19399324281802102, 0.1960007915453565, 0.1437912253482688, 0.10584297574936383], [0.034989181365216934, 0.012079831438078996, 0.0534642381863969, 0.09024069884852057, 0.04813143502800696, 0.08558853799777646, 0.03344896542389066, 0.02765882692690338, 0.004381342545046562, 0.026860961675523754, 0.04700895534047196, 0.07756385892148941, 0.06337062838757712, 0.016831173861940062, 0.0042491765775447415, 0.0023923132750731445, 0.10938984792559378, 0.06528782853556257, 0.013249875609612754, 0.07941926258706278, 0.034318616944214994, 0.05137120170759098, 0.042918053485693476, 0.0325228608844261, 0.0952700507496634, 0.02949287589158743, 0.021453813514522007, 0.024112996630250447, 0.023612068973541744, 0.07264631755289531, 0.061181152930423144, 0.023257912271806312, 0.0398062962678171, 0.04952157051452706, 0.021364355512383967, 0.03638735311406274, 0.026566307022867185, 0.058984690751399727, 0.013763394878966915, 0.016971565219723893, 0.05332587504639261, 0.02717752644281474, 0.11718845445542567, 0.07246987218217504, 0.016561127868631197, 0.05272339285922147, 0.07059730814709779, 0.024303396292511496, 0.02069276261834368, 0.012088622297010115, 0.02650803837534641, 0.04548070569252295, 0.06829664651905337, 0.0834049499263206, 0.06453448831434212, 0.015777828821521855, 0.028503879363979065, 0.0881777772860181, 0.04379313656940095, 0.0465485901241341, 0.03486062415064343, 0.07133000229875888, 0.05866238607033607, 0.030203929974607406, 0.04650139910799842, 0.005708946104747274, 0.03698599337029361, 0.020652906894082987, 0.05246278889957936, 0.04001797019173542, 0.04056929685776273, 0.01791291107844201, 0.04671801812946797, 0.040976679433257356, 0.04704911749990237, 0.059692850937285734, 0.01741449044446551, 0.046421028823862155, 0.03884606634176547, 0.04158080104858645, 0.12377252817274102, 0.05821814317436469, 0.05924412642695731, 0.03205851392610179, 0.12183449426365477, 0.09853563076185604, 0.0818482669250619, 0.10488548841808112, 0.03044291301780651, 0.014956587354742713, 0.06789539264695299, 0.036299900347066504, 0.05347506683920661, 0.06101716414935166, 0.09485244856125886, 0.02425683921413316, 0.06998266814456833, 0.01996910447374948, 0.03514158306643367, 0.08383538408745682, 0.07452439742102739, 0.0451574893668294, 0.0663968020929925, 0.060859821181023316, 0.04259767551575938, 0.0414825541027371, 0.035294582316231345, 0.03418627142485592, 0.04572226087592783, 0.053590351580491954, 0.009820760723443763, 0.021741343549482768, 0.07148657534872332, 0.039878362158854166, 0.005889719393434785, 0.025779172748086915, 0.044001795937337225, 0.01330180009151058, 0.014197066719193133, 0.05800922716697378, 0.04766131368195338, 0.07425166245910429, 0.03488533814708072, 0.02742504370549033, 0.06494815281081585, 0.08807447032942887, 0.04727572630790453, 0.07387834015272318, 0.06488173298778073, 0.04691174644376001, 0.046124261683754386, 0.02818527488758968, 0.04390907248542194, 0.01846837461926043, 0.02387921915449683, 0.11325339020620431, 0.01440052051968392, 0.04671845479958481, 0.034361537020172805, 0.042355587901247126, 0.0206414194056584, 0.006679066704706319, 0.042113772247947996, 0.0478178292753235, 0.03363622795610178, 0.046927428263570034, 0.03548618473653351, 0.03980425464349889, 0.0520351049940913, 0.006391097605603958, 0.024651916502344034, 0.026291967106742725, 0.05015792527927026, 0.04292155833794706, 0.026365804576104688, 0.021797501624772148, 0.07567142256565633, 0.03520145283771619, 0.013419783377509206, 0.015942870015879313, 0.04763550034934475, 0.03323790437031177, 0.0918716847175552, 0.022010443424205148, 0.06920534171043866, 0.07887646631007234, 0.08927846177210731, 0.044580839664465, 0.05657943896949292, 0.023457146843054125, 0.0687302676059546, 0.014826683740642284, 0.0246368590441923, 0.04432337666531244, 0.030550590506003752, 0.03642561154500131, 0.04118055075166687, 0.031647262606589545, 0.016433677651108276, 0.059938117816683754, 0.06250750393636766, 0.0033413690905417168, 0.011544469086783788, 0.020041723863311836, 0.03839582114690735, 0.011385391886916854, 0.06791857446754171, 0.038266639570675554, 0.019050628254790942, 0.027671381192762527, 0.02548821255444519, 0.05503500188370386, 0.05794507113375491, 0.03657648107036948, 0.07008842658251524, 0.055951836759284626, 0.042161231394857175, 0.03481438691397348, 0.028902997765990517, 0.06706534404187434, 0.08159793237404478, 0.0504477784758614, 0.080069295851694, 0.010494290862322576, 0.02142450873619847, 0.028950514369494015, 0.04174722981969676, 0.015622910521473857, 0.05305856398697342, 0.07051017330659014, 0.03711730084051529, 0.09263176651250932, 0.047222222727272785, 0.05810465107882216, 0.055621821403263084, 0.05187016626399371, 0.02584912615167278, 0.06306889699772, 0.06101490418997504, 0.027650070541928855, 0.028063803986315767, 0.052737599959777254, 0.02618993185610781, 0.006833066656855086, 0.02513519349327732, 0.021732489488297896, 0.008803304987058284, 0.02680993447410724, 0.06827114345205408, 0.06668250692347366, 0.025163644083565282, 0.0716381611663007, 0.0920492792201619, 0.08867192697981674, 0.021897571859881285, 0.1006894716392121, 0.03113177353366008, 0.04086162834878891, 0.032780182157312675, 0.015944645424643834, 0.021058538958670634, 0.034035248681902885, 0.07390740552857038, 0.08165136700676334, 0.09223105656283517, 0.05841240391976411, 0.04040770976233386, 0.08455114769599131, 0.0504258721916666, 0.0756690017278156, 0.02523880688503625, 0.028228244759262573, 0.039833660928472396, 0.025090902119935043, 0.012533036605154556, 0.04357298205216085, 0.07812272772313127, 0.0343534279794943, 0.038450496842063246, 0.04811869115538655, 0.10642468929290773, 0.05473455752155954, 0.043835317370511835, 0.09050775709892474, 0.003612719109139195, 0.068808906531382, 0.030367750216335542, 0.028805045763992017, 0.07036794142256822, 0.03804847305159896, 0.16819235147728076, 0.04137578442873013, 0.01725590449848002, 0.0542986266795666, 0.03548956318427959, 0.03033669301188521, 0.028124571995689508, 0.09561508142900083, 0.04284615613399975, 0.023937654426141132, 0.04952480723600715, 0.07296308724870605, 0.055271853287253654, 0.05487857822088465, 0.11161350239548953, 0.031934223821266525, 0.023128891574038614, 0.009511429741377793, 0.03038369825169925, 0.06843715470524565, 0.04184186849142275, 0.026399184942185402, 0.02183402486656222, 0.07647024542694131, 0.007277287048993693, 0.10641175006786663, 0.0762220789047499, 0.0863859742399185, 0.008071547377884628, 0.029889657725429827, 0.030308991272543228, 0.06247329044966929, 0.007434214893428068, 0.11983217025596289, 0.05549499554739845, 0.06684102583676577, 0.06773239211930383, 0.035225937007776195, 0.02783172339531443, 0.028116878557709918, 0.02780452344356285, 0.01775995587869998, 0.017697151990667466, 0.022506276596217387, 0.025047972467878175, 0.013560213997299153, 0.018148230306143244, 0.02589999822028462, 0.053375463917731285, 0.07672457129604394, 0.02621915811041911, 0.02801466710685242, 0.0499629061068258, 0.008912674571958282, 0.06169221018471065, 0.04278388467707461, 0.007824749280247957, 0.0391442584054124, 0.0865107546410253, 0.037665283532753106, 0.005921274555035897, 0.04765639922791912, 0.04562251239774689, 0.015844515817720565, 0.060186843583059896, 0.05144452781326348, 0.02326894010747633, 0.07429729065587444, 0.04536589592575066, 0.04947015452348898, 0.03909234062678391, 0.047255386673514886, 0.07968095822199699, 0.0202006449727642, 0.04499390278191817, 0.05269232033301265, 0.05770159690009971, 0.03686444202978765, 0.02765363285077676, 0.06989633003550191, 0.008872797780279672, 0.045202213579848896, 0.16782876614841724, 0.16869231577842467, 0.1189299714901755, 0.22323783727422838, 0.18484636750673095, 0.17841858338684807, 0.11594131694085176, 0.1411471188428902, 0.09811749231190452, 0.07114479288218484, 0.12089221377766902, 0.11740308164829209, 0.18355405378726222, 0.10049524536776928, 0.08691851259960283, 0.11400479222497634, 0.1400662147470059, 0.11594199875910437, 0.19578003564909582, 0.15469641034160891, 0.15867424527964286, 0.17361679024273352, 0.09854704547192782, 0.12582064125566714, 0.12637137420355313, 0.12256672110168204, 0.23479480987354634, 0.09939939489648228, 0.09012244551652863, 0.19232226715933895, 0.10958307828273504, 0.1081784560735668, 0.1123342915408073, 0.150100510988024, 0.2305590024878902, 0.15675232986048346, 0.1994513894521421, 0.145767119322573, 0.10089298289629722, 0.13864961092270192, 0.16109021080117072, 0.1267191091732633, 0.20913075715784105, 0.20049996463762176, 0.10222845034854067, 0.16450460339265485, 0.2031645103688202, 0.12434792915178884, 0.1275347783080032, 0.21825970601170294, 0.10302456891945294, 0.2444837383565403, 0.17259561036142612, 0.2224270711022039, 0.13814595407776295, 0.17472449209420912, 0.18522456979318974, 0.22772104509415167, 0.1474496629089117, 0.196988278879754, 0.17407904769624435, 0.16485467493053407, 0.1598305937143103, 0.08078512840814168, 0.14605250239612597, 0.2191148286745433, 0.18325370135566882, 0.18589969243734114, 0.2226498954358601, 0.2131539291792339, 0.17047385324633893, 0.1740782509648031, 0.16516186086641205, 0.19325747665378357, 0.1682338274775013, 0.1813816276168631, 0.1195420221155209, 0.11042465651107412, 0.2167706455915205, 0.13546374235903064, 0.4019849344847664, 0.16310067066261846, 0.18764870181199045, 0.12779006178701116, 0.20134353469456398, 0.22961573374848213, 0.27856728122118984, 0.32065238262857165, 0.16467985366621327, 0.26666497150736473, 0.29028579112022157, 0.1743151253509906, 0.2793480473900995, 0.13030314427470008, 0.2516249035515132, 0.18066812396770526, 0.24210033157179434, 0.10463803435765928, 0.12594290122750307, 0.13798280799340817, 0.23933381953787422, 0.15949501655995846, 0.13010814425445374, 0.12662354736558853, 0.22064361841447894, 0.1829984255375401, 0.1064785376131054, 0.15180208419840183, 0.17086068168282512, 0.16902899609938746, 0.07553754870088832, 0.16918831174412083, 0.17837672434266538, 0.10311445401560876, 0.1374908110066768, 0.10914175035131556, 0.15239725790677533, 0.09747806936502458, 0.08458034330678564, 0.19370730816116258, 0.15086007184318959, 0.18181907914338574, 0.08452723043099528, 0.07320596776421993, 0.1283900924928246, 0.1269896837672399, 0.14102750187439306, 0.245539729273127, 0.12610307489071163, 0.3225218823119518, 0.11913696844731608, 0.14785742086748924, 0.11991124585150711, 0.11701780070941295, 0.14560738999036052, 0.18076724042334866, 0.14428084746243494, 0.0951942923148313, 0.22791520241768132, 0.10178025060844037, 0.07324057195575968, 0.15676904589899127, 0.10786672723629784, 0.28240663810603084, 0.15229719150210583, 0.10464974784202154, 0.12663581243325628, 0.13983074996259906, 0.1124922512099147, 0.1871952850131258, 0.14556199161996766, 0.09602510700783423, 0.20172823340662066, 0.09597800026137022, 0.07867222726945916, 0.14673870267166247, 0.15849456701788212, 0.13324510576503892, 0.08605860954811496, 0.2172600072357924, 0.13119752128278056, 0.09456655220879663, 0.1537933458964671, 0.16392410792891057, 0.1380179407856157, 0.17098239773223478, 0.12008212176301788, 0.09665142985120898, 0.17500823573960414, 0.12769274563798982, 0.16747143209701584, 0.09541642716935567, 0.08725750650609694, 0.17952662231701036, 0.08474698275207512, 0.11438490207036657], [0.02073288838859768, 0.010138066680801493, 0.015319543533898411, 0.030876968859604774, 0.044088792882018515, 0.017045839359202695, 0.06090461817239562, 0.023846892159312003, 0.0014675787162794281, 0.07469908078952182, 0.0533275029832317, 0.04435918744533293, 0.031143335715657285, 0.040528606097664566, 0.02318271308115894, 0.04029646996528872, 0.11636876335908329, 0.04876155000660689, 0.03383009799665982, 0.05728931902276893, 0.0704273208975792, 0.08476241942374937, 0.024130363843493888, 0.033668189144302765, 0.02501576038588199, 0.027767965727816188, 0.049189172625061006, 0.012258417066937734, 0.07013577847711502, 0.05505137318264573, 0.07072990264503226, 0.11008434493335024, 0.16309379119305842, 0.08661512645982927, 0.036297988957695426, 0.012264717182505035, 0.09292484876970131, 0.04910796730508728, 0.017427151962634058, 0.02898694185029355, 0.04248141401237057, 0.062220987052686756, 0.0927300019670398, 0.05393947699978467, 0.042492568252548095, 0.03871433752318544, 0.033370747846821626, 0.04698859272344459, 0.03265086268525451, 0.04028237394748196, 0.042538943385044416, 0.022829197978060094, 0.050272332849882306, 0.08026554459525694, 0.05198949594951926, 0.053375230260914376, 0.02299553864905911, 0.0511998584824464, 0.032121183748747555, 0.07576755893927428, 0.024607402963503718, 0.1065778149472129, 0.09505020649803263, 0.05741866147746483, 0.03239640658120475, 0.03465737336345258, 0.0242932666949327, 0.08034255175340561, 0.08789203415114073, 0.08081208704219711, 0.12608976028258764, 0.03551774372857425, 0.039994999045325864, 0.017125784464540984, 0.0324545105198218, 0.0270829682103208, 0.02066957888253514, 0.06106490674879282, 0.033357096160010945, 0.04751821228813741, 0.11618274955018876, 0.03620189854935293, 0.04583699020346807, 0.07346139679993353, 0.10826189070940019, 0.11429774424722118, 0.13656421234050106, 0.07190597018287068, 0.052487150495571476, 0.17526790890241825, 0.07565410897856759, 0.026924192657574054, 0.14936367230069253, 0.0530204932475763, 0.13166340999305248, 0.03012443877636425, 0.02221582202060569, 0.03141517052426934, 0.021677867419296698, 0.016930382248134385, 0.16897569170161603, 0.0136009028421775, 0.05678373546670041, 0.044064618977567846, 0.06088000376738849, 0.03004407806832704, 0.033254007538480145, 0.06590092870136423, 0.013613825787850206, 0.01647177711880255, 0.023207317910067016, 0.07316279870968673, 0.06399071527524822, 0.021583922057142182, 0.04955892496171498, 0.018094722895071875, 0.027358501308387326, 0.054939524345700784, 0.030707755358889702, 0.028344674801994717, 0.04113361637498583, 0.06464626054249464, 0.016752293618816524, 0.049671421142955946, 0.10085844765267066, 0.02691760238620543, 0.04470252123991809, 0.05836025248431872, 0.02182080984986838, 0.05457682767882944, 0.030641636225364866, 0.04040848351113739, 0.07595417029674977, 0.034816930325882095, 0.04825549530646494, 0.042869514154811064, 0.02388575005405132, 0.008221420988951239, 0.04633876630255292, 0.10974093836041228, 0.02878233891791634, 0.05738696842003734, 0.0668292204218526, 0.024309230052054893, 0.013401599323016503, 0.060534796887828465, 0.040145175261122566, 0.05845573002232179, 0.013961396048656635, 0.022332083523994493, 0.04672967032679627, 0.03171319213335312, 0.038889568644545736, 0.03131513284789699, 0.05943824161565112, 0.030063868034631017, 0.06738445796673337, 0.05490305089962579, 0.06509950880201594, 0.0392672844651726, 0.03698955950958114, 0.04213691959458013, 0.02981548317738118, 0.029532063204134186, 0.010557376287667262, 0.05180623239627288, 0.023542400937707677, 0.028311014813821644, 0.029416217303444302, 0.0432188579091622, 0.049521401975183725, 0.03159039973040983, 0.06933697859846777, 0.038467921511901, 0.02493979510731034, 0.04810265693513136, 0.03129715850997356, 0.05020923018755932, 0.016857561760491902, 0.04766160862580423, 0.03832578921930925, 0.04464477353218583, 0.034138099816177166, 0.039579457633437655, 0.07282748202522916, 0.06339285642870011, 0.06354536921266588, 0.006779874299442577, 0.05837433318036699, 0.012554715935801788, 0.058491801272236535, 0.03406738223988683, 0.05392315549655788, 0.028242940240870082, 0.03345849938810833, 0.0722794380459574, 0.025944982903198372, 0.2123531681155005, 0.06350215419285721, 0.02554029121153778, 0.03514214231061839, 0.04204701917666582, 0.07431456593856697, 0.018831515617127863, 0.07967800112260927, 0.057578363996599956, 0.05747006980762367, 0.06847462406562221, 0.0705393765782637, 0.1419596010518651, 0.03955475895875885, 0.005723363879482232, 0.021523155962988254, 0.051294083466693285, 0.05592159543847365, 0.050830312989531994, 0.028993407632374478, 0.013219009927143494, 0.0768212439312089, 0.02792443344069104, 0.013716908663721576, 0.03361329894452807, 0.08285500604899661, 0.028976109367044225, 0.004880123719152424, 0.040650640073562824, 0.07943031723581015, 0.006603152179459651, 0.0049970833201622294, 0.024787337864719095, 0.03274240253132678, 0.019792348837419864, 0.027909299373746883, 0.10259595038669725, 0.036617796192125934, 0.08080265649984922, 0.054383585830369306, 0.0494755094780797, 0.061227443793247786, 0.007946337488735276, 0.020624992565342018, 0.0239718679128395, 0.005356567684606079, 0.018146477880016453, 0.07424919565598811, 0.1216930054849194, 0.0833331291834193, 0.03932700867974951, 0.04004487136919652, 0.05549817098184459, 0.07680293442981859, 0.06810988194399303, 0.05680240885985475, 0.15909769271890964, 0.11598985627173417, 0.052425468926348036, 0.1330030219809663, 0.08348636975091311, 0.0471947354925496, 0.08048558036886877, 0.05302468757896174, 0.10305642285534453, 0.07481993115957707, 0.0679604335117244, 0.07775899683756214, 0.14212191976126165, 0.19893104721221233, 0.059927009541781685, 0.11136242473918585, 0.07041232089602179, 0.12640286807812032, 0.030199007859693903, 0.08520977646713296, 0.13686519296419236, 0.029094303327222026, 0.11713924096716989, 0.08917756799247958, 0.008942911104719726, 0.10776216389551278, 0.053407781336817055, 0.09421221356117919, 0.041602642215307684, 0.013847649228879282, 0.091807501871259, 0.026111172271832347, 0.0346041685571113, 0.024553104566650528, 0.039335048772514834, 0.11953219320745238, 0.01625847908848476, 0.11451070136841267, 0.03161393203622392, 0.040500188066113385, 0.07502816917915499, 0.032655738834892555, 0.018468792137179165, 0.09767785743479768, 0.027513915650366295, 0.016281272119451917, 0.0794996788364745, 0.027817780595092524, 0.019411947878618396, 0.03765349343959843, 0.03272256851496716, 0.020644847649119554, 0.014183295331144286, 0.055831243028684016, 0.09937655015458023, 0.007365377105381941, 0.0273711494200172, 0.037334551884522366, 0.009253351956665998, 0.05590993174982648, 0.01744759310367367, 0.040557636999555176, 0.040068214068249355, 0.03814234563540067, 0.008846487448130165, 0.023007548992492022, 0.02461975804650255, 0.028015833475717136, 0.052482661220335194, 0.05200898905675258, 0.05704979780280302, 0.008223102551945036, 0.01923968343274488, 0.02457187563601521, 0.03987890225084078, 0.038981131473255735, 0.04893661641906347, 0.04645332709074982, 0.05661011696042073, 0.09406629679424149, 0.10441922432472629, 0.030713901299262242, 0.02018355163595369, 0.06262712473530443, 0.03751689230181998, 0.06559421007912006, 0.020814417380719416, 0.008935630396609346, 0.004297679519250749, 0.07146804368183499, 0.032024961190238115, 0.0647111481896812, 0.04922181946195422, 0.029700742358522072, 0.02491672053903101, 0.07586563351534067, 0.05987305396927461, 0.05300651980383743, 0.03200808810370584, 0.15091642527089966, 0.1708436592091476, 0.07801163731323135, 0.17148850605853144, 0.28513930437545626, 0.2509061138956778, 0.19070551520393741, 0.1156555048580612, 0.23127466650499454, 0.10872617829591037, 0.1551958843464813, 0.16632248407169697, 0.12438878462079073, 0.07699863925095528, 0.13685180174727596, 0.13550405390560627, 0.18243061648982187, 0.12482391490090279, 0.1398307193190821, 0.16037800950148415, 0.1326762701595022, 0.31013405671523464, 0.12801491625366673, 0.08227305501819619, 0.16289001180519982, 0.14373795159401434, 0.20315706399419617, 0.09129980008207983, 0.1556891683609255, 0.17892536587051808, 0.26389917959609344, 0.21030650293875128, 0.26919514541664435, 0.2489309400440224, 0.16698643715391237, 0.086570976812753, 0.18791229734497686, 0.13794583659018242, 0.11217237885801062, 0.1651108240888965, 0.17231617213016556, 0.15537674238364543, 0.20905462333992605, 0.19879802370504027, 0.09343922318470094, 0.15934063452145747, 0.2079999807380861, 0.12810671656963327, 0.11882793623954059, 0.1476891573158003, 0.15190670116534158, 0.18742572426074938, 0.16097091558960178, 0.13694658214526792, 0.15451561359147872, 0.10321052144131354, 0.12065044408964536, 0.17374463499553744, 0.12032669533284442, 0.18223434476362121, 0.0964872801916734, 0.19596080175570904, 0.16834377641639403, 0.11089974593731666, 0.1761886240133355, 0.226809814151737, 0.1486225894862606, 0.1847557239835301, 0.1947436872268877, 0.24237333466449093, 0.21917950181711107, 0.1846147638054625, 0.1789539869153692, 0.1356416892620825, 0.15418641028865693, 0.20057960713822998, 0.1450033143403069, 0.1748749517625378, 0.27932865004385676, 0.12251523999317039, 0.2729866064844593, 0.09962361351016069, 0.09839921348517942, 0.2289768623849077, 0.18817881933383404, 0.19111520370408414, 0.2517479679156696, 0.26193232545929573, 0.1987576355496722, 0.34328026036101006, 0.29891325881884945, 0.21200003222592417, 0.2878855763664169, 0.20057729355269865, 0.3163736896409143, 0.17016358763700531, 0.19772148631032438, 0.1765730622554979, 0.09859170839791337, 0.2240294359263874, 0.320844701341083, 0.08858104596935934, 0.17265105980538553, 0.16013368874067263, 0.2420546114444733, 0.15143814646909315, 0.0881936353060507, 0.1587983668451348, 0.13117676030003256, 0.15017315144500426, 0.19850844246966226, 0.16517709069434675, 0.2047734941926695, 0.1244023826814467, 0.19256681774652776, 0.1013128144005614, 0.13685005506680858, 0.12672187475066993, 0.12462696901732877, 0.1454365064179705, 0.1734924541726228, 0.09209042580257501, 0.16558264231970235, 0.2730033378447256, 0.24254473917666944, 0.1371622205741944, 0.10556397418822012, 0.24734742098277618, 0.08109999054502096, 0.18752975900086666, 0.1477593003261474, 0.2043552561512878, 0.11640433282140764, 0.27864431902285547, 0.13539153091128797, 0.07978913749778464, 0.15995564990706984, 0.10418494697660209, 0.09894705828159087, 0.18406350225690873, 0.17605578436726527, 0.19563591918878018, 0.07606183629362814, 0.0914779614897505, 0.12953422182509977, 0.10779018739178296, 0.0801747478544712, 0.15434548078525454, 0.08183871380864613, 0.1588249654178658, 0.14305024978614625, 0.11505158242559242, 0.10407873654677983, 0.22737644342405183, 0.21998936400538494, 0.12401577641045856, 0.19144836002059523, 0.1030000617667552, 0.14401547460546418, 0.11009489396406759, 0.2959940654616202, 0.1274114458130733, 0.1597971463155362, 0.21075743761274124, 0.08417964867886998, 0.1629539188598433, 0.2045452919217848, 0.08580621422058152, 0.22537732166388344, 0.15113342733633134, 0.2615586277698317, 0.14082055088252793, 0.19169372266098378, 0.1274884606321012, 0.15287080749629006, 0.10361342240245112], [0.013413633606697043, 0.01468282104695156, 0.028351795589250904, 0.023669052508569533, 0.03038954350256151, 0.051706204295999585, 0.07287660358293403, 0.03171071000847846, 0.03536140816586633, 0.034405280640649225, 0.02412898297001037, 0.05410949489282024, 0.05113580970153694, 0.04200624414689599, 0.028712555968893633, 0.013466065621844703, 0.029115146664421887, 0.062413187021569866, 0.027498590061441067, 0.03705353934257742, 0.0812794543021629, 0.061460070221895174, 0.01678895858687259, 0.02315624665859486, 0.03653578647983171, 0.024941771614154982, 0.04519384789971575, 0.01616366996219562, 0.01612122294553105, 0.03788671741682676, 0.12843058023962284, 0.017463690526182615, 0.07561323052692799, 0.00746137606197848, 0.03946397753973161, 0.040887579577223915, 0.04936697397140726, 0.02317654032770905, 0.034131040315954916, 0.04415983987611629, 0.02842489761420556, 0.045034976585978465, 0.023377184500737537, 0.046514794155354464, 0.08449034329744116, 0.02933673185086058, 0.07116015294506665, 0.016002942800461765, 0.06283855351108698, 0.044007453496658036, 0.03299063034055214, 0.02363416294927799, 0.06418967980050272, 0.004767613173762878, 0.0193923513495153, 0.03577446745287988, 0.03659787790609464, 0.013152317185285351, 0.027696225424146945, 0.08837924308834538, 0.07898499032542591, 0.027074809373927214, 0.027142780525009, 0.04362549737937028, 0.03722578655147264, 0.054602824872539896, 0.06095852394918762, 0.04933775920841483, 0.033787258359934055, 0.0906021238094376, 0.08091308807413425, 0.12206460409347089, 0.04168913354195895, 0.04259648424903712, 0.08553092818587057, 0.1508895509065159, 0.1266995662703149, 0.2755392727351958, 0.4021443420600507, 0.11865915940894235, 0.27534692337916744, 0.172000574548879, 0.17982141295027348, 0.047618669397648306, 0.024429638006333864, 0.3408742846260148, 0.07562463757612052, 0.3495257461984312, 0.15185528134386386, 0.3699318770199053, 0.38518376828682044, 0.2278129143580314, 0.34970433661533945, 0.3742227967708342, 0.5524406497997623, 0.2852026138815188, 0.2702890883289999, 0.13555827760888686, 0.03496219974852378, 0.026430902897470424, 0.0667205278671557, 0.05973302075759538, 0.012396049550584248, 0.04208527760760438, 0.1787917294930066, 0.054565455103593494, 0.05443884758278728, 0.020500081929288084, 0.02704884473895354, 0.06092373206610642, 0.06726837266356715, 0.02002685409670155, 0.0780617394634793, 0.046055869184314244, 0.06544414111563275, 0.04991449701089052, 0.031544886446828325, 0.005898640008508078, 0.04508820820539709, 0.046504543898927594, 0.04946016090651674, 0.021738003406132904, 0.026734310104661894, 0.014958908601153283, 0.056429377666884856, 0.017110248201436574, 0.0504589288855993, 0.08821899281634439, 0.032552033512582706, 0.08176913004248373, 0.005336686745361095, 0.036310637069325295, 0.00498858405344729, 0.1075450698995302, 0.02348234539010352, 0.004713909452660911, 0.11711111021859032, 0.027563707535004908, 0.009406507296878244, 0.04705845994213897, 0.0717277704708038, 0.035684494256612756, 0.025737890185067253, 0.03587385970017603, 0.0707063377804814, 0.07369844738634364, 0.008689229707083395, 0.04063935176799855, 0.031401708444219925, 0.04197598750432653, 0.028463667408833583, 0.008009674286680117, 0.08128884654011458, 0.020539878281734644, 0.03984226409586207, 0.04860729820305302, 0.029992665907728578, 0.042743301169285854, 0.02980409144994713, 0.020136148030419024, 0.010920898414277022, 0.056904739054340514, 0.05358228467464928, 0.018014536472037435, 0.05468720945739939, 0.025771448666590358, 0.03711403347551823, 0.09601526277800722, 0.03716998470706805, 0.05013285122150856, 0.027894341507025307, 0.03978065913543105, 0.12783408119914033, 0.052108231916903495, 0.02017410194140769, 0.06938984632612237, 0.011164981687832023, 0.02561533143894086, 0.016682650480839997, 0.03542400904059891, 0.012371900543991116, 0.04268523936550464, 0.0714075533793338, 0.057537412766607544, 0.02929807505420139, 0.05088523383282366, 0.003014472191176948, 0.05543969932102388, 0.03472720993862998, 0.043621996357556314, 0.04284635531686006, 0.06017612984343883, 0.07128326327449853, 0.033676321167619, 0.08005399707584612, 0.04857247567645485, 0.06886577323800133, 0.05002495922869252, 0.04017204962550633, 0.10288774561617645, 0.016459657607840437, 0.020558785331705888, 0.06860069149444181, 0.006698677119153042, 0.02651991656861238, 0.02313606215700988, 0.06405583657925168, 0.03645090393782143, 0.06422684272570957, 0.03363851089811614, 0.06790860000276758, 0.07671645076404657, 0.11644835989441603, 0.004647041468190089, 0.06947782386334674, 0.07573831736320451, 0.039386162158822825, 0.0555345754800064, 0.006528368112706249, 0.048087450089834394, 0.05755537752843192, 0.004414497872799515, 0.0440831889488524, 0.03912848848549109, 0.02015755252702342, 0.04796217173157681, 0.03438760316179645, 0.01740981156246797, 0.047218645096666394, 0.007742310079911183, 0.03075319969455802, 0.049029324549220266, 0.049491830981306495, 0.02045243509083746, 0.033626230508689924, 0.06140565499663354, 0.088653824322166, 0.029007164656274745, 0.08438632387908236, 0.061660635870911425, 0.05166459039995267, 0.047835215640765046, 0.07155833480459067, 0.07930966604861521, 0.0957550303710084, 0.14447917230427265, 0.09278446315757691, 0.1022793568911091, 0.10461101443656992, 0.11081060394644739, 0.06944190966145647, 0.11447615080302763, 0.15574259533276483, 0.23628829828193113, 0.29897711990821746, 0.15053845281081815, 0.19970752328874605, 0.04982451232330454, 0.17884618302266445, 0.023325544428981604, 0.007326870653477888, 0.10422938773708959, 0.18739198574856405, 0.13779670991484197, 0.032544211754875804, 0.1490514301845143, 0.10786709495850148, 0.12016664424370374, 0.20497551157830224, 0.14909696645073353, 0.39680547531574006, 0.2096440973541429, 0.20828688066572915, 0.07727260761443647, 0.05983751515046724, 0.0653244858427394, 0.15505899975617088, 0.03400371267249988, 0.029214266950504917, 0.04593032269528316, 0.09538934596123234, 0.13266333859534035, 0.015855545568610394, 0.032404971444198204, 0.02105639965814208, 0.06106650787255457, 0.03427842797170724, 0.07071151653484953, 0.02654255829721449, 0.03923894687285347, 0.10062187970165284, 0.031345538877611684, 0.032416252088883234, 0.0092905072209936, 0.018055855424233505, 0.046217938915135405, 0.03260834480545694, 0.043108338234765876, 0.03321959103848184, 0.01877089124923993, 0.06162506640858709, 0.04673548110370194, 0.07082783166439303, 0.03486794029032031, 0.017442278368698976, 0.07524300321576095, 0.017241243490829103, 0.02343325830635525, 0.05603878390825084, 0.0043196518785290185, 0.03212802682913119, 0.032408721444587556, 0.04518577333299383, 0.05716484122639222, 0.01280314484310727, 0.039453244647912444, 0.051046859232648734, 0.024219042351168972, 0.09355189173572487, 0.0176313316314331, 0.032954754443058086, 0.029636676340634306, 0.037233447430715445, 0.01649913986423804, 0.015409447782252346, 0.012742310758650064, 0.012487568329238604, 0.058059359960738695, 0.0646240056882943, 0.03910213506089584, 0.011785978304913208, 0.04177405821880506, 0.04021157210151996, 0.06535209565153045, 0.01943146588370925, 0.007487519291199504, 0.027695032242204876, 0.005955392280743728, 0.05397587000662762, 0.09983263293942136, 0.02711181142066996, 0.04380191210657359, 0.03499102763711445, 0.05447071300999773, 0.06197564739493593, 0.059025373850618644, 0.09161491502797411, 0.05296687475375591, 0.06924261954883415, 0.034102438423301906, 0.0792881696214599, 0.06311339521480185, 0.0805208970221781, 0.08235870364813075, 0.11594820407129104, 0.13321006490338233, 0.08003638471446692, 0.15790444948980886, 0.15131059282970044, 0.13963588783817907, 0.14211894734011543, 0.09079882454487587, 0.19568490285065868, 0.20049817199187897, 0.14778033710054814, 0.14705134315356133, 0.11049378062448195, 0.19834247718174614, 0.20601149227830673, 0.1136157344726305, 0.22092245909715855, 0.14340787495095886, 0.09372397040527675, 0.22463734201606245, 0.07979692861197457, 0.21164062973712722, 0.08355511082035881, 0.16255984323159342, 0.1515734222747626, 0.14474748693887265, 0.14869495415158812, 0.14740748210780083, 0.20818594092082596, 0.15051902482105842, 0.13350680139997315, 0.11038685007201088, 0.1404374762768707, 0.13245793510108225, 0.22700783255840504, 0.12471106248877703, 0.12208780123581811, 0.1490790093497884, 0.20236676769150844, 0.29714096037130205, 0.1249093030609431, 0.1479246374219656, 0.17325346538376424, 0.12142011730541145, 0.18222293005354945, 0.08536957474725862, 0.20925481743629903, 0.1784380266983663, 0.16367447051790454, 0.18532111219340758, 0.0997718055582335, 0.08685468981463103, 0.09252794627701083, 0.19558866688561058, 0.13649613776754949, 0.14716492334921516, 0.16823846997032244, 0.12534606510833388, 0.22483347584643673, 0.09596718309987938, 0.16896490518364216, 0.1254429675698761, 0.15335465330750714, 0.14506394253863444, 0.21224112009569523, 0.1585479327026875, 0.1785478990284666, 0.2095438317666131, 0.18156737329498415, 0.20166998008085837, 0.3352380838365324, 0.1847056831203161, 0.16757201944147387, 0.3093129023909569, 0.2534800161036753, 0.417112842082016, 0.5559501292244081, 0.22700888975974054, 0.3060544546573393, 0.24335346755481538, 0.3141645065719082, 0.14209112302670557, 0.12697444627842597, 0.3913228291898005, 0.3800011221920291, 0.45154405096846245, 0.26180429684538997, 0.5301584615822762, 0.5508998324794154, 0.4748083026178422, 0.5870971191794642, 0.44554898395173015, 0.5910668029419838, 0.4331737528404882, 0.46207757606621713, 0.20617716645281162, 0.1506901075763087, 0.22294551344408145, 0.3763179246696734, 0.17776506442216136, 0.09004808136171873, 0.1510043261993316, 0.2964941983021075, 0.22369185162167396, 0.15541924494168452, 0.08622202376324324, 0.08542858650006595, 0.26073802502885945, 0.16788407769655028, 0.30462845859508364, 0.22207149905302834, 0.11813084985460005, 0.20231560833992498, 0.10281486767193965, 0.13056974287234968, 0.20075350909704165, 0.11586525207084995, 0.1216823568627719, 0.14057975412616808, 0.20527021028101447, 0.10391898423192963, 0.12973099916933045, 0.13298644383828487, 0.10113353450452128, 0.14820450466246377, 0.21262143678482504, 0.09436373809172262, 0.23649675080612784, 0.1647352877884142, 0.12842903274201578, 0.19077371235095686, 0.17962331793481306, 0.11434275191277267, 0.05111646981188848, 0.1840016789614193, 0.09356696834607471, 0.09377773445580276, 0.13981735874568263, 0.17067412395150433, 0.16491844408935116, 0.09822745657255573, 0.11251633701425408, 0.180930815516941, 0.14511920812149204, 0.16069444977948744, 0.09824129978134748, 0.13093378785396778, 0.15554313668079917, 0.09114223111781383, 0.196093947836949, 0.1944296984302421, 0.07642054930329323, 0.1539204705266222, 0.17628024812907944, 0.10285186971868239, 0.13208599941384408, 0.25331929085716126, 0.07800032219458973, 0.09312737943424333, 0.1721479392219936, 0.14939923410213765, 0.1696290268052009, 0.1444771038668771, 0.1293278530600571, 0.16481361261779265, 0.17347118757184476, 0.1396533239993357, 0.12103269898122358, 0.18943431486766185, 0.12899578458839847, 0.17853329739262983, 0.14166560715004323, 0.21791318912179242, 0.1604395110400454], [0.0472166417767444, 0.03840342456955583, 0.039204304376917506, 0.04462164916819142, 0.029388961810318213, 0.028102468443854202, 0.06797328080621458, 0.06201593978931347, 0.07109544915898193, 0.011097096721641721, 0.033250180929298365, 0.028803235881270903, 0.011683268896904925, 0.026206996464621157, 0.0287619820465484, 0.08550395423005666, 0.05646596602614849, 0.017629538985690283, 0.029882954456092372, 0.029923055328488834, 0.017799459202515504, 0.04064011019504359, 0.031005344128296263, 0.05900894509508245, 0.022683752355195826, 0.10849292750560469, 0.06024112857337441, 0.04535059714990278, 0.05812076190786977, 0.017026095358174176, 0.02224860675332527, 0.011486173626185666, 0.0226049640426232, 0.03410912637088088, 0.02125740006205536, 0.05520648683511442, 0.02204180323338557, 0.015264123775846055, 0.005917885094775909, 0.08018478360627929, 0.034675476021103324, 0.006130314094104594, 0.0756263536130709, 0.036183868670054985, 0.014730302218888557, 0.030263236671265577, 0.0511256552061006, 0.06353417666809213, 0.03412233372669547, 0.031724603012985284, 0.013717934263930207, 0.04111564395228221, 0.03013232565154472, 0.06277795212583677, 0.04979280777455819, 0.030801702636264028, 0.027205781680682016, 0.031189448463039535, 0.046675289575491226, 0.1059661014005542, 0.04860417256432195, 0.04347595701655073, 0.14750396322098472, 0.052641620634183775, 0.05619592769371887, 0.16059047632640408, 0.020999622966853843, 0.14510491292082495, 0.286366117577399, 0.25853873981583503, 0.42632075927911267, 0.37329065162808667, 0.05583967765673034, 0.36045132445231565, 0.7226794825926904, 4.0133164534645696, 3.8731409945795616, 11.627281942675191, 23.983814870157552, 41.65658320150068, 39.85769402596259, 36.50466765126875, 52.22719038686445, 53.33765260634884, 57.40995537850165, 48.394771929710146, 36.740339340702185, 38.42559352997811, 46.46581303688788, 41.79586264394945, 45.63702798658802, 35.915166793331025, 31.444788555945124, 25.423277654955466, 23.74495037140385, 11.375596196420732, 10.082062252106207, 1.3787665578626818, 0.09272443250783029, 0.2020336573402728, 0.3689796297300247, 0.10328536823151574, 0.06736912088648928, 0.02348043783117206, 0.2233827504659853, 0.04350512198382809, 0.010671541582973254, 0.0869027771536381, 0.022119400279235937, 0.045378992198816234, 0.027074175436169873, 0.08926287954372746, 0.023134351865718925, 0.07008355426331682, 0.1239515859032831, 0.040769816541503516, 0.06251752053597762, 0.029956188631213965, 0.0282105136542551, 0.019595625119343884, 0.055043287124604955, 0.052837574433895855, 0.005060712189128202, 0.01031772962080375, 0.07378886874404646, 0.033975129932044976, 0.044267816138604, 0.031517983354147405, 0.04472142445944971, 0.015960026554943576, 0.042509652013259555, 0.08341165319565805, 0.05374632708187546, 0.07068879436701536, 0.03673626785917628, 0.04799541611705096, 0.017991718543212742, 0.07111008909921493, 0.08881962107073876, 0.018146623436722065, 0.03986156951155394, 0.022885852095280445, 0.017257245152347514, 0.018649468228461284, 0.011344690593109738, 0.0406798969713911, 0.0745227350102317, 0.06076559619677644, 0.012112050223344517, 0.03671118231009572, 0.025567720989666642, 0.01850153090462329, 0.015998420008878796, 0.07465143778151082, 0.03416091774500186, 0.037147051865054716, 0.04344462785088728, 0.03962276458379723, 0.04794661248583467, 0.014440735347659118, 0.042951022079514886, 0.0735092849560803, 0.1741122039816072, 0.02324504774033783, 0.03499211548196693, 0.059815099417802796, 0.07186925924953914, 0.025748220880726175, 0.020603685744947964, 0.015443032119242896, 0.028796438766162724, 0.03083341484588962, 0.0274362419957235, 0.03156275927810179, 0.028659594395468314, 0.035662155132740736, 0.042739141311857014, 0.09092534396557078, 0.025242995470762256, 0.028686658366613334, 0.035469698524403, 0.042072821017955585, 0.04611368967039932, 0.04285567094601932, 0.08676719491279895, 0.03967530289364438, 0.06979457823739899, 0.047215864197501255, 0.028747026095046636, 0.006735426835685729, 0.06758352591385765, 0.02707017837242494, 0.04818713728098139, 0.01326735869365474, 0.019800714517553008, 0.042381259507589766, 0.039254226496503244, 0.05385120068826983, 0.05173941420751715, 0.044100885579903285, 0.018722892010344133, 0.1168846163237768, 0.040446822381308006, 0.01737714748859646, 0.02007268913721125, 0.08129911211829993, 0.04333859745172724, 0.025498711789447456, 0.02320707467715106, 0.010009386892160101, 0.07493799296958793, 0.03348222896156292, 0.07975941328632255, 0.06529291535937978, 0.07095970603967867, 0.06135092184488332, 0.01598334722896858, 0.030553794668747053, 0.002482746842302262, 0.0634625091427757, 0.009903349789730724, 0.029969348106533292, 0.040289659443641865, 0.06157028729156141, 0.011902039667831795, 0.03269200926766761, 0.09466567632531929, 0.05671650742090518, 0.012640977436075769, 0.04784557314950132, 0.017050782541534113, 0.029157310228554473, 0.04681060751599651, 0.013541421860516554, 0.0848298428219653, 0.09162515762352175, 0.0346300125332369, 0.06743613825810534, 0.09768054640341191, 0.058821249723194115, 0.025486818274423003, 0.19126860515004207, 0.030180301907802784, 0.11308131153665243, 0.22440199980572348, 0.2686446039907394, 0.29653234948073665, 0.25261194655491465, 0.05689786724565972, 0.9201961936008547, 1.4614408054659445, 6.274989170412864, 6.09083830348907, 16.325527333444168, 33.22755090651974, 52.40604262198172, 53.514139652252204, 51.853255148856874, 69.35168589315107, 73.06861800532188, 74.72670585878434, 66.70961656878072, 50.89202734731859, 54.607394433790645, 62.74792855785739, 59.68012125261369, 64.9946778820407, 50.84942648487707, 44.75750707810925, 36.95558724864837, 34.497865400006695, 18.052190965221776, 15.584498451602077, 3.3546823503509646, 0.46147104893480584, 0.11106764176680196, 0.4191054367730695, 0.1941946166897974, 0.035180852733432286, 0.04917005107047097, 0.24144944794956716, 0.09958533209658439, 0.02862393300259306, 0.044254424921687574, 0.047609196720464576, 0.05631467132198234, 0.03953946018291097, 0.011267466057512549, 0.0741354928862664, 0.021305081374462576, 0.07776157089298771, 0.02908961486912543, 0.03553124219780007, 0.03454777299456539, 0.012742817334289993, 0.021901530619230003, 0.03424200815178695, 0.11536262178372954, 0.02831097459420562, 0.040602736595657565, 0.07488808234132106, 0.030941435158432975, 0.04530702206876971, 0.03660954925562105, 0.005126039858066267, 0.03514204271918824, 0.043432324478823336, 0.10203657596702538, 0.1016883353792852, 0.04546447995028669, 0.023109973032748508, 0.06380659370352665, 0.11596712644302076, 0.023795190800522125, 0.022124743742507794, 0.09870033966557634, 0.020037428025276433, 0.01731904929563884, 0.03239519999272401, 0.04246639485861506, 0.0823361806631569, 0.013520913686783565, 0.0062392618518412836, 0.06927274212601685, 0.06351705077254484, 0.048188209804075385, 0.025890787928214958, 0.03763661269218691, 0.10985965900603803, 0.06062251395515858, 0.05245219390358656, 0.055715893169925104, 0.07572740827116274, 0.036969170079476414, 0.08785066540322958, 0.038033384949930256, 0.029581577381900245, 0.06676391142630769, 0.10378543978496906, 0.03619961943777819, 0.02274492256072981, 0.008828425010095441, 0.12058758657545814, 0.025464542352804737, 0.019071540539903988, 0.02976738434705523, 0.024618681692968936, 0.02049663453362882, 0.04581065976151055, 0.03308004429263454, 0.004693253807002498, 0.078305340101642, 0.16898315339799852, 0.1733047319876571, 0.13572908457248442, 0.1487461747902055, 0.11058167389203465, 0.1352156064803562, 0.12319605467059921, 0.11293086719008223, 0.20933499619845422, 0.09948053892942206, 0.10875145919741162, 0.2890897440093179, 0.1029297425561855, 0.11786021397358949, 0.20605512864647374, 0.15079457132566362, 0.12239134059317651, 0.1137180378540389, 0.11309483298851598, 0.115013959847631, 0.08711643141484068, 0.15166909133474674, 0.24907343239793855, 0.15976566010184828, 0.10962856858367882, 0.25307110901321134, 0.1920072518048748, 0.15144301878829158, 0.15546959224006823, 0.1466255974505217, 0.14600532670174876, 0.13285409448848617, 0.16609857189318827, 0.13266355309995914, 0.14094805855664516, 0.18629542281550748, 0.15956108398254842, 0.09595949157711961, 0.15828182440130942, 0.1738938382796703, 0.08488938317544038, 0.23492110712874323, 0.18733463640655243, 0.18050364489036222, 0.13509787408815277, 0.20531464338062272, 0.20573582319963366, 0.18835563242675799, 0.17814155067166976, 0.12107189203942977, 0.19447308965027335, 0.10423900980141856, 0.20391656356232785, 0.10071931076386284, 0.22299181579822497, 0.1309661167643724, 0.1805600136398308, 0.14763330950612022, 0.13997685825151784, 0.2506788922173362, 0.11427091584811289, 0.16574313773983912, 0.3047601950745429, 0.20821604817625017, 0.16964160596891759, 0.30807211574527527, 0.09011994040901623, 0.2357369141593095, 0.5486070232525949, 0.4512509763721497, 0.5886809599976386, 0.5047082546497546, 0.22224448170633088, 0.9844755056884982, 2.1821750988883357, 7.642778485052048, 7.417143160297026, 19.955411264973304, 41.05957492705315, 64.97551710374894, 65.44394223920762, 64.52056138746201, 83.59774220374324, 84.54974066826605, 88.76812427274643, 79.11786986935523, 58.5209196613681, 63.534069599643836, 70.50538832141508, 66.50499436163133, 71.66451146525722, 56.47513689533357, 48.735378788363555, 45.356272574393984, 39.83500703688591, 21.315763765765777, 17.6519876141702, 3.9340188762833996, 0.3808301825436854, 0.22959935478866103, 0.7139838330688015, 0.44956650224424183, 0.20362730408387802, 0.09990109055633507, 0.28036219458426204, 0.3353200552444304, 0.10618157895101656, 0.23435049419922216, 0.1227619203047887, 0.17019260704757708, 0.1270521965418612, 0.17726588153070022, 0.16528088028632826, 0.16071361729935293, 0.25372306515853255, 0.12681552899941323, 0.22488656573958937, 0.08302599687369601, 0.09619772959981235, 0.16817552818646356, 0.15799843315635959, 0.22171778093662955, 0.08578681687433874, 0.0943316083641783, 0.17512737773358825, 0.1422168227333215, 0.1036891578546455, 0.12644991353755036, 0.13489031022594822, 0.13189947232604027, 0.14824748219501588, 0.18771671509790808, 0.3075874272373415, 0.14767981104312405, 0.25746324430069617, 0.1811023732467044, 0.21359616109440405, 0.10556069533190421, 0.15499596604176108, 0.19803360585243474, 0.20123845807486967, 0.09617178220181696, 0.13207709747216395, 0.06761285942047834, 0.1786089255925148, 0.09855485956875548, 0.18179384420715994, 0.12043502016533768, 0.14723161896390302, 0.15222900967684486, 0.10176375673543062, 0.07111028828207525, 0.16933595220888817, 0.18755957514287966, 0.101610837924865, 0.09913504093645081, 0.16534071175321458, 0.15183200759272422, 0.17114511480735195, 0.11055070095725598, 0.09573895018547775, 0.1696669175139358, 0.30858674296928995, 0.14890755887233442, 0.18568439108710136, 0.23682596943070813, 0.21710277535021308, 0.09703481089203589, 0.0863851162214433, 0.08513097666324147, 0.18799333412560726, 0.1263067929915363, 0.11111950591927576, 0.14230135287488663, 0.15891626777668155, 0.1687428622596687], [0.08251944421640328, 0.07135340628484566, 0.03903978316473865, 0.06809195548656487, 0.027854026130010045, 0.03824340412393212, 0.023388679650041367, 0.019890503852718303, 0.04471644105750226, 0.01634197118091247, 0.011070260661654176, 0.02490024390299955, 0.014637250306775734, 0.016496828193926526, 0.02802658168929479, 0.043592666681375236, 0.006803767145386027, 0.020675525640047366, 0.08361100459531431, 0.012470474992428097, 0.07708693854510784, 0.12053164683522717, 0.01987886889236829, 0.06582083420888071, 0.011563493922773388, 0.0484069891934914, 0.09257374301312432, 0.026476111661102024, 0.0780095152496811, 0.061169259415398684, 0.12670369548422675, 0.030529312413906863, 0.010110852364901333, 0.019022637317257545, 0.0645720879096658, 0.047857259820786216, 0.01684856980348066, 0.028634746333644278, 0.03645491823854466, 0.029073818136126767, 0.016683663632119858, 0.03107509451858219, 0.029891350779742486, 0.03131938080543713, 0.05974877918619783, 0.051647204034511125, 0.0763119256965095, 0.05252345540230313, 0.05697775872484331, 0.0249966828813476, 0.04781353152206829, 0.045065681389983625, 0.11144415865982733, 0.033420865318828055, 0.02442246933858241, 0.022260417913897865, 0.06119733270738394, 0.06684703196609212, 0.047372759004393895, 0.19249152662532945, 0.0524467240358072, 0.05035903868115237, 0.060166818044719204, 0.041759498717804114, 0.2598104457701406, 0.3490870536094712, 0.053041376804392186, 0.471348189899037, 2.423289812380268, 9.84520600688073, 19.491932238301924, 26.32843125251032, 40.95716968659432, 76.79423424505418, 79.74443712542134, 92.55179159102902, 105.40588501961001, 103.81783500794442, 120.35365335402952, 125.40557984382876, 117.16071851791875, 136.32552116147934, 127.07452481792821, 129.05418426759783, 129.8934773475893, 126.50277660739039, 140.9487718151462, 133.5951122160881, 143.50788301037204, 137.26508571255593, 141.58523128878687, 134.75666722943706, 135.78322995093563, 140.8995068457819, 135.8315221724972, 136.47722275026385, 130.67799845049458, 107.90075563615369, 66.2837883733934, 31.117121596490186, 14.356753441595263, 4.596585400642888, 1.0905211346764718, 0.22714131571833165, 0.4038191021930787, 0.48717096988712594, 0.1438841671352425, 0.06405783989917367, 0.058976079923130816, 0.14879295211886207, 0.017035644644150333, 0.09272885283515339, 0.16451897520211436, 0.028723141388787378, 0.03151826489145958, 0.01180462201216048, 0.07687673934044377, 0.025736503565924305, 0.007274991658050568, 0.03478240274313477, 0.07078508395821818, 0.05014239667704509, 0.08699483027861965, 0.06592110745728978, 0.009116455875036698, 0.02859214801461466, 0.08193271279695534, 0.04484617421703954, 0.025380247783276345, 0.019008294236095204, 0.010929929633294384, 0.007214122142026862, 0.0670652138069272, 0.05991171459637343, 0.03355283162466461, 0.023785252724924398, 0.048556548708509055, 0.10922898478325337, 0.03830846797134127, 0.01041745320112715, 0.020804812553368753, 0.04452379675762308, 0.028158791228047306, 0.034112711662366506, 0.04646417106531801, 0.10100729853635836, 0.015501795851084736, 0.028954317996038065, 0.03965485983738496, 0.08032198995351791, 0.021249829198143656, 0.039823483450398336, 0.05814579383079564, 0.02355994626639351, 0.004343246907791904, 0.05833784058209389, 0.06957173858198427, 0.05764738085769838, 0.019730471915775732, 0.08852161286819367, 0.04510718803372114, 0.045496448799366915, 0.03775077511466319, 0.054048242332834395, 0.07534891487129274, 0.06497054556084257, 0.04029771102772605, 0.0509585484471773, 0.03537707849435749, 0.018074973148383924, 0.0866050907080212, 0.03286661985780924, 0.008883341065337582, 0.0056873797720688735, 0.08876786417057438, 0.0356696283204421, 0.01528254244476557, 0.014061613755691198, 0.0675392919971097, 0.06744380679822738, 0.015627821145068495, 0.05161760239711693, 0.020187767034757043, 0.054838144100241126, 0.026280332146392717, 0.035041068500328454, 0.025039564652909196, 0.03678716291042586, 0.00895727429569008, 0.02126884733086392, 0.028892998403358846, 0.02571830323206321, 0.006019421909455091, 0.028229234927904703, 0.10408368547477069, 0.024451992451964367, 0.030418202851808844, 0.0840387497878363, 0.03699808606817838, 0.0704268918883416, 0.031581423095157074, 0.04981639179130716, 0.11998110540932226, 0.03356589342377359, 0.04229806235901291, 0.052632592287996126, 0.01901675184677926, 0.06474337750865568, 0.03568388138627333, 0.06457901334450131, 0.019314516816408406, 0.05750009279337622, 0.027251264320746548, 0.07359697137989345, 0.12828998778375889, 0.0324677178756364, 0.05655114734244924, 0.02406034532243446, 0.024963708541866754, 0.039519982397436135, 0.021395115857763637, 0.03726869513611159, 0.0507829764166907, 0.04010996969056226, 0.051063318631701896, 0.05700475183285533, 0.12481859058982904, 0.03258584480312082, 0.019498965890717604, 0.030171359746506622, 0.020623757248564113, 0.024943391890114835, 0.0420380138131159, 0.05173549566778445, 0.06424724364713316, 0.2805177410764079, 0.05450925106302865, 0.07547073051213257, 0.13674094882463256, 0.09538458089434332, 0.21751997151201774, 0.5110062941187813, 0.02154110923349377, 1.0172390637378539, 3.9333670273903882, 13.90341962537458, 27.46195700860793, 36.10181670035086, 55.23206718506352, 95.49414973105155, 104.22797372264247, 115.6033100620393, 127.8032619722428, 129.83702659606934, 146.6080302576865, 154.93983484083608, 139.616970246838, 156.47787463280463, 158.6954729018673, 151.058618176368, 156.86308276268744, 157.80234921363095, 165.18784276900755, 158.23688507080078, 167.45420394405244, 161.13477922254995, 166.57306701906268, 162.36033162763044, 158.71616732689643, 170.91884920673988, 161.43110644432807, 162.2691600553451, 159.95974694528888, 137.9018589758104, 92.46666046880907, 46.82708686397922, 24.36705397021386, 9.782747164849313, 2.863560174742053, 0.06254599985456274, 0.14826180803919994, 0.4351828337436722, 0.1315178532874392, 0.07228275520666953, 0.019982832769352584, 0.06001352002063106, 0.14139677157565472, 0.1617369422268483, 0.06150629213680664, 0.007603516973059385, 0.03963096172458703, 0.027142340024452538, 0.013550293158679722, 0.06489926874036751, 0.05105440136826327, 0.01473566483435852, 0.005127647206292398, 0.03500885833355208, 0.04180333043839182, 0.06868091622187246, 0.008863907329918397, 0.14281516804570152, 0.017504597706119382, 0.038078262380534605, 0.032529387953540975, 0.055131429370733044, 0.04447855160481507, 0.05491258486384346, 0.030007349898017226, 0.019590710665309624, 0.03524503941016813, 0.032588794241629304, 0.043399838520394224, 0.05872161615820182, 0.09357211645692588, 0.03137165098451078, 0.05141777219250799, 0.00965419022606746, 0.04180263712882035, 0.024157014127159794, 0.03546724321260568, 0.07525338370713495, 0.0374157227305395, 0.012761533819890071, 0.06852363071013844, 0.045094061117138595, 0.058409577055323514, 0.016146304664171992, 0.0887592226987885, 0.02609083838310213, 0.06753261171040997, 0.019114271009100542, 0.044635457903026574, 0.042930762884357286, 0.03607390823984339, 0.04172791674312565, 0.018938210597562215, 0.050455741959834294, 0.0431807182218519, 0.020853823028324593, 0.13103819031628872, 0.0370831907756867, 0.08209248043356404, 0.021417966345325116, 0.040270909441695105, 0.020095012939324784, 0.019528674780421203, 0.005875295873040394, 0.010424234994476842, 0.020415130439364625, 0.032828641048963034, 0.03595220751219219, 0.3403453162360576, 0.14062421786929333, 0.20232853990408683, 0.1525011087857908, 0.17168205051172167, 0.16412126831710339, 0.10063385365590935, 0.13985385517439536, 0.1454901785379456, 0.1493514608591795, 0.13757822163883718, 0.11554299718550137, 0.1723294560947726, 0.10521397925913335, 0.13602289461320446, 0.1360376647883846, 0.11184908209308503, 0.13243230179913584, 0.2030758893177394, 0.14389968807658843, 0.21917697372696093, 0.2134771723180048, 0.06863538761653247, 0.08992713140023333, 0.19225036214676597, 0.2543999191613928, 0.17091119752055214, 0.20092335078985463, 0.1415037021281258, 0.24075333449629047, 0.17812322584852097, 0.13393646947318508, 0.10864213078973756, 0.13409612219660513, 0.1455618384023828, 0.21487778022644982, 0.26356213155292696, 0.12562276840570474, 0.332580003887415, 0.14377487703196465, 0.14236904440387604, 0.07677026077984803, 0.1322120361991467, 0.1342721385580878, 0.14183361023183794, 0.17832968654411455, 0.2633778107983451, 0.11506167180355518, 0.1423311843386581, 0.13207748051612608, 0.3143048232361194, 0.12291076352759717, 0.2610878207750859, 0.07058734900408214, 0.043570905953886054, 0.10545662994826994, 0.1987102606724347, 0.15511466370474908, 0.26356213155292696, 0.37908203118751127, 0.1700028317469743, 0.13468479947938075, 0.33673811463579056, 0.2159505178250613, 0.5448842036627954, 0.5728852688785523, 0.17485000793972325, 1.2211179204525486, 4.866906817882292, 16.261143588250686, 33.1915121693765, 43.128413384960545, 67.40025966398179, 108.60544081657164, 117.21294879913331, 133.13478285266507, 149.75755230073008, 146.1836454945226, 160.19541863472233, 166.67451520119945, 156.73574693741338, 172.041619823825, 165.40341623367803, 165.32299195566486, 168.16121901235275, 163.68869719966767, 182.13938528491607, 173.91447313370244, 185.16714126833025, 177.77427365702968, 180.3706003004505, 177.66033664826426, 179.6901632124378, 187.07881035343294, 179.42730165296987, 181.61562335106635, 178.84178592312722, 149.08955697090397, 100.13303495222523, 49.549823653313425, 26.516910945215535, 11.63543458907835, 3.8212725520133977, 0.2823543602660779, 0.47498149977576354, 0.5728812239343121, 0.32377391512836184, 0.15881309105503946, 0.15828560887565538, 0.2654325811853332, 0.21407230006110287, 0.5045854967207678, 0.3842511328478014, 0.1357664849849478, 0.18627191923799055, 0.10571662486801225, 0.24285102112879678, 0.1399605099352137, 0.14400444293935455, 0.19242332947831, 0.1197798770942515, 0.16385304561305433, 0.261410343791208, 0.1649914522685351, 0.11548813762924365, 0.1651318761850557, 0.13438090772157715, 0.14089987162620793, 0.11050893384362422, 0.1596677847086422, 0.1197333602354892, 0.15348810582391678, 0.13819620944559574, 0.1373366281510361, 0.20235875441182047, 0.10359486775292505, 0.2144603542382679, 0.11852846480906011, 0.19606618481057306, 0.08673995282621154, 0.1669988631000442, 0.13408211810934928, 0.1193134214789156, 0.13894374272035015, 0.12408146078908637, 0.23020209744572642, 0.15908099200216033, 0.1861625218824033, 0.2662296803487886, 0.11671390895160938, 0.1706756408055944, 0.08871425333763323, 0.21432144717583734, 0.13513110698230807, 0.2639895779711585, 0.23739826775366263, 0.1858457751692303, 0.1601999093808474, 0.1147367662539886, 0.17235512004023598, 0.15014028627305262, 0.23145215375529182, 0.15723170171822273, 0.09306220833452479, 0.138766638514015, 0.15113471436404413, 0.16104943960184054, 0.12646159637839566, 0.17427587100575048, 0.18870040263620116, 0.18096412501988873, 0.13157491151603962, 0.11813603626984744, 0.15222294226048455, 0.15239096066403776, 0.20245552663841557], [0.01246904049278988, 0.02176869288837958, 0.08267621644922803, 0.024449678866433042, 0.07486942043948559, 0.03597582983333738, 0.10220497741454071, 0.04312355657138171, 0.04823687170902568, 0.09183228481560947, 0.06818794630347721, 0.07933015890058973, 0.04861767103354778, 0.004874508773472401, 0.07191299520913633, 0.038323100250695026, 0.046744141727685935, 0.0706653367547739, 0.01643199608811448, 0.07095681788820414, 0.06495881675472183, 0.05264479989906954, 0.01905477470568111, 0.03943109321558187, 0.030079837137412642, 0.03344498559712403, 0.0198812686627911, 0.032995230698537444, 0.05530395620172063, 0.09368083199426051, 0.021900737718228373, 0.036755711170694524, 0.038957830909038746, 0.025122328961808837, 0.01761139036276408, 0.07922784019742282, 0.05732504553311775, 0.04738607361251789, 0.07153914430208745, 0.0183968698876279, 0.014389656435307718, 0.048007351766911247, 0.07821357042919244, 0.004663808260022873, 0.007286896185588933, 0.027577167699834513, 0.039920106289848205, 0.077736244026211, 0.07483197406174676, 0.04211508608873814, 0.03170023950177335, 0.061214121524244554, 0.03997929807331774, 0.05826359517091225, 0.09017442458219106, 0.034996030191260005, 0.004771671524541754, 0.04578570061693749, 0.06612618919461966, 0.03238738206545672, 0.07569906301796436, 0.22953264385221467, 0.3868021137051044, 0.333923660819569, 4.336195424679787, 11.33530462941816, 42.959845604435095, 60.073809546809045, 86.346554909983, 97.5477223242483, 114.01841363599225, 112.40826499077582, 108.76297889217254, 98.22260533609699, 104.89064247377458, 93.72073634978264, 81.97490861338954, 82.33754742530085, 81.47490839804374, 63.8886675527019, 78.00779204214774, 74.24598017046529, 56.54154654472106, 66.30864835554554, 72.74808191484021, 71.22631995908677, 70.22180880269697, 77.79102617694487, 86.71440262948313, 81.49355534584292, 90.52460870435162, 97.16616984336608, 88.64964515932145, 97.24926917783677, 92.06513527900943, 99.1252290048907, 104.22718140386768, 110.90151002330165, 122.67200162333828, 138.50853981510286, 119.23822541390697, 118.00275725703086, 93.97226225945258, 62.63782370475031, 35.13513680427305, 15.570911361325173, 3.7161491090251557, 0.2814403560853774, 0.0654197182326067, 0.33669965702199167, 0.03604168658174815, 0.09773236459061023, 0.15917594093949566, 0.026784239885126872, 0.03943248749560407, 0.04538558055496505, 0.08627195737414783, 0.09214878638064669, 0.04611595346021556, 0.01906177483408922, 0.02505615237168968, 0.08242850191891193, 0.045048383124653375, 0.04425297701551069, 0.08835961591572532, 0.04563106193898186, 0.04469408661187176, 0.06776436096838406, 0.01848855337518598, 0.017732715707332376, 0.0034794494962214584, 0.043292176353955464, 0.025964862884833448, 0.03301778049658864, 0.025181319647198244, 0.009768365097472505, 0.045707222569974205, 0.01752139801429885, 0.045128581039006674, 0.0377696591819967, 0.026407081393464923, 0.04459222756145943, 0.021548009770471725, 0.045418135461307345, 0.047331378765163884, 0.03267987060450739, 0.0395508136059488, 0.06437342598914139, 0.062342886963198264, 0.05379851299127745, 0.054478607546057434, 0.0362175535560856, 0.07557444349532166, 0.07518050576289816, 0.05572359618400374, 0.019357457959784136, 0.04311216867438728, 0.05390268562722111, 0.0014109702052308188, 0.017740167827615817, 0.020321993299970226, 0.034347195854230274, 0.05622319659338363, 0.05585220702473195, 0.06637133733038941, 0.05485201412211022, 0.043153510609221075, 0.03688136491203501, 0.0342782594323639, 0.0694450659437045, 0.021391743155676993, 0.04553264645378917, 0.015083357669232834, 0.11210196005601077, 0.04890041110376197, 0.024134868440488656, 0.029154962169066555, 0.031997527581669634, 0.0362746998847973, 0.0343599435572903, 0.005655021654562124, 0.08276862963553398, 0.03113494130722698, 0.033729782613414916, 0.08637881131782647, 0.03376038782598992, 0.030729025790107348, 0.06523465437273826, 0.014357700035156263, 0.009448530092354744, 0.05224476793720838, 0.02909679694341556, 0.016260704573904796, 0.05778123557026829, 0.0050749221625136995, 0.007982843972352004, 0.03363229026417098, 0.03649879975484745, 0.026519163887226777, 0.05132969506385346, 0.09268331656893415, 0.027481542689906015, 0.022662118032214143, 0.049500097070009484, 0.03518490533855173, 0.052501664031296975, 0.030029175742979974, 0.032711797318751776, 0.06830430739829618, 0.04383539780974389, 0.023726353970085903, 0.04033698452516429, 0.06371658603330294, 0.03581970877524826, 0.03919227296606668, 0.04231905316813819, 0.037273536811793045, 0.08021292967661735, 0.010278692653012133, 0.02590180044212649, 0.031377976955545527, 0.032599285815752325, 0.045015058299947175, 0.020089110231868202, 0.016343131804117755, 0.011378471240130885, 0.03908897750079632, 0.06303907319482777, 0.03127019604547851, 0.021674852863314654, 0.02603653424058951, 0.03681381510931157, 0.0666773971170187, 0.03863017127338437, 0.06966474931687117, 0.20460518467570507, 0.049496737774461515, 0.18231015682460802, 0.275019466756813, 1.2796763330698013, 7.419013640572948, 18.212117764257616, 58.05121191086308, 79.4552250831358, 103.22747122856879, 119.01788234710695, 137.2367975788732, 139.66408575734786, 128.7456584745838, 120.35843864563974, 126.18529212090277, 124.51297390845515, 104.7492096501012, 108.19726328695975, 114.63976413972917, 101.43979610935335, 113.77703097558792, 111.06229582140523, 89.62729592477122, 109.33754336449408, 99.12810802459718, 103.09485589304279, 106.32229974192958, 99.72510060956402, 108.9674363597747, 107.6333127483245, 123.49914320053594, 125.08877784975114, 118.06667620135893, 125.58237675697573, 119.64422210570305, 118.15260748709403, 121.77693243949645, 126.11362257311423, 143.02784765920333, 159.77255575118528, 146.29607631314187, 147.8915709833945, 125.35907622306578, 87.63004856724893, 56.731475553204945, 28.61446507515446, 7.92822995493489, 0.9590385673988251, 0.021986388263382742, 0.36170608454173614, 0.10069766111912266, 0.01297113739119302, 0.31098352564919385, 0.029240216263720108, 0.03614705431485369, 0.03704015195610062, 0.07166131234337246, 0.08296385948215762, 0.02348650333231255, 0.016948364246937058, 0.03508357488880715, 0.05345959186313614, 0.03837373866248996, 0.0387666804806119, 0.09656338336607141, 0.0706208423681317, 0.044015206306451754, 0.05118585056475094, 0.018696427502999866, 0.06247335173670323, 0.020432976457560738, 0.0063202344726080145, 0.0518888664702254, 0.08719235072813689, 0.022534844014913808, 0.04366012072310813, 0.024037460360916394, 0.005723881946441027, 0.009458730553066539, 0.01190938740863555, 0.02104364046376319, 0.06477757567359556, 0.01365223935159344, 0.024220626237952424, 0.057255703084651506, 0.055089183452148596, 0.0376247268380417, 0.08350973543260368, 0.048343545622042114, 0.0365520888308604, 0.029482077882294695, 0.034819967864501866, 0.06938262977787564, 0.03622373971607416, 0.024292602113658385, 0.056642959149734634, 0.022559854870421753, 0.012578558507225206, 0.06932139637008791, 0.07317266592215146, 0.01599219650210392, 0.02827702349262132, 0.06573461867388218, 0.06387282583502031, 0.04505250850812562, 0.054762404817607135, 0.026797543001932003, 0.05248929937219909, 0.024902553658091256, 0.01342209313260091, 0.03614101754201036, 0.10484372130444936, 0.05930492316462821, 0.043264447801536134, 0.08441383409644328, 0.06428649799237329, 0.15506719689696066, 0.16268715172285036, 0.1868667099024019, 0.20129531712060977, 0.13170255708598322, 0.09665643240535453, 0.2406661230469904, 0.1232210214760515, 0.1237252222434167, 0.13821951384025236, 0.12010620756735725, 0.13305588204774166, 0.16654575273634928, 0.14544952991268328, 0.1727229954614755, 0.16602202438779418, 0.10213612909278563, 0.21892011976770817, 0.07836117258956356, 0.11506041541935937, 0.11621800491646414, 0.11960740771985824, 0.1319247838710585, 0.19093108213236257, 0.2857492329372514, 0.10558727858287674, 0.1374143247883166, 0.13571265964738785, 0.17556285275326622, 0.14734634829144325, 0.12417085558897066, 0.09241202951318796, 0.1386722718035021, 0.10350446171698072, 0.18487054524162125, 0.1836616125318312, 0.17142812300833965, 0.14307609759271145, 0.10346514608470664, 0.17326750011453707, 0.15670089471724727, 0.1826326951624886, 0.20937095636561995, 0.09363337284735135, 0.1406324609753586, 0.09090035417748075, 0.19516004069197565, 0.1517867011528823, 0.17941655080404975, 0.12675208159752432, 0.1735365195500274, 0.14487740012907213, 0.138440836641577, 0.15528338690919263, 0.16858821975127344, 0.14920527596146832, 0.17326210685555013, 0.18221024363752336, 0.17113564596060785, 0.3314796871235294, 0.13194462554829736, 0.4235103504071313, 0.4652844814042892, 1.6955185417206058, 9.121259047139077, 20.38596591641826, 65.44668005358788, 88.10799721748599, 120.02399383052703, 134.06414924129365, 149.26763257672712, 147.60917602046845, 138.26569803299444, 127.04818217985093, 139.38336956885556, 122.03536956541001, 111.01566668479674, 111.64480701569589, 110.98697062461608, 86.26959800720216, 106.40993333631947, 105.20956254774525, 80.52861305975145, 92.35371974206741, 99.57134369880923, 103.83714091393256, 100.1691835157333, 107.7324624215403, 114.71232014317667, 108.74193929856824, 119.31534705623504, 125.92580379978304, 119.39839932226367, 123.06855324775943, 119.45539920560776, 127.11553712044994, 131.51820152036606, 139.01978154336254, 157.588768313008, 177.94401814860683, 162.26269598930114, 159.58716884736094, 137.7824306488037, 93.23583725960025, 60.78854383960847, 30.353887196510072, 8.374643729579065, 1.0279349994755562, 0.09814588353037836, 0.5713199980316624, 0.1863618273167841, 0.2238157433607886, 0.46862364416160895, 0.13371191378082, 0.17105908313345525, 0.2780392014932248, 0.18676250662294128, 0.1350153510969493, 0.14578098551400248, 0.1410872873760039, 0.10486393070389187, 0.26568646272343976, 0.13291032534212838, 0.14243076044705608, 0.22373384856168302, 0.11668750190085943, 0.1344351773901332, 0.22350831227677487, 0.10640398193631442, 0.14893167532019078, 0.1526682844926273, 0.1143979715303548, 0.1456231714016007, 0.15650161992638342, 0.15696979157866972, 0.07348906789575854, 0.19072452950621807, 0.08466368601206811, 0.1574825648699076, 0.13926422794259366, 0.11610889867428811, 0.10369690300355996, 0.1528047553954586, 0.18156930383655334, 0.24574974461668925, 0.11349037184470123, 0.10400715329113508, 0.1491840859694827, 0.1926411895622169, 0.11350313486951975, 0.11180461834995978, 0.20152914247685866, 0.2408284570781454, 0.1367714544457774, 0.2095792863157488, 0.13414314467339747, 0.16455574742247983, 0.1387473637418401, 0.11770351834955717, 0.11864364612847568, 0.07685248499676105, 0.1593514670047068, 0.1486290552683415, 0.14608142987614678, 0.1321512394614758, 0.11457975653390731, 0.12630461730183135, 0.1980561901244425, 0.1653917791742471, 0.1508183353730748, 0.18024904322960686, 0.22637602452549244, 0.17309301592890294, 0.17318473197519782, 0.1406919706853167, 0.14120978483509633], [0.041924514056694125, 0.05859305128274907, 0.02879402175876162, 0.027838422834212263, 0.07841407862161437, 0.08369249336782002, 0.04913651557158559, 0.03896756022567711, 0.025856890452785358, 0.014147549668597359, 0.04067924579665546, 0.0602701747970235, 0.07553338884345948, 0.04294719163989348, 0.03903556202027587, 0.06486627333346875, 0.04667363482557478, 0.013003063147827502, 0.04869204667967655, 0.09280949125006314, 0.044920584337124904, 0.029084692754211928, 0.06418894818653503, 0.08614193693163895, 0.1178119810778768, 0.025178069519179485, 0.010515383178097828, 0.0671357092177195, 0.054978529712365526, 0.09094972088332139, 0.12586558763418468, 0.06290168681692693, 0.032252209681657054, 0.07732028126596444, 0.02202154212300816, 0.03093410369699761, 0.018089739493124427, 0.029836454834308357, 0.06964797199132942, 0.034163886335708445, 0.030026988561956153, 0.03783817808594435, 0.04830285869238358, 0.0719246780499816, 0.054303824586132844, 0.024450448784796942, 0.05258059790057521, 0.07349461437233033, 0.026394743547444383, 0.02646003339079119, 0.01896769349132815, 0.04674848927665622, 0.08233683949877178, 0.007323164224339229, 0.058031669712715575, 0.046088856930333766, 0.11714145496127107, 0.06671330365802973, 0.029020848901822206, 0.4591939291886745, 1.3142876951925218, 12.132470473166435, 29.496651234165316, 56.58109972553869, 87.36066018381428, 91.83192683804421, 101.64175894952591, 110.05179912813249, 83.3910019167008, 75.60002942239085, 67.06834085526006, 64.65002705973964, 55.23727609265236, 52.280397338251916, 57.875419124480224, 59.13025986763739, 79.08900906962734, 56.03424679848456, 69.14352570810627, 51.75124214541528, 50.27761551641649, 48.751103570384366, 74.52008324284708, 48.93258379351709, 68.30245187205654, 50.44195105952602, 47.25952033073672, 55.180248752717056, 62.68702199382167, 68.00719937970563, 51.268621952303, 70.83810729365196, 68.64478849595594, 58.87408594931326, 59.45245512070195, 93.51442752345916, 75.83286131581953, 82.67793070885443, 68.59859866480674, 83.94688021752143, 103.4021657513034, 102.46417014829575, 110.94972379745977, 121.0264810439079, 117.13446217198526, 117.81099257930633, 104.50332410873906, 71.88137931208458, 42.28775532014909, 12.932614376468043, 1.0582856257115643, 0.14280245098615849, 0.44019718564325766, 0.165103362392514, 0.07664908865286459, 0.11165083386003972, 0.06402215935410031, 0.03759625134989619, 0.009718554060635789, 0.014943731441763381, 0.07386788305255675, 0.10920211041886961, 0.02210876123318749, 0.07389274260569965, 0.03481408813968301, 0.07583289091745693, 0.04163949870534482, 0.027045655897968722, 0.008304696661540338, 0.020276133361602985, 0.10685142324936968, 0.05282879889672322, 0.01982824388711203, 0.0358649424367374, 0.02605756909977044, 0.05445379012775037, 0.04590612580819477, 0.04206114200754993, 0.039855421655961586, 0.051102427420236414, 0.015447048335185936, 0.006327660258619056, 0.04982920844228037, 0.028569213257381515, 0.07475980857927954, 0.07281978284159014, 0.013620470642983435, 0.04106266131143897, 0.09231282112699363, 0.03922914860830192, 0.056438850344068585, 0.03589172487057025, 0.08003057010712163, 0.054094682582804275, 0.030450336409792788, 0.012092236316792909, 0.03548862089613273, 0.04608160973857007, 0.012872692220093263, 0.030358493958990422, 0.022947384277358655, 0.0264673380391492, 0.03401225072241599, 0.08971396743530229, 0.041792099589421865, 0.016014598828229695, 0.08706071384010777, 0.047570666328312895, 0.07429205827535161, 0.05689404446691756, 0.021504654939616882, 0.040468698021985834, 0.049881264116735234, 0.06878221602810007, 0.01750744180753827, 0.02531549994713597, 0.07076371010513076, 0.024026376983871865, 0.009237541817128658, 0.019645918791572896, 0.043342205725850604, 0.042886540458928195, 0.013069852608286086, 0.04793781779646393, 0.09907165482159584, 0.04763189973610063, 0.08205308819249754, 0.029086161727806734, 0.010052488913999931, 0.031312091478837595, 0.04157314399978326, 0.021122509215567863, 0.0981591368514684, 0.0434376334681386, 0.06796195802669372, 0.06652227963411039, 0.08267471491689644, 0.036041096694046454, 0.015026664290006363, 0.07381318437476313, 0.027302739683598764, 0.048040305038974176, 0.03657440497209469, 0.05230824981305388, 0.017861060332506895, 0.07743122611915873, 0.006516367345372396, 0.08349342542069574, 0.04902674283291544, 0.034484406031908534, 0.07960277128844492, 0.042047394559748714, 0.04422372777856166, 0.05194911928547006, 0.07809491873147988, 0.0020665973481241496, 0.03477441244608453, 0.0253658683129376, 0.02358644907813399, 0.03633661511083765, 0.018196059090475884, 0.01930237623802837, 0.008835312140534722, 0.0823143088529187, 0.00324911821911472, 0.02881773601045772, 0.02024407641241147, 0.04946723572849747, 0.07412816908571028, 0.013502198158793393, 0.027099975362239827, 0.0879423201624905, 0.04077605632764678, 0.059549753373909387, 0.035677247064849066, 0.46899749506865784, 2.638848077866339, 18.652264571958973, 42.8301053662454, 76.2198894254623, 105.91009001578055, 106.5768615661129, 118.69127442759853, 127.53021793980753, 114.09585691267445, 103.69362923406787, 100.4567010941044, 98.05710484904628, 88.62955477929886, 93.19126344496205, 103.21422930686705, 93.32916613548034, 110.865643870446, 85.6728329197053, 105.91573038408833, 76.54747009277344, 79.89289099170317, 81.13982031422277, 92.65209444107549, 70.92445435062533, 101.35144864359211, 90.17512552199825, 81.24853272591868, 98.11727400748961, 108.10808427872198, 106.10473371321156, 99.35465628100981, 117.09068852086222, 108.6622053577054, 110.42268276214601, 96.15272352772375, 142.3053470734627, 126.53603046171128, 123.27294011269848, 111.6559700812063, 112.76447111560454, 133.7700342362927, 122.43315281406527, 124.82437087643532, 141.51975908587056, 140.0182444049466, 141.03184761539583, 135.53484978214388, 97.48474474876159, 63.87889692860266, 25.66255988613252, 2.8695503694395867, 0.12416761503705095, 0.428494579729534, 0.15999321885887655, 0.038396039481965766, 0.13312219461846736, 0.025536259673836253, 0.01994455901665553, 0.02397345946050219, 0.02246836482006456, 0.10654423731349169, 0.10655696203391399, 0.04945834144769658, 0.03600739648625736, 0.09255322717851208, 0.03606492968937082, 0.026116904524725773, 0.04381782758320051, 0.020458839585884445, 0.03181210940613622, 0.056059518077921484, 0.03579541612716933, 0.03163278737526027, 0.056873528632305326, 0.054110847038006595, 0.006686309587225439, 0.057536367056590904, 0.026293081764672554, 0.07193757130974723, 0.03262103888236227, 0.04921610827647871, 0.040821925842113076, 0.06992494341947379, 0.030846876925939036, 0.07269612858973204, 0.05669849286336572, 0.1012709170519825, 0.056398339614632635, 0.02247014214404889, 0.05361954719128628, 0.039576921882408286, 0.04198912591222794, 0.03677444202044318, 0.02145132564398791, 0.011856228567569727, 0.1175922210959177, 0.06315841437167218, 0.017142617331457236, 0.027347948447230364, 0.04522637216254108, 0.042662291201732816, 0.06173838613434665, 0.02816544087123006, 0.0312647357537982, 0.0490820735332466, 0.01605732259415691, 0.05574023178327949, 0.02835637104937867, 0.1026295893074524, 0.02896544733835805, 0.039319891722932945, 0.02859539814263342, 0.09412998934426615, 0.015248254264494585, 0.018519206468256253, 0.08184980676178971, 0.12752213785725255, 0.12601577917173987, 0.0955965880665087, 0.12311939991289571, 0.24221827846861657, 0.19751229834172035, 0.10853297858228607, 0.20121593508989583, 0.1289656466894573, 0.17641515621254522, 0.20103351423336616, 0.21252061961398971, 0.21880643231974495, 0.09860279369017771, 0.2786465253560774, 0.1168683675989028, 0.20724927585932518, 0.11095036136647386, 0.2176803290363281, 0.1334791762694236, 0.19315285968684381, 0.13737073438542505, 0.19166263481301649, 0.18462190374491677, 0.19686423392305452, 0.13880374781306715, 0.1244377836044277, 0.17391441540131647, 0.10754571341338659, 0.2297658869816411, 0.20355559825416536, 0.14546970866860884, 0.1312393343616878, 0.13511698032098432, 0.1456021959142339, 0.06332121954690065, 0.17440017643234423, 0.15237075126459523, 0.11058079289092172, 0.1025132205517542, 0.1544715482140741, 0.1678930409252644, 0.1658320652260896, 0.17259177992180472, 0.14383904455650237, 0.1463204339867638, 0.26089816804855104, 0.23606476914738458, 0.1402578746239024, 0.11876982847048391, 0.09885888156150618, 0.20478906109929088, 0.2974480696983876, 0.13321843058351548, 0.16845182545723456, 0.3369836917807979, 0.1385009898653915, 0.1978350665059782, 0.1307703353344433, 0.6023836989075907, 2.831165074340759, 21.51924848556519, 48.22807119738672, 88.07464138154062, 119.77302489742156, 125.23787498474123, 133.27854556422082, 142.0145582383679, 110.33881464312154, 101.21705255200787, 89.16784517226681, 88.00666670645438, 81.66899511891027, 73.7974649860013, 81.83076150955694, 82.60840277517997, 113.16550208676247, 79.93125177198841, 93.98919905385664, 69.98175190341088, 68.77988276943084, 69.83623197001796, 103.03663223020493, 63.92902481940485, 94.03208624932074, 69.75959670159125, 67.25652833138743, 79.81155672381001, 93.11889571528282, 94.03345123414071, 73.24666223218365, 93.86813902085828, 93.37013921430035, 89.48137590962072, 86.27605422850579, 124.958845415423, 111.27080117502521, 117.0832517070155, 96.32124423980714, 112.04724219537552, 130.82490690292852, 133.4020845351681, 137.44510681398455, 154.9782270000827, 154.86242294311523, 159.5385471467049, 146.19376520956718, 106.01493497048656, 70.47893585697298, 26.61562131297204, 2.3102931918636447, 0.17124731093645099, 0.6360967769738167, 0.34699731896961894, 0.21897494101956969, 0.23711365076803395, 0.21173770839889205, 0.11235453158376679, 0.1497826764299985, 0.22327727548057036, 0.15720222265489642, 0.1764604320088702, 0.27109844489924373, 0.1744160804176523, 0.18545163825394648, 0.1907435591302572, 0.08677366069487988, 0.20242106800358142, 0.14136917708862212, 0.10747534823754143, 0.30178728363206314, 0.1583783208362518, 0.13474824688126966, 0.17312336833246295, 0.19801194088593607, 0.11374213898013677, 0.09402010935328661, 0.13474971777008427, 0.20715068034347028, 0.0994639531258614, 0.1529289076044675, 0.12331213231288618, 0.1430141976884296, 0.17235918030623468, 0.18302479428389382, 0.295692992907378, 0.25386039407983907, 0.17092472663329494, 0.22170628961776534, 0.18537361985973774, 0.16443894965754402, 0.164990471675992, 0.17456961975943658, 0.240787364121887, 0.08566238887367711, 0.24790930050996043, 0.09322644992461128, 0.10192425215556737, 0.07557064369921723, 0.11366704704179881, 0.17470150945648072, 0.16614366382841142, 0.13429234795753034, 0.225664742531315, 0.20646267210043248, 0.2096676622186938, 0.22413938486528015, 0.17479106513482912, 0.16666035948982164, 0.13313606080989684, 0.057153169876865806, 0.10252395344357337, 0.13700178644109157, 0.21137847444943844, 0.11395815279214613, 0.13135006471026328], [0.04073354610872846, 0.08830879364282855, 0.022521217225960666, 0.05550591996119869, 0.06426644181051562, 0.02250972782231627, 0.0710205640643835, 0.03349735153718822, 0.04358611279918302, 0.1409031811260408, 0.019061617786064744, 0.06664601049476093, 0.04302753894139202, 0.031744446605443954, 0.03753115302853046, 0.018812020594674735, 0.034063528817627704, 0.013666009782032381, 0.05982683205436315, 0.030866657316143957, 0.014357452971800683, 0.018219143234854265, 0.04172382200317037, 0.03114158328953049, 0.048455540015692675, 0.00894922941487523, 0.05572826165946261, 0.08812176859787396, 0.11464499658153904, 0.045137203358594453, 0.01080811495006445, 0.07175697374247736, 0.12401049806466027, 0.03745793034472773, 0.02680597762997833, 0.08047552929530222, 0.03441013763808916, 0.08283052953981584, 0.03155937508469628, 0.048443359217696616, 0.02956785674717638, 0.05969029220361864, 0.05485492525622249, 0.013596832042469854, 0.01538088993965498, 0.016456302142732086, 0.04511741913794991, 0.0626214824977421, 0.023123653447856347, 0.05694587797587437, 0.03018501526375692, 0.05815646543558087, 0.01853315501413759, 0.062113397664600806, 0.03974899672152054, 0.014492849436318202, 0.13050951303974276, 0.09553776783568245, 4.229221113266484, 23.70117868146589, 63.76908625325849, 99.33123188634073, 91.3581515896705, 99.89253874747985, 82.09664329405754, 66.94180519350114, 70.20971221308555, 65.03330538349768, 48.89462701735958, 50.30244804197743, 64.59640041474374, 38.95166181748913, 41.714677426122854, 39.421801028713105, 47.04732794915476, 60.70894718170167, 58.62862010155955, 41.209801704652854, 56.605685141778764, 64.56070684617566, 56.52293882062359, 51.65575988831059, 47.81018187922817, 81.10280098453646, 29.531201431828162, 47.89448538134175, 45.98810365123134, 33.947027344857496, 29.76379013830616, 40.96875636808334, 60.64567150608186, 38.46050262451172, 46.55921251543107, 44.13321479674309, 50.24459700430594, 49.30864887852823, 39.83130431944325, 61.178776525682025, 50.82960674839636, 78.81376850989558, 53.067632721316436, 86.96773282943234, 80.56797796680083, 71.97965037438178, 90.7476346723495, 87.73940424765311, 90.88623554475846, 110.36507883379537, 108.10734687312957, 109.56161268295781, 76.89638060908165, 51.621968669276086, 17.264059320572887, 1.8847725348126505, 0.21282679431380766, 0.20181251840005, 0.03523376642636234, 0.03156905269039975, 0.03353281757764278, 0.05643538762665084, 0.056995007194458484, 0.1055876463050804, 0.05266953687814455, 0.08044006708528727, 0.049203146068799886, 0.0253223066383432, 0.022453901080054142, 0.00977462307820397, 0.02698338061060396, 0.06451272375641331, 0.08342168128658688, 0.0183627215184031, 0.020923146324592735, 0.024197685735059843, 0.10279826654662048, 0.06355738147131859, 0.056089200154547735, 0.04520197609259237, 0.040539335159044114, 0.06803722616525427, 0.01419339715803583, 0.03534295693821004, 0.040733542278288834, 0.10332816190296605, 0.037514379533428344, 0.06015485558178156, 0.05100813731851597, 0.030058237288387555, 0.01618331054135436, 0.04638516058724734, 0.030942794964498574, 0.05768411860410726, 0.023615328677659555, 0.03309172713347981, 0.02525472810732261, 0.07641180824007719, 0.035473421711715004, 0.03224126611565871, 0.009236209781750316, 0.06825742281733022, 0.045081390022870996, 0.05565276752496439, 0.011691009257769874, 0.052677703375417384, 0.003911350715732683, 0.05441303425017865, 0.0557151768777159, 0.025953183874427795, 0.03412781125535408, 0.02584178319891855, 0.0743064454065696, 0.05018605985828946, 0.014266574834173006, 0.05113882425751898, 0.007655662662845346, 0.04530848529670508, 0.038382089020864624, 0.038684391146225315, 0.012639888633613386, 0.03809049297424574, 0.06827407756880408, 0.03941857533889913, 0.044863342247422666, 0.058418099783481135, 0.04383321828959931, 0.06256827003052158, 0.03901185159901938, 0.020096028005824457, 0.06962141938387387, 0.07027339851183277, 0.030104526235992392, 0.015885631756616697, 0.03537069698194823, 0.040859828042166854, 0.02962300550162552, 0.016877083596022382, 0.017837102847894835, 0.059538955364616654, 0.042974326474171494, 0.017127772462704492, 0.011992952279416064, 0.00854935641625836, 0.06494747099256323, 0.033736562491544796, 0.051035969292805086, 0.05874985415909079, 0.012263819902023722, 0.0237488501419824, 0.02306854874346285, 0.07222627154401234, 0.05284930324001659, 0.09720168016370266, 0.020573178208583308, 0.038733608464920716, 0.026207802772161462, 0.009032647771340226, 0.04729048882220541, 0.08940524166269649, 0.03153763733984482, 0.03464567137040919, 0.021026886120859175, 0.03765001923086182, 0.03248369463929727, 0.04668577731917462, 0.008234885941830375, 0.09146126843388043, 0.03533011347415947, 0.0512515272824995, 0.08592989911595661, 0.1506074926545543, 0.04087957395841518, 0.02345664697068353, 0.14888304405875746, 0.1101904864152593, 7.4788621452546895, 35.366646858953665, 85.77217086668938, 117.54044317430066, 110.12978369189848, 114.29949852728076, 95.62248968308973, 87.15517505522698, 95.00202563501175, 92.58842652843845, 69.61717544063445, 75.74174465671663, 76.94011503650297, 55.52668033107635, 55.237460444050456, 38.75177391113774, 45.06222424968597, 50.33163439842963, 56.63997057945498, 30.840649412524318, 42.72708823603969, 40.235124095793694, 26.225374898602887, 26.426590527257613, 34.80115482884069, 39.03191351121472, 19.950973103123328, 22.885276655997, 19.892535671111077, 24.72007905283282, 23.29400331743302, 28.563831198600035, 37.478015576639486, 30.497789152206916, 42.437448655405355, 42.389882072325676, 46.393704183640025, 60.59095444217805, 55.042863815061516, 76.40792785152313, 69.73882382915866, 104.22205878842263, 91.35278578727477, 127.95433598179972, 121.10954115467688, 113.22987602603052, 117.62675100757231, 111.49842416086506, 105.15751269555862, 125.6710066333894, 122.65810858818793, 134.26462942554105, 104.5370251132596, 75.39536799153974, 31.718558226862264, 5.783709364552652, 0.09446034177897439, 0.187036965282694, 0.03587467175337576, 0.06771287985987241, 0.04801366433140732, 0.05439274441150408, 0.05070532957512525, 0.15400933672583875, 0.013620768459663998, 0.04860172491340388, 0.07920917829558735, 0.012318929394466743, 0.07802559543521174, 0.05344225529340967, 0.07655919589582952, 0.0654516104728945, 0.0798557258601631, 0.02901572185838896, 0.033098870903373726, 0.014338450160838906, 0.06220468853209769, 0.10521514371277825, 0.05037900676289874, 0.07835143561204595, 0.055765899559182514, 0.03861009210888897, 0.06299011634602662, 0.04242119950152213, 0.0437598921839268, 0.033853356426040974, 0.05420322191991633, 0.07637369536584424, 0.0810931263972194, 0.03211447473375067, 0.04878503826236533, 0.02172359137705738, 0.010510890072421923, 0.01949289464391768, 0.03946363280016569, 0.04423719560427051, 0.031383933289156805, 0.09071998643658816, 0.03182162230293597, 0.009206076670858649, 0.024408384812094515, 0.09159649061339517, 0.08152533788233995, 0.015094434343008025, 0.013906183134343837, 0.03659778980598335, 0.04413162102742542, 0.03863268021133639, 0.03263758638152673, 0.040059101452390035, 0.07756873124068783, 0.018872696673497558, 0.06762921539766174, 0.0701806788903571, 0.06088072389003731, 0.055013271799731644, 0.042322975538310506, 0.05082022361156922, 0.14660675168758439, 0.15044785525289275, 0.13540659219987933, 0.17143380738073782, 0.18638212864677753, 0.11017134953891078, 0.13397463597357273, 0.14778194588518914, 0.14594043905456222, 0.21854783168002484, 0.15745493973935806, 0.16812216250165818, 0.16658496111631396, 0.10628396660209664, 0.1117414620614821, 0.07249559741467237, 0.14114685837299595, 0.09559012994530702, 0.14272539786273433, 0.12512678776176708, 0.11220247079167636, 0.1914559596128041, 0.18048061628735837, 0.1472779213180465, 0.11148041760128354, 0.061231626633314364, 0.1550243725819934, 0.18597654637790498, 0.15241018947093718, 0.1321876746031546, 0.05312980633349188, 0.15725310621482713, 0.14465367181166527, 0.15932151296686742, 0.19318258389830592, 0.2493309298710477, 0.11205850754894557, 0.1941383858361552, 0.1264022935121771, 0.17096529864976484, 0.1367054329884629, 0.20113373385562053, 0.11990579130548625, 0.14502263507775723, 0.08394805263848075, 0.13622861986439075, 0.11177168423009497, 0.1751882051147761, 0.11613008100539447, 0.22994835380344625, 0.19082977466525572, 0.2004568185657263, 0.1783381594765571, 0.3345755403560977, 0.14070868672382447, 0.10032714269454442, 0.3619438169463989, 0.27285526837072066, 7.4677054535958085, 41.075182037968794, 98.71554528513263, 133.74223247651133, 121.95399607381513, 128.3618937769244, 107.34244546582623, 92.59944054388231, 95.77157897333946, 90.9682523050616, 68.0890670899422, 75.18614876654841, 82.08283655105099, 55.515117183808364, 56.189576579678445, 52.35929973663823, 65.3014386084772, 87.15520643418836, 81.90804789143225, 62.907019892046534, 82.29087906499063, 93.76107400463474, 88.64162783468925, 83.70884726124426, 70.66855892058342, 124.19222600998418, 45.363772146163456, 73.54233049577283, 71.22510402433335, 55.10528833635392, 46.50823347030148, 61.89653496588431, 82.49605824870449, 53.91545695643271, 69.10153281304144, 61.78742247243082, 72.20453554584135, 68.4954873977169, 57.67320133024647, 81.73704039665961, 70.9350133711292, 105.30215401803295, 77.27710154748733, 116.76622221546789, 111.09751086081229, 94.15063596540882, 115.6003761291504, 111.95623536263744, 113.54796455752466, 136.5820598602295, 139.97128578924364, 148.60210049536923, 114.89820911038308, 78.9345225980205, 33.28796717428392, 5.113172338854882, 0.24091039784252646, 0.2836269242388587, 0.14595370769741076, 0.13458888527126084, 0.10747119604099183, 0.14167486149216854, 0.1890379869409146, 0.24860133837547996, 0.19422092414911718, 0.21893812283392877, 0.18876472337832376, 0.1537027330167832, 0.12446251292262347, 0.12428267378239863, 0.1660516873122223, 0.24716383567260158, 0.15150945393308518, 0.11772139884170987, 0.1888327979512753, 0.1548651948330864, 0.2741912644236319, 0.1193001221925501, 0.15267174721004503, 0.11376945767551662, 0.19939537310311872, 0.19860510744394796, 0.15176499022110818, 0.11618390634295442, 0.08894034120584689, 0.15009162436810233, 0.09173906723698301, 0.1529636267091959, 0.18067855808523395, 0.23567244019960207, 0.1452331560393495, 0.13099587161935147, 0.15702229924499989, 0.155130751551159, 0.1006858020780548, 0.13694943199234624, 0.10577387461859374, 0.16565159023288759, 0.13997786948757787, 0.046620587067257975, 0.07398286518911201, 0.16460918971607763, 0.13232460515874048, 0.08740471796162667, 0.1267741832341398, 0.10422947966764051, 0.14516168003601415, 0.18651683754738302, 0.13263660212678294, 0.1313282312044213, 0.160798714345982, 0.10364764355002873, 0.2088698582543481, 0.14403957573156204, 0.13258452346969035, 0.26045202908496706, 0.139149422006261, 0.13149065716612723], [0.027919162755771994, 0.06572921009313676, 0.015470448490833084, 0.007361399193835115, 0.079444574132081, 0.025549589603718732, 0.05962194949989358, 0.06754634000601308, 0.02506530520716502, 0.06133255105645907, 0.10319196679178747, 0.013116963185189713, 0.07707560810470775, 0.044215427215902076, 0.02063611616200257, 0.0988228907508235, 0.05452835729586021, 0.0704528775907332, 0.03538216148773509, 0.03508462442926342, 0.07136051558078298, 0.03480581055966116, 0.039026280865073204, 0.03864313731150281, 0.07723531445428249, 0.06990929224318074, 0.03206346668453226, 0.05941428604625887, 0.030661799659531926, 0.02411096075159167, 0.14208899330227606, 0.036313207294311256, 0.040800536667267163, 0.034927783248525475, 0.019567716536262346, 0.052778110689213203, 0.031715695325645714, 0.13267191878009227, 0.02021192561744923, 0.030605111068354982, 0.09897430802905753, 0.02158055510071497, 0.04316971719925923, 0.018749040506419637, 0.07396016600391558, 0.024231439569003643, 0.05179545736961788, 0.0610932520019912, 0.023374275281845082, 0.06886038763989365, 0.07661107537006179, 0.0368291751721934, 0.07584286538223106, 0.07071464217358059, 0.12788437487136933, 0.08218140791981451, 4.20462392991589, 37.12158195434078, 81.55039048963978, 90.68762240871307, 78.50619193046325, 70.63641117465112, 77.43934646729501, 67.91619254696754, 83.25825322058894, 46.18945460165701, 57.082406090151885, 57.32646772938391, 59.497550610573064, 59.58493317327192, 64.10367619606757, 61.1620476168971, 63.780331688542525, 90.2436101052069, 97.2546349802325, 79.01134614021548, 56.68898059475807, 68.6718685396256, 89.31770324707033, 101.58224090453118, 85.00886194167599, 74.23628407139933, 75.43004174386301, 74.27831619016587, 94.73778340124315, 118.60003225265012, 87.85274505615236, 103.13154574363463, 105.01617400876938, 104.23340228296097, 131.39700812678186, 112.25674383101925, 94.25877571105958, 116.98589847933863, 84.52286458784535, 92.08426075596964, 95.39257603306925, 67.39099502563477, 64.01776844455351, 45.81489178442186, 50.403484375246116, 50.3907915853685, 38.35304144890078, 48.531815621160696, 52.028286995426306, 61.79553785631734, 75.96539035920175, 65.9009022866526, 82.5699007895685, 79.57368066233974, 96.44789757267122, 98.92408986245432, 104.82888867778163, 89.24455888809698, 58.67234276187036, 13.731283468584861, 0.3283070412374312, 0.14895137910160328, 0.04148558781091725, 0.01237238796743294, 0.03686384065076709, 0.016955377781883847, 0.031151538602106517, 0.03384615519955274, 0.018353390567485365, 0.06335626040855724, 0.035854171240522016, 0.04783626901166094, 0.11194996055095427, 0.01815089437689993, 0.10520053441606222, 0.024270977366775758, 0.0734174539965968, 0.07998456652726858, 0.08668264944947536, 0.05641358859476544, 0.008598539260997167, 0.0560195742535495, 0.0047209320849018, 0.023632672908265265, 0.07517564876545822, 0.005140850252862419, 0.044430755379219214, 0.03773811551171445, 0.07934113694054466, 0.07205265303773266, 0.031919078263003504, 0.012422004609458871, 0.0665352188591515, 0.017557344774925904, 0.04313842250755237, 0.006796574058581985, 0.033781240739288836, 0.01903942230367853, 0.06982710633066393, 0.034311159078272126, 0.010531433677721408, 0.03771332873692436, 0.038313631403950915, 0.0682610540740913, 0.0544774737359295, 0.028379173656444878, 0.06692334964510895, 0.04512680371502235, 0.07632594510552383, 0.0674896801431333, 0.058518530079914685, 0.08863574464715297, 0.08773914598409208, 0.10385611905686318, 0.05323864827533403, 0.08986804303863356, 0.060526002198457725, 0.06946246380046492, 0.07665232154390506, 0.0787173192046823, 0.022465817577716325, 0.011606209070211457, 0.02710959742656879, 0.03320913393831542, 0.029812633330302856, 0.03319756218021916, 0.015499453537256248, 0.048024217192564285, 0.02433522724576535, 0.04370563017625002, 0.10029540367184148, 0.04539196589781393, 0.04361391796039478, 0.04241389102272449, 0.04780109408461759, 0.05068516997139781, 0.034339236200697, 0.025939308106899265, 0.035652031280821374, 0.05243026080631441, 0.0709257760055123, 0.012699395470741778, 0.009619417495184369, 0.05717699521131093, 0.04703570330034822, 0.016960192644487948, 0.055388999622195005, 0.01947552360023462, 0.11640793343465175, 0.07536472692604988, 0.01391934356727307, 0.073093299213196, 0.04369493558882706, 0.022138642492674054, 0.0591636220774343, 0.08366007252686447, 0.03573501392477944, 0.03364461278843303, 0.07741104736323319, 0.05593590596089921, 0.03582583747864251, 0.05048263547641616, 0.013054887080685267, 0.007117254633246171, 0.02310820528486323, 0.0516055173601114, 0.03911677883156846, 0.042273336871256756, 0.0372839632684425, 0.10100688484887924, 0.016760877634008086, 0.012282583310509161, 0.1453909395082343, 0.023538129997529814, 0.02991543275364224, 0.032699509268446315, 8.528427116332516, 53.44959705106674, 101.63981345392044, 105.49937863503735, 94.73773633280109, 87.23523063044395, 101.54790447604273, 98.63561522576117, 110.41666584630167, 67.0637438374181, 64.06079292297363, 55.56439784265334, 44.439814706002515, 41.307480489054036, 44.52894664579823, 32.00712503925447, 35.0773093008226, 48.268765787924494, 59.96586199729674, 58.66977360940749, 48.52655180038945, 55.02447966606387, 68.87928347433768, 70.35768755020635, 72.52614636575022, 61.56056042640441, 57.83954512688422, 68.5843526163409, 63.3898832721095, 75.78428668360557, 66.85977274371733, 69.93199271540489, 61.41516993122717, 76.25120562891807, 77.68337280519548, 59.11551567815966, 57.15373046936528, 54.110061430162006, 49.160936340208984, 48.563163203577844, 47.85424970811414, 41.28384428639566, 31.359851591048706, 33.45936690607379, 28.16001730580484, 43.97259766055692, 43.29197229877595, 53.8817951756139, 80.10137281110211, 104.65118961949503, 132.96627783006238, 97.96320330712103, 112.28226277136035, 100.23325935486825, 104.94456721890359, 110.55325846518241, 125.03451578078733, 120.4854920602614, 81.62595102863928, 24.791981981646632, 1.064790141197943, 0.046605441508994955, 0.09106207533829636, 0.0433612659934067, 0.0374928945975919, 0.07608442056563593, 0.08826894174900748, 0.018733337619191697, 0.10643128530993577, 0.04278231419682984, 0.03658114654582836, 0.09644966527459123, 0.045965681483428326, 0.02990996480108269, 0.07156303092356651, 0.01884303757950904, 0.0228552392218262, 0.022920914024354953, 0.01001782726586586, 0.021089825989498247, 0.022316711969793807, 0.08627958760987367, 0.015627450550035123, 0.04121745703741908, 0.06140945096229834, 0.05898628421428223, 0.07310331198236636, 0.032145489803365165, 0.0038382757432578554, 0.024992883085243167, 0.053932593699785016, 0.056362505851974415, 0.03539128176447365, 0.04096298944205046, 0.06962742551320023, 0.03072394662716937, 0.017811352717539957, 0.009148712964698432, 0.07538796237279331, 0.011950974491605116, 0.009342187512365561, 0.027717672055587176, 0.00927144503821769, 0.02119236302772357, 0.00726999341314959, 0.15370584333375578, 0.07517767889845757, 0.034645456865790396, 0.03688608018320896, 0.09451350828091945, 0.023101980820478454, 0.024050564294861212, 0.04864966286526573, 0.09377221862274794, 0.059361173170468504, 0.0844272253133597, 0.0631719664670527, 0.07140463458434229, 0.06708894721082143, 0.052681146940637025, 0.15515217136952186, 0.09785695346973597, 0.13124226081755855, 0.15264306487815996, 0.12370315891119743, 0.12443066664761114, 0.08705646971300726, 0.26041436820260944, 0.13546008045875257, 0.19776740562050574, 0.16786006850100335, 0.13550912540766502, 0.19610530125998682, 0.15881434743923528, 0.14963335057179775, 0.14134942734193418, 0.11624068111902285, 0.10980617074716477, 0.09575429492660108, 0.21285342353005565, 0.1458039528299724, 0.1377346108276998, 0.25560036361698185, 0.13276300663428922, 0.14214589831329164, 0.12006964985161059, 0.09670608256372715, 0.17294244900826486, 0.18156193407072177, 0.13758435034223143, 0.24469257392469915, 0.21154188100368748, 0.10122760244074369, 0.09866778858967366, 0.08737281039958039, 0.11791577833073756, 0.09651279858043117, 0.14930471417403993, 0.12416552361701766, 0.21514381191903548, 0.1713327757052837, 0.12473730100018364, 0.17948473262931072, 0.10688493959605695, 0.12129277050975831, 0.09041381173677022, 0.17994224033769102, 0.14603452997342234, 0.11306897752107152, 0.2153804411570872, 0.1726240475451754, 0.129603169738285, 0.19936149669510705, 0.21111348463642984, 0.24214896283322768, 0.11894560734471006, 9.09580776768346, 59.82919485338273, 116.89355804074196, 121.16927885240125, 101.67242403953307, 90.64439788941415, 103.69613955097815, 91.38157598433956, 110.55265442017587, 68.73977261204874, 82.53290499410322, 79.62230236299577, 81.53962750588694, 82.34124229800317, 89.82233970395981, 93.15074536108202, 96.12982473065777, 126.41468017332016, 141.95540889616936, 114.3129522569718, 88.02711794453283, 103.00957572075629, 128.27196167361353, 140.0723417343632, 121.79253562804192, 109.4914807042768, 107.65564672408566, 119.83029150193738, 135.38476420987038, 182.1865635533487, 132.18401601237636, 152.3645007225775, 145.6667241742534, 145.52555022701142, 189.24005200785976, 154.65491387151903, 130.81447339827017, 168.56933378404187, 116.07076244969522, 120.23278159479942, 132.99439337945753, 98.11222983944802, 93.20893764495851, 64.64619490408128, 71.39291870978572, 69.06975376990535, 53.50805213374477, 65.471289004049, 74.95894155194684, 86.32091829853674, 108.31836254365983, 91.12541383312595, 111.78801275068714, 102.15870380401613, 120.9394907182263, 125.21150096770256, 140.15836715698242, 130.18334834806382, 91.39877949991535, 26.260285954321585, 1.0490467279188096, 0.16245950103527115, 0.29279531129906256, 0.2993447195378042, 0.12575124901148582, 0.15188862149032856, 0.16992262234130215, 0.06813261177270644, 0.1946002602457039, 0.1682248948923042, 0.1319322608891995, 0.295743003127075, 0.2786664742856257, 0.12472042408321174, 0.2845006321947421, 0.1050170486973178, 0.2028940506880322, 0.2129373714447983, 0.22260690258154947, 0.18575779763200592, 0.14333249189920966, 0.17193652959840913, 0.08437922990490353, 0.24629895304960592, 0.18683015218665525, 0.1841383950123864, 0.12977264370889435, 0.13435017227405502, 0.11813860266439377, 0.16572199371312896, 0.1673021113439914, 0.10956723558446092, 0.188210274904005, 0.19644883040699268, 0.1255722372462192, 0.1398965109500193, 0.11879377637899692, 0.1281769898149275, 0.21044747843857736, 0.08080008244442363, 0.14645128180423092, 0.10350393311631295, 0.0936092027733403, 0.24221939695698602, 0.18803356906339047, 0.35789108925288726, 0.14595606724821752, 0.16542430726751206, 0.1656009977863681, 0.16291215174621151, 0.10429154811126572, 0.2528672683383188, 0.1936338250074656, 0.19797211963563197, 0.11591898547785899, 0.23568842079370256, 0.20630524103199283, 0.15924579283643156, 0.19410818665018006, 0.2678424486469838], [0.07334809239593244, 0.030600999091421405, 0.055458962601879915, 0.06863364859694435, 0.029232241288428346, 0.03657286130492726, 0.012179837513324476, 0.0297803542156133, 0.07407447398309747, 0.037398202299711206, 0.055462873480733366, 0.05030612498822232, 0.03856074455524645, 0.082778473865361, 0.027797146016852032, 0.04066769319075731, 0.01995525743451811, 0.03925638686444971, 0.0860778000506182, 0.033895364857368895, 0.06466123756141433, 0.04671788789452084, 0.01137461877548166, 0.09444108232855798, 0.11136198806906901, 0.01589834690093994, 0.13805690401744458, 0.04658810493926849, 0.045735556331853715, 0.04720931031530903, 0.04983529118039916, 0.08378251635980222, 0.05306820137306087, 0.022291341052961447, 0.0295182487236396, 0.08284364496507952, 0.03747979066364708, 0.01728545442493933, 0.07878364709716651, 0.012495690776455789, 0.05645259396143018, 0.017663379004525564, 0.049266536014094475, 0.03523700697828205, 0.044179578131485375, 0.08210006470401442, 0.0065620008089970205, 0.1093005603780189, 0.02595697409443317, 0.02608783340321914, 0.07859326658710357, 0.08910053019081393, 0.1768582001809151, 0.1244901150705353, 7.294426906493403, 34.031856444574174, 72.84259534651234, 86.94142941505679, 66.9338192478303, 75.77054269852178, 67.3797692022016, 59.807865004385675, 42.077567269725186, 49.387421838698856, 44.28026445450322, 54.96437718791347, 69.07675127829276, 55.0233421787139, 51.868783812369074, 72.99557562797301, 70.44190083780597, 87.1751634536251, 74.37729327909409, 50.56674518892842, 40.14768269754226, 35.069919555417954, 32.24559337862077, 25.397199776864824, 29.556585050398308, 31.623372108705585, 19.78432728398231, 20.524170629439816, 18.71620705050807, 14.206338390227288, 12.85789812764814, 11.431148725171244, 14.50470426390248, 17.992716066298946, 23.67778370457311, 29.361976654298847, 37.67237686341809, 51.462406650666274, 59.275662129925145, 59.66807957618468, 55.876257650313846, 75.72094040532266, 95.1071608451105, 101.88518124241983, 102.4245071411133, 86.3554665350145, 97.13103325136247, 85.95075638063493, 83.5206284061555, 70.91586435994795, 50.393164619322754, 43.936739352441606, 20.364592921349313, 47.87404198800364, 41.27307738027265, 52.02915383923439, 72.31877849948022, 79.57939163331064, 88.55190753936769, 87.03140074206938, 99.11897674683603, 97.39276516822078, 67.02888181132656, 34.65698419078704, 13.31828828780882, 1.0812938814201662, 0.08276385690776572, 0.3253307590080846, 0.028014412382617596, 0.027974704130282326, 0.03817863905081346, 0.027109206721727407, 0.10962561914517034, 0.02453584460571649, 0.03526551694038414, 0.09777190238838235, 0.07338682580138407, 0.03275565968285645, 0.03359890032199121, 0.04191190424946047, 0.08462104555820266, 0.06707807642317588, 0.03720736596733332, 0.028655026596219792, 0.0786050107149828, 0.013973116236288222, 0.024725476264833443, 0.05386120579656094, 0.005353119810141864, 0.022651036570389426, 0.057447006730663205, 0.04640703622792517, 0.026831578373187975, 0.11306386005373732, 0.010511327700148667, 0.022965061756211425, 0.01175008900088048, 0.013931885384203447, 0.06337718610020895, 0.04228797298105013, 0.0446894939147657, 0.062144225042673855, 0.049647952039395614, 0.03196586708297893, 0.035252930115788214, 0.016141861354211168, 0.050113201066250765, 0.007764992506934271, 0.11967693785986594, 0.03248190199355445, 0.07218059738196674, 0.03280473910572548, 0.03068330949322591, 0.05595534927241745, 0.060346963620113755, 0.027997918509607835, 0.05074610460489508, 0.045088449523093245, 0.02933513838797808, 0.025529814959173242, 0.07018583466208751, 0.02587666892777047, 0.06112359674467195, 0.007965542834192034, 0.04720920306299964, 0.038326926859876806, 0.05794400244110054, 0.03170697916028721, 0.04233101563107583, 0.044579908867637, 0.026583927045125636, 0.034729393289214185, 0.02278630279995982, 0.06884519611635516, 0.08964141124799367, 0.04400950278185549, 0.0403984630810878, 0.030317713183561162, 0.04316093017076773, 0.04178901991596626, 0.011440521489167887, 0.03831153615347801, 0.03575542250708227, 0.014700432450720861, 0.00812900876025519, 0.05386397137396759, 0.02429174026474357, 0.07463089896426087, 0.1018839329481125, 0.05471054832601259, 0.022610025968582883, 0.010627736675462896, 0.05890538915991784, 0.033112982242938974, 0.06853701426617562, 0.022946968674659732, 0.0396174977293178, 0.11031612483484131, 0.06144907686018175, 0.047909503186782526, 0.03676519916963674, 0.03758674036831625, 0.03945610598630963, 0.049353609567568194, 0.031561273067528685, 0.027796393335466425, 0.06044202747063772, 0.07571400939336709, 0.020720006620150902, 0.02256957461096106, 0.06501459561648869, 0.03566141968833343, 0.08482120135017941, 0.04583212937558851, 0.10804354032922177, 0.37762217403900245, 12.678334962937141, 49.28709545443135, 92.75519786342498, 97.57099766885081, 79.61257488496842, 99.44664370629096, 99.91049535812871, 94.16248936806956, 67.20523941901423, 61.4520166766259, 48.357901650090376, 49.31692900196199, 60.45197309986238, 55.758916024238836, 47.44081620247134, 64.5682809429784, 65.22901988798573, 78.45464414165866, 67.35942779048797, 55.75642924154959, 45.75117288097259, 42.27823965011105, 38.63275743299915, 31.94951718853366, 34.32656764984131, 35.385348719935266, 22.051914199706047, 21.061919735324, 20.342386422618745, 13.977852482949535, 14.536856912797498, 13.33489364193332, 15.83212160295056, 21.051209703568492, 27.81504288796456, 34.10941346999138, 43.113202433432306, 55.82125425338746, 61.702138377774155, 60.86076644159133, 53.79802119347357, 73.6041941181306, 89.2106774545485, 97.82381796067762, 88.86622275075605, 72.16286428513067, 73.2800651365711, 63.42982476757419, 49.07775463596467, 41.85839699160668, 27.920899814175023, 33.11280588949881, 25.24983632949091, 69.45221624066754, 76.46349214738416, 81.73991157162575, 113.2458322278915, 106.49707271206765, 111.83633635121008, 94.8549210640692, 112.08673261827039, 115.84161758422853, 92.75932419684626, 51.32852438957461, 24.396660020274503, 2.919994256188793, 0.037037148891437444, 0.41521082962712935, 0.036560714980887796, 0.05274008591509154, 0.0670003338206199, 0.023532256018370393, 0.00924172274197542, 0.0533949033988099, 0.04047231012654882, 0.05993084381184271, 0.059048708888792226, 0.05400017797646504, 0.08729766483508772, 0.0016428234835808738, 0.04333375960648541, 0.03457606845204869, 0.015003700804476057, 0.0324154055617269, 0.05280408490028593, 0.02237436008609591, 0.027037671346577908, 0.05226605752062413, 0.03172937382553374, 0.024656505369010474, 0.039657874393367, 0.025225896388292316, 0.08487582341918061, 0.08778639062638245, 0.04260259380023326, 0.017795442986572464, 0.0851231242620176, 0.05718092907280211, 0.053984224195441896, 0.039831791673937154, 0.03126841489105456, 0.02915505601483728, 0.0778907486387799, 0.00872611875585731, 0.02309058334738497, 0.04798941381816422, 0.04773682313821009, 0.0048404039754982925, 0.02004971416036208, 0.05567830123548066, 0.022065940748659835, 0.05562136175050851, 0.0761172014679159, 0.03028604502399122, 0.029613806700874722, 0.034582438473139084, 0.07335159341774641, 0.04762124345307389, 0.039702621589024226, 0.024448018370857163, 0.032898071597540574, 0.06181539329249532, 0.2605389647426144, 0.16980741803924884, 0.2080619725729189, 0.1360213624373559, 0.1449317617281791, 0.13462046341549966, 0.1221654212643062, 0.08660572656099835, 0.15170724251337592, 0.09533773461777358, 0.1308445386107891, 0.1479993922816169, 0.15834740152762783, 0.14175349275671667, 0.11526229490916576, 0.14742418282455014, 0.11574804827931429, 0.13659413573482346, 0.19515037266237123, 0.18541181700364237, 0.16451108449649426, 0.0891866461343823, 0.13458176065356503, 0.11508028007923596, 0.17927791953327196, 0.15556541451763722, 0.34126967792549445, 0.1574447507699651, 0.28046212309310514, 0.1843466483537228, 0.15185575631837692, 0.16256261646987932, 0.12382069978141978, 0.12310070736754326, 0.1561847812826595, 0.2375521594958921, 0.31211466979115243, 0.12151429249394326, 0.1868165617868785, 0.17704138712536904, 0.19988723219402377, 0.1080174703571585, 0.1146154409094203, 0.12248494887664435, 0.15589457185518357, 0.1816860403144552, 0.13063896657718768, 0.24949677258489594, 0.17308290356830244, 0.17649223997948632, 0.23147084630064427, 0.1666917844164756, 0.2763938591364892, 0.3628821214360576, 12.335000095828889, 53.649331984981416, 105.68265530370898, 112.47665543710033, 88.39473816656297, 99.72435535923128, 92.08284870270761, 84.66517602243732, 61.76932465645575, 68.19993680523288, 62.24858337833036, 79.70197354593586, 88.97910856431531, 80.14875504278368, 80.90096366020941, 103.2136409513412, 100.78344237419867, 124.91563658560477, 106.61850929260255, 77.24439682499056, 59.31394054043678, 53.12856281957319, 50.709417481576246, 44.169951715777, 47.400553072652514, 47.94595472274288, 30.134867929643203, 29.116634361205566, 30.31894672301508, 20.377993699043028, 20.715084152836955, 16.81410070388548, 21.16467602791325, 29.110697853949766, 36.29524054065828, 44.54384380771268, 54.46444365286059, 78.25880804369527, 87.7238481275497, 87.4697962114888, 81.09296368014428, 106.92705077509727, 129.62793288692353, 142.56976189151888, 141.871611379808, 123.330700935856, 142.47893548780874, 123.33354073186075, 122.38395844736408, 101.30352512482675, 70.88082190482848, 59.99055723990164, 27.753655833582727, 61.54347458193379, 61.32954851273568, 74.11644781789472, 101.07891451927924, 108.51755619049074, 112.58964323228406, 104.6183515364124, 123.64211359331686, 130.93219941662204, 100.46741700941517, 55.95478742353378, 27.06595647719599, 2.9340944415138615, 0.12540866981350607, 0.569587045859906, 0.1596428868511031, 0.21584442996930694, 0.18609696007784338, 0.09372675130444189, 0.21670500717816815, 0.11414829581495255, 0.13129270004649318, 0.32292083025940005, 0.15165568479607183, 0.11311737895612756, 0.24126324261869156, 0.14959676221253412, 0.13375538160964368, 0.15304383611486805, 0.12701515619072223, 0.09634491041182511, 0.15978023109416808, 0.08840953420487144, 0.11982255585251317, 0.14270705771782707, 0.06981019110929582, 0.14738796218749017, 0.16345501697111517, 0.18149574407406394, 0.18364872693294482, 0.26301566571477925, 0.107898221110865, 0.0930374943380875, 0.21102546113393, 0.14773634833193597, 0.0990967212184783, 0.1717596245749343, 0.20541530733387317, 0.08945316812323947, 0.11915428203440483, 0.10880755215522744, 0.13269848670930634, 0.1514753630204547, 0.10905862981153112, 0.22548679562826313, 0.1688508193699583, 0.1413711229519498, 0.13253108117609255, 0.14200521392687676, 0.16673402650462044, 0.2771267294883728, 0.13975377344796736, 0.12467297259718181, 0.14407286991275128, 0.20176560317556705, 0.16365020085246335, 0.13701681708616598, 0.12992699510387837, 0.1541584480794207], [0.021891017977689064, 0.026665245363068198, 0.02468036326219238, 0.04111500809930506, 0.04383002370295506, 0.015755659194603082, 0.023588341315306967, 0.05744825545397978, 0.08642167393718997, 0.06189470254485646, 0.04768261858712762, 0.03950491344796554, 0.013898046322978072, 0.057107246736244816, 0.005473466956191847, 0.035214127762423414, 0.031194642539166158, 0.07646383327101508, 0.0705019531831626, 0.09750533443424972, 0.0377344727636345, 0.029125931267175945, 0.021338149559714144, 0.0640996338258828, 0.03432049002918986, 0.04495764001002235, 0.07263488752106506, 0.07232034714111397, 0.03747221788451557, 0.00824234668060296, 0.07381532176007187, 0.01757880481290481, 0.06412825870117353, 0.0812119466342753, 0.04532646921072756, 0.027256919964847547, 0.058583015530940995, 0.004619103678006439, 0.08840440907665799, 0.09386527532291028, 0.01922830319662969, 0.05008900800960199, 0.007690850996427359, 0.09007961354068211, 0.01720381051962895, 0.031079951516022126, 0.054132040860431815, 0.05432943107500192, 0.06350193202735917, 0.02273145856546058, 0.2684559318567476, 0.08004328716666469, 12.658880987474996, 50.34212673864057, 84.54765396733438, 94.34744481117495, 76.92030706713277, 77.17297830889302, 74.50357006442162, 46.07378390527541, 30.549735061583984, 37.57987168527419, 38.41022960601315, 54.09279907903364, 37.72440710375386, 53.047310921453665, 86.02198662296419, 47.46778249740601, 44.14467988475677, 33.27994984965171, 19.844023796819872, 6.803398622620491, 3.891156440781009, 0.9023901039073545, 0.5142112076282501, 0.4588904051530746, 0.6845832171459353, 0.3111041998190265, 0.5420012615861431, 0.5389086565663738, 0.31923174918178593, 0.11346830085160271, 0.2058033768327967, 0.09280481811372504, 0.1008980084330805, 0.06734806879033005, 0.11215007803853481, 0.10652830268466666, 0.10934854046471658, 0.03587708876077687, 0.1738167391909707, 0.23134856334617063, 0.9017917585949745, 0.5511745209655454, 0.8549114677213854, 1.1953082344224377, 3.9166783228997266, 7.032716072374775, 18.22502040093945, 31.932978514702093, 33.734497639440725, 45.90620063966321, 64.27491903305054, 79.10982116576164, 103.70625142128237, 119.79419000687139, 118.47232772457986, 46.226960305244695, 34.3446772329269, 40.14800040952621, 29.1946404980075, 38.855987364246005, 53.47936391830445, 78.4682704556373, 77.97914305040914, 82.01432843362132, 86.46815623006513, 105.55397018309563, 94.8463781418339, 70.05810476118519, 33.142780642355646, 5.118164535491697, 0.057338923215866096, 0.029245444813803322, 0.03765490304137911, 0.042970067025312496, 0.11165166123499794, 0.07380537027793546, 0.029868134485197165, 0.07677626690917438, 0.030947877957876173, 0.013299689519279187, 0.047181849893663204, 0.008890162120693395, 0.05689626995233759, 0.0312893271761676, 0.034333268375766855, 0.0379166484720284, 0.0068285180098046705, 0.03799807212706055, 0.016118560789994175, 0.05244514206424356, 0.07964005678771965, 0.029700968354459734, 0.13085298089971467, 0.04765284457995046, 0.04589439700207403, 0.052611042234686115, 0.0456433997850024, 0.12158784459555343, 0.0691940189309178, 0.04655239375067815, 0.025467087679933158, 0.06402501303161826, 0.06719300493357644, 0.04527210761162062, 0.03466113868560042, 0.016393988550971114, 0.09017957269304222, 0.023788359211457354, 0.01608596566403585, 0.06416195890896263, 0.04633404337049973, 0.035309295034817154, 0.03961758199898947, 0.04112116744621627, 0.019509832847923524, 0.02315349065728726, 0.0355336821878389, 0.046711717056290764, 0.06397810163757493, 0.047650553977056864, 0.05023534612489804, 0.04379424739689116, 0.06536381679677195, 0.029180658673266732, 0.04267519595281732, 0.013707842970747623, 0.007689942703432134, 0.03380498180406229, 0.0682711281302956, 0.0588769251630912, 0.014344664091514725, 0.02415817475036508, 0.06858065829522188, 0.04128322951615818, 0.035786154124164776, 0.02285699739361242, 0.07711880014187868, 0.00640451563559773, 0.016083778483012033, 0.04302997510099123, 0.043875567630053534, 0.11280339782036121, 0.019968334555385575, 0.01855549988366904, 0.04897980462579478, 0.010918250622888728, 0.06799623280042602, 0.017642215825617313, 0.021697724418294047, 0.03826406551524997, 0.02959977963098115, 0.05069523636672286, 0.10065677500660382, 0.047002010753438364, 0.022810557143642538, 0.03470129318415158, 0.07049187912695831, 0.010312344022696058, 0.04121975530119192, 0.04085843376214466, 0.02952196999573179, 0.08419529219428379, 0.058880671333040924, 0.008388233761633597, 0.05457499672869041, 0.08313534060312856, 0.030795472426219817, 0.10384522528657991, 0.08204420157257589, 0.04905356740158412, 0.1154794655139408, 0.07359373848885298, 0.03416829517171268, 0.05246515994170501, 0.2969284782246236, 0.650098412748306, 21.17390928729888, 71.76438285458472, 106.63825450404998, 111.17654661978446, 94.37012395551129, 106.71179110004057, 101.63822097163047, 70.60708753524288, 45.606111864889826, 46.32755733305409, 27.649287446852657, 36.29179669964698, 31.009354476005804, 52.79997018075759, 96.5741978922198, 55.4338142948766, 54.08942584068545, 39.57766032988025, 24.465870241965018, 7.250906738542742, 3.977251240322667, 0.5523729889142899, 0.4035408590589801, 0.1747006820815225, 0.4888954950917152, 0.36023476671788, 0.3859822157650225, 0.48083664849400526, 0.4926639735218018, 0.14932578159195764, 0.26631946585351424, 0.0631539787225906, 0.3302296767792394, 0.09624805391555834, 0.16896567127156645, 0.3775371995664412, 0.24849243131616425, 0.16312593624236124, 0.25910304018086006, 0.08623450333552976, 0.4003824317647565, 0.18457210802983853, 0.4229131389048792, 0.668081560682866, 2.718403305738203, 6.619693435007527, 16.371159207436346, 33.75537249349779, 36.68849345176451, 49.86361718946888, 69.96825110527777, 77.66882081185618, 90.95748932130876, 81.07729773367606, 52.037987016862445, 21.468198837772494, 19.49753926646325, 33.24575462648946, 43.29527101209087, 62.52595378506569, 88.23028887471845, 123.1401914165866, 104.09950825475879, 98.49115433231478, 100.09587441721271, 122.76903321666103, 114.62455318820093, 88.98834966844129, 49.30560511927451, 12.629212179491597, 0.01971596604092948, 0.0768011647667135, 0.0937094836826286, 0.08304799125800211, 0.062990648777134, 0.1210878802944095, 0.0601110851482278, 0.06970824012833257, 0.03908348848081885, 0.032762052686584574, 0.06888281869431657, 0.020007939385851065, 0.03162558806399184, 0.06047876904748621, 0.027577770994074886, 0.03816836581174885, 0.03912014578799567, 0.06503537958187443, 0.02161092091081364, 0.06870081918614526, 0.05440073853899395, 0.05205442956198127, 0.08928907975073784, 0.028805041933552395, 0.049582026343071656, 0.0429689217238657, 0.05030448556006436, 0.10938433975341821, 0.014635108133417465, 0.005493387636247902, 0.01677648476024549, 0.020411974157116586, 0.061361076340319655, 0.030950836972483707, 0.08241399987450532, 0.012767439400176368, 0.007289697673367037, 0.02289433460382204, 0.13995490217160794, 0.021333949482669274, 0.03619955815074425, 0.013220056594770043, 0.0411337006446575, 0.0593537804219992, 0.021676034553937858, 0.029728091697418885, 0.02515189037958701, 0.02113523202077035, 0.04457371504676919, 0.016275593492713188, 0.04646854159692603, 0.045390134947674896, 0.06023081702991359, 0.12068955287817987, 0.17187127422901893, 0.07281514800964825, 0.06576045115868892, 0.06012109791739814, 0.11516762176348318, 0.14858333514102046, 0.08816047902068785, 0.14907902467154688, 0.14446438680733406, 0.13619644417157098, 0.128928154346443, 0.10917021817858182, 0.1822753764328457, 0.22749717888091842, 0.1480842441801102, 0.12218314853887405, 0.11927504047390916, 0.2697843589609669, 0.1724003805148025, 0.21178125283650814, 0.10831268233877998, 0.14526880977134551, 0.12928455377057677, 0.121974527475334, 0.1704421525280322, 0.12174401927979724, 0.17841729635913528, 0.15555796814301323, 0.1860007853998292, 0.11686893450396678, 0.17110799018654133, 0.08888867623623341, 0.20066153258085254, 0.19894872852150472, 0.17328931829862057, 0.10134127456694843, 0.12866242908902709, 0.23221723044351225, 0.1750011417654253, 0.17774983459422666, 0.2882599482132543, 0.1221691597733767, 0.1674245475160499, 0.24780258446210818, 0.22266731627525824, 0.21406526737395795, 0.21418162080789768, 0.15914794808674246, 0.17616862911851178, 0.10789558576840548, 0.5826432678487994, 0.6652327554841196, 21.32371048773489, 80.50467091221964, 117.43198963903613, 124.72682153024982, 96.33749069706087, 99.95330410618936, 103.83893735947149, 64.19930750323881, 39.73102108124764, 52.286833947704686, 58.74073320819486, 83.23080447412308, 60.43500884886711, 76.44473537322014, 115.75824368384578, 71.85244790969357, 69.10747128148233, 51.700592579380164, 32.71855081281355, 12.095638436655845, 5.5476694626192895, 1.30591674437446, 1.0554301402261181, 1.0377945510610458, 0.7871493360688611, 0.5846027981850409, 0.9471802617753706, 0.9561766467748151, 1.5132315360730695, 0.22776826675380432, 0.3153528315165351, 0.1763213870506133, 0.3101561200474539, 0.266200507720632, 0.3034990611335924, 0.41781034981531484, 0.3663590880891969, 0.3688273620941947, 0.6181603297591209, 0.29976527116471724, 1.7413556047024268, 1.1072904929038019, 1.7821896845294585, 2.1044001367784317, 5.636799931526185, 10.395469434799688, 25.459583113270423, 48.056106644292036, 50.34077352093112, 69.53736305236816, 94.74563598632814, 115.12533003284086, 149.540190235261, 160.73816484020603, 163.07492471510366, 65.2324245052953, 52.50159940411968, 55.55701201961887, 38.90126720551522, 50.12423123082807, 74.2689887938961, 110.69717022680469, 102.82401623264437, 102.00532344079788, 108.09075524730068, 136.01807009789252, 126.94980913592924, 98.6765020124374, 52.45324442463537, 12.85563393946617, 0.14598271178622402, 0.18375973307317306, 0.23860494816495528, 0.12065222907450893, 0.18410654107649482, 0.23527399787018377, 0.12760097596554026, 0.2476220788253892, 0.12900540665272744, 0.17525620307893525, 0.18235632128292517, 0.18980572961511152, 0.14085887060050042, 0.13493757785087632, 0.15695974050510317, 0.0896862656959603, 0.11489248894635709, 0.20849660489588015, 0.10985081835139184, 0.16870716256239723, 0.16835652411945407, 0.1750735523960283, 0.2513328095477435, 0.18517207744861805, 0.15629748813807964, 0.1444039731136253, 0.1749746044797282, 0.2029505879768441, 0.2272501921341304, 0.2571378407939788, 0.18640097440971484, 0.1413127776956366, 0.21874034957539654, 0.19990759481105114, 0.25683258539967, 0.2266460705188013, 0.12974940060127166, 0.1603576162409398, 0.15057137926980374, 0.11952755071463124, 0.08822777218395665, 0.11988548231461357, 0.08551657169816956, 0.167604363673637, 0.12046750995420641, 0.1043502304462656, 0.10831684219620882, 0.13479456455717165, 0.10211221948866883, 0.1316344518695147, 0.18459031027891945, 0.16155747846970636, 0.17224826609655736, 0.23677099496126178], [0.05094593863994364, 0.06091409468001897, 0.04870217053159591, 0.03827937578241672, 0.030795616067705617, 0.04139278008933029, 0.08654256261164144, 0.014936425835795462, 0.1522976205113434, 0.035932802505070166, 0.0542922911324328, 0.06031522076697119, 0.07790942586237386, 0.05022815255928905, 0.031871670827029214, 0.016346244036310142, 0.01993600756020075, 0.06524729482348889, 0.080582230021396, 0.020359610132272207, 0.04552816483943213, 0.04611777291903573, 0.045228827474338394, 0.03401948642286082, 0.047865303743991165, 0.03063234357884334, 0.05110218993297989, 0.007693936894347351, 0.08712500393871339, 0.04051957775147692, 0.016323408870507154, 0.006940373550018957, 0.02173539870719035, 0.07276407292773647, 0.007156887713203868, 0.05605367665749885, 0.10801465881447639, 0.014905613779480902, 0.022163061545260494, 0.027491792946332888, 0.09530771929290026, 0.016662439166177666, 0.058848499470660766, 0.05449121735329109, 0.08135928066387292, 0.0508752555376099, 0.020206892419786706, 0.14206930484262206, 0.07787586355041112, 0.090661863345773, 9.403979566789443, 52.88222620564123, 86.23497132332095, 95.5613713110647, 73.32496058556342, 64.86059950244042, 58.1984184634301, 40.92597115424372, 41.83558056431432, 48.3462522106786, 54.0097075893033, 56.50433501889629, 64.34183466819026, 60.45358911637337, 50.66146650621968, 45.83666093887822, 19.55165228536052, 12.474208935614556, 2.584590666717099, 0.5341127622992762, 0.21257694239818284, 0.10021635105893498, 0.03963762668952827, 0.099201652281467, 0.040511334645411665, 0.03175665230129755, 0.07249444062190671, 0.21202903631473743, 0.1314980575754758, 0.2026990966330613, 0.04647375482525076, 0.08681929655252926, 0.1397270216576515, 0.1742227198255639, 0.19502652688853203, 0.18194802706280064, 0.08954633207571122, 0.1642607576063564, 0.10814798875681816, 0.1393854383739733, 0.0062356870940646104, 0.08137107841790685, 0.05348304564493799, 0.11613534402943428, 0.051693349340630156, 0.1292745333405272, 0.07507996438371559, 0.12944567738281143, 0.46532312287918987, 0.14423854408725617, 0.1159733777204829, 0.5572707422317997, 0.6880321449810459, 3.244139172377125, 7.878619816995437, 28.170201739957257, 68.81425057688068, 101.3893622736777, 96.36772432634908, 57.949799030057854, 55.11513348548643, 36.91422977755147, 38.22217549047163, 20.955962788674142, 51.46684285133116, 67.74993896484375, 69.52638041588568, 66.83581490670481, 74.27906928523895, 87.25947087810886, 97.0363707696238, 79.43887664425758, 23.4465148756581, 0.2572974628738819, 0.2411458626269333, 0.12638696409281225, 0.08107230412743746, 0.09334609753662541, 0.02314285735689825, 0.09942916507321982, 0.019786930680575392, 0.02903255089486559, 0.03905053520875593, 0.07039922845339583, 0.0724706152874616, 0.015788726422244746, 0.051817842458765355, 0.07559194860439147, 0.046635901164864345, 0.024003670137796192, 0.01904987940384496, 0.0602751505380917, 0.04994202638044954, 0.03205374885921276, 0.015000919905310918, 0.04268097608620602, 0.03357855302672233, 0.01272357703607169, 0.04327133876241503, 0.018742231899992596, 0.015274133672186685, 0.013676869078359057, 0.11148871433350349, 0.0562027880110808, 0.03629584391150744, 0.04665202348523083, 0.022790629281512192, 0.04123769324993895, 0.022215157439331376, 0.010378815556666064, 0.04668155617471184, 0.03108929587347854, 0.052558756733853976, 0.024057242666341128, 0.09327191724291733, 0.037395482687580014, 0.011106170075494918, 0.01999951241868398, 0.05588701422957163, 0.032112988523177566, 0.043499200124173396, 0.042948183723755425, 0.057374550134784756, 0.029443679640309948, 0.06339674432491584, 0.021095613783766187, 0.06276259206295495, 0.08088787612054618, 0.034263454783227176, 0.028887308285301252, 0.015098434279582676, 0.03310357085278919, 0.0389041128237882, 0.021268309154097113, 0.09190623528294026, 0.04473437517580967, 0.06531209820100377, 0.04280708948030107, 0.02464548902465932, 0.009760178490391663, 0.01798996611708595, 0.004979553313234882, 0.041888121049851186, 0.01722023352950571, 0.04681112079490577, 0.010245779600565233, 0.06193984427579469, 0.0782436853454959, 0.0968171270083516, 0.023090073898915323, 0.02136851728503262, 0.04342586252718203, 0.07759850141742537, 0.04969189101229272, 0.07843035799000533, 0.014151091867637251, 0.05323326267722634, 0.020342258240787253, 0.06170790349583953, 0.09119018056099454, 0.05078517125859376, 0.02498373982586688, 0.05124105869101421, 0.020279021513077523, 0.03805554404314007, 0.042415262320108955, 0.08246354278056853, 0.006913271753282677, 0.048429109982305, 0.02356076981091211, 0.1316802486056282, 0.06416414992042607, 0.02220965309759542, 0.11108094871404672, 0.06352470782134803, 0.08057492154259836, 16.03347255337623, 71.10630327655424, 106.34696360557311, 106.49697073044317, 86.9514314589962, 89.61627406458702, 88.76236623333347, 70.20815110975697, 58.26589891987463, 43.19813351477347, 29.018161296844486, 31.24991147748886, 56.100005334423436, 67.10184574127197, 65.30335664749146, 50.59044022713938, 25.3075030157643, 13.145563775493255, 2.937056321290232, 0.2580435099380632, 0.20308042455825115, 0.15902667636832885, 0.02081863277952277, 0.049253301845202525, 0.0212187490110556, 0.15151415771294027, 0.11506846700344356, 0.14456405484628293, 0.0936632885807945, 0.13991702678463153, 0.030137307138272354, 0.06808847744738863, 0.2690827756399109, 0.24462293653238207, 0.23192627024987053, 0.21269133464703638, 0.07559693583677854, 0.29734452525454186, 0.29613992860240324, 0.18801276211536702, 0.17604409386554074, 0.19800866202962017, 0.1107480222239129, 0.11504062736827521, 0.08003315182342645, 0.06397120684625641, 0.11073386491907221, 0.07279222665895378, 0.5233473883521172, 0.2647761970518097, 0.16373822435496316, 0.2346437679783952, 0.4884286411106587, 3.1259682101588098, 9.16138489400187, 28.148983678510113, 68.05013364361179, 77.17618680769398, 66.67966535014492, 42.96652932320872, 27.56586647802784, 23.25354406910558, 38.21448372256371, 38.05909510581724, 84.0742866454586, 102.1750993113364, 104.57944162430303, 85.74909948533582, 82.67925646997269, 100.69682859605359, 108.96640869878955, 101.03832583273612, 38.15955092830043, 0.7635323162521086, 0.46497032406830024, 0.03027755485457038, 0.03635533063882782, 0.09854016600236779, 0.02017617803968249, 0.057193370340692426, 0.019948331999682614, 0.012992067870894268, 0.034627821521773454, 0.007243155437942235, 0.047504679344954996, 0.05430745584289393, 0.048032693955446445, 0.04845788041430135, 0.055305151298882506, 0.04313055095413039, 0.019508720105213505, 0.07203158561981494, 0.042117269439322334, 0.008401431541349138, 0.03163632861669025, 0.004053320932847959, 0.06849173846985064, 0.02446136362249813, 0.04315083313192572, 0.035546717173870535, 0.07968061348243106, 0.018888123769072757, 0.027063302733304522, 0.07184485168827158, 0.0865362577080246, 0.04779660480938131, 0.02480835740214154, 0.031466799104706414, 0.09531696597414632, 0.037926841271860946, 0.025326217517196655, 0.006451131606985245, 0.05271419214325086, 0.03241173217012998, 0.08518170700558732, 0.046819589896908695, 0.024782147619032094, 0.020415268335190993, 0.0035927000346653646, 0.011579903526111476, 0.013442466283337244, 0.015685595665878106, 0.044803411189106204, 0.03759366580315175, 0.05948270535877636, 0.042998925557420145, 0.22396274031169955, 0.17107397588270326, 0.13200488602442126, 0.2057489692684143, 0.08870804036456732, 0.1848018271548133, 0.14623930527558252, 0.16168714651177007, 0.17923074383889476, 0.08980071157096856, 0.13680102543965464, 0.2527007361453387, 0.12430144293654351, 0.20566646159896929, 0.07829434673992858, 0.13264542745967067, 0.1369963165733122, 0.0985291266753789, 0.17999450285588542, 0.12112701972646099, 0.20120340189145458, 0.2040294542788498, 0.21553126854761956, 0.09535841133084991, 0.2101211096610754, 0.11544459319162755, 0.188294391358091, 0.11545087511260664, 0.22563100401912967, 0.1815940484765076, 0.08965376058533307, 0.08614123979162785, 0.1618743017916718, 0.2517005623949151, 0.14961930051926645, 0.21517575778547796, 0.1676545117891604, 0.1481844331588476, 0.12303441011857603, 0.20371997007919898, 0.20529307034467498, 0.07546354460740283, 0.08136881079765097, 0.1490419460160117, 0.2917033602153101, 0.11509372492230709, 0.11114322400141148, 0.2038605778568214, 0.26226183519728724, 0.23055029972907037, 16.585810915116344, 79.2576317633352, 119.12274299129363, 116.91309928894044, 91.34892617502521, 81.88024613165086, 79.02346626404794, 53.79234160146406, 56.99487839975665, 71.51209600510137, 78.06523907569148, 86.77277534238755, 97.61514002277006, 92.80192113691761, 81.17684748864944, 70.88060225209883, 34.14393032750776, 22.339557293922674, 5.385045053497438, 1.3788054138422015, 0.4852411944058634, 0.38770894730283373, 0.2622052059779244, 0.30674840774266954, 0.15076280932032293, 0.2292004221629712, 0.40197154326785, 0.4187475817818796, 0.3917972214760319, 0.31093238161936887, 0.10759873435862603, 0.20441894870131247, 0.42587845075515013, 0.4182640883711077, 0.669067423910864, 0.5292230988702467, 0.2842478538232465, 0.7087042002427963, 0.4478247247395977, 0.5255349677416586, 0.24160545409446765, 0.5037779481180253, 0.13569516219919728, 0.3559900267470268, 0.19484071992337706, 0.26213086480575226, 0.19641619506141833, 0.2264389050223174, 0.7261898813228453, 0.2382163117609678, 0.4019329630799832, 1.29505435305257, 1.3391232851051516, 6.57423218411784, 13.890316947813957, 43.96794180716238, 97.21107313709875, 134.51040514053838, 131.54401856084024, 85.86068307199787, 83.75686491689375, 54.88839303293536, 53.17898488813832, 28.230690571569628, 68.2570622044225, 92.14222554237612, 93.75093860010948, 84.55513784962316, 92.36157232715239, 111.13205909729005, 122.09034550574519, 113.99724852654242, 41.43835036985336, 0.6577138170119256, 0.4868744632169124, 0.17683547801308094, 0.21356357171410517, 0.21331868404822968, 0.20963721788458287, 0.21998132008218, 0.18527982005428884, 0.18341546848175988, 0.09930136628569135, 0.1110008542215632, 0.2026823805945535, 0.10659126745116328, 0.23642496836762275, 0.13108404833943615, 0.18822873762298017, 0.24141138870148893, 0.12752290394517685, 0.1498475027901511, 0.12186493859776568, 0.08105673722081608, 0.14349019875930202, 0.09359251737834946, 0.15674540442564797, 0.08015598636120558, 0.11851436879125335, 0.09664471126011304, 0.10547618817297683, 0.06728336500424532, 0.17705906843466146, 0.12730094529087507, 0.13038854775649886, 0.18132391055264782, 0.13302261851006938, 0.15206857554374204, 0.25806146703900834, 0.1433794071236926, 0.1703926479263652, 0.2016636521946038, 0.1972843871842469, 0.11009398998031694, 0.20195514864979253, 0.15711268229830652, 0.12461949199918779, 0.14597744110130495, 0.11270225123171845, 0.11654887829096088, 0.10448231932617004, 0.11871487698367528, 0.1410202087173539, 0.10861940096102415, 0.12306316139837428, 0.12154729556172125], [0.02763415698052174, 0.04247152381726811, 0.06899066855229678, 0.04888523107154235, 0.04724217931770029, 0.04523639642303029, 0.034518075596180656, 0.04855848691095749, 0.1400521646944746, 0.0376985892052612, 0.04334104510264532, 0.02365838856466355, 0.024491024631706458, 0.03129636752419174, 0.018730922527010405, 0.09982412936346186, 0.02689548542783145, 0.026712574275030244, 0.04812985688688294, 0.05061025806372205, 0.03346159438332243, 0.024172226718116193, 0.010835243081073127, 0.022554281580772613, 0.04800442148060088, 0.02132634414480098, 0.04231832155417051, 0.06254891481911463, 0.05512541558052744, 0.07555826371836086, 0.0371754507444078, 0.025196317733535846, 0.05879512995541577, 0.041586830160550536, 0.06386171372967862, 0.03069595568963597, 0.02985699939721775, 0.05323296773337549, 0.0917116106457768, 0.07197239000590579, 0.07449775288302092, 0.05936645534670642, 0.018578384845187108, 0.055599938101706006, 0.14723457606329074, 0.0883785842527305, 0.0722879569436754, 0.0416368825150834, 1.5682772210528775, 26.320619852312152, 81.3976533951298, 91.79243641514933, 77.24743273950394, 70.48303081143287, 75.13723681049963, 46.79655121218774, 38.171423942812034, 61.8069637206293, 49.86809261383549, 46.127481152934415, 74.943558016131, 70.74797907183248, 43.96971079611009, 19.557376984627016, 7.246571048613518, 1.1218506987056425, 0.10822143360611894, 0.6360365318194513, 0.07770023023289058, 0.05447514482863969, 0.17310194851410005, 0.08381312157237723, 0.3135573359266404, 0.08528196493223791, 0.1930082069649812, 0.3297924244355771, 0.23971871743279122, 0.11032219225120161, 0.08632421989234225, 0.2526094491082815, 0.1353855094602031, 0.11080555542702637, 0.07747845543969063, 0.058741771931489634, 0.13999386540343686, 0.06378961336468497, 0.021774204890994776, 0.019746400798941334, 0.1537110527316409, 0.08234956421919408, 0.05941363487152323, 0.08231030987395395, 0.09385394488251018, 0.16217238660300934, 0.17907496752037158, 0.0964016775270143, 0.12573922909195387, 0.07801725273771633, 0.41068141138361347, 0.29096475952575285, 0.05608069657858822, 0.045659591053282066, 0.044952001602899645, 0.09952094240654862, 0.28920784412372497, 0.04279668600628934, 0.24516725732434183, 7.717328523435901, 28.742924659482895, 54.62117372020599, 75.6175781065418, 76.69721049647178, 61.23489779810752, 62.552935769481046, 34.736423953886955, 38.89099451803392, 26.401201025132213, 60.61833650835099, 84.34177660172986, 76.98549685939666, 72.93489656140729, 82.38900892196163, 90.08970414438556, 56.665654259343306, 10.312213205522108, 0.32440419098542583, 0.09578686898514148, 0.15989534346567047, 0.03329240386524508, 0.1565903482297736, 0.03217155211454919, 0.08455380602108856, 0.01837978804213626, 0.012348322272901575, 0.020356109110458244, 0.04647131483521193, 0.03561689082773463, 0.008417384364762375, 0.05039319471125642, 0.09288250709012633, 0.08805697288123832, 0.11377168699137627, 0.06076081197768931, 0.06720196816229052, 0.011384679425147273, 0.06332002444973876, 0.0786682436122529, 0.05546571949737207, 0.03973961214444811, 0.04804066126985897, 0.005772191929751106, 0.025796461437318115, 0.009192695987651186, 0.022253638035767985, 0.055839463152111544, 0.006697752546789426, 0.08946057619346727, 0.0918203721483869, 0.02773391120436211, 0.06471778251110546, 0.040085600433690895, 0.04174092874651955, 0.08472337958312805, 0.011797670721857539, 0.013886572241092162, 0.04623742053104986, 0.04935899133523626, 0.017735086749458027, 0.04617226092265018, 0.02238208799803209, 0.02390227648579786, 0.013989762369272931, 0.008113689874599298, 0.0470237638200483, 0.03414557683431814, 0.07083976731425332, 0.05877143485591777, 0.03751843213854778, 0.03193465666094374, 0.05090148638813727, 0.03424933578278269, 0.04429949004383338, 0.034174872036542625, 0.03432898211383051, 0.02791413147332928, 0.0026473824888648047, 0.047366657114077004, 0.011191127311077811, 0.03979721429547475, 0.045326254706108765, 0.05768991405925444, 0.013228064128798584, 0.04658826198729296, 0.05580406605957016, 0.038622081384903965, 0.06782923329381213, 0.023546840417228883, 0.023175960016106407, 0.02356720877991569, 0.07706891249624953, 0.05937706949489732, 0.044733019200183695, 0.015695214857377352, 0.0831962522539881, 0.08198345080018044, 0.10327200765811628, 0.04715610550896776, 0.005142352263998962, 0.08187211524214476, 0.02870074480832104, 0.11464501190329753, 0.05904290960320543, 0.052140721705772226, 0.07401390707180386, 0.05782319037544151, 0.04517223272893218, 0.07664852174780062, 0.07813582016575722, 0.0608752808353353, 0.04160228598442289, 0.11058366572063778, 0.0425396022206593, 0.010850442265490852, 0.11427260890242555, 4.528889704135157, 43.28443742567494, 99.27915849993306, 102.27517466391288, 91.8256510457685, 98.33972730944234, 112.31961158014114, 71.3524398496074, 49.36664504389609, 37.87325712942308, 35.90843600611533, 39.045606505486276, 66.58726215362549, 65.47505447941442, 48.23045207608131, 23.439482065939135, 8.30687007596416, 1.1328350512250778, 0.060506233299571666, 0.6154204316196904, 0.08092919890318187, 0.06908290553838015, 0.21879046704740296, 0.14144220058956455, 0.13972441695870894, 0.03022084711119533, 0.24190652664870987, 0.22179483406005368, 0.16734389377938164, 0.17777096329917833, 0.13386620388877007, 0.2631805891231183, 0.2678074231070857, 0.3543008641610223, 0.5002074268075728, 0.45738072164597054, 0.28629548427078033, 0.1713661005299899, 0.5316075322128112, 0.3979925745196881, 0.3808147688546489, 0.2445965064989944, 0.2394292128062056, 0.31428389371402804, 0.23292258291715578, 0.22874594816277105, 0.12760005666003113, 0.16643932780190823, 0.16315342347708442, 0.06010475343153362, 0.22458350135674401, 0.3919596321159794, 0.19880691032496192, 0.05066486481096476, 0.1688524128328408, 0.16632936354125702, 0.4074282956219489, 0.2904021445541613, 0.42449995214419983, 8.750339131201468, 30.3594373503039, 53.945333650035245, 67.26227852606004, 59.753347981360655, 39.595067808705, 39.95516884711481, 37.956128966423776, 52.19259900431479, 51.5149389543841, 100.93718359547277, 122.76164347125639, 103.12603089117236, 92.72954556249803, 92.27185203183083, 102.57414556318714, 77.85947153645178, 20.663399081076346, 0.014721786194000275, 0.22399581998826998, 0.10108354726746198, 0.06301235204802887, 0.24740290107025256, 0.06650094408541918, 0.04100865977365644, 0.05560720444566781, 0.06265494521827468, 0.02538034354426688, 0.14077751206294184, 0.05710195306868804, 0.01931611219451072, 0.05495992143668475, 0.0683137072971271, 0.018426944584315343, 0.029679803260331674, 0.11018432706834809, 0.019425005847287756, 0.011375064064087647, 0.13648849221006518, 0.03243690964976146, 0.045964118664062796, 0.024641626026301135, 0.019183485137839473, 0.03669045197086469, 0.01691754069930363, 0.010728764520477383, 0.13401516202476718, 0.09444764004118981, 0.030489722905199856, 0.019387804617684697, 0.04427546169608832, 0.07094150379059777, 0.0857722228993812, 0.0429565915387244, 0.008128484947636964, 0.01760062682742794, 0.07849451019278458, 0.04158963021191378, 0.050028195950172605, 0.03021457285109547, 0.04193376839881943, 0.021986922609709927, 0.011831847819379501, 0.030609332212817766, 0.05411139479087246, 0.016246064633671797, 0.01721825510744126, 0.03400302319336803, 0.06189706592610287, 0.12831409657073597, 0.16921979795780875, 0.1722356562893237, 0.16900409824184834, 0.21952151411002685, 0.166978852883462, 0.11602872757301216, 0.28772953957799946, 0.305554352460369, 0.11811647804514055, 0.15745470991298077, 0.1101886937695165, 0.09339279825648955, 0.13125165305551023, 0.10340671655872177, 0.3051559560962262, 0.15816657413398066, 0.2794275979601568, 0.09952355476637041, 0.19658954543692453, 0.14698765060353666, 0.15628037373385123, 0.11988625606341709, 0.25937585941245483, 0.1815626541933706, 0.1467563533374379, 0.15224351938213074, 0.2529531314728722, 0.09375694282953778, 0.2361275730354171, 0.15625958210758625, 0.08171803197793423, 0.26319018054393034, 0.1707906152812704, 0.16579817349631942, 0.1929679260619225, 0.14444426933844245, 0.1608671872846542, 0.1657011867651055, 0.20734589486833543, 0.2704602630148011, 0.25729697257761036, 0.11690747638743733, 0.17028162646437847, 0.3171807785909022, 0.2632428261060869, 0.17445475253606998, 0.18584519294240784, 4.0619467343053515, 45.87193481383785, 112.72975029483919, 112.42990862938666, 94.0990803318639, 93.61666802437075, 98.86195951892485, 63.539796260095414, 48.07255314242456, 77.65086420120733, 71.1130105295489, 75.05336869147517, 109.28794107129498, 98.41531138266288, 64.37839900293659, 31.59739621223942, 12.471427975162385, 2.046352858024259, 0.48322491227619113, 0.9440725188582175, 0.24637096531448827, 0.2077904556907954, 0.5447091066068219, 0.3623995473307948, 0.6443102201146464, 0.3588360433857287, 0.6389609652180827, 1.021030524805669, 0.5568971977599206, 0.49392216568512304, 0.46481673876124047, 0.5227837315009487, 0.6770463215727961, 0.22704699497309425, 0.3068510328810061, 0.45243553216418914, 0.29194133776810866, 0.11878450671511313, 0.3678492823195073, 0.2456911235687233, 0.45989076276460006, 0.447771190515449, 0.434008696747403, 0.5059552006423473, 0.43920574529517087, 0.6739330015355541, 0.5186975410869045, 0.5290589721933489, 0.5602991797270314, 0.37220841453921416, 0.6877542695691509, 0.617239430787102, 0.3938844739910095, 0.21612546166344998, 0.2879341156972993, 0.3842350450013915, 0.5878836769730814, 0.3617704665708927, 0.7030850372487499, 13.7562709277676, 46.24068467847763, 78.19799561654368, 107.9734528449274, 109.05779207906416, 90.4965009996968, 92.00804910352154, 48.77182152963454, 48.382541979512865, 38.944915340792754, 79.41455794918922, 110.72337165955575, 98.07409655663275, 93.59439680653234, 102.13701309696322, 118.11529790201496, 84.14431664251512, 21.58134548894821, 0.4601705993615812, 0.37212549318229, 0.31734018616618653, 0.11646823987605111, 0.28669525959318687, 0.17856368043970677, 0.2295703200563308, 0.21002652844594372, 0.2059704299655653, 0.17809716353733696, 0.1743299261696877, 0.16453228981023835, 0.11331374261287913, 0.13945057116929563, 0.19166151632464704, 0.1792743802070618, 0.22336051859442266, 0.2049215789884329, 0.11200377056675573, 0.130740289366053, 0.20908135980848344, 0.2714227452393501, 0.19781067426646912, 0.08519830047002724, 0.12010511972250477, 0.12345231874215028, 0.1250915553781294, 0.0797673499572181, 0.21443781593153555, 0.17334371054124448, 0.17257589125825515, 0.16338729479860875, 0.12185165463315865, 0.14585391708439396, 0.2614708953807431, 0.16902504308569818, 0.12174208873822806, 0.1360216995160426, 0.11112223319228619, 0.10619472501979721, 0.1804503558143493, 0.12854265890294506, 0.18214793004576238, 0.0839969213871706, 0.08745538701693858, 0.12923328716668392, 0.15768709502393202, 0.15993922498197327, 0.10601896146732954, 0.1114641075893756, 0.20248301387313875], [0.012365140775669248, 0.013082334095792425, 0.06445095408707857, 0.042409225547265623, 0.042084875411444136, 0.0167091571230201, 0.05058726010423514, 0.06691950388372907, 0.05649985392547904, 0.03332268349045227, 0.038786430227299856, 0.032188398388004115, 0.07483243371450132, 0.017330925573685, 0.08163313411416546, 0.0365565819365363, 0.0869193323136818, 0.00865654456579397, 0.0793102176319207, 0.07359713225835755, 0.02193872227273401, 0.03051852206549337, 0.04799225217392368, 0.009262130366668347, 0.02815495887320609, 0.020817309362633575, 0.07636906053390234, 0.024045081020543174, 0.023562633319787925, 0.020400275994512825, 0.039514998995488694, 0.034751621330337185, 0.020981439869971048, 0.06240268012568836, 0.06765906984407095, 0.11017506506534354, 0.02602156871298869, 0.018214470098516154, 0.0438379948478072, 0.03028673450312307, 0.014674724455201819, 0.037363904543341174, 0.020131254643802683, 0.03187054276256071, 0.08152916066108212, 0.13071932920044468, 0.40450922483878754, 24.89937255459447, 76.91608659682736, 89.21131287851642, 82.45539111475792, 76.14926322813957, 79.22844148451283, 51.85536538400958, 30.33508335390399, 38.8288837863553, 50.05852368570144, 75.54329626021847, 77.2880292707874, 48.6784573524229, 29.6626361339323, 11.185575012237797, 1.543386717957835, 0.15477378522196125, 0.24515510716986275, 0.090189125809458, 0.06881307404969009, 0.3192700842215169, 0.11284159496426584, 0.021477221331048398, 0.14252083706519297, 0.08344415064540603, 0.11895209610942872, 0.06971720335704666, 0.18346868094898042, 0.13898253741283573, 0.10274861638824787, 0.038590258092529355, 0.004426528804845387, 0.06403125281776152, 0.021062172130651532, 0.07048474684838327, 0.10073798032657755, 0.2843930734501731, 0.05347774814694159, 0.14120040791890315, 0.021082063603605476, 0.24298807425845056, 0.11620267549709928, 0.12911298071905492, 0.11386175594863393, 0.1474757711853712, 0.04179775331830306, 0.14980368256088228, 0.08444509814463316, 0.1682913453588563, 0.04166982046538784, 0.06892120736020227, 0.32535772530301926, 0.10509424737744755, 0.12598208662483001, 0.03459573009862535, 0.17362330199008988, 0.04749545181590704, 0.10710961786248993, 0.02130463321302687, 0.20412480158190574, 0.2549447455713826, 0.21517738189187743, 1.41670850255797, 13.978493790472708, 39.84661333022579, 66.45357993341261, 66.18232450177594, 70.1872762556999, 50.95853505596038, 52.42184192903581, 19.556296371644546, 23.129614822326168, 46.395386880443944, 52.19495634878836, 74.62966642072125, 74.04419775932067, 86.17324106154904, 74.28576084875291, 22.867116082099177, 2.3299396086123685, 0.571328884651584, 0.08298530228315823, 0.11721704485675982, 0.012550236236664557, 0.04843180661179847, 0.0460734892065727, 0.0034636082343621963, 0.040582190117528366, 0.07921494693765718, 0.04797648608444199, 0.026182320772580085, 0.033912674614018014, 0.023078465751642664, 0.03349149096456747, 0.0915334415772269, 0.057470931656538486, 0.02680859765067937, 0.06661760395452862, 0.013195853004412306, 0.00555182003506249, 0.014836506903051369, 0.05490103991882456, 0.012093381618239708, 0.031049137544487754, 0.05667769357622151, 0.03790165230091061, 0.010625091756904318, 0.05163414989628139, 0.006045164378930725, 0.027729010156866525, 0.06032671974671464, 0.005224838866026051, 0.08939677639113319, 0.04529775240488591, 0.05168785649021307, 0.030064883101130688, 0.07001082187578564, 0.02165255012861904, 0.01792957923645454, 0.06079812045960177, 0.043812484119928656, 0.06964666964185816, 0.03022755038053278, 0.04644895272870218, 0.06275048787375131, 0.024378256489252372, 0.02121697934795051, 0.049047986451055736, 0.022129993360008926, 0.019930878601547693, 0.05663867288779828, 0.0020744298789424883, 0.09558761717691537, 0.08280708724933286, 0.026016807476539287, 0.08187665048265651, 0.07980992146317037, 0.02338699042616833, 0.029982461616577163, 0.062018563640454126, 0.07395707866958073, 0.04385056635064464, 0.04375182910852375, 0.07473411399029917, 0.01921535631070935, 0.07266286505205978, 0.05768904071902076, 0.03753160885084541, 0.09524974941966996, 0.019522630346698627, 0.05676966243153138, 0.06585728467231797, 0.04203887949247034, 0.06983845975370177, 0.04527057160533244, 0.015916217816993594, 0.007044984292494314, 0.05311247359420504, 0.03289486935001708, 0.036559155991961884, 0.0695828545177656, 0.022380858426913623, 0.049060178740370664, 0.05036984435132435, 0.08429404092772354, 0.044773897651823304, 0.014964658091025007, 0.01141438639963106, 0.06533333415826482, 0.04344149838171659, 0.05460870459735875, 0.026114366858476595, 0.04432809193648639, 0.14840589385599862, 0.12027533679840066, 2.0522650956146182, 40.11679795480544, 98.71891852348082, 99.85554295201456, 91.67010553421514, 107.09485761580929, 118.12908111080047, 75.51771456195463, 47.31056605615924, 37.90505970678022, 27.112705246094738, 53.22413529119184, 75.95869879568778, 50.06177925294446, 34.51756746538224, 12.353006716697449, 2.0012742833745096, 0.047304274574402845, 0.2775878837752727, 0.06710660553747608, 0.019183852860043128, 0.30929856122501437, 0.10838213586999525, 0.06791372513098103, 0.10825864249660123, 0.0733236541911479, 0.08972054813057186, 0.2927896422484229, 0.19029282363912753, 0.6340967971951731, 0.38591170503247174, 0.31853889926306667, 0.9548741134424364, 0.5230128224338255, 0.6768776596553865, 1.1512187099264515, 1.5133721285289334, 1.9499890482233417, 1.127026756444285, 1.624205929617728, 0.6042536276002085, 1.244129363086916, 1.0300014143989933, 0.811124517311973, 0.9600209372658884, 0.7784147692784187, 0.5324407294392586, 0.5718193647842253, 0.5945948523379142, 0.7260500243113888, 0.5046251187882116, 0.5776999782650702, 0.5725400390163545, 0.4482924060956125, 0.20252510274369873, 0.20933217699489287, 0.18597993248653027, 0.03905785900931205, 0.21797706553291893, 0.1380185536559551, 0.2305784917646839, 0.4033341685370092, 0.2658966159628284, 0.9356207304423856, 12.952919506257581, 39.32074508359356, 61.83189038307437, 49.570180754507746, 43.45402502244519, 38.77847740727086, 25.15293613556893, 24.62596962528844, 45.46755806092293, 81.0815417382025, 78.19150801627868, 94.15365619044151, 90.26309644022297, 93.0009029757592, 94.70576117115637, 41.61896767154817, 7.7683183550834665, 0.06959811498921725, 0.2522633918711255, 0.20414925510844878, 0.059406131040304906, 0.03713199057646337, 0.05008403609897341, 0.009368810982954119, 0.03923670606567495, 0.0767581565906444, 0.052221777638600725, 0.0448757145673998, 0.08814901834534061, 0.037489382084459066, 0.09203069392711886, 0.09393358738311837, 0.028330684121277545, 0.0470917196493716, 0.02721343681426539, 0.04548684588723606, 0.025702337959721207, 0.03326308951082249, 0.042899973810680454, 0.005423659270989799, 0.0571862955187117, 0.04273520745036583, 0.021421036442681667, 0.07172123574080967, 0.04022035529957183, 0.019526206062085206, 0.02493340210358222, 0.049866639498260715, 0.0295519853206051, 0.0023996677191462368, 0.04098461993459252, 0.08852885239907811, 0.04157358833077935, 0.04209523675062003, 0.03210142251074074, 0.060444440647599205, 0.020057488037573717, 0.07300945855076275, 0.08514760077119836, 0.04097864061834351, 0.04989338362769735, 0.02261903899301204, 0.06686135014939694, 0.026746464089580604, 0.03649184367649498, 0.011894993574148225, 0.21462418980175452, 0.1989060727458808, 0.15443575658625172, 0.1930572519138936, 0.15390101189334549, 0.11720735384451768, 0.24487766076720532, 0.10554037868015229, 0.1367475984678153, 0.110361707066336, 0.1298957540383262, 0.1667211102622171, 0.1349816738717979, 0.09180708818377988, 0.16193876042962074, 0.32312945132294013, 0.1768347885339491, 0.1930580180018179, 0.1704779135123376, 0.15551843800612036, 0.11160745030088771, 0.14936390212706982, 0.1723453294365637, 0.1105901468244772, 0.1713818666194716, 0.10800178087646924, 0.1794169185262534, 0.07036784949201731, 0.1720154826198855, 0.11535987152808136, 0.18563375267530643, 0.18342479943267762, 0.16242691165497228, 0.1545810987872462, 0.13471179641783237, 0.2157594095314703, 0.15996432202237268, 0.06906743822318893, 0.10337363688215133, 0.16568140637490059, 0.14726869761943817, 0.11233163321571005, 0.1337884612862141, 0.1373814442946065, 0.2690802015844853, 0.26943275524723914, 1.7645194069031747, 40.549784475757235, 110.86944856951314, 115.5178180817635, 100.01132380577826, 98.64125559406897, 102.44325607053696, 65.54767716315486, 38.51900869800199, 53.54504792921005, 71.2160276597546, 111.01190120943131, 110.30689439465924, 75.45758462721302, 47.14462234127907, 19.06415266375388, 3.9065296803751304, 0.7227654683013117, 0.5294690437374577, 0.20203440810643858, 0.3689184652701501, 0.9402706389946323, 0.5151102884161858, 0.2797914284371561, 0.478260325448167, 0.3217331181851126, 0.5093569681048393, 0.33562149552087633, 0.39442386117673695, 0.7823763631524578, 0.233538824043447, 0.2140932142614357, 0.5469913131767704, 0.3100481016501304, 0.1410326499852442, 0.23118596884512135, 0.7392943362074514, 0.7212101259539205, 0.46252273443725805, 0.6808157193083918, 0.4336480225526518, 0.8230271334609678, 0.3885752088840931, 0.3539967272550829, 0.4629870756499229, 0.31702946090409834, 0.2685048695533507, 0.4480996583738635, 0.3045133921888567, 0.57937188855102, 0.4212235166661201, 0.27324603449913765, 0.664058986210054, 0.292164545145727, 0.3730921735686641, 0.4382901170080708, 0.4354585641093793, 0.22536504893533646, 0.39019885563081314, 0.21236321918906706, 0.42658407902044637, 0.7850699282942281, 0.6377277475210928, 2.9223489040328614, 21.4129130301937, 60.91334189138105, 95.49950768870693, 100.37794774578464, 97.0476044377973, 72.80487783493535, 73.9973097462808, 26.709165919211607, 30.088864411077193, 59.49964123387491, 72.33219300546955, 94.75630483319684, 94.86895530454575, 106.9755312704271, 108.16430753277196, 46.93962750896331, 6.130002189067103, 0.8033047820771895, 0.3839901420137575, 0.279773440692694, 0.16911004820177633, 0.12256287534030215, 0.1784091758271379, 0.1343741661478435, 0.19680993361098154, 0.18470283327323778, 0.1807772914969152, 0.2327772407161613, 0.16740438408188282, 0.18159418637233396, 0.23576997851412143, 0.1593695620014783, 0.15407768709044303, 0.12948871620239752, 0.16821862829308357, 0.15203905051514027, 0.18443942160135318, 0.12794428294704807, 0.06947433050241202, 0.07107602883010142, 0.10612534043649513, 0.1364156525702246, 0.08707523120627289, 0.1371760561221069, 0.21505560455543382, 0.14241873286664486, 0.11128734046172713, 0.11213329305211384, 0.15296272272544523, 0.13467577496363273, 0.12920382342511608, 0.23436537162671167, 0.15360373913520767, 0.16461311208624996, 0.17047613618835328, 0.14371556650486686, 0.1620072946553269, 0.1302878838032484, 0.16427624790418535, 0.14033325767565158, 0.1332249116873549, 0.19292321717066152, 0.20628098668831013, 0.11221613013936628, 0.2517766196040377, 0.11391411039737925], [0.02682604530315486, 0.017740510651961933, 0.026139191937662905, 0.06917104395406862, 0.026280439398702116, 0.04082649938702103, 0.034729255393387816, 0.10470366511013239, 0.008917639779317523, 0.015237579786879642, 0.07337590138758383, 0.04960766730589732, 0.02208397637361721, 0.049684046271948085, 0.03772991454048503, 0.012923270302464165, 0.054115435904673034, 0.015497404252058797, 0.04433935725941293, 0.042255996471090664, 0.041405872531956246, 0.07637558760301721, 0.08544750121091643, 0.07252366687621802, 0.04830519526055263, 0.017684773925030907, 0.0540225247612163, 0.02217594331370727, 0.09103725408954967, 0.032739977863046436, 0.060288702633472226, 0.04590035716612493, 0.03560955170542002, 0.012271348631099589, 0.05328387427594393, 0.012535808885830545, 0.07954131571515914, 0.06262324449996795, 0.03059906854985222, 0.03254828734263297, 0.03107244960002361, 0.04456408915200061, 0.11334941166663363, 0.15302656849305477, 0.15569497530739154, 13.563961040589119, 77.27734473443802, 91.83224847239833, 82.5733995437622, 72.78628580031857, 70.86821540709465, 47.780646431830625, 38.15073736252324, 46.07796122950893, 54.61507051221786, 65.56744590882333, 76.62230891566124, 45.76185741732198, 19.522901311997447, 4.771229913157802, 0.10660012342756796, 0.18502451359264313, 0.13502261361047146, 0.03768860324916821, 0.09021269067400887, 0.07558996443666759, 0.05110747593965742, 0.18105478386484808, 0.15837897967186668, 0.123198414221406, 0.06759157749794184, 0.15835550673786672, 0.26290170247516326, 0.1112963573165959, 0.04418967133988777, 0.13526976889660283, 0.23537674558258828, 0.10470220188219702, 0.21063794321831197, 0.25964668681544645, 0.3689096705807794, 1.5117539056847173, 2.083619909901773, 1.406239206271787, 1.1333763383088575, 0.7241093703816015, 1.1453870034986928, 0.809902208707025, 1.1091148853302002, 0.156465858942078, 0.32764327201631765, 0.360661753483357, 1.030875735225216, 0.05583736790163864, 0.16840602872112106, 0.25484687017817653, 0.16656922567034924, 0.07173981337297348, 0.07976115230591067, 0.09963164977248638, 0.08492098430231695, 0.10733810358590658, 0.1718060341813872, 0.13186934974885758, 0.0428121073562051, 0.1723639760166407, 0.08811099740165858, 0.14654305913755972, 0.04782852769318608, 0.1816011884159619, 0.2263373064417993, 0.9211570517190042, 14.027666584137949, 48.84074934067265, 74.6618220113939, 66.04799116811445, 82.84006580229729, 85.90565696839364, 53.573469423478656, 27.507380016388435, 37.40974672379033, 48.37084154928885, 61.07546914008356, 82.05588986796718, 80.53812088504915, 96.16935437725436, 73.40303928621354, 28.02098105030675, 1.1566095174320283, 0.3748915608852141, 0.12057967288720033, 0.009720575575145983, 0.10098167289529117, 0.05133351784259562, 0.046727463993574345, 0.01862624427303672, 0.0663886968827536, 0.010900084762984227, 0.047060198961727084, 0.06088242077478959, 0.056774477294135484, 0.02480462272351067, 0.061295656262025724, 0.028287476762348128, 0.0051353885247672525, 0.04686437539696213, 0.07947262061098892, 0.06258899653931299, 0.042400967119441885, 0.0350159140033347, 0.04511763364256871, 0.030880420085703655, 0.012178050613241091, 0.06843399076211838, 0.02417082094677514, 0.11117803503669078, 0.07869882584219018, 0.049273760223220435, 0.031478098901589556, 0.05029811170853434, 0.06077800682114978, 0.04764837062647266, 0.03964864686431904, 0.06737512701581563, 0.06551086737383759, 0.048146017511645635, 0.0346912919063001, 0.03877713758077833, 0.02738079446698389, 0.04014119543435593, 0.031154488040614995, 0.045803190404248816, 0.028675515617754672, 0.059465625428504525, 0.014624733387702897, 0.09179005804922312, 0.025705699170488986, 0.04984577892408256, 0.050584919705626466, 0.04541811630910924, 0.010278807566200775, 0.0540266233316112, 0.038096334394668384, 0.040521941132723324, 0.019406077729898597, 0.037519719166260575, 0.06267018653752823, 0.04619960643110737, 0.03271305753338722, 0.040420932439906944, 0.04714178732566295, 0.02996746161501975, 0.032768778938559756, 0.02353722984421878, 0.018503051589152986, 0.08659145434296901, 0.09390110525512889, 0.06516202157663722, 0.0533880315901291, 0.04398085492392702, 0.04341296926741639, 0.021130706356357665, 0.03349103897269215, 0.034564615437580694, 0.06964869977485749, 0.074173184412141, 0.009071968191663825, 0.02747074276539347, 0.04663293257415776, 0.022584218381633683, 0.00815351016729349, 0.08425411242511004, 0.02330054698001233, 0.1644692101305531, 0.0559751526452601, 0.04953504217067554, 0.04151737279889565, 0.11202869906781182, 0.07432718340667986, 0.11570015246228826, 0.14320512212091877, 22.818425739965132, 101.86534973882861, 106.62895064200126, 88.73350543360557, 94.97254510079661, 106.86510086059572, 75.96155428117322, 48.849425623493815, 41.747197797221524, 21.40426616514883, 36.04054143351894, 65.15318478307417, 52.1560582037895, 21.512060742224417, 5.285969415018636, 0.10978286635250815, 0.33842951419853395, 0.2523085757368996, 0.04994266606386631, 0.13413830299771604, 0.06893754035474793, 0.10493217381618677, 0.3240104524358627, 0.21409031844908194, 0.4545038469856786, 0.4515693931569977, 1.332505756328183, 1.3397506191845865, 1.1050462842948976, 1.4378124475479128, 1.7180363785836006, 2.5849262745149675, 1.8841143120681088, 1.5030923317517004, 2.632847832095239, 3.8956482900727183, 5.730974078178407, 9.515573939969464, 6.6421617519470955, 5.398263931274415, 4.985483990561578, 6.498327947431996, 2.93133431865323, 7.140005153994407, 4.910743226928096, 1.4798451791847906, 3.524025534429858, 3.791184295569697, 1.9412203445549936, 1.7290879016922367, 2.3485301723403316, 1.3973865393669376, 0.5316872053569364, 0.4325589826030116, 1.0617786189240794, 1.356778976417357, 1.065085176979342, 0.9566975865633258, 0.6940717370279375, 0.3677489860884605, 0.536217910628165, 0.10212707393352063, 0.07421099851208349, 0.23204741939421625, 0.14335754297433362, 0.2118542456939336, 0.4018282541824926, 13.090582932195357, 40.01669514563776, 58.80719384839458, 45.827557117708274, 65.5462964888542, 50.37594933663645, 27.75685060408808, 25.12408906413663, 60.29150893611293, 87.97834719381025, 89.25082683563234, 104.57193420779322, 92.2665019189158, 112.45447835614605, 97.57652036605343, 48.53802865551364, 4.920557487395502, 0.38730289005944807, 0.09523008394265368, 0.026296588532145948, 0.16574525214251012, 0.053505618425626914, 0.03608347284757803, 0.04968970766170852, 0.017966550639680317, 0.0438347734480856, 0.020373978111292088, 0.09677488492020676, 0.034355534721286066, 0.016369467991734707, 0.010165488798051112, 0.0441096036604816, 0.04341773050386579, 0.04829994372783169, 0.01729351558512257, 0.07516191280897587, 0.0454734125354838, 0.01721236772174316, 0.07526862885682814, 0.005698766232648444, 0.03108479893736301, 0.13186787886004295, 0.05287279149577503, 0.053352500432200974, 0.05777491151445335, 0.04350146774442927, 0.036320799225640875, 0.04411690830883961, 0.039852273034592794, 0.04298163878340875, 0.04587915951326009, 0.03628808344083448, 0.048864347514726465, 0.009426969505335775, 0.027557730133975708, 0.04946506769967176, 0.04856934620728416, 0.02229662514441917, 0.01418924496148623, 0.0260654904489075, 0.026725302825892167, 0.04588645267029924, 0.03174068511373574, 0.09743919806374658, 0.12554178525122905, 0.15089246204062817, 0.09987775551816148, 0.187247792679456, 0.10771982987681705, 0.1556339180998264, 0.06636845683979412, 0.1486299132868167, 0.1175256786988147, 0.14020340577248605, 0.19965192062720177, 0.08277227621405356, 0.13703523383986566, 0.21537962910388747, 0.11364961088064218, 0.08698729963432397, 0.17141756631674307, 0.12283918793283163, 0.1967946424960129, 0.2003419206988427, 0.16719564044427487, 0.20450816730097418, 0.2397129870951176, 0.1872596057552484, 0.16116386249421105, 0.0931221470537205, 0.10265367511179178, 0.16261198317571995, 0.17949447726770756, 0.18178223031422786, 0.12344150158065943, 0.13262180130808585, 0.17891922184536535, 0.10222226035811248, 0.1277244769998135, 0.23387763408883927, 0.18585954943010885, 0.1700700329796922, 0.1605419369955217, 0.171885569429686, 0.1548431621443841, 0.13965920755459418, 0.32140841947928556, 0.31938536513236265, 0.24131455518785985, 22.14216205381578, 112.77257473238053, 122.41267019702543, 99.21087003523304, 94.34505216536984, 93.92255013988864, 63.15474894738967, 47.676711467004594, 62.68048340274442, 79.05307231410858, 92.57043069408786, 111.10872883950512, 67.62864358963506, 32.75639384023605, 8.36514865198443, 0.844391425771098, 0.7339093509700991, 0.4490566247653577, 0.12050455030534538, 0.2694456561678841, 0.320906417384263, 0.3484306694759477, 0.3092548942133304, 0.34906293716161485, 0.36340281607643254, 0.2935148517210638, 0.5236434660130932, 0.8465973299837882, 0.47339260277728884, 0.3973330034603996, 0.5588373613934363, 0.7593568919166442, 0.5617310287010285, 0.5731493547078103, 1.1344541320877692, 2.645935800767714, 4.016823542694892, 6.265279833347567, 3.626976719787044, 5.037844200288096, 2.1965817193831167, 3.3343201010457935, 2.481634823545333, 4.151985722203409, 2.817370833889131, 0.8130884603146584, 1.640057330650668, 2.093459910923435, 0.4608588527527548, 0.5236123321998505, 0.6714915712514232, 0.3991184173332107, 0.2720589659387066, 0.2271899316580065, 0.3647067896541088, 0.3075793067053441, 0.38267939621883057, 0.5182503296002265, 0.3840897947309479, 0.3600315695568439, 0.5540281065529393, 0.1167487965956811, 0.6628064018103385, 0.3550970133754515, 0.3662799358848603, 0.47228327681941373, 1.8013318315629037, 22.182115316390995, 72.25573032133042, 108.03278261615385, 96.77082630895801, 114.5888517748925, 116.53901500086631, 70.89691931201567, 39.54437117422781, 49.93625948506017, 64.19138039312055, 81.36639994959678, 103.26934645252844, 99.21378043390091, 123.35637677100398, 106.90176717696652, 48.17843360285605, 3.403409709853511, 0.5287551723660961, 0.2674996396226268, 0.17179366952228933, 0.37807079512746106, 0.17590143297228122, 0.22633631052749775, 0.06734698860635681, 0.14656722155069152, 0.10261612148174357, 0.1343493448990968, 0.22378640219328866, 0.10477070546438617, 0.09094409779795716, 0.14743878446038694, 0.13240820067303796, 0.13021467644120419, 0.16319877588220183, 0.19745882540460558, 0.17931093792280844, 0.12326042137799725, 0.13243363479212408, 0.1346707800703664, 0.11166878330010561, 0.15054689509974373, 0.14774793158135108, 0.1197795170329271, 0.2112837553384804, 0.20513625214657477, 0.09799808984802616, 0.139354886787553, 0.23057302189690454, 0.13850711856878575, 0.1427754846912238, 0.12235293660553233, 0.10878252406274119, 0.10398318239998433, 0.09316256585260553, 0.06287300065460225, 0.11456465694091975, 0.14976196141252596, 0.15862193679617298, 0.15760207458609538, 0.17793855269349393, 0.08909282334629567, 0.14900413191606923, 0.10246104230323147, 0.3435375126859834], [0.07329502548541754, 0.033872669502612085, 0.06785062246865804, 0.02640139510584695, 0.020654375867677793, 0.01702572572075071, 0.025928625010795174, 0.037843766697351976, 0.06776828333855638, 0.017400675963970925, 0.04412865626715845, 0.05245456111527259, 0.051504849576421326, 0.07530382293606959, 0.044817457411197886, 0.030220726452347253, 0.020551903946926037, 0.06608815292917913, 0.01797280766280188, 0.04061594012103254, 0.0015914406497857625, 0.02889047031320872, 0.04761766965290712, 0.10343454087213164, 0.048411018815973116, 0.03731377174957626, 0.038142675053208105, 0.06565290007499919, 0.04200965706859866, 0.004388120986761585, 0.045062996251809026, 0.06454372733470894, 0.06823967256012463, 0.04347169756769173, 0.08399395662690363, 0.0669671698743778, 0.03351530480769373, 0.07805477572424759, 0.01591128229554142, 0.08475173249720566, 0.12880633104472392, 0.1054319236127119, 0.15289924468003935, 4.354525641087563, 39.9272729504493, 100.31040453141736, 79.41785274013397, 78.48240667773833, 78.65127255839687, 54.90185852973692, 34.73116013311571, 46.674679248563706, 59.22979785550026, 52.07980732763968, 79.9154132412326, 68.63055813697078, 35.023510071539114, 6.025034169996939, 0.21631011949671855, 0.1671684749664799, 0.06976026515927046, 0.30532654855520497, 0.05746125596605482, 0.2618874327069329, 0.12406769418908704, 0.05069908212810274, 0.20492517960167703, 0.1381041563206142, 0.044314221914617286, 0.08487354047716626, 0.0714439578774956, 0.21207532334712245, 0.4638586692031353, 0.5113667231653968, 0.9571870248163901, 1.1154280626966109, 2.7391107236185386, 2.1262455323050102, 3.4718084912146296, 2.3105518231468816, 10.175731393598742, 9.482854508584547, 6.071493664095479, 10.026806842896248, 5.08511072204959, 9.831083513075306, 2.130281896360459, 3.72592929390169, 5.485171396886149, 4.992547198649376, 4.833462238311768, 5.540277265733288, 2.5529770985726388, 2.6261572491738105, 0.9646032462196966, 2.322386104253031, 2.6449549630764992, 1.932780997407052, 0.8393101790739644, 0.7026961710183852, 0.5358690648309646, 0.23477159740944065, 0.18934776225397665, 0.1265942445024848, 0.04505355804858189, 0.049259909353549444, 0.07780961992759859, 0.2226437207671904, 0.09424862572022023, 0.05601718788966537, 0.08476740665613644, 0.06011075189998073, 0.522238215611827, 0.556507167075911, 17.93070927742989, 62.1026006052571, 53.15669405844904, 59.26598564271004, 79.28154253190564, 82.11041865810272, 43.553755206446496, 24.176450314060336, 39.38865307838687, 48.10222195040796, 58.43729472929432, 63.91385309157833, 76.81004139684862, 89.90013599395753, 67.40944585492535, 10.2056610391986, 0.17988545790074334, 0.07257114134488568, 0.05993412649859825, 0.029263817517447378, 0.036890312818990606, 0.012007259929011907, 0.0605451658878836, 0.08839664860598503, 0.028067262873293895, 0.06106941134578759, 0.06555776727656204, 0.02886276857386674, 0.06295992099049111, 0.016556680728230747, 0.031809052715318344, 0.050755703686586315, 0.022314850376137806, 0.012039916342004173, 0.05036161656701758, 0.05504398043417642, 0.029832409890068155, 0.009362264761641141, 0.02976556105779544, 0.06789885536437074, 0.03712416115787722, 0.07239389924272414, 0.0457810657849956, 0.047765474826578176, 0.03835220010049882, 0.06736028789272232, 0.04143864194291734, 0.03385667741719273, 0.06700526742685227, 0.025877446507013617, 0.08510168912189622, 0.10611327455168772, 0.024334857608341885, 0.03259866911497328, 0.05203042036643432, 0.03680847164603972, 0.031075391377652847, 0.048823285201985034, 0.010308300036065763, 0.0394169052672242, 0.02486757791390823, 0.036248599269217065, 0.02261152558569466, 0.0567145424053794, 0.024072457172517336, 0.060719584956044154, 0.02973043018080775, 0.018452568310162714, 0.07029828104761339, 0.08808339525374674, 0.038747240999533285, 0.03534829657104227, 0.02553177231381978, 0.06751339056438978, 0.04137800225327092, 0.04998219620075919, 0.03582044421965557, 0.05490754400530169, 0.03845402467695456, 0.05017763289112238, 0.009125332918859298, 0.034235052073434476, 0.0294236081366938, 0.06604026477303236, 0.03829249886855964, 0.0644585460184082, 0.029851412701029933, 0.030550498575452837, 0.029634129098286072, 0.06564302520165521, 0.0371979660685024, 0.041563690474797646, 0.035046274067773935, 0.018654819352612383, 0.06008202743325984, 0.11345916142266606, 0.07192064076662064, 0.025271976576937784, 0.025142339178391045, 0.00800711746823283, 0.05123117998723061, 0.07657200488592349, 0.12672082521021366, 0.1687807529684036, 0.13036248544531484, 11.328695435677806, 59.6103972004306, 120.8793294045233, 87.24112987518312, 104.12562339536606, 117.7148788206039, 76.5233475162137, 44.843658016574004, 34.18273825799265, 32.5883222395374, 32.62733021090108, 64.66259433377174, 69.53799847633609, 40.46129580466978, 7.06544727087021, 0.18398346139057992, 0.2744942675194433, 0.04573405862996175, 0.5446658379608585, 0.12677006934198642, 0.10343907611264337, 0.050066511837705496, 0.36488783155237475, 1.067563747206042, 1.0458567378021058, 0.9800974664188201, 1.6316410274274888, 1.5732549539496823, 1.0915979478628406, 2.688103731601469, 4.204661192432527, 3.8472379071097222, 3.5864819249799176, 6.950319332461204, 8.442793930730513, 5.760690935196416, 5.74058388510058, 7.618219054514363, 13.15881452252788, 8.332350773196067, 9.98311556154682, 10.154709450660214, 16.43272178788339, 9.928941745911876, 8.20005952350555, 12.32683470172267, 10.069688154805092, 9.745954352040446, 13.210563332803789, 9.881493814529913, 6.4136145576354, 9.037304635970823, 7.6123492275514915, 5.610219009460942, 9.854310808643218, 6.535288441565729, 4.793526626402333, 3.335511030689363, 3.01746319378576, 1.303871228329597, 0.5284404634468017, 0.2762334709686618, 0.4497530906190796, 0.2731480365318637, 0.47680521804478865, 0.31926150403676495, 0.20707044029428115, 0.23584238914472444, 0.10835802708301814, 0.4706877608212733, 0.4968631465829188, 15.324646330648854, 52.12513031498079, 51.66570309669741, 49.33146922819076, 65.23945731501426, 46.45492453728953, 25.34757983299994, 23.555337113718835, 66.74418049473917, 84.68422305199408, 84.19609977353005, 79.58493001999395, 83.28889477637507, 101.7018339710851, 90.60191077570762, 21.92272505452556, 0.06326094757945788, 0.07513654763780295, 0.12357205062383607, 0.11871683816876143, 0.061798045231449994, 0.040578168155925895, 0.02889133790778297, 0.05654076685107524, 0.04543874322647049, 0.14080530573283473, 0.03897542794865947, 0.10789232989472729, 0.04505668368731295, 0.016879745751559254, 0.03943966573945457, 0.015580723974703541, 0.03607249480762309, 0.07369564350454078, 0.031346128765313376, 0.025492355174895738, 0.031696997034633835, 0.03539100597282091, 0.04228320025328187, 0.044714246215599204, 0.035679143132461656, 0.02101419778961328, 0.010379797106819048, 0.1556128506819087, 0.02253678604780186, 0.09894648371564765, 0.042740481965724504, 0.036479134277831164, 0.014004370708379054, 0.04487206032800098, 0.07151963970353527, 0.04419239095201896, 0.024618838740993413, 0.027336390095672784, 0.05740345080172824, 0.059390449220494884, 0.0450629196430166, 0.02951964108844198, 0.08238634410043878, 0.020175718386927922, 0.03349635179244703, 0.11881438414416007, 0.17564873120957808, 0.1767918722884309, 0.1519734580670634, 0.16858785202906978, 0.10571298595037192, 0.052580766439918554, 0.16501101815412123, 0.20033652743985578, 0.11412035658835404, 0.11607300745503557, 0.11291014451173045, 0.17632227571260545, 0.08968118653302232, 0.1434102804670411, 0.09442699397163046, 0.1682165751774465, 0.09984809259373335, 0.08146146913209269, 0.1223448773605689, 0.10767581812556713, 0.1773015505844547, 0.17113132522471491, 0.14567054627883821, 0.23595930948372812, 0.20695088461281794, 0.17158691771328452, 0.13789489174321776, 0.12142593191275675, 0.1871522768370567, 0.17138134567968308, 0.14704559749412924, 0.130890411955695, 0.34412274257309977, 0.19413340626464737, 0.2390832015343251, 0.1342104071931493, 0.10385347605352441, 0.26206507317481503, 0.26994468584176035, 0.15523924492299557, 0.17581075880556338, 0.22918343033281066, 0.2617026829431134, 12.316011901824707, 65.4417339448006, 135.21161510098366, 96.9230221163842, 96.14430612133395, 102.78424339909708, 75.00694351811563, 43.598258418421594, 59.8252607160999, 84.853120311614, 76.09931576636531, 115.47935531985377, 100.47496364962672, 54.701170459870376, 11.914561237058333, 0.8709760863454112, 0.3615700579699009, 0.18029068776917073, 0.8119824745001332, 0.6880920224132077, 0.43673600040135846, 0.30789806056887875, 0.3271974088443864, 0.7057324532539614, 0.8442590457777824, 0.3873963221426933, 0.5845183446522683, 0.4490443980020862, 0.34852888194784043, 1.1157769084938112, 2.153024288915819, 2.539743511907516, 2.6574364352610806, 4.674434152341658, 9.421850865887059, 12.39485546465843, 7.304110257856308, 26.312649596122007, 20.40894904444295, 14.614147217042985, 23.54830626518496, 20.616495378555793, 30.200446036554155, 11.971808229723285, 15.42278697413783, 21.409133826532674, 16.215910815423538, 13.903767735727373, 13.27745641431501, 11.527471350085351, 6.540723866032017, 8.80916880023095, 6.729113344223269, 6.473735667044117, 6.821808267024256, 3.4733178682865637, 1.4346409661154595, 1.6575610301186963, 1.1515565240575423, 0.5170353754393516, 0.424392240182046, 0.2157821776645799, 0.36890728038645565, 0.26020035388008245, 0.34171302832903405, 0.26336402121570807, 0.33799768575737554, 0.5377439577733317, 0.21681340861945383, 0.698498254341464, 1.5376305171558935, 27.6772637521067, 85.71551615192045, 73.35516283589025, 86.62083841139271, 115.08449031460671, 121.91134422056138, 59.27200255855438, 32.64664592281465, 54.66299403098322, 64.4600902065154, 79.71215601890319, 80.93704162105438, 94.20015196646415, 118.23566759786299, 100.59396836065478, 19.569806975703088, 0.23871143438643028, 0.21746492043377894, 0.4198912284787624, 0.15291191577430696, 0.19651210926953824, 0.12694786302745342, 0.12642512293232064, 0.10323678293535787, 0.12316505875318282, 0.25959621694299484, 0.17807968141090486, 0.16753115631159277, 0.17760323600903635, 0.08954660020648472, 0.12159966533222508, 0.08348997802503648, 0.06018225088595383, 0.18621384977333008, 0.14115143957878315, 0.08940430703542887, 0.09337030591503268, 0.20765626772997842, 0.10652347633074369, 0.15587425520343168, 0.14046033634053123, 0.17947855796064102, 0.11310149795345723, 0.1901760718394672, 0.11038973056260618, 0.24258318146870983, 0.15925762123398243, 0.11678805860180048, 0.13289960011118843, 0.19924477553896366, 0.1819595796686988, 0.202732436779526, 0.09938149908257109, 0.12294315372503574, 0.1249972882590467, 0.20855369376799754, 0.14937455074921732, 0.18509842575557772, 0.1211584829575112, 0.11503621470183135, 0.1815299728825208, 0.19939620047807696], [0.05904439964421815, 0.024211680246216637, 0.03816471540278966, 0.018757139970999093, 0.04246839817853705, 0.057934150550394296, 0.053428262697472695, 0.09363285956844207, 0.0460542144343978, 0.029995554059203115, 0.05016092834393344, 0.023802453314044306, 0.058500753009631756, 0.0998426074041955, 0.008020664296758873, 0.00596370768635684, 0.04191635522030054, 0.031839686656190504, 0.017446759983056018, 0.04759923757744893, 0.08251763624890197, 0.07578314882853339, 0.053503132470312624, 0.04754327868501987, 0.07059478771782692, 0.029609606623829856, 0.0396202709676037, 0.03674835672662143, 0.051520952744589704, 0.041049664629803556, 0.023495006908272064, 0.06393292543268012, 0.04663939835623868, 0.05905811261806277, 0.12166524245854347, 0.020825150272538586, 0.059680336891042615, 0.10368459197061677, 0.044293257918569355, 0.12497548539672168, 0.3109372539385673, 2.8548873239947907, 41.536766559846946, 89.58854290746874, 88.30456287630143, 77.8606717817245, 75.26938146160495, 61.67947492291851, 44.12950815693025, 42.159132957458496, 54.61570593618578, 60.51479378054219, 59.44576747955815, 64.6542553747854, 30.539330974701915, 5.6870636343956, 0.43153144419193273, 0.2582887193608669, 0.06662306616142874, 0.22115064604628473, 0.15234188507160834, 0.04098789879090844, 0.028964868941975218, 0.11985786484494326, 0.08454336424268062, 0.028730361767473723, 0.0635066434680935, 0.5204208711943319, 0.7888469256220326, 2.085484996918709, 2.3382778321543047, 7.479326946120109, 3.47362871612272, 5.794379192013895, 11.986461224094516, 8.033936850486263, 15.059981461494202, 12.091074758960355, 5.316650194506492, 6.018511268400378, 5.8498115981778795, 8.697225336105593, 14.363327334004065, 12.270363357759292, 6.515636386409883, 10.893696738827614, 15.692994152345966, 4.3137820209226305, 16.547954159398234, 10.027341265832225, 4.139286558474264, 11.848567358909115, 10.96246079091103, 13.664683584244022, 12.20798590490895, 13.10652050279802, 7.6375475141309925, 6.820888961515119, 2.381000288071171, 5.801670387867959, 15.514370395291238, 6.056676420473284, 2.115713723244206, 1.0946154762660305, 1.2718184772999057, 1.2371198424408514, 0.5055790821150427, 2.441199109438927, 0.23527692432605454, 0.07272130989980313, 0.06689236138857181, 0.14554487721573922, 0.1760912695599179, 0.05035740691387365, 0.42046459932481095, 1.3797098878891239, 30.917455304053526, 72.1947374651509, 74.57076811021375, 70.38935676697763, 78.00849806877875, 91.70656004259664, 37.314197786392704, 18.656061426285778, 33.417138668798636, 55.52678231270083, 67.21269192234163, 71.31568724109282, 80.26494349202802, 83.55271339416504, 29.023629080864694, 0.2312319954076121, 0.23610543309440538, 0.029283178474513755, 0.007956624134338551, 0.05614027140601989, 0.04317748150037181, 0.020721931416060657, 0.02978718771989788, 0.061399568428075126, 0.05977337060856724, 0.03156811040225289, 0.009348320046199426, 0.017958510546914993, 0.017880739216061852, 0.034135506608553474, 0.0620653064951541, 0.06454940404622786, 0.024992988422332753, 0.01906091873083384, 0.05236614307749176, 0.017865472998950752, 0.04046728842020516, 0.035813242993167335, 0.0653477366112413, 0.08809676348802545, 0.08073271267236241, 0.044124270413791945, 0.013704306517367162, 0.032275778376647545, 0.029553645816180977, 0.03725846403188283, 0.05815553080831325, 0.013977768305208416, 0.03309780604115898, 0.0178967657754378, 0.05996672737021601, 0.11703411838220013, 0.06171781667357972, 0.04181689402509121, 0.024427893241086317, 0.015836213339841174, 0.009500746645273702, 0.06762803562225835, 0.02239868720813144, 0.033871056887531475, 0.0182046526817665, 0.049141686665074485, 0.06584101296480625, 0.06123416238434373, 0.0415625911386263, 0.04814623584670406, 0.02867722973948525, 0.02839630338243179, 0.08049618302574081, 0.03220726330313952, 0.028617919212387457, 0.01693930142679282, 0.05420734730338859, 0.031855642352433454, 0.059252128215326424, 0.06319381529465318, 0.03590138906973504, 0.06255037421661039, 0.06044991051537856, 0.015730678025002203, 0.012395339004034478, 0.030271474031671405, 0.0584881432023981, 0.03430859268372578, 0.0116284629668019, 0.028384407952187524, 0.034789083029834494, 0.07499433107553952, 0.022807542587660497, 0.03543137880643049, 0.017033993724673506, 0.06482271357409417, 0.05656129034656671, 0.07588646344600186, 0.039291366439072356, 0.11714180736171624, 0.049317994139968395, 0.04085654918585093, 0.02793217858960552, 0.1853341663316373, 0.1890317969504864, 8.276965925770423, 63.21576141542005, 109.42967199510144, 104.25182957803051, 93.11193743059712, 98.1859782434279, 84.65933953562092, 66.34046662238337, 42.87588727089667, 32.5126342235073, 34.72144049982871, 49.6965555990896, 62.798746785809925, 33.99367217094668, 6.261967882033318, 0.21472091606307417, 0.27173288827461584, 0.18399810899169217, 0.10241941308542606, 0.21361715190352934, 0.17382371059108168, 0.8384092596750107, 0.6976532287174656, 0.5922926661949004, 0.5811552799517109, 1.3020571321249008, 2.206329054409458, 2.897445775808827, 3.9582510340598325, 2.7625321765099806, 6.522730483162788, 2.699911781857091, 1.8528194365001496, 1.5821131366875865, 3.5562071108048965, 8.611598034058849, 14.051835248547217, 12.34988647122537, 11.463981905291158, 11.712460133337206, 14.495341566301162, 17.329751176218835, 15.892019137259453, 16.461571801093317, 20.345781234002885, 12.761260732527703, 6.9029728924074485, 5.254989554805141, 5.211745913951628, 4.072429513739002, 7.186955434660758, 10.80473836391203, 21.20247983163403, 9.769001218580431, 13.363394564197911, 11.305350469004724, 9.244315566555146, 5.84652514226975, 6.886910296255543, 4.036641563138654, 1.2426889952152007, 0.5118405332248057, 1.6867698176253227, 0.6545013958407987, 1.2400124678688667, 0.3394489627211325, 3.285067143940157, 0.28327191909474714, 0.4139855486010352, 0.12081228782452884, 0.07973458437669663, 0.1663169222733667, 0.1500713230381089, 0.5637972597633639, 0.5569398535355445, 26.615507564237042, 60.86748938406668, 66.3861700796312, 70.7061352268342, 58.299446951958444, 49.342459709413596, 31.047077871138054, 28.087880995965776, 55.60958354703842, 96.3910702736147, 97.65572086457284, 89.39760977222075, 91.90303156452795, 100.74412453559138, 50.704710637369466, 1.7792508486778507, 0.3006683049663421, 0.04631350455324977, 0.03456984398766391, 0.02386674341264992, 0.0701909521294217, 0.052814166617369464, 0.034495024010539055, 0.015193836166403227, 0.10820038150995971, 0.018928657481146437, 0.019854650937861974, 0.0916493276975328, 0.020528542095675104, 0.07528507676456245, 0.005474254590338998, 0.025976901956563516, 0.027117338745043646, 0.049802222995147596, 0.03650849076708959, 0.02568973389814698, 0.02421160363742421, 0.024150000592213006, 0.022122292261150096, 0.03199593028834751, 0.08102889758564773, 0.009808796345286313, 0.01163063386845733, 0.03914153879328121, 0.08682932464345809, 0.044659405811539585, 0.041347477479927966, 0.06624015243423563, 0.06951398321337278, 0.02598682471040276, 0.018877214677031004, 0.060541392904856516, 0.007517449867596189, 0.04707935882071334, 0.024586004212558753, 0.060933668226484335, 0.011627730395224307, 0.0230085295850351, 0.00278523450458212, 0.014498813430808727, 0.19683942799606632, 0.12734038349721702, 0.15863051698092492, 0.11292391111172977, 0.17885555993885766, 0.11257875785832444, 0.12575832766390618, 0.19232600566840943, 0.19169196065875793, 0.07660673931241035, 0.14061405954341735, 0.1703328164594789, 0.1380843912521678, 0.1596316713238916, 0.12812044486523638, 0.12094091398701554, 0.15137132828033742, 0.19698994895142896, 0.12056106461151955, 0.07947645105061032, 0.14080536701986868, 0.29277701711943077, 0.13632074959816473, 0.12157054633022317, 0.1320654529357149, 0.12599138693223078, 0.12473136381877047, 0.14950691542077452, 0.08161752890314787, 0.17023241297612268, 0.09096528012906352, 0.1869875679333364, 0.14974458653840328, 0.21370586488516102, 0.2391625069562466, 0.2274259786692358, 0.13746150048269382, 0.2269981951723176, 0.12683026853107637, 0.35444084374654683, 0.371162980314224, 9.08489965623425, 73.29419351393177, 124.57249195344987, 112.24210554553618, 93.55438863077472, 100.50573072125836, 79.26874776040354, 54.69043101033857, 65.4332027896758, 75.61724078270697, 85.19977154270296, 84.79684214438163, 94.5175580055483, 47.1592959280937, 9.496278820499297, 1.3428762579156508, 0.46079250953851214, 0.20416149719347879, 0.41773230077758916, 0.345321363739429, 0.28425928385507676, 0.3816501111272843, 0.3475563180062079, 0.3527845310107354, 0.4096912274197225, 0.8798301015650073, 1.286122380725799, 2.2385199464136556, 6.666263245767163, 7.108992934226991, 17.846931372919393, 9.552304975448116, 14.437865114981129, 28.96537207788037, 20.642153563037997, 35.150806673111454, 28.832703790357037, 19.89766417011138, 24.365539935327348, 22.27949207828891, 23.338651657104496, 35.9582854086353, 31.919562047527684, 28.863998420776863, 44.03058205881427, 41.39667126440233, 20.333086482940182, 38.717249208881015, 23.621542799857355, 19.259037586950488, 34.86101804241058, 23.858891302539458, 33.725742909216116, 21.10773890249191, 27.800534040697162, 19.31182876709969, 18.44653037286574, 12.424593894712388, 23.59605327729256, 35.666786624539284, 14.241073919880776, 11.240545069017719, 6.027027714637018, 4.377404336006411, 2.8696317586206623, 1.1225004638395002, 4.590995042554794, 0.6343935490135224, 0.35262503150490027, 0.2324688903266384, 0.19556565360436517, 0.2769804373383522, 0.18365186789343435, 0.6048724427819252, 2.786692996178904, 46.365878889637614, 96.39724408426594, 87.69996873794064, 95.25969397637152, 114.67985860763059, 129.92909246875394, 51.94100641435193, 24.388348517879365, 42.97285218392649, 76.23956403424664, 87.17077039903211, 89.18489963777604, 101.33029922362297, 114.90879950984832, 49.78863716125489, 1.0015445575118065, 0.48929891699264133, 0.12185971387812208, 0.17656651986462457, 0.20094929052697075, 0.21064399531291378, 0.16047586957293172, 0.12462380507420148, 0.11702079611319689, 0.1996538971340464, 0.10910670948965896, 0.12944737809800333, 0.18046063671429313, 0.2551135147411016, 0.1866512246910603, 0.10897684226473493, 0.1329896001205329, 0.14763580695275338, 0.20615326450957408, 0.14556657282575486, 0.11726921544440332, 0.1602419982514074, 0.0826566658854004, 0.1922007196492726, 0.19155355921435743, 0.20626955665647986, 0.09143336751167813, 0.1256663051824416, 0.12755648157889807, 0.19570846771520956, 0.09335968793640215, 0.12668253613575814, 0.15058565914871233, 0.1334791609476651, 0.16349183515675608, 0.11762833448066828, 0.24209014260240141, 0.176789099050145, 0.20697478655605547, 0.06916496121594984, 0.11170570107717669, 0.1535949904111124, 0.182181362122778, 0.13639060149510063, 0.1689279031368994], [0.05351294605662266, 0.03665703138516795, 0.05968578377618425, 0.07197658816773085, 0.06402007176450665, 0.02576471092329631, 0.04990564486492546, 0.042881373195878925, 0.028526329570600105, 0.0026987877067914537, 0.03694232252817001, 0.046903782959787116, 0.01973893718733903, 0.07403835293746765, 0.07792651728396455, 0.0668947056176201, 0.05347122490826634, 0.01647420561752252, 0.011139973705153794, 0.00496099004521966, 0.05739672454975306, 0.04224922425384003, 0.04923791879968298, 0.043264731254068114, 0.06452890353337412, 0.10080454570631828, 0.05546593017155125, 0.02414126718987621, 0.03565988368204525, 0.025526917231599652, 0.030168278157831203, 0.03707209016166387, 0.030100035045536298, 0.06579418967087423, 0.07069838578782736, 0.10005489802889286, 0.08575202882169716, 0.06459682488874083, 0.09763649634776578, 4.341762248546847, 27.744357855089252, 78.25213216966199, 95.36260128021242, 83.77635909665017, 84.91629400560933, 70.19330101628458, 43.8313844896132, 49.2705548194147, 58.09812345812398, 45.56122033826767, 57.09584020799207, 57.91152454191639, 42.22893545704503, 9.977432047167133, 0.13910293579101562, 0.16887531886177679, 0.019019492526328372, 0.13676521849007378, 0.15156206885172477, 0.06662342622275315, 0.08637905646596225, 0.40560077755681934, 0.34002417217819925, 0.33976149595072197, 0.4940926662135509, 2.634824216365814, 3.6456538208069342, 1.918102752777838, 5.39393118312282, 6.4755723168773045, 8.203639666880331, 6.190452777570294, 10.51392109163346, 10.236148641955468, 7.544863868144251, 5.200460764669604, 11.375600118790905, 8.495135999494984, 3.9674318317444097, 7.76503287976788, 3.054226588818335, 11.233980001941806, 7.529656838986182, 5.670598995301032, 7.731705481006254, 12.793423187348152, 8.88152378220712, 6.826832823214993, 6.32410656059942, 9.85977957325597, 7.402234721568323, 13.756388598872771, 12.01718024669155, 7.938006952885659, 10.635256671136426, 8.898046766558002, 6.428820115904655, 18.417973556826194, 15.410148116850085, 20.918755185219553, 6.379635555128898, 11.246843414921916, 5.762200067120214, 1.8080792888518304, 2.282137438174217, 3.2215436235550916, 1.0910744340189042, 1.8295777997662945, 1.257218680074138, 3.3288430013964256, 1.8676667107689766, 0.2096519727380045, 0.29065584223116603, 0.06562750426030929, 0.25442945951175305, 0.12857769976460165, 0.5471531109463784, 4.543211258226826, 52.18891589872299, 91.20066842725201, 57.311821599160474, 45.94371811036141, 67.40568822430026, 68.97001574116369, 31.685445577867572, 17.337539042195967, 31.12875926879145, 53.99916033590994, 69.22226336694533, 71.73523964420443, 84.26018345740535, 56.29318206541, 7.017294293449772, 0.3332288190722466, 0.1018254268133352, 0.09548635567508398, 0.030435543251974933, 0.06765467249938557, 0.07544931835464894, 0.041046876069759174, 0.03572856729489661, 0.04455503399273561, 0.006555612114513474, 0.014891618310714201, 0.048407192206791336, 0.03185827769489298, 0.048817122024634195, 0.03006204474537123, 0.019095448228800972, 0.03541399627142856, 0.04554099681216382, 0.09323778036501139, 0.01686986704777566, 0.038548314778675, 0.02520301908765349, 0.01437812393921758, 0.06724299217063574, 0.05922789685428143, 0.06322575733065605, 0.033811589312409206, 0.025946009461016908, 0.021542405837305614, 0.010142734071480171, 0.03379797209955512, 0.015495013100125138, 0.019326327976981, 0.08257981194483657, 0.027681072205004674, 0.01848746169989388, 0.0431670627046016, 0.030385927567558906, 0.08476655629854049, 0.06940045664387365, 0.06068438321592347, 0.046536037773494764, 0.057998256787898085, 0.06162822269083512, 0.013502655896328151, 0.0362510928854106, 0.07835780946357597, 0.009907152458664872, 0.07118461413248893, 0.0382647511639422, 0.024487736199291486, 0.01940608539077784, 0.0555806786512896, 0.01651814267519982, 0.0026286688760944433, 0.10839868336915971, 0.04073369549587369, 0.04012600008037783, 0.06407437590701927, 0.08811893407255413, 0.01352466943283235, 0.013007140650804485, 0.07778036302977032, 0.014998293181340543, 0.014669538997564346, 0.06351493636987383, 0.0565052701671037, 0.06725017041448625, 0.039861485241882266, 0.031000479469977082, 0.06565653133176028, 0.03866399022480173, 0.11288196013699617, 0.023913103223387754, 0.005860724880720579, 0.011589472921895645, 0.03374908036822754, 0.08972660788605291, 0.05192036034479257, 0.2687714375074833, 0.21302058391513365, 0.015106697495455946, 9.718756637265606, 44.370067119598396, 99.27330632363596, 108.02113317674207, 99.98555383374615, 113.00948589078843, 109.14348017784857, 81.3571588454708, 50.137779097403254, 33.4528047807755, 40.28945676742062, 51.86463394472676, 61.48596086809712, 46.61061517653927, 10.737446181235775, 0.0689184034783994, 0.32587232188351695, 0.10205280170926165, 0.04819958620975095, 0.1780700440248174, 0.20390783015999103, 0.2290343343009872, 0.20878643127939395, 0.8222749576933923, 1.338257176741477, 0.9483940514826006, 1.7358596286466046, 1.576752727550845, 0.8538377188867139, 1.7295974420924343, 2.5932809229820006, 2.600744212827375, 1.565426393382011, 0.7157921682923072, 4.627765792031442, 5.507684330786429, 3.981717839356392, 1.2907399910111583, 2.3074656532656763, 4.598673082167103, 13.881562217589348, 8.969449593174843, 12.845819188702492, 12.2426841720458, 14.402534365653993, 11.501238538372903, 3.661082954176011, 3.9911290762885927, 0.7935562825972035, 0.7931109097215437, 1.1806987538453073, 1.0946572740231792, 5.934359758130967, 4.0335048927414805, 8.925381764288872, 18.57462125439798, 7.048267779811737, 3.8046100783732633, 0.8953253636437078, 0.3556882800354112, 0.32000994129527005, 1.4368720592991, 0.7747473531673033, 5.251781546300458, 8.165674065389942, 9.862218306910608, 9.147424197966053, 4.161049339079088, 1.3938724634147461, 1.0604809272673823, 5.783038639253186, 1.6816294289404348, 0.09052294096158398, 0.41140695793494103, 0.07726521486596716, 0.222437076210495, 0.3043692144415071, 1.037884888149077, 3.646698642161585, 41.62374119604788, 82.5546584590789, 57.40778238542619, 47.23745307614727, 29.340988051506784, 37.38421601633872, 32.962343769688765, 16.187541292559718, 53.472083999264626, 85.76762091728949, 100.49336741047522, 86.780729909097, 97.3544357668969, 80.49677910343294, 16.579444908326675, 0.016870407139762275, 0.09779563579227656, 0.054719028919334375, 0.048419591339845816, 0.07926101180454416, 0.040488294551088926, 0.12099683840548801, 0.12728428287852195, 0.057925470774212194, 0.01709346321501559, 0.007426666533349143, 0.0159945550953008, 0.008900921825589913, 0.013419014416755208, 0.027591443748303482, 0.043357462366862644, 0.06389807992344422, 0.026651633895873546, 0.011865616975081785, 0.10231460459650525, 0.03487100464201743, 0.04868623590277088, 0.06284549043724133, 0.07547777852103596, 0.061113369470882806, 0.001073451855899616, 0.015858527565855655, 0.04123894963413477, 0.03848372973621853, 0.03781765459045287, 0.07899733966276531, 0.013580560334958138, 0.03801870287486142, 0.033596027492275166, 0.01872244384890843, 0.021730664283818295, 0.06923698114171144, 0.011520959763607432, 0.030260066982478868, 0.012446855544112624, 0.011833534170422825, 0.01692577805970946, 0.09915950978475233, 0.18785526975989345, 0.12447765082000725, 0.1873521185329845, 0.32620109617710114, 0.11453015234081015, 0.13054699006099857, 0.1119355580979778, 0.11533357939052007, 0.17778735758075792, 0.18545283335110835, 0.11958493836103909, 0.164383607465894, 0.17051042628384408, 0.2688187204541699, 0.20332952570771018, 0.12405831727289385, 0.17880530457102484, 0.09848048009218709, 0.059633444649197405, 0.23453548911117741, 0.17640147388221758, 0.12499407835064397, 0.2005257051918776, 0.14221536716626537, 0.11517370450160197, 0.15376569012240057, 0.1137925782090714, 0.11977967791139119, 0.14296423343400802, 0.16723838815044972, 0.12187131244929568, 0.08045796289919846, 0.12479805943345833, 0.14297027020685135, 0.17202242337647947, 0.17075025776941932, 0.28645381932297065, 0.20409754417355985, 0.1480897753349235, 9.814656626793647, 49.65195432786019, 115.4804849624634, 118.83572747630458, 103.58781153155913, 108.46113681793214, 93.1048850090273, 56.46439744580177, 63.42959334773403, 81.2059985437701, 65.41435187862766, 81.10345209798506, 82.22524212252709, 65.55563565223449, 17.605183932089037, 0.88124540303984, 0.770796361950136, 0.2232581539259803, 0.8637886494398118, 0.32500290402000953, 0.2666819480157668, 0.23057904334798937, 0.9948761604966657, 1.120797052018104, 1.6033500745411844, 2.357771276466308, 8.966659807389783, 10.20536195847296, 7.928121109162608, 17.849712333371563, 25.535835950605332, 26.676782831068962, 25.84568358236744, 28.319110601179062, 29.12836617039096, 24.054360658891742, 22.419416750631026, 31.69503773412397, 25.153012621787287, 16.096155951100013, 16.628496108516572, 15.987475898958023, 29.06351762433206, 25.739697217941288, 24.47233823037917, 24.2007964657199, 30.92695332342579, 27.322950170886134, 24.32002082947762, 26.70207231275497, 22.05818214724141, 23.142648858408776, 39.80472633915563, 29.322290112895352, 27.094815315738803, 35.47851285626812, 30.419245650691373, 19.03888083273365, 37.54892810698479, 31.556589834151733, 47.38023911753009, 26.615925296660393, 27.960452994992657, 17.387100150508267, 9.084424068850856, 7.283541838968954, 6.435943630433853, 2.966965864742956, 5.166796042073158, 5.547250259307123, 8.396058890127367, 2.92628966031536, 0.3222408199742917, 0.5213477150086434, 0.2725244103179824, 0.38417792548575713, 0.5020107671378121, 1.1397472480612418, 7.923933979003661, 72.99412435100925, 108.36188516309186, 74.53491764683878, 68.85414892627348, 98.216596264993, 87.7653624934535, 43.403057744426114, 25.484284239430583, 43.8190290235704, 73.80524696842318, 90.80173984650644, 90.51535191074495, 110.30887911396643, 87.31181098568825, 13.520735540697652, 0.38992922332498337, 0.1534995818210225, 0.15944036384744031, 0.23272019780931935, 0.15047031695083266, 0.1879352799827053, 0.19670571500976242, 0.328495713371423, 0.11255801219733493, 0.1165698767609654, 0.11487293072165021, 0.1409179972664964, 0.10269336612714876, 0.1506231821352436, 0.11394529017589747, 0.1773824647910172, 0.1638721058806104, 0.1508086366999534, 0.1843051263882268, 0.23157840504521326, 0.11685220314370048, 0.11518728724049947, 0.2090571514300762, 0.09670987469895233, 0.13730762406222283, 0.16933215241278374, 0.12875612164216657, 0.09130583685492316, 0.1080965765962197, 0.13101235783148196, 0.15819461295200934, 0.17487970150766835, 0.10003622846617814, 0.21957656518826563, 0.11710036200501266, 0.20702709503952535, 0.16912327087934942, 0.16850399604487806, 0.15895140056888904, 0.1475602093963854, 0.1484651890613379, 0.09669230830284858, 0.20850363758302506], [0.08660220255654666, 0.0500359794034833, 0.1363211019986099, 0.05610441083028432, 0.050125561894909035, 0.029550951101907322, 0.009713022905822483, 0.07706672148478609, 0.043395337753839074, 0.02600976904373496, 0.05257422787948482, 0.04494297708715162, 0.025371673344183835, 0.05957221124140967, 0.04280436986816987, 0.016584618039609447, 0.11257958523328267, 0.0224065913202902, 0.038805034672541004, 0.04405647163249312, 0.05730585503061453, 0.035860740444472725, 0.02643592651903389, 0.0314457661607453, 0.048122667151713566, 0.04635915956309727, 0.08537459262316266, 0.034930491369337804, 0.1491935854597438, 0.026847332971350803, 0.003536974799053203, 0.07033095469758396, 0.04282195158603211, 0.06166349720930862, 0.06350995296792639, 0.045784061188779535, 0.06156959398198993, 1.5509450027058203, 34.94573339339226, 95.77287335549632, 107.90943191897486, 87.02854525658393, 86.8354626624815, 66.55258840130222, 47.60796800736458, 35.53937235186177, 34.2550196955281, 58.96301784823018, 72.91714391400738, 76.3351208163846, 43.62923729804255, 11.876622111566606, 0.3983340658728154, 0.25161693623710063, 0.03640644019469619, 0.14618996921325886, 0.08426226360062439, 0.15701508269675318, 0.10407466095902267, 0.07348833245135124, 0.6086851704505183, 0.5480374215591339, 1.6329937548406663, 4.300120895908726, 3.134724411272234, 1.441696206888845, 3.1738316676309033, 9.2792119133857, 7.9175204134756525, 8.84761881443762, 9.882201802346016, 25.467525912869363, 29.467335439497425, 43.73516090454594, 47.45328149487896, 35.62196570058023, 7.244937381436748, 7.89982169866562, 8.425087371180135, 7.001317499145386, 9.245757037593473, 10.413217179236874, 10.806743675662625, 10.062911279739874, 13.791474200064137, 9.52670072355578, 4.454206795461716, 1.8897959878367765, 1.4220473386587635, 1.3984659266087318, 0.846880721228738, 0.9325487178660209, 5.434970942235762, 17.309117547927364, 4.460386979964472, 7.294246967761748, 8.286224680562174, 8.48273346501012, 5.524757917850248, 4.544879246142603, 9.291524233356599, 23.595147209782755, 55.26016704497799, 84.22447419935658, 108.50081551459529, 100.9508099094514, 73.02059250493204, 34.015951233525435, 6.976750223867356, 1.2612219491312582, 0.22165925181921453, 0.47497126484109514, 0.0786603146022366, 0.08151257485752145, 0.14139640385345106, 0.054532708675270124, 0.27537563635456946, 0.7066733317990458, 0.48052766991238444, 5.624633719844203, 52.62224758824995, 70.88299489790394, 77.27549337571668, 63.97678359862297, 96.78457813878214, 125.9117538698258, 33.788912680841264, 25.456227525588005, 40.10022594082741, 63.06347539347988, 59.18547115018291, 79.03140514127671, 75.64440711852043, 21.00311360051555, 0.22632363943323014, 0.09833504596064169, 0.1980407917571645, 0.022391284883563078, 0.07330340648730917, 0.04621732221435636, 0.02849018171189293, 0.02811646487023081, 0.028719787838898843, 0.12849071814167884, 0.03260683944268573, 0.039330230079471104, 0.037869304238307866, 0.05384823975844249, 0.02724367813507636, 0.045779912822669556, 0.038747290795248364, 0.0023088494321376446, 0.03369273077095709, 0.012897736591947897, 0.03228355416907899, 0.0319911326627217, 0.015614314057353525, 0.0439609328074561, 0.01945779249522715, 0.017077654990698063, 0.07459964257695022, 0.01735565680710058, 0.03240972501976836, 0.037988917376365394, 0.03697976507546921, 0.01569041244370202, 0.03133227406520277, 0.008012492053826611, 0.09786279872059823, 0.02889364000199543, 0.06346283856058313, 0.008939026081333718, 0.03663404874743954, 0.01597381326475091, 0.06451564255140482, 0.06411269179455216, 0.033728185320092786, 0.04187201788168281, 0.060820662596773725, 0.06916844691600531, 0.013428921848835965, 0.023543519426077127, 0.013533269727392303, 0.09863931310152817, 0.030493430770753376, 0.019010153914531393, 0.09547193790034902, 0.058709354920973705, 0.024383975335607128, 0.04291417325035699, 0.03195339134113202, 0.03912192694241962, 0.11633088797210686, 0.04479366272026974, 0.05723132999734052, 0.028983754924528544, 0.05258945387697989, 0.040277516950042024, 0.034665643282595186, 0.0654452059778475, 0.10791206431965675, 0.04762946357650142, 0.04602395779182834, 0.025611077735741294, 0.07328216286916887, 0.019079021388484586, 0.04199409016197728, 0.042840831822926, 0.030352194801033027, 0.05891712562691781, 0.014189486279182378, 0.05126381533280496, 0.023780876447656946, 3.8394407255034295, 57.162669550987985, 115.98648640417285, 125.00365457227154, 102.96384088454708, 115.17504999714514, 96.37843239691951, 82.05188905039142, 45.02318097699074, 20.564174882827267, 44.856268436678, 62.234129444245376, 75.7534803882722, 48.25714772747409, 14.673137703249532, 0.5131115650217379, 0.46096466481685644, 0.1664779233115335, 0.08453266965525766, 0.041140231544211994, 0.5427142136519956, 0.14069316578247856, 0.1575347661010681, 0.6227263363619006, 0.20075770725886669, 0.6614401299626597, 3.703596789029337, 3.2598296336589323, 4.764158860329659, 6.436033354651544, 9.137328997735056, 13.71796408007222, 14.824399005982185, 19.147824664269727, 34.560815518902196, 45.3257369226025, 59.11482141863916, 63.11656467376217, 46.061036202215384, 13.745405962390285, 2.8816719641608577, 0.9581951352377093, 5.824493189011851, 8.110657920760493, 10.018383552951198, 12.027648072088919, 10.11277441055544, 5.415963136380719, 1.532632314389752, 1.676899785957029, 0.9586675356953376, 1.7373187503507062, 2.3670717064411413, 0.41580240272225877, 1.9057776851038781, 1.5613668628277317, 3.4364659747769757, 2.323361303537123, 0.42502643840928234, 4.397279475965808, 4.122544901986276, 5.133319102948712, 7.771908304383678, 15.51225329599073, 39.864648388278106, 74.48608413819345, 101.40331022201046, 126.21510213421239, 117.44839299109675, 91.0375213623047, 51.92588175496748, 15.292744713444865, 3.227672817245607, 0.19328035203920257, 0.023868652886801192, 0.06824373282612332, 0.14379283413290977, 0.09879675949172628, 0.1093110864260985, 0.20970444976081773, 0.6667504675926701, 0.668424339063706, 4.425144483966212, 45.27839783699282, 67.91081105509113, 76.20291340735652, 38.68715286254883, 51.075143198813166, 75.23888895588537, 28.74541928691249, 45.44795797717187, 68.2907553642027, 95.2775486053959, 78.75840033254316, 87.057751224887, 94.35310871370378, 39.386840943367254, 0.8068522594628796, 0.27201940515829676, 0.03702804010601775, 0.09537344197592429, 0.06315986610828869, 0.03063223249609432, 0.028871252997628147, 0.04269584202237668, 0.0588555206664868, 0.08293798869295467, 0.018714315656031814, 0.02864554625815682, 0.029122355551789367, 0.03179541826548596, 0.06201496302721001, 0.05194376433087934, 0.00722387922935248, 0.016610375830843564, 0.02064258768974293, 0.027635275468891187, 0.05247733690926144, 0.01314604196757559, 0.020733595104707826, 0.03662369889958251, 0.04221557767220563, 0.10871834121644498, 0.07677088897194594, 0.00668875101367913, 0.01852304839919652, 0.02447015831186887, 0.09574675662142616, 0.03741722809331071, 0.05536948736276358, 0.05965315609148914, 0.054784410693232095, 0.02508764816147666, 0.06427857664323623, 0.05066177364619029, 0.03632746802102174, 0.015089183767896988, 0.11131519541865396, 0.03192898952552388, 0.14356499958422878, 0.2163768151114064, 0.1939471702902548, 0.1564157414700716, 0.1619938727948935, 0.04895980207009181, 0.22372200484237365, 0.27597398166694953, 0.1833595747068044, 0.10202085584281914, 0.14218438657060747, 0.18624498358657285, 0.127830158828968, 0.1915643304105728, 0.14778683352614605, 0.07498283975667532, 0.22726099397386276, 0.08349875739264874, 0.1783938540686523, 0.1055650620330726, 0.11559645480085766, 0.12096188947438233, 0.1318036194049543, 0.16045380624071245, 0.29314872298029165, 0.14325047452603618, 0.2698449105505021, 0.11932083721002264, 0.21716559456000406, 0.13842916146161097, 0.1503574262343107, 0.12284352399048307, 0.12749299587261292, 0.14562885577399887, 0.11806317364736912, 0.1792350952183047, 0.1489384628591999, 5.0558429764163115, 66.05333343628915, 132.1693306584512, 140.48339043894123, 107.76123692912441, 111.25265629060807, 89.21951063217656, 61.998300860005045, 46.409307372185495, 46.96342845116892, 87.28983002324259, 99.140487024861, 103.22977758223011, 67.43756924906086, 20.90244597004306, 1.8002617599502688, 0.6092879897163761, 0.29167847767952954, 0.42024715292838316, 0.27196329687872245, 0.30145060331110035, 0.22431615199292862, 0.251419055726259, 1.5416521723231964, 1.5329385044113284, 9.093022884861115, 16.20165986399497, 10.511659845229119, 8.955209428264249, 11.730731514192398, 21.63359538201363, 17.70302745603746, 17.13092427099905, 19.951118230819702, 33.0853336088119, 37.10540217737998, 51.76219732530656, 56.30185050349082, 44.683739062278505, 12.758391518746654, 19.304168378153157, 27.22574010972054, 14.313291618900916, 20.13639726946431, 32.25487762881864, 27.66411400610401, 30.438969289102864, 31.06192796461044, 25.747304654890492, 11.957549433554373, 7.724208360718143, 4.787892141649801, 5.247381627559662, 5.937522169082396, 8.526527708576571, 21.02430420537149, 42.873380876356556, 22.527007364457656, 24.682332123479537, 27.958738919227358, 22.139790981046616, 15.648770409245646, 8.94547704727419, 12.721791882668773, 29.719788989713116, 62.10607974759994, 91.23177282271847, 121.06964280528408, 111.52197407137965, 78.81602779511483, 38.3054474092299, 8.589982832631758, 3.118868474998782, 0.4771473835552893, 0.34204842162228405, 0.12637276848357532, 0.2765241247271338, 0.1924586767751363, 0.28716410540284654, 0.636174182497686, 1.288120828328594, 0.9284434058973867, 11.248959533629879, 71.90439578025573, 89.36315567262712, 105.23164549181539, 91.39674771216609, 119.64811309691399, 144.5726025489069, 43.11747781692013, 34.43442106246948, 51.43755843562465, 82.58184048437303, 77.199336636451, 98.25509825060445, 107.82426157305318, 37.91113938054731, 0.463501212577666, 0.26338446044152786, 0.23656522374480005, 0.20264562369594652, 0.18186931918946006, 0.11187515206514828, 0.21731395514742022, 0.16444103341669808, 0.11780807402946296, 0.2233795175749448, 0.14964680307574812, 0.18279866045040472, 0.13206764394717832, 0.15864740155877607, 0.15350589438551857, 0.098931223244196, 0.1117773456198554, 0.09333403165181799, 0.08130501865619615, 0.08123626992587121, 0.13804440146252034, 0.14009984600688183, 0.15301305470207047, 0.18435576480002175, 0.1195759368279288, 0.16649146774603477, 0.19835142508870174, 0.13006296038867968, 0.15343512318307354, 0.05955295179099326, 0.16378199861895654, 0.10926475342843803, 0.09626683073058244, 0.15489108860492706, 0.1412284620586903, 0.1408939267839155, 0.1575347661010681, 0.14050971836813037, 0.2058299907272862, 0.0647689035582927, 0.2595668910972534, 0.1298613720122845], [0.0178931862296116, 0.06326248358574606, 0.09680088594435685, 0.026123456491698182, 0.07314726244658232, 0.03372579512576904, 0.04125905944214713, 0.05981596892759685, 0.028310585804584048, 0.044908430352206194, 0.03952873495197104, 0.016420129386167374, 0.0843125572728534, 0.0937414448708296, 0.031031877583553715, 0.01301504476296325, 0.08296721494726597, 0.0429208152326605, 0.044834633102460254, 0.06765150089537905, 0.03560879327837498, 0.045353784075667786, 0.0317803742138729, 0.0012652066558779729, 0.0673628619481479, 0.007075720697626352, 0.0912123664672817, 0.015681101602592295, 0.04373528543979891, 0.02173578175115249, 0.024042162225551666, 0.0762350028080325, 0.0351265370996008, 0.019836082881797227, 0.026815021297924464, 0.0797036191027972, 16.36748786895506, 75.3729320341541, 103.22665537557295, 98.1025258956417, 77.87973450076196, 78.06483114919355, 51.526443266099506, 38.40450294556157, 30.794816517060806, 56.03836136479532, 99.02908386722689, 93.16784689503332, 70.81715399219145, 15.177522147855452, 0.6004269264878765, 0.5802122563604386, 0.07278127160163657, 0.07966736782222025, 0.06113657810454888, 0.1386592023435139, 0.04399703853132744, 0.2263735117571008, 0.5711344208928847, 1.7332392402233618, 13.933831722505632, 29.93503885884439, 51.93305577001264, 58.596499812218454, 58.435098201997825, 65.85043707201558, 71.84876872647193, 72.92503572279408, 90.04319267888224, 81.58707249549128, 85.0393230684342, 111.8357950641263, 103.5391035387593, 112.27182142196163, 101.85816395667293, 95.88974429715066, 61.443006992340095, 15.079188327635489, 1.3475188733108583, 8.623216094509248, 6.584046444585247, 7.731204888513012, 6.7863995605899445, 11.201857751415623, 6.599406446180036, 0.9977252108435478, 2.2416833379576286, 11.146468001027262, 23.46503826879686, 27.301990985870365, 15.628552552192444, 8.643219201795517, 0.9199883692687558, 4.2611261625443735, 11.387425084267894, 2.4507525322898744, 6.20679239111562, 13.183075362636199, 32.92917620751166, 60.05025963629446, 93.23595493070542, 111.54659871132144, 121.5491682483304, 120.84460073901762, 113.3039225301435, 116.41094961474019, 122.99127471062445, 125.88956894413118, 103.66863589132987, 56.28956564011113, 33.26621370930826, 26.91139351937079, 11.775982918277865, 1.92056673669046, 0.10057435926770973, 0.0811365635825261, 0.17583806217918474, 0.25239534285520354, 0.12928512067564074, 0.49831463805129456, 0.391277538071717, 7.447607228832861, 44.75994286998626, 87.62999365406652, 104.1857062616656, 50.59284856242519, 60.73609782803444, 47.25788470237486, 30.423281769598688, 31.70461616208477, 48.353998891768924, 67.8219223022461, 75.25138562725436, 79.99295065479895, 41.295450579735544, 1.752711479221621, 0.609860839622636, 0.04904594865717715, 0.030355707314165852, 0.08033672948518107, 0.07585185159358286, 0.04833350987023404, 0.02721177631868951, 0.014855075916726024, 0.07186625618487597, 0.03418783424422145, 0.026993550427798784, 0.023129119485196088, 0.03249086522226853, 0.028034617951620492, 0.052392638228352995, 0.044643597587222056, 0.052511554226399436, 0.0270043446066519, 0.09067641901633433, 0.07519535254687071, 0.029946792562822663, 0.021239718752762964, 0.06776374043716539, 0.034285648350393584, 0.009385141104670062, 0.0493032660996241, 0.057731436024750435, 0.09736501010915927, 0.023815804311344703, 0.07812798308629183, 0.03732032563176848, 0.035922579061720646, 0.06615357683791269, 0.030833985581393206, 0.01009830384470162, 0.07300254843768574, 0.050595399788430626, 0.014166871363657617, 0.02254137682968811, 0.007835152275454735, 0.049216866703523744, 0.017368835434618018, 0.05995677205763998, 0.04138652881186816, 0.021797336915868427, 0.061380684360741615, 0.061786025311918034, 0.055606200870487, 0.023880144205665397, 0.031709018869385604, 0.05244640993975824, 0.01993789405171429, 0.02635348588228226, 0.06532482292142607, 0.053801336025278416, 0.0178569981512884, 0.048062314745038755, 0.11223057855761821, 0.008520680787642638, 0.017258175949175513, 0.02207390423263273, 0.09210267554848425, 0.032530621355099064, 0.04047497611252531, 0.06320351779821419, 0.05888312281439862, 0.005195806527720584, 0.015439577062704391, 0.03421006228534445, 0.009374119972269382, 0.054269450220970385, 0.05591617536640937, 0.01044478243021595, 0.10234340184157896, 0.013111387022710858, 0.021348455357515526, 28.661986550977154, 96.9724282910747, 119.71986893684634, 111.56205284980037, 102.13376537446054, 110.08072268578314, 92.99966350678476, 61.7166825263731, 19.10093272885969, 27.34994196122693, 61.67966319668678, 81.919218801683, 76.78934697181948, 18.386824054102746, 0.4585052467882634, 0.9610811416660586, 0.0848266558962003, 0.15200987788698367, 0.147876312595702, 0.3363398714892326, 0.26322263202840285, 0.12168575829315571, 0.20770892861389345, 3.9156889050237598, 22.809812215066728, 44.16205598462013, 71.17397200676703, 76.34451881531747, 78.84045631654801, 83.95170473283338, 91.36112474626111, 97.60233740652762, 106.82612034582324, 97.37644810830393, 106.78909317139657, 123.17707738568707, 113.08113190435596, 118.17336467004593, 109.35374275330575, 105.09179730569164, 76.393721026759, 21.33815069352427, 2.064303952840067, 0.999046252860177, 6.255270434964088, 10.501104747095416, 7.171970019417425, 2.4465874654631463, 0.7465981571905075, 0.536326511252311, 4.937058898710436, 19.207591779770393, 34.087103028451246, 40.47306291518673, 25.350125451241773, 14.584244047441791, 2.6011430688442725, 1.0860102864042407, 0.928160933957946, 2.1380207327104386, 16.6428166820157, 25.821880678976736, 46.21653464532668, 77.54301471094932, 107.81871534162953, 118.57263841936667, 120.86907632889287, 125.78563397930516, 115.14957028050577, 118.43158998797018, 126.16677853368945, 130.61478553279755, 118.10182848284323, 77.4174988654352, 51.60412972973239, 41.7176035142714, 22.407906555360366, 5.6469667150128275, 0.1643759619084097, 0.20818828514987425, 0.3064260073006153, 0.0691285184133918, 0.26315711618911836, 0.5647847777412784, 0.47249076407282586, 6.472812439164808, 44.70415499902541, 83.03946341237715, 94.84214198204779, 54.053171373182735, 30.945223723688436, 27.28875690890897, 35.541521810716205, 54.02351825468002, 73.17420036562028, 89.6927132145051, 87.15210776175223, 93.61757016951039, 64.45898409812682, 7.458352071623649, 0.34548674680052266, 0.031284311215483376, 0.04765850596971089, 0.13871828304423442, 0.002464607077267682, 0.043288644688624534, 0.03972180826108783, 0.03916091315688626, 0.0645433059863506, 0.06737237676016747, 0.01756719666563215, 0.05427126584935093, 0.08582535109693006, 0.053705885300352696, 0.02965200959043878, 0.06978995106633633, 0.04141897263546144, 0.04857380100856385, 0.060270642110657316, 0.056356281387589635, 0.06142204927821314, 0.05544363701295468, 0.06452914868150988, 0.06923924876196731, 0.055108569307072516, 0.033063217171377716, 0.03864216437983898, 0.04767554376514689, 0.04597675911481342, 0.040694061937111045, 0.010333019778162483, 0.09674584252699729, 0.04082428539291986, 0.003355942716288771, 0.03419803087449363, 0.055928674090894005, 0.058483002752426176, 0.04688366549089552, 0.03182315256356472, 0.05246996714342987, 0.07969431879539644, 0.11372030547429478, 0.21173948572287637, 0.1530552967902153, 0.13377790459461752, 0.1337840945850457, 0.17673050864569603, 0.1469889835965249, 0.12194589110872439, 0.10030026833016066, 0.2079695364039752, 0.12085750999469912, 0.24071121498221354, 0.24190029069300623, 0.12119946100058095, 0.1254741090439981, 0.23688336473799523, 0.1765372093406416, 0.1821235531280118, 0.17680052908197527, 0.20546142582691487, 0.3415892285204703, 0.10948431422753681, 0.16282032844760727, 0.138665484264493, 0.12912902260018935, 0.14760743105603805, 0.1078559483792032, 0.1630844449203822, 0.13631071384635665, 0.11613659275275086, 0.18942080107667755, 0.14922425962023197, 0.24616274261666884, 0.1468138252535174, 0.21630181510361934, 33.48635673522949, 114.97654668746458, 133.0742685256466, 117.00722048359533, 100.47472046267603, 101.65329856257286, 67.04499490799444, 55.295170276395744, 41.73633283184421, 87.6238904460784, 141.69568523283928, 116.97110329904865, 97.31549447582614, 24.75819076261213, 1.5839935454630083, 1.4919764572574248, 0.3975349748807569, 0.3710580875556315, 0.5442588307684468, 0.31391197334854837, 0.2211179647354349, 0.9427546637673533, 1.1275524766214433, 3.2395169042771865, 17.33337152388788, 34.43089877405475, 61.679227813597656, 65.86346718572801, 67.87669427933233, 75.5946243962934, 83.24834531353366, 89.84622693830921, 101.92183186930995, 95.28461671644642, 106.9208691197057, 127.27626016063076, 120.66102597021289, 127.67886007985763, 115.6101663651005, 109.07020245828937, 75.67173034914079, 18.03729772567749, 5.421660869352279, 27.168342105803955, 26.659885260366625, 30.64942013832831, 27.013855634197114, 29.622614229879073, 20.49261712258862, 3.2810915766223787, 4.624642114485464, 17.022533493657267, 36.447051955807595, 42.78198180660125, 25.981989868225593, 11.89714591349325, 2.8148041329076214, 16.31300908903922, 30.931840596660493, 13.37008220534171, 22.062818388785086, 23.340591269154704, 39.248922563368275, 70.82404951895438, 105.62009349946054, 123.29537607008412, 125.35760141188099, 139.5349613312752, 124.07511188137917, 130.51217632908975, 137.91034698486328, 142.61537121188258, 120.32004648639311, 67.9279596574845, 40.37187360948132, 30.10167879443015, 15.040236250046762, 3.1968371041359442, 0.14280131717603053, 0.3561436426976035, 0.4580108442854497, 0.5034890716835376, 0.35022975035732795, 1.076527466216395, 0.44263723696912494, 14.06738450450282, 62.21445483546104, 110.74310902626284, 131.98733268245576, 68.60154044243598, 82.38257623487904, 59.631734894168, 37.70869016647339, 39.32859766867853, 64.01012766745784, 88.35052520998063, 91.04147511143839, 109.49488532158637, 66.39927864074707, 5.617973044995339, 0.5935533404830964, 0.11593205493784721, 0.15867200830290396, 0.25275214064505797, 0.12751023285090923, 0.2030927279303151, 0.15444364729187182, 0.14950673155967267, 0.19482026537579877, 0.18344310893406793, 0.05826311636595957, 0.21766955784011274, 0.11201337730932621, 0.1903456530623859, 0.13239445705567637, 0.074322517931221, 0.1460449028039171, 0.11567935317514405, 0.33335148507068235, 0.12343847553335852, 0.1128105377598155, 0.20180225282186465, 0.2046577383073107, 0.18255381874980467, 0.16473789248735676, 0.21039605861709965, 0.22829109111860876, 0.15061892268638458, 0.08259763881083458, 0.13099270001534494, 0.10127923676684018, 0.1486341880574342, 0.2631760232390896, 0.20002324344410052, 0.1928427472950951, 0.17261425694150312, 0.21922419538661359, 0.1806269697244129, 0.12434837348278492, 0.16832309204243845], [0.014250657442326268, 0.04580645393880625, 0.05057406423973942, 0.04280503253422437, 0.06995679735536538, 0.045433821111556985, 0.06101402701930173, 0.02348862731108262, 0.06153855592973771, 0.045747220020500884, 0.047896709518447045, 0.06458515736965403, 0.03616558981218165, 0.023747907853835536, 0.06541967226733124, 0.11582032867497015, 0.07289363371749079, 0.006856077544075708, 0.0980036976116319, 0.05436579343832789, 0.054778764625230146, 0.05646405846721703, 0.042548132609696164, 0.05476076538944918, 0.139198895964411, 0.16740040042467658, 0.020820258801142057, 0.07379128958188719, 0.092446327269558, 0.03112331400775621, 0.06667007331646259, 0.004208552850139958, 0.01690432185217017, 0.04791498454588075, 0.29978963276070936, 38.032987809950306, 101.32382731283866, 100.38550223073652, 83.46420118885656, 75.31276287571077, 66.54440633712277, 31.210468123036048, 22.356409757368027, 38.40088259789252, 82.70168458261799, 82.18612040242841, 82.21424379656392, 45.19885609226842, 2.927962306045717, 0.3148473667040948, 0.14382212933513427, 0.1397427724253747, 0.04993048526587025, 0.19635552089781533, 0.11190203409041129, 0.0647044908856192, 0.27028804644942284, 3.38700145483017, 6.666226963843069, 50.02129254802581, 86.46723839544481, 106.00692549059468, 112.74613011267878, 116.56257275612124, 117.89033428315194, 119.6599429653537, 115.75405459250175, 117.90084623521375, 112.70371360163536, 112.80387524635562, 106.45083581247638, 102.73846933918615, 100.27380881770965, 97.43609166914418, 99.33645648341026, 100.44264331940683, 97.06456476642241, 62.438763418505275, 16.697382734667872, 2.9841274599875174, 4.8241181719687685, 1.1824400410536797, 7.110479512522298, 4.346898101991223, 1.2252780843165614, 5.381740456627262, 37.39157046041181, 56.9620442390442, 58.516589364697865, 66.97152891466695, 64.45850164659562, 50.75866676145985, 44.088244822717485, 8.156857557835119, 4.230425771205656, 16.101774746371856, 41.08802780028313, 71.0540416163783, 93.82631871008104, 110.78822412798482, 116.32868966748639, 101.75411916548207, 100.03834893626552, 112.5099563598633, 104.37356425869851, 99.69911098480226, 102.39641512593916, 104.40074628399265, 108.08344394929948, 113.53320075619607, 124.34203701634561, 125.0591717996905, 120.3703469614829, 89.3973038273473, 33.93777055125083, 1.6706149232002998, 0.04497393086973218, 0.02001185601036395, 0.06773613828925357, 0.20176817723099263, 0.20225439791477498, 0.4389176962356414, 0.19276653686838766, 16.065127061259364, 53.2211660569714, 62.563663451902336, 74.1188326189595, 88.66364017609628, 64.6256063830468, 30.310705823283044, 30.12870784728758, 47.44514649914157, 54.27935092679916, 64.6143138793207, 79.33665967756703, 66.74471393708261, 12.152158810246377, 0.3796369546363431, 0.203777962935067, 0.06045176827859494, 0.09193766787047349, 0.029262361950391245, 0.06359757427426596, 0.09147708814951683, 0.12372204297853094, 0.11159879350734335, 0.0927502420099993, 0.07591637151856577, 0.04878844352318876, 0.07925495970994234, 0.05572006834911243, 0.08959651849563084, 0.17175959393141732, 0.1411935284493431, 0.18528669952384888, 0.11495939906566374, 0.11909136323318367, 0.039232749221546036, 0.03620308981607518, 0.07107549256855442, 0.05376357555149063, 0.06278285125811255, 0.06173681565410188, 0.016889113091653394, 0.06093425428374641, 0.05470579475044243, 0.032746734758538586, 0.1128149580871386, 0.043972899100833365, 0.02538151374357122, 0.017144072898513368, 0.049447382559939745, 0.09812191263922761, 0.05660870735864005, 0.054006812297889305, 0.021171973597618843, 0.04919380745700291, 0.018091294651610718, 0.0671601397616248, 0.08222331292927265, 0.08860422778994807, 0.08405472272105756, 0.026474500961241224, 0.05951361700652107, 0.05227217473269952, 0.04710813308314932, 0.10847727632931164, 0.09116985624836338, 0.07824854234293585, 0.024367745762931246, 0.0246164562075489, 0.009218106166489664, 0.23525913576445273, 0.0738730081807702, 0.033074034332868554, 0.05806689060503437, 0.03865998741539736, 0.035375243713778835, 0.03690840781576211, 0.059439015364454645, 0.0873956321588447, 0.058965588349007794, 0.031363034410582434, 0.02798325941717673, 0.10275266133248807, 0.03604420318057941, 0.07343838351868814, 0.023320084137301293, 0.05130210057682088, 0.07207482362226134, 1.5295481056936326, 59.84118946136967, 119.94195353600287, 115.34815988233014, 108.51698352444558, 102.40684863059752, 100.18979949335899, 57.98763421274001, 23.973206820026522, 22.05466574238193, 48.31789347433275, 73.73379707336426, 92.27883385073756, 51.868838725551484, 3.3744567344265604, 0.5851523590184028, 0.07592807734204877, 0.30658167636682915, 0.07573744402297082, 0.3783067502081395, 0.5835032475090797, 0.29903157343787534, 0.5149529033130216, 0.6530808236810469, 11.733106509331735, 66.49125037654754, 102.42377758026124, 116.07194700548726, 116.02642397726737, 118.11221491905951, 121.71892842938824, 121.04638315016224, 118.63796157221641, 116.34339071089222, 114.50386970273911, 113.64410969518848, 112.37003757107644, 108.31331837561824, 105.92371632975917, 102.86265157884168, 105.97141235105454, 108.2267673553959, 105.11606108757758, 73.34890273309523, 23.88710295000384, 3.3861755507607616, 1.2871654860434996, 2.5456481499056665, 2.2930239765874805, 1.0898863235788963, 0.2905370066723516, 9.331481418301983, 47.52724562921832, 69.6665737705846, 73.16829327614077, 83.56939915687808, 86.82732766674411, 67.94947778024982, 59.48903514492897, 14.197908236134438, 8.346536024924248, 27.75478155382218, 60.67469312298683, 89.00891073288457, 104.74019604344522, 114.41400820209135, 115.02651768345987, 111.00478602993874, 109.84788294761412, 119.30458407248221, 114.14426680534118, 103.7812706731981, 104.21776771545412, 108.78660725009058, 112.22202301025392, 116.63392066955568, 127.57866705617599, 133.24622523400092, 132.89575361436414, 106.6426867823447, 49.78864108362506, 4.07222040237919, 0.02714012794557118, 0.1844382111824328, 0.3749692728442531, 0.2301640075541312, 0.07245640435646619, 0.8347460110822033, 0.3285476847762062, 15.976138287974944, 56.71486431552518, 66.43803165804955, 66.02343713083576, 43.19789425019295, 21.872893302671372, 27.556780307523667, 43.58556955091415, 82.4020782593758, 86.62876944388114, 83.72899255444928, 89.71108559639224, 92.71176153613676, 29.417964566138487, 0.5305434054424686, 0.26041825992926476, 0.10107931080124072, 0.05105794452491307, 0.004020293924822322, 0.06691374290253847, 0.07617173160636619, 0.11667534408550109, 0.09300547186285259, 0.07896078960789789, 0.0665302622702814, 0.029892626316136414, 0.0531989457686582, 0.020842352776878306, 0.11452799197286369, 0.25057312611851, 0.1884321492886351, 0.21537339314818385, 0.10682491660718957, 0.05757816098330002, 0.09504639138016971, 0.06821125835901307, 0.04009339154788083, 0.07098914679860877, 0.06059838984642298, 0.05249139845311161, 0.04854477010667325, 0.002713423816584832, 0.04287581905842789, 0.03312452335751826, 0.08082008500012659, 0.018824846821747, 0.04103230507743936, 0.019977152227394043, 0.0871249349908002, 0.07669876945475418, 0.02284771049275033, 0.09271007602012928, 0.02766502840865043, 0.19859582245830568, 0.16618547690731866, 0.1495156488231113, 0.19882086844694233, 0.2118380659169728, 0.17645220422456342, 0.11911046180513599, 0.11701318886010878, 0.14508735418560045, 0.15354807518662947, 0.17272327125312822, 0.18837971823109737, 0.12664983950314984, 0.11657980526046408, 0.23588677627905724, 0.23389945227292278, 0.6339296674536121, 0.1158234696354597, 0.2118091997239859, 0.15891041486494004, 0.10768647440859389, 0.1778418877192082, 0.11479079077440886, 0.17361449197896067, 0.2141449711616001, 0.24949444367760615, 0.16246964403938863, 0.08989380657552712, 0.2544351132406343, 0.18138181147796495, 0.19776991838889738, 0.14640920825542944, 0.16740032381588416, 0.1967743718095364, 2.09947265924946, 72.29470299136254, 137.93389689537787, 120.6195116043091, 103.47541209190123, 99.26755612896335, 86.04763892389114, 40.79156721791914, 33.29822024991436, 56.79096614160846, 124.73954569908881, 109.11657271846649, 104.45271768877583, 63.211007502771196, 5.250469513477818, 0.7533251446100974, 0.2690812434640623, 0.566900835162209, 0.47537860911219354, 0.622870606039801, 0.4433580950623559, 0.200200010571749, 1.030670423661509, 9.09380441711795, 9.063086375113457, 62.96196053105017, 106.3014562668339, 126.68407640149518, 125.87754295718287, 130.6210534803329, 133.07196217198526, 132.6057335638231, 129.11989181272446, 126.8966845543154, 125.15759191205426, 125.28784598073653, 119.78225031206686, 114.13638284129482, 113.0633714122157, 110.40655397599744, 111.07663600675522, 112.95137989905574, 109.11990673311296, 75.78382384392523, 23.93478132063343, 7.156943909583553, 13.509060605879753, 18.723730156498572, 19.310932505515314, 11.36677380531065, 2.9823388591889413, 9.67157248527773, 55.154117922629084, 83.3165474860899, 81.90661230394917, 95.61987738455497, 99.56088665992984, 92.5779067316363, 68.12341920791134, 12.20677879548842, 6.564141396553286, 21.83719777291821, 61.44896507263184, 93.1607081813197, 111.93774530964514, 121.66692564564367, 122.25674029319518, 112.82088264342278, 112.38009452819826, 121.97622022321148, 117.78574036013697, 107.85518553949173, 108.1907521524737, 112.47288211699455, 120.54136230099587, 129.65425199077976, 138.95338366108558, 143.56711079997402, 135.67094033764255, 99.49464567245977, 39.87662730678436, 2.8229300581639816, 0.1270898727459773, 0.3612938679514393, 0.3600589035739822, 0.7977968550497486, 0.26644014002334687, 1.2045196756239862, 0.952637565712775, 26.874707591149118, 71.55834859417331, 78.94930993357013, 98.70293094265847, 127.31100451561713, 83.00441311251733, 41.24814287308724, 38.95973797767393, 64.10890471550726, 71.17705498972248, 80.51580259876867, 103.69111891715758, 104.69497896009877, 28.101428862540956, 0.46625404228125855, 0.31309333179266224, 0.2185303035883173, 0.2591938982086797, 0.0937994530484561, 0.13287954392933077, 0.16600938393704354, 0.2147746341483247, 0.2611101905424749, 0.1851901264801141, 0.2602783416307742, 0.12589909631999271, 0.15572630830349463, 0.1390827570350901, 0.18008655598086698, 0.33092482496173153, 0.21868911361502064, 0.21591434315327676, 0.16151869909897928, 0.21590855152856922, 0.1219360851832936, 0.07963157619439787, 0.22711569773814372, 0.20284589440111192, 0.18439187818477232, 0.2008506337240819, 0.06663957535619698, 0.1031632308337477, 0.11640872250521377, 0.1111526239002424, 0.20545336658195143, 0.1032162594398664, 0.12236871801677252, 0.24865586851393026, 0.16921241287021868, 0.15953964884242705, 0.1377377058229139, 0.17158169299364093, 0.11093673266230092], [0.05730155727735931, 0.059765908912184744, 0.029759093360494704, 0.048218374516093926, 0.06482752460625864, 0.11972368454500554, 0.039108133529342955, 0.0549431594329015, 0.08870707509378273, 0.03843990950694969, 0.08249721234484066, 0.0674350044479774, 0.06136885596319072, 0.05666617544427995, 0.1147709874015662, 0.06540634233744876, 0.016929926425819437, 0.06001453508713073, 0.03467063434542187, 0.05542048966632255, 0.007763255402565964, 0.03210712986577663, 0.1191814092078036, 0.06396318207524958, 0.04861918022675861, 0.1512764559517945, 0.01568061705198019, 0.029529190374418136, 0.019012772020012624, 0.22294134592577336, 0.04954153093539419, 0.0929796317171666, 0.07664958661001536, 0.6617401299938079, 49.81062596844089, 110.43668562366118, 90.53442247452276, 74.36864053049396, 79.05510410185784, 63.769937407585886, 33.309955981469926, 40.13213834454937, 82.34737688495268, 81.59744324222689, 66.88678218472388, 79.57108405328567, 17.809543340436875, 0.7796052699127506, 0.4764840433434133, 0.24962486248583565, 0.07704052893865494, 0.17208348058404463, 0.14619110302338678, 0.2657451757019566, 0.30403918376372707, 0.7846691723792785, 1.8395241950788808, 3.847871860188823, 57.08665009467833, 88.65984332176947, 90.66256630805232, 88.46225000196888, 93.58549302624118, 93.73997165310769, 99.61879653315391, 103.06659129358108, 100.89453958695935, 94.93074832424041, 105.10312511074929, 105.32948509339364, 105.21313190460206, 97.63085303768035, 90.30084533076133, 92.08434704811343, 100.30958083368118, 108.87598237683697, 108.02896222760602, 91.72830566283196, 68.07622524999803, 21.373726590987175, 2.43646260230772, 3.7555255380369004, 2.170568315252181, 0.37363916034660033, 4.029918620663305, 35.757456133442545, 61.742428964184185, 69.35218795653313, 91.37300168314289, 91.7640619893228, 98.54660880181098, 83.0323717671056, 77.59059306113951, 74.08734383121615, 60.160113457710516, 70.27712991160732, 84.29623788402927, 95.10061048692273, 101.790173592106, 106.42840769983108, 103.71669277068108, 115.8526865128548, 118.78471312984344, 115.14817391672443, 112.20652180333292, 98.98013268747638, 91.76297941515523, 99.87311517038654, 110.56208379807012, 106.85681681479178, 101.3283537280175, 98.0672480983119, 101.72685869278448, 109.57787482969223, 114.81434099135862, 55.19075678240869, 1.6126804125885812, 0.27731386944651604, 0.3485462874654801, 0.36982833257605957, 0.13817033099551357, 0.2329990997790329, 0.11632317346670937, 0.40708560917165976, 5.737344497634519, 42.47749213249453, 78.78907326729068, 78.66831133442541, 72.82166557927286, 73.65727947604272, 42.54385079106977, 17.65654540831043, 27.20457696145581, 47.86343197668753, 67.1389356736214, 80.52338061794158, 78.81926767287716, 34.65647428266464, 0.6780940847050759, 0.33432818588710606, 0.12820534272900513, 0.00403896923319647, 0.12357956594637326, 0.025030222210672595, 0.06478305320225416, 0.03258687136093936, 0.22268648379512374, 0.11086921733353408, 0.1187711154981967, 0.05218825363103421, 0.14540037771146144, 0.15874881627819232, 0.16278793825016868, 0.15507347881793976, 0.3609063806793382, 0.052957356111296726, 0.12662298046052456, 0.20789277439396228, 0.08356205157695279, 0.1472977323517684, 0.10930842044012201, 0.013943913922224556, 0.030625105963178703, 0.08622311926897495, 0.09060487406508577, 0.04353607576640864, 0.08247949273115204, 0.030593286501243714, 0.10237118018971336, 0.060726973874073845, 0.0539401434962788, 0.1988201176807765, 0.17388964011784525, 0.11038157172621259, 0.1296453352176374, 0.052196129014895815, 0.01393956924608398, 0.031952349461555, 0.07185319438576698, 0.06160843080931133, 0.09922357005698067, 0.025292582426881118, 0.02255375681054448, 0.03550247559624334, 0.020759094341267503, 0.02980865541875603, 0.10520787353837684, 0.09639349570798297, 0.10015101908075233, 0.040412674012083205, 0.137953742617561, 0.044632726799576514, 0.0663313705233797, 0.09758167509590426, 0.1189812993811023, 0.11513710848145908, 0.02936671461699711, 0.08650789713306774, 0.07503478817882077, 0.0700480767315434, 0.18948991752920613, 0.27921300141080735, 0.06464661294293982, 0.07522402721787654, 0.022269070877002615, 0.16815796945123904, 0.01018628138192599, 0.09153371736887964, 0.0675664421531462, 1.2809801534298928, 71.95326851260278, 125.89909245890956, 105.790983323128, 96.9063755773729, 107.70597073339648, 87.42814848499914, 52.38580319189256, 30.033068695376, 27.43634589256779, 52.08800508129982, 71.20218953778668, 87.16840128744803, 16.42342478998246, 0.7811248819193533, 0.5287951315122267, 0.5198472858436647, 0.10587907381235592, 0.3008274673934906, 0.342753314443173, 0.6034784691949046, 0.8401616398365268, 1.0707368221013778, 1.3868011654384675, 8.227628392557945, 70.30162119096326, 98.48364691580497, 96.92015094141807, 95.5037909169351, 99.231901784097, 98.83612678896998, 103.63857484632923, 108.54956273109683, 107.92767094027613, 104.5272191878288, 112.10654843238093, 113.34511526169317, 110.44412243750789, 105.30380925824566, 93.68890239346413, 97.62533818521808, 104.81283833903652, 115.50840439334993, 117.22054250778692, 98.85675061133601, 75.09324350664693, 30.84799797304215, 3.5350248409855753, 1.0261268481131525, 0.7625074744705231, 0.13883500420037778, 8.213879014215163, 51.42348497144638, 74.91184957565801, 85.56475593197732, 104.9210879110521, 103.8060365184661, 110.68282219671435, 100.52835495241227, 102.95742388694518, 92.34169375511908, 74.76389777275824, 82.39794408121418, 96.54337590740573, 101.13503579170474, 105.14053667745283, 110.9344893117105, 110.80534135141681, 120.4064170775875, 122.07391077472319, 122.43716147638138, 115.03732773565478, 103.4329955808578, 90.63128932829827, 100.3308871484572, 112.58056686770533, 113.00066840264105, 107.64320496589907, 102.4687828556184, 101.33098171603297, 109.84781234495102, 121.00342535203504, 71.16566442674207, 2.8066919359468647, 0.1799468368652367, 0.37380938508337547, 0.3137293686309169, 0.07163165707982357, 0.329334732866095, 0.11544184293597938, 0.7060645064038615, 3.808702336203668, 43.18268722103488, 82.22353196913197, 82.37591605032645, 49.358419833644746, 20.917533366910874, 32.10575892079261, 29.479594807471003, 48.029971891833895, 79.04150916684058, 88.80080546102216, 89.24604938876244, 96.62693023681642, 59.71935279907719, 2.703205837357429, 0.6215571023283467, 0.07301119757035086, 0.08781211585887978, 0.12699008213296054, 0.08551657169816956, 0.04057479353861944, 0.060096269007772214, 0.041351648828675674, 0.06064008035126233, 0.07289487477992812, 0.18078312908689823, 0.16853463956184928, 0.26052465422018883, 0.179874119799464, 0.2649591388481279, 0.4733771584447353, 0.25598844843766383, 0.0927241490552983, 0.26824593183494383, 0.07464376158050953, 0.18887566823151805, 0.19129892691008507, 0.14169071951220114, 0.0863013751504402, 0.14327555624467714, 0.0181560080137945, 0.05458919999880656, 0.030271378270680868, 0.03450921195889673, 0.035329998560970834, 0.05716858356590233, 0.029675921109775384, 0.2116402313714066, 0.1903553517355073, 0.07616555693769649, 0.2733476790449312, 0.016612970953687065, 0.18874233828917628, 0.1871532421078413, 0.17367349607088875, 0.1572848682201678, 0.1443529516578682, 0.23849104621237327, 0.13857340049599448, 0.13282406384185438, 0.13621872200840904, 0.18415469736341508, 0.2719685369201245, 0.18381443175096668, 0.16195729975738835, 0.22320570754668406, 0.3881158932082115, 0.13903807878734606, 0.16654697847702812, 0.19575326853702146, 0.21225896994433097, 0.17177885338183374, 0.17583921131107116, 0.1960248467061789, 0.22523230121981716, 0.12124918010686675, 0.194547446144204, 0.33002286368320066, 0.1629474377560039, 0.16794150364735436, 0.11296416137127147, 0.2766019286167237, 0.13206644885001645, 0.20182077682787375, 0.168978373009351, 1.5011067544260335, 86.49229449610557, 140.2960894184728, 112.72393734224381, 98.95520210266115, 99.90152097517445, 76.74228637449204, 43.20138908201649, 52.049216762665786, 110.34692610463789, 116.76217432945006, 84.78136447168167, 101.08380963725429, 25.855624829569173, 1.3627782415959144, 0.889385179165871, 0.5549191587394284, 0.4110761305257198, 0.5781693143710014, 0.4758602332684302, 0.7512476367335167, 1.1526134802449135, 3.602103989931845, 4.253168163761016, 5.996091000495419, 69.59521016766949, 109.07386595203032, 107.02773801742062, 102.68343848566856, 107.14246734496086, 103.60381480186217, 109.81779052365212, 111.43885904742827, 109.40113282972767, 107.45836719389885, 116.17692532077913, 118.35465661941038, 119.6144199371338, 112.34473043872465, 102.56232353948779, 104.31883935005435, 111.73961070276077, 121.11962949076008, 121.85413252922797, 101.1031469222038, 77.92638717159149, 29.104722122992243, 4.775561680716853, 11.407973401008114, 8.583350104670371, 1.6246668081129751, 7.512254263124159, 58.05810351525584, 85.17688843511766, 89.83425586454331, 111.52091503143312, 105.46170034716206, 109.22749734693959, 102.48357019116803, 116.56301990632089, 113.51594232743787, 76.57573469223516, 90.93505336392312, 106.08803226101784, 114.60083069339876, 114.92172764193629, 118.05132404450448, 116.4863375694521, 126.03520654862928, 126.5094054129816, 128.10577869415283, 123.58419587535244, 110.05649812759893, 101.94816666264688, 108.67656907727643, 121.7645691287133, 116.36056284750663, 109.95383401070873, 108.49777175534157, 110.4234907704015, 123.34150314331056, 135.79990786890832, 64.81154241869527, 1.8361342866574566, 0.4902492030974358, 0.36687233635494787, 0.5523458387582534, 0.24913390737868127, 0.5655726225626084, 0.22080658063773187, 0.8901047502313891, 10.75520275100585, 64.79497824945759, 97.02393685617756, 98.30692845006143, 110.2652858918713, 98.66842192988243, 55.20452822408369, 22.058735201435706, 33.787163303744414, 62.65320724056613, 83.62625783489597, 96.56328585840042, 111.9413068217616, 63.48601272029262, 1.8186275228377313, 0.5446906592096052, 0.2803080474897739, 0.12038506357179535, 0.20882505743253618, 0.09588489759593241, 0.2574686988467171, 0.21393017542939033, 0.23723850777793318, 0.2867938397872833, 0.18230499339199838, 0.4091191436013868, 0.23494496310670532, 0.36657840374015993, 0.24019206783944563, 0.1932497544875068, 0.45072498040333875, 0.21828843430886347, 0.198709923593748, 0.21787117686002486, 0.15019556717766872, 0.2763913770116145, 0.19020668471292143, 0.1647811917768371, 0.2621400578608436, 0.2706185980669914, 0.27046777067645905, 0.18594838498580843, 0.23654435550974262, 0.13337305777015226, 0.16317061449010528, 0.16239193208034963, 0.13165728128965826, 0.28904439160420053, 0.2908585184524137, 0.2929643409386758, 0.2935697342599592, 0.20099611382090277], [0.07214689717417763, 0.10602256208057366, 0.06322581861769, 0.019855606632547516, 0.04586773331186945, 0.04066717608140842, 0.040427375239350145, 0.02090083784423769, 0.05484806493886056, 0.029926008597436934, 0.03452732993830596, 0.12789663993903708, 0.07644818209472203, 0.00713875441203615, 0.022896519869626052, 0.05023735710569928, 0.026568187768721295, 0.027438254891744545, 0.04942429266990193, 0.027066558606982715, 0.08020505429275575, 0.06504203688593642, 0.026114972067936778, 0.04740292754685206, 0.12037655233495659, 0.07905494181379195, 0.13160394624836985, 0.03537682568534248, 0.1271962900195391, 0.07905907868858307, 0.03153816785573239, 0.04225896123135763, 0.1921127574338067, 43.09535564914827, 98.44137161008774, 88.01053416344428, 80.09739552774738, 86.24556956752654, 68.79595664239699, 36.55753727882139, 45.4236549715842, 99.42187001628261, 78.30359366632278, 85.47679285849296, 87.65520664953416, 3.9060026118832254, 0.8147970202469057, 0.058251353085882245, 0.20969934761524203, 0.10743522821294685, 0.15423274328631742, 0.21621598261258296, 0.1053799139035325, 0.6037733211152015, 1.6860767838455017, 1.2403979633123645, 8.086433852872542, 58.76407131072014, 99.0824673252721, 99.68130342421993, 97.66755073301255, 97.82752852286063, 100.36847129944833, 98.59719168755316, 104.71790913612612, 105.04144976215979, 101.70885501369354, 98.26769690359794, 96.69443422748198, 97.39049803826117, 91.38741247115597, 81.8316871889176, 86.76475801775533, 95.30546803628245, 103.06333572633805, 108.35528773646202, 103.09630717000654, 103.21360172763949, 97.06807136535646, 70.76473543720861, 29.009690938457368, 8.620595951234142, 1.048270098624691, 3.838193411788633, 39.73478655661307, 58.28772298751339, 82.98086320200275, 103.6102161099834, 109.2935500606414, 116.09161376953126, 119.14322560833348, 114.3514620873236, 107.90325810832363, 87.22164354016705, 90.88315256180303, 92.04294250857447, 103.81905094269784, 105.73652513565557, 103.53827984102311, 104.3976789905179, 110.55555697410338, 105.84216240913638, 109.76275182539418, 114.1968579446116, 106.59985450006302, 106.33940127588089, 91.75304012913858, 85.41147755038354, 97.03135798054358, 109.06413062926262, 105.49408343530472, 104.07981011175342, 92.52255424376457, 97.6872096523162, 94.92065998815721, 106.29604339599611, 38.27020099086147, 0.1527823090192772, 0.15331328455959597, 0.20533546565040467, 0.023181558203613086, 0.12556013305701558, 0.06110154107333191, 0.06759280323862069, 0.6993868550465954, 0.6497199653137116, 8.117055796807813, 33.84674018429172, 40.53426365698538, 68.80529188340711, 70.30835197817895, 62.97176645648096, 38.5736120131708, 21.67210521236543, 48.44979493848739, 67.33217516253072, 64.80213265265188, 80.06803266463741, 40.39298380574873, 3.5426460062303855, 0.19095155200169933, 0.05967050415253448, 0.03516872556159093, 0.1506602148255033, 0.023017389391879403, 0.10919920694563659, 0.0546295651715369, 0.19915515857358135, 0.12929203078871773, 0.13722405919144232, 0.12897388979552254, 0.1041943621971915, 0.12516746703054638, 0.02585946450821094, 0.02876506938088325, 0.13719283344764865, 0.027244358038109158, 0.14501719585349485, 0.09397519361828605, 0.2167461614214605, 0.03946442953160694, 0.10365872118141382, 0.10176586347722238, 0.12104723933002642, 0.175075973233869, 0.0054112749808888526, 0.057188168603686564, 0.01610554112572103, 0.014448630841328733, 0.07559039344590518, 0.06548207778964313, 0.09081970810169175, 0.1367413471903532, 0.040632246302500855, 0.034120744094252586, 0.10354790656316666, 0.055220368348302386, 0.07368669559758517, 0.16418592613791266, 0.0520785958055527, 0.030381331040013223, 0.03435700561010069, 0.02751121902087283, 0.038273921236395836, 0.04590416845354823, 0.04300386682453175, 0.0481952463216599, 0.11587831386995893, 0.04435716114277321, 0.019440676175778913, 0.07534382804747551, 0.13039368054559156, 0.06691839305623885, 0.016268020713581674, 0.15189570014274892, 0.02534874433261012, 0.04882360312847361, 0.18646665878834265, 0.0668416923332599, 0.02710145199671388, 0.16452562484529712, 0.019856483803220817, 0.15849272840686385, 0.050647926606958917, 0.1271102047194877, 0.13182552951958873, 0.03651139040988299, 0.04865399509247753, 0.2726997525220917, 65.01399555513936, 115.76356241779943, 108.21514145020517, 108.87875157017862, 108.89204840506278, 104.22994275246899, 48.99209007140129, 27.611860190668416, 48.7013679165994, 69.36768916345412, 95.21897192924254, 90.16081671560966, 4.090136073289379, 1.2427059104365688, 0.023096397954730258, 0.23128624975440965, 0.22527725525921394, 0.09816270682119554, 0.3065518295812992, 0.05783952720042679, 1.0626765965454041, 1.3742468842575628, 3.107744633190094, 15.106950863715142, 71.32912528130316, 104.87041088842578, 106.2874298710977, 102.69009867022115, 102.05633778725903, 102.43186550755655, 101.024825034603, 108.12173412692164, 106.7683752121464, 104.34760601289811, 100.99271651237243, 98.89333848030337, 102.90657428003128, 95.40568459418513, 85.05267481650077, 93.89779213936099, 101.69988847547963, 109.67832672980525, 114.70792708858367, 107.12997851833221, 104.5681687324278, 103.99590276902723, 79.41071402642035, 41.478954745877175, 12.72946305813328, 2.863828121654449, 8.442717444512153, 51.92694471728418, 71.33820949062225, 96.64505943175286, 113.09140851420742, 118.46391816293041, 120.21468377882435, 121.63640176096271, 117.35056123425885, 116.36969412526777, 100.93282191984116, 97.94991431697723, 101.85395133110785, 109.74314781927295, 112.22629054900139, 108.11655659829418, 105.25464627050586, 115.1274794916953, 114.46106095467846, 112.09220824703094, 115.89278098075621, 112.20520388695502, 112.1722795117286, 97.13614802206718, 90.60359739488172, 99.40628251721783, 109.49685435141288, 107.7166788039669, 106.33648303247269, 98.61610535652407, 105.37472571096113, 97.36465746356596, 110.86329829308295, 50.86791653786936, 0.6305829663911174, 0.4836074046550259, 0.10912180142176729, 0.008757810855674888, 0.3377561842001254, 0.05532058797055676, 0.07894351432520537, 0.5676218158295078, 0.8134176329739633, 6.1268441907821165, 34.94720820457705, 47.66382648098854, 57.55200793666225, 37.355818056291156, 27.6668361310036, 34.03240165402813, 36.156325878635535, 77.93052919449346, 98.95594735299387, 81.01669711451378, 93.00873202662315, 64.45068828521237, 10.698748077115706, 0.06583351296402755, 0.10842958735602518, 0.02132646097320943, 0.24291574023664, 0.04788851237765724, 0.055403911523641124, 0.027481841464196483, 0.19976999009809188, 0.21049296873952114, 0.3064469061791897, 0.08901489688263786, 0.14961427498248317, 0.24342178727590272, 0.09689260199065171, 0.11772659291783649, 0.17084490027158492, 0.054940815203853195, 0.10770134417520416, 0.08750954177230598, 0.17180972672518224, 0.08885095406684185, 0.13480316006368206, 0.1239380184861441, 0.09508952213030669, 0.11069084908212386, 0.010243046581895362, 0.08613638279418792, 0.04055948710189231, 0.023750328691676263, 0.10867266705439937, 0.027632209201974255, 0.08814670475980929, 0.1257416192862776, 0.20213730903642796, 0.025416246254838286, 0.09833598058790931, 0.1197405921054944, 0.1633331630258791, 0.19037681751914565, 0.08080353750096214, 0.17986040682561938, 0.14443581172775838, 0.11647969289051911, 0.0799620895075702, 0.1505713945915622, 0.12037658297847356, 0.18778739436980219, 0.22422701000205933, 0.11314193207410075, 0.10852703373999366, 0.1043468290158818, 0.10544220451265575, 0.17164645806675957, 0.19680196629656901, 0.23253566255011868, 0.12041277297201658, 0.22180693824925732, 0.33919403930344894, 0.17698792951001277, 0.08858938866685476, 0.2991720433196714, 0.243518881259426, 0.24595140960187684, 0.31343565052074773, 0.28581146992021994, 0.19379243585130862, 0.10339479623061996, 0.1567699498827419, 0.4100142407321161, 75.4922583795363, 133.4761545735021, 113.7138572815926, 111.18997681525447, 101.11935415575581, 84.6907106522591, 49.87000673047958, 63.06121218589045, 132.94459496774982, 107.36154740856541, 102.47642363271406, 111.66601919358777, 6.6981089691961975, 1.7958543641913323, 0.13815415121855276, 0.44091746150966615, 0.3469430186575459, 0.24106284933945826, 0.5781855554349962, 0.40332675280590213, 1.890896212670111, 8.567219357336722, 5.063111128345613, 11.870253162999308, 70.62516966173726, 111.96590008274202, 113.09761370382002, 110.61494950325259, 110.7624698454334, 109.8379671958185, 108.49915242964222, 117.70584952446723, 116.35769951728084, 113.39152474557201, 108.36794914737825, 106.15879966366677, 108.36539176202591, 101.89745826105919, 93.08452006309264, 97.67551314446234, 107.59649738188713, 113.99455778060423, 120.54371572309925, 113.55482086058586, 112.43818483045025, 111.37037446421962, 80.1762116339899, 38.85343390126383, 11.473591712213333, 3.009470383967123, 6.197989121560128, 56.79738313921037, 84.87820779123615, 104.62914589912661, 119.27838263973113, 122.57129084679389, 127.76236734082623, 127.19148989646666, 121.34606007606753, 118.77101621320172, 109.95699544106762, 115.13254719395792, 110.85865420679893, 116.13468139402329, 120.47050860620315, 114.75263426380774, 113.86130702111029, 120.00170692320793, 120.14941553915702, 118.73810752745598, 120.9341484500516, 116.37403226667836, 115.45186734968617, 98.74362945556642, 95.16069335322227, 106.5585284079275, 118.40201531687092, 114.78499381772934, 115.39542444290655, 104.3905951899867, 108.55670144481044, 102.05359212813839, 123.01761734870173, 48.3563954599442, 0.5925975079017302, 0.6003059458828742, 0.37606958960813863, 0.12315381258245438, 0.5462215480304534, 0.4521905066024873, 0.25381390786459374, 1.5808467014182, 1.0423413135351673, 16.233050592484012, 51.533523144260535, 55.85569266350039, 105.22203568489321, 101.2764843048588, 80.05420238740983, 51.29625505016696, 27.30436990337987, 60.326151309474824, 86.64390979274627, 80.57365755881034, 104.60135198408558, 71.72623388228878, 8.09394617234507, 0.196258993819356, 0.2230935522745694, 0.18997325772239318, 0.2994551587729685, 0.16763604907018526, 0.16055350492317833, 0.10689917350969008, 0.2328809230558334, 0.32698278165152, 0.2635538578033447, 0.24475490283821863, 0.36671608506191167, 0.20335952571082502, 0.12266638147975169, 0.2536138363422886, 0.1773956721468318, 0.18276412520677815, 0.2332026953057897, 0.23596664860604272, 0.27254374637719125, 0.18570047893351127, 0.193265535898747, 0.15325941325676057, 0.23317151552727147, 0.30690386230426453, 0.1323407542921843, 0.12453602671983743, 0.13024694406457488, 0.07113220605758891, 0.1641075246997418, 0.15920635463008959, 0.2295369799098661, 0.2900590903816685, 0.2779049522453739, 0.14582511217844102, 0.15452492922063799], [0.09863199696185128, 0.015129173557544428, 0.07165026535550434, 0.07875787589939372, 0.11414623503843624, 0.023928886549847744, 0.07833219148338803, 0.09600161875207579, 0.039285892740853375, 0.025039252472080054, 0.05207001179036114, 0.07860334830418711, 0.19795004098165422, 0.05705432538243552, 0.050783554813073534, 0.013901916024605594, 0.06365313863141403, 0.08428851743378947, 0.07078886843256413, 0.09533048742600987, 0.12058390169254235, 0.060746608707573146, 0.03352885307263463, 0.0722637255826304, 0.04909774386173776, 0.08965035149407002, 0.11072163815580069, 0.07637488280212687, 0.1256780110059246, 0.23296425810023663, 0.1881055200412389, 0.07380467313792437, 15.027121805375623, 93.46616668085899, 89.80148838412377, 76.47157222993913, 68.09620580365582, 48.883530632142104, 40.60741586069907, 53.439085099004934, 86.56214406413417, 80.54092930209252, 93.65661344220563, 71.97162520500922, 1.4304063997922407, 0.09131592623288594, 0.5960426972277704, 0.23291119885060096, 0.12384415739366125, 0.13411282291335447, 0.13841423806884598, 0.2503259708323787, 0.37513968144213, 6.821347388529009, 33.715352550629646, 78.78685320577314, 115.48174012091853, 114.88103697376867, 110.32149345644059, 111.0264688922513, 95.07349121955134, 92.41534802221483, 92.24600361239527, 91.41347269858085, 93.32288249846428, 95.46153130069857, 94.12639571774392, 94.26416504767634, 91.3828468322754, 87.67483418987644, 83.94985337411204, 90.9531198009368, 98.74126818872269, 106.67521892055389, 107.93037737569502, 108.0114527671568, 95.42526506608533, 92.68047671164237, 99.93867366544663, 105.91027828954883, 85.02676363914244, 44.75782479009321, 28.099618688706432, 41.573676063168435, 60.02724316812331, 75.06086041850429, 98.66686082655384, 95.05006682488226, 106.56921294427688, 105.67815242275115, 107.56660107643374, 113.89413725945258, 131.8479944044544, 113.66276448772801, 84.30674199135073, 103.6714364636329, 110.58203297276651, 107.26578666317849, 99.64308384926089, 93.90840607304727, 107.96337235358455, 111.85630906012751, 105.317929790866, 105.9442146362797, 113.8000709779801, 112.01585538925664, 106.16587561945762, 96.50296764989054, 93.64668200092932, 94.19790052598523, 87.3078493918142, 87.89990763510428, 95.1720525372413, 103.38331484025525, 105.92524605412638, 100.6741729859383, 89.38468164013278, 44.39528795980638, 3.2416229719115845, 0.46143632983007743, 0.10579950792054016, 0.08561320602893831, 0.08701793549041595, 0.14423076063394547, 0.1563433308394686, 0.05031441022912341, 0.18872692460013976, 1.9325440617338305, 25.535414295811808, 60.61923473112045, 80.59028840834095, 84.2600893205212, 70.64601313683295, 50.62904419437532, 21.87851994268356, 33.716835206554784, 63.26654826441119, 70.10545561390539, 72.57390514496835, 75.33606959927467, 21.171216580175585, 0.23897073982704073, 0.05135839654793663, 0.04992165993298254, 0.27061617722915066, 0.05115090163364526, 0.06397902094308408, 0.10097749771610384, 0.198531057385187, 0.14387612321203755, 0.19437754316435707, 0.09239044881636098, 0.02015377954399634, 0.05339048690192642, 0.08718153356664604, 0.07698471943337111, 0.01871167648313267, 0.045571387520120035, 0.1302628940151584, 0.07328061537156183, 0.08471448530232714, 0.03314839082679922, 0.09375547960160241, 0.10092027860903934, 0.045870345671691244, 0.07364117465312443, 0.0842918499162601, 0.08155406617950048, 0.03774825085495268, 0.007904783443307445, 0.1641438372673527, 0.05859270271274352, 0.08568381635291923, 0.12169457596516418, 0.06914043874149362, 0.04857561280650478, 0.14162961633936053, 0.03412318408429142, 0.02554302806064727, 0.09750204025617532, 0.13444668403075588, 0.027821907893784588, 0.05183698699599312, 0.03787680423908657, 0.047461529442619894, 0.027495964295080597, 0.03395527676348725, 0.03967101280126841, 0.1802613312799123, 0.04619264269187566, 0.05107717333181251, 0.04301850293432513, 0.06472035656653105, 0.06447151588696627, 0.031207401733545047, 0.1028689994446693, 0.11664301517509645, 0.03629385974378355, 0.046154437887091795, 0.10531118049496606, 0.04557858874660827, 0.11127806313696409, 0.06048836429873782, 0.17445630003367701, 0.12433167276603561, 0.37261094777814807, 0.20062787067745963, 0.21546993554840166, 30.652820833267707, 112.75106445435556, 103.48917176646572, 103.99478097115795, 99.452448814146, 79.68544467802971, 39.60561898446853, 30.236182751194125, 48.280387770745065, 85.20400770248906, 104.3130107079783, 74.27235418750395, 1.443660578900768, 0.18410248081049613, 0.32584339440349613, 0.3310316789054102, 0.2079757110726449, 0.21602637585132353, 0.13177119856399874, 0.280513359053481, 1.1731093352840793, 14.2859419122819, 49.9457202419158, 97.92801180193501, 125.6457857931814, 119.41906236833142, 113.21486119301089, 109.73474610236384, 99.0234984121015, 95.39791830124395, 96.20001162252119, 95.11124795483005, 95.88999532884168, 97.89360477078347, 99.02020362115677, 100.43576348212459, 96.81005001068117, 90.4253335152903, 88.8115841342557, 101.73027899957474, 106.72398182653613, 110.94546410345264, 111.13814661579748, 111.69483292487361, 99.35308733294087, 94.25492394355037, 103.18351714841782, 112.9729058665614, 93.50980697139617, 57.638751153023016, 41.639567959693174, 54.119173096072295, 69.4106077378796, 88.33277256258073, 108.08735847473146, 102.17469138483848, 110.23453450972035, 111.82106264175908, 111.2683928397394, 117.8633483763664, 133.10018754774526, 118.76573670294978, 92.12240188352524, 102.1360795728622, 113.9619158160302, 113.54462269813784, 104.57012991751395, 99.23827171325685, 109.33249919645249, 111.34669903785952, 107.78086446946668, 106.92929437083583, 115.37268254064746, 112.89338373368787, 108.9924846156951, 100.95897628415017, 98.22613546925207, 97.92911006558327, 91.54611941306823, 94.16886714196976, 99.41892039391303, 103.56661504314792, 110.66610505503994, 104.53373032231485, 96.8783933885636, 63.80623894353067, 10.010079895296405, 0.28593039740958526, 0.044171706578063394, 0.1043242983700287, 0.17658525837525246, 0.16454387305965348, 0.2705118360538637, 0.033034948526971766, 0.20182462258925363, 0.8147704216741747, 26.323028187597952, 68.41736947336506, 80.94289379735147, 59.676849995889974, 26.065234330392656, 24.222718592612978, 26.007418594052716, 58.56226144298431, 95.01736994712584, 86.14722790256624, 89.02052094859462, 97.38703850776919, 38.91987492961269, 2.0922285318374634, 0.10518443890877309, 0.12003707579307019, 0.28351970257297643, 0.009367196452653697, 0.1827412804648761, 0.0387913063769379, 0.1985431002873567, 0.17246201994919008, 0.1534147452442877, 0.1773740531456086, 0.05720160578587844, 0.05737300646761733, 0.05015715919134598, 0.03515892729703938, 0.04424948365457597, 0.07274475985116537, 0.08766876548648843, 0.0981015959874757, 0.06540090311318636, 0.06799600297404874, 0.07695717091161398, 0.04651625355285022, 0.05242998501466167, 0.03168264820781206, 0.017547515866857384, 0.02123661801188944, 0.09435042348359862, 0.017576994930183696, 0.14194210360367454, 0.017039932821306492, 0.05804824402495738, 0.17872967637113987, 0.13490292003318188, 0.10981252161605705, 0.24055839576307805, 0.15452238580872937, 0.13836168443724034, 0.13027679085010482, 0.16908649865898395, 0.1428135132957851, 0.20085752851540045, 0.1398575477181904, 0.2161714116171483, 0.11619358203343808, 0.1861037476168525, 0.20503204886711415, 0.29808395331905735, 0.091040103936628, 0.17424046242189023, 0.067352106073691, 0.14722809495945133, 0.19347408035349464, 0.1729850128533379, 0.17369745930116023, 0.3086480300032324, 0.1327515306371835, 0.13107519236303147, 0.22867620351814458, 0.13914039749051296, 0.13294429368069097, 0.13417705172492614, 0.3245118723040627, 0.30170463806679176, 0.5836062710131369, 0.30528088971491785, 0.37370130539901797, 37.28097531103319, 130.65609593545238, 115.56349016004994, 104.0690000595585, 87.07114219665529, 64.86771860430318, 53.2461868563006, 69.77818873620802, 116.19807474074827, 111.49210914488762, 111.69081641781716, 96.88537520747032, 3.3304509280189394, 0.4359908113556524, 0.7534385869099248, 0.6013891329207729, 0.36860829159136743, 0.2646951449494208, 0.42700438549922365, 0.49724355520259955, 1.9003471636003064, 10.393764184367273, 41.024803115475564, 89.32683452483147, 125.35185906194873, 124.06394881586876, 118.82589801665276, 118.215067309718, 104.69307268819502, 102.42114959224578, 102.04033451695597, 101.81753604642807, 102.83615989069786, 102.7630312212052, 106.31534930198424, 105.21390853389617, 101.60809716870709, 94.8910068696545, 93.1919773163334, 100.58524500939154, 110.44952746360534, 117.90784374360116, 117.30008033014114, 120.9136736777521, 108.34093186163135, 101.12874430994835, 111.12624614469468, 120.97356042554303, 98.97948941876813, 61.66824517711517, 36.734867634311804, 55.31774743910759, 85.44922644092192, 92.73256578753072, 113.99705240803381, 107.54065852011405, 117.73143122273108, 115.15418298782842, 117.272443309907, 120.93226571236889, 139.09302003922002, 122.07258501360495, 101.77107949410717, 112.72229779151179, 121.64501528586112, 120.1930715191749, 111.26502744613155, 101.81744190954394, 117.79677006506152, 119.97864338659473, 116.48661213536417, 111.84851138822495, 120.05241532479565, 121.1638032236407, 118.29740570437525, 109.30943565983927, 104.21359431359076, 100.23957437084567, 96.06414856449251, 96.92035490466704, 101.99224625864338, 113.88561787143831, 116.81080387484644, 106.73199915116834, 99.44416476834206, 54.357178595758256, 5.847177726607169, 0.744828003789148, 0.37148832253390746, 0.3976783252531483, 0.28070031515052246, 0.4150774996847876, 0.6619209267439381, 0.18765400314042646, 0.5691520304929826, 4.742290666026454, 42.956746931998964, 73.6595073823006, 111.93048892482635, 130.46692786678193, 96.49012580994638, 67.65713568656676, 25.576222635084584, 43.61505008512928, 82.51886290888633, 88.05368808008011, 96.11514722147297, 111.36507141974666, 38.970751993117794, 1.6813931061375527, 0.31017901075463145, 0.26024068074841655, 0.45883423558646635, 0.18355316512527006, 0.2568960328015589, 0.17301014053725428, 0.2841138497235314, 0.31711176939068303, 0.20285154812999312, 0.2441384625290671, 0.21198086470605867, 0.25302725814042554, 0.21545505812091215, 0.11646470054984094, 0.13953445779700435, 0.21715888362978736, 0.2065458079619754, 0.12369589639767525, 0.20998520566330803, 0.17399942051739464, 0.22529174964274132, 0.16220995555481604, 0.14875855477106187, 0.1677450327382934, 0.21198714662703777, 0.1946041979376347, 0.18589501930100305, 0.18353606604280012, 0.2537765074521303, 0.2121404254989278, 0.23930706774755833, 0.2864285077779524, 0.14267822216835715, 0.18042378788513525], [0.048794633513616945, 0.05784200549486184, 0.06058957600485414, 0.036221253760759874, 0.07295997693173348, 0.03557978918956172, 0.05899663789257888, 0.023282664572639812, 0.1024484324959978, 0.03797727283991633, 0.07595750277922039, 0.13369325187898454, 0.03465305645799926, 0.0642592252622689, 0.10545240114292792, 0.07815573845178851, 0.029652597562920664, 0.03367779588687324, 0.024519149634626605, 0.044828366503239646, 0.025671882134291436, 0.14687702750727055, 0.029202628159715287, 0.011488346443060907, 0.1833031293485434, 0.0227478202883034, 0.023834632837303707, 0.07168015044543051, 0.10792125737474811, 0.23058121903769432, 0.1839264031619795, 3.061950225983897, 73.92076076999788, 90.55505414162913, 71.2811468493554, 84.9091003787133, 49.47056431924143, 34.54535353568293, 83.0266764856154, 84.63858235266902, 91.1743885470975, 106.98874181316747, 55.147520495999245, 0.6187148548422322, 0.16317021612438465, 0.18807339031369458, 0.22927119336541624, 0.07613947164387473, 0.1816317553241407, 0.2105816970429113, 0.3932389989495278, 8.35617328843763, 62.4530565354132, 110.13018377365606, 124.5558689486596, 111.49077553902904, 101.91275550473122, 103.43221895156368, 110.4186034971668, 109.99840782534693, 106.1586113898985, 97.66454619746055, 91.02529925684776, 90.10513474864345, 92.59977786771714, 89.46732597966349, 89.67268559240526, 86.75813705690446, 86.00284545652329, 78.46822338719522, 95.67444539839222, 103.69253881515996, 116.43175386613416, 109.11592160501789, 110.04773555263397, 97.15004890195786, 90.93211158629387, 84.04111908328149, 98.3994100939843, 97.62379277137019, 95.03600120544435, 64.89414753452425, 78.76669222308745, 63.543498977538086, 69.71489737110754, 97.41855867447393, 100.50842146719657, 103.21256622191399, 92.89465381253152, 106.37477321009483, 109.97138269485967, 117.11486601060437, 119.43777207405337, 107.98450608407299, 92.49039080835159, 89.94222302590647, 106.12323945568454, 112.38986122992732, 102.29091905778455, 94.361126038336, 88.67614469220563, 82.20162945408975, 93.52101710534866, 101.96376200645201, 107.74074646734424, 105.29474858314761, 96.77106165116834, 90.07792134438792, 91.01212009306877, 91.4304251824656, 87.87266285188737, 105.36114646542458, 104.24452612476965, 102.48628447132727, 102.97329379666238, 104.65067971137263, 101.75811998305782, 108.05637175037016, 96.68427528873568, 25.720008880861347, 0.3540919979493464, 0.11175414081662895, 0.059452820268850175, 0.041953472180231925, 0.31539855164385616, 0.3826046260374208, 0.08252992429920743, 0.3455089633503268, 0.32355034002853983, 19.02128311895555, 81.70485342702558, 83.32513747676727, 85.27082135600429, 76.88873983198597, 81.32609367370605, 34.1557131275054, 28.78318778930172, 51.7418872925543, 54.07439139581496, 69.79640422328826, 76.38226770585584, 53.97621447040189, 4.226508303996056, 0.3476559094363644, 0.24596417262669534, 0.14264166445261048, 0.037988729684823946, 0.03143065699165867, 0.025492041078846783, 0.04757211040405016, 0.10317483706580055, 0.1109682265368681, 0.04109751065111449, 0.027627290917500377, 0.02138876307365154, 0.04314960356080725, 0.10256006682832396, 0.09243225423438896, 0.2667436947024638, 0.09433890918209668, 0.05450959580259458, 0.124054440867997, 0.007549535066279913, 0.021542015132464228, 0.017680728980790705, 0.07484121308211358, 0.03599055404324205, 0.1409715468124036, 0.0613737742476646, 0.10833968693811087, 0.07306770421564579, 0.03142592256828662, 0.08151023062847315, 0.027388327026499376, 0.10114508711041943, 0.06355950353486885, 0.04831727263667891, 0.020043782724608338, 0.018920898925693288, 0.051332012479824406, 0.07235165715457932, 0.04588423867619807, 0.03377857858375196, 0.09736758416458484, 0.0797142677249447, 0.07303426447775095, 0.09229489466956547, 0.06608162586006426, 0.05317086864623332, 0.14173146006801438, 0.025979186813797683, 0.058572734630997145, 0.0518618235664983, 0.05128330460959866, 0.08520653591521325, 0.07229501261345803, 0.03888033728505816, 0.01802970309771838, 0.0792677840217948, 0.09543790061387325, 0.026469935077212514, 0.05337327673670746, 0.01017669187633381, 0.029568302993392272, 0.2391216438263655, 0.26746090621717517, 0.3238712389382624, 7.336916961977559, 99.24035841418852, 105.44312400202598, 101.93049246265043, 106.77526289416899, 82.40190567508822, 24.286831694264567, 35.73869151453818, 57.94284074537216, 93.27583759061753, 115.84183723695817, 59.87922076256045, 0.4677493539789031, 0.10047128979837704, 0.1342516227234756, 0.18967849773264703, 0.17577669853644987, 0.33280618368617954, 0.07744835584514564, 0.5008332287111591, 16.944866641875237, 83.84405136108398, 123.35619634197606, 129.1911534340151, 113.65983055483912, 105.14570636133995, 104.67507685384443, 112.49396877904093, 113.75818790928011, 111.03014807547294, 100.94587556777462, 92.92768801412275, 91.13362727626678, 94.46255068625175, 92.63647556304933, 93.3658952097739, 88.49675901474492, 88.0969439783404, 82.88341583744173, 101.85333944136097, 107.40510925169914, 119.96282839005994, 111.59397309826268, 112.99962505217522, 102.1658189835087, 92.50765708185013, 85.3733285780876, 100.93053125566053, 102.95503908588041, 100.74199076621764, 71.86798834031629, 86.16177989590554, 74.25601359336608, 79.28712798703101, 105.71179851408928, 105.0173193408597, 109.37161307181083, 97.83964864669308, 110.27415044846074, 114.04913363918182, 117.02153713472428, 121.69438223684989, 110.5123559890255, 100.5506810834331, 93.60231999428042, 109.54520148615684, 117.66402136894965, 109.5548426720404, 101.2043676068706, 89.99559079447101, 84.65406002536898, 94.07323975716868, 102.31064073501095, 105.85167023443408, 105.00818806309854, 99.31135331430744, 94.37878454885175, 96.55148736892208, 92.8476167494251, 90.80481498472153, 111.15582866053428, 109.48524413570281, 107.0852791878485, 104.56463075453236, 104.94505359280495, 105.07551162473618, 111.44178513557681, 111.15364782271847, 40.86658254746468, 2.1788249044649066, 0.29432129715719535, 0.16332934790801618, 0.17263219872068974, 0.3053990511163589, 0.5181905747421327, 0.08838138047365413, 0.45668070114428, 0.4382795756382327, 16.862518441292547, 85.03472605059224, 87.55986167538552, 76.32899407417544, 51.045709733040106, 42.77902041712115, 20.944989958117088, 41.148079287621286, 90.30520700639295, 79.4706949110954, 87.22981775960615, 90.30749767057358, 78.95334997484761, 11.259120433561264, 0.5332604435182388, 0.16113285125503618, 0.09666394772789172, 0.020367384009483843, 0.09939685148457367, 0.07586446140081653, 0.06931878401026612, 0.024669833383673144, 0.1324292374474387, 0.043027948798431505, 0.06731062241259121, 0.010863466717813526, 0.04471400872834268, 0.0793161241698169, 0.07545577647585062, 0.16983190220930885, 0.16044940889602707, 0.07811101423876901, 0.13791661799675034, 0.03527104426475783, 0.013812381413675124, 0.02586197919182239, 0.021950073780552037, 0.005848346815084018, 0.1224416649089225, 0.042511977090109745, 0.04992285886058404, 0.08902101792515286, 0.04414690831195443, 0.09252849019943707, 0.06383163711777137, 0.021008563212930195, 0.11854379422842495, 0.12940286838960263, 0.16158475119981075, 0.1751000283946914, 0.1516323037926228, 0.1704190473162359, 0.0960881024178478, 0.22707806749930307, 0.20381732453261653, 0.17272933866948853, 0.1731607840666848, 0.27482374661391784, 0.17119959898052678, 0.13720622466456506, 0.2612809975060725, 0.15750680389183183, 0.13666748099269407, 0.16979134551459746, 0.10849426049859294, 0.23735340564481675, 0.20291701800400214, 0.1502972730104962, 0.2290109073322627, 0.09062614832674304, 0.2087669113590833, 0.22725653534214343, 0.09348346476232813, 0.1111583159335198, 0.15679631862909565, 0.37465627996190903, 0.3614256963614495, 0.4519022123948221, 11.355496991065241, 120.1132591309086, 119.20444596198298, 99.84647443217617, 103.00626524033086, 64.06051835706158, 49.24087032195061, 110.8810038720408, 120.07746358071606, 121.64948678785755, 122.30226332141508, 79.63321439681515, 2.2614042797396263, 0.2448310519778921, 0.5495031009758673, 0.37062420599883605, 0.39479063343136545, 0.4680527554404351, 0.5020343320023629, 0.9658898449232503, 13.3582386086064, 76.78920576649328, 125.06447484416347, 139.2222542916575, 123.58853401676302, 111.00315432394706, 110.17517335953252, 118.90575747336112, 119.78601578743228, 117.80729770660402, 108.34766264884703, 100.86351363889634, 99.4842827704645, 103.71803422128002, 101.90838598435926, 101.84563590634255, 96.33789077881845, 95.50226903730824, 87.29643529461276, 105.66007814099713, 112.480358154543, 122.5827363229567, 116.46561176546159, 120.78033662611439, 110.3341313331358, 101.33022862095987, 93.00259743967365, 110.16728155074581, 110.0738428485009, 108.61765507728823, 81.6580124824278, 99.5155519054782, 85.82054153565439, 93.57642450640279, 110.57713785479146, 114.83398422118157, 112.86980244421191, 102.7703268297257, 118.54247539274155, 125.38020995355423, 124.9509536066363, 128.02103196420978, 118.22328859759916, 110.54517838262744, 100.67735795051821, 112.12838034476005, 121.00825771208733, 113.58425432635893, 105.6390699263542, 97.75607078306138, 90.08779787248181, 100.00844478607179, 111.43340695288875, 116.84120224368189, 112.51711860779794, 104.787946977923, 98.32842303860573, 100.86685549828314, 99.20672016759073, 98.44079894404258, 116.89595068654707, 114.25562289453323, 110.36776957973358, 109.16357055787118, 109.65561620650753, 108.72684601814517, 115.98851819192211, 106.24806496404834, 30.481734891091627, 1.7489692929290956, 0.9604777095298614, 0.32690329236849663, 0.3005455163938384, 0.4765711628621625, 0.5695874748691436, 0.13471708242450992, 0.7724355449599605, 1.041866829318385, 31.35336595196878, 98.07124107114731, 100.96416950225831, 121.93907537767966, 111.18994543629309, 108.90467843701764, 42.74928492884482, 34.33793860097086, 71.7197698162448, 71.76290804339995, 84.4951020517657, 107.18103993323543, 88.89517768736809, 10.351898766333058, 0.7316461433806728, 0.5532140308810819, 0.2705249821226443, 0.16800202459337252, 0.17746841985612147, 0.14387774731843703, 0.15563879041902481, 0.14185213423784704, 0.24435059227530034, 0.12461347054810294, 0.1374656526792434, 0.21014620670147482, 0.12737063630934686, 0.18146537634874546, 0.21449370970649106, 0.5397051428594898, 0.19111803822940399, 0.21563657499369115, 0.17910055485704254, 0.10096461977809669, 0.14556219080282798, 0.09228603103228154, 0.14251760417415252, 0.10214490079951864, 0.20782169675634754, 0.20708488871253308, 0.2216157380251154, 0.17906683166661572, 0.17866026880520006, 0.14847516352611204, 0.09744652952518194, 0.18642910515829442, 0.24765604716395181], [0.04918072650569582, 0.059202098843431285, 0.023368700076976133, 0.02142896353747816, 0.015836657670837258, 0.08974982801103785, 0.023866262692477436, 0.058808199415403994, 0.11213943707726656, 0.06372728445116552, 0.07629557738020536, 0.15215359598157868, 0.03992111752590826, 0.04544596743559645, 0.07437613642504139, 0.02472055223470013, 0.04428794892925409, 0.0451557350254828, 0.04673003038812069, 0.11528901605596466, 0.043030775662872105, 0.012361738387675536, 0.06477608946302245, 0.1042028274687548, 0.09850412156553039, 0.03425091775434633, 0.02682820758632114, 0.04315349145702297, 0.2392404640634214, 0.24938345285913638, 2.546066862921561, 56.715362456537065, 95.71585778267153, 87.40528106689455, 75.68327780692809, 43.22695509079964, 40.60851804671749, 95.56612522371354, 74.90692307872158, 96.47294582859163, 99.93825789420836, 45.94360436162641, 1.2589459938387717, 0.054613010011493206, 0.07116346244489954, 0.11603765249733003, 0.10222749273863532, 0.20160398926706086, 0.153734908709603, 0.4327004330773508, 35.49029173389558, 111.31124081150179, 118.95361823420372, 96.09297014051869, 89.8051675673454, 88.62497345093759, 103.6048032391456, 107.42609393212103, 110.2759704282207, 108.95613993367841, 98.60539728595366, 82.35343302449873, 77.13032645563926, 81.36810225825157, 82.50682123245733, 83.47905128232895, 82.85653191228067, 80.8247833867227, 80.27389434076126, 81.0481466785554, 96.66908787142847, 105.05346005962741, 111.43533675901352, 106.50798474588703, 110.05773759657338, 92.96172634247812, 81.24339442099296, 75.92758655548096, 90.25601263969176, 98.02488650045088, 99.01159009625836, 73.78185395271548, 78.14907581575456, 88.52478042725595, 89.56586376313241, 104.87453722184705, 96.60157603602256, 95.74999809265138, 93.82351813777801, 96.01721348301058, 98.5832437392204, 101.56806545872843, 108.8836153091923, 106.75481950083088, 88.69115168048491, 91.58135014195597, 97.16924498158117, 104.36475461529147, 100.96758196430822, 98.79550672346546, 90.47547709557318, 86.9926477247669, 83.34347063495268, 88.91187129482147, 90.94755003529211, 86.95319652557374, 86.44394736136161, 89.83752712126702, 93.74285067281416, 84.58788179582166, 80.5074401055613, 95.31985529007451, 96.2724107311618, 104.24886426618023, 108.70029941681894, 103.2200736384238, 99.28678358754804, 96.15393946247717, 92.71983377395138, 108.51426924428633, 39.93037946762578, 0.5067834949060794, 0.2351553614942297, 0.06495359203507824, 0.23332036641095918, 0.05172356384836378, 0.10726889520282708, 0.12775237026113656, 0.08077264883585515, 0.579512358432816, 7.527550035907377, 76.29705813623245, 77.79516819984683, 72.35808849334717, 91.59945580267137, 105.5124479724515, 47.18198291717037, 16.052047917919776, 34.8892238063197, 43.266955421816924, 64.2640423005627, 76.09949619539323, 62.97831681466872, 5.687682388290282, 0.7789773842500103, 0.1307957541317709, 0.0253559532199776, 0.19660040856369082, 0.06045498967831654, 0.033747180470175324, 0.044909093018260696, 0.04943817035265027, 0.05705174749657031, 0.021193803273021214, 0.03495652686744448, 0.042726309339125315, 0.06580977956013334, 0.12674385381321754, 0.11304968742713814, 0.042680979916645635, 0.04203894077950428, 0.08591272342469423, 0.017081546717353405, 0.03691360572232835, 0.043120369645616705, 0.05502366378242451, 0.10355529165075672, 0.18572539211280886, 0.0626953793389182, 0.021721526770101442, 0.04188710598335151, 0.036268073224252274, 0.08228482978959238, 0.10712322358402515, 0.1771071327910308, 0.045453344862307274, 0.10977106093759499, 0.022141948162067323, 0.03443146935634075, 0.0585468102156395, 0.09117121988486859, 0.04960829549799523, 0.019832995547462377, 0.09091582149267198, 0.0640661481227125, 0.00857967434586176, 0.014147133108288532, 0.004777191188036194, 0.07038693274221114, 0.08404791219941071, 0.03198868692702344, 0.03644932962713703, 0.047700794023131175, 0.058380653405742305, 0.10168211474534004, 0.06850123796011172, 0.11866796175919234, 0.01503799089996685, 0.036109910541844946, 0.1456917515925823, 0.21922804114799346, 0.06217491069448091, 0.08018201802887263, 0.04938922499516799, 0.25770217180252075, 0.41887165738209603, 7.935066646145237, 84.53182328131892, 109.8453490964828, 112.93692204260059, 108.635541085274, 72.26487728857225, 25.274345259512625, 58.491952957645545, 64.54625683446085, 97.69881202328591, 110.07075986554547, 53.56626402947211, 0.8761436251863357, 0.1565952665142475, 0.11069462589559056, 0.13921481527147755, 0.047921239653782505, 0.43770430489413203, 0.10692634664836431, 1.5052335781435815, 51.15803857003489, 124.10594171093358, 123.80391920766525, 101.7865022536247, 95.99150626890122, 95.73720332114928, 110.074368446104, 113.24195692616125, 113.6414267939906, 113.28040399859029, 102.16065714436193, 84.80213734411424, 81.953931777708, 83.94627617251489, 89.75067800091159, 88.13231591255435, 87.66767978668214, 87.91526763669907, 86.1049133731473, 88.89455795288087, 101.47974152718822, 110.4115902992987, 113.11541341966199, 106.26423297389861, 113.83905149275257, 96.43229438412575, 82.80089701375654, 78.0996774858044, 93.90692341712214, 103.37605061069613, 102.7915939208, 81.86068134923136, 83.33418246238463, 100.8669339456866, 99.74740320636381, 111.02096188452937, 104.48940753936769, 101.86436130154519, 101.99274047728508, 102.61068636371245, 102.91878069600752, 105.15423359409456, 114.13870488443683, 114.0796418343821, 96.20458510614212, 95.85756517225697, 102.02255049059468, 108.09134360282653, 109.01116294245567, 103.46512763730942, 95.78069456161992, 89.5138531346475, 85.7016388062508, 90.86900849496165, 91.32638823601508, 87.11588075084072, 89.93072263656124, 89.82521087892594, 95.84932035015476, 89.16924153604816, 87.52679609483289, 97.95884163148942, 98.48448630302184, 105.80537057692005, 110.05801216248544, 106.62084702522525, 101.26368953335671, 99.92100731019052, 95.90185657624276, 114.63044458819975, 52.555630053243334, 2.0687656489110764, 0.13109489614444395, 0.2727023265775173, 0.49963571071144075, 0.06729094161381645, 0.05872991289042177, 0.03310169010693508, 0.10265068736888709, 0.904725446335731, 4.620420663587509, 78.67123742257395, 84.89907480055287, 72.322324322116, 91.67831897735597, 66.48368804685532, 25.88526421977628, 20.73142670815991, 61.05175449002174, 76.02353557463616, 80.13467373386507, 83.92744879568778, 82.44457321782266, 14.429129996607381, 0.748230905061768, 0.11549347726207589, 0.0666679665746708, 0.12476108036935331, 0.03592333748876568, 0.02860119168256079, 0.05358485489963524, 0.05654809448207098, 0.03162997200213854, 0.04985506774016446, 0.039640350132099086, 0.026622275491395307, 0.033469213127729394, 0.05512076159638744, 0.05372538989890487, 0.023258735816324913, 0.06338753594806598, 0.012947804268239247, 0.04435428448261754, 0.014507849437875614, 0.09120606922454412, 0.014008583234352692, 0.021246056215116577, 0.10070641750409719, 0.14695146060999364, 0.02048471612074683, 0.04349974787703926, 0.04501806519504997, 0.03529217680014911, 0.06965229272722237, 0.10755309084009741, 0.08047193634293734, 0.1614752465919141, 0.09629848548361371, 0.11632236907438886, 0.1431871956634906, 0.20223302406168756, 0.16554996100885255, 0.09947039592530459, 0.1687793893318984, 0.1507199696835972, 0.11191947025156791, 0.1240494842791269, 0.18846055582886745, 0.1701654262480236, 0.13158840998526544, 0.13941294093045498, 0.17609770469848188, 0.15997532304496537, 0.14424274224908123, 0.13730984571720325, 0.16406394961860873, 0.1973678907679935, 0.08302120116329001, 0.19851873869136458, 0.16547672300329133, 0.28963823231958574, 0.23105309855553413, 0.21735536986060683, 0.18910328827558026, 0.4716088436543942, 0.5457748881270809, 8.777681973672683, 102.56484954587876, 123.77882388330276, 113.20773816877796, 97.86514405281314, 53.986283194634225, 56.60797972832957, 130.45473714028637, 101.12673605642011, 125.27656524412095, 119.68044911661457, 72.44723612262358, 2.543545024048898, 0.36022686069050147, 0.33914749180116965, 0.38384783352094315, 0.3532350519972463, 0.4885136462267369, 0.59564690556257, 1.5437195065521425, 45.129943970711004, 125.73202302378994, 133.61163323925388, 108.08206327499883, 100.95895274992913, 98.26497477869835, 112.2995133553782, 119.43512839655723, 119.91747794612762, 119.62377871236494, 109.11192078744213, 92.02627243534212, 87.42879959844774, 89.5976584957492, 92.74192456276187, 91.75464830090924, 90.7247829437256, 91.93435561272406, 90.06757413187336, 91.92370245533606, 105.60257619427097, 114.6105738609068, 119.76921235361408, 112.27635568188084, 120.64526588686051, 103.98854440258395, 89.29092914827409, 85.66015581930839, 101.12380996827157, 108.61720008234825, 109.30164583267705, 90.62414276984431, 94.4547216353878, 108.38067331621724, 107.35898217847271, 112.25517488295033, 112.820568853809, 107.83481274881672, 108.76708953611313, 106.6169011208319, 109.33991247607817, 112.45126201260476, 126.05408099389847, 121.85809412310202, 103.85573294854935, 103.48949340081985, 107.83652290221184, 111.98598261802428, 112.17509577351233, 108.0956268310547, 101.36666743986069, 94.7426785192182, 93.07196847854122, 96.99118506523871, 99.43955206101941, 94.48292347692674, 96.48349700435516, 97.41673084997363, 101.58993659480926, 91.90358854109242, 90.34490923727714, 100.93152753768429, 104.3791889375256, 114.65869349818077, 118.98491090343846, 112.65757868366858, 108.30134730185233, 105.87555746878348, 106.01697460297616, 120.15751915593302, 44.82295182443435, 1.4621335940976299, 0.9175772147793925, 0.3490760525868785, 0.8295168787721665, 0.17483018158424288, 0.27947929357328727, 0.4092715031677677, 0.2593077388742278, 1.2704753106640232, 14.861128080275753, 98.10346726448306, 88.92246169428672, 94.1722168460969, 122.319333476405, 153.6223420789165, 64.8991407117536, 19.33291150677589, 46.06904960447743, 62.501070268692516, 82.38254485591766, 94.3820244266141, 98.84239473650533, 14.482390880584719, 1.0007778567171868, 0.1770114330875297, 0.1692313658854654, 0.5026942094968212, 0.13876294597021996, 0.1053854603801043, 0.09824012000594409, 0.12020026018182117, 0.1581267069184011, 0.11754470066197457, 0.1983185599167501, 0.1569262624628121, 0.1830906318801065, 0.20148812612939268, 0.2092368450135954, 0.12561292417587774, 0.12999934444744743, 0.18058046818740908, 0.11658555091989618, 0.17563431343484312, 0.29286643490195274, 0.1302395589769848, 0.1343914337696568, 0.22551526345552939, 0.18491954422525822, 0.07364649130331893, 0.2941620427994959, 0.11741009901367849, 0.12361331978031706, 0.26470234617590904, 0.24316651145777396, 0.18811855885771014], [0.07525963498459709, 0.04836036891285931, 0.013905840309997721, 0.029131906752985333, 0.07734522508877902, 0.12228313067387189, 0.08057654564899784, 0.060819628378075946, 0.09665539818665675, 0.030746772216873306, 0.10436686221510173, 0.08105134396182914, 0.03497733764590756, 0.041320515015432914, 0.08629821886819217, 0.04745880216960946, 0.07804548307772606, 0.09120492775353695, 0.0629488778330626, 0.018103034949050318, 0.08937652868729445, 0.04898082352273407, 0.038556600019576094, 0.03224045406245897, 0.141793635763949, 0.13128177563269294, 0.041677308974847685, 0.14389956550252053, 0.4322271133142133, 5.176897616155687, 71.36176724587718, 98.78869748884632, 69.85170179797758, 77.63507273889358, 59.60595315502536, 48.571737504774525, 119.35389611028857, 92.3323114456669, 106.77903621427475, 106.72613128539055, 40.232319601120494, 1.898031004013554, 0.07719622098750646, 0.23431640328659167, 0.06461566299079888, 0.2437567362381566, 0.12013307427086177, 0.0605294878985132, 0.12380226004508235, 55.29682159423829, 124.48498387490551, 99.79782919729911, 93.90476611352737, 95.66980915684854, 94.49781279410087, 90.65465880978493, 93.3533985384049, 96.6028311944777, 94.79170814637216, 91.19779725228587, 85.41186978740078, 77.82825731462049, 84.9198555177258, 91.0994791215466, 93.72699645257767, 94.82782533091884, 91.8855691725208, 88.95969283196234, 85.06552450118527, 86.02039414067423, 99.55707411612235, 110.85380615726595, 98.36854104072818, 104.48666188024707, 102.88423245952976, 82.67641667396792, 82.44771895870086, 77.02978826338246, 85.9578323364258, 93.73548446163055, 94.31528137576197, 78.79395269578504, 66.47927930278163, 85.65613146751159, 98.30745404766452, 121.789578160932, 108.0848716920422, 106.53093845613542, 100.8538567635321, 104.23912894341254, 97.64553054686516, 100.79772764636625, 100.80175199816304, 93.59702479454779, 91.83408414163898, 93.6534284776257, 93.08371989957749, 102.122053177126, 105.67184525151407, 99.97253940951441, 96.02853344332789, 93.71382513353902, 95.61095007004278, 98.8284310986919, 96.70648374865132, 91.53568590840986, 80.72321753348075, 76.94330784582323, 79.69892194194179, 82.71940585105651, 84.19507211254489, 89.38480715597831, 96.37781266243228, 94.13241263358825, 85.61419348562919, 92.05945568699991, 87.71659174273091, 87.94257517783873, 92.67649942828764, 90.5094918897075, 93.87479136067053, 30.43556663297838, 0.4981748729703888, 0.23819450889864277, 0.21370627857264013, 0.17358790872798813, 0.02879645600314102, 0.11205021081672562, 0.06610070144937885, 0.12248707860107384, 0.46101853611969185, 5.201649242831815, 83.22467773191391, 104.24980563502159, 93.36163551576676, 106.3441865674911, 116.57709337049916, 72.36829450053554, 21.188602485964378, 26.882666080228745, 44.30625407926498, 63.887294723141586, 72.68382564667733, 67.89902041035315, 15.52302118270628, 0.653688729770722, 0.23639260881370117, 0.18442846654403597, 0.11067457737461214, 0.03958214660205188, 0.03315921181872968, 0.02367901165158518, 0.10112385115315838, 0.044107125366046544, 0.08864084679272868, 0.09131036443455566, 0.14916441283158718, 0.04422475816681982, 0.06897153167594826, 0.01727122434174582, 0.10878043264270791, 0.06493983309595816, 0.017994363461771322, 0.061117801289524765, 0.03990426359157409, 0.022906184068790848, 0.11698857445510165, 0.058263802014651804, 0.03019200007040655, 0.09142876332325321, 0.14429891181568946, 0.07974143320273969, 0.17185920068333227, 0.22160001790090916, 0.1685982861465985, 0.046618664186568036, 0.05208951638891332, 0.04022393293017822, 0.03149162609911254, 0.019009935579472975, 0.05897495760432175, 0.03567012244715326, 0.03647810772001263, 0.0728670581273975, 0.04965793799548861, 0.01571793127955208, 0.024154685219869982, 0.05140725763574724, 0.02500556375560982, 0.015815327867805477, 0.04157866749371733, 0.07838639220403087, 0.08202849677012813, 0.0653466794099058, 0.0635485599688705, 0.03580713727241082, 0.06685050234438912, 0.050897138839166974, 0.05702897553302108, 0.07504364415522545, 0.10554512076440359, 0.10899122173507368, 0.06395953549673, 0.0413665798823199, 0.2758033279209368, 12.982523595133136, 100.53371291006766, 113.29502659459268, 98.57583830433508, 106.19745854408511, 91.155529791309, 25.523364774642456, 61.60998229057559, 90.69396095891153, 108.21811460679578, 114.3078374862671, 43.06999360361407, 1.0859220330753634, 0.1420187123961026, 0.16732725434966628, 0.025334050766222423, 0.3137097261365383, 0.3177358246138019, 0.1421763732909195, 1.3499767285200859, 71.9732726004816, 131.00382189596854, 104.47836214496245, 102.72665516022714, 102.50364488170993, 99.74932516774824, 96.73599566182783, 94.3630087760187, 100.04968458606352, 98.71252506009995, 93.45128520842522, 87.69626602049797, 81.84957319690336, 89.33755828488259, 97.13569302712718, 99.37079291189872, 99.15486643391272, 98.44963996641098, 93.200481014867, 91.20444959209811, 90.94551824754285, 104.14755728936966, 111.98462547794466, 100.7823205763294, 104.0850974667457, 102.3103661690989, 85.3095979075278, 83.09685553273847, 78.49928855895996, 88.18590333384853, 98.49783805108841, 99.92485123295938, 84.90683324875371, 70.96305831786125, 86.73433611469885, 100.86356855207875, 120.24816513061525, 115.60217257468932, 117.8645956900812, 109.01143750836773, 108.85338952464443, 102.18034744262697, 105.9967508623677, 105.13420597199472, 97.43947275223272, 99.29535788874473, 100.44415735429334, 100.01661900551089, 106.64693863161149, 111.00111469145745, 104.34225589998307, 101.07344673525904, 97.56420412371236, 99.94148992723035, 101.36052500817084, 102.82537337272399, 95.588192478303, 83.80219182660504, 80.31900944248324, 81.99983919820478, 83.3810704754245, 86.41267038160755, 91.60952844927388, 97.99879489406463, 95.003829925291, 86.72801325398108, 94.39608220131167, 90.94336878868842, 88.72093815957346, 95.75004516109344, 93.85464606746551, 99.31455396836805, 39.565206804583156, 2.195529543584393, 0.13738991722704905, 0.4404816494113015, 0.5550252465951828, 0.07115346499748769, 0.24748275807547956, 0.0786301230771407, 0.06356753979719455, 0.49537209433413326, 2.9469009801264736, 86.03933918860652, 101.92054533189344, 88.88241429482737, 115.4763037158597, 93.39965112747686, 23.549951699472246, 13.86424691446366, 41.46326134281774, 68.84069519658243, 95.55790393583237, 85.05022725751324, 87.32149924001386, 27.95276907182509, 0.6130756509880866, 0.3228094104316927, 0.39349615934395027, 0.07387101635216706, 0.038955639897575306, 0.11871757361316874, 0.03468956054759122, 0.061633887911035176, 0.0497278435185792, 0.05281947560668473, 0.06798053565885752, 0.08119261057506647, 0.008326938109202011, 0.08022082804311668, 0.05801838574810855, 0.13456334389986532, 0.06465899292379618, 0.03754335297872463, 0.03740119770349514, 0.03897345910269407, 0.02078984319532831, 0.05744264769037405, 0.0754922652436841, 0.06295217967201626, 0.026742271673414978, 0.1225251378491521, 0.02049541836904903, 0.12496510490534768, 0.035588564726734356, 0.20623048617234155, 0.1065771178072018, 0.1605428869445478, 0.18263222018797554, 0.1309116938782315, 0.2757642574367985, 0.24304933064887602, 0.2628546033895785, 0.13063199517707672, 0.15503733478967222, 0.21348680970409226, 0.14419639392966224, 0.1035494157563775, 0.20738678864173352, 0.08462371154417915, 0.09248431756972306, 0.11438162321405065, 0.1482296936334141, 0.19447103653463627, 0.2047050212539973, 0.20608975582065123, 0.11472020343306566, 0.21644128907111385, 0.13772995301312016, 0.1708427858689139, 0.1357544574045366, 0.2268713769773322, 0.2878675273349208, 0.1681204311429493, 0.24423039307998073, 0.5489895769184636, 15.464982851859062, 122.28181208333662, 130.48432750086633, 97.49017330908008, 99.70629676695793, 76.37671362969184, 67.16485469572007, 168.55292258724091, 113.56709003448488, 127.48343975313249, 126.73817373091175, 61.459908485412605, 4.563662986601553, 0.37857950815270025, 0.40709357648607225, 0.17636857806674897, 0.6106931175435744, 0.3573448685628753, 0.8379099542094816, 1.6498594562853537, 66.87603489045175, 138.58206072161275, 113.40768491068195, 108.66007943307201, 108.78246522718861, 105.71466968905543, 105.15774019302862, 105.44655999829693, 107.43508400455599, 107.13464613883727, 101.37916411122968, 94.97704013701409, 85.96846980433311, 92.57116809968026, 101.2065484446864, 104.11996733757758, 105.71749379557949, 103.09350659770351, 97.3034449546568, 96.3021501418083, 94.49867571553877, 111.79664980980658, 119.50528390945928, 105.65469664912071, 112.0540435852543, 110.87497126671576, 89.44725128912157, 88.35558506750291, 85.23830490727579, 93.82129807626048, 103.8870648414858, 106.93518577083465, 92.79318994091403, 80.98526323995283, 99.58756662184193, 110.25803735179286, 124.7055152154738, 118.67807172959851, 120.3927593846475, 112.94913630331718, 116.2682302536503, 112.4082257670741, 116.71490976887365, 114.32096173686367, 106.0684439443773, 107.52754995899816, 106.93398552556192, 101.3973560640889, 108.52643643656086, 114.39592607559698, 111.26284660831575, 106.76015392426523, 103.26809913881364, 103.33477158700268, 108.26115085232644, 106.72290709710892, 98.99601828667426, 87.72441294885452, 82.88714993384578, 86.6057372862293, 90.41184840663787, 91.6130272034676, 98.36303403300624, 106.08216439524006, 101.99560380751088, 92.86376122505435, 100.04315776209678, 98.76239407447078, 95.19007975055327, 99.79202408944407, 100.37364882807579, 104.91674976964151, 35.59671348141086, 2.003150034335352, 1.069402480798383, 0.5280075931260663, 0.3828179968460914, 0.20126223744403934, 0.676792960974478, 0.22656097347217224, 0.38348584165496213, 0.8964361911339145, 8.88035491589577, 106.71611355197047, 116.03371958578788, 97.88437935613818, 123.23355167142807, 159.9936362235777, 100.01716813733502, 30.159306257001816, 32.99804126062701, 61.17919621929046, 85.59947675274265, 92.43834095616495, 103.39022605649888, 30.509881819448164, 0.7127501863625743, 0.5102253134452528, 0.3211722192504714, 0.24741759463664026, 0.08883388562788887, 0.17728224516876284, 0.15170535793708217, 0.2760854627816908, 0.13923044346513289, 0.15458926528451905, 0.15418316207585797, 0.22704881826235404, 0.10059882811601124, 0.16040607896302977, 0.18665882428326916, 0.22578160158328472, 0.1666543227169783, 0.12496775556956569, 0.18845468759536746, 0.2887753415251932, 0.09903152713612204, 0.2045795973390341, 0.3521072479986376, 0.2722877810799307, 0.13371450315800407, 0.19945001049387842, 0.21761179481062198, 0.21245254504103817, 0.30873312704986144, 0.2942742593586445, 0.2155122695670974], [0.06206660884462538, 0.050089184209824576, 0.12453496185762268, 0.07963810326351274, 0.07765566689833518, 0.11364789484369178, 0.029757231766838702, 0.04123145729423531, 0.016312425084892782, 0.05338511279513759, 0.07407968338098257, 0.04683391574109274, 0.006932818965475646, 0.040735534106891964, 0.034390571752503034, 0.022181357640112122, 0.011983449916325271, 0.026019297262293198, 0.06248406164588467, 0.04361068123891469, 0.05980831570923329, 0.04932017749055259, 0.19601073536661365, 0.1708697521638486, 0.07289968581209261, 0.07388311288049144, 0.21362308142406328, 0.17245576867172796, 14.896578461893144, 78.88131172426286, 83.36584383441557, 80.65149307250977, 52.06940912431287, 28.482818565061017, 47.154236070571415, 106.41326735096594, 109.49122967258577, 108.28685022169545, 114.11904596513318, 36.90022299366613, 0.7934703581756162, 0.21156434270162738, 0.2915172927802609, 0.09968043425150457, 0.34681777860368457, 0.03120211189642789, 0.08420276155154552, 0.7864198977908781, 40.80593093749016, 122.9589779146256, 95.54647414915024, 103.30172169593074, 90.31060418775006, 79.33923275240006, 78.35465508122599, 83.81186439144997, 81.27904092111896, 83.90313794535976, 77.26852724629065, 80.01453938022738, 77.68665975139987, 83.26297575427641, 89.10533828120079, 97.48378769043954, 95.8722113024804, 100.88135257844003, 99.21360784961333, 96.80876347326465, 91.35790840271981, 97.12053698878135, 91.88502788543703, 102.98309187735282, 107.12878611779983, 99.86939676346319, 84.95736122131348, 78.37496511397823, 84.11389473945864, 89.43921043026833, 81.1124578599007, 95.8708776966218, 93.41360692054995, 83.36251766450944, 64.08753172043832, 74.60770899249663, 82.8354452502343, 107.01983051915323, 126.41366035707536, 114.02194376914733, 106.82501423743464, 96.01413050005513, 99.10406389544087, 99.32359110924506, 101.26096740845712, 91.22419480354556, 89.56658547924411, 89.66608816577543, 99.2470342882218, 91.50182800908243, 99.97338664147162, 103.36808035450598, 99.64729647482596, 99.79069832832583, 96.89381614808114, 99.47399047113235, 102.07795789164882, 99.63176388894358, 93.61902929121449, 79.46299137607699, 77.2386230960969, 76.95583589615362, 73.91799157665622, 76.8349092237411, 76.03963298182335, 81.69154874740109, 83.85335522313272, 80.3135730374244, 79.88904706893429, 80.30393969628119, 85.30636587450581, 94.88632355966877, 91.370067750254, 68.52505422407582, 16.62345390166006, 0.7498252259627466, 0.3710357484317595, 0.03298237574316802, 0.010188516443445077, 0.15979414325087302, 0.014355909304633258, 0.09998247207653138, 0.035442015937259125, 0.3087381525866447, 3.3559612881752754, 67.53901743119764, 99.6712778460595, 106.93959451490834, 112.34706032660701, 117.45581411546277, 100.22659132557531, 55.59934616088868, 26.96456909179688, 29.045247224069414, 58.30511085448727, 74.85836413598831, 82.14459819178428, 40.71119000834804, 3.4782340690012905, 0.4225280418271019, 0.13357697505383723, 0.019612459901479945, 0.08678040992949279, 0.034115071213173295, 0.020063057496783235, 0.035161145121580174, 0.02443355846128637, 0.07944416810548113, 0.011355313359789792, 0.09196622762829067, 0.07554698690411545, 0.02987325386775117, 0.05602774458126195, 0.06592804055300451, 0.007343502422314018, 0.043362748373540184, 0.04358061994876593, 0.1249809476036218, 0.05035111733201531, 0.03441204902746024, 0.08399605570781617, 0.08580066774400973, 0.0969421602184734, 0.06873710877111844, 0.15561194669815803, 0.13970428416805883, 0.13088388488658015, 0.024774097950167717, 0.07652114430863051, 0.11584592367252035, 0.08088665037986734, 0.06900145507027065, 0.05086536151206782, 0.057209561608972094, 0.032719412232719125, 0.08153014891450444, 0.056691502311056664, 0.002110983764249531, 0.05609524841870993, 0.0711305742903102, 0.036169140629710696, 0.057379679093437816, 0.04543025114182984, 0.0719882480259384, 0.06677179447104854, 0.053632827325453686, 0.05335775962580116, 0.022957421944386536, 0.049661036821142326, 0.026637449777955492, 0.23726810941532736, 0.050220572119278294, 0.11719471339376704, 0.06561221314534064, 0.07864558273145268, 0.41003921519844766, 30.67458998772406, 104.9731848316808, 99.10946107679798, 110.3871774673462, 90.52042745774793, 52.22970070377473, 26.85007706765206, 66.35202976965135, 109.63995026003931, 115.29800061256655, 126.03841504743023, 40.13168727197955, 0.8102763660492436, 0.3788675878557467, 0.09630557945779256, 0.022321164855853688, 0.20055297792198198, 0.1552257158102528, 0.31700234139157885, 0.22963171434258262, 53.78377514500772, 128.74044172225462, 101.67957844272738, 107.35582074811383, 91.86545525827717, 84.13873903213009, 83.66177881917646, 87.5504558317123, 87.59219769508609, 89.17215977945636, 80.92445865754159, 81.12464074165591, 80.24802238710465, 88.14370647553476, 95.83072831553798, 104.5621047481414, 100.78539571454449, 104.22230982011365, 106.04873011189123, 101.8738926610639, 96.86941900560933, 101.42849968325709, 95.756454313955, 107.52169778270107, 108.09474037539576, 102.94448006537654, 88.27658068749213, 80.81058440669891, 87.43283963972523, 94.66285828621157, 82.1438450967112, 98.00547076809792, 99.0275933665614, 93.02093059785905, 71.36674865599602, 76.54798000089585, 87.54935756806405, 103.45639644130584, 127.77939827211442, 117.28037434239542, 113.15935965507262, 105.4619513788531, 106.55282528169694, 105.31541947395571, 103.3008901534542, 96.14672230136011, 93.44275013093026, 96.79344269537158, 103.38492301202591, 95.06246151462679, 101.94604858275383, 107.8983316113872, 105.33169731017082, 105.22765251897998, 99.22742243736022, 102.7988895293205, 105.07213838638799, 104.28283983661284, 99.48898176993094, 83.19120422486337, 81.59298742971113, 81.44298030484109, 78.04719617289882, 80.23251333544331, 79.65841170280211, 84.15712710349791, 85.47405504411267, 81.95168818196943, 81.47643027767059, 86.14711807620141, 87.83415302153557, 97.57976024381577, 96.93660136192076, 73.03689387536818, 22.92057602636276, 1.808160555458838, 0.4108798894430361, 0.0812943087470147, 0.3121813500840818, 0.04680999081521746, 0.0630989812705065, 0.17805300622938142, 0.05539956397467083, 0.32986998317703126, 2.0836414829377206, 70.46703538587018, 99.41912435716199, 102.18945518616708, 117.24222537009948, 111.94510367608841, 47.41902743616412, 30.50638306525446, 49.19178970398442, 55.53475649126115, 78.75519183374222, 81.58658612158992, 100.2211941442182, 57.541876454507154, 8.097527296312395, 0.40303242182539356, 0.09534282910247004, 0.10186808258895913, 0.03680512001137099, 0.06838470066507017, 0.049487215301562706, 0.013774051161993657, 0.05951190480001031, 0.07087791849288248, 0.046602626135873224, 0.01315684284969804, 0.044807555724776564, 0.05196154140116227, 0.05807144882818384, 0.10322532992088988, 0.0557179692681999, 0.03304671563748871, 0.05089235845051947, 0.05236711600915559, 0.07223124345464092, 0.06884168743366195, 0.005581743429384885, 0.02792907210307256, 0.049358432091051535, 0.1931533193395984, 0.16273664100275886, 0.09991691793285071, 0.07523337349055276, 0.03658209266441484, 0.2818020108726717, 0.19704863128642883, 0.18421230717532097, 0.13348498321588964, 0.21870284191062375, 0.17604973227266343, 0.11989263757582634, 0.13329225081589915, 0.1411761842187374, 0.14096865100004982, 0.11475673050529535, 0.17146120268491008, 0.2275964332323882, 0.1304323679857677, 0.1509322373256568, 0.3303122304139599, 0.19294883515084946, 0.12631592475959372, 0.17398875657348864, 0.13747977934056713, 0.17928885926883067, 0.20171281971758415, 0.3565373812471667, 0.1871410919533622, 0.20808775909245017, 0.27775820044259875, 0.2730319895330937, 0.9107838535020429, 36.8396145297635, 129.2070233437323, 106.93558585259223, 109.577482592675, 77.2955523767779, 39.429586933505156, 61.47917516769902, 156.56143680695567, 135.9111462869952, 127.22083707009594, 136.63570219470608, 56.73121667677357, 2.962451952119028, 0.6639298544295373, 0.7242104939876065, 0.40193495490858633, 0.49330126674425223, 0.11238601013657548, 1.0270757552596832, 1.4878327183185087, 52.35717381200483, 138.51407820178616, 109.04251836961316, 115.04638056601249, 99.18336637558477, 92.28819262596869, 89.26027974774762, 95.14960089037496, 92.14620282573085, 93.30478468248921, 85.06673259119835, 86.18062296221333, 88.18122002386278, 93.4691555269303, 99.48274520135696, 106.73843183825093, 105.86252735507105, 108.61111256384082, 108.63052045145344, 105.07711195176648, 102.93897305765461, 105.81106585841026, 104.94551643248528, 112.93077961091073, 114.96838815750615, 109.98250653666835, 95.54165747857864, 86.70047037063107, 92.04651971017161, 97.74613149704473, 89.7704153676187, 101.73410723286291, 104.79592507885349, 98.14264389776416, 77.8928509066182, 83.06282504912346, 96.86581826979115, 110.26920826204362, 131.96070763372606, 125.7294499489569, 121.12974920580466, 113.84176577291181, 115.62201976776124, 113.8545056312315, 115.03499000303208, 104.69493973639705, 101.45161028831237, 102.0663712101598, 106.69665859591578, 95.53032182878064, 107.06867187253891, 112.40695491913827, 110.85173514581497, 107.46337998297908, 105.93370268421789, 108.6529407193584, 112.28375327202582, 109.98752717048892, 103.90415853069675, 87.97718617223924, 86.7332378510506, 85.32328697942918, 81.72131169226863, 84.00286812936106, 84.89745093930154, 91.043514743928, 93.21912011792584, 88.60238059874504, 84.80445154251592, 90.54088654056673, 95.70923682182067, 103.22145431272446, 102.16536398856871, 77.81560374844459, 20.591529492409002, 2.4283403542733963, 1.5853530144499195, 0.2847723176162089, 0.20299260023861163, 0.36188767802330757, 0.2094239390064632, 0.24105411593712148, 0.24272650119758424, 0.4905982940427719, 7.191567161390859, 84.64448159740817, 113.3994322438394, 107.49651616619481, 120.69601351214995, 147.53094826975178, 127.79839823322912, 71.36787045386531, 32.96308117528116, 39.18634899200932, 78.05022424267185, 91.87746555574479, 113.93873460831182, 65.93420320941557, 8.857843452884305, 0.7709240228418381, 0.21911993082011902, 0.1720594407449807, 0.25309554721799593, 0.25450931651698006, 0.1203965625515388, 0.18511881901612207, 0.1378808876559619, 0.15202043457858025, 0.11125906415644193, 0.1318807184936539, 0.1625895674430555, 0.16944052321055245, 0.1790491810008403, 0.20056961735169734, 0.22256295977821275, 0.13067529446655704, 0.11620351053293675, 0.1529356032129257, 0.12815711749417166, 0.20475135425165777, 0.2296886040318397, 0.17139568684562562, 0.16904771928825688, 0.19602181299799876, 0.2192912434017466, 0.23082143356723173, 0.2423323796040589, 0.19440142978583613], [0.039804040138880094, 0.025797535875631918, 0.05537358593315848, 0.03649610312535398, 0.10739535333648806, 0.11454818605054772, 0.07477247967354714, 0.03970386265146156, 0.06413238025420616, 0.033666825507797545, 0.052677580801349495, 0.053981002795720295, 0.04261882337290914, 0.048796824525080384, 0.019628819709102956, 0.07789434925202401, 0.08961499653636448, 0.04301162346476509, 0.06267819215633696, 0.013854763312866131, 0.09235611275559472, 0.13317142342848162, 0.2058566965523266, 0.052920181694771015, 0.26390999675758425, 0.82685352813813, 8.683553914869986, 43.89460525205059, 92.34076807575842, 86.15595125382947, 86.20363943038448, 66.62729386360415, 40.80502094761018, 43.51939524373701, 110.00742143200291, 96.55792005600469, 111.55246657709922, 112.99698921941943, 46.5808718435226, 1.7493156872449385, 0.2643392817868341, 0.10964772078178583, 0.15230269201340216, 0.1822442579413614, 0.09099683529066463, 0.3317948250520614, 1.023172813077127, 12.077712224375817, 116.34879573698967, 99.00953477428806, 104.28964122649163, 84.0719332233552, 78.63839933949133, 80.98463566072526, 85.77121380836734, 76.15589987847113, 79.66999053955078, 76.06315935811689, 84.07191753387451, 82.42172148919876, 78.53186776561122, 83.70564660718365, 96.95719380532542, 97.20110247212072, 104.84046751453032, 104.53650736039685, 106.02994980350618, 100.33429961050712, 102.22838078775715, 98.73661625769832, 96.46638762566351, 97.13914471287882, 100.91668528895225, 93.47379176847397, 78.16575373372724, 75.06195868215254, 88.89822929136216, 98.86235175594207, 89.12429901861375, 80.64302075293757, 99.61713344820085, 93.11246302820022, 76.63854752817463, 60.019155240828, 76.88244835022958, 81.19377643831315, 93.60271223129766, 97.40217101189398, 91.68453201170891, 90.28362612570487, 96.2406316880257, 94.07864478326614, 83.05157569146927, 82.74984344359368, 84.34773075965144, 94.79328493918143, 100.5939369816934, 96.85262341653147, 91.83383310994795, 99.3035948661066, 104.29182990904778, 97.51138548697196, 98.22731218030377, 96.058468972483, 97.52200726539859, 100.66221760165308, 98.95368022303428, 84.72250538487589, 73.47208869072699, 76.50330420463317, 81.85619415775423, 78.33353704021823, 83.36141155612084, 83.27995961712253, 83.12827371781873, 86.08165371802546, 85.6577161050612, 87.923779179973, 86.37827903993669, 86.74136500204764, 99.75496553605603, 85.69099349360313, 53.56581687927247, 9.412553867986126, 1.1886777127942731, 0.28480486103123237, 0.12057706052737853, 0.33014565225570436, 0.07245180782892051, 0.04380387712209936, 0.06734459075115382, 0.09246249172476032, 0.17181895042379058, 3.901861079277531, 62.90646291548207, 86.05786062056019, 104.42365292579898, 74.74797294985864, 109.4943283450219, 142.59772054610715, 38.18594455718994, 31.873460469707368, 52.18913162908247, 68.63406473590483, 73.8537980664161, 81.30131998369771, 75.0499640741656, 19.727194040052353, 0.4432797395894605, 0.031233071424667875, 0.038569604362090754, 0.027009358652116313, 0.08826969251517328, 0.11014619121147741, 0.03604688448831439, 0.02922364769713773, 0.0661831095273937, 0.11302368640298806, 0.026281749409052636, 0.022872298084680113, 0.10774446726446191, 0.005225292294316235, 0.030183523307524385, 0.011618530636863604, 0.024500775015762737, 0.011157237496527453, 0.05909853524738743, 0.013195628923694453, 0.03327518220870726, 0.029517174285325794, 0.020586048485711217, 0.06720236652801115, 0.07043131987654394, 0.09540783932372447, 0.09029704461535139, 0.09877579166523873, 0.10996670447169773, 0.06488293574582185, 0.012266661130612897, 0.01430750308152769, 0.07816520729853262, 0.12612274802860715, 0.007124766125343741, 0.10003757678092488, 0.033561557366122166, 0.08781085947468396, 0.031322102332788135, 0.019691966421481584, 0.04743503812219828, 0.044581770461293004, 0.044098560503053094, 0.02934213085550695, 0.13466627547337165, 0.03868570498701546, 0.06106957222425169, 0.04476569668059388, 0.05693507996658164, 0.07411168287357978, 0.22745320543406472, 0.15299146634436425, 0.29339497428267236, 1.2020844966173172, 15.185756183439686, 66.65566044469034, 118.2748991443265, 111.19471503842263, 117.72236270289268, 93.7967283495011, 65.45846285358553, 30.670043960694347, 71.90281114270611, 101.46865690908125, 121.9059156602429, 120.38911942512759, 51.99693549063898, 1.7099100856050369, 0.3387373283265099, 0.13763083655747677, 0.3102274887984799, 0.19350015798643713, 0.5175731078751626, 1.0173553865282767, 1.485803994920946, 18.235650024106427, 126.62107529178743, 101.60552409387405, 110.97341491330056, 87.91129035334434, 85.16524684044623, 84.98691235819172, 89.04426697761782, 80.58077273830291, 83.18435576654251, 79.09391987708308, 89.69206994579685, 86.16086990602555, 82.49161812566942, 87.28447206558721, 101.78214842273344, 99.72894453233289, 107.1558112482871, 107.12775061207434, 108.5960820413405, 105.84292334894981, 106.0778497880505, 103.63027511104461, 104.92460235472649, 101.92384012283819, 104.45254510448825, 95.01951940598028, 81.65969125686154, 77.4111524704964, 94.54903110381096, 102.42628005243118, 95.24614610979634, 83.1225392126268, 103.80660918451126, 97.15764261061146, 81.07725850997433, 62.742731417379076, 79.6418514559346, 81.84637254284274, 89.24230744761806, 103.38943373772406, 97.73834951462285, 98.86213994795277, 102.00714342055782, 96.64377289433634, 86.91454548989573, 86.4804018697431, 94.11538170230006, 98.38873340237527, 104.04577178339805, 100.9168343390188, 92.03330916743126, 97.38637954958024, 108.60826492309572, 100.22872509494906, 101.68396365258002, 100.66355905225201, 101.40198446089222, 103.05266687946936, 102.18820787245228, 92.43219067973476, 77.34805722390452, 78.31219150174049, 84.76023074119323, 83.48136548073062, 90.48780118265461, 88.95572339334797, 85.74050949465844, 91.05045733913299, 92.26162249042143, 89.84868234203708, 92.74801208126931, 89.33919783561461, 101.03878867241644, 91.34870652229556, 62.55263766934795, 12.611723311485784, 0.9000306756746386, 0.2452956996257267, 0.18137635693194407, 0.9098281434947445, 0.1863567251712084, 0.06128109293058515, 0.27913964083117826, 0.07916928043649082, 0.12376416249260788, 2.149889334555595, 62.68430771366243, 94.24414527031684, 104.83958105887137, 84.40797836549821, 116.73256043464907, 101.15470255574873, 20.815086941565237, 39.226239496661776, 79.25800831087174, 88.51706904749717, 82.06375029779251, 93.0447707637664, 94.81830181614046, 35.62923385250953, 0.3918921244480918, 0.061101265281679175, 0.08778023894035047, 0.02922143178781675, 0.028252252039589712, 0.11769814807320796, 0.04767213084344422, 0.03148266095517865, 0.030365270006680684, 0.07687373627578059, 0.015697294786091776, 0.056306370759322766, 0.06466081621305597, 0.033032738363310214, 0.0976097445574499, 0.04630063427612186, 0.05246151719362505, 0.024988510638415336, 0.14582244619246454, 0.11076813969280451, 0.03320018986179944, 0.013823577788688484, 0.02061601209964964, 0.11148652332204004, 0.10323584830809025, 0.05337456376442025, 0.05876652806276276, 0.03885315265506506, 0.17492568210488366, 0.1783724342502894, 0.14416571976917406, 0.17586744931196013, 0.13153064695577468, 0.28091561650076224, 0.11862884530977857, 0.120747706612512, 0.19544006115005863, 0.2157323513059847, 0.1445979618978116, 0.14138495849986232, 0.1100998352311792, 0.142440949416449, 0.14972069991692422, 0.2032414715616934, 0.3060307365752036, 0.20088028132675156, 0.11853897553538123, 0.13267921193713142, 0.15066347836006075, 0.23676091324417825, 0.3120626370993353, 0.32772570307697024, 0.30702266721956195, 2.7660978561447513, 21.968824671160792, 82.5859275940926, 143.1897944788779, 113.69608109997166, 119.42665607698503, 88.88052371240433, 53.43654732550345, 63.45859143041796, 166.05573777229557, 121.36334203904676, 132.65786970815353, 132.15670062649636, 69.1009444575156, 4.724166374052725, 0.6732231751084329, 0.8701517144518515, 0.5472822427268952, 0.39766839675364957, 0.37133617747214537, 1.4494231535542397, 3.2977694945950664, 16.863453926578647, 133.28565289897304, 107.81862904948574, 116.71657285382672, 95.67962292701968, 88.80464938379104, 88.51143652392973, 97.99505295292025, 87.1950263361777, 90.24786979921403, 87.19090784749677, 93.17190262579149, 90.89223677112211, 88.92336383942636, 95.60069699441233, 106.8876309548655, 106.89350666538363, 112.17057720307382, 114.22829966391288, 115.36310411268666, 110.42447136294459, 109.25704063907747, 110.50816689768146, 107.17624679688485, 104.4200521899808, 110.40635001274848, 102.00158934439384, 88.19937275302026, 84.06428460151919, 99.2353456251083, 106.51777498183712, 97.25592936238935, 87.35706729273643, 110.04420541947889, 102.99253694472775, 88.6126179848948, 75.52548085489582, 93.21678238530313, 97.53575125048238, 105.8511132578696, 108.89934401358329, 106.74670803931453, 108.22593581291937, 110.15828363357052, 105.91809165093207, 95.63383317762806, 95.06885497800766, 101.44509130908598, 103.26294514440723, 105.78165592685824, 100.76718022746425, 91.67249818002024, 101.41972141881143, 113.54858429201188, 106.35432981675672, 104.25126475672569, 102.54709689847886, 107.48697696193572, 108.44302331247638, 106.3407741054412, 96.44008421128797, 81.55921582252749, 81.99986273242583, 89.23734957172026, 88.66870003361856, 93.5134312414354, 90.9615764310283, 91.33062439580118, 93.90095356971987, 96.78150300056704, 95.76021194458009, 96.26718613409228, 93.72543534924908, 109.24616782895981, 95.33641553694203, 64.65392197332075, 11.601610029897383, 2.4308462585172346, 2.417977942574409, 0.5404453063684126, 0.7814511740880629, 0.4359251116552661, 0.1864228538808323, 0.4419562767349905, 0.2941483451474098, 0.42525151504143593, 8.02326064917349, 79.38161788448211, 101.8942968307003, 111.0067472150249, 82.2022178096156, 133.8303916685043, 167.03940545358967, 52.76946983029766, 39.49678890166744, 67.8282137840025, 88.7415070687571, 89.43555478126773, 106.24866116431453, 110.23640155792238, 41.74102006420013, 0.6417092596811633, 0.11771251222178822, 0.25756240672161507, 0.11663818116029424, 0.21285494038414574, 0.12737172415419934, 0.12796791675951213, 0.18564532060296307, 0.11235588755939277, 0.2383421340416516, 0.05971667244129124, 0.16181804029451263, 0.18770805830436368, 0.12478454564247402, 0.11984261969525008, 0.10531592257921735, 0.19452490783747167, 0.17056815866981784, 0.2464226915711357, 0.12094706567304751, 0.1298628735446161, 0.1655944094302193, 0.2054210529933053, 0.18218896171498686, 0.22994565717395277, 0.32795994212069823, 0.1904689472529196, 0.14534950947328923], [0.02683435161147387, 0.03634588860516106, 0.06953454501326047, 0.03829285892988405, 0.051703607257936275, 0.08303694427013399, 0.02392377099773336, 0.03632588987989772, 0.03798045593524172, 0.07488169316803256, 0.03523141836687442, 0.02373536124885563, 0.043029986592310096, 0.027435140744332346, 0.04071142531991486, 0.03927925458898948, 0.0363481868689339, 0.11002105840992545, 0.044639870569470434, 0.05306642787951616, 0.039124788280816815, 0.024574650789520914, 0.47687061131000524, 1.5940772237316256, 26.97566547701436, 64.43385739480296, 99.44742818032542, 95.71595976429602, 74.3856087038594, 65.8413528626965, 56.41913329401324, 41.30234218412831, 49.211746723421165, 111.32227051642634, 88.90816073263846, 123.09916342458418, 106.26274247323315, 49.337682262543716, 3.72046273562216, 0.19606544936616577, 0.025844225104177193, 0.12989036077933927, 0.12343197910776063, 0.015823207082106702, 0.05724333842555362, 0.4936261493111811, 0.21487925111526446, 69.23989049849972, 117.65670222620811, 97.8294740184661, 88.79449828978508, 78.90501852958434, 91.40248221735801, 80.48642404617803, 80.54309445042765, 79.60612650840514, 84.29964250133884, 78.61939153363629, 82.41410424632411, 79.126969768155, 81.97927028902116, 82.21973511480516, 93.57328661026494, 86.72891539912071, 90.3575941824144, 91.38809496356596, 101.84438859262775, 99.14614308264949, 99.91669270300098, 100.58471941178846, 100.50411470474737, 99.667920297192, 95.34938289273171, 82.65810705000355, 74.47536037814233, 74.1144552538472, 87.12164663499402, 97.72124013593121, 99.81344807532527, 84.61955885733329, 91.73251044365668, 98.42623910596295, 87.02432478627851, 59.99718604549285, 60.27451330615629, 50.520441609044234, 32.69828588731828, 59.4740830698321, 84.9758904980075, 85.26174499142556, 79.92225385481312, 72.75181601124426, 75.79878376376244, 85.55189840255245, 91.83053831900321, 94.70265465397989, 96.58787127464049, 96.59096994707662, 91.79585672193959, 79.69534474034464, 84.4565922214139, 97.17082177439045, 97.89987271831882, 97.39038821189635, 89.59670928216751, 90.50699726227792, 96.836314201355, 93.83575593271564, 81.50504004570746, 70.52206623938777, 77.3382277642527, 77.36850061724263, 87.25387757824313, 88.29245844194966, 95.29293998595207, 95.44165272866526, 94.47021499756845, 87.71878042528706, 90.56199673683413, 93.06567699678483, 98.10137271881105, 100.90986036485242, 90.46240775815903, 49.76703274634577, 12.44766821784358, 0.5636466775209673, 0.9661669848907379, 0.13318437031440197, 0.12133007899167077, 0.07653987515837916, 0.08042238577599488, 0.0728509856027461, 0.023527483290602124, 0.28453280788756186, 3.374259880473537, 62.45732799653084, 87.93363217384585, 94.9274770675167, 92.38885633407101, 125.10496154908212, 119.29710803493377, 57.75251949987104, 23.306980479148127, 50.23009992414906, 66.33167266845703, 66.46277396909653, 71.53642254491007, 86.69945055438627, 27.568510155523978, 0.7257008720790187, 0.0867794446587082, 0.07443068188525016, 0.08809754489770821, 0.012940701675571263, 0.041119049213105635, 0.05034000905711324, 0.04426469816075218, 0.15180248256412246, 0.06129663302412918, 0.019015374803735365, 0.015969422623334874, 0.06873010672749051, 0.11234241973368392, 0.045779169717383, 0.03877046112451823, 0.03552692529234675, 0.07675900694824035, 0.09493874836592905, 0.016848217403035493, 0.01289610673988899, 0.13004835875284287, 0.05886154594801127, 0.035954613028274435, 0.09489865132397222, 0.3002891220873402, 0.04320441715178951, 0.06493788723263048, 0.004543090040134567, 0.05406374029154259, 0.041644757898945006, 0.0988682278341824, 0.07646878219900594, 0.06694456261973228, 0.014824072338430392, 0.09074699103591904, 0.029125958080253297, 0.06588300224393606, 0.04288347227679145, 0.042364348116661274, 0.021784334488573576, 0.02811483118773228, 0.0526250348306231, 0.05047344625176442, 0.05565175628890434, 0.031114749144762758, 0.10674298350368777, 0.03317284818378187, 0.04101247489151936, 0.491076240976972, 4.802442664100278, 42.225095456646336, 83.65385563142839, 123.99937091335174, 116.11033131999355, 97.86536370554279, 110.65960176529424, 68.12492539805751, 59.10001054886849, 38.04521383777742, 71.116791694395, 97.39776226782031, 131.9609743548978, 115.07893623844271, 56.40795061665197, 3.437545116870634, 0.210649082136731, 0.23100541724312693, 0.09617653960782675, 0.3455046119709169, 0.047207310825826666, 0.5265840179016513, 0.60800182002206, 0.2461425791825018, 79.12440453806232, 121.18643529953496, 103.65928496083906, 93.93326605519941, 85.42026365956953, 91.77841001941313, 84.11990381056263, 86.26519710786881, 85.108152820218, 88.30199764620873, 82.8047566260061, 86.04333216144194, 84.54850119929161, 86.07642912095594, 85.64547046538323, 97.94686271298318, 90.90795763077276, 93.01667090385192, 96.16896998497748, 105.97588385305097, 104.47307478997016, 102.75608862600019, 105.31745910644533, 104.24090969947078, 101.92179264560824, 99.11198708318896, 84.09184317434989, 75.52767738219231, 76.41574121290638, 91.1070022275371, 101.91870966265279, 104.11473489576771, 91.16274695242606, 94.21395870947069, 104.20858936925089, 95.56789029029109, 68.14889107981037, 65.03519204355055, 59.00348101892779, 39.99596541927707, 61.27792619889783, 91.71922145351287, 90.69023470724784, 82.65012110433271, 77.788115778277, 83.02522520865165, 89.15089268838206, 95.2758070730394, 98.86865892717915, 99.40467434544718, 98.0936142706102, 95.12673347227036, 83.92788810114708, 85.01523971557619, 98.03954047541465, 96.91652667137885, 98.03081712415143, 90.19510607565604, 94.22305860827046, 101.22771355413623, 99.6948120670934, 86.76193391123127, 73.74094363181823, 78.6636515586607, 80.69318002270114, 88.06404313733502, 93.08624590596845, 100.98292627642232, 100.07062219804334, 97.45549171201645, 93.60930181318714, 95.33967110418504, 96.49273810848113, 98.29263533315351, 100.57585485519903, 95.27799575559555, 62.108837173831084, 22.3411262419916, 1.2698507957881497, 0.9984949147028308, 0.3396604029882339, 0.39883772271775436, 0.5891454544278883, 0.10360583813200075, 0.25905468471107945, 0.05469574750731549, 0.23796385514640042, 2.3225633463551922, 64.83439022494902, 93.84564030554988, 97.36529288753387, 92.52206002512287, 124.95820214671474, 69.76104797855501, 31.02646189351236, 42.583568711434644, 71.17761981102728, 86.97871546591483, 79.19014346215033, 79.19857655802082, 97.3960756486462, 47.923393249511726, 0.3206681946833288, 0.09034075759231083, 0.12218913168556268, 0.0744024285626027, 0.0859770211841791, 0.09384880443253825, 0.04098344398962875, 0.02990407166972516, 0.048601832165713274, 0.05685122781282952, 0.02596625716485564, 0.03665841417387128, 0.06148734678243918, 0.05284238163562072, 0.03157124753230282, 0.030281528935677586, 0.05242446535116723, 0.047941797623230566, 0.047112959437072284, 0.06447449596899171, 0.022292189495337587, 0.12156030373467554, 0.030103831011201107, 0.07848859599400913, 0.09820101887828882, 0.08544688067969777, 0.035090963806836836, 0.22189730598080545, 0.14236336003147787, 0.2124637912117666, 0.13663818579046957, 0.21513687116244148, 0.18307279735322923, 0.10739985027260358, 0.155515618802559, 0.1814502997383956, 0.1998651688618045, 0.17659796011303702, 0.43180122971534735, 0.11612897017790426, 0.2593992097723869, 0.09326771142021303, 0.2473738969814393, 0.16107933235264596, 0.284710478998961, 0.23649665887557694, 0.21100436307249532, 0.16032720255034585, 0.12987726067583408, 0.4903860876877462, 7.540965522489241, 54.92269808246244, 108.32394015404486, 143.2443468032345, 132.7637109448833, 96.42211975589876, 90.72865824545585, 78.42015081836333, 56.89584639764602, 70.71863189820321, 163.96877011945173, 113.47192548936414, 144.88278358213364, 126.15081448708813, 78.5069058018346, 8.620782263817327, 0.50928290272432, 0.5834274967351268, 0.549164796548505, 0.3873213068131478, 0.1514934733389847, 0.18232759298576465, 2.5871796761789634, 1.1037967642468791, 83.73162838720506, 129.10049961459254, 110.888793699203, 98.78724621188258, 88.62339665812831, 99.41251908579181, 93.02593554219892, 92.81192318085702, 90.14658635662448, 94.58708593922277, 88.24923392265075, 93.14507361381285, 90.44148583565989, 88.56606729568975, 91.80232863272391, 104.94426911877048, 95.74085897014987, 99.91521789181618, 99.53935284768382, 109.76218700408937, 109.91989766397785, 109.06559759570708, 111.84413402311264, 109.757762570535, 111.45627437099334, 106.53705735360424, 93.17619369876002, 83.02407203182098, 80.62145556173017, 97.04626298719838, 108.12187533224784, 109.14628075015162, 95.75109635629963, 101.48484060841223, 108.87996750493204, 96.654645704454, 74.08108372842112, 74.54473141700991, 69.9412573537519, 50.26078462600709, 72.86083436781361, 96.79569413585048, 96.81372134916245, 92.85023689270021, 88.24252666965609, 93.1916243030179, 98.41183616269021, 101.88659329568188, 104.03054514238912, 103.96986607582339, 102.7420465407833, 95.17937167998284, 83.1080735114313, 88.05459806996008, 101.95841189353698, 101.01170078400644, 100.59090891192037, 92.292569991081, 98.38405793712985, 106.55767333122992, 105.49538566220193, 92.48048290129631, 78.9736835418209, 82.30132825912969, 84.84686805355935, 94.10010799284905, 97.86992149968302, 106.33961308387019, 104.50427332232076, 101.94869226024997, 98.86207719003, 99.45480223624938, 100.39757528612691, 102.22035561838459, 106.78715552053144, 98.08094501495363, 62.378860981233665, 20.457649192502423, 1.4198446826588724, 3.2502825846595154, 0.9192445898248304, 0.4074114723311317, 0.8107996347450441, 0.25018114957117266, 0.41565133018359063, 0.16983446094297594, 0.6281722409109916, 7.610390493946691, 81.83309139743929, 101.27559000445952, 109.45352785048946, 96.19625399189611, 140.51917814439344, 150.1145350548529, 75.56394361680555, 30.066501017539736, 64.32592161240117, 87.02361091490715, 83.16129222992929, 88.904826717992, 113.96334355877293, 60.59199387027372, 0.9667218164090188, 0.21368928674247958, 0.17417499254788124, 0.21903737718539856, 0.18694714913445135, 0.20832222796255545, 0.07195151410996914, 0.11199111479424662, 0.17848059054343932, 0.20244896892578373, 0.21369377601771586, 0.15881162016622483, 0.19063763981384618, 0.19828624632810393, 0.09456318908280904, 0.14821743622662562, 0.11427689899480152, 0.1250068643581002, 0.24556566901024313, 0.19515878430777983, 0.17189873082022514, 0.20570193146986349, 0.16573031342798666, 0.12753659393638372, 0.23871655185376447, 0.2814272100165967, 0.18269652560833963], [0.061159254307107586, 0.09587899105803621, 0.027384540636933623, 0.011884825672173213, 0.04566379304554674, 0.013648421360900807, 0.09324745605549506, 0.03784727154960556, 0.05336199992246205, 0.06546321670494734, 0.02084894304824693, 0.05354524815394994, 0.02683191928231428, 0.02865597079958647, 0.038507850014514504, 0.039567882044901775, 0.061987858836448965, 0.040389327482590755, 0.036769971897405, 0.028169640948274927, 0.044333500517231804, 0.5460115173651326, 30.10879005155256, 89.17352476427632, 121.85087696198495, 114.70345558658724, 102.49787899755664, 80.51115851248466, 82.60935983350201, 45.93189608666205, 82.28457973849389, 61.55188022121307, 96.0958020917831, 100.76459146315052, 121.81306531352382, 107.38985907646918, 50.56175985643941, 3.8804172363973435, 0.24051033140670872, 0.11787479262678854, 0.07906763589069729, 0.06710118163497218, 0.19741554143688372, 0.055983909030234626, 0.3099172844761803, 1.5993800230564612, 4.223507690814234, 113.01788760769753, 101.39877596209126, 100.78004560162945, 88.73243070417836, 84.80291397340837, 77.25818003377607, 80.57680329968854, 85.98320222670033, 84.509199050165, 80.4814975492416, 82.61919713789418, 78.8002206433204, 80.77573807008805, 84.24430570294781, 85.71690467096145, 84.2508089926935, 81.05071975338845, 75.57241593637775, 86.44095067054995, 95.19423746293592, 91.7823794580275, 90.96651861744543, 94.1364997433078, 99.92750275519587, 93.72038333646714, 87.06074791569864, 74.54681027320125, 70.99923041559035, 71.0077262693836, 85.73825805417954, 99.29543633614817, 99.40249350763138, 88.30422555246662, 82.2987473395563, 93.25719848755868, 93.63449127443376, 81.93569275640672, 78.87596945608817, 78.26470728843444, 66.77386499220326, 47.98110308185701, 70.5766656321864, 81.34126540153258, 66.11338492362731, 63.875174599309126, 70.01888105946203, 83.12226464671474, 87.02881197775565, 91.4912219201365, 88.81746768951417, 87.65251590359597, 91.18180182672317, 95.44716758112754, 92.07222692428097, 96.11219759910338, 93.57690303556382, 99.89624146492251, 94.59341664468089, 93.67806880704819, 92.83502594117196, 91.86141521699967, 81.73107839399769, 74.74681192828764, 72.45974848347326, 76.2347081399733, 82.27429528390208, 88.49206786001884, 93.94090683229508, 96.7449700447821, 96.48352838331654, 97.47085171361124, 96.5656392805038, 96.6429413518598, 98.66526834426388, 95.15121690688595, 92.61718534654187, 98.47966178770989, 81.8415637170115, 39.81703865912653, 0.9085868359092744, 2.0808340464868853, 0.3564163087116134, 0.07588860849218984, 0.12369741325176532, 0.08463963851212494, 0.09095282353941472, 0.03676102782088903, 0.3100214724338824, 6.44472973961984, 61.00387803969845, 86.27527759921166, 96.50510141926428, 43.70209924636349, 46.446856221845074, 69.52290519591301, 48.34678173065186, 24.04591187354057, 36.0082564046306, 50.94417133638936, 73.70917243342247, 72.87629635103288, 81.3265565133864, 30.671314808630175, 0.4663574335075194, 0.15371770237482366, 0.07556535003166046, 0.0985305056336426, 0.06755819904708094, 0.020566132114899736, 0.05935042878733047, 0.05248988925990078, 0.06176272091726142, 0.07133207073615444, 0.061678140979981234, 0.04255611141542754, 0.06937117676340765, 0.062131825909619375, 0.0780581771546314, 0.02783557298713394, 0.017844698609664075, 0.026173658233376283, 0.03215808045840071, 0.06447224367049433, 0.01811134508780895, 0.017586377592036323, 0.057473628286031954, 0.051467119746150515, 0.0558653530935126, 0.08826274409770005, 0.07606808757109028, 0.16238214147667732, 0.03309846487677386, 0.019632642487845114, 0.04100386023281082, 0.029028888994587526, 0.03746763667872837, 0.03039705116421946, 0.06257978816246314, 0.03961595406215038, 0.03207424554162689, 0.019476755086572903, 0.06892634014929495, 0.03256985654814109, 0.046499522192583936, 0.03414397571055639, 0.09844208376542216, 0.024137967266142372, 0.054325374639442855, 0.11303078037716689, 0.08879520584859195, 0.2680755232370669, 43.065851580712106, 110.43012742073306, 140.03890745101438, 131.14963992949455, 119.93885486356675, 105.15879923297514, 122.51604034054665, 62.18079305464222, 72.09685079513058, 39.710471783914876, 55.775656700134284, 99.09541114684075, 131.9540709833945, 114.66679711495678, 58.28608343678137, 3.1969403115011032, 0.30913719246464394, 0.1654945575301686, 0.05800620878055211, 0.25380160449252975, 0.5084706963069978, 0.5218115965685537, 0.6379528547967634, 0.864396371668385, 5.618528550670994, 120.43749793883293, 107.56217664287938, 105.96172409672891, 93.29562202576669, 89.37838231363605, 82.44587544471987, 85.8739406831803, 89.07800720584008, 88.83053702692833, 88.17685834823116, 88.82141359390752, 83.45421483439785, 86.51331840022918, 86.9810296643165, 89.83839004270493, 87.35329397263067, 84.73226424186461, 79.8709100292575, 89.88846302032472, 96.24737031998174, 94.83516016314107, 94.84025139962473, 98.97361370825, 103.93447060738842, 98.23150911638814, 93.17022385135775, 77.52269683345672, 73.66129598309918, 75.8297626433834, 91.11236802993282, 102.53713407824117, 104.14667867845105, 92.14654014956568, 84.81239826448503, 95.37961652201992, 94.75727758099957, 88.40500693167411, 88.51500588078653, 87.85208609796341, 79.96188548303421, 57.38843333336615, 74.79655542681294, 85.56466963983353, 70.28908529589253, 68.47592261529738, 77.28936287664598, 92.44291443978587, 92.24460724861392, 94.03673818034511, 92.38054875404605, 93.27521001138996, 91.32494480379167, 97.62989597935831, 99.78630527373284, 100.31644498148273, 97.27028523722004, 102.02116197155368, 95.81485840582079, 96.33712983900502, 98.29367083887901, 97.39188655730217, 84.6838935728996, 77.57330325341995, 73.92395357931815, 79.72400942156392, 86.80227156608336, 91.99906687582694, 94.97185476364629, 99.64109128521335, 97.62306321051814, 99.42191708472468, 98.73694573679279, 97.38575197035267, 99.94175664840206, 96.60216439154841, 93.8854366733182, 101.42506368698614, 90.19919318537559, 54.86620418487057, 4.315786352080684, 1.2244748564497119, 0.21999062038958075, 0.24482666995496521, 0.3782272609251161, 0.08598944713031093, 0.21422498138441196, 0.037698646661855524, 0.33134926831529987, 4.982072509104206, 64.47560318054693, 90.07746634944793, 103.21295061419087, 51.87545968640236, 47.52351545518445, 35.35091030982233, 34.245080409511445, 47.016388293235536, 55.45676016038465, 72.05954905479186, 89.86585447865149, 82.50496202899565, 94.084332220016, 48.716571023387296, 0.4088770598173142, 0.09132612286315811, 0.01850802733022119, 0.061610614159895535, 0.036477594441103364, 0.09572270146060376, 0.027389144825358546, 0.05260161169233823, 0.04580866027202818, 0.03870432858445472, 0.04182778013449523, 0.05194786290127424, 0.07951473246418661, 0.08866764454832, 0.08208169391559017, 0.03433914427014609, 0.024718857265167662, 0.0469783386365781, 0.04794676187297991, 0.04095053285240166, 0.03482984273784584, 0.05076197411624655, 0.07205744874813864, 0.040450185507295594, 0.09313016799428771, 0.06745260914847737, 0.1640454409343581, 0.2323728688662091, 0.14544001510066373, 0.0783477583900094, 0.20127487789478996, 0.10472408901419371, 0.1383243453118109, 0.07217435376538385, 0.19777325853224725, 0.150635531472583, 0.1832730220931192, 0.17379489036337023, 0.16671954744285153, 0.114982818373509, 0.26992326602339745, 0.1902056428333444, 0.1875047998562936, 0.08031917074995656, 0.08014256450077219, 0.20121811077960078, 0.19010746100496864, 0.9137142930300006, 56.79527682642783, 132.80530375819055, 161.41833520704702, 139.4319755800309, 128.10836745846657, 104.47927997958277, 114.53117724387877, 56.99231316966396, 105.28440137063305, 81.31335381538638, 140.67464520854335, 127.3124401031002, 145.7086778456165, 125.2370983554471, 76.29792105767035, 9.275165007960412, 0.9708988342073657, 0.4242707386372551, 0.16918423615636366, 0.41003486381903775, 0.5812207957909954, 0.21007545082078827, 3.9161909684058163, 5.022287099592147, 6.146526644306799, 126.41584903963151, 114.85251349787559, 112.08426936980217, 97.75786722860029, 94.70794985371252, 85.16015560396256, 89.88766285680956, 94.65564896983486, 97.75934203978508, 92.18879192106186, 94.784192885122, 86.16303505436068, 92.4578586701424, 94.41864367454284, 95.90255475813343, 92.64690122296734, 89.00477655472295, 84.97986778136223, 95.99273004839498, 104.67062888606903, 101.80663185734903, 101.37150764465333, 104.61501752176594, 108.32806648746615, 103.96214685132428, 100.64639476037796, 83.13407098093342, 78.06087740005987, 78.40959964259979, 94.13748033585088, 109.35296612401163, 108.12182826380577, 97.46132819883286, 90.05450479445919, 100.17618102412071, 100.67070561070597, 95.73722685537031, 90.18094631933397, 91.90900141193022, 80.76946227781235, 64.65763645787393, 83.99996557543355, 96.44414778678649, 84.66261863708496, 82.75045533334055, 84.05137215891193, 95.21259415534236, 97.23204212803995, 96.55086763443487, 94.66776124892696, 94.64982817249914, 92.79764575342979, 97.79207029650289, 99.62526059919789, 102.95849077163204, 101.26030060552783, 105.17454362684681, 98.35362818933304, 99.07637980676468, 102.06165652121268, 101.88422418409779, 89.83489913325157, 82.49802727853098, 78.01666444347751, 84.30871102117723, 91.35539808580953, 96.46719563391902, 102.4727915179345, 105.29845914533063, 103.54675216059532, 103.9946162316107, 100.99696836163922, 102.89939634261593, 107.41726075449299, 101.8901155840966, 99.76142960210001, 102.96082850425475, 91.84941276427239, 50.33741989443379, 2.5788434138221126, 4.764075509963497, 1.6331662165541805, 0.18271223041078738, 0.52706248577564, 0.2606505377879066, 0.4586603336276547, 0.1883566589845765, 0.6753185787989248, 11.510819908111326, 79.25634522591868, 97.45071426514657, 116.40741163684477, 60.908505608958585, 70.40554831104895, 97.32195854187013, 61.39238488289618, 32.141456411730864, 46.620107312356275, 68.76457768101847, 99.04118830157866, 90.12609589484431, 105.19255515067809, 61.03328797125048, 0.7114703905197882, 0.18302678611249695, 0.14403779840757772, 0.185019365481792, 0.1558138261879644, 0.14486118970859438, 0.2119397257845248, 0.1946398363478722, 0.21592385796529634, 0.17526139715506187, 0.3051644443504272, 0.2436724206012103, 0.14940329436813632, 0.22401429802900363, 0.2519359812140465, 0.16723445045851892, 0.09704676186365467, 0.16246065016715758, 0.20470632360346858, 0.17008648854830574, 0.09433343165343809, 0.18416686283965267, 0.12233103415177715, 0.1437204388240653, 0.1891884159657263, 0.26692718808208743], [0.05614894352132275, 0.02696961401060464, 0.031101191303722804, 0.07401278092255516, 0.08025196185635944, 0.07499942556023598, 0.0052262996999366635, 0.035154085621357925, 0.04638436002536647, 0.06338577777627977, 0.032311501056556745, 0.034212590375494574, 0.10358266397229127, 0.031039927252418095, 0.023873555849516587, 0.04479851971770968, 0.02575989606069221, 0.011251674112563413, 0.034822162706404924, 0.16294245818449607, 0.5509494136898749, 65.93037497612738, 115.71693328119095, 104.47468296174081, 96.74376195476901, 72.70228432070824, 76.61750008982997, 64.99881990494268, 40.87091284413492, 81.16676699730658, 182.82474886986518, 129.47805127789897, 90.2807314165177, 115.2302848139117, 114.6821649612919, 62.06511843589045, 5.170690465357996, 0.28085990658690857, 0.19103497897665347, 0.11516728468479649, 0.09164246354973124, 0.06221686933009375, 0.402254720008181, 0.9894158534945982, 11.823272974260393, 1.266727853686579, 16.0512722692182, 120.78809507431524, 99.91786941405266, 105.4961544467557, 93.63900984487226, 92.78778491481658, 86.87110131786716, 85.997330604061, 80.26026802678263, 84.16732526594593, 82.44688741622433, 80.85262437020579, 82.32119114168229, 76.8952823454334, 75.94349568889987, 75.85487365722656, 78.77146182521697, 73.72507372210103, 71.3447206251083, 71.50713028446322, 75.80438490836852, 75.91883182525635, 85.20341150222286, 91.50183585382278, 95.8457431485576, 94.09203575503443, 83.95805112777218, 70.62281623963388, 68.44750896576913, 78.49279311395462, 90.66105227316581, 97.21607023669829, 96.04075554878482, 88.28969709334835, 74.73762573734408, 85.81553659131451, 88.5584500528151, 90.39825347162063, 93.19889637731737, 91.88013276746197, 93.64078275619015, 77.93260020594444, 63.13428986457087, 71.42497231883388, 49.48981531204716, 56.93663512506793, 83.24932590607675, 89.85101222991945, 83.25080856200188, 88.52979321633616, 87.68952738854193, 91.98115733362015, 87.95056112350957, 92.8430275763235, 102.89586620946085, 93.41191245663552, 95.8472179597424, 91.44298461175735, 94.79599137460032, 94.79899591015231, 93.48264848032306, 92.95232834354525, 88.90634859761884, 75.26068164456275, 71.22439799770233, 70.24570388178672, 72.51231608852264, 79.50146198272705, 89.470001036121, 92.17886832452591, 92.55609835347822, 94.03484759792205, 94.24048177657589, 94.89143048563312, 96.53643331220074, 89.58871549175632, 94.35186924472933, 91.64833637975877, 95.36626477395335, 98.85452270507814, 75.3283582195159, 6.560717167392855, 1.3222836919369236, 0.6475598425153763, 0.02987336112006057, 0.05759459739971546, 0.1369591766307431, 0.08708155909252745, 0.05103895320527015, 0.13508089757975072, 11.787735319906666, 52.25717298446163, 73.60651616127261, 102.53428643749606, 59.88271951675416, 51.733532644087276, 80.96150152144894, 29.391829813680342, 24.08241148917906, 17.916398509856194, 45.620283388322406, 70.65882359781574, 74.36212155126756, 78.12918939898091, 14.372089908969018, 0.5609438580370719, 0.10635900491427992, 0.028340246813792377, 0.15076651718587647, 0.09542146802789743, 0.0817714512888943, 0.0630231845312782, 0.08165160449401987, 0.04037185301703792, 0.05510566583383949, 0.07910992394411757, 0.040286189065344875, 0.053746124068575526, 0.10269918073449405, 0.051198245867365794, 0.030704532043948293, 0.015112918129401102, 0.034029947353466865, 0.04578380071888528, 0.06378779773630443, 0.05722211779005105, 0.01615056219781118, 0.055342758555085435, 0.09585764018758651, 0.02986087771733442, 0.06670882204367269, 0.07730430067186395, 0.04459495866490949, 0.16651981299923313, 0.067046276113439, 0.0498911198378811, 0.01587683036397662, 0.13417571873193787, 0.00536139308091914, 0.004271430474135184, 0.040079977348326676, 0.04231384377025309, 0.039249480581812324, 0.09072714169780094, 0.029436348178874583, 0.08661072145426467, 0.0817398425011385, 0.0406632537112361, 0.02215346820922869, 0.10604516933521918, 0.8468748989605135, 82.53194009104084, 140.48641850871425, 114.8555023439469, 113.51845264434816, 92.69209477209276, 117.61705490850635, 112.42105976227792, 68.85430582108037, 94.06251599711757, 190.55120621958088, 105.08545875549318, 81.9508566394929, 132.70929982585292, 122.60914171895674, 70.63924312591553, 4.214419068828706, 0.1919006583310904, 0.13136394622345127, 0.17746160167359537, 0.08540237097129708, 0.7806092741027956, 0.5406342542940571, 1.642896146062882, 12.338989146294134, 1.654909140160007, 20.243754502265684, 125.2450607668969, 105.2225612824963, 111.70424661328717, 99.7677916865195, 98.53881897464876, 91.29269507623489, 89.27092506039529, 83.87820736054452, 88.31196831118676, 86.6603994369507, 86.65798325692454, 87.0068859284924, 80.17193625050207, 80.39915915458434, 79.66611523782053, 80.02248610219648, 78.16307867726972, 73.91479876733595, 75.0384166163783, 80.49643393485778, 79.28038151033464, 89.7835631524363, 97.31518853095271, 99.72543793339884, 99.93357458422261, 89.10091384764641, 73.9682371385636, 71.84387360849689, 82.52030634110974, 95.77228499997048, 100.96792713288339, 99.31374596011256, 91.41946608020415, 76.39178337589388, 86.00870547756072, 92.17518914130427, 94.1348837267968, 95.00291209067069, 92.50630778651085, 96.89019972278227, 84.48361735190116, 70.78814414239699, 78.54070094323929, 57.368390021785615, 66.52280192221365, 89.85827645947857, 95.54633294382404, 88.99949704447101, 90.0593920676939, 91.953292815916, 95.69408862821518, 89.67081854420324, 92.54163265228273, 101.97053986210977, 98.56194526918473, 98.02344306822746, 95.09829628852107, 98.06885627008255, 94.89882023103776, 95.32112613801034, 96.87884053876324, 93.86507172738352, 82.00038048528856, 75.19495840995543, 72.42309785658314, 73.49330086861887, 82.26068465940415, 93.04381370544435, 93.14913718931138, 92.87462619043167, 97.10745196188651, 97.55386475593814, 97.93615464241275, 95.57666855473673, 93.99155247596003, 98.32697176164197, 96.1802742558141, 96.8522233347739, 100.71808784238755, 89.62748419853949, 13.453273715511447, 0.825333119400086, 0.2237848700174401, 0.5240800748428991, 0.4680481895564064, 0.322825038625348, 0.39053498436847045, 0.13452847157755207, 0.2068985301640726, 10.123692327930081, 54.853978157043464, 77.49511472640499, 108.75715809483683, 67.62259529482934, 50.8602326147018, 39.54748161377446, 21.358039071483, 34.95044415996921, 36.06850008810721, 66.09192955878474, 84.08932501269926, 80.11167295517461, 93.22348179355745, 27.36374870423348, 0.6241792680755739, 0.06959637596962914, 0.030485817772005836, 0.06017449041528087, 0.06757755042804826, 0.06476970028973396, 0.03737605852825988, 0.06154521706423933, 0.03421254824065874, 0.051453514024615295, 0.06492472584209134, 0.042243654794630506, 0.028297305670416648, 0.12423616458451557, 0.06971541071130384, 0.09613327096186339, 0.037995203127784115, 0.05327231017872692, 0.12014987457904125, 0.10196149168956666, 0.07733316686485084, 0.008582971396765882, 0.025926359305759112, 0.10693367044892042, 0.0478112600713728, 0.10397200517716909, 0.1717589963828364, 0.20672429112657426, 0.29132377897058764, 0.1807207695298618, 0.15143667558027854, 0.13315498318162658, 0.19852846800800295, 0.1013102173624981, 0.10954893374394988, 0.11950731067167175, 0.11604567343789725, 0.15905139036476612, 0.14543175667283997, 0.09685458104696967, 0.22416282715576313, 0.13645332877434072, 0.13885924322230203, 0.0915592510793959, 0.23410554524631272, 2.216845173989573, 104.88115033795758, 159.35317593236124, 132.0392805530179, 119.44873902105518, 100.01578746303436, 102.74560805289977, 88.56606729568975, 49.62845933052802, 99.53721907831009, 175.40114556589435, 155.37319398695425, 126.71765973491054, 139.49134457495907, 130.6888947948333, 88.56906398650139, 10.180664754682972, 0.5999939948801072, 0.5791538292842527, 0.3039943522983982, 0.47340271513788934, 0.8112350791212052, 0.6741509995152873, 2.705752926488077, 23.387334154498195, 3.6797742737877757, 22.74668755069856, 127.0588274924986, 110.3190145184917, 117.1453114478819, 106.29506280345302, 104.40206420037055, 97.14577351847004, 97.00226183860534, 90.16475477526265, 92.98519780558925, 91.74390885137743, 90.15630598991149, 91.83601394776376, 85.29350050034063, 85.52499094317037, 83.38952710551601, 86.1591205289287, 82.55498793817337, 80.30412012530913, 78.22123173744448, 84.41190073567053, 84.13394589577952, 94.8680139357044, 102.72414484331685, 104.50054707065706, 104.90710073901762, 92.96642534194454, 79.33058000379994, 75.86814695788969, 85.12617218878962, 101.18249647078976, 105.39328636661654, 103.56809769907306, 96.35219174046671, 81.89368417186122, 93.85463037798482, 98.80556368058728, 99.37611164585238, 103.2739434703704, 102.57122731977894, 104.84868095767115, 90.1605264602169, 77.80600178626277, 86.87962855062177, 67.32555420167985, 76.0197465650497, 93.81269239610242, 101.31656308327952, 92.56330766985494, 95.15396256600657, 96.77834941494851, 102.04302526289418, 93.3981841610324, 94.16940842905353, 105.46212396314068, 102.58894858821746, 105.11878321247717, 100.34126573993315, 103.19283669994724, 99.30565803281723, 97.70164397455032, 102.97722401157503, 96.58430191778369, 85.21994037012901, 77.06777249613117, 74.35152330706197, 78.2700809355705, 87.05726485098563, 101.52505274741881, 100.17348243344216, 95.74223179971018, 101.6246731050553, 102.46136173125237, 102.14169640694897, 101.39017812667355, 97.3409192792831, 102.16418727751702, 100.6655437715592, 102.2194456285046, 105.68740137161748, 86.04127683947164, 10.492125461178443, 4.032532144938746, 2.436416514458195, 0.5784851264569068, 0.5851146674925282, 0.445049801060269, 0.6064200629630397, 0.3846046364595814, 0.2603625806589281, 19.98584101277013, 76.39220699187248, 87.14420810822519, 121.79152365653746, 75.60203767591908, 81.90324691034134, 111.82381614562004, 38.41986294715635, 33.55166812096873, 26.53811331718199, 59.96181803364908, 93.3838753546438, 92.15560082466372, 106.78303703185051, 39.03942877246488, 0.7489859613199389, 0.25449244726088743, 0.2158492410014714, 0.17920455895364287, 0.2379484108138469, 0.2095163598536484, 0.24686037292403562, 0.17360952772921132, 0.15319256442448786, 0.09164126845256937, 0.3311016074111385, 0.11213526189807924, 0.19824385102237427, 0.22917714841183157, 0.18037759278330112, 0.13873715945068868, 0.11734600809793319, 0.18094610663190966, 0.2323023581336583, 0.1279103529128817, 0.28130261347659175, 0.09234524962882842, 0.14624060762505378, 0.18715383965642224, 0.15371512831939807], [0.0264056277416286, 0.03449718054804591, 0.04986052228618534, 0.046629944831253066, 0.09938486986943793, 0.01679972978308797, 0.057484924252475464, 0.02912574740607412, 0.03073225293548838, 0.051797836072622776, 0.10838006743259969, 0.03242685857619489, 0.05082662044573696, 0.10590169638875993, 0.04383714449021124, 0.1008773010764872, 0.05224143545473776, 0.02419232311958988, 0.03845176088713831, 0.07773893299482523, 56.500663680415, 119.76470162791591, 93.3282639903407, 104.64015991457048, 79.15990983286213, 83.0816916496523, 44.21052471283944, 29.75551982079783, 34.6594121379237, 55.426157828300234, 70.95646873597177, 60.2038674969827, 111.03352915856146, 116.29881689625402, 72.92698121839955, 6.48187997841066, 0.22378716828121295, 0.13262552449539786, 0.11706414902883193, 0.17820535047400385, 0.28207017228968684, 0.06214109940394279, 2.2566192332775366, 3.5935848470657104, 0.5449525999926752, 0.8421105062288623, 47.347581463475386, 115.74602942312919, 110.38551438239314, 108.78624639203473, 102.85795257937525, 103.18515669914984, 91.97150830299624, 93.71589614499001, 86.54800784203314, 90.23370219815163, 84.28290967018374, 89.61996109254899, 84.19840612719136, 80.24065617592105, 73.25733107905235, 75.98082096345964, 74.98783373063611, 77.78500141636019, 70.73359966278076, 76.58203401873189, 69.22430299943494, 74.37583415738999, 88.89172600161645, 94.69076987235778, 97.9593123159101, 93.23032240713798, 79.09935628214191, 71.30532433909755, 66.50201336030038, 81.92885214282622, 92.92086309002292, 96.1438903500957, 91.2057988874374, 87.64270997816517, 74.82542407128119, 70.65188100261074, 76.68180342643493, 80.21199149470176, 83.21548369623001, 86.21386112705355, 85.81115922620221, 87.4889373779297, 73.69728765180035, 78.09744957954653, 59.10862015139673, 73.7428891274237, 89.62741359587639, 83.55104246447164, 82.30623122184508, 86.23221781945999, 89.58598552211639, 89.07970166975453, 92.3613448296824, 91.59412137923702, 93.06863446389475, 84.95481168070148, 82.82115213332638, 85.68954221663937, 87.67416738694715, 93.36201206330331, 91.96538156078708, 91.83931658344885, 88.37977040198543, 87.86754808118268, 82.70355947556035, 78.62428665161133, 70.99938731039725, 69.3313366366971, 74.03439183388987, 81.22722641114267, 86.20075256593766, 89.55291994156377, 91.71001172834828, 89.61967868189659, 90.09412073319959, 89.18882200794836, 90.68008361324188, 95.65484139227098, 91.61715353688886, 88.58252556093278, 93.6079054494058, 90.25507127085041, 8.42600912817063, 2.156583349550924, 0.2676365548564542, 0.11663240485734518, 0.11038733270740318, 0.05165799821336424, 0.05071551088363894, 0.0470039336341283, 0.22248106497910716, 4.21871651564875, 31.017056049839145, 68.44306099799373, 102.25998724660566, 71.3797866144488, 81.03671689187327, 95.86308786945959, 49.639179168208955, 43.789481809062345, 29.454222956011375, 66.84997466302687, 66.68760422737368, 75.30390616386168, 69.03693922104375, 12.678524217297955, 0.13800029011984027, 0.10743790185980259, 0.030019283632657705, 0.046932185669579816, 0.04602668123439916, 0.02079492044304648, 0.03846668044946367, 0.019620467435508486, 0.06696246609452271, 0.04944467443912741, 0.040712911530487964, 0.06192116705220073, 0.05987981852564601, 0.04055862908341712, 0.05140526197670449, 0.009922319084345814, 0.029480572519523483, 0.0547834990486022, 0.04360770881776849, 0.07408113894803871, 0.04639346498034654, 0.06336615443409932, 0.1002222269533142, 0.04726876639911244, 0.11783946831259998, 0.025754307449284582, 0.020281570670645566, 0.043910221617308356, 0.09117439148887511, 0.14617115409383852, 0.04364502879099981, 0.03597985179493985, 0.04994612878128406, 0.09857706079680113, 0.0526918453584996, 0.02361566192590662, 0.02656708268689052, 0.02207277808338404, 0.07460054656070086, 0.10573648952788885, 0.033054832339046464, 0.012156829020128617, 0.02018603759126798, 0.08954882952234439, 71.88574098771619, 136.27465586508475, 102.00380940591137, 121.19984980552428, 107.39198500110258, 117.39693149443596, 66.03532975719821, 53.957222354027536, 38.25304454372775, 18.806272514404792, 76.42924985577984, 71.6576708516767, 123.62858141622237, 125.27286252667828, 79.05986585924703, 6.570650079557973, 0.3194422394998612, 0.08669866834797206, 0.2528187290074364, 0.18105064699005696, 0.7562054513442902, 0.12704096569289125, 3.6444388666460594, 0.670627240211733, 0.8082331176246367, 1.3850528915082256, 58.372163772583015, 113.96906237448417, 112.88592338562013, 114.07807288631317, 105.31069694026824, 106.27874574353619, 97.08667908945392, 97.56291758629584, 93.1134436207433, 95.3198003768921, 90.35982993341263, 92.83527697286299, 88.03997547395768, 86.04894115078835, 79.40178671190816, 80.57608158357682, 78.19297498272311, 81.94429059182444, 74.59591834775864, 77.98530117157968, 73.73309889147359, 77.12737683326968, 93.8957368173907, 99.05814078546341, 103.08457143845098, 97.16533830088954, 83.47668217074487, 75.12943913859706, 70.74941465931555, 84.78694992680704, 98.37942169558619, 99.6606089991908, 97.34490440737818, 90.80676832506734, 77.85882826774352, 74.74054398075228, 78.71126128781226, 82.48207892141035, 84.86281641067998, 92.66243380884971, 91.31174210579165, 93.71988127308508, 79.33848750206732, 86.25354766845705, 68.13347616503316, 79.21497991008144, 93.53832260254892, 86.6521938385502, 86.6386773509364, 90.36238731876497, 93.88065922644832, 94.57000009475216, 96.42056649731052, 96.98009260239141, 95.46040165808894, 89.16013379250803, 85.78740535243865, 89.79666386881183, 92.19996283131262, 97.97789650578653, 92.83879141653739, 92.85483391054215, 91.40448262614589, 91.72869005510884, 86.81013199590868, 84.30463175619803, 76.81997283812493, 72.2591192491593, 76.02461030406337, 85.41451346489691, 87.47058068552326, 90.51535191074495, 93.49967941161125, 92.3037644355528, 93.6014727623232, 93.04721047801357, 93.2057213014172, 98.48856556800105, 94.55383208490188, 92.07661213413363, 93.12094319251277, 102.42156536348405, 17.219144259729696, 0.8521401293335423, 0.2895983651040062, 0.5157053855157668, 0.4664747981775192, 0.15449635414106233, 0.03199204430735159, 0.07863714810340636, 0.21455067600454056, 3.649686262492211, 34.775322098885816, 70.85379677434122, 106.53337032564225, 81.42825572721421, 71.09302213115078, 39.13469137683992, 31.749894042168897, 51.02823557392244, 46.37021703104819, 82.99103783022973, 80.60524832817816, 81.54777034636467, 86.58984384229107, 22.814983860138927, 0.06689524954004634, 0.17876761304515024, 0.06337473844929088, 0.010638571073932034, 0.034080738982846664, 0.038861545148275556, 0.10287535797444083, 0.07209389921157591, 0.05800069677793692, 0.032822956676564874, 0.05083946774022714, 0.06621084191025266, 0.04519304350739525, 0.04527593039036278, 0.011246874571717795, 0.04949165095064429, 0.0831810760522081, 0.0852613112017993, 0.06408448060674053, 0.00938367308868516, 0.0029229261206402896, 0.04558821081093723, 0.04858872440132884, 0.014960556647800391, 0.22427366475664803, 0.11244089267547093, 0.08635439609567966, 0.11690595953334725, 0.1644178975613848, 0.1882138908390076, 0.19881103187799457, 0.08532742458966472, 0.1902021341506512, 0.12690108569879688, 0.1796790584921837, 0.19034553048831804, 0.147767175710009, 0.1415506173526087, 0.1550320181394777, 0.14061620458960533, 0.15817717679085272, 0.06507654914692526, 0.08958508080292134, 0.35187754419542133, 94.74875819298529, 156.880121538716, 116.27120341024091, 132.52770977635538, 108.42752995029574, 104.1884126970845, 57.25677113379202, 37.43721900447723, 55.39544174748083, 77.31557999887775, 90.14651575396138, 84.1459483485068, 138.42976293256208, 132.8226092553908, 103.64116361064296, 13.745947249474066, 0.6628912230653148, 0.36838664703311463, 0.6632770249439824, 0.4906886004872861, 1.952998854460255, 0.0850681804360882, 8.04821967117248, 9.823751622630704, 1.1765862712937019, 1.397867274861182, 58.357721605608546, 117.63163828080701, 117.88649036038308, 116.00944795916158, 111.63889992621638, 113.50415168269988, 102.22317188016831, 101.29244050671979, 96.69277114252891, 102.83247286273588, 95.3349171915362, 99.18649642698227, 94.24297640400549, 90.0445027505198, 81.61769051705637, 84.99871869241038, 82.86258805182673, 84.56301396892917, 78.19902327752884, 82.68237867662984, 78.44275151529621, 82.12555900696786, 98.87258129735147, 102.56993293762208, 106.0448234311996, 103.59735858055853, 88.63298293082946, 78.86886996607628, 75.0206482794977, 90.98203551384711, 102.92764525259696, 103.97240777169506, 99.62563714673443, 95.90878348196708, 79.52603955422678, 78.9363504225208, 83.23344030687886, 88.62868401312059, 90.63138346518241, 99.17530982725083, 93.98724571351083, 101.33196230857604, 85.84421696201449, 93.40322048433366, 74.97899270826771, 84.5133489178073, 99.6574789477933, 91.55818462371828, 90.08605634012531, 93.78067801075598, 96.57254265200709, 96.11214268592097, 99.98414962522446, 99.675090389867, 101.75673930875718, 94.23060524848201, 91.55831798430413, 94.13999065276116, 96.10939702680035, 102.8513865317068, 97.58780894740936, 97.15848199782833, 97.4446032124181, 96.96990228468373, 89.56401240441107, 85.02903076910204, 79.760864011703, 75.94374672059091, 80.43346420411142, 88.78294298725744, 96.07653540949669, 97.00438776323873, 100.44390632260232, 96.26775095539709, 101.16555183164536, 97.89155729355352, 100.33042430877687, 105.75894540356052, 100.1521525844451, 96.59747323682232, 100.38056788905975, 104.56943173562328, 13.623552630024573, 6.074813460150073, 1.5229385442310766, 0.774044881184255, 1.1852854754655593, 0.42562377248560235, 0.26535802550854226, 0.17455029902198624, 0.47408318507575226, 10.16586761320791, 52.889368841725016, 84.74200740937265, 121.57644441050869, 90.36956525618031, 112.7145471880513, 132.52629772309336, 63.5281664325345, 54.741770913524014, 43.75404711692564, 80.95035414541923, 88.82885825249457, 94.25388843782487, 100.3747941601661, 31.816050698680264, 0.5718310093206744, 0.2872172106177576, 0.3142958446856468, 0.21963391453027728, 0.11273933754813288, 0.10115185166679083, 0.1758024390907057, 0.1257196019193338, 0.2080906702265624, 0.14388075038310022, 0.1266791117227366, 0.1500338460168531, 0.1525944795820021, 0.15959492974704312, 0.1755129651076371, 0.18806074986294394, 0.12287461949932961, 0.11991259416625386, 0.1387732268701638, 0.14628770671063854, 0.1167721699382509, 0.15756781513412155, 0.16693400609637463, 0.0859476723557999], [0.0578178200990923, 0.025726147972407843, 0.02086670096633175, 0.044741530437022455, 0.026395122760966904, 0.016919222262297428, 0.06266338367676062, 0.05020313212768205, 0.069710714592328, 0.027938941230757103, 0.027011143636979887, 0.04510534559226325, 0.035023341225760604, 0.040806094635157816, 0.045877677133126606, 0.0504980874698489, 0.16376525193693178, 0.10249494169388088, 0.6503156139965981, 31.35241085483182, 114.14105830654022, 87.7419537882651, 92.98837492542883, 52.817573778090946, 40.95038006382604, 30.381710529327396, 45.371605119397564, 58.58329319184827, 96.72912366928594, 153.73401980246268, 87.3622840450656, 95.08574470396965, 122.05757802532567, 70.25261509803035, 8.420730598511236, 0.3300126900355662, 0.2324093806166803, 0.0867026826486953, 0.07314358522454578, 0.3290950392763461, 0.048588532879347765, 0.7570957680863719, 0.8347408016843181, 0.4450305569316111, 4.3798641524007245, 62.61584274230465, 106.18134544741724, 99.87972044175672, 97.21124572138633, 108.50650295134514, 104.36560969198905, 101.02948481036772, 101.96621741017988, 95.25702676465436, 92.281461838753, 88.72763756782778, 91.31224416917371, 88.90903934355705, 85.44978341748639, 81.3756488984631, 75.28390207598287, 73.73407163927632, 74.68591320899226, 77.51878230802475, 72.35383664408039, 70.54836965376332, 71.21684351275044, 81.98849570366644, 93.14410871075046, 98.68735128833403, 94.40804543033724, 94.58861566358998, 78.03681758142288, 70.58354546946865, 67.93465906573881, 80.69292114626977, 91.33326807329732, 94.47616915549003, 95.86801436639603, 93.68862782755207, 84.60276326825543, 78.22283206447479, 75.8481114910495, 74.54908524790119, 75.50184465223744, 78.57961085534866, 90.15966353877899, 86.81148129124796, 75.3540026757025, 81.39986561190698, 71.32870166532456, 80.76807375877135, 87.1468831646827, 82.31179314274942, 78.0106161486718, 82.20596759550034, 86.86630033677625, 87.74247154112786, 92.39700701928909, 91.73709177201795, 91.96007851631411, 85.56215932292324, 77.01420860905802, 75.77163311742967, 85.62519181159236, 90.28982347057712, 92.01152432349421, 88.20291857565604, 90.8321774390436, 88.33419246058311, 86.3995304415303, 86.84938707659322, 82.76085745903754, 76.48617913646083, 73.11902046203613, 68.90798737925869, 74.27361719069943, 72.80969450550695, 77.16508650010633, 80.83519335716002, 83.99896929340979, 85.83099072979343, 89.32059795625749, 87.57033440374559, 89.59589342917167, 91.47356340962072, 91.71453814352714, 89.55195503850138, 89.83926865362352, 9.552492268623846, 1.951163185219611, 0.5181020149780858, 0.5322075322751076, 0.15235297802475192, 0.03098561544902623, 0.09462209358330696, 0.06400468488854748, 0.3566569216068714, 0.3106948637193249, 14.609755143042534, 56.246443102436686, 93.21480551073628, 97.02479977761546, 91.14508059716995, 80.04907977196478, 53.34892549822408, 29.52957364820665, 29.603843727419456, 60.78060888474988, 85.98363368741929, 72.39763382942446, 70.29030123064595, 5.298546494976168, 0.19183396271640257, 0.10511758241562114, 0.07320769912292881, 0.0324082273178764, 0.06505335966545729, 0.031379666179418564, 0.06705419746257606, 0.034019068904942086, 0.018551554530858994, 0.05393990983946189, 0.07972942860496622, 0.034615196392781315, 0.07383527068962013, 0.051936467343400565, 0.023733562857453382, 0.06459613540960897, 0.04665449411878663, 0.036326234619463646, 0.04378098641492186, 0.07900110881535277, 0.04453622653419453, 0.07329782170634117, 0.08467325445024237, 0.03364601472933446, 0.04131863810001843, 0.05258848477575568, 0.03985273268734736, 0.08447954911858806, 0.007294708367196784, 0.07573175965057266, 0.03610088985653655, 0.08843106127554372, 0.08347969712509264, 0.04438909551789684, 0.07467109559764785, 0.05967559480679132, 0.0714985263203421, 0.06734368676740317, 0.0486652642458437, 0.17433285262555848, 0.19383204259699394, 0.6085135667554794, 40.89330565544867, 132.08518797351468, 97.50887517006167, 112.5145612224456, 79.34184505093482, 65.37634018928775, 58.381683364991225, 65.51004594372165, 34.598988025419175, 35.56569145571801, 114.00394793479674, 92.86314149056712, 104.40359392473775, 129.70056733777446, 75.31499862670898, 8.280752974171794, 0.5463788718465836, 0.24467524501585194, 0.1355066892480658, 0.12086988997555549, 0.8270814546173619, 1.3742691927379178, 1.1536685978212664, 0.4689665144729999, 0.36490275494513974, 6.2864444525011125, 75.89967496933477, 114.90501050026187, 103.72589465110534, 99.42781632946384, 110.1152709222609, 111.65178098986226, 108.3617361130253, 104.54519148795836, 102.45852193524762, 100.79589982186594, 94.84231456633538, 98.2206206167898, 94.7277892020441, 90.25504773662936, 83.90684066280242, 78.05734726690477, 76.57013354762908, 76.53140406454764, 81.27728369928177, 75.54422193957915, 71.9712878811744, 76.48874436655353, 86.26892335953252, 98.88411306565808, 99.05776423792686, 95.55536223996071, 97.8956679374941, 82.10063626689296, 72.75191799286874, 71.29340817851406, 82.81326032453968, 96.25568574474704, 96.3413973777525, 98.2240487683204, 98.50363531420308, 89.93174245280605, 84.67197741231611, 79.35994286690989, 80.54076456254529, 77.4083048297513, 80.02370988169025, 93.63116510452764, 92.20310857219081, 81.07846659998741, 85.21985407798522, 75.53790692360171, 85.71099758148195, 91.47611295023273, 85.88316609782558, 79.88273205295687, 84.25182880893831, 90.45260183272823, 92.79885384344286, 95.26782112736856, 94.79444596075243, 93.86568361713041, 89.13049636348602, 78.86154297859439, 76.47120352714293, 87.26726855001142, 92.28454482170844, 92.58786170713364, 90.18271923065187, 93.25501764974287, 92.80656522320163, 93.32078795279227, 90.30386555579402, 87.3334546242991, 78.47569942474365, 76.58885109809138, 71.93945392485588, 75.73268398161858, 76.56237509942825, 79.37531071324503, 82.71754664759483, 86.18503955102737, 87.82700646308162, 92.66964312522643, 89.22697882498466, 93.50949318178239, 95.48175504130703, 96.7380117600964, 89.83121995002993, 99.47392771320959, 17.19007557438266, 0.8933036882550487, 0.3730474033903691, 1.079140500195565, 0.3032904707135693, 0.1310716377150628, 0.03448035725722871, 0.04775025265952272, 0.388205862574039, 0.3737216220507699, 17.95466515325731, 58.90534331721645, 98.83139641054215, 105.44816817006758, 85.74349834072976, 49.43999336611841, 39.062798253951534, 43.70985769456433, 49.74428299934634, 70.04846357530164, 99.3299061252225, 80.63577221285912, 87.17255115509035, 10.96058785915375, 0.2381010002066051, 0.09998274786818413, 0.09151074239203046, 0.07627369024820867, 0.028768558911378347, 0.06399608555159743, 0.0231589203054506, 0.02452847867032453, 0.07110357735185854, 0.025644105701376835, 0.0739190960302949, 0.12039915958960211, 0.04011110733112982, 0.030911887147193475, 0.028283837844707796, 0.035550333108873136, 0.08676430676132442, 0.02074542541747853, 0.009580053982415028, 0.036447234376664125, 0.06380340677776164, 0.13502909471431088, 0.013367488300578009, 0.21282893935999564, 0.22430438488241167, 0.18001193901704204, 0.10462950779906205, 0.21095973079002675, 0.059489772519877845, 0.1745289558124158, 0.1107515462283646, 0.13894109205613214, 0.20597790698370627, 0.15150648151193896, 0.18452033580791566, 0.17695898670823346, 0.15402805991470814, 0.21155870429450468, 0.14490963710892588, 0.23149730697754892, 0.3222625768713413, 0.8831614808690165, 56.85259049938571, 152.31707142245386, 112.88233833928263, 126.03359837685863, 83.95855319115424, 60.56581597174368, 41.87385505245578, 61.05288021026119, 81.04966071344192, 116.72607283438407, 189.53630078223446, 118.51511293841948, 120.0351647407778, 140.65087564529912, 96.62307062456685, 15.553102820150315, 0.8714790077459428, 0.4407936923446194, 0.41907905270495727, 0.1986044486083331, 1.8425240728162953, 0.7290882677320512, 1.331603733762618, 5.62104965409925, 1.987131197125681, 5.531323965518705, 77.69484181557932, 117.05355152007073, 104.35271293886247, 103.3318925672962, 116.88648992969145, 116.72167193505072, 111.2771789489254, 110.76932614849461, 107.23977350419568, 104.43578089437177, 96.72023557847547, 102.11798175688713, 100.18235483477193, 97.55897168190249, 88.73241501469766, 81.37365633441557, 81.1889519230012, 82.9559326171875, 84.62369303549491, 80.76023686316707, 75.88886491713986, 82.27736257737683, 91.13500795056744, 102.5591621091289, 103.81820371074062, 99.35968475957071, 103.8599612635951, 90.60546444308375, 79.00532922437115, 78.59550429928687, 89.22655520900604, 102.11656185888477, 100.46732287253104, 101.4020158398536, 103.9306188398792, 93.7245959620322, 89.8903928264495, 85.3105628105902, 84.5308191545548, 85.48618301268547, 85.24829126173451, 101.35542592694684, 96.22134147151824, 85.39221086809712, 91.68965462715396, 82.73799004093294, 90.735946009236, 98.06390623892509, 89.73724780544158, 86.66548282869401, 89.44686689684468, 96.64994670498757, 95.99575027342766, 100.47705035055839, 98.9877813093124, 97.9596810187063, 94.54216695600941, 83.65470286338561, 82.06487994040214, 93.73076192794308, 98.39492290250718, 97.00987908147998, 93.28912658076133, 98.22946948389854, 95.96146875812163, 94.52641471739739, 93.02590416323756, 89.81453418731691, 83.14452017507246, 81.29519324148856, 76.65564121738558, 82.57077940048711, 80.42791797268777, 84.59489499368976, 87.88397496746433, 92.20728197405415, 94.5988687392204, 96.17653231466971, 96.26842560306673, 98.1114375206732, 100.76279501761161, 100.99918842315675, 95.14005384137555, 102.09068990522816, 13.960126311548295, 4.976014408373064, 1.3119135580716597, 1.4398370034271673, 0.7719290076244263, 0.3446024668312842, 0.31440162610623146, 0.27065567672252655, 0.8131521988299586, 1.743557157535707, 29.194126667514926, 71.85162421195739, 110.01257542640933, 114.59744176556988, 113.87396058728619, 114.30903773153983, 67.96022507452196, 39.33172379770587, 39.076024486172585, 74.78607485371252, 109.16146032271847, 89.70218181610109, 106.94845907149777, 21.70790272374307, 0.5241372556455675, 0.2150331581792524, 0.28466288961710473, 0.14130441201550348, 0.12389129478364222, 0.1423073130389375, 0.16349499143900412, 0.15371241636814612, 0.13191320062164338, 0.09652684097208324, 0.16740265272317395, 0.22582611129168542, 0.16644530328771762, 0.12672185942891145, 0.1510915376486317, 0.17654555969901625, 0.18865848230498453, 0.15607446462156313, 0.26631211140944117, 0.12159969597574204, 0.17158009953075842, 0.23202406903428419, 0.15099242119298828], [0.08727773122729794, 0.056973897641704935, 0.08246574145291122, 0.027994162763559052, 0.06796813269536342, 0.03561509818199181, 0.034718717853989334, 0.03400215368357397, 0.033541865076028535, 0.10674741915276936, 0.05224700108350766, 0.019157466876711098, 0.04955420202966179, 0.06390541138487958, 0.10384657360132664, 0.05675660829330164, 0.1823864132165909, 0.3753769235505212, 6.895641492259118, 101.43945878551853, 97.7613110696116, 109.80195983763664, 67.20840084937312, 56.47736480159145, 40.18507073002477, 52.965890361416726, 44.119741455201186, 125.62880193033527, 182.9929401028541, 108.42653366827197, 118.52251052856447, 120.91444246230589, 75.57222766260948, 7.030126327468503, 0.16704777015313027, 0.10364175233389102, 0.14987897368208056, 0.16379211097955704, 0.037617774590128855, 0.02077326313742707, 0.5773116636180109, 0.7128814631892789, 1.382458979083646, 2.55069722090998, 80.53040166055003, 117.10487965614566, 108.50181179661905, 104.87198768123504, 100.57893783815446, 97.63202190399171, 110.54248763668923, 106.67168878739881, 99.64502150012602, 101.34281158447267, 104.7086052740774, 101.86771885041269, 96.21412431040119, 88.62800152071061, 86.10919660137546, 80.0544612638412, 70.78011897302443, 66.10210418701172, 74.68248505746165, 73.90407500728485, 73.32406628516414, 69.44202592295986, 76.33018647470783, 88.08808726649131, 98.21775728656401, 89.16091042180216, 88.02455271444013, 90.31693489320817, 75.39614462083387, 68.78895128926924, 65.07663972916143, 75.1063128440611, 88.00997718687981, 86.22475747139224, 95.74414591635428, 94.50788544070338, 90.75236505077731, 85.53369860495292, 88.15319861135175, 84.2510364901635, 80.62685274308728, 79.92081042258971, 84.01686314613589, 88.72926142907913, 83.33520227862944, 76.74824837715396, 67.79099049106722, 81.52767996634208, 81.56720176819833, 77.92811301446731, 70.85199248406195, 71.48513363253686, 75.91075958744173, 81.1974948452365, 83.69668006896973, 87.53276594223516, 83.70545048867503, 75.9639783059397, 67.43784381497291, 66.11760539393272, 74.5443940931751, 85.49568299324282, 89.2852024878225, 88.65093169673797, 87.66098037842782, 94.29252378402218, 92.99640793954173, 93.77260577294135, 90.02481245225476, 83.57272532678421, 80.75153704612487, 71.47812043466877, 68.98964328150596, 69.72729206085205, 72.40102275725334, 76.73478680272257, 76.6733624858241, 82.92252971280007, 81.71451030238983, 89.6850645926691, 86.26467151026573, 87.86316287133002, 89.42592144012453, 90.49047623911213, 84.14273984970586, 86.29865492543867, 2.575668255167623, 0.5176889403693138, 0.4840319705826621, 0.38295816029271773, 0.24422964231381494, 0.07463627690148932, 0.02298823208548129, 0.013971134941394051, 0.03924238660763349, 0.06368088250559184, 8.679264803086559, 47.60372792520831, 90.12853560909149, 92.04112252881451, 74.14027229432138, 79.47098516648816, 38.51287803342266, 28.056690308355517, 38.511869984288374, 51.23348143792922, 82.40025827961584, 74.55951875255954, 64.63912679303077, 5.953335204432088, 0.2902291006138248, 0.059056840912108464, 0.029158995621987892, 0.02937889541499317, 0.009409927879460156, 0.02410109353912694, 0.04439594817437953, 0.0737121143949128, 0.0237637946021653, 0.020861941645102158, 0.03563094854114517, 0.025514667485690406, 0.07794070523232222, 0.07489015843959586, 0.07500541636780386, 0.06134185902473908, 0.03816417914124266, 0.02765436446474445, 0.11264264193033019, 0.012917330248221275, 0.0029965907414143365, 0.043569170764737555, 0.05807145648906308, 0.041224692737863916, 0.045571130880665396, 0.09534692001198569, 0.03981808253053216, 0.06831028288410557, 0.010153359710989941, 0.023753065540785753, 0.06930938411143518, 0.06497603075038041, 0.09282009390693519, 0.05211504626898997, 0.011811757163565246, 0.01291959882608705, 0.08639764175900529, 0.0855340461637224, 0.05677894741717366, 0.6064443326284809, 8.907328074978246, 123.84555908941455, 108.56116510206654, 128.21554230105494, 83.17081574470767, 74.43637986336985, 66.25882640961679, 58.08401861498433, 22.00620682008805, 59.132852554321296, 157.8119354863321, 120.92602129905455, 129.7110636003556, 128.79256217710434, 85.12690959438201, 7.188441032363523, 0.43242212865621815, 0.09296038758850868, 0.13577932461855874, 0.19447446860853704, 0.7747795901471569, 0.9687957083505969, 0.9121322908228444, 0.12510978060984804, 1.0977071619802907, 5.081991947466328, 98.06946815982943, 123.25934517768123, 112.5952914453322, 109.68667353353193, 104.38846926535331, 98.86719196073471, 112.0672070595526, 108.61865135931201, 106.16055688550396, 106.85185109415363, 112.97798141356438, 106.34473569931524, 99.17811039955386, 93.2255449602681, 90.41432734458678, 84.47908309198196, 74.62119410114904, 67.28847211407077, 78.5547665626772, 77.57688045501709, 77.25149631500244, 72.95735605301397, 78.70911182895784, 92.55315657584899, 101.6561540480583, 91.58576673076999, 92.78157972520398, 92.88301221786007, 79.48155987647273, 72.15599229258876, 68.7387292615829, 78.35457663382255, 93.15857441194596, 90.53141793897076, 98.5929947514688, 96.10794574983659, 95.66580833927279, 91.32377593748032, 92.66160226637318, 89.33751121644052, 87.35822831430744, 83.8299229837233, 87.76206770250874, 92.58862264694707, 86.05524047728508, 81.04709548334922, 72.56708806560886, 85.9203266328381, 85.73058589812248, 80.971723218118, 76.27180591706308, 76.19793199723767, 80.84403437952842, 84.73435094279628, 86.56190087718349, 92.18908217645462, 85.47159179564446, 80.15136734131845, 71.86605853419151, 68.85664355370307, 77.78900223393595, 89.59292027258104, 92.03691774798979, 93.86158081793016, 88.35067426004719, 98.10042350522934, 94.33759966204244, 96.70269473906487, 94.82075721986833, 88.34826592476138, 82.11375267274919, 76.92856757871567, 71.92046965322187, 71.39891993614935, 74.30927938030612, 80.06627544280022, 80.52477698172294, 84.41712533274006, 85.30594225852721, 92.91213973875969, 88.8757384207941, 90.46622814670687, 91.79529974537512, 96.2188389993483, 86.37663164446431, 99.55504232837309, 6.131704007425617, 0.9679055141825831, 1.0384084019930133, 1.953077669585905, 0.7657341142335247, 0.11543597470247939, 0.09135295892314566, 0.06209172886766254, 0.0311097274384191, 0.08670158714296357, 9.55199412761196, 53.108495973771625, 92.65246314387169, 103.26342367356824, 78.83673006488432, 40.3220751977736, 21.121441702688895, 37.948896115826024, 63.24501445216518, 62.362351725178385, 89.10200426655432, 84.40240075511318, 81.28315156505954, 9.391362282537646, 0.10833786364885108, 0.09869264048193732, 0.09423574778221308, 0.016367280810710885, 0.07811666030677096, 0.01296529405555057, 0.04363537225271425, 0.1043618826435939, 0.026067286925089937, 0.06453138565824879, 0.0072541679518537665, 0.034293336042713736, 0.05328489700332285, 0.05584294885216702, 0.02577858286038522, 0.07468896076804207, 0.06383733681192802, 0.06716668215249816, 0.0360314937819156, 0.06723978992311225, 0.013584505687768181, 0.01576366577102172, 0.25989529766863395, 0.09499311762591524, 0.1955546832252895, 0.2541806188321883, 0.15588680372363137, 0.16528939918404625, 0.10371058533388762, 0.15454231941651914, 0.22753837908948624, 0.14756408580128225, 0.12056497165993338, 0.22385781690959008, 0.12831864713300623, 0.13131335377693176, 0.27988859902947183, 0.19409645018318009, 0.39435399395804255, 0.8869819307038862, 14.980959430817636, 151.59708115362352, 124.40060584775864, 143.86040995197914, 91.97745461617747, 83.62239037790607, 59.00979603490522, 66.0791975452054, 61.47287584120228, 161.12920945690524, 212.0208014211347, 124.50388185439573, 140.52843493800012, 139.73131518210135, 107.19098706399242, 12.600269990582621, 0.6907659757041162, 0.21442516015902643, 0.3605305992307202, 0.3741798652035575, 1.1536597724883788, 1.2091951408693868, 1.0024136076531103, 4.206063930065402, 7.514309585094453, 4.129852767913572, 101.7988028064851, 124.56180741710048, 117.34105340896116, 112.43641191913237, 107.91122051977344, 101.75859851221885, 114.9737931836036, 114.31041840584048, 109.33912015730336, 108.67263886236377, 115.2660725193639, 112.7271850647465, 105.37521992960285, 97.88873318702944, 93.90258527571156, 90.03606180990897, 81.0881156306113, 73.49237518925821, 83.66875279334285, 82.70122174293765, 82.14109159285023, 76.95432186126709, 83.03730610878237, 95.5425831579393, 107.66811986123363, 96.88952507511263, 94.54575984708725, 98.01035804133262, 83.44963350603658, 75.67548797976586, 71.60341662745323, 84.20231280788299, 94.74909551682012, 94.13233418618479, 102.1755386167957, 101.08277413152881, 101.050979398912, 93.92550760699858, 95.00613627895233, 92.087524167953, 88.34561440252489, 88.3882034978559, 91.76291665723248, 99.49426128018288, 90.1085864343951, 88.27476070773217, 78.64937413123347, 88.49406042406636, 90.1326148740707, 86.4655831552321, 80.96029343143587, 81.66542576205346, 86.68048981697329, 89.1629029858497, 93.463162145307, 98.38648980663669, 89.6198041977421, 83.45031599844657, 74.55955013152092, 71.1895045926494, 82.86741256713867, 91.33075775638704, 95.05204369944911, 95.66121916617118, 92.08306051069691, 101.32247017275904, 96.88338264342278, 101.7708912203389, 98.4735664244621, 90.83510352719216, 86.75484226595971, 78.08323491004207, 75.35586187916418, 76.07692687742173, 78.87533403212025, 83.71233032595727, 87.0111926909416, 91.11474498625725, 89.26175455893241, 98.08675796754899, 94.75587337247788, 96.72953159578385, 95.20868747465073, 101.15842096267208, 88.37151773514287, 106.03915952867078, 4.175739595966955, 3.757989031653251, 3.218789629397854, 1.030270096755797, 0.9056764985284499, 0.2679289246518766, 0.1902189574414684, 0.1535695409702678, 0.18029533026199188, 0.2612845827975581, 17.036293168221754, 67.41063825545773, 102.35941933047388, 109.0249461512412, 96.7205572128296, 107.73642401541434, 48.890198661435036, 35.59050436942808, 53.98967604483328, 69.26141646600539, 106.16514605860557, 91.401321195787, 103.26280393908101, 14.910402855565472, 0.4533568907889628, 0.2206614376195977, 0.1421204948377225, 0.23174309862717507, 0.14382340104108857, 0.10881593315711907, 0.1789701513705715, 0.19276578610222186, 0.2032139077181778, 0.21090460310299552, 0.15451653289698786, 0.10409653276926088, 0.253053427703919, 0.1699908348100801, 0.193770203979746, 0.14198534160612092, 0.18175219966759606, 0.14849220132154806, 0.20586284057747936, 0.14825053122495452, 0.15550274852543108, 0.14257259396535737], [0.05600120729556488, 0.062170946189472755, 0.08812852549336611, 0.031328428303822875, 0.06575763195512757, 0.058116096432410905, 0.03859926345607927, 0.05634828342966015, 0.016057437507345552, 0.04423253012881164, 0.007146800729265858, 0.049787659663707025, 0.06691804831667293, 0.02615415171960429, 0.021692371378923138, 0.2002145968858273, 0.015821740981341613, 0.21519769854362936, 30.238071372432096, 103.4718741140058, 98.46249749583583, 71.9123346574845, 50.98374412905786, 41.029580562345444, 34.775733947753906, 68.22347102626678, 134.822359085083, 103.162807033908, 70.92107326753678, 114.19702268415882, 116.77407480055287, 82.75135747848019, 9.677726684078094, 0.26419948606241134, 0.2948236363309045, 0.049913347879004095, 0.17454826122810765, 0.30551396430500094, 0.17577792427712874, 0.39510301344337007, 3.138160897839454, 1.4954114729358305, 1.3222947236030334, 70.67219888010334, 108.24226856231691, 105.40212738898494, 105.97544454759168, 102.0494971736785, 108.14991243423955, 104.00566947075629, 102.81531641560217, 104.49544014469271, 107.08771105735534, 105.17440242152061, 101.55508241345807, 96.54223057531543, 93.50595520388697, 82.20043705355737, 77.7990670357981, 72.55193987200337, 70.19483858539213, 65.29545699396442, 72.03450864361179, 73.47140619831701, 68.71954887144028, 68.6012109633415, 74.00705291378883, 94.96012687683107, 89.43212662973713, 92.77025976488667, 91.76648601408928, 84.96106393875615, 78.13746560004451, 70.31949150946834, 67.71360997230776, 70.48529009665214, 80.57753286054059, 82.26339893956339, 87.85786767159739, 90.69113685238747, 90.39774356349822, 90.04287888926845, 87.31232873855099, 86.5108237727996, 85.8357132634809, 76.40004388747677, 83.15162750982469, 86.83321122200259, 78.41515371876379, 74.61047818583828, 67.92826560235792, 82.3185396194458, 81.42547084439187, 78.86288442919331, 71.34283788742559, 65.68153196765532, 68.97859004236037, 64.92905270668768, 71.4449764067127, 72.40864000012799, 71.9910958505446, 70.16025112521264, 68.29158690667921, 67.04543421345373, 68.85172490150698, 76.81686632094845, 84.44780611222791, 88.66963355771958, 92.86760514782321, 89.26018561086347, 88.57626545813777, 90.75271806409283, 89.87786477611911, 89.33505581271264, 85.96775593296175, 79.55075833105272, 75.54624588258805, 69.239851274798, 68.82136575637325, 73.57322308324999, 72.48772282754221, 78.17225702347295, 79.7050408394106, 85.24037591872677, 84.85563847326463, 86.01262784773304, 84.93948305806806, 87.85633794723019, 86.95938602570565, 86.06000223467427, 50.26010997833745, 0.2445549845334984, 3.4281275060869034, 3.401397043658841, 0.0719323925553791, 0.04582467534008526, 0.03486313308859545, 0.09305609495288904, 0.0953124154118761, 0.05347155049563416, 0.14179789521280797, 3.90092755517652, 41.92019393367153, 89.10471854671356, 98.6849037293465, 88.60320429648124, 111.50869292597618, 38.706823548962994, 16.623732389942294, 32.743085238241385, 60.805512012973914, 73.05135957656368, 77.86590422353437, 44.59801958453271, 1.3021892669700807, 0.05187078296477276, 0.13317617317361216, 0.028569128987709844, 0.05174557355442836, 0.0700712202477359, 0.0368585086788141, 0.025497214087555488, 0.0027649216832698236, 0.061468102653781255, 0.02822744802782132, 0.04364275734030432, 0.08422041987820018, 0.038085187815370104, 0.10318196934437561, 0.013944507640365873, 0.007839093319020204, 0.02347964684539024, 0.04435518080548895, 0.11828451177045224, 0.01687765241630616, 0.04703001509751043, 0.06378624257781813, 0.04814641204692664, 0.011827114353617354, 0.040041979387282364, 0.07210661627111897, 0.05258200367191627, 0.030103032364540046, 0.008591276747474988, 0.021595897926618497, 0.05339509492079097, 0.054785012072252656, 0.07158992827058801, 0.04657292490704887, 0.016999799390173247, 0.03229854267931754, 0.12643898912375012, 0.02478175882941052, 0.196780669052274, 41.597971224015765, 117.45866175620787, 108.33205161556121, 90.09969834358462, 80.70495497795844, 69.65186488243842, 39.39154386520386, 33.37219222899407, 72.5628597505631, 96.58148565599996, 83.6976920404742, 122.31606221968129, 123.44664619814966, 94.27297469108336, 11.53933750044915, 0.3838403258592852, 0.13873541277022133, 0.08034476574750678, 0.1240359168619879, 0.23274236839384804, 0.16436554311263948, 1.6891997259470726, 1.3813892751932146, 0.6163712386642733, 3.618569119322685, 85.69952857109809, 115.0006143508419, 106.7950394845778, 112.18823571358959, 105.33768284705378, 110.92699758468136, 108.11722340122347, 104.0252499426565, 103.81625037039481, 110.43014311021375, 107.019893277076, 104.99516579412646, 101.25589970619448, 98.93690816817745, 85.39147346250473, 81.28782703030495, 75.1296038781443, 75.3561835135183, 70.6180231032833, 77.92044085841026, 77.45995460018035, 71.73233709027691, 73.84443929118495, 78.74217740951046, 99.42003434704196, 94.02604579925539, 99.22588486825266, 93.30015628568589, 86.98039424034857, 82.34374477017312, 72.49915261422434, 70.24785334064116, 70.72264840525966, 81.04966071344192, 86.1558335827243, 90.88076776073825, 95.09177730929468, 94.15354636407669, 89.1449228409798, 87.98144586624639, 89.78319444964009, 90.01816795718285, 78.65211979035409, 84.21848866247362, 89.91112647518035, 81.44905997860818, 78.69870970326086, 72.48973108107045, 83.56537480508128, 87.64580080586096, 84.8131513595581, 76.29064898337089, 70.65458743802964, 70.56773047293387, 66.77300207076534, 73.35694359194848, 72.3096864454208, 76.44280556709536, 71.42548222695628, 73.8543785772016, 68.89716948232343, 71.31594611752418, 78.50161060210198, 89.04322362715199, 90.90925201292961, 95.83581170728131, 92.91272809428554, 90.86933012931578, 91.84508246760215, 91.78150084710892, 92.55624740354477, 91.27470708662464, 83.38440449007096, 77.76609559212962, 75.09475754153344, 73.29216172618251, 75.81575978186824, 75.19881802220499, 79.96380744441863, 83.30015982350996, 88.26620209601619, 89.4224540648922, 90.57330100767075, 89.2177063418973, 91.8803131964899, 94.28755806338404, 88.67734493747835, 62.657278660805, 0.5001436576487557, 3.2778666528963276, 5.176502437360826, 0.049303798530731476, 0.17373783213476982, 0.04740216145892778, 0.08286111943063237, 0.10022125402165037, 0.12790911185044435, 0.17391371060042612, 3.0263196604867137, 47.68293626846806, 92.44129057853453, 105.26543278847973, 87.0079057447372, 58.85723936942316, 33.78252313983056, 29.21127723109338, 47.3851969934279, 79.26286420514508, 80.5463029492286, 90.47809723884829, 57.06419844781199, 1.794206723570824, 0.059333823831571694, 0.04681543770035909, 0.04072180581128886, 0.01207182677688017, 0.02669671433977783, 0.034835569245079835, 0.043114302229256406, 0.05712494336729569, 0.05595631071276242, 0.03570457725154777, 0.0187984838210527, 0.02616273190435623, 0.07929907871350166, 0.07229618472798217, 0.017448204058793285, 0.01315732261226062, 0.041784913684692115, 0.059653680861717275, 0.10011891999672498, 0.03421197750515515, 0.02443937881429109, 0.1567560224042785, 0.2127772590686237, 0.15124098608090034, 0.11059066010338646, 0.20688864762984938, 0.1253890579626445, 0.06394183503523951, 0.12960183674529677, 0.16831419010075832, 0.1542643980393487, 0.1389277468044912, 0.12835035551219218, 0.16968816879295534, 0.13523002425509115, 0.0793233024136674, 0.33313688852133294, 0.14113642425546724, 0.31789517090205227, 59.76109466245098, 133.68377347146313, 122.77403031626056, 99.21088572471373, 76.33599158256285, 59.18773435777234, 48.78904857943135, 93.57182748856084, 181.74937617394232, 135.2469478114959, 91.06553493007537, 144.7057591715167, 134.1742266378095, 112.93161115338727, 21.44670032685803, 0.6026914211050157, 0.3709723163516291, 0.3145069478740615, 0.2026214766045732, 0.7645916626338036, 0.7109315549173664, 1.8280410886772218, 9.341219682847301, 6.372671877184223, 2.869944077345633, 87.36901483228131, 118.20573206870787, 111.53031303036599, 118.21440050678869, 112.57538933907787, 118.23638146923436, 111.80987604202764, 107.04152122620614, 110.70528168832104, 113.02759939624418, 113.40111101827314, 109.54948471438502, 105.47666026699929, 102.98695148960238, 90.88647088696881, 86.14940874038204, 83.10469242834276, 78.8253551913846, 73.99249307570919, 82.28805495846657, 80.74859526849563, 77.27000205747544, 77.62260744648596, 81.86523914337158, 104.97760142049482, 98.88720389335387, 102.13965677445935, 98.5326216297765, 94.62812962070589, 86.23464968896683, 78.06865938248174, 75.45522336036929, 76.75040568074873, 86.82553906594553, 91.82411347666095, 96.18989975221696, 102.45231674563502, 96.71529339205836, 98.79039195276077, 94.30803283568352, 93.73539032474642, 95.71352005004884, 84.09190593227264, 88.95898680533134, 96.97402077336466, 86.36961060185587, 87.56867131879254, 77.79622723979335, 87.76273450543805, 92.46383636228501, 89.80117459450999, 80.54329056893626, 74.30492554941486, 76.03676180685721, 70.73473715013074, 78.1354808807373, 76.91330955874535, 80.4236190549789, 76.5592372032904, 75.46517833586663, 73.56038908804618, 75.7397364031884, 83.94025925667056, 94.28932312996157, 97.74110301848381, 100.6298972714332, 95.4820139177384, 94.94692417883104, 95.91623598529448, 94.94076605766051, 95.23524192071731, 94.26577321944698, 88.30821068056169, 81.68781465099704, 77.19279412300357, 78.17792092600178, 80.96223108230099, 80.12890000497141, 86.1949396133423, 89.01499040665166, 95.03482449439265, 95.41052479897776, 96.33108938893965, 93.41025721642279, 96.79299554517193, 97.0175120138353, 91.68297875312068, 68.85653372733825, 0.35024032237068303, 9.568039563394363, 5.98240977333438, 0.1239368387107407, 0.41718969602257977, 0.2188542055627031, 0.6030657623083361, 0.2396636663545524, 0.12938557012427238, 0.43335975898850354, 7.916387829088396, 62.32486171107139, 103.95864809713056, 113.80090252045663, 117.35264009045018, 150.78245193727557, 50.022877185575425, 23.35311539711491, 51.97790022819273, 81.03480277522918, 94.67952835944392, 97.92588587730162, 77.94581859342514, 4.050043811721187, 0.26682398071692837, 0.21123812714171028, 0.13823399290202126, 0.14100064283176778, 0.12830159401581173, 0.12773967618423124, 0.22718755678544122, 0.1084134841878568, 0.17824282749525963, 0.16796224930834386, 0.09255659030449968, 0.1274274187462945, 0.21833079897107618, 0.3500512518709706, 0.14738745656946015, 0.1440567514228244, 0.14470195067265343, 0.16710643716637166, 0.15669484262264546, 0.14917639444672293, 0.10751258011066145], [0.06950845205855948, 0.06244690255111745, 0.04222748267854895, 0.025426486935166102, 0.04805444319161677, 0.031790331441668734, 0.11631797939058273, 0.018198384167326075, 0.061349500751783775, 0.04987036268557272, 0.12251387635666518, 0.028777047165579377, 0.031017867750638438, 0.15051332512690177, 0.09756262248922741, 0.04207922934344219, 0.10867067522579625, 0.9133674697049203, 63.592814937714614, 101.67871552128946, 83.4017413662326, 78.58558854749127, 33.089295202685946, 55.80671794952885, 102.68178324545585, 118.74709759989094, 67.45455311190698, 73.25068658398044, 123.42752072118945, 115.37000748418994, 87.5500322157337, 22.665382700581706, 0.22243404250231483, 0.08207424754096616, 0.013971843572724012, 0.17344684129761112, 0.18653349229885688, 0.761233255747826, 0.17408805689023388, 1.3926741793271036, 1.1809458631661631, 2.589827766341548, 73.59525895887806, 117.56641710958174, 113.81354824189218, 105.62218020039221, 96.54136765387751, 99.85941040900447, 101.98961042588758, 107.98276455171647, 109.68726973379813, 102.70213250190982, 99.64207187775644, 97.68913161370062, 102.43666648864748, 94.96924246511152, 83.47273626635152, 72.49125296069731, 69.84704202221286, 70.1948699643535, 72.23533399643438, 72.15414093386742, 72.6964399891515, 73.28100650541245, 71.6039030013546, 69.50186560230871, 75.31407294734832, 89.2252294478878, 92.33623381583922, 93.36228662921538, 85.79139832527407, 77.98780364374961, 74.21159667353477, 67.69578672224476, 65.73231881664645, 64.51227734165808, 65.7788420492603, 73.10184048068139, 81.73893097908267, 84.62008445493638, 94.83635256367346, 70.88698002599901, 76.70121131404754, 89.08360835044616, 78.3509131400816, 75.0920432613742, 80.68755534387405, 90.21395698670419, 78.57002458264752, 78.58390977305751, 75.47495288233604, 73.46656599352437, 82.47097076908236, 77.47893887181436, 74.91130044383388, 66.42453085991644, 68.57631175748764, 65.9638249489569, 64.99210872957784, 65.38763269301384, 67.234006081858, 64.31981840441304, 67.86407209211781, 65.86178056655392, 65.8200151689591, 65.53132480190646, 73.2009038617534, 77.65577500866306, 77.8909917031565, 80.21789073944092, 84.32196078761932, 86.49459300502654, 90.34320692862235, 89.30908187743157, 90.53306533444314, 87.97212631471696, 79.57098207166119, 75.24623947758829, 72.27581285661267, 66.51451787640973, 73.50565633466168, 72.89430787486415, 80.99723431371874, 78.15930535716396, 85.06719543087868, 81.02617356085008, 91.70775244312902, 81.24005256160613, 88.39700529652258, 84.49412930396296, 83.22661538277903, 13.58405730416698, 0.4960726357756123, 5.302748334023261, 0.8512145725469437, 0.13564348190782533, 0.1707167644053698, 0.08064056761682996, 0.017116677594341097, 0.14459831429825676, 0.04624530740623032, 0.2489731974539257, 1.4730435441578589, 35.39384065135833, 84.5521568482922, 90.54772715414725, 77.29505031339585, 90.07454810603973, 43.503996018440496, 18.332436469293413, 37.32848698093046, 61.40930991018973, 77.64993852184665, 64.49227325377926, 27.15880290154488, 0.7352400763380913, 0.07994698991458263, 0.03963892903899954, 0.013831068213368136, 0.030492423365132946, 0.05035098326662856, 0.013714807667589236, 0.021275355247780684, 0.04940636621247377, 0.017328299807324525, 0.0765156667799719, 0.038683640380059524, 0.03126103363390411, 0.07969333054197413, 0.05341852955039471, 0.07828003621750301, 0.018236115912816698, 0.03437045045317181, 0.050942506566042864, 0.06827849023524793, 0.07669372093533317, 0.06351738785123152, 0.07340373336187295, 0.049915611668820345, 0.046108687116253766, 0.06713338031042969, 0.023955760914231503, 0.04439335113631622, 0.0917874227067636, 0.06156740297052649, 0.05714690327764519, 0.04566098916374388, 0.02051037049011117, 0.04308979124611905, 0.08476353025123959, 0.0235239707774693, 0.06573713910315307, 0.13993574997350094, 0.7501987704346258, 80.23870283557524, 113.91745967249717, 96.49983759849303, 91.79574689557477, 53.91291526056106, 58.87569019871374, 46.253024455039736, 74.01638815479895, 71.66727281385853, 79.72596276190974, 130.69333491786836, 126.0059613566245, 96.82208384236982, 30.17783945606601, 0.15195452037357515, 0.12098753809808724, 0.053005826494265953, 0.0565943623622579, 0.1763872859338599, 0.5732403046661808, 0.5448976255232288, 1.0816122062744633, 0.7299727009188745, 5.665486676077689, 93.35199432988321, 122.81349720493441, 115.10663601659961, 110.71516606115527, 100.99660750358336, 103.98892879486085, 107.52796573023643, 110.70308516102453, 112.24030125525691, 106.80497092585411, 104.72827988286173, 103.68813791582662, 103.7953676715974, 97.42375973732241, 87.31090884054862, 76.82238117341073, 73.91840734789449, 76.87093227140366, 75.64031216406053, 77.8354666309972, 76.8888339688701, 75.60760744156377, 73.6602290984123, 71.73221941917174, 78.66065486784905, 92.38681670158141, 94.25190371851768, 95.73480283060383, 90.20027575954315, 83.66701910572668, 79.12365928772958, 70.96492536606328, 67.96643810887491, 68.94394766899848, 69.43629926250827, 75.82493812807145, 83.56641031080677, 87.38871297528668, 95.50371246953165, 79.71605485485446, 82.03189280725296, 91.92060378289993, 81.40481564306444, 79.44130851376441, 84.01460386091664, 93.40729974931287, 82.94878605873355, 82.57085000315021, 75.36428713029431, 74.46531126576086, 86.8586124912385, 82.42842089745307, 81.27231797864361, 69.67988629494944, 69.46155932641798, 69.31324666546237, 67.5385389020366, 68.15554341962262, 70.09495935132428, 66.05897380459693, 71.45491569272934, 69.76885349519792, 68.73344190659063, 68.0143145591982, 74.19389109457694, 76.73731280911353, 80.89856316966396, 82.73387155225201, 85.48981512746504, 88.13987039750623, 93.86872737638413, 91.53858061759703, 92.75842989644697, 89.82869394363897, 82.99133593036284, 78.56620419409968, 75.97292915467294, 71.76306493820684, 76.48017006535684, 76.46326464991417, 83.79995607560681, 81.30108464148738, 87.67838785725256, 83.89786627984817, 89.91049889595278, 85.42092261775848, 91.50408729430168, 88.21878848537322, 88.99630423515075, 19.364576801176995, 0.5202538027398048, 1.8866729231611377, 0.16737432279173406, 0.08492144395507152, 0.15440626220116693, 0.09734207343670631, 0.11411153125546633, 0.15491212537932783, 0.03637511868991199, 0.3070738418929039, 0.7896353833137021, 41.24011378134451, 87.73445421649565, 101.13614190009334, 82.22277887405889, 38.60519493779829, 36.79176553603142, 38.910790720293605, 45.88831855404762, 74.42986872888382, 85.77009201049806, 78.46338318240258, 35.014045392313314, 0.8398155519558538, 0.06874740499282075, 0.03235715989684386, 0.03260831799237959, 0.04069360228435647, 0.023455900034957358, 0.08024960230555266, 0.058505475941684947, 0.02766193915909577, 0.04781444316669818, 0.024518241820436333, 0.04286638468564038, 0.0626932496144887, 0.11272128851663683, 0.06435045101229223, 0.11294605105274147, 0.0727191035665812, 0.046899083010371656, 0.07370639171811842, 0.07221818165553194, 0.03367892203612193, 0.18143772057467894, 0.2664259827185062, 0.14610156266679689, 0.1759384963060579, 0.25488859132653285, 0.14740605718426167, 0.30247685469446645, 0.17459261771892348, 0.12446809004271224, 0.20786852005027956, 0.18322416100530856, 0.0809415175970043, 0.3009054551441824, 0.27479926244385783, 0.2092182290770354, 0.2456667313292142, 0.4001865890477935, 2.828320375373287, 108.27489483741023, 129.7273571260514, 112.70139155849334, 103.05498107787102, 47.407291704608554, 73.77360128587293, 133.91773500750142, 159.99666429335073, 96.53309145281392, 93.05601227668025, 149.1841959184216, 128.24846667628137, 112.06439864250922, 49.005351604953894, 0.4413164094571145, 0.14134204225434413, 0.17675050354051977, 0.44075927967506073, 0.3767830013267456, 2.3945932619033323, 2.031726952522032, 4.4558600744893475, 4.446262524973962, 3.591118166523595, 95.79049264231037, 129.4981259684409, 121.23332331257483, 115.32671236222791, 105.78284048265027, 108.62943003254553, 112.75580267752372, 114.25838424313454, 119.3506326983052, 113.22739708808162, 109.22628925692652, 110.36390996748402, 111.60987438694124, 104.42237423312281, 93.10253158692392, 81.401732660109, 78.38892875179168, 81.39628056556948, 81.57429341346987, 80.46338404378584, 81.5317435418406, 79.52538059603783, 78.76282476609754, 76.63238940700408, 84.68728250072849, 97.3893056377288, 101.0956238162133, 103.82205547824984, 94.4083905989124, 88.12184318419426, 81.67020320892334, 74.55876565748646, 71.65010067724413, 71.8741778404482, 73.36121113069596, 82.73665643507435, 90.31864504660331, 93.0998565304664, 100.88463952464443, 84.13875472161078, 87.50807854437059, 96.64786000405589, 85.29890552643808, 82.84239569017964, 89.13244970383184, 99.40196791002828, 87.03036523634388, 87.83875788411787, 77.7135201423399, 81.09607019732076, 93.77589271914576, 87.65654025539276, 84.24367812372024, 72.41955203394737, 72.04079228062784, 73.05975344873244, 73.10506466896304, 72.43506893034905, 72.31008652717837, 70.00062634868007, 74.58700672272714, 72.67489833216514, 73.08088717922088, 72.07320674773186, 79.9651724292386, 83.17229055589246, 87.80681410143453, 86.21897589775824, 92.07823599538496, 95.35169709113337, 98.75793041721468, 93.93361906851493, 98.00099142136114, 93.25345654641428, 85.9141763564079, 81.63781227604036, 78.89325141906738, 74.34995435899305, 80.71101896224484, 80.96243504554995, 90.49027227586316, 83.80404318532636, 92.99610983940863, 86.95796612770327, 97.4760841554211, 88.27629043209939, 98.5769130337623, 90.3544641310169, 93.6737463551183, 22.314448241264593, 1.386562146006092, 12.258959066483284, 0.9454587702789615, 0.38497220544565114, 0.4445888612779879, 0.31296787723418207, 0.23584289476275447, 0.3012404807152287, 0.14663577109815615, 0.633476265976506, 3.0518515936789976, 55.5788125530366, 99.74598330836143, 106.90343026191958, 103.10726627226799, 122.26841326682799, 59.23916839784192, 28.59707916936567, 50.4207859500762, 86.78011801935013, 97.47962997805689, 92.31240933941257, 52.05106419901694, 1.9164796269709066, 0.1622401394190327, 0.2027854347421277, 0.09619255084544422, 0.09392007359213407, 0.15620911223513467, 0.24320421830540706, 0.17562525827557812, 0.14946311051326414, 0.08735522102083891, 0.16356945518524418, 0.24453544929142923, 0.17519382820014032, 0.20716537390985798, 0.15444033779203892, 0.21527254533383156, 0.09225727209160406, 0.14251509140576088, 0.148530567004796, 0.1329495796873685, 0.15701253928484457], [0.07580451502074158, 0.029683922898144494, 0.08466232237556288, 0.12463986993797364, 0.04515651260472594, 0.04843713092287222, 0.01476301896130486, 0.008468703637200018, 0.026271365087239013, 0.006394899795733152, 0.1912559800210499, 0.0464946115689893, 0.051252986679995255, 0.1021757128558332, 0.10189232161088337, 0.13009740370175532, 0.56715315388095, 14.483769593700288, 98.27462380932224, 90.20142109163346, 69.75797284033992, 42.50360335073164, 40.63394285017445, 93.00013419120543, 136.79375802316974, 86.55187529902305, 118.48328682684131, 127.50968040958529, 114.28631151876142, 84.22612943956929, 19.481330071726155, 0.08055750070320022, 0.012693854739829417, 0.14556352379581622, 0.06513492504675543, 0.1193106635623882, 0.09908350620178447, 0.07570255637889908, 0.18194035086179935, 2.183681289034505, 4.928914097047621, 85.66927140758884, 115.49951630253946, 102.5911529602543, 101.83310785601216, 94.1500005414409, 88.97554705219885, 88.36650494606265, 99.25229026425271, 101.09796939357635, 96.32782597695628, 96.25881579614456, 89.35164743854155, 85.0879918375323, 81.48706774557792, 78.41787584366338, 70.37533037124142, 69.83420802700904, 70.59834064975863, 73.34973427557176, 71.91013813018799, 76.49846399984052, 76.4836609748102, 73.4424198827436, 69.3742238321612, 67.36433075320336, 71.2366436373803, 88.78795577633767, 88.93830022504254, 87.84082889556886, 85.75861515537386, 75.17835893938619, 70.76887746011057, 64.81012252069289, 63.936575381986565, 67.53645220110494, 67.11950425178775, 65.77585712555917, 74.62694429582166, 81.2334551349763, 94.40029482687675, 74.69967288355674, 70.67489747078189, 86.31336381358486, 71.98094475653865, 78.68492649447533, 81.32446196771438, 85.98759528129332, 91.52891589749245, 95.10268149837371, 80.3390762882848, 65.12020157229516, 78.78407616769114, 82.84489031760924, 79.21907486454134, 77.44875231096822, 69.96727835747504, 65.03451347351074, 64.57913021887502, 65.98247189675608, 64.3723467857607, 64.59714958744665, 65.75144429360667, 67.36006321445589, 65.50786118353567, 65.01524286885416, 63.89122886042442, 64.83838319778442, 64.08742973881384, 66.83524224065965, 69.02819233555948, 73.7744406730898, 79.2553803228563, 88.61210023203205, 85.7852872725456, 84.65561328395721, 77.98321447064801, 77.81439565843152, 71.13066119532432, 68.60799666373961, 69.20224358958583, 77.04899218774612, 71.62949254435878, 77.16580821621802, 77.302338077176, 84.23524502784976, 79.9521109365648, 90.58497398130356, 84.99159566817745, 85.15912009823708, 84.41491311596286, 44.27737759005639, 0.5212187670892285, 0.6754889567532848, 0.1921661384403706, 0.02840957011006052, 0.21241249396435677, 0.042430725804860556, 0.08716056574015849, 0.08368131614500478, 0.020422107585135008, 0.12712419348498508, 0.15748693157107602, 0.9632880877583259, 29.350352710293187, 79.59038211453347, 95.58642741172545, 100.8430310218565, 73.91681486560454, 22.557492025436897, 33.84423378975161, 49.54158275358139, 69.6578033508793, 71.15403852155133, 82.86287046247914, 19.190892288761756, 0.7690806927219515, 0.14714926451204285, 0.13426456960939592, 0.05299036683995397, 0.09462006345030763, 0.06088888655687052, 0.14714471394977263, 0.05731783281531065, 0.029657655658440727, 0.038071842563729134, 0.03594038294508092, 0.07350452755007052, 0.08466423759537359, 0.10103067953980739, 0.10102191549395362, 0.015724216073360896, 0.058123994798910235, 0.0318523577504581, 0.052845055282476454, 0.07852965830675057, 0.0884360331861723, 0.06554688116715801, 0.037382455362427625, 0.05510458181942663, 0.048448403906678005, 0.05189244410083179, 0.01566487490274613, 0.016618299095200437, 0.015278865222729024, 0.05948322629856487, 0.15290284529328346, 0.08044004410264954, 0.06867764502643578, 0.19381969325965454, 0.1559274370271352, 0.11179455195463474, 0.804315772989104, 19.123072547297326, 117.04926829184257, 100.80813761680358, 88.09068387554538, 54.77344405266547, 39.52617529899844, 95.1901738874374, 123.52727443941178, 90.46930328492196, 117.00893063699047, 130.90624117082166, 128.07816520813975, 91.05518771756081, 23.374109883462232, 0.8781303056786138, 0.06319276958463654, 0.11524288990204373, 0.08527331579957279, 0.1114884308809715, 0.12325927224611083, 0.12359123346546005, 0.5931386724114418, 0.807738715121823, 8.412632865290488, 102.01516858993038, 118.426145738171, 108.42830657958986, 103.75077816747852, 99.86211684442337, 93.5552986206547, 92.20303796952771, 100.16929334209811, 102.98914801689887, 96.95731932117094, 99.06018826269336, 91.23562459022769, 88.22282068191036, 83.33060526078748, 82.2388449022847, 74.7703226151005, 75.2883186647969, 74.02629606185421, 77.42911692588561, 78.08189345944312, 80.63013968929168, 79.52430586661063, 78.5293496039606, 73.1457474923903, 71.75652242475941, 74.34068187590569, 92.29034992956346, 91.7226182260821, 93.1227788617534, 86.60794950300648, 80.1099314228181, 73.33402910540181, 69.71853733062744, 65.1569345689589, 69.66356139029227, 71.29658529835363, 69.95992783577212, 78.49765685296829, 86.05298119206583, 94.8237931343817, 84.2953828073317, 77.79388950717065, 88.51377425655242, 76.8539248743365, 80.12002760364165, 83.48569577740085, 91.21834262724846, 89.95864991218814, 96.99989272702126, 80.01285276105328, 65.96719034256475, 82.7105805181688, 88.78282531615227, 82.27227134089317, 80.00165047184115, 73.68020965207008, 70.25785538458055, 68.70687177104335, 71.3463052626579, 67.08650142915788, 66.98302145927184, 67.1357193300801, 68.43982896497174, 68.30430323077788, 68.98924319974839, 66.84449903426632, 67.51800137181436, 67.51578131029683, 69.82364900650518, 72.0291663754371, 77.07706851343956, 81.0097074508667, 89.21026168331024, 88.52783203125001, 90.60657055147233, 82.11154830071234, 82.94012546539307, 75.44846119419222, 73.23632286440942, 70.43771959120228, 80.05336300019296, 76.39099890185942, 81.33294997676727, 81.76481077747961, 88.33074861957182, 84.494152838184, 91.9092445988809, 90.40358005031463, 87.98419152536701, 90.18908131507136, 54.28435979350921, 0.5179955594001279, 0.997549255769099, 0.595518202791291, 0.023377113637604544, 0.23395736851999838, 0.010165412189258684, 0.16064995539284524, 0.12421099859620295, 0.2150768098691779, 0.047289906595382965, 0.2157044657055409, 0.3842199990345586, 36.10781400434433, 83.73115770278439, 102.71899084891044, 89.78785422540481, 45.56991231056952, 27.69514583772229, 47.94091447707146, 64.95491289323377, 77.96038627624512, 79.75621992541899, 95.82114988757719, 24.908737213380878, 0.598418427811515, 0.19144983090940984, 0.0708134368722958, 0.0738837487334686, 0.051724950467506726, 0.12969981939081224, 0.0352018665251953, 0.08345620120845496, 0.030843770439406077, 0.029718733933423797, 0.02303881878634134, 0.04782838596692009, 0.13483840010819897, 0.03360577979155126, 0.08919924061985747, 0.04327067226592091, 0.08475827488807902, 0.06726910044709522, 0.06409542034229924, 0.11310788712674573, 0.18914165395882823, 0.13393460021864984, 0.17379770956693158, 0.27091602404271403, 0.1193673617296642, 0.1850958823436691, 0.10675717911292469, 0.1307685120451835, 0.11639102587416289, 0.12454017125550779, 0.2385837428512112, 0.17822303178329624, 0.17520666783375127, 0.41042167693376547, 0.32140002315563543, 0.38960237957296834, 0.9565121932856498, 31.900450298863074, 139.46184835126326, 112.36875103365992, 100.54701758969216, 63.00705994329145, 64.0660685108554, 109.15760855520926, 158.8218673583, 114.44109609050136, 139.81260238155244, 151.71115936771517, 134.46137551338444, 107.61155928334883, 39.03084270415768, 3.9103902732172324, 0.18579542787084657, 0.3820777107631007, 0.29302473931062606, 0.3640770347368333, 0.3135744962961443, 0.20562720725372916, 1.5509021017820606, 5.742307276495042, 6.992357825079273, 100.89160565407046, 123.31211674597957, 110.64877602361865, 109.05364221142186, 103.6241562135758, 99.65279563780754, 97.79465121607628, 107.4880438466226, 109.80211673244354, 104.9315998631139, 103.43276023864748, 96.835859206415, 94.1238618666126, 90.033080808578, 88.59267665493874, 77.92180584323022, 77.23423788624426, 78.59953649582403, 79.89712715148926, 82.21421241760254, 86.95917421771635, 85.40837103320708, 81.88981671487132, 77.50138267394036, 74.1214370727539, 78.65806610353532, 100.94334956138366, 98.06804826182704, 98.31791108654392, 92.76130891615345, 85.22147009449621, 80.15112415436776, 73.23869982073384, 69.1659616654919, 78.00164961045789, 74.57782053178357, 74.50781406894808, 83.30594139714395, 90.09358729085615, 99.94614185825472, 86.12910655237015, 82.84019916288315, 93.19746863457465, 80.2271318435669, 86.65958358395486, 89.68224048614503, 91.75156531795379, 90.66541394879742, 93.71442917854556, 78.8921453106788, 70.18682126075991, 86.09794724372126, 94.2373909488801, 88.46307369970506, 84.11521265583654, 77.67219405020438, 73.51180661109187, 72.23159205528998, 75.20388572446763, 70.06231738675025, 69.67332024728098, 71.67074018909086, 73.24028445828345, 70.76860289419852, 71.90080288917788, 71.48279589991417, 70.84995285157235, 69.9001116906443, 73.01055908203125, 76.65860652923584, 82.52918658717986, 84.590439181174, 95.33320703814107, 90.44083472221129, 92.8799919928274, 84.15627202680035, 85.66408603422104, 78.97945727071455, 76.33985903955276, 75.24445872153007, 85.5947385295745, 78.62744023722988, 86.750864982605, 86.97770349441036, 94.16853766287528, 87.1902096656061, 97.18186716879569, 93.60462634794175, 91.6921414098432, 92.90707203649706, 60.528729961764434, 0.7067438731751134, 4.385998739350227, 3.001502334110199, 0.09741816128934584, 0.599668438155805, 0.25137204857122514, 0.5598616515917163, 0.3806414797661766, 0.38956946843574125, 0.29666831476553795, 0.34106234388966716, 1.5174669604147635, 48.558809372686575, 94.84070639456473, 112.61319314279865, 132.0835719570037, 100.16845395488124, 29.643442015494074, 49.29131984710694, 69.47859810244653, 93.97286630445912, 89.32494394240841, 109.56953587070589, 38.55516902862057, 1.1299209753351829, 0.2230755645301073, 0.13226405356920537, 0.21024428127754122, 0.18804858438670638, 0.15497776379268016, 0.356068566081024, 0.15585684968579203, 0.08790944732965962, 0.2846317864473789, 0.09765719604347983, 0.11188710303676706, 0.15598172201744973, 0.11074026175323995, 0.17982636187826434, 0.25373912236142543, 0.19416549002691624, 0.11395652868574667, 0.1175233344697664, 0.16148617100571433], [0.01250432650258224, 0.012213788614908775, 0.02062601146228131, 0.03619308470778408, 0.026589268593177683, 0.06478192705300546, 0.1528156338439834, 0.04833167125921577, 0.07240115409536708, 0.10854694436514571, 0.08171925005773384, 0.009837983337591493, 0.052622257761897585, 0.061517136111374826, 0.05095435411579186, 0.02037912239170363, 0.16112425574852576, 57.685356755410474, 92.09522770297144, 87.80584919837214, 50.438126748608006, 82.01577186584473, 88.74768872414866, 36.936936378479004, 48.725074721920876, 92.89578345514114, 124.39254145468436, 110.83422568536575, 92.01502307768791, 13.99451373084899, 0.27188696387794714, 0.32765390531670663, 0.004693959565502742, 0.12428451239341691, 0.04609061893255961, 0.1292905905434201, 0.10529136180036491, 0.2963202044127449, 0.21965565610556836, 2.2947883077206153, 85.2204502782514, 114.25102587669127, 100.22773665766563, 107.69596084471672, 99.20487665360974, 89.75168997241606, 76.64501943895894, 79.58791886606525, 76.25470438311177, 82.32083812836679, 79.55701843384774, 79.82467312966624, 69.476150543459, 70.25219932679208, 72.1160311852732, 71.81402437148556, 69.87787969650762, 73.09988714033558, 74.95199895674183, 79.59977226872599, 80.44811817907518, 80.90964778777092, 78.38189201970255, 75.69671584713844, 67.48404933560279, 69.29330533550632, 68.72492251857635, 85.52458301667245, 88.92785887564384, 86.68229410725256, 82.02827638195407, 74.36613805832403, 65.99589424748575, 65.92475814204063, 65.05723576391897, 71.76933288574219, 72.9281500847109, 76.3472487849574, 77.89790291940012, 81.89513544882499, 89.69313683048372, 81.68083283209032, 78.172986584325, 81.89726921819872, 71.23770267732682, 77.66895417244204, 83.80278802687123, 81.53162587073543, 96.99823748680853, 104.84042044608825, 78.07160900485131, 56.9971808310478, 71.94623178051364, 83.35629678541615, 82.72714860977666, 82.46934690783101, 76.48467294631466, 73.5369646933771, 70.98031674661945, 69.44381452375843, 65.61689130721554, 63.575611422138834, 63.72091170280211, 65.4174505510638, 67.19226421848421, 67.70783624341412, 70.71604313388949, 67.70660461918001, 61.33998201739404, 62.72202130286925, 65.5673360824585, 68.14220736103674, 70.1377445651639, 75.62212805594169, 79.33276084161575, 76.96128014595278, 77.16273307800293, 76.20566691121748, 71.23695742699408, 68.6821843731788, 65.4743915988553, 69.34999927397698, 74.05231706557736, 73.5917680494247, 73.51711750030518, 78.48772541169198, 80.70013046264648, 81.61634906645745, 82.59574920900407, 87.01934337615968, 81.7743892054404, 74.48559776429208, 3.0225152065677032, 0.5092555380636646, 0.24702664464712146, 0.17097306678131705, 0.013925934796251599, 0.09534023206440673, 0.10658464845149748, 0.21353067589863656, 0.015556405471157164, 0.17421691287909785, 0.17419475761632766, 0.368554481575566, 2.8129186985954164, 36.963443756103516, 61.005435220656864, 48.76461221325783, 75.93478802711734, 67.96290013097948, 15.953508173265766, 26.694180503968273, 56.387479766722656, 61.51961088180543, 71.91878303404778, 52.37726026965726, 3.6903364812174155, 0.17564548299677912, 0.08544747822827871, 0.05840008522594168, 0.04671252144861125, 0.13368122429857332, 0.08254608109353051, 0.02521949572368495, 0.03568607239773677, 0.025119944513144515, 0.06049832344175347, 0.03953277989621124, 0.15061614944809867, 0.05433881565207436, 0.040246168632180467, 0.013212291336047554, 0.042201826393964796, 0.02979717942165031, 0.02821209562581874, 0.09708938699576164, 0.0388008096976386, 0.021038067174114047, 0.07282374351615868, 0.10815166597885471, 0.04300620339270081, 0.022868977093528357, 0.07098369991346713, 0.038221961322931514, 0.014393593169628613, 0.06837804336100817, 0.11842394743355052, 0.07347036002864761, 0.026126024801464334, 0.03438816240598117, 0.09036434543949944, 0.027823373036939773, 0.05090023766482069, 68.91859346820463, 105.46337127685548, 101.07471758319487, 65.8967524190103, 76.39889855538645, 78.8929376294536, 35.0699274001583, 58.23700674118535, 96.55792005600469, 137.0029144902383, 121.15622520446779, 101.23698603722357, 16.31761787399169, 0.4159987050919764, 0.5020025240317468, 0.024615270686486078, 0.03670935135995669, 0.15975442925287833, 0.18712624516938964, 0.13447538168439943, 0.3009212059119056, 0.5613511716646533, 4.160163373716416, 99.24256278622536, 114.57808094639933, 103.40922601761358, 111.70373670516476, 102.84656201639484, 93.91403075187438, 81.2893489099318, 79.91046321007514, 79.75866748440652, 84.3711551543205, 80.51183316015428, 80.81683666475358, 73.66516344008907, 74.86517337060745, 74.51413692966585, 75.4590202146961, 72.66243303975752, 77.57269920841341, 80.30941532504174, 85.53806812532487, 84.99955807962726, 85.96512010020595, 82.22948612705355, 79.00384656844601, 70.41274193794497, 73.26883931313792, 70.95352695834252, 87.25799606692406, 92.62747764587404, 91.98563668035692, 84.29647322623961, 78.23978454835954, 70.6846014145882, 69.36740675280171, 69.15726969319006, 74.96751585314351, 79.27751818010884, 81.12387195710214, 82.66135477250623, 87.88308066706504, 94.20041868763586, 86.2239259289157, 84.2069019809846, 85.57761346140217, 75.86787239197763, 82.05623503654235, 85.53705615382042, 84.95649045513522, 94.88874758443525, 102.19313436938872, 81.7586918800108, 60.7740310699709, 71.51069964132002, 86.66120744520619, 86.18427861121394, 87.95435013309603, 81.86842410795151, 80.05680684120425, 75.57236886793568, 75.65040834488408, 71.54935067699802, 68.5005158762778, 66.76067013894358, 66.78807966170773, 68.78510736650037, 70.64673485294466, 74.30489417045348, 72.8977438711351, 63.99427344722133, 64.79862213134766, 66.66869055840277, 68.84872821069533, 73.37970118368827, 76.90308001733597, 80.51286866587978, 81.52946856714065, 81.56419723264634, 77.91838553643997, 73.42815814479705, 70.78508469366258, 69.36833243216239, 72.28239459376182, 75.91170095628308, 77.51320469763972, 75.79868962687831, 82.08008304719003, 83.63524790733092, 84.54253135188934, 87.11629652207898, 91.57215610627206, 84.84666409031038, 78.39546342049876, 4.50557170375701, 0.6791679561138154, 0.12138707593323723, 0.2136294552755933, 0.02974567533050093, 0.193147910758853, 0.10029521214986041, 0.3046572328575196, 0.06375195631276696, 0.24236375856543743, 0.07735756676523917, 0.35770575726224535, 2.622982825963728, 46.37162123956988, 68.98695253556775, 55.5408557768791, 61.80501430265365, 50.38554345407794, 27.802206931575654, 37.03845124090872, 68.79379149406188, 74.31646516246181, 81.29871552990329, 65.00110272438296, 5.502866679622281, 0.13279270020223435, 0.1439599945179878, 0.054487241356964075, 0.02817741099504694, 0.09304201425684076, 0.024463263520550345, 0.033259351001752, 0.1460425432531103, 0.05112999892463127, 0.018674473338309797, 0.04941352913456579, 0.0363858783948085, 0.029409366562181426, 0.05059186046222045, 0.05702184708488565, 0.07522848584959585, 0.02698167989541206, 0.014722942029156033, 0.0849750777706504, 0.16987351610535578, 0.26545393971666215, 0.2288446049656599, 0.18321184231148613, 0.13444777187560836, 0.1449096983959598, 0.37074717843244154, 0.16047248346430643, 0.12987635669208344, 0.16685958831541, 0.22276537552956613, 0.17915113198180355, 0.09942420082347048, 0.10836754189503771, 0.23277460537370176, 0.19499286498513915, 0.4932537999364638, 92.20748593730312, 118.5704654262912, 115.49759434115504, 72.73806418142011, 104.19319014395438, 110.21904899228005, 48.536240054715066, 73.80430559958182, 113.2749911277525, 146.38625944814376, 127.08089474708804, 115.71550553844823, 19.950535758849114, 0.44148390692087913, 1.1256721904200893, 0.0893846798628088, 0.18130003925292723, 0.26665026261921854, 0.549854765976629, 0.3809002642669986, 0.6534211505805293, 0.9516039598853359, 3.914077056031074, 96.75428175157117, 122.85995375725531, 109.98994335051506, 116.70123638645296, 108.85439365140854, 100.88286661332654, 83.64806621305405, 85.79290451542025, 84.90127132784936, 90.11058684318297, 85.8033380200786, 86.351653991207, 77.93064686559862, 79.6397098418205, 78.07480965891193, 79.34914850419568, 75.94343293097712, 80.96274883516374, 84.57059983284243, 89.39510730005081, 89.22975586306664, 89.01755563674435, 85.67655917136901, 84.36081578654628, 74.14027229432138, 76.76349070764358, 74.76631395278439, 93.27739084920576, 98.66041244999056, 96.43886043179421, 89.02546313501175, 82.37301349639893, 75.62423829109439, 72.70997216624599, 73.08442515711631, 77.21129986547655, 80.64848069221743, 84.68088119260727, 85.0396760817497, 93.09558114697857, 96.58099928209859, 86.50316730622323, 87.36770476064375, 92.9087821898922, 79.5131584905809, 87.97723324068131, 94.53999396293395, 88.68010628607966, 90.99157471810618, 94.5850855304349, 78.55444492832308, 66.14603473294166, 75.92571950727894, 90.98881336950487, 91.48064721015193, 89.78499089517902, 85.87923588291292, 82.20476735022761, 79.97365259355115, 78.83909133172806, 72.36630978122835, 71.53422601761358, 69.05306016245197, 72.17664749391618, 72.70217449434342, 74.72820420419016, 78.04965157662669, 75.49506679657968, 67.72205875765893, 69.85010931568762, 71.53058605809366, 74.2732249536822, 77.76909228294127, 83.45087297501104, 85.98651270712577, 83.00039660546088, 85.38018488114881, 80.92546278430571, 76.80778211162936, 75.0623744533908, 74.04582946531235, 77.39580031364196, 82.93847022518035, 82.92252186805972, 80.24622594156574, 87.46141018406038, 88.81387479843633, 89.68544898494598, 91.4284247736777, 96.65211185332268, 86.1952377134754, 88.88765458137759, 4.606813471163473, 2.029444133081744, 0.4489149597863998, 0.36180500181451924, 0.2660816415183006, 0.331133017016034, 0.23915590327833933, 0.593141736763139, 0.34472681822315343, 0.5509140510712901, 0.3556623862635705, 0.48412371727247394, 4.8432191341154045, 60.32542174862277, 78.25129278244512, 67.880169499305, 101.55338010480328, 89.85196928824149, 23.0429853547004, 43.21387398627497, 79.01711202436879, 86.2610472402265, 89.5525747729886, 83.81689287001088, 11.739459768418344, 0.35238003658671535, 0.3885240035672342, 0.165481855792384, 0.10470595571302599, 0.25062152755356604, 0.12252843968810574, 0.1049039894414525, 0.22430323575052524, 0.13841940150145562, 0.09358888612158837, 0.20688584374804653, 0.1419672772528664, 0.13070492674746823, 0.3110201446519744, 0.1389275016563554, 0.15000304928229702, 0.1292336242453706, 0.190107062639248, 0.20536606320210044], [0.06875173338959295, 0.04724946864429982, 0.040076200534859975, 0.1384621185641135, 0.09425295411699242, 0.09420667474548663, 0.04436743055139819, 0.04168127731029545, 0.039787737787851406, 0.12127292883251944, 0.1734566472230419, 0.13975279285542427, 0.05526911069248473, 0.0739419867374724, 0.11447883977164185, 0.20560100704671877, 7.381347610104469, 86.60532935973137, 83.03776894846271, 69.28209520155384, 63.12654318348054, 112.39168120968728, 79.79876195230793, 88.4024573910621, 81.39273474293371, 118.57686673441242, 117.48421992025068, 95.9438180923462, 15.954269113079196, 0.25855746300470445, 0.29449863118990777, 0.04515873425970635, 0.02853519703832365, 0.04548573505974585, 0.3091621669309755, 0.2293643956222842, 0.1310079604867966, 0.29193248179170395, 0.831411567426497, 42.34016995276175, 110.48187132804625, 96.36741838147564, 106.41656998665103, 87.91337705427601, 79.5176927505001, 73.6980172126524, 79.41435398594027, 76.90057754516602, 78.2912068213186, 73.32023020713561, 74.1610530114943, 71.86186159810713, 71.75431020798223, 72.73397707170056, 77.60337214316093, 73.94522067039244, 72.00152935520296, 79.40854103334489, 85.52820728671166, 82.88307066886657, 82.2385311126709, 78.38742256164551, 75.05547108188753, 67.77486170491865, 65.90436966188493, 67.14348562302129, 67.55523250948998, 77.39895389926049, 85.99705603814895, 82.7878119868617, 80.52654204830047, 71.39100459314162, 66.66592920980146, 65.73251493515508, 68.75443443175286, 74.6087601877028, 75.40604468314879, 78.91380463877033, 76.6643802581295, 85.48334321668072, 85.83111624563895, 81.63288577910393, 80.38379915298955, 78.73139873627694, 74.13340030177947, 80.40246179026943, 79.19462280888712, 72.6490185337682, 91.67137638215097, 94.33217110172396, 68.06670957996, 51.49340514213809, 62.855279907103515, 75.30225876838931, 85.74295705364597, 86.50636796028384, 80.23378418337914, 77.27060610248198, 77.7056126440725, 73.1380674915929, 75.23148352100004, 71.73958563035535, 68.56125770076629, 66.55711481648108, 65.13105869293213, 69.8616018602925, 75.41101040378695, 78.33338799015169, 67.39961639527353, 60.791924922697014, 64.66453590700704, 62.3594452488807, 63.23411026308614, 63.65112489269626, 66.63321664256435, 65.28783582871961, 68.17694387128277, 66.82402426196684, 65.77949708507907, 63.20637518359769, 66.96559044622606, 66.31613223783432, 66.65450726785969, 68.028286041752, 74.2273332226661, 80.74518280644571, 78.13024843892744, 78.97987304195281, 80.55968607625654, 80.95564934515184, 83.81650063299364, 89.46385860443117, 15.039083073216101, 0.5571812631622438, 0.1205199103682272, 0.07119088839258879, 0.025689877539632783, 0.11666217503408272, 0.06998695057606505, 0.09149278529108533, 0.15912449047450097, 0.05945154090201663, 0.09302529821833296, 0.08965725394626779, 0.2947987537951239, 12.194917548087336, 54.38971857870779, 41.856824121167584, 69.96210082884758, 79.06110532822149, 36.49416746631746, 22.034024269350116, 33.58260777688796, 56.654655933380134, 70.1541792961859, 70.08887967755719, 43.48125803855158, 4.593511733316607, 0.09330839834987156, 0.10678739362065831, 0.09387196327048926, 0.03908818076935507, 0.1599151391776339, 0.05444661571433949, 0.02732458085032, 0.05784051928428873, 0.05103243762747415, 0.0910079435655667, 0.08302673997898256, 0.014415372091706001, 0.03538504197833038, 0.053869276532843235, 0.18055624448724333, 0.08312248564775913, 0.07697919593943704, 0.050413890576530854, 0.03138904118039195, 0.04047335583656546, 0.03815386376734223, 0.13183165822298298, 0.06099779361618623, 0.05582216105634167, 0.03193122458704297, 0.03959588638897385, 0.05209435423415515, 0.07027090872607886, 0.13943200119801108, 0.12111802585422994, 0.04048414235453933, 0.07925263080265253, 0.03901078290636501, 0.3556744291657402, 9.617544777931707, 105.68650707121819, 93.08912492567494, 86.37135997895273, 65.87374379557949, 119.63399256429365, 83.64205714195006, 49.02871324170021, 81.09082991077055, 132.27140641981558, 122.63926552188013, 107.31432991643106, 19.80123269942499, 0.49451839659483204, 0.26604039534445734, 0.09865284221427095, 0.037179319488425414, 0.11946936633678214, 0.5212923115299595, 0.11678911580313599, 0.12381894544007317, 0.47878779230579255, 0.7226685735006487, 54.580318312491144, 114.32112647641091, 101.99620000777706, 109.09852197093349, 89.77429066934894, 83.28687083336615, 76.63431921312886, 82.77968483586466, 77.53189871388098, 80.34616793355634, 75.01885967869913, 77.45453388460221, 75.54011914037889, 77.2338770281884, 75.43500746450117, 82.09276014758696, 78.22031390282416, 77.56889450934626, 83.09459624751922, 89.35190631497292, 86.19099370894894, 88.51230729010798, 82.08567634705575, 79.5027171411822, 71.60399713823873, 71.17922013805759, 71.40590175505608, 71.58020404077345, 79.090162246458, 89.02973851849957, 87.45345561735093, 83.88610701407157, 72.01746986758324, 71.77866028201196, 69.69770954501244, 70.86223771495204, 78.81026191096153, 80.88117138031991, 84.58178643257388, 83.30249755613266, 91.0177683061169, 90.4172848116967, 87.67734450678672, 84.38637395058909, 81.43532383826472, 77.49010193732478, 84.22907121719854, 80.5002150997039, 79.68311479014736, 94.78532252773162, 95.28324388688611, 77.14050108386625, 58.536609142057365, 65.65411852252099, 75.67358955260246, 87.73923166336553, 91.45502628818636, 87.313489760122, 84.07563594079788, 85.52207269976216, 79.07326467575567, 81.51256315169796, 75.06280591410976, 72.48119600357549, 69.35494930513444, 68.47978222754695, 73.73734289600004, 81.19988749104162, 82.88168214982556, 73.51179092161118, 63.725120405997004, 67.2030193574967, 65.2879495774546, 65.23530744737195, 65.41256720019926, 69.29915751180341, 69.58236832772532, 70.09590856490597, 69.97596248503655, 69.11296259972357, 64.85492775517126, 67.68075619974445, 67.49666367807697, 69.92457943577921, 72.39565695485761, 76.71279015079622, 82.32737279707386, 81.06664457628804, 82.19801302879088, 85.45623963879001, 88.1650677034932, 85.97407879367952, 96.498425545231, 19.476307476720503, 0.668297720051581, 0.0660973459842705, 0.12700904280908648, 0.04470087032044127, 0.19017256315677397, 0.02548856878532998, 0.15422943378648452, 0.14317521404835487, 0.07845169353869655, 0.299645240508741, 0.09772795192416638, 0.41124929704012414, 13.062602704571141, 61.50721226969073, 45.099172976709184, 71.76554387615573, 48.24329783839565, 33.02603129417666, 35.77021952598326, 47.555212128546934, 68.12447040311753, 81.70482989280455, 81.917830282642, 55.400485915522424, 5.059328982906957, 0.09146417190711345, 0.07260366177727139, 0.04469983227130386, 0.05463659019780256, 0.03615965263076848, 0.01770434747149627, 0.006181635760567001, 0.031170926372250243, 0.05809063550024744, 0.044861373401457266, 0.12650136400254505, 0.04123225019523694, 0.04512173987384285, 0.11403763441429024, 0.043703626856328025, 0.02495219232514501, 0.1393356120153781, 0.0814699880298107, 0.1497296631456383, 0.12219129205350915, 0.13718762404976353, 0.2567930552627771, 0.1390066232171751, 0.28096734275740964, 0.18123646927697046, 0.18423490676908724, 0.18396896700705254, 0.19505226744278786, 0.22390350639339418, 0.2977965477733843, 0.13079751613399676, 0.1628401854466046, 0.25241948994657687, 0.6008451492074998, 18.390413022810414, 123.35896553531771, 106.37954281222437, 98.40505830703243, 81.53798011041458, 131.270292035995, 89.58972746326079, 116.44622741207, 110.92698189520068, 142.37475733603202, 134.48897330991684, 120.63001571163055, 25.24630423515074, 0.5527907826246754, 1.0333740398768456, 0.3615228056667313, 0.0983519075558551, 0.29662936685546754, 0.7939409200222263, 0.7478802819405833, 0.41866680547114343, 1.1562111517114024, 3.1432496828417626, 55.32061861407373, 123.29559572281377, 108.60668813028644, 115.43293799123457, 94.5217941653344, 86.74998637168639, 80.9174846833752, 87.35040710818383, 83.01214802649714, 84.65270288528936, 79.96816127530991, 82.67332584627214, 78.54054404843238, 80.39078097189628, 79.65019041492094, 88.18930010641776, 80.59189658011161, 78.48501113153274, 86.00197469034504, 95.79926306201567, 88.58424355906826, 92.49027313724642, 84.32656565020162, 85.10181427001955, 76.1633445370582, 75.70430955579205, 73.57305834370275, 74.29126001173451, 86.3138109637845, 95.59020857657157, 89.0842673086351, 91.11305052234282, 77.96739162937288, 75.42167925065564, 74.01465446718278, 76.21170736128285, 82.81880655596333, 84.56426128264397, 88.87547954436272, 84.95099129215365, 94.66949493654313, 94.1153738575597, 88.91931595340853, 87.6944617302187, 84.75832446928948, 82.79400933173396, 89.22650814056398, 88.91885311372819, 80.69609826610935, 87.87905631526824, 89.21230131579985, 71.88767079384097, 64.19591073066958, 69.35261941725209, 79.73703169053601, 93.93807488103067, 96.63383360831969, 91.29944155293127, 87.20653457026329, 86.16258005942069, 82.34817704846783, 85.7347357657648, 79.60403980747347, 74.58655172778715, 74.96117730294505, 70.83059987714215, 76.84819821388491, 82.49052770676153, 85.51440054370512, 72.80723910177909, 68.52437957640618, 70.96480769495811, 69.07892427136822, 69.4508747900686, 69.73352862942603, 72.9687701502154, 72.7408725984635, 73.49042969365274, 73.78383082728233, 72.83117340457055, 68.53522100756246, 72.31764101213025, 74.53818105882215, 74.10152712175923, 78.88155491121354, 79.56850313371228, 88.89533458217498, 85.4108185921946, 87.69006867562571, 88.12750708672309, 88.91300878217145, 87.28789237237747, 101.2761312915433, 22.833587661866222, 0.8502703232149925, 0.1974085240714973, 0.36945362365053547, 0.24405607743368996, 0.3651778417969904, 0.31805859277805976, 0.41087520098493946, 0.4853738808343488, 0.18032139257317592, 0.30256375970859684, 0.2568702769255446, 0.5501846127933072, 17.519331093757383, 74.06020887436406, 58.99025478670674, 94.21799090600784, 98.9762181620444, 53.82161032768988, 36.18447280699207, 52.25125805024178, 78.6847068417457, 95.51940979496126, 90.26833672677317, 73.43468496876379, 10.331546568101453, 0.20930058352889555, 0.2647383829518672, 0.21283188113762488, 0.1658980560398871, 0.20814702365427248, 0.16620409284387866, 0.11060146960399805, 0.1595633362810458, 0.1897164344066574, 0.1968538304490428, 0.12666371335545856, 0.17700026352559367, 0.09972720391928189, 0.2162833370628857, 0.18652865062317542, 0.1982455210940492, 0.2964881002422302, 0.175482168373081], [0.03095705186076943, 0.053093746574896, 0.04829834260406995, 0.10944226366137305, 0.11986198639797589, 0.14330823755552693, 0.06613581125894863, 0.09813404747194822, 0.09264934823037156, 0.11372105624046057, 0.2196910800111871, 0.053979095236788836, 0.032650042971175526, 0.08909415633928391, 0.10245948714474518, 0.176406882462963, 51.57503751016433, 102.34574594805318, 89.19345040475169, 57.92221300063595, 50.695049839635054, 62.081466874768665, 85.00559852969262, 76.59381681872954, 92.53177181366952, 114.50225368622812, 101.05594511955016, 28.114553113137525, 0.03402391441106316, 0.15016529138290113, 0.1745300896225437, 0.06482106648505696, 0.09933563339854441, 0.035795197792110905, 0.3216738842668072, 0.2419650557661249, 0.20627635951724746, 0.872328446036385, 4.3113158306767865, 89.54371021639916, 99.05065690317463, 104.74258868925034, 87.57060896965766, 81.08830390437957, 79.01991259667182, 83.00383260173183, 83.00223227470153, 82.960906182566, 76.6528877135246, 74.90460888031991, 76.05294550618818, 79.91385213790402, 78.77603530883789, 81.86661981767224, 84.5641279220581, 86.03504027089765, 81.13394460370465, 86.32489558189147, 90.93774410986131, 87.38373940990817, 83.28669824907857, 79.2101240158081, 68.68755802031487, 66.02089543496409, 69.84717538279872, 68.004681218055, 66.50812441302885, 74.67498548569219, 79.23210497825377, 78.63721478369929, 76.36564470106556, 67.51645595796647, 68.15076597275274, 69.44812128620764, 65.67239676752399, 69.5419914491715, 74.81981508193478, 77.99651130553215, 76.62255210261192, 82.39159768627536, 79.95957912937288, 80.04486714639972, 80.56097261367306, 79.84409670675956, 76.46853631542575, 77.5207748720723, 81.33895120313092, 67.72592621464884, 74.57531805961364, 73.45719937355288, 60.487929467232, 60.02317174788445, 66.65251470381214, 64.28365807379446, 74.96611948936217, 85.15211474510932, 79.97467240979596, 79.46379938433248, 79.14164727733981, 73.57708269549956, 73.33827310992827, 74.8378344505064, 73.78019086776241, 68.17617508672899, 63.151999365898874, 73.70821537510042, 78.91090992958316, 81.39261707182854, 82.92435753730037, 73.33198947291221, 70.185730841852, 65.49419564585533, 60.919970696972264, 60.28743751587407, 60.253532548104566, 58.85189710124847, 60.114637497932684, 62.898837827867084, 62.23854211068923, 65.8434081846668, 66.4166312063894, 64.14981503640452, 67.0642380560598, 66.45189331423852, 69.0129578498102, 71.76533206816643, 78.18767193825015, 76.89508622692478, 80.83607981281897, 82.33188352277203, 77.41234487102878, 87.51265202799152, 56.16801138847105, 0.639011649595153, 0.15393072078304906, 0.146523064242736, 0.13961478977674438, 0.12371041376384036, 0.05497341224503133, 0.015204606405008706, 0.08169883381455176, 0.15620103766841276, 0.11928300778832167, 0.08101839452020584, 0.06930799749229224, 0.29729525047925215, 39.02830493065619, 46.05927113563784, 81.63282302118118, 96.25644668456047, 72.6452059899607, 20.718108300239813, 29.195287689085934, 32.5826818712296, 51.208056634472264, 68.97535800933838, 75.512419362222, 44.41402512211954, 4.68983926119343, 0.10134733432242948, 0.08034486533893694, 0.019197755440649007, 0.1190264372816009, 0.07205770921803291, 0.01651987020346907, 0.0421108917573527, 0.025479260817049973, 0.034933452299165155, 0.0800026078978854, 0.05947024493868794, 0.044703727828398834, 0.02057719825496597, 0.10764122925578587, 0.09273089062903198, 0.08612319842101106, 0.05384044864425256, 0.04437939684477545, 0.033116203642660574, 0.08966896743063005, 0.07185906261926697, 0.0732111695012258, 0.031422433037791526, 0.04349665671226479, 0.09994070496289961, 0.02246669857882925, 0.03410614628885542, 0.19802835048927417, 0.03754829041539662, 0.030987103574819146, 0.06225357260254603, 0.04727527431602921, 0.2670595680754031, 59.862617369621034, 113.24906426091349, 96.1109895090903, 70.72941841617708, 69.57804587579542, 75.5884898093439, 67.67978345194172, 76.5863407811811, 104.8784831262404, 122.11246767351706, 111.44416993664159, 35.208689089744325, 0.03860347310922319, 0.16910752011162622, 0.22950619849706852, 0.09219723378097819, 0.22884400741707897, 0.040134327456114754, 0.4600221928088896, 0.34375370269821537, 0.3862482014923327, 1.5796793059956644, 5.413691593754677, 100.29663701211253, 103.9447158382785, 108.88457236751434, 91.86195650408345, 84.6996222772906, 84.56318655321675, 89.94205828635924, 86.52640342712404, 86.60291317970523, 78.598830469193, 78.05174612229871, 77.35359561058783, 84.27158970986643, 83.16982730742424, 86.7220434065788, 88.5662712589387, 89.56809166939028, 84.8953171699278, 89.62638593489125, 92.204387264867, 92.68472856090915, 88.43044742461174, 84.26059138390326, 71.17065368160125, 70.14857815157983, 71.49450025250836, 69.51499769764563, 70.36150793875419, 74.79286055411063, 81.08284396509971, 81.74723071436729, 79.28222502431562, 72.79296167435186, 71.47349988260578, 74.0926076519874, 70.65355977704449, 73.73143580652052, 76.18297207740046, 81.31677412217664, 80.59843909355902, 87.11738694098689, 85.79552465869536, 82.2094585049537, 83.27596664428711, 82.64976024627686, 78.78228756689256, 81.98691891085717, 84.50491582193683, 74.23088689004221, 80.73287440884499, 80.13859610403739, 67.7848009909353, 68.1872675495763, 69.88962327280353, 68.2317864510321, 75.63132209162559, 84.9851708258352, 84.14360277114376, 81.70603013807728, 82.74663494479272, 78.47085137521067, 78.54518028997606, 78.45433819678523, 77.1323896223499, 72.70004072496968, 65.78837340877902, 77.16579252673735, 82.76794910430908, 86.46256293019941, 84.49296828239196, 79.68849628202378, 73.50939827580606, 68.52943943392846, 64.98267542931342, 66.0383342927502, 64.4711002995891, 62.58002365789106, 64.73690363668626, 65.83252752980879, 67.35589765733289, 68.54581140702771, 69.69824298735588, 67.32618962564777, 69.89413399850169, 69.65389667018768, 70.48234047428255, 75.88170266920521, 81.96227858143469, 81.38494491577148, 83.67712313129057, 88.76512758193478, 82.53549375841695, 92.92793120107343, 64.6941380346975, 1.3650693960728184, 0.03926747981759329, 0.17569086604541348, 0.0991702963027262, 0.12440737757471301, 0.031709507250437335, 0.09505026778506656, 0.11931372025320608, 0.46740329674174713, 0.24579719610271916, 0.22243079428951587, 0.14127278790598916, 0.3351916282648041, 43.82865451997326, 53.43587267783381, 84.092392306174, 73.84811847440659, 46.888754367828376, 31.9206936513224, 40.47566736898115, 44.058721142430464, 64.03780783376386, 79.74707295817714, 89.0260358010569, 54.9465343259996, 6.108380123492211, 0.06653655185213973, 0.0897048969542788, 0.032147175196798584, 0.059288601661401416, 0.04846742970027751, 0.033710825767728596, 0.07886349644151427, 0.03283190458352047, 0.05815904332144607, 0.1150298868155768, 0.013519002297412486, 0.05067622972532146, 0.030656304893895026, 0.008182858995672676, 0.0568729157619659, 0.03889994147504049, 0.06519623506333559, 0.15124818730738857, 0.12109747937610074, 0.1706988379479416, 0.19074728231756918, 0.16250246324606482, 0.29886003102987047, 0.12267267872248927, 0.13367618344003154, 0.14875829430116763, 0.2214759423006927, 0.48975287005305296, 0.19492140430356228, 0.12488187711325385, 0.2402129513962615, 0.19191607202012695, 0.3146183677017689, 85.15063208918419, 125.01106785189722, 111.1125570727933, 82.97540326272288, 76.28043513144218, 76.76768764372795, 99.85510364655526, 102.09233730070054, 121.01272921408378, 131.66128958425216, 124.00155175116755, 45.51419504227177, 0.3079459563859048, 0.30875160509059507, 0.833949769937223, 0.29536565885909144, 0.2869309695257295, 0.25702139542948815, 0.9323166238684809, 0.7290246517908189, 0.40119846862170006, 2.4429960452741195, 6.419781504138824, 105.82113850501277, 110.34486293792726, 115.70081233978273, 96.57673174335112, 92.3721548818773, 87.94212802763909, 91.12327221901187, 89.97888934227728, 91.25279672684209, 85.06448115071943, 83.62135487218058, 82.71929602469169, 88.26256213649627, 86.21593213850453, 88.67523470232564, 91.73422059705182, 94.38181261862479, 86.56707840581095, 92.95396004953693, 95.9804138060539, 98.1277467358497, 91.59101486206056, 88.39430670584403, 75.0084653977425, 74.7035324958063, 76.77960380431145, 74.2336247044225, 71.35691135160386, 80.64974369541292, 86.6924608907392, 88.99164445938604, 83.27395054601854, 76.78417728793237, 75.20874161874094, 80.22963431573685, 74.19940594703921, 78.47221636003064, 81.85963799876552, 86.6468672598562, 84.05003070831299, 90.73167847048853, 87.17047229889901, 85.57984136766004, 86.41973064791772, 89.61821956019249, 81.94151355374245, 86.99544829706993, 92.32479618441675, 80.7866422591671, 80.03808144600161, 81.35780211417907, 66.92662562093427, 74.61079982019241, 73.44758956663071, 71.43955569113456, 80.40592132076141, 92.96939849853517, 85.17284054909983, 85.58395985634097, 85.49382378978115, 82.88884439776021, 81.7026412102484, 83.03577638441517, 82.27568380294308, 78.03298934813469, 69.23196731075164, 81.443615728809, 83.65071773529053, 88.72005954865487, 89.37974729845601, 81.30199463136735, 76.90645325568416, 72.8585829273347, 67.70358439414733, 68.76610740538567, 66.7461181456043, 65.74725127989247, 65.53658862267771, 68.89520045249694, 67.98676383110785, 72.72142548714915, 73.28287355361446, 71.98147819888207, 75.11440861609675, 72.70935243175876, 77.14479215683477, 82.25131803943266, 85.12208507907006, 86.38100900957662, 88.45683713113108, 91.155529791309, 84.5237353540236, 96.20201987604942, 66.56040176268547, 1.895505365344786, 0.24376563817983676, 0.3611406197230662, 0.17660313886740517, 0.3904727473855019, 0.21202338258585623, 0.4370648972690106, 0.3444692594630103, 0.6332341821924333, 0.2756808764271198, 0.24722447919268764, 0.2706420097139574, 0.8508144295023334, 52.6191802947752, 65.55715360949117, 101.48779807552215, 121.13016497704291, 97.6730812749555, 30.33145320030951, 42.47868061065674, 55.263473603033255, 75.25362922299293, 91.61932652996433, 99.09037482353949, 72.55588577639672, 11.371207064197911, 0.19870160387889033, 0.22079067665242383, 0.11126019030569062, 0.26818081436138, 0.12118862085645238, 0.10731712809853977, 0.2509034632314598, 0.11477783622760927, 0.1330961935943173, 0.26691673864280024, 0.12054172855231071, 0.33932326301451654, 0.13651766483822178, 0.15659891309276705, 0.17160302088145288, 0.19693903474798127, 0.15538156873756842], [0.09644188182128054, 0.049144256890060446, 0.07903788103571824, 0.09036148793154186, 0.04890455946987195, 0.06931107716574784, 0.11614718008786441, 0.10828278192709531, 0.03213732713653195, 0.047179317973073454, 0.09932310020010318, 0.12227656530036081, 0.06656753244779764, 0.21675325539563933, 0.5200647935271263, 12.51427790810985, 89.57936456126552, 87.9584764665173, 68.75597200086041, 53.04344346446376, 33.60704806543166, 36.939572211234804, 89.3032689248362, 77.56998492825416, 112.44454691486975, 117.23700077302995, 51.992993508615804, 2.2910841193891343, 0.24868865707708945, 0.08537047873100928, 0.3946598469009323, 0.10846930901489912, 0.09385651127705652, 0.07447473960177553, 0.21643416445341804, 0.07202760196260868, 0.13879153637155411, 0.779156526250224, 16.665884140999086, 101.7830897915748, 92.10569258659118, 94.47932274110856, 80.68200911245039, 88.39956268187493, 89.49792046700755, 96.69408905890681, 95.64287816324543, 98.30684215791764, 86.6389048484064, 81.4866441295993, 78.14325501841884, 89.5754421910932, 90.43066793872465, 91.92214135200747, 91.09199523925783, 92.33045224220523, 91.60252309614613, 96.20118833357289, 91.48035695475917, 90.11402283945392, 77.55136935941636, 66.61149455655006, 59.18592222275273, 65.09261554287326, 66.11834279952511, 67.10442666084536, 69.39714616344821, 69.00261063729563, 73.86859324670607, 73.44845248806861, 71.49264889378702, 72.27982936366912, 68.0937425551876, 65.62506552665465, 65.71690390186926, 71.79413795471191, 71.0166378944151, 74.13198040377709, 74.63286707478186, 78.41028213500977, 78.75637638953425, 77.77215957641602, 76.51370633033015, 78.68051775040166, 77.10002222368794, 76.75220212628766, 76.34331072530439, 50.28148689577657, 46.62430424844065, 41.79033210200649, 36.389824574993504, 60.04588619355233, 70.63248880447881, 65.91206535216301, 64.82681612814626, 65.80857753753662, 73.43433195544829, 74.82883653333111, 74.3245844687185, 72.77754675957465, 73.19900543459, 77.19805009903448, 68.34252280573692, 70.56945631580969, 63.9168615495005, 70.66871581539031, 77.7623301167642, 81.60800226273076, 79.30861473083496, 81.17334088971539, 78.89533027525871, 75.52709687140681, 70.24502923411708, 70.9419402768535, 63.314107002750525, 58.72848364614672, 58.97800914702877, 61.92108115842266, 62.96928359616188, 65.3558183485462, 68.52724290663197, 67.33379902378206, 62.8065993708949, 63.383725150938965, 67.0982999186362, 73.14383337574621, 73.55605879137593, 75.22873786187942, 79.27798101978918, 75.46982242215064, 85.80267906188966, 77.42937580231698, 90.90931477085238, 20.692420697981312, 0.12188273482024671, 0.16253491473053733, 0.06070060512772011, 0.12624539104440521, 0.10004290875287787, 0.07647709425298438, 0.12868841479141868, 0.11545416162980181, 0.37849640293467435, 0.061603826620886405, 0.09923160631930637, 0.2973300921580484, 2.209519902544637, 32.00368708179843, 58.39323082277852, 82.95898422118157, 84.16875300868865, 53.06694630653628, 16.105512765146074, 35.79862533077117, 45.50103941271382, 56.07132496372346, 72.74383006557342, 65.09801272423037, 47.25003603966006, 7.228599238780237, 0.1973643667635418, 0.03895468611810957, 0.043525576531406374, 0.05228148653141914, 0.13885017274127853, 0.030715228546591058, 0.038670279806660074, 0.03791373350747651, 0.09694258922771101, 0.059664578462440165, 0.07019352618484728, 0.08239848659403863, 0.13493684240646903, 0.18266413541090104, 0.04942926075009089, 0.030059618161871072, 0.03942841573828652, 0.014731599780310307, 0.07343597034172666, 0.027650572329519257, 0.03205707176558433, 0.04854880355959458, 0.1228555209273773, 0.14203161331674746, 0.10392816196526251, 0.02702022560932223, 0.14892683364450932, 0.10873150260698412, 0.13354936524504615, 0.2711243386710844, 0.7519860842054891, 14.38802061542388, 105.95462460671703, 97.06993056881814, 84.19995154103925, 58.25775215702673, 49.32073762339931, 49.32828426361085, 78.38043289799845, 81.22001709476595, 126.3942603142031, 126.66792408112558, 61.97395470834548, 2.4312024587585084, 0.24463943806627106, 0.13951365084898087, 0.4327056424752359, 0.13261970222717331, 0.044389838623183395, 0.16985087054631404, 0.11589864584346933, 0.04306847484962594, 0.2717343591634305, 0.7936679475730466, 18.886900755666918, 109.6544159612348, 97.0252469278151, 98.69859280124788, 84.75651233426987, 94.39068501995456, 92.67967654812722, 102.10831703678255, 101.57613769654306, 102.87134355114353, 90.24834832837506, 85.03413769506639, 82.26233989961686, 92.77646495449929, 95.97041176211451, 96.6734338575794, 94.21618661572857, 98.3382603429979, 96.54860834921561, 99.5016118018858, 93.7571830134238, 92.19120810108801, 81.93524560620709, 70.75336840844923, 63.44536912056708, 67.12711364992204, 68.6960538741081, 70.04313699660763, 71.551876683389, 72.78212808793592, 77.77248121077015, 76.19231516315092, 73.9012901244625, 77.67169198682232, 69.52055177380963, 69.5343428273355, 68.7323828666441, 74.01533695959276, 73.3380691466793, 74.5625703565536, 78.134108051177, 84.49243484004852, 83.14539094125071, 82.0529245561169, 80.64461323522752, 83.00344036471459, 79.62387131106469, 80.82076687966624, 78.26562512305476, 60.728547265452725, 54.01913696719755, 53.335326640836655, 46.1682032000634, 65.48546837222192, 75.59087461040866, 68.22079596980926, 67.97810323776739, 66.11538533241519, 74.1259164194907, 80.50824811381679, 78.49399335922735, 78.02881594627135, 78.05282869646626, 79.4201434043146, 72.21452190030006, 72.64865767571234, 66.07092918888216, 71.01484929361652, 80.96759688469672, 83.56823029056673, 82.58400563270816, 84.90515447431996, 81.63469791412354, 78.57349195787984, 75.90517413231635, 76.00761075173655, 68.48462243233958, 62.80643070897749, 62.87791982773812, 64.50535435830393, 67.63629221147107, 68.81395247674757, 70.9562804622035, 70.166519072748, 66.7687737557196, 66.38518948708811, 70.34210005114156, 75.9793539970152, 78.86177047606438, 78.14908366049491, 82.77566048406786, 80.57346144030171, 91.19749915215277, 81.61311703343546, 100.47407719396777, 29.51696126691757, 0.23649187848692943, 0.10219805197970522, 0.11923249961147386, 0.16977237717759225, 0.18975184299051764, 0.06574344400676989, 0.2793778022450786, 0.23797436587272153, 0.1882280634656068, 0.20372223769945486, 0.14482119991894693, 0.27252382809116, 1.0921631368898577, 38.49518814394551, 65.10336675951558, 92.98061647722798, 59.329104423522956, 31.32043765437219, 27.078847346767304, 47.16131202636227, 56.30503546807074, 68.03386365213703, 80.06187454346689, 77.97720539954402, 56.98994013570971, 7.649125860583398, 0.18229337949906627, 0.05568521134855767, 0.04166544993377982, 0.0042383924535956356, 0.048268798423270066, 0.013845274356314012, 0.06313320241808411, 0.046809466044989326, 0.053645008123449744, 0.04258369058070164, 0.06199315250400574, 0.07948297811972518, 0.12481932603423634, 0.033299915357342655, 0.05939334503284866, 0.017985869461910862, 0.19535070465457058, 0.11978104920877565, 0.22982558055270105, 0.12922774069011211, 0.2774483025554688, 0.23635009093390358, 0.31042749903375105, 0.19084509642374134, 0.2059277435464244, 0.25035077675936684, 0.43017507020023565, 0.3244342522755746, 0.3744388029219643, 0.515247387511115, 1.2052456818280683, 22.52841941771969, 126.00229786288355, 107.19276782005065, 96.11468438179263, 74.21799798165598, 56.2296945818009, 44.71055630714663, 115.72635481434484, 99.95718725265996, 138.71077722118747, 132.26721732847153, 76.60278335694345, 3.1782497273337458, 0.41292402652963517, 0.502008714022175, 0.7731274142861367, 0.5198009528460041, 0.178797168717269, 0.40578644662614793, 0.3439288610412229, 0.38892292087116553, 0.5488967883490747, 1.2128892781273013, 23.373227350173458, 118.16151911212553, 101.59654186617945, 104.00377888833324, 87.84670460608699, 99.82497984363188, 97.16182385721515, 105.12428237545876, 102.36941352967294, 109.78305401340609, 94.82016101960214, 89.69644731090915, 86.48125694644067, 98.95258980412638, 99.95248825319352, 101.76563524430799, 100.49996483710505, 101.31766134692778, 98.8029827610139, 105.65467311489968, 98.53160965827205, 97.41949219857493, 85.6176059476791, 74.65038437997141, 65.34722443549865, 71.71085034647297, 72.75937049619614, 73.93425372339064, 74.25053011986518, 76.01797365373181, 83.75677862474996, 80.15135165183776, 82.0906420676939, 81.96431036918395, 76.1448387945852, 74.50893586681735, 72.46603996522965, 79.94242268223917, 78.08168165145382, 81.02949188601586, 81.88332126986596, 86.83644325502458, 87.24729584109399, 84.8443655813894, 82.2146281888408, 88.47528796042167, 85.1732563203381, 87.12606322380805, 88.71602735211773, 63.743853645939986, 61.67341093863211, 56.93857669830323, 47.6523260916433, 75.53418067193802, 80.76450440191454, 70.68660966811642, 67.98264534242692, 70.82339056076543, 79.58249030574676, 83.80393335896154, 79.19042587280273, 79.78474340131207, 81.55907461720129, 84.80549489298176, 77.4072144108434, 77.88757139636625, 70.20675474597563, 75.92802586094027, 85.30752689607682, 87.71554054752474, 86.07038082615023, 87.11749676735171, 86.55259701513475, 81.24301002871606, 78.16707165010514, 79.44321478566816, 70.11919959898918, 64.20761508326378, 63.92192925176313, 67.83112418267035, 71.29606754549089, 71.56099227166945, 75.43623124399494, 74.71539374320739, 70.61688561593333, 69.12891095684421, 73.52380906381916, 80.07078616849839, 83.67030605193108, 81.41099729845601, 87.67855259679979, 83.0644645998555, 95.8051387725338, 82.72834885504939, 108.13243435275172, 30.866746902465824, 0.3472228246110101, 0.29670076625001046, 0.30673786637283146, 0.8619356359685622, 0.4261815764250294, 0.2769238081189894, 0.43740666441379056, 0.4709380570678942, 0.8578978623113326, 0.5693707639171232, 0.13346190864761032, 0.413583321797271, 3.1586805322477898, 53.910812870148696, 76.79468139525383, 101.63422799879505, 115.35167432600453, 68.76531508661085, 25.361865105167514, 52.81482811897032, 69.48903945184523, 80.71766345731675, 92.33109551091349, 89.38053961723082, 75.62536793370401, 12.116849633955187, 0.33920007607629227, 0.20131664500842172, 0.18747954959830931, 0.10957635203075987, 0.17732419614349643, 0.160810420169465, 0.13129230168077255, 0.19688232891982604, 0.1993598419451906, 0.1843886912590073, 0.2335771437614195, 0.17264853171523542, 0.42265052396443586, 0.35540528715618197, 0.1729138586069307, 0.09229075013389511], [0.09241872512164617, 0.012219320727331985, 0.1369575678461021, 0.0483493066032327, 0.06582384493442313, 0.05894979544644875, 0.11524961615401892, 0.06495526210675318, 0.03366924634563827, 0.05816368198382759, 0.04584280481081336, 0.011419447367980836, 0.10308341213291693, 0.1572276567739825, 0.4853077827682419, 22.815733032841838, 89.40100654478996, 85.50657933758151, 67.17833195963215, 40.53989618055282, 34.55105666191348, 43.93837498080346, 66.95598063930389, 97.34152332428964, 110.6666777210851, 75.76775781569943, 11.913227631199746, 0.11885188414805359, 0.014584059864583035, 0.022034751394042568, 0.18288731214500245, 0.10358487796639243, 0.056361115402391845, 0.08312977114391905, 0.19908774283624467, 0.023922464817822463, 0.259572652078444, 1.1723968122274646, 27.74946281986852, 95.54502287218648, 91.96133367476925, 91.17595749516641, 93.60479108748898, 101.40548321508594, 98.31894659226941, 105.82279374522548, 99.93025625905683, 98.51827359968617, 92.29755140119984, 92.70028468101256, 89.73840098227225, 93.82215315295805, 91.24517163922711, 95.01727581024171, 95.32238914120583, 96.64531830818423, 94.6931468286822, 94.76232174904116, 91.0419850195608, 84.16835292693108, 68.18731461801838, 63.36596465879872, 65.65266724555724, 62.242244828131895, 63.426318168640144, 68.583034699963, 71.23942852020264, 65.08029930053219, 63.435249405522505, 62.83249485877253, 64.45153943953976, 65.03916148216494, 64.66440254642119, 66.075683101531, 66.3664327129241, 66.00113453403597, 69.9453366187311, 70.4425048828125, 73.86155651461694, 75.73548455392161, 77.17049937094413, 76.11611135544317, 83.19296144670056, 77.93263158490582, 78.83746747047671, 75.8161755531065, 77.43633408700266, 50.26937461668446, 22.40354487972875, 22.792518484976984, 25.366207168948268, 49.621010749570786, 66.45633343727359, 62.71855000526675, 69.71763518548781, 67.36400127410889, 68.40512383368709, 77.32129096984863, 77.74485203527635, 74.87737978658369, 72.06140825825354, 67.59845702878891, 68.40422953328779, 66.55175685882568, 63.57859242346979, 64.61247428770989, 75.39175156624087, 79.98285447397541, 79.9887066502725, 80.55973314469861, 79.81849931901502, 82.27850790946715, 79.51105610016855, 81.23683621806484, 77.06952971796836, 67.97236088783511, 63.33705679062874, 60.849956389396425, 58.78753885146111, 66.86714679964128, 64.93828596607332, 62.64162448144729, 66.02111508769374, 69.49661747101815, 67.6272629153344, 67.67778304315382, 69.70226733915268, 74.14730118167016, 77.4320508587745, 81.9222076477543, 77.54139084969798, 85.63754727763515, 79.9759824814335, 76.53805640435989, 9.05923068523407, 0.26780791340335725, 0.19500939716254512, 0.22053437427647654, 0.1314952690154314, 0.1985973239906373, 0.12745281456098442, 0.7289885537278268, 0.4990122990021783, 0.521895498518021, 0.17166200965162248, 0.021677944028089126, 0.30421829512042387, 8.268029785925343, 40.94645769365373, 76.33519926378804, 95.43685174757435, 100.74097094997283, 39.897866941267445, 16.231417905899786, 40.37372104583248, 52.32447693424841, 66.49383914086127, 72.47564192741149, 66.50900302394744, 53.585416963023526, 8.048533951082538, 0.1649845268336996, 0.05195766499626541, 0.042652489106741645, 0.13450947259702992, 0.12770160927527374, 0.06241046740943867, 0.05498086628053458, 0.06367507172868618, 0.04802570340313739, 0.06633042823523283, 0.11089570099307645, 0.1263578910560858, 0.07576686179926319, 0.04055015615097458, 0.04512070948558469, 0.02738997603075639, 0.009099382648034202, 0.12937902773339904, 0.04531720337728339, 0.019725260602670814, 0.025259382091462616, 0.07816005152680221, 0.10944459256866287, 0.07945391274387799, 0.03419158424461081, 0.11518410031473446, 0.11727740492431388, 0.06925263231800449, 0.11451814008215744, 0.7241315562878886, 33.029416299635365, 101.63441627256333, 93.53833829202961, 77.15053450676703, 65.27391141460788, 37.913877194927586, 30.215425568242228, 69.13364918001237, 105.27056324866511, 122.82655869760822, 87.31943607330324, 16.71262114278732, 0.1467738201421115, 0.12004517334242983, 0.04607751116817517, 0.11548635264438008, 0.23761758340462563, 0.13984654669559773, 0.11492571417963314, 0.4699122346937657, 0.21384713149839835, 0.24710233413404037, 0.7711185478875715, 33.90271632902084, 103.66331715737621, 98.34844281596523, 96.90531653742637, 97.57923464621268, 106.61972522735597, 102.67375023134294, 109.76744298012026, 99.68766550863944, 105.03318140583654, 96.25152803236439, 95.12084991701188, 94.15518591480871, 99.69425509052893, 96.00664661776636, 100.07824728565832, 98.27309408495503, 101.64801120758058, 96.82332331134428, 96.91084707936933, 93.13777800529235, 89.201993326987, 70.40214369373938, 66.41860023621591, 67.19493143020138, 65.81132319665724, 66.89503485156645, 71.5303114921816, 73.55638042573007, 68.26296144916166, 65.85467323180168, 66.2498834056239, 67.76211400185862, 67.93021894270375, 68.46981156256892, 70.96162273037818, 70.52846754750898, 70.68930041405463, 73.00600128789102, 74.49883968599381, 77.35424672403644, 80.26507685261389, 80.07495172562139, 80.71209369167205, 87.86285692645659, 83.26696872711182, 82.26172800986998, 80.08087450458159, 82.43017027454992, 57.808295603721376, 32.27441299346186, 34.47155806326097, 35.23768717242826, 55.5667983331988, 71.44528235158613, 66.76685179433515, 66.5841007232666, 69.13055050757625, 73.02811561092254, 79.97787306385656, 80.7258298320155, 77.47819362148162, 75.25140131673506, 73.079114267903, 72.04936658182453, 70.03031084614416, 68.41653793088852, 67.81971793020925, 78.08042649299868, 83.47333246661772, 82.99980824993503, 85.06510088520666, 83.18686608345278, 84.87225363331457, 84.59167080540811, 87.25652910047963, 82.43603814032771, 71.6873396596601, 65.86111376362463, 64.7565233322882, 63.426694716176684, 69.79375270105177, 69.29150104522705, 66.01574928529801, 70.30870499149447, 74.22300292599586, 71.28317079236432, 72.37947325552665, 73.40740096184516, 77.19916405216341, 79.40901171776557, 87.29117931858187, 82.83204847766508, 88.9903030087871, 87.07824953140752, 88.25016744675176, 13.38471362667699, 0.1400572821618088, 0.12414719879386887, 0.23808967742708423, 0.1489801993293147, 0.3907383653906084, 0.16472491495791944, 0.15935969478901357, 0.3207930363714695, 0.15737241674815455, 0.8825629516955346, 0.09678662138720674, 0.2140914216156929, 6.972250284687166, 48.21694343320785, 83.39417903654038, 98.82835265128844, 58.57493462101106, 25.688586773410922, 28.984583846984375, 51.27277966468565, 61.54258420390468, 75.6504475685858, 81.18483343432027, 79.0149704102547, 65.37193144521406, 9.416761590588479, 0.11133319848487455, 0.13150556523713375, 0.10287957145802437, 0.14100804324111632, 0.10828165577784662, 0.04147798055782914, 0.00432671616680079, 0.056037853111422835, 0.021109275046675917, 0.035705665096400246, 0.0392568311954458, 0.12228481606730532, 0.012085782026030846, 0.06377763941042847, 0.026724121135268963, 0.16646152902995387, 0.11089543286230295, 0.2905287635662864, 0.1620793682072432, 0.1902367460030702, 0.1586433106492604, 0.16843340870353485, 0.23638359961971162, 0.11883179732267896, 0.16653355661659472, 0.2231178372617691, 0.20280147662326214, 0.22735578969361322, 0.28612777230239683, 0.9994634949872572, 45.50334576637515, 118.31078883140319, 107.8975236031317, 88.3507997758927, 64.7593984296245, 54.01244932605375, 59.004281182442945, 91.13142290422994, 121.63043191356044, 126.21005012143044, 102.52440990940218, 20.578444465514153, 0.4072846694579048, 0.4743567397517543, 0.178669921513046, 0.6335590647593622, 0.7269428538218622, 0.30122010277644284, 0.3509539179503918, 0.6268993705030411, 0.7277871440014532, 0.541847063408744, 2.1710203684145406, 37.79770051279376, 111.05678096894296, 102.64880395704701, 98.79299640655519, 104.24454181425034, 109.76088477719216, 107.71057559597878, 115.07178967998875, 105.29030846011256, 108.04123140150502, 103.49147027538669, 101.08064036215507, 99.27078816198535, 103.77582642339893, 100.17555344489314, 103.05753846322338, 102.78444736234604, 106.28007150465443, 102.70990663959135, 100.97020210758333, 97.10672240103446, 94.00099754333498, 74.88748381214758, 68.6107187886392, 71.67678063915622, 68.86871660909345, 70.25601971533992, 75.00833988189697, 80.05132336770335, 72.92015629429972, 69.79819282408684, 70.84140992933705, 74.90839788990637, 72.6791109577302, 72.55256745123094, 76.66696117770287, 75.01984027124222, 74.55334494190832, 77.70047433914678, 78.02710579287621, 81.70933277376237, 84.08420239725422, 84.66010047543435, 85.02293540585427, 91.23888800221106, 89.16129481407904, 88.53643771140807, 85.4310344880627, 91.19582822245937, 61.53630841162897, 34.000030332996005, 37.26854139758695, 37.57146212362474, 65.52604529165453, 75.1035907191615, 70.41770765858313, 72.29774675061627, 75.26837733484085, 77.38044815678751, 82.04092994812997, 84.44480157667591, 82.06151454679429, 79.18513851781046, 76.5818614344443, 76.70501601311469, 74.73059684999528, 71.5700686362482, 71.41960651643815, 80.84164957846366, 88.52780849702897, 86.20996229110226, 86.65377847609982, 86.2814357203822, 89.9144212661251, 87.86886599756058, 91.99497976610738, 84.62631317877, 74.20480312839632, 68.46079011117259, 68.00678360846736, 66.06173515319824, 73.83005988213324, 71.58232996540686, 68.857757506832, 73.94123554229736, 76.43608262462001, 76.09175343667307, 75.08191570158928, 76.73259812016641, 82.38575335471862, 85.43703571442636, 89.1270289882537, 87.43116086529147, 94.87946725660755, 91.66885037575999, 96.32769261637043, 11.986707352822828, 0.33612827800454637, 0.5167950076922294, 0.4590884542032596, 0.48134805814873793, 0.3351116486855092, 0.33780818624842557, 1.7430930921146948, 1.4757781716123706, 1.161430723244144, 0.8629769026752442, 0.20183790655386066, 0.42923471259493984, 13.35618720900628, 63.01975665553924, 95.22474565813619, 117.46434134821739, 135.695306101153, 55.57367032574069, 26.285034148923813, 56.22230091402608, 71.83827246389082, 88.70185975105532, 92.22326171013617, 87.57840664156022, 80.55540284802838, 13.991821023725695, 0.4198515757678017, 0.3435734881749076, 0.21461871993397513, 0.2564046946504424, 0.20450171684065174, 0.15784884682826458, 0.06853971855654832, 0.21704631467019359, 0.13071462542058962, 0.18784842093385037, 0.31502080901015195, 0.23053172975778582, 0.09101470046105886, 0.21423106412253073, 0.1983923341838583], [0.03909360084141936, 0.03538000878066786, 0.061025181259479255, 0.051133584216116905, 0.04320954611044257, 0.009866897411073649, 0.09956911401522738, 0.025553644124057986, 0.10800904338999141, 0.054062537533501466, 0.05799611557214972, 0.022893041830449816, 0.06006405501055622, 0.008177248359237227, 0.2071364004645617, 55.23189460077594, 92.43075509225169, 74.22840795209332, 65.12222159293391, 28.694669700437977, 30.410063382117983, 64.43569698641377, 81.83510749570786, 115.11187630314981, 95.52442258404147, 53.616509591379476, 0.5715964025547428, 0.02101555759567888, 0.12320805926837268, 0.13761225126443372, 0.28579547400436095, 0.08686144671012318, 0.21813492561059616, 0.08643827506250913, 0.21056421491647923, 0.09154654168073209, 0.24980297792823086, 0.8413504244339082, 43.97328407533708, 92.25737064115464, 91.94618548116377, 97.57293531971594, 98.59907442523588, 97.0423641512471, 102.65278124040174, 92.74419169272147, 93.13684448119133, 98.39790390383814, 95.01580884379726, 91.91763847104966, 91.7346912814725, 96.67450074226626, 97.79238408611667, 95.05322041050081, 97.17854884362991, 93.98995214892973, 93.85267703763901, 92.58621431166127, 85.83135943258964, 66.48947746522965, 62.45968926337458, 62.30927028963643, 61.96681207226169, 63.444616025494, 63.48167850125221, 62.17012028540335, 62.09899986943891, 62.12158095452094, 59.27092390675699, 58.648075057614236, 58.2880760008289, 61.433628605258086, 64.07758066731115, 68.06577605585899, 70.02505487011325, 72.24431622412898, 70.19807846315446, 76.11150649286087, 75.6629442399548, 80.8815400831161, 78.40454762981784, 75.23138153937556, 84.33931335326164, 75.19818259823707, 76.16358772400888, 69.78116189279865, 74.5410208548269, 53.54152956316548, 28.934108826421923, 24.43503256767027, 29.64801157674482, 46.3328682222674, 63.077654761652795, 70.03775550473121, 59.92728940902218, 62.5409137049029, 62.61248519343715, 74.00156944028794, 73.37308806757774, 73.61538856260239, 65.61887994889291, 66.22063036887877, 66.69959883536062, 68.38956771358367, 61.86423032514511, 62.86240685370661, 63.9247102122153, 75.30523192497992, 80.19511745822045, 80.53144501101586, 75.43378368500741, 77.29619564548616, 79.48191288978823, 81.50189430482926, 78.3714428255635, 77.07896694060295, 68.3486887716478, 62.97281372931696, 59.7563172155811, 62.711203405934, 60.618866028324256, 65.36487902364424, 75.87333233125749, 73.42382000338647, 75.41664292735439, 70.94026150241976, 64.79343283560969, 65.91929820276076, 69.8226527244814, 73.64643804488644, 78.12216051163213, 77.12326618932909, 76.54690527146863, 82.73372250218546, 63.26357903019075, 3.0590148222061897, 0.22786062631395557, 0.08863913841665753, 0.30556642600605566, 0.1774587058612416, 0.20646683961874057, 0.21121535900860064, 0.1325483794414228, 0.15760135446344653, 0.8291149584035721, 0.12257994377925513, 0.027814699006417108, 0.16229929672854562, 18.0055029930607, 53.81467557722523, 84.9701089243735, 96.20040385953843, 87.0459919591104, 28.280702752451745, 15.415212877335088, 28.404365278059437, 42.65278677786551, 63.32809809715518, 64.21987641242244, 66.16253222188642, 58.680752323519805, 8.798301873668548, 0.09596558963699688, 0.0655597667660444, 0.03013836050916824, 0.08434605829778218, 0.10126727813434216, 0.02147695511549471, 0.0714612638037051, 0.03549864898706156, 0.02567301594441937, 0.033160805281612186, 0.0803577815813403, 0.015643076828470635, 0.05838867817674914, 0.03548611195818071, 0.019750235069002357, 0.032173206864465634, 0.03096414775016808, 0.04106704716480548, 0.05722628913879876, 0.039749958161865516, 0.013628182275551222, 0.036111412074176535, 0.050537548658828584, 0.018114501370056983, 0.02695824335058851, 0.013818377009292525, 0.06377339528332795, 0.06362270961906161, 0.1910832884811586, 64.90161180496216, 99.17346631326984, 85.32081588622063, 74.4781138820033, 43.506172933886134, 32.839220569979766, 60.14323942122921, 91.81093431288197, 123.3944316064158, 107.73961682473461, 63.26261020475819, 0.489206618719524, 0.10851961034800738, 0.08030445420093114, 0.1042126716985818, 0.21047913319160863, 0.15315255931308194, 0.6287599222794656, 0.11378177636933905, 0.07007679736782467, 0.18630945754628028, 0.3142203697033467, 0.981498855736948, 50.754112889689786, 102.12989791747063, 97.82956031060989, 102.78593001827117, 103.62425035045993, 103.45762806553995, 105.62033668641122, 94.76276105450046, 98.2845474058582, 100.2950837535243, 101.34489828540434, 95.25621091165851, 95.91367075520178, 101.21018055946597, 100.60804182483305, 101.24421888782133, 101.00075737122567, 96.85084266047325, 96.06332486675632, 92.74068509378742, 87.73700375710764, 69.58690258764452, 65.45354027901926, 65.42700544480356, 66.31204512811476, 68.27944324862573, 65.96513502059445, 67.59190667060115, 66.89683129710536, 66.62720757146036, 61.65998466553227, 63.405192282892045, 61.80015056363998, 66.42074969507033, 68.42705772769067, 72.77895881283668, 72.78242618806901, 76.19135026008853, 74.65152186732139, 80.09705035917221, 79.55687722852154, 84.0145960161763, 84.76355691109934, 77.8367296341927, 84.43505056442754, 79.36728554387247, 77.75130041183965, 73.2745659735895, 74.55464716880553, 60.78927340046052, 35.99277873193064, 32.62624959791861, 38.05545906866751, 53.64990857339675, 64.81212685185095, 72.81171844851586, 62.24382162094117, 65.10507691291072, 67.79744671237084, 76.79844687061926, 78.55345649103965, 76.78594235450991, 69.74712356444329, 71.16072224032494, 72.75275738008561, 73.63797357005458, 67.36787657583913, 64.2953977277202, 65.51145015224334, 76.57635442672238, 83.21853530022406, 82.68620690991803, 78.07617464373189, 80.64724122324299, 80.70053054440407, 82.34758084820163, 79.9122831898351, 79.0005753117223, 71.43591573161464, 65.585853592042, 63.148430009042066, 65.1232139525875, 64.5000317019801, 69.3468927568005, 79.63079037204866, 78.5116675592238, 79.81062319970901, 75.79153522368401, 69.78286420145344, 68.82236988313737, 72.74118638807728, 75.3322256765058, 80.10105117674797, 81.50970766621252, 83.32698099074825, 87.3384125001969, 75.14135529918056, 5.31354122584866, 0.19711365682944176, 0.17880521264047394, 0.5668467187112378, 0.26429831140464355, 0.6935409300269619, 0.43131387522143705, 0.18408996293381338, 0.3396992589677534, 1.144080241360972, 0.3833142686034403, 0.17407085055545454, 0.17112879713456478, 19.70758807274603, 63.733620182160415, 95.42495912121188, 96.3659357255505, 61.99883037997831, 26.08929414902964, 28.828459785830592, 45.095034876177394, 56.50204043234549, 72.01266888649234, 74.19131017500355, 76.81852940590151, 70.42032780185824, 9.746613310229394, 0.11870277279447164, 0.08453115280116759, 0.06457939638846344, 0.07683088897817558, 0.02993675681101459, 0.01928391351905321, 0.01292234046324607, 0.013174866025726642, 0.025798324946193926, 0.021619656228370244, 0.0783805622749271, 0.023227908438251867, 0.0736747982521211, 0.0143201760910151, 0.17045367449041338, 0.1171996086956032, 0.1913838707391293, 0.08102838430673846, 0.15774718696071258, 0.12071498699726597, 0.16517036444237157, 0.08113036593121868, 0.15365796283848826, 0.0951140063003667, 0.11955035715213708, 0.16198990445944572, 0.19860046495112682, 0.13457736330887965, 0.5350484927335094, 84.14077081987935, 114.21253173582016, 98.78275902040544, 86.37631001011019, 45.65091709936819, 45.36230910208918, 95.55334614169215, 109.58153047869283, 135.15855327729258, 119.44240047085671, 77.01387912996354, 1.0677113263837754, 0.14050651612060686, 0.4639398132360751, 0.35136104771687143, 0.9046216873872666, 0.47520562645889103, 1.0671487114121838, 0.3590038472846631, 0.47703826199135474, 0.402935098015493, 1.0098151814553047, 1.5705582018821471, 53.376935143624586, 108.32297525098248, 102.00422517714962, 106.9932133151639, 107.0693543649489, 107.20025170233943, 108.78127282665623, 96.3595187279486, 99.97067236131238, 105.01396963673254, 105.30245211816604, 100.70322205943447, 98.92755723768666, 103.69793599651706, 104.89434519121724, 106.16823688630136, 105.42451627792852, 101.4524418307889, 101.33814396396761, 98.19290514915221, 93.40532287474602, 72.4781051758797, 69.23267333738266, 69.3564005820982, 69.4135259812878, 70.87417740975657, 67.50705011429326, 71.75705586710285, 72.6658062781057, 69.95736260567942, 65.95002605069068, 66.19009079471712, 67.99991161592546, 70.40988645245953, 73.0297237826932, 76.31093548190209, 78.15055847167969, 80.29154500653668, 77.1157273938579, 82.93140995887019, 84.57311014975272, 88.00571749287268, 88.35618911250945, 82.68693647077008, 90.8112947402462, 83.98630003775321, 87.58473734701835, 78.72287934826267, 83.48601741175499, 64.53834933619346, 35.039481962880785, 31.252211947594922, 39.11636998576503, 62.62358157865463, 75.90584093524565, 77.34403287210773, 68.15409998739919, 69.67540694821265, 71.89925747532999, 83.64520288282826, 81.37204031790458, 80.75669888527163, 71.5221372727425, 74.63659332644555, 77.01456946711387, 76.67326834893997, 69.95991999103178, 68.87096804957237, 68.83188555317541, 82.21140400055917, 86.91316481559508, 86.67634779407133, 78.66140011818179, 82.89264125208702, 82.69923702363046, 88.97643350785779, 83.87701496001213, 83.38621662509057, 75.5882623118739, 68.02244955493559, 64.70594829128635, 68.16702811948716, 66.60111596507411, 72.7852346051124, 82.66234320978965, 81.83445638225925, 80.25433740308209, 79.20009843764767, 71.88870629956646, 75.33262575826338, 75.97104641699022, 80.4231248363372, 83.93592896000033, 86.42289992301696, 87.67757200425672, 94.66415266836844, 77.43987990963844, 4.700328169330474, 0.5054834436985755, 0.633713569371931, 0.7655922960369819, 0.37548184695263065, 0.5271895337970026, 1.2365721815055417, 0.4935462616624371, 1.1923579991825166, 2.0997472251615217, 0.44836343776795173, 0.28845097989805285, 0.5754715204238892, 28.46613476353307, 75.45670601629442, 104.30402063554334, 116.34209632873537, 120.11329050986998, 39.74401197125835, 27.605343172627112, 44.90598055624193, 62.59907853218817, 83.79453536002868, 85.23963851313438, 86.08261077634751, 87.38192727488857, 13.439829791745833, 0.23671180700823186, 0.20960983790216908, 0.12777520734215939, 0.1631121160162072, 0.17266233661963096, 0.08920823449208852, 0.17563904785821516, 0.18818372229654945, 0.06407719511058062, 0.11928093169004687, 0.15720390804832982, 0.18412799153837467, 0.13876552002564554, 0.11400539743443651], [0.052566666591672175, 0.07888049593255406, 0.009782500377285385, 0.025029670627367114, 0.058410783643804254, 0.020229028530358788, 0.020033547789939952, 0.0410375029840056, 0.06092321495675753, 0.061445368994628234, 0.05921824797687512, 0.06613022647798061, 0.2912800813153867, 0.4180233529017818, 9.784024876932945, 83.18149243631672, 81.02375738082394, 77.43528289179649, 55.65949962985132, 46.46557769467754, 30.640190801312848, 37.12280573383455, 91.66242553341775, 103.22663184135192, 66.79677163400959, 13.406534752538128, 0.24855244664415238, 0.07072576577024114, 0.09969551852273364, 0.023032967789819645, 0.26417821946163333, 0.07697202535646577, 0.5956796328386953, 0.060861372509069984, 0.26701792353583925, 0.05600077828632728, 0.0969462204844721, 3.223181948546441, 54.223041380605395, 91.88975826386483, 101.35950519192605, 99.03362597188642, 99.98792294533023, 105.85558475986605, 105.08619616108557, 100.95281816297963, 101.97036727782219, 94.66430171843498, 96.07924184491559, 95.33969463840609, 99.31149451963364, 95.62082659813666, 93.18082994030368, 90.7821907535676, 93.34500466623615, 88.82516337979226, 88.47756293512161, 84.19056138684674, 68.24928022200062, 63.824564256975734, 63.06864115499682, 62.269752410150346, 69.64250610720727, 74.27781412678381, 75.45013996862596, 78.0257486527966, 74.11611833880025, 65.07945599094515, 61.17994539199337, 58.904068546910445, 59.51404417714765, 61.388650786492136, 67.72861696058705, 70.15532462827622, 70.83871918339884, 72.89710060242685, 72.9868915004115, 76.09915887155842, 77.30602510513799, 82.09621183333859, 75.8131867070352, 75.60203767591908, 76.27738352744811, 74.09585537449007, 70.34493200240597, 66.5996019301876, 60.30235821200956, 60.41337697736679, 47.880753163368475, 41.633452984594534, 44.986530350100615, 55.151748811045, 49.036197123988984, 64.77024770552113, 67.22700072873023, 63.01015861572758, 63.66980714182701, 67.72747162849673, 72.45992891250118, 72.58510743418049, 66.9352077668713, 63.4204306910115, 66.53935432434082, 66.58028817945912, 62.71077978995539, 63.312538054681596, 60.5211833215529, 70.34579492384388, 75.13565217295002, 74.229812160615, 73.93660714549404, 79.88697605748331, 79.99360176824754, 77.79327761742377, 80.14302053759175, 72.21594964304279, 63.17689857175274, 61.54768328512869, 59.614715729990316, 60.107306588080625, 60.35553770680582, 74.21504051454606, 77.49719358259632, 82.5345367000949, 82.66112727503624, 70.92859637352728, 69.46130044998662, 59.27563075096377, 61.826383375352435, 62.061148997276064, 68.08016330965104, 68.08064183881207, 76.68147394734045, 73.45683067075669, 91.30530941870906, 40.69376291767244, 0.26021129361564116, 0.08730377055584423, 0.4299953153296825, 0.6329649482523242, 0.1332744162890219, 0.10028140724546487, 0.2006648420806854, 0.3625869937241078, 0.42468966615776865, 0.5878688455108674, 0.08269326956642252, 0.2795827154430651, 3.0495989274594093, 34.740091369998076, 70.68965342737013, 83.73460154379569, 91.01583849999213, 84.45136762434437, 23.1219877735261, 15.952059838079638, 27.042651714817172, 39.87201067709154, 60.02468186040079, 61.93757080262708, 70.3986841632474, 53.52579301403415, 3.6311790491304095, 0.13230258779179666, 0.02895457080505308, 0.052701149496339986, 0.050780072943457676, 0.11095380110125388, 0.019876469121945482, 0.05769201697060659, 0.01912060081057491, 0.06717535426780101, 0.09598052835152035, 0.06692278274004498, 0.01624875168706621, 0.05770601722742281, 0.04015152613001485, 0.13968044351185524, 0.059126221664970925, 0.0216607223715513, 0.0345037650737551, 0.033035392857967846, 0.019435413151739106, 0.029741747214669184, 0.036001409509129105, 0.0826878073595224, 0.04086809030043022, 0.19928706359238396, 0.1998619819360395, 0.6111680307695943, 10.020023103683226, 98.63518376504221, 91.31188331111785, 85.27056247957292, 58.67993647052396, 39.42269925148257, 37.595663147587935, 45.90294507242019, 103.42845347619827, 115.87867613761657, 83.68532088495071, 17.31638766104175, 0.40668071638191905, 0.19857469375335401, 0.24417992320752915, 0.14107872251301043, 0.5173787054034972, 0.19949491856799972, 1.0514925708693843, 0.111947585678389, 0.20345170140987445, 0.07652813869137919, 0.3466495150519956, 4.45106448665742, 58.36988879788307, 98.49371956240748, 105.50472090321203, 103.59336560772311, 102.87492859748103, 110.08156207300003, 107.93586869393627, 102.24349760240125, 105.17569680367748, 96.49780581074377, 97.01196578241165, 99.90854986252324, 103.00744195138256, 99.20072678596743, 97.28965390113093, 93.95961653801703, 95.72312201223066, 91.81617459943219, 90.10507983546104, 84.09065861855784, 70.32624583090507, 67.75840343967562, 65.49266592148813, 65.40175322563418, 72.29698581080284, 79.48690214464742, 83.93745083962718, 82.66481430299821, 79.22241672392815, 68.58825145229217, 64.61776556507235, 62.689245977709376, 62.65112838437481, 66.24416458991267, 70.89079256980651, 73.68116671039213, 75.17328339238321, 74.40794267962056, 75.49128563173356, 78.97605265340498, 82.58005972831481, 84.56469274336293, 80.52155279344129, 79.69249709959954, 80.01962277197069, 78.38460629986179, 76.53480083711686, 69.55955582280313, 64.32008512558477, 65.22583100103563, 54.74437928968861, 46.66696786880494, 52.43040838549214, 63.576646927864324, 55.508198122824396, 66.03612992071336, 70.4264388545867, 67.10889031810146, 69.06108533182453, 75.42637825012207, 75.91632150834607, 75.51571415316674, 71.89549984470491, 68.6798466405561, 69.60186250748174, 68.94582256194084, 65.19045906682169, 64.47264571343699, 63.94234911088021, 72.11518395331599, 79.82526932993244, 77.60337214316093, 76.05127457649478, 82.05142621071109, 83.22319507598877, 81.03442622769265, 82.51907471687564, 75.36726028688493, 67.52055091242637, 65.18647001635644, 62.01433943163965, 64.19643632827267, 64.87392379391578, 76.25148803957048, 81.58810015647643, 87.29911035107028, 86.6000263152584, 73.61327832744968, 73.42021142282795, 63.86905570184032, 64.8817999132218, 65.0930783825536, 70.68947299834221, 72.32510920493834, 80.96164272677514, 82.53918863111927, 98.36431272568242, 51.90965098719443, 0.8536102827037535, 0.16278766245851595, 0.38159768006974654, 0.961541836300204, 0.790558549905977, 0.45891623763788136, 0.6561590875348737, 0.6043912169914092, 0.9487642251676129, 1.1974380814260053, 0.3443107099062012, 0.4093337095072193, 2.059675556036734, 38.896921219364295, 79.79956996056342, 97.50125792718704, 84.42524463899674, 53.92278002154443, 27.948597631146832, 28.113945145760816, 36.85776725892098, 50.177924556116906, 71.29395731033819, 68.6658202448199, 78.65562638928814, 65.15601673433858, 4.0837703116478465, 0.13247161743140992, 0.08364723289325353, 0.13476793534092366, 0.06021458745723771, 0.16742212667820916, 0.058306879138634096, 0.04839339879371467, 0.03010739332004901, 0.024104908656989856, 0.07215211423294199, 0.06290276317046055, 0.009275509134656, 0.026976671595607075, 0.2199249819762284, 0.24981171133056765, 0.1912067052457602, 0.11960570700466634, 0.11573006819573142, 0.18066354276191804, 0.10066776836831724, 0.2265654933909255, 0.16702333194834573, 0.2347719498098858, 0.2139608802333955, 0.25095169612717244, 0.42569526381069617, 1.3255077576444996, 15.3124124580814, 113.81355608663252, 102.14321828657582, 98.16871196992936, 75.31805023070305, 65.05154440479895, 44.533861375624134, 56.4587688446045, 117.36959257433492, 123.96943538419663, 96.48209279583347, 22.558107837553948, 0.5852601016240736, 0.41170557900782556, 0.5189230773718126, 0.3857709900025399, 0.6455544081907119, 0.6598507733114305, 2.3291622438738426, 0.3438204442781787, 0.46340827079069236, 0.6024576723575592, 0.6244371026273697, 6.150999126895782, 63.14540586163921, 105.33843594212686, 110.17410647484564, 107.63325783514209, 106.3647319424537, 114.6142138204267, 109.4357438241282, 105.77719226960214, 106.31655739199732, 97.57177429814493, 100.56328758116692, 102.24243856245472, 106.86690515087497, 103.92923816557854, 102.52996398556618, 96.74849233319684, 99.00427879825716, 95.73836434272029, 97.89906471006333, 90.97009581904258, 74.84261974211663, 72.75816240618306, 70.91290689283802, 67.61814732705393, 76.43216809918805, 81.42727513467112, 85.22432557998165, 84.8765839299848, 80.93597473636751, 71.26345695987825, 68.21269235303326, 68.90556335449219, 66.52214296402471, 69.96648603870024, 75.73713194939398, 78.2719087600708, 78.08835752548711, 78.18892709670529, 80.04208226357737, 82.94750736605737, 86.5303885552191, 89.06375331263389, 84.34711886990456, 84.0682932638353, 85.15091449983659, 84.37419891357422, 81.8037599132907, 72.0434045791626, 71.32658358543151, 68.24409484863281, 54.24713650057393, 47.20120253101472, 54.169999168765166, 70.5770343349826, 64.04675083775675, 78.18452619737195, 78.72897471151045, 73.04382862583284, 69.70537385632916, 79.49332698698967, 83.45380690789993, 81.22925035415157, 75.00569620440083, 71.86088100556405, 71.42139511723673, 73.67297680147233, 70.79468665584442, 68.69818764348184, 66.46606091530093, 75.30902093456638, 84.52942279077347, 81.71031336630546, 78.48307348066761, 84.8379485837875, 86.63912450113605, 84.00635903881442, 87.45247502480784, 79.62404389535227, 71.8423987973121, 67.39516058275777, 65.92216153298655, 67.06453615619291, 69.34569251152777, 80.00220744840561, 85.64155593995126, 87.52740798457977, 89.63950234074747, 77.33394453602453, 77.51171419697424, 64.76866306797152, 68.49063150344357, 70.32435524848201, 73.74001795245756, 76.55434208531534, 85.72273331303751, 86.62810264095184, 107.06619293459, 51.38101354722054, 0.9095551710455649, 0.41376359760761267, 0.6751542069738912, 2.114966021430108, 0.6725241964863193, 0.49227924416622815, 1.1082258556158313, 0.9633494360793022, 4.103866084929436, 1.3652007954735912, 0.3236923727297014, 0.5843463119479918, 5.206533574288891, 51.7625307267712, 89.30031930246662, 103.51497311745922, 107.47394684822329, 113.02869765989243, 35.24096627389231, 26.196519982430246, 42.53453123954035, 60.56476869890767, 80.39467196310721, 81.44614957994031, 88.98164241544663, 79.01921441478115, 5.538315590350859, 0.19401837050193743, 0.3330619344788213, 0.3821268629643225, 0.1799778021391361, 0.3204302784175642, 0.13499069838754593, 0.1908846112388757, 0.10612203093666224, 0.2045755677165524, 0.28548456488117097, 0.1692955334100031, 0.08331926299198981, 0.1557447403789528], [0.007481522259167246, 0.027597629908292044, 0.039793410668930704, 0.0038520720291642416, 0.06367032198355564, 0.03139702764700257, 0.018739889586164106, 0.04878266722023968, 0.04554674630203555, 0.015591612956937284, 0.019835671109537927, 0.013449170510284604, 0.08305271035961567, 0.3233682868942138, 35.63685501775434, 84.02590813175325, 70.61020189715971, 56.66801552618704, 36.45060954555389, 32.06839638371622, 31.541841722303825, 64.60379016014838, 112.43186981447282, 91.18605367598995, 34.04616525096278, 0.7977944648554249, 0.16594081906782043, 0.12835534274457924, 0.03251926027118199, 0.17117974198152944, 0.08357979417327913, 0.1137901803538684, 0.5571879434489435, 0.2943341061472893, 0.26677271411303555, 0.18101778181810535, 0.3004124928866663, 7.0179233435661565, 59.17113880957327, 101.25139682523667, 101.18620703297277, 104.3077939556491, 106.07320570176648, 100.9738891355453, 98.72511586835309, 100.91182939467892, 100.47166101394161, 99.33749198913576, 94.95468262703189, 93.72809471622591, 95.16713388504522, 89.82216711967223, 88.54414909116684, 86.21017409909157, 84.72610612069407, 77.1827450106221, 74.72484665532266, 67.43376454999371, 65.58430033345377, 63.44532989686536, 63.68883848190308, 71.53119794784054, 80.0911589591734, 86.6757280595841, 86.76034927368165, 82.98282438708891, 82.22483419602918, 78.26552314143028, 67.47164680111793, 61.155101099321925, 57.82778978347779, 60.12975431257679, 61.60799757126839, 69.09293497762373, 70.76808514133577, 75.02116603236045, 71.88677649344169, 77.0013746138542, 79.97122072404431, 84.0101323589202, 74.55808316507648, 76.68654949434342, 71.47917162987494, 68.99426383356895, 64.81173461483371, 65.27087157772434, 61.14387527588875, 62.29466338311473, 61.21549775523525, 55.844796319161695, 53.47047582749398, 58.314328424392215, 55.859556198120124, 49.69513177871705, 63.16801440331244, 61.162161365632095, 66.24385080029889, 69.08491765299152, 68.3801148014684, 67.81549745990385, 69.93553853804066, 68.7387292615829, 72.37362107922955, 69.76526060412007, 65.75098537629651, 62.06397310380013, 63.538435197645626, 65.42311837596279, 76.48350408000331, 77.06353633634507, 75.87450904230919, 77.70488308322045, 74.63449093603319, 74.18251622107722, 72.59190882405927, 68.60153259769564, 61.58519291108655, 59.14101500664989, 59.26169064737136, 59.403856954266956, 65.7516404121153, 75.05586331890476, 81.32712133469121, 79.79927186043032, 75.90870426547143, 79.59259433131065, 68.07371493308776, 65.10966216364216, 58.682034938566154, 58.7125470561366, 59.63060525155837, 68.02138267024871, 67.06859973169142, 79.6997848633797, 73.98165164455291, 87.35585135798301, 19.20966475240646, 0.388102593921846, 0.04549883516325105, 1.1874878863173148, 0.8434883613259563, 0.7214972557079408, 0.44845754400857035, 0.18473214379722075, 1.2552813969312178, 1.2297678498491165, 0.11753874815880291, 0.03211194664360054, 0.34066747152997606, 11.925643893980212, 48.850959270231186, 82.25196915288126, 91.03567000358336, 88.34727748747795, 57.61091409191009, 29.248739788609168, 16.90048502337548, 30.64512122061945, 39.285628103440814, 63.381407030167125, 65.14156672262376, 63.90578085376371, 33.47582124894665, 0.22273989544520456, 0.06837697083791418, 0.04245784148694046, 0.012702867764258578, 0.024789525045742913, 0.03781846281321299, 0.06609500941610144, 0.06855849537157244, 0.07635009219689716, 0.013879139273006831, 0.047816193677605166, 0.00828882236213934, 0.004399254159521191, 0.03137727023943538, 0.04844203388558761, 0.07714971178962339, 0.03892371701377054, 0.02210995441512956, 0.033275274139258175, 0.01861873469615896, 0.01011699064439463, 0.022813740238967924, 0.10392752611228537, 0.07237639413365433, 0.08835418435234217, 0.1925020067081336, 0.5654372395046297, 42.08279971153506, 95.20432579901912, 78.39886019306799, 72.75508726796797, 50.64364325615668, 48.12110816278766, 29.962140475550008, 66.81189629339403, 124.87249835844963, 102.13155315768336, 43.174030550064586, 1.0091510138684705, 0.1536367115594687, 0.4776962395877608, 0.4134458243366211, 0.23990118425459633, 0.11888838057676632, 0.0526227978538842, 1.3274536209721721, 0.41840722423888027, 0.3846226242040435, 0.15143780939040646, 0.3145123411330485, 9.62845386997346, 66.61846068597609, 104.1469846233245, 104.43243903498497, 106.1366068932318, 106.31955408280896, 104.10295209577008, 101.58210754394533, 102.80954268670853, 102.93999287389941, 100.49848218117991, 95.986265982351, 97.00604300345145, 97.89613862191477, 93.7538254645563, 92.64075094653715, 87.65454769134523, 86.52834107798915, 82.65214504734163, 76.60631349009853, 69.66454198283535, 68.04196726891303, 66.87143787260979, 67.44067576623732, 77.38715540978217, 84.7642158692883, 89.46438420203425, 90.19879310361802, 89.40608209179294, 86.76988847794073, 85.17861427799349, 73.5003532901887, 64.557937652834, 60.1189991735643, 62.71675355972783, 63.619894981384284, 70.93472311573645, 74.01736090260168, 79.02964791943951, 75.7861380423269, 80.93585706526234, 83.42478921336513, 87.02016707389586, 77.87021098598358, 79.47454667860463, 73.1794406521705, 72.01848183908771, 70.1110096900694, 65.23621743725192, 64.38770678735548, 65.68810193769394, 64.78050862589191, 59.858891117957334, 57.52758725996941, 63.591940249166186, 61.88187314618019, 58.1946922117664, 64.97527391679826, 66.87108485929429, 67.99864861272997, 73.09090491264098, 75.98231146412512, 71.10150229546332, 74.52613153765279, 72.39439395166212, 77.98584245866346, 73.54496632852863, 69.9018846019622, 66.00737110260995, 65.0262451171875, 68.21433190376528, 80.09608545610982, 80.97235079734557, 79.40119051164197, 79.8815788761262, 77.98280654415008, 76.60158311167072, 73.71869594820085, 70.8541968560988, 64.58479019903368, 61.404712892347774, 63.32588588037799, 62.55506169411444, 67.44646518461167, 77.41520820125457, 83.7606539264802, 81.87089520116007, 81.14364070277061, 82.17844824637137, 71.0709156528596, 68.44086447069722, 62.0858246280301, 61.14134926949779, 62.104467653459125, 69.54428995809248, 69.81288602275234, 83.28192864694904, 79.86951366547616, 94.18567057578795, 27.36133448539242, 0.16450420502693425, 0.08606332098884929, 1.3776678039181618, 0.8186468265710339, 1.4363040510685214, 0.7582346037510903, 0.21031097689222908, 0.802550399976392, 2.0627330435860545, 0.9881501536696189, 0.061985016650249886, 0.38039093837141996, 11.260992384726002, 55.631964591241655, 90.43972076908236, 101.64770526270713, 77.2426631373744, 40.26062342428392, 30.307973892458026, 27.855504097477084, 43.11557938975673, 47.7011792121395, 75.58335150441816, 73.30055559835127, 76.11429922042355, 41.73609748963387, 0.1969248314778651, 0.17346703537529515, 0.03292313799442303, 0.06571770345251407, 0.021248342987570553, 0.0665438986353336, 0.051295083211434465, 0.07585175200215272, 0.01716383030608056, 0.07253863623425846, 0.053776116410811106, 0.06284458262305107, 0.03894330971243401, 0.2070137344661259, 0.12326818184867022, 0.1441830333562628, 0.1484862871227726, 0.15067648653301502, 0.19843794705886997, 0.1377469448432807, 0.2782436856819738, 0.10043892258357617, 0.29304094973110384, 0.18802264464959023, 0.2810566992528977, 0.22060804129127534, 0.6173552019942192, 51.18009013514365, 108.63622357768398, 90.66997174293765, 80.06295711763444, 55.11996192316855, 44.665802063480506, 43.08572623037523, 94.55398897970878, 131.3646093491585, 114.82528440413938, 53.71262727245208, 2.020702640856466, 0.2628960334245236, 0.5079855787898264, 0.4912354646911545, 0.6416044588531218, 0.5821654741321841, 0.25456427566466794, 2.60341779839608, 1.1140229961564465, 1.0688090997357522, 0.6011384076649143, 0.5583482295755418, 13.637668259682195, 70.0501423497354, 111.30138781762894, 108.75854661387783, 109.6081712169032, 111.71611570542859, 108.82941599815123, 105.9799317390688, 111.13575396999236, 107.95726914559643, 106.70412678872387, 98.69973028859785, 101.3917156957811, 102.56782270246937, 98.4138914846605, 95.3282020938012, 94.90700229521721, 93.353696638538, 86.48762687560051, 79.34534380512854, 73.96012567704724, 72.92029749962592, 71.52602826395344, 69.59833237432665, 78.190809834388, 88.69504267169584, 92.09852249391618, 93.69452707229122, 93.89109273110667, 90.26704234461631, 87.24840194948258, 75.39467765438941, 67.8745291309972, 63.041282623044914, 67.5810887736659, 68.15666521749189, 73.9303627321797, 80.1298099948514, 81.90323122086065, 80.28023289095971, 86.3605107030561, 87.95453056212395, 91.78299134777438, 82.18973682772729, 82.5682455493558, 81.21757738051876, 78.13555148340042, 74.88604037992417, 67.81751355817242, 68.72218470419608, 69.5251174126902, 63.44198411510837, 62.588786232856016, 60.227503699641076, 67.87902416721468, 65.73816707057338, 65.43499923521473, 72.3037479769799, 71.21206606588056, 75.47785543626355, 76.805907218687, 79.86524612672868, 77.1695815363238, 80.00480405745968, 75.09015267895114, 80.04428663561421, 75.54738336993803, 73.12160138160952, 67.72079575446345, 69.51278548086844, 73.87315104084631, 83.48724119124874, 83.32128570925805, 79.40872930711316, 83.7463451200916, 83.07469414126489, 80.53031536840624, 78.83067392533826, 76.09885292668497, 68.27058653677663, 66.40717829427412, 66.5875602537586, 66.24953823704874, 70.41959039626583, 82.50732329583938, 84.639264845079, 87.81748294830324, 86.56772951925956, 87.10428622461136, 74.40189438481485, 72.33871198469593, 64.58374292619767, 65.84263940011301, 66.79942315624606, 75.16790974524714, 73.75437382728823, 89.16663708225374, 85.1892674353815, 99.89316632670742, 24.66389698366965, 0.5463738463098003, 1.0799862612639706, 4.005715145218757, 2.5681029836977682, 2.065817742578445, 1.739440752613929, 0.710585834758897, 4.732912278944447, 4.0848685752960945, 1.1240570319275702, 0.27530555463125633, 0.5999082543196217, 19.36249598380058, 68.48965875564083, 98.80288077938943, 110.87887010266705, 110.29234240131994, 77.62289770187871, 41.56523512255761, 28.3865753681429, 47.60344943692608, 59.87734979198825, 85.87623134736093, 82.98630745180192, 86.21543791986282, 49.17159341996717, 0.34207474440336233, 0.26594821964540794, 0.1261465580412938, 0.19848480099631896, 0.08114873671964293, 0.1694939195388748, 0.18699158223405962, 0.1686293739945658, 0.23287563704915587, 0.1328751772281624, 0.19172465729136623, 0.15875868349065705, 0.12076629956643428], [0.05969614894579976, 0.0325893305031763, 0.03912369660552471, 0.03726484554429208, 0.030907779000699524, 0.11224992227770629, 0.04964783329576735, 0.022620402629517262, 0.06046944958788734, 0.08495630861650552, 0.02466791433342282, 0.04157695528720656, 0.037250128995266654, 0.14301001484836304, 60.182718077013575, 81.49364948272705, 72.23545951227989, 56.81948569513137, 31.015173312156435, 32.87287646724332, 68.8500931955153, 82.37537476324266, 99.82895712698661, 67.89956954217726, 8.314020556788291, 0.09713922101523607, 0.016961841648744962, 0.43897012729317914, 0.08612817799251887, 0.12490888171258474, 0.09404506083698043, 0.10825167109649028, 1.0462373302828882, 0.046817192041705695, 0.07806956888206544, 0.05492189283212347, 0.2972775385264428, 9.713033899184197, 85.70697322968515, 105.3463512851346, 103.93687894267421, 100.61379201950567, 99.86181874429026, 100.92045860905802, 95.49855847512522, 94.98563012769146, 90.60585668010097, 90.1533014543595, 96.5586966852988, 94.62838849713727, 92.49495644723216, 88.4960529881139, 80.31405941132577, 72.88568650522541, 70.84753667154621, 72.98167474808233, 65.65267116792741, 65.13830723301058, 66.42638221863778, 68.33804345900013, 77.20507898638326, 86.8378003951042, 85.06935273447345, 81.74113535111951, 83.8666206790555, 89.7513448038409, 86.52182209876277, 82.7839288403911, 80.16428762866606, 71.00744385873118, 61.716043180035015, 59.62508255435575, 57.600064816013465, 63.15362322715021, 67.64762001652872, 69.59639472346153, 74.71657829899942, 76.25346491413733, 78.47355781062957, 82.33123240932342, 65.20424619797738, 67.46065631989511, 66.23068732600059, 62.94005017126761, 63.28852922685685, 63.285975763874674, 62.3411120906953, 71.64842190281038, 78.12681244265649, 70.53470411608296, 60.87077240790091, 60.51918291276502, 59.467669994600364, 56.72807485826554, 59.225848028736735, 62.495190635804214, 56.446264328495154, 61.52502767501339, 75.70001848282354, 71.51440235876268, 71.5836400370444, 68.90624584690218, 73.2340871134112, 72.98339274621779, 67.39355241098713, 70.84905855117306, 67.760984359249, 68.94213553397887, 75.23495874097271, 75.812590506769, 78.1110288250831, 76.49451809544718, 71.02656149095105, 69.29818476400068, 62.75962506571124, 60.67077075281451, 59.25107671368507, 58.403295624640684, 58.18186606130293, 61.50281921509774, 68.344436922381, 76.1797086654171, 76.1660352829964, 73.46115312268658, 78.6650400777017, 73.78037129679035, 71.98233327557965, 63.17879699891614, 61.96300737319454, 59.778662958452784, 60.03142049235683, 63.08411098295643, 67.62407010601413, 72.10933962175923, 77.52245364650604, 79.54893050655242, 77.95818974894863, 4.322153339462896, 1.044276390344866, 0.5108992563140008, 2.863887692651441, 1.0327383707607947, 0.2151095984323371, 0.05758203355775726, 0.20924372448315545, 1.1365969719425326, 0.8256994320019599, 0.1417921189098589, 0.021165808505048195, 0.6849285695822008, 29.81862879568531, 65.52367618007045, 87.98669399753695, 83.26259136199951, 92.68407744746055, 66.743835326164, 33.98614906495617, 16.907272684958674, 41.409854350551484, 41.9303136487161, 52.68709613430885, 64.37933252703759, 65.06626113768547, 4.815039355908671, 0.4076740259845411, 0.11436784895317209, 0.06503327284008265, 0.12745423182364435, 0.03053302027946038, 0.06056537911776574, 0.0406000935923188, 0.032031652968256705, 0.04998742092040278, 0.059839878531713644, 0.05955498958487184, 0.034531681317715876, 0.046045948345694816, 0.050678068336339734, 0.051858943075903004, 0.04803093961409984, 0.02624940134644989, 0.012541193526328332, 0.03360507499066091, 0.05520455629354524, 0.03216832688438796, 0.03710444205470624, 0.00687457473700746, 0.06671216218702256, 0.08977070390697449, 0.036861753061173425, 70.27738878803869, 89.76386500943093, 82.92169032558319, 60.59454341088573, 41.12419597564205, 32.994169881266934, 32.46535985700546, 92.61371797130954, 109.89100548528857, 81.92761267385175, 10.381462650914347, 0.10121985729182921, 0.04645055768290355, 0.9004357829689981, 0.637312344005031, 0.1433382835239172, 0.2269047018020384, 0.0036680036047924192, 0.9574541137103112, 0.3858628286229026, 0.2600331934950044, 0.24061481047782207, 0.8912763744592668, 12.599806170309744, 90.24990158696329, 106.52343888436596, 109.90945631457915, 102.84612271093555, 104.1365432739258, 101.91001769035094, 98.53992508303736, 95.68849532834946, 94.14166158245456, 93.08264517015027, 100.86163090121363, 99.23092903629427, 97.86042151912567, 93.00233071850192, 82.33032241944345, 75.44210695451306, 73.58850463744133, 72.04822124973421, 68.76546413667741, 69.59386087233021, 69.18545584524833, 71.68935575792867, 83.39953699419576, 91.73768797228414, 88.1538575695407, 86.50763880821967, 87.28458973669237, 92.35237829146847, 90.00018781231296, 85.53152561187746, 84.68506243921097, 75.74180741463938, 66.81275921483194, 60.69572094948062, 63.78113577442785, 64.93746226833713, 73.85700656521705, 73.61527873623756, 77.41092497302641, 79.75339581889492, 83.16954489677184, 82.71869982442549, 69.06041852889523, 67.91726727639475, 73.15951501169513, 67.56949424743652, 67.64757294808665, 65.04098538429507, 65.8230040150304, 74.65783688329881, 82.60037760580741, 75.43482703547325, 64.71080418555968, 62.010730851081114, 60.72707245426794, 64.33933611839049, 67.81836863486998, 67.41965970685406, 63.79180069892638, 63.86563147267988, 78.74272654133459, 79.5974894492857, 76.1076468806113, 73.39022882523076, 78.76917116103634, 77.28281251845821, 70.08996225172474, 72.91081320854926, 72.30277522917717, 72.92016413904005, 79.09277454499276, 78.08846735185193, 79.82650095416655, 80.4206302089076, 73.75395021130963, 70.50775743299916, 64.8694169905878, 62.37169088855867, 62.63039081327377, 62.74977991657873, 60.58144661688036, 66.8649894960465, 70.3972093520626, 77.01766029480966, 81.01799934141098, 77.04961976697369, 82.6486776721093, 77.6603171133226, 74.77277801882836, 66.64235576506584, 64.29691960734706, 62.413499432225386, 64.84220750870244, 63.554018774340236, 72.80474447434949, 75.60251620508011, 85.6252545695151, 85.27646172431209, 88.00292476530998, 8.287767152632437, 0.505312575447944, 0.4126140979989883, 1.427029851944216, 1.595945375100259, 0.3676411515522388, 0.05020165357798819, 0.21094447031857508, 2.0766248529957188, 1.8128216795382963, 0.27084030391227815, 0.0515404956475381, 0.5364630587639347, 32.24120620758303, 75.46253465837049, 95.02772500438076, 91.55830229482343, 72.68827361445274, 41.41932687451763, 30.675756892850323, 24.811180022455034, 47.20394819013534, 52.02765549382856, 65.16004500850555, 72.17211323399698, 78.45423621516075, 6.065951845338268, 0.28283730209354435, 0.13399392606750612, 0.06764237678820087, 0.12805844536952435, 0.03210611862971658, 0.01370269198706674, 0.04929470506707027, 0.06536544090317142, 0.02756699788263969, 0.06444356133860928, 0.04512290432748776, 0.08856897242367269, 0.15210245195175373, 0.17548904784264105, 0.1882308367038927, 0.1015638767351066, 0.10122744922315884, 0.19430893232985852, 0.16897233623650768, 0.1352165717511408, 0.13236392079101456, 0.13067059068670198, 0.09279540289313563, 0.15991061925888062, 0.16025468466743348, 0.2077049602784457, 82.25616608896564, 102.94946147549538, 93.09802086122575, 75.53279215289702, 49.26274538040162, 45.4603095208445, 97.12666373099051, 108.62967321949621, 117.72619878092121, 94.45086986787858, 15.221874348578917, 0.22484098350809467, 0.2576364414586175, 1.3233124560886815, 2.316640567394995, 0.2762189765851344, 0.4298098607649727, 0.2914861589670181, 2.160055627745967, 0.963843716008048, 0.8795889370864438, 0.49333923406177954, 1.6098587575458712, 14.556444248845501, 94.1831131904356, 112.329237076544, 111.54429235766011, 108.11234397272911, 108.66675530710529, 109.55282657377182, 104.65715162215695, 101.62262562782534, 96.91196887723862, 98.92722775859218, 103.7285775523032, 100.52970424775155, 100.01030398953347, 95.99175730059224, 87.37424727409118, 79.97235036665394, 78.66317302949967, 77.96390071991952, 73.27236944629301, 74.31856755287417, 75.80238449958064, 75.30055645973452, 88.26790440467097, 97.37915454372283, 92.48133013325354, 90.78556399191581, 92.9181174309023, 93.18694099303215, 89.16469158664827, 91.08393869092389, 90.06424011722689, 79.63671315100886, 68.61964610315138, 66.98347645421183, 64.85110344425325, 70.28677894223121, 76.55214555801885, 79.10109781449842, 80.72968159952472, 83.53206603757798, 87.23417943523776, 89.06325909399217, 71.51499071428853, 73.02370686684885, 77.46125682707756, 70.36813674434539, 71.58243979177168, 65.71393466764881, 67.76598145884853, 75.40167516277683, 84.23040482305711, 75.57792294409968, 64.45333588507869, 62.81893130271666, 63.92826387959143, 67.7846440961284, 73.18461818079795, 70.27303495714742, 66.23137766315092, 68.78116930684736, 84.39108079479587, 81.92469443044355, 80.4879145468435, 78.60637710940453, 79.73765142502324, 80.42981639985116, 74.13023102668025, 77.4810883306688, 74.96116161346436, 75.16756457667198, 84.73890089219617, 81.55964728324645, 83.03630982675861, 84.35130011650824, 77.26182783803633, 75.34242383895382, 69.90920374470373, 65.74640797030541, 66.1092899691674, 67.27577147945281, 64.35953632477792, 69.08390568148705, 76.00117021991362, 83.3283067518665, 83.15093717267438, 79.30892852044876, 84.81614020562942, 79.38668558674475, 79.29622788583079, 69.57574736687445, 67.85144206016295, 65.72170096059, 68.17942280923167, 69.62693429762318, 77.17599068918537, 80.44260332661291, 91.85926575814524, 90.56642117038851, 93.27250357597106, 6.626009431577499, 1.5111961936758411, 3.372274180573802, 6.334189993719901, 3.693310618400574, 0.7763930938897595, 0.6641290372898502, 1.3397381166296622, 5.65078906474575, 2.934032419035512, 0.9092588482364532, 0.14760691011624952, 1.4326888515103249, 46.204390987273186, 83.2916953486781, 103.36992386848696, 100.57862404854068, 117.94466695477887, 85.49039563825055, 49.379314299552675, 29.96904580823837, 56.67001201260475, 60.063893795013435, 72.62044798943305, 83.19266334656747, 89.07867400876938, 7.494513382834773, 0.4575436838692235, 0.29225000991455974, 0.21314067585814386, 0.2992505213666347, 0.17120859285275783, 0.17464152477200956, 0.2569384281072886, 0.21014298913219284, 0.12920664262867745, 0.13758808885130192, 0.21227082898539884, 0.17178691262679716], [0.04898065498339073, 0.005914067582888228, 0.03660036386140893, 0.07064243838671716, 0.05171862258125217, 0.052374933936422875, 0.012081038984169644, 0.04539367427388507, 0.03124471596111694, 0.055299041747686364, 0.07833190036997681, 0.13219325172324337, 0.2333541968536954, 1.6729427273235016, 73.01925889907345, 71.77696581809752, 64.54170688506096, 57.41855321391937, 37.042138268870694, 55.57564720030754, 70.20244013878607, 86.88448444489511, 103.94469230405747, 37.519875111118445, 0.7369957659994403, 0.04613145524936338, 0.04630217411284966, 1.2685489366131446, 0.38114507532408165, 0.21664171299386412, 0.09884621812811784, 0.12057310751368924, 0.03938691292498862, 0.1418765417991146, 0.2689930207787022, 1.3830866808852842, 1.3014431586188655, 35.60675474905199, 115.327465457301, 97.03068333287393, 104.30456976736747, 94.1899851829775, 100.3737037412582, 85.43510590830158, 88.22756674981888, 84.66377965865597, 87.99708043375324, 88.62425173482588, 95.36930853320708, 94.76698152480587, 94.05725217634632, 85.43897336529147, 76.30774267258184, 66.82436943054199, 67.15540962834513, 61.4022574886199, 64.5687790839903, 64.21720920070526, 68.07222443242227, 77.9285680094073, 83.13004662913661, 85.46592789311563, 84.98148379787322, 84.15601315036898, 88.88748984183036, 81.48366312826835, 94.97905623528266, 84.22738459802444, 77.303726596217, 77.64523167763987, 70.92582718018564, 59.97311838211552, 59.995864206744784, 63.67594172877651, 65.73698251478135, 72.3300749255765, 77.95308282298427, 78.1705076463761, 80.4799521353937, 73.06368366364511, 64.8316563329389, 63.6383536554152, 67.51332590656897, 61.74710050705941, 62.44408607482911, 65.97757677878103, 74.77299767155802, 77.7381447822817, 77.6285380701865, 79.91316964549404, 73.73870788082, 63.42695359260806, 60.08543937436996, 60.64185896227437, 65.45782350724744, 64.5989852566873, 69.72140850559359, 59.741722076169914, 65.79185647349205, 72.95555960747504, 74.91904320255404, 74.16031560590191, 73.27788429875528, 82.31079686072566, 72.71553408715033, 72.61287781500047, 71.13940808080858, 73.27300487026092, 70.50354480743408, 72.56817848451676, 77.07302847216206, 75.67326007350799, 70.4986967579011, 60.67377921073668, 56.01670203670379, 56.5146194734881, 59.81855346310524, 58.97908387645599, 60.02410919435563, 71.6645428442186, 73.3208107179211, 74.60310412991431, 73.9147360094132, 80.04466318315076, 77.30546812857352, 80.0768344633041, 70.90375208085584, 66.27774792332804, 62.13401486796718, 59.74401666272072, 62.59291648864747, 60.335561075518214, 64.0594240157835, 65.68913352104926, 78.03098893934681, 76.13700189898091, 87.32120898462112, 53.483047023896255, 0.25009026089983605, 0.3108174684307268, 0.5230730675881909, 0.3647488938464273, 0.23974114848721415, 0.3082833721512749, 0.4446751227782619, 1.7063977256897958, 0.33630886025005774, 0.37231937471416693, 0.09792930281330502, 0.1671479284883507, 5.568425664978643, 39.5585976108428, 81.82061041555097, 83.20734870049262, 101.23284401432161, 95.73051175763531, 75.6095137134675, 36.4106523606085, 55.43387705279935, 56.219951414292865, 37.142343059662856, 62.688139869320786, 65.54087577327606, 23.554142752001365, 0.6437147552928617, 0.2670448591872569, 0.19726295204412556, 0.060618300471575036, 0.05673024337738753, 0.1290734965474375, 0.08068357579289906, 0.12647864949559012, 0.044068112338502566, 0.08519093836507491, 0.14754245147830056, 0.05512374933929213, 0.06814465467487613, 0.03942330593183156, 0.035801039212533546, 0.0904627034680978, 0.013050151699703309, 0.007000590933697119, 0.015100843626104537, 0.014711282170948484, 0.1163638987007641, 0.04691598290998129, 0.07309306938681873, 0.01772980648843992, 0.26795622802549796, 2.0098739574032445, 84.64436392630301, 78.23605829669584, 74.28411345328055, 64.15112510804208, 42.581944850183305, 44.08602868357013, 62.24005222320557, 101.6931890672253, 114.11212690414922, 45.535944584877264, 0.6883977221385126, 0.07847268434782183, 0.47513965096685196, 2.0429316932155244, 0.5621078213857067, 1.050056738238181, 0.5232200338955849, 0.19454528577625754, 0.07527683365849719, 0.46079627869109957, 0.03591001521976244, 2.963570563062545, 2.1836445168141396, 40.299207779669, 120.27654740118213, 99.71775793260144, 105.47994721320369, 97.72338175004529, 103.27493190765382, 88.88381065860872, 89.26471987078267, 87.34116600405785, 89.37799792135917, 91.78470934590986, 99.62966934327157, 97.9360055923462, 96.14275286274572, 89.76948968825802, 80.68902231031849, 70.5144960649552, 69.53924579005088, 64.0706459168465, 68.15869700524115, 69.39823658235612, 73.28094374748969, 81.97492430287024, 89.09002534804806, 89.74322549758419, 89.60890785340341, 90.22502591533046, 90.23304323996268, 83.8289737701416, 97.45600162013885, 90.16274652173443, 79.52232899204378, 81.5179838672761, 74.41406157708938, 65.82288634392523, 64.15635754985195, 68.12484695065406, 69.75045757908975, 77.30296565640357, 80.49716349570983, 81.44039154052734, 84.98062872117566, 74.97423095087852, 65.6221119819149, 67.21865392500355, 69.45173771150651, 65.48073014905377, 67.88686106281897, 66.63092597838371, 76.04382207316738, 81.4731982446486, 79.11685789785078, 83.71687243061682, 75.27190746799593, 63.90270571554861, 64.66057823550317, 62.69744765373969, 68.98196328070857, 68.63472369409376, 75.1000919649678, 66.39013951824558, 68.22954285529353, 74.86925263558665, 77.85851447812973, 78.1044392431936, 73.79702568054199, 87.20011757266137, 77.98293990473594, 75.31275503097042, 75.43605865970736, 75.16126525017523, 77.27228487691572, 78.20577759896555, 79.18614264457457, 79.26212679955268, 73.67946440173735, 64.28528977978614, 60.29410554516701, 58.98106859576318, 61.08383555566112, 60.968674767401914, 64.45099030771564, 76.45149753939721, 78.97386397084883, 77.67488479614258, 77.32031037730556, 83.60506134648477, 79.59863478137602, 86.10270900111045, 74.22107311987108, 70.37544804234659, 63.92640075375957, 62.3429673717868, 66.1315062738234, 64.58518635842108, 68.5703654443064, 70.15407731456142, 82.56909278131302, 81.98358489621071, 92.257857015056, 62.94984040721771, 0.9453913545416248, 0.24617002045194952, 0.2170170194679691, 0.7515541944772967, 0.3872393047617328, 0.1272367547836996, 0.2829310712554763, 1.9694692545360135, 2.253624993947245, 1.1618828989805714, 0.3750371788778613, 0.34038000469726903, 5.21409982635129, 47.44698609075239, 90.34200668334962, 92.5057037415043, 95.2587761417512, 69.97795504908409, 53.53879959352555, 33.23431699506698, 61.37085107065017, 60.65414382565407, 50.07679800833426, 69.2252992814587, 76.33253205207087, 28.48053574562073, 0.7678254729797764, 0.2826141560029599, 0.19772292655562201, 0.10671640791359449, 0.0399162566980287, 0.10798052959744969, 0.12184705810561297, 0.07143147064432984, 0.059471294479144204, 0.060752833171957926, 0.007373109805367648, 0.060544223599736734, 0.1102541100173708, 0.1556092194251476, 0.23635281820691403, 0.15608155859574196, 0.1332116890097818, 0.19466911622833824, 0.14337658792013122, 0.11407209304912437, 0.4662108042788121, 0.20801438319106258, 0.3071199910294625, 0.22874098391302172, 0.43352976922065983, 2.721611314242886, 100.09041447793284, 90.59219114242062, 86.12532538752403, 79.63916855473673, 54.511645455514234, 80.69966762296616, 107.15235956253545, 107.71410572913386, 128.80295645806098, 56.94957110189623, 1.635915920619042, 0.23958857441621445, 0.31702912382541165, 3.5674304827567074, 1.2468539394678608, 1.4599045846731433, 0.28733123514440756, 0.6021537499562387, 0.20095089931161175, 0.9257402186912875, 0.5755973427045731, 2.906668248676485, 4.292221732677953, 42.47582120280112, 127.0912576490833, 103.02252738706528, 111.75679852885585, 100.5400828392275, 111.11602444802563, 90.4422232412523, 95.97082753335276, 90.05241809352752, 96.86896401066934, 95.18988363204464, 103.49712633317517, 100.21882503263413, 102.35677565297773, 90.35454257842034, 82.69172960712065, 75.38673877716064, 73.0040636370259, 67.07519715832126, 72.76235934226744, 71.29099984322825, 76.88344463225334, 85.88233455534905, 93.8777566725208, 93.66569765152471, 96.87462006845783, 93.60940379481163, 93.16987083804224, 89.28553196691698, 95.73193950037803, 88.61739543176468, 87.34745748581426, 86.09637045091199, 79.27395666799238, 69.45584051070675, 69.03816300053751, 70.32387671932098, 71.08595402010026, 79.9407752867668, 85.68166609733336, 84.40645648587136, 88.3244728272961, 80.17730989763814, 70.05886570099862, 70.47022035045009, 76.90555111054452, 68.79130471137263, 71.78390056856217, 66.27505717738983, 80.45311527867472, 84.77062502214986, 82.63959346279022, 87.41544000564083, 78.2610987078759, 65.27932428544568, 64.67287486599338, 65.72585082823231, 72.38767885392713, 75.82129816855155, 81.63463515620079, 69.54366237886491, 74.11130166822865, 79.43179284372638, 82.45582257547687, 82.66752858315745, 79.14625213992211, 86.16252514623827, 79.54455314144012, 79.03721809387207, 77.87239966853973, 77.40170740312146, 76.36183215725806, 78.17524586954426, 82.12634348100232, 81.33062793362527, 77.73135123714324, 67.3606986384238, 64.98030239535917, 61.48609422868299, 66.61604450594994, 64.68170804362144, 68.09977516051262, 79.14731117986864, 82.07221477262436, 81.36286197170135, 80.07099797648769, 86.80089873652305, 84.15922164916992, 88.1819260504938, 78.31331329960977, 72.95381807511853, 67.04497921851375, 67.34216151698944, 69.99141662351548, 69.8050412824077, 73.25344793258175, 72.46451024086245, 89.91467229781613, 85.89435269755703, 100.89501027138003, 64.12251534000521, 0.6342899126391257, 2.7747655587811626, 2.1522582009915383, 2.0040630885670265, 0.8726646054175593, 1.0033710336973591, 1.227151506370114, 5.158551710267221, 4.587608075911, 1.967601470889584, 0.3285064998893969, 0.46810693317844027, 9.559075966958078, 59.65733228191253, 99.1683986110072, 102.10506931427987, 115.02851024750741, 120.18317145685997, 94.71195851602863, 52.01824965015535, 71.10500104965703, 70.3661520250382, 57.11152576631116, 80.00578465000277, 88.65200642616519, 32.86148982663309, 0.9250875730668345, 0.43401148530744743, 0.3268213822476326, 0.15316146125476207, 0.15325713031474622, 0.2600235101436415, 0.3291400852462938, 0.17256403221718727, 0.20900393896285566, 0.18634558625278935, 0.19307455017922387, 0.26451232572717054], [0.05748271791925354, 0.07864735239455778, 0.032908992180901195, 0.02634857717390743, 0.11178222559993306, 0.011928550140451522, 0.08223335634195998, 0.11481120701759093, 0.049872691592862534, 0.0482743525607211, 0.0386687821047681, 0.07369264810075683, 0.30984242236421955, 3.9005838574901706, 76.58701542885073, 69.11926192622032, 72.63932243470224, 52.53486110318092, 41.00605026368172, 44.668104494771654, 62.07987047010853, 96.69146107089136, 72.06389504094278, 10.938461769011713, 0.11895172838722506, 0.07126336797110497, 0.5132653954769335, 1.8111888703800019, 0.6277624145150185, 0.5082172744216458, 0.5972214920386192, 0.19217511699084314, 0.010104018860616753, 0.08520896441393322, 0.6259507085046461, 5.923092749810988, 4.50265149916372, 91.55892202931066, 102.47314453125001, 99.32962371457009, 97.12293747932681, 88.33330600492417, 84.48168754577637, 83.39306508341144, 77.13363693606469, 72.81018872414866, 77.94345732658141, 91.44541648126419, 90.28282596218972, 96.65648137369465, 93.36168258420884, 89.88363066027242, 81.2352986489573, 68.0115375211162, 66.27484536940052, 65.09301170226067, 64.59065806481146, 68.06443460526006, 74.15086269378662, 81.50138439670687, 82.83359389151298, 88.15286128751694, 94.9968324169036, 88.93343648602887, 80.68165609913488, 79.85272592113864, 71.57067268125473, 88.56796572285315, 81.0377602423391, 79.69831789693525, 74.7188768079204, 69.76720609972554, 65.58812464437177, 65.74503906311529, 70.09256670551916, 75.57793863358037, 75.79683042341664, 82.45134322874009, 71.95919913630333, 68.38575516977619, 67.87263854857414, 66.33723458936139, 60.28139314343853, 66.7588109354819, 66.28649480881231, 66.81869768327283, 76.48688516309186, 73.37055421644642, 73.35353897463891, 71.05107630452802, 74.15342007913898, 70.82392400310886, 70.78518667528706, 66.60972948997252, 60.28878288884317, 64.33382126592821, 62.68101684508785, 62.135026839471635, 63.51514808593258, 68.17473949924593, 71.18959088479319, 67.94019745242211, 67.49449852974185, 71.23638476094892, 79.38913314573227, 74.63642858689832, 77.44462597754695, 76.64532538383239, 74.14143331589239, 73.72724671517649, 76.65282495560186, 73.69257296285322, 68.82051067967569, 60.955017074461914, 56.33007195688064, 55.75740983409267, 55.46571885385821, 55.38448264521938, 70.60645995601531, 74.24270891374158, 75.05974646537535, 74.0581770866148, 77.47463210936516, 74.38018798828125, 74.66806642470821, 73.34013231338994, 71.63166553743424, 68.37510201238817, 65.3647417406882, 59.62956974583288, 56.181692615632095, 62.83832350084859, 62.653540642030784, 67.42933227169898, 71.63143019522391, 83.19317325468987, 76.76833091243621, 81.29403221991755, 21.71437659571248, 0.48420158244909783, 0.24413795691103707, 1.0990489803014265, 0.20626284572626316, 0.12129767347247371, 0.145306623871288, 1.4785708991750595, 1.8442819075238321, 0.5258691659377468, 0.17406243891004594, 0.05939734401181341, 0.10156822045363727, 17.32219865245204, 52.09911715599799, 84.69897900858234, 83.5863987092049, 52.43232642450641, 73.3650315192438, 65.8015251159668, 53.07560689987675, 56.05160720886723, 36.299127609499045, 51.7367450652584, 66.13140429219892, 34.871561373433764, 0.15367496999040728, 0.1558102255747203, 0.07282102390402749, 0.10654799880519991, 0.03961302377584, 0.05987406137489504, 0.027806498035187685, 0.041360703987940665, 0.0497072778882519, 0.052922939611298424, 0.018729064763794025, 0.07961692093240638, 0.01879574697194321, 0.040022149201362364, 0.025334397421008157, 0.04808763778137584, 0.062151116003552755, 0.040335406384040276, 0.1390030072821725, 0.01811645872470352, 0.04454543491104438, 0.09245872257217284, 0.19282946333048806, 0.0853806677004022, 0.44065003553705834, 4.659096214079089, 85.62446225074031, 76.00887375493204, 79.45603309139129, 49.224761147652906, 35.123381460866625, 36.151975970114435, 67.19475100117346, 109.4758539815103, 84.67861406264767, 14.114530413381516, 0.15217086360339196, 0.37428340964740325, 1.0980122488352562, 2.955211747077204, 1.043046482147709, 1.0371286061502274, 1.0274946521366797, 0.32200440524085877, 0.26643263236168896, 0.2335499782836245, 1.7296696382184185, 6.122070666282408, 6.090378895882638, 97.6790746565788, 101.87343766612392, 104.42770865655716, 100.17458854183074, 91.56187949642059, 86.73818788220807, 86.86553939696282, 79.09142524965348, 78.10889505570935, 80.3670035639117, 93.86089048077984, 93.35664626090758, 96.86534758537047, 94.63356602576472, 93.68342676470357, 84.81024096089025, 73.1764518060992, 68.15428826116747, 69.62840910880797, 68.49783297507994, 71.23871464883128, 75.2491420315158, 86.46239819065218, 85.9126466320407, 92.97106942822857, 97.40078249285298, 86.80832770562942, 82.37966583621117, 85.82370296601327, 75.94135407478579, 94.30469097629671, 84.48064419531053, 83.77362912701022, 78.56389784043836, 74.07288597476098, 70.3053003741849, 73.20228453605407, 74.85466141854563, 80.44512148826354, 81.95608123656243, 85.5289525370444, 75.81548521595617, 71.15568591702369, 69.50609391735446, 69.5049564300045, 63.02619326499201, 72.20361771122103, 72.64810854388823, 69.15545755817045, 77.51990410589403, 75.87680755123016, 76.55404398518225, 73.68659527071061, 76.78344772708031, 75.13067076283117, 73.68956842730123, 71.085538248862, 64.90987623891523, 68.74811941577543, 66.36236913742559, 66.87228510456701, 68.93996254090341, 71.20328780143493, 72.04831538661834, 73.46698176476264, 70.43277740478516, 73.82127377294725, 81.92029353111022, 75.09864068800404, 77.4208721037834, 79.0329505551246, 72.47447306110014, 73.72232806298041, 78.54248954403785, 77.7313433924029, 71.08417326404204, 63.70927795287102, 59.04734880693498, 59.41093291005781, 57.41796093602335, 59.124121358317716, 75.07806393408006, 78.40553606710127, 79.67257930386452, 79.95608821991952, 79.81190973712553, 75.93616085667765, 76.30008620600547, 73.97070038703181, 74.18406163492511, 70.13381435025123, 68.58876136041457, 64.42318462556409, 60.947760689643125, 66.12721520085489, 66.47401548201039, 73.12954810357863, 76.3143087202503, 89.04754607908188, 81.8274353396508, 88.6306687324278, 30.209773432823923, 0.4321615668314119, 0.3648181481947822, 1.0541846651223399, 0.6230162853194822, 0.13953275708181245, 0.3703625716509358, 1.914589289695986, 2.2304391284142775, 1.9171429978262995, 1.2374661141826262, 0.4321633441553962, 0.09180502740726357, 18.980819948257942, 58.01299233590403, 90.90001875354399, 94.22259576859014, 62.34025701399773, 69.67139828589656, 53.33824488424486, 55.75541334767496, 60.300400949293575, 38.25650799658991, 61.27298401248071, 75.12517159984958, 43.42506616346298, 0.12501762789343634, 0.10417767680220066, 0.043450139853502476, 0.07193376385276357, 0.042362402253333604, 0.06912462668673647, 0.033782447327769576, 0.006882373512076635, 0.029457005739752806, 0.03275783154212179, 0.05433333429297613, 0.03748567421890555, 0.1284213029148598, 0.19129359493813208, 0.07408966550663595, 0.11532158245362582, 0.23688230753665973, 0.1100287652544437, 0.2794245336084597, 0.153608734028474, 0.11288690140410779, 0.14833663950764364, 0.21150849489194734, 0.1998436417911322, 0.7363558680780473, 5.473482733772648, 100.6027074013987, 88.75211315770304, 94.77104510030439, 72.28584627951346, 59.90944654710832, 64.8053333067125, 85.98527323815131, 118.09438382425617, 98.38748608866047, 18.97965500431676, 0.3676628778057714, 0.2239913307130337, 1.421963865718534, 5.333317816257478, 2.131250721793021, 1.2343055418422146, 1.225531690063015, 1.3557612439317088, 0.4375602190773334, 0.47522199009695365, 1.803389605014555, 9.93654820226854, 7.352480926821309, 103.34904116968956, 107.34837608952677, 109.48046668883293, 106.03520577953708, 94.35137502608761, 91.09453693512948, 90.6029619709138, 82.56640988011515, 82.69125892269997, 83.49346991508239, 101.07441163832142, 99.66976381117298, 100.62299389992991, 98.94729460439375, 99.73089002793836, 89.65696473275462, 76.10571707448652, 71.67437230387043, 72.02042733469318, 72.80167718087473, 75.22908303045458, 79.67254792490314, 92.46050234763854, 87.0358173308834, 98.28599083808162, 99.93861090752387, 89.69579619746055, 87.5502283342423, 88.05593952055901, 83.70364619839577, 92.12847371255198, 89.35422051337459, 89.04536524126607, 82.61056792351508, 78.76398578766855, 72.20381382972964, 75.37478339287543, 77.58572932212584, 84.35704246644052, 84.8155047816615, 91.93965081245669, 80.06897403347878, 75.54240980455953, 73.9533870450912, 72.88523935502576, 67.7941676109068, 72.92257247432586, 71.67226206871771, 71.67317990333804, 81.22749313231438, 78.85998972000615, 77.56108114796301, 76.2703860190607, 80.37968066430862, 74.7260312111147, 74.04925761684295, 72.97841133609896, 67.17697481955251, 73.85436288772091, 70.28721824769052, 71.45198960458079, 73.67008209228516, 77.5811009253225, 77.8483476946431, 78.43921353740078, 75.16657613938855, 78.565278514739, 80.13435209951093, 80.83408724877143, 82.34888307509884, 81.22530444975823, 77.46936044385357, 78.87443973172095, 84.39377938547443, 83.80937760876071, 75.96888126865511, 68.1410384947254, 62.92108943385463, 62.1527284960593, 61.13677186350669, 62.41732766551357, 76.76842504932036, 81.23889154003513, 83.38707954652848, 81.24418673976776, 81.92674975241385, 77.5122868630194, 78.47253799438477, 79.17206133565595, 77.1231092945222, 74.17371442241054, 72.5977139319143, 67.05318481691423, 63.874178317285356, 69.40077827822778, 70.64194171659409, 77.0305335137152, 79.22711572339459, 95.16864791993173, 88.38865849279588, 92.89258280108052, 30.37493855722489, 0.8101729748229828, 1.065216944102318, 3.603467013566725, 1.1360398728039958, 0.5384582581539308, 0.6341441107853767, 4.44718232077937, 4.588730854372825, 3.030787975557389, 1.1519426323713795, 0.26895581954909914, 0.3784352078312828, 29.146536550214215, 69.78757889040055, 97.27296029367756, 101.60862276631018, 78.49366388013287, 102.40728793605682, 89.53342576180735, 68.35236011012908, 68.51495019851193, 50.372395669260335, 71.0487699508667, 87.44839575982864, 50.77924743775399, 0.2700184141435931, 0.3721370151446712, 0.14337265022820042, 0.28674848738216585, 0.13269154595271235, 0.2786236346488999, 0.09370022167962405, 0.1887640492209504, 0.17298536525378305, 0.14228616901222738, 0.18672176606712804, 0.14497578114030824], [0.013243452919977567, 0.03539838722997135, 0.0698197978518663, 0.03126689229130505, 0.09868136366769191, 0.10604495483060038, 0.00957994002683629, 0.09793309494853021, 0.06900527018813357, 0.07491141737949464, 0.19143841619933807, 0.06338773896136592, 0.40274360667793985, 6.204584096708606, 72.23469857246646, 70.86479510030439, 61.80337475192163, 47.57219206902289, 47.62865851002355, 44.435088249944876, 71.67241111878427, 99.1475865148729, 44.848933604455766, 1.1809035751127428, 0.019968930188746705, 0.2750795586935936, 1.4091109941082618, 1.1022399510106733, 0.0878965387481355, 1.666234493736298, 0.9291773181288474, 0.5933930748893369, 0.3606003132318297, 0.9062332912318168, 2.6153143471287144, 1.052454409580077, 36.92740109659011, 122.03590300775345, 92.35055046696817, 101.14820711074337, 85.29108432031448, 87.40110766503119, 81.5685510635376, 78.86480639057775, 71.94500800101989, 72.32567402624315, 73.55703938391902, 89.12996292114259, 87.74191456456339, 92.89908609082623, 92.52408396813178, 90.53979612165882, 85.92077378303775, 75.84530307400611, 63.04258484994212, 66.42811590625395, 60.55956371368901, 67.86058902740479, 73.15819709531723, 80.20394279110818, 81.42300759592365, 80.79734248499717, 82.00512655319707, 73.1318623019803, 74.5231113126201, 85.22938543750395, 78.10763205251386, 75.08405731570336, 79.80633997148084, 74.732252090208, 77.36695520339474, 73.77220492209159, 72.46559281503, 73.61373332238966, 76.44548062355288, 77.25400663191273, 76.89341529723137, 72.50160801795222, 66.71520986864644, 70.64092190034928, 67.34387167038457, 70.20428365276706, 67.79492070597988, 78.0184373547954, 70.32518679095854, 69.30635113869944, 74.41490096430626, 73.7002137399489, 71.72150350386097, 73.0534698117164, 75.73552377762334, 73.05214405059814, 73.93706214043402, 67.67630823196905, 65.16495973833146, 64.9025570961737, 65.61939377938548, 62.93196616634246, 62.85627226675711, 63.03720728043587, 66.01968734495102, 64.72876079620855, 73.75307160039102, 63.87802224005423, 65.65568354821974, 68.40558667336741, 65.09607115099507, 62.78674825545281, 66.8177249354701, 70.67981612297797, 73.97035521845665, 66.03069351565453, 64.21478125356859, 55.884016098514685, 57.6951156123992, 55.357465359472464, 54.88960504531861, 60.287798373929924, 74.63444386759113, 75.08758744885846, 72.97556369535386, 77.36878302789505, 74.70298336398217, 73.04611929001348, 69.62898961959347, 62.08161592483521, 75.81915655443746, 73.0982554343439, 70.86714852240779, 65.75627273128879, 62.24870889417587, 59.16224679639263, 61.10413382130285, 66.42427982822542, 72.17820859724476, 78.70710357542961, 79.70795123807846, 77.90227243977209, 69.70547583795363, 10.767626858526661, 0.45368906651293084, 0.33305068830809287, 0.37914564712874355, 0.18729519820021046, 0.1391562095452701, 0.5866344633602327, 2.2868423211959104, 0.7913346276167901, 1.2109689102057488, 0.23353202118267938, 0.3176424844611076, 3.218860722357227, 26.2023780422826, 72.98067062131821, 80.28981916366085, 81.06952359599453, 101.0011496082429, 72.6383653763802, 61.73313294687579, 37.778096506672526, 52.842037600855676, 58.25230398485738, 67.80499335258239, 39.8323868936108, 0.10390020741690552, 0.009664671266481522, 0.07080097262176775, 0.05376715701253665, 0.11613435577601196, 0.132817015832951, 0.02085003855397865, 0.04808862603479817, 0.10569799360969376, 0.014643691190999123, 0.13054280722093198, 0.06829362047175247, 0.042142741862804665, 0.01670459123899139, 0.07230024499398086, 0.06541589545386453, 0.0760080109560682, 0.05549736275908448, 0.07145187156575342, 0.07403531156840824, 0.12137491045699966, 0.01968750587454246, 0.18408640828584472, 0.05161488278498573, 0.594016976894871, 6.759460722246478, 87.27898859208631, 77.35141477277203, 72.86989504291166, 64.08021257769677, 60.930874886051306, 38.54272334806381, 83.72027704792639, 110.21774676538284, 55.64539478671167, 1.7322693116241887, 0.06029316509563116, 1.2039155080433817, 1.7408054922857594, 1.9300540921188172, 0.09881214253724584, 2.247244768565701, 1.1319308223262912, 2.2944171534430597, 3.651110818309169, 1.9572622256894268, 2.8301849720939516, 0.34973488820175974, 46.070626397286695, 124.03179322519611, 96.74738622480824, 104.33781577694802, 88.6369445247035, 92.79742610070014, 83.52391535235991, 81.12866509345271, 74.39798770412322, 77.15723391502135, 77.37646302869244, 92.15750709656747, 91.30578794787007, 96.34968142355643, 93.59445956445511, 93.92225203975555, 87.94559540287142, 80.12321256822156, 66.20871420829528, 68.21172744997087, 63.98505587731639, 70.68723724734399, 75.14258692341467, 84.42653902115362, 83.99442718875024, 82.24727799815517, 81.25596169502505, 76.94060141040434, 79.63514420293993, 87.01888838121968, 82.9983255940099, 82.06965738727202, 83.02657450399091, 80.91687279362833, 83.02299730239376, 78.42448111503356, 77.48126875969672, 78.82677508938697, 80.69438811271422, 81.55966297272714, 80.56723271646808, 75.40613097529258, 70.42906684260215, 73.471633695787, 73.19848768172726, 74.66648963189895, 71.80615609691989, 81.69736169999646, 69.42512835225752, 72.40005000945061, 78.28956727058657, 75.22732580861738, 76.79805463360202, 76.83270485170426, 78.82165247394194, 75.39696831857005, 75.32682849514869, 69.9351776799848, 66.84860967820691, 68.78676260671308, 70.04885581231886, 65.99563537105438, 67.26305515535417, 68.6626039012786, 69.59585343637775, 69.17749343379852, 74.94739409415953, 68.68871904188588, 69.8840456624185, 72.30687802837741, 64.87440232307681, 63.11613321304322, 69.95054552631994, 74.36331395179995, 76.13507209285613, 71.22248388105824, 68.21524189364526, 61.04556106751966, 59.93649913418678, 57.23246420583418, 57.744007956597116, 61.41505618249217, 77.21565369636782, 80.41295805285054, 78.23226144236904, 80.7760440149615, 76.7253888037897, 76.1581434742097, 71.83595042074882, 67.3921952709075, 78.57592382738667, 76.77110010577788, 73.43219034133419, 68.57750415802002, 64.61510619809552, 63.1808287866654, 66.25211915662213, 69.88676778731808, 78.10283107142295, 83.58398252917875, 84.8558424365136, 85.16160688092633, 81.42421568593672, 16.913371970576627, 0.1560107414280215, 0.6674965146568514, 0.5729279246541762, 0.4508821816454011, 0.4558498941121563, 1.2185946106910706, 2.8647819930507294, 0.6385124667036919, 1.9138234469198414, 1.164311091265371, 0.5207756618338247, 2.3421237161082606, 34.38086502013668, 78.06136377396123, 90.43632399651312, 89.50952283797726, 106.86509301585536, 68.00989012564382, 67.90335070702338, 41.85839306923651, 51.34360982525734, 66.72093652909803, 75.68155980879261, 46.72787051047049, 0.09105680465337732, 0.09709608260421984, 0.060416677621223276, 0.0705890037539986, 0.08359819560522035, 0.17673317463167254, 0.04068248251813554, 0.024786299815581694, 0.07569203033081948, 0.042933199043956496, 0.060853914643127116, 0.12554851150320423, 0.16343286170834498, 0.18787135760630333, 0.17262168799436864, 0.1828263315462297, 0.29562343212385334, 0.20911839249874317, 0.17766795511687958, 0.20346400478193838, 0.21982450188407976, 0.18375599456410255, 0.40642986855199265, 0.23023580531439475, 0.8297109748086622, 8.468168723967768, 96.4238142198132, 90.96198435752623, 83.79797920103996, 69.74669994846468, 70.03014610659692, 67.63083227219121, 104.63928914839222, 115.85835041538363, 71.27775007678618, 2.229406564466415, 0.17884662735366053, 0.8647903860096009, 4.930517365855556, 5.4258411353634255, 1.1760697441716348, 6.091298691688046, 4.646613271005692, 3.777425846745891, 2.6338799057468294, 2.67263243275304, 7.6905377545664395, 0.9415611600683582, 45.88343912555326, 130.69282500974595, 103.53295326232912, 109.15654167052239, 92.64996851644209, 94.35010417815178, 86.91034070907101, 84.75724189512192, 77.27719568437146, 79.02290928748347, 79.74138552142729, 97.44420313066053, 94.7621177857922, 99.97159804067304, 95.71823473899596, 98.0185793292138, 93.62008833116101, 84.06353935118645, 70.84358292241251, 73.11146597708426, 68.1136054377402, 73.76887875218546, 78.84868544916954, 86.68349435252529, 88.66632307729414, 86.73884684039702, 88.32989354287425, 83.2458193071427, 84.67704511457875, 91.89641060367708, 84.68231678009033, 80.65892204161614, 85.11063960290726, 83.53388601733793, 84.85872930096042, 84.37701517535795, 79.3979977023217, 80.68960282110399, 85.17504492113667, 85.27977220473751, 83.4211649433259, 81.29673865533645, 73.53416412107407, 78.0016339209772, 76.71286859819966, 81.69443561184792, 73.81873992181593, 83.67610331504576, 73.02849215845909, 76.51353374604257, 79.96656094827961, 76.74694615025675, 78.54474098451676, 80.4074667346093, 81.12467996535763, 77.01942536138719, 80.6479315603933, 71.90314846654093, 67.88140896827944, 72.91504152359502, 72.20048765982352, 71.64142439442297, 68.10441924679664, 72.06471873867896, 73.85171136548443, 73.68160601585143, 79.88507763031991, 73.7558094147713, 74.83682247900194, 74.63293767744496, 67.37826301205543, 66.84752710403936, 68.53220078252977, 75.30828352897399, 80.38548577216365, 73.43373575518208, 73.2025041887837, 63.132152172826956, 63.55392071508593, 61.258667361351755, 60.319428366999475, 66.03232522164622, 79.3935340450656, 85.42568437514767, 80.56337310421853, 83.34772248421946, 80.57279463737243, 77.51379305316557, 74.74063811763641, 66.25974424423711, 80.50251360862487, 80.87780598671206, 78.06603923920663, 73.41638318953976, 68.41762834979643, 67.06968230585899, 69.67407334235408, 72.73091762296616, 82.34786325885405, 87.77312094165434, 92.58495915320613, 87.20622862538984, 85.79268486269059, 16.014467689298815, 0.6853677524674324, 2.1363895170150267, 1.162685146254878, 0.6837744121589969, 0.47831695466752977, 1.2123702995238768, 5.449944100072307, 6.739495367773118, 2.422321967540249, 0.5935149747998484, 0.4960863334276984, 4.77653491881586, 48.771660712457475, 85.35238312136742, 101.492779485641, 97.55027970960064, 113.87865958675262, 99.7232178718813, 75.7689109925301, 49.107933352070475, 76.90468818910661, 73.91967035108998, 88.3103915183775, 55.98544859117078, 0.19767489284276965, 0.1952899692039336, 0.24371049517104704, 0.17837911453698913, 0.23991695034407803, 0.355517074706093, 0.11362177124547382, 0.1018846300881236, 0.1842148199437126, 0.12795106282517796, 0.19410519890727537, 0.26995596265600574], [0.06670435575107414, 0.04377016159255178, 0.06676060958735405, 0.05104707756770715, 0.06825100300052474, 0.04981030139230913, 0.04138077166111719, 0.06504010634436723, 0.031769624085075436, 0.010534804464588243, 0.057195155325555996, 0.057616266196653734, 0.11131537927975578, 1.3438242457566725, 55.54174615490822, 68.503661617156, 58.56425400703185, 22.565942771973152, 26.812202661268174, 52.30244105862033, 88.84743459763067, 79.00155590426537, 14.379725783101975, 0.23471188851662222, 0.03461346886451206, 2.5809786540846673, 1.5486484549699293, 2.402540474168716, 0.8706211118448166, 2.587696938745437, 0.5149848951447396, 7.548171406792057, 16.675774397388583, 0.4090494296002773, 1.1497606913889609, 18.712267029669977, 113.93772263680737, 99.65267796670237, 96.93821737843176, 89.53897199323102, 88.90697617684641, 83.25132631486463, 86.04725453161424, 84.91849837764617, 79.15168854498094, 69.73582713834702, 72.69645567863219, 81.15255232780211, 89.73585144166024, 89.69014013967207, 94.77657564224737, 90.97976053914716, 85.48764213438957, 79.2641350530809, 70.22704124450684, 63.23580472700058, 62.45496280731694, 63.59290907459875, 69.13568096776163, 74.33422565460205, 74.28830254462459, 72.75947247782062, 69.70682513329291, 66.94997941294025, 69.40261394746842, 73.1826413062311, 78.64036836931783, 74.82261565423782, 70.39133364154448, 73.98320490314116, 77.50310067207583, 79.6605533169162, 76.29830544994724, 80.28366888723066, 80.47391168532833, 78.12390204398864, 70.43579762981784, 69.3913096766318, 68.28345191094184, 68.35418793462938, 71.30886231699299, 67.03089006485479, 80.11623074931484, 72.6724115494759, 66.76948762709095, 70.95438987978044, 73.71398125925373, 73.1694229187504, 72.17350959777832, 72.85928110922538, 75.1863762640184, 72.21070935649257, 72.97653644315659, 69.77192863341301, 71.0242316030687, 65.84795813406667, 65.05304275020477, 69.47636235144832, 70.27974221014208, 62.013919738031205, 61.302931308746345, 62.88523897047966, 64.37959140346896, 69.44369685265326, 73.97719583203717, 71.6977104063957, 66.68711000873198, 56.87399095104587, 59.05561716325822, 80.28133115460797, 70.15061778406944, 68.885527887652, 62.05368080446797, 57.71011083356796, 53.23330579265472, 56.87082559831681, 53.74900333343014, 55.75195773955315, 65.85067241422593, 73.42742073920466, 74.0602324085851, 75.0471164334205, 74.92786853544175, 74.50059690783101, 75.9193495781191, 77.4103444622409, 76.63548023469987, 76.66881253642421, 73.04574274247693, 70.4284078844132, 64.21227878139865, 62.432150302394746, 61.24236206854544, 70.62171797598563, 66.99117214448991, 74.45941202102169, 78.90563041933122, 79.83755419331213, 86.1583282101539, 59.22429084777833, 4.950267970561981, 0.22531395087078696, 0.25056195655657404, 0.05703154192756742, 0.050597824456710974, 0.09403330904822196, 2.010310198510847, 0.4153105436313537, 3.313034869009449, 1.2482115698437537, 0.13166204635654727, 0.08748147231076034, 8.631830600000198, 56.27330349337671, 72.70035451458347, 94.49713030169087, 95.2595135473436, 98.67169318660613, 17.964020006118282, 24.879625381961947, 52.30991709616877, 52.89670367394724, 67.7388229677754, 36.57021830158849, 0.06774196821835733, 0.11187937320961107, 0.09538406761543405, 0.03383814575030439, 0.04482878019071875, 0.09444151899867481, 0.10243682626394496, 0.03479246913845982, 0.038022904867126096, 0.028428762527783553, 0.1336569852766491, 0.05024757288816956, 0.01719054379200022, 0.11751402650148639, 0.04433198749358135, 0.1330120618184728, 0.032741100181855505, 0.1176787737096029, 0.036670966524510615, 0.01978948749902268, 0.027981711919569684, 0.018754064127983108, 0.05360137558572235, 0.027732290928402258, 0.0637266371068695, 2.511527696924825, 67.24272943312123, 79.11391612022155, 67.9747849126016, 33.07930100348688, 31.27545395205098, 44.50490251664193, 102.1682430082752, 91.19285506586876, 18.398630388321415, 0.19417091392942015, 0.28170952873845256, 4.71891628157708, 1.6127035790874114, 1.9384300684736622, 0.15202726808286485, 1.632639638358547, 1.327458033638616, 9.97962171031583, 16.209865462395452, 0.638904090850584, 0.33253406925547513, 24.326724160102106, 117.97465739711639, 103.07955864937075, 103.62069668308382, 92.6178913731729, 92.72422682854437, 86.37454494353264, 89.51794808910739, 88.93146745620236, 82.14881081734934, 73.39368051098239, 74.8485189868558, 86.10232460883357, 92.71681354891871, 92.29955180998772, 96.7457623635569, 93.43614485956009, 88.56242733616983, 83.21495025388657, 74.25210691267445, 65.21758617893343, 65.69421691279258, 65.9188824315225, 72.8065566093691, 78.19515582053893, 77.05183982849121, 75.45858090923679, 73.25434223298105, 68.4276774621779, 71.95916775734194, 78.4871841246082, 84.81443789697464, 83.32997768155991, 72.99598355447093, 77.04873331131475, 79.08063088693928, 82.38839703221475, 78.8257082047001, 82.80242673812374, 83.11667134684902, 80.25735762811478, 73.38148978448683, 71.79413010997158, 72.0453186958067, 71.77997819838986, 73.73442465259184, 73.66530464541528, 81.21501215042608, 74.65977453416394, 68.06672526944068, 76.0747774185673, 77.60420368563744, 76.00867763642343, 74.36934655712497, 76.80251829085812, 76.12280291895713, 74.12200189405873, 75.72655723940942, 71.63370516992384, 71.91332309476792, 71.2945927343061, 68.34104014981177, 70.2223579345211, 73.53130079084828, 66.85705846355808, 67.01294914368661, 68.27953738550987, 67.48857575078165, 72.70956423974806, 76.55089824430405, 73.87553584191107, 71.35936675533172, 59.876482948180175, 64.37899520320278, 83.78673768812611, 73.1779109278033, 71.4658041923277, 65.0262882632594, 62.29565182039815, 57.36463239116054, 60.98201867072814, 56.95098707752844, 57.56383388273178, 66.49578463646674, 75.27470019555862, 75.859800154163, 76.34199280892649, 76.60970241792741, 76.96081730627245, 79.9152720359064, 77.46874070936634, 81.01943492889404, 79.81551831768405, 75.11494205844018, 73.43854458101335, 67.22554160702613, 64.57626688864924, 65.75476261877245, 72.72835239287346, 71.4421993686307, 79.71584304686516, 82.94788391359391, 84.65763722696613, 88.11391215170585, 69.3343411722491, 8.281819858858663, 0.2507948319637968, 0.1134271695909481, 0.31687627396275925, 0.3946073545563606, 1.307971576048482, 2.1887279085574614, 1.401221269080716, 2.607230097055435, 2.776705415979509, 0.594652523436854, 0.2157037149393751, 9.403231374679073, 63.119781017303474, 85.08840760877057, 102.25587660266508, 107.7881443885065, 108.81445607831402, 28.603555002520164, 26.220771997205674, 57.34274164322884, 60.45693882050053, 74.92268316207394, 44.45572383942143, 0.05204132179759684, 0.053509663369867115, 0.023166171327653914, 0.03468910855571589, 0.09797029617813327, 0.05052079814636419, 0.04340704357732208, 0.02510315952672353, 0.05257474115839409, 0.02103700805755873, 0.056902559534195936, 0.05948857742271597, 0.09344823237869049, 0.21602619199022172, 0.1907264294042703, 0.2049547046302788, 0.20063902491763716, 0.23533226651770456, 0.1601660789381112, 0.179735703033305, 0.14189074506923077, 0.126258100443069, 0.11749551781723577, 0.1628206195610185, 0.23675064766599288, 3.033220825656768, 80.81215335476784, 91.73921769665134, 78.189421315347, 36.90586336197392, 35.90453324779388, 75.32489084428357, 111.81181369289276, 102.90421301318754, 26.091476948030536, 0.5274548453669394, 0.2177734087191282, 8.48794629496913, 5.170581129289443, 7.014933516902309, 2.343559548739464, 9.72140423713192, 5.57078448034102, 12.76767380775944, 22.70350617747153, 3.280313966735717, 1.3992923209744117, 23.69766227660641, 120.92124385218467, 108.25440437563005, 108.20651223582607, 96.6280520346857, 98.4735664244621, 89.78107636974704, 94.7471421764743, 90.85109895275485, 85.77504204165551, 75.63618583063926, 78.21326932599469, 90.11255587300947, 98.60070613122757, 95.92732844814178, 101.49089674795829, 95.99054921057918, 92.1286149178782, 86.87612195168772, 76.24067014263522, 68.21520266994354, 69.93745265468475, 70.51317030383696, 76.61993195933681, 82.7837876350649, 80.69592568182176, 79.49215027593797, 77.02941956058626, 72.18759090669694, 76.88117750229375, 81.6924822715021, 87.74025147961032, 80.47008345204016, 79.25197570554673, 86.67034656770768, 84.11902519964403, 86.61416253735943, 84.31002893755513, 84.83632472253616, 85.31666601857832, 83.90524033577212, 77.66937778842065, 76.74027027622347, 77.2924223253804, 77.45468293466877, 80.7960481028403, 77.14687101302609, 84.93069694888207, 77.66808340626379, 69.23095533924719, 77.1586851919851, 80.78571657980643, 80.61414426372897, 77.65988565260365, 79.31327450659968, 80.25197613623835, 77.17144858452582, 79.40087672202819, 74.77121691549979, 74.72148126171481, 72.9794389970841, 72.06668776850547, 73.86546319530856, 79.43507194519043, 71.27725585814446, 71.33943327011602, 73.48108660790228, 74.0815544128418, 75.79414752221878, 80.9858045270366, 77.14064228919246, 71.62287942824825, 62.546424634995006, 66.55141953499087, 81.62348778017106, 75.79297081116708, 76.37725491677561, 70.64424022551506, 65.62614417845204, 59.76526414194415, 64.89117045556345, 60.3567732534101, 61.36596771978564, 71.35737419128418, 79.74357420398344, 80.09344962335403, 79.51268780616023, 80.3257166954779, 82.43075863007577, 81.80723513326338, 79.97962244095342, 84.6609006389495, 82.49512472460347, 81.54493839510026, 77.18414137440344, 69.10958936137538, 68.59216597772414, 68.496946519421, 77.98352826026179, 76.46086415936871, 83.90595420714348, 88.91617021253033, 90.47219799410912, 94.42305241861652, 72.3407986856276, 7.128457205910837, 1.0838761493082971, 1.1114938028397099, 0.24708051594995686, 0.21650515016048186, 1.6858780912814604, 5.283092356497242, 5.041786672607546, 7.644129251280139, 3.9414919720542048, 0.30169942866890664, 0.3052634229102443, 16.335069479480868, 73.56650014077464, 92.99685508974137, 105.60594158787882, 106.07936382293703, 112.79566964795514, 28.848336396678803, 35.47446889262046, 70.56631841967183, 70.73585110325968, 89.276290862791, 52.77480425373201, 0.15817415840443105, 0.18259049903961921, 0.3474278910265815, 0.10791778699645113, 0.19815722179989662, 0.1475714862106308, 0.21814091641816402, 0.14402741025532448, 0.10378919361579804, 0.12080021427884219, 0.2570507059534711, 0.2186417847030586], [0.040620931183859225, 0.033850564035556974, 0.06356295476096772, 0.05927249466279342, 0.016611063394755606, 0.016142407191857215, 0.12234173640007935, 0.13109471228334213, 0.07445028607523249, 0.036316834720632726, 0.0645036302927521, 0.051749913442519405, 0.046591383795584404, 0.5140243741052767, 50.03063955614644, 65.87645023099839, 52.87774293653427, 59.53695081895398, 62.74625762816399, 68.80308751137026, 92.9592630940099, 52.511679895462535, 3.475091269900722, 0.08261536608540243, 0.2974776713357818, 2.360172502456173, 1.1726799583242786, 0.8265793299482715, 0.4521691480711584, 1.4402324273701639, 0.5265753151428315, 6.72762970770559, 2.218561701236233, 0.11928264006611802, 19.222004528968565, 110.7959355077436, 97.02392116669687, 95.6481106050553, 92.50855922698976, 90.55303804336056, 88.08726356875512, 90.61115972457394, 91.16426098731257, 89.31720118368827, 87.59182114754954, 71.18186381555373, 68.34995177484328, 75.27598673297514, 85.55428320361723, 89.5631730171942, 90.3471528330157, 91.292765678898, 86.73387327501851, 83.5362708184027, 73.3233759480138, 63.99649350873886, 64.12047962988576, 62.78568529313611, 63.107998217305834, 63.107033314243445, 66.54141749105146, 64.73381673136066, 63.65068166486679, 60.640529278785955, 70.4390061286188, 74.28407422957882, 86.68480442416283, 66.10714051031297, 63.29500113764117, 64.10223276384416, 69.12014053713891, 81.02816612489762, 76.42528041716545, 77.77954147708031, 78.41711490384995, 71.60733899762555, 68.38540215646067, 73.06010646204795, 71.46828313027659, 70.29559643037858, 71.0868404757592, 74.853986770876, 75.71669640079622, 71.21437241954189, 70.9419402768535, 73.08398585165702, 72.41945005232289, 73.068939639676, 69.52175201908236, 73.13769094405636, 72.02811518023091, 72.0621770428073, 74.22894139443675, 72.64773984109202, 69.60642030162197, 69.78939887016051, 69.21013539837253, 65.96604501047443, 63.30425793124784, 64.63045443257978, 62.92318397952665, 63.687622547149665, 62.505922240595666, 61.45174211071384, 65.03747878536102, 68.11104805238786, 70.4473372428648, 74.74719632056453, 61.92304234350882, 70.64246731419718, 77.61716319668677, 63.524565696716316, 66.16829810603973, 57.079731033694365, 57.402832354268725, 56.06823805839785, 57.08268065606394, 54.49486947828724, 57.18938481423163, 63.34132432937623, 65.79742231676656, 68.78780595717892, 70.81476134638633, 72.11391310538016, 75.23266023205173, 75.60741132305515, 75.89595656241141, 76.62521146958875, 75.04763418628325, 73.33148740953015, 68.504822638727, 62.72108385639807, 65.67387157870878, 60.47039647256175, 60.869921253573516, 67.08593660785307, 69.49002788912865, 78.90178649656235, 77.53834709044426, 83.41452829299435, 43.76021308283652, 0.7287386252034096, 0.4519279223055609, 1.2529930616578748, 0.695334862797491, 1.5870775090109919, 1.4085530369512498, 0.3988058534601043, 2.034295001818288, 3.0246325510163463, 0.30115896896008526, 0.12142129708081485, 1.3883122585473524, 27.567866886815718, 72.51297504671159, 77.65492777670585, 110.10705747912007, 56.5508347172891, 24.09902664922899, 46.53096360545005, 50.357439671793294, 59.07918668562367, 68.40301359853437, 45.14873996857674, 0.22947348654270175, 0.19430038278862355, 0.057013818483439185, 0.06760516789771857, 0.030759625257022923, 0.011622066132634157, 0.10547806508839132, 0.014032637437565193, 0.06389695377419553, 0.04328602083748387, 0.11419443729063196, 0.07283717303747132, 0.054317721421079296, 0.07539203796055048, 0.022825074509807655, 0.06429121709398686, 0.03618841157144597, 0.04922337462044051, 0.018119611176511934, 0.09966780912251243, 0.04088744168139754, 0.03755912672908556, 0.08787543302582157, 0.0426606594344541, 0.11862948882363497, 1.0457548787516933, 59.37068939208985, 75.9558746891637, 52.419759150474306, 52.3586093994879, 42.190457005654615, 56.04062457238474, 111.73431550302814, 61.35330238649922, 4.927689827257588, 0.08841786158060835, 1.112833169679488, 3.9162404883292417, 2.3218860020560603, 1.944008291729035, 0.1457718231024281, 0.7076492665275451, 0.5326961125096967, 7.861102511805873, 0.9379553374263548, 0.22554630533822123, 26.745234074131137, 114.50419133709325, 100.70392024132514, 102.3720807413901, 100.10269149657219, 92.7831643627536, 92.14579489923294, 93.55135271626135, 93.84901354389807, 92.97620773315431, 91.870891663336, 73.24777618531259, 71.19958508399226, 78.17024876994472, 89.96254090339907, 93.39617590750419, 92.43736820836222, 93.04062089612408, 92.59687531378962, 89.22457833443919, 77.65790093329646, 67.97109788463962, 68.38715937829787, 66.72460786757931, 65.63873890907534, 65.06266824660763, 69.1170810884045, 66.48863807801278, 65.98477040567707, 64.97446590854277, 76.4217032155683, 77.918181573191, 92.23014154741841, 75.67276585486628, 69.37595751977736, 68.36364869148501, 70.28491973876953, 81.93326088689989, 79.86529319517075, 79.8721573429723, 79.14097262967017, 75.36472643575361, 75.19081638705346, 76.64739639528337, 73.50273809125348, 74.24900039549797, 74.65855075467017, 79.17774877240582, 77.7231691729638, 72.33736268935665, 73.18875235895958, 75.25851649622764, 73.92135697026407, 74.34227435819565, 71.79373787295434, 73.94866451140373, 74.61747569422569, 77.90879926373883, 75.83717592300908, 75.54348453398674, 72.44872662328905, 70.26694743863999, 72.93162530468356, 70.47318566230037, 67.5498902413153, 68.5562841353878, 68.58517631407707, 66.14616024878718, 65.70856494288292, 64.72647405439808, 68.66977399395358, 71.37884524560744, 73.46196897568242, 78.43981758240731, 64.05999275945848, 73.66732074368385, 80.51259409996771, 67.85316790303877, 71.31040773084088, 59.12003424859817, 59.97374988371327, 58.13456619939497, 59.65692043304444, 58.354979868858095, 58.344444382575254, 65.67542483729702, 68.76643688448014, 71.92516865268831, 72.54877059690415, 74.93864720867526, 78.07115400991133, 76.81948646422356, 80.00709472164031, 78.6087932894307, 80.96398045939785, 74.65454209235408, 72.0689235195037, 67.74685598188832, 71.09182973061839, 64.66086456852575, 65.01170096858856, 70.56158019650367, 72.23654208644744, 84.15562091335174, 82.13978152121268, 87.24663688290505, 53.48460420485466, 1.5599158310121106, 0.38353303267109784, 0.490336291972668, 1.3605226335986969, 3.7254806728132315, 2.3351244916838985, 0.8790534109838548, 0.9061588887726107, 5.517566252139307, 1.8289074421890321, 0.17923587662798746, 0.7741913571953775, 29.67441697274485, 77.60174043716924, 89.92393693616314, 112.6034107515889, 65.48740602308705, 28.84677137098005, 43.70577450721495, 57.344585157209835, 65.5344234743426, 74.50718648972051, 55.47416371683921, 0.2401672772342159, 0.17545956877931473, 0.03879806710286968, 0.04125439779712789, 0.09843248468373092, 0.007920867938082665, 0.14823842703575088, 0.044478348591515136, 0.057900496307880654, 0.0491759805910049, 0.03334847767086279, 0.04390273693828814, 0.17382470650538323, 0.17429520706495932, 0.22859533527685752, 0.09229041305520842, 0.15915550171367585, 0.33448394688387073, 0.17583306728591844, 0.14822993878154986, 0.15805716145663493, 0.21744788263834294, 0.27416273530933166, 0.08818598208768715, 0.23223909459287123, 1.4520370455518847, 73.4160223314839, 86.99856265898674, 69.13848154006466, 76.40444478681012, 83.18476369304042, 100.60399393881522, 113.85843584614416, 78.49220475842877, 7.431258299658376, 0.15416966360663215, 0.7607224896069497, 9.889859249514918, 5.510825168701911, 4.61751958054881, 2.482736764415618, 3.558252871997895, 0.6031125856022681, 12.567108311960775, 4.144583719391977, 0.643939127124125, 29.159892220650953, 116.0852046166697, 103.32431454812328, 105.5288827034735, 101.60101336817588, 97.28103253149219, 96.19954878284086, 97.97239734280495, 97.07280174378427, 94.02863456356911, 95.92662242151077, 75.56483791720483, 75.3454440639865, 82.34023817123906, 93.17494638504522, 97.93543292630105, 98.0370693822061, 97.22544470141011, 94.56729365933327, 94.6976104859383, 80.62754308023761, 70.51074627907046, 71.37572303895028, 69.95489151247087, 70.90196348005726, 68.62877738091254, 72.55434820728918, 71.65483105567195, 70.00339554202172, 69.11911287615376, 78.53524884869977, 81.42766737168836, 94.07326329138972, 76.0498389890117, 70.3433552095967, 70.71510176504813, 70.98502359082623, 85.0110427794918, 82.29329524501678, 83.93887073762956, 85.37521916051065, 78.9460543663271, 78.49604868119764, 81.0154890245007, 76.45617300464262, 78.88783070348924, 79.72892807376, 82.61416081459292, 83.79503742341073, 74.7828898891326, 75.47634140137704, 76.43413712901454, 78.63461032990487, 78.7666843783471, 75.77322559971964, 78.62184693736415, 78.70563660898517, 79.10899746802546, 80.95840284901281, 78.28387198909637, 74.77116200231737, 75.3213450216478, 75.11199243607061, 73.2884354745188, 74.86322787500198, 73.36451376638105, 72.72099402643019, 71.24326459823116, 70.28786151639878, 69.38437492616715, 74.26654907964891, 76.262266712804, 79.34956427543395, 78.76938296902564, 68.66414931512648, 79.03441752156904, 80.81707985170426, 73.39357852935791, 73.4563050731536, 63.61760431720365, 64.06821012496948, 61.8616258713507, 63.99132774722192, 61.04712609321841, 63.61046952586021, 68.85741233825684, 72.16547658366542, 74.29735537498229, 78.23456779603036, 79.21251666161322, 82.53598013231831, 80.31322786884924, 82.10414286582701, 82.83162486168646, 83.45186141229446, 77.61430771120133, 76.88684140482258, 70.22394257207071, 73.42174114719515, 67.96002895601335, 69.0575316644484, 73.54401711494693, 77.79520742354855, 88.36557926670199, 88.48834160835513, 93.29059354720577, 57.37572093163767, 1.5244628753392928, 1.7431030206141935, 2.741449191685646, 2.3989657240529216, 4.79416597274042, 6.071827065560126, 1.2056733427509185, 7.6811461294851, 8.160200397814474, 1.5024434246363179, 0.14440777290972973, 2.223038841639796, 44.19393308701054, 87.27749024668049, 91.91818760287379, 117.06778972379624, 68.99775474302231, 38.12566165001162, 60.01833154309181, 68.65217824136057, 76.44774775351249, 86.08537212494882, 64.08833972869381, 0.4363387072038266, 0.32346530426894465, 0.1574695720187118, 0.1792250594664966, 0.23533661789711446, 0.13986006048658203, 0.25767109927631193, 0.15624680376100927, 0.19722187440962563, 0.11593554829878193, 0.11869650619525103, 0.13970068355481471], [0.0441472607123996, 0.034177086030643795, 0.024122088178691846, 0.08365930643894019, 0.04740894133705766, 0.05518124423800938, 0.05803044397203673, 0.06759535431140853, 0.17481553398313063, 0.04877238632029584, 0.059065995662803614, 0.02916068867630055, 0.04247918852695054, 0.2241664737342827, 41.47373407117782, 70.3459753528718, 65.9035381194084, 63.9713393488238, 54.87643372627997, 69.8754870507025, 85.58774886592742, 29.347658041984808, 0.2763444924306485, 0.03410928724934498, 2.603040760563266, 2.116923038997958, 0.5577946850849737, 0.3098465285954937, 0.05715241144982077, 0.22985633132198166, 0.8719205195384642, 2.8467952291811667, 0.7921018799947155, 14.58590909357994, 94.60745872989779, 83.6328003483434, 84.00919099007884, 94.08655228153353, 97.29378807929255, 90.45642222127607, 94.8315437378422, 90.96103514394453, 93.61406357057633, 97.83396905468356, 93.36518133840254, 73.16743035470286, 66.23498624370944, 70.65644664149131, 79.98926362683697, 84.1005979045745, 89.47822232400218, 84.69363674040764, 83.91884311552971, 86.40389211716192, 79.1434201886577, 64.54288751848283, 61.39484420899422, 64.47164158667287, 60.97273049816009, 59.61288398311984, 59.67226866752871, 61.30885801007671, 61.92200683778333, 67.08767029546922, 70.88557581747733, 76.26401608990085, 78.01558186930995, 64.50784898573353, 76.15043993919127, 73.22388895096319, 77.20398856747535, 79.23426228184854, 75.9245349514869, 73.39269207369897, 72.21188606754427, 71.58726430708363, 73.38379613814816, 71.66437810467136, 70.42677617842152, 68.92720699310303, 72.0907554318828, 72.86084221255395, 72.05162586704378, 72.05345369154408, 71.07280623528266, 70.6661113615959, 72.99417926419166, 71.53422601761358, 72.95836017977807, 71.68355065007364, 75.42454258088144, 76.27944669415875, 61.27594932433098, 67.67979914142241, 75.68838473289244, 67.90867728571739, 66.76812264227098, 63.95448100182318, 64.8538726375949, 59.677454040896514, 60.25366590869043, 61.423701086351954, 61.464101499126805, 64.34704749814927, 61.27491381860549, 60.77586673921155, 67.48360218540316, 68.67637142058342, 73.27133394056752, 61.06764008921962, 75.16663889731132, 67.4794993862029, 65.78723199905889, 60.29723559656451, 59.17397076083768, 56.75073439075101, 56.65865282858572, 58.20927950643725, 57.54863862068423, 58.88659831016295, 60.66240041486679, 62.40182645859257, 63.738448619842536, 65.73256200359714, 71.35058849088608, 74.13170583786504, 77.42972097089215, 75.89594871767106, 75.22710615588774, 73.4642517951227, 72.90198787566155, 70.75221523161858, 68.60496859396659, 65.30420387944868, 66.3956465259675, 67.66909891559233, 62.9402070660745, 73.04831581730997, 79.65303805566604, 77.51686819138067, 83.04093822356194, 14.407640311025805, 0.29608562829033025, 0.9164647325392693, 2.3838192464843875, 1.3356176667636441, 1.8127074405070276, 0.43163915615408655, 0.7442177687921833, 2.6215224785189477, 2.0325852161453617, 0.2785236754965398, 0.1637977034214043, 7.27581722121085, 41.296925390920336, 79.10199995963805, 68.07658610805389, 35.19488234673777, 37.01117507873043, 34.10104313204366, 55.05800808629682, 56.431394623171904, 65.81276662888067, 42.21417557808661, 0.05952889663017085, 0.031832502666680564, 0.06119793791684413, 0.09866141473814365, 0.0426876487120265, 0.10354576151697867, 0.0460946255724036, 0.08601982251650865, 0.010662054541640946, 0.09992450220330108, 0.0028917741128093293, 0.040628852532996286, 0.03469785727981118, 0.0405858481873668, 0.022580562227015055, 0.051192572986286496, 0.05383300610006817, 0.13132922711872286, 0.06743102079077114, 0.07195607233311861, 0.1573839846758112, 0.04543909562691566, 0.02760761011872561, 0.015360939094886906, 0.035784189108638995, 0.21725633001375586, 50.047211570124475, 82.1759771531628, 66.03254487437587, 57.700528483236994, 38.919988678347686, 74.67702511818179, 98.26735957976311, 34.029503022470784, 0.24262033673303746, 0.38916494336820423, 4.117766964820124, 4.557783844009522, 2.20207475366131, 1.6094199423828435, 0.47241559552569545, 0.5943870280058153, 1.1878172428377214, 4.868249249073767, 0.6971188057814875, 20.07551423964962, 106.36665390383814, 87.16928774310698, 94.82178488085347, 97.5838787324967, 101.35200562015658, 95.52610135847523, 100.14006383957403, 94.98442988241874, 97.53335860467728, 100.56316991006175, 96.79551370682256, 78.63872097384545, 70.2126226117534, 73.74575245764949, 81.5134652968376, 88.15091579191147, 90.66393129287228, 86.85514511600618, 87.89518510141681, 90.15405454943257, 80.91549211932768, 68.66257252231722, 64.01739189701696, 67.38244425865912, 64.69354183443131, 62.4554217246271, 62.32816434675648, 63.40230934081539, 68.0966764880765, 71.85342850223665, 74.08487273800758, 79.75611009905415, 81.50098431494929, 70.85481659058603, 78.47924524737944, 76.10585043507238, 81.867843597166, 82.33298963116061, 78.65864661432083, 79.5018228407829, 75.63602109109202, 74.81852854451826, 74.28780048124253, 74.42941373394382, 72.42937364885884, 73.31628430274226, 75.41935720751363, 73.94904105894028, 73.14469629718413, 73.69989210559477, 74.16021362427743, 73.98937871379238, 75.8620672841226, 76.81338325623544, 76.8893752559539, 74.4464054415303, 76.12092018127441, 73.96728008024155, 61.172288925417014, 68.47549115457844, 78.42546955231698, 70.67270878822573, 71.63411309642177, 68.361326648343, 66.62133186094223, 66.42837478268531, 62.083184872904134, 66.15620936116865, 65.3730885444149, 65.52081677221483, 65.31937168490502, 63.9094090461731, 69.4441596923336, 72.37176187576787, 75.47191696782266, 65.38302390806138, 78.50091242021131, 72.13679621296545, 66.76006609393706, 64.27788434490081, 63.132061958312995, 59.25855667360368, 60.820177755048206, 63.128002305184644, 60.76112254973381, 60.420904005727465, 62.97461801959623, 64.44544407629198, 67.21965805176767, 66.84622487714215, 73.2346676241967, 75.74440402369346, 80.1815382126839, 78.52733350569203, 78.24451492678735, 76.85259911321825, 76.9668185326361, 74.56264095921671, 74.67384015360187, 69.9218023976972, 71.59749384849303, 71.46252509086364, 68.26747217485982, 77.15681029904273, 83.38183925997826, 83.96918281432121, 87.65433588335591, 20.807397134842414, 0.2033391937373146, 0.8699424192309381, 0.5598199764086355, 1.171621286099957, 3.008702334857756, 0.8448614973214366, 1.03177665462417, 3.7379226761479534, 3.2749469385993097, 1.0540169837974733, 0.4396753571927548, 6.543843621207822, 49.13720600066647, 85.12492487507483, 78.32449989934122, 38.99083060602988, 29.495099936762166, 38.21584086264334, 59.888344195581254, 62.904129105229536, 74.13824835131246, 52.299903285118845, 0.23522122973395934, 0.06384788967308498, 0.03359673612360512, 0.0461389399283836, 0.011206704751408149, 0.038508623763318026, 0.06119996038896423, 0.05444266270065019, 0.028126667246162414, 0.034673285009639884, 0.051736058742408796, 0.016710967005741213, 0.2089353281283571, 0.15772371402671262, 0.18195080030108654, 0.2913609189131568, 0.18944519331618664, 0.17932336386894027, 0.26043955717355977, 0.17774307769873451, 0.33448140347196215, 0.07939883868300146, 0.09958877949224365, 0.10842114506709961, 0.1410764089274791, 0.39825053164555185, 64.00629943416965, 93.81887405149399, 83.66069624500891, 82.50518952646564, 77.7164383857481, 92.48875910235991, 105.91980964906755, 47.04683765288323, 0.4861227471020914, 0.2527361294074405, 4.868480178617663, 8.37637741719523, 4.5281576918017485, 2.4384581081328855, 0.5317746006673383, 0.3918795606061336, 2.979794466687787, 5.71152598627152, 1.034487502709512, 24.30699856050553, 110.23913937230265, 90.5271033317812, 99.66372336110761, 102.21656660879813, 104.51278486559468, 99.28264940938642, 101.54341728456559, 98.16176152998402, 101.09141119064824, 105.41431027074015, 101.3831727735458, 79.8547577088879, 73.45016264146375, 77.5210572827247, 86.74136500204764, 90.36232456084221, 96.99697448361306, 90.53310455814486, 89.77773451036023, 93.44198919111683, 87.20722490741362, 72.94372973903533, 66.8145791945919, 69.67632478283298, 66.9233072957685, 66.47970291876024, 64.66109206599575, 68.0229280840966, 69.17875643699401, 72.08352258128505, 78.05144802216562, 84.27134652291575, 85.71954050371724, 75.45128530071628, 79.90056314776021, 75.86889220822242, 84.52670851061421, 85.41670214745307, 82.36178767296576, 81.91997189675608, 80.89459373104958, 78.71309695705291, 80.50445125948998, 76.9216485177317, 77.4139295085784, 78.55300149609967, 80.60795476359706, 78.58882058051326, 74.83628119191816, 76.18669048432382, 75.38018057423254, 77.21129202073621, 79.58966039842176, 79.31162711112731, 78.17120582826676, 77.8470140887845, 82.09346617421797, 82.24605421866141, 61.68182050028155, 72.47051146722609, 82.13766344131963, 72.16877137461017, 75.65886497497559, 73.07226580958213, 72.05130423268965, 69.93743696520406, 68.393262586286, 69.92617976280951, 70.30251549136254, 70.5614782148792, 69.34682999887775, 68.53207526668426, 73.39163303375244, 75.41088488794144, 78.74572323214623, 71.16984567334576, 80.39546428188201, 73.23409495815154, 73.31621370007916, 65.7107614701794, 67.19694752846995, 62.82075912721696, 63.725473419312515, 65.38425945466565, 63.73685613755257, 63.86459204458422, 67.64040285541166, 69.04501930359872, 71.54691096275084, 70.9512362941619, 77.64651821505639, 78.09861060111754, 85.7304996059787, 80.74385704532747, 82.77416998340239, 79.97879089847689, 79.20724499610164, 76.75271203441005, 79.19823138944565, 73.50846475170505, 74.33109560320455, 76.09143964705929, 73.6916551282329, 84.07177632854831, 88.16224359696912, 90.54767224096483, 91.85080128331339, 21.401189065748646, 0.4090027595239301, 3.0246558400892445, 6.872956464367529, 3.6678657127964884, 5.573566911682006, 2.4355535930202854, 4.270569759030496, 8.879194874917308, 4.795813368212793, 1.1866377125824652, 0.31687051298156865, 11.892283155072121, 62.984141534374615, 91.83271131207867, 83.14852883738857, 52.74231526159471, 50.682247223392615, 48.329307571534194, 74.4518026228874, 72.42819693780714, 84.68266979340585, 66.47033629878875, 0.3027531672869959, 0.13892812984845332, 0.14984210953116417, 0.15395119065238586, 0.15456885670221623, 0.13621892119126935, 0.11627917703721793, 0.15525494972544332, 0.15747579265265696, 0.2300501822103416, 0.1667276986183659, 0.10118690018932666], [0.08249784053693857, 0.05552712144450315, 0.07636196655972351, 0.11398650570622376, 0.04562467659613298, 0.04302438265914398, 0.04422283911656949, 0.08356737588802654, 0.09618554880181629, 0.041367062517712196, 0.08811627574745687, 0.03831848457095124, 0.03485957461018716, 0.17584216841045888, 37.567582899524325, 71.86682731874528, 63.192474303707, 68.98130432251962, 57.94774763045773, 83.75835541755923, 68.54385022194155, 8.611268554964374, 0.13758824206888676, 0.19763661909007257, 3.955946396435461, 0.957789782795214, 1.4800317369161116, 0.5213602788506017, 0.5900832073342416, 0.25054877984427637, 0.26264061971056846, 1.1131496559227667, 7.746965952457921, 73.86893841528124, 66.48638663753387, 75.67730795952582, 88.227660886703, 98.1051068152151, 96.39631056016492, 97.57630071332379, 95.12055181687879, 95.25181001232517, 94.13318141814202, 91.16131920968333, 93.29571616265082, 81.69266270053002, 68.19834432294293, 69.97681756173411, 73.55008894397368, 80.78788172814154, 81.93744213350358, 86.71012724599531, 84.14201813359415, 83.97482318262901, 78.049635887146, 62.997446213999105, 60.596512440712225, 62.99628911479827, 60.66141197758337, 60.708111716854965, 59.70687573955905, 64.49553274339246, 68.19799130962741, 72.81663710071196, 73.8423369007726, 78.54034792992377, 67.08125329786732, 71.75541631637081, 79.42814503946613, 77.64633778602847, 78.68385960978847, 74.1786801430487, 70.6837228036696, 71.10900186723279, 71.78419082395493, 73.59998149256553, 73.75515045658236, 74.42407146576913, 65.19146711595597, 68.23170800362864, 67.47852663840017, 69.32011865800428, 70.00913004721366, 72.65516096545805, 71.61851775261664, 73.69663653835174, 72.81322463866204, 74.68610148276053, 73.40732251444172, 72.1335014220207, 68.83270925091159, 56.31363330348846, 61.641988831181685, 67.01672246379238, 67.93614172166394, 73.25290664549797, 71.13385400464459, 66.15048270071706, 61.301311369865175, 60.030808602609945, 60.024764230174405, 62.11146516184654, 66.44046352755639, 65.25113421101724, 62.51336689918273, 60.18656199978244, 63.77913928801014, 66.90608024597168, 71.04406310665992, 66.53071726522138, 70.2710973062823, 73.9153871228618, 62.71643977011404, 64.48245163886779, 55.4782037581167, 56.99265049349878, 56.08156627224338, 58.56324203552739, 58.70911498223582, 61.18968071476106, 58.51778176523025, 61.58283948898316, 58.867570892457046, 64.61018362352925, 65.864377175608, 69.01265190493676, 68.91172147566273, 77.64529443556263, 73.51141437407463, 75.97052866412749, 72.69938961152108, 74.71363652137019, 71.25774598890736, 74.42716229346492, 71.88854940475957, 71.82894506762105, 75.66958873502671, 78.18026650336482, 74.38002324873402, 77.975110853872, 75.90606058797529, 65.15423990065052, 1.960934054466986, 0.23149225079724867, 0.7958965279882955, 4.200194593398802, 0.8762084668682468, 1.4176396977516914, 0.4097331477509391, 4.082610270669384, 2.8101799036225965, 0.9959196335365696, 0.03655584266168937, 0.29843583282443786, 22.846117673381684, 47.75840659295359, 85.84966121181365, 46.273636510295255, 61.41884126970845, 38.33304912813249, 46.589548126343765, 54.05572483616491, 61.50691024718746, 33.47787657091695, 0.0911292152839803, 0.08411502916245692, 0.04841492203394732, 0.026446582802060633, 0.016801731187790152, 0.041190915921282385, 0.031160766131154476, 0.04731446354379577, 0.0520012975339928, 0.06678449620883312, 0.03274133766911203, 0.030041940683018298, 0.10771953876340583, 0.03268852739805176, 0.035385267974268046, 0.13569433482423907, 0.04531158795279842, 0.09124214430489848, 0.0599242018295392, 0.04942923776745316, 0.044169392992532065, 0.004912025535539274, 0.035638965651272766, 0.030311295281975504, 0.09788323028553879, 0.01704229811777271, 47.790115033426595, 81.14748462553948, 68.47747587388562, 66.77736374639696, 47.49212080432523, 93.12084121088829, 82.03292831297844, 10.22326659771704, 0.07716308002390208, 0.4323702185384689, 3.554943617313139, 3.243683687140865, 5.871831784325262, 2.9019466955815596, 1.546245512943114, 1.5938613707980804, 1.0517453185973629, 0.8101282965752387, 13.290121747601418, 82.68827007662865, 73.0362819856213, 87.00584257802656, 92.48310304457142, 104.20876195353847, 99.66573945937618, 102.05141129032259, 96.88483392038654, 99.5186270436933, 96.59418629061793, 95.75822722527289, 96.49888054017099, 85.34217711417907, 71.67917328496134, 74.4337675648351, 74.48598215656897, 84.86639361227714, 83.4589687470467, 89.51286469736408, 86.85143455382317, 88.7390987334713, 80.76568111296623, 66.95757312159385, 62.45303300119216, 66.28968761813256, 63.58730400762251, 62.665539172387895, 63.45071923348212, 69.37743233096215, 71.8266857824018, 77.55028678524879, 78.44667388546851, 84.08541833200763, 71.82612880583733, 74.34290978216356, 82.15913449564289, 81.22006416320801, 79.97725332936933, 76.7198896408081, 74.24373657472673, 72.06265557196834, 74.67355774294946, 77.12181491236534, 75.00717886032598, 75.29403748050814, 68.292128193763, 72.5913675369755, 70.00155202804073, 71.01333525873, 72.23927990082773, 76.70588677929294, 73.3442037336288, 77.97981769807878, 77.943402413399, 77.29160647238456, 73.93503819742511, 75.73357828201787, 67.54844680909189, 57.92172662673458, 63.539329498044914, 70.51404891475555, 68.57380928531771, 74.57210171607234, 77.45724816476145, 71.18497817747055, 65.61375733344786, 63.79258909533101, 63.556768355831025, 65.316684861337, 68.66153701659172, 68.85958533133231, 66.87897666808098, 62.78455172815631, 66.55473001541631, 70.3376599281065, 73.76374044725972, 69.47683303586899, 74.53242301940918, 75.95805552697952, 67.87560386042442, 66.24742800189604, 60.23045724438083, 59.51424029565627, 61.05100531731883, 62.738703143212106, 62.37438947923722, 63.11579981157857, 62.13126920884656, 64.59041880023095, 62.02778531659035, 66.18423077367967, 66.55695007693383, 72.0652521810224, 73.43401816583449, 78.46079441808885, 76.98694813636043, 77.86722213991227, 76.4854887993105, 76.64435263602965, 76.11207915890601, 78.76674713626986, 77.0980453491211, 75.62965900667253, 79.99229169661, 83.39293956756592, 79.99116205400037, 84.36777407123198, 82.29439350866502, 71.82335176775533, 5.024648856732154, 0.4406677781333847, 0.9858335037865947, 1.4685507142736067, 0.957346861400912, 0.49297800828372285, 1.346834787437993, 2.4280751039904933, 3.951798735126373, 4.395756125450134, 0.45527428628936895, 0.17739881310732136, 25.982895935735396, 56.360101622919885, 93.46972034823511, 52.88930608380226, 51.833356964972715, 45.282673220480646, 55.708125252877515, 59.23817603818832, 69.78817509066674, 44.03522614509829, 0.15474660442240779, 0.09648915710708789, 0.03606421722760124, 0.019572360944303296, 0.06693228223030606, 0.042369867780155716, 0.055421094875782735, 0.04521544774874084, 0.008755751994378384, 0.18498682206676853, 0.04029799448025804, 0.018935927655547857, 0.19036178687407126, 0.1215775483738511, 0.21538299989075432, 0.2624332550312242, 0.18616301217867484, 0.22942119338099035, 0.16303987392494756, 0.11758997645829955, 0.14691948410003416, 0.09553121778392985, 0.15014045481239596, 0.15594409177860907, 0.22607490600597477, 0.2326133591873992, 60.03122045147804, 92.54872429755427, 80.5422942869125, 83.57058371267011, 85.6025440462174, 103.8896143820978, 96.78407607540008, 15.001561680147725, 0.2529972887808277, 0.33822018833410356, 9.16340785641824, 8.027172723124105, 5.852016950807264, 7.066549947184901, 1.9177407915553741, 1.7378947258956972, 3.1971955107104395, 2.1348683728325755, 15.250784177933971, 84.02492753921017, 76.74958198301255, 94.91789863955591, 95.82511148145123, 108.1306771309145, 102.41101418772053, 103.94837933201944, 99.20844601046656, 102.21015745593657, 100.55119883629584, 98.65366597329417, 100.70577160004648, 89.68874377589073, 76.87896528551656, 76.62196374708607, 79.16375375563099, 90.06933135371055, 88.08844812454717, 92.39671676389634, 87.0320910792197, 93.58454381265949, 85.13799421248898, 71.50831484025525, 67.72201953395721, 70.58736585801648, 66.44367202635735, 68.85516874251827, 65.31235456466675, 72.84408584717782, 75.43775312362179, 83.13534967360958, 83.17545198625135, 87.95547977570565, 74.99846335380309, 80.64687252044678, 86.34393476670789, 87.17022126720798, 84.91573702904486, 81.88978533590995, 77.69215106964111, 77.82615492420813, 78.58614552405574, 80.83174951614873, 79.59588127751505, 80.97392759015484, 70.03425675053751, 78.58237220394996, 72.76166900511711, 71.8399904620263, 75.2817996855705, 79.13706594897856, 78.28977123383554, 79.92836490754159, 80.16871206222042, 80.57292015321794, 76.48992107760522, 77.2874330705212, 71.15951415031188, 56.937250937184984, 62.9985248657965, 71.33027061339348, 72.59088116307413, 79.83585188465734, 79.1888177010321, 72.75429494919317, 69.11133873847224, 69.25648212432861, 67.86524880316951, 71.49483757634317, 73.21732290329473, 72.13665500763925, 69.46053166543284, 67.6696402026761, 70.76077384333458, 74.73536645212482, 75.01212889148344, 73.33000475360502, 74.51111670463317, 78.63629694907897, 71.42272087835497, 71.35867641818139, 64.06734720353158, 63.69336097471176, 63.663268550749756, 66.36819777950164, 67.1102709924021, 67.11187916417276, 65.8615138453822, 68.16284687288346, 65.139523167764, 70.80371595198109, 70.0391597132529, 75.91214026174238, 74.01370525360107, 83.34706352603051, 80.18881028698337, 82.39830493927002, 78.6038746372346, 81.41153074079945, 77.77834907654794, 83.1413979684153, 80.82428916808098, 80.54150196813768, 83.9524813621275, 88.42272820011263, 82.66011530353178, 88.08703607128513, 85.98233930526241, 77.92450443390878, 3.8670358254063517, 0.6444039892765784, 4.137882349952575, 8.750144973877939, 4.104682428221549, 3.7610769175714065, 2.137804266906554, 11.336513700023776, 10.325734596098624, 3.9973173506798285, 0.3712618975870071, 0.6223812290737707, 34.985051231999556, 64.00849203909597, 101.29991654426821, 62.698557684498454, 84.1110392539732, 48.641034018608835, 64.59654946481028, 66.59203175575503, 80.69622378195487, 55.82127778760849, 0.29906935689430086, 0.22788448229191766, 0.09026042561257079, 0.10341492136039081, 0.1303443444832679, 0.17731566192401996, 0.13943751703106588, 0.0812084915777368, 0.0943557707773101, 0.3538595055860858, 0.13768867619575995, 0.10664475571003654], [0.025402755446491704, 0.01009052039139093, 0.02275973487074577, 0.023617132814721237, 0.0816160120490578, 0.02379271825174651, 0.11129877815443663, 0.05077882038970148, 0.028805009374815612, 0.13730949331675807, 0.02705698442314902, 0.048731599799207145, 0.10199293193797912, 0.1134945163803716, 41.65512800216675, 64.34605121612549, 55.048319831971206, 36.4334923221219, 45.68986623517929, 84.85273591933712, 45.53916485078874, 1.787836304114711, 0.1896539369537946, 0.8395936316059482, 4.642146671971967, 3.0191238272574643, 3.302037278490682, 1.3288265731065505, 0.4234548549978964, 3.343360919144846, 0.3812275676717682, 14.794022210182684, 89.84645443577921, 84.54421797106343, 77.22232172566076, 85.74437695164835, 92.85726578004899, 91.37763792468657, 96.08702382733746, 96.14202330189367, 93.75799886641964, 94.13843739417293, 92.61756189407842, 93.92242462404313, 91.38010901789512, 80.52661265096357, 66.62432070701354, 69.72291469573975, 72.32564264728178, 79.58658526020666, 84.66403853508734, 84.4088883553782, 82.0732581230902, 84.44860627574306, 76.42494309333064, 62.46476873274773, 60.13149192256313, 63.23971925243255, 60.20629152174919, 59.96068054629911, 60.271057698034475, 68.93346709589805, 72.14937917647823, 76.52776410502773, 76.85327376088789, 76.44020111330094, 71.67738468416276, 72.13811412934335, 77.03272219627135, 79.39562859073763, 72.55357157799506, 71.46859691989037, 67.36162431778448, 71.49788133559689, 73.36751045719271, 74.24229314250331, 73.46518531922372, 69.7389336555235, 68.11066366011097, 68.35284648403045, 69.27498786680161, 74.7735938718242, 76.69589258009388, 70.48937720637169, 70.66123193310153, 75.30352961632514, 72.49658738413166, 72.56005133351972, 65.45971016730032, 62.700781668386156, 58.147192308979655, 75.2302126730642, 70.3086579230524, 73.87762254284274, 66.71334282044442, 68.55826100995465, 65.34384727478027, 69.13065248920073, 62.95013458498063, 65.19504431755313, 59.556845080467966, 57.50941491896107, 64.21340842400828, 69.19395169904156, 64.43292779307212, 62.74092712709981, 59.70808382957213, 61.83415359066379, 71.00515319455054, 70.53711245136877, 67.55653473638719, 76.30032939295616, 65.22848252327212, 66.37553261172387, 58.38894367218018, 55.90391036002867, 52.9047288433198, 58.45770282130088, 59.944842015543294, 61.26639443059122, 63.6591814410302, 62.21319183226555, 60.157709044794885, 61.734890168712994, 64.54035366735151, 69.09395479386853, 73.27426002871606, 73.769482797192, 77.5548916478311, 75.60690141493275, 74.66374397277832, 76.35864719267815, 76.32154941558838, 75.30031327278384, 74.99461943103422, 74.46215768014231, 76.1587239849952, 76.83392863119803, 78.1339511563701, 78.92203377139184, 68.40938352769422, 67.80156520105177, 59.58418400056901, 2.1738368753463995, 0.46859223455671345, 1.554777280938241, 1.5453228979341447, 0.13736316543673316, 0.32191045221782505, 3.115447677912251, 1.807225928191216, 2.363696752055999, 0.5391935187001382, 0.3086024324499792, 11.423954117682673, 35.45992082165134, 66.68068516638972, 60.80532373920564, 22.105366299229285, 29.330444720483598, 57.11496960732245, 49.05644047644831, 60.60256073551794, 21.59804694114193, 0.04181149310522503, 0.04599714854491815, 0.08549070090896661, 0.2162152012029002, 0.04544268474884091, 0.13646030017445165, 0.032249562847878666, 0.026960947640961217, 0.006511118685481169, 0.08821410517538748, 0.09982586838304998, 0.01513458405350966, 0.01877166499804345, 0.04769607875195723, 0.04227969157058866, 0.026045459164907376, 0.0818933128950096, 0.004376696221785801, 0.08634487362278086, 0.019182364734250213, 0.07128117185446524, 0.0358969419293346, 0.11440909512701536, 0.09141464432280871, 0.07511230861587871, 0.1155175171011398, 55.032347940629535, 71.12126319639145, 64.94582476154451, 45.98642879916776, 41.150687663785874, 95.9134981709142, 52.27347043252761, 2.0020131598557196, 0.6553831936851625, 0.9659777305299236, 4.358295038823159, 3.8643926382064824, 2.647446893876599, 0.6530288522762637, 1.6236287283320583, 1.327765449400871, 0.019053125701424097, 24.673298904972693, 96.77588616648029, 91.04239294605871, 87.15925432020619, 90.8574688819147, 94.6121028161818, 93.95562356518161, 98.80967432452788, 98.13309684876474, 98.61422261884137, 97.08711839491322, 96.95663682876095, 95.65016592702558, 94.12193990522816, 84.07559671709615, 69.5839294310539, 71.56988820722027, 77.06774896191013, 83.2808852964832, 88.67609762376355, 87.9554013283022, 85.05471444899037, 90.1546036812567, 79.23274824696203, 64.4600627499242, 62.37437771212671, 65.91105338065856, 62.71900892257691, 62.9149313126841, 63.91841480808874, 72.37515864833709, 75.9593028406943, 79.85201204976728, 79.16347134497859, 76.7102013864825, 76.0372874044603, 76.19435479564052, 80.24904220334946, 82.91301404276203, 77.69219029334285, 74.97076357564619, 73.81984603020453, 74.36472600506198, 76.73602627169701, 77.14750643699401, 77.48403795303838, 71.56292207779424, 72.64770846213065, 70.96927919695455, 70.34129204288607, 78.87742073305192, 79.19186930502616, 72.29827234821936, 75.63901778190368, 74.04300535878828, 76.33031199055334, 75.08514773461127, 67.50716778539842, 62.24899522719845, 59.41900514787244, 78.53105975735572, 73.34644732936736, 74.8375363503733, 69.0059446519421, 69.7333795793595, 68.49873512021958, 72.49717573965751, 67.38886125626104, 68.35018711705362, 61.64234968923754, 62.96707922412504, 65.92762931700676, 72.71588710046584, 67.70459636565178, 64.8416034636959, 63.20777546974921, 63.56415810123567, 75.08653625365227, 73.36259180499663, 71.30142550314628, 78.40989774273288, 68.04915305106871, 68.91231767592892, 61.36699930314095, 60.43626400732226, 57.067073545148304, 61.94321901567521, 64.78578813614385, 65.3760342444143, 67.946363418333, 66.37144550200432, 63.87923425243747, 63.17477264711934, 65.2865610584136, 72.12226775384718, 73.78817681343325, 76.18921649071478, 79.37615794520225, 78.38635567695864, 78.03573500725531, 77.51183971281975, 80.56723271646808, 79.44280685917025, 78.96096721772226, 77.24740920528289, 79.98156793655889, 80.44364667707875, 79.74803001649919, 81.11532903486683, 74.23645665568691, 75.18797659104871, 70.1958191779352, 4.054710941929971, 0.4746921330450043, 0.583778548865549, 0.6239880525296735, 0.9477508440613748, 0.2462400868535042, 2.201246888406815, 1.3871565076612657, 6.448645735940626, 0.7652174645373899, 0.4894597035261893, 9.90081540999874, 42.08581993656774, 74.01656858382687, 64.50688016030097, 23.06550564304475, 31.64981280603717, 60.16128624639204, 57.52757157048872, 68.63801848503851, 27.220750854861354, 0.22804059568912755, 0.11779361028945255, 0.16536076793507223, 0.06805114598283846, 0.041104321172761346, 0.0784845280671312, 0.06476075238277836, 0.05327079715507646, 0.04448976330158692, 0.055453144164095004, 0.019052334715642275, 0.039994271261797804, 0.08388267469502265, 0.06494316557842879, 0.10804040702961146, 0.12805959450141077, 0.27645946690632456, 0.07744640232093873, 0.17005935371402772, 0.2072524474633317, 0.21915756105895967, 0.25220187501080576, 0.22552349123983617, 0.10155288337339317, 0.21040810151926934, 0.3547751338731858, 69.89924092446604, 83.31497853802097, 76.5403078448388, 47.88352235671013, 72.16100508166899, 105.79640403870614, 65.18419111928633, 3.412419394139321, 0.6364980231850379, 2.301976541357656, 11.70294544389171, 8.239787740092124, 10.041794219324666, 8.759997967750795, 2.8513996014671945, 9.903762090590693, 1.2208884617974682, 23.829098939895633, 95.89888341965215, 94.3808477155624, 87.73728616776006, 94.68992264040055, 99.71403952567809, 95.83607058371268, 101.56650435539984, 102.18191639069589, 101.25150665160149, 101.7454585721416, 100.73140821149273, 99.72954073259908, 99.61689810599051, 88.9097845938898, 73.12644158640217, 75.96251133949526, 79.8297800556306, 86.76113374771612, 90.33299307669364, 91.18400619876002, 87.88421815441501, 94.37941212807932, 82.79870048646005, 68.62726334602603, 66.8234908196234, 69.36162517916772, 66.15687616409795, 67.67200931426018, 67.31520698916528, 76.69193098621984, 81.02270618561776, 85.30250626225626, 85.7719825929211, 84.76661635983376, 79.46089683040496, 79.74663365271785, 83.9946311519992, 86.39993052328788, 78.80359388166859, 79.49346819231587, 76.19205628671955, 76.74451428074991, 80.7108699121783, 80.54654613617929, 81.20015421221333, 76.3030985862978, 76.61772758729997, 75.94428016293433, 71.83845289291875, 82.24133168497394, 84.92631173902943, 76.66459991085914, 76.27244134103098, 78.58551010008782, 77.14630619172128, 75.7327938079834, 72.56691548132127, 66.97623575887373, 59.47698562375961, 77.1273454543083, 74.97110874422135, 78.5331464582874, 69.73512895645635, 69.63321793463923, 69.66471456712293, 74.88777406754033, 68.39506687656527, 74.00753144294985, 66.97520809788858, 65.09147021078294, 71.1966746853244, 77.48603051708591, 71.96643983164142, 69.86983099291402, 66.71975197330599, 68.15923829232493, 79.87497360475602, 77.33808655892649, 73.6510350627284, 79.23285022858651, 71.71654562796317, 72.7102545768984, 66.47580408280896, 61.645911201354004, 60.33362342465309, 66.14688980963923, 68.70272190340104, 68.01753874747985, 73.04491904474074, 71.37218506105485, 68.17905410643547, 66.5511449690788, 70.09456711430704, 75.6820148037326, 78.20159635236188, 79.98293292137885, 84.83338294490692, 81.55437561773485, 80.77585574119323, 80.92532942371984, 81.94051727171868, 82.79626077221286, 81.29218086119621, 80.34705438921529, 83.44591509911322, 85.15435049610754, 83.13416511781755, 83.10123289785078, 78.4921576899867, 80.58059230927499, 74.15861329724713, 3.101111414932436, 1.6828087140475552, 6.22540109580563, 3.8514603386002206, 4.21392337929818, 1.0213110968470573, 7.878168254129349, 10.005153398359976, 7.014008818134186, 1.2398582696914673, 0.4234576435579408, 16.881612539291382, 53.975477064809496, 80.06981342069565, 78.48385795470207, 32.544615268707275, 39.6809559483682, 73.74228508241715, 64.30892206007435, 78.9297608406313, 35.29287099838257, 0.5246917807286786, 0.23182225083151173, 0.2152054360316646, 0.39513356502979036, 0.13030490627692592, 0.17277455317877954, 0.14840316658298816, 0.13563683226464257, 0.16774846481219416, 0.17476011518268816, 0.16224755515013972, 0.1882413474302138], [0.04601547336806694, 0.0506012833436891, 0.06811487683725935, 0.06378527347659392, 0.07508589390424952, 0.025750385079112266, 0.08314698513957762, 0.11613122247640165, 0.032910348156527165, 0.03838193580327976, 0.04940894026789935, 0.05240335579841368, 0.05633212663533707, 0.4254469287491614, 50.28420117593581, 67.87455266521823, 55.21120802048714, 34.8079405292388, 62.02407083203716, 83.29648848502868, 24.26760619686496, 0.17112582471341858, 0.12145367961737419, 1.2945271619865972, 1.625937288326602, 1.7875407780370407, 7.279222819112963, 2.7282398746859644, 0.8112823927114088, 0.1710816061184291, 35.19008528801703, 112.86420914434619, 99.47856395475327, 99.55372441199519, 97.0067725643035, 94.42553135656541, 87.86752454696163, 94.11532678911763, 91.60068742690548, 91.20869359662457, 92.95704303249236, 94.43478815017208, 93.26474512777021, 89.16072999277424, 88.45984951142343, 81.61319548083891, 65.53536876555413, 67.16763173380207, 72.52252994045135, 77.81046544351886, 82.56957915521438, 83.53215232972177, 83.32022666931152, 81.50485177193919, 71.5295191734068, 60.03790809262184, 60.554221445514315, 61.44527412229969, 61.058995185359834, 59.23467728399462, 60.91396554823845, 65.15141971649663, 65.71456224687638, 70.92134783344885, 70.68447589874268, 73.57186594317037, 73.85250368425923, 75.29097018703338, 76.27424563131025, 78.73457585611652, 71.8427518106276, 67.65206013956379, 70.20717836195423, 73.2652307325794, 75.63172217338317, 75.37550510898714, 71.34459510926278, 72.33037302570959, 64.73231054121449, 67.95742450221893, 72.79834316622826, 72.23546735702023, 71.6450329749815, 68.30870413011121, 74.3660831451416, 72.39530394154211, 69.17214332088348, 67.4410758479949, 54.61661984843593, 55.62751270109608, 58.48098208827358, 68.3343642757785, 68.81803174172678, 66.79338270618071, 67.86098910916236, 71.93442544629498, 68.44510063048332, 66.13404012495472, 62.49910123886601, 63.392872118180804, 58.219665942653535, 58.70460425653766, 62.421610893741736, 65.4803418344067, 64.0880298614502, 61.41759787836383, 61.961697301556995, 60.10137596438008, 64.14386480085312, 69.62036040521437, 67.40243265705725, 71.06355728641634, 66.48610422688147, 63.01171579668599, 59.61114637313351, 55.98503674230268, 53.463529309918805, 56.72024188503143, 55.83578271250571, 60.91087864291284, 60.94739198684693, 59.07976719640917, 57.26570237067438, 59.6480990225269, 62.6498261574776, 68.18428654824534, 68.33726682970601, 72.07563077249836, 73.24534431580575, 74.03741205892256, 74.29963034968223, 67.62301891080796, 72.17732214158582, 73.57367807818999, 78.93764480467766, 78.23499141200897, 78.53991646920481, 74.7741900720904, 78.79683171549152, 73.10565302448889, 78.65483407051333, 59.19957991569274, 62.35455405327582, 59.28797444989605, 3.3854967355728154, 0.7336405460392276, 1.2819314507707473, 0.06778018068402045, 0.8622558607209114, 0.6851185593874224, 1.5978239452646625, 5.332739756953332, 1.2673984564119771, 0.011323950677779655, 1.1474744398747723, 23.75250485635573, 46.95522677513861, 60.7629229176429, 34.431098814933534, 50.35563538151403, 57.99304316120764, 52.63006879437355, 55.50387174852433, 11.958337829959008, 0.4059761299961998, 0.13360438567976798, 0.07845421396796742, 0.10176497481523022, 0.03936285393372659, 0.10406187495156642, 0.020961251537946445, 0.028982988836604263, 0.03920375662405164, 0.034282583998696464, 0.034639860593503526, 0.08380995762924995, 0.03544904479396439, 0.07195210399767084, 0.04758380856665392, 0.0649760996982936, 0.11557318104971802, 0.04529879045402331, 0.09807361079560173, 0.07757445391748222, 0.05382114322856069, 0.05203903502514286, 0.03692994254731363, 0.1683319786623601, 0.076336677997343, 0.8512179433338104, 65.45905905385172, 74.72823558315154, 65.9966238083378, 31.836637258529667, 58.786028738944765, 99.22931301978328, 27.2001152653848, 0.01650744234211743, 0.38453130652346923, 2.6788564987720984, 2.860530879228346, 4.16372537612915, 2.1556238397475216, 2.4971416688734487, 0.3290525060747901, 0.39084249206127664, 48.81698369979859, 115.76933614669309, 103.01584366829165, 104.15264852585332, 101.12583391128048, 98.3736244324715, 91.8702248604067, 96.58351744374922, 92.82124273238644, 93.38375768353863, 97.17502655521517, 95.5276938407652, 95.61234643382411, 91.45597550176805, 90.01572824293568, 84.31931711012318, 69.74597038761263, 71.21707885496079, 75.79413967747843, 82.94902140094389, 85.09140429958221, 87.45635817127844, 85.29717968356225, 84.09684811868976, 75.42528783121418, 62.175352727213216, 63.050857128635535, 65.013395432503, 63.65882450534452, 63.446428160513605, 65.54057767314296, 68.03038843216436, 71.70664556564824, 74.02394263975083, 74.05567461444487, 74.87898795835434, 76.0745499210973, 80.71967955558532, 79.28907348263648, 82.06775111536827, 76.70558083441951, 71.34297124801144, 77.74274180012365, 77.9377620450912, 78.4356128015826, 77.46190009578582, 74.16552451349075, 75.21206778864708, 65.33712433230492, 70.94287380095452, 78.39401998827535, 73.90766789836269, 73.48862540337348, 72.4518645194269, 78.4502197081043, 73.49934131868424, 72.75456951510522, 67.74591461304696, 57.06148809002292, 55.357602642428496, 59.04593283130277, 65.47907490884104, 70.1354774352043, 69.19545004444738, 71.75589484553184, 75.24973038704165, 71.36729778782015, 68.52880400996055, 65.94930433457898, 65.15807990104922, 62.37674290134061, 62.41099696005545, 63.92351781168292, 69.46789003187611, 67.18771426908432, 65.61417310468613, 64.96993164862356, 64.4207174547257, 68.43363946483981, 73.05266964820125, 71.16171067760837, 73.77632341077252, 70.32955631133049, 67.51036843945904, 61.04079538776029, 60.050769544416866, 56.65402050941222, 56.8408469230898, 58.67411567318825, 62.67429782498268, 62.16451914079728, 61.79691068587765, 59.82481356590026, 62.43786519573581, 64.42966438108876, 70.74382135944983, 72.8793244208059, 75.17662525177002, 77.1244115214194, 74.95491720015004, 74.58810498637538, 72.10729998926963, 73.35086391818139, 76.59611532765051, 81.1250957365959, 80.29812674368583, 81.34252840472807, 79.87083158185406, 80.94672203063965, 75.9400204689272, 75.99415702204551, 67.61892395634806, 67.10033170638546, 70.98302318203834, 7.543099291862981, 0.7473488620692684, 0.4597497719430155, 0.4636849204619085, 0.7301040390326131, 2.612155613399321, 3.4252102432712435, 8.266953095313042, 1.7957423314932854, 0.0704901401073702, 1.1012708804299756, 24.323048899250647, 57.016082732908195, 67.80479723407377, 32.520839821907785, 48.614860042448974, 68.68132929648124, 58.0522866402903, 63.26679537373205, 17.072351517215854, 0.49767804962973444, 0.19675292134765657, 0.10844962055524511, 0.10065742618133945, 0.04132745577202689, 0.05732891044669575, 0.07211522709938788, 0.028311319333771547, 0.06854750200985901, 0.03732656541791174, 0.025235416945971312, 0.03553470874565744, 0.14958718611348062, 0.19943752326071265, 0.1509667572475249, 0.17390188220287525, 0.16828943013904557, 0.1165343839074335, 0.31115522127478357, 0.1841546820416566, 0.14896207368902623, 0.08657291501520142, 0.10363877225186556, 0.22992670415870606, 0.19871055178584593, 1.3716870474238552, 77.11094994698801, 86.95216101984825, 73.8187163875949, 52.1163873518667, 85.13710775683003, 107.65761575391217, 40.913870642262125, 0.31128845928657445, 0.2869595599270636, 5.15519465169599, 7.364132817714446, 6.524596060475996, 17.786334676127282, 10.538117212633933, 4.715815647955864, 0.5204040172599977, 46.72815684349307, 120.2228815324845, 106.03704929351808, 107.52764409588231, 105.52783150826733, 103.55517741172545, 95.71112740424373, 97.59611652743433, 95.49300439896123, 96.36126810504545, 99.70888553127166, 99.41884979124993, 98.55887797570999, 95.93046634427964, 94.84098096047678, 89.52008185848113, 73.96630733243882, 73.91761502911969, 78.04098313854587, 87.29255999288252, 88.63867036757931, 91.14604550023233, 89.58045498017343, 90.19408625941124, 80.10738972694644, 64.96561311906385, 66.66330122178601, 67.92021689876434, 67.56441870043355, 68.52914917853572, 68.65180169382404, 72.98849967218214, 74.40293773528069, 80.41910832928073, 79.8204840383222, 80.4813563439154, 80.38514844832882, 83.86789152699133, 85.46209965982746, 85.95486702457552, 78.13628104425247, 75.20634897293584, 80.84660745436146, 81.90715359103295, 82.84788700842088, 81.86436053245299, 78.3397892982729, 78.11740659898328, 67.38487612816596, 71.27889540887648, 80.82621897420576, 79.07387656550254, 78.39596548388081, 72.96667560454338, 81.54145533038725, 75.16277144032141, 74.2212692383797, 69.95064750794442, 59.034067661531516, 57.0444610811049, 60.42851732623193, 72.82639595770067, 74.46998673100626, 70.83141573013799, 76.55500888824463, 78.54114809343892, 73.09116378907235, 69.34960703695975, 67.17379769971295, 70.07885409939674, 67.2074673252721, 66.46897915870913, 68.5784298373807, 72.1052211330783, 72.74843492815572, 68.74175733135593, 68.86430002027943, 67.43266628634545, 71.26532400808027, 74.36657736378332, 75.44650000910606, 76.00503767690351, 74.59536921593451, 70.90852952772572, 66.13389891962852, 64.36394899122178, 58.88232292667512, 62.3658779359633, 62.67612957185315, 68.96078248177805, 67.64799656406527, 67.49338457661291, 65.17023140384306, 66.70770245213663, 69.15877588333623, 75.71448418401903, 78.08716512495472, 78.91246318817139, 80.292235343687, 78.97555843476327, 80.73707134492936, 74.33839121172505, 75.29467290447604, 79.74343299865723, 85.35560730964907, 84.57140784109794, 84.93913004475256, 82.71878611656928, 84.41525043979769, 78.02722346398139, 80.54523606454173, 67.70315293342837, 71.24064445495605, 73.3928019000638, 6.018312208114132, 2.3089791978559187, 3.3930313635256986, 0.5015654861927032, 2.3590105002926243, 3.4240092625541076, 5.227118172953206, 19.06091082480646, 3.0898971134616486, 0.13850026974274268, 2.3027713116138213, 37.712369349695024, 64.27361680615333, 76.14876116475752, 48.64405424364152, 68.02193180207284, 71.05752468109131, 67.92237420235911, 73.83292321235903, 24.08870493212054, 0.6347913018638088, 0.379447577701461, 0.2596784641425456, 0.18659879363352255, 0.16938907274555776, 0.2295674395657355, 0.10419953329068038, 0.14889655784974176, 0.2322515665042785, 0.13855587240428696, 0.19858422388713207, 0.17589067709782433], [0.03877896087003812, 0.09845174413414733, 0.0704141135417646, 0.2048081979756394, 0.06057837962984078, 0.07529392508008788, 0.02316157480010823, 0.06328245166749244, 0.033216316012605544, 0.06036277950531053, 0.0655804741226377, 0.05832639522850514, 0.1698496448056352, 2.7684294600640578, 62.26903461640882, 51.257917804102746, 49.8332658890755, 66.26973059869582, 73.97493654681791, 68.51176523393201, 6.946654858127718, 0.05745112062281659, 0.2589485662118081, 0.7998175498458647, 2.582324762498179, 1.5575906009443345, 2.4820390728212174, 0.8009654559916066, 0.2707742671332052, 42.18827616783881, 121.33272401748167, 90.77974319458009, 100.92044291957733, 95.03125513753584, 100.35407620091593, 95.8465668462938, 96.00262226596956, 88.39295741050475, 93.47744741747456, 88.29383911625033, 93.16516399383546, 90.27573431691816, 87.98978482523273, 84.4507400451168, 80.56356922272714, 73.22254750036424, 65.25096554909983, 69.56852236101705, 70.55228417919528, 79.80190769318612, 86.04519136490362, 83.24229701872795, 83.32287034680768, 81.37880248408165, 67.34777835107619, 58.89580411295737, 62.794487091802786, 61.408584271707845, 62.241370139583466, 60.61172339224047, 60.72782162697085, 60.31620417871783, 65.7638232938705, 65.38460070087065, 66.73633575439453, 67.57667218485187, 71.61090835448235, 75.48235047248103, 75.51038757447274, 76.23717923318186, 74.45257925218152, 67.96013878237817, 71.39047115079819, 73.87495533112558, 75.8480958015688, 71.70782227669993, 76.75654811243858, 63.929248394504675, 64.0453113279035, 72.16478624651509, 72.6819585984753, 71.0465185103878, 70.07984253668016, 72.67995818968743, 74.39281802023612, 63.968185763205256, 64.60197018038842, 58.28138051494476, 56.25572343026438, 56.380046875246116, 59.115668650596376, 52.13428512696297, 59.27766253871303, 72.03777205559516, 66.66348165081394, 65.23835120662567, 66.75748517436367, 71.62270684396067, 66.35690135340538, 64.34634539388841, 57.68162265900643, 55.51536037075905, 64.77680590844923, 64.45200620159027, 66.51244686495873, 66.99481994875016, 63.85630407641011, 55.81042851171186, 64.18169998353528, 69.61333936260593, 66.76164288674632, 71.05883475272887, 67.8198669802758, 63.13029296936528, 60.382645207066695, 58.5867174210087, 52.04059539302703, 52.54742053247268, 52.995751365538574, 53.99544192898659, 54.87359785264539, 52.76693597916634, 55.83644559306484, 55.81877923780873, 58.7425688774355, 64.68670906559115, 70.28551593903573, 70.080885887146, 73.52682144411149, 68.97921762158795, 63.74313192982828, 71.07322985126127, 72.99756819202055, 75.4961258365262, 75.04851279720184, 76.0478856486659, 71.86674887134184, 73.3755434713056, 69.87390241315289, 70.55407277999386, 64.85768125903222, 67.60521135022564, 65.49752181576144, 57.66125771307177, 67.61612338404503, 4.397858515862496, 0.565835114928984, 0.2041372122062791, 0.33365421237484105, 0.8414085245420857, 0.6618302219337033, 5.731180002612453, 2.0140371856189545, 0.15953125251877695, 0.033043191633037025, 13.667293921593698, 36.52374213741672, 56.32296069975823, 34.08352974922427, 31.10667436353622, 40.55901773514287, 54.10935932590116, 50.970490440245605, 17.05025092247994, 0.18837601036554386, 0.11971946340054275, 0.05296792046377256, 0.08032470956564912, 0.10075191546592022, 0.04472392573652249, 0.08428135451169745, 0.0191309257605744, 0.024287086280603564, 0.024152946200281866, 0.02963785994647732, 0.09398469310854712, 0.056059552551878084, 0.07904354242547866, 0.02599445111568897, 0.128447970435504, 0.0890662171126854, 0.010083345977980043, 0.08051849150609586, 0.09499800526687215, 0.005367257483979507, 0.033155729949113824, 0.02984558851758559, 0.08166881848967845, 0.26866568673041563, 4.387739781410464, 75.5230176064276, 60.71032393363215, 57.92725716867755, 48.58203764884703, 83.83170373978155, 79.08130553460892, 8.137849261683803, 0.14270613841231794, 1.0785074051349395, 1.802514671317993, 3.572870319889438, 3.745413422584534, 5.207151347591031, 0.800836262924056, 0.2982572424075296, 53.81354201224543, 123.46536374861195, 94.423154400241, 105.40807370216616, 98.4524013150123, 104.88304092038064, 97.15495186467325, 99.63580393022107, 92.28754935726043, 92.21819400787355, 92.44984134551018, 95.25738762271021, 90.89025989655526, 91.40746362747686, 89.27043084175357, 84.48453518652147, 75.09011345524942, 68.44261384779408, 73.25836658477783, 76.9368516245196, 83.12204499398509, 90.39993224605438, 85.5817319500831, 85.7270714544481, 84.54475141340687, 68.97009418856713, 61.3603901094006, 65.58563786168253, 64.03275582098192, 66.43705106550648, 65.3794074827625, 65.14596762195711, 63.25780137892693, 67.70734986951275, 69.56307811121788, 69.99207558170443, 71.26140163790795, 76.68581208875104, 79.16576985389956, 78.42463800984045, 79.89317340235557, 77.64010121745449, 70.98786338683098, 75.11991562381868, 76.26450246380222, 75.3789960184405, 73.80429775484147, 78.98455635193856, 66.11532257449242, 67.01553006325999, 76.83163012227705, 76.06645414906164, 72.84370929964128, 72.59613713910504, 75.1009705758864, 75.61568752411874, 67.97197649555822, 66.04490034041866, 56.80001897196616, 57.278677571204405, 59.81408588347897, 60.923940135586655, 52.003242661876065, 56.78634558954547, 74.79898729631978, 69.81842440943565, 68.9449361062819, 68.10667853201589, 75.36732304480769, 70.32095063117244, 68.25147674929711, 61.52709868646438, 60.35826767644575, 68.74695054946407, 66.22229345383184, 68.04017082337411, 69.06980868308776, 68.63463740194999, 58.98180600135558, 66.71380566012475, 70.97594722624748, 69.70601712503742, 74.7247995868806, 70.92431314529912, 67.71647330253356, 63.46552618088261, 61.75345082436839, 55.60985026821014, 56.25998312427152, 55.8166140894736, 56.19017277994464, 56.06287617837229, 57.78304730692218, 59.316839171994125, 57.00375080108643, 62.535602815689586, 67.22847553991502, 72.94528299762358, 72.81459746822235, 75.93914185800861, 71.90740031580772, 69.01899829987558, 72.13691388407062, 77.34267573202811, 77.12204240983533, 77.43705580311438, 80.41242461050712, 77.04717220798616, 74.0665082008608, 72.04280053415607, 71.75588700079149, 67.30525201366794, 71.43249542482438, 72.0680998217675, 63.70270798283239, 79.48559207300987, 8.333999149260983, 0.5990219825217801, 0.6194231490935049, 0.6407108326112071, 1.0770313682094699, 1.8556005195263896, 4.284513294696808, 3.030303807989244, 0.7549500477410133, 0.0449486461377913, 13.271808201266875, 42.329179471538914, 66.36217301891696, 38.90867264040055, 26.12554861653236, 46.97361484650643, 58.61019672886018, 60.05060088249945, 20.86603460773345, 0.2848261276320104, 0.04628486818664017, 0.09180470565033537, 0.09444947099132885, 0.04662376633214374, 0.018622708777266166, 0.05530369573182637, 0.04652587178673956, 0.01146118096526592, 0.093859460715565, 0.04515270897818189, 0.06802046416147102, 0.18721984579197823, 0.2169513350893413, 0.15546449009449254, 0.23659507053033, 0.1796082413244632, 0.22504470160891935, 0.1744986953394067, 0.20657159448150667, 0.12460318198727986, 0.2926474256861595, 0.19285791583599585, 0.21888472650560642, 0.5328583392885424, 5.380815267562867, 87.17620680409094, 69.55371149124639, 66.64488961619716, 89.79125099797403, 94.03122332788284, 91.35226018967168, 12.472720396134163, 0.2667724383213828, 1.2105197988210188, 4.708471990400746, 7.37711194061464, 8.716508688465241, 9.934964545311468, 3.455248489495247, 0.6869906331262281, 54.4292325358237, 128.61614181149392, 96.54378383390366, 110.96804126616448, 101.77748864696872, 108.61407787569108, 102.53465514029227, 103.55112168096728, 95.09876697294175, 95.7765054702759, 91.62898340532857, 100.02040017035701, 95.14949890875047, 97.44295581694573, 94.91395273516255, 88.20769602252592, 80.67537246211883, 70.63680341166835, 77.4980878829956, 80.03142910618936, 83.99819266411566, 94.21533153903101, 89.38528568513932, 92.08109932561075, 87.6381286498039, 73.62389226113596, 65.48171466396701, 69.22389507293701, 68.05978267423569, 69.91280448052191, 71.46376455983808, 68.72757404081284, 66.13331056410267, 73.81932043260144, 72.29070217378678, 74.64138646279612, 74.4491667901316, 80.0454790361466, 81.79950806402391, 84.00373105079898, 82.95796440493676, 80.43890845391059, 74.18219458672309, 80.6236207100653, 80.61292832897556, 80.34184548162645, 75.43121061017438, 83.97400732963317, 69.26999076720207, 69.17210409718176, 78.97796677004906, 77.74535409865841, 77.83531758093065, 76.9744828439528, 78.85397280416181, 79.32544954361455, 66.1227515435988, 67.13275401822983, 57.95708287146784, 57.315241905950735, 60.79318400352233, 61.16391466509912, 52.214274021887014, 60.746339136554354, 76.7797685438587, 70.72288374747001, 71.9706210782451, 71.7852420191611, 78.66320440846106, 70.68783344761019, 71.95935603111022, 67.03524389574605, 66.26738502133277, 73.20559501647949, 71.71201136804396, 74.88732691734069, 71.97298234508884, 71.555587245572, 61.48289357462237, 70.97318587764617, 75.491819074077, 72.86540000669419, 77.03920195179602, 76.56230449676514, 70.68945730886152, 67.07895478894635, 64.16631644771945, 58.38374260933169, 59.23381436255671, 58.45705563022245, 60.68257708703319, 59.89943665842856, 60.68510701579433, 63.189206969353464, 60.63873675561721, 66.13417348554059, 70.97687290560815, 76.24685964276715, 75.95831440341088, 78.69793307396674, 76.44067964246197, 71.15308930796962, 73.81048725497338, 80.68377417902794, 81.0293193017283, 79.96003412431287, 82.30450537896927, 77.36413894161102, 77.62015988749843, 75.11687970930531, 73.98082794681673, 72.38928702569777, 73.07808660691785, 71.22713581208261, 65.42764086877146, 79.64420487803798, 6.496386864492971, 1.3726330740797905, 1.7174680026308184, 1.381208846165288, 1.01533095322309, 1.1662589157781293, 10.888615308269378, 5.269336114006658, 0.6914313077445954, 0.23083883908487138, 21.429555646834835, 54.77238893508912, 69.92917645362117, 51.03893972212269, 44.71086225202007, 51.57064053320116, 64.02248313350063, 71.24032282060193, 25.995019981938025, 0.44814593008449005, 0.1899153108318006, 0.20485842269995522, 0.16471543078941686, 0.25307153802244897, 0.09976303385150048, 0.13105191861189183, 0.18574305810034278, 0.10121870815994279, 0.14618753305365964, 0.1387053055147971, 0.17176512508623062], [0.024041758114171606, 0.1433518279584185, 0.0353226364560185, 0.06488651337642824, 0.015379189224463078, 0.09345136567830079, 0.03759479195240044, 0.07036204254555126, 0.03978070127026689, 0.07777695393850727, 0.015635416906837736, 0.05269617758571141, 0.33988425387970866, 10.337182033446528, 64.29050653211533, 43.35597753524781, 30.719034364146573, 28.198136860324492, 82.55089298371347, 44.133222641483435, 1.344969210124785, 0.046197986155147516, 0.480714472791841, 1.5480277398901603, 0.825959166451808, 4.3873343063939005, 0.8280745497153652, 0.41159740739291717, 23.547490412189116, 113.18399998449512, 95.8227502146075, 100.95375953182098, 92.28823184967042, 97.10791480156684, 91.3340525473318, 93.65319313541536, 97.35882097674956, 92.23245574582009, 87.5403674956291, 92.47743129730226, 89.44405063506096, 86.76769195064422, 80.77814640537386, 78.25187329323062, 73.5884105005572, 66.59979020395588, 63.479823220160704, 68.4408958496586, 72.32027684488605, 80.6359604866274, 83.59548291852398, 84.07672635970577, 81.78861171968522, 77.52595240069975, 66.00171504482147, 60.5011203981215, 61.75314880186512, 62.64679024296423, 60.53906148479831, 61.04896176245905, 59.59203266328382, 58.94098197260211, 59.61552766061599, 63.07340291238601, 60.24011804211525, 66.8844993652836, 71.81216516802388, 75.34847213375953, 74.27887316673034, 75.85750164524202, 74.91250853384696, 65.86971944378269, 70.35655006285637, 73.17475734218475, 74.00753144294985, 74.7262587085847, 64.274428736779, 62.20590014611522, 72.77340473667269, 75.1160717010498, 68.00076669262302, 71.36772140379875, 74.04313087463379, 70.54961696747812, 65.10261758681267, 61.718310309994614, 64.01405003763014, 59.96094334510065, 63.04216123396351, 62.67543531233265, 62.947792929987756, 63.13638441024288, 60.16015268141224, 63.97526956373646, 69.52155590057373, 70.95750424169725, 67.55399304051554, 64.62266460541757, 66.23587269936839, 63.90322739078153, 61.74522169174687, 53.42771807024556, 60.817098694462935, 63.831353879744015, 62.927008290444654, 67.6988540157195, 64.48866075085056, 63.63340362425774, 58.81924729193411, 71.27455726746591, 68.28661334130072, 69.33205050806846, 67.61229515075684, 65.95893767572218, 61.679945607339185, 59.3226089785176, 57.507430199653875, 56.421710291216456, 51.60482006688272, 53.56274958579771, 52.11886236744543, 52.749226477838334, 53.638651371002204, 54.95945461334721, 58.029403532705004, 64.42411422729492, 67.28170210315336, 73.81051078919442, 70.02883603495937, 64.3870948976086, 72.9584856956236, 77.80714711835309, 77.07134185298797, 72.26519892292639, 74.31277813449984, 74.04604911804199, 73.57344273597964, 70.70200889341294, 68.89050929777085, 65.11033681131178, 71.89272280662291, 72.46265888214111, 78.72169479247063, 75.7870872559086, 66.28798530947778, 63.861826773612734, 2.0443281795709365, 0.710811616191941, 0.5704787722037685, 1.722605817260281, 2.903124877522069, 3.5564316664972617, 1.8076627821691575, 0.47487755696619716, 0.28587851793535296, 3.554520001334529, 33.56854215745003, 47.1621435688388, 51.75231295247232, 41.42465345321163, 45.513332120833866, 43.74917553317162, 52.19620366250315, 15.297707492305388, 0.19339661354259138, 0.21546402134962622, 0.034116304614731384, 0.11079843080933056, 0.06779793094122602, 0.07632375409406039, 0.031186688631292314, 0.030943584035060583, 0.0636197908240701, 0.11956435357851368, 0.020923673010040677, 0.018136846239588434, 0.0157596715801065, 0.0950895757564614, 0.04705563690813799, 0.03675666495016025, 0.0740122676436459, 0.02495296607394853, 0.027093423395267418, 0.047447184446237745, 0.07379001021505364, 0.11139192678514989, 0.03648434367571627, 0.1091014005003437, 0.4699536034416768, 14.572604413955444, 74.66350078582764, 55.05900436832059, 47.280567769081365, 29.867819240016324, 95.77940017946305, 51.94959248265913, 1.3651159742186147, 0.1432380945451798, 0.8976418909526641, 2.766215772398057, 2.8812177046652767, 3.672925570318776, 1.3021643844343003, 0.34188784959335483, 32.68919187207376, 118.82214038602768, 96.84517091320407, 106.63037054000363, 97.29978930565619, 101.1557851299163, 92.94249103915308, 100.06804127846995, 97.80079364776613, 95.80837080555578, 90.7802374132218, 94.80287905662291, 93.32416119114046, 91.07950641262917, 83.95634097437706, 80.55512828211631, 74.59594972672002, 70.66769599914551, 69.08111295392438, 72.27746025208505, 77.41937375837757, 83.58549656406527, 85.2154217996905, 87.6971681656376, 85.0196719938709, 80.0016975402832, 67.76407518694478, 61.56600075383341, 64.42100378774828, 66.9857043604697, 64.92314953957835, 65.5361375501079, 61.52431772601221, 63.35211869209044, 62.13049257955244, 65.08703401011806, 64.81902630098405, 68.93550672838765, 75.74423928414622, 75.9235151352421, 78.98718433995401, 78.65405744121921, 76.14781979591616, 67.96226470701157, 73.95940396093553, 74.95908275727304, 76.47289799105737, 78.2458406879056, 64.93252792666036, 64.7721500550547, 77.2468836076798, 77.02248481012161, 72.11898080764279, 74.35619877230737, 77.13680621116393, 71.48989538992606, 67.11254596710205, 62.846191775414255, 66.20106558645925, 59.46888985172395, 66.37842732091104, 65.82204695670836, 64.9480918915041, 66.65537018929759, 63.60282874876454, 64.75293436358052, 69.43228275545182, 73.77398567814981, 72.54324005496117, 68.0877491735643, 70.96461942118984, 67.02540659135389, 66.02084836652203, 57.77780309800179, 64.44966062422722, 68.0165110864947, 67.64010475527856, 68.57617055216144, 70.07883840991606, 67.60888268870693, 62.85617812987297, 73.4440751229563, 73.51784706115723, 74.17307115370228, 68.6331625907652, 67.14533698174262, 65.32478063337265, 63.25466348278908, 61.37156494202153, 60.689358865061116, 55.2733422863868, 55.82606700158889, 54.8982774057696, 56.271762001898985, 56.70315604056082, 59.25251230116814, 60.44538351797289, 68.3865317990703, 70.67024553975752, 74.99884774607997, 71.3862193015314, 67.30272600727697, 75.16232429012176, 78.21725445408975, 78.55646102659165, 75.90324432619157, 78.18124709590789, 78.12263119605281, 75.6746329030683, 74.63737780048002, 71.14768428187217, 70.63131209342711, 75.06242936657321, 76.6706560504052, 79.24466440754553, 82.07315614146572, 70.98956569548577, 75.37019421977382, 4.97904492962745, 0.3337143349551386, 0.1414149738247356, 1.8183869099424732, 3.780410525298888, 4.821704443423979, 2.8527868947675152, 2.006689973415867, 0.3311352846362899, 2.935740856393691, 37.2341186769547, 53.92620425070486, 54.62781821527789, 31.37212076494771, 53.54076077861171, 49.496051880621145, 62.00241542631581, 18.854088167990408, 0.24241767583354829, 0.1452729772896536, 0.007279174976922091, 0.02039288516126333, 0.020454455647737752, 0.061710676734125426, 0.06431134988463695, 0.055752014215554924, 0.05442497756091818, 0.13130765408277512, 0.03343312655605617, 0.06120540344366624, 0.14748776812226544, 0.22749339440657249, 0.194868988567783, 0.1902136561130324, 0.2208366725713976, 0.19454216013752645, 0.16686036972509277, 0.2902613682371955, 0.17448931842321352, 0.3012048729485081, 0.2433353265927684, 0.29117858998717805, 0.6194841909793116, 17.533706580438924, 89.43766501642044, 61.40312041005781, 46.91759555570541, 44.20118947182932, 102.89030428855651, 65.68662320413898, 2.4049620474538496, 0.13914467226113045, 1.4699106735567895, 7.397105241975478, 5.415025689909536, 15.846364709638781, 6.5736747172571, 0.9565921115779108, 34.294835675147276, 119.68604241648029, 103.16257169169765, 112.98166059678601, 102.08610073212655, 104.27651697589506, 101.37526527527841, 104.66647117368638, 105.86534361685477, 97.42545420123686, 92.7459724487797, 98.99641836843183, 96.10490983532321, 92.94302448149651, 85.80358120702928, 85.47645553465813, 78.03061239181027, 74.06923817050073, 71.46472946290048, 75.43638029406148, 78.26379729855445, 87.41503992388326, 88.30305668615526, 91.68802292116227, 88.65871367915985, 85.7340846523162, 74.42952356030865, 67.18012840517106, 68.76319700671782, 70.56028581434681, 68.24390657486455, 68.28476982731974, 66.06138998462309, 67.90279373045891, 67.21721049278014, 71.575481507086, 65.89679948745236, 74.27317004049979, 81.33811181591403, 81.46589479138775, 80.79983711242676, 83.72046532169466, 81.8661020648095, 70.99854007844003, 77.10581948680263, 81.56353042971703, 80.59191226959229, 80.52968778917867, 67.37139101951354, 66.22157173772013, 81.49310035090294, 79.6519241025371, 77.24502440421813, 77.32708823296332, 80.08315732402187, 76.45652601795813, 70.49419387694329, 63.30750565375052, 68.61663372285905, 61.559481774607015, 69.2042753773351, 69.48715671416252, 69.09478633634507, 68.61004414096956, 63.916430088781546, 68.18819322893697, 73.29133018370598, 78.7354701565158, 72.8368765308011, 69.94544644509593, 73.32837304761334, 71.31203943683256, 69.78814371170537, 61.12498121876871, 70.83852306489023, 72.06065516318046, 70.2657550381076, 74.98428006325999, 73.47007259245842, 71.87773935256466, 65.2074311625573, 78.01871192070746, 73.99910619181972, 76.63362887597854, 74.06388805758569, 71.5760463283908, 70.13790930471113, 66.38495414487778, 63.47691674386302, 63.54023556555472, 60.76411531817529, 59.4499408814215, 58.38149901359313, 58.75473214733986, 59.38383325453728, 61.32552808330905, 64.40822470572688, 70.79240383640413, 74.97745513916016, 79.6496726620582, 75.4327795582433, 69.47716251496347, 78.12589460803618, 82.05040639446628, 84.46340930077338, 79.71653338401549, 82.32013994647612, 81.60951629761728, 78.97917486006214, 76.38870823767878, 76.521009783591, 73.11972648866715, 79.64029035260602, 77.96891350899973, 84.44804145443825, 84.25022063716766, 75.28987192338514, 76.38024376284692, 4.618511449906134, 2.226793775635381, 2.1883444968731176, 4.380727564134906, 6.8927149138143, 9.421936177438306, 6.238930331122491, 1.9482158917573191, 0.4450603117865901, 4.930291339274376, 53.93380580409881, 62.44783193834367, 71.79484398134294, 56.88404790816769, 57.19196965617519, 55.0602085359635, 72.45916797268775, 23.63831093234401, 0.4847250962930341, 0.2920044327695524, 0.17179501783703605, 0.19500070972548378, 0.1841016840790549, 0.2573639899492264, 0.18372763398914568, 0.11074198545106959, 0.16250177376693295, 0.24999934158498244, 0.16426751450184854, 0.19237016297636494], [0.049659477832216414, 0.045295821863316724, 0.07260496412674267, 0.12530203803532547, 0.06315636508647474, 0.038481339541894775, 0.016543345052688833, 0.03585212578576419, 0.029558751792196306, 0.1244197958599656, 0.03633406403804979, 0.07610300585867898, 0.2046931009258955, 25.41460725568956, 60.964913214406664, 48.24627491735643, 29.586789261910226, 39.452536721383375, 94.13533087699645, 22.27955287502658, 0.09848478550632155, 0.14673360052608675, 0.25748699302634886, 0.9363510880258776, 1.7751087032018171, 3.17244045196041, 3.240849284395095, 4.568760596936749, 91.03691731729816, 96.371136788399, 98.5394936223184, 92.78874981787898, 93.91617236598846, 90.93371975806453, 90.24040160640594, 89.6076762291693, 92.47004939663796, 94.18381137232628, 92.59736168769099, 88.11796788246401, 90.1247936679471, 81.97870546771635, 79.58662448390838, 72.72556751005112, 68.92723837206441, 63.66762630401119, 66.6260700841104, 65.24833363871421, 74.98144026725524, 81.59126158683532, 85.3845936252225, 81.05425773128387, 80.74362170311713, 71.30713647411716, 60.736176275437884, 58.1435876507913, 60.19574034598566, 60.22585630416871, 64.03997690446916, 61.34799149728591, 59.24610707067675, 56.824969168632265, 58.748770144677934, 59.50574051949286, 64.02066707611084, 65.5316032901887, 73.26690950701314, 73.6706155346286, 76.69262916811051, 73.76535646377071, 69.63333560574439, 67.6582496396957, 73.0328538340907, 69.04092434913882, 77.0587275105138, 65.26730222086753, 63.8384259131647, 70.54250178798553, 72.28619144808862, 69.64679718017578, 69.20339676641649, 75.01725935166883, 68.94095882292717, 61.44765892336446, 58.411920916649606, 63.746297282557336, 64.411664624368, 63.86827122780585, 62.97254700814525, 60.69491294122512, 61.925897828994266, 70.42138684180476, 70.11884658567368, 67.11378543607651, 63.44143890565442, 59.17020136310209, 63.39710435559673, 70.14061574013003, 67.225674967612, 66.03169764241865, 61.08562023408952, 55.07756894634616, 54.16617878021733, 62.43999112036921, 65.20820779185142, 68.37697690533054, 67.21729678492393, 65.33638692671254, 60.725036744148504, 66.99051318630096, 68.21852883984967, 64.34066972424908, 64.72333615826022, 64.19447514318651, 63.68475137218353, 64.6847596476155, 58.40503323462702, 59.69644615727087, 58.347225343027425, 52.542952952846406, 52.33333756846767, 55.71731144382108, 53.03489269748811, 57.44846128648328, 55.30896917466195, 65.97301113990046, 68.25492059030842, 71.27593009702622, 65.43503845891645, 71.01416680120653, 71.55973711321431, 70.46683926736155, 70.62806437092443, 71.41511148022067, 72.467436329011, 72.67916587091261, 73.81699838945943, 71.07064108694755, 69.42144916903588, 72.63456852205339, 77.35832598901565, 80.38698411756947, 74.75656294053601, 79.21325406720563, 78.31441940799837, 67.31119048210883, 50.41314125061036, 0.397611522386151, 0.940374336656063, 3.232421826931738, 5.197476331264743, 2.2018014134899264, 1.571638937438688, 1.7540622454497123, 0.5247475519295662, 0.1650286228546212, 32.77636262678331, 37.526754948400686, 65.23457004177955, 31.228071720369403, 30.98375120470601, 42.81119954201483, 45.21578111956197, 19.286380429421705, 0.1077046077097616, 0.1648050324330407, 0.015238743282914644, 0.13410864007328788, 0.06359071395690404, 0.16278176358149898, 0.04590071339700972, 0.09083279288343846, 0.1312486959561225, 0.03870422516258494, 0.05019535250481098, 0.059416404279369506, 0.020807287017364177, 0.040891540251792445, 0.033257772860627983, 0.2141061305038391, 0.09019255788335878, 0.057055325127176704, 0.015399058672389197, 0.03680348441365265, 0.07502628460286126, 0.17987508507024857, 0.05211405801556764, 0.025247865874740868, 0.21782764774416724, 33.91496196869881, 69.67612866432437, 63.726614829032656, 40.170852138150124, 43.21682753101472, 107.83108649715301, 26.05580887486858, 0.04306493552341577, 1.230157022514651, 1.1008981326895377, 3.591929852001129, 2.7099118646114104, 3.860350635743911, 1.8986406874272133, 7.418505693635634, 100.21241587977256, 100.92217660719349, 104.02649725637129, 97.2605577591927, 96.9081327992101, 93.12434780982234, 97.10203124630837, 93.3760541485202, 97.84601857585292, 93.95956946957497, 95.82036541354273, 90.05773682748118, 93.79501819610597, 83.66274372223886, 80.9877343331614, 75.39618384453559, 72.37034197776549, 66.10304555585309, 69.81202310131442, 69.2860960191296, 77.6014188028151, 83.83680282100555, 87.27562319847846, 83.4721165318643, 85.20291728358116, 73.73018064806539, 60.797537834413596, 61.7677164846851, 63.53774878286547, 63.51827813733009, 66.0108070988809, 65.8999530730709, 60.574405962421054, 60.45993943368236, 61.416087765847486, 62.472476190136334, 66.50027967268421, 68.545772183326, 75.17853936841412, 76.41909091703354, 78.98279128536102, 77.48920763692549, 73.46891941562777, 69.99427995374127, 77.21303355309271, 73.06536243807885, 79.30599458755987, 66.39261061145415, 66.83677980976721, 73.8139703196864, 73.91767778704244, 72.06364400925176, 73.41667344493251, 77.23648148198282, 69.33247412404707, 61.685954678443174, 61.4604615396069, 64.9475545267905, 66.04050728582567, 63.83502914059547, 65.06063645885837, 62.47762233980241, 63.27359676361085, 70.79996616609635, 71.80330061143445, 69.01819029162007, 65.1886430094319, 60.47826082475724, 62.93272318378572, 73.49972571096113, 72.05724270113053, 69.18333776535528, 62.06791508582331, 60.47556615644886, 58.90630822027884, 64.53674508679298, 67.66657290920135, 70.0777401462678, 72.25330629656392, 66.63859028970042, 66.45423889160156, 67.5875057712678, 72.54690354870212, 71.09914102861958, 67.14722756416568, 69.88458694950228, 67.1088824733611, 68.25545403265184, 63.929268006355535, 62.90894969817131, 63.197867562693936, 55.96707620928365, 54.80896503694596, 57.4399575879497, 55.520039758374615, 57.369547120986454, 58.80982575878021, 67.96807765960693, 71.26850112791985, 74.6398881173903, 68.83895366422593, 72.28639541133758, 75.97235648862778, 73.01840382237589, 72.72880738781345, 74.13964471509381, 75.12011958706763, 75.24886746560374, 76.9155845334453, 74.87487731441375, 74.93086522625339, 76.94727728443762, 79.35741686051892, 81.99065300726122, 79.58546346233737, 81.25534980527817, 82.23263186793174, 72.85509201788133, 63.8289886905301, 0.7810651883482934, 0.388922430574894, 1.2207378182680377, 6.669761509664598, 5.456118891316076, 2.806688258724828, 2.1403270863717605, 0.3521542857971884, 0.11788278292383879, 33.591801812571866, 43.976978948039395, 72.64826543869512, 28.62882487235531, 30.136162311800067, 48.17585660565285, 53.93994039104831, 24.75510777965669, 0.24445752282777142, 0.1182463835744608, 0.0342807836920744, 0.06278365181999342, 0.0439444848997218, 0.06030270672072807, 0.09148180725113039, 0.02430932772826524, 0.04748888261195633, 0.056415748962711905, 0.09172685579546998, 0.05456563130381608, 0.17963225052001017, 0.13567285371884225, 0.1180247466770872, 0.3214859782207397, 0.10445176007887048, 0.1845269241640645, 0.0761065375240099, 0.20452974033692192, 0.12619901208146928, 0.35374373437896856, 0.12242688707286313, 0.2067848273943509, 0.4002583255210231, 41.96433628759077, 83.98656675892492, 65.14011544566002, 41.35379583604875, 56.00773549848988, 115.81759698929326, 35.29822895603795, 0.26804055898420276, 0.7472622634903078, 4.326208579924799, 6.683083349658597, 6.928180004319837, 17.24695190306633, 6.496992870684593, 6.803510410170402, 106.52103054908015, 103.73053089264901, 108.98925258267312, 102.16221040295017, 102.45534481540804, 98.91217370187083, 102.21122434062343, 97.95833172336702, 103.81688579436272, 97.62944098441832, 98.45017340875442, 93.96510785625827, 98.33431443860455, 86.87698487312564, 84.87920407325991, 78.54740819623395, 76.16190894957512, 69.52282674850957, 74.29557461892405, 72.38628249014579, 81.00646757310437, 87.12101905576645, 92.21491490640949, 86.56943967265468, 89.70310749546175, 77.79346589119204, 65.29346835228705, 64.46890769466278, 68.00186495627126, 67.16663545177829, 71.36900009647493, 69.89604811514579, 65.88747993592294, 63.28797617266255, 65.53446269804432, 65.17306335510747, 71.58690344902777, 74.65740542257987, 81.38248951204362, 78.87391413411787, 82.72857635251938, 79.81981723539292, 76.42499800651305, 73.03305779733967, 82.26723501759191, 78.01326767090829, 84.55997805441581, 68.76034936597271, 66.5875602537586, 78.13067205490606, 79.28797521898824, 77.8291908387215, 74.40806819546607, 80.64592330686509, 73.42965649020287, 62.28628912279683, 61.059881641018784, 67.21889711195423, 69.92282221394201, 66.78096448221515, 67.71153111611643, 65.76421945325791, 64.23836646541473, 76.07194546730288, 75.11866046536353, 70.27295650974398, 67.0274148448821, 64.18046051456083, 68.64997386932373, 75.89208126068115, 74.26221093823834, 72.63442731672718, 66.14535224053168, 62.66601770154892, 64.10639832096716, 69.52333665663197, 72.87139338831749, 74.0551176378804, 75.05702434047576, 72.18755952773556, 65.88462445043749, 72.42465895991172, 74.28743962318667, 71.59581507405927, 70.71972231711112, 71.9747866353681, 70.80338647288661, 69.78042448720625, 65.73640592636602, 64.7995085870066, 66.20256393186509, 61.29235267639161, 57.08628139188213, 61.814973200521166, 60.24586431441769, 62.98614978790284, 62.56687979544363, 71.64133810227918, 75.30416504029306, 78.20341633212182, 71.08938217163086, 74.48180090996527, 77.60851044808665, 75.46336620084702, 76.3355444323632, 78.80019710909936, 78.71083767183366, 78.75320711443501, 81.1023695238175, 81.27408304522115, 79.6285467763101, 78.48937280716436, 82.5224950236659, 87.04147338867189, 81.4775912992416, 84.65800592976233, 85.91094432338592, 74.97059883609896, 62.83381277515043, 0.6182369998385829, 2.384932464168918, 8.104378206114616, 13.932106860222357, 7.507308154336869, 6.4778703355020095, 3.369660411150225, 1.1445135406909452, 0.32412395602272404, 44.39992420135006, 51.81423933275285, 84.31191167523785, 46.312942581792036, 38.46588019401797, 55.03098687817974, 61.96261121380714, 31.63751421436187, 0.5899647394976308, 0.3233193185540938, 0.11703365106856632, 0.21310322948040503, 0.09734980326386229, 0.1859690540380055, 0.212059312109505, 0.14926066411839378, 0.19425470862657795, 0.19843445369793525, 0.20486139512110144, 0.11166727410689478], [0.037857510314713565, 0.04377720960145516, 0.015393306309687755, 0.05294034129849846, 0.06497735608248942, 0.04744869363944858, 0.06281331091398193, 0.07091895016210695, 0.039847339428360426, 0.04203377734689463, 0.02488513664913274, 0.06682892930844138, 0.1781821686534151, 43.98578859144642, 55.290090807022594, 38.48369167697045, 36.00432226734777, 57.12488535911807, 77.71872904992874, 8.530297106312167, 0.036978681061056354, 0.2766132054309691, 2.241696821105096, 1.8178322622852943, 3.09534038266828, 3.04228370708804, 0.6895975384020037, 40.906065125619214, 105.98757251616448, 91.03119065684658, 96.23179851039764, 87.52218338751024, 92.38269821290048, 84.73027952255742, 83.43866655903479, 84.57330626826133, 93.90799814654936, 86.23429667565131, 94.62327372643256, 88.4299139822683, 89.45487637673655, 84.3530494936051, 75.1325221215525, 69.02750199840915, 65.92724492472988, 63.43400601417788, 65.21626826255553, 69.30068723617062, 74.63987242790961, 81.39327603001749, 81.76993339292466, 81.21456500022643, 76.62357191885673, 62.843783440128455, 57.377105528308505, 58.985575399091175, 60.72739408862207, 61.59348087926065, 61.809858429816465, 62.061807955465014, 58.15893588527557, 56.59338851128855, 56.18398327981272, 57.853861778013176, 58.80319303081882, 66.19338558566186, 66.6382686553463, 73.75177721823417, 74.17524414677774, 73.71068646830898, 68.50100225017917, 69.91434204962947, 68.44680293913811, 72.89098170495802, 69.93135729143697, 67.20578855083835, 67.63446438697078, 69.16931921435942, 66.70849477091144, 72.12333463853406, 74.23653510309036, 62.93437842399844, 61.18518567854359, 62.66634718064339, 64.04877478076567, 63.314232518596036, 63.001545090829175, 65.08072291651081, 64.18202946262976, 63.288792025658395, 67.33352445787, 65.87964304031865, 64.54348371874902, 72.04021961458268, 69.34708103056877, 66.07102332576629, 56.230526124277425, 64.61203498225059, 65.34873062564482, 62.508134457372854, 59.85283497841128, 59.54357570217502, 55.849534542329856, 55.00595038936984, 60.42925473182433, 61.324578869727354, 67.17747688293457, 67.33675649089199, 62.67126583283948, 68.8144466953893, 63.84371719052715, 56.795088552659564, 65.94821391567108, 64.33167572944396, 68.0596257794288, 69.1835887970463, 68.13198566436768, 62.58008249344365, 63.775891565507465, 58.108678556257686, 50.986434874996064, 51.52210512468892, 52.45952806165142, 54.87908524851645, 55.863407965629335, 61.50109729459209, 69.83015229625087, 69.55217392213883, 70.33893077604233, 70.29033260960733, 72.21370604730421, 67.97937408570321, 67.65865756619361, 68.59708462992023, 72.55004144483998, 69.974424915929, 75.91579591074299, 67.73686178268926, 77.50114733173002, 73.34370167024674, 80.25680849629065, 72.78856861975886, 83.61242755766838, 73.84044631834954, 82.41817566656297, 72.33518185154085, 82.31158133476012, 25.258163521366736, 0.2374536712323466, 1.5500408963811014, 2.2007771845786803, 3.919534298681444, 1.3710366694196578, 2.499344079725204, 0.2582589645058878, 0.4414328548216051, 11.867739904311396, 52.584133917285556, 43.10524786672285, 53.82207316737021, 38.95202267554499, 49.43966388702393, 42.324201983790246, 23.460825643231793, 0.10994481733970105, 0.09447404709193977, 0.14809967319090522, 0.019145749561909228, 0.08795837736538342, 0.24761671620991924, 0.0655765900568616, 0.1288662850856781, 0.08364628294422742, 0.08617677094955599, 0.009192768766003992, 0.014278012526882513, 0.13563237363292327, 0.04056422535570399, 0.078305876363189, 0.11873327075473725, 0.0419491361225805, 0.021979543267779296, 0.07866046781982146, 0.10775749075917468, 0.054811082044315916, 0.07788079715664349, 0.0436910591839302, 0.050008120616116834, 0.17778306748838196, 57.2558101530998, 61.819056387870546, 49.48613220645536, 33.11886595141503, 59.73295557883478, 93.50154645981328, 9.614780487552766, 0.08370151788356804, 0.641339085996151, 1.7093278587825838, 2.032413244728119, 2.4480286913533367, 5.498310356370864, 0.9319690650989934, 48.60720749824278, 111.50468426366007, 94.86674308776857, 101.96147918701173, 93.66224596577307, 95.49144329563265, 88.5660594509494, 86.6323466454783, 89.777114775873, 95.05498547707835, 89.7945144099574, 95.50417530921199, 91.48503242000457, 92.19009414795907, 88.73659626130136, 78.97128305127545, 71.08484006697132, 68.98104544608825, 66.66268933203914, 66.75247238528344, 70.52336062154463, 78.22061200295725, 83.7027754322175, 83.81337058159613, 83.08680642035701, 81.10828445803735, 65.07605137363558, 61.22125579464821, 61.27096791421214, 64.02216149914649, 64.98868057804724, 65.61171770095825, 66.49192502421718, 60.49282458520705, 60.09391953868251, 58.94991713185465, 62.03831295813284, 64.05492113482568, 70.32432386952063, 71.63278733530353, 76.30283970986643, 77.31600361485636, 76.74662451590262, 73.2287605347172, 72.97925072331583, 71.7419861209008, 77.36907328328779, 71.4050074546568, 70.51779085589995, 73.64130758470105, 71.1775335188835, 71.59816849616267, 75.05347067309965, 74.57517685428743, 64.8172612344065, 63.38531371085875, 64.46498924686064, 66.98102105048396, 65.84045071755686, 65.32355293150871, 69.96599182005852, 66.56880347959458, 65.43857643681189, 68.72157281444919, 69.30951256905833, 67.40061267729729, 71.97323337677987, 70.68151058689241, 69.31014799302625, 59.81200702728764, 65.18439900490546, 68.17796368752757, 65.41852135812083, 60.93224379324145, 60.64787980048888, 62.102934006721746, 61.366363879173036, 61.94514489942982, 61.475150815902225, 68.7948662234891, 72.06289091417867, 64.20380646182646, 73.58833205315375, 68.95337704689273, 59.389010783164736, 68.69322976758404, 66.46871243753742, 68.67717942883893, 70.51688871076031, 70.50672977201401, 66.3719710996074, 67.2830984669347, 60.820111074755275, 52.769207031496116, 54.42070922543926, 54.768403806994044, 57.026888862732925, 59.314842685576416, 64.91336322599842, 72.14151090191257, 71.41953591377505, 74.32480412144815, 72.10484458554176, 72.18377836288946, 70.55939935868787, 71.15817269971295, 70.4655448852047, 75.52892469590711, 73.62523371173491, 79.46974569751372, 73.1964402044973, 80.82352822826755, 74.98655503795993, 82.49005702234085, 76.38849642968948, 86.32648021944108, 76.97780116911858, 83.72397976536905, 77.93814643736809, 87.33358798488494, 35.814330500941125, 0.35502585912904433, 0.48205141879377833, 2.6065338763498493, 9.165114087443198, 5.063138584936819, 4.362510115869584, 0.5418244484932192, 0.4567035305644236, 10.335006098593436, 60.19766622974027, 51.136222347136474, 52.451012596007324, 29.313600101778587, 56.40556189321703, 49.03837403943462, 31.7504176785869, 0.22672980392892517, 0.1603634844744398, 0.16534959837313623, 0.0458911526197147, 0.023847909141031486, 0.057233773817818974, 0.048623554588806246, 0.02717047268825193, 0.13101039664639583, 0.07847960978265732, 0.0434646763718657, 0.03467299772666828, 0.16424385770674677, 0.18339130606862808, 0.2611200577549396, 0.1478146425177974, 0.17473935419994016, 0.15773785600979484, 0.20726753939544001, 0.21443709580888673, 0.12040253037646895, 0.2437742183645887, 0.15503699771098553, 0.17443979849978802, 0.5674440221440408, 63.811800864435014, 76.45524732528195, 50.5864001858619, 54.90687916355749, 75.54555554543772, 101.06012636615385, 15.774763803328238, 0.22982453867312402, 0.4616749202532153, 5.291925534125298, 7.066346964528484, 9.537136189399227, 11.307287139277305, 1.6083209432901877, 51.990942109015684, 114.2329986633793, 98.11161794970113, 105.44819954902896, 98.25738891478508, 99.34907082588443, 93.26632976531984, 90.19261929296678, 95.57172636831962, 100.00253769659228, 93.69241683713852, 97.62689144380631, 93.65717826351043, 96.44578733751851, 93.6776844147713, 83.53277990894934, 76.59658601207119, 71.95940309955229, 69.39152148462111, 71.41439760884931, 74.27611966286936, 79.9834349847609, 89.17874936134585, 89.00862832223216, 86.88577882705196, 84.84300059656944, 69.59353139323574, 65.4040870358867, 65.55252913505801, 67.19305653725901, 69.39240794028007, 70.53054640370031, 72.04039219887026, 64.613478414474, 63.837574758837306, 64.19112543905935, 65.46398947315832, 66.94806529629615, 73.09810638427734, 73.4210115863431, 81.81069466375536, 79.67818044847058, 80.11689755224413, 78.0085765161822, 76.56216329143894, 75.36125906052129, 81.11328940237723, 77.54090447579661, 71.5080088953818, 74.89859980921592, 74.69826083029471, 74.12715588846515, 78.01538575080134, 78.55534707346271, 67.59061228844428, 64.32457623943206, 66.10125695505451, 69.7825425670993, 67.76285925219136, 68.64624761766004, 72.12261292242235, 70.81481625956874, 66.74433738954606, 71.8025004479193, 71.91920665002638, 71.04948382223807, 79.1264049468502, 73.98617021499142, 69.46444619086482, 58.14257175691667, 69.21482655309862, 70.61342608544135, 69.14066237788047, 63.07885500692553, 65.92362065469065, 64.82641212401852, 63.79262047429239, 69.2741798585461, 64.14615938740393, 75.01015201691659, 75.6918050396827, 68.99751155607163, 74.16899973346342, 67.53699348818871, 64.62333925308721, 72.25761305901312, 69.61675182465585, 74.97723548643052, 75.51594949537709, 73.4031883362801, 69.72579371544623, 70.7729410356091, 61.97158951913158, 55.76980060146701, 58.070619798475704, 58.76592266944147, 62.131657523493615, 61.92625084230977, 69.80573946429838, 74.53840855629214, 77.26545995281589, 73.85546115136916, 77.1065176686933, 75.74613771130963, 75.67870432330717, 73.87770883498654, 74.85518701614873, 79.32009158595916, 74.82241169098886, 83.045378346597, 77.0795709856095, 82.18619884983187, 80.50973861448227, 85.76878978360085, 80.00743989021548, 89.71476477961387, 80.90285424263247, 89.08533419332197, 83.07845961663031, 89.36188482469129, 36.04879802273166, 0.7328022007019289, 4.800495207309723, 7.116937204714745, 13.275595249668246, 6.641597911234825, 7.779252452235069, 0.8786589063463673, 0.45256374463919674, 15.680955417694586, 72.89859110309233, 58.27424180123114, 78.99810421851375, 49.76576582078011, 61.69461134941348, 60.527568940193426, 37.566653297793486, 0.2388877112178072, 0.3976195509875975, 0.3041618497621629, 0.1946184778165433, 0.14016287972129163, 0.2653040622751559, 0.13954581122004217, 0.19834652212598633, 0.17532763311699515, 0.18090247026374265, 0.10536419377932627, 0.18286610683125837], [0.04885631891328001, 0.08738162041070961, 0.11856113079815142, 0.0543592625387734, 0.026964421849697832, 0.013297317519543633, 0.0975378855101524, 0.026171735352686337, 0.05554257726837551, 0.12818288103106523, 0.11799304595878048, 0.05998219468540723, 0.8532214164733888, 53.90417229744696, 52.89284013932752, 35.90130513714206, 36.389287210279896, 77.68721672796434, 51.37826396572975, 1.8349101394414904, 0.01751740478099354, 2.1071239777149695, 0.8748246056418266, 0.8461432543493087, 3.8265493656358416, 2.2818155586719513, 6.219659726465903, 81.31352639967396, 96.80247199150824, 92.18485386140885, 89.8476311468309, 89.38488560338175, 90.4927747480331, 86.36476255232289, 77.78772354125977, 78.95256550081315, 86.15584142746465, 90.59106149981099, 87.97051814294632, 91.5939566396898, 89.87129872845065, 84.48892824111446, 75.70854571557815, 67.47133301150414, 63.058395924106726, 62.71117202697262, 62.678941911266705, 69.67430083982407, 74.11193709219657, 79.9389317727858, 80.52307467306815, 78.22365576221098, 69.84957587334418, 58.403040670579486, 56.882553485132036, 56.832492274622766, 58.87697673613026, 60.37318445021107, 60.65070390701295, 63.18491197401478, 60.870956759299006, 56.884514670218195, 55.436050045874815, 59.861668156039336, 64.39579863702097, 64.42114499307448, 69.15837580157866, 70.2897991672639, 73.9134180930353, 73.60062476127379, 70.06413736651021, 71.39420524720224, 72.17037170164048, 71.39389930232879, 66.32270613024312, 73.35373509314753, 67.81617995231383, 65.53740055330339, 69.9663056096723, 69.58105041134742, 63.1132738051876, 64.05527022577101, 67.3309592277773, 71.83098470011066, 67.05935862756544, 65.04251903103244, 69.29090484496086, 69.07986564020958, 62.93713585022957, 65.55082290403305, 70.14306329911756, 67.90485689716955, 64.52603701622256, 65.57332161934146, 65.12166461636944, 71.02967585286787, 67.8078096143661, 60.25805896328342, 62.54252579904372, 64.56721405829153, 59.915102604896795, 55.99871404709355, 56.18045314665764, 60.94880404010896, 56.76580413695305, 52.33163133744271, 61.67436799695415, 67.68747129747945, 63.1890461521764, 66.29339818031558, 47.29747318452405, 59.69465363410212, 62.11174757249894, 63.76865479253954, 66.40257343169182, 64.5739330783967, 63.77751934912897, 65.43078268727949, 66.14482664292859, 65.33741458769768, 53.41519786465553, 52.13089619913409, 53.65618828804263, 53.97226464363837, 55.55695318406629, 65.30812232725083, 67.38963788555515, 69.11975614486202, 68.26301636234408, 69.67605806166127, 66.21710808046403, 64.78831806490498, 61.282232961347034, 68.83237192707678, 67.75194721837198, 72.42770271916544, 69.9516830136699, 71.88195197812973, 74.88931163664788, 73.68292393222933, 74.28976166632869, 78.05389558115314, 72.96281599229383, 74.53741227426838, 77.9540006576046, 77.86142487679759, 77.10458786256852, 75.69343674567439, 7.637917687816005, 1.4778551891926797, 3.9745555914217428, 3.7347303571239596, 2.51739727873956, 0.5271824245010653, 0.25400006723019386, 0.024200671562744726, 0.8729847075958407, 52.35760135035361, 43.01774763291882, 48.88084380857406, 29.96757688060884, 28.294729148187947, 56.12443385585662, 24.64717003606981, 0.033637844401622014, 0.026079224490170038, 0.057160440051267226, 0.10098512795182968, 0.037213961984361374, 0.03597746543105572, 0.012026692706821187, 0.02904834571264444, 0.07668766884073135, 0.07405158327591997, 0.06858990497646794, 0.029558634963787855, 0.13164595851013738, 0.07486184382991445, 0.06605459061721641, 0.04536559715146019, 0.04103753362752257, 0.046326110530043804, 0.0857837678444001, 0.011062153536195477, 0.022216848578424226, 0.13536228167433895, 0.16936394506164137, 0.11767112049123934, 2.7753436180853077, 67.79539923514089, 61.64011786060949, 44.69189366986675, 28.74433082918967, 86.05762527834985, 60.87377302108273, 1.427577145157322, 0.15005975511045228, 2.079272698010168, 1.8963513715613274, 3.0060495868805917, 3.953364496269534, 2.335570170994728, 8.722721722818191, 91.19321592392461, 97.23425434481715, 101.95747052469562, 93.37443028726886, 93.42995535942816, 91.33566071910244, 89.54635389389531, 82.85418633491763, 81.70311973940942, 87.22525212072557, 94.64798465851815, 90.81728027712916, 94.40373082314768, 90.21835004129719, 87.05516246057327, 78.18785236727807, 70.45763738693731, 65.08401378508538, 66.12987456783172, 65.85683838013681, 72.1377375818068, 77.57711579722744, 84.1919969743298, 82.08224819552514, 82.29057312011719, 74.45384225537701, 62.74756769980154, 59.319125913804584, 61.40634852070963, 61.132351352322495, 62.564898998506614, 63.99488141459804, 67.00378648696407, 62.58287522100634, 60.748712170508604, 59.78540943514917, 64.18008788939446, 66.28046220348728, 67.7344456026631, 73.31691972671017, 74.93384622758435, 76.536510990512, 77.39139156956827, 72.2301721572876, 74.00313054361652, 75.4265037659676, 74.64332411366125, 70.98026967817738, 76.03746783348822, 70.76882254692816, 69.0039050194525, 74.94346387924688, 71.55160996221727, 63.41932066025273, 67.45318028234666, 73.04567213981383, 78.3776480151761, 71.69472940506475, 68.24050980229532, 70.92467400335497, 72.23298841907133, 66.7748220505253, 68.66008573962797, 73.5996598582114, 72.84374067860266, 67.43915388661047, 69.77687081983014, 67.51174126901935, 72.37837499187839, 69.44045697489094, 63.587378532655784, 64.91532833345475, 67.22776166854366, 62.261138885251945, 57.78984869680097, 57.67243254569269, 64.84442757021996, 59.433631666245006, 55.84300379599295, 61.61701510029455, 68.01390663270028, 68.19386497620614, 70.98986379561886, 49.13063603062784, 64.55741597760108, 62.67608250341108, 67.30104723284322, 68.24563241774037, 67.75291996617472, 69.15918380983415, 69.18177666202669, 68.477734750317, 67.30237299396147, 57.22641983339864, 54.543518635534475, 55.79801028774631, 55.324478226323286, 58.47234895152431, 67.1797675471152, 71.12811165471231, 71.58069041467482, 71.1107983127717, 73.07014772968908, 69.28947710221814, 66.20595285969397, 64.08457033095821, 71.7956284553774, 70.82638725157707, 76.03219616797664, 74.45158297015776, 76.64323868290072, 77.4887526419855, 75.98490807317918, 76.54252006161597, 80.88420729483329, 77.04509335179483, 78.00812936598255, 79.2772279247161, 82.44647948972641, 79.36810924160865, 83.9532030782392, 12.306915925395105, 0.5893466597603214, 1.5439069223019386, 4.01220495181699, 3.875482159276163, 2.345230478432871, 1.6374641536704957, 0.0845821972395624, 0.3873718686161503, 53.311541388111735, 54.41856761132517, 49.41922049368582, 29.713403371072587, 34.25901659073369, 64.74073186997445, 32.12918919901694, 0.06707828326691544, 0.0604621411090897, 0.10062264578957712, 0.0838163927678139, 0.018358350986795082, 0.02820934153973095, 0.009401737441939693, 0.05053488650329171, 0.07320524764157112, 0.03916701504720315, 0.031139897896097075, 0.045452655383175423, 0.1913303211932221, 0.21280368910201136, 0.19264785452715813, 0.1300373577302502, 0.15321589946266145, 0.13765437077851067, 0.21448113054277437, 0.2218309014795288, 0.1478747191328195, 0.23358137256676154, 0.23284343071281913, 0.2339889773077542, 3.5357732782440805, 80.16300109124954, 71.91515091926821, 48.32187860242782, 54.89790478060323, 95.52622687432074, 72.88358411481305, 3.2547084891027023, 0.16437574740379088, 6.01120928602834, 4.174759003423875, 7.364362276369526, 12.194094830943692, 6.108722840586017, 8.47440823431938, 96.24233399668049, 102.15365179123418, 106.85102739641744, 97.60043113462388, 99.91568857623686, 95.33240687462592, 95.30893541151478, 86.12847897314256, 87.35399999926167, 93.18843149369764, 99.86910650807043, 93.52887753517398, 97.6400706075853, 94.92399400280368, 90.55992572538315, 81.7867603609639, 74.26261101999592, 69.28479379223239, 69.9649876932944, 67.6306047747212, 77.61732793623402, 80.19756501720798, 85.79404984751056, 87.95841370859455, 85.64587839188115, 78.31270925460323, 65.178880230073, 62.38415225859612, 64.65914657039028, 64.910758772204, 64.71445198981993, 67.2496328046245, 71.60036502345916, 66.20978109298214, 65.28734553244807, 63.348357139095185, 66.3859582716419, 71.8245598577684, 73.93467733936926, 78.09324479872181, 77.36579418182373, 79.52396069803547, 80.15363447127804, 77.22031347213253, 77.25415568197928, 76.80811159072384, 78.49057305243709, 73.82984807414394, 79.0495264914728, 74.5508267802577, 71.67500772783833, 78.65373580686509, 73.29779424974996, 64.76285403774631, 66.87988665796095, 71.97440224309122, 77.37331728781425, 73.70739167736423, 69.69885487710276, 75.89438761434248, 76.25290793757286, 69.00847065833308, 70.35372595633231, 78.08818494119953, 73.49001392241448, 70.38672093422183, 70.77964828860375, 69.78200912475586, 78.2714694546115, 70.86954116821289, 65.27589613391508, 67.5939541478311, 69.80736332554972, 64.6253357395049, 64.25428736594417, 64.20760723852342, 67.10201832555956, 60.2077074973814, 60.48578785311792, 67.43108164879584, 74.23914740162512, 70.89350684996575, 70.22050657579976, 52.54298433180779, 66.73467266944148, 65.71156555606474, 71.42952226823377, 71.08191397882277, 71.01044839428317, 72.81978284159015, 73.8422506086288, 71.962446858806, 73.50425997088033, 60.20554627141645, 58.99562058910247, 59.22231005084131, 59.15716732701948, 60.9354522920424, 71.28135081260436, 73.30623519036078, 75.92990075388263, 73.95968637158795, 76.18114425290015, 73.18918381967853, 71.06958989174136, 68.24935082466372, 75.71712786151518, 74.565151276127, 79.19784699716877, 77.82860248319565, 80.07271597462316, 81.2588877831736, 79.06153678894043, 80.761350816296, 83.9776159101917, 80.84862355263003, 80.47004422833844, 83.87396335601807, 84.86289485808342, 83.9096490798458, 83.25895140247961, 12.337800668131921, 2.845599641723018, 12.210079469988424, 11.720562769520669, 8.245880161562274, 6.063975951363964, 1.684482585518591, 0.19345440721559912, 1.0138034351891088, 67.27463399210285, 59.016315014131614, 64.41617927243634, 44.70790870728032, 37.22175928854173, 76.60304223337482, 37.15917395007226, 0.1788403760761984, 0.19162027015080377, 0.15335745718931, 0.20484889256617717, 0.1715793640863511, 0.15020030160104075, 0.20276534791675307, 0.08613180158840072, 0.2249169947519418, 0.1530446175245508, 0.17581172407634799, 0.14597457593246815], [0.029844201898442644, 0.053733556396177704, 0.0245926347035434, 0.04085839928818807, 0.011578002670449356, 0.06268088495539081, 0.07351446371044844, 0.036438179217399135, 0.1657845677747842, 0.06711433536463207, 0.1278426307403753, 0.16027186035869584, 5.357123171129535, 68.45616171436926, 43.86531299160373, 42.11754014415126, 45.637832072473344, 74.96039282891059, 31.23006428441694, 0.17774073346968622, 0.20124351425516993, 1.778028172350699, 0.5374889424250973, 0.9408178096336703, 1.4134485226485038, 0.7369288405583752, 29.308663798916726, 103.20762403549688, 90.46813441861062, 90.33486012489566, 84.79288055050759, 90.5532733855709, 86.36332696483981, 82.84578461800852, 76.00676351977934, 77.44814826596168, 76.44079731356713, 83.95561925826534, 88.64515796784433, 88.94801201358919, 85.44984617540914, 82.88516521453857, 77.20971522792694, 71.05534384327551, 62.160110396723596, 62.45374295019335, 66.1580293409286, 69.054472215714, 77.06906687828803, 81.41645723773588, 77.73662290265484, 79.3446534679782, 68.94018219363305, 57.22138743246756, 56.39796033982308, 58.70594570713659, 57.905943009161184, 58.58085347760109, 62.58991195309547, 64.48585233380719, 59.92122150236561, 59.04703893969136, 62.518399300113806, 63.0042476038779, 66.2461414644795, 63.98331826733005, 67.27401425761562, 71.68053042504096, 71.60348723011633, 73.35129537890035, 70.1383799891318, 69.73075159134405, 68.9701569464899, 66.07592628848168, 69.52094401082685, 69.9310984150056, 64.2724047937701, 67.21552387360605, 71.59559542132963, 63.900242467080396, 69.28600972698581, 73.54218144570628, 76.36963767390098, 71.96112109768775, 69.43842518714168, 67.6078942514235, 66.59720143964215, 68.49888417028612, 65.20592497241113, 66.9628369423651, 64.6882034886268, 69.0963239054526, 68.50641512101697, 63.95797583364672, 69.11217028094877, 67.846845042321, 66.77931708674278, 67.09828422915551, 67.93786756453976, 65.12282171557027, 64.76735691870412, 57.127387831288004, 53.283531742711226, 55.806466917837824, 54.43433161704771, 51.96283048199069, 56.874622452643614, 52.593563295179806, 57.911359802369155, 45.07226943969727, 51.70993958750079, 67.69743411771714, 63.76046096124957, 65.08797537895941, 67.03153333356305, 68.68966825546758, 65.8352888784101, 63.88474910489975, 64.64630865281629, 65.14012329040035, 55.06637450187437, 49.55649952734671, 51.42098642164662, 53.78099026218538, 54.74703473429526, 65.07967172130462, 67.42898710312383, 68.7019060504052, 70.75161903135239, 70.33089776192942, 63.80530149705949, 60.491879293995524, 59.69798764874859, 68.499268562563, 68.23391237566548, 73.86554164271202, 68.85577278752481, 70.72484493255615, 72.32270871439289, 73.36026191711426, 72.88321541201684, 76.71415513561618, 73.29639788596862, 80.20498614157401, 75.45417216516311, 79.75556096723004, 73.71351841957339, 85.46435894504671, 42.95351489897698, 0.15955526171432388, 3.45291345350204, 7.713609135920002, 6.4984495409073375, 1.4401250524866966, 0.8954554760167677, 0.23955564795722886, 0.5281736197010164, 30.130419961867798, 53.26204892127745, 45.05337146020705, 39.329005595176454, 26.442572224524717, 60.65142562312465, 26.823004868722734, 0.20747190101012108, 0.03558836171343442, 0.07929417575078626, 0.0454840611576313, 0.044187537785018646, 0.08643820611459595, 0.069016263549847, 0.06598702932317412, 0.060474904133908214, 0.012138912138799507, 0.08691998348841745, 0.055457667913287885, 0.07844456892100074, 0.08124880312431244, 0.04348679333023968, 0.04997649650660254, 0.03194636248442675, 0.03964103961123094, 0.07746285022867304, 0.04799492582077942, 0.06183706591987322, 0.03256471609816917, 0.11243068838431952, 0.3684893947455191, 9.207424694491971, 78.69549335971956, 51.03938687232233, 50.627585072671216, 38.58870529359387, 87.35480800751718, 33.36712060436126, 0.12025397826707172, 0.8616245429842704, 2.5572363022835027, 1.5269983199334916, 2.130322345802861, 3.114453111925433, 0.8752314289731364, 35.11436393184047, 108.59230872123473, 94.09533839071952, 95.27940780885758, 91.13410580542781, 94.41688645270564, 88.8711178687311, 86.85557657672514, 77.40231929286834, 81.01012322210497, 79.36615590126284, 85.89616483257663, 92.2554329902895, 91.2471406690536, 87.35359207276376, 88.19898051600303, 76.37596053461876, 72.72907410898517, 65.1223941772215, 65.70411697510751, 68.35690221478863, 74.30885576432752, 80.4143387271512, 83.52144425915134, 82.57641192405455, 83.80548661754978, 71.52347087860107, 60.53993225097657, 61.04709471425703, 61.42425414054625, 62.12569159846153, 62.35833521812194, 66.23777897127214, 67.38667257370489, 63.984640106078125, 65.2142325524361, 66.9117441485005, 66.64956508144256, 70.4073839802896, 68.234037891511, 69.84802261475595, 73.24874893311532, 75.50893629750898, 75.78764423247307, 72.64715933030652, 70.129484053581, 70.39718581784156, 68.46587350291591, 71.44603544665922, 72.14599024864935, 67.13969661343482, 71.55310046288275, 71.71192507590018, 65.38073716625091, 72.74601090338923, 77.5019867189469, 78.37097998588317, 72.35731186405306, 70.41996694380238, 69.54732587260585, 70.52627102021249, 72.92290195342034, 71.29551056892642, 71.29049777984619, 68.95668752731817, 71.63045744742118, 70.51661414484825, 65.57505138458745, 70.04207011192076, 69.92597579956055, 68.79292072788363, 68.84677487034952, 70.89939824996456, 66.01929510793379, 68.4730592850716, 59.41851877397107, 58.403989884161184, 60.577559548039595, 58.03693448343585, 61.28045612765897, 62.07996852936284, 54.707148152012984, 57.181085078947014, 46.74148505733859, 56.44932377722956, 69.9289175771898, 69.00854126099618, 67.20798507813485, 71.72725369853359, 70.75350961377545, 69.68357332291143, 68.95726019336333, 67.5817241976338, 66.67913975254183, 58.61884555509014, 51.3019738658782, 53.81922552662512, 55.10372331065517, 57.10464592902892, 66.36521677817068, 71.74706166790378, 71.25078770422166, 72.63336043204032, 73.97448155187791, 67.6866554444836, 63.284120482783166, 62.87275014385101, 71.86376002527052, 70.85473029844223, 74.82391788113502, 72.92162326074416, 74.33618683968821, 75.79166073952952, 77.71881534207252, 75.86882160555932, 79.04117184300577, 75.67417790812831, 81.70122131224602, 78.26142818697038, 82.65148608915268, 76.49185088373001, 88.02849861883348, 54.1778007630379, 0.5794296822240276, 0.16759132485716574, 3.8468074269833106, 5.7631051540374765, 4.216111081261789, 2.1675728501812106, 0.36056139596527625, 0.5807458212779415, 27.658271635732344, 63.92303536015173, 48.09599714894449, 36.49356342131092, 31.385658825597456, 66.38942564687422, 32.67711097194303, 0.2911826655749352, 0.026830166856187488, 0.027612658638146617, 0.04738487085447677, 0.08945486117755214, 0.04942710421258404, 0.013238337367863185, 0.015392655134952117, 0.0648489750681385, 0.0801300925893649, 0.028075730060077006, 0.033730054574628035, 0.20738306545442153, 0.17770555471220326, 0.18829862016343302, 0.15240885647794894, 0.08750105351810494, 0.09503827084817233, 0.15875090003734635, 0.30385449528694153, 0.15996050690450977, 0.3181299002420518, 0.26593743312743406, 0.6174166116022295, 10.982301119835148, 94.98714416257798, 60.81809105411653, 53.8884122140946, 62.063427894346184, 95.85968325215002, 46.34109343251875, 0.22623860367363502, 0.7984418397949589, 6.057318218292729, 5.682824042535597, 6.54072827869846, 8.413009412827032, 1.9221516193882113, 33.86071558921568, 116.63851768739762, 99.85392693550357, 101.5655472970778, 96.5964847995389, 99.29440083042269, 93.94279741471814, 91.55619990441107, 85.0496389019874, 88.47495848132719, 82.52977494270571, 92.6378248583886, 96.50787061260593, 96.9282231792327, 90.14854754171064, 91.03056307761901, 83.30177584002095, 76.02885430858981, 68.27133178710938, 69.27854937891807, 72.61537244243007, 77.45582826675908, 84.44739818572998, 88.08610254718413, 85.37882774106919, 85.79228478093302, 75.84227500423309, 63.10941027056787, 63.41124057769776, 64.38336080120456, 64.35668868403282, 66.41871790732107, 70.24958702825731, 72.73757780751875, 67.64009691053822, 66.23158947114023, 70.45768445537936, 72.82879644824614, 75.51847550176805, 69.40354747156944, 75.31761092524376, 79.28890874308925, 78.44060205644178, 77.56172441667127, 76.57235360914662, 75.39299103521532, 77.983669465588, 69.70549152743432, 75.44449175557783, 76.88830837126702, 70.1620005023095, 73.7726285380702, 75.51026990336757, 66.64704691979193, 73.18206864018595, 80.92427822851366, 80.93542560454338, 76.37966325206142, 75.90819435734903, 73.65706766805341, 73.12879500850555, 74.68592889847295, 70.85040000177199, 74.14487715690368, 69.75314832502796, 72.9067417883104, 74.20593277100595, 69.19662675549908, 74.6490821530742, 72.75882136437201, 71.55659921707647, 72.88241524850169, 75.24770644403274, 70.16942162667551, 70.9218655863116, 62.58214566015429, 62.638686626188225, 64.11203868927495, 63.78728605085804, 66.20744336035945, 63.042765278970045, 58.77138653109151, 60.57336261195522, 50.29476411880986, 57.88788441688784, 73.53859639936879, 72.70452791644682, 70.59014289609848, 74.98564504807996, 74.35490439015051, 73.62235469202842, 72.34076730666622, 72.28510887392106, 70.34725404554798, 61.41952768448861, 55.572540683131066, 56.786047489412375, 58.04510085813461, 61.35539693217124, 72.084181539474, 75.62277132464995, 74.11664393640335, 76.447645771888, 77.0780961744247, 70.22692357340168, 66.85156714531684, 66.02437065493676, 76.6553274277718, 76.79165332548081, 79.41794687701811, 77.40016983401391, 77.46858381455945, 76.98669710466939, 79.87921760928246, 80.5760423598751, 82.67826018794891, 79.9088393488238, 86.81246972853138, 82.2880078900245, 87.83684376747378, 79.91485626466813, 91.36661606450235, 53.896162817555094, 0.5705579550516221, 7.706992587735576, 20.400149206961355, 14.845600397356096, 8.712005807507424, 3.0242606612943836, 0.36219117141539053, 0.55673815790684, 38.597263905309866, 69.09053448707827, 63.96382800994381, 54.28049625888948, 36.489001704800515, 79.0838707647016, 40.20931882243003, 0.3852041768691232, 0.11840311750288933, 0.18998551512918166, 0.154188969022324, 0.157319265567968, 0.1916111843480218, 0.11008354054102976, 0.21250109969367906, 0.2205880770399686, 0.19962818722330755, 0.11486796647190087, 0.1238014096874864], [0.10646300901088024, 0.03994907973514449, 0.0413876089958414, 0.038765370470261386, 0.04899166749730226, 0.019693651814915, 0.1937593714964967, 0.017513762032913587, 0.1171782578251535, 0.04158503751480772, 0.18842700117778396, 0.396107078920449, 15.01825724878619, 68.3626994779033, 39.920934400250836, 36.28749385956795, 41.97082388785578, 70.11675204000166, 11.652152711345304, 0.05879748950622255, 0.5289943756595735, 0.6739238084804627, 0.9257687784491048, 1.987699818226599, 5.057403589448621, 1.6914113298539193, 57.320945032181285, 97.87354576972224, 87.73313630011775, 88.23035947738155, 86.21391604023596, 84.66301871884255, 83.26367393616708, 78.6253692257789, 73.27685663777014, 77.04467758055657, 72.88942060162945, 74.21163589723649, 77.12065389079433, 82.35428810119629, 81.7886587881273, 78.54540778744605, 69.82622992607855, 66.35571679761334, 59.50776838487195, 64.83714765118015, 66.46346430624685, 74.41672878880655, 76.9391187544792, 81.97449284215128, 78.43060001250237, 77.56714513224941, 63.70947014900946, 59.62765562918879, 56.863514300315614, 57.908637677469564, 56.77521782536661, 58.803655870499156, 61.6819695503481, 62.9186144182759, 63.344870152012, 64.79998711616763, 62.86166944811421, 61.9798029622724, 63.77476192289784, 64.74972978714975, 67.05524798362487, 71.52169012254285, 73.73975123128584, 69.30842999489077, 71.49123684052499, 70.04417250233313, 66.31797575181531, 67.76647567749023, 69.20655819677538, 67.43014812469482, 67.71008768389302, 71.76624990278675, 67.08433628082275, 69.62318451173844, 72.9749910293087, 70.99975601319345, 63.36869855080882, 59.56592928978705, 58.0951738357544, 58.38966931066206, 65.9609067055487, 69.19235137201125, 68.66240778276998, 67.36452687171199, 69.29812200607793, 62.726084878367764, 56.107422536419286, 53.655325366604714, 57.63070244942942, 62.02338049488684, 64.62857561726724, 65.05576879747453, 68.255093174596, 64.87847374331567, 66.52389234112155, 59.56642350842876, 55.18589696576519, 53.04560861279888, 50.732826186764626, 62.491895844859464, 63.46495743720763, 59.632868459147794, 47.06362931959091, 56.60330426308417, 66.88424048885223, 63.65452558763566, 64.84560035890149, 64.01309690167828, 67.32502860407676, 68.40433935965261, 68.38096987816596, 65.11163511583882, 65.65353801173549, 68.19795208592569, 59.3745215477482, 50.38855975674045, 50.50188879812918, 50.25523839458343, 56.3298366146703, 65.497443368358, 68.91958190548804, 69.90606584856587, 71.31073720993535, 69.48512492641326, 64.2451992342549, 59.320694861873505, 58.078962679832216, 66.61926084949125, 67.01709901132892, 71.56129037180256, 66.53732253659156, 75.39110829753261, 73.73286354926326, 74.68386573176231, 74.07727902935397, 74.83122133439588, 74.91348912639003, 74.99481554954284, 73.5290885740711, 74.33404522557413, 80.58864885760893, 77.36834372243574, 83.28751410207441, 11.487357270333076, 2.084878745578951, 0.7570757885133067, 2.3720116865250374, 0.8757418273918091, 0.8021775909489202, 0.3234528936445713, 0.37533720955252653, 6.975830428061947, 71.16972800224059, 39.005245316413145, 49.1720837162387, 36.08890425774359, 50.97365579297466, 30.843597073708814, 0.16368485867015778, 0.012088289048763053, 0.03025603544477734, 0.062382432421849626, 0.08944029784611157, 0.048870188935149106, 0.1260174492434148, 0.045686113017220656, 0.19113363577954232, 0.060749401098057154, 0.03955948955169128, 0.01483242461202486, 0.06010620516815013, 0.047783834123683554, 0.06843772161030962, 0.016102312065120188, 0.17516673933113777, 0.09610219077477533, 0.16644963934536905, 0.010658893471343384, 0.13519433987957818, 0.05322717610866793, 0.19407138378629762, 0.4819994780325121, 21.257373402195594, 79.26196990474578, 53.00565142785349, 40.45720869495023, 41.019860929058446, 82.04835107249599, 10.374898564430977, 0.07647068975793739, 1.5785819003658912, 2.632308996492817, 2.9631952412666815, 3.09263811476769, 5.897983697152907, 2.8704856095775484, 64.36296055393835, 101.24408552723547, 92.04975174319361, 92.78044223785402, 90.62170305559712, 86.53306361167662, 85.93746739049112, 81.30481089315107, 76.2796506574077, 79.86549715841971, 75.21081263019194, 78.5647842960973, 78.43220818427302, 85.83327354923372, 84.0274457008608, 82.3801600548529, 73.25733892379269, 70.60683650355186, 63.44472192948865, 67.06138257057437, 69.62982116207, 78.1734102003036, 78.3019619603311, 84.74620434545702, 82.29112225194132, 80.27494553596743, 64.71644063149729, 62.87797081855036, 59.799679017836056, 61.07926599441036, 57.583167245311124, 63.90390988319152, 66.71586098209505, 65.60663823158511, 67.45725170258554, 66.49959718027424, 65.81548875378024, 64.3998622125195, 68.57038897852745, 68.44764232635498, 71.13819214605516, 75.02377833089521, 75.68908291478311, 71.52288252307524, 74.65784472803917, 72.90152503598121, 69.2204983003678, 72.06952756451022, 73.26768613630726, 70.3563617890881, 68.81461143493652, 70.65025714135939, 68.83454492015224, 74.15271405250796, 75.76691058374222, 70.70185199860605, 64.54851219730993, 60.70322444362026, 60.839789605909786, 61.6597532456921, 66.67848079435288, 69.6190111098751, 69.89722482619747, 68.42090745126048, 68.37073249201622, 65.0326228910877, 56.821870496196134, 57.702697553942286, 60.11644571058212, 63.54854314557968, 65.23877874497445, 68.97146701812744, 69.66757789734872, 69.3808840167138, 68.30128300574519, 64.84754193213679, 54.212627487797896, 56.539667729408514, 56.96874756966868, 67.34846084348618, 66.32409464928412, 66.65164393763389, 50.2181210056428, 61.39695444414693, 70.76134650937973, 64.14387264559346, 67.01847184088923, 66.90873961294851, 70.76359794985864, 69.75109300305768, 70.02815354254939, 67.42416258781188, 68.64348626905873, 68.52707816708472, 61.638690117866766, 53.472342875696, 53.000673940104825, 54.642378053357525, 59.05918652011503, 67.37271678063178, 73.31539000234297, 72.90441190042804, 71.98179198849586, 71.69096392969932, 66.74518462150328, 60.729543547476496, 61.76393924220916, 67.43004614307036, 70.41127497150053, 72.65062670553885, 71.09571287708899, 75.26113663950275, 76.12793337914252, 75.71850853581583, 75.68607837923112, 75.61138860640988, 78.13682233133625, 76.47757345630278, 76.66621592737015, 74.61704423350673, 83.3152452591927, 77.0150323067942, 89.35567179033833, 14.620389669172226, 0.980976996642928, 0.7689632667649178, 2.8770695530599166, 4.914717568505195, 3.509483837312268, 1.0410218036943868, 0.5564712528740207, 6.944701027485633, 74.88851931787308, 48.252899800577474, 44.94315285836497, 43.83710330532443, 59.27736443857993, 41.663580709888095, 0.16703445554500626, 0.027390531444501494, 0.017091898480430245, 0.09133498650044204, 0.04696960140380168, 0.11202319089563624, 0.029473888402384137, 0.033838038497994986, 0.09272628644060704, 0.059841537112069715, 0.035697322398904836, 0.030572422096625935, 0.20703565990251882, 0.1486989071652774, 0.16906340876894613, 0.09244778283661412, 0.23319030000317484, 0.16793398066393792, 0.33990607206379214, 0.22318657067033554, 0.22482636655049942, 0.11829834731836474, 0.3042391327119643, 0.6602215598667822, 23.376700608961045, 93.03653378640452, 55.15332952622445, 48.90732372960737, 57.395987818318034, 93.07399242155014, 20.430273009884743, 0.2983174569183781, 2.574851666727374, 4.520316383531017, 5.359492282713614, 10.689517759507703, 8.67903926680165, 3.89320612434418, 65.92264790688792, 106.48309338477351, 96.56996957717404, 96.61152316677956, 94.80392240708875, 90.78570519724201, 89.90946339022729, 86.95959783369496, 80.92482736033779, 85.52375147419592, 78.65213547983478, 83.11520438040458, 81.98430661232241, 88.65695645732265, 89.51406494263681, 85.40990860231462, 77.58074006726666, 75.31679507224791, 66.28332553371307, 70.72249935519311, 73.24931375442013, 83.29568047677317, 83.75061265883907, 86.28324001066147, 85.95926007916852, 83.97159899434736, 69.96030438330867, 66.03494536492133, 63.91799119211013, 64.97126525448215, 62.7445984655811, 66.56870934271043, 69.66484792770879, 69.90641101714104, 72.01218251259097, 69.90268476547735, 68.76731549539875, 70.9543820350401, 70.7813427525182, 72.04054909367716, 75.05876587283227, 81.02667562423214, 80.7922669379942, 76.26821302598523, 78.30583726206135, 75.92251100847798, 73.89074679343932, 75.51904816781321, 76.52114314417686, 73.49467369817918, 72.20994841667914, 78.17155884158227, 70.59403388730942, 77.10662749505813, 78.41537337149344, 74.67345576132499, 70.1064754301502, 65.7943275667006, 64.73651139966904, 67.53104717500749, 70.70855140686035, 76.3528891532652, 73.90409069676554, 72.28595610587828, 73.81764165816769, 69.0210771560669, 62.0505036846284, 60.068710465585035, 65.3809803532016, 66.6848664129934, 66.50573961196407, 72.47335126323085, 74.1193425270819, 70.65781162631127, 71.71740070466073, 66.53627918612573, 59.1678753975899, 61.1218943134431, 60.617069582785334, 67.66068935394287, 70.03374684241511, 66.07031729913527, 50.84047955851401, 60.45053751237931, 73.66069193809264, 67.276822674659, 70.19923948472547, 69.11462568467664, 73.70874881744385, 73.22815648971066, 76.54088051088395, 69.94045719023674, 71.40363462509649, 73.95552081446495, 64.04313441245787, 55.292887456955455, 55.137675346866736, 57.23591589158582, 63.926130110217684, 70.43248714939241, 76.19202490775817, 77.68969566591325, 77.27470105694186, 75.48399002321305, 69.11678298827141, 64.39699495992353, 64.4144691190412, 71.25170553884199, 71.30533218383789, 77.45493396635979, 74.69353829660724, 78.87761685156053, 79.78843827401438, 80.7166357963316, 78.14498870603501, 80.405866407579, 81.1459235222109, 81.22375119117, 78.6822122143161, 78.44104136190107, 86.14922831135412, 83.11307061103084, 93.55951909096011, 15.016540231243258, 3.661245487390026, 7.535145215449795, 9.193645408076625, 7.054403837650054, 6.122550666332246, 0.8069044147287646, 0.711198030940948, 10.318229140773898, 89.49890890429097, 55.32541567279447, 69.20418124045096, 48.22422335224767, 66.8275857740833, 47.24703934884841, 0.3271832821830627, 0.1232201787793348, 0.1528285960516622, 0.20821099199594992, 0.17743963027192702, 0.16830990000838236, 0.22011863368172802, 0.08959742247938149, 0.3209056206528218, 0.25557874461575864, 0.11356371710257185, 0.09575276275075252], [0.005684255090947714, 0.09101041036868289, 0.031641013244347226, 0.06498598223251682, 0.07037782395679144, 0.06323284364395565, 0.036046616357540896, 0.08164371378839978, 0.0552506364821907, 0.09434837036796155, 0.035066104253693935, 0.014458735541049993, 26.160385147217784, 71.03228030666229, 34.00609039491223, 36.650987748176824, 52.30183309124362, 50.58114813220117, 2.983261351623843, 0.04493130573762521, 1.364011581866972, 1.198447846597241, 0.9826372011053948, 5.345096203588671, 4.568784621454054, 5.13817205544441, 79.01409964407645, 94.19418211906188, 90.69478465664773, 85.35322250858431, 81.1750667325912, 82.26945507910945, 83.08868131329938, 76.17165211708316, 74.04723367383404, 73.88069768105784, 73.64242938257033, 69.24776661780574, 70.14580895823818, 73.81622960490566, 71.90049694430444, 73.8062354057066, 69.95486013350948, 61.05256642064741, 60.950039586713245, 63.07047290186729, 67.58828240056192, 72.30120628110825, 76.53615013245614, 77.33334049101799, 80.53055071061658, 75.61660535873906, 62.973355016400745, 57.95139935708816, 58.195151129076564, 57.29634784883069, 58.035318466924856, 55.524048420690725, 59.90045255230319, 62.27865619044151, 62.487914639134566, 61.46598031443935, 63.49474783866637, 61.82893683833461, 65.26461147492932, 66.04298622377458, 67.94184484789449, 70.51035404205322, 76.24101531121039, 69.05409566817745, 68.03330667557256, 65.96778654283094, 64.38369812503939, 65.09865599293863, 66.7119150777017, 65.8593879207488, 62.09424987916024, 66.11167477023217, 69.38635964547434, 72.6282613508163, 65.32533368756695, 57.83139444166615, 64.7014924787706, 70.3760991557952, 66.87123390936083, 52.95312304650584, 52.59499888266287, 56.63253376560827, 58.69269201832434, 59.53360503719699, 55.61722432413409, 57.62950612652687, 58.53842519944715, 63.79369912608978, 64.61376866986676, 61.796702800258515, 60.822091871692294, 64.66054293417162, 66.87074753545946, 63.40399203761932, 65.29269172299293, 64.31198150880876, 55.788726037548436, 52.98777326460808, 60.01840214575491, 67.8372117011778, 63.686661566457445, 65.83543792847665, 64.46121984912504, 61.825026235272816, 64.39106041385283, 62.35822539175711, 59.07358946338777, 61.432365602062596, 62.00083078876619, 63.428436248533195, 65.08151523528561, 63.1683321152964, 65.83352381183256, 65.10336283714541, 58.81429726077665, 50.568808355639064, 52.937096241981756, 50.965748294707275, 54.24150789937666, 61.483532920960464, 68.19360609977477, 68.40230757190336, 71.63627040001654, 68.59906150448707, 66.44065964606501, 58.98428101693431, 59.20089783207063, 60.853133509236, 71.84021011475595, 68.0471840212422, 71.49099365357431, 71.50395316462364, 74.69225960393106, 70.91111044729911, 74.67354989820912, 72.91249198298301, 76.61433865947109, 70.06009732523273, 73.53217155702653, 71.78955662635066, 77.86822626667639, 75.52870504317745, 84.9612835914858, 45.525585605252175, 0.21267219777068785, 1.382225475484325, 2.0981998501285433, 1.9388945016168782, 0.8772624812779889, 0.6749569240116304, 0.05247776591849904, 0.33406333396992377, 57.04786962078464, 48.08534006918631, 45.51487753468175, 35.05072739816482, 35.94938555071431, 40.980637227335286, 0.11269813733956507, 0.054128758173676274, 0.030300805623072292, 0.08515091793191049, 0.08152215095657496, 0.02372751842373081, 0.002195990556145027, 0.09156325005836065, 0.026959584004456, 0.07943777127131339, 0.043723089320044366, 0.06362729848572804, 0.023933130676948258, 0.013516616891138257, 0.014787568248838428, 0.013086694093691486, 0.03343820571899414, 0.07073112072483187, 0.03832677364229195, 0.04197773418479389, 0.07456629476960629, 0.013518452629326813, 0.1105066202580929, 0.17719494178891185, 34.946670839863444, 78.05709623521375, 44.11070431432417, 32.26558177701889, 49.59448768246559, 60.63500658158333, 2.5845597780519918, 0.11231503975127013, 2.5327425714462035, 3.0380267097103983, 3.076012413347921, 5.954133897058426, 3.8279452391209143, 6.406775905239967, 82.87679487659086, 99.62878288761263, 95.8662022313764, 87.54203058058216, 85.5795197333059, 86.55885711792978, 86.76763703746181, 79.89109454616424, 75.3762895830216, 76.72824428927514, 76.72241564719909, 72.53345766375142, 71.59583076353996, 75.67695494621032, 74.27890454569172, 75.08961923660772, 71.73956994087466, 65.84428679558539, 63.23312182580272, 65.34561234135782, 70.81396118287118, 76.42649635191887, 79.49855942879954, 78.31219150174049, 83.61922894754719, 78.20402822186871, 65.36907203735845, 60.17601866875926, 60.737855049871634, 60.14056828714187, 59.88612413406373, 59.6796662576737, 63.43542591218026, 66.63435412991431, 65.8084677111718, 65.66023741998981, 68.3804678147839, 65.40904098941435, 70.53022476934618, 69.59471594902777, 70.48890652195101, 74.84297275543213, 76.13442882414788, 74.17369088818951, 70.37737000373103, 69.06107748708418, 68.64212912897911, 68.55638611701228, 67.97876219595632, 66.17663706502607, 64.67866036199754, 67.33453642937445, 73.75690767841955, 74.75456253174814, 67.98149216559626, 62.65853774163031, 68.37947937750047, 73.90776987998717, 71.05965060572471, 57.914144685191495, 56.15427132575743, 59.729527427304184, 61.90253619224795, 64.4128687920109, 58.8937880146888, 60.40011152144402, 64.26515233132147, 68.98588565088087, 68.50461867547804, 65.23538197240522, 65.21011406375517, 66.67740606492566, 69.5702011354508, 66.51676147214829, 70.396103243674, 66.8448834265432, 60.66933516533145, 57.04502590240971, 63.86702391409106, 68.06927481005269, 66.2501109030939, 69.33729863935902, 67.95219206040906, 65.52348398393201, 69.02750199840915, 66.33868586632514, 62.46978544419812, 64.2560955785936, 66.08411619740149, 64.14608094000047, 68.2927949966923, 66.50843820264264, 67.8238913320726, 68.37430969361337, 64.09703562336584, 52.89564071163055, 54.953586747569425, 53.75633816565237, 55.39375512830673, 65.61198442212998, 68.32518592957528, 72.00364743509601, 72.11512904013358, 72.30997670081355, 68.10591759220247, 62.4350332444714, 59.77554859653596, 63.80201455085509, 74.41583448840727, 72.30832930534118, 76.07773488567722, 73.62800290507656, 74.79486096289851, 74.27774352412071, 77.11921830331126, 73.98454635374009, 79.17302623871835, 74.919019668333, 73.9636165865006, 75.0292774938768, 79.62629533583119, 79.57674011107414, 86.66771857969223, 56.154953818167414, 0.8865805006315632, 0.46885199965007845, 0.18579813982209853, 3.905794235967821, 3.312998832233491, 1.4867376415960252, 0.0687048871130232, 0.06653933275130487, 59.09873970093266, 59.050627908399036, 43.5091107891452, 37.05794542066513, 45.11815332597302, 49.53856645091888, 0.2457977936513001, 0.0692363835931305, 0.016411731147297447, 0.06525003741825781, 0.015257300805270433, 0.07110091136588205, 0.02750966386238654, 0.022846015523217862, 0.05901399744494308, 0.02224296834620257, 0.05493686219016391, 0.04349599404621028, 0.11793376607519966, 0.11413656700883182, 0.17454358809176954, 0.11664526747359384, 0.16448782606711312, 0.20630787637445236, 0.1184209367080081, 0.130658317958155, 0.2053699549287558, 0.18500160756370715, 0.1366055964101707, 0.23629356896685016, 38.320521077802105, 95.24640498622772, 46.172227551860196, 55.56354276595577, 68.38898720279818, 74.62947814695298, 5.6797400789876145, 0.15568429604172707, 5.261547267436981, 4.903567250697844, 5.003609753424122, 14.087579807927533, 10.977491313411344, 7.199399154032431, 91.33987334466751, 100.61644354174214, 101.49724314289709, 91.49501877446329, 91.78887490303286, 91.51525820455244, 93.51473346833261, 84.89783533157842, 80.7271477483934, 79.45014169139247, 84.30077998868882, 75.58977634676042, 78.19430074384137, 79.03594724593624, 80.17835324810397, 80.03167229314005, 75.60417929003316, 68.50832923766106, 66.61300859143658, 68.60460773591073, 74.35131149907266, 80.55617163258215, 83.83795599783622, 82.33041655632758, 89.28978381618377, 83.58997591080205, 69.18279647827148, 65.9893125103366, 64.57975387573242, 64.81684154079807, 64.33842220614034, 61.72181298655849, 68.8842962634179, 70.44694500584757, 67.89647086974114, 68.11972433520903, 73.71806836897328, 69.42541860765027, 71.78563425617834, 74.22068088285386, 77.78304807601437, 78.1628276455787, 82.89719904622724, 76.40302488880774, 74.16984696542063, 71.43266016437163, 74.69240080925726, 72.53861950289819, 74.81852069977792, 70.56367474217569, 67.25278639024305, 71.35457361898115, 75.23088732073384, 78.73964355837914, 73.65873075300648, 65.97254045547979, 71.1015336744247, 77.54256756074967, 72.99083740480485, 62.82001387688422, 60.52895745923443, 62.4930254874691, 65.40711902802991, 66.43632150465443, 61.667374410936915, 63.40345467290571, 62.601145621268984, 68.62106600115376, 67.84620961835309, 69.07301718188872, 67.79159453607375, 69.90941555269303, 72.86258374491047, 69.0313616106587, 71.64282860294466, 72.7006212357552, 63.43729296038228, 60.18313384825184, 66.65810800367787, 71.56732297712757, 69.43660520738172, 75.18127718279439, 69.76917512955205, 66.41286573102398, 74.48677447534378, 69.89542838065856, 67.02921913516137, 67.05360058815249, 69.06530580212994, 66.37114740187123, 69.18655410889657, 67.25283345868512, 74.29604530334473, 71.09807414393272, 66.56072339703961, 57.100272486286784, 58.81859225611533, 55.775142869641705, 59.48757994559504, 68.33150879029306, 72.92381978804066, 75.10427321157148, 75.12539125257923, 75.37363021604477, 73.46058830138176, 67.14138323260893, 64.60695159050726, 66.72321934853831, 78.52255605882215, 75.83563050916119, 79.9805167413527, 76.63311896785613, 77.60570987578362, 76.67322912523824, 80.0900528507848, 77.17613973925191, 83.54766138138311, 76.1697458451794, 79.55717532865464, 79.16093749384727, 83.13672250316989, 82.91397110108407, 90.9181244142594, 53.75245501918178, 0.9634342573342786, 4.772129116519805, 7.849103491152487, 6.6317081451416025, 5.216371859273603, 1.6418964319652127, 0.23332762892448136, 0.7279623023444607, 70.34999185992827, 64.49650156882502, 62.37002780360561, 48.694876393964215, 51.86815231077133, 61.707668919717115, 0.3913379977307012, 0.284184513673667, 0.09820097291301336, 0.2497715223580599, 0.14757888661997934, 0.12319603934884073, 0.10009697157769434, 0.1696443792072035, 0.234913369640708, 0.24419622555855783, 0.15359436221901449, 0.10692449271558754], [0.027805075026868332, 0.03043316646418985, 0.02569737370997187, 0.03995266502663013, 0.01117272875196631, 0.14195486662849305, 0.030945085567392172, 0.07586285261617554, 0.07044614367787877, 0.06436447042130655, 0.046958473976701505, 0.16718462409992374, 43.028840095766135, 56.19532677435107, 35.01134287926459, 43.23834957615022, 46.55804364911972, 30.86835703542156, 0.3100519320897518, 0.04189718386999542, 1.0683851160349385, 1.8897062636190847, 6.125770441947445, 2.347013440824324, 0.27939318529059814, 11.435939900336727, 92.4240949076991, 89.92410167571038, 90.18893226500481, 84.33074689680531, 83.15660891994354, 79.62249848150438, 75.67549582450621, 72.25784840122347, 68.2085189511699, 69.87700108558901, 70.82804249178979, 68.1858241173529, 65.93555250475484, 65.83422199372323, 67.15404464352515, 65.00077716765865, 63.11730600172474, 62.25184679031373, 60.54355259864562, 61.870078579072036, 65.28457241673624, 68.9133845606158, 75.99272143456244, 77.08845907641997, 76.09303212934925, 71.12691140943959, 60.200298140125895, 56.34459257125855, 56.32595346819971, 57.068842534096014, 57.98423351780061, 55.91354370117188, 56.17960983707059, 62.84163005890385, 63.012241394289084, 61.604475282853656, 63.77387154486872, 61.73382328402612, 65.15452231130293, 63.490209656377, 65.81717537295434, 70.56822469157558, 70.59467715601768, 69.87125873565674, 67.50720700910016, 68.62621999556019, 63.97165313843758, 61.00596081825995, 61.52488646968719, 53.91688469917544, 59.483696799124445, 70.45408371956118, 69.321318903277, 62.782539552257916, 58.32219669895788, 69.28593912432271, 71.7049511017338, 70.58493398850965, 70.21592524743849, 59.57453889231528, 64.35975205513739, 68.78253429166733, 62.90150503958426, 68.59313872552687, 64.06741780619468, 67.37792568822061, 70.54157610862487, 66.1512436405305, 69.65421045980146, 69.66857417937248, 66.66792961858934, 60.1040235642464, 64.45425764206918, 62.183001349049235, 61.872098599710775, 61.34980755467569, 60.875895023345954, 58.61702949770036, 57.365660052145685, 63.92802461501091, 60.33153672372142, 61.77255276710757, 64.54655885696411, 67.19628072554066, 64.92557748671501, 60.824904211105846, 58.067693710327156, 54.754212671710604, 59.735571799739716, 60.79298396264354, 65.5922156764615, 64.67857014748358, 64.8684952335973, 64.33195421772619, 62.65416429888818, 51.56100719205795, 49.98919187053558, 49.74612259095716, 52.01988920088738, 62.24209577806535, 67.55596207034203, 70.26209938910701, 67.88669632327172, 68.15821063133978, 63.239782010355306, 57.454548804990715, 57.97684769476614, 58.70676940487277, 69.1482247075727, 65.91135932553199, 68.28380492425734, 71.96680853443762, 70.32966613769531, 70.59331217119771, 74.09727527249244, 73.80202278014153, 73.32691392590924, 68.04756056877875, 71.8772372891826, 70.73814961218065, 76.73351595478674, 76.19161698126024, 80.59630532418528, 78.50499952993086, 20.059585494379846, 1.190573198180045, 2.35042467713356, 3.5037005476413237, 4.064832127863362, 0.3676211413356566, 0.0705875558478217, 0.2615104561611529, 29.57900335711818, 68.71401048475697, 39.77009965527443, 41.48179846425211, 31.96651281849031, 42.61357876562303, 0.31836355705895736, 0.06459912315251366, 0.06273887781125885, 0.031013962617444418, 0.023440597428669854, 0.10400195155412921, 0.02434404300255401, 0.05058563982827529, 0.07194181543684776, 0.07449890967578658, 0.05863562278870133, 0.08629245022612234, 0.034707609579087265, 0.0627307074835464, 0.10882645920519868, 0.014500144508577164, 0.024632231873129646, 0.10874115531483006, 0.07103613863188414, 0.08680238133116115, 0.02361620776355267, 0.04152924333128237, 0.023467090664311283, 0.3572845621214759, 56.57877376002651, 61.03221716419343, 48.17891605438725, 35.16065574461414, 50.48871747909054, 37.68839582320183, 0.2414488810445032, 0.04822078769305541, 3.1180658600022717, 5.450456459676066, 13.481858968734743, 1.2882919417273615, 0.5677245328983953, 14.153530540004855, 94.69660635917418, 94.69507663480698, 94.73712444305421, 88.23011629043087, 86.57984179835167, 84.02471573122087, 81.11685875923403, 76.54405763072353, 71.33307903043686, 71.41600578061997, 73.52890814504316, 71.07809359027495, 69.05116958002891, 68.9259361451672, 68.44016628880655, 67.40412712097168, 66.6109218905049, 64.0753213820919, 63.6500148619375, 63.93790898784515, 69.75037128694596, 73.21176882713073, 78.19339859870173, 82.346906200532, 80.43589607361825, 75.2619524924986, 62.94034434903053, 58.71241369555074, 59.589843980727665, 61.6854408479506, 59.7845975045235, 59.72917833635884, 58.74806411804692, 65.07326649081323, 65.69185564594885, 64.01909812804192, 66.12434402588876, 65.01783947790823, 69.08000684553578, 68.4252534374114, 68.27702706859958, 74.13258444878363, 73.17258434910929, 72.66102098649549, 73.05001028122442, 69.11535524552869, 70.03120514654344, 65.7037482723113, 64.77194609180575, 57.51036413254277, 62.545710763623646, 71.51958773213049, 72.01384559754403, 64.7032497006078, 64.54034190024099, 76.74958982775289, 74.91736442812028, 69.98368170953566, 70.85174929711127, 63.052602583362216, 66.51400796828732, 71.24762627386278, 67.04470465260168, 72.76630524666079, 67.96676758796939, 71.94914217918151, 70.81773450297695, 67.72156453901722, 67.89181893871677, 72.71067034813666, 68.98331257604784, 63.51528536888861, 66.92617847073463, 65.69813536059472, 66.57866431820777, 65.60929759856194, 63.81939065071845, 62.188473055439616, 61.49866150271509, 65.86289451968285, 64.10274659433674, 64.08878687889346, 65.62230025568317, 70.48449777787732, 69.68199653010215, 63.823403235404726, 61.15012361157326, 57.060766373911214, 61.084059130760934, 62.448604645267615, 67.19048346242597, 67.87004193952008, 68.19732450669812, 65.75817900319254, 65.50491940590643, 53.5604275426557, 52.59472039438064, 51.866818704912745, 54.77477373615388, 64.33881836552774, 72.80349716063469, 71.44711802082678, 71.79495380770776, 70.22727658671718, 64.82954217541602, 60.5017440549789, 61.68775896872244, 62.09709751990534, 69.60768330481746, 68.7897357633037, 70.7587028318836, 74.91574056686895, 73.50129465903007, 75.72335658534881, 76.97472603090348, 76.36141638601981, 74.37994480133057, 73.70118648775163, 75.52330786182036, 73.50134172747212, 77.48051566462364, 79.56357663677585, 80.21971856394123, 83.74150491529896, 26.727863857823035, 0.6402438254125657, 0.7103608500572943, 1.468353247450244, 0.36701804627814605, 1.1759090495686377, 0.5045374476861569, 0.3403122518812457, 29.18793324501284, 76.59055340674617, 45.76697218802668, 32.69745630602683, 38.5202403222361, 52.28917168032739, 0.5736550953119033, 0.040293509035461375, 0.045624052234474695, 0.04744501258697241, 0.09329239477313335, 0.04241097988861223, 0.05717011191131127, 0.05432691064573104, 0.083394929496271, 0.10297177780059077, 0.02108149861376132, 0.0959440089401699, 0.13181742430934984, 0.18544025418739166, 0.19029578073851525, 0.22420945126683484, 0.10853546836803998, 0.1706762689976923, 0.16826287753159003, 0.15488310596875607, 0.11087565247209803, 0.2832884665939116, 0.22870951302109227, 0.4467301076698688, 67.76862513634467, 74.40092948175247, 51.11039746192194, 59.894302275873, 64.87883852374169, 48.28443957913307, 0.7812946470033738, 0.1455875942783971, 5.7916227463753, 7.758222174259925, 15.99010584815856, 7.024420259460327, 0.6095889703400674, 15.16231413810484, 102.23629613076488, 97.63932535725256, 100.65422381124189, 91.77851200103761, 92.21668781772738, 86.59680212697675, 85.85996135588616, 81.55110436101114, 77.2794863485521, 78.54831034137358, 78.72454243321573, 75.15117691409203, 73.22366145349318, 73.07952219440092, 73.17533785297026, 70.18276553000175, 69.24778230728643, 67.27369262326148, 67.40489590552546, 66.52196253499677, 73.33029500899777, 75.13103946562737, 82.17825212786275, 84.18940036527573, 83.11431792474563, 79.11521834711876, 65.65652293543663, 61.88175547507502, 62.63300703417871, 64.72562290007069, 63.41890488901446, 64.43062928415114, 63.449817088342485, 71.2141292325912, 70.0759829244306, 68.47061957082441, 72.68386487037905, 71.0802822728311, 70.76384113680932, 73.35326440872686, 73.17900919145154, 78.19059802639869, 76.99545967963435, 76.30818197804113, 74.32516497950401, 75.72847920079386, 74.98451540547033, 67.70683211665, 69.13338245884066, 58.55876661116078, 65.862761159097, 75.44744922268775, 76.4536391535113, 67.9633080574774, 65.06999915645969, 75.89782361061343, 76.83112021415465, 75.63161234701835, 73.86656145895682, 64.42329445192891, 67.5239319955149, 74.98336222863968, 67.94101330541795, 74.7632231250886, 69.73076728082472, 73.32321905320691, 73.76176357269287, 73.67063122410929, 74.10789705091908, 76.95757742851012, 73.14537094485375, 66.84227897274879, 72.08520135571881, 65.81553582222232, 70.19870604238203, 68.1378770643665, 66.797532573823, 66.7774578832811, 64.8358650361338, 70.50723183539607, 66.52289605909779, 66.22032442400533, 72.06418529633554, 72.69763238968389, 71.04985252503427, 67.15414662514964, 65.78094443967267, 59.96130812552668, 67.2031605628229, 66.59887236933555, 71.49602213213521, 70.25074020508798, 71.25827158651045, 69.56022262573242, 68.23016258978075, 57.030222877379394, 55.37708897744456, 56.343019700819454, 58.09100435626123, 66.77117424626505, 73.8580499156829, 75.85215153232699, 73.95870577904486, 72.76853315291866, 69.43854285824683, 62.951499569800596, 65.44294203481367, 66.11216898887389, 74.59878952272477, 71.75035645884853, 77.26531090274935, 77.70287482969223, 76.23834809949322, 77.74791932875111, 80.68511562962686, 81.48816600922616, 78.07018126210859, 74.17973918299522, 79.36336317370015, 77.62842824382167, 81.49820727686729, 82.0915206786125, 86.66736556637673, 87.60035622504451, 27.38956182233749, 2.5909463772850656, 7.5028552835987465, 10.502032387641169, 12.938029208490926, 2.6145409047603607, 0.38366648518750746, 0.3689226021449412, 36.439650443292436, 85.1941547086162, 56.71032613323581, 56.07198784428259, 43.65144183558803, 65.38842501178866, 0.8401834580206102, 0.17352404763862012, 0.10005418556712328, 0.14272787998760902, 0.2127912937993965, 0.15216694123321964, 0.15216989833260738, 0.08923084940761329, 0.22074417511542, 0.18801463136990226, 0.13927447819902053, 0.11902935607659242], [0.04968276307467492, 0.014276344370427392, 0.07589963249742024, 0.029495974717241143, 0.12158838851797966, 0.08173837927320311, 0.0294510628126802, 0.05227418188306113, 0.026492586381913676, 0.13186216384412783, 0.25416554222183846, 3.3526071713816736, 61.823602414900265, 46.14825010299683, 33.645142124545195, 34.192022508190526, 46.163241401795425, 16.899569149940245, 0.043804233352984154, 0.32590078971078323, 1.5469240829829247, 2.704542384993646, 2.9506063941986334, 0.3260626487674252, 0.6675259324331438, 23.457776000422818, 96.7398552740774, 92.7659216234761, 90.80038270642682, 85.77149621901974, 80.58304771300286, 76.94967777498307, 74.03575681870984, 68.50860380357312, 65.45967878833895, 67.2416703931747, 65.17265150623938, 68.19977206568565, 68.24012541001844, 66.82651104465609, 62.85649191948676, 60.41715029747256, 61.7186240996084, 62.46098756790162, 61.103114005058046, 60.29080290948192, 61.67729800747287, 65.97780427625104, 73.85429228505781, 74.1699646365258, 72.87140907779818, 69.0098984010758, 61.43456997409944, 56.0488772392273, 56.54266442022016, 53.772027646341634, 55.88145086842199, 53.05885837924097, 53.83089850025793, 57.43642745479461, 60.97335023264731, 59.98810183617377, 64.82066585171607, 63.14809660757742, 66.90011039856942, 62.81677792149206, 66.34898601039764, 67.02597141265869, 69.30816327371906, 68.75031594307193, 64.43181776231336, 64.75960631524363, 67.19630425976169, 64.76093599873205, 63.929252316874845, 64.66379457904448, 63.483620074487504, 71.1461074890629, 64.28865125102382, 61.79861691690261, 72.67998956864881, 70.90060633997764, 67.94966605401808, 69.31573344815162, 64.56039305656188, 63.29550320102323, 61.865556086263354, 62.171540183405725, 65.14429276989353, 64.6393346786499, 63.48106661150533, 66.95611399988975, 64.42661669946486, 60.45919026097944, 57.80989593075168, 64.48935108800089, 68.55360907893028, 62.9515976290549, 59.75153192397087, 64.81877134692284, 64.78213640951341, 60.50328162408645, 62.24997581974153, 54.755283478767645, 59.15961096363684, 63.27443615082772, 62.51343750184583, 63.754314607189556, 63.99759177238711, 61.54234886169434, 68.36897527017902, 61.264778414080226, 58.74417704920615, 55.95735657599665, 54.05479915680424, 56.012807123122684, 59.91148617959792, 62.067652287021765, 65.71011035673081, 63.72060968029884, 62.80761526476953, 53.53092347421954, 49.42200145413799, 50.24231026249547, 52.04202705813993, 62.00871867518272, 67.53392619471397, 69.96772550767469, 69.43040001776912, 67.12502694899037, 64.8551474079009, 59.108149466976045, 56.057647658932595, 56.90951978006671, 64.72250853815387, 65.53550604851016, 68.1427800270819, 70.85000776475476, 74.84636952800136, 70.30481400028353, 72.9885075169225, 68.00406148356777, 69.54596088778588, 66.68756500367196, 73.654463214259, 70.87251432480352, 73.37015413468885, 76.93151720108526, 78.85164291627946, 82.01460299953338, 61.74418618602138, 1.2799635241108558, 0.0679128977560228, 2.6396984967493244, 2.6676556804487785, 1.3068532102531003, 0.35861583907277356, 0.21113605358667914, 7.172377945915346, 76.82348728179932, 37.94214571675947, 51.31312908664827, 38.279748039860884, 46.69205534842707, 0.9186407899664295, 0.06299490439555337, 0.04641293127450251, 0.06911678960727108, 0.03220758506006772, 0.03587710791297498, 0.08493210023809826, 0.05036836963207011, 0.040736959030431126, 0.03670729824431962, 0.04514744595414208, 0.016899985794518745, 0.10517368303431619, 0.05972934353555884, 0.029178925399338047, 0.03751691911489733, 0.08250676546125643, 0.07229268370616822, 0.035213897936046124, 0.09233578844296356, 0.08479051186793274, 0.174396192775138, 0.35553944447348196, 5.159174876828348, 76.03708344121134, 55.1462810270248, 43.316589093977406, 28.649374169688073, 55.241920178936375, 17.804301092701575, 0.07508635355700409, 0.4053515538332924, 3.613859823634548, 6.365567484209615, 6.672454707084164, 1.627030894160271, 0.5072387043506869, 28.742767764676003, 99.10211055509507, 94.37830601969074, 95.4404289491715, 88.63371249168151, 84.14503835862683, 78.51120471954346, 78.35457663382255, 72.67703210153888, 69.00252434515184, 67.81517582554972, 70.16947653985792, 70.48369761436217, 72.94682841147147, 69.9530166195285, 66.6058071198002, 64.48214961636451, 65.63579713144611, 63.90913055789087, 64.05177931631765, 62.52986831049766, 63.87477843992172, 68.46366128613873, 74.1807746887207, 77.2083894668087, 76.44645337135562, 71.88121457253733, 64.57632572420182, 57.96544928704539, 60.72495829674506, 57.214354622748594, 58.907457474739324, 57.409849474507, 57.233746820880526, 59.89396887440836, 62.76184904959894, 64.01310866878879, 66.37415978216356, 65.01080666818928, 73.46655814878403, 65.19685253020256, 70.30717526712726, 71.40400332789268, 72.60178535215317, 71.49498662640973, 68.35741212291103, 70.87895485662645, 69.93214961021178, 67.54171602187618, 68.39325474154565, 66.3363245994814, 65.40482051910894, 73.0968512258222, 66.14125728607178, 66.36378119068762, 74.26903586233817, 73.15858933233446, 69.50731769684823, 70.18665652121268, 67.98754046040197, 66.6572529269803, 65.08022477549892, 63.76359101264708, 67.3476920589324, 67.00111143050655, 64.73733117503505, 67.77992940718129, 68.98355576299852, 63.21128206868326, 59.700984339560236, 63.394990198073856, 72.24550862466135, 67.96864248091175, 64.21355355170466, 66.15457765517696, 68.88646141175302, 63.698052129437855, 63.78012772529357, 58.712876535231075, 62.74890130566013, 65.28402720728229, 65.32610247212072, 65.70700383955433, 66.21527241122338, 65.23155373911705, 71.74742252595964, 65.23335410702613, 63.30920404003513, 59.0723382273028, 56.289322453160445, 61.0047213492855, 63.87358603938934, 65.17595806429463, 67.00802264675018, 66.03974634601225, 64.52286774112333, 55.771306791613185, 51.531793379014545, 52.81132544240644, 55.17059972209316, 64.19458104718116, 68.9395232354441, 72.11105761989471, 72.24360235275762, 70.39493437736266, 67.2805489263227, 61.84099812661449, 58.57985719557732, 59.80844551517118, 67.19759079717821, 69.23505813844743, 70.73110503535118, 73.37460210246425, 76.15921035889657, 73.41791291390696, 74.31244081066501, 69.8160945215533, 74.3732532378166, 69.45942555704426, 75.6241519989506, 72.81435428127166, 75.77080941969349, 78.83490224038401, 82.7610614222865, 82.95241032877277, 72.21277252320321, 2.3255296387980064, 0.40735548662562526, 1.2570414379719765, 0.982828661799431, 0.4541864414368907, 0.05610819147419065, 0.13640469751290737, 5.965426400784524, 83.00216167203843, 43.851416034083215, 44.49103301571262, 48.968430334521884, 59.942449369738185, 2.144673562818958, 0.10586444153300217, 0.022200509838219133, 0.02785261652822937, 0.04418833068602028, 0.030804110067566077, 0.04674208861204886, 0.038648396505102996, 0.03421295809769823, 0.03606872182459601, 0.027076151943014517, 0.060014561900208076, 0.21221845921489502, 0.1695080768437155, 0.1812959483434116, 0.17535032464131234, 0.18648044837097968, 0.2202535570869523, 0.16339293320573148, 0.17396778108612185, 0.12817152760802739, 0.3089597665013806, 0.4580910690128804, 5.766226870398368, 90.58597810806768, 60.401362757528986, 48.35741919855918, 47.522766282481534, 68.31057902305358, 27.711370721940074, 0.2167611614230179, 1.087684648171548, 5.122279592098729, 9.110872610922783, 10.215494421220596, 4.842972024794548, 1.620793467567813, 33.804974786696896, 102.77607702439832, 102.3509705451227, 99.64228368574574, 92.69127891909693, 89.12487168465891, 85.22252128970239, 82.20792093584615, 74.33426487830378, 72.51019800862959, 73.26709778078141, 74.16895266502135, 75.77532014539166, 76.59350302911575, 73.9922655782392, 71.56484403917867, 67.03592638815603, 68.97223580268123, 69.11251544952393, 67.71211947164228, 66.87790978339412, 68.04314397996473, 74.91923147632231, 79.99105222763555, 81.163817374937, 80.16770009071597, 77.16316453872189, 67.31995305707379, 61.06326272410732, 64.43182168468353, 60.51195790690761, 63.01117450960221, 60.255227012019006, 61.4557154716984, 64.48105527508643, 67.60295206500639, 67.853787637526, 69.95649968424152, 71.75520450838151, 75.38921771510955, 70.04316053082867, 73.64370807524651, 76.82642905942856, 76.55758980781802, 73.50840983852264, 72.50490280889696, 75.64386583143666, 72.92079171826764, 70.48557250730454, 70.70903778076172, 70.68005930992865, 69.88225706161992, 76.61850421659409, 68.70950760379915, 68.31129289442494, 77.75946678653841, 78.54657665375741, 72.51882722300869, 71.77306698214623, 72.40380764007568, 68.8334309670233, 69.63949372691494, 68.07802169553696, 69.34147204122236, 72.49447714897894, 68.70422024880686, 73.31717860314154, 67.0969113995952, 64.6013072998293, 61.30724983830606, 67.03267866565336, 74.34763231585103, 69.78940671490085, 65.94105166773643, 71.53611660003662, 70.6090565650694, 65.93491708078693, 68.42049168002221, 60.49402483047978, 64.48249478493968, 70.86380666302097, 70.77255664333221, 68.80409163813438, 70.20498967939808, 66.90242459697109, 71.68122860693163, 69.22447558372252, 63.287470186910326, 63.517148494720466, 59.234336037789625, 64.30908679962158, 65.63793090081984, 70.97633161852437, 71.38363838195801, 70.28737514249741, 66.97010117192423, 58.328931408543745, 54.551488891724624, 56.77240548595306, 58.236567435726045, 67.32400094309162, 72.8374570415866, 76.12097509445684, 74.56562196054767, 73.20613630356328, 72.61390547598563, 64.01744681019937, 62.46330568867346, 63.44167817023493, 70.95554305661109, 71.87805314217844, 74.6882587863553, 76.39256000518799, 79.95540572750954, 76.77311620404645, 79.32975630606376, 72.92904438511019, 79.47387203093498, 73.18342578026557, 80.53338266188099, 77.52192804890295, 80.5254045609505, 83.17458906481343, 87.5683496844384, 87.50730975981682, 73.7740170571112, 2.0154699538984606, 1.336642018248958, 9.985698442305289, 6.5524551849211425, 6.0232627295678665, 0.7744141355637582, 0.33678423312883227, 9.140650264678463, 92.3923864672261, 50.907563855571134, 72.54069835908952, 50.6685620738614, 71.67262292677357, 2.8478912864961936, 0.19315131218923678, 0.1578683207832998, 0.08135244715958834, 0.1129476828200202, 0.13226621393715182, 0.13083159172486875, 0.12944215337835974, 0.14859868754302302, 0.11879457311043817, 0.10454745978237161, 0.22297479332454745], [0.018380617332314293, 0.04874398361050314, 0.007465083448727045, 0.11444304814381946, 0.03642900531450587, 0.058461770625604745, 0.07409987745866661, 0.03314145007020524, 0.03738365429002912, 0.09755189725828749, 0.1841844828619111, 8.078714628373424, 66.91820821454449, 40.0821477367032, 37.20927046191308, 56.66031591353878, 43.88817256496799, 6.736765888429458, 0.10141920869148548, 0.40612395432206894, 2.832465340052882, 6.922226826990805, 8.10082502903477, 4.273664018800182, 0.05432370839820755, 36.68004466641334, 96.83664368044947, 91.30756870392831, 89.36495211816604, 86.10285020643666, 81.79027480463829, 78.66599713602375, 71.14652326030117, 68.14982460391137, 65.32969536319857, 64.87128011641964, 63.84632164432157, 67.97722462684878, 69.77927915511593, 68.77803141070952, 66.59061185775265, 61.94154808598181, 60.7143835867605, 62.945776831719186, 62.02118396759034, 61.13051176071168, 59.42956416837631, 58.756556049469985, 62.999795713732325, 66.69042833389776, 64.97823530627836, 61.94036745255994, 58.659077305947584, 56.31478648031912, 54.06380884109005, 55.22353210756856, 56.67834312685075, 54.05997276306153, 53.65719633717691, 56.20255570257864, 60.08011279567596, 61.92670583724976, 60.74529970845869, 65.78214076257521, 61.86279081529187, 62.885964608961544, 67.38792773216002, 66.78544382895193, 68.90277062692951, 66.98036993703535, 63.25229044883483, 65.30897740394839, 60.441833772966945, 65.26359165868452, 70.97127176100209, 57.28099961434641, 63.98992353870023, 69.79685137348791, 63.33011419542375, 68.15326844492267, 69.9655838935606, 62.73716165173439, 66.98901484089514, 68.66479258383475, 69.74350713914441, 66.89772559750465, 65.26407411021572, 66.57519694297545, 65.02127155180901, 65.3181988962235, 68.32717064888247, 64.22312805729528, 67.8181960505824, 68.52591714551373, 66.34499303756222, 59.9851365243235, 61.09727359587147, 66.42187149293962, 66.1346520147016, 56.462542164710264, 61.10144699773481, 62.77289444400419, 56.7860435670422, 58.16560391456851, 59.57312683905325, 62.89580191335371, 61.1389527013225, 59.43573405665737, 62.94520024330386, 58.37012021772323, 58.79527376544092, 67.1533856853362, 61.71647856312414, 58.748570103799146, 51.76739838815505, 53.76253551052463, 56.778775415112904, 60.2915128584831, 64.08866920778829, 65.01122636179771, 64.07299541657972, 57.930665708357296, 50.35144236779983, 50.7369250635947, 52.68824931113951, 61.93138130249516, 67.33680355933406, 69.80704953593593, 66.61602097172891, 67.88730036827826, 61.1840364240831, 57.220806921682055, 55.09350945872646, 58.455902453391786, 63.11212455072711, 68.17688111336001, 66.80515766143799, 66.17881790284189, 69.35380397304412, 69.01775883090112, 67.89865170755695, 69.05670012197187, 65.3903744297643, 66.49396465670678, 70.35048607856997, 69.17747774431783, 69.03426416458623, 73.18674410543134, 80.83671523678689, 76.86766885942029, 77.58316409203314, 24.450416103486095, 1.6923676527315572, 0.9483187910049193, 0.23396812439445527, 1.1421689439204432, 0.11143929400150815, 0.07093472391246788, 0.6933403375648683, 63.6714937610011, 53.567691772214836, 38.316453579933416, 28.09384103744261, 51.28833970715923, 4.055055620208863, 0.2133555022338706, 0.11508276220411064, 0.10575976327902849, 0.029598488772828734, 0.08472868857244331, 0.0744616701417873, 0.10396774572831008, 0.05349553670854338, 0.11021012890963786, 0.06500167937408532, 0.05550848252530541, 0.070319471039599, 0.03283440203015362, 0.013716371444564675, 0.0425073690712452, 0.040400359148700396, 0.024721025293993375, 0.01640503553883924, 0.04162307761068787, 0.004602245913232647, 0.14970376937379762, 0.4868436358388394, 13.803302107318757, 76.97181563223563, 54.79744895812004, 46.39603407152238, 51.4406963317625, 52.73681217624296, 7.559246709269862, 0.17534905293535802, 0.3726480264336832, 4.75995211831985, 7.219301750583034, 7.437667942816212, 3.885614622023798, 0.3632339090108872, 42.5862673021132, 99.66462550624725, 92.59689100327031, 94.99141170132546, 90.77018045609998, 87.33831051857241, 81.04758185725059, 75.7427252492597, 68.83982443040418, 70.0875303822179, 68.59714738784298, 68.77266560831379, 70.58946040368849, 72.67322740247174, 73.45956064039662, 70.65805481326196, 65.88172974125033, 65.26218745016283, 63.13465072262672, 66.05028183229508, 62.928428188447036, 60.91267901082193, 63.12056941370811, 66.06367280406337, 69.4171973197691, 68.62560810581331, 64.18890145517165, 60.56997760649651, 60.03190294388802, 57.438345493808875, 57.67503307711694, 59.396961427504024, 59.164996377883426, 57.77422197403447, 60.11481792696061, 64.73108676172072, 65.17585216029998, 63.451813574760195, 69.62893470641106, 68.25621497246527, 68.02131991232595, 72.07505026171285, 69.65377115434217, 73.08657461597075, 72.47797966003418, 66.65620173177412, 66.30319626100602, 64.5663982052957, 67.42093055478989, 71.29353369435957, 60.39866416685043, 68.26039621906897, 70.50712200903124, 66.48633172435146, 72.56897080329158, 72.41860282036566, 65.95624692978399, 68.70397706185618, 69.71909430719191, 72.31032971412905, 68.74979034546884, 69.5968810973629, 68.63575919981926, 66.72771438475579, 69.77211690718129, 70.39163174167757, 66.97565524808823, 70.45123607881608, 69.94026891646847, 70.3054415795111, 61.52379997314946, 61.92724320196337, 68.02022949341806, 69.76362105338805, 63.85363686469294, 63.33456216319915, 65.17176505058043, 59.26319291514736, 62.15391305185134, 63.24490854817053, 66.1954487523725, 63.38783971724972, 63.0041063985517, 65.47756871869488, 62.59382255615727, 61.99024823404128, 71.15470532448062, 65.19750364365117, 62.5565835737413, 55.85674778107674, 56.29119734610281, 59.10817300119708, 64.27178505928286, 66.79941531150573, 66.88908853838521, 68.52613679824337, 60.76139711564588, 51.6333160861846, 52.26419794944025, 54.645484570534, 62.600749461881584, 69.71419918921687, 71.91622564869543, 69.91620125309115, 69.01111433582922, 63.901525082126746, 60.109283462647475, 56.828369863571666, 60.96934157033121, 66.19151853745984, 71.28320217132568, 69.63218242891374, 69.24816669956331, 70.90873349097468, 69.75033990798458, 70.3515294290358, 71.68323686045986, 66.82146687661448, 68.3471590472806, 72.08484049766295, 71.0322646171816, 74.14610878113778, 75.57095681467365, 82.01059433721727, 78.52976537519886, 83.35771668341853, 32.78265999209496, 3.432175146956598, 1.8333811505186943, 0.10491876727751187, 0.8964017478208389, 0.22386633580730808, 0.06645653396844864, 0.5337338245684101, 66.66515258050734, 64.58357818665044, 38.51915774806854, 32.97951982867333, 62.43280141584335, 7.519165479367779, 0.2631095268072621, 0.13733802243105828, 0.07546642509799811, 0.046325256342008236, 0.07909022016270507, 0.02215952987992956, 0.09533832450547526, 0.066319074812195, 0.06013114516052508, 0.04852355713204992, 0.04295827693215782, 0.1748665554388877, 0.1062857669087187, 0.12494301092961144, 0.2551697609165023, 0.19776941277086738, 0.14795426970287678, 0.16442650838965372, 0.1782039255504647, 0.10849235293966149, 0.21980951720428085, 0.5192201356253316, 14.558202451275243, 93.30589863561815, 54.493794748860026, 50.27912170656266, 70.5025093017086, 67.3745838288338, 11.425119061623851, 0.26378334710194223, 1.4795799289018878, 7.3347140608295325, 15.369296631505414, 23.126502421594438, 7.806002526513993, 0.4106705635786057, 52.58034883006927, 102.58373968062863, 100.58681395746048, 98.12025500882058, 96.96809799440446, 91.55073212039088, 86.27530897817304, 79.68474649613904, 75.50137396781676, 72.15925570457213, 72.69799324773973, 69.64304739429106, 76.70731452203567, 77.13547260530534, 77.85719656175183, 74.15782097847232, 68.36903018336143, 67.59147520988219, 66.60132777306342, 70.6391332995507, 68.14557275464459, 65.27241699157223, 65.49119111030333, 70.00396036332654, 73.59367432132845, 71.98883656532534, 68.55724119370984, 64.4104447672444, 64.52945340064265, 61.24257387653474, 62.36520721066383, 64.99449745301278, 62.58032568039433, 61.99060909209713, 64.76853362975582, 68.29275577299057, 68.79099876649919, 67.28579705761325, 72.46374930104902, 70.40763501198062, 71.89647259250765, 74.43583073154574, 74.68612501698156, 76.72001515665363, 75.52072694224697, 69.74165578042307, 71.63833356672718, 66.77879933388003, 71.89433882313391, 76.38298942196754, 66.81627365850633, 68.88573185090097, 75.54258238884711, 68.79350123866912, 74.44937859812092, 77.31296770034298, 67.28626774203393, 72.29311835381293, 74.70073192350327, 74.48234219704905, 72.49984295137467, 72.81819820404053, 73.6501407623291, 70.53912854963734, 71.9016658106158, 73.38949141963836, 69.22868820928758, 74.65372623935824, 70.68689207876884, 68.69674421125843, 64.19829160936418, 64.98559367272162, 71.64674312837663, 71.19040673778903, 66.759336533085, 66.95001863664197, 67.3384823337678, 64.13726737422328, 64.65524773443899, 65.7509304631141, 70.83933891788607, 66.38343226525092, 66.46843787162535, 66.95806734023556, 68.437012703188, 62.828647013633486, 69.77563919559603, 69.61453176313832, 65.15608733700168, 58.80759000778199, 58.76795445719073, 64.08420162816202, 66.58693267453101, 71.18735513379498, 69.2543326654742, 71.04666756045434, 62.63425827026368, 54.8082511655746, 56.16137473813949, 58.746785425370746, 67.21157012447235, 73.84199173219743, 75.08324146270752, 72.21722833571896, 72.90568274836387, 67.68333711931783, 63.099298400263635, 60.48398356283865, 64.38582404967278, 69.68718190346995, 75.60907440800821, 74.28771418909874, 73.51946307766822, 76.18966364091443, 74.51818481568368, 73.54900636980611, 76.94701840800624, 71.04978192237117, 71.42155985678397, 77.39106993521415, 74.67624848888767, 77.2293584577499, 79.66519740320022, 86.69927012535834, 83.72575267668694, 86.92060162944179, 32.080940123527284, 4.1252008368892055, 3.6073675655549575, 0.3334725576062357, 5.140660799318745, 0.5392527219749267, 0.18415045323631457, 1.2578050744148994, 75.70629427509924, 70.48444286469491, 56.93162233598771, 37.96777056109521, 73.15220371369394, 7.612175172375095, 0.6659010293022279, 0.2768349112762559, 0.1547652050372093, 0.11501559161490972, 0.19681350358070868, 0.3348128743950398, 0.21996046716888107, 0.136562128581347, 0.21825290315093535, 0.2323695287228592, 0.22219074829932184], [0.03940658606288414, 0.04762617705930625, 0.10493352213093352, 0.03785619647392342, 0.09077704466518857, 0.01425598941427926, 0.06910416447827894, 0.10004342969266639, 0.07054732091003849, 0.12798082534103625, 0.18799428407463337, 24.19037865054223, 68.42788142542686, 24.197650724841704, 31.630659872485747, 53.766104867381436, 28.6808100054341, 1.3291293310542263, 0.00982277553468462, 0.779474912391555, 2.724291273663121, 4.660146428692726, 2.8884694316694817, 1.3967411868995236, 2.7565782637365404, 69.66009401505994, 97.03768084126135, 94.69595524572557, 91.2407393609324, 87.58037567138673, 82.33611183781778, 81.08237328067904, 74.05632572789347, 70.69932599221507, 65.6076305912387, 65.64275541613179, 66.23539417020737, 66.54188817547214, 71.5271657513034, 70.69452501112416, 70.7505129229638, 69.18295337307838, 60.96388947579169, 61.2926233199335, 62.95013066261046, 61.01278574235978, 58.579719912621286, 58.364675967924065, 60.325198173522956, 59.739188225038596, 60.08983635133313, 58.05205129807996, 57.0910470716415, 55.803525140208585, 53.88017915910291, 55.50500139113396, 54.914076712823686, 55.46952355292536, 54.35511935141779, 55.364592306075565, 59.73316738682409, 58.77978040326027, 65.89400675988966, 63.27337711088119, 57.045610335565385, 65.28139921926683, 66.47852620770855, 72.42252519053798, 71.49231941469255, 67.82638595950219, 59.06731759348224, 61.96216014123733, 63.03650125380486, 65.1354988159672, 62.8745505117601, 58.31822333797332, 71.66623730813303, 65.15902911463093, 68.75796456490794, 70.51906170383577, 63.43005618741436, 64.97508172065982, 65.8729907005064, 67.67588461599043, 70.62142772059288, 58.974898707482126, 62.595524864812056, 56.66794492352394, 63.123330762309415, 59.62494134902955, 60.05259736891716, 54.894107926276426, 55.861670355643, 61.31640857265842, 65.41543053042504, 69.00180262904014, 61.35842500194427, 62.95774398311492, 63.27853110528762, 65.55737718459099, 57.73691631132557, 60.31403118564237, 56.36338464675411, 54.95348476594495, 60.65319853444254, 60.03421714228969, 62.849506178209865, 62.17449372814548, 59.23280239105225, 67.03715801239014, 53.778299516247166, 54.12597840832126, 61.57359446248701, 60.414090848738155, 52.877495827213416, 51.63071163239018, 52.533896200118534, 56.39472046206075, 60.39534191931448, 62.49434340384699, 62.9215052050929, 60.3127799495574, 50.61786543938422, 50.0978454466789, 48.98499842612974, 56.84583617794899, 66.01705935693556, 68.18376095064225, 67.00672826459332, 67.1296553457937, 62.25742832306893, 55.46351840419155, 53.01269992705315, 56.535584542059134, 62.38565844874229, 64.5476806548334, 63.82956920131561, 65.28015975029238, 67.2387364602858, 68.40634761318084, 65.13959769279727, 63.866102157100556, 63.44350599473523, 67.74866811690792, 66.70739650726318, 69.63916424782046, 68.30453072824787, 73.27750775121874, 73.60335473091372, 82.43797579119283, 76.53203164377521, 56.55470609664918, 4.33667395384081, 0.3661279746842, 0.24344582711496662, 0.11618405189966002, 0.04492748678932267, 0.25901236601414224, 0.21467171789657688, 39.973278430200395, 68.45833470744472, 41.67863868897961, 29.946048951918083, 47.06695548949703, 18.981120009576124, 0.34142191491780743, 0.22315710692876772, 0.09163705496898583, 0.0228536649111418, 0.09012597718185957, 0.05005953660715492, 0.10128277609305036, 0.03156989921755608, 0.08303519758966663, 0.020129134495472236, 0.03415106585429561, 0.0874565897749797, 0.037487018703212666, 0.06315385614852272, 0.0363077910526866, 0.06313935027367647, 0.020719142856016275, 0.10048343995285612, 0.1450644175131475, 0.04881071369914759, 0.12831698472221054, 0.20959042523416782, 34.70779849636939, 77.10636861862676, 39.48053067730319, 32.25811750658097, 52.5502367942564, 36.971465003105905, 0.8441919364756154, 0.03583352134052304, 0.504113678489962, 4.487655297402413, 7.743164195168403, 1.5542994872216256, 2.3900646403912575, 6.505380859298091, 76.49443964804374, 99.45720272679483, 96.9170444242416, 94.0793743441182, 89.69476069173506, 85.66161494101249, 84.31751281984391, 76.76700515131797, 72.28499904755624, 69.54834568885066, 70.25441938830961, 68.30882180121638, 69.99563709382089, 75.00717886032598, 72.3752135615195, 74.42838607295867, 71.53574005250009, 65.42667988807925, 62.99349638723559, 64.21582460403442, 63.5486255153533, 60.88622262400966, 59.75527778748543, 62.68696708063926, 62.74368847570112, 61.45001626783802, 61.19323045976701, 59.79832187775643, 58.93112505635908, 56.9169173702117, 59.6738572274485, 58.8751999024422, 59.21737178679436, 59.03283603729741, 59.159293251652876, 63.73366725060248, 63.234216167080795, 68.2457108651438, 66.74339602070471, 62.24134268299226, 67.32098856279927, 69.60532988271406, 74.16186886449015, 76.71098586051696, 69.330105012463, 59.81683938733993, 63.648347854614265, 67.05316912743353, 68.49101589572045, 64.8830472269366, 62.45620227629139, 74.49632152434319, 67.30247497558594, 71.07646188428326, 70.88818811601209, 64.23514619950326, 66.64149284362793, 69.81847147787772, 69.41525182416363, 71.92180325908046, 60.28996744463521, 63.09294416058449, 61.100211451130534, 66.27553570655085, 63.709678034628595, 61.85611101888842, 55.20370060397733, 57.488410626688314, 63.749631297203806, 65.10415123355004, 71.94331353710544, 64.72960802816576, 61.55194297913582, 64.31750028364121, 67.14305416230233, 62.53283362234793, 60.38084876152777, 59.41274504507742, 59.11723367629513, 63.651395536238155, 63.11631364207115, 66.29110751613494, 66.40177326817667, 60.83183503920033, 67.32396171938989, 56.71003195547289, 56.972818989907545, 65.68534843383297, 63.49730130164855, 57.32288268304641, 53.923438979733376, 55.49232821310721, 59.4355300934084, 62.814687298190215, 65.05821243409189, 63.14987736363565, 61.20735883712769, 52.45904168775005, 51.62371804637294, 51.64362407499745, 59.61981088884416, 68.37782413728776, 69.79117962621874, 68.33245800387475, 70.34851704874347, 63.86789075789913, 57.85503848906487, 55.22515204644973, 58.04155503549884, 64.13564351297194, 68.36585306352185, 67.2803214288527, 68.3336425596668, 68.77866683467742, 70.46306594725579, 67.47164680111793, 66.21710808046403, 63.24333567773143, 70.32480239868164, 69.86816790796095, 71.68543338775635, 72.26063328404581, 76.82468752707206, 76.92441771107336, 83.30462348076605, 78.57927353151383, 63.29327137239518, 6.631832190098302, 0.22251189235718022, 0.39616974491265516, 0.36392556383244457, 0.11621089562052682, 0.27822045789610955, 0.16904440978842397, 40.514322327029326, 79.32219397637152, 44.431507125977554, 29.566232119837117, 56.191945691262525, 28.352437019348148, 0.269309384447913, 0.23034138755211908, 0.12985717385045945, 0.11220985587926642, 0.0009189178566767595, 0.05816816742862425, 0.0538562951729663, 0.06920927174149022, 0.01811079733494309, 0.041602688180583144, 0.05455979754427268, 0.14604913160925911, 0.13003329746425152, 0.2581789849265929, 0.07982784025971928, 0.2038777535480838, 0.13851465687396067, 0.24463304889298257, 0.3144890214166334, 0.09178071943742615, 0.31220758093460915, 0.2436577270348226, 37.04369937219928, 91.20301400461506, 34.92561163440828, 44.381088979782604, 70.25628643651163, 48.65395038358627, 2.8316019283187006, 0.12536700229130446, 2.55306976456796, 6.754715634930519, 16.510572010470977, 10.923016455865676, 3.985015081782495, 7.8182957249303024, 84.97199950679656, 104.2847147295552, 104.37656094951015, 100.18674004462459, 96.059629994054, 89.79190995616298, 89.12374204204929, 80.34982358255695, 78.10146608660298, 75.48556681602233, 73.5045188473117, 71.62955530228155, 75.48085997181555, 80.76739126636137, 77.0236458316926, 76.53667573005923, 76.41962435937698, 67.35401491965017, 66.09640890552153, 68.24958616687407, 66.37146903622535, 62.259232613348196, 63.61754940402124, 67.07953529973184, 65.239747570407, 65.88848406268706, 66.39071218429073, 62.320990331711315, 64.42771496311312, 61.215340860428356, 63.10563302809193, 64.35964615114274, 62.62010635868196, 61.25273281528104, 63.74643456551337, 66.93190513118621, 65.97720807598483, 70.98455290640555, 68.9253556343817, 67.78862137948313, 70.62273779223042, 75.32685202936973, 77.85313298625331, 77.08513290651383, 75.61060413237541, 64.2814419346471, 66.15467963680145, 71.39380516544466, 70.97186796126827, 69.51477804491597, 64.56689634630757, 78.24996702132687, 72.41629646670434, 75.89095161807153, 75.61122386686264, 66.87004150882845, 69.04766298109486, 73.06777077336466, 71.5857816511585, 75.95335652751308, 65.8181167417957, 69.2654251283215, 64.57513724603962, 69.10593371237479, 68.96701905035204, 65.6435045888347, 59.743471453266764, 61.711395171380815, 67.70693409827449, 70.33580856938516, 74.35714798588907, 65.99040292924451, 65.64203762239026, 69.44388512642153, 70.75507856184437, 62.86806291149509, 63.34420727145288, 62.31767985128588, 61.00273662997831, 65.01009671918808, 65.62888591520249, 68.83214442960679, 71.52329044957315, 62.97049168617495, 70.0111618349629, 60.75549787090671, 59.803479794533025, 67.15045959718766, 68.87887554783975, 60.9414731302569, 57.67587638670399, 57.4868965918018, 62.76451626131612, 66.1295529334776, 68.21467707234045, 67.69900306578606, 66.66541145693871, 54.0783961357609, 55.32626682712186, 54.80920430152647, 63.44636932496102, 72.80869822348319, 74.61840137358635, 71.893248404226, 74.57759303431358, 68.23803870908677, 62.166778426016535, 60.05782588835686, 60.286264727192545, 67.99742483323621, 71.59113960881388, 69.75235600625315, 71.81542073526691, 74.35322561571675, 76.54135119530463, 71.06468692902597, 69.73327759773501, 68.76582499473326, 74.97419957191714, 74.8601213578255, 76.84204793745472, 73.91740322113037, 83.04967726430586, 79.90542688677388, 89.89027515534433, 82.16702630442958, 67.28655799742668, 8.508686807847793, 1.859133717033171, 1.2850013183009241, 0.6828502649741789, 0.31137456756926357, 0.642796675524404, 0.21460060961544516, 50.808594611383256, 82.61034042604508, 61.80785017628824, 42.46333237617247, 67.37329729141729, 31.77252219569299, 0.5174760905004318, 0.3743230010713301, 0.17281845001684082, 0.29867892784457056, 0.19494933586928154, 0.10233071542555287, 0.1945361693299586, 0.11056455948780622, 0.17226179520930016, 0.2486089839329643, 0.1742833173803745], [0.04501249573584046, 0.07679669847411495, 0.09394869463698519, 0.0394760204419013, 0.024488885331177906, 0.012892629658322663, 0.024768827265248667, 0.013095698499631499, 0.024353002400828466, 0.010243111699368927, 0.02725798674228211, 39.40444846307078, 63.57816488512101, 35.88023416457638, 59.84462153527045, 54.504973503851126, 9.971626939312106, 0.21073705967395537, 0.07210996407534807, 0.5276353969689339, 2.5371179753734223, 5.370426870161488, 1.8310280961375085, 2.534706453161855, 26.15239920154695, 92.12748527526857, 89.31560085665795, 94.42910855816257, 88.49558230369323, 88.67528961550805, 82.84653771308162, 83.61776982584308, 76.83788238033172, 73.29697055201378, 63.842905259901485, 66.60818407612463, 64.70610518609324, 67.15153432661488, 70.27636112705355, 73.85211929198235, 74.51846722633609, 75.93605887505316, 69.53500178552443, 64.00442454122728, 62.20133450723464, 60.470733796396566, 59.159203037138916, 58.74755813229469, 59.369222425645404, 58.366495947684015, 57.38471100407263, 54.64043255775206, 53.79382033501902, 53.848827654315585, 55.92089814524497, 56.493666172027595, 55.785607753261445, 56.3870483060037, 55.35534335720924, 58.31945496220743, 60.7410478591919, 62.74480242883006, 61.617262209615404, 52.38288494848436, 64.37945412051293, 65.61093714929396, 66.39308914061516, 68.51123179158857, 75.24610611700243, 64.61430603458037, 58.64072061354115, 64.82375667941186, 61.17761550411102, 63.26463807013727, 56.98908505901214, 56.07678098063315, 66.53918174005324, 62.37065146046301, 70.61855654562675, 65.68317151838734, 62.73546326544977, 66.4447702900056, 70.69153616505285, 67.53214543865573, 52.77232139341293, 51.875165508639434, 60.31038338138212, 63.40648666504891, 64.39649289654147, 60.915228551433934, 63.59612541814005, 55.738645215188306, 52.36165708111179, 62.47723794752552, 58.218681427740286, 61.08400813994869, 68.04315182470506, 64.6439826873041, 60.19336338966124, 61.03427248616373, 65.35028388423305, 56.32831865741361, 58.14591361630348, 59.90604977453909, 69.78302894100067, 66.6201473051502, 60.22546406715148, 63.93806588265204, 57.349770530577636, 62.46072476910007, 63.92524757692891, 55.98202043964017, 60.160697890866196, 60.31145811080933, 54.70070369781987, 51.10665944314773, 51.775811872174664, 54.95761894410657, 58.490011384410245, 62.001976120856504, 58.75964687716577, 57.843024269227065, 53.65618828804263, 50.84038934400005, 47.042719164202296, 52.19214008700464, 64.03036317517682, 67.77758382981824, 65.82933472048852, 64.60807338837655, 59.33798466959308, 54.73137663256738, 52.14912345332485, 54.90966012400966, 58.708546238560835, 62.25806374703685, 61.737710352866884, 66.81399868380639, 61.97781039822487, 63.67568285234513, 60.11107598581622, 59.67534380574381, 59.386174909530155, 62.79759360897926, 65.2833447148723, 66.69104806838497, 67.46748908873528, 71.90828677146666, 71.38985141631096, 79.53257422293387, 78.5604618441674, 68.57518995961836, 13.927090148771963, 0.10518052419948001, 0.019389440215403037, 0.3947089378151202, 0.07299664189978954, 0.07893079726566231, 0.34596674685035983, 18.591024606458603, 81.16560597573557, 38.01609416161814, 41.17770102716262, 39.25777143047702, 28.83768912284605, 0.12816550615694255, 0.017362612885453047, 0.08686569849810294, 0.12595896609127522, 0.07760010254118713, 0.01725675102563635, 0.01329747456756811, 0.09724330938150806, 0.013877632952625714, 0.09733671848211559, 0.07439410884774501, 0.030779250514423175, 0.04904607506168466, 0.08271348662674427, 0.04878638657711206, 0.05776513240209991, 0.044344765840158354, 0.034662054160669926, 0.045585782312217264, 0.0497106793186357, 0.06981880959844397, 0.10925405118013583, 52.31393752559539, 73.45308088487195, 46.75871210713541, 35.76634422425301, 60.739223957061775, 14.804845010080646, 0.3095909616639537, 0.16062586958850586, 1.1239098204720406, 3.481979932515852, 3.828651756048203, 1.9137720883853975, 2.1717690508211813, 32.747209610477576, 96.21333983636673, 93.3474757594447, 97.48163823158511, 91.27388338888846, 92.7755706541, 88.4658193588257, 87.47903731561478, 80.82776438805365, 76.56431275029337, 66.72933040126678, 70.57518297626127, 68.15821847608014, 69.65236694582048, 72.53893329251197, 77.13088343220373, 77.00251994594451, 77.48693266222554, 71.60880596406999, 66.10095101018106, 64.18937998433267, 62.99645777671569, 62.24645745369696, 60.59070341048702, 60.73374440593105, 60.510184995589725, 61.71051656046222, 59.397083020979366, 58.39272875939646, 57.07880927670387, 57.97369803151777, 60.72616638675813, 57.15838240038965, 60.996409846890366, 61.754003878562685, 62.694666693287516, 65.23708428106, 67.12578004406345, 65.86883298812374, 56.46481321704004, 67.63964191559823, 68.54267351088986, 70.52765953925349, 72.14624912508073, 76.18019503931846, 66.68788663802609, 60.95724890308996, 68.0621753200408, 66.00482940673828, 67.84315801435902, 58.743455333094445, 59.08749426564863, 68.63294293803554, 66.45940073074834, 73.66996442118, 66.17946901629048, 63.49738367142216, 68.48658361742574, 73.02015319947274, 66.91142251414638, 52.73753389235466, 57.20144218014133, 64.68111184335524, 67.56534437979421, 66.18937692334576, 65.01112438017323, 67.52884280297064, 60.93830385515767, 57.675848930112785, 64.91814851760864, 62.3545148295741, 60.57314688159574, 68.13808102761546, 68.6427959319084, 62.25723220456032, 64.42080766923966, 66.62001394456433, 59.624019592039055, 60.51750021596109, 64.23568748658704, 70.4084587097168, 67.9333568388416, 62.42621967869421, 65.96055369223318, 61.24118927986392, 63.90430996494909, 67.32712314974877, 60.98363468723913, 63.71785617643788, 63.36729434228713, 56.7023794112667, 53.802563298133116, 54.98966470841439, 57.725039374443796, 60.11546511803905, 64.15352167621737, 62.92528244756884, 61.35837008876186, 55.70611307697912, 53.5200624312124, 49.298391880527625, 55.428577930696555, 66.35910572544222, 70.92283833411433, 67.47217239872103, 68.92265704370314, 62.93045605382612, 57.78048992156983, 55.11176416950842, 58.44168386151714, 59.97987662592242, 63.53992177594093, 64.713338036691, 66.09688743468254, 64.8233840542455, 65.57567896381502, 62.33649546100248, 63.19265473273493, 61.54642420430338, 66.77113502256333, 67.63963407085788, 70.01543721845074, 67.66050108017461, 74.82273332534298, 72.70654401471539, 82.53729020395588, 78.0267684690414, 77.1715505661503, 22.15751224948514, 0.11240084159878955, 0.1508961545844232, 0.28102332846291606, 0.019316682930014307, 0.1383427773872691, 0.3631763604860152, 17.54602674515017, 92.76294846688548, 43.71130897152809, 37.68601102213706, 49.7214626496838, 39.391045724191976, 0.05678441728495302, 0.05130747851404933, 0.05272757952972766, 0.11676261682183513, 0.01188189730108265, 0.04129752471682526, 0.05215649162569354, 0.04977130368652363, 0.006464643961554694, 0.01234033772151076, 0.07867679315348787, 0.17133168786043124, 0.17679564144101836, 0.2173740317624423, 0.2513613693055607, 0.1003488842698355, 0.12087937414405808, 0.1336199219428724, 0.13539536135090938, 0.1288647069445541, 0.12191347026776884, 0.3124529742185147, 60.370736891223544, 83.7668042029104, 46.79773576797978, 77.846433577999, 77.01513428841868, 21.368092106234645, 0.5877105411021941, 0.21597081915505473, 1.975321553407177, 9.77518581574963, 14.26809120562769, 6.638258993625642, 3.0043882179644803, 38.269530265562, 101.38601256955056, 97.15027639942785, 102.71315436209403, 97.97679824213829, 99.16155015268635, 93.10418682713663, 92.40255325071274, 84.8580389638101, 82.5772277770504, 69.98232456945604, 73.27280090701196, 71.14416983819777, 72.67770674920851, 77.78828051782425, 80.9780146998744, 81.67411773435532, 81.34411304227768, 74.96014179721956, 69.94279492285945, 67.5136318514424, 64.93894492426227, 62.799605784877656, 64.39610458189442, 65.79447661676716, 63.541235769948656, 64.99071628816667, 62.49067206536571, 60.19022941589356, 59.978621467467285, 62.887855191384595, 63.47673239246492, 61.136869922761, 64.07506250566053, 65.0184396005446, 66.92078913411787, 69.66374966406053, 69.41594216131395, 68.70862114814021, 62.36273611745527, 70.32336681119858, 73.3091926574707, 75.1252971156951, 76.27834058577015, 78.62688326066541, 66.53537704098609, 61.60053330083048, 71.91566867213096, 69.29971448836788, 72.56769995535575, 62.16839052015736, 62.8791985204143, 74.82896204917662, 70.41084351078158, 76.17704929844027, 70.16051000164401, 66.50917560823503, 71.46127777714884, 75.86185547613329, 72.59646661819951, 56.72981639062205, 59.497189752517215, 66.29747744529479, 71.26788139343262, 68.58976548717868, 65.1383033106404, 68.79449752069289, 62.32943519469231, 59.1094595386136, 65.84570669358777, 64.59327820808657, 66.85196722707441, 74.38203934700259, 70.30832059921758, 64.7432892553268, 68.12017933014901, 70.35174123702511, 62.50725584645426, 63.60265224210678, 67.27802291993173, 71.49792840403896, 67.97116848730272, 66.11285932602422, 68.67532807011759, 64.91015864956763, 68.22016054584135, 70.54022681328559, 63.442972552391794, 67.05592263129451, 65.60532423757738, 59.85363121955626, 57.376411268788004, 59.34733560008388, 60.583533317812034, 64.91528910975303, 66.14364208713656, 65.83658326056697, 65.08841076204854, 57.86812351595972, 56.88430678459906, 51.9516085809277, 60.33799294502505, 70.59910158957206, 74.63092942391673, 71.48651430683752, 71.63051236060359, 65.52119331975138, 61.12341227069978, 58.99695419496106, 61.00312102225519, 64.6443239335091, 68.01722495786606, 67.60239508844191, 72.41113462755757, 68.94277095794678, 71.25970717399352, 66.7405483799596, 67.47212533027896, 63.73184334847235, 70.40165731983801, 72.11966330005278, 74.85170395143571, 72.48858574898013, 79.50902431241929, 77.60060294981926, 88.97355448815131, 82.1618958442442, 83.41691309405913, 24.2170899914157, 0.2511656798061825, 0.5509689029666686, 1.0161005957953393, 0.20756476618830236, 0.4323282675637353, 0.469113358206326, 23.84883434541764, 97.50688260601413, 51.854357334875296, 57.20416430504092, 54.808674781553215, 48.346711127988755, 0.3055542605298181, 0.19740018903488116, 0.1813350035057914, 0.2574450114080983, 0.12720008981564354, 0.1261720994126893, 0.27595679065392864, 0.2136900221868869, 0.12416845007288842, 0.2399967460622711, 0.19203925895835125], [0.028357606366156574, 0.024863412310819955, 0.010235827160818924, 0.043911355427436294, 0.02895536945171414, 0.057024865471307314, 0.042251442078380816, 0.03126012198927422, 0.035085145369051926, 0.024248251368501977, 0.7659407741119786, 59.65006020761306, 46.04542124655939, 36.85839483814855, 52.50583164153561, 36.690670367210146, 4.2083874440962274, 0.2052936985367729, 0.05619916824563857, 0.08308610413223506, 4.698044859593915, 2.342890784625084, 18.454853642371393, 3.0128002310952837, 58.82495434053483, 95.94999190299743, 91.96899014134561, 92.94093778056484, 89.2439313088694, 90.38663541117023, 82.40610261117259, 82.03237133641397, 78.61260583323818, 72.22089967420025, 64.92724057166808, 64.90029388858427, 63.55789799844066, 66.62632896054176, 69.1142334476594, 73.43994094479469, 75.71795155925136, 76.80008642135128, 75.5085362157514, 69.7527325537897, 59.86631616469353, 58.19262512268559, 57.554530020683046, 57.258653871474735, 57.7501033198449, 56.48458196270851, 55.25626820902671, 55.511818470493445, 52.90994951801916, 53.783830058190134, 52.227182542124105, 55.287219632056456, 56.54959917068482, 58.61420539117629, 55.25228700330181, 60.91948824544107, 60.3350668568765, 62.64300123337777, 64.89447701361873, 63.28967063657699, 59.89025438985517, 68.94732875208702, 64.07173241338423, 69.51772766728556, 61.05071113955591, 62.724119770911436, 63.91863446081839, 67.55587577819824, 62.61709005601945, 65.94236173937398, 49.092620418917754, 57.862942064962084, 65.15966061622866, 69.3594051176502, 69.54612562733313, 61.06087792304255, 66.9413423538208, 66.532074405301, 60.118410818038456, 58.61126361354705, 53.6925761161312, 63.49548132188859, 67.63501351879489, 63.6559376408977, 63.19589461049726, 64.14577107275686, 63.202252772546586, 64.36028549748083, 55.83339398907077, 63.39031081045828, 67.13873171037244, 61.13216700092439, 58.00808545081847, 61.54607119098787, 66.23008328099405, 57.519299291795306, 65.14048414845621, 58.23689299245035, 58.978213110277736, 56.23887685037429, 58.684207931641616, 70.78451202761742, 61.95520577892181, 62.69782027890606, 59.358133885168264, 60.77535290871898, 63.93760304297171, 64.31795135621103, 63.00647943250595, 59.03315767165154, 55.17947212342293, 50.06117913030809, 49.842099066703554, 52.45130285140007, 53.22012662887574, 58.7330767416185, 57.52096629911854, 55.02537004409298, 53.05357102424868, 51.992993508615804, 51.569040206170854, 47.29234272433866, 54.69738145028391, 65.95998887092837, 64.59846750382455, 64.15973863294049, 58.829990663836085, 53.50275693401214, 50.563477854574884, 54.63699656148111, 57.55040368726177, 61.0849142074585, 60.77359960925195, 62.23629067021032, 59.05757050360403, 57.839956975752315, 57.37063753989435, 55.2620929287326, 58.660481514469275, 63.51964704452023, 65.04274260613226, 68.43983680971208, 68.2789804089454, 67.28509103098224, 70.15488532281691, 79.80921114644697, 76.44644552661528, 80.75448666849445, 40.11153805640436, 0.4081342916094488, 0.10989632397409409, 0.61655571263644, 0.05736907260612615, 0.19738114408908353, 0.6574244809246833, 7.5766752708342775, 80.61557200647171, 50.071294922982496, 25.25656907789169, 28.049967365880168, 41.1613525882844, 0.3524994850158692, 0.041759360821977745, 0.04393553699276621, 0.04673053600615071, 0.05805510817275894, 0.02862003361505847, 0.08446213594006916, 0.02204953114532175, 0.048298507312973665, 0.04396517693455662, 0.038832207811215234, 0.015738528511006267, 0.00933975135276635, 0.04323166306881655, 0.03906195757970695, 0.044322683355740966, 0.05682793107905215, 0.03973278247060315, 0.10429848120698046, 0.13565365555545977, 0.034324569447386655, 2.311975153223161, 69.82775180570542, 56.70889446812292, 44.84965924293765, 44.92553357155093, 50.32205204809866, 3.5346473128564897, 0.17060618727437912, 0.17811130552041918, 0.16165702393458736, 3.0734496347365843, 4.3664599426331066, 29.25891245565107, 6.521663598475918, 68.36437825233706, 96.89982521918513, 93.18693314829181, 95.11504480915686, 91.76509749504828, 91.6039586836292, 87.28273053323069, 84.79855229777675, 82.79007127208095, 75.4950354176183, 69.52448198872229, 68.63980708583709, 66.81386532322054, 69.73790599453834, 71.38715282563241, 76.01677340845909, 78.75360719619259, 78.46253595044537, 81.16139335017051, 74.17826437181043, 61.282409468004786, 60.82441783720448, 61.32918765467983, 60.879334941987075, 62.71873435666485, 60.16076457115912, 57.51683604332709, 58.16301907262495, 55.67971944808961, 57.49582782868416, 57.080068357529186, 58.91275659684212, 60.283821090575195, 62.10515406823928, 58.33796070468042, 62.19541172827444, 61.68490740560717, 64.92664044903171, 66.78528693414503, 70.09462202748945, 63.22285698306177, 73.13970704232493, 66.98371964116251, 71.69663567696848, 65.24127729477422, 68.63345284615794, 66.25182105648902, 69.02835707510673, 67.09323221637358, 70.58183531607352, 51.37830318943147, 62.65445847665111, 69.33736139728178, 69.84067209305303, 70.08698909513413, 62.624550404087195, 74.00920237264326, 68.44098998654273, 62.73514947583599, 64.13324302242648, 58.1680985419981, 66.96197402092719, 67.64258369322746, 66.48917152035621, 64.2338949634183, 65.13491438281152, 64.05363851977934, 67.76970771051222, 58.54758785616968, 63.76433234060965, 70.74463721244567, 66.39931001970845, 59.46463408008699, 63.16709656869212, 68.56878080675679, 58.27347301667737, 67.68758112384428, 62.79633060578377, 61.31611831726567, 56.829315154783195, 60.69300666932137, 72.37901826058665, 64.8458827695539, 64.44225911171206, 60.514640808105476, 61.45277369406916, 65.64655619282877, 66.3523357145248, 66.13281634546095, 61.118250431553015, 57.354053758805804, 52.916342981400035, 51.2114808636327, 53.17842791157385, 56.02171090341384, 58.87163054558539, 59.044144230504195, 58.71170374654955, 55.85662226523123, 55.65346702452629, 54.011029428051366, 50.36419007085985, 56.68277540514546, 68.1969008907195, 67.89381150276431, 66.66719221299695, 61.914369983057824, 55.74505829042005, 52.774270811388575, 56.8887782865955, 60.735262363187736, 63.17234469998268, 63.5744268663468, 63.020548974314046, 62.32486563344156, 60.91041972560268, 59.8120972418016, 58.58304216015724, 60.10616125599031, 66.89288539271202, 66.43868277149816, 71.01596324674546, 70.5118445427187, 69.07708860212757, 72.26421048564296, 80.12151025956678, 78.77803571762578, 83.11259992661016, 50.19575957329043, 1.0102626993771524, 0.3392600760825219, 0.7846098465304222, 0.014714608907759672, 0.25574524616522176, 0.7038491639879443, 7.086050991089114, 87.15399049943494, 57.08302582463911, 28.668034845782866, 42.554613774822606, 55.729023641155614, 0.6046302977108187, 0.03318317887944079, 0.12084389661228466, 0.03832367481663823, 0.02903089039928971, 0.10835932943248942, 0.09992681578883242, 0.020247619569061265, 0.05506382594185491, 0.03437219330319955, 0.028074146173293554, 0.10314580233347032, 0.07773718631435787, 0.14963589398370636, 0.16500547167754945, 0.12011107222567644, 0.20195931616810062, 0.14571041349441777, 0.26396549216681914, 0.17426399664292413, 0.1922171292526107, 2.2259063393838945, 84.58135497185492, 59.5193511439908, 50.60713383459276, 68.98375188150715, 60.98450937578755, 6.721978552879826, 0.5135223107232202, 0.5902415730299488, 0.3744788233551287, 7.534148443129755, 11.041974098451677, 25.741256360084783, 7.766997987224211, 76.85654501761161, 101.19937050727107, 100.90038391851611, 102.63167104413434, 96.7769059827251, 98.8423005996212, 91.57122258217105, 89.7921766773347, 90.01897596543836, 77.60188164249544, 72.49288466668898, 71.21770643418836, 72.3138520025438, 73.05327369320777, 74.87752099190989, 77.92954075721003, 82.72180634160196, 82.30467796325684, 83.54784181041103, 78.31614525087419, 65.50857897727721, 64.69611490926435, 64.98651935208228, 64.35705346445884, 67.8282843866656, 62.28213141041418, 61.23110486615089, 61.273089916475364, 60.83302743973271, 60.58551019237888, 57.762231288417695, 62.989919185638435, 65.05110509933965, 65.66772914701893, 62.87190683426396, 66.37720354141729, 64.7281018380196, 68.31366200600901, 69.06859274833434, 74.39436343408401, 67.14936133353942, 77.12781613872897, 70.30162119096326, 72.67037191698628, 67.82797844179215, 66.79949375890916, 66.31987417897871, 73.32135200500488, 70.33796587297994, 74.96953195141208, 57.02447268270678, 64.01226928157192, 71.31862901872205, 74.59653023750552, 77.67952888242661, 63.73264743435768, 75.31508491885278, 73.1290146612352, 65.45618787888559, 63.766101329557365, 59.346029450816495, 67.4448177891393, 69.90229252846011, 69.12225077229162, 68.28757824436312, 69.48529751070085, 69.43665227582379, 70.59575973018524, 61.8404999856026, 67.58790585302538, 69.49681358952677, 66.99009741506269, 61.859295983468336, 68.89580449750348, 71.53079786608296, 59.889607198776744, 72.14933995277651, 63.80335207908385, 65.219829774672, 60.65052740035519, 65.63696599775746, 75.01813011784708, 67.07317321531235, 70.59866228411275, 64.27187135142665, 65.34949156545824, 69.85021914205244, 69.43452635119039, 69.36646538396036, 63.38036760207146, 61.24403692060902, 56.756704238153276, 55.048308064860684, 58.67359007558515, 60.37205872997161, 64.8349158225521, 62.80675234333162, 60.90337907114337, 59.47450668581071, 59.140234454985595, 57.76187827510219, 52.926988294047696, 60.9508672068196, 72.19117595303443, 71.14830401635939, 69.40550081191525, 66.1238419625067, 60.150578175821614, 55.15200768747638, 59.3476023212556, 65.88598943525746, 66.1936209278722, 66.9957064044091, 68.63288802485313, 64.9103351562254, 65.17977845284247, 64.71093754614553, 63.4181910176431, 65.29613556400423, 71.05464566138484, 70.1328416024485, 75.98651624494984, 75.51481985276746, 73.77506040757703, 75.92939869050058, 84.96608457257672, 82.43056251156716, 90.42585911289339, 55.79054993967856, 1.206638613535512, 1.5260949490531799, 2.196156877663828, 0.14919547003603753, 0.7035777237146132, 1.0635397631314494, 10.510075207679503, 94.08151595823227, 65.42850379020938, 39.10836050587316, 42.948490342786236, 67.52106866528912, 0.6760906115654977, 0.18803422789900534, 0.1667733727804115, 0.17342871565732265, 0.13225637736820406, 0.24495587834427435, 0.2750374545012751, 0.13006360390253607, 0.10391719158618681, 0.1524668186903, 0.1440316390606665], [0.03601724454652398, 0.0534309669878454, 0.028782287206981453, 0.11192955196865144, 0.027835816220049898, 0.050531948556102095, 0.031063034379434203, 0.03185335749519929, 0.17994412491398473, 0.12363220384765057, 4.540339102668147, 65.27992048571187, 34.544110144338305, 39.020169934918805, 40.28617374358639, 36.995034525471354, 1.0051606150884782, 0.18126754180317928, 0.08278877774794256, 0.3997827687811467, 4.418391143122028, 2.257948671617816, 32.290755548784816, 14.159879876721291, 93.36342411656534, 85.62800807337608, 96.0638818433208, 85.92513545866936, 91.66433965006183, 85.09845672115203, 87.5689458847046, 75.92032232592183, 77.74690735724666, 71.89731982446486, 68.34631181532338, 63.63440382865168, 63.08965721438008, 62.40812578508931, 68.42653213008758, 75.15702909038913, 77.71064896737376, 73.90533016573998, 77.54989454823156, 75.19726476361676, 68.97322423996465, 58.65974018650671, 59.65175074915732, 55.90324747946955, 58.569933599041356, 57.53397287860994, 57.469453811645515, 57.740873982829434, 52.4407712874874, 54.04011772524927, 57.9509678963692, 57.16761565977528, 58.44344892809468, 56.63168261128088, 57.9667515139426, 59.66690678750316, 61.66110254103138, 59.78061237642842, 63.042765278970045, 69.68203575380387, 62.89989686781361, 65.4761056746206, 66.5510743664157, 69.1251297919981, 68.79568207648494, 55.37699091819025, 63.18740660144437, 66.89286970323133, 65.79639857815158, 58.81645456437142, 48.51048577216364, 60.180243061434844, 67.66363113157212, 64.57731808385542, 64.2176014377225, 69.10596509133616, 68.90033875742267, 54.60710025602772, 64.92600110269362, 67.1654587407266, 56.72640000620196, 64.9874528761833, 56.68312057372063, 61.56571442081083, 62.340284470588934, 64.265983873798, 60.451035653391195, 61.4763157598434, 58.86391132108627, 53.3602572256519, 64.01707418503301, 66.05428264987084, 63.128088597328436, 55.53781593999555, 64.18499085210985, 59.97729178397887, 62.77122351431078, 61.12549504926128, 55.071336300142356, 56.66849405534806, 53.844473823424316, 58.374913354073804, 65.71802177736836, 59.04623877617621, 60.08270940473003, 60.14012113694222, 64.07084595772528, 61.34936824921639, 60.136920482881614, 58.98334357046313, 56.54651618772938, 51.438107567448775, 50.740011968920314, 49.482233370504076, 51.70284794222925, 51.16150594526722, 55.62703024956488, 54.94522817673222, 54.0909202637211, 54.841501097525324, 50.57234241116432, 52.02847919156475, 51.27009676348779, 54.73880560167375, 60.38322179548202, 58.24184694597798, 55.11383125858923, 50.51571123061642, 50.86648879512664, 51.93072588213029, 55.40578503762522, 55.63656945382395, 58.65619044150076, 56.26257581095542, 56.73852405240459, 53.55197483493436, 53.75090176059354, 55.57931853878883, 59.87232915816769, 64.96149070801275, 66.86136522600728, 65.93062600781842, 66.5009464756135, 66.59502060182633, 70.64473444415678, 72.61887119662377, 82.38048168920702, 76.3997693215647, 64.49272824871925, 5.700234463137965, 0.19385864116972495, 0.11247365825599241, 0.09539971113084786, 0.18313239899373826, 0.311368714657522, 3.0654303489192842, 72.53551298572172, 59.37103063829484, 34.44928684542256, 19.666316893792924, 43.45508406239171, 1.6607622970496456, 0.14290057152750033, 0.00941597422840254, 0.00937304553395558, 0.05019735199429336, 0.032286342729123375, 0.05611062380335024, 0.09299031864371031, 0.08299443405121565, 0.1263925565346595, 0.016268434401060787, 0.01233989913617411, 0.022329896342970675, 0.0862992990521654, 0.04930821885805457, 0.0779460525260337, 0.012668260699889113, 0.044276036262031526, 0.03117656860981257, 0.14106882465702875, 0.3434374003160385, 8.04298673906634, 75.10452424326252, 42.330195365413545, 40.399671446892526, 41.09907711705854, 43.7408483412958, 0.4257626182609989, 0.2686039094002016, 0.2048194901116433, 0.32023042139987795, 3.1011803015585873, 4.465345346158551, 30.89481930578909, 20.56310603695531, 99.08165931701662, 86.82608819776966, 95.08670960703205, 89.79165107973161, 95.22124690394249, 87.17149995988416, 89.74294308693179, 81.66413922463694, 83.22328136813256, 74.70365801165181, 72.3902597735005, 66.74610245612361, 65.85536356895201, 63.19751454937843, 71.23988351514264, 75.3572190192438, 80.1828561290618, 80.25834606539819, 80.50966016707882, 79.07527292928388, 70.81076052881056, 61.00852604835265, 62.49997984978461, 58.971333272995494, 60.675348158805605, 60.37432193756104, 59.601575789913056, 59.41951113362467, 57.90480159944104, 55.92272989211544, 60.747068697406405, 61.47435457475724, 60.55319378452917, 60.940680811482096, 59.81166578108265, 62.42527438748268, 63.00065079042989, 64.0210710802386, 64.49715660464379, 72.09385410431894, 69.84638306402391, 68.56960450449299, 72.1076451578448, 70.80527705530967, 72.82911808260026, 59.49381259179885, 65.46715874825755, 70.661788909666, 70.93996340228666, 60.4197939749687, 50.99546809350291, 60.734250391683275, 69.25110063245221, 63.491621709639034, 66.43857294513334, 72.92708320002403, 71.73607118668096, 57.93292891594672, 70.49711212035149, 69.11577101676696, 59.345280278113584, 66.91718055355933, 59.40911293029786, 63.677447918922674, 65.2479806253987, 65.60143324636644, 65.2645291051557, 62.833263643326305, 62.68999515041229, 55.236020934197214, 64.30257174276537, 68.56328164377521, 66.81580297408566, 58.95036035968412, 63.26110793698219, 62.45294670904837, 63.30466978011593, 64.0608125348245, 55.98856687545777, 60.635339983047984, 56.82959364306543, 62.26395514703567, 68.17553966276108, 61.43874337596279, 62.01976799195813, 61.87326746602213, 65.2161584361907, 63.67957384355607, 61.90091233099661, 62.38928664115168, 57.66120672225953, 55.384988630971606, 53.681424817731305, 51.868528858307876, 54.18655549326251, 54.810765404855054, 56.45111630039831, 56.993301606947384, 57.621402509750865, 56.360474248086255, 51.42782703522713, 53.18356621649958, 52.982595735980624, 56.67080433137956, 61.89852752993184, 59.7760114362163, 57.9589028512278, 53.37853154828472, 54.554320842989036, 55.418042444413715, 56.86596185930314, 56.65312620901293, 60.708256844551336, 59.0461838629938, 59.64749105515019, 57.35676803896504, 58.49172546017555, 57.92739837400375, 61.896499664552756, 66.30228627112605, 70.05893630366172, 68.17408838579732, 69.83132116256222, 69.82636328666442, 74.61198437598445, 75.79639111795734, 86.30333823542442, 76.91014812838647, 75.49177200563493, 8.49118911450909, 0.11903116404409371, 0.19136082681436695, 0.22688300619202278, 0.10829323902726175, 0.3464805160558993, 3.060003014341478, 78.24326761307256, 69.22143966920915, 37.93957264192643, 28.088049657883186, 60.33100328137798, 4.020399273403229, 0.08327126758353365, 0.026073647370081277, 0.07037214724527252, 0.01740121605595754, 0.08067205383051788, 0.06732815050429876, 0.05766123938824862, 0.046496499975722645, 0.0652862427335593, 0.04374830510407206, 0.13449896187070878, 0.11672965205845334, 0.148089254395135, 0.2181386028326327, 0.22410031438114184, 0.12931662221108714, 0.14399935611553732, 0.09892817421425736, 0.25228732445788, 0.2602387195633304, 7.404480278491975, 89.452405283528, 44.560509958574855, 57.49602786956295, 54.467275604125, 55.909366376938365, 1.5904245165086563, 0.3794235838276725, 0.31084026720735336, 1.0981512478282376, 10.156614741971417, 6.372684134591011, 40.181615121902965, 25.569735034819573, 103.13086325122465, 92.72377183360439, 101.21682505453788, 94.83243803824149, 101.62561447389665, 93.39043355757191, 94.31393992516303, 85.69882254446708, 85.09713880477413, 79.1709081588253, 78.08751029352989, 69.95839811140492, 69.76857892928585, 66.8264796656947, 74.18654057287401, 81.40232101563485, 84.89585061227122, 81.3578962510632, 85.87716487146194, 82.32907510572865, 74.06670431936942, 65.41201414600496, 64.68961161951866, 62.73606731045631, 65.58371982266827, 63.04426754674604, 63.3340169537452, 64.02038466545844, 58.97212166940013, 60.587079140447806, 64.85066806116413, 64.18990558193576, 65.46030636756652, 63.75576980652348, 65.21512685283538, 64.84715753985991, 67.93756946440666, 66.93270529470136, 67.72973091371598, 76.47554951329386, 71.36725071937808, 74.756790438006, 74.63161976106706, 73.84483152820219, 72.1105790907337, 65.41408907982611, 69.44381452375843, 75.44184807808169, 74.38244727350052, 64.93892139004123, 57.10049606138661, 62.78645407768988, 71.35951580539827, 67.44094248740905, 68.33383083343506, 74.97332096099854, 75.73793211290914, 60.57359010942521, 71.71463151131907, 71.60547194942352, 63.504188983671135, 68.42013082196637, 59.35416836892406, 67.08277517749418, 70.8231238395937, 67.82261263939643, 69.40062138342088, 66.13177299499512, 65.63851533397552, 58.92591222640007, 69.65354365687217, 71.36765080113565, 68.03063161911504, 62.368145065922896, 68.47703656842633, 64.18262958526611, 67.7103465603244, 68.19770105423467, 60.71063380087576, 62.22581794185024, 59.05424433369791, 65.06146407896473, 69.9647758853051, 64.87395125050699, 65.81876001050396, 66.6918246976791, 67.97381216479887, 66.54635183272823, 64.68657962737545, 66.1119258019232, 61.32878757292225, 56.610066429261245, 57.6249954008287, 53.83316563021753, 58.057401410995, 58.698685399947635, 61.07585353236045, 60.48331675990936, 60.88555582108037, 60.033016897016964, 55.80265045166016, 56.98975970668178, 56.17483239020071, 59.75713306857694, 65.8316489188902, 65.08300965832126, 62.61285781860352, 55.52276188327421, 56.9627384985647, 58.89315259072089, 61.462422724693056, 63.488997643993756, 63.69234508083713, 61.987357447224284, 64.65167445521202, 62.242174225468794, 62.66424871260121, 63.197279207168094, 65.70152036605343, 70.63412835521083, 73.80745918520036, 71.22645331967261, 74.56134657705985, 75.35376733349216, 76.69933642110517, 81.77546393486762, 91.74648977095082, 81.36938879566809, 80.50205076894453, 8.829512173129666, 0.29917988806001605, 0.5323825680440473, 0.3616792101773524, 0.36130382709445497, 0.7662827557613774, 4.73734995049815, 85.0839674857355, 75.58601871613534, 52.53162122541859, 31.397625976993194, 70.84850157460859, 4.4569367651016485, 0.21718595717703143, 0.18262687289426405, 0.1411689523487322, 0.143287384642228, 0.15499927554159396, 0.16605151877287896, 0.22319084544095302, 0.14136009128584018, 0.17697332787417597, 0.12724372618381055], [0.11246077265710601, 0.09334526250078794, 0.10906135708454157, 0.06812953976013007, 0.03138330318183909, 0.026453115616834937, 0.14227253264717518, 0.05247842475411393, 0.17167727012307415, 0.2969529930382006, 14.965022840807515, 69.99714328396705, 26.06017251168528, 46.85448069726267, 48.39310492238691, 33.382198195303644, 0.08042115237443678, 0.07224139411963763, 0.11594715453083478, 0.1771050183883598, 1.1202045289739486, 0.996367580467655, 0.9118579087718841, 39.35361062326739, 91.7998653842557, 85.28718548436319, 93.02611597122686, 89.2667281243109, 91.54039275261664, 86.01574220964986, 84.80383965276903, 77.52426578152564, 77.63814003236833, 69.1995999120897, 66.73965407956031, 62.9194498831226, 63.42101512416717, 67.09960999027376, 70.61716018184539, 70.5868245709327, 76.60902777025777, 79.20092213538386, 78.40497124579646, 78.04486628501647, 74.73596265239101, 62.828505808307284, 58.66696126999394, 58.03642457531345, 56.131329382619555, 56.93553293904951, 56.63375362273186, 55.90553029890984, 53.45078552922895, 54.64631219064036, 54.74902337597263, 58.01782077358615, 56.41840765553137, 58.332351715334006, 55.42631080073696, 60.41962531305129, 59.54553688726118, 61.66655855794107, 61.96298776134368, 63.09283433421966, 70.3920239786948, 68.56852193032542, 65.36451032084804, 66.65897876985612, 63.63813792505572, 63.533591070482814, 63.39286819581063, 66.24583551960608, 61.748689066979196, 52.948118102165964, 48.53668720491471, 54.62728869530463, 70.0385792024674, 60.72048287237845, 70.47823767508231, 63.089825876297496, 56.621617809418716, 63.52360079365393, 71.91219345215829, 53.781810037551395, 52.255686406166326, 60.458790179221864, 62.84399917048793, 63.43343727050289, 60.80175830471901, 66.33092741812429, 64.57066574404317, 60.18704052894347, 61.29022675175821, 55.917266030465406, 50.55117337934433, 63.33176159089612, 64.65715008397257, 64.046233084894, 57.18273247441938, 65.88744855696156, 58.46913653035318, 61.001387334639034, 56.712506971051624, 58.37082232198408, 57.66049285088816, 58.25231967433807, 62.500034762967026, 59.639712995098485, 59.97886857678814, 60.766680548267985, 63.73900167403683, 61.064141335025916, 64.88139198672387, 59.820416588937086, 57.54407298180365, 52.80902301111529, 55.18792483114428, 53.906019733798125, 50.7663389175169, 50.111550208060976, 50.88850505890385, 53.59963947726835, 53.08342418363018, 51.73034375713718, 51.741934360996375, 49.266910937524614, 50.2607963931176, 49.53808792175786, 52.83124716051164, 51.346484922593646, 51.03686086593136, 49.307181912083784, 52.99171132426108, 50.44118619734242, 52.22015365477532, 54.70270802897792, 56.54896766908708, 55.143296103323664, 53.16897892182874, 52.478932026893865, 54.284567679128344, 54.26970581854544, 63.50778187474897, 64.13063856863207, 66.83718773626512, 65.33302545547485, 68.90290398751536, 66.17278529751685, 71.7452024644421, 74.39289646763956, 82.95881163689398, 77.94630496732651, 80.71924025012602, 23.170097604874645, 0.34572867736701046, 0.21842205536461648, 0.1083291685509105, 0.13946164880068074, 0.48509156211249294, 0.5611873514229252, 65.33129569022887, 64.88744812626993, 49.105509327303984, 35.3741228965021, 49.02347687752017, 9.442334463519435, 0.39040441234265605, 0.20790474068733955, 0.17620763831561612, 0.04750724956994096, 0.05179872090417532, 0.09658242831186903, 0.12650386911005745, 0.018163295425174218, 0.027975108241662387, 0.00567600719683293, 0.051668941779362584, 0.061889443351256276, 0.04334527007754772, 0.04569858109818832, 0.12437909360854857, 0.05988331954745997, 0.10383691323260147, 0.03295664284979144, 0.1383640593098056, 0.3001234632345938, 19.864996710131248, 80.41453484565982, 35.81413438243251, 36.67599285802534, 52.42560348203106, 39.039977904289, 0.06795697079430665, 0.3190644049356061, 0.36493738211931726, 0.1579574168088936, 0.7413088410131393, 0.5010166914472657, 0.8195723220705987, 47.6585901168085, 94.46063656960764, 88.31640058948149, 95.99702896610384, 92.33442952555995, 93.39881174025997, 89.63695280013546, 88.45943374018516, 81.29573452857234, 82.44873877494567, 73.81287205603816, 69.67296723396548, 65.75190321091684, 66.54148809371456, 69.587004569269, 73.15825200849964, 72.83996735849689, 78.27132040454497, 82.568386754682, 80.20455468085505, 80.313518124242, 77.62922056259649, 67.22261551887759, 61.18401288986207, 61.27516877266669, 59.175751516895915, 60.62855428264987, 58.652601472793094, 59.70545976392685, 56.56456693526238, 59.73718781625072, 57.7817411576548, 59.998625555346095, 61.294572737909135, 59.98061010914465, 58.40061272344282, 63.50314171083512, 61.79232543514621, 64.74129669127926, 66.34017636699062, 64.84883631429365, 71.8816303437756, 71.15199104432138, 68.01305155600271, 70.4527344242219, 66.6532442646642, 66.50385687428137, 67.94378249875962, 68.20647931868031, 64.29329141493767, 60.16531452055901, 50.390262065395234, 59.974934439505304, 71.37794310046782, 64.57470578532066, 75.27137402565249, 65.99299169355824, 58.84090662002564, 67.55713878139373, 73.13264677601477, 55.184335862436605, 56.404098849142756, 60.723589389554924, 66.7515702401438, 65.20130049797797, 61.84538333646713, 68.89080739790394, 66.77060942496023, 63.57101440429688, 64.79134613467802, 61.04204662384526, 53.96388253858013, 64.0787220770313, 65.57834617553219, 65.37055861565375, 60.36021317205122, 65.71744518895304, 62.54953507454165, 63.23950352207307, 59.38289973043627, 60.47415410318683, 59.598402592443655, 60.752183468111106, 62.74592814906951, 63.47182158500918, 62.0532375766385, 63.797766623958466, 64.52986917188092, 65.44711151430684, 66.1533695651639, 59.32529972445581, 59.491843561972345, 56.93028480775895, 56.65153372672297, 55.86341581036968, 53.15846304739676, 52.071436989691954, 53.35904129089848, 56.125339923366425, 52.96452537659676, 55.38448264521938, 53.02420816113872, 51.167456180818625, 52.11904279647335, 52.1175483734377, 55.44604424507388, 53.10979035592849, 54.719625211531124, 52.45442505805723, 55.15305888268256, 52.9646469700721, 56.22202634811402, 56.86076079645465, 58.33823134822231, 55.997686386108406, 57.32178049702799, 56.62605008771343, 57.789825162579945, 57.63709983518047, 65.05655719387916, 66.13736629486084, 68.31334037165489, 69.60752641001056, 71.94389404789095, 67.5869958631454, 72.48118815883514, 76.9081163406372, 84.4596516701483, 81.03958022209906, 85.56469317405455, 28.614916147724276, 0.3653574434499587, 0.1756486852443026, 0.04179363559571005, 0.19718307971714005, 0.9793071701161324, 0.584526066818545, 70.9946333977484, 74.84736581002512, 53.32318690515334, 37.68304963265696, 64.33424095953664, 14.297239318970712, 0.6771530222988899, 0.2338744165195573, 0.10176826133242539, 0.04387638734413251, 0.022234451363704378, 0.04068897511329382, 0.05374457274052886, 0.00833213697337816, 0.05660484244506206, 0.034034248937161705, 0.25192844290887156, 0.156990782387795, 0.14892105734156025, 0.21818738731165088, 0.2960847089848211, 0.20258919365944403, 0.31518986929328213, 0.1359101264707504, 0.26258239702832314, 0.522211617039096, 22.335529019755704, 94.82342443158551, 37.68185330975441, 65.58329620668965, 68.30904929868638, 46.742583320986846, 0.6606322442812305, 0.6606872187506768, 0.6253156522589346, 0.5733304578931101, 5.513195260878533, 3.723370682808661, 1.5506590374054448, 52.6072366776005, 99.49015848098263, 94.701109240132, 101.2520165597239, 98.74917568699007, 99.77700925642445, 94.73599480044459, 92.92663681891658, 87.27008481179514, 87.84314309397053, 77.74809191303869, 73.93969012844947, 68.5848468349826, 70.6490255171253, 76.57443246533795, 76.92106016220586, 76.79767024132514, 81.56955519030171, 87.03366787202897, 83.63482429135232, 84.31792074634184, 80.69853798035653, 68.98016683516964, 65.00620180560698, 64.97677618457426, 61.198423677875155, 62.21835759378249, 64.69895862763929, 63.053190938888065, 59.90350807866743, 63.07965909281085, 61.2097514829328, 64.34925579255628, 64.28538783904045, 64.17335710217877, 61.8920869981089, 68.05842553415607, 65.41757998927947, 69.89745232366747, 70.16113758087158, 68.5391826014365, 74.1239317001835, 74.5058842628233, 74.53953035416143, 73.35156994481241, 71.61168498377647, 69.07776324979721, 69.9784335782451, 71.66231493796073, 68.43870716710245, 60.606651767607666, 55.50900613107989, 61.15522269279727, 76.3211650233115, 65.60097040668612, 77.84554712234005, 68.97452646686186, 63.233933756428385, 69.26497013338151, 76.84313051162228, 59.391897647611565, 54.62746520196238, 63.87361349598054, 69.5360137570289, 68.75745465678554, 63.66805384235998, 72.35742953515822, 69.88473599956882, 66.46877519546017, 65.07938931065222, 62.1070642625132, 56.98358981840072, 67.87935364630916, 67.85494081435665, 67.24234504084434, 63.45105263494677, 67.27090774043914, 62.67472536333146, 65.7783870543203, 62.46304288987191, 63.890616970677534, 63.73065094793997, 63.35620580180999, 66.06685776864329, 65.01891028496527, 65.8927280672135, 64.21259649338262, 68.8888854365195, 65.75506071890554, 71.47130335530927, 64.85182123799478, 63.797354775090376, 58.223282367952415, 60.52319157508112, 59.942892597567656, 56.86061566875827, 55.530469340662805, 58.34031020441363, 61.89447572154384, 56.22905131309264, 57.13486386883644, 58.37185782770957, 54.56964554325227, 56.86160802841187, 54.96536170282672, 58.50060962861585, 56.86157272708032, 57.868696182004875, 54.9216978780685, 59.892439150041156, 55.6395386880444, 59.074628891483435, 60.84755982122114, 62.30393978857226, 60.83003467129123, 60.30740630242133, 60.31119923437796, 64.26396777552944, 60.60338051088395, 71.45926167888027, 69.0129735392909, 74.3566616119877, 71.52340812067833, 77.09671174326252, 73.04376586791008, 78.9930522057318, 83.43211620084702, 88.81534960962112, 85.54736414263326, 93.97978536544308, 31.04351243665142, 0.7484781982437257, 0.42505659162998205, 0.20988982771673512, 0.47157136663313837, 1.766437691065573, 1.4477644812676216, 81.93235874176025, 77.62644352451449, 70.31438458350398, 51.92163382807086, 68.82472330524077, 15.345252502349117, 1.023220494389534, 0.4668119994382705, 0.33293320106402524, 0.21629521142571204, 0.1993586621697872, 0.2829060048585938, 0.2204488328988514, 0.11963345470928377, 0.11685624042706144, 0.19461195074742843], [0.06960168495894441, 0.047442557275175094, 0.1084060378132328, 0.06430912822965654, 0.00838323024987814, 0.05138412944131321, 0.07864136924786914, 0.07950331775411483, 0.11646011934405374, 0.19605535232732374, 22.8593203713817, 58.47684791011196, 47.47629404067994, 43.49347229926817, 43.95108738253194, 30.084771417802383, 0.1849886606777868, 0.311316620678671, 0.17086422100903528, 0.06203553631841656, 0.3806834613844272, 0.3541088825271976, 3.738487252304631, 61.11068025712044, 90.71348651762932, 85.15410730915686, 88.16442443478493, 86.19817164636429, 88.24139702704646, 85.13502890063872, 82.82204643372567, 79.28663376838931, 78.09030302109258, 71.66808866685437, 64.3295733390316, 61.45314239686536, 63.76290459786693, 65.36069385467037, 68.35771022304412, 71.37413840140067, 75.43918871110486, 76.87975760429137, 75.67465643728934, 78.45253390650596, 74.34054067057949, 69.51471528699322, 59.08839641078826, 55.96533467692714, 56.49759638694025, 57.63014939523513, 56.13131761550904, 53.99637937545777, 52.425054350206935, 54.73437332337903, 54.30336759936426, 57.66247364782519, 55.4889000615766, 55.78236003075877, 55.65365529829457, 56.398250595215835, 57.47340363840903, 60.51147545537641, 61.09067224687146, 62.85862176649032, 58.56938446721723, 65.21736652620378, 66.6328400950278, 69.81826751462876, 71.6838252159857, 65.15358878720191, 65.17470682820966, 65.77165234473445, 58.81164181616999, 60.59095051980788, 48.86479739219912, 63.08732340412756, 62.53648534897835, 64.25797047153597, 68.45271002861762, 62.225559065418864, 61.30689682499055, 70.79106238580519, 58.05897035906392, 55.43827402976252, 63.36220310580347, 63.96090976653561, 66.21478603732201, 65.37174709381597, 64.72874510672786, 64.79617849473031, 66.04980330313406, 62.483046977750725, 61.22332288372902, 59.67393175248177, 61.57232753692135, 54.60187565895819, 60.86915246901974, 62.235521885656546, 61.86353214325444, 59.05830398682625, 62.164887843593476, 60.25590558205882, 57.29196263897804, 54.11456431111982, 55.80905175978138, 56.999291066200506, 60.86017808606548, 59.799020059647106, 58.588098095309356, 60.61290794803251, 61.06780875113703, 61.7589460649798, 58.08503843122914, 62.08372615998792, 55.905126294782086, 55.041122282705004, 52.78228813602079, 54.62884195389287, 52.62893130702358, 49.46795986544702, 47.28681610476586, 52.45873574287661, 51.658176068336736, 50.579132033932595, 50.31507415156211, 48.59964516855056, 49.0090347105457, 50.35170516660137, 50.12523143522201, 52.56592235257549, 51.78196607097503, 51.8510978452621, 50.00734067732289, 51.490843834415564, 53.54706402747862, 55.904337898377456, 55.76503884407782, 56.402957439422615, 53.89033417547903, 54.295405187914454, 55.01088865341679, 54.943474877265196, 62.38323442397579, 65.99889878303775, 65.90251045842325, 65.60049579989526, 67.57905698591664, 66.01840865227484, 69.78598640811059, 72.2015937682121, 78.47770767827188, 81.08213793846869, 80.53363369357201, 47.35146853231615, 0.2704278421738456, 0.018974038614561, 0.10234269704068862, 0.20905664581204617, 0.4915980387839579, 0.07119274232536554, 53.41593527024793, 74.06608458488219, 48.854418800723174, 39.73333527964931, 48.603842104634936, 19.394084791983328, 0.39707357544572125, 0.10778617309105974, 0.14800783457054248, 0.04076217864489844, 0.125402104439995, 0.013453127354413513, 0.0733529340716139, 0.055032266949814175, 0.026835104292859475, 0.0455622902260192, 0.0500294829778854, 0.030507771936695904, 0.041237808163127596, 0.15423737045738006, 0.04276575520634652, 0.02788836602121592, 0.10756170166836632, 0.08455737599081571, 0.09499600577738979, 0.19122742026323275, 34.73609839716266, 63.655568938101496, 52.28417065835769, 34.759346285173976, 53.09511284674368, 33.572766550125614, 0.3247923217713833, 0.9033274278044702, 0.11926662116762131, 0.07821817461761736, 0.41472316869804937, 0.29224624076197225, 5.3664079116236785, 68.79810610125142, 94.46953250515847, 89.29247456212198, 92.50224421101233, 92.3863224829397, 88.57426504934989, 87.18733849063997, 86.73548144678917, 80.8840347105457, 79.6858133808259, 74.90054530482139, 67.73435931051931, 65.20283414471534, 66.10356330871582, 69.33985602471137, 71.87622531767815, 76.19214257886334, 77.75423434472854, 79.32732443655692, 79.29043846745645, 79.27896161233225, 78.89969195089033, 73.42029771497174, 63.20949739025485, 60.539355662561235, 58.98416726819931, 60.43780942117015, 58.51753857827956, 57.47372135039299, 54.62806924696892, 55.31269542632565, 59.87805974098944, 60.296372675126605, 59.243031932461655, 58.784938320036865, 60.53415852208292, 61.439606297400694, 61.797200941270404, 63.85179727308212, 65.4994986903283, 64.48163970824211, 64.93016665981662, 68.1099105650379, 70.26919103437855, 71.76254718534409, 72.8008456383982, 66.95410574636152, 70.29917363197573, 67.35473663576188, 66.91909467020344, 62.97028772292599, 54.85193460218368, 68.68713440433626, 65.8333198485836, 69.52953400150423, 69.7717325149044, 62.87259717141429, 65.69227141718711, 72.82030059445289, 61.77156825219432, 58.442495792142815, 66.72466278076172, 69.44287315491708, 69.51563312161353, 67.88992835629371, 66.0485089209772, 66.81402221802743, 67.52016652014949, 65.08265272263559, 64.782422742536, 64.26469733638149, 64.59658476614183, 56.30447064676593, 59.97729178397887, 65.48292667635026, 63.76631313754667, 62.27197639403805, 64.53141850809898, 62.89160105489916, 59.284730649763546, 58.02327679049585, 59.147455538472826, 60.71418354588171, 63.18814008466659, 63.983863476784, 63.24091557533511, 63.14607266456851, 65.49250118194088, 62.524679014759684, 59.954875438444084, 61.66722143850019, 57.14436777176396, 57.52965434905022, 56.08525330020536, 56.74378395080567, 55.11138762197187, 50.86881476063883, 50.36209944755801, 54.330188766602554, 54.6801269438959, 53.95003264950168, 52.850466774355986, 50.78498586531609, 51.73970253236833, 51.51071456170852, 53.992307955218905, 54.54462866629324, 53.77594217177361, 52.38678378443564, 52.52888341103831, 54.631854334185206, 55.60455506847751, 59.499849119494044, 58.623030724064, 58.27197467127154, 57.147089896663545, 57.47913422123079, 57.220504899178785, 57.69355843144079, 64.37816366072624, 66.72952651977539, 70.20718620669457, 70.04182692497008, 71.17508595989597, 69.21439509237968, 72.46032114951842, 74.82816188566147, 79.97742591365692, 80.2958909926876, 83.56518653131302, 55.57902436102591, 0.5229197887163008, 0.03751127304689538, 0.20899894406958935, 0.23739331882567177, 0.856262050088375, 0.12302843463276664, 57.08499877683578, 81.85263264563777, 54.854405695392245, 37.34112877999583, 57.31362588943974, 24.988665311567246, 0.18146796572592952, 0.029255131995605848, 0.0507988152845252, 0.08621485318027197, 0.14012757838974077, 0.0900591896366208, 0.12301089121930062, 0.09445140153289804, 0.022819200530648235, 0.048425976682694695, 0.24416919797658923, 0.1322318472328686, 0.27075612617115824, 0.22759742914668976, 0.14732345758426577, 0.1214556331415811, 0.20784066509335272, 0.28183253181557505, 0.26114239687881163, 0.4717874953583364, 43.78284123636062, 76.54089620036464, 58.77997652176888, 60.32052270827755, 67.18500783366542, 38.62497937294745, 0.555059015750885, 2.0794560688157238, 0.36611109010634885, 0.2237474083179428, 1.7671824511020415, 1.6236265219988364, 6.498164188477301, 81.23754224469586, 98.286728243674, 96.9228103083949, 96.59360577983242, 98.90869063715782, 94.21286044582244, 93.79775601048624, 92.67547961204284, 86.98643469041394, 86.00907418035692, 80.37184376870432, 71.99690095839962, 69.93025118304838, 70.92524666940012, 73.86749498305782, 74.34292547164425, 79.01749641664567, 81.63410171385735, 83.82032102154147, 81.89082868637578, 84.94807304874544, 80.35854693382018, 76.65034601765295, 64.73176925413071, 62.64710795494818, 62.86692542414512, 63.85393888719621, 62.16855133733442, 61.61437926753875, 57.53981328779652, 60.786990581020234, 62.998905335703206, 65.00250693290465, 61.91785304777084, 64.08515084174373, 64.09521956597605, 64.31065182532033, 64.62616728198144, 67.03294538682508, 69.06337599600516, 67.0467129061299, 66.60996483218285, 71.7463791754938, 73.49332440283992, 77.08551729879072, 75.12077854525658, 70.00129315160936, 71.89860636188139, 73.45474396982502, 67.59714695715135, 64.00656223297119, 57.66692553797076, 70.34836799867692, 68.7864488170993, 70.30501796353248, 74.41577173048451, 68.0262307197817, 68.26427152079921, 76.97770703223445, 64.56342504870507, 60.490718272424516, 67.68128964208788, 70.89275375489267, 70.33597330893241, 70.81519280710529, 70.5548180303266, 69.38275106491582, 70.11765418514129, 67.70487877630418, 68.38293890799245, 66.41255978615054, 65.10823049852925, 59.30345996733635, 65.72672551678073, 68.21618326248662, 66.06295893269201, 64.95779583531042, 65.58335504224225, 65.59554184636762, 64.34929893862817, 60.36351188536614, 62.38135168629309, 64.4211999062569, 64.76891409966254, 66.49045805777273, 64.46485196390461, 65.7174491113232, 65.99689837424987, 66.80563619059902, 63.186869236730764, 66.92408392506262, 61.571923532793605, 62.07477923362487, 59.67570074142949, 59.702255187496064, 60.13118990005986, 55.252420363887666, 54.10791981604792, 59.12389386084772, 58.86619021815639, 56.82546338727398, 56.6338752162072, 53.140463290675996, 53.52805622162358, 53.85102810398225, 56.82688328527636, 59.43101544534007, 57.353163380776685, 56.802184120301284, 56.66364600581508, 57.598460566612985, 59.382197626175426, 62.65423097918111, 62.63698431753344, 60.797490765971524, 61.90378350596275, 60.51104791702763, 61.519226489528535, 60.27239914863341, 70.26438220854729, 73.79347201316588, 74.95891017298545, 74.20888239337553, 75.97980899195518, 72.94703237472042, 78.49760193978587, 79.63279078083654, 86.75030016130017, 85.81083759184807, 87.8787660598755, 59.23124521009384, 0.7201560502571445, 0.30795343340404574, 0.7506506397358833, 0.6344219861972717, 1.6911219324796432, 0.3164886334730733, 66.15413834971767, 84.89815696593254, 65.80133684219854, 54.87097770937028, 69.98907889089277, 29.019461562556607, 0.3784459637057397, 0.20507257491830858, 0.27688341996362137, 0.3242742624734679, 0.2397652649350705, 0.16533413871882424, 0.1773662696922979, 0.16428026220490857, 0.18841148023643803, 0.1702823312652688], [0.10063004619892567, 0.08857206741888678, 0.030406709617724827, 0.03368826064791891, 0.0759093618140586, 0.05217621455930414, 0.0905693888724331, 0.017140087326087298, 0.0317598641249201, 0.04206656207961421, 36.496736618780325, 45.183390186678984, 28.153292402144405, 40.363781759815836, 50.545560467627745, 24.35380812614195, 0.6818484058303218, 0.2669142565179256, 0.10944361197611979, 0.11142742729956105, 0.14098084711980435, 0.19949137924178956, 6.618501034475143, 63.76623076777305, 84.99121912064092, 86.03794282482517, 86.55205572805097, 87.66579704899942, 82.62595930407124, 82.83801832506734, 79.8389191781321, 77.76753902435303, 71.9810624276438, 70.19447772733628, 65.6659209343695, 63.822889404912154, 60.706511389824655, 66.64479547931303, 69.46814890830748, 66.84926079165551, 71.71826362609863, 73.38084651577857, 74.48696274911204, 74.09541606903076, 73.84579643126457, 72.42476878627654, 62.376915485628196, 56.55805187840616, 55.7214887680546, 56.03350154815182, 54.917802964487386, 53.184444827418176, 52.9520522394488, 54.37559020134711, 54.44338836977559, 56.06311544295281, 57.4034442440156, 55.52522120937225, 57.3951562758415, 58.71204499275454, 56.49534886883151, 61.021764047684215, 61.1943365681556, 62.20584131056263, 66.40560150146484, 65.264740913145, 66.67114596213064, 69.85542804964128, 66.06509270206575, 66.54181757280904, 66.04597506984588, 66.41374434194258, 68.32159303849744, 59.303985564939445, 50.21579896250079, 66.51480813180247, 63.0387762285048, 67.25272363232028, 60.97850422705374, 65.67493846339565, 66.74853432563044, 61.971256117666925, 56.50795536656534, 60.66707195774202, 63.45461414706323, 63.15663952981273, 67.06589329627253, 61.37423607610888, 60.556574867617705, 61.35359656426215, 62.46585130691529, 65.17617771702429, 62.61119473365046, 58.81521901776714, 63.43127604453795, 61.453797432684134, 56.95780807925809, 60.54556085217384, 65.89283789357832, 61.873039968552135, 58.13234613787744, 57.79317094433693, 50.0008491546877, 55.83617102715277, 55.82395676643618, 58.40447625806255, 62.21290549924297, 60.39174118349629, 59.483069219896876, 61.86912544312016, 62.696984814059356, 60.4546481563199, 63.55954147154286, 57.75476701797978, 55.259872867215066, 55.29473881567679, 54.45265693049277, 56.23498978153352, 54.06560528662897, 49.28021953951929, 48.07684813776324, 47.446888031498084, 49.6051682964448, 49.94431211102394, 49.106968449008086, 47.609101572344386, 51.65763870362313, 50.20779732734927, 52.6938622228561, 48.35933723757344, 49.673335167669485, 51.45259680286531, 49.90129939971432, 52.88892169152537, 54.76445398023052, 56.18443043001237, 54.132352259851274, 53.96263914723551, 51.134598485885135, 56.21299312960718, 53.624821093774614, 57.27128390342959, 63.5918108109505, 63.280162811279304, 65.4874413244186, 66.03030127863731, 64.95348515049105, 66.71462151312059, 67.35297941392469, 74.2304789635443, 75.76986805085214, 82.66056245373142, 77.0059794764365, 70.04542766078826, 4.7427500736328865, 0.15756874976138915, 0.32776486549165945, 0.08120426277239477, 0.26772891441660546, 0.08227000598825755, 43.01636695861817, 80.91196983091294, 54.55629379518571, 38.154396933894006, 33.277368930078325, 24.69078287001579, 0.4505821509707359, 0.13637734817401057, 0.06981813544107061, 0.04642524613788532, 0.017939040422319405, 0.03572749860224224, 0.06807879409602574, 0.015354241571208883, 0.05830437786156132, 0.06883673084479186, 0.05945963845137627, 0.09343560724969834, 0.08457617578847755, 0.013710651640600015, 0.12211692789869925, 0.01983510803491358, 0.015038123050133788, 0.07995036070144947, 0.08574547876994457, 0.3624467996339644, 51.012142089105424, 54.66839121234033, 31.68869330037025, 37.0160388177441, 63.41138962776431, 27.175845599943592, 0.6875952910031042, 0.14890254865730965, 0.07813436459870109, 0.016400414113436016, 0.09373091116187074, 0.09027751703416148, 8.547768323652207, 70.18740177154541, 89.01487273554649, 91.70053528201197, 91.19148223630845, 91.4205486543717, 87.60018364075692, 87.529188740638, 84.83970580562469, 81.15167371688351, 75.82334564578149, 71.90733755788496, 68.36260534101918, 68.97129443383986, 65.15733857308665, 68.33351704382127, 70.59129607292914, 71.5871701701995, 74.06073447196715, 76.06786620232367, 75.61442452092325, 77.47664820763373, 76.36410713195801, 74.87232777380174, 65.90800962140484, 59.500206055179724, 58.08610139354583, 58.12149686198081, 58.72339240966305, 56.09920909327846, 57.20578032155191, 56.56505723153391, 57.32622062006305, 59.18513774871827, 59.89670668878863, 59.935624445638354, 60.56282712567238, 61.536449616955174, 60.71056712058283, 62.947687025993105, 65.4455033425362, 65.50298959978166, 67.00854824435326, 68.46802296177034, 69.19084518186509, 72.13906334292504, 68.04443051738124, 67.88172275789323, 69.14065453314012, 68.70762486611643, 69.23093180502616, 61.987855588236165, 55.92226705243511, 69.84212337001678, 64.87188416142618, 66.78407099939162, 64.2842464293203, 68.0709300502654, 70.68791973975398, 63.74889389161141, 58.468920799993704, 65.16938024951567, 66.29083295022288, 64.59794190622145, 66.49427060158023, 66.99633398363667, 63.07573280026836, 62.59327342433315, 64.8825216293335, 65.88408316335371, 65.13191769199987, 61.31872669343026, 65.05590215806039, 63.96346715188796, 60.438484068839784, 61.679588671653505, 67.344177615258, 62.044294572645626, 62.540348883598085, 61.060097371378255, 52.55822273992723, 59.45962129100677, 60.051397123644435, 60.369022815458244, 62.951821204154726, 63.63704358377765, 61.813282658976895, 63.82305414445939, 63.90848728918261, 63.53014722947152, 65.45450518208166, 60.169440853980284, 57.49203489672754, 57.796351986546675, 58.35476021612845, 58.92854021441553, 55.937270118344216, 52.441920541947894, 50.30245588671777, 51.46817645718975, 53.06643639841388, 53.447125957858184, 50.47814669147615, 50.168173543868534, 52.89435025184385, 51.308179055490804, 53.847239094395796, 50.26160047900293, 53.31545591354371, 53.03601057298722, 52.72051472817698, 56.47597628255045, 58.47925624539776, 58.57015717414118, 57.13480895565402, 56.87990196289555, 53.64333075861777, 58.33195163357643, 57.59113750150127, 61.14065108760711, 65.46000434506324, 66.66323846386325, 67.98474773283928, 67.61438969642886, 67.896831727797, 70.80050745318013, 71.03033481105682, 78.0218105931436, 78.50788639437768, 84.90485637418686, 78.92416754076558, 78.76677067049089, 6.758965523012224, 0.22457643802608215, 0.37351254133447526, 0.343306920220775, 1.4154750397128444, 0.12499593228342072, 47.091803704538655, 86.96235918229627, 64.25761745822045, 37.974921041919345, 45.70369651240688, 36.25269066902899, 0.389188630806823, 0.13078933431496545, 0.09340884779850323, 0.024219595849694266, 0.10760290953781336, 0.036419716498423974, 0.02097465233096192, 0.02670569672069002, 0.02301989641461161, 0.027702804204196702, 0.1494499644444835, 0.2756010194218928, 0.16179968482784687, 0.11133332105894243, 0.22358188736102275, 0.1431630179286003, 0.22799725043437175, 0.25518200300153226, 0.16969135571872035, 0.39905008229036487, 66.54524572433965, 61.314396396760024, 39.80800936298986, 56.61261989224342, 74.52562162953039, 31.85221495166902, 1.2278735902040236, 1.3348847964117605, 0.2941507046982166, 0.2847599989223865, 0.27665298071599775, 0.37519695417534926, 11.484461580553363, 77.20300013019194, 95.74886845004175, 96.40213135750064, 94.85001810135381, 98.03644180297853, 92.58034644588348, 91.83920675708403, 90.06676612361785, 88.04643169526132, 81.78701923739526, 78.95667614475374, 72.85034594997283, 74.0394046229701, 67.65067162052279, 72.31120832504766, 75.58566570281982, 75.20244229224421, 78.8932357295867, 80.12048259858163, 80.96543958110195, 81.20908152672553, 79.99460589501166, 77.34287969527706, 69.98964371219759, 63.8427326756139, 62.890083097642474, 60.810250236142075, 61.94452124257242, 58.213621570217995, 60.006650724718654, 61.877495781067886, 59.80131856856808, 62.86180280870008, 64.29879450028943, 63.457465710178504, 65.90109056042087, 67.08175536124938, 62.75637734320856, 66.42847676430979, 67.09439323794457, 69.97189890953803, 72.98160414541923, 71.88824345988613, 73.13638087241881, 74.23275393824424, 71.75352573394775, 73.10340158400997, 70.04442353402415, 73.69677774367794, 71.21343889544087, 66.86921781109226, 57.567940604302194, 71.8674627427132, 67.15978699345743, 70.85410271921467, 68.36386834421467, 72.70892881578015, 72.96847989482265, 67.62343468204622, 64.00532668636691, 64.89482218219389, 69.51147540923088, 68.8253116607666, 72.43077785738053, 69.50573305929862, 65.63190221786499, 64.03358736345845, 68.29419920521399, 69.64433393170758, 65.79462958920386, 61.84962341862341, 70.44163411663425, 67.18816926402431, 63.24697955962151, 64.39575941331925, 67.95380807692005, 67.55487949617448, 63.46242750844648, 61.80312764260077, 55.8521350737541, 63.9584739746586, 65.54744574331468, 65.99881249089395, 65.96164411114108, 66.93113634663244, 65.8905158504363, 65.05141888895344, 68.24760929230722, 65.22990634364467, 69.13517105963923, 63.21810699278309, 61.00209728364022, 59.5266192959201, 61.7490577697754, 63.01538321279711, 59.342334578114176, 55.987547059212964, 52.69175591007356, 56.965056619336536, 57.900361476405976, 56.99626691879765, 54.4059964149229, 54.00195306347263, 56.025037073319965, 54.58513498306275, 58.394132967918154, 52.735655077042125, 56.72910251925069, 57.551070490191066, 55.737362600141964, 60.7700224076548, 62.33986085461032, 62.68635519089238, 61.44351297809232, 60.26226374410815, 56.36969966273154, 62.866156639591345, 60.310457906415394, 64.20456347926971, 70.58533407026722, 69.83227822088426, 72.5495707604193, 73.64128405048002, 71.8551072766704, 74.36243534088135, 73.4386936310799, 83.51110489137712, 83.3655143553211, 88.1986431921682, 83.41969013214111, 84.4934154325916, 7.831061078656105, 0.3358331502925965, 0.9395801792702368, 0.7154457739764645, 2.792766296094464, 0.30970072674174465, 54.99657592465801, 91.20151565920924, 75.39435602003529, 51.855016293064246, 53.41111859967632, 44.3510240124118, 0.6455801487449677, 0.4859918686411073, 0.13535768514679325, 0.14761475485659417, 0.21732464973484317, 0.260064541812866, 0.13633112242865947, 0.14677876907010234, 0.14934021468845107, 0.12277138915153281], [0.09598496400060193, 0.012533527859036001, 0.06450534632970249, 0.06762366892108995, 0.040382390556436394, 0.05117457375050553, 0.11265018789638435, 0.11821551789199153, 0.07176207588805307, 1.1774010211229324, 39.27759901169808, 36.08026719862415, 45.780080749142556, 47.63832715249831, 55.93046872846542, 23.394690559756373, 0.6670673215581525, 0.3237678783555185, 0.1493077172387031, 0.1323184151683123, 0.172255038313808, 0.12402038825976273, 15.186072914831101, 67.83783928040536, 87.53850829216742, 85.80368318865376, 87.24464431885751, 86.75975307341545, 87.14325104990314, 80.33160809547671, 79.36155888342088, 75.35153942723429, 71.01427662757136, 70.60790338823873, 65.0903444905435, 65.64488918550553, 63.24633236854308, 61.50511380164855, 62.20133450723464, 64.76963581577425, 64.18990950430593, 63.92552998758132, 66.31452406606367, 70.43743718054988, 71.71842052090552, 71.25422370049262, 61.93344839157597, 59.217701265888834, 55.19678938773371, 55.55195216209658, 55.3212461933013, 51.189421453783595, 51.22376180464222, 51.11337454088273, 54.49519895738172, 55.985848672928356, 55.558992816555886, 54.595470428466804, 56.04481758609895, 56.29182492533038, 59.32959471979449, 59.02298696579472, 61.533805939459036, 61.59439086914063, 63.56204002134262, 68.72317314147949, 67.49931520031345, 65.89993738359021, 68.16183490137901, 66.23852422160488, 68.04065719727548, 64.4289505097174, 65.05601982916555, 54.91356680470129, 54.76692899580925, 64.66179024788642, 64.7786690342811, 64.467319134743, 62.16194214359407, 64.17839342548002, 63.10146747096893, 55.52473091310071, 59.423025577299065, 66.55445544950425, 61.07499061092254, 59.08099097590293, 60.73092814414733, 60.8499603117666, 55.00978646739837, 59.699595820519235, 60.94634471401092, 59.28910801487585, 60.96441507339478, 63.68180959455429, 56.82443180391866, 65.70988285926082, 63.37150304548202, 57.38335778636318, 60.86169996569234, 58.96205294516779, 63.295103119265654, 53.66560197645619, 47.10914058070029, 51.975311463879, 58.99120007791827, 55.16557516590242, 60.82745767408802, 60.64081953417871, 58.34501704862041, 60.38922694421584, 63.18735561063213, 59.79871411477367, 59.278976532720755, 59.64208995142291, 56.91539941295501, 57.25073460609683, 57.49491783880419, 57.14889810931299, 55.13305087243357, 51.845892860043435, 49.29834873445573, 48.493058681488044, 50.05438950753982, 49.276320703568004, 48.37459917991392, 49.67575527006581, 51.001994917469645, 51.42119822963592, 51.19791730757683, 51.05185608710013, 49.16305442010203, 50.391846702944854, 50.390097325848, 54.22715202454598, 56.84141174439461, 57.512144888601, 54.2972683137463, 52.858221300186656, 53.96745581780711, 54.31557009297033, 52.96494899257537, 59.39151717770485, 63.680923138895345, 63.74054708788472, 60.9500317419729, 64.80205812761861, 66.30597329908802, 64.8655769901891, 65.21920219544442, 73.97774496386128, 72.71918973615094, 81.80365008692588, 78.93103168856713, 81.024031946736, 17.638259318567094, 0.4609120498982168, 0.6987451185141841, 0.6792883238484783, 0.30005374923348427, 0.1922584060699709, 37.94824500237742, 83.57719682878064, 56.25082046754899, 42.98316017273934, 36.80007311605638, 30.02817749977112, 0.17625881298895807, 0.052231376720291954, 0.01812743867987827, 0.11606725413472423, 0.07068868711470597, 0.04039813366328036, 0.05322657089920775, 0.09586400637823729, 0.1376254739420068, 0.02236530875727054, 0.02872105954485315, 0.027862085374973478, 0.06520492250039693, 0.024275991412240173, 0.050488545844751986, 0.07585794965346014, 0.17989650488861147, 0.03745108151868467, 0.09044692205685763, 3.069892535286565, 56.572199867617705, 47.05246233171033, 50.48927445565501, 47.75104038176998, 68.90727350788733, 26.790470769328458, 0.927922466108876, 0.2040722479503001, 0.27006922109473136, 0.1683828928658078, 0.25904778991976096, 0.25987354077158437, 17.61646270751953, 73.87171545336324, 91.45604610443117, 87.67796424127395, 89.39877079379174, 92.15063510402557, 90.60325222630655, 85.07870366496425, 83.67892742156982, 79.36992137662827, 75.60885475527856, 74.49814934884348, 67.33028458010766, 69.61723035381686, 64.65265112538492, 64.49113184405913, 66.79851316636609, 65.74005765299644, 68.16630640337544, 67.05382808562248, 67.7017173459453, 72.961545144358, 73.65591449122276, 71.97038573603477, 64.88869543998473, 62.288775905486084, 58.18489413107596, 57.597731005760934, 58.5353147599005, 55.930013733525435, 53.14797070718581, 55.1253826387467, 57.226510047912605, 59.35778479422293, 58.55375774445073, 58.273167071803925, 60.59401781328263, 59.96621893298242, 63.207955898777136, 63.04619343050065, 66.19471134678011, 66.31938780507734, 66.00773980540615, 71.42341906024565, 69.96869825547742, 68.29190854103335, 70.42321466630506, 67.59690377020067, 69.69546594927388, 68.93712274489864, 65.97570188583867, 59.589526268743704, 58.75468900126796, 66.698241695281, 66.70274457623883, 64.84113277927523, 63.92510637160271, 66.95558840228666, 62.32776034262873, 58.369833884700654, 60.860723295519435, 69.03107135526596, 64.08821813521847, 60.983152235707934, 63.10350710345853, 61.351403959335826, 57.83201417615337, 61.51160532428373, 63.97402617239184, 60.429368480559326, 62.14069074200046, 68.75056697476295, 59.625125700427645, 64.72420300206831, 64.10240927050191, 60.83064263866794, 61.598379919605875, 62.135862304318344, 64.60367641141339, 59.639265844898844, 51.0952571130568, 56.58524174844065, 60.175693112034956, 59.335168407809356, 63.283959665606105, 63.54065525916315, 61.02473328190466, 61.988071318595644, 66.25331940189486, 61.05388041465514, 62.82339888234293, 61.08875813022737, 59.47747984240132, 60.28127939470353, 61.28320178677959, 60.51183631343227, 58.341698723454634, 54.600263564817375, 51.647248345036665, 52.08076830833189, 52.06369030860163, 50.72849981246456, 51.32129546134703, 50.92070771801857, 52.35150598710584, 52.36072747938095, 52.894577749313854, 52.69448195734332, 51.58376478379773, 52.0897505360265, 52.464030942609234, 56.69140854189473, 58.56984730689757, 59.04304596685595, 58.765012679561494, 56.68754108490483, 56.36575768070837, 57.0782954462113, 56.28040690575877, 63.51227298859627, 65.88512651381954, 67.82833145510766, 63.80144972955028, 67.98082536266696, 67.62915349775746, 70.25751806074574, 69.42481456264373, 74.46138889558854, 76.65415856146043, 83.47061818645847, 80.38561128800916, 85.5625907836422, 22.97802894346176, 0.5797386301621315, 0.8734824195984872, 1.1465948483636303, 0.7358134165406228, 0.3967004599830797, 42.33607892067202, 86.3768591419343, 66.23602174943494, 43.81457321105465, 49.81214000332741, 40.92963857035483, 0.14008648543348237, 0.06135919942490517, 0.07809406837388393, 0.0874500550449856, 0.08374643361856861, 0.022484730373347, 0.057521692642401305, 0.007866430687793202, 0.10554980922250018, 0.034968205877850135, 0.14499658808833168, 0.14843057720891892, 0.1653207628236663, 0.23747190412494446, 0.20689093057186375, 0.19320541331844945, 0.40591557840666465, 0.11532471575323613, 0.1347798250255085, 3.6178699568394697, 79.38035488128662, 54.51219850970853, 61.76371174473917, 64.1235076996588, 79.06616518574377, 30.049232782856112, 1.0611884247872139, 0.8049603287250766, 0.2872556682315565, 0.36114411308400096, 0.40126631336827434, 0.38693421790676735, 20.734084113951653, 85.42099322042158, 97.28923812989267, 97.39098441216254, 94.65423691657283, 96.92206505806216, 94.49119183324999, 89.56489101532968, 89.32471644493842, 83.14950942993164, 79.34139005599484, 80.7908078162901, 72.33927680600074, 72.40324281877088, 70.574994702493, 66.37510115100493, 72.97164916992188, 71.6655626604634, 73.29526039861864, 69.3762085514684, 71.12651917242235, 76.76991554998583, 78.14102711216097, 78.22547574197093, 68.18124278899163, 64.95572482385944, 61.8897492654862, 61.81422010544808, 62.90963611295147, 58.58614867733371, 56.66508551566832, 57.45491358541674, 60.59010328785066, 61.99707315814111, 61.63857636913177, 63.446479151325846, 64.48846463234194, 64.04767259474724, 65.20226540104036, 66.74010907450031, 68.43792269306799, 70.20176549111643, 71.12444816097137, 77.84757891008931, 71.6901873004052, 73.39150751790693, 70.8856777991018, 73.09725915232013, 71.45522948234313, 72.6330074187248, 71.12023553540631, 64.49949041489633, 62.210297123078384, 69.19997645962623, 69.95748812152495, 69.57618667233375, 66.70383499514672, 70.37094516138878, 65.28945576760077, 61.2888539221979, 64.33621391173332, 74.93846677964734, 66.67611952750914, 63.27496174843081, 64.12134647369385, 64.41223336804298, 59.24505587547057, 64.67950759395477, 64.3056704152015, 62.65451731220369, 64.98616241639661, 69.43917828221475, 60.44115128055696, 70.43684098028368, 66.8861153817946, 66.39654867110714, 65.42680148155459, 64.6064652166059, 66.54023293525943, 61.17344994698802, 55.82634156750095, 61.342566859337595, 62.77418882616105, 62.62804131354056, 66.89200678179341, 66.15535428447109, 64.54884167640441, 66.0841554211032, 69.22860976188414, 65.11839335964572, 66.73092288355674, 64.90354161108694, 62.45109535032704, 63.18870098360124, 63.5862567347865, 62.811317982212195, 62.15741180604505, 58.24367084810811, 56.265023369942945, 55.717660534766416, 56.15599324626308, 55.82876559226744, 55.03149678630214, 54.29364404370708, 55.12890100479127, 56.697998123784224, 56.86908014359013, 55.89365336202807, 54.65687905588458, 55.31496647865542, 57.09071367017685, 60.249539575269154, 62.301558909877656, 62.97315105315178, 63.52968046742102, 58.88836729911066, 61.03415089268839, 60.765394010851466, 59.71594818176762, 65.8980546459075, 71.56610704237416, 73.19622055176767, 67.65932436912291, 71.26041320062453, 73.26421091633459, 75.04397853728264, 74.41972547961821, 80.36334791491109, 81.44516114265689, 88.96682370093562, 86.08425817181988, 89.89184410341325, 24.127028449889153, 0.8856152911340037, 1.6703946576003106, 2.0900150893195986, 2.5920363058966975, 0.6301902390776143, 50.92102543000252, 93.0021659789547, 75.44945747621598, 55.084499774440644, 58.45965616164669, 48.84993160924604, 0.2722601712711396, 0.12161229812209645, 0.12570193593179987, 0.255586834504239, 0.1839484511724403, 0.12878564667076836, 0.2346199120004331, 0.08405756490725665, 0.180754630616115, 0.10787322366189574], [0.10317573338867196, 0.041891239027703, 0.0917789038090456, 0.06051456833618784, 0.0708188224704035, 0.09307938402578717, 0.07383409857509599, 0.12211821492641203, 0.07382154239401703, 3.5844052751218123, 39.82096102929885, 26.004137531403575, 33.07768890934606, 40.17590807330224, 61.60393399576987, 30.672311090653945, 0.6302244985295881, 0.09723791612252113, 0.13872108692603727, 0.22051528336540346, 0.06527403129204627, 0.2654565444156047, 19.496541023254395, 70.71771406358289, 78.93841358923143, 83.89672094775786, 84.35263372236683, 88.36419859240132, 92.17195710828229, 81.71690294819494, 86.96008420759632, 78.74715097488897, 74.7430072292205, 74.12750105704032, 70.68639001538678, 65.73487227962863, 60.937472312681145, 62.438155451128566, 61.60348684557023, 62.67588638490247, 59.96194747186477, 62.31975086273686, 61.266672918873454, 68.31679205740652, 68.00417915467294, 67.88122069451117, 61.90664291381837, 56.35417099921935, 55.68529705847464, 53.988248302090554, 50.19463385305097, 49.94442193738876, 52.09879159927369, 53.42717286079161, 51.388654324316214, 54.442270494276485, 58.028779875847604, 57.81140604326802, 58.28173352826027, 57.565194945181574, 59.769712109719556, 58.85902404785157, 61.08352961078767, 63.70020158829228, 65.74679628495248, 65.89488537080827, 65.16798780810448, 66.24559233265539, 64.73900210472846, 65.8525316176876, 65.16260631622808, 63.43956009034188, 63.97566964549404, 53.67509803464336, 55.61983270029868, 64.49941196749288, 60.75867891311646, 63.68885809375394, 62.17944375930294, 65.82452589465727, 56.85171581083729, 61.09159008149178, 64.0472685906195, 57.58843498845255, 62.27536139949676, 63.48726395637759, 62.89246789870724, 63.443643277691265, 65.10195470625355, 64.31379364382836, 62.10979030978296, 60.73023388462683, 60.49776677162417, 62.64784143817041, 60.6420393913023, 61.54750677847094, 59.62221922412996, 58.827029274355986, 56.92482879084926, 61.46665888447916, 60.45582094500142, 59.826437427151596, 54.3717658904291, 53.070754927973596, 58.834038549853915, 59.994793399687744, 56.72010852444557, 63.74595995872252, 61.648566645960656, 61.6641031542132, 62.404203414917, 61.81435346603394, 60.772775911515765, 59.90031526934717, 56.900164927205736, 57.871477142457046, 56.08126032736994, 57.6035871044282, 55.454967637215894, 49.88358989838631, 48.400118120255016, 48.303384627065356, 46.52881414659562, 48.4310773880251, 46.95792928818734, 47.82407099200834, 49.961900018876605, 48.446864927968676, 51.00352071946668, 51.50459958660988, 50.66190973404915, 49.27547739398096, 51.64398101068313, 56.51830257907991, 55.9945406452302, 56.893606724277625, 53.75208631638558, 53.44509809247909, 53.98715396081248, 52.913385514290106, 55.42409073921942, 60.02484267757785, 61.892271349507, 63.32913360288067, 64.06049874521071, 63.22895626867972, 64.81549616782897, 65.90595429943454, 66.88484453385877, 70.44481123647383, 74.23992403091924, 79.03195427310082, 76.93460802878104, 81.12606848439863, 45.444996587691776, 0.260647994375998, 0.26012978186049773, 0.49351246186321784, 0.14759871297545973, 0.08375109909402748, 30.18339353223001, 83.1467951497724, 60.8575971664921, 43.63063366182389, 29.777995001885202, 38.429072672320956, 0.823932036517128, 0.06228884712101952, 0.04600736432738843, 0.04685364250514296, 0.03999708280447991, 0.06599906456446455, 0.05297162449888645, 0.007849992356157952, 0.15484547572991542, 0.016533646379567443, 0.060829767551753795, 0.08820213888201021, 0.08351615524940914, 0.12826664508470606, 0.07859089937541755, 0.06586583421355294, 0.12263622059817277, 0.1341410915577604, 0.33857206783948407, 11.219425066824883, 57.74403149081815, 38.52839492982434, 39.30460845270465, 44.62839441914713, 74.57035233897548, 35.24592022741995, 0.7794712351695184, 0.4637012228129372, 0.3129811765205476, 0.24087523440680197, 0.0750404495685812, 0.18701710828369666, 23.4803060946926, 76.86463294490692, 84.55418079130112, 90.3415124647079, 87.38368449672576, 89.41486035623859, 92.9244795153218, 86.34847687136742, 87.65672852916103, 84.8853543496901, 75.5151257976409, 79.03668465152865, 73.40201946996874, 68.86237805889499, 63.30170054589549, 66.33155499735187, 62.71548663416217, 64.70390865879675, 63.942729580786924, 63.4589679779545, 64.88982508259436, 69.83936986615582, 70.4793280939902, 69.79179936070597, 63.92862866001745, 60.18046663653467, 56.7004103814402, 56.87557951096566, 52.708025901548325, 53.35773906400127, 55.094195873506614, 55.35294678903396, 55.83275072036251, 58.15888097209316, 60.351823222252634, 60.478860947393606, 57.59429893186016, 59.05855501851728, 63.185139471484774, 62.71448642976823, 63.5835502993676, 67.03059196472168, 68.19916017593877, 68.4051081442064, 68.57715898944487, 68.57394264590356, 65.73358181984194, 68.71212774707426, 66.60015106201172, 68.24003911787464, 66.29528091799828, 57.3537282020815, 61.895860318214666, 65.09194089520362, 64.48037278267645, 66.83531284332275, 64.19673050603559, 66.95794182439005, 58.85135581416469, 63.70809339707898, 65.57148202773064, 63.94969963258313, 66.88677433998355, 65.02214624035743, 63.22739908772131, 64.20938014984131, 66.76768333681169, 64.95359497685587, 63.813522784940666, 61.93078902459914, 62.32225725727697, 63.6003968792577, 63.08054947083997, 64.14245666996126, 62.25174088631908, 64.14968559818884, 61.566291009226155, 62.243543132658935, 62.885023240120184, 63.3403790381647, 57.15234195032428, 57.56628928645965, 60.58996600489463, 62.961929152088786, 58.843773872621604, 63.11336794207173, 63.24612056055377, 64.31615098830193, 66.0126349233812, 65.69318925180744, 63.06707220692789, 61.88429717094668, 59.69405743383593, 59.73765065593105, 61.13653259892618, 60.23703113678963, 57.85934917388424, 54.028554577981275, 51.52372898594026, 51.67352430282101, 49.608353261024725, 50.108808471310525, 48.6349465001014, 49.0667994560734, 50.15888929367066, 52.112406146141794, 52.697537483707556, 54.13166584507112, 52.794243520306004, 51.54731812015657, 54.14884190405569, 58.536593452576675, 58.25810517034223, 58.248848376735566, 57.59652683811804, 55.48850782455937, 56.4962431692308, 53.98396115149222, 59.10385447163736, 64.18380629631781, 65.86194530610116, 66.45282683833953, 67.33707028050577, 64.97133193477508, 67.96968583137759, 70.59458301913354, 71.51458278779062, 71.24956392472791, 77.05209870492259, 79.77200354299238, 82.12008337820731, 82.91215112132411, 54.60118532180787, 0.3634862277296282, 0.21185804549003803, 1.5739865985608872, 0.8142232510351366, 0.20914779495327704, 34.678106154164965, 86.4702429309968, 73.12670830757388, 42.04004587665681, 39.73052294023576, 55.92884878958426, 2.4460719189336224, 0.37064041641931383, 0.057321663254932056, 0.17157688196147644, 0.09028791284729397, 0.1024777123764638, 0.024881294718192472, 0.038082690368736946, 0.09091654927620003, 0.040582389300388676, 0.2012501179330772, 0.12727474508386466, 0.19952481131880515, 0.2709486593882884, 0.24142474927488836, 0.16935228520343382, 0.2878689675802185, 0.16810763747461382, 0.3549370542168618, 13.952395319938661, 80.6830132392145, 41.192292244203635, 46.74811778529998, 57.8842483797381, 84.22889863291095, 39.84546407576531, 0.8551848691798026, 1.9032649167122382, 0.3021156902034437, 0.7066066515061163, 0.2325728024926878, 0.7901867827580822, 29.230128142141528, 85.9666576693135, 92.65001558488416, 96.597943921243, 97.09104860982588, 97.29699657809351, 97.90032771325882, 92.63704822909449, 94.19371927938154, 89.08112941249725, 82.45714833659511, 84.15272620416458, 78.96813731039725, 71.87071830995622, 67.56962760802239, 70.33373755793419, 67.11044357668969, 68.73169252949377, 68.37132084754207, 68.5000765708185, 69.51181273306571, 73.23604829849737, 72.78169662721696, 72.78568175531203, 69.81233689092821, 65.01980066299438, 60.945011108152336, 61.17736055004982, 56.955556638779186, 53.82292039932744, 57.45840841724027, 61.00876923530333, 59.92254334111368, 61.035959105337824, 66.732954671306, 63.33064371539701, 62.80290842056275, 63.64338213397611, 66.86798618685815, 66.00800652657786, 65.86031360010948, 70.16906076861967, 73.03027291451731, 70.35824452677082, 71.46134837981194, 70.22818657659715, 69.67161009388586, 72.32746262704173, 71.6642604335662, 69.89449485655754, 69.10161910518524, 62.91077360030144, 63.73544408429054, 68.90123305782195, 66.22281905143493, 70.68529175173852, 65.63643255541402, 69.08083838801231, 62.84061416502922, 68.00529310780188, 68.645290559338, 66.40910025565856, 70.48023808387019, 68.51933540836458, 65.92296954124205, 65.6514983792459, 70.23326212360014, 69.57353515009727, 66.4222558852165, 64.66400638703378, 65.01117929335564, 64.88146651175715, 65.55178388472527, 67.90146012460032, 65.65711521333264, 63.81656262182421, 64.337025842359, 64.88191366195679, 65.48325615544474, 62.90428600003643, 59.90574382966565, 61.347038361334036, 65.73028310652703, 67.76152564633277, 63.63704750614782, 68.53848441954582, 64.89294728925152, 65.97994589036512, 68.51738991275911, 67.44777525624922, 64.51357564618512, 64.3903975332937, 63.015073345553496, 63.23948391022221, 62.4852317379367, 62.90863198618736, 59.04918447617562, 56.870535342924065, 54.3780848287767, 55.46358900685465, 52.12012929301108, 54.99594834543044, 51.22055722821144, 52.36926647924608, 54.461509719971694, 55.275758466412945, 55.788639745404645, 58.30592670748311, 57.1340480158406, 55.47490504480178, 57.468190808450025, 62.75042318528699, 62.10287124879899, 63.31564457185807, 59.95677778797766, 60.075535389684866, 62.166084166496034, 58.04159033683039, 63.289823609013716, 67.07014514553931, 70.7868968286822, 70.8881018238683, 74.69801764334403, 70.08363939100697, 74.13751094572007, 73.75351875059067, 76.66300742856919, 76.15087139991023, 83.52906934676632, 82.5305986404419, 86.20779714276715, 86.1519661257344, 56.66534439209969, 0.7119176020064663, 0.6173464379483654, 3.18586255754194, 1.8733300004274616, 0.34727108815023977, 39.399412139769524, 94.62692153069281, 79.03648853302002, 60.31276033770654, 44.97686170762585, 65.95374445761404, 1.1871827994623494, 0.3745507130459432, 0.13456951856853502, 0.2265141654999987, 0.13047867033991123, 0.1852717914528424, 0.10329009499400855, 0.14371526006969715, 0.3896585797830936, 0.10629131338529049], [0.053607278293178934, 0.024673803634340727, 0.03321446591026841, 0.08687933486315512, 0.04487433177869647, 0.09321866647130059, 0.04033331496400699, 0.14549854421807876, 0.534488819539547, 13.625821721169258, 40.008740578928304, 17.218624545681863, 33.97398971742199, 39.992533345376295, 65.09478069120838, 36.70456732473066, 0.7548287607008412, 0.754954582981525, 0.4434290960911782, 0.098899798317542, 0.007041901267404038, 0.7169281234664302, 26.15644708756478, 64.53184604644775, 76.54924300409134, 75.61963342851209, 85.98879552656605, 92.19596201373686, 86.41806756296467, 83.6064733997468, 84.16119852373677, 81.36243051098239, 77.55753532532724, 77.1139701720207, 71.05587728561895, 73.23150619383782, 66.62134755042293, 61.76597887469877, 58.88651594038933, 61.44350121098181, 56.91616035276844, 60.146636193798436, 58.28966848311886, 62.93598659576909, 65.22294413658881, 67.01898174901163, 60.05010274148757, 56.53345861742574, 52.96865171001804, 54.64624158797726, 50.33858876074515, 51.6809493495572, 52.25168558859056, 51.44025310393303, 53.0163908773853, 56.26050087713427, 56.11108603016023, 54.66908547186083, 56.60099790942285, 57.52274705517677, 60.125973147730676, 63.28250838864235, 65.36192155653431, 64.96781356873052, 63.31420506200483, 69.27964764256632, 71.7716706183649, 62.93772420575542, 66.36768787137925, 63.596345070869695, 62.94334888458253, 64.52996330876505, 64.44706793754332, 54.293228272468816, 55.427169799804695, 55.6339846118804, 62.001972198486335, 65.56933649124639, 65.28858107905235, 61.776396689876435, 57.36064726306547, 63.85973222794072, 57.2316679646892, 63.60710805462253, 64.98239301866101, 60.97968486047561, 62.86629784491755, 63.93761481008222, 60.26908866820797, 61.30706156453779, 58.20336064984722, 62.71845194601244, 59.80726488174931, 60.22590729498095, 61.06887955819408, 58.22536122414374, 64.61131326613888, 59.21624214418473, 59.84593945164835, 59.11132658681562, 57.48662594825991, 59.72222397404333, 48.7542296994117, 52.117826861719934, 56.09958956318518, 59.26790760409448, 59.548251167420425, 54.99750160401868, 61.21421121781873, 58.262270727465236, 63.38634921658424, 59.09533116125292, 57.59349876834501, 57.59652683811804, 55.48273017329555, 58.449485455789876, 59.121658109849506, 56.91197518379458, 52.46594113688315, 49.95585172407089, 47.74965186272898, 48.856274081814675, 49.57152612747685, 46.66261403791366, 48.024233464271795, 47.50955966211135, 46.383933559540786, 50.168083329354566, 49.51196493641023, 49.01225497645717, 49.373803369460575, 50.18483577236053, 53.36616039276124, 56.07799691538657, 53.940485600502264, 54.108939632292724, 53.19908703527143, 53.63392491494456, 53.701405371389086, 51.50289727795509, 55.45525397023847, 60.4441911174405, 61.981666088104255, 62.01469244495515, 63.57257550762546, 63.42893046717491, 65.35872874721404, 65.50901043799617, 70.36644228043096, 68.75041007995605, 74.78196420977193, 74.51310142394036, 80.42328957588443, 74.18979614011704, 76.89017541946905, 4.210787444345413, 0.09168473628139304, 0.8953195413754833, 0.08311076450251764, 0.0941578979273477, 28.285195827484134, 81.95652838676207, 60.801495505917465, 50.5503418368678, 26.01164494791339, 41.8239232801622, 6.023797152503845, 0.38806600556258236, 0.16978834244993427, 0.1667111817627184, 0.056176725699896776, 0.07900431106287627, 0.04230218008160592, 0.03049063071939013, 0.025703801187656583, 0.022647707918358427, 0.016992282152416247, 0.05044680171375794, 0.05317848739064029, 0.14014665397905535, 0.028056987719009482, 0.13092670920154742, 0.11093880876057571, 0.28053434986260634, 0.4731554832429656, 21.248251930359874, 52.85091392455563, 22.91151927363488, 27.334409375344556, 46.10112282537645, 74.62350045481037, 41.76066329402309, 0.8315410669292174, 1.825430138457206, 0.6010570797708727, 0.2834837883710861, 0.08712641354049407, 0.9711346054269422, 28.27877098514188, 75.66676462850263, 85.07125116163685, 83.09468253966301, 87.1541944626839, 96.20527544329244, 88.61303375613305, 88.11079778978902, 86.6787875083185, 85.49575359590592, 81.89173083151542, 81.86593732526227, 75.82937040636617, 76.94751262664795, 69.43662874160275, 64.79384860684796, 62.64740213271111, 65.46938273214525, 62.12158487689111, 63.72929773023052, 60.21435983719365, 65.2328912673458, 67.32623669408983, 68.58840834709906, 61.217462862691576, 57.18938089186146, 56.120205540810865, 57.18760013580323, 54.891311276343565, 54.44543976937571, 55.70759181053408, 53.86290111849385, 55.69370269775391, 59.49106301030805, 58.07373023802235, 57.95394497532999, 58.03559695520709, 60.96674103890697, 62.82434025118428, 66.01456472950598, 67.68150145007719, 68.46475954978698, 64.19224331455847, 70.99002069042575, 75.75698698720625, 67.16294057907598, 71.3705062866211, 66.10643448368197, 66.013199744686, 69.11293122076219, 64.77597828834288, 59.175037645524554, 57.62330093691426, 59.363856623249674, 64.78478008700957, 66.4453664902718, 67.8793458015688, 63.07958849014775, 59.58466252973003, 65.82221954099595, 60.35341178217242, 66.39519153102752, 66.08746590152865, 64.93732890775128, 63.46580859153502, 65.57742049617153, 62.75878175612419, 62.4975166013164, 61.6101784090842, 66.17701361256262, 62.41458200639295, 62.56756621022379, 62.36837256339289, 60.08851451258506, 65.65489515181511, 60.85866797354914, 62.127892048128196, 61.13972148587627, 59.79169307216522, 61.793851237143244, 52.534374729279556, 53.67299956660117, 59.411560489285385, 60.92047276035432, 61.58000753771875, 59.168687328215576, 63.90742040449574, 61.32422585641185, 66.23491564104634, 59.929505548169544, 60.368328555937744, 57.95970693711312, 58.53635418799616, 62.76598715013074, 60.86958785210887, 59.702910223314845, 56.07198784428259, 52.76600245506533, 52.11800336837769, 51.9282312547007, 50.91194122068344, 48.5474423439272, 50.37090909096503, 49.48593608794674, 50.00568151474, 52.31134091654132, 51.85688726363644, 49.998523189175515, 52.106714787021765, 52.72196600514074, 56.17945686463387, 58.4399187949396, 57.71954021146221, 57.50615542934787, 56.49519197402462, 54.90265084851173, 57.85549740637503, 55.280108374934045, 59.27339892233572, 62.8053246005889, 67.16211688133978, 62.9892288484881, 67.08591307363203, 64.1258297428008, 70.74255835625434, 69.42614032376197, 75.47165809139129, 71.53070372919883, 78.07574318301293, 75.37960790818738, 85.38300114293253, 76.02814043721845, 84.42761375058083, 6.222004813532676, 0.12917222995911876, 1.2332473599141645, 0.3544678100414815, 0.3193894100766028, 32.89456325192606, 85.76319648373513, 73.55174418418639, 55.031794886435236, 27.983512609235703, 53.37583687997634, 9.207398218493308, 0.936350720303674, 0.32010858277640036, 0.26867383790592997, 0.020279416048358527, 0.12934582548276072, 0.05109557859419335, 0.07931163489458062, 0.04836531401041055, 0.04435503141834371, 0.1395687938577706, 0.14918583264995008, 0.19143495348192033, 0.27109479832072414, 0.17239117213795263, 0.15858818296222918, 0.22336125403882998, 0.42305936976786584, 0.7016211351560009, 26.892876009787283, 74.2964453851023, 26.947481286141183, 46.85044065598519, 60.12336477156609, 83.69635058987527, 48.25892063879198, 1.193512892050128, 3.8338295298237957, 1.1622845742010302, 0.6881487129196044, 0.25594510318290803, 1.9142989117291667, 30.3735774947751, 86.831650118674, 97.50407418897076, 93.13065498105942, 92.72367769672026, 102.81494771280597, 96.09325255117109, 95.00436336763444, 92.43983145683043, 89.95457849194928, 87.24955512631325, 86.59857503829464, 80.83079245782669, 81.63523135646697, 74.41213177096459, 69.26093793684437, 66.15897855451031, 67.97651860021776, 64.05445829514535, 68.12714545957505, 63.94607536254391, 69.85908369864188, 72.00068212324574, 73.15605548120314, 63.935598711813654, 61.40594059421171, 59.045607274578465, 61.93655883112262, 58.42313889534243, 58.81492484000422, 58.70071326532672, 56.174632349321925, 59.18264312128867, 63.463223749591464, 64.00198090460994, 61.23234433512534, 62.81866065917477, 64.80525878167921, 67.83613697175058, 70.2444173443702, 72.73774254706599, 71.7836416921308, 67.02806595833071, 77.60634529975154, 76.44150334019815, 70.15745839764996, 73.24917254909393, 69.75692948987408, 70.29925207937919, 73.10922238134569, 69.90381440808697, 65.94451904296875, 60.56120718679121, 61.44517998541556, 67.95683614669308, 70.71166576877718, 69.60026218045142, 65.52034608779415, 62.85141245011361, 67.95556529875725, 64.19578913719424, 69.22799787213727, 70.21496034437611, 66.11642083814068, 67.02733639747866, 68.99968454914709, 63.32165364296206, 64.35120913290208, 62.89631574384628, 68.78057310658117, 63.19585930916571, 63.91132708518737, 64.54071844777754, 63.9454242490953, 69.77996949226626, 63.98928419236214, 64.8200971080411, 64.0532031366902, 60.671296350417606, 60.083187933891054, 55.08917916205622, 56.897336898311494, 62.01200562138712, 65.1318431669666, 63.32409727957941, 64.09765143548289, 67.19049915190666, 64.37934429414811, 65.95604296653502, 65.13922899000107, 62.57713287107406, 62.14800204000166, 58.29209250788535, 62.8514555961855, 63.068150858725275, 62.782955323496175, 58.81360692362632, 58.40151486858245, 52.515457137938476, 56.00168720368416, 53.58596217247748, 50.618642068678334, 53.97931706520819, 53.32155519916166, 52.05527290221184, 56.2879260893791, 54.82684320019138, 54.31142414769819, 54.271831743178836, 54.861552253846206, 58.64925961340628, 63.86554125816592, 59.36983431539228, 60.72529562057988, 59.62844794796359, 59.98095135534964, 61.721534498276256, 58.1797166024485, 61.54472974038894, 66.24007748019311, 69.9197078520252, 68.43556927096459, 70.7310579669091, 68.98208879655408, 76.3787454174411, 72.60886130794403, 82.07334441523399, 76.59045926986202, 84.58178643257388, 79.65736835233628, 90.07156710470878, 80.55169228584536, 87.64304730199999, 6.201217722508216, 0.20675802963875956, 3.7433475592444023, 0.7476246537220094, 0.4292751313938249, 36.68305704670568, 96.5213635659987, 77.16019922687163, 74.05533729061004, 34.97819885130852, 73.86894626002159, 10.750108572744555, 1.219277715971393, 0.42734397695429865, 0.6986604198332756, 0.1728919331705378, 0.31789314842993216, 0.15978136490429604, 0.14386889134203235, 0.1614793987884637, 0.14782089379525956], [0.05824289930563781, 0.15702194684455473, 0.11097167393252735, 0.09368823240360907, 0.042541475305634166, 0.08072083064865682, 0.17168171343303498, 0.0720317388373998, 0.7031278768854757, 19.832699914132398, 29.14822905294357, 31.468866025247884, 62.04903279581378, 45.56773539512388, 67.5590842769992, 46.553854557775686, 0.3231279804341255, 0.4441451431522447, 0.3028248731167086, 0.0885220495383105, 0.08267543503954526, 0.37912156132440417, 27.43374339995846, 56.58347275949294, 67.69240563915622, 71.61290091852989, 81.04805254167127, 79.91590745987432, 82.54919851979902, 83.60965051958638, 80.46256819079, 82.53977698664512, 77.37599234427176, 83.20075127386278, 77.77708607335245, 77.48343390803184, 73.13410589771887, 71.08313775831654, 60.39436524914157, 59.73681126871417, 60.051397123644435, 62.25661639244326, 58.664560779448486, 60.48010433873823, 59.35633743962934, 61.09572033728323, 57.42212649314635, 55.600691533857784, 50.10963216904671, 52.50586694286716, 50.81377214001071, 52.274549084324995, 52.25958916448778, 53.514943738137525, 53.36943557185512, 54.52592680531164, 57.223960507300596, 56.7305459514741, 60.24445226115566, 62.55464984524635, 61.32139782751761, 63.19735765457154, 64.74445419926798, 65.65081980920607, 75.04780677057083, 66.97653385900682, 66.69269546385735, 65.85013897188249, 64.24605431095247, 64.03849032617384, 62.189081022816325, 65.80837357428767, 62.64125970102126, 53.73556137084962, 54.42161529294906, 65.99420762831166, 63.46423572109592, 63.71888383742302, 63.573242310554754, 60.0253604304406, 63.79399722622287, 62.35565623929424, 59.89676160197104, 65.005178066992, 64.7412770794284, 60.201317956370694, 57.347048405678045, 58.790766962112926, 59.769912150598344, 59.54646256662185, 61.189366925147276, 60.618775813810295, 59.931200012083984, 58.419965697873025, 59.50311645384758, 57.85023750797395, 57.27677129930066, 61.92638028052546, 56.40497746006135, 60.9576254506265, 58.184399912434245, 52.969899023732836, 47.75002448789535, 50.39085826566143, 57.55366317687496, 62.81340860551404, 61.02450578443466, 59.302349936577585, 55.43218258888491, 63.738970295075454, 64.60954819956135, 53.90296812980406, 56.12109984121015, 61.620917858616004, 61.78961115498697, 60.1816943383986, 57.779968246336914, 54.997191736775065, 51.263589551371915, 51.55784576169906, 48.883550243992964, 46.663053343372965, 47.527171104185044, 48.332606284849106, 48.35745449989073, 47.056129747821444, 49.712201933706964, 47.51894981630387, 46.84554553801014, 49.67550423837478, 50.59989706162484, 51.718298158337994, 56.09463953202771, 54.90281951042914, 58.67092286386798, 55.739288483896566, 54.32025340295608, 51.43071389967396, 53.5340182242855, 53.351690769195564, 59.23684243232974, 60.202686863560835, 63.556799734792406, 62.2237822317308, 65.80598092848255, 63.24748946774391, 67.09704476018106, 66.3096446375693, 71.16793155670166, 67.90270743831512, 74.27122454489432, 71.22464118465301, 82.11923614625009, 74.34181936325567, 92.11857365023707, 19.785125486312374, 0.19039160301608427, 0.43946171059243144, 0.1712278063378988, 0.11651425877766264, 25.399865027396913, 79.33360807357296, 63.71887207031251, 49.47623214414043, 38.2671925329393, 24.980416567094867, 7.6025594818976625, 0.3034022276199633, 0.09211552284297445, 0.07729015102790249, 0.02678272494625661, 0.09839483912313178, 0.051592030382204446, 0.12941947717580105, 0.047339369062214136, 0.11111583635811845, 0.08771395701314173, 0.1578834280371666, 0.05970575951880986, 0.06498671001604488, 0.06291536531681496, 0.06185590402193128, 0.12515877959348504, 0.10736343045268329, 1.811251383154623, 33.50778856585103, 45.52899414493192, 36.40644365741361, 54.85577460258238, 53.45280947223787, 76.47029353726295, 53.68674747405514, 0.22656414507617875, 1.7079138443354638, 0.6241825162883728, 0.21739601848586915, 0.1517853068728601, 1.213796693951853, 30.79156291100287, 66.88985732293898, 79.00111659880608, 82.07274037022745, 85.69177796763759, 84.79593215450164, 82.72465398234706, 88.17062177965718, 84.09814250084662, 86.91267059695336, 81.64903809947353, 86.24156090521043, 82.4470756899926, 83.12351980516988, 75.20552527519965, 73.37068757703229, 64.50989646296348, 62.57873319810437, 62.95708894729615, 62.518116889461396, 62.67446648690009, 60.932514436783336, 61.79608698814147, 65.0372120641893, 60.5069019717555, 58.23611636315623, 53.03498291200208, 55.60162113558862, 52.48449002542804, 52.42971412597164, 53.96289802366688, 55.55077937341506, 54.79936307476413, 56.947343195638354, 60.053177879702666, 61.471856024957475, 64.29392683890559, 63.963353403152965, 63.39572760366625, 68.06262247024044, 65.13574592528805, 70.2979027840399, 76.07446362895351, 67.24566336601012, 67.54595218166229, 68.76348726211056, 67.5470269110895, 67.13260496816328, 66.26768312146588, 68.64906387944376, 67.42952054546726, 57.91358378625686, 55.94431861754387, 68.5148560616278, 67.14982417321974, 67.38065565786054, 65.96349546986242, 59.801612746331, 67.8019025248866, 64.20462623719247, 63.11430538854292, 66.53031718346381, 65.59450241827196, 63.85540193127048, 59.67603806526431, 61.86734076469176, 61.333651311935924, 60.993648498289055, 60.7614363393476, 59.995648476385306, 64.11553352109848, 60.04712958489696, 62.81584439739105, 60.46460705418741, 58.66103849103374, 66.72642784733927, 60.471643786276545, 65.08088765605804, 61.401092544678725, 55.524279840530895, 49.17766917136408, 54.944455469808275, 62.23955800456386, 65.1441123408656, 62.17814153240573, 63.674808163796705, 58.229005106033824, 63.22707745336718, 65.39111183535668, 59.065607440087106, 58.67669267039145, 63.30954920861029, 63.449546444800596, 64.19510272241408, 61.283927425261474, 59.16034052448889, 54.82177157555857, 52.07876397717384, 51.03696284755584, 48.445205765385786, 49.837192181617986, 49.912929227275235, 51.34387654642905, 52.265155007762296, 51.93896678186233, 50.21381816556377, 48.31214720203031, 51.704993478713504, 50.865963197523556, 55.530218308971776, 58.760270534023164, 57.32729927186043, 62.72473166065832, 55.8720411023786, 59.12099522929038, 54.51259466909594, 57.20936536788941, 55.870397629276404, 62.259095330392164, 61.30737927652175, 67.3199373675931, 65.1170087629749, 69.52436431761711, 67.4298970930038, 70.45129883673884, 70.62472251153761, 75.1315023053077, 71.97381388756537, 76.30108248802924, 73.13001094325897, 85.0363891355453, 74.89870963558074, 97.54165833996188, 24.528053537491832, 0.07755415258748878, 0.2031534020939181, 0.3179626172829059, 0.22088466031897455, 29.697847250969183, 84.56144502086025, 70.55928953232305, 59.6996154323701, 35.2902312432566, 39.855917192274525, 13.058432244485425, 0.8738131244336406, 0.23026384413242343, 0.18394924790388156, 0.06052045955232555, 0.20278377999221125, 0.07312575835854777, 0.1702410238043916, 0.06268520569128376, 0.1256986494146047, 0.2886703874795668, 0.23294455431882413, 0.18814664364101427, 0.18024959481291233, 0.17855703079652402, 0.17210358273117773, 0.26337799465944695, 0.24218830910901873, 2.924291212712565, 48.09034109115601, 63.23440836321924, 48.54150779785649, 80.5856757010183, 65.77635526657104, 86.61197385480328, 62.4120089315599, 0.32596219931879356, 3.5084995675471524, 0.7440044286270296, 0.47707521807282205, 0.3483979728433394, 2.6142719772554215, 36.18617903801703, 82.97475214927428, 88.86371243384578, 91.9699707338887, 91.14987373352052, 93.6201040206417, 88.35840132928665, 94.06653250417402, 88.95322092117803, 92.89701507937525, 87.79430958532518, 91.66790900691863, 84.29575935486825, 87.88880732751663, 79.80692832700669, 78.00383829301404, 66.11307113401352, 63.496544284205285, 64.07197952270508, 66.70714547557216, 65.69153401159471, 65.41614047942623, 64.95534043158254, 68.51058852288031, 65.41449700632404, 60.78955188874276, 56.01547825721003, 60.0491064594638, 56.218668799246515, 56.372931695753536, 56.93445820962229, 60.16482814665764, 59.56240307900214, 59.5318478153598, 62.60609173005628, 62.993347337169034, 67.41735335319274, 67.13425236363565, 66.23201308711883, 73.07794540159165, 70.26954404769405, 75.16991799877536, 73.56027926168134, 64.7176016530683, 72.90522775342389, 69.97432293430452, 71.39873166238108, 70.25394085914859, 69.32725737171789, 73.40478081857005, 69.96235186053862, 64.09865948461717, 59.34646091153545, 70.00645499075614, 70.18797443759057, 69.06438796750962, 69.02965930200392, 64.1678697063077, 69.60166638897311, 69.75818464832922, 63.89419809464486, 71.50311377740675, 67.52637955450243, 66.70298776318951, 63.19021501848775, 64.36893040134062, 64.85936003346598, 65.16958813513479, 63.64452746606643, 64.78074004573207, 64.50455419478878, 60.53883006495815, 64.03143790460402, 61.79789127842073, 63.033975247413885, 68.07645274746802, 62.55337115257018, 68.46264146989392, 64.45491660025813, 53.480979934815444, 53.14453471091486, 58.70735383802845, 63.61675708524643, 68.63975217265468, 65.18905093592983, 64.81426062122469, 63.129959567900634, 63.70453188496252, 68.00567750007876, 62.29304736660373, 59.3767180750447, 63.1468532162328, 65.49916136649348, 70.23953007113549, 65.0807386059915, 61.99636320913992, 56.18870973587037, 56.12126850312757, 54.73694247584189, 50.71187288530412, 53.485541651325846, 54.64354299729871, 54.773573490881155, 53.73473375074325, 55.6793938913653, 53.66662571507116, 50.832199435080256, 54.31028273797805, 55.754977964585834, 58.89909890390212, 62.51404546922254, 59.43987215718916, 65.41734856943931, 59.44411223934543, 61.08021913036224, 57.38333817451232, 61.4622893641072, 59.676795082707564, 64.89568510363179, 65.22270094963812, 72.09216748514484, 68.86190737447431, 74.40316523275068, 72.68064852683776, 77.30376581991874, 73.5650174848495, 81.96491441419049, 74.87945079803467, 82.53150863032188, 74.62571267158755, 89.52388655754828, 79.61732095287692, 102.96540983261602, 26.002558777409217, 0.19244003019505934, 1.301284057478751, 0.6919312873674978, 0.4128597977180635, 35.3837287810541, 96.11825373864944, 77.55713524356966, 76.32352629015523, 47.13956248375678, 57.46960678408223, 18.33539197521825, 1.792871401675286, 0.4766486296730657, 0.6010944035745437, 0.130068460899976, 0.3588370852653058, 0.2421294582346755, 0.28530346169587106, 0.19645440752708143, 0.24193531623290432], [0.10203443858171664, 0.0583738696971728, 0.18106164801264965, 0.022096547876454653, 0.041555707838626645, 0.09776073282644634, 0.04652780615874837, 0.06542024683327445, 2.0693851382501665, 23.724677601168235, 31.27830943753643, 36.24626190431657, 57.742262501870435, 46.289200475139005, 72.90886771294379, 51.56243885717085, 0.12955682141886604, 0.5629789552861645, 0.31794288285797645, 0.18551344622767743, 0.032978683199372985, 0.922446592200187, 31.173138926106116, 51.17914484393213, 58.33710955035303, 70.94816115594679, 79.47987325729864, 82.20806214117235, 80.72428441816761, 83.93101030780424, 81.77795856229721, 84.64764302776706, 81.30050413070187, 79.74315843274518, 78.3621624977358, 79.23561942192816, 75.2248154917071, 75.99046214934319, 70.44465434166693, 60.11142115439139, 58.11343246890653, 60.4360875006645, 57.64055936567245, 59.53941798979237, 57.315614531117106, 57.26989538438859, 53.80774082676057, 54.7097526058074, 53.881991294122514, 50.070812471451305, 48.6491572472357, 51.21878039452338, 51.22462080370996, 53.271286103033255, 52.12753472789642, 57.8729009628296, 59.339781115132, 60.05673154707878, 60.81281154386459, 64.33636296179988, 65.27784162952055, 64.0916423643789, 64.46768783753919, 64.99523878097534, 66.81948215730729, 88.76856357820573, 70.91708029470136, 60.40010759907385, 68.8161725382651, 62.59034341381442, 60.89501657793599, 62.430722559652025, 62.577984025401456, 54.8807797124309, 53.292659098102206, 61.770670029424856, 65.86807204831031, 65.07019919733848, 61.85780548280286, 62.11517964639972, 64.27956311933457, 58.501476472423924, 61.01920666233186, 64.07260317956248, 60.57158185589699, 60.42017836724559, 56.384486998281176, 58.37390530493952, 58.563728409428755, 56.87985097208331, 55.31274641713789, 57.464680287145804, 60.32785361812961, 60.739474988752804, 59.0120945438262, 60.001661469859464, 60.067604357196444, 61.36193552324849, 61.212618735528764, 58.93309800855575, 61.17350486017043, 58.177445550118726, 46.869734794862815, 51.0092983707305, 57.4216793429467, 58.84437399525797, 61.76722226604339, 58.860118389129646, 64.95725062585646, 63.19760476389239, 47.27188364151986, 61.29538466853481, 63.83193439052951, 58.57107893113167, 56.82069378514444, 60.57059734098373, 56.59012902167536, 54.87687695410944, 50.32851611414264, 49.7518257171877, 48.408876772849794, 48.668416084781775, 46.835288540009536, 49.21241352635045, 50.01479318065029, 48.82470684666788, 47.9154622170233, 46.604115809163744, 46.72879618983115, 48.148713804060414, 48.92999895157353, 53.42502340193718, 55.135898513178674, 54.118510215513176, 54.64240943231891, 53.94318419118082, 50.96506187992712, 52.37628752185453, 54.739448870382006, 52.6670842016897, 58.876313855571134, 62.6232599443005, 61.90873745949038, 60.88312395157353, 62.88585478259672, 64.17786390550675, 66.36266723755868, 65.32676927505001, 68.31826686859131, 68.61806146560177, 74.43329688041442, 71.7662420580464, 82.12033440989833, 76.21317432772729, 87.52577627858808, 46.93494419897757, 0.2637304870351668, 0.26524672825490275, 0.37372293972199966, 0.19678140449668133, 22.024632153972505, 78.96722732051727, 63.20168010650143, 51.99620592978693, 42.8137412378865, 26.79809585694344, 12.099614739418032, 0.3020019721119635, 0.04918238891649151, 0.07396699184732092, 0.1228654724095137, 0.11030840266856456, 0.1170728977529272, 0.03471565733273183, 0.10339471962182753, 0.04904255488767259, 0.10755688297532259, 0.12146908564553147, 0.00884781086501936, 0.14550243594473408, 0.10035302114462662, 0.022068396060457154, 0.08668736089020969, 0.03513388771323427, 5.038840482311865, 44.06468314509238, 44.74584979395713, 43.31117230076944, 58.22377658659413, 53.78535193781699, 81.69074858388593, 60.39329836445471, 0.06286389569962217, 1.0294048464105976, 0.5683715401157257, 0.08341355309371026, 0.022884907891913768, 1.0846598878983529, 32.24694071277496, 69.3509877112604, 75.79606163886287, 80.95186033556539, 87.10500009598272, 83.84633418052428, 82.96689171944895, 87.72868048760199, 89.09008026123048, 86.62482353948778, 83.15483600862565, 83.14200985816218, 82.5124616007651, 81.97472033962127, 79.56015632998559, 77.75397546829717, 73.22870562153479, 63.96036847945183, 60.531863935532115, 61.499591104445926, 58.821490887672674, 61.03236229188981, 59.83330941969349, 62.33034910694246, 58.46541420105965, 57.410194643082164, 55.453661487948516, 53.238177376408736, 51.73510943689654, 54.905588703770796, 54.05777231339486, 55.518286458907596, 55.53730603187315, 59.56774534717683, 61.571350866748446, 61.676552757140136, 64.6393229115394, 68.32715495940178, 66.81380256529778, 68.41496113807925, 67.42515886983564, 67.74098027137019, 71.02492978495937, 84.2527231093376, 69.47748414931759, 63.002506071521395, 71.21305450316399, 66.38657016138878, 63.1623112770819, 67.55904505329748, 64.97849810507991, 59.22748365709859, 57.642940244367054, 62.64702950754474, 66.93556078018682, 67.3775883643858, 64.83192305411062, 64.38393346724972, 66.14135142295592, 61.87593860010948, 67.94018960768177, 65.32172510700842, 61.82437512182421, 64.39775589973696, 60.20455391176286, 60.51753551729264, 60.1148061598501, 58.8383335451926, 58.36443278097338, 61.84803878107379, 63.455892839739406, 61.77186242995724, 61.31481216799829, 60.63865438584359, 62.54860155044064, 62.529095603573715, 62.66034595427975, 61.92209705229729, 62.45478630065919, 58.37472508030554, 51.1270518456736, 55.77144407456922, 58.837066619626945, 61.222028501572154, 63.090135743541104, 58.027371744955744, 66.81533228966498, 61.35237670713856, 49.25060172234812, 61.22938686801542, 64.17037217847763, 62.847898006439216, 60.05504885027486, 62.637101988638605, 57.47773393507927, 56.853739753846206, 53.309172276527654, 53.20050301090364, 50.935334236391135, 51.194948073356386, 48.57826825111143, 50.22472235464281, 52.253136865554325, 50.65653216454291, 50.72224755440989, 50.056374226847005, 50.45141181638164, 52.0320995392338, 50.86071898860317, 56.127265807121034, 56.99412922705374, 57.8034044081165, 58.79828614573325, 57.4671317685035, 54.41894415886172, 53.77542049654069, 56.64585413471345, 55.11075219800396, 63.238267975468794, 65.3738534065985, 67.70357654940698, 63.936328272665705, 67.85530951715285, 68.6723941372287, 71.51125661788448, 68.34404468536377, 74.05196405226185, 70.34223341172742, 79.79143496482604, 73.62899134235998, 84.93767092304846, 78.37949937389743, 91.30994566025274, 51.3401855960969, 0.4010787137573765, 0.4078109718618855, 0.5253758053145101, 0.39157137875595405, 27.13278582019191, 86.76407552534535, 71.82102972461333, 61.565486923340835, 40.800878924708215, 42.48270496245354, 16.76028774630639, 0.7565507424935218, 0.1480625332483361, 0.1001004879212668, 0.04970379984907566, 0.03158979835138927, 0.06054096389561892, 0.07951143828611221, 0.1050627381811219, 0.021786548482674747, 0.22745721973478797, 0.25335998544769905, 0.4418361847919803, 0.19340537758844514, 0.26790033425054244, 0.12027936642088237, 0.2029108586570909, 0.3773074038326741, 8.403224079839646, 66.61185541460591, 59.818310276154556, 51.290955928064164, 72.91154276940131, 68.68081938835883, 93.77631633512436, 71.26721459050333, 0.25939464388835815, 2.0472529194047375, 1.1626986294023454, 0.7621257175360957, 0.24336508144774746, 1.8032957132785552, 40.68756949517035, 88.90212812731343, 92.40240420064619, 93.13904100848784, 93.40591907501222, 90.01012709832962, 87.14686747520201, 94.68462744066792, 91.7151108095723, 93.05252136722689, 87.63717943622221, 89.86636438677388, 86.58672948037425, 87.97781375146683, 84.62850970606651, 82.50640546121906, 76.09519727768438, 68.25794866008144, 64.79687275425081, 65.94954752152967, 62.9660790197311, 64.76448574373799, 64.20586178379675, 64.18202946262976, 60.21389699751332, 60.97873172452373, 60.974895646495206, 56.78258795892039, 54.608131839383034, 57.434976177830855, 57.559895823078776, 58.78539331497685, 58.72572621991558, 64.2054146335971, 64.52140861941923, 63.59624308924522, 66.49048159199377, 70.1616317995133, 70.11108813747283, 69.53851622919883, 71.10922151996245, 72.2321568765948, 80.92474891293435, 87.70382050544985, 63.93371989650112, 66.32818960374402, 73.3592656350905, 71.78270032328945, 64.82510205238097, 71.69520793422576, 68.04071995519823, 66.3248477443572, 60.82833628500662, 63.60672758471582, 71.08081571517452, 71.72003653741652, 69.55895962253695, 68.54177921049057, 68.5747584988994, 65.48903380670856, 69.68359685713246, 68.22413782919607, 63.44447482016779, 67.08630531064927, 61.425462230559326, 63.69003872717581, 63.08372266830937, 62.56706414684173, 60.822927336538996, 64.82882830404466, 64.7499768964706, 65.51500774198963, 63.65969527152277, 63.0092211692564, 63.59914564317273, 67.07104729067895, 65.58596341840683, 64.21249451175814, 69.08716909347042, 60.48941604552731, 53.01566916127359, 61.023246703609345, 61.37790741459016, 65.10471605485486, 65.80206640305059, 62.27109778311945, 67.42809280272454, 68.53775485869377, 57.1098901379493, 61.92532124057893, 65.24871018625075, 66.89283832426995, 66.27157411267682, 66.19897888552758, 62.53941928186725, 60.85929163040654, 56.27469985715805, 57.35459504588958, 53.107837015582675, 53.45081298582016, 50.60812619424636, 53.49574765851421, 55.73997097630655, 53.72087993929463, 53.995285034179695, 52.59551271315544, 52.13743871258151, 54.45811686977264, 53.90745532128119, 58.85181865384502, 62.218224233196636, 61.865179538726814, 59.86166423366916, 60.585043430328376, 56.00065562032885, 58.71988188835883, 59.91276094990393, 57.85680355564241, 66.05243129114952, 68.31269710294663, 71.09606589040449, 67.50048406662481, 72.42341949093726, 74.79727714292466, 75.79158229212608, 74.57017190994756, 81.56711547605454, 76.74032518940588, 84.89376391133955, 76.43032458520706, 90.06523639925065, 82.11808296941942, 96.70700934625442, 56.81412381510581, 0.4969184274875349, 0.6706007029260359, 0.917625570249173, 0.4245111983149283, 30.488569621116888, 98.05627330656975, 76.45186624219342, 77.7506414536507, 53.723688356338016, 58.87587062774166, 20.714976287657215, 1.466956638520764, 0.17292734175439806, 0.23773672539860974, 0.24629296224203803, 0.20062666025853929, 0.23856843641448408, 0.2734179446293462, 0.17655674458271073, 0.13589043801109638], [0.024122159041824843, 0.04474523064169673, 0.07473198426586967, 0.08195738082811718, 0.0469994405284524, 0.06235172378740484, 0.044560526843152704, 0.5382736616076962, 3.7177506617961393, 26.772117999292192, 25.205964619113555, 20.889472730698127, 50.43649504261632, 52.26329580430062, 76.27494381320092, 54.040588409669944, 0.07042786482000543, 0.3597408545113379, 0.24775105738832107, 0.41641389410341945, 0.11891012981293664, 2.0829920855260666, 38.616534509966456, 48.31950949084375, 50.1684324202999, 73.589885311742, 78.34419804234659, 78.04554093268611, 74.76720040844333, 78.82453149364841, 77.64725562064879, 79.28478240966797, 81.01651668548584, 82.91812096872638, 79.42296751083867, 80.13290866728752, 76.30591484808153, 76.08117872668852, 75.06657923421552, 63.17928729518768, 58.54204554711619, 58.942790185251546, 57.74306266538559, 59.049866968585604, 55.89625781582248, 55.905608746313284, 53.11406573941631, 52.36976854262814, 50.239329261164514, 50.54181068174301, 48.925605896980535, 48.562461099317, 50.90275895211005, 51.67569729589647, 57.215747064159764, 58.47258821610482, 60.494766158442346, 63.70959566485498, 66.251342527328, 66.25031486634286, 65.23071042952999, 68.21478689870527, 66.21157753852107, 62.596113220337905, 57.869786600912775, 52.12553039673836, 85.02898370065998, 69.81900492022115, 63.26779557812599, 64.0291472404234, 60.38926616791756, 65.33858737637921, 62.57856453618696, 55.03618794102823, 51.65663457685902, 60.086804359189934, 61.776624187346435, 63.72777192823349, 61.31435325068813, 62.311929656613266, 62.42048517350228, 62.48956595697711, 63.032296472980136, 56.303548889775435, 59.09430350026777, 64.17132923679968, 64.56872809317805, 60.99596269669072, 61.7452609154486, 61.88366959171911, 60.666471835105654, 60.55163268120059, 58.55672697867117, 58.7119940019423, 59.07230292597125, 59.47711898434547, 56.15124717835457, 59.702984748348115, 59.694853674980905, 60.25932981121925, 57.72276832211403, 56.13720509313769, 46.866169360376176, 49.89499615084741, 59.06173213835686, 60.95927284609888, 58.38499384541666, 61.84387714632096, 64.70974122324299, 47.00352291907034, 53.96799710489089, 58.403970272310325, 54.92367083026517, 56.83334342895016, 55.977309673063225, 57.21958314218829, 55.81650818547895, 55.182570795859064, 51.12802067110616, 51.557253483803045, 50.72783693190544, 50.45503608642086, 46.64423381128619, 50.2060361831419, 49.080763093886844, 46.79271121178904, 45.805685981627434, 47.69854337938371, 47.726254924651116, 48.524280748059674, 50.10027339381557, 52.77604764507663, 54.112807089282626, 55.15597712609076, 55.763940580429576, 50.068051122849994, 54.965134205356726, 54.685877138568515, 50.54845125444474, 56.297700635848514, 62.20216997208134, 63.35291493323542, 62.36534057124969, 61.010965762599824, 63.22559479744204, 64.61736156094459, 64.4001446231719, 63.82394844485868, 64.06232656971102, 64.99817663623442, 68.96839187991235, 71.81667589372205, 78.5852433789161, 76.91314481919812, 85.15401317227273, 69.38282166757892, 1.728465960871789, 0.38157947782066565, 0.5706122553636951, 0.39140262490799355, 18.417222422938195, 77.28812340767153, 65.23437000090077, 53.38230879076066, 29.587412918767622, 13.424163845277603, 15.462828490041918, 0.491970572019777, 0.07410484170841594, 0.013558957613103334, 0.02081606255453681, 0.07085321981820368, 0.048701029060588735, 0.047334623147523215, 0.09888618493512755, 0.09078452934420879, 0.05778860916653949, 0.03710850615114455, 0.06464340303453707, 0.09649641962061006, 0.04538761834884363, 0.08544612225265273, 0.1056374190375209, 0.7746612448846141, 8.701102599020928, 50.4215508122598, 38.796426173179384, 29.04852632553347, 47.7459373781758, 61.892761645778535, 86.06639569805515, 62.94940502412858, 0.021257300470625202, 0.33808266022993677, 0.8129062539627476, 0.597687947653955, 0.024980309667185913, 2.558766026650706, 41.842844793873454, 68.4498074746901, 71.77360042448967, 81.39843002442392, 84.90091046979352, 83.33388436225154, 80.51196652074015, 82.49074735949117, 81.93057798570203, 83.32179561738046, 84.43553693832891, 83.67535806471302, 82.02730363415134, 82.48277710330102, 80.06731094852572, 78.34341356831213, 78.50976128732005, 64.97950223184401, 59.19320214179255, 60.43982551943872, 60.04072435440556, 61.403928418313306, 57.03189772944297, 58.384327042487364, 54.621875824466834, 57.18396017628332, 51.64839759949715, 52.90637623879218, 52.09402591951432, 53.73116831625662, 54.703257160802046, 55.921902272009085, 59.144603975357555, 60.4527497291565, 63.093124589612415, 64.41242164181125, 68.80090667355445, 66.2924175877725, 69.14056824099633, 70.37810740932342, 68.94791710761287, 66.85023353945824, 62.89050279125091, 56.496737387872514, 78.43083535471271, 71.7369733318206, 66.05769511192076, 67.11386388347995, 62.828984337468306, 68.22897803398871, 64.2056421310671, 61.29155251287646, 56.189627570490686, 58.2946224366465, 62.58944911341514, 65.09562400079542, 62.88320326036023, 67.52334363998906, 62.76011143961261, 64.0812010149802, 64.21376928206413, 58.41061084501205, 60.609648458419315, 66.98708503477036, 67.71877181145453, 64.89280608392531, 61.90266170809346, 64.58044421288275, 62.425729382422666, 63.37799456811721, 62.379680756599676, 59.35285045254616, 58.68132498956496, 61.29298417798935, 58.52686597454933, 62.414480024768466, 61.07756368575558, 63.02822505274127, 58.278446582055864, 59.88706942527526, 50.41480433556342, 54.66620645215435, 60.325735538236565, 63.635937475389056, 58.923590183258064, 61.562156831064534, 63.54970808952086, 52.54440030743999, 60.3073396221284, 60.582693930595156, 56.95465841600972, 58.69441786120015, 58.70681255094467, 58.99587946553385, 58.908881295111875, 56.751977782095636, 53.50609094865861, 54.91608104398174, 53.18507240664575, 52.43811584288075, 50.4663089782961, 52.86781149525797, 49.88616297321935, 50.412399922647786, 49.14364261011924, 50.85849108234529, 49.23904641982048, 50.979637407487445, 52.25429004238498, 55.11943632556547, 56.95517616887247, 56.96244432080177, 57.510246461437596, 50.31250499909925, 56.58628902127666, 58.57314994258266, 52.73759272790725, 58.20534144678424, 64.55088915363436, 65.34640466013263, 66.90924167633057, 65.18211618546518, 67.38427992789977, 66.86021989391696, 68.62785954629221, 66.56153925003545, 69.66931942970523, 68.66063487145209, 74.4072994109123, 76.20275651254963, 85.06846627881451, 78.573837126455, 87.93178081512453, 73.75882179506364, 2.5975977365047704, 0.672920601021859, 0.8321115266411536, 0.4887346166276163, 21.49281563297395, 85.55361640068793, 71.80101779199416, 69.10329787961899, 28.494346410997455, 20.65225954978697, 21.67334468133988, 1.143921875665265, 0.19046476441285304, 0.066599348079293, 0.03155183677952136, 0.05795692634438315, 0.07625224744720806, 0.10538541441482883, 0.06706922810765044, 0.037433507461701675, 0.17060753558912586, 0.2409924458592169, 0.23560910005002256, 0.22743697969182847, 0.13596689358593958, 0.24671778863956853, 0.22876736798113395, 0.9723442276158641, 18.42986226081848, 73.42997027981666, 51.61098211042343, 33.31679659505045, 63.23167447120913, 74.38964874513688, 99.50316506047403, 75.31371993403282, 0.1776651512350767, 0.7822431251406671, 1.5182166234139474, 1.5805391630818768, 0.13878021359203324, 3.716445738269437, 50.38207215647544, 88.96688645885837, 86.70508307795372, 93.44684508539017, 93.39191621349704, 93.02525304978894, 88.81810311348208, 91.61943635632916, 88.15278284011349, 90.06212988207417, 87.53912802665465, 88.46862777586907, 85.80725254551058, 89.01554738321613, 83.235856486905, 81.56043175728091, 82.43690890650596, 68.85285454411661, 63.29409899250154, 65.03686689561414, 63.24444570849019, 66.63105933896958, 61.33651071979154, 60.18056469578897, 59.891780191852206, 61.005949051149436, 55.738147074176425, 56.83004079326507, 56.57242344271753, 56.91753710469892, 56.55027774072463, 59.60203078485305, 64.17494958446872, 65.92294600702101, 67.88503323831867, 65.36166268010294, 71.55626189324164, 71.33190231938516, 73.43658339592719, 71.93157780554988, 70.96465864489156, 70.71452909900297, 65.58325306061776, 72.70594781444919, 86.76162012161748, 67.74976638055617, 72.19704381881222, 68.8347488834012, 65.94552316973287, 71.64226378163984, 67.45187805544946, 65.56574752253871, 60.45690351916898, 61.00233654822073, 67.35064952604233, 68.1744727780742, 67.05440075166764, 70.47588425297891, 66.8474486566359, 66.55763256934382, 68.6217563383041, 61.2059977746779, 62.730791722574544, 69.5430975575601, 69.3322152476157, 66.99336082704606, 64.26552103411767, 66.19246775104155, 65.00502901692545, 66.4931409589706, 61.869364707700676, 63.15412921290245, 64.08405650046565, 63.162319121822236, 62.868917988192656, 65.61778560761483, 63.1861279087682, 65.24913380222937, 60.62847583524643, 61.66240869029876, 53.522443309907, 58.78432250791981, 64.36691430307204, 64.32952234821936, 63.8030186776192, 63.12804545125654, 68.2587331341159, 56.10063683602118, 60.76457423548545, 61.82444572448731, 59.024406863797104, 61.08627919227847, 60.02844341339604, 62.76871711977067, 62.475629775754875, 60.76073031271658, 57.44400155159735, 59.43599685545891, 54.902454730003114, 55.170034900788345, 52.81084691324542, 56.962118764077466, 54.19609861989176, 55.20135110424411, 51.26409945949432, 54.29604453425254, 50.94032349125032, 55.06043995580366, 55.68809763077767, 59.08058697177518, 59.83780445591096, 61.88268899917603, 60.245672118279245, 54.973481009083415, 58.235888865686235, 60.70127110327444, 54.95200995476016, 62.92356052706319, 68.80621756276777, 71.4069607950026, 69.198423201038, 69.06851430093089, 71.98849139675018, 72.9355162958945, 73.24071591900241, 72.57986714763027, 73.76490931357108, 73.58874782439202, 78.75506631789669, 80.97197424980902, 88.59003297744259, 83.93851772431405, 91.99996902096657, 78.70456187955796, 2.580264782713306, 0.8468012319457147, 1.1795904391234922, 0.679900765178665, 24.251310709984075, 98.65543103987171, 78.81647494531448, 85.02996429320305, 39.83941578095959, 36.26435187555129, 30.886499958653605, 1.854262623575426, 0.3507110374348779, 0.27093560525005866, 0.21759650369565334, 0.1910286817339159, 0.10129357793278272, 0.16106889823511725, 0.21606469556929606, 0.1475315577080173], [0.04080515617745058, 0.033100973814725876, 0.1294793392862043, 0.016061446062409352, 0.07837820272412031, 0.12896480399274057, 0.124869198358107, 1.231295122734962, 5.378963908841533, 27.191897899873798, 20.681357652910297, 19.189988182437038, 35.13643118642992, 47.86697387695313, 77.33262661964663, 56.61580093445317, 0.1798954017220005, 0.09342107456177474, 0.4349074098131349, 0.7836546881064292, 0.09076854108922905, 4.574482354425616, 45.41146032271847, 42.709825884911325, 46.42012134675057, 72.92170170814761, 68.51973549012216, 75.0691052406065, 77.69680300066548, 81.1605304287326, 80.62424044455253, 76.39336801344349, 76.89968324476673, 75.71401349959835, 78.53755520236108, 76.7359870479953, 78.86662637033771, 77.4113093653033, 76.025739946673, 68.7580979254938, 56.93792166248445, 57.55190987740794, 55.67140794569447, 55.47645045864967, 55.343878269195564, 54.17019528727378, 53.89675509545111, 49.83589779946112, 49.127243180428785, 49.55872351123441, 50.93272193785637, 51.12137617603425, 51.28236201501662, 55.65014085462017, 56.44242040572628, 61.23454086242184, 63.587790381523874, 65.9167565068891, 64.80238368434291, 67.24629878997803, 67.42011470179405, 67.70501998163039, 68.44368073248094, 64.90427901667934, 64.41576742356824, 54.34784335474814, 41.529600389542125, 65.07118763462191, 66.32213346419796, 63.40119538768646, 62.76985852949081, 63.25585196095129, 65.1698156326048, 57.92748858851772, 54.07773325520178, 58.36780994169174, 59.08243048575617, 63.64412738430885, 61.29013653724425, 62.25360401215092, 60.55565311062721, 59.02452453490227, 61.72364473342896, 59.99016892525458, 60.67619539076283, 66.06791680858981, 61.258200599301254, 60.44335957496398, 61.4023006346918, 61.08260393142701, 59.84286039106308, 60.10879316637593, 59.043446048613525, 59.96024908558015, 60.413541716914025, 60.05527634774486, 56.998239870994325, 54.057627185698486, 63.393903701536125, 55.802470022632235, 58.65968919569447, 54.37105986379809, 47.50025972243279, 54.48492626990042, 59.12150121504261, 59.181513478679044, 61.275176617407034, 62.003384251748365, 53.04325519069549, 58.63171877399568, 63.59245407965876, 60.5730252881204, 58.93821670163063, 59.342299276782626, 59.63060525155837, 58.75004099261377, 55.34176018930251, 53.15554088161838, 54.345893936772505, 53.74980349694529, 52.02045009982202, 51.55217793680007, 49.961295973870065, 48.160653498864946, 49.94105262141074, 46.20120994506344, 47.78133284661078, 47.0866967785743, 48.958447902433335, 48.967932193509995, 49.623234733458496, 52.393695000679266, 50.820295041607274, 50.795207561985144, 50.5675139734822, 52.116128475435325, 54.092144043214866, 52.25036374984249, 52.44052025579637, 57.242148537789625, 60.10591022429928, 65.19749972128099, 61.22194220942836, 61.735458912387976, 58.81705860937796, 60.67412437931184, 56.59062716268725, 57.277995078794426, 58.00825411273588, 61.06352552290886, 65.18342233473255, 71.40986334893012, 73.6407192291752, 80.87199303411668, 81.60862199721798, 82.54565269716325, 6.710765477149718, 0.5858521956589915, 0.46328955780594583, 0.5269451823926742, 23.876565502535914, 74.43670149772399, 64.27052205608737, 52.43080846724972, 40.05622086986419, 21.09401256807389, 15.513169169425966, 0.7824721547865099, 0.11685270876173051, 0.022462103966503374, 0.12507368254685594, 0.014229252945721872, 0.0649948918350762, 0.10463519217146021, 0.09682620515025432, 0.08196062904091612, 0.023769685818303018, 0.03710635344407732, 0.015391972359089602, 0.05273729352460754, 0.05467948346068302, 0.11941723405353485, 0.1956661183747553, 1.9943218822440796, 11.942180606626696, 50.99296954370315, 33.79352146579374, 29.594865422095026, 43.968918477335286, 56.71560564348775, 90.58242444069155, 66.38751153023013, 0.46401280609350054, 0.04572668886413017, 0.6293807599333026, 1.16224865999914, 0.11747437379052562, 4.563216816994452, 50.04968266333304, 67.60447394463324, 67.63204036220428, 83.15519686668151, 77.47024689951252, 82.83688083771737, 84.95900077204551, 85.39154406516784, 84.4518461535054, 81.42915787235384, 81.19915008544922, 80.38858444459977, 82.12628072307956, 78.49972001967892, 82.2314630016204, 79.99820663082986, 77.13230333020611, 71.61410116380262, 60.14567913547639, 61.17662706682759, 57.62363041600874, 56.91784304957236, 59.265228625266786, 57.08162553848759, 57.02818324488979, 53.30027634097684, 51.406089259732155, 50.766629172909646, 53.44037555879163, 51.52827501296998, 54.49091572915354, 56.60066058558803, 58.18874589858517, 64.77769628647836, 65.05005782650363, 68.32898278390208, 69.3430252998106, 70.48857704285653, 71.3480624844951, 69.19676796082528, 70.05888139047931, 67.80708005351406, 66.6769902936874, 60.07198564467892, 49.00756382173108, 60.457735061645515, 65.9124497444399, 67.4554003438642, 63.8495340654927, 64.0325597024733, 67.58343435102894, 60.70089063336773, 57.889006214757124, 61.59575193159042, 60.763542652130134, 67.53717391721665, 61.780746598397535, 64.54164020476803, 63.965189072393606, 63.3831681743745, 65.35754026905184, 60.211425904304754, 65.18433624698271, 69.33871069262105, 62.918892906558135, 63.96001546613632, 65.27067545921572, 65.45941206716722, 63.794005070963216, 66.90768841774234, 59.03366757977394, 61.1217374186362, 63.31315386679865, 60.05468799221901, 59.9104271396514, 56.60897208798317, 62.61839620528683, 58.830633932544345, 59.70891144967849, 55.882372625412486, 51.96093989956764, 60.18936257208548, 60.655434285440755, 59.75050426298573, 63.907895011286584, 62.60442864510321, 55.32729056573684, 62.514602445787006, 62.596081841376524, 62.74105264294533, 60.057900413390136, 61.60254547672888, 60.86873669778148, 60.20893912161551, 59.51670354412448, 56.122147114046165, 57.62259491028325, 56.36502419748614, 55.80595308734525, 57.00175431466872, 53.16459763434626, 51.00118690921415, 52.49361345844885, 48.842722292869325, 47.83991344513432, 49.086881991355654, 50.36843015301613, 51.679250963272594, 52.473244590144006, 56.068057629369925, 54.04057272018925, 54.34074778710642, 53.64162844996299, 53.60589173532302, 56.420145265517704, 55.18883874339443, 56.1304311598501, 59.96039029090636, 64.77661763468097, 66.88105552427231, 63.60026351867184, 63.204696409163944, 62.7691093567879, 61.969989192101266, 62.65667069342829, 61.5290363373295, 63.44381978434902, 64.71421664760959, 69.87247467041016, 76.09867249765705, 78.48385795470207, 82.88097612319454, 83.19183180409094, 84.17440906647714, 7.651917607553544, 0.6614422137218138, 0.8473487703069564, 0.6604398029946512, 31.76965102072685, 80.44862808719759, 74.65557759807956, 66.32212561945762, 44.564644136736476, 28.368910974071873, 15.393300556367445, 0.8552766771566483, 0.03499500746388109, 0.04318883492340965, 0.11859318391690332, 0.036479023195082144, 0.10201782979551824, 0.24006437630422656, 0.06438356899325887, 0.09047155178362325, 0.18671298669951578, 0.13840299189811753, 0.14918362631672813, 0.11200160253793003, 0.19268965228430687, 0.3422328649509338, 0.4246593903630011, 2.213896041916263, 24.51913602890507, 76.39631763581308, 46.50362468534901, 32.76487596573369, 54.42918154501147, 69.65435166512766, 101.9934621933968, 75.11473025045088, 0.6354948770134681, 0.2995279064822582, 1.5736071092467157, 2.134539629182508, 0.2082752361292801, 5.900472931323513, 66.59582076534149, 83.91945500527659, 84.06106041323754, 92.83771668711017, 84.83610506980651, 91.55496043543663, 89.8443598901072, 92.29429583395682, 90.49050761807351, 86.55732739356257, 86.90477878816667, 84.31986624194731, 84.89614871240433, 83.81124465696274, 87.29262275080528, 82.53224603591427, 80.36869802782613, 76.5109920501709, 61.72908898322814, 63.2560480794599, 60.981191050621774, 59.73072767257691, 61.01897916486187, 59.845178511834916, 61.37953519821168, 56.71788454055787, 53.48550242762412, 53.84795688813733, 54.71983309715025, 56.603382710487615, 58.46781861397528, 59.846465049251435, 63.42345876078453, 64.78867500059067, 67.46046804612683, 73.04406396804318, 69.41241987289922, 74.07625136836883, 73.58950876420545, 71.94201131020823, 75.47686699898013, 69.93210254176971, 68.77525437262751, 58.75243363841888, 61.687970776711744, 70.33419255287417, 64.17844441629225, 69.89011749144524, 69.14108599385908, 68.42769315165859, 72.93670869642689, 65.07846755366172, 61.64290666580201, 64.26025329097625, 60.886430509628795, 69.39756977942683, 65.8322843428581, 67.49395724265807, 67.46927768953385, 65.81566133806783, 68.58024981714064, 62.42470172143752, 66.50823423939367, 69.72505630985384, 64.39402964807326, 66.52924245403659, 67.72440433502197, 67.52488905383696, 64.77035360951578, 67.68670251292568, 61.06569067124398, 61.46587833281487, 66.04168399687737, 64.10012252869146, 62.69663572311402, 60.11652808035574, 67.3923521657144, 61.98257215561406, 61.98902837691769, 57.251668130197835, 56.024429105943256, 62.718648064521055, 64.64273145121913, 63.341504758404156, 65.65204358869984, 64.88421609324794, 60.031463638428725, 63.51412434731761, 67.2399131713375, 66.08967027356549, 63.31762929116527, 63.54435013186548, 63.84744344219085, 64.85282928712907, 61.06297246871456, 58.55360869438418, 61.03895971851965, 59.647342005083644, 58.501935389734086, 59.06679591824932, 55.259778730330936, 54.61037151275143, 54.55223021968719, 51.796561210386216, 51.61769328578826, 52.73220731366066, 55.27387180636006, 53.82770961330783, 55.428260218712595, 60.35605153729839, 55.785803871770064, 57.214852763760476, 55.790953943806315, 57.427453071840354, 60.291297128123624, 60.24884139337848, 58.92053073452365, 61.74472355073499, 67.64601184475806, 72.12082432162377, 66.93528621427475, 67.79279478134649, 65.96540174176617, 68.87443542480469, 65.1259203880064, 66.2101968642204, 69.29829459036551, 70.74584530245873, 76.02006035466349, 81.87730435402163, 80.3770762105142, 88.86326528364613, 88.0407677927325, 91.3884558216218, 8.498368032516973, 0.5369400557491087, 1.0055023515897414, 0.7505140922242596, 32.92979594199888, 92.76464293079992, 79.03090307789465, 80.19466246328047, 56.62908207985663, 47.74617664275631, 28.421443277789702, 1.1420592401296863, 0.13505636744441527, 0.13565247578005638, 0.16851295927359214, 0.12702532983835668, 0.20150298823512372, 0.3294835990715412, 0.20222292702284553, 0.2183835977508176], [0.018442417645166, 0.06699941451511077, 0.028612093113723303, 0.03937954315915704, 0.06330810795207659, 0.01738739582980352, 0.08328163275314916, 1.9502610400799785, 8.645888374697778, 24.60887005252223, 26.159596750813147, 24.23507994221103, 37.36039546228225, 53.504443553186235, 76.8629777046942, 63.59585869696833, 0.4407194124594812, 0.0935643176818567, 0.3809365461910925, 0.1279917497548365, 0.1932492335477183, 11.38823897607865, 56.59769919610793, 37.10325664089572, 52.795902682888894, 66.82865265877017, 71.09805845445203, 77.25951363963466, 74.88487935835316, 75.0447630113171, 77.57599399935815, 80.48766351515248, 78.92567373091175, 74.99122265846499, 71.84800778665851, 74.94790400228193, 75.86847643698417, 76.817015371015, 73.77939070424726, 67.49059969379057, 59.73848612077775, 56.44982584061162, 56.044382203009825, 53.83178495591687, 52.85118849046769, 54.244045672878144, 51.44464615852603, 49.883993902514064, 52.02268192845007, 48.87343445131856, 49.55440105930452, 49.343157891304266, 52.527294851118526, 53.118050867511386, 62.1410398329458, 67.39199130765854, 63.53056300070978, 66.42842969586773, 68.88402169750583, 68.50901957481139, 65.33979546639227, 63.143291704116336, 63.327011600617446, 66.82103541589552, 66.77004460365542, 69.8108934587048, 62.731713479565045, 44.691497510479344, 57.57112164651194, 66.82465968593475, 65.09031311158212, 61.844998944190245, 65.9228910938386, 56.469684800794056, 56.53503933260518, 58.180524610704, 63.89597885070309, 60.2935250343815, 60.403076833294286, 63.86344279012373, 62.43259745259439, 61.82521058667091, 63.06352246192194, 59.6710095867034, 64.21405169271654, 60.37202735101024, 62.56828008159515, 65.98826915987077, 63.93411213351835, 63.88167788905483, 66.60912544496598, 57.28728325136247, 47.76058350839923, 48.453199555796964, 57.83785850771012, 59.47106676716959, 60.79822817156392, 59.50456380844117, 57.43632155079996, 60.172735644925034, 58.82903360551404, 49.9606683946425, 48.93618845170545, 53.29290620742306, 58.8010278824837, 61.4950882234881, 64.56952041195285, 54.120192912317094, 57.49056008554275, 61.52199960524037, 59.34685707092286, 58.13461326783704, 58.87106964665075, 59.50340670924033, 60.20604441242834, 58.07111009474724, 58.595177973470385, 55.49027681350709, 58.335277803482555, 55.027013517195186, 55.77254626058764, 53.45954025945356, 50.47461263595089, 48.60827830529983, 46.707372203949966, 46.98450726847495, 46.392366655411266, 47.09812264288626, 46.357461483247825, 47.59776200017622, 49.047089545957505, 48.7031957410997, 50.16559654666532, 50.87971110497752, 51.17843489493094, 52.18340496863089, 51.58847162800451, 54.57317959877753, 53.402822786761874, 58.69015816719302, 60.81992672335718, 60.74651956558228, 62.64626072299097, 58.84706866356635, 60.94304207832583, 56.60308461035452, 55.799743975362475, 55.56950869098787, 56.49928692848452, 61.8279327115705, 64.83573167554795, 72.27823688137916, 76.15855140070762, 79.7370630694974, 75.78664795044931, 86.9951109732351, 13.667896986007692, 0.7710157082446161, 0.7995062117134372, 0.3629640009134047, 38.745670703149614, 74.5136897794662, 68.42844624673167, 59.180583876948205, 33.850878284823516, 14.868167754142517, 12.773087659189779, 1.2074015145340276, 0.055548851528475364, 0.04059766892403845, 0.01605002752189795, 0.05127231507832485, 0.017625645343815128, 0.22589568739696858, 0.3036113696232919, 0.1430494377329465, 0.006823210456904265, 0.03419777423503899, 0.05301086735280772, 0.026610910577038606, 0.08753673789361793, 0.049310566917542493, 0.11132001411169769, 3.442926853895188, 21.04798943765702, 47.378929045892534, 40.56446590731221, 32.569930245799405, 46.35058556833575, 62.56387133752147, 87.39054079978698, 74.37483787536621, 0.5213833227753639, 0.06416812208631346, 0.8432615993003693, 0.7369136413739574, 0.21368079848827856, 12.528009145490586, 64.6055434596154, 61.56909942626954, 68.17546906009798, 77.07171055578416, 81.29522462044993, 85.06605009878837, 82.10979107887515, 80.30990169894311, 82.20500269243794, 82.94290250347507, 83.58838342851209, 78.68983730193108, 76.37951420199487, 77.71524598521572, 78.45111400850358, 78.15732063785677, 79.18743702673143, 71.05151560998732, 62.53445356122909, 57.51307056796167, 59.58186980216735, 55.803344711180664, 57.25074245083717, 56.93451312280471, 54.64222115855063, 52.07144091206213, 54.122652238415135, 49.769625433029674, 53.51706966277092, 51.57738308752737, 55.01637212691769, 56.050748209799494, 63.652591859140706, 69.78679441636609, 67.25387680915095, 68.6107893913023, 71.40987119367047, 69.98533694974839, 67.26996637159779, 66.74218793069163, 65.91106907013925, 71.322292512463, 69.09056586603965, 71.77869166097334, 66.27767732066494, 53.51430439179944, 60.11838728381742, 67.48433174625521, 66.20689422853532, 66.22426248365834, 67.71837172969695, 62.470515005050174, 59.29897277585922, 63.72833282716813, 65.93757644776376, 63.00840531626056, 63.762504516109345, 65.87456749331567, 63.734008496807476, 63.65574152238908, 66.26591805488833, 61.11410840865105, 66.25070710336009, 61.003866272587935, 62.21172878819128, 69.67953328163394, 64.44857805005967, 66.45553327375843, 68.90272355848744, 58.539339111697295, 47.54086017608643, 48.43849459002095, 58.67406076000583, 61.743464469909675, 62.651328425253595, 60.53800636722196, 60.54154826748756, 64.24896470962032, 60.47493465485112, 52.51253104978993, 53.29546359277541, 59.79452502342963, 62.03542609368602, 62.963211767135135, 65.88612279584332, 54.666516319397964, 59.59279360309724, 63.299555009411236, 62.37999062384329, 59.461307910180864, 60.931533844240256, 60.99627256393433, 61.20576243246756, 57.64661158284834, 60.601254586250555, 57.69375847231958, 59.4101131346918, 57.11793099680255, 58.947336212281265, 57.056145821848226, 54.49610502489152, 49.60175191202472, 49.68316462732131, 49.628655449036636, 47.75291527471235, 49.40320153390208, 50.02721532698601, 50.42899154847669, 50.9368129699461, 51.61082913798671, 52.71130892538255, 52.17080631563741, 52.80220200938564, 54.27744465489542, 55.488927518167806, 56.00323653990223, 56.61062732819588, 61.03966966752083, 63.4724844655683, 63.2317921423143, 65.96316599076795, 63.000148727047836, 62.903332864084554, 59.9764092506901, 60.03397787770918, 61.06487874061831, 60.25296772679975, 66.2175944543654, 70.1356892431936, 75.23281712685862, 78.88788561667167, 84.66530153828283, 79.19085733352169, 89.58395373436713, 15.534927537364347, 0.8986631167992469, 1.0142657232861365, 0.3866067919279299, 40.25750121762676, 83.54508046180972, 77.34576655972388, 70.9314989274548, 44.61517995403659, 21.808797851685558, 11.69432113247533, 1.2954369067184388, 0.36728921075982435, 0.1426663478055308, 0.0527435333107508, 0.04455066729156722, 0.0517073879018426, 0.30944209545850754, 0.2124620904965747, 0.05588098511760754, 0.1108292581874036, 0.1403334721802704, 0.11883024982507191, 0.14169422819489433, 0.22085076858920438, 0.17483741345424808, 0.339225877917582, 4.465734641398154, 37.93685051702684, 69.51007120070919, 54.289400039180634, 35.05974492719097, 56.22575259977772, 77.86854005629017, 97.07790866974862, 86.3911287246212, 0.6269427004360384, 0.18931814529482396, 1.3808243313143331, 1.3695386917360368, 0.649577901969033, 17.82425811213832, 84.83330449750348, 75.6301296910932, 83.65834282290551, 86.66305880392753, 87.24934331832394, 90.37387986336985, 91.77169492167812, 86.32281672570014, 86.87703978630805, 88.85822111560454, 87.75865524045884, 81.59539576499694, 78.46179070011263, 82.45922719278644, 84.50527667999268, 81.17046971474925, 81.78449323100429, 73.91579504935973, 65.5094458210853, 60.56344293778943, 63.131049986808534, 58.14883970445203, 57.945413820205204, 58.59454254950247, 56.8682486011136, 54.50470286030924, 58.177928001649924, 53.957398860685295, 55.90620494657948, 52.71881634189237, 58.26915840948782, 58.80944528887349, 65.49066943507042, 73.54158524544009, 67.97736583217498, 71.71125042823054, 73.20571268758466, 75.56233544503489, 70.8663954273347, 67.78899792701968, 69.28738255654612, 73.47100611655944, 72.8378257443828, 74.3017327400946, 64.03170854814591, 58.56080232128021, 63.656172983108036, 71.01500618842341, 71.83625636562225, 65.58981126354587, 70.95602943051246, 63.4672284895374, 63.41730456198416, 64.49275178294029, 64.96453838963663, 66.16100249751922, 66.52897573286488, 66.67713934375395, 68.35756901771792, 67.09911577163204, 69.28753160661267, 63.31253020994125, 68.46914475963962, 64.93843893851003, 64.8309777628991, 70.30578674808626, 68.3384592302384, 70.06149368901407, 72.32024546592467, 59.757803793876406, 48.040079839767955, 51.21827440877115, 62.81255352881647, 64.92521662865916, 66.4530857147709, 63.09951805299329, 64.46556191290578, 64.03920419754522, 63.75582079733572, 54.05202604109242, 55.41333167783676, 61.92998886108399, 64.92051762919273, 64.10163656357797, 66.76907970059302, 58.145925383413996, 62.43410364274056, 67.48547707834553, 63.585840963548236, 63.29197306786815, 62.5563011630889, 63.03061377617621, 61.602286600297504, 62.208602659163944, 63.627775023060465, 61.60562061494397, 63.55329705822853, 60.566698505032456, 62.46019917149698, 61.18979838586623, 56.08457865253572, 55.41473588635845, 52.621310141778764, 52.05172707957607, 50.20905640817458, 54.000458640436975, 54.30404224703389, 52.64148681394516, 54.19026605544552, 54.3811168209199, 56.15583242908601, 55.754868138221006, 56.49481542648808, 58.20095231456142, 58.38285615367275, 60.30322505581764, 59.81114018347956, 65.24410140129828, 64.41376701478036, 67.26947999769642, 72.07673688088694, 67.22166630529588, 68.77679978647541, 63.9598624936996, 64.50238904645367, 64.75593105439218, 64.10578643122028, 70.22176957899525, 74.63364370407598, 80.3928441386069, 82.76067703000962, 89.58120023050617, 82.30048102717247, 96.19597942598405, 16.977441926156324, 0.8634137566531859, 1.6667207450635972, 0.42157294469014295, 47.65516588764806, 94.14785892732682, 85.653181845142, 85.073667341663, 56.049814685698486, 35.54883703108757, 29.25128736803609, 1.1595785065043358, 0.3744706721796144, 0.20925163051053403, 0.11103979447075438, 0.13649598454996464, 0.22134544688367078, 0.41597523215797644, 0.5205775208530888, 0.23949239973820027], [0.0710037560953248, 0.029446728670248584, 0.015329496931254625, 0.030492086286446264, 0.11511342104284034, 0.050035711272709796, 0.280254635839693, 2.591894365126087, 13.225045704072523, 32.42336892312573, 22.90351567729827, 24.01172645630375, 41.16117215925648, 52.39789978150399, 76.1544878252091, 64.37492378296392, 1.637299781845462, 0.09667862597252093, 0.11771763735000165, 0.16190497595216, 0.4459195560024631, 5.111737731964358, 47.22017895790839, 29.69677644391214, 53.46026197556527, 65.69347166245984, 71.72640646657636, 76.24350993863999, 77.95620502964144, 76.19200921827748, 78.65594802364227, 76.55620128877702, 80.90549007538827, 77.59126770880916, 76.39867105791646, 77.90224890555106, 74.04557843362132, 74.5281005674793, 72.83347975823187, 66.23801431348248, 61.646138698824, 55.60127596701346, 56.58186851009246, 55.170054512639204, 54.2325335164224, 53.62043980629214, 49.23441410064698, 45.89504541889314, 51.06509800880186, 51.581913425076394, 49.8982281838694, 48.76230193722633, 52.001261864939046, 61.60121971561063, 66.28963270495015, 65.94533489596459, 69.03895531931232, 63.920066125931285, 62.25246652480095, 63.07855690679243, 64.73761750805762, 66.446668717169, 64.6049354922387, 63.816484174420765, 64.54372298332953, 63.81474656443443, 67.10124954100579, 67.00468863210371, 55.79091472010459, 59.26480893165835, 64.02454237784109, 64.38218409015288, 60.41531070586174, 62.405011423172496, 60.04089301632297, 54.133293628692634, 62.106923057187, 62.80635226157404, 63.340794809402965, 64.17593409938198, 59.748554845010084, 62.90849078086115, 60.21927848938973, 60.95941405142508, 56.44782150945356, 51.10869123089699, 48.79177070433094, 62.81004321190619, 49.38460165454496, 57.40912383602512, 51.68836262918288, 62.02960921872047, 54.37524895514212, 44.64972034577401, 46.63790702819825, 64.37830486605245, 60.09173085612636, 61.887391921012636, 56.6418807737289, 57.68924382425124, 58.61164800582394, 52.935723412421446, 50.72772318317045, 55.91017830756403, 59.62540026633971, 62.13447770764751, 54.59301502473893, 56.61854267120362, 59.52443453573412, 55.66409664769327, 62.893683833460656, 58.60430140649119, 61.651739843430065, 60.85075263054141, 59.17391584765527, 59.45546357862411, 59.173986450318374, 58.97018009616483, 58.54124146123087, 60.28474676993586, 58.695963275048044, 55.52170676569785, 53.17782386656731, 48.89712164478917, 47.3739750923649, 44.94660846648678, 45.20869731903077, 45.326140926730254, 44.99247274091167, 46.76982418183358, 48.63146735775856, 50.41855019907798, 50.24221612561134, 50.85741635291807, 52.00337210009175, 51.31114828971125, 51.678768511741396, 53.632465793240456, 55.20263764166064, 61.65037878098027, 62.07421048994988, 63.73063133608911, 62.227253529333304, 59.81554500518307, 58.07676223016555, 56.64243382792319, 54.520733587203495, 58.55908432314473, 58.40881439947314, 65.58982695302656, 68.99664078989338, 74.71879836051696, 73.0194236386207, 79.54285083278533, 74.17857031668387, 86.67619089926444, 19.59947970605666, 0.6287208824388443, 0.7324862047549218, 0.5925834731709573, 12.14671063807703, 71.24697516041418, 67.06903903715073, 60.07237395932598, 29.174120618451028, 11.178882468131281, 11.626932851729855, 0.21475995590369548, 0.3853457499175303, 0.09325785186862753, 0.025333740500613086, 0.08836513940965937, 0.0653607677668333, 0.3031284277958255, 0.3471340196988275, 0.004419167178698004, 0.03996288080910041, 0.020539744216347897, 0.015183358956428786, 0.011511542627798214, 0.06819310207520762, 0.0958858245623208, 0.18154259801151293, 3.5233371584646167, 28.555790339746785, 52.42272446232458, 35.806881919983894, 23.57905568615083, 46.18916042389409, 63.63936562691966, 87.68764465085923, 74.76672187928231, 1.8704148213709555, 0.010475178883831588, 0.33640272134254057, 0.15807576207143648, 0.4977955368738021, 11.928719032195307, 66.71076974561139, 51.19441070864278, 66.7093655370897, 74.31952461119621, 81.24483785321637, 82.40355307056059, 84.40257333940076, 79.03608845126244, 83.77421748253607, 79.97945770140618, 85.25153898423719, 82.82476855862527, 80.27270978496921, 80.90590584662654, 78.61973670221145, 77.42470033707158, 72.8792538181428, 68.66971908077117, 61.59645795822144, 58.05488717171454, 58.630710724861395, 59.043767682967655, 57.42060853588966, 55.65813856740152, 53.22024822235108, 50.073522829240375, 52.368580064465924, 52.547608806240945, 53.11442267510199, 51.58437275117444, 54.160448197395574, 65.50934776183098, 67.7148651307629, 70.3185893643287, 71.1309906744188, 64.6728160304408, 63.44768724133892, 65.29710831180697, 68.18673410723287, 68.95256119389688, 68.768413759047, 65.55662016714773, 67.12586633620724, 67.69752825460127, 66.95899301959624, 69.34035808809342, 61.18969248187158, 63.131799159511445, 65.55565526408535, 65.25202458904636, 64.43930556697231, 65.36921716505482, 62.00750666279947, 56.241955910959554, 65.38854268289381, 64.1577107675614, 65.56209579590829, 65.74308572276946, 62.96334120535082, 64.6558557018157, 64.50634671795753, 63.84095584192584, 55.55568233613045, 50.64762838425175, 48.983778569006155, 63.18632794964699, 51.874310431941865, 58.16877318966774, 54.34949075022052, 62.25913455409389, 55.12382938015846, 42.82928166850921, 46.87363755318427, 62.71122301778486, 64.1365574252221, 65.39263371498355, 59.43580858169064, 58.69286068024174, 58.032627720986646, 55.31113432299707, 52.59965865842758, 55.069892867918945, 63.992892772920676, 66.04191149434736, 56.20077494652041, 60.50356011236868, 60.443100698532604, 56.81853648154967, 62.40395630559614, 60.339408920657256, 62.37417767124792, 60.64340829849244, 61.691387161131836, 62.409969299070305, 60.19417924265708, 61.07681451305267, 61.06115248895461, 62.11054340485604, 60.50037514778876, 59.22363973432972, 56.947158844240256, 50.71762307997673, 50.32467611374394, 47.50938707782377, 48.543567042196955, 47.282207319813395, 49.187482941535215, 50.6604584570854, 51.58387853253273, 52.70810434895178, 52.18386388594105, 54.29083562666371, 53.55967836995279, 54.355362538368475, 54.966777678458925, 56.34915821013912, 57.47440776517315, 63.86619629398469, 64.9803965322433, 66.89215583185997, 65.40825651537988, 62.61119865602063, 61.918072700500495, 60.45122784952964, 59.96259858531337, 63.356735321783255, 63.49264544825401, 69.92030405229139, 74.32685944341844, 77.2189014188705, 78.80852037860502, 84.19691562652588, 79.79392959225564, 87.62166253982052, 21.828195933372747, 0.6623162893999008, 0.8183631901779483, 0.6269246207610254, 12.541772742425243, 81.79554647014987, 75.8257539810673, 73.83095418253254, 38.42605636965844, 20.048857811958563, 10.861744130811385, 1.7457232864633685, 0.690021031806546, 0.11047468971340887, 0.08425672478493183, 0.052490176542872385, 0.18848281834394703, 0.3596944602266435, 0.3243281950633372, 0.057799820863311334, 0.12571364941616214, 0.19921361108220395, 0.09447350316951353, 0.1854953665526644, 0.16919453237806598, 0.23365949821327966, 0.32888782781458675, 4.140278427831588, 43.4426030805034, 71.75852283354729, 44.19300740764987, 37.666085381661695, 59.540194619086485, 78.77196388859903, 97.73441145496984, 89.27060342604115, 2.747064554883588, 0.13752716953956312, 0.8323656226838789, 0.41084333172728943, 0.6465707923616133, 14.846304462802026, 88.17481871574157, 61.987714382909964, 81.61186187498032, 82.55599206493747, 93.2106948667957, 89.38562300897415, 92.47614475988573, 85.86623714816186, 89.25749486492526, 84.39626616816368, 89.7288303990518, 87.46228095023864, 82.76946313919561, 85.09474615896903, 81.06222014273368, 81.94630669009301, 78.44344185244653, 74.48084385164323, 64.84545130883494, 62.22078946328933, 61.36917621858659, 63.515081405639656, 60.0140679267145, 59.75901188388948, 55.70874106499457, 51.87394565151584, 54.87964222508093, 56.29872045209331, 56.49412116696758, 53.248948204901914, 56.624222263213134, 68.83602757607737, 70.1691549055038, 70.48148539758498, 74.60287663244432, 68.0585902737033, 67.06333591092017, 68.11922227182697, 68.37331341158959, 71.29616168237501, 68.5432069532333, 70.24810437233218, 70.43632322742094, 71.55934487619709, 73.002973218118, 69.13482589106407, 64.15931501696187, 66.8366542939217, 68.35003806698707, 67.62585086207237, 67.87530576029133, 71.03639095060288, 64.71897056025844, 60.252767685920965, 66.49404310411023, 67.61297764316683, 69.57079733571699, 69.12950715711041, 65.47815707422072, 65.7047131753737, 68.62302718623992, 65.53947548712453, 60.19035885410925, 53.41453890646658, 51.04755716939127, 66.81804656982422, 53.83345588561028, 59.88753226495559, 59.670840924785985, 64.72246931445214, 55.421556888088105, 44.009103159750666, 47.571540955574285, 69.3395108561362, 63.7304901307629, 68.29281853091332, 59.97885680967762, 62.097568204326016, 60.29263857872256, 58.798615624827725, 57.21917913806055, 62.05900738316198, 66.45758859572872, 65.81970922408566, 61.656411386305294, 62.04556934295162, 63.822744277215776, 60.267527564879394, 66.71122474055137, 63.28780751074515, 67.43985206850114, 64.60983845495409, 64.25332246288177, 65.30935002911475, 62.28464564969463, 63.94505946866928, 64.03140260327247, 64.46282017615535, 63.65398430055188, 61.285959213010734, 59.72998242224417, 52.7741962863553, 53.435076436688824, 49.63699440802298, 50.25455982454362, 49.7242828338377, 52.58430650157314, 53.45388420166508, 53.76171181278845, 55.90626378213206, 54.40483931572207, 56.25535472746819, 56.64625029410086, 55.91758374244937, 57.879592526343565, 59.44084882736207, 60.62533009436823, 68.48131979665449, 67.60637237179664, 70.62839385001891, 70.67183802204748, 65.70672927364227, 65.18799974072364, 62.93155431747437, 62.98234901120586, 68.80962218007734, 69.18069408785912, 75.81597158985754, 77.73568153381348, 83.67189853422104, 82.24945099123063, 87.81441565482848, 83.02134206218105, 90.17965193717711, 22.97632467362189, 0.684341807519236, 1.3762870070434388, 0.6298649275014478, 17.2659695148468, 91.56823373609974, 84.33384556924143, 86.87611410694738, 51.15793266604024, 33.93560932528588, 32.45710719016291, 0.8104045785242512, 0.9554731941992237, 0.35726464383544465, 0.17253968594295366, 0.14457926935245916, 0.27911953868404515, 0.56379922094845, 0.6194821072201575, 0.2102990105988518], [0.07432485449939005, 0.036264196819355415, 0.041572488994608005, 0.10864462823637071, 0.13735938096238723, 0.07742912703824621, 0.08398084120163996, 1.8507812748993597, 27.489707777577063, 34.332706159160985, 21.073775099169826, 41.40300981460079, 48.67973212272891, 51.92814496255691, 72.7713337252217, 68.9728633819088, 3.12846994688434, 0.09155010398958, 0.14255843666051665, 0.012114736319129026, 0.010946303805065973, 0.25638134429051035, 16.84346356699544, 25.26286840438843, 52.97406458085584, 65.1430925246208, 71.61452477978122, 71.71772233901486, 73.62615154635522, 70.07031117716144, 77.11902218480265, 77.63304879588466, 77.14942839837845, 74.78876559965073, 76.50313162034558, 77.66885219081756, 76.11432275464459, 72.63463127997615, 70.64977861219838, 65.38299645147016, 58.580629902501265, 56.225748677407545, 57.309432875725534, 53.63819245369204, 54.17216039473011, 51.641400091109745, 49.375623349220525, 46.85002096237675, 49.493396436014486, 50.84121696410641, 49.90925004405361, 47.39103740261447, 55.38915811046478, 63.64760652665169, 65.9837584341726, 63.467040215769124, 60.471628096795854, 62.147095972491854, 63.93075850702102, 67.45598085464971, 68.53900217240857, 66.98739097964379, 64.04701363655829, 62.838452939064275, 61.12720128028624, 63.82890632075649, 62.41957518362231, 62.86601935663531, 66.29297456433697, 61.5459966659546, 59.815191991867565, 58.57424036149056, 63.419097085152906, 58.58372073019705, 55.2761193244688, 58.577633211689616, 53.594689446110884, 63.09081823595109, 63.88466673512613, 62.24043661548246, 61.83154913686938, 64.63095257359167, 63.938093339243245, 60.805829724957874, 44.917229913896136, 55.427385530164166, 45.74947841705815, 44.7962091045995, 46.82038353335473, 46.20318289726011, 41.83984025832146, 50.495209001725726, 48.98400214410598, 41.324436895308956, 40.853058215110536, 46.49631730971798, 60.68603269515499, 58.736712778768236, 60.08617285759219, 58.45441979746665, 52.07547310859927, 48.306769632524066, 49.21411191263507, 44.601585019019346, 63.520074582869015, 55.38106626079929, 54.98308689363542, 60.25407383518835, 53.849894539002456, 59.94193946161578, 58.34798236047068, 59.014173400017526, 59.38905785160681, 58.64980090049006, 60.506568570290845, 60.0631760012719, 58.70198411326255, 60.939613926795225, 62.86172436129663, 60.08556881258565, 58.83899250338155, 60.13944256690241, 56.31459428418068, 53.24360593672722, 49.03023119895689, 45.99128469344109, 46.849891524161066, 44.94853435024139, 45.82492912969282, 47.141151043676565, 50.25273984478366, 49.46675177543394, 49.72627539788523, 50.868124423488496, 51.78874000426262, 50.98530131001627, 54.53718008533601, 51.594602292583836, 54.16875577742054, 64.07077927743235, 65.09277243768015, 63.761665128892474, 63.137055135542354, 59.88191543086883, 57.45687084813272, 58.500460578549294, 55.8397090050482, 59.50119449246315, 60.591836975466826, 73.02509538588986, 72.24721877805649, 77.40864999832647, 73.10267202315792, 77.33366212537213, 72.4707389646961, 83.59463568656676, 26.14782571792603, 0.2538975646659251, 0.4534270644428269, 0.4542689031410602, 11.337325630649445, 73.60661814289709, 67.0638301295619, 59.98234379676081, 40.89284281576834, 13.1767701525842, 11.369238034371408, 1.1767481916373776, 0.8929474880137752, 0.27190084539113507, 0.14412766052109582, 0.10109653245777854, 0.1899570473019154, 0.2576823760905574, 0.09832476506069784, 0.1752606157453791, 0.09437116914458814, 0.058029838762576544, 0.07747700753351373, 0.011610407232036515, 0.0727885954021927, 0.09213282110830469, 0.18272937545853277, 3.5140592821182746, 45.21944853567308, 53.11934917203842, 27.391142537516934, 38.97650218779041, 54.41990906192411, 65.05718869547691, 84.2584183908278, 83.56555523410921, 3.9011729484604256, 0.1793026641732262, 0.3746334198982485, 0.06064745011709391, 0.42609935986899566, 1.2469331223157145, 44.18980675358927, 47.2983870967742, 67.10434821344191, 76.1727503807314, 82.00464802403604, 80.01475118821668, 78.9046968952302, 77.59657075328212, 80.03517104733376, 83.16919972819667, 79.58236478990125, 80.3983982147709, 79.5785600908341, 79.67490919174688, 79.7323719147713, 76.29860355008033, 73.51273229045253, 68.21214322120913, 63.299523630449855, 57.77995647922639, 59.95686015775127, 56.65926864070278, 57.9324072407138, 52.745233505002915, 53.04181568084225, 51.01130270188855, 51.83858940678259, 52.01832025281845, 51.867803219825994, 49.911983936063706, 55.80807508960847, 64.82564333946475, 69.47251842867944, 63.36617254441785, 62.915849147304414, 63.09643507003785, 65.0379063237098, 68.89938954384097, 69.65623440281038, 68.55470734257852, 65.35328841978504, 67.56102977260467, 62.730022938020774, 63.66612011386503, 67.0739733788275, 67.03271788935508, 67.36605659607919, 65.97977330607753, 65.60143324636644, 64.42223148961222, 67.91819295575543, 61.5105894304091, 58.07512660180369, 58.56725462021367, 58.80790771976594, 66.103680979821, 67.36425230579992, 64.13839309446274, 64.83214662921044, 66.38107884314753, 62.26173900788831, 60.12359226903608, 48.52953672409058, 56.42662894341254, 49.204796283475815, 43.705229297761, 45.048499876453036, 48.84933148660968, 45.96487929744106, 51.972024517674605, 49.763298649941724, 41.82192679374449, 42.25828655304448, 46.850413199393984, 61.43298533654983, 60.680764952013575, 61.758118444873446, 58.79345378568096, 52.74429213616156, 52.81135682136782, 49.640210751564275, 48.61988067626954, 64.5421814918518, 57.313261109013716, 57.55985267700688, 61.671849835303526, 58.22928751668623, 59.65401787911693, 60.837138083673295, 60.601266353361076, 61.267065155890684, 60.21880780496905, 64.22923518765357, 61.39370279927408, 61.462618843201675, 61.36341425680346, 62.58899019610498, 60.86488100790209, 61.230214488121774, 63.511304163163715, 58.344817007741625, 55.04233037271808, 53.61746664970152, 47.681822315339126, 50.32007125116164, 46.77591170034101, 48.824930421767704, 48.3154772943066, 52.388219371918716, 52.55843454791654, 52.25676505796371, 52.08518881951609, 53.611747833990286, 53.21681222608013, 56.17405576090659, 55.2658191803963, 57.93017148971558, 66.99470227764499, 69.10119548920663, 65.9779062578755, 65.54588856235628, 62.61430909556728, 61.70233449628277, 63.02027833077216, 60.930376745039425, 65.28490189583071, 65.95226964642926, 78.52144995043355, 77.66102313995361, 81.2824063147268, 78.03958677476453, 80.81413807407503, 76.21152693225493, 83.04811616097727, 30.00056793612819, 0.2274095690658977, 0.4000661906696135, 0.5737360554837412, 13.364271213931422, 81.66624945978965, 76.31182193756104, 74.68589751951157, 48.32835443558232, 22.257856284418416, 6.416868653989608, 2.0189435804082505, 1.039981149858044, 0.19910393793496395, 0.05604884647313626, 0.05136018536323982, 0.12368909353690764, 0.2523865328440743, 0.44916835102823477, 0.1579702257989876, 0.1587680910503672, 0.1328283232907134, 0.12421076876982567, 0.22732415026234043, 0.2224657125771046, 0.23664062211830772, 0.2416363734030916, 5.006695678157191, 58.237869662623254, 73.18138614777597, 35.609661225349676, 55.40815022683913, 67.7452164311563, 77.46282577514648, 93.40933938180247, 95.50022156007829, 4.7252008991856735, 0.21995775521762911, 0.6220013720373954, 0.11174371435997948, 0.7775784464132401, 1.198068725005273, 54.34071640814505, 60.17757584971767, 80.6509360959453, 86.94107640174128, 91.68057826257522, 86.62942055732974, 84.94967337577575, 81.00206667377104, 84.95393306978288, 86.72828781989314, 84.89505829349642, 82.71982162229477, 82.76521913466915, 81.69426302756034, 83.64805052357336, 79.82905049477854, 79.42031598860218, 69.61276669656077, 64.56889675509545, 60.132641177023615, 62.166288129745, 59.22694237001481, 60.47728023221416, 57.467888785946755, 57.723289997346946, 54.563079495583814, 54.511359122491655, 55.9841698984946, 54.751204213788434, 54.25444387620496, 58.10926691178353, 68.28293415807909, 70.84965475143926, 68.61852430528211, 68.1110558971282, 63.30129261939757, 64.44003905019453, 72.42204666137695, 72.15270534638437, 73.64369238576582, 70.30496305035007, 70.74618262629356, 66.06131153721964, 69.62322373544016, 67.89230531261813, 68.55063592233967, 71.2587736498925, 68.69427311804988, 69.52205796395579, 64.14186831443541, 67.55321641122141, 67.25283345868512, 61.877429100774954, 61.795561390538374, 61.990205087969386, 66.29455135714623, 69.50118310989873, 68.31781971839168, 66.95652977112802, 70.18137701096074, 65.87078632846956, 62.735424041748054, 50.12414886105446, 56.35118999788838, 48.967449741978804, 44.99215895129789, 47.968425981460086, 47.5749965636961, 48.417121594952, 54.07862363323089, 52.33752273744153, 43.316075263484834, 42.3823275873738, 49.04597559282857, 67.08284578015729, 63.08140454753753, 64.00655438823085, 62.16896710857269, 52.83330248248193, 52.621110100899976, 53.4145506735771, 51.26314632354244, 63.48860540697652, 59.56419560217089, 61.089013084288574, 62.514335724615286, 58.91409020270071, 63.16950882634809, 64.10151104773244, 62.88523897047966, 63.40165038262645, 62.44275246897052, 66.31168427005892, 63.33494655547604, 64.18451232294883, 65.47987899472638, 67.04381819694274, 64.0769491657134, 64.48194173074538, 66.12306533321258, 61.30648889849263, 58.35334424049624, 56.029226164663996, 51.19215926816387, 54.284708884454545, 52.92674902946719, 52.828450510578776, 52.224719293655895, 57.45937332030266, 55.44473809580649, 55.89725409784625, 54.73833491725307, 56.55997776216077, 56.45790984553676, 59.61745746674077, 57.99607123098066, 60.94798426474295, 70.5438667728055, 72.93925039229855, 69.64493013197377, 68.2980509727232, 66.70399973469397, 64.49250467361944, 67.18998139904392, 63.536391642785844, 68.46024882408881, 70.28133469243204, 84.39789002941501, 82.03002575905093, 85.30224738582488, 82.05683908154889, 85.47391383878647, 77.97901753456362, 86.92239023024037, 32.40157035089309, 0.4158052525693371, 0.8099584089171502, 0.5332312096030482, 14.217462232035977, 92.14100176288237, 83.30113257131269, 87.24346760780581, 64.32399180627638, 41.40698709795552, 31.96773659798407, 2.3419548090427154, 2.2160440298818775, 0.4591864215270166, 0.369279537830622, 0.27939762860055894, 0.6737193549352308, 0.3271675007718225, 0.5831102137604068, 0.30033977582089366], [0.08850614555300244, 0.037228107797883214, 0.11339593618627518, 0.01405422100722189, 0.0875501903975683, 0.0036982686264485486, 0.1214759651150915, 0.9646477406063388, 34.62835873326948, 33.08946386460335, 30.149296368322066, 27.568535650930098, 45.13607071292016, 57.011485715066236, 74.15905260270642, 72.62789264802011, 8.065443779191664, 0.33450928907240596, 0.40043513861394703, 0.06887380950032704, 0.14918486737916548, 0.22242890971322216, 12.917659359593546, 34.4831015986781, 62.13942381643481, 63.42983653468471, 69.25645859010758, 69.49354233280306, 72.79236547408566, 69.49394241456064, 73.70724262729769, 75.52107995556247, 80.22023631680398, 74.38347493448566, 77.61324082651447, 76.10062583800286, 73.54605674743652, 73.42444758261405, 70.64191818237305, 66.59581292060115, 58.038970193555286, 53.112226147805494, 56.40773096392232, 54.18073077355662, 55.32880067825318, 51.202455489866196, 45.88957371250276, 47.734970431174006, 51.063662421318796, 50.78770799021567, 50.6717784174027, 49.367864901019686, 55.93603064936977, 66.87620747473933, 65.45483073880597, 59.60982061201527, 66.32960165700605, 67.28607162352532, 65.55875785889165, 65.85825827813917, 64.52804526975079, 63.32787844442553, 60.96749805635022, 59.06892968762306, 57.44503705732284, 54.68542998836887, 59.35991856359667, 61.95069113085347, 61.139823467500754, 64.91959587220224, 60.272308934119444, 62.47067974459741, 59.64421587605631, 65.51745530097716, 60.013797283172615, 54.42497676418674, 56.06326449301935, 56.874669521085686, 60.816067111107614, 61.27958536148072, 65.73007129853772, 61.35352596159905, 48.12361063495759, 48.54246485617853, 57.55403972441151, 51.95737838745118, 45.19796571423931, 47.266309953504994, 45.23427901729461, 48.91970665224137, 43.08605963183988, 45.60588436741983, 43.50393718288791, 41.708205515338534, 40.582948115564164, 40.28476561269453, 41.31659999970467, 55.106225782825106, 60.02183029728552, 58.67206035121795, 50.754238405535304, 48.584249865624216, 45.787376357663064, 58.17566871643067, 58.88085203786051, 50.16642024440151, 60.9193705743359, 59.47661299859325, 56.515278431677054, 57.05098790507163, 60.136206611510254, 60.403696567781516, 56.297182882985766, 61.00431342278758, 61.05366860666583, 61.35930753523304, 59.466348155852295, 57.38689968662878, 58.521727669623594, 66.18349336808728, 60.22861373039984, 59.50110820031936, 60.327535906145656, 56.14368092629218, 48.14836471311508, 48.30310613878312, 45.95928207520516, 45.91804227521343, 45.42414919022591, 46.61011311315721, 47.993121224064986, 49.339325735645915, 47.7874085980077, 49.36142044682657, 50.36994418790264, 53.682048474588704, 52.732536792755134, 53.06196881878761, 56.84268259233045, 60.95147909656648, 64.42944080598893, 62.28268446460847, 61.82458692981351, 60.537214048447154, 57.14831367615731, 56.81740291656987, 56.253456300304784, 61.360213602742846, 67.03241194448164, 76.02290799540859, 72.61487822378837, 75.0302267074585, 68.54177136575022, 77.876980996901, 77.9779584946171, 85.58336365607478, 59.987250681846376, 0.08661288182221114, 0.29002881458690094, 0.2578023454594997, 9.964356826197717, 74.10058575291788, 65.08244091464628, 61.62524423291607, 44.425286246884255, 14.05403667880643, 5.672349352990428, 2.876750860483416, 1.3637980578407165, 0.1548371713368162, 0.2415498054676479, 0.13930723611866275, 0.05846603390490336, 0.21113294326970655, 0.21270826519016298, 0.09548411869834508, 0.04859723563816759, 0.025957286275262316, 0.05737734252526876, 0.020656145530782884, 0.015921710667410688, 0.1369574605937927, 0.07842642795895377, 2.217890730788631, 50.9827321575534, 49.132236357658144, 40.462448981500444, 38.1954288482666, 51.56349789711737, 71.0607567141133, 83.03629413727792, 87.60472574541646, 9.578574069084661, 0.2887337582726633, 0.36883827118623647, 0.06329404640822642, 0.17105961939500225, 0.04887003571756425, 28.369866071208833, 51.501822548527876, 74.45133978320708, 73.83848513326338, 77.41016403321298, 75.46144423946258, 81.90123081207275, 75.7874559587048, 81.80950226322298, 79.25055580754434, 84.6804811108497, 78.73794124972436, 79.633802752341, 76.71350402216758, 78.20786429989722, 75.52837556408298, 74.01590962563792, 67.76664041703748, 61.71347402757215, 54.867969251448116, 57.27077399530719, 57.30535361074633, 56.39649729574881, 54.61892227972708, 50.426822477771395, 49.93411787094609, 53.37403258969707, 53.54440466050179, 52.39001581745764, 49.93603590996035, 58.52222188826531, 66.8641108851279, 65.77730448015275, 65.85057827734178, 66.20388184824299, 67.62659611240511, 66.90699023585167, 69.65062541346397, 65.9239972022272, 66.90527223771619, 62.683099623649355, 60.456770158583126, 59.18142326416508, 57.82662876190678, 60.21034725250737, 63.931554748166, 64.87922291601858, 66.64497590834095, 65.50867311416134, 65.09959736177998, 62.57274766122142, 67.50022519019343, 63.14020479879072, 56.919976818946104, 60.360358299747595, 57.95086199237455, 63.991488564398985, 64.69333394881218, 67.04223355939313, 60.14052514106997, 47.966080404097035, 50.37549434169647, 58.77197488661736, 53.663060280584524, 45.659079551696784, 48.31799545595723, 47.24480752022036, 50.44082533928656, 43.04079155768118, 45.479121208190925, 44.906666971022084, 43.82172369187878, 42.64367511195522, 39.24816554592502, 42.31948729484312, 54.56941804578228, 63.56877865329866, 59.17531221143661, 53.49581433880714, 48.73207615267847, 49.38240512724846, 63.07571711078767, 63.33165568690147, 54.47160982316541, 62.96907178817257, 61.56870718925231, 60.147330453318936, 57.96109153378395, 61.982360347624756, 59.58614126328499, 57.504680618163086, 62.79727197462513, 61.40075129847373, 62.28709713105233, 61.08906015273064, 57.1047322211727, 60.55064424391716, 67.43094044346964, 61.08716957030758, 63.43471596317907, 64.55503509890649, 57.671836345426506, 49.723451291361165, 49.58295983652915, 47.35921913577665, 48.06968588982859, 48.8802436859377, 49.282235637787856, 50.44961144847255, 51.53709250111734, 52.60033330609722, 51.26120475030715, 52.660941769999845, 54.3485297695283, 54.669583612872714, 56.31411575501966, 60.4206294398154, 64.55580388346027, 67.99451443456834, 66.2277533931117, 67.07303985472649, 62.604691443904755, 61.26912440023115, 60.15652448900285, 61.01289164635443, 65.09319213128859, 73.36862441032164, 78.48083772966939, 79.04387043368432, 77.19594770862211, 76.33889413649037, 82.0261190783593, 83.17675421314856, 88.05867733493929, 68.4600527055802, 0.4675102426159767, 0.4103005431111782, 0.2827906933042311, 10.896972898514042, 84.97705151957851, 73.51600354717624, 76.49980545043945, 51.00808635834725, 27.308392293991584, 14.94346353315538, 5.8026176402645735, 1.2005507273058738, 0.05003777204922611, 0.09173996355985442, 0.012497597377777342, 0.13300008020333706, 0.26889220360786686, 0.13199268990466673, 0.04941429905292969, 0.31514249441604464, 0.1692516825372173, 0.18851644960382294, 0.13156590232205007, 0.17992466628070802, 0.3286412394335193, 0.2903729719260047, 4.286088126320993, 66.9560355524863, 67.82261263939643, 48.64630176175026, 40.973133733195645, 62.46087774153679, 83.51122256248229, 91.29161250206732, 101.40810335836103, 12.318201564973402, 0.5259162956668485, 0.7693075160345724, 0.18804027999360717, 0.3694862896396268, 0.6333399636130179, 49.01450641693608, 67.52873297660582, 90.85269143504482, 83.18554032233455, 87.291045957996, 82.0885161430605, 88.63449696571597, 80.38370501610541, 85.27286883323424, 81.86938116627356, 89.43916336182626, 79.73190907509097, 84.1608533551616, 80.48349795802947, 76.79710542002033, 80.6803068037956, 78.0785829790177, 71.4855807827365, 64.27759801187824, 56.97514103304956, 61.618023149428836, 59.25538347613428, 61.52474918673116, 57.844220592129616, 51.97886513125513, 53.251980197045114, 58.124858333218484, 54.00550673084875, 56.06708095919702, 55.848628474820046, 60.29959294103808, 70.42221053954094, 69.9071954911755, 68.51189074977752, 68.05697425719231, 68.64196438943186, 70.89410305023193, 71.6498496455531, 70.66233019674979, 71.42067340112501, 66.94833201746788, 62.251034859688055, 63.201429074810406, 61.400845435357866, 66.97572585075133, 66.61919809156849, 66.60879596587151, 70.25539213611235, 67.38515853881836, 69.54430564757317, 66.69798281884962, 66.19229516675396, 60.428764435552786, 59.62925595621909, 62.675717722985056, 61.47546852788618, 66.13818999259703, 67.91941673524919, 71.11225743447581, 64.02522879262125, 49.61209127979894, 49.79289685526202, 57.2136878198193, 56.792107551328606, 46.20144528727378, 47.20439534033499, 47.57906798393496, 50.713716399285104, 44.66487246174967, 45.76430889867967, 42.591746853243926, 43.25824776003438, 43.46674526891401, 38.57352964339718, 42.26918289738317, 58.503418045659224, 65.73129115566131, 61.692069653541814, 54.74633263003442, 50.08146562883931, 51.41656198809224, 63.24438687293761, 62.48197224832351, 56.86758572055448, 67.39585876464844, 64.45136685525218, 62.11902356916859, 61.401751502867675, 65.47384638940134, 63.37856723416237, 60.21597193133447, 65.20745469677833, 66.67808855733564, 65.01907502451252, 64.70312810713246, 60.587742021006925, 64.75308733601724, 67.12992206696542, 67.02495944115424, 66.34891540773454, 66.43035950199251, 61.58338469843711, 53.486114317371005, 54.00476148051601, 50.847371162906775, 51.11293131305326, 54.86141497089017, 54.13947136171403, 53.89670410463887, 55.61228998245732, 55.316386376657796, 55.63447490815194, 55.218138848581624, 57.55462807993735, 58.51958213313934, 60.696007282503196, 64.07105384334442, 67.60216759097192, 71.37064749194731, 67.5728831752654, 69.86844247387302, 66.84756632774108, 64.88596939271497, 62.88657649870842, 66.3956465259675, 70.2539094801872, 77.85254463072746, 83.96074971845074, 83.33218989833709, 82.57785535627796, 78.18076856674688, 85.90464499688919, 85.54154334529754, 89.86808238490936, 69.09140525325653, 0.8530844399525274, 0.7574483523926427, 0.3122031989116823, 13.715217440359055, 92.35391586057602, 80.14609567580685, 87.64670295100059, 64.83528844771847, 43.44147736026395, 37.364980713013686, 6.948740578466847, 2.382848705014875, 0.27849526895630744, 0.3875834008138026, 0.2581983822728357, 0.4340854894009329, 0.3286230371844384, 0.3883082732077568, 0.27779322598249684], [0.016658041821492296, 0.02625535001918193, 0.1341997585710018, 0.11210016741026795, 0.07751808516801366, 0.023285998970330245, 0.12847569515748372, 1.7444041443447915, 39.947496691057765, 34.79224712617936, 12.19208755800801, 29.30863634232552, 56.663269458278535, 55.40341984841132, 74.64781914987873, 77.3867396385439, 14.05500844601662, 0.26819916982804576, 0.315862954143555, 0.15923667639013261, 0.2030599087236389, 0.6945933509738215, 26.269419193267826, 44.453331193616314, 59.65295099443006, 62.29380438404699, 68.05964931364983, 67.85008492008333, 68.43317662515949, 66.73896374241, 76.17467234211584, 75.16191636362385, 76.75788956303751, 76.1281922555739, 77.11488800664102, 73.3683184654482, 75.07345122675743, 72.62128737664992, 73.06715103887743, 65.69935129534814, 58.41285444075062, 54.25075292587281, 55.626594866475756, 55.115855201598144, 56.51247393700385, 49.063881212665194, 45.79537014807425, 48.70575312645205, 50.2588273632911, 51.21000997481808, 50.24835071256084, 49.73780324382167, 55.75244019108435, 64.20113532773911, 62.82189661456693, 67.7477345928069, 63.996728850949204, 60.81232516996322, 65.50860251149824, 64.1871520780748, 58.73083706825011, 57.204615377610736, 55.534207359437026, 53.743998389090265, 51.87922123939761, 54.15660427462671, 49.34336185455323, 54.267681875536525, 56.49185011463781, 61.20770008333268, 64.00115720687374, 63.687983405205514, 55.882376547782656, 57.97349014589864, 65.34320400607201, 58.18028534612348, 48.28884832320675, 59.531690920552904, 59.7445854063957, 66.636440830846, 57.33508125428231, 49.30774281101842, 48.88251866063764, 49.20445111490066, 49.54651709525816, 48.87056327635243, 46.890366461969194, 52.60318879158267, 53.774820373904326, 50.214257471023075, 41.78769626925069, 46.80984412470172, 47.40524814974877, 48.81388502736246, 50.257615350907855, 41.4291641789098, 43.162891018775206, 44.39900636672974, 56.09841285213348, 60.695065913661836, 50.07776291139665, 44.075069581308675, 53.09679162117743, 63.254310469473566, 53.74277068722633, 55.849569843661406, 63.20877175177298, 59.485960006713874, 57.94456266587781, 59.046889889624815, 59.17667327388641, 60.544274314757324, 57.37823124854796, 57.88054566229544, 58.1097807422761, 60.91475394464309, 55.79324068561677, 55.597251615216656, 62.09757212669619, 62.69039130979969, 56.1825280804788, 59.40153883349512, 61.03883812504431, 59.91260013272686, 50.2124257241526, 47.701473389902425, 46.37303329283192, 47.10641845580071, 45.31419730955555, 43.51297432376493, 44.555807036738244, 48.27781077354185, 50.43857782117782, 49.8605263617731, 49.715641852348085, 52.67952595987628, 52.985404153024, 53.10866855805921, 56.80350203667918, 62.065459682095444, 63.17460006283176, 61.498614434273016, 62.993343414798865, 58.53612669052617, 60.32969320974043, 56.70294815494169, 59.54390910363967, 62.40041440533054, 69.9068267883793, 72.80424241096743, 73.51837265876033, 70.63379103137602, 79.40572477156117, 75.68104205592986, 83.59636152944258, 74.56184079570156, 95.3131401923395, 15.593161006127636, 0.7150660395141571, 0.05533016406961026, 7.293385026916382, 78.74061630618188, 63.93729709809827, 61.27206225549022, 42.825104344275694, 15.056918090389622, 3.7221317041304807, 8.825162264608569, 0.4741268827309532, 0.07709202536892507, 0.06304581093812181, 0.03666866059985854, 0.14520632764024122, 0.10073617235907625, 0.017857637834705172, 0.08508177849674418, 0.02876226166864076, 0.06845124306217318, 0.12907322075578476, 0.05841644886400431, 0.05336478082162719, 0.0815475391103856, 0.18127770012905522, 3.1672325249641173, 58.378686674179576, 51.11506900479717, 19.959468956916563, 30.90076561897032, 64.17010545730591, 68.16087784305697, 83.46219293532833, 89.325116526696, 17.349633670622303, 0.24392536751204924, 0.5794402235938657, 0.15548880572520918, 0.41743640697771506, 0.9565777091249343, 42.92908637754379, 60.88508513665969, 76.0310822148477, 71.5924261462304, 77.72020386111352, 73.21657765296199, 77.2800511698569, 73.58005585209017, 81.19806751128166, 79.6991886631135, 83.39759149859029, 80.8937543438327, 81.62935564594885, 77.6710722523351, 77.37071283401983, 78.04667057529574, 75.0240215178459, 67.95860905801096, 61.20932394458402, 55.75380517590431, 56.63929985415552, 59.002500426384714, 60.41465959241314, 51.917829129003714, 49.24566345830118, 52.89182816782306, 51.89973915776899, 55.16587718840569, 54.54537783899615, 51.422582826306744, 58.02292769955051, 67.13961032129103, 64.65844838849961, 69.51819835170623, 66.45402708361226, 64.96223595834547, 66.49925201169907, 64.8970579331921, 61.3124587458949, 59.712967180436664, 59.135174597463305, 56.43031204900434, 55.08938312530518, 57.3732812173905, 54.53288508999733, 56.62333972992436, 58.82400512695313, 63.00087044315954, 65.27189923870948, 64.51420714778286, 60.6725711207236, 59.89783633139826, 68.2731988353114, 62.26371980482533, 49.32597398757935, 61.41392653988254, 61.31904832778439, 66.6499573184598, 58.84926911323302, 49.692393964336766, 50.00191603937457, 50.24710339884604, 49.90053453753072, 50.29078683545513, 49.06843900680543, 53.437119991548606, 55.81963039213612, 51.17100984819474, 42.566733898655066, 48.40843746739049, 51.74768455566899, 48.59139250170801, 48.37238696313674, 43.786802830234656, 44.3472977607481, 44.86980453614266, 56.78468642696258, 64.98924932172223, 53.66728859563028, 47.876152223156346, 57.09360837936402, 64.57707097453456, 54.88661619924731, 59.751724120109316, 64.16999955331126, 62.48915018573884, 58.712539211396255, 60.3233350476911, 60.33143866446711, 59.78628412369759, 60.957582304554606, 58.415309844478486, 60.21761540443667, 60.988961265933135, 58.71373161192864, 59.89154092727169, 60.3106265683328, 61.34708542977611, 58.87842409072384, 62.6514264845079, 65.61958205315375, 63.34613707757766, 50.328645552358324, 50.06301087717856, 49.210197387203095, 46.731761501681426, 48.553055255643784, 47.53392934799195, 48.1790651044538, 49.858749528085035, 52.482266041540335, 50.91268254864601, 53.16792772662256, 53.77700121172013, 53.98055261181247, 56.05984810859927, 61.27241526880572, 64.80574515558058, 66.43967120878159, 63.14689243993452, 67.52529698033487, 59.7676371758984, 63.24818764963458, 59.949313517539736, 64.16465728513657, 66.58173945642287, 78.01521316651376, 76.1648585719447, 80.35205933355516, 75.49174062667355, 84.43010053327008, 79.38500681231099, 88.61677569727745, 76.08773692961663, 100.59064219074865, 21.243605882890765, 0.7088519019945976, 0.018825651214067495, 7.408385488294787, 88.87251423251244, 68.92339444929554, 77.9627004746468, 50.79544290419548, 31.97554211462698, 20.292897878154633, 6.342028360213003, 0.7814878237343604, 0.04969578273894806, 0.06599771624971783, 0.1111935712997952, 0.17599543196059045, 0.03021015060855256, 0.09800771191235512, 0.09295468023347278, 0.17604427772664255, 0.25131742650222394, 0.19530959637655368, 0.20478968929138877, 0.3928644125980716, 0.2727241754051178, 0.42375215839955116, 5.336158102558506, 72.52393414897304, 69.88442220995503, 24.789463819996005, 41.227526895461544, 80.94556100906865, 78.88335920149281, 91.74945508280109, 98.49299784629576, 22.110247688908732, 0.39174341146023045, 1.0160086039573917, 0.2835524911361356, 0.9462650624975082, 1.5782666398632912, 66.86958651388845, 73.39007193042387, 86.36571176590459, 77.92451227864912, 86.49693858238959, 82.81837509524438, 82.27857066738991, 76.4809545393913, 86.77100243106966, 81.97211588582685, 85.57752716925837, 82.90454956793016, 84.34827204673522, 79.82243737866803, 79.61425365940218, 78.15999569431429, 80.71333316064651, 69.45758204306327, 63.241601990115264, 59.760318033156864, 62.18994394425423, 61.48855355478103, 62.17975362654656, 55.793503484418316, 52.43663318695561, 55.17733050930885, 56.103892403264204, 58.16069702948294, 58.614754523000414, 53.43770442470428, 62.598517633253536, 68.91616944343814, 68.60456066746866, 70.51009516562186, 67.66792220454063, 67.876709968813, 68.42806969919513, 69.94544644509593, 64.34605513849567, 62.98750300561229, 62.704417705535896, 61.329321015265684, 57.74008166405463, 63.262367017807506, 53.831212289871715, 61.560407453967684, 62.031711609132834, 68.06841973335513, 68.24593836261381, 70.01466058915662, 63.34116351219916, 67.22032485469695, 66.24449406900715, 55.743406972577496, 52.07636348662838, 62.08576971484769, 65.37555179288312, 70.82337487128474, 63.97503029915595, 48.955823836788056, 50.80217369141118, 48.893124749583585, 53.807540785881784, 49.98530480169481, 50.2450559216161, 55.39665375986407, 57.17449941942769, 51.64281998911212, 42.50960849946545, 48.95275262094314, 53.3178367922383, 47.24290517068679, 50.46792107243692, 42.31102282001127, 43.81871915632679, 44.912064152379195, 61.89858244311426, 64.49910994498961, 55.28521922326858, 47.26756903433031, 57.79765029107371, 68.27774878471129, 57.30132925894953, 61.05182117031467, 68.71573632763278, 63.89653582726756, 62.04727165160641, 63.50999016915599, 64.00573069049467, 65.27049895255797, 63.67440415966896, 61.288049836312574, 63.079278622904134, 63.022812181903475, 60.448054652060236, 61.87497761941726, 60.76102056810933, 65.34300004282306, 64.81176991616526, 64.2583627085532, 68.82390745224492, 64.74909044081166, 53.89782590250815, 54.59649808945195, 53.25494158652521, 51.165514607583326, 49.58256367714175, 49.22596531529581, 53.06306708243586, 53.62735102253576, 54.636561178391986, 55.25897464444561, 55.40486328063473, 57.5469990699522, 58.42282902809882, 59.74504432370586, 64.75882968594952, 68.55965737373599, 70.9996618763093, 66.67512324548537, 71.02372953968664, 63.86733770370484, 66.14703101496544, 64.40241567550167, 67.47027397155762, 70.04086202190769, 79.61376728550081, 80.05628124360116, 80.57191602645382, 79.50462341308594, 89.40269316396406, 81.85658639477145, 93.72818885311004, 80.67548228848366, 100.92178437017627, 19.3480557780112, 1.1878948322226925, 0.11617813004000534, 8.640326453793435, 98.95396263368669, 74.79325279112786, 88.94131260533487, 63.56080839710852, 48.002181899163034, 44.735424134039114, 11.957028738913998, 2.078024648850964, 0.2663496190742139, 0.3334388497375673, 0.23815310950721466, 0.3150960082007993, 0.18051993191963245, 0.3918409804182668, 0.2062975035439576], [0.01544392939972421, 0.0352316290410536, 0.06185167138614963, 0.0883691537103826, 0.07412810779867635, 0.260411610286082, 0.09377649339336543, 3.6575300222443, 50.96371258458784, 29.88913339953269, 23.364554989722468, 42.70907278983824, 47.655067828393754, 56.62230422419887, 71.59339889403313, 75.76276856084024, 37.1449435910871, 0.23273204152862872, 0.3175842311353453, 0.18369323664134551, 0.8307937941243573, 6.586902420366965, 48.65834736054944, 53.80973731317828, 66.0920472298899, 62.15259905784362, 67.31358312791394, 65.77936764686339, 68.28326363717356, 69.96348934788858, 73.83377044431626, 74.5879324020878, 77.32559773229784, 75.55170582186791, 76.56767814390122, 73.67800528003325, 73.23904498930901, 71.02198800733014, 73.82264660250756, 64.2584764572882, 57.313872998760594, 56.422443774438676, 53.14446018588159, 54.438995315182595, 53.4116598867601, 48.28248231641708, 44.93633970137566, 49.1298907802951, 50.200603700453236, 52.95615896101921, 49.80805681597803, 46.23356557661488, 54.615097968809074, 61.63850968883884, 62.224664765019575, 62.76741097050329, 62.424340863381666, 62.63095955694876, 60.95413454117314, 57.11104331477996, 53.26709308931905, 54.20247639379194, 53.44575705066804, 52.037057415131606, 52.840613780483125, 53.74455928802491, 50.21664227208784, 51.5899464391893, 54.39381353316769, 54.48064696404242, 57.94839482153616, 58.22946010097381, 61.26141694284255, 59.932376723135675, 47.254472240324944, 52.862379012569306, 54.71223938849665, 61.52532577514649, 63.88535314990629, 51.03562531932708, 43.710500963272594, 50.619650117812625, 53.49366095758254, 51.980900841374556, 53.02660080694383, 54.44898559201149, 53.73553783662858, 49.96670884470786, 50.5329147461922, 54.03348891965805, 49.61013793945313, 52.30885413385207, 51.358271644961455, 48.813590849599535, 46.90746407355032, 47.44274208622594, 43.204201421430035, 41.604815759966456, 47.81365317683066, 54.32527403677664, 48.151345714446045, 53.31859380968156, 57.50490811563308, 59.46209238421533, 50.93620108019922, 61.631931874059866, 60.51508403593495, 59.2514414941111, 53.88396032394902, 54.69444359502485, 60.77662375665481, 55.79419382156865, 56.012826734973544, 57.166964546326675, 56.81088001497331, 56.576373269481046, 62.43696697296635, 63.105017215974875, 60.510436027280754, 51.593158860360425, 55.899991912226525, 58.83998878540532, 60.99431530121834, 60.00463070407991, 52.06321177944061, 47.3881858394992, 47.16399492756013, 45.58647647980721, 46.21762506423458, 43.39457365774339, 44.79360465080508, 42.72493877718526, 50.301404691511586, 47.84101563115274, 51.455311083024554, 50.70798581646335, 55.225661954572125, 52.08225096425703, 54.268646778598914, 60.93633874770134, 61.53122501988565, 61.790603514640566, 58.88608447967037, 60.150040811108006, 56.872657345187285, 56.6667603677319, 57.5516039325345, 62.590970993042, 69.83724394152242, 69.7519245455342, 74.83996821988013, 72.99456365646856, 77.80283251116353, 72.72965461977067, 77.27060610248198, 75.8385487525694, 89.61632113302909, 61.93788066987069, 1.109461279646043, 0.11736019604629087, 8.18462891924766, 75.92899076400265, 61.57721088778589, 60.421511973104174, 43.316749911154474, 19.764988037847704, 7.750932449294676, 13.200516181607401, 0.6434692394348883, 0.12082593951133952, 0.056211218808687506, 0.025911093088648012, 0.06834523181521124, 0.028843819389059663, 0.08099169635604467, 0.10126845024886633, 0.05728954118826697, 0.051388327603138266, 0.11011347925711064, 0.005189456137633252, 0.14189926396694877, 0.2958682431809364, 0.18100426802712102, 7.0842628805868095, 67.69730075713127, 43.15930989480788, 28.521461755998676, 39.75675967431838, 57.083794609192886, 68.42435129227178, 83.4197215111025, 84.60372817131781, 41.454577215256236, 0.21446567088846238, 0.5558801394316458, 0.06452726410521616, 0.7174242420061943, 6.042384284157907, 63.731180467913234, 64.01146127331641, 79.10324727335285, 71.96818136399793, 75.10228064752395, 74.19336549697384, 74.64396738236951, 76.81130440004411, 79.75491769852178, 79.2745920919603, 81.17822816295009, 79.17658775083481, 79.49580592493858, 75.28198011459844, 74.97595679375434, 72.46479265151486, 76.59928460274973, 67.35258717690745, 61.0116639444905, 58.64103440315493, 56.43956884261101, 57.173185425419966, 57.95469022566273, 50.67100963284893, 47.94429948253017, 51.43767610672982, 53.46924420325987, 55.372095800215206, 50.37529822318785, 50.07204801805558, 57.95662395415768, 64.03550540247272, 63.96012921487132, 66.25165631694179, 64.51967885417324, 65.77197397908857, 63.09071625432661, 56.825467309644154, 56.061746535762666, 56.24385041575278, 55.79538229973086, 55.52998296676144, 55.940498228996034, 56.29138169750091, 54.40138762997043, 54.24288465130714, 56.45426204127651, 56.08503756984588, 59.82638251396918, 61.683958192025464, 63.72626181571715, 64.57510586707824, 49.00861893930743, 58.215633746116396, 58.37005353743031, 65.96023205787905, 64.72513652616932, 49.84365232529179, 46.744924975979714, 51.032926728648526, 54.10010253229449, 54.613317212750836, 56.99767504968951, 56.97485470002698, 57.28134086055141, 52.19886695185016, 52.263284037190104, 53.99757177599015, 50.54813354246078, 53.93803804151474, 54.677836279715265, 49.78075319720853, 50.54095168267527, 47.1971389555162, 44.243099997120524, 41.85470211890436, 49.90038548746417, 54.634866714477546, 50.984148133185606, 55.03088881892543, 60.82135054372973, 62.48515721290343, 53.556462026411495, 64.12200150951263, 59.23853689624418, 60.36621047604469, 55.50755485411614, 57.64489358471286, 60.34859903397099, 58.53622474978047, 56.80546714413551, 60.63861908451204, 57.95694558851181, 60.479739558312204, 64.34944014395437, 61.613626172465665, 61.074284584291526, 56.14859173374792, 59.97338902565741, 61.67986715993574, 63.832797311967425, 62.70768111751926, 52.83977831563642, 49.86094997775171, 50.25666613732615, 48.533047245394805, 48.45034799268169, 46.10673965946321, 47.42484038875949, 46.25828827581098, 52.16743699965939, 49.49140779433712, 53.84800003420923, 52.26253486448719, 58.02577534029561, 53.91253086828417, 58.374250473514685, 62.36863536219444, 66.28599274543025, 65.57522004650485, 63.97129228038173, 62.850235739061915, 60.3915842886894, 60.44911369200676, 62.31881341626568, 65.8567677774737, 72.80858839711836, 74.71965343721452, 79.1612591282014, 77.26862922791513, 83.24511328051167, 78.76364061909338, 83.55000695874615, 79.57182145887806, 93.08075458772721, 71.9478242628036, 1.3792270686357253, 0.2302718420903529, 9.602799607861428, 85.46906578925349, 70.9279844837804, 73.84760856628418, 52.83627563907255, 34.05928557918918, 29.58086648295003, 5.079888086165152, 1.2842174571368004, 0.032925895910950444, 0.09732469856258362, 0.025950266994656097, 0.06483313236986438, 0.05520876594668916, 0.07258407290904753, 0.023281176446846897, 0.1861119294358838, 0.13661094370388216, 0.16580704479448258, 0.1419013477261028, 0.28364282822416675, 0.37040277594520205, 0.3503465940875392, 10.840687867133848, 87.22792717718309, 58.00245292725102, 42.717564721261304, 56.512317042196955, 69.10677309959166, 80.2837787135955, 88.30930894420993, 93.95866732443534, 50.596868991851814, 0.23938533128990283, 1.0565516929472647, 0.3353235486053652, 1.436675940790484, 10.217395790161627, 84.0060374044603, 72.76195926050987, 89.74650459904825, 77.39692211151123, 84.80267078645768, 77.77565048586938, 81.51093144570628, 80.6885830048592, 84.21045564836072, 82.01028839234384, 85.61784128988944, 80.40917688800444, 82.08271887994583, 80.49694384298017, 79.27704749568817, 75.6674078972109, 78.83262726568407, 68.39250164647257, 65.31670055081769, 62.32767012811477, 59.16003457961544, 59.2820163696043, 59.57753950549711, 53.22976781475929, 52.22062826156617, 53.54352212721302, 55.609018725733605, 58.06588549767771, 53.64435449723275, 52.31221560508975, 59.92158628279164, 67.40698260645713, 67.81817251636137, 68.14314088513775, 68.46222569865566, 66.99109369708647, 65.72789438309209, 61.01727685620708, 58.94960334224086, 61.1330730684342, 60.20922545463809, 56.89112386395855, 60.25730586821034, 58.92705363612021, 59.115119518772254, 54.545444519289084, 58.49124300864435, 61.56131352147749, 65.17922539864817, 63.18905791928692, 65.06630428375738, 66.22874967513546, 56.38166289175711, 51.43704460513208, 56.064719692353286, 69.3166591275123, 68.81671382534888, 55.32641195481824, 46.434763554603826, 53.206213981874534, 55.70990600893575, 56.859129090462964, 57.55460062334615, 58.44876766204835, 57.97908344576436, 53.359802230711914, 53.47416285545596, 56.43831368415587, 51.1375637977354, 56.320022844499164, 57.734382460194254, 51.921551458297245, 49.26556556455551, 48.50038174659976, 44.83774700472432, 42.28633934451688, 50.6348846035619, 57.86411093127344, 52.58145101608769, 57.02363721786007, 63.00469867644772, 67.42828107649281, 55.0791222049344, 66.94902235461821, 65.58719112027076, 65.03181880520236, 58.06014707011562, 59.79102234686575, 64.62417471793391, 61.05821071132537, 60.23716057500532, 62.572120081993845, 62.01644182205201, 63.855099908767215, 66.11155709912701, 63.66340583370578, 64.93139043931039, 62.19133246329523, 61.558093255566014, 66.06561829966884, 64.74942776464647, 65.00594685154577, 55.13776163901053, 51.42781526811662, 52.538767783872544, 52.36944298590384, 50.818259331487845, 47.78353329627745, 49.784228417181204, 48.66690597226543, 56.75876740486392, 52.85294963467506, 59.63554743797549, 56.02446048490463, 61.82817197615101, 58.616852991042606, 61.872039764158195, 67.32284776626095, 69.86289624244937, 69.40957223215412, 68.92937214143815, 67.73208433581938, 64.63771081739857, 63.33181650407853, 65.36495747104769, 69.86848954231509, 75.6092313028151, 76.23158593331614, 84.56583807545324, 79.01206785632719, 86.87328215568297, 79.06366271357383, 86.80950441668111, 82.860226784983, 98.24031091505482, 72.02766803003126, 1.6815851797019283, 0.21842967027858382, 11.053154814627863, 95.2013683319092, 76.53479299237652, 86.5140244268602, 64.9154773835213, 45.716220640367084, 51.73112430880147, 18.264842264113888, 1.9724107870171148, 0.2991010116473321, 0.3132941387593746, 0.20672085905267348, 0.2180909215202255, 0.09158716732335669, 0.2523158842156972, 0.1467431459816233], [0.061921837379134474, 0.07803615978768758, 0.023996279304546696, 0.019031627359048977, 0.08300064702428157, 0.1694598439480028, 0.3907360364833186, 11.574691783997322, 49.452050732028106, 30.49400994854589, 18.62787135185734, 28.18666981112573, 47.15353396631057, 61.13503425352035, 74.2845292245188, 72.51817610956007, 44.198596785145426, 0.2411005255435744, 0.37752855809465535, 0.6614902014693906, 0.6446496277086197, 20.89521311944531, 65.03722383129981, 60.84152721589612, 66.56596368358981, 61.82268850265011, 67.69875987883538, 67.43920095505254, 69.55368795702535, 70.01013417397776, 71.0532336081228, 73.53599194557437, 75.46524109378939, 71.17582336548837, 74.34913066125686, 71.9847337661251, 75.02717510346444, 69.7884496565788, 70.65271254508727, 60.910176538651996, 55.24980806535291, 54.34143420188658, 54.00060376813335, 52.73880081792032, 52.71694929369035, 47.3820943986216, 45.325693776530606, 46.932371124144524, 50.19132729499571, 52.55039368906329, 50.088443525375865, 49.46518674973519, 55.17915441143898, 57.0308308447561, 60.76554306091801, 63.162228907308275, 60.20418913133683, 56.80597312988774, 54.25057249684488, 54.09376398209603, 56.88204357700964, 55.48226341124504, 55.235361976008264, 54.61576084936819, 50.88710869512251, 52.92273252241073, 51.377330441628736, 51.02515651333717, 50.395745538896136, 53.075018544350904, 55.302371748032115, 55.72405007577712, 59.6601563884366, 62.26497888565064, 51.601466440385394, 42.82506904294414, 51.046227485902854, 59.166286837670114, 48.62926298572172, 43.98523161488195, 52.31647529909688, 48.06031534748693, 53.79262401211647, 55.474881510580744, 58.91011684171615, 55.523314937468506, 62.117356561845355, 51.419888157998365, 44.30891344624181, 42.49975158322243, 51.77183458881994, 62.764967333885934, 53.96271759463895, 55.787208080291755, 57.203085653243534, 53.04653036978937, 50.165537711112734, 40.61899469744775, 47.43670555853075, 47.62297891801404, 48.437992526638894, 53.0925319271703, 60.02931025720412, 52.32074676021453, 58.270240983655384, 58.4398481922765, 54.29170639284196, 57.43060273508872, 53.34899610088718, 55.675569580447295, 56.74236013043312, 56.3733043209199, 55.327070913007184, 57.88003183180287, 60.60613401474492, 59.4319175904797, 62.268524708286414, 57.40180469328358, 56.14773665705035, 57.78211770519134, 60.42376733595326, 59.38939517544162, 58.20353715650497, 61.03912053569671, 52.533629478946814, 46.475218880561094, 46.21492255118586, 43.371553267202074, 44.84298729127453, 45.31592315243137, 43.77570644501717, 45.59758463213521, 49.15901830119472, 49.628318125201815, 49.76953914088588, 49.189173483079486, 51.474726815377515, 52.674705366934504, 55.079381081365774, 60.911780788052475, 62.13346181377288, 61.78579861117948, 60.63964674549719, 56.57309809038716, 57.37195153390208, 53.99810914070376, 57.30886805442072, 59.60746718991188, 64.84596513932752, 73.94786434788858, 72.33056129947786, 72.25969191520446, 75.35690522963002, 73.39475524040961, 72.76078254945817, 78.79625120470601, 79.13275918652936, 86.41931487667946, 8.353346240135933, 1.3278350714714298, 12.074187974775992, 74.68421090033748, 63.76293989919848, 59.55517807314473, 46.11006975173951, 29.938461126819735, 15.812415615204843, 13.284051879759758, 0.6446378605981028, 0.015435648946872643, 0.07289732626128582, 0.09304310210169324, 0.05642522547033526, 0.03841879995419614, 0.06835594938527192, 0.06656082151758094, 0.03818551468993387, 0.050043303204039415, 0.1445117157192961, 0.07986340972204363, 0.07714139207476571, 0.21339345422963943, 0.3467882382533243, 15.50640013910109, 67.53479696089222, 44.45346455420218, 27.348106291986284, 31.380655842442668, 54.821955926956676, 72.59959666959702, 85.12035139145391, 81.46552608859155, 51.450608161187944, 0.22053860308181858, 0.6092695423191594, 0.4113014523060091, 1.3120254681956385, 23.618895199991044, 79.11110770317816, 70.80711272455031, 78.61291962285196, 72.50621288053452, 78.79929496395972, 74.37015456538047, 78.58416864948889, 76.11733513493692, 78.88204912985526, 76.86879065728958, 79.98417239035331, 77.13726905084427, 78.02042991884294, 75.16386970396965, 77.43056820284936, 72.66717910766602, 72.67811467570644, 64.95306937925278, 59.70667962105044, 57.429877096606845, 56.577549980532744, 54.660613152288626, 56.7272590052697, 49.02650494729319, 47.81100557696435, 50.94509309337985, 53.26028777707008, 54.18987381842829, 53.55696801216372, 51.644769407087765, 55.187705178414625, 60.15111554053522, 62.69266628449964, 64.55916927706811, 61.43609969846664, 60.36055834062638, 57.35019414655624, 56.67902169689056, 60.29397610695132, 56.36396907990979, 57.68566270028391, 57.58101386408652, 53.96077602140365, 54.5985455666819, 55.10582570106753, 54.571951896913596, 51.74196573995775, 55.49018659899312, 55.01483455781014, 58.895886482730994, 62.33622873983076, 64.84399218713084, 53.97522603311847, 50.68986446626725, 56.600993987052675, 58.5470740256771, 46.31617853718419, 47.84811904353481, 54.59015169451314, 49.07349494195754, 57.97965611180952, 56.535223684003284, 61.133477072561945, 57.84924122595019, 64.96177311866515, 53.45481772576609, 43.73539624675628, 42.56549835205079, 54.986424830652055, 66.43103414966215, 56.79639470192694, 59.78194205991684, 59.77929053768035, 56.58923472127607, 50.66960542432724, 41.17900325405983, 45.84811425978138, 47.250738143920906, 49.64172870882096, 53.86232060770835, 62.99692061639602, 56.37189619002804, 62.35063560547368, 60.2202747714135, 56.54262127414827, 59.81031648574337, 55.299751604757006, 57.676955038501376, 58.63030672073365, 59.81741205338509, 58.80981791403986, 59.6614743048145, 61.5290363373295, 61.13626980012464, 58.52135504445722, 60.92331255635908, 57.25685742593581, 63.76994132995606, 63.515403039993785, 64.10119725811866, 61.939112294104795, 63.013845643689564, 54.661825164671875, 48.07685206013341, 49.44164860633112, 46.085405888095984, 47.85808186377249, 46.579279361232636, 46.03483869183449, 47.892269242194395, 51.60711073106336, 51.6460677116148, 52.86916079059724, 51.97691963564966, 54.53355581529679, 53.269536725936405, 58.746091165850245, 63.47728152428905, 64.96601712319159, 66.4158388876146, 64.00381657385057, 62.01553183217203, 60.79291335998043, 58.21423738233505, 61.099317150731245, 62.70857149554838, 69.9539815225909, 76.79445389778384, 79.13088429358699, 76.85119490469657, 78.84441006568171, 77.63235845873433, 76.83261855956047, 83.33158585333055, 80.70733977902321, 93.80680884084394, 10.071633650410561, 1.4707761690501244, 13.40289479301822, 83.75335047321936, 72.58578992659046, 73.32245026865314, 54.23674614198747, 37.435940311801055, 35.65074020816434, 3.8499325754181033, 1.3517878829471528, 0.1535478300384937, 0.10833031002191768, 0.03541018881444489, 0.023938751847092665, 0.0471420822695138, 0.11208164340425884, 0.035268857083734007, 0.22867490116867328, 0.2005527480956047, 0.2203166980536715, 0.1963115627727201, 0.22392555440385498, 0.356633908325626, 0.46824675954637995, 22.36753163799163, 88.07324501775926, 60.15488101590065, 36.83019691897977, 42.447980219318026, 67.81253214805358, 82.98287145553097, 91.98007475945258, 90.40452141915598, 58.084720719245176, 0.38345602551294916, 0.7247754991535218, 1.0047097263797637, 1.3499384854109058, 29.800725137033773, 91.59085012251332, 77.53968854104319, 85.0554753888038, 78.90574809043639, 85.04661083221437, 82.76208908327165, 84.88442082558909, 79.0920606736214, 81.42861658527006, 77.94617160674065, 85.14816884071597, 77.8894619787893, 79.06370193727555, 75.80920942368047, 83.56699082159227, 74.2348720181373, 74.50379756189163, 65.75674733807965, 63.08076912356962, 60.6989255259114, 60.141607715237534, 57.02636718750001, 57.58292013599027, 52.835620603253766, 50.097504200473914, 53.53773663120886, 58.86944186302924, 58.20118765677176, 54.47185301011609, 56.184689306443744, 59.745091392147934, 61.738063366182395, 65.42877443375127, 66.8033847501201, 65.52888116528912, 63.8744842621588, 59.95360066813808, 58.778827267308394, 65.74072445592573, 58.11520145785425, 61.48138738447621, 61.31916599888956, 57.60784287606516, 58.317089772993526, 55.78672170639039, 56.186776007375414, 56.02652365161527, 57.37957662151706, 61.26661800569104, 60.86205690137802, 67.98926630327779, 65.40263183655279, 61.39110226784984, 47.17401266098023, 54.663021487574426, 63.35980653762818, 50.695799012337964, 48.10080205240558, 56.03649823896347, 51.81129755512361, 59.532349878741854, 60.21827436262562, 63.840944074815326, 62.98926807218983, 66.23507253585323, 55.012379154082275, 43.80170391451928, 44.31089032080866, 56.027570924451275, 68.6140920269874, 58.637716077989154, 63.788784396263864, 61.12916638774257, 58.43774580186414, 49.69236650774556, 41.58248962894563, 47.063903885502974, 51.13583795485958, 48.2645139386577, 55.05290116033247, 64.83959913253784, 58.205380670485965, 64.21637373585855, 61.66352656579787, 59.47448707395985, 62.372565577107096, 58.36708038083969, 61.52120728646556, 62.5261499035743, 63.22698331648304, 61.661173143694484, 61.453954327491026, 66.47912240797474, 61.74942255020142, 64.88194504091817, 64.29067911640291, 64.74815691671064, 64.71771147943312, 65.79508850651403, 64.89526148765319, 63.81345218227756, 66.35625808469712, 59.317607956547896, 51.18083538547639, 52.11596373588809, 47.83419855179326, 51.92536007973456, 49.585407395516675, 49.385076261335804, 51.50235599087131, 55.53206574532294, 55.93541091488254, 56.566712471746634, 54.14215034054172, 57.62274788271997, 58.147262911642756, 60.818777468896684, 66.22448998112833, 69.4785745682255, 68.33903189628356, 66.52073875550302, 65.87248863712435, 66.16664286582701, 60.34899911572857, 65.6808965436874, 65.79792438014861, 73.81137371063232, 81.24672059089907, 81.40492546942927, 79.36646184613629, 83.74148922581827, 81.80841184431507, 78.03913962456488, 87.73734108094247, 84.81281403572329, 96.3593618331417, 9.946538479097429, 1.571187742294804, 14.389476795350353, 92.71883749192762, 79.19448160356092, 81.97050771405621, 67.42446853268531, 54.28061785236482, 55.237354540055804, 24.42005695835237, 1.870297272839854, 0.37111177499736514, 0.2500524008346181, 0.3628186280688932, 0.13716313987970352, 0.24697061297633957, 0.2621416819672431, 0.15689993968173382], [0.1791590686526991, 0.09206924347146865, 0.08360992441134107, 0.010541807465826072, 0.056908588646160024, 0.07909726817160845, 0.048573080885915026, 14.258963850236709, 38.58495158533896, 33.9645250381962, 15.937530398368837, 45.639789335189334, 52.09998792217624, 60.69549345201062, 73.93310839130034, 75.3954464389432, 20.99317627568399, 0.33910054593316974, 0.20281149705331172, 0.27299659627099193, 1.0670468523617715, 43.64763321415071, 70.40559537949102, 68.74887251084851, 71.6572315462174, 64.81769661749563, 68.73579532869401, 67.29794071566674, 70.14917435184603, 67.1780966174218, 71.31513810926869, 70.4571117893342, 71.88460350036621, 72.64662588796308, 74.65101195919898, 68.77465817236131, 72.27999410321637, 70.39203966817549, 67.668181080972, 57.98282930927893, 54.47126465459024, 52.95570004370905, 54.244806612691576, 52.45127539480887, 50.895828124015566, 44.70813620475031, 45.046828946759625, 47.230824270556056, 49.867716066298954, 53.59516405290174, 50.5527933182255, 50.06432094881612, 52.70571954788701, 55.961886913545676, 57.38361666279455, 59.60436851747575, 54.071359403671764, 55.72702715473791, 53.40217167331327, 54.836841321760616, 57.07245895939489, 57.76397282077421, 60.06749845320179, 58.43244667976134, 60.94554847286594, 54.300841592973285, 52.580658697312884, 49.28371829371299, 51.78690433502198, 50.839659783148, 52.61872529983521, 52.462458072170136, 60.283162132386245, 55.20091964352516, 53.851949860972745, 44.656388375066946, 44.08087468916371, 43.121851259662265, 38.93966328713202, 49.70707931826192, 50.141897586084184, 53.20835951835879, 50.09279343389696, 51.995715633515395, 53.106589701867875, 55.39090748756163, 59.368257522583015, 62.06851913082985, 46.63035254324637, 45.34433287958945, 60.29997733331496, 58.80627601377426, 52.537869561103086, 52.42241067271079, 52.251246283131266, 52.23767488233505, 54.110634096207164, 51.002708788841005, 38.14852514574605, 42.244632782474646, 38.15209058023269, 48.834948155187796, 57.09527146431708, 54.460991967108946, 60.67894497225362, 54.2490388501075, 55.750090691351126, 55.76401902783302, 54.061675071716316, 54.59319545376686, 57.50768907608525, 56.1805865072435, 55.020922076317575, 57.182603036203695, 57.88188711289437, 54.17425101803195, 53.73853060507006, 54.60595884630757, 57.68498805261428, 61.36019006852181, 58.76797799141177, 58.2340806530368, 60.14033294493153, 58.814818936009566, 53.38208129329067, 45.306172140182994, 48.59206322700747, 43.0405483707305, 41.63062495570029, 42.639992006363414, 44.5675584577745, 45.005216521601525, 47.560734825749556, 48.00811252286358, 49.8005650889489, 50.24372231575751, 53.453664548935436, 52.33753058218187, 54.858771293394035, 59.72045890746578, 59.16235270038728, 62.44599234673285, 58.813963859312004, 56.643885104886955, 56.35035061067151, 53.53243750910605, 54.31117703837734, 58.9291246475712, 60.463869648595015, 63.587021596970104, 68.69810135133805, 68.7207648061937, 69.50101052561115, 67.2263260810606, 69.98026140274541, 78.9041163844447, 75.85604252353792, 94.37314418054397, 20.615406920832974, 1.6241083606596918, 15.49549496942951, 76.82968462667158, 60.997802288301536, 60.419868500001975, 46.5228521439337, 35.81646034794469, 19.61643022875632, 7.718868053728535, 0.5574634286665148, 0.133317960726638, 0.11789979773663706, 0.06916864609886562, 0.04083840822380397, 0.03881127445868427, 0.11798753778660491, 0.05443798956431208, 0.14215470832442084, 0.042362953836639086, 0.0733311695136851, 0.04093630276920815, 0.05295934027902061, 0.1352837270185832, 0.02643800070208888, 20.112737532584898, 57.06839538389637, 49.7664051671182, 24.3119191738867, 43.69020269763085, 62.07637956065517, 72.31965711039882, 80.9568888141263, 84.67713925146288, 24.97889860983818, 0.5027832902006565, 0.48442068359544205, 0.40345674260489406, 1.736204061777361, 46.036160530582556, 85.57091405314785, 76.50821501208891, 82.30224609375, 72.73997045332386, 75.46236991882324, 74.19755458831787, 77.93647550767469, 72.03253961378529, 77.82745715110534, 74.23555451054727, 76.6407754344325, 76.78869585837089, 78.68117670859061, 72.52398906215545, 77.74357334260019, 73.08549204180318, 70.08196846131356, 60.41889575219924, 58.217206616555494, 54.94109007620043, 57.93858105136503, 55.276966556426025, 55.32037542712305, 47.68955330694876, 47.86824864725913, 50.750672971048665, 54.087688230699115, 55.142025255387836, 52.773168625370154, 52.8066421324207, 55.197260072154386, 58.435545352197465, 61.122294395200676, 61.27623173498339, 56.278210378462276, 54.711623576379594, 53.9265101955783, 56.89238294478386, 61.26724558491861, 60.30642178750808, 62.57324972460347, 63.09257938015846, 61.99544145214943, 57.90655489890807, 55.15604380638369, 53.008444155416186, 54.97609722998835, 52.17287340471822, 54.55786666562481, 54.0793728059338, 61.164197075751524, 60.417605292412546, 54.259374295511556, 53.71111715993574, 46.20815254026844, 44.74557522804507, 42.81172513961793, 48.56536365324452, 52.444183749537316, 54.251545244647616, 51.94173597520398, 55.63254117965699, 56.496784456314586, 58.56517576402234, 63.18409219864876, 62.06516158196234, 46.51369733195151, 47.504291918969926, 60.307214106282885, 60.96751766820108, 55.04675480627245, 53.48021899500201, 55.2753544622852, 52.44936912290512, 53.95667714457358, 51.21593667614845, 36.74444998464277, 43.476813993146344, 40.00849346960745, 48.770821325240604, 59.423527640681115, 59.027846782438225, 61.482654310041866, 55.96088670915174, 57.15486403434508, 56.39079024714809, 56.33143301933043, 56.85108038686938, 57.95310558811311, 58.02450449235978, 55.22916463113601, 57.68518024875272, 59.07720196631647, 55.8676205911944, 56.67424425002068, 57.66809048191194, 59.596100161152506, 63.54792733346263, 62.83956689219322, 60.99826512798187, 62.08980975612518, 61.06240764740975, 55.545370424947436, 48.519891615836855, 50.46874477017311, 47.231181206241736, 43.80908581518358, 46.141923319908884, 46.95162603932042, 47.68950623850669, 49.61535076941214, 50.84480201044391, 52.7139526028787, 56.08311560846145, 54.602373799970074, 53.750933139554924, 57.19529582608131, 63.89602984151533, 63.03548535993023, 65.16434000384423, 61.78101724193942, 61.28566895761798, 59.2859269726661, 57.334492898756466, 57.29492402845814, 62.452330896931315, 64.43549302316481, 67.48232349272698, 73.58426847765523, 72.93964262931578, 73.66440250027564, 71.28388466373568, 75.68483891025667, 83.48328744211506, 80.5645655047509, 99.17861246293592, 23.0239853935857, 1.7776508893697494, 17.088221426933043, 86.41296063700031, 70.0074669622606, 72.94547911613219, 57.09952723595404, 40.211844828821, 44.02913470422068, 16.671573538934034, 0.7679400797332487, 0.11511061716103747, 0.05199912184428784, 0.049869554462812604, 0.09966322025584598, 0.062311465866983905, 0.08747177363763894, 0.03614608138318985, 0.20295604252286498, 0.16642472616607146, 0.11676192734270327, 0.10954757010744465, 0.14093698092526005, 0.2750013870818, 0.20841331581675238, 26.821665379308886, 77.75374012608683, 66.97123081453385, 30.5465167568576, 61.217662903570364, 73.73441680785149, 81.84952612846129, 87.34248392043575, 96.02070439246394, 29.118395505412934, 0.45629223327963586, 0.6711931646831575, 0.747452559730699, 2.6825469588079764, 53.33361648744153, 91.49529334037535, 81.53813700522147, 89.51746171520603, 76.5652854980961, 83.26891422271729, 78.47360487907164, 80.44991462461411, 74.87956846913984, 82.44704431103122, 78.4842658812, 81.01504187430106, 79.40354393374535, 82.73038064279865, 73.80860451729068, 82.95619933835923, 75.26885586400186, 73.19011734377953, 62.539650701707416, 60.263263948502086, 59.0390137703188, 61.591158836118645, 55.99693721340549, 58.40150310147194, 50.423166828770796, 51.698745143029, 51.47047496611073, 56.531642560035955, 59.24302408772131, 55.11265454753753, 56.541876023815526, 57.28011708105765, 62.39909256658247, 62.56109429943947, 66.80984881616408, 59.972949720198116, 60.229982637589984, 58.15067929606284, 60.87953890523603, 65.38943306092294, 63.24506544297742, 64.5649233941109, 64.7497925450725, 67.25876408238565, 61.04793017910373, 57.51760090551069, 55.06402892451133, 56.797818522299494, 55.21653852155132, 57.7682952727041, 57.53290991629324, 64.21314562520674, 62.047687422844675, 60.12014842802479, 47.26661589837844, 43.73841254941879, 47.17485989293745, 41.01746043851299, 51.923908802770804, 55.25691147773497, 58.23131538206532, 54.19036803707, 58.51383586083689, 58.22860894664642, 61.712768000941125, 66.23762207646524, 63.37108727424376, 48.972211499367994, 46.6210957496397, 64.47479517229142, 62.97552016473586, 57.455050868372766, 55.63849533757856, 58.659179287572066, 55.658723000557195, 57.62148487952448, 53.28117047586749, 37.21862531477405, 44.62907298918694, 41.36615914683188, 50.35562361440351, 62.56171011155652, 59.92905447559973, 65.49993407341742, 56.94000444104595, 59.68038405141523, 60.69858820207658, 61.64900987379013, 59.696599129707586, 63.149642021425315, 61.183502981739665, 57.13948442089943, 61.04705941292548, 63.63065404276695, 59.24718180010396, 62.64689614695888, 62.2600955347861, 62.83359312242078, 66.41749412782731, 64.8137624802128, 60.96919252026466, 63.69917000493696, 65.76283485658708, 61.40805082936441, 49.687847937307055, 52.16976296517157, 48.77855231685024, 45.90178797321935, 48.07125483789752, 51.08975402770504, 50.723875338031405, 54.860273561170025, 55.43970961724558, 55.30655691700598, 58.121198761847715, 58.01578898583689, 57.33494789369645, 60.21085716062977, 66.57118828065934, 66.22521169724004, 70.4162093131773, 64.33747299255865, 64.9182112755314, 63.10249905432425, 58.994169312138716, 59.58304651321904, 65.57224296754407, 66.27551217232981, 70.9949864110639, 76.84477790709465, 75.72162289773264, 77.26851155680995, 74.91881570508404, 77.73143752928704, 87.46759183945196, 83.00173021131947, 102.19886102984029, 23.864704255134832, 1.880201257524952, 19.27766884526899, 95.08850605257096, 76.8954392402403, 81.26885844815163, 70.0599718093872, 51.94197523978449, 62.7165731306999, 33.541065954392955, 1.0941493270858642, 0.2686806101231806, 0.29275155235682765, 0.2297538900447469, 0.15060009224520576, 0.19422732864416417, 0.2532496534648442, 0.15756219204875732], [0.05197635754161785, 0.04181744943883631, 0.011033882976569718, 0.12185737730995302, 0.03489878682059146, 0.12320140196431069, 0.3380790136514172, 8.69732633713753, 36.074830793565326, 31.377657190445934, 19.79723188184923, 51.84361788534349, 52.78349622603386, 58.084654038952245, 73.06154204953101, 72.5492020576231, 36.50732309587541, 0.19993664486513985, 0.1659561867915815, 0.4481643161946728, 1.2038029850490632, 58.590808453098425, 71.8348756913216, 76.43569823234313, 70.90990235728603, 68.61859490794521, 70.33507116379278, 71.62076919309555, 68.81086949379214, 70.21095952680035, 70.38000583648682, 70.6999457267023, 67.38304045892531, 67.43767907542568, 71.25022288291686, 69.65102549522155, 70.49655514378702, 67.40716303548506, 62.027346011131044, 51.63531257260231, 54.40154060240715, 52.43475829401324, 54.773534267179436, 52.8706826702241, 49.53241225211851, 43.92103810464182, 43.22318961543422, 47.0486262536818, 52.43845708908574, 55.44696600206437, 52.822053124827725, 51.22248703433622, 53.06532244528494, 52.97543741041615, 54.162495674625525, 53.14856298508183, 53.450530575167754, 50.382774260736284, 51.09455108642579, 57.620425839577955, 58.50647749439363, 60.534217357635505, 60.14105073867306, 62.21097961548836, 63.54267135743172, 60.0610932227104, 55.157699046596406, 52.762503700871626, 49.555491478212424, 50.03189079223141, 49.218646172554266, 49.56439525850358, 56.37382991852299, 57.780505611050515, 57.17703719292918, 41.0291765582177, 43.145526686022365, 50.03588376506683, 45.60526071056243, 50.51637803354571, 56.61076853352209, 52.579717328471524, 52.239353656768806, 53.84597609120031, 53.435696171176055, 53.7306191844325, 55.717166316124704, 62.469228467633656, 58.04024888623146, 54.45411997456705, 62.381285006000155, 59.87803228439824, 51.71044557325302, 50.90167245557232, 52.78335502070766, 52.455880257391165, 47.899058864962676, 51.04351320574361, 38.211753752923784, 36.438850279777284, 36.43565354808685, 42.22179282096125, 59.85786345697219, 55.61010914464151, 57.08831317963139, 54.00158436067643, 53.93880290369834, 53.20866546323223, 52.0632274689213, 54.15919303894044, 51.78993632716518, 52.56234515097834, 51.6348889566237, 54.29136514663697, 54.68957201127083, 52.01446848530924, 54.62323688691663, 55.91313577467396, 54.91549268845589, 54.77368331724598, 57.440679304061405, 59.218148416088475, 57.9892227726598, 54.79613888648249, 51.04001837392008, 45.71489880161901, 50.11951654188095, 46.96304405889204, 41.44963895120929, 39.72817344050254, 44.959536598574736, 42.7085118909036, 46.03661944789272, 49.5729499478494, 47.69992405368436, 49.2935634428455, 51.644110448898815, 52.7498266004747, 52.89943756595735, 59.41768723149454, 61.27616897706063, 59.34513122804704, 58.26966439524005, 53.84631341503513, 54.83302093321278, 55.45555991511191, 53.70107589229461, 57.41569380606375, 55.504738592332416, 57.57048230017386, 60.6700921827747, 62.3412532960215, 62.945345371000236, 65.7619405561878, 73.31200891925444, 79.25204630820983, 77.72071376923593, 91.9642048497354, 29.81039377950853, 1.9362921315816142, 21.227892867980465, 77.74456177988361, 60.39944471851472, 58.975145816802986, 50.7596512763731, 36.544338503191554, 32.45231405381234, 9.870646499818372, 0.27410632059458767, 0.06214897095736477, 0.10632400235701954, 0.05777194675418639, 0.0665339318314387, 0.07252387371995757, 0.19256128659171445, 0.0713266774771675, 0.02489358276849793, 0.05528581907011329, 0.10215204839985217, 0.0338641889092903, 0.09023043327033521, 0.21962660605147963, 0.5336852852375277, 14.491099522959802, 53.477430189809496, 50.57721399491834, 18.858963674114598, 56.58570851049116, 68.62167789090064, 67.47960136782739, 84.27675939375355, 81.1983185429727, 42.550405071627715, 0.1999421300546777, 0.343666858971119, 0.3707674950841935, 1.2305667876235902, 65.7006025314331, 82.53726666973483, 81.65750257430538, 77.94264147358557, 75.78466323114212, 77.62028540334394, 76.31391648323306, 75.46375843786424, 73.81750045284149, 74.92575830028903, 75.73035409373622, 73.06664113075503, 70.81674606569352, 73.00495009268485, 75.06617915245795, 76.53350645496, 71.27907583790441, 64.34609828456756, 54.89991303413145, 57.73939917164465, 55.51091632535381, 56.30749087179861, 55.65500459363384, 53.34765072791807, 46.77523705267137, 48.835587501525886, 49.12430532516972, 54.161479780750895, 55.6406722530242, 54.01231596546789, 53.761719657528786, 55.52000837941324, 55.200927488265506, 56.127320720303445, 57.0035429154673, 56.310675836378536, 52.836762012973914, 54.01610497505435, 59.54644687714116, 60.923657724934245, 64.81784174519201, 63.32743913896623, 65.07082677656605, 65.31107587199058, 63.70848955646638, 57.86748024725146, 56.05340757677632, 52.42406591292351, 51.47118491511191, 50.740443429639264, 50.52988667641917, 58.52834078573412, 61.109833025163226, 57.98923846214049, 49.61686480429865, 45.87421371090797, 53.86150083234234, 44.16136172509963, 52.73991084867909, 58.60707452220302, 52.88939237594605, 55.35085616573211, 53.68122869922269, 54.57788644298431, 55.290145720205004, 56.56503761968305, 63.344893686233036, 58.50283361250355, 55.94173377560031, 63.17343119652041, 58.55359692727366, 54.658565675058675, 55.593415537188136, 55.028711903479795, 54.95261792213687, 50.45718162290512, 53.22044434085969, 39.60037869791831, 37.304493842586396, 39.41307767744988, 45.7290820921621, 63.50537353946317, 59.401884002070275, 61.678109938098544, 54.83689231257285, 54.6010245046308, 54.61815741754348, 54.764124501136045, 56.94831986581126, 55.020655355145855, 55.64473582852272, 54.86845954771965, 56.19209866369925, 55.57087367580783, 54.79495433069045, 55.4361088814274, 56.863431930542, 55.36485510487711, 56.55948354351906, 59.045285640224336, 57.61724479736821, 58.54858021582327, 58.084312792747255, 53.34540713217951, 48.08893688263432, 50.68743259676042, 48.82863706158054, 46.23009427901238, 43.23202671543245, 45.76876471119542, 44.70149170967841, 49.97156866135136, 52.23827892734159, 52.38823113902923, 50.89323935970184, 53.99745018251481, 56.210165100712935, 54.6923961177949, 64.02056901685654, 64.74582702882829, 61.97438224669426, 62.12909229340092, 57.74667909068447, 57.17107519026726, 57.44214627050585, 57.81847415431854, 59.991533910074544, 58.54643075696884, 62.03619487823979, 65.36409454960977, 65.00843755660519, 65.99394090713994, 69.5853179500949, 77.10993797548356, 84.18968277592813, 81.18269966494653, 95.32275784400203, 31.163307505269206, 1.9687327069620935, 23.094960681853756, 90.14688445675759, 67.14124202728271, 68.90358647992535, 64.35106400520571, 40.803906994481245, 51.182702433678415, 26.09052577326375, 0.19833555174691064, 0.06029332597409526, 0.1680822033555277, 0.03968141244484052, 0.10253851677501395, 0.02113800908949587, 0.08732095390798585, 0.10802803470963433, 0.1215233936184837, 0.11639851821406234, 0.24969586351465797, 0.22437120307116742, 0.13144741916368086, 0.25228409156683956, 0.4693359833571219, 22.033604575741677, 76.50585374524518, 66.15736253799932, 32.48688190214096, 66.19482117314493, 77.86453139397406, 77.68167834128104, 87.6184226620582, 87.63257457363991, 46.886440169426706, 0.18775232286462862, 1.0503800886292611, 1.2537153906399205, 2.3450848604402235, 69.5479848307948, 88.68627225199054, 84.31528491358604, 82.77106346622591, 78.84967388645296, 83.32192113322597, 80.90705117871686, 79.9073096244566, 77.58184617565524, 77.60461945687571, 78.38387673900974, 75.65184393236714, 72.68887765945928, 78.29071260267689, 78.56052460209017, 78.79964013253489, 74.06216221470987, 66.16101034225957, 58.356211493092204, 60.47921396070912, 57.82080404220089, 59.73790953236242, 58.609400487715206, 55.072571846746634, 50.70100007518646, 51.37099581380045, 53.03346887711556, 58.07976284334737, 59.68865240773847, 58.15564893907117, 55.124123557921386, 58.43878130758963, 57.39188894148796, 59.48421847435736, 59.724569551406375, 59.794568169501524, 54.85821431682956, 55.771008691480084, 63.295405141768924, 63.56416986834619, 65.69980236791795, 64.74986707010578, 67.18198760863274, 68.18685962307838, 64.45996469066989, 59.28893935295844, 60.79218772149856, 54.8920996727482, 54.065691578772764, 54.12852794893327, 54.695435954678445, 62.43420562436504, 63.997226991961085, 58.96650483531337, 44.407172741428504, 48.30422009191206, 52.167578204985595, 45.833868211315526, 51.56371754984702, 63.41591604294316, 56.98284849043816, 58.16718855211812, 57.89265009664721, 58.1003592091222, 56.744352694480654, 60.719631718051055, 67.14438776816091, 60.66856638077767, 58.80418539047242, 67.37742362483856, 64.78044194559898, 57.350362808473655, 56.393045609997166, 60.33922456925916, 55.79117751890614, 54.13592553907826, 54.84850252828291, 39.37098280076058, 36.44207054568876, 40.3001844498419, 45.047079978450654, 65.61170201147756, 61.78210373847716, 63.58840227127076, 57.0568440037389, 55.704324476180545, 59.743204732095045, 59.15858722502186, 59.671448892162694, 56.93633310256466, 58.520390141394834, 57.397819565188506, 60.901351205764286, 59.549286673145915, 56.67621720221735, 58.909097025471354, 62.20489994172127, 61.50190138047742, 59.99116912964852, 62.185048826279186, 63.27837421048073, 61.28941482113254, 60.95805691134546, 55.32160705135715, 51.65863106327673, 54.21307071562737, 52.69656865827499, 47.949406408494525, 46.48020421305011, 50.869175618694676, 47.90301653646654, 53.392714838827814, 54.41685353555987, 54.86638069152833, 54.369000619457616, 56.62173548052388, 59.381593581168886, 57.84397740517893, 66.12587375025596, 68.20214117726972, 64.5523561200788, 63.437885238278305, 59.140948326356956, 60.86022515450755, 59.813175893598995, 59.30922585148966, 64.00197305986958, 60.241286908426595, 65.21045530996015, 67.8289355001142, 67.73580274274273, 69.82783025310886, 72.59746290022328, 78.30011060160976, 86.26753484049152, 84.19692347126623, 96.96658395951795, 33.62264733160696, 2.0750688977779883, 24.445934795564224, 97.31779298474713, 74.7825054968557, 78.59539447292205, 76.60927095720845, 49.41641207664244, 70.65182608942833, 38.60114312941028, 0.34539288570803983, 0.2385317867681865, 0.3443172676188331, 0.1575558335189858, 0.19883871829557806, 0.18469808352810724, 0.3187299922348992, 0.1901183394534934], [0.09580476479905267, 0.05660094305752747, 0.05323299071601322, 0.07263704788901153, 0.07832883601827968, 0.07411405774614505, 0.03683133170970025, 9.480937450162827, 25.533610005532545, 34.38692900442308, 28.12210955927449, 37.72440318138369, 45.84828684406896, 54.358441598953746, 66.51012482181673, 77.12583926416214, 42.89297703773745, 0.03754661268284244, 0.41039860236548614, 0.150500837893736, 1.5047810346849504, 64.86764800164008, 72.70098993855139, 79.28677497371551, 71.59159460375386, 71.14017686536236, 69.84239793592884, 69.69548948349492, 70.91482100948211, 70.73999312616164, 70.70799443029588, 67.0195230360954, 66.25408034170827, 67.30231808077905, 65.85961541821881, 66.99437279855051, 66.51050921409362, 61.33664800274757, 54.067346818985484, 53.34486584509573, 53.114340305328376, 53.94979730729134, 53.95305679690454, 51.617261825069306, 50.02140237439064, 42.92753311895555, 42.62552238279774, 46.5431700214263, 51.77860067736719, 51.73496038683, 51.307445572268584, 55.18226092861545, 50.56396815084642, 52.25416844890964, 51.004418942236136, 54.10905730339789, 53.285563530460486, 52.21627443067489, 57.481542556516594, 59.70561665873374, 63.238071856960175, 60.212029949311294, 65.53397240177279, 62.139035501787745, 62.065389079432336, 60.423947764981186, 58.91815377819923, 53.51510847768476, 52.842857376221694, 48.648058983587454, 49.075361990159564, 49.60741973692372, 55.2522320901194, 60.21280657860541, 62.977136181246856, 37.91162575444868, 52.61541481940977, 54.0561798311049, 42.30182093958701, 55.14262145565402, 52.79640082390078, 52.67510152632191, 51.3252805894421, 52.25286229964226, 49.33919629743023, 50.0616733489498, 53.92152094071912, 55.012524281778646, 56.4596474555231, 55.52896315051664, 54.586876515419256, 53.95400601048624, 49.42790462124733, 49.156672723831676, 51.87019586563111, 53.60011800642937, 50.16995037755659, 55.65754236713533, 43.209492698792495, 39.61057686036633, 43.47693166425152, 41.99205175522835, 55.52888470311319, 58.48003679706205, 55.92473030090333, 51.03225992571924, 48.15500920818698, 50.0994889197811, 49.4137683991463, 50.708633007541785, 51.619238699636156, 52.14304770192793, 52.058242136432284, 51.01514270228725, 53.81718981650568, 51.99783371340845, 50.55429166363132, 50.61006776748165, 50.67122536320841, 49.984665455356726, 52.47072250612321, 54.863266329611506, 54.06425206891952, 53.49047207063245, 50.488709634350194, 46.67873105695171, 48.31188440322877, 45.66774014503726, 43.49280549633888, 42.43729176059846, 42.1277069276379, 42.92729777674521, 45.5895947640942, 48.736535887564386, 47.54659075890818, 48.112749591950454, 50.70069020794284, 52.40841957830614, 54.90474931655392, 57.173510982144265, 57.88851591848559, 58.61459370582335, 53.879190721819484, 51.845532001987586, 51.6541438717996, 54.32981221906601, 55.4883901534542, 56.41776046445293, 57.74136427910098, 58.6789244990195, 59.97168279463246, 60.7080921050041, 64.3140289860387, 75.27300573164418, 76.8016004562378, 81.87531178997409, 80.04492990432247, 91.7702671789354, 28.906405125894857, 1.6705189477051459, 25.589862677358813, 74.69436199434342, 63.21649489864227, 61.96230134656353, 48.662889465208984, 30.41963984889369, 38.61263959638534, 17.875786289092034, 0.13912222588494902, 0.17367936430438874, 0.06436470790856308, 0.0854620798641155, 0.07009155222124631, 0.0944967462771362, 0.014334321904536939, 0.045168781502833294, 0.033138243992242127, 0.11706195801736848, 0.0935173564920983, 0.07701697939586255, 0.027216081732823968, 0.14383677693624652, 0.031418072082282554, 14.382938204273103, 42.341087787382065, 54.21984072654478, 30.09599724123555, 46.29942217180806, 57.64910621027793, 60.66336924029935, 78.3588755515314, 86.57758251313241, 50.03047089422903, 0.021055859566155462, 0.44040096503111625, 0.12882847098573563, 2.224700700852179, 74.40559710225752, 82.73971588380876, 85.95683605440202, 77.64840095273911, 78.46182207907401, 77.45661274079355, 76.10773317275509, 79.0921469657652, 75.8257539810673, 73.01051201358919, 71.17135970823227, 71.25449042166434, 72.60054588317871, 72.06448339646863, 72.23217256607549, 69.6611608997468, 66.49787133739841, 57.90452703352898, 57.206576562696895, 57.13333022209906, 56.04580210101221, 55.521855815764404, 54.49640704739479, 52.781064356527025, 46.82664363614975, 45.44999760966147, 50.82099322349795, 54.5194431274168, 53.728022575378425, 55.16842280664752, 57.83383415591333, 52.95085591654624, 54.73107853243428, 53.158506193468654, 55.689227273387296, 56.06233881365869, 54.20486511722688, 59.78562516550864, 62.83494634013023, 65.18142192594468, 62.33800557351882, 68.14252115065052, 63.0422200695161, 66.50430402448102, 61.425485764780355, 62.80747405944332, 57.95321149210776, 54.20441796702724, 50.06926705760341, 53.90654140903104, 51.67621112638905, 58.233551133063536, 60.07523728955177, 64.60140143671345, 43.933958391989435, 53.881689271619244, 53.04593024715301, 43.99569257613152, 57.64826682306106, 54.89356271682247, 56.20910606076641, 54.54602110770441, 56.630694173997455, 52.01691996666693, 52.09107629714474, 56.94829240922005, 57.26967965402911, 58.50843083473944, 59.59518624890236, 57.03152902664677, 55.28701959117767, 51.37255691712903, 54.30572494383782, 54.34998496886223, 55.45313589034542, 52.59202180370208, 57.244588252036806, 45.02390269310244, 38.83985857809744, 44.56182787495275, 44.37100456606957, 57.35853310554259, 61.04976977071455, 58.59535055775797, 53.57794484784527, 51.878801545789166, 53.70996006073491, 52.830521522029755, 51.52863587102583, 54.32060641627158, 55.066523551940925, 54.81769623294954, 53.15614492662492, 55.28492896787582, 53.07496755353866, 53.81211426950271, 52.75389017597322, 54.24868975916217, 52.37808396739345, 53.26389243525844, 55.8669694777458, 55.14567698201826, 54.5511241112986, 52.32070753651281, 50.00489704070553, 51.525874522424516, 49.25800715723346, 44.97282558871854, 45.44520055094073, 44.677604475329005, 45.01361823851063, 48.844769770099276, 51.02150870907692, 50.931980609893806, 52.05147212551486, 52.84051179885865, 54.964118311482096, 57.10281418215845, 60.71447380127446, 61.20922196295954, 61.64704084396363, 56.553854942321784, 54.56198123193557, 54.98836248151718, 58.07966870646323, 57.72045020134219, 59.835588316763605, 60.87262768899242, 61.91813153605308, 63.51730146715718, 65.26930655202558, 67.99009000101398, 81.43136224439068, 80.68451942936068, 87.884900646825, 82.36689459893012, 96.67173939366495, 30.21987549720272, 1.5757696835264083, 28.760283108680483, 85.13651155656385, 70.93192254343342, 74.87836037912678, 60.30861047006423, 36.64301356961651, 53.767603212787265, 32.245114849459746, 0.3011409199285892, 0.08328752396928688, 0.05453240607054003, 0.048018915864128264, 0.11399941428774789, 0.06377796499779628, 0.047549935989081867, 0.009837422178186958, 0.20304000575936612, 0.24858377964025546, 0.11483494042148513, 0.1694776171878461, 0.18744535143336943, 0.2462446680592914, 0.15930438324088053, 19.633115991469353, 65.81406885577788, 70.0777401462678, 47.62727783572289, 48.031434935908166, 62.212987869016594, 72.5858840634746, 84.27696335700251, 92.27602543369417, 55.06842982384467, 0.1054383127860004, 1.3496809572942796, 0.44036535726439574, 3.2966405874298466, 78.23801163704165, 84.56375137452157, 87.65186479014736, 79.280867884236, 82.17988383385443, 81.28659540607084, 78.31776126738518, 82.51273616667717, 78.40078215445243, 79.44055541869133, 72.8892009488998, 72.30254773170718, 73.59860866300522, 74.64992938503143, 73.32999690886467, 71.90441931447675, 70.20893558379143, 60.033566028841086, 59.49121598274478, 60.02923573217085, 58.3558859363679, 58.84869644718786, 57.69193849255962, 55.19946052182106, 49.07785269521898, 47.31795580156388, 53.76980366245393, 57.944237109153505, 56.06559045853154, 58.39478408136676, 60.032444230971805, 55.63161550029632, 58.287821046767704, 54.8834704583691, 58.92788125622658, 59.19081341835761, 55.876940142723825, 62.063318067981356, 64.74295977623233, 68.30834327205535, 65.20389710703205, 71.07526948375087, 67.42468818541496, 66.78847189872496, 64.07524685705862, 64.43435553581484, 59.41110549434539, 56.11966817609726, 52.241036353572724, 55.19667563899871, 55.479725637743556, 61.91401696974232, 66.73891667396792, 61.92570955522599, 44.66319760968609, 55.05407002664382, 52.11123335746027, 43.4986968963377, 60.14723631643481, 60.505391859239154, 58.22654185756561, 56.41698383515882, 59.77441110918599, 53.598819701902336, 54.77834309301069, 62.10458924693447, 59.57454673705563, 61.54877762640677, 61.13321819613057, 60.21400682387814, 58.41513726019091, 54.20029555597613, 55.07753364501461, 57.26423932660011, 56.896709319083925, 54.63983243511569, 61.7565808757659, 45.90604374485631, 40.16985585612636, 45.85995197296143, 44.09519134029266, 60.958566819467855, 61.99974821459863, 61.33988395813973, 56.30199955355737, 55.35809686107021, 55.424835989552165, 54.27480489976945, 54.554622865492306, 58.680646419525154, 56.990038194964015, 58.587705858292125, 54.85216602202385, 58.21872849618235, 56.495470462306855, 58.12547414533554, 55.170478128617816, 57.19303654086206, 57.363985200082105, 56.34490243850216, 62.19112065530593, 59.91063502527053, 57.494843313770915, 55.7034811665935, 50.87773815278084, 52.598238760425204, 51.21321455124886, 48.63052206654703, 47.89279091742731, 48.654275940310576, 49.715983098553075, 51.41992738170009, 54.64483737945557, 54.342418716799834, 53.9108403267399, 56.75920278795304, 58.4337842079901, 58.92146425862467, 63.686018297749186, 64.38655361052483, 64.11542761710383, 59.17597901436591, 57.13030999706638, 57.246051296111084, 60.724358174108694, 59.79931423741003, 63.81646064019973, 63.14368001876339, 64.67111372178601, 64.45795643714168, 68.3293201077369, 71.70247216378489, 82.14721049031904, 82.11028529751687, 88.33022302196872, 84.73497067728351, 98.19672553770005, 34.210477259851274, 1.8224813741060997, 29.871070884889175, 91.69336518933697, 78.82225651894846, 81.25593816080402, 69.9549150466919, 41.05111045222129, 71.11057866004207, 42.98878877393661, 0.40206644623990984, 0.24404288539963387, 0.13643728689320628, 0.15084519441570007, 0.2573424782003126, 0.2508596276804324, 0.32897366030562314, 0.10310171397342797], [0.08105365754736048, 0.021127400686964396, 0.027613279169365287, 0.10172957389224922, 0.023571039219537092, 0.1308825212500749, 0.09467386580522984, 4.689649516536344, 21.35796650763481, 28.061050022802046, 30.48453546339466, 25.671265586729973, 40.41762021280105, 54.04800953403596, 65.21165163286271, 79.09503383021202, 47.095867280037176, 0.041971268402712966, 0.20303764620855932, 0.07999120084869285, 2.2179476051561298, 64.67705611259707, 72.88929508578393, 75.08896027841877, 74.21815487646288, 72.20971307446881, 71.83085918426514, 71.74525737762451, 69.35270570939588, 69.01066718562957, 68.06311668888216, 67.2524804453696, 66.08512816890594, 64.91436343039236, 64.49727427574896, 63.085978031158454, 61.548695256633145, 56.46510347243279, 53.64051057446388, 53.52365139992007, 52.09601063882151, 53.10366361371933, 52.39953148749567, 52.34964678364416, 51.440939518713186, 44.41123239455685, 42.53219350691765, 46.472135897605654, 47.91634867268224, 51.43022360340242, 51.776541433026715, 53.26174297640401, 52.470377337548044, 51.07427635500508, 52.027628037237356, 57.60986289670391, 52.54405121649466, 56.24421519617881, 63.55863148166288, 63.34212841526155, 61.20645276961788, 61.761401468707675, 59.581552090183386, 62.089401829627256, 59.49154546183925, 60.36245676778979, 61.564255299106726, 55.51220286277033, 51.43362822071199, 51.640490101229766, 51.88693261915638, 49.18779280877883, 54.26430471481816, 76.54171989810082, 50.36541777272379, 38.88530708128406, 60.344068696421964, 40.826958763983946, 53.66494694063741, 47.51659247183031, 54.62501764297486, 51.725319200946444, 51.07525302517799, 52.30529654410578, 52.34714431147422, 47.47633326438166, 51.96547808185701, 49.63376629737116, 54.26847419431133, 54.631520932720555, 51.14209413528443, 51.90845858666205, 47.918243177475475, 51.24899441196073, 51.761546211857954, 51.263318907830026, 52.21410143759943, 50.03261643071329, 49.43541596012731, 40.85783173961025, 44.17106566890594, 42.41397326992404, 53.262782404499674, 58.756826693011874, 54.18431974226429, 51.055476434769176, 50.94222191841372, 46.945597356365575, 48.49306652622838, 48.72045024748772, 49.61026737766881, 51.85295704872378, 51.56018349432176, 51.29652961607903, 50.86706538354197, 49.208432320625555, 52.775235714450965, 50.716854295422955, 51.80936382662866, 53.18074603234568, 49.87626291090443, 49.15917911837178, 51.75327785553471, 50.0002254978303, 51.38039381273332, 50.05490726040256, 48.84417356983308, 44.54727980398363, 42.672531989312944, 45.31848446015389, 39.96460999211958, 39.82020008948542, 46.36983656114148, 48.188804349591656, 47.92384824445171, 51.47236554853378, 49.56953356342931, 50.37675342252178, 51.03648039602464, 56.91834511295442, 55.48049049992716, 54.45964659413984, 54.54930020916847, 52.618925340714, 51.724142489894746, 54.68131934442828, 54.42720467044462, 54.17387447049541, 53.38990642178444, 57.250915035124756, 57.99895809542749, 66.052305775304, 69.91550307120048, 78.34460596884452, 78.66336130326795, 81.90337242618685, 77.70247474793466, 87.97722539594098, 20.98850473280876, 1.197466150887551, 35.54163948182137, 75.66239510813068, 63.76778794873146, 62.64790027372299, 48.483127240211736, 33.84588510759416, 46.86436507009691, 21.604669863177886, 0.2928662816843679, 0.2643706607482126, 0.08156483737571586, 0.019467278578949553, 0.05987026157879061, 0.03565809103630243, 0.05645891035636587, 0.07570177496921632, 0.07518298788777283, 0.057052479110538006, 0.056947413982162555, 0.022266946898232547, 0.03323020135623313, 0.11904977231977448, 0.08981441688393393, 8.293127071472908, 36.80690588489656, 45.13298380759455, 32.504887542416974, 25.5046138840337, 49.78214956098988, 62.64828466599988, 73.44867214079827, 87.34007558514996, 52.92508594451412, 0.03280684967795688, 0.31852327106941136, 0.10664418114409333, 3.289011577444692, 74.87967829550468, 81.30914118982132, 83.8088127874559, 79.96335244947865, 80.00756540606099, 77.14071289185556, 74.94896304222846, 73.93890565441501, 74.45439138720113, 72.31476983716412, 74.03174815639373, 70.20726465409803, 69.14477302182105, 68.48029213566934, 66.80390250298285, 65.47319919832292, 61.57352385982391, 57.089552648605846, 57.00739076060634, 56.82708724852532, 56.60590871687859, 56.13913097689229, 53.46964820738762, 52.88586616516114, 47.45865514201503, 46.357175150225245, 49.7760110516702, 52.30481409257459, 54.45994861664311, 54.23365531429168, 55.22102571302845, 53.93087971595026, 53.347752709542554, 55.09463125659574, 58.48435924899194, 55.22370861422632, 58.38822587843865, 65.41033929394138, 65.4492845073823, 63.87600614178566, 65.4480371936675, 62.853569753708385, 64.94520502705728, 63.28322618238388, 62.520395786531516, 63.9641849456295, 58.24926022560366, 53.54342799032889, 53.57732119098787, 51.608718902834006, 54.02253766213694, 58.01580467531758, 69.89031360995385, 54.60510376961001, 41.50473648501981, 59.3807698834327, 41.44140197384743, 54.37227187618133, 50.477562258320475, 57.83453626017417, 53.80549723102201, 53.237090879871005, 54.15047361004738, 55.04126741040138, 49.43633379474763, 56.22797658366542, 51.122125348737164, 55.362866463199744, 56.69281275041642, 52.779671915115856, 52.36350059509278, 49.465563297271736, 54.79876687449794, 55.29172251301428, 53.75689121984667, 54.36971449082898, 51.677219175523334, 50.61502956574964, 40.45729498709402, 46.260853505903675, 44.413730944356615, 52.294164857556744, 60.747978687286384, 55.68661889722271, 51.21606219199396, 53.54106672348515, 50.010302066802986, 49.154519342607074, 50.190868377685554, 53.14191849000993, 53.29740908838088, 53.321029601558564, 55.34118360088718, 52.334114197761785, 52.62115716934205, 54.405815985894975, 54.817931575159875, 54.95672856607745, 55.10773197297127, 53.725296528108665, 51.92532477840301, 54.01319849875666, 51.69974926979312, 53.337621227387466, 51.943285311422045, 50.26266736368979, 47.52215047036448, 45.1486183751014, 46.59636520570325, 44.49371199454031, 45.6570085402458, 48.354857890836655, 50.71182189449188, 49.53173760444888, 53.83101224899293, 52.79225487862864, 54.72328870527206, 55.05189311119818, 58.54671708999142, 59.04992972650836, 57.952740807687086, 58.30767608457997, 55.58247996914772, 54.33861794010286, 57.79548514273859, 57.88931215963056, 58.167090492863814, 58.52972146003478, 61.35996649342199, 59.78537805618779, 69.27620380155503, 75.04779108109014, 86.38213865218624, 81.63588246991559, 87.49045925755655, 79.71336410891625, 90.9917865260955, 20.47312686520238, 0.9610941345172545, 40.64547461848105, 85.03117238321613, 69.38626550859021, 72.41944220758253, 57.61799004770095, 37.196883616908906, 57.36547177837741, 26.3388196499117, 0.4821990592585456, 0.20340631836124007, 0.17082443040224815, 0.09233984870896225, 0.04596195063523708, 0.04699864379701115, 0.059869821078234145, 0.05590621622339372, 0.23328791492648665, 0.18047784304907247, 0.22016640692468614, 0.16036651818261993, 0.2420957044007317, 0.20395423976644395, 0.2209603191623765, 13.045944398449315, 62.657278660805, 67.79106893847066, 51.839295433413604, 35.33815476202196, 60.26577818778254, 70.69104979115149, 80.55941151034448, 92.29472729467577, 57.82138847535657, 0.1962301123046106, 0.5925121350634484, 0.25597136467695236, 3.7754519139566733, 80.68040094067975, 82.43595969292426, 81.78293997241606, 83.71012595392044, 84.3738615897394, 79.59604601706229, 77.39371361271029, 77.92499865255049, 79.00854556791245, 76.31517948642855, 76.71825009007608, 72.63443516146752, 74.58572803005096, 72.26809363211356, 68.25722694396973, 68.10263064599806, 65.21101228652462, 59.991494686372825, 58.72969565852996, 58.17557065717636, 60.32503735634589, 58.40160900546659, 57.78013690825432, 55.80094029826503, 50.23897624784901, 49.60832580443352, 51.63193148951377, 51.57706929791359, 59.191778321419996, 57.318556308746345, 57.542923727343165, 56.53912251995456, 54.55301077135148, 57.62557983398438, 63.329349333240145, 59.37964808556342, 61.63818020974437, 68.40102887922718, 68.48753283100744, 66.57427126361479, 67.99755819382207, 65.62952918391075, 67.74880147749379, 64.26615253571542, 64.78938494959186, 66.20115187860304, 59.38507272351173, 57.78640093341951, 54.3253642512906, 56.79769692882415, 55.79848097216699, 60.28533512546171, 71.82394796802153, 59.49055702455583, 44.475971114250925, 62.28845819350212, 44.4871969376841, 54.10859838608773, 55.79820640625493, 60.79544721111175, 58.31259081440588, 55.88065462727701, 59.65271565221972, 58.99112947525517, 53.90264257307976, 57.48869695971089, 54.61947925629155, 57.37666230047903, 58.94514752972511, 53.9522409439087, 58.29600703331732, 53.07088436618928, 56.05682003882624, 56.950818415611025, 55.43719145559496, 57.64064565781624, 55.25921783139629, 53.9272476011707, 40.627266976141165, 47.37593627745106, 44.95667719071911, 54.5559682384614, 65.38164323376071, 57.27267242247059, 54.32359526234289, 57.27269203432145, 52.00273667612384, 53.0946853083949, 55.41727365985994, 57.135856228490034, 56.590505569211906, 56.24216771894886, 58.96818360974712, 54.16510405079011, 53.167060882814475, 58.10305387743058, 56.4339598532646, 58.25705789750623, 58.08284190393264, 55.64466522585962, 54.776958496339866, 56.99505882878458, 55.044562201346125, 55.44676203881541, 55.630517236648075, 53.3550287062122, 49.743596584566184, 47.2188453520498, 50.794603516978604, 48.39303039735364, 47.8889391499181, 51.266994168681485, 51.95195767187303, 52.19962004692324, 56.705038778243534, 55.598020399770434, 56.49897706124091, 58.08323414094987, 61.88388924444876, 62.74395127450267, 59.06365802211147, 62.00463548783333, 59.454565355854655, 56.54063655484108, 61.15086493953582, 60.49752358467349, 62.41928492822955, 60.64702080142114, 64.63298436134093, 62.6341837452304, 75.1375662895941, 75.38992374174057, 86.94754046778526, 85.393505250254, 87.98449747024044, 82.78665096529069, 93.76249390263712, 25.182436281634917, 1.1806315832561063, 43.24308779931838, 90.33499348548152, 77.80912399291992, 78.99378961132419, 70.747877090208, 43.27862447307956, 74.52471163965042, 37.0276725676752, 0.5900290908832705, 0.33000864509132605, 0.32915801170372194, 0.18524853302346123, 0.14274214454475911, 0.2123269679084901, 0.20061613421045965, 0.11873615124533254], [0.039324764042131366, 0.0059210825542498745, 0.021217393035429622, 0.028463399278060086, 0.04942238511097047, 0.11883970335005753, 0.23356318563943912, 2.9356935428034876, 11.883888302310822, 28.358383332529378, 28.631970613233506, 45.7080150419666, 48.37364996633222, 52.191312466898275, 61.214560308764064, 77.86136996361518, 50.98998069763184, 0.0705132989453212, 0.30645076726232806, 0.04924353039372833, 2.7720059262168024, 62.88983991069179, 72.3918051873484, 78.17930160030242, 76.33194369654503, 75.31201762537803, 74.94734702571746, 69.56497653838127, 68.06828637276926, 70.89201634930026, 69.78551572368991, 66.66494077251804, 63.57470535462903, 63.22932104910574, 61.326289023122484, 60.05078131152738, 59.13418223780971, 54.433786407593765, 52.42399138789023, 54.06688790167532, 52.7669987370891, 53.081180587891616, 50.20020361869566, 49.65346051800636, 51.47653502802695, 43.657909824002175, 43.56798556543166, 46.49761953661519, 48.70794573137837, 50.01736233311315, 55.285811501164595, 52.263064384460456, 50.11250726638302, 50.61460202740085, 54.27239656448365, 56.3838319624624, 53.493955135345466, 61.98587086892898, 62.036540046814956, 62.11767427382931, 62.153905207110995, 62.164350478879875, 63.99151209862002, 65.3471302986145, 61.69635680414016, 58.131577353323664, 59.41653405466388, 57.68165403796781, 56.9727679990953, 52.28174271122102, 54.26330843279439, 57.87150852141842, 70.07538672416442, 60.49623704725697, 32.9893296764743, 51.241177128207305, 44.10241242377989, 44.972052881794596, 48.14855690925352, 45.08532701000091, 54.082608761325965, 51.89480089372205, 53.4457060598558, 48.51296471011255, 49.41931463056996, 45.76456385274088, 49.74756994555074, 48.574946003575484, 49.66544335888278, 52.293482365146765, 46.76220301658877, 47.04730049256356, 47.265607849244155, 49.07767226619106, 52.488078994135705, 55.91699930929369, 53.60642910003663, 51.48548587676018, 47.024731174592056, 44.66945379011093, 43.45051842351114, 46.12985810925884, 48.44931640932637, 57.763866916779556, 57.359898090362556, 49.244996655371885, 49.38881035773985, 47.98592759716896, 47.03713763144709, 46.32651006021808, 48.77074680020733, 48.35777221187469, 50.40803040227583, 50.366582716664965, 52.19690968913417, 51.28095780649493, 54.30483064343853, 54.25029793093282, 55.66571658657443, 54.563236390390706, 52.765825948407574, 50.963202676465436, 48.83446178128643, 50.956071807492165, 52.98121506167997, 49.27779551475279, 49.946587085723884, 45.53654470751363, 43.0774853306432, 43.01224062519689, 40.68640847359934, 40.44777931705598, 45.63560808858564, 46.95652115729548, 47.68107314263621, 48.18790220445203, 47.93133212674049, 48.614679613421046, 50.981367172733435, 52.44877292263893, 54.147927991805545, 53.47365686970373, 50.56831805936752, 53.32274367732387, 52.67587031087568, 55.10431558855119, 53.887710109833755, 55.94285949583977, 56.301603394169966, 61.42531318049277, 60.60753037852626, 71.60646823144728, 73.87846193005963, 79.12235706083237, 77.44561441483037, 82.60247215147942, 75.63710366525959, 85.82440114790394, 8.406712047515377, 0.3290570719588188, 44.244590497786, 73.16286471582228, 64.92151783358666, 61.04321941252678, 44.5221491782896, 38.665317027799546, 46.44367125726516, 19.712879350108487, 0.7571975658497503, 0.19793583771153805, 0.1855669038430337, 0.11247558879756159, 0.06135240039457718, 0.024103673340211955, 0.06458605369252544, 0.06425786545620331, 0.04173697956326989, 0.07515612884514755, 0.0580196651149421, 0.04850960667094877, 0.04241111012355935, 0.14356398834816872, 0.18194505464165442, 4.353388644033863, 24.73441727699772, 47.23373859159408, 29.83032334235407, 28.5372845972738, 54.99185731334072, 63.13860447176042, 68.01330258769374, 85.74572624698763, 55.847236033408876, 0.04762935632419202, 0.32016610065775536, 0.06136985570793191, 3.5404752194881444, 72.86336037420458, 79.50015975582984, 86.67749312616165, 82.87584566300916, 82.26104551746, 79.59219424955307, 74.66895288036716, 73.7976061913275, 74.50760226095878, 72.96342003730037, 70.78080146543442, 67.21115435323408, 67.87254441169001, 66.40374229800317, 62.42212472423431, 61.56765599404613, 56.04084814748457, 54.55554854485297, 57.05590655726772, 54.19644378846692, 55.24426575629942, 53.13093193115727, 53.05202561040079, 53.93054239211544, 47.21214986616566, 46.383192231578214, 48.775296749607215, 51.691265183110396, 54.32429736660373, 55.55501161083099, 53.84484252622051, 50.288923709623276, 49.67475114330169, 57.277967622203214, 61.215952750175234, 54.74024118915681, 62.33788398004348, 62.52942508266818, 64.16467689698743, 65.29630030355146, 68.2330886779293, 65.41603849780175, 66.06872481684532, 64.79574703401136, 61.11108033887802, 62.628547299292784, 61.36807795493834, 59.79588216350925, 55.61378832786314, 59.12343886590774, 60.14076048328031, 69.25995734430128, 58.85615287288543, 36.852020986618534, 52.34608134915752, 45.55786671177034, 46.80579231631371, 51.71217533849901, 48.697551450421734, 55.678566271258944, 54.26002540896016, 53.47446487795923, 52.89975527794131, 52.56236084045903, 49.57670365610431, 51.26010256428873, 49.81367365006478, 50.45706395179995, 55.19473406576342, 48.907245282203924, 47.595298751708, 49.79978061491444, 51.51348767742034, 54.18098180524765, 55.38995827397993, 56.089681656129905, 53.431436477168916, 47.434497264123735, 43.66708424783523, 44.499521024765514, 46.35541792838804, 48.55351809532412, 60.6086443316552, 62.56701315602949, 51.06931063436693, 51.57147207567769, 49.54699954678936, 52.18231062735281, 50.72617384695238, 51.07295843862718, 50.282306671142585, 52.54432186003655, 53.74715981944915, 53.75448680693104, 57.98297835934547, 58.55904509944301, 57.369437294621626, 57.369778540826616, 58.240485883528194, 55.22440679611699, 51.42497939448203, 50.53544075258317, 53.5087699274863, 55.737182171114036, 53.285743959488414, 52.78710480659239, 49.52466949339836, 45.836774687613214, 45.82723156098397, 45.085656489095385, 44.458410662989465, 46.76575668396489, 51.39670302790981, 51.91316150849866, 52.18598588820427, 50.00167285242389, 53.418422052937174, 53.67233668604205, 56.50130694912326, 55.982855904486875, 56.773087978363044, 54.40399992850519, 56.606022465613584, 55.7887456493993, 57.40196943283082, 57.682858205610714, 60.758890721105764, 59.20715401249548, 63.964765456414995, 63.64043251160653, 76.29921543982722, 77.3157839621267, 82.53855320715135, 81.82471321475121, 88.1085777282715, 77.79386597294962, 88.45453077746977, 8.401408022449862, 0.3066303689152964, 48.95187401002454, 81.72220599266791, 71.57486177259877, 71.86085747134301, 52.96700039217549, 43.14503246738065, 58.6044700684086, 22.32453069379253, 0.6452151844578405, 0.19645442284883993, 0.0751153499849381, 0.1810194212462633, 0.039302746675187544, 0.03821392123016619, 0.08251739110076621, 0.019317134921889634, 0.21424117648313123, 0.12425958389236082, 0.15872218706194433, 0.12024844711225842, 0.16641099787046834, 0.39057166465828497, 0.2437619762795587, 7.367144217414241, 45.74595220627324, 68.45008204060217, 46.74877674348893, 59.76838634860132, 70.43501315578338, 70.7736784412015, 78.41837006230509, 90.48725205083048, 61.20801779531664, 0.22983719444563314, 0.8178265609087483, 0.14339308945402024, 5.0030312038237055, 79.77697710837089, 81.4762733828637, 87.14057599344562, 83.02724915166056, 85.5590763399678, 84.24034410907377, 77.22848769157164, 76.06133937835693, 80.00336846997662, 75.35490482084214, 73.60050709016862, 70.52144650490054, 69.67896846032912, 67.61999084103492, 65.57064264051377, 65.00957112158498, 58.01006624775549, 56.20486205623996, 59.7455777660493, 58.653546764004616, 58.351022197354226, 56.24368959857572, 57.66762371986144, 57.24037562647174, 49.02434372132825, 50.43077230453492, 52.90085746395973, 53.84967880864298, 55.15089373434744, 59.09307972077401, 57.37256342364896, 52.05762240194505, 53.30935270555558, 58.554957989723455, 63.83200891556279, 55.53965945397654, 66.7393010662448, 65.83218236123362, 67.64452918883293, 67.92999928997409, 69.1920611166185, 68.95529116353681, 72.15248569365471, 66.8286605035105, 64.5061819784103, 67.29057450448313, 63.57694110562725, 62.29414955262215, 57.77893274061142, 58.81825493228052, 63.055242338488185, 68.89964057553199, 68.99134559016075, 44.522337452057876, 52.360194037037516, 49.582273421748994, 45.53158290924565, 53.21775359492148, 50.91972712547549, 58.08665444774013, 57.855579776148645, 57.34538139835481, 53.20318983447168, 54.20874826369747, 49.5224965003229, 54.20527696609498, 51.38930543776482, 53.39254225454023, 59.78411113062213, 51.44618765000374, 51.896311006238385, 52.33003885515275, 53.417476761725645, 58.54262998027187, 59.99069844522784, 60.538892822880904, 55.80601976763818, 52.285637624802135, 45.25373005097913, 45.722210099620206, 45.50568349899785, 52.11800336837769, 62.99555170920588, 63.75616596591089, 54.39855567870602, 54.887534033867624, 53.060521464194025, 53.186566829681404, 51.76574314794233, 55.52446811429916, 52.69867104868735, 55.80530981863699, 56.024397726981874, 56.87492055277671, 57.781607797068936, 60.62085859237179, 58.58452873845255, 60.384371049942516, 61.19914931635703, 57.62626624876454, 56.74259939501363, 52.5195481700282, 53.98886019183744, 57.42849642230619, 55.26214784191501, 56.89397542707382, 51.74952022490963, 49.71440630574381, 48.21188357568557, 47.65922554077641, 46.36896579496322, 51.7133951956226, 52.12989207236998, 53.630983137315326, 54.91941505862821, 52.195427033209036, 55.379767956272254, 55.709337265260764, 60.18995877235167, 59.11238170439198, 60.52750618227067, 57.55218052094983, 61.346293111001295, 57.66282273877052, 58.6068509471032, 59.189103264962476, 62.630339822461536, 60.78268381857104, 66.78342773068336, 64.70531286731844, 78.47000414325346, 76.82741749671199, 84.5471832829137, 83.05428212688815, 89.10118056881814, 78.09157386902841, 92.39684227974185, 10.520884279281864, 0.484396260712416, 53.8915148089009, 86.74897440018194, 80.42890640997118, 78.76514680923955, 65.27037343671246, 47.83738743874335, 80.04367474586734, 29.842233619382306, 0.8634070763664862, 0.30120563903643244, 0.3882290290728692, 0.30492165576546426, 0.17482622857055358, 0.1413654845448271, 0.19077141408718404, 0.15159252850759417], [0.13386931420574266, 0.0741569510090255, 0.09285256837404544, 0.07764426751002189, 0.0169548510964359, 0.050761449346018415, 0.2968820839399292, 1.8137832731008532, 4.8992771583218735, 22.395909986188336, 31.643436993322066, 47.74175220920194, 47.15982152569679, 57.46324862203291, 55.281300775466434, 79.0271846709713, 50.30802565236246, 0.13174651521107844, 0.15639154841342282, 0.03567956448082001, 2.335721672542634, 61.860253041790386, 74.14486931216332, 79.07638688241282, 77.37510588861282, 72.95449272278817, 71.42862012309413, 71.76805419306602, 67.89624337227114, 68.90200184237573, 63.53754874198668, 64.42977420745358, 63.77695452782416, 61.058100884960545, 56.57417674218455, 56.56349220583516, 51.805649342075476, 53.58409512427546, 51.75600390280447, 51.7634524837617, 49.995044046832675, 50.53521325511318, 51.62537720895583, 49.43095622524139, 50.0649759846349, 45.28914905363514, 44.43174639055806, 45.253439795586374, 50.10681982963316, 52.3723808411629, 52.75094055360364, 51.23117900663807, 47.571380138397224, 47.168588023031916, 53.80934899853122, 57.291531178259085, 56.52948917881135, 63.05989034714238, 61.55173901588687, 62.98176065568001, 60.841519371155776, 60.948294131986565, 62.281480296965576, 60.563674357629594, 59.37119145547191, 59.772155746336914, 59.746213190017215, 60.34560234315934, 54.16122090431952, 59.9589390139426, 56.67152212512109, 51.16104702795706, 56.70354827757805, 36.1955064342868, 42.42104138097456, 47.65828024956488, 44.18315441377702, 50.12279564334501, 48.056946031508915, 47.53808313800443, 54.557050812628965, 49.98210807000437, 52.5619686034418, 47.100448608398445, 49.111553699739524, 49.225671137532885, 43.67706667992377, 44.978383587252715, 46.647469766678356, 46.189772313640965, 45.29909226202196, 47.61911538339431, 47.66175939190773, 50.52612512342392, 51.31722796347834, 51.48584281244586, 49.96788947812973, 52.723123104341575, 46.411339159934755, 40.76464014668619, 44.87191869366554, 38.1676035542642, 40.582912814232614, 45.021153111611646, 61.49500193134431, 54.49241799692954, 49.28114521887995, 48.14759985093148, 48.44685708322833, 51.49040060658609, 49.384750704611506, 51.61116646182153, 52.08702841112691, 54.72911734734812, 57.88921410037626, 60.01167135853922, 60.37747160080941, 60.6520845813136, 57.28828737812658, 56.07233693522792, 55.57669055077338, 48.75678316239388, 49.34768038411295, 52.53019348267586, 53.43153453642323, 49.84909265272079, 46.93219461748677, 46.78698847370763, 43.30939546708138, 42.10609859035861, 43.81828377323766, 41.48324189647552, 45.63361552453811, 46.612725411691976, 48.941848431864095, 49.735179178176395, 47.79601820053593, 49.86585686283727, 49.78227507683539, 53.84680763367684, 52.27172497780093, 51.531495278881444, 53.037167672188055, 54.22930148340041, 53.947012424469, 52.44794922490274, 54.293228272468816, 55.06592342930456, 56.95444660802042, 56.48626073714226, 64.24222215529412, 72.59638032605572, 75.47088930683752, 76.75167652868456, 80.1830130238687, 76.73571248208323, 80.1840171506328, 74.39569703994259, 2.6809495735553006, 0.08967549449974492, 46.17922506024761, 75.68132446658227, 59.80027914047242, 57.03619272478166, 43.890988826751716, 43.14585224274666, 50.534758260173184, 17.00976029519112, 0.5189100845206169, 0.14653097027011458, 0.16611331142485145, 0.06943438667804003, 0.030890603309437156, 0.13278462563551244, 0.12006928979028618, 0.09385075795674518, 0.11547153650392449, 0.09336332685404247, 0.05444947705273667, 0.054917334608974, 0.04438380568077968, 0.0327929834865274, 0.2925483858393085, 2.5579893973565873, 13.804351341339851, 43.14655042463734, 35.002968618946696, 43.02227797046785, 56.50378980944234, 66.98542979455763, 64.3336251474196, 86.49191794856903, 56.02025178170974, 0.13672152083487282, 0.4406700763971575, 0.3189502578348883, 3.6398518998776717, 69.92709759742984, 82.1905291465021, 85.6114556712489, 81.86988322965561, 78.53656676507767, 75.17693904138382, 75.37063352523312, 73.55388579830047, 73.99733328050183, 70.14462440244614, 69.01787650200629, 68.39422748934838, 64.92470279816659, 60.972098996562345, 59.70471843596428, 55.27282453352406, 55.713757776444965, 56.38530677364719, 53.29271008891445, 52.939410440383426, 54.2883566887148, 53.05932906366164, 52.690088902750325, 53.55996862534554, 48.2932335330594, 47.04092664103354, 46.5620836903972, 51.67406951227496, 55.33857522472259, 56.50507242448869, 53.8844584649609, 48.60466972474129, 49.83364243661204, 56.293370339178274, 58.71100948702905, 59.76347946351575, 65.73400151345038, 63.509539096586174, 66.16822750337663, 64.1951144895246, 63.68089175993397, 63.67643594741822, 63.17995802048714, 60.22472666155908, 62.32701901466616, 60.00466600541146, 62.57070018399147, 55.503118653451246, 65.91924328957835, 55.815343241537775, 53.81283206324424, 58.18511770617578, 40.41805559589017, 45.85313489360195, 48.77019374601303, 49.64443906661003, 50.66110172579366, 52.31941315435594, 49.00654008311611, 55.756131141416496, 54.85660222268874, 54.970519619603316, 52.30043280509211, 51.49190287436209, 51.131480201598144, 48.303455229728456, 48.061119433372255, 47.761050270449736, 48.32227476181523, 48.225957039863836, 49.2631729187504, 51.27109696788173, 52.81068609606836, 52.19790989352811, 54.53532480424451, 51.90985102807322, 55.46129049793367, 50.11090301698255, 42.70541714083764, 45.04160042731993, 37.36825981447774, 39.245282603848366, 46.98609190602457, 64.67548716452815, 58.14339153228268, 51.23667816961966, 49.847606074425485, 48.679826259613044, 50.43901320426695, 53.125185658854825, 54.621605180924945, 54.75549136438678, 57.60756438778293, 59.36824575547249, 62.50060742901218, 62.24894031401604, 63.307423283976895, 57.24991483073081, 58.70203510407479, 58.490042763371626, 52.66278528398084, 51.06800448509955, 55.73814315180625, 56.677425292230424, 53.19772989519181, 50.14143474640385, 48.40182435127997, 46.84749495598578, 46.30985175409625, 45.97835656135313, 43.85324385858352, 48.89600376929007, 51.53264061097176, 51.21481880064934, 51.14088996764153, 51.808971589611424, 55.1078417993361, 54.41304491412256, 57.03119562518213, 54.51534032821656, 53.15784331290953, 56.39816822544221, 57.74681245127032, 56.77762223828224, 55.48114945811611, 58.819796423758234, 59.29803140701787, 60.57117000702889, 59.10123825073243, 66.86240073173278, 76.77761124026391, 79.12938594818115, 82.06855127888342, 82.55804738690777, 83.55859694942352, 84.3371795838879, 77.99729577956661, 2.930828578049137, 0.036188924850355235, 49.36180091673329, 85.01902872516264, 66.29172725062217, 67.01198424062422, 52.61737208212576, 45.25652670091199, 64.05362283029865, 13.076958579401817, 0.40393833611761376, 0.15639015413340063, 0.0747347115388801, 0.079660450048264, 0.0719080156376285, 0.03305681267633073, 0.03026507528228385, 0.17011543135008506, 0.3155782758708923, 0.24861840681443292, 0.25380019489074906, 0.16682195807656935, 0.24723509717131817, 0.2679271166843753, 0.6000735454501644, 2.9620996742479266, 30.86780005885709, 70.60527540022328, 57.237065146046305, 62.10002360805389, 65.5163452702184, 76.31324968030377, 71.42756108314761, 90.64538632669758, 59.20556937494586, 0.408665374402077, 0.5516639592186098, 0.4065779686695145, 4.946418164237853, 80.38742342302876, 83.08671228347286, 86.30537002317368, 82.57621580554594, 81.30971385586648, 77.1533037001087, 78.39039571823614, 74.74860052908622, 75.8882059589509, 71.68231902583953, 70.78614373360911, 71.62577413743543, 68.61813206826487, 63.08269108495405, 62.378986497079175, 58.56013944072109, 59.090212468178045, 57.848837221822436, 57.777293189879394, 55.53942018939603, 55.57199939604729, 56.7344997006078, 54.59564301275439, 56.266074565149125, 51.7001768081419, 51.1432316226344, 50.29737641734462, 56.77227997010755, 60.86800713692943, 59.42498284001505, 56.54942658639724, 51.03184415448097, 50.513040096529075, 58.71753631099578, 61.42576033069242, 62.28167249310402, 70.38097073954921, 66.31684610920568, 68.89512984983384, 67.49541636436217, 69.53033416501938, 68.6814312781057, 67.05848786138719, 63.096944978160245, 64.42054879280829, 62.932193663812455, 65.54930102440619, 60.27123420469223, 66.49860089825046, 63.2780094300547, 57.96481778544765, 63.186496611564394, 49.11890422144244, 44.27101158326672, 47.957521792381044, 50.177073401789514, 52.97131892173521, 52.86182203600484, 53.415464585827245, 58.842436344392844, 56.770824770773615, 58.77158264960013, 54.00021937585647, 55.329542006215746, 53.785822622237674, 49.473698293009114, 48.99658510761876, 52.63126119490593, 52.07679494734734, 51.090260013457275, 53.34954523271131, 54.37927330693891, 55.875104473483184, 57.05147820134317, 57.47055207529376, 56.38462428123721, 59.77632130345991, 52.014974471061464, 44.16647649580433, 44.82309302976055, 42.38076648404522, 42.64873104710733, 50.054926872253425, 66.62417165694698, 59.531133943988436, 56.063350785163145, 53.288850476664884, 51.74312676152876, 54.783430407124186, 55.890503698779696, 57.22621587014968, 58.158924118165054, 57.6913187580724, 62.093147693141816, 65.82189006190147, 64.87647725689796, 66.94765736979824, 59.85713389612014, 59.20399258213659, 60.468698086277136, 53.65852209829516, 54.57792174431586, 55.93084919837214, 59.72130613942301, 55.23762910596786, 52.05003261566163, 52.18761367182578, 49.22550639798565, 49.01251385288854, 50.60103454897481, 47.32836969437138, 51.47049065559141, 53.48208996557421, 54.35904172159011, 53.79043140719014, 53.99964278744113, 58.06997260739727, 55.56920274611443, 60.29075191866968, 57.52947392002229, 55.627151843040224, 59.837553424219934, 60.53829662261471, 58.97670299776139, 58.99562843384282, 60.49290695498067, 63.83227955910468, 61.01804956313103, 62.9144488611529, 69.67893708136775, 79.58731482105871, 80.37203988721295, 86.18890700801727, 84.928100339828, 86.95100784301759, 81.99141394707465, 83.98627650353217, 3.794657309209147, 0.18788579070279676, 54.408185097479056, 92.02522124013593, 71.54489486448227, 76.89532156913512, 62.725261180631584, 55.01358724409535, 88.28822228216356, 22.568100075567923, 0.7057787249645879, 0.17362000781201548, 0.26061526709987276, 0.1358844778470455, 0.16208443970930192, 0.23252931934210563, 0.21583312251154455, 0.3864094476786352], [0.08759771083151141, 0.030460241926653735, 0.047068453559111205, 0.046457084752018415, 0.03820977286405621, 0.05977954527723694, 0.01908031990751624, 0.38354844636013435, 0.8531893633546368, 14.979007071064366, 20.05331950802957, 15.41434407234192, 43.26250353167134, 46.96382068818616, 55.729321741288715, 73.7475489031884, 56.35528102997811, 0.7729031037419074, 0.17861022794198606, 0.2360783595471613, 1.515197746696011, 59.46571665425455, 70.35883288229667, 76.44850084858557, 75.91890242791946, 76.55070997053578, 74.53477644151258, 69.91051381634128, 68.96723085834135, 68.10591759220247, 67.19058544405046, 64.86446695943033, 59.47949986304007, 59.563544488722286, 56.3558066275812, 53.962231220737586, 50.529333622224875, 53.04123909242692, 52.103757319911836, 49.40557064548616, 50.68674618198026, 51.16520866270989, 50.95677391175301, 50.31193625542426, 49.41191704042497, 46.69806049716088, 44.54924098906979, 44.564930469759055, 47.53719275997531, 48.97239977313627, 53.83605249466435, 51.68321255714663, 46.77158140367078, 48.844291240938254, 55.49460318780715, 56.7181355722489, 57.09211003395819, 63.37704927690568, 62.80146891070951, 60.825975018162886, 59.282020291974476, 58.6510992050171, 59.4067124397524, 61.87635044897757, 59.82700617082658, 57.44639419740247, 56.980914761943204, 56.34194889376241, 62.16465250138314, 54.71317291259766, 36.8727271787582, 46.689474428853686, 41.320212502633375, 41.86746943381525, 48.23110318952992, 43.61516775623445, 45.2555186517777, 47.94544089225031, 49.70521619243007, 45.82243450226323, 49.46802262336978, 54.77881377743137, 53.70399805807299, 50.403449073914565, 49.01710694836032, 45.456410684893214, 45.00664818671442, 44.04135288730745, 44.36254401360789, 43.20988101343955, 44.656407986917806, 44.882650298456994, 46.9978747060222, 47.80477293076054, 48.72241535494405, 52.42825500426754, 51.95301671181956, 49.49043112416422, 48.090925524311686, 45.3516794789222, 42.751065684903054, 34.40907078404581, 39.144967986691384, 39.54803466796875, 45.93109200077672, 62.46945204273347, 50.252520192054014, 52.33726386101016, 49.92215464192052, 46.91150411482781, 51.11059750280073, 53.58613475676506, 57.459738100728686, 59.59003225449593, 59.478346686209406, 59.25101787813249, 59.1031131436748, 58.05204737570978, 61.08775792583343, 61.161643612769346, 58.57895897280786, 55.63223915715372, 51.39379655161212, 54.66042487852035, 53.62742946993921, 52.97724170069541, 47.782556626104544, 45.19279995272237, 42.96943579950641, 42.11350010287377, 41.06318742998185, 42.198246832816835, 45.6745493796564, 47.456764559591974, 47.98950087639594, 48.50273516870315, 49.89173666123421, 49.6405755319903, 50.11382910513109, 51.051059845955145, 49.142752232090125, 51.624271100567235, 50.703271127516224, 53.22210350344258, 51.484854375162435, 53.99832487106324, 54.11261881551435, 55.58278591402116, 56.57124673166583, 57.73561016205819, 65.5094575881958, 72.96709922052199, 73.81296619292229, 76.4980011601602, 75.70789460212954, 77.79976521768879, 82.04990433108422, 70.44554079732588, 2.753044208211284, 0.06218319210494238, 41.14716537537114, 78.37642423568234, 55.796339358052904, 53.39983786306074, 43.99554352606497, 37.49187723282845, 44.91095019925026, 8.208848084172896, 0.4684939914413037, 0.1986718183803943, 0.17558284764808996, 0.1615402874566855, 0.06922571964922451, 0.10137230878876102, 0.02598928193741989, 0.012073416409323053, 0.0625061173172247, 0.05109380510064864, 0.07248753816970895, 0.043056462590973225, 0.0698146420801359, 0.08409474315422197, 0.15084830473267263, 0.5089429741905582, 4.019586362185017, 40.038923217404275, 23.794627189636234, 19.78694546607233, 59.57876328499087, 54.92846004424557, 66.65615466333205, 82.40671450091948, 63.988762517129224, 0.9430151336616086, 0.49054711936942996, 0.4712984861145097, 2.3411936240811504, 68.69005264774447, 78.4754954614947, 81.98566375240203, 83.11126632075157, 80.89636664236747, 80.11937649019303, 76.02439065133372, 73.09474883540985, 73.19011734377953, 72.30636027551466, 69.8453083345967, 63.79269892169584, 62.3754132178522, 59.12852618002123, 55.750663357396284, 55.43081368169477, 56.32819314156809, 54.21210973493515, 54.64295856414303, 55.36367447145524, 54.36776507285334, 52.07986224082209, 53.25132908359651, 51.84825412688717, 51.110244489485225, 46.84829904187111, 48.23239757168678, 51.79767908588533, 52.86771735837383, 56.52941073140791, 55.85765384858655, 48.77527321538618, 50.07384054122433, 57.86651142181889, 61.31157621260613, 60.45826850398895, 63.561490889518495, 63.86026567028415, 62.916700301631806, 60.85758932175175, 62.880700788190296, 62.983251156345496, 63.36141470939883, 63.973445661606334, 60.79260349273682, 61.356059812730365, 58.94080546594436, 64.79258560365247, 51.360664290766564, 45.05647797738352, 54.565856533665816, 41.59928521802349, 46.00842937346428, 46.117388894481046, 46.432268927174235, 47.22425430051742, 48.78045466638381, 51.24844135776643, 47.74558044249012, 52.53078968294206, 57.06397487271217, 53.73609089082288, 54.233882811761674, 52.53018956030569, 49.669914860879224, 48.08304156026533, 47.53485894972279, 44.592332147782855, 44.77408693682763, 46.909652756106475, 46.71777825201712, 46.951551514287154, 50.42465732943628, 50.780800696342226, 55.21693468093873, 54.01588924469487, 53.13152028668312, 48.159598381288596, 46.207246472758634, 46.010672969202844, 37.67527549497543, 38.45372476885396, 41.4243043622663, 46.39781874995078, 65.9506771641393, 53.50227840485112, 54.276562121606645, 52.15981583441458, 49.240199596651145, 53.12560535246327, 57.21764941369334, 57.766243873103974, 61.16316941476638, 59.59416251028738, 60.822393894195564, 61.09046436125233, 59.78878659586753, 60.85793449032692, 63.23475745416457, 58.935482809620524, 59.01422439082977, 52.37997062744633, 58.753794700868674, 56.24454075290311, 54.272071007759344, 51.44118662803404, 49.287711266548406, 48.12655241258683, 46.16844246464391, 42.32863426208496, 45.737758374983265, 47.93130074777911, 51.62134893478886, 49.64556478684949, 53.562369115891, 51.991671669867735, 53.19463514512586, 52.15253591537476, 55.17054480891074, 54.26651693159535, 54.381446300014375, 54.767599721108716, 55.912468971744666, 55.51978088194325, 57.98080928864018, 57.643454074859626, 59.5492749060354, 59.29648991554015, 62.224252916151485, 67.54327712520477, 76.47809905390586, 77.45054875650715, 80.64007897530833, 79.59913684475808, 84.60779959155668, 83.9258720028785, 77.33108120579874, 3.500958565742739, 0.12713594527374353, 45.03093158045123, 87.26080448396745, 63.43965814959619, 64.75265979766846, 48.42295808176841, 40.99187874024914, 57.7931748667071, 12.041115530075567, 0.6297055199261635, 0.06925780341149339, 0.17743779166090876, 0.016895653567306938, 0.134090974085754, 0.058037599233249505, 0.02575793870604567, 0.04285749040483948, 0.28062137745080457, 0.12656923173175705, 0.2002349441810962, 0.1437402345360287, 0.19483393238436794, 0.17969424235484294, 0.3121326881791315, 0.9997325450662644, 14.249028486590232, 67.03309443689162, 40.129631950009255, 27.343783840056393, 59.31843949902443, 64.82587868167509, 71.98622426679059, 87.2430596813079, 69.11575532728627, 1.3365658997528016, 0.47850357368588453, 0.7926041272378738, 4.063741954103593, 75.29539462058776, 79.0321974600515, 82.712110242536, 81.8638349348499, 82.89273538897115, 83.18470877985801, 77.99964920167001, 75.83819573925388, 77.72433803927514, 73.11368603860178, 73.41703430298837, 66.65717447957685, 66.90461327952724, 61.42618394667103, 58.306275798428445, 56.87846245304231, 58.73451625147174, 58.01812279608942, 59.02088849775253, 58.29598349909629, 56.33846582904939, 55.685661838900664, 56.762030816847286, 55.155612345664736, 53.33489125774753, 51.5171629382718, 52.459943832889685, 55.9440597411125, 56.82392189579626, 59.607424043839984, 57.815034235677416, 50.46568139906853, 52.75617691778368, 59.3906738681178, 62.80583058634112, 61.2386554287326, 68.03625629794213, 66.95699261080834, 65.21040431914791, 61.99258596666398, 65.00610766872283, 67.64652175288047, 68.05330291871103, 66.58630509530344, 62.733156911788456, 62.4295497709705, 63.339049354676284, 66.12811734599453, 57.943609529925936, 47.583731682069846, 52.06434534442041, 43.89883356709635, 45.6389577927128, 47.50280926304479, 49.573193134800086, 50.79069683628698, 49.6135857028346, 54.056242589027654, 52.072911800876746, 55.63780107805806, 61.01771223929621, 58.34833537378619, 57.55184711948518, 55.92583640929192, 49.688844219330825, 51.099493272842906, 49.2675228272715, 49.08095529002529, 48.97240761787661, 49.457102744810044, 50.547290232873735, 50.22178842175392, 54.916626253435695, 53.788619272170536, 58.07353411951373, 54.831852066901426, 55.53302672601516, 52.132731868374734, 47.34697349609868, 44.99889758325393, 38.224979985144834, 40.67017378345613, 43.089315199082904, 49.51690320045718, 65.7147152193131, 55.9412395569586, 56.95561939670194, 53.06135300667056, 52.824386935080256, 57.06380228842459, 58.72258440140755, 60.92821551907448, 62.34916471665906, 63.07263805020241, 62.87774332108037, 64.62607314509731, 63.72771309268091, 65.65043149455902, 65.30761241912842, 61.501662115896906, 61.279954064276914, 53.64121267872473, 59.73709367936658, 57.678170973254794, 57.41849437836678, 54.25869964784192, 52.751289644548976, 50.060814349882065, 48.75198610367314, 46.844027580753455, 48.96968157060685, 51.26395433179794, 53.74604194395004, 53.65749443731001, 55.76632538149434, 55.89500265736734, 57.41147725812851, 56.057180896882095, 57.73767332876883, 55.6447946640753, 59.18203907628214, 56.835861590600786, 59.667969749819854, 56.38969590587001, 61.09303743608537, 59.58773374557496, 61.108499419304636, 60.489345442864206, 64.7597671324207, 68.60339964589765, 78.83159175995858, 80.07241002974972, 84.0937965146957, 82.30286582823723, 87.29281102457355, 85.82741352819627, 81.33549167263894, 4.500084307885939, 0.20046421897507485, 49.86448403327696, 95.73900761142855, 67.0432847545993, 75.54441805808776, 57.72137195833268, 50.8167217623803, 82.73406767076062, 16.969185336943596, 0.9080278981597194, 0.3707740834403423, 0.3332256321464816, 0.21033561427987393, 0.1998561137025395, 0.1477048008312141, 0.21589307655249873, 0.15336176260344445], [0.11051120912475933, 0.06980143472432129, 0.06016319444883735, 0.06851037738904839, 0.06638822190824055, 0.12272569200684949, 0.24397862594454522, 0.12660660150070346, 0.6716113261157467, 10.820650439108572, 36.172246779164965, 29.823706303873372, 35.598772725751324, 53.457677133621715, 49.779945188953036, 65.95084974842688, 66.36203965833111, 2.112170106941654, 1.1191934154879664, 0.634426950447021, 1.661754288981038, 56.98237780601748, 74.09278023627498, 76.09597390697849, 77.3274177120578, 74.66776832457512, 74.87162959191107, 73.05495246764153, 67.83599576642438, 67.30039611939462, 64.30980067099294, 63.03579914954401, 60.250465254629816, 57.691522721321356, 53.864744632474846, 53.29810334790138, 50.81009687915925, 50.70335349728985, 51.88420657188662, 51.49611549992716, 49.575974095252256, 50.735038403541814, 51.209052916496034, 50.111781627901145, 50.41574962677495, 48.247977226011216, 44.005631862148164, 43.90037505857406, 47.75951662371236, 47.376626614601385, 53.24184087014968, 54.139035978624904, 48.2686794957807, 47.74454101439446, 56.057251499545195, 57.614357932921386, 58.06382233096708, 62.025416205006266, 60.096555371438306, 60.464226584280695, 58.84029473027876, 59.23494792753651, 60.06560002603839, 59.59920667832898, 57.84864110331382, 55.678903595093765, 64.7720363063197, 58.79934126330961, 47.98704939503824, 39.2920333339322, 52.63022568918044, 57.85706635444396, 43.285763186793176, 49.332869514342285, 46.53568221676735, 43.2249350701609, 46.74664297411519, 45.84510580185921, 45.194980790538175, 43.803633720644065, 48.01289389210363, 52.999371713207616, 51.828630508915076, 52.101956952002745, 47.683057861943404, 44.3354247462365, 41.82621394434283, 46.136322175302816, 41.48307715692828, 40.89337625811177, 42.85725209020799, 43.05279793277864, 45.70649316233974, 49.38982232924431, 50.16984839593211, 52.06447086026592, 50.42654791185933, 51.06450573090584, 41.878055910910334, 49.94087611475299, 42.53044412982079, 44.78486953243133, 39.825424686554946, 42.9252032310732, 37.90158840917772, 47.80922089853595, 58.88060885090982, 54.306760449563306, 53.65248949297013, 52.75309001245807, 50.605337389053844, 53.03930928630214, 54.58307181635211, 57.65332275821317, 57.99049362059563, 60.665934470392045, 60.7096218293713, 61.50727502761349, 60.06957338702295, 59.16378044313001, 58.498099311705566, 57.9910074510882, 54.696393013000495, 55.32820055561682, 55.55198354105796, 52.25603157474149, 48.46810848482194, 45.478587765847486, 44.31016075995661, 40.72504381979666, 40.66767131128619, 40.578547216230824, 46.864227787140884, 47.278175123276256, 47.47554094560685, 47.980463735518924, 49.093424504803075, 48.15181639886672, 48.37048461360317, 48.15463266065044, 50.177457794066406, 52.46822003395327, 51.32849301061323, 52.63065714989939, 50.457883727165964, 52.12242387956189, 54.473241529157086, 53.14982991064749, 52.79027015932145, 57.138331244068766, 64.9418867018915, 71.95205257784936, 71.97398647185295, 74.51694534670922, 76.00285683908771, 80.26997981532928, 81.39586479433122, 80.36502668934484, 4.679666103855257, 0.0987498366063641, 45.17718107469621, 78.60945224761963, 52.39278893316946, 50.788111994343424, 49.69725770335044, 38.62811334671513, 44.62076540916197, 8.255462511893242, 0.4730470358364044, 0.1449629415066973, 0.05255896357759353, 0.12505766364835924, 0.12155266583807046, 0.025759989906462933, 0.10757752138400271, 0.08835976913331017, 0.034939803168057434, 0.034205132509551706, 0.12892190306898088, 0.09900223959477679, 0.1420360413049498, 0.14357186373203032, 0.25122615478692517, 0.41501753032207495, 1.183657814418116, 28.5282023491398, 44.38544673304404, 23.907760112516343, 48.24021093307003, 63.399073385423236, 57.354449918193204, 78.61612812165292, 71.9470162545481, 2.606175224627218, 0.6722871995260639, 0.9839301736604784, 2.1556907651885866, 66.07569879101169, 75.42175769805908, 83.51289349217569, 81.01515954540622, 79.5693660551502, 78.52461922553279, 79.00951047097483, 73.92171782831993, 73.04480921837592, 67.3563918759746, 65.94485636680358, 63.68717539695002, 58.829971051985225, 55.899438858032234, 57.360792390761844, 55.95967077439832, 56.004468164136334, 55.91670120916059, 54.88757717993952, 53.09087668695758, 53.168292507048584, 55.116604374301055, 54.13875749034267, 51.46401090006675, 50.69250814376339, 46.7091098139363, 46.36849118817238, 49.51218066676971, 50.99618980961462, 55.063142468852384, 54.973104461546875, 49.65717892492972, 48.93342318073396, 60.166907002848966, 60.878268057300204, 61.349517299282944, 64.74983176877423, 62.59131616161716, 63.652536945958296, 59.720172574443204, 63.53586604518276, 61.97895180794501, 63.51121787101992, 59.75740371211883, 60.415287171640706, 65.02086754768126, 57.73153874181933, 47.89743500371134, 45.671258511081824, 58.29226901454311, 53.60298918139551, 46.53081063301333, 49.42738294601441, 48.043217735905806, 44.2874502366589, 48.959499097639515, 46.81319775119905, 49.11406009427963, 46.09308981126355, 51.28439772513605, 56.588210982661096, 54.968738863545084, 53.37801771779215, 49.371453869727354, 47.04173072691887, 44.867419735077895, 48.73693204695179, 42.71118694736112, 44.131853734293294, 45.4920885639806, 44.748316964795514, 46.48517385605843, 49.020433118266446, 52.24088730350618, 55.468695932819, 52.72365262431484, 52.218231693390884, 44.1881868147081, 51.33699278677664, 45.89593971929243, 47.55375300684283, 40.25104499632313, 44.73468672844672, 38.88786054426624, 49.1549547256962, 62.12263214972712, 56.212251801644605, 52.59271998559275, 55.615384732523275, 54.12664913362073, 56.574714106898156, 58.171903241065245, 57.83004906869704, 59.978072335643155, 62.76900737516342, 61.279432389044, 61.198729622748594, 61.24249935150147, 60.35116818643386, 61.11275126857143, 61.79649491463939, 55.92032940156999, 58.294128218004786, 58.20659268286921, 53.72603393370106, 49.960244778663885, 49.9619431649485, 46.508127566306825, 44.54636196936331, 42.88247685278616, 44.278150296980336, 49.00995254516602, 50.5089137631078, 51.858067897058305, 51.15725017363026, 52.32637928378198, 53.93830868505663, 52.09505750286964, 53.94814991181897, 52.32205290948191, 54.982110223462506, 55.80984015618601, 55.665442020662375, 53.24500230050857, 57.502099698589696, 59.15848524339738, 56.3508056056115, 56.931543888584265, 62.475417967765566, 65.25915153564947, 75.75111912142846, 75.18643902194115, 80.44818878173828, 77.93160392392066, 82.71206317409393, 84.03246633468136, 87.26207533190328, 6.227516233921052, 0.19716018900996257, 48.025924005816066, 88.84908199310304, 60.78560206197924, 58.510313572422156, 56.59806789890413, 47.75236222051805, 58.83749023560555, 9.283889339816186, 0.4093861099212401, 0.15517303960457926, 0.17518071277487665, 0.11030609674391248, 0.07292479051337128, 0.021986372941624255, 0.11664090077242545, 0.040175079503246856, 0.23166043774014522, 0.17750335346546867, 0.23354325203164933, 0.18817246080406252, 0.2546150979375647, 0.23868906461904127, 0.3895420118445351, 0.8159844565295404, 5.5436696256360705, 53.437335721908084, 65.86786808506136, 42.481732214650805, 45.68330018751083, 70.72957531098398, 62.56061184790827, 82.95929801079535, 77.67220973968506, 2.9993217414425266, 1.754336321065503, 1.8968513511842298, 3.0965283705342204, 73.27182815920922, 77.68885627869638, 83.78964808679397, 80.88151654889508, 79.93213822764736, 78.90548136926468, 82.53179888571464, 75.01665530666229, 74.85754043825212, 71.3064226027458, 68.58086170688753, 68.57143232899328, 62.1337010783534, 59.1404737195661, 60.587651806492964, 57.93248961048742, 56.2492319076292, 60.08336051817864, 58.570255233395486, 55.613972679261245, 54.42745177976547, 57.259634464017815, 57.849319673353634, 55.62928169004379, 52.41520527870425, 48.98476700628958, 49.749052601475874, 54.34089683717298, 53.36492484615695, 61.50556487421836, 58.038848600079945, 51.93123971262286, 49.73066453010806, 61.14097664433142, 63.86950285203996, 64.83607684412311, 66.07676567569857, 65.07362342649891, 65.48081644119756, 63.43474341977028, 66.74828329393941, 66.3498410870952, 65.98689633031046, 64.41297077363538, 63.082624404661125, 65.7800030708313, 60.70784107331307, 52.72171889581988, 43.12646004461473, 53.57236331509006, 54.76730946571597, 49.73339057737782, 51.61297467447097, 50.03411477611911, 46.99749031374532, 51.1107583199778, 50.838259496996486, 52.470679360051314, 49.47165866051951, 53.03917200334611, 57.99575351899671, 57.90900245789559, 54.9604626624815, 52.02535306253741, 49.290727569210915, 46.74133600727205, 50.77173217650383, 47.542142791132775, 46.71287528930172, 47.59043501269433, 48.67904570794875, 48.716892657741425, 53.19163845431421, 55.277735340979795, 57.027798852612904, 55.79135794793406, 55.98937880608344, 46.59075621635684, 53.77456541984312, 49.01142735635081, 48.44814362064485, 40.826692042812226, 45.88192901303692, 41.90690886589789, 52.9199319501077, 61.63866266127556, 60.063630996211884, 57.454956731488636, 59.002445513202304, 55.97170852845716, 57.10011559147989, 59.053879553271884, 60.20957062321325, 62.69897345573672, 66.56865442952802, 65.41092764946723, 65.94604092259561, 64.25259682439989, 64.12210741350728, 63.76818410811886, 63.49970963693435, 57.176558663768155, 58.47512991197648, 61.329999585305494, 54.84958118008029, 53.408580826174834, 54.32691750987884, 49.51739741909889, 48.24163083107241, 45.99496779903289, 46.97626244637274, 53.903634932733354, 51.795757124500895, 54.37979498217183, 53.830592555384484, 55.19050575071766, 56.87869387288248, 54.649277502490634, 55.400160358798125, 56.97505081853559, 59.11364078521729, 56.54663385883455, 59.7617143969382, 55.289306332988126, 60.38091151945053, 62.97255485288559, 59.9230218702747, 58.12288145865164, 63.717346268315474, 68.81217172068935, 78.11513162428334, 77.23078620049262, 81.79182806322652, 80.36277524886593, 86.83898495089623, 85.68489028561501, 89.18124398877545, 7.498078327025137, 0.23074045807363527, 53.78284162090671, 93.87844700967112, 65.36409454960977, 70.10252952575684, 69.51327185476981, 58.743773045078406, 77.22112148038804, 17.406774759292603, 0.8886059758163268, 0.4966039943598932, 0.4568241434472223, 0.17778934940936106, 0.21293099759326828, 0.1224735571492103, 0.290041531646444, 0.19309446846525516], [0.06609866365550027, 0.02652722887784964, 0.05219813233481781, 0.045280285600212314, 0.17707622880416532, 0.14160405964620654, 0.037503355528197946, 0.1743572142215506, 2.0893303905763934, 9.230237199414162, 35.495688915252686, 28.391182191910286, 38.02256215003229, 51.43869984534479, 56.57607909171813, 61.53840295730099, 74.91701141480478, 5.903489724282296, 1.0468090157355032, 0.3814914696399243, 0.9024091641749106, 55.54744535876859, 64.65440442485195, 75.25642195055562, 75.933164165866, 78.82641423133113, 77.28591903563469, 75.72862825086041, 66.43843173980713, 64.30043012865129, 60.441013997600926, 59.71381049002371, 56.67831567025954, 57.35965490341187, 54.07877660566761, 54.65567096587151, 56.34661651426747, 55.25294596149076, 52.55910919558618, 53.3016138692056, 50.197391279282115, 53.32481468877485, 50.22542838127383, 50.27145739524595, 50.522308657246256, 50.37295656819498, 44.5911632814715, 43.94585886309224, 43.33483203764885, 51.06075986739128, 52.065533822582616, 50.831418883415964, 48.47001867909586, 51.01609583823912, 57.42068698329311, 61.2219225975775, 60.440959084418516, 60.94141821707449, 59.705620581103915, 60.36883454168997, 59.08386999560941, 61.06243902637113, 56.586104669878566, 61.24071859544324, 57.87947877760857, 56.50412713327716, 56.26727873279203, 62.75670289993287, 37.80294079934397, 73.50145155383696, 61.95033419516779, 48.25127986169631, 49.29933324936898, 46.32707095915272, 49.470681990346606, 44.96296867247551, 41.76336972944198, 45.541416291267645, 48.21382907129104, 43.4129774185919, 48.50824609879525, 51.450608161187944, 51.317784940042806, 48.91859662148261, 43.36380266374157, 41.535538857983006, 41.47618555253552, 41.43524385267689, 44.19351339340211, 40.819117946009484, 43.5229528334833, 41.03617014423494, 42.43724861452657, 43.50327822469896, 48.0716823762463, 52.69123423484064, 52.3908708941552, 46.97300687912972, 42.10084261432771, 47.94207549864247, 44.33751144716817, 40.80819414507958, 41.17481416271579, 42.48653711811189, 41.74647608110982, 35.244080635809134, 49.1750882517907, 58.52849375817084, 53.09703873049829, 53.405266423379224, 54.98385567818919, 56.05876945680188, 56.86510678260558, 55.10672392383699, 57.85556800903813, 59.65722637791788, 59.21539491222751, 59.16347842062674, 63.028805563526774, 58.48408860545005, 57.3966585436175, 61.17083764845326, 55.98843351487191, 54.69628318663567, 54.91153501695203, 54.68314324655841, 48.10119821179298, 46.42860935580346, 44.22693590964041, 42.91379305624193, 42.508439633154104, 41.95293787987002, 46.40313356153427, 50.03276155840967, 49.823248155655406, 48.751942957601244, 48.02179767239479, 49.69525729456256, 47.443130400873, 47.69883755714663, 49.01722069709532, 49.81211646910637, 48.8480253373423, 52.17384223015078, 50.05595453323857, 52.57183728679534, 52.58346711435626, 53.6126813580913, 52.34362986779983, 55.42234136212257, 63.30917266107375, 71.20695913991621, 72.64631994308965, 75.10919970850792, 73.90427897053381, 76.21033453172254, 77.93568318889987, 86.83943210109588, 9.216977627046647, 0.4161916979618611, 38.45372084648379, 78.40314342129615, 44.41372309961627, 55.22044912461312, 41.99847659757061, 29.44468963530756, 41.795364502937566, 5.875217280080242, 0.4672687104152095, 0.1234005465202274, 0.1288655496412708, 0.1094666635617614, 0.10582930107991542, 0.07546244144079185, 0.08593738379497683, 0.05055306576973489, 0.20216128758845792, 0.021965667500250766, 0.0662869144411337, 0.16838453229396574, 0.09886481874291936, 0.19035628636277493, 0.11085638536080239, 0.21340120703943316, 3.0725568052261107, 19.159750630778653, 46.31489984450802, 25.3582545634239, 46.253259797250074, 65.25356608052408, 65.05729852184173, 71.8384450481784, 80.28082909122591, 7.194976191366873, 1.2462337146843634, 1.107096335580272, 0.9966525651754873, 63.445016107251575, 70.24324847805885, 81.0176855517972, 79.4344835896646, 83.89236711686658, 81.0639302961288, 80.24613964942195, 71.44182282109415, 68.48059023580244, 62.51133118906329, 64.7568488890125, 59.53845700910015, 60.02785898024037, 57.68798474342593, 60.529836070153024, 57.72334098815919, 61.193952175878714, 54.73214541712115, 56.690612300749756, 52.453879848603286, 56.57832660982686, 53.39185976213025, 53.316008967738, 53.86220685897335, 53.47373923947735, 48.128831309656945, 48.79477523988294, 48.19522919193391, 54.41042869321762, 52.76709287397323, 53.65105782785724, 49.493110102991906, 51.89027055617302, 60.46644272342805, 63.66115439322687, 62.35176917045348, 62.4377396798903, 61.929200464679354, 63.676926243689756, 62.498575641262924, 62.84040235703992, 60.16762087422033, 62.65365439076578, 61.88067290090746, 57.97541210728308, 55.93959216148623, 54.243351413357644, 45.38890277185748, 76.6848393409483, 52.70948110088226, 49.0475719974887, 50.16672226690477, 49.14522332529868, 51.08601600893083, 46.662645416875044, 44.42947926059846, 48.03875800101988, 51.13380224474015, 47.40763687318372, 50.558092440328295, 53.618184443443056, 53.42673747770248, 50.41387473383258, 45.84203850838446, 44.7439552891639, 43.462265922177224, 45.85814376031199, 46.13868736451673, 43.093127742890395, 42.8887055766198, 43.23943607268795, 44.348356800694624, 43.660902592443655, 49.65842623864451, 53.791666953794426, 54.021878703948, 49.11991227057673, 45.21003484725953, 50.394984599082704, 46.77582148582705, 44.04307873018327, 44.1287785960782, 43.715564743165054, 42.704711114206624, 37.12289987071868, 51.30433121035176, 61.132516091869725, 57.891751873877745, 55.98855510834725, 57.382969471716116, 58.42656704687304, 58.69021308037543, 56.95739623039, 58.110392632022986, 60.71520728449668, 59.40882659727528, 60.683083072785415, 64.16945042148714, 60.38045652451054, 58.33336368683846, 62.866780296448745, 59.2659346518978, 54.18877163240987, 58.42246032530262, 58.04984692604312, 49.973843636051306, 51.09401372171218, 47.12282965260167, 48.12944319940383, 45.34451330861738, 46.036807721660985, 47.61322006102532, 52.61133163206039, 51.35737734456217, 52.332078487642356, 51.54621593413815, 52.55638314831642, 50.98273607992357, 51.2549485698823, 51.60212932094451, 53.60034942626954, 52.52165840518091, 58.38349157764066, 54.50503233940371, 56.48829644726169, 54.78666244014617, 58.85970261789138, 56.86724839671966, 59.657591158343905, 68.24374968005766, 75.8150851341986, 74.97773754981257, 79.16420875057098, 77.2029609064902, 82.85905791867165, 81.18819098318778, 94.15359343251875, 10.76728561232167, 0.48339961096644407, 38.519820628627656, 88.033244686742, 47.72731004222747, 65.1712747543089, 51.58523567261235, 43.60832714265393, 61.39691522044521, 10.000436748227767, 0.44202209900944467, 0.07661492879232092, 0.11091499108700983, 0.053586279823174404, 0.11533662842045869, 0.1002731794611581, 0.1529675337576097, 0.06153289070953766, 0.31503738715283336, 0.11265093866255015, 0.20670398979658083, 0.19339050016095563, 0.17864886941688676, 0.25848336698066804, 0.23977965206628848, 0.27382452281252034, 3.997927034093488, 45.64543754823747, 62.41742964713805, 42.601195842989036, 50.470003850998424, 71.6440837613998, 72.1440839767456, 74.73866124306956, 84.73431171909456, 8.097426295280457, 2.6312627042493513, 0.9885417165294771, 1.4780607459045227, 72.58089480861541, 69.16886421941942, 84.60019803816273, 79.24199719582835, 85.54730922945085, 82.2071756855134, 82.12179353160244, 69.32254268277076, 68.72733085386216, 66.41908661011728, 68.38809290239888, 61.50692985903833, 64.15795003214191, 59.503273348654474, 61.79658905152352, 59.64273322013117, 64.22707003931846, 57.564481073810214, 57.80488706404164, 55.79823386284613, 59.47532646117672, 57.42104784134896, 56.1029157330913, 55.14146827882337, 55.56720625969672, 49.234155224215606, 51.29553725642543, 50.966054239580714, 55.884322043388124, 57.13775857802361, 54.529582454312234, 51.298706531524665, 53.20482546283353, 63.756742554326216, 64.50496996602705, 66.00242107145249, 66.4515010772213, 66.55438484684115, 64.34141889695199, 65.78817729027041, 63.22071536894768, 63.04029418576149, 65.94506033005254, 65.34410615121165, 60.526086284268295, 62.57949021554763, 57.07267861212454, 44.32841547073857, 69.13073093660417, 51.62782476794336, 50.566152911032404, 53.199208628746774, 49.55579350071569, 54.81675878647835, 50.65131148984356, 47.90802540317659, 51.378009011668546, 52.08494171019524, 51.55674749805082, 54.32439150348787, 56.74800834348125, 56.42266342716833, 54.26041372360722, 48.93786330376902, 47.93570164711245, 45.84375258414976, 47.616875710025916, 49.53924109858852, 48.022182064671675, 48.429983046747026, 45.49050000406081, 48.03249789822487, 47.871390465767156, 51.83997792582358, 56.63093343857796, 57.26836958239156, 52.01325255055582, 48.1424968473373, 53.38871009888188, 47.79772443156089, 45.921403746451105, 45.33691175522343, 44.471283881895005, 43.762468445685606, 38.37370449496854, 55.35215447025915, 61.35073323403636, 59.30755492179625, 57.36622095108033, 61.538124469018754, 62.00663589662122, 61.11712078894339, 59.2105233284735, 62.25644380815568, 63.451401725892104, 63.70263345779912, 63.437265503791075, 67.55272219257971, 62.99634795035086, 60.3301638941611, 65.71041237923407, 61.795828111710094, 56.4849232089135, 58.82005137781943, 61.726511986024924, 52.43513091917961, 53.098493929832216, 51.54301528007754, 51.990067420467255, 48.30111749710576, 49.506909001258116, 51.05230323729977, 54.947789484454745, 54.144884232551824, 55.99429745827952, 52.59445759557909, 55.333181965735655, 52.93635491401919, 54.83910452935004, 54.09159098902057, 55.758100171242994, 55.65912308231477, 60.462547809846946, 55.82738099559661, 60.29888299203689, 57.78825229214084, 61.887286017017985, 58.34111821266913, 62.10875872642764, 69.21282614431074, 78.39715003967285, 78.17756791268626, 81.80938459211781, 78.63775607078307, 83.85154308811312, 83.40237679020052, 98.46032450276037, 12.306928673098165, 0.6380561234489565, 44.55705827282321, 95.40497072281377, 54.99121012226228, 75.43874940564557, 58.032133502344934, 45.210862467365885, 80.4884401444466, 13.248190629866816, 0.714445447008456, 0.20076768172364082, 0.29842927511180606, 0.25208294752144045, 0.20320437758439974, 0.283258221442661, 0.306893811230698, 0.15444323360439272], [0.003614932624435413, 0.007791671997702291, 0.13140726083469007, 0.04859170831379391, 0.04665094330125759, 0.06812470574532786, 0.17483039608886167, 0.14227110772363602, 0.7751599374798037, 5.841680034514397, 36.090182950419766, 24.232954017577637, 34.74112295335339, 52.71288179582166, 54.53880394658735, 58.09959826930877, 73.40475728434902, 7.060501162082919, 0.23277809873463648, 0.8177833535498189, 0.21106949586781765, 51.752520838091456, 66.40730381011963, 74.03883195692494, 73.52829625529628, 74.45455612674837, 76.80324785171017, 74.17317313532676, 66.62493259676042, 61.88126910117365, 60.46701538947321, 60.29927522905412, 56.7341584544028, 60.790607006319114, 57.72380382783952, 64.19229822774088, 62.96709099123555, 59.060508358863096, 56.04276618649883, 52.45297770346365, 53.008459844896876, 51.17600694779427, 49.78344394314674, 52.825704851458156, 47.845985274161066, 51.971004701429806, 48.66214813724641, 46.831158284218084, 44.58180842861053, 48.13268307716616, 50.45502431931035, 51.65745042985486, 50.00750933924029, 54.1411619032583, 59.54791776595577, 63.542467394182765, 61.0752377202434, 58.679183375450876, 52.13441064280849, 60.376192908133234, 58.35991421053487, 57.916819741649014, 56.66764682339084, 60.201616056503795, 60.68615821100051, 54.08006314308413, 50.56083025470857, 46.15678125812162, 65.20464627973496, 54.78396384946762, 53.676639526121086, 56.46576243062174, 40.927296915361964, 46.39835219229422, 45.26036277894051, 41.005206954094675, 43.46202665759672, 45.042655544896284, 46.15949553828086, 45.99190442792831, 45.89288811529837, 48.602147640720496, 47.94681372181062, 48.2496089320029, 42.153571036554155, 42.371537147029755, 40.17397434480729, 40.96393969751174, 43.008961523732836, 42.23497982948057, 43.92324639904884, 38.24931829206405, 40.59477798400387, 42.38817976367089, 46.65376517080492, 49.09442863156719, 50.225185194323146, 45.92207447175057, 44.353330366073116, 47.17574634859639, 43.49241718169182, 43.19716861171108, 42.697325291172156, 40.74008610940749, 43.82868982130482, 38.86981371910342, 36.28881177594585, 48.38438941586403, 55.30108128824542, 59.27151618465301, 54.02608740714289, 53.18965373500701, 54.40949516911661, 55.697695670589326, 58.18730638873193, 56.65464808863979, 59.825441145127826, 58.37592140320809, 60.172433622421764, 54.977011142238496, 56.67580927571943, 55.68177084768973, 60.81530224892401, 52.45609991012081, 56.10306086078767, 52.53170751756238, 47.935285875874186, 46.44787603808988, 46.68181796227732, 42.444418707201564, 41.308496382928666, 44.47932866311843, 45.74338305381037, 46.02026708664433, 49.104242401738325, 49.10673310679775, 48.83547767516106, 48.19770812988282, 48.491438742606874, 49.250131037927446, 48.58088447201637, 49.62070872706752, 50.59477052380962, 51.27663143219487, 51.582250748911214, 51.92730557534003, 51.89917433646418, 52.43369140932637, 55.065311539557676, 56.48351900039181, 63.279503853090354, 69.83786367600965, 71.62001609802246, 75.16102206322455, 75.55380821228027, 78.62423173842892, 76.39479575618621, 85.91296826639484, 12.56881062061556, 0.7340270220752686, 37.976419387325166, 80.80039408899124, 54.040266775315814, 56.949155330657966, 40.91958945797336, 24.469006176917787, 47.881537637402936, 7.621620239750032, 0.12635754631651988, 0.06884953217400659, 0.11051812689871558, 0.08320565215281903, 0.03203679724866825, 0.03722189865525692, 0.018618893659403248, 0.02858140937713606, 0.07723568983736538, 0.10633472758795946, 0.0615686746764808, 0.03657075456313549, 0.0568250582493361, 0.07728563877002848, 0.19119755815594427, 0.26131338770351104, 1.023649564914165, 18.63771846217494, 56.23275795290547, 20.364867487261375, 41.53136153374949, 67.51030568153628, 58.25834443492275, 66.96799093677153, 77.0103568415488, 8.54252411473182, 1.238236124477079, 0.5019103483326974, 0.14498672087586698, 61.21321101342479, 69.68772319055373, 77.40754388993787, 74.61105085188343, 79.54661630815076, 79.1462678294028, 78.60269792618291, 71.36294395692887, 66.38168288815406, 64.94487554796281, 62.608880535248794, 59.956766020867136, 63.26929000116164, 59.10845541184949, 66.26722028178554, 66.87169674904116, 62.948632317204634, 58.48329236430507, 57.307130444434385, 56.11769522390058, 56.45332067243515, 53.21909896789059, 57.22063825976465, 51.05400554595455, 54.41234280986171, 52.378723313731534, 49.901232719421394, 46.413029701479026, 49.30534232047297, 52.87968058739939, 53.60374227646859, 51.263785669880534, 54.186759456511474, 60.68405189821797, 65.87814469491282, 64.75265979766846, 61.94102641074889, 55.07357597351075, 62.1493709471918, 59.84675922701436, 61.350658709003085, 59.913266935656154, 63.077886181492964, 63.664892412001095, 57.425436973571784, 52.43210677177676, 48.41719611998528, 62.291592167269805, 49.20560429173131, 52.601749281729425, 55.027711699085856, 43.535053345464895, 47.550646489666356, 47.435493546147505, 45.790757440751605, 44.52741299906085, 47.669662967804946, 49.5402216911316, 48.12003343336044, 49.851030303585915, 51.97032613138999, 49.79414416897682, 51.600164213488185, 45.67069761214718, 46.01545826081307, 41.712394606682565, 44.16089104067895, 45.608182876340805, 44.96622031734836, 44.76245710926671, 42.25437594998268, 42.594033595054384, 45.2337847986529, 47.76265451985021, 53.081113907598684, 50.61204856441867, 48.081731488627774, 48.000609028723936, 49.11418953249532, 46.29201673692273, 45.08183610054755, 43.42205378317064, 43.815565570708245, 44.415421485900886, 39.98348443738876, 38.622578882401996, 46.84789111537319, 51.01326780934488, 60.922732045573575, 58.30476176354193, 56.188521462102095, 55.166453776821015, 57.51982488939839, 60.31991081853067, 60.03170682537941, 62.21356837980209, 61.43253426398001, 62.43163647190217, 57.81382614566434, 58.03492230753745, 59.78841789307133, 61.73944796285322, 56.040797156672326, 56.907833160892615, 55.850573970425515, 52.24004399391913, 49.81103389493881, 48.82183174933157, 45.202539197860226, 45.54803725211851, 47.59522422667473, 49.218002903846006, 50.09417803056779, 51.44696035692769, 52.54063875444474, 51.750473360861506, 52.455935170573575, 51.10438446844778, 54.09497991684945, 51.74100083689536, 53.01940325767764, 52.90459940510412, 55.016838888968195, 53.95053079051357, 54.93069579524379, 55.39724211538992, 57.78645192423175, 58.72948385054066, 59.84353111636255, 66.5777543283278, 72.99537166472405, 73.10539414805751, 80.36549737376552, 78.14350605010986, 84.98149948735391, 79.24720610341718, 91.48907246128206, 15.342570581743795, 0.8003791229378793, 42.537853487076305, 87.67031561943793, 57.183544405045055, 61.11195502742645, 54.00765226733301, 36.32714509963989, 60.72287944055373, 9.627370315213359, 0.5472650210703573, 0.07066824788888616, 0.08285636968550184, 0.04786358770704077, 0.08622419179206894, 0.054850029954386335, 0.045298231209838585, 0.02378840517673281, 0.1762725106410442, 0.18509271073966257, 0.1789252279746917, 0.15408885665237904, 0.17938569278245975, 0.18917815038754096, 0.34147039296165593, 0.5161537614560897, 1.412245335598146, 37.59243895930629, 70.33471030573692, 35.36548191501249, 47.93879247480824, 72.90701635422246, 66.49436473846436, 71.98186259115897, 85.74596158919796, 9.180718256581216, 2.832564134751597, 3.0004322624975637, 0.24438592425036818, 66.84715055650281, 71.15903562115085, 80.08052149126607, 75.53123104956843, 80.53137440835276, 81.6706189801616, 82.33270722050821, 71.7903018766834, 69.82979143819502, 65.90749971328243, 67.77137864020564, 62.6920190934212, 68.5378489955779, 61.97291920261999, 70.41565233661284, 69.73085357296851, 67.65380167192029, 61.05698300946144, 58.45416092103528, 58.973525877921816, 58.979017196163056, 56.37993312651112, 59.13399396404144, 52.64391868345199, 56.0439468199207, 56.13101559300577, 52.81367101976949, 50.843311509778424, 51.82562597336308, 56.08437861165693, 55.74778826005998, 53.62982211574432, 57.919777208758944, 63.217444112223966, 68.33863965926632, 67.56102192786433, 64.41873665778868, 57.08072339334796, 65.9633856434976, 62.204680288991625, 62.801119819764175, 62.05366511498729, 65.76519220106064, 67.87327397254207, 58.5158754933265, 54.08058089594687, 55.83780273314446, 56.1218725481341, 56.292601554624504, 54.16778302961781, 54.63986773644724, 45.97132767400434, 46.79898700406475, 52.61024121315249, 47.20256359346452, 47.24861221928751, 49.922307614357244, 50.17315495398737, 52.45449958309051, 52.27117192360663, 55.64796393917453, 54.41518260586647, 54.92666359870665, 48.406899898282944, 48.57810743393437, 43.742699700017134, 48.002836934981815, 49.23546529585316, 46.19676589965821, 49.097699888290904, 44.61620761502174, 45.339476985316125, 46.545507754049, 51.240145544851984, 55.72290082131663, 54.933347317480276, 51.81316460332563, 51.3053314147457, 52.78403359074747, 50.19103311723279, 49.10756857164445, 46.00717421500914, 45.77472671385735, 46.172211862379505, 40.962629625874186, 40.505124368975245, 51.30469599077779, 57.62370101867184, 62.99914852265389, 58.8346072935289, 56.85975666969054, 58.46175462968888, 61.73072461158999, 63.542557608696725, 62.6636407452245, 63.63496472758632, 65.98418989489156, 66.50172310490763, 60.93643288458548, 60.73012013589183, 61.90973766388432, 65.53095609911027, 56.635863857884566, 58.9435903487667, 56.40943719494728, 54.62497057453279, 52.91615078526159, 53.13658798894575, 48.375964164733894, 49.61279730642996, 51.644130060749674, 49.76059221452283, 52.85664842974756, 54.35659808497275, 55.68797211493216, 53.67538044529577, 54.47352001743933, 54.14707683747815, 56.26030475862565, 55.44501658408873, 56.461114421967544, 55.18692854912051, 57.571788449441236, 58.638394648028964, 59.37631014854678, 56.99387819536271, 59.77273625712241, 62.71963650180448, 64.01581118183752, 70.13783085730769, 75.71864189640169, 75.15819795670049, 84.26139939215876, 78.91972741773053, 87.06750223713537, 81.99626984134798, 94.67865759326567, 18.81412313830468, 0.889814249690502, 46.049892748555834, 95.60555288868566, 67.84902588013681, 75.37471279021233, 59.561748043183364, 41.17775594034503, 81.70106441743913, 16.375389483667192, 1.0536502421863618, 0.2497883303271186, 0.416752964618706, 0.14397704763518226, 0.20478941349973603, 0.1855590284591721, 0.09197417196006545, 0.15663950043099542], [0.08255115259558925, 0.02275295307739608, 0.015569603250872706, 0.004652564483319199, 0.027613798193933985, 0.005142814310778294, 0.07854832020858604, 0.08907891118959074, 0.2981587847875011, 10.49771091630382, 46.561848348186864, 44.07021368703535, 29.610315638203776, 45.05733305408109, 55.44654238608576, 59.452196244270574, 79.3992450160365, 12.263678658393122, 0.5789976699217674, 2.2115793920332387, 2.204428666060971, 56.14006842336347, 66.70090106225783, 71.49064064025879, 73.05866302982454, 74.01422300646382, 76.41861238787251, 72.04660523322322, 65.02502526006391, 59.74691529427806, 59.39321556398946, 57.51698117102347, 57.56887805077338, 59.3870182191172, 60.44403030026344, 59.28626037413075, 57.018902917062086, 56.206348634535274, 56.46645276777206, 56.74931057037846, 52.767179166117025, 53.48549850525395, 50.99205170908282, 51.407748422315045, 48.38741748563705, 50.61720648119527, 47.35128025854788, 46.86996229233281, 43.25004608400407, 45.71150202904978, 47.92396591555688, 52.2361804592994, 48.893371858904445, 55.60531993066111, 55.62906595968432, 59.40475909940658, 61.94261889303885, 60.06061861591955, 57.85406574126213, 55.6228058568893, 55.73988860653293, 58.18803987195415, 53.91407628213206, 58.47930723621, 58.369775049148075, 59.66196852345621, 52.46259535512617, 50.785044700868674, 55.141993876426454, 44.873644536541356, 44.47958361717963, 49.97535767093782, 40.19200155811925, 46.8149902743678, 42.07924996652911, 44.39088706047305, 43.43925337637625, 46.60861869012156, 45.796197768180605, 47.47956137503348, 49.84276194726267, 42.97875535103583, 43.96272113246303, 49.14237568455358, 42.27898882281396, 40.354160185783144, 39.33082949730658, 40.263486754509714, 40.006112590912856, 40.754257632840066, 40.92336277807913, 38.017231648968114, 40.1503969777015, 41.19386511464273, 45.62710046768189, 47.27341336588706, 41.26286352834394, 45.2728751397902, 43.207496212374785, 45.81733934340939, 44.75804052045269, 43.16256153968073, 41.089137831041896, 39.770731156872166, 43.72302116886262, 43.96199549398115, 35.52169030712497, 31.347651058627715, 29.986992612961803, 36.69107829370807, 54.08208316372287, 53.696274911203695, 56.44926886404715, 54.5155050677638, 56.16123353281329, 57.335814737504535, 59.3860690055355, 57.502990076618815, 60.62267464976157, 59.361534580107666, 55.0471588104002, 56.473803289474986, 60.66704842352099, 57.69698266060122, 51.81392946550923, 50.289782708691014, 46.8784071553138, 45.18496697948825, 44.25382767954181, 42.44705846232753, 41.68986451241278, 45.54840595491471, 48.38322839429302, 46.94296152360978, 47.87774862781648, 47.82505942929176, 49.024979145296165, 50.88683412921045, 51.2549917159542, 50.212351199119325, 48.96468054863715, 49.765365739022535, 51.21030807495118, 48.812790686084384, 51.06693760041268, 50.954518548903934, 53.17670206869803, 52.04676528130808, 52.22934769045923, 54.252368942383804, 60.8485717927256, 69.17288857121622, 71.20921842513546, 72.42267424060454, 71.16318548879316, 81.68198600892099, 75.3049102906258, 90.22002097099059, 14.000759124755861, 0.6435849493549717, 46.5093631129111, 74.44278901623142, 58.934302176198656, 56.28610218724897, 36.157647717383604, 19.266303777694702, 46.12465312404018, 5.85167815608363, 0.1656445422239842, 0.13170275626884353, 0.021216358816731843, 0.08784898767067541, 0.1709822751581669, 0.014471588581199608, 0.07083286486205555, 0.04008623628666805, 0.06604840828766746, 0.03602397845937841, 0.06803596978105846, 0.05570614470108863, 0.008239918181882992, 0.09361865629832591, 0.11481291539366208, 0.1504985855952386, 0.4036707262839041, 19.982736456778742, 66.00523733323621, 41.59432734212568, 27.74629354476929, 54.48714240904778, 58.63095391181208, 70.49469594032534, 84.2808465034731, 16.435907733055853, 0.9883152609390597, 2.6531894889570053, 3.288408267882563, 63.69856595993043, 70.88457169071322, 77.06572501890122, 75.70224638908141, 77.83770238199543, 78.82261737700432, 76.14198330909976, 66.59229847692674, 61.999869808073974, 61.98581203337639, 59.95819768598003, 61.56293346035866, 62.074979274503654, 64.36009722371256, 63.193894201709384, 61.026937653941495, 60.443579227693625, 60.86431618659728, 60.87789543213383, 56.149995942269605, 58.18840465238018, 54.33786484502978, 55.16116642182874, 52.238949652641054, 53.16835918734151, 49.963896505294315, 48.228914506973766, 46.00084350955102, 51.442920315650206, 50.02539926959623, 54.00820139915713, 50.581128520350305, 58.59742549157912, 58.12250883348527, 62.26264507539811, 64.14775579206406, 63.92603597333355, 61.64884513424289, 59.2087935632275, 57.74870303369338, 60.84681064851823, 56.632141528591035, 61.94456046627414, 61.196372278275035, 59.959350862810695, 53.2792289026322, 54.42169374035251, 52.7376280292388, 49.275716658561464, 47.46524080153435, 50.223549565961285, 43.860135462976274, 47.33758726427632, 44.18848099247102, 46.58805762567828, 45.693741536909535, 48.66466629889704, 50.25090809791319, 51.16999395432011, 53.17123820704799, 45.23571852714785, 46.38008179203157, 49.6912133309149, 44.45367636219148, 43.80985067736718, 41.428870001146876, 43.509114711515366, 42.83723623521867, 44.77156485280683, 41.853501873631636, 40.28820553133565, 42.16794652323569, 43.59536370923443, 47.64978047340147, 50.06970636306271, 45.68657928897489, 47.07812639974779, 47.29261729025072, 47.567081220688365, 46.876100801652484, 45.049500080846975, 42.983128793777965, 41.70637376846806, 45.029480303487475, 46.123346974772794, 38.12201776812154, 38.62729749371929, 32.07143229822959, 34.414232623192575, 53.43775933788669, 54.598412206096036, 58.35664295381116, 58.2739083997665, 57.4301948085908, 60.157956154115745, 58.766040340546645, 58.81077889473208, 62.32879584835422, 59.16531408986738, 57.84422451449979, 57.3955681247096, 63.42088568595148, 59.46766214986002, 53.678337912405695, 52.29000322280392, 50.68418095188756, 47.93404640689973, 47.957004039518296, 45.87186813354493, 47.01801999922722, 46.47740364074708, 49.04873301905971, 51.3059550716031, 49.869210489334606, 51.81320382702736, 50.75448943722633, 53.42646291179042, 54.4384854070602, 53.500128945996686, 50.956534647172504, 52.33597732359364, 53.06486745034495, 53.42873004175002, 53.44344285226638, 54.884553032536665, 56.58224897999918, 57.797438483084406, 57.09802889054822, 58.385178196814756, 64.85410405743507, 73.13849110757151, 73.41038980791646, 77.14450190144201, 76.10745860684302, 85.73971717588364, 79.68006318615329, 94.75920738712435, 15.468885610180518, 0.550833274760554, 52.225896004707586, 81.59233631626253, 62.217800617218025, 66.01836158383277, 42.0504048562819, 22.63167973487608, 64.96278901253977, 11.13973819440411, 0.4546658592599054, 0.10158197939275734, 0.04296410303082197, 0.04664235162518678, 0.05146743384219947, 0.032892180381402854, 0.058217622234576175, 0.010910086998445614, 0.14880956090506048, 0.09593838585480567, 0.12789856281972703, 0.10740926549319299, 0.0643143146449039, 0.2148293634696353, 0.1800575672138122, 0.2616554612834608, 0.49339684387368543, 30.364599189450665, 75.2153939585532, 57.138668567903586, 40.9506546297381, 61.45535069127237, 69.50814139458441, 73.6907059146512, 90.36284231370496, 16.315306617367654, 2.456898150905486, 6.744301251826748, 4.753945008400948, 71.69854194887223, 74.10165263760474, 80.85926102053735, 76.13507993759649, 79.63260250706827, 80.43825734046199, 77.30695862923899, 69.9800495947561, 65.4787846534483, 65.38769937330677, 60.998088621324115, 62.413111117578325, 65.5299323604953, 66.97678489069786, 65.3927396189782, 64.43719925418978, 62.28334342279742, 64.07278360859041, 64.05481130846086, 57.335049875320934, 59.12769071517452, 56.49180304619574, 57.58256320030459, 55.16306877136231, 54.17412550218644, 54.91069562973515, 51.61654403132778, 50.39743215807023, 52.805755676761756, 51.74249525993101, 56.68505430221558, 51.3209032243298, 60.81461583414386, 59.54850612148162, 64.9657190230585, 68.29619961400186, 67.31762316919142, 63.37024004228654, 62.23629459258049, 61.68439749748477, 64.9432046182694, 59.73897641704929, 63.56402474064981, 62.690622729639855, 65.20210458386329, 54.75325561338856, 51.42311234628001, 57.44340142896099, 50.74814696465769, 52.82354362549321, 53.221687732204316, 45.168202769371774, 50.40704588736258, 47.89646617827877, 48.3749992616715, 48.28393359338084, 52.74151117570939, 53.78910956844207, 55.49785091030983, 56.94126744424143, 47.65928045395882, 48.35672493903868, 54.09699993748819, 46.59412160996468, 44.2830571820659, 44.33465596168272, 46.508966953523704, 45.03111593184933, 46.23917848833146, 46.9093938796751, 43.228037664967204, 44.99142154570549, 46.22948631163567, 51.12297258069439, 53.51098214426349, 46.5341446476598, 52.18129473347818, 51.34480614815989, 53.89702966136318, 49.977487517941384, 47.59101944585001, 44.48101135992235, 44.23469435784125, 49.02659908417733, 47.37069599090084, 38.31490032134518, 37.412982679182484, 30.445660852616836, 40.550870972294966, 57.26403536335115, 55.899901697712565, 61.418602005127944, 58.84952798966439, 63.072128142080004, 62.62134582765641, 62.071770775702696, 60.69062971299695, 66.94263673597767, 62.377362635827836, 59.1137663010628, 59.28429918904459, 65.82020344272738, 62.954747292303274, 55.2760487218057, 55.54573520537346, 53.65387408964096, 50.26126315516811, 51.30012642952704, 48.46976764740483, 50.22938605277769, 49.29884295309744, 54.92815409937213, 53.84771370118665, 52.30837952706122, 53.87033400997039, 53.1705714041187, 56.50266016683271, 57.04328044768303, 57.81413209053778, 53.25998183219664, 55.491406456116714, 56.12412006624284, 55.958450917274725, 56.81350800298876, 57.859357018624586, 58.62943595455539, 59.11140503421907, 60.023693423117365, 60.61834827546151, 65.89422641261932, 75.4750862429219, 77.92539088956772, 79.25651781020626, 78.50525056162189, 88.23705888563588, 81.52036082360053, 98.177262736905, 18.612468204190655, 0.8549357986738606, 56.550324809166696, 86.81904362094018, 73.86134470662763, 76.075499134679, 48.70614536346928, 31.747846564938946, 81.39530781776675, 15.662439869296168, 0.642646583578279, 0.29311057180166245, 0.11619962646716064, 0.15862089491659598, 0.2667526119659024, 0.19665159855879125, 0.15426108853951578, 0.18006807794013333], [0.10815511337451397, 0.06678540785346301, 0.12090811010209784, 0.05163022752610907, 0.08392431923458654, 0.05900363227532757, 0.19102944782184017, 0.15860686018582315, 0.5188106769515622, 10.477660740575484, 61.80075460864652, 43.84791727988951, 53.11556800719231, 46.18011543827672, 46.68546968890775, 54.72777589674919, 83.3907195060484, 21.925715861781953, 0.49723825387416354, 0.4850850350433781, 6.222206325300279, 63.46012507715533, 69.76636671250867, 75.25115028504403, 71.42416431057838, 77.46655987155053, 73.7659683535176, 68.4836575292772, 60.662200373988, 61.285696414209184, 56.03609815720589, 57.61117689071163, 58.00138212019398, 59.88404135550223, 58.217810661562034, 59.516146567560014, 58.488634632479766, 56.59331790862545, 56.16130021310622, 56.15440468634329, 54.53056304685531, 53.67993039469565, 52.26488436422041, 49.73442608310331, 49.64343493984592, 50.69828579502721, 49.113620788820334, 46.94132197287775, 44.42104616472798, 46.59329006748815, 48.798328907259055, 52.163675446664136, 52.74298206452401, 54.88135237847605, 59.06735289481379, 61.0082632495511, 60.23301855210335, 61.357503244953776, 58.74390248329409, 57.42163619687481, 54.2949031245324, 53.612375413217855, 55.35437060940651, 57.27166045096613, 57.447119835884344, 52.60839377680133, 51.89148649092644, 56.46038878348566, 45.144613635155466, 43.70497042132963, 46.5349801125065, 44.768705444951216, 40.223670774890536, 42.114598366522024, 44.106421086096, 44.951801684594926, 45.53263410445183, 44.40543905381234, 47.70910632225775, 48.16827074173958, 49.38709628197455, 48.234621555574485, 43.64645650309902, 47.46577424387778, 42.04614123990459, 43.33513406015212, 42.07021282565209, 39.14340296099263, 42.91291052295316, 45.76634068642893, 40.01061939424084, 37.10215053250713, 38.66552099104851, 41.6733552563575, 45.44862870247134, 47.34438080941477, 45.88100333367625, 48.244502006038545, 47.453077531629994, 45.33559776121571, 44.37145171626922, 43.11330833742696, 41.438573944953184, 42.46117115020752, 44.63860827107584, 41.3196986721408, 42.353925704956055, 41.846516132354736, 49.910626795984086, 41.48651315319923, 40.72166273670812, 52.96178363984632, 47.82989571171422, 52.58232570463612, 55.76598805765952, 58.84704905171549, 57.48388813387964, 58.75603045186689, 54.09679597423923, 58.43733003062587, 54.938356184190326, 56.84635393081173, 62.21506672520792, 58.38529586791993, 54.05300271126532, 52.0388577830407, 50.390222841693515, 43.32497119903565, 42.83566728714974, 42.825849594608435, 44.390608572190814, 46.82017172536543, 47.04107176872992, 47.326333984251946, 46.62101337986608, 45.834868415709465, 47.13909572170627, 50.115833436289144, 48.623438266015825, 49.527717175022254, 52.294411966877604, 49.20432559905514, 49.349221875590665, 50.52544263101394, 50.75436784375099, 52.17788227142827, 53.447906509522475, 52.897146901776715, 54.28711721974035, 57.001950433177335, 59.78325997629474, 69.92020991540724, 71.9484204630698, 74.97821607897359, 72.23041534423828, 78.48621137680547, 76.83129279844223, 81.41490397914764, 11.70744244129427, 0.569721203177206, 51.540708926416215, 73.42384353760751, 55.90830341462166, 56.34040740228469, 37.038412017206994, 42.37535361320742, 55.462133807520715, 7.633131415613237, 0.1808824906906774, 0.08496282036386191, 0.13348072376703063, 0.0788706057374516, 0.061601807979205926, 0.042607768724161776, 0.08343101989838385, 0.09698592682158756, 0.07290419806996662, 0.024397291858950933, 0.06729557644575834, 0.01763968773546719, 0.030719135595004887, 0.027464393811720996, 0.07770885638291798, 0.11248481249616993, 0.4762946664085312, 12.315498071332133, 77.87215648158904, 44.27296884598271, 46.88949569579094, 55.63960144596716, 54.01951743710426, 62.29259629403392, 89.65925539693525, 26.86598816225606, 0.49518660912590645, 1.0694098352424561, 7.994668041506122, 72.6588087697183, 74.10064851084064, 79.81364342474168, 74.39909381251182, 80.98814225965931, 76.54620708957796, 72.36215206884569, 64.0846017099196, 62.99117434409357, 59.45178831777265, 64.16130365863924, 61.23072831861435, 63.75644445419312, 61.46614505398659, 65.62563427032964, 62.58762128891484, 61.66562111146989, 59.72929208509384, 58.277567971137266, 57.36509915321105, 57.39119860433764, 54.92815017700196, 53.66473121027793, 55.06215010919879, 53.754478962190696, 52.315200528790875, 49.12170479374547, 49.05758188616846, 49.92550826841786, 51.033852408009196, 55.220096111297615, 55.5022321977923, 56.445319037283625, 59.970117768933704, 63.70108804395122, 63.789812057249016, 62.306528552885986, 61.24053816641531, 58.404131089487386, 55.74375606352284, 54.16749277422505, 58.56457564138598, 59.75565825739215, 59.46317103601272, 56.68456008357387, 55.36543561566261, 53.7062494985519, 49.654335206554784, 44.919606870220555, 46.50511126364432, 46.68503038344845, 41.79437606565414, 44.994661423467825, 46.64386510849, 46.881898064767164, 48.26914625783121, 47.11763251212336, 48.30895047033987, 53.438194720975815, 52.985765011079856, 50.40326472251646, 46.76764334401777, 49.44731643123012, 43.59548922507994, 44.224613866498395, 43.841504204657774, 42.7873162300356, 46.25804116649013, 46.879168095127234, 42.65661501115368, 40.59013782009002, 39.7059061450343, 42.867783654120664, 45.14626495299801, 49.98392804976433, 50.54442690264795, 51.4065089533406, 53.05662655061292, 49.415254977441606, 46.656667724732436, 43.95983819038638, 43.24088734965171, 42.97387592254147, 47.07772239562004, 44.44631407337804, 45.19516514193627, 45.08372276060043, 55.70550510960241, 46.1763225063201, 40.79907071205878, 53.87803362261865, 49.77944312557098, 52.99027181440785, 61.30016603777486, 60.07161301951255, 58.451462330356726, 59.14112091064454, 56.64452445122504, 60.78142866011589, 56.11461616331532, 57.702038595753336, 64.22657582067674, 61.99039336173766, 55.68613252332134, 53.37540541925738, 51.60175669577814, 46.81939509607131, 47.148870268175685, 46.334696046767704, 47.849746827156316, 48.93392916648619, 48.92142465037685, 50.490863015574796, 51.360574076252604, 52.97759079164075, 50.791924538150916, 52.18767642974854, 52.546836099317, 53.786516881758175, 54.32538778551164, 53.58500119178526, 52.70958700487691, 53.08695039441509, 55.160958536209606, 55.01556804103237, 57.70197583783058, 56.91916488832044, 58.18592963680145, 60.10540031617688, 62.85053383919501, 75.23936748504639, 75.07316881610502, 78.22336550681823, 78.34176617283975, 81.02344359121015, 79.30372745760026, 87.86983874536331, 13.025609850883486, 0.5714392013126804, 58.708173613394464, 80.01218595812398, 63.752231828628055, 64.05483484268188, 44.34408533957697, 43.99525719304239, 68.28586809096798, 13.289092125431186, 0.564372132141744, 0.143919836188997, 0.16854755580425265, 0.022109847162820162, 0.130440044186769, 0.07655981642704818, 0.0840956088335764, 0.009582312026571844, 0.19707380493562068, 0.1472324003735858, 0.25995572668410116, 0.21951924648977097, 0.208671901134714, 0.14616856471665446, 0.3520586780242382, 0.33120429383650907, 0.7544048382870613, 21.000183589996833, 93.00313872675743, 55.69486764169509, 71.07780333488219, 61.84190027175411, 63.87147580423663, 65.41736818129017, 96.03027497568439, 28.125490642363026, 0.9155356823917359, 3.551927559798764, 12.118868674001387, 76.7334218179026, 78.25465033131262, 80.74693218354257, 74.55044238798081, 82.8214894571612, 78.69117875253, 73.87171545336324, 66.7639413956673, 66.89166161321825, 60.96669789283507, 65.79416282715337, 62.70102093296667, 65.3900174940786, 63.518274214959916, 68.38708877563477, 66.15484437634869, 61.60761317899151, 62.636317514604144, 60.834106091530096, 59.48613259100146, 58.212154603773556, 56.95663529057657, 56.57757743712395, 56.926162396707845, 55.66340631054294, 55.46083942536385, 51.56487072667768, 50.776340961456306, 52.67742749183409, 54.14915177129931, 60.838848237068426, 57.511850710838075, 59.581854112686656, 62.876303811227125, 68.52663101688509, 67.11140063501173, 66.00703377877512, 63.185119859633915, 60.84701853413736, 60.972149987374586, 56.8687310526448, 62.917539688848684, 63.23723639211347, 60.44706229240664, 57.82940972235895, 53.649245692837624, 57.89918084298411, 51.225342519821666, 45.21803648241105, 48.51553386257541, 53.253996295313684, 44.93888924198766, 49.34118493910759, 50.456648180561686, 52.89489546129781, 50.03322439809, 49.34753917878675, 53.11137891584828, 55.49201050112325, 56.27466847819667, 53.76968206897859, 48.321627570736794, 52.830788243201475, 47.370315520994126, 47.56718712468302, 45.869883414237734, 46.25691544625067, 49.891783729676284, 49.92725372314454, 46.025146515138694, 42.33216439524005, 43.916664661899695, 45.21313351969565, 49.05248280494444, 51.32922257146528, 51.96539963445356, 54.19812648527084, 56.86636194106072, 53.259468001704064, 49.33551711420859, 46.24797244225779, 45.134415472707445, 47.288271304099794, 48.715680645358184, 46.87936813600602, 44.757048160799094, 44.35551120388893, 50.41077998376662, 38.44589571799002, 40.59043984259329, 57.37867055400726, 53.40443488090269, 55.966648670934866, 63.964098653485706, 62.91897135396158, 63.453755147995494, 61.894095251637125, 60.05642167983517, 62.265347588446836, 61.98769084868893, 63.1921212903915, 68.2042984808645, 63.78968261903333, 56.90951585769654, 53.7867679134492, 55.55769451202885, 49.46875218422183, 49.941880241517104, 48.92468806236021, 51.89094520384266, 51.921947617684644, 51.50484277356056, 54.79678215519075, 51.97365230129611, 54.39513929428593, 52.930840061556914, 56.119452445737785, 52.75956584561256, 55.91433209757651, 60.117379234683135, 56.87181011323006, 55.08966945832776, 54.918442310825476, 58.54539525124335, 58.48019369186894, 61.33320808410645, 58.894137105634144, 61.4199826794286, 63.23367487999701, 64.6184519798525, 76.57246343551144, 78.9098273554156, 81.64274661771714, 79.67921595419608, 85.44787714558264, 82.5726935171312, 92.72262650151407, 16.308144369433005, 0.8646165146943062, 62.53721883220058, 86.59623730567195, 74.97026151226413, 74.17308684318297, 53.32825852978615, 64.45429294340073, 81.21367069982713, 17.603067813381074, 0.8833136565742955, 0.33429312970369096, 0.3028419109121446, 0.25694742197951964, 0.19599170574257452, 0.13783496834578055, 0.18463163306155514, 0.29112447353620685], [0.11731188654178575, 0.013792082956511409, 0.039618688996040055, 0.05457117778038787, 0.05093407193799654, 0.08378885190693602, 0.035448401280108004, 0.08979618399133606, 0.17166760209346973, 3.2747920049775034, 59.206181264692745, 42.63148046308949, 31.40119141147983, 41.314077915683875, 50.41853450959729, 52.30087211055141, 83.30473330713089, 26.35544461588706, 0.029522902707779602, 0.4527212523164288, 4.281280281082276, 63.8178530816109, 66.42553498668056, 79.74734752408921, 74.60302568251088, 76.26000742758475, 69.2389020612163, 63.756083596137266, 58.24390619031845, 59.36682977984029, 56.43303025153376, 60.26648813678373, 58.53710336069907, 60.94652514303885, 61.044564785495886, 59.6654123644675, 59.11357018255419, 58.447277161382864, 57.5803941295993, 57.23924598386211, 54.42689872557118, 53.361708502615656, 50.66967210462017, 50.649942582653416, 48.358454704284675, 47.69335016127556, 49.46976023335611, 48.34276914596558, 43.406760461868785, 44.105946479305146, 47.98120898585166, 49.564493317757886, 48.63025926774549, 59.590683367944536, 55.15538877056491, 54.85705329525856, 60.849599453710745, 62.78165701896914, 59.079998616249334, 58.50232370438115, 53.89777491169592, 49.069623562597464, 50.870740644393436, 56.13430253921017, 57.73957960067257, 56.250137975139005, 52.677878564403905, 44.84484649473622, 42.39684427938154, 52.46554497749575, 40.01705208132344, 38.36287483092278, 41.37937753431259, 40.15523718249413, 42.81120738675518, 46.6873602713308, 45.82183045725669, 44.552916249921246, 49.060562887499415, 54.27294569630777, 49.512219890471435, 53.99010750555224, 47.44482878715762, 44.05750128530687, 43.1258128535363, 40.35880427206717, 42.97080470669655, 40.772033814461004, 45.26412040956559, 46.56327609092959, 39.573573220160704, 39.78227469228929, 39.525222163046564, 43.82135106671242, 43.473150499405406, 47.89181424725441, 52.09837582803542, 53.95937573525214, 49.03769546939481, 48.78974283895185, 42.032765957616995, 42.449003957933, 42.39226687339045, 43.969400928866484, 40.7866564104634, 40.128757261460834, 42.29245039724535, 44.03929756533715, 42.430725712930005, 63.22675581901305, 56.87121783533404, 45.0656053327745, 46.939466691786244, 45.89029935098464, 56.62858393884475, 57.61045125222976, 55.73267929015621, 52.01899490048809, 54.852691619626945, 54.43338240346601, 50.92830534904234, 58.795913111779, 59.17911691050376, 58.240662390185946, 56.10819132097306, 50.17222142988636, 47.514972532949145, 45.03709754636211, 43.03072283344884, 41.61912456635506, 42.44576408017067, 47.73315829615439, 49.08199079575078, 47.592164777940326, 47.26411734857867, 48.315916599765906, 48.94408810523249, 51.24676258333268, 50.128808636819166, 49.79610927643315, 50.332528698828916, 49.61462905330043, 48.51286272848807, 52.94931834743869, 51.638689733320675, 53.48732240738408, 53.58863330656483, 51.77602368016397, 54.48706003927416, 56.05825954867948, 60.5372218931875, 70.52339984524635, 72.19094845556444, 77.85909498891523, 75.11197674658992, 78.02727053242346, 72.80239889698645, 76.28870348776542, 10.943408858391548, 0.33061740919947624, 54.86546677927817, 67.99465563989455, 61.72877911598452, 51.19898811463387, 34.737435925391416, 31.692931421341438, 55.26309313312654, 10.492241171098525, 0.2699438891103191, 0.06606662585850685, 0.08976001698043078, 0.016221530667896715, 0.1067386934113118, 0.023832905309034452, 0.04528630705129716, 0.08465093064812884, 0.07904954855480502, 0.031011357918501865, 0.04947273240935418, 0.07549357525403462, 0.048119813474195625, 0.07328773998925764, 0.030859120926188848, 0.0581659572649627, 0.2429837688443161, 4.433767814790049, 70.84603048140004, 45.6652965084199, 31.7395644803201, 54.56540153872583, 54.014912574521965, 57.80476154819612, 90.59481913043608, 31.669369743716334, 0.09149070919281052, 0.41539089093285225, 4.5859445006616655, 74.68556019567674, 72.25093718497985, 80.16316583079677, 77.33643131871378, 78.65607353948778, 72.28216709629183, 67.96803843590521, 60.927725222802934, 61.80157046164236, 60.11817547582812, 62.94799689323672, 60.283268036380896, 64.70555213189894, 62.27997802918958, 63.00669516286543, 62.87505649751233, 60.933247920005556, 60.87363966049687, 60.812423229217536, 57.36540117571431, 56.36076842584918, 55.510198531612275, 53.519705495526715, 51.049169263532086, 50.39844805194486, 52.15009620112758, 50.583838878139375, 46.51478775085942, 48.26040721708729, 51.18011366936469, 51.87009388400663, 53.365717164931766, 62.20019309751449, 56.50004002355761, 57.398588349742276, 63.90137995443037, 65.73317389334402, 61.91449942127351, 62.40728639787244, 57.76330994021509, 54.4021995605961, 53.54285140191355, 57.218151477075395, 59.20880140796785, 57.35765057225382, 53.76026445819486, 50.44057430759553, 47.368570066267445, 51.628742602563676, 42.45710365233883, 42.034425120199884, 44.950695576206336, 43.51096214786653, 45.2108742344764, 47.13960562982867, 47.227435342727176, 45.45466130779636, 52.39213389735068, 57.048497200012214, 53.511162573291415, 56.98314659057125, 49.543190925352036, 45.97217098359139, 45.49695230299427, 44.055618547624164, 45.079808235168464, 42.71368157479071, 48.352782957015506, 50.782099000869266, 42.99723755928778, 41.564187849721606, 42.642204223140595, 44.1945763557188, 46.156239971037834, 49.15340146710796, 55.14855600172474, 56.51835356989215, 54.15191311990061, 52.565628174812566, 45.73177676047049, 44.216090556113954, 44.1790202356154, 45.09283050414055, 44.249979834402765, 41.91476537335304, 45.16104836617747, 45.20247643993747, 43.09174706858974, 60.26746088458646, 59.76531513275639, 46.90101177461686, 50.617618330063365, 46.64810519064627, 56.163010366501354, 58.95607525302518, 57.940542236451186, 53.27642833032916, 58.7768425480012, 56.061852439757324, 54.21397678313717, 62.332435807874134, 61.16684467561784, 60.633147378121656, 57.674817346757465, 52.30819909803329, 51.180921677620184, 48.29476717979678, 47.64281434397544, 45.243433829276796, 46.22598363507179, 51.14616163315312, 51.54242300218152, 49.668612633982015, 50.15902265425652, 51.703357850351644, 51.55403714026175, 53.72295095074562, 55.11817724474015, 53.550170544655096, 54.16146801364038, 54.075936809662856, 52.97278196580949, 56.54905003886069, 54.92314523266208, 56.98985384356592, 56.19028260630947, 56.09213705985777, 57.949034167874245, 59.23491262620496, 64.25733896993822, 76.02854051897603, 75.7481538095782, 79.45116150763728, 78.15243336462206, 83.8834241128737, 75.33162163149926, 86.32400128149217, 14.151743900391365, 0.3905389067386428, 61.447713836546875, 72.78979239925262, 70.41923738295033, 62.22752417287519, 41.81492928535708, 36.173568617913034, 71.57989025115967, 14.056222419584952, 0.5093582244890352, 0.19249580139594694, 0.13610978430557635, 0.024702169954957023, 0.05495131443885546, 0.020553091383208672, 0.04814974069895764, 0.0625042557235687, 0.15609491916914142, 0.17405712225985143, 0.12653072049180347, 0.1495438715022418, 0.20060563880589702, 0.3720038077763973, 0.12846523805731727, 0.26658125341899935, 0.4108389497043625, 8.863152380912535, 88.00906719699984, 53.0950108651192, 43.173971714512, 58.07874694947274, 67.62240702106108, 61.84071179359191, 96.25939630693006, 34.12818201126591, 0.44713659392249205, 1.0181799422829383, 5.6284688172801856, 77.06002973741101, 73.72829006564233, 82.74641529206308, 80.67668253375639, 81.92858542165449, 75.49372534598075, 69.28216580421694, 63.94270604656589, 65.52898314691359, 61.913118746972856, 68.10511742868732, 64.37458645912909, 66.6664626521449, 65.26894177159956, 64.59700445975027, 67.68523554648122, 64.42195692370015, 64.09544706344604, 62.588805844706876, 61.113276866174516, 59.334474148288855, 57.672871851151996, 55.76184995712773, 53.57242607301282, 52.4836310263603, 54.97261808764551, 52.55276672301754, 48.06525753390405, 52.52183883420883, 54.07739593136696, 55.485326782349624, 57.07195297364266, 66.36537367297758, 61.3301407906317, 60.088671407391956, 64.58817128212222, 68.53565246828141, 64.58879886134979, 64.93061381001627, 59.827782800120694, 58.08101015706217, 57.53702056023383, 61.85766819984683, 63.9956384320413, 58.48932104725992, 57.873975692256806, 54.77143972150741, 49.4625077709075, 53.91927342261038, 48.763443346946474, 47.02975180841262, 49.33188107705886, 45.57748640737226, 47.394575380509906, 51.96432882739652, 51.12370606391661, 47.75855172064997, 55.53986733959567, 62.85989653679633, 59.35535684708626, 60.96647824010542, 54.14957538727791, 51.27152450623051, 48.54855629705614, 46.0037656753294, 48.85338721736785, 46.33551189976354, 50.98860786807153, 51.287657214749245, 46.46901369094849, 44.161655902862556, 44.41123239455685, 48.060868401681226, 47.359317195030954, 52.67264220022386, 56.92199291721467, 60.305268610677416, 59.13763784593152, 55.11162296418221, 47.318630449233524, 46.5661511882659, 47.7274198685923, 48.43541552943569, 46.26365800057688, 43.66278925249654, 47.86719745205295, 48.78207852763515, 48.626521248971265, 62.86840023532991, 54.581389119548184, 47.59135284731465, 52.95782204597227, 49.07196913996051, 59.24185129903979, 62.59015121767598, 61.167154542861454, 57.64767846753521, 59.72869588482765, 58.00557121153801, 58.92666139910298, 63.24751300196495, 65.68473262171592, 62.681314945220954, 60.65077450967605, 54.96177273411905, 55.069700671780495, 49.6444429889802, 49.08845878416493, 47.793131336089104, 48.83101401790496, 52.55723430264381, 55.35085224336194, 52.99468055848153, 53.02275688417497, 53.59763906848047, 54.93137828765377, 57.92676295003584, 57.72642397111463, 55.02178499775549, 56.507665111172585, 56.9167761648855, 55.84205458241125, 59.730115782830026, 55.89493989944459, 60.83594568314091, 61.251195246173495, 57.133145870700965, 61.18285579066123, 62.05494380766346, 67.00221753889515, 78.07338976090955, 78.89817791600382, 84.3322217079901, 81.57292058390956, 85.04265708308067, 77.26141991153841, 85.71794802142729, 16.53522606818907, 0.4313131091335128, 64.91130005928778, 80.50396488558862, 79.93853953576858, 69.16964084871354, 49.66467849669918, 51.43921759820754, 86.80853951361873, 18.943682947466453, 0.7019747613418488, 0.3030402357539823, 0.2154167843682151, 0.17829849144383786, 0.23782540773672445, 0.219031585560691, 0.1922840853371928, 0.1366437016235244], [0.019732557590149587, 0.12283328905581467, 0.07615860852022326, 0.12194128692029946, 0.026895020029417453, 0.046519578374441595, 0.05586587786374073, 0.10043868509631965, 0.09248604892843193, 1.1514446139335632, 48.81634827583067, 51.11589270253336, 29.641290595454556, 33.32571214245212, 60.50821988813339, 50.375459040364916, 81.02899766737416, 37.22261828760947, 0.08842831101989554, 0.19865704820521418, 9.939342891016315, 67.16843974205756, 66.69601378902313, 76.71828146903746, 72.92297255608344, 73.5404634475708, 64.50646046669253, 61.45202452136625, 56.61918986228205, 57.47125025718444, 58.53479308466758, 59.620512993105, 58.22048571801955, 61.00841622198782, 58.86562539685158, 60.29786317579208, 56.76007747650147, 58.58305784963793, 56.4058207696484, 55.65674612599035, 53.53322198314052, 50.12213276278589, 52.948063188983554, 48.72813809302546, 48.64109677653159, 49.03808770641204, 47.41430098010648, 49.20933054339502, 44.95231159271733, 45.887243824620406, 45.196283017435384, 48.28628701548423, 50.52946306044056, 50.708938952415224, 53.95040135229788, 50.71744657331898, 56.71154206798923, 59.679662335303526, 57.707157288828206, 62.81547961696502, 57.65651948990361, 54.9633103032266, 50.409536592422, 50.47575404567104, 51.121074153530984, 47.54648093254336, 37.03350120975126, 49.02028014582973, 55.11281144234442, 51.673328184312396, 42.46572502197758, 40.76409493723224, 42.59586141955468, 42.39671484116585, 44.061784513535045, 43.55685387888263, 43.66695480961954, 44.18995972602598, 52.48918902489447, 54.05320275214411, 50.513793191602154, 51.869529062701815, 47.48586462390038, 45.9002935501837, 43.9953827088879, 41.69733662759104, 41.80476642424061, 41.660854662618334, 49.70667923650434, 52.290540587517526, 44.6111124561679, 40.526132583618164, 41.845963078160445, 41.47706808582429, 46.64457897986136, 48.4576436012022, 53.10462459441155, 49.62640400855772, 50.62151324364447, 52.99287234583209, 43.752807647951194, 43.008145670736994, 41.267170290793146, 40.46379043209938, 41.034232493369814, 41.73312041067308, 42.414498867527136, 43.34270815695486, 36.4922062812313, 33.21623094620244, 58.67183285374796, 58.15186777422505, 43.32845426374867, 47.026178529185636, 48.3592156440981, 54.708948519922075, 51.89044706283077, 51.39883679728354, 53.63238342346684, 49.48156656757478, 53.840735804650095, 60.46963945511849, 58.59365609384353, 55.71606413010628, 53.39870822045111, 47.14425756085304, 49.08237518802766, 45.926538129006666, 42.908415486735684, 41.145404231163766, 46.86541234293292, 49.9253317617601, 50.08195984748102, 48.13786060579362, 48.74733417264877, 49.26687563619306, 50.81167367196853, 51.771116795078406, 49.716653823852546, 54.19600448300762, 51.70988467431838, 52.459300564181426, 51.58345099418394, 51.43052954827586, 51.150805719437145, 52.26245641708375, 53.153799349261874, 54.14868893161897, 52.40477569641606, 55.44207088408932, 58.65719456826487, 70.37971558109408, 74.59945632565406, 80.11153174984841, 73.21994304656982, 80.95776742504489, 72.5011844019736, 83.02575080625473, 14.698193803910288, 0.15324571560467445, 60.557520158829234, 68.07980245159519, 59.26973150622461, 54.12712766278175, 34.60392236709595, 29.67519360203897, 62.68187584415559, 9.70516562461853, 0.1313073629693639, 0.01345635737262426, 0.07943636933041197, 0.03513113745758611, 0.06524436070673889, 0.10093757687436958, 0.10481941333461194, 0.04269075519855946, 0.033067093576274575, 0.06852667974007708, 0.08798610974824236, 0.07335559239671116, 0.022856985902293556, 0.05239083792173094, 0.05136446779473655, 0.0360706523661652, 0.039235576085986636, 0.9931514820744916, 58.168231902583955, 56.67504049116566, 30.48213105047903, 46.601440752706225, 66.15264784905219, 58.831347803915705, 89.79848384857179, 39.69251125089584, 0.08846944228055016, 0.2691265039386288, 12.59659472973116, 75.61364789162913, 73.13998945297735, 79.66197321491858, 77.47868784012334, 75.33755225519981, 67.97054090807515, 64.091485469572, 58.62279145948349, 60.74513889128163, 60.49153020305019, 64.042067527771, 63.388502597808845, 62.96286659855997, 62.32693664489254, 62.717938115519864, 60.77536075345932, 62.079807712185776, 60.19658365557271, 59.828331931944824, 56.26271701628163, 54.71263162551388, 53.35122008477488, 51.078834149145315, 49.254763357100956, 53.12981013328799, 50.908218891389915, 50.77579575200235, 47.96271893285936, 48.27746952733686, 49.630691159156065, 49.84251483794182, 54.319225741970925, 55.1965501231532, 56.33899534902265, 50.984524680722146, 58.55742123819167, 63.06099645553097, 60.63457904323455, 65.32896580234652, 59.81054398321337, 58.10306172217093, 55.38430221619145, 54.20705379978303, 54.0602316394929, 50.04148098730272, 43.873091051655436, 52.172379186076505, 57.85256739585631, 52.494052763908144, 45.9983959505635, 43.747171202013575, 43.87060426896618, 46.41100575847011, 45.21480837175923, 46.280084886858546, 47.02308377911968, 45.04631511626705, 52.581031322479255, 57.601508248236875, 54.63237208704795, 52.641773146967736, 51.41225522564304, 47.37644226320329, 47.905142461099935, 42.65294759504257, 43.412683240828976, 42.60696957188268, 50.87346669166319, 53.89490373672978, 48.32573429230721, 40.940079919753536, 43.56977416623024, 44.70357841061008, 48.80889577250327, 51.72108696353052, 54.43435122889858, 51.7202240420926, 55.71684860414075, 56.551183808234434, 45.46821701911188, 43.38956871340352, 41.900550703848566, 43.1304883187817, 44.09194361778998, 43.76428058070522, 45.68894840055897, 45.61096775916315, 42.46956502237628, 39.22081093634329, 55.95420299037811, 54.82278354706303, 45.275860063491336, 49.45393346971082, 50.59201309757848, 56.986080523460146, 55.074976259662265, 51.897338667223536, 55.47900784400202, 55.50701748940253, 60.379899547946074, 61.51028740790583, 62.30706983996976, 59.89096826122653, 54.64538258890952, 50.126725858257664, 50.70246311926073, 48.01012862113215, 44.41620203756517, 45.02171401054629, 49.12357576431767, 52.65188893964214, 50.972953688713815, 50.781392974238244, 53.04584003263905, 52.48349374340427, 55.157326421430035, 55.645743877657004, 53.57619154837824, 57.08549691784767, 55.75872382810039, 56.97505866327594, 54.40097185873217, 56.69948862444971, 55.282493175998816, 55.96428740409113, 58.01436516546435, 58.024818281973566, 55.20553627321797, 59.854804008237785, 62.09304571151734, 75.56885442426129, 76.60142621686383, 84.4464332826676, 78.481488843118, 85.21073848970475, 73.34066575573337, 89.68639035378733, 21.151049713934622, 0.11555438125205618, 68.68234126798569, 74.17160418725784, 67.50587340324157, 65.87327311115881, 42.93892760430613, 31.28632283979847, 76.56275164696478, 13.972559244401994, 0.26349676893122737, 0.10189753100876847, 0.09440209611409134, 0.04070078818908623, 0.11449972332845773, 0.019498776283956343, 0.05138566544760139, 0.009962204494513571, 0.09409356186346662, 0.18945388075324798, 0.17517783228428135, 0.1447366850991403, 0.11603290275219949, 0.1607706142409194, 0.07723859331059842, 0.180967572415548, 0.22540166793811708, 2.3259657573315407, 76.60406204961961, 66.04963856358683, 39.49647903442383, 46.845149378622736, 80.0591367290866, 62.62744119090419, 98.03338235424411, 43.87880986736667, 0.3301271129279368, 0.8611486491657073, 15.156766926088642, 81.11918864711639, 72.1994129303963, 80.29564780573692, 78.94082976925758, 77.27506191499772, 69.8906195548273, 68.03588759514594, 61.28240162326444, 63.2046885644236, 64.69793488902431, 67.54393608339372, 64.2700239150755, 67.04726203795403, 66.90617438285582, 67.05574220226657, 61.68241277817757, 63.198365703705825, 63.54880594438123, 61.75552183581937, 60.00088876293552, 53.7446887262406, 57.58771719471101, 53.05226095261113, 53.37822952578145, 55.47027272562827, 53.95888936135077, 54.184547239734286, 48.97727527926045, 51.193524252983835, 52.31307068178731, 52.75315277038082, 57.32070968997095, 58.821918426021455, 60.5699501499053, 53.00749101946431, 62.38184982730497, 64.50652714698546, 64.18127636755666, 70.08556135239141, 61.589911522403845, 58.38387596991755, 56.642975115006976, 57.446762900198664, 58.7907277384112, 55.249937503568596, 46.15270199314241, 55.602460522805494, 59.18442779971708, 55.12748895152923, 48.26010519458402, 48.719889348553075, 47.51911455585111, 50.241753285931004, 46.25497779538555, 48.31180595582532, 47.58313940417382, 48.27736754571238, 57.910312529533144, 61.266151243640536, 57.68126180095058, 58.76931551964053, 55.894943821814756, 50.75050038676108, 50.04689385814052, 46.02915125508463, 46.84854222882179, 47.06537477431759, 54.40968736525505, 57.8553875800102, 51.179741044198316, 44.28905448605938, 47.72239531240156, 46.059110318460775, 51.54998925424392, 52.527691010505926, 58.858055222419004, 56.0056919436301, 60.961147739041245, 58.72816593416276, 48.98490821161578, 46.63204308479063, 43.140843376036614, 45.68917197565879, 45.21973486869566, 47.39560304149505, 47.08653203902706, 46.65958204577046, 43.07135074369369, 44.744233777446134, 61.870651245117195, 52.44039866232103, 45.203464877220895, 51.381680350149836, 53.81307132782475, 57.8959801889235, 55.63601639962966, 52.892294929873565, 59.22361227773852, 58.87315242521225, 60.24784903372488, 64.2604023410428, 65.2498947420428, 62.98709115674419, 57.56921145223803, 53.0985959114567, 54.21812272840931, 50.743216545351096, 46.757276519652336, 45.612140547844675, 52.56636165803479, 55.73599761532199, 54.70185687465053, 54.08997889487974, 54.82823956397272, 54.73995877850441, 57.940134309953265, 58.73366117477418, 55.71831164821502, 60.790712910313765, 58.28253761414559, 59.07104776751611, 59.78469164140763, 57.43248547277143, 55.28631748691682, 57.489618716701386, 60.554276358696725, 60.7678258803583, 57.40709204827586, 63.06907261571577, 65.87673264165079, 79.2166429950345, 80.17213236901068, 85.00324510758924, 81.24621068277668, 87.5305929491597, 74.9142736004245, 86.34317382689446, 24.59703822289744, 0.1978460368850539, 73.41089971603887, 85.08566194964995, 77.06147316963443, 74.66850573016752, 50.90541047434653, 46.91880756808866, 90.24752463063886, 19.960261275691373, 0.28583230751176036, 0.13640111222142173, 0.17203374615600034, 0.13139923223324362, 0.2338490896527806, 0.239825418158885, 0.20801278972818008, 0.16525589049823824], [0.0635574542496714, 0.09046871725830341, 0.037284744678125266, 0.07357867720026164, 0.03952703806721876, 0.009876822080132703, 0.06891727732915072, 0.06967171305610288, 0.05667919893899272, 0.15061303913112611, 35.36203807400119, 57.74073277750323, 35.618184535734116, 32.495009053138, 47.11158421731765, 43.94156386775356, 77.6222465884301, 47.903373472152225, 0.40385915326976013, 0.20544323889959246, 22.661715284470592, 77.43537702868062, 72.80506610870361, 78.17980366368448, 69.95884526160457, 71.86226952460505, 59.48773684040193, 55.82212501956571, 55.41117045187182, 58.5495255070348, 59.10627849640385, 61.030981617589156, 58.347488141828975, 60.96489752492597, 61.64031790148828, 60.78516275651994, 57.45709050086237, 60.546074682666415, 54.64136608185307, 54.89019340084445, 53.01275484023556, 50.92202955676664, 48.435599880833784, 51.25454456575456, 47.80578097989483, 49.138739647403845, 48.51933463927239, 45.479858613783314, 46.125214022974816, 42.74214621513121, 46.99374445023076, 45.39260941167032, 49.05260439841978, 51.2425381906571, 57.92797104004891, 56.64363015082575, 53.99817974336686, 62.04485939395044, 58.95105461920462, 61.10696185019709, 57.194848675881666, 56.75562558635589, 52.94756897034184, 50.9306783829966, 51.99693941300916, 46.563625181874926, 49.630012589116255, 54.10031826265397, 55.41881907370783, 53.68530404183173, 48.703540909674864, 45.2387152179595, 45.25704053140456, 44.057061979847575, 40.921805597120716, 42.01324039889921, 42.309512707494925, 45.57134005331224, 49.1893696015881, 52.788512937484256, 49.462586218310946, 50.23958813759589, 47.177770291605306, 45.42757734175652, 48.78795031578311, 45.36045382099767, 43.269081346450314, 43.98804003192533, 49.67057774143834, 53.654431066205426, 46.09558051632297, 43.983058621806485, 43.997520400631814, 44.26379049977949, 48.53296879799136, 48.7021759248549, 49.59407583359749, 52.53793624139602, 51.57093471096408, 52.88303029152655, 47.09507496126237, 43.29323922434161, 43.101654975645005, 41.45920953442974, 42.85821699327038, 42.04268170941261, 40.588380598252826, 41.1695699537954, 47.78603576844739, 42.694532563609464, 37.14019360080842, 56.650466842036096, 54.03588548783333, 47.797281203731416, 55.75322466511881, 51.31590220236009, 52.945243004829656, 48.36097678830547, 47.99701613764609, 54.53725068799911, 60.243067664484826, 57.850229663233605, 57.81334761650332, 55.69579332105575, 48.75202140500469, 48.541876500652684, 45.935363461894376, 43.427356827643614, 40.70600463498024, 45.726485483108036, 47.43528958289854, 47.898760764829575, 51.3548787947624, 50.77597618103028, 52.306959629058845, 51.307249453759965, 51.47111039007864, 49.73306894302369, 52.63278307453279, 52.0588069577371, 51.44821159301266, 51.83278037655739, 53.17403485698085, 54.8508834069775, 56.81037402922108, 55.055666431303955, 55.116945620506044, 54.39762607697518, 56.01081848144532, 55.50027493507632, 57.12238288694813, 68.76143978488061, 74.18242992893343, 77.65938358922159, 75.93343088703772, 82.1664144146827, 74.99219540626773, 83.30831835346838, 17.163328932177638, 0.3428730386639795, 68.0362484532018, 58.730617415520456, 61.64145146646808, 42.93403640870125, 32.64239211236277, 31.33743524551392, 66.03581613109958, 11.748282159528426, 0.32126212732926496, 0.152587661399476, 0.06990094188480608, 0.022605973363463438, 0.0779059631449561, 0.10778284060858911, 0.0029548516378722967, 0.0616018922488776, 0.01636811393132854, 0.1061212188834625, 0.043858640917366555, 0.019404773465207508, 0.0559281186771489, 0.034119142970490846, 0.049927520505603284, 0.015539433750804636, 0.031039597834610654, 0.23097215370545465, 43.40463453723539, 62.813298779149214, 36.844937186087336, 43.55286875078755, 54.582024543516106, 50.96256333012735, 84.0382714425364, 52.07577905347271, 0.6242864590979392, 0.3959193873790003, 31.346148790851718, 83.97185787077873, 76.63279733350201, 82.4073342354067, 72.05688968781503, 76.02803061085363, 64.30315617592105, 58.009830905545144, 59.084787830229736, 60.594174708089525, 62.12742528607769, 64.30192455168694, 64.14503366716447, 63.18172308706469, 62.6602675068763, 63.62224055874733, 60.3862577099954, 63.140867679349846, 58.00728136493314, 56.40145517164662, 55.619766020005756, 53.04278842864498, 52.2100966976535, 53.80967063288535, 52.48582363128663, 51.84603406536964, 49.92992877960206, 49.47783639354091, 49.623187665016424, 46.13278419740739, 50.30732747047178, 48.461130588285386, 51.89780150690387, 54.692725596889375, 57.80979787149737, 57.19649607135404, 57.24369395163752, 63.655282605078916, 61.34118226266677, 62.38015536339053, 62.0758225840907, 59.39960902737033, 56.2941744250636, 54.38685132611183, 54.1804365957937, 52.27313310869279, 51.68904904396304, 58.317646749557994, 56.92120844318021, 58.44694768228839, 51.84537118481052, 46.41102929269114, 46.764211270116995, 45.58770025930097, 43.83429488828106, 43.94885163153372, 45.5162032958, 49.30169843858289, 50.46319069400911, 56.40177288363057, 53.656910004154334, 54.78376380858883, 51.636340233587454, 49.37252859915457, 49.96323362473519, 49.16611386883644, 45.66002092053814, 45.464898693946104, 51.94115938678865, 54.727932791556086, 46.536168590668716, 47.15722491664272, 45.61177576741865, 47.95676477493779, 52.54873060411023, 52.77076421245452, 53.22440985710391, 54.30072784423829, 54.19992685317994, 55.32020676520563, 49.56495223506805, 44.76695606785436, 44.76616767144973, 45.012629801227206, 44.07408114402525, 45.07110057338592, 43.49396259553971, 43.80386514048423, 47.580684000445956, 47.527912432147616, 43.57667361536334, 54.840340075954316, 52.214685870755105, 48.19540962096184, 54.78989839553834, 54.59308954977221, 54.44854628655219, 49.780678672175256, 53.199953879079516, 59.05542496711978, 60.324472535041075, 60.394447618915194, 60.70449921392626, 57.29471222046883, 53.05498307751071, 49.34440128264889, 50.856208262905, 46.69675827026368, 44.376095802553245, 48.33490871614026, 49.37203045814268, 51.486121300728094, 53.717251746885246, 54.04497754189276, 54.38829868070541, 53.696984860204886, 54.026146242695475, 53.58408335716494, 56.35002897631738, 54.92702837913267, 54.74083346705283, 54.97200619789862, 55.866404656440984, 58.92668885569419, 60.43638167842742, 60.34381766473094, 59.495907137470866, 58.663195794628514, 60.610613361481704, 60.038257183567175, 59.446187173166585, 71.64140086020194, 75.17445225869456, 80.37549157296458, 77.46709331389397, 85.76617748506608, 74.77210337115874, 86.06577596356793, 23.624821901321415, 0.29791440273965564, 74.96201669016193, 64.61451392019949, 69.88202171940958, 53.15707452835576, 38.10503782764558, 38.95432510683614, 79.48235219524753, 13.777515465213408, 0.3181151913539056, 0.12868994696726724, 0.06800141155479417, 0.03876284621055088, 0.1143215849034248, 0.05474954986223771, 0.05522589950311569, 0.0730539069721295, 0.13409057572003336, 0.29132570951215686, 0.22934507488483385, 0.23580190905880546, 0.13685203157365322, 0.09354537998836848, 0.11676256319568043, 0.16466900586120545, 0.17939762843232002, 0.4778539311260947, 62.60315387479721, 73.54021241587978, 50.052200824983665, 42.773329058001124, 66.03422364880963, 54.59606662873299, 92.90055305727067, 56.16722299206642, 0.6597087712537858, 0.5851676807768884, 35.31791925430298, 87.32645711591168, 75.2308794759935, 83.36256473295151, 75.7474007145051, 77.74548745924427, 65.11322759812879, 61.61004504849834, 61.25580403112597, 64.21868401189005, 66.40076129667221, 66.32518506819203, 67.11234984859344, 65.0622054069273, 67.1835957804034, 67.25394741181405, 62.064251592082364, 67.60384636540567, 60.22362447554066, 59.63686927672356, 59.09773165179838, 54.62349184097783, 54.40063453489735, 57.66973003264397, 53.54662864438949, 54.94102731827767, 53.34870192312425, 49.792069235155665, 49.97076849783621, 45.721711958608324, 54.20049167448475, 50.72290259022867, 54.118106211385424, 58.16356820444907, 59.91238047999721, 61.123918256452015, 60.07665718755415, 67.9327763280561, 64.17361990098031, 67.64595693157565, 64.10645715651974, 62.63555657479071, 57.31683438824069, 54.42994248482489, 57.555479234264745, 52.16471879712997, 51.76451936844857, 59.26223977919548, 62.167382471023075, 63.15849088853406, 57.449167313114295, 47.99751820102815, 50.83103841350925, 50.42000147604173, 46.70435590128745, 47.284246952303, 46.1176085472107, 51.048937843691924, 54.715702841358805, 59.89629876229071, 57.496447563171394, 59.59378988512101, 56.156095227887555, 51.25799625150619, 55.518666928814305, 50.83099918980753, 49.85503504353185, 48.946284632528986, 54.83717864559543, 57.48365671403947, 49.685188570330226, 49.19688878520843, 49.987379735515965, 50.918522957832586, 54.78860793575164, 56.51030878866873, 57.23168757654006, 60.459825684947354, 59.82884184006722, 59.101316698135875, 54.19693016236829, 46.94031392374347, 46.046645026053156, 47.12504971411921, 46.15938571191604, 46.90506358300486, 45.917124440593106, 45.87385677522229, 52.28762234410932, 48.95748692174112, 48.54371216989333, 55.81581784832863, 53.542612137333045, 50.56442706815658, 58.94324910256171, 56.446938976164795, 59.58990673865042, 55.68116288031302, 56.17505204293036, 61.75572187669816, 64.80311324519496, 60.88028807793895, 64.06774336291899, 60.18036073254001, 55.93476764617428, 51.37726768370598, 52.63710160409251, 48.94368802347491, 46.65402012486612, 52.144244024830485, 51.64173349257439, 54.243057235594726, 57.22726706535586, 56.58981915443175, 56.69285197411814, 56.56155455497004, 57.82658169346472, 54.06739388742755, 58.0302821436236, 56.857717037200935, 56.097440104330744, 57.462730869170166, 58.3504456089389, 61.812051034742794, 64.11971869007235, 62.47351169586182, 59.89963669930736, 61.35644028263708, 63.24399463592037, 62.772451216174716, 62.60912372219948, 78.18852701494771, 78.90482241107573, 82.73638186916229, 80.25909916047128, 91.61857343489125, 78.48683895603304, 87.04938873167961, 32.97216146223007, 0.6593883013533008, 80.75825998860022, 71.72589655845397, 78.07937529779251, 60.069032099939164, 48.69094617905156, 50.762259652537686, 93.34249434932586, 19.251602734288863, 0.5057641383140318, 0.3807578638436333, 0.14998725254929837, 0.17163924151851287, 0.2965621962662666, 0.2849182114005089, 0.15143359590682293, 0.2527626054061036], [0.034077601852796735, 0.036771726238751606, 0.049514798297276424, 0.04719588845487564, 0.08526219986379148, 0.0499192544169003, 0.0379968463863817, 0.017101690999322364, 0.05919547218288626, 0.1183227702013908, 27.37711221941056, 65.15762490610923, 41.27300677760955, 27.687538400773082, 50.29658017619964, 47.35244912485923, 66.4792557685606, 55.896567683066095, 0.45587909738382987, 0.29541505620844905, 43.17502290971818, 70.373180912387, 77.23098231900123, 75.45038315557665, 74.09372160511633, 68.34387994581654, 56.13751888275147, 55.51067313840313, 56.64648955868137, 59.27081800276234, 59.61329583198794, 61.890227794647224, 62.82849796356694, 60.60730680342644, 63.03783093729327, 60.00153987638412, 58.610490906623106, 57.08652850120299, 53.815722850061235, 52.10690306079004, 54.58458585123862, 53.41453890646658, 54.3918994165236, 54.093740447875, 49.351908699158706, 50.54954951809299, 49.503237662776826, 46.79255039461198, 45.32268531860844, 43.518850034283055, 43.97828901967695, 46.07523910460934, 46.72253608703614, 49.75824271478961, 53.31675814044092, 54.53983945231284, 56.736735451606016, 57.05066234834733, 60.933498951696585, 60.998139612136356, 58.08214764441214, 57.242215218082556, 54.62938716334682, 50.79942803229056, 53.96504748252131, 53.88504289811658, 53.177274734743186, 53.65551364037299, 59.491827872491655, 55.009413842232, 53.58094546102709, 48.75362173203499, 43.88959638534054, 43.1711515303581, 42.80890495546403, 43.20637049213533, 41.691535442106186, 43.25951076322987, 46.98883756514519, 51.50747076157601, 52.80339048754785, 49.60803947141094, 45.25942533246933, 47.47467410179877, 46.93970987873693, 47.27399387667256, 45.0270680458315, 46.02704101993192, 52.53606134845365, 54.051676950147076, 48.27276660550026, 44.84972592323057, 46.38291374329598, 47.77476679894232, 47.652322169273134, 47.8788233572437, 52.511346493997884, 52.70300134535759, 49.948387453632975, 52.10954673828618, 43.64115738099621, 43.597901482735914, 39.723490130516794, 39.73764988683885, 43.69621176873484, 42.64261999437886, 42.081615155743016, 43.26459807734336, 45.16033449480611, 45.46214519008514, 39.58019810338175, 46.536137211707334, 46.926915107234834, 43.64553474610852, 50.006364007149976, 50.115778523106734, 47.3068594163464, 48.9280338441172, 51.61435142640145, 58.42416655632758, 53.37844525614093, 54.642593783717004, 55.94100029237809, 56.325212140237134, 49.18016772116385, 44.53381430718207, 47.23937111516153, 43.26376653486683, 43.34135101687524, 45.839928273231756, 47.72264634409259, 45.84370159333753, 48.125426692347375, 51.286868818344615, 52.76726938063099, 54.69516138876639, 52.075320136162546, 53.17553712475685, 50.311065489246005, 53.544286989396625, 53.36483070927282, 56.41098260879517, 54.690423165598226, 56.00199707092778, 56.82851891363821, 60.1987252696868, 59.26675834963399, 58.182348512834125, 56.40034906325802, 56.9278411711416, 55.70690147338375, 62.00047385308051, 68.35619618815761, 77.2490095323132, 76.40861818867346, 81.7664267939906, 73.02795087137531, 80.46193276682209, 12.173586718497738, 0.5207512083072816, 67.08563850771996, 61.63468930029101, 57.25536692527033, 47.16457151597547, 35.57827049686063, 38.21409148554648, 71.88619598265618, 8.179847059711333, 0.29038688408270963, 0.05928114379545855, 0.03394157911140112, 0.08345228649916188, 0.08391389277793708, 0.05998146690187916, 0.03237125591465062, 0.02065892451472821, 0.04453799236685999, 0.03347059591643272, 0.036417219051790815, 0.028827007589561325, 0.045160565209845384, 0.04392073617406911, 0.1246636110027471, 0.07430067676449977, 0.06542060689459886, 0.1413663272415438, 36.15188575560047, 74.51951057680192, 38.7111577680034, 31.414066591570457, 60.97472306220763, 50.580465639791186, 76.4988640815981, 58.476118349259906, 0.5600988324130736, 0.20970374495992739, 51.13786582023867, 77.98947457344302, 82.5688103706606, 77.49804865929389, 78.15001718459591, 70.91681357352965, 60.670017657741425, 59.360251965061316, 60.64978607239262, 61.83313377441899, 64.2152480156191, 65.16277105577531, 66.67821407318115, 65.50007920111379, 63.96434576280656, 63.79839812555621, 60.641713834578, 60.839487583406516, 56.90495806355631, 55.04474263037405, 56.28956171774096, 56.179033248655266, 56.88231029818135, 57.997259709142874, 53.37214592964419, 52.71033617757982, 52.25059909205283, 49.8660647484564, 47.881812203315, 45.715377330780036, 47.48777089580413, 48.06409258996287, 49.14777286591069, 52.90748234718077, 56.95477216474472, 55.73594662450976, 56.484432912641964, 60.05963017863613, 64.48964134339364, 61.70136174848003, 60.144070963705744, 61.22156958426199, 58.4556318098499, 51.992491445233746, 56.356002746089814, 55.284830908621515, 55.15847567589053, 56.246768659160985, 63.15554126616448, 56.427382038485625, 55.641374357285045, 50.35429785328527, 45.46235699807444, 42.947796083265736, 44.2081634459957, 45.02236120162472, 44.96225480110415, 46.409005349682225, 48.57575793420115, 55.965240540043006, 56.62108436707528, 54.06291454069076, 48.99559274796517, 51.23068478799636, 50.81500376424482, 49.07016877205142, 48.72135239262735, 47.79459830253355, 53.12741748748287, 56.80523572429534, 50.47841733501804, 47.222022471889375, 48.322015885383856, 49.09806466871693, 50.28345592560307, 50.76956310579854, 56.1995864683582, 56.22234798246815, 53.93298210636262, 55.88857781502509, 47.02127164410007, 43.61147288353213, 41.890552582279334, 42.403963381244296, 43.88155160411712, 43.487039612185576, 42.82098193322459, 45.23839358360537, 48.41656069601736, 50.417353876175426, 45.79725680812713, 49.669197067137695, 48.573749680672925, 47.11151361465455, 53.42267782457414, 52.44030844780707, 51.840723176156324, 55.04075357990881, 57.18992610131541, 59.53057304505379, 56.046413990759085, 54.6985032481532, 58.71987404361848, 56.22243819698211, 51.51807292815178, 47.508575147198094, 49.873364279347086, 46.19172565398678, 46.38367860547958, 49.11859435419883, 49.760674584296446, 48.91865937940536, 50.67157053178357, 54.14223271031534, 55.44818193681779, 56.788153802194905, 55.192000173753314, 56.589462218746064, 53.88937319478681, 56.824627922427275, 56.62961159982989, 59.08925933222617, 56.377571859667384, 59.217756179071245, 60.37903662650817, 63.67087402651387, 64.04773927504017, 63.476806917498195, 60.05798670553393, 61.22171471195837, 59.32530364682598, 65.17113354898268, 70.72336227663102, 82.8985248073455, 78.47728406229328, 85.72442777695196, 73.80186588533464, 85.69603766164472, 14.232266237658841, 1.350758138202852, 74.60185681619953, 68.24452630935177, 64.67172953390306, 58.00934845401395, 49.416753322847434, 47.82199998055735, 80.87498188018799, 9.371342505178145, 0.3579418349169916, 0.07872833554903347, 0.023377992723497654, 0.03796878458571531, 0.09804546472526367, 0.12820379523139808, 0.06416041141135559, 0.01691554120982126, 0.21136889835038494, 0.110406952219144, 0.17457133579638698, 0.16145359694717393, 0.19514159329475897, 0.12815505671765537, 0.27320723980665207, 0.14310314049643857, 0.249518008542157, 0.42158621333299146, 49.06484219335741, 83.38884461310603, 56.516953283740634, 37.258268710105654, 71.27851886133995, 59.542477438526774, 83.06040102435698, 65.27738663458055, 0.590918610893911, 0.5348073895419798, 54.3413322202621, 77.22773459649856, 83.09509046616094, 78.9760918771067, 81.26960369848436, 71.99961523855887, 62.569299897839954, 60.06752983216317, 63.33509952791276, 63.64871655741046, 67.29045683337797, 67.86447217387538, 69.05705313528739, 65.90049436015468, 67.50170784611856, 66.91416032852666, 62.79265926730249, 63.10549182276573, 59.03580919388802, 58.65967742858395, 59.13471960252332, 58.12173612656132, 60.757231558522875, 59.55852777727189, 54.793436373433764, 56.08762633415961, 55.08373491225704, 51.30852422406597, 49.35775303071546, 47.49394862882553, 49.659179333717596, 50.05779020247921, 52.43409933582429, 55.96668789463659, 60.6441927725269, 57.773335518375525, 60.344739421721435, 62.08296129780432, 68.10354063587805, 65.61187067339498, 63.728881958992254, 61.81529875724547, 60.95133004649993, 54.15424300778297, 59.598382980592795, 59.00601487005911, 58.79573268275107, 59.11716307363203, 66.16668993426909, 59.12829083781089, 56.86244741562874, 54.04804875773769, 49.1640507021258, 46.51170476790398, 47.581950926011615, 48.51436891863423, 46.61940520809543, 48.899451532671534, 51.96101834697109, 59.8201734019864, 60.03033007344892, 58.2076281885947, 54.17252125278596, 54.512869235008, 55.204249735801454, 53.30633640289307, 52.33711873331378, 49.67409218511274, 57.28394531434583, 58.364781871918716, 53.12773127709666, 49.78672696698097, 51.195450136738444, 54.31495820322345, 55.31269542632565, 55.41471627450759, 60.990687108808956, 60.548749739123934, 57.35452444322648, 58.86169518193891, 49.55782136609478, 46.5139679754934, 43.7359885246523, 42.709841574392016, 49.63109516328382, 47.925232841122536, 47.40575021313083, 49.09328722184705, 51.8933770733495, 51.89069024978146, 50.4349966972105, 55.5905718188132, 51.98665495841734, 50.30444452839513, 58.349574842760646, 56.23852383705878, 54.64964620528683, 57.774406325432565, 58.241948927602465, 62.282782523862785, 58.408143674173665, 60.181360936933956, 60.928843098302046, 60.39663630147135, 53.955033671471384, 49.48202548488494, 53.20795159186087, 49.64560008818104, 48.441126500406575, 52.90172430776781, 53.292325696637555, 51.36630858144453, 52.30407668698219, 55.86481217415103, 58.55641711142756, 61.66754307285432, 56.09247438369259, 59.30185964030605, 55.74969453196372, 59.66543982105871, 58.39134416272564, 62.15109679006762, 60.54462340570266, 62.76805816158172, 62.735475032560295, 66.90924952107092, 66.5609508945096, 65.6356559261199, 61.0067335251839, 64.45333588507869, 61.37004306239467, 68.93158435821533, 74.14953693266838, 85.39661176743047, 82.49512472460347, 91.88603201220113, 77.35923597889563, 89.35773495704898, 24.3576265535047, 1.552388925225504, 84.2256744446293, 75.69206391611408, 75.93274839462774, 62.698945999145515, 52.149060695402085, 55.58313892733667, 99.03568129385673, 12.944542304162058, 0.46974354213283914, 0.21895828626809583, 0.13770199080388393, 0.16259716703526436, 0.2540421867442708, 0.17843555989525012, 0.18348337451536811, 0.14580021432090193], [0.13577983023658877, 0.033756220307681835, 0.2738250743958258, 0.043902729277408896, 0.03963892903899954, 0.06375493639479242, 0.055267904104003986, 0.13280728651631263, 0.05811785460419713, 0.26603123293288294, 23.244036243807887, 64.0994361139113, 54.665284695163855, 38.151204124573745, 40.84825331164945, 52.142318141075876, 60.080869813119214, 62.2044998599637, 0.2686928368864521, 0.8072023310007588, 52.2555765798015, 72.27378891360375, 74.77061287049325, 76.23630062226327, 70.51746922154581, 63.68754409974622, 55.669478139569684, 57.452556240943174, 58.8850607410554, 63.273549695168775, 64.78624313108384, 63.816770507443344, 64.15503571110388, 61.685221195220954, 63.442113553324056, 62.99485352731521, 55.97263420781782, 55.79907717243318, 52.36199048257644, 58.07093751045966, 60.624678980919626, 64.1129094554532, 62.028146174646196, 64.38026997350877, 55.984409163075114, 52.79912294880037, 49.1844823283534, 48.89919265624016, 48.20899671123874, 44.163958334153705, 45.297115387455115, 46.460710033293694, 46.081754161465554, 47.91805882607737, 51.39413387544694, 49.563995176746005, 52.40491690174226, 55.63908761547458, 57.24036778173139, 56.45093194900021, 60.87006638126989, 56.125214407520915, 57.392277256135024, 52.65867856241042, 49.62130884970389, 50.86386865185153, 48.15586428488455, 56.28453323918005, 55.95213197892713, 58.149133882214954, 50.88888552881057, 43.582137477013376, 44.13285786105741, 41.64476117780132, 42.971706851836174, 40.59054574658794, 42.90715640591037, 47.11062323662543, 46.40384743290563, 51.51842986383746, 49.63623739057972, 52.70971252072243, 48.90346019498764, 45.549614044927786, 48.946892599905695, 50.66780113404798, 46.73489155307893, 48.0563812102041, 49.434509892617505, 51.25794133832378, 47.14925858282274, 45.32310108984671, 48.52248822489093, 47.97632171261696, 48.55379266123618, 47.940957623143355, 52.63500705842049, 49.50044885758431, 51.31474510315926, 51.750367456866854, 46.522334391070956, 44.28842690683181, 40.41602773051108, 39.742780347024244, 39.96722621302451, 40.361000799363666, 42.0150682233995, 43.31858950276529, 46.11413332723802, 53.75397689880864, 46.23396173600228, 45.84924390239101, 44.078454586767386, 47.55291754199613, 49.822291097333355, 48.46404098695325, 51.72718232677829, 52.43221659814158, 54.858916421090406, 54.89688104198825, 51.61784233585481, 52.501607248860026, 55.32541959516464, 52.12646784320955, 47.2209281306113, 44.61932197693856, 46.60067981289279, 42.81936591671359, 43.001830654759566, 45.15344681278352, 47.07280766579413, 48.26735373466246, 48.97201930322955, 53.59255567673714, 57.3594666296436, 60.49102813966813, 59.5896400174787, 59.31965543377785, 54.905110174609774, 55.08282884474724, 53.33037268730902, 51.905705082801084, 53.37379332511656, 52.72983035733623, 56.520091179878484, 58.55011386256064, 61.65847063064576, 59.79716870092577, 60.5477063886581, 57.517236125084665, 56.62292788105627, 56.98212285195628, 60.87347492094963, 72.06063947369977, 72.79009834412606, 79.17672895616101, 72.6548550205846, 79.6878843922769, 6.817724099082332, 1.5679877011045333, 68.65637517744496, 53.00644374662831, 49.65602967046922, 35.97735597241309, 30.051697992509414, 41.91199225764121, 68.45926038680538, 4.922463269002976, 0.21041210049823408, 0.04918498595455482, 0.023911268442809105, 0.013036085367803613, 0.1509386418207038, 0.062463576454789414, 0.08312889014280612, 0.03975413717149247, 0.06779866638563334, 0.022804181376892715, 0.16555218266383295, 0.05068303641652869, 0.051392292108146415, 0.0250589122034369, 0.04142965956200515, 0.04522407006832861, 0.11722873535848434, 0.5335423638743739, 26.758517180719686, 72.56079658385246, 52.09479862643827, 37.70838029922978, 47.46823356997582, 54.95104505169777, 66.62520716267248, 65.77260155831614, 0.25769972032116306, 0.9464087805921032, 60.614123882785925, 78.41296503620764, 78.87800908857777, 79.8270030175486, 74.92520916846492, 65.9776238472231, 59.70336521825483, 60.40913297284035, 62.38341485300372, 67.86896721009286, 67.03340038176506, 66.55592241594869, 66.63616626493393, 66.42290699866511, 66.72086592643493, 64.0348699785048, 59.63745370987923, 58.92343721082134, 54.26510880070349, 62.11331652056787, 64.75771965519075, 66.47137964925459, 62.86844730377198, 65.3760773904862, 59.94264941061697, 55.90999003379576, 51.784950994676166, 51.945368089983546, 51.11138589920537, 47.96418982167398, 47.53178773387786, 49.5042614013918, 47.29499424657514, 50.951270826401256, 52.807771775030325, 51.61391212094215, 51.8666696548462, 57.65498192079606, 62.24240564530896, 60.39543997856879, 60.78647282815749, 59.657630382045625, 61.73363501025785, 54.886298487263346, 52.006470772527884, 53.67675327485608, 51.502234397395966, 55.721979064326135, 58.984237870862415, 60.23867068752166, 54.149999003256525, 45.72088826087214, 44.92715351043209, 43.11101767324632, 42.92179861376363, 43.07812075461111, 44.02105462166571, 47.38110596133817, 48.11442052164386, 53.2596327412513, 52.58218057693974, 54.40797328948975, 53.13228907123689, 49.65394689190773, 51.73528986592447, 52.80750897622878, 49.63166782932897, 50.439393674173665, 49.88512354512369, 53.42720423975299, 48.0010679460341, 48.14459923774966, 49.834164111844956, 50.48265349480414, 48.78997425879202, 51.24360899771414, 57.410963427635934, 54.857386696723204, 55.611587878196474, 54.13910265891783, 48.91592548739526, 45.17559251477642, 42.68175740395823, 40.70776970155778, 42.32022470043552, 43.944995941654334, 42.99790828458725, 45.62810067207583, 50.75458357411047, 55.14328825858332, 50.44966636165496, 50.73020212111935, 47.801234952865116, 50.25318699498331, 53.74808549880982, 49.75570886365829, 54.35819841200306, 55.598498928931456, 58.7083814990136, 57.363663565727975, 53.17375636869862, 57.56697962360998, 57.54156266489337, 55.07175991612097, 50.46754844727055, 46.33960685422344, 48.10896842710434, 45.066491788433446, 44.354860090440326, 48.83344980978197, 50.78663718315863, 52.20992803573609, 52.39006680826987, 56.316453487642356, 60.2520969606215, 65.62076660894579, 64.30056348923715, 63.87195433339765, 60.73579580553117, 58.12420329739971, 57.864044250980506, 56.44879817962647, 56.253150355431345, 58.26756200482769, 58.89128946488904, 63.768937203191946, 65.54235842920119, 64.8604190734125, 62.2126740794028, 62.15132428753761, 59.94224148411905, 61.43373450925274, 64.58602182326779, 73.48191815037882, 72.89142885515767, 83.39132355105492, 74.57250179782991, 89.6821306597802, 9.401483958767308, 1.904390391803557, 77.83375647760208, 57.19728839012885, 58.81564655611592, 50.33476837219731, 35.429742105545536, 49.02427311866514, 80.0606821429345, 5.214575413734683, 0.15183442843056497, 0.06364484956007331, 0.006539475908803364, 0.05160424182371748, 0.06385849616039665, 0.07938026105083766, 0.0418814484240307, 0.0544591106083845, 0.25590050154395644, 0.10524517435941005, 0.4664254008281616, 0.1906260105991556, 0.17135091666733065, 0.17324217324776037, 0.11389334941463125, 0.20362558804692762, 0.31506187132289337, 0.771522674589388, 37.114439318257, 82.2014098013601, 71.83760566096153, 50.628389158556544, 57.2616623293969, 68.75871765998103, 75.08084881690242, 73.60101699829102, 0.6605438683782855, 1.2963272847475544, 63.222613796111084, 80.7002716679727, 81.19638873684792, 82.35234260559082, 78.07012634892618, 68.97129443383986, 61.81709128041422, 60.037559001676506, 64.32297591240176, 71.2095400594896, 70.09255101603847, 67.19500987760483, 68.48396347415063, 68.18547894877773, 68.24169435808736, 67.92684570435556, 60.30695915222169, 62.163283594193004, 56.80217627556094, 64.32001060055148, 66.56932907719766, 69.5568964558263, 68.0723342587871, 69.19056277121268, 62.56474994844007, 59.07884936178885, 53.950397429927705, 53.87980653393654, 53.02937000028549, 50.16653007076633, 50.090765568517874, 50.86779102202385, 52.13904296198199, 54.00907608770556, 56.11322372190414, 55.38597706825503, 57.17952397561843, 60.75815331551337, 63.929248394504675, 63.39989708315942, 63.82186566629718, 63.33311873097574, 62.61488960635278, 55.38560836545883, 53.24248413885794, 56.16916456530171, 52.27412939071656, 60.436554262715006, 60.97835125461702, 65.2141031142204, 58.13370720032723, 47.17668771743775, 48.141222077031294, 43.779605280968454, 46.98076140496039, 46.06913197425104, 47.313068528329175, 52.592869035659305, 51.846194882546705, 56.81181746144449, 58.67024429382817, 60.52549400637227, 56.77160140006774, 52.924262246777936, 53.89112649425384, 56.754974472907286, 52.30381388818064, 53.06266307830811, 51.33385881300896, 54.92634980909286, 50.82037348901072, 51.58727922747212, 52.99491982306204, 54.30981597592754, 56.24832191774922, 57.80489883115215, 61.25608644177837, 58.52683067321778, 60.06099124108592, 60.64372208810622, 51.50507419340072, 49.13720600066647, 44.40681972811299, 42.34253906434582, 45.40054828889909, 46.45779178988549, 48.68559998850669, 48.10528532151253, 54.19693016236829, 57.02260563450476, 53.624585751564275, 55.56208364425167, 49.44569649234895, 52.38290063796505, 54.99025306394024, 51.73085366525958, 57.477937898328236, 55.65347094689646, 60.52358773446853, 59.807492379219305, 56.68737634535759, 60.64914280368436, 61.23302290516516, 56.72180691073018, 51.583368624410326, 49.55803317408408, 51.05669629189276, 49.608816100705056, 47.91734495470601, 50.76838639474685, 52.00323089476555, 54.37253467498287, 55.023969757941465, 59.41941699674053, 63.068684301068714, 68.20982902280747, 65.29633952725318, 65.37780715573219, 61.99517473097771, 60.22859804091915, 60.09022466598019, 59.9922203248547, 60.36761860693655, 60.494644564967004, 62.26033087699645, 67.31834488530313, 70.44259117495629, 68.52998856575259, 65.40579718928184, 63.85074607787594, 63.350639958535474, 65.28976171247422, 68.02487357970207, 79.78539451476067, 77.75174756203928, 88.92559959042458, 78.87242363345239, 96.83318414995748, 15.12125280595595, 1.9205036110454992, 88.34789722196518, 63.76939612050211, 67.48588500484344, 48.76950733123287, 43.13255148549234, 56.95847488218739, 90.19182697419198, 7.209841974319951, 0.4113087148195313, 0.2193794354435898, 0.19334715490619983, 0.16356311197723114, 0.23038082575846106, 0.12817034017174475, 0.17593065156571328, 0.09993518146896556], [0.13300283811986446, 0.12674363930859875, 0.020398339707284205, 0.05537945033621885, 0.08106252884552365, 0.05771709868924753, 0.08970984588226966, 0.08914445001151293, 0.13982629133087976, 0.5512606905352685, 14.252470366416441, 58.661120860807365, 39.665372371673584, 43.27882451395835, 37.38034071460847, 54.581028261492335, 51.25443473938973, 72.12640977674916, 0.6114064986186644, 1.0492557167045533, 62.152873623755674, 72.53614056494929, 75.26660442352295, 70.63396361566359, 66.30483581173804, 61.715082199342795, 56.3001678066869, 58.01457697345365, 60.84246073999713, 63.39223669421289, 63.73325147936421, 64.23440094917052, 65.79034243860553, 65.99095990580898, 63.04769177590648, 58.40087944461454, 55.19305921369984, 56.62621874963084, 62.40482314940422, 63.13127748427853, 64.32488610667568, 62.58384012406873, 64.81043631030668, 64.18170782827562, 59.85534921769173, 54.62229551807527, 48.66814151886971, 47.45042208702334, 47.091285951675914, 45.15878123621787, 44.25717346129879, 45.35633140994657, 43.69737279030585, 43.853322305986964, 46.66452423218758, 52.88399519458894, 49.89984812275056, 50.93700516608454, 58.072314262390144, 55.384188467456454, 59.911682298106534, 56.45196353235553, 56.765011818178245, 54.45651262037216, 52.0471026051429, 54.606433453098425, 54.38095600374284, 55.012132044761415, 57.0237470442249, 56.303584191106985, 52.69123815721082, 45.35688054177069, 43.244260587999904, 43.38424213470952, 43.08706375860399, 40.56302639745897, 42.81595345466368, 44.68584537506104, 46.85585744919316, 47.99622774124146, 49.06308104915004, 52.84952148314446, 56.29492359776651, 48.13859016664567, 48.319878193639944, 49.67048752692438, 46.52092233780892, 49.5622379549088, 45.546244728949766, 47.30365876228579, 48.276716432263775, 48.35270450961206, 48.38356964049801, 49.50248064533357, 46.80808298049435, 47.20199092741936, 54.08289901671871, 51.11979153848464, 48.513953147395966, 48.38312249029837, 44.53074309133714, 44.196172760378936, 42.54068543834072, 42.24252254732194, 41.64805989111624, 41.693265207352184, 43.76937966192923, 47.60219427847093, 52.45110673289145, 51.57234284185594, 54.96790732106855, 45.27690341395717, 48.320521462348204, 50.47327903009231, 49.99710721354331, 55.5674925927193, 53.94065818478985, 56.32686345807968, 54.995512962341316, 53.67264263091549, 52.56844051422612, 54.93765407992948, 51.87205506909279, 50.8505129814148, 47.92969257600846, 43.916915693590724, 46.62869338066348, 43.189280725294545, 43.07185280707575, 46.364321708679206, 48.60467364711147, 47.58338651349468, 52.101325450405, 59.05800588669316, 61.18005129598803, 64.33180516765964, 64.18359056595834, 62.724923856796764, 63.00032523370559, 64.78366221151045, 60.1941910097676, 58.11747643255419, 54.4751242668398, 55.89384948053668, 54.86133652348673, 58.04173546452677, 58.20683194744972, 58.95270593704716, 59.367924121118364, 61.69401514914728, 58.53815847827543, 54.870522714430294, 56.534941273350874, 64.26521508924424, 69.56924407712876, 79.72436243487944, 67.79054334086757, 85.86200098837577, 7.123351260539025, 4.082656113370772, 76.15210302414434, 51.06529804968065, 50.9754208595522, 30.532613915781823, 52.9790146120133, 48.725180625915534, 64.8957400168142, 3.7575249662322388, 0.17197563072606442, 0.09088861771048078, 0.04311789518162128, 0.055765914880940994, 0.06008342937416127, 0.017491438230800054, 0.05853639141986928, 0.022603209701276595, 0.13828444745271437, 0.04648968179319655, 0.022188313718464588, 0.06003612344483695, 0.04181951404579225, 0.06762889364073355, 0.07129344458301222, 0.12198811021423149, 0.23954769596457484, 0.57430375727915, 15.756762085422395, 66.60215147079961, 43.61969024904313, 55.19841324898505, 48.48839498335316, 59.684067157007036, 57.89568601116058, 76.17045187181043, 1.0245895241537402, 1.3616901515953004, 68.88450022666686, 76.59882960780975, 79.58551053077944, 76.86544879790276, 71.03521423955118, 63.73360841504989, 59.141928918900035, 59.93623633538524, 64.06819051311862, 66.28986020242014, 66.49377638293852, 67.52436345623386, 66.77340215252292, 69.59648101560532, 65.16696799185969, 62.93452355169482, 59.78595072223295, 59.418087313252116, 64.85382949152302, 68.29554065581291, 67.44101309007215, 66.315441900684, 66.01178769142398, 64.23901757886334, 63.70690491891677, 59.15832442622031, 50.84561394106958, 49.38397799768756, 49.607302065818544, 47.34864834816226, 46.77225997371059, 46.9563328835272, 45.206390965369444, 48.57353002794328, 50.79575669380927, 55.94460102819628, 51.309442058686294, 54.01518714043402, 62.37030629188784, 59.167349799986816, 61.809144558445105, 58.62848281860352, 60.451000352059644, 56.456748823965754, 52.85527167781707, 55.02912375234789, 56.49638829692718, 55.81190724526682, 60.773760426429014, 58.18123063733501, 52.73565115467195, 48.29676366621449, 43.848352662978634, 44.715314142165646, 43.62839006608532, 43.82861529627154, 44.53676785192182, 45.58045564159271, 51.736819590291674, 53.25394138213127, 52.002528790504705, 57.07419264701105, 59.502269221890366, 53.50312955917851, 51.351925250022646, 52.61206903765279, 47.87041771796442, 51.63385737326838, 44.27963687527565, 46.49993373501686, 49.27899576002552, 49.53063541843046, 51.350426904616825, 52.37557365048317, 48.748357911263746, 53.29784054909983, 56.892932076607984, 55.23544042341171, 51.83855410545103, 52.05146035840435, 47.91730573100429, 45.11261493928971, 44.732694164399184, 44.030374173195135, 42.91340866396504, 42.913141942793324, 47.32768327959123, 50.22316125131423, 53.36548182272142, 54.359657533707164, 56.57488669118574, 48.378745125186065, 49.95664012047553, 51.751257834895966, 53.59559943599086, 57.26706735549435, 55.151207523961226, 58.18626303826609, 56.06220153070266, 57.45566275811965, 55.43344951445057, 57.03854614688505, 53.550452955307506, 54.34406611227221, 48.94690044464604, 44.82284592043969, 48.98942285968412, 45.69326693011869, 47.42376958170245, 49.99605209596696, 51.499669167303274, 51.524768414035925, 56.855700938932365, 62.786038306451616, 63.91455127346901, 66.39877657736501, 67.47292549379411, 66.35452439708095, 67.69472768229824, 68.25343793438327, 64.2233673218758, 62.31927625594601, 59.25434012566844, 59.24329865363337, 57.24813015230241, 60.95190271254509, 62.29429468031853, 64.07372889980194, 62.32638359069825, 66.1583274410617, 61.29152897865542, 61.34144898383849, 59.07397385566466, 68.3640879969443, 69.3764203594577, 85.03996633714246, 71.41737861018028, 94.60161439834103, 7.448594685523742, 6.253396522614264, 86.69111159539993, 57.42333850552959, 56.82972308128112, 31.05873907766035, 50.29849429284373, 55.49350100178873, 75.69439380399643, 4.808563032457906, 0.11515826016904847, 0.12088950182641707, 0.017351841689237667, 0.011192552234616973, 0.11108834912339527, 0.0289377513446755, 0.026336492136901906, 0.04382376093417407, 0.30764286135954244, 0.12511717335831735, 0.13735490700890943, 0.10111004624876285, 0.1684544607996941, 0.10322757455850802, 0.17600243400421836, 0.21337321418667995, 0.4213062848054594, 0.8615456665715865, 22.628522226887366, 77.73119434233635, 51.24846489198747, 56.302870319735625, 52.956919900832645, 72.8289141193513, 62.53581462367889, 84.95136783969018, 1.097001993367749, 1.8734097961456546, 71.47721828952913, 79.32421791938044, 82.89963876047443, 76.63067140886861, 72.73709927835773, 66.23179343438917, 62.16183231722925, 61.86675633153608, 65.19935108000233, 68.46316706749701, 69.96673707039126, 69.71766656444919, 67.67776735367315, 71.4833999449207, 67.36291869994133, 65.17243577587989, 63.172407457905436, 61.311384016467684, 66.49868719039425, 69.61162136447045, 70.2568434130761, 67.68838128735943, 68.89739697979343, 66.94461361054452, 64.94364784609887, 59.38054630833288, 53.38878070154498, 52.92512909058602, 51.89031370224492, 50.47904883661578, 49.27666587214316, 51.47343635559083, 47.97021850462883, 49.807546907855624, 53.09809384807464, 57.98591229223437, 54.138624129756806, 55.89780322967037, 63.936328272665705, 61.66848836406585, 66.23567658085977, 60.97807668870496, 62.85725678167036, 58.472392097596206, 54.01941545547978, 59.43056045040008, 60.72173018609325, 60.60564371847338, 62.72952871937906, 62.37305979574881, 55.68559908097791, 50.45248654580886, 46.629944616748446, 46.34008146101429, 45.21767954672537, 46.28571348805582, 47.722454147954146, 49.20228988893571, 54.947412936918205, 57.4343603657138, 56.78354893961261, 62.588998040845325, 64.44051757935556, 55.5741370877912, 54.70495554708666, 54.747403437091464, 48.854112855849735, 53.29643634057815, 46.67104713378414, 46.96242040203464, 51.844139560576416, 53.39268345986643, 55.89201773366621, 56.17171802828389, 55.44588342789681, 57.17640961370161, 63.577270584721724, 59.77080252862746, 57.810562733680975, 55.62924638871224, 50.88026023680165, 48.129403975702104, 49.52886642948274, 47.858791812773674, 45.91552803593297, 45.39330759356099, 47.89545028440414, 51.853341441000666, 56.28955779537078, 56.23103603239983, 59.288798147632235, 53.156580309714045, 53.9838356356467, 54.28446569750386, 55.166312571494814, 59.67557522558398, 57.157127241934504, 61.21075168732674, 58.02734036599436, 62.804493058112364, 57.67871226033857, 61.18129468733265, 57.93989504537275, 57.54138223586544, 52.93082437207622, 49.248044336995775, 52.93691581295383, 47.92794712128178, 51.07654740733486, 51.670280502688506, 54.92598110629667, 53.42288571019327, 58.21900698446459, 64.88681662467219, 68.45008204060217, 71.7431785214332, 68.07709601617628, 69.60730675728091, 68.19016225876348, 71.85525632673695, 66.37774482850106, 62.81418915717833, 60.58380788372409, 62.68835167731009, 60.363119648348906, 65.53930682520713, 65.2083960656197, 68.21777574477657, 67.03524389574605, 68.96680724236273, 64.52416212328019, 61.70403680493755, 62.22240547980032, 70.64343221725957, 74.27975177764893, 88.92013965114471, 75.68301108575638, 99.32965509353146, 10.623081634121558, 5.543783864667339, 96.189695788968, 63.931852848299094, 68.24037644170946, 41.16242731771162, 67.25120175269343, 63.43375890485702, 90.16058137339931, 6.2931502346069585, 0.3380822925077331, 0.29301284962604124, 0.13686373739713623, 0.12057812538959327, 0.18467605083940491, 0.19279669008908734, 0.2539757515994772, 0.08000477592671111], [0.018378269272826372, 0.10253843250534228, 0.09512355175590324, 0.07328567155186208, 0.0431484850724378, 0.04391820425347936, 0.04817373840318573, 0.0674462276360681, 0.10460939799104968, 0.24485443298134113, 9.467647479426477, 64.74716847942722, 42.161415776898785, 31.00660489451501, 35.839112035689816, 46.91760732281593, 44.80060608156266, 79.78903447428058, 5.319768969089755, 0.300092390708385, 64.14735571030648, 75.80710703326811, 73.93644240594679, 73.10009894832488, 67.04055478495937, 59.440405599532596, 60.02628218743109, 60.34164859402565, 61.98436860115298, 66.09931930418938, 65.68719979255431, 65.4648994630383, 65.19108664604926, 64.28466220055857, 59.7798788932062, 55.718821556337424, 58.03096071366341, 63.29377343577724, 65.99288971193376, 66.06513192576747, 65.97886331619756, 65.08431580758864, 64.96517381360455, 64.10719456211214, 63.25170993804932, 56.366142072985255, 48.7875541563957, 46.83229184919789, 47.41476381978681, 43.9071136905301, 44.64526845562843, 43.92772182341545, 43.98782822393602, 43.75848331759053, 45.46331405639649, 49.010505599360314, 52.21672550324471, 47.78840880240164, 54.57381110037527, 55.93936074164606, 57.55117247181555, 57.35857625161448, 59.41961311524915, 57.25620239011703, 50.292932371939386, 47.20072007948353, 51.351195689170595, 58.224761101507376, 56.976525629720385, 57.63644872173187, 50.14716140685543, 43.83272201784196, 43.342492426595385, 41.27978855563749, 41.821915026633974, 42.94860409152123, 43.31787563139393, 44.297652321477095, 47.57849139551963, 46.859932791802194, 47.97112849450881, 46.671133425927934, 48.966841774602095, 47.73580589602071, 50.83119530831614, 50.85330178660732, 47.22014757894701, 48.81910570206181, 43.97366454524379, 44.92139547101913, 48.94535110842798, 50.59075793912334, 47.84906433474633, 50.230786338929214, 46.51937300159086, 45.49471655199605, 48.327397377260276, 45.820818485752234, 46.25713117661015, 47.015035075526086, 44.8763588167006, 42.102827333634906, 39.98703026002453, 41.51638592443159, 40.16620020712576, 40.00493195749099, 45.705253693365286, 49.855289997593054, 51.99028707319691, 57.871139818622225, 54.359834040364916, 45.69301982079783, 42.34051512133691, 51.997802334447066, 55.791044158320275, 56.39497933849212, 56.923808974604455, 56.14059402096657, 53.68062465421615, 52.75259971618653, 50.395694548083895, 50.53131049679172, 46.904537985401774, 46.17082726570868, 40.51736216391287, 43.28005613819246, 44.07957638463667, 42.56045418400919, 44.9989995648784, 46.98521329510597, 47.23021630317935, 48.24305072907479, 53.03282953077748, 61.152406431013546, 60.68867245028096, 62.46827925405195, 62.73431008861911, 65.22355994870587, 62.218926337457475, 63.99800754362538, 62.33576590015043, 65.08096218109131, 62.82464227368755, 62.78828974693053, 57.6317261880444, 59.133570348062825, 56.21220865557271, 60.076159046542266, 57.891857777872396, 61.20522114538378, 56.2745508070915, 59.10250125392791, 56.36089786406487, 63.5788748341222, 65.443291125759, 80.6607969345585, 66.92338574317195, 91.82447433471681, 3.534403390461399, 11.82640596743553, 78.94002176100209, 47.82137240132978, 48.301745076333326, 55.88379644578504, 66.96873618710426, 47.73269153410389, 69.032483408528, 1.545569639532797, 0.08138670661156217, 0.052270837909271645, 0.020189147908240557, 0.053546730534083424, 0.03922672010958195, 0.055184967425321384, 0.0789667344501903, 0.07361461438478963, 0.02160734711064687, 0.15200097594530354, 0.015254674081300056, 0.060094510835985986, 0.037682815454900265, 0.07333258677634501, 0.013923138575327974, 0.07040074530748591, 0.04373505178298201, 0.26153846433566463, 10.126641950299664, 75.74969137868574, 40.830402604995236, 35.85061242503505, 48.894725076613895, 50.97121607872748, 52.529601204779844, 86.81399945289859, 6.908545109533495, 0.17763849137531174, 69.60499255887925, 79.9873181312315, 78.37018766710835, 73.88020346241613, 69.92084533937516, 62.624832814739605, 62.58617393432125, 62.74236271458288, 66.77195872029951, 69.04421129534322, 69.06165799786969, 69.49709600017917, 66.96556691200503, 68.6202109244562, 63.41630827996039, 58.680434611535844, 60.444575509717396, 65.01794930427306, 69.03282073236281, 68.64921292951031, 66.391355452999, 68.45209029413039, 65.15461644818707, 65.73897900119906, 66.97347441027242, 58.02069587092246, 51.52906340937461, 49.705337785905414, 49.50262577302995, 47.54235067675191, 46.861125192334576, 47.79730866032262, 48.44706889121763, 45.41190747291812, 49.06954903756419, 51.689896275920255, 54.18274294945502, 52.17059058527793, 55.910452873476096, 59.44496339367282, 57.221128556036184, 60.056405990354484, 62.79284361870059, 58.686153427247085, 50.44295126391996, 48.05769128184165, 52.72410761925482, 61.11298268841159, 59.669699515065844, 61.04033254807996, 50.49510309773107, 45.58145976835682, 45.2209625705596, 43.81136863462387, 44.09585814322195, 44.171163728160245, 42.84145670552408, 45.17600436364451, 48.22399585477768, 51.929968864687034, 52.301040772468816, 51.06075202265094, 54.52094147282263, 52.87310277262042, 53.645641034649266, 54.7138475602673, 50.157186985015876, 48.62326175935807, 44.41669625620688, 44.13359134427963, 49.473729671970496, 51.981151873065585, 52.03466476932649, 53.18114611410326, 52.382798656340576, 49.836446931285245, 53.63793357726067, 51.48427386437693, 50.40535142344814, 51.28134219877182, 46.035395668398955, 43.8211118021319, 43.01904985981603, 43.417939216859885, 41.29395615669989, 43.145189362187544, 47.470061394476126, 51.13007991544662, 54.92492206635014, 60.156049882211995, 57.68857702132195, 48.619068745643865, 46.93849002161334, 52.354279102817664, 58.032933665860085, 59.02362631213281, 63.78353234260314, 60.432008235685295, 56.54490017121839, 56.127763948132916, 54.23200007407896, 53.987601111012125, 49.17235043741042, 48.38616624955208, 44.75462805840277, 45.42317644242318, 45.94191382008214, 45.81313848495484, 47.65839399829988, 49.666831877923784, 50.34530778085032, 51.31018338664886, 55.88163521982009, 63.65452558763566, 63.29731925841301, 65.44763318953976, 65.54533158579181, 69.18893890996134, 65.85583425337269, 68.1665966587682, 65.79290374632805, 70.95646089123142, 67.31817230101555, 67.51924084078881, 62.77507920419017, 63.28324187186457, 58.48332766563662, 61.687609918655895, 60.87760125437091, 64.67020765427621, 59.738744997209125, 65.40029410393008, 58.64653748850669, 69.07464888788039, 68.3565805804345, 85.32367921644642, 72.19317636182232, 97.86648550341206, 3.4619770703777193, 14.872066590093798, 87.9433439623925, 53.068381894019346, 55.20817995071412, 55.89917605923068, 65.5720390042951, 48.666745155088364, 79.55530043571227, 1.682110409582815, 0.05730627254853326, 0.0331105882181756, 0.06036112092495446, 0.10249085078436522, 0.09333202450145638, 0.0426228606562701, 0.08411787900953524, 0.06071435640596094, 0.09816649129554149, 0.19397147059921296, 0.19173904442258421, 0.1366368834409983, 0.1451991110919945, 0.14035118413307976, 0.23111631613104577, 0.15634487833707564, 0.23876216472877612, 0.4115915851246926, 15.358233586434396, 86.98958827603249, 55.69727205461072, 39.28507112687634, 48.56100589998307, 67.87106175576487, 56.57128595536756, 96.57394686052876, 6.067937545238003, 0.9093876735818003, 74.99964790959513, 81.73699332821755, 78.90759944915771, 76.02599097836402, 74.47860025590467, 64.43875643514818, 66.41990246311312, 66.19636658699282, 67.373791510059, 73.89775999130742, 71.38298726850941, 71.67303869801184, 68.80005944159724, 68.574476088247, 63.766815200928725, 62.08010581231887, 64.39104080200195, 69.78974403873568, 70.67785493789181, 71.18820236575219, 69.15673625084662, 70.80756771949031, 68.69872108582528, 68.43568694206976, 69.60132122039795, 61.18482874285791, 53.410738129769605, 53.703013543159734, 52.28998753332323, 50.674779030584524, 48.91468994079098, 49.526218829616425, 50.33789057885447, 48.67450360328921, 50.58263863286665, 53.67304663504324, 56.49242670305314, 53.59020617700393, 59.52961598673175, 63.06247518908594, 61.429463048135084, 63.586754875798384, 66.36291042450937, 60.744483855462846, 50.96552864197762, 49.630459739315896, 54.98585608697707, 63.92656941567699, 61.86823114272087, 62.898316152634166, 54.786034860918605, 46.31531953811646, 47.91538376961985, 46.22737607648296, 48.54523797189036, 46.52447208281487, 45.19217629586497, 47.85840742049679, 53.95937573525214, 57.62233603385187, 56.47114392249816, 58.246318447974424, 61.427176306324625, 54.18361763800345, 58.392383590821304, 58.69582206972184, 52.41498954834477, 50.22957824891614, 45.200079871762185, 43.77326280839982, 52.1516651491965, 54.11722367809665, 54.990755127322295, 57.72102286738735, 56.9223145515688, 53.36496799222885, 57.966524016472604, 56.56860697653986, 54.469997729024584, 55.673161245161495, 50.28568775423112, 47.34678914470058, 44.50722848215411, 46.75466814348775, 45.36345051180932, 44.72512006759644, 50.94049999790808, 54.77227910872429, 58.36486031932216, 62.750380039215095, 61.227127582796165, 51.00239892159739, 50.544152336735884, 54.079219833497085, 59.4970916932629, 61.16669562555129, 67.7827613584457, 65.86172565337151, 59.774811190943566, 58.98208056726764, 55.24067678759175, 57.28999360915154, 49.26139608506234, 50.907901179405954, 47.34715000275643, 49.15311513408538, 49.514753741602746, 49.593110930535104, 49.82969260984852, 51.848246282146825, 52.276259237720126, 52.640314025263635, 59.165608267630304, 66.2857024900375, 65.82247057268697, 67.23689294630482, 67.85369350064185, 71.56476559177523, 67.87519593392649, 71.5618787273284, 68.3106731599377, 72.69908366664764, 68.12797700205158, 69.07022445432602, 63.899689412886104, 68.14438819885254, 61.85532262248378, 65.357657940157, 65.05234064594393, 69.69329295619842, 64.01536403163787, 67.26750312312957, 60.56284281515307, 71.77734236563407, 71.93757903191351, 90.81155361667757, 73.50102793785834, 103.5896707350208, 5.181149955718748, 15.453408918073102, 95.45478482400218, 63.219903438322014, 64.90958990589266, 79.04467844193982, 86.28759384155275, 62.4369748177067, 91.3259881542575, 2.377649848499606, 0.24266331426558957, 0.24615440758005266, 0.12514480614974616, 0.2233012846761173, 0.20038583285866246, 0.11765969812028831, 0.24662501539193818, 0.26193563495912864], [0.07896223751407477, 0.02380334389125628, 0.03837692941869459, 0.04101276600493058, 0.022756930988942905, 0.04252889614191748, 0.06202039076015354, 0.07582676987494193, 0.16432170756161213, 0.34564094497792186, 5.122179081363063, 62.485184669494636, 51.34794012192757, 40.90186034479449, 20.259738160717873, 42.66536974137829, 38.60954484631939, 77.8264138006395, 18.06632326495263, 0.17686031458358611, 48.71701425121677, 79.19094362566548, 71.1081781694966, 72.0716142654419, 65.24076346428164, 61.22497420157156, 62.44772211197884, 63.23070564577657, 62.50345506975728, 64.61769104003906, 62.90379962613506, 64.75739017609628, 62.15107717821675, 60.660337248156154, 55.62102117846089, 56.06177399235388, 62.20494308779317, 64.28781970854729, 64.43942323807748, 66.10444191963443, 65.03125006152739, 64.36996982943627, 64.39615949507683, 63.04658566751788, 60.34947764488959, 51.100246367915986, 46.90930758753131, 48.540393844727554, 46.07063816439721, 46.98382477606497, 45.15022262450188, 44.99597149510538, 44.33202797366727, 42.44038651066442, 44.7992685533339, 49.170157832484094, 48.670593000227406, 50.270504259294086, 51.33057578917473, 56.830299669696444, 56.252844410557906, 56.80930322216403, 58.085167869444824, 61.264299884919204, 56.41754865646363, 51.513271947060865, 51.06228174701814, 56.90035320097401, 56.39631686672088, 54.23429858299994, 49.20737328067903, 46.6998294861086, 45.19076424260294, 45.19657327282814, 42.785272675175825, 43.23531366163685, 44.10167894055767, 41.16614572463497, 47.494505605389996, 46.637150010754986, 46.82322725172966, 47.41728198143744, 46.639111195841146, 49.71499466126966, 53.24524548745925, 50.8835393382657, 50.620367911554155, 50.331818749827725, 45.4735710543971, 46.247231114295225, 42.60409839691655, 48.97326661694435, 52.48329370252548, 51.44041784348027, 47.484146625764915, 42.61916422074841, 44.995606714679354, 47.321054474000015, 47.86718176257226, 46.44832318828952, 44.50826791024978, 42.476688046609205, 40.50902320492653, 40.28543241562382, 41.590487341726984, 41.73901573304207, 46.71789984549246, 50.858655821892526, 55.66921141839797, 56.28086582306893, 53.095105002003336, 46.93970987873693, 45.46824447570309, 55.83360579706008, 59.021857323185095, 56.10756766411566, 58.097437043343824, 55.51728625451365, 52.37460874742078, 48.93481169977496, 48.19387597422446, 46.651556876397905, 45.753996987496656, 44.519525112644324, 40.986650220809445, 42.31503148232737, 43.11278666219404, 42.62326309757848, 45.860877652322095, 45.8353744014617, 46.05901618157664, 47.92118103273454, 54.504812686674065, 61.26426850595782, 61.107146201595185, 62.89473502866684, 58.07134151458741, 61.13444982036468, 65.7915505286186, 65.85934085230674, 65.41710538248863, 63.11526636923514, 64.77311103574692, 66.13982169858872, 65.3546416374945, 64.35579046126335, 54.689654381044456, 57.384648246149865, 56.95802773198774, 60.200623696850194, 59.37319186425979, 59.60999711867302, 62.043639536826845, 65.3149394066103, 72.41552768215057, 80.68863007330125, 74.24328157978674, 85.10092781436059, 1.1557810393071946, 17.607900173433368, 79.40568554785945, 41.35352127013668, 42.95477397980229, 90.88572563663607, 35.204841244605284, 48.38952379841959, 63.06724479121547, 1.40648937994434, 0.04975043928190585, 0.06625434804347254, 0.05259569749356278, 0.05318304561378975, 0.05962630470974311, 0.07866599131375551, 0.03846640848825055, 0.024442458487746697, 0.10412726055590377, 0.031856500370908654, 0.025420806393207564, 0.03326002898956499, 0.02701276582815955, 0.07184348805176635, 0.07021920545206917, 0.04070546515586396, 0.23823086743152913, 0.2216260495685762, 5.5380464176977835, 71.06500071863975, 51.33653779183665, 38.421392671523556, 34.810035074910815, 51.33449423697687, 45.64273895755891, 82.9256989878993, 22.14756904109832, 0.22490306727347836, 52.07275882844002, 82.02760173428445, 74.33457866791757, 76.06486951151203, 66.43382687722483, 65.60921522878832, 65.83197839798467, 66.19731580057453, 65.04109128828972, 67.32147493670064, 66.5828690990325, 66.62055523164811, 64.16534369991672, 65.23786875509447, 58.48552811530329, 59.28398147706063, 64.75872770432504, 67.74815820878553, 68.44379055884578, 65.1354831264865, 67.80100037974697, 65.69103587058284, 66.60681909130466, 66.14694472282164, 63.13704729080201, 53.71909133849606, 49.49987226916898, 50.96710151241672, 48.80737781524659, 48.89634109312489, 47.2538564282079, 46.303054286587624, 46.80091288781936, 44.95806963213029, 46.77910843203145, 50.989839492305634, 50.18262355558334, 52.81406325678672, 55.38658111326156, 56.9041657447815, 59.16370591809673, 59.3085825827814, 60.90237886674943, 62.21875767554007, 58.91278013106316, 55.68630118523875, 52.27265457953177, 58.998417239035334, 57.849496180011386, 56.17933527115853, 51.156944228756814, 49.19815963314426, 46.62256271608415, 45.77893541705224, 44.330886563947125, 46.16213137103666, 46.132878334291526, 44.68608071727138, 48.762831457199596, 49.46400611631332, 49.47445923282255, 50.96021775276431, 51.06072064368956, 55.1469752865453, 54.656549576790106, 53.5198780798143, 54.20932877448298, 51.2592984784034, 43.64696641122141, 44.63565080396591, 43.49628071631155, 50.79621168874925, 54.37676299002863, 55.18716389133085, 52.63770564909905, 46.98393460242979, 49.35476810701432, 52.53700663966518, 51.086518072312884, 49.210836733541186, 47.9475393602925, 44.61249313046856, 43.47911642443749, 42.136987255465606, 42.21073958181566, 46.684983315006384, 47.58351987408054, 53.6989382005507, 59.912141215416696, 57.07403182983399, 56.764035148005334, 49.84461722835418, 48.574090926877915, 58.76107854227866, 59.12898117496122, 61.11409271917036, 60.29034006980158, 59.963465429121456, 55.50750778567407, 53.79796628029116, 50.68003500661543, 49.1684006106469, 47.335265221134314, 48.17855911870157, 43.82605398854902, 44.59354023779593, 44.073249601548724, 48.3123040968372, 48.66421522632722, 50.20775418127737, 49.33712920834942, 50.76859820273615, 56.31416282346172, 64.36189366925147, 63.06607200253395, 66.7159237400178, 57.27034253458823, 64.19514586848598, 64.52005932407995, 69.66138055247646, 71.98896208117085, 70.3753617502028, 67.6624857994818, 68.70430654095065, 69.50411704278761, 69.45493836556712, 62.05927802670387, 60.35608683862994, 61.51633178034137, 63.44937386051301, 60.888164197244954, 64.6984447971467, 66.56428490915607, 69.54070491175499, 75.18810995163457, 85.66879287842782, 80.27045049974996, 87.93243977331346, 1.0679132058735819, 22.878104602136922, 84.25102864542316, 51.11495917843234, 51.83386295072494, 108.12058095009097, 46.92201998925979, 51.221243642991595, 71.24710067625969, 1.2704663627570676, 0.08023031987249851, 0.06226276948807701, 0.04197869179469924, 0.01266932843493358, 0.053401641142103946, 0.10717213829799045, 0.07102640931524577, 0.053501064032917066, 0.2350300448315759, 0.07528518401687184, 0.15662163526060122, 0.18353631119093589, 0.11674082162038935, 0.16014954676070522, 0.2990884784488909, 0.301004862713237, 0.4062331371730374, 0.48942826327777683, 9.403494173480619, 84.08967802601477, 65.85702665390508, 58.367864854874156, 32.306001801644605, 62.05266491059334, 51.80842638015748, 93.72854186642556, 22.488666196023267, 0.184331541099856, 58.63188743591309, 83.24641550740888, 78.42437128866874, 78.2606044892342, 70.46170880717617, 65.52591585343885, 69.16108223699754, 69.39091743961458, 67.01081537431287, 68.81792191536196, 69.58620440575385, 69.90378302912559, 67.05735821877757, 67.63502920827558, 60.69149655680503, 59.779443510117076, 66.10430855904856, 69.95256162458851, 68.4340944597798, 68.18379232960363, 69.66599325979911, 69.99066352844238, 69.09722605059224, 69.37881300526281, 68.17861480097618, 55.10996380159932, 52.32355517725791, 53.84467778667327, 50.33353282559303, 53.6088413576926, 51.02562719775785, 50.39253704009518, 50.60722012673655, 47.79224880280034, 49.72988005607359, 53.13508964353993, 54.84984005651167, 55.70723879721857, 57.34967247132332, 62.27820119550152, 62.60999448837773, 62.10603660152805, 65.56232721574845, 64.92792698644823, 61.20788443473078, 55.373492163996545, 54.83397799153482, 62.97800302505494, 61.32310405854256, 58.87016357914094, 54.763802866781916, 51.10306655206988, 48.277449915486, 48.09173353256718, 47.771927002937566, 47.237602126213815, 49.544418627215975, 46.97718812573341, 52.33973495421871, 52.73982063416512, 53.940109052965724, 56.29998737765897, 56.56588485164028, 59.2077031443196, 62.4563709382088, 56.35957994768697, 57.416074275970466, 52.615960028863725, 44.90881642987652, 46.61662424764326, 43.456256851073235, 52.54863254485592, 56.36754628150695, 60.864202437862275, 57.193134600116366, 55.72551311985139, 55.06671182570919, 58.58017490756128, 55.93091195629489, 52.6644483689339, 50.7078799124687, 47.29295461408554, 45.00241202692832, 44.12426002563969, 45.70706190601472, 48.99691066434307, 50.69632853231123, 58.48191953474476, 62.06981351298671, 57.89487800290508, 60.05647267064741, 55.413778828036406, 52.48894583794379, 59.67533988337363, 64.32011258217597, 64.71500112164405, 65.6808965436874, 63.54542486129269, 59.46036654133951, 55.99924356706681, 55.57390174558086, 51.629656514813824, 50.754379610861506, 49.65077369443832, 47.25090288346814, 48.39964743583433, 48.75117417304747, 51.00325792066513, 51.31713774896438, 52.256223770879934, 51.3378910095461, 55.34368999542729, 60.651045153217936, 66.34872713396626, 64.76209702030306, 68.5044696254115, 61.11573619227256, 65.41966276784098, 70.51307616695281, 72.98556573929326, 72.48522820011263, 70.5314250146189, 70.54192912194037, 72.61181877505395, 72.2784879130702, 72.46584384672104, 63.48048610071983, 64.79550776943084, 64.12005993627733, 67.4539961353425, 65.79171919053601, 67.24785989330661, 69.51797869897658, 72.49996062247985, 78.83874616315289, 89.23761629289197, 80.41073014659267, 94.60679977170884, 2.184531217621219, 22.440413198163434, 96.59541007011168, 56.093121574771025, 60.648530913937485, 111.06821860036543, 50.60474118878765, 62.0454595165868, 85.8487904456354, 2.136179425062672, 0.14535105697089626, 0.12452583008956526, 0.13482629591899534, 0.16460689145230478, 0.14611677717297308, 0.1678290266183115, 0.24641424928221012, 0.12495909111514208], [0.1209865804881819, 0.0720994993143024, 0.0365740487412099, 0.022306258700067, 0.024489111327115568, 0.05813933954003358, 0.06648220557479129, 0.05308983186560293, 0.05979884303204956, 0.07920599136982234, 1.5809141171555368, 56.45429342023788, 54.04993934016074, 37.14130755393736, 16.67666869778787, 35.49008384827645, 46.399093520256784, 69.00210857391357, 43.16100043635215, 0.7378119254304517, 25.586477671900106, 88.68023180192517, 68.11770823694044, 75.39055132096814, 66.88335403319329, 67.10273219693092, 63.17857342381632, 64.71236528888826, 59.57680209990471, 61.19934543486565, 59.17736361103674, 59.847014181075565, 57.576781626670595, 58.09952766664567, 56.04191895454161, 61.301044648693455, 61.80635575325259, 63.413570465580115, 68.37626303395918, 66.91883579377206, 64.38118388575893, 65.61818961174258, 62.9087535796627, 59.53736266782207, 51.47798238262054, 47.83809738774454, 48.5643595264804, 47.31940707852764, 47.04915185128489, 45.10341698123563, 45.25833491356143, 43.17550536124937, 41.79607052956858, 42.345080760217485, 43.68306398391724, 47.29890092726677, 44.38551341333697, 49.29779568026143, 49.9244962969134, 53.22069537255072, 55.83975607349027, 57.93429390076668, 56.72714133416453, 56.480294812110166, 56.263862348371944, 60.2781807222674, 58.26494186155258, 59.11548037682811, 55.95547776068411, 56.993195702952725, 50.9635478450406, 47.31923057186989, 43.892436181345296, 44.96158015343451, 42.05525682818505, 43.65976902746385, 42.463159791884884, 44.64226392007644, 44.34386176447715, 47.672710649428836, 44.25610265424175, 46.471241597206365, 46.56244454845306, 49.78649162477063, 51.702710659273215, 50.002445559347834, 46.63697742646741, 46.01225760675246, 45.555983974087624, 40.39500382638747, 45.62469605476626, 45.32352470582532, 50.86990517954673, 50.95178073452365, 45.44479654681298, 41.860601363643525, 46.978721772470784, 45.826415707988126, 47.483628872902166, 46.98236957673104, 44.09700347531227, 43.188009877358716, 40.474231781498084, 41.28764506309263, 41.68156477712816, 42.795772860127116, 46.717229120193, 45.78221844088647, 56.5439627247472, 59.060045519182765, 55.44918214121173, 43.95133056948262, 45.23742475817281, 58.86966936049923, 53.25580450796312, 56.21505629631781, 57.008755745426306, 55.14553185432188, 50.30239705116519, 47.25674329265472, 44.917324050780266, 44.677408356820386, 43.89446404672439, 43.050966185908166, 40.73681093031361, 41.671837299100815, 43.63213985197006, 44.15577234760408, 45.49753281377977, 48.109093942949855, 46.68988235535161, 48.26014441828574, 48.45720037337273, 58.72578113309799, 61.780279836347034, 62.10442450738723, 59.839189052581794, 60.71261459781278, 55.81136988055322, 59.96225733910838, 64.19912315184071, 64.79279741164177, 66.32129407698109, 63.91661836254982, 63.59111655143, 69.17707766256025, 63.775609154855054, 58.72671857956917, 56.09842069687382, 56.55414519771453, 58.88125996435843, 59.29579173364947, 63.43329998754687, 66.3533555307696, 73.59812228910386, 78.61534364761846, 84.80232561788252, 64.60627302046746, 0.12888726057304492, 32.79573521306438, 71.15087709119244, 48.769001345480646, 31.357005911488688, 39.56227287169426, 45.25305540330949, 58.734606465985706, 55.14960327456075, 0.41064203446430547, 0.07113959114517897, 0.029619328279588974, 0.03806234690390768, 0.03582728921525902, 0.041269275224617416, 0.004929384609098517, 0.05923512106340739, 0.0189274164187091, 0.04403106432648436, 0.08816805563025898, 0.041234613576483344, 0.01764372693404796, 0.06571023409525234, 0.023019222257238244, 0.046092315817311894, 0.0568080549278567, 0.06716623782150208, 0.04006673168811587, 1.7234154189786606, 65.53975789777695, 61.74997952676589, 37.55536079406738, 24.084027505690052, 45.73678562718053, 53.22943441329464, 76.95348247405022, 50.335399873795055, 0.5544093119040613, 25.775500612874186, 92.47504649623748, 70.76517474266791, 80.12459324252221, 69.9635991742534, 70.54667518984887, 65.20433249012117, 69.1096442745578, 64.55189328039846, 63.78114754153837, 61.813153220761215, 63.365537120449936, 61.11537533421671, 60.28741790402321, 57.730601295348144, 66.43454859333654, 64.37441779721168, 67.37715690366684, 67.62235210787865, 67.58861972439674, 66.02794001179358, 68.24617370482414, 64.33633550520867, 59.97517370408582, 54.59846319690828, 49.20063464872299, 50.483014352859996, 51.40484586838753, 48.49876180771859, 48.94836348872031, 46.39464555248138, 48.7929238811616, 43.57008403347385, 44.85493090844924, 47.54193490551364, 50.388583290961485, 48.45779265126875, 50.49698583541378, 52.06771466039842, 55.23210640876524, 58.93576522027293, 61.447517718038256, 59.98686628956949, 59.34005175867389, 60.23047293386152, 61.55703029324932, 62.04132533842518, 60.808932319764175, 57.68056754143008, 58.96939954450054, 53.72817947018532, 47.607462021612356, 46.24157113413657, 46.23960602668024, 43.95104031408987, 44.67614927599507, 44.11137111725346, 43.421041811666186, 46.8577637210969, 49.449359986089895, 48.00646904976138, 49.91538463100311, 51.03267177458733, 53.527746354379964, 55.13387064779959, 55.91776024910712, 48.37521106966081, 46.04150672112742, 44.30284946195541, 40.65888127973003, 45.24281409478957, 47.09855410360521, 53.78324562503446, 53.59738411441926, 47.61262386075912, 46.29850825955791, 48.50245668042091, 49.54644257022489, 50.240682478873964, 49.390885291561005, 46.98162040402813, 45.83313080572313, 41.42965447518134, 43.94585886309224, 43.603020175810784, 45.0911517297068, 47.37483016906246, 49.0137807784542, 57.199304488397416, 58.666812219927394, 57.90238541941489, 50.67603418903966, 48.74776171099756, 61.09472797762964, 58.03623630154518, 60.39322383942143, 59.37385866718908, 57.36988444482127, 53.41294250180645, 51.47696256637574, 45.75943731492566, 47.19684085538311, 46.48293418269004, 47.447939226704264, 42.510844046069735, 44.34197902679444, 45.43124083549746, 47.95986344737392, 49.025355692832704, 49.15936346976988, 49.41840464068998, 51.41576182457709, 51.386995161733324, 62.98369438417497, 64.4582623820151, 65.34816580434, 65.38789549181539, 62.61148498904321, 59.526631063030614, 62.33410281519737, 63.19111716362738, 65.58774809683523, 70.41046696324503, 68.15419412428334, 68.45083513567525, 71.10609931330528, 67.31164547704881, 63.958591645763775, 60.94545433598181, 60.94246156754033, 61.92079090302991, 62.285920420000636, 65.0386005832303, 71.00708300067534, 79.0094163340907, 81.63010089628159, 88.14475767074093, 63.2532004387148, 0.0580323362092097, 40.78364795254123, 77.79956125443982, 54.847310127750525, 40.56495228121358, 48.22944010457685, 52.513448884410245, 67.76526758747717, 62.38222245247134, 0.5395260621463099, 0.05098756785774904, 0.04557378537532303, 0.07269657292072812, 0.05265740204542395, 0.01946857901320102, 0.030087892551936453, 0.09988372334309163, 0.02110141115413318, 0.22443380777633962, 0.18674720018621416, 0.15142204330092476, 0.0752486492837629, 0.14070580623322917, 0.10928119367529308, 0.1564860070544866, 0.20153125687952966, 0.1789731391134762, 0.11789196065717167, 3.055737191630948, 78.11261346263271, 70.2355920114825, 50.014263660677024, 24.316939807707264, 53.668229964471635, 59.72375369841053, 84.57998214229461, 52.26726916528518, 0.782364596041941, 33.04181098937988, 96.3703287801435, 72.66613575720018, 80.72579060831379, 72.27304366327101, 73.17707938532676, 69.12054061889648, 70.35749927643808, 66.36469118056759, 68.50188870583811, 65.40216507450228, 65.98539014016428, 64.56494300596177, 61.82537532621815, 59.53631147261589, 67.61644501839915, 67.00904246299498, 70.07539456890476, 71.75905627589073, 71.19795337800058, 68.78724898061445, 71.74239404739873, 68.22443592932918, 64.0242991908904, 56.10987794014716, 53.27800120076826, 52.57324934005738, 53.87160485790622, 51.9240225515058, 52.68440538837064, 48.8657073820791, 48.021487805151175, 45.83881824247299, 47.3392621163399, 48.84902161936606, 52.23628244092388, 50.99674286380891, 54.5009962204964, 54.39508830347369, 59.37517266119681, 60.13071137089884, 65.7660472777582, 62.17835726276521, 64.26450906261321, 62.310886306147424, 65.36584000433645, 65.34675767344814, 62.88049682494133, 59.62304684423632, 60.92427745942147, 56.15615406344014, 50.066160540426935, 47.02149521919989, 48.87874534053188, 47.45759610206851, 48.36106700281943, 47.65393426341396, 47.304192204629224, 49.8534700178331, 55.044954438363355, 53.18759841303672, 54.74525790060721, 57.63915907952094, 59.44141757103705, 58.59407578745196, 58.08050417130994, 49.66668282785724, 46.46529528402513, 45.60571570550242, 40.70116050781743, 46.720139518860854, 47.972085552830855, 56.700814385567945, 57.37417551778979, 52.76807346651631, 52.149092074363466, 55.71476582557925, 54.307654749962595, 53.67703176313832, 55.40175676345826, 51.1313586081228, 47.72861619149485, 43.07608896686185, 46.07522733749882, 46.846934057051136, 47.78550232610395, 51.16072539360293, 51.68275756220664, 60.33676916553129, 60.566329802236254, 61.981344453750125, 53.398221846549745, 52.34892506753245, 65.36305119914394, 60.8270497475901, 64.10128355026245, 63.30888632805117, 61.75802038561914, 58.00008381566694, 53.87846116096743, 48.966163204562285, 50.50472467176376, 48.42326010427168, 49.86064403287826, 47.03201501600204, 46.072979819390085, 48.533796418097715, 50.93842506408692, 52.36749749029837, 51.63875249124343, 52.79983289780156, 54.14695524400281, 52.546267355642016, 66.01839296279415, 67.37427003922002, 68.25888218418245, 66.77713624892696, 64.72634069381222, 61.921567532324026, 67.32827632657944, 68.10545475252214, 71.62556232944613, 71.56197286421254, 72.30122197058894, 70.71717277649911, 75.31332769701558, 68.9402763305172, 65.85555184272029, 64.13677707795175, 62.77536553721275, 66.19170681122812, 66.37853714727586, 69.45710351390224, 74.77479411709693, 80.87631548604658, 86.5704281099381, 90.54382047345563, 73.89797964403706, 0.4294260200713912, 40.2108956152393, 88.04017943720665, 63.31351080248433, 47.39543830194781, 47.19109458308066, 59.11785733315253, 75.70161096511349, 75.1227318856024, 1.1047279594406005, 0.18053589719197444, 0.14862591430785196, 0.13333870638762751, 0.19524443293771437, 0.15296440811887865, 0.1265740734074385, 0.2575014874098763, 0.15319020487368107], [0.05266311706133908, 0.05672201942352038, 0.05619426145248356, 0.08007633619971814, 0.04424778293938406, 0.047470297318913286, 0.06708357693447221, 0.03762326744054595, 0.059998091009836045, 0.057173639746202584, 0.3591525296290075, 49.03793081160515, 52.237659192854366, 49.729566266459805, 45.23313760757447, 36.346521608291134, 43.4388062261766, 57.56057047074842, 65.44821370032527, 0.7432622426459867, 4.047450144444743, 83.7874750937185, 69.01922579734557, 73.44993514399376, 68.79654499792284, 69.89761706321471, 66.44147549906086, 66.1237713598436, 63.9402820217994, 62.46554928441202, 56.4334499451422, 56.250098751437285, 57.12372433754706, 54.70546545520906, 60.309030163672666, 66.36200827936973, 64.17738537634573, 65.58639095675561, 64.1704623929916, 64.78558809526506, 62.0760069354888, 58.59483280489522, 50.32327190522225, 50.69907419143185, 46.9643815871208, 49.05497743237404, 46.561240380810155, 47.96897903565438, 46.49579955685524, 45.750525689894154, 44.17433300325948, 44.77260035853232, 42.96383073253017, 43.05192324423021, 42.729771137237556, 47.23391902062201, 42.961916615886075, 46.38130557152533, 47.29304090622933, 48.96360581920993, 54.5355954477864, 56.95609792586296, 60.30637864143618, 58.37040655074581, 57.29997604124008, 57.17953966509912, 56.296543536647675, 56.59337674417804, 54.70164506666122, 58.530262747118556, 57.33040578903691, 51.77034408815446, 43.515108093138664, 50.41989949441726, 44.07609331992365, 41.61822242121543, 43.24774365271292, 41.24087864352811, 43.32825422286988, 42.646605122473936, 47.739967530773534, 44.305869686988096, 44.31100799191383, 48.45740825899186, 51.481304630156494, 47.06050319056357, 42.84774034254013, 45.04318506486955, 48.30708342213785, 44.46623971385341, 45.17363132969026, 46.62129186814832, 49.028113119063846, 51.122886288550596, 45.87566498787173, 41.991565381326986, 44.11642313003541, 50.56540373832949, 46.95673296528478, 44.19436847009967, 42.55915587948215, 41.23803492515318, 41.73277524209792, 38.48503704993956, 42.56862448107812, 44.13404633921962, 47.28589434777537, 50.57284447454637, 54.240668512159786, 54.05651323256954, 56.86049407528293, 45.72972143850019, 48.946182650904504, 59.44282177955874, 53.37267937198762, 54.34250108657345, 55.240049208364184, 53.68171507312406, 48.10553243083339, 47.420200224845644, 43.581458906973566, 44.621820526738325, 47.21257740451444, 44.184958704056285, 40.98308086395264, 42.225095456646336, 41.581571794325306, 42.191669018037864, 46.42069401279573, 47.03035977578933, 44.87811211616763, 48.16756863747874, 48.356458217866965, 53.862948186935924, 61.85312217281711, 59.062238124109086, 61.31175271926388, 64.01030809648576, 63.23953882340462, 60.44647001451062, 55.58904601681618, 57.54362975397418, 61.99620631433303, 68.03146316159156, 68.63878726959229, 65.51818878419938, 68.77373249300065, 66.29601047885033, 58.90744570762881, 56.42418138442501, 58.53517355457429, 58.73192748715801, 63.88857341581776, 68.27592880495133, 78.97827271492251, 74.76027350271903, 86.87572186993015, 36.35957917859478, 0.1212691443581735, 51.735858609599454, 69.57249964437177, 49.75037836259412, 35.66944991388629, 26.88665120832382, 38.94286394119263, 61.762899814113496, 43.013958623332364, 0.10338201788404297, 0.05963520665142325, 0.06225433102959107, 0.0528463882754647, 0.11207382164655194, 0.009430999127817492, 0.05247606137286752, 0.0857413495560327, 0.06879051276032003, 0.09035830100577685, 0.021514301901803385, 0.04393601579771888, 0.08338670171196423, 0.03914576759862323, 0.05169406946327898, 0.0365695211615774, 0.06159485190085346, 0.049841542457861286, 0.047043923423775745, 0.774904064113094, 58.64784756014424, 58.39071266112789, 42.171127565445445, 41.50684279780234, 45.621299282197036, 50.612217226336085, 63.442219457318714, 74.69247925666072, 1.2103049264800165, 2.9043538051266826, 86.14507059897147, 72.92996221973051, 78.58687508490779, 72.09975334905809, 74.30589045247724, 69.14085065164875, 69.76635886776832, 65.64484996180381, 64.98116531679707, 59.46789356970019, 59.82427620118665, 58.0465756693194, 58.53615414711737, 61.957759241903986, 68.46013899772399, 67.03677362011325, 69.19246119837608, 66.40138887589978, 65.70918859974032, 64.94136110428842, 59.67015451000583, 53.06090193410074, 52.53835985737463, 48.07376907717798, 51.9241363002408, 49.65176605409192, 49.69452381134034, 49.32240070835237, 48.78022716891382, 47.24724331209737, 46.4501823917512, 45.5304140429343, 45.420042468655495, 44.40781993250693, 49.85112051809988, 47.605696955034816, 49.59595857128021, 49.0145456406378, 51.049616413731734, 56.99113253624209, 60.961755706417954, 63.70724616512176, 62.60127898185485, 61.313541320062455, 59.74442851158881, 59.56405439684468, 57.98760675614881, 58.23890909071892, 60.829932689666755, 59.675151609605365, 54.2513765827302, 47.07580435660578, 51.512789495529674, 45.59214430470621, 43.95250728053432, 43.9851963135504, 43.364830324726725, 46.361274027055316, 46.467519267912834, 48.80118831511467, 47.83180982835832, 48.66237955708658, 51.144494625829886, 55.56351530936457, 49.80749199467321, 44.427745572982296, 45.70792482745263, 45.923149201177786, 44.78389286225842, 45.227371723421165, 44.3340362271955, 50.06332466679235, 53.32179838611234, 48.27424533905522, 45.707214878451445, 47.98573147866034, 52.66202042179724, 50.157457628557765, 46.786584469579886, 44.62438183446085, 43.63705458179597, 43.35260821926979, 43.582408120555264, 43.2725840230142, 46.118742112190496, 49.59799820376981, 51.490039748530236, 55.673145555680804, 57.44808473894673, 59.28148292726087, 49.097182135428156, 52.10862890366585, 59.79066933355024, 56.0062018517525, 58.0914475840907, 57.9461512257976, 55.78376423928046, 52.40978848549628, 49.37841607678322, 46.43882320773217, 47.127603177101385, 50.53045149772398, 45.83264835419194, 42.64089807387322, 46.76454467158164, 44.51060564287248, 47.91547790650399, 49.38274637345345, 48.4804129600525, 47.84057632569344, 51.36756766226984, 51.030894940899266, 57.696496286699855, 64.52177339984526, 62.80259463094897, 65.39291220326578, 66.9591812933645, 65.71651166485202, 64.19095285477178, 58.483057022094734, 59.34480174895256, 62.199271340524, 70.25471748844271, 72.8942294274607, 71.43440954146847, 71.06554200572353, 70.08605557103311, 61.66518965075093, 58.9216015415807, 63.57059078831827, 64.43569698641377, 70.44494459705969, 73.62730472318589, 82.98283223182925, 78.85853059830205, 91.40264695690524, 35.53093141125095, 0.09189245336118246, 59.85824000450873, 72.95755217152258, 63.333416831108835, 40.59158517468361, 34.469855754606186, 40.09293817704724, 64.09428996424522, 50.42157434648084, 0.11858717012669771, 0.05235530293336319, 0.06219604706031181, 0.07816349892246147, 0.1304925518530992, 0.05370639857926196, 0.11741792077138541, 0.03912607147808998, 0.08479303995808286, 0.1802808358784645, 0.13455876269407813, 0.14491622546507468, 0.20111637430325632, 0.13171306781230435, 0.23055875733975442, 0.15773603272053505, 0.10486272028497151, 0.12858614205352722, 0.12259984674352793, 1.14814332656322, 73.24627783990675, 65.34810304641724, 65.35146844002509, 58.063022167451926, 54.76564245839273, 58.37730992224909, 70.61331625907653, 77.11835538187336, 1.026988543810383, 6.698686538204071, 93.69001634659307, 73.94249070075251, 80.87159295235911, 74.67611512830182, 77.14930288253292, 70.86777610163536, 71.59030806633734, 68.79609000298285, 68.89927971747615, 63.89701043405841, 64.53693336056125, 61.5192892474513, 61.001281430644376, 63.36640396425801, 73.27032196906306, 69.81587486882364, 71.47550029139366, 68.63859115108367, 68.66095650580623, 68.87194864211544, 63.62352317379367, 55.71433044249012, 57.63127119310441, 52.1448794487984, 54.528241003713305, 53.19645120251564, 52.51629260278518, 51.78036182157455, 50.28513077766665, 51.41977440926337, 50.15793615771879, 47.7551471033404, 49.548752846256384, 46.05307771313576, 52.92678825316891, 50.402488093222345, 52.79077222270351, 52.31130953757994, 52.66020044203728, 59.18538093566895, 63.5928737732672, 66.65897876985612, 68.07282063268846, 63.38993818529191, 62.35316553423482, 63.08325982862904, 64.27610751121276, 61.074727812121, 62.16424849725539, 60.15702263001473, 56.01000655081965, 49.22588294552219, 56.48708443487845, 48.431693200142156, 46.15121149247693, 47.66689377446329, 44.339260824265025, 47.36025071913197, 48.94593554158365, 55.61728708205685, 52.00674926081012, 53.14049466963738, 58.93805980682374, 60.313289857679806, 53.20434693367251, 45.74696417777769, 44.60494256788685, 46.808530130693995, 45.28215154524773, 46.68832125202302, 46.77235018822455, 53.254400299441436, 59.847763353778475, 54.62317805136404, 52.80519870019729, 52.62967263498614, 58.68252915720786, 55.74694102810275, 49.43508648103284, 48.754920036562034, 46.873108033211004, 47.07330580680601, 45.36642759077011, 46.576019871619444, 49.01850331214167, 51.39511054561984, 52.92615675157117, 58.69818725893575, 60.7029341882275, 62.23500021042363, 50.88362955277967, 57.541927445319395, 63.342630478643606, 60.107949856788885, 59.09989680013349, 60.76902612563103, 60.491287016099506, 54.456516542742335, 53.10217311305385, 48.20460757901592, 49.85448198933756, 52.53895998001099, 48.714056784106845, 45.69217258884061, 48.83451277209867, 47.62166492400631, 51.93870006069061, 52.17844317036291, 53.48434140605312, 49.12466618322557, 53.47754786091467, 53.027330367795884, 59.916518580529, 68.38589637510239, 65.86962530689856, 67.38616266558248, 70.69564680899344, 69.55752403505387, 67.78482452515634, 62.42513710452665, 64.4809611382023, 69.48448950244536, 73.74987879107076, 74.9042558670044, 72.65502760487219, 76.24225478018485, 72.87210725968885, 65.17532264032673, 63.837237435002486, 65.55096803172943, 68.71237093402495, 72.66207218170166, 75.91836114083567, 86.55840996773013, 82.27660948230375, 92.77775149191581, 43.597983852509536, 0.18011330777118284, 62.34303405207973, 84.7662711912586, 67.17733567760837, 48.853901047860425, 36.97607378805838, 53.51490059206563, 78.84176638818558, 63.210634877604825, 0.3335861837671649, 0.1942438761433286, 0.07167065095516943, 0.14994714018558303, 0.19145263479121272, 0.1467176812190202, 0.09844897089586144, 0.2824403459746992, 0.2527330190904679], [0.0290471927503184, 0.04158304568620459, 0.03335106321760724, 0.032028354959742676, 0.09266004281779451, 0.05377201784041621, 0.042306956639813806, 0.02101534309106008, 0.04755663925841932, 0.03470658302126873, 0.3402213325663921, 41.618708795116795, 59.505728752382346, 50.16490228714482, 40.14702766172348, 37.570756096993726, 43.15073951598137, 55.543930915094194, 71.89223643272155, 11.076387013158492, 0.2675854414701462, 55.42161964601087, 75.85317919331213, 71.63328939868559, 71.48109359125938, 68.56296000942108, 71.7915335009175, 69.71667812716576, 66.74676141431256, 65.42057668009113, 57.39321862497638, 55.582880050905295, 54.94466727779758, 57.9842492072813, 62.86323447381297, 60.84010731789374, 64.62888156214069, 61.599007498833444, 64.357853627974, 62.75272169420796, 60.147153946661184, 60.1496171951294, 53.796110999199655, 49.555722898052586, 48.88103992708268, 48.62374813325944, 49.166192316239886, 47.651357266210745, 46.81831644427392, 47.67566419416859, 45.34912601594002, 43.05610841320407, 41.216650162973714, 42.64195711381974, 45.554858253848174, 46.86267060618247, 44.77367901032971, 46.837292871167584, 46.74566238157211, 48.599547109296246, 51.8694035468563, 53.79752697483186, 56.61734634830106, 58.5595706970461, 60.021359612864835, 58.18308591842652, 57.29129583604875, 57.72042666712115, 54.543412731539824, 55.888883759898526, 58.26398872560071, 59.439746641343646, 46.390562365132, 43.12350257750481, 48.196413747725956, 37.58605334066576, 42.39966054116526, 40.98476748312674, 45.66681446567659, 42.044015315271196, 45.16259770239554, 44.389733883642386, 43.27270561648954, 48.20154420791134, 53.872146144990005, 45.4737828623864, 43.704742923859634, 43.73556098630352, 44.36887471906601, 43.262644736997544, 46.151156579294515, 48.94528050576487, 47.21010238893571, 50.65712052006876, 44.97220977660149, 40.49575382663358, 44.49270394540603, 45.261727763760476, 48.244231362496656, 45.88329007548671, 42.76420954735049, 40.8801814048521, 39.72248208138251, 38.865832513378514, 42.23401492641818, 45.59068126063193, 49.82978282436248, 53.32665428038567, 56.266447190315496, 57.57258076821604, 53.5857895881899, 44.86454463774159, 54.42423935859434, 56.96704918338407, 56.30931869629891, 54.345807644628714, 56.882443658767215, 52.18160067835162, 47.86699741117416, 44.490821207723315, 43.379347016734464, 42.26294240643902, 43.990844526598536, 42.86362201936784, 42.63702277214297, 44.13987105892551, 42.67261043671639, 46.56069124898603, 47.17279280385664, 47.23026337162141, 46.554050676284305, 46.2246931752851, 50.04701152924569, 58.034447700746604, 62.16185977382045, 61.58634216554704, 61.349709495421386, 63.05710546432003, 65.90589938625213, 64.88724416302097, 64.06576256598196, 59.7401648952115, 56.11352182203724, 57.72921669867731, 66.84835864651588, 67.4301951931369, 69.04361509507703, 70.1897708831295, 62.80568938101492, 56.013250350952156, 61.206127212893584, 63.13163049759404, 66.71452737623646, 68.06631734294277, 76.8660371534286, 72.80301078673332, 92.47346970342821, 15.358380675315859, 0.056870820511492996, 60.83257636716289, 59.50849010098366, 39.07091756020823, 38.11298847198486, 41.46311229275119, 39.88833950411889, 63.30384216000957, 39.857913678692235, 0.03818681703940515, 0.061664029640415986, 0.02327809294295167, 0.02026607079671756, 0.03550791099006611, 0.04046717733745614, 0.055234824427433556, 0.13517837460723617, 0.07151267596430357, 0.031564383384501266, 0.03673902194526407, 0.09412651896596917, 0.07451726514245234, 0.05222032973242383, 0.1738014174324851, 0.03618497949754519, 0.01516625700112913, 0.02052618254486832, 0.028220739012824434, 0.08910058381696863, 51.244632736329116, 64.35753983836021, 53.37034556173509, 44.60695866615542, 44.34805870056153, 55.25249881129111, 61.040720862727014, 80.08182371816328, 13.19756950101545, 0.3612219169735909, 54.33815117805235, 80.93966176432949, 75.66587817284369, 75.30989170074463, 73.88735786561044, 75.26809492418843, 73.49282233945786, 71.39899838355281, 69.07200521038425, 60.30462534196916, 58.34284405554495, 57.756398723971465, 62.02386294641803, 65.27914777878793, 66.78389841510405, 67.28986063311177, 63.724853684825284, 67.16513710637247, 64.85800289338636, 62.58956286215014, 63.797354775090376, 57.46700233028781, 53.33268296334052, 53.18160110904325, 49.307625139913256, 50.34477826087706, 50.616661271741314, 48.66851022166591, 49.11154585499918, 49.341306532582934, 45.984746102363836, 43.74586505274619, 45.574254374350275, 48.61570727440619, 49.93342361142559, 46.83068759979741, 48.950622773939564, 48.03094071726645, 49.78268300333331, 54.62011468025946, 59.096911876432365, 59.74708787856564, 59.66352962678479, 62.00834605001635, 62.22781050589777, 60.38995650506789, 60.65078235441639, 55.73011798243369, 59.342558153214, 61.451479311912294, 59.58047736075617, 48.715782626982666, 45.607433703637895, 50.71014312005813, 41.45709145453669, 43.772290060597086, 42.77026568689654, 46.408240487498624, 46.71394609635877, 49.101088816119784, 47.0215932784542, 47.67049843265165, 52.67643905455067, 56.82709901563583, 47.545747449321134, 44.01231950329196, 43.64340097673478, 44.421913008536066, 43.92523504072621, 43.916009626080914, 45.60448408126832, 46.984299382855816, 50.97985706021709, 48.264749280868045, 43.92640390703755, 47.218025576683786, 47.80390216458229, 48.57451454285653, 47.79201346059, 42.99273467832997, 43.83183556218302, 42.536017817835656, 41.85378036191387, 44.28617938872307, 47.68529361294162, 51.44470107170844, 53.28697950609269, 57.877309706903276, 58.98682271280597, 57.24151311382171, 51.567737979273645, 56.76718088888354, 60.6058947501644, 60.06572554188391, 56.88641701975177, 59.31988685361801, 55.12432752117034, 47.629125272074056, 48.323871166475364, 45.09652537684287, 44.21463143440985, 45.72539114182996, 47.11824832424041, 45.1184396589956, 46.95665844025151, 46.437721021713756, 47.011183308016875, 48.968179302830855, 51.20587971902663, 50.73133568609915, 49.64515686035157, 51.18955873673963, 59.87898542035011, 63.91157811687839, 64.98344813623737, 64.65025063483947, 65.95346204696163, 67.2122133931806, 65.26394467200002, 67.65442925114786, 64.7750408418717, 62.320096031312026, 61.225468420213275, 66.73311941085323, 73.06817085512223, 71.4898326320033, 72.50103535190706, 67.68852249268564, 60.34184079016409, 65.82465925524312, 66.81782691709458, 70.59602645135695, 71.97489646173292, 82.5272254020937, 78.73301475278794, 94.08933716435587, 14.351156219359368, 0.21382217235382528, 69.95538573111259, 63.04819383928853, 51.75089305446994, 41.742777286037324, 41.01057667886057, 43.06461211173765, 65.69676253103441, 51.76035381132557, 0.06454124520983427, 0.04438417340298334, 0.03938323187251245, 0.1349679455761948, 0.018453058606434255, 0.07917313385874995, 0.03063115805778052, 0.08689320871546384, 0.00569521110587483, 0.1302605497861101, 0.07328219351268585, 0.16112587985492524, 0.16808768854506556, 0.23003253154456618, 0.3077500217383908, 0.13532906410194215, 0.09303303570636819, 0.21642805107178228, 0.09145338538913958, 0.6029705222575896, 62.298526917734456, 75.47644338300152, 65.71801001025786, 54.75290652244322, 54.380767729974565, 58.93130156301684, 70.16805664185556, 86.33240299840128, 13.124213334052795, 0.3123934338650396, 65.02571167484408, 80.64772759714435, 81.00537715419647, 76.99062731958206, 75.5426686809909, 77.79692542168402, 75.87825882819392, 72.66773608423048, 71.71733010199763, 62.29829942026446, 62.31106281280518, 60.654324254681995, 63.88945594910653, 66.76559663588002, 69.34361365533644, 68.8570357907203, 65.88327515509822, 67.89254849956882, 69.00959245620236, 63.33179689222767, 67.44294289619693, 59.07513487723566, 55.77795128668509, 55.39333935706846, 52.11622653468963, 52.34276302399174, 52.994629567669286, 50.70984109755486, 52.3855717720524, 51.51134998567643, 49.34254992392756, 44.355895596165816, 48.55740908653506, 52.43876303395918, 51.4101646023412, 50.216418696988015, 53.818464586811686, 51.274176028467, 54.33462496726744, 56.328581456215154, 62.22741826888054, 62.33348308071014, 64.61578476813533, 65.80395698547363, 66.98365688323975, 62.438422172300285, 62.950715095766135, 58.11925718861242, 61.936974602360884, 63.64562572971467, 63.099612189877426, 50.07226374841506, 47.28374881129111, 51.83939349266791, 43.37387923271426, 46.12137402257612, 45.281535733130674, 49.54763497075727, 49.39649035853725, 51.86841510957288, 49.16661593221849, 50.28770777486986, 57.31059781966671, 59.70471843596428, 48.4522032737732, 43.57651672055645, 43.657497975134085, 43.31975836907664, 42.61491237148162, 44.2231115987224, 48.95386657407207, 49.294312615548414, 54.65150933111868, 52.44567817257297, 49.55027080351307, 52.86128074892106, 54.369945910669145, 54.8366726598432, 51.907556441522416, 48.55974289678758, 44.16861810991841, 44.643118996774, 42.69255568904262, 46.190058646663545, 50.287088040382635, 54.2750520090903, 56.7043484410932, 60.65293181327082, 61.68554675194525, 60.75874559340939, 54.74381054601362, 59.629455997097885, 63.27216509849795, 63.238032633258456, 59.801714727955485, 62.45548056017969, 57.36002360620807, 51.83383549413374, 49.60277565063969, 49.62270521348523, 47.44119275000788, 48.48743400266094, 50.096503996079974, 49.92523370250579, 49.85142646297332, 49.38506057185512, 51.52328183574062, 53.64340136128088, 53.79818201065064, 53.16661373261483, 51.85425927562099, 55.592329040650405, 61.707221769517474, 65.88434988452543, 68.14358803533739, 67.2361163170107, 69.06576079706993, 71.90367406414401, 70.47219722501694, 71.43157759020406, 66.03900109567951, 65.12720692542293, 64.8794464911184, 71.71991886631136, 74.63961355147823, 74.04102063948109, 77.33685493469238, 69.38551241351713, 64.07271692829748, 69.2536501730642, 70.24833971454252, 75.46737486316313, 76.21752815861856, 86.39530212648454, 80.28185675221106, 101.49441903637302, 20.782949001558368, 0.24480425422230076, 71.2976364935598, 72.32914924621582, 54.7967037077873, 54.43996021824499, 56.11330216930759, 55.268643286920366, 80.42732177242156, 58.70910713749548, 0.21157598723807644, 0.21663504802892286, 0.16264923037059847, 0.34055690972074387, 0.1855934411287308, 0.22586386410459397, 0.14021425357749387, 0.3163693995485383, 0.09250925373165839], [0.014733895171253432, 0.06690410551645103, 0.1289098448450527, 0.013733878468854294, 0.03765217576836867, 0.0621529316319333, 0.09820051326025879, 0.04827502671809447, 0.023925768571995923, 0.0942363606525525, 0.024220059332888455, 36.52940603994554, 57.57869182094451, 35.9139940046495, 34.77387082192206, 37.41479089183193, 36.171301487953436, 43.161447586551795, 66.57154129397485, 22.14149525088649, 0.7691797938558363, 24.794523677518292, 67.2612508650749, 69.56527463851437, 71.63616841839206, 71.01228406352382, 69.41492234506916, 68.75707026450866, 68.94779159176734, 69.75303065392279, 61.89128291222357, 53.61036715968963, 58.58608984178113, 62.54782884351669, 64.06393081911149, 64.92204735355993, 65.18758396948537, 57.48534725558374, 63.51346538912866, 61.60118441427908, 61.17264978347286, 62.10282025798675, 62.17068902907833, 61.80829732648788, 55.050351619720466, 46.46782913515645, 47.879807872156945, 45.737970182972575, 49.306644547370176, 48.95385480696156, 46.296919699638124, 47.03629432186004, 44.780084240821104, 42.066639546425115, 43.585510715361565, 45.82476831251576, 48.4567649902836, 44.17268168541693, 42.66030988385601, 48.11181214547927, 54.63875378331831, 55.53138717528313, 57.48377830751481, 57.09669136231946, 58.592075378664084, 52.31167824037614, 56.29578651920442, 55.303568070934666, 57.76899345459477, 58.808398016037486, 55.72384219015799, 57.49791452961584, 52.6842131922322, 40.3587846602163, 50.61491973938481, 42.029757499694824, 38.67956699863557, 40.52538733328543, 43.77123102065056, 40.38184819682952, 43.95288382807086, 46.97637227273757, 41.82824965446226, 46.91458317541307, 48.32859370016283, 48.09110203096944, 49.61252666288807, 50.523881527685354, 43.51996790978217, 44.104185335097775, 43.59881931735624, 43.8992218817434, 41.972667401836766, 48.54172745058614, 45.95069992926813, 40.92962680324432, 43.19760007243003, 44.104769768253455, 45.14335455433015, 43.881131910508685, 41.8560004234314, 42.08163084522371, 44.36936893770772, 45.39166804282896, 50.12629047516854, 54.13087744866648, 56.662484984244074, 59.8761534690857, 58.94226066527828, 57.22406248892508, 47.3615215670678, 51.745676302140765, 58.03060377797773, 54.8055878762276, 56.056537628173835, 52.667374457082445, 53.898069089458836, 51.06629433170442, 48.55505958680184, 45.02365950615176, 46.07173642804546, 46.180464529222064, 45.74090019349129, 43.57142940644295, 43.54409048634191, 41.985434716747655, 45.213027615701, 47.295704195576334, 48.57050195817025, 47.51941657835438, 45.72393594249603, 44.76912513855965, 51.35567895827755, 55.94531882193781, 61.476115718964614, 59.89660862953433, 61.37252200034357, 63.2035118533719, 64.61261157066592, 62.79087458887408, 64.81313097861506, 61.39224367756998, 62.2482225202745, 57.75357069507722, 60.55058933073475, 67.54053146608415, 68.77639185997748, 65.31423730234947, 68.80970847222113, 56.31897557166315, 60.805974852654245, 61.4736093244245, 67.88835940822479, 68.83945572760798, 81.3310044811618, 73.1051980295489, 82.37235453820999, 2.4243912629542814, 3.2161861561959793, 70.16877051322692, 63.61378392865581, 37.51476426278391, 33.998500608628795, 39.24716534153108, 39.04326092812323, 64.93973724303707, 35.939195233006636, 0.07454512776025841, 0.02994164636719131, 0.08241799119259081, 0.06339189881879477, 0.07934424725751724, 0.024314052575538238, 0.05392764477179416, 0.03436518359869238, 0.04264704605203964, 0.031608276392122915, 0.09119628628175105, 0.050310786633241567, 0.0205024472257543, 0.1216061847404607, 0.01625978718361547, 0.035740640840583274, 0.05303859973566667, 0.004170697094166591, 0.04174206255664749, 0.02911522901887375, 45.213949372691495, 65.45334416051065, 39.612275246650945, 34.7135212344508, 42.885132297392815, 44.45286050919564, 49.29499903032857, 76.11674677941107, 27.546331113384618, 0.6689855444335169, 24.00887489318848, 69.80826547068935, 74.11727151563092, 74.48719809132238, 73.35740643162882, 71.15410912421443, 73.53046924837174, 71.86869436694731, 72.39492739400556, 65.3602937729128, 58.13871998940745, 60.41794653861754, 64.48728792129025, 65.81580254339403, 66.6187430966285, 66.1043477827503, 59.807825780683956, 67.59331087912282, 64.56000081954464, 64.49308518440493, 66.31537914276123, 66.14736049405991, 66.11938614999094, 57.56978411828318, 49.99625998158609, 49.31497958398635, 49.16916155046033, 51.91245548186764, 51.01836689056889, 50.374784392695275, 49.05568345900505, 46.413410171385735, 45.64066794610793, 45.59571758393319, 47.60715215436874, 51.57676335304014, 47.3374774379115, 45.61890271402175, 50.88846191283196, 55.76545461531609, 58.78372238528345, 59.261435693310155, 59.33046940834292, 60.756619668776, 57.54379449352142, 59.0856703635185, 57.63453460508778, 57.813571191603145, 59.527376313363355, 57.8118061250256, 60.98707852825042, 55.045899729574884, 43.472071847608014, 48.97434134637156, 45.977881954562285, 43.429463140426144, 43.44111257983793, 45.5842250393283, 44.08974316812331, 46.44212192104709, 49.49775026690576, 45.4574893366906, 48.586065923014, 48.57688365444061, 47.496627607653224, 48.11875866305444, 48.7633688219132, 43.940948055636504, 42.97675494224795, 41.60440391109836, 43.67401115355953, 41.21204137802124, 50.11097361964565, 48.7304562137973, 42.10673401432653, 46.88072919845582, 46.9218905510441, 47.31564160316221, 45.56893171802644, 43.874785515569876, 44.87406815251997, 46.02719399236864, 50.156492725495376, 50.566097997849994, 54.98651896753619, 58.45839708082138, 58.11968080459103, 61.21407001249252, 57.886990116488555, 51.01949653317852, 51.46801956238286, 59.62974233012046, 59.15201725498323, 57.51298819818805, 57.81420661557106, 58.25698729484313, 53.947008502098825, 52.23680803852697, 49.13819443794989, 48.839015653056485, 48.85656433720743, 47.502185606187396, 46.62059760862782, 47.44651148396154, 46.16994473241991, 48.3042279366524, 50.54519176483155, 52.90095160084387, 50.3566316635378, 48.88359731243503, 47.71875143051148, 53.36010817558535, 59.38201327477733, 64.34632970440772, 61.68296583237187, 64.79582940378498, 66.51244686495873, 67.89915377093901, 66.73437456930837, 66.61656225881269, 66.16782742161905, 65.22315594457811, 60.193539896318995, 64.13127007022982, 68.12929491842947, 72.86746317340483, 67.81031993127638, 72.30392840600783, 59.185984980675485, 61.721126571778335, 65.9570235590781, 73.58101291041221, 73.33141680686705, 84.7061098775556, 76.04415155226185, 84.11763668060303, 1.675216476282766, 5.35494331390627, 78.57542960874497, 68.78427582402384, 48.10279461645311, 38.26966754851803, 42.51041258535078, 46.86594186290618, 72.98933905939903, 40.8001728980772, 0.06232139053604296, 0.029977694634468328, 0.11283937330928542, 0.023639607919199813, 0.10712728385002383, 0.07180451715905821, 0.036775208108367465, 0.07017183057483166, 0.12179091918252169, 0.20138295757914745, 0.2345850090346029, 0.32345439517690294, 0.15385081781254661, 0.18133164804068305, 0.1749859119374906, 0.15449718151602054, 0.2054807925296407, 0.14001687868468224, 0.15683609391412429, 0.24367222141835, 56.31819894236904, 76.21895590136128, 47.269906766953014, 43.97962654790571, 55.10160915313229, 50.320243835449226, 57.12694068108836, 80.86904341174711, 28.959198267229144, 0.9904684583025595, 34.09659516426825, 73.25494627798759, 76.39179906537457, 78.36898742183563, 77.22123915149321, 74.34990729055097, 76.125030825215, 75.5081832024359, 77.95403203656598, 67.24593008718183, 60.768516217508626, 63.09419147429928, 65.8092757194273, 68.6310915793142, 70.7144114278978, 69.39010158661874, 60.862186339593705, 69.04086943595641, 66.16486210976878, 67.657072928644, 68.51487959584883, 67.09113767070156, 66.87510921109107, 61.70914373090191, 51.66406746833555, 53.050841054608746, 51.00833346766811, 53.49400612615771, 53.783877126632206, 52.87121611256754, 53.198188812501975, 50.40407273077196, 48.02305283084993, 49.8660372918652, 50.41633013756045, 53.538603475016934, 50.12245439714002, 46.85499845012542, 53.805454084950114, 57.42321298968408, 61.579607455961174, 63.487287490598625, 64.10448420432307, 65.34072899049329, 60.53537053446616, 62.23130141535113, 62.22290754318238, 61.46136368474653, 63.139824328884, 58.99883693264377, 63.520823755571925, 56.75115408435945, 45.894056981609715, 54.638612577992106, 46.64156659956902, 44.5880606866652, 45.91465726975472, 50.42359828948975, 46.37314704156692, 52.41506015100787, 56.23986136528754, 50.111836541083555, 52.23955762001776, 53.45719468209052, 49.17683370651738, 49.718622853679044, 50.42578304967573, 42.62921725550006, 43.053268617199315, 42.43525605047903, 44.820092416578724, 41.93787205603815, 53.47550430605489, 53.91532751821703, 46.37460224090084, 51.216717227812744, 50.28793134996968, 52.460336069906916, 50.43101156911543, 45.40982077198644, 46.35971292372673, 47.228725802513864, 52.88805484771729, 55.10168760053573, 56.48710404672931, 61.31150168757285, 63.49827797182145, 64.4808905355392, 63.061247487222, 56.30514529443557, 55.73098482624177, 63.24886621967439, 64.01654858742991, 60.999465373254594, 59.588879077665275, 61.50329774425876, 56.36407106153427, 56.12206866664272, 51.42043728982249, 50.219074141594675, 50.82696699327039, 51.622557024801935, 49.94211558372744, 49.70898951253584, 48.87876103001256, 51.20125524459347, 53.34175148317891, 55.09274459654286, 53.999423134711485, 50.740490498081336, 51.67938824622862, 56.47023785498835, 62.5419766672196, 66.99656932584702, 64.360630666056, 66.6235048540177, 69.10705551024407, 71.07425751224642, 68.77026511776832, 68.45725213327717, 66.57029398026006, 67.8340502708189, 62.93943435915055, 66.76009747289842, 72.7593469619751, 75.42363259100145, 71.33205921419206, 76.9145647172005, 62.474700174024036, 66.65210677731422, 69.7175802723054, 75.06542605738487, 74.96947703822967, 87.39997017768123, 76.52176287866409, 92.60868164800829, 4.2236841974719885, 4.36004686740137, 85.4992288158786, 77.78733914898288, 51.36449252405475, 48.024072647094734, 56.289679388846125, 55.258747146975615, 83.50976344077819, 48.77354345014019, 0.4060891126432727, 0.12979666822619979, 0.36406091624690645, 0.16902144247245404, 0.16937079388768445, 0.12112544924621621, 0.1953971755480574, 0.1704160595733312, 0.21283620187351782], [0.06006384816681666, 0.002279075424960484, 0.044804135142194654, 0.1291045690736463, 0.032926512611729485, 0.08355392338407618, 0.03564274629517909, 0.13716802752066043, 0.1531128759586042, 0.16980637615967184, 0.301828958815144, 27.838853636095603, 60.34637897245346, 48.38315386925974, 46.31505673931491, 28.83441982730743, 34.10968411353327, 32.749296311409246, 73.02068664181617, 36.63294484538417, 0.028481708779450388, 2.762681962020936, 45.67887575395646, 67.33464625573927, 70.72004395146524, 72.61790629356139, 71.00851074341806, 66.46318189559445, 71.9422701866396, 66.58904290968373, 59.20596161196309, 55.995678132580174, 61.46427408341439, 62.151783204847774, 63.32507394975232, 62.76791303388534, 61.73909102716754, 53.195250957242905, 66.86326365317068, 64.56665708172706, 64.29258146593648, 62.76379062283424, 63.72182953742243, 63.250850938981586, 59.90416311448621, 48.58302608613045, 47.337724547232355, 49.92263709345172, 50.832234736411806, 51.46931394453972, 50.98685456860451, 47.58714806648993, 45.14277404354465, 44.07558733417142, 43.25147382674679, 43.638458790317664, 47.44686449727705, 46.14185271724578, 46.03658414656117, 49.002323535180864, 52.838079929351814, 56.63619725934921, 56.0664455352291, 54.026448265198745, 55.92603252780054, 56.28617278991207, 58.14944767182874, 57.74248607697026, 55.417661974507, 56.09705963442403, 61.126326591737815, 57.56717574211859, 54.97723471733832, 41.603376250113214, 43.87649174659483, 45.466055793146936, 42.77964407397855, 44.21014424293272, 40.44233114488664, 44.87752376064178, 42.60518881582445, 42.17911743348645, 43.00103833598476, 50.64047398105745, 45.322485277729655, 46.33112276754072, 46.91683069352181, 52.17703896184122, 50.66960150195707, 43.030805203222464, 45.00060381427888, 46.380764284441554, 44.66524508691604, 48.53919359945482, 46.45821932823428, 41.922429684669744, 43.12844476392193, 43.03409999416721, 40.541068969234345, 43.64173396941155, 43.453832826306744, 42.61004863246795, 46.487946971770256, 54.22162540497319, 57.16898848933559, 58.65713965508246, 58.558342995182166, 55.815072597995886, 55.595055087920166, 51.0383435218565, 50.89260785810409, 57.02185253943167, 54.52792721409952, 52.884897339728575, 58.37401120893417, 58.67762619449247, 56.87590899006013, 54.248175928669596, 51.80400979134345, 49.08412456512452, 49.04586576646375, 51.500363426823775, 46.59134064951251, 44.67105019477106, 45.815986125699936, 43.64577401068903, 45.877190789868756, 46.24991793786326, 49.96539092832997, 47.94741776681716, 47.87264954659247, 44.965855536922334, 50.59685722474129, 57.63406784303727, 59.836619900118926, 64.55181875536519, 62.52481629771572, 63.79756266070951, 64.35936374049034, 63.580479083522675, 66.12373998088222, 64.81162871083906, 64.8194303051118, 61.799985824092744, 60.33125823543918, 64.72850976451751, 68.6854007167201, 67.87816124577677, 67.34373830979871, 58.2474127892525, 56.69038872564993, 64.7355817979382, 68.33122637964064, 73.08031451317572, 76.55453820382395, 82.47454797067951, 56.468033482951505, 0.6678789457486523, 15.403544806664991, 75.65367960160779, 56.51070102568596, 36.47709731132754, 42.53016171916839, 36.87202899686752, 33.40358295748311, 54.64688093431535, 43.90114776549801, 0.050733008331829504, 0.13274028446645508, 0.08217103508931976, 0.03308642580504379, 0.08815678647689282, 0.054101397343460596, 0.06494783871476689, 0.042691988600117546, 0.02992228541012493, 0.09378239993126163, 0.02718489620864632, 0.03510301053944615, 0.029678510486959454, 0.08421609914230724, 0.02677261833131554, 0.11601244054374196, 0.028385610710228645, 0.11365483560028578, 0.18891260899122686, 0.09474235406566052, 37.33436661381876, 69.97484853190761, 52.05060528170679, 49.449701232294885, 37.95212814884801, 40.00954466481363, 39.56363001177388, 77.72878600705054, 47.384330149619814, 0.052333132348834514, 1.9143011180623886, 46.970163160754794, 71.01935217457434, 74.55026195895287, 74.46728814032771, 74.25712754649501, 73.81673166828772, 73.63793434635286, 68.84730831269296, 61.80587330172139, 61.32021719409574, 63.302394805415986, 64.88188228299542, 65.44517386344172, 66.51986798932477, 63.88668675576488, 55.0708342367603, 67.03603621452086, 66.4204280607162, 65.38682468475835, 62.99380233210903, 64.35364100240892, 66.74018752190375, 60.765323408188365, 52.21945547288465, 49.44596321352067, 49.597425537724654, 53.72373542478008, 53.196553184140114, 53.420398927504024, 51.15081748654766, 46.98696659457299, 45.50218866717431, 47.09690670813284, 45.98108260862289, 48.51463956217612, 48.41578798909342, 49.11484064594392, 50.17425321763562, 54.90372950030912, 60.66211015947404, 61.197376405039144, 58.338325485106445, 57.80158442835654, 58.56996105563257, 59.181529168159734, 61.991044475186264, 58.73246485187162, 59.21413975377237, 62.45439014127178, 59.11577063222086, 56.43975711637928, 45.41687319355626, 45.4453613681178, 47.84570678587883, 47.531591615369244, 44.00381580475838, 42.22456593667307, 46.4781371239693, 45.28309683645926, 45.73879780307893, 46.0282765665362, 51.14595374753399, 48.23618265890306, 45.971817970275886, 46.46052960426577, 51.0976654483426, 50.065128957071614, 40.92352359525619, 42.56733402129143, 44.78545788795718, 46.8188302747665, 48.358046777786754, 47.179947207050944, 45.18699484486734, 45.328674777861565, 46.40273740214687, 42.63171580529983, 46.289447584459865, 46.63118800809307, 45.36136381087765, 48.287534329199026, 54.49580300238825, 57.789985979757006, 59.05245573289933, 59.93253361794257, 57.24027364484726, 57.6771786136012, 55.029798400017526, 53.72978371958579, 60.61870521114719, 55.23481676655432, 55.57696903905561, 59.7555092073256, 59.614680428658765, 59.915082993045935, 57.25415099051691, 53.36297150581114, 51.91263591089557, 52.78424932110695, 55.714201004274436, 48.75854038423108, 46.06502525268063, 46.965209207227154, 46.20329272362494, 49.25633230516988, 51.18777013594105, 53.31920569942844, 51.57029928699617, 51.10662414181618, 47.628058387387185, 53.63528989976453, 61.42829025945356, 62.826171998054754, 65.64848992132372, 64.60567682020127, 65.19530711635467, 68.53002778945431, 67.28747583204701, 69.87032521155574, 68.1223758574455, 67.44072283467939, 63.51181799365629, 66.66373268250497, 64.28715682798817, 71.59088857712285, 72.94742461173766, 71.33792707996984, 61.79207440345519, 59.64589072811989, 66.23494702000772, 74.54133464444068, 75.92682561566754, 79.43815492814588, 84.84209060668945, 56.60363766454882, 0.605507315166535, 21.366130921148486, 78.08016761656731, 63.694133681635705, 38.68370509916736, 52.57835234365156, 36.999098100969874, 43.58924088939544, 67.33089646985455, 56.553568609299205, 0.9160601155411814, 0.24292222134047942, 0.06555737657172066, 0.12076729548073585, 0.07343595501996818, 0.06257711451560741, 0.054554358320010286, 0.050765766251471736, 0.08352108119476227, 0.20103472465228653, 0.17884288884459004, 0.12482347823078595, 0.3546200163902775, 0.14946896342500565, 0.1947861744631683, 0.14519102120351407, 0.16075979707942856, 0.21313621722642453, 0.37105741339825815, 0.2502639636757874, 47.30734971261794, 80.00384699913764, 63.493747634272424, 58.505057596391254, 42.270736155971406, 47.07613775807042, 48.16130853468373, 85.68212109227335, 48.29934458578787, 0.10560133629628729, 4.200822172626372, 56.045806023382376, 70.56806779676869, 78.98712158203125, 77.06707431424049, 77.28382448996268, 75.00622180200394, 76.85028491481658, 73.11793004312824, 65.55552582586965, 62.19166194238971, 66.2919625928325, 67.7483464825538, 68.39929519161102, 69.6915671133226, 65.59489073291903, 55.27878261381581, 68.2083228326613, 68.96413218590521, 69.10470208814068, 67.25325707466372, 68.442566779352, 69.08678470119354, 63.9668756915677, 55.194620317028416, 51.080634517054406, 52.42210472783735, 56.56763030636696, 57.17364434273013, 55.66955658697314, 54.14446846131356, 48.410461410399414, 48.848068483414195, 48.401404657671534, 49.16636490052747, 52.0335586609379, 50.7742307263036, 50.212598308440185, 53.536763883406124, 58.71673222511046, 64.28507404942667, 64.4763719651007, 60.46241052689091, 63.39134631618377, 61.677788303744414, 62.450958067371005, 63.0515984565981, 61.32057412978142, 62.152567678882235, 65.60930544330229, 60.77598833268689, 59.782389210116484, 47.86729943367743, 51.712822529577444, 52.00165802432645, 45.06163589416012, 46.86835019819198, 46.41778361412787, 50.584764557500044, 48.75386099661551, 50.69031161646689, 49.92681049531507, 56.67598186000701, 49.93117217094668, 49.36515454323062, 49.04413992358793, 53.346073935108805, 52.28459035196612, 40.32526408472369, 44.220742487138324, 47.433195037226525, 45.8891853978557, 52.14838997010262, 51.020430057279526, 50.06586244029384, 49.160779445402085, 51.020732079782796, 47.103319783364576, 50.54690976296702, 46.367326244231194, 48.47636115166449, 49.92421780863116, 55.77586850812359, 59.89835408426101, 62.50816191396406, 63.566872381394916, 61.59359462799565, 60.59814414670391, 60.17117846396662, 56.360670366594874, 64.36378032930436, 59.013318323319965, 58.51676587135562, 66.04933261871338, 64.79411925038984, 63.973480962937884, 59.374231292355454, 59.00441062065863, 56.13849947529455, 55.31832010515275, 56.81460626663701, 52.227786587130645, 48.31817196261499, 50.878197070091005, 49.54954908740137, 53.30230028398576, 51.77490972703504, 55.18437508613833, 54.18345682082638, 54.14595896197904, 49.968371929660925, 54.642374130987356, 63.78809798148371, 63.68545739881454, 70.51160920050837, 66.57436540049892, 69.316447319523, 70.50787510410433, 68.4546241452617, 73.77298939612605, 70.22551152013963, 69.13229203993275, 66.53834235283637, 68.43539668667701, 68.88880698911606, 74.71604485665598, 74.6187073184598, 76.43043441157188, 64.47271239372992, 64.89843468512258, 70.12240809779014, 77.71523029573503, 78.81956577301025, 83.79161711662047, 86.99690741877403, 68.49391060490763, 0.7893185293482197, 18.870966126841886, 87.83707910968413, 69.0098277984127, 50.47841733501804, 56.29997168817828, 50.67502221753521, 45.97066479344522, 71.66424474408551, 65.19316550224059, 1.0482156757385501, 0.2520170026729184, 0.15427792715209146, 0.21577125325077967, 0.1892030176015631, 0.2157468150459951, 0.18905338530819263, 0.0891780736105096, 0.1744464174994538], [0.04152678035860581, 0.04481170792132617, 0.03372654589193483, 0.026739201576058424, 0.05081836201791322, 0.026595447092287006, 0.0334296063820441, 0.08788718481458004, 0.05765780731434784, 0.12115891962762802, 0.08213792476923236, 35.09529336806267, 58.80193787236368, 41.548627807248025, 34.68443293725291, 39.079680135173184, 36.81395830646638, 31.643095747117076, 52.539764065896314, 56.88867238260085, 2.9866527309340816, 0.5393156637587856, 29.853843835092363, 65.77191906590616, 72.00239227664086, 69.09859103541221, 69.99436624588506, 67.03531449840915, 66.07504767756309, 60.62331791846984, 60.14459656130884, 60.34974828843148, 66.35171598003757, 61.12413006444132, 65.06131502889818, 66.61864111500402, 56.71111060727028, 54.512159286006806, 59.56227756315663, 57.047587210132235, 59.60764761893981, 61.360197913262155, 64.98040437698364, 58.99969593171151, 57.0918825364882, 51.66193762133199, 48.579743062296224, 48.72418042152159, 51.22931195843605, 54.72445364921324, 52.8741539678266, 51.02483487898304, 46.589281405172045, 45.347584524462306, 45.8548411246269, 45.850126435679776, 42.705099428853686, 45.15150131717805, 48.8710065041819, 49.08133968230217, 52.306712519737985, 55.93561095576133, 59.35639627518193, 57.78452211810697, 57.87113197388188, 58.80553860818186, 57.107207236751435, 57.27373146241712, 57.65236177752095, 59.92467711048742, 56.239045512291696, 57.50171530631281, 54.27979415462863, 46.34504718165244, 36.989845229733376, 47.70932989735758, 39.89954963807137, 45.59786704278762, 43.74928535953645, 41.8183692039982, 43.25801634019421, 43.63610929058444, 42.91514235158121, 47.23166365777293, 45.890597451117735, 45.6621507675417, 54.06451486772107, 55.744297350606615, 49.81330102489841, 44.77684436305877, 53.08296918869019, 56.735005686360026, 52.34399464822585, 50.93684827127765, 46.3244390487671, 43.92237563287058, 43.65999652493385, 43.66952788445258, 40.94990937940536, 45.87757125977547, 40.49665204940304, 45.314836655893636, 47.54710458940076, 52.048240092492875, 54.86713378660141, 55.83014626656809, 55.25557787187638, 59.71496366685437, 53.114861980561294, 53.57506975050896, 58.99407517525458, 58.01038788210962, 57.80218455099291, 55.390962400744044, 54.74051575506888, 55.24768214071951, 57.419447514318655, 56.163814452386674, 52.82571661856867, 50.71144142458516, 57.73283312397619, 51.238360866423584, 45.6167414880568, 46.477713507990686, 44.268081572748, 46.64093902034145, 49.571286862896336, 52.28607300789126, 52.71701989635345, 52.206146870889974, 50.42376695140716, 47.415509070119555, 48.48129941571144, 56.879344986331084, 56.876403208701845, 62.09958038022442, 59.62658089976157, 63.64521388084658, 63.187292852709376, 66.13792327142531, 63.79260086244153, 66.64464642924648, 65.30620036586639, 66.05073682723507, 61.81380433420982, 65.57538870842227, 66.45618438720703, 69.25002590302499, 65.58761473624938, 62.193073995651744, 54.99637588377922, 64.50717433806389, 67.80722910358061, 77.98784286745133, 73.59167391254057, 88.18100821587348, 25.902950186883253, 0.560425247155851, 35.57630931177447, 71.91675124629852, 50.384555016794515, 43.44951037437686, 52.36836433410645, 39.3805573063512, 43.03503744063839, 51.81287827030305, 51.77034016578428, 2.176036834716797, 0.22397639199851022, 0.044613999780267484, 0.07676629244440025, 0.05130098208845143, 0.06708678684287495, 0.051455682053441004, 0.08453632389465648, 0.05897355183298069, 0.02136796761694695, 0.10020394809544088, 0.03515570206687816, 0.05013812573686723, 0.03989133585785185, 0.08460275137857085, 0.015223115089259323, 0.06580506045851978, 0.016674311613784205, 0.0708084419790295, 0.02237034003971325, 44.25268234745149, 68.2656051266578, 41.18928770865164, 33.33517682167792, 41.895667352984034, 43.25672980277769, 42.150844989284394, 57.40928073083201, 67.31275158543741, 4.225116843177426, 0.5443358072830785, 31.806372250280074, 69.54011655622914, 75.8487782939788, 72.56018469410559, 74.76523137861683, 70.67015140287339, 67.06648165179838, 65.43681921497469, 61.285818007684526, 62.05705796518634, 68.71249644987046, 64.99415620680779, 67.86819842553908, 64.87394732813682, 57.77849343515212, 55.67472627086025, 60.29916148031912, 59.35382712271906, 61.755337484421275, 62.35439715846893, 68.7979962748866, 61.446556737346036, 60.444991280955655, 52.309740589511016, 50.22694241616034, 52.394585378708385, 54.74421455014137, 56.93714111082016, 54.590798885591575, 53.106801509857185, 50.16172908967542, 48.16950628834386, 46.91051959991456, 47.201304512639204, 44.751003788363555, 46.976329126665675, 50.90803453999182, 51.38099785773985, 53.48831476703767, 60.17807791309973, 60.05344067850421, 60.88119414544875, 60.850666338397616, 59.12020291051557, 59.78186753488357, 59.05099268882506, 59.43328649766984, 61.42360302709765, 58.80081215212422, 61.39745258515882, 56.792488021235314, 48.478867546204604, 42.12932686651907, 46.92574231855331, 43.895840798654866, 48.9892267411755, 46.21378114146572, 44.18087159433673, 44.13481904614357, 47.70972605674498, 43.76811273636357, 47.822219633287006, 46.655589072935044, 46.380603467264486, 55.80440375112719, 54.81998689713017, 50.06497990700507, 44.16752769101051, 52.51984234779112, 58.639979285578576, 54.243735805634536, 49.404680267457046, 48.57038820943525, 44.99306501880769, 46.528429754318736, 46.78851819807484, 42.98627845702633, 47.12164901917981, 42.11410414788031, 47.35726187306066, 50.19132729499571, 50.32135778857816, 55.926554203033454, 55.00991198324389, 56.069771705135224, 61.90818832766626, 57.76618111518122, 54.32272057379446, 58.53365951968778, 57.666470543030776, 58.645380389305856, 58.16297200418288, 57.87500727561213, 58.28817013771304, 58.44383724274174, 59.12377618974256, 53.84670172968219, 53.058026836764434, 62.84678797568045, 53.214768671220355, 48.98721456527711, 48.61058858133132, 47.83619503821097, 51.171131441670084, 51.96124584444108, 55.56340940536992, 54.9715276687376, 54.657369352156124, 53.063839789359804, 51.461155414581306, 51.60913859644244, 58.38896720640121, 63.24224525882352, 64.64775992978004, 62.76651274773383, 65.83013488400367, 66.18790995690131, 68.56616066348168, 65.96917506187194, 69.9188292411066, 69.82336659585276, 69.27232065508443, 64.00300072085473, 68.9302429076164, 70.26040492519256, 73.8424624166181, 69.29158733737084, 65.88179249917307, 59.82564903074696, 68.60834183231478, 72.59609007066297, 81.65553354447889, 77.27620724708804, 90.85252669549759, 24.466754736438876, 0.47244991626470323, 45.09889056605678, 76.14810220656857, 59.34302099289433, 47.23878275963568, 66.63425214828985, 37.699194108286214, 45.50171013801329, 61.87256928413146, 58.60044179424163, 3.653101911467891, 0.3122565799182461, 0.02977309361731093, 0.07485395312429437, 0.04091108698518046, 0.05250478583958842, 0.01956303573904499, 0.04695346759211633, 0.035452373445995396, 0.10038908090322249, 0.20532218168579763, 0.11742273180354988, 0.18476575973533815, 0.15705205409997897, 0.21321763705101707, 0.08196681137046508, 0.18856452928195078, 0.1030576179525064, 0.1734782815460236, 0.16647560972600214, 51.38042126932452, 76.9241980583437, 54.97980386980119, 49.37240700567923, 57.063457119849424, 50.85154064239995, 50.12849484720538, 66.1645326306743, 73.23770353871008, 4.019112490838574, 0.51943059529989, 38.371833524396344, 70.15208475051388, 78.91352222811791, 76.74626365784677, 76.00517888222971, 71.89670008997764, 70.20710775929113, 67.80926089132986, 67.34919040433823, 65.41774080645654, 72.05268490699031, 65.36714223123366, 69.99788853429979, 69.47457375064974, 61.37221605547013, 56.77007167570053, 62.389200349007886, 61.93744136441139, 64.58439796201645, 64.40310993502217, 71.14625653912945, 63.579067030260646, 60.12443165625296, 55.86576923247307, 55.41734034015287, 55.95014333724976, 54.640577685448434, 59.92598718212497, 57.06396702797183, 57.2341469026381, 53.14972400665284, 51.41816623749272, 51.006027114006784, 50.48218281038346, 48.13840581524757, 48.775226146944114, 53.50450631110899, 53.23123870357391, 58.36386403729839, 62.741236994343424, 63.338335483304924, 64.3782538752402, 65.11281182689052, 63.047162255933216, 62.25170166261735, 64.12657891550373, 62.422238472969305, 65.96995169116606, 61.01951260720531, 62.641110650954715, 60.528510309034786, 50.67438287119712, 46.430601919851, 54.44780888095979, 46.7308162104699, 47.859517451255556, 46.04846892818328, 47.435207213124926, 48.66649804576751, 51.346222123792096, 47.85361036177605, 52.43753925446541, 49.32829603072136, 50.40144474275651, 59.30592321580457, 59.90676364591045, 52.208013919092, 44.566236619026434, 54.65416869809551, 62.323767369793316, 56.01447805281609, 54.31430708977484, 50.66913081753639, 48.81700331164945, 48.17447985372236, 51.11339023036342, 44.36147320655085, 51.059563544488725, 44.33864893451814, 49.68433349363266, 52.02598064176498, 54.85839474585749, 58.169067367430664, 58.41461166258782, 58.85967908367034, 67.29659926506781, 61.63041391680318, 57.56100585383754, 63.12795915911275, 61.825673426351244, 62.709697215787834, 59.44994480379167, 62.128484326024214, 61.44859244746547, 60.95356971986833, 62.41889269121232, 58.03496937597952, 57.55656573080248, 65.09793035445675, 54.96740918005667, 52.57753256828555, 52.92423086781656, 51.09241339468187, 53.77172954620854, 54.19686740444553, 57.62683499243952, 57.186325365497225, 57.84547182821459, 55.922576919678725, 53.155988031818026, 54.55309706349527, 61.848419250980506, 64.31563323543918, 68.7077425372216, 64.01313220300983, 68.58749835721909, 69.6100288821805, 72.93788540747859, 69.84636737454322, 74.58539070621615, 73.63187036206646, 71.32298284961333, 64.64820315760952, 70.84712090030794, 73.46561677994268, 78.11204079658755, 71.86603499997047, 69.86373562966624, 61.71338381305818, 71.4158881095148, 77.3187022055349, 84.52493559929633, 78.68620518715151, 91.43270800190588, 33.871278532089725, 0.5313365209487177, 44.42094026073333, 86.37385460638231, 61.914362138317486, 61.576751970475726, 70.6411180188579, 53.16890831916563, 54.47734040598716, 67.1749665660243, 75.01663177244126, 4.628564974954052, 0.5087212377017545, 0.18077801161956403, 0.21449066067655242, 0.18041036602470184, 0.1583181522906788, 0.15621913266518425, 0.11877784941105113, 0.11616090838346751], [0.024395796072278774, 0.05237257438561609, 0.057775007275443886, 0.04649307173226149, 0.07252787269892232, 0.0345412957211656, 0.038720052539100575, 0.024095537486456098, 0.09442402921136349, 0.19588626140067655, 0.11628314537266571, 42.4449796061362, 54.92629097354028, 51.681055253551854, 58.81743123454433, 98.6476412127095, 41.64794222001107, 30.772056964135942, 52.76906974854008, 56.777492800066554, 12.675724625587465, 0.6998140869602081, 16.879763141755138, 63.02235718696349, 73.72474424300655, 64.59749083365163, 72.81412678380167, 61.804743659111764, 65.8888292312622, 56.28223473025907, 61.20548002181515, 63.058239029299834, 63.48260810298305, 61.64221632865168, 68.48041765151486, 54.32431305608442, 56.350260396157545, 60.078692897673584, 60.95260481680594, 61.067404747009284, 63.161158100251235, 61.93248741088375, 63.99991381552912, 60.73341492683657, 56.120578165977236, 47.24256392448179, 47.78154465460008, 52.4730053255635, 56.200967142658854, 56.34603992585213, 59.96625815668414, 53.17607841184063, 48.67809649436705, 47.317387057888894, 45.46200398475894, 44.8506712144421, 44.47486108349216, 48.602759530467374, 52.16870784759522, 47.90078078546832, 56.01399560128489, 52.698059158940474, 59.331677498355994, 58.92967377939532, 59.91573410649454, 59.033765639028246, 58.26283554877005, 59.19390424605339, 59.23493616042599, 56.097224373971265, 58.2414625537011, 59.62401566966888, 54.719946845885254, 49.79637207523469, 42.39021547379033, 43.0696209784477, 44.66784561834028, 39.77178627444852, 46.22437938567131, 44.55918027508644, 46.13023465679538, 40.00944660555932, 41.4844342970079, 45.79173018855434, 49.7409019162578, 54.721625620319, 55.069253521580855, 55.47719178661224, 54.392268119319795, 51.76974004314792, 57.14856078547817, 54.78763518794891, 54.6312463668085, 50.09334648809126, 46.69169841274139, 44.997065836383456, 44.25283924225838, 45.80497995499642, 43.11207279082268, 45.30869030183362, 45.348478824861594, 46.38690279376122, 50.325311537711855, 51.518441630947976, 48.71979128929877, 53.653521076325454, 56.4628206529925, 53.2144078131645, 55.331291383312596, 56.17410675171883, 59.0182722768476, 55.1617390878739, 54.83721002455681, 59.027544759934955, 58.748448510323804, 57.64913758923931, 57.15933945871169, 56.90527185317009, 53.69544336872717, 50.83540008914087, 55.03598790014944, 45.88037183207851, 45.98649155709052, 45.151999458189934, 45.95232379051947, 49.23593205790366, 52.7796797598562, 59.167514539534054, 55.20817210597377, 57.354053758805804, 54.32883947126327, 51.37343160567745, 45.91050740211241, 54.58459761834914, 59.21653632194766, 62.28807772359541, 59.23239446455433, 62.47260955072219, 61.482619008710316, 64.19258063839328, 63.40220735919092, 65.20125735190608, 65.04014207470802, 65.50291115237822, 60.43047066657775, 65.80998174605831, 67.584642441042, 68.78888853134649, 64.85120150350755, 61.53392753293438, 57.85539934712072, 65.71063203196373, 67.96828946759625, 77.2249654031569, 72.34047705127348, 87.04279914979013, 6.12870192335498, 0.13500439603963207, 55.8773833705533, 62.22007951428814, 48.65970450062906, 26.91375674739961, 48.27954838352819, 46.31813187753001, 56.41758788016535, 53.08808395939489, 52.59731700343471, 3.338872992223309, 0.053319198590132504, 0.053181517268380815, 0.133932332598394, 0.054870055492727034, 0.004836697546359633, 0.05266180322054894, 0.05164584422844553, 0.12732648666227056, 0.03341800781087049, 0.040665548144569325, 0.1152282423009315, 0.03458503934164201, 0.018293248834989725, 0.02922701273834513, 0.059790473521476796, 0.04291895746944412, 0.038343068332441395, 0.10112519946790512, 0.021950458739733985, 52.32553597419493, 64.72257521844679, 52.16400100338844, 54.26253572587044, 99.40770241522021, 41.82864973621984, 41.841558256456935, 56.171604279548895, 68.06308530992078, 15.368232688596173, 0.6903992953800386, 18.477050335176532, 65.79443347069525, 77.93268649808823, 69.06863981677641, 73.6618451149233, 64.04471905000749, 67.41654534493723, 60.27243837233513, 65.69530340933031, 67.59867668151855, 65.7480945894795, 63.70854839201897, 69.91333792286535, 53.88052432767807, 58.15963406716624, 60.865073204040534, 62.238926502966116, 64.38490621505245, 65.6611160309084, 65.25724918611589, 66.69553525986211, 63.29667598970475, 57.35261032658239, 49.389104535502774, 50.281722237986905, 54.78919629127749, 56.91783128246185, 58.94711655955161, 59.52178301349763, 55.60028360735986, 52.52853432009297, 50.82748866850331, 47.42043948942616, 46.700849302353404, 47.03528235035558, 50.34764159110285, 53.40365432923841, 50.735748352543006, 58.746483402867476, 56.65398128571049, 60.32923821480044, 59.65371193424348, 61.584188784322436, 60.59749695562548, 60.48705477868358, 63.018085725845836, 60.8757891193513, 58.70887571765531, 60.90498724291402, 59.27601906561083, 56.589776008359856, 52.10171768742224, 44.92007363227106, 44.097246662262954, 44.83526806677542, 44.991452924666866, 48.708012411671305, 44.081145332705596, 46.05307379076558, 42.95969263199837, 44.70979144496303, 46.41792874182425, 49.70278040055306, 53.62739809097783, 54.94514188458843, 57.8426084979888, 53.9341470503038, 52.126558057723514, 58.8781612919223, 55.44821331577917, 57.50386476516724, 50.07185974428731, 45.29431481515208, 48.7124054662643, 45.47433199421052, 48.02859513990341, 44.022568656552224, 47.014509477923, 50.10538816452027, 47.02352700694915, 54.32092020588537, 53.20809671955725, 51.52092841363723, 56.48704521117672, 57.93347412540067, 54.02771126839423, 57.66616067578716, 58.4759065412706, 57.6108984024294, 59.183168718891764, 56.900898410427956, 60.53715913526474, 61.08591441185244, 60.7693281481343, 59.52720372907577, 59.086199883491766, 57.11136102676392, 53.99936037678873, 55.07986353289697, 49.11792755126954, 49.380314503946614, 49.679803156083636, 47.81087221637849, 53.50316486051006, 55.431574621508204, 61.00922815261349, 57.144712940339126, 57.56166873439666, 57.29042114750032, 53.28361803485502, 48.3577133763221, 54.62530789836761, 61.683314923317205, 63.70812869841053, 63.71387497071297, 64.26296757113549, 64.54407991901522, 67.38840626132104, 65.86478510210591, 69.8850654786633, 68.28403242172735, 68.09631563002064, 64.69839772870465, 67.75063714673443, 71.38350502137216, 72.79593483094247, 70.82794051016532, 65.52570012307936, 62.1063700029927, 69.08502747935634, 71.79530682102327, 80.73374517502324, 73.305921400747, 88.7026128461284, 4.728231910736331, 0.42608121890694867, 67.36302852630615, 67.21305278039748, 55.28871013272194, 35.740221238905384, 66.63035331233856, 47.35549680648312, 54.82359155531853, 64.56262096281975, 66.28329415475169, 7.636498280109898, 0.0335822532313966, 0.06795156221356123, 0.11759771394633478, 0.024784723589677485, 0.02000736865034748, 0.152136757369003, 0.02195770593149768, 0.08707693192146479, 0.1288422299248557, 0.13065870100211713, 0.1706311464189522, 0.1404969859868288, 0.11665528790364343, 0.14773680798469052, 0.12209205302379786, 0.18464353806789846, 0.19609155764262523, 0.32049959405295314, 0.1820707237047534, 60.684208793024865, 73.36738494134718, 69.74971232875701, 77.38731230458906, 112.67657864478328, 52.729920571850194, 46.28975745170347, 67.41187772443219, 72.3080704289098, 17.658712517830637, 0.7082812584215595, 23.726499542113274, 67.47439246023855, 81.7339103452621, 68.96114333983391, 78.2947918676561, 69.646483390562, 70.94569006273824, 62.572331889983154, 68.69788954334875, 69.88831320116597, 68.52833332553988, 66.45638050571566, 74.09718898034866, 56.783592085684504, 58.54772906149588, 61.71319946166008, 63.59304243518461, 67.82669190437564, 67.8090726175616, 66.9154860896449, 68.41816963688021, 66.6072662415043, 60.676042418326105, 51.16943305538547, 50.486975946734034, 57.25978743645453, 61.02475289375552, 61.487722012304495, 64.2928756436994, 57.47714165718325, 54.88752226675711, 52.440261379365005, 50.36719460641184, 50.385108070988814, 49.0119254973627, 52.25618454717821, 54.36861622718073, 52.359001636505134, 61.06561222384053, 59.37492162950578, 63.929621019671046, 64.01493649328908, 65.13616169652632, 65.07434514261061, 62.635725236708126, 66.10421442216443, 64.58700241581087, 60.32364099256454, 64.13454132695352, 61.223809257630386, 59.65238225075507, 55.885157508234826, 48.52321778574298, 50.030596410074544, 49.73564986259707, 47.93681167787122, 49.88583741649505, 45.80441121132144, 50.5036852436681, 45.813224777098625, 47.44529162683795, 48.054878942428104, 52.36141781653128, 57.061244903072236, 59.13160916297667, 60.442139717840384, 57.97860099423317, 56.38504789721582, 62.57271235988986, 58.103869730426425, 58.83947103254257, 52.94574114584154, 46.31867316461379, 51.72058882251863, 47.97974986414756, 51.034138741031775, 47.89453637215399, 50.10865157650363, 51.77549808256088, 50.79975751138503, 58.01111744296167, 57.30618907559303, 53.430612779432735, 59.41358835466447, 60.292450304954286, 61.50441561975787, 61.95637856760333, 59.66380419269685, 60.71071617064938, 60.522826794655096, 58.460472014642534, 63.799986685476, 64.62390407439202, 62.92682001667639, 63.695486899345156, 61.30991705002324, 60.83245085131738, 57.26825583365656, 60.11732039913055, 53.82248893860848, 50.7818675810291, 51.81985616683961, 52.08225880899737, 55.678668252883426, 57.24001476841589, 64.9771095860389, 58.12946711817096, 62.89836714344641, 60.90181012307445, 55.36725559542256, 51.68127882865168, 59.87734194724791, 65.36609495839765, 67.1665491596345, 65.2605478994308, 67.40353092070549, 68.61069525441816, 71.4393360384049, 68.58410158464986, 72.20419037726619, 69.91110217186713, 73.0141519731091, 66.45023022928547, 72.55401088345435, 73.56176191760649, 77.24540879649501, 74.53820459304318, 69.46992966436571, 67.17968125497141, 74.07343510658511, 74.26044587166079, 85.96391985493322, 76.06770146277644, 93.74061492181595, 9.473780105190894, 0.3998705318137523, 70.73903606783959, 73.92469098491054, 64.28117129110521, 40.275602955972, 66.77355120258947, 61.74509617590136, 74.02957516331827, 69.45410682309058, 78.95986895407401, 9.475325519038785, 0.35188358096826466, 0.2158264728683618, 0.22071046724675164, 0.2421955563007824, 0.1832027105434287, 0.22123292388935245, 0.0950835083401011, 0.20926494511865804], [0.0518319537983306, 0.11044999103873007, 0.038967820695571365, 0.07147621017910781, 0.02568898887764062, 0.03089829866263655, 0.031195073463623563, 0.041437278306412126, 0.042415729633742766, 0.023961142681899573, 0.5877892336537761, 49.425578655735144, 61.43048286437989, 41.98995720955634, 44.57791743739959, 91.4504292703444, 54.08609182603898, 30.222681953061013, 52.51529632076141, 55.13172511131533, 23.75059073971164, 0.471379078564144, 12.997811032879738, 65.02817100094211, 71.21095995749198, 69.58889515169206, 66.8080602153655, 61.143690924490656, 59.71714842704035, 61.12358877735754, 65.31190349209693, 64.56685712260585, 68.29434825528052, 71.07963115938249, 58.522296413298584, 56.43972181504773, 65.35954460020989, 65.18622290703559, 65.18782323406589, 62.76614404493763, 62.26334717965896, 61.940465511814246, 60.060544090886275, 58.66428229116625, 50.3446449002912, 48.573055421152425, 52.6719714749244, 56.90966098539291, 59.27808223232147, 58.65104036946451, 56.46979070478871, 55.11388224940146, 50.98257526274651, 45.94957813139885, 47.93217543632754, 46.253938367289884, 45.76501100294052, 43.9347703226151, 49.715551637834125, 56.16405371696719, 56.74298770966069, 54.49261411543816, 56.18887055304743, 55.55750231589041, 56.64603064137121, 56.564551245781686, 61.605797121601725, 56.60796011647871, 60.637301168134144, 57.3250948998236, 57.468794853456565, 57.67879855248236, 56.68456400594404, 49.57844911083099, 44.79449110646402, 37.899795886008974, 44.42105400946833, 41.08066158909952, 41.52574469966274, 42.566451488002656, 44.330066788581114, 44.20485296557027, 47.27080891209264, 47.237657039396225, 45.03649742372575, 53.31868010182535, 53.90515681236021, 54.18228010977469, 50.783012913119414, 50.019041107546904, 54.76256339780746, 53.24387265789894, 53.95160551994078, 51.70163200747583, 49.113816907328946, 47.00208733158727, 41.82985782623291, 41.81230914208197, 41.62498066502233, 45.78688606139153, 46.71232223510743, 48.639300330992675, 52.219357413630334, 50.612519248839355, 49.30000397466844, 55.92378108732162, 57.7094675648597, 54.65631815694994, 55.488194034945586, 57.69708071985553, 57.38375786812075, 57.32571463431082, 56.08506110406692, 56.66701924416327, 55.780504749667266, 59.39540424654561, 56.06956774188627, 55.05902398017145, 56.29752805156093, 57.38769985014393, 45.0032788707364, 45.239942919823434, 45.47828966571439, 47.28590611488589, 48.31029584330898, 48.1440265717045, 54.20775590404388, 56.94316587140484, 55.70690539575393, 58.69762636000111, 58.95573008445002, 51.38632443643386, 47.31186828305645, 48.741223119920306, 55.17273741383707, 59.37463921885337, 60.81332537435717, 60.851274305774325, 62.40220692849929, 61.196854729806226, 63.298170412740404, 62.89706883891937, 63.62564125368672, 65.27809658358174, 65.82590656895792, 63.394421454398866, 66.90458974530621, 69.56697694716915, 65.29071092605591, 63.429205033086966, 58.33548568910169, 65.67944526672363, 71.67538427537488, 72.71551839766964, 80.02361574480611, 68.28503654849145, 0.5921586314516684, 4.194086972744235, 72.32142217697637, 54.56540153872583, 36.51427353582075, 20.26769861098259, 46.14306472962903, 44.41213453969648, 42.717011667067005, 44.43953229535011, 60.53583729651667, 17.324187294129406, 0.23399535115928422, 0.0647001241844508, 0.14930765595166914, 0.014340730230023545, 0.05795956168684268, 0.12466873613096054, 0.10262216591546613, 0.06830076041120677, 0.054937371638633554, 0.05601663630635989, 0.048418978469506394, 0.08299837174314646, 0.05691578221176902, 0.025166252612947457, 0.04871694453721566, 0.04761484661890615, 0.12596960705254348, 0.03942390731085212, 1.2227602903881383, 61.31864432365664, 66.2097026455787, 48.93824769604591, 48.390975075383345, 100.09225799191384, 56.686517346289854, 35.094767770459576, 57.294849503424864, 59.780353499997055, 30.605283667964322, 0.4965450668767576, 12.855731018127935, 67.31927840940415, 75.1072463681621, 73.25023158904045, 68.48944694765153, 66.40602511744346, 64.72096312430598, 64.13345090804562, 69.80177787042433, 67.19136207334458, 71.86414441754742, 73.43504582681965, 58.933451021871264, 59.43215293269004, 65.739865456858, 65.58584182493149, 66.94511567392658, 66.95903224329795, 64.7659723220333, 62.745284880361254, 62.966494790969364, 56.58558299464565, 50.62398041448286, 49.659214635049146, 54.91702633519327, 59.91767175735966, 61.58268259417627, 59.4534396356152, 58.92799500496157, 58.87478413120393, 52.72044020314371, 49.94142916894729, 50.69379468117991, 48.890967445988814, 48.77311198942123, 45.564071901382945, 50.17464937702302, 59.4870896493235, 57.50576711470082, 58.01987609555645, 57.87692531462639, 58.95132526274651, 57.96976389423494, 58.62190892619472, 62.209171402838926, 61.16101603354178, 59.367653477576475, 58.28563236421155, 56.820207411243075, 60.185095033338, 58.10783524667063, 51.29993031101843, 45.90659679905061, 40.31851760802731, 48.07364356133246, 42.01640967399844, 44.0453693943639, 44.24169971096901, 46.13296462643532, 46.70982760767783, 46.46144743888609, 47.365075234443914, 45.4076595460215, 52.425391674041755, 53.56747996422553, 54.8397752546495, 50.97655050216183, 49.192527109576815, 55.14284503075385, 55.34705931140531, 56.88431070696924, 53.30639523844565, 48.8412670935354, 47.36158040262038, 43.148021313451956, 42.65385758492255, 42.99610007193781, 45.57058695823916, 47.1664228746968, 49.00426903078633, 51.88859178173927, 53.3712516292449, 52.056779092358006, 56.59942503898375, 58.67172694975331, 56.28226610922045, 60.244263987387384, 57.77386111597861, 58.19505699219243, 56.961051879390595, 59.04905503795993, 58.06449697863672, 58.20691431722334, 59.85526684791812, 61.44937692149993, 58.233833543715946, 59.98914910900978, 59.425433912584865, 48.25579058739447, 47.38103928104524, 47.57372179339009, 50.295842770607244, 48.9633979335908, 52.05464924535444, 58.220968169550744, 61.20138898972542, 61.00808674289335, 63.51497942401517, 64.34059912158598, 58.722737373844275, 51.65524213544784, 50.936620773807654, 57.59931956568072, 63.559062942381836, 61.67098691386562, 63.82983592248733, 63.98828006559803, 64.34993828496626, 67.3340343659924, 65.6517219543457, 67.74170198748189, 67.4088731888802, 67.10091221717097, 66.15335387568321, 70.75296048195132, 71.20584518678727, 71.71507866151872, 66.80817004173034, 63.40709071005545, 70.025800120446, 75.59657773663922, 77.51147101002356, 82.33220515712615, 67.573989283654, 0.5605139294939657, 5.630288306743869, 83.60074673929523, 60.73629002417288, 43.49486081830917, 27.64678889705289, 54.87691617781117, 47.505864789409024, 40.3091392209453, 55.0294336195915, 68.34853187684091, 29.47176575660706, 0.1724976890029446, 0.06634799463133659, 0.15392370341766268, 0.026913208871959683, 0.05431912336198073, 0.08770678643017046, 0.0329641351896909, 0.10582002375515238, 0.21835028824786987, 0.11829044895186541, 0.1848717709823001, 0.12286009447228526, 0.26609448115191153, 0.13187573892214607, 0.13574576996747525, 0.16181183498232596, 0.18144426296555227, 0.14125323734216153, 1.5000983375695445, 72.74380653135239, 77.55162823584773, 58.9955460640692, 57.440753829094675, 102.00275036596484, 67.88327601648146, 45.41791262165193, 68.87876572147493, 69.7783770099763, 34.452546335035755, 0.6464894644675717, 17.928061677563576, 71.91599030648509, 79.26908508423837, 77.53669969497189, 72.33817069761216, 69.79955780890681, 65.2731583195348, 68.86344494358187, 72.76661119153424, 70.51695931342341, 71.82013542421403, 74.9570039010817, 61.99349987891413, 61.18345983566777, 68.76300088820919, 66.3194505630001, 72.0477819442749, 72.43005614126884, 67.36861398143154, 64.804639047192, 64.42773065259381, 63.0670565174472, 53.036257682308076, 54.65664371367424, 57.517487156775694, 64.14870108327558, 64.91331615755635, 64.66044095254713, 60.99118917219101, 60.52670209638534, 57.41239901511901, 52.188170648390255, 54.685610417396795, 52.4917071865451, 50.94294363452543, 47.08504938310193, 52.792941293408795, 60.36548091519264, 59.92531253445534, 62.13989842322565, 63.44515731257778, 63.748242778162805, 59.94916446747319, 61.73826732943135, 64.99945925128075, 63.69342765500469, 63.3436228382972, 62.38675279002037, 61.395569847476104, 63.22537122234222, 61.43761765572333, 56.36097631146831, 48.42229127883912, 45.81908479813607, 53.32252010222405, 48.98052300176313, 49.279117353500865, 48.719528490497225, 47.94122826668524, 48.24010110670521, 47.05369395594443, 49.52374773640787, 46.76322283283357, 54.71067044042773, 56.003122791167236, 58.529195862431685, 52.713497607938706, 54.60770430103425, 59.26883720582532, 60.25925136381581, 62.15128898620606, 55.10811244287799, 51.211492630743216, 49.97442414683681, 45.88908733860139, 47.24805916509321, 44.876939327486106, 48.5120351083817, 50.269613881264966, 51.19208866550077, 54.306991869403475, 56.18904705970518, 53.424321297676336, 60.6520139786505, 61.70241686605639, 60.56744375536519, 62.74646159141295, 60.495993860306285, 61.147809413171586, 61.31975043204523, 62.53028015936575, 60.545431413958156, 60.178568209371264, 63.939732889975275, 63.44310199060748, 61.42035922696514, 60.379044471248505, 62.147472520028394, 49.01131360761581, 49.100571063257036, 49.50451243308283, 53.295087045238866, 53.155650707983206, 52.95252684623965, 61.02842030986663, 61.871725974544404, 63.33655080487652, 66.28768720934468, 65.60002511547458, 61.02610611146497, 53.6186747397146, 56.530822784669944, 60.04906723576208, 67.79902350518012, 65.00305606472877, 66.7204423104563, 67.23534753245693, 66.4453664902718, 67.94331965907928, 70.26472737712245, 70.4832112404608, 71.77323956643382, 68.2917438014861, 69.05445652623331, 75.5037352346605, 78.3994956170359, 73.41071928701093, 69.37836585506317, 65.17622870783653, 75.98300180127545, 76.56322233138546, 81.03797205032842, 81.06240841650194, 77.14479215683477, 1.0668488952421373, 4.324882328510284, 89.52394147073069, 64.79458601244035, 52.28603770655971, 28.580012936745923, 64.59679265176096, 58.504178985472656, 58.387908166454686, 61.98534527132588, 83.92251445401101, 31.97327498466738, 0.35238285579027673, 0.12940591741954127, 0.25832628831267357, 0.10231522512772392, 0.19293507621172937, 0.2672941441978178, 0.20805935255221783, 0.2651081889146759], [0.05723318393011728, 0.041404152664566235, 0.022974951951313886, 0.035546506499691356, 0.15179698205282613, 0.048137759083821896, 0.01916214958914826, 0.03845390976376591, 0.09345978498458864, 0.14713634826963948, 3.4189359218843522, 59.2471621882531, 46.76696869634813, 23.88459655546373, 48.783749457328554, 91.20741490394839, 45.772840053804465, 25.318909268225394, 46.25683307647706, 57.5447319399926, 39.75277062385313, 0.6276422306414574, 5.19096274529734, 63.05546983595818, 70.83224727261451, 74.41590509107037, 65.49509386862478, 62.6528581496208, 61.04514529628139, 66.39140252144107, 62.33700536912488, 68.24936651414441, 74.26777285914268, 61.77164277722759, 61.090123115047334, 65.64977645874023, 64.61953063164988, 63.305618993697635, 62.55517544284944, 61.52258403839604, 61.605993240110344, 60.772756299664906, 55.11456081944128, 52.751791707931034, 48.52043290292063, 46.758041381835945, 52.25977351588588, 57.87865900224256, 57.467527927890906, 58.93568285049931, 58.223713828671364, 56.895583598844475, 52.78408458155971, 49.29867036880986, 48.0929494673206, 47.62424584357969, 44.90616098526986, 45.70727371400403, 46.449950971911036, 53.935276692913426, 54.678746269595244, 53.21451371715915, 56.3047020666061, 56.73624515533448, 58.91097976315407, 57.45137560752131, 56.9523952084203, 59.88563776016236, 58.890104909097, 56.75707294094948, 57.407448983961544, 57.06070361598846, 55.882054913428526, 48.527677520628906, 40.19544932150072, 44.13799224361297, 38.73304067119476, 38.841835452664284, 45.939697680934785, 41.843291944073094, 45.4723237406823, 47.03973816287133, 51.64192961108301, 46.864474896461736, 50.94028034517842, 49.48104881471204, 52.84930183041481, 49.0058615130763, 47.65647988165579, 44.9204227232164, 52.59639132407404, 52.73463526079732, 52.46735711251536, 53.82790180944628, 49.28274554591025, 49.929010944981734, 49.553545982606956, 46.501996901727495, 47.41166122498051, 47.768432171114036, 50.499449083882, 49.10851778522615, 48.86600155984202, 48.34282798151816, 54.4343473065284, 57.76823251478134, 52.910353522146906, 55.08448408495996, 57.71718286698865, 57.21733954644973, 54.423015579100586, 53.13985924566946, 55.124539329159646, 58.34387563890027, 57.25693195096908, 56.26472526980985, 53.608398129863126, 54.16614740125595, 52.32502606607253, 47.75336634728217, 45.235181162434245, 45.86779671330606, 48.337505325194336, 50.44738746458485, 49.34663311127694, 49.88467639492404, 53.07366924901163, 58.41504312330677, 59.03920204408708, 56.836806881812315, 62.16829638327322, 58.83242253334292, 51.16518905085903, 44.26972896822038, 53.0494172342362, 56.91310090403403, 59.867590934999534, 60.94578381507628, 61.32098597864951, 63.32405021113735, 64.53305021409066, 62.15184204040035, 63.61906736127792, 59.68990756619362, 60.212331971814564, 60.71881194268504, 67.1241169591104, 65.93760782672514, 67.5690314077562, 62.316644345560384, 59.76810001557874, 66.66275208996188, 69.70640936205464, 71.20421348079559, 78.11993260537425, 29.295969047854026, 1.2263627422432746, 20.17208299329204, 66.97432948696998, 42.32623769390968, 22.01153535996714, 30.974070795120735, 53.47792833082138, 48.995333871533795, 40.575491689866595, 42.30469211455315, 63.149626331944624, 28.0573021981024, 0.3389770832032927, 0.03836263421802752, 0.010345394970969328, 0.031695141186637264, 0.058707117944234805, 0.038476739183909474, 0.08131926023070851, 0.04431752375357094, 0.03273327076326936, 0.00493107479058146, 0.04767839744266483, 0.06134316137421036, 0.058234426373195265, 0.041830063076509584, 0.04441965476519639, 0.05824273842717371, 0.08960956497298134, 0.25433748299556397, 5.963178882675787, 69.88776406934186, 56.75189541232202, 32.57022050119216, 55.984444464406664, 99.0316177183582, 50.94603838459138, 31.67146036701818, 52.72076575986801, 60.18695423679968, 49.890540338331654, 0.7633866369724275, 2.9083869822563666, 65.70293634168564, 73.72835282356509, 76.3755290738998, 67.88823389237928, 67.63806512278896, 64.92033327779463, 70.79783239672261, 64.9953172283788, 71.8492551003733, 74.85109990642917, 63.62378597259522, 61.3229432413655, 69.12895018054594, 65.67778610414075, 66.84814683852657, 65.32877360620807, 64.56448016628143, 63.55766265623031, 63.71426720773021, 58.69797937331661, 53.98159596227831, 50.54917689292662, 49.69398644662673, 54.92000733652423, 60.30464103144985, 61.393930296744074, 60.4066030440792, 61.663224543294604, 57.9081513035682, 52.52978947854812, 51.138097240078835, 51.84739905018961, 50.16136038687922, 46.327745606822354, 46.39726569575649, 49.321090636714814, 54.152101393668886, 56.905479738789225, 57.89001426389141, 59.11841038734683, 58.897596636126124, 61.41886480392949, 58.97570671573762, 58.33380299229776, 59.96663862659086, 61.26174249956685, 57.47540404719692, 58.3330616643352, 58.27638341534523, 55.108155588949884, 49.993686906753055, 40.77634449928038, 45.86667491543678, 42.874592888739805, 43.7183770825786, 46.612082142983716, 41.712661327854285, 44.42888306033227, 47.18241437788933, 48.72360775547643, 46.29686870882588, 50.233029934667776, 50.92935654424852, 50.883241238132605, 49.69527298404325, 46.96921002480292, 43.45013403123425, 51.90419104791457, 52.94623928685343, 54.27032947540284, 54.01455171646611, 49.85811802648729, 49.29768977626678, 47.91132411649151, 47.345137826858036, 47.57536526649229, 44.512162823830884, 52.129072297003965, 49.04547352944651, 50.9065205051053, 49.28795053112892, 53.459834437216486, 59.42231562829787, 57.79614410092754, 56.96699427020166, 58.13970842669087, 57.932093451100016, 56.2339581981782, 57.70812611426077, 57.23348009970881, 60.44334388548329, 59.653476592033144, 59.47770733987132, 54.96611087552963, 55.219778399313654, 52.72461752737723, 49.27376331821565, 48.42951236232635, 48.93929889125209, 52.88458355011479, 53.29798567679621, 51.296392333122995, 52.68569192578716, 56.579420951104936, 61.916488062950876, 63.68466900240991, 60.08896950752505, 65.8711471865254, 62.646056759742, 53.627296109353345, 48.771001754268525, 55.31603728571246, 59.26657007586572, 64.11118361257738, 64.92273376834008, 63.288062464806345, 65.09261162050309, 67.11060047149658, 65.43567388288437, 67.82812749185871, 62.03195087371334, 61.8761190291374, 61.65696836286976, 69.99732371299498, 71.19831423605643, 73.06981825059461, 65.37599894308275, 66.4474610359438, 70.15814873480028, 73.7743700704267, 74.56035813977643, 80.14477775942895, 26.971543065963257, 1.10893408858007, 27.44420632239311, 73.89022119583623, 47.13265518988333, 25.373661633460756, 35.754675172990375, 44.56813112381966, 53.74444946166008, 41.45423596905124, 58.435486516644886, 72.70754029673915, 39.183207173501295, 0.20583846365972874, 0.07476504095980237, 0.0466033922237975, 0.04117293966813915, 0.061757622602125334, 0.019371243711981564, 0.06714872505155302, 0.019323238727426337, 0.13577474341277154, 0.13992485620321768, 0.22927476333514338, 0.24235891688975597, 0.3274066121347489, 0.16660483343706978, 0.12416418296315017, 0.18706767008669917, 0.3677881178596328, 0.34179922854227407, 6.2159829947256275, 84.19500935462214, 61.72955182290847, 40.22662039726011, 60.571464184791814, 99.80708599090578, 58.127243134283255, 40.40594331679806, 62.14769217275805, 67.61911223011633, 60.02028096106745, 0.5920442085592978, 6.23687893152237, 73.27597802685153, 74.98551953223445, 79.82043696988015, 70.02317213243055, 70.08675375292378, 68.51253401848578, 73.93320252818447, 69.46843916370024, 71.3378329430857, 76.63966148130356, 68.88694778565439, 62.71551409075337, 72.46263534792008, 69.98603513163906, 71.10027067122921, 67.71869336405109, 68.62727903550672, 66.73809297623174, 68.55678619876986, 59.814297691468276, 57.50941884133124, 54.26803096648186, 52.685542875720614, 58.051153075310495, 61.38928228808988, 61.672206770989206, 63.58683332320183, 63.538313604170284, 59.66409052571943, 56.09531025732718, 53.285567452830655, 53.412416904203354, 53.531774628546934, 48.75881887251332, 50.37224661919379, 51.81258409254013, 58.9188951061618, 58.58379133286015, 60.91851157526816, 62.010675937898704, 63.38783971724972, 63.85600597627702, 63.68189196432791, 59.73014716179141, 61.09192348295643, 63.49947429472401, 61.39074140979398, 62.439100742340095, 63.234537801434925, 57.97650644856115, 52.70667660620905, 42.53035783767701, 51.68988058643957, 47.617413074739524, 44.9996663678077, 48.7083811144675, 43.394514822190814, 45.96619329144878, 48.12361455732777, 50.338984920132546, 48.799007477298865, 51.51837887302522, 53.5254753020502, 52.81380830272552, 51.96515252513271, 48.30720893798336, 46.84103873468215, 56.43423834154683, 52.86720352788126, 56.788259706189564, 55.69910772385136, 52.50545117162889, 52.28003255782589, 50.81047734906597, 49.31576013565064, 47.73401337285196, 48.812771074233524, 55.60371568126064, 53.22991686482584, 53.27930342766547, 52.607475942181004, 56.2789007156126, 62.47977964339718, 61.23176382433984, 61.307030185576416, 64.29857484755978, 60.89542058206374, 57.90744919930735, 59.13777905125772, 61.09707355499268, 62.911762037584865, 61.7919881113114, 60.14402389526368, 57.84032175617834, 59.35217580487652, 54.99572869270079, 50.976625027195105, 51.01298539869247, 52.37441655128233, 54.57956129504789, 57.31501440848074, 54.62368403711627, 55.303387641906745, 59.37691419355331, 64.55739636575022, 65.52360557740735, 62.19345838792863, 66.09586761843774, 65.82654983766618, 56.05838114215482, 50.351662020529474, 58.21939922148182, 63.403356613651404, 67.32243983976304, 66.67065174348893, 66.52029945004371, 69.08334870492259, 70.19659580722933, 69.22125924018123, 69.74191465685445, 66.97908339961883, 63.582420656757975, 63.56067895889283, 71.46935001496347, 75.17896298439273, 76.9620018620645, 70.74895181963521, 66.53509463033369, 75.57370247379427, 75.046080927695, 80.45690428826117, 84.48724162194037, 41.401825258808756, 1.3596022249229494, 24.790085515668316, 82.62332347131546, 55.77963398348901, 36.04487173018917, 41.59018924159389, 72.38570197936028, 66.63464438530707, 55.98794714097054, 59.0557897475458, 82.67640098448723, 50.499900156451815, 0.5893578752875328, 0.11000925299501228, 0.2592719472464054, 0.20353673716946957, 0.17601692838774574, 0.06997522943082356, 0.3295903610846689, 0.18095225065706239], [0.08036924991756678, 0.046626305913612734, 0.028007891059162158, 0.07956868803669369, 0.09587399616476991, 0.062103986274451024, 0.15410856043379154, 0.16686315828513715, 0.10933950062721007, 0.3503015481175915, 10.385407574715154, 70.40404212090277, 50.83103449113908, 31.296646518092004, 18.815590104749127, 34.31893079511581, 36.98642884531329, 21.40352679837135, 43.50430980805428, 58.64075199250252, 60.102493839879195, 8.531400272923133, 0.44521668565369427, 41.55613914612801, 73.88739708931216, 69.24153004923176, 65.06701423275855, 64.39381391771379, 62.32702293703633, 66.36083941305837, 64.62453557598975, 72.06877446943714, 53.23142697734218, 61.4136911976722, 63.401983784091094, 62.98851889948692, 62.35910792504588, 64.44636583328247, 59.92870930702456, 61.06259592117802, 58.48340219066989, 59.6828119985519, 52.76980715413248, 50.21171577515141, 44.59672520237584, 51.65064511760589, 57.911038168015025, 63.916712499433956, 59.638908909213164, 60.172680731742616, 62.91596289603942, 59.7303746592614, 52.11031944521012, 50.258329222279215, 50.94786228672151, 50.027937043097715, 47.63904494623984, 48.18964765917871, 43.39928834669052, 45.8096867992032, 48.64472889131116, 52.83081177742251, 54.3933310816365, 56.24283452187815, 55.80731414979505, 57.776653843541304, 58.68574157837899, 59.87894227427822, 58.12347373654766, 56.284203760085575, 54.35650787045879, 54.07760773935626, 56.19022377075688, 49.49003888714699, 46.07711007518154, 45.21859738134569, 35.839731770177046, 46.58844594032534, 42.68912361514184, 43.86598763927337, 43.032907593634825, 47.38970379675589, 48.95516880096928, 47.05733783783452, 47.199037382679606, 45.67046226993684, 48.9006047095022, 45.924239620085686, 46.41376710707142, 44.78139039008848, 45.92725984511837, 46.611905636325965, 50.48046481224799, 49.607262842116825, 49.166251151792466, 49.868928078682195, 51.73242653569868, 45.52322433840844, 46.04275403484222, 47.21331481010684, 46.23956288060835, 48.24040705157865, 44.51416715498894, 47.7128404186618, 50.9132356028403, 58.02183335827243, 53.81002756857104, 55.379501235100534, 56.938262908689445, 57.52203710617558, 56.76953431098693, 57.42045164108277, 59.63113084916146, 57.39345788955689, 57.20702763526671, 54.535673895189845, 55.322556264938854, 49.11487594727547, 45.7111450933641, 44.17632556730702, 46.604523735661665, 47.38187866826212, 51.640670530257694, 50.170134728954686, 48.2545824973814, 51.43776239887361, 55.377124278776115, 58.21277826063095, 57.269334485453946, 55.009939439835094, 62.79681305731497, 59.69845833316926, 53.07202577590943, 46.05861217744889, 49.21977581516389, 53.254078665087306, 60.379934849277625, 62.891185283660896, 63.372440491953206, 58.54590908173592, 61.61347320002895, 60.051091178770996, 61.20957889864522, 57.250346291449766, 61.4713421944649, 57.21393100676998, 58.85144602867865, 66.3019960157333, 68.43316878041914, 64.3139034701932, 61.51898330257785, 67.19708088905581, 72.60226388131419, 69.59229976900163, 65.60833661786972, 4.312651888016732, 0.21369517029773807, 43.606420870750185, 62.069307527234486, 47.70668229749126, 19.32168176097255, 37.305011595449145, 52.820233145067775, 45.04729178643996, 36.12741408809539, 40.995048015348374, 54.08068679994153, 37.06106370495212, 1.0855092036147271, 0.1134924249603383, 0.07049852110926183, 0.07277529611582718, 0.020889055411962253, 0.0407646952437297, 0.05681675002579728, 0.030391518094186342, 0.03191507928403876, 0.07807612659469729, 0.10349759756917916, 0.042758488862384716, 0.08360821603526992, 0.10048383831857674, 0.09034221315936697, 0.0548775669848246, 0.1625905173920816, 0.5138478061604885, 14.165795791533686, 80.05246869979366, 58.41407037550404, 38.81766580766247, 25.139564775651504, 45.23393777108962, 43.913083537932366, 23.10360754689863, 49.24520061862085, 65.093702039411, 69.4505766899355, 10.617040203463647, 0.38069587200880056, 41.010357026130926, 75.99266652138003, 74.61580476453229, 68.3774789687126, 69.26377773284912, 65.23586050156625, 72.177212315221, 68.40320971704298, 75.80701289638397, 56.58148411781558, 63.55516018406038, 64.59526684976393, 67.58002973371937, 65.79399416523596, 67.46138588074716, 62.53673638066938, 64.69961366345807, 60.04513309847925, 61.288493064142045, 55.78338376937374, 52.302005675531205, 47.52398221723495, 54.34609790002146, 57.44719436091762, 66.25835572519611, 60.09034625945553, 62.458787118234945, 64.464200850456, 61.015362739562995, 53.422238519114835, 50.875757355843824, 53.80206123475106, 51.77725530439808, 51.221294633803836, 50.449819334091686, 45.131775717581476, 46.92881745676841, 50.73143766772363, 56.06050706678822, 57.0475636759112, 59.25750155602733, 57.989485571461344, 58.51713457415181, 58.77810555119669, 63.28163370009392, 59.24651891954484, 56.779077437616166, 56.1879252618359, 56.763497783291726, 58.872191444520034, 52.44121843768705, 42.81267043082945, 48.400620183637066, 41.12978143076743, 47.33372765202677, 42.31554923519012, 43.93547634924612, 42.860405675826534, 49.14052824820242, 49.80176533422163, 47.909547282803445, 47.206760529548895, 47.86859773820447, 48.06065267132175, 45.19247831836824, 44.25407478886266, 45.10272272171513, 46.28465444810929, 48.23874788899576, 52.02058346040788, 50.05012196879233, 49.776630786157426, 51.4196567381582, 51.378024701149236, 45.76790963449786, 45.373954619130785, 47.823682677361276, 47.425546415390514, 49.62041062693442, 45.55401102189095, 48.85889814745996, 52.1433771810224, 56.96176575076196, 55.69500100228095, 57.61720165129631, 59.82400555764476, 57.90410733992054, 57.522335206308675, 60.024799531505955, 60.868870058367335, 58.88523724771316, 58.68737720674085, 55.75637825073735, 57.15197716989825, 52.08929161871634, 46.69247896440568, 45.333613041908514, 49.463911979429184, 51.65617958191903, 53.776091221840154, 52.41851183675951, 50.11167180153632, 53.3178093356471, 58.0482622884935, 62.124059892469845, 59.08977316271875, 56.43052777936382, 66.34230229162401, 63.32074365308208, 56.04241317318332, 49.66229369563442, 50.81844368288594, 56.112305887283824, 61.998265558673495, 64.90639709657239, 66.87818434930617, 62.771011706321474, 63.296138624991144, 62.40748251638105, 62.51486524458855, 61.645518964336766, 67.86367201036023, 60.81616124799175, 60.51646863260577, 69.3252726524107, 70.77072881883191, 67.55549923066171, 66.90801789683681, 71.95867353870024, 77.68756974127986, 74.08376662961899, 66.75206445878553, 2.869740604392944, 0.16435487916873348, 52.482175827026374, 69.2901203709264, 53.78002143675282, 21.81222796440125, 37.394673055218114, 52.138791930290964, 56.96339353438347, 29.857879953999674, 54.729164415790194, 63.2344554316613, 51.321656319402884, 1.8494844412611378, 0.12978628007394652, 0.0576575315226951, 0.09747349582011662, 0.06110200838696572, 0.07974926262132584, 0.03177435467800787, 0.07622110597308605, 0.18676279773635251, 0.11106125259351347, 0.29461906021160467, 0.15384802925250224, 0.17504831745980248, 0.2680293128134743, 0.24140040300065474, 0.2505874213191771, 0.24076600559055808, 0.5193754982563757, 16.950687439210956, 92.88215714116251, 65.19767230556857, 47.1848697816172, 27.1137446741904, 49.67874803850728, 52.68077327359108, 33.85197262610159, 58.23391983585974, 73.64999171226256, 76.14650972427862, 11.6063541366208, 0.46058943495154386, 54.15381154706402, 75.92864559542748, 78.40607735418504, 69.28265217811831, 72.64050699049427, 66.19551151029526, 74.96179703743228, 69.83922081608927, 76.47289014631703, 64.53832187960225, 65.59735398138723, 69.36937578262823, 70.04551395293205, 69.20429891155612, 69.45923728327598, 65.77770063954016, 66.38370683116298, 64.5001454507151, 64.65562428197553, 58.954788715608665, 55.36594160141484, 51.33428242898757, 56.34931902731619, 60.87768362414453, 68.8843511766003, 62.22315857487341, 64.39190764581004, 66.6611909866333, 63.43513173441734, 56.11594192443356, 53.90086181702153, 54.10925734427668, 54.53472075923797, 51.723161897351666, 53.84582311876359, 48.782462919912035, 50.44512425699542, 54.53954527454992, 60.4026924410174, 60.81387842855146, 60.230139532396876, 59.88439044644756, 63.87491572287775, 62.8547582318706, 67.1513617423273, 62.64848078450849, 59.36742205773631, 57.77413568189068, 61.34488890247961, 59.523187222019324, 54.572861886793575, 46.16076246384652, 54.36605491945821, 46.90992732201853, 51.47448755079701, 46.657977796369984, 44.20458624439855, 43.632179075671786, 49.1481258792262, 50.83183073228406, 48.61526012420655, 49.36442106000839, 49.317007449365434, 49.88257792688186, 47.01939282878753, 47.62132760017149, 46.37828142412248, 47.566708595521995, 49.5231633032522, 52.647123259882775, 53.280197728064756, 52.520493461239724, 52.11228455266645, 53.01795590308405, 45.8252154627154, 46.7441483466856, 49.99924490528722, 48.543139503848174, 52.25512158486151, 48.68623149010443, 50.71434397851267, 53.75535365073912, 59.48219060897828, 58.989909618131584, 60.86867786222889, 61.278545933385054, 60.083666463052076, 60.4441911174405, 63.20397861542241, 63.07097888761952, 61.67758434049545, 62.599859083852465, 58.7215724299031, 59.38703783096806, 53.44885964547434, 50.236293346651145, 49.42442155653431, 51.95535836681243, 53.15513295512046, 58.18868706303259, 53.8012767607166, 54.65196432605867, 55.652000058081846, 60.7596791175104, 63.99667001539662, 62.0190776548078, 58.23361389098629, 70.32058977311658, 66.03658491565336, 57.8777882360643, 52.79568695252942, 54.818676825492616, 59.486030609376975, 66.38246736218854, 68.5673765982351, 69.7139952259679, 65.86536561289142, 66.75976799380395, 66.94381344702937, 67.9919413597353, 62.058544543481645, 67.65632767831126, 61.34648922950991, 64.6251945341787, 74.09941688660653, 75.69615102583363, 72.09886689339915, 69.49907287474602, 74.67785666065832, 82.14183684318297, 76.39077924912976, 75.74200353314801, 9.12846738292325, 0.3161775404887815, 56.38470665101082, 76.79044523546773, 67.4111089398784, 29.72588827533107, 48.72870683670045, 70.08470627569383, 62.131532007648104, 48.53124295511554, 57.317544337241884, 74.06443718940982, 65.3439727906258, 2.8480849535234514, 0.26463637068387, 0.0903065670882502, 0.287740632531143, 0.14901828922090993, 0.1874254944343721, 0.13624460045849124, 0.20363622134731663], [0.01865604317807142, 0.05680709731795135, 0.0111552054483083, 0.06481012674949824, 0.07189555138710045, 0.042068565399536205, 0.151394632674994, 0.0785542727117577, 0.12051836287062015, 0.34800055707173966, 10.605932051135648, 61.78934835618543, 50.91648724771316, 44.9123465630316, 21.882693344546905, 42.894526373955514, 42.37739324569702, 21.002191843525058, 39.16254020506336, 68.19846983878844, 58.25758741747949, 37.24022972968317, 0.3727940427920511, 9.791345000267029, 69.69368519321566, 69.54292497327252, 69.29596470248315, 64.46691120824507, 64.76477599913075, 64.84605143147131, 61.831909994925226, 56.04783388876147, 56.695730993824625, 62.834605093925234, 61.66549559562438, 64.27258522279801, 61.41849217876312, 65.4443266314845, 61.11273950146091, 60.02190089994862, 56.56033862021662, 55.093733033826275, 49.869496822357185, 51.47660563069006, 46.98911605342742, 53.12600543422084, 55.70090024702011, 64.3052311097422, 57.125038331554784, 57.39826279301798, 63.90136426494968, 58.10714883189048, 53.179577166034335, 51.52807889446136, 51.35061517838509, 52.737781001675515, 48.35898814662811, 50.24134535943308, 47.24853377188406, 47.43029640566918, 46.43722288070187, 50.93693064105127, 53.73249015500469, 55.8702995700221, 55.786407916776604, 59.406857567448775, 56.28547853039157, 56.350527117329264, 58.043324024446555, 54.77325970126737, 55.35541788224251, 56.26151284863872, 53.91693961235785, 51.44346944747433, 47.07990323343585, 42.45209478562878, 37.25748423607119, 47.015678344234345, 43.13288880932716, 48.96904222426876, 50.21617943240751, 49.6177355704769, 47.43679185067454, 46.47149655126756, 47.096169302540446, 47.8260596336857, 48.875827097123675, 49.13723345725767, 48.400086741293634, 45.759672657136, 48.047802986637244, 49.784263718512754, 48.739622792889996, 52.27844792027628, 52.61213571794572, 49.845825318367254, 49.43476876904888, 49.59479362733903, 44.69441183151738, 45.95190017454086, 42.53242884912799, 45.224359343128825, 46.583095827410304, 48.272880354235255, 48.984704248366825, 54.192933267162694, 52.893652069953184, 55.217193557370095, 58.95496914463659, 55.77965359533987, 57.932662194775, 55.70290850054834, 55.05451717684346, 58.84264423001198, 57.593271270875015, 53.75769922810217, 53.10065515579716, 50.032981211139315, 48.401098712798095, 47.08747340786842, 53.825458172828924, 51.31760451101488, 50.264679539588194, 52.288795132790845, 47.90236542301793, 51.307877032987534, 54.50628357548868, 60.7165369679851, 59.05921005433606, 56.53605130410964, 60.29192862972137, 63.24902703685146, 57.1926050801431, 50.237038596983886, 44.75662846719065, 50.38895199375768, 55.79011847895961, 60.56290949544599, 61.32174691846294, 62.734529741348766, 61.54979744265157, 63.651109203215576, 61.822053078682195, 62.706402424843084, 63.63662781253938, 64.42029383874709, 66.08760710685485, 65.21958658772131, 64.15951505784066, 62.89435455876013, 62.671246220988614, 67.08537178654825, 68.50625822621008, 72.99163756832, 40.238630694727746, 0.3705319383692357, 1.8334555529779004, 54.96640897566273, 66.21322493399343, 42.976499988186745, 12.324728388940136, 39.72345090681507, 44.15403473761774, 43.559925094727554, 50.875537703114176, 38.15940187823388, 56.9147639889871, 52.471354007720954, 6.9640407639165085, 0.12743407605035653, 0.049358949200400425, 0.05257840688911177, 0.046822137139256925, 0.1109784308280195, 0.04116792562267473, 0.02784311512274848, 0.09221576544786654, 0.026957913932781068, 0.07429570485387119, 0.013773524476545713, 0.012634824792433892, 0.02375742458107491, 0.1954944227491656, 0.07831568994949903, 0.30172103234837133, 0.13130884917993701, 14.497192925022496, 73.63892278363629, 57.92035379717427, 48.080692060532115, 20.95091469826237, 46.3430703070856, 63.19454531515799, 33.60500451057188, 44.010727021002005, 77.14476862261373, 64.33121681213379, 46.624045372009284, 0.315229368786658, 6.98651006144862, 70.36713261758128, 73.57222680122622, 73.55600387819352, 68.55231469677341, 68.93884858777447, 68.49658566136515, 68.33452901532574, 60.232477265019575, 60.309477313872314, 66.23402134064706, 63.582389277796594, 67.558715574203, 65.43195939833119, 66.90340518951416, 62.99657937019103, 63.01565777870917, 57.455227375030525, 57.651216445430634, 51.609342559691406, 53.44743974747197, 49.02453199509652, 54.92032897087836, 58.2138059216161, 66.29289611693352, 59.51999833506923, 59.78001225379206, 64.01986691259569, 60.70844511831961, 55.80872620305708, 53.039183770456624, 52.86627784852059, 54.34072033051522, 50.90921125104351, 51.268704322076616, 49.50494389380179, 47.996459161081624, 49.23057802261845, 53.18703751410208, 56.33835992505474, 55.086598242482836, 58.299780353423095, 59.67409649202901, 60.255548646373136, 59.82624130864298, 59.391991784495694, 57.64712149097074, 59.06423068815663, 56.66318316613474, 53.64092242333197, 51.610970343312914, 50.07447204282207, 46.20022935252036, 40.99291816834481, 48.857984235209805, 42.94822754398469, 48.958071354896795, 48.96156226435016, 49.81703904367263, 47.05633763344058, 45.20673613394461, 46.718268548288655, 49.141504918375325, 48.20621575078657, 49.349257176922215, 48.05829140447801, 45.27731134045509, 46.460380554199226, 47.76147388642835, 47.01287384956114, 50.64628693365282, 51.26575469970704, 49.23532016815678, 49.62172854331232, 47.829676058984575, 43.86133963061918, 45.24382214392386, 43.76253120360836, 45.9539358846603, 45.70257863690777, 49.1468785655114, 49.06854491080008, 55.10973238175916, 52.80959567716045, 56.78309394467262, 58.57032583605859, 57.05490635287378, 59.43338847929432, 57.17032209519417, 56.66080228744015, 60.49498973354217, 56.95334049963183, 55.757452980164565, 54.630077500497144, 54.56317755483813, 49.095185649010446, 48.33557159669938, 54.846223631212794, 54.39097765953311, 52.29940906647713, 54.92702837913267, 51.07861057404549, 53.03649694688859, 56.48781007336032, 62.53347296868602, 62.83091806596326, 59.826778673356586, 62.298295497894294, 65.80531412555327, 60.21638770257274, 53.03329237045781, 48.963543061287176, 51.0058545297192, 59.5998695588881, 63.450079887144035, 65.22375214484431, 65.39137463415823, 66.08787382802656, 67.55495009883758, 66.52987787800451, 65.80593778241065, 63.52672300031109, 64.96778218976914, 69.12349024126607, 72.0548108316237, 68.18111727314611, 67.25839537958946, 66.39921588282432, 73.03283029986967, 72.5068090808007, 76.00200960713049, 38.02113440728957, 0.40633177865416775, 3.116052213215059, 65.3324096433578, 71.2166238600208, 51.58726746036161, 13.58684414817441, 28.63494965337938, 58.1507145973944, 59.685400762865626, 41.24609539585729, 42.52932625432169, 70.20700577766665, 65.60076252106698, 14.896694171813229, 0.22272527848760929, 0.1214271423316771, 0.06533082138987319, 0.05725627382015509, 0.023316450965320392, 0.07042549760831941, 0.07922614714311016, 0.2123167636173387, 0.1500492903494066, 0.14954289090969872, 0.18220535599656645, 0.17929244456031632, 0.09207631446300976, 0.3079365488261946, 0.18964970814845256, 0.5957398779930607, 0.5569826931722703, 17.86397211013302, 83.97818857623686, 68.07337760925293, 62.76557530126264, 28.47101026965726, 60.64243947305987, 60.54730238453035, 38.53884804633356, 52.811800049197295, 79.64018052624118, 75.00482543822258, 47.26090884977772, 0.5115853033719525, 13.494312494031846, 75.1038888192946, 77.15363317920317, 75.61288695181571, 71.5509823829897, 71.40834146930327, 72.10960634293096, 69.64380048936414, 64.83602585331087, 62.00401575334611, 67.89902041035315, 67.62190495767902, 68.9088503006966, 68.16489435011341, 71.16127137214907, 68.10508604972594, 64.92997838604835, 60.64545577572238, 60.350536684836115, 53.517599182744185, 55.25663691182291, 51.77801624421151, 57.839050908242505, 62.109496132020034, 67.362683357731, 63.11383862649242, 61.15314775897611, 65.99893800673946, 60.66342415348176, 59.115476454457934, 56.04159732018748, 55.507739205514234, 57.752641093346384, 55.192376721289854, 54.11858081817628, 51.92442655563355, 52.21102237701417, 51.63834848711568, 58.13978687409432, 61.120709757651056, 58.22722434997559, 60.835012159039906, 63.612426788576194, 64.13763999938965, 60.553758605833984, 63.94129791567403, 59.61985403491605, 61.83552249785393, 58.907885013088105, 57.23619830223822, 54.06822542990408, 51.302150372535955, 49.31769386414559, 42.915169808172415, 52.21951038606706, 46.509037556186804, 49.88075402475173, 50.231143274614894, 52.07807756239369, 48.93085402827109, 46.6387503377853, 49.228416796653505, 48.438129809594926, 49.549094092461374, 52.1248871280301, 50.51117304832705, 46.54609610957485, 48.202622859708725, 50.50860781823435, 49.38286012218845, 55.13007771584296, 55.30964382233159, 51.913836156168294, 50.681035211009366, 49.13188334434263, 45.68136253664571, 49.99459689663303, 47.138087672571984, 50.39713013556696, 49.73750514368857, 50.17082506610502, 50.65232738371819, 56.163759539204264, 59.18300005697436, 61.65375201932846, 60.555684489588586, 60.23851379271477, 62.91163652173935, 60.44673281331217, 58.28210223105646, 65.69928461505522, 60.08134441991007, 59.71044509641586, 59.669413182043264, 56.7977047735645, 52.403226360198, 52.719043839362364, 56.95711774210776, 56.54400194844892, 56.861145188731534, 58.07711524348105, 53.64061647845853, 55.71355773556618, 57.7839376849513, 64.94787223877447, 64.17741283293694, 63.96147066547025, 66.11370655798143, 69.07285244234147, 64.35386849987891, 55.28952990808795, 52.91663715916296, 53.84554070811118, 64.9582233736592, 65.55660840003722, 68.12610995384955, 67.24997012845932, 68.69610878729051, 70.95011449629261, 70.05168776358329, 66.30978584289551, 66.80117253334292, 67.05560884168072, 72.34603897217782, 74.09536115584835, 73.73107494846468, 70.36227672330796, 69.87642841954386, 76.78198076063588, 77.51314193971696, 79.10637732475035, 49.24383171143071, 0.39131878424556027, 2.3663421455890905, 73.51193212693738, 80.15947095809445, 60.96327758604481, 21.656988397721324, 51.74994384088824, 57.89235199651411, 61.1139319019933, 65.16898801249843, 54.374899864196784, 74.7128677368164, 80.72069937183012, 19.019943629541707, 0.43496382452787896, 0.2489015682330055, 0.159435338310657, 0.15322184430495386, 0.2377144015964962, 0.16974367952394873, 0.1524043365591957], [0.021398590066500252, 0.06192880877924543, 0.059575072579806855, 0.10612545534968378, 0.11042928368213678, 0.05191405544117574, 0.03146888477908027, 0.12960738322186854, 0.058295219280426545, 0.10569920402861412, 17.453296030721358, 70.05790864267658, 44.67429399490357, 49.0677761262463, 28.96799418234056, 46.61376876215781, 21.77738751134565, 6.27630659649449, 28.51182841485547, 66.56895252966112, 54.906910542518865, 67.75696000745221, 12.409153484529066, 0.3804136758610126, 45.3109025186108, 72.43335093221357, 68.53218509304908, 64.6966326621271, 65.97695704429381, 65.08718698255478, 59.83087362781648, 52.06799707105083, 61.359589945885446, 61.50042656929263, 64.41179798495385, 59.23544999091857, 64.47095517189273, 61.706331391488355, 62.03838748316612, 59.98482273470972, 58.60506234630462, 53.36512880940592, 49.54261041456654, 47.57437682920887, 49.28133741501839, 54.12073812177105, 59.61266040802003, 62.327517155678045, 59.0328791833693, 55.408703281033425, 60.28875935462214, 61.766210294538936, 53.97063686001686, 47.6090427367918, 51.70761362198861, 51.622184399635564, 51.39260022870956, 50.42731277404293, 53.0178499990894, 53.04161563996346, 49.620543987520286, 50.51053370198896, 48.75284510274088, 55.29653526121571, 56.72394852484427, 57.45782006171442, 57.42646463455693, 57.790629248465265, 54.260994234392726, 60.015491747087054, 55.859183572953754, 55.829550066301906, 50.13591204920123, 54.31592702865601, 42.7128617994247, 35.35348338465537, 42.64372610276745, 42.30027552573912, 42.440068798680464, 44.844391499796224, 47.48429959820163, 50.83894591177664, 47.300089405428984, 46.823988191543094, 48.5203819121084, 52.72598251219719, 53.4623408317566, 56.52923030237998, 51.48599970725275, 51.40378290607084, 53.253011780400435, 57.330464624589496, 54.895021838526574, 55.28765501514558, 52.34574794769288, 51.920963102771395, 47.641300309088926, 46.29969281534995, 42.73158719462734, 43.930216450845045, 44.21848712428924, 40.26548324092742, 41.82490387270528, 47.858823191735056, 48.033451034176736, 55.67944095980737, 51.047710141827984, 50.60075998306275, 60.59183305309665, 58.55140039997717, 56.561044646847634, 55.502138060908166, 55.653125778321304, 54.84977729858891, 56.96815529177266, 54.506613054583156, 51.73605865047824, 52.67162630634924, 51.5945513017716, 52.222224666226296, 53.81921768188477, 48.48105230639058, 50.835247116704146, 51.687578155148415, 46.925644259299006, 51.27387400596373, 58.04305338090467, 57.42432302044284, 59.55070657114829, 51.33615339955976, 58.85185395517657, 61.27964027466313, 60.16622451043899, 52.939288846908084, 47.711455821990974, 44.72852076253584, 49.482523625896825, 59.15127984939083, 61.62928035182338, 61.812961024622766, 62.712180076106904, 61.523572475679465, 62.396386131163574, 62.711426981033824, 64.32880063210764, 60.32636311746413, 65.4104922663781, 66.92043612080236, 63.45023678195093, 64.44503614979406, 62.506722404110825, 68.96213962185767, 68.80123615264893, 65.29567664669406, 16.755118062419278, 1.0712227057064734, 11.860927727914627, 68.13741422468617, 58.887163131467766, 36.21682451617333, 12.324791146862893, 47.34224704004104, 33.751846282712876, 36.21440833614719, 42.73253248583886, 34.05372365828484, 32.74852752685547, 67.31894108556932, 19.681874975081413, 0.34483624622225767, 0.08299153823886188, 0.00551508228865362, 0.04680578882295278, 0.04470853503012369, 0.022132477400103406, 0.023028966895635092, 0.07061442255132622, 0.04646317898145607, 0.07127423109787126, 0.05139929415177434, 0.024392869616408023, 0.01493335286560919, 0.072140124956927, 0.07412701995382387, 0.044542148393849214, 0.18670075993624427, 21.9961400570408, 80.08446739565942, 53.4341742915492, 54.67215276533558, 29.631910247187463, 50.5826739341982, 38.63965688213226, 15.634302746865059, 32.78287376126936, 77.71018612769343, 60.74556642963041, 78.36897957709529, 17.82073974609375, 0.2081116763574462, 40.49758949587422, 77.42821478074598, 71.1388667937248, 70.09524960671702, 69.25260682259837, 70.17481096329229, 66.13833119792324, 55.93971767733174, 64.56640605003604, 63.80670962795135, 66.70862028675695, 62.524659402908824, 64.86651051429011, 64.70811736199164, 63.78060625445459, 62.45208378761046, 59.80366414593112, 54.648634233782374, 54.24342201602075, 50.32975558311709, 51.2349719385947, 57.25414314577657, 60.91165919457713, 63.25972334031136, 60.480147484810125, 56.068485167718705, 61.0704053601911, 63.64247998883648, 55.09209740546442, 49.92104461116176, 56.33340204915693, 54.170250200456195, 54.357355102416015, 52.38231228243921, 56.36599694528888, 55.70892541639267, 54.34159109669348, 54.34948682785035, 51.94650165496334, 57.397003712192664, 57.33394768930251, 57.93574125536027, 58.726459703137806, 59.22773468878962, 57.46432335146012, 60.967046983780406, 57.04848543290169, 55.53431718580185, 52.80752466570947, 53.84667427309098, 45.91166450131325, 39.28563987055133, 41.58973816902407, 43.66944551467896, 43.92557236456102, 46.54003604765862, 49.080798395218395, 49.9533845532325, 46.709462827251805, 47.284541130065925, 48.732456622585175, 51.6203369632844, 53.00924039656117, 58.342781297622196, 53.481889924695416, 50.685012494364095, 51.67880773544312, 55.40911905227169, 52.8812809144297, 55.66201386913177, 51.666946488042036, 52.22340922201834, 46.300234102433734, 45.289078450972035, 42.494676036219445, 45.603601547979544, 43.02516483491467, 40.2407056285489, 43.1548580046623, 46.620303430864894, 49.99966459889566, 57.08492817417268, 51.919523592918154, 52.70548420567667, 61.40445793828657, 57.047591132502404, 57.63800982506045, 56.55276452341388, 59.25686613205941, 57.819654787740404, 56.85745816076956, 54.497058160843395, 52.750273750674346, 53.19595306150375, 53.58942170296946, 55.438403467978205, 56.59790315935689, 50.2744972321295, 54.08295392990113, 55.60587298485541, 49.041915939700225, 53.610320091247566, 59.65934445781093, 61.985819878116736, 62.560211766150694, 57.550909673014, 60.04290519222137, 64.76181853202083, 62.50767161769252, 57.75794413781936, 50.86503359579271, 49.23625761462797, 53.05742671412807, 63.05420291039252, 65.05906751078945, 66.71350755999165, 66.27778714702976, 64.60326064017512, 66.1687687904604, 66.50589650677097, 67.28466741500363, 62.68153067558043, 67.24725584830007, 70.56334526308122, 66.7217053136518, 68.4007150896134, 68.16449426835584, 73.15233707427979, 73.95618761739424, 68.98127294355824, 14.620179822368009, 0.7574434494299274, 16.66096744998809, 78.17402209005049, 62.10091398608301, 45.87154257682062, 11.737505447479988, 46.19045872842112, 48.296002726401056, 47.712542318528705, 44.85908469846172, 37.19931548641574, 40.80779406332201, 78.66632661511822, 32.82958722883655, 0.26937560508808783, 0.08815953673254098, 0.045098117552697665, 0.1541406288743019, 0.025794686028553594, 0.050895192975839304, 0.06423189124513058, 0.1929499536392189, 0.11857104397589162, 0.18845128616498363, 0.1632095624001757, 0.2228571988281704, 0.19024635274564067, 0.13183020265592685, 0.18382929385669772, 0.24362236441623783, 0.3017066298953949, 26.586230993270878, 95.34916324000206, 58.50699524725638, 69.62311390907534, 36.99064539324853, 66.31985064475768, 31.795301360468713, 14.012159493661697, 43.72363305860951, 81.43680649418985, 66.36801735047372, 84.23344073757049, 16.68203842255377, 0.4764250852167607, 54.447071475367395, 78.2953723784416, 73.9433143984887, 71.8712439075593, 73.3208970100649, 70.13696793586978, 66.23457831721153, 56.639142959348625, 66.49741634245842, 68.01096485507104, 70.80331587022351, 63.99119046426589, 69.7114299958752, 64.87525739977437, 68.19373946036062, 67.21837151435115, 63.10964169040803, 57.57183944025348, 57.95483143098893, 53.70063266446514, 54.46921717736029, 59.955675601959236, 65.53004218686011, 63.92289415482552, 64.55317589544481, 59.54875323080248, 62.91668461215112, 67.09396962196597, 58.40897129428003, 52.120301877298665, 59.28244783032326, 55.53013593919816, 56.865028335202126, 56.12173918754824, 58.19380183373728, 57.78265114753478, 56.95203435036444, 57.10571281371578, 54.027770103946814, 60.43966862463183, 61.01291518057547, 60.10263896757557, 61.09388466804259, 63.156094320358775, 58.22431002893756, 63.48922514146375, 62.174176016161525, 59.96904696187666, 54.2569738049661, 56.96601760002875, 48.60495998013405, 42.76146388822987, 46.467766377233694, 46.69424010861305, 47.92285196242794, 49.39275233976303, 52.5966815794668, 50.595009788390136, 49.01119201414047, 49.21448061543126, 51.292771985453946, 55.83959917868338, 55.927609320609804, 60.49444844645839, 57.648133462475194, 53.817272186279304, 53.350568971326275, 57.82062753554314, 55.01410499695809, 60.09315859886908, 53.5207566907329, 54.819445610046394, 48.870092591931744, 46.30612158006238, 45.08076921586068, 49.352877524591264, 46.87410823760494, 45.17655349546864, 44.7481639923588, 50.31325417180216, 50.61420194564327, 58.91441575942501, 54.314797386046386, 57.950940439777995, 64.92356531081661, 60.97999472771922, 60.66390660501296, 58.79557578794418, 59.12580013275147, 60.35726747205181, 60.857369669022106, 57.752758764451556, 54.82177549792875, 56.27946945928759, 56.42325570506435, 57.014804040232015, 59.65378645927676, 54.07270085427069, 57.980460197694846, 59.368316358135594, 52.09434755386845, 58.32624850734588, 63.2154986166185, 63.47726583480836, 66.86316167154621, 58.58946308012932, 64.37319794008809, 67.94570446014404, 65.06124834860525, 59.375337400744044, 54.19553772095711, 52.28958352919548, 55.05270111945368, 66.5574364508352, 66.43444661171206, 69.42110400046073, 70.41895497229793, 68.99944920693675, 67.38307968262704, 69.31897332591396, 74.63881338796308, 67.04471249734202, 69.45127487182617, 75.00757894208355, 70.73590601644209, 75.36453816198534, 72.50222775243944, 77.99450305200394, 75.79009963620094, 73.78493693567091, 24.816708603212913, 1.0616968620208003, 16.746343720343805, 85.65621775965538, 70.4954255011774, 54.57004954738002, 21.856793934299102, 61.32008775588005, 45.94563614937567, 47.35639895162275, 58.60279521634502, 49.47899349274174, 52.749599103004705, 86.45270209158622, 45.631571969678326, 0.3281641505177944, 0.2826588955377379, 0.11319644689079254, 0.2655623871232233, 0.17422572289022709, 0.18350032038025318, 0.11694739722917158], [0.10284525071901661, 0.0475974066273099, 0.0143140014223454, 0.07998113445336781, 0.07091821471769964, 0.009239556628369517, 0.017518565404198824, 0.07899462771151336, 0.08014342251924739, 0.18610558622787077, 14.301425468537117, 66.73147986012121, 45.1369297119879, 49.95642439011605, 31.008622953968665, 40.93253327954201, 36.876653471300685, 12.507304914536016, 23.955120771161972, 66.66367776932256, 61.51379400683988, 58.25823068618775, 57.49939718554097, 2.2891717187819944, 6.3350945903408915, 62.977563719595636, 66.34081179095854, 69.66838590560421, 62.65310918131183, 65.12426514779368, 53.608202011354514, 59.46148441683862, 60.68770754721857, 64.69831535893103, 60.49595071423439, 63.86142669185516, 61.472550284477975, 62.86288538286763, 58.80466391963344, 58.25092331055672, 53.32945093031853, 50.65026029463738, 47.47010846291819, 46.98819429643693, 51.26747662021268, 56.06115033549648, 60.5174570698892, 62.36446980507144, 55.315366560413, 54.46687944473759, 58.45720075791883, 59.952259217539144, 54.14231900245913, 47.45079471218971, 49.74691883210213, 51.30344083232265, 54.01814460754395, 52.55410032887613, 52.35698553823656, 54.912190052770804, 55.36163876133581, 55.646528351691465, 52.82384564799648, 52.222150141193026, 54.76179461325369, 54.50986862182618, 58.1626582145691, 55.17027808773903, 55.61223899164508, 53.331576854951926, 53.660385224127005, 55.794378172966745, 47.5414602987228, 46.44235334088726, 40.311641693115234, 47.04676312784995, 47.672251732118674, 39.66247374011625, 41.48474416425152, 42.6293388489754, 43.457272744947865, 42.080477668393044, 46.35928538537795, 45.35644515868157, 51.54569033653506, 58.506497106244495, 58.11986515598913, 60.49172239918863, 57.183293373354026, 47.942048042051255, 56.723544520716516, 59.39903636132518, 59.20356896615798, 61.412522331360854, 54.58993988652384, 49.21098186123756, 48.78013695439985, 42.39882115394839, 41.48603854640838, 42.37135279563166, 40.764345968923266, 42.31180729404573, 43.996892821404245, 44.01024849184098, 48.15212626611033, 52.993115532782774, 53.94509830782491, 48.28447880283479, 50.56054784405617, 57.258387150303015, 55.231918134996974, 56.32534157845282, 55.39478278929188, 55.10623362756545, 56.475838999594416, 51.9624186331226, 52.87408728753367, 53.83691149373209, 53.258055948442035, 55.02497780707575, 49.152040404658166, 48.98284112253497, 49.7640674344955, 51.54488232827956, 47.24767085044615, 48.53960152595274, 55.55093234585178, 57.774676968974454, 57.76946806138562, 52.16587981870098, 55.689368478713504, 61.12902518241637, 60.358754050347116, 55.337653467732096, 50.08226971472464, 49.8425893629751, 46.55990677495157, 49.78514232943135, 57.70378012810984, 60.64034100501769, 61.33487116905951, 61.897072330597915, 65.24137927639869, 63.119224040739006, 62.78107258581347, 62.51918769651844, 63.15665521929341, 63.51799180430751, 66.21837108365952, 61.40685842883203, 67.43345860512026, 66.23751225010042, 70.44266962235974, 45.374950901154556, 1.2311197192438188, 0.1190799868275081, 27.054024627131803, 68.33236386699062, 58.95213719337218, 36.04111017719392, 16.524519958803733, 28.3768557348559, 18.984022563503636, 45.342720785448634, 33.699270832923155, 29.30598285890395, 69.54639234850484, 56.97086564956173, 39.864562096134314, 0.8120028830824361, 0.13148195440730742, 0.06529389595192286, 0.062247152785740556, 0.056082259397953756, 0.06739338289105123, 0.08993168196250355, 0.08217829760284194, 0.01777197579823194, 0.01630876318461472, 0.04810234283908241, 0.05169070250685177, 0.03344819167508714, 0.05712019745260478, 0.05266993524386518, 0.09086613302990314, 0.28797346197309037, 17.138990625258415, 82.14462957074566, 48.292653022273896, 54.460705634086366, 32.877814731290265, 49.805048358055856, 38.42519344822053, 25.0433196175483, 33.601160587803015, 71.66673152677475, 71.23733397453063, 61.49806922481906, 67.9636061576105, 3.353983678164021, 3.3366068428562534, 61.12409084073959, 72.61636872445384, 75.69001643888413, 65.97556068051246, 69.00032781785535, 57.16674097122685, 61.917127409288966, 63.69020346672305, 68.80146365011893, 64.74344615013369, 65.95528202672159, 64.29163617472496, 64.38967973955216, 61.25890270356209, 59.86117785976779, 56.78675743841357, 55.77301302263814, 49.59474655889696, 51.04863974355882, 53.69640042704921, 57.38524444641606, 61.35586761659192, 64.34932247284921, 58.30626010894776, 58.59106340715962, 60.67276723923222, 62.20208760230773, 55.87728923366916, 49.905100176411295, 52.029557843362134, 53.04735014515539, 54.01114709915654, 53.42905167610415, 52.8155537574522, 57.70129726779077, 56.464283697066776, 56.35977214382541, 55.09779268695463, 54.959733101629446, 57.23226024258522, 56.79176630512361, 59.30585653551164, 58.933592227197465, 55.697515241561405, 56.21009842042, 56.65369887505808, 56.83935250005415, 46.687477942435976, 46.49239493954567, 42.96554873066564, 46.95374804158365, 48.08450068196943, 40.72144308397847, 44.40609801200129, 45.51324975106024, 44.896625703380955, 41.883045165769516, 44.79356934947353, 45.902847013165875, 51.61863857699979, 55.21470677468085, 56.06618665879773, 59.42185671098771, 56.133988749596384, 46.230188415896514, 56.919921905763694, 58.32466386979627, 57.3077658684023, 58.7549674895502, 53.23047384139031, 48.89862391256517, 47.245803802244126, 44.67616888784593, 42.314486272873424, 42.97830035609584, 42.773152551343365, 43.74007171200168, 45.665837795503684, 44.43719064035724, 47.584006247981904, 54.457603039280066, 55.25548765736242, 50.065160336032996, 54.65589454097133, 59.15183682595531, 59.16746354872181, 59.540782974612334, 57.518126503113784, 57.958730266940215, 59.10286211198377, 55.03259504995039, 52.64263606840565, 56.720336021915564, 54.22504178939327, 55.84776555338214, 52.24158940776702, 52.25289760097381, 52.538673646988414, 53.42447819248323, 50.72260449009557, 53.50132919126942, 58.532580867890395, 61.06001500160464, 63.04126693356422, 57.03760085567352, 60.07074617570447, 64.08355835945376, 64.12043648381388, 60.838616817228264, 53.964498350697184, 52.79876601311469, 49.61000457886727, 51.47218904187603, 60.512181482007435, 63.625758924791896, 64.0785377256332, 66.6636856140629, 68.80096158673688, 65.63194928630706, 66.44353082103115, 66.57758174404022, 66.16707432654597, 68.26913525981288, 69.05025174540859, 65.28971464403214, 71.16836301742062, 69.08144243301885, 75.78893861462994, 41.00378313372212, 0.36160983325492957, 0.14371032646346477, 33.978210187727406, 75.53489454330938, 63.14706110185193, 43.513056693538545, 18.567323684692383, 31.46196657611478, 19.572348671574748, 56.17286336037421, 37.117263424781065, 33.794400076712336, 87.40634010684106, 56.13229820805212, 63.50402816649407, 1.4216693202334068, 0.07290372309545357, 0.008326044659160318, 0.03322476979284998, 0.048807660838769334, 0.04923678498955504, 0.02093291394562731, 0.19593725221291666, 0.18387291490310625, 0.09978702772528895, 0.17246942035853866, 0.3168438531218037, 0.15738819815939473, 0.15552035322593105, 0.2552532951437658, 0.2524687494001081, 0.5031499092377002, 21.892493386422437, 94.80746822972452, 59.82789262648552, 70.26573934862691, 39.506912539082194, 58.76285537596672, 52.325198650360115, 20.557826526703376, 41.66357286514775, 78.32111097151234, 76.6838195247035, 68.83832608499836, 75.24158754656392, 2.3946143446430086, 7.80251112676436, 74.38482422982493, 72.45895616469845, 78.6104485296434, 65.73576265765776, 73.08536652595767, 59.93402411860805, 65.9586944887715, 65.27588828917473, 71.16521727654242, 66.73228002363636, 69.88419471248504, 66.2632743773922, 68.51808809464978, 64.39816382623488, 62.678428080774125, 59.11167175539079, 58.53655030650478, 51.442296658792806, 52.38015890121461, 55.26051613592333, 61.38582667996807, 64.33137762931086, 66.97736540148335, 59.95177676600795, 58.80154955771662, 64.86391390523603, 64.7511810641135, 59.44256682549754, 52.4529424021321, 54.84479588847007, 55.53240699152793, 58.68705949475689, 57.75451598628875, 57.479616672761985, 59.199462244587565, 59.19873660610568, 62.069205545610004, 57.3744422389615, 57.46584915345716, 60.4095212874874, 59.7677509246334, 61.01927726499496, 60.31255637445758, 59.083971977233894, 59.64100345488518, 58.125889916573804, 58.354320910669145, 49.82887675685268, 47.88192202967983, 44.25799323666481, 47.19961789346511, 48.73128775627383, 44.9105618846032, 45.33111841447892, 47.11117236844955, 47.66705851401053, 44.47105246205484, 46.2957194543654, 46.67998621540685, 56.03845550167946, 60.19502255224413, 59.36114234309043, 63.99843115960399, 60.57967370556247, 47.29972462500296, 57.107454346072295, 60.58415305229926, 61.07778333848523, 62.60273810355895, 54.69785997944494, 50.378369439032774, 50.830042131485484, 46.611423184794766, 44.89625700058476, 45.04402052971625, 45.87287226030904, 44.327732978328584, 47.34658910382179, 44.41839072012132, 48.064414224317, 56.925358310822524, 56.86876243160617, 58.087897839084754, 59.08713340759278, 62.007745927379986, 60.22009434238557, 61.068816800271314, 60.293878047697014, 60.33740066712903, 59.71084125580327, 55.962188936048946, 58.068340901405584, 59.206487209566184, 55.228458604504986, 58.112730364645685, 54.06214575613699, 55.9673664646764, 55.956776065211145, 57.11069422383463, 53.42515284015287, 56.96731590455579, 63.14253468667308, 62.9804309721916, 67.35207726878505, 58.52498715923679, 62.815432548522956, 66.0651554599885, 69.07016954114361, 61.98148173670616, 54.655212048561346, 55.57896160310315, 51.91743689198648, 54.017587630979484, 65.44892364932646, 68.1562259120326, 67.98514781459686, 69.94095140887846, 73.7821912765503, 68.62269770714545, 68.20149790856146, 68.55710783312398, 69.2659507259246, 71.83088271848618, 74.20885101441415, 71.50213318486368, 76.03546742470034, 75.13520502275037, 78.69581499407369, 53.66485280375327, 3.3900052549377566, 0.29115330908567677, 34.82304165440221, 84.01665918288693, 72.82506235184209, 49.00833260628485, 30.332221984863285, 37.06585291893252, 28.435071552953413, 59.50382640284877, 50.96425779404179, 40.40281326540055, 83.33695165572628, 69.99808465280842, 72.09251265372001, 2.4159505674915933, 0.23417214893044966, 0.15477049104388685, 0.19608812556872446, 0.18986055086697304, 0.15835613492996464, 0.17343064619889184], [0.1349008822393033, 0.06557911814701173, 0.03736994897706374, 0.053424608458073876, 0.0938114423244711, 0.051464748704024864, 0.043270193460968234, 0.16298142141632496, 0.2979588971262978, 0.7691643495232828, 21.80479507292471, 73.66876417590727, 48.430269379769605, 45.67586729603429, 33.3023505057058, 44.5785254047763, 45.0299588326485, 21.412703183389482, 7.657659467189544, 51.401609912995376, 66.86032187554144, 55.54523706436158, 63.1215343167705, 28.630566404711818, 0.56655480856857, 22.627912298325572, 62.466561255916474, 71.74007200425672, 64.50415803540137, 65.06146015659456, 56.211824263295824, 60.290026280187796, 60.38274718869118, 65.30858908930134, 60.697670367456254, 61.1333986251585, 59.25981183205882, 65.24465445549258, 56.89275556995023, 60.467862621430434, 55.4961407569147, 48.445013569247344, 45.876045457778446, 48.11400475040559, 50.43341598203106, 58.20712220284247, 59.293791324861594, 64.98941406126946, 58.88248374385219, 62.57462255416378, 60.3452257956228, 60.09431569806991, 57.47151305598598, 49.209911054180516, 47.380348943894916, 50.42466517417662, 51.424967627371515, 54.10402490246681, 48.32650307686099, 49.89938528307023, 54.745532466519265, 54.82255212722286, 54.072944041221376, 55.86204298080937, 55.07130884355115, 55.552234572748986, 56.10743430352981, 58.05276124708114, 51.7877084209073, 49.326883977459325, 49.0779782110645, 50.17422183867424, 53.953107787716775, 43.74335081346574, 34.940057723752915, 47.36374947332567, 44.8655487645057, 49.80482086058586, 42.91205936862577, 38.857324892474765, 42.48634492197345, 45.25743669079196, 46.62810502513763, 47.510391204587876, 52.86539531523182, 56.497678756713874, 60.93523263931275, 63.51058636942218, 58.52557943713281, 46.68144141474078, 59.9449832208695, 63.419701130159446, 61.5261180939213, 59.649067847959465, 54.48656582063245, 51.832199865771884, 44.002042893440496, 43.41411490594187, 42.11382958196825, 40.376870709080855, 44.16799837543119, 43.15324591052148, 42.96875330709642, 51.92343027360978, 50.993793241439334, 47.115412450605824, 50.61976778891779, 51.632610059553585, 47.49885943628127, 49.17246810851559, 53.5161792847418, 58.88519802401143, 56.21210275157806, 55.209972473882864, 56.82877386769941, 55.353864623654275, 53.03908571120232, 52.67734904443064, 55.13034443701468, 50.717779974783625, 47.483864215112504, 47.6257755679469, 52.78517892283779, 49.69326080814485, 48.439769360326956, 49.509835089406664, 57.35311631233462, 58.82889240018783, 60.364461098947835, 53.024325832243896, 54.90021505663472, 57.87252049292288, 62.2962676325152, 57.19093022807952, 54.77557782203921, 52.20726082401892, 47.95556845203523, 47.35979964656215, 47.846467725692264, 50.45305528948384, 54.82823171923238, 56.760681521508005, 60.02949460860222, 59.8053389979947, 64.64085655827677, 60.49400521862892, 63.6009067873801, 65.18330466362738, 64.14129957076042, 59.674665235704, 63.292784998493815, 63.1708541993172, 64.23630722107427, 12.02317068653722, 0.1615054764214062, 0.24005031092993676, 29.959896879811442, 67.70691056405344, 57.829425411839644, 33.34439439158286, 12.538907451014365, 56.910594509493926, 80.92201109855407, 32.16902675167207, 42.81996211697979, 30.05914265109647, 56.41683478509226, 50.82285242695963, 70.63195536213537, 9.002031741603728, 0.3726225003840462, 0.04895335544020899, 0.029584262520074848, 0.20855504208274428, 0.10214323838872295, 0.06462641120437654, 0.07993686223222364, 0.052932381644965186, 0.11295934267822774, 0.04036675087146221, 0.02316580743588988, 0.06215377815908963, 0.07720078687153517, 0.08195038644536849, 0.13764122470973, 0.35033228356511364, 24.033040615820116, 90.26377108789261, 50.69632853231123, 56.084425680099, 38.90456199645996, 55.43849760486234, 41.092385553544574, 22.389514561622374, 21.810698240034043, 50.252696698711766, 76.01604384760704, 61.10964475139495, 73.16243325510334, 35.67483532813288, 0.41924544700211097, 17.175264704611994, 60.93836269071026, 74.74690606517177, 68.47593046003773, 66.95489022039598, 62.16833952934512, 61.841861048052394, 65.26715317080098, 66.27835981307491, 64.50458557375016, 61.907878460422644, 61.533986368486964, 66.49891468786424, 61.331313579313225, 61.6656054219892, 56.03834959768481, 48.627450850702104, 48.676919783315356, 51.496931352923, 54.184778659574455, 61.11466146284535, 61.55950138645788, 64.65916225987097, 60.94896485728603, 62.362065392155806, 63.17131311662736, 61.80317471104284, 59.72700142091321, 50.54190874099732, 49.73210011759112, 52.08258828809185, 56.026111802747174, 55.99332863284696, 51.5951318125571, 51.26008687480804, 59.014640162068034, 56.51381538760278, 56.533321334469704, 57.840957180146255, 55.692882922387895, 56.38089018483316, 58.68555330461072, 54.87140524771906, 52.42066129561394, 53.52754239113101, 48.09450272590884, 49.895247182538434, 52.36140604942076, 43.752580150481194, 38.392437734911525, 47.7049760664663, 47.66959236514184, 50.26707218539331, 44.48337654913626, 40.3898419872407, 45.03300259190221, 44.89267979898761, 47.66976494942942, 47.266662966820505, 52.27423529471121, 57.385899482234834, 58.30009414303688, 60.00057497332173, 58.131789161312966, 47.34389835788358, 59.31999275761267, 62.91070299763834, 60.63978795082339, 59.27304983139039, 53.547138552511896, 49.919095193186116, 45.04851556593373, 43.96496080583142, 44.630661549106726, 41.79694129574684, 43.83055294713667, 43.45401325533467, 43.37294963098342, 51.02136358138054, 51.43838213336084, 48.837301577291186, 51.108126409592174, 54.449707308123195, 55.03631737924392, 54.14000480405746, 56.179641216031975, 58.9435903487667, 59.03515023569907, 55.66592839456374, 58.27885843092396, 55.96768809903053, 56.96722569004182, 54.17480799459643, 55.84228992462159, 52.183769749056914, 49.43866760500016, 51.27252078825428, 52.8208097334831, 50.39304694821758, 50.7981611067249, 51.22757827081988, 59.177104734605365, 60.535825529406154, 63.061055291083555, 59.41348245066982, 58.61611950782038, 60.7221616468122, 64.87062508060087, 61.73541576631608, 60.13752060551798, 55.172921765235166, 50.860224769961455, 48.411673422782656, 50.988568644369806, 52.496723897995494, 59.772869617708274, 61.11541063554826, 63.2404919593565, 64.0691436490705, 67.11351871490479, 61.529903181137584, 65.41708577063777, 68.14826350058279, 68.12828294692501, 65.52589624158799, 69.15519083699873, 67.20465106348838, 64.8106324288153, 9.597985879067453, 0.10050222442875947, 0.2288391657413975, 39.879482792269805, 69.62400036473429, 68.62705938277706, 36.8296830884872, 18.709380165223156, 61.30990920528289, 55.80806724486813, 41.234634230213786, 54.945239943842736, 25.961895565832815, 69.59960322226249, 58.03834261432771, 84.06233910591372, 13.662284074291108, 0.5047526571058458, 0.21145580336451533, 0.09976712476101615, 0.07849401223563379, 0.15098252333700657, 0.09274599788289878, 0.4070550882287564, 0.22021077873726047, 0.29511180796450187, 0.15588154836047083, 0.20472637978532623, 0.1706559523459404, 0.28213201090693474, 0.28486032579695025, 0.6276120774207578, 0.8624348801470573, 29.55618496864073, 98.35927640238117, 62.626280169333185, 65.18209657361432, 43.187194024362874, 61.573437567680116, 65.72713736564883, 30.9349569197624, 17.1420677246586, 65.75536666377899, 76.95088586499615, 70.18255372201243, 78.16576942320793, 38.58306100291591, 0.7455892500377471, 30.359886461688628, 64.66017030900525, 78.67717589101484, 69.67521082970404, 72.17872635010751, 62.985463373122684, 66.68820042763987, 65.5792247864508, 71.34246133988904, 67.60520350548529, 66.06885817743117, 63.76598365845219, 70.61344177492204, 61.906003567480276, 66.43658822582614, 60.224028479668405, 53.191897330745576, 51.25125761955015, 54.11195201258506, 56.4440481893478, 63.35147934575235, 63.61743173291607, 69.23901188758113, 62.6501242576107, 65.39979204054802, 64.47362630598008, 64.24538750802317, 61.98421562871626, 54.46439266204835, 51.83179586164413, 56.01292087185768, 57.7746142110517, 59.191335093590524, 53.19746709639027, 52.97559430522304, 60.290955881918634, 58.84258539445939, 56.982067938773866, 60.73408172976587, 58.97470651134368, 60.49099283833658, 60.90121784517842, 62.45689653581189, 56.72256000580327, 55.33799863630726, 50.48281431198121, 53.20079718866656, 50.933569169813595, 48.459310608525435, 46.34045800855083, 55.160621212374785, 51.75095189002253, 50.8810172542449, 46.398556155543176, 43.10841714182208, 47.666991833717596, 48.76744416452224, 50.910234989658484, 49.460534818710826, 53.55543828779652, 58.12647042735931, 61.74620228428995, 65.11582812955304, 59.760729882024954, 49.25726582927089, 60.94866283478276, 67.36830019181775, 64.30177550162038, 61.892918540585434, 56.64380273511333, 52.12447527916201, 46.328455555823545, 49.80781362902734, 46.27689992227862, 46.031100673060266, 48.24704762428038, 46.70016288757325, 45.813793520773615, 52.297153703628055, 53.45802230219687, 51.38313947185394, 53.18955959812288, 53.490268107383486, 52.38159841106784, 57.431697076366795, 61.86071588147072, 63.99898029142811, 58.81817648487707, 59.08179113941809, 61.38580314574703, 57.307150056285245, 56.530536451647365, 56.50446837948215, 58.83124582229122, 54.55417571529266, 50.75701152124713, 51.95969650822302, 56.60653629610616, 53.345254159742794, 52.90628602427822, 53.62794330043178, 61.08520838522143, 63.09495241411271, 67.22514152526855, 59.17257439705634, 61.50960883786602, 63.85957141076366, 68.5803988672072, 63.88361553991995, 63.03384188682803, 58.78664062869165, 55.08750430999264, 52.52713403394146, 54.99839198204779, 54.60904575163319, 63.673074476180545, 63.754981410118845, 67.89210919410952, 66.81082940870716, 71.29708736173569, 65.2675767867796, 69.62526336792978, 72.5006901833319, 72.66482568556263, 70.81796200044694, 77.30275384841427, 71.22275060222995, 75.2649413385699, 15.52501472734636, 0.2924681917553948, 0.5904496425101834, 41.671386226531, 81.67349015512775, 70.38677584740424, 48.505841685879616, 26.323926410367413, 70.06690655985187, 96.12480409683721, 46.63229411648166, 59.69176284728512, 40.68143883059102, 70.52553361462009, 67.55615818885066, 96.28370715725808, 17.944347358519032, 0.7562262889358305, 0.4597418352721199, 0.12252256379372652, 0.2581414466183032, 0.32232898137261795, 0.19562404482595383], [0.0883645878263539, 0.08522276165744952, 0.041232679204474536, 0.051049234105214, 0.2267473166988742, 0.24537380995048633, 0.3851519296726873, 0.07224342425263698, 0.17051896050332055, 0.29812066425238887, 25.251177780089844, 80.66227959048364, 44.8477529710339, 50.92797586994787, 28.975015224949008, 47.45360705160326, 27.04082585150196, 67.77752891663583, 5.018326976606923, 10.531309939199879, 48.6014102351281, 68.926955961412, 51.26974375017228, 58.98685016939717, 5.726948745789067, 1.4499356357320663, 32.63551815863579, 54.477038383483894, 63.71733057883478, 62.660169447621996, 63.833048343658454, 58.11480529846684, 67.46272733134609, 64.25060033798218, 61.68730005141228, 57.681752097222116, 57.595675683790645, 59.86660642008628, 58.20835382707658, 56.51906744126351, 52.31661650442308, 48.794822308325, 50.59926163765692, 56.244379935726045, 60.90387328978508, 60.753434704196074, 64.65738150381273, 64.83642201269826, 63.85025970397457, 59.49333014026765, 62.58344004231115, 64.14928943880143, 55.838893152052364, 50.60283099451373, 49.634056552763916, 53.82125731437437, 51.1499624098501, 44.361210407749304, 48.36709960814446, 50.086215619117986, 57.33473608570715, 60.405481246209916, 61.147597605182284, 56.446640876031694, 54.17905199912287, 54.5514496680229, 48.567670006905836, 46.64157444430936, 48.808083841877604, 48.38813527937859, 48.91333280071136, 47.32577700768748, 36.55350900465442, 25.75023270422413, 21.87088897151332, 32.36468634297771, 37.59962474146197, 32.138373428775424, 51.63990959044426, 43.3765229102104, 43.899194425152196, 41.095276340361565, 43.281805515289314, 47.407648640294234, 55.73086715513661, 61.12614616270989, 61.66168305181689, 64.11769082469326, 54.863854685137355, 44.10821753163492, 57.80398884127217, 61.284982542837824, 60.01307948943108, 57.29859536693942, 55.44806818808279, 42.767249384234034, 41.988196065348966, 40.79794499181932, 44.400857725451075, 46.03159096933181, 46.582225061232045, 47.5059824605142, 52.71251701539563, 54.16555512335993, 50.719650945355816, 33.938849203048214, 33.86872506910755, 39.58410478407337, 50.25884697514196, 53.26711270116991, 48.717033863067634, 48.82804478368452, 54.35159314063288, 57.77473580452704, 59.22557346282467, 57.624685533585094, 50.02678386626705, 52.13501468781502, 53.54372609046198, 49.212692014632694, 51.94552890716061, 48.285075003100985, 48.61638192207583, 48.806867907124186, 47.283258515019575, 47.77763797390846, 52.49156205884872, 56.517145479879076, 60.703820643886445, 56.775586528162805, 58.971572537576, 59.10467424700337, 82.02074543122323, 85.63086355886152, 54.701939244424146, 56.28259166594475, 42.98918101095384, 44.38010446486935, 44.01129576467699, 47.01679621973346, 48.39367758843207, 58.28975085289248, 60.59617903924758, 66.22867122773202, 63.78891775684973, 62.82797236596385, 57.84238884525915, 60.71305390327208, 61.66367953823459, 63.669281544223914, 62.87777077767157, 61.042144683099565, 26.12956120121864, 0.5002313287508103, 0.12060283938603056, 2.1573656172521654, 55.051532253142334, 64.66207265853882, 51.326218035913286, 18.122064067471413, 10.130910469639687, 63.13034003780734, 95.80802563698062, 26.030335041784472, 37.127018359399614, 39.64502311521961, 36.67757749557495, 49.38368774229481, 66.11022349326842, 10.412360141354224, 0.5560128871471651, 0.10975878820904802, 0.24128138358073853, 0.10893340507942824, 0.13440776676420244, 0.08519505991810754, 0.0887193478223297, 0.11611675873639123, 0.03995138182935696, 0.060542132179703445, 0.04684975077848762, 0.06850824766461888, 0.27156624882932634, 0.13622933998703957, 0.42061557993292814, 0.22865962537546314, 29.13021949029738, 91.54786879016508, 52.692814950020086, 61.29343917292934, 35.35995137306952, 55.05952996592368, 37.19841334127611, 49.810331790677964, 9.448130746041576, 12.644577084049104, 49.635703948236284, 77.7634205356721, 56.30179559030841, 71.19187370423349, 7.987395967206648, 0.9231773787929166, 25.609658879618493, 50.35593348164713, 66.18772952787339, 69.92710544217017, 65.78686721863286, 61.41039640672746, 68.0174446105957, 65.69763721958284, 62.72331176265594, 59.071969524506606, 60.69941974455311, 61.329101362536036, 60.71690959315146, 58.02008005880541, 54.56600166136219, 54.297189866342855, 53.47419031204716, 57.946696435251546, 61.5219093907264, 63.819280824353626, 64.88519668579102, 66.28943658644154, 67.4491951542516, 64.8503032807381, 66.1888748599637, 65.92286755961757, 58.091981026434134, 53.53055084905317, 51.48239897143457, 56.66756837598739, 53.2511329650879, 48.81529708062449, 52.343900511341715, 53.106228843812026, 58.46443753088675, 63.37546071698589, 62.79644435451877, 57.14010807775683, 56.5303324883984, 55.55148147767591, 49.99872715242448, 47.62490872413882, 48.552019749918294, 47.59569491109541, 49.42007557038338, 47.58663423599736, 36.74434408064812, 30.039191515214984, 31.015551820878063, 44.087189705141135, 53.04420048190702, 36.1542470224442, 51.9100942150239, 43.29859325962682, 46.81194259274391, 44.37660963304582, 44.43391938363352, 47.593878853705625, 54.40956969414988, 58.85396419032928, 58.752472862120605, 61.501003157707956, 54.33535452811949, 44.43786528802688, 59.93229827573223, 64.51038283686485, 60.746711761720725, 55.81606495764948, 55.25469533858761, 47.563645224417414, 45.43062110101023, 41.39714587119318, 44.21025406929755, 43.48216410606138, 44.320398146106356, 44.44712208163354, 49.95954267440304, 60.29323870135892, 64.88720101694908, 44.47140155300018, 41.692406208284446, 41.328606374802135, 48.43589013622653, 52.621200315413944, 52.44258734487718, 53.21976969319006, 54.95054298831571, 58.343389264998905, 58.887931916021536, 59.86269581702448, 52.26557862374091, 53.30472823112242, 54.187237985672496, 53.067063977641446, 53.707132031840665, 50.05913949781849, 50.396569236632324, 50.799965397004165, 50.78474660073557, 50.061167363197576, 55.12123277110439, 60.813019429483724, 61.65342254023398, 61.79489458760908, 60.24678214903801, 61.35581662577968, 76.44800662994385, 77.98230448076802, 61.02735734754994, 57.052243063526774, 49.77682298229587, 46.70761146853047, 48.250562067954775, 49.755646105735536, 51.6151515899166, 58.452423311048946, 65.59244709630167, 68.67760304481753, 66.17429148766303, 64.74337162510042, 59.29226552286456, 62.33736622718073, 66.49572972328433, 66.83331243453488, 68.45204322568833, 64.00523647185295, 19.13673024023733, 0.8455731623595761, 0.7571313758530925, 4.858395274608366, 60.62589883804322, 68.57745708957796, 59.92207657906317, 16.554712403205134, 22.47743841140501, 65.87893701368763, 76.24818540388539, 34.07415528451243, 48.93852226195797, 31.153415287694624, 40.43111708856399, 58.05318878542993, 77.2094798857166, 18.028664588928223, 0.4639492514393022, 0.12754597085257693, 0.21013935787543175, 0.07740279659628868, 0.07854501836963239, 0.027241843354497707, 0.2392477112551851, 0.18767317066029196, 0.23504958007364507, 0.176318506560018, 0.23570936563755238, 0.4544444598497883, 0.8110502374268348, 0.448400455136453, 0.727383814031078, 0.8740669753282302, 39.6517539024353, 106.99851635963687, 61.78590843754431, 69.70936682916457, 38.34448675955496, 72.28186115141838, 34.869345234286406, 87.64982515765776, 13.459716208519476, 22.06247518139501, 60.64312588784003, 83.03670206377583, 62.18460952081988, 78.17603034357872, 7.207209573638055, 1.3290459806880643, 37.95379123380108, 56.91937669630974, 69.8369929098314, 71.51976031641807, 71.95115827745008, 66.01019520913401, 73.49923933705976, 68.75499925305768, 65.73995959374213, 61.53775968859273, 65.31119746546592, 66.10378296144548, 67.1871494477795, 64.81229551376836, 60.57997572806574, 57.68656484542355, 58.88339373373217, 64.10526475598736, 66.39308914061516, 68.11429577489054, 68.25270052879088, 70.57223335389169, 68.39082287203881, 63.84613729292347, 67.10423838707709, 69.80628075138216, 59.91879747759912, 56.951955902961, 55.40343946026218, 61.81841311916229, 56.23397781002907, 50.920252723078576, 52.3553224532835, 56.449009987615774, 64.58963824856666, 67.52783867620653, 66.0964245950022, 61.52811850270918, 56.90217710310414, 58.28462039270709, 52.551903801579634, 48.005927762677594, 51.75874956192509, 47.917709735132036, 50.034303049887384, 49.18828310505037, 44.4791207774993, 37.73236559283349, 36.570508556981245, 50.23035095584009, 65.62164521986439, 42.250092721754505, 52.501324838207616, 47.51492938687725, 51.910090292653734, 46.684806808348625, 45.45284917277675, 49.958640529263405, 56.16814082668674, 60.83436889033164, 60.64900159835816, 62.91671991348267, 56.40486763369653, 46.030622143899244, 61.19180271702429, 67.90237795922064, 68.25303000788536, 58.799898239874075, 59.01566390068301, 49.8908462832051, 53.38737257065312, 44.74371994695356, 49.12437985020299, 44.95702235929428, 47.82182739626977, 41.195061437545284, 45.46351409727528, 64.63067408530944, 70.20184393851989, 51.214575613698656, 50.70942924868677, 48.0220643935665, 53.425854944413715, 54.934010198039395, 53.76181379441292, 55.684253708008804, 58.59911603312339, 61.401096467048895, 60.35521215008151, 61.810156529949566, 54.96861727006974, 53.627292186983176, 55.9335752456419, 52.77570639887164, 55.37662613776423, 52.781691935754594, 53.38788640114569, 53.53583035930511, 49.407712259600245, 51.73203429868145, 57.046516403075195, 64.77157346663937, 64.82829486170124, 63.139840018364694, 64.28061823691091, 65.6985785884242, 73.89704611993605, 74.4168778388731, 61.38559133775773, 59.90883073499126, 53.61405418765161, 49.02322192345896, 50.344974379385675, 52.453597437950876, 55.34525502112604, 66.62836859303137, 68.22951932107249, 70.13266901816093, 69.10820084233438, 65.42992761058193, 61.7944945058515, 65.62521065435102, 67.70867563063099, 71.00046988456481, 72.01912510779597, 69.44626208274596, 33.81170557391259, 1.9491501513027378, 1.2083844359843963, 4.306782551350133, 68.22618530642602, 76.39805916816958, 66.1637403118995, 31.284798998986524, 24.144449657009496, 72.89954816141437, 105.8465789979504, 37.87968589413551, 50.00979215868058, 58.68544740061606, 53.44448228036204, 68.72895471511349, 95.1086905694777, 25.00635127867422, 0.7529556450824585, 0.4851711433260672, 0.5854997952138224, 0.26628444031361614, 0.31115022638151724, 0.15295308533935778], [0.13169005453105898, 0.06486857925812084, 0.02765911995553442, 0.191997982140991, 0.16383708034071232, 0.30602883667715136, 0.8798030739830387, 0.42570902274981626, 1.0780358626957864, 0.33862357959151274, 17.389275104768817, 82.50111810622677, 46.95927466115644, 55.383192185432684, 29.501230601341497, 54.54680950410905, 16.933064230026737, 47.63959407806397, 50.8329721420042, 2.74090422737983, 18.34605689971678, 62.42642364194317, 57.76036424021567, 61.34638332551526, 36.05855295735021, 0.7664497016418366, 2.277051840097674, 23.080363581257483, 38.76446277864518, 54.58361310343589, 56.37370440267748, 57.110360822369984, 65.43643874506797, 62.06725220526419, 60.52431729532058, 59.04237524155648, 58.76951163814914, 57.20913002567907, 56.428735256195075, 52.18070637795233, 52.624926567077644, 51.526337362104854, 58.06372427171277, 57.755614249937004, 60.79355662868869, 64.66761104522213, 68.98963543676561, 67.34113385600429, 65.14446143181094, 63.51518730963431, 67.86650396162464, 66.70986760047175, 57.95454902033652, 53.214415657904844, 48.367370251686346, 46.936183667952015, 45.42955813869354, 46.94645635543331, 55.43445756358486, 58.57607603073121, 59.16261549918883, 59.203600345119355, 64.04982989834201, 60.10350188901348, 57.998934561206454, 40.44587304515224, 42.033460217137495, 55.31852406840171, 49.5199312702302, 39.30369846282467, 31.515622638886978, 19.24112608355861, 27.70838579823894, 32.49100235200698, 45.84619622076712, 50.12657288582095, 68.6879659468128, 51.24414244005757, 37.458050712462395, 43.400700399952555, 45.08827271000032, 40.27953317088466, 46.39324526632986, 45.170893515309984, 53.71419622052101, 61.57453583132837, 65.19666425643429, 60.68999428902904, 58.92470021401682, 47.8287229230327, 57.52896008952972, 59.24496958332678, 56.888437040390514, 54.109335791680124, 42.628530840719904, 39.29613613313244, 37.38751472965364, 39.81806239774151, 41.569255551984234, 44.0610824092742, 46.86191358873921, 43.22161282262495, 48.89107727235364, 78.94335577564856, 76.33654855912732, 62.27309426953716, 54.30135150109568, 38.7591754236529, 31.049358729393255, 34.72300160315729, 42.875910805117705, 47.54630050351543, 48.162202835083015, 48.99740880535495, 54.373346605608546, 60.07383308103008, 54.4620470846853, 47.58109977168422, 44.37635860135479, 50.355690294696444, 51.70472283517161, 50.51462473407869, 47.11263149015365, 48.947233846110684, 44.84988674040764, 47.8016624912139, 51.3608290303138, 56.570791736725845, 59.404021693814194, 58.6826507506832, 57.0073397697941, 56.017286469859464, 84.77009942454677, 79.3873445449337, 50.17980729379962, 56.94950834397347, 45.26867428133565, 44.94703208246539, 44.28120582334457, 48.00835570981426, 50.42288049574822, 53.3186448004938, 57.289373874664314, 63.64750846739739, 60.13769711217573, 60.384767209329915, 53.09215145726358, 56.88020790776899, 58.87877710403935, 63.23440051847889, 51.69979633823518, 32.917185521894886, 2.131317892382222, 1.1893336066315252, 0.2892079054107589, 27.783228543496904, 67.12770200544789, 58.7285424816993, 31.66440010070801, 3.9987191077201603, 14.626857657586376, 24.94367180332061, 22.47609107725082, 28.546611993543564, 51.103219524506606, 42.32637105449554, 42.998998703495154, 43.20136162542528, 67.09887258468136, 16.665093783409365, 0.7649620814669518, 0.06779469038930631, 0.18053617298362717, 0.22278887910708306, 0.07687388183248621, 0.013513236528172368, 0.035869152089881326, 0.01541814671063255, 0.03943643284841411, 0.025772534596223026, 0.12599156313245335, 0.22588922161488767, 0.5509537037822508, 0.3930925535819223, 0.7128750893377489, 0.19013119440886284, 19.114890483117875, 93.30494942203646, 55.3336291159353, 61.50956569179412, 27.13554128523796, 61.48468217542095, 12.815551238675273, 48.458275102799945, 39.77628523303617, 4.180993120516501, 20.216195929434992, 66.86942961908156, 69.25712539303687, 65.72124596565001, 43.44323458210115, 0.2727458097280995, 0.8313428033744136, 15.317000650590467, 35.5177326356211, 54.91086429165256, 58.22810296089419, 59.68339643170757, 64.50390700371035, 65.22989457653415, 64.48134553047919, 61.60090200362667, 60.74828070978965, 60.07609628861951, 62.41426429440899, 57.859392319956136, 54.37665708603398, 55.168289446061664, 57.37666230047903, 58.32623281786519, 63.41421765665855, 67.20042274844262, 70.2902384727232, 67.06338297936225, 65.62685412745323, 64.7551622698384, 69.77774158600839, 63.62522156007829, 59.33612154376123, 53.39416611579157, 50.81337205825314, 49.17438614752985, 51.38120574335898, 51.55285650683988, 57.5276029494501, 60.22331853066722, 60.1160377840842, 59.21992917214671, 62.09420281071817, 58.94912481307984, 59.657163619995124, 44.72391589995354, 46.05351309622488, 53.40069686212848, 47.94222847107918, 41.14532186139015, 33.46184584402269, 26.56077873322272, 38.4697005825658, 53.92835370955929, 54.711301942025464, 55.30410935801845, 75.2635528195289, 64.5093708653604, 40.36735503904281, 46.4250046976151, 44.76380248223582, 44.0463617540175, 47.28565508319486, 45.337837434584095, 51.09730851265692, 59.36869290567214, 62.2206090342614, 61.00696102265389, 55.04104775767173, 46.1095323870259, 58.007422570259344, 62.694600012994584, 60.27343857672907, 60.04800427344538, 48.645113283588046, 43.31933475309803, 41.78063208057035, 42.30251519910751, 40.58430917801396, 40.87489404985982, 39.98903459118259, 42.21323028687508, 47.389888148153986, 80.03805006704023, 76.31074720813383, 67.52342993213286, 66.69816324787756, 56.90698200656522, 41.10452921159806, 37.91531670478083, 40.3888221709959, 45.970072515549205, 51.718223633304724, 53.23046991902014, 57.099790034755586, 56.27974010282948, 53.63690199390535, 52.573347399311686, 48.81943125878611, 52.09193921858265, 55.39414736532397, 50.569271195319395, 48.22028529259467, 52.81019972216699, 48.17702939433437, 50.32532330482237, 54.59435255296769, 56.50206004419635, 61.239675244977406, 62.204699900842485, 59.61266825276037, 55.84617699346235, 76.81524245969712, 69.06813775339435, 56.132384500195904, 61.579125004429976, 51.76850841891382, 49.32890399809807, 46.27237350709977, 49.748377953806234, 53.74709313915622, 61.93797480675482, 63.855154821949625, 66.08575574813351, 64.43812493355044, 62.73008177357336, 55.981855700092936, 58.60573699397426, 59.58128536901167, 65.32147015294721, 56.93939255129907, 28.62750303360724, 1.3504143179424348, 0.8932076514728609, 0.2601250014718502, 34.94246605903872, 69.27605475148847, 65.2757235496275, 30.84099065872931, 8.58957294494875, 17.459059953689575, 26.19993636685033, 33.53210726091939, 36.81991246438796, 56.1101407389487, 33.40887423484556, 54.43678702077558, 54.66161727905274, 80.81025492760443, 26.080406058219175, 0.5642499870830967, 0.19653777321500165, 0.06644613049443691, 0.12097297476664667, 0.14194962658709095, 0.08126637718129544, 0.21624677934713904, 0.12926900218571388, 0.1971107456953295, 0.2585401494176157, 0.222148536854694, 0.3701921017660249, 1.291737866497809, 1.190066231835273, 1.16774242972174, 1.264530223223471, 26.051329528131795, 113.0641794204712, 66.34624035127702, 74.48016135923325, 41.99767251168528, 76.5231357082244, 25.933495644600164, 56.05342718862719, 63.733655483491965, 7.486375935616032, 27.255608958582727, 74.29927733636673, 71.5176030128233, 71.34416364854383, 46.06972425214706, 1.0942063240274307, 3.0313388234184635, 22.80734504422834, 42.30670036808137, 58.518425033938506, 60.93853919736801, 62.96832261546966, 69.8858028842557, 68.42538679799726, 67.38475061232045, 63.00126660254694, 63.950072257749504, 63.35941430061095, 67.17534311356084, 61.69097531226374, 60.38372385886408, 62.100509981955256, 67.25177441873859, 67.83152426442793, 71.71596511717766, 74.66736824281755, 73.67259240919545, 67.98560280953684, 67.44247221177625, 65.53611401588687, 72.19075233705583, 69.07340941890594, 61.90260679491105, 57.58699940096948, 52.91394249085457, 50.458287731293716, 52.04220356479768, 50.565599856838105, 60.66850754522509, 62.60263612193447, 63.454253289007376, 65.83279425098051, 69.14704015178066, 62.05997620859454, 64.37718699055334, 47.22966717135522, 45.50869195692001, 53.71304304369035, 44.84746271564115, 43.85422052875642, 42.96099093652541, 38.60077050424392, 52.11186093668784, 54.69809532165528, 55.207709266293435, 62.61869430541993, 74.05307016065045, 64.03756856918335, 46.31136578898276, 45.11834159974129, 47.469312221773215, 44.632430538054436, 50.751684942553126, 47.67400895395587, 53.17329745138846, 62.144726860907774, 66.14250459978658, 64.73370298262566, 58.529180172950994, 48.925856928671564, 63.27587566068096, 69.94747823284519, 64.24084148099347, 63.89412356961159, 53.07270826831941, 52.071844916189875, 45.826702041010705, 47.21085156163862, 42.42251619215935, 40.18779285492436, 41.45123535586942, 41.15049939001761, 50.14258007849417, 77.87437654310658, 76.64452522031723, 67.91124251581007, 71.35292622350877, 63.77846856271068, 51.26432695696431, 49.622650300302816, 49.6288437228049, 51.05525678203952, 50.92681092600669, 51.7099238980201, 58.421303226101784, 58.3785415464832, 54.424035395345385, 53.45551590765677, 48.26766752427625, 53.37804517438335, 55.664798751954116, 52.958277040912265, 49.85646278627458, 53.83373829626269, 50.46960376924085, 53.97861888331752, 56.29009908245456, 59.50382640284877, 67.17947729172246, 63.65452951000583, 63.186990830206106, 55.55607849551786, 78.85573787073936, 81.73363577935004, 58.73538309527982, 66.55178039304673, 55.15739702409314, 55.10160915313229, 52.05844217731107, 55.28634494350803, 59.39326263243153, 68.78027500644808, 69.25099865082773, 73.70389292317053, 66.1303452522524, 64.39144088375953, 58.196327840128255, 63.56770000150127, 62.8647171297381, 72.86022247806673, 61.35874271392823, 40.31850584091679, 3.8636022806167607, 1.1546735826038546, 1.9854584288212562, 32.34339375649729, 81.86805540515532, 69.49405224092546, 47.523829244798236, 19.497413750617735, 27.25048830432277, 33.526443358390566, 29.991719069019442, 42.855373274895456, 71.34671318915584, 60.28003600335891, 66.64671744069746, 65.20875300130537, 97.39667969365274, 38.15672289940619, 0.8918163745153336, 0.3968498471283144, 0.3075352106844225, 0.2944512869561872, 0.30607890818388234, 0.3026297964876698], [0.37468450264103953, 0.1376482727186334, 0.17965167850976993, 0.18443980464531531, 0.5970425338995072, 0.5714483943677718, 0.9804217974024435, 0.45852636017145654, 1.406169829349364, 0.06611296651704658, 9.677722761707923, 69.08704357762491, 48.34812318125079, 60.32724172838273, 27.48835259868253, 48.83774480512066, 47.543335191665165, 26.937844022627804, 24.83583211898804, 11.907591185262127, 18.401597661356774, 52.7575772039352, 51.398636756404755, 52.74134251379198, 62.9745787958945, 6.636391455127347, 0.30057956134119346, 1.21503064709325, 8.247830560130458, 23.199550682498565, 43.1437929984062, 50.89640863480107, 58.812339998060665, 63.13248557429161, 63.522824164359804, 66.77492403214978, 60.73258730673022, 55.13606717509609, 50.97401272866034, 48.19247176570278, 47.70057124476279, 51.79929118002615, 53.767889545809844, 61.240855878399266, 63.45850906064434, 61.41996306757773, 62.42165403981363, 72.16095801322692, 71.76965452009632, 69.79348597988006, 66.80613040924072, 63.396221822307965, 55.72255957511164, 51.28499000303207, 46.82886369766728, 49.09964930626654, 50.17083291084536, 56.978553495099476, 61.6359366140058, 62.48188203380954, 58.86817493746358, 62.24210362280569, 56.0521641854317, 55.78352889707012, 56.1884783160302, 51.2601064866589, 54.14064807276572, 38.5151961541945, 25.20678243329448, 22.472045152418076, 25.276249570231286, 44.10914713336576, 54.9679426224001, 59.591232499768665, 56.16972938660653, 55.80987937988774, 47.76409795207363, 48.63662135216498, 44.06375746573172, 40.488411149671, 42.315255057427194, 46.8924766971219, 46.81431562669816, 50.06325798649942, 47.26308576522335, 51.97217356774115, 58.565050248176824, 53.26839531621626, 50.616269034724084, 49.35078690128942, 52.217694328677275, 55.63647531693982, 53.63660781614242, 43.155728770840554, 40.06232407785232, 43.64864518565517, 40.76525203643307, 44.76184914189, 42.005827119273526, 40.37918490748252, 46.2033829381389, 37.05781206007927, 32.84595135719546, 36.49312803822179, 47.886091509173, 57.176099746458, 70.65624267824235, 73.97746255320888, 66.78893473840529, 51.82150748468215, 35.47789312178089, 29.91420715085922, 36.720817704354566, 43.9193985539098, 43.61488142321187, 48.28047406288886, 55.03143010600921, 51.69787829922092, 46.13861283948345, 48.08266501272879, 50.80236196517945, 51.06136783476799, 48.114518580898164, 47.25563718426613, 44.38720003251107, 48.39179877311953, 52.14830367795883, 54.8927233296056, 57.484625539472034, 60.19285348153884, 54.4755635722991, 72.0228042910176, 53.541972790994954, 43.81690702130718, 58.36347572265133, 57.91656086521765, 53.11448935539492, 43.68934369856312, 43.074873032108435, 42.26147543999457, 48.53109390504899, 52.775878983159224, 59.60892631161598, 59.925598867477916, 62.324430250352435, 60.42289264740483, 61.2754511833191, 57.967928224994296, 53.57564633892429, 45.13684734221428, 33.76196599775745, 2.7412292938078604, 0.3206933223672452, 0.46296939434063056, 3.1490974464724144, 54.21411798846338, 57.96957562046667, 55.14555146617275, 18.320126110507598, 5.2838910491235795, 19.214587326972715, 22.570227961386404, 12.755048678767297, 31.599712371826175, 86.18848339203866, 53.86935341742731, 21.317607279746763, 40.81019455386747, 58.53079226709182, 16.642224404119677, 0.875006321697466, 0.2484676713544515, 0.20989232516336828, 0.22014264287727497, 0.062413707961358374, 0.042678666331114314, 0.14661044423137942, 0.08420526665905792, 0.22388328167219318, 0.2692520504276599, 0.4034420950037818, 0.37210722964617515, 0.48145681199046875, 0.15046460193491754, 0.6291139161875171, 0.12598461471498013, 12.781044187084323, 84.65899436704575, 57.13917847602599, 68.25322612639397, 35.09949030414705, 59.427861859721524, 32.42654800415039, 23.50369518803012, 29.088550190771784, 13.439091405560895, 27.382225028930176, 59.623697957684925, 63.43832846610778, 58.54701126775434, 66.6539659807759, 7.882790767377424, 0.05395078445754705, 1.061831203199202, 4.123130315734494, 18.680576239862752, 42.02156366840486, 52.593300496378255, 60.5840628377853, 67.3756036450786, 65.69924931372366, 65.7574180633791, 60.974342592300914, 56.260991173405806, 57.12758787216679, 54.893001817887836, 49.486300868372766, 53.353934364934126, 57.217398382002315, 64.1987975951164, 66.1293960386707, 63.47546154452909, 66.40473073528659, 68.79808256703039, 68.27380288031794, 70.27314478351225, 64.21541667753651, 62.76350036744149, 56.25391913998512, 52.78157426464943, 50.54175184619043, 52.77325099514377, 54.91930523226338, 58.719972102872795, 60.17082152828094, 60.52843578400151, 58.69459829022808, 61.58162355422974, 58.62892996880316, 57.797599300261474, 53.308403491973884, 52.66451112685665, 54.68603403337541, 40.24748740657684, 27.49157874814926, 28.13430420814022, 36.32357966515326, 65.25100085043138, 72.10213030538252, 73.07790617788993, 62.236431875536525, 55.51546235238352, 53.54214145291237, 54.53038654019756, 49.47674989700318, 42.64130600037114, 44.29462817407424, 45.02646007845479, 46.387110679380356, 47.878329138601984, 48.52071531357304, 53.4151311843626, 59.20605182647706, 54.62582172886018, 46.10924605400332, 47.85515577562394, 52.453150287751235, 61.090150571638546, 62.08213760006813, 52.82444969300301, 47.05055213743641, 52.135924677695, 45.49790151657597, 44.62149497001402, 41.969462825405984, 41.52210081777265, 44.52623628800915, 39.461970021647794, 36.960145042788604, 37.905600993864, 45.044667720794685, 56.16374384972357, 69.34613181698707, 79.02305833755001, 76.3400237791, 65.39114713668823, 46.549473270293205, 34.09608525614585, 36.529096172701934, 40.41950295048375, 46.39753633929838, 49.12682348682035, 55.73504055699995, 56.24860432840163, 51.97089487506498, 52.10080377517208, 54.06083568449944, 55.232632006368334, 50.700627450020086, 49.68676928550967, 46.025538752155924, 48.085508731103715, 52.038057619525546, 58.13731970325593, 59.895843767350726, 62.19889479298746, 57.58265733718873, 69.78286420145344, 52.52865983593849, 42.78069134681456, 64.24239866195187, 60.751559811253706, 58.40620602330854, 47.92753919478386, 49.978181777461884, 48.71211913324172, 55.04738630787019, 60.66529512405396, 65.66178675620787, 66.99370599562123, 67.81810191369826, 65.48586453160932, 64.09264649114301, 59.95787997399608, 55.74926699361494, 50.9292467178837, 30.245539565240186, 0.40146316732129744, 0.2555151133527679, 1.3735436768301073, 4.196164358046747, 62.75600471804219, 64.21819763798868, 60.63956829809374, 20.91633116045306, 10.838082432746889, 13.041503294821709, 19.39181766202373, 18.836394356143092, 42.43454610147784, 91.44121170043947, 54.52935887921242, 26.445186484244566, 46.68905865761542, 71.42899667063068, 28.339514770815452, 0.3130497873550461, 0.2408068380769222, 0.1950431816400059, 0.11109340530369552, 0.07709423936302624, 0.026936047868202292, 0.4136305741004406, 0.3043204299624889, 0.24746552109718326, 0.38456859968362317, 0.617368133558381, 0.48056088748478126, 1.3148295951466407, 0.5816368734644306, 1.313832822826601, 0.3267194619101863, 17.256167511786185, 102.49208957918229, 73.80251699878325, 80.54142352073424, 41.340804946038034, 68.23352013864826, 61.62279667392854, 35.22808128787626, 31.51131391525269, 21.918924277828587, 30.93223087249264, 69.58192117752569, 67.02207257670742, 61.160360997723, 71.72167608814856, 7.134859004328328, 0.36392528804079183, 2.965084352800923, 8.445087536688774, 25.974668764298965, 46.65614997186969, 56.92451500123548, 64.42542037656231, 70.22331499284314, 68.25120218338506, 68.18558877514255, 62.72821864774151, 58.54899598706154, 60.1744967891324, 60.07883018062961, 58.56039831715246, 61.47085189819337, 60.06235622590589, 71.21055987573439, 74.44636621782857, 67.49609885677215, 71.15978871622394, 74.39251992010301, 74.61170981007238, 72.79876678220688, 70.77147406916465, 68.01968820633428, 60.43337714287543, 56.52476664512389, 51.21069638959823, 52.24827704891082, 54.598639703566036, 62.294353515871116, 62.853910999913374, 62.85037694438812, 61.66665269482521, 68.14428621722807, 65.97529395934075, 62.853036311364946, 55.47872151097944, 51.211547543925626, 53.61254799750544, 42.98596074504238, 36.667567606895204, 39.4971497597233, 47.02013023437993, 62.37824909148678, 56.14986258168375, 57.49866370231875, 49.21517879732194, 46.989900527461884, 45.83602159254013, 49.58060249205559, 46.594506002241566, 45.34896519876296, 43.06272545168477, 50.223580944922666, 47.325243565344046, 52.071201647481615, 51.02922793357603, 59.333866180912146, 62.277295127991714, 57.158500071494814, 48.43599604022119, 51.38444954349149, 52.52541995817616, 63.567852973937995, 65.90106702619984, 54.31671934743082, 51.03850041666339, 57.91456830117011, 47.109666178303385, 45.61369772880308, 43.23507439705634, 41.47306334587836, 45.30192421328637, 46.007907698231364, 42.47354622810118, 41.26229870703913, 42.7229344460272, 51.10697323276151, 60.63051939010621, 66.04921494760822, 69.09120913474791, 69.13274703487274, 55.316641330719, 44.026643999161266, 42.79076791578724, 42.60500446442635, 47.619621369146536, 51.512252130816066, 58.70804417517878, 54.57499173379714, 50.17486902975267, 50.226934571419996, 53.04560469042871, 54.97778777153262, 52.0661457123295, 49.94761474670903, 48.498232287745324, 53.38961616639168, 59.66574576593215, 61.632139759679, 64.57507841048702, 62.59698398651616, 61.15493243740451, 65.85298661262759, 62.50192534539008, 53.051939318257, 61.798271748327444, 65.94127132046607, 62.64917504402899, 52.0908409549344, 54.747183784361816, 53.2399542100968, 60.09542572882868, 67.34305581738873, 66.66174796319777, 68.82539010817005, 66.96213091573408, 66.19988887540757, 69.02022207936933, 63.02666787178286, 61.75520804620559, 61.207962882134225, 41.491753439749445, 4.155023107605596, 0.3441718334872877, 2.4644416041912574, 3.8060981275573855, 66.65020050541048, 69.11504930065524, 67.43176414120582, 29.923340389805457, 14.58194455792827, 25.76044459496775, 30.090017587907855, 15.358576793824474, 48.01186230874831, 111.08293533325197, 74.40274161677208, 35.803598896149666, 59.53747641655707, 86.11621764398392, 41.86456687988774, 1.1089923112623155, 0.33599828820555444, 0.5449364202157144, 0.18875641898522455, 0.48958601610314467, 0.09521717536112956], [0.21940775005327118, 0.13735317565020055, 0.340423732995987, 0.17464907839894298, 0.5997480500128962, 0.4813099069701087, 0.254683478945686, 0.2236518005449926, 0.39481309512930535, 0.29805315658450127, 7.626653621273657, 67.46224095744472, 46.96324017740066, 44.16084789460705, 19.461902572262673, 44.40578814475767, 39.085418562735285, 90.1847117946994, 12.61743232127159, 3.601939985829015, 36.615203965094786, 57.63531907912224, 53.64465259736585, 38.93880821043445, 69.4383075160365, 22.329937681075066, 0.17170644275123076, 0.8270680940439625, 0.1382645138449246, 1.4536992724864715, 10.913615515155177, 46.34160726301132, 61.01332310707339, 66.42242846950408, 66.83051970697218, 64.48526005591116, 57.80026258960847, 59.97146706427298, 51.75101857031546, 54.63059917573006, 46.99614886314639, 48.68070879290181, 58.918561704697154, 58.962005876725726, 58.8260643712936, 68.50507367041804, 64.57356437560051, 60.246668400303015, 52.784382681692804, 59.696497148083104, 61.32021327172557, 57.83914504512664, 51.74529975460422, 55.41816011551888, 54.687638282775886, 55.30161473058886, 58.289350771134906, 58.54084137947329, 61.62340464130525, 61.90362268878568, 57.67967324103079, 57.638158875127, 58.09109064840502, 57.425723306594364, 54.1734940005887, 44.53165308121712, 25.951038445195845, 22.332296986733716, 30.94932456170359, 42.36285301946825, 61.6220514235958, 68.10257573281565, 71.56843693025651, 65.78189365325436, 54.864874501382154, 60.542258216488754, 53.75072525393579, 46.35367247366136, 54.980451060879616, 50.789771156926314, 45.93735210357174, 46.72066119409377, 44.04585576826527, 45.680903619335545, 48.57186694299021, 50.33491742226386, 49.28037643432618, 41.1974972294223, 42.39482818111297, 38.9160623858052, 38.91176346809634, 44.832016421902566, 51.638120989645685, 51.17491652888637, 47.014195688309215, 43.8664230223625, 45.81260112024123, 45.823293501330966, 36.5694377499242, 36.863909690610825, 37.451645481971006, 37.13963270187378, 33.144996781503, 31.850622469379058, 50.296211473403446, 52.93762183958485, 49.792551686686856, 52.652704792637984, 58.49050168068179, 69.51723344864385, 68.62410191566714, 53.44094822483679, 35.6787145522333, 27.984905050646876, 30.843493130899247, 28.73838451600844, 38.65156912034558, 52.71193650461013, 54.828376846928755, 54.99894503624209, 52.845175496993534, 50.10531756185716, 47.95637646029073, 47.78894616711525, 46.24715658926195, 46.512516698529645, 50.93620500256939, 54.82441133068454, 56.37079400400962, 60.20823701735466, 55.9379957568261, 72.28644247977965, 35.438351708073775, 32.3826390312564, 68.84431946662166, 58.58495627680133, 59.577166880330736, 44.65306612753099, 45.859575425424886, 41.68554206048289, 50.48084920452487, 57.00193474369665, 63.88980896242204, 64.20231988353115, 67.92489236400974, 63.556266292448974, 66.42310311717372, 61.07318632064327, 54.70756392325125, 29.87552473621984, 6.02998371085813, 0.26190119164605297, 0.15002525051034268, 1.7867615746874965, 6.131115651899769, 59.223424003970244, 58.83448962242373, 57.77892489587107, 30.421000911343484, 14.325864776488274, 12.782408191311745, 22.418783287848196, 25.373257629333008, 26.36416796715029, 60.015546660269464, 33.48022999302034, 48.75496318263393, 51.73975352318057, 63.52361648313461, 24.522697541021532, 0.2130170139454065, 0.2765563004199536, 0.1676676118926656, 0.11135219746539671, 0.010214769319000264, 0.09110571936734262, 0.10188508974087816, 0.16204276452622107, 0.4197345481764886, 0.21867788276605069, 0.36849604438870187, 0.18599517763622347, 0.11068321884639802, 0.1602458133692703, 0.29564672119675145, 0.36390083451424876, 8.662805557250977, 77.6158295908282, 54.05943539834792, 48.42943783729307, 23.51518184907975, 54.14703369140626, 55.81041674460135, 95.52315173610565, 18.024801054308494, 6.702611359857745, 44.02547905522008, 66.0502661428144, 53.25352953326318, 43.521540780221265, 75.75002085778021, 27.03953343053018, 0.1422137583816244, 0.3598878208187319, 0.17252113129342758, 0.4518913033027803, 9.753296048410478, 50.56970657840852, 66.0212641377603, 67.33685847251647, 66.6932132167201, 64.8687070415866, 59.71708959148776, 62.71209770633329, 52.2038915080409, 55.68545395328153, 51.05587651652675, 52.27678875769339, 61.77209384979741, 62.31663650082004, 61.99437064509239, 67.48504561762657, 63.15403899838848, 61.298546098893695, 53.81837044992755, 60.983630764868956, 61.21405040064166, 59.676987278846006, 57.348095678514056, 57.31761886227516, 57.3391918982229, 56.5588402748108, 59.66456513251028, 59.76236158801664, 61.12462428308303, 60.71235179901124, 59.42164490299841, 59.298976698229396, 57.23730441062682, 56.17352231856316, 53.06678941172939, 42.53591975858135, 28.938666620562156, 30.75766186560354, 44.05923105055287, 64.68683065906649, 75.37934118701567, 74.58739111500402, 71.92323100182318, 68.22794252826323, 57.1228692608495, 57.70285444874918, 52.858562546391646, 42.44299880919918, 54.41015804967573, 51.69007670494818, 45.00918203784574, 47.658825459018836, 45.418293091558645, 46.1450102252345, 48.769699527371316, 51.23341475763629, 49.214900309039706, 42.76920272457985, 43.22686879865585, 39.332355299303615, 38.39908222998343, 47.06735557125461, 56.73642166199223, 52.23202274691675, 48.104088998609974, 46.517929569367446, 44.28051156382407, 45.16072280945317, 39.28154491609143, 38.874885343736224, 40.24160385131836, 40.959119104569965, 34.51368824128182, 31.607231555446504, 48.41586643649686, 49.87506658800187, 46.578228166026456, 49.58791379005679, 53.897300304905066, 67.42283682669363, 71.06285910452567, 62.24467669763873, 43.892738203848566, 31.678759897908858, 31.926269300522346, 31.02498708232757, 42.27368970071116, 55.08965769121724, 53.346556386639996, 58.003676706744784, 56.602527633790054, 53.68553153930172, 50.73020212111935, 51.062324893090036, 49.623579902033654, 51.99016547972157, 55.100075506394916, 60.380201570449344, 60.424363536219445, 65.73334255526143, 58.59930430689166, 68.37384685393303, 38.77609652857627, 36.04857837000201, 71.40444263335198, 61.8822967621588, 62.42606670625749, 49.98921932712678, 52.577293303705034, 46.151831226964156, 55.303768111813454, 61.956296197829715, 67.68907162450975, 67.14238735937303, 69.67036278017106, 64.86311766409105, 68.68202747837191, 64.45019406657066, 58.84950053307318, 34.10377702405376, 3.0860311273605596, 0.13769736363282128, 2.2066639267629196, 1.8463749823070343, 10.3729824866018, 66.4074920838879, 65.86749938226515, 65.14648145244968, 37.674800888184585, 19.499041534239247, 12.170261529184158, 22.371267695580762, 28.490869229839696, 26.218818656859863, 61.56334138685658, 41.84972070878552, 50.64353735216203, 55.038980668590916, 74.271922726785, 33.428176218463534, 0.4768140740211933, 0.22626880285961015, 0.13684901318723156, 0.15179610871259244, 0.056866863667364084, 0.039836392031922456, 0.2950741777256612, 0.2641495984167822, 0.7154777658081825, 0.44741247750578395, 0.6875916750681016, 0.31941677473725816, 0.2236636902295774, 0.20627213071190542, 0.6000052716943526, 0.5360600352287292, 11.040934670356013, 91.86889125454812, 62.87644501655333, 62.46157984579764, 28.79309177398682, 62.79283969633041, 48.640033814214895, 96.21915278896209, 21.240224799802228, 12.285399763814866, 50.56387793633246, 69.83293717907321, 62.72180557250977, 49.37680790501256, 86.15548841414913, 29.51678279907473, 0.6571239905972636, 0.8703307951650313, 0.23422373729127072, 1.8334861964948717, 15.672429165532513, 56.72354844308669, 69.05543711877638, 67.61168326100996, 68.64105439955189, 67.56113175422915, 63.96457326027655, 65.30872244988718, 57.44628044866747, 59.32970454615932, 54.95603038418678, 56.070799366120376, 68.79160281150573, 68.00257882764264, 63.88515703139767, 71.49668109032416, 70.13874084718766, 63.93792859969601, 57.53780503426829, 65.39073921019032, 66.19452307301184, 61.750006983357096, 58.93771856061874, 60.2182625955151, 58.827280306047015, 57.75147614940521, 61.41851963535432, 61.68282070467549, 65.6425710647337, 65.60416713837655, 65.18335173206945, 63.89590432566982, 59.07912785007108, 59.95062751154746, 55.48630345252253, 46.27747651069395, 39.66036742733371, 46.146057498070505, 59.02712898869669, 67.08250061158212, 63.66096611945861, 62.7611037992662, 61.42361871657833, 63.09904344620244, 56.98279749962592, 62.54187860796529, 53.38950634002686, 40.520233338879, 52.905183838259795, 49.92886973965553, 44.40234822611655, 50.744397178772964, 48.52168021663543, 50.920091905901515, 52.00019890262235, 52.88565435717183, 52.56904063686248, 44.861430275824766, 46.925593268486764, 41.69687771028088, 42.33865199550506, 47.492077658253336, 58.023767086767386, 59.30993580049085, 50.82400560379029, 47.915587732868815, 47.9635779319271, 44.80430095426498, 38.649219620612364, 40.83650189061319, 41.596045340261156, 45.17918932822443, 41.90117043833579, 38.29917553932437, 51.16190210465462, 53.90017540224137, 47.3343316970333, 47.637880002298665, 49.75310833223405, 59.06886300733013, 64.28021423278317, 62.45149935445478, 49.9688426140816, 39.93767115377611, 41.040131738108975, 35.12899045021304, 45.61917335756364, 58.59569572633313, 56.61056064790296, 60.28478991600775, 58.94339030788791, 52.89256949578562, 54.42858534474527, 50.82689639060728, 49.483143360384055, 54.112752176100216, 59.738152719313106, 62.793059349060066, 62.798750708180094, 67.64513323383947, 61.519438297517844, 71.83627989984328, 45.07685861279888, 40.95939367048202, 70.9425364771197, 65.11884835458571, 68.03892350965931, 53.266543957494925, 55.66709726087509, 50.49535805179227, 58.93052885609289, 65.39199436864546, 70.992962468055, 70.73746711977067, 75.06010732343121, 68.52263019930932, 74.19811940962269, 69.75336797775762, 65.37401422377556, 45.10260505060996, 8.187176008378307, 0.35875753469524846, 1.4648625831450186, 4.568373262882233, 8.733125809700258, 72.00642447317801, 69.5182454201483, 67.81421876722767, 39.11915486858737, 23.520802605536677, 19.82701051619745, 32.6081576654988, 33.8475364254367, 39.61980619738179, 74.87723858125749, 48.662889465208984, 68.26970008111769, 65.65720150547644, 84.98454324660763, 43.23882810531124, 0.5248272863607253, 0.2934260161653642, 0.28703757832127236, 0.21065991461998035, 0.22542406834902304, 0.13553397729992867], [0.36810794424626136, 0.07289792380986676, 0.05787818782752561, 0.08668088744724951, 0.4010286422506456, 0.03439940857670961, 0.0691329004363187, 0.08037953847838987, 0.09572617183890074, 0.15283354497965307, 4.665067532370168, 74.3742730540614, 47.860513733279326, 72.996030622913, 37.495948653067316, 41.07603319229619, 32.04132614597198, 58.127349038277906, 37.00886088032877, 1.4318454193492092, 41.672923795638546, 60.95580939323672, 72.52576197347334, 50.9884705851155, 57.40775492883498, 32.46896059282365, 0.11790367414153392, 0.23543343608898504, 0.16943431789836577, 0.15225870324478996, 0.7886459654377354, 9.009177319465145, 59.5471215248108, 68.38515112476965, 66.14942366077055, 61.34105282445108, 60.46696439866097, 56.790828858652425, 50.7951291145817, 52.08215682737289, 50.269421685126524, 63.48851911483273, 62.8490904069716, 68.94769745488321, 67.31991383337206, 66.97470603450653, 53.2978601609507, 53.28558706468152, 39.806369812257834, 49.755806922912605, 59.972898729385875, 58.86414274092644, 61.98150134855702, 59.31711766027636, 57.085383169112674, 53.62752360682334, 57.935325484122004, 57.63874330828267, 59.22765624138617, 59.80008694433398, 62.34895290866975, 63.12973991517098, 59.901641030465406, 57.80730324406778, 43.239977359771736, 30.448055459607033, 30.65901621695488, 42.30823793718892, 58.365797765793346, 78.34179755180114, 69.49366784864857, 59.23498322886806, 56.969892901758996, 45.383368307544345, 42.83983676664291, 49.15390353049002, 48.73217421193277, 53.02338054103237, 49.465194594475534, 48.383808905078524, 48.59573848785893, 50.32697462266492, 49.85651377708682, 51.36963082898048, 45.375543179050574, 47.912963667223536, 52.2709914945787, 45.05224181759743, 40.791375021780695, 38.350221264746885, 42.92958844092585, 40.45148987923899, 49.39164230900426, 51.05901049029443, 44.99771694983206, 44.95632025503343, 43.52008950325751, 38.38651103358115, 33.56658489473405, 36.707752289310584, 45.4292521938201, 50.16341178647934, 57.38034148370066, 54.01985476093908, 46.762873741888235, 43.13858409081736, 39.06442603757305, 41.64944841015724, 41.78122828083654, 46.161370431223226, 56.436509393876605, 64.19826415277296, 62.35959429894725, 46.17099200525592, 27.1521839018791, 19.038535664158484, 18.306113443066998, 33.58032887981784, 54.476520630621145, 57.59611891162012, 56.98054213677683, 51.921516156965694, 53.45476281258368, 46.83233499526978, 44.4704915631202, 46.0299474962296, 49.65359387859222, 55.79861825512302, 57.59545603106099, 60.165749903648134, 57.470595221365656, 44.253035360767, 44.55446166376914, 41.42224119555566, 64.13777728234568, 56.985009716403106, 54.47920745418918, 43.566447996324115, 49.30982558957992, 43.83501660439276, 51.49103603055401, 54.74722693043371, 63.30094352845223, 62.7381657784985, 64.82479610750752, 57.75872076711347, 60.910572698039395, 59.91660879504297, 66.27930118191627, 14.654905546096064, 0.4418377476113458, 0.5567778106178007, 1.5470802423454102, 2.1678802659434657, 14.579730379965998, 61.78531615964828, 58.31571302106304, 65.46966514279767, 58.53949600650419, 35.31743680277179, 12.510552637038693, 14.47651517006659, 29.720832340178955, 33.01069874917307, 46.22065705637778, 30.821590615857033, 35.55324185279108, 60.81407846943025, 68.58891041048112, 22.396708188518403, 0.8767216844904808, 0.22550766386332052, 0.15630482726039427, 0.2934024513008133, 0.063176172289757, 0.22977843550184082, 0.02340111708749206, 0.14618520414636982, 0.06538845418441681, 0.03252695562438138, 0.09518922081277256, 0.1754531029972338, 0.050760537701388525, 0.06131627934894735, 0.13758462613388417, 0.3028689997811472, 5.290860120327243, 80.0199051826231, 54.73268278183476, 69.9637560690603, 40.19296646118164, 52.86909411030432, 40.3424205318574, 69.01280095500331, 38.731812969330825, 4.4612886348078336, 42.44843521425801, 69.09440194406818, 74.84428282706969, 54.35411914702385, 64.62433553511097, 39.12513648310016, 0.2495183149773267, 0.05504712139466598, 0.2953154034912586, 0.18692629622115245, 0.5187606054448313, 9.532435228747707, 64.83062867195376, 69.0326952165173, 68.60856932978477, 64.21505974185082, 60.18020383773312, 56.10205673402356, 53.2267201331354, 57.24955397267496, 52.46696487549813, 65.11706367615731, 67.34995134415166, 73.66264527843845, 66.31738739628946, 60.34216634688839, 53.85084767495432, 53.99852491194203, 42.3697603133417, 53.10840183688749, 64.28660377379387, 60.943555908818404, 65.21436199065178, 58.31223387872019, 56.490026212507686, 56.64040596254411, 57.461008948664514, 60.300208753155125, 61.0503855828316, 60.95675076207807, 58.642477835378344, 61.816185212904415, 56.72961634974326, 56.68260282085788, 48.54917210917319, 39.94699462767571, 46.027335197694846, 58.22687918140043, 70.85063534398233, 80.20209143238684, 67.4952124011132, 56.69283628463746, 52.87261639871905, 47.13433396431708, 44.49843845059795, 48.5563971150306, 48.29305702640165, 48.94724169085103, 44.86993789672852, 47.75377035140992, 48.84583273241597, 52.66835112725535, 50.0011472548208, 47.62654827487084, 43.860131540606105, 49.469379763449396, 52.35503612026092, 43.494692156391764, 42.17340254014538, 41.41045055081768, 45.1433192529986, 41.862954785746915, 51.18223567162791, 50.87709880644276, 44.2077398300171, 42.953126584329915, 42.5217874588505, 39.92039311316706, 35.80845086805282, 36.33028691814792, 45.01242976034842, 48.195899917233376, 56.53172885217975, 53.45499815479402, 49.81903160772016, 42.140803721643266, 39.18610188268846, 41.65033094344601, 42.86450847502678, 44.53051559386715, 47.69349921134211, 55.48232224679763, 61.70289931758758, 56.078130275972434, 39.04776773145122, 24.115684955350815, 20.491718899819162, 35.366380137781945, 52.15093558834445, 55.540592978077555, 59.20949566748835, 52.97705342692714, 56.1642498354758, 49.628981005760934, 48.54740312022548, 50.41790300799955, 53.53417119672222, 60.69466190953409, 60.59941891700991, 63.180377714095584, 62.356915320119555, 43.674811317074685, 46.893555348919286, 48.15902179287326, 67.90677101381364, 64.4104447672444, 60.71443065520256, 50.945908946375695, 52.94825146275183, 47.71399751786263, 53.70093860933858, 57.6848860709898, 67.16886335803618, 63.19150547827444, 65.8198033609698, 59.67814045567667, 66.46787305032053, 63.29464027958532, 70.09193128155124, 14.712211374313602, 0.18194269509084765, 0.1650332806692008, 2.971942371899082, 1.102764200299017, 20.120454795898933, 67.98539100154754, 61.340837094091604, 69.7397808874807, 66.74488652137019, 39.08180605980658, 13.969168355388026, 19.21278892024871, 24.819326785302934, 27.299841527015936, 48.6393670112856, 33.68564451894453, 37.959415912628174, 61.86374395124374, 74.98645305633545, 25.147454623253118, 0.8980453434971072, 0.3999697555217051, 0.048469708811852245, 0.25073270223313765, 0.0032564767330299105, 0.12396076363661598, 0.292082573737829, 0.4628865955577743, 0.2715797013332767, 0.1450528955507663, 0.4520936118018243, 0.2648730612089557, 0.19437265552340016, 0.3008388974253209, 0.3222034655271038, 0.4892648414017693, 7.114041024638761, 95.70154897628292, 62.70463735826554, 89.23504321805893, 49.17411550398796, 55.00408334116782, 45.77754297564107, 65.68026896445983, 46.469868767646055, 7.374059846324306, 49.16547844486852, 75.12732105870401, 81.97435948156541, 62.79966462043024, 71.93583749955701, 45.1669946793587, 0.4847023588034415, 0.40639950082667414, 0.49492099112079996, 0.2575902923220589, 0.8237416789897027, 13.159169497028476, 66.03269392444243, 72.5484803415114, 71.7283990306239, 69.54362315516319, 65.76493724699944, 60.774078138412975, 55.24376761528754, 61.18305190916985, 57.04092702557964, 70.4359466798844, 67.34451493909283, 76.1593907879245, 71.01572790453511, 60.06079904494747, 56.142433612577385, 54.02474595654396, 44.07047256346672, 55.83646128254553, 68.51493450903124, 62.71123870726555, 68.65270383896367, 61.646056329050374, 63.5596630650182, 57.03251354156002, 61.6122611876457, 65.46277746077507, 67.55347528765279, 64.09418406025057, 64.49612894365865, 64.8586069383929, 56.594573067080596, 59.874596288127286, 51.71696847484958, 52.16713889952629, 61.7490852263666, 65.17063933034098, 70.37973127057477, 75.84754666974469, 65.64547754103138, 54.28585421654486, 55.42260416092412, 54.07470126305857, 48.80016849886987, 50.969953075532, 51.87724044246059, 50.50103372143161, 46.3734608311807, 48.836254304455174, 49.207647846591094, 53.10771542210733, 52.09869746238955, 50.429568136892016, 44.63745117187501, 50.27612109338084, 56.89802331309165, 47.214958283209036, 43.50477264773461, 43.37847625055621, 48.0804959420235, 44.95635947873516, 54.70432404548892, 53.616066363550004, 44.894221290465325, 44.161506852796, 43.27770271608907, 40.903017443995324, 35.83033769361435, 37.23346364113593, 47.92391492474464, 50.42593994448262, 56.76004217516992, 55.274205207824714, 50.124725449469786, 49.341463427389826, 40.812038067848455, 43.3548165136768, 40.74520088011219, 45.62169936395461, 48.02512776467108, 51.29820446814261, 55.86827954938335, 58.862918961432676, 49.91982867640834, 36.97826247061453, 30.503859020048576, 40.27606187328216, 59.33063807026033, 60.442955570836226, 60.484477781480365, 55.838391088670306, 60.22444817327685, 52.96375659204299, 51.819099149396344, 50.46130011158605, 54.88259969219085, 62.740311314982755, 64.6819120068704, 66.88270291974469, 65.62264542425832, 55.548755430406146, 50.73069633976106, 48.551039157375214, 71.78484978214388, 65.13864063447522, 63.39273483522477, 50.63206049703783, 56.651427822728316, 50.78542517077539, 59.76489151677778, 63.371248091420824, 73.25076503138389, 67.70411783649077, 69.8130899860013, 63.997780046155384, 70.60969983377765, 69.01163208869197, 75.44976342108943, 22.017381652708977, 0.9292406276349099, 0.5598578517956119, 4.392980067960678, 4.9393922186666925, 20.220247737822994, 76.34904523049632, 65.99947929382324, 73.7059090214391, 67.58403839603548, 44.33599741228166, 23.945958114439442, 25.645899618825606, 40.10408947544713, 55.46327521724086, 67.75521063035535, 40.01129796428066, 50.00415963511313, 74.01764331325408, 88.72653930417954, 38.102841300349084, 1.1043244456091235, 0.5098700018659715, 0.2177040930837393, 0.3644958703267959, 0.17660867002221847, 0.33894049484402905], [0.06467169466158075, 0.08215159943868076, 0.024730277720898874, 0.16707040039041351, 0.10292022008328669, 0.01859496873352797, 0.018388596138045676, 0.08020970444645613, 0.041738833496046644, 0.09449253279355266, 1.4322518749583153, 64.21444392973378, 58.087631117913034, 57.0740867430164, 27.30551523547019, 44.081149255075765, 56.06542964135447, 74.90919805342152, 17.932115447136667, 8.01901517375823, 31.888557672500614, 62.95490026474, 59.3260802761201, 56.394987183232466, 54.30327738485029, 55.68087262492026, 3.9078167080879216, 0.202410894355947, 0.34791987269155444, 0.1396298817088527, 0.4685432662165934, 0.5836726448708965, 24.308661645458592, 61.761491683221635, 66.98790873250654, 65.8971054323258, 61.417907745607444, 53.837652821694654, 53.35789988117834, 51.341350540038086, 56.99634144383093, 58.81331666823357, 68.45732273594027, 38.17685642550069, 34.706562949765114, 93.3033412502658, 53.74274323063513, 47.14421049241097, 46.28636067913425, 52.3799745498165, 59.32271096014208, 62.096305201130534, 58.99359272372339, 56.11463969753635, 52.71935370660598, 55.45534810712261, 59.3120538803839, 60.64105095401887, 60.928827408821356, 59.76406389667142, 60.47272243807393, 57.376321054274044, 52.540744658439394, 47.278783090652965, 42.35538874903033, 55.710494364461596, 64.086045142143, 85.6503342043969, 99.1643036565473, 79.8943030449652, 59.88446497148084, 55.762979599737356, 57.76243525166666, 54.05019037185177, 59.60148949776927, 63.75405573075818, 56.71579391725602, 56.91146135330201, 56.73995571751749, 55.45793294906617, 53.36941988237443, 52.369678328114176, 50.25477947727327, 49.767734850606615, 50.950913890715576, 48.076718699547556, 46.86827959552888, 48.729048082905436, 45.243080815961285, 47.1156281809653, 42.27998118246756, 47.395508904610914, 46.73570740607477, 47.807459754328576, 45.787105714121175, 47.16858017829157, 42.183094716841175, 41.27905115004509, 38.01007724577381, 40.08878438703476, 44.40452514156219, 43.8410335202371, 46.4642519335593, 44.60166738879296, 47.41428529062579, 52.3183148907077, 48.31104109364171, 50.21043316010506, 51.79605130226382, 48.44781806392055, 43.713446663272, 44.31549518339096, 54.24171578499579, 64.22476368565714, 68.00843100393972, 38.25331126489947, 16.99065443008177, 15.43918836501337, 35.8025751575347, 51.99428789077267, 53.68025595141996, 49.72047029003021, 51.822413552191954, 50.69793278171171, 49.25978791329169, 48.30424754850326, 52.59142952580606, 55.81034614193825, 58.09563667543473, 57.10253569387621, 61.31783239303097, 26.990076265027447, 44.2094539057824, 56.77328017450149, 60.77260724959835, 60.76228749367499, 54.46902890359202, 50.70734254775509, 48.52418268880537, 47.10990152051372, 48.193083655449655, 50.87831474119618, 57.91160298931984, 55.7032811257147, 62.65691780274915, 59.265530647770056, 66.7041487847605, 62.1531246554467, 65.68224583902668, 4.560380943359868, 0.10002757167263378, 0.022167953016657024, 3.7918420280179674, 0.3833152185524664, 26.062986812283917, 67.62320718457623, 56.19340089059646, 65.51244251189694, 48.35935292705413, 49.302204424335116, 11.098173818280621, 14.951145495137862, 37.35770471634404, 53.12027092902891, 42.045709779185636, 43.665589824799575, 54.37040875034948, 52.892436135199766, 62.18553520018055, 13.210433894588103, 0.13140038136513005, 0.26558521654336686, 0.031407377494859605, 0.09427873297564446, 0.09072640625339362, 0.05792695315434568, 0.033864388092150616, 0.06185031541052365, 0.05126974102289927, 0.03964301228763596, 0.0242954864346933, 0.06201213233232979, 0.05860485669766223, 0.07028917992307294, 0.06750075011363915, 0.07792712249342473, 1.7716513790430564, 73.04870020958685, 65.25842197479741, 55.82361552023119, 29.733362351694417, 55.46522855758668, 46.30898883265834, 54.54240076003536, 17.609637783419704, 9.80518606401259, 37.06762583025041, 70.74622969473563, 65.96622543950235, 60.74210689913843, 59.40882659727528, 64.38790290586411, 6.275976136807473, 0.1368174656865097, 0.12148524243985453, 0.17303385861939, 0.17252490044601504, 0.7579081277212789, 26.724837749235093, 66.16093189485612, 69.68842137244441, 67.83875711502569, 62.938826391773844, 56.29287612053656, 57.21217378493279, 51.153994606387236, 57.3500725530809, 60.79330559699767, 71.75282755205708, 34.91449563733993, 36.78183409475511, 79.1449656025056, 50.33565482785625, 47.86746417322467, 47.81461415752288, 55.63831883092081, 61.66961016193513, 63.38416053402809, 62.0634671180479, 58.958867980587875, 53.84220669346472, 56.33605749376359, 58.83801191083847, 61.486937538270034, 60.72268724441529, 58.98769347898422, 57.87881589704945, 58.186090453978515, 57.10933708375501, 50.20972321110387, 48.9342390337298, 67.56524239816974, 81.35892391204834, 96.24684472237864, 88.42636815963253, 68.24742886327928, 55.74530147737073, 55.75700190759475, 60.773740814578154, 59.06351681678527, 60.04192067730812, 60.260608503895426, 56.450904492409, 53.916755260959754, 53.86799235497752, 51.92276739305066, 50.78466815333213, 50.40522198523245, 52.37987256819203, 52.439978968712595, 50.448485728233095, 50.930666615886075, 47.78881672889956, 47.547241872356786, 44.67605121674077, 46.35396272905412, 44.15287763841691, 46.992661876063195, 49.15230320345972, 46.510414308117284, 44.53856037509057, 46.02728028451243, 38.35853276714202, 36.224751626291585, 38.924444490863436, 38.471720603204545, 45.10308357977098, 46.14957978648525, 50.48163367855934, 45.91450821968817, 48.89401120524253, 52.46235609054566, 50.084752575043716, 49.87725919292819, 51.37704018623599, 49.18214067336052, 43.8472661664409, 44.37899051174041, 51.44029625000493, 55.867110683072, 63.973590789302705, 52.93344451535133, 32.18471230999116, 19.786743464008456, 37.53012034200853, 52.990581681651456, 52.12710326717746, 52.858884180745775, 54.34337185275171, 53.61628601627966, 51.008466828253965, 53.20907731210032, 56.030191067726385, 58.594981854961766, 64.81338985504644, 63.12266003700995, 65.85595192447786, 30.26639480744639, 46.96425214890511, 63.08001602849653, 65.95195585681547, 64.62218607625654, 60.63952515202185, 55.37553179648615, 53.92520796868109, 52.26618266874745, 50.22366331469629, 50.128632130161414, 57.41125760539886, 58.15834752974972, 65.75305246537732, 61.5778894578257, 67.97125477944651, 63.85457038879395, 70.98415282464796, 5.241312250014275, 0.32973098418404984, 0.08404636470180366, 2.507452354315789, 0.5229994005733921, 29.816430307203728, 71.46964811509656, 60.83213313933342, 70.20258918885263, 56.60470847160586, 55.24912949531309, 14.357729131175628, 20.979665671625447, 43.75163878163984, 58.747122749205566, 43.60445184092368, 44.35612309363581, 47.3007522859881, 57.10853692023986, 75.16119464751213, 20.123953550092637, 0.38173150030835984, 0.2514006236508008, 0.09704778076059396, 0.12201899887933848, 0.05849912890323228, 0.03116812823610681, 0.20237675747804104, 0.1630937299060245, 0.16308928659606367, 0.17023380725614487, 0.26544116137008517, 0.0971904110103365, 0.16717204493620705, 0.24262255838801786, 0.2758973422310045, 0.1700522750616074, 2.5052570527599705, 86.90837952398485, 72.92140360801451, 70.9817680235832, 37.56727303228071, 61.71902810373614, 77.89878937505907, 81.85382504617014, 25.315412475216775, 17.18010098703446, 41.991871326200425, 76.20970695249497, 68.7339125910113, 67.10790972555837, 64.69548733003678, 73.20193152273856, 6.710994445508526, 0.30585658946825617, 0.8912139842587133, 0.37337519709141026, 0.8893250565855735, 1.2273904032284215, 30.16641947530931, 67.79994133980044, 72.5434361734698, 69.68434995220554, 66.29359429882419, 60.65503028131301, 59.58819266288512, 53.43086381112376, 64.43935263541438, 63.035348076974195, 77.55709601986793, 43.79585173822219, 38.68370902153754, 83.53816140082576, 50.47692683435256, 47.67744495022682, 47.56686549032889, 55.50424045132053, 62.994982965530895, 67.94972881194084, 64.74901983814856, 62.548099487058586, 55.55047342854162, 60.99564498470676, 63.95743062419277, 65.72907109414378, 66.09509883388397, 63.95645787639003, 61.293164607017275, 60.025423188363355, 60.08571001791186, 54.038034946687766, 58.51920950797297, 81.24059384868991, 89.40853749552082, 97.96718059047576, 81.72628525764712, 63.42900106983801, 57.80125494926207, 62.4220698110519, 70.37469494727351, 61.66617808803436, 62.33398122172203, 65.97490172232351, 61.81091746976299, 58.84068304492582, 60.331297459140906, 56.83521439952236, 56.8092522313518, 53.968169689178474, 53.69551397139027, 51.27177946029171, 54.00756205281904, 50.27090434105166, 49.58896106289279, 51.23735673965947, 48.74687525533861, 50.52827850464852, 48.17053394932901, 50.21514784905219, 51.289630166945926, 48.81488130938623, 45.914390548583, 47.71936332025836, 41.43423188117243, 39.1453484565981, 41.21142556590419, 40.924088416561005, 50.28040824397918, 49.08662311492428, 52.04858133869787, 50.7023689823766, 56.77302522044028, 57.1922363773469, 51.399954672782656, 55.31363679516701, 54.95152358085879, 49.88217784512428, 44.83608391977126, 47.16134732769382, 49.155586227293945, 52.45783359773698, 62.490146467762614, 58.91154458445888, 43.99808522193663, 34.851431769709436, 43.857174073496175, 58.14630585332071, 54.553093141125096, 56.415936562322806, 58.27850149523828, 57.78064681637672, 53.915131399708415, 58.22785585157333, 57.51604372455228, 61.15616013926845, 65.79082096776655, 65.66545024994882, 66.06994075159874, 37.8108286857605, 51.27368965456563, 62.56214157227547, 68.58876136041457, 66.41616052196872, 61.53950122094924, 57.15078476936587, 55.58237798752324, 53.41937911125922, 55.082056137823294, 54.517760430612874, 65.5889287302571, 63.451366424560554, 72.75912730924546, 63.69507112810689, 71.87441318265854, 64.13249384972357, 71.55402614224342, 8.972778704858596, 0.5330334976315498, 0.41873069720402845, 11.948770188516187, 2.073469061043955, 35.20079728095762, 80.82345762560445, 68.18554170670049, 76.7377285803518, 58.51516554432531, 60.38442204075476, 20.882581126305368, 24.414253811682425, 49.54276730937343, 76.06461063508065, 58.19849691083355, 55.804878357918035, 74.59469456826487, 65.92447573138823, 87.13525725949196, 28.55425669300941, 0.6447073600945935, 0.3297060097177183, 0.12208564086787163, 0.3225597576989282, 0.1338696053191539, 0.09913169313222171], [0.06724748910675127, 0.15097107798341783, 0.3300406982100779, 0.2045233664853919, 0.08073036078243487, 0.05756095464852068, 0.3020983766163549, 0.07654228067446141, 0.15476155845868975, 0.05976841401969714, 0.08577375507522976, 60.16636179339502, 55.425891107128514, 68.51540519345191, 47.76331347803916, 37.70182601867184, 43.08291781333185, 39.90924573713734, 29.921059531550256, 3.180234446640938, 25.76907184816176, 64.25598575222877, 62.919214540912265, 64.12154259220247, 52.755710155733176, 63.48341218886837, 19.652712152850246, 0.081506407849731, 0.59483993918665, 0.1974008631922545, 0.41764055408777734, 0.20536427055635761, 12.730887859098374, 57.57490281135806, 68.28596222785212, 60.27177941414618, 59.82744939865605, 54.28415190789008, 52.442579500136844, 53.45635529487364, 57.35396354429184, 70.08840899313651, 44.606523283066295, 23.43770915462125, 45.29567587760187, 39.90379364259782, 59.66687540854178, 73.023801003733, 49.509282035212365, 51.010035776322894, 52.798091365445046, 58.597264674402055, 60.5359745794727, 54.481258853789306, 58.03480855880245, 56.9734348020246, 62.88605874584567, 66.19485255210631, 62.61900025029337, 59.55961427380962, 59.392058464788626, 55.50389528274537, 46.48257332463419, 45.93170781289378, 65.83298252474877, 98.85925308350595, 142.86382982807777, 115.9270703408026, 70.77987578607375, 57.800348881752264, 58.32060813903809, 65.94959458997174, 57.87634088147072, 62.32898804449267, 60.64944090381746, 59.27192803352111, 73.58224453464632, 62.54818970157255, 58.114742540544086, 59.98694473697294, 64.69223176279377, 64.12907354293331, 61.82754439692344, 55.216154129274436, 44.74495157118767, 45.80849439867082, 42.360699638243645, 46.684057635645715, 46.12677904867357, 45.73100797591671, 43.228837828482355, 39.123979383899325, 43.93296995470601, 46.93837235050817, 49.1002651183836, 53.54356135091474, 54.45777954593782, 50.952969212685865, 54.13717285279305, 51.84942299319852, 50.457989631160615, 47.53295267781904, 51.21808613500288, 54.580475207298036, 53.62096540389523, 57.079107376836966, 59.498688097923036, 56.93165371494909, 55.20805835723878, 55.521624395924235, 53.1112337881519, 52.12170216345018, 48.47309773968112, 46.407597218790364, 68.05014933309248, 90.5363993490896, 55.46372628981068, 27.935642042467673, 22.82223632258754, 42.198105627490634, 55.091842451403224, 51.05253073476976, 56.40159245460265, 47.95087337493897, 51.705134684039706, 52.670849677055116, 55.55528617674305, 58.10738417410082, 66.48142876163607, 61.26270348025907, 66.31599887724846, 40.04231606760333, 41.27210855484009, 60.2908185989626, 60.71438750913067, 62.97936408750473, 57.47141891910184, 49.63385258951495, 49.08320280813402, 51.56687505783574, 49.7740694784349, 47.23008686496366, 50.130361895407404, 54.943957328796394, 58.31936867006364, 63.33617425733998, 62.446643460181456, 66.49847538240495, 53.480901487412, 0.5282088597455333, 0.03140087149316265, 0.2854929612048211, 5.630380972739189, 1.5589137880071517, 58.001750822990175, 59.82669630358296, 63.949177957350216, 57.49470603081488, 66.28797746473744, 45.41327638010825, 5.003902460298231, 22.555336683027207, 18.237830861922234, 28.101605369198708, 55.84296457229122, 30.198306383625155, 32.477140695818015, 54.21221171655963, 66.98177414555704, 9.005661895198207, 0.4219179294042049, 0.22984030476260572, 0.20001173680347784, 0.08636277709757129, 0.06324946392147292, 0.13038854775649886, 0.07611992874092634, 0.23202189334457923, 0.15314823857718898, 0.12586391756250975, 0.03454971119701382, 0.08404176051337874, 0.28731910031168695, 0.06672425105446769, 0.2255394258686612, 0.11727158265608935, 0.114758170750593, 68.07103203188989, 63.499642956641416, 68.99003551852319, 40.35436022666193, 53.462740913514175, 40.15208359687559, 47.94859840023903, 37.206654241008145, 4.4154836862317985, 26.48584577345079, 74.25000452226209, 71.10672689253285, 69.22968449131136, 59.40146430846184, 72.22836002226799, 25.146779975583478, 0.15404468402266502, 0.4822156374012271, 0.17670956380184621, 0.25069913226029567, 0.15219836615987364, 15.184251954478604, 57.27032684510755, 71.56457731800695, 63.699927022380216, 66.90488000069895, 55.249533499440844, 53.811945607585294, 55.66263752598917, 56.90320084171911, 71.05060562010735, 47.18929421517157, 32.993295192718506, 54.68446116293631, 39.53125476837158, 60.759726185952466, 69.17192366815382, 51.09850875792965, 49.911430881869414, 51.93951199131628, 59.554456357033025, 60.53292689784881, 54.94227070962229, 58.878714346116595, 57.37426965467392, 59.05720572317801, 60.59983468824818, 59.99439331793017, 61.46657259233537, 62.58620531328263, 59.429175853729255, 51.80189955619074, 53.940536591314505, 74.91706632798719, 106.84612443370204, 130.43612157144855, 92.94839812863259, 59.986379915668124, 58.252770746907885, 55.93186901461694, 66.22878105409684, 60.54251317054995, 63.20379818639448, 62.61960821767008, 62.05117048755769, 70.05994043042584, 65.36436127078149, 62.45533543248331, 59.69113526805755, 56.756582644677934, 55.4978116866081, 60.757890516711825, 59.02122582158735, 50.12917733961537, 49.77995695606355, 43.20996730558334, 47.28684748372724, 46.61966800689698, 48.12153177876627, 44.91129144545525, 46.270910463025494, 44.490907499867106, 48.28173314371417, 48.35540310029061, 50.934891008561664, 48.06690492937642, 47.84707569306897, 49.58257936662244, 48.71816350567726, 48.37794103930074, 45.861230665637606, 53.46305470312796, 58.41959307270666, 59.27952174217471, 60.54306622474425, 63.349247517124304, 58.13045947782455, 60.777820079557365, 59.10389369533908, 57.60674853478709, 51.92835677054621, 51.213971568692116, 44.954833676738126, 54.7793629092555, 78.88880345129198, 70.3179931640625, 52.74360572138141, 29.73147765282662, 43.068781591230824, 54.005824442832704, 53.73901305660125, 56.599868266813225, 51.28807690835769, 57.59251425343176, 57.037118404142326, 57.20328569412232, 61.6145283176053, 67.34680560327345, 65.0528819330277, 70.84346525130734, 42.71812954256612, 45.229583940198346, 63.677102750347515, 64.10968918954173, 66.235135293776, 59.919221093577725, 54.78656830326204, 51.84996035791213, 54.32828641706898, 53.260805529932824, 50.77616053242838, 54.22290802001954, 56.01444667385471, 57.92236597307267, 62.00951099395753, 66.08585772975799, 70.72780239966609, 58.44803025645595, 0.24019087274228376, 0.26269822952247435, 0.2623810078347883, 2.483019910512432, 2.5564925228395774, 63.09948275166174, 61.26433910862092, 70.43669193021714, 62.84539553426928, 69.5121971253426, 44.99545766461281, 9.327768894933886, 25.52617515287092, 19.271028272567257, 29.937788440335183, 60.749316215515144, 35.419794974788545, 37.229600106516195, 58.72205095906412, 77.76400104645761, 12.026312505045246, 0.4865972619623908, 0.06901015782909048, 0.10097549822662147, 0.09113642417134778, 0.03473452607830686, 0.15998232508859328, 0.1669328416427297, 0.17872062121187487, 0.2551928201630231, 0.24918684405424904, 0.1989676968585099, 0.35964680955775324, 0.3841281297706789, 0.24142795152241187, 0.23086445706505931, 0.2984210626492578, 0.2258100540887925, 80.61775284428751, 70.76525319007136, 86.98827035965459, 64.01914911885416, 54.51336345364971, 59.64189775528447, 43.951126606233665, 42.844696583286414, 11.64726936048077, 39.46435090034239, 80.08204337089293, 77.9705765939528, 73.74419919906124, 66.28535732146233, 78.94929424408944, 23.724544240582375, 0.2909947288853507, 0.9671801821358743, 0.2841553716890274, 0.6723305294590612, 0.3982992548375361, 19.672016097653298, 62.44392133528187, 74.72125376424482, 65.76330946337792, 72.11067322761782, 60.407320837820734, 57.5825475108239, 62.14002786144134, 59.99247135654573, 77.01041959947156, 46.10843020100748, 29.54205070772479, 50.31916910602201, 57.92604515629431, 62.9326133574209, 61.53258215996527, 54.5637619879938, 52.10753456238778, 55.87007991729244, 58.94103688578452, 61.182004636333836, 58.86918690896804, 66.85751345849806, 66.32119994009695, 66.44610389586418, 68.5897341082173, 68.19963870509979, 66.19374644371771, 62.31600892159247, 61.036327808134025, 54.65701633884061, 59.30269902752292, 82.6523490105906, 109.324748592992, 118.69322776794435, 85.12730183139925, 62.46911864126883, 62.8043322409353, 58.511239251782825, 66.82651888939643, 62.952762572996086, 65.89795266428303, 68.59309165708481, 62.75913869180987, 74.28190123650336, 68.20935833838679, 66.54468090303483, 66.1473055808775, 65.99066965041622, 68.02067664361769, 64.79169914799353, 63.36904764175416, 50.97140043012558, 51.085804200941524, 44.50383955432523, 48.46805357163953, 49.64704744277462, 47.78621619747531, 43.84161795339277, 47.97229736082016, 48.14605835945376, 50.62256836122083, 52.41235371558897, 56.96168338098834, 54.47956438987486, 53.67264263091549, 55.05488587963966, 53.060490085232644, 55.20160213593514, 48.32225514996437, 57.50262137382262, 67.4241861220329, 62.5733164048964, 65.74605887936008, 64.75677828634939, 61.83448699212844, 62.630559475191184, 61.199490562562026, 57.66620382185906, 54.13650604986376, 52.241836517087876, 47.2134050246208, 54.17958936383648, 76.33117491199125, 67.51010956302767, 62.92424694184334, 49.29955290209863, 48.141649615380075, 59.24999806188769, 55.67442032598681, 60.82650846050632, 54.59991839624221, 58.5909535807948, 57.37401470061272, 60.05147949341805, 64.13435697555542, 68.81101069911834, 63.869793107432706, 69.33943240873276, 39.55628733481131, 45.201291884145434, 65.30891856839581, 70.41219280612084, 69.28620584549444, 62.99624596872638, 57.29874833937615, 54.98260051973405, 55.668101387639204, 54.860540282341745, 51.76677865366782, 55.55395257088446, 61.50732209605556, 65.90477758838286, 69.2038360718758, 69.56649841800814, 72.3735269423454, 59.438303209120235, 0.9045181122999039, 0.28610914104407836, 1.0454746744325085, 12.306426609716109, 3.025208894283541, 73.58603354423278, 71.72752826444565, 77.59309553330945, 69.59999545927971, 74.69239296451693, 57.36387145134711, 11.326860747029706, 30.96144860790622, 25.27255273634388, 40.40887332731678, 77.96643457105084, 42.596084994654504, 52.73601985746815, 67.71125655020437, 94.97768340572235, 18.909819164583762, 0.5951542803837407, 0.36439425642451934, 0.21900429750882813, 0.25669154861280996, 0.12785280438800975, 0.23510942686228986], [0.11068318820288105, 0.286520530259417, 0.2848958109896029, 0.37560993685357036, 0.03762589129168661, 0.09168924853926705, 0.10716817762342193, 0.05490437240129518, 0.2962177018484762, 0.05623307912760685, 0.14008288482023826, 39.40943771792997, 66.39541118375718, 53.0358576005505, 56.62250034270748, 24.469674941032167, 38.781023025512695, 3.7047749709698463, 31.259050599990356, 9.718547771053931, 7.090050337776062, 53.75536934021981, 63.82335616696266, 58.62590974377048, 58.411834624505815, 55.76598805765952, 16.976018105783773, 0.2574576671806074, 0.12085268364077616, 0.13797804292651916, 0.33617304818284127, 0.3553299653914667, 7.417554028572575, 47.49691786304597, 68.34591957830614, 68.64456099848594, 63.621573755818034, 54.882823267290675, 46.012045798763154, 50.651762562413374, 54.391981786297215, 66.8587137037708, 61.11637946098082, 54.82437210698282, 58.934462993375725, 24.228717857791533, 47.91718021515877, 84.99976204287621, 57.49879314053444, 49.977499285051906, 51.13977601451259, 49.40013424042733, 53.93973250542918, 55.070340018118586, 59.26834690955378, 54.98746818111789, 64.85726941016414, 57.67031446579964, 64.09322700192853, 52.81835432975523, 50.587541595582046, 42.97116948712257, 51.56106210524037, 64.68282984149072, 86.70420446703511, 105.4887725460914, 91.20277866240471, 57.01996980174896, 59.38948931232576, 59.97607584922545, 60.58842059104674, 61.27817330821868, 60.977711908278934, 58.84226768247543, 58.52570495297832, 58.19157000510924, 69.75124205312422, 59.346723710336995, 57.33826621886223, 54.906714424010254, 58.99944097765031, 60.32220148271131, 58.35208123730075, 62.188347539594105, 56.982158153287834, 49.724835888032, 36.91510054372972, 33.866406948335715, 47.59602046781971, 37.688941032655784, 25.047981354498095, 32.50520721558602, 51.66943719310146, 46.65818568198912, 52.993503847429835, 61.67363451373193, 62.459069528887355, 58.162524853983236, 62.00557685667469, 59.58325832120834, 57.29103695961737, 55.07573327710552, 56.161512021095525, 56.36989578124016, 56.49046944033716, 60.01723327944356, 59.927367856425626, 58.199410823083696, 56.564284524609974, 57.33874082565308, 55.65387887339438, 55.65449468551144, 57.297665765208585, 53.22007956043367, 54.16983442921793, 75.78030155551049, 110.3956497869184, 81.5697277745893, 38.81989371392035, 23.81938126779372, 49.37909464682303, 52.574010279870805, 54.2354517598306, 55.47952951923494, 58.59094181368428, 57.60077084264448, 60.13867770471881, 61.197745107835345, 60.12808730525356, 58.816034870762984, 57.72526687191379, 46.45675628416, 53.01537498351067, 61.70514683569632, 64.65676176932551, 59.21927413632793, 60.19537164318947, 51.254783830335064, 48.81011955199703, 48.77024473682527, 49.07289874169135, 48.13107098302534, 53.51233536197294, 54.690403553747366, 59.31330119409869, 60.761008800998816, 62.00844018690048, 71.54999394570628, 30.9835825427886, 0.18698401328536773, 0.05541234232124783, 0.08750495290563953, 1.5610275778078264, 7.15739155007947, 75.64031216406053, 53.93519432313981, 73.84286249837568, 46.29628427567021, 73.5236051005702, 9.547205894224106, 11.04427162678011, 31.949034737002467, 29.737170973131736, 50.60998147533786, 61.64555426566832, 29.959557594791537, 36.185865248403246, 49.7274560313071, 59.64526707126249, 3.7081553186139757, 0.2106412067528694, 0.00799152710016877, 0.16166715161694636, 0.15996816778375259, 0.281882603322306, 0.07796771749253235, 0.04433053575696484, 0.10719802440895189, 0.08936910529530818, 0.13171636199037876, 0.07814174202541191, 0.07358648363621005, 0.13923246593725297, 0.17920540165035956, 0.22065002290952593, 0.18725137797094163, 0.0775881592304476, 45.72470080467963, 72.47287273406982, 62.13887076224051, 44.85617822216403, 33.1709118812315, 44.013880606620546, 6.161703275096032, 32.44234927238957, 12.136203588977938, 8.999916603488307, 54.711011686632716, 73.51335202493976, 64.99113205940493, 66.7374183285621, 64.2630656303898, 21.426758996901974, 0.016887889266194358, 0.16369962884533792, 0.01860051137966014, 0.1435118177605252, 0.27343844514219995, 6.651066022534525, 49.70972691812823, 73.68572450453236, 70.32103692331623, 69.07920668202063, 56.46634686377741, 53.754427971378455, 52.34608919389787, 56.805749554787916, 65.46413852322486, 63.461317477687714, 59.93415747919391, 58.35068879588958, 27.43425723045103, 54.49619916177566, 80.12005898260301, 56.7362137763731, 50.81068915705527, 50.44574791385282, 50.97304390322778, 58.24547513838738, 57.05662435100925, 58.60691370502595, 54.80411698741298, 60.678042827113984, 56.37248454555389, 63.00194517258675, 52.23283859991258, 54.586488200772195, 49.56021008952972, 56.56270380943053, 71.52735402507167, 88.58416511166482, 87.37768327036213, 74.17759756888114, 56.10179393522201, 62.937900712413175, 62.97846586473527, 60.90305351441907, 61.003540715863636, 60.43690335366034, 62.6147876247283, 69.53609220443234, 62.712172231366566, 69.33955792457827, 54.36738460294662, 57.04729303236931, 56.66748992858395, 58.40315441931448, 57.316885379052934, 58.50037428640551, 60.88492039711245, 55.92476560223488, 56.545708179473884, 40.42972464715281, 38.28636507834158, 44.19443907276277, 37.655283174207135, 30.61586230031906, 33.61988990537582, 51.80537869853359, 50.339502672995295, 52.72069515720491, 62.21252895170643, 60.068961497276064, 56.82473382642193, 61.94558812725929, 56.39157472118255, 54.1200360175102, 57.3562934321742, 56.40806828775714, 59.53210669179117, 61.04498055673415, 69.06234833502, 62.25980920176353, 60.66948421539799, 61.05685749361592, 61.514343138664, 59.790641876959036, 54.61556865322975, 57.64894539310087, 54.208140296320764, 53.52974676316785, 59.746338705862726, 88.59346897371354, 101.804058782516, 65.77276237549322, 29.417250694767123, 50.47338885645713, 50.94999605609525, 54.105942941481075, 59.60689452386672, 59.92574399517429, 58.69256650247882, 62.20962247540874, 64.42966830345893, 59.35714544788484, 58.424652930228945, 62.19233266768917, 48.69604526027557, 51.48421502882435, 62.39459360799482, 65.5667124256011, 62.93536293891169, 61.25762008851575, 55.4962819622409, 51.79610229307606, 53.35005906320388, 52.98824787139893, 50.44038603382726, 55.725968114791385, 56.7799089800927, 60.90143749790808, 63.87235441515523, 66.25232311987108, 77.11529593313895, 35.29129812794347, 0.7896228194717438, 0.0344803917311853, 0.2395828594002993, 2.0175218437948534, 9.940775536721754, 80.19285032826086, 58.11191843402002, 78.56702004709553, 50.69329261779786, 69.9429125939646, 10.643458347166739, 15.812610753120916, 35.19778490066528, 31.248393520232174, 49.68802052159464, 65.97840832125756, 34.177992190084154, 40.42430393157467, 56.96088713984336, 62.59113181021906, 3.393470914133134, 0.15166022003658358, 0.09185662342896385, 0.10610563665508263, 0.1337881395292859, 0.24129285957784424, 0.20816835154208446, 0.182184012786996, 0.16276253477459954, 0.3599532447274654, 0.28750317591813307, 0.12426095518974528, 0.2810184255002007, 0.2274647273964459, 0.3913299691292548, 0.2832229813981441, 0.2805392221818047, 0.3124838935271386, 58.0729575310984, 85.46165250962781, 69.40786207875898, 68.82777490923482, 37.48025132763771, 52.75816163709087, 4.201168321794079, 40.538699857650265, 19.27094001923838, 15.508015175019542, 66.16202231376403, 79.51633561042048, 69.07415466923868, 68.03958246784826, 66.65611543963033, 21.487279207475726, 0.32759044259305925, 0.6123587152650279, 0.1415008216375305, 0.3582942353621606, 1.219423824260312, 9.581130473844468, 52.86155139246295, 73.03802351797782, 73.22337119810044, 70.76179365957938, 59.40837944707563, 55.79076567003804, 54.75332621605166, 58.91208587154266, 69.28482517119377, 59.38253102764007, 48.0981779867603, 63.652054494427105, 28.724548355225597, 56.675103249088416, 81.77922941023304, 55.5245897077745, 54.151426745999245, 53.67583544023576, 52.53008757868121, 59.22690706868326, 58.705804501810384, 66.02823811192667, 59.284110915276315, 68.20419649924001, 61.04332531652143, 64.46085506869902, 55.39749706945112, 56.81527699193647, 52.63768603724819, 58.16187766290481, 69.4527889067127, 86.39261922528668, 83.16614027946227, 67.23752837027273, 58.600579077197665, 69.53093821002592, 63.01888196699081, 61.001210827981275, 63.930142694903964, 63.71520073183122, 64.73849219660606, 75.38880194387129, 65.76945189506777, 74.10719886902841, 56.628768290242846, 64.70710931285736, 60.37631057923841, 64.09323876903903, 61.81776985045403, 61.88786260543331, 63.75320457643079, 61.55638310217089, 61.27798503445041, 45.585860667690156, 40.194327523631436, 46.138887405395515, 41.594923542391875, 33.45963754961568, 37.96756659784625, 52.728881143754535, 53.29531062033869, 57.31468100701609, 68.24506759643555, 64.84663978699716, 62.6488769438959, 66.79530466756513, 61.83578529665547, 60.147797215369444, 61.466039149991936, 60.892259151704856, 65.27605695109214, 66.83892142388129, 71.11104934446274, 66.28031315342074, 61.82242962621874, 63.78527779732982, 69.50300308965868, 64.64966227931362, 55.99314035907869, 59.42084473948325, 54.858218239199736, 56.3176655000256, 58.9188245034987, 80.733352938006, 92.81590830895209, 77.71183352316581, 37.53714138461698, 57.18678428280739, 53.81313800811768, 54.88274089751705, 62.55646198026596, 62.376472257798724, 60.039826131636104, 64.28670183304818, 64.91593237846129, 64.61427465561898, 60.78961072429534, 59.13917149266889, 50.142858566776404, 52.13346535159696, 67.74796993501725, 72.27061179376417, 68.03803705400037, 67.03220013649234, 55.02720179096345, 52.85785651976063, 54.230992024944676, 53.4178376197815, 51.937421368014434, 60.6849971894295, 60.64271011660176, 68.14594930218112, 68.70528713349374, 73.58127178684359, 74.23482494969522, 39.93381546389672, 0.823759574803614, 0.13056051917374134, 0.34902585850607964, 4.916911644320335, 9.726461152876578, 87.61330004661315, 63.27933911354312, 85.16160688092633, 59.760141526499105, 86.63427645160307, 18.222945467118297, 18.66564573780183, 41.596280682471495, 41.96221036295737, 78.87686375648745, 74.8536023785991, 40.354599491242446, 52.2465943521069, 66.82964894079393, 84.9530387693836, 9.122396534489049, 0.3763658204866994, 0.22314998231107191, 0.22879939045636888, 0.4902810110680519, 0.406676487576577, 0.21633728497451354], [0.029072477482259277, 0.07120529084556526, 0.023825648541171706, 0.19223487184893703, 0.21146898007681295, 0.035401654594968406, 0.03288030984901613, 0.018552600240875638, 0.17853990107053713, 0.13314637235335766, 0.5605397926222894, 17.934019757855324, 71.24975219849618, 49.22136045271351, 60.172790558107444, 28.949590421492054, 44.50116449786771, 37.1984290307568, 24.820285804810066, 11.434467050337023, 24.935752537942705, 46.329542052361276, 63.84272090850338, 60.710186650676114, 60.17844269352575, 63.812475512104655, 30.784787016530192, 0.12060172089766111, 0.3174391340824866, 0.03885209162328993, 0.4745163618316574, 0.28437441154833765, 4.324320448983101, 48.83770165904876, 67.10233995991369, 71.44139920511554, 63.86365459811304, 63.22310017001245, 54.20634385078184, 48.171404715507265, 51.95125556761219, 61.86068842487951, 70.11637549246512, 67.31967849116172, 52.1945954907325, 54.1120736060604, 56.02990865707398, 56.338779618663175, 63.4069416599889, 48.50239784486833, 49.865578374555035, 50.802711056124785, 56.23531533825783, 58.38084005540418, 60.43278486497941, 66.80012133813673, 60.4242419427441, 54.84979691043977, 41.4196288970209, 41.63228019591301, 46.59446285616967, 54.169395123758626, 61.368897730304354, 65.25663337399884, 73.42163916557067, 62.183338672884055, 52.41166337843865, 60.47520529839301, 61.55103691162602, 56.35882293024371, 60.3899408155872, 61.29019145042666, 58.4069198946799, 54.06556998529742, 56.84938592295493, 54.56758237654164, 57.43071648382372, 63.10775110798498, 65.88929207094255, 58.29775641041418, 58.8289120120387, 59.891082009961536, 62.395193730631185, 58.95286675422423, 57.52171154945128, 53.157243190273164, 45.81239715699227, 21.98949360078381, 30.972293961432676, 51.68361263890421, 15.911480957461944, 46.72783128676876, 48.37078663610643, 49.577648947315836, 53.978207034449426, 56.204869900980306, 58.41578052889917, 57.742850857396284, 56.65673086720129, 54.58882985576507, 57.1106550001329, 55.47079440086119, 53.365277859472464, 48.68716501420545, 48.92766121895083, 50.740168863727206, 55.503279470628314, 53.308780039510424, 55.603845119476325, 54.923113853700706, 54.934237695509395, 50.73844694322156, 52.81901721031436, 55.523624804712114, 58.054216446415076, 52.71480375720609, 66.89639983638641, 102.59221200020083, 86.50834483485069, 29.191351590618012, 28.92390674160373, 58.53945286043229, 53.27025844204811, 57.666670583909564, 54.48337301131218, 60.56864007826775, 59.396161263988866, 62.1228753366778, 52.86754477408625, 51.92110038572743, 50.88577116689375, 52.93818273851949, 50.461606056459495, 57.802702303855654, 62.751133134288175, 61.19911009265531, 53.18871628853583, 50.92130784065493, 50.74185156053113, 53.134866068440104, 50.30524469191029, 52.674403344431234, 55.12442558042465, 56.88900970643567, 59.814533033678615, 67.27378676014563, 59.672049014799065, 75.2325660951676, 11.732823118086785, 2.625039863970972, 0.06300697411080042, 0.09796435133584085, 0.5528787908054168, 18.600599112049228, 68.47654234978461, 53.936457326335294, 61.99540615081788, 48.76065454175396, 51.68664855341758, 4.305803429695868, 32.15251553443171, 19.707621412892497, 24.940371128820605, 42.620113434330115, 50.36600220587946, 26.307187695657056, 42.73759626573132, 54.624672474399695, 42.45561707404352, 0.5572820803330791, 0.14159380938977967, 0.027063689607706283, 0.09002450117540937, 0.23363052476798338, 0.024625758430169477, 0.004537372151389718, 0.017422994020425023, 0.030410919270868746, 0.08545592817808352, 0.11237960564152849, 0.12403191022214391, 0.04927226635176809, 0.10304584318111021, 0.14116164386993454, 0.14442212939743074, 0.3719864329022746, 0.2684012944659879, 21.798833070262788, 80.07011936556908, 53.537815078612304, 55.83683390771189, 31.665549355168498, 51.04626670960457, 21.141253594429266, 32.00654648965405, 14.849508058640266, 29.20900617876361, 53.61208123545493, 69.18467137121385, 67.89231315735849, 64.54786892860167, 66.47139533873528, 31.55289103907924, 0.4340860103407214, 0.6079458036730366, 0.1015713231097306, 0.697214107119268, 0.07478700470059149, 4.150737918192341, 53.952072281991285, 74.02328368156188, 68.86694369777557, 64.82330952921222, 66.83834875783613, 60.115845587945756, 53.61044168472291, 56.65788796640212, 63.413374347071496, 72.25687565342074, 68.28004729363226, 56.7447998446803, 54.90957383186587, 58.66813405867546, 52.745712034163944, 60.14264322096302, 49.512223812841604, 52.58468304910968, 53.05608918589931, 59.72600513888944, 59.25017849091561, 58.85563904239286, 64.0295865458827, 57.224564552307136, 52.05581811166579, 41.84048744939989, 43.86508941650391, 51.98989875854985, 63.04314574887676, 70.46278353660338, 66.02173482218097, 66.54095465137114, 57.40206749208512, 56.63906451194518, 60.452424172432195, 62.42882021011845, 60.60192138917985, 62.918253560220045, 58.9101246864565, 62.409808481893236, 57.35691708903159, 61.10307085898615, 57.466512034016276, 56.20209678526848, 59.00803489069785, 60.69076307358281, 55.58781439258207, 61.5103344763479, 58.98325335594916, 57.4311165655813, 56.94695095862112, 60.845782987533084, 61.5026544755505, 51.9075878204838, 30.714107867210146, 36.61333691689276, 51.30440965775521, 23.457373957480154, 46.873159024023245, 51.02141457219278, 55.3676046863679, 56.03950277451546, 61.51284479325818, 58.92509245103406, 60.051401046014604, 57.933089733123786, 58.90486478805543, 53.85416600012011, 55.10124437270626, 58.285502925995864, 61.601392299898215, 57.64232443225, 56.27613544464112, 54.90542004185339, 56.17994323853524, 58.911807383260424, 58.84540950098346, 55.47783113295033, 55.42122740899363, 58.4351295809592, 54.34009275128765, 56.96503700748567, 55.87333940690564, 58.39361521505541, 81.78482271009877, 90.21176045940769, 38.55535730238884, 31.717803170604093, 61.52708299698369, 54.07027290713403, 58.07542077956661, 56.58076632407404, 63.317158606744584, 60.91027852027648, 60.94237135302637, 55.54958697288267, 52.791195838682114, 49.405358837496856, 51.62023498165993, 48.10181794628021, 60.44195144407211, 62.39830024780766, 63.51255539924868, 58.327562501353604, 54.30466982626147, 54.44620855392949, 60.02719217731107, 53.55379873706449, 56.305882700027965, 55.078828027171475, 61.11748164699924, 58.859730074482584, 69.745774269104, 62.2447669121527, 78.5900757389684, 14.944080325864977, 3.899947207781577, 0.06577050989313472, 0.5575144194787549, 0.6595271777722144, 22.948195395931123, 75.35664635319864, 60.15748939206524, 70.26959896087646, 48.832312322431996, 56.46816684353737, 8.256004779569565, 32.399713108616496, 25.025716020214944, 27.457424709873816, 50.01356940115652, 63.67030136046871, 30.0792859831164, 41.44428883829425, 61.797271543933505, 48.12881954254643, 0.9487028155596027, 0.08702370413248578, 0.07420893007468793, 0.05199203553098825, 0.06801065057516098, 0.09225170263239453, 0.06761892683683865, 0.18333950320318823, 0.2386485845331223, 0.14770136875731332, 0.1505401228824931, 0.15733933707158412, 0.25369318772948557, 0.09045554820688502, 0.20113132833953828, 0.22832216364481758, 0.46813628966769866, 0.5587499660830344, 29.294033358173987, 91.62135047297325, 60.99517037791591, 75.65912385140696, 44.130139658527995, 59.305323093168205, 45.327600048434356, 32.264791419429166, 16.751503598305487, 35.894644952589466, 58.370202587496856, 79.16774672846641, 71.59176718804144, 68.69134702990132, 75.10166875777706, 39.12674857724098, 0.401391277630483, 0.7475320490137224, 0.14135572458467177, 1.687848224274574, 0.9248296772280048, 7.02024930907834, 58.832716711105846, 73.70274759108021, 72.3284589090655, 70.01129519554877, 70.7872498419977, 63.7148908645876, 55.38005036692466, 61.43948862629553, 67.86564104018673, 77.89542398145123, 71.84035916482249, 57.04082504395516, 61.22122049331666, 59.40285282750284, 62.67134428024293, 63.310059116732695, 49.04854082292127, 55.43784649141374, 54.94679712480115, 62.731089822707645, 61.587150173802534, 63.07543470013527, 66.77286086543914, 61.98745158410842, 58.47318833874118, 50.62398041448286, 45.22583415431362, 55.62245284357379, 61.35685605387534, 67.76686791450747, 62.07334756851197, 67.25961915908321, 59.27910989330661, 62.531825573213645, 62.16696669978481, 66.02199369861235, 62.984141534374615, 65.37530076119208, 59.234045782396876, 63.51619928113876, 63.418775450798776, 67.64172077178955, 61.11000168708063, 59.82628837708504, 68.62501190554711, 67.19016967281219, 61.91565652047435, 67.97206278770201, 65.27098140408917, 64.59185831008419, 59.59238175422915, 65.96409951486896, 63.035238250609375, 59.19822277561311, 33.148256271116196, 38.94520951855568, 59.57416626714892, 32.927897514835486, 55.73410703289894, 53.24276654951034, 60.50867488307338, 61.32409641819616, 62.519705449381185, 61.72721409028577, 63.31562103763704, 63.23776983445691, 62.53245707481139, 61.21019863313245, 59.91882101182015, 61.569770151569, 62.63148123218168, 59.08555269241334, 60.53600988080425, 61.58761693585304, 57.91882407280707, 58.56712125962781, 60.60019162393386, 57.41882777983143, 55.170109425821614, 58.85529387381769, 56.8523943808771, 59.56605872800274, 60.43893906377978, 57.570003771012836, 71.9719546841037, 77.2825614867672, 39.8544619929406, 36.23281601936587, 65.04351531305622, 54.3031479466346, 63.14351920158633, 58.11284803575086, 63.07200262623449, 63.39478231245472, 62.94523554463541, 60.80370380032448, 53.81927259506718, 50.00742696946668, 49.189193094930346, 45.45195487237746, 60.728437439087905, 69.16175688466718, 70.3362008064024, 61.811729400388664, 57.652244106415786, 57.55281594491775, 62.26484552506478, 54.964032019338305, 57.673464129048014, 60.166177441996915, 63.218173673076016, 63.956720675191576, 73.1780521331295, 65.91271646561162, 81.19896181168096, 23.571497278828776, 4.2336303476364385, 0.24727182342640816, 0.47717955924810906, 1.6113865207279883, 24.04297205709642, 82.46393403699322, 62.75472602536602, 71.89877894616896, 57.80882120132447, 67.43569435611849, 12.870422255608345, 41.59425673946258, 24.515556866122832, 34.07411213844053, 63.48621668354158, 63.91420610489384, 35.94685954432334, 57.240842388522246, 71.38452483761695, 66.61970799969089, 3.2944592593177675, 0.45812315277514926, 0.24803161410795105, 0.16790846993605937, 0.34029745106254855, 0.16723668743525782, 0.18471539711519597], [0.23451986091752208, 0.06126895809786455, 0.03301879173264869, 0.07748702030268408, 0.12172267607022678, 0.07100695834284829, 0.05229538719680521, 0.12231920575422627, 0.19837442304818861, 0.0903199736269251, 0.26561858733334853, 7.726069035068636, 70.39523247749575, 50.47364381051833, 54.38078734182543, 30.553696655458022, 44.184590001260084, 46.63069378945136, 49.452446891415505, 2.5422300494486287, 22.07888049464072, 65.55629461042344, 58.017204961469105, 63.65710650720904, 59.66358846233737, 60.13268824546569, 43.67053593358686, 1.3611522965854215, 0.10018291898191937, 0.23454845131885624, 0.22350258193910125, 0.06755185583906789, 2.2588520424981273, 42.61794828599499, 54.999898172193966, 70.52247416588568, 66.81007631363408, 66.76547896477484, 56.79294693854548, 46.893516125217566, 51.6466482224003, 59.33682364802207, 59.653511893364694, 64.95014721347441, 68.9447242982926, 52.75898141245688, 51.97928874723373, 49.050117615730535, 52.56827185230871, 51.915793418884284, 47.450861392482636, 50.88120552801317, 53.46417650099724, 54.581032183862504, 63.00474966725996, 53.98577328651182, 55.30485460835119, 33.08508649949105, 25.899218051664292, 56.01802387545186, 63.24595189863636, 67.51833085090884, 60.22661724398213, 58.0424532582683, 58.01272953710249, 60.71393643656085, 61.744445062452755, 54.44921701185165, 55.90057242301203, 56.91891777899958, 55.02909237338651, 56.47211667030089, 57.70524317218412, 56.12543406025056, 51.45486393282491, 53.452738869574766, 56.2112045288086, 53.33444018517771, 58.328221459542554, 58.71200969142299, 55.98535445428664, 53.9605995147459, 56.93788243878273, 57.87787452820809, 56.652408415271395, 47.54871668354158, 47.29339391954484, 22.2036079437502, 28.948407826885102, 32.8411699879554, 45.88744778786936, 47.516486567835656, 42.76768476732316, 56.09844815346503, 55.985527038574226, 52.66882181167603, 54.37626092664657, 52.27694957487045, 50.24450678979197, 49.80636235206358, 53.91093446362404, 51.29907131195069, 48.51656152356056, 50.10622362936697, 46.86359628554314, 49.060174572852354, 51.194967685207246, 52.9341152406508, 51.30344475469282, 52.008985011808335, 53.77000370333272, 52.0898211386896, 52.45397006311725, 52.11705023242582, 52.703315134971376, 55.3714878328385, 53.90299558639527, 57.63678212319651, 82.14062090842955, 51.53875950844058, 24.103001971398633, 45.90996219265846, 54.115140899535156, 65.07705550039968, 59.20627932394705, 61.42291661231749, 55.811601300393384, 58.68703988290603, 54.37975575847011, 58.460432790940814, 44.27742858086863, 58.93429825382849, 83.26907111752419, 54.4258749869562, 63.48491445664437, 61.14118452995055, 56.99753384436331, 52.03883032644949, 53.87595476642732, 55.98778632379348, 52.6668135581478, 52.380715877779075, 55.60073467992968, 61.693352268588164, 56.98728469110305, 66.22802795902376, 59.641352545830514, 59.357455315128455, 2.5454584052485805, 1.4611819290345716, 0.04735050798063317, 0.37172501305899314, 0.557061753446056, 25.54252359174913, 66.06666949487501, 53.145903618105, 39.00459420296454, 55.7096432101342, 51.13576342982631, 4.292301160673942, 23.008847005905647, 22.668410770354733, 31.816580218653527, 48.794939979430175, 35.566252354652654, 18.611989675029633, 50.44505757670249, 47.500781397665705, 34.888694286346436, 0.24489958620359822, 0.1060101131518041, 0.15074259992088043, 0.05005697021260858, 0.12434349350270726, 0.16543751462332665, 0.13181523329788639, 0.1130345571906336, 0.08538766974403013, 0.04851014293249577, 0.04937430926328225, 0.03188215090983337, 0.043726988707578955, 0.07821294223709453, 0.11172344367350302, 0.18048498298852675, 0.04026479222961972, 0.47705413533314583, 8.842792337940587, 78.0723620999244, 56.272828886585856, 52.615814901167354, 36.98528743559314, 51.809842355789684, 43.825920627963164, 56.966668713477354, 5.938973936342425, 23.783956381582446, 71.86988676747968, 65.80229390052058, 68.07773928488454, 67.21640248452464, 65.6568524145311, 48.277214573275664, 1.6003623316364906, 0.16759900105816705, 0.05655309703621653, 1.6753689584232148, 0.13446143888417753, 1.886710798548114, 48.11005492364207, 61.258200599301254, 71.01006400200629, 68.73723876091742, 69.13027594166418, 61.30108387239518, 54.04022362924392, 55.744960231165734, 60.45624063860986, 65.20985126495361, 67.13204014685847, 71.16003190317463, 54.31195759004163, 54.76557185572963, 51.58996212866999, 49.06212399082799, 54.000011490237334, 49.896918112231845, 53.607221418811434, 53.24970522234517, 56.79261353708083, 61.796898918767134, 55.14185659347042, 56.0926861916819, 34.655964374542236, 39.65248738565753, 62.331184571789166, 64.00493444934969, 67.62210892092797, 63.08325590625886, 59.63693987938666, 54.78963559673679, 67.36373455293717, 61.89105149238341, 55.85751264326034, 55.91274353765673, 58.97850728804066, 55.154757268967174, 54.685022061870946, 59.92240213578748, 57.93254844604, 56.1238141213694, 58.07164745946085, 57.324279046827755, 55.25148683978666, 60.16094107781688, 56.14238654413531, 58.788056604323856, 56.96691190042804, 56.32798133357879, 59.80150291996618, 62.65346219462734, 53.895558772548554, 64.49046896349999, 30.208936006792133, 31.645964960898127, 43.702656222927956, 38.7740372842358, 51.35716161420269, 52.7913684229697, 55.78201878455378, 56.70975346719065, 56.92464051708099, 56.423636174971065, 53.80456762929117, 55.69977844915083, 54.49913309466455, 56.601527429396114, 50.74053364415323, 54.55615258985951, 54.057752701544, 53.59078668778943, 54.61367414843652, 55.86590259305893, 55.458384021635986, 55.10181703875142, 56.266678610155665, 55.44208265119984, 54.029264526982466, 55.881199836730964, 56.51920864658972, 54.23226287288051, 59.19376696309736, 60.73025349647769, 52.68937895374914, 67.7400859709709, 57.134930549129365, 31.383711368806903, 48.66867888358332, 55.69709554795296, 61.587271767277876, 60.38587724008868, 61.0902839322244, 56.71858272244854, 59.891815493183756, 57.37869801059846, 58.52027247028967, 45.7496980697878, 54.75473826931369, 71.10394985445085, 62.35384410427463, 63.17844398560063, 63.43482971191407, 58.607282407822154, 55.42145490646363, 55.405898786360225, 59.76940616484612, 53.65578820628505, 53.72946208523166, 57.00286434542749, 67.37281091751592, 61.89741749917308, 68.01003917571038, 63.31050234456217, 65.6997396099952, 2.5312434905959718, 2.4872430774473377, 0.008472596321465268, 0.6374797801817618, 0.1815046153722271, 30.315091033135694, 73.10635120637956, 61.60624819417154, 42.56399608427479, 56.32456102678853, 55.06746492078228, 6.722135937982991, 29.72537640602358, 27.166406416123916, 34.64258909225464, 54.3665805170613, 41.79885541239093, 22.430658263544885, 53.06171778709658, 57.20441925910212, 38.86666013348488, 0.3180976939057151, 0.1347056064274042, 0.07106514272069739, 0.14905359055246079, 0.06587878109947329, 0.09426839844954592, 0.11617140378803016, 0.3216026687333661, 0.15747514913880056, 0.20877000635429738, 0.19056408005135675, 0.13993233322135865, 0.23665467217083902, 0.166503970300959, 0.3138249764038671, 0.38065634187190767, 0.2666890266681871, 0.6044311761375397, 11.81162255425607, 95.64622002263224, 63.963514220330026, 70.04370181791245, 43.25889102874264, 64.84978160550519, 57.76057997057515, 60.08055602350543, 6.08455466647302, 31.270133256912235, 76.32345568749213, 68.50353610131049, 71.97682626785772, 70.96552941106981, 73.86823238865023, 56.27178945849019, 2.211513937480988, 0.5259822405153706, 0.4697299364113039, 3.752181962613137, 0.26716832191713397, 4.05233153412419, 52.77865209887105, 63.795322987341116, 73.44027826862951, 72.93577517232588, 72.33186352637507, 63.960372401822006, 56.58186851009246, 58.616962817407426, 65.60861118378179, 67.07976279720184, 67.51455753080307, 70.91009847579464, 57.09167465086907, 60.95249106807094, 58.854258368092204, 54.35909271240235, 52.016559108611084, 49.65934407326483, 54.44583985113329, 58.045606843886844, 60.7027929829013, 67.26725993617889, 59.12620805924939, 58.11631933335335, 39.18747863461895, 43.14496186471755, 61.48097161323794, 62.622479392636215, 66.57675020156368, 61.97617084749284, 60.034264210731756, 59.968282099693056, 71.2764007814469, 64.1508113184283, 58.90386458366149, 59.98033946560275, 62.26093492200298, 56.80177619380336, 62.97633994010187, 63.9666207375065, 63.00415346699377, 62.234203969278646, 63.60338180295883, 60.349199156607355, 59.94085296507805, 64.07873776651198, 61.99166813204366, 62.04061146705382, 58.53878213513283, 61.02498431359569, 63.752875097336315, 65.20551704591321, 55.204159521287494, 62.35605239868165, 41.40255481966081, 32.57843002196282, 46.79064412270823, 58.39778077217841, 59.726660174708215, 59.43847579340781, 64.66631274069509, 67.1566177183582, 58.48270400877922, 59.75936097483481, 58.54359880570443, 58.41920083568942, 56.01539588743641, 62.87358560869771, 60.38858367550758, 60.4035004492729, 63.75793103248843, 58.47790695005848, 55.55766705543765, 58.87785926941903, 58.76784855319608, 55.63352961694041, 57.092215937952844, 56.01059098397532, 57.32316901606899, 58.63630794709729, 61.3731848809027, 56.07243499448223, 60.537688655238, 65.35063689754855, 53.37938662498228, 59.24266715203563, 43.4630778528029, 27.734408763147172, 52.57193534604965, 60.143517909511445, 66.36044717604115, 64.29200879989132, 66.4492888604441, 56.83256679965604, 62.05571651458741, 56.83226477715277, 60.336329860071984, 45.387165161871145, 57.54305708792902, 66.55268253818636, 60.92108072773103, 69.10711042342648, 68.02790949421545, 60.25199497899702, 58.08380288462485, 58.76351433415567, 63.581973506558334, 58.01980549289335, 55.94603661567935, 61.75116016018776, 70.7326739834201, 62.03077416266165, 71.45032651962774, 63.88241921701739, 69.19697192407423, 5.738137306705599, 4.21042021243803, 0.19985666528584498, 0.9990927084319055, 0.8067593483194229, 32.19185298488986, 78.29945164342081, 64.9542853140062, 49.328645121666696, 63.15180716976043, 66.1666036421253, 12.215870849547848, 30.472872295687278, 29.38067851528045, 45.18257433368314, 71.99447693363314, 43.71726705181984, 28.63870728400446, 68.04821168222736, 66.23610804157873, 56.17782123627202, 0.6336813936791112, 0.2692564630941037, 0.2307610658387984, 0.1598144139373495, 0.28491134725270734, 0.36806173382266877, 0.24881691551737248], [0.09728203512608044, 0.06647687360283829, 0.08935983563142438, 0.1586902871607773, 0.06845465215343623, 0.07853667567213697, 0.048933912128690756, 0.024583414835374684, 0.11305054544561333, 0.07111501504456805, 0.09011913601669574, 1.280750081904473, 61.44783150765204, 52.53333530118389, 55.16980740331835, 28.927111318034513, 40.8290062412139, 25.23498623601852, 35.408988844963815, 32.78804540634155, 1.4232333653396176, 45.79966906578311, 52.20918670777352, 61.74633172250564, 57.22674539012294, 63.168277202113984, 42.01610372912499, 2.336795666525441, 0.35232604270981205, 0.24905999521574668, 0.24617233403748084, 0.20498957695259204, 0.558739853722434, 38.158393829099595, 65.67674667604508, 69.84969354444935, 67.92289195522186, 66.81017045051821, 59.290104296899614, 49.461429119110115, 47.02590396327358, 54.31990431201074, 64.08452326251616, 66.82036861296623, 66.60207302339616, 70.15251621123284, 52.687362855480565, 43.854506861779, 58.143195413774066, 51.034534900419175, 56.05296827131703, 52.38170823743267, 53.068950637694336, 54.49489301250827, 43.563113981677645, 53.63115572160291, 42.493569927830855, 23.86876194707809, 60.48225379759266, 69.94548566879766, 64.11022263188516, 59.85501189385692, 55.76528987576885, 56.68987881752753, 54.82791008487825, 55.98521717133061, 52.6752309645376, 54.90439238086824, 55.66331217365881, 57.40605654255037, 55.03698025980304, 57.618998096835234, 54.1964751674283, 54.368447565263324, 56.232891313491336, 51.911141487859915, 49.256940272546586, 53.26801484630954, 52.59500672740322, 51.280059583725475, 51.65670517952212, 56.43599164101386, 57.16777647695234, 56.94553498298892, 55.77995561784314, 50.88814812321817, 29.145826601213027, 29.361349075071274, 26.082314291308005, 33.52052057943037, 70.75653768354847, 54.37980674928235, 51.96800801061815, 53.76645395832678, 49.04284161906089, 50.22954686995476, 52.242028713226325, 52.30761858724779, 50.993216653024, 51.864378990665564, 52.263637050505615, 48.84624065891389, 42.72274617225894, 47.167160280289195, 43.79961329121744, 50.15284492123512, 52.476100075629454, 52.63712906068372, 54.461584245004964, 51.299777338581706, 52.60816235696116, 52.07600262857253, 50.702019891431256, 51.67370080947877, 51.82948166324247, 53.44687100379698, 53.98178423604658, 57.16655269745858, 55.638754214009936, 61.192363615958925, 36.469656575110655, 37.59189767222251, 47.13611472037531, 53.24888152460898, 60.43521281211608, 56.81700283481229, 53.0596036295737, 56.87685428127166, 56.47766290172454, 57.435866555859974, 47.72568618097613, 61.704601626242365, 57.06299035779892, 54.47032720811906, 61.53728115943171, 62.708877440421816, 59.473145623360914, 55.32883597958473, 51.640062562880985, 56.03535682924333, 48.395073952213416, 48.32001547659598, 53.80604636284613, 61.68068301293158, 60.475652448592655, 62.56723673112931, 67.88045975469774, 36.27218877115558, 0.48701199132107925, 0.6799730838787171, 0.20970071125174725, 1.0915646077163759, 1.7796260478996464, 46.38400023983371, 55.78547831504576, 57.56090387221306, 50.146494603926136, 74.03014782936343, 28.396181252694902, 3.9018233264646227, 34.94079512934531, 17.741268604032456, 31.600814557844597, 55.139103089609456, 37.596161288599816, 22.667212486267093, 47.36784442778557, 59.13613165578535, 21.938212533150953, 0.26565738202583405, 0.2013135806567246, 0.11445814007592779, 0.1689259113082963, 0.019145634648720586, 0.06591706251304957, 0.2514780598181871, 0.09650311522906828, 0.19535425930253922, 0.024106624693940246, 0.17543157592656153, 0.042818990656204765, 0.08853979213463684, 0.09489639136459559, 0.00901074244475533, 0.08972649297286427, 0.11160247839025914, 0.14022234346597426, 1.1938569574586808, 69.40248058688256, 62.0293503422891, 53.36677620487829, 31.451807637368482, 50.50500708241617, 24.950908576288533, 37.44329475587414, 34.530079826231926, 2.9810824749931215, 44.94681242973574, 61.54125452041627, 70.85707587580528, 66.79809739512783, 67.52178253666048, 50.94689346128895, 2.7425506422596597, 0.40438931675687917, 0.2327878893383088, 0.07363533706314142, 0.30944166644926996, 0.798190379094693, 42.38028403251402, 68.21281786887877, 71.07249244566887, 71.18298561342301, 67.75754836297804, 62.96342357512444, 54.239385897113436, 50.430854674308534, 56.618640730457926, 65.6774801592673, 67.2806744421682, 65.36933875853016, 72.69559275719428, 52.91823748619326, 50.60636112766881, 56.054541141756125, 52.430314248608006, 56.5636137993105, 56.54148770916847, 54.091379181031265, 56.62992146707351, 48.11295355519941, 54.38145414475472, 40.66703588731828, 33.57993664280061, 71.25574558011948, 68.3915916565926, 63.81872777015933, 61.79816976670296, 58.29077459150746, 61.547820568084724, 55.6504624889743, 56.08541019501225, 54.912311646246145, 59.29055929183961, 54.911974322411325, 59.92091947986234, 54.63647096387802, 56.427413417447, 56.4531716223686, 56.010418399687744, 59.27896476561024, 55.80878503860966, 55.545264520952784, 56.249545697242986, 57.27929730569163, 53.866835255776685, 58.70044262178483, 55.19462816176876, 58.26693050322994, 57.50791265118507, 61.35475366346298, 54.56357371422553, 44.980509511886105, 46.61074461475496, 39.108164387364546, 35.64499001349173, 55.263489292513945, 51.61268834144839, 51.55439015357725, 57.3823771938201, 57.888147215689386, 55.290785066543094, 55.48683689486597, 51.74388377897201, 54.21103108313776, 55.36418045720747, 55.57238771069435, 52.52812247122488, 51.2019455817438, 52.56806788905975, 50.736497525245916, 50.693018051885794, 53.37139675694128, 54.66807742272654, 56.27918312626501, 52.27174066728162, 53.142157754590436, 54.58818658705681, 53.416425566519464, 55.13682811490951, 54.45156651158487, 55.316708011011926, 53.95904625615766, 64.35101693676364, 54.67551031420308, 63.51528144651844, 43.90423467082363, 38.593078736336004, 50.74513850673553, 55.088237793214866, 61.32945045348137, 57.90573120117188, 56.107901065580315, 59.27187312033869, 59.48887825012208, 57.56284936781853, 50.311496949964955, 56.761336557326786, 53.89540580011184, 58.189267573818086, 61.95693162179763, 65.71081638336182, 61.413659818710826, 57.671804966465125, 55.59574150270032, 55.98962199303412, 51.1852127505887, 52.74630431205996, 57.29250392606182, 65.5159334213503, 64.72327732270764, 68.2854680092104, 69.97622920620826, 44.192411207383685, 0.5639923363924026, 0.7195461829823833, 0.19186155720343515, 0.9351544586881515, 2.7643541174550212, 54.253204407230506, 60.1496171951294, 65.11131740385487, 49.89296828546832, 80.87893562932169, 25.903846448467625, 7.879757304345408, 40.21433945625059, 24.32443545710656, 30.099819590968472, 53.9895034605457, 47.17452256910263, 21.488740290364913, 49.2668991704141, 68.01181993176861, 25.5289972982099, 0.6972098170268921, 0.2307093242603925, 0.10660413772829118, 0.3786709484073424, 0.070331176863082, 0.03757981876392038, 0.12600081747457867, 0.15136705350971993, 0.25093988305138004, 0.18382880356042616, 0.3211397371224819, 0.15546724801101994, 0.1685089449728689, 0.27995880332685286, 0.12236929258271573, 0.1680561410443437, 0.24615155773297434, 0.17967205644855577, 2.229005992412567, 89.99114282669561, 66.54854051528439, 78.7975142079015, 38.75780259409259, 58.62144216414421, 36.339739830263206, 45.409381466527144, 42.55975207974834, 5.404783400797076, 54.69321589316092, 65.01570178616431, 72.4900213364632, 68.75084938541536, 76.49759323366227, 55.53199514265984, 4.896646718825064, 2.9539190809572897, 0.5467113540057214, 0.7949600008226211, 0.6921959860670952, 2.2695875696597563, 43.37192196999827, 69.70770374421151, 70.94237958231281, 76.47998963632892, 71.6160309699274, 63.91015821887601, 54.15554131231001, 52.56038004352201, 57.803984918902, 70.76047574320148, 73.42821305797946, 70.49304070011263, 74.29519022664716, 59.398495074241396, 56.96032624090872, 52.491801323429236, 54.540718063231445, 57.15200070411929, 57.94102468798238, 55.56269553399856, 63.071131860056234, 51.031804930779245, 55.59121900989164, 46.83453152256627, 30.838598012924198, 60.92788603998, 72.70813649700534, 66.81879182015696, 65.21360497320852, 59.35141878743326, 62.88016342347669, 58.067929052537494, 61.71255619295182, 60.42303385273103, 59.77415615512479, 57.920542070942545, 64.33898310507497, 61.255243132191325, 60.718298112192464, 60.99573127685055, 62.42918499054448, 65.41364977436682, 60.4650620491274, 57.45376433095625, 63.122275644733065, 61.40628968515704, 58.44843818295387, 60.49587226683094, 63.19463552967195, 64.73636234960249, 64.68915270220849, 65.42663281963718, 63.6515877323766, 46.22682694465884, 47.22588208413894, 44.52584012862175, 40.497389454995435, 69.30738664442494, 73.19090181781401, 64.85688501788725, 67.91204267932524, 64.25889615089663, 60.380895829969845, 61.131833599459746, 56.156769875557195, 56.78882452749438, 61.54139964811264, 64.38315683795561, 58.930791654894435, 57.73890103063276, 61.15810171250374, 56.9079351425171, 56.391315844751176, 57.17215776443482, 58.303510527456964, 59.33798074722291, 55.14237434633317, 56.48009084886121, 58.48023291557067, 55.09393699707524, 60.14119978873961, 59.34432714216171, 59.358969350014966, 56.497035488005615, 65.78053651317474, 56.47611356550648, 58.5128003551114, 34.781727329377205, 38.466268508665024, 53.592759639986106, 57.9246997833252, 66.30742457605177, 62.47082094992361, 57.481330748527284, 61.06721647324101, 60.87379655530376, 60.67935289875154, 49.36729223497453, 61.105145792807306, 70.61759948730469, 57.79583031131376, 66.65499364176105, 67.56819986527967, 63.77223199413669, 59.86107587814332, 56.63638945548766, 62.79092557968632, 54.05644655227662, 55.495524944797644, 61.99095818304247, 70.19394428499284, 65.01150092770978, 71.11388914046749, 66.00227986612629, 52.11997239820419, 1.5926573257292471, 1.9450256564924795, 0.7835252498907428, 1.8833848737901258, 4.022267792494067, 56.510587276950965, 65.13898188068022, 68.3343642757785, 57.1880865097046, 88.73541170550932, 36.86397244853359, 9.685503763537254, 46.170764507785925, 26.460158171192294, 45.23258455338017, 77.94362991086899, 54.62766524284117, 34.48272112877139, 62.73288626824657, 79.19784699716877, 37.58557873387491, 0.5580793633576363, 0.38628420762477383, 0.16526721327775912, 0.40401316758605743, 0.2952398978654416, 0.09688258156060212, 0.3594272181151375], [0.0406385550365573, 0.09890114663228874, 0.17294107005000117, 0.3718452888631052, 0.030704892105272705, 0.08889944743244879, 0.029121170030726545, 0.01156099934896995, 0.13561326740009172, 0.05907885444861266, 0.09878739023641234, 0.09193585224209294, 43.851451335414765, 58.75546563056208, 51.5657611047068, 41.57063622628489, 34.856264129761726, 48.21327993946691, 18.35793972015381, 60.51497420957012, 3.4682457533574875, 11.620650195306348, 64.54591166588568, 38.774280471186486, 65.12974469892441, 59.52704291189871, 57.24200733246342, 2.766984066655559, 0.27662690308305526, 0.026231015236267162, 0.2192842260363602, 0.15590770260220574, 0.47539264384296637, 31.14464290680424, 73.87299414603942, 66.50086802821006, 64.25427167646347, 62.57551685456307, 62.06383189847393, 49.88475484232749, 48.907688510033395, 49.473984626031694, 56.424726593878965, 60.28825729124008, 68.9615277321108, 65.29326438903809, 65.58883459337297, 39.279317009833555, 63.94761685402163, 59.43822476171679, 47.981911090112504, 56.8315391386709, 47.9693163594892, 48.82115710166193, 56.91950613452543, 40.61444082567769, 24.57964643355339, 61.383587006599676, 72.30160636286583, 60.62203922579366, 58.269703618941776, 56.74800834348125, 54.574736779735936, 54.63878516227969, 50.719258708338586, 56.35814043783373, 56.200108143591116, 54.0100331460276, 56.96799839696577, 59.22496941781814, 58.218304880203746, 60.16840142588462, 61.094449489347404, 57.20062240477532, 51.54481957035681, 54.876174849848596, 52.09010747171218, 52.56765996256183, 53.018540336239724, 55.597820358891646, 52.17990229206701, 50.91796990363829, 51.302683814879394, 54.5957959851911, 55.77779046950802, 43.935935266556285, 19.944758107585294, 24.118218806482133, 33.85451432197325, 35.72870908244964, 48.0065082734631, 58.278552486050515, 55.975689734182055, 47.802697996939386, 46.11302721884943, 44.49916016670966, 43.98086209450999, 51.06312505660519, 48.42595085020989, 52.542172401182114, 44.83799411404518, 41.38105630874634, 44.85926904985982, 47.20424236789827, 47.7848865139869, 51.81620051783901, 53.924325435392326, 54.04938628596645, 54.39238186805479, 52.37249066752773, 51.02991827072636, 52.82289643441477, 49.451270180363814, 50.80896331417946, 52.96424688831453, 52.841304117633456, 52.77414137317289, 53.05341805181196, 52.978045786580736, 53.83968853181409, 46.690827646563136, 36.284705054375436, 44.77824857158046, 46.171858849064, 54.2739615901824, 57.18508981889295, 56.23352673745925, 53.90767105164067, 61.968173134711485, 52.530079733940866, 56.82707940378497, 42.834690616976836, 23.46736619549413, 58.91215647420576, 59.599508700832246, 64.85576322001796, 60.89009400336974, 53.65730616354174, 48.908990736930605, 50.914412313892, 49.5805161999118, 48.28182335822813, 53.17293267096243, 62.104095028292754, 60.8332980832746, 59.06180274101996, 61.53658689991121, 17.4846730309148, 0.3934500714944255, 0.0601592107916311, 0.06066249225348715, 0.4270183895864795, 5.839735029205199, 66.23757500802317, 52.18618200671289, 65.05462346538421, 60.03462899115778, 67.94663798424506, 13.89158191219453, 15.983189728952224, 39.74116040814308, 18.96024319433397, 38.76510996972361, 58.795105103523504, 26.39634709204397, 48.86847265305058, 58.637088498761585, 55.1454730187693, 8.924665931732424, 0.4736816017858444, 0.2310801721027782, 0.20940302480613032, 0.13002290931199828, 0.10125705852143227, 0.1324637420475483, 0.17853893579975252, 0.01102651704117776, 0.03742102788941514, 0.08711891353971536, 0.20768242197171335, 0.09168133485100924, 0.1567456802173007, 0.08818489424283467, 0.0625697753932928, 0.11440648276719356, 0.2327042018934604, 0.03296992681439846, 0.09787349330802118, 49.756469803471724, 66.5605821917134, 51.36643017491987, 35.578729414170795, 40.146811931364, 46.965652435056626, 21.49836970913795, 64.46629147375783, 8.571493760232004, 15.896174888457022, 68.14583163107595, 41.53748827595865, 74.58086429103729, 65.9719285657329, 63.16946175790603, 3.7105435517526444, 0.3134419937287608, 0.04358663373897153, 0.463367147190917, 0.41351743823578285, 0.5201170713670793, 35.43306043071132, 74.6747422987415, 69.9540364357733, 67.93381967852193, 66.17100454145863, 63.310757298623365, 52.950930441579516, 52.643059684384255, 52.03828903936571, 58.447096732354936, 61.498614434273016, 67.56810572839552, 63.992147522587935, 66.08615582989108, 44.05729732205791, 67.12239896097492, 57.7516330442121, 51.705573989499, 56.436670211053666, 50.65070744483702, 52.69865928157684, 57.951262074132124, 38.97077552733883, 31.689152217680412, 79.34666956624677, 71.05251973675144, 62.03204501059748, 58.97631468311433, 58.49213338667347, 58.24192539338143, 60.93371468205606, 52.433291327568796, 59.3793107617286, 59.22672271728516, 55.10192294274607, 57.05379632211501, 59.66853457112467, 57.38652706146241, 57.8762153656252, 59.64182323025119, 59.975593397694254, 54.89069546422651, 55.156883193600564, 55.56160119272048, 55.43142949381183, 54.70097434136176, 54.83371911510345, 54.775228731093875, 54.16501775864632, 54.67378054895709, 58.6268981810539, 57.570341094847656, 52.924956506298436, 36.429471892695275, 45.10124791053034, 37.94951192794308, 43.89961019639046, 50.51936295724685, 50.26255753732497, 53.16897892182874, 56.429417748605054, 53.0734182173206, 53.55936850270918, 50.78861405772548, 54.59505857959871, 53.68706910840927, 54.30466198152112, 51.11894430652742, 48.83226133161976, 48.0226605938327, 52.56077620290941, 53.67652577738608, 56.13545571604083, 56.94929261361399, 54.94760513305665, 56.6080032625506, 53.15137532449538, 53.80668570918422, 56.20872559085969, 52.951926723603286, 55.794052616242446, 55.826216051655436, 55.396347814990634, 57.93277986588017, 55.16917197935043, 56.161390427620184, 58.05434588463076, 54.460101589079834, 40.005065318076845, 42.80951292284074, 49.38923789608864, 54.90709881628714, 55.63141545941753, 57.47257994067285, 57.41558397969892, 61.157187800253595, 55.69392235048356, 58.6902601488175, 45.268305578539454, 28.468456806675082, 60.15984281416863, 62.44840460438883, 65.21636632180983, 62.519646613828606, 55.901219614090465, 52.59538719730993, 53.67957738138015, 51.82201347043438, 50.85048552482359, 56.24182647274387, 64.9285545656758, 64.64191167585312, 66.20459571961435, 71.27341978011593, 20.748626301365515, 0.2970218490208349, 0.10580543744107408, 0.08158728375189728, 0.6178608813112783, 7.628712375317851, 74.74136767848846, 54.41510415846302, 72.45320597002583, 64.77055365039458, 72.43539840944352, 16.801707975326046, 19.78318783544725, 43.14184358043056, 26.158055259335427, 34.42490539243145, 63.61849861760294, 38.49247386378627, 44.64995961035452, 65.32620053137502, 58.471074181218306, 8.549248037799712, 0.448747523609669, 0.25816611464946504, 0.10160382822035782, 0.11532038735646395, 0.03639681429992761, 0.11516667947533632, 0.0548005368440382, 0.07747804941309076, 0.22296347054502658, 0.305149827392832, 0.344324836567525, 0.20494195692721875, 0.31066152357286025, 0.22128863380320613, 0.1732594868348491, 0.14744145044636342, 0.26180377590560144, 0.19644405001834517, 0.20815964878326465, 63.05619939681023, 77.4456536385321, 68.96639931586482, 52.04460405534314, 51.43824092803463, 70.3964013438071, 22.952317806982226, 72.09201059033795, 10.4708505253638, 19.63549098660869, 75.3663581417453, 48.853846134678015, 76.52117452313824, 72.03339469048285, 71.13302246216806, 4.738606579842107, 1.1901793676999308, 0.7185256312931738, 0.7497095773296972, 0.8954876517095874, 1.5707187739110764, 42.54430578600976, 71.86406597014397, 76.19963430589246, 68.32720987258419, 70.09095068900817, 66.55942901488274, 55.96808425841793, 54.403050714923495, 52.57710110756659, 60.15350426397016, 64.69127862684189, 72.7230493484005, 71.71624752783006, 65.13343172688639, 56.70086145401002, 66.84955889178862, 55.388306956137384, 54.23390634598271, 55.485452298195135, 55.36376076359903, 56.366836332505756, 59.10968703608359, 42.68653485082811, 34.373585101096864, 62.07195904947097, 73.2788727360387, 66.74694968808082, 62.44799275552074, 57.32966053870417, 58.7481660996714, 62.70551989155432, 54.58223242913523, 64.01856468569848, 62.57714071581441, 60.16654614479312, 63.44185467689269, 64.79464484799293, 62.43779067070254, 62.65678836453346, 64.55148535390055, 64.92417720056349, 60.51004771263369, 60.1567715983237, 61.97817910102106, 60.056943355068086, 63.774620717571636, 63.57715291361656, 61.751948556592396, 57.58605803212812, 61.33708730820687, 65.48778649299376, 65.61424370734923, 56.947449099633005, 41.31357192993164, 49.558684287532685, 46.96867266008931, 50.677399173859634, 53.68055797392323, 72.76122969965782, 72.17729076262444, 66.19643718965592, 59.71355553596251, 57.328421069729714, 54.41329594581358, 60.496723421158336, 58.63100098025415, 61.40891375080232, 57.23924206149194, 53.72141338163807, 56.019263344426314, 61.80014664126981, 59.2133278231467, 64.44967631370791, 62.439261559517156, 57.675888153814505, 59.89879731209048, 54.61936942992672, 56.06285656652143, 59.31561539250036, 55.41146070726457, 58.32779784356394, 58.57923353871992, 57.99791082259148, 58.71379436985139, 59.493608628549886, 56.06690445253926, 60.68336548343782, 47.22830218653525, 36.41693207525438, 45.724186974187056, 50.31974177206717, 59.694422214261955, 62.585934669740745, 57.163434413171586, 58.845911564365515, 61.883540153503425, 58.00510837185768, 57.80832698268276, 54.46353366298061, 37.39207644616404, 63.574560226932654, 67.68885197178011, 68.46192759852256, 66.32966441492881, 56.62801127279959, 54.92463965569773, 56.237515787924494, 54.83386032042965, 55.22224949252222, 59.26131802220499, 67.92760664416899, 67.79345373953542, 65.1061555647081, 71.02470228748938, 29.17066501032922, 0.5763360353246813, 1.1300998109002267, 0.3214653551338181, 1.1078681844857432, 8.732311917889504, 76.67426463096373, 60.15281392681984, 74.90937848244944, 71.58637785142469, 79.59304932625064, 21.690326583000925, 25.264194165506673, 51.32599053844329, 27.073028510616673, 56.034129127379394, 83.86589896294379, 38.390300043167606, 68.63396275428035, 75.9468375482867, 76.70055235585859, 18.78748828364957, 0.8773868326698581, 0.4759998451317511, 0.23925679705796704, 0.21185649799243098, 0.1513319513610294, 0.3338858467196265, 0.31301963413434647], [0.15772323905219957, 0.13666536659002304, 0.15728272317397982, 0.24849319740408854, 0.06104372824812609, 0.11000945217787259, 0.11424970287348955, 0.020928505109623078, 0.3907265676365745, 0.2805086093083505, 0.10752963322785594, 0.5275707391481246, 25.373547884725756, 66.06566536811091, 48.24543553013956, 50.764542471977975, 33.162733739422215, 38.69042804164272, 22.665720024416526, 32.00217696928209, 46.421105861663825, 23.78327585035755, 50.27987872400592, 59.03695060360817, 50.618979392513154, 62.68449206506053, 57.72783210200649, 5.035461360408414, 0.13571881899429908, 0.1126852210971617, 0.05975030753160677, 0.34861373384633376, 0.42467989087585484, 32.24792718887329, 74.87594419910063, 65.25788853245398, 68.16855784385436, 64.1601897055103, 57.0698074371584, 51.51602937329201, 49.91139950290803, 51.863131676950765, 53.53102937821419, 55.92467538772091, 60.66285540980678, 64.48101212901454, 70.29589453051167, 51.21126905564339, 36.62526876695695, 70.52495310383459, 51.18967640784479, 51.31524716654132, 49.09520918323148, 50.26487958046698, 32.15016211232832, 30.021130961756555, 71.16546830823346, 69.53766899724161, 58.21594361336001, 58.13062421737179, 61.064039353401434, 57.67584108537244, 55.49002185944588, 50.158634339609456, 53.36741947358655, 52.52402751676498, 53.454362730826105, 56.05294081472582, 59.63940312785488, 60.35974248763054, 59.78814332715927, 59.364550882770175, 54.5578117524424, 55.501624230415594, 57.19756687841108, 54.14362122935634, 55.39353547557708, 55.16277067122921, 53.05999586659094, 50.913710209631155, 51.829983726624526, 47.3387522082175, 49.12001032983103, 48.82356935931791, 50.517284101055516, 28.83413153309976, 14.9819988589133, 34.97624158859253, 38.643885197178015, 32.72681524676661, 38.55158398228307, 41.68118822959162, 48.720152147354625, 42.98365046901088, 38.724203571196526, 40.147941573973625, 43.329940842043975, 49.392077692093395, 49.40084811179869, 48.94942645103701, 47.70289328790481, 42.967372632795765, 47.663222435982, 47.42187899927939, 48.184348537075905, 49.22227436496366, 58.25215493479083, 58.29445769709926, 56.63549515508837, 55.32148153551164, 53.129876813580914, 52.35585981799711, 49.96715991727768, 50.50369308840845, 52.96484308858072, 52.276671086588216, 54.488876096663944, 54.67773822046096, 55.24595237547352, 56.350025053947206, 49.9899253537578, 40.38585293677546, 44.83890018155498, 43.88877660997453, 43.671402777394945, 44.24179384785314, 55.93955686015468, 53.86787860624252, 55.31616280155798, 52.11003703455771, 54.12680602842762, 40.32464435023647, 34.69269737120598, 55.5734428282707, 64.58410378425353, 58.90609641228953, 61.87196916149509, 53.33980990994362, 51.40011941232989, 50.1594070465334, 50.380095281908595, 46.99033198818084, 58.48124488707512, 55.290910582388605, 66.02710846931704, 50.357490662605535, 46.21130220351681, 10.355880952650502, 0.10130480112087342, 0.18700626047868885, 0.03687262384881897, 0.6425990248399397, 15.52482351180046, 67.63506058723696, 45.88536893167804, 66.07799729993268, 52.50485104899253, 65.325608253479, 20.980610962836973, 13.829040700389495, 30.2498306382087, 21.672230728210945, 48.7460829365638, 52.259644077670195, 31.004865323343587, 40.734947804481756, 46.244183432671335, 43.44314436758719, 1.0048294199570533, 0.101912944697805, 0.07744417300507908, 0.06235012649408272, 0.05343543328044396, 0.08083064169172319, 0.025747406912306627, 0.02219427388251549, 0.08430577739472352, 0.061044544131765445, 0.05694505443135577, 0.03721269027840707, 0.07114103905135585, 0.1240622089995492, 0.19215380442478966, 0.11910406497096825, 0.207975588498577, 0.20453108865166866, 0.3031991223894781, 0.8420179015205753, 28.504069966654626, 75.59291424289827, 53.54409871562835, 40.09989646173293, 41.39041116160732, 40.79152407184724, 21.79697386680111, 43.85280847549439, 48.91139122747606, 32.8943161426052, 54.94158821721231, 65.54755949204969, 58.61188727040445, 68.87123477074408, 61.636536736642164, 7.731752549448322, 0.11988369732974999, 0.7333549484610559, 0.08405824672550925, 0.5194787669085688, 0.24474964747505806, 37.81184457963513, 75.58767395634806, 69.32297414348972, 68.04200649261475, 66.60629349370157, 57.170392697857274, 56.28217981707666, 53.55650517248339, 56.80109762376355, 54.42099948083201, 55.69041182917934, 62.02581236439367, 64.68839568476524, 72.7029432788972, 52.48912626697172, 41.06222252691946, 71.40812966131395, 50.17421007156373, 53.70732030560894, 51.85169012315812, 50.24558544158936, 33.86219824514082, 38.122755173713934, 84.84344774676909, 76.59173011779785, 58.45375299453736, 61.767410539811664, 62.990170217329464, 59.551997030934984, 58.20820477701003, 52.639886486914854, 58.80245170285625, 53.06800142411263, 54.87047172361805, 57.15278517815375, 61.25543532832977, 59.07959853449176, 64.25721737646288, 61.59480271800872, 58.184403834804414, 58.432815382557536, 60.29751016247658, 60.08409007903069, 58.839157242928785, 57.28453366987167, 56.939639660619925, 54.55055144525344, 54.750537410859145, 56.487213873094134, 56.01071649982084, 55.10524519028203, 58.76974305798931, 43.960661888122566, 29.96452919898495, 46.32964795635593, 45.29319693965297, 43.031217052090554, 46.65215699903427, 44.932119231070246, 51.00713714476555, 57.0642690504751, 50.82491559367026, 51.84477498454433, 48.48454713821412, 54.55025334512034, 51.95194590476252, 53.89176191822175, 50.50482273101807, 52.268383118414114, 52.995590548361506, 53.67847519536173, 53.48993862828901, 53.43351925573042, 58.36524471159905, 58.67355869662378, 58.5344361489819, 54.49650118427893, 54.588104217283195, 55.10862627337056, 55.337049422725556, 54.97272791401033, 56.52856742182086, 54.072053663192264, 57.31236680861443, 57.730734655934, 58.01953484935146, 59.3041189255253, 55.80474499733218, 44.43701021132931, 44.08466369875016, 45.98666806374827, 46.14152716052148, 49.038581925053755, 55.64779919962729, 55.786604035285215, 56.28498038937969, 51.95567215642622, 52.57088415084347, 41.907595280678045, 39.63953179697837, 52.52219184752434, 64.80347018088064, 60.93954724650229, 63.39637087237451, 56.7507932263036, 54.202503850383145, 53.6950707435608, 53.90731019358481, 51.173167151789514, 61.17611323633502, 59.05384425194033, 69.62569482864873, 56.68222235095117, 58.12217150965045, 14.694143956707372, 0.4057191228193622, 0.4338264291084582, 0.08440520794641587, 0.6674099160778908, 19.580697436486524, 73.81040096282959, 51.653045608151345, 76.70638099793466, 56.27033033678609, 75.01887536817982, 22.404150885920373, 16.062249022145426, 35.56055315079228, 25.62540915704543, 34.49759475646481, 61.773556893871685, 34.569550637275945, 35.886376596266224, 54.78898448328818, 52.39402055740357, 1.706867306943863, 0.06595395730748292, 0.08606797880342892, 0.06429941423477666, 0.069927126770058, 0.10291314143086634, 0.14812912161071456, 0.11840980545046831, 0.3068317274653143, 0.18823410023845014, 0.11536156458239402, 0.25976346925862376, 0.14191159798252967, 0.3501161854834326, 0.30656203387245057, 0.1769002737297166, 0.4277926899733082, 0.4159131790361097, 0.4068004712462426, 0.7457897199257728, 38.571164454183275, 89.99188807702835, 64.37981105619862, 64.93332809017551, 50.68947615162019, 58.29592466354371, 26.24121931291396, 45.13085003822081, 53.28446918918241, 37.329506797175256, 62.26990930495724, 73.16337462394469, 64.39860313169419, 73.54953981214955, 66.85558365237328, 9.022118199256159, 0.2633508751469274, 2.018242211591813, 0.12200596006286722, 1.267163359349774, 0.8215230883609864, 44.34352051827216, 76.09152593920308, 71.93417441460394, 70.9291062816497, 70.40505409240723, 61.29622405575168, 60.31155224769347, 54.71451436319659, 59.90567714937272, 59.692786585900095, 61.166530886004054, 65.6094309591478, 69.48742343533424, 77.79686266376127, 55.48088665931456, 51.286551106360655, 65.49346216263311, 48.093569201807824, 55.61859323132423, 53.19416838307535, 53.87815129372382, 38.497663159524244, 43.41985725587414, 75.50771251801523, 75.84523247134301, 63.611512876326046, 64.04523288050007, 65.47956520511259, 63.987707399552875, 57.62137897552983, 53.36727042352, 57.20419568400229, 55.075721509995006, 57.12039424527077, 60.995080163401944, 64.10156203854469, 67.10312443394815, 68.05393834267893, 66.26183878990912, 64.42883283861222, 61.40075129847373, 65.22200669011762, 64.80627467555385, 66.36902147723784, 65.11004263354887, 63.89459817640243, 58.2522020032329, 60.575970988119806, 60.19059027394941, 61.20757456748717, 59.73226131931428, 67.0684193026635, 46.467068195343025, 32.944516597255586, 57.26572982726559, 48.71665339316092, 52.89189877048616, 55.511798858642585, 56.060765943219586, 69.30616286493117, 64.30381513411, 56.966715781919426, 56.033289740162516, 54.27949605449554, 59.5523068981786, 59.02844690507459, 58.426308170441665, 59.86563759465372, 56.32425115954492, 63.33010242831323, 59.84713185218073, 61.61603843012164, 59.669177839832926, 64.7511810641135, 59.97540120155581, 58.80960218368038, 56.08215462776923, 56.40349872650639, 57.90393867800313, 55.347157370659616, 55.64665386753698, 59.95236904390397, 58.51677763846613, 58.917263400170114, 59.25022948172785, 62.94792629057362, 60.68786836439564, 53.65407805288992, 41.529725905387636, 45.88266641862931, 47.690384849425286, 49.44941882164248, 51.67074726473901, 60.1743124377343, 56.93974164224441, 59.49502068181192, 55.91492437547254, 55.38964840673632, 41.526933177824944, 41.61107978513164, 50.6827728209957, 67.55451079337828, 63.93370028465026, 67.47576528979887, 57.90503694165138, 59.17130354912051, 55.910154773342995, 57.09323575419765, 53.62278146128501, 64.45612076790103, 61.14544422395768, 75.00396251678467, 55.84606716709753, 61.554010068216634, 19.019759278143606, 0.6091752828609559, 0.9740307855029261, 0.1769274085639946, 2.252368364603289, 20.18058276945545, 85.34855488807925, 54.97750143851004, 80.01954432456725, 62.87276191096153, 78.15381403892272, 28.97042016829214, 21.945545404188096, 39.62016313306747, 29.827795374778013, 67.56476386900871, 72.98435764928018, 45.443980693817146, 58.680826848553075, 60.752340362918, 71.33527555773335, 4.097158341638504, 0.3352267457352531, 0.2178266365081072, 0.14392386581147873, 0.2528924879527861, 0.17153928236615273, 0.4265255192595144, 0.25371212542297383], [0.10365024824897129, 0.09879746429261663, 0.11859182028039811, 0.11954010689571021, 0.04731853913155295, 0.09855949440069738, 0.06574910539653032, 0.14016211363336734, 0.07034086021444491, 0.4177854672795342, 0.17209864912494538, 0.7473519877079995, 14.180491931976812, 72.85575097607028, 45.74010002997614, 46.87668131243798, 33.808861855537664, 47.6766957775239, 28.08945974996013, 25.980254219424342, 23.45459888058324, 49.146709903593994, 48.263556880335656, 61.31310201460316, 59.65324909456315, 52.944784087519494, 65.37493598076605, 16.825681501819243, 0.3565401391636941, 0.3002464356681993, 0.08555087711541884, 0.3139510131891697, 0.8053512787145953, 33.44243011166973, 72.03360649847215, 68.18702436262562, 65.40909982496693, 61.99446085960635, 55.767364809590006, 55.61119956354941, 61.55980733133132, 61.67105751652872, 56.44325587057299, 52.19152035251741, 54.07427764707997, 66.0388598903533, 64.17765601988762, 73.058286482288, 41.080920465530895, 43.1966116351466, 60.99631571000623, 40.45445519108927, 47.51137571950113, 43.06792651453326, 50.854486342399355, 83.8902255027525, 70.26915181067683, 58.23907383026616, 62.66881042911161, 60.0660667880889, 64.21253373545986, 61.716349124908454, 54.938324805228945, 54.57609391981556, 51.58230566209363, 51.77425861358643, 55.533140474750155, 53.987891366404874, 58.118778659451394, 59.90266084671021, 63.229171999039195, 60.36958763676306, 59.6293540154734, 53.01775586220526, 54.361810914931766, 55.56103244904549, 59.00790545248217, 52.27523942147532, 57.558809326541045, 52.03010305281609, 50.06447784362301, 43.72496274209792, 44.267183349978545, 46.36048563065068, 45.16069143049179, 16.717333870549357, 17.962488320565996, 45.10837877950361, 30.649224019819695, 32.22512056750636, 35.084412713204664, 34.637890092788204, 38.75881456559704, 38.483613229567005, 39.263502013298776, 38.6034220264804, 41.05555057525635, 48.380514114133774, 50.28256946994413, 50.87011306516586, 47.89049240850633, 47.6051046771388, 49.314316703427224, 49.40702584482009, 46.54671584406207, 48.967469353829664, 54.63848706214659, 52.89122020044635, 55.325678471596014, 56.92723712613506, 54.96725620761995, 53.16375040238904, 47.23611947028868, 48.36917846433578, 49.602971769148304, 53.981858761079856, 54.76315175333331, 54.06256152737526, 57.51797353067706, 54.91337853093302, 44.1248679930164, 44.34885101933634, 34.52513371744464, 45.854958795732074, 54.37532348017539, 47.72831416899159, 46.40395333690029, 45.87137391490322, 47.46923377436977, 49.851438230083836, 47.20118291916386, 38.81702253895421, 58.2782857648788, 86.46151957973358, 64.01831365400746, 62.61063775708599, 62.46163475898005, 56.3087813315853, 49.008399286577784, 50.00455971687071, 51.501022385012725, 50.14140336744247, 53.570370751042525, 59.50508156130391, 62.47977572102701, 53.90432134751351, 44.13959649301345, 7.710275121273534, 0.7504586887455756, 0.1157158725864945, 0.06687683278634664, 1.5438419580459597, 21.325228444991573, 53.011189814536806, 46.74770593643189, 65.36911518343034, 53.41432709847727, 64.92517740495744, 14.618259822168659, 18.479911704217237, 26.90281333461885, 23.94458724606422, 66.22421541521626, 46.272903027073035, 31.751359047428256, 48.82420478328582, 58.48712844233359, 40.17239362962785, 0.5378208730009295, 0.08522488372099978, 0.033590358441635486, 0.07839075124432003, 0.022843179082678213, 0.07512325601231667, 0.08932480243064704, 0.06206421098942238, 0.22947475824865604, 0.2257007180202392, 0.08861291522700941, 0.06841058677603161, 0.2202845376826102, 0.06201278350706543, 0.16934350583582156, 0.14891616970060334, 0.09146918212213824, 0.07333696113839265, 0.19185003524105396, 0.6350958371354688, 13.584974158194758, 79.01920657004081, 50.42260592983615, 46.55732585537819, 44.924278413095784, 47.18665838241578, 24.86045675892984, 41.635822096178615, 22.851381494152932, 50.823001477026175, 56.9709558640757, 66.7500562052573, 64.63202730301889, 61.0097929739183, 72.78184567728351, 19.508363046953757, 0.32451950253978856, 0.4940966192272402, 0.4020760989477558, 1.0115018006294005, 0.7342847340529965, 39.823773368712395, 73.58240142945321, 69.53640599404612, 68.91181561254686, 64.888769965018, 58.76262395612655, 57.58577562147572, 64.79111863720802, 62.806269891800426, 58.518068098252826, 54.07226547118157, 55.41384550832934, 66.60890579223633, 62.89178540629726, 71.64512711186563, 42.63886236375378, 45.930103563493304, 59.16079551942887, 44.32503046527986, 52.03043253191056, 47.113466955000355, 58.599724000500096, 87.35292526983446, 69.84247638333228, 59.57161280416674, 65.98450368450534, 61.35013311139999, 66.46671987348988, 62.77909963361679, 59.54740785783338, 56.33652033344392, 55.892413893053615, 52.43704895819388, 58.1233129193706, 56.155644155317745, 60.29223457459481, 60.88797592347669, 64.0331990488114, 62.632355920730106, 60.45897453061996, 56.621264796103205, 58.27846619390673, 60.669248873187655, 61.66335005914012, 57.669808480047415, 56.4441462486021, 55.53775710444297, 56.90160835942915, 52.507655543665734, 53.496598812841604, 55.19860544512349, 57.635562266072924, 31.392913249231157, 30.820400176509736, 52.24117755889893, 45.01286122106737, 43.00107363731631, 49.64081087420064, 42.32248790802495, 48.81880760192872, 44.74510062125422, 46.36260371054373, 46.76532914561611, 50.57311904045844, 54.938250280195675, 54.38364282731087, 56.84941730191631, 51.47684489527057, 52.01386836267287, 54.531696611835116, 54.79842562829295, 53.39098899595199, 55.20033521036948, 56.00496630514822, 54.39588846698884, 54.90297640523603, 57.83977654672439, 55.67979005075271, 53.74648909414969, 54.55577996469314, 52.07071135121008, 53.43150315746185, 57.307091220732666, 56.40201999295143, 55.71325571306291, 61.65170061972834, 57.36953143150576, 47.67491502146567, 47.51426258394795, 36.485561786159394, 46.375202363537205, 54.770200252532966, 49.44582593056464, 50.612221148706254, 47.00184806700676, 48.30059582187284, 51.31684749357162, 49.31073165708973, 40.3083743587617, 54.04183180101457, 75.65471510733329, 65.18637980184248, 62.94778116287724, 64.43654029600083, 59.24698960396552, 52.50971086563603, 53.69210543171052, 54.38917336925384, 52.16064737689111, 58.05484794801282, 62.15534471696424, 66.67329542098507, 58.73515952018, 53.08347125207224, 9.489242088410164, 0.7703798552674632, 1.6425246240631228, 0.16712828599397214, 1.8791177027648496, 28.76016151520514, 65.49337587048932, 53.76911332530361, 71.21939305336245, 60.99355436140492, 73.69569516951039, 15.79258313102107, 22.793073500356368, 32.49281840939676, 24.418831217673517, 51.22610738200527, 60.15142540777884, 31.513131933827555, 50.950580489250925, 67.78077663913851, 45.78926694008612, 0.4393680333610504, 0.024371302326119716, 0.048567691457367716, 0.10065364936787276, 0.155288320515425, 0.08395150003414001, 0.0912218353140258, 0.07647324083072525, 0.2501500004361714, 0.2081718295812607, 0.11655093140659795, 0.17403934902000814, 0.3171874895211189, 0.17365402211585354, 0.3001585194180089, 0.19823314111319282, 0.16273431209546907, 0.3939604086260642, 0.3169534956255267, 0.7266092072090795, 21.790739259412213, 98.66248346144154, 58.239901450372514, 64.71214563615861, 49.88389976562993, 66.9352783695344, 35.62242069552022, 39.159778856462054, 29.86849584887105, 60.0470942835654, 60.650907870261904, 72.84703546954741, 71.13752534312587, 64.65027809143066, 79.75221910784322, 23.283765931283277, 0.5307494524505831, 1.9360267587246436, 0.34340599071114297, 2.212473692432527, 1.0402592704180749, 49.62549794104792, 76.05784062416323, 75.77242543620449, 69.90546180355933, 69.04727858881797, 60.6474797187313, 62.98718137125816, 67.9641003762522, 66.62632111580142, 60.69446579102547, 57.42169895479756, 58.48444161876556, 72.35240105659732, 69.23632114164292, 73.42468292482438, 45.03890183664138, 54.15337616397489, 56.50636680664555, 46.42194132651053, 54.82191278088478, 55.44044310046781, 59.72085898922336, 78.65881135386806, 66.37087283595916, 65.03178350387081, 65.28052845308858, 66.31825031772738, 67.20582777454008, 63.18236635577295, 59.33194814189788, 57.411532171310924, 57.052348967521425, 58.088682313119214, 59.67220590960596, 58.397517973376864, 63.91508471581244, 64.75811973694833, 66.28594567698818, 70.14329864132789, 68.54557606481737, 63.931280182253936, 65.41333598475303, 64.23425974384432, 68.51880196602114, 59.4985233583758, 68.5352445417835, 61.27174454350626, 60.81898535451582, 56.83623029339699, 59.50728985571093, 60.13677143281507, 65.72939272849791, 29.44622524323002, 40.021041131788685, 59.98286154962356, 44.487538183889086, 57.99409435641382, 56.99581976859801, 55.853943286403535, 62.07561862084174, 57.27755577333512, 55.99174399529734, 55.154914163774066, 56.812915725092736, 62.701495539757516, 59.53424046116491, 61.16743303114369, 57.67167945061961, 59.36570405960084, 60.07645322430519, 61.71782393609325, 60.38173913955689, 59.133072207050944, 58.95207443544942, 56.77073063388948, 57.49253696010959, 60.47070241743519, 57.51817357155585, 56.027676828445934, 55.561899292853575, 55.15328245778238, 54.57517608519524, 58.67587289502544, 61.13537942209552, 58.700897616724816, 63.64231524928924, 60.88599904890984, 49.67415102066533, 44.87606856130785, 39.75227248284125, 49.08714086778703, 55.78454871331492, 52.701926615930375, 53.43400955200196, 50.38641422025619, 49.57784506582445, 54.30127697606241, 49.11605658069734, 44.312274917479485, 46.48109459107923, 70.21387777020855, 72.69194495293402, 66.23187972653297, 67.9929925549415, 59.66804427485312, 56.213961955039736, 56.25664910962505, 56.18935300457863, 55.11341156498079, 62.80270445731379, 65.18475986296131, 73.38990719087663, 58.71169590180921, 56.74432131551928, 13.991218939904245, 0.8587314885470175, 2.395978594018567, 0.34701815656115936, 3.4089444193147846, 29.262385714438658, 72.0046672513408, 57.990375949490456, 77.998715677569, 62.993967071656265, 78.44457149505615, 22.020588190324847, 26.193593894281697, 32.74910607645589, 33.465866273449315, 93.2214343163275, 63.60759050615373, 42.812713576901345, 66.20377202187815, 74.09056017475744, 62.68973235161074, 1.4184823944684, 0.2739435728759535, 0.12663935175946645, 0.3773613670660604, 0.21667543618429094, 0.30542047093472174, 0.16595773428918856, 0.1660430764839534], [0.28930146006807206, 0.19186252247421973, 0.07432227278308523, 0.10842250104272559, 0.05791111428651118, 0.11321661798583885, 0.21475404170492005, 0.1390190644850654, 0.10711603001841616, 0.2237454777763736, 0.026450757981247963, 0.14572906007449474, 2.8792447524686016, 64.6088735518917, 49.98482627253379, 45.676800820135306, 30.03949942127351, 55.93852135442919, 25.853832306400424, 30.532511934157345, 6.603289592650629, 12.205838407239607, 66.05544367144185, 56.60755218998079, 63.653105689633286, 51.39017620394307, 63.73891145952287, 34.7720233855709, 0.16620493554059537, 0.13878179173315727, 0.1600689543110709, 0.9734369141440239, 0.6891354341660777, 26.919777585614113, 72.66953252976941, 62.020874100346724, 66.86299693199896, 59.770692702262636, 55.89117834644934, 58.370241811198575, 67.96695586173766, 64.2959939279864, 65.94637040169009, 58.41513726019091, 53.65682763438071, 63.302536010742195, 69.14123504392563, 66.42631946071502, 64.20837602307721, 37.70205351614183, 37.0874337996206, 55.26777252074211, 63.898402875469586, 77.13635121622394, 82.58566087292087, 67.40215809114518, 59.48353990431755, 62.29117247366137, 61.426034896604484, 66.92755130029494, 66.68219135653588, 63.82477998733521, 57.46790839779762, 52.359213444494436, 49.47365514693722, 49.224423823818086, 50.52133590944352, 51.994629136977665, 54.710266436299975, 60.7832133385443, 61.04245062797301, 60.66057651273666, 58.57042781768307, 61.16339691223637, 52.54424733500327, 53.08983725886191, 55.29799438291981, 58.34572307525143, 56.1213626400117, 51.44748987690095, 46.55302301529915, 43.95519802647252, 43.82584610292989, 43.8603590380761, 44.745332041094386, 9.539508242760936, 23.71906861182182, 42.58753815004903, 25.378160592048403, 32.95953927501556, 29.13719346446376, 32.45006849688868, 35.877335533019036, 38.73540978277884, 36.694714330857806, 36.11022233963013, 38.67787253472113, 49.0847364548714, 46.32480775156329, 49.85676480877785, 47.94511533552601, 52.70570778077649, 53.326128682782574, 49.18874202236053, 42.73536443710328, 48.89580765078145, 51.53992837475192, 56.13415348914362, 53.39497412404707, 58.3391256486216, 54.462278504525464, 50.32330328418363, 47.29956380782589, 47.34333353657877, 50.48763098255281, 51.90749368359966, 53.867137278279955, 55.25638195776171, 53.50106639246787, 54.25583239524595, 53.22023645524056, 57.48680637728784, 43.67740792612876, 24.80412171732995, 32.95271042854556, 48.70070895841045, 47.797532235422445, 44.349549201227006, 46.129261908992646, 51.073468346749586, 55.52857875823975, 69.37177627317368, 83.41224547355407, 55.07256400200629, 58.17615901270221, 61.89950420010475, 59.9722711501583, 53.96990337679463, 53.12465613888156, 53.930820880397675, 48.29988587287165, 51.41226699275356, 54.348619984042266, 57.051639018520234, 57.06973291212513, 60.525717581472094, 49.74262775913362, 2.7993455817622523, 1.0981714725494385, 0.7891012055258598, 0.3879484570314808, 1.0472049299747714, 39.032270446900405, 53.86573699212844, 56.34467494103217, 62.34069631945703, 58.10295581817628, 54.55690568493259, 10.230498467722247, 17.75492629697246, 20.956537415904386, 21.84208896852309, 53.11967080639255, 34.49795953689083, 29.72972239217451, 52.8009037048586, 57.466155098330596, 28.839689531633933, 0.22168624875766618, 0.1267050437989735, 0.0406520496753435, 0.07693621074600566, 0.04199530058089764, 0.0640066575649525, 0.08523828259879544, 0.1211341979703115, 0.11994162889858408, 0.17717807253281917, 0.20906004724242996, 0.17936500840850417, 0.0818091964409236, 0.10316732174326336, 0.02995781848327287, 0.02597306385606287, 0.09060612278840235, 0.048144749636130954, 0.14315022426026483, 0.19860110846498322, 2.6621829934658545, 73.28121831340175, 58.39212079201975, 44.774043790755734, 38.64520311355591, 59.27905105775403, 18.94715424506895, 42.04643541766752, 12.719119767988882, 14.52487309132853, 67.62532526446928, 67.11717436390539, 69.19565400769635, 58.337399805745775, 70.60438109982398, 39.41723146746236, 0.5567677595442342, 0.5247353558098117, 0.7354528649199394, 0.49796006191642056, 1.1932670084699508, 32.07437407585883, 75.0556593556558, 64.30106163024902, 70.07434337369858, 60.48328930331815, 56.328189219197924, 61.04005013742755, 68.95014501387074, 65.37314737996748, 70.24870841733872, 60.2871354933708, 56.31656723637735, 62.95164861986714, 68.17597112348004, 66.26941680908203, 65.52779859112155, 38.57826786656534, 44.26833260443903, 60.9691729084138, 68.05364024254584, 78.05449962615967, 78.40124499413275, 63.13436831197431, 62.95272334929436, 64.14626921376875, 64.99191261106922, 66.67331895520611, 66.0459436908845, 64.21809957873437, 61.058795144481046, 55.85168400118428, 54.2613943161503, 52.8937775857987, 50.25162196928456, 57.332551325521166, 57.836320938602576, 62.54661683113345, 62.9130603421119, 66.30650674143146, 61.41392261751237, 62.05173923123268, 60.67848997731363, 60.71373639568206, 61.36888596319384, 60.14354144373248, 59.67768153836651, 57.1780962328757, 52.67207737891905, 52.83393790644985, 50.74282038596369, 54.57843557480843, 50.38192310640889, 24.129781953750122, 37.97033579118791, 52.84301034865841, 38.95887113386585, 42.846049800995864, 43.66180473758329, 45.39191515214982, 42.47819815912555, 44.33676619683543, 44.63049680955949, 45.43336676013085, 47.17631509227138, 55.784842891077844, 54.093450192482244, 57.063492421180975, 50.1663927878103, 54.385882500679266, 57.34407524908743, 54.592795372009284, 48.735402322584584, 53.27448283472369, 54.226410696583415, 56.513689871757265, 55.120079594273726, 58.27559501894059, 56.77029132843018, 53.37567998516945, 51.895204897849794, 52.18820202735163, 53.29843282699586, 54.502161164437574, 55.33367618437737, 56.790770023099846, 56.31008355848251, 54.35786501053841, 53.95910509171025, 56.75193071365357, 45.81823756617885, 28.638285629210937, 37.738484490302305, 47.69262060042351, 49.011211625991336, 48.99573395329137, 50.17186841657085, 50.46817210412795, 53.034869163267075, 59.33060276892878, 76.36031812237155, 57.06358655806511, 61.04945598110076, 62.82291643081173, 64.93521867259857, 56.223642364625015, 54.73371436519008, 55.019800278448294, 52.993201824926565, 54.614901850300456, 58.532494575746604, 59.50692115291473, 64.70402632990192, 62.61400707306401, 56.88774670324018, 3.130078608951261, 0.9806983857866257, 2.323962651914166, 0.39623329956685344, 1.7401048589137293, 47.26006946256084, 59.177622487468106, 63.754283228228175, 66.95536874955701, 68.67412782484486, 57.89841205843034, 10.60001515573071, 26.648114227479507, 28.08446853391586, 22.997070089463268, 47.780666043681485, 45.00196879909885, 30.573041785147886, 52.78556331511467, 63.33276179529006, 28.222163338815015, 0.3582486378089074, 0.1471540142571734, 0.01714415716818504, 0.08700409994250344, 0.07557737761207166, 0.1439934112732449, 0.030374486044409777, 0.052026946157697714, 0.2706018667067251, 0.29233752779902955, 0.2866017968664246, 0.2147049967560076, 0.21070131401140846, 0.157598213502957, 0.23727831370647878, 0.1723465858207595, 0.3672793741908766, 0.35043812627273224, 0.23026562145640775, 0.44210241566742625, 5.850678932282233, 98.0225330783475, 63.03605018123504, 63.59469375302715, 39.76733046193277, 77.60539608616983, 36.61637283140613, 41.004438169540904, 14.31690412182962, 20.09915436467817, 76.44175437188919, 70.46946725537701, 75.92484874110069, 63.29604056573684, 77.9485720972861, 43.870737629552046, 1.0298115471678397, 0.43786218029356777, 0.7505553383981028, 2.6321486696120235, 1.6552997837143562, 42.964466156498084, 80.45515491116433, 69.914012570535, 70.81112923160677, 67.03858575513287, 57.539432817889804, 66.52717928732595, 74.8102915671564, 69.01830011798491, 72.95996835154872, 63.775071790141446, 58.33750178737026, 70.48791808466758, 71.48240366289693, 71.5701941520937, 61.05559056805026, 41.84633178095664, 49.21043665178361, 61.93847294776671, 67.99332987877631, 72.78079448207733, 73.2056656191426, 64.59791444963025, 66.85414806489023, 65.82866791755923, 68.26285162279683, 71.13088084805396, 68.60399584616385, 66.4996285592356, 60.62369446600638, 55.973712859615205, 54.86383115091632, 54.32839232106363, 52.87039241483135, 60.44544627589565, 61.83800143580284, 67.35166934228712, 66.77206854666433, 70.88564642014043, 65.186164071483, 68.80060072868102, 66.55375726761358, 62.3327378303774, 68.52760376468783, 66.42736281118086, 65.04220131904849, 61.250273489183, 58.98010761507096, 54.784967976231734, 57.64834919283467, 60.89611876395441, 61.00121867272162, 25.350219588125906, 45.60764158925703, 52.01253867918446, 45.1471867099885, 53.66559413171584, 50.035299331911155, 57.58850559111565, 57.42224808662169, 59.79735697469404, 51.777769134890654, 53.22544144045923, 51.55035795704011, 61.02707101452736, 56.557455678139966, 63.175725783071215, 56.22692146608907, 60.96344232559205, 62.50053682634908, 60.47885702502344, 55.44627566491404, 57.534937781672326, 59.435702677695986, 60.556268922744266, 54.794554248932876, 59.85673381436256, 58.00509268237699, 56.41669750213624, 53.811263115175315, 52.71325049861785, 56.79168001297982, 58.02628917078818, 56.776068979694, 58.474427807715635, 60.05293469275198, 56.64243775029337, 54.141801249596384, 57.211322630605395, 46.94581700909523, 36.0392431289919, 44.21406661310504, 51.52563133547383, 53.12580147097188, 51.89528726762342, 48.91654129951231, 51.70974346899217, 53.3750916296436, 53.74923475327031, 76.6965280040618, 74.12005639845326, 62.88764338339529, 65.59822082519531, 66.06953282510081, 59.056068235828036, 58.242749091117616, 57.05161156192903, 55.73863344807779, 58.40753178442679, 62.56288682260821, 62.61022983058807, 66.72431761218657, 66.58413210222798, 60.81218396463702, 5.72942425166407, 2.8633267937168, 3.3738335678654336, 0.5969532999780871, 1.5211320476185892, 49.4165885833002, 65.14136275937481, 66.73023254640641, 73.78705501556396, 69.28488792911654, 64.89937605396395, 15.6524182135059, 24.003893483069636, 28.51559977377615, 31.56163400219333, 74.81586917754143, 45.32978088625016, 41.48029619647611, 64.95159064569782, 74.89262996181365, 46.930641358898534, 0.31174814268465967, 0.2282962545512184, 0.23788045881496322, 0.2198267235390602, 0.17167198411639661, 0.19495603147773974, 0.29495209395404787, 0.14664626650271878], [0.25234243682315277, 0.29965388198052684, 0.06892643207984586, 0.15516928577375028, 0.11330000665639678, 0.07833118024732798, 0.0548960182124809, 0.2366902799375596, 0.24020919756543255, 0.19790432085433315, 0.08039102979725407, 0.10844981973810543, 0.12594551358732486, 50.78253830632856, 55.71905689854776, 48.03386288304483, 41.39823629010109, 49.00657930681783, 41.298910110227524, 25.812794508472567, 21.222472152402325, 5.9023272318224755, 53.75998596991263, 62.27198816114857, 63.64937159322924, 54.0820792413527, 59.565529208029474, 46.83481785558885, 0.062245160957137426, 0.08340560876193547, 0.6180312592656382, 0.31844470109189715, 1.1918569163930033, 14.291721524730807, 68.15450006915678, 58.907488853700706, 69.38537120819092, 60.58349409411031, 62.56426749690887, 63.84344262461509, 70.16637002268146, 63.53115135623563, 65.07207016791067, 56.03454882098783, 56.36185884475709, 59.24547164670883, 69.78544512102681, 59.92955261661161, 69.53996750616258, 46.64856410795643, 54.240299809363584, 55.81146009506718, 60.51446037907755, 62.28818362759006, 51.814659026361284, 56.17045110271823, 58.41333689228181, 61.61117469110797, 62.845105278876524, 61.391663166784475, 59.18529856589533, 62.29857006380635, 55.39226855001142, 52.160059021365264, 50.66144689436882, 50.19488880711217, 46.69611500155541, 50.67160191074495, 55.8875423092996, 56.463554136214725, 56.92148693146245, 59.07790407057732, 58.16696889938847, 58.38850044435071, 57.78844056590911, 51.32023249903033, 53.482015440540934, 57.069215159262384, 53.750309482697524, 52.69653727931362, 47.95771791088966, 41.554334855848744, 40.836748999934045, 43.24207582781392, 38.86840951058173, 7.697026335423993, 25.806701106409875, 37.30391725417107, 24.367220670946185, 34.15216730486962, 31.48019971386079, 32.51026707310831, 34.7617506980896, 32.5008886860263, 32.862186047338675, 36.10392301313339, 38.37928995009392, 46.12426873176329, 47.572415644122714, 46.99924753558251, 49.50574013494676, 50.47870759041079, 52.00530582858671, 48.2934178844575, 48.83780756304341, 54.1209852310919, 53.61128107193978, 54.033916458006836, 55.03611733836513, 52.28345678698633, 48.99485534237277, 50.49157296457599, 45.80713333622102, 47.975082243642504, 51.41686008822534, 54.3450584719258, 53.26772851328696, 52.11037828076271, 55.61583972746327, 57.30377289556689, 57.58568932933193, 57.014035255678245, 64.8468319831356, 59.74759778668804, 46.193192620431226, 46.40508297950991, 46.88595379552534, 46.71413829249721, 52.455648837550996, 61.287422257085005, 62.77903687569403, 49.465873164515344, 27.554189582024854, 42.31089338179558, 61.431741945205204, 59.45092147396457, 59.47645218141618, 53.77622850479619, 52.430549590818345, 54.53146519199495, 51.89852322301557, 54.79633500499111, 54.597341399038996, 61.09335514806933, 57.41045744188371, 61.10872299440446, 43.214344670695645, 0.6680509784529287, 1.7123402390749225, 2.8034086669645, 0.9078944149997927, 5.060131597903467, 57.70745538896131, 49.25746587014968, 63.03915277604134, 58.03213742471511, 61.367595503407145, 43.32422987107308, 5.081300629723457, 29.52042668096481, 20.42705862752853, 27.446706833377963, 45.82670596338088, 35.88206591144685, 35.65847119977398, 48.576067801444765, 64.67653051499398, 11.879464849348992, 0.5436269001614663, 0.030084240227757447, 0.05305790132091892, 0.13104712290148582, 0.06972207567624508, 0.18260683203416486, 0.08275078744777749, 0.09402464459379835, 0.16332395464902924, 0.3126158445112167, 0.09177459839491114, 0.13310603016326505, 0.035759950086714766, 0.06288605479283199, 0.05610373667291096, 0.15792611445630753, 0.17974604522028279, 0.0245317479505414, 0.17391584032485563, 0.057702562170884306, 0.12456555940931845, 56.12727365186138, 66.27653983331496, 50.455510693211714, 39.54333959087249, 61.724939115585826, 30.259542426755353, 32.51598000526428, 28.690056993115334, 6.8088972953058065, 56.41821153702275, 68.22363576581402, 71.7540591762912, 61.329175887569306, 66.79356313520863, 54.81099682469522, 1.0235143044302542, 1.4935197873461632, 2.6981925579809376, 0.8175198193038664, 1.1092592775821686, 17.357611771552794, 77.03537371850784, 61.207198019950624, 71.78688941463348, 61.38169250180645, 64.11244661577287, 65.82532605817242, 70.87110227154147, 65.54254670296946, 67.58093972359934, 58.90602580962643, 58.96916027992003, 59.69470462491436, 69.88910551994078, 63.53723495237289, 71.39182829087781, 46.28246576555314, 57.5538279164222, 55.43028416172151, 58.94975631467758, 59.07854341691541, 54.14568047369681, 61.8505451756139, 61.010585292693115, 60.353549065128455, 67.21601024750741, 63.07241839747276, 61.26116983352169, 64.38867169041788, 59.73740354661019, 56.13762478674612, 54.3969435845652, 51.53820645424628, 51.944924862154075, 51.85988003207792, 57.96334297426286, 61.43973965798656, 59.310194676922215, 62.411393119442856, 62.097783934685495, 64.69250632870582, 63.22015447001304, 57.36662887757825, 58.21795578925841, 61.381837629502826, 58.496338167498195, 57.88917487667453, 56.847824819626354, 51.32055413338446, 49.6395557157455, 53.08502843303066, 46.357351656883, 23.871034960592947, 40.554103005316954, 48.23722208699873, 34.109386013400176, 43.60726810270741, 42.036543200092936, 41.812944566049886, 43.961987649240804, 44.185723566239886, 47.298555758691606, 45.613870313090665, 49.06232403170679, 55.101111012120406, 55.72106907444616, 54.319527764474195, 56.4863548740264, 55.04670381546021, 57.53234117261825, 53.60081226594987, 49.56587791442872, 56.00362485454929, 56.59007803086312, 57.5648654660871, 56.65441274642945, 56.13647160991546, 52.858542934540786, 52.26329188193045, 50.182078346129394, 50.61156611288748, 55.293871971868704, 57.94120903938048, 55.41429265852898, 56.15041171350787, 56.318398983247825, 57.36788011366322, 59.539229716024096, 58.2464361190796, 61.17883928360478, 58.888163335861705, 51.393231730307306, 50.183866946927964, 51.300028370272734, 50.62055226295225, 52.10891131431826, 55.57535302254462, 57.25311156242125, 48.97936982493247, 35.986177382930634, 47.653730300164995, 62.88634507886825, 64.3103733370381, 63.734318364051084, 54.21465535317698, 54.81765700924782, 57.41132820806196, 56.349189589100504, 56.691687030176965, 59.10303469627135, 65.254429001962, 63.15721611822806, 65.27690418304937, 48.48850873208816, 0.5086540671125536, 2.844878415907583, 3.8219699984596627, 1.0267940800516837, 7.004203873295938, 62.103898909784135, 51.845265280815866, 68.46868976469963, 62.16570369658932, 75.65598595526912, 39.95890686588903, 9.317627606853362, 35.72006810096003, 25.896382178029707, 24.308296865032567, 47.4831424990008, 47.55600836969192, 28.237333105456447, 55.3988895108623, 75.01453722676924, 15.221086932766823, 0.4569264621503892, 0.12018595732027486, 0.10200060047810117, 0.14798773242340935, 0.06413524542304297, 0.12893947712596388, 0.030188433931119023, 0.12080952990800144, 0.4060176519616958, 0.3621881070636934, 0.1424927063166134, 0.28646911043793927, 0.22853406356467357, 0.2189025150672082, 0.12740730893828217, 0.3762430012706788, 0.3243979397079637, 0.27020150915749613, 0.47693309344110957, 0.0948261104584221, 0.35360237583518034, 78.13736361842003, 71.3088309380316, 68.75030809833159, 54.43388838921824, 70.33206662824078, 59.834160574020885, 33.4843014132592, 29.519565720711988, 10.334520705284612, 65.95548598997055, 73.98523669089042, 74.82287453066918, 64.23940197114023, 73.38773419780117, 60.1467695543843, 2.086591595603574, 2.116166266702837, 2.9748699309364444, 1.543132499341042, 1.9046956012325904, 25.341015746516568, 84.19323644330426, 67.32055710208031, 76.63454671059885, 65.10062502276513, 68.63668487917992, 71.30395150953724, 73.1821470875894, 66.2053252804664, 69.4915811477169, 61.565510457561864, 62.8210219260185, 65.00589586073353, 72.60522919316446, 64.22045300083776, 70.38627378402218, 45.27736233126733, 54.78167710765716, 54.946075408689445, 60.41505182943037, 57.91725120236797, 55.564182112293864, 65.94012598837575, 63.56689591561595, 63.80043775804582, 68.55965737373599, 65.29965393004879, 62.51202937095397, 64.4160851355522, 59.50315567754931, 58.40585693236321, 56.83807772974814, 54.38187383836316, 51.91704857733942, 56.02155400860695, 59.860742476678666, 63.73476551425073, 60.67013140647643, 68.67342179821384, 64.33859086805775, 66.4313244050549, 67.21732816388531, 64.43273559693368, 61.495802094859464, 67.20126998039984, 63.771259246333955, 64.26215564050983, 60.75499580752466, 58.53865661928731, 57.170431921559, 62.23290958712178, 54.820638010578776, 25.29436307568704, 40.66327041195285, 55.172529528217936, 42.73067720474736, 54.53241832794682, 51.56552184012629, 53.51496727235856, 57.03390990534137, 54.88821652627761, 55.083177935692575, 53.207425994257775, 54.35478202758297, 60.250363273005334, 59.95992745122602, 56.74535289887459, 58.60538398065875, 57.891269422346554, 59.60786334929928, 58.08396762417209, 58.657504435508486, 62.59518361860707, 60.856604806838504, 58.23318635263751, 60.663581048288655, 56.40482056525446, 53.13239889760172, 55.51432878740373, 52.56964468186902, 53.26095850236955, 57.90813169171734, 60.096127833089525, 59.34351913390621, 59.57040863652384, 58.68662411166776, 62.64970064163209, 62.03241371339368, 60.99988114449286, 63.241778496773016, 59.261435693310155, 55.251310333128906, 56.08533959234915, 57.47309769353559, 52.43458570972566, 55.164637719431234, 58.1509970080468, 58.421213011587824, 59.6472910142714, 51.20502856469924, 52.50188181477209, 66.84886855463829, 65.92558183977681, 65.8905158504363, 58.883546706168886, 58.259740798704094, 60.27441916927215, 57.79625784966254, 61.72443705220377, 61.916986203962765, 67.96978781300207, 66.91376024676909, 68.0916166305542, 54.72834071805401, 2.081468244714122, 4.724425250484098, 9.382168246853738, 1.2589276077285891, 8.310124662614639, 67.8713990795997, 60.555453069748424, 74.27906144049861, 67.89679250409527, 75.14087677001953, 51.841005586808734, 9.74692709984318, 38.459400438493304, 29.82331014448597, 39.44475081659133, 67.1241875617735, 51.294713558689246, 48.039648379049, 62.88965948166386, 88.9865061544603, 22.809827904547415, 0.5984348527366116, 0.21903405236380719, 0.3113770803376552, 0.22559135130816893, 0.10572591751453378, 0.24665009711057911, 0.14647656270573217, 0.21726612061742814], [0.49168711948779326, 0.2667070450561662, 0.1470077374289113, 0.0432040915644217, 0.08804819351362606, 0.04445911595417608, 0.05904625740743453, 0.09040985872308094, 0.12302556180305059, 0.051731408588708415, 0.12239032169623722, 0.22782265899642823, 0.37069631019426935, 23.0424323005061, 59.756144631293516, 48.283058904832416, 51.384284803944254, 32.83063450167256, 50.530302447657434, 22.705596800773378, 20.81624992432133, 2.335674604100566, 28.005054266222064, 66.22356430176767, 59.96380275295627, 66.73111115732502, 56.28419199297505, 59.76974348868094, 3.3748180827786847, 0.9440139284537685, 1.8716021963665563, 0.21238376566719627, 0.8764513473837607, 3.852863076233095, 58.73068017344321, 61.592606190712225, 71.49359026262837, 65.14349260637837, 63.14099711756553, 63.302896868798044, 67.9868422785113, 66.602888876392, 66.66548205960181, 60.83932676622945, 57.73598278722456, 61.13553631690241, 68.5347189441804, 62.61873352912165, 64.83381363653368, 46.853833506184245, 46.13407465719408, 51.03033404196463, 53.90752984631447, 56.53268198813162, 55.58993247247512, 60.792674095399924, 64.07331705093384, 63.00170983037641, 58.98041748231458, 59.15162109559583, 57.007975193762014, 56.672592932178134, 54.315068029588275, 51.365331911271625, 52.57010752154935, 51.81949530878375, 47.627077794844105, 49.40953616173037, 54.241637337592344, 55.121487725165586, 58.120202479823945, 55.755727137288744, 53.70899123530234, 61.82999587828114, 57.59850371268488, 55.41493592723724, 52.19240288580618, 55.77506049986809, 53.45364493708457, 53.88745123340238, 46.18577541843538, 47.28810656455256, 39.64692546475319, 41.47190624667753, 34.97899901482367, 4.728515792277552, 26.61905730924299, 32.63074071176591, 27.32291683073967, 30.84398734954096, 29.162794774578465, 35.641467725076986, 36.60974402581492, 32.47291434195734, 33.99575887187835, 34.763876622723, 35.95679883033999, 45.9328099989122, 47.406989682105284, 49.56822349179176, 47.3043373323256, 52.02799674003355, 47.822505966309585, 44.6255075547003, 51.056531552345525, 52.781366379030295, 55.329898941901426, 49.59328351482269, 52.828415209247225, 51.93268314484627, 50.67038597599153, 47.771538688290505, 45.41029930114747, 49.283573166016616, 51.07226417910669, 55.13039542782692, 53.80858413634762, 55.200645077613096, 54.789031551730254, 56.24760020163752, 56.0463120091346, 55.951304358820764, 54.17030903600878, 65.13772672222507, 77.05177707056846, 75.64820397284724, 60.98310124489569, 54.590783196110884, 51.83820893687587, 47.585716401377034, 37.56562955917851, 30.564271365442586, 48.425758654071444, 63.37646092137983, 61.12408691836942, 62.385740818515906, 56.35914848696802, 52.94828676408338, 55.340618779582364, 54.18279786263743, 53.97283730968353, 63.35932408609698, 57.112573039147165, 59.99323621872933, 56.1378130605144, 64.25400887766193, 20.504074365861957, 0.34323665463636, 1.3032600740271232, 1.3052732305180643, 0.9748628795627625, 25.97641618021073, 54.84466252788421, 47.26361920756679, 66.94159338551184, 53.59419914983935, 54.571045829403786, 24.20811756964653, 10.64029593621531, 45.13979696458386, 12.927950678333161, 40.924315914031, 52.11819164214596, 24.258712222499234, 36.94588330484206, 50.493110533683534, 55.91131971728418, 6.850709271046424, 0.32555271000150715, 0.030154881195255348, 0.05011554529529907, 0.020285793730328162, 0.06689370970331854, 0.12477804155599688, 0.10687839720518359, 0.21159512411442497, 0.07522575857658541, 0.1217836183646033, 0.1525933151283572, 0.14979003087407158, 0.06081999226983997, 0.08390073138739794, 0.08363484525151792, 0.25376553707305466, 0.12815551637040992, 0.019827090924785986, 0.3588397206077653, 0.17813603483861495, 0.5609786690723512, 24.964442714568108, 72.54596217986077, 51.360625067064845, 50.27875300376646, 47.521907283413796, 42.047062996895086, 22.84999493629702, 35.528452473302046, 2.889889084523724, 28.529516343147527, 74.35014263276132, 68.9776800524804, 73.92162369143578, 62.75798943734939, 69.43188267369425, 5.723125415463602, 0.9354102094807933, 4.3306344843679865, 1.0877056083371563, 0.8866946170887641, 4.884074541830248, 67.79925884739046, 63.46940148261286, 74.73775909792992, 67.2467145612163, 65.96543312072754, 64.04486810007404, 70.01284845413701, 67.6555275147961, 68.45847591277092, 63.47399457808464, 59.67534772811398, 63.75514614966608, 70.92145765981367, 64.37057779681298, 65.64819182119062, 49.57650753759569, 46.77865735946163, 49.60902006395402, 55.55732188686248, 59.06404633675853, 60.77098731071719, 59.73865870506533, 66.02125629301995, 63.992841782108435, 65.40312997756466, 61.182145841660045, 59.689307443557254, 60.522826794655096, 58.92594752773162, 52.61428909917032, 57.594091046241026, 53.1757842340777, 48.69884191020843, 53.96782452060331, 55.87990937694427, 57.8955408834642, 59.92647355602634, 61.17139070264755, 60.099073533088934, 62.22584932081161, 62.567036690250525, 59.662760842231016, 55.92611097520398, 59.35051664229363, 57.77482601904101, 57.74605543382707, 55.32167373165008, 53.15362676497429, 49.60496041082567, 51.22250272381691, 47.16307709293981, 22.68205277381405, 43.548691426554036, 41.94081383366739, 34.65466214764503, 43.41349124908448, 41.42820319821758, 44.80665437636837, 44.681366028324256, 44.1729131052571, 44.705386623259514, 44.19536475212344, 44.271337139991026, 53.00921686234013, 55.61023466048702, 53.45374691870905, 53.87885339798466, 57.26938155389602, 56.328581456215154, 50.39517679522115, 56.90192214904293, 55.88904065470542, 57.53045451256537, 52.11036259128202, 53.624621052895826, 54.02983327065745, 53.07634038309897, 52.36626978843443, 48.438019983230106, 51.82246062063402, 57.673872055545935, 58.44237419866747, 55.83368424446353, 57.65129489283408, 56.63766814816383, 59.33227369862219, 59.09058117097425, 57.36822528223838, 58.89072072121405, 60.63945454935874, 68.08932596637358, 72.70469265599405, 62.41813175139889, 60.662506318861446, 56.11835418208953, 50.153111642406834, 42.64755825842581, 36.82842400766189, 51.576881024145315, 63.932154870802364, 64.5933723449707, 65.39627759687363, 59.08394452064269, 55.924322374405406, 58.108184337615974, 58.17138941057267, 58.08488938116259, 64.45868599799373, 60.78513137755856, 66.16487779924947, 60.79040304307015, 70.14198072495, 22.122395269332394, 1.0074162230856958, 5.715703800801308, 2.7555952197121036, 1.6837342708341538, 31.94915633047781, 66.74082294587167, 51.279008388519294, 73.28222244016587, 59.62861660988101, 58.65437438411098, 24.592966802658577, 18.24082951391897, 46.00140833085584, 18.394407956830918, 29.230557641675396, 59.44693242349933, 27.66088785663728, 35.73846009469802, 59.92219032779817, 57.36971578290386, 6.986025158436068, 0.2553141838119876, 0.15444733983566686, 0.08415029985049079, 0.18302605066808963, 0.05341051627070673, 0.12077936136554326, 0.024718022229330196, 0.2770052892306159, 0.6521780043840408, 0.27799878269433975, 0.2939044533958358, 0.2891837889629026, 0.21171769818230984, 0.19387881992565048, 0.13283285853122512, 0.48483388077828193, 0.26862091655212067, 0.17077054377765427, 0.7801540953017051, 0.42658288392328453, 0.7515709871245969, 39.277249920752745, 85.4336154076361, 62.50250977854576, 64.6368125946291, 47.150670636084776, 72.14231891016807, 28.361752648507398, 31.924008054118005, 5.745741801877176, 38.804961250674346, 79.14603248719247, 72.10663318634033, 76.5931421710599, 68.34005171252836, 74.34173307111188, 5.89081262388537, 2.5508835334931654, 5.364920843032099, 1.2425731627210495, 1.3166387883886215, 9.34617461696748, 76.52779548398911, 64.938074158084, 80.64015742271178, 73.02852353742047, 70.75669457835536, 67.39589014360982, 75.37773301524501, 70.42129270492062, 72.74344567329653, 67.25278639024305, 63.95662653830744, 67.17618250077771, 75.47063827514648, 65.61971541373961, 68.87060719151651, 43.999909124066754, 48.44335048429428, 49.16816526843656, 57.14416773088517, 59.33056746759723, 63.08652716298258, 65.67076113916212, 70.24998711001489, 65.0541449362232, 68.57228740569084, 62.64505655534806, 62.02740092431346, 59.58535678925053, 59.97563654376615, 54.13080684600338, 59.86542186429424, 55.15474942422683, 51.26580569051927, 55.87862283952775, 60.18392224465648, 60.25215579617409, 62.6276098528216, 67.76969202103155, 61.64219279443065, 69.96885515028431, 69.13424538027856, 65.35479460993122, 61.5122329035113, 65.73418586484848, 65.78226627842074, 65.31762230780818, 59.571628493647424, 63.13556463487687, 56.535721825015166, 61.74317029214675, 53.36650163896623, 18.54022010680168, 37.22374400784893, 51.48995737875662, 44.411448124916326, 51.9910676248612, 49.33775286520682, 58.3597690828385, 57.06667346339072, 54.278150681526434, 51.500983161311, 50.51288712409235, 50.04392462392008, 57.61077680895406, 58.262094220807484, 57.30288643990794, 55.08899481065812, 59.252265191847286, 58.23101335956205, 54.39117377804172, 60.824104047590694, 60.573511662021765, 61.32031133097988, 54.496222695996686, 54.76532866877895, 54.16546883121614, 56.176024790733095, 54.91823442520634, 51.34904230794599, 53.464898217108946, 59.78801388894359, 61.47524495278636, 58.896368934262185, 59.32720991872973, 60.20153368673017, 60.278388607886534, 61.06719686139015, 60.528886856571326, 62.081933636819166, 62.182805230540616, 68.23971748352051, 73.36878914986887, 65.52058927474484, 60.69172405427503, 59.352497439230646, 53.48702822962115, 49.2737280168841, 39.41845916932629, 49.318019420869895, 65.98613539049703, 67.92079740954985, 68.49470292368244, 62.6486219898347, 56.61490663405388, 60.57393527800038, 59.44496339367282, 61.59370445436048, 69.39494963615172, 63.89518260955811, 71.688657576038, 66.26936974063997, 73.0385491155809, 29.642449655840476, 1.3871609203277098, 7.722655102129906, 6.643189412932243, 2.5618445969397023, 33.79733400960123, 67.96634397199078, 57.30889158864176, 77.61141300201416, 62.65014779183173, 66.91041838738226, 31.245471354453798, 16.415511408159812, 55.50526811230568, 19.987011840266568, 56.28063440322877, 74.87355155329551, 33.235101469101444, 56.04411940420828, 63.46575760072278, 79.66357354194888, 15.544324555704671, 0.620454732448824, 0.19309802311322383, 0.12484473717068473, 0.3633211204601873, 0.28726887558737113, 0.24104446322927553, 0.18202085138088275, 0.3117705430955656], [0.14398377388715744, 0.1094982187233625, 0.2742228885331462, 0.17830961504049841, 0.09033939395580562, 0.08473224322041197, 0.05235754374054171, 0.08086935211453708, 0.14422565848836977, 0.15992687564463387, 0.25507285079408076, 0.28153194955760436, 0.35553806551521827, 7.380352308673244, 62.73193705466486, 51.97459759250764, 49.09583284008888, 24.905915068041896, 57.45550978568293, 24.626493261706447, 31.888345864511308, 6.768396371795285, 12.123568654060366, 72.12488789712229, 57.62979638191962, 58.77134338501961, 53.7368949767082, 63.683574661131836, 19.073364350103564, 0.6917635447555973, 1.5522916014156036, 1.5549342983192014, 0.09986527594587497, 0.4910595402602227, 31.80163206592683, 67.43894207862117, 68.14287416396603, 70.90025332666212, 67.21582197373914, 66.28120745382002, 68.21124892080984, 67.24117617453298, 61.43899048528364, 62.217855530400435, 60.657481762670706, 64.42320031504478, 66.22463118645453, 64.04235778316375, 50.62342343791839, 62.02927189488565, 52.33289041826802, 52.22668047874205, 61.962179753088186, 53.339927581048784, 52.9265489885884, 44.16434664880076, 49.51626385411909, 56.94966916115054, 61.05481786112632, 59.291598719935266, 58.46038572249874, 57.90491927054621, 53.67447830015614, 51.37836202498406, 53.6710972170676, 51.192790769761615, 50.12247400899088, 46.50039657469719, 48.39718418736612, 49.031753078583755, 50.32851611414264, 51.12264702397009, 52.206229240663596, 58.37806301732218, 58.64888698823991, 56.521283580410866, 56.24927897607127, 51.5516641063075, 53.28160978132679, 50.35761617845105, 47.74619625460717, 43.52414915638585, 37.24224190558157, 39.14624275699739, 35.25287851210564, 5.64657889066204, 19.635485103053433, 32.64396694398696, 29.08157817779049, 29.676252641985496, 26.991464784068448, 36.564538709578976, 37.74269711586737, 34.798181672250074, 37.35535129424065, 39.115852232902284, 36.65091322314355, 43.40693696852654, 49.64487052732899, 52.201165460771136, 45.57135574279293, 45.06789599695514, 47.391260977714296, 48.938106490719704, 52.78316282456922, 53.08596587950184, 51.81357252982355, 48.875936923488496, 46.59617693193498, 46.68418315149123, 44.76329649648359, 43.63537972973239, 48.90361708979453, 51.298957563215694, 53.606185913085945, 55.251227963355284, 53.92679260623071, 52.82566562775643, 55.44986071125154, 55.41121752031388, 58.22041903772662, 58.14885539393271, 59.45407898195329, 52.592249301172075, 59.25740741914319, 59.110196944205995, 53.989209282782774, 56.01102636706445, 53.22403330956736, 46.25956304611699, 53.19885953780144, 43.99718699916717, 52.99901085515177, 61.107373699065185, 63.1609227580409, 59.94132364949873, 53.44017551791284, 52.73277213496547, 59.00752890494562, 58.12332860885128, 57.99009746120822, 61.23572934058405, 57.95655727386475, 58.05195323882565, 60.712928387426565, 50.103313230699115, 2.7791745480029815, 0.561213030690147, 0.9877243926448207, 0.6234288696319826, 0.8149230263886914, 44.621679321412124, 63.8191278519169, 55.79824170758648, 63.762790849131925, 46.35005212599232, 65.38617749367991, 19.02762559152419, 13.57534375882918, 45.858449705185436, 12.901378581600806, 51.73847090813422, 41.95834290596747, 29.287433970359068, 40.79876084481516, 57.04663407418036, 31.219942608187278, 1.0610821530703576, 0.13395597407173726, 0.06421909374635547, 0.039947390511271455, 0.02995673063842039, 0.13638873224056539, 0.07096219582543259, 0.019815465540535027, 0.11727332933655671, 0.18567896718459745, 0.2668327141192652, 0.24318333474859116, 0.21944533432683638, 0.13568855852129, 0.0552519426621016, 0.0297378305901563, 0.1500848215073347, 0.05437119435819407, 0.10059938736019597, 0.2698807634653584, 0.19546276799613432, 0.49214232893240073, 9.056219285534276, 69.328488995952, 61.59177857060587, 47.55134467155703, 31.16028924142161, 64.17410627488168, 17.78485986494249, 43.488985107791045, 8.448966760789196, 15.448129407821165, 76.7329119097802, 67.39502722217192, 69.18380844977595, 64.07698838941513, 69.73922391091624, 25.796748092097623, 0.43875632747527094, 3.28453786911503, 3.637278334748361, 0.39213690486165786, 0.552048106347361, 37.84257242756505, 73.0475470327562, 70.5764538241971, 70.9488985615392, 67.60972992066415, 67.00155073596586, 68.99558959468719, 70.86659939058366, 64.49686634925105, 66.12492453667426, 63.03653655513641, 62.736883163452156, 66.97557680068478, 67.9492659722605, 52.15661910272414, 64.89950156980946, 56.03965182458201, 53.38106147704586, 60.246417368611986, 53.12625646591187, 55.27318539157991, 49.38467225720806, 51.824853266439135, 60.032444230971805, 64.30969476699829, 60.15376314040154, 62.03122523523147, 60.77283474706835, 57.94132671048565, 56.18248885677707, 55.020404323454834, 56.61977037306755, 53.99873279756116, 49.33344610275761, 51.93171039704354, 54.13050090112994, 53.74673228110037, 55.14597900452153, 57.985743630316954, 62.72641435746224, 60.53245229105796, 60.13694793947282, 58.71068785267492, 58.10339512363557, 57.550034984465576, 57.84269479013259, 55.310126273862785, 51.45911970446187, 46.78315239567911, 49.008775834114324, 48.13133378182688, 25.384610929796775, 41.50093963069301, 39.1966099123801, 39.36590333138743, 37.43124131233462, 37.58365677249047, 41.59307218367054, 46.292554101636334, 45.75940985833445, 49.39058719142791, 46.96353435516358, 44.49388065645772, 52.804684869704715, 56.01352883923439, 58.191440566893554, 49.02355140255344, 50.24049028273552, 51.622149098304014, 53.9946888339135, 55.90026647813859, 57.07772278016614, 56.40215335353729, 51.26122436215801, 50.8716231776822, 50.0274859705279, 48.83464221031436, 47.70515649549423, 50.829077228423095, 52.919104330001346, 55.453269250931285, 58.701740926311864, 57.3505824612033, 54.47631274500201, 59.023822430641424, 56.238723877937566, 58.86198935970184, 58.491690158844, 62.55925863019882, 57.51907179432531, 58.82358151097452, 58.858553363430886, 54.5772784756076, 56.57408652767059, 56.134396676094305, 50.148828414178666, 53.167668850191184, 45.788011781630985, 53.70912067351803, 60.8606566152265, 63.7393742992032, 63.61990282612463, 54.24710119924238, 54.67620457372358, 60.63973696001115, 62.530205634332475, 62.98170966486778, 63.272584792106386, 62.26533974370649, 61.091048794408, 66.10670904959402, 53.03467304475846, 2.0418760853428997, 1.5481254314222646, 3.4504695717365514, 0.5244428327968044, 1.2721880381145787, 49.96386120396276, 68.53608392900037, 58.49040362142748, 69.67488135060957, 51.003010811344275, 67.97045461593136, 20.273386047732448, 17.89081288922218, 49.718669922121116, 17.11858645562203, 37.17970363555416, 52.96474110695624, 32.10558241413486, 39.824055779364805, 69.20498924870645, 38.50542160772508, 0.7998402873354574, 0.06911924874950802, 0.028488013683067217, 0.09147240735229947, 0.08676341809933225, 0.01636207141282578, 0.10154000543538602, 0.05037441023535306, 0.1284619132357259, 0.32453007455314364, 0.2502147655092901, 0.49009846763745435, 0.42634426285662963, 0.21607753520290698, 0.16146979204589323, 0.1828016328715509, 0.2219400536869803, 0.17347618246511107, 0.37405428807100943, 0.4447072984710817, 0.40066514885233295, 0.775203267412801, 13.870759029542247, 90.6750943583827, 68.50078259744953, 66.84442058686288, 33.975676336596095, 84.39017864965624, 35.16074595912811, 43.35863690222464, 10.486183070367384, 18.80341506773426, 79.91190664229855, 71.03179393276092, 70.4079488015944, 67.20913041022517, 75.67172250440045, 27.75811556846865, 1.7342785457449577, 6.644608820638349, 3.7335105000003694, 0.8819340241532173, 1.4727639527090135, 47.45536035107028, 77.7407100123744, 77.56068106620543, 73.58418218551144, 74.12899155770579, 72.11272854958811, 73.54700596101823, 73.33413893176665, 68.26351058098578, 67.69548862211167, 66.06489658355713, 67.65142471559587, 71.67010476512294, 67.63900649163031, 58.11466017077046, 61.4244737932759, 52.84565010378438, 53.59998072347334, 59.995550417131, 52.85741721430133, 53.89796710783436, 51.89343590890208, 57.03704387910905, 65.95332084163543, 66.37171222317603, 64.18218243506648, 64.25292630349436, 61.28409608717888, 59.90498288985222, 58.06131985879714, 58.04587748742873, 57.33514793457524, 55.86764412541544, 52.111747187952844, 55.88046635350874, 53.73837763263334, 57.14206926284298, 58.93573776368172, 56.344557269927, 67.26796596280991, 63.62238568644371, 63.03594035487022, 63.62904587099629, 61.77797348268571, 62.03566535826653, 61.53464140430574, 61.38741131751769, 59.95282403884396, 53.18327596110683, 54.78421880352882, 57.21802988360005, 16.900400692416778, 29.91720776404104, 50.607922230997396, 48.23003630484305, 50.05739404309181, 42.348485377527055, 49.99614231048092, 55.07731791465513, 55.46627975279286, 56.35020156060496, 58.050172482767415, 50.880817213366115, 56.83349640138688, 61.03963828855946, 62.57306929557555, 51.02808652385589, 53.372675449617454, 55.59527474064981, 55.65039973105154, 59.915490919543856, 61.05525324421545, 57.52289218287314, 53.621498846238666, 51.60953475582985, 50.39390594728532, 48.882746158107636, 47.99934210315828, 53.830823975224654, 56.47490547549341, 58.47020733741022, 60.07918319394512, 58.881836552773755, 56.53269767761231, 60.40705803901919, 58.85741587608092, 61.70400934834635, 62.78517146264354, 63.179648153243534, 58.48461028068297, 62.397256897341826, 62.9928844974887, 58.95786777619393, 58.92803815103347, 59.51244777248752, 52.34751301427042, 52.60717391967774, 43.88472087921635, 58.26327877659952, 65.86658154764484, 68.38830471038818, 66.09371031484297, 58.077876183294485, 57.681787398553666, 64.90746398125926, 65.23955537426856, 64.25282432186988, 67.07347131544545, 66.2658239180042, 64.12702214333319, 67.962570651885, 59.66874637911397, 5.26460720646766, 1.3019859165914598, 3.224551836329122, 5.448157460458818, 1.541718484893922, 55.539541782871375, 77.14014807055074, 64.95286933837399, 74.6862740670481, 56.78536107463222, 73.10476656882994, 25.653507055774813, 19.1369185140056, 57.01522765621063, 18.686253870687178, 71.9687383405624, 58.873281863427934, 43.17856088761361, 57.15815098054948, 73.21257683538622, 59.016048292959894, 1.4990372138638652, 0.23434197530150416, 0.13230709238879143, 0.1729131231625234, 0.14527529087518493, 0.21833315852188298, 0.2621443479532196, 0.09732549529402487, 0.17174485439975418], [0.138300305472747, 0.28691218504982613, 0.08637862745672466, 0.20452227864053943, 0.13201996263477112, 0.04501105549054281, 0.04501108230362016, 0.1610650065084619, 0.08036111406381093, 0.14520013764981302, 0.07718009483670035, 0.06826598768032367, 0.107342975905105, 0.4701443593348227, 47.37819948504048, 50.19420631470219, 69.18544800050798, 39.93856937654557, 53.79343986511231, 30.755484950157907, 22.882223090817853, 13.50536181080726, 8.936849794080182, 76.55962944030762, 82.78461917754143, 67.68583174674743, 44.30695226115566, 47.617644494579686, 50.64527888451853, 0.1319717450608169, 0.9645359530564278, 1.9028660606953407, 0.0738128396351972, 0.6568147975110239, 3.60853398038495, 50.071863666657485, 65.37472809514692, 74.9711165889617, 66.87337552347492, 70.06460805093089, 65.73173438349079, 69.86574388319447, 65.95557228211435, 64.6165810092803, 61.72758671545214, 66.63948459009971, 63.93615176600795, 57.56211588459631, 64.58818697160291, 59.48487743254631, 69.40757182336623, 66.5632180244692, 60.668786033507324, 56.71897495946577, 55.43226103628836, 56.60486144404258, 43.38097480035598, 49.97945654776789, 60.158650413636245, 58.19270357008904, 58.37179506978681, 53.11119848682035, 49.392881777978715, 51.27104597706949, 50.44715604474468, 49.198606783343905, 48.40792363689792, 46.850499491537775, 46.45673667230914, 47.64104143265755, 48.3183680811236, 47.07670257937524, 49.44364117037866, 51.10283905459989, 55.0610008547383, 54.251051026005904, 57.18828262821321, 52.71911836439564, 51.52833384852256, 49.27389667880151, 48.01151714017315, 43.798977867249526, 36.18872465625886, 38.51545895299604, 39.55087054160334, 8.977358072034775, 19.229794356130785, 37.46799392084922, 31.317089911430116, 30.390210305490804, 23.31771404512467, 30.380016065412956, 39.15293824288153, 37.1767657802951, 37.95008459398824, 40.9615509740768, 36.94859366263113, 41.56852991350236, 49.372736484773704, 51.45317731365081, 48.33808583597983, 48.866578148257354, 52.669496459345666, 50.78400135040284, 51.50743153787429, 54.536281862566554, 47.7165666703255, 47.103657107199396, 44.15707065213112, 44.50765602050289, 43.23595693034511, 43.48203859021587, 44.198459502189394, 47.48440550219628, 52.65426197359639, 54.42738117710237, 54.57475246921663, 54.48804847655758, 56.41662689947314, 55.472492787145804, 57.508391180346095, 60.24921009617468, 55.80242295419016, 57.03545139681909, 54.134027111914854, 50.91534583799301, 52.239643912161554, 49.01771491573703, 50.84581398194837, 49.219716979611306, 49.03732284422844, 36.74413227265881, 56.2396966257403, 62.37719005154025, 62.21716519325011, 58.18327026982462, 52.59914875030518, 54.22462209578484, 61.40401078808693, 56.44864128481958, 59.073612997608805, 58.76278869567379, 62.08319271764448, 55.62537108698199, 62.76231973401962, 11.154960913042869, 0.41639143240547954, 0.0877249044095797, 2.057485647739903, 2.5565972010935507, 5.673912907800367, 56.38269447511243, 50.45776997843097, 55.77926135832264, 52.61181408359159, 58.13613122509372, 56.26183448299285, 5.771202887258222, 28.649948796918316, 22.563661913717947, 16.536343943688177, 53.2217465677569, 34.68778656375024, 31.97905459711629, 41.77123800400765, 56.76587866198633, 16.45959688771156, 0.19833044960133492, 0.08451688824401749, 0.027048762384501678, 0.02730141626670957, 0.06176999109166284, 0.1045070639661243, 0.031984768387290745, 0.013316021556214941, 0.08944520080882697, 0.13191517712848802, 0.08952357160348086, 0.10262018174774225, 0.11029131124697386, 0.19640995910571468, 0.06952765788282118, 0.06654720047428724, 0.07251530885696411, 0.025660346765371583, 0.09309948617292028, 0.054187241325815844, 0.06336002573070508, 0.14648895800834702, 0.3495129372083372, 55.497274321894494, 55.06911623862482, 66.88849233811902, 37.792628888160955, 66.73275070805704, 23.094901846301173, 30.73928556134624, 23.261006378358413, 9.311251794138263, 83.97441525613108, 79.6792551778978, 77.25141002285865, 53.61209692493562, 50.84724956943143, 59.47405561324089, 1.1409972584055317, 0.5803701317598743, 3.4184355745392465, 0.6317539164616216, 0.3821218987145732, 5.3140427989344445, 60.38422199987597, 66.51767146202826, 78.39298448254986, 66.09310626983643, 70.86752506994432, 65.24965939983245, 71.59017470575148, 68.29435610002088, 66.90982218711608, 64.43607745632049, 67.51907610124158, 65.39141385785996, 64.4276325933395, 63.93795997865739, 62.089637171837595, 70.22588806767618, 67.68774586339151, 60.33609844023182, 58.61660195935158, 56.31686141414028, 58.32702121426983, 50.02692507159326, 53.90498030570246, 61.99754384256179, 61.39384400460028, 62.837507647852746, 58.448434260583696, 51.94069262473814, 53.23991498639507, 54.45932103741554, 53.7694545715086, 50.772614709792606, 48.79999983695246, 50.92447319338399, 49.67273896740329, 50.5172448773538, 50.9181817116276, 53.42852215613089, 56.39731314874465, 60.59395505535988, 58.772425959187174, 61.300169960145034, 57.78494965645575, 58.30924503264889, 55.913524089321015, 56.66480310501591, 49.18190533115018, 44.58293022647981, 47.7655884527391, 50.15158976277998, 36.943314152379195, 41.21603042848649, 42.27486248939268, 40.768519370786606, 38.880698296331595, 34.701373654027144, 40.446273126909816, 47.187274194532826, 46.710474798756266, 46.53493304406443, 50.37325859069825, 42.55089929026943, 50.230590220420595, 54.215177028409904, 56.877701513228885, 51.90733286642259, 52.20724121216805, 55.66839556540213, 55.0062406447626, 55.68171593450732, 56.701861658403956, 52.433130510391734, 49.3513713344451, 46.26159483386625, 45.17523165672056, 46.54074207428963, 48.341965060080256, 48.340592230519945, 51.650601971533995, 56.24111260137251, 56.33317847405711, 56.892465314557484, 55.168363971094934, 57.320254695030954, 56.29427248431791, 57.606979954627256, 60.94672126154746, 58.30039616554015, 58.413882101735766, 53.80893322729296, 53.49184490019276, 54.06859805507045, 51.30899098611648, 51.62292180522796, 49.71472401772776, 49.88066773260794, 41.09402902664677, 56.34212147804999, 62.93698287779286, 63.766548479757006, 56.81093100578555, 55.90565189238518, 56.7323737759744, 64.3143976888349, 61.26133065069876, 61.314486611273985, 63.547958712424006, 67.10768222808838, 60.45087091384396, 63.25524399357458, 11.842219983377765, 0.696225118252539, 1.5250773391415997, 0.8096870299308532, 1.4506964529714277, 9.598670332662522, 64.136259325089, 55.15321185511928, 65.18094731915382, 53.60055731188867, 69.23268902686335, 49.1788145034544, 11.384993214761058, 33.668731258761504, 24.88968037789868, 18.519810053610033, 44.74706965108072, 51.281361810622684, 24.71338748931885, 48.5636652669599, 66.82446356742614, 16.12116792509633, 0.09931877946421024, 0.10544840216396317, 0.02425055346271444, 0.016481351302636248, 0.02677246128329106, 0.1258065682204981, 0.03438410597042211, 0.07963337650101993, 0.05963170179916967, 0.22171108532817135, 0.32688052423538705, 0.14956847824636968, 0.45382628818192794, 0.2568544801925459, 0.1427323692628453, 0.14456888120020592, 0.27095699442490456, 0.14441007117350257, 0.24416478531014538, 0.2764695179798911, 0.08779747591864678, 0.22668702557923334, 1.82890351981886, 83.09140343819895, 58.698010752277995, 87.92082171286307, 51.355549520061864, 74.0437113854193, 46.10158958742696, 30.14473661299675, 21.336522909902758, 14.26758521987546, 84.56883476626489, 84.20429752719018, 77.04031590492495, 54.69653029595652, 59.74522475273379, 63.52859004851311, 1.219524702718181, 7.312207991077054, 4.61375508577593, 0.3217191753848907, 1.495137519894108, 10.333652880883987, 70.7675281647713, 71.45600611163725, 85.31636791844522, 71.33261619075653, 77.8604756632159, 69.18974691821684, 74.51499985110375, 70.24755524050805, 69.27789042072912, 66.92853189283802, 72.08513075305571, 69.35993071525328, 67.55716231561476, 66.36054915766563, 63.035756003472116, 67.3986985606532, 70.17308512041646, 64.42504775139594, 58.77459502989247, 56.557600805836344, 57.16628205391669, 47.28477254990609, 58.447649786549235, 65.55557681668189, 61.8249007194273, 63.67192522172005, 61.88009631249213, 53.363136245358376, 55.86635758799892, 58.83333644559307, 56.5256295665618, 53.30340247000418, 51.69976495927381, 52.952805334521884, 50.661835209015884, 55.43702279367755, 54.65515321300876, 55.204536068824034, 59.27135144510577, 61.222401126738525, 59.29294409290437, 63.16105611862675, 63.60902217126662, 63.37679432284448, 60.200961020685014, 61.929733907022786, 55.585700235059186, 50.329394725061235, 53.103753828233295, 60.40423785486529, 27.5776316273597, 33.14849945806688, 55.34641996506722, 48.742564570519235, 48.159206144271366, 38.26270534146217, 46.62531621994511, 56.686383985704, 58.39629811625327, 54.36864760614211, 58.72776977477535, 49.2850479772014, 56.02438595987136, 60.02858069635207, 59.058496182964696, 56.724897738425966, 56.861494279676876, 58.92127990722657, 57.32466736147481, 59.213939712893584, 59.805491970431426, 53.179259454050374, 50.65433563724641, 47.29964617759951, 44.82516011884136, 48.93080303745885, 49.876717905844416, 50.37012069456039, 53.56546386595696, 58.23184882440875, 57.81990581943143, 60.25246958578787, 59.1080278735007, 60.305625546363096, 58.23506516795005, 61.0419564093313, 64.10579035359045, 61.27801641341179, 60.94845102679346, 58.958993496433386, 58.44092292170371, 56.68426198344077, 50.56811017374839, 52.11205705519646, 49.56874908939485, 52.22761792521323, 38.506092333024554, 54.56198515430574, 65.42944515905073, 69.38471225000197, 60.11687717130108, 59.34019296400009, 58.2865462764617, 69.5580025642149, 64.29396606260731, 65.94403266906738, 66.5109798985143, 69.78608838973507, 64.82006180670955, 68.73333992496615, 19.106859430190056, 1.1011443839919184, 2.534633399017396, 9.827876975459438, 5.967267953580426, 8.489774119469429, 68.66880124615085, 59.48733675864435, 67.4278574605142, 63.311114234309045, 68.48586190131404, 64.42698540226107, 11.26679062843323, 35.934205978147446, 30.934800024955507, 20.959645894265947, 77.73089624220326, 50.28648791774627, 46.095980598080544, 56.125838064378314, 79.37953902829078, 31.493235711128484, 0.22896724032057872, 0.1644532295364526, 0.2742945024323079, 0.17923126477868329, 0.10280647134828953, 0.18330699043168178, 0.14591284456752962, 0.20172365220083346, 0.26973450195885473], [0.09108673570857895, 0.14684477520565833, 0.0355997572713081, 0.3262127407135502, 0.08979153383763568, 0.21102808115463104, 0.13659396719548011, 0.0976868819505457, 0.010550588748658137, 0.2228569843235516, 0.061762383838574735, 0.06493252461716052, 0.2387520676899341, 0.2710066675659149, 22.364287837859123, 59.68866025247882, 51.7602361402204, 49.763318261792584, 32.01560912593719, 35.91534329998878, 22.812353910938388, 22.268866377492106, 1.84141575809448, 32.19721094254525, 81.92489054895218, 57.87832952314808, 52.76286848129765, 58.216116197647594, 62.676910123517445, 14.562225822479496, 2.2760425652227094, 4.5687630484181065, 0.38868607712849496, 0.3412171549374058, 1.0300030078618758, 13.413116489687274, 58.08410098475795, 68.81298757368519, 80.97417077710553, 69.03695491052443, 67.04106469308176, 66.44815921783447, 68.91449066900438, 66.35415569428476, 65.68553278523108, 66.57369859756963, 61.990150174786976, 66.06734414254466, 69.94149269596224, 64.08600591844129, 64.4676564585778, 63.732655279098026, 65.27863002592518, 64.89036636967813, 59.2337163033024, 55.850926983741026, 66.30205877365606, 60.92443043185819, 60.2280959775371, 54.53595238347208, 57.518091201782234, 52.32537515701787, 52.748210583963704, 48.27952092693698, 50.655665320734826, 51.40317101632395, 49.324887491041615, 46.27546041242538, 49.49356902030207, 48.24807528526553, 47.34689504869523, 44.70250760355304, 46.53503894805909, 46.54466444446195, 50.90077423280286, 53.241123076408144, 57.79200600039575, 54.274781365548414, 55.31947328198341, 51.91429899584863, 46.377057644628714, 36.51765461890928, 33.176869961523245, 36.81563315852996, 40.09791174242574, 18.00796231915874, 21.02931111089645, 41.94440280237506, 29.18672907736994, 37.569936321627715, 15.00254717565352, 25.66411118353567, 45.2736125453826, 37.36914627013668, 44.69014821514007, 42.404932206676854, 39.03665173438288, 37.6659010302636, 46.46125132037748, 45.43356680100965, 48.79511256371775, 51.045423400017526, 49.97352984643752, 50.51805680797946, 51.24040834365353, 46.28565465250323, 44.04545176413752, 45.8341270877469, 44.19840066663681, 44.2429901707557, 41.304664227270315, 45.091771464194025, 45.57602728566816, 44.62136160942816, 50.26564836502076, 54.70273156319895, 55.40645184055452, 55.68348100108486, 55.811597378023215, 56.86848394332394, 56.43228107883085, 57.42068306092293, 52.85110612069407, 58.04497141991892, 47.278269260160386, 42.79931083802254, 46.08662966758975, 49.84457015991212, 49.228059860967825, 46.11045022164622, 48.00637883524741, 49.40133840807023, 59.89995441129131, 57.76922487443494, 61.44326586877147, 59.014318527713904, 55.73723316192628, 59.18722837202011, 59.97663674816009, 64.02781363456481, 60.601862553627264, 57.090945090017016, 51.4817988487982, 53.74922298615979, 19.86216868123701, 0.356307064573611, 0.12284982889409989, 2.6779322903002463, 0.8430594133753931, 2.2100658474429964, 41.761443845687374, 53.187335614235174, 56.08641432177637, 55.17472213314426, 60.380899752340014, 61.96929885495094, 11.670990874690395, 4.510821796232655, 63.99737996439781, 20.272595690142726, 24.855065461127992, 50.15939135705271, 26.996234386197983, 34.3954836937689, 45.75070611892208, 53.1739289529862, 1.151502468893605, 0.33445410009834076, 0.08864324464793168, 0.09048019325540912, 0.08748022358744376, 0.18293264922836136, 0.14605887624765598, 0.029666082625607812, 0.039433969875737544, 0.006760851378672787, 0.047057935171910835, 0.11270197544006572, 0.09291874304894479, 0.14523026022699573, 0.1418254590563236, 0.1735434449848629, 0.1904274406091821, 0.06702801257732414, 0.01917567104101181, 0.026557349539812536, 0.04705235805182208, 0.06113424153637983, 0.17106190233701662, 0.15942692666524844, 24.677291877808113, 71.09451263181626, 53.68788888377529, 41.09696295953567, 40.5015040213062, 31.486567681835545, 20.360362645118467, 37.009919920275294, 4.2632633639920146, 32.93920963041244, 89.02216049932665, 56.95890634290634, 51.02513297911614, 64.60036593098795, 70.814071009236, 21.73258816042254, 0.857799312760753, 2.0157220887561, 1.224107379394193, 0.0978457915686792, 0.5961962212477961, 19.860709559532907, 63.31258120075349, 69.42782694293608, 78.12501599711757, 71.03617914261358, 66.85843129311839, 66.14248891030589, 68.927183458882, 67.74181181384672, 67.91413722499725, 68.12494893227854, 66.2219012168146, 70.4592534034483, 69.47395401616251, 66.48379787322014, 65.72916130865774, 66.77748926224248, 66.26163482666016, 65.46067507036271, 61.368289762927645, 58.19737119059409, 68.42978769733061, 66.29420618857107, 60.969439629585516, 62.249964052631015, 60.87504386901856, 55.55059894438713, 55.16469655498382, 51.09618671478764, 53.8881847166246, 55.06374259148875, 51.11688898455713, 48.2910801518348, 49.8320185753607, 51.29749059677125, 49.328150903024984, 48.42254231053014, 49.75203360280683, 49.15395452130226, 54.19094462548533, 57.81719938401253, 61.19511711981989, 61.00670214622252, 59.64269791879962, 60.35582796219857, 54.37469590094782, 48.121716130164366, 41.91011344232867, 46.28430143479378, 48.875901622156945, 47.66061798218758, 48.002589825660955, 49.380008559073175, 40.072667367996715, 40.45832264807917, 26.52610105852927, 29.97001071130076, 50.509651168700195, 45.63248980429865, 51.35410608783845, 51.47749600871917, 47.15030977802892, 44.41577057684622, 54.04070215840494, 50.69286900181925, 54.155439330685525, 53.702154544092, 54.609485057092485, 55.72435602065056, 53.08684841279061, 51.34087593324723, 47.09025436832059, 48.51097214606501, 46.38381588843561, 44.80105715413248, 43.64693503226004, 47.00465256167997, 48.90871224864837, 48.54143327282321, 53.05135096273115, 57.46855558887605, 56.086724189019975, 53.23096806003202, 55.90862504897579, 57.56108822361116, 55.905306723810014, 55.92080008599066, 54.2253634237474, 58.913231203632975, 49.08782728256718, 44.34669371574156, 47.21010631130588, 49.57029450324274, 48.90413876502745, 47.90516991769114, 49.56810582068659, 53.88145785177908, 60.00241064256238, 61.0615643378227, 62.73081133442541, 61.689033739028446, 58.70511808703023, 62.16335027448593, 60.9288352535617, 66.78071345052412, 63.2606529420422, 58.208196932269686, 55.17416123420962, 55.61548279177759, 23.100936412811283, 0.39623829446011977, 0.5658975664165713, 2.171688642232649, 1.293556375368949, 5.794607670076433, 49.98730128811252, 58.227491071147305, 59.12745929533436, 59.107184563913655, 64.95144159563127, 58.280121434119444, 12.249353181931282, 14.177237345326333, 55.22598751129643, 27.504193090623428, 18.683278752911477, 52.78911698249079, 39.08189627432054, 30.95111708487234, 54.61453706987443, 58.83740002109159, 2.3859669893018665, 0.460373091721727, 0.11492605891919906, 0.11185732519915027, 0.14075600031402805, 0.20033718627547065, 0.3262573883177773, 0.07574158855864117, 0.02673811756164557, 0.013551867469364117, 0.23426199572220927, 0.2191250636092117, 0.147703820238671, 0.259457616315734, 0.4463640095726137, 0.28719407476244435, 0.42984568303631204, 0.17297549804131832, 0.12831691577429735, 0.2990320330906299, 0.18147945704479373, 0.10257183393884091, 0.6573367791791117, 0.4163321984871742, 43.50799683601626, 81.34033972217192, 65.16359475351149, 62.742092071040986, 48.52068785698184, 54.31873152332922, 30.825632618319606, 33.696921333189934, 5.277744695063561, 45.13355647363971, 84.7724763808712, 64.28714113850748, 57.98386481500442, 71.7992997938587, 75.33970955879458, 17.442485978526456, 5.881547004945817, 17.710162247380904, 1.0501464624558727, 0.5346156224127739, 1.5694083345513192, 29.168513590289702, 68.8965654373169, 76.65011852018296, 84.74311351776123, 76.27451235248198, 67.08363809893208, 69.99718250766878, 73.95228878144296, 71.63101442398565, 70.32813641332811, 71.56467929963144, 68.61129145468436, 71.94654557012743, 69.61081335621496, 69.07335450572353, 69.63797184728807, 72.3485335996074, 70.08908364080614, 66.15012968740156, 59.984348127918864, 59.95208663325156, 61.438602170636585, 62.252101744374926, 65.91620737506499, 61.01157372997653, 62.24706934344385, 57.28005432313489, 59.826747294395204, 55.378108793689364, 55.40472207530853, 57.41728236598354, 54.41459425034062, 53.75456133196431, 53.256169288389145, 51.59619869724397, 52.01388797452373, 48.42490749974405, 51.08094830666819, 50.427183335827245, 54.712529643889404, 58.84360128833402, 66.17995539019185, 64.18193532574561, 67.3658134091285, 64.69308291712116, 56.86389084785216, 48.98646539257419, 46.026248701157115, 50.20269040138491, 56.12726972949121, 45.850659878023215, 44.54128642236033, 62.40495258761991, 43.42233227145287, 57.04577507511262, 29.133830032040997, 39.78225900280861, 62.16821009112943, 52.93190302387361, 62.75190584121212, 60.065270546943914, 52.8992179132277, 48.215692197122884, 58.32076111147481, 51.286480503697554, 55.556478577275435, 56.32878149709394, 55.44413405079996, 56.721171486762266, 55.04739023024037, 49.738246471651145, 48.02039738624327, 51.20255747149068, 49.276144196910245, 47.010292929987756, 43.190830061512614, 48.12242607916556, 52.12407519740444, 49.48666172642862, 52.203773836935724, 59.575354745311124, 58.68596907584899, 59.749033374171105, 61.10460450572353, 61.42304997290335, 60.53065584551904, 63.03166497138239, 54.619361585186375, 59.78840220359064, 48.33366532479563, 43.06791474742275, 48.428876938358435, 50.16549064267067, 50.77690578276112, 49.99486361780475, 48.67233453258392, 52.531060326483946, 63.34333258290445, 64.89172743212792, 66.77672832242905, 67.39564695665914, 61.85426358253726, 67.46242138647264, 66.08639901684177, 74.92511503158077, 67.38941038808515, 62.82057477581886, 60.073146666249926, 61.21012803046935, 32.87279998102496, 0.7349083909103948, 0.394831603813556, 12.26849336777964, 11.189005124953486, 3.144325638009656, 52.38063350800545, 66.32593031852477, 67.2355358062252, 66.07354933215727, 69.90778384670135, 69.2996125067434, 16.89859640213751, 7.490039429356975, 72.65169359022572, 28.43299661913226, 35.42440375974102, 73.5127793588946, 40.14268559794272, 53.04340816313221, 59.211621592121745, 77.30970428835961, 6.516174731716034, 0.6263248045598308, 0.3283740586090473, 0.43878047456664426, 0.26929544164769115, 0.43201404894071244, 0.4107028924890103, 0.26209847460831365, 0.07403219359055643, 0.14885995416871964], [0.06890639121974669, 0.12198963472920081, 0.23770669475197795, 0.06650152631224164, 0.04258431494235993, 0.1718159626808859, 0.17884897158270885, 0.0724784370451685, 0.12917478869278587, 0.18178488097844586, 0.021602852089751153, 0.04862198410856147, 0.2309149422592694, 0.18736344131250537, 5.4105728191714135, 54.571991120615316, 47.19330287748768, 44.38863561999413, 34.312058802573915, 42.30867724264822, 21.75017018471995, 43.23529797215616, 6.325134221584567, 2.7517944430151298, 45.953567181864095, 67.85075956775297, 61.49456262588502, 65.68486990467196, 49.54465004705614, 32.16247443229922, 6.237644774298515, 3.200897002412427, 1.8325331831170668, 0.22503267402850816, 0.049656589680741874, 0.7433720690108115, 21.571761177432155, 62.35959822131742, 55.39663807038338, 68.49043538493495, 57.946127691576564, 65.01952217471215, 70.55645758105864, 69.83888349225445, 67.69464139015444, 65.91845097080355, 66.08656375638901, 67.05271413249355, 62.59341070728918, 62.22172690976051, 62.69620818476524, 64.18079391602548, 58.049062452008656, 59.424469009522475, 62.66299355414606, 62.10606405811926, 56.05025399115778, 63.729199670976215, 60.77226600339336, 54.562628423014, 54.48610298095211, 51.858350307710715, 50.246099272081935, 49.75321815859888, 50.185004434277936, 49.161379568038456, 48.47878125406081, 44.26637926409322, 46.835990644270375, 47.58324530816848, 46.67969988238427, 44.886478531745176, 46.43928604741251, 47.06519826765984, 50.13939903628442, 53.753141433961936, 62.19133638566541, 53.98305900635258, 53.570794367021136, 51.43782907916654, 45.70159019962434, 36.25636592988045, 32.703610504827196, 35.687375145573775, 40.2263536760884, 35.1525442830978, 30.043631638250044, 42.85024673708024, 35.83915910413189, 37.44343596120035, 9.814614461314294, 21.12112791307511, 45.71870742305633, 39.45101484175652, 47.03731413810484, 42.85340032269878, 41.02616417792536, 37.566319896328835, 45.09258731718987, 48.43490954368345, 49.401299184368504, 53.98769917026643, 50.42844241665256, 50.89669889019382, 47.7839373004052, 43.25972257121917, 43.449730027106504, 43.91563700091454, 43.50290167716242, 42.9107375298777, 43.60185523186961, 43.45763752537389, 42.16280821830996, 45.10881024022257, 49.44553175280171, 54.00434570927774, 55.27119674990254, 55.77603717004099, 56.78415690698932, 53.06734246592368, 51.26243637454126, 57.62185750469085, 47.76794579721267, 48.37294786207138, 54.04258881845782, 53.24644573273198, 49.615091892980764, 50.81772588914441, 50.925493009628795, 54.77725267410279, 50.018825377187426, 44.54670713793847, 58.01414551273469, 58.87682768606371, 58.573499033527995, 56.484562350857644, 59.60243871135097, 57.45312890698833, 59.442688418972885, 57.59320459058208, 48.31951733558409, 50.49511878721176, 33.89815853488061, 17.651061934809533, 0.8049234952176771, 0.28928264494865175, 0.7671097629973966, 0.33633089293876006, 10.498643459812289, 55.64400626767067, 51.582286050242764, 50.75432077530892, 49.92009147520989, 55.930923723405414, 59.90695976441907, 14.679145793760977, 0.3009948422831874, 31.773489059940463, 63.157133748454434, 16.077442323007894, 37.94800966016708, 45.36467821367326, 21.642103002917384, 40.787754674111646, 53.959152160152314, 33.27413297468616, 0.1840100139980355, 0.08469758540271752, 0.12853884378508215, 0.24139625080410512, 0.15854342810569272, 0.15645358621353106, 0.03612906657039158, 0.08037265900882982, 0.010452708567402536, 0.029436532039976412, 0.03450948008967023, 0.10806425534669431, 0.15128290641211695, 0.034199624337376125, 0.03909188863490859, 0.1448073796927929, 0.1648314318229114, 0.08626490936524446, 0.05918612974064966, 0.16499854624271393, 0.06703629398778563, 0.10092938739445903, 0.14192472872955186, 0.3226310651629202, 5.781734451170891, 58.98091170095629, 55.69968038989652, 38.64077868000154, 44.60853153659452, 44.18789263694517, 15.679685550351298, 48.792857200868674, 15.71240988469893, 4.591476023197174, 45.76350873516452, 79.65242616591915, 64.12835967156195, 74.03606276358329, 51.87279639705535, 38.13826422537527, 10.515766566799535, 1.7503597731551819, 1.4854284279769467, 0.6573921826577956, 0.1154561457975257, 0.2778172811433193, 28.99117539005895, 68.61984222166001, 55.28314821181759, 68.75301453375047, 56.92078090483143, 63.692741240224535, 69.622651069395, 68.1868439335977, 68.3203378800423, 67.88948120609408, 67.41933022775959, 66.05360800220122, 64.57100699024816, 65.19723300010928, 65.34435718290268, 64.62080932432606, 60.45826458161878, 63.00962909575432, 64.34088545460855, 65.68150843343427, 59.03579350440734, 66.83648170963411, 63.18164071729107, 58.15604509845857, 59.011286535570704, 56.231804816953606, 51.663133944234545, 53.677341630381925, 56.704787746552505, 52.019069425521366, 49.86809261383549, 47.05467062611734, 48.92710032001619, 49.22478468187394, 49.33116328331732, 46.08278966719105, 47.77636712597263, 48.96129946554861, 52.502909475757235, 57.39530532590805, 66.11941752895233, 62.798178042134936, 59.939899829126176, 59.407269416316865, 53.51741875371626, 44.769317334698094, 40.61707665843349, 46.1083988220461, 45.072430256874334, 51.650970674330196, 46.8568576535871, 51.66662485368791, 41.60200734292307, 45.183441177491225, 23.18101944461946, 29.81970548629761, 56.951493063280665, 45.49506956531156, 54.56980243805916, 50.135888514980195, 50.296089879928104, 42.59630856975433, 51.524344798057314, 52.905148536928245, 52.44117921398532, 56.19715852122153, 52.45409165659259, 52.91012602467691, 51.2986163170107, 46.49972192702755, 43.556359660240915, 47.553247021090606, 46.06001246360041, 46.58777913739605, 44.27241579178841, 46.839897324962, 44.832604777428415, 47.917921543121345, 53.822673290006584, 57.65990057299214, 56.073599938423406, 57.775371228494954, 55.536505868358, 55.59185443385955, 54.169857963438965, 57.119954939811464, 50.1897426574461, 50.76583685413484, 54.49223756790162, 54.236985406567975, 50.9995787374435, 52.97070703198833, 50.760372992484804, 56.04260144695159, 50.17162915199034, 48.24260750124532, 61.645609178850734, 62.313875152218735, 60.07855953708772, 59.04158292278167, 61.99235846919399, 58.73850530193698, 60.348681403744614, 56.28344282027214, 50.26928832454067, 53.720624985233435, 38.80194494801183, 18.937479719038933, 1.0957903487067069, 0.9441971766852564, 1.1183412805680306, 3.675867593096149, 20.314249300187637, 62.03985052724039, 58.25963881707961, 56.14556366397489, 56.88809971655569, 58.704231631371286, 63.432503746401885, 15.450942727827258, 2.0770722483434985, 33.674979594446, 54.91943467047907, 18.596423749000795, 27.525962245079782, 56.53708680983513, 27.377406397173484, 40.053914516202866, 65.58373158977878, 32.55457416657479, 0.3937052400602449, 0.06201324699025962, 0.1530979832093562, 0.13956163859655782, 0.1642447770122559, 0.15444341746549453, 0.029799100387120442, 0.10057242106526129, 0.01492930792136899, 0.031133131424505866, 0.12840267931742053, 0.19334462681604972, 0.3247567752916967, 0.12673252337281743, 0.09509717534867027, 0.2151995831199231, 0.3794803662646202, 0.3805057596295111, 0.30671632398040066, 0.44206043404917567, 0.3805820926302864, 0.3443315168542247, 0.4209590324711415, 0.47273137696808387, 13.939308331858728, 84.40019638307633, 58.68316850354595, 57.23290351129348, 48.08683449222196, 63.96338478211434, 28.213802806792724, 58.07201616225704, 11.821611850492417, 7.588586038158787, 57.150816148327245, 79.84268465349751, 70.31045436859131, 78.90345742625576, 62.171183247720045, 50.454012347805886, 8.935965299606323, 8.990347981452942, 6.027845038521675, 0.8769341053501253, 0.19899211974153597, 2.0377662994207877, 32.895641903723444, 79.46584686156243, 63.12965362302719, 70.50432928146856, 58.9568087362474, 68.37496080706197, 72.2297328518283, 74.59969951260474, 70.9905384432885, 72.20507683292513, 69.38268046225272, 68.34671189708095, 65.4577725164352, 66.28690273531022, 67.56208096781086, 74.6498352481473, 62.14139676863148, 61.43524854413925, 66.81518323959844, 66.49082676056894, 59.27608182353359, 66.0051824200538, 66.24124634650447, 57.485378634545114, 60.991032277384114, 60.66321234549246, 53.808890081221065, 58.52559120424333, 60.75465456131966, 54.16162490844727, 53.69969914036413, 47.95303067853374, 53.238247979071836, 52.53051511702999, 52.183624621360536, 47.67443649230465, 51.73601158203618, 49.440534653202185, 54.48190996723791, 60.57781842447097, 70.92079870162472, 67.5868703472999, 63.42106219260924, 62.94554148950885, 56.64184547239735, 47.61982925476567, 44.02482794177148, 51.12399239693919, 53.97295105841852, 62.712211455068285, 53.28081746255198, 61.24266016867853, 51.092793864588586, 52.904650395916356, 23.10001857819096, 24.418138919338105, 65.2698988299216, 51.21930599212647, 64.08786904427313, 57.84120036709694, 55.741940006133056, 46.8744690956608, 55.464875544271166, 55.67689926393571, 55.730051302140765, 58.952184261814246, 54.287650662083784, 56.41574044381419, 53.00516113158196, 45.13503520719467, 47.83180590598814, 51.02555267272457, 48.505931900393584, 47.381690394493845, 46.05221871406802, 47.28318006761613, 45.69947211973129, 47.928492330735736, 53.393448322050034, 62.335252069657855, 60.173641712434836, 62.94048947672691, 61.200243657635106, 58.11963373614896, 56.8874603702176, 57.54988593439902, 50.19550069685906, 54.00569108224685, 52.44649010319864, 56.49439181050947, 51.017205868997884, 54.614835170007524, 48.840745418302475, 58.13418180711808, 55.032653885502974, 49.48242556664252, 59.33064983737085, 62.99219808270855, 63.92419638172273, 62.289933004686915, 65.36179211831862, 62.535567514358036, 67.01620471092963, 65.49542727008944, 53.8977906011766, 61.111456886414565, 49.03046261879706, 32.07969477099757, 2.1703030649692785, 0.5258435479575588, 2.3894368160155515, 5.667163979622626, 15.587571628632086, 66.92110292373165, 63.52161215197656, 63.05568164394748, 62.36068471785515, 64.45028428108462, 71.23135628238802, 20.094747581789573, 1.6554592525766743, 38.179092176498905, 75.37713681497883, 19.37239996848568, 55.936791589183194, 66.19394256222633, 32.48310465966502, 58.38370730800014, 69.00586620453866, 55.75573498202909, 0.7848629006935705, 0.32432488556350436, 0.27326543184538044, 0.4270875826478005, 0.2594063190683242, 0.29123745618327973, 0.09713522203627134, 0.26377498142180905, 0.08680614282286937, 0.06548897258096165], [0.06345534622068368, 0.06955906748771667, 0.05569751855106123, 0.0362104480905879, 0.15647909694140957, 0.06193658074123725, 0.1946281305243892, 0.0906890135018095, 0.11805835495432539, 0.23068672466662624, 0.046027535422434734, 0.06709661575094347, 0.09443882236918134, 0.0162601683123578, 0.2848183135351827, 34.97823415264007, 58.24536138965238, 47.30282721980926, 31.345860496644054, 42.90943530298049, 26.157643410467333, 28.363229420877275, 23.767790332917247, 0.9391980546136057, 7.61054297608714, 51.14219219453874, 56.63630316334387, 63.023451528241566, 50.37056784476004, 74.12290403919836, 54.04437349688623, 37.49331674268169, 5.679373827672774, 0.41662999218510044, 0.20049731397340376, 0.21954392984269128, 0.624995795228789, 23.245660105059226, 67.54288488818754, 55.97405802819037, 63.83262472767984, 62.661444217928, 60.951039791107185, 64.54466435217088, 65.75042055499169, 65.71082422810217, 64.37929722570604, 66.56540670702535, 61.93007123085761, 59.48311236596877, 57.18009271929341, 52.70750030394524, 59.32110278837143, 58.81311270498461, 62.110602240408625, 60.50873764099614, 64.43598724180653, 57.110933488415135, 58.78209852403211, 57.78624796098279, 56.68921985933858, 50.24225534931306, 51.245385831402196, 46.13088969261416, 45.22324931237006, 47.91663500570482, 45.0754387147965, 45.659189378061605, 47.35172348637735, 48.2322249873992, 47.148764364181034, 47.23776686576105, 47.22699995963804, 45.90777743247248, 50.73057082391555, 56.555992634065696, 60.073342784758545, 53.5903513047003, 50.37066982638452, 52.18331475411692, 45.16544534314064, 35.6351605538399, 34.45358968550159, 36.55152036297706, 39.28685188293457, 40.38449579669584, 40.283526143720074, 43.864959978288226, 41.06952205781014, 30.346642578801802, 13.771265168343822, 26.095834701291977, 44.13565451099027, 41.61614748739427, 44.35075336886991, 42.44005703156994, 40.20423935305688, 38.35470061148367, 42.856836318969734, 51.8196012127784, 52.00950668704126, 50.76440911139212, 51.02200292771863, 51.125188719841745, 44.801814171575735, 41.7531244985519, 40.5029631430103, 42.97932017234064, 45.8735429856085, 47.26699636828515, 45.00465170029671, 42.21449329007057, 43.4029047719894, 45.26557560889952, 47.64577965582571, 51.42314372524139, 51.74832390200708, 55.66030371573664, 52.78246856504872, 54.556266338594504, 54.626382627794825, 52.94698453718617, 47.591780385663434, 50.60493338492609, 52.07147621339368, 54.49767397296045, 57.60830963811567, 57.87298333260321, 52.84681112535539, 56.93292456288492, 55.226246387727805, 49.06958041652557, 57.81705425631616, 59.794956484148585, 61.133747716103834, 59.090745910521484, 59.38443337717364, 58.70695767864105, 56.87207291203161, 53.16848078081685, 39.32011358199581, 18.31801195298472, 4.060355232607934, 0.5702867599264269, 0.05213750413649025, 0.4983499700263624, 1.7225046936542758, 41.505281694473766, 58.03434571912212, 52.52460018281014, 54.03137476213517, 59.43816200379403, 45.19079954393449, 59.48680331630092, 48.75901106865176, 7.592088224426393, 10.566504386163528, 64.0737916577247, 52.41724098882368, 18.508931359937115, 41.482951641082764, 34.39814306074573, 25.426643048563314, 35.92840087029242, 53.44834973735195, 13.448448219606954, 0.5202702276649014, 0.086024503313726, 0.1946231356311229, 0.13626536144123924, 0.14551843186059307, 0.06869721091202191, 0.035357700300312815, 0.04283861399838521, 0.02657353123199315, 0.0630166689534822, 0.017202374104770924, 0.050022955908770525, 0.10903377791926747, 0.02716889646234772, 0.13749631151797312, 0.09083016520185817, 0.11499316822136603, 0.031491262207348505, 0.07606588889874759, 0.12466084542534045, 0.008182300709097857, 0.025952467582218593, 0.16206347954369363, 0.061071694287801945, 0.22736898172766934, 42.239094395791334, 67.65173850520965, 44.70911679729339, 34.70947727080315, 56.05674943616314, 21.72069553406008, 33.03129511494791, 27.55669401537988, 5.647049575082717, 8.336241764407005, 55.669187884176935, 62.88287378126576, 68.3776201740388, 59.77894144673502, 78.47262428652856, 62.102557459185206, 44.02127035202519, 8.749765484563767, 0.32437363939900554, 0.02302865663002576, 0.15554348908124432, 0.741146430373192, 29.267977053119292, 72.2685407823132, 56.14057048674553, 61.72613151611821, 58.39321513329783, 59.410654421775575, 65.29450385801255, 68.16291747554656, 66.15764494865172, 67.55969616674608, 66.05591435586253, 65.32797736506309, 62.876088080867646, 61.666931183107444, 55.11859693834859, 60.71583094135408, 63.42214084440663, 61.84345745271253, 62.659510489433046, 67.54244558272823, 60.020198591293834, 61.244370322073664, 61.502144567428104, 61.165460078947014, 55.4285151727738, 53.08977450093916, 52.92865137900076, 49.93142320263771, 48.4950198665742, 50.51192614340013, 46.91416740417481, 48.605218856565415, 50.62750662526777, 48.32408689683484, 49.469662174101806, 50.09236197317801, 50.32399754370413, 52.6992594042132, 62.213717429868645, 62.69607482417938, 62.03625371379238, 59.415271051468395, 58.94412379111014, 50.916687288591945, 44.1387963294983, 42.58395310371153, 46.18315527516027, 48.18284234692974, 48.48795175552369, 48.0738357574709, 51.574723720550544, 49.133985734754994, 38.60188837974302, 34.07586151553739, 54.76227706478488, 53.255953558029674, 51.74994384088824, 51.73566249109084, 51.28857504936957, 46.38073682785035, 43.64082397953157, 49.77366547430716, 56.353237475118334, 53.7275871922893, 56.25732767966486, 53.20051870038433, 55.080844125440045, 47.13174127763318, 47.08382168123799, 44.15770607609903, 45.91548881223125, 47.69214991600283, 49.37244622938095, 47.8298564880125, 45.55963962308822, 46.801509088085545, 49.54488538926648, 51.52822402215774, 54.48077640225811, 53.30259838411885, 54.30690165488951, 54.123507315112704, 55.13658492795883, 55.837661527818256, 57.113318289479906, 52.67278340555007, 55.5279198000508, 54.7511532229762, 58.001409576785186, 58.5531811560354, 57.6283686391769, 55.27083981421686, 55.73380893276584, 57.76536133981521, 48.558115113166075, 57.273327458289366, 61.27665927333217, 63.81820609492641, 60.094629487683704, 60.40112741531865, 62.14827660591372, 56.037910292225504, 56.80163498847716, 43.81007817483718, 23.924812616840487, 6.919621882900116, 0.30078217627540715, 0.04689175920981554, 1.129746184714379, 5.528912198159003, 51.899393989193825, 61.93225599104359, 56.552411510098366, 60.756498075300655, 64.72333223589006, 50.94406151002454, 64.444420337677, 52.54747152328492, 7.982533699081791, 16.559219206533125, 60.13654785771524, 54.80610562909035, 16.432879663282826, 35.39763358331496, 49.4628333276318, 24.630372485806866, 38.4140617616715, 64.62433945748114, 13.001702024090676, 0.45049460244274914, 0.10357568491130106, 0.16842636069463146, 0.10839851482981637, 0.11209156424287828, 0.05006692935562423, 0.010726101407330605, 0.02369171338936975, 0.08134624950828091, 0.028418198175307725, 0.2444572163926017, 0.20604662507051424, 0.14416545929927982, 0.12015846242467243, 0.1817880372606939, 0.2583047152767258, 0.1873289060688788, 0.15184495447864457, 0.24098950408158765, 0.49224066397836136, 0.17204483910914392, 0.10987962325734478, 0.27316289863759474, 0.14771855977033416, 1.0393164306879044, 67.13015740917575, 70.30511210041662, 67.44754775877922, 42.000963380259854, 68.1138329352102, 34.503513613054835, 38.921008494592485, 32.50478948316267, 4.522625188673697, 11.970617790375988, 63.86625120716711, 67.170361703442, 74.19877836781164, 65.83757954259073, 84.09574201030117, 64.23480887566843, 46.37815590827696, 8.104935182679085, 1.589484495982047, 0.4262581239304235, 0.32572688775197156, 1.2034362434379517, 31.87641597563221, 84.34969978947794, 64.76826298621394, 64.515576054973, 62.91842222213746, 63.554626741716945, 67.68019137843963, 71.40097525811964, 69.48819221988802, 69.17236297361313, 70.38373208815052, 65.460180851721, 66.24679257792812, 64.69976663589478, 57.53483972241802, 64.05960444481143, 64.10448420432307, 66.24691809377363, 64.29637047552293, 68.57613917320006, 59.8955221329966, 62.517528533935554, 63.16817129811933, 65.04486068602532, 60.068102498208326, 57.250209008493734, 52.88633292721164, 53.66533917765464, 52.9023636541059, 52.13465382975917, 50.40161732704409, 51.43995108142976, 52.419331612125525, 48.662999291573804, 51.78054225060248, 50.75106913043607, 50.354439058611476, 55.655675318933305, 66.99423159322431, 66.4947569754816, 63.12315817802184, 61.48800050058673, 61.6464211094764, 54.51516774392898, 47.244340758169855, 46.70388521686677, 51.13778737283523, 52.678537522592855, 57.05371002997122, 57.68465072877946, 59.4651282987287, 53.56468723666284, 43.6301786668839, 43.487667191413145, 55.4605217133799, 58.11520930259459, 60.12870311737061, 57.938404544707275, 56.643673296897646, 48.874454267563365, 46.60000124285298, 54.43308038096274, 60.76374269300892, 58.59022401994275, 56.55068958959272, 57.93259943685224, 57.390924038425574, 50.35730631120744, 47.13054887710079, 48.0240491128737, 47.44767642790272, 49.81099859360726, 53.51952114412862, 49.91472567281416, 47.68889827112998, 49.33070044363699, 51.73349342038555, 51.71969844448952, 56.33289998577487, 55.68829374928629, 61.6445658283849, 56.978325997629476, 58.56806655083933, 57.77412391478016, 59.2916654002282, 55.580244218149495, 56.92490723825271, 56.889256815756525, 58.80247131470711, 60.84300987182125, 58.92358626088789, 56.77206816211824, 56.43250857630084, 59.59928120336225, 49.796525047671416, 58.33283808923537, 63.672862668191236, 65.62460268697431, 62.945345371000236, 66.06943868821668, 67.36392282670545, 62.97618304529498, 62.89930458991759, 49.669573614674235, 30.050180035252726, 11.463384724432423, 1.0523597823996698, 0.2390052597489088, 1.1866823295431754, 8.105130320595157, 49.467634308722715, 70.07631240352508, 63.22553203951929, 66.89524665955575, 70.51772809797718, 56.531124807173214, 68.3041149570096, 57.90372294764365, 12.942754683956025, 15.522687781241634, 72.52673472127607, 64.94779771374118, 21.52040558476602, 61.87729181781892, 49.6494165543587, 37.02490729670371, 48.11706027676983, 72.22269611973917, 27.034199007095832, 0.6915421147019633, 0.1605124119669199, 0.3948310215867335, 0.21410245328180252, 0.17303102409407017, 0.16680119709382135, 0.236060586307318, 0.21610497647235472, 0.14396474426311834, 0.1507329165695175], [0.055414675058977264, 0.03911363787107891, 0.07552635615631458, 0.020074962503126553, 0.09432481316428992, 0.0393616205321685, 0.04681110930358691, 0.029170829765198213, 0.060734420248697844, 0.009855218400667992, 0.059053236468424725, 0.03578789314375289, 0.163195910713365, 0.1452281611460832, 0.16452551759298772, 20.54596724048738, 52.51819887468892, 40.614197638727006, 33.48045356812016, 32.98048473173572, 35.38676469556747, 11.888299007569591, 73.04838641997307, 14.783104292808043, 2.912998954134603, 40.58725487801337, 68.51735853379773, 59.44029969553794, 65.46636642948275, 51.12560056870984, 58.03371813989455, 63.511143345986646, 52.97508047473047, 7.444031988420795, 0.2025322580049115, 0.18393208753437768, 0.1503616550396527, 0.3429248262076609, 16.64576630438528, 56.685211197022475, 64.02125543163669, 64.67014489635345, 64.46329086057602, 64.65637737704863, 61.54030922920474, 66.77677539087111, 63.81378558374221, 63.194392342721265, 63.09606244487148, 59.95031764430385, 52.29541217127154, 52.05073471992247, 50.73718786239625, 54.57070850556897, 59.09142055819112, 56.2874161812567, 58.64738864283408, 62.68376642657865, 59.74709572330598, 60.601662512748476, 57.0082458373039, 52.786179127231726, 47.75311531559114, 45.84046956031553, 45.804630864051084, 45.698193427055116, 45.46346702883321, 45.80346592010991, 44.36309314543202, 45.19689490718227, 47.18934520598381, 44.840269088745124, 47.28871845429944, 44.79933523362683, 50.571342206770375, 56.63276910781861, 59.746248491348766, 54.328710033047585, 52.647978336580344, 50.436597024240804, 41.8563259801557, 37.710066918403875, 38.47160293209938, 38.387660288041644, 43.82209631704515, 43.71747885980914, 44.801461158260224, 41.796294104668405, 39.55747973534369, 34.44201869349326, 41.17259802356843, 42.28042441029703, 46.092623049213046, 41.491804430561686, 42.899570541997115, 40.48204906525151, 39.79692866725307, 39.15128692503899, 44.83163202962568, 55.49163395358671, 49.56401871096704, 50.35302700534944, 53.50241568780715, 52.998245992968165, 45.45782666052542, 41.443386693154615, 43.659549374734205, 42.95054566475653, 45.936559784796934, 43.9835528404482, 45.69685589882636, 47.42147891752182, 43.92965555191041, 43.082647169789965, 43.441744081435665, 47.44791569248323, 50.54466224485829, 49.834783846332186, 51.762989644081365, 50.718513458005845, 51.27485852087698, 53.95506112806259, 60.15860334519417, 59.22942523033389, 57.98093480448569, 55.43372408036263, 55.962463501961004, 56.70007305760538, 57.16961999093333, 57.84727219612368, 62.03879540966403, 59.60554522852744, 53.61184981561477, 56.33705377578736, 58.8582395738171, 57.28328635615688, 63.50992348886306, 56.31512380415394, 49.20092098174557, 23.846320106137185, 5.481583408771023, 13.063208710762764, 7.0850551993616175, 0.5184333326835786, 0.16787879168987277, 2.8367108154681424, 20.970308857579386, 54.875284471819484, 48.63775883951495, 57.769291554727864, 53.51283350298482, 53.898904554305545, 54.258197584459865, 59.18382375471054, 32.34211506382112, 3.1208323567144336, 15.015998944159477, 69.42866633015295, 37.21683671397548, 22.879869668714463, 47.44043573256462, 18.7619242360515, 30.300786149117258, 44.54340450225338, 48.89147735411122, 3.477322117936227, 0.263686728092932, 0.15726988354036886, 0.08070308039145124, 0.061810662699562896, 0.09960846795189766, 0.06841210363012168, 0.06596397007665326, 0.07229793140844953, 0.03171047060600212, 0.089425734514671, 0.06122820988117207, 0.056660452767485575, 0.13509376785687863, 0.04845056044418485, 0.056688449450678406, 0.07147581181338719, 0.09236516025398048, 0.017931256969008717, 0.06924198369585699, 0.12240186664125613, 0.019725379346299077, 0.03983212875262384, 0.04014475008232459, 0.13188644883132752, 0.16729178447877208, 18.660389761770926, 61.47339359406502, 44.4944219435415, 28.459825631110903, 44.709732609410445, 37.82192899334816, 17.29455770984773, 68.49433422088623, 18.397645873408166, 6.128065518794521, 46.96961402893067, 78.01092209354525, 64.83408428007557, 75.1687805114254, 59.929956620739354, 61.50694947088919, 68.24909194823235, 62.892644405365, 10.147996314110296, 0.19767590407882968, 0.3672354313875399, 0.5380267974349761, 0.9221632622422712, 21.632883471827355, 62.47782630305137, 65.6217432791187, 64.32942428896504, 65.74137556937434, 66.89287754797166, 65.12475544406523, 69.64815432025541, 66.85679174238636, 65.93358347492834, 64.39379038349276, 62.00130931792721, 54.078647167451926, 53.91535105243806, 52.916080182598485, 57.06202153236636, 61.28648481061382, 58.83060647595314, 60.741722506861535, 65.09876581930345, 64.4056986993359, 61.21223042088171, 60.23653299577775, 56.52960292754635, 49.26487130503501, 49.31093562033869, 47.14282197336997, 48.2503031915234, 48.252076102841286, 48.898219908437426, 47.411747517124304, 49.03811124063308, 49.93654189571258, 49.0443988000193, 51.82901097882179, 48.09538918156778, 54.49055487109769, 60.90390859111663, 64.72526988675519, 59.583501508159024, 58.44618282010479, 56.21410316036594, 50.664000357351, 44.4186770531439, 44.86103019406719, 45.90838147747902, 49.92055039252005, 50.37082672119141, 50.45009782237392, 49.96727366601267, 48.51558093101748, 33.3508074668146, 32.986627163425574, 48.72684371086859, 51.711163366994555, 51.54693765024985, 50.23929788220314, 49.04389281426707, 45.51979618687784, 44.71139961673368, 48.80855452629828, 59.730633535692775, 56.270298957824714, 56.00384842964911, 56.491583393466094, 55.22947057600945, 47.2150759543142, 44.680103025128766, 47.24139505817045, 45.959074189586026, 48.456047196542066, 47.23366406656081, 46.529167159911125, 49.013890604819025, 46.34685539430188, 44.37435427019673, 46.5074803752284, 50.42817177311067, 54.3958806222485, 51.938547088253884, 53.925078530465406, 52.73881650740101, 53.04920150387672, 56.11928378382037, 60.78346044786515, 61.0971127786944, 59.121230571500725, 58.525500989729366, 58.97670299776139, 58.95245882772631, 59.85188968719975, 60.585671009555945, 62.247292918543664, 59.1644472460593, 52.603479046975416, 57.55691482174782, 60.74921031152049, 60.01606441313221, 61.35625593123898, 55.62628499923214, 53.74880721492153, 30.03745194404356, 8.426857340720392, 30.173936697744555, 11.885676903109397, 1.1208577261817072, 0.7819843099963281, 1.3054145584183356, 29.202744114783506, 56.499604640468476, 56.5431978625636, 61.72623349774269, 59.529317886598655, 57.33228852671962, 58.77894493841357, 64.85591227008452, 31.0655326227988, 5.060916562234202, 25.076414615877216, 59.96476373364849, 47.6922244410361, 19.80056001294044, 49.25422599238735, 25.628870648722497, 23.565180301666263, 54.02331821380123, 54.73070590726791, 1.89741114695226, 0.22565285284673015, 0.21189676357373116, 0.1423180076263605, 0.09426691223897281, 0.06348963631617446, 0.09671944313712659, 0.06121431304622562, 0.039624285268326925, 0.12912859359095175, 0.03135989153487308, 0.28616062215259, 0.11466538984208338, 0.29246016315394835, 0.09065787202768749, 0.1440725328340646, 0.17274582488161905, 0.19093449888450487, 0.09743405761377466, 0.13515712332821664, 0.19292332442297092, 0.11743915672864645, 0.344716613932002, 0.22141569714632728, 0.26610915939654073, 0.30621180911698653, 39.12090424568423, 74.95520745554279, 52.90473276568998, 45.76807829641527, 53.52312972468715, 53.06174524368779, 18.325319328615745, 90.03999986956197, 19.463600958547286, 8.62678054840334, 51.59898358006632, 80.62248322271532, 70.75192497622582, 79.75081489932153, 63.016556001478634, 70.9709579713883, 78.2427812391712, 67.6046229946998, 9.565604752109898, 0.5443099441547548, 0.9607547882103151, 0.9315217923252814, 1.0189603100861273, 24.426238613743937, 67.69624171718475, 70.40043354034424, 70.32950924288842, 67.6942648426179, 71.52794238059752, 67.00727739641744, 71.9534646311114, 65.43882746850291, 67.41394089114281, 65.45917280258672, 65.26595292552825, 58.275822516410585, 56.36807972385038, 55.07710610666583, 58.4613976940032, 62.76341799766787, 60.50297960158318, 63.45411992842152, 68.07097711870748, 64.94566786673762, 63.98085109649166, 63.432131121235514, 58.666831831778254, 54.19204288913358, 50.58168941928495, 48.84914713521158, 52.3279207752597, 50.44188830160326, 52.39582877005301, 51.29161880862329, 50.85852638367684, 50.16840104133853, 48.8682294660999, 54.41366857097995, 50.86885790671072, 57.23067168266543, 63.59654903411866, 66.77199009926089, 62.64295808730587, 60.8474382277458, 60.40397505606375, 54.14204443654707, 49.32715854337139, 50.00572858318206, 53.353565662137925, 56.864851828544374, 56.912006562755955, 59.11549998867897, 54.47558710652014, 52.042835066395426, 41.98093183578984, 57.654954464204856, 58.162666059309444, 58.48848166004304, 56.64276722938784, 56.47743148188437, 51.78146400759297, 49.85731786297214, 47.704764258477, 53.86512902475173, 66.07019962803011, 59.95485974896339, 58.496408770161295, 60.93706830855339, 59.27397158838088, 50.70047447758336, 46.65802094244188, 50.62493355043473, 48.216131502582186, 51.41330249847905, 48.84246341643795, 47.07568276313044, 52.809838864111136, 47.80034065246583, 46.989912294572406, 47.654742271669456, 52.215929262099735, 57.86036506775887, 56.241383244914395, 57.0858891548649, 57.66223438324467, 56.16221804772654, 59.26157297626619, 63.16790849931779, 63.42354505292831, 60.16099599099929, 61.031981821983095, 61.66725281746157, 60.19365756742416, 62.30941149496264, 62.14981025265109, 65.03250521998253, 58.46919536590577, 54.017411124321725, 58.49978985324983, 64.05284620100453, 62.05055467544064, 67.7978781730898, 58.68040323257447, 61.11956442556074, 41.83148168748425, 17.699691480205907, 44.85252649553361, 17.50408091852742, 0.8815526962280275, 0.37593181635583606, 7.482797753426337, 28.90092557476413, 64.32151679069766, 60.822766519361934, 67.13498976922804, 64.43505764007568, 63.76392441411173, 65.19745265283893, 68.07616249207528, 42.50869850958548, 5.451316929632618, 20.40036689850592, 77.45539680604013, 49.7571522958817, 29.679708250107307, 71.94463929822369, 26.417070934849402, 44.78935672390846, 59.8194085398028, 75.11588342728155, 8.88507450780561, 0.6542957165548879, 0.3677469636163404, 0.47125337885752805, 0.15161583290225075, 0.16128203921741055, 0.1857069293938337, 0.1493242034508336, 0.18345993222488513, 0.25937806574567673, 0.13418834386093004], [0.08549509825365198, 0.013997788097889674, 0.0607237984396277, 0.04967417139860411, 0.049712119563933344, 0.02684341443161811, 0.13368484023357594, 0.060905265516691634, 0.08014835612547976, 0.04759715764873451, 0.08941599753715339, 0.11100499109635431, 0.0798751998151983, 0.04506484635414616, 0.027111301972200314, 1.3622658819921556, 49.2360967974509, 56.649415646829915, 41.76867277391496, 32.95890777341781, 43.59266511855587, 12.780696076731529, 45.154066547270745, 53.14901405765165, 2.7882626796922376, 22.309904175419963, 61.82361025964061, 65.16875267028809, 56.85479879379273, 66.62909815388342, 58.328790203217544, 52.770297450404016, 60.36759899508569, 31.022266918613067, 0.592638018631166, 0.4780812447349872, 1.0798113480690987, 5.474489312018118, 15.88385864611595, 45.1464218478049, 36.180715176366995, 46.90383195877076, 58.90108362320931, 63.46638910232052, 62.52351014844833, 64.55563522154286, 65.93552112579346, 62.395515364985314, 64.40598895472866, 63.16404104232789, 56.682912688101496, 50.16476500418879, 48.03937773550711, 50.258650856633345, 55.29086743631671, 58.437094688415534, 62.69697696931901, 59.21189615803381, 58.9269281202747, 59.463677021764944, 56.15109420591786, 51.37636553856635, 48.206043166498986, 45.50418515359202, 46.97082604131391, 44.5320100169028, 48.30835034770351, 51.2220359617664, 50.771940062122965, 50.23693269298923, 48.89462309498941, 48.54339838027955, 45.54876289060039, 45.771843771780695, 52.74802623256561, 60.02351299408944, 58.25258639550979, 55.54605683972759, 56.162167056914306, 47.16100215911866, 40.679665919273134, 38.23415440897788, 38.73195417465703, 44.80466181232084, 44.688194874794256, 45.031178689772084, 45.75969619135703, 44.74810515680621, 47.224960327148445, 41.61641813093617, 46.79824175373201, 44.5068754688386, 45.4632983669158, 42.647338605696156, 43.850792377225815, 39.58217497794859, 39.0217153487667, 37.462686954006074, 43.537069443733465, 51.98346607146725, 51.384688808072, 50.00939207692301, 51.18000384299986, 52.97500594969719, 44.89413499832154, 40.85933008501607, 42.138971974772794, 44.81408726784491, 48.36934320388302, 48.837336878622736, 49.15728853594873, 47.87925089559248, 46.44557360679873, 45.40672994429066, 43.25546287721203, 41.9821987613555, 48.64321485642464, 49.83756088441419, 51.731469477376635, 52.54228222754694, 54.45109190479402, 56.366091082173014, 55.96120049876552, 54.58553506482033, 54.76630533895185, 52.9846392908404, 55.878418876278786, 54.77349112110754, 57.76374924567438, 57.81884677948491, 60.494393533275975, 61.66651933423935, 54.35982619562457, 49.13946136351555, 47.51210528035318, 47.41435197091872, 38.75981476999099, 40.44748513929306, 26.01035252694161, 0.8207763058523979, 3.324197199075453, 5.576056145852612, 0.8104297674952016, 0.28154098939511085, 0.46078650340918575, 3.282777705500203, 41.761031996819284, 52.960006806158255, 53.199902888267275, 53.192218965099705, 57.18952209718766, 61.40637597730083, 60.28581365462273, 54.99883913224744, 6.033506979865413, 3.494263570154867, 46.79195811671596, 68.30649191333403, 17.215092451341693, 22.922268529092115, 44.324822579660726, 26.978405252579723, 35.65345056595341, 49.83208133328346, 31.465702633703913, 0.14924321263547868, 0.026800279851041497, 0.048497330111962174, 0.021348022517838308, 0.04999851387354636, 0.07763924197323861, 0.042532163506914536, 0.06224350237678136, 0.11643972608350939, 0.058400904940020655, 0.02023694987949585, 0.06600454209312316, 0.04633962432102812, 0.032425946931565, 0.08982848225822372, 0.0366202783170006, 0.03971181081367597, 0.0414623485337342, 0.0348527985624969, 0.022716638594565373, 0.10806519763484117, 0.02875028962960407, 0.010852021364224775, 0.0418899673217487, 0.14665791103916784, 0.20455039406736053, 2.2270808441023675, 56.71849250793458, 63.73583632130777, 33.58405513148154, 39.09860557125461, 48.84651522482596, 15.84546942864695, 54.93066441628241, 49.74144712571175, 8.473008928760406, 21.15417976533213, 65.06908524420955, 70.43933560771328, 66.99720474981493, 70.78939145611179, 65.43570918421592, 60.57935599357852, 65.01327776139783, 34.782362753345126, 1.071792675122138, 0.4440577784853597, 2.4702047917150685, 6.7306705251816785, 20.742695677664972, 50.91048209897934, 42.1403173477419, 53.089994153668805, 61.70943398629466, 68.6345511098062, 65.57449833039315, 67.40669235106438, 68.10796506943242, 65.31337438091155, 65.08405693115728, 66.51908351529029, 57.79552436644032, 52.438986609059, 51.34505325748075, 52.32281777166551, 56.790165978093306, 61.02048535500804, 65.58076235555833, 62.063624012854795, 62.863034432934185, 62.90001846128895, 59.73916469081756, 54.72088429235644, 52.73419987770819, 49.717744242760446, 46.00213789170789, 47.47344247756466, 51.811983969903764, 52.110444961055634, 53.11977671038721, 53.267242139385594, 52.194822988202496, 50.29864334291028, 50.201529379813906, 49.43463540846302, 55.27280099930302, 63.2861561929026, 61.826599105711914, 60.78181305239278, 59.92133132873043, 56.4467820813579, 47.22929062381868, 44.32299475516043, 45.02410273398123, 48.761180139357045, 52.088715030301, 52.65962777599212, 51.921214134462424, 49.95887979384392, 50.83914203028525, 48.58764271582327, 48.83704270085981, 54.38654930360856, 53.56435383519819, 50.74793515666839, 52.98480010801747, 47.55115247541859, 45.70646178337836, 41.948438921282374, 47.90633878400249, 56.72775714628158, 55.496964454650886, 56.05358800580425, 55.266556585988695, 56.21857073999221, 47.39437533963112, 42.94545835064304, 44.79354973762266, 47.504189937345444, 51.47255774467222, 50.920131129603234, 51.83609870172317, 51.38103315907141, 51.62178039550782, 47.681932141703946, 45.2269834087741, 45.647347742511386, 50.115668696741906, 51.45822932643276, 53.80251622969105, 53.53843481309953, 54.7461090549346, 58.655111789703376, 56.25246001828102, 54.58728836428735, 55.19864074645504, 55.06693932317919, 57.10290439667241, 57.925947097039995, 58.202442815226895, 60.03168329115837, 62.18652755983415, 61.20791581369216, 58.324475596027995, 52.76035424201719, 54.46608320359261, 51.65399874410322, 44.639435891182195, 47.98045981314875, 32.68140988965189, 0.3843357395981589, 6.952543806645179, 14.579559756863503, 0.44800398931387936, 1.0963031986067373, 1.9871872134747046, 6.841948166970284, 49.11286377137708, 58.97067823717671, 61.722926939687426, 57.30380035215809, 62.102828102727095, 67.46270379712506, 66.98258215381254, 53.67734947512227, 7.404684241740935, 10.995205717702067, 47.141080441013465, 61.441312528425655, 29.258255458647206, 19.054191804701283, 56.7267490971473, 28.568541965176983, 29.822866916656498, 60.375177014258604, 36.50057661917902, 0.6263589414377367, 0.027354774290635705, 0.04710137618765716, 0.06632055336188886, 0.11075746042714005, 0.053150027224253264, 0.02902481915248979, 0.05818128285388793, 0.06152710291526972, 0.060328179144210396, 0.032824764644066175, 0.13091613718819234, 0.15090781444263074, 0.12477595779684283, 0.14113875316275706, 0.09404944285990731, 0.13290352248136075, 0.21229093113253195, 0.1137383851493078, 0.1600011708515306, 0.3098772946865328, 0.1634895675365002, 0.12934884386918238, 0.15782042496627377, 0.32457178037974144, 0.496152768572492, 6.424793312626501, 80.74301765811059, 67.76582456404164, 60.06584713535925, 43.46207372603878, 67.2109660794658, 17.981456902719316, 62.70353124987695, 58.73472413709087, 6.991318396983608, 27.419534614009244, 78.2228006855134, 75.38672308767997, 74.12586150630828, 79.60863682531541, 77.97733091538953, 62.70989725666662, 74.80062684705182, 37.128226449412686, 1.2711137989836356, 0.8469700777242262, 4.617183727602805, 8.410294152075245, 28.921663145865168, 58.83084966290382, 48.102802461193455, 55.680637282709924, 65.45468168873941, 71.34588949141964, 68.6428665345715, 68.40376669360747, 69.76332295325496, 66.13837042162496, 68.65605354309082, 70.49034210943407, 60.38117824062225, 54.854370394060695, 55.05872980240853, 54.61738471061953, 59.214312338059955, 63.72015468535885, 68.49499317907518, 64.04397772204491, 64.16239799991732, 64.68193554109143, 62.578843024469194, 56.96928493438229, 55.495599469830914, 51.55373904012865, 49.57434238926057, 49.21665360850673, 57.12377925072947, 54.842928840268044, 57.62273611560945, 57.222768106768214, 53.92145818279636, 53.506436117233775, 50.221407951847205, 52.8499254872722, 58.053592789557676, 66.07260011857556, 65.49270906756001, 64.20887808645925, 63.42866766837336, 59.119339989077666, 53.00622409389865, 48.962103551433934, 48.67142454270394, 55.92401250716179, 59.689342744888805, 58.176072720558416, 59.595339221339074, 55.043208983636674, 59.61634351361183, 51.391043047751154, 60.70462865214194, 60.44692500945061, 58.36801782731087, 55.71678584621799, 57.18979666309973, 50.89968773626512, 49.08579549481792, 45.44935826332339, 49.25555959824593, 59.701557005605395, 60.18478124372421, 57.46286422975602, 58.73384944854244, 56.77020503628639, 48.989964146767896, 46.989363162748276, 47.14415557922856, 51.141733277228575, 51.87961347641484, 53.18597455178538, 52.16313415958036, 53.03180971453267, 54.140534324030725, 49.87193653660436, 48.135114946673, 46.72683108237482, 53.47458647143457, 54.13967532496299, 55.97761954030683, 55.70688970627324, 58.09800186464864, 62.70897549967613, 60.79280745598578, 58.83374044972082, 59.15508454845798, 57.99961705361643, 58.84206371922647, 60.10633384027789, 61.6137203093498, 60.32565316846294, 62.98547121786303, 63.14925762914843, 63.27294565016224, 56.257088415084354, 57.03005421546198, 62.56864878439135, 48.726573067326704, 54.808890511912686, 41.756999800282145, 3.091657522224611, 12.4008459045041, 25.619657001187726, 3.2142029077776018, 1.3274432021764018, 1.8297458488133647, 7.73179030226123, 49.95729123392413, 64.99458766752674, 66.82026663134175, 62.41016933994909, 67.65070299948415, 71.25874227093112, 70.56354138158983, 64.76783152549498, 9.659016978356147, 6.0247699003065796, 58.228075504302986, 75.86288313711844, 23.919995946268884, 30.445078380646247, 64.85347255583733, 34.54394148242089, 54.24793666408908, 61.464117188607496, 57.86289107414984, 0.9225649374627298, 0.10230525832382903, 0.12652121334066316, 0.2260784606539434, 0.17608746976381348, 0.13392545312883394, 0.20393963813060717, 0.1158952367522063, 0.1710638328785858, 0.07970633105404916, 0.09022901600767529], [0.09627122041438857, 0.050983764231204994, 0.10533339704477018, 0.11211715157954924, 0.06329749763432531, 0.025583985036299117, 0.12532447675062766, 0.05532911835959362, 0.04683080542412016, 0.0938871854375447, 0.02447796474781729, 0.049308314619045106, 0.08687104579181441, 0.0715549027306899, 0.07689022248791111, 0.06659937106193074, 26.14950841472995, 55.52929262961111, 43.13910184368011, 33.04623542293426, 40.31070816901423, 25.693813331665535, 19.722261659560665, 73.0039930343628, 12.818037040771978, 0.25582694178146703, 14.25963947849889, 52.972609381521906, 60.3067591113429, 62.5732889483052, 58.78544430578909, 57.82996669892342, 59.44330815346011, 51.27153627334103, 8.039780201450471, 0.413576886658707, 0.8410666041797208, 8.306913222036055, 41.12802028656006, 64.61052879210442, 43.35958219343617, 52.10242371405325, 54.24620297647292, 60.42730923621886, 65.42607584307271, 61.649472713470466, 66.1408572043142, 65.88943327626875, 61.94438003724622, 63.23382393006356, 59.101834450998616, 51.01468378497709, 47.782199690418864, 47.88245154965309, 48.67586074336883, 48.78457315506474, 55.92722100596274, 60.26409941334879, 57.86892367947487, 57.22132075217463, 53.56672686915244, 48.31668146194951, 43.49439405625866, 43.45482126359017, 44.37077706859958, 49.599704434794766, 56.170623687005815, 54.94872300855575, 52.96678858418619, 53.29587936401368, 51.26084781462147, 48.460079393079205, 46.65909174949893, 43.80080569174982, 48.00698680262412, 58.39483899454917, 57.41516428609049, 52.087051945347945, 51.8186951452686, 42.74982621592861, 38.6474427869243, 38.32569076168922, 45.60737094571514, 49.843236554053526, 47.58005249884821, 47.46401309967042, 48.14968655186315, 47.171710229689076, 45.43916402324554, 42.272752254239975, 48.74125842125186, 45.57780411935622, 47.08336668629801, 43.49078155332997, 42.97009083532518, 42.75843581845684, 39.250236557376006, 39.52007209101031, 45.04435785355107, 52.7392989589322, 52.695403714333814, 53.830090492002434, 52.494354786411414, 53.58946877141153, 48.4729604567251, 42.61317083912511, 41.824390042212706, 46.45823894008514, 51.22615052807716, 53.615815331858975, 52.33456919270178, 52.151982861180464, 49.37703932485273, 44.79385568249611, 42.95360903586111, 41.06126546859741, 43.706904149824574, 44.377197988571666, 47.369566348291215, 50.389273628111816, 50.65220186787267, 50.61922257946384, 54.95937224357359, 52.38670141466203, 52.289363876465835, 53.13186545525828, 53.678926267931544, 56.9927603198636, 57.094632117978996, 59.70698164355371, 60.535825529406154, 54.90986408725862, 52.7635705855585, 44.32329677766369, 32.36335273711912, 19.90400468149493, 18.31125174799273, 8.148046443539283, 0.8940955167335849, 0.10423318753319402, 0.7381336210716156, 0.22109303623437884, 0.2200310238667073, 0.5842393660737623, 5.441401177837003, 15.194759003577696, 50.86925406609812, 52.875232619623986, 51.01630764622843, 57.99882473484163, 55.69676606885849, 50.38296253450456, 55.72516010653589, 24.119962300023726, 1.189223289970429, 17.75032731794542, 70.88704278392177, 37.201535547933275, 10.385500731006747, 32.363107588983354, 32.45268864016379, 22.507856392091323, 35.97586547174762, 57.21083625670403, 18.006944464099025, 0.5944387542624628, 0.11813759908921297, 0.02605513485539104, 0.10527568764143413, 0.09320015012617074, 0.042157914234145034, 0.03268080523177501, 0.05312369295185613, 0.03437968564309901, 0.038816939678884325, 0.022878315705325336, 0.05981854298302244, 0.05925423495711819, 0.0658028464644186, 0.12795552145689726, 0.016687913504879803, 0.05501028788726657, 0.05452719284221531, 0.020535095977867325, 0.0036201068301564988, 0.0190844644431866, 0.14170349785877814, 0.02705771986755633, 0.09150519591545866, 0.07008621258841408, 0.035261119595698776, 0.08317353774703319, 24.31415492488492, 66.10961160352154, 48.649835817275516, 31.320453343852876, 48.965166922538515, 23.61617503627654, 30.286747986270537, 74.11968769565706, 24.216615384624852, 2.748223615269507, 12.864706381674736, 55.65619699416622, 68.91485937180059, 70.58153721594041, 67.36038484881001, 66.62214771393808, 67.6532917637979, 57.32641281620149, 10.149807468537363, 0.7488389950125449, 1.2918529635475529, 7.696358061605885, 51.002728400691865, 71.08876243714364, 47.026802186043035, 58.05952733562839, 57.34067063177786, 65.44223208581248, 66.99705569974839, 67.83149288546655, 66.26547874942904, 69.4932520774103, 66.41532897949219, 65.44970812336092, 64.1499876206921, 52.81662456450924, 49.95041531901206, 51.97806496773997, 52.879480546520604, 53.66340544915969, 57.531019333870184, 64.70260643189954, 63.605864663277906, 61.09330415725709, 55.47814492256411, 52.15789779540032, 47.2103730324776, 46.66219042193505, 47.407558425780266, 51.15088416684059, 58.196880894322554, 59.22474976508849, 55.71225158629879, 55.41202945093955, 54.04804483536751, 52.42142223542737, 50.42210778882427, 47.66095138365223, 53.0801764611275, 63.3693535866276, 60.65151191526844, 57.78166663262152, 57.76159978681996, 49.85137939453126, 45.37281320941064, 44.8818422902015, 49.91522381382604, 54.861112948386904, 54.005785219130985, 55.21935870570522, 55.54236981176562, 53.46056399806854, 53.62629198258924, 47.64506970682452, 55.49087693614345, 54.323505047828924, 55.30696876587407, 51.034460375385905, 51.693532313069994, 48.719865814332046, 46.53838865218624, 44.74940738370342, 49.23912094485376, 55.6423431827176, 57.2418543600267, 56.56525727241271, 57.064402411060954, 56.107528440413944, 51.532291520026426, 44.92969128393358, 45.03849783251363, 49.23758729811638, 53.79476170386038, 53.22668875417402, 54.81535850032684, 54.705241880109234, 50.84480201044391, 47.35836013670891, 46.909727281139745, 44.13751371445195, 45.84494890705232, 48.54949374352732, 48.51435715152372, 51.44669755812615, 55.160997759911325, 53.589606054367565, 56.13577735039496, 55.92948813592234, 53.68301730002127, 54.382391591225904, 54.726877673979736, 59.37404694095735, 58.87178744039228, 61.60575005315966, 62.39085166685043, 59.56141856408889, 57.144607036344475, 48.9611308036312, 37.91548928906841, 26.808468564864132, 23.03621142141281, 12.602430235955024, 2.0995920463915794, 0.16374879636831824, 0.874140581055995, 0.5941711137852361, 0.5541384232140357, 0.30769615043555537, 3.6820580738206066, 18.9264755095205, 55.75523684101721, 55.9508454415106, 57.654617140370036, 62.649331938835886, 61.438602170636585, 56.30845969723117, 60.95154577685941, 20.323366849653183, 5.281034092749319, 24.912700768440004, 57.70679250840218, 45.16116603728264, 16.01137686160303, 27.959792075618623, 47.30594942646642, 23.95317331437142, 36.21698925572057, 67.94135847399312, 19.593354925032585, 0.5820555864803253, 0.09281172056592281, 0.03043935645461804, 0.014697844031146698, 0.03436619483475243, 0.018298329913147518, 0.01368135452315572, 0.0326849382761265, 0.027075897218779694, 0.06382196142728772, 0.07575092717043816, 0.13922428411822166, 0.11164117349131454, 0.18479677097451302, 0.15723781509985849, 0.1370705658149335, 0.13432683723588146, 0.2060705116919933, 0.14446757373309907, 0.09709654225697441, 0.19297282902463792, 0.18865097464332659, 0.25651773858454924, 0.23044934466240868, 0.21135866341571655, 0.11675720058021047, 0.22856452322054296, 49.3226517400434, 69.60745580734746, 60.414537998937796, 43.96789866109049, 62.5557755654858, 38.091803750684186, 27.282912577352217, 87.08586677428215, 21.27862088141903, 1.338380853975973, 19.007311636401763, 64.98185957631758, 74.19380480243315, 75.85386168572211, 70.3356046061362, 74.22241457047002, 74.48842971555649, 60.93831562226819, 10.326628896497912, 1.0602382306129703, 2.6893010350965687, 10.03216480055163, 60.152876684742594, 79.76620627987771, 56.034858688231445, 64.6023428055548, 61.50581982827956, 68.61134636786677, 69.6592781620641, 71.28087228344333, 69.65506553649902, 70.31174090600783, 69.01034555127545, 68.93163927139776, 68.03931574667654, 54.91788141189083, 51.920343368284165, 54.015697048556426, 54.97616783265145, 54.19415312428629, 61.382516199542636, 66.82791525317778, 63.56877865329866, 64.15441205424648, 58.287907338911495, 54.45808156844109, 48.60317530170564, 47.785659220910844, 48.77821499301542, 53.47788518474948, 63.543377384062744, 60.86422989445349, 57.967253577324655, 57.892854059896166, 55.73799802410988, 52.12189435958863, 53.526655935472064, 48.37617205035303, 54.21300795770461, 65.96766102698543, 63.59641959590297, 58.95021130961757, 60.165106634939875, 51.7646566514046, 48.014764862675825, 49.618300391781716, 55.55822010963194, 61.519956050380586, 61.19472096043249, 60.29416045834942, 59.854603967359, 58.2336413475775, 57.36062372884443, 52.57753649065572, 59.08397589960406, 57.996953764269435, 59.91929954098117, 56.2343975036375, 55.49499542482438, 53.77421240652762, 49.84978298987112, 46.45723481332102, 55.16268437908542, 59.117700438345636, 60.733305100471746, 58.92848530123311, 59.1554924749559, 58.667235835906006, 54.781735943209746, 47.64497949231056, 46.56718277162122, 52.249112513757524, 57.05545940706807, 56.59261580436461, 56.81633210951283, 55.55222672800864, 54.28921568778254, 50.1276280033973, 48.789503574371345, 45.42361967025265, 49.39687082844396, 50.61281734897245, 51.15168825272591, 57.291189932054095, 58.970795908281886, 56.71460543909381, 59.315521255616225, 58.35356389322589, 57.51776172268776, 58.72482799714612, 57.4529210213692, 61.104377008253536, 60.98851803810366, 63.98155320075251, 64.78720803414622, 61.457539373828524, 59.644109972061656, 52.351709950354795, 44.40994585714033, 33.70377763625115, 30.738410872797814, 21.03366101941755, 4.466260729297515, 0.5587309671025122, 2.3301612225271042, 1.3083987466750608, 1.4566845639098076, 1.0195223121873795, 10.0044414881737, 19.734262151102868, 61.85509512501379, 62.74490048808437, 61.31524362871724, 66.57617753551853, 64.43222961118146, 59.880479843385764, 65.80089753673923, 29.797726485037035, 2.9897381653708797, 23.14453944083183, 78.34398623435729, 44.80997270153415, 12.853657064899323, 48.35956865741361, 46.18920356996598, 35.200154012249364, 51.21599551170103, 72.84678443785637, 34.903897393134336, 0.8626110803696417, 0.28935906987997795, 0.1627300066813346, 0.17006987976210733, 0.1497774670321134, 0.22549156069515214, 0.18352590771692415, 0.09707985686198359, 0.1320618063571953, 0.12688538855722836, 0.19543056165979755], [0.006459690245514315, 0.14442283419832108, 0.008195367296256365, 0.05384968000374014, 0.03215025870069381, 0.1006623368049341, 0.03721390452776705, 0.0644434234427829, 0.04993823424522435, 0.08607449821166455, 0.08921627075441423, 0.08874475895877808, 0.04513008257133826, 0.11657461118433746, 0.111126423693232, 0.45822826003836054, 6.754731324411209, 62.063643624705655, 55.536168544523186, 38.776512299814534, 37.49050048089797, 41.325664597172896, 10.771328595376785, 50.48221026697467, 55.58880675223566, 7.357327505465477, 0.8135588383001666, 24.397873993842836, 55.39707345347251, 55.995085854684156, 48.17487601310977, 57.36038054189375, 57.01950303969845, 60.80624941856631, 14.60273115865646, 0.21439811725529934, 0.07206108766577898, 0.5078052416924508, 0.6568841131464128, 3.806966442254282, 26.96887585424608, 52.721428640427135, 67.09359307442942, 63.22001718705701, 65.483558177948, 62.58922161594514, 63.20097407987041, 65.1943539804028, 67.62786696034094, 63.169928519956535, 61.96541963085052, 58.51684431875906, 50.89093300604051, 46.180499830553615, 48.18585864959225, 47.928782586128484, 48.67304448158511, 51.09074638735864, 53.46373327316777, 48.33135112639397, 46.69456958770753, 44.492888296804125, 47.40478923243862, 44.089723556272446, 49.00718335182437, 56.02357795161586, 56.357210836102894, 58.01573015028431, 58.75565782670052, 55.59154456661594, 52.00575690115652, 49.68848336127497, 47.511367874760786, 45.03281824050411, 49.99510288238526, 55.831605388272195, 55.33140120967742, 52.178207828152566, 48.59631115390409, 45.58927312974007, 39.79981553169989, 41.27170455071234, 49.00765011387487, 50.65468080582158, 48.713240931111, 49.98307689543694, 50.37374104222944, 51.836028099060066, 43.92357195577314, 44.89939881909279, 52.66847272073069, 46.89210407195553, 47.79943458495602, 42.12803640673238, 44.658745719540505, 45.21500449026785, 41.95819385590092, 38.26081868140928, 41.35685136241298, 49.658179129323656, 53.06190606086485, 54.26582267207485, 53.87017319279333, 56.60757964657199, 47.639947091379476, 41.54788647928546, 41.77648221292804, 45.478105314316295, 51.00842368218207, 53.63747858232068, 53.37335401965726, 53.29582837320144, 50.33758463398103, 48.27117804558047, 45.84583536271126, 44.082435792492284, 43.475488232028106, 42.682675238578554, 43.669406290977236, 44.38413666140649, 45.724084992562574, 47.78896577896611, 45.73454203144197, 45.635172705496515, 45.45632831511959, 48.73663002444852, 50.07273443283574, 51.681977010542354, 54.16664161989766, 56.87355164558657, 55.39392379022414, 56.32133683850689, 45.06117697684996, 46.34263884636664, 33.70795496048466, 35.546103139077466, 15.722039303471966, 14.298829840075586, 5.818356640877263, 0.40314264655593907, 0.2778861064824366, 0.8301776142851, 0.2122007932273611, 1.6283788411848008, 4.906240836266549, 29.12459481147028, 54.927789318946104, 53.45237801151892, 57.50990913760278, 48.648466910085375, 41.58970679006269, 39.76141945008309, 42.14971534667477, 2.253183727302859, 6.333288829172812, 55.03485041279947, 73.66927408402967, 23.390913317280432, 18.122279797830892, 40.371897143702355, 29.872530006593276, 25.907478563247192, 43.564094574220725, 54.39543347204886, 7.047216584605556, 0.4634891083884624, 0.11728783138096334, 0.1362383798245461, 0.03982918314455498, 0.15709573643342142, 0.09670934609828458, 0.0568132451735437, 0.07512082751359671, 0.07586593228963114, 0.07191965251319832, 0.06719430728304772, 0.0393436519399045, 0.07261489262624134, 0.06605476681743899, 0.05852364371680926, 0.026003466055337942, 0.015625376366980134, 0.09131824747929651, 0.033592695009804545, 0.029586668036157088, 0.06829638604915912, 0.1055331314883886, 0.04611225325554129, 0.011461320776312102, 0.08979203179478647, 0.1424897032519502, 0.5472099240268431, 5.709068621358564, 74.31236236326157, 61.36872514601677, 38.400568808278734, 41.99771173538701, 37.48857459714336, 14.001781882778292, 58.55421666176089, 56.185383565964244, 17.978167995329827, 2.0519825623881434, 24.904589306923654, 63.489268287535644, 65.58493575742169, 53.919496997710205, 65.83916418014034, 62.44667483914284, 68.37262307443928, 17.86170105780325, 0.21640073237640245, 0.05781697357193597, 0.7671684759759134, 1.0445109971107975, 8.227243019688515, 32.8273985462804, 58.49666372422249, 69.71581520572786, 66.65070256879254, 69.21306148652108, 62.375919203604425, 66.87872563638996, 66.40549167510002, 68.99321263836276, 64.81765347142374, 62.14627619712584, 60.40035078602453, 54.21292558793099, 47.908833411432084, 49.50464971603886, 50.01419305801392, 51.600450546510764, 50.84870476876536, 57.188055130743216, 53.36218310940651, 49.65171898564985, 47.8083775889489, 50.55890437095396, 46.66641481461064, 51.441512184758345, 57.31608521553778, 60.836777225617446, 60.07351144667595, 58.7110173317694, 58.56840779704433, 54.62249948132423, 51.33690257226267, 51.348842267067205, 47.5348432602421, 51.97145969636979, 59.75381474341116, 61.27560807812599, 58.6291653110135, 53.89175407348141, 51.323405696499734, 44.910530505641816, 45.52791157076436, 54.14194637729276, 57.12494027230048, 54.15365857462729, 56.58600661062426, 56.14674429739676, 58.3668803399609, 51.740275198413485, 49.01236872519217, 58.30752703451342, 54.56085158932594, 53.741539062992224, 50.97340868365381, 49.86228750598047, 50.607067154299834, 46.93952552733883, 44.46805969361336, 45.615776584994414, 55.097353381495324, 58.05625607890468, 57.96537868438229, 56.855704861302534, 58.98376326407156, 49.647271017874445, 43.96470192940005, 45.455571297676336, 46.77797094468148, 53.38208913803101, 55.675871602950565, 55.25247527707008, 54.50305938720704, 51.94814120569537, 50.316909820802756, 47.55476105597712, 45.97064910396453, 44.40060669376005, 45.8039052255692, 47.16475194500339, 48.3181562731343, 46.55022636536629, 49.20048167628627, 48.4086492753798, 48.030972096227835, 46.92343596489199, 52.182855836806766, 52.09859940313524, 54.91894045183736, 54.86525889365904, 60.01717836626115, 56.61087835988691, 61.53413541855351, 51.8898626296751, 51.794866746471776, 39.299874151906664, 42.52225029853083, 20.43637621787287, 17.724006252904093, 7.399762647767221, 0.2175991237163544, 0.07911646633499092, 0.41107818364135684, 0.4504613848703523, 0.757486472927755, 4.5626931805764475, 35.32599541448778, 59.036640736364554, 59.320636026320926, 61.19909048080445, 55.60345288245909, 44.0609686605392, 45.04713881400324, 37.477180111792784, 4.406521070388056, 11.156352373861498, 47.19662120265346, 63.85965770290744, 32.22759166071492, 16.909059324572166, 40.12906320633427, 40.23283343161307, 20.64491883400948, 49.1576180150432, 61.643612692433024, 6.417506529438881, 0.37682532002368285, 0.1416368941746412, 0.12572982153224369, 0.10506826167505597, 0.10137868264029104, 0.03305611553631964, 0.016602498531762152, 0.010898039308226398, 0.07386290348104893, 0.06411137029288277, 0.052885723059936884, 0.12508977039326585, 0.37305414496410283, 0.1876739827134917, 0.16073764181665837, 0.18258204142893517, 0.17844672945718612, 0.1743606922607268, 0.21758659051791315, 0.2155774330059367, 0.19811113395037191, 0.19342224684453782, 0.24322669532510544, 0.3349160511166819, 0.41217304585922154, 0.3587638166162276, 0.9521549916075123, 14.762671685987904, 90.90321156286424, 71.22593556680988, 52.918519896845666, 53.15089679533436, 64.38858539827409, 13.438279474935225, 65.18187692088466, 62.618474652690274, 14.818704705084524, 2.519369005195556, 31.665682715754357, 69.06652173688336, 72.96991548230572, 63.290713987042835, 72.82663914465135, 68.0135222404234, 73.27495036586639, 19.84613991552784, 0.45632548149554963, 0.32905998309293105, 1.7981844972218237, 2.4113111390221507, 10.120518149868136, 38.484291799606815, 62.54684040623327, 72.33562900174049, 69.19668166868149, 73.39475524040961, 65.59039177433138, 69.42822702469365, 68.31175573410528, 71.35637006452008, 67.7837811746905, 64.89453192680114, 64.67267090274443, 55.80666303634644, 50.54146551316785, 52.789850465713016, 52.08836593935567, 54.243363180468165, 54.82621169859364, 59.060492669382405, 54.13909873654766, 49.6699893859125, 47.899455024350075, 55.197224770822835, 47.959639872274096, 56.219645469419426, 61.60464002240089, 61.060022846344985, 63.76397540492397, 64.31937517658358, 60.57626516588273, 58.05114523057015, 53.40298752630911, 52.116144164916015, 49.77326539254958, 54.6002596424472, 61.746425859389774, 63.07623878602059, 59.19493582940871, 55.81087566191151, 56.38146285087832, 48.52042505818029, 48.473148730493364, 59.5386335157579, 61.19577607800884, 58.49254523554156, 58.69416290713895, 61.02583546792308, 61.28989727266374, 54.70701086905695, 52.90343446116294, 61.43904147609588, 60.159525102184666, 59.874419781469534, 52.68588804429578, 53.868510107840265, 54.30108477992397, 50.49805664247083, 48.85760376530309, 50.99027095302459, 56.280905046770656, 59.75346565246583, 61.54070538859214, 60.60421989810083, 60.751669637618534, 52.61405375695998, 46.34656513890913, 47.49873784280593, 49.28176495336717, 55.99913766307216, 57.74789894780805, 56.94921808858072, 57.36564828503517, 53.55076674492129, 54.15452149606521, 50.74449916039744, 48.49227028508341, 47.941189042983524, 49.29308491368448, 49.45879720872449, 50.91714620590211, 47.780324797476496, 53.67611392851799, 51.477648981155895, 50.16959344187091, 49.67326848737655, 55.39926605839884, 55.78811414780156, 57.439271173169544, 56.88031381176364, 61.78618692582654, 58.522351326480994, 63.40525111844463, 52.11546167250603, 54.13829072829216, 39.32978222447057, 45.13913408402474, 22.97481652229063, 18.928334712982178, 8.365688958475667, 0.7984191635924002, 0.5966033510142758, 1.731792988796388, 1.11363799100922, 3.799612488477461, 11.207251010402556, 37.279963339528734, 63.92032107999248, 66.39429723062824, 68.79115566130608, 61.864249936995975, 50.561551970820275, 49.40665321965372, 46.08500580633841, 4.615337271844187, 9.42444355257096, 67.82298918693297, 79.56754607539024, 34.08082331380537, 22.395205920742406, 61.25748672792989, 41.604337230805434, 38.927817729211625, 54.585699804367565, 76.0437044020622, 15.195121822818635, 0.5924881105461429, 0.3848673739740926, 0.23121509550800248, 0.26751370499691657, 0.41263459851184203, 0.12708785793473645, 0.28437772104817055, 0.19123813017241417, 0.2280654475813912, 0.14775061288908606, 0.20142454083167738], [0.03145885477293163, 0.0672851882935051, 0.1438768280129279, 0.08159463053509113, 0.024105749438486757, 0.032822968167883736, 0.04102627979591489, 0.07513686939473115, 0.05624789909850206, 0.07796976294729017, 0.042291803420671535, 0.0658183444231268, 0.08455234279315318, 0.09252678948424517, 0.07375221143686965, 0.02191028891942434, 0.7446708025470857, 46.918921316823656, 50.13289574653872, 49.006241982983006, 40.77082572444793, 48.152914662514966, 23.641695937802716, 28.39615183491861, 72.49890158253332, 40.253716130410474, 5.2891573213761855, 12.486387894999597, 58.40672377617129, 67.3282527923584, 51.853306139669115, 49.27984299198274, 61.38000196026218, 52.611194349104366, 20.62912541051065, 0.9024039547770255, 0.2040027484538094, 0.0734911899593088, 0.08074481686156604, 0.55888669745576, 11.56974861698766, 33.9975788516383, 57.20120683793099, 65.19535026242657, 63.15851442275509, 60.536731596915956, 63.799586603718424, 62.31962142452117, 62.62620172192974, 62.18886921482702, 62.343081120521795, 60.42311230013448, 52.82903102136428, 47.532819317233184, 46.141562461853034, 46.803536953464636, 48.45463122090986, 46.79905368435768, 44.98576941028718, 47.62696012373894, 47.42031005121047, 47.31014244018063, 45.47119409807267, 47.27552752340994, 51.42408901645292, 57.80134124140586, 60.80530804972495, 60.34066407911239, 58.33972577125796, 55.00532673251245, 52.40613283649568, 48.79228061245334, 45.10859058749291, 47.089701314126295, 47.56775194598783, 51.61127628818635, 53.39151067118491, 49.93995043539232, 45.61274067048104, 42.26460941376225, 40.19874411244547, 45.805772273771225, 50.30721372173679, 51.229107995187086, 51.4384723478748, 51.2133361447242, 48.22374090071648, 52.150970889676, 40.65152683565694, 52.47580589786653, 49.896310144855136, 50.3567297227921, 47.60597544331705, 46.86316482482418, 45.330612428726695, 45.12442519587856, 37.886675557782574, 40.814552307128906, 43.305873178666644, 49.20052482235817, 51.76319360733033, 56.02139319142988, 52.28144461108793, 54.95020174211072, 47.519730367968165, 42.4961704592551, 41.02632499510243, 43.682510929722945, 49.754508618385564, 53.6309439136136, 55.08949687404018, 54.22181760111163, 54.305407231853856, 49.57946500470562, 46.97967883079283, 45.08829232185118, 42.73066543763684, 42.93127506009994, 40.697689210214925, 41.52881199313749, 41.90009570890858, 44.24429632002308, 43.72169148537421, 46.80475681058822, 47.4393335465462, 47.703379661806174, 47.63494999177995, 52.66522107585784, 53.36771365134947, 52.80744229593585, 52.555218204375244, 51.78765350772489, 52.167491912841804, 54.914308132663855, 50.215222374085464, 41.154798307726466, 29.031128652634163, 25.997185130273145, 7.1813057507238085, 0.21205614050549848, 0.4463200974127939, 0.16963037511994764, 0.13084011062258674, 0.3833195699318763, 10.5031120200311, 40.23264515784479, 54.93551246581539, 49.681089693500155, 49.50177069633238, 53.13375996005151, 53.919999061092255, 50.77086141032558, 17.8231559261199, 1.8390081582530853, 26.91940692163283, 72.49385741449171, 65.50490371642574, 21.217588801537794, 31.743326033315352, 34.340123361156834, 25.137329024653283, 35.487326422045314, 50.304734783787886, 48.25974825889834, 0.7374476353006979, 0.09294869708678416, 0.01947882543918827, 0.06525075754090663, 0.05987742833132225, 0.18513087724005023, 0.02628790875596385, 0.12682394064482183, 0.10526457936653208, 0.030810529884371548, 0.05342382704839111, 0.05582657755322515, 0.0115551378187393, 0.030118419240499218, 0.056727179025690404, 0.05009452384265681, 0.0654631554179134, 0.11697189672099007, 0.024005606425024813, 0.06790816333265075, 0.06779772409748647, 0.025316334982973435, 0.027279335697511994, 0.045381049144892924, 0.05030178893057089, 0.05341613935607095, 0.032514541169568416, 0.03830242736805831, 0.5134088684233927, 48.08518317437942, 58.34463265634353, 49.91775766495736, 43.93732378559728, 49.057856452080514, 19.508884722186675, 40.96121365024198, 66.56662264177876, 43.18328342130108, 8.227294991093299, 14.41503986235588, 64.35602188110352, 73.56936347100043, 59.580806839850645, 57.451214790344245, 69.07813195259341, 58.73324932590608, 25.494429449881277, 0.7869306026447205, 0.3851382013770842, 0.1769363411491917, 0.4850876397423206, 1.3453240620513118, 13.358194481941963, 36.417869521725564, 64.31824945634412, 66.96234272372338, 68.1405834997854, 62.63543890368555, 65.83370424086048, 64.37229579494846, 66.30260006073983, 63.70389253862443, 64.08990867676275, 61.53927372347925, 55.09027742570447, 49.19163280917753, 49.780839489352324, 51.65863106327673, 49.42464120926396, 50.29559958365656, 49.21173495631064, 49.22286272048951, 49.14558026098436, 49.44115046531924, 48.015710153887355, 50.241161008034986, 54.8319265919347, 59.27675254883305, 61.86877635217483, 64.72476782337313, 61.21872194351689, 59.32423283976894, 55.55861234664918, 52.57811307907105, 47.420055097149266, 48.75920718716037, 50.973949970737586, 55.5868887132214, 58.62584698584772, 55.89102929638278, 51.74009869175573, 47.98066769876788, 44.44110908815938, 49.8481983523215, 57.07038010320356, 58.68548270194762, 55.96920605628721, 55.86489062155447, 55.55811028326712, 59.24218470050443, 47.055200146090606, 54.35823763570478, 58.90548844491282, 52.72653556639149, 53.65928696047876, 51.886093231939505, 51.729669109467544, 51.39832688916115, 43.67221078565044, 44.38963582438808, 46.38767550068517, 52.456076375899784, 57.33340640221873, 56.30447064676593, 56.816139913374386, 57.556506895249896, 49.581645842521425, 45.815468372837195, 44.17098329913232, 46.32451749617054, 51.918362571347146, 56.518537921290246, 57.21176978080504, 56.752530836289935, 55.680527456345104, 51.37162339302802, 49.64651400043119, 50.04697230554397, 44.37045151187528, 45.188328450725926, 43.32976041301605, 43.18333048974314, 43.45878285746421, 46.48861377469955, 45.65595342266945, 49.76662089747768, 48.94233088339529, 50.14432945559102, 51.656822850627286, 54.49244545352075, 54.42224679454681, 55.910829421012636, 55.31743364949381, 56.70739220034692, 56.03818093576739, 59.03286349388861, 53.450652168643096, 45.362689571995894, 33.438390070392245, 28.215358026566047, 7.859707618913344, 0.07776704076076708, 0.7520605479517292, 0.28937448356901446, 0.1357148506588513, 0.6840612967648815, 12.260754531429662, 44.50842872742684, 57.42503296944403, 55.99803939942391, 52.35123142119377, 58.085544416981364, 59.53903751988565, 54.37569218297159, 18.818994722058697, 4.539418326270196, 22.412699691710934, 66.92424866460985, 66.34989600027761, 27.442480479517293, 22.274814651858424, 38.707247164941606, 20.424448290178855, 28.334786353572724, 60.19353205157865, 54.43488074887184, 1.2050447829308049, 0.16012138536860868, 0.058427905708911924, 0.0769089073723843, 0.05575273816864337, 0.13366714360252505, 0.07924320792118389, 0.06228519671206033, 0.1210557352451067, 0.04296223377628673, 0.05174237513734449, 0.14002398798061957, 0.09293740495078026, 0.23547884978113637, 0.29086222631796715, 0.2092289849514923, 0.31184797926295194, 0.22501644828627188, 0.11597438895654295, 0.1961439733784045, 0.1863366996328677, 0.13880302769041833, 0.20293021003805822, 0.15432694145748693, 0.2007216091958746, 0.1974080031317088, 0.17891410437803115, 0.16988372039650718, 1.5287850821210494, 73.53949854450842, 62.6945843235139, 63.86201504738101, 52.94873391428302, 72.61016353484123, 31.61292683693671, 40.292900608431914, 83.44241634491952, 49.13876318162488, 10.31696907935604, 16.701179588994673, 71.07459483608123, 79.44669000564083, 65.88668761714813, 61.79371003181704, 75.2362060546875, 64.0123987197876, 28.18552055666524, 1.49469870473108, 1.0457916509720588, 1.2175383899481067, 2.1203720281201024, 3.3650964883065995, 17.45116226134762, 39.74344714995354, 65.85004483499836, 69.4325965450656, 69.13364918001237, 66.24559233265539, 70.12747580005278, 69.57817923638129, 66.75786956664055, 66.80821711017241, 67.4464024266889, 64.66206873616865, 59.170401403980875, 52.064678745885054, 51.5609012880633, 54.13386629473779, 53.60026313412575, 50.01178864509829, 50.10492140246976, 52.55946613127186, 53.11204964114774, 53.57708584877753, 50.77920036931192, 53.42652959208335, 58.76107461990849, 61.67337563730056, 67.44294289619693, 66.09654226610738, 64.12374304186913, 61.724499810126524, 55.71571111679078, 54.0136887950282, 49.70037598763743, 51.36244112445463, 53.98997806733655, 58.866268665559836, 61.67690969282582, 58.20562777980682, 51.825853470833074, 50.481182605989524, 51.04962818084225, 55.180393880413426, 61.58301991801108, 62.53597544085596, 61.168664655377796, 58.994616462338364, 56.12183332443238, 60.33678485501198, 50.15647311364451, 58.28207085209509, 59.155500319696245, 59.67001330467963, 56.88033734598468, 57.006284652217744, 57.097040453264796, 54.69037609715616, 47.061601454211825, 49.05998237671391, 49.36529182618665, 56.62080587879304, 59.038350889759684, 60.54394875803302, 59.54850612148162, 59.42363354467577, 52.32941127592518, 48.632616612219046, 44.6230992194145, 48.40204008163945, 55.37289204136018, 59.06940429441391, 59.37483141499182, 59.640673975790705, 59.77715284593644, 52.98476088431574, 52.78846979141236, 52.51806943647323, 47.74113639708489, 48.31333568019252, 44.17081071484474, 46.50410321451003, 45.633423328399665, 49.77883515819427, 47.41063748636554, 51.63159024330878, 53.80809384007608, 51.71959254049486, 52.72373499408845, 57.33313183630667, 57.54583020364085, 58.3458407463566, 57.667651176452644, 60.37376888336674, 58.08182208768783, 63.15979311543127, 59.04968261718751, 47.60267673000213, 34.88104958688059, 34.89045543055381, 9.533202052116394, 0.804357203024049, 1.7879607167936142, 0.7657655544819371, 0.7340249383161146, 1.5619106013928692, 15.281763057554922, 47.76523151705342, 65.29543345974338, 64.4788509030496, 57.70153261000111, 63.377021820314475, 62.18997924558578, 59.86462562314926, 23.96689964878944, 4.395693367527378, 34.71573345122799, 82.48800170037055, 71.42607842722248, 28.445705098490564, 41.40138987571963, 52.72174635241109, 31.55413050805369, 53.942215365748254, 64.19679718632852, 71.57728579736525, 4.085355439493734, 0.43021432454547576, 0.1925575021173685, 0.22904492163610077, 0.15204979106783867, 0.1956391214363037, 0.16356279022030293, 0.3648821625017351, 0.24800795731284928, 0.12420295467299801, 0.14997055183254904, 0.2046784839683002], [0.024802033346326604, 0.0416346455383445, 0.05296046642826931, 0.06618359982366524, 0.07049297463269004, 0.04286987421613547, 0.014499659000355151, 0.14398057163963396, 0.09735885076224805, 0.10052932861952052, 0.013308099249467976, 0.08983118654859644, 0.09285349534043381, 0.04840015951964644, 0.09132952429354192, 0.23118365525959, 0.39201754836305497, 23.123896006614935, 62.21599632693876, 52.16486784719652, 46.26383450723464, 39.23354294992263, 36.28520319538732, 12.526253884838475, 75.26303506666615, 71.3197821955527, 11.99565427918588, 8.305653160618197, 46.934006752506384, 69.11374707375803, 63.89717909597582, 56.38268270800191, 58.22004641256025, 56.44713901704358, 34.80310424681633, 3.5735672760394315, 0.3593853590709548, 0.10328724514693023, 0.3824747281689798, 0.6176207587122917, 8.71520548097549, 43.423720790493874, 64.50192228440316, 68.42886201796993, 63.952249173195135, 58.56855684711088, 61.056704521179206, 61.686954882837114, 64.31253848537322, 62.775039980488444, 59.99462081540016, 60.45220059733237, 58.17797507009199, 48.104453779036, 49.24920143619661, 48.74904040367373, 46.2501532800736, 49.09185947910432, 46.49551714620283, 46.24201043959587, 45.81091450106713, 46.91959204212312, 46.91451257274997, 49.160755911181056, 54.59831414684173, 61.68704509735108, 60.487972613303896, 59.84994811396445, 58.20157204904864, 55.236770106900124, 49.31143376135057, 47.7262431575406, 45.191678154853086, 45.85361734513314, 45.204088534078295, 48.916439317887836, 50.24866057980446, 48.541633313702, 45.863227152055316, 43.67320706767421, 42.51365246311311, 47.70013978404384, 52.03391559662358, 52.17543863481092, 52.911957771547385, 52.02641210248394, 52.585706787724654, 45.217620711172785, 45.154066547270745, 56.76070505572904, 48.79484584254604, 51.535660836004446, 47.96911239624024, 49.117543158992646, 46.451217897476695, 45.39594342631679, 41.72742512918288, 41.528302085015085, 39.03657328697943, 46.927032778340006, 51.54551775224748, 54.053516541757894, 51.08490205580189, 51.90756036389259, 45.09450535620413, 42.81356473122874, 40.99027449084867, 42.11790100220711, 50.9957387370448, 54.977222950227805, 54.04405578490227, 55.08791223649056, 56.19498552814607, 51.97233830728839, 51.19096294526131, 49.114636682694965, 48.23712402774442, 48.82105119766728, 49.450305277301425, 46.469456918777965, 43.04477276340608, 43.4898558739693, 41.327684617811634, 45.879457919828354, 44.30204537607009, 46.17937018794399, 49.20920894991968, 48.42824151439052, 49.774834340618504, 52.441049775769635, 50.03724090514645, 56.70547808370283, 57.47496866410779, 60.40129999960623, 56.36052916126867, 46.96793917686709, 35.144095497746626, 16.82356930548145, 12.93066691967749, 2.2647289787569354, 0.5609306200377403, 0.14529954521886765, 0.24454957595275295, 1.4099147122713829, 12.496397783679347, 46.6732632729315, 50.174696445465095, 48.02308420981131, 53.248179420348144, 51.361032993562766, 60.15450054599393, 48.78913879394532, 10.937233086555235, 13.11094101398222, 58.14914172695529, 67.84003580770185, 28.839536559197214, 11.724085057935408, 33.705009260485255, 39.48377839980587, 32.785105589897405, 27.26638763181625, 53.999081888506495, 25.624501128350538, 0.03834481884334837, 0.08810401834066837, 0.10460329227029316, 0.024897319362348607, 0.023139835140036962, 0.031125853589225202, 0.007453006072600763, 0.029127017196808613, 0.04900252679362894, 0.20984272863115036, 0.006950062168236341, 0.03638351884400172, 0.05422420123772276, 0.0757444384057195, 0.018069809715774272, 0.08407998063992109, 0.07719278891360568, 0.0324461525005679, 0.0504963522807004, 0.10620263104717578, 0.0636605620234003, 0.058197726931182615, 0.012028430768799399, 0.029945758344124884, 0.08112753906677808, 0.03023674535084396, 0.08684267755597831, 0.24037079615218027, 0.5738778123932501, 25.296863586671893, 70.82119403346893, 53.56151796156361, 44.22260953534035, 49.12794528468963, 30.724439390244026, 17.690095401579335, 74.32647505114156, 67.61770802159464, 21.30214333534241, 8.322786073530875, 51.54518435078283, 74.36660089800435, 70.63867045987037, 62.49582605977213, 64.79208354027041, 62.13128882069742, 39.86377369972968, 4.335217283618066, 0.15452252370455574, 0.2051200570478555, 0.14236230283014237, 1.450587729773214, 10.406166718852136, 47.35610869623, 68.20545165769516, 72.20553182786512, 64.98496217112388, 60.02990253510014, 63.64835569935461, 64.28800798231556, 65.69978667843726, 64.76858854293823, 62.656745218461566, 63.842250224082704, 61.39385969408097, 51.01498972985053, 51.26631952101185, 51.37650282152238, 50.14070910792197, 50.24785649391913, 47.5347295115071, 49.44289592004592, 48.25347246662263, 49.69495527205929, 47.82299626258112, 53.19137173314249, 54.57885919078704, 62.97988576273765, 64.20335146688646, 61.45069091550766, 58.83567417821577, 57.297861883717204, 52.09439462231052, 50.03879808610486, 49.160100875362275, 49.082281051143525, 51.14013295019827, 52.809058312446844, 54.12620198342108, 53.96782844297348, 52.55233526229859, 48.66579986387684, 45.380783465600786, 50.91966044518256, 56.8229099242918, 58.68653781952397, 56.49089305631576, 57.516828198586744, 57.70281914741763, 52.69625879103138, 50.32730410175939, 65.52691213546261, 57.250256076935806, 58.10503859673777, 53.46138377343455, 55.92178067853374, 51.386030258670935, 49.95315705576251, 44.918590976345925, 44.876233300855084, 43.284692379736136, 49.92688109797817, 55.48107101071266, 57.415176053201, 55.23926081195955, 55.75668027324062, 47.136801135155466, 44.77572648755966, 43.710289155283284, 43.8723732579139, 52.853502688869355, 56.538451794655096, 56.1195348155114, 58.23018573945569, 57.56781508845668, 54.555266134200565, 52.73788690567017, 52.49868900545182, 49.972772828994266, 49.77628169521209, 51.206754407575055, 47.64751726581205, 45.688034488308816, 44.839484614710656, 44.31674249710576, 48.67156574803014, 47.277892712623846, 48.37154757591986, 50.004226315406065, 50.62134065935689, 51.51057335638231, 53.70515907964399, 53.71018363583473, 60.25155959590789, 61.25805547160488, 62.574163636853626, 60.405979387221805, 49.897596682271654, 39.820682541016616, 19.77681790628741, 17.031319602843254, 4.251066753941198, 0.5258615050585039, 0.34133246649176846, 0.2616448586265887, 1.6142384515654657, 14.826606319796655, 50.53488769838887, 53.96042693045832, 53.29930359317411, 57.661308703884, 56.30496486540764, 62.731748780896595, 51.068247672050234, 11.867996819557684, 17.6426366836794, 57.76814230026738, 66.2910290687315, 38.84421240898871, 15.638857599227661, 26.20537277190916, 49.507858214839814, 27.73991380968402, 29.660959320683634, 62.96027783424624, 24.690731879203554, 0.23214667374568604, 0.03373031121408267, 0.09575200432370748, 0.025503697106614712, 0.029063261444530183, 0.038900381975596955, 0.03455637999239468, 0.059288567187444824, 0.09305813274676762, 0.08761731502149375, 0.030550653708257505, 0.16141015976186723, 0.16864541587570023, 0.1839691049028789, 0.1593861861094352, 0.24616923904226673, 0.22320218354223237, 0.11010647721348271, 0.13045683683406922, 0.33678447827696806, 0.17978384399846678, 0.1987215528084386, 0.17480739812937476, 0.26582518592476845, 0.14311475438937066, 0.1563422736381331, 0.23542681708931926, 0.3516966555147402, 0.649820598623445, 38.32939347913189, 80.5297270128804, 67.10346175778297, 56.51442727734966, 61.57760704717329, 51.36129186999414, 17.292639670833466, 90.13857687673261, 79.15508531755017, 18.28720958002152, 11.825073342169485, 60.243353997507405, 81.53215146833851, 79.43055337475192, 68.04249286651611, 73.10049118534212, 68.03875092537173, 44.07639534242692, 4.9426556306500595, 1.4431849915173747, 0.6909951279240271, 1.2124765712407328, 2.797126255689129, 12.870869405807989, 50.38942660054853, 74.55094445136287, 72.4566262768161, 68.26112577992102, 62.277432410947746, 66.49827926389634, 67.97156072431996, 68.35615696445589, 66.70432136904809, 64.76502703082177, 67.21790867467081, 65.20316362380981, 52.62240056068667, 54.289662837982185, 54.59162258332776, 51.00444639882734, 51.47004742776194, 49.67454325768256, 48.829476448797415, 49.997060145101244, 51.76578629401423, 51.49204015731812, 54.374684133837306, 57.63173403278474, 66.02200938809302, 66.42639790811847, 66.00522164375552, 60.92341846035373, 61.30141335148966, 54.16821056796659, 50.81782002602854, 52.18771173108009, 52.810764543471805, 52.9720994733995, 54.70432404548892, 55.50862173880301, 55.0686377094638, 52.92396022427467, 51.20586402954594, 49.602630522943315, 55.51404637675132, 60.41518519001623, 63.3151307413655, 61.6673626438264, 62.994355386303326, 61.832251241130216, 55.4712180168398, 50.28725277992987, 64.17834243466778, 59.97551495029081, 61.161788740465724, 57.19295024871827, 59.557382445181574, 56.10259802110734, 53.878155216093994, 50.233994837730165, 48.52517504845896, 44.549727362971154, 51.89110602101972, 58.24409054171655, 62.17579203267252, 59.5810970952434, 57.318415103420136, 50.08963592590825, 47.242610992923865, 45.08345211705854, 44.99350824663716, 55.06189907750776, 60.10636914160944, 58.4917333049159, 59.89025438985517, 59.2575760810606, 56.854634054245494, 55.24063756389003, 54.467962018905155, 51.61828948605446, 53.499344471962225, 55.109916733157256, 50.0273016191298, 49.24812670676939, 46.74955337278305, 46.15765986904022, 51.073715456070445, 50.7388234907581, 51.2882730268663, 52.82174325758412, 52.715992235368304, 54.4086322476787, 57.042154727443574, 55.55274840324156, 61.75441964980095, 64.51855705630395, 64.99781577817856, 59.312869733379735, 49.99571084976197, 42.02865531367641, 21.200389208332187, 18.861195502742646, 5.282523122525984, 1.1251821392966856, 1.0576582916321293, 0.8835895708011043, 2.9296239201099645, 16.191079270455145, 56.59880530449652, 59.5588807905874, 58.06717595746441, 63.85934783566383, 60.83876978966498, 71.04822866378292, 58.21373139658282, 14.85834417804595, 18.485997261539584, 69.54369375782629, 74.74844363427933, 38.31769304890787, 14.696080626979953, 47.2265959555103, 55.360207096222915, 43.61155917567592, 41.31956138918477, 67.61912791959702, 46.17468295558807, 0.29004925381272073, 0.19492592422231553, 0.22240730603375744, 0.13924357421215505, 0.13694370165467262, 0.10497663755931201, 0.14898429023883036, 0.12229338093029878, 0.12235832986451926, 0.30504707968042744, 0.1166432909667492, 0.2413273794997123], [0.0225106452126056, 0.1205318843224837, 0.14712968330469825, 0.08514157165923426, 0.05748587420150157, 0.10284960209842652, 0.04652206816019551, 0.1238753065286625, 0.14603540331365603, 0.09317185849912706, 0.05453904805284354, 0.08316500352755671, 0.04682419791577324, 0.02269248001187319, 0.05071974734986021, 0.09744982370325635, 0.1340065358747398, 5.682609292768664, 54.55791765643705, 50.05454247997653, 42.87238459433279, 30.53770907463566, 42.964199435326364, 17.02057819212637, 30.503629561393495, 70.5690170103504, 16.18801001579531, 6.033837929848702, 35.585522959309245, 67.63482524502662, 55.8240391362098, 48.975345473135675, 63.302908635908565, 59.968180118068574, 43.93063614445348, 5.746767501677237, 0.12033444814263813, 0.19453384042266877, 0.2773154935529155, 0.5286913112767282, 15.8467657719889, 46.7064739811805, 62.25551420642484, 68.15652401216569, 62.84476011030136, 58.37180291452716, 58.34099269682362, 63.74525000972133, 61.31351386347125, 64.4726025673651, 63.74196306351693, 63.67421196353052, 58.87351720563827, 50.7138301480201, 49.57004347155171, 50.09233843895697, 46.91873696542556, 46.39541041466498, 46.94039629351708, 47.75618260906589, 46.18244924852925, 47.07202711412984, 46.30729044637373, 52.790458433089725, 58.48781093474358, 61.05623383675853, 60.97923771027596, 58.684709995023674, 57.05477691465809, 53.83597012489073, 46.881964745060095, 46.191658973693855, 46.64600672260408, 44.914080250647764, 47.369585960142075, 48.88932005051644, 47.71592340161724, 45.29044343579201, 43.82840741065241, 42.989263380727465, 42.45786459215226, 48.69441747665406, 50.464940071105964, 53.23017181888704, 53.14654688681326, 50.74900988609561, 50.87178399485927, 45.20498675684775, 54.45024859520697, 54.06895499075613, 52.463419052862356, 52.70476641193513, 50.89530644878265, 51.72449158084009, 49.45306270353256, 44.49527309786889, 40.44736746818789, 41.47751915839411, 41.73463052318942, 45.67620069749894, 49.95283934377855, 52.77720866664764, 51.73756091825424, 49.4288146111273, 45.44600855919623, 41.929972402511105, 43.585224382338986, 42.266264653974964, 46.93493243186705, 54.53010412954516, 55.51239505890877, 54.447424488682906, 57.23438616721862, 53.19007342861545, 57.033435298550515, 54.798268733486054, 54.955241987782145, 55.60446877633372, 55.876171358170055, 54.79736266597625, 50.39834214795021, 44.76064497424711, 44.953017619348344, 45.78082992184547, 47.32473365722164, 47.494988056921194, 48.53460442635321, 48.18166563587804, 51.26431126748362, 51.09174659175258, 50.718509535635675, 53.80808991770591, 58.69171142578126, 57.626803613478145, 59.79682745472078, 55.20786223873016, 49.289617538452156, 34.84419891911168, 18.744326522273404, 12.909788143250251, 2.9021342339054232, 0.30744119637435485, 0.25378107333615907, 1.7488779752485215, 20.137236656681186, 52.42557994781002, 52.714670396620235, 59.900252511424405, 55.82034426350748, 58.53853502581197, 58.75792495666012, 40.9788643160174, 8.903163498447789, 22.054528459425896, 62.33167094569053, 53.56001961615778, 18.948580026626587, 20.634365697060865, 42.560905256579005, 28.448727284708333, 37.50346783668765, 38.14139819914295, 59.47264748234903, 8.40238469262277, 0.3543701185093772, 0.14190557653144484, 0.063113747615247, 0.048759539025805654, 0.0216089635561671, 0.09920366709270786, 0.08941092603509465, 0.015675058126479628, 0.12419126417127349, 0.011875511000623867, 0.02240418197376834, 0.06354734571951051, 0.0736890628092712, 0.10484967380762102, 0.03943479342025615, 0.010098145839067237, 0.057744463349902825, 0.017601042430126862, 0.029352361959735715, 0.06348634596853968, 0.04876364142664018, 0.038474670746513916, 0.011881818777070412, 0.028517511898591637, 0.04165972342654582, 0.07212751514969334, 0.03547177845311742, 0.09009153386878391, 0.2664238376723182, 5.062528166078753, 62.429345807721546, 59.115868691475164, 43.04400790122248, 39.13025517617503, 44.78087655959591, 16.50915603483877, 42.526105988410215, 60.43950780745476, 24.342729391590243, 9.216770722020058, 38.33450040509624, 75.69727282370292, 62.63956523710682, 55.12630047336702, 70.9950021005446, 66.45718851397115, 51.46609367862825, 7.366174411389136, 0.17452036030590537, 0.07770779152070323, 0.21069766743288887, 1.1227056528291395, 20.57261778462318, 48.502205648729884, 66.67633133549845, 69.3400364537393, 64.51337560530632, 61.58429861068726, 62.55684637254285, 66.51358435230871, 65.05169737723567, 64.88301977034538, 67.61787276114187, 66.03942471165811, 60.17762684052991, 53.360017961071385, 50.90064871695734, 52.13562657756191, 47.94793944205008, 49.88943815231324, 48.95344295809346, 48.2004734008543, 48.77263346026021, 49.01244325022544, 47.493022949464866, 57.067179449142955, 60.08634936424994, 62.84277539099417, 63.52425190710253, 63.540149273410925, 59.81472130744689, 53.699608925850164, 50.18406306543658, 50.23113150750437, 49.2502369419221, 48.30405535236482, 49.95432984444403, 50.223455429077156, 52.202934449718846, 51.44872542350523, 48.61028655882805, 45.651772176065755, 48.67574307226366, 52.480465673631244, 57.38945707198113, 56.4520812034607, 58.857286437865234, 56.1417079740955, 57.2994779002282, 50.95011764957059, 59.493871427351436, 58.71399441073018, 55.604511922405614, 56.121186133353945, 55.14948560345558, 56.08304500579835, 53.29882506401309, 50.53166351010723, 44.6064801369944, 46.11052082430932, 44.87118913281349, 50.44760319494432, 55.44864085412795, 54.08995143828854, 56.08455119594451, 54.13221497689524, 46.43582259455035, 44.15196764853693, 44.503157061915246, 42.73259524376162, 49.467830427231334, 56.93378356195266, 57.776332209187174, 56.64402238784298, 59.755344467778365, 58.17407231177054, 58.413580079232496, 58.718348241621456, 56.59590275056901, 57.50376670591293, 57.893160004769605, 57.70213665500764, 52.05969733576621, 45.29667608199581, 46.46190635619625, 48.48812826218144, 49.54156314173053, 50.088714168917754, 51.17725818387924, 49.910269860298406, 54.493457425025206, 52.01381737186063, 52.46198738774946, 56.33673214143323, 60.87618920110888, 60.80430784533101, 64.70989027330953, 57.91003011888074, 53.55454398739723, 38.86269461724066, 23.818228090963057, 15.968604395466468, 5.69623266496966, 0.4831434005210477, 0.46743375639761653, 2.1746627794158075, 24.189054850609075, 56.17432248207831, 58.19792424478839, 63.0757563344894, 59.73850573262861, 61.50867531376501, 66.8547599546371, 43.0436078194649, 13.518645897988351, 29.30386870138107, 65.37766202803581, 54.0104724514869, 28.306015768358787, 17.069711762089884, 42.74240116919241, 41.69543427805747, 37.61663998326948, 41.5912639710211, 67.49904847914173, 12.19995975494385, 0.43226468226602005, 0.01913057144490942, 0.05935469206662909, 0.058678673099606275, 0.042219875425460844, 0.03081643067660832, 0.036222299470776514, 0.058587726971675316, 0.08669881390467768, 0.05798899861533315, 0.03620809237022073, 0.05841819554447167, 0.17014449672593226, 0.29771142008323825, 0.1960612512043407, 0.0726794431947412, 0.14207855918474738, 0.1438882120794827, 0.1268999442277897, 0.17559570260345939, 0.2409936103128618, 0.14767807968441518, 0.16326827537869254, 0.2566080450290634, 0.11336684016691101, 0.21847646292899886, 0.20396851964535254, 0.28725922287952516, 0.5899125842317459, 10.958991454493615, 87.8439824811874, 65.05403510985836, 58.107666584753225, 42.68094155096239, 63.746116853529415, 21.530323297746722, 43.141980863386586, 76.88751605249222, 23.82458821419747, 9.485603109482797, 45.31771959797029, 81.31981003669001, 66.8177798486525, 62.93974422639417, 77.09632735098563, 72.97635601412865, 57.866413362564586, 9.694625235372975, 0.4070221158044954, 0.6948651589693562, 0.6205466017127037, 2.2842780716957587, 25.40996120822045, 53.33092966387349, 69.310665745889, 71.8515379198136, 68.51458149571573, 64.77957117942073, 65.24807476228284, 69.29085777651879, 67.58552105196061, 68.940841151822, 71.62911599682224, 69.62920142758277, 63.7151615081295, 54.98375761893488, 56.22953768699401, 54.770721927765884, 50.26495018313008, 52.55998780650478, 52.909965207499845, 49.01099589563186, 51.97262856268114, 51.28094603938442, 50.44149214221586, 59.964218524194536, 63.89609652180826, 65.79902656616704, 65.64248869496008, 66.86560138579338, 62.493908020757864, 58.33819604689076, 51.76645309694352, 52.31226267353181, 52.389290178975756, 51.76378588522635, 52.532009540065644, 54.12539789753576, 55.37211148969589, 53.30684631101547, 50.22936251855666, 48.09067449262066, 52.43059665926042, 55.56887326701995, 58.46411981890279, 58.4499639849509, 62.374864086028076, 60.544686163625414, 58.43228586258427, 54.6722625917004, 58.69795191672541, 60.013977712200536, 58.19914802428215, 59.79889062143142, 57.386860462927054, 61.831482456576445, 57.67720214782223, 54.19824415637601, 47.086061354606386, 48.179512254653446, 48.34245143398162, 52.17056312868672, 56.6741697249874, 55.56923804744598, 57.71139344861431, 55.948699905026345, 50.95013726142145, 46.84241156424246, 46.662716019538145, 46.31371136634581, 50.33057143611293, 57.365554148151034, 57.245427639253684, 58.69948164109261, 61.04227019894508, 59.038813729440015, 63.352385413262155, 62.414962476299664, 58.14232856996598, 60.38712455380348, 60.26409941334879, 59.61481378924463, 54.63707500888456, 48.829472526427246, 48.7940299895502, 50.94853693439115, 51.28234240316576, 53.7820218455407, 54.21125073586741, 52.23622752774147, 57.3823340477482, 57.70910670680385, 56.41131208788965, 59.50844695491176, 65.12554776284003, 62.21889888086627, 66.15295379392563, 61.296588836177705, 54.29010214344148, 39.600849382338986, 24.862686626372803, 17.51659131819202, 7.103114772227503, 0.9883727481768978, 0.7237227717714926, 3.0598806854217284, 26.876162790483047, 61.456327361445275, 63.81499367375528, 67.02438677510908, 65.38986844401207, 68.87245855023785, 69.77600789839222, 49.4531136943448, 14.108908676332044, 28.740869337512603, 71.30719138729957, 59.68249036419777, 25.27716152129635, 25.73534142586493, 63.518187922816125, 39.2511583143665, 49.80800190279561, 48.9532115382533, 80.92001853450653, 21.020334766757106, 0.5594373614557329, 0.2282149266571768, 0.19621603160856232, 0.26682198888832526, 0.28595849751464786, 0.30783153349353426, 0.15754883147535786, 0.20737258537161737, 0.29590706851693893, 0.11388443981207187, 0.1719819432905605, 0.16149203923921432], [0.043804267826940746, 0.021161842084820234, 0.05823124710830951, 0.16288729985394787, 0.06386873492550466, 0.05584852214181616, 0.08160265147565834, 0.06935852099089854, 0.07291880736668264, 0.025003518300851988, 0.12589327405176817, 0.07244531906420186, 0.0380795494082474, 0.0407985027038282, 0.006505697655806979, 0.1292881237403039, 0.052726223554101684, 0.288093063619829, 31.79816665187959, 54.114360347870864, 42.00080648545296, 30.01626918392797, 43.081203737566554, 22.54625443489321, 19.571222951335294, 86.03589534759523, 43.6026357835339, 3.754834955738437, 30.70667301454852, 65.95456031060988, 68.07520543375324, 59.159222648989775, 62.05351998729091, 60.53041265856836, 48.313814209353545, 7.157831836131312, 0.0771326739941874, 0.26805900638141944, 0.0990911364375103, 2.6163216608185924, 14.341518955845988, 44.28976443506057, 66.73180149447533, 64.95583072785409, 61.72434683768981, 54.869914747053585, 59.9324865495005, 64.72308904893937, 65.70237936512117, 65.88110216202276, 64.31040079362931, 60.72985341472011, 58.50578323487313, 50.59450772500808, 49.59835513945549, 48.11261230899442, 48.17430726943478, 46.426455974578865, 45.37739061540174, 45.275099123677904, 46.70985898663921, 46.8205012044599, 48.399482696287095, 53.47259390738703, 57.27969738744921, 60.916024792578916, 60.68364004934988, 61.28391565815095, 60.51575868360458, 49.36227552352413, 46.720888691563765, 47.70004172478953, 47.92773531329247, 47.47362682896276, 47.08918748363372, 45.92219214285574, 48.396054544756495, 44.81943738075995, 42.01797469969719, 42.757337554808586, 45.630003021609404, 49.693358867399155, 51.730806596817516, 54.630038276795425, 52.39389504155805, 53.623907181524466, 47.674746359548266, 52.288383283922755, 55.6216722919095, 52.30652032359954, 55.78928693648308, 52.525961245259936, 51.565455159833355, 50.51764495911137, 48.42259722371256, 44.207963405116914, 43.01896356767224, 39.25400987748177, 42.228625589801425, 44.20408810338667, 47.304298108623875, 48.79238259407782, 47.901004360568145, 46.99132827020461, 41.70914688417989, 42.17354766784176, 41.338486825266195, 42.774007628040934, 44.71049354922387, 54.61196791741156, 56.452022367908114, 56.06043646412512, 54.40733786552183, 57.4970280739569, 58.07941767477221, 58.104010935752626, 55.20989010410925, 56.89410878765968, 55.474595177558164, 55.88700886695616, 53.109884492812625, 47.83863083008797, 43.38576793670655, 46.67536174097369, 47.143237744608236, 47.22114386097078, 45.1161019263729, 46.93380278925742, 47.60794055077338, 44.62375425523327, 52.20656656449842, 57.79163337522938, 58.26040367926321, 60.046439247746626, 58.72597725160661, 57.45309752802695, 54.85389578726984, 48.700222584509085, 36.40436480122228, 20.390794354100382, 9.884870975248276, 0.9179337214558356, 0.1836174092586002, 3.6709381543820907, 21.431328558152725, 53.191128546191806, 54.11722367809665, 54.285438445306596, 54.844925326685754, 56.70210876772481, 52.72881838583177, 24.25461530685425, 8.233413888562112, 33.83043881385557, 56.3009326688705, 29.99202697507797, 13.533900976181032, 30.696721961421353, 33.428031090767156, 26.39279930822311, 43.17964346178117, 42.596171286798295, 51.0687340459516, 1.2830120637532205, 0.11176745542475294, 0.04775614770610006, 0.05471078964370874, 0.08407889279506861, 0.05870723285742345, 0.045954216977641474, 0.05131883193708716, 0.011873756659277266, 0.09112518566149859, 0.09485783415936655, 0.0692319096396527, 0.028728120960295204, 0.020209211750977465, 0.01964781485918549, 0.08399763384894018, 0.09507967790047969, 0.05186568464963667, 0.028873037982491717, 0.028729825505926728, 0.0418750056245875, 0.032646381070897464, 0.03889161792974319, 0.10138090429527145, 0.022118385212736267, 0.06710926386257333, 0.04362660054598124, 0.06595604106663697, 0.039325660365002776, 0.09999588627608554, 0.3824176392968624, 34.16671145346857, 66.71939111525013, 43.344920373732045, 34.70077745376095, 52.89111037408152, 19.94497776031494, 29.121274525119414, 85.89814955188383, 41.27147705324235, 7.140876410468933, 36.77130645321262, 73.03945126072054, 75.43939267435383, 64.95388130987844, 69.2043459799982, 67.52245718433012, 53.225935659100934, 9.192167655114206, 0.11970555124383782, 0.313472667889249, 0.05296154278180292, 3.507295890200523, 16.60819980405992, 47.90377747627997, 70.67721166918355, 68.19119776448896, 64.35123266712313, 56.71590374362085, 63.321241794093964, 68.34140100786763, 67.54671312147572, 68.25965096873622, 66.51962480237408, 62.40204218895205, 59.923908325933645, 53.37366780927105, 51.55604931616014, 49.87791815111714, 51.29807502992692, 49.6862829116083, 46.58261729824928, 47.94391509025328, 47.79196639214793, 48.924644916288315, 50.55737072421659, 55.65756197898619, 59.365908022849794, 63.77786844007431, 64.26039057393228, 64.66095086066954, 61.7513523563262, 52.815600825894265, 47.068057675515455, 48.82698966610817, 49.480256495937226, 49.937926492383404, 49.15881041557559, 48.482774226896225, 49.87018323713734, 47.34575363897508, 47.76421170080862, 46.46951967670072, 48.767291192085516, 53.547303292059134, 55.73535434661373, 59.05841381319108, 56.79614759260609, 58.246997018014234, 53.271588125536525, 56.763034943611395, 61.939539832453576, 56.90258110723188, 60.55939897414177, 58.55619353632773, 57.774210206923954, 54.04591891073412, 55.18655592395414, 48.04165271020705, 46.4305313171879, 44.68162098238545, 45.803916992679724, 48.159657216841175, 50.91334542920513, 52.619007710487615, 52.59641485829508, 49.77503438149729, 44.45495505486765, 45.19197625498618, 44.79823696997858, 45.722421907609515, 45.588818134800086, 56.42486779920517, 59.73524232064525, 57.5620452819332, 56.413496848075624, 60.016221307939105, 60.645518533645145, 61.43380118954567, 56.121468544006355, 57.22495678932437, 55.27578984537433, 56.82041921923238, 55.72014731745566, 50.07711572031821, 45.89998760531026, 49.05777015993672, 48.38562104009813, 50.072365730039536, 48.41061046046596, 49.565705330141135, 49.013247336110766, 49.929065858164144, 52.95315050309705, 60.45320864646666, 60.63339056507234, 61.02512944129206, 60.04349354774722, 60.345402302280554, 57.6065484939083, 52.793576717376716, 39.3766898493613, 23.86512983229853, 13.126966837913761, 2.022968790223522, 0.631997348560441, 4.737146967841733, 25.448978985509566, 57.14391669919414, 58.92557490256525, 60.98693732292422, 61.81528699013495, 63.32650169249504, 56.738578965587, 25.750028740975168, 15.107609821904092, 35.22714776377524, 61.250622580128336, 33.509169240151685, 17.975214450590073, 24.413218305956935, 43.786410593217425, 31.184482420644454, 44.58975907294981, 48.322925875263834, 57.09374173994988, 2.660234065786485, 0.24887619540095332, 0.10198722458294324, 0.08144044767945044, 0.0994533581298686, 0.024525377929451007, 0.07214775519265283, 0.04943578015832652, 0.046892536789058685, 0.047979500640424035, 0.10467378002020622, 0.03687472676017112, 0.007580026323276182, 0.1322359074988673, 0.14628890180780044, 0.1368950703932393, 0.17145496672920643, 0.1660933318517862, 0.1955645657595127, 0.16142981757800426, 0.1887107907884544, 0.2255111112589798, 0.13889544853760352, 0.230837092404404, 0.1721230107209375, 0.16468345427945738, 0.24317348285788493, 0.1680848540197457, 0.27851377764055807, 0.2213127196075455, 0.7097197263952225, 56.90576214944163, 77.51435787447038, 62.254812102163996, 44.1330853585274, 63.64941081693096, 31.58985741676823, 26.86344450519931, 97.95977515559044, 51.888285836865826, 7.184314208645975, 40.48863080240066, 80.75011714812248, 82.77737848220333, 70.27276039123535, 72.79930022455031, 72.89571992812618, 59.25889007506832, 11.076560578038617, 0.31585020644049494, 0.7230634458603398, 0.6482155524915265, 5.708932809291348, 20.345622378010905, 51.165141982416955, 73.29791976559547, 70.14632671110093, 67.11273424087032, 58.62955754803073, 65.76182288508262, 72.94103899309712, 71.05947017669678, 70.90421492053618, 68.1643138393279, 65.34712245387416, 63.618059312143636, 55.65299634010562, 53.58088270310433, 52.518508741932536, 53.756730402669604, 51.97036143272154, 48.77040163163216, 50.00898022805491, 50.420174060329316, 50.85230550458355, 54.223037458235225, 58.292398452758796, 62.351726024381584, 65.77447252888834, 66.11784073614305, 66.5796527554912, 64.5416441271382, 54.16721036357265, 49.64936556354646, 52.62507561714419, 52.052319357472086, 53.341904455615634, 52.501215011842795, 52.24295047021682, 53.84097114686043, 50.631578045506636, 48.20311315598027, 48.521601769231985, 53.923941043115434, 55.75024366378785, 60.40152749707622, 62.698945999145515, 61.18990821223105, 63.105032905455566, 56.650482531516786, 61.573567005895804, 58.981048983912316, 59.997021305945616, 63.64111500401651, 61.72236211838261, 59.14652201437182, 59.34115394469231, 54.56550744272048, 50.8297989445348, 48.87628209206366, 45.45850130819505, 47.07327835021481, 49.37602735334828, 53.67998923024824, 56.258280815616736, 54.336193915336366, 51.20148666443364, 46.42538908989199, 46.668528972133515, 46.35941090122346, 47.11895042850126, 47.41086106146536, 59.33713743763586, 61.726994437556115, 57.688671158206084, 58.77544226184968, 63.158592870158536, 62.349870743290076, 64.6754087171247, 59.74121609041768, 60.290583256752264, 56.8590114193578, 58.61456232686197, 58.15158536357265, 52.30138986341415, 48.033090176120886, 49.84711970052412, 51.158721062444876, 52.32477895675167, 50.655167179722945, 53.720950541957734, 52.51328414486301, 50.82373888261857, 57.44278953921411, 62.67274456639444, 63.23740113166071, 64.66992916599398, 63.63641992692025, 64.6194011934342, 59.141897539938654, 54.92025836821526, 41.58929886356477, 25.44054981200926, 15.913451948473531, 2.8407067300811892, 1.945137811764594, 6.2766605904025425, 29.24559404773097, 64.56569610103485, 61.70143627351331, 64.81100897635183, 65.43327339233892, 68.53281267227666, 63.12153823914067, 29.546400616245887, 13.222493221682887, 41.99824517773044, 63.6870930271764, 37.49041418875418, 16.2935511912069, 41.052326386974705, 51.756466742484804, 33.71569379683464, 55.45273973095802, 52.64822936827137, 76.45156029731997, 6.624366448771569, 0.34953239584161394, 0.18810630145092166, 0.13215375222986744, 0.21953225466272525, 0.09528858241655173, 0.16581180986137162, 0.11075545327677844, 0.11033279490807366, 0.14770230338458093, 0.217186953091333, 0.09472355426799867, 0.21443940939441805], [0.034900027883028796, 0.05182036288803624, 0.028535216190521757, 0.06587937864805422, 0.04601661483907411, 0.07654277863161218, 0.11074708759664528, 0.021012571767993996, 0.1018265912669801, 0.028266683220863346, 0.028145955424875985, 0.04394188020077925, 0.04006918316947357, 0.05118229208634265, 0.12418554915535836, 0.15294855009884606, 0.10478477849955521, 0.20443865248272497, 9.536844953413933, 45.454861348675145, 41.63397858219762, 29.307663594522786, 32.223520240476056, 36.33449169897264, 13.987460328686623, 37.983103106098795, 62.02320398822908, 9.52602215351597, 20.802315704284176, 62.40569783795265, 60.95023962759203, 58.30924503264889, 63.04854685260404, 60.935299319605676, 51.323386084648874, 10.283087645807575, 0.14951460694353427, 0.36362988453718925, 0.2750289356035571, 3.7260567709322903, 19.371560581268806, 52.84994117675289, 68.30075740814209, 66.1654269310736, 58.78364786025017, 54.632446612081225, 62.379221839289514, 65.66711725727205, 64.29758641027635, 64.75598204520442, 67.85739621808453, 60.46806266230922, 52.07707735799974, 51.04655304262715, 48.93252103559433, 47.15963325192852, 48.42058504781416, 52.06340005320888, 53.355252281312026, 54.60970863219231, 51.97292274044406, 49.80134564061319, 49.8227813936049, 56.51573342661704, 60.42029996072093, 63.46348654839301, 62.43681400052963, 62.57852531248524, 60.44793698095507, 52.82626182802262, 45.49345354880057, 46.631890112353915, 46.11275657530754, 45.84651785512125, 46.70235941486974, 45.205049514770515, 44.001368245770855, 45.1702110229, 43.79408274927447, 42.6224393998423, 49.14714528668312, 51.26648426055909, 55.73871974022158, 53.02847962225638, 58.235049478469364, 49.26016053845806, 49.229079677212624, 62.24720662639987, 53.10010994634321, 57.08362986964565, 53.63572136048348, 54.404851082832586, 52.38410088323778, 52.09278645053987, 48.731668226180545, 48.535522260973536, 41.70056866061303, 43.74262517498386, 43.042552701888546, 43.22013016669981, 45.498572241875436, 46.971410474469586, 47.241061656705796, 44.82525033335532, 41.13291932690529, 42.69799993884179, 43.696129398961226, 42.24316189366002, 43.18340109240624, 50.04153590048514, 57.97077978810957, 58.31204168258175, 56.73168343882407, 55.19989198254001, 56.41486183289559, 56.56634769132061, 55.96392654603528, 51.79257608229115, 50.754897363724254, 57.45398790605607, 55.29187940782117, 48.84665643015216, 44.95299408512731, 47.482667892209946, 51.0653764970841, 50.50548561157719, 50.01917839050294, 44.970076007227746, 48.88422096929243, 47.44515042151175, 48.492489937813055, 51.601250710025916, 56.28555305542485, 57.34700525960615, 60.3344432000191, 57.2544216340588, 59.708703564059356, 57.209200628342174, 48.55529100664201, 31.467161755408014, 14.851206444924879, 2.3992013114113964, 0.1571910377712019, 5.212440173472128, 24.560211089349565, 50.0629912653277, 55.703308582305915, 55.26852953818537, 55.33445673604166, 61.32555161753009, 42.59746174658499, 10.071328686129663, 26.31374001502991, 57.915854838586625, 58.53938618013936, 29.102860958345477, 16.184865255509656, 34.57362205751481, 30.136270176979806, 50.40078186219739, 45.91643410344278, 47.605732256366366, 30.210169592211326, 0.4360797388419029, 0.08458153840394751, 0.04930135854069264, 0.02599354713193832, 0.016908585131468794, 0.047425174740173166, 0.03477828885098139, 0.06991645516527277, 0.03524336167761395, 0.10716995494740625, 0.03720275028758953, 0.04069842480783982, 0.06777629661824434, 0.0985052170712621, 0.005744570150836221, 0.05891953114300005, 0.03961465937355834, 0.027580343134280656, 0.08828865319129922, 0.07511220136356932, 0.014153524196796842, 0.025762125376551866, 0.012525051096153837, 0.02731819550747112, 0.051556353667570706, 0.07919466859030147, 0.026795212179422382, 0.07420251025788246, 0.17267569719303041, 0.17132848561290773, 0.30715918408766874, 10.386265593190348, 61.164283367895315, 46.81926958022579, 28.042093207759244, 47.470900781693004, 33.48262656119562, 19.3858007461794, 48.77985454374745, 52.190206358509684, 14.183945578913535, 25.389804147904922, 70.85826827633765, 68.59780634603193, 65.2575865099507, 70.7844884933964, 70.46003787748276, 58.362024445687574, 12.358034214665814, 0.09867492086824872, 0.3218455798923969, 0.19832583775203075, 4.970240189183143, 21.781437358548565, 57.30478094470117, 70.30319798377253, 67.56951778165757, 62.26938370735415, 57.01936183437225, 64.40003479680708, 69.55374287020776, 66.64369721566477, 66.1631441116333, 70.5008932851976, 61.014907744623, 55.337563253218136, 51.16851914313532, 52.57140190370622, 48.431446090821304, 50.03791947518626, 54.95890548152309, 54.20984260497555, 52.63258695602418, 51.29734546907487, 49.96732857919509, 52.548852197585575, 57.88793148532991, 62.873895475941325, 64.4465894083823, 64.75653902176889, 65.62968607871764, 62.239730588851444, 55.1174476838881, 47.7956259635187, 51.08167394515007, 49.034945887904016, 48.52123698880596, 49.09252235966344, 48.229220451847205, 48.6591318345839, 47.215299529414025, 46.659703639245805, 48.00044036680653, 50.965909111884336, 55.381231000346524, 60.63908976893271, 58.16623541616625, 61.26507259184315, 55.72931389654837, 53.10691525859218, 64.51648996722314, 59.114566464577955, 60.41767981744582, 57.57809169830815, 57.99616144549463, 56.706839146152625, 57.31737567532448, 53.30725815988357, 53.28496733019429, 45.84796520971483, 48.51845210598361, 47.51415275758313, 45.372691615935295, 49.47113698528659, 51.695854356212, 52.47129517216837, 49.924657114090465, 45.23136469625658, 45.177432106387236, 44.56337328880064, 43.88820394392937, 43.940449914624615, 53.58241242747153, 61.12174918574672, 60.47864129466396, 56.94215782227055, 58.01192545121717, 55.74590944474744, 57.714786298813365, 58.58585057720062, 54.65012473444785, 51.42494409315048, 57.56413590523505, 58.119437617640344, 50.95883707846365, 47.81564181850803, 48.930720667685236, 53.42402711991341, 52.641918274664114, 54.34143420188658, 48.25475508166898, 50.59773583565989, 48.53213333314466, 50.72399300913657, 54.14802605105985, 58.35000238110943, 60.54718863579535, 62.85604084691694, 61.883269509961536, 61.46689030431933, 60.27312870948546, 52.88579948486821, 32.58322904186864, 16.161553628983036, 3.358048479403219, 0.3827043706851621, 5.734359573933387, 28.174037817985784, 57.95951081860451, 60.19650913053944, 61.86036679052538, 57.9283554323258, 68.22297680762507, 44.7657322883606, 14.267465587585205, 31.54853132463271, 54.71890741778959, 56.38932328070364, 31.131451975914743, 18.8341684110703, 29.994233308299897, 38.680830001831055, 44.174544811248786, 48.78759338009743, 56.15358491097727, 35.15140287337765, 0.7139136594149375, 0.08356764401880004, 0.08077336129762473, 0.10183614438339587, 0.12110195332957853, 0.026987249354621577, 0.05630315319004078, 0.023730818347464648, 0.0314786255870375, 0.09206439413490797, 0.05095102163332124, 0.07178276792288789, 0.04765427716436887, 0.22114349078507195, 0.1579787293749471, 0.10441534791982944, 0.13555323675034509, 0.0909154307878306, 0.28910083696246147, 0.2077910838828933, 0.14565098039325208, 0.12289512001218335, 0.136069166323831, 0.08940457516620237, 0.2072306139574897, 0.1917503212368296, 0.14527273214151784, 0.2773173321639338, 0.3111381528358306, 0.3756950339001994, 0.5150563558263164, 20.277086803990027, 78.79002248087238, 59.561532312823886, 44.11139857384467, 48.894744688464755, 50.6034585737413, 18.735412936056814, 50.426791098810014, 69.58028162679365, 14.4376709576576, 28.782817125320438, 75.80757771768879, 74.15886432893815, 70.4422773853425, 73.82157187308036, 74.5210167669481, 63.108978809848914, 14.992530422825968, 0.3260019439603052, 0.8561479336311741, 0.8114454775087295, 6.857226289087727, 24.99789857095288, 61.08449451385006, 75.12402626775926, 71.78472426629835, 65.32985225800546, 58.940401461816606, 66.52757152434319, 71.88785906760924, 69.15164501436296, 70.24075385062926, 73.40474159486833, 67.36571927224436, 55.07494880307106, 54.607112023138235, 55.03115161772698, 50.73654851605816, 53.31848790568691, 59.07321291585123, 58.675421822455625, 55.65567924130348, 55.402902095548576, 50.904563242389315, 53.64261688724641, 60.85903667634534, 67.12588202568793, 67.89609432220459, 65.03945958229804, 68.72933126265004, 65.89567768958308, 57.26758118598693, 49.68353725248768, 53.53540282095633, 51.20494619492562, 52.3415078655366, 52.385885561666186, 50.18437685505037, 50.06541921246437, 49.865986301052956, 50.45006252104237, 49.91074838945943, 53.568048707900516, 57.558723034397254, 63.77154950172671, 61.321256622191406, 65.32587105228056, 57.950587426462484, 59.496519027217744, 63.79173794100362, 60.207664351309504, 61.8209195137024, 60.610401553492395, 62.21474901322396, 59.61428034690119, 60.339000994159335, 54.70392788610151, 56.86261215517598, 49.70685966553227, 52.005274449625325, 49.95082324550998, 48.354038115470644, 50.82526076224543, 54.316087845833074, 55.47907844666512, 51.50725503121653, 46.40498884262578, 48.191761816701586, 49.18533740505096, 46.1544592149796, 47.01730612785586, 55.97170068371681, 64.14183301310386, 62.25858934463994, 60.989977159807765, 59.73716428202968, 57.44499391125095, 60.671013939765196, 60.207664351309504, 56.6811554662643, 52.158509685147195, 60.86797575796805, 62.12549940232308, 53.02152525994086, 49.40150706998764, 52.96967152626284, 55.040498625847604, 55.32487438571069, 56.78307825519193, 49.53366348820348, 54.261264877934615, 51.157363922365256, 54.82857688780754, 56.22624681841943, 62.736510538285785, 64.85182908273512, 67.15915941422986, 65.12421807935162, 65.21407957999938, 62.7310819779673, 55.274260121007124, 34.74126023630942, 17.759291894974247, 3.558248949627723, 0.9085634242623084, 8.4945103814525, 33.454471788098736, 62.018963906072806, 65.7418344866845, 66.26180741094774, 65.24959664190969, 72.41558259533298, 50.29737249497445, 14.303930882484684, 33.340585770145545, 73.70549325020083, 68.85317617847075, 35.10384805740849, 20.576544077165668, 48.60253203299738, 44.4874087456734, 60.24901397766606, 59.75764689906951, 63.79415412102977, 53.15276776590655, 0.9858942392372316, 0.12806131053836117, 0.16593040027205022, 0.20839163552849524, 0.1321173936969811, 0.34093036226207213, 0.16589243295452288, 0.17128843453622636, 0.18320286376101358, 0.20246301897831503, 0.1185064857465125, 0.14384321207481046, 0.1954687281601852], [0.020293939160183072, 0.02245042878653734, 0.061120827336825674, 0.042656399985595096, 0.10155181085029918, 0.03011361778443379, 0.02683057671322698, 0.03208822856146482, 0.055369184758033485, 0.06890251481484982, 0.13024835366635554, 0.01970902719955531, 0.06775491510427768, 0.011512251259128173, 0.039423229323039134, 0.049931098136209676, 0.02792057044233286, 0.10367264865987724, 1.1341354395112684, 38.079679704481556, 50.89933864531979, 36.13487835853331, 33.46434831619263, 37.189305597735995, 19.465107148693455, 22.340994842590828, 90.45509646015783, 43.727473059008204, 9.812094338478582, 41.07577039349464, 69.78166395618071, 63.606131384449625, 61.742181854863325, 62.33686808616885, 55.45540302030502, 11.32357870378802, 0.06495112523196206, 0.14734509190724743, 0.9208325981613129, 4.074619912332104, 24.90853128894683, 62.137576380083644, 69.05360929427609, 66.09093327676096, 59.52455220683929, 53.667425878586315, 59.17664973966537, 69.3142194132651, 63.418971569307395, 64.8413485096347, 64.138922614436, 61.915185836053666, 55.97349712925573, 49.24276874911401, 48.37467762731737, 53.83576616164177, 56.029386981841064, 62.32710138443978, 63.72711689241471, 62.55561867067891, 61.95707282712383, 56.988312352088194, 59.44191963441911, 56.87555205437445, 62.249018761419485, 62.568319305296875, 61.72887325286866, 64.41304922103882, 60.51078511822609, 54.486381469234345, 44.68499814310382, 48.37190843397572, 46.09284270194269, 44.13480727903305, 44.09070022644536, 45.151262052597545, 43.520113037478545, 42.77505097850677, 44.52791898481308, 41.99670760862289, 50.09419764241865, 54.3505694020179, 54.09269317503899, 55.10217789680728, 54.18912464572538, 45.20439840132191, 64.22545402280747, 56.50786515205138, 54.22882687660956, 56.08869321884648, 54.57240296948341, 54.288023287250155, 50.21278658220845, 50.244051794851984, 49.35479556360553, 47.225352564165675, 42.52216792875721, 40.923500061035156, 41.34594717333394, 42.86937221404045, 44.067189539632494, 44.09109246346259, 44.88176776516823, 44.01922287479524, 40.383432834379136, 42.47103983356107, 43.67638418751378, 43.0324016078826, 43.30883849051691, 45.51509326504123, 53.75076055526734, 56.05401162178286, 57.16572115498205, 56.401015866187315, 56.30321548831079, 55.75664889427924, 57.769879910253714, 55.68196696619834, 54.9516490967043, 57.00681809456118, 52.85095707062752, 51.60151350882746, 47.644226397237475, 51.04856521852555, 56.26166582107545, 57.35881943856516, 54.99937257459087, 50.9840500739313, 46.625402512088904, 46.86582811417119, 49.22084269985076, 53.18987731010684, 54.379802826912176, 55.77299341078728, 58.030988170254616, 60.48586237815119, 60.41984496578094, 61.34726193643386, 58.19687304958221, 43.703103373127604, 22.039635219881614, 4.233166527363562, 0.22671906337622674, 2.528136483123226, 25.776122308546498, 56.09439634507703, 56.461224248332364, 57.31423777918662, 58.714570999145515, 56.96475459683327, 43.25945977241763, 21.331394410902455, 58.285357798299486, 74.78216817302089, 51.29019106588056, 19.57146025473072, 24.804925803215276, 43.04603576660157, 26.546140447739635, 42.21304985784715, 41.33754545642484, 52.73980494468443, 7.951360171841038, 0.32688542719810243, 0.08784430687345805, 0.015146093566962069, 0.04715918135198374, 0.04456294768099343, 0.10046252575252326, 0.05646335749676632, 0.04934396835104112, 0.04661912000888298, 0.060580229732177915, 0.023102473031969804, 0.04083733187027035, 0.020501300009087692, 0.035932339021875974, 0.07631177247892465, 0.10527483728383819, 0.13300404853878484, 0.06592691440375582, 0.06843922314264121, 0.04394502499170842, 0.06753939158853985, 0.018422907300954385, 0.03894488785355803, 0.03518932566587483, 0.051199253272986224, 0.06494174831576886, 0.025804267873266534, 0.07423315377485368, 0.052446861931633566, 0.13166311887964127, 0.07182447374948571, 1.431934898418765, 50.31001821640999, 61.20634294325306, 35.392032438708895, 39.49751061777915, 41.0148520623484, 18.40536117553711, 32.82488822937012, 79.83075280343333, 44.62364442886845, 14.564818509163397, 46.22246134665705, 73.00643274860998, 70.41286745379048, 70.11257079339796, 68.33045759508687, 58.5932638568263, 14.63384928241853, 0.5955750771587895, 0.1072146178733918, 1.3356655932241872, 5.433507407865217, 27.465512637169134, 65.16651691928988, 72.59634894709434, 69.99040465201102, 61.67560354355843, 57.14987870185607, 64.11751824040567, 70.35078417870307, 65.63574221826369, 66.77619488008561, 64.8173318370696, 63.00844846233245, 57.89197544897757, 49.093047957266535, 49.28440470849314, 55.721371096949426, 61.27043839423888, 64.8608583788718, 64.2180250537011, 65.20361861874981, 62.50070941063666, 59.61089141907231, 61.34699129289197, 58.576672230997396, 62.433503520104196, 63.047793757530954, 64.81377424732332, 63.686979278441406, 62.15929846609793, 57.022950803079915, 48.532549104382916, 49.777560387888265, 48.584124349778705, 47.1033590070663, 49.659497045701556, 46.85801475278793, 48.22680819419123, 46.10297026172761, 47.69968086673368, 45.4418194678522, 55.39726957198113, 57.86230664099417, 59.32918679329657, 60.2762116924409, 61.1984315226155, 52.99739876101094, 64.95825867499074, 63.94900537306263, 57.55085475983159, 60.60618500555716, 58.993726084309245, 58.51082740291473, 55.0961531362226, 55.60906971654585, 54.2783546447754, 51.1424667604508, 45.23306308254119, 47.74840454901419, 46.99076737126997, 48.13164757144067, 48.00994426973405, 47.08334315207697, 48.568940854841664, 47.75686902384604, 43.82857607256982, 46.284866256098596, 44.353879497897246, 44.68044427133376, 44.951374146246145, 47.41538747664421, 56.124692732288, 58.00960340807515, 59.63292337233021, 57.86633883753131, 57.34875071433283, 56.29785360828523, 60.650244989702784, 54.721496182103316, 55.87615959105953, 58.047069887961115, 53.22175833486742, 51.73160283796249, 48.492007486281864, 52.72602173589891, 58.36782563117243, 57.89939657334359, 56.28976175861975, 53.457037787283625, 49.479095474366225, 50.03726443936748, 51.01597816713395, 55.232471189191266, 56.49456047242688, 59.518033227612904, 59.296803705153934, 63.135058649124645, 61.9589045739943, 62.95798324769544, 61.81813463088005, 46.1478147199077, 24.259145644403276, 5.878934706411054, 0.6003691328148688, 3.5901770428303754, 29.55531616364756, 61.395028560392326, 59.268029197569824, 63.27789175894953, 62.75658915119787, 62.602655733785326, 47.908421562563994, 24.700427978269516, 49.98116277879285, 77.54681941001647, 50.686365712073545, 26.803304764532275, 22.14675122691739, 41.65785012706634, 36.66796768865278, 36.61976568160519, 49.74329848443308, 59.97198089476555, 10.783863509854964, 0.546871435738379, 0.20526500088312935, 0.08261868324611457, 0.06779614595636245, 0.08063984749418113, 0.013586041694056365, 0.048466548699164586, 0.043459279282439145, 0.03532075954060401, 0.037923776920163826, 0.026073237513041785, 0.039411205573067556, 0.1431562457113497, 0.1447257300418231, 0.16594599782218858, 0.19721361598180187, 0.22140235189468632, 0.16358333669843214, 0.25026757961079, 0.10177476541890253, 0.15111801364729482, 0.14072799213951634, 0.11971202468679798, 0.3145933625919204, 0.06212659735953616, 0.16373537450788483, 0.10876408432640376, 0.15217389731157213, 0.26152194748001717, 0.25706316254311995, 0.18381360437600844, 3.6226260758215383, 73.4964858331988, 68.437695195598, 57.55734628246677, 45.173423444071126, 55.315515610479544, 26.85213435080744, 31.793095027246785, 101.56209561132617, 52.215285993391475, 15.575148501703817, 51.93948453472507, 82.44989979651668, 75.7743787765503, 75.42651161070793, 72.09511710751441, 65.20634466601958, 18.62503940059293, 0.8604238074152701, 0.26058535902730884, 2.174739020486032, 7.617159033975295, 32.62554945484285, 68.76793522988596, 76.01424740206811, 74.74445850618424, 65.26744342619374, 59.42720682390275, 65.78542378640944, 75.42029857635498, 68.94014296993133, 69.49286768513342, 68.96324573024627, 67.0293289615262, 61.14252990291965, 51.51437021070912, 50.195700737737845, 59.25234363925073, 64.77919855425435, 68.64902465574204, 66.96884601346909, 67.56421473718459, 65.80073671956217, 62.101525875829886, 65.59779720921671, 60.451800515574796, 65.01720013157015, 65.5238526867282, 64.90136077327114, 67.16459581928869, 62.91187186394969, 60.33652990095077, 49.8163487065223, 50.90594783906014, 50.35687485048848, 48.45176004594373, 50.22640897381691, 49.002711849827925, 50.60347426322199, 49.28605602633569, 49.373752378648334, 48.07983306146438, 55.98126342219692, 62.700318828705825, 63.21747156881518, 63.811157595726755, 63.12175004712997, 56.821662610577, 67.04432810506513, 62.62434251846806, 60.38444949734596, 59.48009998567643, 60.383445370581846, 58.366801892557454, 55.98535837665681, 57.84600919292819, 57.7005127937563, 54.041639604876124, 47.68743914942588, 47.70098701600106, 47.72707077764696, 51.84755986736667, 50.11468025945848, 49.109274802669404, 49.3704418982229, 50.25550119338497, 44.84591730179326, 48.46520200852425, 46.167791351195305, 46.79294655399938, 47.39612863909814, 48.605160021012836, 57.47484314826227, 59.24342024710871, 60.53378197454638, 60.52618826589277, 60.06603933149769, 59.54488969618275, 61.32626548890145, 56.52937150770619, 57.55496540377217, 61.9236110871838, 56.932881416813025, 53.80914503528226, 53.735941840756325, 55.58788499524517, 61.89520528239589, 61.485886343063854, 60.97422492119574, 54.68515150008663, 51.72350706592683, 51.156936384016475, 53.72579859149072, 57.88109479411956, 62.026487012063306, 62.28603416873563, 63.39863800233411, 66.36312223249867, 64.43295524966332, 64.91662663798179, 63.65165049029935, 46.18860736969979, 25.93714737123059, 6.663751948264338, 1.324843896492835, 5.857798524441258, 36.163778381962935, 66.40127904953496, 65.80995036709693, 67.28104314496441, 69.62001523663922, 67.281921755883, 51.63397504437355, 27.859775558594738, 66.11841340218821, 88.33422383954449, 62.6183726710658, 24.437780187975978, 34.53586139986592, 62.81220051550097, 38.26054019312705, 54.23449077913838, 56.12249228262133, 72.25527532639043, 18.214192698078772, 0.6726888747465226, 0.23489008056780986, 0.2455717517483619, 0.20723127279310458, 0.1806870310176765, 0.14538902428842362, 0.11673326799345594, 0.16800127382720673, 0.13540006513076444, 0.17194066647320025, 0.13235425276141013, 0.13647894675452865, 0.17993237312522628], [0.029615817681675958, 0.03414070068468009, 0.043971608242680954, 0.03892149535879012, 0.02339763904831583, 0.058142423043928804, 0.06214979067144375, 0.039725332265539516, 0.028937331911536957, 0.04858664447261442, 0.011864578925944384, 0.008277132818024726, 0.07002751493165571, 0.034701749006466526, 0.0598844533575879, 0.003311200787486028, 0.0584329312456952, 0.05250693854665565, 0.09652450440391418, 20.89321271065743, 52.82202566823652, 38.13613830074188, 52.25466266755135, 57.64122616860175, 30.828250800409627, 23.141934987037416, 73.2186565091533, 88.71332091669883, 26.50414755267482, 14.559353666920817, 51.52090487941619, 71.71433341118598, 62.53219427600984, 65.53512165623327, 57.125159925030125, 23.834486315327307, 1.57683472960226, 0.13416908441051362, 0.11506125045519684, 3.460200726985932, 40.418538047421364, 68.9773113496842, 70.20276961788055, 68.75798809912898, 61.88164172634002, 52.58280423379714, 61.101599970171534, 67.19034225709977, 70.65152798929523, 66.87101425663118, 64.04253036745133, 62.476935925022254, 54.67310590128745, 51.47985727556291, 53.60067890536401, 56.10614776611329, 62.65320724056613, 62.310278338770715, 66.12518341310563, 62.54623636122673, 62.33136500081709, 63.91228414350941, 59.727762360726636, 59.90097814990629, 60.95542107858966, 60.718384404336255, 63.89491588838639, 63.04537365513464, 59.725812942751, 55.095015648872625, 45.56351884718865, 46.87108016783192, 45.66590447579661, 45.79100455007246, 46.08564515267649, 42.321350420674975, 43.346022559750466, 44.33822531853953, 42.515586191608065, 45.778978563124134, 52.611802316481075, 54.98762507592478, 54.3392494417006, 60.40142159308157, 49.42365669435071, 58.88780247780585, 63.74835260452763, 52.92309338046659, 57.9340075677441, 56.12887397889168, 57.86988858253726, 54.66613584949125, 51.76509987923407, 50.85374501443679, 51.370128969992365, 49.39288570034889, 44.86720008234824, 41.48565023176132, 42.81537294387818, 42.57265275524509, 40.47589486645114, 42.161074530693796, 41.92166874485631, 42.161364786086544, 41.19318654460292, 42.444885469252064, 41.41613798756754, 44.338727381921586, 44.979368102165964, 44.71738515361663, 48.35494418298045, 55.761771509724284, 56.14067246837001, 58.62093225602181, 57.07149797870267, 54.506883698125044, 54.631826877594, 58.36325606992168, 55.25203597161078, 57.43930255213092, 56.3576619086727, 52.637940991309385, 51.70150649163031, 54.334464150090376, 55.059533888293856, 55.38814221659015, 55.095050950204175, 54.84516066889609, 49.55765270417737, 47.17251823794457, 50.64631046787385, 50.82316621657341, 53.756710790818744, 53.23860099238735, 55.448938954261045, 58.02601852724629, 60.307924055284076, 64.14646140990719, 64.5769101573575, 51.003583477389434, 27.10784346826615, 7.364270100670477, 1.1271284929206296, 3.4308878740956708, 31.26566371610088, 57.94302509677026, 56.37287678257112, 50.691519706479966, 47.01330138790993, 58.15638242229339, 39.372092831519346, 39.48489235293481, 56.56839909092073, 49.24917005723523, 32.62938749405646, 8.454302164816088, 41.55544488660751, 39.014019658488614, 24.685519049244544, 42.21192805997787, 47.707839396692094, 44.98494179018083, 0.9848916446489673, 0.031530901511770584, 0.03760463235178783, 0.1453889323578727, 0.04429267186130728, 0.038748420774936676, 0.057710560128813794, 0.01181198507472272, 0.05326387172024097, 0.06323790365469552, 0.021062154893673236, 0.025436290945377082, 0.06020274756836796, 0.01915228620712315, 0.00498128371433385, 0.04097769449975702, 0.03346784183034494, 0.019270081801580328, 0.08987561198732547, 0.09335583451414302, 0.09795973182565744, 0.05356950249763266, 0.06475389589585605, 0.04617733625514854, 0.04805542761459947, 0.017961655337844166, 0.0555516324276405, 0.044812795766178644, 0.07839577678110331, 0.047739297602205515, 0.06721840074826634, 0.04781473428010941, 0.07565570244145009, 22.663137143658055, 70.6225573632025, 39.20888693101945, 44.84125752602854, 67.04122158788866, 24.774690212741977, 28.619338620093565, 75.2958417707874, 81.67561607976114, 35.07309275288736, 20.46616465814652, 55.61635748032601, 78.14919348685973, 72.65718490846696, 71.02047397244361, 62.594116733920195, 28.027815780332013, 2.4865875513322893, 0.21712140660853158, 0.10685800394463925, 4.873317931928943, 44.31629142453594, 71.0929907521894, 71.93116987905195, 70.28859892199117, 63.4344139406758, 55.914892996511156, 62.17806700737246, 69.20090998372724, 71.83474233073574, 67.8241188295426, 68.32015745101437, 63.884533374540275, 56.19742916476343, 52.277263364484234, 55.316868828188994, 56.43194375499603, 62.12093376344251, 63.62414683065107, 67.05998620679303, 63.334071866927616, 65.73614312756446, 66.08490851617628, 61.592280633987926, 62.049311284096014, 66.13050214705929, 62.3834187753739, 64.99687833170738, 63.21479651235766, 63.22059377547234, 56.23054573612829, 49.75219834235407, 49.130753701733006, 47.898796066161125, 47.0659827416943, 48.19482518780617, 46.404918239962676, 45.057148702682994, 45.84825938747775, 46.2676941194842, 48.98556716980473, 57.29687344643378, 58.28339661321333, 57.205956828209665, 63.15797705804149, 55.59571404610911, 59.4938478931304, 66.03760473189816, 59.684961457406324, 63.07022971491661, 60.105274800331365, 62.05853277637113, 57.68395254688879, 56.353359068593676, 57.0061630587424, 55.33040885002383, 54.41217022557413, 47.70950248164516, 45.01814857605965, 46.23005897768083, 45.31293822873024, 46.82790663934524, 48.05886407052317, 46.1875993205655, 46.508700232351984, 44.08853900048041, 44.627758995179214, 45.702366828918464, 44.48478468002812, 46.20464986370456, 46.062299205410866, 50.78890823548841, 59.75479533595424, 58.37148128017303, 59.95119625522245, 59.024300959802446, 57.56286505729922, 58.080335509392526, 60.22509144198511, 58.00872871952673, 57.787652169504476, 55.91432817520634, 56.01638040234966, 54.56371491955173, 55.556407974612334, 58.13925343175089, 57.95287809064312, 56.57566724285003, 57.65045158324703, 50.56645885590584, 50.31540363065658, 52.897091988594305, 53.791953286817, 55.11821646844187, 56.66275955015614, 57.5773621374561, 60.06576084321546, 62.5969212285934, 64.92070982533117, 67.5721771486344, 52.13182187849476, 29.341268500974103, 7.969664892842693, 1.893168245592425, 3.5095865543811553, 37.24512092528805, 62.66127555601059, 61.75613372556625, 57.265467028464045, 52.381112037166474, 63.708979852737926, 42.81188987916516, 38.604771321819676, 55.116996611318285, 54.66240959782755, 38.563751174557595, 16.37931577620968, 28.784605726119015, 50.21260615318052, 23.80518032658485, 39.55733460764731, 56.828836625622166, 47.76487850373792, 1.4157143042933558, 0.05538827949954618, 0.017214106741331277, 0.02734910907043565, 0.07701646611695329, 0.03706280134558197, 0.05068396721335669, 0.018342211429450302, 0.1038248933130695, 0.0687910643436255, 0.04412631586854977, 0.03525021050365702, 0.06039766331894263, 0.038553550989637454, 0.0859573174027666, 0.11622135272069324, 0.17203541622767526, 0.1600304354102381, 0.13568970765317642, 0.1864995239602943, 0.16422364830730424, 0.15157616486953152, 0.09233552031219007, 0.058681760433941126, 0.1626160740852356, 0.14593260963597607, 0.26897166224737323, 0.17986002378165725, 0.16927517079297574, 0.14634283439766976, 0.2336150651136714, 0.20205823344088372, 0.3810803562162384, 40.51210618788197, 78.45633076083276, 55.06977519681377, 66.87510136635073, 74.91709770694857, 44.45252318536082, 27.417243949828613, 86.86684946860038, 94.58437165906354, 36.08211855734549, 24.085584686648463, 62.26377079563757, 86.73468912801435, 78.18127847486927, 76.26090172798403, 67.694107947811, 31.854382061189224, 2.525936768900964, 1.2126995334702155, 0.5939509707593149, 5.961523642463069, 45.20382965764692, 73.73998657349618, 76.43900086802822, 73.98237336066462, 66.30304721093947, 58.727393227238814, 65.3535355291059, 73.53660383532124, 75.26667502618606, 69.08815753075385, 71.32439490287535, 67.81952181170064, 59.640693587641564, 55.62916009656845, 59.447791422567065, 57.80505964832922, 69.19537159704393, 66.61220842792143, 68.78007104319911, 66.5442023738738, 68.03170634854224, 68.59475474203788, 63.35239718037268, 65.53962845956126, 67.1741428682881, 64.68274747171711, 67.52265330283873, 65.66531296699279, 66.5346396353937, 61.30756362791985, 51.76144423023347, 50.41770296712076, 49.745683285497854, 49.23906210930117, 51.289567409023164, 47.71512323810209, 47.679084500958844, 50.77898856132261, 48.44522145486648, 52.6960862067438, 60.31627870375111, 61.484282093663374, 60.078335961987904, 65.3035919897018, 57.594753926800145, 65.06332720479658, 64.29740598124843, 62.19527836768859, 64.38804411119031, 61.60074510881978, 62.008157776248076, 60.9376488193389, 58.69890897504745, 58.07100026838241, 56.83031143680696, 56.13965265212521, 50.58365060437111, 48.59316933539606, 49.39087352445049, 47.92022005204232, 46.46285949214813, 48.52979167815178, 49.03440067845006, 48.30045853891681, 47.173294867238695, 47.57674594079295, 46.783517176105136, 49.050494163267075, 50.23859970031246, 47.298018393978, 52.02264662711851, 62.0047963050104, 59.778682570303644, 63.539423634929044, 64.4887117416628, 59.89281961994787, 61.48916936689808, 64.13837740498205, 57.88777851289319, 60.65809365241759, 58.928332328796394, 58.10972582909369, 55.21652675444081, 58.592718647372344, 60.713301012592936, 58.81731748580933, 57.48163669340072, 60.24198509031727, 51.779514589617335, 51.972506969205796, 56.19974336316509, 56.853033727215184, 57.162328304782996, 58.74763657969814, 60.60910717133553, 63.75090214513964, 64.90108620735907, 68.44145282622307, 69.9176368405742, 54.12615099260884, 30.196968855396396, 9.530334799520432, 2.5188877794050404, 5.834077500527905, 41.2366581732227, 65.67953940360778, 66.94459007632348, 62.40745898216002, 56.359352450216974, 69.0871298697687, 49.56862357354934, 47.25217765377414, 64.12781053973784, 60.114633575562515, 42.842178421635786, 9.700492120558216, 58.10370106850901, 59.96675629769603, 31.79528763217311, 57.795798932352376, 61.26671606494535, 68.23046068991384, 3.7804345498161935, 0.2972652811196543, 0.20590523588320903, 0.19711636878069372, 0.2730841447989787, 0.146424024395885, 0.21758701952715076, 0.07290452748777405, 0.18744363539641906, 0.26185366355123063, 0.12409380246554652, 0.11572114327141356, 0.152083529580024, 0.15571282515602727], [0.052302710997361335, 0.037444133101211446, 0.056633042141554825, 0.024015657498591372, 0.04810746796729584, 0.05391230769155007, 0.09709664950928382, 0.1342753714491283, 0.045826314768243226, 0.05254470285088305, 0.01888924608788183, 0.009083720938032194, 0.04719134172304504, 0.0923651296104635, 0.04083113804940255, 0.04982839638908064, 0.0591396588471628, 0.19394635823705506, 0.17001685115598864, 6.521297837457349, 69.06384668042584, 44.31354968778549, 60.04671773602886, 67.33581512205063, 38.91325789113199, 18.743298861288256, 48.97520819017964, 84.80591850896036, 47.108360029036, 17.605742869838593, 37.18655209387503, 68.7894533526513, 64.74020235000118, 64.40725195792415, 61.46833765891291, 37.52156173029254, 8.539741193094562, 0.053525816333750566, 0.30597753942974154, 8.563812778842065, 50.24938229591616, 72.60311111327141, 69.2040478798651, 67.08609350265996, 63.5709830253355, 53.766873651935214, 58.71520642311343, 68.8634527883222, 70.32597910973334, 66.50755959172403, 64.85073866382723, 61.96539609662948, 62.04438086478942, 57.81712485897926, 63.068794127433534, 62.030158350544596, 61.75476089600594, 64.07101854201287, 61.840645113298976, 63.79326374300065, 65.04357807097897, 63.73038814913843, 62.27931122626028, 61.77778913128761, 61.44438766664075, 57.65629983717396, 64.65181173816805, 61.41187121791225, 61.19241852914134, 52.053574515927224, 44.65693750689107, 47.372684632578206, 44.7868150280368, 45.74519911120015, 44.44583554421702, 44.696004313807336, 43.76437471758935, 43.575363543725786, 43.5203601467994, 48.43309348629367, 53.364061924719046, 54.7761034196423, 59.21656377853886, 52.71156387944376, 51.183396693198915, 64.90852302120578, 54.67663995681271, 56.60879558132541, 58.072757490219615, 56.73040082377773, 57.85157895857289, 56.97678058378158, 54.927149972608014, 54.29979432013727, 52.374365560470096, 51.06427431106568, 45.281637714755156, 42.71073195242113, 42.49450737430204, 42.01391112419867, 42.364622008415964, 41.665698789781146, 41.6578265928453, 42.29221505503501, 42.113633463459635, 41.941343353640654, 42.105380796617084, 44.99245312906081, 44.64347201008951, 45.164174495204804, 46.196616849591656, 47.45688223069715, 51.43636603509226, 52.624353901032485, 52.78961904587285, 53.20855955923758, 56.09276071671517, 55.48996694626347, 57.91120682993243, 58.900660007230705, 56.746164829500266, 54.610893187984345, 53.50936612775249, 56.155718680351015, 61.44548985265917, 55.192478702914336, 57.54489667953984, 54.521149358441754, 50.38994435341128, 49.13728837044009, 52.57619111768661, 52.7534116468122, 53.475312109916445, 53.98469463471444, 54.958626993240856, 55.608646100567235, 60.66061965880856, 62.43294262116956, 66.89381107207268, 55.621068246902965, 27.197734386690204, 7.63734257028949, 1.5329039385241847, 4.93824492539129, 33.65066482174781, 57.82999023314446, 55.16917590172061, 57.827942755914506, 49.887363218492084, 62.93220543092298, 44.031743080385276, 46.52468389080417, 58.85613718340474, 54.17411373507593, 20.01562160830344, 13.66575341070852, 54.18395103946809, 27.28988459033351, 40.713806229252974, 38.262901459970784, 56.568489305434696, 7.745485257717871, 0.372931540252701, 0.015973818052800435, 0.08766586967413464, 0.10364297807456986, 0.033117322131030025, 0.03714777198770354, 0.04329539392323744, 0.06142137512083977, 0.016865789544798674, 0.05921449414604615, 0.048642660821637804, 0.018028050263021744, 0.07625453038922242, 0.029609851771965626, 0.05146472572138713, 0.04339838295333809, 0.03805685405349059, 0.08816937330148875, 0.03433947368795353, 0.04180157992748484, 0.11142569594085218, 0.016844354404677308, 0.02050711078599336, 0.08734486351210265, 0.05345794094365932, 0.08518546849729554, 0.02951167185880965, 0.04541473403092354, 0.038098142362169685, 0.033135972541546634, 0.11555939146708097, 0.14501764018449093, 0.24550949944363487, 6.55532096662829, 81.3182253991404, 49.42837138329783, 65.62341813118228, 78.5117930750693, 38.11621658263668, 19.10397452692832, 62.940301202958636, 83.08249181316745, 48.28624779178251, 19.59933457836028, 43.595528448781664, 73.94773883204307, 71.15366981875512, 71.90226985562232, 66.86298124251827, 41.86845787109868, 9.95288291285115, 0.2662635720785587, 0.7947249037604179, 10.902357332168087, 52.561086070153024, 76.72017205146052, 69.77164622276061, 71.92997747851958, 67.79651318826984, 56.29433524224066, 61.017822065661036, 69.17507725377237, 70.57780311953637, 68.41645163874473, 66.4249623206354, 65.10795593261719, 63.854868488927046, 58.75867020699286, 64.47304579519457, 64.001800475582, 65.04966558948641, 65.575200434654, 63.4164063392147, 64.2759584611462, 63.962443413272986, 65.91194768105784, 63.78689773621098, 63.30843133311119, 61.236913896376095, 59.654166929183475, 65.9419616576164, 63.95899564989152, 62.482886160573656, 53.52568318766933, 48.71015794815556, 51.139054298400886, 48.634613098636756, 47.241991258436634, 47.97334071128599, 48.72714573337186, 47.7312167229191, 48.23143266862439, 45.66928555888515, 51.23708609611758, 56.782411452262636, 60.65606186466833, 61.128393680818625, 58.466049625027566, 55.396151696482015, 67.5051752213509, 59.73158274927447, 59.57407997500513, 61.102957110251154, 63.044102807198804, 62.586950563615375, 60.26745696221629, 57.87243812314926, 57.29800701141358, 57.001879830514234, 55.03413654142811, 48.4192749761766, 46.09555305973176, 46.89399465437859, 45.70763457205988, 46.344180337844364, 47.026194218666326, 45.60182079192131, 44.31143160789244, 43.71145409922446, 45.43750486066265, 44.83899824080929, 47.32389819237494, 47.895889589863444, 46.12484532017862, 48.60975311648462, 49.85102245884557, 54.59266201142342, 54.4826473728303, 54.303253850629254, 58.01027413337462, 56.975862749161266, 59.47937826956473, 59.65732051480202, 60.8497759603685, 55.87764616935484, 57.69657865647347, 56.85578723107615, 60.06163450979418, 63.69781286485734, 57.342196433774895, 60.02217938823085, 55.57718869178526, 52.262750594846665, 51.20686423393988, 53.48498467476138, 55.36966393070837, 58.14948297316029, 55.97274403418265, 58.21097789272186, 57.59057660256663, 63.28040992060016, 66.35432827857234, 68.56774530103131, 59.00905078457248, 29.25797893155006, 8.294702883689634, 2.612306134354684, 5.519383780417904, 38.5923844768155, 63.28559529396796, 61.707919951408144, 59.623219428523896, 58.5203234611019, 65.08209182370094, 49.981798202760764, 48.34575014729654, 62.435449015709665, 56.53334879106092, 32.63921499252319, 17.973667075557096, 40.32529546368507, 36.12328775467412, 32.57574712076495, 45.065299387901064, 65.86265133273217, 10.67676809526259, 0.7266490437811421, 0.19653000508344945, 0.07983895619550059, 0.06689800745657375, 0.05193202020300012, 0.05707401384208953, 0.1373193758509813, 0.04369075274876049, 0.015574403749328228, 0.03586971899494529, 0.01750953514279137, 0.048292983819039605, 0.04759633410421591, 0.027125507157536286, 0.13342522835779574, 0.10582946961925876, 0.16478643181823915, 0.1718767594185568, 0.199346128971346, 0.15085401974858778, 0.27918257239845495, 0.2918366901576519, 0.11803429979350298, 0.18631797644399828, 0.11085623214321752, 0.16242256027556237, 0.13156164287319108, 0.2120905991403326, 0.23956130168611006, 0.16325813237457507, 0.17891355279472568, 0.30745697778559505, 0.49349116461892284, 12.655504807349175, 101.37444157754221, 60.86699516542497, 82.0729051097747, 81.56859028723933, 60.36287253902805, 24.79337834542798, 63.91198604337631, 93.47865550748764, 59.37311733922651, 23.073730853296098, 47.575922243056766, 79.07692032475626, 77.77452084325975, 77.75165342515515, 73.6633748392905, 48.52262550784696, 11.531804588533218, 0.9769358521988316, 1.068953124265517, 13.414411852436682, 53.634019051828695, 79.55432768790953, 74.75580200072258, 74.5497755850515, 70.3617746599259, 58.73499085826259, 64.78212072003272, 74.10930125944077, 73.46284758660101, 69.81540418440296, 69.64332980494346, 67.25998001713907, 67.5547618250693, 61.536818319751376, 67.15024778919836, 67.42660230205905, 69.18639721408968, 65.69817458429645, 63.25148244057933, 64.35667299455213, 66.17091040457449, 67.2425490040933, 65.24510160569223, 64.01643876106509, 63.43819902789209, 60.74296197583599, 67.91343119836623, 64.19531845277356, 65.38770721804711, 54.65602005681684, 49.08923541345904, 52.671991086775265, 50.61749281421785, 50.063540397151826, 52.38300261958953, 49.94590067094373, 49.49934667156589, 49.376709845758256, 48.87718031483312, 54.96690711667461, 59.74101997190907, 63.705343815588186, 66.97207804649108, 60.00935716013755, 62.034174857601045, 68.59531956334268, 60.09349984507407, 63.30415202725319, 62.92550210029849, 62.498328531942065, 65.42984131843814, 63.29985310954433, 61.766802572434955, 60.186409027345725, 58.01243143696939, 58.0278463517466, 50.9121883300043, 47.48809253015826, 49.62267383452385, 48.644454325399096, 50.682910103951734, 49.18838508667485, 48.45422329441194, 47.21107905910861, 47.31159371714438, 47.38079217172439, 46.57800851329681, 48.958126268079205, 50.55613517761231, 49.47055647450109, 50.78216175879202, 52.45950844980056, 55.190788161370065, 56.27594717087285, 56.22844334571593, 60.08596104960288, 60.10783218568372, 60.86556742268225, 61.19323045976701, 62.7006483078003, 59.05556225007581, 59.935706815411976, 59.47179632802164, 61.71272485486923, 66.82063533413795, 61.473546566501746, 60.68227898690009, 56.66244183817218, 54.37626877138692, 53.37565252857824, 55.05094781998665, 59.659034590567316, 61.965709886243275, 59.961312047896854, 59.30580946706957, 58.73374746691797, 66.5376990841281, 68.5245600054341, 70.25713366846885, 60.75126171112061, 31.091314361941432, 9.384297113264761, 3.3459550767175616, 8.73068315367545, 42.67999233738069, 69.36063674188429, 64.71181615706413, 64.79733167156097, 62.21109336422336, 72.29781735327937, 54.80800797862392, 55.21279265803676, 68.84429593240061, 65.63294164596066, 25.838176165857625, 18.263765573501587, 76.97368268043765, 37.30265032860541, 57.34388697531916, 53.02100750707811, 79.57781484050136, 22.404864757291733, 0.7657662899263444, 0.3201374183258703, 0.15656407141397077, 0.2442003164680735, 0.15743522063618706, 0.16963633528399855, 0.22933454883675422, 0.1309831545598084, 0.09926280908046231, 0.1741078526021973, 0.1309777306573045, 0.14701230331294, 0.22551987530483356, 0.1837437065137971], [0.0687262762878691, 0.039058939193285284, 0.01833005361409197, 0.04385671803667661, 0.04076415132130346, 0.11879276514293687, 0.068915898370887, 0.056255050529275215, 0.02072144686544855, 0.06569812224516947, 0.06599716466641234, 0.03159211768258003, 0.04065534768385753, 0.02827278511118024, 0.002136961087554453, 0.009865280007943511, 0.04961483022798935, 0.06866754032671452, 0.027745530842953635, 0.6551864010191734, 44.660753973068736, 52.854836294727946, 68.46248457508703, 22.585484020171627, 39.375466069867535, 24.720785079463838, 28.063107305957427, 64.1324193246903, 66.58817214350547, 35.88174427709272, 28.00888053832516, 68.55721765948881, 68.73219459287583, 70.39006279360864, 62.285743913342884, 57.140045319834066, 20.8988275835591, 0.3076565590116286, 1.669377537985002, 20.67489947042158, 54.92105460936024, 74.71782561271422, 70.6182506007533, 69.69839988216278, 64.34763585367511, 53.13243027656309, 59.59066767846385, 66.64303041273548, 69.40380634800081, 68.38336252397107, 65.12501039812642, 66.86845687127882, 63.030943255270685, 61.28575917213195, 60.84308047448436, 63.327156728313824, 67.07009807709726, 62.810678635874105, 63.5618595923147, 64.56431934910437, 66.17435424558579, 63.04330264368365, 60.597457731923754, 58.878055387927645, 61.854553837930005, 64.94105515941497, 61.36694438995854, 59.359491025247884, 57.032611600814334, 47.632082739183986, 46.18904667515909, 48.14559551977342, 47.46710000499603, 45.85360165565245, 43.267312357502604, 43.53544166011196, 44.04190201913157, 42.12330210593439, 44.81598177263814, 51.65845455661897, 56.97568232013334, 56.55067782248221, 58.41675719907207, 49.8576355749561, 64.14810096063923, 58.772265142010106, 56.16385759845857, 57.96671229024088, 59.04517189148934, 59.88716356215939, 59.459040780221265, 54.29904122506419, 53.95857164936682, 53.91490782460859, 52.32614394157164, 52.623075208356305, 48.59082768040319, 44.62167147667178, 42.98167359444403, 43.40072393417359, 42.74622940248059, 42.35709105768512, 41.565239044927786, 43.47498616864605, 42.16826423521965, 41.02222219590218, 42.197870285280295, 44.190093086611846, 45.34220695495606, 47.33720679436961, 46.67648746121315, 44.010636806488044, 46.49272049626997, 45.1376945741715, 46.47978844181184, 49.096401583763864, 53.266896970810436, 55.55399571695636, 58.56971002394154, 59.146243526089584, 59.7250049344955, 56.37448495434177, 56.26499591335174, 56.61682075069797, 54.288646944107555, 57.327773878651286, 58.49915050691175, 56.23937499138617, 52.68715104749126, 55.88909164551766, 56.164418497393214, 54.9598390056241, 56.10035442536878, 51.70427568497197, 53.66160508125059, 55.25483654391382, 61.17650547335225, 65.46953570458197, 67.9415467477614, 57.59147482533609, 21.30864662508811, 9.21020761612923, 3.4742136395746663, 8.470910460718217, 44.5187916294221, 54.30680751800538, 58.301549342370805, 44.55440282821656, 51.775235283759336, 61.12390648934149, 47.37599119063347, 65.85233549917898, 44.00050532433295, 29.11674418757039, 7.246953479705319, 43.451134235628196, 41.59390372614707, 28.622405913568315, 35.7650851434277, 49.131714682425226, 33.95164005218014, 1.1287223235253365, 0.12696359847341815, 0.03145642818943147, 0.06716317346980495, 0.034850799073014534, 0.05824896289155849, 0.013756679160700691, 0.03545304760336876, 0.032798997276733, 0.025452085763155937, 0.022060313832855994, 0.04951106744908518, 0.04480152278237286, 0.026914503560551715, 0.006213946476383436, 0.03281254171123428, 0.05068051981769743, 0.06229630115652277, 0.031621342021671515, 0.04164327551881152, 0.01578605373299891, 0.009561497417669143, 0.09526102623391537, 0.04546842913353636, 0.06781359743927756, 0.03053536450850868, 0.03521043138818876, 0.05308210586888656, 0.03998569107704586, 0.04078854356081255, 0.07893731667389793, 0.023925314664900787, 0.06487603329362408, 0.0566047428536319, 0.5684944206187802, 54.57128901635447, 60.43280447683027, 68.15764581003498, 25.210598899472146, 42.06500784043343, 20.66947679365835, 42.964611284194454, 68.85787517793717, 66.1334753036499, 40.27304949298982, 33.74723357539023, 74.60347283271052, 74.77813597648375, 74.76767893760436, 70.92257945768296, 65.17993927001953, 24.171041365592714, 0.2958961287813802, 1.8095452747037335, 24.046276653966597, 58.467598961245635, 77.51604449364447, 71.14850797960835, 71.08771908667781, 67.26436522699171, 55.7298904849637, 61.00943211586245, 69.9715772751839, 71.64966137178483, 67.6751079866963, 66.77297069180396, 67.75925851637318, 62.5751442293967, 63.30553662392401, 63.235734124337476, 65.65921368137484, 69.02742355100571, 66.14360286343482, 66.16042983147406, 64.159522902581, 67.4537843273532, 65.68929433822632, 60.9675568919028, 61.35072146692584, 62.12841372336111, 64.94450684516661, 62.82677996543146, 62.58757814284294, 59.54175964478524, 48.8051655984694, 48.25927365210749, 49.98927424030919, 49.882217068826, 48.17936712695707, 49.01628717299431, 47.25797491688883, 47.46575070965675, 47.035376487239716, 45.39941080154912, 51.88177078000961, 61.52616516236336, 61.25706311195128, 61.726613967649406, 55.896622596248505, 65.19766446082824, 63.48011347555346, 58.89173269271851, 61.01362512957666, 63.81537806603217, 63.7507805516643, 61.66725281746157, 58.65093054309968, 56.869358631872366, 56.821168391935295, 55.45511668728244, 57.97933055508522, 51.81024635991743, 47.132184505462654, 45.7980687387528, 47.36902113883726, 45.353679887710086, 45.524656003521336, 46.17726779753163, 45.719997882843025, 44.32808206927392, 44.89602165837442, 45.30157904471121, 47.13805629361061, 47.8440672351468, 48.175593806851296, 48.52252352622248, 47.253472035931004, 48.51827952169603, 46.90355347048852, 49.49557335146012, 51.20487166989235, 55.477231010313965, 59.30785302192935, 58.64910271859939, 60.2056521754111, 60.50508199199554, 57.95197986787366, 59.36286818596625, 59.36678663376839, 56.34365120241719, 59.57136961721606, 61.128699625692065, 56.06429999874484, 55.31637853191745, 55.53573316143405, 59.33766303523895, 59.84858705151466, 57.9331446463062, 56.29915583518244, 57.73999929428101, 55.67992733370874, 63.34569384974819, 68.56361112286969, 67.89098739624023, 60.237168419745664, 25.328168023017145, 11.978368393836483, 5.818395374282714, 11.341265651487536, 50.16417664866294, 59.69053514542119, 64.37087981931626, 49.490584096600934, 56.396309021980535, 63.13916537069506, 54.34787865607969, 70.38382622503465, 51.44695643455752, 37.62564182281494, 16.15066610997723, 27.54111828342561, 42.259145552112216, 32.18572232031053, 35.471919352008456, 60.3961460051998, 39.0452064237287, 1.79728357782287, 0.13046193897964495, 0.026820514148341554, 0.054404549826417244, 0.03992313999802836, 0.006818478427556974, 0.044767784270187544, 0.03649879975484745, 0.07424794693267153, 0.06362031176385861, 0.055742587503646655, 0.03074803626194837, 0.09553556916333976, 0.015039989431839318, 0.04084476292313587, 0.12682662961343605, 0.1274748778932037, 0.10762360923352743, 0.11215462860080505, 0.1795805549068797, 0.32070505883424516, 0.16855743833847586, 0.13932693990007525, 0.09554165190145855, 0.1617363140347504, 0.16921723922414167, 0.10228429815822071, 0.15100821792598695, 0.14119158258601544, 0.13650971284556773, 0.21828445065165722, 0.2795206623211984, 0.13620297124068584, 0.20555363216948128, 1.967285229794441, 82.85252324996456, 65.71792371811406, 86.98399497616677, 33.19562281331709, 57.545959641856534, 36.89217036770236, 37.12121717391476, 80.96387847777336, 75.91614892405849, 46.45859195340065, 35.18452336711269, 82.85373918471798, 80.82562277393957, 82.94130217644476, 75.51507872919883, 69.6282208350397, 25.135893437170214, 0.32520861394943734, 3.111320854194703, 28.545376446939287, 61.63375969856017, 80.166562603366, 76.91275258218089, 75.24620809862691, 70.357679705466, 58.45065039973105, 65.89034326614873, 73.61434521213656, 73.37268798582016, 69.44249660738053, 70.72279745532622, 73.2354050297891, 67.0328277157199, 66.03281944028794, 67.29974500594601, 70.83958994957709, 71.5760620178715, 69.7157524478051, 67.87473309424617, 65.95616848238053, 68.69242175932854, 67.05698951598137, 61.09543008189048, 60.7552586063262, 63.67276068656676, 69.9822461220526, 63.38682382337509, 63.99120615374658, 61.22935156668387, 50.42728139508156, 49.926069167352495, 51.57120927687615, 52.04031298237463, 51.40222572511243, 49.88223275830669, 49.1482670845524, 48.598723411560066, 50.043806952814904, 49.48701081737396, 55.57599236888271, 64.87734017833587, 63.91121333645236, 63.94911519942745, 60.6951561281758, 66.86039247820455, 61.302880317934104, 63.18490020690426, 62.03770106838596, 64.98879432678223, 66.01094045946675, 63.27474994044151, 59.9132041777334, 59.216202920483006, 57.739783563921534, 57.970995518469046, 58.601755788249356, 54.698056097953554, 49.713696356742616, 47.98657086587722, 49.70950334302841, 48.52669300571565, 47.159837215177475, 49.39399573110765, 47.75915576565651, 47.842117817171165, 46.85493176983249, 46.39548101732808, 47.632675017080004, 49.862491469229425, 51.21547775883829, 50.070208426444765, 47.59261585051014, 51.5369003049789, 49.43800864681121, 51.51008698248094, 53.65346616314304, 59.24132570143669, 61.08253332876391, 62.25601234743672, 63.0619417467425, 64.58840270196238, 60.32296242252473, 60.95042397899013, 60.5672868605583, 57.84086304326212, 60.818204802851525, 65.29058933258057, 58.82396982562158, 57.8243733990577, 59.721557171114036, 62.067240438153675, 63.56244794784054, 59.942253251229566, 58.531353166026456, 60.79465096996677, 59.92630489410893, 65.94604876733595, 70.36498315872686, 71.63345413823282, 60.1027056478685, 28.003808913692353, 12.622654957156028, 7.465869294058892, 14.438727055826496, 54.0683077996777, 66.23327609031432, 68.65442968183949, 55.70388909309141, 62.038112917254054, 70.61610898663922, 58.14812975545084, 77.94255518144178, 58.21169176409322, 38.30771061681932, 8.658096751859112, 56.75853206265358, 62.09007255492672, 38.24835731137184, 54.877171131872366, 63.640918885507894, 64.67245125001477, 3.33595916148155, 0.3730204064519175, 0.2278566733002663, 0.20941826995582352, 0.1595467581383644, 0.1283783177214284, 0.1729449617766565, 0.10281215572068769, 0.14338153684812208, 0.19866855484583687, 0.1642312478995131, 0.17722769970855407, 0.14957232400774956, 0.10672664284826287, 0.11208601776630649], [0.04201439532241033, 0.040553998081914844, 0.02674257427814507, 0.05312979867261264, 0.03601005098091499, 0.06316117228819959, 0.04219186725094915, 0.027075991064550418, 0.02333400203966566, 0.030333937010577613, 0.17502165760003752, 0.1104437321003887, 0.03523989512975659, 0.0445103059492765, 0.058441695291548974, 0.1490621860589712, 0.014666666167848294, 0.08696631648607793, 0.09672616938910178, 0.2837880172075764, 18.39753604704334, 56.12923483694754, 48.70738091007356, 43.42115948277135, 30.179318189620975, 38.454407261263945, 11.856576838800985, 59.34692767358596, 66.6068426255257, 54.29188682186989, 48.716374904878684, 58.76715821604575, 75.00147573409542, 66.69494690433626, 71.71060715952228, 59.58536463399088, 37.79304465939922, 2.6655878559235604, 1.98018406668017, 30.558987932820475, 62.416013671505844, 74.87136287073936, 70.91157328697943, 69.11063271184122, 64.1075122740961, 55.91884674564485, 54.8869142993804, 66.12854880671348, 69.31088539861864, 69.81727123260498, 66.05155268023091, 67.4077513910109, 66.96129937325755, 64.88956620616298, 64.68783086346042, 69.00567793077039, 66.53271767400926, 64.72762330885857, 64.17634987062024, 62.8740837497096, 61.76511987563103, 62.989703455278956, 62.45854393128426, 60.07176599194927, 65.05594922650245, 63.07344213608773, 63.93574383951003, 61.18605644472184, 50.13445292749713, 47.516008038674634, 49.006030174993704, 48.468437963916415, 47.617679795911236, 45.36909088011711, 44.736616534571496, 43.929894816490915, 43.87381276776714, 44.159624115113296, 44.977136273537916, 56.59267463991719, 56.12857195638842, 58.80946490072436, 47.92577412820632, 56.01449374229678, 63.49793672561646, 53.489252213508856, 58.175649104579804, 58.097488034156065, 59.074377859792406, 57.19849255777175, 62.23225455130301, 57.73670450333626, 54.27273388831846, 55.5868455671495, 52.84064123707434, 54.21452983733147, 51.74959867231308, 44.13404241684945, 42.06700432685114, 40.14132061312276, 40.84542136038504, 40.66793803245791, 41.77684307098389, 42.20556597555838, 42.58904826256537, 42.0647568087424, 40.92124469818608, 44.423074030107074, 47.09112121212868, 48.03994255681192, 47.646062066478116, 47.04267994050057, 49.41406649927939, 49.10838442464029, 48.875478006178334, 49.37099103004702, 51.462159541345414, 55.424839911922334, 58.37779237378029, 57.83546193953484, 59.267456531524665, 59.44852882815946, 56.59515750023627, 58.94042499603764, 56.760697210988695, 54.17423140618109, 54.36964781053605, 57.19294240397792, 57.43282671897643, 56.55086609625048, 58.849641738399384, 59.19003678906349, 58.93056415742444, 54.54258511143347, 53.81957853994062, 54.50609530172041, 59.425076976899184, 62.857405831736905, 67.70418059441351, 59.017111255276596, 26.578278387746504, 15.555316998112588, 7.530803641965313, 11.709879213763822, 41.39184282672021, 55.67877415687808, 57.442981735352554, 45.46353763149631, 59.25880378292453, 58.598935604095466, 62.31434583663941, 54.25892322294174, 46.15112520033314, 19.62589883035229, 15.052542686462404, 53.75776590839509, 33.40229642006659, 33.79189368217222, 39.163634546341434, 51.68056103491014, 6.76758247998453, 0.6251099116859898, 0.11045412025264195, 0.047952473058455417, 0.051918345533551714, 0.041829285497266444, 0.022923436368845647, 0.012026737714486738, 0.0182640359872171, 0.07650802122248758, 0.011856606823482342, 0.026195129762674053, 0.06251874627665648, 0.05090426345686278, 0.03421000099831051, 0.039297307450925155, 0.04214219794037842, 0.04889178878417419, 0.03626384441891024, 0.035892923798171744, 0.04909644151226648, 0.06972348527802576, 0.06225018649392071, 0.03285934968340782, 0.03486057435492835, 0.025351733990734624, 0.07872145607947342, 0.0660329869377517, 0.03746271839425449, 0.05375187738888687, 0.016069151949317708, 0.07018523711350656, 0.04478272298471101, 0.04480956287513818, 0.36426138613493214, 0.2708509678561842, 22.2481248840209, 67.40927327063777, 54.85737100724251, 43.594924403775124, 35.39190300049321, 34.156831003004505, 19.38140965277149, 70.84405360683319, 73.07678438002064, 56.698496264796105, 51.232493000645796, 65.88723674897226, 78.23411280109038, 74.23973575715097, 75.95298782471689, 64.95035902146371, 43.25973041595952, 3.4357123894076196, 2.508449862080236, 33.83550259374803, 65.6442145378359, 76.28824849282542, 73.87868942752962, 71.05377489520659, 66.15643685863864, 57.10823097536641, 57.2009361943891, 65.8888292312622, 70.39732702316778, 71.3620339670489, 65.4634834874061, 67.15452317268618, 68.63313121180381, 65.24120276974094, 66.6130478151383, 70.60751899596184, 68.38115815193423, 68.05482479833788, 67.4031622179093, 66.32799348523541, 62.74994857849614, 63.79961013793946, 66.64013570354831, 62.55538332846857, 66.3934813776324, 64.2625988683393, 65.27475080182477, 62.07950176731233, 51.720416238231046, 51.317745716341086, 51.361609581978094, 49.557895891128055, 49.61786500869259, 48.93319568326397, 46.194016318167414, 48.405170133036954, 45.772306611461026, 46.98208324370846, 46.4366227580655, 59.641278020797245, 58.987254173524924, 61.76397454354071, 56.782627182622115, 58.646290379185835, 69.4950092992475, 59.45533414040843, 60.57440988479122, 62.221064029201386, 62.729481650937, 62.148237382211995, 62.9559200809848, 59.4293680498677, 56.91838041428597, 57.0247237143978, 55.872660836865826, 55.40331002204649, 55.15646349999213, 48.07417700367589, 44.49608895086473, 44.210846347193566, 46.05712167678341, 45.23839358360537, 43.84053145685504, 45.55459545504662, 44.220601281812115, 46.85378643774217, 44.9447492630251, 46.106782805535104, 50.02157495867822, 49.95631064138105, 49.659842214276715, 51.94310880476429, 50.69379075880974, 50.17263720112462, 50.8774047513162, 50.994201167937256, 53.763625929432536, 58.025053624183904, 60.26234611388176, 59.21234330823345, 59.473749668367454, 61.021156080307506, 58.118770814711056, 61.516743629209465, 57.39901196572089, 55.776782420373735, 57.20020271116688, 61.74067174234698, 58.87428206782187, 59.6211366499624, 61.31396493604107, 62.13307349912582, 62.6753725544099, 59.01285156126946, 56.16492056077527, 57.27888545682354, 62.304092761008974, 64.48373425391414, 67.84514273366621, 62.26992107206776, 32.46769955081324, 18.95493034393557, 9.17186938947247, 15.586467481428578, 43.79265500653175, 63.69937789055609, 61.155367820493645, 50.007203394366854, 62.075355822040194, 64.28274416154431, 66.5238295831988, 63.359728090224735, 50.25579144877773, 27.62789091756267, 21.04166461575416, 34.99977580962643, 42.147456061455514, 32.58764955305284, 44.342312428259085, 63.78265765405471, 8.905997410897287, 0.7720708258209691, 0.15045969897220213, 0.04688777555260928, 0.07966074116167524, 0.0249982227180754, 0.01420350760341652, 0.03409356329469912, 0.0318782362005403, 0.024626844359802145, 0.06355108039814138, 0.025371073880383087, 0.01813778661251549, 0.019094915797693596, 0.06339659876821023, 0.04632874970294295, 0.13300564200166734, 0.12642184407600474, 0.0941167896493308, 0.2063560786266481, 0.11803224667786591, 0.18482042776961483, 0.17081393499768552, 0.07497166253386006, 0.12461444347976677, 0.11941115897629531, 0.24813394813287645, 0.2264220664097417, 0.15778020535024906, 0.14646255861847632, 0.19107421800013513, 0.23353980463599008, 0.09686267093545008, 0.10563017950663645, 0.44115289565055604, 0.39207102130016974, 40.18321937130344, 88.05026777328985, 65.10468075352331, 63.46890726397115, 44.69546694909373, 56.29829291374453, 15.107031272303674, 78.21292415741952, 76.78631890204646, 68.05715468622023, 59.28552296853835, 73.63361189442297, 85.65141677856447, 80.89355822532409, 83.24693326027163, 69.58377253624701, 46.40196861759309, 4.154506825631665, 3.041126362739071, 39.3036239377914, 68.47432228826708, 81.37102050165977, 78.61295884655368, 76.77521074971845, 69.94476395268595, 59.489007688337765, 59.284699270802165, 70.66906882870582, 72.6443430685228, 72.68266462510633, 68.61431952445739, 70.50700433792608, 73.13944816589355, 68.49083546669253, 70.07495526344546, 75.5104346429148, 67.63197760428152, 69.49915132214947, 70.98595711492723, 68.67770502644201, 66.23952834836899, 67.48536725198069, 69.0892401049214, 64.24683486261677, 69.32670823989376, 67.47323143866755, 68.03365184414771, 64.47597972808346, 51.52463113107989, 51.70767245754119, 53.04636955261231, 53.53709336250059, 51.192810381612475, 49.91785964658184, 48.17557811737061, 50.399671831438624, 48.449508605464814, 49.48841894826582, 50.34615893517771, 62.31068234289847, 61.698184628640455, 63.66417461825956, 58.02048798530333, 59.990125779182684, 67.83799617521225, 61.706382382300596, 63.51697198806271, 64.28388164889428, 64.42406323648268, 60.859068055306714, 66.14879608154297, 61.97078543324625, 58.3325086101409, 59.1120247687063, 57.28796574377245, 58.68261152698148, 57.991231026188025, 50.73613274481989, 47.167517215974875, 45.458728805665054, 47.79535924234698, 48.48228000825452, 45.98851550009943, 47.56898749259211, 47.216299733807965, 49.043649627316384, 47.27832809571297, 49.15704142662787, 53.92969123778805, 53.69932651519776, 52.404818842487956, 53.31191009090793, 53.591853572476296, 51.97530361913866, 54.870934563298384, 54.210470184203125, 56.33664977165961, 59.89530248026694, 62.90929878911665, 60.58842451341691, 62.29345529310165, 61.41465610073459, 60.17083329539145, 63.026216799213046, 58.86959483546596, 56.973619153422696, 59.67801493983115, 63.23917012060843, 61.34509286572857, 60.38524966086111, 61.96048528917375, 65.15106670318112, 65.93506613085347, 61.960791234047186, 58.11560938435217, 61.36142169275592, 65.57835794264271, 69.33379988516532, 70.14784859072778, 66.0600563787645, 34.13669355453984, 19.167652245490782, 11.177958749955701, 18.085597791979392, 48.97169374650525, 68.3240484422253, 65.21465224604454, 58.16910659113238, 68.30590355780818, 66.93069704117315, 70.96548234262775, 71.9035485482985, 57.07454958269673, 25.218910401867284, 18.939897860250166, 75.46517049112629, 47.37681881073983, 50.34095394995905, 52.90874535037626, 76.51551062060942, 23.250686622435047, 1.0020025555164584, 0.24509763525378322, 0.1677239499986172, 0.19101735895439503, 0.25806336693706056, 0.1247511288872169, 0.1545587596633742, 0.08327772570473534, 0.12204821747277053, 0.1909889677359212, 0.09375008634261547, 0.14960339653395838, 0.20852320346861117, 0.24667643521341587, 0.11738962148346248], [0.013705917217227961, 0.06304514444162769, 0.03279957184267621, 0.039098783426227114, 0.009569717541096673, 0.09351891931146385, 0.056438762243957295, 0.049625302649914264, 0.1061596994798991, 0.06891790552124863, 0.048409800736173514, 0.07678023524462216, 0.03715630620718002, 0.060189601499587304, 0.05681696069997646, 0.05632892055737396, 0.02084230681160285, 0.003363251434488883, 0.06346493764149566, 0.08579330563905739, 1.075496863453619, 44.29522437434043, 49.43804394814276, 36.001808028067316, 29.75786343697579, 43.572974820290845, 18.62255850145894, 33.0603559555546, 56.659735402753284, 70.20234600190194, 71.10748783234628, 61.60924880735336, 76.85507020642682, 70.29912656353366, 70.43266757842034, 65.14023311676519, 48.466492468310946, 8.56632701812252, 3.41005910788813, 30.663346513625118, 65.98233853617023, 73.2165619634813, 72.58148316414126, 69.45574637382262, 62.94542774077385, 59.84987358893118, 58.455474915043006, 66.2595324362478, 67.72354925832441, 72.93189202585529, 64.26122603877899, 66.87228510456701, 69.33712605507144, 70.18039641841766, 68.32511532691218, 69.25346974403628, 66.67785321512531, 65.58035835143059, 61.162247657775886, 58.868163170353064, 58.36868070787, 64.18486533626434, 62.752486351997625, 65.40422431884274, 64.56957924750544, 60.88351618859076, 57.559197641188106, 51.04319157138948, 48.890841930143296, 48.383200937701815, 48.777469742682676, 49.106670348874985, 49.452407667713786, 47.73926150414252, 44.38018683464297, 42.80956783602315, 42.98569010150048, 44.38509764209871, 47.56606140444356, 55.471829906586684, 58.64043428051857, 54.38124233676542, 50.35278774076893, 64.38729886085757, 54.99650924436508, 59.293253960147986, 58.42605321638046, 58.95826001321117, 57.918561274005526, 58.496393080680605, 60.75402305972192, 57.29204500875166, 55.97462677186536, 54.98431067312918, 54.728882005137784, 52.71695321606052, 53.226359275079545, 46.879556409774295, 41.22002732369208, 43.17585837456488, 41.96952166095857, 42.0617954192623, 40.46976027950164, 40.854238848532404, 41.61076991788803, 41.518123534417924, 44.426874806804044, 46.42097642344814, 50.87935809166201, 50.69044105468258, 49.028011137439364, 48.54135874778994, 49.34793141580398, 49.44946589008455, 47.97534504244405, 49.653366381122225, 48.18433676996539, 51.58512584624752, 54.44924054607269, 56.34598893503989, 61.07980335912397, 57.883601188659675, 56.67180845814367, 59.15423731650076, 55.71952758296844, 47.422267313926454, 42.24354236356674, 48.006547497164824, 56.518483008107836, 60.07477837224161, 60.13995639739498, 58.812806760111165, 57.8207177500571, 57.063166864456676, 54.11344643562071, 54.543071485334835, 56.9838055487602, 60.1488523329458, 64.15780098207536, 62.66558624082997, 44.2850693579643, 26.69601421202383, 12.692614351549457, 16.52120359482304, 42.669178362815614, 58.811359405517585, 53.06066266952023, 53.36838437664894, 61.03227207737585, 63.60567246713946, 57.01664363184283, 55.486523105252175, 43.00410170708933, 10.979976134915507, 32.562789570900705, 37.50042407743393, 29.085586840106597, 33.91022766790083, 43.96762409517842, 45.265563841789, 0.4276079708530057, 0.07511646847330755, 0.03231231310975648, 0.026923032034368768, 0.04532211783131765, 0.01108625466229334, 0.01726101430493497, 0.048995003810212504, 0.07778397896477292, 0.04540728765629953, 0.06484414871421552, 0.025485755327428063, 0.04004534634370958, 0.04266035299928438, 0.012972594873468964, 0.022024503052835504, 0.024542718329617096, 0.08922181723098602, 0.03651837330131281, 0.04020252077269458, 0.025853071504482822, 0.030166765134180748, 0.03794447661587789, 0.011293327270616448, 0.031219097980929, 0.07404177735048918, 0.03861936177277277, 0.04292768321090168, 0.03351080021069896, 0.03959302505057666, 0.03852088117010651, 0.09846742595395735, 0.011737106683393641, 0.05821338576835491, 0.05799618068962328, 0.09467901391608101, 1.2027521575650861, 57.65216565901234, 61.45929267329555, 40.87745927995251, 32.03932965955427, 45.227767882808564, 17.06087858446183, 47.31801071474629, 58.32277328737321, 74.88400074743456, 74.004393546812, 66.11464008208245, 82.93284554635325, 75.79814049505418, 76.74838958248016, 70.26966171879923, 54.874727495255016, 9.482825090808253, 4.249181074480857, 34.47348002464541, 66.63893545827558, 75.74506298188241, 77.24587163617535, 71.07691687922325, 67.24980538891208, 60.63428094310146, 58.04126870247626, 68.25995691360967, 69.06307005113172, 73.91588134150352, 66.22961259657338, 65.62169228830646, 70.62615025428035, 71.72615543488534, 70.1869938450475, 70.13457529006466, 67.77893312515752, 68.51724086269256, 62.53238254977811, 60.471463357248616, 60.7640721721034, 64.699339097546, 65.09793035445675, 65.7584104230327, 65.23128701794532, 62.256094717210345, 58.452799858585486, 53.72896786658995, 50.63850102886077, 51.19790161809614, 49.678489162075905, 51.73261480946695, 52.01228764749343, 48.3505589731278, 47.29708879224716, 46.082997552810184, 46.60863045723208, 46.301179393645256, 49.00282167619275, 58.99872318390877, 62.61906300821612, 61.01815154475551, 53.63040262652982, 67.23274307866251, 63.27858601847003, 60.04347001352618, 61.921018400499904, 63.06245557723507, 61.78198214500182, 61.44922002669304, 65.26743950382357, 60.22217712094707, 58.57154569318218, 55.28024565789008, 57.23452737254482, 55.930119637520086, 57.281101595970895, 48.25458641975157, 46.23996296236592, 44.16761006078413, 44.04978206080776, 44.64659421674667, 45.03189648351362, 43.861876995332786, 44.786301197544226, 45.09022212797596, 46.2162483123041, 48.46577467456941, 52.32594390069285, 51.55809679339009, 51.58140743932417, 51.24336188839328, 50.02757618504186, 48.603132155633745, 49.7608079448823, 51.085196233564815, 51.822554757518155, 54.74501863602669, 56.46273828321888, 58.63637462739022, 62.00305477265389, 59.93063911314934, 60.201922001377234, 60.602603881589836, 57.87207334272323, 52.90697243905837, 48.243466500313055, 53.187637636738444, 61.21587038040162, 63.20728909584784, 64.28114383451401, 61.4389394944714, 61.428835468907515, 60.44226915605607, 56.80558089287051, 56.93426601348385, 57.95318011314639, 64.61592205109136, 66.77865812855383, 65.9723678711922, 48.76197245813186, 29.215766383755593, 16.070584058761597, 20.956823748926965, 47.43578772391043, 65.42510701764014, 57.504398207510675, 59.39613772976784, 63.65445890734273, 70.35715410786291, 60.71816082923644, 65.85183343579693, 44.65534894697128, 22.73635014410942, 25.44349551200867, 35.722209715074115, 40.94845025770126, 31.439193294894313, 53.73022694741526, 51.19202198520784, 1.6828793167106568, 0.2394126193417657, 0.10397701539219388, 0.09502661098996479, 0.06256373479000985, 0.06449789229419924, 0.03661025788695101, 0.038492964926145734, 0.055378753196207754, 0.049352192304908275, 0.034775377716869116, 0.1759338231697198, 0.05277190154658691, 0.07535829178748593, 0.042144871587234164, 0.05647171551602022, 0.12747025072214105, 0.16455041545052684, 0.16283362773397278, 0.14731890702199552, 0.14701270167866062, 0.17266244387194035, 0.24211139388142094, 0.0679462762068837, 0.13966967231563984, 0.24936509739247062, 0.09070811207376181, 0.12699031195933783, 0.15612012346185025, 0.15358736017538657, 0.15173048562099858, 0.17446178522321487, 0.10923703636733756, 0.1484062309346853, 0.22395239812472176, 0.13543358913833095, 3.3842660919312513, 82.17165470123291, 67.11638988987093, 59.62508647672592, 41.826994496007124, 64.27110648924305, 24.348089310430712, 44.574787386002086, 67.1329422919981, 83.46757442720475, 81.58614681613061, 73.456587483806, 89.88685484855407, 81.06727215551561, 81.7566208685598, 76.02054672856485, 60.58895795576034, 10.555419768056563, 5.28245791312187, 37.28500358520016, 69.3674224422824, 79.04336837030228, 83.24334821393414, 75.08586160598263, 68.93104307113155, 64.90895448192474, 62.61182231287803, 72.66164856572306, 71.41585673055341, 76.6019125907652, 64.95601900162237, 66.26937758538031, 70.91023968112084, 75.66518783569336, 71.5741479012274, 71.94714177039363, 70.03919893695463, 72.18570032427388, 68.0506435517342, 61.66444832278837, 62.15811783267606, 69.14872677095475, 67.0036688158589, 69.08578057442942, 68.88667321974232, 64.84285469978087, 61.681102706540024, 57.4528504187061, 52.82903494373445, 51.285876458691014, 51.416852243484996, 54.75671514388054, 54.78796858941355, 51.5644431883289, 49.80865693861439, 47.57800502161826, 48.29846989723944, 48.79805826371717, 52.48008128135435, 62.90348191415111, 66.93876143424743, 62.2045704626268, 57.68302686752812, 65.10956802675801, 63.00695011692663, 65.06987364061418, 64.16440233107537, 64.19612253865888, 61.89529549690985, 62.32048042358891, 66.30445926420151, 61.159521610506125, 59.40500620872744, 57.364036190894346, 59.36500195533999, 56.98846532452492, 59.22229043899044, 50.595943312491144, 47.66083371254706, 48.135585631093676, 45.946769714355476, 47.668953018803755, 46.78129319221743, 45.762998827042125, 47.31709288012597, 48.615683740185155, 49.57923358486545, 51.99508413191765, 54.49325346177625, 55.001023892433416, 52.58230217041508, 54.0889080878227, 52.60462830143591, 51.1215252261008, 52.551648847518436, 55.57270934504848, 53.21153663819837, 57.95811837719333, 58.06734854175199, 61.20700190144201, 66.17042403067312, 62.0669109590592, 61.09001328868251, 64.32035576912665, 61.12291805205807, 56.35889353290681, 56.02289938157605, 57.22291323446459, 61.47304450311969, 64.58115023951378, 66.67717856745567, 65.17271426416212, 64.56386827653455, 62.974606252485714, 59.85745945284444, 62.05864652510613, 61.93013398878036, 66.33037044155982, 71.05923483448645, 70.36375153449275, 51.16594606830228, 30.79775437231987, 19.10604161600913, 23.14977384382679, 50.7408356666565, 71.19840052820021, 62.2593306726025, 64.23692695556149, 67.0242847934846, 74.11457292495236, 65.03538423968901, 70.45576249399494, 49.560731764762636, 15.503202426818111, 42.71107712099629, 53.598360784592174, 40.77368513230355, 51.96094382193781, 59.82224441343739, 71.87787271315052, 4.911314912380711, 0.4269778482135265, 0.3120011049172571, 0.14877995926766627, 0.18955089812797887, 0.11485433776772792, 0.11321605874165414, 0.21998784715129485, 0.18956796656693184, 0.14171376343696349, 0.18901310440513397, 0.2635746647513682, 0.1449442029960694, 0.1873081297643723, 0.12005325557003099, 0.2678746856268375], [0.04250810834609213, 0.07694962494555982, 0.07253594726564423, 0.007029154521953916, 0.017981841754648956, 0.021030109435800585, 0.020439714200854785, 0.11437603843308265, 0.03557543781015181, 0.016171244656546943, 0.07730154275533653, 0.09685577614413154, 0.04745931927895835, 0.10180442834333067, 0.05666190067366247, 0.017489364047745065, 0.07025948635512783, 0.00766539772514314, 0.04094108315785566, 0.003557345316362297, 0.07424142752443591, 22.175647327976844, 61.04819690027545, 42.287441530535304, 40.48233932064426, 38.010936244841545, 36.55908661503946, 16.31739429889187, 86.57071052059051, 77.87651031248032, 72.25587152665662, 68.54257152926537, 66.71779078821983, 65.04403698828914, 65.1827790660243, 65.64052750987392, 57.12953336777226, 14.361962349184099, 2.980085457524946, 31.554238373233428, 62.12194573494696, 69.11160545964395, 70.73800840685445, 67.6641567291752, 68.06339125479421, 64.40170964887066, 55.181554901984434, 66.08899562589585, 68.33336799375473, 71.24944625362274, 64.53262659811205, 65.95627830874535, 67.92195843112084, 68.14106202894642, 66.83701515197754, 67.34738611405896, 64.95450888910602, 62.87916714145292, 56.382706242222945, 55.10826541531471, 55.390001420051824, 62.10170238248764, 64.69607176319246, 64.99176748337285, 65.69259305154124, 59.12590603674612, 51.0970417914852, 48.46149929108159, 50.105741177835775, 49.660426647432395, 50.88365700937087, 50.771441921111084, 48.64871401940623, 45.345164422065984, 43.996677091044766, 45.85946167668989, 43.71461552958335, 43.68134598578177, 50.8981893908593, 57.459024229357325, 57.86902566109934, 47.46278147543631, 61.90603494644166, 61.3269244470904, 56.20230859325778, 59.42016616944344, 58.85259528313914, 60.371591967921105, 60.522469858969416, 58.87390944265551, 59.529211982604004, 60.48450916044174, 56.65085123431299, 54.48640108108521, 55.2300157854634, 54.350655694161695, 56.60375141328382, 49.46873649474114, 42.81129760126914, 43.88449338174636, 42.34375107672907, 41.35263481447774, 40.8373648120511, 42.178580068772845, 42.64036463152978, 42.400880398288855, 44.77335345360541, 48.228792913498424, 50.60060701062603, 52.34468890774635, 50.13982265226303, 49.414878429905066, 48.73332346639326, 47.35011139223653, 48.569289945787006, 48.86703314319734, 48.969642346905125, 49.86882609705771, 50.46576769121232, 51.38015847052298, 56.14945465518583, 57.752837211855, 57.03082300001576, 58.47832272129675, 58.183078073686175, 56.47729419892835, 46.33608848817887, 34.085051628851126, 43.06522007911436, 52.36812114715577, 55.68315936673073, 55.100808989617136, 55.63283927979008, 59.39718892497402, 52.82623044906124, 54.492386617968165, 54.71849164655132, 60.37631057923841, 63.79479346736785, 58.8344935447939, 46.84200756011471, 36.67394538079539, 21.306922743397376, 25.35105505297261, 40.62061071395874, 56.08867752936579, 52.80686570752052, 53.11021789427727, 56.78323514999882, 61.141200219431234, 55.86619284845168, 53.347784088503936, 17.604987813580422, 11.541266325981388, 48.26227034291914, 30.6762844516385, 28.132778406143192, 31.07608183737724, 50.315489922800374, 20.255127414580315, 0.46757851637178854, 0.039975881321175445, 0.1536808075803903, 0.0948415547909756, 0.0610800791201332, 0.020485227484436288, 0.0708666263568786, 0.019842447157228188, 0.04645449920527397, 0.05884559216698813, 0.05450623267660699, 0.07357033450276622, 0.030741739019210783, 0.02023070243247334, 0.014448012225329878, 0.02747424187198762, 0.03708530134791809, 0.028367280141420426, 0.03177949895841941, 0.055615635243274515, 0.02231841268498571, 0.027070570992486134, 0.043361530293740576, 0.05173450358392251, 0.04827092431725995, 0.026324227069234176, 0.04346157371577236, 0.10847649491962888, 0.07097872800283855, 0.027649076542847102, 0.00983988515086352, 0.016160113399007147, 0.06105725736086888, 0.1273621633769043, 0.061184791848063476, 0.012629660402214336, 0.20484320819377902, 25.02772427374317, 78.81495306568762, 48.2144291939274, 43.4543780357607, 42.34366478458528, 35.549939217105994, 22.49806811732631, 84.75804990337741, 82.05419540405273, 80.34881945579284, 73.80670609012728, 73.2088113600208, 70.72732387050506, 69.65171583237188, 72.24603422226446, 64.21970382813485, 16.673158176483646, 3.1420158522744335, 33.098285275120894, 66.63911588730352, 74.39960372063422, 75.3455303561303, 71.68762991505285, 70.80180968007734, 65.60153522799092, 57.93955772153793, 68.13341340711041, 72.20461399324479, 74.24307761653778, 64.03408942684051, 66.62601517092797, 69.55746127713111, 70.2401811845841, 67.26112534922939, 69.42359862789031, 68.79614491616526, 64.58939898398616, 59.425932053596746, 56.840639037470666, 57.46498230964907, 62.30786215874457, 65.49153235650832, 68.60783976893272, 65.37655199727705, 62.89851227114278, 53.518152236938484, 49.73424565407538, 51.19094725578062, 50.83581193800896, 51.69810187432074, 52.967192588313935, 51.49368363042032, 47.47665097636562, 45.97250438505604, 48.586230662561235, 47.06995610267886, 46.88128225265011, 53.502141121895086, 57.50445704306326, 62.893146468747055, 51.868179767362534, 65.24865527306834, 65.09915021158034, 57.621351518938624, 62.21570214917583, 61.75692212197089, 62.171520571554865, 62.72155061844857, 62.01244492684642, 64.46087468054988, 63.708375807731386, 59.66851103690363, 57.22161492993755, 56.22692538845924, 60.11481792696061, 60.1678797506517, 51.19190431410267, 46.17715404879662, 48.354069494432025, 44.72006413244432, 46.122684094213675, 43.42045737851051, 44.93820674957768, 46.194443856516195, 44.478501043012066, 47.396218853612105, 49.9511605693448, 53.17427412156136, 52.38343800267866, 51.20489520411338, 50.60329383419406, 49.33368144496795, 50.72305164029522, 50.465477435819565, 50.59113056428971, 50.1556101922066, 51.40857996479158, 52.02162681087371, 55.103433055262414, 57.44138140832224, 60.53417813393378, 59.29424239743141, 58.72784429980863, 60.5812426536314, 56.44170261198475, 49.92186438652777, 39.376532954554406, 47.83290024726622, 57.94142869211013, 59.30167528890795, 59.00374381772934, 60.557222058696134, 61.909266979463645, 57.61172994490593, 56.971442237977065, 58.66293299582697, 63.101236051128765, 66.18498386875277, 61.55792067127844, 51.6955719455596, 39.038475636513006, 26.00005630523928, 28.70458152986342, 48.222838755576845, 62.76759532190139, 57.217206185863866, 57.33625404296383, 61.7114540069334, 65.77393124180456, 62.30559895115515, 59.328323871858665, 26.19591593742371, 18.75232227386967, 31.087321389106016, 36.54582508148686, 31.26165505378477, 35.26832088347405, 63.83432311396446, 20.644242225154755, 0.43437813498800804, 0.12549526839246675, 0.014491324921348884, 0.07587628213748818, 0.07949981673230087, 0.10695306013428396, 0.1002180747567646, 0.07644897116528404, 0.0798136676331201, 0.009487586212344468, 0.05194712362642731, 0.08359723033443575, 0.04258046535054042, 0.03416731074872998, 0.0558952420138784, 0.05210920484856733, 0.1299093904033784, 0.24292258906268308, 0.3105248841306856, 0.1437222314698081, 0.14990692056955832, 0.12086123318201113, 0.11711424351820063, 0.18034017704907926, 0.13922759361805456, 0.11185778485190485, 0.07362611336453308, 0.2293218930642451, 0.1616211097326971, 0.1397890901012767, 0.18933826276371557, 0.14180725680724268, 0.13408780248174745, 0.14690992332273914, 0.17649784774309205, 0.1567073604993282, 0.3812769650211258, 45.01219834050825, 88.50859672792497, 61.97759466786539, 59.956711107684725, 56.73477034414969, 51.91300461369177, 20.797400974458267, 101.16207661167269, 91.1982757814469, 86.2724691821683, 78.69612093894713, 77.87483153804656, 79.65149264181815, 78.56438421433973, 75.82118049744638, 70.24685705861738, 18.49208478004702, 4.295301283559492, 38.01059892100673, 68.6088909641389, 77.71310437110164, 79.26160904668993, 74.1117488184283, 73.37049145852366, 69.08163070678711, 59.82458999080043, 70.79620853547128, 74.71910430539039, 76.79534819818313, 63.791898758180686, 67.54847034331291, 72.38220322516658, 72.40995791650587, 69.80555903527045, 74.04167959767004, 70.3147925100019, 68.88662615130025, 62.531931477208296, 59.79516436976772, 59.78475439933039, 65.51113636262956, 67.60224603837537, 70.49671988333426, 66.87979252107682, 62.600110115543494, 55.92924494897166, 52.374475386834916, 54.17493743281211, 54.031939583439986, 54.932778573805294, 55.63992700269146, 53.236271104504986, 49.431034672644834, 48.33336722466254, 51.68765268018169, 47.29053451168922, 50.016789667068, 56.481330317835656, 62.247202704029704, 63.071877110388975, 56.03106967864498, 63.70149989281932, 65.5340547715464, 59.60765938605032, 63.72531652450562, 65.52770445423742, 63.95179025588497, 65.01056348123859, 62.70262518236714, 65.3691347952812, 65.17524811529344, 61.62262016727079, 58.61665295016382, 59.07889643023091, 60.623592484381895, 63.13766310291906, 54.365556778446326, 48.921789430802875, 51.66417337233021, 48.29324922254009, 49.8555802529858, 46.23041199099633, 47.52551586397233, 48.06131947425104, 47.73840250507478, 50.31422691960489, 50.87712234066379, 56.371794208403564, 55.64634400029337, 53.49294708621118, 53.59527780163673, 52.19865906623102, 51.62544781161893, 51.631417659021196, 53.84190467096145, 52.85893124918784, 53.94616519251178, 54.712137406872166, 57.22663948612829, 59.26687602073916, 62.90756117913031, 61.82301013700424, 61.78194684367027, 63.37046753975653, 62.52514969918036, 54.47966637149934, 49.62751403931649, 53.22995608852756, 60.69547384015976, 58.85376022708032, 63.83728842581473, 64.71498150979319, 67.5160558762089, 60.29465075462096, 61.37894292031566, 62.64235796466951, 68.3576709993424, 71.06438882889287, 67.08794486138129, 57.25808905016992, 41.71776825381864, 29.607636659376084, 32.55782385026255, 51.48500734759916, 67.71754803196077, 62.367003656202755, 62.591386764280266, 65.6934206716476, 70.04507464747276, 68.6127741106095, 67.34186341685634, 23.385314133859453, 15.137449252989986, 65.23418564950266, 41.65353159750662, 41.42699118583433, 48.81637965479205, 70.5654162745322, 38.37886633411531, 0.5533723352897553, 0.18908042821191973, 0.26602773957194825, 0.2612093836069107, 0.2634887403297809, 0.267309925609058, 0.17018398089754969, 0.14187648051208065, 0.12241425428299174, 0.17541305192055243, 0.13070880315236508, 0.1805721331507929, 0.12416860329047327, 0.1512036469554709, 0.14111057644890201, 0.1323079963725421], [0.017802776363227638, 0.05686216754838825, 0.03790354070764396, 0.010942410163190818, 0.01893778541876424, 0.04133027497558825, 0.04278138723044146, 0.011248291834377715, 0.06670797934695598, 0.09485425652876016, 0.08381739634299472, 0.05460102073547821, 0.07749283491002937, 0.046417152418965296, 0.055664680192186955, 0.030791563462586175, 0.0375119203911914, 0.05209518543955299, 0.08115655847734983, 0.07997496744557735, 0.05633611412298295, 2.303042200303847, 68.21954865609446, 50.87295286117062, 44.4338095572687, 43.465380284094046, 46.06882210700743, 14.465137354789244, 37.13615355953094, 80.87362474010837, 65.82662044032928, 79.135755877341, 70.50880078346499, 71.01557885446857, 64.09583537809311, 60.496727343528505, 59.4184011028659, 24.15823874935027, 3.474707367920107, 21.945261032350604, 58.84572721296742, 69.11698695152037, 74.95576443210726, 68.58446244270571, 67.3917402759675, 59.60782412559756, 57.77095463968093, 68.50986680676861, 69.46742719219577, 71.03390416791363, 64.45079418920702, 66.40951602689682, 65.78401957788776, 64.93083738511609, 64.06262466984411, 59.67289232438611, 60.40138629175002, 57.02944624808527, 54.29510708778135, 52.54942486363073, 55.74075937271119, 60.554539157498276, 67.04935658362605, 64.3948180444779, 62.647617863070586, 55.5689517144234, 50.55422498333839, 48.17521333694459, 49.88289956123599, 53.452668266911665, 56.447652847536155, 53.323665434314364, 53.999383911009765, 47.00078118231989, 44.49619877722956, 45.70012715555007, 43.975939519943736, 45.36598044057047, 51.09552383422852, 60.240447521209724, 51.14266287895941, 56.56589661875079, 63.31926884189729, 56.22022598020492, 62.03634392830634, 57.28852272033692, 59.292112550427845, 60.34161721506427, 60.41130596591581, 60.01956708969609, 62.17978892787811, 59.62117587366412, 57.70033628709855, 54.85651593054495, 55.072658138890425, 55.18193537189115, 55.28619589344148, 54.35144409056633, 43.75333324555428, 41.61684174691477, 43.471750213253884, 42.481445881628225, 41.70439297153104, 41.064791679382324, 40.2876171758098, 42.925328746918716, 46.91492442161807, 50.73932555414016, 53.16680592875327, 50.297246979128936, 49.50069988927534, 47.59400044718097, 52.9695930788594, 55.61293325116558, 55.18080572928152, 56.417207410258634, 55.37303716905656, 54.93343753199424, 54.249890004434896, 54.43693214847196, 55.84024636976181, 55.20226109412409, 58.625556730454974, 61.703209184831195, 61.13757202702185, 63.334734747486735, 62.831729996588926, 43.439296522448146, 28.366775243513047, 30.202211103131695, 41.69757196980138, 51.70722530734155, 57.24167393099878, 58.91884019297939, 53.9258159360578, 53.24839122833745, 55.10609242223925, 58.455490604523696, 62.32201799269646, 58.32673095887708, 52.13320255279542, 41.242482892928585, 29.028641869944913, 32.509394345744965, 44.21465889100106, 54.97446944636684, 53.69410191812823, 54.63600812419769, 64.58440972912696, 58.067623107664055, 59.284161906088556, 46.65440059477284, 10.475829974297556, 28.250780951592233, 44.48714202450168, 27.527135033761304, 31.897967438544, 32.52655863761902, 50.865343463036325, 3.3433302756278747, 0.278969538668471, 0.019944216192309416, 0.04656673491662068, 0.042428450523725444, 0.06881862052626188, 0.06956970078810569, 0.01451892706926071, 0.13405694446015742, 0.04052568347223344, 0.04749272837333622, 0.0430143813812925, 0.07771991103166535, 0.07331420832704152, 0.03951527861758106, 0.0751068310872201, 0.043620716990722765, 0.14710339116713694, 0.040952348480782205, 0.07744493143212411, 0.040378380086152785, 0.016766902915532553, 0.15629753410335512, 0.04722683840701657, 0.038923609761461135, 0.03773879349952744, 0.0581350302954595, 0.021566286713125247, 0.04031403253095285, 0.061663658087772716, 0.09729082215457194, 0.024075427678443735, 0.053679095205640605, 0.044925234490825285, 0.010620909874447653, 0.023395045840692137, 0.17137788296226533, 0.22098624357773414, 2.7684882956166423, 77.24166685535063, 59.61092672040386, 47.30715359410932, 47.67033369310441, 46.24551311615975, 23.598155667704923, 45.62202099830874, 88.31500422570014, 72.84556065836261, 84.82901342453496, 76.18743573465656, 77.82690017454087, 72.2057044121527, 69.20942937174152, 64.91111178551951, 28.154276917057654, 3.884490127525022, 23.079131957023378, 62.616027093702755, 75.15432265497024, 75.5971896263861, 70.8161106417256, 69.25106925349083, 61.771885964178274, 58.279548768074285, 72.21916598658409, 72.03413994081559, 73.68144912104454, 66.554973202367, 69.37720483349216, 70.07795195425712, 68.58489390342467, 65.96132247678696, 61.638031159677816, 61.79611836710284, 58.99029793277864, 57.37016293310351, 54.70548114468975, 57.52926211203299, 63.12870048707532, 68.30416202545166, 66.17269116063272, 64.03474838502946, 57.874187500246116, 52.236019642122336, 49.973761266277684, 50.371556282043464, 54.99154352372693, 58.06678372044718, 56.572129264954604, 55.26300291861258, 48.538507184674664, 48.98387270589029, 47.98452731101744, 48.76230978196668, 48.67430356241042, 51.79342723661854, 61.15727409239739, 56.814833764107, 58.803573500725534, 69.72935522756269, 60.25532899364349, 64.3399715423584, 60.270343826663115, 63.047503502138206, 62.969973933312204, 61.82143726656514, 62.762880632954264, 65.0666259181115, 62.90279157700078, 62.26067212320144, 57.715127545018355, 58.655668766267844, 58.503739680013354, 59.47275338634368, 54.982035698429236, 47.523138907647905, 45.230203674685576, 45.971194313418486, 46.915159763828406, 44.42076767644575, 44.07623844762003, 45.45374347317604, 46.235609131474654, 49.14127742090533, 51.58170946182744, 52.76216245466664, 52.32472404356926, 52.1572623714324, 51.73083797577889, 53.95526901368172, 54.887871357702444, 56.13762478674612, 57.87368935923423, 57.16315592488935, 56.37550477058657, 57.44691587263539, 55.568994860495295, 57.46372715119393, 56.805106286079656, 61.19852173712946, 62.678639888763435, 64.7457956498669, 63.17628275963568, 61.391965189287745, 47.35335519236904, 34.798362101278, 35.64941052467593, 46.78580784028577, 58.22282737301242, 62.079937150401456, 62.8087527521195, 58.57962185336698, 55.07143828176684, 57.178555150185865, 61.7342939684468, 66.62838428251206, 63.120275235945186, 57.14277921184417, 43.71385851214009, 34.58587161956295, 36.908656089536606, 50.61183283405919, 59.12810648641279, 59.49134934333063, 59.50636417635026, 70.22231871081938, 64.13952273707237, 64.37099749042143, 51.42201016026159, 20.066357466482348, 26.679659889590358, 32.043687412815714, 33.49630386598649, 30.89336410645516, 41.46992152737033, 59.953345714076875, 4.311246208606228, 0.3701699771467717, 0.1093083821357258, 0.00892754146573885, 0.04763818165707973, 0.06988699908458418, 0.015773365401753014, 0.041220758876372735, 0.09735951725874217, 0.032167223717777, 0.015955697200561485, 0.09853261237543437, 0.01043262844529724, 0.04727735807518325, 0.05908905490932446, 0.007104337912037849, 0.05213231389080325, 0.15797004193788575, 0.18714072423115855, 0.1429106072793084, 0.17116846516728404, 0.073392755321918, 0.27804575920585667, 0.14000209318774362, 0.16915420550973187, 0.11370619413472953, 0.15973078777953503, 0.20137891263490726, 0.16066523118605539, 0.21457549725328723, 0.19733620537144525, 0.150272972701538, 0.15529368313089495, 0.22545229102815353, 0.1280590812225015, 0.11012079539678751, 0.23959588289501207, 0.4065899809281672, 7.293475731726616, 99.42099140536402, 67.22777735802435, 64.391770362854, 55.81853605085804, 63.811420394528305, 17.286397218704224, 50.32537429563461, 91.05758036336591, 79.3591348586544, 89.14591912300357, 83.20259478784378, 82.73795081723122, 79.01413886777817, 72.78085724000009, 73.33861043376308, 31.04744265156408, 4.497013582337288, 24.54825962743452, 65.22908656827866, 77.6486990528722, 82.17250193319013, 74.55307822073661, 73.63920519428869, 65.34203906213084, 61.71072836845153, 75.64676838536417, 77.85071680622717, 74.95529374768658, 66.67913975254183, 72.10615465717932, 74.33892465406849, 71.6298298681936, 69.26319722206362, 64.62563383963801, 65.12670878441104, 62.91234647074054, 61.29862846866731, 58.254531891115256, 60.18276906782582, 67.23856387599822, 69.86185289198353, 67.65220134488999, 65.34569863350161, 59.98346559463009, 56.57124673166583, 52.43784912170903, 54.3026811845841, 59.02206128643405, 60.744374029098026, 59.46337892163185, 59.07993193595641, 51.192539738070586, 50.81030084240822, 50.486713147932484, 51.705495542095555, 48.95205836142264, 56.77814783588533, 63.93717158225275, 58.0664542413527, 61.42871779780234, 68.7266169824908, 63.315428841498594, 66.81068820338096, 63.39990100552959, 64.43477915179345, 64.5714972865197, 61.45998693281605, 63.40288200686055, 66.5127920335339, 65.45597607089628, 64.78368574573149, 59.21932904951034, 58.07671516172348, 62.25633398179085, 63.17243099212647, 61.45959469579882, 49.86285232728528, 47.720190940364716, 49.51111378208284, 49.48033886571085, 46.87094680724606, 46.586198422216604, 47.12069588322794, 46.95452859324794, 52.254635210960146, 54.22945445583713, 56.563460826873786, 55.150819209314164, 54.88820083679692, 52.853789021891934, 58.81836083627517, 57.89992217094668, 60.764005491810465, 63.099188573898815, 60.76424867876115, 61.147542691999874, 58.797101589941214, 58.728424810594134, 60.26695097646406, 61.86045700503934, 64.24272814104634, 66.92793569257184, 67.47927973347326, 67.08537178654825, 68.9996688596664, 48.570039118489916, 40.44954438363352, 43.11635994142102, 52.395283560599054, 63.09861198548348, 66.95812225341797, 65.87083339691162, 62.43618642130206, 59.588506452498905, 62.18626868340277, 66.61886861247402, 72.62162470048474, 66.94535101613691, 63.411856389814815, 45.747760418922674, 37.98480933712375, 40.33704688472133, 53.48888743308283, 63.77274190225909, 64.16274316849248, 63.15190130664457, 74.26509780268516, 68.54152817879954, 72.14562154585316, 56.348852265265684, 13.75074823056498, 35.817327191752774, 64.03094368596231, 38.77229967424947, 46.21016863853701, 50.22775042441584, 78.01336180779242, 10.927675251037845, 0.7371642440557481, 0.20815707472783906, 0.1413632475680882, 0.14748145555776937, 0.15444540929409767, 0.162343607254086, 0.1152222131889674, 0.29687905023174904, 0.18031010043717202, 0.1720633784369115, 0.13312551944005874, 0.16431583932811217, 0.19495344210055568, 0.11872962417621767, 0.11529893689458409, 0.20183640502152905], [0.07165284707180916, 0.05005304784243626, 0.05370277115294049, 0.018628146086308747, 0.08838148772596352, 0.06193690249816545, 0.03571121157297204, 0.026597714712542873, 0.0690742717274735, 0.057094958685939355, 0.048814662882397254, 0.022625050867997834, 0.15521598649361443, 0.009675515241049712, 0.05199335703265764, 0.04301327821468154, 0.04877837329742409, 0.0195905095672295, 0.06848479005237741, 0.06584888834866785, 0.08306505969695507, 0.05768272815452469, 36.49021763955393, 64.85640256635605, 38.05790662765503, 40.30671519617881, 49.11554275020477, 21.5434318588626, 18.111975731388217, 69.24531121407786, 78.25830598031321, 72.6475437225834, 72.39280146937217, 73.85163291808098, 71.75722060665008, 66.19481332840459, 62.24145250935709, 34.337322788853804, 5.9328584709475125, 18.145737532646425, 48.22209742761428, 74.23010241600775, 71.79813092754733, 69.82452761742377, 67.76123539094003, 57.6553584683326, 56.36426325767272, 68.79923574386105, 69.96275978703653, 68.28453448510939, 68.41727533648091, 64.37152701039469, 65.53370175823089, 64.08908105665638, 61.935691987314534, 66.68641967158165, 65.84943294525146, 66.3749756351594, 62.83557784172797, 58.662764333909564, 56.20844710257746, 60.376796953139774, 62.18968114545269, 61.350246860134995, 54.98251030522009, 52.0848201167199, 50.55662939625402, 59.476907176356164, 60.421935589082786, 61.51313504865093, 62.9765203691298, 60.972742265270604, 54.69108604615735, 47.368068002885394, 45.03133166220881, 41.934267397849794, 44.568444913433446, 47.06699863556893, 53.77328672716695, 57.02722226419757, 50.50230064699727, 61.84318288680046, 57.53367477847684, 57.676241167130016, 58.5088622954584, 59.181544857640425, 59.043751993486964, 60.70784107331307, 58.75656389421033, 62.632642253752685, 60.31941267751879, 58.48317077082973, 56.63784857719176, 55.011006324521965, 55.81524125991329, 56.470230010248, 54.268893887919766, 59.2794668289923, 48.25645346795359, 41.1072160351661, 43.303578592115834, 41.58050883200861, 40.93971906169769, 42.88961948886995, 41.925598959768976, 44.43230336712253, 47.02310731334072, 48.72853033004269, 49.68002673118345, 49.78209464780746, 52.31936608591388, 53.48289012908936, 54.7434026195157, 59.46161385505431, 61.95078134536744, 59.44739526317966, 61.338785694491484, 58.56602299597956, 57.8093271870767, 57.94611984683622, 58.98015468351303, 57.51618885224866, 55.670505800554835, 58.09653097583402, 61.576414646640906, 61.434648421502885, 64.74463855066608, 61.6632676893665, 46.11583563589281, 27.399242231922766, 29.51851844787598, 57.31286494962631, 63.022545460731756, 58.7786703725015, 53.84124179040232, 54.615576497970096, 55.20950571183236, 57.37975705054499, 60.70695461765413, 60.90596391308693, 58.41665521744759, 46.266839042786636, 35.928271432076734, 30.730921106953776, 44.25252937501477, 52.15418723321731, 49.99483616121354, 53.664664529985004, 60.637532587974306, 55.59500017473775, 65.40341238821706, 26.32997274398804, 10.962349983953661, 44.93241340883317, 36.936524529610914, 45.65353332027313, 48.26012088406471, 40.808598149207334, 32.23787611530673, 0.5537426928358694, 0.08620917646875305, 0.07290214495432955, 0.03699968719194013, 0.05545078461328822, 0.019359091642282663, 0.050223398983718893, 0.07286534209044711, 0.04755121535591541, 0.06402053524770084, 0.028875186859119325, 0.04049253484774982, 0.03480498318470294, 0.04555602745723821, 0.08724825982485088, 0.02835066369434278, 0.00887163236902486, 0.08329604286700489, 0.036645386848718896, 0.053293496340272896, 0.06948048984932323, 0.06708127867069937, 0.03736658202063653, 0.024935175597126928, 0.04995581979352621, 0.0251397363946683, 0.06445046379080703, 0.064001735450039, 0.06181702122933442, 0.05521361145281023, 0.04634928468975329, 0.008940747863943539, 0.11350251433830108, 0.014133260213589717, 0.08209315459093741, 0.037370795504220074, 0.09922661142604006, 0.07457409354467547, 0.07387713739468206, 40.250844955444336, 78.01995923442226, 43.15823516538067, 48.101017782765055, 45.52338907795568, 24.997916221618656, 35.304787158966064, 67.82681742022115, 86.16295660695722, 78.69588559673679, 81.10749213926255, 78.74165965664771, 77.94337887917796, 71.53857984850484, 71.6471432101342, 39.0580992544851, 7.386067202014308, 18.60298195192891, 55.688030950484745, 78.23014336247599, 73.87195864031392, 73.04275389640563, 69.8230214272776, 59.11480572915847, 59.213602389058764, 71.38639973055932, 72.0982785378733, 71.00454130480367, 69.86984668239471, 68.25834874183901, 69.32869295920096, 66.38352640213506, 63.20304116895122, 66.1527027622346, 65.89429701528242, 68.1283692390688, 63.87344091169296, 61.71251304687993, 57.95804385216006, 62.59323027826125, 64.23562865103445, 61.62703675608481, 57.51016016929381, 53.60185953878588, 51.371874424719046, 56.99220334329913, 61.28964231860254, 62.8795515337298, 63.36760028716057, 61.372663205669774, 57.823412418365486, 50.50314003421415, 47.238974955774125, 44.43529613556401, 46.437850459929436, 48.23286433373728, 53.9373359372539, 62.22200147567257, 55.0225341704584, 66.11549515878, 60.61490051208004, 61.19433264578543, 60.88378290976248, 62.245206217611994, 62.7273557263036, 63.64439410548057, 62.790458817635816, 64.15298823387393, 65.02502133769374, 62.96653401467108, 59.73222601798273, 57.74108971318891, 58.99289846420289, 59.970690434978856, 59.13630816244311, 61.282056454689275, 51.79864398894772, 45.21562814712525, 45.41652018024076, 46.171709798997455, 44.404140749285304, 44.7448339000825, 44.96354133852067, 45.556748836271225, 50.76881393309563, 52.947878837585456, 51.68635829802483, 52.721589457604196, 53.526440205112586, 57.08606566152265, 58.0225472296438, 62.08259651737829, 62.324010556744, 60.282864032253144, 64.26110052293348, 61.388686087823686, 60.85423177288425, 61.67947492291851, 60.71721161565473, 58.927492941579516, 58.51384762794741, 59.2258950971788, 64.0709283274989, 63.01379465287732, 63.751949417975645, 61.18381677135345, 49.49219226837159, 32.98695664252005, 36.89014642469345, 61.748689066979196, 67.40264446504655, 61.98827920421478, 54.39744957031743, 57.110627543541696, 59.76260869733749, 62.35026690267748, 61.11018603847873, 64.72102588222873, 63.4323311621143, 49.52241413054928, 39.974863067750015, 34.92005755824428, 49.54991779019756, 58.25635971561555, 55.774648651, 59.31078695481824, 65.51684733360045, 62.10777813388456, 69.13587708627024, 34.22606868128623, 19.908531096673784, 30.024949389119303, 34.352278786320845, 54.03148851087017, 48.37098275461505, 51.90522655364006, 38.99592576488372, 0.691151655008716, 0.1467831817365462, 0.03617569451190291, 0.036862132274695945, 0.04276727206043659, 0.09333635289822856, 0.06087324687189633, 0.02257906835556271, 0.10642590737270732, 0.114232205425299, 0.050216546327236204, 0.06101727140166106, 0.017460413585086505, 0.02792576451845948, 0.058191184540309256, 0.04480211267007455, 0.04134583805177001, 0.12671860355523326, 0.14619453509728755, 0.2174134240035088, 0.26550113073279785, 0.24496407548506416, 0.31873958365571115, 0.14408207828960112, 0.12914196948610968, 0.2260824136676327, 0.17373058494300614, 0.1385558264390115, 0.17204019661632278, 0.27922642327124075, 0.12239216796813474, 0.1321032517138989, 0.12649791660688578, 0.1280684734604532, 0.12931207164881692, 0.18175213838056212, 0.23308721521208364, 0.2525032693219762, 0.15726072112879447, 63.10995548002182, 81.51799955675679, 60.23021797980032, 53.2670852445787, 69.74833165445636, 29.912779408116496, 28.48262440773749, 82.34780834567162, 91.87986604629025, 84.2815839090655, 85.24444733896564, 86.03114143494638, 82.6992448683708, 78.49120063166465, 75.49578066795104, 43.306677264551965, 7.807980871969654, 22.033320203904186, 55.834060792000066, 82.48475397786787, 77.34136566039055, 78.58171324576102, 74.5907800428329, 62.55237094817623, 60.62276486427554, 75.9661199200538, 75.91219517492479, 74.97099107311618, 72.92057206553798, 70.91104768937635, 74.32124260933169, 67.76350252089962, 66.45249735924506, 71.21119529970231, 70.13898403413835, 69.37696164654147, 68.68863274974208, 66.57486746388098, 63.1490065974574, 65.41788985652309, 67.6138170303837, 64.81661404332807, 58.55342826535625, 54.289019569273925, 54.63570217932425, 61.79555354579803, 64.424047547002, 64.50991607481434, 66.93904384489983, 64.91294353238999, 58.38011833929247, 51.82454339919552, 50.138543959586855, 46.878509136938284, 49.78145922383955, 52.105145838952836, 57.57818191282211, 64.61449430834863, 56.099114956394324, 62.122204611378336, 62.95962279842746, 63.040039231700284, 62.89573131069061, 61.66023961959347, 62.61795689982753, 65.38773075226815, 65.07753010719054, 64.84208983759727, 65.5551100546314, 64.30940058923537, 62.51805020916847, 59.227773912491344, 60.46514049653084, 61.77608290026265, 61.90115159557712, 64.69624042510986, 56.65207893617692, 46.378606980846776, 48.58536381875315, 49.36689607558712, 47.30241929331134, 48.616699634059785, 47.73547249455606, 46.504848464842766, 51.990671465473795, 54.42798522210891, 54.041816111533876, 54.532233976548724, 57.42929658582134, 59.278996144571614, 58.784012640676195, 66.67054191712411, 65.76350558188655, 62.158270805112785, 67.46030330657959, 62.95834410575129, 61.55588103878883, 62.14824914932252, 63.31840984282955, 61.111154863911295, 62.45510009027297, 63.25935071514499, 69.0169272884246, 69.55779860096594, 69.3162904247161, 66.09014095798616, 52.613912551633774, 38.31386481561969, 45.30658791142125, 66.58395167320006, 69.84866588346421, 66.46142467375725, 57.851516200650124, 62.20912825676703, 62.03591246758739, 66.9536429066812, 68.0410494342927, 69.709194244877, 69.4339144614435, 54.057666409400206, 44.51809344753143, 38.936890171420195, 52.68741776866298, 64.12657107076338, 61.08020344088155, 63.425961232954464, 68.07765299274077, 65.18851749358639, 77.3045502939532, 31.851487352002053, 15.615676391509274, 56.9890340681999, 52.5516253132974, 59.13926170718286, 63.51617574691773, 60.721985140154445, 59.39880494148501, 1.8870650376043014, 0.3671295580364043, 0.12242859544893428, 0.1127797180426217, 0.25332888227797323, 0.14932228823102292, 0.13277371654347067, 0.09870497449751824, 0.25807697265859575, 0.1486773954163636, 0.13782387539263696, 0.17172796982190303, 0.21903573775724058, 0.15167621595244254, 0.15767872934379887, 0.20464256976640996, 0.12422337091618008], [0.06230822914550382, 0.03701187565081543, 0.04284822840183493, 0.014756786836040838, 0.04095085460932986, 0.053854824284151684, 0.013880670491245486, 0.08375914301723243, 0.048310871972071553, 0.0846240945881413, 0.03752792396792962, 0.03827554917323493, 0.08693197276443244, 0.03483101102193037, 0.059615924218369115, 0.05200211341763216, 0.04767540586932052, 0.04217128629886335, 0.022969715740351428, 0.07665640479254146, 0.07701737010070393, 0.6245196562620902, 7.889982433088365, 74.52796720689344, 50.57266796788862, 41.13668480227071, 49.52246119899135, 55.56140899658204, 7.915617083349536, 38.53809887363065, 62.497987285737075, 74.06358995745259, 75.64960818136893, 73.68111179720971, 73.5461744185417, 71.39636255079701, 65.69946896645331, 42.49283252223846, 8.563017518289628, 11.532818521222762, 49.41114825587119, 76.09693881004088, 76.15659021562146, 70.47968110730572, 64.18050758300289, 60.33497664236254, 57.654934852353996, 69.17726593632852, 71.08112166004797, 68.55174203072825, 68.54952981395107, 67.90856745935255, 70.55717145243, 67.14561939239502, 65.04717488442698, 68.55245590209961, 70.4484982644358, 69.99647648103776, 67.91673383405133, 64.72465407463812, 60.95316963811075, 59.01580902837939, 58.63447620022682, 56.52677097628194, 52.71509401259884, 54.50102759945778, 60.44328897230087, 64.6361889377717, 63.40427444827173, 61.72919880959296, 60.48334813887074, 62.22882247740223, 55.886138100777906, 50.50161815458729, 46.245250317358206, 45.20262549000402, 43.79031335153888, 47.54308023760396, 54.87690441070065, 55.536262681407315, 55.3904721044725, 61.18629570930236, 59.51096511656239, 60.1607253474574, 60.87531451256045, 59.305613348560954, 60.087016167179236, 61.464689854652654, 59.58359172267299, 64.0404672007407, 60.19832518792922, 59.20047029372185, 58.57156530503304, 57.81030777961978, 59.68406323463687, 58.60737654470629, 56.264344799903135, 57.71709657484486, 54.647673253090154, 42.74000067864695, 42.404751777648926, 41.72789973597373, 42.31398028712119, 40.224941622826364, 42.02371312725929, 43.660369150100216, 45.91526523713143, 48.77695198981993, 49.84866903674219, 49.01272173850767, 53.53401037954516, 58.106882110718765, 60.35739298789733, 59.43874643694971, 58.20753012934039, 58.79698391883605, 56.620017482388405, 58.864507521352465, 59.30431504403392, 59.78186361251339, 59.070953630631976, 60.449713814643125, 56.59692256681381, 57.315904786509854, 58.589439545908284, 62.18790431176463, 56.789718827893665, 59.468576062110166, 60.19372032534692, 41.173131465911865, 32.305327153974964, 59.55503686781853, 67.41990289380475, 62.83933154998287, 55.31776705095845, 53.31958616933515, 54.53486980930452, 61.394675547076815, 61.24227969877182, 62.19031264705043, 61.89804115603047, 50.86175449432866, 38.59415738813339, 25.727673192178052, 46.81795558621807, 55.37940317584623, 55.092305291083555, 58.69158590993574, 56.87947442454677, 61.20176553726197, 51.71780393969629, 11.504982440702378, 23.70307122507403, 45.1305401709772, 37.35419419503982, 35.927859583208644, 41.98292832220755, 44.682115201027166, 12.036546949417362, 0.40897036932649156, 0.01869706718641664, 0.06445740454740102, 0.027907453101849364, 0.05649357583493956, 0.022358450355128418, 0.02601182024415222, 0.0901793352057857, 0.06935007870197296, 0.016631048713480274, 0.11458806858788576, 0.027081503067165617, 0.01325203501994932, 0.07738608055778089, 0.026815438815843196, 0.052279682394357464, 0.04969237747812464, 0.010920279798278166, 0.027569652377297322, 0.01075977097160273, 0.06577273920899437, 0.021603043611732223, 0.053435287723738345, 0.011225086073541354, 0.0218396058170906, 0.02497371556537767, 0.04786858260030708, 0.03376131862281792, 0.04784677973798206, 0.04707440989272249, 0.03388144503978472, 0.040817585954022025, 0.010096806142809651, 0.09210381701949144, 0.07676814637717701, 0.07374387640025347, 0.04444845967114933, 0.12436523507799833, 0.5421702299387224, 7.9589911430112785, 85.08508143886444, 60.13253919539913, 45.28812139264999, 61.4600653802195, 41.8306815239691, 21.90009101744621, 52.90767454331922, 67.54343402001166, 83.6213940958823, 79.29039139901438, 81.78920791995141, 79.14123150610155, 77.19656744310933, 70.8980332651446, 48.169086594735425, 9.238072133833363, 15.01239134419349, 51.67892540654829, 75.53840114224342, 78.41223547535559, 73.14575533713065, 66.2576340090844, 62.26812070415866, 60.7360036911503, 72.45209986163725, 72.68568485013901, 70.61916843537362, 70.41702516617315, 68.98706236193257, 70.32276276619204, 68.99165153503418, 66.13066688660653, 68.1858084278722, 72.24776006514027, 72.81424445490684, 71.40006526823967, 65.61382793611097, 63.693349207601244, 61.46776107049758, 62.325148044093964, 58.65022451646867, 54.80036327915808, 54.74712494880923, 60.93778610229493, 66.19484470736596, 66.6744250635947, 67.08409309387207, 62.65164221486738, 62.21641994291737, 58.291637512945364, 52.34314741626863, 47.818462002661924, 49.833324724628085, 48.5362361323449, 50.52355597096105, 56.20623488580027, 58.77605807396674, 62.189892953442, 66.40123198109289, 62.94320375688615, 63.41248004667221, 63.871432658164736, 62.63106938331359, 63.5610515840592, 64.15243517967963, 60.65465373377646, 64.89668530802574, 63.785375856584125, 61.86935686296033, 62.04233338755947, 60.62739718344904, 61.99815573230867, 61.34934471499536, 59.562179503902314, 61.43291081151655, 54.47285321451003, 45.3869455091415, 45.878814651120095, 46.109277432964696, 45.649081430127545, 44.29536165729646, 43.75581218350319, 45.26891746828633, 50.78796294427688, 50.58168941928495, 51.76971650892689, 50.73395975174443, 55.7031399203885, 60.31008920361919, 60.97973977365802, 62.9075062659479, 62.19738075810095, 60.9228850180103, 62.17523897847822, 61.39695052177676, 61.11639515046151, 63.288184058281686, 60.635736142435384, 62.629559270797245, 60.27286591068391, 60.57581801568309, 62.3204686564784, 64.91693258285522, 63.013563233037154, 62.982517673123276, 58.037263962530325, 42.944654264757716, 40.30742906755017, 63.66067194169568, 66.79362589313139, 64.55960858252742, 57.898235551772586, 55.61864814450664, 56.425722875902736, 64.5616639044977, 64.45018622183031, 66.6796810396256, 64.79616280524962, 52.22485265424175, 40.56819608134609, 31.441431007077618, 54.163189934146025, 61.69551741692328, 60.34721443730017, 61.222526642584036, 62.983608092031176, 64.18152347687753, 58.03618531073294, 22.39555697287283, 26.878702525169622, 28.941853546327163, 42.61525361768661, 35.64611573373118, 45.920121131404755, 56.87757599738337, 14.371549602477783, 0.7168203195737255, 0.07817227062919448, 0.06459657207972581, 0.07115251504846158, 0.03137004028464998, 0.043489382707423745, 0.024493093069102016, 0.06457978709330482, 0.03148730919365922, 0.01028488455866013, 0.043059427351240194, 0.03465755339411478, 0.021674165299402613, 0.0873145570738181, 0.05193639456504776, 0.08368073391818232, 0.04483171813790837, 0.12263072008687644, 0.15966891851877013, 0.10591223009771879, 0.12702819500719348, 0.110206252504741, 0.15840784586485357, 0.15774110422259377, 0.3066633413395574, 0.12104796711355449, 0.23883699619721985, 0.10799122418487266, 0.18865293582841275, 0.13025200024487513, 0.14917765083091875, 0.1604879277968599, 0.19487576078503363, 0.19420885060343052, 0.3101844653006523, 0.2222913050002629, 0.16610169753191933, 0.3035368445900179, 1.1956009412965467, 15.912124226170203, 99.94454153122442, 69.22883725935414, 57.86525626336375, 66.88278136714813, 76.1721149567635, 13.297796845436098, 54.7195153851663, 72.82416020670246, 88.33156447256766, 84.8584625797887, 84.93091660161173, 85.56172786220428, 82.88018380441974, 75.75469632302561, 53.32966273830783, 11.651064253622486, 17.65484113847056, 52.653469654821585, 82.98666046511742, 82.6095324177896, 76.96711663276919, 69.87532231115526, 66.32986053343743, 61.00735325967113, 76.93741644582441, 77.61318591333206, 75.82751120290449, 72.1451194824711, 72.14578628540039, 74.52450767640146, 72.57328541048112, 67.85430539038875, 69.74713140918364, 75.81511651315998, 77.17770084258049, 73.73936683900895, 68.81780424425679, 65.72017908096313, 64.84057580271076, 65.16513624498921, 62.02617322244952, 55.35359790248256, 57.11800159946565, 64.72774490233391, 66.69316614827802, 67.57788811960529, 64.75343250459241, 64.15274112455307, 63.810981089069, 59.56738841149115, 55.45587762709587, 50.21018997315438, 51.25831788586032, 49.62407412067537, 55.90687959424911, 58.63866921394103, 63.55625844770863, 59.652119451953524, 65.83914064591931, 66.52635558958977, 67.39996156384869, 66.29593987618723, 64.86070540643507, 64.96340482465683, 64.61374121327555, 63.11807478627851, 64.53574096002887, 65.01364254182386, 63.01066067910964, 62.42112844221054, 62.06347888515842, 65.42613075625512, 65.36387489688012, 63.57197930735927, 62.54592257161295, 58.54486180889992, 47.358316990637014, 49.06482258150655, 48.630957449636156, 48.03008956293906, 45.9993451641452, 46.422851316390506, 47.323568713280466, 50.908913150910415, 53.286881446838386, 53.80712501464352, 52.66635071846747, 57.720956187094416, 62.5481112541691, 63.63018728071644, 64.01946290846794, 63.97450470155286, 62.610877021666504, 64.06930446624756, 61.89262828519268, 62.875142789656124, 63.703080607998764, 62.40723932943037, 66.06844240619291, 62.52459272261589, 62.65898096945978, 67.70777348549136, 69.16660493420017, 68.39474524221113, 66.15367551003733, 63.6390204583445, 49.83732161983367, 46.89046059885333, 69.59824608218285, 70.30859516512963, 67.45820876090758, 61.61074715275919, 60.333278256077925, 59.838906641929384, 68.70098821578488, 69.56092865236344, 71.45288390498008, 68.20379641748244, 58.495675286939075, 46.113929363989065, 36.39823021427278, 55.45720338821412, 66.3365364074707, 64.61794991647044, 67.10219875458749, 67.50020950071274, 69.9635991742534, 60.91409106408397, 15.471938194767123, 30.587936985877256, 61.71332889987577, 54.6949182018157, 50.803334712982185, 60.03669608023859, 70.2452959552888, 30.64857682874126, 0.777590336097825, 0.239329268975604, 0.14790862618434816, 0.10822267466855627, 0.232612501168924, 0.13512981995459528, 0.14489434599395723, 0.23774265491914368, 0.15488817747081482, 0.0975843104383638, 0.2003497194739119, 0.17746449748594917, 0.16609880171956556, 0.2329554480891074, 0.07955397148766825, 0.11866041579313817, 0.13379694954041513], [0.04895111846347009, 0.05762958846565697, 0.022543416538786505, 0.033069219470264456, 0.06255266481950399, 0.1266530034462771, 0.03327804737754407, 0.028776135520949483, 0.04625399101285204, 0.1147942151874304, 0.030648239903272163, 0.03263999955848821, 0.02512793864063438, 0.036277151366154996, 0.02486148559969039, 0.07093601094018068, 0.04835228285481853, 0.058321473113591635, 0.10204902489579494, 0.04393207427534846, 0.03366946085025707, 0.021281976162666277, 0.1513477021287526, 47.818207048600726, 63.74060200106714, 53.67199543983706, 37.63676174225346, 56.73772781125961, 24.56254097723192, 12.774551683856597, 63.939356342438735, 62.96443946899907, 78.62060746838971, 71.88778062020579, 76.86286003358903, 67.669797097483, 67.56349302107289, 46.483455857922955, 13.430848544643773, 11.28324693249118, 46.31100100855674, 72.82573699951172, 76.66529024800947, 67.8637896814654, 68.78577416942966, 63.0158656643283, 59.520421951047844, 65.85932516282605, 72.90467862159976, 70.98443523530038, 71.77717762608683, 71.74564176990141, 71.88891026281541, 72.13083421030353, 67.75796413421631, 70.05180543468845, 74.21153391561201, 70.32094278643208, 69.04286984474429, 69.48178306702646, 63.41774778981363, 61.25295246801069, 57.51947187608289, 58.24110954038559, 53.75699320147115, 61.445434939476755, 67.27225703577842, 64.35007949029246, 64.22289663745512, 64.81658266436669, 66.06149981098791, 67.10110833567958, 59.258454691979196, 49.281243278134255, 44.715851506879254, 46.63874641541512, 46.035164248558786, 46.55940863393968, 52.09538698196412, 57.69662964728571, 54.912648970080966, 58.76897427343554, 57.57853884850779, 59.50914905917261, 58.851340124684, 62.18281307528096, 58.95808350655341, 61.574261265416304, 63.58123610096594, 61.94242277453023, 63.85461745723602, 58.699952325513294, 57.78466724580335, 61.14904495977587, 58.674460841763405, 61.570554625603464, 58.36062415953606, 58.34001210428054, 54.97480677020166, 46.27623311934933, 43.557693266099506, 41.37197209942726, 39.831186648338075, 43.47297007037748, 44.910801149183705, 44.57612099186067, 46.7262113478876, 47.4252640047381, 47.70212058098086, 51.5116245515885, 59.031220020786414, 60.28932417592695, 59.070616306797156, 61.14087074033676, 61.308677581048784, 59.66104284409554, 56.53291340797179, 56.63894291846984, 50.29654487486809, 53.0764502094638, 57.384361913127286, 60.616496916740175, 57.722721253671956, 58.21926586089596, 59.316878395695845, 61.618081984981416, 57.853595056841456, 57.0438374242475, 58.359953434236594, 53.79394977323471, 38.47292477084745, 64.5955845617479, 69.59517094396776, 64.7342638815603, 54.2479915772715, 59.67617927059051, 57.84319293114447, 64.45686994060394, 60.21972563958938, 61.06910705566407, 49.539747084340746, 37.56709260325278, 14.470808121465868, 29.675238709295954, 47.1387230965399, 55.48216142962056, 57.88018872660976, 67.97937408570321, 55.07243064142043, 70.72410752696376, 28.543534894143384, 8.910361047713987, 39.946861267089844, 43.97030307400612, 42.713924761741396, 39.83292033595424, 35.72315500628564, 35.576179873558786, 1.802290851070035, 0.2640150427337616, 0.05650717389559554, 0.0361687307726712, 0.005310272033731904, 0.04395464705603738, 0.07657216576438758, 0.09542656251259389, 0.02873225975030613, 0.006559927104746984, 0.01587106746756622, 0.06593554821466246, 0.025278201041322564, 0.039803607299202876, 0.04192602324990496, 0.032513851690436565, 0.14537407025214166, 0.0422553223137173, 0.05241099752545838, 0.05064105479827812, 0.0847296002170732, 0.03011063578718853, 0.034814114952760364, 0.03022910553901907, 0.023834004645205797, 0.00713372360839839, 0.041097583429467295, 0.02516940314953606, 0.0347789898214321, 0.06429266500016374, 0.056935083797021266, 0.037992743985547174, 0.005649016004040717, 0.05874967795886821, 0.04971906798140657, 0.01414263329934329, 0.011088770303514697, 0.033577706499566, 0.0036572142139888342, 0.030179727341859575, 0.11971784695502251, 51.434561744813, 75.46364076675908, 51.93701736388668, 43.07372770001812, 40.247620767162694, 28.547969133623187, 34.37791932013727, 62.603240166941, 75.76357656909575, 82.94078442358202, 81.52338104863321, 80.30469279135428, 76.78476564345821, 70.29961293743503, 56.18612489392681, 14.446135432489458, 14.066247997745393, 47.237264802378995, 76.40145594073881, 77.88532780062768, 75.3086914554719, 70.27754568284558, 64.90474970110002, 63.02527150800152, 69.17357890836655, 74.09063077742054, 72.94537713450771, 70.62885668969923, 71.89765714829969, 71.74302947136664, 70.94645100255167, 66.59316139836466, 70.78484935145225, 73.58084817086497, 70.61592855761128, 72.68401392044561, 69.1150414559149, 65.15386335311398, 63.28255937945459, 60.046635366255245, 57.99951507199196, 54.48642069293607, 63.24520664830362, 67.71916404847177, 66.7911861788842, 65.92679777453023, 66.40873155286236, 67.0404371138542, 67.77009210278912, 62.11947464173841, 54.311310398963194, 48.164058116174516, 48.26704386741885, 48.35260645035775, 47.7837529490071, 55.038588431573686, 59.464390893136304, 62.42085779866865, 61.41910406851, 60.5517856536373, 62.37354224728, 62.30407707152828, 65.6159342488935, 61.84527743247248, 64.60278995575445, 65.87556377533944, 64.59692601234683, 66.61442064469861, 60.69143772125245, 60.500426138601, 63.9914297288464, 61.9483926219325, 62.89164420097106, 61.02468621346259, 62.2507171477041, 57.464193913244436, 47.438968766120176, 47.302603644709436, 44.48214884727232, 43.89002392368932, 45.417347800347116, 45.659722820405044, 48.881895003780244, 47.23325614006289, 48.66384260116085, 48.430249767918745, 55.044044448483376, 59.46437912602579, 61.56346298033192, 62.91099325303109, 65.8474717601653, 63.087135130359286, 61.029965723714525, 60.32182493517476, 59.548984650642645, 54.58708047866822, 57.08216682557137, 59.547658889524406, 63.30924326373685, 57.99017590861167, 63.240138946040986, 62.81232603134648, 64.54770811142461, 63.03872523769256, 60.73235588689005, 59.17755580717518, 53.13175170652328, 42.09629266492782, 66.06323349860408, 69.81262714632096, 65.1479091951924, 55.70375181013539, 60.617567723797215, 59.682874756474654, 67.61700199496362, 64.03836481032833, 66.05199983043056, 55.49794112482379, 38.215672200725926, 18.185606464262932, 34.219031949197095, 53.82801555818128, 61.59241791694396, 63.65491782465289, 69.48689783773115, 60.23931395622992, 71.35288699980705, 39.191957981355735, 17.670834602848178, 26.54499903801949, 33.599273927750126, 50.42617136432279, 36.1548432227104, 46.05006533284342, 43.773007854338616, 2.75991571045691, 0.560515645530916, 0.03776951362529109, 0.07015613343326316, 0.036590841388510126, 0.019945968618436206, 0.03809562576333842, 0.03465246657029756, 0.06351351910721391, 0.02668019365369072, 0.03286989488368554, 0.04027306980964157, 0.06142912410019387, 0.03646383550198328, 0.06181273879783769, 0.049800664006221684, 0.0639663000531014, 0.025516439064015305, 0.18079606065106008, 0.2245935371085521, 0.15859762116545634, 0.08994166408815692, 0.24595908580287812, 0.2500771454745724, 0.08009851444512606, 0.16426886281659528, 0.14089483076766615, 0.17933130053983581, 0.1812243957312838, 0.16657248920490667, 0.232180243718528, 0.13947948332755797, 0.1562336730139871, 0.19008455497603263, 0.19706988256544838, 0.23838935570130426, 0.20273559306177402, 0.151358473324968, 0.15899056298357828, 0.14615129709484118, 0.20817238116456618, 76.54408900968491, 77.94221001286661, 78.73388551896619, 49.1900638611086, 80.41298943181192, 31.63872426556003, 24.549153927833807, 77.77863148720034, 77.37379581697526, 91.27848040673041, 82.8666437825849, 87.42859563519879, 81.09377168839978, 79.08029356310445, 61.11914080958213, 17.005963440864317, 15.16185227901705, 52.9017674538397, 82.84817726381364, 82.63323137837072, 78.09584140777588, 73.84540419424735, 69.13868550331362, 65.53003434211978, 71.21638067307012, 77.03479320772233, 77.68169403076172, 74.80940511149745, 78.20665620988416, 75.53542014091246, 74.92757828004899, 70.16604054358699, 74.17402821202433, 78.23832542665544, 73.41033489473405, 74.95385031546317, 73.41516725478634, 67.97185882445305, 68.19959163665771, 62.93580616674116, 61.18597015257805, 55.86547897708032, 65.34239599781652, 67.91531393604895, 66.37790172330796, 68.54717639184767, 66.5865953506962, 68.33560374475294, 69.81862052794426, 62.306889410941835, 55.31685706107847, 48.57049019105973, 51.07188763157014, 52.0407562102041, 51.45678589420935, 56.379835067256806, 61.983376241499386, 57.72369007910452, 62.86962793719385, 60.60785593525056, 65.97868288716963, 63.63433714835875, 69.73334035565777, 60.852415715494466, 66.94450378417969, 68.08343456637475, 65.0900307009297, 67.28163150049025, 63.48405937994681, 63.74850165459418, 68.2031374592935, 63.24729334923529, 66.79705404466199, 64.21257688153175, 64.4911906796117, 59.94504990116243, 53.32757211500599, 50.582320920882694, 46.47528163848385, 45.303269586255475, 50.87214485291512, 48.105850142817346, 49.762977015587595, 50.197108868629705, 50.808061169039824, 50.087800256667606, 56.80905219047301, 65.2544407690725, 64.75010633468628, 65.67169074089297, 66.60621504629812, 63.651768161404526, 61.863539987994784, 58.388119974443995, 59.705651960065296, 56.054490150943884, 57.90513107853552, 61.22023990077358, 65.15674237282046, 62.71572589874268, 65.67406377484723, 65.99245040647446, 69.84347266535606, 68.63763409276163, 68.28570335142075, 65.29617871007612, 59.041751584699085, 48.20207765025478, 72.05135914587206, 73.69723273861793, 70.28906960641184, 57.50478652215774, 66.61314195202243, 63.43219387915827, 74.22486212945755, 68.60328981953283, 71.0246552190473, 61.00780825461111, 44.64800627000871, 23.40290008052703, 37.60100149339245, 60.42601093169182, 66.47010095657842, 67.69922271851571, 77.61800258390366, 64.002141721787, 81.58803739855367, 36.41131131879745, 11.442489277931953, 50.24697003826019, 63.95182555721652, 61.252925011419485, 59.07659792130994, 54.51616794832292, 67.58223410575621, 6.045583957625974, 1.028351322297127, 0.1708234191661881, 0.1687626886151491, 0.1018425565393221, 0.2248357434666926, 0.22479553917242637, 0.2792642680147002, 0.1964621450151167, 0.11667083182762708, 0.09622374594572092, 0.13781831359430669, 0.24177837546073624, 0.1526506951138858, 0.22107206074701202, 0.11266285132977272, 0.2528549956097718, 0.1471904187553352], [0.09667723935337798, 0.023197826080685182, 0.016404641003558235, 0.04043574474992291, 0.05986701336599166, 0.025874558355539076, 0.059760680362101526, 0.01943700661462161, 0.03710063076728294, 0.0416749149500843, 0.03753544695134606, 0.10349161442249052, 0.010654075735909565, 0.057843418927082134, 0.0709288556789679, 0.056602325846230796, 0.014492930833160158, 0.0814888874189027, 0.06559834695391117, 0.0056942530171645266, 0.15222111897122476, 0.12249268636467958, 0.46179957808025424, 11.753507737190494, 76.7021526828889, 43.45505660580051, 77.97114141525762, 69.4982256427888, 55.07782390040737, 7.987269470768591, 52.85777414998701, 67.94795590062296, 63.45207245119157, 81.224684715271, 72.89138963145595, 74.25256975235479, 66.180983051177, 55.1115680509998, 18.477050335176532, 4.905327904608942, 37.91674052515338, 75.7724803493869, 71.71584744607249, 73.91559108611077, 67.17536664778187, 66.22600401601484, 61.38780747690509, 66.97545128483927, 73.08123234779605, 71.74313929773146, 70.15770942934098, 75.4949648149552, 74.85197067260742, 70.22078898645216, 69.46565428087789, 67.51841714305263, 71.21626300196495, 69.98742365068006, 71.22552764031195, 71.08999406137775, 69.44684259353146, 66.04177028902116, 63.35324833470007, 59.04682320933188, 59.85637295630671, 62.47451582262593, 64.3623721984125, 63.46093308541083, 64.03308137770622, 65.06905778761833, 66.1177073755572, 63.70777568509502, 56.09521612044304, 48.76922492058047, 47.06155438576975, 46.24798420936831, 45.45904259527884, 47.37290820767803, 49.77148463649135, 56.88459703999182, 55.70347332185315, 58.85284239246, 55.33209939156809, 60.01935135933661, 59.799345616371404, 60.21231628233387, 58.50843867947979, 61.445383948664514, 63.08587997190414, 65.06165627510318, 62.862077374612134, 62.88607835769654, 56.93337563545474, 62.602977368139456, 61.80597920571605, 61.46640785278813, 60.33750264875351, 58.509301600917695, 56.81517108794182, 45.74492846765826, 41.1960655643094, 44.56638959146316, 42.79053649594707, 43.386779908211004, 43.38644650674636, 44.697043741903, 45.87961873700542, 47.41303797691099, 52.18666053587391, 60.4727420499248, 61.36756804681594, 62.79491463015157, 56.051124757336034, 56.17291042881628, 55.07851815992787, 53.83114560957878, 49.79983160572667, 45.980235376665675, 41.28074561395953, 43.923187563496256, 56.45535246018441, 60.7485709651824, 61.9294907200721, 61.89966501728181, 61.85919792421403, 62.23671428618893, 56.76596495413012, 50.993879533583126, 54.16132680831417, 51.49791586783625, 38.847413063049316, 61.00421536353327, 68.82776706449448, 62.849129630673325, 57.389606122047674, 55.45934107995803, 56.161104094597604, 63.34665090807023, 61.62051777685843, 58.647592606083045, 45.14158948775261, 11.823919184746282, 7.671831480918392, 34.53748133874709, 44.15812576970747, 53.76021346738262, 55.74614478695778, 62.021886071851185, 65.57373739057972, 60.09054630033432, 9.161965404787372, 25.4215302390437, 40.98923898512318, 53.57046488792666, 50.46757198149159, 33.62492230630691, 47.376822733110004, 9.204928105877293, 0.4108388884173286, 0.12370210937074116, 0.028261851121280945, 0.06415743515976975, 0.09328759140184811, 0.04376848769043723, 0.021713777790747343, 0.043514502730460904, 0.07299197642433067, 0.039616264327759707, 0.030575902051021977, 0.04945657944547073, 0.0714218179364839, 0.04271632721347194, 0.08272651778233629, 0.03226942750775526, 0.06761410048291569, 0.021441538870755224, 0.10139717600278317, 0.012879773745343331, 0.002294386889139611, 0.021611974281709523, 0.006586359053354471, 0.024157016042379603, 0.016588714694784536, 0.02679652602021252, 0.03660815497559886, 0.014450268354266884, 0.022382834933758266, 0.05670810343637582, 0.03166635926332205, 0.028511854339270826, 0.06024487857376376, 0.04925853805616499, 0.028168662270951658, 0.038286220778020165, 0.008932539231834874, 0.1376489009107313, 0.12755284266125771, 0.18226837438921775, 0.6654525307878372, 15.280843261749515, 88.03374675012405, 48.587262245916556, 64.07106168808477, 65.26270520302558, 37.231780944332, 21.6082098022584, 70.82375926356163, 68.33243446965372, 74.53345068039434, 85.89816524136452, 79.9345700971542, 76.02389643269201, 73.19219619997087, 63.68761862477949, 20.86036286046428, 4.8944511721211095, 38.74418412485431, 77.74138466004403, 79.37322401231336, 75.73831650518602, 69.22716632966073, 67.01374930720176, 63.663947120789565, 70.79794222308745, 76.89026955635318, 75.19364833831787, 71.25944829756214, 76.39062235432287, 74.23140464290496, 72.4152688057192, 69.69364596951392, 69.04880046844482, 71.61911395288283, 71.87118114963656, 72.90012082745953, 74.00399346505442, 69.86508492500552, 66.35737988256639, 64.16154292321974, 60.355263140893754, 61.977955525921246, 65.9035224299277, 65.75907330359182, 66.3717749810988, 66.27688500189012, 67.87441145989203, 66.67935940527147, 66.83797221029958, 61.66287937471944, 50.79456037090671, 50.73602291845506, 50.76196547477476, 49.26866423699164, 48.96053460336501, 51.44269674055038, 59.4637397796877, 61.44088499007687, 60.33318411919379, 62.00272921592959, 64.56220519158148, 63.49405750151604, 63.30953744149978, 61.3679995075349, 64.47083750078755, 65.58594380655597, 64.41977216351417, 66.04679092284172, 64.11134442975445, 58.911430835723884, 66.80806806010585, 62.460638476956284, 63.97165313843758, 62.81862928021339, 62.360712174446356, 61.06214877097838, 48.32537735662153, 45.87142098334528, 48.072706114861276, 45.843301511579945, 46.94952757127824, 47.040067641965805, 46.5315519609759, 47.80082310399702, 49.355725165336366, 51.77433706098988, 61.58163139897009, 61.68128705793812, 64.69624826985022, 60.62483195335635, 58.836839122156945, 60.25331289537492, 57.680202761004054, 55.627579381389005, 52.87493451949089, 45.98814287493306, 50.09861815360285, 59.654849421593454, 62.37362853942379, 65.38218844321467, 64.72963940712714, 65.66273989215975, 66.0043744117983, 62.238216553964925, 60.35977778896209, 60.35984446925502, 52.90541918047013, 42.06982058863486, 63.223684603168124, 69.3898505549277, 64.37503360932874, 59.03886079788209, 58.22735378819128, 60.11042879473779, 64.50318136522847, 64.3720643751083, 62.34760361333048, 49.241321394520426, 13.237026583763862, 9.37069139172954, 40.61459379811441, 51.10575729800809, 58.029187802345525, 60.911565057693, 66.53079571262484, 69.33641218370008, 68.12347412109375, 18.050849514622843, 26.05938215409556, 25.937678852388938, 50.807221781822946, 59.0856429069273, 37.320948185459265, 63.476897132012155, 14.01045620441437, 0.7632697625986992, 0.23744870698259724, 0.03780342450725936, 0.13664612246136512, 0.050603347950645035, 0.04818546337886684, 0.03255990123556506, 0.0710368664154122, 0.03319775370220023, 0.019804587092010245, 0.06252991583859248, 0.012035646359436216, 0.05376121217024423, 0.018371357244529554, 0.0036277535846531996, 0.05941895918259698, 0.04504945181730775, 0.05266643805249084, 0.333045203118555, 0.10231923942844715, 0.1666149151541533, 0.1292850440668483, 0.10699753153828845, 0.13487812942795216, 0.24154455010448736, 0.16501461876736534, 0.23223863494011665, 0.22858899206884448, 0.23295049916111657, 0.14321463693293834, 0.18307832850804254, 0.20444131846870148, 0.1422288656354912, 0.20084421390727644, 0.11540768307543571, 0.23390997832100238, 0.09867849083797586, 0.2144678006128919, 0.3473101586343781, 0.40409363746162386, 0.9477542761352755, 27.826704094486853, 101.10382156987345, 64.36580427231328, 97.55736351013185, 90.89309969256001, 78.1765559411818, 12.306010838477844, 68.72815455159834, 78.49276957973358, 80.17296391148722, 91.36390178434311, 88.74808880590624, 83.72631749799176, 79.2884066797072, 67.46333137635263, 23.510135719853064, 6.87374682195725, 42.23275584559287, 82.4983802918465, 82.64584572084489, 78.54928308917631, 73.38720075545773, 70.03572371698195, 67.36570358276367, 74.28218364715576, 79.43943362082206, 77.24064703910582, 77.13943419917938, 81.48367097300869, 78.69004126518004, 76.01499265240085, 73.71485987017232, 71.09823103873961, 73.17589482953473, 73.77599393167804, 73.3562610995385, 76.50641072180964, 73.18827382979855, 70.0733470916748, 67.67025209242298, 62.769725168904955, 64.69927241725307, 67.26904853697746, 65.8035216023845, 68.85093258273217, 66.88495436022359, 67.92109550968294, 69.26315015362155, 68.98306154435681, 61.045682660995, 53.51845425944175, 51.968082535651426, 52.97113849270729, 50.69411631553404, 52.17185358847342, 53.926898510225364, 60.087784951733006, 60.0737310994056, 64.35448823436614, 64.10680624746507, 65.80410603554019, 66.073133560919, 63.633658578318936, 61.995284557342536, 65.38177659434658, 65.71100465713009, 68.59535094230407, 67.02246481372465, 65.9274096642771, 62.976818469262895, 68.05462867982926, 63.17387050197971, 66.26460798325078, 64.4996786886646, 65.28894585947837, 63.879151882663855, 51.53422917089155, 47.71103220601236, 51.702659668460974, 49.61743354797364, 50.96644255422777, 49.677724299892304, 49.275304809693374, 50.193774853983236, 51.809238310783144, 55.42149413016535, 66.14928245544434, 64.93819967392953, 66.77985837382656, 60.295286178588874, 59.75483455965596, 58.69356670687276, 59.878769689990634, 56.873029970353656, 55.48361270658432, 51.256815618084325, 54.2565344995068, 60.35777738017421, 64.5310458829326, 66.87139080416772, 67.95881302125993, 69.2044008931806, 71.22280551541236, 69.25796478025376, 67.2797566075479, 66.8515436110958, 57.89108507094845, 46.68286523511333, 69.49563687847507, 76.39149312050112, 67.85301100823187, 63.76081789693525, 62.07656391205327, 64.1733374903279, 68.63382154895415, 72.17305460283833, 68.39552971624559, 54.399430367254446, 16.795840109548262, 10.824358059513955, 42.7843979866274, 56.68940813310685, 64.00913530780424, 65.79253896590203, 69.50738045477098, 74.62800333576818, 70.43501315578338, 11.792425494040213, 30.121837815930768, 59.56878085290233, 72.60431920328449, 71.14284407707953, 49.073651836764434, 74.19819001228579, 31.630632415894542, 0.7872380184069757, 0.2851549019255946, 0.19391615905107992, 0.2054313645367661, 0.14585736448005324, 0.21013030271616676, 0.15073968878676816, 0.15300694132043471, 0.21813363858288337, 0.0792065582748863, 0.17838855274021628, 0.14105762445157574, 0.20527583336637867, 0.13782942186920874, 0.14589133281861583, 0.19338932038555223, 0.11852166960917174, 0.18378509058346673], [0.12088435371556591, 0.023804211485830527, 0.053530562248441486, 0.02716679163577576, 0.019476324162115494, 0.03135252942992074, 0.04294172560255374, 0.07545416769120963, 0.03372753414535715, 0.019973524801072576, 0.04514861040778699, 0.015255156716692354, 0.08474659204723374, 0.0423962097134321, 0.051358557426400726, 0.024163594822429364, 0.06633080361831574, 0.02257934797765507, 0.1090879939616688, 0.04692624848816664, 0.008927209175101692, 0.029097982464478384, 0.11368371711503114, 2.2776549045116674, 76.37243040146367, 50.88904242361746, 73.6840457300986, 70.39630720692297, 61.88477962247787, 27.291784978681996, 11.344745774422924, 79.0625487604449, 60.820271891932336, 78.8420017303959, 73.49106511762066, 80.02167024920064, 68.6601798765121, 59.857537900247884, 18.533695244020034, 4.088849290724724, 35.48843645280407, 70.20246367300712, 73.50464436315721, 72.83084392547607, 71.46236819605674, 70.33928378935784, 65.02521353383219, 70.1666602780742, 74.21924529537078, 74.31237805274226, 72.98457730200984, 77.11448792488345, 77.20410623858052, 70.04447060246622, 67.21022082913306, 62.64404066147343, 65.06157782769972, 72.10311874266594, 70.16406366902014, 69.09965792009908, 71.24353916414323, 66.91359550722184, 65.43910203441497, 60.015562349750155, 62.49033474153089, 64.54483693645847, 64.54309540410196, 65.73720608988117, 66.41456803967877, 67.1471961852043, 61.80788939998996, 58.51458111116963, 51.29415658212478, 47.73311122771233, 49.19937949026785, 47.66193589856548, 45.926914676543205, 46.74425032831008, 48.87168115185153, 54.04218481433008, 53.06512632677632, 55.35049530767626, 53.763963253267356, 55.029410085370465, 56.044472417523785, 55.819085182682166, 57.824106677885986, 61.09162146045316, 62.74007989514259, 63.68674001386089, 59.64042686646985, 64.64216662991431, 60.26972801454606, 56.783290063181234, 64.18469667434692, 61.4385001890121, 61.22568022820258, 55.36676529915103, 54.53427360903833, 48.45401933116298, 43.7112932820474, 42.76214245826968, 42.13738733722318, 43.60835067687496, 44.55424985577984, 46.52622145991172, 45.34319539223948, 50.146365165710456, 57.36219267691336, 63.245681255094475, 63.10889251770512, 59.40604171445293, 61.29452959183724, 53.59425014065158, 45.14894000945553, 51.62723641241751, 51.22385986389653, 51.30173067892752, 50.120285326434725, 51.64764842679424, 56.217958850245324, 65.22845506668091, 61.04169361052975, 60.18718565663984, 62.738189312719534, 61.7482929075918, 60.488949283476806, 51.434753940951445, 52.088428697278424, 51.45875884640602, 37.4082052323126, 54.76923534947058, 64.0353092839641, 63.30853723710584, 60.79554919273623, 59.80620976417296, 63.833173859503965, 65.4314612573193, 62.55738373725646, 57.60378322293682, 24.87362219441322, 1.2573645432149212, 14.153041224325857, 36.119122197551114, 48.32752289310579, 54.971182500162435, 64.898489598305, 55.324697879052934, 72.58712353244906, 27.282086918430945, 10.999744880583979, 40.7617336703885, 38.93995354252477, 60.560305041651574, 37.18072345179897, 37.92123163900068, 49.69288818297848, 2.282475007157172, 0.39430790610851785, 0.09357408530289128, 0.061746621579532666, 0.030784456081868663, 0.04984239664589686, 0.04996205191879023, 0.014232025226397861, 0.04814060893090022, 0.027626113057316794, 0.04096531834934027, 0.040704373480571855, 0.02842252274164029, 0.014105191709653986, 0.043932005327435276, 0.058364542576694683, 0.07318919043867819, 0.0059562364138752944, 0.03622594987973571, 0.03286500724272863, 0.02887412965778382, 0.0386127810775032, 0.037466142807276025, 0.027278791775085756, 0.04961524391546846, 0.04963403988269068, 0.03305053075535163, 0.03022008676893048, 0.010190321538116663, 0.026051520835608247, 0.029443610692396763, 0.011521114896412098, 0.019395346753299236, 0.008556954093247412, 0.019703390707652417, 0.013844264077863867, 0.050126779974708637, 0.04994290355112284, 0.013641900995055274, 0.02152358305700604, 0.0570042270626272, 0.04111979614883181, 1.61243244524925, 86.59884175946637, 58.613805309418716, 78.70885295252647, 92.05438013999694, 50.915494888059555, 25.50512771452627, 34.2510934029856, 85.21881857225972, 69.78606485551404, 85.21163279010405, 78.48449337867, 84.06731267129221, 75.79919169026037, 67.23417866614558, 23.316007814099713, 4.513528721947824, 38.14222581924931, 71.95426479462655, 78.31431742637389, 76.62266192897674, 75.07862875538488, 70.76151909366732, 67.68765957124772, 71.50879336941627, 76.93963650734194, 77.76734290584442, 74.65979806838497, 77.59479784196424, 76.66417629488053, 70.3216645025438, 70.55514750942108, 64.5393769971786, 67.22854614257812, 75.70600401970648, 73.17131350117346, 72.6626762267082, 72.44608294579291, 69.99422504055885, 66.52360993046915, 61.2314147333945, 66.32510662078857, 68.38755946005544, 67.11618592662197, 65.29504514509632, 67.9418997610769, 68.2205920065603, 64.22249263332736, 61.31769903244511, 54.45060553089265, 50.557045167492284, 50.4781388467358, 50.884508163698264, 47.378627023389264, 51.63717962080433, 51.340032623660186, 58.74744046118952, 60.93143970735612, 58.37073602984029, 58.10442670699089, 59.42078590393067, 58.934180582723315, 60.1733357675614, 60.40437121545116, 64.47344979932232, 64.44392219666513, 67.61341694862612, 62.88121854105304, 65.94344431354155, 62.520309494387725, 60.81983258647304, 68.05572694347751, 64.13961295158633, 63.76267710039693, 60.63265315947994, 60.22704870470109, 50.754646332033225, 47.45194788902037, 47.4147520526763, 43.646429046507805, 47.38845648304109, 45.495383354925345, 48.52879147375784, 47.096494859264745, 50.16613391137893, 59.37818111911897, 64.68656393789476, 64.51554859838178, 61.65403050761069, 60.80856361696797, 57.369025445753536, 50.80312682736305, 55.18341802781629, 53.36811765547722, 55.87047607667985, 52.2317874047064, 52.147954587013494, 58.223372582466375, 64.9986473206551, 62.86820019445112, 62.57102574071577, 65.54108365889519, 65.4150265262973, 65.38189426545175, 58.977518850757235, 57.63370306261125, 53.20291134618944, 38.616754162696104, 58.04839564907936, 70.39394594007923, 65.7784458898729, 61.859531325678674, 60.85076047528175, 65.13580868321081, 69.07527646710797, 64.45896056390578, 62.32310056686402, 24.75336036374492, 1.3082989713838025, 16.8945740115258, 40.56523469186599, 54.13020280099685, 59.9817358293841, 68.23182567473381, 64.20217083346459, 76.19114629683956, 38.48184031824912, 20.348395493722734, 30.41354448564591, 29.39844685216104, 65.52173068446498, 40.26910751096664, 42.763417228575676, 57.88240094338694, 2.1405504163234466, 0.313641881389964, 0.013783181972441175, 0.05922607739546126, 0.03648731609686248, 0.026693644242421277, 0.02904473743852108, 0.03182984051114369, 0.022077198410707138, 0.04621117818920363, 0.06836819147030193, 0.07272808977793302, 0.06056568555293545, 0.07816576654271734, 0.03134471724831289, 0.027654171027543566, 0.05890553854706307, 0.06289957241425592, 0.028017808067341967, 0.2167213708162308, 0.10160228072275078, 0.09646209122072305, 0.09816607760806238, 0.10634575159318986, 0.19603482117095303, 0.15667869348920163, 0.1691919583226404, 0.15594773835712866, 0.09578018103756251, 0.11668734868327457, 0.1292768469260585, 0.13012559573736884, 0.15875693681018968, 0.20581992433196117, 0.1307957847752879, 0.1244194204768827, 0.1448513684614051, 0.1661100632120525, 0.12574330467971104, 0.07604086846714059, 0.1469228702086595, 0.14495013251660332, 4.448046222809823, 109.57925550399288, 65.37255510207146, 95.61958712916221, 77.96885075107699, 93.37870567075669, 33.430604165600194, 21.037379426340905, 89.75292159665017, 76.98283749241983, 93.60652477510514, 84.26141508163946, 90.4374614838631, 80.22025200628465, 74.64213955786921, 26.093657785846343, 5.6907913569481146, 40.33436398352347, 77.32519765054026, 82.78995360097578, 81.53652883345082, 77.85792612260389, 76.5582566107473, 69.95649183950117, 75.9422326857044, 81.1852413608182, 83.01302663741573, 78.11697513826432, 80.51932488718342, 80.06714620897847, 74.84165483905424, 72.60960655827677, 67.87299940663, 69.80642195670836, 76.17249934904038, 76.43608262462001, 72.24155487552767, 73.86394916042205, 74.15030571722215, 69.00759204741448, 63.03659931305916, 68.82493511323007, 69.34673586199361, 68.19550452693817, 66.7614467682377, 71.15529368000647, 71.38442285599248, 67.42333889007568, 63.49122162788146, 55.70683087072065, 50.71130021925896, 52.98415683930921, 53.18753173274379, 49.24951130344022, 52.317997178723736, 53.27895433672013, 59.276270097301854, 59.465669585812485, 61.76540228628344, 59.981100405416186, 60.09956382936048, 59.45359653042209, 60.790461878622736, 63.2033706480457, 66.31658723277431, 67.15751986349782, 69.65522243130592, 64.52376204152262, 69.73895718974453, 62.60505622433078, 63.36569009288665, 69.9796808919599, 66.78514572881883, 65.79100531916465, 62.21560408992153, 63.75721716111707, 54.33525254649501, 50.19688921590006, 50.166659508982015, 47.85935271170832, 50.16014052975563, 47.56455521429739, 49.90981486535842, 50.32601756434287, 51.538406495125066, 62.58855089064568, 67.2418115985009, 66.3204703792449, 64.48649952488562, 65.23174593525549, 61.13528136284121, 54.83840634745937, 57.84460498440651, 58.658481105681396, 59.541873393520234, 58.22514549378426, 56.90524439657889, 60.790285371964984, 65.37557140473398, 65.19908828120079, 65.85155102514452, 69.7281079138479, 68.23898792266846, 69.43818984493133, 66.76169779992873, 64.08558230246267, 55.515615324820246, 43.271909375344556, 64.34938130840179, 77.37170127130325, 70.3565029944143, 65.74823579480572, 65.13138424965643, 69.7531561697683, 71.2301403476346, 71.76664213980399, 67.53558143492668, 30.824377459864465, 2.617457186983478, 18.69164516848903, 45.32322660569222, 60.309261583512836, 63.42974632017074, 76.28823280334473, 64.37396672464186, 83.9924503141834, 35.37983386747299, 16.434458417277185, 48.67302094736407, 59.010984513067434, 75.07355320838191, 53.486859567703746, 50.11081280246858, 73.53586642972886, 7.35795557498932, 0.8723698147842962, 0.25600269767305545, 0.2236361110643033, 0.15592607339063, 0.18194919151644554, 0.2549684789752768, 0.06858556891881651, 0.2603582905665521, 0.21915046708478084, 0.26262168201708025, 0.11173232263254543, 0.18300685250470716, 0.2735625207424164, 0.13442498842074027, 0.14985245171814196, 0.1293441400893273, 0.08545250376506199, 0.11927784435571202], [0.08703550954739894, 0.05552307650026295, 0.033877576295767105, 0.05388396243835169, 0.08517997564687844, 0.041548207837847934, 0.008635244448669255, 0.05355129641811213, 0.026357705111525236, 0.054548122364306645, 0.012008902229999584, 0.08328524102727253, 0.01625950756152311, 0.01873831144504009, 0.03336258901042804, 0.008982437411172977, 0.026521870092819297, 0.018554314362606215, 0.021969134048108133, 0.02519665289700272, 0.03726564610617296, 0.15544038896839465, 0.008428082782624951, 0.09254928182570205, 32.35932054058198, 70.8983313652777, 34.07498682698896, 32.49236537564185, 37.69866066594278, 70.15998440404093, 10.677069137173316, 34.041627068673414, 74.69092599807247, 66.85118275303995, 79.43946499978343, 63.23893870076826, 76.20735353039157, 60.15365331403671, 30.63127721509626, 2.697523303570286, 16.714925535263554, 63.46313745744767, 80.03124867716144, 73.31129504788306, 75.68548217896493, 73.27689586147186, 67.6127815246582, 69.43083932322841, 73.06358168202063, 77.30874723003757, 72.03052351551672, 79.11977614125898, 78.75593708407494, 71.95153482498662, 66.75203307982414, 64.3077688832437, 63.66665355620846, 68.87966786661457, 70.04358414680728, 71.81049423833048, 71.75926023913969, 69.67566582464403, 68.62268986240511, 64.3889658681808, 63.27254164603449, 65.55081898166289, 60.39174118349629, 64.1609545676939, 63.5551013485078, 65.82946023633404, 59.56124205743114, 53.2041782717551, 50.813195551595385, 50.10372900193738, 47.753511474978545, 48.07228642125284, 45.834099631155695, 46.33917931587466, 46.7151031955596, 50.73936477784188, 52.966835652628255, 52.165938654253566, 53.366344744159335, 52.084412190221975, 53.37555446932393, 53.68670825035342, 56.668042982778246, 58.67821455001832, 65.60863864037299, 65.50786902827602, 64.08138144400813, 59.02337528044178, 63.65614552651683, 57.020154153147054, 62.533908351775146, 60.42561869467459, 62.08579324906873, 55.66102935421852, 56.277131726664884, 48.4939569042575, 44.24734792401714, 42.442975274978146, 41.46921157836914, 43.45007519568167, 45.11269730906333, 46.587626164959325, 48.38293813890027, 54.454453376031694, 61.81027420105473, 64.55726300516437, 61.07017786272111, 60.02200680394327, 64.12898332841935, 55.18366121476697, 53.24570440476941, 55.60953255622618, 57.83693675071963, 58.8805264811362, 55.58401361588509, 55.02176146353445, 57.078464108128706, 60.1230941280242, 59.70756215433921, 52.374687194824226, 52.17280672442529, 55.49641924519693, 55.21766816416095, 56.11855422296832, 52.35977434342908, 47.96889666588076, 33.08872645901096, 43.51803418128721, 53.38056333603398, 60.300581378321496, 66.49023840504309, 61.07400609600929, 65.3193756072752, 70.57992119942942, 66.6308710652013, 50.82591187569403, 5.0572653259000475, 0.5196748854171845, 14.876588102309936, 32.568094576558764, 42.32479818405644, 59.41704788515645, 61.74449213089482, 58.42999127603347, 61.13505386537122, 11.500406995896371, 24.44513855441924, 41.619956108831595, 39.23724566736529, 50.570553810365745, 35.26846601117042, 51.5313736854061, 31.437965593030377, 0.19256363082076275, 0.13888910532959048, 0.03334098916140295, 0.05198457383460576, 0.008859457316688232, 0.05079626804217697, 0.04850371545481105, 0.027235467587747884, 0.09466925395592567, 0.04144183652956159, 0.0409193262608061, 0.03213075601736144, 0.11085700589202105, 0.025700679379365137, 0.005551191364159627, 0.03263659046722516, 0.03009034403329415, 0.027663314286919854, 0.04402490114913352, 0.055977561991781964, 0.01829719227257996, 0.06147089504426526, 0.023658258329716422, 0.09566497673550922, 0.07761592991770276, 0.046151634005288926, 0.06302665107913556, 0.05371715445371886, 0.08309871393946872, 0.05961708867201402, 0.08799274406966665, 0.026952581960828077, 0.03809797765326597, 0.0834626363470189, 0.08803756787411629, 0.030199427292832447, 0.02707739683589147, 0.02986320662462423, 0.03357950297574844, 0.01629187860676358, 0.07023777542335373, 0.024194133002310995, 0.1873614035186268, 31.5694591306871, 83.26157154575472, 39.458365363459436, 41.642419522808446, 43.0850084366337, 44.673007457487046, 21.710120824075517, 55.951390650964555, 79.68247936617944, 78.46142199731644, 84.97884796511742, 70.55205668172529, 79.97414681219286, 68.3876222179782, 35.52429868328956, 3.7451871508552186, 18.012886854910082, 66.25678677712718, 84.86134944423553, 76.14701178766067, 76.97750306898548, 76.30371047604469, 69.48377563107398, 71.64458582478186, 77.50867043772053, 78.08893019153227, 75.2130562259305, 80.60924914575394, 80.46780063259988, 72.97126477764499, 69.17522630383893, 66.90389940815588, 67.63480955554594, 72.20659086781164, 72.26232774796026, 72.01595583269673, 73.98664874415245, 70.82311599485337, 70.19988275343373, 68.56721970342821, 65.08067192569857, 68.53301663552561, 64.27416986034763, 66.407562686551, 68.20210979830834, 66.86731938392886, 62.67358787598149, 55.34685927052652, 53.499646494465495, 52.292164448768865, 49.023978940902225, 52.74750847970286, 48.49091706737396, 49.33353631727157, 50.17039360538606, 55.54890448047269, 55.44525977103941, 58.203694051311864, 56.83192745331795, 56.794304078625096, 56.840529211105846, 58.70356482844199, 58.915957250902736, 61.35465952657885, 67.09233007123395, 67.4973383257466, 65.23043978598811, 65.76354872795844, 67.41257590632286, 61.59268856048585, 64.44961355578515, 65.71081246099165, 64.78694915771484, 61.14648757442352, 60.425199001066154, 53.42059112364247, 45.03240639163602, 46.91969794611777, 46.1542474069903, 48.90858673280286, 46.726697721788966, 48.699869571193574, 50.13599834134502, 55.94645238691761, 62.11499137263145, 67.02678726565453, 63.869326345382206, 61.60200811201527, 65.28973033351284, 57.487394732813684, 56.825039771295366, 56.87478719219085, 58.491042967765566, 58.73433190007364, 56.36574591359785, 58.13225592336347, 57.725215881101555, 62.54419280636696, 64.5964474831858, 55.22782710290725, 57.160206302519775, 59.693512224381976, 60.14330217915197, 61.654077576052764, 57.64180275701708, 49.14135586830878, 34.652363638724054, 47.58653617674305, 63.31678990394839, 62.90032832853256, 66.38886082556941, 62.40443091238699, 66.77057804599886, 73.17915824151808, 70.14060005064934, 53.852483303316184, 5.100536423344766, 0.6569709568735093, 19.82609268157713, 36.090026055612874, 48.41694508829425, 63.35879456612372, 66.42915925671979, 64.31270322492047, 66.72701620286512, 21.026292847048854, 29.214081725766583, 28.08234064809738, 37.21507949213828, 57.01323509216309, 38.48797490519863, 59.827778877750525, 33.258094403051565, 0.27099171352963297, 0.09503832447432703, 0.05478210476858001, 0.07459215023705075, 0.05022854709457006, 0.023655531056705984, 0.02479356041388406, 0.053786477749987, 0.0791068519315412, 0.01257142527104025, 0.055279973819251024, 0.03627707475736257, 0.02947869943454862, 0.05536661836348715, 0.038927264000859954, 0.033486446275586085, 0.011865269362686143, 0.004400624020490795, 0.02181534764296826, 0.3486817318104929, 0.2224149209477248, 0.1525788207448298, 0.2154718201246954, 0.2249819130426453, 0.17389785258039353, 0.17410543176435656, 0.21689210117103594, 0.10417157108144415, 0.19692864659572804, 0.11633324752291364, 0.33285889053537004, 0.10325467108838982, 0.1672803697687003, 0.1630700731109227, 0.17714863943476833, 0.23452983538229621, 0.24989889213635078, 0.1307449931459081, 0.18418999869496594, 0.06319232142320083, 0.24884588896266877, 0.09674760452922314, 0.2743536137765454, 51.81127402090257, 93.49665134183823, 53.24280969558224, 49.351214439638206, 55.190803850850756, 92.99222669293805, 14.994041515934853, 50.61012268066407, 86.77303421881892, 83.63956251452046, 90.42014029718216, 74.85558709790631, 87.50153603092318, 73.8007519322057, 39.0997548257151, 4.7361957930749465, 20.607318993537657, 72.09771371656849, 91.53274413078063, 80.63543488902431, 82.41775205058437, 81.63905174501481, 73.56166778072235, 76.71047595239456, 80.82843119098295, 83.81354316588371, 80.33551477616834, 83.64282592650383, 85.22718891020745, 79.01722969547396, 72.95983499096286, 68.77053183894004, 71.16327178093695, 75.84764865136917, 75.96351546625938, 76.40944188640964, 79.00276399427845, 72.37294643155991, 73.52977891122141, 71.5268127379879, 66.47325454219695, 71.1944232448455, 66.00805359501993, 66.97749876206922, 68.96037455528014, 70.38552853368944, 63.557764637854795, 56.13807978168611, 55.7074898289096, 55.559224236396055, 50.08674121672108, 53.135238693606475, 50.57935168666225, 50.5982025977104, 50.54293247961229, 55.130477797600534, 58.19332330457626, 60.037778654406154, 58.79115135438981, 58.744467304598906, 58.21886970150856, 60.95965723837576, 60.748833763983946, 62.02399630700389, 68.85694165383616, 68.19717545663157, 66.54147240423387, 65.82346685471074, 65.10527303141933, 63.65185053117814, 67.283537772394, 66.77538687183012, 65.0734273079903, 63.40421953508931, 64.5358507863937, 55.14565344779722, 46.75930438503143, 49.78985701837848, 47.85835642968455, 51.57500613120295, 48.27526515530002, 51.3867715866335, 51.9194882915866, 57.8821656011766, 65.14264145205098, 67.2068868144866, 67.26627149889546, 64.38023467217722, 66.66454853550081, 61.136328635677216, 61.60496950149537, 61.84519506269886, 61.80213528294718, 62.279397518404075, 59.68320423556913, 60.64918594975626, 61.33612240514448, 66.26976982239755, 65.63480869416269, 56.999793129582564, 58.58327750236758, 61.94768659530148, 66.17232245783653, 66.2972342583441, 61.500681523353826, 51.43826446225567, 37.624900494852376, 51.91937454285161, 70.078336346534, 70.31889530920213, 71.43433109406503, 64.95011583451303, 72.44217626510128, 75.33422608529368, 72.78220653533936, 57.330609752285866, 6.854698321511669, 1.031861721027282, 21.18122450767025, 39.879506326490834, 50.82297009806479, 68.43800898521178, 73.99741957264563, 65.55665939084946, 70.68320505080685, 15.281868961549575, 31.14961058862748, 54.906824250375074, 54.21130564904983, 62.36792541319325, 45.4365203457494, 70.68937101671773, 54.19758519818706, 0.3255276129611077, 0.41742488501533387, 0.15444383115297364, 0.1697783986286771, 0.05882823261462393, 0.15305364204029884, 0.08803788197016524, 0.121210852728015, 0.20250518445766744, 0.13266341520413277, 0.10210998251192993, 0.14520422855932869, 0.19711491321363758, 0.14683846264116227, 0.14655343196805448, 0.138353533261726, 0.08017806501518335, 0.11106559631204414, 0.08684835426749722], [0.037857939323951165, 0.01923291121549424, 0.05444707153665443, 0.03479496275465335, 0.04272114590651566, 0.11040520553867664, 0.054962641048815944, 0.05872566110244202, 0.039987836123233846, 0.05982575187038991, 0.08293925273802974, 0.054407292421186165, 0.06601610235990056, 0.05272155041776357, 0.04829083877285162, 0.061601723709534255, 0.07590813607337975, 0.010886666732990454, 0.03121253452263773, 0.01553096560641162, 0.030060231032210494, 0.02062010875482473, 0.040915752460639325, 0.14420547973244421, 2.07321435213089, 75.66058297311106, 59.89206260250461, 50.7738894800986, 50.948784043712, 54.82969084093648, 40.49379264154742, 9.173938439738366, 57.58036667300809, 68.61478236413771, 61.66107116207, 70.22162837366905, 74.40662476324266, 64.78668243654313, 42.679627556954664, 4.122591970428344, 4.472466899502662, 51.48965143388318, 74.82397279431744, 76.29972534794962, 80.37297341131395, 74.07792229806223, 73.03653301731234, 70.2860729156002, 71.99590467637586, 78.32475093103226, 75.08076252475863, 76.51183928212812, 77.2191132268598, 71.90074797599547, 69.0203554399552, 68.1791482433196, 62.92498434743574, 65.64254360814249, 70.09068396783644, 74.33689286631923, 72.31218891759073, 70.93393079696163, 69.52456828086608, 66.01108166479295, 62.42085387629848, 61.00136772278817, 58.187251475549516, 66.45717282449046, 69.42785832189745, 65.0195457089332, 56.42432258975122, 52.60640905749414, 51.64549504556964, 48.82238872589604, 49.49331798861104, 48.42386022690804, 48.65598609370571, 45.94608329957532, 45.270000042453894, 48.77910144867436, 50.42808548096688, 50.96426171641196, 50.29232048219251, 51.12195668681976, 53.07956849375079, 52.02480785308346, 57.3352381490892, 60.4416415768285, 62.97006414782617, 62.34323801532869, 62.81103949392996, 59.89141541142618, 64.67089799142653, 56.411484672177224, 62.03528881072999, 62.68977942005281, 61.69977711093042, 56.92606041508337, 55.63635764583465, 48.361827942632864, 44.517171690540934, 42.96245790296986, 43.26136996669155, 44.71084656253938, 45.9959013231339, 46.66687765429097, 50.35837319589431, 60.324543137704175, 63.55953362680251, 62.98024269842333, 58.39745913782428, 63.03605018123504, 63.413947013116655, 61.52741247607816, 57.80743660465364, 57.286698818206794, 59.850669830076164, 58.16100297435638, 51.64463212413173, 52.342190357946585, 54.6521016090147, 56.06886563762542, 49.20152502675211, 45.33916711807252, 46.95830975809405, 48.66061449050904, 48.47208184580649, 47.39231609529065, 49.08848231838596, 46.66595981967065, 27.948438775154855, 33.96884749012609, 45.505652120036466, 52.109817381828066, 68.11864960578181, 66.18846693346578, 68.52299890210553, 70.3503684074648, 70.34461821279218, 41.23535594632549, 2.4589206230255867, 0.6876391112323731, 18.728862577869048, 36.687928630459695, 40.55529932821951, 57.8493235957238, 48.73110340487573, 62.80945093401017, 29.23981247409698, 9.25248586362408, 41.715854137174546, 32.72347142619471, 50.716442446554865, 42.001033982922955, 39.90667658467447, 56.73321708556145, 8.09449726535428, 0.37524261301563633, 0.09564363352593877, 0.1169108548351834, 0.006153265609511085, 0.053381554316729314, 0.04291610379192618, 0.060977040294317476, 0.03747299929419833, 0.01414897459213652, 0.08536654869995772, 0.09506054102413117, 0.03752693954494692, 0.03476694308882279, 0.045063023064886375, 0.04362152138304326, 0.003790414400188433, 0.031071419211765452, 0.06450572937366462, 0.04175465704212266, 0.0481384217498764, 0.013717047517157853, 0.03348017967636547, 0.03886316542423541, 0.015669858304693574, 0.03920814247741815, 0.007773521938361228, 0.08285762606969765, 0.03218043490403122, 0.028006906636179458, 0.03314587039752834, 0.04528393983961113, 0.11267318585587126, 0.008494558147034578, 0.04266148680941232, 0.044875239592886744, 0.043780503779529564, 0.03256986803945995, 0.019779428764576876, 0.06654641140372523, 0.08441585656856337, 0.021945913923123193, 0.11854911087861947, 0.08507240158055099, 2.8555688358122304, 85.07584033473846, 67.06167282596712, 41.588310426281346, 55.411068470247336, 44.038517013672866, 36.87516689300537, 27.731470907888106, 69.13165661596483, 78.81267024624732, 70.79598888274163, 75.02118172184115, 83.56745366127261, 70.16305954225602, 48.15431102629631, 5.297114339567, 4.672976501526372, 55.53135187395158, 81.122161803707, 81.80073184351768, 81.5784981942946, 76.57655838997134, 77.08350120052215, 72.26313575621575, 75.55358855955063, 79.3771856061874, 76.28726005554199, 76.93938547565092, 78.41882505724507, 73.86008170343214, 72.04680919647217, 69.40200990246188, 64.56302104457733, 66.95620029203354, 72.88400773079165, 74.00282459874308, 71.55185314916795, 75.10144910504742, 72.50156879425049, 70.51583751555413, 65.88340067094373, 66.46246017948275, 62.40376803182787, 67.37890628076369, 70.80839141722649, 67.35543481765255, 59.43350222802932, 52.34370831520327, 55.11422349560646, 50.992279206552816, 52.41910411465553, 51.505533110710886, 49.64599232519827, 50.262502624142556, 48.474050875633, 53.22315469864876, 54.31303231946884, 55.77771202210457, 55.62486117885959, 55.94642885269658, 56.43738016005486, 55.75657044687579, 57.95560413791288, 63.94956627199727, 66.50725364685059, 65.79728895618071, 65.07571012743058, 62.642895329383116, 68.11110296557027, 61.46048899619811, 64.00232215081492, 67.4173298189717, 66.16616433666599, 60.90897237100909, 59.925336068676366, 53.43298189101681, 47.032795567666334, 45.96085494564426, 45.654623739181034, 48.10550105187201, 49.15203255991782, 50.73119840314312, 52.19835704372775, 63.29393817532448, 63.57152431241928, 66.31671274861982, 61.50363114572341, 66.42022409746724, 65.17200823753112, 63.20252341608848, 59.45305524333831, 58.26624016607962, 59.32643721180578, 60.04106952298073, 53.444486202732215, 54.106696036554155, 58.897114184594926, 59.04661140134258, 51.018543397226644, 48.047583333907596, 50.617371220742505, 51.918899936060754, 52.03240548410724, 53.90904780357115, 53.73072116605697, 46.301104868611986, 30.627629410836008, 37.67652280869023, 57.02545327524985, 62.600518042041415, 68.00438311792189, 68.90328837979224, 71.2562947119436, 73.1294539666945, 71.92359185987904, 42.00855316654329, 2.2747533311766963, 1.2332428246736526, 20.93655097869135, 41.37525512326149, 44.840002367573405, 60.36758722797517, 59.453121923631244, 68.848492868485, 38.39936464063583, 18.75003553205921, 33.1908885125191, 22.70495157088003, 52.67088890075684, 49.25137442927207, 43.55441808700562, 67.10571319826188, 8.092066376439988, 0.35332836150642366, 0.10417339437070394, 0.027968663526999376, 0.06465673296441955, 0.03703089378353569, 0.06153521195594823, 0.04991186166843099, 0.06410055313139193, 0.014971528942095897, 0.028378953406166647, 0.07342703009565031, 0.02901880919272381, 0.03705489148776378, 0.03323202847593254, 0.03626857118140306, 0.01968962985331253, 0.0079241314726401, 0.06530409258219504, 0.04267145361330721, 0.20884220248028157, 0.1738622294919145, 0.10437996231860693, 0.22037619244187112, 0.10239209439004622, 0.23024090745997047, 0.12008347773864386, 0.2367081604297123, 0.1380427313908454, 0.15696570066915405, 0.12459411916713561, 0.1728788483887911, 0.15402904050725122, 0.11188694981918221, 0.1408471954205344, 0.110438629954813, 0.20956453146232715, 0.11899198630764601, 0.2480776713139588, 0.17163443048634838, 0.234604069302159, 0.12804351431588012, 0.27017745399667376, 0.48564146002454145, 6.346758738640816, 107.0149197116975, 75.09530667335757, 75.08917993114841, 68.72218470419608, 80.25322344995315, 51.22694284685197, 15.42655735246597, 68.25696806753835, 83.71621347242787, 71.90988709849697, 83.60032312331661, 86.27651706818612, 78.23546994117, 53.756495060459265, 6.17840031462331, 5.829488817722567, 59.482696594730506, 83.98365636025706, 86.38488431130686, 86.31308140293245, 79.4337304945915, 81.13414072221326, 76.68025801258703, 78.74526039246591, 84.85235152706024, 80.32883105739471, 78.96710180467176, 83.74960068733462, 78.54524304789882, 76.58037093377884, 75.72993047775762, 67.54771724823983, 70.72057739380868, 74.61465158770162, 78.58024627931657, 75.14827436016452, 77.3761413943383, 75.91724718770674, 71.92980489423199, 68.0766410212363, 67.29975285068636, 66.55601655283283, 70.43392273687547, 73.50142801961591, 70.65628974668442, 61.26213865895426, 55.090257813853604, 57.056396853539255, 52.22040076409617, 54.35743747218963, 52.87385194532333, 52.03786150101693, 51.25851400436894, 50.11242881897957, 55.18461435071884, 55.83442557242609, 58.05840946012928, 56.742140477703465, 57.48014619273525, 57.333943766932336, 56.51344276243641, 59.79190095778435, 66.3784900788338, 65.33713609941545, 65.7989912648355, 65.77482946457403, 63.71526348975397, 67.71273136138916, 60.75781599167855, 67.78155326843262, 67.30241221766319, 67.69612404607958, 60.53650802181613, 60.8781974546371, 54.396653329172445, 48.801113790081395, 49.45209780047017, 49.791857427166356, 50.355760897359545, 50.90844246648973, 52.70777879222747, 54.234894783266135, 64.98369524555822, 64.966072036374, 67.70300388336182, 63.6546197245198, 67.2922218999555, 68.06554071364864, 68.09448780552034, 64.385282762589, 60.77380357250091, 64.15696159485849, 62.19329757075157, 57.76216853049494, 56.19523263746693, 60.209531399511526, 62.295981299492624, 54.96411438911192, 50.173739387143044, 51.61839539004911, 52.72369577038673, 54.73134133123583, 58.343687365132, 56.379085894553896, 47.39373599329303, 33.70295393851496, 42.01625277919155, 64.86267051389142, 73.77161656656574, 72.22427291254844, 71.43046363707512, 72.98568341039842, 77.41949142948275, 72.85524891268823, 45.78030040187221, 3.2278311829413138, 1.8355665235750138, 24.35073887148211, 45.28661128013365, 46.44478128802392, 69.5199320393224, 59.03453834595219, 74.88280050216183, 37.50613897077499, 13.370008660900979, 51.108640240084746, 49.19041295205393, 64.48058066829559, 59.23517150263633, 53.481070149329405, 77.18776564444266, 17.3097078646383, 0.8836616443530206, 0.14701835540754182, 0.27229161151955206, 0.26391980268301507, 0.22009047228963147, 0.14197035692632198, 0.14461464729280243, 0.18472727147802231, 0.07514927235822524, 0.12453857013174605, 0.23072053978760398, 0.13092687774089076, 0.0920920882133707, 0.11017734034647865, 0.22282019678142764, 0.20018142527870594, 0.0791144745063878, 0.1342410813536375, 0.08692826489887892], [0.06251043422267803, 0.06386291648771975, 0.11235522106289865, 0.00362139385786929, 0.02944265499771122, 0.0201845916003109, 0.07193312033890717, 0.05055103563673554, 0.10269426245002017, 0.09362573495074626, 0.029610667655604984, 0.07511967838171028, 0.019460483379061186, 0.046356282902941595, 0.04353696059796118, 0.02521826615256648, 0.017698119176671873, 0.03445863866457536, 0.04473699136607109, 0.06125927474650164, 0.048544555602054444, 0.06330567179247737, 0.11467380148749198, 0.14179228744920225, 0.01856593208597793, 31.11461324076499, 74.17116488179853, 44.01025241421115, 52.22597837448121, 53.17960462262554, 62.00769101419757, 13.201829195022585, 21.993186512301047, 71.3374642402895, 67.26501634044033, 80.46614539238715, 58.49491826949581, 81.58506424196305, 56.559699273878536, 14.80681109812952, 0.28126109151109574, 31.154937167321485, 78.56633755468553, 81.42310173280778, 79.54026991321196, 82.89840713624032, 77.69771299054547, 75.13391848533385, 76.75680698886995, 76.22911484010758, 72.89694370761995, 70.59543025109076, 76.19003234371063, 73.10635120637956, 67.69319011319068, 64.96850782825102, 63.6254608246588, 61.30510037945163, 63.33196163177491, 73.8566457071612, 69.72543285739037, 71.3727028139176, 67.8097786441926, 64.96928445754513, 61.00658055274718, 52.17059058527793, 64.14380988767071, 68.91713434650053, 66.56059788119408, 64.48866859559091, 56.19386373027679, 56.588458091981956, 55.52804923826649, 52.677643222193566, 49.430709115920536, 49.02846221000918, 51.05190315554219, 47.24483105444139, 47.585787004040135, 47.21671942741641, 49.612448215484626, 52.746249398877545, 52.78795596091978, 54.26149237540461, 53.81623668055381, 52.54711066522906, 55.307364925261474, 61.77812645512243, 62.031731220983694, 62.827595818427305, 64.860999584198, 62.786963985812285, 65.33999550727107, 59.16167805271765, 62.24779105955555, 63.87755155563355, 58.73138227770406, 59.12819277855658, 54.68409246014011, 47.07916975021363, 46.07919677611321, 43.36467342991983, 43.676486169138265, 43.62596604131883, 46.64294727386967, 48.47003829094672, 55.967844993837424, 65.92359712046962, 62.84709392055389, 58.24103109298214, 59.53766076795517, 66.71118551684965, 63.41158182390275, 61.28810867186516, 60.90595606834658, 63.481902076352036, 58.65346047186083, 52.19614482695057, 42.40330050068517, 39.271291840461, 37.74780404183173, 36.4400662145307, 39.23318209186677, 43.32044478385679, 37.079804789635446, 41.03844119656471, 45.439171867985884, 46.879540720293605, 42.37706768897272, 41.02831755914996, 22.97571670624518, 24.1589290865006, 29.3663187180796, 42.782903563591745, 68.66505146026611, 65.6725222833695, 68.13565700284897, 65.82608699798584, 59.8036680683013, 27.95964498673716, 0.47729392085344563, 0.3257693290229767, 20.602900443538545, 35.50769136797997, 54.593583768413914, 47.26651783912413, 42.32454715236541, 62.02729894268898, 11.43600461944457, 24.368713132796753, 45.69721283451204, 38.15958230726181, 52.741024801808024, 33.582960790203465, 44.90367420258061, 42.73912599009853, 0.819795529448217, 0.08739311939045306, 0.037645280977050145, 0.022210555166126262, 0.11562108452762328, 0.09871624365088441, 0.039698821792919795, 0.042452957676423174, 0.04683974950063614, 0.052817472286762736, 0.04360941719383963, 0.03161558295570074, 0.034308987219006784, 0.05840231454180134, 0.02059615893109191, 0.07714908359752548, 0.039302424918259346, 0.015680956045886683, 0.026539105155895797, 0.018060827334862084, 0.04977468979514895, 0.07884331768558872, 0.047707635188294996, 0.004969133559854762, 0.014351552179563912, 0.057319947217981664, 0.0279544391894653, 0.0596370414320019, 0.006506925790510591, 0.050298548378651185, 0.07342350609119862, 0.017939662868757884, 0.013012627755562145, 0.030025653653748097, 0.022188669949349378, 0.018177378036442305, 0.027448878616034508, 0.032594038113471, 0.024579812306910757, 0.052990669444684065, 0.013814208533374533, 0.03755613898618087, 0.14443639395458086, 0.08599507787655439, 0.10483537860695394, 31.77790564875449, 85.4998250161448, 45.68430431427495, 54.521843617962254, 49.231680208636874, 35.37188714550388, 23.583980221902173, 39.54110383987427, 77.93227072684996, 71.24247227945636, 87.22714270314863, 67.40117749860211, 86.09990842880742, 63.95133526094499, 16.216216760296977, 0.24119309960834442, 34.36977255728937, 85.18064606574275, 85.08969414618709, 82.10414286582701, 84.75957962774461, 77.48548923000213, 78.67431256078905, 78.68859783295663, 78.70522868248725, 74.31375088230257, 71.93339778530982, 78.1054747489191, 76.48155858439785, 72.79602112308626, 69.17213547614314, 67.54573252893263, 65.76577271184614, 65.73849654966786, 76.721435054656, 72.77968052894839, 71.77154510251938, 71.32903898915937, 69.0525031858875, 65.49800426729264, 58.704694471051624, 65.59511430801885, 70.6429458433582, 68.06936110219648, 66.14748600990542, 58.57782540782806, 58.72201173536239, 57.31971340794718, 55.32678850235478, 51.76374666152462, 50.64051712712934, 51.917334910362, 49.44111516398769, 49.51116477289508, 48.69200914136825, 53.45340567250406, 53.88725119252359, 54.70727759022867, 57.113251609186975, 57.970928838176114, 56.84411817981351, 60.46583475605134, 64.49992187561529, 65.0582085117217, 64.10725732003489, 67.09792337109967, 64.16956417022213, 68.64661632045623, 62.910977563550404, 66.0184714101976, 67.40227576225035, 63.66426091040335, 63.044781377238614, 59.07529569441273, 50.821538432951904, 47.57549078233781, 47.61153344185122, 47.1058810910871, 46.148979663848884, 50.251916147047474, 49.25745410303916, 56.12614400925175, 67.09395393248528, 64.86358442614156, 61.946780527791674, 63.10988095498855, 69.24608784337198, 64.93402234969601, 62.39870032956524, 62.20143256648895, 64.0849547232351, 60.36744602264897, 54.72214729555192, 44.95728123572565, 43.54481612482379, 41.93517738772977, 41.552997327619984, 43.773541296682055, 44.82468551205051, 39.319944920078406, 43.040466000956876, 49.886170817959695, 50.87053668114447, 45.97678369091403, 40.72270608717396, 24.64380660364705, 27.546176179762814, 40.147192401270715, 53.584954123343195, 72.65632198702905, 67.96441416586599, 70.2747372658022, 68.19402971575337, 62.56498136828023, 27.246452185415453, 0.6312408214134555, 1.087521869809397, 21.04193525929605, 38.62440278453212, 54.18741056996008, 52.22129114212529, 50.82924196797033, 65.93581922592656, 23.46032161866465, 28.473324468058927, 31.148828075778102, 36.61325454711914, 60.74802575572845, 36.07437972099551, 51.23116331715738, 49.09396186951668, 0.3546036527522149, 0.0868827286326597, 0.08518117074404033, 0.10050521983254342, 0.05270514464486511, 0.039856789122906425, 0.07532255378581824, 0.020588791080480142, 0.047886945727852084, 0.028371024396150347, 0.06558982805619318, 0.07234783437583717, 0.02438215396156715, 0.021242808002317627, 0.02583234499569141, 0.043881313289485635, 0.06247376925462197, 0.051062939418179375, 0.012940262132624706, 0.05990036117333559, 0.1397255354470784, 0.27440733186179594, 0.16956374079229372, 0.06037239773919987, 0.12878437496481404, 0.11587534144881273, 0.1169545601512636, 0.17767717881548792, 0.19843877443382818, 0.14170570419200007, 0.1718161618637462, 0.20352549099874115, 0.08641139303724613, 0.14746100101019108, 0.2129046901339485, 0.10404279936225184, 0.1165316489735438, 0.10154278633455116, 0.1959077118625564, 0.22689374674472118, 0.15616587423268827, 0.15525384655883237, 0.2226786237330206, 0.24620682331583194, 0.1608164875858253, 50.865378764367875, 98.4960808292512, 64.17675387474799, 71.72905798881285, 73.19982913232619, 83.97804737091064, 16.198301334534925, 28.61777359439481, 85.08372429878482, 79.30604950074228, 92.70089657075944, 72.95518305993849, 94.42580592247748, 71.96620448943108, 17.348929605176373, 0.29080507615881585, 39.60991005743704, 88.83474965249339, 87.62065841305642, 85.7776229612289, 90.84558410029258, 80.97429629295104, 80.91608831959387, 83.85582631634128, 83.6457363251717, 78.25743521413496, 76.16572933812296, 81.14417414511405, 83.79644947667276, 75.86252227906259, 74.70398749074629, 70.58475355948173, 69.49826486649053, 68.5429088531002, 78.63015451738912, 70.23209325728878, 74.13033300830473, 74.52635903512278, 74.26337195980933, 65.5968636851157, 62.02544366159747, 71.53101751881262, 73.97822349302231, 68.11811616343837, 68.54252446082332, 60.01375021473054, 60.31691020534885, 57.70955777937367, 57.9085200063644, 53.98677349090577, 54.098976812055035, 55.73981408149966, 52.16215356703728, 50.752261530968454, 51.1125429984062, 54.867510334137954, 58.000397605280725, 58.218328414424775, 59.92068021528183, 60.67219457318706, 58.0430337690538, 60.24201254690848, 67.2044784792008, 68.54711363392492, 64.92715820189446, 67.39470558781778, 66.71586098209505, 70.98452152744417, 61.471138231215946, 67.30525201366794, 68.98903139175908, 65.48085958726945, 65.2249720019679, 62.59679963511806, 52.94460758086174, 51.158724984815045, 51.82557106018067, 49.85075573767386, 49.985042002893266, 52.20934752495059, 52.54563977641445, 59.3025892011581, 68.31767066832512, 68.14104633946573, 64.59309385668847, 61.770936750596576, 72.85437814650997, 67.68949524048837, 65.69137319441765, 64.3893071143858, 69.5743823820545, 62.87795512906967, 56.09044259594333, 44.89864964638987, 46.509873021033506, 44.69900492698916, 44.2779855574331, 46.222645698055146, 46.324121336783136, 41.26229870703913, 46.16745794973066, 51.45952763095979, 54.01713263603949, 52.20943381709438, 43.66326385928739, 28.445406998357466, 30.25694189533111, 50.6134763071614, 66.41701559866628, 76.08774477435698, 72.70875623149257, 71.63001029722153, 71.1100922861407, 64.65460446573073, 31.06344396068204, 0.7053353745610483, 1.5695613069880394, 25.799030911537912, 42.11274700780069, 61.95687670861522, 58.23847762999996, 49.451944828033454, 76.77849769592285, 15.71622537028405, 31.806140830439908, 61.35510275440832, 56.00167151420347, 70.03446855852681, 50.041826155877885, 61.57827777247275, 69.12418842315674, 2.31968040427854, 0.39378316652390266, 0.1517461138146539, 0.3047900112165559, 0.1848681550472975, 0.20276689541436013, 0.21838045679032805, 0.13257909956718647, 0.17388657576614813, 0.17790633103539868, 0.13882855374005534, 0.12637705091507206, 0.11915618959333628, 0.17658332783368327, 0.12366860068493313, 0.1886211278577966, 0.2109773661340437, 0.16340732033694946, 0.06642091854084885, 0.14168049989929124], [0.028303060905947804, 0.024427456570969477, 0.07711834048912411, 0.05307437604173057, 0.023077021675905394, 0.023453676464757132, 0.05771076314211373, 0.02214701391846663, 0.1344253714647024, 0.04729736829176546, 0.056921163979437084, 0.07926625184594624, 0.008210942821366893, 0.016302115456651778, 0.025501063679374998, 0.030620796718604626, 0.07281673381165152, 0.05411262436199093, 0.07422959146600577, 0.022800249430621346, 0.07462163696125632, 0.1062663312580797, 0.03231851459150353, 0.10924347150590151, 0.3453915680368101, 3.2346649323740317, 72.13871817434989, 61.30652027745401, 48.333104425860995, 60.287884666073715, 63.68537502904093, 49.94626152899958, 9.084162250641855, 48.59354980530278, 80.96967574088805, 74.55632594323929, 86.12852604158464, 72.08250276504025, 62.365846557001916, 27.45694225834262, 0.3675630718709961, 3.6394986414140273, 58.30477745302262, 75.74983258401194, 88.85404771374118, 78.51721379064745, 85.12370109558107, 81.12653132407897, 78.03846497689524, 75.28849124908447, 66.13398521177231, 61.45562525718444, 71.25136037026682, 69.79147772635184, 68.21340622440462, 66.98466885474421, 67.13516235351562, 63.795483804518184, 63.589571137582105, 63.76590128867858, 68.53731555323448, 62.334181262600815, 54.08871196931409, 57.184650513433645, 46.55516855178341, 59.44891714280652, 72.80464249272501, 66.70967148196313, 70.1282210503855, 59.0645601672511, 57.99883650195215, 59.51362056116904, 59.018895933705, 57.18020646802841, 50.93047441974763, 50.52818436776438, 49.73033897338375, 48.64767459131057, 46.46651121877855, 47.72188148190899, 48.66242270315848, 50.26325964158582, 53.81257318681287, 53.16993990252095, 55.21454203513361, 56.1752873851407, 56.24226970057334, 63.184300084267896, 57.73051892557452, 60.82604954319616, 64.15010921416744, 63.184460901444965, 63.94563997945478, 62.915198033855816, 60.42810155499367, 61.64675843331122, 61.41584065652663, 55.23400875829882, 53.133936466709265, 48.60666228878883, 43.78876009295064, 42.39550282878261, 41.69173940535515, 45.138482970576135, 47.20969054006761, 50.70916252751505, 63.53582682148103, 63.0284054817692, 61.5920296022969, 57.71699067085021, 65.84395731649091, 63.60232276301231, 64.12810471750075, 60.247652915216264, 64.09154822749477, 63.364811481968054, 58.23518676142539, 46.512583378822576, 32.443682878248154, 21.965669124357163, 19.59986213714846, 19.56783010113624, 26.567772319239957, 31.835197748676425, 35.02149005090037, 37.722316480452015, 42.0748176882344, 43.498383106723914, 40.44288419908093, 31.679156057296264, 19.967437251921623, 14.932495605561042, 20.462373687374978, 38.40610327259187, 60.7685632859507, 69.57388816341278, 66.9790598653978, 59.26297718478788, 39.845377783621515, 13.548538281071572, 0.33704608198135133, 0.6191416577466073, 16.759826867811142, 36.248038738004624, 63.76271240172848, 43.86967858960552, 65.9576040698636, 44.560172634740034, 5.216632696890063, 41.60689461615778, 35.01066823159495, 45.839179100528845, 32.94271230697632, 33.12799330680601, 51.704032498021284, 23.525856579503706, 0.4796575472479867, 0.09041014983649216, 0.125518434891297, 0.04012697684248129, 0.1565233615016745, 0.03955560165547556, 0.04077547410082433, 0.05166528370952414, 0.05820986176390321, 0.05659279954289237, 0.02206860290419671, 0.07754179558927014, 0.047617734770380685, 0.04118848742256242, 0.048280668955656796, 0.07654241857028778, 0.026857864765089848, 0.016909529334835468, 0.02825006294334608, 0.020781144266948107, 0.0643988601082275, 0.008561287278069124, 0.026543446959206657, 0.016745270507770683, 0.02926215319143188, 0.03416491289352698, 0.053894791091161395, 0.015800467677294247, 0.09916998986755649, 0.009050716912644285, 0.034555483669523275, 0.022062817025148583, 0.06918165427181991, 0.058126971050496065, 0.04657773976965297, 0.04853632781774767, 0.05542870595931046, 0.0431355994735514, 0.016113770825247613, 0.09400007615406668, 0.08405472272105756, 0.11378293316210471, 0.058120325237752936, 0.09930303635736627, 0.1681077753704402, 3.7006557468445074, 84.19372281720563, 66.43423480372276, 46.28337967780329, 61.80298643727457, 38.603237675082305, 36.80875724361789, 24.18744275646825, 60.566365103567804, 81.1681241373862, 79.8643518263294, 87.85520045988022, 81.03477924100815, 68.99519735766997, 30.370843602764992, 0.41389677433236954, 5.523614056648747, 65.27250328371602, 81.1839940471034, 89.72440596549743, 80.33896646191998, 87.22385575694423, 80.77218440271194, 81.99593251751315, 76.73801099100422, 70.20230677820021, 64.36631418043568, 72.09256756690242, 76.41176392955165, 73.44229436689808, 72.0833029285554, 67.31462647837978, 65.76680429520147, 66.73670445719074, 66.32225113530313, 68.99239678536692, 65.1550792878674, 61.93507225282731, 62.26365704690257, 52.50307813767464, 61.11605390425652, 71.27956221180578, 70.0580184690414, 69.74913966271185, 62.58047080809071, 62.08304366757793, 60.16765225318171, 62.276742073797415, 60.40068026511901, 53.26667731808078, 52.57075079025761, 50.92665010882963, 51.048114145955736, 51.21132396882581, 51.27576851075696, 49.01074486394083, 54.28566594277659, 56.94211075382849, 55.72664276246102, 58.878663355304354, 58.190087349184104, 59.278384254824736, 64.86473368060204, 62.37426396339171, 64.05703529234856, 64.77877493827575, 66.2551393816548, 65.92428745761995, 67.39603134893602, 63.58046339404199, 64.75601734653597, 63.27698176906955, 60.130840809114524, 57.33641878251107, 53.42292493389499, 46.933414474610366, 47.20147317455661, 45.55820403560516, 48.38051803650395, 49.52870953467585, 52.582176654569565, 63.695824223179976, 65.962507032579, 64.8120758610387, 60.0680789639873, 67.09283213461599, 66.08181768848051, 63.42441974147674, 62.88563512986707, 65.94521722485943, 64.19869169112175, 60.81762429206603, 48.43820041225803, 34.277063415896514, 26.924060813842285, 24.12311980801244, 25.223207358391058, 29.980048056571718, 34.264868767030784, 35.41992441300423, 39.73892857951503, 44.90921651163409, 46.486181905192716, 44.42662769748319, 33.6890491362541, 21.584630473967522, 19.02925729751587, 25.186254708997666, 49.32262428345219, 66.26787139523414, 72.01736788595878, 67.95708717838411, 60.939668839977635, 40.54483444459977, 14.146094706750686, 0.4078669882109089, 1.1153691045699583, 17.68182312288592, 40.76052558037543, 63.38942043242916, 51.3465202239252, 67.75841912915631, 52.7874578199079, 11.72130900044595, 32.6363810800737, 29.622857416829756, 43.95251120290449, 45.86974220891153, 36.59189724153088, 62.57450096068844, 27.187359717584428, 0.4989815941981731, 0.204690434939919, 0.08824556074555844, 0.03420771805629615, 0.034379497951557564, 0.06422198189783, 0.04754458486493077, 0.05580449889924738, 0.03901175200758923, 0.019332766945984577, 0.06627709319394443, 0.0531813525594771, 0.044678611635801294, 0.03889438733758946, 0.014417249964730395, 0.051733044186426755, 0.02260029665194452, 0.023884541550350767, 0.03463462821298069, 0.034894565676128676, 0.141310770545275, 0.06885652655675527, 0.1464919457512517, 0.2381631912242982, 0.11625916682063572, 0.13271296577107522, 0.1917720781338792, 0.07165102378254937, 0.18953952938318255, 0.09800927473172065, 0.14316508636599587, 0.13790501942557676, 0.2177074791923646, 0.1709614069231095, 0.12485442818292689, 0.19209516805506524, 0.12383960683139102, 0.17090330681493207, 0.13545035114211423, 0.16173464396307546, 0.19535825828150397, 0.22535740337785215, 0.18808955476889688, 0.2977902658524052, 0.7338183397246946, 8.613701405063752, 107.10220813751222, 77.79079867947486, 69.71099069041591, 79.98923224787559, 89.55779152531778, 62.30909770534885, 14.068101317651811, 58.40121676844936, 94.75618716209166, 85.42832805264382, 96.9274151709772, 85.57275756712883, 76.20748689097744, 34.874432548399895, 0.5668378933783501, 7.5612059331709345, 71.41016144906321, 84.03990314852807, 92.50885732712285, 84.6663684229697, 90.21641239043205, 86.5701456992857, 86.89886385394682, 84.25276233303933, 74.32810675713324, 66.34731508070423, 74.83731669764366, 82.00161210952267, 77.16392547853532, 76.65133445493638, 75.2387006821171, 70.1472210115002, 69.68749569308373, 67.47619675051781, 69.16411030677058, 66.45965176243936, 62.57950590502832, 62.02407083203716, 54.55246163952736, 65.16688954445624, 73.80736504831623, 69.72492294926798, 74.14815625836773, 62.77709530245874, 62.930761998699566, 63.576643005494155, 61.9238817307257, 63.50817018939603, 56.30748302705827, 55.53436425424392, 52.16372251510621, 53.0402075090716, 52.07041325107698, 52.7804877681117, 51.35489840661326, 55.81918324193647, 58.88129918806015, 56.5887914934466, 61.11146473115491, 61.56435335836103, 59.84905381356517, 67.16902025284307, 64.25642505768808, 64.403219761387, 65.21685661808138, 67.87762780343333, 66.92166774503647, 65.26443496827157, 61.919088594375125, 66.22243465915804, 66.479765676683, 61.045243355535696, 60.19798394172423, 56.313374427057084, 50.45733851771201, 49.18609834486439, 46.65137644736998, 50.56257963180543, 52.35929581426805, 55.85714786283432, 66.9221148952361, 68.18313337141468, 67.65050688097554, 62.94294880282495, 67.48562612841206, 67.19202103153353, 65.9798203745196, 65.02270713929208, 68.5385864011703, 68.10550182096421, 62.70525709275277, 51.113994275369954, 35.845152485755186, 27.058472594907208, 26.03294930150432, 26.493696397350682, 32.53163810699217, 36.57046541090935, 39.72449033491073, 43.55865032442155, 49.43448635839647, 49.9905058645433, 48.71723390394642, 35.65063822653986, 25.94297012975139, 21.322655370158536, 31.85529793462446, 59.774332661782545, 70.45644498640492, 74.96611948936217, 69.89765628691643, 65.59021526767363, 42.94987101708689, 16.737461513088597, 0.8966871615379088, 1.2188278691422556, 22.075495489182014, 43.21704718374437, 73.07348958907589, 54.6299284504306, 76.06911351603847, 55.82216424326743, 9.345524484111417, 53.96041908571797, 51.62939763838246, 64.02360100899973, 48.999966190707305, 50.22765236516153, 72.87658660642563, 44.00681249557003, 0.6263308106891571, 0.2644567690309017, 0.18144355816466196, 0.29621485200139785, 0.1986293158223552, 0.15822845871650404, 0.21660567621790597, 0.09561055384936834, 0.16516061980397473, 0.1359053460821029, 0.15940763657131504, 0.2158145372185015, 0.19488309990734826, 0.1695734547871736, 0.10956140565535716, 0.09636547987259204, 0.08916447554985363, 0.12447319984916719, 0.13382238365950125, 0.09121266524157218], [0.06030931039863537, 0.05239990074187518, 0.052235360377498215, 0.03418837050576845, 0.08910560169287267, 0.07263432061600109, 0.014287987949266551, 0.03553631753029843, 0.10163451004172526, 0.020933387004920555, 0.022300135742332187, 0.00839832313959637, 0.045399508033428466, 0.033313770057453264, 0.0547849124808225, 0.07052783929412404, 0.033825850039119684, 0.05778520007527644, 0.03842549556265435, 0.08996417175137228, 0.06448960322285853, 0.045935470806134325, 0.04220679064371413, 0.104114237061191, 0.1631041487017947, 0.19658836566152113, 35.31052950889834, 67.09367936657321, 37.57868712948215, 60.12271758048766, 56.42553852450464, 69.82007964964836, 33.658431114689, 11.71316223759805, 77.10991444126253, 81.23082714696085, 72.44271755218506, 59.61851258431712, 63.827737454445135, 28.447272085374404, 1.4270867263117146, 0.6360512407075974, 37.01084167726579, 70.2304458618164, 85.13839429424655, 83.27749636865433, 87.45871943812217, 81.2696978353685, 73.51561915489935, 69.80661023047664, 55.71807630600468, 48.49308613807925, 61.63707410135577, 65.39788969101446, 70.5640120660105, 67.64134422425302, 68.72581681897564, 66.35065694009104, 68.96460287032589, 61.50771433307279, 51.99312294683149, 38.909166859042266, 37.464518700876546, 37.30514887840518, 57.52280196835918, 73.76768635165307, 68.62729472498741, 69.41877411257836, 62.801515979151574, 59.19454359239148, 56.92156145649572, 62.14315006809851, 62.35706829255628, 59.726601339155636, 58.430140326100016, 51.63342591254942, 48.54270804312922, 51.89430275271016, 48.93397231255808, 49.894615680940696, 48.051172302615264, 53.24327253526258, 55.203445649916134, 55.7040185313071, 55.57404687327724, 56.91144566382132, 56.69518970674085, 63.67330197365054, 59.75085335393106, 61.45943387862175, 64.3364021855016, 66.13720940005395, 64.91970962093723, 64.20859959817702, 62.72455123163039, 62.88416031868228, 57.47239558927475, 54.026754210072184, 51.59295097474129, 48.190749845197125, 44.49750884886711, 43.550656534010365, 45.092861883101925, 45.32142623778313, 46.88201181350216, 54.84672961696502, 63.60647655302479, 64.30345819842431, 58.077966397808446, 63.27233768278553, 66.17736662587812, 61.281895637512214, 60.843433487799864, 58.36217349575412, 64.31039294888897, 63.41680642097228, 57.30352186387586, 46.268592342253655, 30.15451312065125, 13.05980605463828, 7.211388368760386, 5.875559016581505, 14.091918929930657, 22.984747963566935, 30.26601629872476, 35.90697296204106, 42.15177851338541, 39.151843901603456, 37.85099767869519, 26.646829651248073, 17.97964084532953, 13.018078900152638, 15.56735279098634, 31.59065365791321, 55.82242704206898, 56.31586905448668, 57.55633431096231, 39.72481981400521, 24.827075427578343, 1.8704406844992794, 0.10091917544242837, 1.265510693192482, 11.245295059296394, 38.21979068940686, 59.26124349717171, 49.742008024646395, 86.72818583826866, 17.754432078330748, 47.02316222652313, 47.99307807799309, 37.06967722985053, 50.76197724188528, 36.774605166527536, 35.49918374707622, 48.312833616810465, 5.524722126222426, 0.6599450327696339, 0.12742172671301713, 0.06340704437705778, 0.06675311724745459, 0.04964512517495502, 0.1795625671624176, 0.10680229403078557, 0.1280353861230035, 0.0397032076462863, 0.05316551752208222, 0.05416884372431425, 0.026722366793922363, 0.017457948697190133, 0.06950507361081339, 0.048630012710007935, 0.042486979641140475, 0.04083538217650306, 0.052044512553801464, 0.04716252915621285, 0.08358197752386333, 0.00840515089822152, 0.053816922084097905, 0.08002771259916407, 0.056461005606838775, 0.1246825103918391, 0.06943905981437815, 0.019328145520581354, 0.04674910980787489, 0.0385007445490168, 0.02250005404705242, 0.04295641533850182, 0.03493355955147455, 0.07517873609979307, 0.044856183155770266, 0.058973226245612874, 0.05444168210810712, 0.04908752807926747, 0.05852489627056545, 0.02148942894212181, 0.05262912957057838, 0.03503493596649459, 0.07089067385682175, 0.031962946372767614, 0.11473489699945336, 0.08732766483820255, 0.09055719275267855, 41.72719763171288, 79.01466446538126, 40.05900967505671, 65.95402686826645, 49.77022163329586, 35.0322961807251, 37.84885214221093, 27.156884862530617, 82.8044742153537, 86.71211196530251, 83.74945163726807, 69.70415792157574, 68.68177644668087, 36.19953863082394, 1.2657671181424972, 0.6611549001066916, 41.96436374418197, 74.60740304762318, 90.01597142988636, 87.77767089105423, 87.36086414706323, 85.89700421979352, 78.73351681617, 71.74590849107312, 58.724059212592344, 52.471726632887325, 67.11734694819297, 69.9910165417579, 76.23832456527218, 70.98456859588623, 72.46203130291354, 67.13409546882876, 69.44059033547678, 60.90768583359257, 57.001522894828554, 45.29716245589718, 43.68669609869681, 42.023603300894464, 55.524742680211226, 72.79513466742732, 70.4177547270252, 70.12221982402187, 65.80803625045284, 61.27463533032326, 62.17964380018173, 63.99630523497059, 64.80776125384916, 61.211991156301195, 60.782617138278106, 53.07963517404372, 52.32538692412838, 53.46426279314103, 49.79744680466191, 51.49082030019453, 51.466148591810665, 55.333907604217536, 58.72524769075456, 59.7695787491337, 61.104651574165594, 60.17983905730709, 62.4811093268856, 64.84475312694427, 63.272388673597774, 63.41556302962765, 66.69930857996788, 67.8416596689532, 67.6900286828318, 67.90007160555932, 66.37641906738281, 65.6042298962993, 62.961842859944994, 57.34903312498524, 55.69033730414606, 49.73204520440871, 48.222787764764604, 47.023699591236735, 49.06197886313162, 47.94572330290272, 51.179584149391424, 57.368692044288885, 66.41563492436563, 67.02256679534912, 61.31445523231261, 63.075211125035445, 69.43607176503828, 63.06202803888629, 64.47832138307633, 59.83425863327519, 67.12987499852335, 64.84397257527998, 63.02364764675018, 47.64174745928857, 31.36181277613486, 14.340117689101929, 7.904542271168002, 8.593895396878644, 18.464908638308128, 27.247789713644213, 32.21387709340742, 36.94104310004942, 45.19516514193627, 42.14821700126895, 42.473761958460656, 28.704456014017907, 19.387118662557295, 13.628821353758536, 16.582757349937193, 39.40565263071368, 60.46849804539835, 58.773120218707675, 59.44052327063776, 41.9061283142336, 24.63346919705791, 2.4789323104966074, 0.81722000313382, 2.1303323968764274, 14.601933936918936, 41.41146252232213, 64.643570838436, 52.86221427302207, 86.04028840218821, 26.401826643174697, 38.22714513347995, 40.47780506072506, 32.538355165912265, 50.96549334064607, 41.952953569350704, 45.58771202641149, 57.22552553299935, 8.346266361974902, 0.9292975020024085, 0.12950557013673167, 0.18080742939585642, 0.05478242269506859, 0.09798237738469917, 0.07047694807331409, 0.029185553975102883, 0.1468722011533476, 0.040114324900411794, 0.08740247332400854, 0.012339420331221436, 0.08661870409043566, 0.06659865093928191, 0.018229939328927188, 0.010795380653543098, 0.01845681052204342, 0.05149380641899282, 0.06845370220441012, 0.019009587009467425, 0.02756552507860526, 0.10691071845470898, 0.13099000338585148, 0.21802194296352326, 0.09163254271111182, 0.13898740973203413, 0.14825509710898324, 0.16983179495699946, 0.11522737662157706, 0.14555857486782536, 0.09761712198416073, 0.10855917878929647, 0.17129888397551354, 0.2215167441435399, 0.16956908808600518, 0.18717596427567545, 0.12022063045972779, 0.11428053791244185, 0.2338780324545599, 0.15232123134116973, 0.19370137864062864, 0.11657615102106526, 0.19467322245961238, 0.09309938658149013, 0.19641668535768989, 0.25325788124915094, 0.41508326066597817, 61.5992271515631, 93.25525299195321, 56.859266373419, 80.29559289255451, 78.85140757406913, 93.05459237867787, 41.743773568061094, 18.506558325982866, 90.98921345126246, 95.69481034432688, 87.19387315934705, 73.59738488351145, 74.02203636784708, 37.88955065511888, 2.073300644274681, 1.2751906124814865, 49.89537269838395, 78.20000387007191, 93.8051300664102, 91.74305377467986, 93.52781065048711, 92.49501920515492, 83.33286454600673, 77.2508373568135, 64.76759618328464, 54.946075408689445, 70.1212941446612, 75.04517093781503, 79.80921899118732, 75.23237782139933, 77.01934691398375, 71.61294014223161, 76.17783377247473, 64.376018124242, 56.86724447434949, 43.62322430456839, 41.32911236055436, 40.24679314705634, 61.36104514521938, 77.63242906139743, 73.88583598598358, 72.65628276332733, 68.57212266614361, 64.07891427316974, 63.06415004114952, 65.49154020124867, 66.39283026418379, 62.94826753677861, 64.44378883607926, 56.55710658719463, 54.40816156325802, 55.47355182709233, 53.3912714066044, 54.671631090102665, 54.09791777210852, 59.252265191847286, 60.05557837024812, 60.67587767877887, 64.17014468100764, 61.857887852576475, 63.526244471150065, 65.2631994216673, 65.87819176335489, 63.631179640370036, 68.1934727391889, 68.83531370470601, 68.63040124216388, 67.37528201072448, 66.86207909737864, 66.02604942937052, 63.689724937562026, 59.100069384421076, 59.54853357807283, 51.418942866786836, 50.23483030257687, 49.65484119230702, 52.492409290805945, 50.45591469733946, 53.7214369158591, 58.9683287374435, 68.09085569074078, 70.09425332469326, 68.4647987734887, 67.69553569055373, 70.83836617008333, 63.9584465180674, 65.02970072530931, 61.094865260585664, 68.9611590293146, 67.39166182856407, 67.42218571324503, 52.72631199129167, 33.879229176429014, 15.083128348473581, 9.939699826701995, 10.779369454230032, 20.976592494595437, 29.013689794848045, 35.498948404865885, 42.692316424462106, 51.996806052423295, 47.621919878067516, 46.858877674225845, 30.95173878054465, 22.143532922191007, 15.479105345664488, 21.788223058946674, 44.777338581700484, 63.03550889415126, 59.35134818477016, 63.29797821660196, 42.09239382897654, 28.1454574677252, 3.3750931389870185, 1.1861866400126488, 2.2841312279624324, 15.542832093854106, 47.10119385873118, 72.08945320498559, 56.86505186942316, 100.86529439495456, 22.865300024709395, 61.24752783006238, 62.05293555413524, 53.16484866603729, 71.2294029420422, 51.19066876749839, 57.315210526989354, 71.2514623518913, 19.565949324638613, 1.3881041277800839, 0.22037073789585024, 0.2532146738902215, 0.23457460556059118, 0.27834171429276466, 0.2281981186881181, 0.2369223586133411, 0.32609752108973844, 0.1608004150611739, 0.26530295910854496, 0.16399524685355926, 0.26481033392971565, 0.09841446629575185, 0.21243146230136195, 0.09726573277505175, 0.25213760023395865, 0.12914291943513578, 0.24572535237718016, 0.23336113761028937, 0.18153245500739545], [0.07556448435230602, 0.006489484362499488, 0.024478286504745487, 0.004149149434881345, 0.010869087887957934, 0.02123020202552359, 0.08391553220609504, 0.0174685379475235, 0.009930853303822299, 0.06107473565686134, 0.13288683708636992, 0.01838287154603149, 0.03227719563930746, 0.06226638925351924, 0.03928121960451526, 0.04066757444712905, 0.03791034356841157, 0.08629405134988409, 0.12857567729248157, 0.04163002985860071, 0.04834050425298272, 0.0480187971205, 0.050475461063005274, 0.024821484318724083, 0.0538167956795904, 0.09463344700634481, 10.738900399977162, 75.95974999089395, 49.45336080366566, 36.62338210690406, 71.79103928227579, 44.849878895667295, 58.983331803352606, 11.697591408606499, 32.847367332827666, 88.12032130456741, 78.34485700053554, 79.05449221211096, 59.351822791561005, 26.570841573899795, 2.11030894229489, 0.21477025212539783, 14.288776805323941, 59.62543949004143, 76.11663695304625, 84.46715124191778, 84.65946505146643, 76.4743963364632, 73.56977139749836, 59.519923810035955, 46.56727298613518, 40.66203486534857, 48.25008746116392, 49.89342720277848, 66.01530997983872, 66.28087797472554, 72.40135223634782, 68.28138089949086, 67.96908178637105, 58.79350869886337, 45.13755729121547, 21.456718060278124, 15.309150026690576, 40.68272536800754, 61.293929469200876, 63.83474672994306, 66.28748324609572, 65.24559582433393, 63.87253092181299, 58.14195594479961, 59.13706910225653, 60.29075584103985, 65.66906275287752, 63.18288410863569, 64.32542347138929, 55.015858296425115, 47.327651900629846, 49.40619037997339, 50.84809680138865, 47.21248719000047, 49.81154380306121, 57.69750041346396, 59.18695380610805, 56.55461195976504, 59.872207564692346, 59.15370387415732, 61.262730936850275, 61.79302361703689, 57.695554917858495, 48.59008243007045, 66.57950370542466, 64.45870168747442, 63.82760801622945, 61.72258177111226, 62.915221568076845, 61.18442081635999, 55.747027320246545, 52.607381805296875, 52.90497595264066, 47.10397481918336, 44.87313855078913, 42.47074565579815, 44.87104400511711, 46.97192038259199, 46.85129965505293, 59.93605982872748, 64.27423261827039, 59.97920197825278, 60.32230738670596, 65.00862975274363, 65.0489987865571, 62.02986417278167, 59.884684624210486, 62.82653285611061, 64.54801797866821, 60.02049276905676, 55.922953467215265, 47.927531350043516, 31.024734089451453, 15.47319531440735, 5.1571945701876, 2.05756286940267, 6.030196009143707, 18.11064212552963, 27.0999163581479, 32.281571319026334, 35.267477573887, 36.09038691366873, 33.806826145418235, 24.09099363511609, 13.782222309420186, 8.240609476643225, 7.30927994174342, 24.326965385867705, 35.78774859828334, 39.83846264500772, 34.73734178850728, 23.280979087275846, 7.9377593532685315, 0.8631968005530296, 0.2565607007953429, 0.5781544216217533, 4.06363261803504, 45.95639128838816, 55.13039935019709, 67.11755091144194, 61.34108028104229, 17.652179810308642, 69.22627987400179, 41.92144124738632, 45.907891181207475, 58.421228701068515, 94.12891387939455, 41.17924644101051, 41.30751971275576, 1.0125134656986883, 0.15525308047090808, 0.04133582528259966, 0.03255571839549849, 0.024520162785906467, 0.043369145207707925, 0.06568596442981113, 0.03191715729753337, 0.05663177809647976, 0.041761911894765594, 0.028348892116017883, 0.026273615470516588, 0.04318653282919719, 0.06574290008434365, 0.04866810260160316, 0.07501857775834299, 0.11115619386996954, 0.03600491436138269, 0.05263602819233652, 0.08391481974432546, 0.028694453311242887, 0.06325495677189001, 0.0873603538099316, 0.02396047618540545, 0.021876006484812787, 0.05401491367768857, 0.028236281021588275, 0.033836341613242706, 0.061852291917368296, 0.020616917998620102, 0.004831457504957554, 0.07912464815402225, 0.08157479651873151, 0.05392887434291263, 0.004674587595922452, 0.09944126926242344, 0.0901997744316055, 0.003967223183867792, 0.02605459284818461, 0.06297426215643365, 0.03466007765382528, 0.12556987769541242, 0.057083593771582654, 0.05837454768498579, 0.0834106802639942, 0.1831798198362512, 0.09551330664826017, 13.004727152086074, 92.89925867511381, 52.22187165291079, 45.76387351559055, 80.6454683119251, 33.17446947097778, 43.79207057337607, 24.346118319419123, 49.678787262209006, 89.72897944911834, 83.38494577715474, 76.28526749149447, 69.35283906998174, 31.370938170340757, 2.5607232893666914, 0.15146796261110615, 16.204881110498984, 63.03384188682803, 79.93247555148217, 87.41044290604131, 89.52850710961127, 80.63675280540221, 78.42309259599256, 64.04564080699798, 48.31426528192336, 44.79664056531845, 51.99584899410125, 57.582237643580285, 74.19408721308555, 70.31625947644635, 73.81339765364125, 69.627271621458, 71.97614377544772, 61.416782025367986, 46.03237544336627, 25.433016900093328, 18.815372413204564, 41.45294550926455, 63.01797589948101, 68.37321927470546, 66.81339463879986, 66.01464317690942, 64.12452359353343, 59.174731700651115, 61.7471867992032, 63.731568782560295, 66.57172956774312, 66.28171736194243, 65.93163797932287, 55.56563338925762, 49.57917082694269, 51.115971149936804, 52.48007735898418, 50.451800131028705, 52.7279789986149, 59.023802818790564, 61.26014217253655, 59.6018111321234, 62.358307761530725, 62.29136466979981, 63.45911310565088, 65.02061259362006, 62.57762316734561, 55.34751822871547, 69.01053382504371, 68.98936087085356, 64.87535153665851, 67.34842161978445, 67.84356594085693, 64.42001927283503, 60.776133460383264, 55.78647067469936, 53.67883605341758, 50.795529196339274, 48.408606129307906, 44.88978508980044, 48.25580627687516, 48.87592907874815, 51.43598948755572, 61.375761878105905, 66.14958840031778, 64.8383165174915, 64.65605966506466, 67.04638342703542, 65.10210767869027, 64.52365613752796, 63.47546546689926, 65.79610832275884, 65.6410413403665, 62.35966490161035, 61.07820303209367, 49.927779320747625, 33.36621453685145, 15.958318960282112, 6.265918199093112, 2.60322829888713, 9.246884719018015, 22.886223908393617, 29.874353908723403, 36.18595546291721, 39.47534138156522, 40.98838783079579, 36.96507153972503, 25.269106934147498, 15.187976244957218, 9.100703866251054, 9.437289314885295, 28.190719658328643, 38.48166381159137, 41.27199088373492, 35.802473175910215, 23.188311130769794, 8.879973465396512, 1.9759577128194996, 0.5739780779807799, 2.581227969738745, 5.6618388718174355, 47.173392926493, 61.804618143266254, 68.44274720837994, 67.88241309504356, 22.72480268632212, 69.48823928833008, 37.73222830987746, 40.441840848615094, 67.92996006627237, 90.43800277094688, 50.424829913723855, 53.00230172372634, 2.4461601722624997, 0.25606816754706446, 0.012378032120215076, 0.0948361691928679, 0.04190263458557668, 0.04330257599752757, 0.04235192983140869, 0.03522246279903958, 0.009162312940574222, 0.056956258467248375, 0.013815115389954901, 0.007526791831027837, 0.0314596553348125, 0.014225062444776058, 0.012733700887991056, 0.08287768225155531, 0.11103660754498937, 0.03948588382392641, 0.044955023819760936, 0.05013138416313356, 0.04075323839882209, 0.1934877167185468, 0.18096833850347227, 0.08614395940375906, 0.11153297889376841, 0.17808865996137743, 0.06374405794626763, 0.20965951104317943, 0.15198956123523175, 0.09693940996282524, 0.15664500094229178, 0.19816177236216687, 0.16240448060054935, 0.14500621015266066, 0.16517846965261046, 0.16219671755548448, 0.20030395338131537, 0.19113501473780603, 0.13303859910416987, 0.1637555379420519, 0.09046662583827011, 0.2333938189211392, 0.19192593923259169, 0.1867040234708017, 0.20364880051103332, 0.2666890266681871, 0.37376997752055047, 21.549327181231593, 108.61878471989786, 66.57298472619826, 53.83580930771367, 92.50665295508601, 67.18056771063036, 72.66896770846459, 15.966345110247213, 43.05466890335084, 104.40424503818636, 90.29958232756584, 88.51914005894815, 70.90083383744764, 36.77082007931125, 2.9494081101109906, 0.3193703804525637, 18.675141795989006, 67.86074592221168, 81.00126651025589, 94.57830767477714, 93.04993260291316, 85.2914216441493, 81.22714011899888, 72.01947812111148, 54.59345040782806, 49.44492770779518, 56.338846298956106, 61.41225953255931, 79.96720421698787, 76.4442019308767, 80.49059744804137, 73.4126647826164, 75.54311583119055, 65.6430378267842, 48.15996708408479, 25.65082415457695, 19.859754462395948, 45.99461086334721, 69.08424300532188, 71.86132815576369, 70.98534522518035, 69.26904939836072, 68.93982133557721, 63.04752703635924, 64.33113836473035, 64.64486522059288, 67.54819577740085, 67.74229818774809, 70.82561062228295, 60.60785593525056, 52.946851176600305, 52.40781161092943, 55.00120039909117, 51.056727670854144, 55.466409191008545, 62.39942989041729, 63.61511361214423, 61.31500044176656, 63.94922502579228, 63.232827648039795, 66.36360860640004, 66.87060633013326, 63.03659146831882, 52.82200997875583, 68.73315165119787, 68.85563158219861, 65.31346459542551, 64.8009559416002, 66.44207169932704, 68.29670952212426, 63.23098021168863, 56.66474426946333, 56.10486122869677, 53.91954798852244, 50.098877030034224, 47.72034783517161, 49.198253770028394, 53.27607531701365, 56.89754478393063, 65.23222054204633, 69.15686176669213, 66.3255145472865, 68.90339036141673, 70.27465881839876, 70.39349878987959, 67.07042755619173, 66.27380986367503, 68.56281095935454, 68.99350289375552, 65.38065087410712, 63.74421842636601, 57.06392388189993, 38.215295653189386, 20.50252110727372, 8.316030771501604, 4.539677692997841, 13.88326942920685, 28.7649703410364, 33.72468386926959, 41.522598958784535, 44.20135028900639, 47.1393742099885, 43.79714219800888, 27.361148172809234, 17.785756126526866, 12.179420263536516, 11.027993790564999, 31.149802784765924, 40.53206712968888, 42.69873342206402, 36.902042973426084, 26.171134402675015, 10.688149832910108, 2.9971416390711263, 1.0127048038186566, 4.286158238687824, 7.026065693747613, 53.625527120405636, 65.86972728852304, 79.57349238857147, 73.38215658741613, 28.450272698556226, 83.37585372309532, 53.699338282308275, 71.524106302569, 68.93509880188974, 99.73688340956166, 59.43447105346188, 72.58703724030526, 4.318670274749879, 0.425281239252898, 0.1264325769678239, 0.2998030852646597, 0.1600355375558138, 0.11773868178528164, 0.17170527829758583, 0.10467860637412918, 0.19019317092193713, 0.16147815772602636, 0.14747665984736336, 0.09930614667433886, 0.14238130181066452, 0.2127856553922738, 0.1504027633176696, 0.18344321618637732, 0.270947985230915, 0.15143238548790255, 0.1633702110378973, 0.15464866774216776, 0.1390503974811685], [0.04649459624723081, 0.0720977985991105, 0.06863070681931512, 0.0314023481276367, 0.023292361330541394, 0.05168050204613998, 0.0669194196140574, 0.027906470594086477, 0.01902989408512029, 0.010184752078907145, 0.07864950510162501, 0.06549631170327626, 0.04327988064277076, 0.06939857206757992, 0.004395410792166067, 0.01021613965877482, 0.08431467933640366, 0.05323509362736537, 0.018014772044074152, 0.030463315854449908, 0.10046348336242861, 0.0454664143222955, 0.021654720072664564, 0.0519725539150738, 0.04407929722219706, 0.03312542351082929, 1.1492051857133065, 57.30030944270473, 70.4563351600401, 39.87899641836844, 43.97921469903762, 49.33139470315749, 52.46882800132998, 39.56127266730032, 16.776455756156675, 91.69323967349146, 81.488981862222, 86.7203018742223, 50.70964497904624, 28.272687389004616, 0.4172806459809504, 0.5355842639842342, 3.54978937775858, 33.76713175927439, 51.553138917492284, 70.81270602441603, 65.88373799477854, 68.27097877379387, 58.230428926406375, 43.705135160876864, 32.45687577032274, 25.224305622039306, 24.720749778132287, 34.86534441671064, 54.99017069416662, 68.78422875558176, 69.8009620174285, 66.78009371603689, 67.06939205046623, 54.754373488887666, 44.17783960219353, 8.317938023997892, 6.744054142505893, 37.563660529352006, 56.72361120100945, 58.97096064782912, 63.589143599233324, 63.61529011880199, 64.06854744880431, 66.12673667169386, 59.16336859426191, 60.00729007105674, 68.84526868020335, 68.79077911376953, 63.30261838051581, 59.27083369224303, 52.108424940416896, 48.7694053496084, 49.89134442421698, 49.84942213181527, 54.0062362917008, 59.97100422459265, 57.80670312143142, 60.05124807357789, 60.33122293410763, 61.758530293741536, 62.13485033281388, 62.629206257481734, 54.65646720701649, 37.48313819208453, 65.76048927922403, 64.73525231884372, 62.11789392655896, 63.57678421082036, 64.2542677540933, 60.63113912459343, 58.00195086386896, 52.549530767625384, 48.46280936271914, 45.71177659496185, 45.03836839429794, 45.676679226659964, 47.190843551389634, 49.07542082571214, 58.589059076001575, 63.34053201060142, 63.79244004526446, 61.150680588137725, 58.65979509968912, 66.95997361213931, 62.16530753720192, 58.422366188418486, 57.220877524345156, 67.64270920907298, 64.24553263571956, 59.771477176297104, 56.95182254237514, 51.38685003403695, 35.03862296381305, 25.366779834993427, 11.065878983466856, 4.139261553364416, 3.0364432979014615, 11.403690172779946, 22.974261506911247, 26.24851296024938, 35.76732873916626, 33.829630805600075, 29.664940526408536, 18.933451444871967, 10.81741056134624, 4.923067804305784, 0.32027356747177343, 13.678013759274638, 21.91228762749703, 19.525486153941003, 13.158809619565165, 6.747289607601782, 1.5014493489457716, 0.12570423419557272, 1.172084616076562, 1.5123106371010504, 4.550925089466957, 48.477816350998424, 56.508696694527906, 69.98068501872402, 39.190141923965946, 34.90543103987171, 19.447327044702348, 38.964648785129675, 51.30180128159062, 60.18096477754655, 52.99604162093132, 49.16748669839675, 28.058114128728068, 0.24294091388583186, 0.023758232803835024, 0.05750160581702667, 0.10478057267685091, 0.09175335477677085, 0.03423252398328435, 0.04688470737047253, 0.05845543124803132, 0.062383516436262484, 0.05771047968958175, 0.01094152820446799, 0.019550021820431276, 0.04687898086323854, 0.05697847118661289, 0.05418237283705704, 0.016624554203102188, 0.039922906341211456, 0.026327710854069843, 0.09829629723343158, 0.0348413072436327, 0.058501653162942785, 0.024856532841259917, 0.02229506998593288, 0.021913205799196037, 0.10503549609453448, 0.061315279604206165, 0.022205223194173267, 0.03477652684875554, 0.040433331572961424, 0.02822252782812763, 0.0327362853192514, 0.049724112670387954, 0.07460166504907031, 0.019989281314455216, 0.04122894452584367, 0.07155098802139682, 0.043417787960460114, 0.07869976813033705, 0.049770376720135255, 0.026017290111931584, 0.006117592246512012, 0.097379389579498, 0.029848539871313882, 0.01685837189847183, 0.03121873408916497, 0.10939041483065776, 0.12408814873666534, 2.095599073556162, 67.917204518472, 81.75837809039702, 37.531952088879, 59.64624766380557, 45.86603949146886, 37.57304676117436, 39.04266472785704, 35.41072645495015, 101.48152228324645, 85.58299495327859, 93.58001739748063, 59.96900773817494, 33.6407490699522, 0.37932886471671445, 0.4677144510130729, 5.585294798497231, 34.97741829964423, 56.26431342094176, 73.2183034958378, 71.01040917058145, 73.3198771938201, 63.946612727257516, 51.00938466287429, 32.99341286382368, 28.282371720960064, 31.138433794821466, 41.43564393443447, 61.47941050990936, 72.96083127298664, 74.90638963637814, 69.64924473916331, 70.08938958567958, 59.98263797452373, 47.33191943937733, 11.757055521011354, 8.872683740431263, 43.62933927966703, 59.948509431654415, 63.4033291570602, 66.54850129158267, 67.40495866344821, 64.2332830736714, 69.2477979967671, 63.33409932351882, 65.0409226263723, 67.94943071180775, 68.85647881415584, 66.19647641335764, 61.19328145057925, 52.53994841729441, 51.909090088259795, 51.60145467327487, 51.347716546827755, 53.8527500244879, 62.44738478814403, 62.563526168946304, 62.45400182662472, 63.791918370031546, 64.79934384745937, 66.74930311018421, 65.4007294870192, 57.948234004359094, 43.07049566699613, 67.50421816302885, 68.03466381565218, 64.75256566078433, 66.44582148521178, 66.30152533131262, 63.75006275792276, 62.151547862637436, 56.69689986013598, 53.24580246402372, 49.590098550242764, 47.53307427129438, 49.93432575656522, 50.44277475726221, 54.09276377770209, 60.54351337494389, 66.43367782715829, 68.24937435888475, 65.5803858080218, 61.601874751429406, 67.79681128840294, 64.91992142892653, 61.88787045017366, 60.52390544645248, 68.29718805128529, 68.6511976488175, 63.574842637585064, 58.47239994233655, 53.94858137253792, 38.952136424279985, 26.425717799894272, 14.164712236773584, 6.061970639613367, 6.249781568204203, 18.999372759172996, 24.41461074736811, 31.174819661724953, 37.74277164090065, 37.811526867651175, 34.22895554573306, 22.19477084375197, 11.160452231284111, 5.574935328575873, 2.6442065258179945, 18.563050262389645, 23.913812329692227, 19.995366488733602, 13.694381810003712, 6.2605494549197545, 1.2429189441665527, 0.46268980289178513, 2.2405735523469987, 2.3563553008341023, 3.5507537905246984, 55.0404005665933, 61.56350220403364, 76.88596279390397, 42.09196629062776, 38.891202403653054, 24.276941437875074, 31.99231613066889, 55.88755799878029, 61.611845416407434, 60.217030971281, 59.55118902267949, 33.99471159904234, 0.3735464637077624, 0.034084086787075765, 0.04626367436421495, 0.0248335674405098, 0.11790664656268013, 0.08637328016301317, 0.007741833190178319, 0.13716666388415522, 0.032686504925931656, 0.05470479883614087, 0.01744565681644505, 0.11869534940248537, 0.0782815913759893, 0.011689935777065976, 0.0905485206373757, 0.03545181803225029, 0.030593732747459607, 0.0669427929566272, 0.008126178065374976, 0.04266242143667994, 0.02353908760743516, 0.12492511511570024, 0.19380095474902662, 0.21111147748606823, 0.2315106522291899, 0.1529314816598931, 0.14517560751447756, 0.14024148034232278, 0.12516921371101372, 0.11676167453368826, 0.08862128090714255, 0.1927996165449581, 0.19435497421410777, 0.13078816986132052, 0.18044851720333102, 0.15764724313011094, 0.13310163281857967, 0.08787618379198736, 0.14731098567285847, 0.10192769955122664, 0.09380424109798285, 0.19675315117403386, 0.18092012092951806, 0.1822149780608954, 0.07749251315310117, 0.24337926939610513, 0.20100078695724088, 3.1967324258819705, 87.6071576149233, 91.33664131164552, 59.37969515400549, 64.6813864092673, 69.143337434338, 71.59157106953283, 49.52481854346491, 22.784116768067886, 110.70440307740243, 95.55518181093278, 98.58676602763515, 60.69313610753706, 35.690799374734205, 1.0724618069587217, 0.6818879972542486, 5.109936873758993, 39.994831854297274, 57.90504086402155, 76.73682643521217, 77.40005216290875, 78.35511792090632, 66.5998294276576, 54.606064750302224, 36.07589375588202, 28.384978963482766, 31.29419503673431, 46.1270300803646, 67.89809473099248, 80.26855207258656, 74.11032107568558, 74.42890382582142, 72.61561562938076, 63.556125087122766, 52.07974456971692, 14.98730778694153, 11.521166140033353, 52.29381184424124, 65.55456876754761, 70.344022012526, 67.90347622286889, 70.66215761246221, 67.49555756968837, 73.13754973873016, 65.49131270377868, 67.83055936136554, 69.89239246614518, 73.12423721436532, 70.35797780559909, 64.84103079765075, 56.23406410217286, 54.196420254245886, 54.429703220244384, 53.975798699163626, 57.64860414689588, 67.67678676113006, 63.286544507549664, 65.89636018199306, 66.38815479893839, 67.3569723867601, 66.79680301297095, 67.51297289325346, 60.89540097021288, 45.76829010440458, 67.75648932303152, 68.88353532360446, 65.12166069399926, 67.00684593569848, 64.84045420923542, 66.3136846788468, 62.440830507586085, 58.87145011655746, 53.89402512581118, 51.016668504284276, 49.40704545667095, 53.71529840653943, 52.17723900272001, 58.77103744014617, 66.63077692831716, 72.36762769760625, 71.27415718570833, 69.45467948913574, 66.30200386047363, 70.98916561372819, 67.00136246219759, 62.624958330585116, 61.690732125313055, 68.4989155492475, 70.43568780345302, 66.894956404163, 63.62106384769563, 59.73645041065832, 44.87346018514326, 30.96826764845079, 17.822181217132076, 9.321057719569053, 7.98976262730937, 23.86327455120702, 27.882511577298565, 38.949410377010224, 43.80082922597086, 45.4743359165807, 40.30863323519307, 26.477279316994455, 12.95622802549793, 7.549756044341673, 7.284147845160577, 22.796301611008186, 27.000201863627282, 20.718288729267737, 15.8672179906599, 8.11147867671905, 3.1721183273100086, 0.714372025141793, 2.0898368666248937, 6.115468826986128, 7.555205197103563, 59.52314407594743, 64.57194443671935, 84.64906292576944, 48.25523753320017, 49.017687459145826, 28.690715951304284, 57.70883998563213, 73.33256998369771, 67.00427286086544, 73.45711308140909, 67.27559889516523, 50.47842910212856, 0.21653147294156014, 0.1699583220385736, 0.2029418392527488, 0.27675211249339965, 0.285836934682823, 0.12065409832904417, 0.10687442120885658, 0.20691872424175664, 0.1541561038503724, 0.1863120162799474, 0.07221229810027346, 0.17391617740354232, 0.16220045606455497, 0.12794343258945212, 0.23949212394654754, 0.12376159609806155, 0.1513768900786677, 0.16234886261724657, 0.20789220748889833, 0.17393975758985167, 0.207078576148037], [0.046512492061142004, 0.08501883671288529, 0.027772004926396955, 0.06444151588385144, 0.03335546056229261, 0.01949969558946548, 0.06417900436527788, 0.04585151523051243, 0.08395487082100685, 0.013451506120843754, 0.04281181624279388, 0.062443673490516605, 0.06921825029196278, 0.10795098924708944, 0.025861977276602582, 0.13488240419856964, 0.13180674504368536, 0.08880764711648227, 0.14020469280019884, 0.11974477494556098, 0.06228629987867129, 0.0948929746124533, 0.05597810974464782, 0.02866922412067652, 0.10704103001062909, 0.25085086363457865, 0.19016281851837713, 37.140907472179784, 85.80038839770903, 60.402523779099994, 49.31998845069639, 59.01215730174896, 48.04051914522725, 62.30914869616109, 12.34831948434153, 48.97482772027293, 91.72170823620212, 69.35903641485399, 63.08451106471401, 27.425092612543416, 0.9291052445769311, 0.12423942045819376, 1.122598645667876, 12.768797566813808, 35.607986373286096, 41.82889292317052, 45.090433935965265, 43.42303437571372, 39.858607938212735, 27.27850187209345, 15.522124921121906, 9.852240777784779, 9.70160803487224, 21.518346340425555, 42.501057732489805, 64.63702440261841, 67.6452273707236, 66.87116330669772, 68.814713416561, 57.70219156819006, 32.73155543111986, 10.260320248142367, 9.143982318139846, 33.82157817963631, 50.74305180580386, 61.45917107982021, 59.61918723198676, 67.56373620802357, 71.80166890544277, 71.21458422753119, 63.28279472166493, 60.712928387426565, 66.44648828814107, 64.8985758904488, 58.25005254437847, 57.72403132530951, 52.710073378778276, 50.84002064120386, 50.234991119753936, 50.91285513293359, 53.2172554539096, 61.12554996244369, 60.3490226499496, 62.3940013300988, 60.07229551192253, 67.26762863897508, 63.87457055430259, 64.3762848454137, 53.911420837525405, 44.73814233656853, 67.45039539952433, 63.13530183607533, 62.79196108541181, 60.02291679382325, 61.70347198363274, 56.80996218035298, 56.37349651705835, 54.16747316237419, 49.771496403601866, 44.89029107555267, 47.16964706297844, 46.08931649115778, 46.28288938153175, 54.94932705356229, 63.28780358837497, 63.33289123350575, 60.99519783450712, 61.1434163585786, 56.49702372089509, 63.62796721919891, 60.43925677576373, 57.57252977740381, 60.50235594472578, 70.64041983696723, 65.66571697112053, 55.022722444226666, 52.34032330974456, 48.32983316913728, 39.32436150889243, 30.090996219265847, 20.277896773430612, 15.342585290631941, 6.937011220762807, 8.972067775264863, 17.180587360935828, 23.286715553652858, 28.407734594037457, 29.65512871742249, 24.165259791958718, 17.025516456173314, 9.454366334023016, 3.6576604410525295, 2.6215639085538927, 3.545560572416552, 7.182453534295482, 6.851604061741983, 3.1849873786972416, 0.9872225131238661, 0.33502832896286444, 0.17184749485984926, 0.03143894414777958, 2.233588791662647, 0.7884308479485974, 35.27616170144851, 77.70264733222224, 67.72183910492929, 32.45345742471757, 45.430719160264545, 44.27248247208134, 46.37424922758534, 46.04109094988915, 40.6028502218185, 43.01057754024383, 63.63500395128804, 4.683636032765912, 0.29330439204650544, 0.06632069891859448, 0.07356691775062392, 0.08471925036921617, 0.0430224176436182, 0.08644334656456787, 0.04318703844722721, 0.06470091325501282, 0.0841540766639575, 0.02918710147270993, 0.029455667001105128, 0.10414084329480126, 0.013337221124299593, 0.05605982834353082, 0.03592447895977286, 0.0780072246467875, 0.014113687624734257, 0.02550590727027626, 0.04024226924464588, 0.0650984286180427, 0.038201142883589195, 0.03633383038123289, 0.04781697891772755, 0.017666307375616124, 0.08421982232961925, 0.06632355642655204, 0.010213792556896806, 0.05770806651262026, 0.01593845639182555, 0.09703265052408942, 0.024744377569145253, 0.059548217367621205, 0.008962239503049323, 0.030978674692432248, 0.10888327228566332, 0.060254014172260804, 0.09313513224403705, 0.004303804871010324, 0.055243718708234454, 0.11980289803637613, 0.020404022164462556, 0.017876521902038686, 0.022963646408771316, 0.03791121307820563, 0.06028948787359461, 0.12564562846936528, 0.07432105470328562, 0.1560450008799953, 43.85946473767681, 99.7633437187441, 65.86595396841726, 51.09799492743708, 64.22553247021091, 29.833778950475878, 49.139426062184, 21.549221277236942, 75.75195850864534, 97.80542204456945, 79.65015119121921, 65.72548997017645, 30.43913991220536, 0.583273972715101, 0.6796250348129581, 0.9539291899531119, 14.453627159518582, 38.4161013941611, 44.88144220844392, 51.736180243953584, 49.690644587239916, 46.46797034048265, 30.917010115038966, 16.810084196829028, 11.910870286726183, 12.143967920734037, 28.4977686789728, 51.53547256223617, 69.20524028039748, 69.53235026328795, 68.0337538257722, 72.56253027146863, 59.072601026104344, 40.21056221377465, 12.461143520570571, 13.634375429922535, 43.72071089283113, 55.63017206807291, 64.6033626217996, 64.2417710827243, 70.41748016111313, 70.31800885354319, 73.01469326019287, 65.89122187706732, 65.06446469214656, 69.28389949183311, 68.6542727870326, 60.995582226784, 59.91166660862585, 55.06515856712095, 52.94785530336442, 52.17985914599512, 54.64810471380911, 54.64981486720424, 64.21349471615207, 63.3251759313768, 67.61013000242173, 61.19349325856855, 69.15729322741109, 65.40892724067935, 69.24162418611589, 57.90931624750937, 47.46946127183976, 70.78513960684501, 65.85912119957709, 64.34099920334356, 64.28361885009274, 62.9496011426372, 59.11206399240802, 59.503253736803615, 56.634530252025975, 52.30730872000418, 49.710574150085456, 50.103474047876176, 48.26222719684724, 48.62455221914476, 58.29657577699231, 67.26845233671128, 68.26726036687052, 65.74025377150505, 64.73768026598039, 64.36605138163414, 66.58310444124284, 61.74175039414437, 60.645985295695645, 63.64553159283054, 73.16023672780683, 69.14431018214073, 59.69965073370165, 56.36132148004348, 52.33831897858651, 42.13667738822199, 34.592194480280725, 20.997781138266287, 18.746321047506026, 10.028846475385851, 13.61561571398089, 22.083865827129735, 26.450415003684263, 31.86743570912269, 33.76092656966179, 27.783314835640695, 19.517331546352757, 9.13323796564533, 4.923424739991465, 4.943827929035311, 5.196243726438092, 8.840024125191475, 7.906543660548426, 2.9745495223229934, 0.40660720258470506, 0.35170419381991513, 2.132966023299002, 3.961386233568192, 2.8595958842385203, 0.658824950937302, 41.09964586073353, 80.72783024080339, 71.35589153535905, 36.08500149942214, 44.754322113529334, 37.892143341802786, 44.55345753700503, 51.16871918401411, 48.179214154520345, 49.594770093117994, 70.70894364387759, 6.327098838744625, 0.3077176008974352, 0.04087329203743608, 0.07236672610404991, 0.03635146955568944, 0.04203014992057316, 0.08808616849203264, 0.08883350258392674, 0.05638774461863984, 0.08566928366499563, 0.09463299501446948, 0.0351081203459011, 0.046821803891009865, 0.08659906925693636, 0.047266337900392474, 0.0655483673777311, 0.01450943811270859, 0.06275485074448009, 0.0627337335308473, 0.08125231180700564, 0.0457879031197198, 0.017100873200463194, 0.18811000931647517, 0.15365177284806006, 0.14655508671797093, 0.2287745385641052, 0.15409961252683593, 0.10035537303455415, 0.22882202069365212, 0.18179189834383228, 0.19531367196431085, 0.14792903476665098, 0.13658549426303757, 0.1704734548806183, 0.1264676178294805, 0.2888701832102191, 0.2400746572041704, 0.1818091200003701, 0.1826233029245369, 0.18021542729148943, 0.34170466264890087, 0.16396094143631, 0.0898316998275057, 0.19190102605329407, 0.12711961227919788, 0.19150137330495542, 0.2147779436481576, 0.3792285071986337, 0.3130070702923883, 59.074844621842914, 110.27185193953976, 82.6680306465395, 69.45395777302404, 83.26124991140058, 71.55164134117865, 78.49058089717742, 18.472869088572843, 61.63139450934626, 108.66013434625442, 81.78435987041843, 73.55288167153635, 33.45455808024253, 2.305988390599528, 1.4068284198161096, 2.6489753925031234, 17.6493380531188, 44.07990978610131, 46.79129915852701, 53.024063033442346, 54.58531541209067, 46.55254448613813, 33.43955893670359, 18.568669057661488, 12.343608717764578, 13.430022885722499, 29.876379812917403, 58.310711999093336, 76.05333774320542, 76.66416060539984, 72.3832779545938, 77.82418589438163, 64.34101489282423, 44.198298685012325, 16.181623416562235, 19.04268945417097, 51.90485000610352, 59.49598558487431, 68.62816549116566, 65.74799653022521, 73.81462927787535, 74.58353150275447, 74.6244888920938, 69.51951626808413, 67.207624220079, 70.21294424610754, 72.15592168992566, 63.60699038351736, 63.30740759449621, 57.71276627817462, 56.830656605382124, 54.49587360505135, 57.72282323529644, 57.9829744369753, 66.68834163296607, 63.93670874257242, 70.39985302955874, 61.62584827792261, 72.03206108462426, 68.21983891148722, 70.35382009321644, 60.92351651960804, 50.223510342259566, 68.66693419794883, 66.50007570943525, 65.83659895004766, 63.57130073731946, 62.58369891874252, 61.62897440694994, 59.9310705738683, 59.64412173917217, 54.874817709768976, 50.13028344800396, 51.48771770538823, 50.165533788742565, 50.51105537722188, 61.55290788219821, 68.94555584076913, 73.70383016524777, 68.88086026714694, 70.78210369233163, 70.38321433528778, 69.7835623833441, 63.28648567199708, 61.486721807910556, 63.76491677376532, 73.68509692530479, 69.1308250734883, 61.77821666963639, 58.311959312808135, 54.601942339251124, 47.252813077742054, 39.939420530872965, 27.659648387662827, 25.128558604947983, 13.212237204274825, 18.046554519284157, 25.419096408351777, 30.613399051850845, 36.15394892231111, 39.31160596109206, 34.31716965090844, 25.26712613721048, 13.112532515679638, 7.379505076716024, 8.807454724465648, 5.770279659378914, 8.712631425549908, 8.596982302204255, 4.225137435620831, 1.97187501576639, 0.8148070713204723, 1.5099706981451282, 2.978053669775686, 6.279803879799382, 2.189570482700102, 44.84064171391149, 84.381910293333, 75.81760329584922, 46.33601004077543, 56.415760055665054, 58.52612072421659, 70.39738193635019, 56.2817208997665, 58.276799186583496, 56.75337806824715, 89.59819978283298, 10.97212354983053, 0.6965203378950396, 0.17936099410778095, 0.1720949106158749, 0.1541947453252731, 0.19390975455603293, 0.19726370281029135, 0.12007790827943433, 0.1538877892157724, 0.13339098422758042, 0.15875249350022885, 0.09763278082133302, 0.18314730706474475, 0.25217461760245985, 0.1063407643608028, 0.09966738777415407, 0.16580264744979722, 0.10608035575358138, 0.11569099005071387, 0.18640595398122267, 0.20580998051070398, 0.13547564736537396], [0.0749568846978007, 0.04708197884141438, 0.03984155929497173, 0.0526661814130362, 0.07640174184475215, 0.039021132754222046, 0.02590529571828102, 0.044423741844272426, 0.06209868111557538, 0.03203992288739931, 0.015594176478653908, 0.08165677558750876, 0.052059298050740076, 0.09428673859445319, 0.02521322912446434, 0.046019893695390036, 0.09209764235082174, 0.0020797527536013795, 0.08083360645199016, 0.0036933424416929488, 0.06705557642083976, 0.10580256461135804, 0.0382447600995581, 0.06210701615219155, 0.13612506009878653, 0.20945283584296706, 0.05096191923404413, 6.34197933058585, 49.51817012602284, 60.13246859273603, 53.28956827040642, 65.84483592740952, 67.78483236989668, 57.25328022433866, 68.3984479596538, 14.462749611946846, 67.1987125950475, 73.82885963686051, 75.37803896011846, 35.91615523061445, 0.09454396793678885, 0.5174380312523534, 1.4025478882174338, 1.157628843380559, 13.813125683415322, 18.942000250662527, 21.421387310950987, 15.279371392342354, 16.99791669845581, 9.719456780341364, 4.5462873770344645, 1.5301170945167544, 3.4968503732835097, 17.265498830426125, 34.27572196529758, 55.306756957884765, 65.5945534090842, 63.71132543010097, 66.11863305491786, 51.110660260723485, 27.203037431163175, 14.881497929173133, 13.888183178440219, 34.338393595910844, 51.0295731021512, 58.046728641756125, 64.83706528140654, 66.7367358361521, 66.03530622297718, 71.67398006685319, 61.75177989467498, 55.211988572151434, 67.0151456709831, 61.925187879993075, 54.6032210319273, 60.50029670038531, 54.890569948381, 49.84021240665067, 50.285075864484234, 52.53364124605733, 53.24011110490369, 63.544554095114435, 61.79620858161681, 65.54794388432657, 61.4705498756901, 63.890993518214074, 62.112955662512014, 61.873043890922304, 55.32583144403274, 45.767760584431315, 71.28218235508089, 62.9926020868363, 62.02270192484703, 58.44037771224976, 58.82651152149324, 57.71727308150261, 54.378108362997736, 51.117704837552964, 47.274527319016, 46.72603091885967, 46.5447703484566, 48.19861811976279, 51.82388444100657, 61.19023376895536, 63.88137586655156, 61.03793990227484, 60.38046044688071, 59.49445193813693, 54.082267515120975, 58.800984736411806, 59.50142983467349, 58.566438767217825, 62.603832444837025, 71.89335823059082, 64.24827437247, 54.31361283025434, 49.2187128528472, 45.39760651126985, 39.72627893570931, 33.95036920424431, 24.516192290090746, 31.22694011657469, 26.940358261908255, 16.379393243020584, 11.26754274291377, 20.25297207217063, 22.08008073991345, 24.297365219362323, 18.685836138263827, 13.212963823349247, 7.114762250454196, 3.739652441393945, 3.5798820468687245, 0.16683177932375864, 2.133156748548631, 0.46891154000355356, 1.1418238979193474, 0.24781317179722173, 0.5478419159208575, 1.3402255936976404, 3.1177182399457504, 0.9509748484819167, 0.9132584400715367, 28.409595758684222, 90.54772715414725, 52.173359778619584, 35.663162354500066, 47.15262789880076, 35.958540362696496, 47.31619465735651, 43.3312548360517, 36.78243029502131, 64.31180892452117, 23.164865163064775, 0.23052730176958347, 0.04214736137298807, 0.05239679808578184, 0.0556240085842869, 0.0884720086750965, 0.06564960589692478, 0.02703283541655589, 0.044346612112055865, 0.03968368772597563, 0.00622794098754023, 0.014557311904706783, 0.032283427764571486, 0.03023972734808922, 0.05146138174759765, 0.027615801513855977, 0.0013582615605217496, 0.07636252580390823, 0.03220966115834252, 0.02786094773440592, 0.08254045800816628, 0.04435874311433685, 0.03735550821969106, 0.07005155477071963, 0.06401738662633204, 0.05906396552980427, 0.041648006111743956, 0.02661912303958689, 0.0160009260740011, 0.028386587472332102, 0.01525963067017015, 0.006195547438466982, 0.016659133496784394, 0.003967298835050315, 0.10933648990166765, 0.09516396289390903, 0.09400030598044397, 0.06200629091190715, 0.11303508579130135, 0.03698705823250836, 0.09550463453295732, 0.07425316399143589, 0.02215840756112049, 0.05557979381973705, 0.04212978731600508, 0.03505206952292112, 0.0657610716899076, 0.09670457337051631, 0.34484899392531765, 0.22442185680472085, 9.503322416736234, 62.37915515899659, 69.81416471542852, 57.03866381799021, 72.8415519960465, 54.79950820246051, 32.60057376277062, 46.0231186497596, 32.649158200910016, 87.66185114460608, 78.63647737810689, 81.13047722847232, 33.86092739720499, 0.2909041466491838, 1.60099518154898, 1.2759551069428845, 2.392786765290845, 15.377409073614306, 20.061891848041167, 21.93855574054103, 19.706346642586496, 21.098527216142227, 12.112405588549953, 5.919054179422318, 1.8626171494683914, 4.4215805203683916, 17.976087177953413, 39.432214921520604, 60.62179603884297, 69.29150104522705, 64.48744481609714, 68.6611447795745, 57.087791504398474, 34.24473524093628, 15.673734334207351, 18.474281141834876, 44.408776990828976, 56.30115232160015, 61.61361440535515, 68.22471049524123, 71.17618422354423, 71.02910318682271, 70.84552841801798, 66.36104337630734, 62.27355318684732, 69.97346001286661, 68.19933276022634, 61.980987518064445, 61.85750346029959, 58.1463921454645, 52.127915197803134, 54.622636764280266, 55.23502465217344, 54.8256782562502, 66.27187221280991, 66.51314504684942, 68.86440200190391, 65.03098726272583, 68.15798313386979, 68.05172612590175, 66.5249906047698, 59.03349107311618, 48.19932806876398, 73.0601849094514, 66.03088963416316, 64.71355768942064, 62.43128345858667, 61.562725574739524, 61.232332568014826, 58.921574084989494, 54.87728488060736, 49.856682439004224, 48.54349251716368, 50.51502873820644, 50.83589823015275, 54.48624418627832, 64.71585227597144, 69.32233871952181, 65.94792366027832, 67.7307350404801, 67.53092950390231, 61.055425828503026, 61.56303936435331, 60.72359723429526, 61.66395802651683, 65.59162339856549, 72.56296957692793, 69.31763972005537, 60.52887901183098, 54.00942517865089, 50.045823051083474, 41.68432612572947, 39.394752364004816, 28.71425409470835, 32.088861350090276, 30.921385518966186, 21.439285086047267, 15.327798935674853, 23.528094291687015, 26.73485548265519, 26.93319993634378, 22.67609077115213, 15.777237838314427, 8.272467947775318, 4.673882569036176, 5.550122905162073, 1.074645341404023, 2.6922352131335967, 0.46506225461921386, 0.9402492498197864, 0.6545863396698429, 1.7344597102172914, 2.6832895125112226, 7.8296647148747605, 0.9904429628964394, 0.7932915226105721, 29.512291685227428, 94.30177273288851, 54.16551589965821, 44.48380800985521, 48.17929260192379, 29.813710143489224, 44.366399703487275, 46.73343243137483, 42.33825583611765, 72.75931558301373, 26.736461693240752, 0.37795600451288686, 0.20837013910133995, 0.05329812734177517, 0.05747491531374474, 0.05450112287015204, 0.061473059242651354, 0.03743613514328196, 0.024153484377048673, 0.03918367362911663, 0.09745091920898807, 0.06662891907317024, 0.059414416281206, 0.07054187402489685, 0.04426812257377371, 0.06975690969416211, 0.04872581200493921, 0.07044287248244209, 0.025169077562168244, 0.035714375516099316, 0.07486998734454955, 0.061265552837041125, 0.07097937151669495, 0.21327575248095298, 0.1435116338994234, 0.10084622855027837, 0.10736209745969504, 0.15048833533881173, 0.1695689808336958, 0.1411958726783914, 0.09950043423281563, 0.12816359093713184, 0.06610612535188276, 0.09936389438207112, 0.30786208507995455, 0.2595499758758853, 0.1790614077641118, 0.17597612654489858, 0.16136713626403965, 0.1669779029344359, 0.17932511054940764, 0.19757364666269672, 0.1455954849840172, 0.23260153078984833, 0.22057249481158875, 0.11735967510650236, 0.2420949383128074, 0.2409244019297823, 0.7723533590474437, 0.4991796432483581, 14.010829810173282, 92.80891864530503, 86.5864392249815, 79.01940268854942, 84.51779688558271, 91.91269628463253, 76.43943232874717, 80.30930549867692, 24.340448533335042, 83.21774298144926, 88.17263787792575, 89.4686988092238, 44.03570075188914, 0.3133010029071762, 1.875848529800292, 3.523250376024554, 2.2650773342578643, 18.48777017285747, 23.217313135823897, 24.02350925630139, 22.017109047982004, 21.853603086163922, 13.806466479455272, 7.273598140285862, 1.6042663156986239, 7.129086746323494, 22.577941302330267, 48.615754342848255, 66.55337287533668, 73.12007165724232, 67.80515809212962, 73.3815525424096, 61.018967397751354, 40.79465804561492, 19.25945924174401, 25.95599828227874, 53.8625834065099, 61.40883922576905, 65.45834910485053, 74.80983657221641, 74.57292541380852, 73.40423168674593, 73.2874470372354, 67.42452344586773, 64.42648726124918, 74.12128017794701, 75.23171101847004, 68.13906162015854, 68.27744283983785, 63.422164378627656, 56.60049192367062, 56.894532403638294, 59.18918955710627, 59.702965136497255, 70.44416012302523, 68.86905393292828, 72.79769205277967, 67.47506710790819, 70.50002251901935, 68.63529636013892, 68.07103987663024, 60.13261764280258, 51.14903673048943, 75.29575547864361, 66.52745385323801, 66.61352634429932, 62.09235145199684, 62.56001957001225, 62.542698383331306, 58.92680260442919, 57.608337094706876, 52.05288810114707, 49.46508476811071, 51.522418914302705, 52.03072670967349, 56.31147207752351, 65.76421945325791, 71.98827958876088, 70.14210624079551, 72.52517361794749, 73.37464917090632, 66.21809651774745, 64.19811118033626, 63.47212360751245, 63.680385774181744, 64.93245732399726, 73.86805980436264, 69.00814902397894, 59.892046913023925, 54.34533303783786, 51.51166377529022, 44.71065044403077, 41.39807547292402, 32.653553216688096, 36.816594139222175, 36.798927783966064, 25.395764189381755, 19.57786548522211, 26.794740269261023, 32.15573580034318, 32.20968996324847, 29.397444686582013, 21.680187256105487, 10.56168673499938, 6.6857745858930775, 5.908259326411832, 1.2431942455230223, 3.7648193490120674, 1.561433910842865, 2.015958656707118, 0.759440180995772, 1.8393604361241864, 2.8049817825517347, 10.047458121853492, 4.244416865610307, 2.0774576212129285, 37.09871453623618, 94.31274752463065, 63.378626069714954, 55.49645062415831, 54.1911760453255, 53.336213096495605, 60.363037278575284, 57.032348802012784, 53.43768481285342, 82.34824765113093, 44.306458042513945, 0.3391599943560939, 0.3921794380632139, 0.14761740552081218, 0.1773301869510643, 0.2009513742861248, 0.14356607210732278, 0.10274865469264408, 0.1375921491173006, 0.09962147612485195, 0.2140661713577086, 0.17679573337156929, 0.16427272389973366, 0.11454763446724224, 0.12570490069206686, 0.1846091100765813, 0.1543718954968837, 0.22085332732287147, 0.13245516186279635, 0.12175046974011969, 0.23169359402550807, 0.16111703920027903, 0.11342903884548335], [0.015771855250932276, 0.050290496794567, 0.08459532032570533, 0.0707112254214383, 0.031918597542831016, 0.09136644973149223, 0.07886719664618855, 0.04723283304502407, 0.038344998874010584, 0.010764929616162855, 0.020085839036431526, 0.05351820908066246, 0.05529018577128168, 0.07804691566214447, 0.16752364864993483, 0.04857401168274303, 0.038664944004267454, 0.10742121646481176, 0.05616670526984719, 0.027445090311248938, 0.09085795887175108, 0.07863568487547098, 0.04006788082000229, 0.07437195358497482, 0.10994911509295625, 0.05740890151730949, 0.3852134924982825, 0.255910046999493, 17.104924840311853, 61.73352126152285, 48.22105015477827, 44.56788401449881, 76.07103547742291, 55.33924987239223, 89.8890749100716, 17.225529878370224, 25.610939533479755, 73.61790672425302, 74.68155153336065, 31.73713064962818, 0.5248128226207149, 1.9470232460767993, 0.14372836017320234, 0.49601030686209285, 0.4310337015457692, 3.7468168956618157, 6.051483202365137, 6.837021179737584, 6.865937873240441, 3.932557548246076, 0.8153682766902832, 0.44095760451689847, 4.482461098701724, 14.994195468964117, 33.53920675093128, 50.870281727083274, 58.69762636000111, 60.59794410582512, 60.4126395717744, 51.81542781091506, 28.455654190432643, 20.690681126809892, 19.00057104326064, 33.49762962710473, 51.230017985067065, 58.62953009143953, 54.353758288967995, 56.872908376878314, 66.48748490118211, 59.16614955471408, 49.8345406593815, 60.41329852996334, 62.945278690707305, 49.0951778042701, 52.0275652793146, 55.366023971188454, 54.61671790769024, 52.92075957021406, 51.47812751031692, 50.70611876826133, 52.085051536560066, 66.55320813578945, 64.67737382458103, 64.26918060548844, 60.72846489567911, 63.82372879212903, 61.76656723022462, 65.47998489872103, 58.9792525383734, 34.95368011536137, 73.52295398712158, 59.81757287056216, 63.20720280370405, 54.07031213083575, 57.83913327801613, 53.08205135406987, 52.42143008016771, 48.9403030180162, 49.26416920077417, 47.46802176198652, 49.88793980690741, 50.768892380499075, 56.72033994428573, 62.195443107235825, 62.05976047823506, 61.97479409556236, 61.05581414315009, 53.2326429120956, 53.84108097322526, 54.08605652470743, 57.53389443120649, 59.677610935703406, 69.00449337497835, 68.2807376307826, 63.486275519094164, 46.07378390527541, 35.050664640242054, 37.305741156301195, 37.31670418093282, 36.02234555828956, 30.854026655997004, 33.441480898088024, 38.04715541101272, 27.516734869249408, 14.819723540736785, 18.077753051634758, 18.019092044522687, 20.8164381980896, 15.936965577064024, 9.611028740482947, 5.776385809144666, 4.208228588104248, 2.740036402979205, 0.7118320453070826, 1.2692081399502293, 0.5389114757699351, 0.41607399621317465, 1.097627979132437, 0.5987329528697076, 6.114715731913044, 6.852151232381021, 0.9666223475529302, 0.05932366167525611, 30.634950514762636, 63.17793407747823, 51.33936582073089, 38.14241017064741, 32.458554544756495, 46.85003272948727, 50.132409372637355, 39.639370979801306, 53.524800654380556, 44.954676781931234, 1.759136934434214, 0.23097835901764133, 0.10241370573039017, 0.03740542650883717, 0.068635088842242, 0.022881362820044163, 0.01658044477564193, 0.020164081511358102, 0.03549710915033375, 0.02893925287700709, 0.0362596845614814, 0.04562385305161438, 0.03579858390073623, 0.08210184968887799, 0.044554497731188615, 0.04052499782354121, 0.0239170313392195, 0.015117290576228933, 0.04318371362563583, 0.015911299532519716, 0.07011550012975931, 0.014496358119011407, 0.06983403176549943, 0.04030402359222213, 0.02594120800495148, 0.0723163251795115, 0.0809950671429115, 0.03846301471874599, 0.07672502328791926, 0.09378904957444438, 0.05087651192180572, 0.04383408013851412, 0.05109542154616887, 0.048089798149322315, 0.11539650585262046, 0.07201169797730061, 0.04970338999203617, 0.07886186467423555, 0.10169548297961874, 0.07920489586409062, 0.03661482377097972, 0.08733547127415096, 0.03209885803141421, 0.05954412645810555, 0.04455308812940794, 0.026870849955406402, 0.04053451263556077, 0.15946452626057211, 0.07638975256873716, 0.266986207495774, 0.22539325629270848, 22.708395411891324, 81.13600777041528, 54.644625571466264, 52.1775371028531, 78.46135923939367, 43.99547292340187, 77.9077402237923, 30.544190791345414, 37.72761560255481, 79.77196431929066, 83.31817919208159, 32.73478158058659, 0.43496137304652127, 1.7467037564323795, 1.6059795334454507, 1.4104312393934497, 0.43397256804089396, 4.9586378182134325, 9.150384606853608, 8.267802288455348, 7.663948987760852, 5.627968224786944, 1.8326536734257977, 0.6194670918968417, 4.023842624118251, 17.16294453990075, 36.61730635550715, 55.64151164024107, 60.83273718433996, 63.570276998704486, 66.97599257192304, 55.153149097196525, 30.022193924073253, 23.920390144471202, 24.462930425520867, 40.73304545494818, 54.476803041273556, 62.41211483555456, 63.27883312779089, 65.99298384881789, 69.19320644870882, 64.31415450188422, 55.5977419114882, 64.42788362503052, 70.25894580348846, 61.46690991617019, 56.88536190217542, 58.02480651486305, 58.91631026421824, 56.22826683905817, 53.48186639047439, 54.85539413267567, 54.34279918670655, 67.96905040740967, 65.76856543940883, 67.5599785773985, 63.382493526704856, 67.26653037532684, 64.04666454561296, 71.21303096894296, 62.32340651173746, 38.5299874121143, 74.10103290311753, 65.5866066871151, 67.15047528666835, 56.928500129330544, 59.83154827548612, 56.04564128383514, 56.90607986142559, 51.78061285326558, 53.8600181764172, 49.890924730608546, 51.0902129450152, 51.60070157820179, 59.6917236235834, 64.75982989034345, 67.21833229064941, 67.31233581419914, 68.21947805343136, 60.062964193282596, 60.73168516159058, 60.04580774614888, 60.11992485292497, 63.658138090564364, 71.05275507896178, 74.32587885087537, 68.31189693943148, 50.69500669356316, 39.698532089110344, 42.25689018926313, 41.96640337667158, 39.9751337112919, 33.02086553265972, 37.15034861718455, 39.22281134513117, 31.29920194225927, 18.332552179213494, 19.628489555851107, 20.62987458321356, 24.718551289650705, 17.84011233237482, 11.954025183954547, 5.682207249826001, 5.12296453599007, 4.735404945188954, 2.2456307132397932, 0.8013176725756738, 1.535649720218874, 1.841081621185426, 1.2580596607538963, 2.681227326393128, 6.669767883516128, 4.558508501898858, 1.0279157553468983, 0.04876356864828737, 32.504420780366466, 69.94241053058256, 58.634421287044404, 51.62472609550723, 29.841480524309222, 42.24377770577708, 54.02660123763546, 47.36432213937083, 61.48789067422191, 54.099541633359856, 2.0695307562428136, 0.18465236340078617, 0.08888100769611136, 0.047940012638366995, 0.03161400672979653, 0.026412369315362266, 0.06703961114849775, 0.04154630793979572, 0.08284645650776164, 0.039186358767291235, 0.04493190711664577, 0.03562251391309885, 0.05198253221028755, 0.01541735572485073, 0.011460373700115711, 0.06630199105148354, 0.02342010074625573, 0.026518089448912974, 0.05195128348385615, 0.030253775485400713, 0.09502763754778332, 0.03350371006695974, 0.06440426102809368, 0.13366407925082793, 0.1526145051203428, 0.13024334345133076, 0.1369700244357509, 0.1614966510885185, 0.12102972656007736, 0.1670054667779515, 0.18859983061350163, 0.18853402366080593, 0.11351534631103279, 0.12043004059382986, 0.2839331449039521, 0.21231969007320944, 0.15859725344325268, 0.22945814946245766, 0.21472793342846058, 0.09408707309874798, 0.131351443668527, 0.16887944041480943, 0.07633918310485541, 0.17219367467107313, 0.18302749091338727, 0.14002060187199425, 0.1280302303512731, 0.3067237703550247, 0.16572850546048534, 0.5552821005544355, 0.43750968791784783, 36.868922479691044, 95.87029718583631, 71.02786371784826, 66.21972037899879, 93.79028781767815, 79.93986529688682, 107.7504425664102, 26.155209579775413, 36.10676673150832, 90.37395046603295, 91.19632244110109, 40.39438409190024, 0.6776300192840639, 8.5999515364247, 1.2384826209275954, 2.1482801821924027, 0.7729377309160849, 5.595770958931216, 8.327318372264985, 9.345900051055416, 9.06173021562638, 9.037058507242511, 5.3184162416765774, 1.4247638251512282, 6.517258776772407, 24.87699151039124, 45.301861455363614, 60.36767352011896, 66.73227217889601, 67.55899798485541, 73.72056299640288, 60.17235125264814, 35.433648786237164, 26.468967814599317, 31.549870814046553, 49.09981796818395, 61.17498359372539, 67.74603228415212, 67.59495042985486, 69.97462887917796, 70.33937008150163, 60.363943346085094, 57.80447521517354, 69.61276669656077, 77.80084779185634, 68.46908984645721, 61.75818904753655, 63.54125145942935, 63.442399886346635, 59.91697749783916, 56.35456323623658, 56.82166653294718, 56.41312422290925, 71.59732910894579, 67.32061986000308, 67.92036594883089, 66.88986516767933, 67.33187706239762, 65.54763401708296, 71.72184867243614, 61.52873039245606, 42.01455439290693, 74.5713564657396, 65.00970840454102, 67.96646948783629, 58.07585224028557, 59.5880671470396, 56.63800547199865, 57.95216029690158, 53.98172147812382, 55.67309848723873, 51.97196175975185, 53.31569125575405, 54.47882698428247, 61.206464536728404, 65.43261835652014, 68.20045455809563, 72.251509851025, 71.76611654220089, 63.76228094100953, 63.60225608271938, 62.01946596945486, 61.351035256539625, 64.267713639044, 71.1652486555038, 74.58547699835994, 69.05392308388987, 49.97097246108517, 40.66177206654703, 41.872117442469445, 42.674226453227384, 42.075464879312825, 38.8636673650434, 41.49138865932342, 43.927235449514086, 36.20787366744011, 23.24136510972054, 22.66426286389751, 24.461955716533048, 29.36626772726736, 23.721951553898474, 16.966465173229096, 7.489779082036788, 7.3415193730785, 7.107479389636748, 2.5704345876170747, 2.307215847315327, 1.6908903900654086, 1.2312362871823774, 0.9035095115823131, 3.218073796841406, 12.752014725439011, 16.471307123861006, 5.18823326595368, 0.2291984150126096, 39.649165138121575, 78.91482445501512, 63.96019197279408, 44.500784027961, 41.16438065805743, 68.6007873473629, 64.33912431040119, 57.59988830935571, 69.12425902581984, 76.35445810133412, 5.125399837570806, 0.37697253147921256, 0.282684329656824, 0.10347482943606955, 0.16324976669444194, 0.26372135526710944, 0.287998283221837, 0.11613722094484877, 0.15164233954443088, 0.12298325076699258, 0.18902044352744857, 0.183337633948653, 0.2831255963012096, 0.23079532529077224, 0.08370944689358435, 0.1584635098134318, 0.1273041705210363, 0.07797582270277124, 0.10124358303484418, 0.0921142281543824, 0.20554834616280374, 0.12350779882962666, 0.12420285508156785], [0.1207851300076131, 0.07474642502324236, 0.05801031118138664, 0.05526603101902912, 0.03290101720560943, 0.0570519236967929, 0.017683088531597488, 0.06751893704096157, 0.039100840372303804, 0.048105778743422804, 0.03873743890454212, 0.04609236944346659, 0.03956214021590929, 0.0628115872161523, 0.03641236205435088, 0.02718479470199635, 0.02954340896629278, 0.04609827215092317, 0.05908537002640867, 0.05424256819570738, 0.06652928933861756, 0.11518334954856865, 0.12018369736089823, 0.03562969598738897, 0.05812486047826468, 0.09214314797352399, 0.11620977713215737, 0.22710163236385394, 2.435081192562657, 56.627379771201845, 70.06372159527194, 60.380754624643636, 64.87577515263712, 45.16072673182334, 32.459584166926724, 33.95335412794544, 23.17818553216996, 67.3023965281825, 64.8980502928457, 34.93906536409932, 0.15242382583598937, 2.798256878891299, 0.8615669944593984, 1.4332205778168094, 0.31937874613269684, 0.8312899126641212, 1.8738741067148026, 0.4290888494541569, 1.6009948138267764, 1.0292390036967494, 2.2968556419495614, 4.3990822953562585, 7.634006104161663, 17.228128448609386, 27.86764579434549, 42.01731574150824, 54.92824431388609, 58.43158375832343, 54.92392578432637, 46.46672694913803, 30.8822363422763, 19.905465764384118, 19.7063740991777, 36.08999859902167, 49.59125957181377, 51.47531124853319, 46.88065075105237, 45.561526283141106, 34.64240081848637, 26.02095861588755, 42.66910383778234, 52.164459920698604, 37.87476724193942, 33.042285596170736, 52.19789420404742, 51.08969911452263, 53.4373474890186, 50.90511237421344, 51.45961784547376, 51.949270848305, 53.450279543476725, 66.22167371934461, 65.89173962993007, 65.35893663283318, 60.762671885951875, 65.54134253532656, 62.21025005463631, 72.02436539434618, 56.975117498828524, 30.632024426614088, 72.66863822937012, 62.796416897927564, 60.773066166908514, 55.748380537955995, 54.76687800499701, 52.62377339024698, 53.16327971796836, 49.18926761996362, 48.806922820306596, 48.10506174641271, 50.99153787859025, 54.292777199899, 57.8417730331421, 63.007840494955744, 63.99439896306684, 58.557809552838734, 58.50271594139838, 55.46802912988971, 52.460893046471384, 54.498501593066806, 57.677331586037916, 62.02999361099736, 67.21960313858526, 68.18183114451747, 63.068186160056825, 45.169999214910696, 31.625486266228464, 31.546597596137758, 35.25573007522091, 37.65892705609722, 31.99955290363681, 34.67501532646918, 44.86585863174931, 37.083797762470866, 16.600433511118737, 15.441044626697419, 17.424849041046635, 14.596338675868127, 13.290775802827651, 7.35317861841571, 3.473855233000171, 3.8681890022370125, 1.3330232640427928, 0.9025819936106283, 0.17261277073093, 0.5007367935632506, 0.3035603788110518, 1.528816461082428, 3.520746432965802, 4.205944788071418, 6.958628383374984, 0.38393237898426674, 0.13841492754797782, 34.54556534367223, 58.256245966880556, 20.36949980643488, 20.36005081668977, 39.46713186079456, 45.418955972117764, 42.37721673903927, 46.23016488167548, 54.00511449383151, 11.875161028677418, 0.2677189859171068, 0.3590282701676892, 0.14976045988019437, 0.061019523700158444, 0.08612858401911874, 0.1584710481186067, 0.05953918136055431, 0.04708346505198748, 0.036936324059722886, 0.06656284398970104, 0.04933456462177058, 0.03604614138302784, 0.047624116282789945, 0.03542177589429963, 0.04226717752434554, 0.0746894663860721, 0.055078802960774595, 0.03391232221357284, 0.05101904258011811, 0.07207637878074762, 0.02691033412702382, 0.04414373670794791, 0.008781200477613077, 0.03712409987084327, 0.04480904193534967, 0.03684414453023384, 0.056395826846241, 0.027300834039887114, 0.08847768538661542, 0.0488384384211273, 0.04012835580074499, 0.040108713306366436, 0.046518011724636446, 0.019322382624170954, 0.011242873677533242, 0.04963960168102095, 0.06073478414046188, 0.1644074787656146, 0.01830628956668079, 0.03283598783215688, 0.058980151680448366, 0.041991753593808225, 0.07971448222956351, 0.08774735078576111, 0.06195137772949473, 0.0723296934137902, 0.0399921760113249, 0.09339915678626107, 0.021351234341460853, 0.06265789082634353, 0.08748602287303056, 5.353991158546941, 76.63679030633743, 77.81838863126694, 57.98230371167583, 72.55379123072471, 50.66947206374138, 30.61821964479262, 30.610280767563854, 40.27187278193813, 71.07929383554767, 75.63636625966718, 37.124719850478634, 0.18617651064790067, 2.3626112361108107, 2.6549386209057224, 3.1477579570585683, 0.9510409771915406, 2.1091427726130334, 1.8268405982563574, 1.2015550992181225, 4.011456514558485, 3.1340012242717132, 2.5272519886493683, 4.2913504762034265, 7.484745700513163, 16.09912028235774, 29.362192384658325, 47.27911256974744, 56.691039839098536, 61.75023448082709, 61.25625118132561, 52.715552929909, 33.71474850562311, 23.88904844560931, 24.066823990114276, 43.65449343958209, 53.048311125847604, 59.652884314137125, 57.06382190027545, 56.21264011629167, 44.89499791975945, 36.941301976480794, 47.233895486400975, 63.299884488505704, 49.70638113637125, 49.269597761092655, 59.19794428733088, 58.053506497413885, 58.1467608482607, 53.74158613143429, 54.03567367984403, 55.00507962319159, 55.61014052360289, 69.05008700586134, 69.32586100793654, 69.9944446932885, 65.86170996389082, 67.19811639478131, 67.08739572955717, 74.83196658472862, 58.32057676007671, 34.47928121013027, 75.24535302192935, 67.37499175533172, 65.43927854107272, 58.40682575779577, 57.39310487624138, 54.669705206348056, 55.988453126722774, 52.37158067764775, 52.144298938012895, 49.99515779556767, 52.117822939349765, 55.960478782653816, 63.0286172897585, 67.79812136004048, 68.66416500460717, 65.93954547759026, 66.44376616324148, 61.65038270335044, 58.13520554573306, 58.38042428416591, 60.98577630135321, 66.25246432519728, 70.4350523794851, 72.13282677435106, 69.08843209666591, 50.64154478811449, 38.5146431000002, 37.25628399079846, 38.28426268792922, 42.58896197042158, 33.92772536123953, 40.04790152272871, 49.87621192009219, 40.77767418276879, 19.010245569290657, 18.484469498357466, 19.146016451620287, 18.472674931249312, 16.06861306775001, 8.806860485384542, 3.1164064522712462, 6.144590954626761, 1.4775689787441686, 3.4436598468211392, 2.1152388713052197, 2.01549839108221, 4.138473647256052, 4.875198708426568, 5.213694841630998, 4.462543793262975, 5.031597825788683, 0.7555591182843332, 0.2254460397506914, 36.31108691615444, 68.73732505306121, 36.65796956708355, 21.64018692508821, 34.64632711102886, 48.97894228658369, 51.06347414755052, 51.8663990113043, 66.35937244661393, 15.15502735491722, 0.25766126270736417, 0.35184932151629084, 0.2292795437237909, 0.05880392464478651, 0.09897417013323116, 0.1517925387428653, 0.05227267652028992, 0.05130035389635352, 0.03434072624170973, 0.07349573286069978, 0.040022995728518695, 0.046102600547695355, 0.04769597916052707, 0.004536622342833829, 0.040433783564836755, 0.047365071312073743, 0.014897150423137412, 0.027170168168302027, 0.04253900084163874, 0.015857577616829547, 0.11293181713910834, 0.07625185674236667, 0.03459461544069552, 0.15526936750017828, 0.14814816655651217, 0.17811371103650142, 0.19146843152421136, 0.10883586676490885, 0.14253105667810287, 0.15235219661506916, 0.18592702645447948, 0.10518088426080444, 0.15756939327524555, 0.1414993201051989, 0.20952739151975802, 0.12608135629805828, 0.20187507713994673, 0.20314741128635025, 0.09129908762031025, 0.13152387473852406, 0.24652632794553236, 0.2714283836464728, 0.2143522745539104, 0.2749169335490273, 0.22319838374612794, 0.2128783979963872, 0.16597426646659452, 0.1557814819558013, 0.1670792563668182, 0.25776554259561724, 0.20384577703812432, 10.555636479008584, 102.01158354359289, 88.53971681287213, 79.182738027265, 85.48954056155297, 65.46541329353087, 47.899670754709554, 47.2044502535174, 33.618207208571896, 81.8633250267275, 82.082609053581, 43.78431996991558, 0.7757392838116616, 8.849123043398704, 5.049219073787813, 2.987438430709224, 0.4330052441406635, 1.6700543919878623, 3.288650964536975, 1.7175129873137323, 3.298353192306334, 2.6422598044718466, 4.485427881440809, 7.33239152739125, 11.094719190751354, 21.867303925175822, 36.70266889756726, 53.224276496518044, 61.75342729014736, 67.29761908131262, 68.11630402841877, 56.92984550229965, 37.711867286312966, 24.466168342098115, 28.49989264242111, 50.757086046280406, 59.78125172276651, 67.26640485948133, 60.31339576167446, 56.72932217198034, 41.16684390652565, 38.4955999928136, 50.60655332380726, 68.84910475823187, 57.54149598460044, 61.14968822848413, 67.6212695337111, 63.276613066273356, 63.0612043411501, 57.74005420746342, 56.67712326972716, 56.71415828889417, 58.777630944405836, 73.6063043532833, 73.7617321937315, 72.21884435222995, 67.06351633994811, 69.04505852730044, 70.73811038847893, 76.80076106902092, 59.05242435393795, 38.19817058501705, 76.34235366698235, 69.43618943614345, 66.02248791725405, 60.23323036009266, 58.2942811904415, 55.82397245591687, 55.44834667636503, 54.71002324934929, 53.91351930556759, 53.43621784640897, 55.30179515961678, 57.58169635649651, 64.55472915403305, 70.86088057487243, 70.47548417122134, 68.28494241160732, 69.83985624005719, 64.29655090455087, 60.349073640761844, 60.257203886585856, 61.50899694811914, 67.09968059293686, 68.84970095849806, 72.49128433965868, 69.01336577630812, 52.473389717840384, 40.28253378406648, 38.42680554236136, 38.815163335492535, 46.599514868951616, 38.943346392723825, 44.53811322489093, 50.89638902295021, 43.59430859165807, 23.02832745736645, 21.534885014257124, 22.889022519511563, 21.310254796858757, 20.304335509577108, 10.986602979321635, 4.4522956205952555, 7.469603390462938, 2.794334508718983, 1.9922641087924282, 1.9024332516616391, 0.9945955271682433, 3.576656387698266, 4.904114911633154, 9.161842830719488, 16.939732259319676, 18.42897972752971, 2.0245990253263906, 0.35953569616521563, 42.508725966176684, 77.93941728530392, 30.070186084316624, 22.967530719695553, 59.9585703111464, 61.4391669919414, 61.222777674275065, 60.67585414455783, 76.99238454141926, 29.04749474217815, 0.4353290952501759, 0.6912338409212329, 0.29679781426825835, 0.2498251791562765, 0.21857082963951174, 0.3616284032262141, 0.16709845453020067, 0.1911810259785383, 0.1779113412504235, 0.1964041061939732, 0.29775900946509454, 0.12187312807767622, 0.15785080801335075, 0.23995085739560668, 0.12005402165795527, 0.13626851772348728, 0.14972728827307302, 0.07177411879022276, 0.14985854977801924, 0.1472111950598417, 0.17497438997510942, 0.15096755397896613, 0.211956012813795], [0.04499079246494559, 0.04129406582984713, 0.026181066303604075, 0.10438815945939672, 0.06839593151404012, 0.1321762752148413, 0.07886936467501425, 0.04577574147392185, 0.22309966565620518, 0.07592818459435817, 0.06152693437592638, 0.03878861740832368, 0.03589575449305196, 0.02591733287479128, 0.09204154939300592, 0.024887907972198822, 0.06600399817069692, 0.02288360171200287, 0.029379648096378774, 0.020429856564489104, 0.057763787917792804, 0.028213148996714624, 0.010335967301451152, 0.11628696815140786, 0.05695892062278525, 0.12463127443146323, 0.03887266491449649, 0.2373614648897802, 0.09277529308512326, 38.183402861318285, 77.99137300060642, 83.36517703148627, 73.70014313728579, 58.890265726274066, 53.61559175675916, 50.62838523618637, 20.856499325844553, 44.365952553287634, 84.06681845265051, 26.402611117209158, 0.022140289581711256, 0.5186505339318707, 2.548186903999698, 2.4377944921293566, 1.2369813337441415, 1.7492101509724896, 2.370874199175066, 0.22576646368590095, 0.644340557196448, 0.5470890047088747, 2.6008780637095055, 5.861435051887266, 6.221222300683299, 15.383641719818117, 19.057482673275857, 31.625774560436128, 44.62988884218278, 48.231683700315415, 54.50291425951066, 42.01004366720877, 31.374756597703506, 17.419800950634865, 21.834997323251542, 35.56180830924742, 46.327831898966146, 43.22742185285015, 43.87999050078854, 27.3357488647584, 7.487495282003957, 8.40544218017209, 28.89572843428581, 37.95505423699656, 24.471655737969186, 28.74945148344963, 43.74501782078897, 49.75910955859769, 51.420829526839725, 52.16646425185665, 48.077644378908225, 51.083199747147106, 50.467399397204005, 64.17527121882286, 65.50587646422848, 66.90626851973995, 64.49066900437879, 66.42078891877206, 64.40058785100138, 69.48825497781077, 61.11543024739912, 27.269462770031346, 68.5197276453818, 62.8407592927256, 61.900586774272305, 60.64367894203433, 55.816821975092736, 52.3973741839009, 47.638448745973655, 51.10068959574546, 48.814661656656575, 49.13923386604556, 52.51958739372992, 55.757347076169914, 58.295967809615604, 62.52553016908708, 56.38012532264956, 57.02959137578165, 52.8102977814213, 53.49519460431991, 49.644309628394346, 55.44792698275659, 57.22969501249252, 60.31028532212781, 65.93974944083922, 67.6604304775115, 62.95428837499311, 55.382992144553896, 43.395926875452844, 29.969677309836115, 30.9093967945345, 34.2428054348115, 29.910380878756126, 36.622695692123905, 40.942735364360196, 40.76529910487514, 21.819362755744688, 14.749054197342167, 14.367504658237582, 12.99996147232671, 9.981299504157036, 4.432705833065895, 2.496536643274369, 4.153325211617255, 0.40916841837667656, 5.169457370235074, 0.5711014484686237, 3.5001628148940305, 4.185768606201295, 4.476997727347959, 4.915416240692139, 4.678243264075249, 0.2020320332338733, 0.8175975312629055, 0.21486702435199292, 37.394276895830714, 45.70897602265882, 12.483062705686017, 38.00124406814575, 49.992384679855846, 51.34981109249977, 38.889915866236535, 59.99433840474775, 43.928949525279386, 0.46602354174660104, 0.23804207272346944, 0.13354764920809578, 0.20215600158178038, 0.061055667728426, 0.07883240859354697, 0.07738166789133703, 0.05549289646648592, 0.056661192042332505, 0.10857279983259017, 0.11106437057136528, 0.06771447332275492, 0.0963314502469955, 0.033091834385789214, 0.04560938165072472, 0.042686082062221346, 0.03895562840625644, 0.0497086568465156, 0.0426313259278334, 0.03567976366368032, 0.04336138090659534, 0.029364213339924335, 0.054338451760310325, 0.01906023308214161, 0.003966114750402349, 0.05933103144108769, 0.04863255229147692, 0.13330129065340565, 0.12248029872294396, 0.06036251903541627, 0.05986675289609741, 0.016608251852073496, 0.08292573128616618, 0.07251913929658552, 0.04733376895948764, 0.028205882652752826, 0.019525108641133677, 0.03282730039509554, 0.08713645695318138, 0.04080497614678837, 0.05433257586593109, 0.06473779272768768, 0.03912521345961479, 0.056571900664318, 0.07166008660269362, 0.03741706338440699, 0.007687199151053304, 0.09518083215000168, 0.016866009795076905, 0.048440877092821945, 0.020177480389153766, 0.23622011645667015, 0.07150909067281792, 49.70165468031361, 89.9695070328251, 86.20751473211473, 81.51250823851555, 62.150124042264885, 48.54154702155821, 31.09559366779943, 29.854502793281313, 57.37240652884207, 85.02899154540032, 33.153712288025886, 0.1636008188248642, 2.1194331107601045, 7.22074959547289, 3.893931272529787, 3.555257897223196, 4.32717054120956, 2.6753523513194057, 0.6067762019172792, 1.909532864247599, 1.6079758972890916, 3.196324254235914, 5.549724784589583, 5.729324721520947, 15.374176059999774, 23.753130474398215, 34.541862626229566, 45.20240583727437, 54.543071485334835, 59.83185029798939, 45.51721918967463, 32.998237379135624, 21.333836086334724, 25.548473827300537, 41.39784405308385, 54.15355659300282, 52.854110656246064, 50.77128894867436, 32.62336861702704, 13.581342043415194, 14.068823033763518, 40.14532535306869, 50.77214402537192, 30.17630384814355, 44.29030179977418, 53.99017418584516, 57.46751616078039, 55.08363293063257, 58.592126369476325, 53.33109048105056, 55.11388224940146, 55.043922855008034, 66.29515540215277, 66.4545605259557, 70.13835645491078, 65.95729812499016, 67.45842056889688, 67.30126688557287, 72.81913172814154, 64.2430889991022, 30.243843140140658, 70.87944907526817, 68.13009508194463, 65.81309610797514, 63.586488154626664, 59.29990237759006, 55.084884166717536, 51.768304455664854, 51.760243984960745, 49.38958698703397, 51.930392480665645, 54.35995955621043, 57.49602394719278, 60.402625760724476, 65.56539058685303, 61.23728259917229, 63.82850623899891, 57.94587273751536, 57.3035728546881, 56.00278154496224, 59.994989518196356, 62.7408722139174, 66.09513021284535, 71.03578690559634, 74.6935147623862, 68.54736466561594, 57.87718026868759, 46.7663215052697, 33.9698947629621, 36.39480990748252, 38.56639877442391, 34.97982663493003, 41.00947057047198, 45.43640267464423, 45.62724951774844, 25.779044474324873, 17.072069106563447, 15.852521850216775, 15.331387904382522, 11.833138715836311, 5.213671307409964, 2.8068208838662794, 5.596713308365115, 1.94722488041847, 8.791244549136009, 3.5384902550328166, 6.257545899960303, 7.340020047080133, 7.884499449883738, 7.045546635504692, 6.003478784714976, 2.1757742810633878, 0.8674408050794756, 0.27968414548423987, 38.96490373919087, 53.248312780934, 14.821657269231736, 36.95295141589257, 47.37738755441482, 51.59803436648462, 38.64554043739073, 69.24389131607549, 46.94344397514097, 0.45771047653209784, 0.14828880497765157, 0.07256432316235958, 0.18871267536474814, 0.20782197254800028, 0.07529252313918645, 0.10424820285650993, 0.18331656653073528, 0.08003004150645388, 0.16988182049845496, 0.14007142414489102, 0.04617337941101963, 0.019262761831463828, 0.032633506963329936, 0.04361673716395613, 0.03377385948213839, 0.05596841873240568, 0.05456763845417769, 0.0490305119855029, 0.06398699591837584, 0.047628203361865976, 0.06803859746263874, 0.015311395231213783, 0.0289887938678505, 0.12433564110148339, 0.1508414405848711, 0.1537750210733183, 0.1494029113241742, 0.1482419357184441, 0.2046275084778186, 0.16035882665986018, 0.13256858884086534, 0.4372914447899788, 0.16819160071111497, 0.15230947955241128, 0.16795869466037522, 0.20851842307996368, 0.08852106128488818, 0.1756209068961682, 0.14092430983099247, 0.11411074984578357, 0.1659501346969797, 0.18667825227302892, 0.19740351385647253, 0.19129364090340753, 0.1359613164658508, 0.09309120476245882, 0.20628490905848243, 0.1355043450190175, 0.2902219913178875, 0.12699840184781822, 0.3224127607480172, 0.2586853996880593, 71.86979263059555, 101.70064941529306, 102.47863584949125, 86.85905964143815, 78.38447293927594, 75.98587297624158, 75.2250429891771, 32.22200032203428, 55.086029498807854, 101.13033679223831, 36.7510199546814, 0.2942633502666028, 2.2632274464253457, 8.696187869195017, 6.519130727937145, 3.9009013243259925, 3.680280749836276, 4.34750214699776, 0.4271192986878657, 1.1749311536550522, 1.2892999908616467, 5.279488678901426, 7.6592985276253, 6.505584822547052, 18.325625273489184, 28.682100465220792, 42.13315902217742, 48.68636485069029, 63.34553303257112, 68.99426383356895, 47.34206268864293, 34.62014136775848, 24.20142992850273, 29.362821925070982, 46.175867511380105, 60.98918484103296, 57.76264313728579, 52.44024961225448, 33.74215410601708, 19.46451683198252, 21.231717178898474, 45.31350697240522, 60.56483145683043, 38.431677126115375, 58.31918824103571, 62.61044556094755, 62.8054932625063, 59.247828991182395, 61.017061125847604, 55.17783649506108, 57.52140168220767, 56.97735717219692, 68.38697110452961, 69.10279581623693, 71.53449273878529, 68.50298696948637, 70.71800431897564, 68.14573749419182, 73.81967344591695, 65.7819877901385, 32.963383197784424, 71.27330210901076, 69.39772667423372, 67.58929437206638, 66.06062904480966, 60.590397465613584, 56.555655310230875, 50.79920837956091, 53.83369907256096, 50.26092975370346, 54.476653991207, 55.170501662838845, 59.023944024116766, 62.46441571943222, 65.12519474952452, 60.65114321247224, 66.17937487940635, 58.85768651962281, 59.856557307704804, 58.1746018317438, 61.43025144453972, 64.33910077618015, 67.96583406386837, 70.12086268394225, 73.31645688702984, 68.92451624716483, 59.384268637626406, 49.45889134560862, 37.10293108417142, 37.74312857658633, 42.781209099677305, 39.20605890212521, 47.15653850186256, 48.24653771615798, 50.47801333089029, 28.28395831969477, 20.701689258698497, 18.204559356935565, 18.482827986440352, 12.694738314997766, 6.0025668336499125, 3.8813865521261772, 9.050138631174642, 1.467847751994287, 11.21424263523471, 3.7025367684902686, 9.334022133581101, 11.67281379622798, 10.740559562560051, 12.352130066963936, 14.558314238825153, 3.5254954426519336, 2.5688524015488166, 0.33161890062112964, 46.36880497778616, 59.337215885039306, 20.89520331351988, 58.21136620736892, 64.49325776869252, 67.60015149270335, 53.340386498358946, 76.75532433294481, 68.70230613216278, 2.1053309642499496, 0.41263680484506393, 0.4404521703479752, 0.2480997040026611, 0.212681605330398, 0.248319142227692, 0.35922733045393423, 0.4655842362873016, 0.31250568106770515, 0.3466190553961262, 0.24991980633668362, 0.2402530024729429, 0.17820245466165005, 0.11270273386711076, 0.2268682973038766, 0.10987930150041658, 0.11169693703132291, 0.25882482769027837, 0.17696788864991359, 0.2681575252884819, 0.1384488958865404, 0.22158213740875646, 0.15904740670755987, 0.16164884211555605], [0.05429640119414657, 0.0520325462604242, 0.01865200206427084, 0.10891184736523898, 0.0970681893428968, 0.06524292812232049, 0.0399771070618543, 0.030437703619921402, 0.051077797693470796, 0.02610990631153747, 0.02943879966023228, 0.0147863999647539, 0.08082131840168469, 0.03527825315212531, 0.06886605669053332, 0.05284201774385668, 0.05504332925944079, 0.03872162684978497, 0.06597989704459906, 0.04960566015553571, 0.032683995987979636, 0.06349332502952988, 0.12149038288982646, 0.07150122294983557, 0.07587636640715985, 0.0563399522234836, 0.10275765622575438, 0.21787272435763191, 0.04508919645881942, 5.845898053338451, 95.21089969142791, 59.547678501375266, 53.522659040266475, 68.87970709031629, 68.46526161316903, 63.083663832756784, 46.16731674440446, 31.455204409937707, 103.90775142177459, 23.385637729398667, 0.15317574113367066, 0.705024833160062, 3.7634011670466396, 4.226983891379449, 3.6845200965481424, 1.8790558028605677, 1.2574831949126337, 3.175017449163622, 6.429394743134899, 1.8806400726879797, 0.9600694153097369, 6.262619976074466, 5.167583948181522, 10.37223723626906, 12.690889489266182, 19.632298177288426, 35.24089567122921, 38.75284079582461, 41.99430319570726, 35.389451519135505, 24.524305712792184, 12.726608553240377, 19.76270521840742, 36.38993440135833, 37.08924201227004, 42.210441481682565, 33.75474099190005, 11.508599846593796, 8.05192287891142, 23.251390687880978, 38.23682554306523, 34.3473679788651, 23.213816342815278, 28.079861710148474, 35.41327207319198, 44.806470024970274, 48.12944319940383, 54.622515170804924, 49.25297475630238, 48.87908658673687, 52.10672263176211, 56.80718121990081, 65.67987672744259, 66.88311869098295, 65.06183278176093, 63.27396154403687, 67.55979814837056, 64.15539656915973, 68.48721904139366, 26.248799293271958, 61.49227588407455, 67.0676975865518, 62.82503058833461, 63.63940485062138, 60.76312688089187, 54.284297035586455, 47.88240055884085, 50.823017166506865, 47.84624807296261, 49.38829260487711, 49.88928125750635, 54.94048210882372, 57.68669820600941, 59.56783948406097, 58.85082629419143, 55.30830237173266, 51.79713779880155, 51.70162024036531, 53.247893087325565, 55.098690909724084, 59.79222259213848, 60.274019087514574, 63.323505001683394, 65.64612473210981, 64.50767247907578, 58.531925832071614, 52.3910827021445, 35.51165688422419, 25.17799811978494, 28.495107350810883, 26.432817289906165, 34.00173264165079, 45.96817016601563, 43.29593389264999, 23.28514268321376, 18.116459000495173, 13.3448495980232, 8.810765204891082, 8.746058844750928, 2.4514820931419252, 2.0489884456319194, 0.2590882700056799, 1.3843961396524984, 7.313442066792519, 3.7814769196894864, 4.828890715875934, 5.718775997238775, 7.27595107209298, 5.066079872269785, 1.1588440426895696, 2.4049944070077713, 0.6427299952314747, 0.04307046667822907, 42.707417549625525, 41.39631040634648, 35.824046211857954, 46.650874383987926, 57.75715574141472, 42.4321299214517, 49.683713759145434, 68.10029291337537, 9.457002166778812, 0.28952816080662513, 0.15033242112446218, 0.15612620619996903, 0.06908033914383381, 0.13204323638591076, 0.11846697093137812, 0.07983804455087071, 0.15061458662873314, 0.061711944609640114, 0.10786344837998191, 0.022164187694509185, 0.14158339059400943, 0.03717833889588233, 0.08159649978962638, 0.021163489173857436, 0.04209225666859458, 0.022227342067767056, 0.06875366393116213, 0.04969538437322744, 0.06530949350206122, 0.04311795646865522, 0.052711913031676126, 0.03860579052519414, 0.011689172561971412, 0.0367924144431468, 0.058700410844457734, 0.03825947664858353, 0.07114359012414372, 0.11902008641270861, 0.042429507725060954, 0.07724348095155532, 0.060539791781094775, 0.0254050096602089, 0.047857049146607045, 0.08754799172522561, 0.01921545590213951, 0.08673937826026833, 0.04082725015318683, 0.08976793832956784, 0.04821616435243238, 0.033184871933753454, 0.06372901580987439, 0.02074693269546955, 0.03852491079258823, 0.04204201279208065, 0.049260560528285084, 0.13799428399051392, 0.05854561894891724, 0.08772786916984666, 0.04764015050304513, 0.03582264672243788, 0.23961232314186715, 0.13386877794419566, 7.658208599013667, 107.85809593815958, 72.0618946321549, 58.65870860315139, 71.54414176940918, 70.40033940346011, 46.23025509618944, 38.27324082774501, 48.71993641699515, 101.87546945387318, 27.01962151835042, 0.2935937281337477, 1.54896714754643, 8.321927074463137, 9.556329327244914, 6.286339038802732, 7.2664893346448105, 2.8743268357169245, 3.5552350984465693, 4.637614863534128, 2.7835068058583046, 1.1015402982311866, 6.161679740874998, 4.565599166577862, 9.414228720049705, 13.770357139648931, 22.788658872727428, 37.920168676683986, 42.41459692678144, 47.84820141330842, 39.9344704997155, 28.024579824939853, 14.410868421677621, 24.083311673133608, 43.954625360427364, 45.327533368141424, 46.36675357818604, 40.55035321943222, 17.623744587744437, 15.341752767562868, 28.950610237736857, 43.95039312301144, 41.164306133024155, 30.52900729640838, 39.49325092377202, 48.70380763084658, 53.36850989249445, 53.22335866189773, 55.64824634982694, 54.052084876645, 53.06097645913401, 54.262602406163374, 60.68299678064162, 71.25083477266374, 69.95562107332292, 68.34984979321881, 67.54255540909307, 70.34244521971672, 69.20888023991739, 70.40131215126284, 29.155997307069843, 64.7161856774361, 71.06169808295466, 67.68689863143429, 67.82523278267153, 64.99172825967112, 57.563853494582645, 50.912964959298414, 55.258084266416496, 49.68712622119535, 52.256933719881125, 55.25692324484549, 58.15000072602303, 60.86498691189674, 63.72324943542481, 62.45901069333477, 60.44042956444525, 55.72953747164819, 56.16747794612762, 57.37122197305003, 59.65799124010148, 64.51047305137881, 65.98502143736809, 68.0223632627918, 71.6389689906951, 69.6250044914984, 63.67310585514192, 58.00427682938115, 40.889163632546705, 30.49824610833199, 33.274391851117535, 29.19385406278795, 37.71116518205212, 50.76028670034101, 47.49787884373819, 25.475484401948993, 20.712281619348836, 16.55069589614868, 11.12605598665053, 10.228147987396488, 2.536873072385788, 3.2566652615224165, 1.628964132358951, 2.8779712079032778, 7.322027644803447, 6.870990376318655, 8.77142285147021, 10.286575613483306, 9.288299064482413, 7.3428475856781015, 3.197545337100183, 1.5728352603412445, 0.3124298690067184, 0.2684924282854603, 48.707016129647535, 43.17056709720243, 39.61418151855469, 44.76723847850677, 59.49194554359683, 45.83505668947774, 53.54659726542812, 74.79314296476304, 5.929757347030025, 0.32702454876515175, 0.15530914278520694, 0.03097495725077968, 0.04705817265916736, 0.03635464499013559, 0.0994469000086669, 0.12610546508503537, 0.2557063595421853, 0.0970870734102303, 0.12421167275357632, 0.07207473935258966, 0.04632862329843544, 0.09804391722765662, 0.05089233929832136, 0.07887797550328317, 0.038396725130658, 0.046441843432764855, 0.05742580524735874, 0.057815824440049554, 0.014094090138021258, 0.05563700909636194, 0.02326878305945185, 0.0435778237278423, 0.02972939021645054, 0.15233731918757962, 0.1371220928887206, 0.1287573933481209, 0.1660327342969756, 0.24527794170764186, 0.14952119529968308, 0.2693742874168581, 0.18639945755562476, 0.1183555204601538, 0.15594669647755163, 0.2997678145766258, 0.13593464128432736, 0.25939761630950436, 0.15850382136000743, 0.22805945677382333, 0.2004110524731298, 0.11669019086947365, 0.14033387054599103, 0.1308895845807368, 0.15832624217915922, 0.09792644530534746, 0.10744257499614071, 0.2069931113792043, 0.23252118348834977, 0.19065702183833047, 0.13159660712605523, 0.18340200065605103, 0.3461712310391088, 0.3088878768105661, 12.58552089814217, 134.41273812324772, 79.99103653815486, 77.98241430713286, 85.59480128749725, 92.46777442193802, 85.03337675525297, 64.487236930478, 43.59077845850299, 122.82750006644957, 32.51805690027053, 0.2876673025950309, 4.575908135983252, 15.601454857856998, 10.678181129117167, 10.57369311009684, 7.908773037695116, 1.8196124054731864, 6.500080266306478, 12.43505975892467, 6.334929850793654, 1.7156805049988533, 9.376843629344817, 6.186241622894041, 10.316000253923479, 15.756420839217403, 25.98932077807765, 40.44204481186406, 49.02158629509711, 52.40160249894666, 43.07954065261349, 31.430034560541955, 17.200303154606974, 27.505558075443393, 46.114945257863695, 50.167871521365264, 49.73910939308905, 42.68192606587564, 23.417583473267097, 24.571317280492476, 37.161617586689616, 58.70960920087753, 59.24147867387342, 46.41967027418075, 54.375331324915734, 59.01619734302644, 62.72921492976528, 59.025975811866026, 61.3210722707933, 57.432305043743504, 56.11084676557972, 59.31308938610939, 62.866462584464784, 73.27770386972736, 72.22795994051042, 71.48300770790347, 69.40533607236802, 72.53499523285898, 68.53859424591064, 72.48816213300152, 30.823375294285437, 66.36447152783795, 73.39602608834544, 69.52384656475436, 71.0328608174478, 66.4476179307507, 57.57261214717742, 51.640525402561316, 56.710263375313055, 51.15175885538901, 52.90006122281475, 55.60379805103425, 61.75103072197207, 62.62118501047935, 64.9974000069403, 65.21445220516574, 60.35471400906963, 56.15665220445203, 56.217923548913774, 59.02255942744594, 59.87127011822116, 66.75910119087466, 67.17881048879316, 68.03998254960584, 69.74649598521572, 70.04432939714002, 64.91270819017964, 59.66627136353524, 43.78755984767791, 33.72796689310382, 34.83127863176408, 33.84322181824715, 42.01909649756647, 55.30221093085505, 50.70110597918111, 29.67781178412899, 23.692559273012225, 20.414269739581695, 12.22806549841358, 11.197776525251328, 3.3184558297357256, 4.3691923637543955, 3.926376873447049, 2.6433896922296096, 16.13460204293651, 13.26369183678781, 10.598877668380737, 15.862649410001694, 14.533119874615824, 16.952046540475664, 7.07141270560603, 7.7794809302976065, 1.8007548754253697, 0.4576831118714425, 51.00179095422068, 56.76793398395662, 55.67766020374914, 63.82656466576361, 76.83567016355454, 61.900159235923525, 64.49009241596346, 90.99800740518879, 19.360495575012703, 0.7255684920857031, 0.41343816345737827, 0.39249380990382166, 0.33214431436311814, 0.42509799102141016, 0.3873818890461999, 0.3571411811055676, 0.48404526986902763, 0.3251160092411503, 0.3464218337208994, 0.07233565357784111, 0.3139827292292349, 0.194923288879856, 0.23221954402904357, 0.22614857302077357, 0.11040418664173735, 0.17297482388394494, 0.16740682024148204, 0.1345184511475025, 0.17640706632406483, 0.20030767656862739, 0.12162264030907424, 0.1139568044773994, 0.08233579761919477], [0.10611055493955651, 0.012576237260814638, 0.06621974385193279, 0.04653048363604373, 0.06119147596520282, 0.09336192491314105, 0.08498627031522413, 0.11093242724816646, 0.022014233644210526, 0.05694554472762731, 0.035396085135758884, 0.0606402182470887, 0.09045072185296206, 0.038897099288841414, 0.0514858199523822, 0.09326562000017974, 0.024887839024285638, 0.024222865129911134, 0.0581410440856651, 0.03368693531580991, 0.10557710493524229, 0.0659145420837787, 0.09624927199535793, 0.05490840202377689, 0.1102012422897162, 0.05721471355026288, 0.04683737079763124, 0.0451608180188604, 0.1685907171979066, 0.13231473794627574, 22.228542450935613, 103.34795075078165, 76.40043612449401, 45.26229258506529, 71.86500733898532, 62.28931327019969, 60.90823888778687, 23.782026575457667, 76.74063113427933, 26.61492313108137, 0.5895532583517413, 3.4465660779706897, 7.421344018751576, 4.345652259165242, 4.307028189782174, 6.0205126577808015, 4.400873837932464, 1.458629324070869, 2.0679725946918612, 1.388411666116407, 0.3245458866079008, 2.980069277747985, 4.195496574524911, 3.4824052645314127, 6.7953582540635145, 11.213636629043087, 19.45783115202381, 22.906247608123287, 28.646769715893655, 23.93335553907579, 15.546354382268845, 11.23796611062942, 16.711705269352084, 23.34008920577265, 38.503393742346, 37.05483498111848, 19.48834719196443, 16.137049601924037, 36.395512011743364, 54.59653731315367, 63.801708605981645, 46.38881298803514, 29.92548396510463, 33.63702674065867, 36.229866396996286, 42.77048533962619, 45.403388084903845, 50.574636997715125, 51.17159035898025, 50.21075087208902, 50.66017996880316, 55.26468953778667, 65.45128491617018, 66.1095174666374, 63.12046350971345, 62.99745405873945, 68.99236540640555, 65.04503719268307, 70.52656127560523, 22.481301946024743, 58.68293708370578, 64.16985834798506, 66.76957391923474, 66.59444009104084, 63.37141283096806, 57.141775085080056, 50.489399971500525, 51.25629394285141, 52.01443318397769, 49.21289597788165, 52.759118695412916, 52.61474801648048, 51.96096343378867, 54.72948212777415, 51.838452123826556, 53.055653802810184, 53.13119865232899, 53.008479456747736, 55.47177891577444, 55.16552417509018, 56.1434651959327, 57.669769256345695, 60.02024173736573, 61.62078449803015, 62.75581252190375, 62.96270185901273, 56.84658142828173, 41.15182907350602, 19.97435042935033, 13.762632031594555, 23.994342511700047, 30.219553862848592, 37.05463886260986, 36.67625957919706, 26.91766146690615, 19.12461796114522, 14.236960334162559, 9.250343268917455, 5.529719716118229, 1.13991713571933, 2.869158132422355, 0.6567826831052381, 4.831388285083156, 7.57440519909705, 6.371348077251065, 6.366888832661414, 9.644589520269825, 8.03950563553841, 7.666591194368179, 2.9963056839281514, 1.755181591837637, 0.12185417506242953, 0.6423106693452405, 45.23167456350019, 34.34508123705464, 28.74891607992111, 63.668300951680834, 45.68333941121256, 39.521923449731645, 67.75361030332505, 30.570862908517164, 0.09035690672575467, 0.09526678721510595, 0.10622316986442575, 0.12977082041963456, 0.0501423622030885, 0.16163768787537852, 0.18115092789934528, 0.06830190954309318, 0.0793587186584069, 0.04674830924599402, 0.024845662053614378, 0.15903910231446067, 0.12293127170133016, 0.0919852419305713, 0.04027002077970294, 0.09021287453511069, 0.11202971796475111, 0.02952882839787391, 0.03213761058906394, 0.05043511121203342, 0.03600030634251814, 0.04885583244744809, 0.060809519847915064, 0.018703577018553214, 0.049163864910482406, 0.04144138070724664, 0.004966712722014035, 0.12128337827180663, 0.02110493898902449, 0.07235911119008258, 0.054723307520391486, 0.09016382192531902, 0.0860232852339264, 0.054770203592676314, 0.02664643215886768, 0.027102997579101114, 0.07457367985719636, 0.07367842184800295, 0.08310589984419846, 0.015877118604558132, 0.0722501045393367, 0.042544639248761444, 0.02743282907402083, 0.04529175776687842, 0.0197817423501082, 0.07447069465753532, 0.009501462937482904, 0.061554276053943945, 0.05119722313998688, 0.08287143097409318, 0.03652296982885849, 0.07823609341416629, 0.07740657340975539, 0.09539431787186092, 0.14971866212304563, 25.6862804197496, 116.64695862800845, 81.15155604577835, 49.57373442188386, 77.81448195057531, 65.5643746929784, 45.240319467359974, 37.02137324117845, 100.93105685326361, 28.73374042972442, 0.5802188140730704, 2.8311366371570097, 7.53052564397935, 11.813079714775087, 10.182972088936838, 7.173912573245264, 7.5796876511266165, 4.159256325614068, 4.659376173250137, 3.102547737859911, 0.33261227151078565, 4.642342300184311, 4.149586702546766, 4.788784971160274, 9.035284615332081, 13.474020111945368, 20.10041540668857, 28.9093606318197, 36.05905894310244, 27.71440467526836, 16.70455674971304, 14.699977501746147, 19.6684879256833, 29.73975189270512, 43.771509508932795, 42.67690935442525, 26.992268869953772, 21.880565458728423, 42.28138931335942, 57.72960893569454, 65.38529496039114, 51.448733268245576, 38.35401027433334, 44.06796616892661, 47.26162272114908, 52.88087298793178, 54.83531944213375, 56.56802254338419, 55.034062016394834, 53.645409614809104, 53.33745256547005, 58.46825007469424, 69.15180190916985, 68.5624893250004, 66.70792994960662, 67.6195280013546, 70.73481559753418, 71.63353258563627, 75.92642553390996, 25.17510537178286, 61.61079814357143, 70.69761583881994, 71.26488470262098, 70.93460544463127, 66.69032635227327, 62.03836002657491, 54.784124666644686, 52.35627951160554, 53.486777197930124, 53.45081690819033, 56.069073523244555, 54.138467234949914, 56.5251471150306, 55.96741745548864, 54.80992601763818, 57.184203363234005, 56.69626443616806, 56.43163388775241, 60.35257239495555, 61.29385102179743, 61.48661198154573, 64.53534480064147, 68.16199964092624, 68.54555253059634, 69.38867384387602, 71.00949918070148, 62.342865390162316, 47.29185635043729, 24.982956301781442, 18.231662934826268, 30.64989474511916, 36.15752612390826, 39.36749973604756, 43.38814489303097, 32.14707716818779, 20.266837650729766, 15.51050195770879, 11.263632139851971, 6.625191127100299, 1.9723626154084362, 3.7606540370372037, 0.59715683421781, 6.799540971556018, 9.106588402102071, 11.931201892514384, 8.211241710570551, 11.10940650586159, 8.444896321142874, 7.256393153821269, 2.917979628809037, 1.0721097742357562, 0.3030473144064027, 1.1897537905362345, 48.1450463879493, 45.67093295435752, 33.46271661020095, 60.9605162374435, 57.144701173228604, 41.21150401330764, 76.12266955837127, 29.79198805747494, 0.2509483559838226, 0.09213623786044699, 0.1416480484148187, 0.05346084058645272, 0.13332225081901397, 0.13372683717358497, 0.17128714750851357, 0.07207536754468757, 0.13852677638492278, 0.16297304041443333, 0.08773279511519978, 0.09865127939490542, 0.02816077539577119, 0.1049015915862495, 0.027887879555384, 0.06702024444577194, 0.01112437040935601, 0.02549599217731626, 0.08683284864790979, 0.0239615774367966, 0.022145263407559648, 0.04556899732579628, 0.04217374927153991, 0.055776774177267674, 0.06708186855840106, 0.13205215364934939, 0.10525907885523574, 0.22400858301308849, 0.10253886917545911, 0.16400637045021982, 0.19836758954390404, 0.21548493554995907, 0.1670634902773365, 0.1023218441273897, 0.09868540095105287, 0.11167935531346068, 0.20505927563194307, 0.14840650672633804, 0.1777898090621156, 0.08737366075717634, 0.14764257917000403, 0.30108729377388954, 0.13787028499908988, 0.11640141402641613, 0.25654314206011836, 0.25588197753794734, 0.14363287497432004, 0.1791116631319446, 0.17855065694499403, 0.3330350294709206, 0.21275266764625428, 0.3319723429458757, 0.2979972321660288, 0.2918955257102367, 0.38149174543157705, 39.92474302168816, 132.12955782490394, 98.64520149846231, 65.22529363632202, 90.10904142933508, 89.73015616017004, 84.91820027751308, 34.68009087347215, 102.98073061050908, 38.20459542735931, 0.7230532722127053, 8.27701985836029, 17.12736472006767, 17.774997065144202, 16.385487625675818, 16.19305516442945, 13.211915569920695, 6.856235890619217, 9.684762435574687, 8.175884485244751, 1.2322755927039732, 4.458680748939514, 3.901857892351766, 4.4840648578059294, 7.838779812858951, 13.58132439274942, 23.165853600348196, 36.133011310331284, 39.890324223426084, 29.499218425443097, 19.656004982609904, 15.998442845959818, 23.859960148411414, 33.08009332226169, 46.348338050227014, 41.643827653700306, 32.469405781838205, 29.534568786621097, 49.89481964418965, 64.99931412358438, 75.16226937693935, 65.26195603032266, 61.68421706845684, 59.03283603729741, 60.62633029876217, 60.81213297382478, 61.24866923978252, 59.685098740362356, 62.163715054911954, 56.22743529658164, 54.94084296687957, 60.40365342170962, 71.09563442968553, 68.47196102142334, 67.45658489965624, 68.30930817511775, 72.62546077851327, 72.72608526291387, 76.10465803454, 28.53259736491788, 61.88373627201204, 71.34090023656046, 72.16651993413126, 73.36011286704772, 69.66625213623047, 62.92366250868767, 53.21800854898269, 56.25003207114435, 56.245125186058786, 52.95809268951417, 57.3715945982164, 55.57333300190588, 57.887331362693544, 56.71824147624355, 56.03738077225224, 60.234901289786066, 59.01734267511676, 58.08524631684827, 61.332651107541984, 61.68362479056082, 64.53720400410315, 66.37095912810295, 69.29292094322943, 65.96275806427002, 68.20543596821447, 69.92437547253024, 64.51889438013878, 50.436648015053045, 29.94085769499502, 22.323981561968406, 34.87001595958587, 40.240933126018895, 49.845790017035704, 49.42484125014275, 35.808286128505586, 22.9376716767588, 16.217092429437947, 11.591851172908662, 8.472683372036103, 2.047504441392037, 6.45927437851506, 2.722828474736983, 13.41845287430671, 13.932670700934626, 16.338995772023356, 17.831412515332623, 20.151739620393325, 18.87562786379168, 13.496790451388206, 9.787583447271778, 4.56236566266706, 0.46992026329521214, 1.3194092074709556, 58.55724473153391, 52.34754831560197, 42.96518787260979, 81.71301980172434, 65.33698312697872, 55.533768053977724, 83.53834967459403, 53.433327059591974, 0.20641543511902133, 0.15587120617349304, 0.18684634728537453, 0.1796176335624149, 0.18355235307207032, 0.37064881274296396, 0.4244761727750302, 0.31037316807816107, 0.32492387438974074, 0.27809111161097405, 0.20090687989948258, 0.22198952764513033, 0.19090894219135085, 0.17695100407206243, 0.15461552677856338, 0.17607389468579523, 0.2985050258857589, 0.16596320415696791, 0.21326799967115928, 0.10478103999048473, 0.13331472783559753, 0.24594692032664056, 0.12087623318356853, 0.0923457475859792, 0.21998269904044368], [0.02704846552543102, 0.1241389710095621, 0.11708096465876988, 0.08646489661787787, 0.1756175973963353, 0.09631543134849879, 0.10355341473534223, 0.1518782486598338, 0.09831724973816065, 0.06123507785941325, 0.01062315738489551, 0.03593630735732375, 0.02224586607377616, 0.018428153088015896, 0.03711777964546796, 0.08295655866423923, 0.030536998191007206, 0.04747673628791686, 0.09738794678161222, 0.07570325351891018, 0.06774445800411125, 0.059757286592596964, 0.09195306623775153, 0.09788165980529401, 0.044860844800789515, 0.15489536337554455, 0.0751246732749766, 0.0990737232589914, 0.2778817551030267, 0.12116805139568546, 0.6829371699883092, 30.165948790888635, 89.98958956810736, 63.72389662650324, 59.51832348300565, 68.2042984808645, 66.68598036612234, 34.34399474051691, 43.876770234877064, 24.740698952828687, 1.6048383688734424, 3.265885037760581, 3.4969594642039272, 14.356096444591401, 6.6165123927977785, 8.25790418732551, 4.350668480319362, 6.554162886834915, 3.1588251696478937, 0.9805097442961509, 0.34120569426205855, 0.5936892138373467, 3.469478358184138, 1.0527710183974237, 1.555203103250073, 1.2952309822843922, 5.955564091282507, 11.07438366259298, 11.761059280364744, 12.486277088042229, 9.991369208981915, 7.3724747184784185, 16.772719698567546, 25.129772578516317, 34.373051658753425, 31.568555024362382, 21.931211102393366, 28.959533629878877, 47.16570900332543, 55.93082958652128, 64.248160623735, 66.36099630786528, 52.12827997822916, 40.82545257383778, 44.27173329937843, 43.855173664708296, 48.40672339162519, 51.92450108066682, 55.34314870834351, 51.26455837680448, 51.68356164809197, 52.10904467490412, 58.20984432774206, 64.19894272281279, 64.09959300871819, 64.61984834363385, 66.55617344763972, 66.35482249721404, 67.88884578212615, 18.741557328931748, 54.34693336486817, 63.05494423835509, 62.735580936554946, 67.79638767242432, 63.48150591696463, 58.749229061988096, 49.68505520974436, 53.29344749450684, 49.27117063153175, 50.83139534919493, 52.51537869053503, 54.890864126143924, 59.38206818795974, 60.06585105772942, 59.92559494510774, 55.47077086664016, 55.14086423381683, 56.953846485384055, 52.9759394737982, 53.22298211436118, 52.118446596207164, 53.57357532747331, 51.78709653116042, 58.335740643162886, 58.160132208178126, 63.83148724032987, 61.87353418719385, 52.079419012992616, 15.970577347663143, 5.629742606993645, 16.955062843138172, 32.96397939805062, 37.783270112929806, 35.32208088905581, 25.910641954791163, 23.08548031314727, 16.283681527260814, 8.379552575849718, 5.798360888035067, 3.088498788495218, 1.506785365843004, 1.59122749922737, 3.6909113535957956, 5.60581075568353, 7.7237626814073135, 7.985814271434662, 7.9686249744507585, 7.268019059012014, 4.375761353200482, 2.614305562550022, 0.31300492524620027, 0.08309194172221808, 1.2174100548990312, 35.11242235860517, 24.787294749290716, 60.0452390024739, 68.70054106558524, 28.113666657478582, 48.745894662795536, 62.38421501651887, 2.858477518443139, 0.1473028651408611, 0.12125104170052275, 0.04613951449432681, 0.041297976708700584, 0.05093074711640516, 0.10991061917476116, 0.079559295798742, 0.037118940268673246, 0.06964933562783465, 0.09426678200402568, 0.10052575098891413, 0.017265476767093908, 0.05702545918944863, 0.03862486611450872, 0.1113734947096917, 0.14063443748220322, 0.05878259675697454, 0.034000678964319735, 0.05120370807426591, 0.016355461989259048, 0.06198403988814643, 0.05725503658815738, 0.023098219328770236, 0.05354520984955373, 0.06551207013187871, 0.06553200373966848, 0.006639475280779504, 0.1951063379284836, 0.08873368132739298, 0.13644399782342298, 0.10085994918500224, 0.09581224181719365, 0.11379598730033445, 0.10962316766381265, 0.058205920241532795, 0.14014303804405276, 0.06999257366142927, 0.04322292200560051, 0.07511331985193877, 0.07647268924741976, 0.024879528885527004, 0.049923804979170525, 0.0596289515435215, 0.10962868349686747, 0.07855012817608734, 0.06802968019920011, 0.08304472772344466, 0.09022042050116486, 0.03224149977247561, 0.14916603693798666, 0.08333934215648521, 0.05288983695209027, 0.23965338545460857, 0.30523565988386836, 0.16158317305868672, 0.9708917249114284, 34.2304225121775, 109.95850947595413, 63.34900433017362, 66.50198982607934, 71.872420618611, 67.21968943072905, 25.81377313983056, 64.42693048907866, 26.78035889902423, 1.2827296531008137, 2.2708851387423854, 3.4340024811606256, 10.375059381608041, 8.326296594835098, 14.626210466507944, 10.748242505135076, 7.872293033907491, 4.5214685797691345, 1.112472311623635, 0.2717162794884174, 1.0630392932122754, 3.4759715968562714, 0.49213141984035896, 1.9923524846953733, 2.4758005430621486, 8.217949944157755, 13.447879475931968, 19.17633637305229, 18.219362381965883, 12.522256989632885, 9.198429719094309, 17.953468830354755, 30.831463221580755, 39.3522495608176, 37.06828086606918, 27.072599011082804, 35.430793300751716, 50.52004544965683, 62.927020057555175, 73.2846699991534, 71.82686621142973, 57.991250638038885, 48.216437447455625, 54.65081507159818, 54.20479059219361, 57.918777004365005, 57.50417463241085, 59.872709628074404, 53.40547430899836, 54.77248307197325, 54.661648658014116, 63.269737151361284, 69.68355763343074, 67.00424148190406, 67.22480420143374, 70.55334321914181, 70.07476698967719, 71.86324227240779, 21.84470126705785, 58.26502815369637, 68.44361012981784, 69.99102438649824, 73.38837746650943, 69.6354458408971, 61.27092084577007, 52.52814600544592, 56.36936233889673, 52.66001609063918, 52.53022878400741, 54.17003447009672, 58.22254496236002, 61.20851985869869, 62.61514848278415, 62.87124787607501, 59.46568527529317, 59.11309557576334, 62.55223366522021, 58.167871044528106, 61.34270021992346, 59.78484069147418, 61.49606881603118, 59.61589636341218, 70.07552792949062, 65.77125226297687, 71.52127435130458, 70.25503127805649, 60.22760568126556, 22.227204922706854, 8.978127837181091, 21.509162110667077, 39.85885112516342, 44.86628617009809, 40.12705887517622, 32.056315483585486, 26.973555241861654, 17.973645502521148, 10.870885214497967, 7.212576846922598, 3.794918391973742, 3.48286614302666, 2.223097186896109, 7.172567690572432, 10.148612126227349, 10.874087829743663, 13.326346797327842, 9.72487553473442, 6.974676270638743, 2.6135585961803316, 2.688682526350022, 0.5768874347690613, 0.1632724735405176, 1.540078689013758, 39.53212945692001, 35.37340118039039, 51.231814430605986, 76.73436318674396, 30.972923501845333, 54.09514857876686, 68.37536088881954, 2.2962552741650613, 0.1222305847031455, 0.29892606780894343, 0.04084775449648019, 0.0789980521245349, 0.05005966684210205, 0.23318332860306387, 0.105132628382454, 0.1364719447109007, 0.022703040533909397, 0.017026399878124078, 0.057685574171163385, 0.0857364465933173, 0.008089829108587677, 0.05694048854732706, 0.049339276062504905, 0.05614377625827348, 0.03292584228479574, 0.07674635883661048, 0.019766206087003795, 0.042772243971065174, 0.032216211210095116, 0.006508216648663004, 0.03265316477946697, 0.07217204784073177, 0.03856724864172359, 0.15233207914617755, 0.16948624333787352, 0.1741871580241188, 0.1734302631549297, 0.22473037573358706, 0.17817708182959788, 0.16913388885797995, 0.19297926416320188, 0.2047770794841551, 0.13313518746966316, 0.17599045238908262, 0.16295592601020492, 0.174214108997295, 0.1751199466807227, 0.2212657737395456, 0.15386250831427115, 0.1710660392118077, 0.1471131051620168, 0.20048455094858525, 0.21162391369861944, 0.1354005401052775, 0.22410607536233243, 0.17312209662650863, 0.2079775190401462, 0.2081789848424735, 0.22128308732663432, 0.2277067498934846, 0.27082151943637484, 0.4522666250986438, 0.3586449810574132, 1.3408202005009497, 58.154574209643954, 119.89020962868969, 84.72687490524785, 84.9246015856343, 86.05273800511515, 95.03727205338018, 47.87323790211832, 61.438429586349, 30.495900530968946, 1.4361074422636342, 5.932174507648715, 14.505433824754531, 25.132043630846088, 19.99313073773538, 22.453188357814668, 21.30659522548799, 10.82432177758986, 9.974955070403315, 5.616542850771259, 0.9824954441958859, 2.045554042823853, 3.650615619074914, 1.147430926080673, 1.4928223408998982, 1.9047030782507313, 6.386666403662774, 14.505728983109998, 19.507113772053874, 20.23479384760703, 14.345772766297864, 11.933946571042462, 19.290157671897642, 32.58506471110929, 37.82787138415922, 37.8881033005253, 31.478236567589548, 41.217360111974905, 54.70908580287811, 67.8348582790744, 74.07134840565344, 76.07023531390776, 71.2287518285936, 63.68820305793517, 69.2158934377855, 66.69730817118, 66.59323200102776, 64.70779180526733, 64.95561107512444, 56.21794316076464, 55.69782903117519, 57.21311515377414, 65.70586635220435, 70.7269630124492, 69.76123625232329, 71.19408592101067, 72.54819008611864, 72.97069995634018, 73.46700529898368, 25.643373612434637, 57.731601499742084, 71.00103470586961, 68.56090468745079, 75.98298611179476, 71.0401564259683, 64.31657852665072, 55.54912413320234, 59.278851016875244, 53.570723764358036, 55.537937533470895, 55.83221727801908, 60.91768003279164, 64.10390761590773, 64.7063522954141, 64.83528060297813, 60.24970823718656, 60.089102868110906, 63.6634882034794, 59.464402660246826, 62.16091840497909, 61.9562412846473, 65.90877056121826, 62.02425126106509, 70.06780086025115, 63.86744753006966, 67.76642860904818, 65.37507718609226, 59.131056108782374, 26.787134793496904, 14.371923208236696, 25.348617299910515, 40.58636057761408, 46.00629560409054, 46.184355520433, 34.364508736518125, 28.219917781891365, 20.64481096882974, 11.58086951701872, 9.86712028903346, 6.107750583079554, 6.842891987292998, 4.672357257335417, 10.90262895630252, 15.824037598025416, 20.18633688649824, 18.994793391996815, 21.428739793838997, 17.73261389424724, 12.844908218229971, 4.922127906353244, 0.5957675184453688, 0.2421116543513152, 2.668515414960923, 55.855594604246086, 39.890002589071955, 76.69305278408912, 85.90629239236155, 46.20306522615495, 61.263123173867505, 87.68961368068572, 8.6696598991271, 0.66867561590287, 0.4556674426121097, 0.19172775228658032, 0.23479755246831527, 0.11258289473311556, 0.4290894316809793, 0.3263973985468188, 0.4673962180893268, 0.14465079132106998, 0.1886311789313632, 0.1779360399251023, 0.2553838058825462, 0.10065341954149547, 0.1145775885050816, 0.22111341417316469, 0.2321195542331665, 0.1256154752486656, 0.15845037906640963, 0.1341651620403413, 0.10598227351663575, 0.13196964597990438, 0.12458733162812649, 0.10746156631578362, 0.14660592431262617, 0.23173422732901192], [0.03937000919493937, 0.15631538395199085, 0.12289252297412004, 0.05214071787533261, 0.17140875630561384, 0.09319072724470208, 0.054394176995922486, 0.03508703377578528, 0.04461856183385657, 0.03772534865645632, 0.023429289970907475, 0.054185873858871005, 0.038290824966445085, 0.11862650108073028, 0.04657022444711578, 0.04984759072202349, 0.02913265943437094, 0.057034238557060885, 0.07486148376859005, 0.0637293567190007, 0.08657610960184567, 0.10011127443924066, 0.18351826215943984, 0.05371214423869407, 0.0037870776084732386, 0.12486839396578651, 0.12830126459800428, 0.07845991366212407, 0.0477972291710396, 0.27727945677695737, 0.09449932799344102, 1.4731202755243549, 61.8567503652265, 87.76868081861927, 51.94173989757415, 76.12784708699873, 64.94030598671206, 54.32621932798817, 47.57073294731879, 12.872837455041948, 0.2655103237878892, 1.2592320817132152, 5.594133369384274, 6.499853749429026, 7.7238283811077, 5.822615354291855, 5.520985578337024, 6.812921647102603, 2.8895949067608004, 1.2881883666399987, 0.7664000591443432, 0.23795791030410798, 1.1920567121236556, 0.8494522638859288, 0.32974192391960855, 0.8141914430645205, 0.8694855243928972, 3.627416515542615, 5.594689365356199, 6.021960012374386, 4.510629109797939, 4.612053757713688, 10.968344346169504, 16.784159291175104, 22.36529000343815, 21.9942416298774, 20.83685609602159, 30.032309716747655, 49.91722030024375, 51.171166743001635, 57.168302074555434, 67.88290731368527, 68.15642987528156, 54.67616535002186, 51.1115231821614, 51.41212578742735, 52.82652854919434, 57.71872435846637, 59.339306508341146, 61.16860581982521, 55.75436607483895, 53.66590792132963, 55.968217619003795, 61.05958746325586, 64.28694894236904, 61.7329054494058, 67.81627408919796, 66.00919892711025, 71.61054749642649, 32.862256650001775, 53.4989796915362, 66.0542904946112, 62.29092536434051, 64.96373822612148, 63.32138692179034, 57.60867049617153, 51.753415138490745, 51.20200049492621, 52.763751014586425, 53.65107351733793, 59.31499958038331, 66.94564911627, 67.57733898778116, 70.34947410706552, 65.79198591170773, 62.91322900402931, 58.77273582643079, 57.41011619567872, 55.03604673570203, 52.27847537686748, 47.95255999411307, 45.76846268869216, 44.46294100053849, 44.92857733080464, 47.16727795139436, 47.050085375385905, 41.89413762861683, 36.78582706759053, 17.04818187221404, 2.18980876668807, 14.365055138064971, 22.921799805856523, 31.181015045412128, 36.06414233484576, 31.804322811865042, 24.042011076404204, 14.16970149163277, 10.086051302571452, 2.3235029991595977, 1.8816733720802494, 7.179538232664909, 1.5829221255356267, 3.6026114465728885, 11.051406418123554, 12.091928855065378, 6.9307702395223805, 6.202625363103806, 4.596534409830648, 3.3761798806728858, 2.4440212547779083, 0.3550632135762323, 0.15335811602492488, 0.3959381412113867, 24.71427982853305, 51.68561697006226, 75.8807691451042, 47.802882348337484, 44.78686601884904, 67.71848940080213, 27.103646532181774, 0.03070775727410951, 0.11814018080551779, 0.07016272178941196, 0.1435765675118854, 0.08874689634408682, 0.13565429906931617, 0.03226702199167302, 0.0596046474041237, 0.0547735475664658, 0.078520143494731, 0.10947902822085928, 0.10200206370603654, 0.05211021225418776, 0.07149392213191717, 0.028712724508236975, 0.05576244833308363, 0.04184875562186203, 0.09100339300329648, 0.06366723847966041, 0.04931372319979053, 0.02451755042608467, 0.08643105085338317, 0.0750753678561699, 0.014983529709429752, 0.07749014594141515, 0.010667548349667943, 0.10442737550024064, 0.04519343804267626, 0.1039606057888558, 0.03972503732168867, 0.10215402490669682, 0.07056818148421665, 0.04181521629253703, 0.08040819016675796, 0.0412123242483264, 0.08649351000184975, 0.04188085087544976, 0.07235481343682736, 0.031050541400609, 0.06045077236429338, 0.019721116067000458, 0.05920487208171718, 0.018237707460479393, 0.04643494864144633, 0.059034723953734485, 0.035820697028670585, 0.027347096174414602, 0.08558027956995272, 0.1559935810585176, 0.0397715043847359, 0.12523862127695354, 0.1496319103265001, 0.10060859573704582, 0.134118614538062, 0.028351165481933185, 0.08202619850635529, 0.02307629772281695, 1.7881480099693423, 75.02348807550247, 97.28963821165024, 57.61179662519886, 88.10096833013719, 68.18220769205402, 48.616362310224964, 43.29390602727091, 18.273006677627563, 0.6896813790644369, 1.1644860044602425, 2.1866973465488804, 6.654342672517223, 6.283859120261285, 9.131196371970638, 10.305856024065326, 10.204867739831249, 6.380216065914401, 2.9136821819889933, 1.6360719574074594, 0.2922344430079383, 1.4490571473875355, 0.4778607339868623, 0.40207208464703253, 0.5013831879102415, 1.3567086189023911, 4.1975597412355485, 6.129920799886027, 7.081707946715817, 5.200254349939285, 6.255241997780339, 13.415935693248628, 20.440318199896044, 25.786194955149007, 27.563195343940492, 27.91229609520205, 36.721441361211966, 58.62962815069384, 61.59172757979363, 68.19073492480864, 75.69548422290434, 74.38244727350052, 63.411091527631214, 57.831437587738044, 59.59255041614656, 62.32509705328173, 64.36678878722653, 66.5326862950479, 63.15116782342235, 58.722039191953606, 57.40079272177912, 58.38424075034357, 63.90358040409704, 68.61721423364455, 68.77592902029716, 71.51091144930932, 69.76773169732863, 75.68979678615447, 34.17788236371933, 58.235602532663655, 70.18437370177239, 67.9281557759931, 71.75661656164354, 67.29463807998165, 62.84362654532156, 54.24495566275812, 55.339759780514626, 55.77286397257159, 54.92258825609761, 60.701965362794944, 68.15849304199219, 70.81958586169829, 73.13533752195298, 71.03298633329331, 68.46938010184996, 62.97213908164733, 65.11173317509314, 61.782170418770086, 59.51977475996941, 56.85717575011715, 56.79275866477721, 53.85917486683015, 54.11940059354229, 56.56290777267949, 53.63536050242763, 47.82866408748012, 42.83269020818895, 19.79348994070484, 4.149246927230589, 18.561355798475205, 28.52083613795619, 37.58372737515358, 43.323665049768266, 39.04690481001331, 27.48088832824461, 15.78646815592243, 13.645368852922994, 4.272596643817041, 3.164441513438379, 7.874222349735999, 4.443661012957174, 9.215479281640823, 13.38302504631781, 11.24479986006214, 9.419768087325558, 4.904472337615106, 3.3288868829127285, 5.912818101144606, 1.0189463979294224, 0.2793103252207079, 0.12916689798716577, 0.160703458973477, 41.14805575340025, 48.88837083693474, 76.04410448381978, 56.03773770793792, 43.97466474963773, 76.32783305260443, 26.30535202641641, 0.15996439863116513, 0.07650180824942167, 0.1298292269629817, 0.2014924775088026, 0.08557040469660875, 0.058575710882582975, 0.043953264267334057, 0.0664580814660557, 0.04306928307238606, 0.09001567584252165, 0.08676191656700066, 0.05910957457437631, 0.06766554328703112, 0.0631689059457952, 0.04854686152670653, 0.0450094965016169, 0.09142219028886288, 0.09658696355238076, 0.05680646912585344, 0.04597006733679483, 0.027427847587293195, 0.050447054522772955, 0.0776672501477503, 0.03321381856597239, 0.06219683613087382, 0.044861427027611964, 0.21235494543948483, 0.21013796359540957, 0.13502184752254717, 0.17694985494017604, 0.22568544222702905, 0.12132152178955656, 0.15359249296447924, 0.27881788390298046, 0.14229324766464774, 0.18119906886450707, 0.169256784682793, 0.11621163872581337, 0.06737345694414071, 0.1752345227906781, 0.16458896499487663, 0.15431168098603526, 0.2367663831119576, 0.12337278349385147, 0.24381354931862126, 0.18164799638813545, 0.1963873595119484, 0.1290240991980799, 0.3611218352471629, 0.11868336012647038, 0.2656913350426382, 0.16100436298837587, 0.24129946325575155, 0.30907394424561535, 0.20048246718943122, 0.3091255172846779, 0.18106331808432458, 4.848970799676834, 103.30027826370733, 108.43713191247757, 78.86916022146903, 96.36846957668182, 83.62454768150084, 78.25242242505475, 67.56320276568013, 20.86507166585615, 0.6710539818290742, 2.3528631656400623, 10.983306227191802, 21.93726528075434, 21.07313379164665, 17.526359981106175, 13.70475353733186, 18.833558482508508, 8.659614709115798, 4.444363117218018, 2.4540399687905468, 0.3091559462970303, 1.9110421187454656, 1.0439500981761565, 0.7281175424014369, 0.7295342534780503, 1.2114411880893092, 5.2878570556640625, 7.858064145811143, 7.104000737590175, 5.973165237134503, 6.4700216727872055, 14.23904703509423, 20.66022784479203, 26.129537666997603, 29.29605926236799, 30.625454456575458, 41.95800558213265, 61.2493242756013, 67.52467724584764, 72.40440384034189, 73.88797760009766, 76.93304692545246, 73.97612110260995, 67.39531747756466, 67.89729456747732, 68.46690116390106, 70.61899585108604, 69.8614606549663, 67.58221841627552, 61.183020530208466, 56.792452719903764, 59.511274983806, 65.61677755848055, 67.95246662632113, 69.81923241769114, 73.96973548396942, 72.4632864613687, 77.76800186403337, 40.31582293971893, 58.72598901871712, 71.69126202983242, 70.62982943750197, 74.01252854254939, 69.51887299937587, 64.82537269592285, 59.04372453689576, 58.34468364715577, 58.966751944634225, 57.64972594476516, 63.479960503116736, 70.08130165838426, 70.21584680003505, 74.1465873102988, 72.24355528431555, 71.11324587175923, 64.07841613215786, 65.08288022010558, 62.19770239245508, 62.988832689100704, 61.24286020955732, 62.626943049892304, 60.70455804947884, 59.73115521092569, 62.66501749715498, 63.632501479118105, 57.17059666110624, 47.65600527486494, 27.74415977539555, 13.883118417955215, 25.127781975653864, 32.899509360713346, 38.634726462825654, 43.19002989799746, 38.59873479412448, 29.51648077657146, 18.336978573952955, 18.175673061801543, 5.838478399861244, 3.710088556812656, 13.270220621939629, 3.161430113738583, 12.490518150791047, 24.935962384746922, 24.46083195747868, 16.446858009984417, 15.777865417541998, 14.613881476463812, 12.869198476114581, 5.896772175065934, 2.2683341272415656, 0.5201931285762018, 2.167513034036083, 41.376027830185436, 67.55445588019587, 92.51245806294104, 68.16238403320312, 58.63250717040032, 86.84898699483564, 45.82664320545812, 0.2631838066924003, 0.19630900403905302, 0.29139674118449616, 0.24919177766048142, 0.11702586761525563, 0.26650182542300993, 0.09091221321854862, 0.22569042179853688, 0.13184892584479627, 0.25652789691042516, 0.16948665702535262, 0.1258008378828245, 0.13483749612444831, 0.20572157396424204, 0.08089418868504225, 0.3092786429389831, 0.21318616615908764, 0.28938910052660977, 0.15926695218490017, 0.19748237494739795, 0.14128928943987817, 0.20464546557876373, 0.24250338575051678, 0.11078224337149052, 0.1787946253053604, 0.12329409860314862], [0.04469064687709174, 0.1019939125305222, 0.21459166170848956, 0.18971713920754774, 0.04473070944509199, 0.06477215177109165, 0.10719901266237421, 0.07104965242286844, 0.04443871120231287, 0.0508007305043359, 0.10818338967979917, 0.02609504229058662, 0.05501429069667094, 0.061175690723523024, 0.09493359259419865, 0.0442996011265824, 0.03889945500920858, 0.06359228826758843, 0.10263074610021808, 0.11429933771010369, 0.07298195599428109, 0.06345087609764549, 0.15765934731931458, 0.06506571666367593, 0.050180306537978114, 0.011441353652175638, 0.2994449851253341, 0.039265411380197734, 0.20694429625666913, 0.16393849506012856, 0.43011647979578665, 0.1343712090484558, 21.555430389219715, 96.73976113719326, 63.61095589976158, 46.86619289459721, 91.36100707515594, 43.36712098890736, 51.13737160159696, 13.02898406982422, 0.08213252384936617, 0.5193352326750755, 1.123717869481733, 4.08742277372268, 3.5809393707782995, 9.661970523095901, 8.237290170884902, 6.700193218646511, 5.717068785621274, 2.082141666643081, 0.07746202285371481, 0.4610652674830729, 0.12264236462332549, 0.9307132324864789, 1.0039803493888149, 0.17719845047160504, 0.18441947267180492, 0.639580148122003, 0.9784221240589697, 1.4473662381210637, 2.0588008674883076, 1.913342466277461, 4.462709513402754, 11.594587026103852, 15.118505185650243, 15.505974561937395, 17.798921562010243, 29.442497030381237, 35.77099615527738, 39.03998182665917, 47.76560414221979, 66.56346905616023, 74.3121740894933, 61.8067087665681, 54.850950087270434, 57.097040453264796, 57.83583456470121, 60.136724364372995, 66.52149969531645, 65.47328549046671, 65.97399173244354, 56.829695624689904, 54.720237101278, 55.05942013955886, 63.550327824008086, 59.0480391440853, 67.27173143817534, 62.18247182907597, 67.38529189940422, 51.38589689808508, 52.947133587252715, 64.91813675049814, 62.496332045524355, 64.32722383929838, 62.73564761684787, 57.1041948564591, 50.98793322040189, 53.1319478250319, 52.26778299577775, 60.64201977945144, 69.88757579557358, 69.74901414686634, 70.07300192309965, 68.61366841100877, 70.75849102389428, 68.75132006983604, 64.03904730273833, 56.7366530818324, 50.04030035388086, 45.673400125195904, 39.27460232088643, 34.64431101276029, 33.488200249210486, 32.01852148579013, 24.230663353397002, 18.90231174807395, 14.399587685062041, 13.936846063983056, 8.130682110786438, 0.13093300644428502, 3.061015230994071, 8.096569747694078, 17.265571394274314, 24.90393230991979, 29.710255669009303, 25.93321127276267, 17.701921347648867, 6.797905343194162, 2.6804301046556045, 0.26327120200280224, 9.516776146427278, 4.908721245104267, 6.3921792949399645, 7.576950817338883, 6.905169910000217, 10.633030726063637, 4.573919004009617, 1.995039921133749, 1.5178799124494677, 1.031995817057548, 1.391881492830092, 0.5618392616029709, 9.996709515971522, 30.622871575816987, 56.71604494894705, 64.92390263465144, 33.44576020394602, 61.10598125765401, 50.85742027528825, 2.126888555865134, 0.19882050072473867, 0.1016766831819569, 0.17785832796606327, 0.14263507609646167, 0.23208425290161566, 0.10810901020323077, 0.1156398077164927, 0.077340176569358, 0.10528711001238517, 0.10754401269819468, 0.10854956438584674, 0.04348925630291624, 0.0664128746176439, 0.06077366310261911, 0.06967801795971972, 0.023054644247637163, 0.053655036214378574, 0.07709626949602559, 0.09554089347441351, 0.12167384562593316, 0.09635938181271476, 0.0630224529173105, 0.08368775894444797, 0.04840651804941797, 0.04604488348348006, 0.0034324698724723874, 0.020512676414763256, 0.0494390168798066, 0.14335889128908036, 0.04664982098244852, 0.023333686028396892, 0.032483637182702946, 0.14204600044796545, 0.07383572268149546, 0.00769763422619191, 0.044091144771946054, 0.005413356824823085, 0.05378611768866259, 0.018253486956499757, 0.04404838557445234, 0.03021129974043898, 0.13435705174361506, 0.03449832584949271, 0.055142855572123686, 0.09164051768640358, 0.08864784117547736, 0.20714540965855124, 0.07947160937492886, 0.1214767158812573, 0.09482730555558398, 0.0307666905029046, 0.10435632084526363, 0.34546538826919376, 0.037899518746041486, 0.21840884800880186, 0.07914809044450521, 0.4691286799648116, 0.1928637993912543, 26.645743154710342, 116.92870247748591, 64.85497482361333, 58.9191069141511, 94.68782809472854, 47.10042899654758, 59.19062514458934, 12.882800275279632, 0.08439626770033952, 0.49222607766428306, 1.830308708933092, 3.193480535860985, 1.362002470320271, 7.888098224516838, 9.0334685579423, 11.327770736909683, 9.334828180651511, 4.428640786678561, 2.1366827141854072, 1.688522013925737, 2.089402709276446, 2.9258263303387553, 2.0487902433641496, 0.9181528226021798, 0.3094773967900584, 0.5337962147689636, 1.82935900505512, 1.3653540130584472, 2.0992184406326664, 2.0321991078315245, 4.932126518218748, 14.71783507254816, 19.408299461487804, 21.821788741696267, 24.202841981764763, 35.026573442643695, 44.44938528922297, 53.46216432509884, 60.4488391260947, 75.94444490248158, 81.90552188504128, 70.23880051028344, 66.60130423884239, 66.78823655651462, 67.9194010457685, 68.43942103847381, 70.52477267480666, 70.53726934617566, 68.44981531943044, 58.37552132145051, 58.71889737344558, 59.02036682251961, 66.84091398792883, 63.889942323007894, 71.43626090018981, 66.39549747590097, 73.86003463499009, 55.94592678931452, 61.23829849304692, 71.62742937764814, 69.94218303311256, 70.85557753039946, 70.08765589806342, 62.142440119097316, 55.75735884328043, 57.46003620086178, 54.21039958154002, 62.86861204331922, 74.57177223697786, 74.68581122736778, 73.3530604454779, 72.81301283067273, 75.04360983448645, 72.52040401581796, 68.6316171769173, 62.44385465498894, 60.58885989650604, 55.743050036891816, 51.96636845988613, 47.49109314334008, 44.97331196261991, 41.48076295852661, 30.5549322020623, 24.238227644274314, 16.781858821069044, 15.459466038211701, 13.855353920690476, 3.1616544242828124, 6.229842689729506, 9.715478516394093, 16.91998116431698, 30.195668589684274, 35.46823624641665, 32.334107545114335, 24.946368432814076, 9.939114412953778, 3.496463529525265, 0.6523640718190902, 15.7783184512969, 5.770956268233638, 8.300492302063974, 12.173019936007838, 7.319660494404455, 6.980757905590919, 3.8017288523335613, 2.3244831014064053, 2.7752276630170885, 1.1583396504002235, 1.5065802994274324, 0.9531961970271604, 19.715385744648596, 41.541900942402506, 51.5625016150936, 79.5909704700593, 36.06532296826763, 65.89959221501505, 58.172185651717655, 1.9634259852670857, 0.33312175062394916, 0.23777322182732247, 0.2812664541265657, 0.15605463826608273, 0.24955501058889976, 0.12293265832047309, 0.09569498439950329, 0.0955898924580505, 0.04329744703887452, 0.07585581992903064, 0.07049422335600661, 0.024117114352843454, 0.07338548514751658, 0.06232688721689967, 0.004798795346305856, 0.04901510978778524, 0.08918459301874523, 0.015968580884228072, 0.07289986967319444, 0.05092686688106868, 0.02028092907200898, 0.02709498238419333, 0.04711005213339964, 0.008461590510823073, 0.1119637654553498, 0.027433443859580065, 0.18557321640752977, 0.11309782073142068, 0.2593609666632068, 0.28293266471835876, 0.10253711483411251, 0.1960429570247089, 0.28709610743868735, 0.23436391605965554, 0.11984946852129315, 0.11599545637446067, 0.22065848052020998, 0.12211986201544925, 0.09268764496570633, 0.1668578109914257, 0.09318099026718447, 0.17871769475600413, 0.09623552837799634, 0.1708140269282364, 0.1936464961017332, 0.18771959558850337, 0.2797054733720518, 0.1718440627859485, 0.4293247432478013, 0.17448401709477748, 0.20481794261403624, 0.18739125030415674, 0.5181360292819239, 0.2590826315985572, 0.37205924189859824, 0.37253633081432314, 0.5656878421864202, 0.38499678154626205, 42.683546004756806, 133.62468688718735, 86.7705709703507, 69.784880299722, 110.61175669393232, 63.43505720938406, 73.66355526831843, 25.20009086978051, 0.2513870638945411, 1.255275635950027, 3.6583838732011857, 7.687833770628899, 12.956273132754912, 20.869141124909927, 23.587633909717685, 20.13962341893104, 17.900424657329438, 3.800598474279527, 2.153480999892758, 2.6066069304943085, 0.9979795520344089, 4.0847906181889195, 1.4981810339996893, 0.9865345048808283, 0.48621225681516433, 0.7055010947008288, 1.6566316735359932, 1.9065128843630514, 3.205951956971999, 2.9865186349038155, 6.210804485505627, 17.48110955761325, 19.82986992405307, 25.24054031218252, 30.20047937670062, 41.67475162013885, 49.397180695687574, 61.943870129123816, 69.01252638909125, 78.49519360450007, 83.64314756085797, 77.19971318398753, 75.35864676198652, 73.63891493889594, 74.85628527979698, 72.83657843066801, 73.95650140700802, 72.85335833026518, 72.09264601430586, 61.70844947138141, 61.808791545129594, 60.7760863919412, 68.50643081049766, 65.9072800605528, 73.25613867851996, 70.34991341252481, 73.9786078852992, 62.70246436519008, 63.19771851262739, 71.60728408444312, 73.20545381115329, 74.25167545195549, 75.3229610381588, 64.99850219295871, 60.16875051682996, 61.98933039942096, 56.74695714827507, 65.81856389199534, 76.80578954758184, 77.68176463342483, 74.2770924106721, 74.3606310506021, 76.87283069856706, 74.66714859008789, 72.40205826297884, 65.96682163976854, 62.71644369248421, 60.905897232794, 57.73141322597381, 57.46117761058193, 57.40568783975417, 58.123512960249386, 52.19032402961485, 45.65088179803664, 43.01587666234663, 36.13011267877395, 20.56702840712763, 7.026609432312751, 15.47008095249053, 23.237272116445727, 35.84801581598098, 38.9338856358682, 36.26333990404683, 31.708516959221136, 29.79909343104209, 14.210818717556617, 3.972250218352964, 1.5401070036234394, 14.276721400599326, 7.5970588480272605, 17.038215129606186, 17.89814772144441, 21.94012664979504, 23.31485071489888, 10.817228171133227, 8.284514527167044, 3.6871316596384975, 3.2785366427513862, 3.0731686949729924, 1.0511398027020118, 17.229465976838146, 47.87757212115873, 70.75187006304341, 84.6427635992727, 50.961394463816, 76.60852570687571, 78.155163334262, 5.465670843278208, 1.01826531512122, 0.44278273238770427, 0.38914919260048103, 0.2733116116254561, 0.30236856050549016, 0.3978752711367223, 0.22349300584004772, 0.3056207876051626, 0.24148548472552533, 0.2186865089160781, 0.11096681693508742, 0.15021586850766214, 0.09101853090068025, 0.1457412408724908, 0.24989752849984556, 0.1577779070864762, 0.14855180296205706, 0.14918146594878168, 0.21458924087064885, 0.2827218373215968, 0.1631521670928886, 0.2270088284727066, 0.16648826549851126, 0.12553075358511942, 0.35603737098074734, 0.15008977043532556], [0.08479804251222842, 0.056083504290830706, 0.10138956108881582, 0.05893677961261523, 0.10377441577973867, 0.16213279517908252, 0.030203964448563998, 0.030288195815838637, 0.037308681095319415, 0.03240571071904513, 0.14307471863444776, 0.08410961292083226, 0.05597879539334005, 0.12094832971812257, 0.03525359661228234, 0.07453529119131065, 0.0834226159138545, 0.09730543145128796, 0.17078025777253414, 0.036827439983044906, 0.07721791659752208, 0.07862371858209372, 0.09015197820600965, 0.10052462483966544, 0.10272094529242286, 0.04732890430116846, 0.2219314122151944, 0.10903799906373025, 0.2585232341962476, 0.16331545107306975, 0.2622678413266136, 0.16978987462578282, 3.4919832021959367, 78.97909641265869, 83.9691985038019, 48.85383828993767, 60.95307942359679, 83.47322264025289, 43.05917570667882, 13.627808401661536, 0.56598398113443, 0.6047529330657375, 0.9220138444535194, 3.2573933514856526, 0.6770960866443573, 6.428749513241553, 7.616234825503442, 7.091402084596696, 6.890910623535034, 2.0885010544330846, 0.8134875001926577, 2.1504445950831137, 0.7168895739220804, 0.6104393279360187, 1.1662616124076228, 2.1391493947275224, 1.4407982292675203, 3.0029278705197, 1.389306947108238, 1.6729694484703004, 2.2758162934933943, 2.1001703508438605, 3.1628127492243245, 5.8118303072068, 7.13506345787356, 6.835968513642588, 7.590473678804214, 11.323340419800052, 26.078539010017153, 33.49122439661334, 42.746370607806796, 66.12690925598145, 77.15633176988172, 66.97499628989928, 65.13315323860415, 64.1851399021764, 62.630304521129986, 67.40802595692297, 72.03417131977697, 70.99577872983872, 70.63806641486384, 69.43878604519752, 58.4019620187821, 53.67166203837241, 57.766188959921564, 58.42015004927113, 63.44927580125871, 63.221401783727835, 66.96040507285826, 38.62456752407936, 42.86683051816879, 70.89853532852666, 60.742965898206165, 66.98735960068242, 60.59810100063201, 59.844390115430286, 52.99571214183685, 53.83690364899174, 55.956093572801166, 69.10008938081803, 70.67539953416394, 74.53858114057972, 74.06311142829158, 74.08743012335994, 71.6580238649922, 69.52514879165157, 61.47830440152077, 60.049596755735344, 48.114887283694365, 41.64936604038362, 32.818857585230184, 23.34030297494704, 18.614776519037065, 11.441205682293063, 5.143666315463282, 2.4689942502206375, 4.262506346548758, 5.46214904515974, 6.704885353965144, 2.530178321946052, 3.0383333900282463, 1.937033336970114, 1.4812447298919003, 6.217864261519525, 14.046126238761412, 19.76698256308033, 15.289033170669311, 5.454931884042678, 0.7908926255279972, 0.4978477227832041, 2.095142117431087, 7.608130228134894, 8.06988831489317, 12.014908213769237, 7.485095281754771, 4.602894533065058, 1.6873406450594626, 0.3940035240544427, 1.7366274326078355, 0.8196947122773817, 0.73472177189204, 6.952912019145105, 39.29234712354599, 47.27487640996134, 79.72226788920742, 31.65433922121602, 50.51438939186835, 59.927242340580115, 19.92102776804278, 0.04834448407974936, 0.09759423893786247, 0.08393349696791942, 0.15323247760534286, 0.06789178437282962, 0.218158521118664, 0.07349612356554117, 0.03547092809552147, 0.062258015912506855, 0.03027438899622329, 0.07339113121551853, 0.20380468408186592, 0.03802899143568451, 0.004533027475249143, 0.02443940371214863, 0.004951366065670887, 0.036120685568499955, 0.019816750653028008, 0.016202882172599915, 0.126520830296701, 0.03403606839598187, 0.01108272874262184, 0.03148937571583496, 0.047441584343511256, 0.043250937840991446, 0.05031829812533913, 0.057205673712756366, 0.09303509648288451, 0.07738589669667906, 0.1020628527828282, 0.055984870470579595, 0.03410164552230028, 0.0771824467266279, 0.08260174504210872, 0.04854427981040171, 0.021586093916407516, 0.014510158235357415, 0.05785876366820547, 0.04166200636856018, 0.05259933641120311, 0.10966835919046596, 0.08477521309208486, 0.040651509583356886, 0.12171588087033842, 0.17185901682223045, 0.12789359090909844, 0.044426495930360216, 0.06511863801748523, 0.03905409751760383, 0.08590454926654216, 0.09633485933825855, 0.16255895456960126, 0.11941828359399112, 0.2822342683230677, 0.253698596310231, 0.27567998776512764, 0.17199121295444428, 0.22496539618699785, 0.2800636347984114, 4.5590561628341675, 89.9729351843557, 99.5233025089387, 45.672129277260076, 77.87407844297348, 78.67741907796552, 58.05872717211324, 22.314491387336485, 0.7913448012644245, 1.1424721921643903, 1.287507835415102, 1.833222907397055, 2.6097158991521408, 3.609674409512551, 8.564070674680895, 13.779373688082542, 9.317525625228882, 5.248465672616036, 1.579433912711759, 3.6695895944872214, 2.356707823853339, 1.6045258050003361, 3.5353415723769896, 7.173475228971051, 1.7314844698675218, 4.914965658418594, 3.8856536005773856, 2.4478784155461097, 5.208591347740543, 1.0327042951699228, 3.5268530730278265, 6.729788482189179, 10.291547217676717, 11.706735434070712, 12.477599824628523, 21.175793986166678, 39.662975803498306, 47.8182384275621, 54.7061401028787, 73.547547248102, 83.77759856562461, 73.53736477513468, 71.97564171206567, 71.66353871745449, 70.88581115968766, 74.85226877274053, 77.2027490985009, 74.84502023266208, 74.0797265883415, 72.44420805285054, 60.36757546086466, 56.209561055706395, 61.737067084158625, 64.0419263224448, 69.78800250637916, 69.18292983885735, 75.43488194865566, 46.82108955998575, 48.84123179220384, 74.84803261295443, 66.93296417113274, 71.80119822102209, 64.66994093310448, 62.95004829283684, 56.74805148955315, 56.046006064261164, 59.26894310981997, 73.64083690028038, 73.80967140197754, 76.99450262131231, 76.46688891995338, 76.80383620723602, 74.48248340237525, 75.36158069487541, 68.6393677803778, 68.61783396813178, 58.09231442789878, 53.62935143132364, 43.05782248896938, 36.81592733629289, 28.677036685328332, 20.74202299118042, 12.80636210595408, 7.567964667274107, 7.274413502985432, 11.85276919795621, 16.21409966099647, 5.299962470608373, 8.85652357532132, 7.121344968195885, 2.832633266525884, 6.316020104192919, 16.126457241273698, 23.428628867672337, 17.667537850718347, 4.711741776235642, 1.15687599345561, 0.7773378948050161, 5.733809951812991, 10.871965827480441, 7.576151634416274, 6.4516399752709175, 4.726131481509055, 3.8017013957423553, 1.8880685514980748, 1.841291222841509, 1.8114772871617348, 1.4662906936099454, 0.8771373944417123, 11.626916181656624, 60.22755469045332, 39.75259803956555, 87.443555555036, 36.05464235428841, 53.39099291832217, 69.27943583457701, 20.371386466487763, 0.18364914062042392, 0.11434927898188753, 0.1095359638753918, 0.16025808609781728, 0.07357637893648879, 0.26151802510984484, 0.11274751170628494, 0.04300680477172137, 0.08880394691180798, 0.09701185123694521, 0.07482950725863058, 0.14907641997260435, 0.015782403324039716, 0.03194720901158308, 0.03737655648541066, 0.021063673662983125, 0.03839672130021838, 0.0627051163164358, 0.047247675998557004, 0.013639216814490577, 0.01897280521300291, 0.027178357648212585, 0.05228013821667241, 0.08741129865689624, 0.03234808941582038, 0.04614961536360845, 0.012604842026297365, 0.11527997621845816, 0.133388793216117, 0.1941918434515115, 0.13585316017270088, 0.17818232187099997, 0.209945859387517, 0.0830331368131503, 0.2079828356903407, 0.12898294495478754, 0.2132628515603081, 0.17710518692770313, 0.09613461927661011, 0.2238005288546124, 0.1784185374215726, 0.19527915204244276, 0.13230955919190762, 0.21334617128295286, 0.2736032459764712, 0.363422519857845, 0.12942054969889502, 0.15304256440891376, 0.26531543101995225, 0.30321619082843104, 0.36538989493443125, 0.37553688270911095, 0.21028561938193538, 0.4588640210849624, 0.2386482474544356, 0.3494931721398908, 0.19920432609656166, 0.5855156685556135, 0.38280377825421674, 7.654168557736182, 115.17426552311068, 109.59221501504223, 71.83799789797875, 82.64861491418655, 104.47639311513593, 69.62362381719774, 25.300409409307665, 0.7022834641318167, 1.2370668904435251, 2.9989760825710916, 8.229963183403015, 6.70448576250384, 18.366743480005574, 16.736943760225852, 19.339559924217966, 16.261222035654132, 3.5477404296398167, 1.1288744379435818, 3.408839986208947, 1.414387440008502, 1.4376197611131978, 1.3903700319990036, 5.179739373345529, 4.507401489442395, 5.159531322217757, 2.9639853537082677, 4.719062389865999, 4.986354756739832, 4.956297143813103, 5.386241376399995, 8.756039315654386, 13.687577478347288, 17.873534848613126, 21.053516057229814, 30.455758994625462, 50.133833193009906, 62.45204064153857, 66.01471377957252, 78.01129864108178, 86.59825340394052, 80.22247206780219, 77.13351926495953, 74.99479986006214, 76.27463002358714, 78.82210746888192, 79.46748641229446, 78.16796595050444, 76.04197071444604, 74.07324683281684, 61.8993982961101, 57.980726918866566, 62.8733894901891, 66.36916268256404, 72.84454084211781, 74.54785362366708, 77.26223576453425, 52.635677783719956, 52.19258723720428, 76.98190396831882, 71.4353979787519, 77.8756630805231, 69.43810355278754, 67.91627883911133, 61.868442950710175, 60.55844191581973, 60.559983407297445, 76.14061832427979, 76.29764649175829, 79.939300475582, 78.08444300005513, 79.73677281410464, 78.2875668617987, 77.50717209231469, 67.87542343139648, 71.08890364246984, 61.608417264876834, 61.638976450889345, 55.61676148445376, 54.07138686026297, 49.28666791608257, 42.10172906998665, 37.86693034633514, 27.694498646643858, 18.29395409553282, 21.11643283597885, 23.78128916986527, 7.443789782062654, 11.607580857892192, 14.231831835162255, 13.221725417721657, 24.253164029890492, 29.344918266419445, 33.036527556757775, 20.530513102008452, 9.685456695095185, 1.6375805990349863, 2.0506554529551537, 6.00052131760505, 16.24515110446561, 22.16615911453001, 25.56415938561963, 14.01073665388169, 11.654805214174333, 9.041979120623681, 6.15406543977799, 3.3036552561867625, 2.215069320894057, 1.0270153875312498, 10.709890550182713, 61.44351297809232, 57.71759863822692, 98.59086882683539, 48.416239061663234, 66.23684544717112, 78.54020672459757, 43.218121913171586, 0.37712311372160917, 0.366614501803152, 0.15404604765917027, 0.3539991787364406, 0.23227983514868447, 0.4036357926745569, 0.1757248343839761, 0.2714788841624414, 0.172019190485439, 0.18688629110974653, 0.15036681847226235, 0.21338844401461465, 0.0992392901811869, 0.2557341991773536, 0.12821352454803644, 0.0778521454682754, 0.09726269140599236, 0.12733004131023923, 0.09099812231837742, 0.3971077429671442, 0.12073591651935732, 0.089737149255891, 0.13170916076389053, 0.14410568911942745, 0.16458256049982964, 0.18437459524120056, 0.23393608659746187], [0.10742838704778303, 0.06502207263462967, 0.2123556195968582, 0.08601827501890161, 0.15326921918219136, 0.08705640076509408, 0.06461597708684784, 0.04745235937016626, 0.0482288392771396, 0.025230071567479643, 0.03511493469798758, 0.035703818824502735, 0.23308560642744267, 0.008658428184477793, 0.1191378647701875, 0.021428477071646242, 0.05141165881087223, 0.10335603218165137, 0.08367056793142712, 0.0834018013049518, 0.025179352716452656, 0.03348247794013831, 0.03934476659783433, 0.08544468966823432, 0.0244497248317085, 0.09961142505128538, 0.2027537187020625, 0.4105160589660368, 0.10125720407813789, 0.12697253871949452, 0.07474125392975346, 0.2533443419322852, 0.15889015950022206, 25.57941544440485, 80.02415703188989, 75.4474021542457, 47.55855791030392, 70.15647780510687, 64.71071789341589, 28.598087218499955, 1.7833041279546678, 0.4515254809971779, 0.6623664834806997, 0.45315400006309636, 0.660407075718526, 2.0862552523612976, 5.919619981319674, 12.009117814802355, 8.271580511523831, 10.440268785722795, 5.331518428940927, 1.4419876880222753, 6.7392252145275, 0.12938604509878543, 3.6460771916374086, 0.801561411109663, 0.9845469663700751, 1.282796578541879, 0.1088755194758696, 0.24939214029619772, 0.5353826909295974, 0.42913346641486694, 0.4922457508021786, 1.564665208420446, 1.8086959589873592, 2.0622581916470684, 3.49512747218532, 11.714539970121077, 30.309603637264622, 42.80712027703562, 53.17525471410444, 75.0907959476594, 83.93907470087852, 72.74859182296261, 70.9092120201357, 72.63394878756615, 70.38974900399485, 71.9275926774548, 77.14148952114967, 76.60086139555901, 75.45585878433721, 73.04371095472767, 71.16942205736714, 57.8984316702812, 56.48699029799431, 56.99732988111435, 65.74281900159775, 60.848865970488525, 67.76433406337615, 43.344186890509825, 42.1978271392084, 72.23570269923057, 63.35996735480524, 67.33161034122591, 61.24664137440344, 61.38076290007561, 53.89016159119145, 55.55588237700924, 63.148700652583955, 75.38491095266035, 73.8901113694714, 76.1758804321289, 78.31368984714632, 73.63209785953646, 76.14997709951093, 72.8452625582295, 65.04734746871456, 57.2740883981028, 45.48920169953377, 31.424050984844087, 18.954900926159276, 10.516819723190801, 6.370220886122796, 4.180841618968595, 4.78326472543901, 3.541446496402064, 5.575830609567705, 8.782230942480027, 8.545878721821694, 3.2375397845622036, 3.7307368939922707, 4.808975861918542, 3.1491079878422523, 2.941869559787935, 1.8677560672644649, 7.9631253211729, 9.809166289144947, 3.023723786877048, 0.7401456131089119, 0.6140159166628315, 6.81913762323318, 4.867938401237612, 3.6144342057166563, 7.674704126773342, 2.9483880487180527, 3.21485034400417, 0.5075465184786628, 0.765214216324591, 2.076373085860283, 0.6513213955106274, 3.5703023931672497, 35.614599489396625, 35.09917651453326, 86.87007365688201, 38.01739246614518, 34.942819072354226, 54.08875119301581, 43.978532206627634, 1.5290087797949392, 0.23784629129354032, 0.022721411322333643, 0.10273741618279489, 0.1504279829321369, 0.10370498523116113, 0.09364828091835783, 0.0449729694293872, 0.06283339007847732, 0.0943302677103108, 0.035218866016235084, 0.08439105064157518, 0.135540014072772, 0.06312667534896924, 0.02145684722270216, 0.11432698582329097, 0.02342681933735167, 0.07116049768463259, 0.015377125575117048, 0.07759977312337968, 0.07988385660874267, 0.03735670331685293, 0.07984801901564484, 0.05304261020595028, 0.05144085442166656, 0.12023788275978259, 0.07080380714708759, 0.06809999174889057, 0.03546100725690204, 0.11413700367894866, 0.20168583810089097, 0.05240044466430142, 0.20066001572676245, 0.062058273808009205, 0.023028911354260582, 0.033171101503314517, 0.06810846468133312, 0.046670321495302265, 0.06545668963583247, 0.017018520663822853, 0.23288737351615585, 0.04006073321966876, 0.1398031248320495, 0.11072864786030785, 0.09023781835792527, 0.14548179753605398, 0.129647909273063, 0.08198298348654663, 0.04278519468742513, 0.1264345458137893, 0.01311173271988669, 0.11348226663446236, 0.01342353720833818, 0.29100744594489375, 0.18045533538585712, 0.5776992428206629, 0.1197034904673215, 0.19548210405534316, 0.10104125921404171, 0.3774353711595459, 0.28149723045287595, 28.394555430258478, 100.58661783895185, 84.19381695408975, 51.6179717740705, 93.36557357541977, 63.3223282906317, 48.145426857856016, 3.7178273931626356, 0.6318225579396372, 1.2851137187211745, 1.378469438322129, 0.6293289111025873, 1.1410082900716414, 2.060948855453922, 7.129687359256129, 8.3060993302253, 6.213692330544995, 6.072760589661137, 5.1141156688813245, 10.294185992210142, 3.6549635664109266, 8.557143768956585, 3.239633594789813, 2.56399993934939, 3.6849140496023245, 4.623204075521039, 1.4881036070085343, 0.9983795112179172, 0.9847102350284977, 0.6091454973624599, 2.323343898019483, 4.75391362943957, 6.66485756635666, 10.894156636730319, 20.799401383246146, 39.37158684576712, 53.778174000401656, 64.68069607211699, 81.68208014580512, 88.62010971192392, 79.36933302110242, 81.48024282147809, 80.24522181480162, 77.80455835403936, 76.94310388257428, 81.6994405561878, 78.93639749096286, 78.75331694079985, 77.51806059191304, 76.33590529041906, 61.977210275588504, 60.15084881936351, 60.614496507952296, 71.92651010328724, 67.58378736434445, 74.83735592134538, 50.741529926177, 49.987360123665106, 78.16194118991976, 69.30019301752891, 72.45381001503237, 67.13411900304979, 65.18606993459886, 59.84686513100902, 60.41039205366566, 69.05089501411685, 77.39927553361463, 77.3538701764999, 75.10057833886917, 79.20469545548963, 76.5579192869125, 77.92026042938232, 76.92073852785173, 71.2675440695978, 69.38593602949574, 59.108023951130534, 46.961835968878965, 35.84778439614081, 25.994090380207187, 16.08901821797894, 9.16809214699653, 5.74436406935415, 7.616231393429541, 8.712347053712415, 13.390017651742506, 13.726515827640412, 5.030579480432696, 6.481875565744216, 9.11602464414412, 5.9143095824026295, 4.755182516190314, 4.227578130460555, 12.391580285564547, 10.125872185153346, 1.9617809187020026, 0.9812282121950581, 0.989974975105255, 6.933766930334031, 6.417212841972229, 7.227175908703958, 7.0073407888412484, 5.007354146049869, 4.244141809401974, 0.7160493899737636, 0.37471336883402645, 1.9921968156291594, 0.7505479226669958, 4.32012939645398, 60.020951686366914, 31.4294050201293, 91.21634221846058, 47.75307609188942, 37.308400523278024, 59.63372353584536, 49.538338953448886, 0.7888287846599856, 0.21873757633711063, 0.009332139311628717, 0.07684189000076826, 0.03188575918395673, 0.12196875117238491, 0.14784252811824122, 0.10623974034622793, 0.07378668539346227, 0.29795898905684876, 0.014636846195395677, 0.03256898320790741, 0.017825898812002233, 0.10073741342151359, 0.04793687933875669, 0.05319339163120716, 0.029892365846242157, 0.07310711177847079, 0.02208179493825282, 0.0997316089248465, 0.032804172200661515, 0.04458178961349111, 0.031645762989477765, 0.06532822435180988, 0.02792811449316721, 0.02296094786405804, 0.013660675894859578, 0.07255911376447448, 0.20921300435739182, 0.1793378276089507, 0.2936071499941811, 0.09943028356158927, 0.3311497177327833, 0.2580100472175306, 0.16023239150883692, 0.06808794884672088, 0.12362884838254222, 0.11770531099529997, 0.1748030927152403, 0.09370240503020826, 0.2699020607096534, 0.1417019503611711, 0.24027762453882928, 0.2001366397786525, 0.28284269535253126, 0.2512883917698937, 0.3023918495783883, 0.16819118702363584, 0.10660498808588713, 0.240077767521143, 0.1761687057273042, 0.2582613240566946, 0.13652705707617346, 0.4055149757092999, 0.4501575237560657, 0.8398688716753837, 0.35039721717757566, 0.47745850718309807, 0.26304505284755464, 0.8258873993350614, 0.4916010418486211, 41.81478808003087, 119.77570779861944, 101.1481051291189, 72.11614885637837, 94.42367999784409, 85.00083677230343, 53.98810317439418, 3.635769693120834, 0.6771150856248794, 2.7663010839493047, 2.652485178362939, 3.1575405934164604, 10.103832387155103, 18.777874554357222, 24.5162844657898, 18.14704760428398, 26.877006100070094, 17.461989964208296, 6.055983141545327, 11.79117916091796, 3.151102758223011, 9.086730422512177, 2.3385992213602993, 1.8577776801201606, 2.539658935800676, 3.0691320857694073, 0.6676615606392584, 1.9843135870272115, 1.182118161551414, 1.1262629974272944, 3.441426302156141, 8.606894131629698, 11.349621280547112, 16.033042073249817, 29.689882878334295, 48.12820373042938, 63.209222824342795, 73.85191532873338, 86.66152123481997, 90.63041856212001, 81.85801413751419, 86.42953657334851, 84.89235185807752, 81.13931825084072, 81.50648347793087, 84.26312523503458, 81.29605616292646, 79.91027493630686, 79.50194835662842, 77.9577112197876, 62.94657307286417, 62.0521903038025, 64.13552584186678, 73.8992504919729, 72.01961932643768, 79.31712627410889, 56.442267433289565, 55.674126148223884, 82.72702309393114, 74.187223065284, 77.23263755921396, 69.67524220866542, 68.60236414017217, 61.690053555273245, 61.88859216628536, 70.75444313787645, 80.76692842668103, 79.77471782315163, 81.39253077968475, 82.90258838284402, 80.08231009206465, 81.93584180647328, 81.63123053889122, 74.20965902266964, 73.76075160118842, 66.92688449736565, 60.101619151330766, 52.52267037668536, 47.69388360361899, 42.19119048887684, 33.062128866872484, 20.734191979131392, 13.666050530249073, 15.822451979883256, 21.554587079632668, 21.480787684840543, 7.871335485289174, 11.106345095942098, 14.224858841588421, 8.303135979560114, 7.693181922358852, 13.923678667314592, 21.035530028804658, 14.019933631343227, 4.27441172061428, 2.2056936304415427, 2.2545803362323396, 13.109559359089022, 14.173632687137975, 14.226547421947604, 17.096454481924734, 11.114252594209487, 10.816950663443535, 4.473687737218795, 1.9237230189384955, 4.4596873271849855, 1.4237019660011416, 4.560774160969642, 56.19702908300585, 43.94104219252064, 105.65120573966735, 57.586799360090694, 54.011974719262895, 67.3318535281766, 81.2747263139294, 3.2773895946241196, 0.5920258837361491, 0.16815283666214637, 0.21637146781769492, 0.2729078526458433, 0.2860440542140315, 0.5019408999191177, 0.2266688692954279, 0.18809395211358226, 0.42058404775396474, 0.11728868173855929, 0.2562891992349779, 0.16639817355861589, 0.21816126371343292, 0.16423144708237342, 0.25111853475532225, 0.20644404084211398, 0.22896348648974973, 0.10933034587651493, 0.22126318436236153, 0.1907942435073276, 0.10905742705349, 0.15177452035488623, 0.20603213068698684, 0.07652690528982109, 0.19038124550734797, 0.16844105426101916, 0.1655666310820849], [0.13445236840315405, 0.1031620510583443, 0.1350250038047952, 0.1566376158547017, 0.1453934982419014, 0.10477812119549322, 0.08644228170235312, 0.05523407749170738, 0.04671271680103195, 0.17220400153629242, 0.18398926833704596, 0.12245447389901647, 0.04023095029556463, 0.08285866794927467, 0.026576990118971276, 0.03013928747555662, 0.09816145809787898, 0.020806928871259577, 0.05977029476555125, 0.07286569449089228, 0.17099129967391494, 0.02359130224513431, 0.04563021924226515, 0.05225069362730269, 0.16800387852614926, 0.11668865103274585, 0.2024042753562812, 0.15768427582037065, 0.1661726372737077, 0.05705571200157847, 0.16654756070385057, 0.15338839181969244, 0.33283385478200456, 0.5519222840666771, 38.778634302077755, 82.57027733710505, 65.27136579636606, 31.59055167628873, 82.00806048608597, 52.82033512669226, 28.077308247166297, 1.3170733134592734, 0.5963051283071118, 0.1201516902074218, 1.0844151074847868, 0.4022619825217032, 4.838887366556353, 5.557700924334988, 6.040224038785504, 4.114566801055785, 2.82922595258682, 6.197691511723304, 7.442812621593476, 3.172477959625183, 9.908157106368773, 3.0688102062671416, 0.9179463465848278, 3.3472693158734232, 3.923947210273435, 1.1798082532421237, 4.770517022378983, 0.5701070663429076, 0.19455242571571182, 0.15974112996651282, 0.25324308043045385, 0.8326324051426304, 4.007479721500028, 11.802528539011556, 35.03915248378631, 49.4890308380127, 56.89188480377198, 68.40461392556468, 80.92362711506506, 75.7510014503233, 76.92728888603949, 74.9979534456807, 75.97729083030455, 75.0403150435417, 79.78838336083197, 74.20863920642485, 77.40886965105611, 76.9404366708571, 77.21071150995071, 65.8735006086288, 59.188001078944055, 55.13148584673482, 59.81341908054968, 62.853534452376834, 63.722868965518096, 50.308304140644694, 11.256872915452528, 60.60559272766114, 67.56101408312398, 67.34722137451172, 64.99097516459804, 61.0846592533973, 60.584906147372344, 62.65479580048592, 75.0699681620444, 76.9532314423592, 76.28467913596862, 79.78035034671908, 80.94659651479414, 81.87356241287725, 72.74308481524068, 76.20523545049852, 69.96251660008585, 56.549901193188084, 40.658088960955226, 21.385121076337754, 10.827985271330803, 6.077131580921912, 4.9980777405923416, 3.459399828026372, 4.379231179914167, 4.411375003476297, 7.516590933645926, 6.22120661120261, 3.8415384581012115, 0.5218978274253108, 0.9448243881906233, 2.1756178765527667, 1.7805661910003232, 1.2517578827757991, 2.433352653057345, 3.244851818007808, 1.5973441903629613, 0.5210986445027014, 0.6123020860456652, 1.2157218422620528, 1.9582143810487564, 7.801176540313229, 3.3936623748271697, 1.8819800523980972, 2.564241655411259, 0.26542197852846117, 0.8293346111332217, 0.4603676984627401, 1.5601082722986899, 4.111128843599751, 35.03378668139058, 31.287589765364128, 84.14630136182232, 42.59338640397595, 24.565955400466922, 54.96072546128304, 48.734986551346324, 4.9415284395217896, 0.09971759717671141, 0.07751947944803585, 0.04517800903188125, 0.03243693263239918, 0.13840044848620892, 0.10003906299149799, 0.11050806050339054, 0.021648658401963693, 0.08155301663904421, 0.014213897670889574, 0.08288114496897306, 0.08979865845533148, 0.092110397714761, 0.05577136942696187, 0.060069747043833624, 0.04388269607818896, 0.042896024627430786, 0.09077256305083152, 0.03693114147491513, 0.10087086593792324, 0.02967979368423262, 0.03392837941646576, 0.11114846404281356, 0.0374877771302577, 0.0260283715737563, 0.09832569202708621, 0.06277736223813507, 0.05950621659717253, 0.1173771878764514, 0.12959097361853048, 0.170834175040645, 0.11648500187983436, 0.15484382097999896, 0.09967100370915667, 0.09188960351410413, 0.08593060391684694, 0.07830164755784697, 0.0687776578049506, 0.12844669106867046, 0.0462687496967133, 0.023998680990189317, 0.17255736725224605, 0.06987630449716123, 0.03316229149218529, 0.17137763781412957, 0.03731822655085595, 0.16586234102085715, 0.010841783556726672, 0.1100715052997393, 0.04465505443212967, 0.04381634137262741, 0.012721059479630523, 0.03433203114376914, 0.13096593290327058, 0.2679193332310646, 0.21302374019738168, 0.0423990557300708, 0.11528245834333282, 0.06591508600620494, 0.2305512190345795, 0.35042470441229884, 0.5975173245514593, 45.8295928278277, 102.02824577208489, 68.41726749174057, 44.18480573161956, 95.9235002148536, 56.48000847908759, 48.636899840447214, 2.5044853264285676, 0.6695119387680485, 0.4898135748601729, 1.5192368073809532, 1.078644197794699, 2.6210498329131835, 6.247883631337074, 6.157881415659382, 7.850769517883179, 7.228558053893428, 7.885498183388864, 9.666790135445135, 7.571177088445233, 11.914791676305956, 10.588722652004613, 4.0165411320424855, 6.048550250068788, 5.7956166998032606, 4.165119288429137, 3.912900344979379, 0.13777971808468142, 0.17988299109762718, 0.3116303796489393, 2.033683847515814, 3.2918163172660337, 7.643485982571879, 17.14650784769366, 40.418463522388095, 51.42734458369594, 62.03453179328673, 73.47677200071274, 83.62333959148776, 82.40311376510128, 84.44491924778109, 81.63186596285912, 84.15718986142068, 83.15095286215507, 86.80311879804059, 81.45038573972641, 83.35921502882435, 79.84090389743929, 79.1212038840017, 69.1292090569773, 62.918535970872455, 59.51158092867944, 66.75503761537614, 68.48081773327243, 74.48942599758026, 58.50573616643106, 15.385169483000233, 73.04091038242464, 73.25442068038448, 73.18173131635113, 67.57233404344129, 64.38170556099185, 61.85589921089911, 65.09586326537594, 77.46400248619818, 81.28610903216948, 76.89897721813571, 78.75257169046711, 80.93137771852555, 80.0428432033908, 75.50692804398076, 79.08974647521973, 75.34550682190927, 66.84813899378624, 51.38534776626095, 34.529993534088135, 23.665173284469113, 15.070427713855622, 11.243322107099718, 11.15390383428143, 11.68040358251141, 9.461498183588828, 8.945065198406096, 7.019640361109088, 3.2418833192317718, 0.6987350061535836, 1.4678825630295662, 3.830936536673577, 3.3970836622099725, 2.1214178300672963, 4.249490451428199, 3.67358599939654, 2.372526497610154, 0.8671914281383638, 1.730825143956369, 3.490560362415929, 6.83720160876551, 4.6683039780586, 6.516496366070164, 2.5797923822556776, 4.418777986880272, 0.6988749857391081, 0.38523172539088035, 0.9529007935235578, 1.1242709236760293, 3.3814304634448025, 62.673921277446134, 30.354093120944118, 82.84201914264311, 56.32454533730784, 30.999640726274063, 60.59852069424045, 59.93786019663657, 4.101910047954129, 0.256768693666785, 0.1568292757315982, 0.08567653851763857, 0.07541105226283112, 0.09701002028680618, 0.07412124365087479, 0.13053905339010302, 0.10248449991547293, 0.1958129621080814, 0.05760442630778398, 0.08256366281139274, 0.10324310316073318, 0.06685831644121679, 0.0356267465488805, 0.12043875867440818, 0.07307206325593495, 0.10936206957745938, 0.026554032379100402, 0.051479373322499376, 0.03164891352606637, 0.0305855164544717, 0.08487398480816234, 0.05572684056636307, 0.06101837456827203, 0.020182605517367204, 0.04845129205815254, 0.014856841749391489, 0.04834972412115143, 0.22006848556620462, 0.15774199288458596, 0.3125038424566869, 0.17460919586160492, 0.1508558123943306, 0.18892866619411977, 0.28554303271155207, 0.1950848261795698, 0.21188954702548443, 0.21425222347099937, 0.1905070677880318, 0.1311298910408251, 0.10058850125079194, 0.1823695746040152, 0.2646937047041232, 0.18121923229867415, 0.33626761407621447, 0.2798509075035972, 0.2901987941755403, 0.19409257377828323, 0.41300740753931386, 0.17156335284873364, 0.19396210900477825, 0.18431211311009624, 0.36965246943216173, 0.3730227353592073, 0.4641031738250487, 0.32689602985497446, 0.30186254410974445, 0.47389178566875, 0.49893014373317846, 0.32801133129865895, 0.48758692498649325, 0.5171570914887613, 67.93053273231753, 115.06876945495607, 93.88287928796585, 55.11126210612636, 107.39781364317864, 78.64993110779794, 52.56416120836812, 2.796641842972848, 1.2548960240617877, 1.3165099630432746, 2.883975866340822, 3.242459417350831, 12.100446281894563, 19.462216361876457, 19.854531826511508, 13.177450683809097, 9.635330765478074, 21.020691702442786, 18.75598184524044, 11.385361917557256, 20.223271885225852, 14.098048613917443, 1.9763699294097963, 6.858561365835129, 7.565091040826614, 3.857347571080731, 10.749538848477027, 2.736887720323378, 0.6087764268440585, 0.7500233056564486, 2.4860465093966457, 5.693260488971587, 12.602520450468987, 22.479370178714877, 49.62264245556247, 58.35528973610171, 69.85239997986825, 77.4670462454519, 81.94064278756419, 80.34239461345058, 81.90282329436272, 80.85981015236148, 83.66338699094712, 82.97564644967356, 85.95678898595995, 79.09774026563092, 85.24778135361211, 79.66751160160189, 80.7804213800738, 69.36505333069833, 64.03446205200689, 62.99239027884699, 70.25398792759066, 70.83031746648973, 77.56430533624466, 61.803100186009566, 17.256287144076442, 79.52688678618401, 77.33993791764783, 76.35762737643334, 72.39767305312618, 67.92957567399549, 65.89039817933114, 69.70110631758168, 80.68912429194297, 84.27973255034416, 82.12786536062919, 81.89674362059563, 84.73754375211655, 83.15205897054365, 76.7491348328129, 81.80965131328952, 80.63013968929168, 72.67451393988826, 63.32117511380104, 51.57876376182803, 45.72008025261664, 36.287399722683816, 27.64016401383185, 19.33385091443216, 18.475928537307247, 17.604513206789573, 14.685951106009947, 10.190322610639758, 4.693869006249213, 1.8185059293623895, 3.0501034423228237, 5.508476159264965, 5.540248338253268, 4.9215464149751975, 7.609120136307133, 6.842205572512842, 3.0600233616367465, 1.6408758802760033, 2.756255893938003, 4.868835153118257, 10.504499558479557, 19.634998729152066, 10.578118524243756, 13.455216269339285, 6.612314966417129, 5.272788780350839, 1.4769448315904987, 1.5354342350075323, 2.561559979954074, 5.074532089694854, 59.79272465552054, 41.40124867039342, 103.48277830308484, 65.87652867840183, 45.652646864614184, 68.60505488611037, 83.18389292686217, 14.965114035914022, 0.5338179103789792, 0.21276835712694356, 0.18232472781692782, 0.20751058845029724, 0.1508413180108032, 0.3636105791214974, 0.3040936985804189, 0.2350919140923408, 0.3104300118021427, 0.2227281436564461, 0.16586407237956602, 0.20819542508932853, 0.22580060056380688, 0.13463826729885994, 0.1561212266284612, 0.19622592946454404, 0.18728009094634365, 0.15069330982383222, 0.1176885796350337, 0.33131010590061066, 0.10613286341991156, 0.18985500439040123, 0.21465247376791893, 0.15091279401413857, 0.2148159722527189, 0.13064935472944092, 0.0958438199614325, 0.13457702623019296], [0.0744138662553122, 0.09919321765342068, 0.1470062052530627, 0.09881330699089075, 0.024945037063932227, 0.14578504578000115, 0.018122060742649822, 0.02916366492788638, 0.04518089335291617, 0.046779791629242326, 0.06802677672596709, 0.01133461653690545, 0.08256320315863817, 0.07168277046613156, 0.1411164600041605, 0.027875361678701256, 0.06751414133055557, 0.03765927740342675, 0.054250692558144374, 0.0034567704208330404, 0.10848202607444218, 0.0019323506139992408, 0.04560400371349627, 0.02493236980010425, 0.16128550193482832, 0.11110387006474119, 0.23670253734434807, 0.15014178780538423, 0.23761491741864915, 0.18529111219029273, 0.08938785146681533, 0.011199962220064575, 0.13380574422978586, 0.09281637838050243, 2.8827731695867356, 78.8938162403722, 80.19055181933989, 51.74176177670879, 36.680260396772816, 73.75358935325377, 40.902727188602576, 23.555148839950565, 2.0777005630154766, 1.0423030704259872, 0.4483624571754087, 1.052706789585852, 0.37392886415604626, 2.160164228370113, 3.2097274834109895, 4.555799614998603, 6.05196810537769, 6.477113808355024, 13.327434274458117, 9.087610994615863, 8.670041349626358, 8.384184895023223, 6.650841466842159, 5.546004906777413, 6.694788682845331, 5.529576059310667, 0.3627543073267706, 1.7434403444490127, 0.19248355931091696, 0.021820298486178922, 0.2100367633806121, 0.7180168876244176, 3.4950031820804845, 6.362695328650936, 13.12363184267475, 25.044408075271118, 40.09916690088088, 56.11771483575144, 68.2453578518283, 75.59643653131302, 81.51847024117747, 83.48771972040977, 84.4608440706807, 80.6300377076672, 76.30058042464718, 77.65230763343074, 70.97600998417025, 75.28382362857943, 70.35007815207206, 71.99323746465868, 64.86163893053609, 63.35178529062579, 62.267187180057654, 67.6156291654033, 58.13511533121909, 68.77653306530368, 3.5704720356772026, 37.519000422570016, 79.48035178645965, 70.4129223669729, 72.73993907436248, 61.73481564367972, 64.84126613986108, 70.02445082510673, 80.0354769922072, 79.67198310359832, 85.57966093863212, 83.52219735422443, 85.31799962443691, 77.22231388092041, 74.02063215932539, 70.8857484017649, 75.62373622771233, 61.64648386739916, 33.81682426698747, 13.167727128151926, 6.795981420624641, 6.140543558905202, 6.137431158173469, 7.760007833280872, 7.021468675905659, 2.590247459949986, 0.23334541748608315, 0.4916655464518455, 0.2234031590482881, 0.31092708029093286, 0.08401139278806026, 0.2703892619859788, 0.46477040576358, 0.27115501283157256, 0.7823302140158992, 1.5621580784359288, 0.3568240207049155, 0.7911681107455685, 1.31010951294053, 0.9631748906066342, 4.663423568971695, 2.2887248137304863, 5.1638086668906675, 1.3154101059321435, 2.1992972252830385, 1.927011313457643, 0.3059229326824988, 1.0146873167926267, 6.1922462813315855, 37.40086255535003, 29.91252249287021, 76.16019095143965, 58.04360251272879, 20.741660171939483, 46.7877729477421, 55.76181465579618, 26.77253377053046, 0.149336552788173, 0.07934171916736711, 0.0698728800841397, 0.10833479929715396, 0.07708424957649362, 0.02292470041392071, 0.014566169796331276, 0.06276100626095168, 0.03167599090375006, 0.07813294733604116, 0.06484816301493876, 0.08637969997981865, 0.02795690407736167, 0.06984074269571612, 0.04420021270972587, 0.10285499535741345, 0.07502031677793111, 0.01522125158038351, 0.044057574799104084, 0.031743375997569774, 0.011089488510943709, 0.056920964796576774, 0.12426585815246068, 0.02706475063948141, 0.012591968876339737, 0.04970270434334394, 0.02769772504125872, 0.04437050639441417, 0.021016072789807955, 0.01292474597932831, 0.013938285091200904, 0.09640179244020293, 0.0973384575017037, 0.03724164840194487, 0.10375812108958922, 0.04335266282601703, 0.10840995252252587, 0.04697177709350663, 0.04353955380558487, 0.08237216381296035, 0.052059937734156854, 0.02504142816178501, 0.1358549681402022, 0.09531335003914372, 0.026627567243732275, 0.0370827617664491, 0.05230645333687144, 0.10158953301969076, 0.02180362649772677, 0.08729658465111449, 0.07339600353471695, 0.042506135669687105, 0.032983222270324346, 0.16031525157872709, 0.07918788105129235, 0.1914350760559882, 0.23410499366300724, 0.3065301646148005, 0.05332525451517394, 0.05134295604582276, 0.02270485041663051, 0.1347267044888389, 0.0873542710718128, 3.4606194400018264, 96.8561770839076, 94.16733741760255, 51.839526853253766, 52.28247619444325, 88.42665057028495, 48.35060996394004, 47.560632844125074, 3.1205673515796666, 1.3611330524567635, 0.6624434599953314, 1.4849179069842062, 0.35239520512761613, 1.5130188700652893, 0.35319582829552315, 2.2655627275666883, 6.969442848236331, 11.21690494398917, 7.343912509179885, 9.38375876795861, 8.821122223331082, 10.448555773304356, 12.801082595702141, 9.040429784405617, 13.114706489347643, 6.901013668506377, 4.112744614962609, 0.813940717808662, 0.5603448998543524, 0.030643442277646357, 0.9516781171964062, 1.8041257848662717, 6.012127610944933, 8.891817062131821, 13.87924115503988, 26.713460914550293, 44.05960367571923, 62.94446283771146, 77.6504562747094, 82.63614177703857, 88.8117253395819, 91.57413298083891, 90.9594112826932, 87.15585754763696, 82.88136051547143, 83.67877837150328, 76.30248669655093, 82.75680172827937, 76.12381489046159, 77.07981417256018, 68.36133449308335, 65.87195519478091, 67.24822075136247, 75.94780245134908, 63.88176810356879, 76.9814960418209, 3.7771446618341633, 43.75552585048061, 85.05549892302483, 74.89401063611432, 77.84965776628064, 65.46853157781786, 67.80879020690918, 72.70021330925726, 83.7004533890755, 82.0498651073825, 86.81478392693305, 83.34034842829551, 85.28041547344577, 80.58366744749009, 76.2090793732674, 71.13838826456379, 78.3910389869444, 70.20008671668269, 50.1258433249689, 32.74887661780081, 19.65617952808257, 18.669452398054062, 19.390742932596517, 18.81232277039559, 7.575384811047585, 3.0010257661342625, 1.3272605668152533, 0.5821587325584504, 0.23390502939301155, 0.2156797363873451, 0.029884549834194685, 0.15968384191153512, 0.6438562670542348, 0.5820763627848318, 1.5559134199734659, 1.9706189992927738, 0.4290033846853241, 1.374796016081687, 2.6681366610911588, 4.708862266232891, 4.6587162344686455, 4.085745470177743, 2.6672171104338864, 3.467500993321019, 1.0263035999190424, 0.7685340736662188, 0.6538225193658184, 1.057317903445613, 6.5722808049571135, 69.51564096635389, 31.89220351557578, 74.7828898891326, 72.35483292610415, 30.96567103939672, 48.31204129803566, 72.71150973535353, 29.192238046276955, 0.2984194078993413, 0.13947108700390787, 0.03660947647726825, 0.19394064322113994, 0.07687567447822902, 0.06700047171644627, 0.046684555408935395, 0.04886668791333514, 0.02226066880769307, 0.06882464197734672, 0.08592985315068115, 0.11863276001907165, 0.05678685727499186, 0.10413725800331562, 0.03682398875694602, 0.07280177211449032, 0.09579988481897501, 0.01614700754984252, 0.044044053347240535, 0.029003690447538134, 0.03544965766430382, 0.0594017988130931, 0.13006919634438333, 0.024059211512306528, 0.04754043649882079, 0.05183650053016121, 0.041307548977314465, 0.10584001098909687, 0.0680754233091589, 0.16398303541204623, 0.10919257262421232, 0.14651512757184046, 0.1536376615084948, 0.11950747155013586, 0.2419883601607815, 0.1385912656663887, 0.14526140936199697, 0.12903168346853028, 0.12559772499146002, 0.18802780808219988, 0.1163825989069958, 0.14043597474453912, 0.20007644058956256, 0.28249063198604896, 0.1256302454238457, 0.10673276389077788, 0.13583125005806648, 0.1891539266873752, 0.17628034005963034, 0.22923147936742153, 0.1725333580566991, 0.19403614374178071, 0.311425160015783, 0.5308789519533035, 0.23523849735577262, 0.35368198769227155, 0.2684401810890244, 0.5065171721000825, 0.21745693779760794, 0.16196168178031523, 0.14920979588022157, 0.15872791739961795, 0.3390345704411307, 7.380651389398883, 121.96075823999222, 105.00506585644138, 87.0108239881454, 60.46004533767701, 103.58034333875104, 61.16776251023816, 45.634933440916, 4.292629168879602, 1.7070982364877578, 0.9448555832909, 3.0083628046897153, 1.2219549787621344, 6.305560123535895, 10.432358345677777, 20.238818199403827, 19.923153692676177, 23.53349735659938, 25.267357557050644, 25.171651724846136, 26.021935286060458, 14.65993892761969, 20.34819741402903, 14.16001323730715, 16.125325637478984, 13.52180144479198, 8.914217718185919, 5.74737988172039, 0.6919837490685525, 0.37354300099034465, 1.2516606815399662, 3.5000701488987094, 6.755095124244691, 11.09154599328195, 14.529196523850965, 29.98139342954082, 47.16622283381801, 64.67822890127859, 77.30566424708213, 80.934688198951, 87.5656432490195, 86.83585489949873, 88.96676878775321, 87.16839344270768, 80.44418796416252, 80.08438894825598, 75.20130480489424, 81.9311349622665, 77.23435555734943, 79.00051255379954, 70.98799674741684, 69.23022577839514, 71.26211550927931, 80.55109608557918, 67.53152570416852, 79.4585826320033, 4.702484002036433, 46.28258735902848, 91.3390810258927, 80.49231544617685, 80.68753180965301, 68.20973488592333, 70.0177671063331, 76.81929034571495, 86.70241586623654, 84.55794626666655, 91.86405104975547, 88.45055349411504, 90.18136993531259, 83.07435681743007, 79.46110863839426, 74.74527435918009, 80.56587557638846, 75.80289440770304, 61.5771245956421, 49.30195339264409, 41.23435966430172, 35.37979464377127, 34.60972747495098, 29.52729278995145, 16.552996366254746, 5.905806864461591, 2.624163704533731, 1.0826614402955579, 0.49516178787715975, 0.5149954365145776, 0.1380528743949629, 0.31241987922018577, 1.039015633925315, 1.7205639784374547, 1.664051817309472, 4.069587266252888, 0.9450870031310666, 2.0561367201228298, 2.578125620080579, 4.257470023247504, 15.038243685999225, 9.61074632983054, 13.195828949251483, 6.5376198003369, 6.627746060971291, 5.44462634671119, 1.0002423919016317, 1.9077152133949342, 8.902098574946004, 58.592236195841146, 43.33438880981938, 94.83237528031873, 84.46725322354226, 45.19745188374674, 62.09694062509845, 85.76910357321464, 51.05896342185236, 0.2639640519215215, 0.21839259162304864, 0.18908908500546412, 0.2678318153465948, 0.22263837347347892, 0.17613728080065022, 0.15503577197030668, 0.27720113194757895, 0.15653983239204655, 0.18716468746143003, 0.23425784352565968, 0.18736886521500928, 0.24593873850760922, 0.2830192939408364, 0.14120097482396712, 0.18813205732693597, 0.24602763535034275, 0.0743415245726224, 0.1690211820025598, 0.16775718289277247, 0.17912388989521613, 0.18271183204506675, 0.2445017414227609, 0.12242704029044799, 0.10565202833423692, 0.1423164754505119, 0.11974456044094217, 0.22442979347561637, 0.1660069937427198], [0.019292263877427867, 0.10778213580769878, 0.08441701336132904, 0.14559402941696106, 0.06536124274134636, 0.05950681414575346, 0.017919422825798392, 0.01756127289075765, 0.017698967619048014, 0.014938238591346291, 0.13002723004789124, 0.10776725838020926, 0.013353869172504113, 0.09256444270572356, 0.020100975018595497, 0.09779087072538753, 0.042198677772596, 0.0490114325657487, 0.03096310587059106, 0.020814574428743893, 0.02039111358293843, 0.04142867513902245, 0.09507884286464223, 0.054603564147386825, 0.06282007163991371, 0.06652336747896287, 0.15873099707307356, 0.08778909491675516, 0.0628988178176505, 0.1168205637124277, 0.06240494008506499, 0.09448843422315775, 0.020994405908089493, 0.2342157699768582, 0.2000734222031409, 26.634625196456913, 81.3969316790181, 62.63149299929219, 45.16468440332721, 43.73247015860773, 72.56769995535575, 41.47100802390806, 27.49508534708331, 9.362599542064052, 1.6168910769685623, 0.06290919447858488, 0.8247027209689541, 0.9534032246278179, 0.4939556590491726, 2.3906135270672464, 4.898911397303305, 2.0906152119559627, 3.889344060613263, 5.676922836611348, 6.262500834080481, 13.196399654111556, 10.826850725758462, 7.041478157043458, 10.511273491767145, 3.0140828461416307, 2.247894165977355, 0.35732801462854114, 0.29538744639965797, 0.0516431016336766, 0.0535382078059258, 0.2091987398002417, 0.06889434065669775, 1.0537856865313746, 2.2721425035307488, 3.9928103022037016, 8.590456458830065, 10.141651880356575, 13.8328512830119, 21.773853455820394, 38.966378550375666, 56.821203693266845, 68.40178981904062, 74.73434663588002, 74.55482759783345, 76.55629542566116, 74.19290265729352, 70.18783323226437, 70.33054474861392, 71.72886187030424, 65.63880558936827, 67.89836929690453, 61.09037414673836, 76.1602693988431, 60.45674662436209, 75.59936261946156, 6.058974929394261, 33.87002729600476, 90.71669501643028, 72.87189545169954, 72.28710928270894, 66.08647746424522, 72.19038363425963, 81.67719287257042, 83.54686121786796, 90.646602261451, 87.29692951325448, 89.61935704754245, 77.05071803062194, 61.38195922297817, 35.56962559300084, 32.4453910704582, 45.21390230424943, 44.059721346824404, 28.903843818172334, 10.224481551877915, 6.286777363669488, 6.633892415031311, 4.880744449553951, 4.456812720144949, 0.5372172570036304, 1.9283037344294212, 1.0157417602116063, 0.23740119420953337, 0.13566802736491929, 0.08576754976304309, 0.07055508904159069, 0.07549142254696739, 0.16369049707728048, 0.1168019860802639, 0.09538841899484397, 0.1754907025925575, 0.193711644218814, 0.13979169480021925, 2.068594535512309, 4.299071171591359, 5.111704391817893, 1.4063270918784605, 3.2149763501459554, 0.8620562488513609, 2.336807188487822, 0.22802945677070852, 0.9348095965481574, 7.230890393257142, 39.69142083198794, 24.753829086980513, 72.88006967113864, 60.73192442617109, 27.193553140086514, 37.750267290299945, 52.812764952259684, 38.65855486162248, 1.1631521534535194, 0.07024060228779432, 0.031519458073401646, 0.028822121863824227, 0.014029360496469084, 0.09033328057416985, 0.03275319671017989, 0.11735327061145537, 0.09781472670334963, 0.007262603058705047, 0.02170917360232242, 0.09332997904669854, 0.01478126526044141, 0.017742820407053637, 0.047458331025536024, 0.041075562232083855, 0.07269651929457342, 0.08884179165526744, 0.13620808870802004, 0.01395360972251623, 0.06692076792880412, 0.0650594117600591, 0.009025506874276026, 0.025845657688595598, 0.07635116471999115, 0.023236565231796236, 0.004478419770396525, 0.079988649775905, 0.0667646085663188, 0.1000192519577761, 0.03150662227023033, 0.03346848151376171, 0.07026039799975772, 0.052239799857019424, 0.042705015925269936, 0.058282107685602484, 0.02981977518497696, 0.03995803913341896, 0.07912312363905293, 0.03852139444901578, 0.14134752744388196, 0.06308580072776926, 0.05855974944068059, 0.04429502758167444, 0.029047619844336185, 0.19439807432072778, 0.07329717819248477, 0.06722052281181659, 0.12632671893844682, 0.01980115693332928, 0.03524364513014594, 0.05428710854762504, 0.008831663646795338, 0.0863458848588409, 0.07820111383954365, 0.0534393058549012, 0.09698673887478729, 0.12028950176412061, 0.07670420867901656, 0.1830025470905727, 0.08797660259710205, 0.13317992700444115, 0.03925528752827837, 0.2973212974686777, 0.08209700801319654, 37.37742247120027, 102.7218149554345, 73.75369133487825, 45.22513597242294, 61.656587892963046, 76.35503076737928, 39.143022491085915, 57.68520378297376, 9.221364798084382, 2.463890511182047, 0.5995166301727295, 0.5589468200360576, 0.6944673448320359, 0.9321792796254159, 2.3955387982629963, 3.5677506462220228, 4.335658550262451, 7.114220963370416, 4.962110096408475, 10.108680436688086, 11.89864622008416, 11.229489868687047, 8.839977056749406, 10.880017472851662, 7.475146680108963, 3.2681242208327017, 0.5897872522473335, 0.2325359689852884, 0.06068414955910656, 0.2297228941273305, 0.12611250543305952, 0.42778251632567377, 1.1842493568697285, 0.8308140801325922, 6.000146731253594, 12.003018529184404, 13.11461921661131, 18.763648117742232, 28.383449239115564, 46.97732148631927, 66.03216832683933, 77.21566154110816, 86.97509904061594, 81.88703183204898, 87.11163674631428, 78.0189629523985, 77.62001083743188, 76.61030646293395, 77.25751323084678, 69.61808543051444, 74.08701435212167, 67.53942535769555, 84.24891056553011, 69.2729325448313, 83.29633943496212, 6.120257550670255, 36.80926715174029, 98.13525415235951, 75.39385395665323, 78.18829167273738, 68.35527835353729, 75.9557334838375, 82.34208168522005, 85.02808940026068, 90.1601577574207, 87.26515831485872, 86.55209495175271, 78.65982332537251, 63.89474330409881, 41.281435951109856, 39.7670284394295, 49.64577267246862, 48.166356625095496, 36.08119680035499, 18.73142976914683, 12.58260363532651, 10.312730958384853, 5.261299667819854, 1.8136265008680283, 0.8191927101823592, 2.2925322094271263, 1.2997537202412084, 0.2430756687517128, 0.041733551319808736, 0.03704430415265022, 0.0941679566617935, 0.0616169803505463, 0.21842668253567912, 0.10674003406517929, 0.15355480143860464, 0.10879790710826075, 0.21139912817987705, 0.7033089800707756, 4.435747631134526, 4.231505403595587, 5.594533941438121, 2.609465357757384, 2.2043600245829555, 0.6947053836718683, 0.845555205258631, 0.29325686395168304, 0.6757228280748091, 7.319091260433198, 75.42422879126765, 26.76597752878743, 64.82334090817359, 75.4028832527899, 34.34726207487045, 40.680289576130534, 64.95667403744113, 39.17531536471459, 0.18367042254296043, 0.021401070276155107, 0.021765622791023027, 0.05442858200460192, 0.020317900475234758, 0.053988885840461145, 0.019158960748163444, 0.08044582806647786, 0.06542730250305707, 0.0059178415235252154, 0.06410298929099115, 0.12385218599510771, 0.04808810892544928, 0.08988636020090311, 0.04849955942782183, 0.11637074752680718, 0.03806708898815898, 0.11900803584965969, 0.03526719467293832, 0.0693688938213933, 0.07167896300914788, 0.06232210299781254, 0.04927232763880203, 0.025692721641051675, 0.030666568556860573, 0.02071060863653979, 0.03466653577502697, 0.017906948999171297, 0.07755513318003186, 0.020691391320959217, 0.1450190651080301, 0.13990014220678038, 0.15998761109527082, 0.16508134502557018, 0.11543849513175027, 0.11280963377606486, 0.10025835565982327, 0.13366712828076657, 0.12543998748785065, 0.16791859761841837, 0.2655117027461529, 0.2065690051043226, 0.169054506827266, 0.1994155212155273, 0.13653281805736406, 0.18916034650418068, 0.2351676189010182, 0.18812972841964615, 0.21031802490113244, 0.09111945532382497, 0.17333041125487897, 0.19330272180659158, 0.1630817942561642, 0.25379565965023737, 0.10329454596484862, 0.22721245464298034, 0.32709309831261635, 0.21559313780838446, 0.16987068158003593, 0.22286649913557116, 0.1610919574816381, 0.20056730376616602, 0.18555522866306767, 0.3466488102511052, 0.301466966949163, 56.89657595849807, 122.48948589448007, 90.05757208793395, 78.28247562531503, 66.56571265189879, 101.93357544560587, 58.5615122702814, 54.18177804639263, 15.431205361120163, 2.3095437740125964, 0.6958518802158294, 2.2272021924295733, 4.704044615068744, 3.5954653784152004, 7.820905081687435, 16.47176996354134, 12.925376622907578, 19.59271950106467, 22.280241250991825, 23.331454107838294, 40.339823922803326, 22.46303350694718, 18.58156188841789, 19.496221350085353, 16.841594557608328, 15.185824824917702, 0.7227190740166173, 0.5732092934270059, 0.1227597369542045, 0.3400043458227189, 0.49025959124968904, 0.5761814694250784, 2.024329239802976, 2.5278503952487825, 7.245446308966606, 11.493857618301146, 12.614682739780797, 17.001064400519095, 26.014631832799605, 41.998500131791644, 60.8703487919223, 73.46150613600209, 81.1355370859946, 82.90742858763664, 82.56317784709316, 76.02510452270508, 75.64180266472601, 76.09638967821675, 76.6704442424159, 72.89313116381246, 74.91479919802758, 69.8397699479134, 86.71339850271903, 74.52541766628143, 85.64093620546403, 7.257626248944191, 37.305509736461026, 100.36525495590703, 78.38681067189863, 80.06440054985785, 71.32683461712253, 78.67824277570172, 86.4917375195411, 90.62528025719428, 94.7116368816745, 92.96309132729807, 91.00522456630584, 85.41645896050238, 65.1954443993107, 41.898664043795684, 42.31197987833331, 53.62329136940741, 56.20083770444317, 49.73482224249071, 31.399587162079353, 24.879984278832715, 20.68272852128552, 11.89318431961921, 8.369231839333812, 1.6939955589271363, 2.7081306182569076, 2.1526097434182323, 0.5796231653901839, 0.31646736687229526, 0.2973407254584374, 0.22307083010673526, 0.1904013476544811, 0.24554541364552515, 0.15111721691585359, 0.17781533511175265, 0.28719928416032947, 0.3649841134826983, 0.90080424061706, 6.241584304840335, 12.04544190437563, 13.952275687648406, 9.642752870436638, 8.732615901577859, 2.422280292357168, 6.188784789654517, 0.2825597024733021, 1.2570397219350262, 11.248750667418204, 61.742774132759344, 35.44351354722054, 88.90202614568895, 85.13535053499284, 47.546367183808364, 59.431584189015055, 82.75007878580402, 61.781048620900805, 1.8773988466109, 0.2887225427454518, 0.14162364085355114, 0.2655408753743095, 0.09918222429170724, 0.26285910798657325, 0.14520713969344093, 0.24861368771281936, 0.20198902505780422, 0.1366195392103926, 0.15076990329450177, 0.24396623064193035, 0.1258232995807644, 0.23550115826149143, 0.2104544498386883, 0.17288899139290856, 0.19755394288128425, 0.2700326020919508, 0.1518479115780323, 0.13007210747849557, 0.2367735996602043, 0.19909725764826422, 0.12647989055802747, 0.12704222207708707, 0.13980019837617874, 0.12651616482124214, 0.13513847674813964, 0.182475233450532, 0.12571399415572806, 0.11787721346462927], [0.06520994803718021, 0.045123693398049766, 0.07729959689200887, 0.07780729868118802, 0.07384150664532378, 0.0721990447791834, 0.07719842732072839, 0.124582267786947, 0.06064450067858543, 0.03159591939390427, 0.03956092596654931, 0.10074683630298223, 0.09660043137808962, 0.013386918205557572, 0.11011750887959235, 0.04386751987640897, 0.032974006232595256, 0.11462511659990396, 0.05160880387730656, 0.03954817443304966, 0.06243724601283189, 0.09815622571735613, 0.03639718202213126, 0.07433081466344095, 0.05398954850651565, 0.07437634326878094, 0.04396822979493488, 0.03272745615592407, 0.06925103119424275, 0.012037620951061048, 0.07288339112194316, 0.10793807300468607, 0.020020259994893305, 0.019943057484323942, 0.07935048321322088, 0.6606123259951991, 58.97769927978516, 67.54777216142224, 62.09430086997248, 36.73200822645618, 51.812658617573405, 93.61999419427688, 46.79579419474448, 36.95728563493298, 23.885922316581976, 0.22608042183902957, 0.10454966611559353, 0.5584472081353588, 0.537711782080512, 0.5389702500354859, 1.0527315495475646, 6.742394979923003, 3.8082980869277834, 1.011992158187974, 3.0769606463370787, 5.696998017449533, 9.729913819220759, 8.515661762606713, 12.589611930231895, 2.1944442727873406, 2.4565919608839097, 0.6407835190334629, 0.06313485333756094, 0.06449901844344794, 0.04696636468232159, 0.029451702496096976, 0.04558704635729233, 0.1602979839569138, 0.31013972576587434, 1.127603835155887, 0.293803084641695, 0.3151552727626216, 0.20357550121843818, 0.009896894541358756, 0.7144926380245917, 3.4243517344997776, 7.544421620907323, 24.268824092803467, 29.639437275548136, 37.46113761778801, 52.6066130207431, 70.07508862403132, 72.06223195598972, 76.70346275452646, 71.79836626975768, 81.37216583375009, 75.83462638239708, 78.40604597522368, 63.27464795881703, 86.42570834006034, 2.820555553320916, 36.743422323657626, 99.23776180513444, 76.83199882507324, 76.93205064342868, 72.17732998632616, 78.62799721379434, 84.30075645446777, 86.16280755689068, 87.27283831565612, 83.54966179017099, 75.11359276310091, 68.12359179219892, 49.58124183839368, 28.035197680996312, 18.204484831902292, 15.422102520542762, 9.270827847142375, 3.0296051358023, 0.8154532205193274, 0.29902250295685184, 0.07865875944375031, 0.21331399559013306, 0.3561764312607627, 0.6834405816851125, 0.694329816727869, 0.059874704888751434, 0.01532468877191986, 0.08660096915498858, 0.048671507862426584, 0.04099358699374622, 0.015080331621931927, 0.09121169997078758, 0.0733586950528045, 0.015057686062890195, 0.20533558822447256, 0.0842504888292282, 2.030732386535214, 3.256701053150239, 6.666504471532761, 1.636086175999334, 0.6453703632277827, 1.1814959755828305, 1.2052390628284024, 0.6714885068997261, 0.707635538231942, 10.592275338788188, 39.261972288931574, 22.13461345241916, 72.07013945425712, 61.04972270227248, 33.251049826222086, 30.37905900709091, 50.79721581551337, 35.64748464092132, 1.9989436600477466, 0.37655011059776433, 0.03144431059368916, 0.10532684699301759, 0.04016769058521717, 0.006816962052271852, 0.027483381300924287, 0.04930117467959081, 0.04050091584964145, 0.00714407345625542, 0.02504397540413324, 0.026067055183492845, 0.07610263813647532, 0.053897303859553033, 0.038674968264756665, 0.04407274717044446, 0.03468877913790845, 0.024987035919161096, 0.04194107687761707, 0.019901244405416713, 0.04857195473666634, 0.05218433892174114, 0.15918297362664055, 0.04303008618374025, 0.11500598487233925, 0.08239471744145117, 0.12850843009448823, 0.16498544613920874, 0.05390870324786633, 0.03416488608044963, 0.03386607731602365, 0.02792787126025125, 0.024348091777233828, 0.09511196084560887, 0.09266507601545704, 0.07667895076015303, 0.04121648793619487, 0.034730760756159024, 0.10201521743569644, 0.02236291281728735, 0.038986605171474724, 0.03663480334404496, 0.10998747311532499, 0.07770779918158248, 0.03657363122329116, 0.08274042227816197, 0.07797204588930454, 0.06377119661098526, 0.12333667776998013, 0.034493989791841276, 0.09477997664362194, 0.03195971731216677, 0.032140628975485606, 0.06720851821404311, 0.042290290397021084, 0.005443810256228092, 0.03289080525357877, 0.06559927392029954, 0.04552593169313285, 0.023630845788565856, 0.0403860601175937, 0.05738042602916399, 0.07356207607494247, 0.05925421580492009, 0.06264169955806387, 0.08542136995181923, 1.561879957875898, 80.48789101262247, 85.301862993548, 75.12729752448298, 41.712339693500155, 77.39741633015295, 90.63572945133333, 38.49932232210713, 72.94318060721122, 25.239471466310565, 0.6027621463421853, 0.3510828658698067, 0.2792779963103033, 0.2969409501360309, 0.4623070040777807, 1.3492486385568496, 3.0496854647513363, 6.469384287634204, 7.303390012633416, 4.5919471979141235, 5.245615580389577, 9.801693193374142, 6.8968868447888285, 10.68446868850339, 7.952281438535261, 4.335698754556717, 0.7372289018765573, 0.08543037914580877, 0.09441537241781912, 0.07313361075977165, 0.08380265681133156, 0.04100741488077948, 0.34907893307747384, 0.398960541933775, 0.6888350664127258, 0.14897629228090087, 0.31520647807948055, 0.02903763005780357, 0.11925028817307566, 0.8825480589462865, 3.9630919742968778, 9.914211284729744, 28.463589145291238, 35.25818547894878, 45.149069447671216, 61.55161350004135, 78.26631546020508, 80.8106000961796, 86.14247398991739, 76.69556310099941, 85.66037547203803, 80.71807922855501, 87.13182126322101, 70.34420244155392, 90.84923974929318, 3.0088256443700487, 38.62747792274722, 105.8137095359064, 80.66628040805941, 83.44602492547806, 73.49559153279951, 82.69732290698637, 86.06597208207654, 87.63114683089718, 88.90350095687374, 84.88335394090223, 83.21369509543143, 71.20626095802554, 52.80038202962568, 28.732298958686094, 17.94813048455023, 17.56839994461306, 8.767319071677424, 1.999051892949689, 0.5190896555300683, 0.3040280601670665, 0.3506094235326013, 0.4018458129177171, 0.6834060157979689, 1.5157807089628712, 0.10886765175288725, 0.06698098243965257, 0.04181490985736732, 0.07169810754637565, 0.07413931566500857, 0.08600764171851259, 0.0681283982891229, 0.085233693732129, 0.08178251359852091, 0.020894381638255813, 0.2769533178258327, 0.5190507995505487, 3.886593988826198, 6.39100601596217, 3.946631257572482, 3.0152178820102447, 0.6356699740694416, 0.5634661259189729, 0.6167135880358758, 0.23282683724837921, 0.47853050933730223, 9.45993511907516, 78.29297188789614, 23.440580329587384, 53.09900383795462, 73.3917663943383, 39.769962372318396, 36.19653801764212, 57.57443997167773, 46.38722442811536, 0.8673880982302851, 0.08509587451455095, 0.06582402113464571, 0.11987217536736881, 0.0904056988656521, 0.06615061207764572, 0.13852024931580792, 0.060099517220571164, 0.047271305980581435, 0.08206953610023184, 0.10432857314064618, 0.020369163248687983, 0.1484069663790926, 0.04963603171129381, 0.045046341500335166, 0.0609963380491301, 0.03220602224070219, 0.047035201512757814, 0.10954703384589766, 0.06964419517786273, 0.030414102366194132, 0.01723071169709006, 0.16766912874675569, 0.056247669272124774, 0.08722520823920928, 0.027523572188651854, 0.061256501508215745, 0.16815672838880172, 0.11890029324398887, 0.0548419515572248, 0.013719580395357504, 0.12652117503626695, 0.17873899200029914, 0.2533329885092474, 0.1067021816608406, 0.16379534387059752, 0.2122381936398245, 0.20656796322474558, 0.2347940131421051, 0.12858166810004942, 0.20055872358141408, 0.11614817600216597, 0.24402125107665218, 0.12273964246795063, 0.10581813151797942, 0.2416000914789977, 0.216377780382191, 0.16533125822822894, 0.2140425298843653, 0.1651395370642985, 0.14251342133408593, 0.222942280553041, 0.13726757298554146, 0.1545523858118442, 0.19059308414017, 0.1902083088193209, 0.1720497420718593, 0.1390595292492259, 0.2122325552327018, 0.1434891722014835, 0.16322545106372527, 0.13479502420992623, 0.24063696574059226, 0.09120964685515051, 0.1267427506466066, 0.11837985141262894, 2.776387703995551, 102.83888986033779, 108.84821984075732, 102.0738943161503, 62.79461653001847, 77.00296709614416, 120.18463842330442, 63.797711710776056, 67.91802821620819, 39.700006900295136, 0.266174889740444, 0.6097354463511898, 0.811799593990849, 1.406821555668308, 1.5133657546774035, 7.301973546704939, 17.21281551545666, 12.414286886492084, 15.579434671709615, 15.82477500361781, 18.356574735333844, 30.5041669261071, 27.397712507555564, 33.569483526291386, 20.574369122905118, 15.003122783476307, 1.3020344559223422, 0.21290665131903466, 0.15948384699802245, 0.16986905747363645, 0.38013806806937345, 0.1710709728180401, 0.689742114515074, 0.8299206990388133, 1.4774787642302052, 0.8006674784325785, 1.0002414725961224, 0.5292923532186017, 0.39749636404937316, 1.5066295742027223, 3.881730740108798, 8.67967272958448, 26.76340445395439, 34.206872601662916, 44.020885959748306, 62.55628155123804, 80.51334719504081, 81.15574513712238, 87.56057554675688, 80.39240483314761, 88.76434310790032, 85.0203231073195, 91.22364567172144, 72.44515726643225, 87.22212991406842, 4.981684684753418, 39.861016273498535, 108.97875632009199, 82.5997108028781, 88.50802406187981, 74.17362028552641, 87.45615420802947, 87.5238464724633, 92.63016839181223, 91.68020171503868, 90.8760452270508, 86.84557453278573, 79.570158373925, 61.5023995214893, 38.680061217277284, 20.326157616030788, 21.440389233250773, 13.10367678442309, 5.420595945850496, 2.040652550997273, 0.9177589308350318, 0.3774606520610471, 0.5919118285659821, 1.2634722864435566, 2.323602039006449, 0.9800925021690707, 0.162195629710632, 0.12942955889288457, 0.20855707987662286, 0.1076891633772081, 0.09250075781657811, 0.2268984198810593, 0.21200611496404295, 0.32986446734397645, 0.16908233114067586, 1.1310069815766428, 0.34630008702797277, 7.4553092929624745, 8.154262419669859, 18.21702072697301, 8.413962548778903, 5.5952036861450445, 3.689784162467526, 2.888162261055362, 0.6708066273600825, 0.7527543171759575, 16.074645673075032, 61.403944107794, 32.308451321817216, 86.45510258213167, 86.50207688731533, 50.21927026010329, 51.1554301938703, 72.72120583441951, 70.4995753688197, 4.1382441886009715, 0.9192293293533788, 0.3066172534900327, 0.2060728405992831, 0.16936120246687245, 0.13163425268665438, 0.24447103661875574, 0.11952799504562733, 0.1878959796721897, 0.128760457699818, 0.2484005926958015, 0.10892802714219979, 0.23154717930141958, 0.14661946874712745, 0.2056013900906809, 0.1910890647841077, 0.11789949130146735, 0.1362083491779143, 0.18601350245937226, 0.11238687581592992, 0.14037215962044655, 0.15933095117009458, 0.23927619440420983, 0.12983886434906913, 0.21119537943553543, 0.11068903345374331, 0.19789419317197418, 0.2901588350294098, 0.18021464588180666, 0.10056815395552306, 0.15629227874019455], [0.010510283905351836, 0.02551008053424378, 0.012391807338703546, 0.046998973214818586, 0.02623658469547668, 0.0921796597239952, 0.028828231415020365, 0.04229915403430501, 0.048407958294715614, 0.05546506449219681, 0.04457559196218368, 0.12341898625656483, 0.04933600103662861, 0.07556251550634062, 0.10773401782517472, 0.027542519458239118, 0.04497164792771782, 0.09347923595698611, 0.1212023874564517, 0.025154611906938018, 0.04989267116592777, 0.03993186190904629, 0.03194961452766532, 0.12641154019342316, 0.05998569187678157, 0.024463617836215326, 0.012358052547149842, 0.026641937137971965, 0.0844938213366174, 0.0647933877283527, 0.03371756734146226, 0.09642391705945616, 0.03134145754419508, 0.10979178361594678, 0.0696866441097471, 0.09588988482831948, 4.363806459211535, 59.22465955057452, 55.23291833939091, 55.47424608661283, 32.2082975218373, 55.44478124187839, 98.32832890172159, 40.84381318861439, 31.262880794463623, 32.89966821670532, 1.026305009520823, 0.7360238149281472, 0.046484062538271954, 0.17932252117222358, 0.27064069204272767, 1.055702867527162, 3.268242382234143, 2.503194131197468, 4.6938832248410876, 1.4447194962732255, 3.5771042733423175, 4.308048986619519, 5.346712710395937, 3.0681453645229344, 2.2908899620656045, 0.6972993573834819, 0.10946018245792198, 0.028082117318145694, 0.025296966365027814, 0.02299985172407281, 0.13228378799413482, 0.34494665481390496, 0.7003173760829434, 0.15633323380062658, 0.4852926142273411, 0.4445790859960741, 0.3693638381458098, 1.1928862934151006, 1.2389561245518348, 0.21464588541177013, 0.35438709501777926, 0.9267371748724292, 2.7513843101839868, 11.21308651662642, 22.625047006914695, 34.32308066275812, 56.29902639696675, 65.0789382380824, 72.36350920892531, 79.38881935611849, 78.57731234642768, 86.8888931889688, 90.83455439536803, 43.43939850407262, 0.2817297228161366, 33.88819179227276, 90.72217064519083, 76.26883276047246, 79.85846827107092, 78.18666781148603, 80.51066429384294, 82.82061869098295, 85.65394278495543, 87.3365846756966, 66.13576596783054, 57.57795441535212, 53.29322784177719, 42.30515103186331, 24.474173899619814, 18.062034153169204, 10.445511033458095, 1.7102534155691824, 0.3666810901655305, 0.4610653900571408, 0.4411984012732583, 0.5783542173524057, 0.5540552567089758, 0.32826276135540783, 0.2021160577574084, 0.10210749272617603, 0.10864811393642619, 0.1534710680284808, 0.038404589023200736, 0.01709100790321827, 0.06398851660290553, 0.13318257766865915, 0.19204144996981468, 0.06176439481937598, 0.2672331635990451, 0.18236738359255178, 0.6551863397321394, 0.4317218936499088, 4.4661410970072595, 2.0164158579803284, 2.0956390327022922, 1.1952107880384693, 0.3157870195085003, 0.4675421731606607, 0.5855518279056395, 17.162528768662487, 47.539071575287856, 20.932858067174113, 83.01324629014539, 65.92249101208103, 60.95289899456886, 30.373344113749845, 44.51135089320522, 46.907083603643606, 7.209285978348025, 0.328793844148036, 0.27727418609203835, 0.09131722092147797, 0.08757406935816811, 0.06697633228595219, 0.04234027763408038, 0.09763728541832778, 0.020865073029492653, 0.014354134853478643, 0.0838444545684803, 0.06456441936954375, 0.03256286982627165, 0.02569699258122954, 0.045296155111563784, 0.02742105813306426, 0.037401117264263095, 0.022089340904306982, 0.0673891694074677, 0.06886345199159077, 0.0890452569470771, 0.038626919230145794, 0.08329159955704406, 0.05326037835930625, 0.034516217832964276, 0.11756952957160051, 0.06767076034579547, 0.13086876231095484, 0.08536428107970184, 0.0695748565598361, 0.03203394740158993, 0.02276063310883699, 0.03833147359170741, 0.08647955954074861, 0.017422660772177963, 0.0835631470826845, 0.05066862630267298, 0.08878393669522579, 0.037291386660428784, 0.04525836399425903, 0.040438583105682366, 0.05264229096111752, 0.07045963448622534, 0.011492459377604387, 0.04346264623886636, 0.05253822557748326, 0.1058613848421843, 0.04995367474733822, 0.06342680178462498, 0.07284189979996412, 0.07255636350882631, 0.0509204279120651, 0.033932627374005896, 0.019110597617503618, 0.012931978806943424, 0.036979527588212685, 0.05741530218191686, 0.032080537038705045, 0.04035653891943155, 0.03360411738075557, 0.05572007984043129, 0.058759966519691294, 0.05012189999463097, 0.06447562977911965, 0.06640548953005383, 0.1435753111276896, 0.0677604845634872, 0.0395658097770666, 8.093421555334523, 91.32967518221949, 76.86955944184335, 61.2831154946358, 36.53490128055696, 85.77195121395974, 94.33472064233597, 31.988427100643037, 66.50034243060698, 45.274436243118785, 2.126185716159882, 0.16676966491485798, 0.19419627143971382, 0.5007295616932455, 0.1012920534178134, 0.5179277146535536, 2.7295536235455544, 2.3942596152905495, 2.953602594714011, 3.7948794134201544, 9.424990723209998, 11.73320064621587, 8.063336485816587, 11.836626683512042, 4.939087744682066, 0.3989214714496367, 0.2930206943663859, 0.07364468333581764, 0.08756087732411201, 0.08322286614847761, 0.183308890329734, 0.743402467379647, 2.2467802128484173, 0.302369816889686, 0.40363996019286497, 0.0764401228497586, 1.5907492152144833, 2.2172430494139275, 3.031042439322318, 0.3843025526692791, 0.4819104892592277, 0.33320635737430665, 2.574767335768669, 10.74957513040112, 25.453366156547304, 43.41041218849921, 68.29945518124488, 74.90913529549876, 82.44616570011263, 84.74668287461805, 87.26497788583079, 92.86815427964734, 96.80934398405014, 45.083075569522, 0.23666766502203482, 36.526566243940785, 97.76772022247316, 81.93928564748457, 83.29832415426932, 83.33886577237038, 84.52561024696597, 85.18587850755262, 87.19074310794954, 89.30924661697881, 72.85512339684271, 58.54890969491775, 54.54739001489455, 47.7219638516826, 26.772804414072347, 20.447825616405858, 15.664729552884257, 4.927692769035216, 0.12265953265370862, 0.10739411993492996, 0.7065872235163566, 0.34202592928082715, 0.428428542950461, 0.2621868505112587, 0.09736121797393407, 0.024766444731804154, 0.14650247179933135, 0.0687061588189775, 0.05930642086652018, 0.016134518401456938, 0.02599624759187141, 0.03562260967408938, 0.1702205692568133, 0.08772423791308558, 0.6942906543131798, 0.7912242496686598, 3.265682790548571, 1.6176643967628481, 1.8805800113947162, 3.491304877304262, 0.2902038503558405, 1.1521514985830554, 0.208241788730506, 0.40462346387005627, 0.35627936283426903, 15.889200914290646, 93.97655333242109, 21.682179820153024, 53.02952297272221, 81.14225218372961, 79.40315169672813, 39.120166840091834, 44.09668968569848, 64.15764408726847, 7.9470362490223305, 0.4509766249647064, 0.24577306433310434, 0.17940412485791793, 0.11196709793782043, 0.10607763614145019, 0.06455522631445239, 0.10585763867223456, 0.05720756211948972, 0.02857872806940108, 0.03206045021333041, 0.09980438727765314, 0.016244773775519385, 0.01831399066553962, 0.10141209939554816, 0.06485150315828862, 0.026429401365138834, 0.047806640561189384, 0.05659059704011006, 0.017229734934986602, 0.10621029958729783, 0.05156863788743654, 0.052645474056442904, 0.025162946943554188, 0.0767932357566972, 0.08528632397252707, 0.014559984593952616, 0.12335255111177122, 0.1279658176785996, 0.07845694124097786, 0.01943190255382609, 0.039555076885247425, 0.11021765955393353, 0.19811542404274787, 0.17698078957055846, 0.20020155806935605, 0.1038546558289278, 0.1232120352646997, 0.118525653266378, 0.07029137093453638, 0.21105797390543649, 0.19477811521820484, 0.1889740032774787, 0.21712523704815298, 0.1359011632420363, 0.2517635195005325, 0.23697278252051723, 0.2303282874486139, 0.19949787566738747, 0.27584344028465213, 0.1904116745197004, 0.22138073289346313, 0.12617415252832637, 0.0622438854207435, 0.2039317167814701, 0.3039402052039101, 0.18319992198338433, 0.2780735222322326, 0.16609144727549247, 0.09275501473776757, 0.2691133272263312, 0.08603601761522793, 0.15432072082354178, 0.216185599565506, 0.180575764407554, 0.2714834194029531, 0.2337764645175588, 0.23687803276604225, 10.674230321761101, 120.9213536785495, 98.6805263642342, 91.91987422204788, 55.997403975455995, 82.57546271047285, 124.75834169695456, 56.3642789471534, 55.28353652646465, 57.36371063417005, 2.1248396077463707, 1.0637889562114593, 0.4070310943549679, 2.015439187807422, 1.7197391775346573, 3.177819247207334, 15.096258482625409, 9.239658732568065, 13.40213679498242, 13.424158942314888, 16.252891902000673, 17.963335552523215, 19.032083365225024, 24.536678829500755, 15.005947870592918, 1.8734241373115972, 0.22825742921521588, 0.24282718047259316, 0.138341827438243, 0.1807513364380406, 0.5809040643995809, 2.3784384900523774, 6.028560380781851, 0.5317033851338971, 1.0249597591257866, 1.5593654734473077, 2.0359115086255537, 3.1555813695153887, 4.308911417761157, 1.3370492093024717, 0.7045835665156764, 2.4038252955482853, 4.647706141394954, 14.907364979867014, 31.8285140299028, 51.44276342084331, 72.80800788633286, 74.63248268250497, 82.41031523673766, 85.00106426977342, 85.93961684934555, 94.12951792440107, 97.57632424754482, 49.479523012715006, 0.16627855659011873, 38.55890704739479, 99.76224545509585, 86.70068217862038, 86.09479365810272, 87.02786276417395, 88.22304033464002, 90.40849870251071, 88.82414356354745, 91.28386974334718, 73.41666560019218, 59.798255197463504, 56.84353766902801, 51.81972672862392, 35.66303291628438, 28.778969280181396, 21.61961997708967, 7.083838284015656, 0.4810765565883729, 0.922894906853476, 1.149938423787394, 1.1379881876130258, 1.1172508616601269, 0.7480988315036221, 0.2606006194987605, 0.29077789535926235, 0.30973130897168194, 0.22416331745203466, 0.18417432453603516, 0.10807550151742275, 0.10642462800587378, 0.11288582888101378, 0.24097865627657986, 0.15350869826732144, 1.334884306115489, 0.7902344027834555, 1.8296677691321221, 5.900131685118522, 13.7742648009331, 10.332124137109327, 4.139792544226493, 7.062287311400137, 0.6447953682753348, 0.5040894701115547, 0.6127233731169855, 24.207958713654552, 73.54944567526542, 30.460546247420776, 96.45211804297664, 91.36051285651423, 80.54590286747103, 52.45521345446187, 58.17240922681747, 85.47610252134263, 19.28663146111273, 0.7440562774577449, 0.3689201506635835, 0.26161191684584467, 0.21644007865219347, 0.2802648707743614, 0.20541431141957162, 0.13947058138587784, 0.18218822627057954, 0.2131221212086178, 0.17461238278736993, 0.21883398084150207, 0.09299403417014307, 0.09938016608958283, 0.2690901913710179, 0.2061371613414057, 0.3008074571769084, 0.1616726521282427, 0.1802927715283248, 0.2584630809724331, 0.23759335970445988, 0.15976204416684567, 0.18756551998517207, 0.14012315040153844, 0.2741017853540759, 0.19781252819924586, 0.15002761006114945, 0.24226387602186975, 0.191678048502053, 0.2452495964544435, 0.16533479755443914, 0.11471895470974908], [0.05731919645181587, 0.12378872327146032, 0.03209153806129771, 0.019177185979882078, 0.029735248873851476, 0.03605020930990577, 0.01260693344633065, 0.019410716392280116, 0.0842784280558267, 0.05434600155680411, 0.10021933880183967, 0.14345010171734518, 0.10939380860016232, 0.06385276582272303, 0.08635125513519011, 0.17242256642108963, 0.0987434474330756, 0.09309036972662134, 0.04845143761485816, 0.0079461268145561, 0.06713578582651193, 0.05972934353555884, 0.03385497287156121, 0.05846640162710702, 0.08784933241024133, 0.03388416465191591, 0.07709488287688264, 0.010918574295036737, 0.03526809099580973, 0.00299604993122029, 0.024977641765989607, 0.09780276040997236, 0.03232025361109165, 0.08677310911157439, 0.057411640281638796, 0.12911281217971157, 0.059195257678267464, 8.986498175128814, 54.52851164725519, 51.51440551204067, 55.77734724167855, 35.57975707515594, 54.40960891785161, 103.2287577659853, 52.429223829700106, 31.021262791848955, 51.225452346186486, 3.686234172313444, 0.8232008209151607, 0.25102876457235507, 0.1472423901601184, 0.24560538300823784, 2.4525720217535576, 3.6103880357357765, 1.508398318002301, 2.305920239417784, 6.630711372821562, 7.067045636715428, 3.0741296756652097, 4.769029953787404, 4.8241127787097815, 2.211890975313802, 0.11440098991677647, 0.09307382988833612, 0.05056369140924466, 0.03592509949099153, 0.09682481087023213, 0.23150171964399277, 0.22809584595022664, 0.03095079675286768, 0.07545214521908954, 0.013753305501004141, 0.2413478493690491, 0.5560026522124968, 1.026438124958546, 0.6356388402561988, 0.8190845385674508, 0.8070840470252499, 0.9488263702200306, 1.0176823528543597, 3.0903776038077573, 17.915641492412938, 38.62161005696943, 53.32618359596499, 68.74448730099586, 86.77569358579575, 84.99117205219885, 67.94654384736093, 30.304783044322846, 2.3373617135709335, 0.12984618814962526, 11.126700235951333, 75.05294507549655, 78.29661184741606, 77.76560921822825, 79.56581238777407, 79.39664840698242, 81.02881723834624, 79.23470158730784, 64.12360968128328, 48.75501809581634, 33.0922487474257, 24.61705800025694, 17.05229251615463, 10.65093634590026, 3.8265128385636116, 2.112452272445925, 0.46887789342191916, 0.060777462898723544, 0.060814032105789076, 0.12436615438350748, 0.055195125751197345, 0.09902473193623366, 0.0875306474946199, 0.012491645832215587, 0.05956576844196647, 0.023866703193033897, 0.05249885631905449, 0.08297352751176204, 0.05475415405066264, 0.05475142294721258, 0.060363373223451845, 0.17691246984947115, 0.05001801464165892, 0.12819583557786482, 0.30456732477872606, 0.7304963373368787, 3.3998415787373824, 4.103054154303766, 1.1638320718080768, 0.6438384938143915, 0.28117103021471734, 0.12438304662223786, 0.528408287753982, 29.68154784171812, 43.33074885029947, 17.407627874805083, 73.66415146858462, 77.67591245712774, 26.972886477747274, 26.24779320532276, 45.7598138624622, 60.81871471097393, 14.895538053204938, 0.06584553288355952, 0.09672495897018141, 0.00561772131233386, 0.045656603310377374, 0.05260320898566035, 0.13403151034107133, 0.08157478885785227, 0.06314924812965816, 0.03776197915055579, 0.008270172909232638, 0.07198068673812574, 0.07417054906968149, 0.033363592585608844, 0.03218950155461508, 0.031626878922144254, 0.030277529956712842, 0.014716587329824126, 0.03208202899493758, 0.06844270118181744, 0.1400599481477853, 0.021574399584243377, 0.0768324671192996, 0.02003286214124772, 0.08340409956872465, 0.08245239620127025, 0.05405663865648451, 0.0630426738080719, 0.05359295627943451, 0.029685240569374258, 0.22460827664021524, 0.10376339177450827, 0.03169940255071608, 0.041399402919435696, 0.06793965720721791, 0.031940386998617364, 0.10780543254147615, 0.03421757760788164, 0.062253515145951704, 0.05946041603061942, 0.025845356999085318, 0.06675084962719871, 0.059414102185157046, 0.06604316058538615, 0.11130259327229955, 0.06493771869328714, 0.10946923761718697, 0.06770370978741877, 0.08874783097135444, 0.052368560084892865, 0.1562241888454845, 0.11127827764158288, 0.08010522537534276, 0.06989450674624213, 0.025589447243199236, 0.048719139379118724, 0.04622265801674897, 0.03989797017927613, 0.04416718665931014, 0.039727596055355766, 0.03192420530643675, 0.039513474480519374, 0.01919377752910218, 0.03869020192313098, 0.06836426143925037, 0.07921793468056187, 0.06811545140320255, 0.0703781227310819, 0.14947080203602392, 0.09903128198798626, 18.055201384329028, 85.00471991877403, 69.46469722255584, 60.374835768053615, 43.7813978041372, 86.77209284997757, 98.16386392039638, 34.388148861546675, 62.699765774511526, 65.29042067066317, 4.819145587182814, 0.38752597486299856, 0.05641752245625662, 0.375781755053228, 0.4454640707662029, 0.7938646789520019, 1.4866930246353152, 0.734417420481482, 2.6424711221648804, 2.4283187812374485, 4.445996784394787, 9.269546212688569, 5.230965037499705, 2.28357792862, 3.0212406814098363, 0.6457290762374479, 0.33601051496882595, 0.018220072116462455, 0.05550972358774274, 0.1473264912924459, 0.4786886298848737, 0.7212109839723957, 0.05152086081403879, 0.21891544663137008, 0.08553332604107358, 0.0885563396338013, 0.25702001647122447, 0.34854325375729994, 0.3499479525752606, 0.147282732350211, 0.5805534412783961, 1.1429757264352616, 1.550575809613351, 4.906527659585399, 19.610552557053108, 42.68520908970987, 55.5481239288084, 70.63354784442534, 88.53450790528329, 89.02143878321495, 68.17379813040456, 28.265593782547985, 1.8790423197131005, 0.10063904007115673, 12.79656598644872, 84.93670601998606, 85.36770389926049, 84.79748541308989, 83.84551832752844, 83.21076900728288, 86.29965905220278, 83.35803831777265, 69.31265830993652, 53.40386221485754, 41.1443648030681, 31.634919566492883, 24.760675584116292, 13.95140099909998, 8.156267241124185, 4.334797099713357, 0.47074052895749774, 0.19648204797938948, 0.12464939241087246, 0.061130296183569785, 0.046659224711719065, 0.050845408752079935, 0.016730283912751946, 0.11203642123408857, 0.02014624698448085, 0.046015086493665175, 0.21598543611265, 0.048545402129210775, 0.038017381373192036, 0.04837280251987038, 0.06989495107723821, 0.12469228567375291, 0.0642879688811879, 0.22763089186722235, 0.6663072397631984, 2.583717449057487, 2.3904311368542337, 2.550516546733918, 0.48089444216701294, 0.6324726295086646, 0.2051440968869194, 0.49554385124675693, 0.6760394368921557, 28.646110757704708, 80.35212993621826, 20.868917549810103, 40.56617998307751, 97.5555984435543, 48.08295526812154, 39.07722865381549, 51.77307405779439, 69.10900885058989, 19.283179775361095, 0.09700383795725723, 0.0839182977835017, 0.05405966853422504, 0.13864362011513404, 0.05840964983367632, 0.06905969307427445, 0.046131436097165274, 0.06645543846271693, 0.02796244480827403, 0.059252733424786604, 0.07714839411839362, 0.03578060381715337, 0.022970679095916213, 0.047629750859473026, 0.04591325808676981, 0.019821056067162467, 0.011302492555020558, 0.04803229558972582, 0.00728648393452468, 0.07980790665192951, 0.02270253874631899, 0.0331388836756589, 0.06959865891164349, 0.039914004399531314, 0.03541673120531825, 0.021896842161133405, 0.06814434057882718, 0.08501233262640816, 0.0901536712603223, 0.13822775694631761, 0.059372622354496876, 0.032498732945250894, 0.1470197343658055, 0.22215930805090936, 0.10893929629556595, 0.2279880267357634, 0.09924124370539382, 0.11749789268980104, 0.13607489666150463, 0.11967604919787377, 0.164285640142137, 0.17904302165392907, 0.21326067587060316, 0.17781610119967692, 0.14804405520760244, 0.16860449145878517, 0.17113864902527104, 0.31745166728092783, 0.21194861240444646, 0.23626361492901082, 0.16798311754340128, 0.19487064331769946, 0.15861999093284532, 0.12592978580223937, 0.19064985125535922, 0.2041242193550833, 0.2512969259893702, 0.15146263063915316, 0.20242171151743782, 0.11523294608078657, 0.12237455560675553, 0.08918456237522826, 0.14437751243672065, 0.19500139920461565, 0.2054518037625859, 0.36237631954493066, 0.1716294049495651, 0.32905728646343757, 0.3596712630842963, 22.67693800310935, 112.95636915391492, 90.9491660518031, 90.89001670960458, 59.61736332985663, 82.5421304087485, 129.96943012360606, 72.42519240225516, 51.508565102854085, 81.42299190644296, 9.59233178246406, 1.2769125329871334, 0.3948822881906264, 0.930796153843403, 1.1945927695881937, 4.658586796252958, 11.445923313017815, 9.232276831903766, 10.102549772108755, 17.13634498657719, 11.514045076985514, 17.765877554493567, 14.852748916995141, 12.520412495059352, 7.509419370082117, 1.0752555151139538, 0.243603564618576, 0.1151127698681047, 0.21210851027600228, 0.486416005559506, 0.7877394076316588, 2.37562247341679, 0.13498199562872612, 0.41770735695477457, 0.16389951650654117, 0.6501731829297158, 0.85081810672437, 1.6088480117820925, 1.7113563370320106, 1.554568537300633, 1.5203643662314263, 2.3563891312768384, 2.6480215211068434, 9.262512422377064, 27.63031101995899, 51.888430964562204, 63.18209571223106, 73.02755078961773, 94.56038244308965, 97.23625475360502, 71.46046976889335, 34.148433208465576, 3.10829597134744, 0.15275692086546652, 15.843910286503455, 87.4760720037645, 89.17503879916283, 89.28202536798294, 86.57064776266776, 85.49707935702416, 88.07404518127443, 86.94457515593498, 71.2925531018165, 58.39503511305779, 45.024742080319314, 34.382853661814046, 26.095177704288115, 14.228475266887298, 8.224618954043235, 4.9715237848220335, 1.2161951007381564, 0.4812781296430096, 0.473462653857085, 0.321824252004585, 0.2316330884012484, 0.19165171039921625, 0.2042445411244708, 0.2176439398599248, 0.23939895233319652, 0.12354096277586876, 0.2731395789211796, 0.14764861594284737, 0.10304523797165002, 0.1335932927266244, 0.19662198159963856, 0.25471833594624077, 0.27136433869600296, 0.297982094268645, 0.5187436902234631, 2.9854507696244026, 11.912029347112103, 9.727535882303792, 4.664633129873584, 4.846400666621424, 0.8732650344890933, 0.9174083690008811, 0.5664447983426433, 43.291717344714755, 61.63919610361899, 25.419612200029437, 86.73108839219617, 107.60618563621276, 48.611310297443026, 49.34902575708205, 64.81732791469943, 88.99487649240803, 37.114878623716294, 0.14368040306914237, 0.1607993578598384, 0.13852548935720999, 0.28994117412836323, 0.1762911418993627, 0.3707542877283789, 0.18065177565140111, 0.15563341248179638, 0.14282975435977982, 0.13696915109551724, 0.2114613498410871, 0.13893638827627705, 0.1452272265188156, 0.16160263169196346, 0.1558642194516236, 0.22190869004736025, 0.21408126328981694, 0.16260636009035573, 0.13265494227169022, 0.2597394140978014, 0.13993938123026203, 0.1545108332028312, 0.15957350992868025, 0.15223527627606548, 0.3169557326022656, 0.2405390750256277, 0.1799217091813203, 0.34200935113814573, 0.1873727569416646, 0.48405504515094144, 0.16989113612761422, 0.2493317878895229], [0.05772136196854615, 0.16283554295378347, 0.06536388574468513, 0.043345737391181534, 0.0035294599553209642, 0.06248835556870026, 0.030034099773113287, 0.06280500652088274, 0.024599064096447923, 0.07089700940395556, 0.039522158087141095, 0.051464538029845686, 0.10970408187037516, 0.054559694122402906, 0.10762093558667168, 0.0777159656788553, 0.06344355995796862, 0.031117388317661903, 0.011794302807820421, 0.03772948936168705, 0.012688065030341669, 0.04721243978447972, 0.11148027204457792, 0.02630145127524532, 0.008949036935284253, 0.05926750743040635, 0.0437597313054627, 0.036583207322344664, 0.027786566342617718, 0.02098183057481243, 0.022968560862805576, 0.03116807652517192, 0.11061198799119842, 0.022553163092403163, 0.0965407224852712, 0.055100180644301645, 0.2906996011734009, 0.16752522679105883, 15.958403291240817, 74.63084313177293, 53.699263757275, 50.9071716185539, 32.0272546429788, 45.899442395856305, 96.65489673614503, 49.60021434291717, 29.82234916379375, 61.5465771767401, 15.02622260201362, 1.067069773712466, 0.2891413783354144, 0.09672233894948037, 0.49740633356475067, 0.20755515944573188, 0.6343883396156373, 0.8010785305692304, 3.977277961469466, 7.060184430691504, 7.253733786844439, 6.973565259287435, 2.999855919230369, 0.9363991370604885, 0.16567284151190714, 0.08391069053041358, 0.7175346199543245, 0.04670918513570101, 0.3064790512284925, 0.42916233260785386, 0.16721549744327224, 0.1303694568454258, 0.04729222018091429, 0.03710832229004272, 0.036515557928191084, 0.08431986575165103, 0.00712591142679054, 0.010581651698767899, 0.03716743746471982, 0.12841892038141528, 0.21605364858142792, 0.915276805960363, 0.7939863950014115, 2.8816329856072707, 9.333508303088527, 15.25965952104138, 17.148780861208518, 25.104410532982122, 21.796250189504317, 3.7774876240761053, 0.7358253675122416, 1.3802923598597128, 0.4786870670655082, 1.4707860975496232, 28.194379229699415, 71.32797994921285, 79.63654841146162, 78.9907144731091, 76.95229007351783, 65.92864128851122, 51.178328990936286, 32.934765585007206, 17.24058589627666, 7.689453219213794, 1.8069364082428718, 0.11953625347345107, 0.358531262965933, 0.31812919544116147, 0.2610585562163784, 0.2525681263256458, 0.03937072931758819, 0.03531346255312524, 0.08280219960837595, 0.007339033735690699, 0.028120684099473783, 0.04197297294834449, 0.022996806524573796, 0.048564251722587694, 0.1114582010514794, 0.056038948617154555, 0.06620609216512212, 0.06715170513357847, 0.02850424708618272, 0.14198239982849167, 0.3958122576436689, 0.1491796273377634, 0.12849776615058223, 0.8625599669833338, 9.181341913438613, 1.0186864796184725, 0.3743538284494031, 1.405373465630316, 0.3781746766499935, 0.29233057172067706, 0.31413631453629465, 42.57316658573766, 36.863195819239465, 25.484900051547637, 95.58489768735825, 82.49810572593444, 26.030403683262488, 20.33943287787899, 44.76263361592447, 54.13022633521788, 31.081357425259007, 0.06973173604497025, 0.14118162344299978, 0.033917052806505275, 0.035797756525778004, 0.045515210292632544, 0.03186116776158733, 0.04692472397319732, 0.03364470088854432, 0.03456489889011268, 0.05743147812843804, 0.033757266017698476, 0.05611379540735676, 0.03839325858280063, 0.10260476039782648, 0.0312537998486791, 0.06607437100742133, 0.05963662008364355, 0.040205799629010504, 0.07101398336911394, 0.03399920041462587, 0.025962769549580354, 0.061007032636553056, 0.05223708790576747, 0.03140990558500973, 0.08654651562533072, 0.0635771235571273, 0.030842062063334934, 0.08218507748097181, 0.0465568945172333, 0.024986068733156692, 0.06329194732731389, 0.06921103374371607, 0.06649222600484087, 0.0637304330725343, 0.08925237647828557, 0.009144473625647445, 0.07986340972204363, 0.05875983628474417, 0.016108615053517204, 0.021364713658488566, 0.044608008972699606, 0.0792266374393817, 0.0370390564503689, 0.01969403102843752, 0.1304365355040758, 0.19717934120806957, 0.07189365914992749, 0.1099978919110952, 0.07457792398429687, 0.046996276585325125, 0.026193771871828267, 0.02816552897134135, 0.04488815966572973, 0.022341406814032988, 0.06379473466245879, 0.058498627115641876, 0.040081884907258135, 0.03033261933934785, 0.014800120599477764, 0.07734639720330316, 0.05956434734886693, 0.012916977847776106, 0.01085580392335091, 0.042705667100005576, 0.022984485915531556, 0.10054077397310927, 0.056857536546885974, 0.08584263404050181, 0.04984767499169515, 0.17620336354499863, 0.11561262691693923, 29.584457412842784, 100.94363981677641, 67.03098420173892, 55.232380974677305, 44.047271743897475, 82.13006973266602, 91.9047966311055, 30.796450184237575, 57.85300670131561, 84.37008042489329, 5.553284825817232, 0.8379409654486565, 0.19591934107724698, 0.45310034326487975, 0.37116371575863133, 0.5384987075963329, 0.4196273571541233, 1.5255073289717398, 1.7739911954249106, 5.42229482243138, 5.565487809719579, 6.0918674353630315, 6.22645866486334, 4.2657957442345165, 1.1674825726978242, 0.38092704670083144, 0.4157943128337784, 0.6063016564134629, 2.250597659618624, 2.5849078884047847, 1.8112458673215683, 0.1226933018094109, 0.03913791136695974, 0.08173903044793876, 0.11865001231912645, 0.10961879330176501, 0.07441316145442187, 0.042823751892654166, 0.0963998542377545, 0.19776708386357755, 0.09338718283200458, 0.20207499544466698, 0.4923374974919904, 3.414698536357572, 10.456110258256237, 16.837599623587824, 17.71603991908412, 26.28182172775269, 24.902667345539218, 3.4008986574988214, 1.3181424044793653, 0.9453087396198704, 0.7900801433190223, 1.3821860066344662, 32.21958414200814, 82.47034318985479, 83.74028898054554, 87.05139698520784, 83.49323457287204, 70.84926251442202, 56.71472311019898, 40.27871339551864, 24.530179462125226, 13.872308365760313, 6.080251336097718, 2.1359573208516647, 0.676420335808108, 0.7684346660971643, 0.4013758332979295, 0.2329343653494312, 0.14234241518762805, 0.019909529646317807, 0.0407476919222503, 0.10415352971082735, 0.09364661084668291, 0.016225190652954965, 0.024730072792379126, 0.10328057252110974, 0.09576407786939414, 0.03615938449999498, 0.0416267165283282, 0.04320458186069324, 0.006886706218093394, 0.07208263771908899, 0.5835166080824791, 0.07630139198755065, 0.10167934150705416, 0.675451449088512, 2.195271157449292, 0.23452680167411608, 0.5070357829813035, 0.7023637501462814, 0.16594026748451496, 0.6154584295807347, 0.6181744257769277, 46.45847035992531, 76.47309410956599, 24.983144575549712, 49.21661830717518, 103.3332810863372, 47.59905638233308, 23.454985234045214, 40.46962299654561, 63.87711225017425, 40.54887056350708, 0.2739406310983243, 0.08344394380166646, 0.013046707176873762, 0.027760716620832685, 0.02488995151173684, 0.03798751926590358, 0.0199952204110882, 0.01486752293027577, 0.018610978055925622, 0.04923912155772409, 0.05970177203116398, 0.07293288806273092, 0.039676076642447905, 0.015719682748068967, 0.03723034094418249, 0.02838876124681725, 0.051713696635899045, 0.026988256760242007, 0.029751658477189562, 0.05264122992934239, 0.06752087524341, 0.16026698803949743, 0.03243540045655063, 0.03202125907034403, 0.08477981728050979, 0.09272384262012859, 0.020523489745814475, 0.04570318528661325, 0.05447516781127742, 0.08823850507577581, 0.0032560948860801517, 0.060755096961774176, 0.06819585233085579, 0.3083261811444837, 0.21945229040518885, 0.30559455675463526, 0.2625945931480777, 0.13390297610913554, 0.21508057902176536, 0.15932779488784654, 0.173231371408028, 0.34212751253958673, 0.18943339556215272, 0.1523075336890836, 0.13641418168140998, 0.2608511915370341, 0.13284946731742353, 0.2316086042311884, 0.13304737847178214, 0.28523218487539603, 0.15888614519949884, 0.23057487582968128, 0.0677615417648227, 0.14956241083000937, 0.22613027884114176, 0.2239166831056918, 0.14714701221354548, 0.16425809162037988, 0.1924107809581103, 0.11286412561011892, 0.11808312257691739, 0.17614780684872983, 0.13169229150779788, 0.10793371396439691, 0.13808751689089885, 0.2426876605398232, 0.20268581266845428, 0.20924977657775726, 0.21475200391104146, 0.446262518244405, 0.19331767584287352, 36.01666988865022, 127.22435935851067, 87.99891610299387, 84.35712091384396, 54.31687624223771, 71.60253017179429, 122.9212211793469, 70.00093229355352, 42.22544846996185, 87.29254430340183, 24.573621672968713, 1.0518279335191174, 0.5125261206300028, 0.4832951165735722, 1.4789257511015863, 1.7960168974053476, 2.311963386112644, 5.197148813355354, 12.8318408420009, 19.92459124134433, 16.158866805415002, 17.813616721860825, 13.153233970365218, 5.290093787254826, 3.0763114940735603, 1.9762216147876557, 2.164866905058584, 0.4309142531166154, 2.2905376841945033, 2.1278367888542915, 3.6357336563448754, 0.34702857535692955, 0.1225488865748048, 0.11446654406045714, 0.21439278528334635, 0.13849570385871396, 0.19505582209075653, 0.0631695494596516, 0.20268305475192688, 0.3670721627291172, 0.2943252501708846, 1.1504683114828602, 2.29960032047764, 5.075248902843845, 12.895880399211762, 19.74447600303158, 19.73446415316674, 29.528281227234874, 30.519224905198623, 5.832485018237945, 2.576630706748655, 1.6117114645819512, 2.6892596050616238, 2.370872728286251, 38.04352329623315, 84.2688597402265, 86.01240819500339, 88.16219652852705, 87.85535735468711, 73.23134929903092, 58.0324786709201, 40.849571228027344, 23.34863801156321, 11.303567751761406, 4.907753400264248, 1.2664491202562087, 0.394799611981838, 1.3593440839359838, 1.3096871227025986, 0.3175709931360137, 0.20515912753199378, 0.20820512376244993, 0.11709590337329334, 0.2011270535689208, 0.13180375730078067, 0.14791478553125936, 0.12302697140483126, 0.3368327418161977, 0.20266551133846084, 0.16870710127536329, 0.1455841928480133, 0.16385100781917572, 0.07688915762569636, 0.1771334402503506, 0.7467617935711338, 0.21866024742203377, 0.4198770098868878, 2.641685667537874, 24.447164458613244, 2.251846689370371, 1.8174334062683968, 5.438204446146566, 0.5287430375333756, 1.7599443298193718, 0.3765371483900855, 61.79824821410641, 55.195173371222715, 33.764221360606534, 112.79916840214884, 109.81693544695455, 45.47084108475716, 41.96602682913504, 67.72673422290434, 80.5859894906321, 61.26187586015271, 0.25714599196949317, 0.22937320563341343, 0.10144929296427196, 0.1997859553704339, 0.11395691939058805, 0.14938832501009588, 0.1304795743236619, 0.06505830859344813, 0.15096033743071943, 0.139316015486275, 0.12401180807501079, 0.14120794622407806, 0.10544112432868251, 0.20607912252026223, 0.08408760321476767, 0.18047957440778134, 0.11122904117068938, 0.10400061090026172, 0.18952048443738492, 0.18353876267229358, 0.20580421952951342, 0.2860408366447495, 0.12055800792070166, 0.14226801272842193, 0.23370641343776258, 0.2399307092831981, 0.14505292619428328, 0.2053416249973159, 0.15979173773479077, 0.10891573909189432, 0.06644463662298457, 0.1690088326652204, 0.15277173700592211], [0.11939975958798202, 0.03354622794675731, 0.08970911809874159, 0.07575962992925799, 0.15006102681640657, 0.03577111964865077, 0.07452111856471147, 0.057599201588140386, 0.03410805767822651, 0.050786385507953745, 0.13333709760298654, 0.04008872607242196, 0.04221312619084793, 0.0928517180164495, 0.07824966849218454, 0.00572503682398688, 0.02931181484112336, 0.01847112295968879, 0.012469621762002428, 0.011568477324720834, 0.025659180396506866, 0.01777443685568869, 0.07108342923944996, 0.04633721497450625, 0.03217260548544507, 0.08489336683264664, 0.04369125070591127, 0.09549210899539533, 0.035188268464539325, 0.02556796039214298, 0.02682744149839686, 0.02581843092376667, 0.05361354489239955, 0.03388693789020181, 0.06281513803368134, 0.07839495706702433, 0.009185493803553043, 0.16630023687837586, 0.17381310793420962, 30.712146682123986, 79.17002170316636, 62.224915796710604, 53.14018088002359, 40.911148517362534, 64.02205167278167, 105.6396661266204, 60.88201784318494, 21.477188910207442, 55.87198618919619, 24.768814502223847, 0.4373980229420047, 0.4210907689506008, 0.3142652930992265, 0.5564242457189869, 0.3557668193694084, 0.5160492057761839, 0.5777898250568299, 0.6850614398717881, 5.175196288093444, 2.0058769396235867, 2.5228248584655026, 2.9222648182222923, 0.9825521347022826, 0.07927894592285156, 0.026574255185081597, 0.587862778094507, 2.3163912517409173, 2.161390949641505, 1.7124041001642905, 0.02828963521507479, 0.14533959629554905, 0.05771861937377722, 0.05613879285632603, 0.09859640451688921, 0.05242045871132324, 0.05315999402814815, 0.07022682036603652, 0.13429997819325618, 0.11320452911839371, 0.09431415688126318, 0.2890051985459943, 0.3978829320159651, 0.5309377262188543, 1.4152419038357273, 1.2667396207970958, 0.7652259834351078, 0.8661254014699691, 0.2286056774638353, 0.7010466304998244, 0.42118466068660065, 0.36656041599569783, 0.21480714691983116, 3.1561072122666145, 26.545685452799646, 49.69835988936886, 45.72737586113715, 41.37134844256986, 22.713221888388357, 13.696028224883543, 5.519791706915825, 0.8367743054705282, 0.2915541262876603, 0.3761741759315614, 0.22880227094696415, 0.02587737755910043, 0.24066413121838726, 0.05925531897153105, 0.08614333121166115, 0.006470196183785917, 0.08144921938618345, 0.030104426644562237, 0.053967052334619146, 0.12123790329262135, 0.047761985296083075, 0.04250833051159017, 0.041551279850424304, 0.03133080509160796, 0.08144505186787537, 0.06574314523247943, 0.07681654781223306, 0.06167143771064378, 0.048013576231296026, 0.21426831131740925, 0.14502473415866976, 0.3665685671712122, 2.306888084257803, 3.985338677321711, 0.6617746345939175, 0.2432827423176458, 0.11975432806197675, 0.7898098062123022, 2.6193222740004143, 49.896023811832556, 26.7415980369814, 26.185945272445682, 104.54654862803798, 83.07336838014665, 24.113923811143447, 24.533180075307047, 46.966633027599705, 48.42749626405778, 28.511053746746434, 0.8760774964767118, 0.09307809699807437, 0.00793174830182726, 0.06341832502174281, 0.032333411171191165, 0.08459972533126993, 0.11149867347651914, 0.09994766870213133, 0.05599161970519251, 0.02629113015568545, 0.024433945335688132, 0.06798520113431639, 0.03873473461416941, 0.011969464023657625, 0.05039982137180144, 0.04424387206053061, 0.04521627129325944, 0.07768934412348656, 0.045029732714136766, 0.0346833284223272, 0.050509915867399786, 0.020913989658677773, 0.017911235261107647, 0.037316973997099746, 0.0013645868133490666, 0.024500930148567406, 0.0461140803752407, 0.015200300033264344, 0.01766413360113098, 0.04236586880119097, 0.049999927305766655, 0.024250097640399492, 0.06339792410031923, 0.05574707677888294, 0.024590072139436682, 0.059425850143475886, 0.04551105426564332, 0.04895546984288001, 0.09897532692599682, 0.037125524794382435, 0.06789055097127153, 0.061494536517608556, 0.05585995217364642, 0.025006352826171828, 0.048011435015547665, 0.07344849587928864, 0.061754546759109345, 0.13491818050463356, 0.1270834682509303, 0.015422645561967888, 0.06912687898523386, 0.007458262872176186, 0.11579918464826, 0.0384560011837992, 0.027909810737436338, 0.06953688924230876, 0.06296193580173197, 0.07602869533002377, 0.050957560193754976, 0.03746286778139972, 0.05794369983637045, 0.027192869268718268, 0.040647418673841224, 0.031205836998959704, 0.02383267931309679, 0.0247254858409325, 0.0759966115677549, 0.05061305428464567, 0.047572991405163086, 0.10064887664010448, 0.026382999419565165, 0.09397900107526973, 0.4640286487917747, 53.506812664770315, 99.40490184291717, 74.24803549243559, 54.455465347536155, 49.105191615320024, 94.56961570247528, 95.837443413273, 32.34858109105018, 46.763928859464585, 92.87379464795514, 15.68652714452436, 0.43205673535985334, 0.7314302291600936, 0.23869885522271359, 0.5229427713540293, 0.45641971031023615, 0.8072793075153906, 0.14865939235014303, 1.8979721684609692, 2.951931419872469, 2.854246261619753, 3.193618799409559, 2.1602093356270946, 1.3752262510599629, 0.06548814520600342, 0.384154605769342, 1.4578241350189334, 2.6359195382364335, 1.4401230913016105, 0.3793300904573933, 0.046498369230257894, 0.16389749403442108, 0.08234789414751915, 0.1100713597430337, 0.07035073508778888, 0.010086444803633758, 0.0072371502662257805, 0.0952150532975793, 0.18727868134456296, 0.016898622158013524, 0.22866458962521247, 0.3450240296942573, 0.5320243453306537, 0.5437311494062024, 1.9325417328265406, 1.4498759421610063, 1.1069103907192908, 0.9909667218885115, 0.7846542796300304, 0.9544680255555338, 0.4802052081832963, 0.6138091342103097, 0.2347374758532932, 1.8041380422730602, 29.39247504357369, 52.382712364196784, 49.6587400282583, 45.49410466224917, 27.586152976559056, 19.107712545702537, 8.536115942462798, 1.3464393634949963, 0.5120331277289699, 0.3747398754762065, 0.3846939316680355, 0.22314356249426642, 0.2965633913634285, 0.15755589480601973, 0.13058671938075175, 0.035294026902486245, 0.08426837698226014, 0.0700321497635976, 0.0488627961866798, 0.009891990621033455, 0.07987336120418004, 0.03911882811676591, 0.04708832587986704, 0.05982207081791374, 0.046217015779186646, 0.1127781628841354, 0.1282083457936683, 0.03725147347957377, 0.025536481839334293, 0.5393583195344095, 0.4553369216380581, 0.5076686022502761, 1.6309183307232398, 0.707074516723233, 0.07870103983629136, 0.8891484886407853, 0.07612410392011366, 0.9614986289412746, 3.02090899598214, 65.76581585791804, 61.72316620426794, 20.47889667172586, 59.1507464070474, 104.18713400440832, 49.13144011651316, 25.404395364945938, 43.41889235281175, 67.43463531617196, 40.93812265703755, 0.015625463509481522, 0.14867489796973046, 0.019214140146129557, 0.04349237811120768, 0.06589634749557703, 0.014794288755154178, 0.029150375217619925, 0.049063683592624245, 0.08553583880946522, 0.06227209660855513, 0.03236025106161833, 0.10736274863443068, 0.03210615118845336, 0.03672500253624974, 0.03947462616187911, 0.07750357546272778, 0.033360899786555, 0.057695219218130075, 0.023709967349385543, 0.03774895565584302, 0.026032663581352082, 0.027910147816123023, 0.029395034972337947, 0.03299583590799763, 0.07820961741550315, 0.06439758074139396, 0.0716802730194984, 0.06453141630176576, 0.05026293295105139, 0.06879349284234547, 0.09112438893005734, 0.04802153205438968, 0.0473420656917076, 0.04916178115132836, 0.1800397633304519, 0.20194011800471814, 0.27437249018299964, 0.1905896827097862, 0.3176585416640005, 0.07713140228823309, 0.2333997637634316, 0.19259134788186322, 0.2310754836446816, 0.3817890794767488, 0.27214194858266466, 0.17248083506861042, 0.16603083439892338, 0.3170174792889626, 0.3204215756587444, 0.09489662885185211, 0.17326685660068067, 0.12227098818027204, 0.15175380533741367, 0.0794933969154954, 0.13623758309310482, 0.15427435718236432, 0.09865672628004706, 0.17865394091894551, 0.149982855204613, 0.14118039770232094, 0.13818047399963104, 0.12990146905424135, 0.15645072104469424, 0.09360788510211053, 0.1625622947129511, 0.07773376956221559, 0.18898282861036642, 0.22503679558154077, 0.11902545668905783, 0.29640101136699804, 0.10513096597165832, 0.3328745493725423, 0.36707001768292924, 59.2360540359251, 125.30118988406275, 95.20423950687533, 86.04555222295946, 66.12383411776635, 88.4001902611025, 134.20744126842868, 83.33185257450228, 32.728758781187, 88.65225745785622, 43.06250579895512, 0.3192842415263576, 1.1299418129267231, 0.506660491828957, 1.8745749852349682, 0.744791844439122, 1.1546963813804811, 2.206283211708069, 6.2134614010011004, 14.174808417597125, 9.232152296650796, 12.213714526545617, 10.818984412377882, 7.375156148787468, 1.0494430098802814, 0.3054746180292099, 1.0255307704210281, 6.248109167621982, 8.644426311216048, 8.134731467693083, 0.2208572343712853, 0.33589915642815255, 0.17963154571911982, 0.19866178262858622, 0.21772575805023794, 0.14023875306931236, 0.13171830785370645, 0.2705503855982135, 0.25043365215101554, 0.2878454333591846, 0.326357745835858, 0.6525513649948183, 0.719789308646033, 1.4433298740656146, 2.5075205054975327, 2.7081735191806673, 1.1648044518886076, 2.0098645192000175, 2.075445935610802, 2.885073639692799, 1.193000655020437, 1.028594141525607, 0.24957652233781355, 3.4109916513965977, 34.433205127716064, 55.64192741147934, 53.7001423681936, 48.917419910430915, 27.099286817735244, 18.037782138393773, 8.154624258318256, 2.9421247589972714, 1.0282399024694198, 1.0135816374132711, 0.87901804836527, 0.40920908232369735, 0.377705677622749, 0.3201468565290974, 0.3740479142194794, 0.10908201081498016, 0.2640863501977536, 0.18476811928614495, 0.14155685330831236, 0.34223822756640376, 0.14099043854061635, 0.13956490213111525, 0.13160543245894293, 0.36737577869526805, 0.18565466687563928, 0.19375449917729826, 0.28050260317902415, 0.10318964554537689, 0.2052540917910876, 1.173497404783003, 1.6543175977083946, 1.826189239659617, 5.070734254775509, 6.6631263302218535, 2.5908735682887416, 3.1640862937896483, 0.21580083956641538, 2.422528627418703, 4.632556476900655, 72.18456283692392, 43.04032871800084, 39.38300486533873, 124.23113592209356, 111.8356538588001, 45.09023781745665, 45.30919628758585, 74.6558992324337, 80.83639360243275, 65.24814144257577, 0.997551400815287, 0.3154514117106315, 0.11263554795615136, 0.24833935162713452, 0.16809253022074702, 0.19116150605822765, 0.26732463449720417, 0.21724761193317754, 0.2423841211824648, 0.22827138733719626, 0.08850719509345871, 0.17568516635125683, 0.14291408531848462, 0.09990147360029722, 0.11282364552419995, 0.2439488251242907, 0.13153867555722115, 0.24917953557545142, 0.11348747603234746, 0.2036543623093636, 0.11990367690281523, 0.16202033347179814, 0.0869728435551928, 0.12959714828720018, 0.1778242217316743, 0.11744867920154527, 0.12476254359728868, 0.12745849127250333, 0.13737416645932582, 0.14813741068205527, 0.21573058930375885, 0.146776991746118, 0.09842440245612975, 0.1557103430311526], [0.08484126519291632, 0.006303219659809745, 0.055697824986230944, 0.0908828950336864, 0.09246359489137128, 0.08068174484276003, 0.02426598247350945, 0.05162198058960419, 0.03848505889876716, 0.04914880745233067, 0.043264348210105975, 0.11237886253624194, 0.08307560106679317, 0.03212345711466286, 0.026570780976344983, 0.035582524123451406, 0.015303449941829089, 0.051927634349633614, 0.0411956963099299, 0.03706326099833654, 0.03337006602856902, 0.029855838774012464, 0.03834549300072174, 0.016839077974098827, 0.022852450661781817, 0.035805811940301815, 0.031081039360874606, 0.031887538423160874, 0.06008047993565279, 0.04542953484962064, 0.030011820021055402, 0.04582939061125921, 0.0366833311836085, 0.03258931518141781, 0.04072300473889036, 0.056762629744386485, 0.08835590038929256, 0.2646391592439144, 0.016353929813410488, 0.6631963712073142, 24.260104663910408, 74.21774694996496, 74.369825086286, 60.965262305352, 23.03772153392915, 37.336570985855595, 102.2050662194529, 75.1603631050356, 27.001921822947843, 47.854669401722575, 52.86916471296742, 0.23272137758472275, 1.7474699669307279, 0.3469508327543736, 0.19501204782676315, 1.305804711676413, 0.4257903200003409, 1.2455852978652524, 2.585695549365013, 3.6480244032798277, 3.658989879392809, 1.4312867267477898, 0.8612481793088298, 0.17893820550412903, 0.4057131473335528, 3.7208270257519143, 1.2784031562266813, 0.3782192936107036, 0.13821330852806568, 0.05330078949731204, 0.01913977790653946, 0.055164976360937285, 0.025008172284991994, 0.050198079777821425, 0.04536012728368083, 0.016017998343393687, 0.06670846198234828, 0.05689475309824752, 0.048681298466098887, 0.041168289514438766, 0.1249322320725168, 0.08181422963858613, 0.07482699449023894, 0.06181748854296823, 0.5032042708368071, 0.9575994252677887, 0.6274272970134213, 0.577986617722819, 0.23231594853343504, 0.06642976685637428, 0.03909812842105185, 0.27669827183408124, 1.3801787336987834, 1.6520358814347176, 1.999590483403975, 2.1107600148647063, 1.3790244537015117, 0.8663459735051279, 0.6935112671025339, 0.7787442483728932, 0.5778518475351796, 1.2368543470098128, 0.43344807360441456, 0.20783778460275745, 0.1540548270267825, 0.01624790515990988, 0.1289504321832811, 0.17023164688819842, 0.1126964596070109, 0.06968462163762701, 0.028572438487542734, 0.097657012182378, 0.05122231634994669, 0.029357795438338673, 0.04834482881931528, 0.17209806689812293, 0.0829133666270683, 0.024532604053796783, 0.05418418463499797, 0.09262026753276588, 0.06311464776855803, 0.06205063974184375, 0.03357204510980556, 0.4357493097984022, 0.11865060986770738, 0.24374656259052216, 0.41746144273108055, 0.012381119454549927, 0.1059190329584864, 0.31447691722742976, 11.664292447028622, 50.19517121776458, 20.91215383621954, 40.14712572097778, 110.66350060124552, 84.78907585144043, 27.162454628175308, 37.036376307087565, 49.94217441928003, 32.379767856290265, 14.876927387329841, 0.46729913942756196, 0.090033671247863, 0.06284654380813723, 0.027967043251039523, 0.12013019378026647, 0.05002350749207601, 0.0564532068317696, 0.019654744124460607, 0.05801050270336771, 0.03904485849723701, 0.030162902135822563, 0.009935436424829308, 0.0250808721137864, 0.009491244282182908, 0.08125621119454023, 0.029646072409025608, 0.07232137369893252, 0.05288826647184549, 0.033445851276478464, 0.03440489759668708, 0.01967859435676327, 0.025645710655578205, 0.04886566901639585, 0.019325920035161318, 0.046005958556047374, 0.05785321719163369, 0.010027394746430218, 0.08529118863084624, 0.062210468665486386, 0.048779070437435186, 0.03532139156314154, 0.07093076323789936, 0.024271902417944326, 0.08983674834692672, 0.041688520671619524, 0.05200003348891774, 0.01560484904104904, 0.031391643964114695, 0.06980740254925144, 0.049963204881116274, 0.03340566613441033, 0.05158609703123089, 0.04708510064970582, 0.013222587557749884, 0.06516287193423317, 0.07568959417122026, 0.0703728060808874, 0.05490146509762253, 0.08358581562436397, 0.06592191184961027, 0.07464004605407677, 0.05687804855105858, 0.08919046125224522, 0.06208499112436849, 0.08592350228178887, 0.0506026623019528, 0.05408238687161958, 0.05851994351213498, 0.03613439854234457, 0.02710044842153307, 0.041875281416240244, 0.015364499488515, 0.02591548468767395, 0.03095788881182671, 0.027224928133129597, 0.026401010146665, 0.082431091296096, 0.08117679085943007, 0.06775591101857924, 0.08372770276881995, 0.05588866514904846, 0.15376233465729222, 0.19031022915676718, 0.051065850552291646, 1.330555112611863, 47.435207213124926, 96.4177502355268, 79.00117151198849, 71.6508851512786, 48.19389166370515, 88.47796301687919, 99.8150719365766, 29.24848483454797, 42.28542150989656, 84.30937782410653, 30.747063621397945, 2.1095217716309334, 0.67732107134596, 0.19696073035799688, 0.17173265827999962, 0.6749898964358915, 0.5068197768301733, 0.5720199572463189, 0.31704021677855526, 4.534437406447626, 2.8987279005589026, 2.4985206271371534, 0.2825525012468138, 0.5780314185446309, 1.0661970463491257, 1.2805084884166718, 0.6767226647465461, 0.17055354171222256, 0.17969208198689646, 0.044298302607550744, 0.016406581121226473, 0.017741169487576813, 0.030623060508420875, 0.014764552094763326, 0.07564044196999843, 0.05434221325201854, 0.06500161042617214, 0.023081524357680353, 0.09706302591028715, 0.030690029999541662, 0.04436958325846542, 0.07771128488163795, 0.03549720491132429, 0.19307779839202283, 0.7212001974544218, 0.42602416067834825, 0.2262067650595019, 0.4352392791019332, 0.1329430985835291, 0.0716219813893399, 0.038600209574665756, 0.8556017435846791, 2.055959845742872, 1.9004610349093716, 1.454701805787702, 2.915294766426087, 2.2466512649290027, 1.8581729814890895, 1.1468898841450292, 1.3490270246421139, 0.9245050398092117, 1.2278804543518251, 0.3775546970146318, 0.5808701726698107, 0.08608268769157511, 0.02778933575046399, 0.10019112378358842, 0.21258916916145434, 0.011636378570279528, 0.06653655185213973, 0.026330062743997382, 0.10144068213600306, 0.03059931752842761, 0.06347184009369343, 0.0792467702300318, 0.1194800609242051, 0.04190889735435767, 0.04868981736381689, 0.04500114614324224, 0.11981750733309215, 0.0635285152783317, 0.06640954979605253, 0.0025831912634819145, 1.6456889961996388, 0.32231096298463885, 0.24285670550119495, 0.3257772963373892, 0.07957159917080596, 0.25309910186596457, 0.5007266812026501, 8.48993395605395, 69.14901702634751, 41.21620693514424, 22.44683804050569, 77.68643225392988, 109.3932096419796, 49.39289354508924, 33.32264877134754, 48.8777647479888, 56.98963811320644, 25.42002993245279, 0.42976772592913726, 0.19945135880862513, 0.05507023426734152, 0.05542066203610552, 0.031842046206997286, 0.01941528802196826, 0.03924733936606396, 0.027746101578457222, 0.08385523342557492, 0.04211040912196041, 0.05191413588040779, 0.08086800379979034, 0.04750712316543345, 0.020262998784141197, 0.06009882008056006, 0.02617843287636436, 0.007833709157327371, 0.04250835732466752, 0.024499595240359346, 0.04538090358818731, 0.042301299080492995, 0.054207573299326246, 0.006565274877263414, 0.02766710259170542, 0.035447566244270534, 0.04871206072669837, 0.05336651984121531, 0.05058045724346753, 0.029825258459294998, 0.015187701717349551, 0.029034257355716922, 0.03804620926178271, 0.03194038891383717, 0.025668453890830282, 0.05074387911947505, 0.1893892382541972, 0.10804974564140844, 0.32732044256502585, 0.2226758658164932, 0.11428637550242486, 0.183465892388936, 0.11641276744945396, 0.10480289647896444, 0.1485585751793077, 0.17534615712300425, 0.1786415149728137, 0.21719657515566196, 0.199427564117697, 0.16141054280582937, 0.1653694400503751, 0.1346304378802738, 0.13275790448871352, 0.1321988441650906, 0.1743290987947295, 0.12729763579104217, 0.12634247736704926, 0.16533778529734383, 0.19434378933041327, 0.18376362479982838, 0.31968839887169104, 0.11133826998693329, 0.14023372753252908, 0.12883409407109986, 0.14491884548577572, 0.10719541971000934, 0.09359318387484358, 0.18069899731105377, 0.2618296083904082, 0.13703118889562546, 0.33859406988466945, 0.13755058118652913, 0.183076765688677, 0.22839321063891535, 0.14962112380852624, 1.0540329184262984, 55.59337239111624, 118.45918778450259, 105.07714333072786, 96.83540421147501, 39.15062012210969, 63.50282792122134, 131.45351379148423, 100.23109420653313, 38.08901494549167, 71.73667523168749, 81.42128175304782, 2.249762194771921, 2.6939105554934475, 0.4742917142087414, 0.25866557333257895, 2.9871376339466345, 0.7903495611202332, 3.6330443812954814, 8.390132188796997, 8.472340164646026, 10.62272567902842, 13.847394451018303, 2.9524609398457313, 0.7248217708641483, 4.614871980682496, 8.647760325862516, 1.7319936425455156, 0.6325291974409935, 0.38884119461140326, 0.09629449416552821, 0.19524636347928356, 0.3600216410573452, 0.16009326994178757, 0.2242806208350005, 0.15688877011979782, 0.13447708239959133, 0.12520482913861353, 0.14758812564034618, 0.2402453415937001, 0.1785177764512839, 0.23631011646601463, 0.14609330423897313, 0.24815696141412183, 0.21453183024160324, 1.2982396853546943, 1.0812361490341926, 1.1290835493033933, 0.7839089680102564, 0.3784263518548781, 0.14333479016298248, 0.21214701385507662, 0.8964720440487709, 3.1197188938817675, 4.356605477871434, 2.641752592978939, 3.940475097587032, 2.8025025994546953, 2.3583939527311633, 1.6460116111463117, 1.409652771488313, 2.004085642195517, 1.611660596343779, 0.9984186123455725, 0.5445276969863523, 0.2280205241855114, 0.14275093923412985, 0.3564230502853471, 0.6974226668957741, 0.2739168517291546, 0.2783064742482478, 0.10889591273641396, 0.19025376847674771, 0.10630384658373172, 0.2103878155110344, 0.13069853757417974, 0.331157531829611, 0.17054843956664686, 0.1453239681018937, 0.18513650032541445, 0.2695343078624818, 0.2174225864150832, 0.12800471962339457, 0.2098588624428357, 2.962338693680302, 0.522638665091607, 0.7890904190078859, 0.7281818325000425, 0.2163476424832498, 0.23442388542236822, 1.2330214559070527, 15.98612464243366, 68.67986233003678, 28.831531001675515, 54.51818796896166, 133.24619385503954, 110.6647792939217, 49.35689010927754, 61.501254189398985, 79.98667486252324, 74.36853070412913, 46.31798282746346, 1.006224619284753, 0.4196229751311964, 0.16259719767878134, 0.14496140933084875, 0.19446792621766368, 0.18572954430935845, 0.11104999876190579, 0.186713308456444, 0.17664777114987376, 0.07929301129714136, 0.08626248852740373, 0.13504340523673644, 0.10268227317400518, 0.19390353392208778, 0.16078374498794157, 0.2615319985535837, 0.13277852757563516, 0.13396343576811975, 0.11968040823816292, 0.17467451251802907, 0.10522840469474755, 0.15184365212917328, 0.16417484850652758, 0.13666962603888205, 0.15439752879883015, 0.14848602665287836, 0.10749966386825809, 0.1953429978100523, 0.14250306382534966, 0.1950573389448466, 0.26089697295138914, 0.182593900470003, 0.2498052608702452, 0.23756806348120016, 0.15379239594744099], [0.03770382924666328, 0.06743741762493888, 0.012904648620244718, 0.0186290864592358, 0.05744992935609433, 0.06539265234624186, 0.07368595249229863, 0.08591785621378692, 0.04881299281072232, 0.03652840905312089, 0.02863587631333259, 0.04278021894635693, 0.07624832507703574, 0.03520396177566821, 0.008809403046935557, 0.045772964405196334, 0.062407035335537896, 0.035417769254455646, 0.06134570861655859, 0.01595636752749523, 0.08524258801292989, 0.028280876914880453, 0.04567954381326995, 0.08155323880454225, 0.04103790134972623, 0.014407390413144905, 0.04597667484514175, 0.052832751910412507, 0.04316323226498019, 0.08877931718504237, 0.05954796072816657, 0.02361091792643551, 0.057142923450878555, 0.036221560195929585, 0.10400406595680023, 0.015268234795169726, 0.12150936654859013, 0.04507323884735665, 0.04312983849236081, 0.14744066903668065, 0.3317137423061556, 41.797329610393895, 99.9916099732922, 58.060959000741285, 51.82850107069939, 30.96634960943653, 37.50631939980292, 100.04557394212293, 85.86564879263602, 22.103891488044493, 30.968977597451982, 60.49987700677688, 12.644764377224831, 0.7627085572288883, 1.2715980891258487, 0.40277982731499984, 0.08720081599970018, 1.6852244037774302, 1.482966772971615, 0.7589948081201123, 0.26267120194050575, 1.765367742027006, 0.5728742372124427, 0.2558878764149643, 0.09226929967201526, 0.026330202555043564, 0.1723096603828092, 0.03456992059645634, 0.08664482768865363, 0.05706216629234053, 0.03547275138478126, 0.09807247698547379, 0.043788153167453506, 0.01931477728630266, 0.030884212220928846, 0.04132589678310099, 0.044949527138904224, 0.07772256169588336, 0.1042551589348624, 0.033454251430568197, 0.06829994069712778, 0.008578340395263607, 0.05434521631668172, 0.057514139015467904, 0.03813343986328091, 0.023742832521337177, 0.08771077008737672, 0.01647794412659301, 0.018724115835803173, 0.0713479747214625, 0.022795626089998314, 0.9021331273740338, 0.9201355807242856, 0.3265602994830378, 0.6258300956218474, 0.3981322783135599, 0.31566511959798876, 1.0928305526894908, 0.8265105658961881, 0.019473562415148464, 0.12363650160090578, 0.15284019462283582, 0.022322363783455184, 0.04500577714474452, 0.06056793402099322, 0.04103519705935352, 0.041427388111309665, 0.5481760528299117, 0.6599998233779785, 0.03870473078061496, 0.03230690452901106, 0.07183218059400398, 0.04537178714188837, 0.067970706750789, 0.05578132090909828, 0.13430742456788017, 0.0842798223358489, 0.06298620163673355, 0.06252352666530399, 0.05078456604913358, 0.035614512124729734, 0.010863892854221407, 0.012908801774404222, 1.005556835762916, 0.15430938272226244, 0.1799263976394169, 0.2641788936190067, 0.23905957538274028, 0.25374934197433535, 27.73485983571699, 52.65583092166532, 25.717867266747263, 63.83203637215399, 115.94756864732312, 70.06653001231533, 20.462693360544023, 35.85935146577897, 46.440203882032826, 18.484398895694365, 10.964287634818785, 0.3880437277257443, 0.10907641071225367, 0.08544164829917493, 0.022287922385599346, 0.01483303652475438, 0.05628297060367562, 0.055210072126600056, 0.02427543408327526, 0.071157923629207, 0.03913714527903546, 0.08411139790569583, 0.08527747565700163, 0.0414009963823182, 0.022359396473714904, 0.09774430024047052, 0.012788655247629411, 0.012793636734357045, 0.025561199666211204, 0.04691600206217939, 0.05176732279059868, 0.046957933884714885, 0.09325487178660209, 0.03926412052204532, 0.018228133276645696, 0.08987213394814923, 0.018968607051177852, 0.04730551563684018, 0.046293904193707054, 0.008021696600236841, 0.040125888997628804, 0.027163530016438137, 0.03443610035784302, 0.06826072465628386, 0.032471916037461454, 0.0400941193314089, 0.046769706081719174, 0.024286919656480034, 0.114266533825186, 0.10249380788375294, 0.12016066875789436, 0.04452225692089527, 0.03624474201651831, 0.04042013953890532, 0.022751633490946506, 0.011410232287861649, 0.06945090353368752, 0.008494719025498677, 0.028174024886421623, 0.09613792111556377, 0.06820166693820108, 0.04803791867509004, 0.06792091869659002, 0.05107320499636474, 0.03974196786481527, 0.05175915629332585, 0.03692110955354668, 0.043708522158164176, 0.040241610409030994, 0.031127542813098243, 0.019122364728020567, 0.07601479083419808, 0.007170723739921326, 0.020756202359353344, 0.1095710966675993, 0.019980898397343776, 0.06038409590180363, 0.02110349491328722, 0.024146392318089644, 0.028239199816579783, 0.04617649355843183, 0.05593517817737115, 0.055572676862920486, 0.07690348346988041, 0.020968761114824205, 0.011750396393660096, 0.11013699815638604, 0.8191870104882025, 64.60983453258392, 115.24191071910244, 66.03512579394926, 33.6709983887211, 37.34887938345633, 79.99655139061713, 105.63954845551523, 42.7912268330974, 32.920770568232385, 79.07319407309257, 53.008891305615826, 6.833467022065194, 0.8124524234764038, 0.8382636416823634, 0.0765825845601578, 0.30542675285570087, 1.4219918126060118, 1.126220831947942, 1.3296931717664966, 0.7181586445339265, 0.37313044732136114, 0.18937930975469852, 0.46567365406982364, 0.17172688197705055, 0.14431752775224949, 0.3040960274877087, 0.029575799163731358, 0.0625055963774362, 0.06492828815093925, 0.05879881100789194, 0.09192351822651203, 0.07557869528330143, 0.06311810282509654, 0.028251221651331555, 0.019681394408126513, 0.07462182848323738, 0.07424978554368981, 0.03460683454308779, 0.1008404139429331, 0.09806772724034325, 0.028586586216284383, 0.00978269094165655, 0.0329873476537966, 0.08719208259736339, 0.029075300516260248, 0.04895602525662511, 0.025343343412743944, 0.07343229311969011, 0.08230207442876794, 0.08315889014592094, 0.9800786512993998, 2.0464440531307653, 0.5568272079671583, 0.8440887291104564, 0.35725155905369793, 1.2390501388619024, 1.7574683336480972, 1.080015433892127, 0.5057550371894913, 0.065760895489685, 0.09913337086477589, 0.06920118951388905, 0.11069966675413233, 0.0422590263488312, 0.12723459441575313, 0.12114585782851904, 0.8017828411632969, 2.9432914189753996, 0.50566804024481, 0.10176604733832421, 0.11581140375065228, 0.04290581906154271, 0.12599065148782346, 0.0844011323586587, 0.044163218323862365, 0.055796420502085844, 0.10382323090227381, 0.1285362390861396, 0.14802692548161553, 0.07827357043542209, 0.04125451654075615, 0.030644943809977947, 2.034113101901547, 0.23952966225483727, 0.5756264540456957, 0.2169571880010828, 0.9245351317428774, 0.42462130047140584, 24.967074624953735, 78.51010645589521, 33.15249635327247, 30.99128019425177, 95.66842063780754, 96.088561396445, 42.78510009088824, 41.4585623433513, 56.744544890619096, 53.56125516276206, 17.060251005234257, 0.21658011952475195, 0.20399830514384856, 0.041511496904516415, 0.051284614619949175, 0.2146671979778236, 0.025302698617921244, 0.04749533690271839, 0.05434604752207956, 0.039153945587214925, 0.043726176654379216, 0.05975089741930847, 0.032696935213020736, 0.05126314117543159, 0.08430785349299831, 0.08139031488568553, 0.04843857882904911, 0.019008928173852545, 0.02485863958305169, 0.08057914268706115, 0.08254556781462125, 0.03464765553813308, 0.07952191836891637, 0.05148609191359532, 0.042197670366975575, 0.06998990001457353, 0.0285579709170927, 0.0525889176154329, 0.04787448913820329, 0.06748117656717378, 0.02622593607332918, 0.03128112045927875, 0.012807948214392509, 0.05543078588802488, 0.060550287185657414, 0.024115302554902532, 0.024512567024137226, 0.2754265965232926, 0.2261227711794838, 0.22478458411510915, 0.20424754418913396, 0.13736975379288197, 0.20281053178252714, 0.10568852476294964, 0.13084394106220815, 0.16865116153513232, 0.1320436347516314, 0.13302002913288533, 0.11864703989798024, 0.148393222761731, 0.14864715026511302, 0.1449463480422574, 0.14355733870498597, 0.12286089120372651, 0.16644686610708315, 0.19067779814283695, 0.1818919647485018, 0.16095847432171145, 0.09289615111605776, 0.1588882136368944, 0.18533240432941145, 0.21351406711243817, 0.13168835381586708, 0.1423533242796698, 0.23349659727706065, 0.09330223900296035, 0.1506428705948976, 0.1519171046393533, 0.06721543598799937, 0.10219836607575418, 0.09880939228159767, 0.14328393724656877, 0.2146812633521134, 0.35214791194565837, 0.19206821708188904, 0.16046437825406754, 0.18147456940383683, 0.38878566855865143, 66.237229839448, 140.024535886703, 88.39563246696227, 84.6866000083185, 50.5417126224887, 60.13366099326842, 129.87482255504978, 115.555888606656, 31.721800065809685, 53.96234496947258, 88.13663051974389, 23.96398336656632, 0.727033619919131, 2.560330807201324, 0.6663376381320338, 0.4331301471158382, 4.0265819093873425, 2.5740304204725453, 2.2843964782453354, 1.7963440475925323, 4.269970616986675, 0.9244873278564023, 0.6641416624188424, 0.3702182100424844, 0.2778837469316298, 0.6487844187405802, 0.19529948401595318, 0.17495814891111466, 0.13617407440418197, 0.21731168752716434, 0.18114490644826045, 0.2619686073833897, 0.22973228636528217, 0.14399923354146943, 0.129964655986236, 0.12020956048922193, 0.27734766924573534, 0.33446755260229116, 0.15020613919102377, 0.1729042978296357, 0.08651116832850442, 0.10642927815957416, 0.1532602253099603, 0.27508354235079985, 0.18826632189654535, 0.1737311212045531, 0.09273852852563705, 0.18344683212137994, 0.2711210904582855, 0.3415612203459586, 2.7754458448579236, 2.0956772758114726, 1.078373676826877, 2.045163399269504, 1.9336312937159694, 2.6303885059971965, 2.8086553273662447, 1.546114603838613, 0.7214055090181289, 0.24834180310849222, 0.2584931116190649, 0.11213041256151854, 0.2595937961051541, 0.15613061886641288, 0.1117088880029417, 0.22833719428989196, 2.5024760923077984, 3.701550537540067, 0.2137899966610055, 0.15720421448349953, 0.2212886644467231, 0.1478535291408339, 0.193847410320755, 0.2799944110935734, 0.3074153945330651, 0.1772930163649782, 0.2252206413616096, 0.3614550834942249, 0.1949640600791862, 0.1956809345152109, 0.1658472797322658, 0.16495691702490853, 3.010792713011465, 0.6808146161417807, 0.42587045279722063, 0.3734794156926294, 1.5090903711895791, 0.42049622343432524, 44.502639309052505, 78.2950193651261, 35.31033731275989, 81.55143384010562, 137.1329802851523, 95.38988528713104, 41.84403327203567, 63.095909472434755, 81.38379958368118, 75.69666877869638, 31.357921784923924, 0.4585046952049579, 0.3374324967303584, 0.13307593822959932, 0.09402269873047069, 0.29582828403480593, 0.1903808011763519, 0.09262527774779067, 0.16292618647698434, 0.16568237164568517, 0.08978978715716832, 0.16645049736384424, 0.2746166883697433, 0.1521307972049521, 0.2379942075499604, 0.12450080965795826, 0.30928137021199353, 0.09289301781644745, 0.09866063332846088, 0.12248066644514762, 0.17735418082485277, 0.11152429145670707, 0.12363773500246387, 0.19774272226758544, 0.11344272117581099, 0.16502396504004158, 0.11482718761169142, 0.11999625862846452, 0.1555036984744572, 0.1731996400462043, 0.14524772703166933, 0.09036534901468024, 0.13219847644288696, 0.1242475180075534, 0.11034453137507362, 0.08245615003209922, 0.19616448921301674], [0.08108559575292372, 0.06190219488475592, 0.043889728765333855, 0.0669135667023159, 0.03200951111202519, 0.05132103060942985, 0.12737313375598, 0.03792663825856101, 0.022986452846277147, 0.018548995797191898, 0.06723841862572778, 0.06192732639911194, 0.024585743742664496, 0.015614775625327903, 0.028661511530498826, 0.05082039215091256, 0.058125385248492804, 0.03811260993261972, 0.05663749311239489, 0.07572769938457398, 0.07146399873759478, 0.03575169165889102, 0.017699542184991222, 0.09433693267525205, 0.05591278542734443, 0.08558097670996383, 0.0023368195416556014, 0.037240051108622746, 0.018696755005587495, 0.08711570363131263, 0.07898413230695071, 0.05287165385520747, 0.02633204691172127, 0.007559428613017043, 0.036944544183150414, 0.025757881249451352, 0.036399698620962526, 0.15021531692435666, 0.023353031663704785, 0.037087967333894585, 0.12193968579653772, 1.0924706752261808, 31.644182243654807, 87.00075918628325, 70.94096752905077, 62.862481378739886, 33.63952529045844, 37.10588462891118, 116.75490225515058, 103.23304883895382, 39.590627685669936, 27.157590889161636, 55.202786691727184, 42.485795790149325, 2.7011953774959814, 1.5906020037589537, 0.3679345019402043, 0.3439473390819565, 0.21888477247088187, 3.4532323912266767, 0.501593525010732, 0.4163491749955762, 0.08313341772243862, 0.6780022767282302, 0.11533879644928441, 0.10459055222811238, 0.06978352358865161, 0.11007188068282221, 0.01946514119364081, 0.016536513463624062, 0.06585700888066523, 0.022874575281035037, 0.17202530386707476, 0.1221385392390432, 0.02024727482949534, 0.014663462005104991, 0.05347308650192234, 0.06272693067007969, 0.01048807405881704, 0.06749212396361175, 0.07440055164718822, 0.008083414079831734, 0.01525838481968329, 0.036969097301123605, 0.0713909982192901, 0.06161241063607797, 0.10583605031452833, 0.03333042863936674, 0.03592503437351796, 0.04698965758565934, 0.026764764014871854, 0.5166525766253471, 0.21622352091775787, 0.16083170209200154, 0.043404442708819144, 0.05246051361844425, 0.06095173257973887, 0.030258180490965327, 0.12731408369877648, 0.06914369461517181, 0.02874873638633759, 0.15166591973074023, 0.03319392326257883, 0.035665319075868014, 0.17201298517325234, 0.12072309986838411, 0.02358878756152286, 0.07550500528586489, 2.4947504939571505, 0.9481779534009196, 0.11903928457609109, 0.027376301361307986, 0.09264321952697732, 0.1028821914787254, 0.11397910529687522, 0.10206341202701293, 0.02692970274496944, 0.02072211144672286, 0.010325878881098283, 0.04597511968665546, 0.14479495374666107, 0.10570245224141306, 0.1320753354699381, 1.1380138055932139, 0.3386039064536172, 0.624514508151239, 0.49155060261968647, 9.913744522679238, 60.72709598848897, 57.002644692697835, 33.26270711037421, 93.18232044096916, 110.78449787632113, 55.94605622753021, 25.141957421456617, 37.774766414396225, 45.04958637299077, 20.099801555756603, 5.9486955308145095, 0.1229043283890332, 0.05976550671602449, 0.04455108480948595, 0.07556797005236149, 0.03158935402039319, 0.11388275441863846, 0.036177360753138224, 0.07097607733862055, 0.013655563215574911, 0.03296585888752053, 0.05119877446803355, 0.03559026927236588, 0.025765568941771507, 0.04646390293454451, 0.022610062357759284, 0.05549979891868369, 0.08738285381226771, 0.056640132285294034, 0.03321648838238851, 0.1113177618132003, 0.02997412466474118, 0.008565783256574745, 0.05563689035273368, 0.030992676864468285, 0.04024616480174084, 0.04104424838817889, 0.015707594838233727, 0.03923826888504048, 0.06673256310844614, 0.0067691241706451105, 0.016833362958183693, 0.09154014484656435, 0.08715668933526163, 0.04053717479109764, 0.025109903015677008, 0.12765768945457476, 0.10179957134589072, 0.05484651361081389, 0.01106777374872998, 0.023821525072919267, 0.09024458291429667, 0.03141547887465887, 0.01003355505095134, 0.04593876115376911, 0.06128081713893241, 0.0743770327479128, 0.0023978006192332795, 0.014307878464610587, 0.03780633564137163, 0.03694968846356196, 0.0403764495445836, 0.05051127950390501, 0.005919337310197373, 0.034708616984707695, 0.054653742906427195, 0.027844813922720573, 0.007358906056446534, 0.031140066435440417, 0.04018615330419233, 0.1070549191846963, 0.027322813102434722, 0.0366958950255667, 0.0380800511958378, 0.020059732675191858, 0.013916072371836393, 0.03646871931250057, 0.0645186992422227, 0.07186629448927219, 0.04855833752381225, 0.052953012392766056, 0.02961788803429133, 0.03911756407169085, 0.061175912889021064, 0.039092781127340374, 0.15131483695680095, 0.021338287455540512, 0.033727656719425035, 0.02278898793813442, 3.163877182429837, 59.912643278798754, 113.65299778599893, 75.80049391715758, 41.91558514871905, 36.12071860221125, 71.97300587930988, 117.20590422230383, 47.10366887430991, 28.025095616617513, 60.12902867409491, 79.4695338895244, 21.209585205201183, 4.175589075011592, 1.0314297700120558, 0.5018382441372641, 0.3542174831513436, 0.18541287420497787, 0.2718129904279786, 0.9969291535596695, 0.1645067944041183, 0.018386694324773648, 0.30168202315126696, 0.143847961819941, 0.20998008819597386, 0.03275553327834895, 0.1767970970080745, 0.14603422353825263, 0.1031071761803281, 0.02903271751898912, 0.03350030863657594, 0.07158782918967548, 0.05043884589066429, 0.003548302845428548, 0.018314379455161192, 0.06025604813569977, 0.04429541828651582, 0.023547916770762494, 0.037769011837700685, 0.010481257791510754, 0.009763155699587397, 0.0651544985932208, 0.0435630037569471, 0.038565482809058124, 0.03345721236039554, 0.10458519727352167, 0.04749033051813322, 0.035088087146681164, 0.09491523712753289, 0.0816442347281883, 1.1821180389773462, 0.3206037207236213, 0.2224595379084349, 0.036002037701227015, 0.07272428998182859, 0.04990253071751326, 0.07203749215771114, 0.0989420174230491, 0.016761306643245683, 0.03923198313362176, 0.08036691334939773, 0.03889387788911981, 0.014182597233523286, 0.03478642087429762, 0.15540461266233077, 0.16737564046296383, 0.05623335491925959, 2.68630606032187, 3.94286627250333, 0.527979155942317, 0.10926903585993475, 0.1721126685339597, 0.08424899495777585, 0.0703229260961375, 0.13318654600410693, 0.1423778237714883, 0.023014089468145565, 0.03858735844973595, 0.08824700099085608, 0.19480578631402987, 0.09559580665682593, 0.7170905953934117, 1.4353150009147584, 0.5017479989797838, 0.7841433296280523, 0.8067103799793028, 10.164768368967119, 64.91100195915469, 75.90868857599075, 35.71094859030939, 62.5111742942564, 109.90048977636523, 82.17707541681106, 43.89734698880104, 39.27669294418828, 57.112659331290956, 55.69473035873906, 14.981922372694939, 2.00941062742664, 0.8515262171145409, 0.03130456083454192, 0.08238577719537482, 0.09176031085512332, 0.12457690517147704, 0.039257892227220925, 0.02789352753860576, 0.03569703894637285, 0.03223934323496876, 0.009604105312797812, 0.024312533806228352, 0.046667804896471, 0.06087066898603113, 0.02826702221476984, 0.030710572647231243, 0.012059605759268087, 0.0406336329216438, 0.023227504326871807, 0.028846119568052313, 0.08049461254549604, 0.02734094448838263, 0.0363416712911379, 0.004910249647969801, 0.01584742695183283, 0.02359938638795528, 0.03434663277960593, 0.05839011076116755, 0.039365611850254, 0.04389476196299638, 0.060879456014522625, 0.052335989856792074, 0.07875934678820834, 0.026173397763482025, 0.05356164626596917, 0.045082090993321715, 0.04296995211212386, 0.15801225338251362, 0.13745921754067944, 0.08646496556579106, 0.176395145995963, 0.11550793334120706, 0.217282775368902, 0.22627136159327724, 0.12316515834461297, 0.1407499788629432, 0.052364453853618716, 0.12595011011487053, 0.20124984214142447, 0.12101300286069033, 0.12839999800968555, 0.162293060772842, 0.13015349665957113, 0.0740382916504337, 0.13754034625186076, 0.11717759132865938, 0.1145562529563904, 0.22521849631542162, 0.13963228722493495, 0.2536239946681646, 0.16138725373293125, 0.20214889228584307, 0.11558439657692948, 0.1389282677442797, 0.11003739906535034, 0.14494024998238011, 0.2178830665446097, 0.13359102510636853, 0.1328465102180358, 0.2533104195589981, 0.06794752493020027, 0.11488467484952943, 0.15082880013412045, 0.17014639662398448, 0.2891427879371951, 0.09978970903302394, 0.09366357969420572, 0.31547497657518236, 1.9424030617360148, 56.39080593662878, 136.7819595336914, 107.5351828913535, 93.2541625730453, 58.74108622151037, 56.58790503778766, 138.43898834720736, 130.89757273274085, 54.78162611684492, 45.92811884418611, 90.11914545489897, 67.23506512180452, 7.094552238141337, 2.289991248999873, 1.3614892526980371, 0.39977722230457496, 0.22002216789030263, 6.0410286149671, 3.6837885745110053, 1.1894719927541673, 0.18506390583370963, 0.9551782197048588, 0.2554530602309012, 0.2887952598112245, 0.15754877018832392, 0.2567861757932171, 0.1994589737225925, 0.1595314976669127, 0.14684796213142334, 0.1882349889004423, 0.2216275817444248, 0.14150966229217668, 0.06367943842985457, 0.15803289179119373, 0.16449734087913268, 0.17758602967425702, 0.13594412545282997, 0.13030550382550687, 0.299628172069788, 0.1820725163504962, 0.15522222244931808, 0.09330978496901451, 0.16813582951022735, 0.18681306842594378, 0.257091844875005, 0.16312100263612886, 0.1448246319928477, 0.17775348117274625, 0.15250886159558452, 2.1904679700251553, 0.6329596775674051, 0.4417914452572023, 0.12117102381683166, 0.5735152995874805, 0.16663224406300053, 0.20658054238846227, 0.21595751986868922, 0.1837820415535281, 0.20332013346975852, 0.3486797706254067, 0.20181604240450168, 0.09012547922470877, 0.31089704964430104, 0.32606332292479856, 0.27900156114370595, 0.1981230696002322, 9.478879186414904, 5.229441686984032, 0.3595358187392835, 0.30073510783333934, 0.19953291652904404, 0.27556979367809914, 0.23667434530873455, 0.2554221868875527, 0.24964900957720898, 0.2699560545865567, 0.15027038332435394, 0.1931184929825606, 0.32984157663679897, 0.46973741342944486, 0.9022984185045766, 3.3247826128236713, 0.7711566071356497, 1.0528085260621964, 1.0444709153905993, 16.087368861321483, 86.19342557845577, 75.20519579610517, 42.29492149045391, 115.4457562969577, 131.33682327885782, 79.57528098937004, 46.29334642041115, 67.2047608898532, 76.3218318262408, 77.53064355542584, 22.0542872336603, 2.413958738888464, 0.827181475056756, 0.2719423980001481, 0.16870619729161265, 0.20008662955895548, 0.26433002744470874, 0.15323636933199822, 0.11948219064863459, 0.14932599609657643, 0.18220520277898158, 0.21074432218747757, 0.10736145394583864, 0.11815357968331346, 0.14607243600391573, 0.09630728017298446, 0.10292161436330888, 0.21282742250590556, 0.14883648123471968, 0.22144247958016014, 0.2444037587772454, 0.1354482520612017, 0.14225051528023136, 0.1779728427889847, 0.08592641341590113, 0.11653122762518546, 0.10541709215049783, 0.12224997438850904, 0.14639999987857957, 0.13820567829233987, 0.18551966686162258, 0.094691003192096, 0.28771388074082715, 0.1897950963147225, 0.18019112698253126, 0.16851993067370308, 0.22156834782611942, 0.17545158614314374], [0.09872626408093399, 0.06481683767971493, 0.030239351965006322, 0.057924570620901165, 0.043395115588341034, 0.043585913616322705, 0.04252572453791096, 0.015437399457779624, 0.038687428684845086, 0.023328095501769456, 0.09971625652284392, 0.03622058343382613, 0.021609224026061354, 0.01701048440149715, 0.040016349915775566, 0.03497726103711513, 0.03185272738788157, 0.0327736359359997, 0.03499080164117679, 0.06302909873005363, 0.03739517242197068, 0.028430763932485736, 0.08900798676956086, 0.02112083531345331, 0.046651636610829064, 0.10627504167777878, 0.06964279323696129, 0.057374304986648986, 0.06062039955248756, 0.009624329076388912, 0.08003914263099432, 0.021432527761545875, 0.062252059578895576, 0.016565145999794046, 0.044955073615476016, 0.02398803236804182, 0.06964617168470737, 0.0661995038089733, 0.08660094617235084, 0.06212028862547971, 0.07691433127488821, 0.1557529681632596, 0.10663760044882375, 10.668418349758273, 68.13437046543245, 68.68878179980864, 72.551680995572, 36.0009882527013, 33.946368386668546, 90.52282794829338, 131.46165663196194, 86.49233371980729, 35.831785048207934, 33.1746655894864, 56.14793277555897, 28.840144526573923, 1.5207171343987989, 1.8200583299321516, 0.612049951188026, 0.19763067424778016, 0.2804098758966692, 0.33316636758465923, 0.37080990571168165, 0.19665712971360455, 0.035354662761693044, 0.046297409045960636, 0.010832743719220163, 0.028693080098638614, 0.09202555347714694, 0.09476276264796335, 0.021012839898767493, 0.09652733126835478, 0.07678235730817241, 0.026686149987302003, 0.060556841067849636, 0.05997563314233577, 0.024182687648722244, 0.07727892783981177, 0.06812474404972407, 0.026394479247110508, 0.03178647418896998, 0.04488133765276402, 0.0317581634097282, 0.01408524948337506, 0.02702106256037951, 0.04309562500566245, 0.06076812811736619, 0.08533906912611378, 0.07258132265339937, 0.027091739917053815, 0.08138324389414442, 0.5830850247894565, 0.100461476212067, 0.0036398029506897497, 0.027226946774810076, 0.007823677235958918, 0.0019690506545180877, 0.08509460280859664, 0.04742662647678968, 0.054938133896118214, 0.07144079393436832, 0.03453411364687547, 0.07469669825607732, 0.06286962986773541, 0.06302060281497336, 0.0406683711785703, 0.08233679353349632, 0.07159551305155601, 0.1708274794321868, 1.2533822343234093, 1.0374176358022997, 0.06987736169849673, 0.06835252497225039, 0.0766107382913751, 0.10225766128109348, 0.2449417670047091, 0.1881840746969946, 0.1892833955465786, 0.0531379881525232, 0.11628485374873686, 0.1487180900069014, 0.2619098024743219, 1.4481693434138454, 0.25634648728995557, 0.6554761048286193, 0.8876850155572739, 29.375934408557033, 52.62104734297722, 37.981106619681086, 44.974104281394716, 102.37350848413284, 88.27542751066147, 41.71885475035637, 26.208514590417188, 40.06189261713336, 42.88469299193352, 40.70157627905569, 2.3334209572884346, 0.6698444209271862, 0.1538375338479396, 0.08735090028494598, 0.0812926616579775, 0.07130667492146454, 0.0086768813273539, 0.04888361462602212, 0.0525878450923389, 0.05552904815563271, 0.02772546891543654, 0.021127793307025588, 0.07902491116716016, 0.05889184855585618, 0.07047920803269071, 0.04134844275071256, 0.004570155926499396, 0.11720729255748373, 0.041573745378803824, 0.0351101964441759, 0.03602528080884968, 0.026496273180049275, 0.023795548946626728, 0.049767339181515484, 0.016597490231957168, 0.007311036094887964, 0.026790638634514426, 0.06148794816145974, 0.027146452001386115, 0.03130619260182064, 0.06283728946601191, 0.0443921483782751, 0.025920211450166764, 0.06252549551126939, 0.12805726559412095, 0.014119314540538096, 0.04875868483777008, 0.08491228920437636, 0.04734979551886359, 0.08350791214334388, 0.026042197545569752, 0.02632669004191074, 0.014118456522062903, 0.07280156527075075, 0.03504499853138001, 0.005140096135061956, 0.029543770942837003, 0.03530032797566345, 0.0529931094347229, 0.0027479190799978475, 0.015960219992144455, 0.07661944871107418, 0.0077537391541315425, 0.03390323641079088, 0.04901591418010574, 0.024727445110798846, 0.021941529984976497, 0.05397646755520856, 0.033184427602757374, 0.009526694043269082, 0.03750733535496458, 0.04336969679101341, 0.07839228342016859, 0.09404421814026372, 0.057468867049582546, 0.002932016711471783, 0.05215439254478101, 0.0074489084598157685, 0.07706798552986115, 0.09398654704132388, 0.09387176408762894, 0.00870352490775047, 0.03641123207466256, 0.03986508585512638, 0.1146236916763648, 0.035479083101475434, 0.05639426019643584, 0.1208682811909145, 0.035564628309540214, 0.10253834057479136, 0.140609125937185, 0.558204143758743, 31.198842217845304, 91.17161935375583, 83.0769455817438, 54.01124908078102, 44.663946782389, 77.7018314792264, 110.32051286389752, 85.13494260849492, 43.90136349585749, 53.32641893817533, 77.94821123923026, 63.50712291656002, 12.390961531669864, 1.9058486554891834, 1.2935042813900979, 1.106043301763073, 0.15807586932374587, 0.46295159045727025, 0.5964995307787773, 0.2296353609211022, 0.4913851276280419, 0.04592444297046431, 0.12617301105731918, 0.06736155193779739, 0.06698615353314147, 0.1476066190028383, 0.020406617287306056, 0.03425420044110187, 0.09065431737971884, 0.02800667106414274, 0.04317862297137899, 0.0680826551791641, 0.06278865054369935, 0.04976682973304584, 0.10183107288133714, 0.07570912175241017, 0.0882684284700982, 0.020204799084533608, 0.03596749096628159, 0.04674406128845388, 0.026955789954011, 0.034885058524988355, 0.025406097505061377, 0.03596418912732794, 0.08683458766749791, 0.05091812964829226, 0.04567843298577974, 0.05691314686930949, 2.3171075745936367, 0.06956931008326431, 0.05269027104781521, 0.08643800693173563, 0.01926578021788549, 0.06283255504263986, 0.021613592642449567, 0.031575602742152355, 0.0661211330143194, 0.016268051357098644, 0.06280111862466702, 0.05657887589486857, 0.03144683676861948, 0.03096624683108061, 0.010054113020399406, 0.0192797057811291, 0.025014649558391784, 0.06660647269698881, 3.603557473228824, 0.6464746942923916, 0.04058508592988214, 0.0679372210476187, 0.2699752987152146, 0.06251477411076908, 0.32054537546730816, 0.1531273396986146, 0.0758493694687082, 0.08405003426296097, 0.34733672656359216, 0.18626304793982737, 0.32043282182947286, 2.0673192749100346, 0.6326167766124972, 1.1051159063654563, 1.5061892881508798, 33.67877252640263, 76.91480790415119, 60.38308059015582, 44.65481158225767, 83.92266350407755, 108.80917656806209, 68.05986896637948, 42.935511219886045, 44.458802900006695, 54.90434531242617, 62.95122108151836, 14.493956969630334, 1.471412328462447, 0.45859374526527624, 0.14846592450574522, 0.09816438455374972, 0.12597257181281044, 0.035532866304199544, 0.09333943257168417, 0.06440821404178297, 0.07349084521974288, 0.052578096623502435, 0.07241555654834356, 0.019662165601227074, 0.06095455944417946, 0.0039375772570154725, 0.01864252172620787, 0.031086559024369045, 0.02160882374512092, 0.05282301110245528, 0.06595404157715459, 0.05731771407168239, 0.022425969514334877, 0.018503024776075638, 0.00949190694823741, 0.022111748976092187, 0.07542252825993685, 0.05704247783268652, 0.026628013489948168, 0.023719968627237027, 0.07417392751742756, 0.013268206178420975, 0.05879969583944448, 0.04520118702203036, 0.03718991831485783, 0.0943241466677958, 0.11785535697614956, 0.0490120952318032, 0.08300311382739775, 0.03300869469380668, 0.19021687368231435, 0.18840985613003855, 0.08415047605071338, 0.1127858927112914, 0.1402589165034794, 0.14989794201908574, 0.09315673592350177, 0.1604994344374826, 0.13412999860461683, 0.12540915244889836, 0.1253050104564717, 0.1798100288837187, 0.1379644831702594, 0.09503289291094388, 0.16782749444246295, 0.14526441242666016, 0.11947986940222403, 0.09511251242891436, 0.14220900863649386, 0.2117394704011179, 0.13919118911989276, 0.1702452679314921, 0.17440720911948912, 0.1471142849374202, 0.08747392634470617, 0.22599910926674643, 0.15762416856183162, 0.2463862564294569, 0.11900726210085616, 0.14044892163045947, 0.1558253481503456, 0.19685678754843053, 0.27384943599181794, 0.15120283490227115, 0.08597342823181423, 0.21223758076948507, 0.1866447129437039, 0.2197930463139088, 0.2664030000807778, 0.1244091855422143, 0.17620253617004042, 0.3874037378738004, 0.38196105089399124, 25.34932921009679, 108.87708848522557, 113.84945361844956, 106.36895241275911, 64.2501296535615, 58.60670581940682, 110.70267723452662, 152.64578173237464, 108.86325036325763, 57.497945908577215, 64.33967736459547, 89.802335616081, 50.76876294228339, 2.370222105133918, 2.5195629173709504, 1.5654017559943663, 0.23592469763130913, 1.1402777486270474, 1.7512664535353262, 0.3640556455619874, 0.6026487040423578, 0.21321552264834606, 0.3613880661226088, 0.22802202571784297, 0.2232725410571983, 0.1647106963660448, 0.18569822663501387, 0.1461911949539377, 0.16288633458316326, 0.2737597730611601, 0.13412734794039882, 0.13361848169757476, 0.22356776069969903, 0.15812828505952514, 0.3479442955745805, 0.15595550648868084, 0.11279896983215887, 0.19448988229757358, 0.13902369165612807, 0.18156447748263038, 0.17810082543761502, 0.07022289033498495, 0.16975722395845, 0.21266838265282495, 0.1952124870712719, 0.16839000216174513, 0.1346863316552293, 0.12222241820587267, 4.277780055999756, 0.46430024228269057, 0.2512473294571523, 0.1914126143580483, 0.09386176664021709, 0.13666335943966143, 0.14342359507516508, 0.20850664064768823, 0.14745453522811014, 0.16418637046890874, 0.19781222176407615, 0.12036165958570859, 0.19874396854110304, 0.1950782991104549, 0.14189074506923077, 0.17930479389765572, 0.09955240563759882, 0.21342230510086785, 10.130083830125871, 1.2771218894950807, 0.1184501629623194, 0.2187789297632633, 0.40017010283566296, 0.1861543247416135, 0.5512991787925844, 0.33565042300089715, 0.3557312116026879, 0.13934478974871098, 0.3288532619274432, 0.38125410495746526, 0.26672095721287115, 1.5836388161105495, 0.6077254154989796, 1.2898974168685176, 1.0922010122768342, 47.80244696524836, 77.70733064220798, 52.51835576949581, 60.61247256494338, 122.50872904254545, 107.25343119713568, 62.280464403090946, 51.134743613581506, 67.94526515468475, 72.45663412155645, 82.2848072359639, 18.537956899212254, 1.2244965520597275, 0.9089945785460934, 0.2570564822564202, 0.31150232039151654, 0.260629884057468, 0.17077111068271822, 0.18792021869411393, 0.18656594378332939, 0.12688032471604888, 0.07879764352354311, 0.2080976109831564, 0.18868125043809417, 0.13688788448850955, 0.1605233057372032, 0.14247122521121658, 0.1532927993685007, 0.3065182442866987, 0.1257976509570595, 0.16288452661566197, 0.15302636931019445, 0.15088575111041147, 0.1600145773902055, 0.19049298709198353, 0.15673124712080727, 0.13247436002617882, 0.21510717759449638, 0.13613475877190792, 0.11336376049345541, 0.16059167142356598, 0.10369331771207434, 0.13674301726202812, 0.3103482855423805, 0.14991121066193427, 0.18940713406810838, 0.2753212441119456, 0.13429873713081883, 0.20819516461943427, 0.13123889003069172], [0.029345800416664253, 0.03632161510928023, 0.06489630398010054, 0.04416804467778533, 0.04305485380633224, 0.0432881735445511, 0.007358534982608211, 0.04513541071285163, 0.01716882328412706, 0.029534786646705002, 0.05469402763992549, 0.01817889106009276, 0.027493618150812485, 0.09326628649667387, 0.013996444571192467, 0.0107239889198794, 0.015595326568150233, 0.10157033485630829, 0.06869685085069749, 0.02428349332823869, 0.016854480171816486, 0.03771982133208263, 0.012251868930404947, 0.029596675059668003, 0.015973994253023018, 0.021686007103492177, 0.020971685655475147, 0.15727466392901637, 0.04548665436525499, 0.011599944386210655, 0.06474833409752577, 0.04717939075142626, 0.03665264553180145, 0.03527205167037826, 0.003888227788153135, 0.03312247024188119, 0.11520537457639173, 0.012239338604793435, 0.043426077031800826, 0.07720185173374992, 0.09511533929335494, 0.07407121810941927, 0.14304520892760447, 0.10198221436791843, 4.025313022636598, 41.79305814927624, 67.73420241571242, 68.7196586978051, 51.269167161756954, 24.327657684203118, 59.56530955529983, 118.70552047606438, 113.22917784413984, 58.123767914310584, 36.60227191063666, 51.07017747817501, 60.181204042127064, 24.728923997571393, 1.4606557185611417, 2.1133448568082627, 0.07869160163306421, 0.9020082243988592, 0.21248942451371303, 0.07437374623071763, 0.12440634335601523, 0.09046407476548227, 0.14060909529366802, 0.058110350772978804, 0.29296103143884294, 0.02465056627237749, 0.01200399926728419, 0.07869402247090494, 0.07971727078960789, 0.06152852783880888, 0.0332622314923473, 0.03679692287058119, 0.09789997696756356, 0.05344904666285842, 0.08343570835648045, 0.051684623599172606, 0.05042576876979682, 0.04198401993621261, 0.11655159024221283, 0.05620517054452531, 0.02427554133558466, 0.03736903733243385, 0.06403525179672627, 0.08887549952393578, 0.038602055846563274, 0.03554590895111042, 0.32532729629066687, 1.3853049037917968, 0.05361317717019589, 0.01586923651742719, 0.014519810943203348, 0.0639336570466478, 0.049583083544407165, 0.06140027705940509, 0.0432015328307546, 0.05000370028879374, 0.022694416299101808, 0.04865406787083034, 0.009516896736327439, 0.02206012805653436, 0.08367555516381418, 0.04587708724542491, 0.04284273938185746, 0.11055142107990482, 0.009853806883667507, 0.1839898658856269, 1.0913465484496088, 0.2780733996581647, 0.2294281647811013, 0.24956644062073002, 0.022355246192385114, 0.14464930511049687, 0.04755757005524732, 0.05002517373331132, 0.19041440179271085, 0.08663694464391278, 0.27120627943546544, 0.7527192609925425, 1.8458350435380015, 0.24808079695268986, 10.918880316518969, 50.970313933587846, 50.438291488155244, 36.48667573928833, 68.59855944110502, 99.19863224029542, 74.92108283504363, 33.608938647854714, 24.57474150965291, 45.17829895019532, 56.17644840671171, 48.62232039051671, 11.48849573827559, 0.5070086941123009, 0.3328049579455007, 0.07570982655330051, 0.10713804738535997, 0.09770218072639358, 0.07401433608104145, 0.049547360864497965, 0.025135683789548856, 0.017029224827344862, 0.05602322849294832, 0.03475816372121054, 0.06402229724992668, 0.03034103289997626, 0.033392167665184505, 0.033372165109481544, 0.025577264529983365, 0.03874785770031233, 0.015829394199705173, 0.07254251263915532, 0.06429792036332431, 0.013859791722479127, 0.07215502536705426, 0.03283360529871237, 0.06641437614997549, 0.022472118650893533, 0.012029305066642983, 0.06416802632532294, 0.09318256840830849, 0.08321746522861143, 0.036911705824276136, 0.05510660812198635, 0.03625344860577776, 0.0532522616577485, 0.04256315942433092, 0.02656304348830975, 0.06599361001844369, 0.032103690130996614, 0.03405138249358824, 0.08875258837736423, 0.018559372458126278, 0.019641896829970425, 0.02500501600274396, 0.02679586718459764, 0.05306301112737387, 0.07898614711819157, 0.012287517874351433, 0.027923786096395026, 0.060860790282247536, 0.03164167207996211, 0.001782110238338881, 0.07812596827505097, 0.03666607888355371, 0.06727977205188045, 0.018686778625593554, 0.06771795902281039, 0.07162919793758663, 0.036238682261037256, 0.06020748582217963, 0.03261256594991973, 0.04292840716399012, 0.024311635568137133, 0.023360422496954282, 0.0916435130901875, 0.05700623421298881, 0.03989588642012208, 0.035608149764518586, 0.0145646883738077, 0.059382562345314416, 0.07482753075178593, 0.028402096922359163, 0.038687895998478904, 0.043845479526827415, 0.019454927326390342, 0.061387008416556546, 0.03625800299848761, 0.15466090982719777, 0.06917797704978336, 0.019997566555356307, 0.029755542542965665, 0.001935910768224858, 0.2258551000587402, 0.11220660000558823, 0.32603871618067065, 19.623957257116995, 74.9994125673848, 96.01414618953582, 62.07258270632837, 48.91771801056401, 62.874821155301994, 99.0959838128859, 118.95914877614668, 74.17037256302373, 41.08824353064261, 58.151632432014715, 82.41871695364676, 54.388914492822465, 16.28926109883093, 2.7612382846493877, 1.217031301029267, 0.7253722510030194, 0.5933499901044754, 0.04459144615177666, 0.15455742667038597, 0.27101874111160157, 0.1006773368064915, 0.11618600542386694, 0.053136467467993505, 1.0189922406308114, 0.3097714519789142, 0.02505282563487849, 0.06124408322296316, 0.04475517829339351, 0.07430283713244623, 0.11379106901586057, 0.011032511679185255, 0.03793702258037464, 0.05985581316053868, 0.04064707776471492, 0.023854671782183073, 0.03353028182661341, 0.09092273160574899, 0.03736340658619039, 0.08947029018834715, 0.07442726513310786, 0.029665057983009085, 0.11228780532556196, 0.017880388730836493, 0.05279013443918479, 0.06796637069313757, 0.48686061234724143, 3.89972681960752, 0.14635362091564363, 0.03682179008460334, 0.04645303214689897, 0.08202012342911574, 0.07049411610369721, 0.019302445185941555, 0.07198768878175367, 0.03120391603348957, 0.06447027482452893, 0.030276551279389573, 0.042758714858322375, 0.030398351598470926, 0.07573791133660464, 0.06525676367023299, 0.0269467520317243, 0.044777697447927735, 0.04055282213695107, 0.14010124028690402, 1.6345448070956816, 0.5479101283896355, 0.08591105335301931, 0.34863343762774623, 0.11892238721972513, 0.3044295821699404, 0.19489042370790438, 0.13162047842577582, 0.10079254876942405, 0.11357959044436294, 0.6052194499681073, 1.2396002512785698, 1.9620644325210204, 0.5647536439280356, 20.265639366642123, 79.1058046587052, 82.48534233339372, 43.267277056171054, 55.513246213236165, 98.90064977830457, 97.77267025363062, 57.320964644032145, 37.12252724555231, 49.059546993624785, 69.26285205348846, 60.54870267068187, 25.06711663738374, 0.9149817701789641, 0.5970456595382383, 0.1084196205521303, 0.1869800296281615, 0.13946045370351884, 0.06983619979432515, 0.08233241151056944, 0.06035028078082589, 0.04054204327985644, 0.05921974567876709, 0.01418715832950247, 0.10627907896113974, 0.07591153750376356, 0.07315865417401637, 0.009015502723594828, 0.08040472744934021, 0.03341992303068119, 0.007415100999717271, 0.10714694932704011, 0.06591706251304957, 0.04692286620998094, 0.019549064210525924, 0.032418600148371154, 0.0580874409136032, 0.0440379974221991, 0.06541290771095984, 0.021065180940974145, 0.04613054360473349, 0.030793635730421355, 0.08347150764518207, 0.04578922462138919, 0.043214881912835186, 0.03976231899052378, 0.04080160919036116, 0.010945371093018161, 0.03973439508568376, 0.032009779242798686, 0.059944710003272186, 0.022776916307667573, 0.17864932906964134, 0.1516227276935693, 0.12142918778643494, 0.11110198548844746, 0.1460244482563388, 0.24860133837547996, 0.12136604681971574, 0.11928533669561149, 0.1074583947117771, 0.10449507469010931, 0.09027459057829074, 0.12902647407064516, 0.12428304916548154, 0.21466929705873614, 0.1599108644070164, 0.13784826763214605, 0.12986082042897903, 0.17488642775964353, 0.18775270590859075, 0.08885491474141037, 0.11360471812827934, 0.17245677990778802, 0.19842677749693396, 0.24607098060509852, 0.14801618492891713, 0.1569398835061058, 0.14166444269639833, 0.20765464362357894, 0.16021374492875992, 0.20239315175962067, 0.11517354362313786, 0.15214628750278106, 0.13449162274839419, 0.07562926474718318, 0.224251861894323, 0.14260464708410925, 0.24672969364591185, 0.11356714917647262, 0.1908352292112766, 0.16592905195730348, 0.3875118788451918, 0.24141456030549543, 0.6254328330678325, 0.30453214602124307, 12.761130313719473, 80.64877879235053, 115.81394918503301, 105.36131120497181, 83.66317518295781, 53.328509561477176, 84.81604606874528, 142.62225889390515, 137.98862180402205, 77.8335132906514, 59.13980299426664, 76.73125666956749, 93.14184158079087, 44.489930829694195, 2.514600628806699, 2.8253180461545147, 0.8163322604471638, 1.1967164878883672, 0.42320152504309533, 0.15340765127010886, 0.6509152463366908, 0.16824824525223625, 0.49339393273957316, 0.16347064516477047, 1.3711087429715743, 0.41814850102509227, 0.24348073008079685, 0.12292126659303905, 0.23224084127333858, 0.2672521012925333, 0.25688101747824305, 0.14959958141609547, 0.13627224091079929, 0.16011985319276012, 0.21115990956464123, 0.17193734165160887, 0.13792340553575946, 0.14815604194037377, 0.24058877881015503, 0.1704966826664825, 0.1797133179441575, 0.15972873466389795, 0.17361024785186016, 0.1567799703127915, 0.1833638188339049, 0.17272484939425223, 0.6684923063843482, 4.776964418349728, 0.3976068339280544, 0.16885607473311887, 0.10481201292526339, 0.0922365034479768, 0.19785886119690635, 0.15177419859795802, 0.19306619982084922, 0.12161271947045481, 0.13075688283049292, 0.17388387913665465, 0.16608605401650553, 0.1657855177238103, 0.16491879648979635, 0.2931636770165736, 0.12351593468338253, 0.17997576434525753, 0.1399010002252556, 0.5643794252987832, 3.825245667849818, 0.4960922169829569, 0.36107013963403245, 0.44932251856211697, 0.1524150924336526, 0.47406709722934237, 0.42803725588225555, 0.26619658535045965, 0.28318035626603716, 0.20569390286841702, 0.7633778729265737, 1.127419606331856, 2.9872621691996053, 0.5645391393092372, 19.31514513108038, 84.34045084061162, 77.64009337271415, 58.15090679353284, 89.74855992101854, 119.50366004820793, 91.65143505219491, 58.30913128391389, 49.43707120034003, 67.56664660669142, 89.12814294138263, 81.11306190490723, 21.471281820727935, 0.8077491952046272, 0.9430443062897652, 0.16628958825622836, 0.40039281991700976, 0.2566298938566639, 0.13998079594344864, 0.226048567903138, 0.15801390813243005, 0.1343410558277561, 0.08438846892527035, 0.172157070990051, 0.17336876161636847, 0.13079400745130357, 0.10897370896512464, 0.10930672738580935, 0.16212636004051856, 0.13622200086472497, 0.14858279887947345, 0.22161258174286735, 0.18724174058485418, 0.15104684407912916, 0.0906297029747117, 0.24760424429851197, 0.17137544680266611, 0.18116168377380218, 0.1164014982960878, 0.11392767781451826, 0.160643796045934, 0.16218170223216857, 0.15267513331867036, 0.19054085226549258, 0.16056614537392894, 0.183585723862052, 0.10371485244362585, 0.09961478051639373, 0.21220843878484544, 0.07081843176556211, 0.14452775760043052, 0.13918801751588622], [0.10236914239583478, 0.037327369810232235, 0.019510964742831646, 0.021855117182337472, 0.035925042034397205, 0.07928101436024712, 0.04246234608393523, 0.06770254533377386, 0.02213418194573493, 0.03268537111580372, 0.02344755733746194, 0.07728032978071321, 0.03481176689327244, 0.06484244799902363, 0.04066322689815875, 0.06956027790663705, 0.06612088020530439, 0.06302359055787807, 0.015276242329198268, 0.0496938024016638, 0.051975193087972944, 0.09159685833559883, 0.07174095484398066, 0.01715943296139519, 0.061006013739613764, 0.014621103088551713, 0.07151158811945109, 0.09242247895247514, 0.01960487563102957, 0.044077217293482636, 0.02923973362832781, 0.02402246227457879, 0.08184491145995357, 0.012713706950777242, 0.09492858237917386, 0.015628908989920972, 0.07579128468228925, 0.11822538510445627, 0.0273449300608087, 0.12276683092838335, 0.09739233646541835, 0.09475956040043985, 0.1355851672950291, 0.06941812263140756, 0.08232591508497154, 3.1849153051453256, 16.983711834876768, 52.048130266128055, 70.86834876768052, 54.84104218021516, 36.31728818339687, 41.54178719366751, 95.17032669436549, 131.7363637493503, 111.027190608363, 65.75521369134226, 39.04866987659086, 41.605494330006266, 50.033981415533255, 24.05492744138164, 0.14770909092359005, 1.0431192911440328, 0.1478456231134553, 0.05269890485872185, 0.07568721929865499, 0.1252050206605946, 0.2817615307867527, 0.060135385457185976, 1.3151918015172406, 0.14003137306820962, 0.02326449296707588, 0.059156420850946065, 0.10938085405336273, 0.14878693066777723, 0.11496885259064937, 0.03922114298949319, 0.050461016475192966, 0.0561466261053518, 0.01068972084941643, 0.01503652479920176, 0.08987905938298472, 0.07512383057825989, 0.029245327985394868, 0.08121465092464801, 0.06732679452867278, 0.10783534827491931, 0.003749478731356982, 0.044277315628865076, 0.0427154423819194, 0.1153415160614156, 0.2865255864397172, 3.046729223382089, 0.08820388556247757, 0.039746407344336473, 0.04872562814383738, 0.017736090324638833, 0.0373590781894182, 0.06927096480203253, 0.04262078838843492, 0.055627222323129256, 0.11402221306437448, 0.015180378874403336, 0.008670242217880104, 0.007383186255596699, 0.025499935614906495, 0.05227941809402359, 0.020274953586199594, 0.03855080456442891, 0.022988172713667158, 0.12107206057877311, 0.40862645713552354, 0.3921339017969947, 1.1377476972918357, 0.8382526713032877, 0.16875066103473788, 0.5032986528690785, 0.1303806264073618, 0.3798905603827969, 0.2544128507255547, 0.07117035723621808, 0.38814491261878326, 2.0169192696771314, 1.9721846378618673, 28.812972307205204, 56.32501209935835, 35.155474293616514, 47.272224887724846, 102.25001658162763, 97.81671062592538, 54.22596354638377, 24.448252916336063, 35.65488615343648, 54.73163550899875, 53.872522692526545, 34.608095768959295, 4.408737209535414, 0.9168331901873312, 0.18990771123959174, 0.18796714924035535, 0.273128516611553, 0.024905773142593044, 0.2733248802683046, 0.1316872506492561, 0.049129582475870855, 0.10068608553058679, 0.02932098682879681, 0.03937424949160026, 0.024466620900878505, 0.06306900808046903, 0.06204052738124325, 0.036998997712808276, 0.07323831199638306, 0.06065477391765003, 0.010321058272834747, 0.044612019442983215, 0.04120934799674057, 0.024133709732503183, 0.07228732875157749, 0.04327832548428447, 0.011353378987780983, 0.027747384775730393, 0.020091433393498583, 0.04866319580844814, 0.06541036429905123, 0.00839818715898981, 0.05229528760537506, 0.04389416058397582, 0.035422450051673, 0.014418271734499404, 0.03790786527397652, 0.06750706267813522, 0.05275350011464569, 0.07028425397771983, 0.02245126956803424, 0.04399429593655852, 0.00968175023914345, 0.042781103777909474, 0.04025926490524604, 0.05629471473155483, 0.012949792266402756, 0.02919567399658263, 0.053097017770332676, 0.014757294369290673, 0.060462807605583826, 0.039720693603158, 0.014769645621849885, 0.04127946802444997, 0.021122731381065903, 0.06612752218760791, 0.025638482616012617, 0.024283897439618746, 0.056230941742298104, 0.10324922420324818, 0.021859608372793566, 0.010932546781165706, 0.040811786668435227, 0.06131811412952601, 0.022575149815830014, 0.07508375651894078, 0.017774955880257393, 0.03456159705115903, 0.04191570787600452, 0.012598829193701668, 0.027838976332737554, 0.038059267230452075, 0.04456207817119937, 0.008791557028739443, 0.06849197595710717, 0.06368811054515743, 0.03956126304523599, 0.002640655997487146, 0.09922708640055311, 0.04454806642306428, 0.03962136647333542, 0.06738925367713937, 0.15971166622494498, 0.10154083281034425, 0.10514736025323791, 0.044839451795503985, 0.1314717654379145, 0.2651693227310335, 11.229834056669667, 48.17856304107174, 87.9427085384246, 78.59249191899454, 51.4037593718498, 59.959119442970525, 82.90655782145839, 119.71980617892359, 108.18601392930555, 69.76058513887467, 58.806350538807536, 65.89355960969003, 75.26709079742432, 62.24102104863813, 11.79615664866663, 0.863644686197081, 0.935139014355598, 0.23847633732422707, 0.09908519159521788, 0.05964836038108315, 0.45524679905464577, 0.41100644716812723, 0.10311380284087313, 0.5068104305574971, 0.1857066076369055, 0.0896847258592325, 0.045945495066623536, 0.16382620189218752, 0.15345835096893773, 0.04108596570609559, 0.007107485096991784, 0.0921045448030195, 0.10417614462635211, 0.08207157389411042, 0.05776553842869978, 0.09087861260218967, 0.04511594058825605, 0.03545005986046407, 0.07101189194908065, 0.028314954420972257, 0.06948097248471553, 0.018604182856037252, 0.11638165661884893, 0.05424791548941886, 0.05908542748300299, 0.05952758278938071, 6.0266438126564035, 0.22812086638183365, 0.023133154853337237, 0.07680136394957382, 0.014319056645035745, 0.05870865778096261, 0.05645137971207019, 0.03057066392483971, 0.03136846022830615, 0.07833134112579208, 0.043147159740328796, 0.04165363685798742, 0.046392993836273114, 0.04744304374100701, 0.06669682510677846, 0.028129080423123898, 0.04565826189073344, 0.016799139895386273, 0.23831669992256552, 0.7364802807569505, 0.8619231947006718, 1.2504300378984021, 1.8535360045010045, 1.307286877305277, 1.6089588187394606, 0.6956041580246342, 0.2170750582891126, 0.157366625123447, 0.6296013319684614, 0.9763202852299138, 2.0126785746505185, 4.310494094125686, 49.23502991276403, 81.61932222304806, 44.79422830766247, 41.08938101799258, 85.2444944074077, 112.90639815791961, 81.31335381538638, 47.00814347113333, 42.15535571498256, 54.684606290632686, 68.89250186181837, 53.59103771948046, 14.352697710837088, 1.1435737653124718, 0.6721206826548423, 0.14926670089123711, 0.22262089134704685, 0.1745552326282186, 0.18110796568855164, 0.0894004995784452, 0.033066603280003035, 0.06933032895528501, 0.04983961574673172, 0.10947473046760406, 0.04049681727924655, 0.017970291063970616, 0.02214569050157743, 0.05246366223981304, 0.10420489590615035, 0.06256561936630357, 0.0295774711506261, 0.05288796769755502, 0.05980460401324015, 0.07914668084272454, 0.017795826030534603, 0.03391354412381207, 0.042660728382367286, 0.005044532412167398, 0.010179801235696482, 0.05862600838525161, 0.0696407171386865, 0.026972548127354636, 0.018700715680156025, 0.08474863750199157, 0.0527513359162596, 0.02526412417571391, 0.03303731956909741, 0.05944281133011945, 0.0744802630957096, 0.16892287760011612, 0.019284499576315284, 0.04669814197827251, 0.027642126210154067, 0.15815872939363604, 0.15077059277363364, 0.1098135864782718, 0.20089690543470845, 0.09220920007435546, 0.21141766750764465, 0.09419306136307218, 0.18969452429202296, 0.22817079999273826, 0.0956809726513682, 0.12519753598157438, 0.20065780939354053, 0.1831099832610738, 0.06320649021936041, 0.14519829903879475, 0.16539300491492595, 0.15102087369849607, 0.14967942309956397, 0.08985079839945802, 0.11861979781139283, 0.19693057713729722, 0.2389733445259833, 0.18291532031951413, 0.10468786837713373, 0.1545841018519094, 0.16028054779575718, 0.2730676279433312, 0.13959857935626663, 0.17479812846549098, 0.15326275340011045, 0.10298850916085706, 0.16233482788647377, 0.12806478091665816, 0.06268191534364898, 0.13185117814329364, 0.16481064019664643, 0.24222586273906693, 0.2046730753875548, 0.15742375996083985, 0.2099318093349857, 0.2660458498904782, 0.4359048869340651, 0.3111338627434546, 0.42314731666157324, 0.2668017028800903, 6.577386260032655, 45.11422703343053, 106.20127108789261, 113.08030036187942, 89.05896017628332, 72.2763619884368, 68.50823510077693, 118.90160760571881, 156.01916128589264, 137.0698771938201, 90.5634323243172, 59.59655123372232, 65.05276426192253, 76.46149173859628, 35.47148396891933, 0.4706132357879993, 2.608091792752666, 0.2827520518293304, 0.41851775540459546, 0.19399359521846618, 0.6109484393269785, 0.8135777147066209, 0.8703401107941905, 4.584991855006065, 0.3036610427643022, 0.1566445412895372, 0.20273488826088368, 0.3320905349908337, 0.2764883330993114, 0.15788298370617052, 0.21403591088469953, 0.2962276303479749, 0.19240154193774348, 0.07276471644159287, 0.136519028474727, 0.22585646369524542, 0.16308450620741616, 0.23621149030664276, 0.2319387728047948, 0.11752963171250398, 0.15956560390130167, 0.08071966619501192, 0.17468837870945855, 0.12210651676380828, 0.20282802923071772, 0.6133649257882949, 8.014180852520852, 0.4473090249924891, 0.1881854689770168, 0.17051641709141194, 0.20198930084945696, 0.2113210331768759, 0.1966365372701999, 0.1241036237127358, 0.07909796531161956, 0.215659634240212, 0.12873071816659745, 0.1382220419304025, 0.10259543710778798, 0.17912022799493807, 0.1374973993628256, 0.12953019220261805, 0.26656620745216647, 0.19292988213560275, 0.44495639962054073, 1.6522411929984249, 1.7233292494089374, 1.1105231387961296, 2.6048906483957848, 0.8328464807521913, 1.3470887609066502, 0.6731280576317542, 0.8763415210189358, 0.5067487451578341, 0.6163961212000539, 2.8711548639882, 2.8476782527662095, 3.85109237124843, 48.94240933079874, 85.53681296686973, 45.83742580106182, 58.76957831844207, 120.94286395657448, 117.13671361246418, 78.380126953125, 47.2777005164854, 56.4224829981404, 78.08041080351799, 89.21898503457346, 60.93489531547793, 9.064110113728432, 1.061392755758378, 0.6005166507055683, 0.31184267793451587, 0.5477144388902573, 0.20673512360982357, 0.44192799276882605, 0.20909809116874972, 0.1335089770896781, 0.2062805883225895, 0.12782638967638055, 0.22004536503264982, 0.10982299403798197, 0.1563948579132557, 0.09421479527748401, 0.1333124142500662, 0.19075570928473629, 0.1296853709725603, 0.06557004766598826, 0.1496602249361815, 0.2360000040742659, 0.15678335642141683, 0.17916421676355024, 0.1376645444261451, 0.15507182406802333, 0.13003263862863665, 0.10378762313555326, 0.1704734395588598, 0.18921415651998214, 0.1228408809871443, 0.17350173915826506, 0.3126763041702009, 0.19084572461583924, 0.12389235964585697, 0.09481665693343648, 0.18445979954013902, 0.16894019118720488, 0.26771687151443574, 0.18006484504909287, 0.12468734440664131, 0.08324806278030719], [0.008300150887319639, 0.01976012909454444, 0.01922926272175485, 0.029601001541220376, 0.035981383970788414, 0.02277814396356623, 0.02477126534006769, 0.016845622280191992, 0.07391309756184779, 0.02545054401120832, 0.008060559761830637, 0.006942949041859397, 0.03507610936198504, 0.061876626700283065, 0.10671673733140193, 0.04439158913409037, 0.05639951555959641, 0.025904024012326717, 0.024969605503663905, 0.08823619149024449, 0.03762197275195391, 0.04909279110330728, 0.0427099840054589, 0.06873792082431816, 0.06191940504997488, 0.028055078244858214, 0.06575590825729793, 0.039866238817452423, 0.018273198398791494, 0.00917925401740978, 0.02851738166364451, 0.052760490666954755, 0.012446956093152686, 0.05456608712613102, 0.08290284057898868, 0.02359487796052089, 0.025818164708212982, 0.039063505077313994, 0.06577169732941736, 0.042946977135274685, 0.030217171804378593, 0.12649477564639625, 0.07601659880169938, 0.1365548967113418, 0.1652331376868871, 0.10654014640397604, 0.6250761425302875, 22.149143872722505, 50.674881012209006, 78.68241617756506, 55.86089764871905, 32.34507253093104, 26.317136787599136, 58.798529332683934, 99.35790400351249, 121.46196611465948, 112.51928375613306, 73.18531636268862, 51.02331299935618, 44.887141412304295, 50.809057451063595, 5.783514716932851, 0.16976364377525546, 0.24414544925093654, 0.19066531090967118, 0.19205353883725984, 0.1551275186601185, 0.04831371415827063, 0.6795929816942061, 0.2985830442799676, 0.4162984906185058, 0.14104984099826506, 0.023241673123031374, 0.16646270880535727, 0.08011457930889823, 0.05344081504811203, 0.07084896036934468, 0.03084729827429739, 0.02933751900620278, 0.036854272212592826, 0.07043610792607069, 0.09048261409324986, 0.04475062390068366, 0.004754932982201178, 0.0436987009109749, 0.0419691271869646, 0.04002748117331536, 0.025941447407427817, 0.0426310041709052, 0.05473892422272794, 0.06308456349577155, 4.479442834854126, 0.2366430889214239, 0.06288622333217533, 0.054514954587624925, 0.031452917591518456, 0.03522938823387508, 0.025722953385763594, 0.024547619377112678, 0.06444651077711774, 0.0071130564714211135, 0.04368207680301801, 0.00598034855248707, 0.06709780318722611, 0.09008496083439359, 0.0944726757945553, 0.03386197108474951, 0.05374841850190874, 0.003776812509092833, 0.025582895276226827, 0.1753333481329103, 0.16342242759081627, 0.07150352121360841, 1.043524766160596, 4.60449387950282, 5.441807143149838, 1.448294123814952, 0.8632267086255936, 0.3599857881424889, 1.2106874801458851, 0.2748454728674504, 10.459235406691029, 39.10350068922966, 60.04528999328614, 66.81759941962459, 88.58639301792269, 106.60616951604044, 69.74123216444447, 43.69488992998677, 37.51883960539295, 45.517438842404275, 62.68715143203736, 50.994613016805346, 15.452520501229072, 0.7516450831486333, 0.5805574249356025, 0.16499822448578574, 0.05054827772020813, 0.11072614275279546, 0.15766988868915266, 0.10629986292652546, 0.00971116610021601, 0.03346925143212561, 0.04292170772509229, 0.07392669562250376, 0.09889072017563928, 0.026516024841957038, 0.08384548112629883, 0.05491479502750501, 0.0914997413694378, 0.06923513486981392, 0.02062842272402298, 0.017536999394876823, 0.012920393642308492, 0.025372602225792025, 0.023641630391319914, 0.05547069906887989, 0.005937774173705088, 0.046152679715305574, 0.015848445848772125, 0.09075560186418796, 0.034594925706304853, 0.03577671592093764, 0.04728126512359708, 0.08386567520398287, 0.02605355862948683, 0.055820544610821435, 0.039760836610390295, 0.055739251190736416, 0.05586465212306189, 0.0339326810001606, 0.04687495507119645, 0.023665792804451722, 0.06700807896953437, 0.036963068189159516, 0.06654009117834991, 0.031107971181852684, 0.0730125075807014, 0.04456534936663605, 0.0336934125892097, 0.0332160746949094, 0.03371704640167375, 0.010156109009028204, 0.041506800785540574, 0.0276061411451308, 0.04784366942100948, 0.020552083977588245, 0.023278079536412994, 0.04932941651091941, 0.03449047344826883, 0.05204513308502013, 0.04957081081586019, 0.08840198057793802, 0.021002333002885985, 0.052974593089593035, 0.052333722236536206, 0.04225057256858676, 0.010845008786887893, 0.06749834459755691, 0.04704557434325257, 0.05858476221140835, 0.02397010016495422, 0.03510716656643537, 0.017384049940794226, 0.028246899000218803, 0.013717613464611913, 0.025368392572648106, 0.04967824315592166, 0.01330824289095378, 0.07243106982881024, 0.04380370858275602, 0.05530063521056887, 0.05599648053307207, 0.06462090303220096, 0.089852943445646, 0.18930302271919866, 0.20392364221474818, 0.11631792576442804, 0.1102433158385177, 0.2653747875123255, 0.11583227964658892, 0.02064904006528518, 3.7878480745900065, 45.498148625896825, 86.5005079392464, 88.73772590391098, 60.30290342146351, 51.831607587875865, 64.13714578074794, 101.85936420194565, 123.68529104417371, 109.22435160606139, 68.44152342888617, 48.997753973930116, 61.53774007674187, 75.4864768059023, 48.93285443705898, 3.3756881135125316, 0.4058064261992132, 0.22095599842648353, 0.3406492692808951, 0.19305562780749416, 0.18635134723397995, 0.3608514674969258, 0.2669566671454138, 0.16701662101812903, 0.21574581913169355, 0.028091358253732327, 0.022635167059037956, 0.1279302175727583, 0.03585297231292052, 0.020012005397509185, 0.08370761594344532, 0.047425469684024016, 0.08016602211301366, 0.01617455798681946, 0.06600539245071911, 0.10786573132199627, 0.03694527196667848, 0.038652433788463954, 0.019817754228208816, 0.06839685081954926, 0.03947117493578023, 0.07450461703082246, 0.023639713256289403, 0.08376784577605226, 0.09166228990521162, 6.568092203909352, 0.6589130204050773, 0.1460170172034733, 0.11619246354506862, 0.06096697389899243, 0.034614127700126944, 0.06179413435259654, 0.06378617362990495, 0.022584438631911914, 0.08180591758460769, 0.07979473760051113, 0.027427330477944305, 0.18280897199386553, 0.07527887911325501, 0.02234171133398289, 0.046865673915993784, 0.08542381377229769, 0.05344390238244688, 0.05087997080878385, 0.08646075974308676, 0.07059699405104884, 0.0846762498540263, 0.4857891004893088, 4.827038866858329, 5.534779083344245, 3.3301726848848405, 1.7050760095157933, 0.6829887123838548, 2.868090512291078, 0.4023791326870842, 20.36041755830088, 57.879239513028054, 66.0479284101917, 54.07903155972881, 63.62468027299451, 107.19112826931863, 99.65225435072377, 65.75195812409925, 47.19420110025714, 44.22619458167784, 69.64456142917757, 72.95144896353446, 34.055633852558756, 2.8929083289638644, 0.7459319671315532, 0.21753943014529445, 0.12918359870391508, 0.09463137856894925, 0.12815727837263577, 0.006193192675709725, 0.1636741947262518, 0.07187722656395167, 0.12376548016383765, 0.07187775516461942, 0.02691716571608859, 0.08264022563854534, 0.040302736564509334, 0.034481192293066176, 0.07604557990787492, 0.026281343382452766, 0.01839618232371586, 0.015398129790781007, 0.03921630897469098, 0.044370268907157645, 0.09711228536381837, 0.05062913830061594, 0.03698504725170713, 0.004935291625799672, 0.09570408552404373, 0.038181940889767105, 0.0475389004925326, 0.042255808779549216, 0.01348764727628159, 0.02500215466434677, 0.06198287926494114, 0.02547392501465736, 0.04699843312283197, 0.03387282272019694, 0.044811589177697904, 0.07893291166833333, 0.036642448901529276, 0.00547059316886589, 0.06090352649710352, 0.05059458390479127, 0.044495964783333966, 0.1576683565133041, 0.14517922344948017, 0.09412780599368196, 0.09958750012541011, 0.12555247217777277, 0.15016994919748078, 0.08230870875019221, 0.1401751371280801, 0.12463460691393384, 0.1432249025111237, 0.18832946286326457, 0.13329644897772422, 0.15632839212494512, 0.14020996348511788, 0.2655145525932312, 0.16842040053058058, 0.18556272100296714, 0.12951200527529563, 0.18112229153273568, 0.16723126353275392, 0.21826093175238181, 0.13639613264991393, 0.19290827845613803, 0.1462509191685146, 0.19857423410059946, 0.11281598464495714, 0.09371543618580026, 0.1481416241656388, 0.1340223632512554, 0.09239562757072911, 0.15973323926089272, 0.28855755805007877, 0.11987502521444714, 0.16727329111627995, 0.17650252087943016, 0.1271253043124753, 0.15044112900091758, 0.17216382788554316, 0.26216129381810466, 0.31371720315467927, 0.25285459724405124, 0.23093043255709836, 0.2890645550383676, 0.40545681431408853, 0.24812414220744566, 0.15761497550674025, 1.703460115578867, 39.1222260844323, 100.27046695832284, 122.65540999750938, 89.06996634698685, 64.61605541167721, 52.90512892507738, 81.47235885743173, 123.9514473945864, 144.74173515073716, 137.29477021002, 94.76547533465971, 69.33678088649627, 65.06804189374371, 76.30808784115699, 12.859170936769056, 0.36462160067692884, 0.300165873862082, 0.44156076086144297, 0.5293733746774736, 0.16282319361644407, 0.2876018173992634, 2.8104547146827947, 0.7924036573498481, 1.1548165039670084, 0.4817453207027528, 0.1477014913313812, 0.2549985249436671, 0.122483707814207, 0.18603789469888135, 0.1984808173391127, 0.19814890208503894, 0.21119032325523518, 0.09420706545032802, 0.2827151570348971, 0.2409743508624454, 0.1359141714149906, 0.1814073834928774, 0.11852839586114693, 0.1987092187928577, 0.09080877602701226, 0.12341953783987031, 0.3202719740088909, 0.16081532313218042, 0.20668776405434455, 9.919708486526243, 0.5637936438283613, 0.21111317820126013, 0.18004376230941666, 0.19845703796994305, 0.12614493393489432, 0.17429626426629483, 0.13489049408705006, 0.17216479315632777, 0.10699973787151038, 0.1757341806566523, 0.15954957734192574, 0.29884023531790704, 0.21032072153062592, 0.23299854819572743, 0.1094816099371641, 0.11166891353505273, 0.18414461564633156, 0.2633990773991231, 0.6789964749928444, 0.36491161092154445, 0.7506547459671575, 1.7885355891719943, 9.533423666031132, 11.564251415191158, 6.822487327360339, 2.2540368428153377, 1.0883247299540428, 4.157769257022489, 0.25181357568550494, 17.360386848449707, 61.00770235061646, 82.27059256645941, 73.64908172238258, 105.1808351086032, 129.61647956602036, 96.56150510234218, 70.34331598589498, 61.877154534862896, 65.85090775643626, 90.4932846561555, 87.01176535698676, 29.20264997789937, 0.7917440862905595, 1.1728873536471398, 0.30713555793608394, 0.26065966955596404, 0.4242748448685293, 0.3697514479919788, 0.26808030362571444, 0.26914501262287943, 0.14200829360033237, 0.16359404660761356, 0.2258571378526188, 0.10927903330734662, 0.17613960970794001, 0.18536102537426258, 0.1745240375279419, 0.16060307081187927, 0.20083347335457805, 0.09599833989575987, 0.1066358537683564, 0.11299640601200443, 0.18068913009858903, 0.13060590222237572, 0.2058625801075851, 0.10778215879033651, 0.16362588522174668, 0.20036815154937007, 0.17021047221797128, 0.1771006210436744, 0.10939416100060749, 0.18705872217974356, 0.18926842618853817, 0.11652020361995506, 0.178816857176923, 0.13800401330715226, 0.11276009853088087, 0.16379384233826594, 0.15008053141495875, 0.15748647191832144, 0.22646964046983953, 0.19265272684635656, 0.15248422420793964, 0.13823377839740247], [0.007527147104302722, 0.01822911961484821, 0.04370676781681757, 0.045972005539243264, 0.0313788675327575, 0.05738771918620314, 0.1176116414247982, 0.03331260560380836, 0.05176934526271878, 0.009006417878422766, 0.04339794245278163, 0.07730992375722817, 0.01978288190589557, 0.045813915635188746, 0.05336654282385304, 0.02391863246298125, 0.08266406629474894, 0.08129777912531169, 0.006678235978113428, 0.036036151596495224, 0.04641419148913795, 0.05167866726556132, 0.034239284709216125, 0.04002484966129546, 0.04635611436359825, 0.09481001495113296, 0.09703899373210247, 0.010088480682292534, 0.02495151625255183, 0.06272242990352454, 0.02992635142178305, 0.061439772722341364, 0.07681060296994063, 0.05169070250685177, 0.023980647280451753, 0.0321858549760955, 0.07044722386185201, 0.1676095883932806, 0.07957532235811796, 0.09728652440131673, 0.05238141887070191, 0.10722812400349688, 0.068554695575468, 0.07522717583924532, 0.036805323024670926, 0.16499943490470612, 0.14670042891896543, 0.1747350641075642, 5.685655013207467, 40.613825013560636, 71.72052291131789, 82.54577821300876, 56.5133015571102, 40.72631859010266, 38.01998515282908, 57.806781568834865, 88.32870898708221, 135.02495734922348, 134.34690506227557, 81.91911682005852, 37.664002603100194, 43.452797320581254, 14.447752429592995, 0.8925049956287108, 0.22473422149496697, 0.2937898159988465, 0.03231384145516542, 0.16897299507212254, 0.12499788580762765, 0.21536691204434444, 0.07957574370647631, 0.14961395322555496, 0.19340410588249085, 0.19010523934998821, 0.07404004599178031, 0.1674769326083122, 0.08092031228326022, 0.06324878976409955, 0.09313060466440455, 0.036206564024811795, 0.010445793666276, 0.07485558489157308, 0.12102259428150232, 0.10493028157901381, 0.012711703630855248, 0.11328424056691509, 0.01431335216282957, 0.053736283669188145, 0.04737645920906817, 0.12295679009008793, 0.046542139663811655, 4.602820498328056, 0.93150622541866, 0.08044630304099092, 0.06288189876584277, 0.05375433270068419, 0.038910099800916455, 0.029426390951078747, 0.10385840965975678, 0.09022196799877191, 0.0642192048291045, 0.06258313213625262, 0.07748419343824349, 0.04484492166328334, 0.056921704071423704, 0.023400532945449797, 0.047045647121605375, 0.02807557875771196, 0.07936617269391015, 0.1188837074404282, 0.2807957390623708, 0.0802759710519064, 0.03676700713713804, 0.06457116094327743, 0.17779469670307252, 0.05597369324776435, 0.2812222661750932, 1.1956470291460715, 0.5452736827634996, 4.524233360444346, 28.359050135458673, 52.11369268355831, 91.2680547468124, 107.65631352701496, 101.93668196278234, 88.89522475581016, 51.75046551612116, 31.32320292534367, 41.47983727916595, 64.68757590939923, 62.601639839910696, 36.399191194965, 3.4074541637974405, 0.5047946080805794, 0.05248410912651209, 0.08837888302702097, 0.02913899881194436, 0.04793216023714312, 0.12365152458510092, 0.16607077822329538, 0.06205746558524909, 0.04993514308044988, 0.06423589022409532, 0.0145730645876498, 0.07275343962734745, 0.14619271180802776, 0.06486596689829904, 0.06094096904440273, 0.12039880718915694, 0.040310500865621914, 0.06731576286256313, 0.03160141415954117, 0.046507087310836207, 0.020461538130597725, 0.04285371359137278, 0.014341092206567768, 0.0430827125936987, 0.009967711709079244, 0.03288269621290026, 0.006040389257137694, 0.006217193252767527, 0.03069226506106075, 0.10279001577967599, 0.04567465234187342, 0.07846295503118346, 0.016237585955569823, 0.040971711353068395, 0.007452327605982822, 0.056596963230760834, 0.04314873788145281, 0.04198222346003017, 0.05076367100099883, 0.020874354184695312, 0.05759102742998831, 0.03817539466845413, 0.024066366773519306, 0.06697257845512322, 0.014680706644280544, 0.020465496889946443, 0.03995792422023031, 0.07251896309636294, 0.09239302287178655, 0.08037020752747213, 0.014730342438504582, 0.04769253176486781, 0.02565662166283977, 0.050655346168505574, 0.024314671191537095, 0.06089224585241849, 0.05791579125328891, 0.031711303726619774, 0.03016239460257273, 0.07362812051489469, 0.06636565295799125, 0.04585396671187013, 0.039234407801902106, 0.04507496254518629, 0.01230672657144286, 0.0496400383511378, 0.031948771830948616, 0.023977672944085735, 0.0371324080943821, 0.009963175510957597, 0.0417927316119594, 0.05612202702210315, 0.0851052820742611, 0.013391770414947985, 0.023417273881815137, 0.05095408215457874, 0.0500646157700929, 0.048030108408702, 0.07740964542233175, 0.09406470333135898, 0.13671989672847334, 0.036256497635716395, 0.11163823171368531, 0.07401472678588283, 0.05023343090508735, 0.08698192935797476, 0.06103576476415319, 0.04024956240168503, 0.21539809182286265, 0.17187061539340406, 1.360179671356755, 21.909604726299165, 78.04418379260649, 88.34513587336387, 69.09309187243062, 49.14698054713588, 61.377899569849816, 74.3231959496775, 92.44036489917387, 117.01561435576409, 121.30947220710017, 87.2230242144677, 55.354825604346495, 61.999956100217766, 65.57887961787563, 16.369194099980017, 0.4158387765769036, 0.5370134163287379, 0.35493592040673383, 0.15659306018102556, 0.4380253263779225, 0.24550741568448084, 1.2744541874816342, 0.4257521075346778, 0.3098420239984989, 0.1498839532535884, 0.2089621871709824, 0.0742222753263289, 0.07812122619079967, 0.07132470097032285, 0.021888432430944616, 0.07102555895764982, 0.10970810383197763, 0.06037039441927787, 0.03251762084302402, 0.08670766222020311, 0.16435703953667996, 0.07748667556311815, 0.05158805438587743, 0.07386337079468273, 0.08848847190458929, 0.06826420269546009, 0.11071623723593452, 0.026941898864723986, 4.267170044683641, 1.2918696336207853, 0.1866181909797653, 0.04947836698603727, 0.09982608288766877, 0.05655648314484185, 0.09918099089014916, 0.04242403019640235, 0.05659482967589171, 0.03226504165438875, 0.0243569094492423, 0.07325702752437323, 0.04511152409137257, 0.09600949413593739, 0.037469368037437244, 0.06160428627364098, 0.08925442193304339, 0.09749442534220797, 0.05490558665065516, 0.36342374559852386, 0.08222473019193258, 0.1327997941764132, 0.20257045514881614, 0.31983751022527296, 0.20540940845685624, 0.39365213484533373, 2.191661351150082, 0.5999464361417679, 10.058800635799285, 50.38360188084264, 68.8549098660869, 77.26855078051167, 97.1402115975657, 113.30469915943762, 120.0443587764617, 81.96085083869197, 48.210699019893525, 48.722183935103885, 64.51513674951369, 78.03405623282157, 60.80340570019138, 12.740835970447911, 1.3154217504685926, 0.07876274821859214, 0.12276405769009745, 0.09725812552196365, 0.1961101276139098, 0.0888776675527615, 0.09445582952110038, 0.1574788570043541, 0.04109630023219413, 0.10013612633150432, 0.02002395062346853, 0.03341695060953498, 0.11150528481530567, 0.08282599429930411, 0.07428388411719954, 0.0697203979436909, 0.09039102828190212, 0.03565218449840623, 0.021940702610018275, 0.017369136124128298, 0.10412356801210873, 0.024811461973454685, 0.10666769238248949, 0.07964607057792526, 0.016003567162120057, 0.04047246717457329, 0.028413356499626275, 0.04868437047867526, 0.043205596927192905, 0.051202964968979366, 0.051123533142550345, 0.032153832500860575, 0.017948078344606103, 0.01835842951080732, 0.11007720499389595, 0.09150245332068975, 0.06546084183238207, 0.06902721860716421, 0.05193259476894333, 0.025631921072941155, 0.02440848823396429, 0.03622436790817207, 0.04544982085785559, 0.18557923785861463, 0.09012373254424141, 0.11113439866852377, 0.11545400841221695, 0.1761594360634204, 0.1861130938895287, 0.2468774107194716, 0.12582414993836036, 0.14088333944880194, 0.08580574690694771, 0.14270701175255163, 0.18651892130653705, 0.14721346268009755, 0.2113921414580076, 0.14748767619171452, 0.09929510734734998, 0.2356332011761204, 0.12199642992908917, 0.08405357358917113, 0.0839840894144389, 0.21323541029086038, 0.12982332808596472, 0.09155658509341941, 0.11784531356346224, 0.13012438531844847, 0.18362837963767592, 0.18421042259902726, 0.16319777996790025, 0.1342604327346048, 0.19193622013253553, 0.11454368145355295, 0.14681077622357877, 0.1883554179221392, 0.10598192877706983, 0.14727991314664965, 0.2909485184617581, 0.16620089059635518, 0.21856840880167103, 0.1688321881116398, 0.20444401509819493, 0.13336899750415357, 0.23969311477436175, 0.31315483333122346, 0.2946501327378135, 0.1723830056406798, 0.318327704144101, 0.34295485685429267, 0.2620144807282956, 12.18027534023408, 75.16107697640696, 120.10372777138988, 115.85034093549176, 82.04816279872772, 72.50138836522257, 66.92954386434248, 83.34305486371441, 111.11096459050333, 154.02060385673278, 153.80652089272778, 96.99144394167008, 52.94865938924974, 74.96984574102586, 37.546919853456565, 2.9280535011522235, 0.6891674872848296, 0.6424024160350523, 0.3962868031474852, 1.54192489962424, 0.29081975440344504, 2.600384335364065, 0.6471539384895756, 0.4944219001598897, 0.34027321204062433, 0.3472022934546394, 0.21276696284692134, 0.24333454518308564, 0.23378438586669587, 0.24728251801383114, 0.1825786093550344, 0.1901586050347936, 0.24506342176708484, 0.274638353336242, 0.40048257477821847, 0.28130518753201733, 0.12400945618508324, 0.35738620666726945, 0.09428107720469275, 0.2283358766186622, 0.09117962386939796, 0.20657910214316463, 0.11103885984348674, 6.3214437615486885, 1.8939343335167056, 0.24028268071912953, 0.30026344282011835, 0.18059528432786467, 0.07554494144935762, 0.19334562273035127, 0.2669692616308889, 0.12386079682337663, 0.17687179058069186, 0.15395184948800072, 0.2814073223740824, 0.12873254145585722, 0.1552953378808114, 0.14771305925903783, 0.13895590819658774, 0.24119509143694756, 0.22579617257560455, 0.37402373648458914, 0.7746937270126035, 0.23857476430073862, 0.20510422967133984, 0.32465258733399455, 0.34795434664814706, 0.1829738034716537, 1.5661732371776336, 3.5970517320017663, 0.7633203856887356, 10.030157527615948, 45.74778787551388, 83.60858363489952, 104.96713653687509, 119.17244726611723, 127.3405791867164, 119.57893033181469, 78.0353270807574, 55.48990026597054, 63.20161734857867, 90.23082317844515, 98.70861837940832, 59.12785937709194, 5.9946402138279336, 0.9980966102692389, 0.16257056846253334, 0.23617842595183083, 0.2132152621784518, 0.2687224385238463, 0.2569500573219792, 0.3526236831901535, 0.3069196743590217, 0.13247497289651824, 0.27964133649103107, 0.08813465419676035, 0.07391613127002794, 0.21202817829626225, 0.16279406695356294, 0.2391346213558028, 0.21316831631045188, 0.10198937729001047, 0.12057815603311024, 0.08703429912847858, 0.33051466148707176, 0.2309663620807471, 0.10051069736120202, 0.10200698965138967, 0.15124044981935333, 0.09712530885853114, 0.07671809019220453, 0.1136811124160886, 0.13308955927289304, 0.12852697708313504, 0.1683790777479449, 0.18424972290954283, 0.26883664691159803, 0.1820715817232286, 0.0737680771177815, 0.15910745267906498, 0.16094488392193473, 0.14651970877762766, 0.1553353736357343, 0.1220833426040988, 0.12815232178376568, 0.14616539311264792, 0.1564383104203209, 0.1513079728089994], [0.058367970820155844, 0.051870997469391555, 0.10391401998218029, 0.0596829645726229, 0.011657138595417624, 0.04354411968961359, 0.014370046499665948, 0.023114929621618603, 0.02189996396942485, 0.017178918407749266, 0.017811555730839892, 0.04915602783101702, 0.04717735295754768, 0.05087800962369769, 0.03993583024449406, 0.03845635741468399, 0.0472187715011739, 0.03206519995846095, 0.04117096699173412, 0.036878158834071896, 0.032206727041592526, 0.0633483620420579, 0.025628351103214007, 0.036529964211607174, 0.0661264803080309, 0.013772445250182383, 0.0465125456872967, 0.03507100338596971, 0.014527842417479524, 0.08603761107811043, 0.0241707960489176, 0.004999139308629017, 0.12137415969083387, 0.04887953520782533, 0.03778455576168434, 0.08296137735728296, 0.052943972555259546, 0.05520665920489738, 0.1093493295352786, 0.1266131592133353, 0.019959451765903545, 0.13471331327192246, 0.05026633055099557, 0.0624073762446642, 0.023106393486922307, 0.09799966798915018, 0.045734533604474804, 0.1408253619146924, 0.03175161910363503, 0.4824816537720542, 14.899456501007082, 58.67029528464041, 92.91268102584347, 84.30037206219089, 57.28429048292099, 44.283104250507975, 45.16165241118401, 51.097747818116225, 87.08185811196604, 127.41531602797971, 122.06910979363226, 70.99511192690942, 31.195412105129613, 10.624707456557982, 5.398068793358342, 1.2213584107737387, 0.28301065246905055, 0.32619512069129175, 0.0884286251159445, 0.4542858490059453, 0.19086244065434704, 0.5600081276028388, 0.25919778993533504, 0.19937663459249083, 0.13150415563535306, 0.16100290742131973, 0.1673083932649705, 0.10803073900000704, 0.0556463438777193, 0.09192491250653421, 0.18143016694774552, 0.11098544053252667, 0.1460079467224498, 0.009395473715548795, 0.16003104828057751, 0.05669745864466794, 0.046107323479748545, 0.020463043493368936, 0.06348968228144992, 0.18548309382411743, 0.22477280168283373, 2.836233512047799, 1.054228178916439, 0.18675050968604703, 0.019737636753087564, 0.1270648829578873, 0.05103638298028419, 0.14400450422638847, 0.07371111848061124, 0.057371650491991354, 0.01455165051494635, 0.06453644183854904, 0.048036616325618765, 0.07970149703924695, 0.0792249903503445, 0.109003915811979, 0.05002869390732339, 0.08073935465466592, 0.1139503616779562, 0.13267953369405963, 0.13179902287740863, 0.1719469024289039, 0.0869189186262027, 0.03665737229429426, 0.13996101555324372, 0.7881622881658616, 0.034411137382830345, 4.207873613603653, 29.258883037874778, 53.65944385528565, 61.993876426450676, 100.01403024119716, 102.42683702899565, 81.36031243108934, 59.03107097071987, 27.811312713930686, 28.22411471797574, 51.371462575850956, 66.18062219312115, 41.346598286782545, 11.990949396164188, 0.222629226383663, 0.4915961388859057, 0.02002275744152646, 0.09385446582229869, 0.11139780267952912, 0.05175813356594694, 0.09560057172371496, 0.04839385461602961, 0.04009653250837038, 0.0997911339565631, 0.030808290992412838, 0.07776312605147401, 0.08283729409618724, 0.0881162451039399, 0.037081949713249365, 0.07040454510359034, 0.05060538574452362, 0.1107282265119495, 0.03414298362669445, 0.03829582752059064, 0.0882979381769415, 0.1542795972237664, 0.09906259966233084, 0.034601284236076384, 0.07181488998955296, 0.03812737627736023, 0.05618800251414219, 0.04694153194225604, 0.09059724382935994, 0.034277627409826365, 0.0843604147854832, 0.06982020387846617, 0.10923619367062085, 0.025193310838433045, 0.056794391749727155, 0.010469109552251476, 0.05477337136624321, 0.046409932040278955, 0.022879089454128858, 0.03928310418080899, 0.022308595268236055, 0.027588095944074374, 0.02852281705746728, 0.07099275507273213, 0.056582250512175025, 0.0019140943796599225, 0.011546557633987358, 0.05315078182085868, 0.032749959988699805, 0.039095424130679145, 0.039847906333424395, 0.030094674345286145, 0.02273295626735255, 0.017620257830487627, 0.06667935830210486, 0.005339845421633894, 0.019585620011052778, 0.09494116920376978, 0.03971503987427681, 0.023141344333247795, 0.021308434924351114, 0.06326028491340338, 0.06518813751397595, 0.04715817394636331, 0.07861710724330719, 0.05841307807713748, 0.02715332381006691, 0.01063040744948892, 0.06076248204936424, 0.034604616718547004, 0.0098726871205614, 0.09167293086647989, 0.06711709328115949, 0.022150375129234408, 0.059715002369616306, 0.03578094855671929, 0.0582407504290102, 0.07829030179568837, 0.047085242375971816, 0.02840548494620429, 0.1194790573490243, 0.04845498077150795, 0.07594688480058986, 0.03893971676006913, 0.13029798084209043, 0.07173576076785404, 0.10222133339172411, 0.037471087904827255, 0.09262051268090164, 0.1595303485350263, 0.1664148895971237, 0.03211181257821379, 0.09282178696124785, 0.2563585761574007, 4.990409997201735, 51.80610041464529, 95.87880872911023, 92.80294879790276, 69.59226054529991, 61.695776293354655, 65.49775715797179, 72.00031342044954, 93.79879151621174, 116.90453283248411, 120.22764328987368, 72.4985642586985, 65.58486515475859, 56.39852516112789, 34.06047797972156, 7.661774523796574, 0.9585522547844918, 0.6875216239883054, 0.8624524695257988, 0.3861203873830457, 0.6205813514609492, 0.8059243124819572, 0.6656411109912781, 0.1811074907140386, 0.29650541382931894, 0.13794401330092262, 0.15205022007707628, 0.08337124205765226, 0.08908308636877807, 0.009560751439552874, 0.10844218184150035, 0.12706875936278414, 0.023685425722731218, 0.10631789663626302, 0.24224826314997291, 0.16642967509406228, 0.04672537640398068, 0.1018196658321446, 0.05442255289263783, 0.06563773919497767, 0.01971829111777967, 0.10424969672796228, 2.1112880639491545, 1.509869574539123, 0.2992840147306842, 0.05019821384320817, 0.09259248918463146, 0.06526731270095033, 0.04007615456958452, 0.08325870374157544, 0.06407402733701371, 0.05382971958287301, 0.07314160871770113, 0.11401357159258858, 0.10691248045693483, 0.148772788684695, 0.11275304286109825, 0.11864039025479749, 0.08279159695150391, 0.057984923027575984, 0.06298287681514217, 0.14416339086188426, 0.132157429451904, 0.07174656260758638, 0.08071915291610264, 0.7650902939419594, 1.770389969310453, 0.07142379444332854, 8.997374907616647, 48.69053040781329, 79.79650266708867, 69.03502510439965, 94.67531573387885, 112.37853342486967, 108.75871135342507, 90.09266945623583, 48.761850864656516, 38.27276622095416, 54.74778390699818, 79.48752972387499, 73.81716312900667, 31.44757736113764, 1.7338122739907236, 0.4986775798663017, 0.12342351383619732, 0.0395124938879763, 0.05341099507565941, 0.025324687256567904, 0.03714852275386934, 0.06414975512832885, 0.18369129077801782, 0.1676460848219933, 0.16809240764667913, 0.06561869424918006, 0.03636877548189894, 0.09102556358782515, 0.14508960648409783, 0.09374974160304955, 0.07292580174943132, 0.01624874785662659, 0.060712199868454095, 0.04491222631787101, 0.04882288683626441, 0.09443792604630995, 0.019936264199655385, 0.06914935600493224, 0.031908460284372976, 0.04192246094105705, 0.03295912880510573, 0.020037579327641476, 0.007949161001541203, 0.10308828445211535, 0.040055297825845985, 0.09666484405076313, 0.025439993065271168, 0.09810010211602335, 0.02735654203852098, 0.07780705353305226, 0.033314666380324674, 0.05716158918315365, 0.07083069683322984, 0.06207012901863745, 0.07541122080217447, 0.032561988825158726, 0.028139181292405533, 0.0747247217523475, 0.02198620057184129, 0.09196520873135136, 0.10861574672162534, 0.1138901165235908, 0.10814825688759166, 0.1902737940150884, 0.1779857437096296, 0.15503604776195942, 0.12661354225729743, 0.1116779993378347, 0.1717784550161131, 0.16236168692909903, 0.14660744116671626, 0.17263912415552526, 0.10025710693650669, 0.17117847027557512, 0.12647067452029837, 0.10897024624770689, 0.1311761933949686, 0.14729292131960392, 0.19443283939073164, 0.11067391087811802, 0.16764550259517086, 0.09868465018488708, 0.13272851735593813, 0.08810396471451368, 0.0858326978801239, 0.13004261309341078, 0.22500230630318965, 0.09378046938969244, 0.2025777176623383, 0.11421088519836627, 0.19808246694024534, 0.20842456198748083, 0.19249509659505662, 0.1967562002039725, 0.24940470413815594, 0.1809953660854409, 0.20256561347313468, 0.30534766193839813, 0.36738319442637507, 0.2219533682951043, 0.2364504944172598, 0.24845932099607684, 0.1632404357435242, 0.2648020295366164, 0.18963893695223719, 0.2080907928006303, 0.29402552593138914, 0.23428494771642072, 1.1887083563112444, 37.62900721642279, 103.08107268425726, 127.89672420870875, 109.23082351684572, 84.56232363177885, 76.24115651653659, 75.57470660055839, 77.4827592603622, 109.92687948288457, 151.12613001177388, 142.99577836067448, 91.25187104748142, 63.51147282508112, 45.93706577054916, 26.415517676261167, 3.172822147607804, 0.6062237605933221, 1.142113663015827, 0.4250173679282589, 1.2071374899918035, 2.6656488978093673, 1.2734031148495213, 0.42734036101929607, 0.2996373038378454, 0.23508014698182386, 0.5023032288637854, 0.3642055842905276, 0.18744567319029765, 0.11967630200688878, 0.2636496800809138, 0.42251851169332383, 0.22954618828671597, 0.4619908549131886, 0.34507964767756005, 0.2823239006102085, 0.16121911275531017, 0.1782608612049972, 0.12550468361305614, 0.18278042755780682, 0.319377520392018, 0.2399773333942698, 4.331669009500935, 3.5831047642615537, 0.39716651723269497, 0.11655377359279703, 0.3197521986740251, 0.32061364922312, 0.2592758389730608, 0.2505701536973638, 0.2584658388889605, 0.08358151021022951, 0.23272252671660917, 0.2365130838006735, 0.32428805205610495, 0.24732154253269398, 0.33924343665280654, 0.1705006969672057, 0.2066259714023721, 0.18925004007835544, 0.3804784256123728, 0.715948817951064, 0.6155887871019302, 0.4388353264620228, 0.11889531367248106, 0.909708327343387, 2.591077531537702, 0.20000465815105747, 9.65204986833757, 54.515155976818455, 85.2405563477547, 90.42817331129505, 109.2052653528029, 127.14624143415882, 108.43800267865582, 89.46003037114298, 50.477240623966345, 46.96570734823904, 77.1821331208752, 104.09761767233573, 82.03396381870394, 21.390906572341922, 0.458023316196857, 0.7131407686298894, 0.18669502959857065, 0.16164093608817748, 0.2093092709659569, 0.2013912313287297, 0.34941962769915985, 0.19442200690748232, 0.2027122886671174, 0.30015931614945013, 0.3254076435921654, 0.25926437829771354, 0.26828184603683414, 0.14881562832142078, 0.2557943064358927, 0.1762303451616918, 0.2071604709471426, 0.24224558184223793, 0.15224255411134613, 0.15243677272190972, 0.13206047336420706, 0.2277769235473487, 0.17260081975931124, 0.18494986598530125, 0.21229860733353326, 0.1732724796860449, 0.20700814202427867, 0.1978543259563946, 0.1984013893431233, 0.21641004800556168, 0.1502296427685407, 0.3558494649346798, 0.18896248131509752, 0.16043312186675687, 0.20577323893385552, 0.16485790782157453, 0.13094285833499125, 0.19775398376007236, 0.1110025396149966, 0.2188684701198532, 0.10487051906004068, 0.13052935471698163, 0.20893048645267565, 0.2697912843958024, 0.1580628458290331], [0.05457957410403798, 0.04791443296257527, 0.022256212091193567, 0.07677556976916329, 0.09748592176624844, 0.03954092341084634, 0.040604533071840004, 0.020759103917366555, 0.09199651874481671, 0.034167218818179065, 0.06531232802738106, 0.022874513994001096, 0.1336240588176635, 0.03691947395582834, 0.011627461306840904, 0.011657570477484936, 0.011861912939967889, 0.09046307119030146, 0.042353101945932836, 0.029701690392328367, 0.027640239718640526, 0.020711493468092337, 0.07868380285799503, 0.031878492839994936, 0.048957814071928306, 0.03153662801900458, 0.042609320052208445, 0.027689294243652015, 0.029048736417485826, 0.08716585940771526, 0.03541704147092758, 0.032656321061715, 0.04957329677117448, 0.005500970949088374, 0.13930991742639773, 0.08528836942728489, 0.07097371012693451, 0.1258224415622892, 0.03399764525613958, 0.023092337688731573, 0.054216111349242355, 0.04670890551360865, 0.025050448847093412, 0.06151529366991693, 0.03817765079739113, 0.026039117872114145, 0.1533001538125738, 0.03166637266986072, 0.05938742700363359, 0.1486962258575424, 0.27428233695607035, 2.940978446314412, 42.10287832444714, 79.89196531234249, 100.45001737533077, 83.55177202532369, 65.54843418059811, 53.95589267053912, 49.93509454111899, 72.61773370927381, 89.53890923530825, 115.18104337876844, 96.79207771055161, 47.52605322868594, 25.1385312311111, 24.494421174449307, 13.701083179443115, 2.4528563935910506, 0.2350738190955693, 0.800177059586971, 0.07778648407228532, 0.9176757643299719, 0.6372938353207804, 0.4863310004434278, 0.11993650377037064, 0.16377314264255186, 0.2794602639492481, 0.22903361417833837, 0.062236339454689336, 0.21007272354777784, 0.2394424508055372, 0.1581613340925786, 0.38943601591933164, 0.13179294013928983, 0.1225233298816508, 0.3624406709305702, 0.38085426834802477, 0.32050020692329256, 0.12982034034306003, 0.18094302695845405, 0.17510171378812484, 0.6106603289804151, 1.236369689145396, 0.3905609087838281, 0.2998219003840801, 0.2790556163076432, 0.10969117328885103, 0.23093775635765446, 0.22301464521836853, 0.14501197113385125, 0.2817832876838023, 0.2392234109462269, 0.14885609308558126, 0.12077235932191535, 0.1823040127994553, 0.026058886771000205, 0.03997195129012389, 0.5139749767559191, 0.2894756991055704, 0.3157891032676543, 0.1687934393844297, 0.11881833715784935, 0.13407741432949422, 0.2969840962079264, 0.05992748451629474, 7.635336768242621, 37.73342855515019, 67.9395777179349, 63.97530878743818, 75.65014946845271, 94.761043056365, 88.16174153358706, 73.8427605167512, 42.106502594486365, 37.84015624753891, 45.828357281223425, 68.5744603987663, 44.1381020699778, 11.956820853294866, 0.6660088944819667, 0.6655382100612887, 0.03506338081112312, 0.03216401380937427, 0.07061584747486538, 0.11092988383625785, 0.03492739254368409, 0.019186827196409146, 0.12267310007084763, 0.029229998566030018, 0.054580156330860434, 0.010695522050223043, 0.028024658808604847, 0.0440023819945993, 0.05680017571355547, 0.1080210862921611, 0.06810031350581877, 0.04986792652597351, 0.08403347144203802, 0.09319184573307153, 0.0818771331180488, 0.06266979966312647, 0.021920903067615245, 0.04504006340979569, 0.034836247232892824, 0.006686684012698431, 0.050984204731761455, 0.012003138375979279, 0.01844208631213875, 0.046717707863858635, 0.08181160961788508, 0.029606381393668633, 0.061275347271153045, 0.0361494904744529, 0.052546897692786115, 0.030069471967797128, 0.011396417807367061, 0.02570868882861349, 0.04760312930410428, 0.028296821119804538, 0.03182725496439925, 0.06064456196561937, 0.03830670979955504, 0.0236483030171404, 0.03842944474590402, 0.06321765212041718, 0.032621195930386745, 0.040884074724970326, 0.015693692257627845, 0.03990574214126795, 0.02828005528558166, 0.10241403514819761, 0.02653468865901232, 0.036859868484879696, 0.012659237141750995, 0.041680151161046765, 0.03624587582664625, 0.02644616145370228, 0.036939396072299256, 0.09350138355887706, 0.07164530876663423, 0.048831957317287886, 0.037928465378260424, 0.029794664738038858, 0.008881147181044423, 0.013704110207336565, 0.0790627712323781, 0.06378216699006097, 0.026610996761930086, 0.011880273194683176, 0.02277579015841888, 0.024162962799891833, 0.025749938832896373, 0.1112508440330144, 0.009736053424046166, 0.03106397283714145, 0.038167143901509624, 0.036596307425849864, 0.06800934822568971, 0.061448896829519546, 0.09228442224764055, 0.17434500278003756, 0.08203074140774627, 0.0636199172285776, 0.05579601064504636, 0.11065222292898164, 0.03720666882732222, 0.04050630527818876, 0.018167139271334298, 0.05792310739296579, 0.04493026002760857, 0.03747586063259552, 0.019080846592964187, 0.017932352474740437, 0.07399828653902778, 0.028240389168082226, 0.09012053029671793, 1.475329550523912, 16.294837728623424, 75.89951022978752, 103.55834668682468, 96.5655686778407, 73.43586952455583, 67.33277136279692, 61.939308412613414, 76.0860267762215, 101.36658899245724, 119.35770080935572, 110.42275336480911, 72.20958755862328, 49.36758641273745, 51.68282424249957, 46.15529467982631, 17.73468294451314, 2.498368144996705, 0.5561325194374208, 1.5041559069387376, 0.27938399223550675, 0.7016157418970139, 1.6764264049068576, 0.7334242028094108, 0.21905700435801861, 0.3824832777102148, 0.2789889360147138, 0.2727811417031673, 0.15443646138714207, 0.2734514379933957, 0.279752112804882, 0.09859118745812485, 0.16645091105132334, 0.8948345770758968, 0.5287171744050518, 0.7914111138351503, 0.3324440998896476, 0.3155555383812997, 0.0496102222091248, 0.17995118824464662, 0.15940988886981242, 2.2007686043939283, 0.9979435765454847, 0.4217156821921949, 0.2014496838373523, 0.23187422223629492, 0.009653216336793717, 0.40387763131049376, 0.1524167931488445, 0.19491939715320067, 0.19843210946888695, 0.1650303235698131, 0.07440327892019864, 0.12022611564926564, 0.22983299628380807, 0.2257981644042077, 0.15734571092311414, 0.31266257587459784, 0.07358868230855273, 0.06624101045271082, 0.4617271061626173, 0.31153884746374627, 0.06037058977169856, 0.6580589855870893, 0.17705012052770586, 14.264328672039895, 52.34276302399174, 85.45926770856305, 75.51241151748165, 71.34351253509521, 94.20879687032392, 101.38267071016374, 100.2865957444714, 60.47607214220109, 48.1099097959457, 47.95359157746839, 74.06232695425712, 76.15388378020256, 36.69345917240266, 4.987587851862754, 1.2007429234443174, 0.05241864691338232, 0.05569119832568592, 0.032560893319427006, 0.15220253367818173, 0.05896065474277543, 0.07505830707809619, 0.07811642281951443, 0.1203145758218823, 0.08219705143522832, 0.05912894127710212, 0.019295071589670355, 0.0627836135155972, 0.028589405419845736, 0.05423329087094434, 0.09684172609160024, 0.12290065116699665, 0.053606355157230175, 0.03960889073148851, 0.029770207381056204, 0.058868601617793885, 0.04063553665013563, 0.06436874519192404, 0.04638265164929532, 0.02618304664088834, 0.08404457971694008, 0.055045945449702205, 0.05781853639130151, 0.062286334352627884, 0.11863807666926615, 0.03582691766261574, 0.030188108343751203, 0.04105835589730451, 0.06695318110888043, 0.09508998944394051, 0.013766405604509337, 0.004515287751752523, 0.06102869377261209, 0.05262557875304934, 0.030756624107579553, 0.0600224411145093, 0.06631530565960754, 0.053429764229804284, 0.05056130504536052, 0.06699651104187773, 0.06833005561343125, 0.15559225823850403, 0.11802685341887897, 0.11800541827875762, 0.10145431850105525, 0.17547389462349877, 0.21550191205836114, 0.24503912145812667, 0.17592607035992608, 0.28372339003028413, 0.12136553354080647, 0.12647284254912408, 0.15786283559376196, 0.22953365508827472, 0.2012475898429271, 0.1617830760416485, 0.17348856244596744, 0.16999628935610095, 0.1821388442429804, 0.13737732274157388, 0.1562496536080876, 0.1456678649711032, 0.12979435464066844, 0.24086792592800435, 0.11392773144067296, 0.16917390929114434, 0.25272168098918857, 0.19537125113269976, 0.1022255392144284, 0.16074970004058656, 0.16178211077086388, 0.13624988646516878, 0.21846078877006808, 0.1414613068223961, 0.26255098742342764, 0.17814614719921545, 0.2568464822346165, 0.2508683304392523, 0.280226995387385, 0.23310011613272855, 0.1610860892481381, 0.1729800179600716, 0.12429153741968256, 0.20019104734303492, 0.3329455810448816, 0.16412632449740366, 0.1659163808630359, 0.2763477099999305, 0.2336769956614702, 0.21236527230470412, 0.28640111247378014, 0.5104076730147485, 6.668614216389195, 62.826434796856304, 120.97392128359888, 138.79600248029158, 110.7568451666063, 92.1893959660684, 85.01109769267421, 80.70891657183248, 98.60008639674034, 110.77650408590995, 134.84669346963207, 123.84969326757617, 77.98551297956898, 58.69941103842951, 63.418920578495154, 28.241029939343854, 6.796112329729143, 0.41122024698603543, 2.092822280622298, 0.7605171167562086, 2.804417451543193, 0.902907060038659, 0.8884308174733193, 0.2626818658844117, 0.6977916761271415, 0.4911085086003427, 0.45968716723784325, 0.1880519398518147, 0.5036084281821405, 0.5436428347902914, 0.334131240003532, 0.925536378016395, 1.3409933976588713, 0.46090160045892964, 0.9261381554026759, 0.42093154523641835, 1.1464169933911295, 0.18250561649760894, 0.7848605104992468, 0.2849543707505349, 1.868204075482584, 4.081992007070973, 0.9773461076040423, 2.492783425315734, 0.843837758706462, 0.5635979543289831, 0.7661064942517589, 0.4324545494971737, 0.3138915034792116, 0.39273010206318676, 0.36673471632023014, 0.37970035607295655, 0.518450002756811, 0.6316014956082068, 0.6635167185337313, 0.5565669832210387, 1.088771757579619, 0.9355847549534614, 0.6504695670258615, 1.198945865035057, 0.6181599007498834, 0.2163909877380056, 1.2195998406217945, 0.16852189185878924, 17.68050128413785, 58.182132782474646, 95.64450202449676, 85.13571923778903, 94.51315710621496, 103.65321313181232, 106.81534167258971, 104.18819304435485, 68.28044737538984, 61.47006350178873, 73.97769789541923, 108.76212381547498, 87.69661903381349, 30.251207390139182, 1.8313931217116697, 1.1943416153230977, 0.094863748358142, 0.21474503251093052, 0.29560066399074375, 0.16212213123517652, 0.10881896686529922, 0.15164541921788646, 0.28881330884272055, 0.23631054547525224, 0.15535434197273948, 0.08804610209359277, 0.21674455263681952, 0.24526516336106488, 0.2923769353618545, 0.19251772683233986, 0.17176570731305307, 0.16327081879060115, 0.17067433845612312, 0.24289588323764263, 0.18058480424506052, 0.1028226281426126, 0.11547734345039053, 0.1574970745751935, 0.12052466011335775, 0.15549381594023398, 0.18859362530131496, 0.13540803244517696, 0.11423546129897719, 0.2327477156875595, 0.1637778004571315, 0.11548069125461964, 0.17837813394444604, 0.20944686035715768, 0.16120546106849948, 0.2053108129410013, 0.09852305159813936, 0.08053169886191046, 0.17818342503761092, 0.11460912834492423, 0.11302155667855857, 0.18429365039112108, 0.15483859626035537, 0.22538150450395, 0.09951318193587566, 0.1684851043166653, 0.21502719801520148], [0.020167831511747454, 0.022440720537316897, 0.11674573990486323, 0.027861673602714177, 0.07446189230728535, 0.043305153883392775, 0.07776957651179645, 0.07153804113547649, 0.03945027605720586, 0.05181981513517038, 0.02567233221094695, 0.06058523228632347, 0.06280687194497836, 0.031929190623604005, 0.02149025248664041, 0.06442414100972876, 0.032193860594904235, 0.053963298503790176, 0.03178660442391711, 0.06702086497699061, 0.05884527807093917, 0.14615027053702265, 0.04660057685067577, 0.10078074335451088, 0.030172639113340168, 0.09013959822515327, 0.02468422434533075, 0.019970276588273626, 0.026969968326269623, 0.05796512348517295, 0.1558908333461131, 0.04003501947849028, 0.07775629254718942, 0.10415909150915761, 0.1207564400148488, 0.06856920528075389, 0.0998418566380297, 0.040235516179593346, 0.02973987796013394, 0.13314851739954564, 0.06380156433630375, 0.07469020183047942, 0.1062912597591358, 0.03382556275614808, 0.03101303948149566, 0.022825894223886634, 0.07978858591447915, 0.042971641335996895, 0.027475504001842874, 0.1326579606581119, 0.213685670807477, 0.08697671996008965, 0.13343429883881924, 10.961829289313286, 25.896550839947118, 61.544612069283765, 70.64061595547584, 84.00693954959993, 65.68328918949251, 61.608154466075284, 70.28110719496205, 81.94252552524691, 90.35798641943163, 104.47064292046332, 84.51698103258687, 73.7207434254308, 55.273048108623875, 46.08533920780305, 30.12110237152346, 8.198071372124458, 0.1014213767203112, 1.3737572008563628, 7.046291885837433, 1.403426253987897, 0.35485177330913087, 0.6960883255927794, 0.4791586707916952, 0.2772259838398426, 0.09001766001024554, 0.30042710984426163, 0.44236558219117506, 0.3721134196366034, 1.0425107108969842, 2.290132454326076, 4.251254047116926, 3.8277577007970507, 2.3268647155454083, 0.28787426890865453, 0.38789676141835033, 0.41786400661353146, 0.4447951227907212, 1.5218399128606244, 0.02988019270912534, 0.631662905216217, 0.425646479331678, 0.3472419768091171, 0.2185377806064583, 0.5143472035565685, 0.23700494289157853, 0.3682164222963395, 0.8294466438312685, 0.8602433171003097, 0.3047615433892896, 0.14505914682822843, 0.24403608253886624, 0.40954753996864446, 0.2877955763570724, 0.26216055837369734, 0.3757460553559565, 0.3709403858069451, 0.27971172464951394, 0.4437968489383498, 0.3331981142682414, 3.6952075746751603, 23.93640910425494, 63.83548021316529, 89.7225389172954, 87.0993361934539, 95.78267143618677, 87.1927905851795, 66.61206722259521, 50.216705030010594, 40.43301943809756, 51.9078702311362, 73.423263026822, 60.71513668183358, 28.331040490058164, 4.394466646255986, 0.7171026689390982, 0.1273304090324429, 0.028276517874591296, 0.04232946430302916, 0.05741432925025302, 0.09859344741750149, 0.07157831437765591, 0.018466775410718495, 0.07902633609069933, 0.07212207592543095, 0.05123527472718589, 0.046624015310719136, 0.1869531705855362, 0.06300337732799592, 0.08161569795300884, 0.09764485436701968, 0.06461589281717617, 0.1575177129838736, 0.13705806326000922, 0.17718398673159463, 0.034389311537867596, 0.04448971733631146, 0.03548284842362327, 0.058189755786330476, 0.045260566497041334, 0.03121139305163055, 0.07443544695213919, 0.06627056612482955, 0.03340650500068742, 0.054232130247739055, 0.082333154615856, 0.013827972260544137, 0.011408732670749868, 0.06987205270918147, 0.042990441133658734, 0.041030144709492886, 0.023066461153869188, 0.03552635455684316, 0.039087809216711795, 0.008773930303211655, 0.027495657859910882, 0.047224057507851434, 0.05081456222180879, 0.06779284411740881, 0.02884348422559279, 0.04578482727670381, 0.04284697201763911, 0.06898554342408335, 0.06234202128384383, 0.06470829068172364, 0.09189651362718114, 0.019545837065144893, 0.05357504131332521, 0.06828635029735104, 0.03135576806662064, 0.028141743856512254, 0.06048468707670128, 0.07436055419666153, 0.01595722841880014, 0.04098109209970121, 0.07841201018421881, 0.06386495811203796, 0.06390874003691059, 0.04808764927269471, 0.03115954996657468, 0.03672946499840867, 0.030001454851439888, 0.03630959518974827, 0.02941353025004989, 0.1186505409197942, 0.053609932787836566, 0.06294247333801563, 0.023300970243590496, 0.02394314153089879, 0.024371072499742432, 0.05419108708719573, 0.04161050993829005, 0.07955091479685038, 0.07499295977815505, 0.04460043619356809, 0.0984392109357061, 0.06927709350542677, 0.04113781453681089, 0.08883591576088821, 0.1308239614891429, 0.10618623676559619, 0.03590128181742565, 0.10905296842177069, 0.06402471808776741, 0.06621468767163254, 0.045219423745067856, 0.06198793927568102, 0.015388108403121513, 0.03828788701925547, 0.019331935740586732, 0.018804696794118614, 0.03681515959361869, 0.0818270386286801, 0.1668190316206986, 0.29342745641066187, 1.392568152758383, 30.511372320113647, 72.2265321977677, 98.23608260000907, 89.38877659459268, 78.38747747482793, 72.39189932423254, 78.4364600335398, 77.88931292872276, 104.6543824288153, 117.46012872265233, 92.44354986375379, 71.7954715605705, 74.62043316133561, 78.77231690191454, 66.36771925034063, 37.509837765847486, 9.86350582491967, 0.2910875787417735, 2.2687724521083217, 4.483501997686202, 1.7388253082190792, 0.7870227783437699, 0.9497388728683995, 0.5155792567999132, 0.49753518955361464, 0.2404423947295835, 0.6816639318581551, 1.1190838342712772, 1.3771281102972648, 5.50581875347322, 6.109713729350798, 3.7583758754114953, 3.9717591866370174, 3.0116502411903876, 1.8272237647925655, 1.138365960890247, 1.6811420744465244, 2.045568383989796, 1.377746496469744, 0.12635321791974768, 0.5896429212823991, 0.49964999059034937, 0.2552537394747619, 0.3263867652464298, 0.7483371154915902, 0.6459120180337661, 0.8554291592970972, 0.3689325919314739, 0.8467422738190621, 0.2358143350049373, 0.5880064349020682, 0.5787111530380865, 0.38617156205638764, 0.263419455337909, 0.1791248551660007, 0.02474614148659091, 0.2727807739809636, 0.6692220510975008, 1.0009726269110557, 0.19572538293657765, 7.530307462138515, 55.37146429861746, 100.64391582242905, 93.44655482999741, 83.64104517044561, 89.29970741271974, 98.90563903316375, 87.89470657225579, 76.11964148859825, 54.151673855320105, 59.79547031464116, 80.89063213717553, 89.43396229897776, 63.71567926099224, 13.348918076484436, 2.4294707323274305, 0.28396142887011655, 0.10095358811198704, 0.08385410727632624, 0.07581272748328986, 0.013885250739422778, 0.023001060227773363, 0.06625014988164749, 0.11710587017718824, 0.1293822606244395, 0.07448064613967173, 0.16472681485597165, 0.14033426891171163, 0.0453597289179602, 0.0621463088018279, 0.05841442639188421, 0.057680345621080174, 0.0631644319923174, 0.10221418579139056, 0.12656897892274205, 0.12676824605272663, 0.09973488012028318, 0.05491731162633627, 0.10881519005183252, 0.01848921029558105, 0.0428089204304401, 0.044120114386802724, 0.05698319028822645, 0.03833455326516302, 0.007148895979738765, 0.009301355983611316, 0.07730443090681108, 0.006321716852741497, 0.05549144856030903, 0.06139976761093544, 0.05713183049773497, 0.017853238574799993, 0.04748050544050433, 0.08611911517237464, 0.06949416451877163, 0.02193672852891107, 0.013809948126905629, 0.0133267525328143, 0.05432077811189717, 0.08182102483847449, 0.013203870114539901, 0.02768673742520473, 0.02278272516935343, 0.12114688438633758, 0.19947496963845146, 0.2123288065195084, 0.1755997015824241, 0.17298367986034963, 0.18113042738649154, 0.1140681247136766, 0.15605204888889868, 0.20448656362150947, 0.16135383697767414, 0.08856978447687242, 0.12609542933322732, 0.1279295587371434, 0.18829071413605444, 0.1875160919922975, 0.13585126027464867, 0.09838461184934263, 0.15998966421090788, 0.2348773788300253, 0.23876371222638318, 0.10528448233080488, 0.25591006232125146, 0.2788992117970221, 0.20412924489186657, 0.15922023614327754, 0.1299740329024292, 0.13716174559968133, 0.12559446911778183, 0.10338217876250706, 0.1481235138471088, 0.24388173114388223, 0.18024179603784315, 0.2753280469727132, 0.15307875440245675, 0.19825684387357007, 0.2775627867348733, 0.4488679526313659, 0.22948019747291842, 0.101061177500073, 0.17766800108215502, 0.1482102962871713, 0.10640949776936924, 0.17451951760918866, 0.16981852631415092, 0.1117808543025486, 0.18070262856781485, 0.32150084032647075, 0.14905080199241638, 0.08647412797736545, 0.2742871786317518, 0.2491952097343822, 0.34236941246255753, 0.19234397809111303, 14.203781985467481, 53.49637916011196, 109.14009909476005, 119.04316594523769, 113.46589288403912, 95.63722210545694, 91.59690626205938, 95.09699406162386, 104.48618335108604, 113.17549628596153, 131.28379283412812, 116.05856387845932, 112.03825212294056, 88.03177772029754, 71.87671169157952, 45.69897005634923, 12.620518246004659, 0.34031559202459555, 3.5981225390588087, 15.314713908780007, 3.8291383750977057, 0.691734065692271, 1.1063412793221012, 0.7070101653375934, 0.4709367393966644, 0.1802080115603824, 0.43866945310465755, 1.3931957319859536, 0.6182431898290112, 3.13823125535442, 8.45345885522904, 8.476708704425443, 7.584952452490407, 5.286681325204912, 2.185234057326471, 1.1703515413307375, 1.3129545796302058, 1.3320942751822935, 4.758451811728939, 0.7555351550540617, 3.8717475725758463, 2.2302207014253064, 0.9650811625103798, 1.2600973320584143, 0.7654162796754992, 2.1587659034036824, 1.895641667708274, 1.311700156619472, 1.28792287120896, 0.8645082817923638, 1.051105604537072, 1.8232225794945995, 3.350391522530587, 1.7281574419429226, 1.7490971376818998, 0.47102937474846845, 0.5768123581524819, 0.6990285710461679, 1.4342938363552096, 0.3755876590167323, 9.747486037592735, 51.81285865845219, 95.75489321062642, 123.10197184162756, 108.69148192867156, 111.09223919530069, 105.1897624231154, 94.96164091171758, 82.05188120565107, 68.12512151656613, 77.75829792022705, 116.44665102804862, 109.69756203313028, 59.751457398937596, 7.569187466175326, 1.316457378768152, 0.4316636709676635, 0.12200088089992925, 0.13917117890331054, 0.31575907262102254, 0.2591368399800793, 0.14835353940725327, 0.1199360134740991, 0.28631163340422416, 0.2306941097542163, 0.1835247892285547, 0.1683069735525116, 0.24771548026511747, 0.26921184613339366, 0.15613950548633454, 0.2788063006535653, 0.13821975898838815, 0.16371239187015643, 0.19775723197287132, 0.2722999159126513, 0.14492143486295977, 0.19227783405973067, 0.1093836043090109, 0.1625827492605294, 0.16591564541862858, 0.0786190071413594, 0.14126817605668499, 0.18516771074744964, 0.0991737130548685, 0.15719741162273193, 0.18528472301700424, 0.11281046881190232, 0.11368825235554289, 0.12666533746185804, 0.236904907130426, 0.07101842667907476, 0.11112581848377183, 0.11411513186871045, 0.21869665192019558, 0.18785024422311014, 0.1282996404916048, 0.16084495541309157, 0.15402122641042357, 0.11827714200462065, 0.19452884552940247, 0.1681729388092795, 0.14033785420319728, 0.1936879108149198], [0.04005102688566812, 0.05913384423981752, 0.051266393218670166, 0.12461216053775243, 0.037263091202945485, 0.07967157364492455, 0.005883305801093699, 0.05925401662205977, 0.03157150225653764, 0.02253334631302184, 0.07996942096900556, 0.04483998805705098, 0.06251312319129225, 0.026287313122602723, 0.06309390210756852, 0.020482584481097518, 0.028442621058333787, 0.004210332568149053, 0.06608183270380383, 0.0621032661518022, 0.07128794407171589, 0.14981385620851673, 0.17296877178934314, 0.04148986258153473, 0.059904115004164565, 0.09455499194201925, 0.06677142674884488, 0.18241190862271095, 0.08637144921287414, 0.09544129438337781, 0.009828571947441708, 0.09511101089658276, 0.071958324631616, 0.07545184644479906, 0.04273770872743861, 0.06272413444915606, 0.07184524239311296, 0.0023517680716806004, 0.07367025535073012, 0.17469204060973662, 0.07392345507058405, 0.05577972361577615, 0.048922007122347434, 0.06550830864017049, 0.11393222071590925, 0.055129360933337486, 0.04489109761291935, 0.07471059509102376, 0.030446743457427913, 0.033206092569256024, 0.21196548166053913, 0.14313096480984844, 0.04772393753932369, 0.27823599415921396, 0.1377938141024882, 2.403416633605957, 6.917866622248004, 20.423283346237678, 79.00055962224161, 88.21438758603989, 78.7225341796875, 59.66571438697077, 57.88352274125623, 62.66704536253407, 76.80509136569115, 97.07313906761908, 89.08165501010033, 73.9709278845018, 72.48249038573235, 57.372347693289484, 43.131064907197036, 23.449495876989058, 7.354537229384146, 0.7123359473001573, 2.7509893765372615, 2.855852717353452, 1.05175708570788, 0.44791708429974897, 0.1422231199760591, 0.34497095512286313, 3.114273173193778, 2.0617605409314557, 9.662916794899973, 3.242725403078141, 0.6626982301954301, 0.46241146782713555, 0.7536505174732978, 2.4490722869673083, 2.1842698897084882, 1.3506071269512179, 0.8025020445066114, 1.7951816777067802, 0.14807492855095095, 0.17453464018481393, 0.331338481797326, 0.06415342085904653, 0.02455576097652797, 0.7076182552883703, 0.5016926567881338, 0.95058377591833, 0.6651616012377124, 0.46880698432364776, 0.5492767679595179, 1.2540121424582698, 0.9842748519393706, 0.8320734673930753, 0.6004564055512028, 0.6530964518747022, 0.6189186342300907, 0.5312209336027023, 2.7161913341091526, 4.488164715228542, 8.008991556782878, 27.094797665073028, 38.35440251135057, 71.32482636359431, 98.24453138536023, 88.68584863601193, 66.48651215337938, 60.316059051021455, 51.51267574679468, 49.899702995054184, 69.19301817494055, 76.77489696010467, 39.65557429098314, 8.259965392851061, 0.5864931967469954, 0.26330555338532696, 0.12150734407647003, 0.05600149840897611, 0.05277100139327588, 0.01714476429286503, 0.06811776498873388, 0.04774543013603938, 0.06473079834493899, 0.06567780559341754, 0.07180220357352687, 0.03017668405758037, 0.05049616841959858, 0.051021823479283246, 0.0325855536897096, 0.09419391172066813, 0.09310874051504558, 0.04853594477378553, 0.021863241544774464, 0.06929112823619958, 0.05853470219599624, 0.15061547529072533, 0.09022084951040246, 0.0956484905233787, 0.10371245458842286, 0.031595272049608256, 0.027637422430298986, 0.06217056697595024, 0.03467554879945613, 0.04193017544645456, 0.03249258508965854, 0.06493924320825646, 0.01322679816850371, 0.014999374322923682, 0.04362486918727237, 0.08016194652525649, 0.09190900852122615, 0.011983349367285208, 0.029095559711417848, 0.1354505809684915, 0.02040277918680541, 0.04725806798124987, 0.037303575119304086, 0.047248610625824625, 0.0423255878981323, 0.04101306477922105, 0.016430624790730017, 0.0017929060930093272, 0.03160470259195614, 0.05123262406296788, 0.02400058471868115, 0.12467926217904016, 0.061746966319098595, 0.03394311128724967, 0.02893977573201541, 0.08608516981644977, 0.03852081605263295, 0.09084878113841818, 0.06037445085483694, 0.06994778050049659, 0.03380429998580967, 0.0773238359139331, 0.04803511096284755, 0.0060013336159529225, 0.08110007481469263, 0.12148311271542504, 0.07570233421340104, 0.004734677138678249, 0.1041533075453293, 0.04449195431305036, 0.08274656630331471, 0.07677990582681472, 0.13609876796122522, 0.05165699846862305, 0.029049429727057298, 0.10516540928473396, 0.03495442012565271, 0.0393204203236007, 0.07423706848414675, 0.11331545098895028, 0.010863922540128473, 0.11503555586621647, 0.057441433441014066, 0.12124403965689483, 0.13911291025578976, 0.0777150540342254, 0.10516321827327052, 0.07049193275311301, 0.04268849140874321, 0.039605301609563257, 0.028909827439835476, 0.051248780857290954, 0.01893237683801882, 0.07102764271680387, 0.10615357077650486, 0.05344494043158428, 0.017157180662897807, 0.005572690664144654, 0.052121113685350266, 0.07869451276717648, 0.16471791291429153, 0.12855301641168135, 0.01217759957897567, 1.4152621285569285, 1.4416303846143907, 18.403652983327067, 43.46650992670367, 81.11805900450676, 96.25117501904889, 84.34121178042504, 86.68846007316344, 75.06062507629395, 75.37371650818856, 96.8420800855083, 105.26533080685525, 111.88737423189225, 87.84270378851122, 72.57348937373008, 86.37922040877804, 77.29169276452835, 60.74600965745988, 37.76858475900466, 12.032815794790945, 1.1797894994097373, 3.4636247109982277, 1.4522535113557693, 0.7950690304560046, 0.6422985345125198, 0.30118752871790244, 0.2662915496095534, 1.461993859660241, 3.298514990075942, 3.649930920331709, 0.7269092685272618, 0.19731480087484085, 0.1656161510055104, 0.4533068499257488, 0.5763385480930728, 0.9984792865091755, 2.0782460176175643, 2.089703260890899, 1.1872317065154354, 0.1919595704924676, 0.19639788556002802, 0.32684972750083097, 0.0025804199404158303, 0.09682390688648147, 0.5767329301564925, 0.1746746810573724, 0.2814815409721867, 0.7846980385722653, 0.7423867573661189, 1.409361903225222, 1.2977425249353534, 1.0097954470303752, 0.9302870424524431, 0.9341533349887018, 0.47318986526900725, 0.3475641014595186, 0.1697112433612347, 2.4620967622726195, 10.938446079531024, 30.35183971928012, 57.11849974047754, 51.48400322083504, 58.172793619094364, 111.1620181606662, 115.6081267326109, 95.68392184472854, 85.60719597724177, 67.96867385987314, 58.428390949003166, 78.72361675385507, 97.2642683213757, 80.32927820759436, 25.2698149219636, 3.4849479409956166, 1.0102604930439303, 0.348635858465587, 0.07198900645298344, 0.01616473482441037, 0.06546811966766274, 0.053035546875288414, 0.023971392938326445, 0.0567308102824515, 0.04765459892129706, 0.05977460017968571, 0.113763191076296, 0.05553799606258831, 0.020696081694275625, 0.04626714474251194, 0.06952014256028399, 0.05652895377528283, 0.10564253650485508, 0.05058468987924918, 0.0836528483177385, 0.005227440692138889, 0.111020757185836, 0.054538634365364436, 0.03270487954479552, 0.10277867001751739, 0.01136726145857885, 0.04898451223608948, 0.05991473298279509, 0.009514701894424375, 0.04775774116898256, 0.0707031891591126, 0.10145722963516751, 0.09428090100447017, 0.03448201583758478, 0.010728203361072849, 0.03648992462624465, 0.07703727306497675, 0.07459102408780206, 0.11475612529583516, 0.12335348573903884, 0.03913490830229656, 0.024124828858240962, 0.04428621757054522, 0.03539144264293775, 0.06874164401163017, 0.05723063668776905, 0.05011903865623379, 0.023640992623122952, 0.04727255087345839, 0.0640597781016221, 0.12849058024585247, 0.20988107899263983, 0.19848651703326933, 0.2868636763624607, 0.15333304962804242, 0.2941049539273785, 0.21062879612849605, 0.2728100691831881, 0.18648832375484128, 0.2486511340905582, 0.20769852513988174, 0.2542811908548878, 0.13696731248449895, 0.16046059377972158, 0.18531433997615693, 0.1843529455964604, 0.12556297524321464, 0.1802059890882623, 0.23578016748351438, 0.11160567297690338, 0.22850266928153656, 0.2708818871648081, 0.2862023279791878, 0.1958081817194339, 0.1825452538868112, 0.1842483745947961, 0.16440784648781823, 0.28365404375137826, 0.13956871724897815, 0.2721004572606856, 0.17171324561199836, 0.25380310602486134, 0.22454041657188248, 0.20566292227275912, 0.24745001547759582, 0.17358832241546723, 0.26900932312973086, 0.12881845055568603, 0.14327757871679722, 0.22113655002847796, 0.13595138796635214, 0.2543979273327897, 0.17460300587117675, 0.2014159912904424, 0.20406582813349464, 0.14467138376447464, 0.1476331256450184, 0.22968454376584102, 0.09926631776315552, 0.223328220327535, 0.3540710684272551, 0.4214860090324956, 0.15682884672236058, 0.6747546767996204, 0.2953041573205302, 7.363952388686519, 30.573396759648478, 79.71086948148667, 127.0960743196549, 112.50245678809382, 98.80209630535495, 87.31193650153376, 78.83009341455276, 87.15882285948723, 92.84975836353918, 118.93423388081213, 112.66423102348082, 105.13794006839876, 112.47845188263925, 87.56441946952575, 60.814780573691095, 34.16938650992609, 9.221046105507883, 0.4478322017577387, 6.641153212516539, 4.8784969314452145, 1.909860014434784, 0.9386681056311055, 0.4298209230745993, 0.35364938299021415, 3.7318930126005605, 15.330978997292059, 20.550487772110973, 3.3542955065927202, 0.9950167529525297, 0.6625124691955505, 0.7812170576184028, 3.6082753491017128, 3.512311866206508, 5.088657525277907, 10.611105657392933, 5.406481296785417, 0.3531359508633614, 0.8051321162812172, 0.43777922829312665, 0.1606660738827721, 0.12393918293978899, 0.48854343172523285, 0.6302855404153948, 1.2645325521307609, 1.1962978974465401, 1.3254919455897425, 2.5561939324102094, 2.1082597490279906, 0.9225895135633407, 1.0360338971499474, 0.9063474076890177, 0.6084317485651662, 1.0131892778219715, 1.0648307132144128, 5.702492277468405, 18.580579334689727, 38.856293309119444, 64.086613885818, 65.33971309661865, 85.98380627170687, 114.97998268373551, 110.21951967670073, 95.22981336039882, 96.7442326391897, 75.71088344820085, 75.82396538026872, 103.50472004182878, 122.7392702717935, 85.46795183612456, 16.93230329021331, 1.1728480073713488, 0.6691055444459761, 0.4074972435351341, 0.23125001379559118, 0.1253440273144553, 0.18346552466673238, 0.1611903231711157, 0.19626093968268365, 0.18194937537754738, 0.21093340800894847, 0.23590422776197237, 0.2229331028197081, 0.10447393832427841, 0.11505880663471837, 0.15450046037233647, 0.11592801765448625, 0.16423373002438776, 0.23462858411573598, 0.20780415334288152, 0.26230534899138636, 0.2346794370321497, 0.15489677297732524, 0.14694284978172473, 0.14456373308935475, 0.1926719403314975, 0.12481200223368023, 0.10240434413595546, 0.21272020084002327, 0.18312749603102285, 0.12113639664265419, 0.10792392336072461, 0.19365391183284023, 0.15405637452438956, 0.09884080954737241, 0.0771369870692011, 0.18262573908413612, 0.20894645172501766, 0.18331029993151465, 0.1688653137534857, 0.24361523979854202, 0.05234851539435406, 0.17702775076031688, 0.11643128379458383, 0.08600077757071103, 0.19196779827677435, 0.1683764883707608, 0.1256546146807171, 0.1839329302310944, 0.08809862508168144, 0.08846268538505801], [0.14552554115653038, 0.045902513703631784, 0.041569558708297635, 0.020366326808148337, 0.10023760999883376, 0.1006607816464478, 0.060410158212987654, 0.07027461659163237, 0.026583858097212452, 0.029805771097721114, 0.05701816603240948, 0.027903308566179008, 0.08529130354403489, 0.17597791919064137, 0.21063976650757177, 0.17934531994885017, 0.1144506247533906, 0.14163286455215948, 0.060168380864084735, 0.052858795069398425, 0.06206374367578857, 0.0799974368043965, 0.11184375012113203, 0.06511938878365102, 0.07105865395597874, 0.21006383692785618, 0.17553228584508743, 0.09330779314041139, 0.047446119584023, 0.05070949709343334, 0.06566144195535491, 0.052458644363909006, 0.07380543922584865, 0.07927733713821059, 0.011276337355675717, 0.036926284477475195, 0.07215068930940283, 0.0423511445912863, 0.03624984416209402, 0.07036362068667527, 0.0509191217321542, 0.004153657383510783, 0.05863481456594122, 0.08175467396335256, 0.07420490045220622, 0.055138109657432766, 0.04953978808536645, 0.08181714077269839, 0.06574817843014194, 0.026371473626744364, 0.03573767991075593, 0.06722679707191645, 0.02805621971586539, 0.1423792946603029, 0.009093742325691687, 0.2420208576105295, 0.21342835719546965, 1.3106894108556932, 9.381568124217372, 67.29597953058058, 93.20474070887413, 83.2813952046056, 72.0648128755631, 75.228682948697, 65.30767909942135, 64.82338797661566, 79.67796864048128, 86.69682256637081, 88.4903577066237, 96.55042832897556, 72.53461084058209, 50.14687507383285, 47.01003405355638, 42.19111204147339, 30.312906272949714, 16.62298910079464, 5.35029040228936, 1.879334536290938, 2.3591494992856057, 1.9395475762505687, 3.4351282014000803, 6.055481568459542, 11.055327807703327, 14.448380989413108, 15.709681876244085, 17.41387228811941, 11.557866777143172, 6.6395734779296385, 2.987057960802509, 2.337426677826912, 2.000167929837781, 0.4503890661703002, 2.013667379656146, 2.15295295080831, 3.8236678944480036, 9.542094065297036, 7.10381099293309, 4.863133007480252, 7.714015101232837, 5.605993145896543, 4.300777892912588, 4.112114093957409, 4.0228889978701075, 3.9207605296565644, 6.403856681239221, 9.39905797281573, 12.686567037336289, 16.895738955466978, 16.07000550916118, 11.778604042145515, 15.169791156245818, 20.930310487747192, 39.72041106993152, 66.11302406557145, 103.84833535840436, 101.8527824647965, 72.31352252344932, 58.537291634467344, 58.318435145962624, 56.062260366255245, 71.00155245873236, 80.74314317395611, 61.44455632855816, 17.897877077902518, 2.053886015088328, 0.6070771212539365, 0.16195639577363768, 0.06337020703921876, 0.03936219126767209, 0.005980544862517667, 0.08207417093217373, 0.13081219437862598, 0.06646948851524823, 0.018835562476587873, 0.00886131795273433, 0.06014231855290071, 0.042074004623798594, 0.030588768497710268, 0.042129067193356254, 0.008323912061901103, 0.048594596465268446, 0.015811537647800102, 0.08652616066918259, 0.011195908657335227, 0.012696163537311218, 0.05710181900330129, 0.023563431966448986, 0.028956890136243838, 0.014748575331102458, 0.08305238094180824, 0.05134980487186582, 0.04922808989161446, 0.03484518364852956, 0.02439341353883426, 0.021150235852767384, 0.05455857180359383, 0.03728920330984458, 0.0719973951157543, 0.05969021942526583, 0.03921443972015574, 0.07776177007584803, 0.02111810229478344, 0.05334740977794413, 0.0980275918939902, 0.0383601789062302, 0.05026818448377233, 0.04759596255157263, 0.03496575056605282, 0.09322139374431103, 0.05120586078133314, 0.12449511762468085, 0.12029650380774853, 0.024732953282974424, 0.080460314789126, 0.07204833996271895, 0.03794968218332337, 0.16864625857241694, 0.20545044012608069, 0.18615578030866964, 0.06317026192142118, 0.13858270080339524, 0.2199636081293706, 0.1239776252318294, 0.11320966956836563, 0.18040299625887027, 0.08980371463563173, 0.136020197983711, 0.03166152524851984, 0.1026192777639916, 0.11719849020723375, 0.22070933343662372, 0.2801494672894478, 0.1325090944526657, 0.018684424820446202, 0.14795422373760134, 0.1161570932656046, 0.08334628291307919, 0.037349241620470444, 0.1005062923556374, 0.03316110022546303, 0.07851458169640073, 0.16190895960936624, 0.11777592131928091, 0.11130862238426363, 0.04083090056214602, 0.06535047154513098, 0.04718056286595041, 0.031810808971884756, 0.10467985509744576, 0.06304841946750399, 0.019352426677341425, 0.06018973939541367, 0.0024385064616874465, 0.020153882965866118, 0.03311469444944974, 0.024066353366980632, 0.03716593593238823, 0.03381963706605377, 0.02550863645850651, 0.04965803375647915, 0.04569160969807737, 0.05245586346474387, 0.07611361617643027, 0.03736003962976318, 0.07330697645703632, 0.13005948234950343, 0.05680085370136846, 0.04981400925786265, 0.15058446405155046, 0.1550017883099856, 0.06730263977642022, 0.7426968084708337, 1.4983174589372452, 8.415867840090106, 42.17727391950546, 100.42712642300515, 99.81707234536448, 79.6519241025371, 68.22553419297742, 64.76552909420383, 63.591814733320675, 83.88605210088915, 101.08886949477657, 108.9908136860017, 105.1036742425734, 95.35965950258317, 78.69888228754844, 71.31321614788425, 69.18982536562028, 68.36916354394728, 54.219993698981504, 36.4861697535361, 17.14241485441885, 9.427497117750107, 8.039599282126273, 7.424993784196916, 9.065916365192784, 13.582154954633406, 21.788225020131758, 28.76734925854591, 30.80909590567312, 32.60570814532618, 26.444374553618896, 19.841448760801747, 11.487202336711269, 5.1845771266568095, 4.70017078422731, 6.434961567001959, 10.131118355258819, 12.027456856543019, 16.908616096742694, 23.62944833693966, 20.86943138030268, 18.460086084181263, 21.50196260021579, 15.782075101329436, 10.975192804490367, 9.366236559806332, 8.91839994538215, 7.487589418888093, 10.44993252523484, 16.26863923764998, 21.192373844885058, 27.822799374980313, 33.915114941135535, 36.91710487488778, 44.92548650310886, 56.4642797746966, 62.925651150365034, 71.1830719055668, 94.3125984745641, 118.3845058564217, 98.07356311428933, 73.172623572811, 65.30008931313792, 65.74271701997327, 80.15197923106533, 96.27475630852484, 86.68210583348429, 46.92895473972444, 7.402245998382569, 1.3260517413577726, 0.3408104848236807, 0.10256589675742774, 0.04083426751857323, 0.09374188154094643, 0.0820706928929975, 0.057889188850118276, 0.1671570908999251, 0.014263724029484778, 0.021819371519790545, 0.04322264238350815, 0.04528244596815879, 0.05300437092720982, 0.07838707402228348, 0.020621114245225346, 0.06751411834791785, 0.07134115653893641, 0.10970650270821587, 0.028187919806148258, 0.06521487398253334, 0.04560752005706872, 0.04551466253976669, 0.02323070465917549, 0.07245240537750144, 0.09572774231914552, 0.039945111399696726, 0.047108715309971766, 0.036491828354736494, 0.06772157495781299, 0.040462079022320054, 0.10005985461776296, 0.07800517919202966, 0.09568492566505749, 0.09709306421779818, 0.006653135586079331, 0.04103519705935352, 0.07273313063647478, 0.02743454894141084, 0.05000089257655125, 0.01762086878560724, 0.04542381217282626, 0.014623586171036287, 0.037840740650051066, 0.08673941656466454, 0.06149772727381318, 0.15648020010802055, 0.15886463345058505, 0.05327584950493709, 0.22827943126040123, 0.10743880584355324, 0.18500456466309487, 0.33404218994321366, 0.3009558024425661, 0.25498602238874285, 0.09786737226550618, 0.23961993805583448, 0.23973817606606793, 0.1568788722638161, 0.2214401659946288, 0.22028082981705668, 0.15172136917469964, 0.29321279857427845, 0.10254472208720061, 0.19685082738437962, 0.19517064334884768, 0.32486065681422915, 0.23830229746958903, 0.2270470562601282, 0.23531717458559623, 0.33754474393302397, 0.38372786415200083, 0.13890988163409695, 0.14422803336093504, 0.2849545852551537, 0.18586451367985818, 0.2518677074582346, 0.3235564074449001, 0.2356523686959859, 0.2212164683207389, 0.09084731024960357, 0.17358990055659126, 0.1965080183600226, 0.17107791357463406, 0.23755790515532418, 0.17959720965835357, 0.12011452728221494, 0.11885851846947787, 0.09004236634580359, 0.06447031312892515, 0.1023491551618903, 0.13271390039834285, 0.1044011829541095, 0.14594244620492383, 0.10404027127210172, 0.1967059448361397, 0.16865840872689603, 0.11389696534963385, 0.23789867638580262, 0.24844663458005076, 0.22770256705341801, 0.1805022965756155, 0.14335061753949813, 0.14969874383701434, 0.4556971361800548, 0.2937846372444784, 0.10300183909073954, 0.5766541763178764, 0.4767112037347209, 3.852585323395268, 25.51898152597489, 107.62666040851225, 130.8348304994645, 109.67641261316116, 94.49768727825534, 96.01883734426191, 85.01124674274077, 91.43798751215782, 102.1214569768598, 104.90608092277282, 105.24564835333057, 115.70211456667994, 110.1550437558082, 94.48728515255837, 83.04111865258987, 75.9665592255131, 55.19748364725421, 28.885659710053478, 9.900502600977498, 4.168675897582885, 3.6226067091188128, 2.772901697504905, 3.9393905622343866, 8.670225701024457, 16.102443510486236, 23.797659181779434, 23.302065749322217, 27.913149210714526, 25.020713037060155, 23.390676013885006, 14.393531545515984, 5.258736889208517, 5.27755004744376, 8.137738945022706, 11.321045833249247, 19.555566810792495, 25.310348695324315, 32.76085749749215, 26.255890938543505, 19.144129791567405, 22.024449763759492, 13.222749156336631, 6.749081150177987, 4.882761038118794, 6.275627045862137, 4.413976025196814, 7.275548048557774, 13.785336671337006, 20.092243148434548, 27.981394529342655, 38.746635606212, 54.18340583001414, 67.72066239387759, 81.2731965895622, 89.45333096288866, 93.84094130608344, 117.75402407492362, 126.19288582955639, 103.35081408100744, 86.24982141679334, 81.96169807064919, 76.39468592982139, 101.99963600404801, 126.50989178688296, 97.33174093307989, 37.11175249468896, 3.4003855624506554, 0.9172591350732312, 0.26735307168095346, 0.17061714233169634, 0.1341421487590959, 0.1921485643833876, 0.2207407736850362, 0.19105748663986885, 0.32667095322282086, 0.10726435996231534, 0.12446514060420376, 0.13773743003126115, 0.25587704393171495, 0.17061150392457364, 0.3196562538223882, 0.17061737215807363, 0.18377168404479183, 0.1685673055509406, 0.12035681024914789, 0.10596345839721542, 0.2642102725803852, 0.16930331686331382, 0.15214405052604216, 0.13611051974998367, 0.12228601882534644, 0.2818457698149066, 0.08119924489649073, 0.17051736704043804, 0.14532436646761435, 0.26554954748961235, 0.11701983850329153, 0.1947858220627231, 0.13654231754762514, 0.1889238398401968, 0.17601691306598727, 0.15966881126646074, 0.22269016101716027, 0.17850369575523561, 0.08543836178197976, 0.10632291451216706, 0.09556755333417848, 0.19447794664771328, 0.09794665470478997, 0.17563276593723606, 0.19270770131580292, 0.115730244395954, 0.20354669631248523, 0.20645936260059958, 0.1646406299644901, 0.16533157998515716, 0.2574482289773803, 0.29573344234978], [0.08027825399392075, 0.09781814345549192, 0.16886096237407577, 0.15228275840561237, 0.19998532209184863, 0.23816574995796527, 0.3518760426630897, 0.16392534899134792, 0.2437001070187938, 0.13055298086856643, 0.19397928469604064, 0.12345755878355234, 0.21410692723528033, 0.12875999804706345, 0.18592269039682804, 0.08182421942511875, 0.28121371663385825, 0.14402189442226965, 0.02907232426467442, 0.11400912828262776, 0.02016481121010598, 0.07657181336394242, 0.0804697453314739, 0.09555062279105188, 0.124205352528201, 0.10883427330202634, 0.05285176621269315, 0.09514435104304746, 0.03368112836934386, 0.08822221038562637, 0.05489994441309283, 0.036306258876838034, 0.021268033362444372, 0.09763314088265743, 0.03037545323041418, 0.03286313032731414, 0.04159763583072251, 0.12714549072928008, 0.023512289851843834, 0.06331164727828677, 0.14085505548263752, 0.0570952881037468, 0.02995063449376293, 0.07968920132806225, 0.08333466135926786, 0.08133586901690691, 0.01704910480897994, 0.006162975295146387, 0.051823952009961496, 0.029152340233145706, 0.021207541144723376, 0.05513003126027123, 0.10856805008745964, 0.17107091153100615, 0.04007025569256756, 0.06288842966539726, 0.06478835453069018, 0.213319925110667, 0.20838979691747697, 1.8164253571341116, 29.602011980548983, 57.61410690123036, 96.3921057793402, 103.45176019976216, 82.78818068965789, 75.38762523281959, 66.82342806170064, 64.64427294269686, 67.33219085201141, 66.99673406539425, 54.77020809727331, 65.11831098987211, 82.18706177126977, 67.63858287565171, 39.04315502412858, 23.45823491773298, 24.58680868148804, 21.64921622122488, 28.831460399012414, 38.886158235611454, 40.83279525080035, 48.498922624895656, 57.18073598800167, 62.47413535271922, 65.5696738150812, 67.80913537548435, 63.33180473696802, 39.55227082775485, 21.34111208300437, 14.720218893020386, 11.95515678774926, 11.09036143748991, 11.961136441076956, 15.807329281683892, 20.459092624725837, 19.941408403458137, 22.1207223784539, 25.323678870354932, 30.559348790876328, 30.349974632263187, 36.36970281600952, 39.77708931892149, 48.33925077992101, 52.75604355719782, 59.285664173864554, 63.130281202254764, 53.390075083701845, 51.742789437693936, 43.96141890556582, 45.13871046804613, 44.065298957209436, 56.70538394681869, 73.80458016549387, 79.85077258079284, 81.12008294751568, 79.57635571879726, 69.66368690613778, 71.16149886961907, 79.16350272393997, 93.8799375103366, 61.05981496072585, 22.188418565257905, 2.862795557706587, 0.6868537178924007, 0.05078234822459279, 0.29160042864180385, 0.16725731052217946, 0.02078547649415991, 0.09347225689599592, 0.021214119924773133, 0.09439158538777022, 0.012780031970431729, 0.07221998962303323, 0.056065275228672454, 0.05730927944363606, 0.039057993074698795, 0.06797000194989866, 0.042954385205502474, 0.07205430012676986, 0.07030458595123022, 0.023263989264265667, 0.059586782233729485, 0.07409009451587355, 0.04049818474619139, 0.05424952810449947, 0.013822357793669067, 0.03624920830911687, 0.06996300266755205, 0.0966962306730209, 0.015870796463963006, 0.02486970955355754, 0.06004090000304484, 0.1175438809478956, 0.0508737693270368, 0.05231080088584174, 0.12737714039582398, 0.08024626982308204, 0.2242881591401754, 0.04223354626446963, 0.001893716440874062, 0.08294941106390569, 0.0937037916493512, 0.06757326799655153, 0.10400244185040075, 0.022431364688541622, 0.04696546069857094, 0.022460027868228576, 0.09787695602543893, 0.15698603264266447, 0.2912857503660264, 0.1269965402541622, 0.10153095027612102, 0.1397142126675575, 0.09552522697636197, 0.11211047895372876, 0.1393557448060282, 0.31302806110151354, 0.15014960190221188, 0.39047716005194577, 0.23092459496711534, 0.2607894754938541, 0.4467783405655815, 0.48120470777634655, 0.29118456547298743, 0.36964214256694244, 0.31718378165556543, 0.20647302960916875, 0.05611939167964363, 0.18195767977064659, 0.1858220264435776, 0.1294835068045124, 0.15779833099053753, 0.30429530227857254, 0.1882609592810754, 0.08825994787677642, 0.03700181308593001, 0.0763834783086373, 0.07222570463894837, 0.08341874716983688, 0.15490440321305107, 0.06830210872595349, 0.07643693592399359, 0.03736633304206114, 0.11261644938419904, 0.01789523359958924, 0.12949227085036616, 0.03499277431758181, 0.04872162916487263, 0.02554283462344639, 0.026737994987577684, 0.06703125312924385, 0.06396074591565036, 0.035501705677879435, 0.08522300680558528, 0.05031801850324677, 0.011082933671141585, 0.09660807693557394, 0.019907288839139288, 0.09179175110353578, 0.044301784477166595, 0.04168219278536497, 0.04905299666608053, 0.054568013837260586, 0.05572610512195576, 0.07859163481982485, 0.02692741022685603, 0.024724978307682662, 0.04252868163729868, 0.11485221570417767, 0.0679107144054386, 0.03719553756978243, 0.017931278036426634, 0.07416607511620368, 0.5119337201599152, 1.2632354733444031, 11.56888275377212, 62.476775107845185, 91.57316807777651, 103.56266129401423, 102.43246955256309, 79.00528215592908, 71.90754936587426, 71.23422745735415, 75.19990059637254, 89.465129452367, 97.21864331153132, 84.82590690735849, 86.25077063037504, 99.84725106147029, 101.83199390288323, 78.85090551068707, 69.49243622441446, 65.22781179797265, 61.510718868624785, 63.54178490177278, 70.55473958292316, 71.24193099237257, 78.60513764043009, 92.40787982940675, 82.68709336557697, 96.33112076790103, 96.42717961342105, 103.86120073256954, 78.66455370380034, 61.286053349894864, 53.69478833290839, 49.68307441280734, 41.912643371089814, 47.318151920072495, 49.543492947855306, 56.13308660445675, 46.08323289502052, 42.074092049752515, 57.97584356800203, 63.788015611710094, 58.36326391466203, 65.6260225849767, 70.67575254747945, 70.72343287929412, 74.35613601438462, 84.28814211199361, 84.72735343440887, 77.66653014767554, 79.5803016231906, 71.42665893800798, 73.82629440676781, 74.18758392333984, 83.35808538621473, 90.16313091401132, 89.42934174691477, 95.32431894733061, 87.14456896628104, 74.15377309245449, 75.95008527078937, 86.91800502038772, 106.50357600181334, 92.24628602304767, 49.12192444647513, 13.452722622502236, 1.7838984896098415, 0.5208750081158454, 0.09387515019625427, 0.06351041262068095, 0.10324373901371034, 0.11154273885392374, 0.038481033106725064, 0.022065061662766724, 0.08620926073842472, 0.10801031509594572, 0.02612658404564906, 0.04904218716546894, 0.039316486462109515, 0.01794882719555209, 0.018196260188556006, 0.001055619124540939, 0.03529864258223003, 0.0479760762274025, 0.027412709689909415, 0.062168188272945346, 0.04603978133790436, 0.0416217599394581, 0.048704993565596884, 0.03204656870014245, 0.18877068354237467, 0.04677560112829651, 0.03535790331361275, 0.02538523118522379, 0.09566465497858102, 0.13334920179219018, 0.04531189438796813, 0.05305382190272213, 0.08082863454136156, 0.03564787908427177, 0.1775208815571762, 0.07524186174475378, 0.06412240961987166, 0.04613599048987512, 0.11351059656590225, 0.09074666927899085, 0.022130560265072895, 0.034495092958452246, 0.04306274451195233, 0.08715089004967483, 0.16698465982992805, 0.18896150072255444, 0.30963052244436357, 0.13937042305065742, 0.07622256920102143, 0.1551424420528835, 0.08161392828990376, 0.12461764572729027, 0.2839901418455186, 0.3351252544070444, 0.2380056988688246, 0.5663374234591761, 0.3312698403193105, 0.4746655957593072, 0.623413547873497, 0.483260182964225, 0.2991063129757681, 0.3437870122011631, 0.3990522579800698, 0.33258450848440974, 0.18047931393788708, 0.2726041447491415, 0.25857538946213265, 0.23148900258444974, 0.19387917232609567, 0.39273243097047655, 0.3468008633823164, 0.22338664219264062, 0.22546157601379582, 0.1661852164374244, 0.16163447030609654, 0.21740944034630255, 0.2346762501063847, 0.3435141010390174, 0.26095485855494777, 0.17500650438089527, 0.12631852945853628, 0.16734982329991557, 0.28377395183328663, 0.2215685623307382, 0.23594820120882606, 0.06764968526699851, 0.16602225421417147, 0.16043443953798664, 0.14941170601354492, 0.1377124862084466, 0.2772002126420698, 0.19681094484704156, 0.17244413945703738, 0.27583109094731273, 0.14156633747681496, 0.16685686104239958, 0.19087454484355068, 0.32206354722861325, 0.17894494707786268, 0.14277704751058934, 0.1628846032244544, 0.2220557789288221, 0.09241933033110634, 0.12105789561305316, 0.22520741868403651, 0.368551233362767, 0.29368415715232976, 0.1760293390121191, 0.2252108660796958, 0.15798838208279303, 0.44953291694964137, 0.48771437137357654, 3.40075500069126, 45.54400505558137, 107.5553987872216, 137.25069845876388, 131.97661676714498, 103.8050716154037, 95.35014383254513, 90.52654635521674, 93.14443818984493, 99.28845451724146, 97.00537620052215, 71.47838715584048, 78.91907630428192, 117.8290747058007, 122.66968742493661, 104.23981928056287, 108.17165805447488, 100.27505613142445, 93.87447757105674, 89.3347655573199, 99.16806913191273, 95.14863598731257, 94.28456137257238, 104.49507144189651, 97.81369824563303, 116.00880469045332, 112.028132407896, 108.33445995084702, 86.29622305593183, 71.83572292327881, 68.80470352788126, 70.04630627170687, 64.07712175000098, 67.36513091671851, 73.48421665929979, 78.43388695870676, 67.08710547416442, 79.05846165072533, 89.05569676429995, 87.08023425071471, 80.3261403114565, 94.13944152093704, 98.5981487458752, 89.43648830536874, 95.4541572447746, 104.8198123132029, 107.30172341869725, 101.08459411128875, 111.0918704925045, 97.19124947824787, 88.23683138816588, 79.73404284446471, 87.78327988040063, 107.91080474853517, 108.97022124259703, 117.47257832557925, 103.73592807400613, 89.57903508217105, 90.8213124736663, 108.33659372022076, 137.9257069864581, 100.66231958327755, 39.603202804442375, 6.844976236743312, 0.927494437463822, 0.3952748316430277, 0.3541476159326492, 0.31505525232322756, 0.19190310981244812, 0.2185974894992767, 0.21845082962705245, 0.24028050502942455, 0.16640931247703492, 0.23914382973265266, 0.12282240294641066, 0.24430847276122342, 0.1521094999606571, 0.2087287755022126, 0.18875510131399478, 0.11571094664114139, 0.20030894827458168, 0.14653608773744878, 0.16271560422835812, 0.29159019370713546, 0.14841294186490198, 0.16962542619195678, 0.14481884036814013, 0.09596558197611764, 0.2952973851032796, 0.1691060339010531, 0.20640363736498743, 0.14116135275652333, 0.13980459572086412, 0.23368517748050152, 0.11510167691496112, 0.12513244149064826, 0.14357881981038279, 0.14141206269062337, 0.39654426997707737, 0.2067844903156642, 0.14598234406402036, 0.19147241518141764, 0.3000875796762205, 0.19337528565477943, 0.1864061378423245, 0.17201572776802126, 0.08738011887837803, 0.30315542473427715, 0.22627079468821326, 0.22378532967019468, 0.24523433598299182, 0.1919366491417731, 0.11868558178145079, 0.2690930718616132, 0.21651864862970768, 0.2811689770990803, 0.554907881925183], [0.07040341895434164, 0.15868222791581385, 0.1248254547376306, 0.1939495298410616, 0.14851829427624905, 0.2369694117336504, 0.25595023597200073, 0.22351560543381402, 0.2584819573788874, 0.25950741203081223, 0.13966106148737092, 0.2610255531486004, 0.1865697895447093, 0.2845015821437682, 0.28921798712784247, 0.1620510382758033, 0.17127968581213107, 0.0759145329075475, 0.012708997425262727, 0.022544400961769205, 0.013600394351317758, 0.09703288801134595, 0.008533289637266388, 0.07138239505190043, 0.11937011964619161, 0.09238551521012861, 0.047265843773681315, 0.020247939410769654, 0.04168159906722365, 0.03358782269060612, 0.005744497372483414, 0.06592073973508612, 0.0145901923984169, 0.05560026751951345, 0.03283153303087719, 0.10087439760325417, 0.0675394375538153, 0.03016800045095865, 0.08206625724391592, 0.018406572391188914, 0.04275630934224014, 0.0055007133520238345, 0.06436607920594754, 0.006513981460293214, 0.023719472585306055, 0.04240788872383776, 0.0644377314095055, 0.07160521938555664, 0.02360056616335867, 0.03468994359155336, 0.049058209894405264, 0.032639436483863866, 0.04965359427695794, 0.04807545698337978, 0.037987300930845166, 0.12848340966288122, 0.052077676500043565, 0.030743460801820603, 0.12825244947546913, 0.33068706191355185, 0.24641567420574928, 3.3816138342503583, 34.18503284454346, 80.51584966721074, 110.89927427230343, 102.78003861827236, 91.06486812714608, 80.17302666940998, 79.90521507878458, 81.46438075650124, 79.54705561361006, 64.326851214132, 65.2174488959774, 51.59673606195758, 47.13477326977638, 55.808569308250185, 60.23905900216872, 61.51827335357667, 69.65751309548655, 70.31636930281117, 72.57758432818999, 91.3349154687697, 72.17028540949669, 101.25932001298474, 84.24794566246771, 57.945519724199855, 36.45024084275769, 41.3139602445787, 36.307972554237615, 29.604349713171686, 32.90368472376178, 33.42292808717297, 24.863306360860026, 43.90403462994484, 35.66943030203543, 46.30534495076826, 59.36390369169174, 39.41591355108446, 55.312464006485484, 53.65203057565997, 60.803797937208614, 66.73204468142602, 83.98071458262783, 73.06655483861124, 72.5680451239309, 82.0451347289547, 77.54412866407826, 57.03529842438237, 61.379429294217026, 60.491557659641394, 64.02664476825346, 74.16024500323881, 80.10271426170104, 76.62346993723224, 73.22038235202913, 71.84165354697936, 91.89521035840436, 111.26349772176435, 84.88267929323258, 29.736411994503392, 1.8283407822732003, 0.41837483404144166, 0.09601239760917041, 0.08375834628579118, 0.13042092263217897, 0.14680218071706835, 0.08867887539728996, 0.02524563081322178, 0.10394879271306338, 0.036074616871173346, 0.037829781762294235, 0.026618607845457814, 0.038305706224374236, 0.03745387390916867, 0.06319679920711825, 0.029840310171787298, 0.10347831513612502, 0.025981546364604466, 0.07054662377002739, 0.05797063165734853, 0.03948063229120547, 0.03342274223424254, 0.05787346489547242, 0.0782423063872322, 0.025568138507585374, 0.10588504163728607, 0.05975617576510676, 0.06730032619088888, 0.11094871427743666, 0.022711164896346392, 0.046021801254321495, 0.045016939045801285, 0.057440498813746445, 0.014917416321564347, 0.02019063028837404, 0.03469287387786373, 0.097109496803774, 0.022439918060216214, 0.0588102946658769, 0.07417389687391059, 0.057058990857894384, 0.07921137696793003, 0.16460888328090792, 0.04916680668811164, 0.04407427168541378, 0.028618689130751357, 0.04905290090509, 0.13025051403430202, 0.1710699156167046, 0.18262137238296772, 0.42086244410564827, 0.22517276086634208, 0.1157686330618397, 0.2245434809235796, 0.12326045202151423, 0.14791311545958444, 0.08768564240346033, 0.13726055562015504, 0.05486152893412979, 0.26830148853121266, 0.1463939324622193, 0.1679119632969941, 0.2547521817107355, 0.2482249134130055, 0.22642902248809416, 0.22010846003409357, 0.08564675301914254, 0.1988178807040376, 0.14753520428653688, 0.21481082414186772, 0.1949688557895922, 0.19258642959738934, 0.11104122705517278, 0.12146978278554256, 0.011526195016959983, 0.02190909190704265, 0.03463862336150581, 0.018573652337034865, 0.029859475776432987, 0.05311032471757743, 0.038049553235572194, 0.03181303445730479, 0.07667705086210082, 0.014147246106257363, 0.025186860378110604, 0.03449205541983247, 0.008377543962260169, 0.08871651329700986, 0.044141748709784406, 0.01665223487502625, 0.01694739514571284, 0.04582059209144885, 0.03548363749418528, 0.06418846938158236, 0.017260008814534353, 0.014980757428753762, 0.05148471678577123, 0.0779182052299861, 0.058213634746930296, 0.055837249158010374, 0.09114586237457492, 0.03783234432640095, 0.017553228967552705, 0.012211032613601175, 0.029287930134864106, 0.019792318193902893, 0.05454068365056188, 0.026513952574121858, 0.053971357748753605, 0.08398352250937494, 0.05891942772113028, 0.13845237392571666, 0.02107611684609325, 0.03528563057883613, 0.16147254996242064, 0.2285040022745248, 1.3742576707755367, 13.501509062705503, 65.14679916443365, 109.49868217591317, 118.07766668258176, 108.58477777050389, 92.29084414820518, 79.26572753537086, 73.30617243243803, 76.11329509365943, 62.37128296206075, 60.449713814643125, 81.82803938465734, 70.87906468299128, 67.02028397590884, 96.54999686825661, 99.5258677390314, 112.059613350899, 113.65273106482722, 117.12282842205418, 112.83792926419167, 136.22040164086127, 106.15142560774281, 125.20280899540072, 104.1741588038783, 79.81352575363653, 54.95947814756825, 65.65376943157565, 56.67295379023398, 56.92998278525568, 64.2198528782014, 66.28134081440588, 45.38791825694423, 73.29476617997693, 64.4341633396764, 79.03039316977225, 91.88767156293316, 67.34951203869235, 83.99367409367716, 78.5647842960973, 90.12038492387342, 91.13271728638681, 112.24278803794616, 99.68836369053011, 107.08223542859479, 101.64073128854076, 98.94957742383404, 87.71303023061445, 87.87707159596106, 79.93078893230808, 65.95092819583031, 74.40735432409471, 82.81235033465971, 81.37681776477446, 83.13491821289062, 84.42384043047505, 101.22597986652006, 117.84965145972468, 109.18373938529723, 60.74851605199999, 10.99705413464577, 1.3488589755950438, 0.6355617411674992, 0.15139366740420943, 0.12776665780092442, 0.1365023124362192, 0.073453176676506, 0.012560967213263916, 0.138884294297426, 0.07440918545809484, 0.021627922317073233, 0.021629578982209487, 0.02955441190410526, 0.04618909953522586, 0.09567518868753988, 0.01793897722006565, 0.013877386846880039, 0.06280186172995357, 0.09431417220302167, 0.05019522226986386, 0.10034787303377544, 0.012091142726280998, 0.02794769761573163, 0.04224622501961647, 0.04211998905145353, 0.037793024863687255, 0.11853476971267693, 0.07534935920228882, 0.12145319698198188, 0.018531538568617358, 0.03633838094350311, 0.019833399658842434, 0.0021906533173375554, 0.059143010481831536, 0.02869618275473195, 0.04394432785169732, 0.05298931346905809, 0.010080786286703041, 0.06652459321964173, 0.03812001800284751, 0.041004411816116304, 0.056010530585603374, 0.027830698752715707, 0.06125610314249512, 0.030683165851740107, 0.04411177168930731, 0.13983781329326092, 0.14055724646295273, 0.19533562804422072, 0.04818676955877774, 0.233809758698748, 0.17150741310850268, 0.02530222364340819, 0.09537175658249086, 0.0889890950413481, 0.10081720147882739, 0.18896202166234294, 0.27856394107784, 0.38085386998230414, 0.396182676476817, 0.19640445859441835, 0.27957842535068916, 0.35069118043588055, 0.36185397015463927, 0.20803748840285888, 0.28664362526709036, 0.20542439313665514, 0.3334553665932148, 0.22775866001123385, 0.2729356156722192, 0.3407713224089915, 0.28321550438000315, 0.23370370148651062, 0.1826798555351073, 0.10491285307873642, 0.10357772270517965, 0.104016016928419, 0.27561024312050114, 0.1285764740239228, 0.24155165940042467, 0.29421683340784044, 0.227780876561038, 0.12528820248741296, 0.14415222129994823, 0.2360934055139942, 0.13409154099081794, 0.14942829947798483, 0.2033931722924594, 0.07972100163779913, 0.1495955977588892, 0.08487914057989275, 0.18750455470815783, 0.13493989143640767, 0.09693339617261965, 0.12443949964137808, 0.09044595678607303, 0.13523621424551935, 0.14343903940771857, 0.10200975522879632, 0.130499676470795, 0.19124899329918046, 0.12523052372759388, 0.25572958732804946, 0.16728040041221728, 0.10837799899520413, 0.10336866497152275, 0.18270023347389314, 0.11770289015745926, 0.22526521235704425, 0.13593713873096053, 0.1881466129974973, 0.2538340253334853, 0.1717168155817255, 0.13698842586769214, 0.334239871271195, 0.45556549163114646, 0.3120726575293849, 5.018414739639529, 50.12651405026836, 114.71423425982076, 148.13386363367883, 139.9058606547694, 117.44267417538552, 101.66701116869527, 97.8793587223176, 99.03026057827859, 103.61143204473682, 90.79722127606793, 90.63598832776471, 71.63365025674143, 69.37552605905842, 94.56010003243723, 102.16930989296206, 115.59013874300065, 134.18294998907274, 125.24175813121181, 122.13588422344579, 145.9115114519673, 112.32052941476147, 133.19826249153385, 105.20779748116772, 89.22381739462577, 75.80098029105895, 98.89679016605501, 88.92663509615006, 79.74857914832332, 85.7607646142283, 80.9191713025493, 50.37980110414567, 88.0810191554408, 75.12779174312469, 96.39213715830158, 110.38298837600216, 83.29204836199361, 98.95777517749418, 100.54158118463333, 95.50819181626844, 89.33880559859738, 117.16241298183319, 102.6585392798147, 94.5594410742483, 105.08941250462686, 101.59757737190493, 76.62194021286504, 91.58001653609738, 96.16516528591033, 100.96008239253875, 107.20406424614691, 106.27304261730563, 95.58288158908968, 89.45855555995819, 95.85647475334906, 125.12502839488369, 149.04135888622653, 114.8570320683141, 44.39172644768992, 5.028335884694131, 0.644081803339143, 0.6023328919564525, 0.17017402175453403, 0.22035897078533329, 0.4135908294589289, 0.31056613030452884, 0.0866156320778593, 0.19907871832049664, 0.22564741362246776, 0.18253325694991698, 0.09375171044901495, 0.1195831303935378, 0.14871712473611678, 0.2333063776454618, 0.0783799187610707, 0.21810055890631294, 0.1167597133486021, 0.31395766283235244, 0.3300516992326706, 0.20181458683744555, 0.15264114965834927, 0.16281821404493627, 0.10502094042397316, 0.11489741489171021, 0.15573396918273744, 0.2607610689536218, 0.14578470870131446, 0.25684285097785536, 0.19598646570117245, 0.14650552082927, 0.1576583667267715, 0.09071231023558686, 0.08653996557357811, 0.08271501880259284, 0.12364993878309766, 0.18901724127992509, 0.10728533544968213, 0.21702149342144691, 0.146666812980848, 0.12370039333379078, 0.1699562076359026, 0.24392086291505446, 0.22575091210103806, 0.13634776185837486, 0.1035846404791359, 0.2313102589499566, 0.20221852967816017, 0.3168444353486261, 0.2556104912993408, 0.452404827360184, 0.20701036367925907, 0.09976591434209578, 0.3088429227711693, 0.1456725687509583, 0.2866048612181218], [0.05058138037941629, 0.11450300218477366, 0.040303104286712986, 0.21624134012287666, 0.09521306146897617, 0.16278387798417002, 0.18840178156331663, 0.1141753463795589, 0.12567243388583585, 0.07151639915161556, 0.02818302833475173, 0.14862274270384543, 0.07470005372118566, 0.1303959634876059, 0.06280305299667582, 0.021821761714114297, 0.15392975551226448, 0.06727917450329951, 0.0908429665310729, 0.04234088284354057, 0.12974806760828342, 0.09131054063477824, 0.02952125944918202, 0.026128056849683487, 0.007271993860241867, 0.018236983507390947, 0.07335864142664979, 0.015550476908233139, 0.058732372032658714, 0.04221208431127091, 0.01044266515471522, 0.02282669861620713, 0.008754128845588816, 0.11073197268189923, 0.021489720055533033, 0.029122106573213975, 0.06878554851057068, 0.05527525854807708, 0.06024080681644621, 0.017529076130519954, 0.07781639980572848, 0.04096834439664118, 0.02395761293178845, 0.07581276578768607, 0.010473716613506118, 0.045956224128003084, 0.04808564595277271, 0.021595807911287394, 0.03631797236120028, 0.0513910893501053, 0.08927090814517391, 0.019513479426443096, 0.11635053046648541, 0.04612654079532912, 0.038081165853767626, 0.077564035121712, 0.07406721913045453, 0.037349758729819334, 0.061273183072766954, 0.10159940789303473, 0.10988700834493484, 0.2344303205609322, 0.24203697610045635, 1.7332548071299831, 12.781549192244007, 49.37025362445463, 92.57175645520611, 120.88171420558807, 117.94339610684304, 93.53171733117874, 90.75393399884625, 74.98242870453866, 90.01244914147162, 82.17920134144445, 64.82961277807912, 53.749438716519265, 47.55844023919875, 53.793471244073686, 57.944233186783336, 56.96097343198715, 54.1674300163023, 50.661297844302275, 38.5622489067816, 51.51229919925813, 66.18747849618235, 57.941797394906324, 70.04080710872528, 59.357494538830174, 53.365768155744, 60.452781108117875, 53.27992316215269, 48.64469751234978, 39.52424941524383, 51.37807569196148, 41.21805044912523, 71.15719210716986, 51.907062222880704, 25.90635088182265, 42.24569966716152, 43.88165750811177, 38.25737484039799, 56.724560414591146, 58.05110600686843, 52.50748688174833, 48.641139922603486, 55.372425279309674, 57.17455041023993, 55.52288347674955, 71.58363219230407, 69.50800018925821, 61.40845483349216, 74.46841778293734, 76.42527257242511, 87.6572698162448, 107.69694928200015, 94.60806277490433, 57.54859155224216, 21.675135243323542, 1.4590796611962782, 0.32747369079339894, 0.12563644307515315, 0.1299167448474515, 0.02849960459336158, 0.0933379003958356, 0.16587150343243154, 0.05320774045802894, 0.049440583529611754, 0.04656262485490692, 0.010975174786102389, 0.05970445716933859, 0.017527078556257392, 0.06815043097782521, 0.05125426987726843, 0.04249827943802361, 0.08791104079254212, 0.052367847623123284, 0.01448489361322455, 0.040360859655324495, 0.01237577599127807, 0.0034442532623577267, 0.04364754538983107, 0.0386594741364881, 0.02011098395732622, 0.023810487661150195, 0.06911474415251324, 0.033784699626266956, 0.03541236450414985, 0.04847433215247528, 0.12999054975807667, 0.05029417784704317, 0.047556474549515594, 0.060890564289424694, 0.027992716772601973, 0.0660641284118737, 0.01389787395319511, 0.019796506779628898, 0.059931981452410264, 0.09538440469412074, 0.13862036168575287, 0.05554523559347276, 0.09385968288106304, 0.03497614254874568, 0.049266501540137876, 0.0851559664513315, 0.012389125073358659, 0.11692151111821014, 0.024300529208454876, 0.08651984810468652, 0.06261636886084754, 0.060634357674467954, 0.1184980204749492, 0.01241744447108959, 0.06542232293154925, 0.053113277986525535, 0.07841598618054584, 0.05928811902600912, 0.023355050305385264, 0.08253845851868391, 0.07414930545154118, 0.12116923117108884, 0.08406938564392828, 0.2059575443666789, 0.0506552618988339, 0.0696965572874873, 0.040967704713224404, 0.030803301844805963, 0.020776467300170375, 0.03246130955014979, 0.05110076117900111, 0.0589674499426638, 0.05862183320606428, 0.0281624952631612, 0.12459201242534385, 0.05378163224386592, 0.06317461713127072, 0.08466895669698717, 0.09934164718875002, 0.050948076025252385, 0.08714171231634195, 0.07549408087206465, 0.020373775097992153, 0.010216192327319615, 0.03802430297758791, 0.01708395989431489, 0.01382899977597258, 0.02466690501258258, 0.044614578176650314, 0.015827044224997443, 0.02259333291271281, 0.06714974394849232, 0.028727831762103785, 0.046958202015488386, 0.01988161914801646, 0.07554622847707042, 0.03834245929254159, 0.10961973558991187, 0.10726929356854771, 0.0615821156891123, 0.003672297288205535, 0.12184023226220762, 0.020724723806544658, 0.057244805483928615, 0.05931849441220684, 0.01313571510235629, 0.040623807844014904, 0.07834864705200158, 0.08632515451960987, 0.06100939984823908, 0.16948127908812416, 0.04982153607171871, 0.014681178745963882, 0.08908500924946801, 0.04948425437173536, 0.11143047632949968, 0.14438547975113317, 0.14691033701021827, 0.32683397673310777, 0.184259130469253, 1.96950945883028, 12.347568350453532, 40.8587731084516, 82.85904222919096, 116.38955700782039, 120.33590855136995, 116.43523693084718, 97.33072896157542, 95.85112464043402, 88.27302702011602, 84.33717173914756, 65.34121536439466, 48.67746891513948, 43.49535895932106, 44.486094751665675, 54.65557682898737, 63.201703640722464, 55.28023781314973, 52.53249199159684, 55.462380916841575, 38.91613691083847, 56.70428176080027, 57.8864449070346, 63.740060713983354, 66.61111800901352, 66.28285484929239, 62.835691590462964, 64.64306093031361, 56.12435148608301, 51.089659890820904, 37.1614489247722, 61.39077278875536, 44.18149525119413, 82.02680157076928, 67.53289853372883, 32.97324403639763, 48.35602675714801, 48.88266771070419, 37.817355509727236, 48.29653224637432, 60.92690152506675, 53.25961705177061, 40.46487692863711, 61.68849637431484, 56.83711674905593, 43.975209959091686, 64.02757829235446, 73.69812703901722, 74.23733526660551, 89.43235412720712, 93.15699761913669, 101.68411270264657, 111.01140699078961, 117.36715286008774, 88.27737300626694, 50.925226288457075, 8.308254672634988, 1.5331680856404768, 0.37599929338020666, 0.06946757360691987, 0.03431513124415952, 0.07864203574436326, 0.12784194126124346, 0.019235628912405624, 0.010463895366316842, 0.03677276811832863, 0.039403288054370114, 0.054214943065157825, 0.09775684109979099, 0.0163640440892308, 0.12454725756880738, 0.02809470605796143, 0.026466411072760824, 0.015747827860797127, 0.009645079525427954, 0.10655221228878345, 0.01871066907751224, 0.04097451906531088, 0.018963583429614385, 0.03170356049292511, 0.025614435116069454, 0.05447754268384269, 0.08043088169107515, 0.03026362546088715, 0.10968404101027597, 0.046136553564499465, 0.006807764687935912, 0.06188477787579741, 0.02789213708902319, 0.0429174138022767, 0.01013424869010886, 0.048047173017215346, 0.037310404793149045, 0.042339411954725945, 0.045892251955886046, 0.03768003455573513, 0.06246540357448882, 0.05717720588549011, 0.08616039965061412, 0.02729656118448944, 0.08409912517714886, 0.020841697771703045, 0.0655528949573636, 0.044373723963696154, 0.04091468759842458, 0.05867666211880504, 0.025671271179171822, 0.012425449132288416, 0.06895959602608796, 0.020447614482573925, 0.05997471766726625, 0.05606448998855007, 0.08291695191855393, 0.07367865167438023, 0.23284453387943008, 0.2806872916558097, 0.18900129132934157, 0.3137318507557915, 0.19679753830836666, 0.2760209581784664, 0.2422644582486922, 0.14548840121396128, 0.16240276456359895, 0.13455508547204156, 0.27616473756009535, 0.1920058728466111, 0.13002638735117453, 0.20498180882103983, 0.1633318913199248, 0.08868083658237612, 0.2442048976738607, 0.16698285186242673, 0.11166774908140784, 0.19663071500197535, 0.22708629528360985, 0.15808475594366753, 0.1455555564814037, 0.14208061230038443, 0.17325839898999662, 0.12169355706822489, 0.1346345900768234, 0.11290530283604899, 0.20551373431038475, 0.07405879216328745, 0.12271963991224767, 0.11328851533753258, 0.08699371945112945, 0.16216216699009942, 0.11545708808567255, 0.13296333862648857, 0.1546954757143413, 0.11077138024472422, 0.22764944651674843, 0.14149104635561668, 0.15381631321243702, 0.1863756935082136, 0.35607546087234254, 0.1877107242903402, 0.08682469747239545, 0.21768988981362314, 0.23998516281285595, 0.12611167039722204, 0.18706184781847462, 0.1409251218841922, 0.18943106665486292, 0.18148604540094254, 0.3423432735425811, 0.14413709872432295, 0.21136315269095285, 0.16037894412875175, 0.2106828359706748, 0.22033874606413228, 0.2895215111634424, 0.28584245051587787, 0.45046745228671264, 0.6596052574534571, 0.40979918453001213, 3.2493716141869946, 21.57723680619271, 70.3365538197179, 128.56071087621874, 162.17441128146265, 157.84637389644502, 121.61725274978147, 116.46945568823047, 103.2746651864821, 113.21475136664607, 103.33048051403415, 84.69402897742488, 70.68047508116692, 68.73940390925254, 79.02214050292969, 81.51101773785007, 83.01701176551082, 76.14940443346578, 72.98958224634971, 54.715075262131236, 83.87799555255522, 99.34109272495394, 87.89553026999198, 98.2123444157262, 82.5622521677325, 81.00676567323747, 92.19403220761208, 83.8555125267275, 84.60928224748181, 68.78553882721933, 91.95532460366526, 78.4291644250193, 108.87905751505207, 87.17055074630245, 52.50140328561106, 74.73469180445518, 69.09386065698439, 59.62099936700637, 79.78841473979335, 85.86233046747024, 73.52589576475083, 70.1801061630249, 80.19659226940524, 82.84687503691643, 74.65880178636121, 95.1563238328503, 90.15996163891208, 86.6986660803518, 105.72056893379458, 112.10993736020981, 130.68017144357006, 144.93479421061855, 136.409506951609, 81.86928702938943, 32.731584848896155, 2.5502870880788375, 0.7203350083962564, 0.3482899850895328, 0.21212983816381425, 0.1429996113743513, 0.22759387449872112, 0.36271309179644434, 0.12499978570567986, 0.23103811387573522, 0.14471405486185707, 0.10211999528110029, 0.19240624571759857, 0.15121797279965493, 0.20684444435661842, 0.20461891297130816, 0.22288456348882568, 0.178653956240704, 0.21990530883833287, 0.08219048606171724, 0.208994010463357, 0.11153949830200403, 0.11214709795650937, 0.08073281992467181, 0.11664113059880273, 0.13267505974058183, 0.16782940966227364, 0.31367825524460885, 0.09508281886096924, 0.14079870205492745, 0.13861731265581426, 0.3134468966914762, 0.1555278762093475, 0.1593351646536781, 0.16123466434017306, 0.1066536806343544, 0.1339559281064618, 0.09703962192420038, 0.11883213440136564, 0.12070349567840177, 0.12682030938806074, 0.255212631196745, 0.22479526338077363, 0.2986079574592652, 0.18679167925109788, 0.10727464852313842, 0.09146633993593917, 0.17226208632271137, 0.1711779799793036, 0.1302956672565591, 0.16611226954527442, 0.08563628059721763, 0.10422552665395123, 0.22573493150693758, 0.1235141037332435, 0.09725775779976, 0.1270047527167105, 0.14957877446807202, 0.1359980580426993], [0.10388328453465816, 0.1617156449825533, 0.12270158321987237, 0.13523302731975434, 0.106318716350342, 0.17038461932491872, 0.1724899055496339, 0.14559658815062818, 0.17126329153055148, 0.13898125038512293, 0.11051862485586636, 0.12141545949083184, 0.07530207625560223, 0.12569994410319676, 0.13398739899839127, 0.11234209031587648, 0.1908961332012569, 0.1422387481697144, 0.07419915479277411, 0.039578856254417094, 0.09711917249425765, 0.01029229262888792, 0.016798597888179848, 0.11412834688540428, 0.028465636254798983, 0.0263585937735174, 0.030547675541451866, 0.07134357737677713, 0.152583938212164, 0.0217572781783078, 0.05876924001401471, 0.09614147576353244, 0.03348288013629856, 0.06513469522037814, 0.048222745047701944, 0.03201777911594799, 0.022939683178499825, 0.015693704706556615, 0.04574449274749045, 0.050294526417048714, 0.005796764199922403, 0.010276854999603765, 0.07745209435421614, 0.038191869389265776, 0.07210713721090747, 0.054187953787585424, 0.0990896885313334, 0.02265246532436821, 0.04683427963285677, 0.050927594664596745, 0.05598885795822548, 0.04759270284745482, 0.05045452388003469, 0.032391779410142096, 0.05875299128914072, 0.08424042243390314, 0.05658334984834637, 0.04617240264891617, 0.03211573494838611, 0.05222333279708701, 0.2941563431053393, 0.11645769850621301, 0.028822029933273315, 0.13614441147975384, 0.43420833926047053, 0.026676895645176692, 1.6354446233280244, 16.280347512614345, 51.12951509414181, 91.58047937577771, 125.2744314747472, 113.72653438198952, 107.74842646814163, 88.9070075558078, 80.09834474132907, 71.74805794992756, 67.16785923127206, 74.9228165226598, 79.47941826235864, 79.3358124456098, 71.18641376495361, 68.57693149197486, 68.74557771990376, 74.99488615220594, 73.73419715512183, 79.31647516066029, 88.81210973185878, 97.29196025479226, 100.82943608683925, 92.16598726088002, 78.73142227049797, 77.66932287523824, 75.45451733373827, 74.82389434691399, 78.18731108019429, 78.25409335474815, 71.8214298063709, 76.65787696838379, 79.76179753580402, 72.00416518795875, 73.5577061868483, 68.71575986185383, 74.0117048448132, 71.49662617714175, 72.93448079016902, 70.28697506073983, 76.44007559745543, 77.66919735939273, 81.84492911061933, 91.19689510714625, 108.67891465463947, 89.4449370907199, 53.42212477037984, 36.616612095986646, 18.380585524343676, 2.778073097428968, 0.0755792468666069, 0.24295764524609814, 0.03681156281081419, 0.05446001076169553, 0.0051490526605067, 0.036880510723999435, 0.13437580557600146, 0.037511330503489704, 0.006730089596878257, 0.07496057724159572, 0.0934841925458562, 0.047722003167314876, 0.04032579581103018, 0.061337373579942414, 0.025529531506641258, 0.03323795799646647, 0.05046559768098016, 0.07237596512441674, 0.1021745484021883, 0.01593349309968612, 0.04555202081739422, 0.052279942864251715, 0.02223511019931926, 0.012233521124618429, 0.07700939512541218, 0.05302574861073687, 0.004361721118085928, 0.021686947476419232, 0.026468607829883698, 0.007242262945510448, 0.07695040635524258, 0.07171937414715368, 0.04603920294152153, 0.06684248906470115, 0.013200439955858935, 0.04990623092218753, 0.030381359768310384, 0.11629993035908669, 0.12234281658405259, 0.05015307977314919, 0.06020060252217997, 0.03883577012006314, 0.04549927949424713, 0.07513026571682385, 0.046759520942765864, 0.059006267617787087, 0.015234331574080693, 0.010361893632028614, 0.13654928894773607, 0.11366363028965651, 0.10134026333088837, 0.19890760492172935, 0.041678488750251076, 0.03883386256113168, 0.15202173692805154, 0.15175596570536015, 0.13172593808943225, 0.11574616370302056, 0.1867671644375209, 0.09737834003904174, 0.07651749006923168, 0.09326051019372479, 0.0909822259939486, 0.05843881097051406, 0.0355187013384796, 0.06508227182371963, 0.14097139359481875, 0.09879841424164273, 0.1173735719414488, 0.18942525970839685, 0.030503265424481327, 0.07491802105740195, 0.013640358285497756, 0.10277451782096779, 0.07537853949132466, 0.11488587760757055, 0.15186399942444218, 0.1674194147269572, 0.08289234517442604, 0.06367287688678311, 0.060994277272613785, 0.01890602149820376, 0.08735765718043813, 0.01719384371573406, 0.02707768603408289, 0.0451468407446819, 0.08856411542623274, 0.09225389364385798, 0.10126265862415876, 0.03912506790290918, 0.03638529233754643, 0.06546579842125216, 0.04129256046707592, 0.05257344263936243, 0.05162389963985451, 0.04263987929950799, 0.058135436322059364, 0.04243224648939025, 0.02086484511833518, 0.05553975040393491, 0.0613870888557886, 0.030828956214170304, 0.1082843370855816, 0.037802738858567136, 0.1017223573440025, 0.014360506789788846, 0.10856160728801643, 0.03331188931159916, 0.055721221311438474, 0.011814234500390389, 0.0032874635531521977, 0.0642919065731187, 0.05366388836034364, 0.01755173701132017, 0.042744170679079915, 0.09021072182804347, 0.08396611699173528, 0.019710484681831255, 0.08950951389007031, 0.16721237180454118, 0.08945500673425776, 0.2772682412497459, 0.22207243368029597, 0.01959293806594947, 0.9919196126922485, 1.6573145336681798, 12.577384921812243, 42.48551730186709, 85.05894276403612, 116.36900378811745, 135.42328188496253, 115.36668131428381, 117.13817273416828, 108.21469430000552, 98.36915293047505, 93.41376381535684, 84.57812293883293, 81.82184203978508, 77.12111673047467, 85.64443495965774, 76.59691549116566, 70.11057038461009, 80.29791493569651, 90.25223147484564, 91.21104701872795, 97.83096451913157, 108.31179649599137, 124.09411184249387, 118.0479508061563, 108.78272410361998, 97.34364924892303, 93.26237601618614, 91.43485746076031, 88.40264566483037, 93.86376950048631, 90.50518512725831, 79.06609458308067, 91.82434881887129, 97.59172347284134, 91.45133926022439, 95.08232439717939, 86.74727209152715, 86.70152941057759, 82.66040555892452, 79.87350663831158, 75.99665949421545, 84.29182129521524, 91.13787912553357, 96.7844290887156, 99.83237743377687, 109.26155136477564, 107.94450575305571, 89.18213044443439, 69.76400544566494, 45.41054248809815, 12.03104974762086, 1.7036747427717334, 0.8073837406212284, 0.13970296649682906, 0.10875296839062246, 0.0756823163359396, 0.05283608822332275, 0.16246123239398003, 0.013716745870037666, 0.027196757164933992, 0.10339487283941239, 0.12358289076796464, 0.07069594196734891, 0.10298645604521998, 0.04804101367030413, 0.06053528335366038, 0.02082817057418006, 0.09352776762698928, 0.051045679457245335, 0.039067684086940946, 0.008690347237842939, 0.03514732489542615, 0.05512248146377745, 0.02284355638098092, 0.049600638449192054, 0.02237546899836631, 0.03817115820223286, 0.036205579601829095, 0.016599690819519664, 0.0524481374680275, 0.014687159977432702, 0.02847638638359645, 0.05552132981979559, 0.09338208068642886, 0.067041480403033, 0.027415011784121878, 0.08360895147967724, 0.020480012340891748, 0.0338711871224786, 0.06654774439671347, 0.03982745561628573, 0.03813093475576851, 0.005358110394163599, 0.05109024279180074, 0.012255965585580036, 0.09490140924049963, 0.03632211306643102, 0.03450828499250835, 0.02853588077179607, 0.09487422844094616, 0.05447821301077643, 0.06968235401737113, 0.14519682814998014, 0.029649789850678177, 0.0860115257842887, 0.11545357174210011, 0.1517472016595064, 0.04572621388961712, 0.15918104308507136, 0.11868160578512377, 0.10211853971404415, 0.1959652297439114, 0.24796793687968488, 0.2632616105819902, 0.16611351060771173, 0.12366090916217336, 0.1955228292893979, 0.22885531487484134, 0.2364971185283315, 0.2748173727623878, 0.2653860643265709, 0.13748547903472377, 0.17356397614123362, 0.23740323200341196, 0.2588749298405263, 0.1708982659563903, 0.24260294653715628, 0.27341184656946893, 0.2723241549345755, 0.1758774850637682, 0.22003353663509895, 0.18170536105190555, 0.28423397231005854, 0.19142332426722974, 0.22282166767024228, 0.17363994141980527, 0.1748137413373878, 0.10318219150987365, 0.20990459789191523, 0.21428343389303456, 0.19512204273093134, 0.30631909206990277, 0.21128836718778457, 0.10124575106366988, 0.20585498051537623, 0.17815826671017757, 0.21421755033154644, 0.24594024003994083, 0.16250751942636507, 0.14699053109413193, 0.1440366492756913, 0.12013247672228083, 0.11304450101189076, 0.16600380681695479, 0.13068428833878812, 0.16813985913270907, 0.12366185145032023, 0.28250990675822385, 0.14832684890397135, 0.13625961578180715, 0.1868730837539319, 0.16478116113332011, 0.18769172530981804, 0.2008835601830675, 0.1282364995248856, 0.11640078583431822, 0.16752197857825987, 0.15198091976344585, 0.09096140372416667, 0.23635222065833308, 0.1782101002191344, 0.25604913792302536, 0.4125717180150171, 0.28773229749452683, 0.35772481752980145, 0.7640447371429013, 0.23935056621989897, 4.0198094469885675, 22.52200242011778, 66.03824015586608, 122.5736991820797, 164.81383692833685, 156.0760513428719, 150.47903307022588, 132.43446719261908, 117.57146127762334, 108.78628561573645, 99.80334404976138, 103.10336743631672, 102.85514416233187, 106.95356599746212, 95.16314875695014, 90.50970369769682, 102.55053289474981, 107.94258379167127, 106.5005793110017, 124.27883194338892, 141.9658737797891, 162.3061558508104, 157.7234938836867, 143.94770622253418, 127.20040936623852, 116.64497390870126, 113.98770147754301, 107.75397269956528, 115.74865741114463, 110.98435048134097, 100.29643304886358, 113.49044692131781, 119.38942493930941, 115.6152262226228, 117.95009551509735, 103.63202448814147, 102.86361648190407, 98.08607547513901, 99.07876460782944, 96.05768449844854, 105.36725751815304, 110.41043712246804, 124.12935041612195, 132.76598591958324, 149.96310018724012, 130.70955784090106, 95.58009670626734, 60.12498078807708, 26.274279009911325, 3.903380752571168, 0.4391565011633981, 0.5181435675870988, 0.2502464049405629, 0.16727574259763764, 0.16717317874633497, 0.19195996885818822, 0.32899079003161, 0.14634937678854312, 0.12073202479270198, 0.18533226643358508, 0.22367895070102908, 0.2768136140319609, 0.24878964278726812, 0.17373098330872674, 0.14200829360033237, 0.17009667751769866, 0.19532763008629123, 0.15448118560016155, 0.14010574488389876, 0.0938657962626988, 0.14473755843937397, 0.24506247181805874, 0.15778827991697097, 0.12845323345954382, 0.18751659761032752, 0.259551354834149, 0.10959774886648502, 0.17331386375571453, 0.11102579038349852, 0.06400930056829127, 0.19906004109690267, 0.2518466553620754, 0.146424560657432, 0.2416330792250172, 0.12031261463679614, 0.1275351383693276, 0.17687666289989026, 0.21009282569491097, 0.28213948792507576, 0.12873816454122144, 0.24601732380688193, 0.09698874602514891, 0.11245786152299374, 0.17000759681386335, 0.13858856903689523, 0.1280378682478782, 0.07833738555951465, 0.11165769800784127, 0.2907328187457977, 0.22042816384665428, 0.19057633745814526, 0.2312104989804568, 0.20004751310954172, 0.17209538559038795, 0.2945063227126676, 0.21359231533302417, 0.2517345460552362, 0.22641805210901847, 0.3025374062840016, 0.2203071985634104], [0.0636577504807182, 0.12941008493784936, 0.06058911252165995, 0.034642725762340336, 0.06688655444210576, 0.030296628528665152, 0.037512885661976, 0.12105116170019874, 0.04605767715181555, 0.031741357355889295, 0.06977641429271429, 0.03737357640338521, 0.02177366288378835, 0.02710791011791556, 0.048059710046096195, 0.03829008952203778, 0.03374812275832219, 0.0639094410073613, 0.12338391475139127, 0.05925717673474743, 0.03817940130829811, 0.09044113809302931, 0.0650772003216609, 0.06537691690027714, 0.015732529084949244, 0.04100672540164763, 0.041634672351421854, 0.048160657451878634, 0.025061932505078377, 0.04297444521779976, 0.10252926243288864, 0.028966491133154883, 0.029286419026433464, 0.04381948616355658, 0.038657869182286725, 0.04193115220855802, 0.006210305643523293, 0.042769869098499905, 0.029308183584362272, 0.02194465562370756, 0.02119155097452383, 0.013291644638464337, 0.050786113546740626, 0.0668228465703226, 0.030569713975813602, 0.058874220872718486, 0.02297356916261056, 0.04592124072294082, 0.012198063702653012, 0.0302524846272483, 0.07778796262197918, 0.046823393523452744, 0.031419742153957486, 0.03833716945542443, 0.021752679735542308, 0.07491552361076878, 0.028820428809511568, 0.04173182379153948, 0.04052282979471549, 0.05647278037823497, 0.04089795623815829, 0.07895590962782022, 0.0974811183949632, 0.028634899551229134, 0.0956435492562671, 0.07711434151015936, 0.045506388790184454, 0.22137221399574514, 0.10192462753865028, 0.3578161964974096, 4.208743889485636, 19.534413468453195, 48.21296614985312, 79.25853390847483, 103.21974415932934, 112.45327026613298, 102.16848619522588, 115.6862368122224, 103.83303811473232, 110.47543864096366, 104.55042392976823, 106.49355826839324, 105.60093664353894, 109.51326554821385, 116.61358710258239, 98.35253777042513, 66.23787310815626, 26.558360592011486, 39.95213685497161, 63.79934733913791, 77.4322783562445, 94.47311755149596, 103.85425813736455, 106.4953076454901, 110.0498850114884, 115.8118232603996, 115.74454676720404, 92.27207952930083, 58.854717285402366, 56.76344679247949, 55.45185327529908, 109.34543517328079, 117.29789949232533, 107.72311933578985, 99.41502940270209, 98.7821549753989, 100.37535113673057, 87.0444622347432, 69.47476202441801, 45.05268896779707, 19.93030417350031, 4.785644623541064, 0.09901982131263903, 0.059642446182307705, 0.08459080806783131, 0.1266175259145037, 0.14201270626677623, 0.11492579844930481, 0.00797071775812055, 0.0756061288918699, 0.032587648940182505, 0.10995292254993994, 0.03533000622185008, 0.05291373123444858, 0.10425811603425011, 0.07736096053474373, 0.03490056797501541, 0.05650233605035371, 0.06562113040877927, 0.09273046928067362, 0.035050541177512176, 0.03290496255841947, 0.020718614255348523, 0.019737655905285673, 0.01783861587154529, 0.02012712542989081, 0.014326874572303028, 0.06996657263727919, 0.06458701130243079, 0.04019729222261137, 0.02365018950865394, 0.0933585694480327, 0.013440030123738032, 0.012365623411061543, 0.05278436579711495, 0.08488729175540709, 0.022025129329713605, 0.11731720319198025, 0.015635763561623474, 0.04171297419816256, 0.05466935577832403, 0.025191924219290097, 0.040419415585816874, 0.008790705713533587, 0.02680599678217644, 0.04133257323936109, 0.0217192285063286, 0.09973931576936476, 0.09019518556493906, 0.03280887981095622, 0.09325142439094283, 0.06933057410342079, 0.04135640240424583, 0.018667567055672407, 0.07130370250031834, 0.11369654908776285, 0.02198783233912001, 0.02937378752375803, 0.08115530975403325, 0.14838991326189813, 0.08739729456964039, 0.044811443620992285, 0.13100808306086448, 0.11207573686636264, 0.09435294391286951, 0.023826851299212828, 0.04244278402878873, 0.029193563424351237, 0.0629245200675101, 0.03004874545900572, 0.05104607782296596, 0.0372045697464097, 0.08173568264370965, 0.05405871475475931, 0.10856923752374227, 0.019704999492293405, 0.015982772663025367, 0.04733695588525265, 0.0389596120634627, 0.06783950653287672, 0.031116436453415986, 0.05997880857678191, 0.06120466799925893, 0.05559794244266326, 0.12655407085173553, 0.02331360303346188, 0.019587161763000394, 0.10145809531452195, 0.027569920508070823, 0.04079065030260433, 0.004573546823174243, 0.040395279985762415, 0.036888497190610055, 0.02497598318563354, 0.039782582016121, 0.018626497082051732, 0.055556451120684226, 0.024295605178321564, 0.03193388099692041, 0.023605744917726806, 0.07182218314659211, 0.010880159773683597, 0.03930570377457527, 0.04436396400354082, 0.03528910095713312, 0.0664368225261569, 0.0319517940478099, 0.04924568310079556, 0.055796198336587804, 0.06980528814658042, 0.032894578236605854, 0.039815316953125506, 0.034774194111026106, 0.04474255699484099, 0.06626073721676104, 0.027704974148242224, 0.04587470854242002, 0.06634114580529352, 0.023273875628928506, 0.04372549866656623, 0.02003510103320643, 0.059440149174582575, 0.08593621934133192, 0.043009750379790226, 0.022659549722447995, 0.01209195190665102, 0.0800719082115158, 0.14571030624210835, 0.25131712006705426, 0.05817172973747215, 0.13843990201430936, 0.21224836728745894, 0.09960921871806346, 0.7306278593117191, 0.7894641473408669, 3.9158203044245323, 18.785917374395556, 51.14093311371342, 84.1890630414409, 112.78899377392186, 125.33118032640027, 127.97499118312713, 122.11503290360974, 133.68405588211553, 129.4666999386203, 133.68926478970437, 123.29252058459868, 127.82088910379719, 132.21489291037284, 122.9498544816048, 132.47265538861674, 119.88653829020839, 93.45610972373717, 37.46424021259431, 51.581391749843476, 81.25321603590443, 99.4496011734009, 114.40468080582158, 119.81426469741331, 121.18510169367637, 124.46730967490905, 130.66084984810124, 131.50431632995605, 106.32258215258199, 81.35844538288733, 81.47891706035983, 85.4117521162956, 126.58054936316707, 123.45763667937248, 125.02887541247954, 115.79309002045663, 112.4351724501579, 115.76755539063485, 104.28892735512026, 96.02330884625836, 74.37241385059973, 42.36220975075999, 15.606187197469897, 1.6241179214369867, 0.39909368801501494, 0.278220028886872, 0.017544518547853636, 0.07520337348743793, 0.05032678637954016, 0.01945628904767575, 0.03429063558278065, 0.04637540828797125, 0.11016452369550545, 0.03450506359278675, 0.07396872320602979, 0.06776505810839516, 0.04105510002362632, 0.05371384495388597, 0.07460274523304355, 0.050415809626781175, 0.027074275027600028, 0.037165644818977, 0.03371343429711077, 0.04339609235044449, 0.012519896282033335, 0.026722564061562863, 0.010019525108228048, 0.06510720032477571, 0.01352846348327735, 0.01451316800328993, 0.04051774680133789, 0.043027098440835555, 0.022390534117397283, 0.016527615352383545, 0.022344653111612125, 0.0044100899944051865, 0.061347259944605256, 0.026991449431666446, 0.12217448408445045, 0.02082837550269981, 0.025416001106702515, 0.05382385517981264, 0.10335370327436155, 0.04949604446489004, 0.03260655215971413, 0.015738108120257818, 0.059990571856859236, 0.04925674924086179, 0.010381624226518458, 0.06945818136896818, 0.009525241349042665, 0.06130163174783511, 0.032026014561134006, 0.008920501117714712, 0.0770543568256882, 0.018975114968094616, 0.07843145349573705, 0.05150262026056167, 0.07459192807155271, 0.07234536757272098, 0.16406957270397296, 0.10057256662196691, 0.07388757151221076, 0.08412629831582309, 0.13932526982840032, 0.019284338697851188, 0.03752852151651056, 0.2548910121643736, 0.22889769485881253, 0.1177282783112699, 0.14563087824611895, 0.1989885804153258, 0.13171593298114118, 0.18947402886565656, 0.18476496300389691, 0.2058868497730263, 0.10644332821210546, 0.15727071091532707, 0.1300554680487802, 0.14254818640408978, 0.2325077616279164, 0.2821938495241827, 0.15279680340280458, 0.18885438630898155, 0.1561236934315774, 0.3053968754266539, 0.22736882851008447, 0.09894087595204193, 0.20636591519559586, 0.10461346591792761, 0.2199239247748929, 0.13505989144886696, 0.15237352450288114, 0.1382278029115931, 0.11364630904168853, 0.18970547934934018, 0.1428607655989547, 0.17503952277043175, 0.08835589272841331, 0.173312300936349, 0.1010767673893321, 0.16641862810619418, 0.1138672641208095, 0.14822973959868954, 0.14661493350661572, 0.128564017434274, 0.10488615491457524, 0.21498538493629427, 0.17718809296286878, 0.1443930946651005, 0.12120620257431462, 0.13954455483584635, 0.09809791876543915, 0.04614603390256244, 0.10000635103713121, 0.10974968708450757, 0.12537274795073655, 0.18905861002783622, 0.18797084178415038, 0.10861807562891515, 0.12459510742055795, 0.12319629215785574, 0.1543903275723419, 0.21701390915099653, 0.21003227410537584, 0.12541404775073453, 0.17231431819738882, 0.18924705233545075, 0.20988317807355236, 0.4076463548887161, 0.16009432714312308, 0.23457633691930005, 0.2315723989158869, 0.2314335531404903, 0.4988144951001291, 0.20530295287889821, 0.6002062931656837, 6.806323730176495, 32.62438451090167, 69.86881902140956, 118.99322632820376, 149.63631968344413, 169.21650917299334, 162.51488870190036, 181.37191864752003, 169.06527826862953, 178.93033735213743, 171.623197063323, 172.90654951526275, 166.9404518988825, 161.83057631215743, 162.9855574330976, 140.4033427084646, 100.76869426235076, 38.67142808052802, 53.51904653733777, 89.40248920071511, 115.35907191614952, 134.0316406373055, 143.20374242721067, 148.4361214791575, 144.30039005894815, 149.37874547896848, 153.39791974713728, 124.95773146229406, 94.49067408038725, 90.47593993525352, 108.84849440666937, 147.31422947299097, 149.33890988749843, 147.08757923495386, 138.31168390089468, 130.68607853304957, 130.89259916736233, 115.40793680375623, 94.63525264493882, 64.53479174644717, 27.882021281027026, 7.1238028234051125, 0.4646028470127814, 0.1597239236317335, 0.4244860706310119, 0.20361988835277098, 0.21724398067641645, 0.168512039968083, 0.1716442210900207, 0.18752554551728312, 0.16601255554105007, 0.3203829341838437, 0.19526438186726264, 0.21614240752833508, 0.27106623856290696, 0.2580739695939326, 0.14756390194018043, 0.1358847689604567, 0.19808833517374533, 0.17711957405892112, 0.2395056683810488, 0.10510565442664009, 0.10527230153280882, 0.155709408403885, 0.08653354575677265, 0.18872635769507579, 0.12945179076444718, 0.18608379868730424, 0.18312461554042755, 0.1537314919574607, 0.18003047834480965, 0.12374718598420582, 0.06126308603392494, 0.07563154002831829, 0.22067887378075432, 0.2581972484627078, 0.12426666254478118, 0.2999698166405001, 0.15411879536845993, 0.1841433132968603, 0.13126286858272168, 0.12811242392466915, 0.08703855091645833, 0.08998899300011898, 0.06888606690711553, 0.10219269702511449, 0.08286655099401552, 0.22168509962577976, 0.18338007521965813, 0.2994806235355716, 0.19593100093545454, 0.19490335527206623, 0.11166249371824727, 0.21354589040481278, 0.13129994723825686, 0.2484645763592374, 0.14854642502482862, 0.16062361729000846, 0.20356669120730894, 0.28474271597881473, 0.3294575827256326, 0.13091036088524327, 0.21407269842682347, 0.12813538357975984, 0.13668120928829716, 0.09856251278711904], [0.05527886682220044, 0.051558188448149356, 0.04187606282592301, 0.0838532952231265, 0.09668737469661622, 0.06678149314416994, 0.029279265680440494, 0.09300945552005883, 0.02799896421962448, 0.0820525442700713, 0.022024280887337464, 0.06472565789496706, 0.04231007844810525, 0.038330937330160415, 0.03849019551829946, 0.03760419951211061, 0.09138640632191974, 0.041306208323446975, 0.08940598476798305, 0.07314041362053926, 0.0276680831842485, 0.020283242657540307, 0.009908402139591354, 0.045542862236259446, 0.05049886504909204, 0.025976813856452226, 0.0518224849515865, 0.04699529216234242, 0.062410766183729136, 0.04772130985774341, 0.02838843374422962, 0.018736124264016267, 0.014405765349135525, 0.01566190343920983, 0.03426439707137404, 0.0029033145091811857, 0.03126851448248471, 0.013424658569537345, 0.030176810462087877, 0.03224653297013814, 0.05954737467090449, 0.03613967688814287, 0.025494448510148836, 0.00337354454395902, 0.028117740406624736, 0.031100383080962687, 0.03188940576247631, 0.07912988053454507, 0.013386632837805779, 0.03094273942312406, 0.019619339371039983, 0.03754881518562475, 0.06202825465269628, 0.013257490523580103, 0.0833844417525876, 0.01153997693871779, 0.03206550064797123, 0.06548883468513528, 0.07157197883052212, 0.02834337245252344, 0.03706911774051767, 0.09222472101570138, 0.03743222043398888, 0.03424488864238224, 0.12813910676707185, 0.10919320081631023, 0.031814746663815556, 0.06386545989962836, 0.0300055017108999, 0.0783564917923462, 0.14282901891537253, 0.7091924127551817, 0.4250910042995407, 0.5105285616892, 3.762317857434673, 9.15464626204583, 10.520980377351085, 21.816481774853123, 33.53381349194434, 24.209798305265366, 22.335007344522786, 22.84862210673671, 13.146636543735383, 12.565650170849217, 7.246056237528402, 1.1167724550731721, 0.2624305584017308, 0.5655228574910472, 0.534262118800994, 0.06689865097043014, 0.21334076270220742, 0.7175101051407476, 3.415557045129038, 6.465293255544479, 2.1095771751096173, 4.6534725158445305, 4.2036957990738655, 0.4317825065264779, 0.41877816401181683, 0.26849708610003997, 0.1933308985204466, 1.749104246977837, 5.256395724511916, 4.734102227995473, 2.133808352293507, 2.0243756953747045, 0.8449617016219324, 0.18208331819022858, 0.07243046461935006, 0.7319203415705312, 0.6840785184214193, 0.28239110184292643, 0.04016987393580137, 0.1081695617927659, 0.08873931207363644, 0.03622183981802195, 0.07238906522792193, 0.018665148133051493, 0.00956712912152251, 0.020191269971790816, 0.08957768805445203, 0.08037838934650345, 0.04794919803257912, 0.04599011968821288, 0.08886688869566688, 0.010010864484244058, 0.010209335840397306, 0.0249886121450653, 0.018229870381014004, 0.0650356094082517, 0.051980360351022215, 0.05270995567702959, 0.03403732094973807, 0.08179403556090209, 0.03616678873978315, 0.032447696167735324, 0.11372035910044948, 0.025311508629050468, 0.04361001474242057, 0.008117018526630297, 0.04972893902431092, 0.019672954034420754, 0.04847166233605916, 0.017881484236568213, 0.056692597816788384, 0.03240325157680819, 0.027389326771240563, 0.054510369551398104, 0.034639676732401696, 0.017369980736064817, 0.09107428677980939, 0.07582099357199285, 0.018058567375485456, 0.04407580769170196, 0.024979093502606117, 0.03542396307532345, 0.09323769609533972, 0.016150680941439444, 0.031859218067820036, 0.04439467646842522, 0.023799536434272607, 0.08963407212567907, 0.03120535819400703, 0.08931676616832133, 0.06311609567473493, 0.009877351638410362, 0.14234786973364894, 0.05051832751280839, 0.11311039989513737, 0.046428816107612465, 0.08709509586614948, 0.06806554077493568, 0.0754636825032292, 0.10308479109118063, 0.042844999341234084, 0.05482623143301857, 0.10064659369809013, 0.0313528435259697, 0.11904183564887894, 0.038861767313773596, 0.0664760692105178, 0.03651532810181379, 0.03925649794719873, 0.11519792054088847, 0.0463849192695512, 0.0423454180840523, 0.005673772614118794, 0.13061762336761723, 0.02601626929977248, 0.04072150320655877, 0.0248607175965463, 0.01738515693784481, 0.0458504350465392, 0.041337686876255664, 0.024022002621824225, 0.046416773205442775, 0.030545327481963945, 0.023026967406152718, 0.03411077345991808, 0.026768025634209477, 0.0809847939038469, 0.05248635759456985, 0.033626058138906956, 0.052276878512554595, 0.04075535663193272, 0.03390695193722364, 0.00656880175454482, 0.028142682314219496, 0.014683974966887507, 0.06457807105635444, 0.023192720104669853, 0.07089161614496862, 0.05682135038378258, 0.021928962312578675, 0.025891682335866556, 0.04572538268421927, 0.04158492260161908, 0.04728868085470411, 0.017874512836457263, 0.027773150227843758, 0.038801893712051456, 0.02388410679545374, 0.04540837550115201, 0.06942773703485727, 0.051882929288812225, 0.02449137894737144, 0.03710302479204632, 0.03148904629802752, 0.01897106236297517, 0.0036992556828584888, 0.023435541248369603, 0.015928311472488268, 0.09923306954724175, 0.08646655136779433, 0.11572308913474122, 0.010996282423636126, 0.06375950227882113, 0.05428317085569424, 0.020626247034318024, 0.13658979967717202, 0.1081276261397908, 0.13400356345359357, 0.043458501703196, 0.06085455049610427, 0.05003366581795197, 0.1905735182545839, 0.12689179305227535, 1.0432514259892127, 1.5934616567627078, 3.3721300334699693, 14.322212069265305, 25.714203773006318, 30.75552417385963, 50.139544163980794, 66.84888424411898, 54.08466408329626, 48.946927901237245, 46.90143931296564, 30.29042128593691, 31.140373406871674, 19.629158319965487, 5.3617496067477814, 0.633518799178062, 0.6789372104310221, 0.1746811928047288, 0.02301023221544681, 1.1112463257966505, 2.9225766466509913, 8.335641641770641, 12.686505260006076, 5.699133748008359, 8.485412443837813, 7.1945932699788, 1.9535272712669067, 0.7791120931506158, 0.39014820189725974, 0.4640121932231611, 7.978369612847605, 13.74396449135196, 12.979379815440025, 8.98786315994878, 9.514804174823146, 5.400751204259935, 3.469628388843229, 0.5543888420347245, 1.1544162996353642, 0.4335925271434169, 0.3600996900950709, 0.0833486807682822, 0.08008996490389109, 0.021179709170434265, 0.09938572788791311, 0.07727174959596127, 0.06950811497987279, 0.08878228194530934, 0.029140659307520238, 0.02525631390932587, 0.02101780414851683, 0.053374655694971164, 0.052491111170140006, 0.04393783908697867, 0.0230317784383172, 0.04161805973478383, 0.047809195464416865, 0.031023216959569725, 0.030326343164028182, 0.025826878958351673, 0.04306627234684364, 0.06202824699181703, 0.06048674402277797, 0.01692272136889158, 0.05674150103943483, 0.07110182301051195, 0.032284155548099554, 0.007498062576257414, 0.04118690162055916, 0.08816021088991435, 0.017207888022605932, 0.026821774362976995, 0.019042704990434072, 0.026098361366518566, 0.04231871991989113, 0.07226920311128901, 0.0072051641801672605, 0.02735919653317861, 0.03667420707643032, 0.024870822296267556, 0.04738058459254042, 0.0723968256985949, 0.017688161948876038, 0.016831382620899428, 0.07013275242981411, 0.06648546144846948, 0.009684441122977484, 0.007682151110437249, 0.01606009679005271, 0.01409068104675821, 0.05212325873153825, 0.03165759521746828, 0.02776797338869543, 0.06873295657456883, 0.020793436147693186, 0.0881954585953105, 0.0723802169123965, 0.04241712774420458, 0.05661661721645825, 0.08801106889281543, 0.10316425739156623, 0.06421021478731306, 0.08710618881929307, 0.04546035073637482, 0.01871935459935377, 0.1317749830383447, 0.08785480993889994, 0.18842752211757247, 0.10949323915185467, 0.1859309335028933, 0.28240792513374363, 0.11101785371260298, 0.24354954009815571, 0.13642962601396347, 0.15393052160018875, 0.1255152862699282, 0.2858778744214966, 0.1830763520011979, 0.1680053494149639, 0.12281055156622203, 0.13163802183924184, 0.2129789087320528, 0.08406089738972726, 0.1481310827958007, 0.19759498987226717, 0.10621498038451518, 0.15368738061478063, 0.15617328996379531, 0.13131271026307537, 0.1565907465954942, 0.1255940707520612, 0.1043940430146552, 0.13277147956673177, 0.18572430426795639, 0.13550259833855016, 0.12761065165602392, 0.10356865988503541, 0.10119394819823005, 0.13986566825018776, 0.14385065844943448, 0.15324016912810265, 0.16348881677033442, 0.09372695814818145, 0.10500616258791379, 0.1606960892076454, 0.22919475311233153, 0.21132607403541767, 0.15393501087542505, 0.11261705459365923, 0.10990729435316979, 0.1454222725043374, 0.15336790662859717, 0.2612669321317827, 0.10363177786911688, 0.08236120875564315, 0.1563958078622818, 0.2205714835755287, 0.16002917902604227, 0.12735248768642066, 0.19940559271602862, 0.11190979456108426, 0.18657119914648995, 0.19568140948972396, 0.212582059865517, 0.27786156102534265, 0.2298424498087937, 0.25875753452700956, 0.13640112754318023, 0.19475926945526756, 0.3447919050532003, 0.22861145376678438, 0.22157993107553453, 0.161720747128129, 0.10638699776703313, 0.2320797176611039, 0.2520705675405841, 1.0657608052415233, 0.44512542926015397, 0.6146278676967467, 4.871981874588998, 11.122236578695237, 16.313242470064473, 31.119341658007716, 51.258435556965495, 39.3018941725454, 33.793937237032004, 32.089675241901034, 21.152453922456314, 20.772884199696204, 11.945755847038763, 2.743003921162698, 0.34943081258285436, 0.9807092335916335, 0.6031198174722734, 0.1153923613169501, 0.72005229130868, 1.8208811696498626, 6.423075804787298, 10.502173592967372, 4.254821933084919, 6.265544593334199, 4.785506359992489, 1.1972081324746533, 0.45562236599864503, 0.3272005344831175, 0.35980076258701665, 4.259455232850967, 7.603948981531206, 7.149252631971914, 4.7721271553347195, 4.681390475842261, 1.9251055318501689, 1.0375203528711874, 0.1777529908764747, 0.9578225713583731, 0.9238857956182573, 0.4026305321003161, 0.16927252012875774, 0.28609945769271544, 0.1942510314045414, 0.17839529431394993, 0.2020401384441122, 0.3573881984958726, 0.1408750656992197, 0.10994306299835445, 0.1421617716550827, 0.09765518889311822, 0.20412089453349191, 0.1725486798151847, 0.2366745904568703, 0.1669743789299842, 0.1262782485554776, 0.24330443792766143, 0.053372031843830506, 0.1375369907867524, 0.22996047331440836, 0.0886635612996836, 0.1402533853486661, 0.10133801869327023, 0.1501459706454508, 0.11856378146236944, 0.1619870546123674, 0.16585998147005038, 0.25225927031809287, 0.2482401432409402, 0.21553407242942244, 0.09158329857933907, 0.09129505799782854, 0.09423266044787823, 0.21717826565427167, 0.15925146188707123, 0.13652567811790975, 0.14439735411395951, 0.16122830581040154, 0.11666647278733792, 0.20270773810484718, 0.23823820655384373, 0.13757057608135287, 0.15941594096441425, 0.08261099172335479, 0.15567272811407046, 0.21209757054044356, 0.1475230388102993, 0.18402610184444537, 0.14029568872384487, 0.13434473304979264, 0.26807662640367785, 0.0992035675012777, 0.15783795305798132, 0.2069984127076403, 0.13736702651987154, 0.28835898806010524, 0.21562535946647968, 0.15775040452999456, 0.16483726941289442, 0.13960110744641674, 0.13244561640725983, 0.13576824698717366, 0.12476540110524624, 0.1228690500401201, 0.17280813847338], [0.03790095516089951, 0.030256177171043334, 0.034929441828881545, 0.03797159995883703, 0.054498165770764315, 0.025590523596732848, 0.022308543557301167, 0.03939637028041386, 0.04091892789508547, 0.05573263219107063, 0.014852651248445675, 0.03903000022194559, 0.07533520955832736, 0.01621955607627188, 0.05023725751426913, 0.03749064229909451, 0.05325835971762577, 0.038828319914999514, 0.04549486682780328, 0.010988173382957617, 0.025364759400667205, 0.01738575448642575, 0.059608336117479115, 0.022913538512863943, 0.08094134139678172, 0.0449749727493092, 0.008601908132644191, 0.026232671901403416, 0.036920665222550594, 0.0790162543736158, 0.019611791489766012, 0.07207856979221106, 0.07517688982789555, 0.07375991062050866, 0.027162765843733668, 0.02052830652363839, 0.04210685064355212, 0.015525673854074653, 0.04896863506385877, 0.05536400983410497, 0.05283319241096897, 0.052173100411891944, 0.03817946642577168, 0.01376646689154328, 0.07355171090532696, 0.07444129986388069, 0.06463599496430929, 0.021938764407569845, 0.04228552149969243, 0.006727123400196434, 0.048298645208800034, 0.041392849037243475, 0.10192828177804909, 0.02887000618953138, 0.06577281581778681, 0.0630608071092396, 0.06858067361698036, 0.04505661090896015, 0.021777562271322937, 0.03078223825732787, 0.04722805648681618, 0.07166034707258787, 0.04408733348452276, 0.03991387416458419, 0.09081722597681707, 0.023673455598914338, 0.07511738011793745, 0.038770832677161506, 0.03812436555181781, 0.011567539824623496, 0.02291404796133359, 0.30843524142138423, 0.3613216616213322, 0.22418309784223958, 0.18742134223782247, 0.29250530105444694, 0.26770056916340706, 0.48018397222603526, 0.3847654842801633, 0.21175589532621447, 0.41696164696927995, 0.6189112184989838, 0.4235538642012304, 0.5044731882310683, 0.3198977553796384, 0.0509815464066642, 0.03538606087526968, 0.16402147770408662, 0.16906501755358713, 0.12258533703824206, 0.04872576987010337, 0.050429928627225666, 0.071383643775217, 0.23578166901584596, 0.11952322997873831, 0.1457775534401017, 0.1561236934315774, 0.03481716015225938, 0.09516554869591229, 0.09482062526888425, 0.12191743094233737, 0.0769155263720501, 0.45774384732207946, 0.29269087819322465, 0.12952242407106584, 0.07548813602977222, 0.09298753774454517, 0.023889712643839663, 0.2096517735551442, 0.28719560693829294, 0.2230502376633306, 0.0666610564615938, 0.04646674895118322, 0.023241123454945705, 0.02779981391804834, 0.05130905282473372, 0.02376409720689539, 0.026937555146193313, 0.05231323321500132, 0.02207201199545976, 0.008055594554471393, 0.06265304915066208, 0.0492238381036347, 0.015604965869457492, 0.030812295717037017, 0.07831159903998337, 0.0484890295493026, 0.03761819976892683, 0.009001378935100812, 0.0962993971282436, 0.02585391037075991, 0.04058811580762267, 0.03344059208287828, 0.07659642776894955, 0.01497288204489216, 0.02745568913768136, 0.005605929303959373, 0.06008336042624809, 0.03342410970118738, 0.026897189973462975, 0.0366479302606275, 0.03599588218475542, 0.03429235545017066, 0.06499119163040193, 0.030182460360529444, 0.04867603544205908, 0.04452945814738351, 0.09146147527761998, 0.036080435308958256, 0.02717993195889698, 0.06917052301428012, 0.04135482809356144, 0.06938237696886063, 0.03337693017637057, 0.054846007992783864, 0.051469950441030726, 0.07626393794893258, 0.007137396999995315, 0.05253870055199631, 0.034026844697373534, 0.016237017135286046, 0.11287134981924489, 0.06915499441205494, 0.04907482251104328, 0.044575396609762986, 0.02337871859180591, 0.03651034853030597, 0.044059367444846904, 0.009626079587295893, 0.06056847028254021, 0.11997131480564995, 0.07240452488223392, 0.03257534556811856, 0.052077653517405835, 0.028778577426208124, 0.017274817294110695, 0.02043339780591909, 0.023677768673928037, 0.07271781653886841, 0.02331595492338942, 0.0602638392498897, 0.06709113822228487, 0.010145154909320898, 0.03469137617597177, 0.007998591867245494, 0.12233599074064724, 0.04541900114066178, 0.06724766530697385, 0.030256401251761184, 0.07946469926185186, 0.05413798953316385, 0.06677012439937362, 0.04168863558480817, 0.047008223726504275, 0.029752790372097687, 0.006724646542176244, 0.007912448631794824, 0.05129625915639824, 0.046776164202920856, 0.008818446714881687, 0.05023964770859288, 0.024280291080715197, 0.015169079077520199, 0.0276561456191684, 0.03038992080086422, 0.050384043791000886, 0.050886620451966603, 0.0792105495929718, 0.012920473123930637, 0.07255739772752409, 0.03875134340036781, 0.03309484128089201, 0.07445503582036303, 0.056066071960113706, 0.025439194418610107, 0.03482784707880309, 0.12161243601792282, 0.08726461580203426, 0.061898843250087196, 0.041866387135439345, 0.1231085367861294, 0.07470928508067325, 0.039664194618742314, 0.0534778937036472, 0.08420361190914147, 0.019174366776320725, 0.03894308754693597, 0.05340485871138592, 0.07822663222830142, 0.037403714302326405, 0.08468594086626846, 0.09147052277600573, 0.02926855194081943, 0.046255496375623255, 0.029640029890522845, 0.021631921296037977, 0.08381070839541574, 0.0819778583583332, 0.09392794897599567, 0.008919084812664698, 0.09805439731046077, 0.11466155940246199, 0.10093188484109218, 0.06560554051952017, 0.022418938742409793, 0.09738872819129499, 0.01956909549452605, 0.10729145649219714, 0.20718584377919474, 0.24273626115773958, 0.0730650382296693, 0.052257695670930616, 0.2059051592744166, 0.6212494414179557, 1.13299022999502, 0.31345152386253883, 0.26496143711190073, 0.06084511612331676, 0.054272303898488326, 0.3442732022414285, 0.2611021006539945, 0.10201960711950257, 0.022161701739194895, 0.1492544588062071, 0.12924637194843064, 0.03358490006517499, 0.011525956572093552, 0.041307598773029544, 0.06591694759986093, 0.22348721421534018, 0.09768069962099676, 0.156567043835117, 0.1553867015266611, 0.05017456470898563, 0.007588811915352821, 0.018092943655867732, 0.05507213799583335, 0.10564442874202806, 0.3452045506527347, 0.26701225448519955, 0.18274273603193222, 0.2027161344284973, 0.20752551184306223, 0.0680887915434376, 0.20172398927952015, 0.15551696711730573, 0.1478655567212451, 0.0871347945423857, 0.05851565725019863, 0.018501892881167513, 0.07924578197660946, 0.09468398582670959, 0.09472061249036944, 0.08772891104942368, 0.06132169176013239, 0.0062662990099089525, 0.02767404143307959, 0.009463271539237712, 0.0026742417708925546, 0.033608231272908955, 0.02194718754429731, 0.00947816716131544, 0.07132229545424063, 0.021858229414529858, 0.034344759694631063, 0.07281018375989891, 0.019217549237392603, 0.0871523532776102, 0.010584545595901869, 0.03847618760060399, 0.04948626152209697, 0.11485503490773902, 0.05805728769290352, 0.06325692178741579, 0.01892677673529233, 0.03372536611653144, 0.044633217095848055, 0.053758036735798084, 0.054579539630081386, 0.018532268267365235, 0.048242483303071036, 0.04148074996567542, 0.016624144346062696, 0.0679788655871826, 0.08338504696204778, 0.02462894152549486, 0.0348320720537055, 0.03894265470725875, 0.04725696864507852, 0.14580464230910425, 0.08040931631600665, 0.03650948668139116, 0.07311257398537091, 0.005019717387885096, 0.02938779735667331, 0.08341337689348767, 0.06743976951486642, 0.04909805795778671, 0.035054685713182536, 0.049658750048688347, 0.05602058548960955, 0.04986106237817196, 0.05722354271359021, 0.0917372745912402, 0.02086878089504617, 0.025010822949210004, 0.03842166129259333, 0.04727130215014181, 0.05165920480184498, 0.010136113156594578, 0.012723518621867463, 0.05821566104949002, 0.12146426695248774, 0.06926341117509911, 0.17597349120243905, 0.14596210402106086, 0.14628687933568033, 0.1434097442054941, 0.15752171196283835, 0.1102032800835948, 0.1755770560233824, 0.32858369090864736, 0.20789502669245968, 0.2406021087400375, 0.158064010282678, 0.1883703106713872, 0.16136587987984383, 0.12710697948932648, 0.15584891301489648, 0.16449792310595512, 0.14511205286027926, 0.06805642432863675, 0.07873081767390813, 0.11525026732875455, 0.12229577878550177, 0.1507394436386324, 0.1933667820788199, 0.1852580478354808, 0.14738330437291056, 0.1292010348650717, 0.10588075920578935, 0.2048436525247751, 0.07829355000848733, 0.19244525491470293, 0.17316528866367956, 0.27299294969247234, 0.1039299316283676, 0.08108298339310192, 0.12551169331756332, 0.19528308973437358, 0.07686932360933674, 0.14859306445765882, 0.18759158229635609, 0.11713893453200018, 0.09212960353902272, 0.13660437066949185, 0.2465618284599435, 0.14963655281932126, 0.18433393129417974, 0.16320435300229058, 0.18360332856255193, 0.05297406448892528, 0.1267874825205053, 0.172806560332256, 0.1894794221246435, 0.14460315597393822, 0.16544272402121177, 0.2123730710797733, 0.10722564953950145, 0.19235864101398378, 0.21309028259448468, 0.16653993046812474, 0.23397452888950226, 0.19467273216334083, 0.22056927724230677, 0.1158375733141457, 0.25139048064668335, 0.19324809973759038, 0.25090551634709685, 0.2833457086836138, 0.20482879041904406, 0.18091031500408727, 0.20327133366898184, 0.6391208018026044, 0.39561374894072937, 0.257876533414087, 0.18143035080884734, 0.23609524412501245, 0.2767022554912875, 0.49736404551133034, 0.5213561726193274, 0.26239651345437576, 0.5422136824457877, 0.48003268518274833, 0.29608596536901693, 0.6988149244458445, 0.3585453283402228, 0.14568986701628855, 0.1460097700117096, 0.26312733069062233, 0.2822876493296316, 0.18230667878543177, 0.10560238583674354, 0.16055784098082976, 0.1377233033699374, 0.3534044800025802, 0.239873313975911, 0.20473283024564867, 0.23303185769867515, 0.1478574515110062, 0.12277219354385331, 0.16848815334660394, 0.15145667047510225, 0.1567436730669391, 0.41646188185099636, 0.4213438844007831, 0.3142784391680072, 0.17556507440824665, 0.21312498637745458, 0.13468083114393298, 0.2918307146718425, 0.3390992895489739, 0.45188287633561325, 0.2293204221754305, 0.2628335512934193, 0.22256144292412267, 0.17798889999187764, 0.12306140705702767, 0.1484047447241122, 0.15201966849065598, 0.32744497781799686, 0.18406276681250144, 0.14822066911766607, 0.1547193316923034, 0.25152165022107864, 0.1451307454056317, 0.14584192014749975, 0.23949921792072637, 0.17666375174397425, 0.15719943409485204, 0.11931727490117473, 0.17935128011290105, 0.10587938790840488, 0.1549553633817742, 0.060525730237244606, 0.16393624276163118, 0.13284923749104624, 0.11026773872154375, 0.18780541275778126, 0.1271084656998996, 0.07667905035158319, 0.23837486131777688, 0.12230071239173414, 0.18886961613691625, 0.11055875254134018, 0.1409106581441818, 0.1824674346754628, 0.07952117526362981, 0.07008158541735142, 0.20220876971800483, 0.17612683136136303, 0.08162928069190634, 0.1332166072942557, 0.16805413389398208, 0.2359935229704265, 0.19073387577889428, 0.16575545643366155, 0.1675377140242246, 0.23738792556668484, 0.08731356882039579, 0.10687799117858372, 0.2789872812647974, 0.16064793292072513, 0.22053426702416715, 0.1562956342053029, 0.09594120505836704, 0.13225862966670146, 0.12122875620280543, 0.1487849541609326, 0.19353919782705847, 0.10306691825990716, 0.16359750932503134, 0.11707113575070136, 0.2039069108544819, 0.10898176821008806, 0.11990312531950975, 0.10802991162504881, 0.06757139874201629], [0.03047315433861748, 0.03509806927233454, 0.039352948416865645, 0.04228973115283636, 0.04004276845784437, 0.008454885326265808, 0.015542690582092733, 0.03664176708327667, 0.02261739764963427, 0.02381350221713224, 0.01775187556631863, 0.05078892508942274, 0.03896443075650642, 0.04853784084139813, 0.0368285661322936, 0.021636774463038293, 0.07585430307494057, 0.06674811469330903, 0.027237934390864065, 0.08903110730311564, 0.11844244079604266, 0.021714495998176358, 0.030160533008916728, 0.042941580045848124, 0.09255336507433846, 0.04046418576411182, 0.018771429426006733, 0.015594463761625512, 0.1305541759657283, 0.01533224335646317, 0.005090371761921673, 0.042904512881631815, 0.019180478242736672, 0.026132019439471826, 0.08498843068317061, 0.05340428031500309, 0.021748224934262615, 0.08240642326493418, 0.05019393907259068, 0.036496612573823625, 0.046588675674772075, 0.08817433755123809, 0.05430901866225947, 0.05968433970044698, 0.08192427050802978, 0.05536145876131712, 0.0846368193085636, 0.014647175933444693, 0.02345984730298721, 0.02344508670390614, 0.014370508067640326, 0.026275630281757445, 0.05444714431500724, 0.03589828641364171, 0.016143927876386913, 0.023777407984579765, 0.022401600257463516, 0.02968508926700921, 0.027961996646838325, 0.05591594554003208, 0.02489235128215965, 0.057337486801008065, 0.02564315958279035, 0.0144145485471874, 0.007053106260906545, 0.018939936210611658, 0.06014748198551036, 0.027682278793485417, 0.055689566558407205, 0.03222037489796358, 0.04665257889897593, 0.2366124300826942, 0.19348845216295413, 0.1401720574546245, 0.10518214830587949, 0.08999882190818749, 0.06376392260614423, 0.16728249949312982, 0.1221526429177292, 0.050097354537537025, 0.05802624964065129, 0.44689009747197556, 0.09390957818757142, 0.1153029818388243, 0.08250039927060566, 0.09042499662046471, 0.04151063122516198, 0.1810095387120401, 0.12357061803941766, 0.048540545131770835, 0.044887811095724185, 0.023620262283891923, 0.07451887392709333, 0.03736838998813783, 0.04896574308194461, 0.03376707577356889, 0.07745845288398766, 0.05632943383628323, 0.08463022329153554, 0.16692504286766055, 0.1623029433070652, 0.0217022615740256, 0.10736666334372376, 0.05565136941450258, 0.11807452707040696, 0.01768857946679477, 0.017751092241416057, 0.022371613660887368, 0.12324598828150381, 0.21720529323624027, 0.08716184510699204, 0.06187307588275402, 0.04551058695200951, 0.04862278850088197, 0.02799642463815549, 0.019437483504354473, 0.050297675038417505, 0.12486116975666055, 0.046701520426018585, 0.03057172878705446, 0.051060304075719855, 0.0060055590696602825, 0.09146874545202141, 0.05020294826658023, 0.035325559081449624, 0.02923358577273546, 0.042858133918695876, 0.021353425352924296, 0.07211259175692836, 0.016098267120879986, 0.022020758798105583, 0.04338036073491939, 0.07182365403540673, 0.0893761762868493, 0.02152193788318865, 0.042721831555207895, 0.028523071781702103, 0.022978387855654283, 0.06129463736508643, 0.006250580800922528, 0.05034702259206003, 0.03049254785442064, 0.060448048921722564, 0.06372484063068706, 0.013738780473959784, 0.04552315845484695, 0.07605127194115231, 0.04765127409970568, 0.035632775660844586, 0.008978454711576624, 0.05453915530515294, 0.003182643094107569, 0.041124461624290676, 0.05823519246111955, 0.0220230168422624, 0.04912770556045636, 0.09873383302962589, 0.026317690424020254, 0.07345761232558759, 0.016515884631043, 0.05909193156948013, 0.04828688575916233, 0.02872505277815846, 0.09039160284784534, 0.07780100143845044, 0.032557170132115, 0.025807542899142832, 0.05835204385221005, 0.08452883921563627, 0.030083338159226605, 0.0633403449319303, 0.07777305455097268, 0.04890478929624923, 0.03200133886909293, 0.0625177503623549, 0.0148140155192044, 0.053624365884330005, 0.04580017967870639, 0.03751759710271032, 0.06387176863368481, 0.021520160559204318, 0.011536312165610012, 0.036842623845704144, 0.018239189840612874, 0.038307506530996294, 0.011726589253803175, 0.04988561549614515, 0.015581817565215452, 0.11963055889693, 0.030282942367897882, 0.07244447636748515, 0.08537646953857715, 0.10145270205553501, 0.08574171727823635, 0.026584683556950865, 0.04745738490694954, 0.0367775408460969, 0.05473716605094172, 0.022836389628449277, 0.04322895494800422, 0.05251470284776823, 0.005941463844670404, 0.04667176557103953, 0.08273947999001512, 0.04898296856892206, 0.09722404993109166, 0.028569782077665293, 0.06080912914307368, 0.021062559005053296, 0.005980253270301487, 0.026878143112445553, 0.10353811595949436, 0.04078323074105767, 0.021866874716755365, 0.023884742648430893, 0.01978222690072031, 0.035886251172351266, 0.07792346825402591, 0.016066742602795843, 0.022838249306885466, 0.06951582182439105, 0.02814629441878248, 0.024382734273169792, 0.02555031930246661, 0.044303619257745244, 0.010077489235798919, 0.06305281681218936, 0.0214846849426507, 0.054373634348232905, 0.05725681391214171, 0.05753065587111539, 0.02813184600053055, 0.06670564277878692, 0.039328000763611454, 0.050230508279656215, 0.06322477673811298, 0.01637471952445565, 0.03944310164379497, 0.14353084738456434, 0.09129713409610334, 0.0590182607242417, 0.03791788570402611, 0.03525494109658945, 0.049853968403993115, 0.05293980120651184, 0.04915758681994292, 0.06903772933348533, 0.014782334910705687, 0.1437818790755926, 0.12093653196408866, 0.04515355933577784, 0.07178662900602625, 0.05551340464021891, 0.12330128450787838, 0.10583383632042717, 0.0807237264610106, 0.06576179947343565, 0.09774834518471072, 0.04188399949681856, 0.155588029433162, 0.04617021546789235, 0.03627500631996701, 0.048382983828384074, 0.198578447584183, 0.10569790934002209, 0.046518333481564644, 0.026154950366265355, 0.024814078163716103, 0.03365637606851036, 0.06656551763655678, 0.06734233079177719, 0.1016542751101717, 0.028922929458560485, 0.04403867924045171, 0.02083354276574908, 0.07941413745884934, 0.05072119908647672, 0.030792741322769757, 0.07419792139121602, 0.04281219162587677, 0.1309877357655956, 0.11204288701616949, 0.034439674158009796, 0.03304965358467833, 0.017827377361696095, 0.08821135491973932, 0.10368566449371078, 0.12056793642020035, 0.024486830300321023, 0.034840587120983875, 0.06660866370845227, 0.010906216339208187, 0.06550989444217374, 0.04262910810329261, 0.02602621312102964, 0.022833409546423825, 0.04566912118706011, 0.019030775086233215, 0.08184655088811152, 0.04460078476357364, 0.012100486126127503, 0.0699651400528608, 0.0592785582487141, 0.03742968468295951, 0.06378047776618792, 0.03694075587836485, 0.0592262804087612, 0.02005547322633286, 0.06435665632447889, 0.0912367050806361, 0.05801919014042905, 0.030579788032017892, 0.03074640066423003, 0.07867275587012691, 0.04582600067219427, 0.04263641275165062, 0.013637835941007061, 0.04081612655652627, 0.053862217032620986, 0.03706708760751832, 0.01716246092391591, 0.05356310566346492, 0.032546084839850664, 0.04200725921339566, 0.019689924797163378, 0.014657624415121974, 0.013817191488229701, 0.054528698204986514, 0.024184855677547957, 0.07107569941229398, 0.07323855714451882, 0.022910575667816787, 0.028807903271949584, 0.037949996279372324, 0.04669958605400978, 0.006829337245078698, 0.05438304573838269, 0.047278308024209355, 0.07764461224958782, 0.01900819655988486, 0.013302793132982427, 0.05946480954486517, 0.012432373609514007, 0.02260813947706934, 0.03887253467954936, 0.08346737843127021, 0.06351274152797076, 0.015856733962502933, 0.027432133849229545, 0.02281042882391522, 0.06422186698464137, 0.04694316753997438, 0.1742947167686878, 0.13839793571781728, 0.07346192540060129, 0.11385460834830038, 0.1474496629089117, 0.1293464536748586, 0.10173762547633342, 0.061867242123210625, 0.12532839912079996, 0.12854840456237718, 0.125116752009959, 0.08345231714267885, 0.1734374184161425, 0.16965983886151545, 0.09059140623937692, 0.10477905582276084, 0.2650514371212452, 0.14770006640784203, 0.13157805247652915, 0.1509271351800811, 0.2228716778899393, 0.1361807546908817, 0.09639383278666966, 0.16607293859124186, 0.16698654440622177, 0.19122719043685546, 0.11299016239542155, 0.10171155550427015, 0.2019496634602547, 0.1948247086857596, 0.1058077663483639, 0.0915532372891903, 0.13201421697533902, 0.06930633508149656, 0.16636369960202327, 0.23111853778602617, 0.09356624056254664, 0.1950059191233689, 0.0797635731437514, 0.14514505592805726, 0.11154104579961109, 0.2194109216572777, 0.1585805067612279, 0.09883366194703887, 0.16633656476774525, 0.07194989766444891, 0.20154245708498264, 0.13462761867671244, 0.1375425525850827, 0.11675942223519088, 0.22141087079240432, 0.16562192730845945, 0.14805835040826953, 0.1610871464494736, 0.09874375386824531, 0.14248070937971916, 0.16035599213454033, 0.09675901157841568, 0.1421868074084482, 0.2993505724495457, 0.14311735908831322, 0.24782890724318646, 0.17489122347004954, 0.18763207770403356, 0.19301749195062345, 0.16522918467319783, 0.2563157671641919, 0.1730021425793248, 0.16343721308775488, 0.13119404324360434, 0.0827870846936299, 0.4498646943078887, 0.3572242250365596, 0.3166301452344464, 0.15595639515067303, 0.2532537596961183, 0.15493475561661108, 0.26322391905611564, 0.19968994923176306, 0.20792470493864632, 0.16714348517838987, 0.49908231943845754, 0.17758874162550897, 0.3853617764769062, 0.3006874265209321, 0.27954413525519833, 0.17176172365584683, 0.4238090021235328, 0.22828981941265447, 0.1698268307072501, 0.132624835016266, 0.22597485492306374, 0.08792487634045464, 0.16795791325069245, 0.2274246763197645, 0.26147043572798856, 0.12322155007671927, 0.1606253946139928, 0.1907734672028211, 0.14633943296728597, 0.1370134769428161, 0.15884473048631223, 0.23271946236491206, 0.1498345099389553, 0.21905148852496378, 0.15181924456790571, 0.13007800635551253, 0.1319801567062255, 0.1262541627511382, 0.3791708973867278, 0.3821543501990457, 0.204641972217829, 0.14779319205591757, 0.12566784501916942, 0.16839462933280777, 0.25934374500666896, 0.12101748447504737, 0.24682900928441556, 0.12965638220550554, 0.10221130530079527, 0.14498794661654582, 0.08914745307617611, 0.21198251945597513, 0.13157488087252264, 0.06063586303723916, 0.2446607046670491, 0.19678828396624137, 0.0944291849830939, 0.19203564302334863, 0.09801067667262209, 0.09060526476992715, 0.1598928613407958, 0.1695410799114935, 0.2661720398933657, 0.13226065213882154, 0.12935101955888734, 0.19197090859374694, 0.38491223608293845, 0.10809639273511787, 0.19109032116830352, 0.12533786030666483, 0.089003574103117, 0.17697260775152715, 0.2031364715507915, 0.08857523136201406, 0.13179142328519977, 0.11585035932160194, 0.12821167061525968, 0.14611797227013498, 0.07801837888696501, 0.10097288586679967, 0.1122836071637369, 0.11721518326310382, 0.19862896342191005, 0.2593647358157943, 0.1147397386751348, 0.15219476554662953, 0.08466824423521759, 0.12598250031230912, 0.13405775651335716, 0.10581691343817981, 0.1587318091262733, 0.11488573205086494, 0.23245465641300525, 0.1815897124188562, 0.16844077846936642, 0.08203883129622667, 0.16261964405496276, 0.164686533952913, 0.14626984154024433, 0.3259837723547413, 0.13852130651714342, 0.13022694916975114, 0.16195281048215207, 0.1598574067916601, 0.15483533272579794], [0.05798475448823264, 0.01672256940735444, 0.03380226985281033, 0.044396346540100155, 0.0076248247510633405, 0.006292483416355906, 0.018734528885913954, 0.022371918180837266, 0.07344894021028474, 0.02514527904080047, 0.03164432657461974, 0.09338589580429178, 0.09783412404959241, 0.10467443885582109, 0.012540921565115213, 0.04896201606419298, 0.03839428897105879, 0.0590655091969717, 0.01804183218477955, 0.0656939240833444, 0.02428341863466607, 0.03599914188887324, 0.018984011164115324, 0.015524730608317883, 0.043794082687987436, 0.005145284944334098, 0.03585426317107293, 0.04262542322037682, 0.039265212197337425, 0.005570294245356514, 0.006066384535628341, 0.036551272947221033, 0.053576339832356865, 0.05003116454087919, 0.045376705426362254, 0.02766923423135473, 0.05994526924745691, 0.08734107137687745, 0.04813517736751707, 0.12727092996600176, 0.01913587085812563, 0.046969463507975304, 0.018796392401019414, 0.027793595199322993, 0.046968812333239664, 0.032734787617359436, 0.018525990176825755, 0.022419764202148206, 0.05779893220131917, 0.047721635445111224, 0.047731747805711724, 0.035365732732198896, 0.05512002998241975, 0.10764550402640335, 0.06866162612793908, 0.05906527170971517, 0.042851871149914886, 0.04139767156072682, 0.04644875354584187, 0.033325724859511664, 0.061734088381091436, 0.015504255950931582, 0.026421671537982843, 0.016839259919980844, 0.0613556447769365, 0.048981041857792486, 0.03945237513811838, 0.012322757918868336, 0.09399980036241394, 0.03649263657749661, 0.04680557048789436, 0.0878165744905991, 0.08882002709733863, 0.06354058499357874, 0.09684113620389855, 0.10952063445602694, 0.0423470996470461, 0.1497781105459698, 0.08685666632147566, 0.004762513901016886, 0.12829787082849972, 0.13879276211223296, 0.028090015684645024, 0.1258049900793741, 0.039769520217012015, 0.06977760938987618, 0.026201442327170123, 0.07833682631532993, 0.16528673319806977, 0.18336084641275868, 0.05978576591118209, 0.07385538815851174, 0.08811115061924343, 0.048136334160282734, 0.019352261968437704, 0.045108455909235824, 0.06880777272125406, 0.04998335682396447, 0.03713646452994116, 0.0561122096053535, 0.01924124816733022, 0.04802523225906396, 0.04966107512553854, 0.10599695942214421, 0.09873607766724403, 0.05610388989049581, 0.03130764433843715, 0.050998748911003915, 0.03947482917517905, 0.1218596985563636, 0.07087932043378392, 0.01281225458613687, 0.02110583339667609, 0.08520194704854682, 0.041163754273927024, 0.011728370408227128, 0.02116948572708474, 0.07061403184648483, 0.06183764431625605, 0.03426777551912012, 0.037136115959935614, 0.053075406429988724, 0.08991185560702317, 0.029940962633718888, 0.14541974441418726, 0.036091141387700074, 0.03577628308126042, 0.039229661887211185, 0.050595472566783435, 0.07822018176797899, 0.05558187374845148, 0.11953038523995108, 0.05641564554084213, 0.006753527578116665, 0.027211320496374564, 0.025174214181700544, 0.02935616367105996, 0.03295181266542885, 0.01252487968398078, 0.023552997848920287, 0.04112738424972181, 0.009396091373937746, 0.040246333341084184, 0.010252770152874291, 0.055895031339699225, 0.012686888127767993, 0.036048918451753356, 0.019715104192014665, 0.03679269406523916, 0.005894128229439018, 0.02775923998635863, 0.02612136890210452, 0.04638547085285668, 0.015351319903387659, 0.03375121009265704, 0.022914720203487143, 0.06652159781585779, 0.04798941381816422, 0.09633030877598832, 0.0433776411227882, 0.02083789414515899, 0.022048046849968455, 0.042009921368932536, 0.019590630226077575, 0.029693868634621465, 0.06880067874707523, 0.058338016782316475, 0.04840221646572313, 0.05689567623419627, 0.02935100981454936, 0.08829072162869477, 0.016052877368976273, 0.01458718741853391, 0.04061859461569017, 0.04352303694993739, 0.05588712531232065, 0.028883223121445027, 0.1111163113326315, 0.045675671238812714, 0.012927517302394395, 0.0189621546756356, 0.026435476442378376, 0.01850111913236399, 0.006260724762649906, 0.05702308431688336, 0.050565656424770435, 0.03787093217514696, 0.10369666551630344, 0.05019102793847842, 0.08540291489372331, 0.08153265402201684, 0.1141200271705466, 0.03477848037296245, 0.04593188168420907, 0.05126503724304419, 0.06164448673746759, 0.09282598512307291, 0.06018049271416761, 0.0591857428662479, 0.02109060165352158, 0.026546620478432988, 0.042493575658168525, 0.006213137774818367, 0.02184127397354572, 0.046794921865746866, 0.024872967342455542, 0.017293142117259484, 0.03663458500898654, 0.04221413359646836, 0.0381504048803641, 0.01689734279117998, 0.010925915332571154, 0.07133822242218642, 0.022514567582777912, 0.03754553632930883, 0.011242943583056332, 0.04872606864439384, 0.045179050911458275, 0.04181590960210851, 0.040443378816088366, 0.012792862985553521, 0.0813618164149023, 0.05485159277375187, 0.02671783155341062, 0.0323924420761966, 0.08032601957599964, 0.04014795999072733, 0.046027546913753596, 0.010031852420539627, 0.012785287333592292, 0.09806958883399926, 0.006863494232792648, 0.07959294238037641, 0.08963758846925152, 0.043213840033258163, 0.0334777320254474, 0.03791592451893995, 0.0818153711095933, 0.021240015611833623, 0.014935906811226762, 0.07516559003101242, 0.04590317253924666, 0.05874341135964759, 0.03534951465084188, 0.013997956637233017, 0.027887858487966082, 0.0346036667695209, 0.032332204582710425, 0.09120798444435482, 0.0797021865183788, 0.03548500496113012, 0.06526322945231391, 0.12313051584867701, 0.019323152542534857, 0.0709635594619378, 0.05811731451221051, 0.14406813548937922, 0.09603698137066058, 0.07175181797074695, 0.17894871623045017, 0.06692983074894836, 0.13263450304587043, 0.06303837988525629, 0.013934058201078688, 0.10400460987922647, 0.10697193654073824, 0.046208960364662835, 0.07866342491920918, 0.03429823900542913, 0.06202132538742116, 0.023995538114479954, 0.0172916233479496, 0.05922498572016916, 0.005133871191872224, 0.033081672229473634, 0.08349970734167485, 0.026324742263363256, 0.03184243308139905, 0.015656310039752677, 0.08652017752249395, 0.08411958738560639, 0.019535874091689626, 0.05732509532883283, 0.04014606775355436, 0.0857105681432351, 0.07401907816529274, 0.022060369374230508, 0.08700219238357199, 0.0576660504204131, 0.1282678325209887, 0.05483290788927867, 0.03009299469751216, 0.07466127435045858, 0.02979453258787192, 0.038312562711296544, 0.043080261112341, 0.02371304510762134, 0.11521747110471611, 0.09695234918786634, 0.027078503832942056, 0.050637879363831975, 0.05690923599045604, 0.032012113895747936, 0.018658896855589364, 0.03229736290391415, 0.03002967370013076, 0.05437543848529459, 0.08762607140646828, 0.02953769395037765, 0.02895145665764088, 0.002141186780664289, 0.016210094890407017, 0.03306128279936891, 0.05271831369628349, 0.08337145656227105, 0.03697164454347184, 0.032242380773588535, 0.10476718912081373, 0.050037729914390275, 0.030767847295670264, 0.019668531791877844, 0.0383751061294348, 0.0479139541576226, 0.053363152884788094, 0.016548265252382528, 0.04678729163002103, 0.0265909539866111, 0.032692867286142804, 0.017788324114536087, 0.0034353764579376027, 0.05561750832824938, 0.005721175262043554, 0.0932799305226053, 0.025557855692421718, 0.009377695687655962, 0.028522349743833466, 0.03744871430699864, 0.01472268730492121, 0.01582962306847255, 0.016214187715142485, 0.06536410024930393, 0.027115946380241264, 0.022289745674859134, 0.04425002374656258, 0.05266110225009823, 0.04094068096169541, 0.06158830567954048, 0.09380350565357555, 0.005395065039216031, 0.03356387095165349, 0.06418565783890025, 0.06243947915913117, 0.11757137584349803, 0.22250272994560583, 0.15180491872372168, 0.18835937093582847, 0.15486488839791668, 0.10660209227353336, 0.12077382254985072, 0.20794368859740997, 0.315552014376848, 0.082805608699639, 0.09485200423026278, 0.29414007139782755, 0.18544281292105877, 0.22392391497569702, 0.17267775030866747, 0.1890814088044628, 0.12859414001145672, 0.23100782275920917, 0.1372510101646185, 0.1396140543323371, 0.16286987901454972, 0.2208401965758493, 0.1959043257539311, 0.15317822325854533, 0.1621598687263266, 0.2306218216976812, 0.0830067910494343, 0.09438802307892231, 0.12642665510816922, 0.1053671891831102, 0.10123574595537879, 0.12895251594243512, 0.12650529403359662, 0.12113225210698382, 0.26117500158086904, 0.18097792992428427, 0.25234710995949083, 0.24044280841706261, 0.1773165659077706, 0.13991445272920594, 0.19225869718338215, 0.1133365567112642, 0.10353211749104724, 0.09205599781125785, 0.1498686008515858, 0.16478382711929662, 0.16528993544559326, 0.11475188116873465, 0.23088920170501356, 0.1518006286313457, 0.08684581085558861, 0.11409832389965174, 0.22728746997252589, 0.21137878088460815, 0.19850419834256175, 0.1243499439630297, 0.1288430726215724, 0.11134510349121787, 0.09892331721681742, 0.1339214541498692, 0.18281850212764356, 0.18914934548158802, 0.13280117313467688, 0.13422966664356573, 0.27019200966723506, 0.11665032365389409, 0.18254241936149138, 0.06803488959708522, 0.22685331262407765, 0.12189751265630608, 0.12613554169694263, 0.21291996592715864, 0.21781730555718948, 0.13978944250172184, 0.1806186653313137, 0.13694311942785017, 0.2709926634786591, 0.2505463896499526, 0.3291786654341606, 0.1687431686948384, 0.1937795962176977, 0.1696333781846108, 0.21922707587720888, 0.37094819990377276, 0.2973222167741868, 0.23086975839349533, 0.07448335043004445, 0.22606151478905834, 0.23077713836344982, 0.2597805683410937, 0.09477153435469636, 0.15225309548118424, 0.22315727546811107, 0.223569905745887, 0.08940229222418801, 0.11033728418330993, 0.1589499450018329, 0.10465427542165404, 0.0900497054681182, 0.18477876790829245, 0.21045207496612303, 0.11018235822238269, 0.1620064059933347, 0.20855173258291138, 0.1723096450610507, 0.20900876531677864, 0.1647331733857432, 0.1001708071318365, 0.11716001727167638, 0.3057201645307003, 0.1258914201189914, 0.14455380458985606, 0.15178414241921517, 0.28904840590492376, 0.12149020668960388, 0.10536034035706714, 0.10788976350018095, 0.13461792000359105, 0.14026346706574963, 0.08458386731123732, 0.16526056363457636, 0.16227524156772322, 0.14489379441065176, 0.13940325757909205, 0.2521914562150355, 0.13332398217772284, 0.11853681516743476, 0.13729676093545654, 0.1604994344374826, 0.1492997192807736, 0.13646668934774014, 0.1410093149470706, 0.14926130763225018, 0.080926931282926, 0.11787547444504116, 0.110189214709305, 0.10573566215293062, 0.10706688547807355, 0.1544223806910938, 0.1357524349324165, 0.13622141863790252, 0.19251113847619106, 0.08092964323417795, 0.14232625073242572, 0.09559143229477829, 0.21486149319717962, 0.19859658854622997, 0.11592194257724671, 0.11245193200245981, 0.1247840783288402, 0.10219992889511971, 0.08251654074317025, 0.1391893505088745, 0.08991820647591546, 0.15049323830152714, 0.1228177221491933, 0.23368867084143624, 0.23046196979140085, 0.16842957826391344, 0.11455459820647394, 0.09910828148525569, 0.16833571717143062, 0.10808551428659309, 0.08063457680926209, 0.10210671131649326, 0.11483811968637091, 0.10610267189481568, 0.1949502398530322, 0.12342686164042643, 0.10653247020297474, 0.2338322357184464, 0.18619445242708732, 0.09859455058411246, 0.11755335745551895, 0.19065167454461898, 0.12372366708493042], [0.02581417147490767, 0.03040500698731311, 0.06522834946912143, 0.020963932845681425, 0.03302794648334384, 0.06405860215665833, 0.049672926505727154, 0.04960257282120086, 0.004856060418645822, 0.04212529037988955, 0.06766476187734835, 0.02479626278903696, 0.03551495899896949, 0.016620348380397887, 0.03000018314548558, 0.07148597013926314, 0.09186889615751083, 0.034675510495059916, 0.029045130058582273, 0.005496072774422506, 0.017551072430045857, 0.07973448478526647, 0.016076360836685184, 0.022480649039930394, 0.020120318738683578, 0.010917248005317825, 0.057804382916900425, 0.042591029703016245, 0.04499333970729382, 0.02145040442325896, 0.03124616003685421, 0.038602572955912164, 0.023695379120087432, 0.04708458737079655, 0.05199514584796083, 0.031720630847097885, 0.030795037671322786, 0.027226975503107233, 0.0695833754575541, 0.041478612580366676, 0.06654286441663582, 0.03739968084940507, 0.1128303487935374, 0.05693252123291454, 0.041189069649384874, 0.07551482653305416, 0.03697515705660467, 0.10296874409241062, 0.05137834547748489, 0.027972317766398195, 0.03873063604377451, 0.040805788199988105, 0.03881099483659191, 0.03288129810243845, 0.029170337553706863, 0.0768684043038276, 0.026456787093212048, 0.045543402328246066, 0.011188833835354496, 0.17773101947480635, 0.011462413409214106, 0.048205986874358314, 0.042751283805456855, 0.05581200273046571, 0.01978971349496034, 0.018949598494556644, 0.027524587255151525, 0.033139500376437946, 0.0071349158327305515, 0.018687387665493355, 0.03734407052698155, 0.0770817751124982, 0.10355454088459093, 0.08237822356844142, 0.03766216938534091, 0.01387513550599256, 0.10535586640358933, 0.05385496601041767, 0.06930631975973807, 0.005337220612883328, 0.027531315422346516, 0.08422441885716493, 0.06067386099828347, 0.09503774224750458, 0.07556912684512716, 0.04517232465948309, 0.043247226144998305, 0.041519333983981804, 0.023356333502658436, 0.04107707908617393, 0.05690031106613817, 0.034371477010990345, 0.08989700116217138, 0.03724443313154963, 0.006541241262663877, 0.042498570551434835, 0.03211403423319421, 0.0631338995580952, 0.050783554813073534, 0.0936101527223664, 0.10835608888056972, 0.09815244124301019, 0.07215520156727684, 0.02211050216799542, 0.03436324156580433, 0.04335507983341814, 0.008695161142837136, 0.04246128888259973, 0.1083530092071141, 0.033593740719821186, 0.04186938253922328, 0.023061556275933984, 0.038075408703016664, 0.029665958136320118, 0.06021163801872923, 0.029014672317932692, 0.07141468565790884, 0.005805851439119227, 0.023283103157976465, 0.08172536343936959, 0.03453238994904584, 0.04201320022524845, 0.026755398589997526, 0.023601391623097084, 0.13201225579025286, 0.012195682126818406, 0.014752811797323727, 0.05359359213241166, 0.03782104069907819, 0.04245688387703511, 0.060133749859467636, 0.01921634073369205, 0.020284763342070005, 0.0169863315644644, 0.020468498039389812, 0.07712231648545112, 0.019955173164846438, 0.0260366759668555, 0.05887543512207847, 0.0625571234512233, 0.041100119180496664, 0.07473926210115034, 0.062385213321014765, 0.029942485233468395, 0.020976851003304608, 0.01913344427462547, 0.02723297014111473, 0.0424950733600605, 0.03650548770242641, 0.052326478875212135, 0.01420622051227838, 0.02571270121411691, 0.051736192807795546, 0.020376726451720444, 0.04706994743056355, 0.0743533912745695, 0.0429035437804076, 0.04645036233048286, 0.04821757012377343, 0.02859828820932777, 0.014875193385617628, 0.06388779902350038, 0.04111963143992809, 0.04369890775471445, 0.03680349590497152, 0.0654412682859167, 0.09083868409957617, 0.028742226554201018, 0.03325913266669358, 0.030793342701790315, 0.053675440966241786, 0.029563474724249496, 0.018650958269474008, 0.04314046030143096, 0.04970818570244217, 0.05021647737932302, 0.051434679752996856, 0.050807100525426294, 0.017617170496152777, 0.02677101720755379, 0.047772082334925095, 0.07193828377151681, 0.01983966434284324, 0.03273524343967438, 0.038085754720434066, 0.023164945586975065, 0.03408334368178922, 0.03357365772488617, 0.036468516299200636, 0.07184454525310187, 0.0738919458742584, 0.0729591572176545, 0.15323453072097995, 0.028414745033989032, 0.019136188784614205, 0.047678726860472274, 0.02325339618349268, 0.042418016406196746, 0.05269635378593399, 0.06467915635796324, 0.009520266565584369, 0.04015433384225734, 0.028235603033775286, 0.05214248753843769, 0.07774479356744597, 0.036485803073212024, 0.06706835476741677, 0.036714449675092777, 0.02753315020292517, 0.05263531956100657, 0.0374920365791167, 0.03087314033520318, 0.021286858057963754, 0.029023591496591127, 0.05016685403402775, 0.04278697967228871, 0.04028453814586805, 0.050996680473608356, 0.037694130573541894, 0.052861514681529616, 0.06008850853709925, 0.01943361284511705, 0.08907323447807182, 0.06361468867849439, 0.08214578483133547, 0.03360152417313188, 0.02933311591585798, 0.05613102855521345, 0.06299383187245938, 0.019093215082501693, 0.043985681277849985, 0.04158060186572614, 0.02379334069818499, 0.059328522503135674, 0.013210879819047068, 0.077535291502793, 0.047563384662592606, 0.03679820606785436, 0.014127019469836547, 0.032263953809536276, 0.06542324989793763, 0.03402394888501975, 0.03980725004728283, 0.02487440567253338, 0.08409280495177354, 0.09671221126712139, 0.011094827186166039, 0.08376432177160056, 0.05194323956065121, 0.08051130560136611, 0.02018630763726129, 0.04395889501357752, 0.12740787584334612, 0.08469210021317967, 0.06912540809641923, 0.04778178100804648, 0.05035572535087986, 0.06216575977422538, 0.10360652761113259, 0.03241791449967892, 0.02612303897377945, 0.08009010279971747, 0.00845443429200039, 0.03597140184513504, 0.04762534585390841, 0.0014531616597518986, 0.016938772826125065, 0.06798850297327004, 0.029011617542334625, 0.03805679276645665, 0.05237451258806452, 0.013135847252523227, 0.003959976949714004, 0.0690423411827895, 0.06481047148906416, 0.12762506176987964, 0.06241035249625003, 0.034132936383567514, 0.07474490050827304, 0.04453702326563578, 0.034560784997959296, 0.029761881920539086, 0.0578774523831183, 0.027564502351226348, 0.11521671267767107, 0.03258325159549713, 0.05734353123473064, 0.0493920556900482, 0.04173129519087173, 0.023051371136980674, 0.07496459154231895, 0.032946327475891, 0.08473431165780752, 0.06712203454827109, 0.029237866289012378, 0.009900938527989052, 0.029414181424785527, 0.026951737348891558, 0.06071088602766395, 0.01920866836313038, 0.06110094352475098, 0.008160533278339334, 0.052626662767462196, 0.0549260143851561, 0.06864251223422828, 0.029984085722976637, 0.016082366966011546, 0.05829632244703751, 0.06372764451248993, 0.024103784422960975, 0.09837456077577607, 0.04769520924216317, 0.01957302744079742, 0.04528962421200929, 0.061761472193944844, 0.06982364361324618, 0.019802204558565732, 0.025701458873828093, 0.031875001394280025, 0.021898140680165063, 0.013415772907225596, 0.019370778313567562, 0.015557053773063085, 0.05850132757557496, 0.07213025774446226, 0.020030958412755883, 0.03823877312242985, 0.024741177236841574, 0.005595106875614053, 0.03212596605261488, 0.02399729437104637, 0.03833938727996523, 0.03339219830870148, 0.03839636889977321, 0.0629772613906572, 0.0383112488705064, 0.010837961735594417, 0.031279519335517, 0.062259923471438314, 0.04278379657696332, 0.018325614134570765, 0.061819327153986504, 0.03627255483860931, 0.06443385500460863, 0.011761177165974534, 0.053601705003529794, 0.07844433909462345, 0.05431404802948237, 0.033062883923130656, 0.10899728915143399, 0.03460244485928166, 0.044821540659834305, 0.16404197821694036, 0.0746804112268071, 0.21064454689621928, 0.18849084694539348, 0.21763163648786085, 0.1642329639364635, 0.13397699552437953, 0.1812432261724626, 0.06127495656631166, 0.16569164130956898, 0.18945464684117228, 0.10385390506276201, 0.119265349461667, 0.18990152124916354, 0.1260140324912725, 0.24996921900779973, 0.16257531820766388, 0.15994530772009205, 0.13993063250616675, 0.07525543682277203, 0.13023134651443652, 0.2510062569091397, 0.18772854349545895, 0.08163626741377578, 0.13043625971242306, 0.10240682626083013, 0.11846238972559092, 0.28968903927072404, 0.15794016450883883, 0.184707920097055, 0.14106583691412403, 0.13146647943123696, 0.11780998924927366, 0.11414045873548716, 0.1234277349806601, 0.13311868593577417, 0.14289819665493506, 0.16685315317684607, 0.17307246945077376, 0.12098360806703569, 0.15080990840590772, 0.12760420119570148, 0.21439992522280063, 0.13360253174699124, 0.0959781228354381, 0.1598741075084094, 0.17157087583215008, 0.17945244968418153, 0.23392097934359507, 0.09131129906182328, 0.13715554028749466, 0.11273273387022557, 0.14111989207806128, 0.16333719264836083, 0.15428572592716064, 0.1407754283037878, 0.1394687121313426, 0.1480228192503414, 0.09742107242345811, 0.36218921023030437, 0.14788869257655837, 0.24084192490385425, 0.17727141268551352, 0.2624727851681171, 0.13085057538363243, 0.08922307361518184, 0.20580886202233456, 0.10061798031411825, 0.1957393870238335, 0.15674842281206963, 0.1524653324797269, 0.2675512433052063, 0.22434777610244291, 0.2224956972584609, 0.1949937996124068, 0.1919413529216282, 0.2652261358114981, 0.12857959966265387, 0.23593029007315638, 0.08797277215748064, 0.1777722656486496, 0.20105634365350972, 0.20856210541340614, 0.2851898048914248, 0.17205939477970525, 0.14081065302654622, 0.09210081395482825, 0.09158525976442522, 0.14331160834239376, 0.10834208479331386, 0.1527485398635749, 0.1930998617242421, 0.1344592325509556, 0.13908779789363185, 0.171436243540337, 0.13505495784263458, 0.1341861222059496, 0.22310007934368428, 0.2523263030114674, 0.1965287793427706, 0.24109572983316838, 0.19210045406174278, 0.18012577968259014, 0.1710856663844278, 0.25452223275938346, 0.12168591151074057, 0.12332938461294099, 0.099451603788522, 0.1595509869437064, 0.12131533179912837, 0.12992523310165252, 0.15967218205332756, 0.14407746644029695, 0.22758892557073027, 0.1787866120256724, 0.22139933350826466, 0.18160014653638487, 0.18303525904493947, 0.1395083341987864, 0.10506718915196196, 0.17527393035350308, 0.12115741043441719, 0.2543980652286161, 0.13273220989973317, 0.2637259824381721, 0.05961698908058386, 0.12982521266225847, 0.23883206259098747, 0.20043175216884385, 0.10877562161054342, 0.13374824167018937, 0.1314532261101469, 0.1399705150435048, 0.13359548373808786, 0.23205109661625278, 0.1626055633589145, 0.07919849902992288, 0.12334167266324644, 0.1378202134923589, 0.19579810000235037, 0.06173247959645045, 0.133054441802444, 0.16396786687114548, 0.20315783008212046, 0.12280400151446944, 0.09413031110119435, 0.10379991118585873, 0.181004834932185, 0.1493685905851664, 0.11574043336534694, 0.12826596326645345, 0.11048482505664711, 0.13918384999757813, 0.09545036486440128, 0.09758150655656092, 0.10877568289757737, 0.21399126328047247, 0.09711560252453051, 0.16940136079586324, 0.1764309529455439, 0.0748547115513394, 0.1575190766203788, 0.11526290777950518, 0.16560066070768142, 0.11863623039736865, 0.12882969672641448, 0.14230493816637224, 0.15169892279851824, 0.13617039718214544, 0.11250492996506153, 0.138492991907462, 0.11470465184820276, 0.14114420770877792, 0.17215586057113064, 0.2218421936155327, 0.11538755794566487], [0.04878334520805267, 0.08544981479644777, 0.0814014767867423, 0.06997922074890907, 0.06246439233842877, 0.04798545697403531, 0.009648294221880216, 0.04415483732197074, 0.025808014043216265, 0.051501528585269574, 0.01767916041576574, 0.059245018919389096, 0.045724436565632784, 0.04720455290929926, 0.09461227999699694, 0.05510124933695602, 0.040487019014695, 0.06487132185288975, 0.002488072350388393, 0.04748590252993088, 0.040694222815575144, 0.0553198257130721, 0.04330944397576875, 0.05556129279636568, 0.047365404560320803, 0.03074515002569364, 0.023679480880438804, 0.0522585881633624, 0.03662688965578714, 0.02726363855594349, 0.042088085319846875, 0.03615059747150348, 0.03039249294106999, 0.019341586533212857, 0.0394045214559282, 0.024320054874424974, 0.017842679967983596, 0.05478948602573045, 0.037030717583313104, 0.02609814877711958, 0.009608596503253906, 0.026649542475840258, 0.04677960393770088, 0.04091065414550324, 0.003394883204882424, 0.05357099636908501, 0.013669259910051142, 0.016743345711860928, 0.005691532926228379, 0.06424004242064492, 0.05664759015123691, 0.02934144903725434, 0.03999469261015615, 0.028249729695099018, 0.07057754307865136, 0.04687042749156395, 0.006253682978210912, 0.017871925374493003, 0.06263027335667322, 0.03365349174747544, 0.03201890143475706, 0.05181528372509826, 0.00816318873060687, 0.022656163613822673, 0.10243183903155789, 0.027647419877710844, 0.0020240047747539657, 0.0315019644556507, 0.023150066244265726, 0.019661368869785822, 0.027346701639133598, 0.0710062458810787, 0.06982267068158235, 0.10061604211166983, 0.08207734253618025, 0.036660360037198955, 0.035028408897379716, 0.03131043289848153, 0.08160759274276995, 0.039565285006838466, 0.06782054585675079, 0.020587952214203054, 0.11934912117618708, 0.041569807686873024, 0.11292648516715535, 0.03344092150068572, 0.0715359497154432, 0.09508835001578254, 0.036172339046794566, 0.030315171686872363, 0.06205232896571679, 0.019040337778748046, 0.11116712594464903, 0.12957090211491432, 0.042009289346395, 0.0782131873852303, 0.0037051361258847704, 0.05755220975486502, 0.03716276432838171, 0.05218400184305445, 0.0523051394960813, 0.034148373055241765, 0.045456995271266475, 0.060408239162737326, 0.016351551110405597, 0.09794949689098904, 0.09228020876405701, 0.02916914820220442, 0.060197316004984805, 0.05832249584097055, 0.0752673494899946, 0.08207505193328665, 0.0483208311150872, 0.05634921805692777, 0.05512827308848501, 0.04521694928107243, 0.06610812484136512, 0.09799163938770372, 0.02147291017125451, 0.013237148973970644, 0.010836375933591156, 0.01968935214643998, 0.04554778052073333, 0.03635842563404191, 0.0013075418715860936, 0.0379070034250617, 0.05551532369046923, 0.03755973959942499, 0.04226463794287655, 0.033124952366755854, 0.03176234433457496, 0.021134374002295158, 0.04108385513386419, 0.011147432528706569, 0.09589615908841934, 0.024004426649621418, 0.07874332022883239, 0.06272414211003531, 0.009019328375166703, 0.037088557221596284, 0.011901367425678239, 0.035518299142319354, 0.017234884961057576, 0.029717161537959214, 0.1296026487984965, 0.016599962780732783, 0.0068499062270406755, 0.036843091159337954, 0.033897456277402184, 0.006434426580991356, 0.03038787534610639, 0.03691596910357475, 0.05091179410115846, 0.01677203378940542, 0.001072692471244673, 0.04785526033130385, 0.04534005194962506, 0.07254772969791967, 0.0103105082845075, 0.006431263116669031, 0.033541865076028535, 0.04923321501982789, 0.011693489467424732, 0.03433110800782039, 0.03937770837857839, 0.03618014931318261, 0.06954342397230287, 0.05728163133044878, 0.0428213770200889, 0.06632020096144368, 0.02600209475795348, 0.05511071052282088, 0.06430257817790394, 0.013841691937658095, 0.0552253287676121, 0.02676665816726464, 0.06328026065602899, 0.03805880374725788, 0.0330074114965335, 0.050610752190433206, 0.0422800209883961, 0.0730607787808103, 0.06346416772313176, 0.07156644001482956, 0.04734678096288154, 0.07151967800793148, 0.06314675834390425, 0.05520988060461898, 0.04858670959008798, 0.07242186911283963, 0.05592580509161758, 0.022807274456886996, 0.05562018963598436, 0.09479205018930859, 0.037806898715995976, 0.0827627077758793, 0.02497793287940083, 0.022214226642503374, 0.05723633255148607, 0.08458179887384178, 0.026605302813432874, 0.03485145790862941, 0.041292441723447655, 0.05210909376581831, 0.01612547473351081, 0.027457730761999567, 0.07038632753275095, 0.04339981553775649, 0.04183685444595833, 0.044667844270025535, 0.06901783403009176, 0.02016814943823603, 0.020619197110194835, 0.024834055821561528, 0.04884347927966907, 0.011490656198152613, 0.044175345495703726, 0.03693400281331232, 0.08077808806011755, 0.0026956644620851527, 0.014224056954375439, 0.09563287765148187, 0.03202802745715505, 0.02944526927275283, 0.022939190967008475, 0.05107416260627009, 0.05497670259266611, 0.019707284349527572, 0.042533891035183784, 0.02046316415221701, 0.0735469918037134, 0.028605696279555563, 0.08630545073819738, 0.048461075000945604, 0.03658166365517724, 0.08149823369157892, 0.033587761403572176, 0.08350099436938764, 0.05878104542892787, 0.03421365523770933, 0.04823058978804658, 0.019835401063544617, 0.011426346947348887, 0.10484300884267977, 0.008944893357223802, 0.12908999808132648, 0.02185301427098532, 0.14348036219035426, 0.013946638322405279, 0.01850972038453385, 0.022824293100124887, 0.04150386666879058, 0.12152890179065928, 0.058055150307594776, 0.04200073980516003, 0.06567513960744105, 0.03788405143085026, 0.020844045831190965, 0.11559647012261615, 0.06188926715103369, 0.12998917079981298, 0.06225211320505027, 0.08615755746441503, 0.13368983512684224, 0.021787038778946288, 0.0069447603609953685, 0.03555409460058136, 0.02988010460901405, 0.051159163891908624, 0.10280486256364854, 0.03686693181554156, 0.11059250637528398, 0.02739043759873077, 0.0065667290079046885, 0.02992190045094298, 0.003560852562640644, 0.05056518145025738, 0.020557027159919663, 0.03971654523704802, 0.018215538791170525, 0.07903809554033703, 0.0233060896261445, 0.09253330889248079, 0.07091404719939155, 0.05003446637983284, 0.039003899606365355, 0.06267614287113951, 0.027503196165085803, 0.04390932146399733, 0.053906849315089565, 0.04384015904619329, 0.01236054903617309, 0.08154216117315716, 0.06999099552030526, 0.1032685372798193, 0.03209904380773585, 0.029254733629885222, 0.050573512656433936, 0.014996803140327817, 0.017812409918875467, 0.026803062665426446, 0.023565866210828387, 0.03975360474038509, 0.03142347683258836, 0.05141114170152334, 0.022783123535074057, 0.01613747550084466, 0.027095043671227274, 0.017018725592342597, 0.04160508986622576, 0.024653963872321674, 0.006206957360489235, 0.0707564322698501, 0.02063576567677721, 0.06016009945362326, 0.04790448148043887, 0.016311065278827183, 0.01861944907314835, 0.011099564482367808, 0.08914239689587586, 0.030309809071402398, 0.03544612982941251, 0.08802557093722206, 0.04232091859223382, 0.0357284753643457, 0.019493700951457988, 0.008417792306582053, 0.043279083911329515, 0.01819725610285757, 0.09623726739758447, 0.01920434379679782, 0.032162722951221856, 0.039340104952815085, 0.02514184122124026, 0.02390334134801261, 0.025067046141972946, 0.05960082845582117, 0.02972117200824282, 0.04340641921566379, 0.016789123295776306, 0.006255101677285688, 0.03406322621289761, 0.039322105717034116, 0.039578649410677534, 0.011083152963809911, 0.07196072248681899, 0.03933308375698905, 0.09068055589112545, 0.07903068747010925, 0.04289789771240565, 0.019905519176034198, 0.02725700614973903, 0.27718081529582705, 0.16906880202793306, 0.1831472610994693, 0.1405408521813731, 0.12828450259422103, 0.20358072593808177, 0.1428046419976219, 0.2047786882687961, 0.0988194203725265, 0.34727026077528156, 0.1707449411192248, 0.17717565169497845, 0.1742865043061395, 0.13772143411540216, 0.185819988649699, 0.18405910491222338, 0.14450849815001413, 0.19706248215609984, 0.0929726143517802, 0.23868463663083894, 0.08222122917011862, 0.1642735359529334, 0.12136222404097358, 0.15898611967361745, 0.15343959713655134, 0.1485622064360688, 0.12786016649296209, 0.14659999479209224, 0.0964940447480448, 0.15997043540400846, 0.15959073158521808, 0.08608359933620499, 0.16084817298237356, 0.11288013684773639, 0.23274120394020315, 0.10075557736619827, 0.07922416297538627, 0.12140354682360927, 0.22751983976171863, 0.1474258528962251, 0.08929482541016995, 0.0957835441635501, 0.12943951803590023, 0.10117795228237107, 0.10592238842359475, 0.12932861914798138, 0.13574598447209404, 0.14966309010501833, 0.10349043464708714, 0.15819206954010073, 0.14829124113725078, 0.1554249293140827, 0.15501801405222188, 0.14772770686015008, 0.1446524613927449, 0.1470224922823329, 0.1731585470899459, 0.15068765609495102, 0.1515276408604076, 0.20057577669860857, 0.17880178056657317, 0.15446384136955585, 0.12197471133643582, 0.16061071636936358, 0.19055229761908132, 0.1138758366446822, 0.17306100877542652, 0.2759720511253803, 0.1553125748591077, 0.15213300353817402, 0.13518090269738628, 0.3304283693432808, 0.17851175500019906, 0.19716722169710746, 0.12558595022006383, 0.16025050182736691, 0.3347842227066717, 0.17942592772024293, 0.1658641796318754, 0.14970160900585114, 0.23471961068289898, 0.1842545645852243, 0.2698477603975804, 0.197588263620292, 0.30232048082736235, 0.1724662793980491, 0.14909685919842414, 0.21866695835225045, 0.1211386182976346, 0.22218362368162603, 0.1519013538716301, 0.13860730754752315, 0.15529618057752811, 0.2922888046070453, 0.09705535737016509, 0.29035715987124755, 0.25691645670562024, 0.10822422982704256, 0.11489101039666323, 0.19875558243403513, 0.18153130587550903, 0.11996629692974592, 0.15460483219114043, 0.17247109043021358, 0.15370596590782368, 0.24289436638355258, 0.13555204165318321, 0.11559975663981131, 0.1839069292069443, 0.1193884827737366, 0.18376472796643936, 0.19481098039015649, 0.1900444732558343, 0.19388229796482673, 0.21705319413975363, 0.11883082439101512, 0.25669453635571465, 0.26000254997803324, 0.21462297938283414, 0.16007212591507744, 0.14430740006989048, 0.16031091552107565, 0.20622889270945904, 0.09328454237190947, 0.1357454022452716, 0.1306725671935466, 0.1573955832469848, 0.15120291151106358, 0.14375826824576626, 0.09894514306178016, 0.20710799392432938, 0.16972248953196312, 0.07617920862450715, 0.09249924096248804, 0.14753684371469483, 0.09039518047845171, 0.1872401164784547, 0.1539369567387527, 0.08544153338598628, 0.2721655134472155, 0.10259961228697531, 0.12765771243721247, 0.09962431831105102, 0.18861757320982797, 0.21244160530547943, 0.13774446271840604, 0.1676635669484254, 0.19999937214437993, 0.17297960427259246, 0.08605454928211628, 0.21485059942689635, 0.09344767313450576, 0.13125215867354026, 0.2529929986884517, 0.1543693520849751, 0.14411334999867026, 0.16005822908013098, 0.21575061484209954, 0.118439928027651, 0.10311515115561987, 0.10818358886265948, 0.11899282900436271, 0.08325007759154805, 0.11348337746195256, 0.12090746658824145, 0.15187455611603876, 0.1688642412303917, 0.1390728591791084, 0.1251828117716697, 0.16912576832598256, 0.12733341975798532, 0.20133706891248304, 0.13869589795508694, 0.11735418991696452, 0.13376137241721153, 0.09259248152375223], [0.05530235507795888, 0.0525230378843844, 0.058014865574096484, 0.04777077232457457, 0.023813289627733252, 0.039187048246423085, 0.055494436303213726, 0.024106542339488387, 0.04560982215128118, 0.01438474581171308, 0.03411291084522682, 0.06333621954845806, 0.05015452767932608, 0.07509271208677562, 0.05132132938372032, 0.028357751922862186, 0.04372551781876434, 0.035181787360699913, 0.04089652748417951, 0.055011302953766245, 0.04106668710348107, 0.0915702214584716, 0.012020790956974512, 0.02044686754684775, 0.0115887489688072, 0.05481003250385966, 0.022287637017847552, 0.031416064931920944, 0.025077068487242348, 0.032368360102296836, 0.02859493465943923, 0.02030755254259754, 0.07414739023173049, 0.08553527190440124, 0.02221047089645459, 0.0187532750574211, 0.04532402155980949, 0.042585372143695434, 0.027266710568519852, 0.05146763302505978, 0.008409404601421087, 0.052385122905815804, 0.08749357649996396, 0.06370536667565185, 0.05108809774561275, 0.08214681138915401, 0.015597357658759482, 0.03404823387221944, 0.026232329077057304, 0.015984655324099286, 0.0244475414811243, 0.0734303395954832, 0.035470862978047905, 0.035505245004089615, 0.07206938439799894, 0.027005376910129865, 0.0242466444990808, 0.04051358311346943, 0.025294378903063557, 0.05957670434708557, 0.07335781405169157, 0.03343542098938938, 0.021914808838177594, 0.042038500278947816, 0.02870882512070239, 0.022921570944750023, 0.03578350345994677, 0.0480414733230587, 0.07892947959443254, 0.006975739520238413, 0.029316694821201028, 0.015542123677028764, 0.09573552577245621, 0.06237000264527817, 0.0303430802699539, 0.044318466041717804, 0.02496304013015282, 0.0264806890364496, 0.05244461729401543, 0.07054270139985508, 0.07984506957713636, 0.07794820523310093, 0.06373527857865538, 0.03323484384905427, 0.0693338146553405, 0.06442326000861584, 0.05343099763136237, 0.06931254039368323, 0.03551626517888039, 0.02008058175805115, 0.012712286815287606, 0.029456212838751175, 0.08614161517471076, 0.040702059895040534, 0.04206416422441121, 0.04902930539702216, 0.019783033208260616, 0.02212573774158955, 0.04650228393955096, 0.012250475607992662, 0.017736477199040594, 0.03127569847199465, 0.024724484180971503, 0.017740577684655305, 0.06729800494447832, 0.04140418713852283, 0.03454185879578994, 0.14556456567539325, 0.03653383295562479, 0.04854691515286123, 0.1107061938232472, 0.011631500505421673, 0.08330987841491738, 0.05433953577472318, 0.0385113931711643, 0.027298890091779254, 0.09740188958183413, 0.019468827991776412, 0.030920587990793492, 0.05168897497858252, 0.0655641334672128, 0.02948107430711389, 0.031752871657391234, 0.06131009318895879, 0.059907918630708615, 0.0454588798475602, 0.031199344403801427, 0.03324836913135744, 0.024705919955346375, 0.043212851779835845, 0.04164783757240061, 0.09097596705560723, 0.03422184088718026, 0.040452667632170265, 0.042525904568573164, 0.007882287750215902, 0.027705979638642846, 0.031516297960713986, 0.09406118698778654, 0.04959249493455695, 0.020309186225096067, 0.05242290636224132, 0.03831760740027793, 0.05651427553065362, 0.05468668085673163, 0.01655209760722374, 0.03806981626116941, 0.01800476693578305, 0.03959567954523429, 0.04371408012605483, 0.05210564637015905, 0.05225938106436403, 0.02466187373013987, 0.015974534345009637, 0.046410828363150365, 0.09288555612006495, 0.018417466161472183, 0.03929222062710793, 0.04715671454886756, 0.03608823791446705, 0.011626734480922742, 0.021771653818206924, 0.049118301831185825, 0.03110322909760139, 0.030480068282134114, 0.05321444372736639, 0.026251680458024628, 0.048337393936010144, 0.0078095888790314, 0.017704517926059423, 0.03630824304456192, 0.03867633573170151, 0.0018128972770946642, 0.042820515171174085, 0.04487448499628133, 0.015305464753069946, 0.03203406422999838, 0.05557130939597565, 0.04139255792383225, 0.10744728643687503, 0.025241631834257035, 0.08382866549636088, 0.013671052555793957, 0.060995533656809604, 0.06956333459745492, 0.019269666198881406, 0.10133270204307572, 0.08578569072509006, 0.12641832773243228, 0.05448246862919581, 0.05061207369210259, 0.05398368027301566, 0.05623547315237023, 0.0475288953842415, 0.053419579090850974, 0.04141786180797123, 0.017409235081304947, 0.019614867332781998, 0.05481611524197844, 0.08205059840674363, 0.023603529008405826, 0.07990542964469041, 0.031220007710339084, 0.07310027061330696, 0.0526695636912219, 0.02879348358199481, 0.029926772770141403, 0.03561544292155774, 0.030977291903728922, 0.02698908221998042, 0.01062021848009599, 0.03284980422787128, 0.023237700957143982, 0.024630757153875405, 0.020384925507730054, 0.06585359212852294, 0.030612498071164857, 0.012472915940076835, 0.06454342089953923, 0.020817633034781586, 0.0869038649984906, 0.03673680412072328, 0.037046476011915554, 0.06044722920764358, 0.01717407098640838, 0.04931057457842174, 0.03505357105525271, 0.08052538629741439, 0.01300363867138062, 0.03729392241145815, 0.09021431478040834, 0.04334343146652945, 0.03662430793948231, 0.05685877377888369, 0.0702759802281376, 0.04927445353279191, 0.05218124775696666, 0.025623344718628836, 0.024824719124984358, 0.019231622272561637, 0.04440254036096796, 0.03860647617388637, 0.03137188081088806, 0.10895417372305548, 0.08728386759157143, 0.04919036006134364, 0.05196953552865213, 0.033864820931827834, 0.03100892175890265, 0.05845579897023498, 0.13388212319583664, 0.043993518357315374, 0.027157127436610962, 0.05246770335361362, 0.023829534522167618, 0.11782669762690222, 0.021717278812561306, 0.004711760576033304, 0.015392368809590417, 0.053149705467325066, 0.026264173436849832, 0.06889273187205677, 0.02575061299026974, 0.0475909446756686, 0.04691222907915231, 0.012455045981633087, 0.03610874225776042, 0.045886621209642584, 0.012682311710030323, 0.01262483596351118, 0.011859105227725401, 0.022224626286075484, 0.02739084937099007, 0.06789228999085965, 0.07037996134210019, 0.01546015131152085, 0.08141038638930168, 0.04486022426957085, 0.012528007237931654, 0.015559130828947791, 0.025439468295043035, 0.053053913833273035, 0.031191790776868022, 0.03781972302784843, 0.036468121763919635, 0.04892712075924201, 0.22738909919656095, 0.054719680094070015, 0.030449099177795074, 0.07466257669992986, 0.08200974293774174, 0.011489946609212747, 0.0592312561498294, 0.03721359809259734, 0.020303785305229888, 0.09996016359617634, 0.031605273327459736, 0.041702440489203706, 0.05835738731548191, 0.03526866939219256, 0.07551622081307635, 0.026850048753042376, 0.03431290575873948, 0.03149044249326952, 0.014759814798561557, 0.0343796128647462, 0.0397725769078299, 0.0437974228313373, 0.0224275304184806, 0.07423040351920551, 0.029829454705900246, 0.03339529713435519, 0.05815956426123458, 0.035043627233995546, 0.07334906532759629, 0.014024444127215013, 0.02610799109172677, 0.08358225331551607, 0.021096707374278097, 0.019852429282881563, 0.045284575692588286, 0.020907962461933497, 0.033872792076679974, 0.039137693031901316, 0.17817921155402738, 0.014373779263077004, 0.05033926978226631, 0.014271332240182788, 0.06317268275926191, 0.05019045720297483, 0.046374910330820474, 0.07238987728112167, 0.007384134768207948, 0.019098679204621626, 0.04840474838631288, 0.042267790394684965, 0.052102700762090184, 0.04026882568254106, 0.05254398655867385, 0.09962380503214176, 0.05028058361682681, 0.10311835340314335, 0.0483504519046795, 0.03426450049324382, 0.02639964842537959, 0.06978539284318686, 0.07187077610362923, 0.0680215520063235, 0.06510282596272808, 0.04517030984824223, 0.039660881288469806, 0.05067012400456494, 0.15555718673333047, 0.18556134204470343, 0.13521436541791887, 0.1988107714081003, 0.13759219508257606, 0.21968406264580068, 0.14678195599586735, 0.121331442628176, 0.18804029531536565, 0.13047192876617755, 0.18526279758061134, 0.16170104334671653, 0.21322494552981472, 0.22753284793467293, 0.18506195997038197, 0.17974270507693293, 0.16482252988123125, 0.1324909228471018, 0.16716893461923446, 0.18907603086723437, 0.13369214871237356, 0.13300378806889057, 0.11846170024645906, 0.1915579718808013, 0.12837000566744997, 0.21833573257730854, 0.11360959044747776, 0.1560181571591285, 0.09013412069649467, 0.11564344663413302, 0.11288415114845961, 0.11741409799264324, 0.22898490630811263, 0.2906990495900954, 0.11382027228753414, 0.176647495358221, 0.10001234950557833, 0.17472679035798197, 0.11392030038780744, 0.15569517449025186, 0.09083755028944823, 0.14394787500702566, 0.13840688362477288, 0.18078830784126637, 0.2515456440948671, 0.16119867352949035, 0.21470024701087706, 0.20084369296748794, 0.1336277053961831, 0.09334182276600793, 0.14119187369942665, 0.17385380252474741, 0.1653960539448646, 0.11087952121611565, 0.14530553602643553, 0.14095012699404072, 0.08851698569713101, 0.2462444688764311, 0.15385769728210666, 0.10867278196758802, 0.15664233495631527, 0.13512916111898038, 0.06538322946477322, 0.14236032632329773, 0.12015004311838459, 0.14115392170365781, 0.10537616773358277, 0.30612233004743056, 0.24531042383563137, 0.14326948882831683, 0.14938556709356848, 0.13542462590961687, 0.08854916905083003, 0.15521935728048125, 0.17597087118173801, 0.12051311516833883, 0.2327992887266221, 0.1687168765572771, 0.1944772571685814, 0.24307807426779504, 0.19777399397665457, 0.17120891460968604, 0.1824801210914889, 0.2791336959888858, 0.3145188069151294, 0.13834814000273907, 0.15300615991075195, 0.13460497311767072, 0.1434701272556859, 0.11994336025729296, 0.1632514980531508, 0.1870956322959354, 0.21384285672778086, 0.07383740807492888, 0.14866215026667043, 0.12423621054979102, 0.09645456823730662, 0.1303004782887236, 0.12148557951854122, 0.11662794622562586, 0.19119853874848736, 0.16632930225422307, 0.1307875569909811, 0.1072908589436162, 0.11510242002024768, 0.20334726830403652, 0.08971874016307055, 0.18116427315098627, 0.15844003687943184, 0.1641129486022457, 0.2379787632174069, 0.122405995855168, 0.17741016653035918, 0.17808931879699233, 0.1055581902243918, 0.14079899316833866, 0.16851933312512216, 0.20676783556419037, 0.07047438933964699, 0.1781246814155771, 0.15728307557442497, 0.1501822678913032, 0.19086818631377914, 0.12542319484055042, 0.1874219704299204, 0.10714530989888216, 0.23676370180422263, 0.11106394922300694, 0.11219851777798708, 0.13385558591013955, 0.14458631736136254, 0.1785617345763791, 0.14445727751139673, 0.13882999398535298, 0.13923675602962896, 0.08381131360487593, 0.1625300730548559, 0.22380515602567505, 0.15097673171229903, 0.13998844150093295, 0.11377896482665693, 0.15230187996020242, 0.19167734370116266, 0.13453352775785232, 0.12482505637190996, 0.14652390693945272, 0.13264466137174638, 0.12798503882461978, 0.24056224152445796, 0.15123190027811836, 0.11634545130354744, 0.12389588365030867, 0.1442410415338893, 0.1395933699583815, 0.14384431524142144, 0.1959676505817521, 0.07625829954180988, 0.08211095081341845, 0.1382746108837666, 0.08496225345879795, 0.16232258580144376, 0.12830799851085872, 0.20420709474673196, 0.1554046892711232, 0.13131723018182864, 0.1950887638715006, 0.1715701250659843, 0.2121440720774474, 0.07640013306011116, 0.14836492347380809, 0.2995817777850936, 0.19213212413653252, 0.1455215728210826, 0.15173900451871658, 0.21065482779616312, 0.17955257737588498], [0.042503132605023926, 0.031054708918917085, 0.02369892227673723, 0.03340097001543449, 0.008179289983555434, 0.08794142383961909, 0.06198628452576457, 0.018627042919697783, 0.005411190232412229, 0.05854285720195021, 0.031397640517342, 0.05258311066896685, 0.05253604222689906, 0.05510689540495796, 0.06000507390126587, 0.033996974929205837, 0.058973486715507124, 0.01392020637379779, 0.10109217341748938, 0.013453376332988903, 0.04917803753708159, 0.019862759978540485, 0.06121768383309246, 0.0115236209615344, 0.010501044884985013, 0.013624035824661054, 0.03671455692740218, 0.08952029274716493, 0.014923765275236821, 0.021568912479485718, 0.021533224273533113, 0.024600843335652066, 0.034913855770062056, 0.035819957753823656, 0.062437249843271515, 0.05062942941402716, 0.014275503588930495, 0.048162806328506245, 0.010832992697795554, 0.050756883461989706, 0.013861328686377215, 0.07056592918571926, 0.061430974202531005, 0.03787433360553077, 0.06200074060489574, 0.026662498937859654, 0.03187282953501469, 0.00811311913909571, 0.05279057877018087, 0.04199240859898348, 0.00526206499348665, 0.021099616593170552, 0.012682187220742627, 0.04382646522454677, 0.014333184263969382, 0.012444568771658646, 0.03522969466904479, 0.040504976115640134, 0.0497019267641008, 0.013209967216807268, 0.06543138575169348, 0.007146759552039928, 0.06268075089000406, 0.03685153727870315, 0.017684952040473302, 0.04927254980430008, 0.013309800922269783, 0.03733495025024299, 0.0700509419003802, 0.04397131712926973, 0.03554157672389861, 0.054469563878111305, 0.02775365712061044, 0.03288938033003961, 0.022432713003288356, 0.05849506863723359, 0.008156594628798626, 0.018353275654296723, 0.04510403558191273, 0.0181100657209754, 0.023994013599510637, 0.031385494193302534, 0.04610408292782884, 0.05332818097104469, 0.016063210937464913, 0.016235195761246067, 0.02647760553255437, 0.08679296611057175, 0.03779469110492257, 0.0864037474797618, 0.029965349127568548, 0.02257401792092189, 0.008102435085381712, 0.04825359923885234, 0.03004249035110397, 0.014948824011240036, 0.020917293412851232, 0.030849994903790857, 0.025068522776447, 0.023150579523174994, 0.09914673909905458, 0.05885191622280306, 0.013810474812353571, 0.04561180248856545, 0.034018678200100703, 0.044633056217383955, 0.03098955122573722, 0.034424030642595985, 0.009935547507578328, 0.031868912910501805, 0.0627758990101997, 0.05841538017134994, 0.02101461530753201, 0.04022382950830845, 0.07562081479737837, 0.06882515525625599, 0.01013098419794152, 0.027047959907400995, 0.041951120290304386, 0.05983662648847508, 0.04936569843501334, 0.022492500420119015, 0.019267856316160292, 0.027223265722333908, 0.09312318893329752, 0.03755339256097232, 0.035093250579290816, 0.07004984639464848, 0.047307741122260216, 0.035249731698704344, 0.022096593841730107, 0.03925268282933582, 0.05512593652031595, 0.0186668316112651, 0.03789701746896871, 0.04969336190110734, 0.04591524991537294, 0.04433577962880654, 0.04850571494429343, 0.09015865849270936, 0.08711856880014943, 0.025606546325669177, 0.026498705509208867, 0.026634938924783663, 0.0939142283412718, 0.009107136415437827, 0.02023952010448181, 0.07992787602087183, 0.004331549223993094, 0.05296414365030585, 0.01969747650887697, 0.003110982272060468, 0.03172252882993029, 0.06488644442851506, 0.11655073988461688, 0.0430318673381642, 0.03745372452202343, 0.02558352729876436, 0.06108967054094519, 0.056060035187270374, 0.05842272312410417, 0.017266915097171744, 0.034305302336091, 0.06439448574617987, 0.043016737101659666, 0.035070087910900195, 0.02320164311376791, 0.09661009940769404, 0.024764521851114208, 0.011642076349216364, 0.0406264738299914, 0.01914684889808057, 0.053055020830323624, 0.019537722278806954, 0.029913061711516593, 0.0338336028489134, 0.02183548043361835, 0.004085581852949315, 0.03894462355322415, 0.027309115450348587, 0.019535805143776442, 0.044615834560846133, 0.03128865301879424, 0.028097578887677485, 0.03651699051260948, 0.04765720745067924, 0.01858237807849242, 0.03321025625712449, 0.057824462081395814, 0.04917033069256333, 0.026870934225078073, 0.04197226431701453, 0.0469899908339064, 0.022211187188663793, 0.06071134951085814, 0.049925858094807596, 0.028983438913259777, 0.014665442342389257, 0.014149201545684088, 0.025812991699504278, 0.0246854500860096, 0.02166184660558018, 0.05594017307063746, 0.0399831208520599, 0.06381715039512323, 0.04210304318656845, 0.04570436506201664, 0.019794756268721916, 0.031328771128168995, 0.06818425375968218, 0.017139244629370592, 0.0016472117309721428, 0.026336595558771686, 0.03564943041231844, 0.028354446253468914, 0.024000736021046198, 0.018030291070200263, 0.021868081305236108, 0.11484703694980954, 0.0625060790128285, 0.03700798392416008, 0.05736102868292121, 0.05394383604007383, 0.05538889620032522, 0.05056094881447573, 0.02763883011685985, 0.017811463800288977, 0.025957094753281246, 0.031040723983859344, 0.06810430482390427, 0.06021397841733791, 0.014593405179649353, 0.06783199121033953, 0.03889783856368834, 0.09126887311257663, 0.0439693980790194, 0.03572949043084537, 0.02768553658238342, 0.05087182729414875, 0.049587316180188815, 0.037419633609392954, 0.04049702412298611, 0.03185018206075315, 0.04323490362073626, 0.0747424949921908, 0.04249174853846912, 0.036672563817832744, 0.11489154665821022, 0.028639065154317408, 0.022654635268413735, 0.06054201726651481, 0.024015707294306448, 0.06489594391877614, 0.10770796317486994, 0.06655935062876632, 0.014385136516554462, 0.010357827620370495, 0.032701550892764525, 0.05424911058658073, 0.02827502017269933, 0.015026069614255141, 0.05994336168852545, 0.05162613278615379, 0.05466530317320459, 0.0033330804980059546, 0.03709673137974836, 0.03650547621110755, 0.026630057029486186, 0.014157284730895153, 0.048219358939076626, 0.0003703813367352386, 0.12140352384097154, 0.007588429829000586, 0.06849792079939958, 0.043653179966514154, 0.013374391710385682, 0.006931860876765343, 0.04090822181634365, 0.06640836235976989, 0.014016502668269941, 0.08944383717232174, 0.01537501596049556, 0.02419057452390271, 0.028404343475197113, 0.06333977802686634, 0.13790455977282218, 0.02381112159890754, 0.041883057208671685, 0.05920822754682553, 0.017000768491397464, 0.016874145648832765, 0.05449634631194415, 0.04931903601954541, 0.023736021999690323, 0.04184869816526771, 0.0892274173337125, 0.005599340947810561, 0.08253320315552336, 0.055431973324307514, 0.013026204748800205, 0.025235761685537237, 0.01162219157953176, 0.03530361449285861, 0.02860993083055702, 0.04843742203628344, 0.01455342592371087, 0.0453159163495706, 0.09709763776270613, 0.02967776546645309, 0.08080860900302088, 0.06396915756105896, 0.03425883910348339, 0.06787898304361491, 0.061655357525113134, 0.047060532209974144, 0.00646814929261323, 0.016886847386617335, 0.02576014886970722, 0.06564683265863888, 0.03200689492176377, 0.04868734673026109, 0.047558577460867744, 0.022446726666643255, 0.06734280576629025, 0.012626872799779861, 0.015638285906114165, 0.015006809206228825, 0.035873200864561146, 0.028930693759673068, 0.1060926361430076, 0.05494027511186658, 0.09275389624939812, 0.05279031830028661, 0.04031521230635624, 0.0764337336764701, 0.006001780340973769, 0.05195565401546417, 0.061682814116319346, 0.04885121293726468, 0.03779259968488928, 0.04403759139559923, 0.0313194650751088, 0.030808336957688295, 0.017563850776622855, 0.03475816372121054, 0.029615233539633697, 0.054618793975321524, 0.023458769034233787, 0.04222610372028524, 0.02200009932200755, 0.016605809946814855, 0.02423280129028905, 0.19442171579407108, 0.11193104584010378, 0.15083707388370268, 0.13754010110372497, 0.08504537399858238, 0.21900296451583987, 0.07758540897479943, 0.1281177865401391, 0.07866006945410083, 0.15417442867352119, 0.12248045194052881, 0.12208279102079331, 0.12917927796802214, 0.12646893550071026, 0.15252171655095395, 0.09299154438438917, 0.23616080592957236, 0.09715617454100041, 0.21525999681363184, 0.09829651939892962, 0.16813219825346626, 0.16520771888955949, 0.09909071508915195, 0.13968001450261763, 0.16189961333669003, 0.11503305075870407, 0.19481537773484187, 0.15838829530102594, 0.20484009787680643, 0.1090802641345128, 0.10566640014369642, 0.2037028097096951, 0.25057792182891603, 0.10387950006031221, 0.11082826993398129, 0.24197339080274108, 0.16563312751391243, 0.18518931442691436, 0.10809165831174582, 0.18944560700366575, 0.08570073923516659, 0.15620359640207984, 0.2208661822782409, 0.0900955405086279, 0.202806425551253, 0.09248761174779746, 0.10013238782243383, 0.16003795839365453, 0.1641780201105341, 0.12027270145594113, 0.10264463527428527, 0.09791886869577632, 0.1401886509190644, 0.1240582713076184, 0.1495272320725264, 0.08739419191354707, 0.16964038022823874, 0.1060916172460683, 0.18181736310643537, 0.1130427007052687, 0.1519495714455843, 0.16082188084481225, 0.11425076007482507, 0.15259029674193553, 0.09574615907284523, 0.18206772064009022, 0.15733045045166247, 0.1477005107388381, 0.2041041938167426, 0.18679460570696862, 0.22073697388893176, 0.2973126253533748, 0.16414273410074173, 0.0866808491428533, 0.14320604142642793, 0.1248599440159817, 0.22587432886563966, 0.2968931156060388, 0.1402596672696452, 0.1821262037922298, 0.15266407100904375, 0.25811392874006306, 0.21554619194038455, 0.2090583924925135, 0.18851929945090126, 0.0968660953484716, 0.13577846660008355, 0.20160236516066138, 0.12270333756121898, 0.13255099946212384, 0.14343202204233216, 0.10814730693856556, 0.21057644167975073, 0.11370997860907547, 0.13084993186977603, 0.16590878127082703, 0.10481477850267004, 0.16744227479061774, 0.25268173716481657, 0.13765674565107594, 0.15408228361798873, 0.1176351373414359, 0.14488760442022355, 0.17242488000662098, 0.1851435942995933, 0.10332766394581526, 0.1381820061754796, 0.1937168536166991, 0.15379628767409634, 0.2750726026152411, 0.22076645295225808, 0.17950612180415662, 0.10365440810640013, 0.15873689595009052, 0.16929476732207885, 0.23958370209701602, 0.11570210598649518, 0.12487070755131784, 0.20874435773059247, 0.1902397490677334, 0.0900980839205365, 0.15673317766237646, 0.20239643061593657, 0.14108422302430676, 0.16427802522816967, 0.12004889652974184, 0.18515194465796794, 0.13175907905303663, 0.08899187594051323, 0.15581708972252187, 0.1274117905526392, 0.16042535373520467, 0.12227435896713888, 0.20358277905371883, 0.1853076596894572, 0.08743110202973889, 0.1573545975430358, 0.09394498677143166, 0.14044890630870097, 0.1471803063947347, 0.1532946226577605, 0.13481115802161156, 0.17302667271466027, 0.13163046821230842, 0.15365250829246738, 0.10029147364078991, 0.12542383835440682, 0.19204054598606404, 0.12443068196936963, 0.15967648746746202, 0.07174696097330702, 0.12899701032907734, 0.10086194867448461, 0.18889886537386527, 0.16466837766910755, 0.09669126642327155, 0.15545128273867792, 0.1601662781209715, 0.16320291275699295, 0.12504601911191018, 0.11929762474591694, 0.18117057039372383, 0.13488686283028897, 0.12516483168808684, 0.2497726102029124, 0.21260718754943342, 0.19420583221700885, 0.23442865048925723, 0.1526625235114367, 0.1860174248295446, 0.2435289016894756, 0.0630928793801896, 0.1306849318526445, 0.156246007029568, 0.1143057115616337, 0.14362913646524952], [0.014820317549991512, 0.08393784068645009, 0.06176055671887533, 0.0811706008690019, 0.07805282986091991, 0.007600349199492485, 0.024559978290551135, 0.04599152162911431, 0.04577288013552466, 0.09417872785800889, 0.022637507457646634, 0.044022005336779746, 0.03790210812322555, 0.028063329011802713, 0.05974306800072232, 0.02005599608134118, 0.043667793093669804, 0.022953731315811316, 0.04295808157973713, 0.055324196244680116, 0.05502878891063794, 0.026673540180068345, 0.027584106541208686, 0.016723492543303197, 0.05144565779295179, 0.0648498867127684, 0.027034459522955363, 0.04819124351225553, 0.06300380633723351, 0.033049576975885904, 0.05041702770658078, 0.06892461645146532, 0.047397817740397113, 0.04499759915615282, 0.07026593681545028, 0.03600291870233994, 0.04497335247334935, 0.08403155622222731, 0.051510668014206236, 0.03500629576944536, 0.027160329684134454, 0.04172846449599151, 0.04335119193720241, 0.01493898839990218, 0.04200951151189305, 0.13909752721027022, 0.06556321416170367, 0.01849237806914795, 0.08293791208416224, 0.030160259132483797, 0.028153081957791603, 0.06470069108951478, 0.01660362085057122, 0.03905574843708066, 0.06744797431653546, 0.035672079801799796, 0.05118898769480087, 0.06223579170182348, 0.06135620785156085, 0.032879470982739044, 0.03335348788588759, 0.02915511730187122, 0.01203366602215195, 0.02853852569035465, 0.022267781934070013, 0.02870852826163173, 0.01916403416544199, 0.02094998813023971, 0.01923316785494887, 0.08097692618086454, 0.006716649063051709, 0.02503616130730558, 0.03221962413179778, 0.04821421082822546, 0.06615095681721164, 0.020306054840705568, 0.0741297472268343, 0.06238489922496581, 0.027256805051658905, 0.010820240206686, 0.03812702004647544, 0.020930853169110995, 0.037713232975933826, 0.015230415907177716, 0.046348744597766674, 0.04620823258113477, 0.017453344508765206, 0.1379222257603561, 0.034826395342186574, 0.03590001394191096, 0.06956544133924669, 0.02001725884544994, 0.053649459094289816, 0.006674001427111968, 0.0036164990348380903, 0.06208057845792463, 0.03681334013479852, 0.10176741863570868, 0.04651264910916648, 0.03747730853877241, 0.03150182847504414, 0.054480055452234326, 0.05151048032266479, 0.03258509403695503, 0.024463790205998287, 0.038289641360602075, 0.011417890294274737, 0.109912664629519, 0.08188340737814866, 0.06504281063473995, 0.03577819064019188, 0.1138314341885909, 0.07496014823235812, 0.09097231281620842, 0.02897283817160755, 0.09386775744778496, 0.04172553037924152, 0.005471162946759573, 0.07637064633590561, 0.026470367916889732, 0.07165399620369559, 0.05067123483205515, 0.027375722964925152, 0.03185354327152093, 0.043844973908797394, 0.05149105233290503, 0.015685559276701705, 0.012471084989937804, 0.029816835322567535, 0.04149644710724393, 0.06890813790021405, 0.03826925576093697, 0.07736099883913994, 0.033703693489153544, 0.02268851550686504, 0.01165959869526447, 0.05974704016660971, 0.08690361218947558, 0.06752950139343739, 0.0827628686543434, 0.008879417737555361, 0.055031872414533174, 0.06194264049671831, 0.0622697830230238, 0.05074766359382099, 0.026141986243366718, 0.07745761018727096, 0.009699469852832057, 0.03341344958772102, 0.027462991870819565, 0.04588754434559134, 0.011009499355549774, 0.06690972860181524, 0.022537247615776235, 0.01108136319089681, 0.04347604894710164, 0.011881624382259625, 0.06349756149575114, 0.01627822117429347, 0.01867603807289514, 0.0319200799229645, 0.07362324053481703, 0.009405496060818194, 0.05684591882351426, 0.028333819336107666, 0.026602935601746844, 0.05239004885116893, 0.02515530330128968, 0.03202994076174594, 0.03082678435490497, 0.033664316569845525, 0.0850515180237351, 0.0184747580468895, 0.07243642478340095, 0.06577887557326786, 0.052762091790716496, 0.056825747728467955, 0.03454774235104842, 0.03791247712328069, 0.0176027316539999, 0.06487641633758623, 0.014813227406252297, 0.03937571271953564, 0.03478576203868274, 0.0826804529154493, 0.027172213623059854, 0.02286257068326156, 0.031280509504159136, 0.04808765693357395, 0.037860107352776874, 0.09093966214887558, 0.01317481527240166, 0.05901558324694634, 0.030373447995272376, 0.05209530035274164, 0.02603894550233118, 0.039539529130824154, 0.019604649635091908, 0.030025575129735856, 0.01288654787781378, 0.08540850733557055, 0.08204276132727824, 0.02943374347993203, 0.02489029816652258, 0.051188436111495386, 0.04391674868642323, 0.07027860024883863, 0.05620554975804783, 0.03684672241609904, 0.045746270071474776, 0.07138847012913997, 0.07614108808939496, 0.026967869245357094, 0.06886987946927547, 0.036568877647721, 0.0195773730745479, 0.041052299972263076, 0.06918209094193674, 0.022418998114223924, 0.01595753964201938, 0.004010851651753089, 0.03047520170859512, 0.05758399474284342, 0.0075491050994324115, 0.04045754761224793, 0.0433224291660853, 0.09945909612842145, 0.04503717525832115, 0.04770080551445004, 0.01100232015408936, 0.06329526448802603, 0.024849586339006503, 0.06121129849024358, 0.054900848396843484, 0.03334254431988924, 0.06563659006309125, 0.024796414091402007, 0.062458508783170295, 0.01940720196392748, 0.010322900714292642, 0.06783000704261564, 0.022154201738416188, 0.06511886018298327, 0.04129822568727597, 0.03401406635079653, 0.017723662463287194, 0.04007870181193275, 0.08015624683109984, 0.021945680266306288, 0.07866243666578686, 0.03216030977426037, 0.061752271477974234, 0.07490887396758603, 0.04301173071707449, 0.07753837883712784, 0.025794513658770633, 0.018091754304365288, 0.1109315385861743, 0.050345260589834184, 0.06966819671253044, 0.029896217353281476, 0.054386857025805986, 0.03471144767958791, 0.021512740997657664, 0.013662164020652493, 0.024407702993841904, 0.041210818885555195, 0.023461048145808523, 0.04786089490798693, 0.058633500725151076, 0.0635263319277475, 0.030569798245485273, 0.038818636563636606, 0.05967764026154915, 0.03334083977425772, 0.04731585782381797, 0.058843025772441784, 0.046542580164368116, 0.09511345471706122, 0.03799737115660983, 0.01765839751779793, 0.06361309521561188, 0.028730049586644577, 0.056434200190368204, 0.04337246619885968, 0.042150372098530495, 0.025400192882384987, 0.01103744337019781, 0.02535018840834739, 0.07316178747362669, 0.011794979838023504, 0.02658710822523121, 0.047237958173237504, 0.04019217475527718, 0.060291027710322416, 0.013333095740827342, 0.019227933559206226, 0.13279280745454375, 0.046587530373325275, 0.03563797356741082, 0.016091596410279314, 0.010616735652870229, 0.03625732501067462, 0.014299366270161927, 0.10796598158776761, 0.014939228759988423, 0.07458912418974985, 0.022637268055170294, 0.06488147251788648, 0.003997029031574306, 0.04581874581955133, 0.08253141817065977, 0.06357256916441745, 0.01758000757094593, 0.038814530332362464, 0.0222117253654306, 0.013985587190085602, 0.001999925553982687, 0.044162590131764455, 0.02031910897893531, 0.04864387124055817, 0.040409820334565257, 0.03726551587122583, 0.011622734544348094, 0.015286963729698573, 0.055716912066864396, 0.057337597883757085, 0.03822989799382706, 0.04499323245498442, 0.04180758222637158, 0.017741311213842804, 0.016728908784927863, 0.0252273079052928, 0.01402451499034801, 0.02977280058867989, 0.0307048557160963, 0.061529278604974674, 0.020905802093987024, 0.025236416690712495, 0.08984454712199588, 0.047090520721770106, 0.01649192906165075, 0.09161804832758443, 0.023443445360528368, 0.044227359035322746, 0.057878452127859484, 0.03775920208183028, 0.019242391553557208, 0.02632680112465976, 0.04241128632378194, 0.019967104984267105, 0.06839721854175292, 0.12772859089196692, 0.17623206119864218, 0.15096896358074682, 0.16260847449302673, 0.11122377814664958, 0.12235639166207084, 0.13523673518530785, 0.2602792915798003, 0.14719313070658716, 0.13939144450329966, 0.13908606653492298, 0.15494685980581469, 0.1324770566556723, 0.10205166023825446, 0.16166195754081975, 0.15800849955168464, 0.16560492015654044, 0.13949748639377857, 0.11811512973039381, 0.25770030254798554, 0.11277915879843697, 0.1598777387651705, 0.09813701223221519, 0.15890659974707713, 0.13509065753990604, 0.13668752185279323, 0.1197756712715472, 0.1493657100945711, 0.19030774703189252, 0.07983471206840008, 0.19774975495473032, 0.2073702104990521, 0.14311348268341634, 0.14115418217355205, 0.14397816612355172, 0.18317995773207757, 0.11925264006300319, 0.21454280062067896, 0.1650288220374815, 0.19498554118458303, 0.1513079881307579, 0.1426617665997436, 0.13359295564793772, 0.09998018147363778, 0.13569667905328736, 0.29479945859601425, 0.16426685566623367, 0.15928901551711946, 0.2875613679568614, 0.14916557728523208, 0.24972877465188506, 0.10255006172003285, 0.15950322902250677, 0.1830776237071522, 0.2784142168539186, 0.16092164081431207, 0.1528752508062509, 0.2191616979337508, 0.17951290934316574, 0.14847142501704155, 0.14079844158503318, 0.13240170424744008, 0.17633077928856497, 0.10527518968428336, 0.12649667554444846, 0.2200112434765024, 0.1611524018188638, 0.20337395880731846, 0.10341837641692932, 0.1557267526344907, 0.11162405908708611, 0.15241371347538887, 0.13836749138370638, 0.14232540803570903, 0.11221583902595506, 0.2268036394830673, 0.18812025957290204, 0.16555621228631467, 0.2442001938940056, 0.15039560805645683, 0.10543014628872757, 0.3105305838248422, 0.22427024800450573, 0.17831009001501147, 0.20757012880377232, 0.14146643961148878, 0.11072108657249521, 0.33153236332920294, 0.17367953284373208, 0.11011832859367134, 0.22738899194425155, 0.07524861864024594, 0.19573073023028914, 0.0976414759192736, 0.1071157695485219, 0.17494590682608469, 0.09062595680476197, 0.32367285280939073, 0.13061238332621514, 0.10598061110584006, 0.15203321292515726, 0.23220397712242222, 0.16183395960157917, 0.0766525437094031, 0.1869209029621655, 0.1587114618310044, 0.12608396865788007, 0.2099745876846775, 0.2653523871014195, 0.176681570949093, 0.10295002856442045, 0.12631192578062897, 0.18264677585853686, 0.21468251973630922, 0.13736019301558697, 0.13723348207291097, 0.34201603142484543, 0.19439212947843537, 0.12337591679346178, 0.14737789579216512, 0.250491185354129, 0.1740294818075434, 0.20826634950935843, 0.12471478567608904, 0.13878882442030216, 0.1088272329540022, 0.10776518228193445, 0.11569940169612247, 0.13454193940326092, 0.1285953351086186, 0.23058526398193455, 0.16070229451983206, 0.1279295587371434, 0.1032363232826033, 0.11556797165183291, 0.15198315674018475, 0.11952167482025201, 0.1576286731588264, 0.1378366077739385, 0.11885931520091912, 0.13549142877661413, 0.15041931081683407, 0.13239746012033957, 0.16460638583427475, 0.09805134828052214, 0.10485839188819933, 0.14828521968616595, 0.10222556219706613, 0.0874790131685234, 0.2365751522442987, 0.17673216339561248, 0.1807000238688723, 0.1457583705984777, 0.10144693341346518, 0.06310407192476335, 0.0842681011906074, 0.14538631233717167, 0.2186593281165246, 0.09777492077480401, 0.12841780189304583, 0.16880022692343882, 0.17366369014545796, 0.1102886529218766, 0.19818368247680127, 0.15117632826009106, 0.0786705342151465, 0.2117176522170344, 0.1534438106201349, 0.07479012267844332, 0.15681544018368568, 0.16370278512758596, 0.17879732193485384, 0.13066093797885603, 0.13303761851162682, 0.15015231385346384, 0.12011345475912096], [0.03747630879403122, 0.0598408552938171, 0.011088499299911483, 0.035565019014381596, 0.058798393489973205, 0.028998950278506647, 0.03404638760032193, 0.07194083484430468, 0.013172793757891463, 0.050324913294565295, 0.11000493225911934, 0.022970029836400382, 0.023943647148928816, 0.022005655374678395, 0.010240987720598858, 0.0383962424952657, 0.06931054090420086, 0.029980881560233333, 0.03894650812951788, 0.05192023394028506, 0.06256722432050495, 0.03310261707332346, 0.058903255605048714, 0.07069143737035413, 0.021897853397193457, 0.022464262419230035, 0.05619404694786476, 0.06374076376819322, 0.03564595620358183, 0.056512869759312565, 0.058537437129885926, 0.0466283935032064, 0.0446050365515534, 0.02952674655393968, 0.06720696305555683, 0.07126555898256841, 0.02553084917787102, 0.07224710913555277, 0.011547232748970631, 0.08294910462873598, 0.05019582747932404, 0.07273650908422086, 0.023198046330963413, 0.06405316293239594, 0.05807321849128893, 0.07375562052813268, 0.026003747592650117, 0.020181561722570372, 0.02421580946012851, 0.05174280414658208, 0.07903221198507855, 0.02598742608942332, 0.09316661845772498, 0.05316156067795331, 0.028630730117701238, 0.08625473571761001, 0.06513664108370582, 0.016701986540048834, 0.03958464404868503, 0.04232563769384738, 0.032600971209185745, 0.03689505873368152, 0.01640592037039178, 0.023416597809221958, 0.0550129423819242, 0.03393259673048893, 0.029655347818568833, 0.010991520229576817, 0.057962288959853114, 0.02517409735329209, 0.07780644066271283, 0.03983467599497207, 0.02382757525230127, 0.03653439603024914, 0.08757697283140115, 0.02056685415276837, 0.06689676639413641, 0.04338478872312173, 0.04442539276374925, 0.037146117237787095, 0.030013105133548382, 0.04143486129901102, 0.1336348300138789, 0.08880637541052797, 0.009752165210703689, 0.006848924198082739, 0.0981008988474646, 0.10629189561211294, 0.011536931739218775, 0.07521077389678649, 0.0130199754963659, 0.012953933929243397, 0.05520740614062356, 0.05466794617654336, 0.06547306859565359, 0.048668121753801266, 0.01433996509970917, 0.019119909416223248, 0.04710949671965453, 0.03566743347853903, 0.04819919167446995, 0.021165938739995324, 0.02941642797762348, 0.08597377297138015, 0.12050674131680882, 0.0807903224842683, 0.06395404647675253, 0.028453415237186898, 0.032972841778950344, 0.030641009948486765, 0.04954932588002375, 0.026672944546707218, 0.0605911081807027, 0.020019239182734204, 0.06923947092746535, 0.0822117603233745, 0.055894242269137216, 0.08357868334578891, 0.03343943529011261, 0.034156393995808984, 0.02190747546152242, 0.022520606270841053, 0.04497649726427851, 0.0880318068929257, 0.041869367217464794, 0.02425000762506839, 0.04252985758226245, 0.004691547346151164, 0.013292497868890004, 0.008986761977505541, 0.02602637974515317, 0.033538433002127756, 0.007505715794620976, 0.03813576877057072, 0.0600253407573027, 0.09493437400388141, 0.052960271075848615, 0.03674682072033325, 0.08085537100991896, 0.009849328142140183, 0.02434189029548678, 0.1216503190657785, 0.0800815532584825, 0.042959575451189475, 0.03543356981789393, 0.03344552185867102, 0.04542803331728905, 0.03555219087208952, 0.020124507324409582, 0.047593066739218856, 0.01758768568716703, 0.07828795756664007, 0.038288791003006126, 0.039736356270769914, 0.10112710702683657, 0.06499867630942215, 0.06605950124081104, 0.016879573381776293, 0.034681688994169235, 0.03686981613657648, 0.033544902614648306, 0.008586250253081804, 0.05827676039189101, 0.018215563689028064, 0.0203739627895336, 0.02050184393151393, 0.02686281177786089, 0.048701542339498, 0.03038250123931756, 0.020973223576983138, 0.029230232222846923, 0.037027247205016114, 0.03968603578546355, 0.05435666167027047, 0.061650446901518496, 0.02504571825416098, 0.03980969003732166, 0.034007792090696674, 0.04086168963582285, 0.04109239701421992, 0.04239879526017655, 0.012827519845638066, 0.04641140292909357, 0.014199711637751711, 0.061776541143415444, 0.09698781139788129, 0.05658902272942567, 0.03639292640371188, 0.025043059929063725, 0.011740570358421293, 0.017738304318740003, 0.022816592001266057, 0.0027848361388614945, 0.07402218082138608, 0.03093549414658018, 0.03733482001529586, 0.014741802156241912, 0.09937567681434656, 0.055807601555340716, 0.02292282349850622, 0.038149056565617366, 0.032518333304793604, 0.04769916225585246, 0.06720442730452746, 0.009547446407527934, 0.03810281166806817, 0.02864354868389426, 0.018612303388034625, 0.010869125234744242, 0.07740145594242119, 0.0922669094776915, 0.027163832621168227, 0.05749126746048851, 0.04493830395081351, 0.03265786089844281, 0.12838996991875673, 0.03970110473493415, 0.01834332608738013, 0.02089234959003666, 0.02450902578270724, 0.023885593006026842, 0.10064470146091715, 0.054899074903298775, 0.0390600691729736, 0.01822483718335148, 0.053553950912769765, 0.03741088105485805, 0.004667328912839895, 0.07906225795346884, 0.05372411436251095, 0.07116300279214498, 0.03139453786124866, 0.07788950757634255, 0.01948038059767456, 0.04556371897999798, 0.06876992031691537, 0.053645214967189304, 0.0298996934772379, 0.03890990061805614, 0.02785163210524667, 0.06607339807575749, 0.06231451106648292, 0.07950993675378062, 0.06008224193787864, 0.047662095091636145, 0.08484419930966632, 0.0019940996947210104, 0.054038685385978995, 0.013773195058738273, 0.0551266604734044, 0.026192948327309666, 0.021176028117958098, 0.029333548755535198, 0.053322787712057756, 0.05199940912725945, 0.010892971636607282, 0.01478242492603679, 0.012871761423265262, 0.009824654365318918, 0.09923985708625087, 0.08008332292158758, 0.027859620487077102, 0.07376800816986831, 0.04279165280862682, 0.034573138165738315, 0.031955517235121904, 0.03816720518854357, 0.03328523328227382, 0.1176297517433282, 0.03986814637638388, 0.0387504470774964, 0.061697365956441055, 0.038389891626373414, 0.027755828979875774, 0.022837515777697968, 0.036888654238634536, 0.05467170000737233, 0.03094167456090931, 0.05365914244565272, 0.019576702747614156, 0.091848487575208, 0.05216512543660018, 0.01301549388200886, 0.04436552299246673, 0.12247473692461369, 0.028502640216761542, 0.08244124196109273, 0.012457762720934566, 0.028225176577125827, 0.04278236399254492, 0.07754253103367745, 0.08401830290113727, 0.053429630164417534, 0.05900327221400315, 0.019016512444302924, 0.07953353226184845, 0.01881864342478014, 0.06073457346628271, 0.01976335240948585, 0.0014459664183255707, 0.001886581528871771, 0.02818592414710551, 0.028034684984313867, 0.040804443715680996, 0.04895917004755428, 0.07108792617556549, 0.04388351196182832, 0.03830693579549271, 0.04603785079633517, 0.01297337819837154, 0.061150658800597155, 0.020668203754711057, 0.03400266696248324, 0.05479300619974252, 0.17947737818523762, 0.03436783043247077, 0.01310494805370728, 0.0259704380897024, 0.027727838042342377, 0.1133714213726982, 0.009092802910374538, 0.09069518050959996, 0.01659091719756684, 0.03505393877745636, 0.008898452149644014, 0.0191593284703671, 0.01935810338886034, 0.021323302775741588, 0.052827121164169044, 0.029594800059473323, 0.07201139920301015, 0.04820488370774735, 0.03654157044366002, 0.01957682149124242, 0.06537777491875234, 0.03447151660258251, 0.07391784730697833, 0.044703149432016, 0.06147663304281812, 0.03231277276251105, 0.005541730178294764, 0.03910771601142422, 0.03874880764933844, 0.027181337730238037, 0.0033032212635472178, 0.013358250237821091, 0.08115167083639292, 0.0140415872597406, 0.019523009560221148, 0.023965946053184813, 0.0907240390417076, 0.04266369314263425, 0.13810657715845492, 0.12130472914225633, 0.09065518305907327, 0.16846929226190815, 0.1761841194163407, 0.09851856232290307, 0.1040959275598007, 0.23791675606081564, 0.15314328964919816, 0.21623717260456857, 0.14517464224369298, 0.1033597247254464, 0.12588470918877473, 0.147897609839997, 0.07586148131879107, 0.1464466086678928, 0.14968362126138904, 0.13290004444218453, 0.16139705965836204, 0.15766129318264224, 0.11902726465655912, 0.23019799121445228, 0.26262532859559984, 0.15538349927913758, 0.1793268725516335, 0.16270795867087381, 0.10605902786576941, 0.2489894078744035, 0.1415292281777628, 0.15029027096686826, 0.1407739267714562, 0.11490572694568865, 0.16531618161787912, 0.23915743545418788, 0.22495186707425505, 0.18130121902833063, 0.1633390159376206, 0.14493977500786706, 0.10943028970711655, 0.243715857786517, 0.17125521696382956, 0.17950261312146343, 0.1610392659542061, 0.1299244057266943, 0.16110358669632868, 0.1804628890127905, 0.13325768492875562, 0.04953584656299603, 0.15214340701218576, 0.2138580099469231, 0.20588698766885266, 0.1425780791548952, 0.19106315569050852, 0.06510196028337364, 0.10729797590043276, 0.11459694754692817, 0.053312345933649814, 0.07640543438854717, 0.16077003201409695, 0.1548791529550668, 0.24446869238970742, 0.12246445602466985, 0.16899986943650633, 0.10991592050319719, 0.2441882735659038, 0.11767139628289208, 0.2134773868226236, 0.23634498878832788, 0.18608448816643608, 0.15466455640571733, 0.10959932700760903, 0.2315765511124365, 0.10522549356063528, 0.12904749552328743, 0.25283110898829275, 0.12178328894679585, 0.2042447709508481, 0.16276402098517265, 0.15991146195559733, 0.07306276294853419, 0.25912093599477126, 0.10291597595618618, 0.22148672881866657, 0.21610398055805316, 0.17586432367322907, 0.16145365823420788, 0.21056931706205492, 0.16568667705981963, 0.16223177373889955, 0.1951903164867432, 0.15602106829324078, 0.08041211253693027, 0.3459343872964383, 0.19760055167059745, 0.17999640275393763, 0.13196074403822422, 0.15285239074259035, 0.20908443948193906, 0.14256310979685477, 0.11106103042801542, 0.16509743287198006, 0.13085924749893527, 0.1535133101166256, 0.2084979685323854, 0.3453259602669747, 0.14981742617824387, 0.10339504137875573, 0.123287579194913, 0.32360194371111933, 0.20331967381700394, 0.27923782265955405, 0.09977268655934643, 0.24159475950704468, 0.10362082281179967, 0.21243138569256953, 0.20304786582146922, 0.154228407228666, 0.15574469441367736, 0.10468891791759, 0.23905468774178337, 0.0743771246784637, 0.12440334029135205, 0.12947569270768475, 0.1270156158434768, 0.11422587753904444, 0.07920446685485302, 0.25540646676334644, 0.13734531558809743, 0.12356591425956258, 0.14099333435297012, 0.07789875425758862, 0.13180141307173238, 0.12775721193681802, 0.12771497750955244, 0.12413621309303469, 0.18218588204153124, 0.11681762193479847, 0.1283577176171445, 0.375768976706651, 0.159993801085699, 0.09651880470975753, 0.27463020216072764, 0.23105509038413727, 0.228867924682075, 0.11111823421332145, 0.1617184028990807, 0.11292421754689948, 0.1321274141270307, 0.10706468680573088, 0.09325645758860535, 0.08099011055404141, 0.2013810883246122, 0.14850347813579345, 0.13404488623622926, 0.2450773186020313, 0.2175070246260974, 0.09160137059347284, 0.10704290692604358, 0.15726159446902815, 0.17728884884667012, 0.15776393364273733, 0.1579999346886912, 0.21917363358361108, 0.08006944140839962, 0.15297603733356924, 0.12107726231577898, 0.1290162238142183, 0.2224877452658069, 0.10019457117924768, 0.11525543842224345, 0.1429684009523161, 0.09258760920455379, 0.12341186163886902, 0.1515251893790499, 0.11784454747553795, 0.111487373679636], [0.047341636682470004, 0.015056555125591977, 0.026250152112615686, 0.01130371159243007, 0.037688959480053, 0.04704546326050355, 0.04308243680204596, 0.03442503038733717, 0.02458939032118407, 0.03341123559361985, 0.09886332487146701, 0.031938490931004766, 0.07449704808213058, 0.03745319209091606, 0.09978033977770999, 0.02397143315794247, 0.057009685439087694, 0.025724646440076254, 0.025954202771367087, 0.003917242650077829, 0.06074981478553626, 0.06176381642299314, 0.02089661286933528, 0.07970368805071039, 0.047981262642649875, 0.03331413011877768, 0.038845947598137205, 0.044309793926414945, 0.02372765631955718, 0.04347948102100242, 0.07847664502239035, 0.03150277650885044, 0.0478099002653072, 0.01362613969362311, 0.020732336805292198, 0.03798321385176913, 0.011454247869551184, 0.006328470396598982, 0.01845856869382964, 0.034868771495718154, 0.0261625288910563, 0.061512018644040635, 0.017845870724188227, 0.020639080922269536, 0.06257811426034858, 0.0358812639399642, 0.009710422037319552, 0.05445255289575266, 0.05009524396530563, 0.032634456912356044, 0.0010830777506682001, 0.08656558355376606, 0.04571682931254468, 0.05949574034480799, 0.029776106258073164, 0.024113699515920975, 0.022834395884626338, 0.03146191529418913, 0.08517738626969439, 0.06848904184035717, 0.03886248743642242, 0.05712290557341711, 0.03178974729962647, 0.027811822346261436, 0.00961940696147541, 0.012962242152782218, 0.05607036971336892, 0.012049269317949732, 0.048570139108285795, 0.02272404858001298, 0.036801649633074, 0.0360557442951587, 0.02481521388906385, 0.02749049251208142, 0.01676725723119753, 0.0605311158353523, 0.04114674329156837, 0.02348799911898471, 0.07302732372115697, 0.06366079951065683, 0.0148416665052214, 0.0656671493103908, 0.03149893649312998, 0.02806930066717248, 0.021176807612421054, 0.035041535813962264, 0.02585159295478896, 0.03582519779522573, 0.012073609846523933, 0.023034059465111747, 0.016220186183589603, 0.07253197893019646, 0.04714605826584082, 0.022864656357635415, 0.008412327226852218, 0.04261448348481809, 0.04872996037104919, 0.018796265996511907, 0.03743651435680447, 0.09314995604537188, 0.05289477438876226, 0.016315165764441895, 0.05363961486446281, 0.0016882509413746096, 0.03544462829708092, 0.0035959499232816484, 0.03051084586449208, 0.06566419987188232, 0.020256159534197182, 0.08901887287896487, 0.07061079895544438, 0.039084120503356384, 0.044065997935831554, 0.02941314529086794, 0.0434026270804386, 0.022522115464051886, 0.07246190486776252, 0.11895591888817088, 0.024176459353897842, 0.050759997609401905, 0.04116727827837871, 0.024908464026427077, 0.021547659285246365, 0.032411969657386505, 0.060019690858861136, 0.013505454032471585, 0.009946331152722481, 0.050577599735509966, 0.038952590867636666, 0.05695443134754897, 0.03508220742186231, 0.05269339285610665, 0.06412026457368367, 0.07745535022789433, 0.06671790784645466, 0.012590343812330356, 0.03960556207945751, 0.01621278385902124, 0.054757865746655775, 0.03758672887699739, 0.04998051080732577, 0.07194079653990847, 0.08583372443794243, 0.043339643161743886, 0.10912438313807211, 0.02704117619883149, 0.025796375252426635, 0.03765081213186345, 0.028339178121138005, 0.06158750511765961, 0.0616620454726921, 0.013351442589003955, 0.03553413417971423, 0.06547372743126846, 0.06891864862653517, 0.013933904983493832, 0.0642856246521396, 0.021498024448632233, 0.017485460829770854, 0.0256942116820644, 0.051226437902979316, 0.059863646409564444, 0.025299582555289232, 0.04441932917782857, 0.04479527150491073, 0.03533707721339118, 0.04523470336871763, 0.026746199789246725, 0.024017802544779355, 0.0053954136092215785, 0.01509281023660855, 0.021922134553953525, 0.0468914489442062, 0.02963232304600458, 0.03781477026941796, 0.07180660091821225, 0.023244513394010645, 0.01710884243009552, 0.04133816951164796, 0.0634430926443348, 0.01264328814877738, 0.020222262058767582, 0.024876910780045777, 0.029807144310325388, 0.015266650908386276, 0.07143628167649431, 0.05720202330379717, 0.03432350841561153, 0.06348662559063205, 0.03643668534594678, 0.04168924079426835, 0.012421972050722088, 0.06839178697836977, 0.026300593256770123, 0.052397227095019434, 0.014413172461753412, 0.032468150715313615, 0.03918972572371845, 0.06265519419685006, 0.024047218405851917, 0.02469391727279271, 0.10387266655602764, 0.09871439737898689, 0.07427299034691627, 0.009472142837400879, 0.03718887260484119, 0.08514763907559457, 0.05277280169989794, 0.02641369656269108, 0.0539081440036816, 0.029080768468819802, 0.02431616314776963, 0.06684309427416132, 0.057803459780951666, 0.01473655062352097, 0.02648986676978248, 0.03540207594332676, 0.0245094662832637, 0.024570027448897882, 0.06052126394464605, 0.0375769765777213, 0.06187918926438978, 0.025937777846270514, 0.015095939705779236, 0.05015001542145207, 0.044263621807218566, 0.03903094634053208, 0.04882492846058262, 0.024258359898662856, 0.08787056070662315, 0.016854122025711883, 0.07398181564865575, 0.05798341383436515, 0.02773715941716106, 0.11370620945648802, 0.05233198321694809, 0.008249887858607597, 0.024715702898139437, 0.030087655064679926, 0.0355586298410931, 0.04164203828681381, 0.025040738682653156, 0.03129901244275032, 0.07751856780340595, 0.06018350343971003, 0.019893275175784386, 0.050708700361992085, 0.08605716164193808, 0.03413994608807468, 0.04083055582258009, 0.033189215652284124, 0.018006235909377857, 0.04847825452264759, 0.05831654716823852, 0.03468345099639508, 0.04745157796048349, 0.03231717010719642, 0.04677485802300996, 0.014049503820828133, 0.013200102877172252, 0.020256797302394144, 0.03284321204128285, 0.08113474029326632, 0.07178060755494141, 0.01640353592172746, 0.019256694415103526, 0.04623029974379367, 0.05470432003118819, 0.013877970988922303, 0.029554000131845958, 0.058796106717519225, 0.023772026216911695, 0.06234126668723841, 0.009627461418389313, 0.013439965006264468, 0.025769100607102437, 0.033549050980758284, 0.06849432018615546, 0.037846585900913325, 0.0252685789769936, 0.03423657275796418, 0.014933364356928056, 0.07435228810795853, 0.03523287010349093, 0.019273810734551762, 0.063983625131509, 0.054239224221917896, 0.03170889629531772, 0.005606592448818828, 0.0386073227010427, 0.1234890296754818, 0.0306479602811798, 0.041093967494464693, 0.05651884141468233, 0.09780279871436859, 0.01439097410653748, 0.07453597300956327, 0.03466128424230603, 0.03544368600893406, 0.050690145712466016, 0.05353277241210303, 0.009258540287133186, 0.057725150273331714, 0.0401481706649065, 0.02765888246827789, 0.03445768105467001, 0.03780985964582332, 0.03876782961249833, 0.04857481990550314, 0.07494717070292081, 0.08940994544255157, 0.08630388791883185, 0.022492165256652142, 0.02356639864193576, 0.014302330072818985, 0.042973943430209355, 0.035566719729573495, 0.055977650091893254, 0.046960691801242294, 0.0656277570693243, 0.004386356111706025, 0.06160114914359105, 0.09524790314777244, 0.07647993643918345, 0.08046678057120693, 0.024846276839173613, 0.03665909982256351, 0.011275204503157688, 0.1003698980615985, 0.022192703402270714, 0.0232925949873583, 0.013624770311458458, 0.02947889670218912, 0.04752976106359594, 0.05043704941448185, 0.02076073185420565, 0.07774647130000015, 0.04079683646259289, 0.062425907911552544, 0.011711248343119459, 0.028155207851781484, 0.04909870913252235, 0.016663959850707365, 0.05940631490140673, 0.0854329072359589, 0.040261597642975475, 0.011704496235676832, 0.025972686557760163, 0.035533444700582374, 0.028681456629607468, 0.0185334078231526, 0.0503882342919467, 0.14105797685202093, 0.11481581120601586, 0.10204689517136543, 0.12092445075752274, 0.07573200479870842, 0.1353030171125166, 0.10735079000193266, 0.10116583277140895, 0.0834117527870882, 0.1557721203613666, 0.3466661851252279, 0.12646470669536822, 0.14400015284697856, 0.10599762591863833, 0.20798779994009003, 0.1131112119483371, 0.1750032561680963, 0.06962121254013431, 0.1512683813850726, 0.09710958107344567, 0.1447113275888466, 0.1430232375259361, 0.12830691832688548, 0.14564396302786567, 0.10678239106651276, 0.14045780825038112, 0.12461722437893191, 0.12193883543894177, 0.16678173846054464, 0.10439905322967999, 0.1901369860335704, 0.1440602907490346, 0.11135490175576941, 0.0928485693950807, 0.14194175120322935, 0.11463868401704297, 0.12023581432238703, 0.09667265814759078, 0.09322892438860671, 0.11922310737352218, 0.1352295492805781, 0.12368947658086978, 0.19838038321223952, 0.1691428674084525, 0.14284935088888293, 0.1563829375851539, 0.09879177992021847, 0.1636868658205194, 0.11599055341174526, 0.14510414683290068, 0.16284813743925866, 0.1367757292163949, 0.13748690395826293, 0.2593283926046664, 0.11458212374559335, 0.1577049908378432, 0.22141421093575417, 0.12642034254367315, 0.28553855875807427, 0.1732285062391912, 0.18545081087898824, 0.17351879227545955, 0.15589340740153868, 0.13081777149871474, 0.1002553372734016, 0.12140427460713733, 0.2037640354566036, 0.09021510385097035, 0.1833545338482626, 0.15788198779186896, 0.20801395418182497, 0.16246423545864322, 0.12485009978615469, 0.12494668049076874, 0.2038504654962209, 0.18806370696233166, 0.1210743511816667, 0.15854756498048383, 0.10501279690933805, 0.11426174577565924, 0.09914508434913813, 0.1264862873921952, 0.10950240156342907, 0.09754252034209429, 0.15757677836283562, 0.17707874157255699, 0.1998472730478933, 0.13615363517836218, 0.13553751662613886, 0.1009364354033624, 0.14457490265129075, 0.16709391928968892, 0.1450173490710797, 0.08041522285390286, 0.18364445216232733, 0.16972705541599184, 0.12493015597424201, 0.0693950787066452, 0.09158339817076923, 0.2310449473800198, 0.1585599449613402, 0.23056425785105075, 0.12427485202469173, 0.14146286964176163, 0.11591481029867165, 0.16732553831271588, 0.2447685545250293, 0.1071459457518593, 0.0816098910065428, 0.17604190285407728, 0.20384268204291023, 0.09209646257541834, 0.1244624822791065, 0.08740151571410318, 0.29110850826386486, 0.13363748067809691, 0.15832564463057827, 0.2350057904878932, 0.1483040041620693, 0.11379449342888211, 0.14401038778164696, 0.14998362129253728, 0.15644518988988093, 0.1459398261842228, 0.1378954892917987, 0.10983890568416928, 0.12726524559360358, 0.11369667932270996, 0.16150912299992579, 0.1906599942594767, 0.1505894129795413, 0.15320001079911186, 0.13192144372770864, 0.17664873642065834, 0.11777778291293692, 0.18114222514052547, 0.08480266202241184, 0.11298113021879427, 0.12148430015170768, 0.1460816290590071, 0.14656487732164322, 0.12689195393073943, 0.1832551109574495, 0.11278069863516478, 0.12758398413537972, 0.14452685361667988, 0.19504068419337275, 0.17267385858201212, 0.23184671967981324, 0.14737107760963902, 0.12983829744400519, 0.08507656909885906, 0.34130764524302176, 0.15271029675439482, 0.13314563690895034, 0.08517711047804163, 0.11602087517178829, 0.09807420834418266, 0.19783673657765313, 0.14370606701460578, 0.16711080386754007, 0.12117108510386561, 0.08373969204483495, 0.16415543583852632, 0.12503163964157143, 0.11392184022453525, 0.2128028004400192, 0.15798059862948235, 0.17791756188436864, 0.1405340493206055, 0.14074769592092884, 0.1182971598820821, 0.16901824022493056, 0.13750119915893003, 0.19048318116655275, 0.12189172103159851], [0.038842565319951505, 0.022826058932790355, 0.012771414438893479, 0.026383395870065978, 0.02881527303778116, 0.016352773020644824, 0.09141082920494581, 0.08273090746614241, 0.043376798426071485, 0.02925087829240628, 0.04917457865010347, 0.02279414370986483, 0.024021069909776413, 0.07333450965703496, 0.04186508478596807, 0.03818902337262708, 0.11332153372706906, 0.027789567492061087, 0.029741720401591835, 0.03214921682111679, 0.013785612386380954, 0.04571868324532144, 0.05184312336026661, 0.0341514220851804, 0.046851773250607714, 0.03567001902528348, 0.026525227473147457, 0.04993592832057227, 0.039100468819660526, 0.07960479376056502, 0.03593566384346735, 0.02131397182482385, 0.06614881177102366, 0.031056482412461794, 0.024155926282307314, 0.04302940053504802, 0.04297092121334807, 0.036895422625445554, 0.04004942576190637, 0.045974686846978245, 0.08770480226244658, 0.01975826558566863, 0.006735744283369352, 0.03414152805963832, 0.010071152731055215, 0.04856966796421236, 0.11853716756787994, 0.03737271838491002, 0.06744578330507202, 0.048257613539575576, 0.06558579077283222, 0.030902736226937948, 0.09003565541558689, 0.035429237590682124, 0.015183493021815537, 0.03256452840662772, 0.023796251832297253, 0.06804463423548207, 0.07216696101691454, 0.04859633931529619, 0.07772599376978413, 0.03421822495217766, 0.035466764407653006, 0.023195830421642433, 0.058413104890214826, 0.06056594219239009, 0.037351899945567694, 0.021327152367561095, 0.07262065360743193, 0.07306667765782726, 0.05749171562192421, 0.03846126037739939, 0.03229721351676891, 0.05009904376141006, 0.020692025258716558, 0.06296608033740232, 0.07707502587788528, 0.0210676247614526, 0.09230645493634286, 0.014113238505688647, 0.029988123006337596, 0.060278517494518916, 0.046151166691655116, 0.06264228944576557, 0.034103851855522206, 0.018901036181036505, 0.020208336495523973, 0.07231322252341817, 0.0638416115825455, 0.02696480106322035, 0.04166153139404712, 0.06419829445921126, 0.06082147848041308, 0.019077906730554758, 0.05338765237660659, 0.08558615546433196, 0.0281587012127162, 0.07910471454623245, 0.061957276606511694, 0.057719979179842826, 0.03698576737435595, 0.03286202333026356, 0.05934373317887226, 0.03964923675202074, 0.01929175442895822, 0.09014843887979947, 0.051112428698087894, 0.022815592256524873, 0.11469954970262705, 0.06405032457663648, 0.016960876377960368, 0.03730417266788502, 0.010636622337774645, 0.08382957714099078, 0.027546497369785945, 0.05447129523682018, 0.012704644130633004, 0.08365802707210665, 0.08248727618446274, 0.03748542907076978, 0.02306346191964563, 0.03453355823313037, 0.031073366990312937, 0.09568598286639299, 0.03233731438916537, 0.015381730721151878, 0.023097830539148663, 0.058295824489886724, 0.04277582160167156, 0.16590490486593018, 0.017200960672550628, 0.08567892871196232, 0.040671132925537326, 0.0419757308648719, 0.026906202997892138, 0.03270320181224135, 0.005886731171725138, 0.023114044790066058, 0.04743578122748483, 0.10001624123223367, 0.015497432980355958, 0.05091642127222112, 0.029688645830197685, 0.059585391784146916, 0.021749546435932, 0.07580551859592238, 0.10109730620658207, 0.06284884590234968, 0.02418199242393096, 0.006182428661568632, 0.03664559369245845, 0.08946930959580407, 0.015282846007105565, 0.06475732796975682, 0.06796968019297046, 0.03385373180912387, 0.027693138089812094, 0.03047535684139979, 0.06256723198138418, 0.01838269151536928, 0.023681045615024144, 0.05324312222881183, 0.0655443913814041, 0.08126984755959242, 0.05114715546369553, 0.07729629505305521, 0.043926608238008716, 0.05438738179603412, 0.029685217586736527, 0.012194658441829586, 0.06951612825956076, 0.037311006172169606, 0.06197786521947673, 0.03897955333213172, 0.07612698441070896, 0.047731142596251545, 0.036066224377962856, 0.0301330381133143, 0.04651316238807575, 0.010807534638461808, 0.038625846707051804, 0.0020862836531558705, 0.12948304715175785, 0.028947593659282695, 0.01765359223129288, 0.045763219766799486, 0.0170240058533607, 0.06462524675073163, 0.023443845641468803, 0.03387497542726417, 0.032819218167494384, 0.06632076786650766, 0.05240644696318815, 0.02169764780950162, 0.012206121032396633, 0.06053532548849622, 0.061275619232366164, 0.04240478989818404, 0.05293846438308397, 0.05597091617903883, 0.03944983172620978, 0.016301121457570022, 0.049694587641786185, 0.04301102591618415, 0.06526652363038833, 0.061767378731841044, 0.0498544127349892, 0.045070454117751894, 0.042678382878582326, 0.025147676896003467, 0.07026088063515003, 0.0696069633047427, 0.0233071640644583, 0.05898769381606291, 0.14390457571754534, 0.06688632461572848, 0.026960892099586707, 0.04403878266232149, 0.0466939706295248, 0.06557528004651109, 0.11086651304316138, 0.06083039957429133, 0.07950030702857241, 0.06641157992905186, 0.02444887638933236, 0.025345206921619755, 0.024575089374857566, 0.037012136120709686, 0.048958580159852584, 0.05999083615719311, 0.014798168032880754, 0.06523851545587664, 0.039619501049239794, 0.055415360707669496, 0.07857198466456707, 0.07588555946225121, 0.026522768330910516, 0.02995673063842039, 0.06333136638145774, 0.03624108777711949, 0.011056882851276428, 0.06541229484062042, 0.008904485092047722, 0.019055630808936495, 0.022093856992620616, 0.0014721289194459398, 0.043775037742189826, 0.02903684673290099, 0.02505507027249663, 0.035107618558310696, 0.020563843427225947, 0.0339708743136256, 0.06057546083484927, 0.051869185671450636, 0.048729090861255125, 0.041753151679351445, 0.052261204353623816, 0.032849628027648695, 0.047679929618513396, 0.060034035855243285, 0.05532586631635505, 0.017133575578730915, 0.017196950202267018, 0.04818270929277905, 0.014755563968191705, 0.015761147256970646, 0.014702385974927776, 0.06694856159869703, 0.04770017349191251, 0.06988298478386096, 0.009923225940926182, 0.04682707457592891, 0.0377393221001952, 0.014141838483121848, 0.04927557202116136, 0.06920770126124544, 0.025814849462720658, 0.01687926886182639, 0.05148626045293866, 0.0383845558239808, 0.017347823558074814, 0.04616121393478206, 0.012763759305310107, 0.022839614858610496, 0.010928404160715159, 0.07781165006059794, 0.025330812129522526, 0.02961839173710154, 0.009215359741281117, 0.03314913010164615, 0.025445803842176835, 0.020412544892620177, 0.015697680702883632, 0.02667951183543811, 0.04771017476976399, 0.0044277215079825015, 0.01623324223703915, 0.08558140571920142, 0.03865403874266533, 0.017141276677589745, 0.015216697187673663, 0.0073495482924514485, 0.04388632733495005, 0.06338983804227845, 0.07737394572506029, 0.08391929369780325, 0.04077455479531519, 0.021867583348085324, 0.049329596541581616, 0.008037917075618621, 0.019009912596835245, 0.08880869665693852, 0.051898036542679035, 0.06480851030397801, 0.09364394486070642, 0.08599654110448976, 0.026981281529691432, 0.018597697921758218, 0.034086886838439016, 0.022577695142958435, 0.02140044399927701, 0.09022323204384697, 0.032314477308142575, 0.06495473350608541, 0.030802662161389188, 0.03960856131368107, 0.005085788640914666, 0.06487018038188258, 0.0400429523189462, 0.04345782371538301, 0.05237346687804788, 0.01135097825974827, 0.015543380061224585, 0.0747492978529584, 0.09258885792787037, 0.14019773672184638, 0.010064248363637637, 0.051077403158189795, 0.019589345113584594, 0.036097312225930156, 0.04287989081574544, 0.10759280483809211, 0.1003363587322735, 0.05314926879720823, 0.024969044344259367, 0.06668290528919428, 0.0034434139172756866, 0.022215756903132124, 0.02297570271747968, 0.017339201238487038, 0.04683785343302354, 0.025312062127575762, 0.07998074374852643, 0.27079060012775086, 0.18424883424755067, 0.12258201987752992, 0.24064104132834943, 0.09210192478231846, 0.2249155238631272, 0.20148886157379997, 0.14005260902547068, 0.15896062426749738, 0.10163631800922657, 0.24768195625755096, 0.07815986766570038, 0.1496470482238839, 0.12306483147004921, 0.16544296916934753, 0.20591881096122727, 0.08953542298366947, 0.08053752113013499, 0.16299796891548943, 0.1093516584425684, 0.09783214754274777, 0.1850048404547476, 0.15717597648261056, 0.1064288568112158, 0.14607974448271338, 0.18804636273172595, 0.1422662507261961, 0.16063941402300713, 0.26232155941186414, 0.136865055068366, 0.11147690125771108, 0.16160944987448955, 0.13511492720534726, 0.09324338046773788, 0.1289292115477785, 0.09374971095953258, 0.2162631276634432, 0.22271138165266285, 0.12069827861963742, 0.12768401223565304, 0.06902632994517204, 0.16395193224232044, 0.13757981510171968, 0.20645750866782284, 0.17617109592162794, 0.14510246143946726, 0.1308407081711677, 0.15708868842451804, 0.08365140807244086, 0.1826366328544194, 0.25965915872685374, 0.221589001556558, 0.16931255588368063, 0.0999777146705216, 0.1457172623204608, 0.11441930707904602, 0.20263430091642565, 0.14972635364580542, 0.11988197363192037, 0.11121231747130234, 0.14005633221278269, 0.23888818619232025, 0.1775043953450457, 0.12265623847563421, 0.21290973099249028, 0.11087445737493616, 0.11052309114846492, 0.20424844817288462, 0.20311978615580067, 0.13976673565564618, 0.14822995410330836, 0.160415425235706, 0.11679770364876717, 0.1494381513686911, 0.3042934943110712, 0.16604163623865575, 0.07773809795898777, 0.1531717727982229, 0.1250245609891511, 0.2267621328393298, 0.13705289982739957, 0.1870901011411221, 0.13482245015761546, 0.10173724243237127, 0.147668702768222, 0.1659885769890201, 0.2563415077184477, 0.14151310968783595, 0.08214193140907634, 0.09801696625448043, 0.24424551565560604, 0.11456431220135382, 0.1353988393900856, 0.09050073207265909, 0.14756843718069215, 0.10964904611389484, 0.15802509301612455, 0.15588899473509482, 0.19022583691102846, 0.14926101651883897, 0.1304387724808147, 0.1457046218697102, 0.09842358274205078, 0.14651875882860155, 0.11345078042077442, 0.0858704966583079, 0.08394569308767397, 0.17888061101398162, 0.3543078815264087, 0.12896854250181106, 0.1535332437244154, 0.052641007763844345, 0.1470009192463852, 0.2587206397325762, 0.12703955609111056, 0.1107545186495108, 0.16258947551250458, 0.12815174721782246, 0.2135922846895072, 0.12946565695587667, 0.17113881756461438, 0.18490779243649977, 0.17710952298535457, 0.12080196095930955, 0.12057097778925974, 0.16444924587924636, 0.10852973036948713, 0.15645614494719814, 0.22210980344924236, 0.18542199065127682, 0.20401754927250648, 0.16834500215707288, 0.09384325795596647, 0.11710246874680443, 0.19805799809194383, 0.13749119405063892, 0.11951710127534405, 0.2197793180183057, 0.24496173125601586, 0.09916373092921511, 0.13691537172323273, 0.10978299658745529, 0.17666847084558782, 0.09179271637432038, 0.16681708575737092, 0.1630483315356316, 0.1342611835007706, 0.14991825867083766, 0.05334272898072678, 0.12380788313044656, 0.17907155076822928, 0.17208597803067777, 0.14525768617468496, 0.10399430599664489, 0.10197912703358358, 0.1793185528367758, 0.2576194343066985, 0.30127280962563335, 0.18910786948136746, 0.10154106263672152, 0.1756041908576604, 0.1795065814569112, 0.09940321767522443, 0.12764357045413027, 0.19551587321104544, 0.153627349965034, 0.17633306223057932, 0.20459905597231082, 0.08769604587747205, 0.20950594105787818, 0.07986155578926687, 0.11500659774267867, 0.09385710882563746, 0.1357035432010889, 0.14589853404510408], [0.03405836538501805, 0.022082635719749718, 0.015268999925484101, 0.02882712441796978, 0.046248842902000875, 0.06395141879517226, 0.06094587966799737, 0.03231353501999571, 0.0670068302462178, 0.043972198130382646, 0.03762730472390691, 0.022798062249597524, 0.030055854754943042, 0.07086375352716254, 0.0532544986344874, 0.02825803217297841, 0.00762335529866358, 0.011555589810614626, 0.02026129040807005, 0.014925725502713073, 0.04006572428249544, 0.01706685698140533, 0.031132143171083544, 0.009391557091035911, 0.016893830278047153, 0.05351091209318369, 0.021448632844934062, 0.05544334206910384, 0.04744643368007195, 0.030915190901366935, 0.03539397073308787, 0.06486312471209996, 0.082232000366334, 0.07608740064766138, 0.040623194973675475, 0.04960882792910261, 0.05590990876718875, 0.017602553538557504, 0.032247348853777495, 0.024893316552944245, 0.02427860377206197, 0.0918434773601832, 0.032285975006919716, 0.04835752289622061, 0.034705824594223694, 0.043580233074364164, 0.05882686897811871, 0.014896822920549783, 0.01981104138277231, 0.13833292549656284, 0.033662137049700946, 0.006013503880240024, 0.007872081065039721, 0.020347174610041326, 0.037129619534337716, 0.04384756711642108, 0.07166585524476345, 0.044215205050404036, 0.023128181027488846, 0.03327313675394943, 0.029081157258441372, 0.07573726782274824, 0.04761175162369206, 0.05205456745780764, 0.029546645687772866, 0.014852134139096786, 0.045803351282712915, 0.0734098467435087, 0.05982981596682822, 0.028763113941456524, 0.02521812825674011, 0.032524948474019766, 0.022332257808997266, 0.04578801803290845, 0.05863168509677053, 0.06004644264917701, 0.05753307670895612, 0.03871906045523863, 0.01266725233665878, 0.059706142562772, 0.07471504606186383, 0.017747788487242597, 0.057755483524693604, 0.02703931268995568, 0.028215087199163054, 0.0182182009467074, 0.06531574477952334, 0.03245349162288251, 0.017989969947525573, 0.04165498900317377, 0.02819179812626493, 0.09064883219018098, 0.008391909068450332, 0.09465000216638851, 0.06585955229257384, 0.004566453327800358, 0.06545102824607203, 0.012059500422178498, 0.06102638784796, 0.07176617445844798, 0.024648700848281867, 0.02922863875996442, 0.027656888724454952, 0.025501226473058906, 0.04526619341284518, 0.03152545654184876, 0.005464660775502243, 0.01752410421989137, 0.009207740039264244, 0.0078921219251389, 0.07198784199933853, 0.031104284383717085, 0.0038131109519576236, 0.0588318255669888, 0.022718549983936454, 0.054469870313281016, 0.028772128881105495, 0.04929239531197856, 0.03062332672397456, 0.0512147665534529, 0.04983715277405516, 0.05989596382865022, 0.03607037657451245, 0.016750905084453763, 0.03057648619306424, 0.05842882118398144, 0.04910113763124232, 0.03993339791533448, 0.006066194928867082, 0.07264866944282286, 0.029198860922347636, 0.006328307602915072, 0.019030531853317253, 0.02881871468778099, 0.0819443726551629, 0.06901749695140509, 0.0826075213450578, 0.027175017504862724, 0.03243107972065768, 0.038062396699622754, 0.025070704211811387, 0.033505709556442116, 0.009818427985714329, 0.019384776655163978, 0.011189873799711708, 0.02826497676001201, 0.02089436631649733, 0.01832390767371943, 0.019026251337040338, 0.04680212692267472, 0.03961854726977406, 0.06380288966841276, 0.007136376187836211, 0.042182651213220054, 0.02591080963611603, 0.031217604109476653, 0.04594682805961178, 0.02657074075672896, 0.03635893891295118, 0.026200216586491274, 0.04162606152315294, 0.04828370649427657, 0.0211607082746923, 0.03213273060898627, 0.01534494509424774, 0.02969509054486069, 0.04604652291163803, 0.03254482462521523, 0.033290197532023155, 0.034334413677213654, 0.021949095103228768, 0.045463641084009604, 0.021705059710169033, 0.08276377263809405, 0.03778165228845131, 0.012061447243116075, 0.03741102661156366, 0.04542795670849662, 0.004888208340778346, 0.03526001642908781, 0.015181212952630896, 0.03564191892022087, 0.04410760417099922, 0.09799545450556664, 0.019736872580383095, 0.04915249616568608, 0.031222581765764666, 0.08180708203825258, 0.08551879335314998, 0.13378302206195172, 0.10177828176247497, 0.07185496404887208, 0.04765852895234862, 0.035735373986103845, 0.021110519939552874, 0.07504058746440757, 0.01671153582602499, 0.026751361306636568, 0.032320923938025395, 0.05111786026147105, 0.04510162240495125, 0.0414891233066878, 0.08478519521773824, 0.007319498014816594, 0.07262040079841692, 0.02912889028178348, 0.03306392580270767, 0.04558942889073684, 0.08975659256740924, 0.10255897132259223, 0.045829700876868544, 0.09368237949186757, 0.0589092655648147, 0.12758549332859057, 0.04252103607981436, 0.07123706051178517, 0.025559125483156215, 0.044575162952946085, 0.010798116545042685, 0.018508322274072037, 0.02007101906553632, 0.06605561717503494, 0.10577464070651801, 0.04934983658454111, 0.0341525137604725, 0.03231806643006783, 0.07897411187690112, 0.03529028456297613, 0.026051245043955507, 0.07302451983935411, 0.02395709199199994, 0.006352932541631163, 0.020197605518924616, 0.04638028060716968, 0.017174055664649895, 0.06057619627925658, 0.029521410751547066, 0.058023687076544574, 0.03692381001347977, 0.03192556894294197, 0.053064405407396056, 0.040801628342559265, 0.07580189500004053, 0.04138095552221902, 0.0523588843944092, 0.025831040731000326, 0.033535529528894735, 0.023832244558199763, 0.05620519352716304, 0.019069242276131146, 0.02020600375779454, 0.0021081887403382894, 0.011706872065852006, 0.054943285837409, 0.06854321957836229, 0.05732969568681814, 0.0420946047280825, 0.018991139612250754, 0.03255897043873707, 0.011235695433682732, 0.02848394958662891, 0.04143445527241115, 0.005119536250394079, 0.02308613046132509, 0.01100687837723883, 0.06666936851557224, 0.06822353874843928, 0.023954868421799714, 0.021275307367285414, 0.041199626340981454, 0.04315823737171389, 0.02881232359927268, 0.03749149265669046, 0.04137751195699938, 0.07951621101388047, 0.020285801391207406, 0.015441870538427707, 0.015197144708626214, 0.03156343535069497, 0.02173808193014514, 0.08040462019703082, 0.010699886836171632, 0.07455720130594508, 0.0363704685362116, 0.032550290662554965, 0.049391461971906886, 0.05584803950642386, 0.07982525854341446, 0.022955500978916403, 0.14150054584587776, 0.0452864755906405, 0.03247520638509624, 0.01434659080264429, 0.01084826561817599, 0.025590019893922636, 0.09932970387801048, 0.019677110061409975, 0.0395476994585366, 0.09698019648391394, 0.006993762217462064, 0.013984314526521392, 0.0025252082231154126, 0.028117081571009853, 0.018138453109009613, 0.029334096508401058, 0.056242613091824524, 0.08393708225940505, 0.03237825412783892, 0.017792303941302726, 0.05380332785388155, 0.006200267976495408, 0.02404651935062101, 0.030067392039082708, 0.052795428106741565, 0.003640041874361135, 0.022977439821847988, 0.09294881199997279, 0.020558365898567344, 0.0030024237827503035, 0.013260591264453628, 0.026067792543119965, 0.08178565455901046, 0.05977408307033682, 0.06630448083723746, 0.013622124435289974, 0.0636516294382032, 0.006599612853249476, 0.04666337307782904, 0.044918098381810614, 0.018023361804925146, 0.024124238970539263, 0.05561952696992986, 0.03465009935861153, 0.01572923682209465, 0.011480515109254949, 0.02768165826226675, 0.05553536455056841, 0.03280137214929827, 0.010380698217739983, 0.036720946100690675, 0.039992831016500155, 0.008967735226296129, 0.046301258637780146, 0.01254628322297527, 0.02363533314858233, 0.01918665482662618, 0.09691776031808508, 0.03546476874861025, 0.04017697174041983, 0.0360938303563143, 0.08369710521712419, 0.022018221131856405, 0.1483988611688537, 0.19626604182825935, 0.10509195677455395, 0.17576318474546557, 0.1675948948268929, 0.12923583057859253, 0.11683266024075209, 0.15873162526517146, 0.13965409008725999, 0.23292413041476281, 0.11831690196789081, 0.28819023421214474, 0.14709664959340327, 0.17592345033922505, 0.15891522589710452, 0.1464267210253785, 0.08908460322286814, 0.12086551561350785, 0.09894076869973252, 0.163178903561446, 0.11772116135445335, 0.14829913184287088, 0.13130632108978688, 0.16745704496579786, 0.10849949287911577, 0.1199912790569567, 0.2132907678042689, 0.13680215924978256, 0.17218311797947655, 0.19497532157167313, 0.12493119785381902, 0.16587597738590934, 0.25358273317256286, 0.11365934785815979, 0.11593826791091312, 0.18750772631216436, 0.20746031776070598, 0.20085437223315242, 0.12513666263511106, 0.16229194228447255, 0.1628649913735928, 0.1405982474886602, 0.10314326658244095, 0.1082381419837475, 0.11513269581501523, 0.10346195915894163, 0.1835959434749619, 0.12289191010378062, 0.13809240453185576, 0.26659234637214296, 0.1823274244464213, 0.06218322657889897, 0.12399099346610809, 0.15518040937041083, 0.13007334854093291, 0.09816820733249189, 0.09463175395203215, 0.15097731393912148, 0.11004015698187775, 0.13666306832625022, 0.1273946991310485, 0.24830887664950665, 0.1283449009661713, 0.16213510876461384, 0.1024578630383457, 0.0990611057908785, 0.15196498513462084, 0.25438278943540593, 0.11670735123897753, 0.1225472777901638, 0.10143157335058336, 0.08470168397311242, 0.12059590629031583, 0.11424095414939428, 0.2128434797087985, 0.14120059178000496, 0.09873202506212458, 0.15173361125972964, 0.17667786308353947, 0.09997823561031012, 0.14868105731664166, 0.1638337708408794, 0.14122426389686524, 0.08561743483428033, 0.12313412412280038, 0.1406883241067971, 0.16087875521231085, 0.17221264300807831, 0.23624858428393644, 0.2100372843204006, 0.21496114591437004, 0.17399992613542467, 0.10514225044678296, 0.15869872944970287, 0.11979975707588658, 0.16203822928570932, 0.14426483622481748, 0.07390605721382365, 0.09914326872075759, 0.10380021762102844, 0.09585891955442007, 0.15005387155519379, 0.12286441520817819, 0.11753817359285972, 0.2499403834583298, 0.17766328198054146, 0.23052072873519314, 0.15291721710274297, 0.08551163043105796, 0.12478025555009804, 0.17066186654471582, 0.16350950114428997, 0.14136854889652423, 0.24410262493596924, 0.1365945341005441, 0.23399605596017456, 0.19944357535531446, 0.0993922396352695, 0.10862627276970495, 0.16450089552710134, 0.12093225719347117, 0.1592197611687645, 0.19421448901055322, 0.11736555100088158, 0.21757670798368994, 0.13759199589971574, 0.11362871966294705, 0.10508795013470996, 0.11426981268150192, 0.13356206698283074, 0.1603010789521279, 0.1420722312984928, 0.1380479407887305, 0.14185904435092403, 0.2565629837373572, 0.16605122765946775, 0.10668102997325121, 0.15402510281532042, 0.08988522639077517, 0.11056279748558037, 0.11050332608001848, 0.1759388027412276, 0.14061706260808055, 0.1158712198957801, 0.167198735439489, 0.12536958400760928, 0.13531061670472547, 0.13457894145000365, 0.1344382570635888, 0.13723944223696186, 0.1847257852674492, 0.15777603783194097, 0.07695846560020601, 0.1714233732632091, 0.0895799556747079, 0.14320843162075167, 0.14719898361832867, 0.15014770200415967, 0.15179676754820734, 0.13921429433168905, 0.13878683259169902, 0.1271563232125294, 0.1415996163362457, 0.09536693788944714, 0.11532771881789931, 0.0961281381727707, 0.20878633934884303, 0.060461210312261704, 0.18069496768857204, 0.11578629904937361, 0.20835276422721727, 0.17166449177649715, 0.09895685654614242, 0.16760805621743205, 0.20932912796495423, 0.15811838720354343], [0.03404097518913689, 0.03423954517911038, 0.012733495001861406, 0.024389793773392038, 0.037862838456226934, 0.03135485642199074, 0.03810694088198004, 0.04206497244717133, 0.03423240140921647, 0.01848073927835832, 0.03172206343151629, 0.04660740652452073, 0.023957415664147948, 0.05456943876079975, 0.023752967864575408, 0.04786170696118667, 0.06956888107402671, 0.02153862327817948, 0.0137495756104228, 0.04655439707060014, 0.011475465632224036, 0.05641384906465969, 0.03068379595905783, 0.0396982855313728, 0.0982262155101184, 0.04266594161069201, 0.0326304043072366, 0.045010752885812716, 0.06418806718542211, 0.032508316705183636, 0.005862875193763044, 0.014381957251668699, 0.06226843853871669, 0.06801865619396971, 0.019052907366365678, 0.015432878581416464, 0.018593074581135186, 0.04576199785656026, 0.04530932416298217, 0.03925290499483386, 0.07576717589531215, 0.026194227694143212, 0.06782698099531474, 0.08002101699070585, 0.031109330987918283, 0.04764648605017893, 0.06333589779152986, 0.067735678636499, 0.02584173340320347, 0.056975594526457216, 0.053428707028468775, 0.07796236253794163, 0.054051873589595484, 0.035751377562842065, 0.026084872473391797, 0.026157715943672007, 0.05502798068787783, 0.013250989309932678, 0.030336823246832338, 0.048625668991477265, 0.023413391731258844, 0.054098938201223655, 0.026808228013255907, 0.03677826479918534, 0.0168681203673083, 0.0568421496709268, 0.0475706318543563, 0.05561426011545043, 0.003947518923650346, 0.0528856196380671, 0.008232169202528894, 0.04721084632159722, 0.09098522905861178, 0.02326309485661407, 0.05861397697440079, 0.06355985210487439, 0.05496212776990668, 0.06351819990443126, 0.026379057897194743, 0.022389446272544807, 0.028952586637329192, 0.021215449087321762, 0.0782085525532884, 0.01150658795414793, 0.04966238513588906, 0.06715574241693943, 0.04177425740166538, 0.026801733502877817, 0.020512053968324777, 0.10031162941407773, 0.07353612867694709, 0.08376675027032053, 0.1180039856943392, 0.04062740845725902, 0.01393313889556955, 0.03708283071436229, 0.025258324890127106, 0.016594033260198853, 0.0345851619157099, 0.04208256182591281, 0.040195430628955364, 0.03979197425407268, 0.0166841903175678, 0.004224006279987554, 0.017685474895481623, 0.06100226756966403, 0.014089082795826179, 0.010311192975589826, 0.054242472434716846, 0.031137796899964734, 0.005389799142346508, 0.01298043674098388, 0.01812421536493686, 0.04658001122034846, 0.030464447749358033, 0.03071496233103737, 0.022355983552012234, 0.01930816786273593, 0.053883832203404564, 0.019656077117448854, 0.028313504599575556, 0.047064600136852076, 0.02920960339026586, 0.05185418566989322, 0.025403714971616868, 0.042392528660955935, 0.020225251716892087, 0.024881128094068942, 0.03030841670660002, 0.10341618540546588, 0.006238180710258143, 0.0357994380887718, 0.01750197193975891, 0.08736163317676514, 0.039550070500662254, 0.07188649622783547, 0.07901087643638735, 0.025523293635717807, 0.036927219104742816, 0.03676254084453948, 0.003620480776824538, 0.03649441390148094, 0.021707193265038154, 0.048501842369836186, 0.02506311611092139, 0.05191989686159838, 0.03988254116848111, 0.025621435244477568, 0.03630928109369932, 0.005592555324021246, 0.03762782949413504, 0.012832885333937744, 0.013704508573057191, 0.020760025138095505, 0.02328721896534966, 0.024507035869323922, 0.01564986245225995, 0.047938158705590234, 0.06748147534146424, 0.0291956510139449, 0.06266374373808503, 0.0416958904374511, 0.05584451550197217, 0.0527842662056848, 0.032261965811372764, 0.023093427448803862, 0.03925850126712073, 0.029052486417875178, 0.06626805335643791, 0.026348964048309192, 0.02563318320279641, 0.08095700789483325, 0.03699620532232427, 0.05895571347566382, 0.02178177192446686, 0.022534704203867627, 0.03573227899088975, 0.020828909849026994, 0.009435023004639774, 0.01035221411110533, 0.02576303702118176, 0.07457752561857624, 0.012524176798310253, 0.03016753122210503, 0.051811652468337174, 0.07591194353036343, 0.0455165624378189, 0.06484067833591854, 0.0016406199034874238, 0.04883060900254115, 0.030473269251806122, 0.061371927975767085, 0.017815232952876438, 0.02047583907692423, 0.034119257883679484, 0.06223340916837897, 0.04822520802037851, 0.05663260547143798, 0.023220144137139284, 0.007290952621147998, 0.059948268481680465, 0.028658108184895212, 0.06226570360482701, 0.05112708396007938, 0.01872187502862465, 0.030004157226592786, 0.057061990092117945, 0.04199211748557226, 0.028194282166359406, 0.03760771585568305, 0.012234832092578854, 0.050610779003510555, 0.030465905231633977, 0.04184009499787804, 0.021615316340279196, 0.017578130655531442, 0.04021798042700656, 0.018165882887138475, 0.11752179463303859, 0.02453503255251675, 0.03260996125097717, 0.04138191696256399, 0.02892944886679611, 0.055178543778076294, 0.02738871581612095, 0.05662261568490536, 0.04858737225614248, 0.07490357263915001, 0.03808794573189751, 0.04667857226224677, 0.062250941090526125, 0.04857343711679982, 0.06593425352607044, 0.07693628735479809, 0.008140192686339781, 0.03170066085013171, 0.062571027947049, 0.038498289237219485, 0.039611012795038765, 0.020859459520227486, 0.09056676119085282, 0.010676564246926819, 0.0523111532862869, 0.020668990910053253, 0.007340911608715092, 0.022152928117242073, 0.0535474966220077, 0.019284126108452197, 0.009276011879856308, 0.03703355976951219, 0.035581294552332936, 0.07129794151912774, 0.021078261892281232, 0.020163899565476085, 0.020765872304177573, 0.036507452717952193, 0.04288248019292951, 0.03377285590695758, 0.014959122148162175, 0.044990283016475945, 0.14621561783696377, 0.03801116073924688, 0.05053974350073165, 0.03634380867644664, 0.042196747231026815, 0.026486317867473252, 0.046787628708707715, 0.029246381356290756, 0.007460283429076475, 0.043095544566430395, 0.03768909354543975, 0.03559207340942756, 0.04620181659476892, 0.0415602277573799, 0.019804606244208354, 0.029824873500113046, 0.06884427681084603, 0.044034791344235984, 0.034057970849737045, 0.023975315308498762, 0.06899104393537968, 0.007787059190788217, 0.0571659826973994, 0.043771977220932325, 0.03748282820226685, 0.016776722247502016, 0.03326472510854083, 0.04825094091375509, 0.024000751342804685, 0.01495428717575006, 0.008691176528020973, 0.07406904241971432, 0.042114362135649695, 0.026448421413078908, 0.031224523798652717, 0.03399556915786478, 0.021294486378469778, 0.0524744832317435, 0.04108768174304597, 0.02053702077377708, 0.04550501749279999, 0.037047544704569925, 0.008235521794807526, 0.029029130312283675, 0.03039304069393585, 0.030427219706677625, 0.075373659511247, 0.0342152984963069, 0.013393843640393067, 0.09564075303534347, 0.035469767472316185, 0.03402029081518131, 0.027186033849213875, 0.01055226648121231, 0.031258777504967104, 0.0554950223604758, 0.015366340972362988, 0.011426050088278229, 0.10024997465793165, 0.007767769575659787, 0.008902597642924276, 0.04198583939503278, 0.03878358421066115, 0.019857573563293106, 0.018635787813353445, 0.03840782957512044, 0.031966673390519236, 0.043742440701011694, 0.026599199007896167, 0.024456625368686456, 0.014404446720295857, 0.025791592948559313, 0.0025070093256691775, 0.035970693213805076, 0.03218600819368036, 0.07553030150912463, 0.038431651079125946, 0.06191428758264069, 0.0335135274837094, 0.02263320970439142, 0.011193861287357587, 0.087898132211018, 0.027837606950572906, 0.04591766309233443, 0.03639283064272135, 0.03764139691127404, 0.033004871915064515, 0.04770737088796112, 0.0392585510628358, 0.023208183589421456, 0.03325603001060025, 0.04010970155978876, 0.1940295707073904, 0.06933035959880199, 0.05942139151175657, 0.07627073314882095, 0.08765479204274955, 0.08245605044066906, 0.08171019489846884, 0.1016590708205777, 0.0867626060461325, 0.15610320824048213, 0.18933669994435004, 0.14961294198949493, 0.11768738453787182, 0.11953146542392432, 0.1008909757459356, 0.17406469120854334, 0.1528504448792627, 0.11346659247553158, 0.15507252886891365, 0.1376462349247548, 0.19066716484244794, 0.14214611281791042, 0.10971388779580594, 0.10688051160785461, 0.16689139628602614, 0.14575176692057043, 0.17289320487649212, 0.1568411041291491, 0.18756617882078697, 0.17472141242075354, 0.12591211215382622, 0.18498099979854402, 0.15287105264442583, 0.1235507227360241, 0.09088040524793249, 0.12765255666548206, 0.08853387027498215, 0.16992865911414548, 0.16012228935235934, 0.14202312506254644, 0.2323410149303175, 0.08234712805959486, 0.20458739611410326, 0.14514081180095673, 0.17891240366283925, 0.09019891641313031, 0.166269761900748, 0.11905168753958519, 0.13753941162459313, 0.23740827286195373, 0.12408076364907528, 0.1776564331544984, 0.11577213408365367, 0.07885288612376298, 0.17847049350459732, 0.09669098297073957, 0.21567415926725636, 0.25609510319848217, 0.13848876310212, 0.1865022665550632, 0.1970912410967773, 0.11315418182001, 0.10460287858281406, 0.10025271725270057, 0.21303765235408662, 0.13474581072167044, 0.18440177604075403, 0.16208941928080975, 0.08791646469504603, 0.12719946162354562, 0.15309055215649067, 0.12348087083908821, 0.20545301418150627, 0.06747463417630042, 0.12185114135424938, 0.28298696503043175, 0.12501619530901795, 0.13029169892111134, 0.10268994937500647, 0.0952005742358104, 0.16454154415236366, 0.07689339409191763, 0.11626571687238833, 0.12372617985332206, 0.23517034617402863, 0.13721956991620604, 0.11265790240178186, 0.14725074051849305, 0.17981079497164298, 0.16074544059172755, 0.1047959633832497, 0.18967944768167314, 0.24608265578506455, 0.17282627943542697, 0.10975597666636591, 0.28050294025771083, 0.13754186310595082, 0.07523908084558864, 0.0637318809787112, 0.13604419185749947, 0.09963897357304251, 0.14527172090545779, 0.184111689187346, 0.20351131837214195, 0.1469414095364271, 0.15587396409002044, 0.21498772916534256, 0.12911390002456405, 0.11646466224544472, 0.16077499626384628, 0.15867098174508543, 0.08155518466786993, 0.1242018974716625, 0.1236733351083052, 0.11294600508746602, 0.18780931980619509, 0.15597072099485706, 0.2114214213384736, 0.14374251747804304, 0.07971275853173387, 0.18432150534804792, 0.11511859979720847, 0.11261199075247973, 0.10570460494848029, 0.1402668072090995, 0.12444748993842833, 0.061073100059143, 0.12706866743223322, 0.09879976255638946, 0.14880444343772628, 0.19714164968219497, 0.16079799422333318, 0.11010980203507409, 0.185763037673408, 0.1535209863176269, 0.1380109080984708, 0.1667566414201452, 0.09319999690858588, 0.1400867459033766, 0.21981556929888266, 0.05139826376351619, 0.19240854398137142, 0.12328309758055596, 0.14063056107730637, 0.12743293457934934, 0.2025501231753057, 0.08997846695203936, 0.13035448748738537, 0.19682522472595015, 0.16514160550169407, 0.1269975591511015, 0.14839211959512005, 0.09922317935213928, 0.10772347645533663, 0.09989686175099305, 0.1075144493651967, 0.08007320290010783, 0.06761019343450185, 0.08781062198742744, 0.16040062441700892, 0.3298758973758067, 0.22378727553352235, 0.19261710375787752, 0.18990398805227973, 0.1217528905779604, 0.16874657012522223, 0.19210186366352344, 0.13239715368516985, 0.1789109940610586, 0.14761627171068423, 0.160793949279093, 0.1810171995912829, 0.07810939779324878, 0.15969608399656512, 0.13428624989765306, 0.10269970167428256], [0.03327912373107768, 0.018675980616300818, 0.024572113123271736, 0.09567743332515802, 0.020194514354150143, 0.08839955207921806, 0.07229338084617931, 0.014876320492476227, 0.03946413458775609, 0.029584800696841655, 0.012560986365462023, 0.04242976053407596, 0.019004766401203892, 0.036945084275137034, 0.02547177039237032, 0.015263755096032497, 0.0578163338885192, 0.036465428964865786, 0.029016694790052793, 0.013249648656065186, 0.053030230225093906, 0.08297014140313672, 0.040308417106467875, 0.07560095013750177, 0.03240184963590676, 0.021404619178464337, 0.03218153040976294, 0.07574306710833505, 0.04256558026217165, 0.00837201759549639, 0.015979193117199166, 0.0078046370782108325, 0.04335891793391878, 0.03328947357893471, 0.03334041076502012, 0.02037706927606656, 0.048180506789996747, 0.016441581763267037, 0.02135163270718148, 0.03584023993161898, 0.04081997614834578, 0.03362269118247974, 0.02424056559140163, 0.02757991412504306, 0.03113690823797257, 0.0831549984192656, 0.024716963112774878, 0.055257297616692326, 0.015426861918381145, 0.027741554846626618, 0.04895684880114371, 0.03475836290407085, 0.039306814602065476, 0.071374588615952, 0.015663495944482426, 0.0314840494895414, 0.03077510406353301, 0.0593420937507143, 0.015966633105680587, 0.03211783977495807, 0.061249365399201075, 0.05270432876122575, 0.05171447804558182, 0.015605076952206512, 0.026747400632068038, 0.024640999749423038, 0.01223428912776252, 0.036330156989635966, 0.046427475453744975, 0.03414641187015561, 0.05880808450221535, 0.0183845741764432, 0.016906558828909072, 0.016464514605280374, 0.07122300279837462, 0.050937362285631324, 0.05223113540259581, 0.05177866472231765, 0.04339658264671603, 0.023649141883417487, 0.044889373915089716, 0.04211197577176556, 0.04407614093994902, 0.02640274150537387, 0.05217744796086223, 0.06005951977004448, 0.027842686113510883, 0.08145401509658945, 0.022899270125274217, 0.02155843048146175, 0.040815184268379406, 0.026721859260672526, 0.03782125903413661, 0.0198746285957074, 0.030831444084704406, 0.06210708893054436, 0.011640981801094548, 0.04732265685414595, 0.014173256706506496, 0.029793871837037227, 0.03603587580484248, 0.07863682634647816, 0.02942035417823542, 0.033551559918710304, 0.033422611999295415, 0.04079007190622149, 0.03320946718656248, 0.06203039203800502, 0.031378275729835994, 0.0504989110143675, 0.05846837047307242, 0.08986433517308005, 0.08094568511531239, 0.06894466497244374, 0.016137975373215253, 0.055386885219523986, 0.06893043871968985, 0.08522924276128893, 0.046680395551506555, 0.007830640496385675, 0.07185507130118148, 0.03500307436972376, 0.0776954192007261, 0.02397848499728547, 0.1020063154940163, 0.02451970887881133, 0.010584935343133347, 0.04662928599563818, 0.032156276321339036, 0.03019962073003333, 0.04312808032057459, 0.034073035968768026, 0.06187168543317145, 0.021051852926311475, 0.013306339162461942, 0.03853824455291033, 0.10821984780411567, 0.02090131090353093, 0.02178507950907994, 0.010848271363835421, 0.04405673976326662, 0.09765262249857189, 0.05174668438191857, 0.053323293330087784, 0.01834021002474812, 0.034513842960399006, 0.034331889417503154, 0.026153805064818552, 0.05417152886248885, 0.0534863589752105, 0.03158176017384375, 0.005875475424897647, 0.0642531042197539, 0.03824157700423272, 0.023832985748266502, 0.04422368947416545, 0.052238643064253756, 0.0163479907167775, 0.028848339307812915, 0.04386652779254702, 0.06799049480187316, 0.029105695054656076, 0.04301610507912213, 0.02393627738309724, 0.024227331422509688, 0.11026575455381987, 0.015918998716158733, 0.03186156612730796, 0.02709864811491101, 0.036665665196074594, 0.04748270411284701, 0.033089949809495485, 0.017700729621273857, 0.06569889599397298, 0.08591832352742072, 0.05239068470414608, 0.03863096800482562, 0.039411764817252275, 0.04184192594801707, 0.04494720589249365, 0.039802461997756076, 0.021804323637737863, 0.024042457169402513, 0.029291379445743178, 0.010962908760824753, 0.08477805527828394, 0.11854384019370041, 0.057014163223005114, 0.0064679256907003305, 0.022840350303017808, 0.0314075919994784, 0.06568318353064599, 0.020719006875409715, 0.034687469127557935, 0.038421465940172636, 0.006709316644006439, 0.015834769264103907, 0.052177677787239515, 0.025347141293628563, 0.08478359409397648, 0.01436684329453255, 0.003294753358556679, 0.024798042028241103, 0.020114868023102323, 0.06946259403541204, 0.029438315109620174, 0.031678199152191805, 0.014008407034130107, 0.056581610828758254, 0.025572897828814965, 0.05546094293916418, 0.053731560737134955, 0.009015170432957671, 0.021690936879284924, 0.026235703694363757, 0.024766910130218155, 0.09317708321877065, 0.01587071985517058, 0.0220708379657158, 0.010820019956407769, 0.022674450132575248, 0.05441912464917668, 0.03821942940234177, 0.041926111350016254, 0.0561180433648969, 0.05525295006772203, 0.07001716508379868, 0.021733452843862678, 0.06193906286611192, 0.042672392071014455, 0.06894210623877664, 0.0563253850616034, 0.0404962350524241, 0.055828956256230036, 0.02392839242313658, 0.029290498444630258, 0.0653252212871467, 0.07490066150503774, 0.020420270889336546, 0.04649672214122069, 0.027642128125373876, 0.03814385865905112, 0.03803221283540611, 0.01807531980316966, 0.04136587125098994, 0.030827937317231012, 0.02477974018773004, 0.022913957946002487, 0.019155254797829736, 0.04880866824438976, 0.05272093371698453, 0.0531755915782865, 0.05080018658190966, 0.014476902358564398, 0.021998643754951416, 0.06933898574882938, 0.013551658710404752, 0.05940247680090609, 0.05251497097854173, 0.006392824176263305, 0.03402022952814737, 0.040884802508498394, 0.03395057681407179, 0.07933037340520852, 0.058409194011361375, 0.042811881360267444, 0.046140920265667865, 0.043125563721743324, 0.022733147789333618, 0.0787004576094689, 0.06118581840588201, 0.023286380099072572, 0.02647008829479737, 0.026065124641923655, 0.04555023583253065, 0.013362224318928296, 0.02073215677462999, 0.00862840328350543, 0.06818947081844653, 0.0792496353988686, 0.008909427316769237, 0.04873421215902894, 0.07030907522646651, 0.00887739526543526, 0.041134056875542294, 0.0132802912154265, 0.07524224478871593, 0.12208159592363144, 0.1003877938755097, 0.03587255735070475, 0.06646437104791403, 0.09809012765124922, 0.05539311734478801, 0.01303237654464019, 0.03337648967581411, 0.025107924593612555, 0.03330807036329662, 0.0850741406001391, 0.07973580245649622, 0.038409277481297334, 0.0526828246731912, 0.039494061812518105, 0.047463276123087254, 0.05168587232248918, 0.12659958413531705, 0.06665125819704225, 0.032772517447630246, 0.0186287283131312, 0.03745444081423264, 0.03183697087449893, 0.057556863739005024, 0.0648276241976888, 0.11835938154329216, 0.05613963172260312, 0.0430377010977076, 0.04901507148338903, 0.05122845271422018, 0.13429544295274443, 0.026289596064617077, 0.02796137994605928, 0.02153731326782896, 0.08823472826230912, 0.03951119919938426, 0.06103275020817115, 0.05851248947663173, 0.03274064818998018, 0.01824215460087984, 0.03607545956789005, 0.06370486105762183, 0.08244300396331856, 0.035349556785677715, 0.032597577439681176, 0.021861437407712785, 0.04749788797550625, 0.050503702894333875, 0.045667539215496475, 0.06904021145836, 0.02758079129571636, 0.023861583810479894, 0.025448488980351437, 0.06194844744318436, 0.040626960295823314, 0.035263199524413195, 0.0049683679507354335, 0.05994389795007245, 0.02451345377090958, 0.05984238363922604, 0.019093755174488313, 0.0409527774900198, 0.08139670405897402, 0.059534071554099365, 0.04126282476429497, 0.17325295976573424, 0.07324824049588173, 0.1352217811490259, 0.19426670556347217, 0.1066991556135397, 0.15765108889149082, 0.11216890847971363, 0.0934844606766297, 0.09497169780755237, 0.1551977076357411, 0.13657637781673862, 0.11966572233265448, 0.15188823844636642, 0.08881482536033278, 0.2180978009897855, 0.12190088344317292, 0.1289612493447719, 0.10800144379778255, 0.06677645994650741, 0.08413472528299017, 0.11864749955073481, 0.12137366939456233, 0.20095267663559607, 0.21799704510598414, 0.1331857186291487, 0.10585905593489447, 0.17661934928788295, 0.12251689474308684, 0.1870038396408481, 0.14887526060544676, 0.15035532715339817, 0.09909433102415455, 0.09060249153164127, 0.13623923784302128, 0.15877377542276538, 0.10302946422128909, 0.15576301923682614, 0.11261860975214552, 0.20183173188519096, 0.09818289323800033, 0.19785378969484763, 0.1321545336395502, 0.1479967262956404, 0.06486779784843807, 0.045029487566000996, 0.10142333790539734, 0.10955726878056604, 0.1678330562407932, 0.17453825611981655, 0.1579733974029941, 0.1818106062109432, 0.08376865016837275, 0.12759229618935816, 0.21761778561818987, 0.1436072416723736, 0.1304530523597233, 0.13939280813980487, 0.23809332400560382, 0.1684442105432672, 0.23845851811910831, 0.13971471828558754, 0.14813624622841037, 0.137639110307059, 0.1048707029211425, 0.11344482791760277, 0.1575646894953905, 0.1596266917523838, 0.1332952845240793, 0.13868482032370183, 0.12693761277102655, 0.1843609129108729, 0.13688141870642864, 0.13945662326389743, 0.1415483190888359, 0.14985953037056232, 0.16405115595027325, 0.17667502855821965, 0.12765273286570467, 0.0822847608416792, 0.1372451419311185, 0.09446554351598026, 0.14172263473512667, 0.20552726342312752, 0.15127555196804388, 0.17933382862998595, 0.15733305515060503, 0.10436388213307628, 0.16121425575787024, 0.1501299900513503, 0.12178464492242183, 0.29275188943551433, 0.1431222620510286, 0.1969420684561614, 0.17256138155296927, 0.12442954049836244, 0.20790356091193615, 0.13808371709479442, 0.1632058392128637, 0.1413268277481679, 0.16131888804656846, 0.11654136296842368, 0.2205235571149857, 0.15405139495288173, 0.2435208271227537, 0.0984302630287505, 0.13545444205162988, 0.13294496783806434, 0.10912468191236259, 0.1860017353488553, 0.24185267066763294, 0.16063975110169382, 0.28325794565100826, 0.2187223771526929, 0.16471854110638942, 0.24741990822217158, 0.13810892138750325, 0.1252446427280384, 0.2234491702890204, 0.18547273631538116, 0.11373964153350362, 0.1430976706286592, 0.18844416154728783, 0.2123105736269105, 0.1073805065525155, 0.16222405157262282, 0.20155269201965104, 0.08876094639661813, 0.05892407787483066, 0.1727716267229088, 0.16312975136022415, 0.19340058187803916, 0.20215336623932087, 0.13141573376713261, 0.1591651390997633, 0.11943522179799697, 0.1721052068375772, 0.21871646295391747, 0.1404632474746435, 0.11736685335035286, 0.10389201793699496, 0.18859045369730842, 0.3170402780655892, 0.1447990906214522, 0.14907425960465787, 0.17244626918146688, 0.1748730671862441, 0.21505044112282418, 0.12438086327165367, 0.15132856525240407, 0.12300536772536656, 0.10361663231085386, 0.15432360131413708, 0.1876208468550636, 0.2072794903670588, 0.1669031633965431, 0.13649244522375448, 0.13688356375261662, 0.10368555724140137, 0.11472769577296511, 0.15366435201177675, 0.1850926954179041, 0.20114501066986593, 0.0968034906432994, 0.04959310014401713, 0.15157869295968165, 0.20202477072035113, 0.09382917725991818, 0.21270820390312903, 0.167104491303044, 0.14333580139904253, 0.15133795749035575, 0.22908838946492444, 0.14292622015120524, 0.22792442611628966, 0.22517619294024285, 0.21523250957890866], [0.011932392071391787, 0.07591418816798157, 0.012366564741598503, 0.04802104941899738, 0.027254594887997356, 0.01622149044828069, 0.017227093846867644, 0.053637010165520256, 0.015785987657915442, 0.011679584013989136, 0.02414288555061625, 0.04600467535877421, 0.13981746599799202, 0.047295751846245224, 0.04963827251847233, 0.005694639891566288, 0.05674494460465447, 0.015362578523044866, 0.02473958568917888, 0.04624533038886805, 0.03372343174452263, 0.031424761945081335, 0.04411756714445449, 0.010882458995066343, 0.02765559978152235, 0.0391727147413598, 0.03350693912756059, 0.0343487395213977, 0.03801455450875144, 0.1005332433288136, 0.02015274724051837, 0.06503259868270929, 0.016444157733912432, 0.07216888389760448, 0.07157881233480669, 0.03899458014676648, 0.03250124954408215, 0.059938895395926894, 0.023731689772478515, 0.080931190731785, 0.03630955688535206, 0.03526889921856984, 0.06338835566214497, 0.03618731989615387, 0.03521771305390904, 0.037769034820338415, 0.028938789393812902, 0.10182246205306823, 0.05801026138567156, 0.01602431090788976, 0.0158731579299896, 0.0684780944439192, 0.037148844510797537, 0.03240145510062575, 0.02550604516610263, 0.03186294317035185, 0.021306684413444132, 0.1112405171677951, 0.0156089227135864, 0.02994806618399678, 0.09784683344825622, 0.01599246271765761, 0.06532394958119239, 0.027663992274732842, 0.06916404191044069, 0.00034460974993341935, 0.0537142624718047, 0.027781127118355328, 0.042594484759554754, 0.0188830311995961, 0.08069672186167971, 0.03440324667721026, 0.031162104869802153, 0.00567623271396564, 0.05144489936590676, 0.051571131503630074, 0.010256536432632036, 0.04677216905439573, 0.05733678966099697, 0.05357970295834446, 0.011489715825225557, 0.02171792424163751, 0.00701839002900787, 0.07293040593785625, 0.012259891786191975, 0.05986510963749982, 0.059084481364416505, 0.01030075598523141, 0.016492022907421473, 0.0603928063215027, 0.03893119020147189, 0.053050171493762927, 0.03926401326973592, 0.055565038966315414, 0.032456552144140005, 0.04439803576397319, 0.03938006026850593, 0.042290930080437855, 0.03132679462132435, 0.037371504135550036, 0.031078003737474644, 0.02247714035723719, 0.05168368897190498, 0.051964598091980146, 0.06003267604917769, 0.05262707645494131, 0.029954556863935246, 0.01955813660676922, 0.052485909433134144, 0.011782708067086436, 0.004684946062268629, 0.045835553788610046, 0.0374458797816788, 0.021674368312702547, 0.03841355225191482, 0.03410565982302351, 0.007510293169968552, 0.07377423646469271, 0.012753220808301723, 0.038112043027555755, 0.03325755452556956, 0.018233968951408903, 0.007222244110439094, 0.06432160780194306, 0.03698279112277012, 0.0459636360286705, 0.03936509857134473, 0.02639898575932509, 0.05545227465430095, 0.03778624115511775, 0.029900289110599026, 0.0446555255762031, 0.03586978794285848, 0.03305116660832878, 0.009307313274832503, 0.03297918115652377, 0.05185138178809036, 0.05610684315944391, 0.011761893458183736, 0.042326924721560175, 0.025668653073690595, 0.030578772965518218, 0.014792153285065246, 0.01913152139393553, 0.014439433955797746, 0.029063489355687654, 0.019973442446620717, 0.017033733254779252, 0.017734376202908256, 0.03268796432342741, 0.08062718406079278, 0.023326073029649355, 0.06623492771459204, 0.07572263554339448, 0.051426379190337275, 0.04433355414338651, 0.08394923241388413, 0.020622309342387225, 0.03554649883881211, 0.022873998799872015, 0.04121206377843215, 0.03154694913856445, 0.03105671798449851, 0.0848401160610299, 0.018182123951133222, 0.05233721176703131, 0.007697435043331597, 0.03720313333155167, 0.0617746374149236, 0.03453039812044271, 0.007865872401218381, 0.01465127354622969, 0.009423967398282503, 0.04822944065616016, 0.03795710557530965, 0.01814161130647746, 0.037199816170839534, 0.022208109430427996, 0.027080765707538496, 0.05519727845826457, 0.058061324976264476, 0.004078413664002813, 0.012816230582463886, 0.038083280256438645, 0.0771270202653062, 0.10749813935328877, 0.019382560745842995, 0.035696349467241, 0.08467604301028675, 0.043829138871402516, 0.027346467982316693, 0.011135157884939784, 0.018081366152112043, 0.030480368971644394, 0.01612130146954329, 0.053203856392252835, 0.04141907988777084, 0.056348225973065824, 0.040880753733818574, 0.015448003072261572, 0.052356582300196734, 0.04015939002255759, 0.005577048746823904, 0.03245625720028916, 0.056881438490123525, 0.02367419678898108, 0.06367301095216986, 0.04224154422239911, 0.03541777691533489, 0.08431001386094479, 0.05246973731705258, 0.013121058882754898, 0.016879877901726195, 0.04182614453677689, 0.009380430621545642, 0.06209228428140764, 0.07458353940878185, 0.06018056549252041, 0.09580379186738884, 0.03642343968573598, 0.04674463202395747, 0.03312039031316677, 0.05269692069099796, 0.030172250323718598, 0.04419874182091125, 0.03287650239203246, 0.030073072581041246, 0.0894716078595769, 0.044283111084012255, 0.04256577178415272, 0.016399017918194016, 0.028344939102328597, 0.03722917266009796, 0.11407605372369291, 0.03899680946262614, 0.06019204148962613, 0.06317394680433697, 0.015673413910272143, 0.06714199113869859, 0.04420986158713218, 0.030303234121792262, 0.047968392365521965, 0.05775365257455457, 0.009482109641295769, 0.07410204548749232, 0.0166011827757522, 0.068597826325605, 0.07936641018116668, 0.10368653017306521, 0.04583798228733001, 0.052648350716598576, 0.0084697206189195, 0.039922504145051205, 0.03829974989076296, 0.02870724889479818, 0.06378155795016116, 0.013115863849018371, 0.08325485031931631, 0.03818200600724067, 0.04713974570134475, 0.07154645278088509, 0.061387253564692316, 0.02768021610174929, 0.04008993649134233, 0.0331051298417151, 0.044664695648656744, 0.06787345954968084, 0.02067536859202289, 0.02214169726827212, 0.028999729772969603, 0.13278586669794976, 0.06064667636829038, 0.026417555730609645, 0.016162258445195133, 0.041285799741144144, 0.02747975387460282, 0.019292064694567554, 0.018664742106451623, 0.09097085724915228, 0.03705682202933296, 0.11973663143092587, 0.02711434717169933, 0.00894614591098, 0.0260498124595371, 0.03788555296318185, 0.08845270325940463, 0.01958138737527113, 0.038135209526385994, 0.02415126655250788, 0.018224877402967504, 0.01962134843662141, 0.05084231375686584, 0.012620102497749032, 0.013965225530668132, 0.010025190328428102, 0.031720023722417896, 0.040427869366061304, 0.057229882091163635, 0.009002840247816377, 0.04869693049019383, 0.10353335855348457, 0.05315742380316219, 0.044561151204810995, 0.02424094288970434, 0.06345872083799013, 0.035724453402743224, 0.06594861767465068, 0.02219542492962172, 0.031518672833279256, 0.0340668574696587, 0.03877059135946535, 0.04509459354824597, 0.030506324030519016, 0.004038223733885154, 0.04426969305401848, 0.02633998741305644, 0.010575278804847791, 0.050641100763553576, 0.055246151037394046, 0.02832298876807815, 0.00743042994027717, 0.05995903584745623, 0.023840765371137572, 0.05116009851917625, 0.030422686381385695, 0.015314402126316583, 0.05287538470339872, 0.015496158401571937, 0.09924718854768623, 0.03035759189045958, 0.03610520293155024, 0.05508315817062413, 0.05107410131923614, 0.026461172946578553, 0.05937434222188689, 0.013530869956969494, 0.018290082976642637, 0.04080609846559744, 0.003816193258840471, 0.06530057623862259, 0.06922791066068797, 0.051666903985484, 0.03153409226797521, 0.02643037812724229, 0.055350729699937574, 0.006812112236906204, 0.03595877671614289, 0.033867701422423124, 0.01758366372556456, 0.042860420691149856, 0.05243982158360943, 0.05046763930529837, 0.22201657054885743, 0.14305319156377547, 0.09410045665478516, 0.10172303150137586, 0.10772317002016692, 0.11019731225866465, 0.0697159239902131, 0.21318274940694534, 0.19237903427452813, 0.13673022359369263, 0.1756912644111341, 0.15539980163016628, 0.2705156664934851, 0.1561207976192236, 0.2230959884341686, 0.14010713916392098, 0.11856260168696604, 0.19712162414385428, 0.12453425705673234, 0.12039687664758776, 0.09681065356539142, 0.17229884322131836, 0.1391065670477767, 0.15594102742691196, 0.09894964765877494, 0.09301264244582384, 0.12218424404460577, 0.20958313207712867, 0.1387881502629288, 0.08245673991980092, 0.1440986104670071, 0.15260492902128928, 0.10852932434288726, 0.21597429719423095, 0.12861249547812248, 0.08769592330340417, 0.12395807466800175, 0.2201485570760504, 0.10743868326948536, 0.23270559617348258, 0.09745516333608858, 0.1354351519576965, 0.31694797979247186, 0.1517966909394149, 0.13337846635089767, 0.11296750151462133, 0.1591685558519056, 0.11372956747729933, 0.12975111663822206, 0.09205532365388448, 0.09923143011908378, 0.19347936636017216, 0.16035010857928186, 0.1089303024233349, 0.086438144827562, 0.16198690139478253, 0.2048465330153704, 0.17543865457898186, 0.13703483547414505, 0.1940736514065535, 0.2097772127918659, 0.13340529475000598, 0.13012066213113646, 0.25172778915974403, 0.19959593492169536, 0.15997285624184918, 0.10236894321297446, 0.08357394892241686, 0.24781562327857942, 0.2438985697564579, 0.2108909973814603, 0.27850816987695237, 0.1702397367766788, 0.20875405640371386, 0.11838608736833257, 0.19640214500888703, 0.05665335879330674, 0.1698276121169329, 0.1396951677217599, 0.1745477709318361, 0.11053415345809153, 0.21321235104433953, 0.12517158092269975, 0.17122625884029175, 0.14296653169778087, 0.14940232909735174, 0.1455671550525773, 0.10552884905689186, 0.10478860893917662, 0.21794138115740594, 0.19377616414379692, 0.196908452518044, 0.12561261007982877, 0.19837302876816643, 0.2466906538052905, 0.2961576405552126, 0.09999471416156139, 0.0822637700325539, 0.14696497440097794, 0.08898965428553282, 0.2087205783614228, 0.09416789537475956, 0.2515839484910811, 0.0893902799655353, 0.23876630160356724, 0.11946759667367705, 0.23160298114582417, 0.11520552013309733, 0.20771694189358145, 0.11513287967611706, 0.06531556091842151, 0.26332421528716243, 0.16414849508193233, 0.1575192911249976, 0.10927782288842625, 0.20404209472960044, 0.07491850369279424, 0.13468550428027107, 0.1311397735750483, 0.13711623997697908, 0.16294245818449607, 0.15873049145504353, 0.09414054603586275, 0.20489295794358178, 0.19706626663044577, 0.18558375777736788, 0.1820524142033631, 0.05241357541132358, 0.30410620113534315, 0.14357759406970394, 0.13656110202352847, 0.07834674715394936, 0.14791415733916147, 0.14350244084433203, 0.0817420794778774, 0.16924682553977738, 0.18104427313852697, 0.07167514789128496, 0.1666841235372328, 0.1935408832204919, 0.11847411087083241, 0.0831432389696279, 0.22944026897030495, 0.14284761953017405, 0.0810091325172013, 0.10421260275066861, 0.09952253586943112, 0.12191980581490264, 0.08746978180903582, 0.15619547587008248, 0.14476953494933345, 0.10014498996878825, 0.123011818185689, 0.1614094549609769, 0.15920673767405172, 0.11734731810828371, 0.13758280284462437, 0.11208339774560545, 0.1709977194907204, 0.12808389481036894, 0.11932393986611597, 0.13430451343376792, 0.07464189232597429, 0.18341100985004058, 0.23217511092943532, 0.14100903915541788, 0.14262986669857658, 0.13164457955187367, 0.14045002479707042, 0.12719830483077996, 0.11574452427486259, 0.134738287738254, 0.07724293702912909, 0.11717789010294985, 0.15882138012638017, 0.09356435598625291], [0.03496588463143956, 0.03347269882778487, 0.06020605706820085, 0.028474902088243156, 0.052322207935034275, 0.05031375522394815, 0.02626492803345525, 0.029946281199133205, 0.06530423813890066, 0.0410071314282475, 0.05354325632534681, 0.017924283653677955, 0.029674003974744873, 0.06862915932170807, 0.0354744406086543, 0.046626589366144715, 0.01661667115836134, 0.017226176456578316, 0.015234588213535327, 0.03785507798555397, 0.053875382253599745, 0.008075913121443122, 0.014368202142988243, 0.0165432492916983, 0.03299675138306714, 0.020451054217353947, 0.007657033481424855, 0.05930692265411058, 0.04546147688562351, 0.024854642519306754, 0.022473022634644183, 0.05645126096844193, 0.02949752604528781, 0.058341326282149365, 0.04734669669320987, 0.03685146066991072, 0.021789718171461456, 0.02842279661807322, 0.021650483606443293, 0.06710769338232857, 0.0459729784709071, 0.07422605980067484, 0.07344858780983957, 0.023474081216620344, 0.006947047133449346, 0.0629819306965557, 0.03428607352919156, 0.10304647137320812, 0.03135760093197948, 0.02343465833203687, 0.017248877556994557, 0.0704729950596248, 0.12230736969579613, 0.023685094389703967, 0.0075656492469622005, 0.026497646392653548, 0.03032620526820181, 0.05884178854044407, 0.03332348788277276, 0.07434020690139263, 0.02668780856765807, 0.030580939079124122, 0.06820901372139493, 0.05685097117337489, 0.056526877677008036, 0.07142560241082985, 0.038935158536919666, 0.08207837675487803, 0.013335639152735954, 0.08741361990330682, 0.009057882707566023, 0.038947189947770494, 0.025051285798150687, 0.015713073324502235, 0.0036214984767514494, 0.04965867727033554, 0.04600130457190737, 0.042361172682215134, 0.07013843680221228, 0.06136777960965711, 0.03133811165518578, 0.05143367617781605, 0.1077025316114868, 0.02160893865830956, 0.045553346149503224, 0.0520956336009887, 0.04949139431118966, 0.05469500823246856, 0.09430951438844205, 0.02474105849321331, 0.03788421230931436, 0.04810337322734056, 0.05940420815961496, 0.048429642413412376, 0.05328262938306697, 0.11421046385000791, 0.028876286195290667, 0.061843313366895726, 0.039241999733231725, 0.061632305939471534, 0.09491822487043758, 0.020218718902117783, 0.015537335627502011, 0.03826110841586225, 0.015604359702387405, 0.06545770087189252, 0.07687274802235827, 0.047634918122522296, 0.07619709677753911, 0.07210870769115225, 0.0758874210559072, 0.03898049945071821, 0.04934089250802513, 0.06572054563871314, 0.011840699007734658, 0.021206769311139663, 0.019409620886548393, 0.06056783442956306, 0.0476620874307569, 0.022008949552752802, 0.04342947080130539, 0.021573432398238973, 0.022240340664622285, 0.046835976517609054, 0.053776392202463844, 0.038939548220725796, 0.060198434493354255, 0.0480111362412572, 0.07272102644727116, 0.0057760003443446855, 0.056076946578198866, 0.020043598863506512, 0.004337755014984719, 0.03430890677977474, 0.045574919185450966, 0.015214441058736657, 0.01758930213268726, 0.08878419716512004, 0.08454408436532944, 0.0825827154180696, 0.0721689222020007, 0.01421761223971243, 0.01811661960316762, 0.05909988739257378, 0.1011723368578861, 0.03403343305352234, 0.009563251759015746, 0.010143119988272028, 0.009179921471513808, 0.07199693546299973, 0.027083190375818845, 0.1012332255261079, 0.04842093965459255, 0.040694667146571224, 0.030581762623642723, 0.023539010998642734, 0.12912932903535906, 0.025334286338259137, 0.05845270014458126, 0.05954812543707029, 0.020424560981712515, 0.04246631058894339, 0.026547807914715622, 0.021181348598592227, 0.05947338972961711, 0.018592365949805227, 0.06301727033250275, 0.03137501028005875, 0.01583860544938474, 0.04610808190679358, 0.02716365067528621, 0.09963092964983757, 0.02786441428226329, 0.062211414784072876, 0.06839128136033974, 0.043797652657714584, 0.039810632325468526, 0.046223416443794005, 0.11582690170936047, 0.010444368742736838, 0.04583604025444196, 0.038048296851376374, 0.0694931379609531, 0.07059942254976881, 0.009728865604096604, 0.019992887673358765, 0.06845122774041469, 0.023249646183103326, 0.0509212323043856, 0.004135656711314955, 0.010035772875492132, 0.011084660241800931, 0.08587968205252001, 0.02973567022220983, 0.036916149134236964, 0.06797799990782816, 0.05338404793292285, 0.028179862476404638, 0.008715583131678643, 0.020604020908414837, 0.03337961148410555, 0.03653044684699947, 0.006207709084264935, 0.05358579335734249, 0.0464638110039936, 0.014003234983031309, 0.08865691931738008, 0.02229263191111386, 0.013258112012408675, 0.03481530621948262, 0.10714101980650619, 0.030761078908859246, 0.0652818913541494, 0.03656980461410938, 0.03256222631241525, 0.023803202164990288, 0.027029824691013466, 0.03242926792271676, 0.05483510273118174, 0.06585356914588521, 0.03150533141207791, 0.054651777890901414, 0.08735982520926384, 0.04001222453230331, 0.034219745636707356, 0.01811061538906107, 0.06844191977213468, 0.06508182749272355, 0.10591150231419072, 0.07004819164473204, 0.04570403181376957, 0.022851544762811354, 0.029747240065086274, 0.028169150652003386, 0.09115261927006707, 0.133000677751918, 0.02197142465100173, 0.03528227128328816, 0.0460863211793044, 0.03677219738282504, 0.05025727156129095, 0.03228360013435445, 0.06166804394113922, 0.044035565093039505, 0.06816700145962738, 0.04440497652056717, 0.03376882628447587, 0.029347246407621333, 0.02897047479036114, 0.04487909301514587, 0.007773804433283306, 0.0756300921221414, 0.049264900416376135, 0.01560610734046467, 0.012918936160032549, 0.02195718882214879, 0.05881748057060665, 0.029884252975124027, 0.03985999520086954, 0.036312632728368044, 0.054651444642654354, 0.06976053329004396, 0.05434215579542422, 0.05275689388415026, 0.07229710403349131, 0.046870393017607356, 0.01842425944614074, 0.022499220926434766, 0.08817980741901744, 0.03410431533871639, 0.03676818308210181, 0.09648007896518516, 0.04032173171459187, 0.020279550113745277, 0.07042888371694474, 0.057982709033474814, 0.0630612361184772, 0.043402715180549896, 0.006323134594206368, 0.06254198938427914, 0.05589841744832455, 0.0220335045859458, 0.07519510739873494, 0.04969363386232046, 0.09145835729976816, 0.06103119121924524, 0.01872479190839635, 0.07088757120072842, 0.010879831313486061, 0.0938500454949756, 0.006591459762515321, 0.022016698532106898, 0.034518883818940777, 0.048329790513361656, 0.03093497703723129, 0.03349361302811773, 0.05462822068722979, 0.03325423353441781, 0.009133357689866136, 0.04664129442385128, 0.0676239293909842, 0.01626461736797806, 0.05065950985637404, 0.018402387635902535, 0.043955957066387906, 0.01407271245449421, 0.05441082791695672, 0.03829426087078549, 0.03651575711105139, 0.008000502777811622, 0.11234575987703378, 0.01778204985443623, 0.022515092353006045, 0.030238225815757632, 0.04452981054782868, 0.07099107734017795, 0.10046189756042535, 0.060624969266955896, 0.09624238486491865, 0.023615388049473687, 0.03471859144948183, 0.027515924715947722, 0.05349468635094743, 0.043053647217851494, 0.06666438128318518, 0.20089613934678419, 0.05779664159842557, 0.029126260684983387, 0.04875726374467054, 0.03017267358729676, 0.028072939584812814, 0.02112992686189471, 0.07169303604431691, 0.06214106109954658, 0.11230013168026363, 0.06981686373511631, 0.04021341454297785, 0.058424569396001685, 0.0167040741296425, 0.012837781593383802, 0.03696774132549763, 0.025564683451046868, 0.06109493739542462, 0.05104821903871433, 0.06253128713597694, 0.009930249051972023, 0.025913670974513216, 0.045416227902375886, 0.02429892616947332, 0.05790305887198737, 0.045219956176175226, 0.013433197577063356, 0.23629405926312172, 0.12012909827453476, 0.16698164144350638, 0.10226122358994139, 0.18497839509960146, 0.18001108099856686, 0.23156740402262058, 0.16545816835376526, 0.14962363657691788, 0.14333644491289893, 0.10363075897217759, 0.18908565293156332, 0.11026626017184989, 0.15737892849551094, 0.06920569411088383, 0.1309288695694939, 0.1260251637488123, 0.06390674437786784, 0.08598721015357202, 0.10848615528835405, 0.10793703112510905, 0.11578252989678614, 0.07971085863368166, 0.08612017237371014, 0.23441479961958625, 0.18295036118117072, 0.10473742660495544, 0.19514179247761929, 0.11922600318587596, 0.12040689707763734, 0.16204342336183594, 0.09605542110699801, 0.08942296893726434, 0.1384555302079647, 0.16163937326881195, 0.07070290570658061, 0.1049738949645431, 0.1135314571400804, 0.1314406622681887, 0.11727124557740266, 0.23380572907626632, 0.13517863507713043, 0.13718874253813299, 0.14019871731438946, 0.12406620797851395, 0.19378454514568855, 0.15754821860501844, 0.1838208056024967, 0.1345997790415441, 0.17134607499164922, 0.1262570432417335, 0.16071127307030464, 0.24301542359734737, 0.19031363058715098, 0.13070838946488597, 0.09903597044608287, 0.16491357177015276, 0.12775106025078606, 0.16986213203880096, 0.19008015763134728, 0.10144371584418321, 0.13128991148644878, 0.15582669646509234, 0.18409471267894392, 0.1610690667744606, 0.1720068258263411, 0.2620590670454887, 0.1864800040399836, 0.14253812000876473, 0.1349450548690173, 0.12972929845413855, 0.10876272835077778, 0.1325404121270103, 0.09506981068801496, 0.09835537027327285, 0.19837857524473823, 0.18691026966177648, 0.10389132079698386, 0.24346668002826555, 0.1669055076255914, 0.22995311887033526, 0.16197911794147185, 0.36781581959897475, 0.10404697454143917, 0.15940490929830461, 0.13906971821861883, 0.1499966907525255, 0.15837020030425442, 0.20092174200521362, 0.13364549395778488, 0.08957087753280517, 0.14458567384750615, 0.12388686679543988, 0.12938445163590293, 0.12425169318674073, 0.20140181866384324, 0.08227391303667138, 0.10704803205425702, 0.1587807927881518, 0.18255712824963755, 0.17746929319635515, 0.10639432156758924, 0.0899060793040741, 0.18267959506521303, 0.1654751601839258, 0.24817427500121056, 0.1719108043659118, 0.10938464618858793, 0.17450387409377485, 0.14878878460055397, 0.1337175368661842, 0.22804087148078028, 0.11170345643955855, 0.21912333225050282, 0.17972574389028936, 0.10146254628536203, 0.17594174451885686, 0.1216018180392923, 0.19879992360309248, 0.08399627021243496, 0.21421600283393938, 0.22125903216581191, 0.09344678447251359, 0.1685072595794355, 0.19511032158568983, 0.17498735218278824, 0.20051384615080975, 0.134238951629208, 0.11499533625019175, 0.15170131299284198, 0.12439995418272673, 0.12031940983668452, 0.15995065501380354, 0.11123133177358298, 0.3012863847036516, 0.15032103705790736, 0.14537296708553069, 0.15865363751447972, 0.13695243505700944, 0.16693912356370882, 0.18095461020786918, 0.1150205098993836, 0.16945320962657853, 0.11561891649879756, 0.12969410437489712, 0.15115878484662504, 0.18627312965691092, 0.11739593404795855, 0.16927225965886347, 0.3249231695888504, 0.10307287842395807, 0.18567201110624498, 0.06643887564179397, 0.13056574389338493, 0.07529573304758919, 0.06729015254325445, 0.17709165781496033, 0.1397874813166357, 0.1569147864657064, 0.1567978354831857, 0.1863178538699304, 0.09909503582504489, 0.13745284368914945, 0.12065940731835943, 0.08224077973394625, 0.12541833018223125, 0.23687026463449004, 0.16247398009704006, 0.11197026954182696, 0.11677295134793367, 0.17180712202623968, 0.13775321144250133, 0.09189177920380909, 0.1306925008013364, 0.09652127151287372, 0.07667548804273529], [0.02197261400250418, 0.008101765716057873, 0.037421774825141314, 0.09655284965711255, 0.022136625766213384, 0.04416761183810811, 0.08094963046812242, 0.05056310152154296, 0.03008616885410682, 0.017836089696614973, 0.04250248909116753, 0.057564267978793195, 0.004736509525232138, 0.09460540818831614, 0.04309898430121042, 0.05704816986596393, 0.021294377210940567, 0.12227352393130142, 0.07925474520532355, 0.026518288631773284, 0.043486046394513506, 0.05856817640784768, 0.03155771267390059, 0.0813491453206347, 0.12055916471346734, 0.041875787034270265, 0.05732951948659555, 0.1115960279299367, 0.01162030891845784, 0.057816490936543674, 0.0075950904846972525, 0.07774474760217052, 0.06618304057948052, 0.0849884843093253, 0.05966463591903449, 0.00195561598605221, 0.047039690787994096, 0.04426466751723521, 0.05198539354868474, 0.03455919536551641, 0.015365065435969062, 0.02511209402714045, 0.011681005107088676, 0.008801509468485753, 0.11884795411700204, 0.06316676856048646, 0.026245551754630385, 0.03543436654933518, 0.06869701939004083, 0.020993174421751214, 0.0218481247148086, 0.049494918315641345, 0.0393204203236007, 0.027650625955673958, 0.04151488684358136, 0.05038323556824077, 0.048323661809967416, 0.06625178930980545, 0.008803335630575256, 0.041817782687083374, 0.038060447005855466, 0.09604724694884594, 0.056435736196656386, 0.02099486556084406, 0.025625003298984903, 0.007789389534492887, 0.013789756922051312, 0.07115741035029774, 0.09164022657299235, 0.03761609685757468, 0.061281376383117134, 0.0218226925109423, 0.03182693129225123, 0.007043840427462373, 0.03396617819464976, 0.006987718262544443, 0.07396946631131635, 0.04329773432184612, 0.025752530125300252, 0.0638971989223313, 0.0656600783188497, 0.045166651778403795, 0.06271469624592893, 0.03626365289692918, 0.026029151068219257, 0.010387387122928856, 0.015681619669551092, 0.02356355071007725, 0.015289199748827566, 0.019159947086365956, 0.015927255228762666, 0.016000621554051197, 0.014433457512378454, 0.07585175200215272, 0.08199724038281749, 0.0136122677565342, 0.03939151711341354, 0.04783272585501114, 0.053356989707437255, 0.022938302305016308, 0.03533402818345255, 0.05532202055497516, 0.06416547525253508, 0.028565258328472416, 0.01554447269412659, 0.015625965297071925, 0.05187006667256356, 0.01617551751194462, 0.07270327619006557, 0.08992905428092327, 0.0907256325045901, 0.048820787755351876, 0.017411309264359937, 0.02906666862057342, 0.06182353680713042, 0.04583687529027943, 0.010575861031670245, 0.081933080519159, 0.05601292844080637, 0.050469949060390075, 0.008631549989654413, 0.07634273009194482, 0.05340080610626648, 0.05742242296917304, 0.01865831079832729, 0.04206087004633681, 0.026619538642285813, 0.01803566326176928, 0.043667475167181224, 0.05630426401753099, 0.07378573544443616, 0.03951644307122596, 0.03563903076874633, 0.05263958667074481, 0.05556396644322142, 0.029997254774395018, 0.035671267748600057, 0.05499459457613769, 0.0127970831724064, 0.01847612934427396, 0.010744290249872833, 0.04341641283263603, 0.012748791862489476, 0.008728796233152671, 0.019913949973640904, 0.013390587766714876, 0.03381152419493564, 0.02883576014409623, 0.033528198067459374, 0.04157979364296602, 0.08200709993440299, 0.055674704452676166, 0.04621728007952052, 0.011294755066985325, 0.01898536522452149, 0.13293473290339594, 0.014078415021480573, 0.06818090595545308, 0.018585693323984742, 0.045743967977262316, 0.0416237287854235, 0.05213324085719163, 0.042384044237194524, 0.04155726299711293, 0.02235250359761619, 0.02578319854012901, 0.08552987864541431, 0.05534809052703842, 0.035737231749320225, 0.053253406959195296, 0.050370733013316515, 0.028273453522894173, 0.04857816004885301, 0.06294017507424278, 0.025832025153983026, 0.06203152584813296, 0.02508508176693032, 0.0674207781952235, 0.027670168858622352, 0.0653623229253196, 0.10715898456833056, 0.023546026448809335, 0.07591355997588366, 0.059740834854423046, 0.047089624398898695, 0.007723511718664199, 0.009308429847982143, 0.0277996281417267, 0.05165409882582965, 0.06827821444359518, 0.09511795165317674, 0.04049582902582423, 0.0512450117047035, 0.0767927531213049, 0.03678986720079857, 0.02198827475489628, 0.10526621879469003, 0.004320584111771877, 0.022002738494906696, 0.06406920864396999, 0.048425497877742016, 0.05176624260662545, 0.06265395696485235, 0.05393403011464304, 0.1058796407174199, 0.044093370257366094, 0.028154968449305144, 0.05421736390299855, 0.05271015869032952, 0.0743087743138594, 0.04189108964055777, 0.025515669145651405, 0.03176623797645012, 0.011764505818005533, 0.051854327396159215, 0.020713012237402222, 0.012568633838166154, 0.026884070717759674, 0.007192115787596953, 0.09661493342249625, 0.02429406534159376, 0.08487170186614798, 0.04204214302702777, 0.07429006644674847, 0.09846994638322823, 0.04688091906568697, 0.03467785855454784, 0.060122668397642916, 0.007891883480272466, 0.09742492584571724, 0.0619048761924909, 0.06629983834441631, 0.05744403430951699, 0.03497562543939679, 0.013143001556126101, 0.007706380556262429, 0.029941385897297054, 0.041823589633549416, 0.046768733150055336, 0.07942071049323968, 0.0232464381899204, 0.06786788242959207, 0.05446366500109435, 0.07246160609347206, 0.03260786983094389, 0.06325422515792233, 0.03349893733919148, 0.05459109989685878, 0.003152212884742767, 0.04989427228968951, 0.03302498172307688, 0.05286186708197479, 0.05401266137919119, 0.053814868968460834, 0.06572803031773337, 0.04097624276314051, 0.011206270954121026, 0.04380249816383566, 0.04380225684613951, 0.031994719869427146, 0.03934086337986012, 0.04227167446046107, 0.044251287791637645, 0.01694866876688696, 0.06264813852706744, 0.10028300070834738, 0.03293031623827354, 0.027194315259675347, 0.05337401984199401, 0.06674754778824507, 0.09652382258566157, 0.039272080175578594, 0.027289135877283353, 0.10603082816927664, 0.008029640453206676, 0.04427517058267709, 0.03867448179892475, 0.02092550970583914, 0.0434076564476615, 0.053692934583992734, 0.03521944824305754, 0.024468677846955198, 0.018696913968831785, 0.0050662241917434, 0.03841884974991122, 0.07480557467187605, 0.04879345373821355, 0.05125407069440811, 0.026986766719229283, 0.029962141134385622, 0.018450471144469998, 0.06668178680082483, 0.012133697952864873, 0.0315079954828346, 0.03991354474677675, 0.05476938770903696, 0.023463878840688738, 0.013247263249790957, 0.03873733548267234, 0.06644654418191602, 0.025956815131188884, 0.036586294656679515, 0.020084578821796085, 0.026088118770970933, 0.020994704682379964, 0.02759340493338964, 0.03331428716680215, 0.07957399702600895, 0.006858258979440097, 0.03813420595120519, 0.02260434159618472, 0.002000316857330261, 0.0132784296217705, 0.02917425992387918, 0.06608897264325811, 0.02950880668997284, 0.03985549060387477, 0.019776588493597605, 0.025265395881668217, 0.04094294092107204, 0.05922030109251219, 0.03281637981173492, 0.007781041570142993, 0.02942565933711106, 0.026999066260853605, 0.05626962152159503, 0.0686184800560436, 0.05467632334799536, 0.04885358014895071, 0.0045871410533905995, 0.01773622055958596, 0.10422234738906545, 0.04575001241098489, 0.03067052157054986, 0.0367388840494377, 0.03161572851240635, 0.00743881477260842, 0.10561896397942498, 0.027492603084312815, 0.03988595025974416, 0.059392479353494225, 0.020389221345765457, 0.029878955477127628, 0.02201981459473891, 0.06524990718331068, 0.025064301631984212, 0.10562819533891256, 0.03482333482092908, 0.026887192526051117, 0.013838595027224192, 0.021480425493791703, 0.026612969438335108, 0.12331508941227391, 0.16920896547455944, 0.14435368710227553, 0.16290346430915018, 0.1312483741991943, 0.17131080430361534, 0.20985019032753285, 0.12298891981763226, 0.17612932880799617, 0.07687859327322052, 0.12898466099173794, 0.0972088430857947, 0.11392840559804633, 0.1640793173423698, 0.1511657409249775, 0.1962359958598691, 0.15218646115353032, 0.16704988455580128, 0.16827968550064873, 0.17726756692413362, 0.19703956080540536, 0.11931483108069628, 0.11112902073129532, 0.1933307912681372, 0.2159367895294582, 0.09742735434443721, 0.15774312669471388, 0.19955306464145262, 0.256723479157494, 0.25590318285169145, 0.06935562517854475, 0.2165879489433381, 0.16140511890332546, 0.20381813658581627, 0.19061669496999634, 0.1459862204689172, 0.10902151285159974, 0.20823163040463002, 0.2732813358306885, 0.12476963757146751, 0.15075856519322242, 0.13395851748364587, 0.11291851785274283, 0.17207390448499113, 0.16260413843537533, 0.38000047867817266, 0.12930163753128823, 0.14657336557584424, 0.25379671685157285, 0.11899660581782942, 0.14268393718427227, 0.16968752527909894, 0.18710689378842232, 0.18739037696392308, 0.16127767251624217, 0.17131782166900175, 0.09737482369546929, 0.19625490290984032, 0.16411567587525616, 0.08696012649564974, 0.13317065734055736, 0.14258687384426594, 0.09578221117056186, 0.24457323274785475, 0.10075073569051682, 0.15550956670795718, 0.13101649470627308, 0.15735508783930735, 0.19273451439315276, 0.1226504545118059, 0.13720050964864994, 0.0863181601368612, 0.1906939319545223, 0.18588463114874978, 0.10022194350078222, 0.11332983812016827, 0.22335886384450623, 0.1396115875292209, 0.1930218433300334, 0.11565969535900701, 0.12713131044180165, 0.11936400626455584, 0.20173374923967546, 0.19091097998522943, 0.1635163040050576, 0.17020699417879506, 0.1817837624900764, 0.1889307805967908, 0.10090718616641338, 0.2632219578710295, 0.10948776928407532, 0.13756481510016227, 0.11633058153693715, 0.22471935938923593, 0.15770718184930665, 0.09595180005435983, 0.15122157341289907, 0.23332422749409754, 0.19374801807345884, 0.12731871086983912, 0.1426342946867789, 0.23520472820007035, 0.10608998547878959, 0.22228477793114804, 0.09754674148655708, 0.16787655471313387, 0.11190979456108426, 0.1946090855785916, 0.19840848331730213, 0.2066729325921305, 0.14230662355980567, 0.15132355503737926, 0.16643673842472417, 0.16623326547203526, 0.10840262872196975, 0.15162502595734212, 0.1370487016655745, 0.23294956453384894, 0.21223436320020309, 0.09853715527682536, 0.14631822765354188, 0.1828349730180156, 0.11922043372666645, 0.1942150559156172, 0.10385022784072546, 0.20363461256267565, 0.15470131330432432, 0.14103609738090347, 0.2082264363285034, 0.11378641886216019, 0.18042735785486239, 0.27358896609756256, 0.07944170130236496, 0.21149781562628286, 0.1652094042829929, 0.08775618377952807, 0.09476667735725643, 0.13382198529378062, 0.0927197823541299, 0.12443702517738267, 0.15268674721160244, 0.08963761911276849, 0.1811089616028532, 0.11198893144366243, 0.18788041276556833, 0.11708815056349962, 0.11853837032592106, 0.24408433075633743, 0.11862572733192675, 0.13882411043009452, 0.14862637396060652, 0.15499261057665273, 0.15857184996768353, 0.07851394584342357, 0.1455395912090617, 0.24734136888817435, 0.13645768015375062, 0.22218432848251637, 0.0944978034784717, 0.1641055022276217, 0.07170362337943047, 0.19657950968511645, 0.14000293588446033, 0.1442549230470773, 0.3998084174048516, 0.0823385248922052, 0.2357499070105053, 0.11797389376067347, 0.14399929482850338, 0.1343024143528554, 0.24526516336106488, 0.11063850995513702, 0.13801530544315616, 0.15101089923372193, 0.06389523773724515, 0.13012060084410254], [0.055292729183190295, 0.04574180760931584, 0.03398687022948458, 0.03271181647094988, 0.06714139359011766, 0.030257379929084453, 0.045149564187252716, 0.044610973732966575, 0.013127427946235384, 0.05046819471904347, 0.06408997345715761, 0.01937051784367331, 0.0055119748445107575, 0.033667131942967256, 0.03669206841638492, 0.02797260313414999, 0.028004880333619735, 0.08024910434840188, 0.04384040419432906, 0.012783827936096538, 0.04734049904190245, 0.03774180805550949, 0.05291084691341366, 0.03279079247506396, 0.06422889967178626, 0.07328358013182878, 0.03959433506092718, 0.04067815795180298, 0.06123945988234013, 0.01980003078408059, 0.03220616013652856, 0.06993905475903904, 0.04626146803099302, 0.03863774405251588, 0.08002972741040491, 0.06600680971337904, 0.054895386189943364, 0.02946124412119389, 0.0288336246740073, 0.06517037193501188, 0.05305929177050149, 0.05005771331789513, 0.06175099594158031, 0.011600782294877836, 0.0043842599036232124, 0.036507487191908786, 0.018944800868930838, 0.04477284811136704, 0.024898972197045243, 0.005157699877952016, 0.0207653398730702, 0.013034869203223817, 0.05349816439012366, 0.0794369668789929, 0.02879751895013596, 0.03813688725894017, 0.038892437643822164, 0.021293463651090864, 0.03282187649259164, 0.05199021607216808, 0.037701596100364006, 0.02467536836892607, 0.0248105694810229, 0.02872349570445236, 0.03666881381744339, 0.06489025954637798, 0.06801307141300171, 0.019535010327555, 0.03927638942015268, 0.022423075617200906, 0.040879007053351214, 0.03122198804762335, 0.015666585194037085, 0.05749407134229138, 0.03550190869117937, 0.06694499162896987, 0.027733378773254734, 0.05738415304691561, 0.06032944318928546, 0.029117791582980466, 0.011521315994492222, 0.06490146741271019, 0.08446749855553912, 0.026240317458887736, 0.014071997119894913, 0.04072007445257999, 0.07823102957298679, 0.022829985133402293, 0.013061684195793444, 0.029101134916286797, 0.03781372072896169, 0.04020506801504282, 0.11826568132927341, 0.011931273583022338, 0.03886884596619395, 0.10141196149972179, 0.05937334630758532, 0.03650595884649985, 0.04067135892147499, 0.06139061669067991, 0.016348408234696236, 0.020589400120379946, 0.061806073832896456, 0.08047076422841319, 0.01409459192561166, 0.06634460086183203, 0.03408163530571807, 0.05425534654228438, 0.046215774716749314, 0.01114692978350626, 0.015188058905844248, 0.028756016136838064, 0.05406836363216562, 0.028257953648966168, 0.041182462141037955, 0.030640391332487908, 0.04013975901949791, 0.034505235962569714, 0.024547422109472177, 0.017491664226737716, 0.047139136661444946, 0.03972985218429277, 0.03916292796812711, 0.013208737645688797, 0.022812292332791036, 0.04097615466302922, 0.0392994448362339, 0.03407065343532351, 0.07027006602936214, 0.09643969847069633, 0.017017101485943122, 0.08286571595817804, 0.0056140081799258635, 0.03637134187644528, 0.07636054163618435, 0.028255283832550052, 0.08540037914269394, 0.02112949210699768, 0.05429230645419129, 0.03944263816060078, 0.0706810875224971, 0.03836886634329154, 0.019368817128481406, 0.10290672161406088, 0.055252513397605195, 0.07107625099559946, 0.019555543399145527, 0.048793438416455066, 0.04029890229444831, 0.024422291223140016, 0.03208426405645667, 0.03225119461515739, 0.022435078299754573, 0.05345160922696514, 0.07806160156765292, 0.05345250171939692, 0.043003690624309164, 0.06142225995239231, 0.010080808311730865, 0.04326457803648326, 0.014186994578208656, 0.06932834478756113, 0.04046759485537487, 0.06674593134272484, 0.0958642591872523, 0.034800248761330886, 0.027805634271053058, 0.02000686111709764, 0.06459336983220232, 0.014966811755702141, 0.05004836704521891, 0.015566351207634135, 0.04523360786298591, 0.06575967740988539, 0.036161970046739426, 0.04096881554071461, 0.005014171868923211, 0.03546865281438635, 0.03229774594787629, 0.028803657229629256, 0.025434498299634265, 0.021644881588496992, 0.03448743590964906, 0.051283002004868565, 0.056567143258308215, 0.01374883250513625, 0.05743365764858262, 0.07053034440163644, 0.01839074501467328, 0.015250486453183958, 0.030359901645551288, 0.013564160307719102, 0.02383376907316908, 0.029775148648167812, 0.01746369818706186, 0.0769864890964762, 0.06401236875042801, 0.11144624241898138, 0.01829427347758845, 0.03368395523378446, 0.03265474675103061, 0.07889543464707752, 0.04899066009168183, 0.01990886123460387, 0.05313408493454899, 0.011944416778973274, 0.030515091906812404, 0.0710976631530831, 0.032141712989898465, 0.046578823784065825, 0.03430622164160013, 0.024262717023732203, 0.02421759252977227, 0.053073027726983836, 0.028097088591405944, 0.05101946775891608, 0.08768932728637611, 0.09408417728639419, 0.04152312611920699, 0.04776232237476976, 0.03204296042601908, 0.027638098502892162, 0.06385823569050239, 0.03321996259112512, 0.02505012134450578, 0.05841157654480589, 0.04830154868203306, 0.02800735479761516, 0.05612414142477417, 0.06496077027892874, 0.08084538122338635, 0.02453768704717438, 0.05525307647222954, 0.048119824965514486, 0.05560524326058165, 0.0487335609842933, 0.02499041245168736, 0.02163439001437397, 0.03823617225392692, 0.05839702087424456, 0.01025903004882557, 0.05785656116542317, 0.02556021332800869, 0.03580091280802604, 0.08667928632348777, 0.022646526227735227, 0.0512366536854496, 0.017597012807645144, 0.03229645125928425, 0.03751061804172012, 0.046582539310498584, 0.07772410153261117, 0.02043470207061018, 0.049653203572116555, 0.04282407748002199, 0.005980241778982623, 0.0717490523933403, 0.03061510851576684, 0.12914011555333293, 0.07116290320071482, 0.012528598083243256, 0.0722896576588673, 0.008638455314681897, 0.01605116037441598, 0.01783288744909148, 0.03910307351860308, 0.08685558613750242, 0.015207504132582296, 0.06781565055491463, 0.004417609147381999, 0.06192123983055354, 0.03663303368093987, 0.06675117904500616, 0.043939390415025335, 0.007064263373913785, 0.021909300666002017, 0.025791234802454713, 0.05717420282082693, 0.03730016602804104, 0.0031923101661020833, 0.03206906487203894, 0.07918952814032955, 0.023362885469630845, 0.037301905047629154, 0.008802224803085049, 0.03549950317509713, 0.03285491020388661, 0.00992563624505795, 0.10471147154608082, 0.06680170254361245, 0.06358718995245234, 0.054173252560318484, 0.016324529274096413, 0.039227164440578034, 0.02872846953030075, 0.01165185833439952, 0.04520061628652677, 0.04644384292224723, 0.07102455538246902, 0.05275134357713884, 0.05694253017164527, 0.0310463892040594, 0.059471221700791395, 0.020121502344526594, 0.04263693369143913, 0.0313174253660104, 0.045276098929706125, 0.046370650881961475, 0.026857138896781593, 0.06271063981036987, 0.030692703646397403, 0.017712858708335028, 0.029007969048595237, 0.028322462082630204, 0.015973770172305165, 0.07183336803028662, 0.054024290593881766, 0.012369274777630645, 0.06143836312056069, 0.07532230097680323, 0.03844437962998787, 0.041633864128661734, 0.04431810981083301, 0.019895755385439244, 0.0747094382982581, 0.026427901748027054, 0.07086586026895432, 0.09534324278994914, 0.05774388878395962, 0.026494792715135603, 0.06407989940095334, 0.0441931302268659, 0.062401021545332294, 0.03464294409739875, 0.06404637539338681, 0.031556831672787666, 0.0014040330396739827, 0.045983370453599966, 0.03269210885909777, 0.05773077718913556, 0.05638394099209578, 0.04668237588879082, 0.026539944022172884, 0.022717517680458488, 0.09167827049931211, 0.030666323408724803, 0.02150008330992874, 0.0023732417556006583, 0.0030010618220624188, 0.0193765833448138, 0.05198553910539035, 0.03654036002473966, 0.177246913193695, 0.14136125573948508, 0.15582643599519808, 0.23511432982500524, 0.23754943222288163, 0.10134836854112726, 0.1830116175715962, 0.14377112320113566, 0.20849502675475615, 0.15536065453723555, 0.18414153597287594, 0.1671934953980869, 0.13671286404132843, 0.18785122481565322, 0.10854364252619206, 0.11101183226151813, 0.10923483003411563, 0.1724414734710609, 0.15471088940337782, 0.16411838782650812, 0.14979520962843973, 0.13511857378386682, 0.2373172769383077, 0.20421198238768887, 0.11932729533122433, 0.13880299704690136, 0.15742382124787377, 0.08756926598688287, 0.18150712814061873, 0.0689239499549712, 0.20697919922249935, 0.18859872744689066, 0.14360040816808903, 0.13868354861774754, 0.27655878254482824, 0.2905332988067981, 0.15087979094636056, 0.1288586395281938, 0.15359771768412284, 0.10627404576347721, 0.10596677555792755, 0.1974321808665991, 0.24042668992713576, 0.18620888552358075, 0.10943406652058325, 0.1263154191415637, 0.10799100968025385, 0.12301444586726928, 0.08857390602990504, 0.1626473917595802, 0.13825377329222618, 0.09432816096851904, 0.17936929850088013, 0.2102277950654107, 0.1429496777634467, 0.1298394465758916, 0.14793001535919406, 0.11806412359639523, 0.11776032376914256, 0.162189255859102, 0.11118318314754194, 0.10575161210351414, 0.156052248071759, 0.09050100786431182, 0.10658200544815873, 0.14823698679045325, 0.09206268575883682, 0.15435237557657305, 0.19046870210478384, 0.15782751894045263, 0.12938083570090034, 0.10433510020976106, 0.11051147725553283, 0.1558892245614721, 0.18737464151795835, 0.18513236345062334, 0.1900292434278996, 0.1366729815039904, 0.2114653028547764, 0.08973871207525654, 0.16025736597516846, 0.09272531350894321, 0.1877453208210007, 0.09163886293648713, 0.13773133197138387, 0.19841190006944442, 0.14295724671213858, 0.10223326904158439, 0.08717074704867217, 0.23261394141422165, 0.13199092790244088, 0.1434101425712147, 0.21049306067007206, 0.07388958632345162, 0.09989330710302438, 0.16164896468962395, 0.2281217703655843, 0.17319495158810772, 0.18151765418869836, 0.1945085901646845, 0.11797736413897046, 0.11884509660904446, 0.1601225191787366, 0.15943123207938287, 0.11908470592912167, 0.2836156474246133, 0.1387216997963767, 0.099429234021133, 0.08841250662601764, 0.08289889522617863, 0.10404164256948618, 0.1464691776181421, 0.27316302121166264, 0.13522596398909248, 0.2196309267873726, 0.1461081510229457, 0.15911414828752318, 0.1539054398815478, 0.1591664108057176, 0.11771179976001864, 0.15073285528248356, 0.2357195546069453, 0.14028626584237622, 0.27766222494744486, 0.22356419072997188, 0.0775840453382942, 0.16907338323372026, 0.09841581461049857, 0.12773107301684158, 0.14594095999435072, 0.1167608394978508, 0.3256128632253216, 0.07699686192697094, 0.1974192186589203, 0.13948568863974464, 0.10944315998424446, 0.1860956424066136, 0.11885681775428596, 0.12051928217612928, 0.14374142963319056, 0.13496670451375747, 0.05891279723014563, 0.09910538567290192, 0.20136446421665533, 0.1451344532711852, 0.12181800805152425, 0.18785238926929815, 0.13779738407221534, 0.16066297888755798, 0.11965754051362315, 0.10208125421476942, 0.10371982435425443, 0.05995703252753424, 0.12006201195500552, 0.2145498792730993, 0.18713792034935567, 0.16429043585254302, 0.25464872919744064, 0.13741916646399807, 0.1404093761718081, 0.11474755277196247, 0.14336721100393804, 0.1529155929963435, 0.22273162169562233, 0.1656760744029476, 0.16510921530425549, 0.14873610839488047, 0.14642964748124923, 0.22508266892644668, 0.14234080640298707, 0.11735561484050368, 0.12451754867910378, 0.0794436241830549, 0.25563848415209406, 0.11908238468271111, 0.13542661773822], [0.051998244673614545, 0.013933466398157181, 0.030564261345012538, 0.06431108175386345, 0.0643951905470702, 0.043317369155345425, 0.09329754288398451, 0.06701187110475956, 0.042566767698454286, 0.05481184047136096, 0.07854180846122966, 0.07594147621984444, 0.04159664757730019, 0.06435352302486859, 0.036760422611428846, 0.03339070826768875, 0.02987144398503006, 0.06994951952008471, 0.07786292432537002, 0.02635433240943859, 0.019610305279192906, 0.056588007662925995, 0.06992428458385891, 0.045294282026588924, 0.062416607604151776, 0.07335763019058975, 0.03937765475242369, 0.019943289225921035, 0.02275489319506432, 0.01816468395953698, 0.04750290202097066, 0.019960045484044862, 0.050859416669775406, 0.04112401346285497, 0.007576083364490901, 0.04781633540387115, 0.028218308598884655, 0.003160151949663076, 0.033049883411055615, 0.021279438496417096, 0.06287008185961074, 0.04266499549210553, 0.025017811586299253, 0.04619253160912664, 0.0650352493469273, 0.012846046724476883, 0.04237753632027776, 0.03186742286948908, 0.05102523640098591, 0.028257350354725798, 0.026163339029036226, 0.08602312435546229, 0.03697478550396139, 0.0226847501847172, 0.051513962192280646, 0.013104590865212583, 0.05091927494973906, 0.10702843552515393, 0.03240308303746485, 0.02405796278898995, 0.10542498285611791, 0.029649293808747205, 0.024851555184971903, 0.04017074344559543, 0.015723703752061533, 0.09100621986773708, 0.07538521211714515, 0.022422135244273854, 0.05041705451965813, 0.08442472786672654, 0.05481640252495005, 0.07308573026450411, 0.0355753458796009, 0.015803872938117674, 0.03172679785488835, 0.05086828030705933, 0.03388313043321814, 0.011484809989680447, 0.02989614457492867, 0.020883978164244085, 0.07839859598466466, 0.017872722105934255, 0.04676424004437943, 0.05354794861388303, 0.03881611996480534, 0.0013949395760127735, 0.009509447488873717, 0.011661595311917124, 0.03895603060241669, 0.034616966055886406, 0.0009038565082347863, 0.06664752734885102, 0.0074727199089172636, 0.03215001355255804, 0.0042834551817166715, 0.016343415256649736, 0.0627482125926162, 0.006871205865360436, 0.03350478259005374, 0.058965511740215366, 0.011008470882511428, 0.05300704457406556, 0.024870339660875262, 0.02967262884692079, 0.049781841225922115, 0.03716630748503151, 0.032757548089589805, 0.01864714123639128, 0.042922106090812914, 0.053918497681978254, 0.04317334845602032, 0.010220447945738993, 0.01847353996708989, 0.09732819958439759, 0.016864186505817117, 0.0703448132281342, 0.042573509272187955, 0.09594151915441598, 0.060473253214431394, 0.08358346373443643, 0.04949444717156792, 0.018916557122382428, 0.021412663101669283, 0.05932890554709781, 0.044990321320872155, 0.013682728693369898, 0.05013164846346744, 0.024704881906208974, 0.048634873537887494, 0.03936895965448311, 0.03890785899373793, 0.014741540728737752, 0.013124330078191577, 0.0076103653202974995, 0.07873747497797012, 0.1024958226949938, 0.04663622675223216, 0.03561188444314945, 0.09404879168517168, 0.06600623514743582, 0.1131998406602971, 0.1100272254177159, 0.014869887269132081, 0.05887762230310229, 0.0449233039492561, 0.011277989232762447, 0.025526469070163947, 0.024713711069536307, 0.0021116617520625194, 0.014786703527093896, 0.022600030436390833, 0.014560710462260873, 0.015892255544332008, 0.021579199125088995, 0.06771710866521444, 0.08893019054085018, 0.09580550024345999, 0.008857211721460185, 0.034726118263337886, 0.06822742281421539, 0.04334435077203859, 0.02748682678136374, 0.05709210117798179, 0.03753032565357224, 0.04579400884047632, 0.015473899716931968, 0.0220569679438467, 0.06538600270305911, 0.05215345025663415, 0.026359922936066028, 0.06517037959589113, 0.04205163485640961, 0.03513031391306751, 0.06589018048778658, 0.04208825385919021, 0.02276690736893685, 0.05577181375795796, 0.013173767647165205, 0.043642807136019396, 0.07466185657728104, 0.011961984132686931, 0.052580643865850665, 0.024346959882325703, 0.061885042176131284, 0.05589428823441268, 0.06873783655464649, 0.009557284891695507, 0.051877716060487494, 0.08374032789781209, 0.05339624405267739, 0.10486321824212229, 0.08914627330077272, 0.05857559596939434, 0.006274560789367365, 0.06605314271103951, 0.02219850268785752, 0.05625732964084995, 0.046785970128351645, 0.02009242930780015, 0.06900191472302522, 0.02502029371117392, 0.01683094978122221, 0.06548404663560853, 0.04764741301656731, 0.035897558630113645, 0.029346045564800024, 0.06443927890711254, 0.06599966977392474, 0.018239511597541072, 0.03983483304299655, 0.008653431375991673, 0.0836429121573606, 0.033785867910351486, 0.04738687800483839, 0.06083330687796397, 0.02232488421272607, 0.049514514844744444, 0.03549712830253186, 0.006632650394984071, 0.030008288355724468, 0.022090555153666966, 0.045289352250796173, 0.0752177759404144, 0.09049123258239801, 0.020989734686971195, 0.08989279533946708, 0.014666796402795421, 0.018590552236644492, 0.10429159407654118, 0.036788024759340676, 0.042581580008470246, 0.055869700642482895, 0.0476587396265278, 0.03861220268112037, 0.049653548311682484, 0.09571285723077674, 0.04859160489192413, 0.06325309134779439, 0.01707110110850584, 0.04290904429170393, 0.10972125756163752, 0.04818034591153265, 0.07275224453018558, 0.04449164404744103, 0.03526736321228166, 0.03258735782677128, 0.045968596447980216, 0.026136411038497766, 0.025438811374647964, 0.07498879992072621, 0.05561529050370859, 0.03276234763043542, 0.07490157314966764, 0.0625688292747063, 0.02413949944199093, 0.0724373287671516, 0.014217437954709656, 0.05943986955249022, 0.0341230730015424, 0.05047013675193152, 0.056474009949353435, 0.020429636314210874, 0.07526882803968846, 0.05227258075929938, 0.029793726280331615, 0.027587471582416086, 0.04321022026781594, 0.04258221969188702, 0.035483265941542004, 0.004947124332595136, 0.11413924065568756, 0.0246113732141713, 0.011816093221216673, 0.06268843858232422, 0.020380170016940084, 0.09597591650221618, 0.05141144047581381, 0.03490482359343479, 0.06318778235224948, 0.014784361213265408, 0.025667731852961645, 0.04877362355229355, 0.04935819843423463, 0.00221770053030923, 0.03825347818013641, 0.03908733424219874, 0.0044777676380509815, 0.021551106680905627, 0.014558706184728973, 0.050645356381972956, 0.027066790348579808, 0.029914051880158728, 0.04711876255309871, 0.05853451833489442, 0.053745434589443676, 0.045035738843463125, 0.09578205029209776, 0.04227545510436739, 0.022927529193581115, 0.07331445347517729, 0.02589721157546005, 0.017092308337469737, 0.0896243045046445, 0.019431498442446033, 0.02225196604887324, 0.05887703624584022, 0.02959440743941213, 0.014477599498575494, 0.026478344807401303, 0.03721195866443938, 0.058180003487054384, 0.0682491873721442, 0.03377236561068604, 0.008591316967091013, 0.03505393877745636, 0.0225185378334455, 0.07438957360723326, 0.03132785373787967, 0.04056138699994453, 0.03217598010275153, 0.015853758668527007, 0.017877307142161073, 0.016876677569422512, 0.023653567956400015, 0.028264091928459467, 0.08418862722934255, 0.0475503726591987, 0.01159316067764115, 0.029366754836613135, 0.04194034143320976, 0.05397708042554798, 0.07193770154469437, 0.05754664412609512, 0.05007377818166729, 0.0737450255321399, 0.06918771402730096, 0.07013007878295838, 0.029420942150717302, 0.05989901668902847, 0.07743871079817896, 0.0636579305113804, 0.06663615860405468, 0.04096026599947964, 0.043850363337344704, 0.015680329769008582, 0.009417938286318414, 0.056022033395786444, 0.028060109527300925, 0.049473663206182183, 0.03037347863878935, 0.02726880581899276, 0.02183708538781972, 0.1384414648336749, 0.12150415715070502, 0.1486096732438572, 0.26355376587279383, 0.20810211558015118, 0.1836558668723991, 0.17191727014799274, 0.18903455486701382, 0.1415663987638489, 0.18845482549119383, 0.17991939559578898, 0.21684555366875666, 0.11362534887608021, 0.15083353455749252, 0.2007747450543027, 0.13862457516933643, 0.1726372702227485, 0.12758898668952529, 0.14754079672838413, 0.17928069277155786, 0.20069876445397256, 0.1477330847973785, 0.21327930712892165, 0.11416440664400017, 0.0914301039771207, 0.16929740266453835, 0.11435917683786924, 0.09199017553680366, 0.12008220603268956, 0.08944667169764157, 0.14519563305281824, 0.09827234166403932, 0.18730072935502376, 0.12028548746339737, 0.13378299141843475, 0.129548900069729, 0.12367968597719747, 0.1483024106991868, 0.15392137451037285, 0.13752531560678638, 0.12731249023589397, 0.1379897947152776, 0.16025632409559143, 0.15445195168497103, 0.160275399684906, 0.23163630597053037, 0.1446854644605229, 0.2021545153712073, 0.12443774530003149, 0.1548788005546216, 0.14607579146902408, 0.22350678010092628, 0.23854217492043975, 0.16661272414268988, 0.1784637059655882, 0.22656180084713046, 0.1545820947015478, 0.12050912385025334, 0.11455518043329639, 0.18310460532384534, 0.2510750362829816, 0.13224108625323544, 0.08501218706970254, 0.06655577299815994, 0.13370803737592313, 0.13422290974807355, 0.19534463723821027, 0.10554133629005764, 0.221644910653272, 0.10390875695814049, 0.131219431397415, 0.13893062729508648, 0.10122886648581875, 0.19444829904504363, 0.17918684700083348, 0.13497097928437496, 0.17890730151726356, 0.09844634321428115, 0.17579791917195245, 0.09187509380881825, 0.2076302207405529, 0.1465825739526941, 0.15063085833624487, 0.12425386121556645, 0.166500783375194, 0.2517869771127739, 0.21571635539012574, 0.10735980685680144, 0.16060500135344846, 0.2587307827366937, 0.10387180087667319, 0.1958955004210434, 0.08450175034663371, 0.08884546887730399, 0.2583469420431122, 0.10965910484834064, 0.1341629250636024, 0.21156737640980752, 0.1333600342754395, 0.18384096903666375, 0.16903195319877518, 0.18960990221990695, 0.13277976863807248, 0.12489755893306387, 0.1303918419345733, 0.14045220048677537, 0.24538744631553852, 0.13201279205179986, 0.13165135176912432, 0.21089499636042505, 0.18601054535998454, 0.08372236313598772, 0.08213070056010639, 0.1623228615930965, 0.1238319765956652, 0.14906561813287197, 0.19564275269306478, 0.17194057454264935, 0.18534749626151978, 0.15447645117678951, 0.153670480715171, 0.1258679165414745, 0.1798585682146011, 0.1889502392300675, 0.1263749288515218, 0.11723471084429372, 0.23943036193809203, 0.10288437482930961, 0.18132956428152902, 0.09217227463640514, 0.150178728565093, 0.060703577548866315, 0.1621133518675643, 0.08049131836742163, 0.23747510637246796, 0.23470272610504783, 0.14618892733368183, 0.05951360934564184, 0.18550567809612523, 0.14470116926297066, 0.2291920258393211, 0.1497085804059621, 0.08165685219630119, 0.08703476644211239, 0.15767543516572446, 0.12016583985138325, 0.0908631912522739, 0.08089146141203181, 0.09610911620961082, 0.1593429481069888, 0.07788510257077795, 0.09873528859668201, 0.10995022592044647, 0.10143736497529092, 0.29614841685660426, 0.2237033122970212, 0.14776394281896854, 0.144628421553681, 0.13780194995624406, 0.11631937367060494, 0.16930431277761537, 0.1839637882526844, 0.1654750376098579, 0.18045780218897328, 0.13466040723987166, 0.13288360419532946, 0.13439981477154841, 0.2002242955589487, 0.10265192843132442, 0.10529343023776047, 0.11672808923908781, 0.08406578503068417, 0.10205847075990132, 0.16327466455198106, 0.12229033956123937, 0.08834763430058958], [0.03479922220351235, 0.04395990624963757, 0.030871433874351845, 0.026187591457499132, 0.027249684264402718, 0.03214796426736059, 0.03726715912982341, 0.08566071880200217, 0.05280894572816549, 0.06484057108360915, 0.016874101598777117, 0.020182475282420075, 0.0950990062988093, 0.07828898412445862, 0.044095155242229664, 0.06712789512089185, 0.029908756297382138, 0.05364315802111261, 0.014283722754748119, 0.043596477968798536, 0.06836057655633458, 0.08104013609549693, 0.030593598682072856, 0.03103636111313057, 0.03004598371203869, 0.040004172948219126, 0.04504045028419745, 0.06341370168111979, 0.0741315551943356, 0.07184545689773175, 0.05400340703706588, 0.034651524282150695, 0.0444560247894016, 0.07478723452696878, 0.030722634701599038, 0.026624836140282215, 0.031640101599717335, 0.010879037454874526, 0.07660215044574392, 0.04193598622336023, 0.050054557035647096, 0.02447103356732236, 0.06053357114714961, 0.029872884230327704, 0.0838516481340893, 0.03560927591376728, 0.1429958881870393, 0.03556608387659635, 0.043191079561027794, 0.05650624692920716, 0.02000833775157169, 0.06067959899683634, 0.01433575736178506, 0.0383381117435713, 0.013960448014850338, 0.025693905246894688, 0.08884238920384839, 0.04129278263257396, 0.07457645309548225, 0.06549651854701581, 0.0583256368014601, 0.03458685880046218, 0.04828230072293551, 0.04683973800931727, 0.045273616804831454, 0.011515657477561506, 0.013257411999567864, 0.03603364648898283, 0.035876364807688424, 0.02976497308531356, 0.017422149408488505, 0.0407909682290929, 0.008165300260448169, 0.06730522149272504, 0.03188567108384544, 0.08213233998826436, 0.06257769291199024, 0.040165928582991325, 0.02116005326951704, 0.05062977798403271, 0.02695272560231388, 0.0635013114961405, 0.024073410951983065, 0.043750040293220556, 0.024572955819988446, 0.03280989487745589, 0.017576740205948873, 0.015141204010785348, 0.02521801525877128, 0.027636064539453196, 0.03713960165999109, 0.03279507490656069, 0.046902453797238494, 0.03359752136372751, 0.013476232566209811, 0.056823326890627225, 0.07327208881296458, 0.021541321822892756, 0.05578607831510806, 0.0622250932839609, 0.09214938392922764, 0.04421169253727121, 0.0761860880940672, 0.04954852148770325, 0.04342409286407694, 0.04962876919777163, 0.09182594926847566, 0.030492484652166887, 0.05979550671913932, 0.059484137943194765, 0.04624526910183411, 0.06279897357847902, 0.016406424073201996, 0.04252884251576278, 0.013251037190427944, 0.05365312865544712, 0.01724778971214208, 0.018862806478395097, 0.09546199407909187, 0.09347952707039733, 0.03959163460099409, 0.05459090837487771, 0.020386427040061644, 0.06228651438329009, 0.03518409711579162, 0.05254795872456124, 0.005833968302355178, 0.021121314118405985, 0.033834571950137615, 0.021855400634869453, 0.07189384301102932, 0.008279238602206593, 0.022690892294650118, 0.026844611443999796, 0.0317174113625961, 0.00969608087137702, 0.10736681656130861, 0.021564260410565524, 0.022493373760352695, 0.017281775287682974, 0.045030215349529064, 0.03799281293346036, 0.07386786006991902, 0.04284581905531307, 0.02973086493570478, 0.04740781135736935, 0.04382485260946616, 0.05942200821253562, 0.02375122501454767, 0.030903923663220582, 0.030614457341031204, 0.06893649847517092, 0.05193157970244366, 0.03141483153036285, 0.004216932894421681, 0.031236670122692184, 0.008667930547568587, 0.010840837438140186, 0.034674775050652605, 0.04965443697367465, 0.05968340890361898, 0.0292888954056487, 0.03583216536489706, 0.02843995315713748, 0.05529518066454799, 0.08913602304434584, 0.02385668659342393, 0.010145900887437165, 0.045523756003427895, 0.02924964297562838, 0.03939070889065343, 0.037296959950077924, 0.03848446518062584, 0.05729996381447681, 0.010956940935894607, 0.017469621961936355, 0.03394003927467331, 0.03715236851524922, 0.052035311837830854, 0.04274994698202899, 0.02090994471443757, 0.01800277510717992, 0.005845328907467305, 0.051207247400476094, 0.04135415393618807, 0.01637098293060497, 0.0423798154318525, 0.020001483179869193, 0.05420723622063956, 0.044890208950927185, 0.04477522298393231, 0.0568720730652492, 0.020803755352033243, 0.04102583546491881, 0.029180018989849957, 0.027866861933181365, 0.029295985549387914, 0.045695945755728794, 0.04031024422616728, 0.04172893180962532, 0.019743217703615947, 0.019951896223750328, 0.07686819746008805, 0.030682177598317786, 0.06782219294578799, 0.1423339422551855, 0.022192427610617974, 0.039187948399734114, 0.04344621748333016, 0.07630424949550822, 0.033477686060171936, 0.056872076895688815, 0.036019872228104266, 0.06897876354595346, 0.022889544639075478, 0.025523351092312126, 0.11196109180849408, 0.055482665362257155, 0.015605050139129164, 0.05036097305316118, 0.057573552964435476, 0.0416209363949395, 0.012551780861441889, 0.03749597044060788, 0.048549841608731985, 0.06634784907463097, 0.004151768497972479, 0.018862831376252637, 0.041862675439446204, 0.053762732854773926, 0.01790026488203195, 0.019367288783072464, 0.08072230153747144, 0.06976615637540817, 0.055583968998924385, 0.035614017998018575, 0.006836630402117848, 0.07237294673799508, 0.08107733732509999, 0.03574707980958685, 0.10736572105557689, 0.05344044732590837, 0.056249661100727905, 0.04490852228275711, 0.015283933851958044, 0.03227561366774383, 0.029612619264592088, 0.07733131293207407, 0.052798714623936725, 0.03427349819591449, 0.08353326199275833, 0.009384773382466407, 0.03980727686036018, 0.04250171534236401, 0.0015034826238632143, 0.019843623102191957, 0.05472266400653509, 0.024954917682935635, 0.027364909633873936, 0.03908588250558223, 0.03697526430891406, 0.04266655831147106, 0.021294641511274442, 0.005516674315121266, 0.047299835094881636, 0.03311072611400197, 0.05252674191949829, 0.018486762644662973, 0.05626285696522363, 0.023886313128675667, 0.07904625437673062, 0.03946005133911967, 0.07116267337433754, 0.03872547261116486, 0.03537462318256017, 0.05063997461430488, 0.01948340856019528, 0.07257002285651623, 0.05070349862498622, 0.008802202778057227, 0.0063938756319393796, 0.06325634339103295, 0.09183823731878112, 0.029498567924864834, 0.06723942220090859, 0.06844302293874564, 0.016625816332957438, 0.023820234214766853, 0.009251631131666082, 0.016134158340132525, 0.05369415649423196, 0.08249822358090071, 0.013195213320995531, 0.018100353641315334, 0.08308349177241327, 0.031140656323142113, 0.09842304648050378, 0.016633641921103965, 0.011210043937148107, 0.05035248096852053, 0.0352795938059928, 0.024973728971916343, 0.026414432007098393, 0.02284091337764215, 0.01738840515064376, 0.037556782500037265, 0.04666574028951507, 0.037467471969824646, 0.06904896784333453, 0.018336257011058833, 0.028303284986665653, 0.02352514672243307, 0.05955151537613523, 0.07951257975711938, 0.03498746149782692, 0.006361260874977997, 0.08078495220791909, 0.06684192215963718, 0.0542720127850771, 0.050136302447607445, 0.008318006481614806, 0.009567901912716129, 0.03057549602442211, 0.10804314196350114, 0.03901171753363263, 0.01717941828011986, 0.0347351772530425, 0.019556453128555612, 0.03375059339187799, 0.021795404459079428, 0.03157275672551365, 0.05241955089713297, 0.08210613212037472, 0.06622866877625067, 0.01556047627086481, 0.03829956219922151, 0.033807850803338715, 0.032387156069519064, 0.03794394418477051, 0.05192041780138689, 0.0695229541029661, 0.025824040602592212, 0.048183820120269255, 0.010319550994843727, 0.057339110907407544, 0.0077796846369071115, 0.06144159218116153, 0.057048744431907134, 0.04606111688659557, 0.006067593039328894, 0.005832074628767348, 0.016749828730920152, 0.12577164227203017, 0.2028400568111289, 0.09145854882174924, 0.14026162845473136, 0.13072726587134023, 0.08181268980185832, 0.17275463489274825, 0.15966862740535892, 0.18624041770254413, 0.11844556643477372, 0.10951851239247669, 0.10645154067465376, 0.1761269692571894, 0.2033497504289112, 0.10586352988837228, 0.12423670084606256, 0.07266309487843707, 0.1186827932214064, 0.10739965108974327, 0.12376573297285265, 0.15460207427461303, 0.21538399580505588, 0.12075394256821564, 0.11572894204648272, 0.14076865608653716, 0.17867327697815436, 0.13668012144344469, 0.16540176896077974, 0.17500203042741747, 0.22795971212608201, 0.18911640370084395, 0.173516723838064, 0.11805746629233323, 0.16409047158254733, 0.0922964191845348, 0.0890317278343343, 0.0947554158647695, 0.09310086513118399, 0.13452683214939412, 0.09896978811030427, 0.1981390348725742, 0.1314927256035228, 0.14908683876837456, 0.16253684527210652, 0.12821046785721857, 0.11839941729821506, 0.14233185849603147, 0.10479925756132412, 0.1375974657674951, 0.12112616170798579, 0.09660276028537944, 0.08543479947313186, 0.15579608359163807, 0.12014727754097794, 0.1120716842612432, 0.12561226534026285, 0.1585085251398625, 0.21679431770838078, 0.1324100699275732, 0.12186149886298565, 0.18240309861158172, 0.10360197704886237, 0.22284583008337408, 0.16003196758608665, 0.18147201067016971, 0.11220268529629517, 0.26238131426995803, 0.1958271194129221, 0.08697952384189253, 0.10608741908424324, 0.12067705798413485, 0.2230106002741283, 0.10433823350937137, 0.1994048725933798, 0.18208250613702884, 0.15717458220258837, 0.17130067662125634, 0.13388348683234186, 0.18150142844646208, 0.1576347252534282, 0.18766561703335857, 0.1411854385608627, 0.09785480842354799, 0.15665526652047712, 0.2113474478885051, 0.12253704285549542, 0.13732032580000741, 0.13470854820503345, 0.11739304589648401, 0.11947711148569662, 0.11804351583123208, 0.1403577571674701, 0.16331653891792222, 0.13801467725105826, 0.13180905862921669, 0.15321638975893298, 0.21876152424562365, 0.11212906424677181, 0.18466972295315037, 0.17859565694966625, 0.25647767218610934, 0.10813299641613999, 0.19166363072731804, 0.08298970728872285, 0.15624905605950665, 0.14822230854582402, 0.1821646307625117, 0.2180256355073183, 0.18638454948461827, 0.1771928733515163, 0.13646169445447384, 0.1413473895480556, 0.07832367258567004, 0.1752991499679704, 0.18551824193808342, 0.18439022343485587, 0.09680417246155201, 0.11306744534522296, 0.17108653972466148, 0.12063315348519434, 0.17504477813359232, 0.17927146907294952, 0.08152744462413174, 0.1305211882197088, 0.1445179823185167, 0.1329349780515317, 0.24614789583269628, 0.10824108376137673, 0.27236172388638225, 0.10166622608179048, 0.1465926709915361, 0.1258432025450372, 0.19210955518628323, 0.11899159560280463, 0.10279173181662637, 0.1149099404292722, 0.1679020501192539, 0.316007714117727, 0.14542018874518334, 0.11967625604161333, 0.11450159258299297, 0.15740938815138034, 0.21808626370564585, 0.19412914681578838, 0.08383764404683344, 0.09555095220885931, 0.09744872053664538, 0.2688692822571724, 0.19832404510628796, 0.09398836266970444, 0.08928814512347022, 0.22479291915172533, 0.11964833979765255, 0.128532623151137, 0.09532553849801903, 0.10782064704765236, 0.10004329945771925, 0.18478336443583812, 0.10263192587562146, 0.10151802637283841, 0.1580676568611976, 0.21552916946670703, 0.22576252599397015, 0.17750537593758878, 0.1604613292241289, 0.1693534956223542, 0.18930654672365035, 0.04524333717962427, 0.14409260433768073, 0.17723091727783605, 0.16255798929881665, 0.17357364417083804, 0.14452008139942923, 0.18108213320374492, 0.1536535501720444, 0.13395805783089132], [0.005840863572478656, 0.033842504790593544, 0.012637878610422055, 0.04046147381285987, 0.0449341670760224, 0.060525806846037034, 0.06198774392326033, 0.0205559776194634, 0.027762505436135877, 0.022518798303339752, 0.034203297728973056, 0.028421570877394373, 0.032259219386164224, 0.018247473166294156, 0.04662211541266692, 0.04979444337227652, 0.008139678449820607, 0.03810312193367751, 0.012598305381083441, 0.05066928896872748, 0.01358809385208353, 0.008986396170521696, 0.04048818729877953, 0.06919643210787928, 0.057008011536973144, 0.013093254679153043, 0.05759111169965998, 0.055281609416969364, 0.04401803317089235, 0.020824317151920933, 0.0408330264561359, 0.04287005041635806, 0.043673833696952755, 0.03168418038366062, 0.012486837672880821, 0.07914393058707637, 0.016058792525361625, 0.01045259652704361, 0.04466758380013128, 0.06199103044045549, 0.06350914091472665, 0.048194595146924264, 0.033097626010496775, 0.014368547840164074, 0.02392838284703753, 0.05199971556242916, 0.036804055149156245, 0.032308203048042716, 0.023771179689755364, 0.09206661578988837, 0.014424926165731685, 0.032583010277800986, 0.03425604288255976, 0.05966804117985791, 0.01671634111253004, 0.01809185006535582, 0.03013270869550686, 0.03054832097052807, 0.03179310659517444, 0.02623316602811458, 0.043478324228236755, 0.0505375869632248, 0.043113984302767826, 0.07229433845608466, 0.04116479232306442, 0.020884313327710957, 0.021622391162259925, 0.026040104210316658, 0.08519425552578704, 0.06803392432630062, 0.01761672233471707, 0.025316645248582768, 0.042043246193638736, 0.0002605128969251734, 0.022553881299832178, 0.0364563393316442, 0.017364924555764567, 0.027948044270517367, 0.0863046846502731, 0.03876172772218143, 0.02767796571847172, 0.08812926859865267, 0.06360359955579042, 0.01999934196412083, 0.036339189166263226, 0.018349152186044285, 0.04227378886313208, 0.07619920351933088, 0.008918609838151645, 0.021643033401379665, 0.023302996546150218, 0.11427201901472385, 0.0130496671490912, 0.017146440110199394, 0.10527883626280293, 0.06808115364683252, 0.06570925350270926, 0.07398122576095405, 0.08451607619081775, 0.05740019492805005, 0.0383652082734531, 0.0647793913019761, 0.038496347204331434, 0.03889252574393346, 0.048466981538841804, 0.06262512907626168, 0.021983034713494203, 0.043798300002010605, 0.06314974225636932, 0.016059185145422816, 0.019622970627801075, 0.055868777506534135, 0.031028296122507706, 0.07496493628188487, 0.07214420820556341, 0.11880602612490616, 0.020039565410585176, 0.035384448260189064, 0.06615448848254259, 0.029880512550833727, 0.041457981832565806, 0.03491015173494816, 0.03897308755005079, 0.0339852997492398, 0.04267153788297888, 0.03262530599210051, 0.025271095575824864, 0.013266981395352031, 0.04982040609203039, 0.009963501098325417, 0.028538108172435916, 0.05709956287436428, 0.056013299993449644, 0.030710220246786074, 0.040935111502485896, 0.02149979219651751, 0.03085227210014578, 0.015936550748113905, 0.041844147602997483, 0.04295516278474562, 0.021354020986285423, 0.026637126105807485, 0.041765133294487194, 0.033807950394768874, 0.07764455862343311, 0.017597252210121483, 0.05028450981743875, 0.011875539728921029, 0.021503109357229645, 0.022716416429067333, 0.053068638043177706, 0.039046425147042166, 0.08410862466740994, 0.0487642542969796, 0.048452563764106844, 0.014364788263675668, 0.015062802572614484, 0.0817206213551183, 0.03602285997100896, 0.03273862188742046, 0.02000986992742025, 0.029678217458328413, 0.04510614615414412, 0.024539389677586097, 0.044213715009391315, 0.026998692792990518, 0.04207009374494514, 0.011698475742201892, 0.033499412313704534, 0.03895001298177146, 0.02454647599088569, 0.019792844879350836, 0.012395574576071194, 0.05530066968452546, 0.020381351707563288, 0.0936742053337155, 0.019421803599764264, 0.030553325439893433, 0.03750367345468652, 0.03813651570629689, 0.03824857521742102, 0.039694527870104204, 0.039069901911481734, 0.08117656869393203, 0.0747841242099962, 0.0030263805491549355, 0.03256223014285488, 0.054488225779946775, 0.04480377891130986, 0.01829347483092739, 0.034230558967758576, 0.07080605944558498, 0.04622713580066639, 0.05051242097491219, 0.030521672602081974, 0.032020713232697985, 0.051877873108511975, 0.02842375231275876, 0.010284724637805935, 0.06602513453652782, 0.03953059271518742, 0.03783882926067999, 0.04842016590578903, 0.03652121165707227, 0.024922437470165953, 0.03535311909452562, 0.025371476076543335, 0.06331183880026783, 0.01571929874649692, 0.03368527673545384, 0.06931247910664928, 0.028423470775446588, 0.03133225874344428, 0.01090106248269759, 0.03448984525617092, 0.04710098548281578, 0.03152905523987307, 0.04809341791476454, 0.0380161939369094, 0.04965936291902777, 0.0651886278102475, 0.12034459880763486, 0.03474662260663125, 0.06368188991121228, 0.03208667148775872, 0.0035739892947247195, 0.026841112337405645, 0.021837409059967727, 0.016424235617441517, 0.01792635209107351, 0.03264821585147612, 0.021508759255671216, 0.023123774106704423, 0.028226582348466884, 0.029901922793097557, 0.05929793261231915, 0.027225198179122903, 0.036072475655424985, 0.018531176592073133, 0.024746917150614244, 0.014281782637079878, 0.04739167371524438, 0.018686836082187873, 0.04210040018322968, 0.05940227378760615, 0.08971795875338778, 0.025072314911672187, 0.038104378317873326, 0.01772941961403816, 0.05154541393201198, 0.016208198822794423, 0.005430029770885144, 0.02937564911741403, 0.03954340553572101, 0.07835158116875157, 0.02976263268670488, 0.025618041474973003, 0.07386162411421537, 0.07395569971131702, 0.007104747769077339, 0.03107728744526544, 0.0713717770732699, 0.05300179687178424, 0.0726113762826689, 0.018890462252461625, 0.01875764750424893, 0.05586038118288402, 0.029449806428484382, 0.054651168851001616, 0.015280275782119605, 0.046537596762420676, 0.03380858624774603, 0.04474006337864746, 0.049012570206316254, 0.03501260450350181, 0.04017194237319693, 0.016816106827689276, 0.06467247607126352, 0.04522266429698756, 0.03573930784759503, 0.1118961658569113, 0.030652231221357663, 0.02983037401140938, 0.02659649854796308, 0.07339483908107204, 0.09694124091296427, 0.055551172774885936, 0.018642630893737078, 0.05890078880193253, 0.030737847292555437, 0.09301394479529512, 0.02076436311096674, 0.04478046302533439, 0.04602946979444354, 0.06818420013352748, 0.041037269327188694, 0.01752966984866127, 0.015768294857304185, 0.0680048359678157, 0.0019111979687999514, 0.03421734395106474, 0.04631418637150238, 0.01335932180330518, 0.04692581947892905, 0.043180400295363325, 0.011847866717876207, 0.007270571330727469, 0.033453638560228774, 0.007175001383368527, 0.06573347720287501, 0.04202742264756272, 0.027016414321898937, 0.007125230566147836, 0.015804684991317413, 0.07920373141044572, 0.044951561102343184, 0.049328378461782015, 0.084367286594164, 0.01155725700945984, 0.036041970034280134, 0.047197420630724206, 0.014763067799410032, 0.05320918836420583, 0.036391888354574485, 0.034193116420459364, 0.024608331845111908, 0.023992071566622586, 0.009314471408875, 0.08442250621174613, 0.03299973529553221, 0.03719848700829091, 0.02743643543292438, 0.060177891845664674, 0.010259856466173885, 0.0586755819348318, 0.027204408468077743, 0.05323003744706512, 0.01475381058445501, 0.048248822680644454, 0.02102695506877236, 0.05939219973140186, 0.05870308832175309, 0.023251479048462167, 0.02982001075701368, 0.055741691180775245, 0.04805549273207303, 0.016815501618229093, 0.029817304551421158, 0.01936626031003412, 0.03812935661464449, 0.04556826188138897, 0.029437958878735383, 0.13274198518164698, 0.18899462636440031, 0.09222652132232344, 0.13420201086949918, 0.16796327586616241, 0.18640937073336494, 0.1935287483877713, 0.20663271297610578, 0.2549976975687089, 0.23204532031330372, 0.09948492095234895, 0.10368072322659916, 0.16389349505545633, 0.07129316879135948, 0.163331676815306, 0.17281791375529382, 0.1107004481638151, 0.10238285536967939, 0.13987227192809507, 0.18240977889828144, 0.16644784669962623, 0.07705980371082984, 0.1419147695865362, 0.17352053895592692, 0.21151883707892513, 0.07555198179738176, 0.21582904692378738, 0.16010520559164787, 0.09617647065991357, 0.142230152663204, 0.19742183867962132, 0.11660507084020685, 0.12251872569322587, 0.1492682024235687, 0.15354668090660728, 0.15731203369796276, 0.12159056420768462, 0.09457093423172351, 0.08984862270975306, 0.1950246729557553, 0.19301078102040678, 0.10591148699243223, 0.15169591973385504, 0.09105939403056137, 0.17384994144160903, 0.20013855499846323, 0.11651347736797987, 0.1792953556944286, 0.1193391390505337, 0.17566802130351145, 0.12133509686757481, 0.09013044347445812, 0.08564340521491344, 0.15766745252955347, 0.0813117755516883, 0.18949393182992938, 0.09303188657448178, 0.17363050321657814, 0.0662035487532135, 0.12631344263471905, 0.1578561859505792, 0.14918531171016156, 0.12813712259934795, 0.08648927353562848, 0.21668810727855853, 0.13375879836178597, 0.0895075603658634, 0.21568758112768974, 0.25047086870237706, 0.2890749431906208, 0.10932530501797315, 0.1428884366947797, 0.16146590031923788, 0.12112384812245447, 0.10355588919933766, 0.10340793463852137, 0.07788920880205209, 0.11335506539551482, 0.25601550666314943, 0.16610825524455117, 0.09664127152533301, 0.2043938210173961, 0.14880668041446518, 0.1195406814616534, 0.11099264175901491, 0.12779848109329903, 0.09503002008122784, 0.23600953420804394, 0.08917309403900178, 0.12319983148406591, 0.0856728766173605, 0.11931120748481444, 0.11630697070711082, 0.16984766829879056, 0.19705341167507634, 0.16574025724924382, 0.18309541226875398, 0.14052337005494103, 0.21860072239031716, 0.1204697086265491, 0.17495600386492668, 0.16666026755927071, 0.1307476438101261, 0.1272935218988888, 0.201461159834458, 0.1691608857964316, 0.07620219892311482, 0.10428148171594066, 0.13883053024689998, 0.25799702372281785, 0.07635784500669088, 0.0976477578402527, 0.09422046432812368, 0.1555428915326634, 0.22866452833817852, 0.18962864073053484, 0.1529029219020759, 0.25782986333773983, 0.18967665912162876, 0.09989097053485532, 0.09970491842156458, 0.08287179869629684, 0.3383929871263043, 0.13057703602938883, 0.14499920810903275, 0.11228932984053128, 0.1280154065499383, 0.11596995330746136, 0.09959626417126387, 0.10253984976800219, 0.1404305508420352, 0.23600070887515623, 0.18790440663935679, 0.15013291650722105, 0.22775702058307587, 0.13183423227840854, 0.08117632354579626, 0.10005479077658347, 0.17227906283111344, 0.1023353196139778, 0.1317199472818644, 0.0989665705410223, 0.10810859651575166, 0.16706609497627906, 0.1514790708860082, 0.1856140795374109, 0.1669095525698316, 0.1551642755587255, 0.15590929606508824, 0.11686407750652683, 0.12173614389593564, 0.10472361403968065, 0.21289854610879577, 0.19387203238664136, 0.14142142428505805, 0.15275954088616758, 0.132658374345591, 0.26733505329297436, 0.1505550309534996, 0.1442405205941008, 0.1802422863341147, 0.24435935632115413, 0.14227492284149895, 0.11161675060828848, 0.0711563301663245, 0.08385921708278118, 0.14084794618670018, 0.12614126437373702, 0.09287844682412763, 0.14709882528310822, 0.12474902980630437, 0.12535417031857277, 0.10736657907405209, 0.17187709649724348, 0.18730406949837364, 0.13623674039638814]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.021777853384734164, 0.06069361074497143, 0.033742319642295765, 0.030333994467171933, 0.025384254423120332, 0.03647985057004037, 0.01760507971348782, 0.0034059208560539714, 0.033823881193154284, 0.058695159311736786, 0.0494817913990588, 0.014872605923653371, 0.057671769266767856, 0.03333590233758573, 0.02855049581417153, 0.0361260098795737, 0.020226096328828606, 0.04430331282257553, 0.021138298287687284, 0.014714515061988948, 0.06221466682731144, 0.05523089822682162, 0.019957352684991016, 0.04434714071272362, 0.022866087026834007, 0.001962347026076919, 0.05127847059479645, 0.008703167719255772, 0.08960196538077247, 0.050887884497041666, 0.01763950004392574, 0.04316271898607093, 0.0825331035640932, 0.020798951980748007, 0.12518678010711748, 0.02023683879674683, 0.037777645648607326, 0.045938041031120286, 0.04868474969219777, 0.07002412116215115, 0.008097639374975717, 0.05162744662694393, 0.0680768558935773, 0.022361570248200048, 0.02649869593310981, 0.021149555949734587, 0.05222389970215098, 0.0349814247249836, 0.056286188172957594, 0.029883071284500823, 0.05824852622144165, 0.01920663823013104, 0.044140634051854574, 0.04012621458499663, 0.07783098611980677, 0.062479740909991734, 0.07401752300680646, 0.07381299285278206, 0.04431490756330952, 0.018392809621629216, 0.031540485271703333, 0.055679649550227396, 0.03440213968015967, 0.03843746568647124, 0.08755703156273212, 0.01574260409876344, 0.040134350438752485, 0.011464609208727076, 0.023813925480710405, 0.05114907834438547, 0.016504889354109764, 0.0799305726503653, 0.09259253514990692, 0.03869049686698183, 0.044733942336132454, 0.05368721190719836, 0.0465520988068273, 0.054806320807866515, 0.027001301322372693, 0.061293097528358625, 0.025815035239042296, 0.04953309247690824, 0.016901456683333364, 0.06198944080801261, 0.034119254053239866, 0.04201755160465837, 0.035066705632714495, 0.044983453342630986, 0.03303219061044436, 0.039690260760365956, 0.05564825909753, 0.010700823378659064, 0.03910301989244838, 0.05226939000309475, 0.051140831407880595, 0.006092065718070034, 0.03730851255597607, 0.005585207583217492, 0.03362469450240174, 0.020347613195377975, 0.04011004629935469, 0.009729287910064863, 0.0118948279076346, 0.0377847281314673, 0.01213501658170454, 0.08706669698679641, 0.05137753725472478, 0.03287768216743585, 0.03262511063967982, 0.007958050973097524, 0.09880491832811987, 0.05117695245351042, 0.050594131912915945, 0.020617911997701854, 0.010056358615627453, 0.034251266324351874, 0.05450478093999048, 0.020937320866411733, 0.08108273058408692, 0.008138365566640372, 0.03293117042630911, 0.025217187883813056, 0.035416566496414524, 0.03544572380281264, 0.07985580246895552, 0.05558887196163978, 0.009791474139708425, 0.011789359625489002, 0.024065263606908343, 0.08892850514741675, 0.11886600314849809, 0.004566161256779226, 0.04923956588872018, 0.032200307224787054, 0.06880136822620708, 0.021333836484700445, 0.0558083331693084, 0.021160231384959434, 0.06065162146584161, 0.03426173108539755, 0.013316591334108625, 0.06989292094423886, 0.0035808747493466667, 0.045400274121352745, 0.039920608077438614, 0.045281465375615705, 0.0782014279355926, 0.005800823987116136, 0.0014877968539123334, 0.07885151482637852, 0.04917062563641418, 0.06431309656510431, 0.014939870358625007, 0.06120685518028275, 0.06275531805811391, 0.06086829028302624, 0.013106844121319874, 0.004441532636842421, 0.04737420691057079, 0.04898701351316226, 0.05682243439819544, 0.023984450906995806, 0.04124153901131884, 0.043363660018170075, 0.020979444210928296, 0.024230960764050968, 0.06285176086690157, 0.00807497466373588, 0.050744936320810556, 0.0390090094128203, 0.03303594827171295, 0.10447130298181888, 0.029360779350803747, 0.046320855166883244, 0.047488698750854506, 0.024033057270571593, 0.041845434630710276, 0.01844534410103675, 0.04105387811338709, 0.0256853346382418, 0.03629112097945425, 0.043855676157099586, 0.019637579924517104, 0.01490564059255825, 0.05187872729654755, 0.059933111432098576, 0.012611338451895262, 0.024060383626830675, 0.007303634249124557, 0.09263974148780109, 0.051402071220499855, 0.03985074085874423, 0.015854488367274884, 0.00973142242254389, 0.03319820952451518, 0.04991172760304424, 0.034873172670843146, 0.03908883577453033, 0.009066460977098154, 0.02608603118137727, 0.02834544472035862, 0.025246697590656342, 0.017728634373915773, 0.012718342740329043, 0.04664366929641655, 0.06979175903383764, 0.01922183166888933, 0.05604077190641434, 0.01633743977084035, 0.03829573559003972, 0.031901339497116786, 0.045545543543994434, 0.011149635031488875, 0.053802527292000676, 0.040427536117814244, 0.09043327037004695, 0.033435999385772214, 0.03391812916003889, 0.05122300965951816, 0.040669202383968144, 0.04252171406762735, 0.08214754683356132, 0.051086458317454786, 0.028152878944491668, 0.01541385853347639, 0.019092263218255776, 0.018539473324293093, 0.05165309142020922, 0.054063950965721766, 0.0626841561508275, 0.0909237198591713, 0.02160603710029635, 0.06626158757435699, 0.07117966520449809, 0.04824509566289283, 0.020932699441008513, 0.012282895491338305, 0.06551339546398771, 0.019401521421968937, 0.02853844142068298, 0.023691280549692533, 0.017429540241738, 0.06053706833852395, 0.03778988390319771, 0.07719564642156325, 0.015003564823869497, 0.025963692685529113, 0.03792097686880058, 0.06985553585353398, 0.014051360626434608, 0.10745587428250622, 0.023582227933671207, 0.04507156877568172, 0.04830665848848801, 0.018384013017038667, 0.007031969895075646, 0.0854289695440281, 0.02736921121756877, 0.05805095597620934, 0.10139833279554883, 0.023957270107442336, 0.017226708887685693, 0.026363510142771468, 0.04806910228404788, 0.05729773449861715, 0.016001402963733962, 0.047739358889239455, 0.026962675169230472, 0.016010355658739085, 0.0399325437272989, 0.05714166323624312, 0.011570770800444148, 0.0934909034760729, 0.024477196744673198, 0.012101959887771838, 0.024484424784238783, 0.027456173688293468, 0.051800164979912584, 0.011053756254935458, 0.0220754919498558, 0.06175863383818538, 0.023947385657999306, 0.08721886503119623, 0.024448485684490973, 0.004552743226785454, 0.09572123057178913, 0.020997859049408187, 0.01244374618474995, 0.00967635793776642, 0.007104625673814407, 0.03461731462589195, 0.06266252948872506, 0.0745983325665997, 0.04966804269520987, 0.0832645643141962, 0.034973445919252215, 0.04946540860879806, 0.07375458630943492, 0.02594274209601985, 0.026426474909268083, 0.038014615795785384, 0.047827746283503315, 0.059077697655847, 0.029930783240425012, 0.0622269357254188, 0.1231560878635895, 0.06373582633152124, 0.03252221354013009, 0.08602191393654193, 0.007218844595275099, 0.09003817584485778, 0.05631377499911094, 0.056483210665324045, 0.029966076911096613, 0.042171948964917855, 0.028827733457869584, 0.007630243386712767, 0.05705218033624753, 0.058419819650871146, 0.024088815064920534, 0.03484831694813986, 0.01596453210954825, 0.023250253307783318, 0.020580444552545107, 0.02062593102304926, 0.047122838140855876, 0.08486487602274265, 0.0564430944711691, 0.04745176565202494, 0.0013159422650783053, 0.057128888720105735, 0.04089313371467494, 0.03027613567669065, 0.10765116541616379, 0.08342454645542369, 0.03525987853326144, 0.07700475263259104, 0.09252123534679414, 0.05028756650825662, 0.03194367926147196, 0.04988108791651265, 0.0377593323167774, 0.04283329351775108, 0.04814971771631991, 0.04389881456811582, 0.02793242373774129, 0.08292226856874843, 0.040701370415908676, 0.025047035925390742, 0.02449179455007036, 0.03448686517414547, 0.007839195304475124, 0.0997206921719255, 0.24802073565942628, 0.10480580761307672, 0.11349303783067774, 0.08293195958099059, 0.1673595985818294, 0.06421597959894328, 0.13386093320385103, 0.16843232085868237, 0.21116403111767387, 0.20034179812477482, 0.13735696012454648, 0.12383684125398436, 0.188620193230529, 0.12070577862041613, 0.16050853556202305, 0.09770213476111812, 0.1893943403997729, 0.25106060318648815, 0.18812715436422056, 0.13149332315210374, 0.16475819381735018, 0.12590179294948617, 0.14755207354262953, 0.10887243214153475, 0.19724183866093237, 0.16062467449134396, 0.1312583793074854, 0.1480019663370425, 0.24230066356399368, 0.09630974697610063, 0.21106275429408397, 0.15496023570097264, 0.10193915256569464, 0.14244870222624273, 0.1779232309350083, 0.20629725839582183, 0.15465790676253457, 0.10167550340655351, 0.23213611705408943, 0.16069091045327727, 0.12362253581804615, 0.15074710451787518, 0.14008044866063904, 0.11024995015994196, 0.19854924431250942, 0.10912465126884562, 0.1371332624506566, 0.16414209058688534, 0.09557840880006553, 0.11875699649775222, 0.2036473296222187, 0.07065919272962116, 0.1624587349473469, 0.18520955446987383, 0.251669826947393, 0.2906481813519232, 0.1690581380840271, 0.189437379219359, 0.13451160232145942, 0.1409793302657143, 0.20914698290007733, 0.15902560384523484, 0.08702133692079976, 0.15779728911096053, 0.1562862726108682, 0.16578473631412755, 0.11775864603658838, 0.14723324307030247, 0.08487107367405007, 0.10193755144193288, 0.23110418129832516, 0.15627761581732383, 0.09170038745768609, 0.17365549300466815, 0.17687074870111483, 0.1528258228133763, 0.09899693060546153, 0.1411994120046016, 0.11623596967828852, 0.15933082859602668, 0.24884397374285808, 0.09463628919254388, 0.24713879991923612, 0.15302987799288767, 0.0945164883629449, 0.09458189694991997, 0.1597985252737999, 0.1170861587348965, 0.13652416126381967, 0.2188708909576939, 0.13612057082355022, 0.14552368722375364, 0.18126672974997954, 0.20893034855684928, 0.10604275615825769, 0.16030282563259526, 0.13336764918940683, 0.10145897631563487, 0.1420126143362253, 0.1794213158709388, 0.13989828827400363, 0.122567824268293, 0.13338647963058564, 0.26692418501742426, 0.14492739502701069, 0.18741340556692693, 0.16773377124580646, 0.10947352770956294, 0.13179430377579507, 0.1534191119454561, 0.11894294135873357, 0.12784127476474932, 0.10254417816477437, 0.12118125875150004, 0.16951975202368152, 0.1516645407724765, 0.05483326028972384, 0.2792508461542668, 0.17687850151090853, 0.10457386683312156, 0.1261842725498061, 0.12198744371773736, 0.13690322156875365, 0.18791015229878888, 0.1326759637243325, 0.17937096857255508, 0.09862246682807323, 0.18077231192540738, 0.2535768036520289, 0.27540572828823523, 0.1151663883619251, 0.19850234440978498, 0.1396489419764088, 0.15268449491310507, 0.15561141043661103, 0.14810829934093261, 0.1248203372702964, 0.19145283397407303, 0.1330974499785131, 0.19349035206100634, 0.2248857843299066, 0.29223309469319164, 0.12658251569636408, 0.18639741976174617, 0.10833544281101036, 0.1319773681461811, 0.1529718238499857, 0.1467931868448373, 0.225794104138209, 0.1468748364958071, 0.1549611243629648, 0.08349363992531454, 0.15441131838146718, 0.14311372783155213, 0.10593937259287604, 0.09936076874334006, 0.2604436940483509, 0.135188119245633, 0.130873941065323, 0.15203886665403843, 0.16134622206370677, 0.1596669420119255, 0.13808112771761033, 0.123972186007567, 0.11134676590201356, 0.13589710297603763, 0.1782676793875233, 0.1627057216941349, 0.10330799846879898, 0.14623116942182665, 0.19107561228015732, 0.15368733464950515, 0.20846179386060085, 0.17884914012205216, 0.16445948081391473], [0.024007328207634633, 0.051983064641394926, 0.03465903577424827, 0.02533404885100261, 0.04207460983325878, 0.08110390525431403, 0.032063685019590685, 0.019754021458568114, 0.019243847120613344, 0.03884814627047989, 0.023671567192180984, 0.03610607627178392, 0.009017338461783386, 0.07422101894213308, 0.021813168122823683, 0.07415982383874155, 0.03689623084820567, 0.05008102537343099, 0.00844724359922111, 0.05482524317959624, 0.01250361595603247, 0.006404134028050448, 0.0433866081819419, 0.06893534934328449, 0.019567496285984115, 0.054905238080649614, 0.04689640936351592, 0.06319200732715188, 0.03127733023927337, 0.0324685605723531, 0.033363098458897684, 0.06089147976449421, 0.04937748086728877, 0.07936764358272476, 0.02876154920687118, 0.0604565563281217, 0.012224908381129706, 0.023076751629912087, 0.01944785633484923, 0.024309706941787756, 0.04389972621274572, 0.055312176325148156, 0.09650398090842272, 0.043148293550456726, 0.0796829117462039, 0.033556688877363364, 0.027332109579395865, 0.009203035301799256, 0.06553031834623506, 0.021778569676943367, 0.04847466157028272, 0.020167446552565502, 0.056156523961333506, 0.09660468316606938, 0.05981174012225482, 0.042249323845270186, 0.028343721022528988, 0.010752733496408309, 0.020850410106621926, 0.041610153707405256, 0.018125912249689142, 0.03300349295680081, 0.011520005026531797, 0.0429676155439548, 0.051140130437429876, 0.03684078523468587, 0.06350817947438167, 0.04766917757449612, 0.0334235044917272, 0.04742204527100248, 0.044180267610617226, 0.0424383215666298, 0.005820813615085377, 0.0407721760923103, 0.022085303620946024, 0.0379150205351893, 0.037018498480920835, 0.05726589588448406, 0.017123503437746438, 0.016361401085892034, 0.061397438703645627, 0.03930700995448617, 0.047728549388627854, 0.062208304467100295, 0.06581760897871948, 0.07775336609131868, 0.01418811593940782, 0.03684285750252105, 0.027362534761308666, 0.06937279320892788, 0.07556348843800445, 0.04206006948445593, 0.00845077430694214, 0.007741414714649681, 0.04384836001742271, 0.051144830386845336, 0.07272948405795521, 0.07156539813525255, 0.03664997188494571, 0.029638587730005387, 0.05723951947725108, 0.03943617620895948, 0.014480066301691678, 0.01305848673631948, 0.06056699173284635, 0.05776077719225038, 0.02946313444314705, 0.046240917722424196, 0.07513452516568285, 0.04147222340707818, 0.020290698608263366, 0.022431994795859344, 0.08846941163703319, 0.015974460609046923, 0.02721139135950756, 0.04922524770541538, 0.007788865243069708, 0.03943620302203683, 0.03514440993087427, 0.0411727519765977, 0.02291509750178985, 0.04749622173427094, 0.08789100759332219, 0.04486170281926471, 0.029706769555266348, 0.023997202440495455, 0.053162794079511404, 0.07614520964242759, 0.010270763642995829, 0.012183314594890804, 0.03619639803805659, 0.04514273068296813, 0.0742251021907695, 0.07517829176879699, 0.0025176919429683157, 0.03477530110807669, 0.09597265296765874, 0.03381274227473525, 0.03552362728383272, 0.03977016373086841, 0.06532289237985689, 0.053977248964891325, 0.057223829996561816, 0.016768523191492406, 0.01962951110345462, 0.01982355351379562, 0.030150700270408587, 0.0632969422205802, 0.027365518673773737, 0.045573161013664744, 0.043076564738106345, 0.024260560486225352, 0.04466248165455557, 0.07148731079313063, 0.0285260422876285, 0.03949958147601255, 0.009996823050201902, 0.03989230878951569, 0.01669631365896954, 0.06344000147956033, 0.04646649997260782, 0.02921943038311457, 0.016390772896908944, 0.07011006856637617, 0.055683280806988485, 0.02224136147678139, 0.08141427811595701, 0.026876396431978193, 0.04663135826347336, 0.012689847142375525, 0.1151656222740008, 0.03250550899294115, 0.03331049886201659, 0.01792479884780703, 0.036881261490165226, 0.06617931739216851, 0.03063121742959465, 0.021954342805510087, 0.017393739037816564, 0.02994866564779753, 0.02005821582110178, 0.009622826586447416, 0.061467547240036155, 0.03985273651778698, 0.023602738022624005, 0.02750209491369465, 0.07783690031858222, 0.024330169150245287, 0.04790690231827959, 0.01757626331621601, 0.08178191604993998, 0.07268542634142984, 0.05060032573378375, 0.008022063843635543, 0.043918020392377535, 0.09620138383921116, 0.04690582075366571, 0.02051989296300998, 0.07574965546448385, 0.12154248452955678, 0.10943434231223599, 0.034118874839717345, 0.1315790790343477, 0.09103697829789693, 0.04038658871826145, 0.017826810456632126, 0.0880026342647691, 0.03073612742516543, 0.018865432244755568, 0.013308263958371697, 0.0772966321317419, 0.050377068560450315, 0.020379685466327978, 0.05779533158807505, 0.04088205225285023, 0.055586121705991615, 0.05572974020915647, 0.02588589454159862, 0.004507305594386473, 0.03501833867161505, 0.0794818519704765, 0.06487127588761431, 0.023342727781123212, 0.018808793449293704, 0.03550404990692774, 0.03643341798094973, 0.005858283933071841, 0.03292459739191878, 0.023535328030946757, 0.06283622460379716, 0.08546742715782697, 0.04997139436102683, 0.02444751275282714, 0.03890309392684891, 0.02942459064445669, 0.04398476197234085, 0.018255886726922566, 0.033194379084893776, 0.04946786009015576, 0.02061798477605466, 0.032386393812034404, 0.04866698794367333, 0.07164115657008464, 0.07133826838746186, 0.07207345998575611, 0.04378490112421494, 0.029556532052435705, 0.032619993172345624, 0.019435514658389073, 0.05677283020509828, 0.04971398881846859, 0.03875097567816416, 0.03484349825509614, 0.021762179225803386, 0.07980879531392167, 0.040123659681769154, 0.03506430011663226, 0.03185947470727467, 0.10201383081655349, 0.04297093653510656, 0.012752784138184883, 0.03957248240288708, 0.03905256534175527, 0.019102400476713816, 0.029634180809220964, 0.015628774924534225, 0.04724017982821792, 0.04514291454406996, 0.02270748192865041, 0.04421980157794972, 0.044552479089508136, 0.06643979494730312, 0.030847591302928426, 0.023877926381124605, 0.042022902728809465, 0.07837190548138273, 0.005453444290680872, 0.09576112077000642, 0.036647581690621954, 0.08157615249435748, 0.07066224942043905, 0.0732799488750677, 0.04445414787398712, 0.051868894558039405, 0.05753932798641825, 0.10407397147989082, 0.044590871585833455, 0.05284938750968826, 0.051719587852036765, 0.12968327189164777, 0.04124957527364454, 0.05924096631426966, 0.1034593391382406, 0.03991154525729437, 0.014219066849158657, 0.04514063160205561, 0.0028227534212712803, 0.041386513490109675, 0.06456811191333879, 0.04943391090379127, 0.019700565758431633, 0.03691865424174936, 0.05962076972449019, 0.024011334847478617, 0.03906662305516582, 0.02943623326568594, 0.08764571390084683, 0.11138799675409833, 0.06057984285777616, 0.026373444387929577, 0.0489175982863432, 0.04396337279749494, 0.048880374074102416, 0.02115085638398605, 0.013958528006990111, 0.04551157520543184, 0.025549756227842262, 0.02063024601328277, 0.05045237117296746, 0.020211065683754224, 0.08896086470133836, 0.029865623632025336, 0.039021711150604876, 0.06632917185103701, 0.06588771368467039, 0.009632644960806977, 0.03520298884400437, 0.02766491158024198, 0.019794018909094796, 0.04839731733344736, 0.027577391780552366, 0.036723160094791846, 0.041873791375227516, 0.0055828997433455966, 0.06265317172472996, 0.038509301751131014, 0.06823653159963508, 0.03696473826083445, 0.07364443818768186, 0.05262222328794099, 0.051720645053372274, 0.022849196703323436, 0.0814073296984838, 0.0790669923768409, 0.09380078604144436, 0.048493438385306835, 0.0691944862445516, 0.033017788157467885, 0.04334068887176053, 0.05170790884163111, 0.01574665766149279, 0.01812716097300572, 0.14265286465806348, 0.09723420059608837, 0.11196877567037461, 0.08353711541501746, 0.2027797197262126, 0.13615616326851232, 0.16000254980979428, 0.15769506233834452, 0.06323174047734469, 0.1666991695040657, 0.08782457244852859, 0.10725856067672854, 0.11050737868513792, 0.10506429333960819, 0.14395905989072016, 0.20772665588846131, 0.17348142250651316, 0.12283827628820174, 0.1520457154800815, 0.354866512840794, 0.14056400335844488, 0.14848685402783657, 0.11877287750042255, 0.18446732252355547, 0.18173232734684022, 0.12323228296853843, 0.25669862726523035, 0.19902188991827352, 0.0720582991057346, 0.10139971175381254, 0.1825555041432381, 0.21888897063270693, 0.15650955659727897, 0.12216844731160711, 0.20786580809902763, 0.11820686109844716, 0.15179183394197496, 0.1271334478271104, 0.10935168142520613, 0.1384098560459191, 0.13945349762516637, 0.15882597665392584, 0.19272541326861228, 0.15766394384686025, 0.16424430203774285, 0.1287774035647031, 0.15255871859769668, 0.08238884154707193, 0.23706938620776902, 0.2068683922651314, 0.06289998993217465, 0.11735721596426542, 0.18238327225610135, 0.1745583123016742, 0.19718721659193117, 0.20161664503956997, 0.11092826739073762, 0.13357286882256308, 0.14983009727251145, 0.10340326150218326, 0.127816874864361, 0.11018732247213203, 0.24566392744741133, 0.13731145450184423, 0.14448600580855725, 0.08861741982400419, 0.2083905170401258, 0.22481821537498506, 0.09708161886420943, 0.1050439460443393, 0.1198370578969198, 0.15470961769742353, 0.09833450203821545, 0.13192911992870993, 0.16899528823071913, 0.1807568829146124, 0.15258801379992118, 0.12048032660517963, 0.12562331998901022, 0.15106227308992418, 0.15022023520883054, 0.08285967152445547, 0.1369362859235656, 0.1690248132593209, 0.12675323839028999, 0.10359233966277492, 0.14125096972190565, 0.0703790880018665, 0.182541208942571, 0.17165224969146714, 0.19000141911448973, 0.18664108168694282, 0.08208142578481667, 0.10521057782874954, 0.1831277718226756, 0.2177393484500147, 0.1894779359140704, 0.28475705714475724, 0.12516220400650657, 0.1816429248860767, 0.10884422478416275, 0.19509594977623035, 0.09506678464071405, 0.18791378355554997, 0.15276517929329028, 0.17629209184838882, 0.13909283875217363, 0.14717194071460157, 0.19005401871137081, 0.1953558834089387, 0.08511510332145038, 0.12299514045157742, 0.18154789933994894, 0.15735965372333605, 0.1063982515986408, 0.09478554610283145, 0.1024336469990592, 0.23269994244460138, 0.10756006224020835, 0.12067628423533133, 0.08118878779632431, 0.19834673663060512, 0.16597192223754623, 0.16022863767800793, 0.10757259543864958, 0.10457404303334414, 0.16050654373341994, 0.1506009042984055, 0.10348612923295268, 0.09878847042038556, 0.32328849117602076, 0.13165280733618046, 0.31512898062506034, 0.17156057961044774, 0.0900096697131953, 0.12819652505699666, 0.15287235499389712, 0.18739773140799615, 0.15595457186141323, 0.15089558767935923, 0.1157601141641217, 0.11205007292089925, 0.34769458155478206, 0.09989834796156614, 0.13445010078289818, 0.06820311484437797, 0.21985221894518023, 0.20312513344951216, 0.2364995393661722, 0.13926220547047355, 0.08267269244477635, 0.08948682236575312, 0.11784535186785845, 0.14043048955500126, 0.11503495065675629, 0.11237633444609181, 0.13813411035845358, 0.14189653669393834, 0.14386440206679607, 0.11646334457421496, 0.2495956438924036, 0.17267911394517269, 0.1185186205792331, 0.1591391687191302, 0.18443271067113648, 0.1730190731224514, 0.14466488733887672, 0.17356199963438898, 0.2643493941474346, 0.09930459151585257, 0.12839966859187812, 0.14246066851961997, 0.10926188059872198, 0.09391520127293565, 0.1370101827647417, 0.11093869384738708], [0.042884598426040144, 0.06137267491149326, 0.0430823908367705, 0.0663267510131963, 0.020452040555556456, 0.04951470253628589, 0.017734021887243274, 0.04895183092523967, 0.06836149586184372, 0.01734623392563193, 0.040663000902221094, 0.022953838568120714, 0.0475530922713299, 0.04668624846324806, 0.025361762081663457, 0.0340477972021026, 0.017568719265381658, 0.04297366380811699, 0.005171687207034519, 0.04553890539213054, 0.07276847793330109, 0.048080030528287736, 0.07746391509088778, 0.023495853435428395, 0.07644782969427687, 0.056966098866635756, 0.1262071632569836, 0.04092474250243076, 0.0455031214251874, 0.04238189536056692, 0.03600536252281839, 0.035804570877864476, 0.029286600972315478, 0.04146840828921526, 0.024866434527681242, 0.014524756998364485, 0.03152047888556075, 0.038734891662193884, 0.04912925305806341, 0.022384150689768217, 0.03325237960164105, 0.04310525473087065, 0.008056222746569303, 0.08819412560232225, 0.0465888059097192, 0.004215786635364977, 0.025379807282719883, 0.01780619311536993, 0.0272388173071968, 0.0339965918852437, 0.030556119745597247, 0.043080261112341, 0.07711881546363716, 0.01480416650132787, 0.05155305182861705, 0.024137132230304906, 0.011644539321892926, 0.08042358087315675, 0.05824274608805295, 0.07714494672273436, 0.029014484626391245, 0.007228246888130784, 0.07674890990939832, 0.09674909840067548, 0.02567927488276074, 0.04303843654211491, 0.027527571167616595, 0.03399316747222216, 0.0428425670120745, 0.02758576129112513, 0.052596869608086926, 0.03052392490057936, 0.03152218534641209, 0.009227297306361218, 0.04045522253539774, 0.005488741791792094, 0.037247210200275147, 0.03222251611371194, 0.06645462640951719, 0.021955396176405975, 0.009056593764633422, 0.0030509011083913427, 0.041158414641094786, 0.03443059601610707, 0.041172499167582685, 0.010509670077402507, 0.027606392038926005, 0.006328174495138229, 0.05336118786926231, 0.05226865072824782, 0.04450947857431827, 0.007975981260965308, 0.03258683305654315, 0.014873581728146923, 0.028875510531267332, 0.051761596283364686, 0.056777710185175946, 0.026475006579271248, 0.039878917572599266, 0.0396339456370521, 0.029900882828740344, 0.05955939842087608, 0.025601051560032274, 0.03794965537024602, 0.018331832853296114, 0.04845378184390645, 0.04605817510896633, 0.031278542573413545, 0.05571783137237353, 0.016181092716813568, 0.08911309403277214, 0.03396565725486125, 0.05048314109444619, 0.058249935823222326, 0.05492656596846158, 0.06197914458631028, 0.02153994477984886, 0.012530170478707841, 0.07229119749559511, 0.01886613704564591, 0.06180185268843367, 0.041219061991620454, 0.06937018084910608, 0.036554494346942634, 0.07352633041239555, 0.024926348349019408, 0.05896840755256915, 0.041151190431968826, 0.05995361194495232, 0.012911976251240461, 0.12446587604861106, 0.025933405399442683, 0.05070542150567617, 0.01868890260436362, 0.015688151526715488, 0.07314747695120112, 0.09254053310160676, 0.010537794122712748, 0.028877308922669584, 0.03614367969754723, 0.03220604522333991, 0.034033195566265814, 0.06394333273713147, 0.014124309433804405, 0.013250716391109653, 0.05568548714021041, 0.05978217678925684, 0.011629806493499107, 0.0310366177525852, 0.0842097023081395, 0.03960034885113278, 0.035076312375284975, 0.07428260475036598, 0.03362793122388182, 0.02064283475309851, 0.014566849699364075, 0.06172960293629478, 0.017736172679090695, 0.06096510464445718, 0.050324982242478486, 0.04045711477257071, 0.021233570897170616, 0.029411446490895846, 0.0030235508118846245, 0.02188817387627017, 0.020104029794193564, 0.06166691779189053, 0.01470247790547869, 0.04694794792862189, 0.06844250199895713, 0.06062842049305478, 0.09288847491505647, 0.04342838295645291, 0.02723680058073613, 0.009984043746014998, 0.08978859206000644, 0.010387527891584944, 0.02752178720378828, 0.03417378419169015, 0.05001159865529307, 0.057761719480397246, 0.013593893137670333, 0.041316033401075876, 0.06766928179610161, 0.0877569575283316, 0.0680334340300291, 0.030437192256231944, 0.04035765357736138, 0.012780476301427812, 0.04283406726655461, 0.05566888218445163, 0.021694796047203486, 0.016578943243310336, 0.016199934649311246, 0.017041526284188997, 0.08040576166803799, 0.044588144312823014, 0.01706443231312498, 0.038469442196430705, 0.008222929224552167, 0.013646932277497987, 0.02804362906082984, 0.04918253447319712, 0.048307845924770644, 0.0355436145177772, 0.04418027527149647, 0.06351069607321294, 0.012229829538433303, 0.013225680637744167, 0.07187122809550456, 0.011242601716320121, 0.044341444849006595, 0.04325685970064613, 0.05757204760166426, 0.045139306269946604, 0.03577768885260148, 0.005698522520927532, 0.030695823539469032, 0.04444155338851195, 0.02313264157442797, 0.056830692826019186, 0.10977867585156234, 0.05128101783714468, 0.043918736684586734, 0.03151396905342418, 0.011460825691991037, 0.05426558147695276, 0.017397427751171975, 0.06252711961766885, 0.011471308647624908, 0.0392972270116931, 0.02383226179517806, 0.008435298373261768, 0.04586229791804668, 0.025993307729461984, 0.05240018036396754, 0.04220065044900102, 0.03698145429934225, 0.13796307356847873, 0.05448825642346375, 0.02256172604017681, 0.061607392760173935, 0.014143354379602019, 0.014565924648195507, 0.025558901402438362, 0.0730614605990629, 0.048422410543407166, 0.06691706006325061, 0.01937221855886521, 0.031002999899247964, 0.040405308076691245, 0.022665845049965768, 0.018633278875401425, 0.06396892390424205, 0.09844049796341889, 0.02056720463799373, 0.0724495325477854, 0.048396972593881434, 0.0627105938450944, 0.05098551474211197, 0.03844523764846306, 0.06889342901206787, 0.025463339594763615, 0.0169740186163014, 0.035362511332477295, 0.08153158915980209, 0.07013921821189505, 0.0735535265337075, 0.034301912397026055, 0.009597096565900552, 0.06378778241454594, 0.05836224814336147, 0.03923928395154015, 0.033372433240255045, 0.01911244005896151, 0.017235235446282936, 0.010161358626529334, 0.028553431846141338, 0.1091015613788078, 0.031403587274854226, 0.041473092916872234, 0.025351783786449703, 0.033596950628223925, 0.04025994289305903, 0.12298260725313619, 0.030399031501503724, 0.10959179636331336, 0.023847166035744934, 0.05595606173418703, 0.02526319529410572, 0.06552385256415413, 0.020889631893125274, 0.061336963722902926, 0.02255408048269249, 0.05583691207932369, 0.016039347298623576, 0.03840008442620597, 0.04328969805952042, 0.06746059178464836, 0.04082043963153997, 0.06147952119429266, 0.008186879999665244, 0.06278722178972056, 0.021194944744028395, 0.05325364444645182, 0.05079131911418611, 0.026455840974625562, 0.0269992807654724, 0.04733937672309337, 0.01783299470140088, 0.02242224441180306, 0.044603914232744325, 0.06281210432550119, 0.016784965353567275, 0.017329067810468616, 0.08543266208782312, 0.008533317407953643, 0.040056186487838145, 0.042130698960634975, 0.07429149137028764, 0.04804012883875159, 0.07042161354254331, 0.10049752830978363, 0.046308023194151546, 0.02717820826106735, 0.05058938982866464, 0.016055956084821976, 0.10749623179435731, 0.06810828848111053, 0.021654951814261657, 0.04066250677550993, 0.02025292664315672, 0.049335993375749364, 0.07144161364844731, 0.029169107982588392, 0.09167522913025272, 0.03261236676705941, 0.012068717417517498, 0.04342705379390428, 0.03938013304685874, 0.008093592515515705, 0.04193549592708869, 0.04585842917402906, 0.03500534198997963, 0.01599996176082641, 0.04470070561153754, 0.061614490564792394, 0.040657921739283114, 0.017407666516279983, 0.07537706860251005, 0.06385698696718582, 0.04253139741899025, 0.15115994930026994, 0.13287897702426682, 0.1552461550360726, 0.21690586011015603, 0.13855035657123213, 0.16233602298363564, 0.16624996618878457, 0.17795765892632548, 0.19172582174501113, 0.18520357898406445, 0.10780385440035213, 0.10447288112294291, 0.11059282047133293, 0.19631088861534673, 0.1320272098265348, 0.19993043955295317, 0.11731665160867477, 0.1747048342780721, 0.12664237780676735, 0.1586856906332316, 0.1339754173832555, 0.11090051968612018, 0.10529618815428789, 0.15115783489759893, 0.15816822888389712, 0.1151427468885818, 0.17564344520290054, 0.15907588985658463, 0.1486275843795269, 0.18523904885495865, 0.13994561718596568, 0.1460390498921756, 0.1254396350874055, 0.15699589985512918, 0.09190603610007994, 0.08505633671677883, 0.143896424542031, 0.283645800645313, 0.18071169904883833, 0.18217074414414747, 0.11507158498129538, 0.12344231363385917, 0.06649257840528604, 0.22175749493462427, 0.1572146945663037, 0.19229546940374762, 0.14493075049211904, 0.08881001432816829, 0.09646521685945411, 0.09827723696587548, 0.16689158014712796, 0.18092278691549457, 0.1789715609723522, 0.1221243283080478, 0.14348721101639733, 0.11650534151422402, 0.12496820756144102, 0.21401130414057165, 0.0950116875971998, 0.24982148661248146, 0.10487982702832069, 0.12733285285292134, 0.1635438831703317, 0.2138929435562703, 0.12450546747253788, 0.1731644153234459, 0.10676869341442663, 0.15983391853590168, 0.16083818319584095, 0.16779055368275414, 0.1046761931971677, 0.1332948401930832, 0.12765885390821965, 0.1242973979923033, 0.2611886685894382, 0.12649139719865016, 0.09683145285253564, 0.10463954355087011, 0.1884499531719954, 0.1500942137452864, 0.10042381532970937, 0.13009470707226184, 0.12238259186908124, 0.14072595434563775, 0.1058209200780238, 0.1916924203115125, 0.09757742330792452, 0.131495698024669, 0.201301982085551, 0.09567866672671611, 0.19870638426753784, 0.12729864702710222, 0.17409504361210332, 0.11551068359685522, 0.10181670107187764, 0.1485840399419108, 0.16629036966591113, 0.0707100456460349, 0.22072578900523726, 0.13178832828998566, 0.10127188998364633, 0.21176465937206823, 0.28590205215638687, 0.1039348192693245, 0.19529761476141794, 0.2695771168556906, 0.10411855013620469, 0.10496929077611816, 0.13203963577266664, 0.17239402198503095, 0.24030534159992975, 0.14354310479135285, 0.129765028794927, 0.16357670237700786, 0.15874290207941688, 0.21333864829953642, 0.11622133739893475, 0.12524934650789346, 0.14527527555342645, 0.14725668536078546, 0.1878183596437016, 0.1071115484040591, 0.2816179352662256, 0.11004171214036404, 0.1595545875569505, 0.2125029689482143, 0.11309111746208322, 0.07244374858395708, 0.17521235220614942, 0.11898435607192018, 0.180819564228577, 0.16803936371880193, 0.20532375982692166, 0.11748368175880564, 0.10090137155906809, 0.1468548416009834, 0.09939581726587589, 0.10733185230844444, 0.12524666520015848, 0.12099000490120343, 0.14201385539866265, 0.1255866626818334, 0.1387590542435646, 0.11221555557342307, 0.10095924950174748, 0.2739967393778986, 0.24648699699149978, 0.06759815819321141, 0.0898986176076916, 0.1810280627180492, 0.15932385719591574, 0.1857936965121377, 0.1694381176944702, 0.09687548758642328, 0.0800941017786822, 0.12369470130051337, 0.16979784194019534, 0.20579692637247426, 0.19599339113600794, 0.11646184304188337, 0.14584510707326476, 0.12288269406605153, 0.10497300630255092, 0.1397066590406241, 0.0762421427474868, 0.14658741562837554, 0.1609279687005666, 0.14538857995742752, 0.20334092509602347, 0.12843000567367963, 0.19304720084032706, 0.10097929036184665, 0.11931161351141431, 0.1910290800996365, 0.12007476731894479, 0.17797780703873406], [0.06030560253308185, 0.059924171186022224, 0.06296404637396336, 0.04003767397314791, 0.03994005521939647, 0.013449485563943464, 0.05805934080854059, 0.03936841573205687, 0.03323270646374553, 0.020803858773903023, 0.04040122865849445, 0.05406095556193783, 0.036472576565199324, 0.02773964345725554, 0.047528006722249334, 0.07243342937961703, 0.05837170932922633, 0.0965925176898318, 0.010422762190442412, 0.0211085376870488, 0.007725382888419254, 0.0064633191082506414, 0.02586697025464908, 0.021927997041794083, 0.04989049547622281, 0.034921003370395595, 0.017845742404460907, 0.03863460309202633, 0.017131217943143942, 0.02679414540198782, 0.010441472930383059, 0.027278607913983927, 0.016529708687636643, 0.02309927078444631, 0.059416074861562064, 0.05050512398743341, 0.08309121393869001, 0.005725539090382236, 0.08451779222776813, 0.11036251145865648, 0.056824790118562604, 0.04778053994560915, 0.07403015579667784, 0.04202578321940476, 0.07134285725412831, 0.02482808033575214, 0.03508950823978071, 0.04232739969607323, 0.05728694415020366, 0.04427509780432429, 0.05632037867701823, 0.018990145613168998, 0.0651374454760263, 0.0483941572207597, 0.06503681216629283, 0.02871824991739085, 0.04595794016495348, 0.046473383272607485, 0.02543406737517686, 0.0959812178306522, 0.06619797163312474, 0.05604003646200704, 0.04810795826356738, 0.05486203838259943, 0.012109922414134828, 0.021354653008822954, 0.059273187972364895, 0.04884687687961325, 0.03358373561153009, 0.07133757890833002, 0.07794731657110876, 0.02874628298976008, 0.062167931633490714, 0.012197627032536172, 0.03863544961918266, 0.016023921160658282, 0.06800316589614076, 0.01991192367108118, 0.037214969389981804, 0.010672235850154633, 0.057642872430263996, 0.01981559769070197, 0.04072262552536784, 0.034397569965691335, 0.07072896801776464, 0.028133581189679045, 0.03000318812536857, 0.04613629692504483, 0.020427131206698475, 0.046048327048699704, 0.03461397065210246, 0.08060748027938028, 0.025082117006663355, 0.03767477153169532, 0.023127686900777683, 0.04884436411122161, 0.047681408168207255, 0.057184613955717896, 0.03684616700235394, 0.02789476860104309, 0.02386340518451987, 0.03898054924643329, 0.10736612708217676, 0.02909832145838488, 0.060024980695978294, 0.04061716203127177, 0.05425228602102688, 0.0836409433113952, 0.0479281114624633, 0.04185366624545667, 0.018950345430282817, 0.05488643828298777, 0.03716131642220482, 0.019529358513893622, 0.021284481270178672, 0.03501222528997929, 0.05776335124767596, 0.009123947257326256, 0.05181491983333423, 0.04277676388981842, 0.035900167159495816, 0.07591724485879944, 0.021498689029906547, 0.10402494951361611, 0.06226953021400879, 0.009016162516819614, 0.007440593533007609, 0.028763724896576137, 0.02995033954991208, 0.0447587022978452, 0.026651024855973742, 0.108036637877024, 0.03903679159139434, 0.04909109804899462, 0.025308825406095675, 0.06594893177069965, 0.02881983126093063, 0.050213420688505137, 0.05262740970318837, 0.04191314914233742, 0.06589136026318997, 0.04596487709110783, 0.038010023098679326, 0.0055388022860091545, 0.07209898603539314, 0.027444826010915063, 0.026147764461535602, 0.03799955067675441, 0.011296806267402586, 0.03825813982515566, 0.032771939051247416, 0.021239308895723476, 0.014138856485876587, 0.09795741057924687, 0.05833464216501002, 0.0040293371139635, 0.009474811696207092, 0.04663146551578276, 0.027886019876947808, 0.01784047554998148, 0.049079491816941774, 0.035084861916519945, 0.0157824540773647, 0.02734763626640122, 0.02262911687965595, 0.05608197211498215, 0.03593939852209822, 0.05577474021382871, 0.047893032296410495, 0.05839004564369398, 0.05940943287925855, 0.032706951812630704, 0.020312070546130982, 0.05578938015406171, 0.057682869880790674, 0.019525704274494803, 0.003968356515190775, 0.051469383535966765, 0.016364884870727698, 0.034842916028273684, 0.05942748574119422, 0.016728339964644085, 0.07490757161811476, 0.04209122628033642, 0.032935613736269936, 0.023030094960103595, 0.05862712687362106, 0.035204333328311486, 0.03211947728789622, 0.026692713445593274, 0.01396598204249336, 0.05985831443761146, 0.0241951902036465, 0.10903138006406446, 0.017801885786015662, 0.027133972429099585, 0.07612041137631863, 0.06052004586484644, 0.02391956709024887, 0.027221672259451404, 0.04403201427551047, 0.023040477366697405, 0.0829820923747555, 0.022224517118546273, 0.022838134393696825, 0.039727642020631226, 0.0027797842678058174, 0.07636843234180443, 0.02215797280622346, 0.011355156311765315, 0.016751458582979058, 0.03731181439492972, 0.0347149716840396, 0.026898601490463463, 0.08571603035013522, 0.02857889852396423, 0.0050778806983162806, 0.010734492942931191, 0.0162766162200921, 0.05605188401175603, 0.016326630270228754, 0.052370161208654606, 0.026135399802437714, 0.0357066227063056, 0.032681276375848445, 0.06814703720832063, 0.03608449174451732, 0.01206937816835219, 0.07934931109869674, 0.029120135812028766, 0.012891629913581476, 0.03613307704067519, 0.05629260032888382, 0.044482657836089214, 0.06555831885986751, 0.05875963710188385, 0.03347421568187495, 0.07184200184119326, 0.055629263947447466, 0.04046980501903642, 0.010768381799871643, 0.03415516825513013, 0.08542909977897521, 0.01935511947639527, 0.025874200209434477, 0.04171299335036067, 0.08872828806840605, 0.04152224128765445, 0.007382711281083645, 0.04420344560076633, 0.026926690104207205, 0.03608130098831269, 0.08371553729258238, 0.018101763243096012, 0.015399348828190518, 0.015226008986393291, 0.04107732040387008, 0.023833504772835204, 0.04405924870121864, 0.045392287654742125, 0.003507654938373655, 0.04414193257088623, 0.06651607432192372, 0.040171792986051696, 0.06704555599079018, 0.03856660512786719, 0.03440589351098865, 0.04801682061365536, 0.042560236798899795, 0.08579364271774408, 0.028382908335075747, 0.04882438453815637, 0.05304722971613369, 0.018901174076862873, 0.057340041704235546, 0.08228185736844618, 0.05104391362457987, 0.013034626927917764, 0.04134239448655037, 0.022677573856086503, 0.03262279322370887, 0.02869725336260613, 0.05730600824819938, 0.05803389136769599, 0.03845051216382173, 0.055565762919403856, 0.07501658592973987, 0.08928834430633054, 0.01915309826032289, 0.00862259729464929, 0.050884808654025684, 0.05521823096299364, 0.06659112795586548, 0.02405192601614662, 0.017096351366490126, 0.008932426233866043, 0.036633543129409515, 0.06680292828429131, 0.029122485786736495, 0.004601822649654482, 0.014714020935277787, 0.05654837793460297, 0.036483700161859874, 0.01759079791935942, 0.05453949238383963, 0.043087328273442485, 0.026209423048121315, 0.03787598069456797, 0.08193290431893642, 0.0070918650430206575, 0.08100856561213732, 0.03998954449930499, 0.02395960476039158, 0.07633365961092134, 0.04938902198186806, 0.011494467485575907, 0.06445531312736773, 0.058099192702361656, 0.06061384183985572, 0.05721457182399689, 0.030631769012900132, 0.04497445947039993, 0.02508238130699723, 0.06177242342082243, 0.005749927499451705, 0.021825869860608253, 0.005778746290748278, 0.03151896011625086, 0.044958459724101334, 0.032426766645643985, 0.0199647952291754, 0.05746892833661649, 0.02469172434610946, 0.05623014501085686, 0.05084477672954241, 0.08703405398034281, 0.04312433798106448, 0.037929227635745084, 0.05126640854042865, 0.04479304601949069, 0.03456938816534896, 0.044900298328889955, 0.039517163193874785, 0.03671800815350106, 0.022874536976638823, 0.029961321420306643, 0.06184610958781935, 0.058572401382750085, 0.0336967603934388, 0.09208169240023821, 0.01532592025825814, 0.04887201605484851, 0.17878434440541655, 0.16940067131673137, 0.099521869372937, 0.16814273962330434, 0.11435802770598281, 0.09280312505941238, 0.14116146000883273, 0.20471977610741893, 0.13242260312601445, 0.09765600094631796, 0.12340333508027178, 0.11850635551156537, 0.12662054430092537, 0.1274611342758421, 0.09351252247729609, 0.23459559636971644, 0.1043911088979052, 0.15591312650470965, 0.2294342628409786, 0.10871686266675111, 0.1288750491315319, 0.16965211669523872, 0.11829518337523746, 0.24488133798924186, 0.15893926573616846, 0.1348446513856611, 0.09437162113646347, 0.18172049894928935, 0.10955358389765026, 0.1641482039685211, 0.08297684467247418, 0.15974102271420343, 0.09254603361290309, 0.11523401094300133, 0.13608171484403073, 0.10169768165196143, 0.2268660296836207, 0.1647400834988202, 0.26210086480263745, 0.26041740191078955, 0.09030657474912944, 0.14890702261078745, 0.19234587798916525, 0.08543941132243603, 0.12558247218088758, 0.24995063371475668, 0.32202435417040703, 0.31832120771850314, 0.14000023925496688, 0.22198805675631572, 0.16727837794009717, 0.08852353574888361, 0.17952907379836808, 0.11349538205972604, 0.08766646722271558, 0.1298505242072767, 0.2730014992337073, 0.11782004032284023, 0.12937850679361051, 0.24730113395039113, 0.234675407409668, 0.1506360524123715, 0.1618907880038023, 0.11051903854334548, 0.1767037108901047, 0.11964160588479812, 0.1591337294948678, 0.10857304498072594, 0.18253851231307755, 0.202932063970835, 0.17407022236335665, 0.18552466175488888, 0.11458374785199282, 0.11213021337865822, 0.10962452363943863, 0.17743573854527167, 0.1973407252901985, 0.05348807501216089, 0.12759686973426612, 0.08122541445998416, 0.15549435220178098, 0.10814749846054662, 0.1442576809636047, 0.16450418970517575, 0.12342302353992579, 0.15276828961026284, 0.13532684244696172, 0.10642622912963552, 0.12037775509299771, 0.14831468342773377, 0.12998370093203362, 0.2239375666625077, 0.11725589317540008, 0.17808147405664768, 0.19567569447380884, 0.20603573130023098, 0.14091358460005254, 0.1236961568675695, 0.16388655429886234, 0.1513015070269185, 0.07314687940262019, 0.11352796377914567, 0.2794240126686712, 0.09104630158793542, 0.1555217015406778, 0.10868203630971332, 0.25154613439113865, 0.19142862559566576, 0.15663622157467952, 0.13994178674634428, 0.1664347619178795, 0.20237522530219249, 0.12201920572307803, 0.15678354028251865, 0.14919364674677774, 0.27588863947218467, 0.1493958633152708, 0.1374092379644994, 0.09949510226086264, 0.12592040122516696, 0.15192098104425017, 0.3391656634067336, 0.11570954470023995, 0.20406117031891502, 0.18339414059394793, 0.1410917460077232, 0.07897218133533195, 0.10128078426444724, 0.12643200240188068, 0.1723197727434097, 0.1806349523605839, 0.15604176798895483, 0.29263765040424566, 0.11604941960784698, 0.18823362526393708, 0.1264629140496254, 0.08575725354134076, 0.17722737795162588, 0.15260667570175665, 0.08301095090686314, 0.12111496150253281, 0.16057579808177488, 0.2105971260537063, 0.1738016319371039, 0.1688730665632794, 0.10977626267460086, 0.10904734533640648, 0.09647158305010489, 0.08792895958909104, 0.19748805931979613, 0.061303983637762655, 0.11806021654798139, 0.1218478701588127, 0.16815809202530693, 0.09148769080638887, 0.09884413436896379, 0.09451835761748015, 0.2393938808311378, 0.14090020870489461, 0.12600613412477318, 0.15675413782798475, 0.09191618676507667, 0.17287009966469583, 0.13135023324960662, 0.12457830711237847, 0.16990058965259985, 0.1137998254008351, 0.12367749496573403, 0.0955016084856564, 0.14661307957383896, 0.12059605184702143, 0.23899179192319994, 0.10586731436271822, 0.23568040751401456, 0.09778677215499264, 0.16949526785362154], [0.021520648940256046, 0.0432377036720995, 0.07505004098939319, 0.038330002702892794, 0.024113098136900414, 0.06168830696673644, 0.014711716925845513, 0.03952145328625076, 0.0533065083436668, 0.033080775906602224, 0.035708457486884254, 0.03258094184040543, 0.033962780594705574, 0.018424244124382254, 0.06122512254683722, 0.04083450883626938, 0.05062532318275302, 0.05650656485569574, 0.02348751265315279, 0.025458082316383242, 0.06657469536988966, 0.044577549316830216, 0.03541279734382707, 0.010856660026606294, 0.07779774556477224, 0.06951700159979445, 0.015350937817035424, 0.01299588203114728, 0.10431522022812598, 0.08790332628714462, 0.02983351114145931, 0.0237681613033337, 0.046240205260654615, 0.03722209400767761, 0.013311217227319797, 0.05189265477501097, 0.0814136116194629, 0.06421550079399059, 0.057082375691783045, 0.06374286667954537, 0.04197736646259024, 0.021453068494015647, 0.02270668519720916, 0.009177141529958575, 0.04601252392955846, 0.027173165487305775, 0.043928488983862826, 0.06464952407705207, 0.013250543063716784, 0.028726129131692073, 0.01406684230577441, 0.020563536992056236, 0.0244247044001015, 0.021319753873432358, 0.0333820897785406, 0.03257562519021092, 0.04447808429118126, 0.0913474890553663, 0.05239770206953249, 0.020169765883756262, 0.10462581525526701, 0.05007665867226259, 0.0266941498604513, 0.01638122935659222, 0.10664903048065402, 0.01704823338396607, 0.05543660432580979, 0.009927554337698366, 0.09082046652873678, 0.024226821974040042, 0.025869636240625576, 0.051781870800280766, 0.031030015989897713, 0.004599020683071426, 0.03920142771676183, 0.06396512793857725, 0.012490279322880651, 0.04473274340853096, 0.007922038137387004, 0.019048398938931285, 0.05717401512928548, 0.04266664258114273, 0.029357600085917982, 0.04459963563168722, 0.08327751886099578, 0.030811027841522332, 0.04489710757268533, 0.05926733506062339, 0.053959682568787574, 0.030618046462956457, 0.011952326636791471, 0.12186132266276306, 0.06910388868662619, 0.037340240087360144, 0.03607755481836296, 0.012051797408099857, 0.02492848764954796, 0.07759840948687446, 0.011969571275967024, 0.10536777140993266, 0.004830379715009082, 0.05808333085188943, 0.02542696765533859, 0.009249322334184282, 0.06393897369684232, 0.05117194989936487, 0.033414200353886814, 0.042193820775156064, 0.07747079456044782, 0.049572519191931334, 0.05875093817350365, 0.04231923702924002, 0.059269648646154714, 0.04917016981409923, 0.01805100991811243, 0.06571968762023796, 0.01863602147017035, 0.034064340870827436, 0.05497414768943864, 0.03218511187080895, 0.04934945737101859, 0.008651783329344565, 0.007424812600572384, 0.021699285322439768, 0.025249846212025133, 0.0574886895746233, 0.07608469635728868, 0.041946420340888926, 0.017302080448116028, 0.06063429638743401, 0.03257696584407841, 0.0331321191192875, 0.035488211039093234, 0.059238537815549684, 0.11149620667340294, 0.11843571454406747, 0.05419376456449109, 0.08624194971015377, 0.0396590733209685, 0.07151888893736948, 0.050273861195291245, 0.07185488744007965, 0.05596947210330156, 0.024716252566225106, 0.029867699730300137, 0.04108393557309624, 0.03617110564523647, 0.052906943695439454, 0.010400855906247612, 0.03324029456463552, 0.05121586588962425, 0.01156869853260897, 0.08004835866872342, 0.0439961536997749, 0.07720583539095617, 0.035515801695686196, 0.03064665601648871, 0.0876437756983984, 0.06154030261020507, 0.02714267135747979, 0.006034885394206692, 0.06370072801327033, 0.01967225880962947, 0.02021658151680904, 0.02875029154482388, 0.026702864110589992, 0.05681345201728325, 0.03651001528205891, 0.050716372732553756, 0.06230185146353418, 0.01615571222388216, 0.04952003450823888, 0.027517179184923732, 0.06097630101947054, 0.0499886773045986, 0.027120039204976736, 0.01426196873052827, 0.11433023403608993, 0.062119327185134736, 0.06836774713930584, 0.04773287395496042, 0.03736638283777622, 0.049285063850543195, 0.015957492719134016, 0.03594214494730677, 0.035758724346035914, 0.040586667901445786, 0.007630402349957055, 0.02404821048971386, 0.056789178521402424, 0.0832693600246022, 0.05927464736986065, 0.11769250966608526, 0.0390028347441506, 0.034557157571637825, 0.04529615894200341, 0.056186110276969216, 0.04369839447580519, 0.015409918926325778, 0.00788363893779235, 0.01698136348427544, 0.02083174437434683, 0.025628916093058167, 0.045465027703152555, 0.038133658198339325, 0.013004737049942056, 0.045657400041818626, 0.03901733678855723, 0.026664992554053187, 0.08119768973800444, 0.04249505803830201, 0.022427635755570188, 0.008040412607031965, 0.035665966420164036, 0.03875125530025652, 0.05386256943306616, 0.0323011665304582, 0.03553664694810587, 0.007258148736230308, 0.009684142348687015, 0.09011872999009587, 0.057819072652848504, 0.039976137960630084, 0.004710824991155777, 0.025747313066535903, 0.06201217829760525, 0.08400534835433768, 0.019532269648005886, 0.04418875203437863, 0.009326580386128156, 0.04292481804206487, 0.10040796497055601, 0.027242057859116507, 0.03560312805817493, 0.02436892936877426, 0.009328781931300559, 0.053334941696976466, 0.04209976816069215, 0.036038610738732164, 0.04800549783413449, 0.05452114457805311, 0.026882293393775344, 0.03490580801641749, 0.03123395625622042, 0.09857633301327307, 0.008223300777195443, 0.01721107686359075, 0.03399289168056942, 0.0399394155359797, 0.02475345762626779, 0.025654758153963956, 0.02196912447200908, 0.026946715642547896, 0.01389637242086352, 0.009645391706257098, 0.01748339813803473, 0.06325314497394909, 0.014631123518601302, 0.04983937059859595, 0.023904337262314175, 0.012059036938984309, 0.025604498955691536, 0.03365488602749763, 0.03335977746774593, 0.040392548882312355, 0.0417205163337771, 0.03897649664131384, 0.06907857714160796, 0.07344766850433043, 0.04808195340897768, 0.04951572909410443, 0.03019743737944913, 0.03790627181109402, 0.04796261223213327, 0.047339572075514064, 0.044649377720610756, 0.0437742103672316, 0.03787710301337704, 0.04423730668701953, 0.0743396629789664, 0.06919175131066192, 0.03434113609874922, 0.03982205086597993, 0.0272891626903607, 0.05504641659377564, 0.011894816416315736, 0.023098077602504243, 0.0265415221632969, 0.026892426821793762, 0.07949912725316902, 0.03308171819474909, 0.0692246241434928, 0.011611173319960795, 0.04216898037421127, 0.05671877504116105, 0.03801402590808369, 0.06802737427454802, 0.07687328428390526, 0.04435940578039135, 0.031916902573298545, 0.0575201336534754, 0.050186994485557086, 0.06134085161911865, 0.049050905246047244, 0.019456032408221115, 0.038216311424489946, 0.010044766747723184, 0.007615223754152296, 0.043007635977119214, 0.06467792295640515, 0.04650510314311232, 0.06915481821183236, 0.02824069560325194, 0.043346400057236036, 0.04256842627881035, 0.06015780118985042, 0.006158282049000264, 0.03038244569794305, 0.06283460432783732, 0.020364271777291453, 0.037559452316453384, 0.00405299726069995, 0.029571698678116647, 0.003880636335628468, 0.040406759813307755, 0.030703292896730766, 0.03865338373749006, 0.06464674317788693, 0.09874426714715459, 0.014277984756195258, 0.02666532771752006, 0.036535943527856184, 0.041867187697320216, 0.07719781445038897, 0.04592539674993004, 0.06096157680956587, 0.04036797661214106, 0.01713383987906479, 0.05800376496007366, 0.05795735152318113, 0.087619720537576, 0.052728422226444374, 0.024486723048011624, 0.030058327303718657, 0.05197482536576929, 0.029053055238158956, 0.03796448300202047, 0.01918891861644243, 0.017918235389515758, 0.02805687855148027, 0.04486772427034955, 0.04871013784600843, 0.07072575044848266, 0.12204086302869743, 0.1788901105042427, 0.09119522908041555, 0.12048558962921943, 0.1571927538081523, 0.11112191909623724, 0.09448536987146063, 0.1356247740407144, 0.225895764005761, 0.1294666988354537, 0.17806923197161767, 0.16089940894274943, 0.20249090457875885, 0.18602146977378478, 0.10076468615161796, 0.24550645041369626, 0.12893489592017668, 0.1317069391089101, 0.10943663291512959, 0.12966447209398593, 0.1021177966087576, 0.08329040445988217, 0.06034361581588465, 0.1445363071416655, 0.10593303704574224, 0.11853683048919325, 0.11868182028974257, 0.18515222044962068, 0.1826572712630995, 0.14549420816042732, 0.18494343084673728, 0.13961560182994412, 0.11524031584661816, 0.14826102662951718, 0.12260661896077857, 0.17262631516543128, 0.16152180941595187, 0.18051597890594315, 0.1510765376470743, 0.1666989549994469, 0.11370135245904808, 0.11563849004526293, 0.09527805636847213, 0.21882509422158042, 0.221107775766042, 0.14117623018401285, 0.1913533038309505, 0.08210496766672981, 0.179138905218532, 0.17211859805449364, 0.11202990182585294, 0.11505293074033915, 0.14001975917527754, 0.162294102652419, 0.12302369254851535, 0.13904862015718414, 0.24555791620044942, 0.09926253328880957, 0.09177688133692549, 0.15357044495401845, 0.1108656780073239, 0.23323355332737972, 0.12918042709990857, 0.19633344224383756, 0.1776483279442595, 0.17564425725610028, 0.12104699418189065, 0.21891132507833744, 0.08434376003400934, 0.08793830586176726, 0.14043752224214617, 0.07946944134610315, 0.15489226838033046, 0.16342342350511782, 0.11463160536462262, 0.09189600034827188, 0.11871316094672489, 0.07799038603421181, 0.09033480508913917, 0.18956300231718248, 0.13379385454520104, 0.10162757694601052, 0.14405737961492232, 0.12984615750610828, 0.13249469199968925, 0.2776859430295806, 0.15931446495796406, 0.212696528723163, 0.1386275935557581, 0.21004863774343846, 0.1994836723972713, 0.20760530756125528, 0.1367056628148402, 0.22284357778487668, 0.10096889454871417, 0.13165395646806688, 0.17210154493729915, 0.13986079593098935, 0.18807990206105096, 0.11197631397554952, 0.10778061129272946, 0.12610637672966526, 0.15764034833879242, 0.10451972739951265, 0.1795332719601931, 0.107181400300995, 0.11852819667828661, 0.1797423067112123, 0.13432600986092322, 0.11976257116804201, 0.10294260517243417, 0.14176579612878062, 0.23111501378157448, 0.10044337355441625, 0.29584290099240124, 0.12160460659933668, 0.2439483041845022, 0.12162526799065453, 0.13513251658408873, 0.19023191964914724, 0.1483057968078121, 0.14577015303075314, 0.14610009177798225, 0.13144584102255683, 0.14015221577738562, 0.15777948522760024, 0.15531723267368733, 0.14707377420798426, 0.14552462185102125, 0.1281331006377455, 0.09478530095469567, 0.12989025352702988, 0.19275216505892817, 0.16340977181830715, 0.16874183570185017, 0.12656683387655404, 0.3056040868884133, 0.2074238672972687, 0.13661989161083776, 0.07845714042383818, 0.23166019259200943, 0.17516255649107118, 0.13131286348066024, 0.12740196164457068, 0.13681447794360502, 0.13085031491373816, 0.10226408109789896, 0.16348253484935532, 0.10584122140801723, 0.14025064275389718, 0.09984290617848597, 0.1657878619528586, 0.11259843099621997, 0.21369296396451615, 0.0813369415400009, 0.1519134733825922, 0.2945428804284142, 0.2341836096057969, 0.12213319194533172, 0.09490576061990955, 0.10284677523398593, 0.09716659333677062, 0.1309075723251989, 0.16090680935209797, 0.26724842407049676, 0.15514028168493701, 0.12216111585017174, 0.13050108607257568, 0.16996417495031513, 0.19080591868729363, 0.10314646882996445, 0.1136842993418536, 0.13028575407881893, 0.1657474125104566, 0.11180691661373263], [0.06789893197316317, 0.07493697407264864, 0.03447938049512525, 0.02990979434651954, 0.039406042140457904, 0.03857928005257442, 0.05645001607556498, 0.04991353940098517, 0.018759191171416355, 0.01932032184765464, 0.023584252321011117, 0.04016720028894563, 0.09974215795556385, 0.039851483964030786, 0.05889305897477654, 0.0827170336138337, 0.01949547827544232, 0.01846730401138625, 0.07367679008072422, 0.0339432951483515, 0.04410381969665328, 0.038786457040377205, 0.04898732377877159, 0.030557021814128085, 0.051311052314216093, 0.05738160580456738, 0.04207411953698724, 0.03048448477901759, 0.023556196266004158, 0.031660496775481495, 0.03956409757055583, 0.045369676569656986, 0.0701385134110047, 0.016321937981692534, 0.09882636112912048, 0.028733732554340558, 0.07151591651622327, 0.03024262124522319, 0.03864514063142481, 0.06623415396578851, 0.04574017967247675, 0.04061349247011446, 0.03765014946580895, 0.054866807279928084, 0.0815726131681473, 0.08050021264822253, 0.01942894545443837, 0.02205082008825435, 0.03818497459794726, 0.026651042092952038, 0.06538248635948667, 0.04236594157954378, 0.05651815193555048, 0.017128438959198616, 0.010921735365334298, 0.03613499609092551, 0.047997461571808786, 0.07298274506484309, 0.07712076132696483, 0.02840182304592623, 0.06665149568429878, 0.02528777714037607, 0.03416043894004918, 0.10535332299168072, 0.003266839029815709, 0.04107959951544481, 0.02080330910581735, 0.039992107063411705, 0.05418012436899928, 0.0548960182124809, 0.01105951244807652, 0.016071092066985947, 0.05825817126840834, 0.05985952868697144, 0.09621625360582145, 0.018427128445417173, 0.025995828158732866, 0.03552331701822339, 0.025678658181981697, 0.036031524425432566, 0.036430024211445165, 0.05777065589603397, 0.060108128048840075, 0.04291696564084099, 0.008872653181183963, 0.05371750685416403, 0.03586053743117279, 0.017536436320252476, 0.039454696384528955, 0.07066903695944818, 0.057454054739566586, 0.010112709170507809, 0.06648746859883109, 0.038555381939776485, 0.03341506603324125, 0.051105170015005336, 0.16253744282068747, 0.020832903082332304, 0.00606422943453635, 0.07063444042878766, 0.03318032520192285, 0.03187579812572128, 0.03366518224919996, 0.03068887703721562, 0.04862496419058693, 0.07899648164429011, 0.03410290573693572, 0.050655729212467714, 0.029569704934293707, 0.04543257238824041, 0.03754346406147365, 0.02929665204588204, 0.009565037701489225, 0.0369418207405796, 0.014231059955613268, 0.0422938373841105, 0.049185617977092345, 0.02470189033286466, 0.015790036432595266, 0.043232019299701344, 0.055013543760944764, 0.019193325537226854, 0.014482238160957013, 0.023579902856821017, 0.019401289680371844, 0.013517427986728088, 0.0438582731951629, 0.05852429106110527, 0.056544041876951535, 0.031635734898548935, 0.05781049246809656, 0.02568521780983335, 0.050868927651355346, 0.030536025259343368, 0.05562042712324089, 0.026113351791976925, 0.05609913631492565, 0.04834686661319387, 0.01680609788895855, 0.0726055616753236, 0.014250587536803177, 0.024180201693407954, 0.02240899492115263, 0.09878110831543323, 0.03257177559839141, 0.09400949137465608, 0.02111140477110542, 0.003992349910174287, 0.014014502221177665, 0.029223854540877288, 0.13185905352715524, 0.016888186125265017, 0.07533000016044225, 0.008924414869397879, 0.047723799643497315, 0.05715286727213571, 0.031591759536475424, 0.06002386603804846, 0.00890332829928206, 0.03659745272729666, 0.03351282651325868, 0.022440515608797153, 0.07216784967890671, 0.030677247822525042, 0.020369772288587787, 0.039796314142163725, 0.05579187377025524, 0.053187358688803456, 0.010826389019888256, 0.0647099684142778, 0.044544213000805154, 0.059929246518520586, 0.025983798663101854, 0.04291229633494251, 0.02739216512700002, 0.02824812091045803, 0.1360211785762541, 0.05735975314652728, 0.022717653661065047, 0.06310373867651628, 0.04205428935106724, 0.023736952796518326, 0.04724779091174564, 0.055199507774124225, 0.04884211181272422, 0.06421302249955554, 0.08791029002637633, 0.010573212282672044, 0.0437828901434137, 0.045767456233020753, 0.005551257439243097, 0.0383255479016131, 0.04138539500174023, 0.004044012006958046, 0.09814169302943254, 0.036769945084327654, 0.03706365553361755, 0.0845161374778517, 0.09721661887822614, 0.0380981270404112, 0.031852970620797526, 0.03921659242722296, 0.0373601507125122, 0.03312976722935996, 0.012415344432567157, 0.009975293106699904, 0.046744536262966936, 0.020988801974923383, 0.023376828269852747, 0.051393027552553726, 0.10397329220488187, 0.011644186921447757, 0.06930448114871979, 0.01184610088521074, 0.013267055131314744, 0.014541699990419852, 0.03781769672528871, 0.07062892459573285, 0.021004882160454028, 0.07769459948664711, 0.023573172774406213, 0.07938272785395384, 0.022049414316913294, 0.041103390375933344, 0.057633353787804806, 0.07084803340295631, 0.018649288197799076, 0.03454158683457682, 0.03432942261438697, 0.037148733428048517, 0.05358753620737022, 0.012838142612318118, 0.005044986319262534, 0.07354688455140398, 0.016079019161782438, 0.05361305459612801, 0.055445873989693584, 0.028148531395521377, 0.02332190359612146, 0.111286673965233, 0.038693519083843116, 0.05783552822146205, 0.02981551765133777, 0.026467008621341763, 0.020207635525073257, 0.01847356486494743, 0.03454998315822694, 0.016332870056372017, 0.014344345207416244, 0.009059736640342783, 0.03195570301144354, 0.03274805242976835, 0.03729997833649959, 0.04319326291161199, 0.007982452788705668, 0.040562900023594986, 0.07393827121103964, 0.023623960573346387, 0.027193901572196234, 0.023661757436310573, 0.04376123283779429, 0.059995815728700934, 0.017537472454170068, 0.05018350878550161, 0.02277458356993814, 0.08704460301106015, 0.04854750121012331, 0.014160556883941737, 0.04085204841929578, 0.05141856126307, 0.06015025522379626, 0.07146426686836828, 0.0411716066751509, 0.021601499944564798, 0.05716104909116703, 0.10314448466224056, 0.0719023236043511, 0.014223186486971476, 0.06895461645458015, 0.07992243679660944, 0.04861959774467734, 0.044762628498457135, 0.08153384911917871, 0.07799928031501271, 0.019177484754172545, 0.07693630267655657, 0.008812724995697218, 0.02246971121959148, 0.07116857991223374, 0.013482983716042533, 0.05607166057152133, 0.028881365358228647, 0.05783520263409423, 0.025953331346353217, 0.03017085987413603, 0.0870201648062756, 0.04173119942988119, 0.06512567070463011, 0.006623394616443905, 0.07476788314600145, 0.08064367793380253, 0.04234210092334017, 0.06445363539481355, 0.14574994363131064, 0.04834428489688904, 0.05780115385629958, 0.03376140672292921, 0.038393162821810094, 0.10785547340469015, 0.01697038352910069, 0.05435990222219018, 0.019255855548826438, 0.013227666720687864, 0.05616611155170587, 0.058095082640647895, 0.05960751640340013, 0.03797930297291568, 0.01335469367463262, 0.022640945277206843, 0.0508677746890293, 0.04325570290788047, 0.04456114354393175, 0.004091632511136273, 0.05149226658226502, 0.07456886882503187, 0.06212792269164517, 0.09335241010112148, 0.06855928444213445, 0.05512413238325427, 0.050770638570670164, 0.023845520861927542, 0.04040436195810476, 0.03443017466774872, 0.03086991318982215, 0.04642925660816893, 0.021009298657337507, 0.023896117138886647, 0.09884914458398858, 0.07159234144754949, 0.06577945013921108, 0.012347077380024619, 0.020477022682767243, 0.026082438229012395, 0.10221977057235856, 0.04009330727820916, 0.02871983954983373, 0.08190049879973935, 0.062076590970278754, 0.03418570068935233, 0.054148722424983024, 0.1261678399638303, 0.02939517095294451, 0.14006488175401766, 0.2508713794691909, 0.1733024796891597, 0.12467104971649186, 0.0820902357959459, 0.1628163601121595, 0.1773364841938019, 0.18038781239621102, 0.1220944585398801, 0.17868905838939453, 0.2963303167733454, 0.10823798110528339, 0.17252486980249807, 0.1272975515213705, 0.13233686256552898, 0.17104693297897616, 0.1958827220744664, 0.12146840382727886, 0.2252179906973916, 0.21042903104136068, 0.156119296086892, 0.13432144397689452, 0.1147902774954996, 0.1595675957299048, 0.17274090659714517, 0.12575265861326648, 0.12221989011572254, 0.10450233720363149, 0.13803237388210912, 0.09443421051987717, 0.11315695505829589, 0.11330002963903452, 0.15866974068264808, 0.11203850499324261, 0.24896132309109936, 0.11353989942900597, 0.18259826717117142, 0.1504390758852805, 0.0982602911009904, 0.14351275238779285, 0.14469779847610384, 0.2053740918035469, 0.10726399990099092, 0.18638942180381668, 0.12365872581158915, 0.1936611896681209, 0.08618541242134187, 0.11061768002447583, 0.15113715052364335, 0.16746921044203544, 0.15627672715533167, 0.11696981296183602, 0.1419539320012254, 0.12591163717931317, 0.1239191190970521, 0.15505061875427925, 0.1311329553925222, 0.17023183074930023, 0.13498288429071828, 0.13848883971091241, 0.13604413057046552, 0.08059600428227456, 0.1507057817352395, 0.21432046658329426, 0.1454201427799079, 0.17149241310694527, 0.16112626289888737, 0.12762984215852716, 0.13966879897540616, 0.11791469814676432, 0.15954211564554324, 0.08629333122723526, 0.12357901436306777, 0.13988854363560677, 0.19679222165817217, 0.19604680278608877, 0.14990823824078808, 0.13771601021289825, 0.1138745113125732, 0.12102252533358913, 0.2117674479321126, 0.1333498146625296, 0.13314939073977933, 0.12282195095453532, 0.13364131111771832, 0.15671120626070809, 0.17173676451127376, 0.11438877847526344, 0.17097715769083272, 0.19963638436409736, 0.21816175400970444, 0.10258453567662548, 0.14913689495334703, 0.12585122348560443, 0.198913840877433, 0.1308947633351049, 0.25890777969071943, 0.13693576498377708, 0.06312195241691605, 0.17849879279252023, 0.24029475426481617, 0.12119853403419258, 0.08179602738950523, 0.0988257559196603, 0.12599720920045532, 0.156172018257841, 0.13002836385801916, 0.22263731627214342, 0.09002152109338392, 0.14344910580304363, 0.12798204342083586, 0.16544655446083317, 0.15864041483690663, 0.09062625557905243, 0.14114908002797635, 0.14735745656634533, 0.12585457128983352, 0.09767579665828137, 0.124990324519815, 0.15047690530698146, 0.1353573327463481, 0.12887805219619505, 0.08113178319387859, 0.14232226707521947, 0.15572604783360036, 0.11975499455847087, 0.1561093063003594, 0.21420025206621618, 0.11259542027067755, 0.20808311659962903, 0.13965744555236834, 0.10922764412938588, 0.2647426424007262, 0.09669456826222521, 0.1834293040296724, 0.10279849637299777, 0.15742664045143515, 0.17866261303424838, 0.16215279007390623, 0.1551348731041916, 0.1409210616181935, 0.09986183621109494, 0.12552256410520884, 0.1312335580587387, 0.13786712871684184, 0.3239924340478836, 0.1228058401254877, 0.11731568633789018, 0.11153186040539896, 0.12820366499645094, 0.21006048146274783, 0.13202567765068624, 0.13774945761167234, 0.12419003843059465, 0.08153483737260103, 0.17072526798132928, 0.1880186150271085, 0.1641015492139324, 0.22298752570584898, 0.1542936319545392, 0.12469870549055839, 0.229946990166941, 0.2792370259281128, 0.18083655605873755, 0.08778048408848625, 0.1193023055431343, 0.1105254660210302, 0.15159654280831739, 0.10945351749298074, 0.12935751598448525, 0.18674723082973113, 0.2477933914070168, 0.11814369714909023, 0.1037167906460743, 0.19685738509701145, 0.060462616083602753], [0.07097233882955006, 0.029392478153890664, 0.07567992614161584, 0.04291104761162593, 0.023330485696093212, 0.03565115027970845, 0.020879176708178657, 0.10323256945177432, 0.02160246330012958, 0.03721760856288095, 0.05620232452788661, 0.02790877460351875, 0.015050439828736408, 0.009757429192353402, 0.007630398040712481, 0.027064710419865388, 0.06490771869017233, 0.067467364001899, 0.025979351522701404, 0.02241698713342269, 0.007950914864082852, 0.019965852430510907, 0.021248975010108084, 0.014182626919430352, 0.05542824247611627, 0.04914395428533035, 0.028181869626766252, 0.01727265118050479, 0.02858586800885537, 0.0203583384263179, 0.12276658578024757, 0.03864831223543133, 0.03176318894651148, 0.0377384104555653, 0.06427802505993074, 0.05418217748463635, 0.039231347280644605, 0.01614187667596965, 0.023068717282806194, 0.053583460619613055, 0.010360279101728192, 0.019936674056694876, 0.03815502822098713, 0.015547140595322896, 0.011809462730232026, 0.06797000961077791, 0.058389042068513176, 0.01341120798080679, 0.04340548075795655, 0.02987945343427841, 0.03209232904707953, 0.04563488854816364, 0.08267423228150414, 0.050568253462833744, 0.03454835139094822, 0.02281661881434341, 0.1315890841426388, 0.012121572696243324, 0.09705633796270817, 0.04568478768511165, 0.04720177967101336, 0.04405605411457439, 0.03589639800690836, 0.02154495882531328, 0.010294811142938993, 0.08377746784038122, 0.02854123381116698, 0.02829977438875264, 0.04963479830973572, 0.04617344835893281, 0.020977454297544978, 0.07384784985333681, 0.07730541149935416, 0.010885817333004408, 0.039523448945293506, 0.057242786842248136, 0.03710952887852346, 0.0771374543828349, 0.054631725539483374, 0.09874094232556321, 0.02940495581095738, 0.01644546582904314, 0.018315430910837267, 0.006870323906637609, 0.004994510701151505, 0.020862571752419876, 0.05987131111924687, 0.0843074398055192, 0.06064590261948686, 0.02736573700883216, 0.003927134520997624, 0.04575716767219767, 0.033662619685093244, 0.04780918780353762, 0.027469737274992852, 0.019001633101593585, 0.03061927986451455, 0.0748432202324752, 0.06480294084476848, 0.040004310844045494, 0.032597516152647235, 0.01282466425290031, 0.02511864982455248, 0.05300425601402118, 0.014772358530711745, 0.013639472496335306, 0.012795918718761495, 0.04590090491899079, 0.04509099293500186, 0.06958498424219509, 0.05146999257586656, 0.04833112733678953, 0.00689413104649453, 0.03859509593777118, 0.043447320649941126, 0.008291654014629463, 0.04789789695472968, 0.04031064259188791, 0.028051588714363116, 0.01896100554374918, 0.05583398179301331, 0.04087927518412471, 0.08485212831968263, 0.011508854616793894, 0.045929832399011626, 0.05312861506676963, 0.062420729157184406, 0.06268988648850111, 0.06942065838243693, 0.016064509456496567, 0.030633107751547813, 0.05827934210819583, 0.006239591748453678, 0.04068147511251512, 0.030928875146914395, 0.03375998179939005, 0.08114373416549737, 0.037263156320419044, 0.06947643724420378, 0.08045979384933749, 0.04622308702598657, 0.0595345426981728, 0.06123759828868413, 0.03262010808553427, 0.08929742244823326, 0.04490832693033642, 0.042267054950277654, 0.016496858837443496, 0.04045776594730635, 0.03149913376077049, 0.02852046899797936, 0.052746049909582066, 0.01027382799469295, 0.034707827914145686, 0.07265448405016815, 0.04870714627266411, 0.09910750773645217, 0.024047024968651035, 0.02985393887596025, 0.028667630657794017, 0.03426448517148534, 0.09734143758372915, 0.022443438234228282, 0.08747612501704886, 0.04654678598707242, 0.006121813390974797, 0.057703328258808584, 0.043799177172683904, 0.013587224342289471, 0.052753235814311815, 0.014987816928976007, 0.004527168339043255, 0.04030376312232787, 0.10690878025226055, 0.030946309392851208, 0.03796918295143593, 0.03760032693765337, 0.022420980366728, 0.12260156278047832, 0.019346387989278284, 0.023530855992688768, 0.030180416820991426, 0.016878755582917123, 0.017716013075363253, 0.057472410206232345, 0.037010439235957406, 0.010144240391861287, 0.008668845065028198, 0.02313731662598589, 0.06654464940149939, 0.017093285099573193, 0.03992141630019873, 0.09084537204715515, 0.050139389781942295, 0.03372991667880166, 0.06014542886987329, 0.10768366286591177, 0.03146620921700472, 0.05086849481167813, 0.018020644108013763, 0.07563289600394427, 0.04454215605472846, 0.03321355043519889, 0.09015613040255924, 0.005660938726167285, 0.0318365361196019, 0.012225358457785222, 0.026566956282383012, 0.020313491639230522, 0.06399159627636114, 0.054073067412020705, 0.03407835644940215, 0.027352405163729866, 0.015385452950853976, 0.03059923900441537, 0.03979344131244768, 0.032378667815318035, 0.04548533286358561, 0.01605850332717021, 0.040386512109469024, 0.020256019723151, 0.04887836309330118, 0.0750395532457098, 0.02918002090506977, 0.018843428284350424, 0.056047953980704474, 0.05200459171206721, 0.01304851993242459, 0.1058420028177, 0.08693504477700881, 0.04172188380072194, 0.07779830480895697, 0.08681194210845618, 0.0069302836932512305, 0.03485478656066041, 0.015193769133709853, 0.03605924531697266, 0.021678989738105767, 0.027781287996819424, 0.044244952244503845, 0.016043968724026796, 0.03426141315890897, 0.008411659772748189, 0.03497839484724306, 0.06786799734278072, 0.01900590787221107, 0.011531401542015375, 0.01625167239727753, 0.05234053275818306, 0.012948081975111799, 0.05393450508915609, 0.07325699688085625, 0.052443307283664906, 0.0207436480934942, 0.07440520946176783, 0.06938339586579992, 0.051638815371740254, 0.06493884484253584, 0.05098618506904572, 0.03378930764513151, 0.029042510037881233, 0.04592142458404264, 0.04207480901611909, 0.044086199674394824, 0.01503349492146123, 0.026965850603676615, 0.07057896034131128, 0.015331809559176046, 0.04888889297182041, 0.04691163536101099, 0.022101420195653074, 0.022164070866100734, 0.037290007702165076, 0.06206716042793086, 0.09824801837244342, 0.07808028645212613, 0.13781290501356125, 0.004328187534420361, 0.031079206495515765, 0.052968169442347945, 0.05349183267342949, 0.013438446236954582, 0.026603536980767405, 0.06265170083591534, 0.02486620470130396, 0.0850068474368703, 0.06422780416605454, 0.048588433287917614, 0.025938948045574853, 0.09863737489907973, 0.01922444594393094, 0.03283370105970291, 0.09431338313245967, 0.0652355736782474, 0.03389387481635617, 0.028799097091259978, 0.06140101633425202, 0.015474852538787791, 0.0506662322779096, 0.03431319687215071, 0.09107834704580808, 0.037474914514009035, 0.03434789682468099, 0.06097102267367225, 0.05453174340448553, 0.04243767422233378, 0.05508790025487543, 0.024928188875257492, 0.06071113500623934, 0.08588618613899716, 0.0061534279243900415, 0.018690930822143154, 0.020041856013478774, 0.024720598199975588, 0.048453471578297116, 0.008188311626473743, 0.04679843820931931, 0.016839123939374284, 0.09244867915948553, 0.01670568291428349, 0.02886601678666569, 0.024940028764127244, 0.07046593172896294, 0.021954578377546805, 0.09201625316974618, 0.0386114748975923, 0.05461674852056369, 0.006333226366193906, 0.04368586127736396, 0.05871574792470183, 0.04376030970184554, 0.007472424965066415, 0.057275805231784625, 0.010374755290667377, 0.027934474938158548, 0.025226413497641206, 0.029046767571520422, 0.05168550843072515, 0.017525419975901325, 0.060209469989903515, 0.0743526941345584, 0.03933035265353899, 0.028201102264105316, 0.021133385748872836, 0.006764246105787255, 0.057905885736427964, 0.013228880012437943, 0.028223140698467052, 0.061756416013644594, 0.048307547150480176, 0.0473781292807431, 0.019615962838513717, 0.14045980007898423, 0.22925896660214473, 0.1953521448998682, 0.12798852452467527, 0.1659958854678177, 0.1465583042872529, 0.13743205206288447, 0.15396479637392108, 0.19911674692505793, 0.1799480013188816, 0.13940541794703853, 0.1533242549386717, 0.1920207809176176, 0.12603834046110993, 0.08858139070892528, 0.09779077113395739, 0.2041704297786759, 0.16899217791374654, 0.13956327802471577, 0.10575461516817732, 0.25144724776187255, 0.10185336603993371, 0.1136071083226031, 0.11405681725591423, 0.1567765535606492, 0.20478351462271907, 0.1364998609548615, 0.1332083948317074, 0.07244620006531477, 0.16117642633616924, 0.25387144106770715, 0.1272209350680632, 0.12484533471926568, 0.19738966298680152, 0.13982376324072962, 0.09050859979564145, 0.1486697498588793, 0.1688524281545993, 0.11883099293035847, 0.227543419948028, 0.10430536833741974, 0.08362767466854665, 0.16372484845980523, 0.1328161578144758, 0.10696828230133942, 0.1453169660582658, 0.14592134814348914, 0.12707769960886048, 0.09657280624754007, 0.0764849926194837, 0.18874696546023895, 0.19291508131690566, 0.3284809738397598, 0.14968660900429373, 0.09515107729502263, 0.1717770913796079, 0.2786173220844038, 0.0566006251310389, 0.1912975173083044, 0.10814805770473135, 0.12181493603894789, 0.1976634321674224, 0.1390421850186202, 0.05971875237000566, 0.09035536688902686, 0.1827519290870236, 0.13215836407917161, 0.11260939371441642, 0.1197674741307574, 0.11124052482867434, 0.08979510380736283, 0.11392079068407898, 0.1139500016166318, 0.19554568935305844, 0.18369363500706612, 0.19909592465527598, 0.11732392178307618, 0.19279714974184192, 0.19807391739901037, 0.13143047329879579, 0.09457433566210732, 0.18288666863114605, 0.18047948247723042, 0.1604216918349266, 0.10995620140625585, 0.12463748740452914, 0.1203015446662903, 0.16113084410467457, 0.08452447251446786, 0.10629653044405485, 0.1194013300682268, 0.1510552404027793, 0.10393697963727098, 0.16819563033359666, 0.14740660876756714, 0.18697941675782206, 0.10981441385323003, 0.23867725154324887, 0.29472205307214494, 0.15608868321343777, 0.21258471052973502, 0.09097933018159482, 0.09498188677694529, 0.24688101133271573, 0.10191011017248516, 0.09512911355423351, 0.14474285976781, 0.15269131309563114, 0.08770763678776641, 0.19899287050770176, 0.20455316730564643, 0.1614951342344284, 0.17340185661469737, 0.2061484687991681, 0.13942884491576304, 0.07696924445730063, 0.19402102116615544, 0.14932725248077225, 0.09250561481401806, 0.15086480626656165, 0.10448126212483454, 0.10050516620638872, 0.15762940860323368, 0.09524437914332075, 0.20043048046288953, 0.11916341380246225, 0.11495946801357693, 0.18062952845808, 0.15974897470685745, 0.22853985518938114, 0.12552700741516967, 0.2037463541473112, 0.11717766027657256, 0.21068986865781972, 0.08990909769049577, 0.2146327393429895, 0.15900600731613176, 0.13374700060775205, 0.18181336412747062, 0.16949399614766722, 0.15678107347940246, 0.19694884067341206, 0.16798132489765846, 0.1305647173355664, 0.1291036038028617, 0.18095580530503105, 0.10696586912437793, 0.08723712856731108, 0.16783129423856738, 0.248307436404209, 0.1220358604745519, 0.14066295127474493, 0.17811625444841, 0.12221465007432046, 0.1620390106953921, 0.15785889790183114, 0.23065894631849182, 0.13563821122290629, 0.11418826262196226, 0.1385804178613809, 0.17571271487301396, 0.16434908754402594, 0.14496026019896233, 0.1145613014758114, 0.37657624951774077, 0.08361915577082865, 0.1388207396432277, 0.19602404997473766, 0.10306346320336866, 0.1275764075258086, 0.09633505086023962, 0.13590197529523604, 0.1383552339769179, 0.18806349245771287, 0.18511137264149805, 0.09440254810596667], [0.033295058359902714, 0.02113681399233399, 0.02703728830261577, 0.024287065213185646, 0.018475259834479903, 0.013215740646926627, 0.03252443902555012, 0.02708042479841219, 0.04175584830884491, 0.00872222607159206, 0.025681636348787337, 0.02487875705194329, 0.06762088036104556, 0.006310318422038109, 0.054143604957648826, 0.056835507688623284, 0.04770184739402706, 0.024053965725245017, 0.04468793875627941, 0.07551869527707178, 0.03368290569332819, 0.0444172760621915, 0.09547612840129484, 0.02174503992371742, 0.01873307523407763, 0.008537748268985701, 0.033417605614710244, 0.06743641404975807, 0.026054548798128966, 0.04288366379877252, 0.06994632493344045, 0.0542464905658797, 0.064035274779364, 0.06702671022785288, 0.060267669689511104, 0.02883428350962218, 0.042970745013125485, 0.0228029977710497, 0.04188238305129832, 0.07465948936559501, 0.05879576580839292, 0.07802044732436057, 0.038293556069895145, 0.03538233002707843, 0.03843468861774572, 0.025197629659106175, 0.09293389626808705, 0.041505161357382615, 0.04801803486301534, 0.05617871369806029, 0.0031592412626430875, 0.11400232542186015, 0.0022540801306134995, 0.030300265531085675, 0.05618412993968495, 0.02165189129300416, 0.020219672681583513, 0.046741069715109565, 0.05202124263310144, 0.037789803463965654, 0.03776066914020527, 0.0517856169702305, 0.03285487956036964, 0.03028399956923339, 0.03184702194806549, 0.05953375745805041, 0.0668807628173982, 0.03179670529319875, 0.028785788228795416, 0.049344370547201366, 0.08569123208402626, 0.026104200871721394, 0.02870863551394113, 0.012320537221497826, 0.026358256694830717, 0.02933071231499555, 0.0607582685657807, 0.007726159031247541, 0.006657729240795297, 0.03426114119769585, 0.024942039744928483, 0.0535724979014166, 0.08755405914158591, 0.018228537388025753, 0.07338444326793955, 0.033025085144946655, 0.029396931039950544, 0.023689779017360944, 0.03503561395430758, 0.07052189445183163, 0.0749444127863934, 0.020779213725378918, 0.059198789343598394, 0.046244817109958786, 0.03949121196543978, 0.08392742955155912, 0.0841678049595606, 0.055502001421465996, 0.06894044382798095, 0.049320380503852526, 0.07264735943247234, 0.07084693023634535, 0.018633908982719147, 0.053587838812100316, 0.05393136029822692, 0.04619500224268244, 0.07748249272305159, 0.022929408024215413, 0.030186233343556527, 0.04255660171169908, 0.021859633270651106, 0.029043513613062042, 0.00873752963548947, 0.06331206479620549, 0.01834007978980099, 0.07018045672485906, 0.13537044817161176, 0.05143314757714829, 0.03896898131877665, 0.038874622269143025, 0.057844943442051454, 0.0912908981403997, 0.027461789112778443, 0.04304726953588186, 0.005694480449517048, 0.0016864987546502945, 0.06746197074291206, 0.05755497150183205, 0.16042069592062505, 0.037569587659691615, 0.006839397415939358, 0.08528900528026205, 0.07024096234911872, 0.011575944766762757, 0.021990904351696376, 0.01613457585805126, 0.028611112521180225, 0.021205133713421323, 0.039987541179382996, 0.03964853961200964, 0.02231964991698342, 0.029061740760000485, 0.08065658651532666, 0.022307773638937264, 0.07878915526934209, 0.015346984803346137, 0.07613250024376378, 0.03618298000806282, 0.04879477907032256, 0.02131473408230851, 0.06308802621318929, 0.09539853901632371, 0.09608633275474272, 0.05443087643793514, 0.032313580985271165, 0.024428774242199237, 0.04774962063698519, 0.0420574149897983, 0.029205514395970012, 0.02977755033381043, 0.04882508550860709, 0.01493732598910649, 0.043179787425023895, 0.028156445083779194, 0.03898835951282133, 0.03179920657027153, 0.04828900782271259, 0.049133309493622476, 0.0518390401116302, 0.017642378619301225, 0.057851091297643806, 0.022185613258531498, 0.02048785708123638, 0.030142526112256512, 0.060131072382172274, 0.02797801554533503, 0.007818273443263024, 0.025211614594163916, 0.0017671226857102387, 0.030519935497713667, 0.04072709947884564, 0.038164742215867006, 0.03005903785026843, 0.023083912636784297, 0.025214339951954545, 0.03284505448274074, 0.048429531330663356, 0.007485177456175969, 0.004498372051579457, 0.02493370470831231, 0.01126544550061226, 0.05301410024384818, 0.061226719840159344, 0.055774131173928904, 0.03633532042224561, 0.0452246752777888, 0.03406845476298082, 0.04498368699944789, 0.042786317006234205, 0.06478811704343365, 0.01137378661247391, 0.009407401704529842, 0.005877241257563114, 0.1297020104022757, 0.04538338571306198, 0.04380715597841529, 0.0518810638647166, 0.06676840836242323, 0.008318181724227484, 0.03497379831969738, 0.07846433398944717, 0.05883772827444538, 0.05304513063522116, 0.002920426998189801, 0.03327820825600817, 0.032775248551080306, 0.05412453319877387, 0.04357844808950059, 0.024227465487896435, 0.02780962367391875, 0.017890468532700213, 0.014364337229410247, 0.03148856557785504, 0.020095093378556833, 0.05756013876488132, 0.05586316591248878, 0.04634694046070499, 0.06300004484552531, 0.008910428019120328, 0.03231577965761385, 0.13489323668181896, 0.05708371634565054, 0.04160197954925318, 0.04238423192873598, 0.04282146895063981, 0.020812090388649417, 0.06936173089930127, 0.010560792082199648, 0.03250850439672509, 0.010297867833756873, 0.019762302869029587, 0.04547246641689732, 0.0330012368278638, 0.026031522110344905, 0.020218766782613053, 0.059734870859932516, 0.047565131343059966, 0.07767963778948592, 0.03130130687608354, 0.024687723451924902, 0.05367315036334819, 0.025767623972628387, 0.058563296427770015, 0.024835333273175265, 0.023028917099920013, 0.08725689363575752, 0.0260914416773425, 0.04451367673614333, 0.03261814690044811, 0.044995649462385524, 0.04675616930809714, 0.1634975654944297, 0.04256377995554959, 0.006839556379183646, 0.03174540613056912, 0.07780618019281857, 0.014680254652405219, 0.0591378317274634, 0.01971356627050667, 0.10501668097511416, 0.044012115141677285, 0.024342131613182928, 0.019760749625763106, 0.09671961167646993, 0.009659713720001522, 0.05685356055055896, 0.032627014368171656, 0.0711959905381645, 0.026296933271711873, 0.04637272314979665, 0.04350920140202488, 0.03439848544076085, 0.015540627890356607, 0.029325954908985766, 0.06718045641337672, 0.019331713575088692, 0.04051167555453797, 0.0640623368352892, 0.03253148320401388, 0.04778496027293225, 0.01589265869810216, 0.021463588796435826, 0.04067205223104647, 0.03882442818834417, 0.06687900847605159, 0.03717366575954422, 0.0488353242737151, 0.06519456499166067, 0.022091891977094838, 0.03686059243796814, 0.058914865667541186, 0.07116149359893414, 0.07781983187962925, 0.04795660227236729, 0.1061170130607582, 0.008212037369488709, 0.029836994926294977, 0.012562023456989518, 0.10267421392904175, 0.08902035142865874, 0.03460011212155223, 0.058057686058624144, 0.03804412167218905, 0.020331418096658685, 0.09118687106116165, 0.057653390817464366, 0.008659053503745988, 0.03994431083781585, 0.05834712556773617, 0.06212576998457794, 0.032736438536836256, 0.009187736525951375, 0.04003089792545765, 0.04759802715852857, 0.07975320031325664, 0.021475788746629993, 0.04778652309229778, 0.02326998773271278, 0.018485812695636865, 0.03595106604118501, 0.05113436562579967, 0.033064657416675365, 0.04568724299690897, 0.010345362412232545, 0.01663737468451502, 0.04802202235066122, 0.025380546557566813, 0.03574282419116747, 0.05859893100756792, 0.05252073962061156, 0.02204459562386957, 0.03897331354598846, 0.055363622959703214, 0.046945691799684885, 0.06597518560386474, 0.02435210033229763, 0.021302185562108795, 0.0015150294841019317, 0.04204008225051146, 0.021351812737843683, 0.04137892538921968, 0.05078983290361301, 0.1519623651139198, 0.07430113641725433, 0.08647009069400449, 0.13590997325316553, 0.07347869506526379, 0.08855941164637766, 0.10179318983348147, 0.06597242768733733, 0.09490460382714387, 0.10585698749749892, 0.1503287745459426, 0.094931899539886, 0.13382842043234458, 0.11995733370103183, 0.18057504428490517, 0.1637803438690401, 0.19076110254372322, 0.1037870026043346, 0.17402100887510086, 0.18130010053996118, 0.26961741308050774, 0.14868003075882313, 0.1354759231570267, 0.0743044765606042, 0.12369197402750293, 0.09372624568641187, 0.09642806925600576, 0.19226445816457274, 0.07924215071984837, 0.13617071893907365, 0.201261532643149, 0.23708040255212018, 0.07807165264121949, 0.18683496321881973, 0.18576274655999678, 0.1643302571028471, 0.18792320643701863, 0.09989147615288535, 0.09029872234790556, 0.2094991994841445, 0.14037177657648442, 0.10612006209069684, 0.14258400867542914, 0.11786959088978269, 0.15689439320516202, 0.09859247448583765, 0.1723251813241551, 0.14717906533229738, 0.23493785381076798, 0.2407001679943454, 0.08551215137084646, 0.26498193762475447, 0.07551629742186877, 0.11205198814070995, 0.1971695046391218, 0.152406650144727, 0.08832013940498715, 0.15005040883777604, 0.11875893470020064, 0.10574605030518387, 0.1435765675118854, 0.14863113902749556, 0.122119318093023, 0.1394583699443648, 0.1508418695941087, 0.10006362377035041, 0.1968082482175481, 0.14882931065174843, 0.08546905126422645, 0.15709762100971517, 0.1543426156164177, 0.15152509744849899, 0.21114878596798067, 0.06940201946323918, 0.18460768515304213, 0.09928961449693288, 0.25280247262168315, 0.09040727700677612, 0.11071088994222303, 0.2811533489054249, 0.2164111971374481, 0.3060174066453211, 0.16600060456943128, 0.10984648995461965, 0.11936111045220207, 0.2243359936701675, 0.14937487250614553, 0.1001513714811975, 0.14579439205267739, 0.2143251090761154, 0.13693676089807866, 0.12980566209843084, 0.15032964788617628, 0.15965324435983935, 0.22488841967236614, 0.18712393158385832, 0.10734319807060304, 0.20844579794474188, 0.13316140299843204, 0.17202720376512698, 0.12225487735122444, 0.12975191336966332, 0.25094418846551453, 0.18237936520768752, 0.19548357494415777, 0.06526592608180738, 0.16664747389093523, 0.0863978409418656, 0.08915081620216371, 0.10614145126554275, 0.15765738613422842, 0.19667205310636954, 0.07711953558628598, 0.24119843158029744, 0.19914918308777196, 0.1456079568954245, 0.26601713691507617, 0.17906638733561964, 0.14467381992407385, 0.12295377170366627, 0.13806629625539626, 0.15850875496623978, 0.0955175890797569, 0.1244854419341972, 0.15443243176466034, 0.17140422106510209, 0.16625198866090468, 0.14458962686119542, 0.28303630109275546, 0.19623650147789912, 0.12316587080638255, 0.1636455430378837, 0.24405687416513122, 0.1836121232519227, 0.09205268065054571, 0.15843502666440704, 0.19743938209308734, 0.1063427332067682, 0.15240992900104294, 0.16491101303648564, 0.13614081086650973, 0.09274333189692228, 0.17312868498265746, 0.13104067244116338, 0.08758346925699904, 0.10356292954736179, 0.1505516295231158, 0.2034101181573445, 0.17260950719637258, 0.09510338832173618, 0.23828398796819875, 0.20654210009642188, 0.19187395250605, 0.26210935305683847, 0.2029039485440139, 0.07880359602671477, 0.09820949181073135, 0.15089633844552502, 0.10574486286890124, 0.10019063348731688, 0.14481566876413363, 0.12351726001549153, 0.1495767519959519, 0.19472913155632635, 0.16290798422790345, 0.19118226704097566, 0.14456187915657798, 0.127227270615197, 0.18217898725021273, 0.12063866165736992, 0.15458940318034542, 0.09262659541902044, 0.06303226267318092, 0.13573617854666326, 0.12852566707278454, 0.1425696828312451], [0.03278026259654472, 0.0630597154339475, 0.05497191071269974, 0.07474426465529589, 0.05579465849986, 0.039354204801061464, 0.030077243929788954, 0.01469917223608542, 0.09662660094158304, 0.01692032159846877, 0.06781431756192638, 0.07593573056041233, 0.029095592270154628, 0.013051407126289223, 0.020245648807876056, 0.016179068329473658, 0.010326920760675304, 0.03106201548249491, 0.011958846045027097, 0.06426749901185114, 0.027334976663452484, 0.03102574504971985, 0.0504746068749697, 0.020952261496155013, 0.06182264431469864, 0.04631273463488587, 0.044050745125259125, 0.02663100506329248, 0.03435832711177007, 0.06229885989018987, 0.004208403941799677, 0.06726136295905999, 0.018945718259220163, 0.043340876563301975, 0.04319403666041551, 0.021333440034199628, 0.027872695692724762, 0.012027011590919668, 0.02070074525451468, 0.052033320009227724, 0.017813208565536528, 0.048063854581766555, 0.04843896953389049, 0.015919393251439738, 0.03772559380459209, 0.05605461128476647, 0.057444447996996106, 0.030813638286124316, 0.05973118597701673, 0.007285657517176363, 0.024988972206389713, 0.03993113412551823, 0.020184547550255255, 0.021395820658653978, 0.0020521316928939237, 0.023965639618015098, 0.06333887787355531, 0.03197993054204891, 0.050004255702538844, 0.021183951382314967, 0.01797838095245102, 0.03096294499212696, 0.024287524865940217, 0.06385950356601708, 0.037618736030473825, 0.015411129345246142, 0.024704217324934663, 0.0354688405059278, 0.06902525742207805, 0.07278109540141399, 0.02282594018916209, 0.01136649345543476, 0.013204396799987844, 0.021651397166292996, 0.06153556818683302, 0.06445944234127961, 0.05395724640918836, 0.14690946366998459, 0.07941081263725797, 0.01454304543233687, 0.026267526986738367, 0.03836369524980265, 0.031263314660698656, 0.057208071567959366, 0.07201607233934826, 0.007992096399257501, 0.05688962413959446, 0.05778825676609432, 0.02379009631582566, 0.014848858155610581, 0.03132897797190855, 0.03699160113389935, 0.0905134950974776, 0.04338598765072323, 0.1390213014618043, 0.015931953262958317, 0.01350673818735466, 0.03407893484578498, 0.05256112011510038, 0.019645890063275735, 0.044812474009250446, 0.004388923942667222, 0.01448517993858625, 0.031905213986793836, 0.011579767545504917, 0.006717298322567537, 0.04348514241076285, 0.04660710391979064, 0.03264020640222776, 0.02442074372553297, 0.05665456538178748, 0.04953691908609002, 0.11129290992093664, 0.07571001807528158, 0.04337831144972194, 0.08373823647777881, 0.003135103986771297, 0.05138066672389546, 0.022786316206498493, 0.02186962305718372, 0.05874895017534014, 0.03861342842179922, 0.06456239689742366, 0.04621658293950943, 0.05553351061779165, 0.0596562089518674, 0.029145866790185535, 0.04115999661265843, 0.06109777575118407, 0.015400494129637317, 0.024460944189359585, 0.07087018100484725, 0.04670106460370364, 0.03164158781029044, 0.06503414618031633, 0.06247632798828906, 0.017258392369014122, 0.01892161521790249, 0.01997631719155658, 0.1174408114785629, 0.010404621228395451, 0.014104110568070845, 0.0569721203177206, 0.04573369473819772, 0.04492478249894996, 0.018910154542555253, 0.010200969202654257, 0.02959303805724748, 0.022221104196843602, 0.025128088027779615, 0.0667746673007646, 0.01738381436875751, 0.03711033710128358, 0.03943108172426301, 0.11446218502016799, 0.05506085735114832, 0.0620554622653271, 0.04726583228236245, 0.03432723543336315, 0.018567868373206547, 0.05367377472500648, 0.03513442780522089, 0.025132188513394327, 0.04613240519838949, 0.07087506864580416, 0.030256292084231976, 0.027394517016927564, 0.014721156086682554, 0.04609502393812422, 0.045693026960737286, 0.020550729917182077, 0.006572040391244716, 0.03964084808924987, 0.01460556395261759, 0.06838024203335086, 0.03457097779779184, 0.05219778759525188, 0.036762586809814944, 0.028259008935081865, 0.008020110319428628, 0.01916287737267633, 0.042483907628564105, 0.07090024995587527, 0.0048939645339194085, 0.08200395897391342, 0.014417237515801625, 0.054130294179964455, 0.07235736450961522, 0.012329772411425029, 0.006697164095502588, 0.045861773147818544, 0.03346313805048985, 0.039051301296680205, 0.05636869967284222, 0.04927171859890223, 0.06537195265052781, 0.030447919402391683, 0.021658437514317133, 0.04853751525403031, 0.06319756529504253, 0.03918488787847661, 0.0287762638406768, 0.040709192173615585, 0.029285984271536433, 0.014795508750173596, 0.016625822078616872, 0.030277453347920414, 0.05259500801443093, 0.05738091632543553, 0.038030531272412314, 0.034721801357884566, 0.06530701137718654, 0.028010007377052983, 0.057392128022207375, 0.03758726130810477, 0.04811550422962155, 0.0762057229275665, 0.08938262674717173, 0.04147008219132981, 0.013285945901917595, 0.03246042088815763, 0.07797027622619945, 0.06903667213214983, 0.03453597141009185, 0.036981446638463006, 0.06592444760063965, 0.029792255391516996, 0.04854585029064648, 0.033238701101753025, 0.06610152116345783, 0.057297937511917085, 0.02555960428810889, 0.030345501107794624, 0.0556635080776628, 0.06748672304374558, 0.05348213783074772, 0.03498740021079298, 0.03012795703515651, 0.026386927535396912, 0.012856999866574282, 0.013985446421429517, 0.04867054259164199, 0.01822006062514359, 0.05173947549455109, 0.159152697831873, 0.05694402021265799, 0.06841166696000485, 0.017753497757498297, 0.06380337230380505, 0.07777477058792308, 0.03469874594180334, 0.04646445834828962, 0.013287058644627613, 0.0666380048759522, 0.05320943734278122, 0.024082445043830142, 0.06950950159901573, 0.054410942830145366, 0.058529699641850695, 0.03210299873664495, 0.12910933414053533, 0.011299864873440276, 0.047226110623488506, 0.08087594813156514, 0.009447772622919612, 0.03807735456634433, 0.07272019141143368, 0.056835063357627204, 0.012380716300779774, 0.024335321091536074, 0.061600723964793075, 0.06272305809562245, 0.06501824985588751, 0.01851177924583035, 0.021337678415640708, 0.08051551908494965, 0.04698826330563715, 0.018656763300720244, 0.03924772624046572, 0.021198669846560207, 0.04184769075964728, 0.03598024633022086, 0.009352008759554838, 0.05111296112919527, 0.0870685585804524, 0.015066029717995515, 0.0717220094896132, 0.07647236749049156, 0.07817875939391314, 0.13181687272604437, 0.025132125311140573, 0.036848721905581416, 0.0504855772540454, 0.05475814536874814, 0.04404216111006756, 0.009022083418864396, 0.07443743111986308, 0.04055886274023403, 0.029289446988954183, 0.04168217363316686, 0.004048730629766661, 0.105651683594671, 0.05881169660677833, 0.06663060446660365, 0.050665113789540146, 0.020900083247632272, 0.046648805915948846, 0.020091688117733406, 0.06247969494471627, 0.015829258219098613, 0.04545398837616367, 0.034270353404985326, 0.08768425578431738, 0.07856862153857946, 0.050119831557235414, 0.009522406823722827, 0.03140713043150402, 0.016719775101650628, 0.026838302709943345, 0.022410199594413562, 0.10429877998127092, 0.06851917973929836, 0.005925387968384331, 0.048352018554484656, 0.0665428107904811, 0.05707923856173312, 0.015943979885759615, 0.022517821541236296, 0.07274911123057527, 0.02587183299774845, 0.10882896431271108, 0.023108979033666755, 0.010795011973729538, 0.07045688423057718, 0.019967325234545336, 0.04994237112001546, 0.0762021069925639, 0.0052963148693614195, 0.009957464325482087, 0.03234006464481354, 0.06304529765921255, 0.03745839765836154, 0.016806904196498856, 0.013453539126672813, 0.07844533500892502, 0.06432788972292217, 0.06880565831858305, 0.02886413795603139, 0.030142009002907626, 0.045155053207230185, 0.01942927487224581, 0.060004227374109535, 0.1402914139532274, 0.14139173071711295, 0.1365639671923653, 0.08611870148489553, 0.10083021731266092, 0.11033056559221399, 0.1765226077048048, 0.13032991138677444, 0.12115263004576969, 0.07305190748264713, 0.24997663473890674, 0.17318540613257116, 0.07811243916230817, 0.09402544898611885, 0.10634095588278387, 0.11598223369688758, 0.12503690266561124, 0.10506997771200635, 0.10906994493017275, 0.1263559451927581, 0.12674727822623907, 0.0612355528339263, 0.15467174231044709, 0.18774786423290932, 0.1663025198203902, 0.16054857131694594, 0.11092968465339755, 0.22172017113095333, 0.09229083440356678, 0.24013709336999925, 0.09680673119521911, 0.17203808221365177, 0.17602886403760604, 0.05784781244132788, 0.10309186208272174, 0.1569468089409413, 0.08839009089335319, 0.09612379445424003, 0.08063090724810477, 0.159226655960083, 0.1973527528706097, 0.23110389018491392, 0.08028951548640767, 0.1428110464926689, 0.1595624782625706, 0.14884558235926015, 0.13904607674527553, 0.11279453418307728, 0.17927827193371712, 0.10830833095937006, 0.148607773345805, 0.10438359357536801, 0.06822611280386487, 0.09415500211499392, 0.2040049701087898, 0.13049596860524149, 0.1935159547194358, 0.16465055846398877, 0.11841347501162561, 0.11164305806760827, 0.07997104507540503, 0.10687406880841141, 0.08426145154742465, 0.11353691934698051, 0.23161151536530067, 0.1115747153638832, 0.0774223778036333, 0.16889908290918798, 0.23336521319804654, 0.15089552639232529, 0.13101954373621172, 0.13714620933657692, 0.13667504994138596, 0.1031840071382542, 0.12189467047010699, 0.10107729598999986, 0.08564484546021109, 0.27098417522445806, 0.20010107797720741, 0.09920145309860669, 0.15009887155986604, 0.07351836309798303, 0.2803534305384082, 0.17640777112495515, 0.2204607225834362, 0.13187552441752728, 0.13431085664178097, 0.14345494339302664, 0.12601394822160084, 0.08426492958660088, 0.09678495131553182, 0.10678157901331302, 0.1582551338980275, 0.1488794894107888, 0.21550018069965227, 0.12031360289021847, 0.14693901934210332, 0.1592694649532918, 0.09511831171450116, 0.1059832847526958, 0.17062848043297568, 0.1484909602591107, 0.11856051026693276, 0.21992887370288375, 0.07675850899108956, 0.15769513894713696, 0.14898193068802357, 0.26578654444986777, 0.17497734707449714, 0.24927043956854653, 0.14105796153026243, 0.1326382568766994, 0.20467258509128325, 0.22786004408713312, 0.07612558246980752, 0.12757460721918654, 0.20104865213074993, 0.09246541818063106, 0.2179683627740991, 0.15987844356606085, 0.16936864884149644, 0.12541942568796297, 0.15544625720189464, 0.12639997992664576, 0.1392885588950688, 0.14776565885591894, 0.13005689297231937, 0.2277156058698893, 0.1739538995729339, 0.125851935947374, 0.11538489962056761, 0.18914750687056975, 0.1437852651842179, 0.1455402347229181, 0.12008409060898328, 0.13186421695976488, 0.2868087938235652, 0.13405136734006867, 0.15245356536920995, 0.20130405052294656, 0.10081386899635678, 0.12465486993953107, 0.15836197251994766, 0.1779425057071832, 0.17761613692968123, 0.23836197571889048, 0.10220239569823589, 0.14285691983757481, 0.17883220957892557, 0.07273404994198392, 0.1352367964723418, 0.16695328086854952, 0.13193296569008983, 0.1007941345714273, 0.2011241730783255, 0.21727785708442812, 0.12867594288001138, 0.16671384774869488, 0.12001511205228106, 0.19947598087451152, 0.17581304174757775, 0.0815626770077694, 0.10559760544809604, 0.1121111837546191, 0.1527102201456024, 0.18106544780875408, 0.08211010811670173, 0.11553255540709342, 0.20048953052009308, 0.12938615235109485, 0.14027025460475875, 0.09461869215292316, 0.11187515206514828, 0.12970896648062816, 0.18601618376710724, 0.16115451622153484], [0.03823188216155095, 0.059811533278515266, 0.04978197146086924, 0.027338337874220266, 0.027180330324617606, 0.03751720256742932, 0.07185955291553851, 0.09327260672204918, 0.011029745144168697, 0.04362710999445089, 0.0407253566288179, 0.01873838996905233, 0.06659235369654433, 0.038248839517754894, 0.05075142891596883, 0.0507469128276552, 0.020893726633080555, 0.11788951683669321, 0.009267309121036483, 0.09583986694774321, 0.05784765922374303, 0.03580372435070815, 0.08115740117406653, 0.02439801581203938, 0.09056854617571639, 0.026995980841738564, 0.03795651568760795, 0.06259246691760999, 0.026349791423267415, 0.1260085932670101, 0.029931016897241917, 0.0136828723348557, 0.02000705263907871, 0.023765914750495748, 0.03896428136936119, 0.026050344890644474, 0.04322832675590631, 0.00578992878041801, 0.01765995459150403, 0.08653662543022826, 0.031565344824846235, 0.017694034012815645, 0.037313335079459414, 0.04857761612642677, 0.04785852386586128, 0.09332336004703276, 0.029430772974005634, 0.03666974844471101, 0.08296133905288675, 0.05803230939613235, 0.008286755839963595, 0.03713854062821596, 0.07604744916241016, 0.060602208794725526, 0.04612515417618617, 0.00437646878943328, 0.035877613531005, 0.04508374574323816, 0.054597366496079394, 0.033807260915637016, 0.06734036194581179, 0.029619962217346318, 0.01026930520310998, 0.04339429204382243, 0.01996758378921978, 0.00851805406367226, 0.01167082762901461, 0.027710348255031055, 0.05337108955568364, 0.020861001272175102, 0.03918000406795933, 0.0452824306464003, 0.022168575463095502, 0.04135878876812997, 0.01763791232670267, 0.07456132285897771, 0.030395622410240675, 0.04330476317855139, 0.04009141504103619, 0.07801702291133904, 0.013870974690953811, 0.015212544033514156, 0.03093844166986885, 0.036051097971897934, 0.1046788055569895, 0.11857962416064356, 0.006055525718106618, 0.051135936106044444, 0.008746674810085566, 0.04993189869809055, 0.03930232532682919, 0.023225533565686598, 0.039592707124088085, 0.03187883566434105, 0.019806737883857662, 0.009931943063894588, 0.0429814510918673, 0.0368350280839349, 0.003219600372587241, 0.05385776606178092, 0.04077313370221565, 0.01773327112107748, 0.01573407083689686, 0.07845393817631469, 0.019131866133501454, 0.014733142489867826, 0.02610507229673526, 0.07989887959293782, 0.03506523474389988, 0.058171009614823334, 0.035990657465111826, 0.03154199063447455, 0.03366396799983998, 0.02758132947248317, 0.008756282510265948, 0.01597531192425278, 0.03478480442877739, 0.062123854764767235, 0.019074633619898272, 0.08451198528130209, 0.062827889567181, 0.051857119786643216, 0.06328961842002408, 0.020384318383050062, 0.10727592788997198, 0.12619996969137462, 0.01486732949307489, 0.08657655393284175, 0.024613937693497828, 0.04821324938788049, 0.025802369890434128, 0.024089596474603302, 0.08103320299978219, 0.056169087803291703, 0.01049969657023828, 0.08159035576447364, 0.05247900315049676, 0.03438549258956506, 0.05855732477240025, 0.044198217050683115, 0.02031802687974226, 0.030638276929816896, 0.03216284552528974, 0.0329057899333777, 0.03596831451080019, 0.08938769824923047, 0.0375190603306457, 0.05069079305676203, 0.0520283404377199, 0.06769950396471447, 0.04644359777411146, 0.06394850766105999, 0.03934239172526906, 0.02381172872358753, 0.0526844526100303, 0.03155056507356706, 0.04781540460704316, 0.03239603119812185, 0.06240022864433066, 0.05529803434206594, 0.015735735162912358, 0.032233065144429286, 0.022575724381773223, 0.007494650133359697, 0.04277808922192743, 0.027791521016268, 0.0981729723993809, 0.08945154401684001, 0.04617895270066877, 0.06934984887559568, 0.058123378098131194, 0.10450403025794415, 0.045737203420890916, 0.056209230810524, 0.024902586216828036, 0.06321156938229838, 0.039022389138417865, 0.021130014962006, 0.03146200530952023, 0.04380820551887155, 0.03848334669225639, 0.09836063329731265, 0.060682605891939134, 0.019461994487491828, 0.0425072618189358, 0.07114362076766069, 0.06589895985539883, 0.04506304221708448, 0.038388413076679555, 0.03735836572764862, 0.045732403880045305, 0.022026004585167094, 0.04205407484644844, 0.03836300194023117, 0.030239265780114842, 0.06325473077595234, 0.041546886336178555, 0.01764968135243943, 0.03521320079603503, 0.026786723925221353, 0.07478744137070834, 0.051567415977197315, 0.046603227514893784, 0.050395535109865094, 0.009464461848350062, 0.07523135101843266, 0.0033262893679596845, 0.03246668365693862, 0.06731622251531771, 0.01788212775042461, 0.04120603849690768, 0.0368845135334038, 0.059986450303826606, 0.06698806109207292, 0.023928723756163835, 0.08175616017392567, 0.08124142569760162, 0.07858988047847826, 0.06577089293709686, 0.07133965500660482, 0.02194544660948938, 0.021697341374331908, 0.06265229072361704, 0.02435959267219709, 0.025181698860720764, 0.04533190460455033, 0.06761020875626034, 0.05725276513746189, 0.06524832138130743, 0.04263219926806708, 0.028482764065566085, 0.0029334217646054084, 0.018323193296730038, 0.08704796613704774, 0.06883548212147529, 0.060695077803346424, 0.0168004154317802, 0.014830192423335489, 0.0036994910154927283, 0.012405489669031194, 0.017357683109660304, 0.038203395182086576, 0.027808187259060722, 0.026399479886036248, 0.03963874517789772, 0.04800511095973273, 0.03479287516505968, 0.07110178470611572, 0.03299259535607792, 0.06545358697973913, 0.007597648739559397, 0.061265886085288185, 0.02500982703490844, 0.03172566595998022, 0.12861606544784962, 0.07448413950060645, 0.013815388308777926, 0.04726929883021982, 0.040542717437229814, 0.01121859922404251, 0.06683760142374424, 0.052918814227826176, 0.05092436177355628, 0.07857389222349852, 0.04999926463971215, 0.06598352830136014, 0.08698525417956614, 0.10873630597826936, 0.06320360206788586, 0.027425032214171467, 0.10314280692968639, 0.13739373234491195, 0.06656218515408617, 0.031574543625597036, 0.10064010493337147, 0.07559007934985623, 0.01660084761228533, 0.038846820938370885, 0.06291193324291418, 0.021500510403946526, 0.03156395054482405, 0.027381822940022237, 0.0552385552756248, 0.047358325907900456, 0.04674418769296139, 0.08369217927177107, 0.02197477245523084, 0.06396401328064742, 0.06684132461105624, 0.08142602224383624, 0.009635775387587567, 0.008446042756399801, 0.02289531328114531, 0.0253645257438503, 0.05632843409154204, 0.10247990338792724, 0.06945729270697602, 0.02740942317271425, 0.09514491794811142, 0.04049919981269106, 0.10221753359561968, 0.08458235045714725, 0.02206636018179838, 0.09817560008096118, 0.06760915921580407, 0.011630924981868556, 0.024929874268690908, 0.07581836589041256, 0.026377552534423532, 0.049859886433208184, 0.050230324418554385, 0.05229849751377779, 0.0222237165566654, 0.03555079659206733, 0.10185069239307797, 0.04373980918899179, 0.06999111809437314, 0.06467655931989993, 0.023975098888660153, 0.03384097261474498, 0.04529379173031738, 0.04782185123692598, 0.051821408598052884, 0.01000334820409696, 0.09191627869562757, 0.10323703574437289, 0.02417896637663005, 0.05749051286388309, 0.05526125063038161, 0.010110025947553017, 0.021468995461961436, 0.019113349788371595, 0.02676341953056474, 0.0439739792848066, 0.035285542478724834, 0.0722285927904229, 0.03404795425012708, 0.024334196857507193, 0.025676308207273967, 0.07940067729401974, 0.08599247317761184, 0.03336567634476289, 0.039246293656047315, 0.06691305342340662, 0.019637062815168214, 0.029634054404713457, 0.010003032192828195, 0.09307488708967164, 0.06974553328848655, 0.03257973142148506, 0.042080152479390946, 0.05040959282327564, 0.12349815378265998, 0.16953038532407055, 0.14807736471055016, 0.16595941968262196, 0.14723187943379726, 0.1454339630060619, 0.09492786991740428, 0.14296872270924432, 0.15581538900732994, 0.14071912084135318, 0.17927165293405134, 0.07762198201230458, 0.11974878158540496, 0.17193280641109715, 0.103084928987007, 0.1420966235380019, 0.10850572883481942, 0.1278212951916841, 0.14462707323893426, 0.20101318225985576, 0.2139696136357323, 0.1436778290137168, 0.16608882725479143, 0.10942975344556956, 0.14857463238220062, 0.1192886308736859, 0.13405734282587806, 0.15085936704229924, 0.09535661868510709, 0.2641834595030354, 0.11535268562335162, 0.18485885473989672, 0.1433271139619812, 0.14268045914509606, 0.12389543165843334, 0.15327968394323704, 0.11717268836594398, 0.1431339678745116, 0.09770911382210833, 0.20964734556694187, 0.16912265800901, 0.207221788624602, 0.1607434487631244, 0.31349644725841863, 0.18853707269074457, 0.1936173234735766, 0.2462163687713685, 0.12276450202109353, 0.1805979962791166, 0.15222571549877045, 0.12384116198987731, 0.14898474989158494, 0.17349515080211625, 0.11997568150681835, 0.10617717394545194, 0.06127941519803098, 0.08546207220323625, 0.14625638903629395, 0.18855677647215707, 0.2030062672471808, 0.14440190467622974, 0.1873498968780041, 0.09925406801724627, 0.13652089772926224, 0.20287215589515625, 0.13761458017172354, 0.08915306850066108, 0.10852473547622081, 0.11832549747440124, 0.16783728504613524, 0.12968226065558772, 0.16980626890736242, 0.11597673318559125, 0.2123001241876233, 0.10155712750049369, 0.2759388641965005, 0.09291350300754271, 0.0998470277315186, 0.21627592133177867, 0.16702677934400498, 0.09525377904215167, 0.08308716133357057, 0.16682174357195056, 0.1574462676240552, 0.20191434680694537, 0.29553315632285615, 0.11357318594931595, 0.25223734488169997, 0.11503128109559899, 0.1590129940380012, 0.17760824622406116, 0.177069119508228, 0.18856013193726542, 0.1472333503226119, 0.18470997321269206, 0.2183585619974521, 0.16689620731819063, 0.14203112302047594, 0.1440315318083571, 0.24280067383041307, 0.14498022445026906, 0.1687618152749154, 0.08129426278173923, 0.16607263215607213, 0.1597761861499279, 0.1488628653028319, 0.14751669560228625, 0.12527384599971195, 0.22313919579309804, 0.15762665068670628, 0.22252954302295563, 0.09827991061273122, 0.21892077860332307, 0.18691448314536005, 0.18942358963672193, 0.08319904081403248, 0.11562338279139613, 0.0883847589214002, 0.13886685813626937, 0.21001837727042938, 0.13223023844822762, 0.1436217207341425, 0.2803980781426353, 0.10439505425071526, 0.19712094998648091, 0.19566431040725402, 0.11347360218003874, 0.1849917403512424, 0.1258291907969021, 0.14293814047930703, 0.22574346572641404, 0.12748831507539557, 0.25472294779554494, 0.14150701162795867, 0.1435806277778841, 0.1719820658646284, 0.15488794764443753, 0.09565630462020637, 0.22118842950271023, 0.11383290507740552, 0.14803933610598888, 0.2002231923923377, 0.10225658875799949, 0.10257763322442771, 0.20957297375125272, 0.17367380250605846, 0.07760565667863815, 0.0891438907673282, 0.16372031321929348, 0.321215212104782, 0.10402629782836284, 0.06619082403279121, 0.11649515254483109, 0.11690245085065404, 0.1847466688242651, 0.20466227354782246, 0.13221376755785558, 0.1260253399490349, 0.12022112075599933, 0.1882115772534763, 0.13558735830649254, 0.15394192098850204, 0.19331064315572863, 0.13393743474396969, 0.17763507462316946, 0.10913766710267914, 0.23987317608008463, 0.18566842581475937, 0.1338241456617271, 0.09900939485598957, 0.12239895550714386, 0.21691840863035572, 0.15360625190359933, 0.11312861746597676, 0.15602427054076426, 0.11296744022758738], [0.033565828306300026, 0.05320630787361053, 0.02330958298707922, 0.06433062465681184, 0.027655527003169544, 0.05923917749896646, 0.06476085963508775, 0.03393034060155192, 0.07789611125424986, 0.02967610497087721, 0.0065366136127962705, 0.028593685936122656, 0.02890980828763737, 0.028820823344792572, 0.018997471328944932, 0.07512426724837673, 0.01958348454096385, 0.05812262350152578, 0.05094956989670473, 0.04721846506600419, 0.02856717929394255, 0.019579684744859417, 0.06819034415868021, 0.03529772710716052, 0.046126697843353597, 0.0670569783617412, 0.04105839803214035, 0.06757427157173235, 0.012751661819375813, 0.04208050487983612, 0.012131988619183822, 0.013854445386377555, 0.003981971334020097, 0.03725297884234498, 0.005466149858905063, 0.0954583858049685, 0.026731040824445027, 0.07669389713555574, 0.011270696075723298, 0.0036329402393030547, 0.08485309359046721, 0.03918930437536009, 0.03188162230916562, 0.045148261837781443, 0.037401868030428886, 0.11345659502811971, 0.052443713310264775, 0.024341080157506852, 0.04048805323339278, 0.04411868946326356, 0.09236024963038583, 0.03835280147951938, 0.06980538773801058, 0.11809652911559229, 0.06331300708435236, 0.03950649158908956, 0.013674628271180536, 0.034095463192751335, 0.022842472366568063, 0.021475687239980026, 0.08591651555991943, 0.012144732491804228, 0.04499315201575237, 0.021178512158052578, 0.013796112578993124, 0.036431533404656, 0.029985642796682737, 0.025253795395274798, 0.006110770712351246, 0.037091571777578325, 0.020681390043107734, 0.012199976049633998, 0.03335641817219796, 0.03278135427183682, 0.031109700625341748, 0.009579877782192443, 0.015105242886009718, 0.035756766991389376, 0.045999465960889094, 0.0386602095808954, 0.04124260387353359, 0.028357834277314045, 0.03377718813416939, 0.0376915182137201, 0.013604281289923578, 0.018776267271248565, 0.005471688674597611, 0.07549696136265993, 0.03710662157485082, 0.08136495737539184, 0.018155262993288138, 0.05307410791095707, 0.0027213597692729487, 0.04331631195400992, 0.11533339552941824, 0.02271794477447627, 0.04214779421266529, 0.03912578419511838, 0.09298587533374948, 0.04938463612850155, 0.039094294150990826, 0.02882832334557128, 0.033687762690768126, 0.05165936184986945, 0.02690503854424723, 0.00857736554837996, 0.026482948995826226, 0.007607436470401985, 0.05239935681944894, 0.07162642469930072, 0.026097702530903683, 0.028912828589278846, 0.07751892786473036, 0.05584254282556715, 0.015653643096166275, 0.03191200152580296, 0.016832330654705727, 0.054497893809551196, 0.03636508676854353, 0.05604618814803901, 0.02835918259206078, 0.06903816600360217, 0.04762707721261729, 0.03403140675096262, 0.03440860929268022, 0.02894364830647265, 0.017603589672475092, 0.06402994663785062, 0.02305868344621793, 0.02263408112940529, 0.01615606845476695, 0.014905518976100271, 0.031696085390003945, 0.06847551272761437, 0.041206831397909316, 0.02698369662187273, 0.05760729147662079, 0.05626826554596905, 0.012591257372180061, 0.01780127483089605, 0.05485071177263895, 0.013171438739875392, 0.012821285805154233, 0.06665478220149394, 0.04909693946941726, 0.030384111939178362, 0.04214416678634383, 0.026976125757961024, 0.005517491635175483, 0.08946125801171988, 0.09505888627421472, 0.02899004833682651, 0.03307841635579544, 0.08971678663886364, 0.024957679429902666, 0.020281354250806957, 0.03611871289209493, 0.03084505172145944, 0.03365963194218855, 0.09087479748432675, 0.018864890237549142, 0.026861620511138634, 0.08970604608616523, 0.03496111573411092, 0.04551784946553169, 0.033627142153319814, 0.024483231602296717, 0.1040554627956402, 0.05829532653273595, 0.03723563078129965, 0.046317522684412624, 0.03599296338976391, 0.027846868953577457, 0.047415384136500864, 0.03533042373976881, 0.047191383857880874, 0.03103063269067676, 0.061979937487311905, 0.015344642489517649, 0.015757039110476694, 0.08732891356151912, 0.019246388617302143, 0.050243451335136934, 0.03467308582677957, 0.037705989614609754, 0.013501851504007656, 0.043497553035136194, 0.028753409522675702, 0.05977922735074836, 0.04052076135731993, 0.04320408007310283, 0.038138381130392515, 0.01038649846093669, 0.030660133418296615, 0.03688144918170668, 0.013835128479366823, 0.010923249346594657, 0.02999083687280936, 0.0969868844314929, 0.11045525406276989, 0.05151082123179109, 0.027312834807220968, 0.024150808814973123, 0.03343703743490962, 0.0433214983692573, 0.032186490829072656, 0.010490336891023383, 0.02664891619896216, 0.051880837868778944, 0.01976119395675919, 0.03012248908259696, 0.10021339395954725, 0.025563888634825428, 0.024389487338222327, 0.0328988644985422, 0.030372486554927407, 0.039590615704054796, 0.08662188335532144, 0.0456847608720343, 0.06217819721167607, 0.03643986461083255, 0.07988008745615521, 0.06667389609520474, 0.04271402511925947, 0.027352650311865637, 0.007410867885130668, 0.04844641973895412, 0.06074155635771252, 0.037419189278396874, 0.041542301299951734, 0.08029523816320204, 0.02035275556056971, 0.021584347235940157, 0.029007902015901865, 0.01395497144380164, 0.01365430300093947, 0.02667150238618976, 0.0715415498181697, 0.03092388599930752, 0.011764592002897013, 0.019229278043513338, 0.01919976259101062, 0.02523020371764658, 0.07021841638150715, 0.031779627278146726, 0.05013494264154185, 0.019927639964847796, 0.031519287618838494, 0.047512455137386445, 0.0725084140656456, 0.007615418148963082, 0.04309260661924078, 0.014550485103691538, 0.044974574383588574, 0.06030286759919217, 0.010160547530939503, 0.0717170145963469, 0.05907052707287574, 0.060723725661274895, 0.035699011622777874, 0.02504405967380491, 0.06056062554219558, 0.06584050734677623, 0.045979593640133265, 0.01689210658021752, 0.03419619609391497, 0.04020578813769164, 0.039581158348629554, 0.08251859385880732, 0.011590130799900622, 0.06211936931997057, 0.03963907459570516, 0.03324924247159112, 0.026298934676414056, 0.1196536104825716, 0.05203609324751362, 0.02211715947205742, 0.06405093361653628, 0.010287569696834732, 0.05885185493576912, 0.044770909908918605, 0.06532892915270021, 0.0458448349438127, 0.04042829071441966, 0.02800325431200045, 0.01950012651392289, 0.07758586096667475, 0.05446349263131138, 0.020179058530277783, 0.055116222525436076, 0.05693966117236884, 0.04905485442929691, 0.03401611180555436, 0.06386334549695735, 0.052582402037636894, 0.019761123093626192, 0.04985056314316969, 0.04039726798392592, 0.01975417467615297, 0.045424153081952565, 0.01876166563541178, 0.05455376460186897, 0.05255852307703707, 0.02193137357432035, 0.028511287434206858, 0.034232416730974956, 0.025379094820950302, 0.011151320424922293, 0.04452782254966517, 0.06393808886528977, 0.02106645264692845, 0.03796449066289971, 0.04582323892522724, 0.02410724522515891, 0.020990678890337868, 0.04384916440974321, 0.057190466867459405, 0.019105395880497752, 0.011352133137294123, 0.0657421033529024, 0.025275933421066692, 0.06716518828104581, 0.06850532886962737, 0.0668670345217951, 0.04897461438010778, 0.10969123457588496, 0.08221558310211667, 0.062187110644675074, 0.03518666351033795, 0.07283678233262993, 0.006170190885783204, 0.03862757806576068, 0.003019030414326417, 0.08023767431657161, 0.020234124930275064, 0.051803857523707614, 0.03202414913703838, 0.09774687429589611, 0.03754783459308167, 0.031383019729307106, 0.03120555163120791, 0.10540842003519497, 0.052324533011884465, 0.02973550934374573, 0.04948383302337701, 0.09213259894280665, 0.026242405048481403, 0.017450944738342397, 0.02694158285345522, 0.02184266059268867, 0.09825007914895974, 0.04665168640654414, 0.11976935870705113, 0.2711776583906143, 0.11566624541075961, 0.10117357025944418, 0.1399454639683808, 0.16927114117049402, 0.1397753464839151, 0.19909385621788042, 0.16358223353182116, 0.08006591740394793, 0.11781292336602366, 0.12207645547365951, 0.1422225837145121, 0.1009031259004147, 0.10671492170302138, 0.19575486199990397, 0.13570050949290877, 0.1706939503069847, 0.15076303914670022, 0.17120560510985314, 0.08672436293695243, 0.16810786730099112, 0.18805262933094657, 0.12811439277063455, 0.1418476909278862, 0.17767754653769155, 0.10458504405593681, 0.1966394177607952, 0.1077649218120402, 0.08361911746643244, 0.09865312566680294, 0.1404738807750325, 0.13785209807176746, 0.17075120771844543, 0.07913598625530159, 0.20280985762515377, 0.12404417528981164, 0.17346683619243486, 0.10680406369389066, 0.11539302015256499, 0.1308826438241428, 0.17091343449729104, 0.14820763030119483, 0.13595272095934038, 0.23223131113956053, 0.168466258553728, 0.15195988298904511, 0.1638815134403206, 0.10475512323600632, 0.12256254592249471, 0.23608024412345505, 0.13552472295780338, 0.16003582866922503, 0.17450963507496542, 0.1499062004469095, 0.1284184760504192, 0.09432182542138523, 0.13570470765473383, 0.11144408971191415, 0.1312994875855023, 0.189984611145431, 0.14259877885060926, 0.13816173548900312, 0.11571677657024515, 0.12540765091656678, 0.08421802202299719, 0.13209116284645375, 0.1703217388280938, 0.08575926069170238, 0.1656189089220378, 0.1487496068641063, 0.08929584430710924, 0.12029018358237321, 0.2273197069523796, 0.08854168437180981, 0.2138994553036267, 0.07618033477375585, 0.20496665560189756, 0.23221079530494831, 0.14594148093413922, 0.19308366662552282, 0.12159562804886412, 0.2425347800336538, 0.11427835456185764, 0.1328816583320018, 0.10764309084944187, 0.14310796685036153, 0.22217844492725788, 0.16337473095665056, 0.13831326768042582, 0.10563492159088773, 0.17768343009295004, 0.17877368046151054, 0.0798903913387368, 0.14416286992209573, 0.16667070167679943, 0.18564170466796046, 0.13954107679667013, 0.20359650734932194, 0.1241696298482918, 0.11871547453225621, 0.15257129776141337, 0.18465437055114778, 0.18342316000451966, 0.11963302570004618, 0.18869300222685262, 0.1053564333086533, 0.09504525757004177, 0.10886339996490749, 0.17527855752456575, 0.17045528327505435, 0.19634654234734275, 0.1640144756604587, 0.13872211348385582, 0.18745673549992425, 0.11218387017687483, 0.1074319800001479, 0.22002736196642925, 0.15617336657258774, 0.1416471137875511, 0.1243219894146727, 0.11056509574935322, 0.16952945069680292, 0.13649564747127796, 0.09218244062316033, 0.1337905910106436, 0.15953572647225472, 0.1366173022336537, 0.1470885290614059, 0.12293241317233733, 0.07776249019849686, 0.10783866543563143, 0.09119122244057157, 0.24427327868198198, 0.3123157219060006, 0.10400778148323299, 0.09281362046397502, 0.20590960258437743, 0.1846035942435265, 0.13048610139277675, 0.13413746030099932, 0.10426360122378796, 0.10233570265793994, 0.15629640029322717, 0.1461726556261701, 0.1294202585854838, 0.1251746299526384, 0.20455027149329263, 0.18468827760267645, 0.21552464954795378, 0.36349814805773, 0.23615836976997315, 0.11845556388218557, 0.1680600480927575, 0.05546918221478982, 0.11799173594842996, 0.13991521881713023, 0.1359075677370833, 0.10647021023736847, 0.1387147743615412, 0.05860992819972097, 0.2049959967693975, 0.22851950789411224, 0.13810642394087008, 0.13528882916415894, 0.16939225967132276, 0.125736678019166, 0.24231197102175606, 0.17412464524949753, 0.2370033953939715, 0.09978636122879483, 0.11946102363928673, 0.12041946858047478, 0.09693950189337616, 0.2060505014754111, 0.2573360430617487], [0.026532325277765913, 0.045141382368221405, 0.030405152544018724, 0.05101479462257797, 0.037137996705789725, 0.053683473398127866, 0.05002864794204793, 0.09163327815551912, 0.042875382388311054, 0.03227251101165049, 0.01614470928606968, 0.02964348686228116, 0.040813464400989395, 0.10365620841302219, 0.054320873872887705, 0.06736043344942794, 0.022218507158780293, 0.025231469677941456, 0.04207677403164487, 0.013729382490348673, 0.020400749053806067, 0.021210572937683716, 0.017674981406138792, 0.050898479493034464, 0.01772923383771652, 0.04010446151838668, 0.03875688221606036, 0.02836737590241096, 0.03855897106170174, 0.05748630704117879, 0.07006165180956164, 0.034305428740598505, 0.011525885708960555, 0.04147259112928183, 0.018061867299219294, 0.04811914314726188, 0.04568247793001994, 0.019695781539344502, 0.015558599355450321, 0.03204191280078263, 0.05790038139469201, 0.042939584386805375, 0.07784662963522058, 0.03212793298336047, 0.04604834237045819, 0.04630013248853145, 0.049822892047344684, 0.05686118695584517, 0.03217054853936838, 0.017923281993716955, 0.04807002158955701, 0.06935859759969097, 0.008328864820331575, 0.04841820855114249, 0.06391631664648172, 0.05715388999951463, 0.04087458672602812, 0.006049264385740483, 0.04322206015668569, 0.010195665958998425, 0.014670260077823075, 0.02743578617340855, 0.03168727346365491, 0.16266052250660237, 0.01944948235646852, 0.020274827181692087, 0.06802764240532153, 0.053458450392128966, 0.08601452118807262, 0.026689436504497167, 0.0409044909681524, 0.03765184252012161, 0.03175482326637834, 0.036475506851509694, 0.10573063661614734, 0.0067216511383923075, 0.042738907655040105, 0.004515304509925867, 0.0713705436717118, 0.06936812007258977, 0.03683008298638367, 0.10214930580508325, 0.06616061718593683, 0.005980645890362682, 0.032853301419245626, 0.020998977537777637, 0.0449414870461389, 0.017909216619427168, 0.03982905290960785, 0.03517684226314868, 0.056067623288160374, 0.08358671960811462, 0.040132825923783165, 0.025117462388269847, 0.04999918420048011, 0.03874136893559368, 0.018958965834650784, 0.017561939387251774, 0.046745509194630774, 0.08380019766909462, 0.03237083839673189, 0.03030342755899314, 0.02684336463590303, 0.06761009384307169, 0.06145345888310864, 0.04581568146785421, 0.04258959328815822, 0.05266728074920755, 0.02856504956951305, 0.04012277101977699, 0.06549020598251974, 0.03814878460440425, 0.08470759817188786, 0.07406377939567452, 0.031854705809946024, 0.017580947943872983, 0.007525403775470032, 0.02444467056662806, 0.06524295110495822, 0.02432837267406285, 0.012613304425030948, 0.09716445595146188, 0.07264237220008528, 0.018475100871235616, 0.02691913264683418, 0.043823680494942015, 0.08763603821036317, 0.02703781498806371, 0.041267789014044313, 0.10098213254804574, 0.011137608408687577, 0.07025445315746531, 0.06202523243583499, 0.009826279429328299, 0.01587333987587162, 0.06522400575059076, 0.026836793516732516, 0.020684644001566117, 0.05953579908236862, 0.01808029171379824, 0.027475948332838958, 0.07414554395983297, 0.02075313034677698, 0.063184296652194, 0.05706846736551774, 0.03580714876372968, 0.054183119772783214, 0.03668138148984121, 0.032719768463603915, 0.013423685637873509, 0.057791516470212134, 0.03097733212334495, 0.029909851803113858, 0.015932726054151934, 0.07828772007938355, 0.04688209118021112, 0.06142495275144616, 0.024657828785899668, 0.005721394554711879, 0.0752975410150905, 0.05012205321221583, 0.006222341842423644, 0.07904178808413206, 0.06782311225129713, 0.008519009758357801, 0.051655190501121745, 0.0687793048939878, 0.014678765569002399, 0.05407741496099099, 0.011484566756764488, 0.04653583859063445, 0.041491973153766126, 0.03041158959780249, 0.025508155738334023, 0.0455399894065434, 0.09118348495253632, 0.06398159882894928, 0.019879841824032126, 0.03366916973684584, 0.026309357302623893, 0.043554224389334845, 0.042052205591913194, 0.020855766976432457, 0.04964222553216162, 0.06521469778231075, 0.0627888190830427, 0.00648228983928059, 0.012861976565252389, 0.03934235342087285, 0.01581226734654798, 0.07772446925481481, 0.037780675526347854, 0.028775739070448666, 0.03295532517856167, 0.006826510380638103, 0.07178705801526386, 0.042020010746895306, 0.035567075960458286, 0.05723980676022269, 0.02426740356660899, 0.05239394823870352, 0.025951163317527504, 0.02461314862293582, 0.038430203172949054, 0.01633807179337788, 0.10498567739681852, 0.013915904790102957, 0.014746990486709102, 0.09894498984419531, 0.03549291481894832, 0.018121897948965914, 0.02364197896132546, 0.023560449969203725, 0.039076011462677876, 0.10704892837712843, 0.06842764755410534, 0.046169077827324795, 0.03132249495284933, 0.04484543877263223, 0.12892680603169626, 0.02637692434232562, 0.039616118771054094, 0.04609475963779035, 0.07110457326616011, 0.0299958375117351, 0.023964919495366277, 0.09756229307141998, 0.031583575802224303, 0.055993381707418355, 0.014804595510565467, 0.023855502987580917, 0.03595368606188605, 0.024508474199401758, 0.02032061817214614, 0.01892011177035109, 0.08260185229441813, 0.07361055411879094, 0.04507117807084034, 0.052120585084682515, 0.053099798669497815, 0.007535013390870224, 0.02705304673121822, 0.04356244451276237, 0.05263372226768444, 0.07325561026171332, 0.038498856142283454, 0.023765112273395065, 0.046488463713396946, 0.01172157712355857, 0.06095647083355054, 0.052102639475056244, 0.04930333887797691, 0.043731493304573724, 0.03291053967850824, 0.03339347767553503, 0.11172112242709245, 0.042798781256762244, 0.020229237289318157, 0.03462201074486779, 0.02440717822361377, 0.025332252374820174, 0.027495282476827986, 0.05108568839909089, 0.028604776974046425, 0.028285415985831813, 0.08593225866676339, 0.06393612384976399, 0.11694958824063502, 0.0017928601277338702, 0.02817653190915383, 0.03534807057510461, 0.02305736194454855, 0.0598145286822992, 0.03316364363737164, 0.014847745412900565, 0.05604461383735461, 0.05491486780585782, 0.016412836229128223, 0.0016107052473554148, 0.01602176941120096, 0.014212196955697672, 0.027954623050567125, 0.05598552547575486, 0.02908354553754532, 0.01892541309878711, 0.07826309035261793, 0.014128343844335648, 0.005072453922982658, 0.13632831854685662, 0.07242248198317905, 0.05480249036824512, 0.052566888757170215, 0.05244824855077652, 0.019820230607424053, 0.027665265895906958, 0.06061129842794711, 0.02980056744549544, 0.09051440674210749, 0.0721154109604897, 0.029750924948002064, 0.04769710914021538, 0.02226689518729766, 0.1282471787905501, 0.026855068544166225, 0.04918289070408191, 0.09027174073121241, 0.024348185623004556, 0.03391010821947167, 0.02923232938853964, 0.04884048387588513, 0.03338528819562447, 0.04254224522399806, 0.025040769326170127, 0.031857251137074445, 0.11788064553853005, 0.023422625005966233, 0.03658035747526634, 0.08066534290030118, 0.0065425388240856275, 0.07925327431650893, 0.035243147172995155, 0.06402232406300402, 0.032050274650476156, 0.028393296487328988, 0.0920819758527702, 0.009508545420342877, 0.03322971489040121, 0.03157558358995424, 0.030593150520637154, 0.030696930536519618, 0.07087584239460769, 0.051740291378190445, 0.07567172900082604, 0.017115765949711204, 0.04471076051554373, 0.04161053292092778, 0.04221891398511587, 0.03841246440706234, 0.024150385551394957, 0.04851001269754864, 0.060256879341097615, 0.056296679747080615, 0.05165483810067658, 0.043763600049480315, 0.06476379375183774, 0.08696045591345719, 0.01743677402696302, 0.08122677809648937, 0.046947097571025935, 0.14258961643903487, 0.08589874232007612, 0.05346798052590701, 0.09249777007367342, 0.16420242767180168, 0.10164060044072329, 0.13790649031439137, 0.1708012639034179, 0.10885908688989379, 0.11802407251971385, 0.1732141497514902, 0.13311519257483945, 0.14007902373709988, 0.07120768870076827, 0.1348172867250058, 0.16195792794948624, 0.2982136979699135, 0.1425764856920127, 0.12189668528134785, 0.07452310273243536, 0.13139993703413394, 0.07065040570112967, 0.1368744319845592, 0.10059165753303997, 0.11824325027485048, 0.13509344609995044, 0.17879123919673506, 0.16098298913528844, 0.15117833541045267, 0.11880363593058241, 0.15872793272137642, 0.13650450344768264, 0.16631831655338888, 0.1466632889763963, 0.11626188643276693, 0.14028445787487492, 0.16369808134773087, 0.09398318391533629, 0.1476801787653277, 0.09221060967613613, 0.09376787490421727, 0.1293554322253312, 0.10789357861804386, 0.26699294906950766, 0.1538175083095989, 0.20025314643017708, 0.1912680229232196, 0.1458666801092125, 0.21038956219150176, 0.2174790011298272, 0.21323796902452746, 0.18371929895252953, 0.12463995420764531, 0.2142905278672134, 0.10337716854748227, 0.1441030997422434, 0.12406586323894801, 0.13233180638522873, 0.11682933541916071, 0.11112653094554141, 0.1564873706909918, 0.11975563041144803, 0.17852102466408284, 0.18319425293274466, 0.19776040357687782, 0.18922379390606958, 0.21876555386810534, 0.11614943238636179, 0.11315367620197997, 0.1931014551871246, 0.14429336533911769, 0.2063098682030555, 0.21069904639115258, 0.12217885078561884, 0.164227080381205, 0.10989304511777817, 0.20726046074301968, 0.19730006134317768, 0.17031104424067084, 0.14704958115133548, 0.1511312210031094, 0.09622229803954402, 0.2217879086252182, 0.13555349722023935, 0.2339185891492713, 0.10775893866535156, 0.19397824281646361, 0.20147015370668905, 0.13209605048741066, 0.1005175844916413, 0.1369970826612365, 0.11116684249211704, 0.20605569555153772, 0.11449914876251452, 0.23749291025582822, 0.08996962629739316, 0.09553843433217657, 0.1319800647756746, 0.1621819167367874, 0.20084190032174512, 0.07354162152736418, 0.11929361810607296, 0.23917059684472702, 0.13153599424948617, 0.10705275881674983, 0.08663727406172023, 0.17104794421503622, 0.12938368554797866, 0.09862173138366592, 0.228673093201172, 0.09772741566261939, 0.09449387344742015, 0.10240177008052988, 0.09118771375787836, 0.13670903360170705, 0.16657359237151761, 0.1967139274723107, 0.08985311964586859, 0.06902597754472686, 0.15005207890945096, 0.12072932816320851, 0.09700054377918282, 0.1425811741501093, 0.11659286705957306, 0.19424297215957798, 0.1668740826989374, 0.06961359762616696, 0.10963353283342817, 0.2592181985176379, 0.1736438637899776, 0.1281267191253362, 0.17768330751888214, 0.19182714453387648, 0.07261747434254616, 0.18303282288534028, 0.17896071316734438, 0.10329381052044131, 0.07914503375368734, 0.1334801108966912, 0.12552082508562074, 0.20288078204518367, 0.21828932297085563, 0.1481218590971924, 0.15922213604132976, 0.26860173371049667, 0.17945752118624028, 0.18061486553520928, 0.16325466965715732, 0.13231789422852377, 0.10923019520217374, 0.09766992842478138, 0.16669802037217926, 0.15407785562978638, 0.15543422962148346, 0.10264752342575982, 0.09796032937423838, 0.10029446904457386, 0.24862459680486113, 0.13374295566351185, 0.11592325258759723, 0.07758530172249002, 0.08581251912419835, 0.12867335350282733, 0.1677418304907699, 0.1200301503582347, 0.08342812408603008, 0.1753390937923424, 0.13605998859049814, 0.20891602271266524, 0.20677422473747886, 0.16467550228680336, 0.1767407742238814, 0.2390089829362208, 0.13304993720544925, 0.16858409819824083, 0.11476977698264584, 0.2581241023876975, 0.12806571554392576, 0.19792327386957986], [0.03796739030569311, 0.036012287957653884, 0.023454059508719274, 0.07784636150444708, 0.07950560069612919, 0.011927554226149956, 0.052498231957396196, 0.07291111584392286, 0.06466251692824787, 0.029321274111768412, 0.009130676382131154, 0.058620477230438305, 0.032377277365735466, 0.04064612015480957, 0.03712737106627995, 0.03197916445412463, 0.031949601121126645, 0.07156771938166312, 0.04379382987897243, 0.009575422023302846, 0.060591089028504595, 0.0403592317184854, 0.03839208646827648, 0.0716590294013581, 0.01774167893604646, 0.04912455693908757, 0.017276788055295908, 0.040848221810114, 0.06024990794098666, 0.055822559422062296, 0.028159672229160226, 0.021125757428366813, 0.045788155928734815, 0.013218813617112897, 0.0109172077857018, 0.04193679061568072, 0.06264495926218168, 0.030463405869781014, 0.005660347880855684, 0.0771087107639159, 0.058419578333174994, 0.05716894745766636, 0.18806225139527552, 0.05945146046278458, 0.016703907505518967, 0.030253095582367915, 0.026623754041089166, 0.03054290855934303, 0.0376062756103854, 0.060111510327025774, 0.01902513667911051, 0.026874192013976075, 0.05469442983608573, 0.020684647832005736, 0.01676135452374095, 0.012091535346342192, 0.07093221880495548, 0.03584284080012191, 0.034256073526076736, 0.01633165389179222, 0.03391786102926539, 0.1256075309168908, 0.01956431127543892, 0.008919796316824373, 0.07396213484988098, 0.04942926841097013, 0.08897364304791536, 0.027033953904925336, 0.033152420449280934, 0.06472765738444944, 0.03991026972090045, 0.053098975124979214, 0.03585759565354355, 0.04020822429729085, 0.01991782254809814, 0.01989516932817717, 0.0338448949849173, 0.092320941658991, 0.0616995224939479, 0.02765751883177267, 0.01682592807487855, 0.022658684043093555, 0.027271720783544645, 0.014144501596268629, 0.07847584063006986, 0.05023163825934453, 0.01418166356386557, 0.07681866221490406, 0.04144696931865427, 0.031350185200872446, 0.0074123799511712175, 0.007767682911963353, 0.012463368569320489, 0.04828975475843876, 0.028333830827426527, 0.036071085205842415, 0.07130470607549914, 0.059169448176098455, 0.03578654482900616, 0.013481201604008676, 0.07085646037012339, 0.068556304360109, 0.020090018046058474, 0.022788288882903518, 0.03350166844264154, 0.011080054138156195, 0.026470787350028276, 0.04865099202781435, 0.08705278483009146, 0.007360271129366612, 0.026318052400564475, 0.0873154150922933, 0.02585304852184509, 0.0356699692295684, 0.07407551586267448, 0.011433578817354096, 0.015932509634313325, 0.008836676734649848, 0.11902872022361526, 0.03376495371001863, 0.026795323262171402, 0.056109325284318584, 0.09652740787714721, 0.040420817526718306, 0.04245395742116436, 0.05429505670983946, 0.09796780639237936, 0.022494333285477855, 0.013692892764905288, 0.02184665191077417, 0.0426241132100263, 0.12964558036577317, 0.06564289496670808, 0.019893918689640782, 0.04707707204825936, 0.04447709220731932, 0.035737549675808805, 0.02312076912682143, 0.059076966041879314, 0.05527536196994686, 0.011992292486191278, 0.06900539276220145, 0.02581357201110692, 0.05051870289589128, 0.03595794168030543, 0.03554516201538425, 0.008360827923752367, 0.07035317890826734, 0.06308970777618308, 0.017975471733558564, 0.023387867596841628, 0.03735374238702559, 0.08562514167879859, 0.02913208678364754, 0.06010034459552938, 0.10608007996192864, 0.03444813176869385, 0.025347509015832218, 0.05635027142782366, 0.04135123131075694, 0.01300913343701752, 0.012395859943822989, 0.028823171404280493, 0.03353148458465453, 0.04395532504385037, 0.04285737932209046, 0.07859264605588491, 0.048858345215839726, 0.08869284884102883, 0.02588625843336265, 0.0514240387917286, 0.04110927393119182, 0.06084553364123549, 0.009065932376430401, 0.10612163257094161, 0.0683024151611232, 0.059961506481012034, 0.04377168993796072, 0.06650149566872467, 0.022857610263951847, 0.013688139189335128, 0.057530893358371915, 0.013860243714354454, 0.05881469967144151, 0.04877953009018975, 0.04792413929657591, 0.030760481360278306, 0.02802448260838226, 0.051401171067188826, 0.025411364359540806, 0.040745336201883135, 0.07173099570096501, 0.031101532212849108, 0.043861755064778754, 0.05552968783904949, 0.09884474723930321, 0.055722634743658774, 0.044552797015996716, 0.0331282350535114, 0.03743133943287596, 0.01963743245259168, 0.016836773964666554, 0.043301277478495916, 0.06642595939939061, 0.03334426035683963, 0.01622012872699528, 0.042535473006747426, 0.002075577335011575, 0.011244284236923823, 0.02270871341498869, 0.06821339574432181, 0.06348885107605208, 0.057852152329418934, 0.03886467844788586, 0.08087609368827074, 0.08420243213373808, 0.03197083516316789, 0.02111960574233484, 0.118932101214605, 0.018235539431653677, 0.03720780646788978, 0.022672308916826884, 0.043848210630277475, 0.030385270647163835, 0.028416581729787494, 0.0462076656760708, 0.022491906701977697, 0.01488410298817701, 0.03196761759388591, 0.001483621794426243, 0.014802889049714132, 0.047201829466728434, 0.04368666566968445, 0.05342532091984346, 0.017081506497737382, 0.013222408484697584, 0.03496862722620849, 0.09874412159044897, 0.03586802594063263, 0.01813467821076272, 0.0690578927676524, 0.10697228128030416, 0.015321241376260597, 0.01955180105963542, 0.02276253492210902, 0.041876032182406035, 0.06199628963405567, 0.03584911122978215, 0.02156918827113846, 0.018388373972547632, 0.05410207150083396, 0.028236336562962785, 0.02879699609512764, 0.0799803453828058, 0.07802826908206748, 0.04663149998973935, 0.028687870700753508, 0.016460251325981754, 0.08045442357298829, 0.02829390232481303, 0.05519722100167025, 0.029266343692377694, 0.048955550282112056, 0.038340643664161046, 0.07778908111034863, 0.01899345894344151, 0.03236694667007654, 0.025910993497217857, 0.04979162799915479, 0.07989419879572046, 0.0464715791355458, 0.02408481225551617, 0.03303993192891921, 0.06409831615465303, 0.017368938856487794, 0.04164206893033078, 0.05442164507844756, 0.03246483355460148, 0.05647130948942035, 0.004981522159200283, 0.04721708227730086, 0.028641493653037378, 0.03943642135709524, 0.017171073667404634, 0.12184165718574679, 0.04985990558540629, 0.02328432123777607, 0.08567833882426062, 0.043021486846790205, 0.03363489879355316, 0.045604551466362137, 0.02930490281282654, 0.10020026321252508, 0.02136895395514946, 0.015272948151123861, 0.007340425142883173, 0.08639283838772005, 0.04351476703079478, 0.034911385136506254, 0.03929614682771987, 0.010075088507766205, 0.012600530866503477, 0.11176817554740176, 0.031018306335975087, 0.073833026052002, 0.03746571762847804, 0.02802475073915576, 0.01837285686164133, 0.022305287683622974, 0.05259473222277818, 0.0060519212744228786, 0.03108976127189254, 0.02228527938226058, 0.04106400196530646, 0.02337404354024799, 0.022167027965488455, 0.06679583431011246, 0.08198864487630707, 0.024960293704944275, 0.029109839590326436, 0.017091668654052962, 0.07889654547456773, 0.06670345176732348, 0.010648241018756263, 0.055457078025586186, 0.03543876389402055, 0.04343184950431028, 0.04898620912084176, 0.04380333703011275, 0.05918562029218001, 0.09934029887400328, 0.08935406698935455, 0.028834928938698386, 0.027009894913663308, 0.03907658219818146, 0.07995033771881173, 0.06921704753392166, 0.025866930035033056, 0.024026532116676533, 0.03587212068058791, 0.025836937692797473, 0.028117654221733252, 0.1015034017543639, 0.005717333331103287, 0.0536410627706397, 0.08767820368971556, 0.03805504608598929, 0.03190970900768955, 0.03361116922009857, 0.03433729799824857, 0.053975475471346616, 0.026889320335260807, 0.07603073312390236, 0.24676899395642743, 0.1635782651963734, 0.11334554292261602, 0.1630188677940638, 0.16729832686964544, 0.1361428486603883, 0.22654554446137723, 0.14584640942273602, 0.11215333391221301, 0.08612283835968665, 0.1413840391943532, 0.16738373035144422, 0.15537116526355668, 0.18874385514326636, 0.18435797113324368, 0.13999354364650865, 0.09792083754174172, 0.12706151983189967, 0.13905246591856404, 0.20174603728998095, 0.1545123500569213, 0.1161949456699433, 0.14869595006588968, 0.13496529491197679, 0.12166743347000693, 0.1443372928206959, 0.1776098090434267, 0.21310047156387762, 0.12040554110201136, 0.06947632233101515, 0.07182617446467762, 0.13863697047195128, 0.18519326744060363, 0.2925163327205566, 0.105349040560184, 0.1258614201158766, 0.1381883953487681, 0.16998991550457093, 0.26719712682308694, 0.100947244903974, 0.11663038238522508, 0.45399632905760123, 0.10153659634412297, 0.16416571673847016, 0.10261588399448704, 0.11973374327945134, 0.1363140539897065, 0.13120764896513956, 0.24374745125251435, 0.16165576755039154, 0.15289486265711247, 0.2068916200509956, 0.07459884584550897, 0.24817747724873407, 0.12076790835107527, 0.13741950354268476, 0.11836066857100495, 0.07213434865397793, 0.07723862395411538, 0.13209586662630882, 0.25954648251495055, 0.20706927584063625, 0.11662638340626033, 0.20211002098456507, 0.189824927778494, 0.18675541264876244, 0.11562262436435108, 0.15304906083451164, 0.16522863308989233, 0.17442879747719536, 0.20371160439906583, 0.18989226690703825, 0.11997804105762513, 0.23479255757504897, 0.12261564347652659, 0.2091049399947928, 0.1341320670420124, 0.20479059327513943, 0.07162410345289015, 0.1822832364949488, 0.09845437181572761, 0.17094251519489675, 0.07223142731574274, 0.1370329508978513, 0.15014284500671973, 0.11665471333770022, 0.17762419617464467, 0.17855411966241178, 0.1908801526071564, 0.16300199853797115, 0.12109966272668493, 0.11089413051283169, 0.1938901886704468, 0.18213378806268016, 0.1297813311459557, 0.1423329923061594, 0.2110793477585239, 0.1105699604076724, 0.1360044472159878, 0.11723738449114947, 0.21561066590009198, 0.12248276552606015, 0.12640516634189314, 0.1700223363455265, 0.17252837848519126, 0.15070296253167814, 0.10338744178654687, 0.2527901845713777, 0.11448483824008897, 0.15275511289796523, 0.1815487880019411, 0.13435908953749365, 0.14562888641751584, 0.1091994061284969, 0.10560117541782318, 0.19006888081710185, 0.08891053272471314, 0.2847299989192717, 0.14997312588797462, 0.20071672155491768, 0.25696852004095433, 0.1742901355629006, 0.1606413752080933, 0.18061097380855393, 0.10964253436653845, 0.16229509856672059, 0.14598651158232845, 0.11495671775792876, 0.12727087633984704, 0.12773242899246756, 0.17584976800266774, 0.1008598878979683, 0.17425529388410432, 0.108202189477461, 0.13679630633804107, 0.14163493298955504, 0.1567688007508555, 0.15773407153544888, 0.13117124446697775, 0.25599068541440273, 0.1876909132566183, 0.18412059112902612, 0.1423585336775549, 0.08243463062230619, 0.1551150773922282, 0.15894645164089818, 0.14854377436061061, 0.13080009018942235, 0.15809591018384503, 0.11654808922039887, 0.226900871362417, 0.16042109428634568, 0.1297329909979336, 0.16510385268878552, 0.15961311667436556, 0.13704271085800665, 0.12989914014695153, 0.09981366460241618, 0.15081186959099385, 0.1421436000495188, 0.1489243055543592, 0.11768790547766032, 0.15002292160305286, 0.10941473812225366, 0.09741962451728121, 0.20225098116263268, 0.16241477682225167, 0.23741230248443543, 0.24432226234386045, 0.09997497973663193, 0.1659104053772265, 0.16427646240880414, 0.29020522931410425, 0.20315073610794163, 0.1154752979956327], [0.06620773159328007, 0.016821147686231042, 0.06225231621835021, 0.012686047346271094, 0.0452219556656576, 0.06005709510176413, 0.12922371106763042, 0.043203984312112295, 0.0976577093223891, 0.026360495586789427, 0.02792841901311711, 0.05942789942867333, 0.03582301444464153, 0.02987494309162421, 0.019658291111550024, 0.037228375928656715, 0.08481664312702995, 0.02983265695342374, 0.03216228628110501, 0.057438323124041485, 0.017837152643609914, 0.011726495408032452, 0.07576563605858434, 0.04260813261592581, 0.0912961228600433, 0.045059985526266604, 0.037852094073088906, 0.035776375011811336, 0.05985319697027726, 0.014352033857346303, 0.005607031512960431, 0.04361238961498584, 0.02312734790687119, 0.031160003873669816, 0.013001873796325059, 0.02457537857304898, 0.017703857175224734, 0.0587935786273691, 0.026739960003103462, 0.010657897557041818, 0.05017000265539654, 0.04063897255447604, 0.05627678444368705, 0.0216880334060519, 0.03129555930143162, 0.04740201590222217, 0.02599532254070284, 0.025338346604257826, 0.06109094990777874, 0.02706198314685495, 0.03184563341370273, 0.026900106853234674, 0.05230856007866321, 0.023262179381544554, 0.01584168129240073, 0.07496331983636464, 0.013052487310262458, 0.11227796875661421, 0.017824320670878215, 0.009564650827087462, 0.037116002321483633, 0.030767753449899536, 0.03210207177025657, 0.08163845842523922, 0.029561653350209518, 0.029418900526399096, 0.026987274252479116, 0.056598503067488634, 0.025586396298040787, 0.038962802819667325, 0.02516969809338691, 0.052578552445817384, 0.0427095549962213, 0.02475258045559449, 0.0858733771489032, 0.02851850398245358, 0.09981069984214921, 0.026947027823377042, 0.005154968774501956, 0.11795449641443069, 0.035924436824937026, 0.006556858443805287, 0.07862325126845991, 0.040362939584038915, 0.04534233872207903, 0.017417449459073045, 0.005512461789147628, 0.086344720405196, 0.09771042383245884, 0.006214681441985792, 0.05093661534990515, 0.05014516225445175, 0.0052191329474050195, 0.01293462181028219, 0.05883173746687751, 0.07372540602039906, 0.07790908112280792, 0.03098788498450191, 0.042560324899011084, 0.01188513306495283, 0.050685020584252574, 0.017562165383189436, 0.010159068981245642, 0.03497451078146696, 0.03333280351193201, 0.0682154871643551, 0.009449786476550565, 0.10556519226801973, 0.10150185425675685, 0.03451188943619209, 0.04265771382638524, 0.03255328223589928, 0.0189788879511217, 0.02304922417557288, 0.009595435112714767, 0.04341281221939191, 0.036422397806158954, 0.0856211886651093, 0.05021668422306257, 0.041089796145716985, 0.058178233823949294, 0.041955203538940805, 0.12195827108958077, 0.05665440450332338, 0.015431207552131627, 0.02068022558946283, 0.02560140013003782, 0.05033818959829308, 0.05089108674456516, 0.05019537931788833, 0.08175827457659668, 0.02990049212389896, 0.01737084450019944, 0.02568386374942718, 0.02732089788262402, 0.024077612944247744, 0.03211494779304391, 0.03643528340504535, 0.04298796283922369, 0.03994807232952407, 0.052498825675537514, 0.02226054431840537, 0.01593557973166988, 0.04906271832183965, 0.04905875764727112, 0.019189058427488612, 0.009335354965690885, 0.03617530380706153, 0.04240516911170656, 0.025718701597783836, 0.12561507688294496, 0.06198418544485204, 0.02894269261178711, 0.033789660045576674, 0.02445505680366149, 0.027870692372802767, 0.03506363362013813, 0.020118690801844485, 0.053992333236120404, 0.03304249449302593, 0.05053991587051461, 0.015039484771419198, 0.03821166893166881, 0.03448167109801885, 0.03193686107894586, 0.001282280122282945, 0.019209128015884952, 0.03737056567784279, 0.06390043181337177, 0.009335245798161675, 0.05684842776146628, 0.022748013725504283, 0.042174657085730184, 0.060369735583662994, 0.03871856249808785, 0.056507491822084116, 0.049557879251698335, 0.02649745487067248, 0.017480042672926382, 0.03128475171603984, 0.04240868928571863, 0.053473262702144926, 0.026777776018265757, 0.015333200008758615, 0.07213582720367179, 0.051022700649956544, 0.040032885923621156, 0.0561228237535444, 0.060579218496117866, 0.049540289872956854, 0.020221677916725318, 0.02175626885746756, 0.04698856974080686, 0.06712404935951195, 0.019449712182845802, 0.09947346027700171, 0.09840484423142287, 0.0827237292222919, 0.04558014773553418, 0.03106606234195492, 0.026895516071348425, 0.029871359715358387, 0.05974546585592532, 0.06416695763266857, 0.05888045682842213, 0.060191409467088605, 0.018236926050796624, 0.1014022475048419, 0.016162043940576337, 0.07618895326290401, 0.02268658305007604, 0.02156559340355377, 0.02755989816280142, 0.08489976366681438, 0.023654847323233565, 0.03441094586084928, 0.0489822790897902, 0.04024972328014913, 0.007733921895945265, 0.04392686870790297, 0.03531901286013665, 0.059998677067098126, 0.06383173670920153, 0.032462443360277725, 0.03446777809351202, 0.04647383143404319, 0.02861118146909341, 0.01170099904430249, 0.04882022851116715, 0.03529853916036026, 0.04511000723728249, 0.02982933213183236, 0.024558457606021437, 0.09829344738635326, 0.028740893561212767, 0.047571539668546575, 0.011760025161258396, 0.013227771100167547, 0.059851714590143774, 0.020988788568384705, 0.009425024599618009, 0.026796441750540852, 0.08458515433895011, 0.05610897671431304, 0.03453473800853376, 0.015497045148344291, 0.023581352678217718, 0.01703337510867465, 0.039055763758839145, 0.07290851114498031, 0.0269215707216532, 0.013753562140458775, 0.08691733282419943, 0.056107467521102204, 0.03739716808101343, 0.0684024968875512, 0.06272115819757024, 0.06256622074532413, 0.0830955806398584, 0.03234251995661086, 0.009956733669124303, 0.008369094012455355, 0.03068188265446694, 0.16527351052049669, 0.059349065150825255, 0.052932898754314076, 0.06900263484567404, 0.03187928957143619, 0.041436630962116104, 0.02953123391395615, 0.015207834507999642, 0.05456280060893586, 0.1398383648765664, 0.0425376333746939, 0.04691798622990328, 0.049467032715197534, 0.009052265367861237, 0.01661095997288583, 0.02632620357607882, 0.016406439394960483, 0.04974336829036475, 0.019349582575922532, 0.02420223438211026, 0.0808018138031325, 0.024452178228286006, 0.06679891398356808, 0.021052454305332036, 0.04332961507081505, 0.04598419399811857, 0.057686493476672526, 0.008671642243561727, 0.08737044318789437, 0.03613322642782042, 0.044181240542281064, 0.05828217663351567, 0.02301770731836798, 0.07369388916319417, 0.043866068139792457, 0.05350369171449735, 0.048329867122154084, 0.06929054600937713, 0.029484584905026905, 0.04320247894934109, 0.023740312092066295, 0.05024206471599398, 0.033535479733179656, 0.04050609843444921, 0.01779563259333372, 0.048952845991739345, 0.050353748844035214, 0.03701831845025863, 0.021855789424491026, 0.004719264886056584, 0.028635587115141175, 0.029435271825340968, 0.06810097234143365, 0.049171633042034604, 0.01516163940616553, 0.022913159299341422, 0.03317910712212324, 0.04318891919308132, 0.06844339832182854, 0.051924252071447914, 0.05858716772749059, 0.07783295496577218, 0.06235515969174524, 0.05699452072862656, 0.03975655034845395, 0.06441138564578949, 0.019129788120006843, 0.020308002619253054, 0.003332970133464363, 0.029533143388107422, 0.031014454828935768, 0.01609914812199291, 0.007064132660161705, 0.05257124779745937, 0.019156620349554766, 0.04102971953069491, 0.026683143092199203, 0.011704874491589445, 0.03589391205159407, 0.025752171979195652, 0.02997959070208092, 0.056856406567197655, 0.07326920832236929, 0.02490259196248747, 0.05876735160728136, 0.04356404563652412, 0.07921804959375052, 0.017603175984995983, 0.03497062288525124, 0.15853757519395123, 0.08000715079927638, 0.122194915649391, 0.06380496193624793, 0.0989031078173749, 0.23057415570703246, 0.16871978769138937, 0.11424109204522065, 0.2501388461959939, 0.08487674272468976, 0.1279063462730377, 0.1270313819329585, 0.14577974445156514, 0.10160244926209412, 0.07561559773861401, 0.24612141983403316, 0.272979497188522, 0.1804362904400595, 0.15103575112598558, 0.24871643542522387, 0.2263143084823124, 0.13156004941030858, 0.1009475666609022, 0.07114563557890154, 0.23515275679528716, 0.09333634523734932, 0.1412703057811145, 0.11235623229895869, 0.2275263974743505, 0.1359587730539422, 0.1045322452761954, 0.1305119032340665, 0.10751729155139578, 0.14359683819836186, 0.12275170069187881, 0.11078741446497942, 0.10010537556222371, 0.18794032084124704, 0.09333858987496746, 0.17585649425464292, 0.1455989017361595, 0.12566798291499578, 0.11808218028877052, 0.12890811348634382, 0.1615704100338682, 0.11447157725811967, 0.1851708517079392, 0.17328061553980076, 0.13537314480110524, 0.04837296339833448, 0.092281281287151, 0.10240206119394112, 0.11049347418931224, 0.12320946887015335, 0.16458168715959595, 0.1513832486084392, 0.17194036003803054, 0.27936526904663733, 0.14911780404227395, 0.20502660964285174, 0.19577611327892352, 0.09720045442302382, 0.23447931954456916, 0.22497495696429284, 0.10129745433767957, 0.10522288120081348, 0.20215134376720076, 0.14333197095942113, 0.18967984604739374, 0.11081307841044281, 0.2132486023249165, 0.14863680807813523, 0.11059264427111035, 0.1016373445670451, 0.16482980771651193, 0.121307211267131, 0.23585411028996592, 0.187266408616016, 0.2154209059212477, 0.20516055245553294, 0.14220738453009438, 0.08880400819884193, 0.1433253059944799, 0.22570185183036715, 0.12102587313781824, 0.08615610189735891, 0.13982734853221526, 0.2124665644500525, 0.10427195924304186, 0.19544389158968004, 0.16994347525460107, 0.17023774494807567, 0.13340606083793025, 0.12417748224951568, 0.14131138341561442, 0.2555323503310642, 0.18917116366567152, 0.11509378620934103, 0.19168025483527493, 0.12367950211609564, 0.13462919681783647, 0.14326688412937427, 0.05260285658521518, 0.1761232460698774, 0.2740640938282013, 0.21990670311835506, 0.15694293253604444, 0.23400311929083642, 0.1936851222548754, 0.197499887717347, 0.13090643851507094, 0.08521949812289208, 0.09196306368516338, 0.216096687401014, 0.12683258977748696, 0.1736813254894749, 0.10373367522392543, 0.16245389327166543, 0.18547500393563704, 0.10805040447702331, 0.28625797660600755, 0.09431064819856998, 0.3346517507828051, 0.12950328719471732, 0.1874156885089413, 0.11417875547082194, 0.13780044842391245, 0.1462861592130315, 0.15127343756537284, 0.12473985207297149, 0.15321110375225544, 0.13939676115349417, 0.1362153512215422, 0.10400453327043403, 0.11281478954779525, 0.16355905171123244, 0.10208933644237057, 0.14773515323477407, 0.12016194046384866, 0.17336252566066482, 0.10291136410688201, 0.08826180180955319, 0.07016721872552749, 0.08992680198242588, 0.1356521387013697, 0.2769032769626187, 0.1871093912350555, 0.134022286642463, 0.13223933957276807, 0.14997913201730098, 0.2215317441450973, 0.1194257606121321, 0.20820947514185983, 0.1448946983944024, 0.09589283426682796, 0.11811380439828481, 0.16757011954342166, 0.11206641357632414, 0.1150094858941532, 0.1439737994223833, 0.15059160399100474, 0.14912166512541233, 0.125788863928568, 0.10141683381892021, 0.21505436349299648, 0.1301146713235686, 0.08231977105981882, 0.13455932959914207, 0.16921403697661816, 0.24067200660224886, 0.09244074248858998, 0.1445399230766681, 0.1154687096394839, 0.15297312619945697, 0.13875998887083224, 0.11004263144587317], [0.02940386222044547, 0.059855748043065114, 0.07438025031719478, 0.006446351697142687, 0.003048613857132413, 0.08364784576359295, 0.02143816808388839, 0.024965323072167176, 0.03906371575149317, 0.045988671782035986, 0.03476438435515569, 0.07091438427807824, 0.023981909410307006, 0.03699653474013171, 0.06562885257505602, 0.04907141341978023, 0.07531645572594098, 0.028746997366749474, 0.051883151454310265, 0.0772087388641892, 0.06526021106589226, 0.009082206956771834, 0.04340920394526855, 0.037736966379828034, 0.01706874730335849, 0.028664589288734624, 0.01882779626025548, 0.05757667477272692, 0.019829848841313395, 0.06829884519139606, 0.008391549007125921, 0.03107029497773657, 0.059542532995223045, 0.018829837884573687, 0.0345811897498225, 0.053485232825961807, 0.06445116093081814, 0.018321211044225964, 0.029907109208344936, 0.03260827585754376, 0.037822155357008024, 0.049167691519664186, 0.06510672535026266, 0.031471987435173605, 0.037429987287689606, 0.05250067577787465, 0.07436004091775225, 0.051532761989942485, 0.06974891173623263, 0.114425711574093, 0.0684967793283924, 0.02632513296820464, 0.04610925785175735, 0.07940336626263396, 0.0938982094427751, 0.0481072458017978, 0.019526956828251, 0.0072050870925698795, 0.02616417406487369, 0.051699263539405606, 0.05741767705448213, 0.0790250414021073, 0.014495761528040373, 0.06715197326435197, 0.05488840329851355, 0.0053608070236570654, 0.01890914139127539, 0.05122161920993559, 0.026117017522694606, 0.023659246583138744, 0.02464996680857674, 0.08090069277151939, 0.05107736102335396, 0.05488989333952627, 0.06260794572412007, 0.0968681867685049, 0.04332971849268483, 0.02078651071285769, 0.08387396427532358, 0.025798405385425976, 0.04602676550407083, 0.03406640164734375, 0.073258061743071, 0.08207252384313653, 0.023521308621932423, 0.05820145011849462, 0.019072433032335776, 0.027003630229662505, 0.011404715497196924, 0.05934181412862194, 0.045784195254166285, 0.047338583822091745, 0.040722468477343364, 0.06613690676468034, 0.05824153949957221, 0.015663109070080665, 0.03304061757761144, 0.01797357566594597, 0.09430522429606608, 0.07004373301301273, 0.07849827934537204, 0.11327711594921928, 0.051591134059333035, 0.026615034045291044, 0.02906808971367296, 0.008765385550026213, 0.032843472511177106, 0.05011279120921128, 0.02475613701878296, 0.06348754489614118, 0.017011645024702433, 0.026229827799984527, 0.015329955626399288, 0.020380417080295664, 0.012695651216011856, 0.0183194452115605, 0.05101798920922222, 0.006549123349794818, 0.054259954561148925, 0.05854101476049232, 0.024023705252235936, 0.021129806203046636, 0.0251399336623088, 0.08278631094482639, 0.04140033754670332, 0.053179142395815546, 0.014949137149679085, 0.026822241676610806, 0.04757788670699924, 0.023112340244434537, 0.056017739472970854, 0.05960927840562598, 0.03619037275653213, 0.024536428747758753, 0.038279540491320437, 0.05480622504687598, 0.035255289666595004, 0.04388880179894548, 0.07649584808537076, 0.01310094428669301, 0.017385327392407966, 0.02037745806568813, 0.044476578928410046, 0.05960193545287175, 0.061544608024339524, 0.05734672199093527, 0.022355079568261584, 0.022345817565257033, 0.030400977364831397, 0.08271780736263722, 0.031784819439053535, 0.06616306866729452, 0.0569343560134932, 0.07253763265907764, 0.047093596564786094, 0.03569621923229387, 0.05221784377710954, 0.08436133409099233, 0.024010045904546015, 0.057757329796591116, 0.061040162108838565, 0.053231902871160745, 0.021940403835727804, 0.0076890047245298425, 0.04602263629015896, 0.04723295561909195, 0.014405670545754895, 0.06119801069519693, 0.11163342068152082, 0.0560012647521592, 0.030678441004467108, 0.02367431936304896, 0.034849829971790314, 0.004145565101005618, 0.022097055409704486, 0.015282903463699886, 0.0404599761109679, 0.021038850499016624, 0.03907755896028492, 0.049980882359969045, 0.020416547702024543, 0.045006458962997126, 0.010340775460785916, 0.015400139813972338, 0.05851511715821201, 0.06831625070903571, 0.012870296280110076, 0.08971507060191325, 0.03685098186495804, 0.03345920035855905, 0.028154506881330765, 0.02135933955169974, 0.02330497113777505, 0.05926612464170303, 0.05355582782818426, 0.046827465280770295, 0.050761437854699554, 0.12366013541336983, 0.04807580172294571, 0.016664758497368426, 0.0344407313593453, 0.030473250099608017, 0.043915327593323686, 0.018548720005539157, 0.01137644781040088, 0.09847644280882613, 0.05405795632771427, 0.020091883470154098, 0.06458531824811813, 0.011057388469306453, 0.06380310800347118, 0.04281200010389571, 0.09587457839159236, 0.016656750963339885, 0.02295365279179908, 0.017620037580209396, 0.06246043549429986, 0.06094126398825358, 0.019624056557433742, 0.015210605831065727, 0.05178725256794884, 0.029634787933900956, 0.010244071224494087, 0.03783814361198776, 0.022074654998798526, 0.11809410827775156, 0.06267776314709937, 0.029063889636628093, 0.12881564667388318, 0.012601434850254127, 0.05023623095645059, 0.007834582018756099, 0.07409206336183895, 0.04473398447096829, 0.04926746298048285, 0.06327877827589551, 0.021899360675184477, 0.03607349072192465, 0.03811390845165138, 0.04159875431909196, 0.09959180553954455, 0.051204937645384384, 0.023262236838138873, 0.09289736153497812, 0.0447018432521051, 0.02184208602674546, 0.008145382932026782, 0.04797499221298964, 0.04001387545178014, 0.0036772814083604085, 0.0342365421144472, 0.033973348777621024, 0.031993760344301986, 0.01236211855880796, 0.0433435655319162, 0.03383142715920845, 0.037549550630032055, 0.10195109587643417, 0.02232371592864154, 0.02517321826739898, 0.03974731132808713, 0.02856384872669174, 0.06563108955179492, 0.02439796984676392, 0.017827923199342146, 0.026395450263554533, 0.029236956559602293, 0.02232806156239202, 0.05534471207929235, 0.027590884504118757, 0.04404491136571573, 0.033238762388786966, 0.020336041437281717, 0.03678356229718174, 0.03808154123685053, 0.04335062120169882, 0.07723408871360364, 0.1267631362462717, 0.055876185576761925, 0.04038669597057085, 0.028805696938727653, 0.022013900395963463, 0.06180742980852243, 0.011194931895231769, 0.11749035438462613, 0.05369727064164416, 0.06691788743820883, 0.02372708175361397, 0.02700372216021342, 0.034100875603936376, 0.01571566748973583, 0.038500970544954466, 0.031593776262936094, 0.10200739567798954, 0.04823186149400088, 0.0765725794518667, 0.017433569864219716, 0.011999438171305004, 0.06185145305109121, 0.024126801534645984, 0.02984583558094117, 0.04046723096361084, 0.029635716815509146, 0.060527051738913984, 0.10250377468764783, 0.01609721183476429, 0.02809637229919674, 0.05104831479970486, 0.010217604801930007, 0.019035691455487284, 0.022319073435820402, 0.034269100851229126, 0.04961548906360423, 0.039947585863692146, 0.06074547106700559, 0.05835868583451356, 0.026356125055181406, 0.06434879626237577, 0.08022236021896524, 0.054835485775143876, 0.020643970478446256, 0.02436076095628162, 0.026218135383040197, 0.03967206234172468, 0.06327305559910114, 0.051250450928965886, 0.016000989276254853, 0.01889662734503227, 0.04636405486493342, 0.02012468735507179, 0.02706029583820172, 0.008794707565328047, 0.02217925472875997, 0.0302121615893538, 0.038202299676354856, 0.043055600742058414, 0.06640984090946375, 0.036474373041381764, 0.03586822895393257, 0.03698767876372703, 0.014337053007986999, 0.04971181695920326, 0.04318857828395502, 0.06543281067523264, 0.09233997128303013, 0.04622998947818433, 0.05907515041349877, 0.02115852683932791, 0.05018904377075453, 0.03407912253732643, 0.037523997767317685, 0.02536709788405607, 0.11637351310421383, 0.15140019447332428, 0.11734492025308071, 0.13774901328067626, 0.1006620686741606, 0.18300709765284293, 0.07526908084870347, 0.06064538167969835, 0.1538953275209473, 0.10180106521734308, 0.13621979453150304, 0.22456058000604953, 0.16097473070746468, 0.17401771469702645, 0.09370921555185512, 0.22770443630795326, 0.07550497464234791, 0.19788829429495722, 0.1433618177449511, 0.19897828419362346, 0.1911155561045293, 0.20826259567852945, 0.16581588544912879, 0.08016571567784395, 0.1413718737181156, 0.07332825837957282, 0.16129300959648626, 0.14504563303724413, 0.14023377349780453, 0.1512155672835727, 0.12257448923323425, 0.07969829479172345, 0.15112855501713293, 0.1177481965973012, 0.14244836514755604, 0.2569732544643264, 0.26395492015346406, 0.11579234348309618, 0.16824996128918665, 0.07301026294308324, 0.13463146443809235, 0.14858025546756484, 0.11983571724305231, 0.14184893199032353, 0.134353389843337, 0.16350911810032784, 0.11110683482500816, 0.09397657257654975, 0.15250139989920203, 0.2585648480922945, 0.25733466410348493, 0.04485243698582054, 0.26056102807483367, 0.12164968321280134, 0.11135009072360494, 0.22747255681503206, 0.16085908207441532, 0.08235431396432462, 0.20152644584736518, 0.2109049248599237, 0.12986049867205082, 0.1705145631586352, 0.12820858328092483, 0.1308979809043869, 0.18803274168843226, 0.11308717210927319, 0.13702887531009414, 0.1587944138314455, 0.20478881595115508, 0.10815779468224895, 0.09834936414394649, 0.1927915266564777, 0.2566839796641181, 0.10444528663591032, 0.12330458634683203, 0.3021393163550285, 0.0895882983722033, 0.08785991208447565, 0.11955139903171409, 0.0684184774816517, 0.127640659320018, 0.13965412073077696, 0.22703239333725747, 0.16816271919636958, 0.08984074732589145, 0.1356809742508396, 0.12520387152870818, 0.11767666696781114, 0.17229891983011078, 0.13315864508190464, 0.09776772720919502, 0.15611307545294686, 0.14285233863178762, 0.14068742012304647, 0.22012421080181677, 0.08618201099095807, 0.08435574164914508, 0.102479359465501, 0.17376675961479066, 0.1781163770224779, 0.1317033231739075, 0.22337646854500617, 0.20446402531477714, 0.17893656607597105, 0.13820149545227328, 0.20543810611049976, 0.13559233787800037, 0.11472233315749515, 0.16560603864490986, 0.1673705689609051, 0.16432118662182363, 0.11794217772060826, 0.3085207674772509, 0.10110489047703244, 0.13450836943041894, 0.10765596112656979, 0.11727363577172642, 0.13510282301614362, 0.20890997061806343, 0.21088332118045902, 0.1537449138178941, 0.2325601313984202, 0.2350090693442091, 0.17541806213557723, 0.1868891869221003, 0.11879910069007067, 0.14896075601779646, 0.2745545126738087, 0.1966766649556737, 0.09009717993678586, 0.13436621415518946, 0.12985368048952473, 0.15316737545353754, 0.18482016729972056, 0.17755782231688502, 0.1769523370650507, 0.1241823009425594, 0.14728915216701646, 0.12340957869685466, 0.17081254071766333, 0.14269955005616913, 0.2005255826178097, 0.20637192132492221, 0.15883762119037492, 0.09629126893536699, 0.1328371333018426, 0.1417393201301175, 0.08010363191246025, 0.10258574609554584, 0.1713628982824664, 0.07096874587718519, 0.1311718113720417, 0.16877431782983965, 0.13979255281869443, 0.20634113991212463, 0.13291125996939598, 0.09391776766748199, 0.11813156997724888, 0.17618837886519972, 0.16103980221575306, 0.2513910015864719, 0.10605800130795087, 0.1310854885847338, 0.17838389492563664, 0.1241884219850744, 0.10250590441207733, 0.17962291956909243, 0.16722518079463514, 0.21831397568025898, 0.2384026396659113, 0.20292307009860394, 0.1433686512492357, 0.10683031752705575, 0.12010541849679525, 0.10873607615189207, 0.1229285597500782], [0.050682841064107996, 0.08328924766711651, 0.012764095426386884, 0.0604912064849369, 0.019287477743120927, 0.023903161317350406, 0.017737708685378877, 0.05445152633793412, 0.01441124096257432, 0.055186675801392526, 0.024211454250278975, 0.03284080269476099, 0.033512830343698306, 0.062396666335482756, 0.04796340130269528, 0.04236753121198666, 0.018731820765101624, 0.029968288989977974, 0.021039166510285392, 0.05234257821294089, 0.02324487728577468, 0.009739048827830101, 0.027430770212724328, 0.04159298184658251, 0.008525805915856074, 0.038991810738920205, 0.035200866780454115, 0.0523278501725966, 0.03514683459915462, 0.032040470640265176, 0.03980345408161802, 0.015088399485384506, 0.017535492116885803, 0.025275950658044992, 0.011194415743492786, 0.020803104177297606, 0.02715714658880907, 0.03932185673845872, 0.007558514574362386, 0.05897527553081032, 0.02136291335186651, 0.023916523805969668, 0.035884370426497156, 0.04786543014849867, 0.025489968811011603, 0.03952492366454775, 0.023942576541054635, 0.08010003129921614, 0.04761342935624623, 0.01598172120734929, 0.06833465214097692, 0.019351026651659803, 0.08907434530556203, 0.03906058245188287, 0.05170612002632791, 0.002687011738382881, 0.02067562331625771, 0.04270474396405682, 0.06403856129655916, 0.04058179558224736, 0.0674758292734623, 0.0720688404755727, 0.06518442198754319, 0.03496833228235764, 0.04671620250108742, 0.04100092611606083, 0.021514254021308115, 0.07920565429113566, 0.012788090257785253, 0.03549784842518068, 0.08352101990772832, 0.032625895879802205, 0.020179008734562708, 0.043126548144726023, 0.07662614431953238, 0.05412144203399939, 0.0512895405653023, 0.09457958336438864, 0.05464054704193146, 0.023563133192158515, 0.09669158818019975, 0.04183974642787249, 0.052974210045630896, 0.06113324179163864, 0.01346112339712319, 0.027729456403082418, 0.000494517026973265, 0.05868300149637846, 0.036650040832858895, 0.03388889141440873, 0.03796566277742386, 0.08070563146423909, 0.04561533032345676, 0.027470022642744646, 0.06822494835021996, 0.020124792692161376, 0.01693054312659848, 0.004550410010251067, 0.06979405729761047, 0.14056700642310804, 0.0095036098988907, 0.048951861568756645, 0.0732660597010005, 0.01675903902298981, 0.06073647336433492, 0.04905427220247446, 0.027970264650761124, 0.078288838567753, 0.014452439255922314, 0.02316190613313548, 0.03684997062889799, 0.049482431082475575, 0.03172866710942359, 0.06499569622739669, 0.01143887344252078, 0.03711463868497841, 0.049976565454515724, 0.07024994856047054, 0.022787225935908578, 0.01438921114670173, 0.03397841644924014, 0.05644430489008946, 0.046893731886220556, 0.03741846915574805, 0.015003403945405398, 0.04399099792804449, 0.01240522058064779, 0.0435211255605663, 0.07053868709913186, 0.005993830742344501, 0.0678934084792291, 0.03339610535711531, 0.01482167352561749, 0.06790126854133222, 0.017058594723141963, 0.040585327247578296, 0.08206919136066591, 0.020103093251706134, 0.022828186742000045, 0.037188520204396024, 0.013528764172787628, 0.02297802587911006, 0.021551579740198872, 0.03251706542927892, 0.0465529568253025, 0.04211230135913338, 0.05510305347401769, 0.012865553238248874, 0.06423350386021119, 0.09444511961191894, 0.06577463144616735, 0.048112221542866006, 0.11584680467363327, 0.03783517885172079, 0.028385608795008836, 0.022240095516486515, 0.060188923511774316, 0.03525974446787469, 0.02799984330551759, 0.0215059821869457, 0.0609293666427895, 0.01957425126625646, 0.05687370483252791, 0.012544092211511829, 0.03684797496985524, 0.053666780342257796, 0.04023968752834105, 0.07933258739930969, 0.05395664886060742, 0.014015846705484777, 0.06541192711841676, 0.06290545213907477, 0.013658526060622067, 0.04052428536177163, 0.06093513911529895, 0.03145330638114003, 0.07836947698266276, 0.03892372084421016, 0.04419000075769521, 0.028586990327664444, 0.017506599110821565, 0.034772696409134135, 0.02501963104511942, 0.053318225658468665, 0.023108919661852623, 0.031655637862821745, 0.025653358128282334, 0.024865702913713553, 0.019338535588054408, 0.05126709035868126, 0.01632772386074066, 0.03996573448661835, 0.08818774408991299, 0.028787178678377986, 0.017229169945142443, 0.05095986228796744, 0.04318758236965345, 0.03625688451011816, 0.037911082843258496, 0.03211379866115749, 0.04160638455481779, 0.04556958338305835, 0.047698752398812966, 0.032262774034132885, 0.04201044613916067, 0.05632878266154759, 0.01022340025707719, 0.09693980066766662, 0.015828936462170415, 0.05949886981397868, 0.0298692146691704, 0.036116027753920324, 0.03222077326368421, 0.00753258920139483, 0.027563761161159606, 0.058863924651016156, 0.023751136914436376, 0.029845617245882753, 0.06541929688424834, 0.06938376358800358, 0.014749823096809129, 0.05571450655078215, 0.017994915045076804, 0.0804027739251333, 0.11061299156637923, 0.017643960590864864, 0.08009051648719658, 0.03735393007856704, 0.025602800155719443, 0.018514046866086223, 0.04917177859874022, 0.029871957263939326, 0.02885436458933738, 0.0321449420504993, 0.04603705789533354, 0.03315843040904692, 0.033988364100936926, 0.01953716686506185, 0.04971731747049959, 0.016503487413208333, 0.01677964678815296, 0.039541720142287594, 0.0335136883621735, 0.014171701548020206, 0.0445547811837206, 0.02149347963202144, 0.05616013989633611, 0.08397976867854597, 0.04450898444760711, 0.01840272662980903, 0.054824427295956886, 0.019429123569880764, 0.0380119153358523, 0.09084290524403896, 0.012197749606604058, 0.02425898809076077, 0.04364183420435556, 0.04371646265949934, 0.05196337618174092, 0.05756625214651708, 0.02789949153309628, 0.01466793978902241, 0.028768553165718917, 0.0454413938906885, 0.04748876769876769, 0.02830837755614231, 0.07702827153186645, 0.03501726231808144, 0.02961933977090784, 0.02761804423625431, 0.0413128694579486, 0.048161235848261465, 0.07687193596915853, 0.08673317294808165, 0.023376223060392567, 0.049158984930404735, 0.043443103335917964, 0.05451567471027375, 0.006875596506776469, 0.050132759290957646, 0.03864334798568199, 0.03283695310294148, 0.033996289280513604, 0.04863485821612901, 0.016727236798033118, 0.09386449391322751, 0.07076125862377305, 0.03237938793796686, 0.07304528848298135, 0.09980603436669035, 0.020745793139682184, 0.03911006024047252, 0.02159445959654066, 0.08511629075773301, 0.022625920377791892, 0.022671173191479137, 0.04282309688747891, 0.03763667780966048, 0.024034566463782422, 0.051813092713634816, 0.02150082641521529, 0.04219014738355914, 0.06193201102676892, 0.021703403045032776, 0.04753446484345102, 0.005921136659209527, 0.06963936882393976, 0.04441433045412264, 0.04648828368273474, 0.03390417869893774, 0.037460201795423226, 0.021802940849034537, 0.01855473954140419, 0.029371253687948472, 0.01805860184944205, 0.008654095957265988, 0.009196329159632085, 0.04067859462191982, 0.04057289747100684, 0.07782062095019125, 0.034005673857586044, 0.013853507886280217, 0.021760398071379434, 0.04353917459206235, 0.01070819984775998, 0.12094144258768329, 0.0342573375711518, 0.06764857443950831, 0.06667855390978437, 0.04493048219310661, 0.05789125728751383, 0.07510494651092638, 0.030476396805757, 0.023643673930857933, 0.089641074169307, 0.025622285602073518, 0.03803960175343579, 0.06978547711285853, 0.025814234677161423, 0.015358332480724542, 0.04556096106347057, 0.05270279275493757, 0.09368161340394328, 0.08184909430002013, 0.025253395114334363, 0.03909328291493078, 0.056199076315087665, 0.0836529708918064, 0.035173854520243984, 0.08885784119728113, 0.046053846712194146, 0.03336868707030531, 0.19103701677053206, 0.12582930571009077, 0.11085764174499821, 0.1786700440871139, 0.14850082747157545, 0.08984380401670934, 0.14461066363559616, 0.18140605049988917, 0.07176670305911573, 0.10818699029304328, 0.10706163777579224, 0.14471267590359335, 0.07927894592285156, 0.14711402446752594, 0.16273636521110613, 0.1859351010212014, 0.18637210821672795, 0.1030376613620789, 0.11029321114502608, 0.09668901412477417, 0.12851438259765988, 0.08313390035783091, 0.10406334584038104, 0.17013951715442444, 0.09430519365254911, 0.15653290695721106, 0.17649890494442758, 0.1921714397688066, 0.12894580501221842, 0.21425502735280225, 0.12580500540113257, 0.17567764336784042, 0.2081388265134827, 0.20465893340447258, 0.10074214784488564, 0.13664478946837688, 0.08133667340922741, 0.16842050778288997, 0.10130850132554771, 0.18043739360667047, 0.1118057674818462, 0.11887069160659468, 0.12354131517631393, 0.22003745900527125, 0.20497522046489103, 0.10068017133181134, 0.09182587265968324, 0.17184738760753987, 0.24179538261265526, 0.13087351205608538, 0.2178924128172859, 0.11946581934969272, 0.142891853446922, 0.14689409594622352, 0.1155224200638552, 0.13389911502599716, 0.13677058110554374, 0.16293982284203654, 0.18606141359815676, 0.2527116145938635, 0.17304010989685215, 0.15331711499921738, 0.09884281669773402, 0.11055117593176904, 0.13216366540760766, 0.10524163503319987, 0.15151287068522748, 0.14658534719098001, 0.16673614090729147, 0.11091611723625854, 0.1079508207077461, 0.14384282903084833, 0.1729782866013627, 0.1114365820502562, 0.10769568278544372, 0.222339645148285, 0.08121533274290063, 0.2501837695918737, 0.16525552277603459, 0.09916766862114591, 0.17696824105035874, 0.14425464725542453, 0.21014173274799702, 0.18586494268909579, 0.1042705343195027, 0.09080391136869308, 0.11766810210481768, 0.3332176035450351, 0.11488137301057579, 0.09170670768306141, 0.2640557679678163, 0.19118324763351874, 0.13028958451844033, 0.11463483825566308, 0.1971329775668921, 0.1743740375123678, 0.21419461365909348, 0.23618110725956581, 0.11093634195745954, 0.17180606482490418, 0.14626688444085661, 0.1450693051541044, 0.2261719693459811, 0.20126128749501324, 0.14121219035117857, 0.1986861135810614, 0.09962755886297073, 0.19532381496842832, 0.08155533788545478, 0.20529883132586557, 0.17631418582412506, 0.22231214259180332, 0.1563983512741904, 0.19452461672406043, 0.19223160831437958, 0.13635226645536963, 0.15516317239211452, 0.1586297968582761, 0.23886638332999524, 0.16468207532119367, 0.17822036579731973, 0.13405631626805953, 0.17929348643989335, 0.1288437314571873, 0.14722349843190563, 0.145281603439681, 0.1911683855277877, 0.13627170464925228, 0.154710705542276, 0.10928611195976697, 0.18675544329227942, 0.10525353237866394, 0.0942689347110929, 0.18105979407987288, 0.10072170095818658, 0.09689377410517586, 0.23354683732313497, 0.0792372860615292, 0.16930491032619632, 0.1434848055003151, 0.14936076116658029, 0.09708454532008018, 0.14281409552260754, 0.19597008674135133, 0.10397287085652353, 0.09959904507042901, 0.09621706565902119, 0.17130573280155661, 0.09322602091537369, 0.25996586968821866, 0.11933102617941557, 0.15650543504424635, 0.21336009876141626, 0.15507740118811209, 0.22144329163335988, 0.17851866511327608, 0.19469690989823113, 0.10061729849586565, 0.26551672828293615, 0.1562700775121489, 0.177215518910558, 0.11032373208792941, 0.17793893573745606, 0.10875790965773406, 0.12754325890132498, 0.15464195681195106, 0.1872376803188555, 0.17491325615875183, 0.18356742968242015, 0.1131918197197299, 0.1732147626218296, 0.2456813482868095, 0.10537308039924792, 0.12170890180934822, 0.16319978711826189, 0.11274675327923991], [0.09364729266493552, 0.0035851523927938676, 0.08979261402160892, 0.03996833152468166, 0.08428286370490828, 0.031735454648432714, 0.03568910227547731, 0.018009838437841787, 0.02459105273197976, 0.05855301935826579, 0.018009145128270312, 0.046310398066716815, 0.0347456649967259, 0.029503788814068805, 0.05192551611652298, 0.056647302868265303, 0.022656927786527142, 0.05295865079988876, 0.05483468138282338, 0.04740851232782007, 0.025282113835395827, 0.01799540151090872, 0.05563400603169876, 0.015133694433907588, 0.016790596099810737, 0.02005072922686175, 0.07775116741897599, 0.1191087457681856, 0.0027753620252629085, 0.09595089607060918, 0.038685176386347706, 0.046541128427751606, 0.025961867481049512, 0.09357554853082665, 0.05441296530226546, 0.0772526586848882, 0.04986238387984134, 0.02774453492865207, 0.032993641066094564, 0.02819382825926427, 0.021522891662654378, 0.027286908476643508, 0.029518919050573345, 0.07267106219284958, 0.07548458138180357, 0.06923996122373689, 0.03519450058980334, 0.020765740154010635, 0.06328928517177701, 0.019188552809458588, 0.06646459321341207, 0.00529244564653885, 0.04645479797956444, 0.07102218050990375, 0.018741274290087245, 0.021877709115224502, 0.06948182284231148, 0.06433363538235426, 0.01773354691273022, 0.04785989516324574, 0.10750861943609293, 0.13141009536000992, 0.05131426605305845, 0.03296436884650781, 0.11708038243194742, 0.015554622401513401, 0.020646904595196247, 0.014426689125567436, 0.0071790966021287594, 0.024497051828450734, 0.0616290424049141, 0.012527931586749131, 0.042754961027493404, 0.026176389336826342, 0.11876338567104071, 0.09563477754953409, 0.011903030794083834, 0.02532546292059124, 0.08632853296735594, 0.01583388730538108, 0.08478224577922976, 0.03987925465128595, 0.11746117409559027, 0.035461723549111236, 0.12414592708791457, 0.03722609298664235, 0.08111293743094129, 0.01633481591969969, 0.034228900387402506, 0.018864430584794572, 0.02727839340936513, 0.03647320858773686, 0.01688852894961113, 0.01731765884605627, 0.05280635635098142, 0.03697805669939807, 0.07640147371397865, 0.022924081797921853, 0.004102811170366383, 0.009591267594406682, 0.059786589455700694, 0.06956158025610833, 0.01798294875169954, 0.055284631633830655, 0.09773843200697054, 0.019907585698209947, 0.028483147109528224, 0.022708753634604718, 0.05561976062674677, 0.004788642766089329, 0.019778748861544078, 0.02781817896081315, 0.023792001959537307, 0.04003701130709341, 0.05325006681584543, 0.0647655404323051, 0.03675740422500718, 0.07654357536305344, 0.04268472225615575, 0.06991559714679757, 0.03045837841777792, 0.02016342267574322, 0.13382298120808217, 0.0035902047426544974, 0.08440545309455165, 0.03298673478345717, 0.03066044176868614, 0.02036284685375229, 0.002083007190864714, 0.030629072383406664, 0.017655245065989516, 0.05745800775325587, 0.024620514558327776, 0.04528070311813105, 0.019501595487517696, 0.05842156250089888, 0.03837172768168873, 0.022225449830594084, 0.04736803224190109, 0.043298619153398665, 0.04856473435797999, 0.019624537277606227, 0.026355146377858137, 0.11025915087591256, 0.04346816973280042, 0.030871780529137582, 0.029902024299747525, 0.044650806474589536, 0.05016190893647652, 0.09255938652542331, 0.01865981807631831, 0.05624055231530821, 0.053452988185228846, 0.06914386315451515, 0.02136594514482685, 0.015459148693949947, 0.05162807098860222, 0.00718082029995839, 0.04589743071025418, 0.04739540073299601, 0.04482589970012346, 0.11799842389600894, 0.05932698266640787, 0.03776361857871375, 0.02394815749158302, 0.05611068509038418, 0.022317826627723636, 0.033196999105594815, 0.021357464551505063, 0.028263969354391582, 0.016663218660640623, 0.10238483187652404, 0.015214565548024353, 0.03629425427906456, 0.012473047132633868, 0.048561616380128174, 0.008316769249617093, 0.06519906958865543, 0.06091661510928985, 0.02380066641396092, 0.029709358932450417, 0.02095170991284953, 0.04301063138090315, 0.038788498664695414, 0.012596932168479168, 0.02282861192079802, 0.05660511440627518, 0.0288853298632368, 0.09101110750869398, 0.024379794410760366, 0.04061259997768268, 0.04311783006414772, 0.03902435415394364, 0.059004815881170576, 0.04556474553781652, 0.03935009856978732, 0.03439999846441131, 0.006502067835460748, 0.053285318351681196, 0.04959875387289832, 0.056433361324091116, 0.07199885834368967, 0.11578910293117647, 0.04993876667633172, 0.025203331268482634, 0.049745034531600056, 0.03964792674167022, 0.03432682940676328, 0.020841261101586205, 0.03709655517952577, 0.06876673339115036, 0.017466389070895892, 0.014751548709858571, 0.01607664428921717, 0.01735756628125185, 0.04603333470802154, 0.04686282023847584, 0.02273755279489823, 0.04222534146280058, 0.06429801229387522, 0.033411036410759536, 0.030687819835880113, 0.02485897091607894, 0.04463817368471815, 0.08657034095977584, 0.04091289112224214, 0.10417762317604597, 0.02524276947482459, 0.033290002179602464, 0.07087600327307178, 0.04399006330077687, 0.07719402231516377, 0.048062598197570736, 0.03715290477679622, 0.028798742775594997, 0.05824426294214303, 0.018434011745416833, 0.05571343785812778, 0.041003672541269374, 0.13679463626636615, 0.08211582313261687, 0.011303477935613164, 0.03876858803954336, 0.039094589094841675, 0.02039130893535912, 0.004672063815016901, 0.058370311218764515, 0.03268279706037814, 0.09210551007380409, 0.03751590787883728, 0.07866986771865238, 0.04115872873714374, 0.09628734656519468, 0.048085163317380414, 0.02157514651996955, 0.014044644908168384, 0.010612741461955013, 0.052562832321611144, 0.0801155062752866, 0.05002914972963834, 0.061284053860412496, 0.040671489156422116, 0.05106733676286475, 0.026348718900173426, 0.07801178286993697, 0.05220703427649794, 0.0933735311451939, 0.0504072409333481, 0.0401084375147137, 0.028840270486750433, 0.06928729779657818, 0.04790751518861902, 0.023686174573677204, 0.024800441798663912, 0.022571499406870817, 0.03315348531149569, 0.043634012446648655, 0.02188226350793435, 0.03292954631990964, 0.03844423024284263, 0.01343980604302018, 0.027484631939460675, 0.02226316050866679, 0.08667786906082785, 0.030488029850887197, 0.056393923117749156, 0.03250930878904558, 0.031373217634315935, 0.038301488910351074, 0.07617062077887597, 0.01631083353723009, 0.036219369184466145, 0.031831022201766895, 0.03827728053194381, 0.061073636320689996, 0.055789851298135136, 0.001636717403720644, 0.017175668279730508, 0.06869898823600623, 0.022685928044900782, 0.09092725918538148, 0.041229860000913186, 0.008865839786707394, 0.011070824693888428, 0.04666102501834112, 0.04265068880011959, 0.05698371122801497, 0.01859483466814122, 0.02047021216112039, 0.009838512895869152, 0.03969309911612542, 0.019578568171709776, 0.02184709241133063, 0.024632387005934314, 0.013115653174839193, 0.04400612050366979, 0.03149632987896762, 0.029369755986056505, 0.046167097490040526, 0.03074672816681766, 0.09953910635123331, 0.0828611424132701, 0.01524225771126728, 0.019097750323013436, 0.022173972552522056, 0.07193679756094372, 0.03811454813506815, 0.018900116875527367, 0.028281323161096345, 0.07481338110782447, 0.04780811145000401, 0.024004520495392145, 0.07325506633928708, 0.03933936950840777, 0.021128986488967653, 0.049681560316633795, 0.007551570466133736, 0.05580585104443374, 0.09468796948391585, 0.048952983887565714, 0.08029835614105386, 0.047720739122239814, 0.012892156599029418, 0.05096466565925268, 0.03087275920646085, 0.10706503920617605, 0.025974980991093383, 0.03283041837294737, 0.05760325802369945, 0.022216172505831046, 0.027176578409008445, 0.043692897794948476, 0.20445647168784373, 0.11293053011139555, 0.21162944485343274, 0.10274589677611667, 0.16625002747581852, 0.06831775990224655, 0.19161974921101527, 0.11815036977491072, 0.08732576494015033, 0.07090647058982043, 0.08346800662336812, 0.1265789763701539, 0.15333471969971735, 0.10296480640047982, 0.13565434503459162, 0.16757874569344908, 0.07290350859083476, 0.1839881498486765, 0.17806509509682658, 0.1977696732407616, 0.19683118489000107, 0.08789985590884763, 0.21159726916061294, 0.13950153133801876, 0.15479253905434764, 0.14164362042661638, 0.26736116156943385, 0.17634865978071768, 0.10958832598501637, 0.2873082831501961, 0.08464212829787886, 0.17311604453190682, 0.1027957461173496, 0.14540805391246273, 0.15593244724216002, 0.13689936048561527, 0.11480759108258833, 0.1388664904140657, 0.17743186214037482, 0.11486795881102163, 0.12013606201376646, 0.08809022875803132, 0.10394985757527814, 0.14267806895077229, 0.15925731479881272, 0.18776479477603591, 0.12987972747895027, 0.16217682991297017, 0.12330778093347627, 0.10037521471179302, 0.11634316836153308, 0.10664279452495037, 0.08151668874967484, 0.1408003414830854, 0.11273772876349189, 0.18803510123923903, 0.2152692051904817, 0.12045496909488594, 0.10799657147858413, 0.12481084544091456, 0.1503960523874529, 0.2560756139216885, 0.22869152527663017, 0.26559989478799606, 0.28444149020698767, 0.18447720505777868, 0.13136318013552697, 0.14779322269943454, 0.09334203727062672, 0.13196872667439524, 0.24281222643631123, 0.12408214260733898, 0.17500894054049448, 0.11301257812808599, 0.23778220037779502, 0.21395899565710177, 0.16185698820458305, 0.1488487386415082, 0.15311613949316163, 0.09618397066069227, 0.317431258698625, 0.13724981506745662, 0.29216616925212646, 0.11387821151724747, 0.20145524563568257, 0.12788710980525902, 0.16653456785265477, 0.14530049516789376, 0.21970833231124187, 0.11710922564229659, 0.1568562879918083, 0.11801232839183462, 0.13251939067436805, 0.1357335891694792, 0.14479884547331642, 0.10437904301309779, 0.155888810873993, 0.123946629314413, 0.10706073379204159, 0.17236613638458714, 0.157712651717086, 0.15168537836401694, 0.16275920995300816, 0.09233123788069333, 0.23223679632909838, 0.2083926467645553, 0.14088910042999253, 0.16501178424204552, 0.11522316313799351, 0.15810743214622622, 0.12531942823120665, 0.1026334350688323, 0.07789493147884646, 0.13510729696962143, 0.155540639234166, 0.15044613921594235, 0.16490079342357575, 0.1940852499777271, 0.24594252298195518, 0.26524038504688974, 0.08445331060718145, 0.09328991264825867, 0.12485687966428458, 0.1111722587337417, 0.23550132680083477, 0.13317471760655605, 0.1501162770775057, 0.17081897585622727, 0.19349835001893584, 0.16597400599670026, 0.14515420301787316, 0.13776180694901174, 0.10001945880151565, 0.12031903445360162, 0.12868630038874765, 0.13842992754953523, 0.21673961903058717, 0.1439702141308977, 0.10015404512805325, 0.0899927391700687, 0.13371487088020773, 0.14997248237411823, 0.08077959725332838, 0.24757881017942585, 0.1687652167052992, 0.2695710494393303, 0.1882320011575376, 0.10049351400906041, 0.13290583606689207, 0.19494038796232593, 0.07956725545227528, 0.14176492278854694, 0.15712808066558454, 0.1403793302034178, 0.12226269910893134, 0.13513086183417228, 0.14544787516276683, 0.14936249252528916, 0.15003692569030871, 0.21809276013124376, 0.10276978339759574, 0.22896112693894297, 0.19332063294226126, 0.12736325888263603, 0.1661717026464401, 0.17922259266338042, 0.18983189917860493, 0.1961464401815207, 0.16156143148339566, 0.19432551047253996, 0.1034363258569952, 0.15087006162972222, 0.1060338082513021, 0.11496364319276427, 0.12529826122185878, 0.11063540729904368], [0.02666002638908404, 0.06780770622313985, 0.016537112927424814, 0.0944059725189882, 0.05401698977596337, 0.013831655228240116, 0.0018032637214468372, 0.011683886555293876, 0.012353600618699867, 0.05007767373876226, 0.028152457596133315, 0.03635942154834348, 0.0513612004297395, 0.08751416894336862, 0.04187736900583391, 0.01935929657080241, 0.12805761033368687, 0.03555833872768187, 0.021957481850779826, 0.062502482230024, 0.009400314433620343, 0.058900340640496825, 0.03986056593637313, 0.12716465824914555, 0.08128932917550688, 0.06982967272521028, 0.020381453214213252, 0.04137339040396675, 0.03411185364389131, 0.07481663698150266, 0.029342692014911485, 0.05029662549796124, 0.04506228762047906, 0.04064556474106447, 0.05430238817127482, 0.08422333867319169, 0.030272276508772088, 0.05823947489261628, 0.031630764903140166, 0.02312084956605348, 0.03314231191912005, 0.050213187031688235, 0.015709343433920896, 0.01148996480380095, 0.018195291087331793, 0.07764465821486327, 0.010405617142697016, 0.0437920180810315, 0.01720902949361311, 0.0764909144791384, 0.0426241859883791, 0.09604466523254111, 0.05716225567964777, 0.08627122192974053, 0.022187239280150785, 0.0042937921018399786, 0.064315548046462, 0.011451483249754436, 0.04425447471740265, 0.05526015895508951, 0.018496848192186128, 0.020313478232691848, 0.05196023522125137, 0.018621299175485488, 0.05642260544963422, 0.057584282025815024, 0.039648459172777595, 0.07537917534430182, 0.07314635080195243, 0.012130963018975191, 0.02327462064943487, 0.04146282350824725, 0.03669683731371357, 0.055064411999116984, 0.061246006103653106, 0.06304778361452684, 0.039835039886736104, 0.04328828845773974, 0.07948219671004242, 0.02200097457746104, 0.08168932666341144, 0.06854308168253592, 0.0035025413014790827, 0.024566702627306505, 0.03154191594090193, 0.039784700249231635, 0.0882150934288098, 0.09022844910261132, 0.030715029363730745, 0.03502663157339539, 0.023425078402543743, 0.018732353196208997, 0.010937368347039147, 0.06230852025891505, 0.05802967022323321, 0.028676266383920467, 0.08563611205787429, 0.005524623434945581, 0.055626693722461505, 0.03843370419476302, 0.02965960726742783, 0.05738455524307586, 0.014745894023367475, 0.03414935364778485, 0.06913605671856674, 0.03440600076329804, 0.039082105692115524, 0.003419030775060697, 0.0313117524849311, 0.013546882152196862, 0.04132915265677918, 0.03607683852615376, 0.07286878948610637, 0.05928351483758419, 0.07356212204021793, 0.10454735253006221, 0.051869779389591954, 0.04517772940978889, 0.01978048213547276, 0.04810900780402365, 0.04457295661972416, 0.0615402911188862, 0.05290741866995251, 0.1236094433754202, 0.03468979037396851, 0.019785444470002286, 0.03243224800474221, 0.009425852932186137, 0.027959650502570217, 0.030747003958470402, 0.056512291362929734, 0.0879996465218644, 0.019152192361352426, 0.06760178178909325, 0.051325370497520895, 0.02338634499709212, 0.07552601141674865, 0.03243142829066323, 0.05182966702587662, 0.06527848992376559, 0.030718386744058905, 0.0344732326395329, 0.021544524070416248, 0.007367685902863742, 0.022572587251723297, 0.03662106355712299, 0.02291041861979231, 0.0566056200243052, 0.07543192049788852, 0.02939692529429111, 0.10106247984954428, 0.03723644283449939, 0.05691344181316034, 0.10109533736061665, 0.06284084411398058, 0.030006279290143042, 0.009622203182399033, 0.036827394017769445, 0.06820008113619781, 0.0743005771730696, 0.011481755214082378, 0.01858686160806927, 0.05259259483746944, 0.014751170453945956, 0.03205144868022011, 0.06807034414622092, 0.016512561724671436, 0.04937319460535242, 0.036076524430104805, 0.09033774686676842, 0.057014052140256094, 0.052254428305933555, 0.05613763989399999, 0.01256336794129663, 0.017339883056739648, 0.08191985018070667, 0.021954658816778855, 0.006519060144426242, 0.06262871819818694, 0.041781665471893166, 0.017070181802996708, 0.012802901610191311, 0.03724008175213972, 0.020647266571740472, 0.07118676683955616, 0.040519367077297745, 0.05609462022661202, 0.013205039356234334, 0.07683727049058484, 0.08611939096402738, 0.06361397621672481, 0.031161940160898433, 0.07381667773569785, 0.11676569649529074, 0.03795703662739646, 0.03145164971600377, 0.062340584868985804, 0.03492956823338905, 0.06767740232809898, 0.03721040733639271, 0.02678371319967893, 0.06030425804877474, 0.02880951397181038, 0.05528178561719195, 0.03779919187147771, 0.051351586026289774, 0.04776545950481969, 0.03813806703434356, 0.016538811727396904, 0.06537113293644882, 0.12444948176703147, 0.1215204748234922, 0.0213454982581278, 0.0293236700517516, 0.02568265333050682, 0.016680072594974792, 0.054756731936527844, 0.01828293346108929, 0.018438931945110523, 0.03802717963774358, 0.02579502502246009, 0.08104293231642054, 0.08006650729164963, 0.043050693948903394, 0.0407704217509637, 0.09659155241904721, 0.030081798322498802, 0.02040720334456813, 0.05424053806270804, 0.020524476084016988, 0.030449955281050458, 0.01090282161209372, 0.043202800706269286, 0.03506041605085616, 0.04815395418254118, 0.06820224916502353, 0.06148188074509944, 0.07235445337550295, 0.027299815142947822, 0.018674304798966455, 0.054040876397442435, 0.06919201944143542, 0.06718849267570243, 0.04043183387106946, 0.04890674282045615, 0.022715410938666716, 0.0381382164214888, 0.030976577526739532, 0.08528457729205971, 0.01482261677137426, 0.02795368076242026, 0.03648104183676262, 0.036000846434504755, 0.04856641592097379, 0.07087968049510833, 0.06258757927665307, 0.09799327881586167, 0.057571293005058845, 0.032898462302381956, 0.019486248831174547, 0.0077228342096561636, 0.03673753956513059, 0.031506568644075625, 0.08202288134564316, 0.041788544941453204, 0.03790107390452777, 0.04215202684844694, 0.03708890962204145, 0.03750126410816466, 0.06333929922191367, 0.02683151708615403, 0.037305348612848795, 0.05109249509029812, 0.014991243257217351, 0.06038511479874292, 0.05393379262738651, 0.02694959421792338, 0.054106147088591135, 0.030865058107602022, 0.07242579148301194, 0.04399788122804415, 0.036988238007911754, 0.04542264771918136, 0.019111061100697806, 0.022840135798399008, 0.02651299687943632, 0.021517283899048646, 0.05089726141323486, 0.026631964588417645, 0.04291425752002866, 0.025268831786008614, 0.023835006305166793, 0.06954503275694386, 0.06916813281995636, 0.050180352503253575, 0.10194926492629514, 0.06363536539157072, 0.03615950324362324, 0.038102018767066544, 0.05022035378421988, 0.05936146428387973, 0.007957069901749492, 0.0782224570491141, 0.005762139419769688, 0.02873022195642754, 0.015176690161047925, 0.03873476142724676, 0.05423539378229649, 0.04086815158746416, 0.02035883255302906, 0.006604884016973477, 0.07443795972053083, 0.03928021602933446, 0.09382545407260619, 0.05398492899633223, 0.02385758674673496, 0.023307587328036467, 0.009399906491800662, 0.025376922961684967, 0.031642574148492954, 0.030069397274224512, 0.031645797463434364, 0.07223972404796271, 0.028166683848887205, 0.038512473355137536, 0.012410300701195675, 0.05588432143051779, 0.04969347298385636, 0.01082544098608196, 0.03006291808560491, 0.08011798073928203, 0.02870287261753073, 0.045192867307172674, 0.0184181135057682, 0.05049400039077286, 0.06100882528229587, 0.06528208287613047, 0.03016285808576692, 0.04084878871517797, 0.04550796310086885, 0.0679708676292531, 0.017599632828346184, 0.014859885991280599, 0.0634512170067718, 0.009771597030903063, 0.02815989822509789, 0.028097029219591813, 0.03713775538809357, 0.06791714188312331, 0.03562974578310405, 0.022134279621945276, 0.008120599030066402, 0.11274204949938482, 0.13104456416781873, 0.16399474123552923, 0.13679060664388443, 0.12441447920977108, 0.12018503035388647, 0.20061593502759936, 0.1530465633878785, 0.1325601159084228, 0.10304062612234585, 0.16421045627324812, 0.14123638340782735, 0.13803329318761826, 0.19440213458672648, 0.13022318001716368, 0.15370362167877538, 0.19453362591804998, 0.3417092285329296, 0.09755296978138148, 0.13628575470178358, 0.09814176197734573, 0.14193104129404793, 0.14203746622848895, 0.11471623509761789, 0.14896150678396225, 0.1668358549115158, 0.20211216603075305, 0.1607048226099822, 0.08434710783823844, 0.2991211750814992, 0.10666688032928975, 0.18691754749705716, 0.1922711078077555, 0.18960021886854403, 0.3306189413753248, 0.1772870868444443, 0.11722429204852351, 0.09757206835333379, 0.21131012408483416, 0.19049736911491041, 0.1918033651647068, 0.08967030042361829, 0.14858521971731417, 0.13809525437893408, 0.14034237412195052, 0.2435312459185239, 0.30408095087735887, 0.13895158746069478, 0.07126286235307494, 0.2743306924258509, 0.12522631790488958, 0.19102668990531277, 0.20105142536903584, 0.15668483751435436, 0.18855495318289728, 0.09395399596542121, 0.11829455518313955, 0.1798770002900593, 0.14213140392976423, 0.22705894594471301, 0.13948461611665067, 0.1472580336755322, 0.22003702999603367, 0.16665715724229815, 0.10796747545921996, 0.13791137795534827, 0.20522933182937486, 0.21775813292591803, 0.11410689642352444, 0.06832371240541821, 0.067540027441517, 0.17662252089188946, 0.13421538676465714, 0.14238730793999088, 0.14646689467612775, 0.18376262888552683, 0.20386673720373263, 0.2454242032141455, 0.11822535446093929, 0.1515438053156099, 0.20389535824858374, 0.1503195048820588, 0.10383855266075942, 0.2307282006668468, 0.12945002876222134, 0.18888014218499585, 0.19834236992943674, 0.1945521192805421, 0.16450228980712353, 0.1548997913637469, 0.16918210643193415, 0.15739158426802005, 0.07910795509815216, 0.15072818214614547, 0.16221335698519984, 0.10488465338224366, 0.1353658363223076, 0.19230075541042513, 0.16679169760356027, 0.13215790442641706, 0.13529743999242783, 0.1599907214122434, 0.11027139296094257, 0.2032369976082156, 0.1912590903380225, 0.11991811766018791, 0.1614935560933044, 0.12027483118037063, 0.12718348102944513, 0.20623315215831806, 0.13131824141788867, 0.23670226155269533, 0.17493879753014735, 0.16622148303975984, 0.17288453276118926, 0.2245999109600821, 0.2398619299093562, 0.18367861968375024, 0.1645431989022801, 0.21964673884212974, 0.1854684155794882, 0.21217549700410138, 0.14800429524433228, 0.17110625882783245, 0.22989636707690456, 0.1484494382936147, 0.21846956813768034, 0.1019681566545079, 0.14420403948714658, 0.12673590182056352, 0.1897132321591339, 0.21576144732534888, 0.11816793617101447, 0.08713012906692683, 0.09147744821084124, 0.15483937767003814, 0.14316281874574002, 0.13887807366348084, 0.21926533430814746, 0.1896311228554095, 0.15380742659251537, 0.1706693742063738, 0.1164996111765504, 0.12243385081209483, 0.13032241904687497, 0.17808608590595185, 0.1637830251767751, 0.1697090676715297, 0.16775186624257796, 0.15370405068801296, 0.209995363989184, 0.0894158366586893, 0.10482688269187367, 0.1563144799682402, 0.18529783844226794, 0.07283309744971414, 0.0795195434963511, 0.11639873271868115, 0.20139892285148944, 0.07951183665183284, 0.09300000199507322, 0.11534238174077004, 0.12420686172141183, 0.135595386907939, 0.11756595194099412, 0.11823986416622517, 0.0924834289077309, 0.1296672606540303, 0.09763991309990806, 0.14739265064558676, 0.15532455647424345, 0.17174293917994346, 0.11774412100954403, 0.14773115425580932, 0.12113630471210327, 0.24904286548975976], [0.046101999168674794, 0.08021498279225442, 0.07858900713824457, 0.036617761718169335, 0.03607292764730031, 0.09221577310874578, 0.02967227836169543, 0.002367829583818093, 0.02564900866409223, 0.012899257276477593, 0.057697617073333075, 0.027317984833291946, 0.013890565474397473, 0.03582008798877078, 0.0733949922986569, 0.05124521471800343, 0.04680987973246844, 0.039168470614259286, 0.02919144902168022, 0.028754863174512025, 0.02629579946158394, 0.056432426696823496, 0.049131195090951464, 0.004306669082237227, 0.013026674935263733, 0.07840392029573841, 0.03602648739733043, 0.008611160559549687, 0.03259226845036591, 0.07335241313182539, 0.024097037103567875, 0.032899523334157084, 0.03307567376102651, 0.10413294492830193, 0.013231709749708253, 0.019636093713943998, 0.04047471947307068, 0.06408104470240013, 0.03256996763089011, 0.01738377989480092, 0.03562148735528031, 0.02343993093217573, 0.04892368102446199, 0.0932273309257242, 0.026248564395392616, 0.03802678510246258, 0.014952920666415126, 0.020058378614785693, 0.0592905858291253, 0.03806620415660643, 0.02885285539612655, 0.04022114053969422, 0.02670594186882579, 0.03746699699531159, 0.05009459662100962, 0.055521402598148396, 0.09213794623651812, 0.03716290222420808, 0.019661924283530925, 0.025800167387651823, 0.057643144391477115, 0.07113999717177884, 0.04607662633662263, 0.03960739686003616, 0.10868947502345809, 0.018592994141903137, 0.071166442526925, 0.06882719305013457, 0.036097607169781006, 0.04338515644532539, 0.06823937378583417, 0.05167999642810995, 0.02323168908215819, 0.051932100642232165, 0.043128317807831114, 0.06000574805863923, 0.06725996867903779, 0.010507931057814389, 0.008922333025463648, 0.03392080280689463, 0.03701936799071489, 0.03968022883899751, 0.01978987820386406, 0.05650656485569574, 0.034890175992322546, 0.06432858686293326, 0.051813253592098915, 0.03909055564192034, 0.0345315778958461, 0.012550636517604994, 0.018878480637325876, 0.05076045726215647, 0.026091564251410387, 0.07895089175191619, 0.11285843357684151, 0.07527389188086794, 0.041416122788383115, 0.06160283836746409, 0.03084472996453124, 0.10158394823872274, 0.027415255017037836, 0.025890803249973445, 0.025833417518785404, 0.02880336420099822, 0.016278542931221666, 0.03178455513871966, 0.06371062586925204, 0.03623289446676931, 0.14028828831449633, 0.04618052318091354, 0.042549473263563654, 0.04881801451706598, 0.03554328509996976, 0.059581013591659654, 0.03974298293131494, 0.04154864067752515, 0.019003831773936268, 0.052959397735614935, 0.04912922241454644, 0.040287491414816155, 0.028603633587819435, 0.040145225056837645, 0.0668207551502893, 0.021294151215002905, 0.06437535653071058, 0.02828907405567025, 0.04669215883158388, 0.058197569883158135, 0.07162938179868845, 0.04562581423670054, 0.017436978955482765, 0.06154569203875238, 0.056774940777329676, 0.014975146792318313, 0.08816314500666435, 0.052965438338897886, 0.02486258110542211, 0.06460928913926886, 0.08528587198065174, 0.02815970478789701, 0.018506433867338686, 0.03691508427202221, 0.07509972179128278, 0.054632499288286895, 0.034109022949011095, 0.03371935998720508, 0.060202529233309536, 0.03679452501537819, 0.08043166310075792, 0.024598064351706736, 0.048676452959977815, 0.031324649575136365, 0.038387294588310104, 0.05292207393194399, 0.10255536304846888, 0.0742012462128074, 0.01194441582136337, 0.02326695210931282, 0.006715472160478033, 0.025732514163058613, 0.04086473100488225, 0.06178375003078292, 0.07205097530517848, 0.06142653855344942, 0.04384595450134047, 0.0400254127359198, 0.08003878256966991, 0.029958695653946172, 0.019948282203967535, 0.010126426932401955, 0.019898674180430752, 0.04093863550693758, 0.05110302496881736, 0.03209267378664546, 0.1260406310640035, 0.029963087252972108, 0.009740650909201754, 0.007676949852236337, 0.05483362035104825, 0.09050908243103374, 0.03925590422905741, 0.06622007326974023, 0.033189472291738756, 0.07129875357232748, 0.035492639027295575, 0.032481756436848835, 0.048860202979056105, 0.015638016817730763, 0.026845812286821105, 0.030557073525062976, 0.02084829187351129, 0.047649914293640086, 0.043961940213076534, 0.012863396700742024, 0.01809829478001883, 0.03782060019852173, 0.002563317506311221, 0.006428557389881463, 0.036985595004572984, 0.027455522513557828, 0.0742105695028459, 0.013772271922789516, 0.013473404744159312, 0.06418141371179974, 0.017413544325879025, 0.012978673781148128, 0.025491583341312025, 0.058613402408457575, 0.038808796164249225, 0.024108231563361424, 0.030721426197898485, 0.05118740955367685, 0.03073711567858775, 0.022720959330458316, 0.04275959968987492, 0.05400169866099473, 0.024702700470844587, 0.03105761813780954, 0.04490689817635764, 0.09276060717961482, 0.016367418706537257, 0.10214631040129932, 0.023244829405279412, 0.030652870904774438, 0.05362194504648928, 0.024087118180168253, 0.030283095585482738, 0.01288265710876834, 0.01620436263751359, 0.038790555610772104, 0.015755953180844027, 0.03512867065446992, 0.05269948325510468, 0.06433260116365648, 0.04003909123580783, 0.03764420079307691, 0.09991507166095319, 0.06083845881925476, 0.02841192391520787, 0.05645019610622718, 0.06815280585039048, 0.025674829657580105, 0.017215102655632843, 0.11877702969697215, 0.035528472789953795, 0.03910652474470196, 0.08526934746412501, 0.02154483433602558, 0.08834176606708959, 0.028724979999805653, 0.04267327307212738, 0.00641279656725425, 0.06250321384399168, 0.021974353022092295, 0.08474308336454053, 0.01816848950130084, 0.06078083368559038, 0.05119749893163962, 0.07081142206105494, 0.026074788841088454, 0.041322407252605886, 0.04235458432606632, 0.054882787874028574, 0.035043814925536994, 0.021589889882072326, 0.03964092852848192, 0.04071670366571315, 0.07089221369354956, 0.06725017807536549, 0.028072790197667577, 0.0388300359519499, 0.02441291239172701, 0.05276934281291981, 0.021472358587949027, 0.0601642937850087, 0.02076503343790049, 0.03847904893900118, 0.05120951119029234, 0.0239765218969795, 0.05974790584596415, 0.08256580019670148, 0.0236586298823597, 0.0318487782046319, 0.02116139392338453, 0.04728451333639603, 0.037194955342959975, 0.04461675386635527, 0.07025313548623555, 0.101972829790846, 0.03453414812083206, 0.03809006779544777, 0.035891311183091135, 0.0321013803759049, 0.07413747705399029, 0.04183710342453372, 0.01986233671496232, 0.026473575910072655, 0.021579787097570878, 0.019179643206899206, 0.03941755261152022, 0.019342821849990758, 0.08195498297291418, 0.035926409501342044, 0.1080434560595501, 0.01799155383430902, 0.033937783145736304, 0.015466724345911176, 0.007962896000413645, 0.03408152805340867, 0.036365856686907436, 0.11717834209482517, 0.03946690399560236, 0.03463056028610276, 0.008268036481533802, 0.04413753139576124, 0.011758723769397026, 0.018520796100699136, 0.053216987139275, 0.0386787144347064, 0.010772039869710082, 0.023917324367850542, 0.049319078154381246, 0.05623415548114046, 0.03827830708976235, 0.09196150852667709, 0.01730378690896736, 0.0351079058412823, 0.056362222399442434, 0.027320779138995756, 0.02687629684054804, 0.07210517602582132, 0.04184420122915218, 0.038151787669067426, 0.08082399970941967, 0.04916036388866844, 0.047896257526571714, 0.06638778523812372, 0.019715127174652392, 0.03322057546146455, 0.05477615226540835, 0.065686370456411, 0.04780115920209116, 0.09168981544433102, 0.03067699692872984, 0.029977229236054326, 0.03167120668466293, 0.03674114783925395, 0.05646985775280384, 0.03331281627798754, 0.03340133390719852, 0.07802597081829464, 0.059118706342433734, 0.10677902794052517, 0.1552916913022918, 0.14148906984877202, 0.15606945440653833, 0.18551128585973095, 0.12522863915130017, 0.1445784726210179, 0.1065295820515002, 0.124042451591982, 0.10988219731277037, 0.2087064057348236, 0.12213992585818614, 0.15084084303629014, 0.12603048805988606, 0.16221033859877818, 0.12010800787397932, 0.11211659233536451, 0.16408869425856298, 0.11393196790689424, 0.1017614814542955, 0.18902900839044204, 0.09579140422565323, 0.18423711310230917, 0.1469935494805536, 0.1624932089039395, 0.17403337353419873, 0.11907614872700746, 0.12012847008243685, 0.12125101871788503, 0.12534937460816678, 0.1594997816268475, 0.15803488361979687, 0.1049949087563061, 0.17349262271196614, 0.10974956451043968, 0.149773605948975, 0.10070945121227734, 0.1408396264718425, 0.07677522502959737, 0.14782087847350106, 0.10383519719565108, 0.10452624680774827, 0.11149964640818297, 0.1750961060245191, 0.16640512963696835, 0.1807758052863421, 0.18960859987043566, 0.08462397967495265, 0.19345607728727404, 0.19982312595651996, 0.10252545497590497, 0.19078609233181323, 0.10433943626741249, 0.133191816689026, 0.1932271855372575, 0.14259166955467195, 0.254175057033858, 0.09955736988734815, 0.1069917245918224, 0.1489415425326555, 0.2984184885938322, 0.13107585119864634, 0.14419643989493772, 0.14799078145334799, 0.17871885920964903, 0.1778880062122499, 0.1487230849001677, 0.26979349072902437, 0.13897852311211248, 0.1134872155624532, 0.19526787522819736, 0.0891329893361657, 0.15562480165352746, 0.06466400313882098, 0.13337681160098122, 0.2193887970380245, 0.2349035483935187, 0.1089933897638994, 0.24283335514126286, 0.12227508675066695, 0.20419253907617063, 0.20811644142433522, 0.18638741465345507, 0.2457055106999413, 0.1182629387345045, 0.15841115536468645, 0.16390941436252288, 0.1168522414480967, 0.1453380641197005, 0.1750050794573561, 0.16125658977656596, 0.2602990566482467, 0.1243978014756595, 0.20160811082009347, 0.10140296762749072, 0.15137174196781653, 0.1321333589693231, 0.1580098019011559, 0.2159522185402532, 0.2137839292446452, 0.17330180553178634, 0.23495872204582538, 0.08537030253078669, 0.22967397175248594, 0.18825357419348535, 0.08748969243418786, 0.15531341755582442, 0.11985558956380814, 0.16534777508387644, 0.11220399530664568, 0.13030761822817788, 0.17710814402709085, 0.17499928783264854, 0.13445085154906397, 0.11202751163152919, 0.15216543970088806, 0.28075201076365286, 0.10293413223999162, 0.12938207676333766, 0.07478633054321812, 0.09402728759713712, 0.11166716685458539, 0.1150083214405083, 0.09303061486852747, 0.16225333145308882, 0.20035114439745105, 0.153633723816564, 0.28264253189967525, 0.11461753999033283, 0.08992151597574835, 0.14916422897048537, 0.21194024672431333, 0.12032534701809769, 0.10404638465373747, 0.20009528635249985, 0.17716137181606986, 0.10824974821580034, 0.11190810916765083, 0.27785567747008416, 0.0981395556441238, 0.059286793693900115, 0.1410982730768381, 0.10911318293261914, 0.10261460462765348, 0.08805953927578465, 0.15031936698623244, 0.22013427719714182, 0.1414633599380332, 0.16758409298716054, 0.13226587685846514, 0.07909186725174228, 0.15364028152919587, 0.15537707946233212, 0.18419784343531057, 0.16331234075609716, 0.1355537423683751, 0.08237713572358893, 0.13301227632309162, 0.17311714769851777, 0.19305602617321477, 0.10383548064818306, 0.1440796574517604, 0.16818427691055884, 0.2815677411854267, 0.14718350864225818, 0.29232937662351516, 0.23079514142967042, 0.13434059617500152, 0.16562823987295552, 0.1134144984966805, 0.05842511714886754, 0.21241269314721709, 0.15868748327897442, 0.19691439736033642, 0.1549858077158851, 0.19674685393129626], [0.12151297482271349, 0.02999897847222465, 0.0315641573885636, 0.03034778021936936, 0.038888768082664865, 0.02398342243395746, 0.016117149272993687, 0.03796530271609945, 0.10604023572898681, 0.06310890593956556, 0.016051131646118818, 0.003928655684332274, 0.04164897521296817, 0.04070648022236363, 0.02761876052846351, 0.0626942876636261, 0.053413293339432254, 0.044220000760810035, 0.0424784837260602, 0.025066335595423178, 0.04845622949482453, 0.04288504275703623, 0.05770131727800735, 0.057809167135987556, 0.08065755944699049, 0.037356511794871865, 0.04069487015987116, 0.07479484944093613, 0.08189437775722436, 0.047200695656600504, 0.038917346992680145, 0.04116003108661502, 0.03887820756062865, 0.08064256710631233, 0.006761030451725087, 0.04386160567763352, 0.047323093524262796, 0.020400457940394842, 0.06255460302195241, 0.046827511246045755, 0.022661625820722793, 0.03457569306896579, 0.07106623056554986, 0.023696773400109623, 0.07621021220280279, 0.07199849062148603, 0.017305847685483676, 0.056370021174511606, 0.0324068675118108, 0.025897200084141186, 0.034362705304257335, 0.1303854374395263, 0.1079359126367396, 0.007137227981847021, 0.04575329892818005, 0.03876611740598756, 0.014004214617964483, 0.04907275407364772, 0.03704241191547725, 0.030015221451439207, 0.05212167292953499, 0.044432046237371625, 0.014054897079815068, 0.020773090767644106, 0.07971696435443817, 0.03600356604663595, 0.04945417009894887, 0.03482658686416765, 0.013505103547246227, 0.01775970498490478, 0.048986894769533995, 0.014275741076187022, 0.05377726937313715, 0.01966985329354723, 0.026792599819600586, 0.04941203143267382, 0.02931820592963167, 0.03323310865990577, 0.12460087606262778, 0.08799590035191468, 0.08787926346544297, 0.09336475177758163, 0.09384581668963356, 0.024992471312983863, 0.03976127328050714, 0.03436582328210916, 0.061443017104700695, 0.043262551733923536, 0.0185152419632481, 0.040217620365682154, 0.04505016427907733, 0.05179092978998538, 0.04217857562546288, 0.06552888576181666, 0.017168754336213874, 0.13395582085415242, 0.05272923811008373, 0.010458280899441771, 0.01831415920488296, 0.0715939732148282, 0.030165255940969915, 0.061728281434625394, 0.0589751108219066, 0.01525659504677019, 0.0947540905326605, 0.06447722324200215, 0.019010240099422874, 0.059656925244076606, 0.048073817555221825, 0.036789503309034535, 0.04907798645417056, 0.00850869917250689, 0.12511289092682062, 0.0418388347832426, 0.08952737139958529, 0.02770552573154771, 0.05901553345123126, 0.053212271868101055, 0.05870701069192541, 0.008813031430866931, 0.006821088393354008, 0.003101881626324969, 0.014404225512407722, 0.020456183176007003, 0.056349712183638934, 0.031078342731381138, 0.08990308390029016, 0.07034748687498993, 0.05152731893524047, 0.02303109662006459, 0.03251555240562847, 0.06264800829212032, 0.05578941845845792, 0.03807986350429635, 0.037553978618234396, 0.05873784956131732, 0.0689957170717178, 0.04680198519640873, 0.011288053712867683, 0.048912040318452546, 0.006256875170830397, 0.0494545339907129, 0.08576890573866906, 0.02819969457754445, 0.08364062921534623, 0.008291752648449714, 0.1045074393492072, 0.07509085049311962, 0.038304143405008706, 0.028144212574848247, 0.09620641703687369, 0.03378008011608355, 0.029010070044727578, 0.012714775643431613, 0.038404259605393294, 0.05113274151940019, 0.009055345041316845, 0.04100680584087968, 0.051790987246579705, 0.03949219638842248, 0.0655925170248074, 0.07425094999733471, 0.02704005196480261, 0.03535708742997339, 0.027651696563548142, 0.09161426385323848, 0.02060937394778575, 0.043939796441625205, 0.04271158895966026, 0.027095422884749792, 0.0376722434415452, 0.039396385602172346, 0.03221294767553768, 0.09221932775671444, 0.03313848530993827, 0.027497611384117798, 0.07251884052229506, 0.02158528760886721, 0.03550772712896428, 0.04902548261828, 0.0328274536126804, 0.06996526262692868, 0.05798243324182207, 0.018635680561044046, 0.04576303207525804, 0.05295860100417368, 0.03736292395079809, 0.030552157155808904, 0.03687058988538, 0.08357927323349061, 0.04356208828187758, 0.05106526832546919, 0.019708322398664973, 0.009562397570980173, 0.01847517173436861, 0.006820469777355152, 0.05444403399803466, 0.007439005815784537, 0.05837002010535329, 0.06832833957648085, 0.07404295712589257, 0.01947169507583303, 0.03345448125694548, 0.03634807961662451, 0.09427547710196627, 0.017467158989259796, 0.01748211685598137, 0.03861924685958413, 0.06355139832462996, 0.02894351615630571, 0.03537916225351153, 0.017242120661502405, 0.07932454347610474, 0.13838871201920894, 0.03107182523836532, 0.04710138001809678, 0.04044487268754071, 0.05577266794599353, 0.07683668826376239, 0.039201082977195906, 0.08750237885021395, 0.033929857966159625, 0.04871468074739941, 0.04674976098261053, 0.02556362816493117, 0.04829328642376969, 0.06025241304849906, 0.1142067559844544, 0.02297717552151411, 0.01039134492466767, 0.009229972868436768, 0.02803344392187653, 0.004781141328895766, 0.06829244835722832, 0.015155154471886496, 0.027601318621647455, 0.016100396845309485, 0.019850824328680194, 0.07586040113481783, 0.022236759203576276, 0.02152180573302171, 0.029235895527827165, 0.04653363225741252, 0.03967342214779027, 0.1519253171019016, 0.00838123842127501, 0.04185231026983069, 0.026832202734846263, 0.04079878232592056, 0.032204061055616025, 0.03500918009048028, 0.0967864528478634, 0.03427314579546933, 0.025722872946531545, 0.011098745725898734, 0.09442351593245422, 0.08926713899258645, 0.037688867549502084, 0.05082707243761228, 0.041779612356256095, 0.024341304238224705, 0.02300541735284271, 0.016601316841138948, 0.11978845727900345, 0.07507740565004849, 0.0012421907412053478, 0.04219857818116585, 0.04139906584074901, 0.09013327033889872, 0.04762896944979026, 0.05459712517838325, 0.05872069302225306, 0.061799680829168334, 0.06459625032279762, 0.0699518790708915, 0.03787128074515251, 0.015110271295622714, 0.008875710829611748, 0.02859962886319526, 0.015317154297184561, 0.0421733700580174, 0.0671896341467096, 0.04720589356316675, 0.053410845688514175, 0.05884996652903576, 0.040132136444651315, 0.09188625570987502, 0.03314577846697742, 0.03130361663117524, 0.05191117112014083, 0.0515429126549392, 0.0637242775560627, 0.051562198918432965, 0.021303374913611242, 0.022432515735647852, 0.043472666668915944, 0.024791034238953746, 0.010918151989068476, 0.022173440121414683, 0.08713576747404952, 0.0143857876912901, 0.05031680042344717, 0.04580577978143289, 0.04287717120361425, 0.03058694137801086, 0.01467218678895264, 0.0332935874710881, 0.05539382980655759, 0.01722419611929405, 0.02671796561879737, 0.021895223800393365, 0.08188303199506576, 0.07459254860277138, 0.00952916180399517, 0.02410748079719563, 0.15016869281328496, 0.04915562946529639, 0.03640402318729508, 0.057123905318158294, 0.02092075613026898, 0.03910579313073428, 0.08590765958351475, 0.02409519274689017, 0.04173369304607472, 0.051716301334841605, 0.018425069584120667, 0.07505328920219215, 0.06384735724197761, 0.047214274565058376, 0.02614860332781269, 0.007845296237182112, 0.041057183782780365, 0.07409243874492184, 0.03296377512836649, 0.04820925806979499, 0.037776576955952955, 0.04221776868366907, 0.0965704313749748, 0.04236545894415148, 0.051158386312665484, 0.058851858766208735, 0.04590367815727669, 0.03502755853978377, 0.04947968465726703, 0.041827577121195295, 0.009523659377479026, 0.03156580830804043, 0.05977302203856169, 0.09678190228559318, 0.019270438032465118, 0.018896941441081224, 0.0801922146591448, 0.1888903005108718, 0.13880246078535435, 0.10749006478656685, 0.16684749944796487, 0.11423201390331793, 0.11271244020111139, 0.11324756027710055, 0.08120254673544439, 0.16589577309787273, 0.14116999422830923, 0.09238480274835903, 0.1309575059361035, 0.1604943169701484, 0.1906053721904755, 0.11562091598827993, 0.13805408481388323, 0.12271415472270981, 0.14392896795705443, 0.12498492359994881, 0.17448302118047593, 0.20068811583182505, 0.11490224124563318, 0.16917147313154515, 0.28865724141078614, 0.15734083860391573, 0.11037363505531704, 0.12565876687726668, 0.20980920462358385, 0.11592702174018468, 0.11721005813489038, 0.16776090608008448, 0.1044099546608425, 0.07429228044084965, 0.15474772291077724, 0.08820920221267209, 0.08405244743992245, 0.21377996090919743, 0.22894058046081375, 0.1453697648380072, 0.21390138584519588, 0.17144071749381481, 0.15406716104236343, 0.12616586345698566, 0.08006341995731478, 0.21204731517261077, 0.12040056153050355, 0.2160314167098653, 0.17865041691449382, 0.07392193821649398, 0.08760259081158908, 0.17370662171273463, 0.21636271909359964, 0.3086723609557075, 0.0699600762116813, 0.2082037907694617, 0.11432022126691957, 0.15932500632780214, 0.10910798885649252, 0.11380451385893169, 0.10078969126146647, 0.09960868245651645, 0.20245267679133724, 0.21031047127419905, 0.1504788971355846, 0.17470451252114388, 0.10084496450520332, 0.17959232201739667, 0.24073923847848372, 0.13131589718884037, 0.11736738195102062, 0.16895873051497245, 0.1593006906970855, 0.1654559773423018, 0.11088911263692765, 0.1390668683715405, 0.20738219211418785, 0.13309579522859666, 0.12839727073667512, 0.19798437704242047, 0.3121365186187529, 0.19329360536029264, 0.15510663510330264, 0.17702467108686126, 0.14237178699864497, 0.12358544950163174, 0.22391185675176883, 0.1277749775157821, 0.1651877852817697, 0.27007933345533186, 0.2082499552277788, 0.15438973002376097, 0.1628291384587365, 0.21337333676074782, 0.18826852822976728, 0.17198727526251348, 0.282036985360807, 0.10560578726712735, 0.06867553828464401, 0.12413708643326837, 0.09645823013758469, 0.16834595210609898, 0.16429880153267615, 0.11097561162445815, 0.08013599146638187, 0.15800232488301494, 0.14854561297162888, 0.17139533444518046, 0.16051428122145517, 0.1813797277188109, 0.16074783078605132, 0.14605806419445624, 0.16579802027873455, 0.31740193285288354, 0.1351987678677805, 0.1646683163820736, 0.16632677416407293, 0.21844166721547806, 0.1684564526282972, 0.12630054171407415, 0.149560694793059, 0.1316859789433018, 0.14605760454170166, 0.11268705970817998, 0.1316605141806987, 0.1132088421934074, 0.14060262951158708, 0.14082830369232163, 0.22741546794291467, 0.12896837396246771, 0.12366022734392075, 0.12659831242936273, 0.16501812745005856, 0.13787095915646325, 0.11586591090646484, 0.11685021131509736, 0.1400290594826783, 0.12022842157391772, 0.12031630718059118, 0.12421784742224602, 0.23685079067945483, 0.12508502064813531, 0.20054237526510993, 0.24750595521782678, 0.17343216305298192, 0.19108814547859854, 0.13583636752540065, 0.1740966830402613, 0.18824045876822165, 0.19945623112782357, 0.1471543206923431, 0.12058020914874731, 0.15464594046915733, 0.22452678020683028, 0.1306008153985585, 0.07695599113621059, 0.13692667918099513, 0.19517177715897563, 0.08426930394864852, 0.11714140133511637, 0.14385217530352457, 0.09916122582170273, 0.2729575257868536, 0.1856227210091968, 0.08961220797632011, 0.16773793876411455, 0.13165522817402117, 0.13452698536697896, 0.10963901802296601, 0.18484627557618005, 0.10569955642905929, 0.16663624304196528, 0.10182590178784826, 0.1202301912370228, 0.2840711939479074, 0.12477807219951384, 0.12223253056647317], [0.028300031028207273, 0.013350361447420814, 0.02437685071791132, 0.01124658728874619, 0.0487729876993164, 0.017642928287386894, 0.018059279837255037, 0.03946726405692678, 0.011421712115406992, 0.03167301082172461, 0.056209399349867344, 0.05020843345611807, 0.07315684620651507, 0.07125036745902992, 0.034926109346410925, 0.012365844618949679, 0.04402091749192726, 0.05442935575340545, 0.016218439503122243, 0.05609241006295047, 0.017082194061649424, 0.02907994683952101, 0.01444736105059424, 0.07893289634657484, 0.02686234446422708, 0.03479245381670133, 0.03930345530651751, 0.06183338869783667, 0.01941482836921369, 0.016788791962749055, 0.042592937261947704, 0.017333518781308687, 0.07205374088258513, 0.03441175791404901, 0.04811950703902591, 0.01905127176864734, 0.009742762439043052, 0.07008146284328354, 0.020603578492638566, 0.06609784394142128, 0.07301474455744028, 0.028232320347019745, 0.041899171868158926, 0.028859185197600917, 0.05408995198987184, 0.01917777012192434, 0.07479395311806472, 0.05793873558662111, 0.012496932796503027, 0.03384464983678153, 0.02812917426889462, 0.03870031428373149, 0.04244069643919507, 0.06591955229880349, 0.005986183269640372, 0.08173564433931343, 0.047969426584219745, 0.008577735185803426, 0.0337056546742397, 0.014294392444313535, 0.0037340255409118632, 0.0304241553549805, 0.019947529522581928, 0.010285164180752492, 0.014105865867027353, 0.06583952675423314, 0.01080080742887672, 0.0982300459497398, 0.03756500645390442, 0.12145566378509808, 0.03021722351531348, 0.03731752174996561, 0.035210695688522635, 0.18493201613666552, 0.011814631908501108, 0.08369265424628412, 0.02405285489775481, 0.05653023314211638, 0.04271751081931495, 0.03516480319141861, 0.06068307703601257, 0.05617029822221207, 0.10800573389015852, 0.08130405338541155, 0.019016002995833274, 0.13023177552367413, 0.015093222966477757, 0.04096550604088172, 0.02154335770155153, 0.055380944207671194, 0.02169751565933468, 0.08002067225113993, 0.08492118348517726, 0.007200588241234543, 0.08024217125268714, 0.04813627670368841, 0.06603038223880915, 0.006299603246002188, 0.03270881723672633, 0.04388005307485019, 0.02109502006562487, 0.033310406931465676, 0.055342758555085435, 0.04992780012769565, 0.031858038292416645, 0.014967454311948632, 0.03916686566005792, 0.04513231188719792, 0.04934046349878754, 0.11149531801141079, 0.024948651083715023, 0.02174973604269326, 0.018189095351244175, 0.04570071465305744, 0.08117125204373753, 0.022892624312531085, 0.03183114094539516, 0.02712538649868821, 0.026168787829397668, 0.03918571142299522, 0.03426570325128494, 0.05359473743385846, 0.07081938171458822, 0.031213647265347744, 0.022157302479289716, 0.003058697489435755, 0.06752822202660384, 0.07134380720315442, 0.021271074731503765, 0.05545679840349382, 0.07801748256409362, 0.005607434187925631, 0.025861023497136853, 0.03860749890126529, 0.00967088328193753, 0.04289521640467067, 0.0484394368475243, 0.06554180200422002, 0.02780369798382444, 0.04433608223353663, 0.04037510122983687, 0.03364296569939583, 0.011272637151001443, 0.046850543679489244, 0.017405783855206063, 0.01850972421497347, 0.045262202094759674, 0.022705089819106846, 0.10433332288577672, 0.04307920391100549, 0.008437811141653408, 0.04656316494689353, 0.05520833310701194, 0.033530511652990695, 0.028323555673142115, 0.05054724350151035, 0.06746363315370775, 0.0974429595554548, 0.022524404151725675, 0.09928244391396161, 0.012808611838056917, 0.032099223838398055, 0.017177790343280763, 0.030825662036095897, 0.0318855389336785, 0.056767846803150834, 0.04353378133307542, 0.014306575157529405, 0.016472933911568215, 0.05311010255207939, 0.04704966908320785, 0.041356004038525206, 0.028804664635249687, 0.057537190601109504, 0.02923886028809413, 0.04587103898126272, 0.06151673008477496, 0.054131856999329986, 0.0750055312809925, 0.05167771731653521, 0.027173019930600163, 0.01116541931555877, 0.029399784717468486, 0.02842931985674847, 0.02568391354514226, 0.01902202827735774, 0.014318158406944526, 0.036707068417942336, 0.03485364892009286, 0.07185383789962338, 0.05222380394116045, 0.015607645261972664, 0.0529968862481896, 0.09006302773712144, 0.04682885956079249, 0.07956497251026093, 0.013100364932700271, 0.04314800626748512, 0.02030304986082258, 0.025503796698044867, 0.053589895758177006, 0.05200096045530612, 0.07092178468742678, 0.026893725340825417, 0.03966085447539245, 0.0268876368570472, 0.031860361454047026, 0.03943423417607143, 0.02305715318558918, 0.012060026150016535, 0.033978427940559004, 0.012480857399021907, 0.02542323489192753, 0.10775205919579153, 0.03710629981792262, 0.04992810656286536, 0.029384129710735816, 0.05875170426142793, 0.04894070732857912, 0.06924527021305216, 0.04973316016877371, 0.06540133212242397, 0.06704928683898143, 0.03881724611405404, 0.026418396512106545, 0.0060461976400185986, 0.029785590426575755, 0.030621987985326882, 0.05591519094342667, 0.02537676208322087, 0.07659469641024068, 0.08001122638703355, 0.08958677385723399, 0.015556743507453752, 0.038332611232274966, 0.1341743091301572, 0.032525365991938504, 0.04083174708930235, 0.03773150034248829, 0.07144922856241465, 0.03528100340777347, 0.0684044657335166, 0.071732857294621, 0.0055554900750247466, 0.03389056531652328, 0.033474698317267244, 0.0628770915641179, 0.011312744726667242, 0.11038764680345213, 0.1301351258711469, 0.05557959846731636, 0.027539941572373914, 0.03326311632389984, 0.053482402131081595, 0.09245486148903448, 0.07727935684904938, 0.048459240220366954, 0.09105346451002745, 0.020543563164650433, 0.04172982813249673, 0.020073223483538436, 0.043425414365746325, 0.006045299880732332, 0.019050961503038005, 0.03355170930585554, 0.03058639554036481, 0.07038600577582275, 0.029733753087179318, 0.09260145241334554, 0.07521379994408739, 0.028158963597830267, 0.033411603315823504, 0.024762821135922305, 0.06752871232287538, 0.03169263416390506, 0.05758215996226477, 0.10873903325127979, 0.022149105338499914, 0.0324725863643952, 0.02226531704617364, 0.06841265521342717, 0.014033635267086569, 0.02785931022146777, 0.04648655615446549, 0.07915003630783289, 0.047108627209860476, 0.0383020481545358, 0.044637223735692046, 0.1497999287300533, 0.0543887569238582, 0.012898426071079749, 0.038550191694089485, 0.02533604259482555, 0.050913805081959695, 0.026729261585240884, 0.0664094195611054, 0.04640606712670096, 0.025143419362364278, 0.02119188230755108, 0.060889553053364645, 0.044721715572860934, 0.016903291463912014, 0.08895868901163341, 0.11225194474982639, 0.05194942572063977, 0.054099516597606485, 0.045717668178821766, 0.02325179314451112, 0.04903937179234721, 0.03577126137491676, 0.08274120368784474, 0.09215736656539864, 0.0636542801024212, 0.0188294644167106, 0.01103348078040947, 0.03452881614887907, 0.02950443041270539, 0.03563981600886872, 0.01551176169736972, 0.054597117517504005, 0.04951287541658648, 0.06459372989352673, 0.017662831251659704, 0.03491541092854834, 0.02302631048575765, 0.0534184567720419, 0.06789720827533353, 0.0961785007929129, 0.06722793854292362, 0.06374795733380222, 0.06627249666639874, 0.05355027752117284, 0.1108171769808377, 0.03214361288795068, 0.014681550298607158, 0.039733303410391656, 0.020124746726885922, 0.04022735734319976, 0.03484924008408862, 0.05400043078548005, 0.017991073114136537, 0.049032595744656945, 0.08848040499874661, 0.020716622426745393, 0.04576662119718329, 0.05972976871435681, 0.035405098160188046, 0.04404758118213185, 0.02896061523877565, 0.04343743811571791, 0.0521912413739389, 0.022678652124839927, 0.212093387700377, 0.12639277870015753, 0.14030238433230308, 0.099172372401001, 0.07038550781867198, 0.1466777527164067, 0.18662539220625357, 0.1700267030466949, 0.15011966318613099, 0.1272768441647772, 0.14385375344464857, 0.14742004594975902, 0.19489836037879993, 0.17059411372869246, 0.10106523776607168, 0.09488455530616546, 0.07801370575062691, 0.19656659344271307, 0.16710718793253745, 0.1721766521973956, 0.11006584390997888, 0.18186098415284388, 0.09671035733434463, 0.153460189579956, 0.09751199939919096, 0.15550375976149114, 0.1299753046083835, 0.16706745861278427, 0.10458102209433433, 0.15662787121630486, 0.16804307158435547, 0.15947044045934755, 0.10929738877401238, 0.09556109521297679, 0.10662498298071085, 0.09982026828032348, 0.13599324701053483, 0.1776243493922295, 0.16238868386755068, 0.13649163317055474, 0.1415502036651296, 0.10470956398714935, 0.14731369762411042, 0.16005216166377068, 0.19514333997522632, 0.09920590406944675, 0.16624268835350392, 0.13600305293596562, 0.10610804217116487, 0.16050864281433244, 0.11581081386295058, 0.11837624313850557, 0.16210356126389197, 0.10991181427192305, 0.21101044581061412, 0.1206106305002205, 0.27093946633319704, 0.11076085419664461, 0.1297722606649322, 0.19154848771229868, 0.22445971686993876, 0.17206958374909817, 0.1897529614788871, 0.15998542008380737, 0.1547475543714339, 0.15778745254201276, 0.13572937568589566, 0.2403791618323134, 0.1842980783793234, 0.17431160134653892, 0.10093088892679061, 0.280595361104896, 0.2011880341676935, 0.2379962300220805, 0.11161540229354175, 0.18381075452893011, 0.12074111059548394, 0.17079545695695186, 0.2816086809241003, 0.20723851998486828, 0.14477483627776946, 0.16916293891206866, 0.1949228905141354, 0.1470100663362011, 0.1687996140530994, 0.165366850673191, 0.12429450217994953, 0.06497771614381383, 0.10759685744321155, 0.1608578256902195, 0.1270235601752516, 0.16545251462488406, 0.20955847936772534, 0.15101472967334334, 0.18538929401866852, 0.10272499023666305, 0.13877305833082046, 0.12692788345438819, 0.20536986299820487, 0.1669179642152402, 0.15552309582069998, 0.1303706212990707, 0.1339666839809187, 0.11256455458820828, 0.16250679930371625, 0.11263697287969052, 0.27930787373935023, 0.10048562330344032, 0.2746839815330121, 0.16248393924005572, 0.1745319129118035, 0.12842598371207714, 0.22814633114443672, 0.3129077240103676, 0.17345437960278604, 0.20627999077400855, 0.09535999713285316, 0.14875087857006059, 0.14003924845207122, 0.1311561831783864, 0.1932323030045917, 0.12019601605472066, 0.1339489260628339, 0.18366902826293824, 0.11331922014153774, 0.10197194112885384, 0.24465157289899167, 0.18443206715728008, 0.1596700063636226, 0.14896663957305495, 0.15405427544347702, 0.12229891208511208, 0.16434171777819434, 0.10052182861874182, 0.2093385661681814, 0.186855448409915, 0.1969540041060217, 0.14961917794519855, 0.09053765751060941, 0.08679176335253062, 0.1568067833901413, 0.13144954888811036, 0.14720419301621376, 0.130256382267802, 0.18200165321750028, 0.15973083374481048, 0.10025124636388595, 0.16215666647880309, 0.16813832695686048, 0.10218113675833711, 0.19589468836784366, 0.15985333120390294, 0.18378456964367823, 0.1336609076468214, 0.26102996581504423, 0.1946374155100315, 0.13358357873174453, 0.21921736188232901, 0.08308058829918023, 0.11323518795712341, 0.13615483027552405, 0.12333349850509437, 0.09537689703246278, 0.2373148101351915, 0.10328107813913977, 0.12907364976502236, 0.2631817535767632, 0.07949057771193405, 0.12143074294492123, 0.14521380465838218, 0.15560351973099096, 0.14567420817911625, 0.08071444147536833, 0.19152467769961204, 0.167226375891797, 0.10995355840291708], [0.04436956027582769, 0.016916291975987055, 0.035910451889879284, 0.027028401682694114, 0.070450947049164, 0.0340138633374966, 0.014432636840689569, 0.07328728799738231, 0.037113420605178804, 0.055382101000436855, 0.02638621507362733, 0.04267298578915577, 0.02423074817465198, 0.07049413908633494, 0.04252505804141683, 0.03534411756141532, 0.020604610796116536, 0.04330497002229095, 0.01988042022041496, 0.01725529737380003, 0.04781650777365412, 0.049555910405732935, 0.009520456172345627, 0.026427855782751596, 0.05266668703106623, 0.016883357856122237, 0.02645664919738568, 0.04167864579827555, 0.027068356998384963, 0.06458425338590337, 0.02147726155066442, 0.023398747960586223, 0.026240579844001802, 0.0888251369037936, 0.028513300330227906, 0.10095237769306668, 0.08006888982509414, 0.04366727981476053, 0.02871573906421902, 0.07890472729359904, 0.02409041810390209, 0.06974289028514778, 0.06492271869172973, 0.060100884687516, 0.03222560727848642, 0.04325755684065723, 0.025140808917762294, 0.0233739382031584, 0.04230533636385395, 0.049483392522820545, 0.10334711491821275, 0.01906605726558595, 0.06971869722849901, 0.044938602725103985, 0.030685776296342095, 0.08071338427403281, 0.046372868706502264, 0.06927771403664543, 0.044057126637668385, 0.044467290112328146, 0.05721992677858761, 0.039676321790583675, 0.043454307371810566, 0.09514077341244107, 0.03777066658761713, 0.05023590536908277, 0.06689011675095366, 0.03907837101348466, 0.059979268229536475, 0.0605550445916672, 0.046149201676129334, 0.029902767405034076, 0.017723266012786378, 0.06429552250812132, 0.07133482865268184, 0.1651931172537227, 0.0365320977664763, 0.022816086383236032, 0.0776094947791388, 0.06789316333109333, 0.06733293089294626, 0.09270311994177681, 0.10319899947893235, 0.05915587692851982, 0.01715715768026008, 0.10314065422261916, 0.13368911500419342, 0.09557650124113407, 0.05517964694468726, 0.0873057317409304, 0.02473968911104866, 0.0520575475398331, 0.10701079252025775, 0.04425768845624501, 0.009615760382955835, 0.07288988754754105, 0.018415667770069935, 0.09032724380132653, 0.05102834288751887, 0.027514653009993416, 0.08485905375451812, 0.06961133766679034, 0.02310085467122976, 0.06562604869325316, 0.03867418302463428, 0.025806401428135655, 0.030382365258711002, 0.07905318747244536, 0.041054046652730436, 0.03925841316700943, 0.05959704781191484, 0.0644061072999912, 0.046479803089412956, 0.02413999165348228, 0.020048388828253074, 0.029877226033638564, 0.005986716658357652, 0.0629846541391265, 0.04203480007427354, 0.01219446787745842, 0.020530648837466876, 0.03468464609355696, 0.037789998816386346, 0.048014733024061694, 0.049488582768507546, 0.019232869080658403, 0.03211028997846429, 0.05649534932848427, 0.04073727312648008, 0.027101285372590347, 0.06408484832894418, 0.011540901989886358, 0.030795229193303856, 0.04487781747875195, 0.0802715507245833, 0.03254395128498155, 0.05319957396075611, 0.02801172532922318, 0.0255129840074768, 0.012728163029908413, 0.01780190685343358, 0.07781178029554506, 0.03296061501567883, 0.044279284474830476, 0.016866199401838165, 0.01252142558505218, 0.02565547827661278, 0.03482084886561479, 0.03538890689190838, 0.02149681594493168, 0.03618461560578116, 0.01657250427430676, 0.07991037857268127, 0.052150623392193556, 0.009440455525632828, 0.06147482890575644, 0.0364383707393802, 0.08985975396729286, 0.04050004250940777, 0.033921507607784965, 0.028525046373326934, 0.06011229939758778, 0.06202889433611305, 0.017506712108790394, 0.051698834530168006, 0.02387474328579922, 0.013585551397784824, 0.06845050761776586, 0.020000182745617726, 0.032428689526333924, 0.052554623689502485, 0.032525511548644116, 0.0232639241467921, 0.02363806808247201, 0.03225340860925856, 0.08940341837343671, 0.05543999809531435, 0.050632267769786625, 0.01703691635010464, 0.015167627340903687, 0.059948184212008794, 0.015294506822923019, 0.04712288410613134, 0.01851684883266928, 0.05968753811753085, 0.043742770118819135, 0.013764187779968545, 0.06540402875191743, 0.027965545549147555, 0.015066942320235316, 0.0726602909966342, 0.06215972300138205, 0.04905432582862916, 0.03192090155226329, 0.010822997165603504, 0.021309911558825164, 0.0377273864503349, 0.02103288458930629, 0.06421831999755194, 0.0245936727526808, 0.0480118716856645, 0.08091022290529744, 0.08421081313562971, 0.06263913316351753, 0.0682693048410358, 0.023091496907234676, 0.053004765462490826, 0.09276128899786742, 0.04564266817103471, 0.027711056886361014, 0.04150808398281375, 0.08094113455304215, 0.02226842927836603, 0.01410697477929775, 0.028822162083440253, 0.06981183053745378, 0.014585230063887374, 0.05470322835589609, 0.06791914137260568, 0.02881469464139833, 0.04643283423877532, 0.042756362968394836, 0.08474355067817435, 0.03845386762893008, 0.025665753430897192, 0.05800273840225512, 0.01572957485839124, 0.03801151697013167, 0.12398743881813942, 0.051636930795446526, 0.010876390621096138, 0.028485248105660565, 0.06036039314142639, 0.05789969191556016, 0.027599068238369884, 0.08003008747172934, 0.03862933240710728, 0.033937327323421355, 0.04240742141020395, 0.054165342702500285, 0.06036915335684054, 0.015763661940582097, 0.029839373629299865, 0.04730205291942243, 0.03574175166807348, 0.04986095129542294, 0.02679439629578302, 0.026558881715661096, 0.028727446802921837, 0.058093730495461536, 0.08802354080422271, 0.0638035255213899, 0.09721399119664585, 0.05851974815971429, 0.07882317723405939, 0.08868651329389504, 0.033107677084063335, 0.04706164303746435, 0.02594254865881897, 0.04040679428726435, 0.05345745830826702, 0.031449202065085696, 0.07676649162726057, 0.01681212891614245, 0.07755015360852403, 0.09874504855683736, 0.021600241645149166, 0.11388333664546091, 0.10125642266845512, 0.09870536520235962, 0.04414821449186533, 0.048637777011120514, 0.030895083008574385, 0.10386737288847085, 0.04936970507485732, 0.06080137633327996, 0.03355624454636728, 0.045003187767560446, 0.03190972624466785, 0.07923204602012712, 0.05923214864226119, 0.07047893990191721, 0.04318415029575268, 0.04335031093608949, 0.0229270791169256, 0.05734049752655049, 0.03414160083799112, 0.02817470670467423, 0.02073963762321059, 0.0871088088399941, 0.01696878240533894, 0.019368079768854286, 0.07228260964996393, 0.039222330425775824, 0.04562288011995055, 0.0676826653521388, 0.05544346847361135, 0.10284420117856034, 0.019112118302033316, 0.0476530667454485, 0.06937896787759758, 0.03184328152377519, 0.009221247126979214, 0.0760916447747619, 0.0675397210063473, 0.02821767083068769, 0.011330561058956289, 0.02449298964723224, 0.01689535670823628, 0.07657622603038627, 0.06360360721666967, 0.010380065237592545, 0.05359708549334638, 0.03477353527541122, 0.07287089622789815, 0.027815890273139365, 0.029381320083273516, 0.06999913903494036, 0.01947825087324506, 0.06571762684372164, 0.047017202276976845, 0.017490156948746696, 0.09744767865706837, 0.0399887056330279, 0.014553412517172196, 0.03641017487332706, 0.007068737327391583, 0.08457694187640183, 0.03668403598449884, 0.0525211954429265, 0.005475521987048729, 0.036226999420191974, 0.014723853673785927, 0.016401810308678016, 0.02855652301091581, 0.021801720854015123, 0.04353565824848991, 0.04900881254504766, 0.11064293794333936, 0.021592337532990405, 0.03122171608641023, 0.024539897210835934, 0.031016364303087036, 0.06140139937821416, 0.0315699375219523, 0.023449424676777377, 0.050232277942761305, 0.020616515802459854, 0.07287529357258352, 0.08210464590980161, 0.018036304860405864, 0.05389906586177888, 0.13141057033452297, 0.1189136844609053, 0.21859903699688374, 0.13508459012354576, 0.1480089837024289, 0.09266850808935781, 0.12266661130612898, 0.1726855950490121, 0.1885904843408254, 0.18502537161111834, 0.06638365602421184, 0.24274807423353198, 0.18903407989250076, 0.1254958506192892, 0.13521257277217605, 0.1513616449289745, 0.1547193316923034, 0.15398332037993018, 0.14629512244174558, 0.07221135581212659, 0.12813513843162408, 0.12957047310567674, 0.20211984223175436, 0.16589417963499026, 0.16939348541200164, 0.30939364805817604, 0.12477319221943618, 0.08604668922001317, 0.15560768724929902, 0.16754315324848698, 0.19028107185036908, 0.18245209759521872, 0.1352252745099606, 0.14736324819105287, 0.10459072076745572, 0.1536486625310875, 0.2131741692221934, 0.1312025927848393, 0.12689900193964282, 0.14426471365074958, 0.08562170960489782, 0.11181173530677635, 0.1802663568166956, 0.09664935375293417, 0.13252547341248683, 0.160104546756033, 0.2359133595300298, 0.14749305412894295, 0.17002471121809176, 0.11970938934433846, 0.1976864607704263, 0.10351289634502704, 0.195758554543699, 0.19421125611951276, 0.18181972265724214, 0.1331658156648759, 0.11381305573928742, 0.21226879119152026, 0.1874541154792232, 0.16052068571650213, 0.15169208929423364, 0.11850905214105883, 0.1406979002058506, 0.2063269979290424, 0.1202638531404157, 0.1217587434897019, 0.15759847397285123, 0.13896422791144541, 0.12749348616888448, 0.1377022512737782, 0.07257755350081191, 0.08127497268780585, 0.07551242101697192, 0.1510817164014424, 0.17911740879137672, 0.37170552378219945, 0.11199967199636084, 0.2719689965728791, 0.2139743174155874, 0.22488805195016248, 0.102583700640788, 0.17651624917503328, 0.09203393447903857, 0.09675391709371921, 0.09651807692622948, 0.1694996651983069, 0.25397261063898763, 0.14702702752284466, 0.11081659475401526, 0.21357222850764954, 0.15685104795040625, 0.17212900152850538, 0.31455165676532254, 0.24900168060295044, 0.2258108048549583, 0.2080374577593419, 0.19537636860003396, 0.18581655657579824, 0.12255715266350778, 0.1519521301792514, 0.18861080099257732, 0.19428034192852436, 0.10490707677578735, 0.20632597137122385, 0.13437945215452102, 0.20149575636511852, 0.22478876695517572, 0.24865764583791458, 0.13838639843367762, 0.1961380285361121, 0.0914874303364946, 0.17068104938633982, 0.14550292624100564, 0.24641521455299473, 0.18172705666192118, 0.1499218286405648, 0.15959162024721024, 0.21618903163940678, 0.09500467023181339, 0.16692154950672583, 0.13830680189834488, 0.15641932676155723, 0.10610310090405327, 0.13433373202719998, 0.2383771749033082, 0.16951811259552357, 0.09415026769162187, 0.20389963301920122, 0.13852127587362645, 0.14476961155812587, 0.14053677659361594, 0.1311576693889595, 0.10749499073191997, 0.24630954038471947, 0.21407364837584958, 0.16359121208229374, 0.11303110213409509, 0.1591680349121171, 0.2021316093422713, 0.15437937251502468, 0.06730140637486212, 0.2262029346198805, 0.1300017193200127, 0.16184807094114442, 0.09795676706539047, 0.08921830854829281, 0.14598501004999684, 0.12424980094956777, 0.11024952115070437, 0.12808946426957846, 0.15941595628617272, 0.09524627138049373, 0.19037395235030882, 0.10445358336813028, 0.11148672250490035, 0.21315584439904461, 0.17059947634416242, 0.15033268159435642, 0.13019629033102145, 0.11872734123420332, 0.12342419565444994, 0.12880790918584795, 0.14862966813868092, 0.05834805636456417, 0.1409584467088984, 0.13103973781389575, 0.07499222433374775, 0.15231810570243867, 0.11556804826062535, 0.11279091824807468, 0.14700268124861104, 0.1084075393455644, 0.25535109392817945, 0.14489927960018958, 0.19480151154341238, 0.1914509647195378], [0.08865193208499302, 0.04966979320611685, 0.006586648251545886, 0.04776842426508666, 0.0665801422550313, 0.011231555686061902, 0.02586074004460487, 0.13227562149686198, 0.03126306951256289, 0.042289095299859206, 0.049131589626232465, 0.06731722609049852, 0.010016514382685625, 0.020021727053268303, 0.06274694854754113, 0.0019315145008506314, 0.007122934696399757, 0.02512316016720668, 0.01280235194210564, 0.013486161065708487, 0.0938947543862366, 0.029863235352921392, 0.02328628433808204, 0.038262284360826015, 0.025729074428278594, 0.0684610030223285, 0.025708451341356964, 0.025275132859185822, 0.03838074070611789, 0.04313423200660656, 0.022831431124359373, 0.04257060962939455, 0.04786474449980644, 0.011951961787417533, 0.10177482670593647, 0.053687460885773745, 0.01646627852272603, 0.04041259740329078, 0.014040859476212534, 0.04990338873598845, 0.07674880265708893, 0.053459411832473935, 0.046729934627130154, 0.06786570673988712, 0.07629339402962117, 0.009382352544625681, 0.01671210656152858, 0.05121094760515037, 0.026884001769846486, 0.10060500278468094, 0.010770748053947765, 0.008507192852125775, 0.03870913195573995, 0.05186819358758869, 0.04747305906588032, 0.06260821768533319, 0.021944038922928517, 0.032421752600179564, 0.02082286350008461, 0.04874409469325216, 0.020394522674201478, 0.047111028895503095, 0.06866305871235748, 0.024432254196595282, 0.11827706539582823, 0.026859038794833808, 0.019215314175873514, 0.013246382248678036, 0.04920982635549961, 0.04932773494792562, 0.05094680048885846, 0.02322529224799045, 0.03615143250734095, 0.019313453869413466, 0.069136033735929, 0.1228896884488002, 0.0623749285906313, 0.05673447601316918, 0.14106070412503136, 0.024827061438812845, 0.010379890952589772, 0.054368478576502496, 0.017662507579511693, 0.003352169972664166, 0.04092611763025484, 0.13022272036440913, 0.05439069129586701, 0.10839027172375111, 0.01882280328220898, 0.07068959875933586, 0.051899289096435236, 0.05823128924314534, 0.07072898333952313, 0.04700326713763418, 0.12426570493487582, 0.05181387029287796, 0.07813703058467758, 0.03659503571989556, 0.08921405676031306, 0.0688910541395026, 0.01263271805064212, 0.04307777898746633, 0.01622315477429619, 0.026580818643372868, 0.04303674731824187, 0.0828138058404288, 0.023522350501509446, 0.0457624536788752, 0.03681008809155995, 0.05753940076477105, 0.0322840751088675, 0.04040676364374738, 0.04552804609580387, 0.05071456093461283, 0.03372797081547399, 0.03437245760353343, 0.053266767532594746, 0.03943145327690629, 0.046274035703390844, 0.028782545761655898, 0.020930803373395916, 0.006246247616100816, 0.02372317470520014, 0.06014285864488733, 0.012335842700615045, 0.0424909939418637, 0.08488362985512904, 0.11445169727648459, 0.03984413335039731, 0.00806386064317438, 0.060694671776746555, 0.033855099276068716, 0.04695364379233891, 0.029174095214975458, 0.00850480265780202, 0.053198175850294294, 0.03316397688561871, 0.05592274840079969, 0.051048460356410474, 0.055672873502537135, 0.03607937044674351, 0.01117518406376363, 0.20490045028348125, 0.011388643930155424, 0.053262094396256635, 0.03618885973288167, 0.0674526704355113, 0.043074369896203286, 0.05827545804241973, 0.018488566781724655, 0.06167555926367641, 0.05085330711857927, 0.01660845295015362, 0.026404308155179027, 0.051615625890272285, 0.007092104445496995, 0.05198881796170628, 0.04600228516445045, 0.03862527214110859, 0.07297695344013554, 0.01344528069884907, 0.02564166379611819, 0.029209072874378295, 0.016844861937927145, 0.09194203457164188, 0.08292700299212048, 0.017470709806788835, 0.05347634620604016, 0.034572988778593085, 0.011249562582722115, 0.08528070088716284, 0.037158861110407504, 0.061341357237148675, 0.006430403661778978, 0.024905968495013735, 0.02680354338559893, 0.020761971001423175, 0.03436581179079029, 0.048316261400618864, 0.10341060062449786, 0.01853679584699773, 0.019081024708406582, 0.07996903792504342, 0.017553520080963933, 0.051517765818824696, 0.04186478984211722, 0.02639131530398323, 0.049925846603488734, 0.03835939749654743, 0.05875677576348667, 0.08502487348572862, 0.03629592435073949, 0.02035650173051944, 0.01682242322262497, 0.029262042108682856, 0.07335723182486911, 0.05400163354352117, 0.00644708426872028, 0.053589784675427986, 0.07198423372521516, 0.11270092589960945, 0.06007483386765084, 0.03071862040087581, 0.05199956617528393, 0.030357770005901976, 0.034617743635129546, 0.03571323021465252, 0.03899718867614865, 0.04101137938578764, 0.0319123845697651, 0.08066757987704008, 0.01734529355270488, 0.04007545742957343, 0.03191635098999306, 0.04131081634231153, 0.07745082264826184, 0.06446562467082854, 0.028110284455901677, 0.05594497261148307, 0.03829536020695683, 0.0379507968412532, 0.03399330536804853, 0.04854668915692357, 0.018161814960260547, 0.047434980665603955, 0.038638441192526976, 0.05603539779962552, 0.04623480434078844, 0.025503143608089418, 0.02765179998541792, 0.010036538963416412, 0.10718839468374368, 0.010472713995935216, 0.06948798985010193, 0.062049674471059156, 0.02702964274513145, 0.011519139347177361, 0.027397470285875664, 0.07170231336907995, 0.008762351841846061, 0.06741245081948657, 0.02062967336255937, 0.038782201421957825, 0.027623653915079854, 0.07456115431963437, 0.05057011505648975, 0.026728070318518628, 0.1053184200258505, 0.03420903572752591, 0.06240926082095793, 0.1154838168933507, 0.03759977152390826, 0.05410724642476248, 0.11329226150748231, 0.06689329601583943, 0.07079518865793943, 0.06443232282876007, 0.06428285907473295, 0.04080661557494633, 0.09596259423321295, 0.03466023087141014, 0.07350356994016517, 0.04707316116940591, 0.1078940689143154, 0.10972104305701871, 0.11560163355522579, 0.05011649141388555, 0.05740180754313066, 0.09744925679819239, 0.031193474255081628, 0.046684360056514704, 0.09633279856174223, 0.01730107112727579, 0.03447474566318336, 0.0190804731251011, 0.0601531970014255, 0.02751332384744479, 0.06651294102231342, 0.05896437026920819, 0.0214846849426507, 0.020563787885851437, 0.07504958899751787, 0.08108407123795441, 0.0775741474823125, 0.04921083759155966, 0.0731963686825287, 0.040839346681511214, 0.01702244303399517, 0.05689852991171422, 0.0554550402317076, 0.05396736260022848, 0.0560285221605051, 0.04129040009912945, 0.041967909107165, 0.03627349329631656, 0.05287726544925282, 0.027097508559123646, 0.03187136630707931, 0.1069300315312801, 0.03044870464251407, 0.08884081106272437, 0.011981065467660947, 0.06191981490701438, 0.02512346085671696, 0.017223529622799928, 0.059807917343512665, 0.045360809101933436, 0.026980931044466076, 0.04926254852644859, 0.04102525323809635, 0.051049624810055386, 0.0520202850231961, 0.03726253195876076, 0.04119849636129314, 0.05524716610389371, 0.04514851464679645, 0.009191252869523821, 0.05463285168873207, 0.0487639325400514, 0.0360346079293278, 0.037309715314017194, 0.043612052536299156, 0.017078313826312943, 0.024633846403430068, 0.05905311772479646, 0.08010761556966652, 0.05428960982469782, 0.023095850201864398, 0.05833701320713567, 0.006779097199004385, 0.12424289849737, 0.036525509410327485, 0.05045076238832647, 0.0033396319861734108, 0.08832662050882656, 0.04374152139550255, 0.026123266884936925, 0.02304958423689729, 0.052771342302402185, 0.043209396723297336, 0.10915919417335142, 0.07607434650943165, 0.009019300604479448, 0.08919397759581767, 0.05648481178908579, 0.04175842619471012, 0.07882474771430416, 0.027253304029844945, 0.051312929229630586, 0.038393553526651476, 0.01326261565179354, 0.038576985619241194, 0.20613372926750492, 0.12923613701376224, 0.18817912576900375, 0.22163076867018977, 0.15125394828857916, 0.1681265904898605, 0.13388072891581443, 0.16443070655147876, 0.1830015052109957, 0.2150181428559365, 0.12483745933540406, 0.21034758057325117, 0.10220217353273785, 0.1353736197756183, 0.1832085787769287, 0.10582778422582535, 0.08237472254662745, 0.07041040567621108, 0.17994292981682286, 0.1350175727519297, 0.14963613913184212, 0.11150805805359157, 0.1884834925013204, 0.1980373750050222, 0.1857329150962253, 0.16636512452556243, 0.13649310405936935, 0.20081505660087834, 0.077864280300996, 0.16757404191359399, 0.10468556245248165, 0.07195454015727006, 0.1401595855432172, 0.07568148896098137, 0.20251016402917527, 0.1895021136489607, 0.08790381658341616, 0.09240819907356655, 0.12548670352947328, 0.3559363393052932, 0.1927333805830248, 0.17995691858232024, 0.19003590839284082, 0.17618578948801564, 0.22421127455609463, 0.1835035226277767, 0.1256979675963521, 0.174634155006178, 0.11865939689619888, 0.18069806268378613, 0.2589695876644504, 0.09716998710627518, 0.10213352439384307, 0.24120659807757025, 0.14651843707167334, 0.29336071483069853, 0.22037717303441418, 0.20574107856279422, 0.13294518234268313, 0.18167957453237427, 0.1418703824522034, 0.29105365636848635, 0.25346015910467795, 0.13430109668162563, 0.17976387974716004, 0.104697689624323, 0.11722349531708226, 0.11487248639065413, 0.13150424756590398, 0.2808188442741671, 0.12160813060378838, 0.2247333175112163, 0.1140251165376075, 0.20324844296180433, 0.23826800737409826, 0.29708626169350844, 0.24406646558594322, 0.14581803352602069, 0.15476145120638032, 0.09954841431951332, 0.20076834055925571, 0.18409724076909406, 0.14437084747177942, 0.21295522129343403, 0.3291777461286514, 0.21872061515046706, 0.1466068589398938, 0.27723756708925773, 0.199615485485523, 0.24401188948221747, 0.14277914659150187, 0.16884777034001966, 0.2242947781398412, 0.10592234245831929, 0.21947038540196037, 0.2170028774848869, 0.20434499057310246, 0.10373601179209449, 0.12142008666189448, 0.13110768981277943, 0.1264758149702703, 0.1433098616619264, 0.1457091877537389, 0.09066631431661307, 0.1604290616007582, 0.15306724776183406, 0.35472248831102926, 0.14151439671554875, 0.1928710312612595, 0.20789323404671686, 0.17055962445034137, 0.12096949672747044, 0.2014812006945572, 0.1517915887938392, 0.14863432595326057, 0.12774228854405303, 0.11694200397018464, 0.22008474195195785, 0.1577402308823601, 0.1803076489558143, 0.12415055425897722, 0.0755313893539771, 0.15273019971866764, 0.17730746478323015, 0.16529353605883737, 0.11829949645025116, 0.30301535321820167, 0.23871828321247335, 0.09763582219039241, 0.09311941978071006, 0.1074284176913, 0.08188407387464278, 0.1729623060072622, 0.11463585715260237, 0.1030167241791083, 0.12152479555938514, 0.15793949035146546, 0.19227809452962494, 0.11368930189599914, 0.26285880155140356, 0.1343116686949807, 0.11860362569531126, 0.31519327072366593, 0.10546330257409042, 0.1727758861717678, 0.12376295207368752, 0.2180724588012503, 0.10194306727498771, 0.12096726741161078, 0.12354953529974147, 0.16049503709279722, 0.2099354252699883, 0.10404626974054884, 0.10880327738460996, 0.16228541521535766, 0.08616239914009649, 0.1545754603801235, 0.0896683162558944, 0.21369657989951873, 0.2176890777604234, 0.15093609840879518, 0.14280543872906318, 0.13346492703403198, 0.1699192821979523, 0.1886894016136085, 0.1794942167978133, 0.19029182772482597, 0.19554958107971376, 0.15576324906320343, 0.11063966674790268, 0.1490681768665391, 0.22262622331899984, 0.13430114264690107, 0.142290826826807, 0.13411483006371608, 0.3272224139542349], [0.05974062034980424, 0.026493344808958715, 0.009108072957925258, 0.038566356149291804, 0.022393763177998127, 0.028393758055303368, 0.03943847830317194, 0.03309420159747524, 0.024538995142305092, 0.007826675033767619, 0.03156876157698853, 0.07632320251075492, 0.0021574199443773158, 0.006555993243255803, 0.03173986731487657, 0.012253903851453817, 0.03041046536377361, 0.029152200422099525, 0.04390125838859428, 0.0022212831883676233, 0.03228702454737598, 0.058956322515563625, 0.04202588664127454, 0.05005617731160695, 0.017800397660222747, 0.05411290398408329, 0.022119614783854737, 0.05515480271330284, 0.04617336408926114, 0.05900400765841046, 0.02985426829376769, 0.037814551934359536, 0.03815590539166043, 0.036404904188408006, 0.08273161226703275, 0.0621407967992127, 0.05186371197323165, 0.019094613192963506, 0.03197060916723023, 0.015016917736389706, 0.08545406658442752, 0.019201871248022206, 0.08598945479119018, 0.06910612566336509, 0.04552324655495825, 0.06256765332974254, 0.03540592170470665, 0.03477171964703068, 0.047627847130981185, 0.14113738952625182, 0.04440890272117911, 0.03822282317184633, 0.025963292404588674, 0.04079006041490263, 0.013361592296390765, 0.08564617845319933, 0.05670375588740553, 0.03688088227664271, 0.019872249892702507, 0.010338336428356989, 0.05877882760438708, 0.08545426576728783, 0.053495766534920663, 0.006963795251888975, 0.08115863457562462, 0.0504962795023476, 0.03166281802189206, 0.03882801731026942, 0.025680958360974348, 0.06985927436260447, 0.022805320932680083, 0.05288718245743264, 0.015219348809501577, 0.040993843633200855, 0.07147773469407713, 0.1368422716134979, 0.05282487652655091, 0.03327568016585804, 0.20340141539852466, 0.071197584001047, 0.2826154736741897, 0.17651617256624086, 0.07416596786389429, 0.1101279506580003, 0.013159515538943872, 0.11718928949126314, 0.07585858550643729, 0.10046213504768188, 0.04947146836427912, 0.10797769507212986, 0.020865272212352966, 0.08589244507733854, 0.16424181991286818, 0.052890216165612784, 0.197515347371659, 0.09582788533260746, 0.061103862319742484, 0.025872279243964343, 0.037136556460492076, 0.029051911851931966, 0.03663114910464614, 0.038020813447092815, 0.12110296456563859, 0.03554464107559573, 0.01791673194196436, 0.07405785753601983, 0.016868352108905395, 0.04825047360012128, 0.03595870393779009, 0.009086330425024275, 0.06000154989681417, 0.027431442454877882, 0.09418265788906044, 0.07181671327881275, 0.10778612712578428, 0.04437507610888251, 0.018924013073105487, 0.030780223446087013, 0.013886311771197906, 0.0282374129164964, 0.022623836618637847, 0.021801450808021813, 0.018655231124871684, 0.04802639671270886, 0.056179828355990113, 0.027970222515925288, 0.023466144545724796, 0.023771710205642928, 0.009601311964703905, 0.027199497844483105, 0.02263471889760225, 0.025217586249533682, 0.04642222392102403, 0.05699308048332891, 0.04612785846655888, 0.09330603879906478, 0.07087939704257636, 0.049264900416376135, 0.06328849227077539, 0.037895224823225895, 0.023506436940102328, 0.05980790202175418, 0.011887581673480812, 0.06423892010183585, 0.01944670720296281, 0.06905434578056298, 0.01981238586707942, 0.042773266698444085, 0.016430573079795126, 0.12600580470696573, 0.025974299172840776, 0.056861512543212984, 0.09732348048278401, 0.049632377471894994, 0.08684834660661798, 0.07736662192450416, 0.011933680056714484, 0.03411831559553262, 0.07280416230881408, 0.05465923958728391, 0.06351301731962351, 0.02074682544316015, 0.013208847770827913, 0.04134229872555983, 0.03392368712792954, 0.09178776744632952, 0.03272372530773282, 0.06121804389441687, 0.009009007255606835, 0.05991063058196057, 0.04432107074066036, 0.026949816383421425, 0.021889650510744225, 0.03402910848718978, 0.0831010198641208, 0.016719355668512084, 0.034674414989328196, 0.05167859448720852, 0.017963216241989887, 0.05120937712490559, 0.02768217920205526, 0.04890095885662783, 0.03850847054573317, 0.05417356665636744, 0.007531787203099098, 0.060798924851922266, 0.024974090948460564, 0.06050216920313336, 0.01930764500772761, 0.04384247263172462, 0.055359095380070715, 0.03808335686523107, 0.02114650308935633, 0.015033687401052206, 0.019201026636085684, 0.019383100837829615, 0.06298160127874824, 0.04810995392261013, 0.05132407197848924, 0.10509338935897236, 0.01196082925514108, 0.05494545769667434, 0.017485388051418048, 0.055324491188530965, 0.012918854763190593, 0.06669984349320013, 0.034587728310256236, 0.04517944161629966, 0.022875515653962092, 0.02096056014359478, 0.05485325901498718, 0.04430920020827363, 0.06237194850860585, 0.07040529586975613, 0.023244819829180356, 0.02118233685201455, 0.06606743025082736, 0.009058489832246016, 0.05551666434433672, 0.03855116462575332, 0.02808228202704941, 0.03448530618521956, 0.0543763003342094, 0.05098680943070401, 0.021431252225151947, 0.11985252521211102, 0.04867599330722325, 0.0233865556712713, 0.017192087459167647, 0.05940567138755034, 0.026831222142303185, 0.08836800457849618, 0.09322055104759433, 0.04414588941501514, 0.03951975257105885, 0.03955990323917039, 0.024984331628788384, 0.08489220237900173, 0.08263048100014848, 0.056299989246913505, 0.07760050090690775, 0.04555465615985375, 0.009854889940470457, 0.07655569487401555, 0.04055426238224872, 0.04046945644903087, 0.06662031590578056, 0.06169961442449882, 0.04414395887344595, 0.00662512789037259, 0.07849922929439815, 0.04311290794923421, 0.06530507317473812, 0.17297929783742275, 0.11213302492134034, 0.0731563865537605, 0.2242038435032291, 0.140561735738189, 0.023045828490848505, 0.09158368928418045, 0.058724734136053634, 0.1683225251373745, 0.07709563364304843, 0.08819817054656245, 0.09011660026566637, 0.08324706686600562, 0.03927419840868923, 0.06511712116339514, 0.15396516409612473, 0.08766917917396753, 0.08798869912542644, 0.033436685034464446, 0.062423015929638385, 0.07145368719413396, 0.06804768326542071, 0.0535330175602388, 0.03453622804954648, 0.03513284200321763, 0.09494755837705829, 0.027318369792473894, 0.018567431703089707, 0.09939924167889742, 0.050916582150685216, 0.08837739681644786, 0.052188111904768214, 0.06879393717334156, 0.06905598520872093, 0.013971486384229315, 0.04931950333317922, 0.06852676400974875, 0.10385703070149307, 0.02726673163593777, 0.11120658713362871, 0.028463801474220334, 0.08869821911737805, 0.05093367357227591, 0.036584766311270576, 0.040334337691385905, 0.02493675948391038, 0.025048108448484735, 0.04934911646189229, 0.06844290036467776, 0.03426879824649903, 0.0509308084034391, 0.044145356983907764, 0.06250155909407525, 0.0383189786976624, 0.008248375792567047, 0.01804060835932051, 0.04319987808083815, 0.014903246567794874, 0.13534787922136246, 0.11389698067139234, 0.035791715922495054, 0.07433070741113156, 0.010684140856497952, 0.037076104462387106, 0.037501991891692725, 0.02176510951211376, 0.09576846755320027, 0.04845444834040058, 0.045890689136520516, 0.03598378948687065, 0.0355950688132115, 0.01662958357032509, 0.08942309151133222, 0.03404399357555855, 0.010254056222977178, 0.04192674720299341, 0.08164130827231754, 0.040555105078965425, 0.05770295287572569, 0.013426133288791584, 0.07556986228953447, 0.04058867888224702, 0.057564179878681905, 0.04543944802736083, 0.03131278287318926, 0.012258556877983915, 0.018645848463019057, 0.04154935313929473, 0.01035602444091872, 0.09945616201167146, 0.04769095745418341, 0.07719966072228647, 0.015143671771511437, 0.07884900205798688, 0.03506241937077815, 0.053438045640265754, 0.02454089887079693, 0.05187743260795551, 0.06663387566204033, 0.12351916757442298, 0.15346182900811398, 0.18273217934033564, 0.16724900612908025, 0.10966331833192419, 0.17742433915695838, 0.09808405257400968, 0.15299001077730812, 0.12830714815326277, 0.16038107385318126, 0.15105528636805474, 0.20458082307971295, 0.09723419293520913, 0.1358227005168315, 0.14754900919093242, 0.0828577256611278, 0.22039595751031754, 0.08875726917458159, 0.1756102429522622, 0.13478455944888054, 0.173856882198203, 0.17229628448765125, 0.12735596572559688, 0.17250024773661168, 0.09566534445771287, 0.13424428360116097, 0.18917847214446915, 0.12390998732899466, 0.13656998864345013, 0.180772174029581, 0.10069079697132112, 0.17705248007851263, 0.17014771429521425, 0.10162166274723508, 0.14220589831952127, 0.10974974837154151, 0.12474178261454068, 0.15617240130180315, 0.0867194369915993, 0.10324411439679324, 0.1210884165559565, 0.12591405035627465, 0.1764379703109303, 0.1801688185021762, 0.10609625973888945, 0.12223197898316769, 0.1081612573996667, 0.10450335610057078, 0.1250979062470217, 0.20759430653866262, 0.16755867418983292, 0.06187683737446224, 0.15574071075647108, 0.11939858747345787, 0.1993624926094086, 0.19594909593222604, 0.2457813074391696, 0.14189903414057148, 0.17498188231500889, 0.10704584870367281, 0.2623201191665665, 0.24287637863909048, 0.1804936704255881, 0.13013731688261032, 0.19384417742971452, 0.14745219099906184, 0.1683533831589645, 0.14743499998604098, 0.11643670003620848, 0.1937592489224288, 0.14790907051534424, 0.09889595255616213, 0.11428760124310372, 0.08873473086784925, 0.15322573603160922, 0.4472166041453039, 0.17517795485834922, 0.3141120755143704, 0.3526819365159158, 0.2837755759396861, 0.451762845679637, 0.3532139692575701, 0.13894953434505772, 0.3112245062666555, 0.128933486318396, 0.5824284567948311, 0.2837126341558272, 0.20281215588892662, 0.17390019680944183, 0.1731511773241143, 0.11696654942727859, 0.26931989517423416, 0.3576027644017051, 0.1710644610706837, 0.3548398223375121, 0.2097673915446766, 0.15238852450443854, 0.19323185867359563, 0.14495771678705371, 0.13683101012101098, 0.2182799920199379, 0.18233346121926464, 0.1992810421412991, 0.14022841088233456, 0.13371408947052496, 0.2594102414384965, 0.18551309382723224, 0.1641755686291764, 0.17430570246952196, 0.15855562422544728, 0.1505435243128769, 0.06072302086038455, 0.28741142922832125, 0.26770433831599455, 0.17155051321512269, 0.19845331478263104, 0.1506090861174368, 0.07637456870607792, 0.10894012367052418, 0.13848431979215917, 0.1047666835027837, 0.11882802050921226, 0.1453610314356704, 0.10563307531899023, 0.12044780617279392, 0.26959225475307436, 0.0828360683555084, 0.15170070012250256, 0.11904158283986392, 0.1034148294298399, 0.1308501923396703, 0.11913204250196296, 0.14560564330989315, 0.13501467693957592, 0.11012461817552967, 0.2252727966274946, 0.17325423147168853, 0.15519081284442257, 0.112231329323784, 0.11323290501510906, 0.0834190919094028, 0.21296674325581522, 0.13129093804426734, 0.2145476576181189, 0.2000064507968003, 0.12189196617973429, 0.13255155104542934, 0.1155015518287978, 0.15861059869489363, 0.1972931359083422, 0.1488746017698319, 0.2177245323095591, 0.2653119376590175, 0.12958588679471325, 0.15613829506741417, 0.23950189922846135, 0.17310417016908047, 0.20598878543223106, 0.15878915846828492, 0.12509797519493487, 0.14350532133492733, 0.09820313328095982, 0.15050180316452058, 0.13389160736433922, 0.2030652560173504, 0.2624848587138038, 0.18616927877789546, 0.2216859116789795, 0.1839086452438947, 0.2484193465281879, 0.25476410203883726, 0.11440188623964788, 0.13047548341414622, 0.1256035779032015, 0.29970554695014034, 0.21993769903577146], [0.027426426494193655, 0.052199499801762646, 0.012550340616144242, 0.06334880254261437, 0.04961470382348184, 0.03606113372370601, 0.07176081950385725, 0.10155363413955897, 0.04223036316914424, 0.05657991011356635, 0.024848860470698248, 0.012546411542702588, 0.025846238000198238, 0.07722494162378774, 0.04275623273344771, 0.039664956876226974, 0.03490700311357937, 0.05983612087044505, 0.07678243391696485, 0.0221714923428672, 0.04551700676881498, 0.03887554157465216, 0.04906320095723195, 0.020227785552701643, 0.021505122253250693, 0.013677185089627822, 0.050187293259847554, 0.04287198861880649, 0.04921584780658445, 0.02393838412488901, 0.04559849937176032, 0.05986653073059936, 0.03227795023591288, 0.0708416059252716, 0.022712597480764794, 0.04514856061207191, 0.03994760501589026, 0.04231688513931248, 0.06449908739136112, 0.05330082780170826, 0.022676346200187842, 0.023307020422972502, 0.023586152219063333, 0.05678327581394584, 0.04492674751447574, 0.011695883492188109, 0.05864319173739322, 0.10153827407667715, 0.015269648227390024, 0.002982518185050257, 0.05827433572361066, 0.05557155454411142, 0.0625948494510545, 0.028677396363608783, 0.031044366731939298, 0.010667782006484848, 0.04101534389079579, 0.021520949629766327, 0.08010753896087408, 0.02877692459151149, 0.05674127887393679, 0.13855096944157155, 0.025858273241488684, 0.011186259779928914, 0.0852768627866622, 0.0257419791793631, 0.03014443367118797, 0.039764548306383436, 0.019531497814422174, 0.11218735587693031, 0.10682228126473005, 0.029184261201730663, 0.1483886568777023, 0.04023861500524706, 0.12519438736020558, 0.12027630973006449, 0.028733228851530342, 0.10068105233292426, 0.13753205718052003, 0.03729875259582074, 0.07630044203852454, 0.07769176496132728, 0.05870950430811894, 0.038650560703489094, 0.047237958173237504, 0.16667894478286469, 0.04765815356926573, 0.03415914425145715, 0.09229566841836899, 0.1095057340458997, 0.06336047389214078, 0.072455010076444, 0.08703463620716527, 0.10691733745437478, 0.09799383039916716, 0.07704015355557203, 0.03868114676386599, 0.054567485236592835, 0.03796793039767973, 0.0810121585645022, 0.04919866445444284, 0.09687379453211062, 0.06255492860932024, 0.01415080171183593, 0.04630633780071813, 0.035508891582609184, 0.030620748838109356, 0.05935617061632295, 0.06362057606419248, 0.08557620398219555, 0.17078047227715293, 0.011544757327365299, 0.033876136050469456, 0.0524845764401459, 0.05176608938904059, 0.04050858822020312, 0.04170240984568673, 0.10764180382172908, 0.083713821255632, 0.048764928454352964, 0.07063480049011207, 0.017934970580221667, 0.024201862829466982, 0.042455462783935576, 0.08269122411166469, 0.04831810001163714, 0.036185148036888534, 0.012355512008070947, 0.08079938530441254, 0.055179872940624916, 0.02676615254923461, 0.00990294280552095, 0.043299664863415306, 0.03579165080502149, 0.035923931206907, 0.031241973366348014, 0.07036260178973598, 0.02376510652773563, 0.015402093338179252, 0.0476718052560764, 0.04545403817187875, 0.0267710899859066, 0.11182730987427697, 0.07704373884705767, 0.06400306844302724, 0.051787244907069596, 0.05756092017456409, 0.045651708008541216, 0.039462740307733904, 0.005511930794455112, 0.01034201269278363, 0.04028473349828874, 0.06067759950735396, 0.06555772897216582, 0.07356267362352341, 0.03971404395997524, 0.06320852418279936, 0.019629865419119596, 0.04529383386515322, 0.01311762106319469, 0.03912660390919736, 0.01973593220745604, 0.021898232610715974, 0.037895496784439014, 0.01969102987899415, 0.0534788053482771, 0.00228820048974857, 0.01950118563047821, 0.06345161920293205, 0.00929128192740703, 0.06406424822466028, 0.01322486858454443, 0.053202113542225093, 0.03371213960851874, 0.044097687162819414, 0.04209827045880018, 0.008089651950755188, 0.027711985767969204, 0.04405778547328326, 0.03832840924001029, 0.0072446550550540134, 0.06508138316172747, 0.0033147159340460937, 0.05385600788999469, 0.01912819657234415, 0.03714784859649597, 0.02858940733506555, 0.018850005149180372, 0.019862493762986797, 0.08551710795971655, 0.03160255371532854, 0.1055241299552783, 0.01672565482646948, 0.029393667505393108, 0.018203086031961347, 0.02504637325933624, 0.12013584750914767, 0.06776370213276918, 0.028884544623114412, 0.013977192781655299, 0.01879151625138137, 0.01836539325003903, 0.04023379248176371, 0.07557941540595024, 0.028924806373974973, 0.09145451153838828, 0.017675023540974628, 0.03359400502015506, 0.03398264908502179, 0.05363521368933782, 0.017888942102511084, 0.06296334540351264, 0.027611015379549037, 0.07433449954635675, 0.01411309390659294, 0.04734910603973174, 0.025803752679137454, 0.023503083390213793, 0.03965422015396818, 0.06484084687526188, 0.06283487245861082, 0.019353767331208915, 0.043454506554670876, 0.059419158365457296, 0.0039128002977269075, 0.01101796558472298, 0.033691351812693386, 0.06854528801575785, 0.1153238500738817, 0.031545646789093176, 0.059298185421334165, 0.007236421525087809, 0.018843591078034332, 0.06881888099615613, 0.016028496620786047, 0.010926580871455373, 0.008045259070762945, 0.06955103122539098, 0.08089133883796393, 0.030282630187068737, 0.10822050663973055, 0.12936528411603745, 0.026970885716558948, 0.04462964712612091, 0.06595789499941372, 0.07854609089272638, 0.10255364701151849, 0.24708073045457565, 0.07064873562945474, 0.01964213623244676, 0.08495938062908188, 0.17513568212668743, 0.06888613585502872, 0.1495128755848254, 0.1334093243724877, 0.06427024160662005, 0.14377847764520876, 0.07279671593419007, 0.05620114858292284, 0.022919770638127963, 0.02394217242967458, 0.0680078620151166, 0.13580615301766705, 0.09923182082392516, 0.08293800401471316, 0.10525245219469072, 0.07191895537318722, 0.07099197366304937, 0.08127445940889659, 0.07314088093417306, 0.08784945498430922, 0.09704996411117817, 0.041523133780086235, 0.02788839091907346, 0.03973334171478787, 0.0630508364749051, 0.01895119961831839, 0.07745927259806665, 0.02486389303099244, 0.010893508855764185, 0.024177891938316248, 0.0695608065073048, 0.044358789079612305, 0.054295566158309105, 0.03660196881561029, 0.07626421374058531, 0.0669335232927434, 0.06205797503371874, 0.0945224485269958, 0.09232118680712678, 0.026214536685015888, 0.023052529844966148, 0.022292120547424403, 0.06787430990727679, 0.023766539112154036, 0.02078762920122714, 0.040469854814751495, 0.01854681627704732, 0.022358174563475677, 0.039709106523303256, 0.020407766419192477, 0.03585292251720544, 0.022653430595152804, 0.06325149788491188, 0.01150474263986032, 0.031572821842987216, 0.03458258019940507, 0.0076740894714490545, 0.10848721248968955, 0.027867137724834106, 0.03891213759479504, 0.042369549853667136, 0.035621104311318166, 0.01232134831708766, 0.04976517881356901, 0.04588244603045526, 0.035031584331825856, 0.04565706296313194, 0.05629372264769289, 0.06428378604112134, 0.04508322097301003, 0.02272873320766995, 0.03449008657386707, 0.05772412371551318, 0.01843280515693609, 0.04613826577101023, 0.06169104573106574, 0.05348980254043014, 0.04483214331670635, 0.03329005963619679, 0.05340258343025081, 0.02484790669123252, 0.018415169812919154, 0.034264534967200416, 0.005534409250568358, 0.0831472302877134, 0.011669391214156584, 0.02027193903021755, 0.07287252799517686, 0.05002006009641675, 0.05951662390162388, 0.02100586275299711, 0.028231621291788838, 0.02431965459348454, 0.016264410524238503, 0.008421602636395444, 0.03629316643421208, 0.09481745366487773, 0.047340529685419415, 0.044830523040746494, 0.04597818403835258, 0.06509548684041347, 0.12584445892923302, 0.15345858079531502, 0.1449852040217769, 0.13391944699950759, 0.13507006509650138, 0.17716788356342625, 0.15653054740640426, 0.16845174884844213, 0.14313595970311474, 0.16142554280738677, 0.12251353927797849, 0.1147617330594409, 0.11376316809365827, 0.1491350256988118, 0.1571139846477778, 0.23603326761193816, 0.08519577237987712, 0.08226396155453498, 0.11451001188928082, 0.09324491264358645, 0.21306179944545994, 0.1271602455827017, 0.11536888072207091, 0.12612699215570766, 0.10662895897703786, 0.1167101014946257, 0.11101546351827922, 0.14820199189407213, 0.1653395166560527, 0.13004169378790165, 0.11634099267182813, 0.15975111975304543, 0.12981018201718408, 0.19869509213153394, 0.10770490648405207, 0.22153857764938187, 0.0788790710090149, 0.20397034293461233, 0.17629213781366426, 0.19907139451994052, 0.10559180616250924, 0.08585943434868129, 0.16062256008867296, 0.16585996614829188, 0.1726185317121206, 0.11435718500926612, 0.18142235285091787, 0.25554342796244933, 0.12053035214663514, 0.11783941468644528, 0.1527471609053112, 0.18364963091669545, 0.15547022043216616, 0.1474799080601623, 0.2162967589233191, 0.11596206260184128, 0.1712214018428518, 0.18531657695289583, 0.14506332966829502, 0.1315601413408595, 0.1164248180125029, 0.16967080924059116, 0.15891671210767763, 0.12324379727004037, 0.20209820790877267, 0.21211693724316938, 0.09229053562927632, 0.20611483753929216, 0.1342749424398907, 0.22003361324389137, 0.22134192287921908, 0.36982110070605434, 0.2216978320070813, 0.13604805294063785, 0.2050618956526441, 0.35328156885600864, 0.1354865871009327, 0.15525878016506472, 0.32841211785712554, 0.12916032495277543, 0.149951460921476, 0.1357336964217886, 0.13243686768316454, 0.13612095386751238, 0.13810493773029697, 0.2102134232559512, 0.20722937289505236, 0.23146395150932575, 0.14920375910737824, 0.2642148691079309, 0.13356695462378765, 0.20297363190160644, 0.2909270986433952, 0.25116462260484695, 0.23431059634012563, 0.25140603223154623, 0.17374678004172542, 0.22033175934226285, 0.1549036218033683, 0.2115400730361862, 0.14311541322498553, 0.26171536935913947, 0.14809150669363239, 0.08681912801318592, 0.14665996415480492, 0.19774571001049013, 0.2830775472665987, 0.1522374672875289, 0.17288719874716577, 0.20310846337627983, 0.2469494076625955, 0.16707203981857147, 0.21794061506948165, 0.2239031693147075, 0.13377701593262534, 0.21874491545942523, 0.09118144715865774, 0.20600684978548559, 0.16064483792551104, 0.18871440672345702, 0.216099904970296, 0.23626917672734107, 0.06824004028232829, 0.1516471046113199, 0.12316001023376182, 0.1234221118952959, 0.08635893899707064, 0.1585206599725831, 0.13239451834271032, 0.13023194406301747, 0.08466230705380441, 0.10277238043565905, 0.15470050125112458, 0.20504153303561673, 0.12422841943560109, 0.2589346846986202, 0.12609627202994403, 0.08652626792149198, 0.1280209377047516, 0.17752434427459396, 0.23145727122262602, 0.10862205162524216, 0.13985405435725567, 0.2835140028788198, 0.1358679456696395, 0.1275017445967082, 0.2360896516831652, 0.143490765664366, 0.06953581671921477, 0.12853882846332368, 0.22252082494237732, 0.16244405670271767, 0.1313290892228965, 0.13679242993314422, 0.11664717503252531, 0.07864609601036196, 0.13873792553861297, 0.10188580220264774, 0.16768662619494623, 0.10565559064308483, 0.12353455061994253, 0.07106106713294022, 0.128923894897584, 0.1154759951356438, 0.10407751080610099, 0.1305384251980051, 0.1027430392681591, 0.22377854213118556, 0.22512155554948315, 0.08517822130553185, 0.10739516181450699, 0.16974321987119415, 0.22226643778624075, 0.17078857748739182, 0.13559232255624187, 0.17675139220251193], [0.06616977959751122, 0.023630660012244217, 0.020005018675639745, 0.025764561536151077, 0.019159667464273594, 0.040850772882901856, 0.07576687712102168, 0.06813966744248906, 0.030919923409519177, 0.08768298407836307, 0.06870423593828756, 0.031317086372103904, 0.06339704309920631, 0.03365378286088667, 0.0414279856598906, 0.04242552789829431, 0.09414123551499459, 0.009679279605587645, 0.007258653396650428, 0.008007771515798184, 0.04931056308710287, 0.07255537525540398, 0.01984967136635415, 0.009755916168702947, 0.05519483846822574, 0.04999200978706922, 0.03870111484561236, 0.025419247404281652, 0.03426504058523044, 0.07991102208653766, 0.07339786512837296, 0.04127690546034325, 0.05943674391375915, 0.05846334876672876, 0.010792875546030702, 0.03694135342694579, 0.07437230598541998, 0.015185458037341315, 0.017227342825443033, 0.07913044743960904, 0.004026025698910798, 0.020630232606744094, 0.09492926419742646, 0.004407396237741435, 0.019853655023560412, 0.04349168863207583, 0.07549189752148044, 0.020670496272824464, 0.04632408422748408, 0.10129064381603273, 0.06923344947638051, 0.05532781984056196, 0.030214930997200073, 0.06550880659732126, 0.13044991139923373, 0.038207367347973975, 0.1295527151875919, 0.05927426815633813, 0.05726252509761722, 0.038484989950853976, 0.046544706058358, 0.10315770733981364, 0.04764878814439139, 0.05704656108132294, 0.13762391112264127, 0.025019994936883453, 0.035955720025325016, 0.08029552161573403, 0.01376653679706637, 0.07646746452777617, 0.07965466608443568, 0.11458997614681722, 0.07072807935577247, 0.11341320380808846, 0.34945030185964804, 0.5822193454350195, 0.1886572412425472, 0.32675764373233246, 0.1723026430174228, 0.026102055825533408, 0.04020301106896612, 0.3650272595545938, 0.4140947927390376, 0.32619677544120823, 0.3512598934673494, 0.1054927739765375, 0.06388940397770175, 0.08726385737498922, 0.027325557612423456, 0.08541655125877551, 0.086437608566015, 0.153773213105817, 0.3033565687796762, 0.12891644852296, 0.3441297292949692, 0.4630129387782466, 0.3486058891059891, 0.10986819322551451, 0.053059310922699596, 0.11001790978855665, 0.058105037953223915, 0.08419318545249202, 0.026414416685339906, 0.004057346724890052, 0.07333687686872098, 0.10961074171768082, 0.0592105487932361, 0.04538561885936126, 0.03966867623309936, 0.05989681418624617, 0.07613568716952879, 0.025114558915036823, 0.08249463062853583, 0.08554198283461795, 0.030567402305502086, 0.033545396741359465, 0.06266147611782917, 0.09213863571564998, 0.057975806581277045, 0.030267406104793473, 0.10668582568365721, 0.010931305718728372, 0.016094628203239654, 0.020330349404004314, 0.03848862886849431, 0.035561023865856474, 0.02792661679127524, 0.06588104105884991, 0.032113103436366204, 0.031632017456896366, 0.06548589290750605, 0.03468391064914965, 0.024269274736364043, 0.04194845813476751, 0.013637398313280317, 0.025276373921623154, 0.025123951152988502, 0.06932553324487901, 0.04298227846682553, 0.06961088567491501, 0.05381109215499413, 0.024055903927693446, 0.021223822428334146, 0.044360685147224896, 0.03795813213312819, 0.022172386750518795, 0.03466229547836608, 0.03829883441569344, 0.009514405992963623, 0.031694449792285605, 0.01707491431114895, 0.08155706158328442, 0.040052271778545076, 0.051988446409063, 0.02742094130465581, 0.0627151558986835, 0.03392490520772915, 0.022071466157813708, 0.04436988969363513, 0.05871156508463526, 0.02276601296128525, 0.015446069657862669, 0.0434719963419822, 0.034942178040622704, 0.02709462423808873, 0.016500440298489506, 0.0595122074047404, 0.05607059570930659, 0.06104552472430853, 0.020761971001423175, 0.013486106481943882, 0.04891519277026096, 0.05096877572096644, 0.092647279792976, 0.016976330286612915, 0.02185634483823613, 0.04747051565397171, 0.01022456375311219, 0.03061870912901096, 0.020879944711322748, 0.028499035773077802, 0.016746729905266437, 0.05429499925324514, 0.07243998709224886, 0.04258754017252115, 0.02629719948726556, 0.053489882979662194, 0.0535312632188922, 0.0039076842668075715, 0.030380400243185224, 0.00812075416287107, 0.0476302832905804, 0.13614438083623687, 0.01647278069398336, 0.038741912858019915, 0.022075488119416183, 0.02461927158067063, 0.04350299992027783, 0.03595506118971013, 0.021073048663956505, 0.0396018197399474, 0.0137143537604941, 0.06247896333074859, 0.04407060978513572, 0.04571414417437008, 0.05870788786259871, 0.07991011044190777, 0.014441843302319608, 0.01614029087396639, 0.12979021776587735, 0.04720775898726237, 0.033720876841295155, 0.06047016971053616, 0.009692221703458457, 0.038374830337782065, 0.01605737238987199, 0.06061359286128033, 0.019923355618131258, 0.014721876209331377, 0.026263279029198235, 0.015245591151347805, 0.0425021788255582, 0.04558835636764284, 0.0472920248284936, 0.01776773933201067, 0.03029012444218801, 0.041877307718799966, 0.029796737005874038, 0.012636807044937968, 0.0113814628134752, 0.053753604917156125, 0.06557860486810246, 0.14951281429779145, 0.02957930018554532, 0.04460891678688988, 0.026877279348310926, 0.04613591005064307, 0.10185700495757403, 0.0924699534211428, 0.09219296667123995, 0.10445354506373407, 0.09453809970328886, 0.031599320824288075, 0.007626717467041267, 0.023077914168337182, 0.05080907703227094, 0.13245248055506137, 0.15600164030348102, 0.0487345262550779, 0.016478154800772186, 0.32698189298952784, 0.5445937031219082, 0.24463969853616532, 0.2671388734973246, 0.12264048770791101, 0.04873051578479429, 0.05192352045748023, 0.3236397578110618, 0.5594805075276283, 0.4933444128161477, 0.41729333239697647, 0.27918162244942885, 0.0028880552347419004, 0.024770018531970923, 0.05017857517926924, 0.047255708430443084, 0.18796063749299896, 0.04826771057841759, 0.2097792199422275, 0.08945594902240461, 0.34458242597118505, 0.241928743198514, 0.1894949430659894, 0.04709959503323321, 0.013462061854830433, 0.059356473221053044, 0.17620406834588898, 0.022705664385050055, 0.029881878102558757, 0.08630207995133055, 0.10317188762729207, 0.1359593859242816, 0.08829305053598459, 0.02843787322842306, 0.05887464222107684, 0.053477296155066266, 0.10087259729663212, 0.06140532940926571, 0.08775740952020691, 0.07716461986062989, 0.04655829262769511, 0.0977828114804241, 0.028760988047466646, 0.11216297129830045, 0.02727277223922072, 0.05207400310844664, 0.08348292235525386, 0.029026322600041187, 0.030879288190795533, 0.014252236541060191, 0.05994456827700619, 0.024533015826056083, 0.009186530895080538, 0.07152763000058551, 0.013957274495624008, 0.047998112746544426, 0.09980083262968449, 0.02958801060524439, 0.02813016060709713, 0.030799877431784427, 0.05111800581817666, 0.10740293760693843, 0.03262166707446018, 0.03874081352184858, 0.03081621425676971, 0.06694164382474077, 0.07130295173415253, 0.045428370395975734, 0.025034757451184338, 0.05905900894093418, 0.04216554063943125, 0.06735375316272821, 0.035407327476047704, 0.05925585140263843, 0.050674303014191895, 0.038351311438506654, 0.027286653752408685, 0.11084578270393033, 0.015271565362420535, 0.030887655786148487, 0.06760941968569834, 0.08342568792643086, 0.14452637864216683, 0.05041787040329749, 0.055803223362853455, 0.06377387791872025, 0.008514892035764794, 0.06277319088938736, 0.05053841433818302, 0.05343967740754447, 0.04271444646761783, 0.05226279781650632, 0.04023030678170823, 0.07078791082265877, 0.060495347190167637, 0.022042393121087266, 0.007132602247199225, 0.02245042495609772, 0.06026763138511489, 0.051727436422821016, 0.13283557048247707, 0.03118798331988435, 0.22690425747104231, 0.242504243768992, 0.1471132277360847, 0.10324146373257523, 0.15501199260113702, 0.1127945724874735, 0.143745229429295, 0.1422507910718841, 0.08931591581072539, 0.19746703786715386, 0.23008326188691203, 0.14171857446912797, 0.12566996708271966, 0.1359873174900009, 0.20412850944745928, 0.18383076474551233, 0.21181584936716866, 0.09449899857563358, 0.10178935173298083, 0.14839242603028976, 0.19586229817040507, 0.19134902906033302, 0.18152061128808608, 0.12565643030909762, 0.10671075418471329, 0.1307151770038951, 0.19268916198803535, 0.14723048515377507, 0.21099700862842224, 0.154216670761666, 0.2080505578628471, 0.13149756727920425, 0.10125973982916725, 0.12857344031574267, 0.18184247546859328, 0.1452202857622216, 0.16093673274642037, 0.17194799027375637, 0.1620643528839273, 0.19798083771621028, 0.11146596152215235, 0.1704304313827907, 0.1095728510089459, 0.06497417681760366, 0.0842705373502066, 0.17251676459225918, 0.1674272901108188, 0.18292106597894625, 0.17614428284427813, 0.23709647507677156, 0.19976798294773027, 0.12085701203754834, 0.06079217178686973, 0.23240217939019206, 0.22389108044726236, 0.1494329266490475, 0.39626544461615626, 0.16351109460717247, 0.23659946787501537, 0.12879555984850855, 0.10183365459764197, 0.22157774006407108, 0.2867225936103252, 0.19393007120778485, 0.2840452082455158, 0.19496307948664313, 0.1814207287445184, 0.21546972104378287, 0.1652281427936208, 0.18976500438105678, 0.15530989355137273, 0.22557040646431908, 0.19838045982103195, 0.29348926438439277, 0.7535144602579456, 0.8208594110704238, 0.33075487601660913, 0.38378458530191456, 0.25015691054924843, 0.28003357350826263, 0.14076107181608677, 0.5658862283152919, 1.315121198854139, 1.220361515879631, 1.12680220075192, 0.56381632003092, 0.1606665948225606, 0.1331259024840209, 0.3126695319529503, 0.14873995415626035, 0.22062661126255992, 0.24116869204707686, 0.48198602552856173, 0.162567212997425, 0.6475814155513241, 0.562387474121586, 0.6201234147433312, 0.24097055106634097, 0.33668917693918754, 0.21848864372699492, 0.2978517673909664, 0.22891232713816628, 0.12849023550628655, 0.1011851535088593, 0.13472786894248379, 0.2584641534955271, 0.31247739710154077, 0.2243853756977666, 0.11769450915556763, 0.18211071349440083, 0.18092523839685226, 0.11766639372874653, 0.22921025873191897, 0.39630626178076195, 0.1978149337153281, 0.2322181191055044, 0.14255278293163548, 0.28815358456584717, 0.09574771423133151, 0.16811421050900416, 0.20143954083323481, 0.16099536911614482, 0.13619244519260623, 0.12785553166102018, 0.1448101682528373, 0.12795828703430392, 0.19908979595188173, 0.1737935420486235, 0.11124745792438907, 0.14249655207799328, 0.17242072781007137, 0.1051702816039324, 0.12209827365774302, 0.22398187718804807, 0.10782934214559295, 0.180683292508606, 0.2367526548163545, 0.15636386199583932, 0.14555909580761386, 0.15088245693233707, 0.21640447088547293, 0.24255808442831042, 0.0889412375287183, 0.16360409768118014, 0.0996140067675902, 0.12304465271412365, 0.2280763107081575, 0.1635283315854688, 0.24623003577993763, 0.19388396803650165, 0.1107229481661512, 0.2706550638521871, 0.1613425754851872, 0.11357023651080747, 0.16037686036959772, 0.1509950871789648, 0.18386068813983472, 0.16447014475782074, 0.17142064599019868, 0.1632684132745189, 0.1300252382192881, 0.1122309156363049, 0.11464523406879557, 0.11008636740547036, 0.15361559817627554, 0.16999550794641818, 0.2359914851765479, 0.21332084441617613, 0.15183473486573468, 0.20372775353250966, 0.08741293808505421, 0.18975749671939882, 0.09102331895020702, 0.30927665111037994, 0.1345579506408784, 0.16215001683562033], [0.025344839199416103, 0.0181949520934253, 0.004943741575604486, 0.03309837294622295, 0.03840974862537077, 0.0219462912214259, 0.05140170732873583, 0.02176227498679392, 0.039251916741411534, 0.049596359848134944, 0.04629785337695672, 0.04215069385545869, 0.02419660555108661, 0.03340566613441033, 0.03670204671159868, 0.10668223273129233, 0.049217402965070746, 0.02865833226561306, 0.047929000124455466, 0.04726628427423778, 0.06291952900468342, 0.04556783287215137, 0.025807717184145606, 0.03674001785956564, 0.02265729933917042, 0.012254084839725928, 0.052070800860923146, 0.059432407856107726, 0.026759552701766935, 0.041944834538885666, 0.04358271902967845, 0.06486571408928403, 0.0341424741782248, 0.05371781711977336, 0.044142081958031466, 0.06375529645611683, 0.09719889926453752, 0.05542769472325041, 0.04823093069717289, 0.03955973469982705, 0.029664048662168846, 0.04431861925930266, 0.06192307078069257, 0.08439627536121877, 0.053018286914354375, 0.05978305779036976, 0.04168249155965544, 0.03257751742738389, 0.04962057588742145, 0.014297016295454195, 0.007202683012902497, 0.0355203484275168, 0.037337677523253426, 0.018020601973177928, 0.04904252807459524, 0.011536642541027358, 0.07960273298404871, 0.07226933334623614, 0.11684301008860912, 0.05283078306444711, 0.07423633303973945, 0.07376540347092575, 0.07418760218687596, 0.06676856924088732, 0.058359593648703835, 0.05133541007976859, 0.09204269852489234, 0.16012121682926533, 0.24815725252753307, 0.17766443111242788, 0.09795196369410523, 0.054070263530217835, 0.29748101147913164, 4.061443690330752, 10.122687220573425, 17.858457257670743, 21.918286892675585, 39.66807096235214, 52.52136030504781, 70.01812796438895, 66.19285998805877, 84.42575454711914, 99.09596027866488, 94.32518928281723, 87.96057101218932, 87.50579572493031, 67.92286842100083, 65.74811812370055, 77.39162691177862, 57.283741351096864, 59.82137364725913, 57.32298466467089, 44.24943070257864, 45.06485223770142, 43.26379399145804, 21.7979387698635, 14.139424716272663, 4.241577559901822, 0.3048492144913443, 0.09622544666091282, 0.3018500109113032, 0.5670383019793419, 0.16204717719266493, 0.03840978692976698, 0.11486451907624161, 0.1665605382332879, 0.08173163003859021, 0.04043519699705705, 0.08376242953442758, 0.02797825494781137, 0.0966412868470915, 0.03014838860009707, 0.1539433459120412, 0.08585241698329488, 0.027554493412495624, 0.08911890864011743, 0.06982440970117046, 0.05246810171933425, 0.03437940602100665, 0.11209434514204342, 0.08789141361992206, 0.003830966067447838, 0.0356233106445401, 0.009479111364682116, 0.03037627102927335, 0.052652717417766975, 0.03405157784600893, 0.11427266252858025, 0.08193333332817401, 0.021014291635384003, 0.01689237854143064, 0.005137703546713437, 0.04079514723871985, 0.08112484243728461, 0.010677553457959045, 0.03546707850370196, 0.012153195848147716, 0.00694385877126948, 0.038436067576009425, 0.02868088397888407, 0.015697305319800733, 0.025483217661178885, 0.006016439912209829, 0.020378105409984148, 0.018509932973932837, 0.02185577793317216, 0.06421117622765803, 0.07145737207704975, 0.06044986455010311, 0.02054319735766659, 0.050673429673958215, 0.06571318353376081, 0.05271774679121952, 0.054514364699923226, 0.0662291054463675, 0.0022240265013439764, 0.014871070874975094, 0.09122217239271249, 0.06012511987900061, 0.04538348913493176, 0.04995467832251903, 0.05932438562834456, 0.06663952173004228, 0.09793356226216401, 0.04078257956632203, 0.032332832774808334, 0.029100031749675834, 0.06581095933553673, 0.08197965866495525, 0.047557887981735894, 0.010883847529429102, 0.004839638845183917, 0.07944121100609342, 0.06069117075493259, 0.06110807580332603, 0.014987047010612105, 0.06820016540586948, 0.06743921793156094, 0.051665287539963765, 0.016293037314749053, 0.012008655166644002, 0.05959101103907151, 0.02285754323125847, 0.016906120243572423, 0.012755754644111281, 0.011389000161040214, 0.017051255600827358, 0.06451181211178342, 0.06465421253514868, 0.055091385954930905, 0.042776154849918625, 0.06105867079308918, 0.027810895379873055, 0.060995311491311564, 0.0380697243306185, 0.05205005136949401, 0.015078776463445638, 0.0880842992374974, 0.05683071197821729, 0.07436795460601008, 0.0554971520849053, 0.012565698763806255, 0.05348930841371898, 0.01735141651043969, 0.04621338452242556, 0.02275319822553185, 0.016540184940001177, 0.05200623114022517, 0.01841363763707059, 0.02668573246938327, 0.036309051267322034, 0.029339139282162634, 0.10479752620261525, 0.011965166270402412, 0.05044083771926742, 0.052222137699925134, 0.08551241184074072, 0.026000518532049273, 0.11221955455238782, 0.03957758071802316, 0.020830055150473793, 0.0773270917876113, 0.037789887733637326, 0.0287604249728423, 0.06688404933459337, 0.04443791064043199, 0.02810505207537884, 0.028950815059004292, 0.06223271968924712, 0.011865837225360016, 0.0344114514788793, 0.06257829812145041, 0.056485229307004524, 0.026241462760334535, 0.057962062963915456, 0.029722035772377448, 0.06471589793481174, 0.1372640183375728, 0.07179566118265353, 0.07710118778049946, 0.06939897809417979, 0.0566716606338178, 0.10139153759566047, 0.15891655889009276, 0.26673168244381107, 0.3892628494049273, 0.029824802636980053, 0.07185607487636228, 0.34557567428677316, 5.781426054816093, 13.901826162492076, 22.641346416165753, 28.119862041165753, 48.39599178683374, 67.22512583578786, 86.87440395355226, 84.80803658885341, 105.60311748135476, 120.4211965683968, 114.18968000719624, 113.92248030631774, 109.16852843376898, 89.00863616697251, 86.25400266339703, 100.83736711932768, 79.3939733505249, 78.27207349961805, 77.04293604820006, 60.24412278206118, 60.8272340989882, 56.61412608238959, 32.89358069819789, 21.47908929855593, 7.445583285823946, 0.9270062249514365, 0.12168503050962765, 0.2255401613130685, 0.4606830508958909, 0.10332003371008944, 0.03029528404435804, 0.032729402019251744, 0.09225319650384689, 0.09015372488647701, 0.07177821736061765, 0.05393697955315152, 0.08808191670405288, 0.034256763005208586, 0.042949819321473764, 0.17194897086629946, 0.21676877633698527, 0.011782464834170477, 0.10793346115538191, 0.0771591806363675, 0.05062538446978696, 0.035206524339774926, 0.014726955372269356, 0.038658003247673475, 0.024532828134514635, 0.06475248629407537, 0.04004228199201246, 0.03805467836378563, 0.014497776339281232, 0.056151398833120064, 0.10390655062491856, 0.02774467473969825, 0.04907633936513336, 0.032282259480486956, 0.030271807279918465, 0.042092528629807696, 0.021117724996480732, 0.03188704046601009, 0.09476624834801882, 0.0440919223511892, 0.0077740189379021055, 0.04392076681758608, 0.03142430037710696, 0.05540756193260032, 0.01733751392983381, 0.012536122024269595, 0.06253922380687249, 0.030900922513777213, 0.0865208823233843, 0.06893761696354037, 0.07951503889935632, 0.06636273416299975, 0.054543740341379765, 0.05522951926855792, 0.019336585894287116, 0.1158286790333448, 0.04294523428524694, 0.04094942585535107, 0.028051389531502803, 0.04411383246582362, 0.03357505966578761, 0.03827926853010732, 0.019942743388274987, 0.04330300500676517, 0.09340837282399017, 0.01859019217532008, 0.07478658335223314, 0.015894019461777664, 0.04748311780032612, 0.04068012679776838, 0.040074208706256845, 0.03683198671487551, 0.016715917848951874, 0.020782860303898493, 0.05737510171809024, 0.015802433650429933, 0.10973858647048475, 0.026023089397518386, 0.04309412347333085, 0.11973113091962954, 0.17805470694457332, 0.12978470193282252, 0.08751480479634578, 0.14612469852211016, 0.10679968167096378, 0.11694054074224927, 0.19702731872037535, 0.08486735048673807, 0.12605773014647345, 0.17596059028179417, 0.10698429353895689, 0.1588474117940472, 0.10710558057912897, 0.13438637758935654, 0.18651040240881905, 0.11618001461629907, 0.13954470805343122, 0.10043518407450569, 0.19655065881388803, 0.19650222673531503, 0.2692971883281585, 0.09372257612525456, 0.131982286430655, 0.08784315008069239, 0.10107167290463563, 0.20463958202350527, 0.15539401000545872, 0.21300388319838434, 0.11491985360701239, 0.06848423080819269, 0.1315117858710789, 0.07403191779890368, 0.13116781239307698, 0.09437997915571737, 0.13997670503393297, 0.2195279645703493, 0.2229460956709039, 0.16061704425561815, 0.13258208731009116, 0.2133120497268054, 0.12706244679828807, 0.19544039822874532, 0.1503047959939126, 0.09159528785535405, 0.15326972480022139, 0.138805509815293, 0.0811543521441279, 0.15455902013326847, 0.09853151686970266, 0.07850887434136483, 0.12951623408063767, 0.18675944227124416, 0.1439169403766432, 0.08523072897186203, 0.10840530236882549, 0.18559675062856368, 0.16038092063559642, 0.21540481807483783, 0.28651942709280603, 0.2402444835752249, 0.3814061887321934, 0.24758849353078874, 0.24280931530219896, 0.14540526535241835, 0.08777456222883157, 0.17862348126307612, 0.2652275147697618, 0.4092508800808461, 0.4616679335313459, 0.12569478833146636, 0.15147775321477844, 0.9267422616962464, 8.293699737518065, 20.77118581341159, 30.284247475285685, 36.33912794051632, 62.78802694812898, 84.938047470585, 107.71742405429964, 105.11651608251758, 128.42665995320968, 139.68398001886183, 136.13117556418143, 132.05650760281472, 129.67760578278575, 106.53528444228634, 105.12876172219555, 119.68620715602752, 98.11770546820857, 92.7176215571742, 89.43440944917741, 70.86808989124914, 73.17539276615267, 64.93442243145358, 38.58080171769665, 25.831759168255715, 8.84652643434463, 0.9004793580501311, 0.18696043309905838, 0.8209540382508309, 0.8243937730308503, 0.34290601108824054, 0.20169755924613247, 0.17079462958199365, 0.2647498129836975, 0.2434920835038347, 0.11642782873804532, 0.16482776992263334, 0.317499348593335, 0.37802437019924967, 0.33194359932695666, 0.4297344470697065, 0.33089595876874467, 0.11511068610895066, 0.27914307290507906, 0.22169691270157216, 0.1447635288200071, 0.11074357125307284, 0.1702918920425638, 0.18629016745234692, 0.1758577812823557, 0.18292799141378174, 0.15960331074893475, 0.11147026693628681, 0.16547365865159422, 0.13699035640926133, 0.25465594574568734, 0.12057919791268727, 0.1505994334095909, 0.1751607332018114, 0.12933559054809232, 0.12063657789821587, 0.11169176593783403, 0.08951082390042082, 0.2259796812769867, 0.11692498915738637, 0.12265181048743187, 0.1023783814162016, 0.07510568961621293, 0.14788241065557928, 0.15217987279738152, 0.1136022053598877, 0.1445719608736615, 0.09883260474570336, 0.15553601206310336, 0.15457377498669012, 0.19103588296040414, 0.25367553706371015, 0.09664779859444789, 0.1778655291925515, 0.12596822809427977, 0.22379611618816855, 0.2124182396237889, 0.23974163878348567, 0.1374231807647213, 0.1378425679379894, 0.14202514753466652, 0.11146917909143433, 0.11711487171029854, 0.1245892851523334, 0.2179889092522283, 0.12950377749098888, 0.18979474391427734, 0.1202563378178785, 0.16537285680251737, 0.11922634026456265, 0.10058519175095905, 0.10519317231110989, 0.18281615789859526, 0.07638980619489186, 0.11029133422961158, 0.14138194011344066, 0.1508131106534312, 0.1450451274192141, 0.14214078084595744], [0.06005201593882615, 0.0531446454565852, 0.07189120000769054, 0.009578907723358322, 0.03916193588426517, 0.053631659041369156, 0.01792888592688307, 0.056952209692568555, 0.019968610347038316, 0.027624596203226718, 0.014717121676151312, 0.02930406011610983, 0.0373544242052782, 0.05093318327600437, 0.02515109747858538, 0.027083219104116003, 0.03732946123026552, 0.06000965510705306, 0.07387244127570622, 0.022781430480761394, 0.013880339158218236, 0.04935711825026139, 0.06880632481507717, 0.05866779465108149, 0.05141195375472308, 0.016463895989281517, 0.050266813186387864, 0.0519695125460144, 0.02724938165967263, 0.06568640876080721, 0.0372326506992742, 0.042187324349558165, 0.009685328827359745, 0.08089058807179814, 0.05557264621940352, 0.040791715164819074, 0.06751264745910322, 0.03147708383508988, 0.05319621466520814, 0.04380532119783663, 0.04612167613700994, 0.02634573498770835, 0.02839856908746785, 0.05084125272509071, 0.0060068393941037366, 0.03317785456836705, 0.004673705637199624, 0.049593529153254726, 0.048560555348353046, 0.04487021405610346, 0.08135439302291601, 0.08124313407367276, 0.03812198684881291, 0.04232430853129875, 0.0364678114983103, 0.02890920307817719, 0.0858810916543007, 0.02073655220409555, 0.08407060372372789, 0.10555585365622275, 0.15390009258783635, 0.14175591359455741, 0.06279295978827343, 0.3248599520133388, 0.7222964386305502, 0.20543228384227524, 0.582602144249024, 2.572207744083097, 5.478395502413473, 20.61308683887605, 48.88967698620212, 52.437802053266964, 72.29806054023005, 101.99423097795056, 110.23859024047853, 112.98639881995418, 120.16643078096452, 108.49371602458339, 102.47164618584418, 99.4514839110836, 113.10217149796026, 105.68663258706371, 111.83299449182327, 98.71715345690328, 105.98266955344909, 105.92138644187682, 116.62498551030313, 114.74954343611195, 119.5398792143791, 118.66100941934894, 128.26739603473294, 120.5547611175045, 131.58810600157707, 137.93909011348603, 133.14618910512618, 137.42519686298988, 133.5709974842687, 124.67354789856942, 76.22653392053421, 40.64130906135806, 20.067267456362327, 8.562709612231101, 2.129648678725766, 0.32738053450180643, 0.08279292228361292, 0.3420765830143806, 0.26938911887907213, 0.17463256154329548, 0.024853062462962927, 0.1394747795477029, 0.117151107669117, 0.011728681631446367, 0.1362547741061257, 0.12270630232148594, 0.03519144006854585, 0.08966635507080825, 0.054641481669199084, 0.00688670909092311, 0.08475355578646546, 0.005877673618435379, 0.03090742085459492, 0.04469376868538318, 0.06738160045877581, 0.014837498029303408, 0.05161345786144657, 0.03938614300662472, 0.028050500869510636, 0.018862772004438505, 0.025742216666619626, 0.036808031145483255, 0.04425311491133706, 0.04840136993856681, 0.08176182922456535, 0.020343187122395443, 0.036102307119196465, 0.0691344402730465, 0.07611759983363652, 0.02273208675755849, 0.06660088025514158, 0.0521658264070509, 0.04459427301621726, 0.06477772123030116, 0.04808992455382982, 0.03111969998797342, 0.0333819825262312, 0.05417981410338994, 0.01556023303794885, 0.0568409507433253, 0.03856926345296445, 0.02641926219146098, 0.02761670741282644, 0.014793468083465293, 0.02428581265942945, 0.03588121797468874, 0.055718034385673465, 0.07165866167915445, 0.012246256378749687, 0.012506188096238241, 0.03629647976448459, 0.03632015188134486, 0.021228476412474148, 0.01960351199452435, 0.005809323253831076, 0.038027911251711274, 0.05389173440034351, 0.046913857015991406, 0.006662878309256368, 0.048079919445538716, 0.08745635994860242, 0.019232083840536016, 0.0497017658856367, 0.008984783555441087, 0.04210740605729722, 0.047829040972095345, 0.09791519913461902, 0.0305432073336335, 0.026498314804367484, 0.06689478222641253, 0.02517002942641416, 0.024850270072478923, 0.023685963899498026, 0.03728163436115269, 0.050161644636142644, 0.03016906339795359, 0.03719315503633792, 0.04070490208123961, 0.03482505851875871, 0.01944399525171086, 0.06522625804908815, 0.056489929256419984, 0.03900526324287057, 0.05391292056188949, 0.06971076055760346, 0.03539597788344949, 0.03996761906291208, 0.03299833335463078, 0.06424432102170202, 0.06405437718175593, 0.04423212410221177, 0.012497492998297657, 0.03441043258194001, 0.03950052376415941, 0.15058415761638075, 0.014137821309568902, 0.026726101472553228, 0.03586018886116724, 0.05770717018974885, 0.0695146497098669, 0.017663710337552815, 0.052228998017287066, 0.061338059228634646, 0.027748911205919522, 0.016734053065339406, 0.07037653692907865, 0.044114403201327215, 0.03326664798923078, 0.07112189451412809, 0.02821859205141664, 0.03509008280572391, 0.013776526583598988, 0.009339985967193161, 0.07164044410831506, 0.04442543106814546, 0.031017745176570553, 0.03133123984650499, 0.08590753700944685, 0.0009061240087894183, 0.09227198097975024, 0.023672938489565448, 0.03469087055794174, 0.04850930023577906, 0.030943298667308786, 0.07625476787647895, 0.038738825523685065, 0.0891271364244242, 0.0463931700364957, 0.13972564269938778, 0.0942213606509951, 0.10563848389973564, 0.25598962821306726, 0.5356338451946936, 0.13355546330492343, 1.0519609263827725, 3.889186185213828, 8.220242079227202, 29.091344879519557, 59.49545606490105, 67.01976622304609, 88.27883997271138, 125.38913726806642, 133.2493317511774, 137.8064355542583, 143.19203807461648, 134.23770627667827, 124.97760218958702, 121.34046677620181, 130.91643148852933, 130.2021521906699, 136.11430937244046, 117.91686519499748, 124.59214302801318, 129.7550255252469, 137.10848900579637, 135.35757433983588, 137.64941523152015, 139.37552482851092, 159.88994444570235, 142.2115239789409, 153.29926429256318, 164.9964781730406, 160.88708939090853, 165.8018349063012, 165.72494076144312, 153.45783787388956, 104.45476516600579, 63.31563280474756, 33.96519184112549, 15.03606382877596, 4.091820240982117, 0.659348771216408, 0.1353986248854668, 0.36249874039523067, 0.2678575865443676, 0.1826919750460694, 0.07195731339555594, 0.20892999615640412, 0.23491404379808137, 0.06507524679745398, 0.2263037671124743, 0.13084268467801233, 0.013834262800012386, 0.0374917492961451, 0.03635912277405301, 0.04244925364130928, 0.06960900109862128, 0.1296383331740095, 0.04865655382614463, 0.036723922352276506, 0.007793729901388889, 0.08000594804123526, 0.04557620238272413, 0.02333113495560904, 0.07339684623143367, 0.0074437795011627105, 0.06699648805924001, 0.035144758500879815, 0.02779151335538876, 0.0825240484048282, 0.014992271730255698, 0.031587793116247466, 0.03650118228829196, 0.10222576137992645, 0.03982510372635819, 0.008446467935197778, 0.06203747069042537, 0.03411995119325096, 0.08435312162844405, 0.041221069141982064, 0.009080531139437471, 0.03530656776180671, 0.020699534835594318, 0.02098907202091669, 0.009591756933068317, 0.02979340835384304, 0.013978666543299633, 0.012130204591930155, 0.016449223490311735, 0.034966865223982645, 0.008490118667513372, 0.03293744085596935, 0.06776449886421043, 0.062411689319677895, 0.025758298767370083, 0.007864473333146663, 0.043632549218713276, 0.0821803660402375, 0.04543748684227467, 0.0383365182806888, 0.04649908935290672, 0.038822290803035425, 0.017060375877565915, 0.03324874834487996, 0.02993490096301802, 0.0021926123478014266, 0.07566534748841679, 0.028903842377927036, 0.040061771268806154, 0.03873741975234401, 0.04093123509758904, 0.015506372268822406, 0.06693627354839156, 0.019486214357217955, 0.1916991465634877, 0.13535848187823452, 0.271448485793606, 0.21903472652118053, 0.1703774947072229, 0.11696075014169179, 0.17809526363928474, 0.10478159923466945, 0.1662855279902297, 0.13342398729535843, 0.14661358519186898, 0.115264700425248, 0.2244530059397221, 0.2028024878593222, 0.10948534078535535, 0.14459011715746697, 0.16807532388596766, 0.19178556128134652, 0.15127610355134935, 0.20730809609015144, 0.1223370019767073, 0.2363694729583879, 0.18385252164256188, 0.11934303077718905, 0.11863875848751877, 0.17270468596008517, 0.22775259259487354, 0.07757168067919631, 0.1387992125725554, 0.18553610710847765, 0.09518955023058, 0.14786561800827905, 0.1363741152829701, 0.16443714169004273, 0.1703909472111733, 0.12045470862499169, 0.12470717842300093, 0.2210837052834611, 0.1533786318595371, 0.10477164775253305, 0.14004337000510386, 0.14043845686941378, 0.11864970588395674, 0.18136466643021953, 0.07408939737586245, 0.17707918590355307, 0.08842806587175978, 0.1614835509850133, 0.12552450996853654, 0.1470012103597964, 0.1364092480751776, 0.2259772144738705, 0.27955816998597116, 0.22714919110219325, 0.11603443492804805, 0.13384400266072444, 0.21006406675423347, 0.1257306259245642, 0.3335404329963269, 0.19562105708304914, 0.3154223310130258, 0.28360694466579345, 0.22249707621672463, 0.5013628712584896, 0.9755474557318996, 0.30584690611689325, 2.0912572549235438, 5.080294541774258, 12.124892453993521, 36.722245447097286, 69.93426769010483, 78.18731108019429, 106.83915045953567, 140.09493458655575, 150.2616710047568, 149.47520440624606, 160.92005298983668, 147.75631197037237, 140.3941486727807, 132.13884599747198, 144.0257456994826, 136.15003431996993, 141.8669516040433, 127.33717456940683, 136.3860825569399, 136.13305830186414, 151.79577273707238, 151.94913741080993, 153.28366894875805, 155.9431928203952, 168.4193737276139, 157.00031865027645, 170.5305188701999, 182.322167734946, 176.87565865055208, 180.8852623355004, 180.53723827485118, 171.0454946948636, 116.43106352898383, 70.28578266020745, 37.11583175966817, 15.34483967288848, 3.8642872245081015, 1.072678517910742, 0.22241803126469736, 0.4187592569618456, 0.5362728238105774, 0.4961571812389359, 0.13954487659277456, 0.2675451146018121, 0.3539607517661587, 0.15435933165492552, 0.46428685106577416, 0.44821907615950035, 0.11278001681691217, 0.2162023156040138, 0.13859037700439655, 0.08749202134147768, 0.1927922467791265, 0.18154809852280926, 0.10292742897065417, 0.14075089816845235, 0.12478399405916854, 0.1302456263933451, 0.20840844349755397, 0.29429209388552174, 0.19614576602414732, 0.16651924609416918, 0.15988869382248772, 0.19526456572836448, 0.1491098673713784, 0.22444142269030695, 0.11891577588093859, 0.15978041495526993, 0.13863384483322022, 0.21759749960995492, 0.16536119694430984, 0.12472588629011186, 0.18192409447604613, 0.11091927351850657, 0.19617906020533657, 0.11052825458107457, 0.2354310152511443, 0.13014166826202025, 0.10526552165467894, 0.14884006652620532, 0.12769923440270847, 0.18754635246530657, 0.06237422378974096, 0.12182026035002164, 0.18905551503262213, 0.08697666633393496, 0.08499504968283639, 0.12903851697281485, 0.14716463223580392, 0.15366075139853264, 0.27260252064274204, 0.050361620397457195, 0.15852775394676194, 0.23182310884998691, 0.1465886566908129, 0.091087210683092, 0.09011265491285632, 0.21035049170736345, 0.11821895762677155, 0.12349872068772394, 0.06971872787201597, 0.2039907055516397, 0.17037472146893703, 0.09678552588147503, 0.1617902925898952, 0.10973045827760812, 0.10244722973795668, 0.15949569071733183, 0.2858622155843243, 0.12548481129230032], [0.06795509387889216, 0.0185429111438533, 0.04287840460517234, 0.06172822014759145, 0.018425391341048866, 0.046732727017614155, 0.009182331775645576, 0.03570256244030691, 0.05212335449252879, 0.05501979503840689, 0.05037674680352212, 0.02788421957032575, 0.027323910523386254, 0.03140044822958449, 0.09017021109860751, 0.06392688865983678, 0.0127251896511523, 0.04219312746558459, 0.05944405622299641, 0.022996827591991714, 0.039935309304705555, 0.0290179128698524, 0.03937655924669197, 0.027867972760671572, 0.06692936343531455, 0.029148044395110304, 0.029272497293629476, 0.08057116005089014, 0.03431089860837787, 0.050830929690311034, 0.042550024846869136, 0.0600451709432227, 0.020883574052864028, 0.03144957170250916, 0.11591426637624541, 0.06676981030332466, 0.07462375136392732, 0.07083215240028597, 0.03178412612948207, 0.0058638591379407915, 0.04681048494192862, 0.015570663325037929, 0.020311388727878372, 0.0642650781740104, 0.09143439406949667, 0.03419580155863397, 0.08944219774416379, 0.029068633636099198, 0.052491183948492816, 0.09964023761811758, 0.03670331075667374, 0.07751449221564878, 0.04233216859340187, 0.029295527811853156, 0.13654381907995672, 0.04583757626073015, 0.07377472676096425, 0.033014210526861494, 0.15595625725484666, 0.01724838726072302, 0.12863989078229474, 0.3513780242252735, 0.06060618096061292, 5.901929111249986, 17.9166103178455, 34.0567046596158, 68.39397645765736, 85.91077173909834, 101.19426358130671, 105.54805524887578, 112.46694364855367, 104.81107327245898, 100.07576834770941, 76.83246166475358, 96.28944950719034, 84.00064806784354, 64.31534298004644, 84.10481837487991, 83.24312071646415, 66.4713482702932, 79.2928546474826, 113.50795638176703, 78.16255307966664, 70.76583370085686, 68.95218464636034, 87.71941584925499, 73.7795005306121, 77.98141802510908, 93.72989116176483, 76.80995510470483, 61.1524691889363, 74.21968460083008, 82.53954948917513, 90.62705316851216, 82.54547226813533, 93.7451962501772, 90.49737176587506, 99.61499183408677, 116.23874187469484, 128.58267614918373, 128.08397816073511, 120.32471410689817, 96.79315243997883, 85.34296943295388, 70.06240367889404, 43.250214745921475, 15.607081497869185, 2.8562363741859316, 0.07744922152450008, 0.21768742301050695, 0.39790704846382147, 0.05638005309588006, 0.12136721127336064, 0.11889099293658811, 0.0711424792966535, 0.04846541105859703, 0.027030807198776353, 0.018352049913617875, 0.07995503383778757, 0.032131761507762056, 0.031195425864068732, 0.05473589051454779, 0.028658943220732674, 0.022244766737604817, 0.02483954675675881, 0.022458915125518557, 0.02844369932708721, 0.050262515433132655, 0.07273994881900088, 0.049601350910961635, 0.024554230715899218, 0.04631609776087346, 0.019811654253111734, 0.016019724914053037, 0.007218415586037502, 0.039466789082413724, 0.08640866576423568, 0.008892119475339931, 0.029438973945235054, 0.06137875764961205, 0.04353580380519552, 0.034030108231930964, 0.06258154633424937, 0.008443098105940848, 0.029473844352328492, 0.05996813697199668, 0.09473386581145948, 0.022549045369810155, 0.073508802320688, 0.036207414382407745, 0.01229982699207481, 0.01590306600255351, 0.0932400020199918, 0.034830022768508044, 0.015058075810121673, 0.02315837638302436, 0.037218340176848635, 0.033266368367138414, 0.041532422596168135, 0.00931724751999061, 0.035270691864312656, 0.007328811728756034, 0.026829398853043397, 0.014154876341983197, 0.02890535540157749, 0.03626201346877121, 0.03191349731247512, 0.0460220349111384, 0.090937624354997, 0.025762242204960317, 0.10287947186659421, 0.02574938341915127, 0.013792098278269894, 0.04310983593665785, 0.045483360187180584, 0.010967843324667024, 0.009052338146214044, 0.034807273787596536, 0.009733787719010106, 0.008385887617365488, 0.046743812309878494, 0.004109479008137339, 0.0339305168017745, 0.02015520829797512, 0.04045071793840297, 0.057917116585397915, 0.0712716417206872, 0.043910983874793016, 0.02059615510065229, 0.0799803990089605, 0.021017357902300936, 0.01595163884978261, 0.043894168244855064, 0.05607117410568942, 0.03727465146972287, 0.025250447591045694, 0.05975106978909143, 0.021104023513954975, 0.027175929149492618, 0.03100649134496287, 0.030750782687156916, 0.037872946986387816, 0.07696595027922623, 0.016492176125006332, 0.038661435321574254, 0.0758819435272486, 0.044321047758022626, 0.004747981213093285, 0.03400940853621691, 0.0630016038344512, 0.08375613995256924, 0.036087127086976846, 0.04340939546724962, 0.033535935555494605, 0.05176017519026514, 0.08080208959478526, 0.062355642327137535, 0.00987175153568387, 0.002848617746607371, 0.0736750127567399, 0.04363080253824592, 0.022919092650314974, 0.030474456688088757, 0.02849955096720688, 0.042991398743564085, 0.06383174437008078, 0.028356083766407067, 0.07296051319328047, 0.05795041076658715, 0.04439042468044547, 0.13073086648458435, 0.05756260173755789, 0.08308994989361494, 0.030407060102950183, 0.11431427642462716, 0.13265501888048264, 0.26081619664065303, 0.19283078100171783, 0.11342805825294026, 8.92386478762473, 21.545869611924697, 43.82555976990731, 83.45482672414472, 104.77954526101391, 118.37998728598319, 128.61599276142738, 135.9006343349334, 132.31117925336284, 125.3240651469077, 100.1076650619507, 120.16476769601147, 113.68312158892232, 104.9419156966671, 109.40397262573244, 111.27704558833953, 101.82723214549404, 113.2749205250894, 141.83839674918883, 118.82099505393737, 93.91603900540261, 109.59900071544033, 119.05396815269225, 110.56814778235652, 122.48756393309563, 133.97867295049852, 107.5367126157207, 100.92041154061594, 107.48070901440038, 120.51141108236006, 118.08759027911772, 114.38409620715727, 121.590313911438, 114.50227722044914, 120.78667517631285, 137.32544314476752, 148.12223772848807, 155.40695774939755, 146.91948213884908, 126.15562331291937, 112.82360476832237, 94.21722996619441, 59.27978454097625, 25.64102215151633, 6.108306088755208, 0.07523859821019635, 0.29121634280008657, 0.350153049634349, 0.05981707975508706, 0.1703321729456225, 0.39380893772167547, 0.046218567107233315, 0.072391938057638, 0.039759197182232336, 0.03244539790396248, 0.036147061975732926, 0.004929013056455241, 0.00319577096830002, 0.04083092354478375, 0.023363379596342004, 0.019934521349627646, 0.02519755688075337, 0.02232749082688843, 0.022217066913482644, 0.05040806064742708, 0.07514308236779706, 0.11221510358154775, 0.02055568076039274, 0.030108107697038405, 0.09950459409024447, 0.069540903543032, 0.008803623871156767, 0.05655308554489767, 0.033554011400068, 0.09041264728312531, 0.09654635323151466, 0.0659038398354765, 0.06646130669621692, 0.06453113284923377, 0.013158806907613913, 0.023264148227509954, 0.06809429205473393, 0.033124419935648484, 0.1430823335484151, 0.022582243790008852, 0.08807625531429246, 0.055808612791400765, 0.04839702622003613, 0.044813707410808534, 0.055565150049064434, 0.03034311282869068, 0.047549855549849813, 0.05589133496546457, 0.0095983759327341, 0.027577303680441076, 0.010302241238194608, 0.02686562523576281, 0.041454404201959415, 0.013014609050456316, 0.021256235608410452, 0.0391263970654578, 0.07050859516546612, 0.062449514910939245, 0.026135708152827238, 0.016950808067415512, 0.05583055354955216, 0.02478557969293287, 0.04230711368783828, 0.05624098515498543, 0.023522789086846095, 0.053879683837294585, 0.04652304109185935, 0.07072607220541086, 0.11741076551017263, 0.13318731209203122, 0.15113384102381047, 0.09879582486445866, 0.16058859175011037, 0.16073059380775498, 0.07217952485887275, 0.17633721442712894, 0.11743188655424504, 0.20128459188966982, 0.19412618971640067, 0.14581921330142408, 0.1563178660768655, 0.21184126816449628, 0.17946597879692433, 0.16560222352704695, 0.2033844695336396, 0.16834506344410682, 0.09607276533760371, 0.13241213836496876, 0.13912081628316833, 0.11459860229684461, 0.1116620340654927, 0.10397168342024089, 0.18907946294113515, 0.22273039595494348, 0.13777579571450912, 0.12025567898226362, 0.16035116578061737, 0.14230932018929912, 0.18446157686412337, 0.1543257923256005, 0.15143099120788037, 0.15059915761793816, 0.33727762439558584, 0.14299455519405105, 0.14432693531195964, 0.137785509709389, 0.14119518319925956, 0.09359693770567257, 0.09676843445988433, 0.10778386716640766, 0.19745619006214604, 0.1760333686346008, 0.21522425115108493, 0.14004857940298898, 0.18157998310221782, 0.09097789759717642, 0.18495623983683127, 0.1691599358474055, 0.11123009071114565, 0.14233475430838524, 0.12994354260304283, 0.1387029766075073, 0.38288492228715654, 0.11861919260193264, 0.16733764250191951, 0.13281816496483742, 0.32171654004243116, 0.2308554172275528, 0.4181662436214186, 0.44538562336275656, 0.38108967184539766, 11.74184751126074, 27.532846004732196, 52.15293599713234, 99.96744817303073, 120.17990020013626, 140.77405375819055, 144.65194425275251, 148.24343896681265, 137.4767368070541, 130.12473244820873, 103.58137099973618, 125.84010785625829, 110.16990953876127, 88.89103566446613, 108.54706025892689, 110.32508634751844, 95.84739054402998, 111.89111617303665, 147.74112455306516, 107.79500853630805, 102.50686122525124, 100.2292585372925, 118.96801333273612, 105.98554857315557, 110.5882538518598, 129.36902507658928, 109.46262774928924, 90.43667700982864, 104.84208353104131, 113.0836186870452, 117.20552767476728, 111.95840051097255, 120.8747402314217, 115.1518609446864, 128.8175162961406, 146.66438687232235, 169.5656785657329, 171.5279305365778, 164.80495668226675, 138.50171489100305, 125.9573631901895, 103.43533331348051, 66.8652875961796, 30.794367405676073, 7.546954491446096, 0.2745235933651847, 0.47431304209655334, 0.6270162448767693, 0.1913718278369596, 0.47439654568029993, 0.5507241225531024, 0.11148862240295257, 0.22416445126216258, 0.08191279451092405, 0.14573693545835634, 0.13211445191935187, 0.13713385999923752, 0.14204587787389755, 0.15983414836227894, 0.32433723490084376, 0.10186217605106293, 0.10933603024891309, 0.19191086262224183, 0.10761391056040603, 0.14184441207157028, 0.15612830528088156, 0.20272238570595943, 0.08060820806290835, 0.17779800620290542, 0.12773799079079784, 0.1768324443049008, 0.11512788478285076, 0.21354029796296553, 0.13570784861522336, 0.21192870944017367, 0.156234301206085, 0.2901989167496082, 0.15505205899957689, 0.10821284576048774, 0.14538718567740533, 0.17043009430410402, 0.18164028954361716, 0.15651657396266538, 0.24260648586336644, 0.07030793375545932, 0.1523107206148486, 0.1701854364646058, 0.12110106466758637, 0.2615780864031084, 0.19373577598842884, 0.11753985132541388, 0.10810216903806695, 0.20532388240098956, 0.10295113939191065, 0.13181057548330677, 0.10826570582726311, 0.14774880492158476, 0.10091608044721427, 0.06425952403655937, 0.22891865502442085, 0.11819481053539824, 0.12304181052792458, 0.1686041237365815, 0.10934075701140589, 0.11529375814021596, 0.24393480571527637, 0.12865610120277252, 0.13918882956908596, 0.12316145047905946, 0.10114983685554997, 0.10793385186022329, 0.12454192559685438, 0.138052751820895], [0.014009558081236339, 0.010956348175363196, 0.04944581974057421, 0.030483542490870725, 0.0791310296664315, 0.033048803227082375, 0.029497261744953936, 0.03902937202984768, 0.03662934113714484, 0.037122877960604046, 0.06951968290752943, 0.04730777942665643, 0.04591675144770453, 0.04694677198365812, 0.10264547031012275, 0.06214238643165558, 0.04741802713983963, 0.02496872067211136, 0.09308427932762331, 0.06195083380706849, 0.024172039026574745, 0.02584563853639749, 0.05791751112067892, 0.01024110071856769, 0.007044172239294577, 0.036994550572407824, 0.018617757934055502, 0.0411300502356983, 0.05360722083658461, 0.06104056047455919, 0.044663194116325154, 0.07441108535614706, 0.03320453741076974, 0.08357166598040251, 0.05757927947166947, 0.048230911544974775, 0.05758091506938781, 0.04083892916359248, 0.06267663699785067, 0.05754658283906118, 0.009225914517657892, 0.05994560249570397, 0.009349101455882192, 0.032570906088597355, 0.004185089492239058, 0.0404034924483107, 0.05360847339034081, 0.01842204162159995, 0.04954589763656259, 0.06433531311490844, 0.032481315936292374, 0.08241510304111628, 0.11260128850417753, 0.02408112354216076, 0.05177067442526741, 0.07938938515801584, 0.17348038062693613, 0.03826819472916184, 0.17115712706600467, 0.05279443602287962, 8.807761649931631, 29.76101702259433, 62.209457735861506, 87.10411364032377, 101.5039582406321, 101.80082674949401, 111.03601594125072, 85.37662336903234, 69.56405870376095, 55.63409051587505, 52.75150145253828, 51.456844729761926, 55.04712743143882, 89.69889486989668, 60.52017527241861, 46.109885400341405, 51.25163024471652, 58.14569004120366, 35.34513265855851, 26.839318006269394, 26.732096095238965, 39.01143873891523, 29.874775563516927, 34.86009236304991, 35.52591077743038, 28.77205021919743, 39.200748012911895, 41.34713957386632, 35.49107620793004, 47.800293584023755, 44.63948295962426, 59.75787831890968, 38.799136530968454, 50.66702842712403, 51.36473571100543, 44.36779998963879, 81.58889247525124, 82.94386740653746, 69.72219297962805, 69.12548280531361, 69.80227208906605, 102.22334446445589, 104.72392605197047, 105.37389416848461, 103.88903387131231, 118.15166611825268, 110.62594782921576, 88.97309949321132, 48.49903637363065, 35.22011495405628, 3.968428113768178, 0.18022560093912388, 0.7198419542081895, 0.3966214916398449, 0.030248566087515607, 0.13178504943366975, 0.085190310172977, 0.02188903572518499, 0.021436934682330298, 0.04582991155104772, 0.010802818409677957, 0.09958386120776977, 0.0534261521252413, 0.06657010650322323, 0.07612663967114303, 0.015358556561442393, 0.02291057949825641, 0.0734710571686587, 0.030439982731496135, 0.03271292346800047, 0.018226030365293546, 0.035870956226943, 0.023683096815441406, 0.007946947486244985, 0.06842053825816802, 0.06317023510834383, 0.03579975218482075, 0.02816355821015614, 0.034467942802415746, 0.007178092548142999, 0.058415541049814036, 0.045150104279239336, 0.015116361694620743, 0.02818939835584212, 0.07347327882363912, 0.03975139074628392, 0.030053868671999346, 0.04058570263066119, 0.015261247115690383, 0.023240200318996946, 0.11858363080048755, 0.06724030320202151, 0.02641466949435492, 0.025745495522935546, 0.04849584007094945, 0.03236485908048288, 0.06903189174350231, 0.037785237579936945, 0.0624440833475561, 0.01497585159320865, 0.03307423734616849, 0.03936755388314205, 0.03186102220488172, 0.0639526790098077, 0.03768109558751026, 0.04954898497089744, 0.04214272654104618, 0.08104533017162355, 0.07122971372859133, 0.051663602146530346, 0.047518384657920375, 0.051893397880297516, 0.054410563616622845, 0.05912416088845461, 0.019851950477928888, 0.03258536982860777, 0.02878293455127747, 0.08037517943810071, 0.08996450116917973, 0.024848490833274783, 0.02288043010799635, 0.0451542143409531, 0.02470560394407761, 0.05610153417012865, 0.09615494358924129, 0.017091021309756947, 0.05759602615369424, 0.07065396800997757, 0.06630458808954685, 0.03712187821586286, 0.07174783431354069, 0.017212762257024165, 0.024761285129634124, 0.034201099056630366, 0.056447426698380904, 0.05364573973741743, 0.06862575789132426, 0.03703565118954547, 0.07774981144335001, 0.017881110768705126, 0.06685785678846222, 0.059255387919444236, 0.02588366714095877, 0.037094463759492484, 0.037818880331131725, 0.035167369585964954, 0.04921210929751397, 0.03775179401160248, 0.08428847912939326, 0.01759574110169084, 0.05364429949211979, 0.038572151604438984, 0.07249203510582447, 0.05873092795692145, 0.03199086644716802, 0.01600253581625199, 0.03262964588019156, 0.059386339158781117, 0.018649426093625448, 0.05999445592263534, 0.038687037980003704, 0.056032969300905545, 0.0772332230342492, 0.0182761344307613, 0.11211832369407339, 0.04144488555950023, 0.004056090340694232, 0.11940973405275615, 0.13771294586120114, 0.0565508370768399, 0.022520552644686356, 0.024215956932053934, 0.1748524134558055, 0.04562261965005629, 0.10275317461139734, 0.07022262220421145, 15.331594809409111, 41.227468059908965, 78.70373033708142, 105.94885087782338, 119.35854804131293, 120.7408069795178, 133.4390332621913, 113.7129629811933, 97.74922232474051, 82.77165182175176, 90.71471029712309, 86.13054998459356, 84.21408776314028, 102.08479850522934, 99.79832341594081, 83.135177089322, 67.00501026645784, 83.42040400351249, 59.7686726816239, 43.76488854808193, 47.34851890994657, 64.73772341205229, 50.6039410252725, 59.24727985935827, 52.278204733325595, 64.70915286771714, 60.278510201361875, 72.52095314764208, 65.6531810760498, 76.11560144732076, 76.19389980070054, 91.79317382074173, 77.15864596828338, 90.23283927671372, 85.1211593997094, 92.12550055596137, 127.59790235950102, 128.66275525862173, 118.64921092987062, 119.29251101709183, 110.66933708806192, 131.71213919116605, 127.28910200057493, 129.04540600315218, 128.86295303221672, 133.18087854693013, 135.00694582539222, 113.36008302627073, 71.79078040584442, 51.32104050728583, 7.595315354485666, 0.2259628579861695, 0.736758585178083, 0.5060881628624855, 0.048449744560545495, 0.19600022464029251, 0.02219719650794662, 0.012364611217391588, 0.0263192379216273, 0.08793442179599116, 0.02378189342937643, 0.089891814746924, 0.03520057566704289, 0.04599683444886919, 0.12285401173416646, 0.035084950016631235, 0.017528980369529417, 0.11209903360014001, 0.03873080075267823, 0.02018336585963205, 0.10714114238057407, 0.013888962435415916, 0.0348412191435214, 0.0818349676386964, 0.01978804342328541, 0.06164640961815754, 0.018695525434469024, 0.04116373895216854, 0.03843651956788475, 0.10536506711955994, 0.05817035077920845, 0.007954236812844512, 0.018760179424838676, 0.04881484291305946, 0.06576233573498265, 0.02647711332106302, 0.025733492840381882, 0.07845942336585253, 0.04951704293489457, 0.008198987061698592, 0.03882333268261245, 0.05496154937352385, 0.09515945829691426, 0.08846187333185827, 0.07319494375898954, 0.01756291231891561, 0.023275651037693027, 0.037413910932598576, 0.06901068642975823, 0.04851971137067003, 0.0663940288547066, 0.04634398719175689, 0.009267556184392062, 0.05701872144615459, 0.014065866501280859, 0.051515551824723525, 0.04527882237227694, 0.03197537997977869, 0.04477585117603022, 0.03579194574887234, 0.048739168747899034, 0.017184570221410646, 0.05999327614723195, 0.030758656155798706, 0.011744337595788943, 0.03297740000209982, 0.09395008125612814, 0.1440743254798074, 0.11023557068960321, 0.11227434516073236, 0.14179771135170616, 0.13208613730967045, 0.10255243659259812, 0.17700996219871507, 0.18239484018375798, 0.15068548040524607, 0.11854726460672195, 0.21726982848298168, 0.1308750901972094, 0.16145975629408515, 0.20938704421202983, 0.17251628961774612, 0.12354354449217358, 0.1987531615961944, 0.14384491279000236, 0.13829014714687102, 0.1564819621102464, 0.14307527021775324, 0.19719489279293245, 0.13207274609275405, 0.14495149615310854, 0.17457496705314807, 0.10120811316395, 0.2102268297946261, 0.13009191851221746, 0.20802388268132366, 0.13437568300193356, 0.14386147561092533, 0.14403329381058294, 0.16756961392539163, 0.18235440606311445, 0.08944130908217161, 0.1616521975806644, 0.15441456659426614, 0.20124552140553154, 0.11909820439834749, 0.10296984725902159, 0.1725786032095071, 0.11449731015149625, 0.29991242133321305, 0.12909476314821552, 0.18969398803047596, 0.178672035915717, 0.17649571801866257, 0.3023350977849576, 0.18085999834922054, 0.13478406915260902, 0.14610212957186086, 0.2525775338853559, 0.16650298970841593, 0.08413504703991836, 0.1999470330173931, 0.24432491300807846, 0.18615001932747904, 0.2629233980851789, 0.15818695207276653, 18.86725752584396, 51.668127121463904, 93.68505062595491, 121.10185330913914, 131.8127401413456, 134.74130722784227, 139.00569238970357, 110.60017785718365, 94.07409483386625, 77.24370648784023, 72.85094215023902, 71.48875005783574, 77.26706812458654, 119.08358989223358, 82.14885004105108, 61.64579353024883, 71.38217141551357, 79.42426189299553, 47.448774691550966, 38.99036776634955, 42.20139649606521, 53.879025982272246, 43.727955510539395, 51.23587408373433, 51.8933770733495, 41.25709372182047, 52.36264159602504, 62.347446718523585, 52.63067676175026, 70.24999495475524, 65.75219738867976, 80.78885447594428, 54.218997416957734, 74.65455778183477, 74.48601353553035, 71.12085526989353, 106.24572723142563, 118.85517458761893, 95.86778686892603, 97.29955396344586, 95.08087312021564, 130.38276164762436, 128.8560418159731, 133.69467766054217, 133.38357094795475, 152.8676780577629, 149.2701272041567, 127.39030699576102, 81.75989212528353, 58.45226249387188, 9.543889530243414, 0.33714312999959917, 1.0759643609485319, 0.7184710245459311, 0.27567526866351405, 0.35743667653972105, 0.20938563461024917, 0.11112376536813476, 0.16105140078692667, 0.16834245874516426, 0.14797504600738326, 0.2521578402769181, 0.12109767855896104, 0.1773846251589637, 0.28368364538877244, 0.22281141741381538, 0.2099182649004844, 0.2573007417301978, 0.14742488762544048, 0.13625788442309827, 0.2722527555400326, 0.12078221121262159, 0.14113383487828318, 0.13561941142524445, 0.21978851107339706, 0.1452803164119682, 0.21846403698286704, 0.09752743607086521, 0.13452948281361213, 0.25202385149896145, 0.17746612159234865, 0.24003353360439503, 0.12391230857540524, 0.09592818156365426, 0.18083802694755216, 0.11747321699775996, 0.27805173469166605, 0.14815498473903826, 0.11880581162028736, 0.1536860476217924, 0.1782027457750613, 0.12616610860512142, 0.19548666993937186, 0.1468112818416088, 0.19071113828930164, 0.12154357237440926, 0.18070210762802633, 0.11243801218487563, 0.16286304551026515, 0.1854465054648538, 0.16647392433256875, 0.13931158749807265, 0.10869682180665194, 0.2252869692540938, 0.09098823212327496, 0.1950649078935385, 0.1248616447311736, 0.12758222213315387, 0.15912562428462892, 0.17915154566928265, 0.15071699726245097, 0.10250601932526597, 0.1523585245013237, 0.11373489178837308, 0.09246509642370286, 0.11521789245307447], [0.02176311768351063, 0.07034148840654282, 0.09080935059295547, 0.060073274878724936, 0.0019363379819438825, 0.04234680853363487, 0.025653030625694705, 0.02865807945659805, 0.04108105891294057, 0.030636501521052375, 0.02418533065206101, 0.01608776788587772, 0.03413797341166966, 0.050918505031375155, 0.053205334941946694, 0.008878295418746289, 0.055932895235356786, 0.011607676128586455, 0.06080357500562265, 0.04428643973604326, 0.041093488689512014, 0.05946485551014062, 0.028777928166692297, 0.008875116153860526, 0.06556967228290535, 0.02898781902096685, 0.04608946597023357, 0.03161287675010822, 0.016266185933003025, 0.04928328269611924, 0.09474951698775254, 0.04843420063656184, 0.08023366767672763, 0.016391041027682445, 0.06012311655907862, 0.042244773282999956, 0.09627764023119405, 0.0689934264688242, 0.04604735794747549, 0.0572393624292266, 0.005942292177238532, 0.035507190867417285, 0.04482242549138685, 0.05024804786268262, 0.01989107841866151, 0.017987767444743265, 0.02569122968481914, 0.04461891040386212, 0.05076942432131018, 0.052934178121147625, 0.037077854973294085, 0.04165752858464276, 0.11245584671175289, 0.0730734498750779, 0.08976193220024148, 0.0501759551585682, 0.27467754639444814, 0.9483928870289557, 19.45064733105321, 47.86079614393173, 76.22619659669938, 91.15571806507727, 89.71521192981352, 89.26835983030259, 82.098816287133, 73.95810957877868, 58.82190665891094, 58.47214106590518, 48.6726914682696, 46.72335978477232, 44.70969338570872, 57.37994532431326, 55.68756026606406, 40.94452396515877, 43.49759471031928, 60.24769213891799, 89.6701595860143, 49.54949417421895, 67.27496347119732, 84.97395284714239, 77.24757394483014, 67.21584550796017, 109.12633157545521, 53.454966775832645, 90.40293678160637, 80.78425745810233, 80.23533744196739, 87.79895367160921, 79.0707778930664, 61.78761466856926, 60.15429658274497, 48.43031644821168, 60.282232530655406, 35.420128376253196, 61.774541408784934, 46.872174509109996, 32.24040016051262, 40.340463269141416, 33.900963029553814, 39.33497936494889, 34.66066337400867, 58.895207912691184, 62.15665871097196, 56.745725524040964, 74.30651803170481, 69.51752370403659, 76.40426435778218, 97.51526863344255, 99.26956438249158, 95.71024094858478, 83.67416566418063, 54.29444812959241, 24.20562098103185, 4.527184943999014, 0.23854845684141884, 0.5362641823387916, 0.02373063640158263, 0.044373072788960514, 0.0363825842167341, 0.06938200924665698, 0.012098222336311255, 0.10642973781232873, 0.12793230133191233, 0.011861493506829345, 0.0857347305563669, 0.03735846148863916, 0.04405764757745689, 0.019899750533964367, 0.023258088472028895, 0.037489098631927086, 0.08073612176362546, 0.040419702868788474, 0.07739054685037944, 0.0703589705329749, 0.040031656352502686, 0.031265553552657366, 0.0607058298473637, 0.05690506081126871, 0.04523014514556816, 0.10773763376017732, 0.034719146863226934, 0.054754234489894686, 0.07194439715315258, 0.04627553340528281, 0.043248539985788446, 0.06989352615369905, 0.05192257433889374, 0.026297498261556033, 0.05915046068689516, 0.018423395682006113, 0.05509166557702327, 0.02877479103664237, 0.03902225124259149, 0.021245424192579045, 0.016526516016212203, 0.04086704075997395, 0.048823319675941626, 0.042549055745644916, 0.05009764565094825, 0.021228210196920463, 0.005645514982226756, 0.01407157960197618, 0.028523433758246324, 0.10380327431184631, 0.042992429131822246, 0.04798754456362898, 0.04303422688897099, 0.007478722207804001, 0.03857232014378233, 0.019758156418139418, 0.07370300560949311, 0.06529992506388696, 0.009682032734065527, 0.06779269856070319, 0.01930253903171228, 0.0914296749678831, 0.014356793178575895, 0.030354927819702896, 0.0442446036744983, 0.006711152860999949, 0.014633665015290101, 0.045406766716511025, 0.007571849771099346, 0.033759751973012765, 0.07904989329437095, 0.05352170244159718, 0.07651569742348886, 0.02470970442969232, 0.04449195431305036, 0.0548494324058054, 0.06031277694649274, 0.024018107064729257, 0.08044588169263256, 0.021277709052928036, 0.04948121300267597, 0.033918136820918134, 0.010880022835467133, 0.026063933375201402, 0.04927692799678734, 0.02243958289674934, 0.050688241983974175, 0.05063316026221841, 0.06047902951738047, 0.028280687308119192, 0.04017972582650762, 0.09806672366516245, 0.059946165570328315, 0.07217040075169456, 0.06568783368434637, 0.016927155102753354, 0.022490454965361187, 0.01422983613015423, 0.08000003384245981, 0.05485749931164807, 0.01037812224709459, 0.05267419086228456, 0.04022469518766288, 0.042236189267808394, 0.019601908955542792, 0.035886277985428615, 0.017320175444887533, 0.025297521778772918, 0.0410861112628012, 0.03707838740440146, 0.05580026243302611, 0.05632436616466411, 0.058708041080183564, 0.02554294762141522, 0.10602050896493659, 0.08456284585859507, 0.07762133083756893, 0.12297567415742144, 0.14576322759591764, 2.4162248882555195, 26.221997737884525, 67.1035009814847, 93.636272030492, 106.54510605719783, 103.32508333267705, 103.36876284691596, 102.41985521008893, 94.68675336530133, 90.41826540423979, 78.80205631256104, 59.55733929910968, 58.208094950645204, 46.97929836088612, 50.25075512547647, 44.99491637752902, 42.54659645019039, 26.244543521634995, 27.44770899895699, 48.72638479355843, 27.027791815419352, 28.824798253274736, 31.43064056673358, 31.801987040427427, 30.45084034242938, 46.6072811618928, 33.72165579949656, 43.82997635872134, 20.724599822874993, 34.6898889541626, 36.58224821090698, 34.08133714429794, 37.140632906267726, 25.56412212310299, 22.294287258578887, 26.374238652567712, 19.178462297685687, 36.62268000264322, 28.617828507577222, 29.276698443197436, 41.56055573494204, 32.629032519555864, 46.12550820073774, 56.145928444400916, 92.74981637154856, 104.76456180695565, 96.48865099876159, 113.99775843466483, 108.05306911468507, 105.54855731225784, 119.63130966309579, 109.22400643748622, 114.47773102791079, 106.44318719064037, 73.87300983552011, 37.09521578204247, 10.729747549180063, 1.0080917287738094, 0.19335351343597137, 0.021474532362434174, 0.0471714502500911, 0.036536816868089864, 0.05180235982181565, 0.0447804477035759, 0.12498295475398341, 0.10257731146749952, 0.013996306675366096, 0.14859447405943949, 0.057165913749486215, 0.05935222526351291, 0.0496379086267083, 0.03951747728992374, 0.054766442100968094, 0.05402358579299143, 0.028065184859799284, 0.07217617705464363, 0.02139045038230477, 0.023617837615611575, 0.028948034159839157, 0.0722667822734483, 0.08639432459829316, 0.04048272892231903, 0.12841993161747534, 0.014708466797826752, 0.028591056339322563, 0.01408803229776001, 0.021264277616395585, 0.03201357903890312, 0.0340712241708271, 0.06747706267502039, 0.029001022546341824, 0.048342204968174624, 0.02498525284951733, 0.08105770249160067, 0.08274789929630295, 0.030911465798835122, 0.031176340698655096, 0.05146000278933395, 0.023624094638733134, 0.006434392585839716, 0.022073084518553752, 0.005476902381727292, 0.04274614718592456, 0.03370648204919792, 0.026990380739012075, 0.028451787300347805, 0.07646677504864431, 0.023589086335813327, 0.06737390127513679, 0.03141892627031813, 0.030020796656308156, 0.07696658613220339, 0.08628326483191022, 0.11809421553006096, 0.03608066513533554, 0.05742567118197199, 0.046134044626547445, 0.04434467390960744, 0.05294270851018448, 0.09148810449386797, 0.2251003349139806, 0.15621862704715422, 0.16248761646209225, 0.1449103572315747, 0.09043636536526103, 0.12285850867028199, 0.13874056088107248, 0.1785895435680305, 0.14075141910824085, 0.17086368474748828, 0.14172439673735251, 0.08706783079692433, 0.21267015997680927, 0.15299168084898304, 0.1119512705613048, 0.19683951992661725, 0.15584214079764583, 0.23712442196424932, 0.1521770842373371, 0.08714611732190655, 0.13847549445927143, 0.14893662424818163, 0.1288724750761063, 0.22123672368545688, 0.1733597830658959, 0.09179899063442024, 0.13095309326965965, 0.1897308981466678, 0.20624157912548513, 0.18303299142468363, 0.21585579871410326, 0.25210689542995346, 0.1508977480473057, 0.2169430460180006, 0.15436195167562655, 0.22730352717541882, 0.18872617383397397, 0.11168389055397242, 0.17275601385101197, 0.19034451925225798, 0.17174750506397218, 0.1454599487084535, 0.15914313705457797, 0.12997611666158324, 0.08826340293331493, 0.1212043179980209, 0.201892375405277, 0.25178195157599065, 0.1434973693422733, 0.13269476352199433, 0.14619625113423795, 0.3472054190933705, 0.1689076784156984, 0.18727325744205908, 0.13425457982286332, 0.43678886046813387, 3.1154949915024543, 31.70555949211121, 79.62095306765649, 109.37706516635035, 121.7719510293776, 111.684689675608, 112.29988205817439, 101.38012901429208, 95.00529689173545, 77.17987383565595, 81.41077764572637, 68.96515200215002, 65.87539119105186, 59.27478744137672, 74.31321743995913, 79.34419847303822, 57.92803772034184, 64.72514829327984, 86.12893396808256, 127.3270626991026, 74.10323727515437, 98.30611259706559, 116.8774292545934, 109.6255002483245, 97.28347224573936, 160.32233084401778, 80.86774902959024, 134.5537708651635, 109.83328388583277, 112.86940236245434, 121.03837367027037, 114.76558593011673, 87.85664389210363, 83.18061382539811, 73.35766530806019, 86.5626931959583, 51.30095797200357, 87.32590798408755, 64.03114764921128, 41.806813901470555, 59.2412119527017, 45.68115857339675, 53.71519642491495, 53.629312207621915, 82.2396921342419, 89.31166279700496, 82.80194820896273, 103.268813010185, 98.27365890625985, 108.20096600440242, 125.99829704530778, 131.50240221331197, 129.7576613580027, 120.4852645627914, 83.47914541921308, 43.121635529302786, 11.678932693696792, 1.1223579101985501, 0.7084433013393033, 0.22015882265423575, 0.11358469258993865, 0.18121006988709976, 0.2160569734030193, 0.1758105443009446, 0.3609147463594714, 0.3519910477822827, 0.184321949679044, 0.28007040701566205, 0.14182254792221133, 0.12623704068603056, 0.17561923682449326, 0.09561624588264574, 0.15962378061827154, 0.1369339416945173, 0.14351797710743644, 0.16502082407955201, 0.11533841340532226, 0.20151452551926338, 0.11267514704095741, 0.231783103738581, 0.12257732375855408, 0.13746793562125775, 0.30757216676588983, 0.17341327132476916, 0.2281990686371442, 0.10053308245034949, 0.12943269985337413, 0.19167564298597076, 0.24101997905921554, 0.17250867470377879, 0.10887774879172926, 0.1374823840395097, 0.11547597981388531, 0.1500369563338257, 0.12822646377307753, 0.1274502328446796, 0.13586675057247763, 0.17541124395305113, 0.18057486042380336, 0.08723293040548602, 0.13347032029301892, 0.18072400242090228, 0.1117776673767836, 0.13378256240919714, 0.07514488267441911, 0.14670422871506986, 0.19354143480379737, 0.11776685849913668, 0.19523916225279533, 0.13077646403783752, 0.09698660097896092, 0.19046029045937524, 0.12097925668762577, 0.15286325386935665, 0.13615354324781126, 0.2015243008011772, 0.24629670075110852, 0.08287529971811079, 0.26596700412131125], [0.08442562418959795, 0.05939354038526935, 0.03848237759103218, 0.08351565729225836, 0.0432423385040414, 0.06371293179390412, 0.07570968865747414, 0.025874826486312577, 0.08902904652659932, 0.05807222257698736, 0.03201739990242547, 0.04395750073355533, 0.03209551788806435, 0.09569159829087796, 0.017436641876796083, 0.02919383730078417, 0.061329992322791974, 0.038391806846184116, 0.023363877553492788, 0.018831257062453418, 0.04013736882517415, 0.04260230268682203, 0.033622798434789145, 0.041845932587861054, 0.04101666539246517, 0.014574501960117732, 0.006219723736942416, 0.17569546257295918, 0.017021805265798204, 0.06533263701825373, 0.040480629841406504, 0.06122818689853434, 0.04876556430733012, 0.025608264277839375, 0.04283000700055592, 0.011635369249439288, 0.07809322567716723, 0.033491364560059966, 0.07546698434218284, 0.008189983613368484, 0.01421698404761452, 0.04249272147013296, 0.0253511919835282, 0.04827336047685916, 0.09063588530426064, 0.08076023055060257, 0.0784681337855516, 0.02731220661512306, 0.07678860858563455, 0.08358372420433068, 0.049460180058714845, 0.11606445025292136, 0.07159852377709842, 0.12020818919183747, 0.023282838857642586, 2.9489418383567565, 28.208717453864317, 68.48648948054161, 94.62714118342247, 93.24215227557768, 81.73210605498284, 93.83569317479288, 67.58422666980375, 58.785154050396336, 59.726691553669596, 60.30302109256868, 37.757743327848374, 65.50065186715895, 99.13911419530069, 64.65651073763448, 95.1224345545615, 99.2853872237667, 65.72527816218715, 56.88513048233525, 99.05559908959174, 130.25286843699794, 76.09612295704504, 80.40213231117495, 90.96352977137413, 71.88232852566627, 69.80274277348673, 76.55518147253221, 65.29838700448313, 62.58378913325649, 52.78069565373083, 101.30550984413394, 76.36379334234422, 80.67108923389067, 83.9281391328381, 88.47111455855831, 120.37921936281266, 106.51818290833505, 134.38964320767312, 129.04756330674695, 132.63094655929075, 177.00603823507987, 124.17636394500734, 100.37859885923325, 112.14419534129482, 112.63198129592405, 88.79222331508514, 60.01327168556952, 50.323205224929325, 42.80849310659593, 39.503343182225386, 36.35485664490731, 47.89852542261924, 59.24209448599047, 91.9953170899422, 73.64452392824235, 83.21526404350035, 98.3922400013093, 94.385664386134, 79.45731178406747, 68.64754984455725, 33.05445278844526, 1.7161317001427374, 0.10849612975312818, 0.02151205343374562, 0.2501311853167511, 0.08958970797398398, 0.09976814365795544, 0.011643268573548526, 0.05570712912407133, 0.07006151391373527, 0.0620879635455147, 0.03162397736413104, 0.08600029493531874, 0.06119324945874753, 0.07614246704765866, 0.054249102925701495, 0.07025809207510564, 0.040853492495033054, 0.019331338192005793, 0.04019016377447594, 0.007589148036429599, 0.10382785041245723, 0.020441956923253114, 0.11074129597193773, 0.06143745530637042, 0.048190201632678516, 0.04911609549796389, 0.029825277611493107, 0.07264147587721387, 0.04398453980684281, 0.057648372941560326, 0.07616104467982247, 0.06521567837485383, 0.020856525403477495, 0.02289837571762262, 0.03339885561276348, 0.026148838899849404, 0.004037627142914121, 0.0830882951436985, 0.06211186931919187, 0.03590869754853268, 0.06421391882242695, 0.07489798019730276, 0.042272930844656886, 0.05505208947485494, 0.07513334539027945, 0.05913698903074669, 0.025108248265760563, 0.018169125354277994, 0.07287316384815401, 0.03887377957242631, 0.0909512990244454, 0.19459839099116866, 0.04147903009828541, 0.03008884441618237, 0.043724184825776086, 0.036315720062702894, 0.04426836772190948, 0.04797146054765871, 0.008674537098305601, 0.031504354649974455, 0.06742964949338667, 0.029489621933129047, 0.05368809290831128, 0.049921997011669224, 0.08532834389517385, 0.022740588418298194, 0.024747386379467867, 0.024276249966914618, 0.05625581661719949, 0.026529268586948037, 0.0071162309482573505, 0.060009773850681326, 0.05191779395024623, 0.04511898961819468, 0.03295095847739327, 0.04015484329072699, 0.10769856327603902, 0.012529491533284948, 0.05653498288724692, 0.031214338659699407, 0.09142169999259134, 0.0206945744162846, 0.01988080134915729, 0.04080757318485168, 0.05028694597703796, 0.05406792696204878, 0.0038165595446292677, 0.05090045599987911, 0.045237005462930094, 0.07100436896566423, 0.01572370854011106, 0.07562459161084506, 0.04718676434769746, 0.02156173806607483, 0.06386887282133102, 0.08033583316230967, 0.06017452488923746, 0.03657652320520532, 0.0661432882770896, 0.05057616715109156, 0.04152334828470503, 0.06799869960354221, 0.06490917425722846, 0.07410582996183827, 0.08597060136737363, 0.07655994666199531, 0.02109466574995989, 0.06512543321737359, 0.06245449065200745, 0.042586046301068804, 0.0339460683866374, 0.0429532437344953, 0.056882526334976, 0.160060879744349, 0.03813153230434945, 5.008845627307892, 39.241454370560184, 88.05911664039859, 110.88921731518163, 106.73899665955575, 97.54080326326432, 115.0785126224641, 99.3190097808838, 98.15535237712245, 90.78812137726815, 78.50918862127489, 38.300822934796734, 59.386622059729795, 83.38736195718089, 46.117941948675345, 59.63193101267661, 68.32730400946834, 61.06562006858088, 55.15797753487864, 81.52494999670213, 105.09150705029889, 82.46255336269256, 75.53469842480075, 87.82978350116362, 73.11043047135877, 76.49877778945431, 71.59764289855957, 69.64313368643485, 57.06155477031585, 59.75265764421033, 78.72719395545222, 71.91127561753797, 76.25654005235242, 83.09964041556083, 82.96373813383042, 89.2570084910239, 86.46183336934736, 100.23354961026101, 83.68776844393823, 114.26244781863306, 116.42350119929161, 67.66542757711103, 66.20956928499284, 65.96682948450889, 62.026396797549346, 40.20477279540032, 34.750775906347464, 34.809678139225134, 36.129351738960516, 52.933993647175456, 55.862356770423155, 86.64401177437075, 86.45013686149352, 133.03443293417655, 106.16294953130908, 101.41446544278054, 118.32399937414355, 113.8683908216415, 102.8490331096034, 89.2534940473495, 48.80726798888176, 4.873832743014059, 0.17087326084654178, 0.04557971106541734, 0.29779716064372375, 0.08189490635789211, 0.22626599897780728, 0.0283736654842693, 0.05793154968189136, 0.12816827939522843, 0.057386447480248834, 0.045306669668324535, 0.0587340152912563, 0.0902343862840245, 0.0736014912986467, 0.06492376057130676, 0.017835166560666218, 0.08392620381088027, 0.013334286049939694, 0.06534158492520933, 0.02403496674472286, 0.07657074084084842, 0.02984369628041262, 0.03430541341884002, 0.11766178187944236, 0.007658001625039165, 0.024966761402245012, 0.028618915126689022, 0.05775081038835549, 0.04032456240947208, 0.09839247191144575, 0.0483111669159224, 0.01763764036548955, 0.023685416146632166, 0.03407902294589627, 0.01628806348890066, 0.036165107176789356, 0.03425984650910382, 0.03317592785723748, 0.03449302452105669, 0.0067375790639480045, 0.08185271023502273, 0.043986849561934514, 0.0028276614114386782, 0.017200818946284634, 0.03520912903871748, 0.04586241283123532, 0.05915385445639972, 0.013627806892468324, 0.07608869533625341, 0.03400587687088597, 0.030774585038964308, 0.0228693065113358, 0.06421168184568805, 0.026197267147982796, 0.03623744885947916, 0.02978036570693216, 0.06847424868253932, 0.03848548024712551, 0.03118159606181566, 0.049400739296669924, 0.1491840093606903, 0.1447811028769901, 0.08334449792821562, 0.19914901454842862, 0.14482562790714926, 0.14327587800160532, 0.1887480839486084, 0.16347384741229398, 0.2351708977573341, 0.14233573490092832, 0.09364092647428475, 0.11884931775350725, 0.10983827749207137, 0.2204545785582835, 0.12573853195194276, 0.15200846828520298, 0.17056972148918337, 0.07934853734989321, 0.16832824015328962, 0.1510092138402885, 0.23404173012222015, 0.09737937425773951, 0.15299574111498174, 0.21901552835779808, 0.12137617450207473, 0.2897500198694968, 0.1686783576564443, 0.3112778259861854, 0.11366085705137062, 0.1650264931301917, 0.14108347225814097, 0.15455189551557266, 0.12445265337103799, 0.20481688541270074, 0.09882240811543119, 0.2298841862789085, 0.1687935466367391, 0.1849650498479605, 0.22974541711230434, 0.16622655454181856, 0.11713010153823322, 0.17446668818593028, 0.19657629211583447, 0.20441819793514668, 0.24609866702268202, 0.22108676963515822, 0.24501187937153926, 0.11698673584408338, 0.21972624344691155, 0.150704724533904, 0.16841938929452052, 0.20398640013750524, 0.17867102467965695, 0.2621080047420917, 0.15207102702509973, 6.15213220157931, 44.54620899692659, 101.69672704512074, 125.36088051334505, 114.86757539933728, 99.57665458802255, 115.09013852765484, 90.81274601720995, 79.22213431327575, 78.89344753757601, 78.713622554656, 58.96586941134546, 92.15810329683366, 123.78356210647092, 94.61831585053476, 133.71348934788858, 135.5406862689603, 98.2379888719128, 87.10434113779377, 148.63534650494978, 185.10989035329513, 112.19677863582488, 121.88372288980793, 135.1862922791512, 105.95684466823455, 106.21001012863653, 112.08965870641894, 97.60696580333095, 96.13574750961797, 77.52128478019469, 141.5810892658849, 109.07123796401486, 116.56171767942368, 126.4805446132537, 132.23006463819937, 177.8503833278533, 149.81320288873488, 193.2628191671064, 176.19581776280558, 181.04767983959567, 233.3356826536117, 176.29710905013548, 140.40477045120733, 155.68972925986014, 159.33667059867614, 121.07861718823834, 77.96506174149053, 66.54206860450007, 57.06749716112691, 58.7073616827688, 52.306088862880586, 72.79990426955685, 83.79604155017485, 125.1891826814221, 102.42320491421609, 111.68576440503521, 129.52585712555918, 128.97012003006475, 114.43065474110266, 103.07762099850564, 55.266576197839555, 5.732234629892535, 0.20234640507448107, 0.1458183399611904, 0.5268843243679693, 0.29345809992763305, 0.3699264224738844, 0.11217945751043097, 0.24524283955895135, 0.23895227710806557, 0.16678736154590884, 0.11868361293548539, 0.24246111301885498, 0.16117334666271366, 0.2546310019228728, 0.13486907426868716, 0.1838332621921455, 0.1611279329705623, 0.11114588998738797, 0.2538612980635897, 0.09287475428033261, 0.4672115908995752, 0.15353460736092062, 0.2126166870396945, 0.2703811720974984, 0.18839922282964955, 0.10943270288407804, 0.1360395953299538, 0.16619171286302228, 0.21372457275227194, 0.2701685673767521, 0.18535958512896494, 0.13566600489279917, 0.17915283269699545, 0.10805124717374003, 0.09313821191749266, 0.11083714889302371, 0.12536832762341346, 0.20487732974992645, 0.2980068542303578, 0.11564390628688759, 0.16159115569485774, 0.12122263516029044, 0.08278133137331856, 0.16651792842293942, 0.12759358321707095, 0.13240270016174163, 0.1267682383918474, 0.1619600117086403, 0.1365130376671591, 0.09032032602737028, 0.14238376861378071, 0.19988136396052378, 0.20699781515905935, 0.1567070540641585, 0.1292842013701316, 0.09013165389337847, 0.13166699528453812, 0.15862421973818736, 0.061777514075079275, 0.10173010249291697], [0.07072918252238343, 0.032340926493728356, 0.028221351883163857, 0.014624584000557663, 0.029797826765946327, 0.06604985619384436, 0.04172445785614752, 0.06219554144228178, 0.04983089766615341, 0.022861408144836465, 0.05541311607005135, 0.032503911699619026, 0.03049801389176038, 0.03360291079227482, 0.05471097733525019, 0.010127456363050208, 0.0502368055223938, 0.01659501385274193, 0.024864697423312935, 0.10212519701810614, 0.02359920061163364, 0.05971870257429058, 0.07175888896228806, 0.0696977217411322, 0.052608958475532076, 0.03284225826181712, 0.010868412772974661, 0.01062168266564127, 0.011410491800145998, 0.038802449125796556, 0.021533094038585984, 0.02977563319877992, 0.1466699845848545, 0.03094597997504377, 0.07989899450612646, 0.03872703160009077, 0.0574331711827507, 0.05029353433318677, 0.024799317564635028, 0.04736344337523465, 0.030422898970784682, 0.05321696415663727, 0.03317541840876783, 0.0396985728143444, 0.0486616483108411, 0.04335707166202126, 0.044720842232627254, 0.06884528804690608, 0.03959731514295263, 0.030471039935946468, 0.07745657596857318, 0.0036227663522661337, 0.031062766248660705, 2.9475410619089684, 24.842007890824352, 64.34544717111896, 84.89039851773171, 85.43632968779534, 74.90769186327535, 71.04481620173301, 52.83220421883368, 58.71978775147469, 44.10369111645607, 34.66059277134557, 52.014064481181485, 54.14683365052747, 80.57178266586797, 83.08682995457804, 80.92099912704961, 66.86271452134656, 58.18964412135463, 37.18846228814895, 23.309241725552468, 18.056180015687023, 9.51964634080087, 4.87570861654897, 3.439945362267956, 1.8270074215627488, 1.1535174639955645, 0.5634564425676101, 0.3083742914661285, 0.8419085041649881, 0.7521592200763765, 0.7187403810601081, 0.6676370458256814, 1.8316602106055908, 0.8807723897118723, 0.4163443026763778, 0.5308065106791835, 1.3262103522016158, 2.550471684625072, 4.950364068631203, 7.883577692893244, 13.864944115761789, 11.359395827016524, 16.921430480095648, 35.856280249934045, 41.16944051557972, 44.845172051460516, 60.04743160740022, 89.16815111714025, 114.76455042439123, 109.59933803927515, 115.51733955260246, 89.01598668867543, 57.5589858331988, 39.082657214133974, 47.33548487386396, 39.97447475310295, 42.5355157544536, 58.7551361514676, 61.67230875261369, 86.2504489960209, 91.85898334749284, 90.00236080538842, 99.51319063863447, 88.61537148875576, 51.7124891281128, 20.601470739610736, 5.723951074384875, 0.2802167604527166, 0.5261832006996678, 0.03264921559621731, 0.053901728017315756, 0.014329862315207722, 0.03964806463749659, 0.032341148659226396, 0.05989638134656895, 0.07549627954440732, 0.06197593467790754, 0.020684611442829334, 0.04667297215952028, 0.02720335892762148, 0.05320577927294278, 0.06605495833942006, 0.049719186725034836, 0.030400868197302186, 0.07763997741764592, 0.00675955429605599, 0.015835142731966994, 0.017754970561532725, 0.05707223268766558, 0.0668738910087174, 0.04442710880069964, 0.021953975083306435, 0.018568056064747998, 0.03462406003006524, 0.020707913922266136, 0.011733301141629777, 0.016418597210318814, 0.04686810241471376, 0.029348073782579556, 0.03627035616626663, 0.06272751672734177, 0.09694422865586896, 0.010937032225962368, 0.07746645084191715, 0.04532313672825695, 0.03308651390515509, 0.014964999000151313, 0.022819799994448983, 0.031868114263840744, 0.028882416813904722, 0.03066631383262575, 0.025041721190416047, 0.02147545358316312, 0.014684581133957594, 0.04995083256113914, 0.060829461116584084, 0.05400033119404989, 0.04715843058581795, 0.08040591488562285, 0.02174695705874793, 0.03502181288035166, 0.04915152706446187, 0.03212544894326599, 0.04713101612944757, 0.0603674641329675, 0.020378005818553993, 0.09300927931983625, 0.07648225768559402, 0.1118290335721066, 0.03042321498205345, 0.02670127447814711, 0.07412495151642831, 0.02893799840803108, 0.01819664323251815, 0.05756677308630559, 0.08805011639431601, 0.02961540973985628, 0.020133363300814264, 0.019413882250627203, 0.06229028736631717, 0.0377536402835, 0.0628879355386861, 0.059288222447878895, 0.07074622031781944, 0.043523040780377005, 0.00490749508307706, 0.04830700322805394, 0.01977145953494455, 0.04517996638652779, 0.07288870777213767, 0.028464705457970984, 0.017850802415200782, 0.01308069562524437, 0.03680701224854396, 0.029542449441167618, 0.04414529952731344, 0.002869227905795279, 0.012354190506401562, 0.03057084970116135, 0.04512836270394825, 0.048818485661139416, 0.06142735443708878, 0.027480213527357387, 0.015538294195017267, 0.04608771162888697, 0.026350310447836117, 0.09741052339274077, 0.0502320634381425, 0.06713148807325671, 0.026914765945665782, 0.03160137202470534, 0.10437331267542417, 0.010379630482695516, 0.04475991271676556, 0.006929327998565691, 0.02177011972713855, 5.281406717915689, 37.66842703665457, 84.332378602797, 99.08836657001127, 95.38810453107281, 91.67670296084498, 106.38030375203779, 84.89628207299018, 96.91212577204551, 63.294428471596014, 32.41071731813493, 39.247102583608324, 37.26288926216864, 57.964896232851096, 73.32750228143507, 89.00231330625473, 71.12566409572479, 64.18581062747587, 44.975390818811235, 27.7329594473685, 21.377884303369832, 12.988365965504801, 7.135362048302928, 4.759430933383204, 2.134495992814341, 0.9478479227231396, 0.17673006431469995, 0.22512026852177036, 0.2789680677796564, 0.41555749973462475, 0.20391909165247796, 0.5982136065440794, 0.763012295769107, 0.3196509218504352, 0.10530725812479373, 0.23376768514994653, 1.2636196204731542, 3.245236455432831, 6.03654730704523, 9.443513135756216, 14.812690731017822, 12.652707176823771, 20.53474141705421, 36.79972794748122, 46.22480692402009, 50.65543782326483, 69.47064353573707, 85.30056861139114, 101.9976983531829, 87.66566368841356, 81.37300522096696, 48.31671676328106, 25.124200851686542, 25.64285978194206, 46.89162162042434, 54.92535744943927, 58.60370912859517, 97.97803771111273, 94.96434734713648, 101.62201373807846, 111.43904732119654, 103.39881604717624, 117.05297885402557, 114.19826999787362, 70.45196563966813, 33.858103290680916, 12.587755668547846, 0.7412931515324501, 0.6390216393816857, 0.046067463925048235, 0.12643960199408955, 0.008855920863307772, 0.04041889464602836, 0.09626139150632006, 0.12319741830710443, 0.03656250379619099, 0.0436644644416388, 0.04158100789232601, 0.0527371249852642, 0.06406147881681401, 0.025520786612985596, 0.039497405786307595, 0.06814037990425864, 0.0276971485600957, 0.04641798362436314, 0.03932067696305533, 0.08190111167007878, 0.032316419341030626, 0.005904876921821627, 0.07238835276615235, 0.0599041571390004, 0.056755934135928277, 0.05667632993971629, 0.026529921676903486, 0.03782032823730861, 0.02563321384631338, 0.04505948756911582, 0.04431646655223543, 0.034903559548359726, 0.05326745318128698, 0.02830714990024365, 0.017259374876777013, 0.050020086909494096, 0.06683904932992113, 0.01545977209799833, 0.07154736442551499, 0.012033498440418514, 0.036034109972177014, 0.01299632444692355, 0.010766096942637478, 0.03313727872145753, 0.01821278853552236, 0.05842413272588484, 0.017897736791881825, 0.003733456002420656, 0.027206647360036453, 0.016882700935727166, 0.05520802667184223, 0.04359274712060729, 0.032447198210584546, 0.04665488865406764, 0.02576829046912251, 0.03431609268450449, 0.12235175683012894, 0.13485367590140912, 0.12062951456755401, 0.16205289220858007, 0.15259207406591985, 0.20775014414421974, 0.13163121897847424, 0.14328628147561706, 0.1871480327099562, 0.1487446885796324, 0.13271432940758046, 0.17586473736070818, 0.12687883850547577, 0.10045717845881179, 0.10768553212044701, 0.13758992746232018, 0.10660934712617628, 0.1688365548128082, 0.09593458605870124, 0.2107791025792399, 0.1862321592747204, 0.15385526112250744, 0.15087422914803028, 0.0975190397472151, 0.13522116827868647, 0.17344255120523516, 0.1758299110036704, 0.05866091901196107, 0.14564483636809936, 0.2076073300333754, 0.13273291470062348, 0.19461947373084484, 0.2162965290969418, 0.29446863118679295, 0.12365156288949714, 0.09598491037444723, 0.2072187242729049, 0.16083436807797802, 0.1342165665400605, 0.20354174738449438, 0.18900055588493425, 0.19722944335831752, 0.09202103355839368, 0.2079914618403681, 0.14505825816623627, 0.12386787547579697, 0.14089450901073797, 0.16729579877949532, 0.184903824101052, 0.1801544466927167, 0.17264071761840777, 0.17943000330800013, 0.10973200577521518, 5.429830676124943, 42.54015984073762, 97.81029362832346, 112.68250142374347, 107.4384964666059, 92.41691697028376, 95.19526512392106, 72.7096034634498, 75.24157970182358, 59.08927894407704, 47.31510816081878, 71.72728507749497, 78.44572467188682, 111.67169878559729, 110.60304118740945, 108.11647030615039, 96.73306957367929, 84.84753485648864, 55.52798648034373, 36.42348635581232, 28.4022452369813, 14.64166166320924, 6.976472225881393, 6.503437324877709, 2.3542766897909106, 1.507596438450198, 0.6707257897623125, 0.432215775212934, 0.8129884398752644, 0.9427478609065857, 0.7738966891361821, 0.8923363337113012, 1.9853978772317211, 0.9721645953193788, 0.3288805653010646, 0.45881637041607215, 1.6287926512379802, 3.291388043472844, 8.243228639325789, 12.020109276617728, 20.681953853176488, 16.647437234078687, 25.27898934579665, 50.51155744060394, 61.151288555514434, 66.20697267593877, 92.10607697886806, 135.83139665665166, 162.41207553494363, 161.41348715751403, 163.24211182132845, 123.68644422100438, 86.00637558967837, 59.89836585137152, 72.99988239042221, 58.01796197891236, 63.951856936177904, 85.4292223530431, 88.2520031159924, 112.72846375742267, 118.672392137589, 114.26681733900502, 128.6926123403734, 127.83674332403369, 78.50773734431114, 40.443460787496264, 14.949726577728027, 0.725308757635855, 0.9654261472244418, 0.15125817709392117, 0.2848975576700703, 0.2732664124379235, 0.09419770385589331, 0.34344135332972775, 0.2397692945575522, 0.17898531991147226, 0.14694632782090097, 0.13207564190510782, 0.18914111769728123, 0.10424713799429518, 0.11496300733978711, 0.1650806861899553, 0.17929017694006044, 0.10497676779425914, 0.23315394147028848, 0.07582195884277744, 0.123828720721987, 0.08369463841400801, 0.09925314871173713, 0.22035834259323536, 0.18417142872368136, 0.12658741099820023, 0.17386403745941578, 0.0928696521347569, 0.14694571495056152, 0.07968306496378877, 0.13037547829651064, 0.18421436029095806, 0.12607703556216535, 0.1805627868781167, 0.19415776786063949, 0.25585064454184425, 0.14988153241574764, 0.14188679205554147, 0.1511227480706669, 0.14933100631160123, 0.08087600941859907, 0.12121213209484855, 0.07838436973191078, 0.18221571350530272, 0.09605288535596863, 0.16202508321692868, 0.1917166133681613, 0.07209930779232133, 0.14852114412332737, 0.11223950348193608, 0.11636101821016882, 0.1380178182115478, 0.13189023330567345, 0.20264023043695958, 0.13515062690261873, 0.11605000949554867, 0.1126642073053987], [0.037654864736982895, 0.05638477602793325, 0.046352161349908966, 0.03229335243363054, 0.041662672865054304, 0.04637693280294057, 0.024627526178054755, 0.037211276846186775, 0.07784364189231589, 0.0517903054283271, 0.09691059739599306, 0.016807450034144907, 0.016385122998467377, 0.012264575456239045, 0.030905375399837093, 0.020571012094977404, 0.12437357777549375, 0.07498228051249059, 0.020833314854591604, 0.03939100383450428, 0.015048819552776555, 0.0320410471214282, 0.04193148162636546, 0.02576905272660717, 0.04652670682257703, 0.011983878925562868, 0.006358075385627848, 0.021925786878132535, 0.059279783989392945, 0.01585082742460673, 0.008091396716002735, 0.10181238799686394, 0.038712242272712534, 0.011776917399988781, 0.026777726222550677, 0.059672488320258364, 0.0032252682262145344, 0.07379126659924946, 0.04046520849149074, 0.04506485018458578, 0.016355389210906242, 0.025845686416892756, 0.08051465340559522, 0.08378187284594582, 0.05557762962135096, 0.04515690714000695, 0.030574254961984775, 0.025879386624681856, 0.1387358724229759, 0.17738200513826263, 0.027387122353238445, 4.094528637586102, 40.98637565489739, 81.64445677111226, 92.96737455552625, 83.92553467904368, 88.02515675944667, 84.2898993338308, 53.9338920962426, 46.73325592471708, 57.577511187522646, 50.579767457900516, 65.62864665062197, 73.08009486044608, 82.2992572476787, 73.26403833204701, 69.58039929789882, 44.20925778727378, 16.625883809981808, 4.731661042859478, 0.4393473489870949, 0.38306323691241206, 0.6953595614721698, 1.056052203620634, 0.3708030109203631, 0.22071123333467593, 0.1240586466907013, 0.08070852727659288, 0.2082675446065203, 0.15777645151942007, 0.3485582997241328, 0.5785404073615229, 0.5004285197825201, 0.2861443198015613, 0.3246133636322714, 0.901211983253879, 0.3146028007951475, 0.319443495884057, 0.14117264489252723, 0.09916894032710022, 0.08193193904815183, 0.1269766909160441, 0.107627255812047, 0.49826450525752963, 0.1349658311735238, 0.37966692399594093, 0.8840323083343045, 0.21014970006240954, 0.31193604873072717, 0.9280022005400351, 2.3499733594156083, 5.324576814328471, 18.083254175801432, 36.40446678284676, 77.79163806669175, 89.54927998204386, 98.57053525986211, 58.99920563543997, 61.839170302114184, 52.46185794953377, 43.6837072526255, 56.73367600287161, 70.60838191739975, 57.98508859449818, 67.01095657963907, 89.15212431261617, 74.1895607979067, 96.82548061493905, 96.81779276940131, 98.1200118218699, 48.85507383654195, 9.032351663035731, 0.24693128202230702, 0.24300301297297403, 0.16229405668714356, 0.02036989677787548, 0.015356568563278886, 0.07584280409519711, 0.013991687165182686, 0.036399219816009847, 0.08991796898865893, 0.03259309199488452, 0.005920363868015909, 0.07295158060808336, 0.016050094554591325, 0.03084877682399125, 0.08989485611598338, 0.08366840756348065, 0.010148464409153788, 0.029499088864653345, 0.05361261409557155, 0.014392196974386613, 0.012984032566178472, 0.025790742590963363, 0.010120136392933708, 0.03351594066067088, 0.03880555944276914, 0.05770972509297633, 0.01847377553912661, 0.09599751252080164, 0.03567608644164378, 0.06266892249245318, 0.02529018648689793, 0.0634271809981475, 0.05367194377486745, 0.02342099898434695, 0.02907972658924278, 0.027442736506101587, 0.04708362210001196, 0.007483154505250916, 0.04057810303845233, 0.028565434528695, 0.036409259398257544, 0.039381799288094044, 0.07581394556308947, 0.014429851153474903, 0.04696149619356279, 0.06094924662442458, 0.06378579058594282, 0.07063935105238231, 0.008975915130107634, 0.05295394702003368, 0.07778442329576901, 0.02938981982879341, 0.04286559944551799, 0.05025558233741791, 0.03216671809974698, 0.06930176919746785, 0.020562935613035675, 0.0899914138379597, 0.02194741354023497, 0.06191117343522849, 0.046941217846207084, 0.06918756847059535, 0.026702770264819268, 0.07163047730442017, 0.09984428513674967, 0.01616804240902345, 0.028206344220727205, 0.053228191175167604, 0.005876060045744863, 0.0544394949270833, 0.03212460624654928, 0.019199034807482557, 0.028968779820828672, 0.015329362865867875, 0.026327002222739884, 0.07596097315751738, 0.014076634824666527, 0.02101307738602402, 0.006665764545511094, 0.03297663391417554, 0.04257831264347319, 0.04097976293715258, 0.025832412028384787, 0.045114159433832096, 0.033276453914661566, 0.009248462400489278, 0.08134260292976134, 0.06738760658810217, 0.0275315624857021, 0.0861266075122741, 0.01378239194426926, 0.051644200969847946, 0.002875054722666861, 0.08039150477176712, 0.04991689486609352, 0.053929828122378363, 0.018463165221375324, 0.027096769284276713, 0.03632902317950803, 0.08739923277208883, 0.0190196227612755, 0.025984189367943236, 0.18787678150880724, 0.10410829987977782, 0.046324654962987676, 8.262798324708017, 58.37909067830732, 104.0863290909798, 110.85109187710671, 97.38878788486605, 105.6255377492597, 119.59490222315635, 89.32362602603051, 69.80937942381829, 53.20555894605575, 29.838068062259307, 31.664729579802486, 43.456217627371515, 68.44424555378576, 72.08219682016681, 75.86494630382907, 51.1605175079838, 19.363117679472893, 6.142142415046693, 0.4191437411692835, 0.4650001708538302, 1.0510779027977297, 1.328207451489664, 0.48556387063957035, 0.1916636766925935, 0.27113313336045514, 0.1519465837026796, 0.1288906773251872, 0.17346000268815026, 0.4074344549688601, 0.379890437808729, 0.1378741920475037, 0.14938366719551627, 0.25414433690809435, 0.5972287851956584, 0.26097094640135765, 0.2053643931304255, 0.15232503113727416, 0.2268678529728805, 0.1623727185952087, 0.26004753466094693, 0.23271596900397734, 0.616922147812382, 0.428571219165479, 0.6492786373822921, 1.1711231450880728, 0.4748769747393747, 0.5253027511700508, 0.1349961835770838, 2.068234658048999, 6.576427730821795, 22.356576458100353, 42.07406851553148, 75.70671789107784, 91.17856979370119, 72.18462559484666, 48.01249381034605, 37.3317111692121, 32.39361382299854, 39.86698219853063, 63.840304728477236, 116.23267789040844, 103.29080966211136, 97.91338136119228, 109.25004313069006, 91.34109712416127, 109.93779151670395, 117.46976990853588, 117.47047593516689, 71.63030839735463, 19.60246462975779, 0.7192255905078304, 0.40871630392728314, 0.14964262023568153, 0.02357152185492939, 0.028566407460358836, 0.017051897199463942, 0.05751931010895679, 0.04394087279515882, 0.08640305800062996, 0.009232967314610799, 0.0633653270591411, 0.008130784169019712, 0.038983345467356906, 0.1448864859318541, 0.055365001917966915, 0.06179111596617488, 0.03273420539053698, 0.02829840500658799, 0.05740873297796615, 0.03833864417467867, 0.023608117875072266, 0.08149012848134003, 0.04251328710046026, 0.046653222412832325, 0.06448641629709352, 0.032036793418228626, 0.03011337838195745, 0.08827510875679793, 0.01956639120415334, 0.02628717522677635, 0.05607719938721388, 0.027477604997975212, 0.02222202350235274, 0.014925430558862226, 0.01685190420117109, 0.06583548947087219, 0.032078137268282236, 0.05081562708402353, 0.027414624909720114, 0.013188883519521164, 0.055097514658325145, 0.026960447768590627, 0.01673232170663053, 0.05026944469840777, 0.027873668624388597, 0.054239990309842175, 0.012743799842052884, 0.035038597866772644, 0.08359811899642791, 0.070846225435455, 0.08008297818202166, 0.034440106997687014, 0.008618589697195398, 0.009949965282313285, 0.13568190887810724, 0.24408992319818468, 0.19865533216826378, 0.17476425205747928, 0.1852072408843425, 0.13490489654002652, 0.1639385563471625, 0.16441149306633782, 0.23347329288240404, 0.12663208924594427, 0.21828581428816243, 0.05409859729209735, 0.07342808729698581, 0.13669588753292639, 0.0881430735030482, 0.10246463525559633, 0.23295371673039852, 0.22003365920916682, 0.08815110210449466, 0.3242469897433635, 0.1115232419162508, 0.1966263023355315, 0.1020123446059804, 0.07525812579138626, 0.22176103426083443, 0.09939042400688895, 0.0918612122956303, 0.11024246548092174, 0.3081762424159435, 0.11648604375941139, 0.12141403456729268, 0.14041145993096216, 0.17675186717702498, 0.15247593513659893, 0.12372811805577048, 0.16791308178536354, 0.1245338203866155, 0.19456420814798725, 0.1316263466592758, 0.21282428154541602, 0.13486763402338953, 0.2189642617539052, 0.1776772707460388, 0.1413829360277422, 0.10981564725478811, 0.16909915443149307, 0.24128752760589126, 0.10032831480906856, 0.39468341176548316, 0.18254130087312193, 0.16071709533852918, 9.256276834395624, 66.44705310944589, 117.85912006132065, 123.52899243754726, 106.82986228696763, 108.26605381504183, 107.47699845221736, 72.52158072686964, 58.38634314075593, 68.65586526932256, 66.46237388733896, 93.58045670293993, 110.99076747894289, 121.38860994769682, 109.35306810563611, 100.93084504527431, 70.32437878270304, 27.788417839234878, 8.048146617028022, 1.433332733088924, 0.6633204774510476, 1.316566959984841, 1.886447754598433, 0.451104806796197, 0.26010131403323145, 0.3743979244703247, 0.14805482640381784, 0.289541092370787, 0.29935642536128726, 0.7199157437970563, 0.9731498456770374, 0.6434535499541991, 0.46113507341473337, 0.5584262479697505, 1.0985715543070147, 0.6600215189879941, 0.5663930720859959, 0.8587900789514665, 0.4454190247962552, 0.1591972994708246, 0.33897389627752766, 0.40564291239265476, 0.6593832145294836, 0.5948073957716266, 0.5973023296363893, 1.22287318110466, 0.5607321726218347, 0.7838441876153793, 1.4516461568494, 3.064908673686366, 8.940306382794535, 29.417937109547278, 56.45350894620342, 114.42873277971822, 127.39338997871646, 137.29094197673183, 85.16779638105824, 91.09768267600768, 82.83782220655873, 64.4485309816176, 76.91767907911732, 92.33994437802224, 77.23938403591033, 91.92645595919703, 111.25988129646548, 92.4938032704015, 121.78282383949526, 129.11196078023605, 132.8461591659054, 81.12149500077771, 21.84051021452873, 0.6863238914839683, 0.41142494567940313, 0.393148294139293, 0.15203036307807893, 0.14840607771710043, 0.2698664222994159, 0.1578481726708912, 0.24405618468599938, 0.18637698053592638, 0.11811610266205766, 0.20507654325375635, 0.19166954492609348, 0.08654424800507485, 0.1686963607226649, 0.19761417271389117, 0.21571240237643644, 0.17491461979525705, 0.1678059214065152, 0.13550517239397572, 0.11762976706508668, 0.11507356148814002, 0.20814391333729992, 0.13151298096824077, 0.10621321838228934, 0.18957616370772162, 0.14321866655542007, 0.07579168304800987, 0.1701126121465237, 0.10348411442171182, 0.1279990352509964, 0.15110785532141888, 0.10715554483355054, 0.15340948988112713, 0.10320431612912687, 0.1215010927990079, 0.11396028251657564, 0.09961357009747338, 0.11893055371699796, 0.11051516979932786, 0.1497061289246044, 0.14055709324536786, 0.13199521799481687, 0.13605484047964697, 0.12913276110925984, 0.19929501558503798, 0.13706678134058753, 0.1761801817244099, 0.12865980906832603, 0.21296456756611026, 0.16999918516845475, 0.19699794690935843, 0.11785424614865934, 0.12571596300169346, 0.10662953354298108], [0.03768106111355367, 0.04869154106164652, 0.10511074125045732, 0.046454847775279515, 0.035342596876885624, 0.02912881367299105, 0.027078099721562, 0.014517609398030948, 0.0778886572187466, 0.056710248482563806, 0.00512830795712709, 0.11326060675445104, 0.0758019256435575, 0.024490212578506722, 0.05225286931700764, 0.02263922732503664, 0.04383560848392306, 0.08882586468732165, 0.01471959997058636, 0.0311826590088106, 0.024244779074985175, 0.07437658075603747, 0.059627810072514324, 0.021506512702833262, 0.08628138791649573, 0.09569462433817888, 0.04265516275359739, 0.06407896860412533, 0.042330184425677986, 0.013586109684359644, 0.03608156528864657, 0.07016640667232775, 0.11937667735882344, 0.05877515038235053, 0.02590261249532623, 0.040359802453988985, 0.0412290939129889, 0.037301361125202916, 0.026668223529873837, 0.05113101016069132, 0.10080629238678564, 0.03298983743955051, 0.05949600847558149, 0.13390487600718776, 0.024149943135618687, 0.032486885395501895, 0.07514188727063519, 0.023581867872346795, 0.14110668472224666, 1.210487561841165, 34.143298825910016, 81.62340933276762, 89.02296850758215, 84.1344165802002, 64.23650726195305, 64.84314103280344, 48.98227237885999, 35.41468804882419, 44.12169871791717, 52.39238492904171, 68.56106942699802, 93.84099621926585, 73.54256583798316, 53.623997396038426, 31.617814110171413, 16.963080167770386, 5.325548581538662, 0.496757549023436, 0.1671522951895191, 0.23746490208131654, 0.02780744415377417, 0.08638615810102032, 0.1174012047328776, 0.38032281783319294, 0.44153299783506705, 0.23436584660122473, 0.16440369429126864, 0.09679754580100698, 0.25737149761088435, 0.26938902694852124, 0.20571621134877208, 0.26429337779841117, 0.18129642331792464, 0.2680897111854246, 0.35963243774829373, 0.4930867314819367, 0.33685186337078776, 0.33036037137912166, 0.16351152361641008, 0.048492480775401484, 0.17874653030547405, 0.42734774610688614, 0.23766172539082267, 0.4319207087880181, 0.2740086290624834, 0.3715407229479282, 0.1979361901119832, 0.21365203954760106, 0.04742126769175933, 0.039366515834004655, 0.13725137788682215, 0.060732451402732444, 0.22825958958316236, 0.2314863672419902, 0.7332958677603353, 6.202981808493215, 29.73739454823156, 55.02202818470617, 65.2724640600143, 58.62614508598082, 67.31410872551703, 60.765805859719556, 29.359429074871926, 32.302954120020715, 44.96286669085103, 56.68810982857981, 69.15593608733147, 77.21787375788536, 64.82758099032988, 88.16542856154904, 88.56514946106942, 93.68776490611415, 42.62233349584764, 1.3529605490546073, 0.27559957917659517, 0.010158924382149933, 0.03732288053499595, 0.17873451804682133, 0.04675243079902665, 0.024912028250494794, 0.03475381617224024, 0.03895163708817094, 0.03302789285718914, 0.03791931828844451, 0.0761551074984093, 0.06320275937116916, 0.043489443994457685, 0.04164322572309644, 0.11592618670434722, 0.02312671396911385, 0.06587403901522199, 0.03339619728766623, 0.05529856677317331, 0.03566584001565653, 0.04941843592772081, 0.03048924410024718, 0.00459504995359889, 0.03223734374548639, 0.03671504722367372, 0.02196540894557632, 0.05101443839169318, 0.025215904686539888, 0.08916587749075505, 0.025642925925973444, 0.08036862172546887, 0.03816874502527137, 0.018645676093236096, 0.06790634004339095, 0.024062375455433806, 0.0499928831273029, 0.007811137334248352, 0.007628462232288815, 0.05839624712544103, 0.0255501565087827, 0.026785155360196388, 0.0420502022719912, 0.018487689611051353, 0.027623106162213994, 0.053078267768385916, 0.04269718650668379, 0.03418881483676453, 0.06335603441261957, 0.021462343903558872, 0.04322983211867752, 0.046662606989904765, 0.03613866948252244, 0.0394176024072353, 0.036833469095008994, 0.04595703618120282, 0.06213306697205671, 0.024275951192624146, 0.01917678569894164, 0.030933318456875223, 0.004335140261138159, 0.03995045103252896, 0.06428721811502211, 0.040727206731155034, 0.020590135564787254, 0.11358018799294388, 0.04074966459865532, 0.10675635939884572, 0.013112732464627875, 0.03800673658148416, 0.036307932778952584, 0.012449193069891585, 0.009587481204840926, 0.024989441435243336, 0.013825557168362843, 0.018325305784181244, 0.05941924263512897, 0.08790059901413419, 0.03944819229805181, 0.051982670106113925, 0.058614731571006204, 0.0166309280546322, 0.03212074707863072, 0.04461249441749627, 0.0426471647956679, 0.039421566912243446, 0.02725206488262742, 0.0602887869031439, 0.006011235302374248, 0.02955351749645366, 0.06551311201145572, 0.11289365829959994, 0.01635939776597004, 0.05173631538186343, 0.0460554133619993, 0.07767937731959167, 0.09796036001775535, 0.04186209704306337, 0.024721638164332798, 0.03496937033149504, 0.04439578346547581, 0.21774984385457732, 2.342873133959309, 48.0396052329771, 102.75830868751773, 104.20259598762759, 94.18534894143382, 91.23884093376898, 108.42972647759223, 78.97042797457787, 57.02028359136274, 39.42401324549029, 29.3907452783277, 50.99868835941438, 66.95729071094145, 73.366561243611, 61.14593452022922, 40.653703751102576, 21.344406873949115, 6.27202925182158, 0.29208229794617624, 0.27013473693401585, 0.14647981091853113, 0.023148754318695397, 0.1334744724895685, 0.19990358051032792, 0.6905563740480332, 0.5317320674657822, 0.1508384528419664, 0.17772879781982592, 0.08793046112142264, 0.1994092392945482, 0.27392043702064023, 0.18648403366246533, 0.2283615405641256, 0.39642880520512985, 0.264766268552311, 0.7170223216375997, 1.0948059563675234, 0.7525243069375716, 0.40751330073802705, 0.14967105741943085, 0.18431208246657926, 0.09998601140274156, 0.20813878054820723, 0.25711902567455847, 0.4909962613976771, 0.23667572426699826, 0.43894840103964655, 0.5802326649427414, 0.35540458235529165, 0.1942970426452737, 0.0733678957687751, 0.1418377930719045, 0.23903115352074947, 0.4061874783327503, 0.12827433660746584, 0.15566204884840598, 6.916473690540561, 33.95389149265905, 56.20931786875571, 72.28471663690382, 66.8151597053774, 46.93529721229307, 45.92627533020512, 27.68198040223891, 35.2025858817562, 66.94602566380655, 93.31501422389861, 110.6812846276068, 108.1535053253174, 77.92059775321715, 102.66330888194423, 102.11410645515689, 110.4008508497669, 62.518046286798295, 4.8527299011907274, 0.3541058794625344, 0.03172387331423741, 0.04359940059422966, 0.16486109474733954, 0.023834659650381056, 0.11188043807182582, 0.030623004967046362, 0.03490046455314563, 0.1490780440790038, 0.062128393835718596, 0.007685765609024994, 0.12228266336023809, 0.05980908562759719, 0.017852870852596337, 0.02576448875779827, 0.08237355809298255, 0.050144829006204684, 0.0598580539677172, 0.0883598457421026, 0.012635654082611926, 0.03818893527251579, 0.01725710151086171, 0.06646138330500934, 0.06837030587297294, 0.10527831532301442, 0.05552545520326784, 0.0062674443113557516, 0.028614937215142196, 0.0480101709704726, 0.022176134835688338, 0.03213369971021049, 0.021578253006502505, 0.016058460234724466, 0.05321531706760007, 0.012616069044827694, 0.023666493774902438, 0.06477061959524309, 0.012884190242226808, 0.07750071029389098, 0.02681490446951601, 0.046380567890141285, 0.12460551089456967, 0.006250657888519908, 0.02912982107861148, 0.047051193598177166, 0.05590730023780658, 0.02580518526355586, 0.03171997201148301, 0.018561770313329274, 0.08338013633845315, 0.03081092058921293, 0.019818403487724644, 0.12769427015295914, 0.18378006504668346, 0.19714126663823284, 0.16084959790591272, 0.16520019590614304, 0.09932253329503922, 0.12490321266194507, 0.08652377047485883, 0.18868190927370904, 0.1920785899123838, 0.1094695823567529, 0.22408047270390297, 0.1930470629445007, 0.1497466702975573, 0.18695519305765632, 0.11149319594786053, 0.12173070467167324, 0.16164792281004692, 0.1076543523419288, 0.1553958332947185, 0.1412608369343704, 0.12467196136112176, 0.15492327961950533, 0.14626213469572608, 0.17568418575871378, 0.15520094052678154, 0.1351768271096291, 0.13432725092336056, 0.15412812631937767, 0.06884400868007252, 0.13074560601624752, 0.12817493669929045, 0.20798819830581067, 0.18980983584638567, 0.12369006646857147, 0.16702434318440576, 0.17121084515125523, 0.2656504259474816, 0.17848940055456855, 0.17246281668063135, 0.2277740430567534, 0.1298297785462872, 0.15903389291657558, 0.3215065400206274, 0.13342130598762345, 0.12344401434905107, 0.11170390843143387, 0.11305323441422756, 0.42563820558209575, 2.4849703090806163, 51.45214573029549, 119.33746922400691, 112.49524747171711, 101.41783083638838, 85.15667253924956, 86.91696951466223, 66.97423535008585, 44.72607320354831, 57.49478447821833, 82.49492860609486, 96.85027783916843, 129.12910153788906, 105.36771251309304, 75.63056115181216, 49.139076971238666, 27.368139797641387, 8.775489368746358, 0.9493991588392566, 0.49925165551324047, 0.311031298892152, 0.15007064888073554, 0.2958560164176649, 0.5298769089483446, 1.360623634630634, 0.7053324327834192, 0.3046286118126685, 0.48758576053284836, 0.31953950202272785, 0.27914402285410517, 0.447103590854714, 0.37965681163534043, 0.5766614694749156, 0.35694993491615024, 0.37336051884678106, 0.7305658368333694, 0.6747484868091922, 0.7736818780822139, 0.5622335210923226, 0.3204868463498931, 0.14342805370688438, 0.5454432026993844, 0.7265205248709649, 0.5298527618569713, 1.168591132567775, 0.42411013596480895, 0.6858318791754785, 0.8416206389665605, 0.5607370755845501, 0.26034980231235105, 0.11068432967388823, 0.2062899345952657, 0.27413111119981737, 0.609038919210434, 0.4630783626869802, 1.0615165555669417, 11.27153669634173, 46.284815265286355, 81.74060975351642, 95.27296727703464, 86.11430352733981, 98.66061641323952, 87.80536282447078, 40.769762762131236, 47.50815545358966, 60.982850213204664, 72.83157348632812, 95.45254907300396, 97.52801633650257, 82.92329849735384, 107.27746748155164, 110.215542393346, 127.11761597664126, 71.23902059370472, 5.50584375858307, 0.5458928656674201, 0.12286819968252413, 0.11704148814803171, 0.4312529252661813, 0.1341571794041703, 0.16353677387439436, 0.10940747560873147, 0.0996024618225713, 0.22612378241554384, 0.11768327064571843, 0.20602295295365397, 0.33444481511269847, 0.14648155759899847, 0.10564719431943471, 0.19857602674634228, 0.13377191378704964, 0.23792228721562894, 0.1707655029191125, 0.2523356033188682, 0.09383491525847105, 0.10525976067348834, 0.1279503197198914, 0.08177160450647916, 0.12060389658736607, 0.20324376982546624, 0.158913663077739, 0.15975131893590575, 0.1620232752494274, 0.12367066912232869, 0.15273453577631904, 0.15811475594678234, 0.12488956863601362, 0.06878689682531743, 0.12119340124509989, 0.10598716115759266, 0.13043221476818287, 0.14498005591092572, 0.07414921352099027, 0.17968327197576725, 0.11777569915378287, 0.1417080943863238, 0.2230078423576009, 0.08677435783489097, 0.10191024040743228, 0.10891609915321875, 0.1712544202323883, 0.153671522594748, 0.1474981256310017, 0.1130816639370976, 0.2461522318903477, 0.16762446582077012, 0.16367883721907295], [0.05548068119453327, 0.027585330366667722, 0.021427260907066446, 0.014012491240376427, 0.04271982057440666, 0.03598848943628612, 0.05440149313559937, 0.09561413147997472, 0.0479091048210619, 0.05717769618176165, 0.017180645936018518, 0.07263153971683595, 0.014096761869657186, 0.06844052549211249, 0.02137387415484315, 0.017428381533752528, 0.07840953572022338, 0.019736290353560643, 0.06994006599509908, 0.05684232587114938, 0.0019859826340595443, 0.04506077459682861, 0.046896007167355674, 0.017819074883816705, 0.03130189484856542, 0.014346301604452875, 0.02004225820963902, 0.0346342719820959, 0.015254895289188192, 0.02095575102665011, 0.09693670567245254, 0.02575219687705319, 0.09666051565399093, 0.04323719039319023, 0.04275194647151136, 0.03496293902337071, 0.023860574489639654, 0.07230720873321257, 0.12685423942222712, 0.07906650974144859, 0.0514338638693575, 0.060092009558913216, 0.021476439921365633, 0.019557150268566706, 0.020345809058316296, 0.10799854798542877, 0.13085302686499012, 0.5111362532742563, 15.668763710606484, 64.16332760164815, 87.1205013029037, 75.29593590767153, 74.27826127698346, 75.18620367973082, 44.03276681900025, 27.69577733932003, 37.87953684406896, 53.660667634779415, 75.37730939926641, 72.48056057960757, 56.886224823613325, 33.81562794408491, 16.117895687780074, 4.44641157504051, 0.5298976852528511, 0.17863685715823405, 0.44732333551491466, 0.07348417259392238, 0.04823618222989383, 0.09289658012529535, 0.13519165857184318, 0.13980284904039678, 0.1849521489273156, 0.44711903518726753, 0.04762718446492668, 0.1262200641776285, 0.1385118683139163, 0.0981202272457942, 0.09617303092513355, 0.03920085315081862, 0.055152332079747034, 0.13403082086193946, 0.07745166534497853, 0.08346589988157635, 0.20314355020321187, 0.46059951666862736, 0.20140944889956908, 0.16340742758925886, 0.11867818903298148, 0.06617494303012086, 0.17978700028071481, 0.10208284001677267, 0.1916161792412881, 0.10888623704593028, 0.07871188764129916, 0.18164818024923726, 0.23988682776689532, 0.05160014325332257, 0.23962010659517782, 0.09902496942349019, 0.1924300557302852, 0.023784789241730206, 0.07974879530769202, 0.050950427915179924, 0.09184053558255396, 0.16383075245445775, 0.3083593374298465, 0.9112237105446478, 9.801643183154445, 31.166978843750496, 60.10098764973303, 65.12521436137538, 94.97099968694872, 65.76969115964829, 38.02658650182909, 32.470974729907134, 23.48334397039106, 43.433883651610344, 79.52680833878057, 69.17838773419781, 73.14774790117818, 83.38702463334607, 93.84818984616189, 72.78739190870716, 12.695503177181369, 0.4256320462351845, 0.10856366806453276, 0.09495495878640683, 0.035591406912933436, 0.03293285965018215, 0.09426473654926786, 0.06185257153946066, 0.04764478916542665, 0.057517088453976385, 0.009225779494661237, 0.04937727402354922, 0.09907782949026554, 0.08160963053664855, 0.06538978717740505, 0.08482457213704625, 0.03083866637861056, 0.01665799394099703, 0.05000886372140339, 0.031751651662371816, 0.06313991334830081, 0.05061245290562511, 0.006017218927867832, 0.04448084220770867, 0.03106053501758124, 0.050419954162451534, 0.04656190090181847, 0.04525890791668527, 0.044954487558213935, 0.05161494024158005, 0.03313284307237595, 0.07248736196948637, 0.07674035270728412, 0.07434339382715764, 0.02658996764840859, 0.04280559943928834, 0.04522086782080512, 0.02238497806472644, 0.04441097115857467, 0.012323678181987378, 0.03934035776183009, 0.06478142143497545, 0.04453098266235283, 0.049301312575417186, 0.03021697262151828, 0.05537828588257394, 0.05987518752414373, 0.03220327964593326, 0.00253194788162927, 0.05461856797938386, 0.01897600171486697, 0.020077053923159838, 0.034010940712065466, 0.04925233274397831, 0.01047614032417656, 0.03193240627766617, 0.03328393093280254, 0.020915027707815174, 0.03639766465752356, 0.07751911172583219, 0.03590659080674091, 0.06433106132692869, 0.018276933077422362, 0.050565656424770435, 0.019201156871032812, 0.015159243466182342, 0.021387152373790744, 0.020637280615647475, 0.04220443875378659, 0.020334756324788737, 0.05414117645892886, 0.00518187090957297, 0.015924375695777277, 0.09192426899267782, 0.06108686665914232, 0.04727245894290748, 0.03576307955588545, 0.032939922980844014, 0.09567740268164104, 0.04691281513641438, 0.035296547331757126, 0.08275939061516717, 0.05699197731671795, 0.05688654829657847, 0.046281857461097746, 0.08746028997965398, 0.007536414374161753, 0.009896639817123933, 0.012605926040710222, 0.034672668308860836, 0.08726810150208973, 0.025569513635409456, 0.03692403600941743, 0.05316036175035181, 0.05763578228652478, 0.05212539228640738, 0.05816805251543561, 0.1382885843275055, 0.11873026769007407, 1.9301794853902634, 24.696321256699104, 87.39379636702999, 101.5961104054605, 87.02750975085844, 107.8029631030175, 113.81931412604548, 69.00809411079653, 43.05028369349819, 33.463795261998335, 23.178595419852968, 49.61713544784054, 54.55714887188327, 58.42653566791166, 42.0581123136705, 21.287728624959147, 5.684380733197735, 0.5121037916791055, 0.4011034737190893, 0.4822715311761826, 0.06876989733427763, 0.09817233654640375, 0.04785997177203817, 0.3093941077109306, 0.4711081898741184, 0.5019933922636894, 1.1127249367775456, 0.24138914150816781, 0.3953968234840901, 0.3717749926351732, 0.5215711675343976, 0.433444457669412, 0.8624999056900702, 1.0268359390958663, 1.391528234366448, 1.8893837712464796, 1.3379036731296972, 1.675545587655037, 2.3304411816981534, 1.136762446934177, 1.3286613432630416, 1.0567326122714629, 0.9239684105400117, 0.9207808719046655, 0.5180692877019606, 1.0113178782405392, 0.7177555597116871, 0.6698596813986379, 0.9976896030768272, 0.9852791012775515, 0.47425616772905477, 1.0812777016432056, 0.5719220818531129, 0.13574532563647917, 0.10855793772685914, 0.05175427248280856, 0.15860227898003595, 0.06644731026984031, 0.17034888898413028, 0.4762672404608419, 0.9674282720492733, 9.95840561005377, 33.46054753949566, 66.75632415279266, 67.96713629076558, 59.77342267190257, 37.754656422522764, 32.191643138085645, 36.1481555815666, 35.11122995807279, 73.83948141528715, 118.82255615726595, 97.9037872437508, 100.52102796493038, 98.92609027124222, 106.8083284747216, 94.62831789447416, 26.5057086560034, 0.2037340967405227, 0.11691349017764292, 0.1170455330922719, 0.07874404035148122, 0.12217986968255813, 0.025382461777377515, 0.10269037072336483, 0.02678537369525481, 0.07467192297260608, 0.02539214704396023, 0.04025382951142327, 0.12739063120417057, 0.08052022286480473, 0.01865331015940155, 0.03984942701795409, 0.04273043855303719, 0.015592279453431408, 0.06114928367277307, 0.055116938817645275, 0.04896040344911237, 0.03537186909647238, 0.027419497228918538, 0.09714193296648803, 0.023018898585090236, 0.04696172601994007, 0.045050712031943184, 0.0483001965368467, 0.06827403926440785, 0.025869381516390753, 0.033373724098407456, 0.05643002118074125, 0.01602573008576949, 0.062147017433157856, 0.03968860601044951, 0.07530656553083852, 0.02213327413154466, 0.016544141784130086, 0.12144122302772538, 0.03240880188381961, 0.014057500821147716, 0.01766109797773102, 0.03236426536234156, 0.046165423587925976, 0.08540022592510908, 0.10498316462842688, 0.08956266507025688, 0.01655349188724593, 0.024591732635012558, 0.07830124919212635, 0.009197694711357115, 0.015838502027514963, 0.19911014324715062, 0.20819312682555569, 0.11520458550582971, 0.09818968077700946, 0.16778929729855832, 0.10883387493630571, 0.2742086392977546, 0.17548226030363193, 0.17209552348621432, 0.14497248696223383, 0.12365971406501149, 0.20630412254362337, 0.10710289927139398, 0.12811220942005036, 0.1574360326893868, 0.09162020103465165, 0.17432427244080653, 0.076318851131345, 0.16084878585271298, 0.12337665989874833, 0.10199920619807898, 0.12234140698227192, 0.17918283270011026, 0.19150799230462123, 0.09962899910826838, 0.1000218106914432, 0.1468231102391597, 0.10700061121174406, 0.11594933022053973, 0.2095400932575426, 0.12357727534347966, 0.2972750870450851, 0.1297591758831855, 0.18428620401649706, 0.2083741227585462, 0.1711868053121913, 0.14606586296952542, 0.22071707092465895, 0.2510128759088055, 0.222941208029947, 0.18244920178286492, 0.17823931881256644, 0.2660241542804626, 0.27619645360016054, 0.20874130870065383, 0.26336212131765585, 0.2680426120998398, 1.8058253968915634, 27.005110709897934, 96.46099044430642, 116.78124489322786, 93.14223381780809, 96.32748080838113, 102.37351632887318, 60.310312778719016, 36.74317913670694, 54.46240794274115, 76.15861415863037, 111.8631104500063, 104.99551880744197, 84.79633223625922, 55.035022997087054, 28.789908770591985, 9.959916703162655, 1.6893374991993753, 0.7106318613213878, 0.70931363850832, 0.14463317129881154, 0.5098923103463265, 0.6962853021198704, 0.6782696107702871, 0.6211907284394388, 0.713297724723816, 0.9558343586902466, 0.26250152878703614, 0.34988436727754535, 0.4878542590285502, 0.2725577811079641, 0.2673774026334286, 0.3899447902316048, 0.5459885960144382, 0.9959658439601622, 0.719243057312504, 0.44917058800497367, 0.501412391181915, 0.6871911030142539, 0.4034234943889803, 0.42109809275115695, 0.4995572020209605, 0.5224122095011896, 0.43377059662053663, 0.3767624701703749, 0.37129192823363893, 0.4770439003984775, 0.3805098965043022, 0.6622587408750289, 0.627870586129927, 0.45416879077111527, 1.2120269695597312, 0.5270201364351857, 0.5636953394259177, 0.21156927630785974, 0.2301453609740542, 0.18432176581794218, 0.1296680267419546, 0.4347898919255503, 0.48202037691108646, 2.5610064354635056, 18.937636613845825, 49.8145914846851, 89.7236999388664, 94.11094157926499, 131.9502741290677, 96.31664722196518, 58.349472861136164, 44.87868085984261, 29.057720361217378, 57.15007482036468, 103.16860429702267, 88.72896332894602, 94.28562825725925, 100.93865840665757, 117.24835211230864, 105.64816198041363, 27.599083069832098, 0.37513349145170183, 0.2242612234887577, 0.372284165313167, 0.19811637399177398, 0.18492006516504675, 0.16495026738172577, 0.1661402930415446, 0.17736237796564258, 0.19572253308949933, 0.33850259898651036, 0.13392571359872818, 0.22274841434292256, 0.1390327161718761, 0.18735974876871034, 0.14830009711365547, 0.09678410095793587, 0.1149896901821898, 0.22290209158053323, 0.08502657420092052, 0.141622721548042, 0.11919878408192627, 0.08311570576962926, 0.12009446343947804, 0.08752099478677397, 0.1542715226570445, 0.10664346868232374, 0.23779153132871275, 0.1136589035271637, 0.12293106485759059, 0.14108998400549735, 0.11966504051440185, 0.18217756232667356, 0.25024583803549894, 0.16244119153388087, 0.19379804361491434, 0.16904690723505714, 0.15793129321067564, 0.28763200126348004, 0.11036900022337515, 0.12215700195801836, 0.1366117557570819, 0.14888558747066608, 0.20444571581338683, 0.17217079928565412, 0.16113950089821893, 0.17172173386619938, 0.1555112521013906, 0.09706710915892355, 0.1222725893040338, 0.19140755817774804, 0.13527897727345267], [0.06206083637211592, 0.04630129311173674, 0.09073706253642037, 0.06315937198157753, 0.03616378184468035, 0.05495795259071935, 0.04369609621203235, 0.01250042328460803, 0.04453073368377743, 0.04193835726548587, 0.05392982046149912, 0.05099239421167201, 0.024842055694710825, 0.027115789332216787, 0.07328195602542932, 0.06331922388785789, 0.04689854674882466, 0.03501495639342935, 0.03518400901568032, 0.04934712080284954, 0.007266421528202632, 0.03004890825268963, 0.02842702925385487, 0.01739823022827266, 0.04718030622649578, 0.042021941288464496, 0.06707285936441153, 0.046803808485668515, 0.04447490119585588, 0.07650786800490272, 0.07797772260082346, 0.057315488586262356, 0.08600116061467318, 0.05529701927556627, 0.06152462462083467, 0.10742002136764989, 0.1025988385381718, 0.04532859893515707, 0.04725017727562978, 0.014231293612430173, 0.1286930726059983, 0.019000016656073353, 0.054119530644628315, 0.14217304846932813, 0.014794397922683389, 0.06528713139555146, 6.543425398488199, 54.04516189329086, 90.58246366439327, 74.7093846721034, 75.83796824178388, 65.8041452592419, 44.05490075388263, 29.93196960418455, 38.46869645580169, 57.898812140187914, 69.08615712196597, 93.2621406739758, 55.592387876202984, 33.30091884059291, 10.972134336348503, 2.09629112674344, 0.20284938776204664, 0.13341159199274358, 0.12271615421219219, 0.040281772568461396, 0.06554523407812081, 0.1953095504112782, 0.09015907218018848, 0.11332990706808145, 0.02583878396469499, 0.07977435200084602, 0.03397823258813831, 0.2593309973036089, 0.31784715251095835, 0.07883894332354108, 0.10310006688439077, 0.15377963292262248, 1.17949262501732, 0.23782436585714742, 0.4434680133577316, 0.1502912822029283, 0.4285312906628655, 0.6596047671571855, 2.4106114862426637, 2.987898573760064, 1.3061116371423969, 0.5352173385120208, 0.11313136772162492, 0.1118054074205218, 0.1880326650796398, 0.10989068556697139, 0.07067524227163485, 0.07363300049497236, 0.08166789918416932, 0.13515749105042027, 0.05199903757461617, 0.09175221330576366, 0.06323657066170728, 0.09289812762290241, 0.08868992238515809, 0.23182606594937466, 0.11264437328903906, 0.21998504326949198, 0.3176662331867603, 0.36483742296695715, 0.2961405721162596, 0.126601223563475, 0.2885584773555879, 0.17306477792801397, 3.4772044468310574, 21.415125246970884, 50.2348538367979, 62.32568933117775, 61.857581907703036, 78.50996525056901, 73.90220795908283, 35.69290568751674, 23.347378930737896, 36.25234550045383, 51.73935736379316, 74.15390645304035, 74.18999225862565, 78.92477943051246, 80.38139081770375, 31.586195884212373, 1.4958065291566234, 0.434208890843776, 0.07329051322754353, 0.07356734675986153, 0.07425185398108537, 0.022059553490591147, 0.03823036530746087, 0.015805041222202203, 0.046500472141610044, 0.04112083036752959, 0.07352933347705873, 0.023831987918745128, 0.052749987601512865, 0.08367203115936249, 0.07831628749807996, 0.023301818685966636, 0.021260510379027937, 0.022385918437653494, 0.04485845843690538, 0.03881058880999204, 0.046013140630337505, 0.006148893641488206, 0.04205426253798989, 0.09537508140408224, 0.10221176495354983, 0.022804683164483117, 0.04115195268945348, 0.04543901518768361, 0.08644277199862466, 0.058607829118808435, 0.0370090794298918, 0.06550575756738264, 0.027275248618435957, 0.02889786880733746, 0.05287658746143984, 0.039840157354070295, 0.07049443786062541, 0.04449553960453599, 0.07790842994807229, 0.03835509208241298, 0.023118601097995718, 0.0948116850228079, 0.0072172990128878635, 0.03774060146702874, 0.054334192311451326, 0.09719309231807148, 0.03408327090343641, 0.032442858322493495, 0.03942351660601074, 0.052732934484318386, 0.023650051612827568, 0.04106874021911814, 0.07265219344727455, 0.05826313168771806, 0.07377441266491529, 0.05149939886084007, 0.025923997839732517, 0.033884624304670485, 0.016191323821042335, 0.03111298714253691, 0.023601880004148812, 0.026956837579247453, 0.031011001687617074, 0.019608999099282008, 0.030300001230751796, 0.03975089278913314, 0.053610511184219396, 0.019775860710069537, 0.05305019447640066, 0.01778993864483651, 0.06810773689780505, 0.028240756890285882, 0.021411109858402805, 0.03559630987564883, 0.03574630989122295, 0.08142495738162149, 0.04461056387592708, 0.030616069956111814, 0.07156063306836352, 0.054214314873059916, 0.060901304842123104, 0.0480621615274539, 0.04216880417398868, 0.004675911012811646, 0.07731573070369421, 0.11011034595750033, 0.027502901221234954, 0.11494793839031651, 0.07366075586046904, 0.03036850481294096, 0.06879382992103215, 0.02206346628466441, 0.03341688549206142, 0.11798733094286536, 0.03038495272067526, 0.12355607769061482, 12.48535042808902, 73.9607689457555, 109.52408344514909, 86.64591020153415, 93.41197521455827, 100.67272170897454, 72.85524891268823, 49.12871014687323, 34.81569113269929, 28.235397415776408, 46.98575065981957, 80.59336354655605, 57.25729673139511, 38.370900000295336, 13.013727030446454, 1.9780179377525084, 0.1754239456908357, 0.24690344238713866, 0.07036978769446574, 0.036214845435273264, 0.15346366761913224, 0.10127291654146488, 0.32538018700095916, 0.5399426301160167, 0.3769373527217296, 0.5554412016945501, 0.46791029373003595, 0.8928793981190651, 0.9774735846346425, 0.7376165423662432, 1.0688100803282954, 0.9990340567404224, 3.052678478340949, 2.3035060205767235, 2.4763342305537197, 2.1804965696027203, 4.62654838638921, 5.818232105624292, 10.333262605051841, 10.231140755837965, 5.823366488179853, 3.9235508057378956, 2.6071298314679057, 1.89985147406978, 1.9740936063951062, 2.7661890512512577, 2.2981995440298513, 1.872757824678575, 1.1181031191541304, 0.8322163274691952, 0.5565451037499213, 0.6731761066663651, 0.5141775610466157, 0.7959010019417733, 0.5793194268499652, 1.456531959195291, 0.812231851441245, 0.449568463429328, 0.20857499101229254, 0.13010973771733622, 0.4280287982715715, 0.21782167225835786, 0.188802277008372, 0.11721932013789493, 2.8403963725413046, 25.284270817233672, 57.81841924113613, 50.110785345877375, 38.08572015454693, 43.23241503007951, 38.991481719478486, 36.076513490369244, 38.97802798978744, 66.68419176532377, 82.95277118682861, 102.66448559299593, 92.77294266608455, 88.50076767706102, 96.50110060168852, 49.50166479233773, 4.624158682361726, 0.1700833169442992, 0.13487517232856444, 0.14999537308129574, 0.06862439425481905, 0.10868955929312976, 0.09875024263296397, 0.05125821139963885, 0.0404694794316686, 0.14484130206608004, 0.1295461268314431, 0.02169497416264588, 0.09356073239037106, 0.027498431098196777, 0.04174166802136649, 0.07506812832528546, 0.01569866129542671, 0.022786099786659884, 0.0466414782849531, 0.030210763478891987, 0.009650141451387637, 0.0318875250166222, 0.09214267299901094, 0.07385116701404895, 0.10896168904559267, 0.03041238249880412, 0.041884359558142965, 0.05551600550872184, 0.05768229914528709, 0.01589841967929275, 0.04819251138777022, 0.06318444986977885, 0.028717062481108214, 0.06532430198163756, 0.030608070082962516, 0.0352787702614742, 0.027327296632011572, 0.03924027220496247, 0.03526028072942169, 0.07935779935289776, 0.01787442473634597, 0.104437104816879, 0.024911003607896068, 0.06455318085969457, 0.04995665482936367, 0.051893152732161746, 0.04674195071622249, 0.00841852009011012, 0.01860650218722801, 0.03537438569530364, 0.2038432336262157, 0.09981068452039074, 0.22761063650250438, 0.13157117300696913, 0.12648490077305224, 0.10585125715982531, 0.09647544413324326, 0.09848438714060093, 0.11120336956434673, 0.18459844613267531, 0.15024790630465554, 0.24930100647672532, 0.11104134962924066, 0.09038328313298764, 0.22376921118026782, 0.15714194685701402, 0.18234519768626462, 0.0929095806373704, 0.0745667620832401, 0.11131203147552668, 0.12036067133228626, 0.10060525559369596, 0.12170848812186912, 0.12421563342814484, 0.17875995216590745, 0.16830778560571133, 0.12567148393680974, 0.12880777129002158, 0.1864826700259601, 0.22392950741754425, 0.1371284820620091, 0.14707627165461742, 0.19296078612246823, 0.10686435481353153, 0.22393185164659257, 0.2878759849456049, 0.3005665072029637, 0.20581286100129928, 0.21229825493308807, 0.16520310704025531, 0.18710925333922912, 0.18411406405991126, 0.14708016338127275, 0.19134263988704453, 0.261995880113494, 0.14868743116817168, 12.345710127584397, 80.68653552762925, 122.36997912006994, 91.75380891369235, 94.30796223302042, 89.6130891000071, 55.53227363094207, 37.70592097313174, 57.35623459662161, 91.57581175527265, 95.31200270498954, 126.86668626723753, 81.95826207437824, 54.43561423209406, 19.971602809044626, 4.393098719658391, 0.5856353008458691, 0.7730827360383926, 0.23341025916799424, 0.2168015342566275, 0.5845013681438662, 0.3212529955612075, 0.42548333324732324, 0.38908098013170306, 0.18006270000290486, 0.4239150593357702, 0.2363014290289533, 0.7433658177333494, 0.8187930574340205, 0.2792079145869901, 0.40320307557140633, 0.4164783374196099, 1.964632972113548, 1.550613194704056, 1.3061319844376658, 0.9777682526938378, 2.2874988279035016, 2.3863935470581055, 6.230723752129463, 5.951158779282724, 4.025280172786405, 2.929240018129349, 0.8533479741984799, 1.0022661510494448, 0.9178785018382535, 1.3923496031953444, 0.7946302152929768, 0.6663030722448904, 0.3985200413773137, 0.36590700428332057, 0.1730144919166642, 0.2952546067535877, 0.2371231655800535, 0.5140579287563601, 0.36379535952883385, 0.6827810719128579, 0.41421255577475796, 0.4909079467817661, 0.3629083829301019, 0.6529094038471099, 0.5620973413029026, 0.25662532797263515, 0.767891969411604, 0.6960081621523827, 5.991401806954415, 37.47939625094014, 78.74791975944274, 90.29263973236085, 87.30797490765973, 108.12364824356573, 104.81040646952968, 52.92159111269059, 31.8527562387528, 46.75079676412767, 65.01301104022612, 95.02928610770934, 95.44817170789166, 97.81078000222483, 112.32986465577157, 53.417566976239605, 3.7612016979725134, 0.7208328429729708, 0.19067853358724426, 0.2403758829759975, 0.13953168455871845, 0.230508103606201, 0.17540666274726394, 0.18915124537964023, 0.1281960117780874, 0.23160872680525627, 0.18866580610554065, 0.17881023817725722, 0.160824301682653, 0.14045708812773228, 0.17895659161431177, 0.17274424674049502, 0.10609314176103762, 0.1381700705256193, 0.15565821840878458, 0.14894577133799755, 0.11066498595380014, 0.12965357832370267, 0.1398048561907584, 0.17985882868449535, 0.17322248478810634, 0.15802495512029818, 0.1167910693273429, 0.12099490786391882, 0.1687618152749154, 0.11380276717846433, 0.12723345294474595, 0.11872223142774836, 0.1638563704346457, 0.17981231182573304, 0.11122597681899225, 0.09343073493049991, 0.1398606120698875, 0.14145421284821727, 0.1500938919883582, 0.16852633516875007, 0.11786084982656664, 0.209675430350246, 0.1264229319208572, 0.199601634615852, 0.13332664816369935, 0.1588864056693931, 0.11537172290826998, 0.12086586035307377, 0.12450697666574871, 0.1328813518968321], [0.024733020315667795, 0.0361605336318814, 0.017195812561699463, 0.037200490328212904, 0.015366037410022992, 0.028278025152582317, 0.03514951207644997, 0.04980294694823604, 0.09734061786965018, 0.04744414690761797, 0.010497274774787648, 0.014467628864240984, 0.04362377368154065, 0.05826966641771217, 0.0265243943525298, 0.0957027525310555, 0.03670289323875501, 0.09895066655571423, 0.02513504410613208, 0.022057879588476593, 0.015460226962703372, 0.04936207866957111, 0.04096911048456546, 0.025602984016821272, 0.022739138596901493, 0.016469624411735325, 0.027870736422858415, 0.03617279869954913, 0.05209735729881833, 0.03524279860298961, 0.04366056888454384, 0.01425127510071522, 0.04942762132193293, 0.05199644436699249, 0.044291388664034106, 0.05584112556290723, 0.04168338405208723, 0.03631002419898587, 0.011179537358393353, 0.04963468339654708, 0.038070367844474894, 0.04995757796531243, 0.03392457578992171, 0.3123872438746114, 1.0465779636175403, 32.98688996222712, 95.93602042044364, 90.57903551286267, 69.20926463219428, 89.25856174961214, 78.86777170242803, 25.526734090620472, 46.75332669288882, 59.81121078614266, 54.117819878362845, 63.73566373702019, 48.891681317360174, 23.953767553452526, 6.041776316781198, 0.1046480777703466, 0.5023401849452527, 0.3404267973476841, 0.07239216788401527, 0.025574914555275635, 0.05360945398288389, 0.1587405118850931, 0.14875700727345484, 0.12021431023435247, 0.20655372931111246, 0.07322636868564353, 0.19386342155837244, 0.32715202579575203, 0.404869653885403, 1.2789207865153591, 0.44166599069872214, 1.2278890345365772, 0.6635833988266607, 2.1937105444169815, 1.222895734733151, 4.1424499500182375, 3.7302961176441567, 2.4434880575826092, 9.17018178970583, 9.472389624964807, 13.18917464825415, 14.689128225849522, 5.5880620306538, 7.69198707034511, 5.124335894661566, 3.185013854695905, 3.5640246397064583, 2.9790928527232143, 5.018464749859226, 1.7816765894812925, 2.2169606387615204, 2.3789226576205227, 1.2412678714721435, 0.6718279757807333, 1.0351126304557248, 0.47457250075474866, 0.08289803720770345, 0.18122153056244697, 0.202716977125214, 0.09215139874046849, 0.18368733776432855, 0.10791757249183233, 0.11249197541826195, 0.0918163808303014, 0.35453819819996435, 0.032998597654964656, 0.1663369324899489, 0.1431214040325534, 2.5141927023087782, 27.47167075833967, 58.437859550599136, 66.98133484009774, 92.15107440948488, 67.79041782502206, 60.613802248431796, 34.09804644123201, 38.07035230821179, 53.434111533626435, 62.143369720828154, 68.6407406099381, 74.34946014035133, 90.65158367156984, 67.99679725400864, 22.334585689729263, 0.8222004939471522, 0.3278836704069569, 0.03004028210266223, 0.02844038982725432, 0.06438913845246838, 0.05319898790349403, 0.0808149292283962, 0.06003753687705725, 0.16456215191752682, 0.010158808511351387, 0.01783845307786138, 0.11299324206887715, 0.03832002823811866, 0.04060326902676494, 0.08145600692519257, 0.01415155152039182, 0.0506549937680604, 0.046440996905608524, 0.030164415159473018, 0.03567461938326878, 0.019870796240866184, 0.02388407615193677, 0.03705817800495894, 0.055607959042273225, 0.09527994094476586, 0.04360970064637162, 0.026461368298999248, 0.02606704369217398, 0.03117624110722494, 0.03523503430187702, 0.025713406015007247, 0.02192296767457118, 0.07517542659996018, 0.0491786121030248, 0.03162639437153215, 0.02147411484451544, 0.024473224578785802, 0.07285318427508877, 0.14884740564851992, 0.06835128390981306, 0.024266687274399786, 0.046701700456680796, 0.02337797548651936, 0.1269798778418091, 0.08692621178324185, 0.04231115097119924, 0.055484055811839725, 0.038260449580247366, 0.03135251793860188, 0.08041470191411434, 0.0436243022822084, 0.0283216557750899, 0.017012407282187093, 0.022301531937574188, 0.05394874283322885, 0.05714383509550845, 0.11209845137331756, 0.01748886226015466, 0.034513758690727335, 0.03807759205360086, 0.02106847320382874, 0.038607713405884085, 0.08780740441814547, 0.07994279941363681, 0.04733204526165801, 0.09002600270774096, 0.07407939992845058, 0.02941405502027802, 0.007368248498683135, 0.04085666026859995, 0.04301202949136496, 0.04577445061576944, 0.010324761350338739, 0.07547149660005685, 0.06731961628482228, 0.05964406262782793, 0.028128662905205163, 0.03270107974869109, 0.06960772939266698, 0.052044240592588345, 0.07114291596677035, 0.040649471789478295, 0.02464928307510432, 0.05545849911868573, 0.029495968971581712, 0.07545456605693025, 0.06758478995893272, 0.07148604674805557, 0.05011614667431963, 0.10378148677127977, 0.031156280686357812, 0.06303454178475565, 2.720115665466555, 52.3032255326548, 117.76831719183154, 105.26777052110242, 86.73890175357943, 133.49956327869046, 112.33949015217443, 39.847731205724905, 31.171715105733565, 27.367506334858557, 30.194850775503344, 52.10842101804672, 53.811655352192545, 30.8682805492032, 6.384405157258434, 0.2185315599725131, 1.0503949200914753, 0.3822642991379384, 0.17770203070775156, 0.21012155399207147, 0.6773953512310983, 0.49351138934012384, 0.6732266684693675, 0.6576170447853305, 1.6225752042185877, 1.9408370554447176, 1.879378295233173, 2.807963029030831, 4.649839420472422, 5.475160037317584, 2.6851734759346133, 4.2849467166008495, 5.963059250385531, 8.668187049127395, 6.0429275324267735, 6.685616710493642, 8.776858275936497, 6.717741412501182, 10.428624249273732, 14.401860698576897, 16.3992335719447, 15.003462068496214, 11.044640329576309, 10.893320191291071, 10.110113082393523, 10.165132168800602, 11.700846975849522, 11.343393537306017, 5.86877723855357, 6.06475797391707, 5.831542178507775, 8.155197904955957, 6.894618243940416, 3.609130916095549, 5.275050517051451, 2.601442394718047, 1.901164364910895, 1.0286594735037897, 0.9186931903804503, 0.9641701307508254, 0.3440296475685412, 0.29915494423720146, 0.7054158444366148, 0.42386045258852745, 0.8149612694978715, 0.13648342070800645, 0.19584429510418447, 0.2376711635940498, 1.4621399679491598, 27.668240339525287, 58.4231153611214, 58.739262319380245, 77.17618680769398, 42.84359831963816, 39.71975211174258, 26.388827908423643, 48.00044036680653, 88.00858082309847, 94.00586128234865, 95.13515087866014, 89.87287552125993, 103.66541954778857, 96.54875739928215, 42.92518361922234, 3.535198896161972, 0.2503577634812363, 0.053262362527030135, 0.016048396712229136, 0.06703110757253825, 0.028205386610821854, 0.01767320216693465, 0.09094245070891996, 0.035813549428337046, 0.034000989229929064, 0.005275846915244456, 0.06433894437166952, 0.03674956331510217, 0.021985681547272592, 0.01002471726913486, 0.07656616729594047, 0.022606783501443364, 0.023821766390615416, 0.027538520479274374, 0.02805725584978298, 0.014313547515250264, 0.05236114818422545, 0.047403609365104675, 0.02297938951561528, 0.061396883289900527, 0.026408268829747557, 0.052045864698987816, 0.008534382270168393, 0.030081097352048083, 0.04353565824848991, 0.0339514922891413, 0.0386715017168993, 0.09933845260210576, 0.06210698167823496, 0.04969209785603228, 0.04830342559744755, 0.053122444228539546, 0.03788198682389433, 0.02132991986018756, 0.03941751047668438, 0.012549473021569993, 0.012494014959121424, 0.028047986185899185, 0.05454599647031677, 0.0770892214871222, 0.023822881048545245, 0.027891039668071656, 0.03183797061924012, 0.1259063588335149, 0.1762159886739908, 0.18982771633853837, 0.12410728561301386, 0.18714391115692355, 0.0870733542908584, 0.14755617977390367, 0.14784654241896447, 0.2506246685140556, 0.08775683495426372, 0.12771931356720387, 0.11548932506552628, 0.15961570605154962, 0.21965171841363754, 0.18891205740792139, 0.32165402726780984, 0.17573657085097608, 0.1762602532342557, 0.16170591566591494, 0.0788778376074568, 0.09385117164422428, 0.16066982771360105, 0.1342827871802353, 0.09546138886963168, 0.1653746494482602, 0.1778869336891559, 0.11462006041960371, 0.15799664051061676, 0.10314165779779996, 0.1272809963613268, 0.17527973729996912, 0.14216293610872763, 0.22921526894694377, 0.12731083548597752, 0.11515193994367316, 0.13639576492771027, 0.11999033676880984, 0.16768846480596453, 0.10734001880571728, 0.1809066531038092, 0.10305111386602926, 0.2452753523304578, 0.10238297028286804, 0.40265798869152225, 2.596892935614432, 57.30942503098519, 133.19288099965743, 114.90047624034267, 88.0481496933968, 112.86676652969854, 102.42339318798435, 36.071857636974705, 67.6010222588816, 89.36310860418504, 82.87688116873466, 97.29610227769422, 75.9446253315095, 40.56259885911019, 11.033086988233752, 0.35055138471145786, 1.319177542482653, 0.7992503996337614, 0.2502274366035577, 0.4853205304713019, 0.6344549586215328, 0.40733654893213705, 0.34900673695148965, 0.37141073314893636, 0.8101313609269358, 0.6544774938975612, 0.7554110488103283, 1.2224256631828125, 2.8413127362728123, 3.91711100935936, 2.71505678853681, 2.984209094316729, 3.6956449189493736, 6.324773853824985, 8.03812005827504, 10.248112851573575, 11.76840489910495, 12.398827845050443, 21.956202483946278, 23.80167961120606, 33.58040732722129, 34.09372791167229, 17.236104588354788, 17.90338408562445, 12.539067287598888, 15.832521684708135, 12.429880269112127, 8.308635142541702, 11.821564782050348, 4.991942663346568, 5.550431301516872, 6.6171875307636885, 5.174116655703514, 1.8517092831673163, 2.898940198844479, 1.8430771270105917, 0.7046052008386582, 0.24993330480590945, 0.35071238574962466, 0.4986790507551163, 0.2499520892818128, 0.17068658054115313, 0.29351620003581047, 0.41049963404094025, 0.6983699192923885, 0.22137250510915635, 0.4045635557943775, 0.36150371475565823, 4.450692351787321, 42.78848901871712, 87.96746653895225, 95.30789206104895, 122.88366840731715, 93.7093928552443, 84.32112140040245, 47.129301563386, 49.89909895004765, 64.14932866250315, 80.6429030818324, 91.93176684841033, 93.98175439526959, 118.00595791109147, 108.30919988693731, 44.13010043482627, 2.2979629760788334, 0.5212389918104295, 0.10092701252189376, 0.0651262759140903, 0.20419940322397218, 0.2716257278957675, 0.16870405224542465, 0.1418270371974476, 0.23358770045301608, 0.08168222502835336, 0.1897996928422682, 0.22112010978162291, 0.10861930903047325, 0.1765080213907265, 0.16889232601369583, 0.29037349286579317, 0.08956682492768572, 0.12700246977469615, 0.181898124095413, 0.07553535002854563, 0.10320781715094082, 0.16472683017773015, 0.16017749364818298, 0.1382421440775356, 0.15497089964487862, 0.13847013184380147, 0.20914350486090108, 0.1389887427250224, 0.10230999274720108, 0.09325502500418695, 0.18809413597468408, 0.1003932177780136, 0.22883869076688446, 0.12194475729859645, 0.17667194888476404, 0.15596670669413384, 0.14929781938272138, 0.21008729454009764, 0.3706151048742956, 0.19067079609920903, 0.16523626332561817, 0.15423868812860983, 0.1661771112271855, 0.1863092430416615, 0.2158850479510523, 0.14036284399128732, 0.12144511475438073, 0.14940631275455798], [0.01826727845435662, 0.007166611284182798, 0.031055227943485787, 0.04437658147165372, 0.06627329339784, 0.02442367209662353, 0.030208522671713468, 0.032366441052046516, 0.016612658772857922, 0.05962797861185767, 0.03349275117920291, 0.04106954461143863, 0.1441222519403504, 0.07189836292978256, 0.029695092460080504, 0.0640548023605539, 0.06663402121874594, 0.03981402226453347, 0.030501700689895984, 0.04546733745824426, 0.09559579133506745, 0.05356006812484515, 0.02995601817665081, 0.020196502352313652, 0.04238484862951502, 0.009955889057187785, 0.005851751597102491, 0.04860542894851777, 0.03379724431602705, 0.042564580517430464, 0.023807723998963356, 0.06854971600396019, 0.025371587159292355, 0.05410148927401151, 0.03836567558708691, 0.06623550994141449, 0.02856490784324706, 0.14347248680649266, 0.057105634121164206, 0.03718305416705628, 0.04545989108362025, 0.42461547820318135, 0.31503735650931636, 19.19469894901399, 66.10694439180436, 93.37370072641681, 69.00850203729445, 76.20955005768808, 68.53517393912038, 36.782077281705796, 38.0723056485576, 53.163350320631466, 67.60667047192975, 68.40280179054507, 55.41031537517425, 37.17687560665993, 10.857490320359508, 0.3443643054173839, 0.4089151497089094, 0.13289949285887903, 0.20130530690714238, 0.11735405968201738, 0.11815023187908436, 0.07109038531780243, 0.04080862272530794, 0.05376735236495734, 0.14080696048275118, 0.26876141707743373, 0.8736760866257453, 1.38268010270211, 1.3164686555823972, 1.353540324395703, 2.1606140751992506, 1.6266734681783186, 2.0319592303806737, 7.138949546121783, 4.594682070516772, 5.4643548880853965, 7.764284197361239, 4.8431235263424535, 6.1302978377188415, 5.289393644179068, 9.598954704500015, 14.91452330543149, 20.94950656737051, 22.2875270535869, 7.68086911209168, 5.167123069686275, 8.231160486898116, 3.5027096588765425, 6.961458863750582, 12.9001538215145, 8.519285052053391, 7.930674081848514, 9.776270351102276, 4.462055458176521, 6.932842721862178, 3.977398329204129, 3.5675996349703882, 2.3767361813975922, 1.9315360125995453, 3.4470612772049445, 1.70912119890413, 1.082163054135538, 0.39973505682522253, 0.49139122568791915, 0.5810907447049695, 0.21978871025625737, 0.15622492428989182, 0.11389331877111428, 0.09475363087990592, 0.20416188023744092, 0.20642959242386205, 0.5004555473644887, 2.230090282617077, 28.72932384091039, 46.283760147710005, 69.54243859937115, 75.6699574378229, 96.79440759843396, 77.46871717514531, 27.56729029840039, 26.765632360212265, 50.502363404920025, 66.80534593520626, 58.1675454878038, 61.70990859308551, 73.04335794141217, 59.169993477482954, 10.680990526753089, 0.17924735262509317, 0.05561412605006368, 0.029910357421143886, 0.04612090238820642, 0.04598069680674423, 0.2000015631558434, 0.12446559259607909, 0.051141926913612315, 0.028622155678608728, 0.047972169178988666, 0.03804387652405328, 0.0385615949128424, 0.05943295943941321, 0.05419214811897086, 0.01763002353630239, 0.03720783711140675, 0.03644314346714847, 0.04250974394381047, 0.11577554317491671, 0.07174752787837098, 0.0235253133465566, 0.03798169316723943, 0.02550547060015942, 0.06283432087530533, 0.05197001816404443, 0.11512125046142649, 0.04308608721100515, 0.04436658785468148, 0.05627672698709273, 0.013164741216197371, 0.03671590141170929, 0.06893535700416373, 0.037129102424988826, 0.023793107041368083, 0.055815021116887374, 0.045993555592553276, 0.00754175257057913, 0.06935072221582936, 0.013907448137028804, 0.031219576785881675, 0.00888683059583268, 0.04812007011365026, 0.01655581696409612, 0.0479477271437645, 0.012740215508177156, 0.0739270403620697, 0.029561161138718168, 0.049310689491610375, 0.0645454203890216, 0.026225210205020926, 0.007636097734869128, 0.06245654376764452, 0.014047987924347964, 0.09465835252476316, 0.05957816757502095, 0.028699159006317778, 0.06895877631200899, 0.0372068067231486, 0.023634086340485562, 0.0495817122470227, 0.01819222673563467, 0.0452153864617069, 0.037759968169754556, 0.025317453471342885, 0.015268484731355022, 0.029168780480000763, 0.05146369150268936, 0.05068312068620036, 0.030064513463707223, 0.013829181721854596, 0.08076498795661234, 0.0650110179858823, 0.024475172357333284, 0.040037796547215794, 0.03797448044943233, 0.033525884481928045, 0.04397921932620868, 0.054606605516446215, 0.050458587976473, 0.04967561164390176, 0.04189166037606136, 0.03509548755602972, 0.03975737006253293, 0.11877344440548651, 0.04666263380298211, 0.05333298817276955, 0.0441214703624287, 0.31208843894062505, 1.905099482786271, 30.38364621900743, 88.01983802549302, 107.6252483552502, 82.078443496458, 115.02951437427153, 102.71181291149509, 49.536307165699625, 41.40417475854197, 30.763312039836762, 43.18916305418938, 56.412747675372714, 63.23136068159535, 43.706488378586315, 13.07890505559983, 0.16895762734836148, 0.6339133651025834, 0.20927565502783946, 0.19625773743516017, 0.3110762835750657, 0.22617500305416124, 0.6747008667838189, 0.387230602002913, 0.5303904942927823, 0.945472069565327, 1.6568824600788856, 2.705644325863931, 4.550000880995105, 5.799993574619294, 2.6577411543938423, 5.05257809354413, 8.745587179737708, 4.025491735627575, 6.082720958417462, 7.918054346115359, 9.281331954463836, 10.83470723321361, 11.486602214074905, 9.905765441156204, 10.252233301439594, 15.138959365506327, 23.795735259209913, 19.432265143240652, 21.038714993384577, 13.46024670908528, 9.022565349455803, 7.700972730113615, 11.196617464865408, 6.796578111187105, 15.272097356857794, 18.27188095738811, 14.80481755348944, 16.899610334827056, 15.131097955088462, 11.13826338321932, 5.98198615735577, 6.80315935803998, 2.2489681599601625, 4.3245312763798625, 3.611742969482176, 3.257658111472284, 1.5246295760716162, 0.7344617922940563, 0.7665453707018207, 0.4083320035809471, 0.5479920078669825, 0.5297990131282038, 0.20621609904112356, 0.319172055610726, 0.20040659384141046, 0.10172354478028514, 0.4436827631246659, 2.132852029415869, 26.83537406306113, 46.04483289103354, 47.0467278265184, 54.78816470792217, 50.599367541651574, 44.212489820295765, 22.62091478993816, 45.4377951160554, 78.59072685241699, 89.84860389463364, 81.38616869526525, 70.86459898179578, 87.7525677219514, 82.69194141510995, 23.56887125199841, 0.05854184596589016, 0.06984872533188713, 0.048684178956694184, 0.06912699389842249, 0.13257123950508334, 0.14976081228063953, 0.08413151537458743, 0.01888900477018568, 0.024262341640649304, 0.0444921764785484, 0.05434640375296435, 0.03113395496902447, 0.08976373250686354, 0.012274749103873488, 0.04512725570689767, 0.011338363664465086, 0.07115551045224552, 0.01736187552582593, 0.08873758837580682, 0.0727235928418175, 0.042757102243241765, 0.03405223285118419, 0.08787295856182614, 0.04854228032091933, 0.041763160618082176, 0.14207408523126958, 0.06662839813338173, 0.09031110232876194, 0.046239776251417015, 0.01203381445168728, 0.05146643026701866, 0.02777783485550073, 0.011971017266924103, 0.03925141495382113, 0.03696597549283216, 0.06894257355241046, 0.040229073380150145, 0.06239453661105326, 0.037130542670286475, 0.0330283869839003, 0.01631479804223824, 0.029105850187460744, 0.026821517723522363, 0.010381405891460038, 0.057419584613413586, 0.07624024284943458, 0.13295722524485282, 0.0681905739850575, 0.17750539125934725, 0.13621977920974457, 0.19952456617066938, 0.07224070464050578, 0.07218276541079245, 0.22078601883784418, 0.1520667062892068, 0.15138235994644705, 0.10598821069804892, 0.16943307683592843, 0.19466079651348053, 0.20112591975879288, 0.12708123893507067, 0.17180791875768095, 0.1196648336706623, 0.11110090530447422, 0.14529681794585722, 0.2454611592956128, 0.16377634489007536, 0.1105447254714466, 0.1699729543179274, 0.18644301731499935, 0.15909377034873734, 0.1815801976068366, 0.06517771105732649, 0.12781767159580223, 0.12467065135077124, 0.15972139554158335, 0.14854807977474507, 0.16775571200395786, 0.11915681778543419, 0.1024252353536506, 0.1703482301485154, 0.15045668058578046, 0.14347719058634775, 0.3715858608484269, 0.12565163459869164, 0.22842750073440615, 0.11662202436597117, 0.6153834142511891, 1.7506913360088103, 31.689921002234186, 101.48405613437777, 120.26477244592483, 85.73156649066557, 97.21296371952181, 90.77581297966742, 45.524585400858236, 51.16663640545261, 83.89327710674655, 104.65820281736313, 105.84028751619401, 85.79674059344877, 61.90752936947731, 19.848626698217085, 1.218775284867133, 1.2090232920262123, 0.2784292321772345, 0.6843370884176224, 0.38826567871916684, 0.22910913512591394, 0.3339664698127778, 0.17656399177447443, 0.2376548765647796, 0.4822428182007805, 1.2556928780771073, 1.649013695216948, 3.223279762652613, 7.4601073322757605, 6.046892068078441, 8.347629385609782, 8.660955179122187, 10.501883337574622, 17.659789208442934, 14.568309418616758, 20.62346346916691, 19.524003498015865, 19.646736421892722, 18.537976511063118, 19.595810328760457, 27.2205174738361, 38.24570186676518, 43.0658672701928, 47.489606565044774, 25.69632757094599, 18.920639022704094, 29.955723477948098, 23.3163922063766, 21.6703950589703, 29.508432072977868, 25.70366240316822, 24.865553878968765, 28.2481215846154, 23.119871654818137, 22.29848223347818, 13.873637068656183, 14.659470204384098, 11.357853354946261, 7.677987150607571, 12.211133606972234, 6.478973992409245, 3.562460594600247, 1.844151243567467, 2.3960072763504523, 1.372432420330663, 0.5590914574361617, 0.13124926286118646, 0.16998734144914537, 0.3355158979613935, 0.423175294192568, 0.214785497275091, 0.7778989776007591, 4.517309886793937, 42.37347479789488, 70.55253521088632, 99.85872791659449, 107.23832222723193, 133.9236185627599, 99.96892298421552, 38.68686260715608, 36.49371247137747, 64.02681343017086, 87.91259258024155, 76.37505838947912, 79.02817310825472, 101.58402950532975, 95.15970491593885, 21.58077282290305, 0.22244443065456806, 0.1775563361063119, 0.15425005687340615, 0.18591096925158657, 0.1823131292457542, 0.3973014099944023, 0.26239228464903375, 0.10405838159063172, 0.13584752176557818, 0.19998104732123115, 0.12034586285270991, 0.10176310556069498, 0.1911354590688021, 0.1930619556937487, 0.10700500855642943, 0.10861979166586554, 0.1294520971996169, 0.10943384435508521, 0.1738931947658139, 0.17548371587068806, 0.1087919929094853, 0.09689985684329465, 0.34026711398074705, 0.18356597411536402, 0.08509677849830159, 0.32865613218276735, 0.1630652007917243, 0.1568277588775081, 0.16234356128881056, 0.1094330552845232, 0.11689442991008682, 0.12223709645050189, 0.07242789822480372, 0.12001398590303237, 0.14384495875527784, 0.20728388771174416, 0.17761668851298673, 0.16695139629225578, 0.09415376105255659, 0.11686573225644328, 0.08112232966889298, 0.13062418108024906, 0.11928459359032494, 0.20701802455850188, 0.09814664195742338, 0.3625905790155934], [0.01700755986084621, 0.01857306244933317, 0.03255088438069628, 0.01388520477414732, 0.02631707946890064, 0.0196282911084352, 0.09537865903468863, 0.010350790145176073, 0.030105435965402477, 0.05235706876602866, 0.022914639764255094, 0.04831445343311756, 0.023587161539903572, 0.06716927152968223, 0.0561575428582728, 0.04081005914016597, 0.026821969715397687, 0.056481624863320784, 0.014138768385765294, 0.02306933206836543, 0.07463508946520668, 0.035624226119609616, 0.07105578878714193, 0.0181277297932895, 0.023175318417469823, 0.026433578459545973, 0.04610031377524138, 0.009111956066091456, 0.015698309852591446, 0.03424378164533166, 0.03543127921500033, 0.06657412080394645, 0.01236370436081122, 0.002443127647688192, 0.03038604439596736, 0.03731654881830177, 0.053675663131739826, 0.10214005912383718, 0.052858795069398425, 0.20506793242548743, 0.33010495766516657, 12.375919242059032, 67.29168845761207, 99.15956543337916, 77.28110236506309, 78.42943114619102, 87.6407801720404, 48.37362250974102, 43.251587575481786, 64.09712976024997, 60.7402123943452, 61.48623151163901, 50.997284150892696, 37.67107071415071, 11.209157282306302, 0.5550718860280129, 0.8189475620465895, 0.03799539081932556, 0.14247952960431576, 0.0820250187309519, 0.19655821244082144, 0.21712589588376785, 0.2639771367032682, 0.34717937210394495, 0.8630398444591031, 0.9396542140072393, 3.2525511855079285, 2.4985478385802242, 5.856560036059349, 10.107945972873319, 7.49908882764078, 5.5220642301344105, 8.72107824971599, 12.56919893526262, 5.321293300197971, 5.247085488611653, 14.42237469457811, 14.039541559834635, 3.8018585356973835, 7.859915014236205, 16.350068623019805, 5.908083310050349, 7.970072329044343, 10.345742606347608, 7.11007550839455, 6.753108443752413, 9.798686696637063, 9.771930248506608, 11.461564744672469, 9.519819905680995, 12.482276270466468, 16.236877845179652, 3.7803659083381778, 9.651160470900997, 6.127282515648873, 13.82459371320663, 9.3223403346154, 7.66866171552289, 12.562890783432993, 3.565113832873683, 7.41066683684626, 5.621051124988064, 6.841081813458474, 3.9500123406610186, 5.943144396428139, 4.887161447155861, 4.57159205790489, 0.7846322162978111, 3.3432604084091806, 0.8936438925804631, 0.7467980754952277, 0.041532667744303906, 0.04672232737404205, 0.21814398076986113, 0.13646616840795164, 0.47245500308852045, 8.198397909441303, 44.481729153663885, 62.43242094593664, 64.16268433293989, 78.61195471978958, 103.71245661089498, 50.81205806424541, 31.514402781763387, 45.682382352890514, 49.856035247925796, 68.50541883899321, 81.82693327626875, 70.47251101463073, 71.68047551185855, 22.026587455503403, 0.1957710264551063, 0.32261886904316567, 0.0691068074816177, 0.03230958583674604, 0.12756035032291568, 0.06659478985614355, 0.03409559342769846, 0.01907903479502326, 0.05039186171826817, 0.04729227763750861, 0.02916669480562691, 0.08328689577718897, 0.009740856795331404, 0.05624127243795703, 0.09882676715572035, 0.04808650397124791, 0.02247800986703125, 0.038380959041176305, 0.04398057147139504, 0.0691768202570177, 0.07274938702222801, 0.039157354678477974, 0.0036805791774719597, 0.0477972827971943, 0.09580507889510163, 0.02961227069458654, 0.06619889859951313, 0.06673541295552446, 0.014139949118778592, 0.01869171223182592, 0.04216151101694953, 0.08662725363167063, 0.045391146183734944, 0.04904370018911939, 0.00838742170843386, 0.025293963300364635, 0.010759624457287212, 0.09194783385722868, 0.011717544628247138, 0.025721840643053575, 0.03548418907749076, 0.06159310138994648, 0.04516348783527652, 0.030702850480954495, 0.02105618323830347, 0.0013267680450582938, 0.05421221579214739, 0.07521356245683086, 0.015907141590310682, 0.04171875050111164, 0.04496162366722861, 0.02797231010551895, 0.05720289664403085, 0.066213661113814, 0.019821893018219742, 0.028862316581991412, 0.041424683820936954, 0.029857152614802606, 0.033963726713292064, 0.03056279045619792, 0.06153038560202526, 0.03768281928533989, 0.04165856663378016, 0.07844452295572528, 0.036445855418400425, 0.027440386531393857, 0.021580390391811248, 0.06797771645529617, 0.01439470399711882, 0.036360053570881005, 0.016671285566483295, 0.06898637845992081, 0.042373636932743174, 0.02046881596587839, 0.05416819254957861, 0.08590887766331436, 0.09284421035479154, 0.04198652887416463, 0.03592713345443049, 0.08039856044154975, 0.03544678100414815, 0.10108217597007753, 0.04486648703835184, 0.07327847032537384, 0.24619012259908263, 0.5289204634966389, 23.438848603156305, 89.87789615508049, 118.91371204007058, 92.33107197669246, 105.6975289314024, 125.53102508667978, 67.25809727945636, 39.51460038461993, 31.445063121857185, 42.291916954901914, 60.08237208089521, 54.65761253910681, 44.88506647848314, 12.768168026401153, 0.5816021237161852, 0.9651637774321341, 0.15692132885657972, 0.2077346385246323, 0.09599736696409603, 0.5523016508067808, 0.4641387203047353, 0.7203787673384913, 0.8254052542390362, 2.443726096422442, 1.5522381591220058, 3.0813389920419265, 1.714597930831294, 1.9421033681400361, 2.051792572582922, 1.1027889602607297, 0.6352729566635624, 3.8637915349775747, 5.626815047956282, 2.4748148024082184, 4.911252644754225, 1.2853754143561087, 1.4794298982427967, 4.611484033446159, 9.838968457714204, 28.082111189442298, 15.2762972347198, 13.84086468527394, 19.70863926795221, 18.325032995593165, 8.048091213549338, 2.1971872352784683, 1.520776705395791, 1.9487462697490572, 1.5810754246288732, 3.980328339722849, 7.59113803025215, 8.992879871399172, 18.536691934831683, 11.095961601503435, 7.265100815603811, 4.792719598739378, 2.2102668689143274, 0.48759470843980396, 0.20291977592052954, 1.9840213704493739, 1.5590171179463788, 3.297508166682336, 1.3964999611339262, 0.9052545985867901, 0.8145076228726296, 1.1007375606606085, 1.2649322661661333, 1.2268279108308977, 1.5403277595197002, 3.739346496520504, 0.3123056095454001, 0.13250405359412396, 0.1241877937929765, 0.16215619150429003, 0.4518057772469136, 8.480799736515168, 45.28334786815029, 54.07641533882388, 64.69588741179436, 53.10004326605028, 56.36540466739286, 27.728491867742232, 35.505651735490375, 77.41251745531636, 88.19637606220861, 110.33926179332119, 106.30230349879112, 84.14777617300712, 92.07786729258876, 43.20347578294816, 2.7769059471545683, 0.12390565127134325, 0.1292553658206617, 0.03092304330259081, 0.09681249217640969, 0.1095617733775608, 0.04292581012592681, 0.05249263951554895, 0.03740061930711231, 0.10084671118567068, 0.010538429018079994, 0.012914767684114557, 0.03685093589968259, 0.037624278676606, 0.050298460278539896, 0.03147569530072712, 0.11090128577404446, 0.07112366417723318, 0.0275835721948815, 0.010596580837192315, 0.03964462873315619, 0.0521291729303137, 0.008415806223638356, 0.030532757894346313, 0.016343518678519516, 0.02766417805105448, 0.04554258261416708, 0.08796187072631814, 0.044951285310690446, 0.045289287133322614, 0.06516256549906346, 0.023017967788262234, 0.028103895282613176, 0.053049164088142496, 0.022843650226751645, 0.004292668825421002, 0.035792022357664766, 0.03750337468039605, 0.030963364425265504, 0.011007868545880962, 0.03389320831986205, 0.08351129825196921, 0.043450572693179694, 0.017872831273463466, 0.0679421240103341, 0.13229357859780713, 0.11178914337388932, 0.1743562336290075, 0.11900858743296516, 0.10565724539300127, 0.07814224764344194, 0.20175852452314672, 0.11179131140271503, 0.10317148926157145, 0.161377938103772, 0.10518797057410402, 0.21857458347034073, 0.11942421311452506, 0.1477117262660496, 0.15093294212654715, 0.12017207580708689, 0.13069346607212098, 0.07039493836101986, 0.214475155056965, 0.13751926351218455, 0.16029228426275716, 0.12433302874166159, 0.14906849862346727, 0.12243474713496624, 0.14079038234006974, 0.12499713504146184, 0.19660325841076914, 0.12135183588872034, 0.07833405307704404, 0.18912624026979172, 0.13211734773170564, 0.1902325784847621, 0.14823747708672477, 0.14051253757169171, 0.17867863959362432, 0.1115812117894811, 0.18155928340650376, 0.24837071526675458, 0.22851449767908744, 0.4787300599198188, 0.7123583170675463, 26.711054540449574, 100.56618229035409, 134.26833214298372, 97.46761183584891, 98.03315485677412, 115.04649823711766, 61.304021727654245, 54.758684173707046, 93.98946577502836, 91.04546808427381, 94.99994677882042, 77.6433724741782, 59.43009368834957, 19.126181025658887, 1.634583785649269, 1.526112844867091, 0.2687466162587366, 0.6682950234220875, 0.139513528274913, 0.5602608753308174, 0.39912451539308796, 0.6005134637798033, 0.752451436654214, 4.379488095160454, 3.8332970680729037, 9.686883457245367, 10.631766742275609, 17.93530433408676, 28.963177511768958, 24.110060276523715, 21.319884215631795, 29.02338001035875, 34.78899155893634, 15.41895874084965, 23.663494510035363, 29.49695521785367, 27.973614508105864, 18.10161282939296, 23.336914047118157, 33.14011343063847, 18.99115735484708, 28.925732604918945, 26.90000491757547, 32.70355559164478, 31.499544843550655, 31.17195437031408, 27.36536275955939, 30.39378946827304, 23.53125179967573, 35.99692859957295, 38.701489125528646, 14.302132475760676, 26.433701784380023, 24.374973235591767, 29.237792453458233, 28.32911264511847, 28.257874558048865, 27.582975856719482, 19.510359533371467, 21.901110833691014, 23.232435834023264, 19.764350652694702, 17.614634883019235, 13.76223881398478, 8.012617788007184, 8.651668967739228, 5.301008272555567, 6.436499626405778, 2.065181092869851, 1.5696098463189219, 0.25058480129847605, 0.12632198451507476, 0.22480825623196943, 0.4693743490403699, 0.754959914953478, 13.808865008815644, 67.77431257309453, 87.29687460007207, 92.74775320483793, 117.89082065705331, 143.37682877817463, 68.27094739483249, 44.37943373956988, 58.50493600291591, 63.85663747787476, 90.64074224041354, 103.84054553124213, 92.48686851993685, 107.56501643888413, 45.48405947223787, 1.7116458569803548, 0.46518289814552954, 0.14925124123692513, 0.11742136816704467, 0.3982300311326981, 0.17453189759004503, 0.12675726035189244, 0.11952699913132576, 0.16215043052309946, 0.2537150059135691, 0.08245889262686815, 0.12586056975828064, 0.10359237796717113, 0.07262113624282422, 0.14327405471234553, 0.09318374818371189, 0.2591950626623246, 0.2056237445363114, 0.10195219904304513, 0.18841550985891975, 0.13908713905801698, 0.15720468945801258, 0.06125308858651308, 0.1685708142336338, 0.17496447679736923, 0.14484436641777718, 0.14840597046479104, 0.14335280855096158, 0.13056438025687972, 0.16268894436859316, 0.15881944958481098, 0.2746987823517092, 0.1880148918397965, 0.16539461369956696, 0.11342582127620136, 0.10431268447709661, 0.24282050018589346, 0.18541811424637997, 0.1263430749156302, 0.09568716264179639, 0.21762258132859585, 0.1830822815217318, 0.1465274156221459, 0.14194089318475417, 0.1306949369609356], [0.10731564954884591, 0.008257836978431911, 0.039082078879038175, 0.07348951222675462, 0.05482103735689194, 0.06017167121171952, 0.03507573014846252, 0.08043953082374028, 0.054536730636872595, 0.03526162138328918, 0.02370200578063246, 0.03747873729275119, 0.04943317928982358, 0.031674780484829704, 0.004142329337135439, 0.05846626756172027, 0.04426489351317287, 0.06433294590322242, 0.01017388224887151, 0.04476933176779459, 0.074625160965708, 0.031069092219695452, 0.08056362174571523, 0.04550268092463094, 0.047744771300424496, 0.05236422402724143, 0.043777155975300464, 0.028985940190332554, 0.04248069772016137, 0.03773288696163124, 0.038091523362503904, 0.015414724212830827, 0.014491413979070082, 0.012797059232158767, 0.09874693313313108, 0.01317043420708468, 0.02162269376699002, 0.3912403981291479, 0.32822470210732957, 12.976663574095696, 51.15643432063442, 105.17783841779156, 85.87599600515058, 81.82449356202157, 68.24328684037732, 49.72624794129403, 40.39560002665366, 55.0657469226468, 71.27029757345878, 60.53923406908589, 53.74166850120791, 37.558600671829716, 18.726399329400834, 1.6371080760032901, 0.34090698125862307, 0.0875424605704123, 0.25860241704410125, 0.012151479811197328, 0.10493870854618088, 0.5385834062772413, 0.19856289599932012, 0.4761799983680249, 1.2520980258141796, 2.163197691402128, 5.177800741887862, 4.409580028826191, 5.546188277582969, 4.803521315897665, 6.983635944704856, 8.716038004044565, 10.063265273647925, 6.493366149164016, 11.664259106882158, 26.13776287724895, 15.952829603225956, 10.250221125541195, 5.097673093118976, 3.666279604358058, 6.281091397808445, 12.84730870877543, 11.927197152568448, 5.683539875092046, 8.848472910542643, 19.449199976459628, 10.693796084773156, 11.982179957051432, 7.131671097970779, 5.0694320278783005, 0.8109604519221091, 7.139032406191673, 1.1971048025354263, 11.28666723928144, 17.051986571281187, 11.724105650378812, 14.624885685982244, 10.035187967361944, 10.22187807867604, 5.470375726299902, 7.152682744687604, 7.725883703077994, 19.555570733162668, 13.677511695892582, 18.057454785993023, 27.90358647223442, 43.074641612268266, 43.45750808715821, 23.158595254344327, 6.202641542880766, 2.2628820327020462, 0.8465959816690415, 14.593834242513104, 0.5243206877381571, 0.40303352499200457, 0.5107635974643693, 0.21289134488230754, 0.06639881690423335, 0.46088517553383307, 0.2273178070543274, 19.660786351849957, 71.7391384801557, 70.73335647583008, 59.99811172485352, 69.59346079057264, 60.488133430480964, 23.413888600564775, 26.331096503042406, 21.37162027820464, 43.630594438122166, 65.4997104983176, 71.739805283085, 72.19705166355257, 56.02530771686185, 8.583535436661013, 0.2169955383625723, 0.04446419511711405, 0.04929340271759899, 0.09593951966493361, 0.09604750741874019, 0.018760809532156395, 0.06748194265509806, 0.04593574659778707, 0.0572480958315634, 0.03563515819428909, 0.004967335168452513, 0.08010147154451379, 0.06028358899657765, 0.05512669494736099, 0.032005841550867886, 0.02556911526968883, 0.06210452253599802, 0.008285376881699889, 0.01893811675179149, 0.045411910996922565, 0.0402075884443137, 0.030904946390599496, 0.06981862573734215, 0.04999251540509924, 0.02722546439467659, 0.03516520921801848, 0.03477956055693569, 0.04895984803536727, 0.02822643487654146, 0.030467621268584367, 0.030183096213506597, 0.011476274812594058, 0.07091856711814482, 0.04909415090937288, 0.020562790056330063, 0.07200226743495272, 0.024787990954674544, 0.03827765591502671, 0.0453146101696597, 0.03838486608959014, 0.01772947324019286, 0.0642350283751805, 0.019938642902660276, 0.14141387065812466, 0.04180940934607098, 0.01589596245227562, 0.046392695061982646, 0.008158920663258722, 0.024255201701195012, 0.03550149883413988, 0.011860315646645764, 0.08271242176452953, 0.028152704659488895, 0.0281651976383141, 0.043344641885449814, 0.03525260069798078, 0.02647410068030079, 0.018676679671531724, 0.028857076540589336, 0.015541381529352118, 0.02787859648496153, 0.10261562352459278, 0.07766872103656493, 0.044728736768686966, 0.03243082691164267, 0.062012500054533445, 0.06038956960002261, 0.00664373568724841, 0.022019893118751147, 0.019635427217449875, 0.024196869851420486, 0.04713126893846258, 0.025052938632847323, 0.06238692935796515, 0.07315748972037146, 0.011205051916711515, 0.010701444867487636, 0.048083301723724416, 0.059307497220053795, 0.008455483832456654, 0.4334423739102579, 1.0306781458277856, 22.63256815172011, 71.32810546505836, 127.53526995258947, 98.85365193889987, 102.30282737362771, 105.1065218833185, 90.15292490682295, 58.378286592422, 39.19522923807944, 51.29343486601307, 56.54800276602469, 55.11516486444781, 45.17458054327196, 24.26324844360352, 1.575351705954921, 0.32427325123740786, 0.055027812148534486, 0.35789439875272017, 0.2083847713806937, 0.3224729446153487, 0.5377660823925849, 0.270794645071991, 0.4471285346775286, 0.8414840301679027, 1.135506185312425, 2.1229191172507504, 0.6721713057448787, 0.9569787714750537, 1.8205442135372472, 4.4568367446622545, 8.50030372219701, 10.71912577075343, 12.25757937277517, 18.629008839207312, 29.08278234543339, 23.459611669663463, 16.66737268047948, 5.564952406191058, 0.6077104614626977, 0.6157842927402066, 6.474258322869578, 10.387050067224811, 14.44865261354754, 19.221745652537194, 15.354312196854623, 4.388590935737857, 1.2273101172139569, 0.44168918784106936, 0.7842196932723446, 1.2096465811614068, 1.2045714018806335, 1.2532051147953158, 0.33305445746068035, 3.2412792742252354, 4.637094659190025, 5.430551411644106, 1.2137329554365528, 2.181604394028264, 5.239560911732336, 11.264502906030225, 14.530333030608393, 27.830997128640455, 25.941487473826257, 30.880353604593587, 42.86645789300242, 60.8093677028533, 62.599411933652824, 39.96400202474287, 13.000257611274721, 3.0284068517146574, 1.5291121097341662, 10.245460348744547, 0.46193640138353076, 0.6371300763660862, 0.5006435453411072, 0.40661474088988, 0.018298408437159755, 0.754193336732926, 0.15853210532617185, 19.709078573411514, 67.15197363207417, 70.48274840078047, 56.85822694532333, 43.42864728743031, 33.413055481449256, 20.525504235298406, 24.22859234194602, 26.488660074049427, 73.9650913976854, 97.61017430213191, 92.19943723370953, 86.64208981298631, 80.74614770950811, 19.542411181234545, 0.10484266410311384, 0.018523575084644462, 0.19079834973860174, 0.2007859146162387, 0.06465138567070808, 0.032763083074842735, 0.028069835013499665, 0.06438409759392662, 0.02062628916915386, 0.008588159727233072, 0.05481635655967459, 0.027337947169378884, 0.034652776835906896, 0.03703189352827688, 0.042528302423776164, 0.006737475163273274, 0.03175897737814775, 0.0032200368033016044, 0.019383903314930298, 0.05053196387786058, 0.010274885196028458, 0.06227100876370265, 0.03296638748818829, 0.062288019746061296, 0.018281636857277444, 0.022391493642522443, 0.052928447783474004, 0.028205838602697177, 0.02922145477045448, 0.032682682147189494, 0.04274081904441119, 0.02843322498994249, 0.10269730381907956, 0.05277727565337574, 0.05548263471874018, 0.0053059943902847035, 0.052445888999969735, 0.05769880450961571, 0.1006155364936398, 0.026930489900311636, 0.04646998184222368, 0.06171898495766425, 0.056817336083059354, 0.21574684568951208, 0.10567039146178192, 0.08487727898623675, 0.19848780406098213, 0.12932590719672943, 0.13561953399931231, 0.11579686340184943, 0.18475748598575595, 0.1552992755727422, 0.19594574046711769, 0.16281868901944932, 0.15240021500616305, 0.12081526024567506, 0.24014115363599794, 0.050928628883294524, 0.11810006844180247, 0.09773776551047642, 0.08290416591109769, 0.17949660699213707, 0.13301716396404853, 0.14476886079196008, 0.07678773524540086, 0.21827406249940398, 0.12455342457659783, 0.10374124417261732, 0.09925300315503152, 0.0971794942574155, 0.12685498252751368, 0.16515645228566664, 0.12907504404504455, 0.09213158004586736, 0.1682777089938041, 0.09950781932040569, 0.13476911511632705, 0.19806521464019053, 0.19124536204241938, 0.1738494205018205, 0.5908837998586317, 1.2870916964546328, 26.116948819929554, 86.77728606808571, 145.1516071442635, 108.01857579138972, 99.47563002186438, 88.14477336022162, 65.84437308772918, 47.32977390289307, 77.27482657278739, 102.46941043484597, 86.88781061480123, 81.45494353386664, 59.33630197278915, 34.251536630815075, 4.893984410070605, 0.6069728107221666, 0.28503321651970187, 0.7044934745757812, 0.4956849646424094, 0.3748953606813185, 0.6926231566936739, 0.6302257855573009, 1.6104570415712174, 3.460123505323164, 9.272761575637325, 17.87832602377861, 17.588611918111003, 15.944834832222233, 15.828043318563893, 21.400077073804795, 26.744732010749082, 21.831094564930087, 15.939482758122107, 20.143306524522846, 35.74084881813296, 22.406033623603083, 14.500504386040474, 16.72552966302441, 16.28837856554216, 21.962188020829235, 28.15377289249051, 20.40330671495007, 18.23408695959276, 30.28630279725598, 41.5915620711542, 30.71338026754318, 34.21155198927849, 25.17546230746854, 15.62598143854449, 10.743527816187951, 15.472884466571195, 13.570658487658347, 31.689226742713686, 44.07082165441206, 32.97522875570482, 32.114909810404626, 26.592855876491917, 23.936993537410615, 15.368538633469614, 13.771849601499497, 11.674316064003976, 26.566719162848692, 21.568403628564653, 25.121908226320823, 31.94446517575172, 47.73771216792446, 48.290087792181204, 26.958428621292118, 8.670163923694242, 16.12688183784485, 7.956197925152318, 22.994200875682218, 1.2878264054175348, 0.8461338774331155, 0.49616220677571915, 0.6895846068378418, 0.17271916502185408, 0.8923492039884291, 0.2700043794128203, 30.164097432167303, 90.6873635322817, 92.51109307812106, 87.824033306491, 109.61906756124189, 83.50307972200456, 34.25580024719238, 39.512078300599136, 28.290795010905114, 59.71835259468325, 85.77517540224137, 93.07636153313422, 100.72770549405007, 92.86469474915536, 17.32771154372923, 0.23317076476110568, 0.13108519747132255, 0.2685625100087735, 0.3623543481432623, 0.1792978837845787, 0.1044957182039657, 0.19944797269999984, 0.16797781621496524, 0.11057798900911886, 0.1164431275138932, 0.12028570196801618, 0.15338531214623682, 0.17390188220287525, 0.13001078980103617, 0.0868227745917055, 0.08761313218142718, 0.11097717444382368, 0.14194683802704658, 0.12954963551413629, 0.1405328848669606, 0.09221075523284175, 0.18414411002830153, 0.1341044725549798, 0.08050326933904041, 0.10098276840102288, 0.1980401329215496, 0.12036556663412241, 0.07414070228415151, 0.1556224114592037, 0.14778591422063692, 0.12861632591774388, 0.18488421225019042, 0.1575171920440851, 0.1415975938641256, 0.1439759751120883, 0.1287224750605322, 0.2134355431001994, 0.11127952636489946, 0.1208879313461723, 0.147480245138849, 0.24336203241780882, 0.13080128528658422, 0.1486281206410739], [0.051210028299641226, 0.09423020130564129, 0.025784001017229694, 0.04764423758212117, 0.09187579094882935, 0.08906908228152222, 0.019593075961775838, 0.03132701295638277, 0.05422191446526878, 0.08484109665357298, 0.08662009837045785, 0.051842234698274446, 0.027961077341329188, 0.03661978419028944, 0.012248238631253763, 0.026246377214368795, 0.10830925026487921, 0.014562347975199022, 0.06299120036043948, 0.03171105474804438, 0.02876802648027097, 0.032796825417467666, 0.0859791892130048, 0.05458298702574065, 0.027501001323182738, 0.03518731851551322, 0.03825110713801077, 0.029697363910775994, 0.04440240246514159, 0.019170070938285322, 0.08763161788304007, 0.009354138483984337, 0.03387893993227232, 0.027957754434957623, 0.05440752224756345, 0.16849581422584672, 0.1234813534744805, 7.430996971745645, 49.75224541079614, 104.91536125060051, 93.77704589597641, 76.49014857507522, 73.56572351148053, 69.00131625513878, 42.35948370349023, 33.978390616755334, 56.77960303521926, 58.93808726341494, 51.930039467350134, 46.822493768507435, 26.897765244207076, 8.101103517317004, 0.4651038378717438, 0.14139766023764688, 0.04448479905183758, 0.1979559092151542, 0.16322725903122656, 0.14511119484180404, 0.21939193799851403, 1.2408725701032148, 1.8450853805388174, 5.441341851988147, 6.195381725988081, 7.3850655267315535, 10.064677326909958, 15.809397351357246, 35.01725781348444, 44.024616133782175, 54.837433599656634, 62.490142545392445, 84.42949648826354, 91.9414629474763, 107.78583019010483, 109.43337471254411, 124.5710720554475, 110.63533798340829, 85.60977689681515, 16.963639105519942, 1.5871961607087044, 4.567236265828533, 16.23368013289667, 17.431705344107844, 12.518067898288852, 16.853995130908107, 11.036148398153244, 3.007845542123241, 1.0179160403147822, 6.82411216920422, 12.584630520113054, 10.684221579182534, 2.209410566476084, 0.6163382049529784, 7.586363034863626, 13.492770021961583, 5.778398965635608, 3.44476840669109, 11.631046437448072, 36.89922278927219, 73.89507709010955, 94.30622070066391, 108.79553456460278, 113.71570079557358, 112.77864656140729, 130.3404784971668, 140.67381366606682, 139.3845933483493, 135.98065068644863, 120.54979539686634, 57.820635380283484, 11.13251220795416, 4.608539804335564, 2.392717388368422, 1.0737398867645571, 0.7354215472455948, 0.28862868165296895, 0.36632997674807427, 0.27728972235514276, 0.12860095819398282, 0.9486247971653939, 2.1575739931675697, 37.23374212941816, 64.9215688243989, 64.25431482253536, 58.96214315968176, 98.06975057048183, 191.77520536607312, 126.69471386940249, 31.33577019937577, 32.54365428801506, 47.33744605895012, 59.8141800203631, 72.24397890029415, 65.92207524084276, 14.290412433685797, 0.2415619403003685, 0.466765635797093, 0.08256704892001807, 0.05886226990109971, 0.06542239187946243, 0.05407639223361208, 0.03417271549903578, 0.06236258691417114, 0.02639650746489004, 0.005244740872688953, 0.05454696174110136, 0.05419993923316079, 0.014126010148996308, 0.07220743344195428, 0.03273515150912347, 0.034750085324048996, 0.02736703169742419, 0.0522536315744923, 0.04456438409585146, 0.049111993097129374, 0.026192781703186133, 0.05136943587492551, 0.01369265144720914, 0.028128879325043772, 0.0174118033910711, 0.04751850340154864, 0.043252083142438245, 0.05080685537729052, 0.01730571936575636, 0.01832896385401968, 0.023826223107114918, 0.03398903825831029, 0.01412893660486706, 0.07168723675873011, 0.03687705949790055, 0.030946862891376502, 0.03474952607986427, 0.026093502453858816, 0.03864689880321103, 0.04321248022719257, 0.04222557511961749, 0.024717959027076443, 0.04568314825695369, 0.014292675449753241, 0.058650649603336096, 0.02037011319771409, 0.030313865506961465, 0.03944295225664973, 0.04081796133710493, 0.04236596839262113, 0.027850504040778167, 0.06811577316013075, 0.0875473635331277, 0.006960681583281727, 0.020107166924243493, 0.05993589999214296, 0.03670773108399684, 0.09016736125152919, 0.02953032609976588, 0.02923498005275765, 0.0204745807775086, 0.02511048332727965, 0.035452806285672614, 0.039971759768142816, 0.022694146253108498, 0.1252268924708328, 0.03566570211983016, 0.03227177556724318, 0.0712131355859099, 0.08275149990954707, 0.010547323298880891, 0.0286347865532603, 0.02852036174566996, 0.08571919429326251, 0.04293711375324957, 0.07132095480037313, 0.06080395421914517, 0.04228673957949204, 0.10485987043789319, 16.374760923847077, 73.54731190589168, 125.00746711607903, 110.8600191916189, 93.49956958524643, 103.53120388523226, 115.93267933014901, 68.13167971949424, 20.890908318181193, 19.136406644698113, 38.84922519806893, 53.36523471340057, 50.127808432425226, 32.84199956924685, 8.839766229352644, 0.5664639198972333, 0.2815495082928289, 0.01256694365668321, 0.030702840904855443, 0.5222258356309707, 0.2646479845768021, 0.18900791032900735, 1.1774274971215957, 3.0541758431542307, 9.329526116771083, 12.898694699810399, 15.214644439758795, 18.83355652132342, 28.499655339025683, 46.041887191034135, 56.576694903835175, 70.60095294829338, 75.73458240878198, 98.22954008656164, 107.23744361631333, 121.08753665801018, 127.80955345399919, 136.78310486578172, 127.5533599238242, 103.0775111721408, 27.4683936180607, 2.9237942974413595, 1.3515412639225683, 2.3916002483137193, 6.7060135256859565, 5.899549703444205, 1.7666254745375727, 0.6473105881483324, 0.5382277576192733, 2.1874043537724406, 11.827690543666964, 22.791590844431234, 18.59799465825481, 4.629219030180286, 0.5433756233223024, 2.429681069427921, 1.8589683646155943, 0.21164943974825645, 5.6543353776777945, 18.450248779789096, 52.967957450497536, 89.82969022566273, 112.50595554228752, 121.42453101373489, 124.93723315577354, 118.73870372772218, 135.92380769791143, 147.31154657179312, 142.9499964560232, 142.8395111330094, 140.3669431132655, 81.27427131898942, 22.91441006045188, 8.091336815587937, 5.173495940623745, 0.9682437573229113, 0.24997271236873445, 0.36920384834370307, 0.32692541698774985, 0.35457898472105304, 0.08560389039977905, 1.4343714257401805, 1.476313207418688, 39.285126040058756, 66.64218318077826, 69.76169909200361, 50.28051022560366, 41.74056506926014, 130.93204252181516, 79.94027322338474, 33.29466658253824, 60.58141523791898, 75.93202667851602, 80.63700383709323, 83.33016595532818, 86.86471569922664, 32.565101808117284, 0.6139404723240484, 0.5338942127362375, 0.17205052348154207, 0.04741917627172605, 0.04972427737929168, 0.10095993898087934, 0.013263195005786276, 0.08680464895141703, 0.05661099030065441, 0.05581882857387105, 0.04883786768562371, 0.05478039639250887, 0.01834422432547135, 0.0716957173520519, 0.07374253574638598, 0.036438244334872694, 0.04945439226444691, 0.062817509075807, 0.04623262482064386, 0.09459282136372021, 0.056321098799667055, 0.033428564502467076, 0.02170035976075357, 0.008604579864280119, 0.030394906118031473, 0.012204647270752298, 0.026131883458865267, 0.0125109234772202, 0.08019907114606711, 0.028209762888089306, 0.07230137880410879, 0.048400144197887955, 0.019228552175205083, 0.05665873673053519, 0.016973269765355417, 0.01887584337964654, 0.037238059280019616, 0.02984331515167029, 0.08196150238114981, 0.09607609015919509, 0.012484079756353413, 0.01587226160711819, 0.14748485698815317, 0.292063421539722, 0.136556290991364, 0.11820403423400656, 0.1424721291949672, 0.1373151164021223, 0.2011041628617433, 0.16884128923618025, 0.11333709297281121, 0.20996783078918535, 0.22454723475440858, 0.1669839550290377, 0.11485625298753863, 0.08730588495851525, 0.09129285166460661, 0.16347954710645063, 0.1574453176750291, 0.12358832233134778, 0.13199979920060406, 0.0794494770947964, 0.15650845343066802, 0.13335683202791598, 0.10070701505267814, 0.2536104961989388, 0.15649167610512627, 0.16787231058603333, 0.1579944801426703, 0.152964040396675, 0.09066825251906149, 0.16675756072565434, 0.14523894766405707, 0.11900844187625956, 0.18710770584162206, 0.17279042652057064, 0.17108889927546825, 0.21131467464710438, 0.4052545364585615, 21.380577010493127, 88.74573538380285, 141.4716551380773, 121.13680947211482, 96.19024492079213, 97.65417545072495, 87.53773166287331, 49.9548868210085, 46.27705289471535, 86.4851636271323, 86.03809971963206, 74.77590807022588, 71.75809921756868, 46.233055668492476, 14.46570021490897, 1.13738120082886, 0.5105144656713932, 0.11970884542191222, 0.4339401471999384, 0.4499174624441132, 0.3073947101591095, 0.48050297123770563, 1.8405817641365914, 6.352863907814027, 11.387523143522202, 12.401177344783662, 14.721125941122732, 17.5416866425545, 24.51800246392527, 42.47754312330677, 51.604584724672385, 64.6777621392281, 70.0227249822309, 95.46430049404022, 101.10630050782235, 116.79261192198723, 125.19673716637396, 141.4603744014617, 127.29544055077338, 93.65291072476296, 21.130355288905484, 7.854797301753876, 15.106899872902902, 36.9118449764867, 39.08314358803534, 29.440510349888957, 45.908157902379195, 32.221090332154304, 10.324576516305248, 2.3354282302241174, 11.398762695250973, 21.249267824234504, 18.796305771796934, 3.772470912625713, 5.259181097630532, 24.525494190954394, 38.40563651054136, 18.078264920942246, 10.554643138762444, 15.320634726555118, 45.64805769151258, 83.56702220055365, 112.26759310691588, 123.49837441598217, 125.49071881078906, 117.53794854687108, 139.01275265601376, 159.01864482510476, 158.3227849775745, 154.85919091009325, 141.63785380701867, 66.23179343438917, 14.283761074466092, 10.915983646146714, 8.688181331080775, 1.7838282546689435, 0.4877047186657306, 0.28274932455631996, 0.66793036557013, 0.7266744779002282, 0.2233922193127294, 1.728606553327653, 4.413842174314684, 54.693666965730735, 84.1660544180101, 88.07864219911637, 86.91490634795159, 123.67652846920876, 207.83666795299902, 144.73870708096413, 43.870435607048776, 44.384242565401145, 64.87518679711127, 80.37336564833119, 92.41822704192131, 103.5792293856221, 33.23548193900816, 0.3358000552942676, 0.8377813740122704, 0.28626530040656367, 0.18018092269137984, 0.16515081387854394, 0.30512693668565444, 0.1835330936216539, 0.26962967048729625, 0.16423791286445436, 0.18185091775751885, 0.27093238768077665, 0.11797500458816368, 0.11190073174094001, 0.1786157284532824, 0.1916369402240361, 0.0741184167864342, 0.16841486937576727, 0.12148764795593678, 0.1440329107666208, 0.19375117435570688, 0.09679259687301614, 0.11149144160651392, 0.13540605593833233, 0.0827051515901281, 0.16927434341801753, 0.13907333415362144, 0.11435792045367342, 0.11811981818849042, 0.13839788975254183, 0.11108829549724057, 0.1394988193867668, 0.14121721588796185, 0.09346374565915716, 0.16839061503208455, 0.19759554145557268, 0.0833027767798593, 0.1519753426433571, 0.1197019353088352, 0.20697215121359597, 0.15332788619543278, 0.06962478250986145, 0.17654258727787003], [0.030232853624188614, 0.06668024696409702, 0.044593752076428746, 0.0670167817283542, 0.04575225321816341, 0.10197819240631596, 0.01761450451017628, 0.07574926475964247, 0.022430675209409768, 0.003553063363670522, 0.007689771770064029, 0.02889833420575146, 0.02889284135533437, 0.06909986672502372, 0.026686833720774423, 0.011384976284217932, 0.07151479802785382, 0.03747221788451557, 0.03933079698453507, 0.04903467184293175, 0.04786862856558254, 0.10236673687975253, 0.10511134645991749, 0.08484073659224857, 0.015121909128802439, 0.048615989470553976, 0.06912529318323059, 0.05679279445640503, 0.05439150334906675, 0.028073008532726, 0.1171177828444108, 0.023891907485742724, 0.049657413225260474, 0.12572483429985662, 0.09849092187059504, 2.42523800461523, 53.12157315592612, 101.98520952655424, 102.57879749421151, 83.52223657792615, 79.80020538453134, 73.94229458224389, 43.172677332355136, 33.5291301819586, 55.15168213075208, 100.67989180164953, 86.51178867586198, 65.86354563313147, 38.04797126400856, 9.028791131511811, 0.3167585722140728, 0.5252542731262023, 0.021182024671185403, 0.047587225318796215, 0.22460050850866303, 0.03212716498021637, 0.22101598311095472, 0.12915445671927545, 0.7155044256679474, 21.656494179079612, 73.69587559853831, 103.80439696773406, 114.97090631915678, 118.92882100997434, 116.35179242780133, 121.28820511602588, 125.55022901104344, 123.05777457452591, 120.67530339764012, 118.63646322681059, 105.17350812112133, 115.86155891418458, 112.04164105076944, 112.87228922690116, 100.0670293069655, 113.05430289237731, 119.74656458823912, 130.86871193301295, 44.395350717729144, 3.005835082261793, 3.9582583885039058, 10.648846703190959, 12.135569145602565, 7.434935031398651, 1.0414106086377175, 5.032489674706613, 43.36648164256927, 64.91948996820759, 79.1447381050356, 74.41177875764909, 51.87706393580283, 24.631219717764086, 1.8857237095794372, 2.131975869978628, 8.472821635584678, 35.57299883134904, 86.8806875905683, 118.31527602288031, 123.8953104326802, 111.00172658120434, 115.22379721364668, 114.44670507984777, 107.26380978861164, 106.5178769634616, 107.46902819602721, 98.90525464088687, 100.04581712907361, 108.31033737428727, 136.9674248849192, 131.54185341250513, 88.2309478329074, 79.44403848340436, 56.50758274139897, 27.49207296679097, 3.940451318217862, 0.19548700701805855, 0.2252125667948877, 0.10451049604002507, 0.13656104073649453, 0.28284965143088375, 0.2994072323124255, 11.22420447487985, 62.07106867144185, 84.1431007077617, 77.27030015760853, 96.67558331643382, 90.06409106716033, 45.504636226161836, 30.215860951331358, 31.720103640710157, 54.55968272301459, 67.74545177336663, 69.01469153742637, 69.95500133883569, 33.47552707118373, 2.5800733220192695, 0.3934876098027153, 0.035709035883267085, 0.11237372974714926, 0.0391675781218275, 0.04479764254703637, 0.06207632666994488, 0.025700528077000094, 0.08335764399699627, 0.05135705589406914, 0.08107189810083759, 0.029203384671540513, 0.1087505781962987, 0.09518105431549972, 0.050150915574763096, 0.08379285854678001, 0.051858533218863516, 0.07314150146539174, 0.06199230980728904, 0.0407166577004377, 0.08735764951955888, 0.08021397155619438, 0.08027924224734306, 0.06619663097925725, 0.0471639694015105, 0.03825585305270168, 0.013088342140338594, 0.033922059191090446, 0.036225409787749095, 0.02909666287802881, 0.03576248200730451, 0.07167770662495206, 0.11595807128375578, 0.08852073952795998, 0.07062588322667346, 0.0037217913561635803, 0.029545548266821334, 0.09546914934030465, 0.043805508889378085, 0.04453592775990406, 0.029592327510697708, 0.13937365594169787, 0.02507060845082085, 0.03484304243278119, 0.009683046842955295, 0.03564489134136708, 0.12502915751669677, 0.08424649751114269, 0.03885060158227721, 0.05208745178195739, 0.03393982860049413, 0.025485176931045232, 0.021676337158667947, 0.03740159223877615, 0.022916194922741384, 0.03275010937584504, 0.06228300953103651, 0.05891619099965019, 0.07268654482979929, 0.01921551144351402, 0.04406872520884199, 0.09988762273062622, 0.02764003095968116, 0.06665570150700308, 0.07972117783802171, 0.08901360985492507, 0.004359304589489776, 0.003475685371086002, 0.01216948096219811, 0.034125995626973535, 0.09545955025861341, 0.05933671198304623, 0.023276905506669034, 0.014766628193038126, 0.1866726291876647, 0.11963402927522698, 6.063974970771421, 75.49907545889579, 123.65537904923963, 118.13206995687177, 103.20371735480525, 102.23693155473279, 111.138044634173, 74.3022269587363, 31.928269709310225, 17.982802275688417, 59.98088859742688, 82.00389492896296, 69.21993347906297, 43.529154100725734, 11.183462815900004, 0.1040504525806154, 0.8522214572275839, 0.12507373617301065, 0.11711940695081027, 0.5007372838595222, 0.5777046360796498, 0.21396319381892684, 0.08718826747950047, 1.8840716562924849, 35.677977146640906, 92.37282168480658, 120.95623139412173, 131.1218773934149, 127.97883510589601, 125.47943807417347, 130.55911925531203, 128.871017425291, 128.09541579215758, 124.82708515659456, 124.04754546380813, 112.75916807113157, 117.93092296969508, 117.002137091852, 113.62988718094365, 103.87601160234021, 112.95269781543364, 123.52899243754726, 140.05544416366087, 57.87438361875473, 5.878410579696779, 1.3590804271159636, 3.174795835248886, 4.898552500432538, 1.4746892235932814, 0.4945143516505919, 8.90610723726211, 56.34099183544036, 80.61379909515381, 92.3602230318131, 94.07685618246757, 74.6756052201794, 37.7008258142779, 4.378211853965636, 1.6927880817844023, 13.054059782335836, 48.55412606270083, 98.85856274635562, 125.61673671968522, 127.91906602921026, 115.12784034975114, 117.81424814654936, 117.77557357665032, 111.87490109474429, 110.40458494617094, 112.61975134572675, 104.03816238526376, 106.63628547422348, 108.52922916412355, 134.89272640597437, 141.61507268105785, 114.49046304149013, 100.96260055418938, 75.2982344165925, 40.973384764886674, 10.999180059279166, 0.04054842862270532, 0.27685011046067365, 0.09749714495433916, 0.3897314807099681, 0.5633164016950516, 0.635861189615342, 11.370447104977025, 62.80515593867149, 90.28493619734242, 77.99058068183162, 94.32886062129852, 86.28064340160739, 29.893014584818197, 33.9531187857351, 52.07486906359273, 87.83446681114935, 90.58388356239566, 80.7727570687571, 90.05766622481808, 57.672106988968395, 9.206966757774353, 0.24448954530300634, 0.061568077127899856, 0.04651138889453104, 0.021883186643883105, 0.12000550530971059, 0.03483831183984876, 0.08684355089621199, 0.12193634565318785, 0.06525769063662137, 0.047700280744221904, 0.053342851554794665, 0.06985788008258229, 0.0018671524618008746, 0.08050513859357565, 0.08456676056788814, 0.03503573652837546, 0.09112172294408084, 0.04463345458310458, 0.008838410008578532, 0.10297195400081335, 0.19361151652711053, 0.04443839710626391, 0.06731449881748808, 0.0622084308716078, 0.04895792132423771, 0.020655224310053934, 0.05711099673663417, 0.02891281518274017, 0.059732718152865294, 0.05870003929181446, 0.019518612215535778, 0.08289766948549979, 0.059224732911154154, 0.037348069505946296, 0.01437393439588167, 0.1254402632795034, 0.03600245904958537, 0.025324396143156677, 0.014055751267850641, 0.03017544874080247, 0.1945321243857184, 0.1988188612965807, 0.21709065583925094, 0.12354974980436026, 0.16420593635449487, 0.23208734789682975, 0.10308443102985622, 0.12455784490392094, 0.18106794525538722, 0.13108145896225207, 0.11231525425588894, 0.10860090759853203, 0.10043291645424982, 0.16498644205351032, 0.1586035047207148, 0.1860576444455693, 0.2535670590136321, 0.18021570308314216, 0.06668085983443646, 0.1310614027803944, 0.20014431597965382, 0.23068456429867978, 0.14096592372703937, 0.1846009129357915, 0.17121911890083746, 0.21994506880160303, 0.10825687283349615, 0.17375332243259878, 0.12003648590536849, 0.08223797585214339, 0.1321996868618073, 0.12072266319826727, 0.14914734439263422, 0.244039545256284, 0.186860213476804, 7.92329021999913, 91.71475779625678, 144.35062777611518, 132.30471518731886, 103.4090377438453, 102.72662378126576, 98.740570006832, 56.43304986338462, 41.442045242555686, 78.76159314186343, 152.88537579198038, 118.15106991798648, 92.45267329677459, 60.74587237450385, 17.13068892878871, 0.9592705388222972, 1.0492440721681042, 0.21305328054774195, 0.2822686809926264, 0.5920528500310837, 0.3354892993886625, 0.5414572165858361, 0.8964859562054758, 4.629809837187491, 25.874330612920946, 81.48851902254167, 115.9224105650379, 127.48157270493047, 126.5723123858052, 126.35643297626127, 130.38355396639918, 136.17720850052373, 134.21832976802705, 130.38047098344373, 134.1258402793638, 118.45627738583474, 125.83616195186492, 126.12549166525565, 124.32834794444423, 113.1504088063394, 124.44203392151864, 134.3614649003552, 144.47109160884736, 51.538535933340754, 6.014140277139603, 13.391456181003203, 29.04005596714635, 36.338355233592374, 21.69443722694151, 3.6823819145079586, 8.158703523297465, 65.78700842395907, 90.15403885995188, 102.12142559789844, 103.74505150702693, 91.28775288981777, 38.22543105771465, 2.8435183340503327, 7.2531395477633325, 12.246564376738764, 43.68014966287921, 94.56693280127742, 128.28075562753986, 141.41762056658345, 121.63395420197519, 125.18975534746725, 124.39946836040868, 114.38758711661063, 114.7013767303959, 115.92929040232013, 107.41250684184413, 109.4094168755316, 119.95801171948834, 155.30786298936414, 150.82326027654833, 105.46703477059643, 88.01200112988873, 61.72293870679794, 29.494529231902096, 7.087154157700078, 0.23666103070061054, 0.33938314044667833, 0.30081931621797625, 0.8741561479626164, 0.8013744856561384, 0.7013488368641946, 20.530909261395855, 81.46001123612928, 103.80078054243519, 100.26474029787126, 114.10021074356573, 105.97298914386381, 56.73995963988766, 41.99609571887601, 41.59585706649288, 72.85094215023902, 90.13536837793167, 87.39677736836096, 104.01019588593515, 62.18670014412173, 6.4283224651890425, 0.5598996495527606, 0.16843501748817583, 0.2286445334433548, 0.13057139762226613, 0.2908121548112362, 0.17321215792288705, 0.16402342356741428, 0.2150297414271101, 0.2160620908703535, 0.16595591099992876, 0.1608461198667365, 0.22277118247603217, 0.21860026273756258, 0.19714112874240647, 0.2263077201261636, 0.17631895089101407, 0.13606541249300205, 0.20064320775770372, 0.08826809139141152, 0.1524527686377687, 0.24617095507921713, 0.15351498018830054, 0.31155950119418485, 0.12917727081766053, 0.16493733581756392, 0.09942116711529032, 0.0924975325864169, 0.22576909902836048, 0.20210536316998545, 0.1537015685631383, 0.22508559538231743, 0.14467366670648898, 0.1628885562381437, 0.22846180615165543, 0.11200146464210366, 0.17923883372737517, 0.25866027200414293, 0.09399266042295965, 0.15195753875999682, 0.07061747158126486], [0.042163054684116956, 0.02353320979783612, 0.01718143692180034, 0.018457789199366685, 0.023441539716816718, 0.048285372735511874, 0.126999152613984, 0.01829803879973629, 0.04768119749402808, 0.04238640761844093, 0.14758293156421956, 0.05770088060789051, 0.08686510861040124, 0.06361874894449307, 0.0776918032657235, 0.08872823444225135, 0.032888093302326823, 0.06734249933112053, 0.01947458705774719, 0.052169285294029026, 0.15181493915377126, 0.07756170621442218, 0.07773209182966141, 0.2369997488154519, 0.22040541103530317, 0.14434826319977162, 0.06768537730339073, 0.024854121579518242, 0.04914257915750627, 0.08199760810502114, 0.03548388264232105, 0.05067231884646801, 0.10077708145423282, 0.05655911848730138, 5.161230689094913, 87.77094010383853, 108.42792218731297, 83.5245115526261, 79.27464700514271, 66.7081025338942, 62.131159382481734, 38.076220173989576, 41.25894900291197, 87.04409353194698, 106.86637170853155, 73.56921442093389, 52.60702094724102, 17.514045699950188, 0.358405624546351, 0.95515989488171, 0.09352266548141357, 0.37314659645480497, 0.2590131321020665, 0.23166010066145853, 0.06245899141856259, 0.018311370644838582, 0.48455453447757235, 2.1983423732942153, 68.74739769966372, 136.98520106654016, 120.88713492116621, 111.35183734278526, 105.11708874856274, 109.58138927336663, 107.85839403829267, 106.54993841725012, 100.97802331370693, 103.5457637233119, 101.04045960210986, 108.10553473810997, 95.59538610519903, 105.6279068608438, 111.94515858927082, 101.08816346814557, 96.74072604025565, 95.19701450101792, 98.62380889154251, 102.8201879993562, 115.94537212002663, 62.434519413978826, 6.2437470016940955, 1.6841799501449832, 1.9290665128538687, 0.1377848661955326, 7.905135529656564, 48.75996028223346, 73.21783281141713, 86.94179811785298, 86.04010012841995, 95.80614289929791, 92.59731461924892, 73.59369785554948, 64.66464181100169, 34.13587377917382, 62.52895047587734, 98.9565670874811, 118.52098080419727, 117.05782690355855, 116.65398751535724, 108.73448679524084, 106.43209472779306, 116.96091298134097, 115.60911516989432, 118.50736233495898, 121.34482060709308, 109.22736398635372, 100.29599374340427, 106.69695669604887, 99.06813498466246, 107.30007602322488, 117.66220923393004, 121.85581914840208, 133.84819922908662, 131.15633933774888, 113.80878648450299, 40.53399693581366, 0.21755496640839886, 0.03827747205392488, 0.15777571607501278, 0.0841493345797062, 0.21027333133162993, 0.6730189667113367, 0.7017973966656194, 23.819185149285104, 56.965291961546875, 51.02915733091293, 35.15037129002233, 48.81926651923887, 77.81111655696746, 33.344170816483036, 32.63452187661202, 50.14915789327314, 62.93093458298714, 65.13752668134629, 73.78066939692344, 61.78131926444269, 14.322766104052144, 0.16063811167353587, 0.038001201596231236, 0.07924326154733859, 0.1991155977931715, 0.07993854762565705, 0.13656061172725695, 0.033959850308395205, 0.01948729454119119, 0.11920148071141974, 0.047873470241263996, 0.03676618359261944, 0.07136391701116677, 0.019909862894564867, 0.12749232171523955, 0.13663426342029728, 0.14518925920128822, 0.04292695159693399, 0.0806618725220042, 0.10873982998272104, 0.15233368793081853, 0.12010633014142515, 0.08002751341630375, 0.04929541752883985, 0.08967131165967834, 0.03781429912534453, 0.053454183282390724, 0.061008672064711014, 0.07048834746162738, 0.04352942995366551, 0.018535813339234843, 0.0349735684933201, 0.048725938409446716, 0.02069481381876094, 0.059109095769423636, 0.025054712126392032, 0.008870061888780085, 0.03184036847444312, 0.04507181009337787, 0.0345529823924505, 0.07235295184317135, 0.08107911464908431, 0.060996885801995956, 0.02874045880631574, 0.034594849097512426, 0.01914425377523707, 0.18175685748217568, 0.06132704288428349, 0.02671067246175822, 0.06035373200692477, 0.04594744476039083, 0.10944835406037108, 0.05075925067367573, 0.01684663160103223, 0.11823755058069384, 0.059548167571906126, 0.018869739574109836, 0.06776584717895716, 0.048891118457240444, 0.06566433010682945, 0.21005613008333793, 0.17005808200807343, 0.10092574847681869, 0.22337631532742133, 0.3330831704360824, 0.2035684532095348, 0.2007599135920886, 0.005786958753296565, 0.052886883683142163, 0.22805050886686773, 0.022116985187054645, 0.05184967341201921, 0.12042146806995715, 0.008369154341879391, 13.421874161689514, 111.58614404739873, 120.95529787002073, 98.7725765474381, 102.89304210293679, 104.0275876752792, 105.05346005962741, 59.774654296136674, 23.132778213870143, 43.44636855586883, 78.24730765435004, 79.72299745005947, 65.35077418050459, 21.997208902912757, 0.1780910501557012, 1.1105977864034715, 0.2387769961909902, 0.6709781084810534, 0.06456293315897066, 0.868772327178909, 0.5064367328680331, 0.349701578698812, 0.2905662712310591, 4.746847969870414, 87.96112798875379, 141.41079564248363, 120.44154582485076, 110.68486182920395, 103.82560914562595, 109.97291241922687, 107.47990885088521, 108.58163987436603, 104.59647255559122, 105.96252426024407, 106.22132224421348, 113.49039985287575, 109.11530971527101, 109.89875608874907, 116.68183634358068, 110.02430331322455, 104.42108769570629, 102.23525278029904, 105.00374794006349, 106.25309344260924, 121.08390454323062, 77.69892108055853, 10.121387935453846, 1.8706951482642082, 1.3969461307410271, 0.1453441162143023, 15.00721283497349, 66.72870282203921, 91.01008046057918, 97.8316548562819, 95.77572099624142, 108.25774623501687, 111.40890782879247, 97.72284046296151, 78.96342262145012, 50.22194923893098, 77.6812155016007, 108.3070739623039, 112.93000298161661, 117.49662245473554, 121.37011204996418, 115.2995538711548, 111.2980067345404, 123.62377259039111, 121.79746996971869, 125.12662872191399, 125.84460289247575, 113.93665575212049, 103.62559180105887, 113.89367441977225, 108.74642649004537, 109.97788598460536, 113.37462717486967, 119.2559309928648, 132.79049288841986, 138.57463959724674, 127.61738869451709, 57.421067453199825, 1.565009273828999, 0.026823266319209532, 0.5604873922082686, 0.1092893218681697, 0.2843737680344813, 0.8876282024768092, 0.2852095086728373, 21.999507411833733, 61.88197905017484, 55.40406311711958, 39.86799024766491, 29.414089264408236, 27.541204575569402, 26.605138778686527, 48.07505169222432, 82.72838023401077, 95.08366584777833, 84.06597906543364, 87.52228536913472, 81.38709437462592, 32.699464559555054, 0.326635713178304, 0.0440473934905904, 0.24665806442499164, 0.09531660591282191, 0.07930586625251078, 0.1556080243279857, 0.07013761708813329, 0.05461491373998504, 0.2600295162729679, 0.14691838093342321, 0.07248094981356014, 0.17998042215983714, 0.03840192686766386, 0.12355553376818858, 0.12293396833082362, 0.12600192064118962, 0.07183461675360318, 0.08405972527520311, 0.16270065019207616, 0.15811952101367135, 0.23031278182902645, 0.03724297373405388, 0.08354636209626352, 0.05213994029608946, 0.04890770426080112, 0.09559929235688142, 0.07853996218933214, 0.03148845449510602, 0.06027582086502545, 0.09116101559371718, 0.0722929135325455, 0.09217093398253765, 0.02548067233405046, 0.06558595931217556, 0.05503625826789968, 0.09492718809915167, 0.027092837338005344, 0.03638978161278271, 0.05707596353585682, 0.15701546574071532, 0.24344503038352538, 0.1511688512419501, 0.11142456213072424, 0.1289507232966923, 0.13584805802712518, 0.372384216396078, 0.09122375819471576, 0.11825530849877866, 0.11005449814782028, 0.24533375887380493, 0.3271639767673708, 0.17025191757467487, 0.09073818102478982, 0.19226389125950877, 0.18857487146892857, 0.11274557350383652, 0.21636259651953177, 0.11663039770698357, 0.15867885712894703, 0.4140119326691474, 0.2887070984128983, 0.16390774429084795, 0.38449355371056065, 0.4401858781854953, 0.20325863193119728, 0.25966347946274665, 0.10209728843502461, 0.1500511902474588, 0.314148755804185, 0.2441197086966807, 0.1492857918023102, 0.3221428832940517, 0.16399133980514544, 17.64145605025753, 129.60187265949867, 135.52132544978974, 107.3863132538334, 99.61651371371363, 88.9974574119814, 80.71884016836844, 51.595174958628995, 57.439914441877804, 135.173426904986, 150.28834312192856, 91.20972125760971, 77.55220874663323, 29.633063424018125, 0.8855055260562128, 1.3025354161377878, 0.42445892047497535, 0.9313624460370311, 0.5644016112050703, 0.736863998876464, 0.22778125960500012, 0.3686827859811245, 1.988678449584592, 6.595003095365341, 78.51413865243235, 150.73608952183878, 132.20063117242628, 121.7140882245956, 112.33583450317384, 120.84926051478233, 116.42638806373843, 113.78839015960695, 109.07875322526502, 108.6060134826168, 105.50512098496961, 118.30842756455945, 111.11974285494898, 114.81012836579355, 118.86371750985424, 113.04047261514972, 109.94051364160354, 105.13950901646768, 107.72885384098177, 113.49385153862738, 130.2995289525678, 76.37237548828125, 8.708509995091347, 7.044031129729364, 9.831201184180475, 0.35173784040154954, 15.258056252233445, 82.54216178770989, 97.44415606221845, 103.3266915044477, 95.88805767797655, 108.9134096330212, 113.7234200200727, 120.98679450250442, 96.3520505351405, 46.775001710461034, 80.95109939575195, 112.26401590531873, 113.99848799551688, 124.7269235118743, 125.79644403150006, 122.77195930480958, 116.4633289460213, 128.12859904381537, 126.49061725985621, 128.73954742185532, 135.9175632845971, 121.71357047173285, 112.33221023313462, 118.2453715416693, 108.03086065476941, 117.15228542204827, 126.7997157189154, 135.70834405960576, 150.48419490937266, 150.56513694024855, 128.3952888365715, 48.21919095131659, 0.9773488655205697, 0.18420954925879357, 0.6565586789961785, 0.22178225489633702, 0.4550807724796957, 1.3433262273188562, 1.4290169001586976, 34.649080614889826, 76.26995455834174, 72.2054220015003, 51.39398090301022, 71.53664219763972, 108.69935804797758, 45.65668690589167, 40.63924197227725, 64.95797626433834, 84.50941870289465, 84.46887708479359, 99.48182736673664, 97.02755328147643, 29.487368945152532, 0.16722942492173565, 0.15907682448385224, 0.3531675749728757, 0.27887846613603257, 0.2035589383975152, 0.2924547698949614, 0.4100593786326147, 0.24599815628701643, 0.38185744516311154, 0.20219141016564063, 0.22696024317654873, 0.23136622933370454, 0.15871426571280728, 0.23121072880683408, 0.22788287350727668, 0.1884191564374393, 0.16079301465182536, 0.211565277328895, 0.3123924839160135, 0.31703381228350824, 0.38617879392639287, 0.16332409254485564, 0.16314968496801394, 0.1301517040138283, 0.17576237269226583, 0.17046773986470315, 0.1342425522424521, 0.1882850144418978, 0.1084990868525159, 0.2455907354071256, 0.13877469775897844, 0.2344425473242037, 0.09671221126712139, 0.16847712168049428, 0.11598159018303118, 0.18627662301784564, 0.14702203262957836, 0.15815442397950158, 0.12475292919383896], [0.11138428122766557, 0.059438521237743486, 0.06379953037286479, 0.027331751433291265, 0.020717373192911188, 0.03937731384329739, 0.047276201282417586, 0.045150724810458, 0.023401454166178743, 0.06740765510908059, 0.01785904935170566, 0.007015204539657721, 0.1082364948947103, 0.015084557554444239, 0.0925080203301003, 0.08394150258672815, 0.05819191232383732, 0.01630897960445333, 0.03262946584952935, 0.051982329196987614, 0.11201474860671068, 0.1458498414966368, 0.028939647412288095, 0.10343438765454678, 0.048248612006465276, 0.09312858219228445, 0.04335614852607251, 0.1609719421474203, 0.03300008386553776, 0.032377748509808894, 0.09718111070293574, 0.0195355293521237, 0.09994583009111305, 6.004570674511695, 85.25011124149447, 91.51917272998442, 90.63355645825787, 84.5588170328448, 64.08770822709607, 44.966993024272305, 25.43768452059838, 47.74117169841644, 82.24253193024667, 78.00503853828677, 62.78293963401549, 45.95329261595204, 7.4915142405417665, 0.5721122555194363, 0.03612349711118206, 0.2609536634577859, 0.0515791715963954, 0.492702063413397, 0.017611166282046228, 0.41278610005974775, 0.9220991560047673, 1.6405549813662808, 1.091319582154674, 80.04667928141933, 129.44944935460245, 93.98953637769146, 93.39330473253804, 93.81770518518265, 101.76507042300318, 103.75806593125867, 107.78888963883924, 112.18308171918316, 111.12199429542788, 109.56800614633869, 109.27357735172396, 114.12832629296088, 111.66931398453252, 91.96232995679303, 102.05031302667435, 94.0823631901895, 88.68332262962096, 95.1147545537641, 96.65134306876891, 104.37889868213286, 100.10514690030007, 113.23337478022422, 68.86523354438044, 16.24850571155548, 1.935743122331558, 11.60904194078138, 50.26475406462147, 73.12450393553704, 93.70427023979926, 102.22029286046183, 110.91440677642824, 113.5970098741593, 116.91433875791489, 106.9017122637841, 81.18544532406716, 76.4035269521898, 102.02671604771768, 100.72424596355808, 106.43708398265224, 117.7374638280561, 110.42043916640743, 108.89935185832363, 100.94551470971878, 107.72860280929073, 114.47640526679255, 112.77902310894383, 109.76081417452906, 105.39900518232777, 86.99153377163796, 86.83858486913866, 113.24737764173939, 113.59054580811532, 107.45062443517871, 98.33151386630152, 96.14010134050923, 98.35442050810784, 99.96009765132781, 129.27677093013642, 62.003792178246286, 0.12769373389141214, 0.25730420444761554, 0.09633597016574875, 0.28508754747529186, 0.05565000194755774, 0.19047293091012588, 0.3576652158892924, 3.2818625675093744, 27.427000845632246, 62.221240535859145, 78.31506267670663, 81.13023404152163, 79.36352006850704, 47.31530820169757, 18.573546524970762, 26.030533121478175, 58.07674261831469, 67.36452687171199, 72.2874544512841, 68.14463923054358, 39.34783689437374, 0.43991495885195275, 0.30720021575689316, 0.15460893842241458, 0.07080657272449425, 0.0059798041512558785, 0.0695351961879961, 0.11346244793986121, 0.053432200389403495, 0.026705911225308816, 0.06834297185583461, 0.04545722509764376, 0.032217073059009935, 0.016645782499483997, 0.04959471275909774, 0.02067843485893982, 0.19539913673314357, 0.12217298255211885, 0.10166321535624805, 0.10066807480348695, 0.15773716653066297, 0.0785659938569992, 0.04328768324827956, 0.06044088216919092, 0.015343514425049146, 0.04139315547241319, 0.03132613961614909, 0.03287267195241105, 0.05420911313605405, 0.06395222701793236, 0.04588033162778424, 0.11197507291311219, 0.07848082786245693, 0.024573176070266677, 0.03664069456018267, 0.033555359714814735, 0.03252930751430892, 0.03414506738584849, 0.05436883097694767, 0.057063503115768396, 0.027812335625170704, 0.0159896511749755, 0.03667676581009742, 0.012865081136565537, 0.01225163144314842, 0.024661023372543917, 0.07601302117109299, 0.028939340977118384, 0.036973218854156234, 0.004930096113258192, 0.02069222635679668, 0.13180196465503785, 0.0603383987571203, 0.07062270396178769, 0.06585666414109931, 0.06239590790843772, 0.019173717516804897, 0.050025353763973525, 0.04165256433489342, 0.08205105039861896, 0.24292900887948854, 0.10349709195114913, 0.13724149535259894, 0.028467093737074928, 0.10490171416031738, 0.047350404558763395, 0.23351061668607498, 0.006999519368213031, 0.05175487386182912, 0.11873505573960082, 0.050035378024462736, 0.07742259230825209, 16.15800290338455, 111.09496916494062, 106.17918029908212, 108.19929507470901, 108.89044807803248, 94.65141281004875, 64.63376099063505, 28.476938932172715, 25.597589746598278, 55.95448147866034, 80.56920174629458, 73.91972526427239, 52.77714983109505, 8.596086040619882, 0.8686734711931599, 0.12506007682532072, 0.7393115578639893, 0.08986282597986922, 0.7659384452046887, 0.34140656251580487, 0.9572145426946302, 1.3621721128302238, 0.5729065354793303, 4.424440418520282, 98.15678796460553, 129.57927196256577, 99.25982121498355, 100.97194363993984, 98.64941412402739, 109.46485565554713, 108.72308054277974, 114.15273128017303, 117.77814665148335, 116.53534366238503, 113.38305242599981, 112.17330717271375, 115.51843781625072, 114.09700224476477, 101.9170779566611, 104.53699373429822, 96.51854730421498, 93.19655079995432, 100.51159858703615, 96.0706518542382, 107.24178175772391, 105.69310449784803, 119.72873349343578, 84.55693429516208, 24.410651114679155, 4.959197736555531, 18.3200123617726, 64.50489544099378, 85.52125684676632, 102.4253700625512, 110.43399487772297, 117.74137835348807, 117.51725412184193, 119.40337288764216, 115.7041463544292, 95.35001831669962, 80.93584137578165, 106.86812108562839, 105.007584018092, 109.98542478007656, 120.74869094356414, 114.27622318267824, 112.14240674049624, 104.89557681545135, 111.13983323497158, 117.24731660658314, 113.56052398681642, 115.38470852759578, 112.33905869145548, 95.13342503578433, 86.68845222842309, 112.6705538841986, 120.53837345492457, 118.2649520135695, 106.1491035646008, 102.33287272914764, 99.49703047352453, 101.49487403131302, 134.04560427511893, 81.74856432022588, 0.7975057416385221, 0.32483191319531013, 0.30300159427908163, 0.37053929281330883, 0.247248595640544, 0.14060970816400745, 0.6347040291274748, 2.478440788484389, 29.093098178986583, 72.5111315327306, 85.14368164923884, 70.67341481485676, 37.14306869814473, 41.308429702635735, 35.03870533358666, 50.88843837861092, 88.39596194605674, 90.2287050985521, 88.32899139773461, 85.29645796745055, 62.44812219373642, 2.3452670055051006, 0.5359188299025259, 0.1415138144887263, 0.030105104632375222, 0.11951206041680229, 0.03713107893183347, 0.18497084147266804, 0.058994776298922885, 0.03731227021724467, 0.05063776062020371, 0.051830314370172645, 0.05429490732269422, 0.04479282002355303, 0.18350235817413177, 0.15656961789054258, 0.14042397780764487, 0.17807716864251322, 0.07576372083877364, 0.05740292220106048, 0.04862784468118222, 0.03462394128643698, 0.02555543485458099, 0.043074618874778675, 0.04967989407539849, 0.01764269271535018, 0.022509411811047507, 0.03705961825025659, 0.07371137895050549, 0.0488339644676495, 0.022497263571788228, 0.09015992253778443, 0.1427737686542734, 0.032434504133679216, 0.09220965972711002, 0.03989431593987731, 0.08419742191871328, 0.03035433218634177, 0.019762059636113626, 0.28243449306295765, 0.13259425278632872, 0.17275298014283183, 0.14640805912354302, 0.17373611609781944, 0.08665973575966013, 0.25562518486572855, 0.18810984077713183, 0.2410982885668355, 0.19907976020007365, 0.1746892980149677, 0.0955461181940571, 0.22802876729157665, 0.291037047582288, 0.32181150430152494, 0.18034777664128812, 0.12243764294732003, 0.15623624706941266, 0.12861254144339793, 0.16983985420196288, 0.15013985726381504, 0.27979731199241453, 0.20717442906912298, 0.271003358066082, 0.220512050474363, 0.2511624009498666, 0.17527722453157749, 0.3643941032069345, 0.10301889986881327, 0.12489261000507301, 0.30542568033260686, 0.14546926433761276, 0.14326861548808315, 21.78134910521969, 135.83541316370813, 114.69138253119685, 116.2030561508671, 111.36283566874843, 80.66507231804633, 53.74661068762503, 36.501553289351925, 66.85290075117543, 129.34215684090893, 106.92206936497843, 82.08651573427262, 72.36624702330559, 16.73018159404878, 1.537921875715256, 0.3023672428342604, 1.1253044682164346, 0.30794289203420766, 0.7489209970639599, 0.2781192730030706, 0.9702696615169126, 3.1964343257488745, 7.346880272511513, 3.7956577587512235, 92.8855303795107, 143.36054309721916, 105.75036325762349, 105.68702482408094, 104.16631406353366, 116.11744649948614, 113.44426493490897, 114.84204861425586, 119.8530020252351, 124.28909286375969, 118.84481168562367, 117.48787556925129, 123.98237136102493, 122.43759293710033, 108.06331434557515, 113.80303628983037, 103.30059205332111, 98.99801869546214, 106.72939469737392, 105.27886298394974, 110.82666335567352, 107.8959232761014, 123.84310368568667, 84.47237583898729, 22.01150005863559, 3.714651744211874, 15.322406657280462, 78.0197552711733, 92.0024871826172, 108.50345134735109, 114.0865687401064, 121.33246514105029, 122.1500204455468, 124.69082986154865, 116.41597024856077, 106.300138350456, 98.33637760531519, 113.76574239423199, 113.13445260447841, 116.74264877073227, 124.37109393458213, 124.19874498921057, 117.36529365662606, 111.74143068252071, 115.66296146761988, 123.192304026696, 115.84781492910078, 119.30687473666285, 114.36803017893146, 99.95599485212757, 97.44166927952921, 125.9376415129631, 128.96037686255673, 119.40093317339499, 109.59039503528227, 105.44467726061421, 105.87789520140618, 112.38058090209962, 150.41042297117173, 71.69440777071061, 0.5161942721855256, 0.7406010983451721, 0.8563978621555913, 0.4474895765944835, 0.42877211806274235, 0.3156604924269261, 0.7947124012054936, 6.72093177034009, 43.43065554095853, 88.97116968708654, 103.7610077088879, 124.30985004671159, 105.65812480065131, 64.85267631469235, 26.182205292486376, 33.77099921626429, 78.30855154222058, 87.79492147507207, 94.02839137661843, 102.83863882864676, 66.11438905039142, 1.5327970539369893, 0.5760268422384416, 0.26560188661659917, 0.26525653418033357, 0.2114891588327385, 0.16375365336575817, 0.1549142704255158, 0.20496238083128007, 0.11162080321340792, 0.16436728979310683, 0.17677607555543223, 0.14235880946920765, 0.12949901242409984, 0.2415168177216284, 0.3909755462119657, 0.27431040641761595, 0.30275561876835366, 0.29147626111103647, 0.15648692635999573, 0.3561336222675539, 0.12797308019212178, 0.17638518685294738, 0.1857549477849276, 0.18152949790800774, 0.0950280282526247, 0.16485819893498577, 0.11401604605658401, 0.18232681157608188, 0.2538969824391027, 0.13454607627805204, 0.19656766596580708, 0.3085290718703501, 0.12087565861762532, 0.27206886379468825, 0.2518968800863912, 0.15942858141516486, 0.10418611909112624, 0.16283120689613206], [0.05547039263371018, 0.08257402798100826, 0.0563949152016111, 0.020678093949813518, 0.06734943242683526, 0.03227017061304181, 0.04484242421665019, 0.07655333532320877, 0.01541731263240499, 0.036723014538086234, 0.07942566708210977, 0.004994567200135921, 0.07556965544579491, 0.06644350281285663, 0.07915018186453851, 0.04413569661518259, 0.04146208806383995, 0.020359726960680658, 0.11778933551883507, 0.07246627922981017, 0.08723674552334894, 0.09372302045625064, 0.15304962773957562, 0.0037145748079168584, 0.044201315876336834, 0.16016632408624695, 0.050605056326716184, 0.06608298183569024, 0.025467836530879143, 0.0783953630936242, 0.2356092532676074, 0.03529452869007665, 7.28314862135918, 97.04645910570699, 96.32326818281605, 94.51108609476398, 86.43481608360045, 65.91082588318856, 29.69529574917209, 47.80296079574093, 84.79093505490212, 76.44821843793316, 79.81924456934776, 77.23483408651045, 39.11361648190407, 2.336987617515749, 0.6763744318196852, 0.10444887192739595, 0.20686359655472542, 0.28318384962697185, 0.04284725547017109, 0.38326373744395476, 0.37526657624590787, 2.103783098920699, 6.10104872334388, 2.967536814751164, 83.19340075215986, 121.17144400073637, 95.04692892874442, 109.96993926263626, 90.91665744781496, 91.82872618398359, 95.83715315788024, 99.85646863137522, 103.9139566113872, 103.56303784155078, 104.09105946940761, 100.42947984510853, 104.01188250510924, 107.22073431937926, 102.68261478793238, 97.81863258730982, 89.04266665058752, 94.81552477805846, 96.15719502972019, 101.57362737963277, 90.71785603800129, 87.76033401489259, 105.39346679564446, 102.03861651882049, 102.56053493868922, 69.50352868726178, 43.18909245152628, 57.69500970840455, 65.89188867999663, 89.02713406470515, 93.39019821536158, 90.77316930217128, 96.43314161608296, 92.86871910095216, 102.85231221106746, 130.22820457335442, 110.16575967111896, 78.96629379641625, 104.87990302424278, 105.84799105121245, 96.89031739388743, 114.90155881451024, 118.30137514298963, 106.83397293090822, 106.32141328627064, 98.69591774479036, 108.65205426369945, 111.33890921069731, 110.5386672481414, 111.08973672313076, 119.34827927620181, 93.51638870854532, 81.31951978129726, 92.23451891253072, 100.85815568124094, 94.10541888206237, 102.67389143666914, 98.31824841037874, 101.35151924625521, 84.1795003029608, 121.82100419075259, 37.269125830742624, 0.5461034479160463, 0.28636958029481674, 0.11000683981805079, 0.22988934971151814, 0.08185458715043722, 0.13294236313912178, 0.42983342562952354, 0.699734291242015, 4.257509737245498, 27.39094445782323, 47.76811838150025, 58.845825272221724, 56.9987811580781, 53.79989608641594, 29.197107668845888, 21.011109352111816, 46.0106651244625, 53.09189650320238, 64.55370541541808, 79.01167561930995, 41.68067047672887, 2.830608342924426, 0.25090741624514906, 0.04859700198135069, 0.07803845039058117, 0.17496974748228827, 0.02374975029529343, 0.1268893722144346, 0.012485335182939327, 0.06305638678191651, 0.10638028683681643, 0.030131354635100693, 0.11640672301573139, 0.03719392495470182, 0.1002793005036731, 0.06185768517635523, 0.07647271989093674, 0.02153363221535279, 0.06506958540769354, 0.051581328133902246, 0.02266428797625967, 0.017594911811512806, 0.04465478630135617, 0.07844787075995438, 0.036580499201532335, 0.06833817614542861, 0.05098925708162208, 0.01615855824052086, 0.0740388279119807, 0.010205647127041894, 0.042044268921017654, 0.03234197603418462, 0.06466016503832032, 0.1102187090943898, 0.061828305704459074, 0.05820208597147177, 0.008918414485730953, 0.12909528408800403, 0.06291119396806726, 0.03938241598887309, 0.07473317170215231, 0.06771093399654474, 0.00873820475047274, 0.02421550877061823, 0.047115430070628087, 0.069762617049198, 0.07980518703979832, 0.04467789151315247, 0.021507016405643477, 0.045970136284708016, 0.05887322878885654, 0.10486904817122607, 0.04464495739328765, 0.0267522442229693, 0.05325030430310196, 0.06510294853679596, 0.005474540436895745, 0.0736951991735447, 0.11043893638998271, 0.08739623736830489, 0.1790268265552098, 0.0757472116440054, 0.14306750208620103, 0.20698538921292753, 0.05886379824650865, 0.029669966691383914, 0.06414249644524629, 0.01600707776003307, 0.35723758560995905, 0.0012888767378171906, 16.93620800971985, 121.44105203690069, 110.34922461355887, 121.0107288052959, 110.84048578816076, 107.34657964398785, 53.2284342089007, 33.823460917319025, 35.94649476389731, 53.601216270077614, 85.61482106485676, 86.32316973901565, 47.28560409238262, 2.0365387201309204, 0.9551877191951199, 0.028272254595292673, 0.15438196189220876, 0.4641550532992809, 0.1132447946996939, 0.4941065477267389, 0.41315097241632404, 1.2178177362488163, 1.8677245657290182, 6.9765031145464995, 96.96018265139674, 124.29263084165513, 102.45350914616739, 115.41553835715018, 90.86803574715891, 93.65612706830426, 99.09461882806595, 104.20601629441785, 106.07836754091325, 107.19127731938516, 108.18060105846776, 104.85843981465986, 110.46504436000701, 113.21578687237157, 108.02291393280031, 102.41272434111565, 93.10412406921388, 99.07178278892272, 104.6440665952621, 108.20035411465554, 95.6845651134368, 87.94345378875734, 110.49516816293041, 105.37482769258561, 108.31384397322132, 78.9589197404923, 56.054435237761474, 69.23111223405408, 78.77217569658833, 102.88743311359038, 102.07838150762744, 98.30051929719987, 102.41219089877222, 98.29443177869244, 108.86401130307107, 130.35226914190477, 114.65396311975296, 88.87496963624032, 108.69745962081417, 110.03418768605879, 101.76137555030085, 117.85805317663379, 124.0316677093506, 111.27739860165505, 109.5644917026643, 100.46654624323692, 113.67464926935013, 115.24748832948747, 114.88833258228918, 115.36657933265933, 124.89851151743244, 101.37553984119047, 86.29773709081834, 95.23585381046419, 98.5491975661247, 93.8509511947632, 104.0169894310736, 103.22647494654503, 108.07337914743732, 88.6973725595782, 127.5074681928081, 51.09311157657255, 0.15924378568606992, 0.12272862612359947, 0.3337752849103943, 0.3916418894885048, 0.14543497424212196, 0.13544128066109073, 0.6085697056785707, 0.7685366477216444, 2.917616564419962, 29.98070505357558, 55.66513215341876, 54.64639848278415, 34.427639284441554, 31.7036904827241, 26.049115350169522, 39.39973769649383, 77.453459155175, 85.21604937891807, 86.30150256618377, 93.30334909500615, 67.10772929653045, 9.107446420577265, 0.026590141933411363, 0.18899240470941991, 0.056780920093578685, 0.23890131693934244, 0.09472593680144319, 0.17577076901591596, 0.023356992338273316, 0.132419875853004, 0.07965967629946048, 0.03469694946562091, 0.14976375405826878, 0.1581582390973645, 0.11801939938337573, 0.06207042013204867, 0.1443860926214726, 0.04093272896904138, 0.03737113641334638, 0.05244990330069296, 0.05999108130532888, 0.0499219395550749, 0.004315544210840017, 0.06045116306913476, 0.09938758948156912, 0.03776230090748399, 0.05117283473091741, 0.042661034817537, 0.0611473914356001, 0.024371461289364005, 0.06550188116248577, 0.05853898079705335, 0.11659593907214942, 0.09067625047699099, 0.04226029039390626, 0.06416781182070413, 0.04658925790159453, 0.14021802273008133, 0.1798333179566168, 0.27479294987936176, 0.24517157806023476, 0.12934504407307795, 0.1113695033916062, 0.15377699758016294, 0.1468306485443346, 0.12802685190352703, 0.14166623534214112, 0.19692720635043037, 0.19612707347879488, 0.09549427702422104, 0.21057823432549355, 0.13103770002001716, 0.1657361050526942, 0.2569913494610979, 0.17636808777047744, 0.11848557154617964, 0.1790295844717372, 0.2517735092870651, 0.20863661512492165, 0.2157503390504468, 0.3227016984695389, 0.16588907748941453, 0.1752130263635228, 0.2519874316790412, 0.1878252697567786, 0.29738733424775066, 0.15950051707125482, 0.14815394285946124, 0.49888791696679213, 0.13912285407704694, 23.31304446343453, 148.89536826841294, 120.26546278307517, 126.08798596166797, 109.18752839488369, 81.74627365604525, 40.92504155251288, 71.49717530896588, 116.35142372500513, 110.95554459479548, 101.23476597570605, 101.35185657009002, 67.33881965760263, 5.151122250864583, 1.0516832961190132, 0.19613666489960688, 0.5004097659501338, 0.7335424254978857, 0.16974245378326985, 0.8622278525463997, 0.766694114333199, 6.314218265395011, 13.893668613126202, 5.408584667790321, 96.78654716860865, 137.67294945255404, 107.57798379467381, 123.3114028746082, 99.06527165443667, 99.1494143393732, 106.91391083502002, 110.47130446280204, 113.1900090555991, 113.44152712052869, 113.35825520177042, 107.45913597845264, 111.84634623988983, 115.47486812837663, 112.48660256785732, 107.04528670157157, 97.8727299167264, 102.12684631347658, 108.05402617300712, 110.71951989204653, 98.68728068567093, 95.34143617076259, 117.2357613040555, 112.62223812841602, 110.64290031310051, 82.6596446191111, 59.33610193191036, 77.15320171848421, 92.9923600535239, 108.58691938461797, 109.83562946319581, 103.84944931153329, 109.25089036264728, 105.75313245096515, 119.2175074546568, 136.10680980067102, 121.22805164706324, 94.87755313996347, 117.52033710479738, 114.1097342583441, 111.51704757444321, 121.2524409447947, 124.09470804276006, 118.7268424803211, 113.88163274334325, 105.95727612895351, 118.91054276497134, 119.82043066332419, 119.82603965267059, 123.32402506182272, 131.7113390276509, 104.16009318444037, 88.63910967303862, 101.90522455400037, 109.735318768409, 105.81373307012744, 115.19033155133648, 110.34191331555768, 112.32644434898131, 94.46065225908833, 140.35810993563746, 45.48851528475362, 1.0234904637740505, 0.7485893729232973, 0.2725150640453062, 0.8036294194959825, 0.3050655577211611, 0.22325695882881844, 0.8282546110210881, 0.9771773843995988, 8.430887576072447, 43.30586925629647, 64.91823873212262, 89.42525463719522, 82.18750892146942, 70.24904574117353, 40.74743663111041, 29.0885050835148, 61.652543929315385, 75.62325769855131, 85.27782670913204, 108.945431863108, 74.01942406931232, 7.238085981338256, 0.3190490831771205, 0.27992365521288687, 0.22178089125983177, 0.34864066949775147, 0.23629773648515826, 0.24752824837642334, 0.12739111383956286, 0.20950509836116146, 0.18104010562021888, 0.18196281255973926, 0.2386166539884383, 0.26166833156058866, 0.2726687106393999, 0.2293289410731485, 0.29244113352990925, 0.09427543879757005, 0.15343054197728634, 0.16016802480143888, 0.1271750770449158, 0.2338005196783812, 0.14452372797794882, 0.1383591563470902, 0.31166509875366766, 0.1498435650982203, 0.15880584386327576, 0.20358994963669008, 0.15051925464743568, 0.07895182637918381, 0.3369572770691687, 0.1329941813263201, 0.34424657302518047, 0.2246854983029827, 0.10628061879786754, 0.23817066824243915, 0.1322057695999261, 0.26290605385457316], [0.08722421232490771, 0.014721414641356997, 0.07571808498112426, 0.027799040169244813, 0.02433763276184759, 0.052825504718648816, 0.07076540315944342, 0.03571544803919331, 0.04045714158564806, 0.05336035283342485, 0.021199096940577995, 0.02563569788640786, 0.06374536412617852, 0.08266483238267322, 0.09324915677068696, 0.047259998522819056, 0.018801661170718652, 0.0376512143280237, 0.022647472346321713, 0.04975720766871687, 0.038229361732280066, 0.08086464833468199, 0.03637316516570507, 0.16907725963861714, 0.15701264653715397, 0.08986177643941295, 0.09849523494560873, 0.0529565632102951, 0.055529756786962675, 0.01244307298498649, 0.24324854415270591, 2.6255122644286004, 83.17642473405408, 84.25055011626213, 74.11369431403376, 64.89969768831807, 58.71067216319423, 36.555250537010934, 54.244685019216234, 78.77988707634711, 78.14093297527683, 94.21695540028234, 88.47219713272588, 23.7333538839894, 0.32151986995050985, 0.21465258102022836, 0.26087772882273125, 0.14697782935634737, 0.1996700003022148, 0.2600778717427485, 0.17024152942242163, 1.968322328982815, 1.6186986767476605, 5.867551988170994, 33.601819545991965, 107.76572412060155, 115.30998737581315, 99.61503890252884, 109.51612887843963, 84.76985623759609, 84.6871099164409, 93.52073469469624, 100.04063175570582, 103.2121975191178, 106.2059622426187, 106.84899560866818, 112.1115690662015, 107.750301361084, 114.85750275273477, 106.18653866552539, 98.07524973346342, 88.51948522752332, 87.98764321111864, 90.63011261724657, 98.33230618507632, 101.32140328807216, 100.58055385466545, 85.25928174295734, 96.72601715210946, 100.26834887842979, 119.60674778107675, 81.64332712850263, 55.45854483881305, 61.19757252354776, 82.15026993905344, 98.51183306786322, 95.42823822267594, 90.03113531297254, 97.63454006564234, 98.67003010165308, 104.44143695216026, 112.85183014408236, 95.42840296222319, 98.89597431305917, 107.45460171853344, 109.14312716453307, 111.7926097685291, 99.05544219478485, 115.46234007804625, 112.94832045032133, 102.68823162201913, 91.31877099314045, 97.10586732433688, 109.83732392711025, 106.01789243759649, 104.57111051005703, 102.811488182314, 108.88829861917804, 96.18441627871607, 91.20467708956812, 83.41515587222192, 82.53522703724524, 84.47891050769438, 87.31792988315706, 94.39972216083159, 107.03796755883002, 97.85332202911378, 105.80406050528251, 31.41854201593707, 0.24657955573451137, 0.3849670879783169, 0.30622838725966794, 0.04379972492554977, 0.18752591323948678, 0.10942085150388942, 0.11867788259781177, 0.21484326030458176, 1.4898361914580869, 17.174480230577533, 45.84206988734584, 90.70007201164, 84.77931699445172, 76.81452858832576, 37.2729697535115, 21.40916520549405, 29.768108667865878, 35.75265515235163, 55.42416918662287, 80.36209275645595, 65.2694320678711, 25.08591655761965, 0.46620240795516205, 0.10133472451519582, 0.03175975495739089, 0.15852234536601653, 0.041670383540012186, 0.10626614739697789, 0.06722869696996867, 0.027682250065188256, 0.10915576209945065, 0.021666027530426943, 0.08349684983371727, 0.07677976793098835, 0.04840663296260661, 0.034351478285727, 0.05437464941473258, 0.03128394923893915, 0.033376171749325535, 0.032468077936960806, 0.031485311619396654, 0.06136756893547793, 0.02671059393774598, 0.042452808289277943, 0.03548762498183116, 0.055636583917563966, 0.05411861899999842, 0.01166266113174178, 0.025968158978127667, 0.049075603920726046, 0.014941754934918738, 0.1465153880417347, 0.050377022595174854, 0.01673357426038673, 0.00916475580344277, 0.022099428367049947, 0.057442517455426924, 0.0685236766754139, 0.021970513006371838, 0.031694867310204336, 0.03855990568896936, 0.07434286522648989, 0.07899510268602641, 0.025262720319592667, 0.014892674554439803, 0.10345859603295404, 0.04190745710906002, 0.05007902971438823, 0.07058803082233475, 0.037891769766687386, 0.08623048137392729, 0.050184707713103106, 0.02137215045701352, 0.045117541712017796, 0.018465105339043567, 0.04069922153928107, 0.045461756507715875, 0.06054516971832322, 0.13046747013445825, 0.13303470737751455, 0.19186773187210485, 0.12885497762791573, 0.062046981672005314, 0.0876060841725238, 0.06945484122561832, 0.04192743668212526, 0.06506469010585739, 0.3999594286564858, 5.784541887621726, 107.74826957333474, 99.22418255959788, 99.57083379068683, 97.00793358587451, 97.13431235282653, 52.75136809195242, 22.363240565023116, 44.91027162921044, 69.77424283181468, 99.65420769106959, 95.12343868132561, 28.35256645756383, 0.1066891888096448, 0.45291712567690884, 0.3061872636598926, 0.5950201843534747, 0.47986114277474345, 0.4743850850049527, 0.0761836366127095, 1.4373204352394229, 2.204521332056292, 11.97609636091417, 44.39889261799474, 123.2340302005891, 119.01533280649494, 108.63333671323716, 111.70246585722893, 90.45656342660227, 91.37017757661881, 102.0602366232103, 106.2028165017405, 109.66929743366858, 112.0119643980457, 110.73451119084513, 114.27697627775132, 113.2953796079082, 118.97846252687516, 108.78885869056948, 101.42438119457614, 90.00192934466948, 93.53516901693037, 94.68656509153305, 101.48691946460356, 103.5590527134557, 103.16926325521162, 90.61049292164465, 99.17861246293592, 105.04281474697976, 125.98608278459119, 88.53177793564336, 57.8032632027903, 69.06692181864094, 91.91673632591002, 102.31819521996283, 99.99599518314486, 98.8159187378422, 101.14907003218129, 107.40646639177876, 108.17634136446061, 115.07783013005411, 98.68901437328708, 103.29022130658551, 109.98556598540276, 110.94620150904503, 116.33219626642044, 102.03097574172482, 117.40286211813651, 118.62857926276423, 106.75230918392059, 94.13362072360133, 96.07848090510215, 111.46352291107179, 108.56334593988235, 108.78124144769485, 105.53194999694826, 115.11504557824905, 97.19081801752891, 95.1518758650749, 89.65734912503152, 89.48537672719648, 89.56622462118827, 90.15600004503804, 96.58934608582528, 114.67823474637925, 102.79342959004065, 113.36838276155534, 49.54550120138353, 1.7268918646920113, 0.6894978243977793, 0.2786471688699338, 0.08312772568916121, 0.24593310010048652, 0.09212234102550054, 0.10357565426778409, 0.13086568263749923, 1.3340853683410154, 19.254593541545255, 49.207024189733694, 72.47036241715955, 49.87848689479213, 30.38116139750327, 24.491763768657563, 32.559047629756314, 56.117334365844734, 70.81170974239227, 72.7809121531825, 93.99809498940745, 87.82761050808816, 45.02089815755045, 2.300847879340572, 0.10360433659966915, 0.013966455101786603, 0.117680796181723, 0.061186002266983834, 0.04507732592643269, 0.04893736335478964, 0.01345231625882368, 0.02203118716997485, 0.08968221309084086, 0.12642333028657785, 0.04568357343575166, 0.041413625341749964, 0.04309730656865624, 0.007366783355527948, 0.07644924695693678, 0.12743544734774098, 0.025957422255868876, 0.030695681813203042, 0.07802866744778811, 0.018059599678963423, 0.15964857122350126, 0.043485529285164616, 0.06069801575053604, 0.058776104161816264, 0.02127991155571034, 0.0215583500422297, 0.05475781212050108, 0.00638505939634577, 0.04457464201315757, 0.021698950158972895, 0.034790584562166084, 0.10455951800629978, 0.12655538086208606, 0.11961138371618525, 0.15301043468136943, 0.06493832390274733, 0.1615490515025393, 0.1540621967926141, 0.2031860834047679, 0.15495442875450657, 0.1060261320503008, 0.14378275241582625, 0.23092661743923543, 0.2551108487551251, 0.15011548034606442, 0.1520349749273831, 0.10907629579906503, 0.15077816172232553, 0.16580929709297998, 0.11601979498781505, 0.1034195561923327, 0.11996101092306838, 0.10146275312910158, 0.13394976875955059, 0.2036919465829288, 0.2493089278258624, 0.14965452524202486, 0.3118146697600042, 0.19975609326314545, 0.29732521983884996, 0.17835461504517064, 0.17238202504813674, 0.14841366198755082, 0.12338091168672809, 0.46618500243752237, 9.692313978748938, 130.54184513707315, 107.7053431541689, 106.35775012354698, 85.61741767391082, 79.46929854731407, 50.229237002711145, 74.82310987287953, 106.4949546321746, 107.00064228427027, 116.79283941945722, 113.57057309919789, 40.963131689256244, 0.9827222675085069, 0.5614614270387158, 0.831035694047328, 0.8032298280346779, 0.706850819049343, 0.9063344761248558, 0.49949294256587184, 3.2950672266944765, 6.157255307320626, 11.171720220196633, 37.54108336664016, 124.16160014367874, 127.93278648007302, 113.15832414934712, 121.72216830715057, 97.3041666707685, 97.3625550731536, 105.01026691928988, 111.68900428279754, 112.61695861816408, 115.7174510340537, 114.12708682398643, 122.09964936779393, 117.25876992748631, 123.54115962982179, 114.65302959565194, 110.02638216941588, 95.14090891807311, 98.65652145877962, 100.52087891486384, 109.03437552913543, 109.72550499823787, 113.07734289476949, 93.13324374537315, 104.37671784431704, 111.64107291929184, 130.22676114113102, 94.00012677715671, 72.5796631843813, 85.64999688056209, 96.57567270340459, 108.48145469542473, 106.57414728595366, 103.45992657446094, 113.76798598997055, 118.1029659701932, 115.14847986159788, 117.98565572307957, 106.05569624131726, 113.61616673008089, 117.67339583366149, 117.87771994067778, 122.41944020794286, 111.26556873321535, 122.1915348114506, 120.24760030931043, 109.70374368852185, 98.99324124859226, 104.55549163203086, 116.11159432318904, 109.01891354591616, 111.23324840299546, 114.24342432329732, 122.12220299628474, 105.38446103372883, 101.66764659266319, 93.55161943743306, 91.8694168521512, 93.07861297361313, 91.81525676481186, 106.32171138640373, 121.47737318469633, 106.61184910804995, 118.34984779357912, 42.4993868027964, 1.450913409071584, 0.7063633419813649, 0.6211910348746085, 0.08597520555579856, 0.605247458142619, 0.350040189561344, 0.2573314771777199, 0.31170475146462845, 3.991714244888675, 33.370109450432565, 65.2922994859757, 120.2245367726972, 126.49739511551397, 105.85643983656361, 56.74039894534696, 31.235951762045588, 40.98098631828062, 52.68716673697195, 73.28248131659724, 102.54132316958521, 100.28778814500379, 45.118208239155436, 1.9470111112440787, 0.29009711898622975, 0.12009755843469214, 0.3046479785153943, 0.24569524512175592, 0.19908464784103058, 0.1993879573720117, 0.09126492775976659, 0.18346394652560835, 0.13888041789252914, 0.3027895411416408, 0.2601738472379023, 0.1606446693861677, 0.1734354878745733, 0.1901375069733589, 0.27369339920340047, 0.2107862271969357, 0.13031305745244026, 0.1275157333622056, 0.16760785703457173, 0.23275042763881146, 0.2620661150543921, 0.19242041834419776, 0.13728816542894612, 0.12552014326736813, 0.10527958702896872, 0.07345638658490873, 0.14970671115142686, 0.1722827247313915, 0.20864640572859397, 0.10556498542428018, 0.12551215297031787, 0.2346415310016563, 0.1884356732930868, 0.16353573199481736], [0.057308846603958845, 0.008137460625279815, 0.01258719614857147, 0.054892026894395395, 0.020696458992578333, 0.06121894021728828, 0.021329726422986677, 0.02123396543245162, 0.037907784834744475, 0.03371889267357127, 0.028943217382015243, 0.0574252421727344, 0.02635703861503111, 0.08194636448376602, 0.04209742776208347, 0.013305611378933876, 0.1486633453638323, 0.03678675688382599, 0.15282193108672096, 0.022584545884221312, 0.04770998707822254, 0.02058621127939513, 0.13018096857253583, 0.0495523251142473, 0.06251792273213787, 0.031384143963335984, 0.008276529523784356, 0.0376581589150573, 0.03720265069615938, 0.1416086714955107, 2.2340418254175494, 54.87829292974165, 97.1678799967612, 93.36597365717735, 76.45956977721184, 62.12117695039319, 32.220392150263635, 71.90814556614046, 117.77479694735621, 81.14074599358344, 102.36724838133782, 73.70599531358289, 16.796393163742557, 0.226352000008187, 0.15729206944665602, 0.04139217871030973, 0.17372355225586122, 0.14384941738699714, 0.21417193745653476, 0.7123052424961521, 0.46119032367583246, 24.241369462782338, 73.94941760647681, 114.17248433636082, 128.13523569414693, 111.18501893935665, 103.86276183589813, 109.44623224196896, 88.1192308856595, 93.63104743342247, 88.57295497771233, 95.10529379690848, 102.64806655145462, 104.13135005581765, 102.93897305765461, 103.52133520187871, 104.36353868053806, 105.55655110266902, 99.57100637497442, 92.20740748989968, 89.51935229762908, 90.49217854776691, 90.42476084924515, 93.39448928833009, 101.53251309548656, 101.52510766060122, 91.18781089782716, 77.89521217346191, 88.55650455720964, 97.1449419759935, 106.626918854252, 92.03119893227854, 59.39001883229902, 75.11127856469925, 100.84511772278817, 103.6381120066489, 89.94296827623921, 79.79094859092467, 85.99285910206457, 93.35956450431578, 102.77570047686177, 111.41732523518225, 93.30486312989267, 93.38851159618747, 103.74140370276668, 95.68862084419497, 107.87779408116495, 114.07583713531496, 103.73220182234242, 114.43736199409732, 109.05919628758585, 96.72002377048616, 85.94222130313997, 101.23558967344223, 110.21995113741968, 114.1679108527399, 113.99477743333387, 108.16569605181294, 93.20116350727697, 81.36260309526998, 88.38595990211734, 101.13156841647242, 106.345959478809, 106.77054036048152, 102.90374232876687, 99.77421652886176, 105.1672480183263, 91.65964065059539, 97.04449792062083, 64.47356354805731, 8.416844510263013, 0.4581916103920629, 0.22224282695641442, 0.08406845101666066, 0.3332235790308445, 0.22277164212878675, 0.05153910902839515, 0.318872882954536, 0.04868098820048956, 10.304589098499669, 72.85320928019863, 111.63232603380757, 80.8026376847298, 81.06982169612762, 49.38148729262814, 24.241569503661125, 31.282178855711418, 54.23075276036417, 58.76178849127985, 70.8734792278659, 78.52945158558508, 59.30979067279447, 3.724437322347395, 0.4174201046266864, 0.19137478493634733, 0.05812660332829241, 0.018257196737273086, 0.06089331454507286, 0.0687678672012783, 0.03321715870932226, 0.02121375986344872, 0.02873237274827496, 0.02556162292978937, 0.01473648646365731, 0.03147096087735507, 0.025422543497575868, 0.04004915380069325, 0.14628272713913074, 0.03683908834993359, 0.03365862836700774, 0.04189531461546018, 0.013603214512489015, 0.013636276952081151, 0.024607096528334003, 0.07847787842394845, 0.031290916808610486, 0.028283807201190826, 0.01959539720818641, 0.015882764672560078, 0.06298555429243753, 0.0558373257668028, 0.058012096166250214, 0.027974968430616205, 0.023335819583266013, 0.08396492955545265, 0.027697058544764598, 0.07794868786849322, 0.04741763260455863, 0.016611364084265886, 0.10653829247119928, 0.06706728990520201, 0.026962276803509846, 0.08027211762964725, 0.023335222034685077, 0.014464188171851059, 0.043648958822051366, 0.07185970613312337, 0.01753868095787062, 0.02584817237220705, 0.06554678923660709, 0.04008121074988477, 0.02993546786808199, 0.09549915700429872, 0.10183930832652316, 0.018128432678960023, 0.05863748438235733, 0.04905326096641441, 0.010485452122896189, 0.14991285009009225, 0.03303809714834056, 0.0932450122350166, 0.06808839317771696, 0.10768609902551098, 0.05220735603342614, 0.02164414614408968, 0.14211502496994313, 2.6629157412436704, 76.08102183188163, 106.84275119535386, 116.86224183728619, 104.77512867219987, 82.57209731686501, 51.19636012661842, 40.64581978705622, 74.9048520672706, 79.13138635696905, 106.52767504415205, 84.26110129202567, 19.423988942177065, 0.3126480508475535, 0.042012357528531746, 0.04829837707802654, 0.39543166516288636, 0.18879601040915137, 0.22446209174250403, 0.7969759765171236, 2.406997757573282, 35.20558257256785, 87.3430173627792, 126.91877534312587, 134.48382716025077, 113.2738850193639, 110.26538787349578, 113.05368315789008, 96.65313951430782, 98.50289790861069, 90.72166858180877, 98.33992342795096, 106.5944573187059, 106.51837118210332, 105.96046893827378, 108.64161291430074, 108.70004838512791, 110.0460881571616, 103.88919861085954, 96.92650518109723, 96.251951648343, 94.98867388694518, 95.5802143773725, 99.6576907557826, 106.5941043053904, 107.0633452938449, 95.88822241752379, 79.69931417895903, 92.25177734128891, 103.14037107652234, 107.19781198809224, 100.05741165530299, 67.1234344667004, 84.45266200650124, 107.19752957743984, 110.35000908759334, 95.09293048612534, 89.4971909061555, 95.33557614972516, 99.11776081208261, 107.41118892546623, 113.55795875672372, 101.64808965498402, 100.4338493654805, 106.12343557419317, 97.54056007631364, 112.4965104749126, 116.67979671109109, 107.90291293974846, 119.13527888636436, 112.66277974651707, 100.84489022531818, 87.5499459235899, 101.39337093599381, 111.56537901970648, 115.09465709809335, 119.812436872913, 115.92141428301412, 100.1642099503548, 84.25268388563588, 89.46947543851792, 104.17768109229304, 111.10389647945281, 114.49913147957095, 110.96222831356911, 102.2958847784227, 109.3970221857871, 96.16746379483132, 104.64396461363762, 87.72749593180995, 18.8427544793775, 0.49726715071066735, 0.17447545223178404, 0.3049741787535529, 0.3497668493899607, 0.30077911192371004, 0.0457946332021346, 0.37206212238919356, 0.08008771260539371, 10.89123643213703, 76.71024061018421, 100.86969529428791, 75.98398239381852, 45.12163639068604, 22.676637941791167, 28.06995576427829, 41.25960796110092, 93.03926375604446, 87.84015424789922, 89.34639930725099, 89.62726454580985, 85.13325598932083, 11.110658722539103, 0.6526694651092253, 0.173095099688057, 0.05706448370831148, 0.022637430848854206, 0.05487524190797441, 0.07255491560264941, 0.006653101590927691, 0.03874179411439165, 0.12268732632360152, 0.018054968677461147, 0.047749551689072, 0.046001837003014745, 0.036609480307707866, 0.03596963218202995, 0.05109759723587383, 0.0741036159677371, 0.04791694956140653, 0.0357649143364641, 0.01589936962831886, 0.013880850521907693, 0.025714457470683322, 0.0698759597575953, 0.010874917817061708, 0.041009513961692015, 0.008437362980217704, 0.03658714884471509, 0.007260342141718514, 0.08097345580256755, 0.019275616786833254, 0.020487989231403318, 0.02120441167555269, 0.023007537501173157, 0.015573336971893668, 0.2807259944177443, 0.10287187227438535, 0.1067959814662895, 0.14577324802596725, 0.1468230949174012, 0.183338706471747, 0.16658111535493406, 0.10403915278373227, 0.10566643844809263, 0.17074253560314256, 0.12923029942377923, 0.13234303723419868, 0.18052014642425124, 0.1699203240775293, 0.1218101250067834, 0.21881355693744076, 0.265121917210279, 0.15068293699333746, 0.26429677922879496, 0.13954777240512833, 0.18766143419329198, 0.09197243294047733, 0.3382526398185761, 0.21420559935992767, 0.25479647691451734, 0.20001405038900916, 0.1727588636980903, 0.13176916077012016, 0.15602169648533867, 0.3816991101109213, 5.035398112189386, 98.92561958682154, 128.10217011359433, 128.7794928396902, 101.38718928060224, 80.16206756714853, 41.203459232084214, 97.68163204193117, 155.4273226953322, 107.44087342293032, 120.59000753587293, 101.96197340565344, 32.6223821409287, 0.6363582274606151, 0.2038639946089637, 0.13312875233109922, 0.5369316594254586, 0.39286070473251805, 0.3773430422429116, 1.1053175407071267, 2.2721807466399286, 30.52159990033796, 80.36843130665441, 123.75002584149762, 141.15635933414583, 120.43412470048474, 111.97110114559051, 121.07420844416465, 102.92364443502119, 104.01185112614786, 98.61125730699109, 105.1117386356477, 113.29044526623143, 115.23758826717254, 114.35603557094451, 113.54583863289126, 113.15254257571314, 115.40940377020068, 108.91050707909369, 99.3486079862041, 99.87628444548577, 99.92177609474429, 99.35614678167529, 104.67160947861211, 108.4545393913023, 111.55930719067975, 99.56127889694707, 85.08150423726728, 97.46985543158748, 110.65926444145941, 116.39672710049538, 105.30854748141383, 74.54197791314895, 93.74290558599657, 113.3869198829897, 119.13982099102391, 104.37311710849886, 96.93446759254702, 104.6871812881962, 107.45173838830765, 115.12961326106903, 122.47755404441588, 108.33451486402943, 103.21167976625505, 113.0143496298021, 103.89636870353453, 114.71512071547971, 118.62782616769115, 112.23131118282195, 121.06965065002443, 117.71654190555697, 106.05867724264823, 92.53461160967427, 110.73899838232227, 122.93242346855902, 120.8913161677699, 123.84383324653872, 121.46275058869394, 103.85984359248992, 89.18800615495252, 96.08848294904156, 108.83604480374245, 116.86885495339672, 119.69751142686414, 111.74888318584813, 105.64919748613912, 116.2861241063764, 103.1268467441682, 108.81749983756774, 79.58634207325598, 12.66164625844648, 0.9183871842199757, 0.5256797890028646, 0.3213140374470142, 0.6621014783459326, 0.3034401642939737, 0.21992542630722448, 0.664172857519119, 0.23488954430626285, 21.812979098289244, 97.24682946358958, 131.72913089875254, 118.44723240021737, 119.17449474334718, 70.97015780787315, 36.756742692762806, 38.32755780989124, 75.73633963061918, 80.37147506590813, 90.12714709005049, 103.46790467539142, 95.23201773243566, 11.65817649133744, 0.5757015919493091, 0.35272839208764417, 0.2601903640935498, 0.13147942631715728, 0.22054859286835118, 0.26336622754892997, 0.11938940207924574, 0.17190406279217813, 0.1506361290211639, 0.2260344105982973, 0.13652238393983535, 0.12292057711390719, 0.16181833140792387, 0.16338446027328893, 0.18227729165265638, 0.21803853642796317, 0.1360135023752528, 0.11726942994902212, 0.1801470003180927, 0.08287334619390388, 0.09636047731844649, 0.10042594505413886, 0.1255223955658655, 0.11772465471538807, 0.06957696330162787, 0.10989724327960324, 0.1309552536376061, 0.15191771750969274, 0.09915158843561526, 0.11378096431613931, 0.11665562498233012, 0.34498214000655764, 0.17841521259998122], [0.10339896374892804, 0.02555458449698504, 0.017438043817697514, 0.04408949002202961, 0.03535580423270022, 0.030760015961864305, 0.029204123946387443, 0.10516333318645917, 0.0634230096493998, 0.05247165636730291, 0.030743328651653665, 0.009349045914507682, 0.02313772456780557, 0.11443611504810472, 0.04193034781623752, 0.03109961699303841, 0.11267765980934906, 0.014316935539095393, 0.02890560054971326, 0.021297161940545328, 0.019574896695332664, 0.03331460126285111, 0.1284163999521444, 0.09128449364535271, 0.05269045490891703, 0.018156222518413298, 0.052569631351939136, 0.048983573778382236, 0.08453803227072762, 0.35411724820733076, 30.38094762832888, 90.73498110617362, 95.5933072490077, 78.30291117391279, 62.1801301740831, 52.24520975543607, 69.51746879085418, 77.51289875276628, 78.54701595921671, 94.69407250804286, 55.96877067319809, 17.435853250565067, 0.35681859680241157, 0.11069605848000896, 0.14592202230086251, 0.14795558737410655, 0.04045415767318299, 0.197732517976434, 0.8177538131994586, 11.419972911957773, 90.1801069321171, 125.94241111509263, 118.84378402463852, 100.90574972091183, 95.68421210012129, 108.26897990319037, 105.36439418792726, 94.50443375495173, 96.41116849837765, 91.38785962135562, 88.85236109456709, 88.08366283293694, 98.50126620261901, 101.38182347820651, 101.16810137225737, 102.44068299570392, 101.18589324335899, 95.91613400367, 91.56260905727264, 88.06896963427144, 85.34903341724028, 89.39779020124867, 93.92854352151194, 96.3944435119629, 101.84449841899257, 101.5815427226405, 92.74958102933823, 78.20613845702141, 81.90754582805019, 94.85212049176617, 105.22995887264129, 106.24551542343633, 71.06432607097011, 69.84877570982903, 97.81845215828189, 105.00305760291316, 101.28149709393902, 93.88547589701992, 99.87562548729682, 99.76796427080708, 103.83019831872757, 95.84160112565564, 92.0325090039161, 104.04601497034874, 98.13975703331732, 92.09816948060067, 99.28082942962648, 107.20448001738518, 108.84161456938713, 107.91744924360707, 110.05088913825251, 99.02482417321976, 85.94961104854461, 80.56982148078181, 90.02658536357265, 98.74041311202511, 104.16748292984502, 105.08261895948841, 98.23494511265909, 81.52911555382514, 93.41045333493142, 99.94371783348822, 98.76553197060862, 101.58046799321329, 104.8473551965529, 105.73564652473696, 98.66645290005593, 104.80808442638767, 97.33342755225398, 104.01571858313777, 108.42545893884476, 35.37406013857934, 0.13197500859537434, 0.2473739123031978, 0.09308481558917031, 0.12402339132442591, 0.09768045447286099, 0.07446278863015675, 0.053658230801022826, 0.6151923212793566, 4.62199745639678, 62.00929134122787, 84.98888923275857, 46.884176961837284, 71.14857858227145, 77.40437461483863, 50.89368258753131, 18.136204211942612, 24.779899120330814, 37.88345529187111, 63.79849618481052, 78.26699795261507, 57.77930536577779, 3.1606189185573212, 0.5765707033776468, 0.06990086527601366, 0.01261893708649422, 0.1251933531415078, 0.07336286257111257, 0.06819091106374418, 0.04132440291164864, 0.006411572262990259, 0.05116032068467429, 0.08572913811451967, 0.027866507617516384, 0.03286652409681871, 0.08566561410383833, 0.040188968677314064, 0.039499707880520055, 0.02234996593136701, 0.029681551856018847, 0.021519716228208235, 0.05413188764284696, 0.03337404968577527, 0.03465140170808281, 0.01842453523779348, 0.0383871145576479, 0.03033830754218563, 0.0375371017012625, 0.06326019681329209, 0.03957529394556919, 0.05727095972566355, 0.0259035739356712, 0.03888311818422329, 0.10037417283221599, 0.07994085355030914, 0.042372920640533975, 0.04518766940060643, 0.04218017291878501, 0.04171950892815667, 0.01161003759461305, 0.03350044653240231, 0.047470396910343444, 0.04921891215828158, 0.1003730466829673, 0.024881620305560292, 0.01612736697068378, 0.029194448255903782, 0.05132758832206169, 0.04517699013494196, 0.06914001739313526, 0.03725808481836031, 0.08545127802438314, 0.020251794748248595, 0.041801618231881055, 0.029349272710181055, 0.056437620772950114, 0.02462770429349715, 0.09270559440577224, 0.0933149713842619, 0.03466112336384193, 0.026316077808939645, 0.03975212236025161, 0.08764284107113078, 0.0715137025221221, 0.25055755921188866, 48.03220764283211, 107.3769780128233, 120.64365771508987, 105.02744690064462, 90.9868678738994, 68.27981195142193, 20.466254872660485, 55.73993959734517, 84.04546506943242, 103.4076492248043, 65.56077395716022, 20.684544578675304, 0.18073331805006151, 0.020858670449665478, 0.1938221753845292, 0.14220805868746775, 0.22461909380170608, 0.343754131707453, 0.5097257015445541, 19.463577424326253, 109.28985518793907, 132.96590128252583, 123.92046851496544, 106.07212312759893, 102.92662543635215, 116.17043772051412, 110.61087808301373, 101.28881623668056, 101.71529554551648, 94.50876405162197, 94.21195830068281, 92.00305984866236, 102.84510289469074, 104.50592071779313, 108.58933556464412, 105.74973567839592, 105.69068047308154, 99.23583199900966, 97.1975488047446, 90.23224307644753, 88.86474009483092, 94.62656851737731, 99.98353773547758, 100.99075532728627, 103.91041078875142, 103.34566008660101, 95.00722669786023, 81.90202313084757, 86.56064571872835, 97.54374504089357, 111.09653811300956, 110.77648839642926, 75.57662856194281, 72.87126002773162, 99.43915982400218, 106.21349319334954, 106.51757886332851, 102.34667162741385, 107.41725290975263, 104.79481112572455, 109.71796620276668, 101.85312763337167, 98.53777562418293, 105.8978129971412, 101.58861867843136, 96.35384698067942, 102.77038958764847, 110.75176961960332, 110.57727121537732, 106.31970313287552, 114.44618732698503, 103.43695717473184, 88.78893636888074, 83.59665178483533, 90.40335255284464, 99.34456794492661, 104.91116431451614, 106.85591466965215, 98.8675763530116, 84.21367983664237, 99.4643492852488, 107.55937607057633, 101.10744583991267, 103.51390623277234, 109.85222108902471, 108.7930791608749, 101.78490977133475, 107.24163270765736, 104.46195879290181, 107.3387662826046, 122.36510753631593, 54.63794969743299, 1.604823905133432, 0.32466386414823994, 0.17808398682503931, 0.04362293864570318, 0.06138564478005133, 0.07391171094270484, 0.06530550218397571, 0.7941451284193224, 3.7698309123516087, 64.78281105718305, 90.78425392027825, 48.27158989444856, 51.701326062602384, 32.02752136415051, 23.74304606068519, 19.71193798126713, 45.2754246804022, 72.41667301424089, 79.89424813178279, 86.85956954956056, 79.00491345313289, 11.652037982017765, 0.5120068355914086, 0.09278378900020354, 0.1276330903713261, 0.10028033472237088, 0.05080648765508687, 0.07019000984127484, 0.12570406565622938, 0.05754813799754747, 0.047623737069267424, 0.036455783917899096, 0.021547768452775576, 0.055360650538557, 0.17979481437754247, 0.04265127102694204, 0.027042698798581, 0.040925592860026706, 0.04028689386623521, 0.03142277586213764, 0.06072620778614956, 0.08104123926210789, 0.014664385141053749, 0.023759912451609008, 0.04808259692283408, 0.046485376379062096, 0.04433337794316392, 0.06089726372832253, 0.03706266728019522, 0.09950281676626015, 0.09035185054545442, 0.04191283121584885, 0.046816563849607785, 0.029748971423795147, 0.20052365207624054, 0.20118500045951337, 0.15297972987736427, 0.14768175690645172, 0.08660064739806038, 0.16786943009543806, 0.15217127729087107, 0.27649354249719654, 0.217528214618083, 0.1805029400894719, 0.09995585818204189, 0.1311612853239621, 0.15330969926811036, 0.1806169492943633, 0.11966050527389012, 0.1510098726759034, 0.2593590667651546, 0.0870664441777814, 0.12481142766773702, 0.10907175289767404, 0.12643020975613786, 0.11705935331842593, 0.16328794851658807, 0.29607551592972975, 0.1529560424387455, 0.23113525382453398, 0.1818659790461102, 0.20935623215571528, 0.2303048451581309, 0.8491410483275691, 66.96178574715891, 125.13000980500253, 128.98319721221924, 107.10116478704639, 79.80270785670128, 73.05656848415252, 95.14546671221333, 118.56207155412244, 101.0712423632222, 114.9292899716285, 82.91160983424034, 32.99934348752422, 0.7596400993004923, 0.2651978518453337, 0.3259373167830129, 0.2935945555087059, 0.49646042948288305, 0.5711332564392398, 1.1776435952032767, 15.943981716709754, 105.75226952952724, 139.73434325187438, 133.15122542842744, 113.24045073601508, 105.7436481598885, 119.39105664530109, 118.89538672662552, 105.6829926275438, 107.33097645544238, 100.35717487335206, 96.32157371890162, 98.03187616409795, 108.81246351426648, 110.9270917215655, 110.99371710131246, 112.72840099949991, 112.49935027091735, 104.97611091982935, 105.31104210884341, 97.92881981019052, 93.98087578435099, 100.92114894620835, 103.32651892016011, 104.86163262398013, 109.32539186170025, 108.62978304586103, 102.53830294455253, 85.37623897675546, 88.79304701282133, 101.37012697035267, 115.5286830471408, 115.09644569889193, 82.32939674008279, 83.9111944936937, 104.56985535160189, 114.76500541933122, 114.10138745461742, 109.9567836330783, 117.46902465820314, 111.15650330820392, 117.20172297570014, 109.49052364595475, 105.03741756562265, 114.8509680840277, 108.06801334504159, 100.2577506342242, 109.62389207655384, 116.15098276445943, 114.39518082526423, 111.76452559809532, 120.01509789497622, 108.74061353745, 93.84673072445779, 87.69318303754254, 96.35101502941501, 106.93284803821196, 110.8014032917638, 114.84932068855532, 107.19990653376426, 89.9289732594644, 101.13684792672434, 111.42782934250371, 106.49329154722153, 107.2428172634494, 116.47500191965412, 116.07319431920206, 104.21953278203165, 111.21503291591522, 104.48131176733203, 115.29211705730809, 123.83619246944305, 44.46389021412019, 1.0727407855372275, 0.7004903893797629, 0.45172913781096863, 0.44262920836767844, 0.3617337862810781, 0.49602584312519726, 0.19484009173127914, 1.0264554691891516, 8.744438905869762, 83.03488208401589, 99.20431967704528, 72.73895848181941, 104.82324830947384, 111.67068681409283, 75.53520833292316, 24.272458168768114, 34.498167422509965, 55.6358830390438, 80.62697041419246, 98.19539193184146, 95.11547626987581, 10.528419152382883, 0.756454705711334, 0.2013859912873276, 0.1953222521490628, 0.18269310885619733, 0.13009224026914568, 0.2618054306555179, 0.16327497098715077, 0.17557294979210825, 0.131834308887201, 0.09362601074239901, 0.07138053345824442, 0.22084496164273834, 0.2189362842229105, 0.08229272049521247, 0.09299598769434998, 0.11570682508810876, 0.14588169543252838, 0.15842067017670602, 0.17376498229080634, 0.224967862990114, 0.11427367376464029, 0.1435573999920199, 0.0904773970344855, 0.17548858818988647, 0.19870092972151696, 0.16973384295500096, 0.1588967325346124, 0.1750258251183456, 0.14407843171108153, 0.16508876075667722, 0.16077645183090242, 0.2513826359063387], [0.0437156506062996, 0.044557696148272485, 0.013935288729807063, 0.06549466461423906, 0.08407765173263128, 0.04612629947763297, 0.03567032163001357, 0.026430437499056422, 0.06620599257369196, 0.010773989563477377, 0.03133554143019982, 0.018667917540897767, 0.04333892686953468, 0.06408391370167656, 0.03725533456271214, 0.05535565564529069, 0.011018607183359565, 0.07732028892684369, 0.10906831316289403, 0.037534098636599324, 0.12244901169211635, 0.029603125519990444, 0.09957958643715228, 0.06487220285400268, 0.1704020095207999, 0.11943733620066797, 0.07362583757288034, 0.09724303358985532, 0.6650154316617597, 38.469990837958555, 94.33913723114999, 96.65326503015335, 81.04285147882278, 72.61461150261664, 42.57384515577748, 44.845442695002404, 99.80509342685824, 84.84248284370669, 103.73014650037213, 52.965411832255704, 13.516019871157985, 0.2440871193163818, 0.14721908576546178, 0.08193168623913681, 0.12612586600645898, 0.15442941337823868, 0.27970053976581943, 0.36011792298766876, 13.536325000947523, 126.238903076418, 109.3845098249374, 93.09806008492747, 92.1793782326483, 105.8442569548084, 112.35162596548759, 104.85723956938713, 96.25717624541252, 99.26658338116061, 86.23892507245465, 88.22500936446652, 89.31617352270311, 86.67505341191446, 82.47553640796293, 89.08635400956678, 90.67678097755679, 92.87035080694383, 89.4212616643598, 86.55329519702543, 83.62667360613423, 80.0645495999244, 84.40412659798899, 93.64414030505766, 101.24847858182846, 108.12007888670891, 97.65637982276179, 95.74624830676665, 76.81204965037685, 74.77804968433996, 81.49216682680192, 93.1242379834575, 94.9138899772398, 103.90939881724697, 82.14885788579141, 58.211193623081336, 72.98048234754994, 83.02165585179483, 78.37320789214104, 82.71530305185627, 81.74703459585868, 89.9899818051246, 91.91308067690943, 93.84774269596224, 95.49616582932012, 96.2915518976027, 91.74034733926096, 84.65226357983005, 92.47015922300278, 103.93685540845318, 105.71167299824377, 103.53564400826733, 106.90794883235809, 102.9481984722999, 94.94848528215962, 82.55076746786796, 78.97577024275257, 82.44112937681138, 90.57290092591317, 93.05539254219302, 83.08451575617637, 77.23499098131734, 93.46262085822322, 103.70961681489023, 97.4041243522398, 105.75965143019154, 99.81653890302105, 99.66628859120031, 100.42071727014358, 99.32450109912504, 99.57466986871536, 96.73563480377199, 90.44612992194392, 113.47046636766004, 55.832331026754076, 1.4840114717521977, 0.12304189479759625, 0.11218133442584546, 0.3241377456053611, 0.17044025262997997, 0.15423174737201584, 0.15528881081169651, 0.35351225325176794, 3.5990734686774597, 61.48013222602106, 95.17181719503095, 50.91729917833882, 76.73595566903391, 78.78520581030077, 67.15518213087513, 26.39758656101842, 28.388909178395426, 57.31188043471306, 59.021123839962875, 79.90149667186122, 69.9014845202046, 12.179687965300776, 0.5404769304779269, 0.13518896194234972, 0.0095494449394004, 0.07008717019831942, 0.06020716023481181, 0.0402614061209944, 0.051276394496521646, 0.010654157132751519, 0.030348666966141715, 0.06824712659562789, 0.061327724702536106, 0.04912369892061238, 0.024393013257893826, 0.017033099317021908, 0.03817637526099721, 0.0477878331026483, 0.013670891677329858, 0.06668758608641163, 0.05419626584156387, 0.024835442440704476, 0.05316117763399117, 0.06900851840093251, 0.049588499786031824, 0.016176224228054766, 0.04873862099503318, 0.05605760668855041, 0.12653258208545948, 0.05879583858674573, 0.025501306912290956, 0.05912111185851598, 0.03204764888411568, 0.08797186817373, 0.05677913127827549, 0.019086038753870996, 0.0828567067641885, 0.06382188481849528, 0.05642577705364074, 0.01771594412745007, 0.02888484339740488, 0.06686069897466129, 0.04252766657079901, 0.06929030086124136, 0.07465700724072034, 0.11835300003088291, 0.011003113055090991, 0.04096760129135463, 0.02404204731236302, 0.028382033079622254, 0.09829283451601382, 0.022719476950324835, 0.06372081100820534, 0.14973809011280537, 0.022571168073843566, 0.06976784942972084, 0.11586402633017111, 0.20355058803914056, 0.11555291802412081, 0.10134893544619122, 0.021972792117946574, 0.7443234276387, 55.62053088218936, 114.96014333540394, 118.55175572056925, 104.26245920119747, 98.48167788597846, 64.50886095723799, 27.217667871905913, 67.03376123982092, 88.80242147753316, 111.43057500162433, 63.94695789583268, 15.490849902552945, 0.288228293460223, 0.04750480957990212, 0.1669904667763941, 0.07224671076983213, 0.3864037479844786, 0.3229095840886716, 0.19056515257445075, 19.81723204735787, 139.21397024585355, 112.48147995241227, 99.03128823926373, 99.32798416383805, 114.3351685616278, 120.35917605123213, 108.49017020194762, 100.61104636038505, 101.9834993731591, 90.8990538504816, 92.73560954678445, 92.39230801982265, 90.02690699792679, 84.22434083877071, 91.85574346973051, 94.6020850827617, 96.24325967604115, 92.53461945441462, 91.2565778916882, 88.3022016094577, 83.95863948329803, 88.39713081236809, 96.33894981876497, 106.38298665323566, 112.36701734604375, 104.53867250873198, 99.19925197478264, 81.36265800845239, 79.44272056702646, 84.59421250127977, 96.79563922266807, 98.63526221244567, 108.26815620545419, 89.86681938171388, 64.66895641819124, 74.72658034293883, 85.18610600502261, 82.02698984453755, 84.82641681548088, 86.83334458258845, 97.32932475305374, 102.60616779327394, 101.18562652218728, 101.52721789575394, 100.54189497424711, 96.94876070945494, 90.95814043475737, 94.95225075752505, 106.21474835180469, 107.354094905238, 106.29313299732824, 107.787336380251, 106.27434484420284, 99.72798747401085, 86.09710785650438, 82.31296985380112, 85.44380572534378, 93.35554799725934, 95.3637779912641, 87.96289305533134, 79.6429967880249, 96.43546365922498, 106.31604748387491, 101.73959070636381, 108.77407135501986, 104.76980209350587, 103.19762199155747, 105.69764660250758, 102.73552756155692, 101.63859751916702, 103.49689883570518, 95.36111077954693, 118.08897879815872, 73.62870893170758, 5.056833374884821, 0.29591184890558647, 0.20508195183450179, 0.4598147974860284, 0.21355699867971484, 0.21972740790055645, 0.14364885556842052, 0.4657434293579671, 3.351369908740444, 65.09951891437655, 101.05159913339924, 60.13486516091132, 72.51679543525943, 53.58200842334379, 26.395456714014855, 9.98380099573443, 34.42655671027399, 97.98079905971404, 82.83904598605248, 90.67614555358888, 90.59823943722634, 25.315779216827888, 0.16213112510740757, 0.21650027784128345, 0.05397645223345007, 0.06545894193432986, 0.13842488669099348, 0.0157188295176433, 0.024206700674708814, 0.06466303020715714, 0.09827343716977105, 0.047439420145125165, 0.018851740338328867, 0.03465258914436545, 0.05572597488700863, 0.019357756734074607, 0.010106692507472492, 0.03235515274648224, 0.0669843685482779, 0.08460560122564917, 0.06911882740114966, 0.04928611339099946, 0.024423551437775456, 0.013711518277564358, 0.06536220035125172, 0.025954959283192313, 0.1384326548225457, 0.06293442175393144, 0.17229223954341105, 0.01338490243670681, 0.030937937967058633, 0.028548500155128782, 0.029768880133727388, 0.14423506604807992, 0.2595203435949741, 0.1468467363907445, 0.2919181712692784, 0.276115033775568, 0.10785275379255896, 0.12228484671082228, 0.13080453349938317, 0.17589332776204233, 0.22676856797789374, 0.15230810059414757, 0.1088196793270688, 0.22683756185635445, 0.16375947563398272, 0.11954661098218734, 0.1345041559468354, 0.12743049841975013, 0.25339455133484257, 0.297242145264341, 0.08312863733379111, 0.2545092552299461, 0.22500400701838158, 0.1654010488381309, 0.37611947725376776, 0.30691596649346814, 0.2689967899312896, 0.15422820804580567, 0.3121305124894265, 2.6859672655982356, 76.53064312473421, 136.8471336364746, 128.84870698375087, 109.41868151387861, 95.4168241254745, 57.27307642659834, 66.65529174189415, 155.5331482425813, 111.93414457382696, 127.63521194458009, 82.09261894226074, 26.220873978830156, 0.4222991347553269, 0.23496895698049378, 0.3915122367681996, 0.2984506949301689, 0.2620915185299612, 0.6935053835472753, 0.45982068104128687, 17.120155403690955, 141.25295946674964, 122.53206714507073, 104.16347426752891, 103.49736952012586, 117.0758148931688, 125.95666500829883, 114.17525352970247, 105.74534262380293, 111.30737335451188, 96.8706427851031, 97.56447084488408, 100.34976159372638, 96.42373577240976, 89.88382677878104, 98.93697092610022, 101.9697867670367, 103.50666553743424, 95.85616880847563, 94.74786389258601, 92.48400518971106, 89.99060153961183, 92.57942076652282, 101.93096314707111, 108.98802880317935, 113.02374762873497, 107.46958517259168, 103.34228684825283, 85.50386505742227, 82.98862949494394, 87.94763503536102, 101.2322791930168, 103.17939081499654, 113.08177517306422, 95.38573541948873, 72.13363478260656, 84.1556993607552, 95.41749877314415, 91.74634856562461, 95.48174719656669, 96.47441279503607, 107.94725925691667, 113.18416472404235, 115.2430638959331, 106.74014983638641, 105.58571000253002, 101.21287130540418, 91.22528522245346, 100.52592308290544, 110.27419751690282, 111.86798987850067, 108.92130144180791, 113.6326014611029, 110.88976644700574, 104.51597767491495, 92.28142261505128, 88.34026428960985, 93.11820537813249, 101.17170210807555, 103.23686138276132, 92.02636657222625, 84.33240998175837, 102.60123345159717, 112.95228204419537, 107.09867015961679, 115.97887700603856, 107.77189793125277, 108.05870948299285, 111.18527781578803, 109.55204209973736, 107.9369277338828, 106.84876811119818, 101.51751395194762, 127.36207377526068, 65.94109089143815, 3.326055421944588, 0.6915820125610598, 0.24762744144085916, 0.6420236621652881, 0.5332022821230273, 0.27209426727025743, 0.5166903294382558, 0.616055365291334, 8.496084232484142, 85.07166693287512, 109.95562261150731, 74.48546440370622, 110.93196330531951, 114.7832993538149, 102.56710098635767, 43.69270124743062, 34.39581317286338, 75.69637852330362, 78.78878301189792, 100.01335559352752, 102.6316475099133, 25.059848485454438, 0.48201308375404733, 0.26766600327626355, 0.12578008456095574, 0.19100373791110134, 0.33829627618674313, 0.2289447020138464, 0.19314049502774594, 0.11148591045170061, 0.18353430404057428, 0.2513638054651599, 0.21626878139232436, 0.07906198982269534, 0.1277114228615838, 0.07332295705113681, 0.20571441870302926, 0.12384184380812992, 0.19019217500763555, 0.2429278750693606, 0.20499253405197976, 0.17527861881159967, 0.07449641989003267, 0.3364104435088173, 0.30185571060545985, 0.2053685453269751, 0.1687509521481491, 0.12765233449998403, 0.24825053139319345, 0.21531984360227663, 0.06610469276746435, 0.15889638013416724, 0.22194279628174923], [0.01751877224793838, 0.06351887023136502, 0.030119876722775163, 0.05709782002433654, 0.1033816654835978, 0.08253855044923483, 0.06336919963359833, 0.03641872441456203, 0.019254551284135352, 0.09084671270102264, 0.09827634830388332, 0.008636181948766595, 0.058379178686488065, 0.0752148418236644, 0.047465451812792214, 0.014882952898680685, 0.128061241590448, 0.04905838609462784, 0.03368901141408471, 0.033019684225080476, 0.08965948326212746, 0.10994298638956201, 0.10045162432136075, 0.1755583175127545, 0.05292525702726938, 0.39140519896341913, 0.35906072165216174, 9.983990250095244, 60.763044511118245, 97.4207865807318, 84.47741216228854, 68.65734008050734, 72.58633121367424, 49.00290796833654, 63.783434283348825, 89.51880316580497, 76.16676484384845, 110.91692493807886, 58.24654986781459, 15.540491419453776, 0.14537054624768997, 0.06303058877106636, 0.1250700742727326, 0.06229607516058511, 0.16786808178069132, 0.20512224805931892, 0.026270169990077138, 2.2437158611512955, 113.61842601530014, 111.96575103267547, 96.22624443423365, 99.59129287350564, 88.60414566532259, 89.24947754029306, 87.42730909778227, 90.0558776240195, 87.27546630367156, 81.96027817264681, 81.81954353086411, 81.37380538448211, 82.09715320217995, 80.58576983790245, 78.87280802572928, 76.65586087011522, 78.82897946142381, 87.83540817999071, 88.8725926799159, 85.57088267418646, 82.63472972377654, 80.21247786860313, 82.21619713690974, 90.20906186872914, 101.54651595700173, 98.09366918379261, 95.52603075581213, 82.49441869797246, 74.40118051344349, 76.90085995581843, 78.89810731334072, 81.36767079753261, 93.55723627151983, 95.65510811344271, 97.10971124710576, 67.99977825533959, 56.439133459521884, 71.31293373723184, 81.3119182279033, 74.54244075282928, 81.0585880279541, 91.2570328866282, 87.13529648319368, 79.07269985445085, 90.68675948727517, 101.32349783374418, 93.85469313590758, 82.35504119626938, 86.53993560421853, 93.97521188182216, 99.58318925672963, 100.0480999485139, 98.53422980154716, 98.36109638214113, 91.92754637810492, 79.7532859925301, 78.46251241622433, 76.19099724677302, 77.27358710381293, 77.80234613726216, 79.23906326293945, 77.7324338113108, 83.39677564559445, 92.32152492769303, 92.01828648967128, 94.26939748948621, 97.43018457966467, 98.06578897660779, 91.59026176698747, 92.94081226471933, 88.81849535049932, 91.5393650916315, 96.18265905687886, 86.75925885477375, 106.37681284258443, 57.27717530342841, 1.61701928944357, 0.07973085352850538, 0.12761396881673606, 0.24141528042814425, 0.05186666907261937, 0.22636801124580447, 0.03933913968203049, 0.1903277878919917, 4.38776086415014, 60.56153666588568, 97.49549988777407, 61.81589495751166, 109.37082075303601, 107.97180544945502, 114.02536407593759, 57.28516124909925, 16.88342663549608, 35.81405201265889, 53.28735213125906, 73.5787457804526, 74.15953113186744, 26.866907958061468, 1.4539222347159542, 0.40499633418456205, 0.05003563083347775, 0.10954101239481281, 0.06588099509357445, 0.03857522744745497, 0.048453326021591504, 0.11666114081538494, 0.16974754060708708, 0.04908128446268459, 0.08553865035214732, 0.028583696149590037, 0.06976941990996562, 0.08052509518400316, 0.04490869082210045, 0.014221736665574775, 0.10022044196845063, 0.02505508559425512, 0.06583470806118942, 0.07143694051210919, 0.10173393293253838, 0.10955074937233042, 0.09096377093585269, 0.20303252874122513, 0.1330926695898656, 0.06169598699817735, 0.06568911305117993, 0.022106711947990042, 0.03166307849178632, 0.0025423702684366297, 0.02121402033334298, 0.03452958223680335, 0.05274908744820184, 0.07814273793971346, 0.10670117808565979, 0.029905577032496373, 0.059703955381748185, 0.0506662322779096, 0.019587493096027645, 0.12652836860187594, 0.027120242218276667, 0.06724376591943926, 0.07103990012359235, 0.03760672377182111, 0.025441542478098024, 0.02355880288016652, 0.030445693916971647, 0.00420105763741078, 0.04139785542182865, 0.03190345198456799, 0.04139261538042657, 0.1594032085831127, 0.17338474221046896, 0.22110817413176262, 0.029229803213609323, 0.3021986115603678, 0.040659813976456086, 13.866340479543133, 82.02953938514956, 113.67080534658125, 100.20916031252955, 93.86108659928846, 107.50833818989416, 78.4413786857359, 40.14442320792906, 56.352594206410075, 87.1294835305983, 124.32121707547097, 69.11509636909732, 18.881723227039462, 0.237255193172924, 0.0948433091323222, 0.20296459206409995, 0.11283686054089379, 0.7172726178842207, 1.6573095081313964, 0.22661346581674394, 4.808234043659703, 125.82317890659456, 112.35190053139965, 105.78965756200977, 104.26274161184989, 94.13656250123056, 91.87668892645067, 89.13971393339096, 93.96594724347516, 90.99195126564273, 85.9818607761014, 83.92117300341206, 83.54322125834804, 86.66074460552585, 86.78559364811068, 84.15094544810634, 82.46166690703362, 83.90001573870259, 91.44730706368723, 91.44994289644303, 87.13071515483242, 85.50006820309548, 85.89031265627953, 86.3588946865451, 94.28031736804594, 106.81045439935501, 102.20700387031802, 99.46825596594043, 85.08652487108785, 76.4688265708185, 81.21611825881466, 83.20184953751104, 87.14740876228579, 99.81256161966633, 98.50794992139264, 101.72246563819148, 73.89640285122779, 57.91524294883975, 75.3251261864939, 86.73036667608446, 84.37468528747559, 92.30467442543276, 101.10812833232265, 95.12652166428106, 83.38321208953857, 94.96918755192911, 105.33941653466995, 95.65881083088537, 84.95438806472286, 90.45811668519052, 96.40500253246677, 105.01673883007419, 100.9565757936047, 99.7661913594892, 103.32797804186421, 95.07764108719365, 84.79856798725744, 80.85644475875363, 80.4532015708185, 79.25146579742432, 79.75119144685807, 81.74795243047899, 83.03168927469562, 88.10383166036299, 96.88680295021304, 94.6083216513357, 96.16145472372733, 97.25761598156345, 99.44382744450724, 94.8814441311744, 95.54368142158755, 90.9118486219837, 94.36510332169073, 100.99992582874914, 92.10392752001363, 107.98147801429995, 74.59395716267248, 5.07443844310699, 0.13119062649146204, 0.14203974917050333, 0.24518510717297756, 0.027237386637998205, 0.35973570640048674, 0.06050120776278838, 0.23087587177513108, 2.8108592091068147, 66.21207175716278, 101.73115761049333, 65.71681760972547, 113.36454668352681, 108.03528508832379, 79.77347050943683, 28.125886801750433, 31.38098728272223, 59.98278702459028, 77.32359732350996, 79.60008605833977, 93.47194825449299, 46.121774104333696, 2.744812378960271, 0.34574596031058225, 0.03881325862640816, 0.04641792616776882, 0.04201915655885974, 0.07503526315333382, 0.043306394945830114, 0.048336800217868826, 0.04501081034240704, 0.043405178153226455, 0.029915158877209313, 0.05201908992603422, 0.036388322215286956, 0.06224003199848437, 0.09844499489953441, 0.08030293734684106, 0.08652975362154745, 0.03542631113481137, 0.019996825365289565, 0.06078800809900127, 0.0721896831847487, 0.04285015511296449, 0.0531347667528016, 0.08369867569736897, 0.05001397352785834, 0.04853373077968436, 0.014088746674749401, 0.0383657445350001, 0.02030512404387757, 0.04223401740854306, 0.11305565525206829, 0.11496628619610302, 0.1808675979414294, 0.1378708825476708, 0.1841498863312506, 0.1564382950985624, 0.1895075375514646, 0.18938073467823768, 0.15665993965681524, 0.2691122547032372, 0.15379395876680652, 0.23096798618714656, 0.2063837344007146, 0.25644194184532093, 0.12217755609702681, 0.1385033340944398, 0.17037367958936, 0.16465904671818982, 0.13399145926438993, 0.08349956178496923, 0.1629099454129896, 0.3290337215988867, 0.3750972401711249, 0.24492819192669085, 0.10964629585824667, 0.6960940252869361, 0.47655283803901366, 21.370092515022527, 104.05231429684548, 131.8709324252221, 112.71213100802515, 96.9609514359505, 94.697398677949, 60.89451451455394, 86.6998427914035, 151.4862349725539, 97.67506599426271, 135.43363694221745, 81.64918714954008, 30.699334259956117, 0.5672061058782762, 0.3149571317818857, 0.3252284096614007, 0.346038973619861, 0.41463911353099736, 0.5275030169756182, 1.1772931559431938, 4.290688085940577, 132.89045056989116, 122.98960378093105, 109.633250851785, 108.86073220160701, 100.24371639374765, 100.77891595901983, 96.39225482940675, 98.18695883597098, 99.85660199196109, 93.01478816616921, 88.72619413560437, 90.32445799919867, 90.18348017046529, 90.46256465296592, 89.50239981374433, 84.64623097450503, 89.17328942206599, 98.44783567613172, 97.8447320384364, 94.051941287133, 92.79642981867637, 90.57094758556735, 92.31208770505845, 99.36048492308586, 112.8841975427443, 109.90919743814777, 106.19837637870543, 93.11855054670765, 81.98627564214891, 83.25702159635483, 88.11883080390193, 92.88174136992424, 104.79910219869306, 102.87001779002529, 105.01666822741109, 79.93296977012389, 69.8762087668142, 79.98513729341569, 93.7183201697565, 88.31039936311784, 99.22061320274108, 111.41566215022918, 109.91593607010381, 90.22340205407913, 101.32651021403652, 111.36913499524518, 100.93686196111865, 89.70113846563524, 96.52987510927262, 104.8889244756391, 108.86939279494747, 104.81661165914228, 102.72586284145233, 105.73736452287244, 103.14040245548372, 88.80714401122063, 86.12166189378308, 83.44298116622433, 84.26556494928177, 84.98243301145493, 88.42718401262837, 86.8212793719384, 94.22352929269114, 100.24833694581064, 99.85469572005734, 102.22816113502749, 107.91171473841514, 108.94487488654353, 101.23077300287063, 100.86960900214412, 97.58136841558643, 99.67736536456694, 106.82817566779353, 96.19229239802208, 120.44734308796545, 68.95910370734431, 3.6610508397702253, 0.2953135342367234, 0.26287381687471945, 0.48174565778143946, 0.1855600856605076, 0.6251909944318956, 0.16120388292737547, 0.38278910000958755, 9.173599154718461, 82.88246662386003, 114.89303942649596, 77.45612636689218, 121.4318266222554, 130.5184756555865, 145.47594008907197, 82.07478000271706, 23.609002982416463, 49.02935258803829, 74.23750000615274, 94.1198375148158, 110.77506065368654, 50.06419543297061, 3.3625199813996596, 0.45477035365277724, 0.24217265027184642, 0.19335909055606013, 0.1522198932305459, 0.19961900948997469, 0.1829237626084397, 0.17614658110805098, 0.2906585082171425, 0.14293843159271827, 0.15333421408168732, 0.1658068302898638, 0.1350374757162025, 0.233450984402049, 0.18057365000488299, 0.11201048915785168, 0.21871721372008326, 0.1275056976103975, 0.2714522549461934, 0.18033669900990304, 0.22072522210017329, 0.21994817911857562, 0.20327530200442961, 0.2540219773448283, 0.16300435808877792, 0.1190019531115409, 0.16601483848306442, 0.09883824315282608, 0.1420495704176926, 0.16125631398491322], [0.06332865059976617, 0.057207876215538675, 0.07671553145853743, 0.09951309766620399, 0.031037312977376486, 0.07058467535722641, 0.04778297610520836, 0.019569442149311788, 0.0875280504565566, 0.09767802597414102, 0.003037460813967271, 0.056128611547812346, 0.03667982633135492, 0.014998513431618772, 0.028683406323374763, 0.06159102146123206, 0.035967322426938245, 0.03222580263090711, 0.04649183450026378, 0.050368396445147456, 0.059055561545274915, 0.03300440843187032, 0.18035830268936773, 0.2691311923967254, 0.9170865507856493, 14.448612409253276, 50.454224155795195, 97.53848122012232, 103.90432327024399, 91.25469515400549, 74.30608657098587, 81.8679141998291, 41.70602075515255, 53.62726473039197, 102.29377454326999, 95.42913252307524, 115.1282561209894, 71.16873956495716, 19.885094934894195, 0.05767409051317842, 0.13190256732125438, 0.18107090235477497, 0.27571541167074637, 0.41889647863084273, 0.11736896009214463, 0.20471960756807558, 3.1745639251124476, 32.20643831837562, 126.70284102039953, 96.03352269818707, 105.27424243188675, 73.57052449257144, 82.59140322285315, 75.30279221073275, 86.65013851657991, 73.16364918985676, 77.05086708068848, 76.5996297713249, 80.1947016869822, 79.43948068926412, 82.43126853819817, 74.93560344942155, 79.1367913830665, 77.5230969152143, 80.12427945290843, 77.5317967322565, 79.77479627055507, 81.51049214024698, 84.47476064005207, 80.45553930344121, 89.10639732114731, 103.24764005599484, 96.02288523027974, 94.29298662370252, 88.99621794300695, 72.77058063014861, 73.28698419755506, 74.18084529138382, 81.55688593464514, 76.87099502932641, 91.05746269226076, 93.25573152111423, 99.07568946961435, 83.08704176256734, 50.217395367160925, 46.489712038347804, 56.508269156179125, 74.87425757992652, 87.47297333132836, 83.37845817688974, 71.96914626706031, 75.24750248078378, 95.87736529688682, 96.11463731335056, 91.42857382374426, 78.24096125941124, 81.73996648480816, 94.6845176143031, 100.15671037858533, 100.12467245901786, 96.76036927007861, 102.91121052157496, 92.59856193296372, 86.46195888519289, 84.45765910610076, 78.97795892530873, 84.36718571570613, 81.23980152991511, 73.5298102901828, 74.16469297101422, 78.02610951085245, 85.35307345851776, 92.62812875932264, 89.69785151943084, 85.34778610352548, 81.76609731489613, 83.32306646531629, 79.8552127038279, 78.37529459307271, 81.17136401514854, 84.44317771542458, 93.95606287064092, 93.81493599184098, 94.17737084050333, 45.67214496674077, 0.7349300252333765, 0.24490583748106035, 0.25061271754243686, 0.057830609936988166, 0.06097542001835762, 0.08840947291783749, 0.1729109934380939, 0.2708675153553486, 4.78924241758162, 56.60377886987502, 101.69017668693297, 82.21502042585804, 84.81988999151415, 115.54637293661796, 95.80171846574353, 46.771538257598884, 18.6557750932632, 44.54479694366456, 80.19754148298695, 68.52597205869614, 85.38985744599374, 67.51005464984526, 12.94624069044667, 0.6084826168033385, 0.018092382496463198, 0.030430577087005785, 0.019571813191437436, 0.11384266503756085, 0.09051003238005985, 0.06321813475580947, 0.005998201752757473, 0.029246582454370878, 0.034261635324407014, 0.02312985684482321, 0.013486233844061293, 0.006272875395933948, 0.11058208757951377, 0.07574947926426127, 0.03056987102383808, 0.015577255511626363, 0.04944293924997892, 0.056969642023285555, 0.0167618639722106, 0.06637815551291551, 0.04182530567049981, 0.06066840262182298, 0.07399768132956759, 0.011859443264021989, 0.03006608777439162, 0.017308789463112914, 0.02545682593218742, 0.06613814016623844, 0.05421479367801259, 0.08705145949798246, 0.040915974626137365, 0.04159739451302637, 0.04594076830413073, 0.04174764350717587, 0.028789145609123573, 0.050412622701016166, 0.10124263308581807, 0.07977159408431861, 0.03324761836519165, 0.05463047298572717, 0.025282604131667365, 0.01896930802162857, 0.06917669002207057, 0.023531083903846242, 0.05763313928318601, 0.025765888783479893, 0.054453705858078696, 0.0538653694844294, 0.03447092671488081, 0.09761963475255236, 0.23634580084152762, 0.7952207771520462, 22.069123598837084, 64.8547669379942, 122.2035058852165, 117.60989266057169, 121.06889755495133, 108.87570781092491, 114.98065733140515, 58.52105694432413, 24.963524879947787, 56.00437794962237, 105.04556825084072, 127.06697033297633, 80.92572950547742, 22.84124020607241, 0.3935798774323156, 0.11430159766948032, 0.01641012619309608, 0.0501968233936256, 0.6834236051767104, 0.3163424638971206, 3.059102830386931, 2.7007499433332876, 39.9660377348623, 131.0094936432377, 101.35316664172758, 106.91143189707111, 77.58217565474972, 88.24601757910945, 81.02963309134208, 90.88101094768894, 79.47001241868543, 81.77081200384325, 80.246869210274, 85.1178018508419, 82.06051042003017, 84.53913457932012, 78.04459956384476, 81.743331878416, 81.24829738370835, 83.35840702056885, 80.72701438780754, 83.11562799638318, 85.59251846805697, 91.18475144909274, 87.87616945082142, 95.45668325116559, 107.88542701352029, 101.74727855190154, 101.56277810373615, 93.17176926520564, 75.57718553850728, 77.03059627163795, 79.8972918910365, 87.13583777027746, 79.50122664051672, 92.86321209323023, 95.69833263274163, 99.7318470862604, 88.2133363908337, 58.52118246016964, 50.80042431431433, 60.4390488901446, 81.6280455743113, 96.48639955828267, 90.11872183892035, 80.89260116700204, 80.73718901603453, 102.15627977924963, 100.91612831238778, 96.66257673694243, 82.31784143755513, 87.37618492495629, 96.40223333912512, 106.13504578990322, 102.62694851044687, 96.60975810020201, 107.14666428104525, 98.41058100423506, 92.88579710068242, 88.28439404887538, 85.46355878153156, 87.27897290260562, 85.76686782221641, 77.88136620675364, 78.19998818059122, 79.80303733579575, 89.0951479634931, 95.51684456486856, 93.2615444737096, 89.66845727735951, 82.4999257056944, 87.42906631961947, 81.32344999620992, 81.75290246163645, 87.47455012413764, 88.74074612894367, 98.33977437788441, 99.11759607253536, 95.96241012696298, 60.72420520167197, 2.646513860071859, 0.3067867734259175, 0.26754333727782775, 0.4226585525658823, 0.2172320909918316, 0.022458442066225315, 0.2051255882026688, 0.2597087092937962, 3.5423714403183233, 60.53906148479831, 102.85148851333126, 89.03488466816565, 88.2140188832437, 125.93804943946101, 79.01100881638067, 31.84894173376022, 33.63137068287019, 68.71831724720617, 100.44775809011152, 77.8814995673395, 94.76572636635073, 90.96170979161417, 25.153897116261145, 0.5109670397735412, 0.03120500004790243, 0.13022722496140388, 0.03466489634686901, 0.04457002250297416, 0.05784004430977568, 0.06256108412579184, 0.08715870414650248, 0.046793339894183224, 0.006645321968056623, 0.051750254351645715, 0.07706124395612748, 0.07458931571173091, 0.038883432280272245, 0.046047154934175556, 0.048064394673753175, 0.02555309828641194, 0.03837517124690837, 0.022142177988444606, 0.01569486149932228, 0.012923663880135263, 0.06440744029297944, 0.09592991292236314, 0.04468827200452647, 0.051270763750278184, 0.018878202930453326, 0.0694690828001307, 0.043685397794169765, 0.17638446673029856, 0.11106852276791489, 0.23691367117627976, 0.19770979580859985, 0.15936096649496787, 0.13651247076209516, 0.17033405752191622, 0.08731241968850936, 0.1914090903535966, 0.20730425032877153, 0.13749775176327075, 0.1314621740171025, 0.13544678117238707, 0.16512444513219018, 0.08659959785760411, 0.14630382520056542, 0.1715647777722728, 0.11693572971008478, 0.097287037680226, 0.15813881110760475, 0.1117991791256974, 0.19318151137521192, 0.20609314192927655, 0.4101876830381732, 1.6583159638027993, 34.7668654687943, 87.79417622473933, 143.18970034199378, 134.45299733069638, 119.17329449807445, 103.58527768042781, 101.74284627360683, 51.3207188729317, 78.01096131724697, 157.51967184005247, 128.27897487148164, 137.6033195372551, 99.0998669593565, 35.94999351809102, 0.7214558869600297, 0.2610425296570024, 0.6455967575311661, 0.5175944970500085, 0.6668709579014009, 0.11351258839450537, 2.6877181135839034, 5.3570589423179635, 41.02558758951003, 136.55032004079513, 105.28031426091349, 116.28653987761467, 81.98039993163079, 92.26652545313682, 82.15194086874686, 95.52714470894107, 83.21691143897273, 85.20432933684319, 84.31690093009703, 91.1319955702751, 88.52344682139736, 92.84453376646965, 83.85623424283921, 87.93088651472523, 87.41933884159212, 90.66669264147359, 85.22157992086103, 89.3978137354697, 90.6882421432003, 95.86105608171033, 89.80779555536087, 99.60015743009507, 109.47410460441344, 104.94165682023572, 104.7239495861915, 99.60387583701842, 82.16127610975697, 81.32888640126875, 84.22665503717239, 93.31612817702755, 83.60792467671057, 98.22524901359313, 100.95663855152746, 106.56032485346641, 93.26297221645233, 66.16873741149902, 62.15942790431362, 69.78811233274399, 88.86850557019635, 102.70578030617007, 100.52338923177412, 89.92700422963789, 85.17674722979146, 106.69986709471672, 105.38597506861534, 101.07276424284905, 85.11061606868621, 91.55805910787275, 100.2403353106591, 109.28856865052255, 105.91959784107824, 100.74741148179578, 109.77583685228902, 100.61029326531195, 96.70945690524195, 94.23049542211717, 89.38160650191769, 93.11130985136955, 88.69785893347957, 80.1819069154801, 82.63152906971594, 85.17419768917946, 94.44704947933074, 103.34544043387137, 101.70747433939289, 94.83953752825337, 88.16197687579741, 93.41013170057728, 89.28882675786173, 86.97140416791363, 87.76454664045765, 93.215299729378, 103.52466137178483, 103.44025981041693, 103.44424493851201, 57.298611056420114, 1.8942807278325482, 1.4893852414623385, 0.38922350312913623, 0.5576385257224883, 0.43662464186068506, 0.3378448665382401, 0.3121624123905936, 0.5239193189528681, 9.618304737152593, 77.3336072121897, 122.61897117860856, 91.83017746094735, 91.87202130594562, 124.8679562537901, 117.36079077566825, 68.28739781533518, 24.535339340086907, 59.914780970542665, 101.97602333561068, 84.78287066182783, 111.09431020675167, 104.02594812454717, 30.21391937809606, 0.46511103909823204, 0.15823259559129516, 0.20232343775851114, 0.1734122600887091, 0.2009101893993155, 0.1328332109316703, 0.14792567930154263, 0.1485135445311185, 0.1171236357561523, 0.09078981535088632, 0.1235523161989066, 0.1875344014936878, 0.15716480692067455, 0.2537086167402806, 0.1751858762074863, 0.11102148496936406, 0.090189662071005, 0.1358507853001356, 0.19267593931046226, 0.14278875333407234, 0.1405993046899957, 0.13821546889601216, 0.15944981737242592, 0.16238083912720605, 0.1694741085051529, 0.12442327389914183, 0.08910193213171537, 0.09025424328302184], [0.04644439450555271, 0.06983915689371287, 0.00822516524368116, 0.01630897577401371, 0.06943152150920323, 0.024370733505835938, 0.030237741265145522, 0.03155344556416235, 0.02912924076700884, 0.048686343155080275, 0.0504194293922234, 0.019685146323735678, 0.07291038039951556, 0.03331883389863276, 0.014986447546811355, 0.05501972226005408, 0.11097679906074079, 0.020284255808820168, 0.04947906412604836, 0.08463990664289844, 0.043878471103286555, 0.10341793208593324, 0.24188123042545012, 18.88044453436329, 69.40279437649635, 95.58237952570762, 104.80852373184698, 84.5127134938394, 73.34254849341609, 45.11221093516196, 54.30791362639397, 35.75114111746512, 63.590214406290364, 110.078079008287, 104.13935169096916, 118.62542567714569, 61.51668871602705, 24.394643922005933, 0.18132354283044416, 0.07834421906379924, 0.15237465831300906, 0.08398389789245783, 0.27009744377386186, 0.08184658919250773, 8.230720200846273, 13.060692510297223, 0.29141941738705485, 75.01787908615606, 119.5679476953322, 100.14408034663047, 89.87765296812981, 90.38844754618984, 91.3642155739569, 94.28536153608754, 92.0410676156321, 95.51118850708009, 89.560027276316, 79.63861157817226, 75.14227313380088, 75.0222642960087, 72.99366151132892, 72.19922465662803, 75.82817016109344, 75.59338492731895, 73.5042207471786, 77.03091006125175, 83.4461033728815, 89.49579454237416, 92.68162988847303, 96.53397790847286, 103.02455133007419, 94.22258007910945, 95.61363297124063, 97.35746383666994, 77.48934884225169, 70.67845113815801, 74.94725288883333, 79.53420592892556, 82.06964954253166, 77.8993385068832, 86.00958408847933, 92.0673631852673, 89.39407963906565, 95.96880359034385, 82.81020087580528, 68.59699049303609, 63.72366912903325, 50.26191034624654, 55.55566272427959, 69.49812366116431, 66.61799784629576, 83.48290304983817, 96.55231106665828, 98.21548231186406, 86.6724568028604, 78.79643163373395, 76.6707266530683, 87.67990189213907, 93.69554688853603, 96.45593058678412, 89.31435354294317, 101.74991438465734, 100.65245874466436, 94.40980265217443, 93.98327627489644, 89.28237838129844, 87.94080226652085, 90.97430844460764, 82.94286327977335, 74.43874897495394, 73.35692005772745, 77.59672764808901, 76.67126794015208, 80.10746032960954, 79.61265333237188, 79.38447336996757, 76.55849195295765, 76.00860703376033, 77.42736754878875, 84.1575114957748, 89.85180454869425, 86.966108968181, 94.50436315228863, 94.05404367754537, 93.44885333891838, 31.779878600951168, 0.6952616247919299, 0.32647115749216854, 0.3868016234088329, 0.06878976199415422, 0.1260925105382358, 0.042102997221292994, 0.10748808061884296, 0.23261216409023733, 3.444266098160898, 42.942771527075, 83.84285896055161, 90.04500481390184, 53.895927475344756, 57.59222792040918, 88.49790434683524, 47.72360732478481, 32.13053849435622, 45.34870632233159, 62.286865711212165, 63.523181100045484, 82.34702387163716, 88.38745824752316, 17.767679883587746, 0.3608675859868527, 0.031164318863903324, 0.12741174458736373, 0.06602087508766882, 0.02575176212215616, 0.04998398501606238, 0.06547915133377237, 0.0680991720348116, 0.026383960859910138, 0.06372584420586787, 0.007148909865082392, 0.05802568656602695, 0.0441667155152367, 0.07218402179498827, 0.04200031845680168, 0.008500073022479493, 0.02773320257303215, 0.019941444869243333, 0.013056145380100897, 0.0066848722147575075, 0.021986880474874092, 0.021839623054068898, 0.059166671107372934, 0.0727309319641321, 0.05025583514643293, 0.048070075215711716, 0.018935533120266853, 0.12488386128097774, 0.054609049336924675, 0.05659078090121189, 0.0363295019844607, 0.0789685041132954, 0.0535350208801608, 0.0007770320289343926, 0.05143934905889535, 0.1407722260562643, 0.025070888072913213, 0.06010998964249607, 0.03097859999885963, 0.022113532045735948, 0.07050782141666259, 0.03873359314316223, 0.045228750865545966, 0.09621970100148071, 0.018961120456937822, 0.008942524230317965, 0.0186998346790431, 0.05600217256634947, 0.09034115595803147, 0.07485533208255807, 23.240106028895227, 90.69702040764594, 114.37627500103368, 124.58664386503159, 98.62962968887823, 112.7043019571612, 69.57235843904557, 66.25101304823353, 58.20700060936713, 27.74399111347814, 78.73272449739518, 111.64623475843861, 127.96727195862802, 70.00086953563076, 28.006915430868826, 0.21984051312169722, 0.06505118397575232, 0.1943113838112162, 0.07064255329990579, 0.2430519047043016, 0.5561845521292379, 10.786462080094124, 6.348090383314318, 0.15754800410039965, 81.03473217256608, 125.44754920467254, 105.72438932234242, 96.42786995057138, 95.98451660525416, 97.43442858419111, 99.11547014790197, 99.23867963975476, 101.72991814151888, 95.34954763227894, 84.55044669489708, 79.80947002287834, 79.71802388468097, 78.75810223241007, 79.05402152769028, 78.33858905300018, 79.19413643498575, 77.8979342983615, 82.74497185983967, 89.68494692156392, 94.06563035903439, 96.48392846507411, 101.53834958230297, 106.6153007938016, 98.64024362256451, 102.18348533876481, 100.09167748112833, 79.614590983237, 74.27370348284322, 79.67417178615447, 83.28559214068999, 86.66742047955914, 79.83034487693541, 88.67257533534881, 96.88413573849587, 93.5153139791181, 98.18270698670419, 91.03873729705812, 79.29036002005301, 74.07908331963324, 57.785298747401086, 61.042803641288515, 77.40937955917852, 74.06827326743834, 86.54764698397729, 98.96361950905093, 101.93373234041276, 90.85707664489748, 83.06187583554177, 80.58925290261546, 89.76195873752718, 97.94427394866945, 100.34129711889453, 91.18570066267445, 102.68102230564241, 104.07654669977005, 99.61052033209033, 98.1573292516893, 93.15310662792575, 92.53528625734391, 94.04736780351209, 86.60625503909203, 78.5884597224574, 77.41232133680775, 80.34241030293127, 79.70640582423057, 83.16785827759774, 81.62751213196786, 81.87725728557956, 82.49802727853098, 79.57969757818407, 82.02761742376512, 87.32915570659023, 91.50128672199865, 89.76880719584804, 96.1035370057629, 96.6960031755509, 97.73302293592884, 49.03913105687788, 1.615975816403666, 0.44344288567381523, 0.5539719063428141, 0.7820292333922079, 0.20494977102404643, 0.08689682465046646, 0.08211803712671803, 0.24078880436718467, 2.229131753406217, 45.07842756086781, 91.7846779669485, 102.0770243675478, 60.36104079215758, 63.082628327031294, 52.778534427765884, 33.29937342674502, 47.858752589071955, 71.39306775985226, 90.17654542000064, 81.34009653522124, 90.81988473092356, 107.8740050715785, 30.318042616690363, 0.31597155476770095, 0.05469513463697607, 0.055636361752065926, 0.098953309559053, 0.06346776833637588, 0.04393087917818658, 0.06804025987343443, 0.02152002840903738, 0.015766061711004906, 0.022596832019306963, 0.0454447225427195, 0.1430621241489726, 0.05998322124322576, 0.10207632826941629, 0.012670711223636905, 0.007182430042209285, 0.03516706315079524, 0.033301566276819475, 0.04141758984675811, 0.05677048214561036, 0.09417197862339598, 0.04825102901386638, 0.04245148678760856, 0.06067722029383145, 0.05466899188656, 0.025546352882238648, 0.034457845763573726, 0.25693675803561367, 0.194150842425804, 0.10980780251444348, 0.14395247153457136, 0.23080595859116126, 0.22624954340919373, 0.1249029521920508, 0.17168321496536657, 0.21768769880215968, 0.1256890886373097, 0.1697698031221667, 0.10795424512076764, 0.20696577736206595, 0.13945202673635176, 0.11532054823492804, 0.19690767110836124, 0.18341666357892175, 0.19822610842604793, 0.08321166594302462, 0.14629060252299234, 0.10546121881493639, 0.306447641623597, 0.16549183025715813, 36.04867250688615, 114.42746193178239, 140.1450938563193, 136.44248624001781, 109.27817436956592, 101.73578600729667, 67.83752549079158, 70.59580679862731, 47.53596898048155, 95.12754148052585, 164.28135164322393, 139.48859891583845, 138.64812912479525, 87.21516378464239, 38.895477787140884, 0.5354827113689915, 0.24599572012741722, 0.4343350502031465, 0.3244283074332822, 1.1992390622054379, 0.2951712257439091, 14.981181044732372, 22.53236924448321, 0.5957561190570555, 87.89316115840789, 127.97019804677657, 113.94304137076102, 100.75703697819864, 100.44483200196298, 101.63944475112423, 107.01874794498568, 104.95370634140508, 106.09403348738148, 101.80296051886775, 90.60138517810454, 84.00278183721727, 84.45945555163969, 83.24326192179035, 83.09177214099516, 83.55480793983706, 84.73059331217121, 82.85594355675482, 85.36532694293608, 95.84599418024864, 99.09806266907724, 101.74065759105068, 106.2776396351476, 108.83637428283693, 103.16381900541245, 107.8579782670544, 106.39167862553751, 84.95909490892964, 79.23329737878616, 82.96613077963553, 88.13710904890492, 92.74773751535724, 85.27480648409936, 94.72585155117898, 102.13745240242251, 96.91211008256482, 105.72105530769595, 93.807538401696, 80.13745077194707, 74.11229795025241, 62.98721667258971, 71.60701736327141, 87.47905300509545, 81.10311477415024, 89.95128370100453, 105.42854847446566, 108.58823730099587, 95.50682683144846, 86.49729944044545, 85.76420061049923, 96.34156996204008, 102.58101755572905, 105.58861255645753, 94.95719294394218, 105.65655585258239, 106.66764090138098, 104.77205353398477, 101.78641596148091, 97.58028584141886, 95.35357982881608, 99.9087538257722, 90.58643310300766, 82.40894240717735, 80.7353219678325, 85.00813238082394, 81.68748517190257, 90.11898856009208, 89.59168864834695, 88.08585936023344, 85.20780455681586, 84.24157573330788, 86.05017277502245, 96.38928167281613, 97.84403385654574, 96.81051285036149, 104.4661400395055, 102.2201987235777, 105.85994643549766, 45.23095284738849, 1.624827747864108, 2.09405071793064, 0.7344932325424687, 1.0479765337321068, 0.3534013543638491, 0.15119328944673463, 0.20202323854450258, 0.5438144384853302, 7.1740670165708, 60.06037542896887, 103.05277670583418, 113.39332119111093, 71.85379720503285, 80.88348557872158, 119.22507762908937, 64.54127150197183, 43.24630414285968, 61.72375455979378, 86.39875381223618, 84.96724559414773, 103.53753459069037, 125.11641486998528, 38.884730492868734, 0.32083121819361565, 0.14043052019851823, 0.24897521992604582, 0.3323468986538149, 0.11343999390280056, 0.1272656746028412, 0.21975886347072743, 0.14821179781950292, 0.1424774764886787, 0.1977759551617407, 0.1390341870606907, 0.30981882685615175, 0.12153448657162728, 0.21681892445250867, 0.16221547138787087, 0.09602958096131202, 0.16369693221584444, 0.1328489616993935, 0.11345817316924373, 0.13717460055505076, 0.14223494837360998, 0.13315872169069706, 0.14392380452444478, 0.14802698676864948, 0.11433295364822112, 0.1663409774341891, 0.0962696499341438], [0.1088804760647397, 0.005622798560052029, 0.07021788011996016, 0.047535188796539465, 0.09924515075380765, 0.01872782944701612, 0.014025013905108697, 0.06723885529584463, 0.04046577156611508, 0.0425944579464774, 0.12659681855791038, 0.0702839475425501, 0.01584124174945417, 0.018949738305602825, 0.10328453319567828, 0.03383430764980374, 0.0770204421132803, 0.007446078722545457, 0.0559021138225592, 0.017862931502261953, 0.034677667032566764, 0.2949460265376876, 43.51147205598893, 120.03951857166906, 113.28741719645839, 104.73771710549633, 81.3650506542575, 88.57817957478186, 53.582796819748424, 80.85866482027116, 200.58742184792797, 92.36856199079945, 75.40983369273525, 85.76027824032693, 114.97369120197912, 69.22514238665181, 22.9290856084516, 0.05865777039059228, 0.041645129451588284, 0.14673225221134004, 0.06723444262940077, 0.08524019781860613, 0.09413812519802202, 8.142635533886573, 62.125150311377745, 7.658485616407088, 2.065137456501684, 103.4002124109576, 107.23875368795088, 106.79171331467168, 101.8722923340336, 95.45007013505506, 92.50330325095885, 100.79994770788379, 104.56047304214971, 103.08216310316517, 97.90866667224516, 96.98676847642469, 85.71359419053601, 81.0507825113112, 75.56785814223751, 78.02454056278353, 70.77319991204047, 74.81659873839348, 73.97854512737644, 74.99096378203362, 83.75180505937146, 92.21858624489077, 95.12683545389484, 104.07484439111526, 92.09157989871119, 96.66875054759365, 94.68540406996205, 78.95762535833543, 69.24759403351815, 70.19668209937312, 72.39568048907866, 78.02290885679184, 80.84379119257774, 77.45577335357666, 76.69495905599287, 85.11235760104272, 86.08782752867668, 85.9505210384246, 88.54775767172538, 95.1428779478996, 96.65506147569226, 88.95382496618456, 50.694889022457986, 56.94623316487959, 63.16464508733442, 86.59122451659172, 95.20190961899297, 91.041671229947, 83.63691883702433, 73.57119129550073, 71.36616814521052, 79.9623247884935, 87.47629165649415, 98.03614370284542, 89.9282907670544, 86.31507396698, 102.43782751021847, 95.57275402930476, 95.19012681899532, 95.90224096851965, 95.7352892045052, 91.31629989993189, 83.81111914111723, 74.27868489296206, 75.0594562099826, 74.95556831359863, 78.958935429973, 78.53459773525115, 74.41392821650352, 74.71657829899942, 77.93201969515893, 80.23805956686698, 81.20391184283842, 78.84059752187422, 78.32713573209702, 83.38517327462473, 78.86897194770076, 93.77901492580291, 94.89128143556657, 105.19198248463293, 34.052605782785726, 0.6502553075551987, 0.21472503761610678, 0.08790955458196902, 0.13987694506443318, 0.13213751116587272, 0.043805891933340224, 0.06519002209026968, 0.19914354468064926, 5.39406160193105, 46.274005213091456, 82.39519842209356, 95.79612516587781, 49.17348400239022, 71.87791193685224, 78.84460618419033, 27.455643953815585, 26.353975688257528, 31.610243935738843, 44.168414146669456, 74.14862694278841, 74.82389434691399, 86.2728065060031, 20.640357117499075, 0.5227943954448546, 0.14505784447875716, 0.053231389592251474, 0.009505680251506068, 0.08541722541614886, 0.03590699300290116, 0.06707017805667655, 0.062475703626630776, 0.0277377933549184, 0.049906138991636616, 0.02342728282054586, 0.022540677774457202, 0.05572643837020282, 0.061907726039569226, 0.012178428869153704, 0.07189201206089028, 0.027365097325415384, 0.012858078135327708, 0.0549028019210504, 0.04843736457968912, 0.04315136556303309, 0.005587958317670611, 0.02315357301173912, 0.03807075471887666, 0.03545839489708024, 0.020922332356173187, 0.053020857139340336, 0.10407235503437058, 0.04053010379955654, 0.0435060719328542, 0.0704269455144963, 0.07068934595032085, 0.01708595172291802, 0.05913456819290596, 0.09706336298897382, 0.004800034972328332, 0.019962389713093158, 0.012766434867385656, 0.03442896041838873, 0.015219277946368582, 0.02827328115311121, 0.039864844537430236, 0.0307270301310646, 0.05136892259601624, 0.01608505784984558, 0.05332878235006525, 0.04828177212226776, 0.30836905142472637, 54.61668260635869, 139.28430618778353, 129.26494890643704, 113.03141194005167, 98.69947925690683, 123.55062038667741, 82.71645622868692, 72.1418482257474, 156.84391021728516, 44.86907497529061, 60.27518010908558, 100.545989928707, 124.22537003794025, 79.07925021263861, 27.25912928581238, 0.3019784378909296, 0.03014073729695332, 0.2076349091986495, 0.22704146381828094, 0.15317598628180643, 0.5505854299952907, 11.146576846799544, 58.597782427264804, 3.23849095932899, 3.7457281927908626, 111.70545470330023, 109.85805757584112, 112.6041324677006, 107.23913808022778, 100.15214473970475, 98.57513227770406, 106.94801192129813, 109.78195574975784, 110.1036685512912, 104.23429658336025, 102.3200701129052, 91.89598698769846, 85.36963370538528, 79.14775833006829, 82.30596450067337, 75.38807238301924, 79.14463612341112, 75.7263611209008, 78.74457790005592, 87.45142382960167, 97.11699901088592, 100.53202629089357, 104.45633411407472, 97.85001154868834, 101.79826936414166, 99.25614987650226, 82.22888208204701, 74.71862577622937, 73.77011037641957, 75.74013648494598, 81.93235089701992, 85.38764522921655, 83.68884317336544, 79.44778826928909, 88.70903768847066, 89.6304024419477, 89.12692700662922, 91.86596516639956, 98.74440608486053, 99.75057248146304, 96.39619288905975, 57.83157487069407, 60.04181477331347, 68.00949004388625, 89.01257422662552, 99.43050707540205, 97.72200892048498, 89.11054718878962, 76.87375637792772, 75.62191624795237, 83.34620844933295, 94.04955648606824, 101.65253762275943, 93.91869052763909, 86.20094083970594, 103.00886969412528, 99.56139656805225, 99.88422332271453, 98.81875853384696, 97.98668261497252, 96.39426308293497, 90.24204115713798, 77.77290482674876, 78.0527816280242, 75.68341116751395, 82.31164409268288, 82.22368886393886, 78.43069414938651, 77.56367775701708, 83.01515256204914, 84.80196475982666, 85.63406421292214, 84.74519237395256, 81.50523616421609, 86.62191314081993, 82.71918619832685, 94.207455419725, 95.33651751856651, 107.06864049357753, 49.37083413524013, 1.4952582553509743, 0.1682801298316448, 0.16491401610114884, 0.5428398520715776, 0.09826628190855827, 0.09590704519782337, 0.06914505825167702, 0.21948051308431935, 5.030479459993301, 50.59908905336934, 88.68737836037913, 100.71578933346657, 56.57445523046679, 66.47998532941266, 40.79120243749311, 27.682629554502427, 45.055830786305094, 59.739105855264974, 62.97395906140728, 85.26875034455331, 83.04345638521256, 105.5833173567249, 31.884141083686586, 0.5375171957477447, 0.015529792534277565, 0.157971405574391, 0.10251096059237758, 0.1886233035475016, 0.05921495762924033, 0.010374525464290093, 0.02715591893291041, 0.0213141595163653, 0.06076990544135052, 0.0375153562955318, 0.05759719443777877, 0.07748841458270628, 0.10840055262369495, 0.03561872177787366, 0.04921883554948915, 0.02324629646365441, 0.004516367456920806, 0.050206445457954565, 0.020547631091528365, 0.03463824414798329, 0.021602174101938165, 0.028835413489310496, 0.007162005180538062, 0.08337875738018945, 0.01190068369220582, 0.26933245901619235, 0.20245446943708006, 0.09744384055656773, 0.14357895770620915, 0.17767572324843178, 0.1286989408394983, 0.09072604619206921, 0.1898929563861701, 0.24717667530621254, 0.15318522530217327, 0.24877493389912192, 0.18697878856572414, 0.16331276976533476, 0.1430945756334451, 0.20936689609962128, 0.1571929683127711, 0.13757909497907087, 0.10700495493027473, 0.09280298716358601, 0.19741134327505866, 0.3119089905052416, 1.5099254683140786, 75.68781206684729, 167.62553307317918, 144.83089846949426, 128.5801266085717, 105.41450638924877, 120.70701183811312, 72.24829350748371, 94.4813153051561, 210.17648727663104, 119.32916164398195, 117.9784542514432, 106.84792872398131, 135.6698734529557, 91.6668656564528, 43.73012458124469, 0.5475286778903777, 0.21921058966507836, 0.5065137400261818, 0.382970693491159, 0.49880125710079753, 0.27616403275920504, 11.138620318905001, 78.76055763613793, 10.17983615398407, 3.950431298825049, 114.90732469866353, 111.04288008905228, 118.53948654667025, 111.48337794888405, 107.61657991716939, 103.3635853182885, 109.76550532925515, 114.54994970752348, 116.38569739557083, 106.50805534855013, 107.16015723443802, 95.76044728679042, 90.58313831206291, 82.29029070946478, 86.87951872425695, 80.31583232264366, 84.20288547392815, 81.683853057123, 82.21711497153007, 93.93399561605146, 99.70068777761152, 107.17811384508687, 109.30865903054516, 101.90718573908653, 106.07053064530896, 103.26122714627175, 85.90449594682264, 76.41778869013633, 78.23270074782833, 80.01428834853634, 88.1789921176049, 91.59908709987518, 86.65076609580748, 84.2309461101409, 94.42368784258443, 95.6274946274296, 95.48650895395588, 99.93962287902833, 103.99398865238314, 109.30115945877569, 98.91110681718396, 62.8288156755509, 74.22314413132207, 75.48912048339844, 95.97852322363086, 104.1515188832437, 101.53557254422097, 93.7175827641641, 80.5569717960973, 77.4188324712938, 88.43607994817918, 98.1979493171938, 105.24403233681957, 96.7972630839194, 87.21928227332332, 106.68712723639705, 103.68659250197872, 105.6395249212942, 104.50542649915143, 101.94373438435217, 100.85244471027006, 93.53896587125718, 83.11639678093695, 83.142119684527, 82.00226322297128, 88.96303469134916, 86.84480574823196, 84.08253931230115, 83.01118312343475, 90.63762003375639, 90.77286335729784, 90.56359706386444, 88.73739642481651, 87.55230719043364, 91.57880060134396, 87.69631308894004, 103.17822979342554, 102.74933430456348, 112.42386033458095, 46.294315245843705, 1.7312559918049844, 2.3353573824128797, 0.44445026065072707, 0.6466803735783023, 0.26689381729210576, 0.3389383191543241, 0.18040858870071752, 0.3412602397222673, 10.602744144778098, 65.81653210424608, 94.20324279415993, 114.05681363997923, 66.94238570428664, 110.00965718300112, 105.96523069566297, 37.53735319260628, 33.77387823597078, 44.251646841726, 62.830231651183105, 97.65295167123118, 91.67179215338923, 122.08141034649266, 40.14272482164445, 0.6198027609817444, 0.14670975986988316, 0.21801599812123085, 0.11758544121778781, 0.3952355466542706, 0.210011865523073, 0.18022872657785494, 0.0925940903083932, 0.2642650325452128, 0.12444294703703736, 0.13336758790237288, 0.13512940626711617, 0.16646177417808966, 0.2501884733717288, 0.15216229874039852, 0.19755657822374376, 0.197405643580902, 0.112788719575732, 0.18667000916696366, 0.25257102213799953, 0.15147327926130066, 0.08889943977156956, 0.14138514236096414, 0.1699408705556585, 0.1935566339882151, 0.1174444810397202], [0.028448763168266708, 0.08127714837751082, 0.008506262055297774, 0.04628566491808142, 0.045373258030702995, 0.03240823497875564, 0.07345032682942768, 0.026816720097896554, 0.06340694095518801, 0.02756707257621231, 0.02690959868261651, 0.04845013526538688, 0.0069022769551543945, 0.026607388487806725, 0.025800140574574474, 0.05458521634160031, 0.03779330831621924, 0.030271378270680868, 0.02473572843648013, 0.025127894590578737, 0.1409118225978267, 64.67056458996188, 130.23341348094326, 96.21032745607438, 101.55907538629349, 71.46820468287315, 82.92080386992424, 47.34847968624484, 42.339652199899, 49.51312203561106, 141.2129669804727, 127.42273715234573, 82.16442185063516, 121.75058195667883, 77.9893647470782, 30.32726214778039, 0.3760204374069168, 0.021805987963753364, 0.09483407011195537, 0.15316149189827905, 0.3869283037079919, 0.5616639806858955, 0.490020081521042, 21.638600326353504, 15.254243708425953, 1.1586834706606404, 50.8857633221534, 109.68978789544876, 111.69879451874765, 109.95810939419655, 103.47384314383231, 108.02146265583654, 110.40210600822203, 103.07508714737432, 97.67559943660613, 103.62216364952826, 101.27226383455339, 96.57232299927743, 96.62653799979918, 83.45982382374426, 76.50228438838836, 74.0169059076617, 76.76766410950692, 75.00031471252441, 73.85932860835906, 72.09939249100225, 78.52174805056664, 87.13066024165, 96.01494635305097, 94.15156164476949, 97.81794225015949, 95.68982893420805, 79.74681408174577, 72.08107502229753, 69.98130475321125, 71.62430717099097, 76.32054528882428, 79.23022224057105, 80.54152550235872, 77.79172435883554, 82.07403475238432, 80.35082770932107, 82.54034965269028, 85.23702621459962, 81.17189745749198, 79.40440685518327, 81.12547228413244, 93.88434625441029, 83.27911238516532, 45.21099582795174, 58.269958573002974, 83.79579051848381, 94.59503266119188, 92.60929353775518, 85.13997893179618, 74.08395490338727, 73.88078397320163, 74.06469606584119, 86.56066140820904, 94.19887327378797, 93.55253727205339, 89.95988938116258, 92.13043489763814, 94.65174228914323, 95.55425613157212, 95.21426508503576, 91.84613366280833, 93.23937523749568, 94.72629085663827, 76.62118711779195, 71.29161173297514, 70.06492184054467, 74.37080567882907, 73.64366100680444, 72.85242480616417, 77.77696055750694, 78.49837856907999, 80.5362852158085, 82.10047937208607, 84.86192995502104, 86.49341629397485, 81.59238338470459, 85.50519081854051, 80.91215810468121, 93.41124565370622, 91.57538813929405, 106.70167922973634, 30.029283608159712, 1.1224845292106753, 0.44519217084011725, 0.10566122138932829, 0.19443475461054235, 0.07515057470769652, 0.0894133315511769, 0.08751246056729749, 0.472484237003711, 10.851949972491111, 52.46658440559141, 86.01405559047576, 108.31469904991889, 65.78118370425317, 70.93716282998362, 70.09440237475981, 35.99406134697699, 30.314496794054588, 36.286646627610736, 64.37381375220515, 74.01845916624993, 67.92393530568769, 77.38419794267224, 5.965595552998205, 0.1832650241351897, 0.02398514038612766, 0.0902398101865284, 0.07643656820178994, 0.040975832906101024, 0.06092688451791483, 0.06502800981604284, 0.009350783018875987, 0.03884823054015156, 0.04632661231763421, 0.06333802751595936, 0.038081399510584535, 0.036053863549304586, 0.018278984277839624, 0.02447021959890281, 0.027207036149658026, 0.05896229800137301, 0.08021418606081317, 0.046101704224823944, 0.0345077027656859, 0.04077677645029561, 0.11062309626610049, 0.042652584867732185, 0.011274078353908996, 0.013653486159690207, 0.06870110263867725, 0.08239670160917506, 0.02262659836560488, 0.033387195754555926, 0.009634688500344995, 0.04577213319979849, 0.06253918167203665, 0.08470403586303996, 0.07210630983594926, 0.02358365285721037, 0.06486638824665739, 0.0298467357342522, 0.047658379565203385, 0.06586561970893415, 0.02659641427829141, 0.07481390970849222, 0.02322051952022218, 0.022975308182198676, 0.019836711073895136, 0.011726675438694658, 0.1868028334912754, 78.31865556778448, 150.90621056095247, 112.94627297309138, 111.18430506798529, 102.27883815765382, 109.13318787851642, 80.23397245714742, 68.06580743482037, 60.96585066087785, 147.47270891743324, 106.06709464903801, 94.02300204000166, 131.21239785225163, 86.24331028230729, 37.68381057247039, 0.17097061529995936, 0.10599089966666315, 0.13029617287458914, 0.36578501244225814, 0.4039541481723709, 0.654151875886225, 0.7073101653687416, 11.80482606733999, 10.252584353570017, 0.28106261345167316, 67.02873276126, 113.11171854695966, 114.98092405257688, 116.40521510954827, 109.43124094317037, 113.61536656656574, 113.13653930541008, 107.25191716224917, 99.76670911235195, 107.41191064157795, 105.87103105360463, 101.94764890978414, 101.80693780222248, 90.09169670843309, 80.66413879394531, 78.60274499462497, 81.23918179542788, 78.23708595768099, 78.09553546290245, 76.73186855931436, 82.08191087169033, 91.5834289981473, 100.14024426860195, 98.99846584566178, 99.93606921165221, 99.69214485537623, 82.73540127661921, 75.20886713458647, 71.7598250604445, 75.92557045721239, 81.10457389585434, 84.27341753436674, 83.94010236186367, 82.04111037715789, 85.5878508475519, 84.98849699574133, 85.05651089452928, 86.23734827964537, 87.3838649257537, 85.52024487526187, 85.84546427572928, 97.413051666752, 90.75131385557114, 54.75207105759652, 63.88352532540599, 85.17317787293466, 97.55091513356855, 94.11547583918419, 91.54819826925956, 81.08284396509971, 78.02539563948109, 78.55242098531416, 89.6201572110576, 98.5335002406951, 95.82870437252907, 93.59507929894232, 96.64236084107431, 99.02989972022273, 97.73450559185397, 97.85050576733005, 96.81242696700558, 97.86490086586245, 96.85184678723736, 83.11006607547884, 75.24467052951937, 72.9903196519421, 78.41848773341026, 78.26918663517122, 77.2957798742479, 82.54860231953283, 82.00609145625945, 84.39482273594027, 86.32349137336978, 88.00119107769382, 90.37466433740433, 86.17870100082891, 88.99108748282157, 83.25801003363826, 97.94305016917568, 93.38685635597476, 112.95576510890838, 47.85666981051045, 0.9646574239577017, 0.19816483671386398, 0.32551247506372394, 0.3192664069994804, 0.12448476777682382, 0.19594906528870906, 0.09452957314469161, 0.7803716642722007, 11.100970468213482, 58.419820570176654, 89.54690302571943, 115.94631348886799, 74.86935461721113, 54.06678592005084, 22.1247467302507, 26.97882494618816, 44.24237043626847, 55.44944886238345, 81.67252525206536, 87.58589836858934, 72.92793043198125, 95.27209651085639, 11.43081924607677, 0.3453640808020869, 0.13583486599306907, 0.043159574195141756, 0.04525979274823781, 0.010675210186520652, 0.050114480433084314, 0.05140688225266434, 0.07441899904440488, 0.024277165441984133, 0.042355928810373436, 0.06200384326098908, 0.01090748612994268, 0.07075251756055702, 0.029669583647421775, 0.04740668520812066, 0.08701716174161242, 0.013576882155311686, 0.05978489257094841, 0.07718105244660571, 0.08068439550697803, 0.03774081214120792, 0.06429542291669116, 0.0406205328181386, 0.06019207213314311, 0.040645936293707746, 0.12668032214165698, 0.18848021364500447, 0.10116373369049642, 0.12720624916255474, 0.07503545467531489, 0.12101278835607153, 0.1443690548260366, 0.14422406502548726, 0.26057454186581797, 0.07101298745481238, 0.20336266667131456, 0.1523256286858551, 0.22585451783191776, 0.1716969126174527, 0.10754985028817769, 0.1359811428213312, 0.2149577904492617, 0.1485288816113626, 0.1400443046323715, 0.2223360138915239, 0.8819207248668518, 102.21706082743984, 166.5779935159991, 121.31184131868424, 127.61956953233289, 102.80181561746906, 108.39712373671993, 63.15282698600524, 58.836854811637636, 58.375270289759484, 153.55519110156646, 178.69979612288938, 104.51493432444911, 150.38833218236124, 98.43224817706694, 57.252609499039195, 0.624861699198523, 0.2536424727088982, 0.4117257424419926, 0.43849303837745424, 0.908067673444748, 0.6018595109062811, 1.372089458088721, 37.541895297265825, 21.48018756220418, 1.1863000210254424, 65.22508182833272, 113.60521547255979, 115.44692516326906, 119.01610159104871, 111.7555747493621, 115.37548311295049, 120.37299063897903, 110.40873481381325, 107.4596929550171, 113.68594569544639, 110.79197391386955, 107.09571269250686, 106.20549155819802, 93.7893464488368, 86.2411137550108, 84.12420272827148, 86.88941878657188, 84.58633638197377, 83.70206156084615, 81.29335757224791, 86.40759483460458, 97.51377028803672, 104.58048497476886, 103.87530557570919, 105.20982142417662, 105.57792802010815, 87.99729224174254, 82.90939761746316, 76.72072118328464, 79.19601132792812, 85.01172527190178, 88.8747029150686, 88.21708617671844, 87.92596786252915, 91.4332728232107, 88.26107948057114, 90.15754545888593, 91.72170823620212, 89.43266007208055, 89.36798018793907, 89.32934484174176, 105.09830844017768, 91.78518787507089, 62.60218504936465, 70.53426481062367, 88.48789445815548, 103.37501510497063, 99.89031084122198, 95.03060402408724, 82.11194053772958, 84.448331709831, 82.25731142105596, 94.59765280446699, 103.39620374864148, 95.31905512655936, 95.67963861650037, 100.24708963209584, 101.16919963590561, 100.78691759417134, 101.89089221339073, 98.68373486303516, 101.8738377478815, 102.74195240389918, 85.31120607929846, 80.59778013537007, 75.57758562026486, 81.99573639900454, 82.62005221459174, 81.89915195588144, 88.99049128255537, 85.43585900337466, 90.89957160334434, 91.17755782219672, 93.19356979862337, 93.3093346318891, 89.5140100294544, 95.21661066239881, 88.58724024987991, 105.14520429795789, 102.59718556557934, 120.83537532437234, 43.537049831882605, 2.5278697619515085, 2.852306159273271, 0.2512925592882018, 0.4509714155668213, 0.4159154160128486, 0.2868780175284032, 0.23361800689130063, 0.906904997123826, 18.730458982529182, 76.52242968159338, 100.7282389363935, 127.01634037879207, 82.97773315060525, 101.62029573994299, 93.00320932942053, 47.01451340029317, 41.32386030689363, 49.83414842236427, 86.64540029341175, 98.576701225773, 82.06380521097492, 113.57321677669403, 17.855184039761944, 0.5688344410830929, 0.2235702428245737, 0.17495583532558334, 0.3087885918155793, 0.14836838619122583, 0.1528067625458202, 0.1304094926003487, 0.31854603920252095, 0.14902670086631853, 0.14687563322724836, 0.1398876549736146, 0.11342772117425358, 0.15216456636065437, 0.11176316533237697, 0.08781971545108865, 0.1678197569544277, 0.19286128662286267, 0.2681795886207012, 0.13114826182924932, 0.22167524773507352, 0.08345820835881657, 0.15765133403962658, 0.1237501354227143, 0.15877823405448468, 0.10699713317256783], [0.06917419257543742, 0.015024489557911313, 0.044968568254262216, 0.05967817652309614, 0.06139527067481991, 0.03512800032753618, 0.028618758078664545, 0.09451962932343445, 0.0136160618069792, 0.02501545586593209, 0.10207390743157557, 0.06781598763360132, 0.03362054996673138, 0.007646536161642402, 0.06098538682225251, 0.03005532232383567, 0.0222404689843496, 0.04039087881063742, 0.09557116926918108, 0.1811665714147591, 45.03165721893311, 135.77118042976628, 94.39667840157786, 108.72472009351178, 87.27854928662701, 72.58848851726901, 30.59330474945807, 37.41576363963466, 47.10844239880962, 38.625167646715724, 48.91956544691517, 72.30194368670064, 114.46984706386444, 72.1685831008419, 26.63051063014615, 0.7783993249458652, 0.09688412905820916, 0.0993526328895842, 0.15612418372784892, 0.22587961487231717, 0.5354048768358847, 0.12148128942616525, 4.270938461826694, 1.627158371190871, 0.36152249923156154, 56.43656822942919, 112.23095032476611, 107.91704916184949, 104.86539025460522, 107.08454962699645, 107.65812566203456, 102.32859734565982, 103.33767414093019, 97.05788889238912, 93.99557682775682, 93.59499300679853, 96.25446196525328, 101.7640035383163, 97.81744803151777, 97.05399005643784, 85.37219893547797, 76.12299903746575, 75.46419774332355, 73.68208454501244, 73.71425582516578, 71.684264521445, 70.55113100236463, 80.43898690131404, 96.67038225358533, 91.55896125301238, 94.84570349416425, 87.23884705574282, 75.6900635073262, 68.47256506642988, 70.1576074477165, 69.42336328567998, 76.59490723763743, 75.53242345010081, 77.52173977513468, 74.99250135114117, 74.29223275953724, 76.85279523172687, 79.21142624270531, 76.41376433833953, 84.55321588823873, 84.8982197238553, 92.69128676383727, 83.27741792125087, 96.0493298499815, 59.968070291703754, 64.56396633578886, 90.10444441149312, 87.65971737523233, 89.25120338316887, 83.82924049131333, 80.377162502658, 71.4611130376016, 76.17037342440698, 81.24234322578677, 91.6692739917386, 94.11985320429649, 93.69087926803097, 93.26009319674586, 95.78289893365677, 91.32447411937099, 96.29204611624442, 92.54961859795355, 94.37548191316667, 92.95588201092136, 86.48930565003427, 75.83798393126457, 71.66646480560303, 71.39958673907866, 75.26843224802326, 67.52387708233249, 73.58349184836112, 78.97457784222019, 83.60716373689714, 83.92578571073471, 86.77818821322533, 85.33502271098476, 86.88140146193966, 79.97069512644123, 81.94328646506034, 81.81333049651116, 93.50852827872001, 88.99762999626898, 110.93889021104383, 24.15338089389186, 1.4511303651717402, 0.48228250155525826, 0.27327297015055535, 0.16190790240803074, 0.09480908032386534, 0.10482528156811192, 0.0466329938611917, 0.07752930835610436, 5.824252943838797, 29.648780361298595, 70.6490804303077, 105.47020404569565, 83.69472672862392, 82.09937326369747, 82.7596023005824, 53.95937181288197, 23.882894246808945, 25.588925230887632, 61.863606668287716, 69.19599133153116, 75.52047591055594, 54.37193455234651, 1.5566179757156682, 0.17833543220354667, 0.026255028262253732, 0.08199283537725288, 0.033806927667389956, 0.08446463338670232, 0.03523328762140966, 0.014190937058188984, 0.01388095585899728, 0.047436838428820335, 0.0034328409463107107, 0.03993643545395425, 0.006218247581273318, 0.0340914488920281, 0.02170590623732536, 0.014929455393294414, 0.07728565409178696, 0.009439923094525453, 0.01648228784512368, 0.08618872192117476, 0.06938213182072486, 0.010788250290187857, 0.029326200057121537, 0.03336347001154096, 0.019432841011533336, 0.06633679442588361, 0.022664828068246285, 0.035084333315852194, 0.03716033966010136, 0.05320697820054428, 0.07111748950856348, 0.062431875736482685, 0.031434678953261144, 0.023825060568689823, 0.05838372158787905, 0.01579482352451211, 0.043691668223830006, 0.06550043325630889, 0.02948162589041937, 0.013074980609329238, 0.03824756781180059, 0.030138630555161548, 0.05200418185502772, 0.10795286616250392, 0.131995064777232, 55.12798709254111, 153.28818751919655, 103.73355896242204, 124.17539904194494, 108.67114051695793, 94.56927053390011, 59.706550182834754, 57.5563931465149, 26.05938607646573, 24.23932198555239, 57.19164409945088, 84.10034687288346, 132.44836807250977, 81.07311648707237, 31.080639631517474, 0.10392411702102232, 0.11690854891053132, 0.021395324616723006, 0.3001369157385442, 0.4070003589074458, 1.4791025029074762, 0.8180630675727322, 3.6215667907268774, 1.6117889313928544, 1.5237324564687669, 70.77928743054791, 116.00901649844263, 108.15695701106903, 104.72140789031984, 106.22143991531865, 111.68680775550105, 103.12858043178436, 106.6067421820856, 100.83602566872874, 101.33904610910724, 99.71454943380049, 101.50344833250969, 105.72299295856108, 102.4021496311311, 99.85724526066934, 87.32582169194376, 77.7559680323447, 79.59532430095058, 77.57604106780022, 79.43215370178223, 75.09343962515555, 73.58525691493865, 82.7649445687571, 100.73991975476666, 96.63322956331315, 99.778774323002, 91.47437141787623, 78.09140912948116, 71.06097636684295, 73.83373906535488, 74.33551219201858, 80.92330548071092, 81.24866608650454, 82.27319702025383, 76.59018470394996, 76.57593081074377, 80.80727392627348, 82.37490407882198, 80.44436839319046, 88.22431118257585, 86.58211677305161, 95.75757611182429, 88.0168648689024, 100.09705112826441, 66.18971424718058, 68.04457172270745, 90.74553228193714, 89.86345398810603, 93.43698424677696, 88.7870850101594, 85.46985026328795, 74.91583470375308, 80.58456174788937, 84.40265963154455, 95.43586331029093, 96.64085465092813, 98.31657748068534, 96.93168270972468, 98.37183583167293, 96.06496441748835, 99.53672485966837, 95.40173084505143, 98.45893598371937, 97.95407987410023, 89.56169036126907, 80.15430127420734, 74.86581663931571, 72.8467373694143, 78.49906890623032, 72.03589716265279, 79.36122155958607, 81.92147808690225, 88.33497693461757, 87.70515411130845, 91.49702702799152, 87.45438914145194, 91.48271822160291, 82.66368466038858, 85.5503059202625, 83.50027130496117, 97.85118825974004, 91.9466483208441, 116.1359130182574, 37.016713465413744, 0.5850981812803977, 0.2607891997022014, 0.9657131544043942, 0.9932073145624131, 0.37657925258240393, 0.044849920386989275, 0.09882223191520861, 0.10465110381764751, 4.917666210282234, 34.51582201065556, 74.23136541920324, 111.10407690848075, 90.99446942729335, 62.76466531138267, 34.04819311634187, 32.408593354686616, 33.48147338436496, 48.060711506874334, 75.40708018887427, 80.10071385291316, 82.22500678031676, 74.63289845374324, 3.4335680786640417, 0.36666763766158017, 0.08057273053113492, 0.07188081951631654, 0.020480150236718116, 0.0411124378743191, 0.07213169798975991, 0.0715462765806625, 0.03271817117028179, 0.05618303443395323, 0.061570363900353836, 0.06706238694248662, 0.010593228244913683, 0.04455125334882929, 0.04787681421505348, 0.07774808008464114, 0.03273647301079285, 0.059208618251666914, 0.03178711770282638, 0.04723408942921989, 0.07073195576066933, 0.058305588280481685, 0.005843820671866378, 0.005083921301599232, 0.02497957039233898, 0.2437063889397729, 0.1014932893937634, 0.1571316353135532, 0.18353186788097506, 0.14732544941286888, 0.12420818705352084, 0.06945703223708176, 0.18099787885383253, 0.10852597653865816, 0.13072332817940943, 0.15063286548660648, 0.15112034255458465, 0.15387943885739774, 0.1573107313484915, 0.19529635837722212, 0.15361012830849619, 0.18405579541239048, 0.2490620176878668, 0.1866283493056413, 0.33988468288894624, 77.15512367986864, 175.41666246229605, 117.73867976280951, 138.66203000468593, 114.97112597188642, 96.98458763860889, 43.1888061185037, 51.54973822255289, 66.06462201764508, 52.515241407579, 76.30342022065194, 94.73396301269533, 143.4637014327511, 92.36913465684461, 47.040032340634255, 3.158871992941826, 0.22139735700142002, 0.361076973138317, 0.3898115522198139, 1.5365534588213892, 3.8808371751539172, 0.44406464263316126, 13.37527052048714, 9.2781989612887, 1.1435182392597198, 69.42328483827653, 117.55701911064887, 109.00839374911402, 107.53615563915623, 107.56474971771242, 116.03899125129946, 111.8122608430924, 114.36406074031707, 105.76655480169482, 105.96077488314722, 103.06343770796254, 105.46194353411275, 110.40306306654408, 105.80227974922427, 106.07653971641295, 92.93789402131112, 83.2602144056751, 84.4297004515125, 82.64796380073794, 82.82546674051594, 79.55225667645855, 77.34551552803286, 86.17229969270768, 104.09014947952764, 101.57972274288055, 103.43712975901943, 96.42097442380845, 82.2842659488801, 75.5290109880509, 76.40485271330803, 78.07919486876457, 84.78907585144043, 84.6703927747665, 87.59229967671057, 81.40488624572754, 81.36114397356587, 86.15425678991502, 87.56288974515854, 85.49880519989999, 93.20296779755624, 92.91186517284763, 101.7850431319206, 93.66447387203094, 103.68800455524077, 72.9098012370448, 75.22266603285267, 94.1193432961741, 96.96711740186139, 96.03301279006466, 93.36774656849524, 89.32375154187604, 80.26080146912606, 83.11309414525186, 89.26132309821345, 97.99649638514366, 100.64321764053838, 100.34066953966695, 100.20710499055924, 104.84338575793852, 101.77062449916717, 105.3956711676813, 100.36680036975493, 102.4740937448317, 101.06158548785795, 95.63941863275345, 82.1732158045615, 80.8670900714013, 79.1483937540362, 84.54344918650966, 75.63521308283653, 83.08751244698801, 90.91202120627128, 94.95523175885602, 92.52304061766594, 99.29910767462947, 93.84503626054334, 95.14211700808619, 88.33026224567045, 90.07205347861014, 89.20866920102029, 101.90172579980667, 97.65332821876773, 120.57436512362574, 33.49107142417662, 2.8513706739871734, 2.4829544559601815, 0.4736578530601917, 0.6403469102036569, 0.4601385768863463, 0.2047448425043014, 0.1929736870431131, 0.4945212157983934, 13.754081264618906, 48.065273223384736, 85.6816739420737, 123.9649481927195, 106.85282384195636, 121.15708028116535, 111.65637800770422, 65.7609756531254, 34.16284399647867, 40.83506238075995, 81.44961695517264, 93.16110041833694, 93.85935291167229, 92.29883793861636, 5.869956891382895, 0.5362171138967238, 0.18874247618500264, 0.1370850448767024, 0.10858245254043611, 0.22813096342067565, 0.16711985902680507, 0.2233353602669893, 0.17571590179877897, 0.14611958105477596, 0.14660557191218102, 0.27583084579917694, 0.09678923374702854, 0.09353504546226994, 0.15536382614124208, 0.2078137754072105, 0.12785849642128716, 0.17137828132798597, 0.13125628022657287, 0.2180336334652478, 0.3487331516319706, 0.09972164212095161, 0.1415565009078672, 0.16667565060479028, 0.10778624203897293], [0.016026412861632006, 0.05882396167444606, 0.018357060128642667, 0.020451634528956587, 0.09633910346535907, 0.0035406580061516577, 0.02944865921181777, 0.03595073662337757, 0.012291171156140345, 0.03877970014488505, 0.062405219707157344, 0.040372852761779106, 0.01822767553911094, 0.007449798079417839, 0.02279897197900761, 0.06042115157470108, 0.08004701801485593, 0.0681805152506117, 0.5136762024654496, 13.729443876974045, 118.9287974757533, 92.50261291380852, 102.27416269240841, 59.95135707239951, 56.884032218687004, 41.997197904894435, 44.679349930055686, 48.28923663785381, 112.81901559522076, 105.8080848570793, 83.01346594287504, 123.14588669807681, 73.82455287441131, 22.93354534333752, 1.0389449086881455, 0.1503446478877337, 0.2763696201145649, 0.038309253211463654, 0.5286460201586447, 0.2920528801698839, 0.4111507168460277, 1.0520962481537173, 1.8608145752260763, 0.4995847811862346, 66.10989401417395, 118.0988710157333, 111.46478591426727, 113.76941373271328, 108.64264842002623, 99.17295640514743, 99.38760419045725, 99.89693180207284, 96.80597074570196, 98.58034903003325, 102.94743753248646, 100.06105161482289, 98.61762723615094, 96.34733584619339, 100.7956252559539, 93.04376663700228, 89.11334776109265, 71.78630890384798, 74.87536368831512, 77.50903129577637, 73.6546044195852, 72.21693023558586, 73.98470324854698, 83.43071983706567, 92.78659251428421, 93.00142072862195, 92.73564092574581, 78.27894549215995, 69.39367094347554, 68.98779976752498, 69.87205105443155, 73.36832631018855, 77.98266533882388, 81.17466665083363, 78.64140387504332, 73.74656046590498, 75.29497100460914, 72.36400342756703, 77.3670885639806, 76.12860018207182, 76.7596467848747, 72.00804833442935, 80.59909805174797, 83.8367400630828, 101.844098337235, 64.2767390128105, 66.22106182959773, 90.13456821441652, 84.47736509384649, 95.60801613715388, 85.89718464882144, 79.31230175879695, 70.20131049617645, 73.08672366603729, 77.67402187470468, 85.25262155840474, 88.23425046859249, 94.6886831714261, 89.80696401288434, 83.64596382264169, 86.15434308205882, 89.16793930915095, 90.42658867374544, 93.30563191444644, 90.74029984012728, 85.69519042968751, 82.14139753772368, 76.05260033761301, 73.16315497121504, 71.45813988101098, 66.4506773794851, 67.8061386846727, 72.96369460321242, 81.47066439351728, 83.17891936148368, 87.7486296622984, 87.28832383309641, 82.29829234461631, 84.21367199190202, 79.94022615494268, 79.7640254420619, 81.51912919936642, 92.80905985063123, 88.44222237986904, 106.71914946648383, 12.354548208175167, 1.6697089782645627, 3.8078114678782806, 0.14249957046441494, 0.22475156572557267, 0.022604990855700547, 0.14954495934709428, 0.05874896166665901, 0.2417522058972428, 1.7553544212733547, 18.15507277365654, 55.386914514726215, 94.12883543199109, 73.75230281583725, 88.18158088191863, 94.65941444520028, 38.48538221851472, 23.17949168143734, 36.735310862141276, 62.220350157830026, 71.53949768312516, 81.56871580308484, 32.122311322919785, 0.8876236059492635, 0.05146808884737473, 0.0158369516570782, 0.04748716657500594, 0.09174934813692685, 0.019495416988408374, 0.06820440187209076, 0.07766253870701598, 0.041401172582540786, 0.07024708339163373, 0.030729313073078954, 0.021697224545923453, 0.07076333472204786, 0.01773974264881784, 0.06865292336911925, 0.060799173830497655, 0.1030030495096599, 0.04778183080376156, 0.006931528586128186, 0.0545805432052622, 0.03484615274975377, 0.05447253246881789, 0.002696460235916499, 0.09546939448844041, 0.08893378349321504, 0.02761067255520292, 0.04136656456056141, 0.10461217122933558, 0.10154390482292061, 0.04222383993046899, 0.12147665459422335, 0.04081474759826257, 0.036814661636467905, 0.046458279849180294, 0.059104533715834545, 0.026944788931418332, 0.07338081967205771, 0.06284357904787026, 0.06254730603447364, 0.046821754095294786, 0.21379512945009818, 0.1288100848755529, 0.6219502586510874, 17.55173771612106, 136.51318304000364, 106.31312139572637, 119.36913844077819, 74.85050370616298, 84.01102665931948, 75.82196497148084, 54.668673622992735, 23.61120931563839, 46.14925815213112, 96.52278346400108, 97.17855668837025, 133.8808019699589, 85.41288960364558, 27.141615075449792, 0.3342832931347432, 0.34758837112495977, 0.15913037402975946, 0.17120082472120562, 0.67845806839966, 1.4062436189382308, 1.610233711619531, 0.7591018152813759, 0.907896192323777, 1.4569366987674468, 80.58649155401415, 122.48827780446699, 113.6469259569722, 117.25514565744709, 112.8291117760443, 102.60919586304696, 103.98400229792442, 106.8658539556688, 103.09808008132443, 103.63206371184319, 106.92477580039733, 107.39525625782629, 101.50428771972658, 100.42882873165993, 102.78171739270611, 98.70983431416174, 95.54986307697912, 76.41759257162772, 78.4255087760187, 79.20775490422403, 76.8759136815225, 75.43462307222428, 76.04708548515075, 88.75547855131089, 94.42581376721783, 95.69834832222232, 95.78519744257774, 81.50363583718577, 72.64246817558043, 72.41016972449519, 73.21901736720916, 75.09340824619417, 82.51385011980611, 85.73513584752237, 84.35072745046308, 77.30760189794725, 79.66648394061674, 75.24740834389964, 80.06035266384002, 79.99291143109723, 79.53498255821967, 76.04147649580433, 86.00206882722917, 89.4265490193521, 103.09857429996615, 69.97376595774006, 70.92106542279645, 91.33310333375009, 88.20822162012901, 98.54026240687217, 88.52867141846689, 83.53341533291726, 73.53610177193919, 75.8571643214072, 79.70657840851815, 88.02258368461364, 92.37552812022548, 98.64130266251104, 92.31710833887901, 86.95158050906274, 88.82831696541079, 93.24946357357888, 94.00706937236171, 94.55649145187871, 91.76096331688666, 91.34679240565147, 87.1841613708004, 81.81529952633767, 78.27043394888602, 74.06651604560115, 68.77977294306602, 71.99971722018334, 77.14874590596845, 83.1009897109001, 86.35369362369661, 90.11858063359415, 91.58520975420552, 86.84464885342507, 88.11792081402194, 84.0843749815418, 83.89113549263247, 85.956357525241, 97.75167772846838, 91.01972949120307, 114.8112109399611, 21.95565531330724, 1.8743945562070417, 5.8066003168782885, 0.10572787869961993, 0.676188241810568, 0.02154015353880823, 0.3850327263916693, 0.04374728237669315, 0.2602968503150248, 2.4516968429088593, 19.302909297327844, 60.41206690572924, 100.34942426989156, 87.38213908287787, 82.68217471338089, 50.08390142071632, 34.95163656050159, 40.21826574879308, 51.1324490270307, 73.74261456151163, 80.81919008685698, 92.6072931289673, 50.63142899544009, 0.897893290365896, 0.00693124465479125, 0.021212919081951824, 0.03447442773669478, 0.08236194420005045, 0.07890419103205204, 0.011286865318975142, 0.08694871944645721, 0.007961966161195549, 0.020015711347842892, 0.032327025828342286, 0.04978330828429711, 0.024814679542736664, 0.02675475699136094, 0.06722917194448172, 0.03225098394097821, 0.17502656056275293, 0.09116051763656641, 0.013319041857856416, 0.017670294863262007, 0.019715588742626772, 0.06157263918148895, 0.0470405679586674, 0.05083174557395039, 0.1570607415370403, 0.13206836406982717, 0.11796048722199856, 0.20272269214112915, 0.1754638588716907, 0.0896269015427078, 0.24446856981563955, 0.14845473962205072, 0.2747439202522078, 0.18762403378082862, 0.23275634183758692, 0.18729360473732795, 0.22549172923449548, 0.10986957984465746, 0.17934901249264518, 0.11337485344659899, 0.3471573700587596, 0.28709261407775266, 0.7682302125519322, 27.645418028677664, 160.85796971474926, 114.20593430919033, 136.91222929185437, 85.37959652562296, 82.1290812953826, 59.52046901948991, 58.964112189508256, 68.9437593952302, 158.0010094181184, 158.833885500508, 109.45677557299214, 149.27593231201172, 98.87170268643288, 40.984026155164166, 1.9824701956202908, 0.488739213155162, 0.5369310465551193, 0.27551604494933163, 1.4824105318515532, 2.790426111990406, 2.3892215759523454, 4.1159018778031875, 4.651632433937443, 1.0275125479505909, 79.55778721840151, 129.32551030189762, 122.15078138536023, 122.52139045346169, 114.73223009417134, 105.43061948591664, 110.97981622142177, 110.82558078150596, 109.91070362829394, 108.51923496492448, 111.95159912109376, 109.32682744918331, 106.84799148190407, 105.24401664733888, 109.16663000660559, 102.36374178240376, 98.42961234431114, 80.57624632312407, 81.58293831732966, 84.81264145143571, 79.90836081966278, 79.79487880583733, 81.88415281234249, 93.35135106117495, 103.43152861441337, 104.05775070190431, 99.96228633388397, 88.52524326693627, 77.53200069550546, 76.89233272306382, 76.04568127662905, 80.93819479788505, 85.70344309653007, 87.79925961648264, 88.74936749858242, 81.94356887571274, 83.16194334337789, 79.56451800561722, 83.57902465328094, 85.20069722206362, 84.02443332056846, 79.93751971952378, 89.68138540944746, 97.72207167840774, 107.51400209242298, 75.90307958664434, 74.35624584074944, 92.91396756325999, 92.99152066630703, 102.3981095898536, 95.1330327987671, 87.54421926313832, 78.46191621595814, 80.5516295279226, 87.46526979630994, 91.61360771425309, 96.10438423772013, 103.31862711137342, 100.36177189119401, 93.11804063858526, 94.75502614052066, 96.68742887435421, 98.07994873292985, 98.93836728988155, 96.5550567257789, 94.85550941959505, 91.11410956228934, 81.76504611968994, 81.60931233436831, 77.62598068483415, 74.59064668224704, 77.60752985554358, 81.85773172686177, 88.56973863417103, 92.09762034877654, 96.57146007783952, 97.22688813363352, 91.55581551213419, 91.83813202765681, 87.80467248732045, 89.74375109518729, 89.95498641844719, 103.71215066602154, 99.05937240969752, 121.67758664777203, 19.033628779072917, 4.335853197882253, 9.176756662707175, 0.4473057461361732, 1.2759260568887958, 0.17119229050172916, 0.6128832097015073, 0.2261968672035202, 0.9034194196424178, 7.314399615410836, 35.85361696058704, 74.5399461253997, 108.23825205526045, 94.19477831932807, 121.32742881774904, 129.1788842601161, 50.247558393786036, 38.02732782979166, 52.78180568448959, 84.38553456337222, 93.52305673783826, 104.58486233988117, 69.55749265609249, 2.0653487741947174, 0.15057784505188465, 0.2210984907803997, 0.1438658576338522, 0.2811211425690882, 0.14321402406259892, 0.3178410544510811, 0.17979792469451505, 0.07936810323547933, 0.18187190856664412, 0.11769500711271841, 0.16728102860431518, 0.16597244317733473, 0.05085868505580772, 0.22447110093649358, 0.20628066493138192, 0.2840297026259284, 0.16714020632207396, 0.07367500509586065, 0.11210736097587694, 0.11984577597749811, 0.15294458176339829, 0.08879908225348881, 0.17905837405593167], [0.024468063061395963, 0.0808528199371311, 0.05231462749502352, 0.07429625643717666, 0.051151077833867846, 0.05645894099988284, 0.0177509390238312, 0.10410560325028435, 0.10016556709043442, 0.008025564865449504, 0.09991757676846559, 0.058474786459438266, 0.026124360475448832, 0.05944331311770986, 0.051841660132331234, 0.02385780508179338, 0.05965118724552374, 0.21346037967070458, 0.9676563211025732, 80.03256659353934, 104.21049564115464, 110.28346215524982, 73.29940242152061, 72.75629535798105, 45.464898693946104, 30.322416059432495, 56.44684876165083, 90.29967646444999, 81.83734324670608, 88.29486677723547, 105.99712740990424, 80.15315594211702, 22.30843132542026, 1.500088286495978, 0.029614741328142347, 0.20930677351932372, 0.11193689875184529, 0.10791240905922268, 0.3906561794780916, 0.44459489805083124, 1.2571535932440914, 3.135826106994383, 1.4196349584287213, 58.44442952063776, 125.34359855036583, 102.44287167826008, 110.16867006978681, 102.49694547345563, 109.20891315706315, 103.16742758597098, 97.6611102011896, 102.94013407922561, 98.54269427637901, 104.06037868991976, 103.3109078868743, 101.78127765655519, 102.56588505160425, 97.48247761880198, 95.15727304643201, 99.80022184310421, 93.49666703131892, 81.0043965616534, 71.40582330765264, 72.79597405464419, 71.7270105115829, 72.79514251216766, 71.14594274951567, 83.2742251119306, 87.76996735603579, 86.52612886121197, 87.78008707108037, 72.83355036089498, 69.44151601483746, 68.71569710393106, 68.1662436454527, 71.73390603834584, 85.93534146585773, 88.2854687783026, 89.45943417087679, 79.78095439172561, 76.08151605052333, 75.66510938828992, 75.51052877979895, 75.32652255027526, 81.7809787873299, 73.68606967310753, 77.66594179214971, 82.26972964502151, 93.40026301722374, 68.01018038103658, 70.56958967639555, 89.88515253989928, 86.19848543597807, 89.96431381471696, 85.89846334149762, 79.05522177296301, 68.76724489273565, 69.26793544523179, 70.96917721533006, 83.78990696322533, 83.97976536904612, 87.8934435690603, 78.3457277667138, 74.2540837872413, 75.34382804747551, 84.94546859495102, 91.98235757889287, 91.72619542767926, 86.87419214556294, 92.83249993478098, 87.61727732996788, 86.25892131559311, 81.26887413763231, 77.13936359651628, 67.33346954468759, 66.04497094308176, 64.32318379802089, 74.71280497889366, 81.21880116001253, 83.99126575839135, 81.70431998468216, 84.31940340226697, 79.63406947351272, 82.72552474852532, 77.08654495977586, 81.48620482414, 84.20977315595074, 92.2239677367672, 87.2422359835717, 95.96399476451259, 1.0446269521790168, 3.9040571162777566, 4.829697253242617, 0.5729662903374242, 0.28962251219537954, 0.04172035162487338, 0.047424355026094184, 0.17006372041519613, 0.16839338827037043, 0.18923084191497297, 10.18667676756459, 50.46443016298356, 92.16867800681823, 81.66171519987046, 70.16955498726138, 66.11357319739558, 32.436210763069894, 26.78020004303225, 48.2580537949839, 66.18380715770107, 68.22435748192572, 75.07485543527912, 13.612105192676669, 0.5561040822536715, 0.08410290199061556, 0.19903869788733222, 0.016033985640763516, 0.154317288749641, 0.015854415588922078, 0.06274209921098044, 0.031057116350219138, 0.03958423036120592, 0.030438103900861838, 0.00663537240114003, 0.07331489014529413, 0.01045778677273061, 0.05450596837627311, 0.04648610033215054, 0.03736882282781505, 0.0417797923869183, 0.061755492877695835, 0.024774756785782597, 0.07649156565387404, 0.03334551291059583, 0.05153689120385436, 0.01366691855383256, 0.0406347245969359, 0.02542571510158239, 0.01310173718769464, 0.025951810661823522, 0.04005285400536753, 0.048335302515976855, 0.02296685057151462, 0.031227829468045986, 0.05476918852617664, 0.05020937957470456, 0.042832979421702125, 0.04681457585144428, 0.05831709492110437, 0.055474337986520225, 0.044874121104517294, 0.060127935252122344, 0.006686364649794997, 0.09410771916830733, 0.6634933068867653, 96.01323619965585, 121.42181673357565, 120.10448086646296, 86.06448942615141, 80.76902297235306, 63.6092379016261, 33.90879600278793, 23.703457578536003, 42.80572391325428, 86.55147521726548, 101.61193324673562, 111.25170707702638, 91.4372108828637, 28.662159135264737, 0.5334374404722645, 0.05977976744273498, 0.22531724504886136, 0.01811405129340147, 0.3135953951747187, 1.0516490979540734, 1.6672443814816016, 2.190678552273781, 0.767834359599698, 2.0502192118475517, 73.27556225561327, 128.99507414910101, 108.53917629488053, 114.94582668427499, 104.6969715241463, 112.07014883718183, 107.35187484372048, 102.33228437362179, 109.22750519167994, 103.60408152303388, 106.42104933338781, 108.18471170240834, 103.05849552154542, 103.82223590727776, 101.93111219713765, 97.92212824667655, 102.9823152480587, 97.03087945138255, 83.79535121302452, 76.38111452902518, 75.61548356086978, 75.16231644538142, 74.8096404537078, 75.21303269170946, 88.28873219028597, 89.98796570685603, 88.9504909515381, 89.82415968371977, 75.00084815486785, 71.3184093659924, 71.39040054813509, 72.46241569519043, 76.28286700094901, 90.48582430808776, 90.86722773890342, 92.20544630481352, 86.34299339786654, 80.59304975694226, 80.43023217108943, 81.09683898187454, 79.9806736361596, 86.34953591131395, 78.52911426175025, 81.27045877518194, 87.96358339248165, 97.0429446620326, 72.6072374466927, 75.3346497012723, 94.59021599062028, 91.29145560726043, 94.33233584127119, 88.07482181056854, 82.53548591367661, 72.25946441773446, 72.8859846053585, 74.98296999162244, 85.65374666644682, 87.77567048226634, 90.43381367960285, 81.24516733231084, 75.93382312405494, 76.70242724880096, 86.37546277815296, 92.62580671618062, 94.25270388203283, 91.34946746210899, 96.02763914292859, 90.60366799754482, 90.65146600046467, 84.3303389703074, 83.12118207254719, 70.32342956912133, 69.15639892701181, 68.24861341907133, 80.03449639966412, 83.70903553501253, 87.88204516133955, 84.04604558021792, 90.05131198513894, 81.86102651780652, 85.0998373954527, 79.46670193825999, 86.98699166697841, 85.57613080547702, 96.45298096441455, 90.4943907645441, 111.09664009463404, 3.792394837064128, 0.21640198876059827, 3.2704582762333656, 1.0344137131206452, 0.2778588031088152, 0.05977348169131626, 0.05349268303102544, 0.22507888445210075, 0.1862031705076656, 0.38749989723005607, 10.543614414430435, 56.57702830529983, 94.08765054518177, 94.05686778406944, 64.13008551443777, 36.14742209834438, 29.64247319006151, 40.95569487540953, 64.78557632815453, 78.66104710486628, 77.07220477442588, 93.44963781295284, 22.65115038041146, 0.8226431701933185, 0.06421419461407969, 0.19135097492366068, 0.060180213092075246, 0.16850122280659216, 0.0233264924627879, 0.06798477978595803, 0.018982279805406448, 0.008664619132515886, 0.02918559802515853, 0.023257755223781835, 0.03220243311877693, 0.03127582296128235, 0.002514266572336877, 0.012806238880711458, 0.019767703788895762, 0.0196961032962727, 0.06915539277777558, 0.04145855639850901, 0.09301733090392045, 0.0086280221547631, 0.06845403928309679, 0.04097899301878868, 0.12325324313414675, 0.14285984629344556, 0.1630856246957856, 0.1772030469991507, 0.10666999064626233, 0.12379883563206082, 0.11236642126835163, 0.1676802829869332, 0.20817149250257402, 0.15654007754018232, 0.15771652812198286, 0.1257233251066458, 0.10576202323840511, 0.18979662849057108, 0.15546266680523274, 0.2073425087597101, 0.14008014222546933, 0.29364615919128545, 1.8472136340795027, 120.04928527339813, 134.27545516721665, 138.1926478109052, 98.58944892883302, 97.92848248635569, 61.971985678518976, 42.60947596642279, 78.21213183864471, 140.08357540253672, 118.14979907005065, 98.50552589662614, 119.33475494384767, 106.63649728221279, 43.655768209888095, 1.676253330323004, 0.23678286932408812, 0.5340176448225975, 0.4601169732068816, 0.40748038960079996, 2.243033613889448, 2.25320628093135, 3.264936804771424, 8.34931698537642, 2.556825679156088, 72.98201207191714, 137.7478196544032, 113.08136724656629, 121.74061913644115, 110.85165669841152, 117.23943264253678, 111.21750400912379, 106.14057633184619, 112.02312746355611, 107.55957218908496, 111.38454206528203, 113.61138928321101, 109.16500614535425, 111.69370328226398, 105.27979650805074, 103.4822448607414, 110.54930471604871, 102.8835028986777, 87.57818698883058, 81.2372519893031, 80.7180949180357, 80.43244438786661, 80.49863830689462, 79.84707770809051, 90.77604832187777, 98.14781358165126, 95.69353949639105, 95.12478797666489, 79.16347918971893, 74.90604446780297, 74.63015279462262, 73.60398231014129, 79.47613131615424, 93.26509029634538, 96.8075083148095, 95.71910550517421, 88.17637981907015, 82.20283754410283, 85.89859670208347, 84.81166870363298, 82.50711933259042, 90.01340619979366, 84.38609938467704, 87.35515317609234, 92.47702337080433, 103.191510938829, 77.19985438931373, 77.43458470990582, 96.32761416896697, 96.49513075428625, 96.20754257325204, 90.70753235970774, 86.36878690411969, 74.16235523839151, 76.22119165235951, 78.896679570598, 92.40067051303004, 93.53447867978005, 96.68627569752356, 87.68497743914205, 79.36290033401983, 82.43967025510727, 93.35364957009593, 102.1925538586032, 100.13705930402203, 93.20190875760971, 100.04398930457332, 94.38095754192722, 94.50109189556491, 88.25262285047963, 87.96419528222854, 73.95668183603595, 73.6585424792382, 73.4657266063075, 84.8601491989628, 87.90633247744653, 93.04560230624293, 88.74132663972917, 95.01635013088104, 87.12936585949313, 92.47548580169679, 83.66511283382293, 90.95227256897958, 88.63830166478311, 101.52269932531543, 94.38356984046199, 118.03743885409449, 2.1487800392412373, 7.740277821017851, 14.9276985468403, 0.9852775691017028, 0.9249951522196493, 0.24943367758345222, 0.3631295678356002, 0.41015060438263806, 0.8024682140638753, 1.4212892180488956, 22.99041186609576, 72.31956297351469, 108.7632691475653, 98.33258075098838, 93.52388043557444, 89.55503802145682, 43.16318519653813, 40.31556798565773, 67.92602200661936, 91.88429832458498, 88.89840972039008, 106.31552973101216, 35.98889558546005, 1.321529616271296, 0.2729885370260285, 0.3113651293660364, 0.18696394178175157, 0.29998106281122855, 0.09763772974932387, 0.1273133712370069, 0.11868463183242468, 0.16138254995307616, 0.12299970633560613, 0.10733926037867224, 0.16737251482423277, 0.1006063357776692, 0.13610033078059075, 0.10243727825582029, 0.12644255143259803, 0.1381349377334118, 0.174608062051477, 0.1470799948419294, 0.12117018112011495, 0.08911671762865397, 0.24468273735575138, 0.09927391735536438], [0.0644206246661563, 0.0834834126515254, 0.050705919462826946, 0.008301428338933376, 0.05598970065494219, 0.03814945110089837, 0.04784936911516613, 0.00958172788452958, 0.08686366070422434, 0.03725830315341873, 0.09404899086803199, 0.023015133262942397, 0.013707078798043152, 0.03600478412643556, 0.05826325043134632, 0.10150625160144222, 0.1618899299853271, 0.4906657097801086, 8.904787359699126, 105.55014979454779, 104.7739205821868, 83.80518851741668, 58.12883169420304, 40.02029588145595, 35.81646034794469, 69.51040067980367, 101.12435125535535, 93.61928032290552, 97.15995680901312, 137.48034538761263, 102.81262566966396, 32.80353288496695, 1.899164814141489, 0.06416316932788299, 0.2322986196245878, 0.1355627055970892, 0.1337189464679649, 0.21359977702940666, 0.22922806261527925, 1.4579263617915492, 0.9171013822478633, 2.377955548224911, 28.891588372568933, 113.00171959784724, 107.66221277175411, 103.34252219046317, 94.78151782866448, 97.82614000381963, 104.9877917382025, 106.00661954572125, 100.42652237799861, 104.25458308189147, 99.37224418886247, 91.78856111341908, 91.716993547255, 92.8381089241274, 90.9456829870901, 92.69455017582064, 96.79716894703527, 90.40597269611975, 92.53160707412228, 79.85219247879522, 70.42470516697054, 72.67522781125962, 72.1910818161503, 68.90859926900556, 76.83625067434004, 83.51723947832662, 86.07025531030472, 84.61178471965175, 75.98135440580307, 68.9653951891007, 67.54905869883876, 70.01034598196708, 68.02444211898312, 68.71597166984313, 85.38832772162654, 90.57208507291733, 92.42463619478288, 90.58964160180862, 89.96452562270626, 82.21944485941242, 83.67356161917411, 86.28494231931626, 90.57372462364935, 78.76793953680223, 71.19547444005167, 83.62634412703976, 93.93672558569139, 65.37604993389499, 71.91909682366156, 89.54922506886145, 82.59328596053585, 92.03583517382222, 86.67122517862629, 83.6199192846975, 68.64601227544969, 67.67881070413898, 67.61698630548292, 69.5810817903088, 69.36106035786291, 70.76607688780754, 67.61692354756018, 67.77138648494598, 66.95904793277865, 74.14092340776998, 82.87040925795033, 88.17880384383663, 91.71725242368638, 91.70429291263704, 87.1970267449656, 87.33861646344586, 81.60331895274501, 78.32380956219089, 69.2418909072876, 68.68696182004868, 65.08591221224877, 66.51334116535803, 68.9548832370389, 79.53362541814005, 81.37314642629316, 81.02351419387325, 78.95940611439367, 80.96428640427129, 76.32141605500253, 81.21545930062571, 79.76124055923955, 90.05310058593751, 85.717053721028, 96.01905699699157, 50.86247621044036, 0.3692053192325177, 0.38305462608414315, 0.35827088500222853, 0.1006366728594707, 0.23076425276456342, 0.1312292066793288, 0.16816143216865678, 0.06932112823931441, 0.06759597484262721, 0.11106738895778695, 6.754996084397839, 38.78195654961371, 80.3384251748362, 70.58672258930822, 90.95264127177578, 73.2029042705413, 26.474684669125466, 21.542867037557787, 66.19908871189241, 66.98462178630214, 74.90011384410244, 57.841063084140906, 5.374616451801793, 0.3327871847056574, 0.17585821029159332, 0.036918941524720965, 0.05557287987622042, 0.02988898548327627, 0.02437502742865153, 0.0025085663993752775, 0.042898139030101805, 0.038506176112399954, 0.02377196492987775, 0.014177120662474585, 0.048977778323235056, 0.006721045928932126, 0.040856679420798056, 0.05577087530025071, 0.024393921072084098, 0.03561370007153, 0.09993674428833109, 0.03252648064986833, 0.02421864973110778, 0.01832843142291231, 0.15211585849042863, 0.05916141191377275, 0.07294072514219631, 0.039811038352068395, 0.04284265511218579, 0.07367717312468637, 0.02662094824406649, 0.04805474579634686, 0.051666149388878584, 0.04482815582906047, 0.041731720369669704, 0.07335275021051207, 0.014761663943288789, 0.04631815853738978, 0.04162936719254621, 0.0210333155137637, 0.07506819727319865, 0.24416348296067408, 0.5290760712758188, 12.243825581765945, 126.39460548277825, 112.74172921334545, 105.29195585558492, 82.97890201691659, 74.48784136003064, 55.59316450549711, 37.5836959961922, 52.49970882169662, 96.53523306692801, 106.05293489271595, 140.02260608057824, 114.01138474864345, 42.87478116250808, 1.38548901004176, 0.07706030166798061, 0.15542319795537382, 0.1542921457439661, 0.24903635374240338, 0.3203427911766114, 0.5440507000011783, 2.519933581352234, 0.6541483212382563, 1.8696504494836255, 42.35271761494298, 121.34645231308477, 110.29929284126528, 108.99558328813123, 99.32418730951126, 102.0644021803333, 108.04491842946699, 109.81148335241504, 106.94394050105926, 106.94757261583882, 105.0941821067564, 95.60488608575638, 95.93068599700929, 95.6495697267594, 94.2127270852366, 97.87233767970916, 99.46275680295884, 94.38845711369669, 95.3983497619629, 83.4819067678144, 75.18988286295246, 76.47171343526533, 76.67372334387996, 73.56295431813886, 78.74642141403692, 86.02841931004679, 90.99232781317927, 88.08662814478721, 78.20012154117708, 72.49228062168245, 74.11478473294166, 71.83089056322652, 69.8628334845266, 71.13999643633443, 87.9313728886266, 92.77016562800254, 95.4243629209457, 93.4331952371905, 95.51919014223161, 86.97739754953693, 89.406356657705, 90.75442821748796, 95.77678003618794, 83.2181901316489, 76.13405227661133, 89.0806822622976, 96.96384614513767, 66.51863636509066, 74.80321561136554, 92.96851204287623, 88.5526135659987, 94.42750038639193, 89.6586670414094, 86.58873773390248, 72.90827935741794, 70.64850776426255, 69.56473335143059, 71.72679085885325, 73.01509334195045, 73.05956517496418, 69.6998119354248, 71.53527721281975, 69.08195234114125, 76.32118071279218, 85.55332614529519, 89.88147335667765, 92.98458591584237, 93.61965687044206, 91.98177706810736, 93.50650433571109, 84.78422780190745, 82.35329181917253, 74.03560776864329, 71.07277485632127, 68.96675232918032, 68.75288117316462, 74.07027367622622, 81.86782790768532, 84.86794687086537, 84.92945747990763, 84.23697871546592, 85.02458280132663, 80.21765539723059, 84.90816685461229, 83.73176174779093, 93.9275001710461, 92.51667068850611, 99.97337879673128, 65.22737249251335, 0.5674886391047509, 0.7916118288713118, 0.5592333982067724, 0.49846433163169895, 0.34590328412671245, 0.06687641909886753, 0.20485030216795785, 0.030022436084466118, 0.1680161818982132, 0.2582570952513526, 6.284664677035424, 45.092767746217795, 81.44598484039307, 77.97158072071691, 73.15480816748835, 57.90283256961454, 34.7679009745198, 35.83377761225547, 75.39416774626702, 77.89140747439477, 85.67203275619015, 79.09020931490006, 8.46519164500698, 0.3803716023122111, 0.16677685081958774, 0.019414678982068456, 0.08571777703060258, 0.03316431779474501, 0.10566035570997385, 0.00844282805994754, 0.011613459134804867, 0.008767075731509156, 0.03709091677240307, 0.022334194096225887, 0.031111493271084565, 0.07857478088549069, 0.023318423641725414, 0.030662776421635386, 0.07672735219520908, 0.03667015064087126, 0.08940306597299154, 0.01920871241318603, 0.021884954391768383, 0.033833683288145455, 0.08291157398132548, 0.1696732147566734, 0.24826055182324303, 0.12230831964482224, 0.11220270827893289, 0.21518936350701318, 0.20779307571149644, 0.13363211806262695, 0.10609510294612377, 0.15704600200537713, 0.22193613131680798, 0.1871621900147969, 0.138419539397282, 0.1336306931390878, 0.12289085290244511, 0.19764192041850862, 0.3789665051285298, 0.4576638370992676, 1.147609884219785, 18.996303504513158, 146.2771704889113, 127.65099556215348, 112.98491616402904, 85.8975298173966, 63.69561241519067, 49.249699577208496, 99.32086113960513, 136.02610311200542, 124.63208844584804, 119.10059728930075, 155.9430359255883, 125.95217781682169, 60.848567870355424, 3.5498795922725432, 0.2523680548033407, 0.43665592889151267, 0.403238530120542, 0.6159758760083107, 0.9128557842585349, 2.237981846255641, 3.3451492747952862, 5.768354265920578, 5.053955826067156, 44.215109963570875, 129.37656387206047, 116.5371479526643, 114.73128872532999, 104.59767280086395, 107.72019324764129, 114.41185874323692, 116.68829256488432, 109.476575697622, 112.00970511282645, 111.04027563525786, 102.13889583464592, 98.67112836530133, 102.14042555901312, 102.66871390804168, 104.71740707274407, 104.89285469055177, 97.91297343469436, 101.02672346176641, 89.61408538203086, 78.44552855337821, 79.13676000410511, 80.1450131016393, 76.8344856077625, 83.43966284105855, 92.44022369384767, 93.9479749433456, 94.80232208005845, 82.1253550437189, 77.37911455092892, 75.95029707877868, 77.12631779332315, 73.99360702883813, 77.87188191567698, 93.78665570289859, 98.70570013600012, 100.93204529054704, 99.26351608768587, 97.37005464492306, 90.0921360138924, 92.72816488819738, 94.09815465250324, 100.06206358632734, 87.166761736716, 78.96196349974602, 94.58937660340341, 101.11747141807311, 73.29904156346475, 80.2399972177321, 95.06530915537189, 92.59256070660007, 97.09980334005049, 94.31957244873048, 90.5802357581354, 76.43790260437997, 75.10344166909495, 73.08222078507947, 78.15709314038678, 78.94874511226531, 78.40085275711553, 75.93299942631876, 74.73448784120622, 72.39199346111667, 80.51335503978115, 89.98401195772233, 94.26196852037984, 98.93022444940384, 97.54743206885554, 95.83475266733478, 96.22298886699062, 89.44390942973476, 87.67408109480336, 76.33235162304294, 77.42369621030747, 72.44935420251662, 73.62762635754001, 78.73727444679507, 88.18471093331614, 90.3651329778856, 91.96671516664567, 90.35875520398541, 91.78506235922538, 84.48360166242047, 89.4921467381139, 88.20090247738747, 101.290965695535, 95.07344415110927, 105.68240427201795, 72.34857282330914, 0.6032433721327013, 5.045578623971632, 1.2019990624920016, 0.6249541200457082, 0.7719494162067291, 0.2841159947697194, 0.800579715399973, 0.22866595326171768, 0.2738275258771835, 0.32129372079526225, 12.524412332042573, 61.905615252833215, 95.77270077120875, 92.7643918991089, 120.19477382782968, 96.55631188423403, 34.96067370137861, 35.34809404803861, 87.55604128683768, 92.72144979046237, 98.13320667512956, 97.84262964802404, 15.343956159007165, 0.9592280669077751, 0.3161625251654656, 0.091414337887639, 0.2562876823808878, 0.13703261381916462, 0.15796849444027872, 0.18896274178499178, 0.10840181666877001, 0.22766902772409303, 0.11165235837500904, 0.11117883942901127, 0.1227257839374004, 0.13080923727923824, 0.11516071165040617, 0.11396412061707628, 0.24590694585875159, 0.16243107917328037, 0.15239301377967482, 0.1281936139228844, 0.16215924053422867, 0.09911809507156573, 0.1978142902014717], [0.03686381000725012, 0.014335658727964808, 0.03937521859282448, 0.059314437976647774, 0.07708332261010524, 0.08411814714030874, 0.051653512768567576, 0.05200860984323006, 0.12119650390119323, 0.08884071913217345, 0.08069901246457331, 0.008085978559158262, 0.07791114189932424, 0.08814909495413305, 0.07994735763678629, 0.08100489605098002, 0.15403072590068465, 0.32918304745708743, 35.13566240187615, 111.1966605340281, 93.89732929968065, 70.24173444317233, 52.268077173540675, 31.870401020972963, 39.0054492796621, 76.06679931763681, 93.60901940253474, 106.65334778447306, 125.06103884789252, 96.4260107471097, 36.540455356720955, 2.092231228466957, 0.07255509180287201, 0.07238475215290824, 0.06689072962129308, 0.13561170458072616, 0.20503229401524992, 0.4823421031957673, 0.9211186860357562, 0.8818441160744237, 4.411269099481644, 20.68281481342931, 99.80015124044111, 101.29983809686478, 108.95763827908425, 98.24122874967514, 90.21433353424074, 88.64130620033511, 98.76481025449692, 98.50811466093987, 103.11964527253183, 94.58567388596074, 93.95628252337056, 85.04407698108305, 86.96831334021785, 79.44487787062123, 81.61929084408669, 80.00096013469081, 86.15338602373677, 85.98942310579362, 85.5832616744503, 76.97197252704252, 70.69924754481163, 69.29842010621103, 70.12729537102484, 70.61530097838371, 72.58322469649777, 76.50348463366109, 78.58332926227202, 75.12659934259231, 69.38157435386412, 65.24279132966073, 68.48578345391059, 67.50680692734258, 68.71207283389184, 64.87193907460859, 70.78453556183847, 76.76841720458, 89.36051983987132, 89.01305275578653, 93.0968519949144, 89.92016361605737, 91.11396835696314, 83.8015877815985, 92.11299603985202, 79.87010986574235, 77.1243409187563, 82.51053963938068, 92.07391354345506, 55.509217939069195, 67.67527272624355, 90.94901700173655, 83.31943435053672, 89.07332389585434, 84.80910347354028, 81.20894032139933, 72.34638414075299, 69.84746563819148, 66.62530129955661, 66.12510496570219, 65.69185564594885, 67.39425843761813, 67.53014502986785, 66.94547653198242, 64.15643599725539, 67.70774995127033, 71.14404432235226, 83.09975024192565, 84.02448038901053, 89.33070982656172, 90.02350238061722, 86.17705360535653, 84.48732006934382, 78.15317077021446, 72.41587285072573, 66.96955988484045, 65.25390732672908, 65.84923682674285, 63.436335902060236, 69.80778694152832, 75.82570691262522, 81.14247183645926, 79.93504862631522, 77.17319011688232, 76.47114861396052, 77.06954540744906, 78.51537812140681, 80.82348900456583, 89.00584343940982, 88.04047753733974, 83.00823350106516, 15.571129052869736, 0.45723620681993427, 1.0095271936828092, 0.6565741846157659, 0.31748304624230633, 0.03307338698857254, 0.08202602996701196, 0.4951348215822251, 0.13771977936548574, 0.09813156534707355, 0.15700596625045424, 5.822827652577431, 41.99488762886294, 61.540921118951616, 76.71928559580158, 67.2533747457689, 41.15300970692789, 24.269126115306733, 35.450581658271055, 58.324420682845584, 62.60117307786019, 77.82963798892114, 47.48517428675006, 2.167052890985243, 0.18045211781657514, 0.022527150576934222, 0.10550538378377115, 0.06957918495660828, 0.05925676687770794, 0.01883317228226412, 0.020595816106745796, 0.04650577730048568, 0.056514099330431035, 0.022149241319106474, 0.026917531523072434, 0.05737679860284252, 0.07425036010963303, 0.02420502677259426, 0.027917448634041414, 0.04526715868362977, 0.13522256255870865, 0.06934287747548473, 0.041681480323595387, 0.020253457159044284, 0.042916394905337406, 0.026072908095234347, 0.03033111397657664, 0.057498637226320086, 0.047382009516079585, 0.06838687635477513, 0.03686848314358823, 0.025091815679784746, 0.028096335910020337, 0.08962108693536251, 0.05182928781235411, 0.07544232397190026, 0.016085599857052008, 0.06910353628618103, 0.04821062553673983, 0.058768711413346955, 0.10624999826353405, 0.26995703517909975, 0.4516366556767495, 44.022294090640166, 126.84171645872055, 103.77008407346665, 80.4534290682885, 56.104712178630216, 37.54833582908877, 38.36925260482296, 54.24234336422336, 98.21996950334119, 112.94941086922924, 133.38299043716924, 108.14351112611833, 44.34685453291863, 1.2746788657480672, 0.18545784356613315, 0.0679025708908035, 0.12099111572869363, 0.15325337648391724, 0.19882996957148277, 0.22798229639808978, 0.8575869531881425, 0.7388462054152644, 1.936244572843275, 30.899777181686897, 112.65604111456103, 107.06071730582946, 115.6363913320726, 102.90407180786134, 92.63172165040048, 90.87293870987432, 103.15697839183193, 101.29028320312501, 104.15904983397454, 97.6804631756198, 97.12125086015271, 89.09744647241409, 88.19239093411355, 81.46637332054877, 84.82817403731808, 82.38841272169545, 89.24366458769768, 88.90695264262538, 86.84969302146666, 79.81840518213089, 74.37654802876135, 72.00005454401817, 74.64184930247646, 73.5282648763349, 75.83506568785637, 79.79039945910054, 81.98851923788749, 78.00867065306633, 72.83606067780526, 69.86472406694966, 72.65767912710868, 70.84999207527407, 71.85435418159732, 68.4696154440603, 71.47783802401635, 79.27463916040237, 92.10832057460662, 92.49496429197251, 96.3554943761518, 91.42921709245252, 92.12109181188768, 87.72353433793592, 92.97726677310084, 83.88410660528368, 79.2820445952877, 87.27232840753372, 95.38377423440257, 59.46998027063186, 71.91159725189209, 92.94378542130994, 86.02124921737179, 92.20464614129837, 90.14358966581284, 87.02985532822149, 75.72067368415095, 72.91386481254332, 69.45074142948275, 69.25754900901549, 67.64958120161488, 69.23610148891326, 70.40210447003766, 69.89704439716955, 69.21720350942304, 70.42763125511908, 73.26443056906425, 84.400188538336, 88.09965825849964, 93.32111743188675, 92.78015198246126, 91.01114734526604, 87.055680213436, 82.99881196791127, 76.38169503981068, 70.046172911121, 67.96846989662417, 69.85160766109344, 65.90364010103288, 72.26799949522942, 77.82883782540598, 83.32680840646067, 82.37022861357659, 81.28195131978681, 81.20243703165363, 80.81599727753671, 82.91237077405377, 84.26694562358242, 91.2815712344262, 93.80814244670253, 95.51646017259168, 25.826436511931885, 0.732533763493261, 0.674003420337554, 0.7567364422063675, 0.2849797742261041, 0.22471344519046046, 0.20481336140824905, 0.5805226139003231, 0.022330821394139243, 0.06066820726940229, 0.18026385937006245, 6.177969344200627, 46.61667916082567, 67.36709994654503, 82.86858143345003, 56.10142523242582, 34.66970051488569, 32.11925775774064, 55.581617047709805, 70.37333780719389, 73.63795003583355, 91.11527058386034, 66.67510755600469, 2.8330384963943116, 0.2075325751737241, 0.07523149657513827, 0.04862487609047563, 0.033563219776917855, 0.015555630764743734, 0.045850649551157995, 0.04461110013747408, 0.06212740175185665, 0.06597860235600703, 0.03844248356237527, 0.06665439149665256, 0.044414418554233934, 0.019448743081621585, 0.043574215453718944, 0.016217761515309254, 0.029974515369582563, 0.017742644206831054, 0.04625172339259617, 0.0290451702781983, 0.005218487997133766, 0.06747632723061309, 0.1356482929399898, 0.179119216758878, 0.26908384816300485, 0.15347066966276016, 0.18307184740420313, 0.2333542887842463, 0.09338732838871018, 0.13816660780820156, 0.2808425317127859, 0.24849047013107808, 0.15738073646301226, 0.08419679372661537, 0.14725466288866537, 0.14787902454695395, 0.15011810036676546, 0.31956953266935967, 0.3834045444044375, 0.4159152015082298, 60.909462667280636, 143.63032371767108, 119.06086367945518, 94.00793229379963, 69.7246640728366, 41.9740088524357, 57.64457587272891, 109.27444811790221, 121.31697962360998, 126.75489087258617, 143.76699478395525, 118.09911420268398, 58.441213177096465, 4.0677763569739565, 0.330445223277615, 0.26789907786634665, 0.23278571364860381, 0.42638508002123526, 0.3817486300343468, 1.044782253523027, 2.3646067419359764, 3.6382868741789176, 9.180032822393603, 28.746666600627286, 115.02739629437848, 113.53398523023053, 120.91611339199929, 110.36749501382153, 98.2967459770941, 93.98157396624165, 107.92436045985069, 106.1747637102681, 110.5711836968699, 102.01481557661488, 101.34129754958614, 94.1601751696679, 94.32545600398895, 88.47669216894334, 90.0884646754111, 90.65192884014499, 93.57403186059769, 94.52428094802364, 93.28848331205307, 85.45001875969672, 78.23092783651045, 77.07577413128269, 77.5648073996267, 78.7422009437315, 80.33820552210655, 86.62005393735825, 87.7776159778718, 84.5659871255198, 78.11269191003616, 73.21478120742306, 74.38339648708221, 74.46990043886247, 75.67013786685082, 73.5063309823313, 77.22897406547301, 86.23385737019201, 97.03828488626789, 98.20113428177373, 99.54035697444793, 95.32147130658551, 96.3459316376717, 90.67118767769107, 98.92375253861951, 91.9486879533337, 85.47312936475201, 91.84949905641618, 98.59836839860486, 65.06754375273182, 76.68160730792631, 99.56287137923702, 90.62659817357218, 95.99225151923396, 96.45682488718342, 90.69265873201432, 80.61324211858934, 76.71673605518957, 72.6923450346916, 74.13345521496188, 71.93846548757246, 73.41020153414819, 75.28713410900485, 73.82247401821998, 72.06061593947872, 76.02890922177222, 78.5041287637526, 90.00557714892973, 92.53899681952693, 96.50414436094223, 97.72980659238755, 96.48873729090538, 93.02228773793867, 87.32484109940069, 78.90526956127536, 73.99659587490943, 72.4840279548399, 73.94510299928727, 71.99021723962599, 78.30820637364542, 84.507810531124, 90.89418226672758, 88.42252423686367, 84.9093984788464, 84.81442220749395, 84.6037438607985, 88.1517630238687, 88.29005010666387, 97.62168253621748, 99.04056856709143, 103.89015566918158, 31.537740884288667, 2.103255049836251, 4.258266754688756, 1.8506601717202895, 0.6242378584800229, 0.6373639476876105, 0.6874786004904778, 1.000588173347135, 0.23880895737919117, 0.15833571102590333, 0.4068080095514175, 10.996186310245145, 62.917786798169544, 77.64407065606888, 98.39557401595577, 89.75228617268225, 57.19776691928987, 35.66631201774844, 54.83724532588836, 81.03036265219413, 90.86634912798482, 105.34271132561469, 83.39936440990817, 4.755328624479232, 0.27235816923841355, 0.15353552666642975, 0.1453459395035621, 0.10717898712403352, 0.20866857631312263, 0.09881980341648865, 0.10491756451947075, 0.19632740547099423, 0.09379543108685363, 0.1692643536314849, 0.1527089331178896, 0.17651528390424867, 0.1730036441116564, 0.2651157885068848, 0.08338024359076254, 0.18408922748940607, 0.13987843127500627, 0.15258963790632066, 0.10706922204624261, 0.07094184086928446, 0.19689486211826726], [0.04755268624473003, 0.08457316506293514, 0.024261060358595946, 0.05311362655653108, 0.03145503582462909, 0.05727455650846805, 0.06752999168970893, 0.023989916944335547, 0.036240026745344364, 0.055383648498043905, 0.061081829631040176, 0.024723214390237006, 0.08440020539227032, 0.04039281318264623, 0.040393288157159285, 0.03874013936447521, 0.08845542287153584, 0.7542464113043201, 74.6814730859572, 105.94677202163204, 89.79963702540245, 75.48752015636813, 67.74824450092932, 96.56619625706827, 106.41131401062013, 98.394099204771, 102.25098932943037, 113.4173260965655, 105.98614477342176, 61.76506888481879, 2.9147995671918316, 0.19853179282959432, 0.07895755671685742, 0.07014916969403144, 0.20685184476596696, 0.1561492194812144, 0.3059825649665248, 0.19210302811716834, 0.6257924040959728, 4.036671226063083, 20.354402603641635, 123.15404522803523, 107.32947811003655, 111.41941193611392, 100.32617245951008, 93.09174506895005, 82.63996216558641, 82.42780116296585, 83.62069591399163, 89.92378004135625, 87.37062300405195, 87.0923073061051, 78.45862142501339, 76.57927267013058, 71.58115325435516, 71.1262446065103, 67.24098790076472, 74.5113520468435, 76.60088492978004, 78.11226829405754, 73.89195488345239, 70.59528120102422, 71.50782846635389, 68.43371791224327, 70.07349614174136, 70.34507320773217, 70.69165383615803, 72.65953048583, 74.64575598316809, 70.18830391668504, 64.62761071420485, 61.21836893020138, 65.1773230491146, 68.99225558004072, 74.29656305620748, 74.88476953198834, 72.30137102065548, 74.50177361888271, 82.27582500826928, 85.99886032842821, 85.65722973115983, 79.98481565906157, 78.7570353477232, 86.20514562053066, 89.55983900254773, 70.6956938774355, 71.64924560054656, 85.3372427725023, 91.33186386477564, 53.88308563540059, 67.54791336674845, 87.68250634593349, 78.39725202129733, 88.10779325423702, 82.89005248777329, 86.53055329476634, 74.957443206541, 73.93710136413574, 65.90986098012617, 65.19050613526376, 64.67953505054598, 65.65793891106883, 65.06778301731234, 66.70547454587876, 66.25184459071006, 67.96523786360218, 63.796931159111764, 69.20980591927805, 73.21804461940643, 76.38011040226107, 77.41274495278635, 75.08425343421199, 74.26559202132687, 75.15226733299994, 70.66847262843963, 67.94019745242211, 62.95183689363542, 67.58527786500993, 61.35225119129304, 65.86393787014869, 68.5324518142208, 75.61523252917875, 75.65949255420317, 79.7992483262093, 77.96114721605855, 77.87049339663598, 74.6442105693202, 82.85821068671443, 82.46288284178704, 86.86267606673702, 86.46573220529865, 54.190560233208444, 3.2119698534088754, 1.1621715609104404, 0.945557258542507, 0.19552436146524646, 0.16753423598504838, 0.2925979670497679, 0.27575809808988727, 0.07450951999353786, 0.15226103215207978, 0.04202202172769655, 0.5276816073925265, 10.551201258936237, 38.53076011903825, 63.96111765215474, 89.25776158609699, 72.3230460382277, 30.429998828518777, 16.520589743891072, 50.48338305565619, 68.92577140561997, 73.57101871121314, 73.49959235037528, 28.32357818080533, 0.9530300478781424, 0.08696130627105314, 0.10651777663658704, 0.06814324507309545, 0.02851994997341066, 0.025646999598510807, 0.015679151908825004, 0.0742385087294444, 0.04698422219183657, 0.04903880105684361, 0.04533208846565216, 0.04970688718341051, 0.007514792500108842, 0.07617824335372256, 0.02579423020623865, 0.026603460371974978, 0.02276773091345545, 0.023250544421194543, 0.03918978701075239, 0.030449677574177905, 0.012445582880548412, 0.0774513359271711, 0.02597219051582919, 0.0388756028616861, 0.006139595249307252, 0.024924030933048458, 0.028788530823564338, 0.024706025292435964, 0.021903338586731304, 0.09265761431907454, 0.031224592746565902, 0.004130053256953797, 0.000995762759797095, 0.03461348035583093, 0.05950232487051718, 0.022459215815028837, 0.031002647498802795, 0.08828080845095458, 1.2342505060857343, 89.56453015727382, 117.96450630311044, 101.92085912150722, 85.41515673360517, 69.93538164323377, 88.46745890955772, 65.370723355201, 88.53676719050254, 111.0326740818639, 121.24221924812564, 117.97974863360007, 69.83021505417364, 3.8431341273169366, 0.4461477582733478, 0.11439956499323731, 0.14657528079565496, 0.2098180912435055, 0.3194071220294122, 0.06319375400761924, 0.18579576494953326, 0.5537031014119426, 1.225749013885375, 29.83977233209918, 129.22422685930806, 110.33583364179059, 114.98028862860896, 103.14594084216704, 98.68767292268815, 86.27849394275297, 85.09524037761074, 86.0952643425234, 93.09201179012176, 91.36922836303712, 91.02196524220129, 83.59191356166717, 79.5514565129434, 76.74012907089727, 76.91035993637578, 72.11578799832252, 77.4322783562445, 80.38455224806263, 79.97263277730634, 79.39984121630269, 75.08132734606343, 73.60325274928924, 71.32703073563115, 72.42211726404005, 73.16827758666008, 75.04430801637712, 74.3694720729705, 76.80674660590388, 73.0417811486029, 65.95186171993133, 64.148869745193, 69.19934103565832, 73.3427446119247, 78.60390601619598, 80.58991970554476, 78.90239838630923, 79.65953350067139, 86.56836494322746, 89.98415316304853, 87.23592881233462, 81.05250050944667, 80.09734845930531, 88.687284223495, 92.03087729792442, 72.35443284434658, 75.01630229334678, 88.83311010176136, 93.5132194334461, 55.89618329078921, 70.63834882551625, 89.20831618770477, 81.40625907528786, 92.71999851349862, 87.22396558330905, 89.37659371283748, 80.21947537699054, 78.5637644798525, 68.66622032657747, 68.56099097959458, 68.99249092225106, 69.54803974397721, 68.38469612982966, 69.279890829517, 68.14768298979729, 69.90140607280117, 65.71046337004631, 70.63728194082938, 73.4629495682255, 79.10406312634869, 80.77001140963647, 78.68262798555436, 77.57370333517753, 77.41265081590223, 72.49451637268066, 71.14468759106052, 66.8420357857981, 69.99917507171631, 66.26049733931019, 69.32459800474106, 72.32696840840002, 78.28526050813737, 80.03498277356549, 84.2653060728504, 82.05913759046986, 82.21167072173088, 79.81208232141311, 85.43843992294805, 84.48175814843948, 91.95496374560942, 92.26902792530676, 72.57800009942824, 4.8229296938065565, 0.44689607295778494, 0.8244412704821557, 0.3051003381129234, 0.17408350632796366, 0.2095134946848116, 0.22942900747781803, 0.12040872036689713, 0.15613235022512176, 0.0667470345093358, 0.8264495852974154, 10.135597701995604, 42.6531554806617, 61.94598428664669, 68.2276758070915, 51.8174478315538, 38.10073890993672, 31.260945104783584, 64.26201443518362, 80.8432577502343, 84.71250334093648, 84.9328464077365, 41.71486569989113, 1.2074483378279595, 0.07707450493809677, 0.08477295313270823, 0.07662691806833591, 0.03181965154175076, 0.007306511388085182, 0.08338033552131346, 0.06127724333876564, 0.02900024305187887, 0.049022215253282944, 0.017849388982980482, 0.020957949698992798, 0.030756166370044795, 0.043525354365908334, 0.037568802419569225, 0.04679766063007616, 0.02030919963163474, 0.017595323583772107, 0.045730178394625266, 0.03990828555317656, 0.03757837085774349, 0.1558096893131733, 0.17594891510182814, 0.1683402983772178, 0.14029334449479658, 0.13685246058289083, 0.07960713032873408, 0.1783769082037672, 0.11370641630022757, 0.20180997498814138, 0.1375675576949312, 0.11318359959630236, 0.10159052127311308, 0.19731513795352754, 0.15298570536317366, 0.19207538766486032, 0.20854082349086964, 0.24328785978498, 2.935737914616062, 110.87897208429153, 132.44549689754365, 117.48259605899935, 101.33429219645839, 85.48326476927727, 108.39079303126182, 131.04078631247245, 128.69134149243754, 118.43724604575866, 132.24983338386784, 126.88525476763327, 86.85520787392893, 5.484525676696531, 0.4870642078739982, 0.3281480626713845, 0.3178420350436242, 0.5303876138021869, 0.5544186275332206, 0.5707036956183372, 0.47580642325262873, 2.6661786629307658, 9.070236855937589, 26.03230211042589, 134.62635040283203, 116.34561077240976, 120.13319261612432, 111.46902991879372, 105.17400233976304, 92.37739516842751, 89.43265222734021, 92.71245971802743, 98.97144855991488, 97.5944769767023, 95.84376627399077, 90.02835827489054, 85.13851981009208, 83.24628214682303, 80.24248400042134, 77.38870866837041, 85.33463831870787, 86.72529112908148, 82.5062721006332, 82.65755791817942, 78.20585604636901, 77.69140581930839, 72.86798092626756, 76.14808651708788, 78.19102948711765, 78.44028042208764, 80.72662215079032, 81.87775934896162, 78.24735472279211, 72.46374145630868, 68.25505395089426, 73.4825300401257, 76.09789586836293, 81.70767753354966, 82.70672875065958, 82.0129006908786, 85.03285115764987, 91.28310880353375, 93.77248810183619, 89.52561240042411, 86.38175425990936, 86.02870956543954, 89.37948842202464, 97.03404872648179, 75.88420514137515, 79.01435067576747, 93.02905774885609, 101.53007338123938, 62.85509555570541, 76.93212124609178, 93.17256158398044, 84.20211668937438, 95.45801685702418, 89.82947057293308, 95.4113563414543, 83.72094385085568, 82.70484601297687, 72.40936171623969, 72.2389268875122, 73.64364531732375, 73.79924574205953, 73.7505534387404, 73.06526830119472, 73.23277704177364, 74.50492720450126, 70.28095030015515, 74.8927240986978, 79.32172329195085, 84.57187852551861, 87.79198754218318, 83.67186715525966, 82.46693857254522, 84.94539799228792, 76.23093481986754, 75.69058910492929, 70.58941333524643, 74.56351172539496, 70.81583607581355, 74.59782461966239, 79.00465457670151, 84.5294306355138, 85.78283186881774, 88.15657184969994, 88.92462684262185, 86.41281943167411, 84.03654559966057, 92.29410756018855, 90.0100721851472, 95.42543765037291, 99.38301501735565, 79.38452828314998, 4.0403778658759215, 2.358328253030777, 3.971977613625988, 0.6935995204314109, 0.43453889087803904, 0.787006721140877, 0.8758053820460074, 0.33077608133035324, 0.3325550600646004, 0.2270205496179481, 0.7630480261098954, 17.820559317065825, 57.49771841110722, 81.46444351442399, 109.10843772272911, 93.68101842941778, 45.540435698724565, 26.539739139618415, 74.75676690378498, 93.80478489783503, 100.55325415826614, 101.71337358413204, 56.83119397009573, 1.7536538286555199, 0.18836378360227232, 0.15241590448685233, 0.15585482721367191, 0.11205484564866751, 0.1006388562100549, 0.17521520205322774, 0.11729524711207037, 0.15400346849233876, 0.1933623081253421, 0.13780567314355605, 0.16160126805545824, 0.16115546617056095, 0.2110054662391063, 0.069790035336008, 0.1406385896787528, 0.14704800301021145, 0.13758798159899252, 0.19452640936980325, 0.11946214212765617, 0.16354350012636956], [0.06273135099740279, 0.06547095419298257, 0.049082111837642814, 0.07103523464813348, 0.00870089435334047, 0.05159076633712938, 0.04756282541840788, 0.030402404203590368, 0.04718903579839295, 0.025860537031304934, 0.036711979041536974, 0.048872402929250276, 0.08256830530421388, 0.030696409596731106, 0.12819482434180476, 0.19391392207434102, 0.5133165088632415, 11.127434699766098, 94.82253797592656, 96.96081807536464, 76.67479022856682, 60.104651143473966, 36.64901479598015, 28.55329767350228, 86.97478525100216, 78.03405623282157, 118.7616809721916, 108.72463380136799, 77.59146382731777, 5.6975020420166755, 0.4931484781686337, 0.13087205648902925, 0.1423618278556293, 0.12337154243141414, 0.025796055410718246, 0.11124032564581403, 0.24282456045189213, 0.1510410830979386, 0.9445058794752245, 9.498796001557382, 126.27600085350775, 100.46860940994756, 104.18361956073393, 98.07386905916276, 99.00178417082756, 80.83612688126104, 79.13352797108313, 76.38437794100854, 74.71469556131672, 74.92560140548214, 76.91225051879883, 73.19687166521626, 71.18829650263633, 68.13899101749544, 70.57774036161362, 67.13734319133144, 68.34031843370008, 71.10001963953819, 69.93012566720286, 70.25295242186516, 70.70005555306712, 66.64008863510625, 70.82384555570542, 69.05713942743117, 67.420546162513, 68.72601293748426, 68.9669406029486, 72.0738107927384, 71.16519374232139, 68.26436565768334, 62.26137030509211, 67.03215306805026, 70.43794708867227, 75.92744535015476, 83.37088015771683, 87.04017116177468, 87.60985620560186, 84.27821067071731, 85.93469819714947, 88.9333188149237, 88.10968383666008, 78.84056614291283, 77.25042158557524, 85.79164151222476, 80.59455594708844, 72.04898218954764, 78.21055504583543, 85.74182741103634, 81.35559774214222, 49.45187030300018, 58.59369531754525, 85.77002140783495, 73.3489498015373, 83.09960903659945, 81.70332370265838, 85.43028923772997, 79.7392988204956, 79.90904331207275, 74.51687474404612, 76.44374693593672, 74.33693209002095, 72.64744958569928, 65.28234843284854, 65.19988452234577, 62.50939353819817, 65.05185427204256, 64.29115372319376, 65.73057728428995, 60.42574028814993, 65.03709439308413, 64.4613963557828, 68.28618188058176, 67.30607571140413, 66.67561746412709, 65.18985109944498, 65.85774052527644, 67.27525372659007, 65.48094587941324, 62.41455062743157, 63.47465353627359, 61.77305483048963, 71.63244216672837, 75.59220037152691, 80.12176913599815, 79.43836673613518, 78.31174435154085, 74.79512768407022, 76.78502451988959, 79.91934345614526, 90.0058360253611, 81.05485393155007, 85.10913341276108, 21.032956953971617, 0.26621117166453795, 0.10915436781942846, 0.08584396703349007, 0.02277701781431754, 0.047704130336041414, 0.13586956977603898, 0.13816723600029945, 0.05868795425480893, 0.13262325687514198, 0.09181955243430792, 0.4768721128423368, 16.107987780724805, 30.421000911343484, 81.19505513098933, 77.02727010173183, 47.47518793229134, 25.043313733993042, 30.182707117449855, 51.47315394493842, 58.19770851442891, 66.32018012385215, 52.29488265129828, 8.789205897238947, 0.20158612409666662, 0.09166983587126579, 0.050305730452941316, 0.004420843474837321, 0.12055492058636681, 0.0712073899264778, 0.07231156777350173, 0.027912340742806276, 0.0979602451045667, 0.04597824532538653, 0.09441029325488115, 0.031573402154589855, 0.06628892925237456, 0.0502419957680808, 0.05267213391620786, 0.013721224611564992, 0.018195051684855454, 0.03287465612013494, 0.059164652465692455, 0.12256722671971207, 0.044500220401753346, 0.01971282699565974, 0.05035666763902672, 0.025864091679273594, 0.03432641954972379, 0.028463286280091253, 0.028986390266988068, 0.030896603693104083, 0.06134318052640846, 0.06232949574628185, 0.10705509538491888, 0.019958829319465066, 0.06037269651349034, 0.02341550804914967, 0.021835643227302262, 0.1173638885900859, 0.4730622350208221, 17.63635696903352, 112.66890648872622, 102.38164347987022, 92.78563545596216, 68.72027843229233, 53.61056327819825, 34.85415389460903, 58.31323016074396, 88.37392607042867, 128.88478494459585, 117.96645179871591, 88.91587211239724, 7.353268342633402, 0.9231091050371047, 0.08053890774927794, 0.15583762087889258, 0.1476041828432391, 0.26247413348286386, 0.15929869886848236, 0.18688031562393714, 0.23987959589689012, 1.311393476301624, 14.038797290094438, 136.99896074110464, 102.14382233158236, 111.11329447838568, 105.638701223558, 104.88818707004671, 84.10208056049963, 83.18483429570352, 80.11498343560004, 78.15196268020138, 78.74653124040174, 77.87035219130978, 75.67469566099106, 75.88624477386475, 73.27664482978084, 73.76046919053601, 70.62629145960655, 72.86505483811902, 72.4475577569777, 74.39244931743991, 73.32403490620275, 73.18253147986628, 68.82237772787772, 73.1189969278151, 71.91259353391587, 71.28526533803633, 70.2892735696608, 73.68594415726201, 74.80585144412133, 75.48587276089576, 70.88621124144524, 67.6914172018728, 70.60687572725358, 76.48589672580843, 82.43573219545426, 89.2099714279175, 91.1395186762656, 89.78610484830796, 90.05321041230233, 90.5247812886392, 90.38393682049167, 90.88498038630333, 85.02480245405629, 82.88739312079646, 87.05528013167843, 85.67506082596319, 74.00932788848877, 83.58508863756734, 90.51898402552452, 86.16866757792812, 55.67260034622685, 61.57448484051613, 89.0258083035869, 75.29548875747189, 87.25704685334237, 85.04505757362612, 90.2549300655242, 83.36155276144706, 85.73617135324787, 79.83216485669537, 82.25401663011121, 79.29825967358005, 77.6679265114569, 69.60047398844074, 67.25626945495605, 66.22505480243315, 68.13286427528628, 66.80669523054554, 67.51889567221365, 63.77977078960788, 67.23083680675876, 67.93549845295568, 68.86977564903998, 69.31165418317242, 70.54413349397721, 68.46890941742929, 68.29969836819556, 70.35948399574526, 68.4227038967994, 66.37463046658424, 66.42475835738644, 65.8586112914547, 74.74801217356037, 76.99044689055413, 83.31525310393303, 82.73100037728587, 82.14717911135766, 77.40792828221475, 79.06714577828684, 83.23598984749087, 93.46638633358864, 87.04303449200046, 95.86543344682264, 30.050144733921176, 0.5067632701848784, 0.27081848572819467, 0.23360348186425625, 0.09382978246937837, 0.21233731009546788, 0.1996123904903089, 0.15584146664027246, 0.04193395609036089, 0.13462933471366284, 0.10627714075869131, 0.6494936322973621, 17.189165584502682, 38.04750450195805, 77.57932016926428, 56.62286120076334, 42.56173679905553, 35.424446905812914, 44.35469927326326, 62.94447460482198, 68.53442868878766, 79.82592044338104, 68.54530934364566, 12.029750462501282, 0.13027473773446777, 0.0346795171349039, 0.08072294505132784, 0.027407925470822284, 0.030431473409877192, 0.015812033689731074, 0.014822575594148329, 0.02279422414909688, 0.02334649118805124, 0.025694110175414432, 0.050875581124977726, 0.0569823399306305, 0.05390504900846751, 0.07389211441360174, 0.04047275828798452, 0.03807491840674512, 0.03956754496621509, 0.04115990851254713, 0.036717943036027496, 0.07991282239315972, 0.14630486708014243, 0.1419399892010035, 0.16434721828949067, 0.14870817682916118, 0.10090341701382592, 0.15386293732350872, 0.1510736418347205, 0.1363744523616568, 0.13153410967319243, 0.08698374498635532, 0.23325043790523084, 0.09424396790564062, 0.20619109393127505, 0.13297515170228097, 0.18492072400066162, 0.23557824202843253, 0.6751950854255307, 27.272275109444898, 132.37472165015438, 119.56950879866078, 109.21041150246899, 83.11467878280148, 57.66239520042174, 37.39398271806779, 119.86317665346208, 96.7597887592931, 140.45323525705646, 127.12601769355037, 105.13952470594838, 9.676405825922567, 0.9448606701147173, 0.741496624485139, 0.23949570923803315, 0.4144974485520394, 0.4513982797582304, 0.567772827081142, 0.45782100769781303, 0.5707048600719822, 2.1405273723986844, 11.341134252086764, 142.1878799315422, 108.73946036061933, 115.1868171076621, 110.82788713516729, 112.41101064989644, 88.33417677110242, 88.21548584968814, 82.83226813039472, 83.22244198091569, 82.28002194435366, 85.29584607770367, 81.76856840810468, 81.28891744921285, 76.50439462354107, 79.10880919425719, 75.01603557217506, 76.56759969649777, 77.30419728063768, 79.80205674325266, 78.26229895314863, 76.9969815592612, 72.28002548217773, 78.90603834582915, 74.65585216399163, 75.41472096596995, 73.10287598640689, 76.89474890308996, 79.23427797132923, 81.24523793497394, 76.345350357794, 70.39707599147674, 74.8284678305349, 79.51056188152683, 84.9563100261073, 93.15585228704637, 94.51460053843837, 96.08896147820258, 94.70903242788008, 93.37064127768241, 94.63671961138326, 94.74264714025682, 87.11322922860423, 87.0948725361978, 91.354339045863, 93.20135962578559, 78.130169991524, 85.73569282408684, 95.87766339701992, 89.28756375466624, 63.34678819102626, 69.55782997992732, 94.46409610009964, 79.35387888262349, 91.50477763145201, 89.96833032177341, 95.91280783376386, 87.85759310568534, 88.31379613568707, 83.95082612191477, 84.90819038883333, 82.34730628228958, 80.15398748459356, 72.81535056329542, 72.30985902970838, 70.25354862213135, 73.05459945432602, 70.26905767379269, 72.48878186748874, 67.94516317306027, 71.88787475708993, 72.03739550805861, 74.14723057900706, 75.57731889909314, 74.71929257915866, 72.66448051698747, 72.0972038084461, 73.73924916790378, 72.10426407475626, 69.10463933021792, 71.18983407174387, 72.70137433082827, 80.40417194366455, 81.68762637722878, 87.63750891531669, 87.41736196702527, 87.01740572529455, 82.20217858591388, 83.42179252255349, 87.18032529277187, 98.84963543184342, 90.50946835548648, 104.84155008869787, 30.788146526582782, 1.0065307480192955, 1.5239342133845053, 0.4692533071483336, 0.1719085827109314, 0.25287970960620915, 0.7591524383714123, 0.3685680260100673, 0.3925025126626415, 0.3674776683891974, 0.40437295311881655, 0.7143302886716781, 26.525369536492136, 51.33748700541835, 101.33087188966813, 97.43622502973004, 67.79914902102563, 36.920246693395804, 46.197487615769916, 73.34833006705009, 85.3891827983241, 93.16743112379505, 86.0047987968691, 19.2287863069965, 0.2841076290895862, 0.12120471636374151, 0.15287106796618433, 0.06558521620688901, 0.23213502920923695, 0.19149818637919044, 0.10133671634379895, 0.10290781711979259, 0.19839679281557762, 0.21860098286021143, 0.22326612124039283, 0.20453977608873, 0.19061787474539973, 0.17094974706490196, 0.22105588097005124, 0.13038235776607068, 0.08459570336966746, 0.10475539136677982, 0.2006643211408969, 0.24416320716902135], [0.06850913632661104, 0.009264944782180172, 0.06579533114188141, 0.11096258812974538, 0.033100123457129926, 0.044867992401123054, 0.019949023394034277, 0.02061689118554275, 0.02293462125254014, 0.04244661446841013, 0.01234006192985802, 0.07430923396661397, 0.015390064800158145, 0.04111570906975577, 0.07434108790250556, 0.05644061617673405, 0.19339178718866842, 50.71441458117578, 95.2790234165807, 95.56302655127742, 86.34110281544348, 44.265512420285134, 24.759683224462695, 66.76724403135239, 70.20799421495008, 96.61814412763043, 116.36112766881143, 89.20339753550869, 15.234357291652312, 0.033660279286484567, 0.23463114284940306, 0.03211396720050083, 0.11991050274622057, 0.10915050673629008, 0.11604649315197622, 0.050067189825518485, 0.09816505871112309, 0.1253644358967581, 0.14246760927621396, 86.74124733094247, 110.27189900798183, 101.61795800732028, 106.52368991605698, 91.96033739274549, 82.28734893183555, 75.66923572171119, 77.34440157490393, 74.90078064703172, 79.19881190023115, 72.78851370657645, 73.00629154328378, 70.2338347896453, 71.97096624682027, 69.38294718342443, 70.75533743827575, 66.99758129735147, 69.16401616988644, 66.82900567208567, 66.52909340397005, 65.99409780194684, 66.95883612478933, 68.1723782324022, 68.77800003174814, 69.38515155546128, 67.88524504630797, 71.12011786430114, 70.85635415969357, 67.33412065813619, 67.21662998199463, 62.68797905214372, 65.82751474072857, 70.41536208122008, 75.5943968988234, 81.66439025632798, 88.70246379606186, 87.79697679704236, 88.75981669272147, 87.99274229234265, 87.59073072864165, 85.7825102344636, 84.82067446554862, 86.51105911500993, 81.9316448703889, 82.22553237791985, 80.42272475457962, 64.88920534810713, 77.15544531422277, 81.70635177243142, 87.38689299552672, 59.4977153501203, 58.92380591361754, 82.49885882100752, 75.07376501637121, 80.96984832517563, 80.89809248524328, 81.52310648272115, 82.6641788790303, 81.27947238183792, 78.72478562016641, 82.1800015049596, 81.91293516466695, 84.15504824730658, 79.06491002728863, 66.31461035820746, 63.757691767907914, 61.5739788547639, 64.66108814362558, 66.99249790560815, 66.33039397578086, 63.467769776621175, 62.340547269390484, 62.63357970022387, 62.26978378911173, 62.341367044756495, 62.50833842062182, 65.60333559590002, 64.02817841499083, 62.91003619470904, 61.53986207900509, 61.93437799330681, 63.14795540225122, 60.080191243079405, 70.2417972010951, 77.82480562886884, 77.85730638811665, 76.87223449830087, 74.99573338416316, 77.32252259408274, 80.08199630245086, 84.46621771781676, 88.60069397957095, 83.24601542565131, 57.170157355646936, 3.004388463112616, 0.2573881370405997, 0.14789043925702572, 0.0869993501973729, 0.6399778396852556, 0.11213426598377767, 0.10789392335760979, 0.031323199753739664, 0.0685596521643381, 0.07636051099266737, 0.031213781330734495, 0.12336171352334561, 26.862238376371323, 39.760466314131214, 63.15080304299632, 60.38989766951531, 38.108348308071015, 19.86342383969215, 42.871384389938854, 53.78240231544741, 63.441933124296135, 66.67903777091735, 43.084322021853545, 3.0193074432111557, 0.1000520405209353, 0.19860297771951846, 0.007216734501848659, 0.03679596143023622, 0.08455934483678111, 0.028133958487981753, 0.047625077723134915, 0.016946414553169763, 0.02869326395974044, 0.07793446161573933, 0.025626652303241917, 0.03027771190259486, 0.03416641442585857, 0.09229726954213074, 0.10244820266962053, 0.05238776207871495, 0.029782035778607094, 0.014182232384149347, 0.10300046013247582, 0.08154369334900573, 0.012192657994737309, 0.03917132812221685, 0.05088103950143822, 0.04601816233668116, 0.03647522722941734, 0.03491466399282217, 0.04689769639122871, 0.052853493740962404, 0.023213312548074513, 0.005941234497098072, 0.02104424950366299, 0.011586565618223, 0.05469825644526751, 0.036712201207035014, 0.10939590768107485, 0.21061767253183553, 62.699710861329116, 108.27156082276376, 102.83703850161646, 96.12270955116519, 57.725859149809814, 40.60277569678522, 49.74886040533743, 64.52479754724811, 111.34893478885775, 122.82600956578409, 102.97239949626308, 18.54843747231268, 0.1048836957723383, 0.2918681304060644, 0.1853449375278527, 0.16227973084295952, 0.21819296443173963, 0.08378493719764295, 0.07826485235484378, 0.06214923908813827, 0.1630460332718588, 0.8360620888490832, 95.60968706684729, 112.71297039524202, 108.07905873944684, 109.10614705854847, 94.05678933666599, 86.66127020312895, 80.4138288190288, 81.31429518422773, 79.05268792183169, 83.69654670838388, 76.96849730706985, 76.42211114206623, 72.42851072742094, 76.24373743610998, 73.39248026570966, 74.70022201538086, 71.51358650576684, 71.94732219942155, 70.70714719833867, 69.3455748404226, 69.52889073279597, 70.2349095190725, 70.85394582440777, 72.71927602829473, 73.35735936318675, 72.10624094932311, 72.70523394307783, 74.40773087163126, 71.50277645357194, 69.61090749309909, 65.83601843926215, 68.86049532121228, 72.50473022460938, 79.70070269800003, 84.68316401204756, 90.33968464020761, 91.92162359914472, 91.46505971108714, 90.67691433814265, 90.95845422437115, 88.80642229510893, 88.04309768061485, 87.33548641204835, 87.94943932564028, 85.96573198995283, 83.96563699168544, 69.71386186538204, 81.74698752741661, 85.43845561242874, 90.6107831770374, 63.59092827766173, 65.70232837430893, 85.83313234390752, 77.54152421028384, 84.02981481244488, 84.39384214339718, 85.9490462272398, 86.64833422630065, 85.1641328873173, 86.12448600030716, 84.61035697690903, 86.04128468421199, 87.18426335242488, 83.9104570881013, 69.5764769277265, 65.7330640669792, 65.7638232938705, 66.95294472479051, 68.66766375880088, 70.9364018901702, 65.05458816405266, 67.09455797749182, 66.70850261565178, 66.57005863804972, 63.458265873693655, 66.07176857609903, 68.12276809446274, 66.87011211149155, 65.3113425931623, 65.64269658057921, 64.96658978923675, 66.86928841375536, 63.51956859711678, 73.44715810591175, 80.52323156787504, 82.1014678093695, 80.21231312905589, 80.15028476715088, 79.34426123096098, 84.40274592368834, 88.52043444110502, 93.0646179568383, 90.3827993331417, 69.85783638492708, 5.59556552479344, 0.25700850983060175, 0.0814974063166207, 0.05612958447947618, 1.9370669222647146, 0.15881816255709819, 0.16164501167593465, 0.07263166995178308, 0.08489769522941883, 0.21467809174810687, 0.09891941016840358, 0.06844630945594081, 30.787303216995735, 43.4652312340275, 47.767059341553725, 34.65676061568722, 35.31869980596727, 35.847525519709436, 54.34973785954138, 66.60645038850846, 77.80082425763531, 80.54306307146626, 55.526386153313425, 3.93041372779877, 0.09536733625516777, 0.07339729056242975, 0.04814037144364369, 0.013268193729492206, 0.07194304883840584, 0.008577242974312076, 0.05578620471961557, 0.03740439995101864, 0.025341489479967186, 0.0871393068002597, 0.038378745047075134, 0.05591802929918613, 0.04509783026972606, 0.12197102645352004, 0.04702994231915763, 0.06194631005787562, 0.019774677104226524, 0.02949498646381882, 0.01042321609753755, 0.17324511502538958, 0.17289613133236287, 0.12907999297303538, 0.2071872687027339, 0.10745313168773729, 0.11092586187465538, 0.14512184346395154, 0.1745499006562656, 0.11080027708122808, 0.2385783342704658, 0.1494371860979065, 0.15761561902059665, 0.12199871287110353, 0.1393542279519381, 0.154707518616511, 0.23862768565454792, 0.8695828482027977, 84.89327753743818, 119.92951962255664, 118.87163285286196, 109.7634578520252, 67.36327171325684, 37.52033010605843, 92.2377666350334, 97.48370924303609, 122.62807107740834, 135.9670949751331, 115.654018463627, 27.5161406301683, 0.35500885197712534, 0.7468669008343451, 0.5277010353822862, 0.4988467014364658, 0.44639266126098176, 0.29852552639861263, 0.4381555919685672, 0.37977531011546817, 1.0486972692512697, 0.7846524410190121, 97.44442278339018, 119.10545318357407, 113.41636903824346, 118.33227557520713, 100.4830123532203, 92.3348060730965, 86.5177506785239, 84.89496415661228, 81.6408795695151, 88.99215436750843, 80.1146931802073, 80.15834916022517, 77.12259154165946, 83.19627977186634, 80.18740607846169, 79.48073617873654, 74.35759513608872, 78.11285664958339, 76.35620747843097, 74.36974663888255, 73.43211973867109, 75.54826198085662, 77.2313980902395, 75.48403709165513, 76.18877718525549, 76.26873077884798, 76.5557933622791, 76.72048584107431, 75.46889674278998, 74.68536407716813, 68.9001504836544, 71.39939846531038, 77.0436263853504, 84.49507851754466, 88.27090109548261, 93.7521545348629, 95.0110706206291, 97.83982907572101, 95.52981976539859, 96.16991135381885, 91.93230029075377, 92.68566208501016, 94.23677905913323, 93.27531983775478, 90.51881928597727, 89.25125829635128, 74.05410566637593, 87.88918387505316, 89.76869736948322, 94.07559317927208, 67.67313111212947, 69.41246694134128, 90.08896673879316, 84.12428902041528, 91.02434219852572, 86.88854802039363, 89.547758102417, 89.27862075067337, 86.34633525725334, 88.39019606190344, 90.38417216270201, 91.06668026216569, 92.32990311038111, 88.81837767939415, 72.41497855032645, 69.12386678880262, 69.08437636590773, 71.00759290879773, 72.61771801979312, 73.4152457021898, 69.84929346269178, 71.14108685524234, 70.61214739276518, 69.87561256654801, 67.607541238108, 69.55460579164567, 73.3130758039413, 70.25338388258412, 66.31992909216112, 70.05982275932067, 69.48259107528195, 71.64111060480919, 67.20982859211584, 79.3715452378796, 84.50657890688989, 87.16637734443911, 85.50407686541158, 86.33995748335316, 86.23448494941958, 88.97029107616794, 91.6219388284991, 98.09121378006475, 93.68354443580874, 73.77579781316942, 4.383704643095694, 0.7845342183305372, 0.20361843278571484, 0.16592241763587923, 3.091817358809133, 0.7142492059257723, 0.6222300952480686, 0.3239371531432675, 0.21766411861585033, 0.1569009049525184, 0.24334009165965745, 0.6263708311223215, 45.207814785741995, 58.29896842279742, 84.67034570632443, 79.14588343712592, 55.36180742325322, 32.72730358185307, 64.02785285826653, 78.54860059676632, 91.29715088875064, 95.11229915003624, 71.2510387359127, 7.1727319398233975, 0.13637442171813982, 0.26055220274194596, 0.16931370501556706, 0.1239573315627152, 0.15172676243368657, 0.05015819341004376, 0.1309635733524638, 0.0568255945108831, 0.12078879956877041, 0.25113080748386923, 0.0831129938183773, 0.11828753781775314, 0.2396480228391386, 0.21054703922521686, 0.14128003509775286, 0.15514409680279995, 0.16448175865075282, 0.14050032613017868, 0.22120154492797392], [0.008183748615274747, 0.058530672573514526, 0.03765139818912552, 0.03084804137958394, 0.04616547721408067, 0.04953030008642424, 0.009620066754700196, 0.06985712931641648, 0.04275200009766606, 0.014854106815501809, 0.03817348327908305, 0.0860085916675387, 0.06596449101644178, 0.061339043651617346, 0.08087751095093067, 0.31177342358616095, 13.826919678718815, 93.91022605280723, 94.67562952349263, 72.43988560092065, 60.02294817278462, 48.05062317079114, 29.774155001486506, 64.78951831017771, 81.86067350449102, 109.27990021244173, 106.23062610626222, 35.94938162834414, 0.5794388139920851, 0.12998452830699184, 0.2769236549014046, 0.11920787754558748, 0.03848667534428739, 0.24856429036346175, 0.21117881661461246, 0.34189612334293706, 0.6021003076626409, 1.100598439093559, 24.264425154655214, 123.76943372911023, 94.26169395446779, 105.33132076263429, 82.07641170870873, 81.53343016101469, 74.39064502716064, 79.55952875075802, 73.94747211087135, 77.74281240278675, 74.70305396664527, 76.29870553170481, 72.64821837025305, 69.32844192750993, 69.66071374954717, 69.08188958321848, 67.21199374045095, 69.4661484995196, 66.99138395247921, 67.64036363170993, 66.41821584393902, 67.57732329830047, 67.19231128692627, 67.54468133372646, 68.51236927893855, 66.54175481488629, 67.0118744142594, 70.53610047986432, 70.14541672122094, 68.63751642165646, 65.09854224420363, 65.05810260772705, 66.27965419523179, 76.3274565050679, 82.29340507138161, 85.65176194713962, 86.92314332531345, 89.7517684198195, 84.18215966993763, 82.46431842927011, 82.5798636098062, 80.60222025840514, 77.39321939406857, 78.38013479786535, 75.23424486960135, 83.39030373481013, 77.54784707100161, 69.69704274208316, 76.86220892014043, 81.94508291059925, 84.7411209537137, 72.71656959287583, 78.72167910298994, 80.13355193599578, 73.4660090169599, 73.26173197838568, 79.7307009850779, 73.0004942801691, 76.17701791947889, 79.13458701102965, 83.13965643605879, 85.87237173511137, 83.7869651855961, 74.75150308301373, 81.78819594844695, 70.34421813103461, 62.79162768394717, 63.96049007292717, 65.99273281712686, 72.07296356078118, 70.74751623215215, 73.88243921341436, 68.54332462433847, 65.69273033449727, 61.400009970511164, 59.6562457853748, 62.78076664094002, 61.227770851504424, 61.65332055860951, 64.13731444266536, 62.52978201835387, 64.86752248579457, 60.143372781815074, 60.55631991355651, 61.38301041818435, 71.40539184693368, 75.8046280953192, 73.65893471625544, 75.6790102681806, 72.53540315935689, 75.64179481998568, 84.64401875772785, 86.0460856653029, 83.55396070787984, 89.8139379870507, 40.55419714220109, 0.15346481675101867, 0.3043348324154654, 0.14917000527343444, 0.5076362120528375, 0.023945527894782926, 0.044513040883166176, 0.21577352087103555, 0.044244864144392555, 0.07046777033998121, 0.12569285012901793, 0.6354239679151966, 4.339758407685065, 35.92925594698998, 21.310590159508493, 85.10397941835465, 65.84716581529187, 25.631292712303903, 19.157175594760528, 44.686253301558956, 55.273848272139034, 59.09116168175975, 61.77112894673502, 22.15769267851307, 3.9927678915762135, 0.03505591145386139, 0.043092112492529616, 0.06872668231446898, 0.05240482285678868, 0.06348828800142774, 0.020129236002122203, 0.02561724091309213, 0.057237818762059176, 0.06864663378726091, 0.06295585306361318, 0.06607102320319222, 0.06317523000161014, 0.021643607967322873, 0.05625520757729969, 0.02287362341678912, 0.05616408141870653, 0.04822192916406259, 0.10733595853971858, 0.045911063244866754, 0.05150838507219188, 0.03863400171300577, 0.08487628307193519, 0.0777347578156379, 0.03881652982184484, 0.006747482186784187, 0.04265089564385914, 0.0189183957334007, 0.08072007988249102, 0.07597405027838484, 0.033647018304515275, 0.04213988052440747, 0.07489107774510499, 0.12241128186184554, 0.2827619496853121, 18.753799046239546, 110.17753462637626, 107.13698387145998, 86.38273485245244, 76.97970744102233, 61.6270955916374, 34.385905265808105, 62.934547085915845, 92.64261799473917, 118.30904729904668, 117.16321314534834, 43.26108363366897, 0.3565355732796654, 0.11833698879326544, 0.24038620984121678, 0.162056676682926, 0.01442846549194186, 0.3303658565686595, 0.10550221217976463, 0.34533273248422536, 0.6756879557524959, 1.0828793769882572, 29.444203261406194, 133.471918413716, 98.1311042847172, 112.08554806247835, 85.68674948907669, 86.97114529148226, 76.52100193885066, 84.33518701984038, 77.28551110913678, 81.65605129734163, 77.53815097193565, 80.03965823881089, 75.75118972409156, 72.73396922696021, 72.66096607331308, 73.55860833198794, 72.70357085812476, 72.95697950547742, 70.49721410197597, 70.13264548393988, 69.69154357910156, 71.51391598486131, 70.72827308408677, 70.75247410804995, 70.50702002740675, 70.37314168868527, 68.10961246490479, 72.72919178009033, 71.63895330121441, 72.06680543961065, 69.77107355671545, 66.58846239889822, 71.71093663861676, 82.42306293979769, 87.2510770059401, 90.91545720254221, 90.04612661177113, 89.9957633787586, 87.2868097982099, 84.01515299274077, 84.45875736974901, 84.7312601151005, 78.40662648600917, 80.9404540831043, 80.6164506173903, 87.57166800960418, 82.38985615391886, 72.86842023172687, 80.86515242053618, 85.89627465894146, 86.08098691509616, 76.56634453804263, 82.33526460586056, 83.24647826533165, 78.51009861115487, 77.51784878392374, 84.20791395248906, 77.40338617755522, 76.15801795836418, 82.29859828948975, 88.55329605840868, 88.66943743921097, 86.03409105731596, 78.86899548192179, 84.91944759122788, 75.7923589214202, 65.7432073162448, 68.58474485335812, 70.30086809589018, 74.97092047045308, 74.75286806783369, 79.1098133210213, 73.10634336163922, 71.81867630250993, 66.23270342426916, 63.61304652306342, 65.99330548317202, 64.92369082666212, 65.6902749307694, 67.42424103521532, 64.9612553658024, 67.7137041091919, 61.92418375322896, 65.61371810974615, 64.38360006578507, 75.60571685914071, 77.7196704187701, 78.33164645779517, 78.85132128192534, 76.0855717812815, 79.23111654097035, 89.48703196740921, 88.70966526769823, 90.82605069683444, 95.64638476217948, 53.17919669612762, 0.9605023469175062, 0.28417093859564874, 0.25972148764037317, 0.473986566066742, 0.12120681544465405, 0.024620587336680582, 0.24239863088775068, 0.08238317249643226, 0.4012846075479062, 0.19134398820179124, 0.6476740202596111, 3.8332218075952227, 44.41087545887117, 24.782362368799028, 57.04169581013342, 47.45189689820813, 28.948841248789144, 34.02258788385699, 60.04173632591002, 65.0586909632529, 73.26678399116763, 77.19845802553239, 33.77328988044493, 4.00728605447277, 0.0028773541834520838, 0.07838157351098715, 0.04635993714234041, 0.03656381380654151, 0.025850100998556422, 0.013727021981931984, 0.02425139998987077, 0.07339310006148393, 0.029341299650109107, 0.02328732813287887, 0.0563696802653853, 0.044920975041966286, 0.061878434667784366, 0.03246851843751727, 0.036072429690149524, 0.0327943969187477, 0.03182443193039827, 0.055037824917704835, 0.13234809341449894, 0.16211408731197158, 0.1545906135992658, 0.17719235241172776, 0.15583432670081818, 0.1531236471548196, 0.11450337756785656, 0.20948956209805705, 0.14875021973444572, 0.1888903158326303, 0.15538705392710625, 0.19329752773046496, 0.16354391381384867, 0.15957378572033298, 0.29805946914899734, 0.571907189103865, 31.820853640956265, 128.7496828263806, 120.48335829088767, 99.82230478717436, 85.41971452774541, 68.23381823878135, 45.843564310381495, 87.14119572793284, 106.55244088942005, 127.65751454137988, 124.60498486795734, 58.62919276760471, 0.776561817094203, 0.23141889021761958, 0.5830317050699265, 0.41707279100533456, 0.3519542142748833, 0.415165446578495, 0.8217272967580826, 0.4825625833003752, 1.104393209661207, 1.4516282610354887, 29.524172544479374, 137.06582930780226, 102.2438584604571, 116.95595510544317, 90.07582679871591, 91.50214179869621, 79.9096473570793, 87.79922823752128, 79.39934699766098, 87.34298598381781, 80.67947526131907, 84.98103664767358, 80.84016692253851, 75.55995064397013, 78.08456851590064, 75.6045558375697, 76.82143980456938, 75.7086947656447, 73.12545314911874, 75.03027377590057, 73.91047631540607, 75.03978944593861, 74.95854147018926, 76.15510755969633, 74.8662716342557, 74.03792196704497, 72.63232492631482, 78.50627822260704, 75.49434508046797, 74.22969448950984, 73.57047742412936, 72.69634585226737, 73.09440366683468, 85.74238438760081, 88.17385381267917, 93.56109588376938, 93.1175385752032, 95.83064202339419, 90.93382173968901, 87.70753106763287, 88.5236115609446, 87.7781572649556, 84.69578619926207, 85.74848759558894, 85.89166195161881, 92.62812875932264, 87.16579683365362, 76.89949497099846, 84.53085053351619, 87.16084680249615, 85.73108796150454, 76.22253310295844, 83.6463874386203, 88.7572749968498, 81.07873332115912, 82.97949821718278, 88.27785938016831, 80.93357424582206, 80.27312555620748, 84.16507382546702, 90.89392339029621, 92.60996034068447, 90.88440772025817, 82.09821224212646, 88.83744824317195, 80.4249369713568, 68.37543149148264, 71.94431766386955, 73.48911177727484, 78.49203217414119, 77.16449814458048, 79.7915683254119, 75.25901071486935, 73.95885482911142, 69.41808377542804, 67.49666367807697, 68.99002767378285, 66.17785299977949, 67.02433186192667, 70.19157517340876, 66.87624669844105, 73.08609608680972, 66.7228114220404, 68.89628302666449, 68.93139608444707, 81.9283422347038, 84.35454783901092, 81.04943321597192, 82.3577319422076, 81.33200860792591, 82.54802965348767, 92.68718396463703, 92.78362720243393, 94.31856832196637, 100.2316354936169, 51.400205704473684, 1.364066985345656, 0.43964293635179924, 0.47794678098251747, 1.9802476826214024, 0.47538648449605514, 0.4531117120096761, 0.41970194347443124, 0.32561712267418064, 0.32536416044158323, 0.2898399585918073, 0.8615881384861085, 7.648644879941018, 60.124102177158484, 35.05751702093309, 112.54970565918954, 87.49285190336167, 37.7001315547574, 32.79978309908221, 70.219510293776, 81.12522909718176, 87.30862602110832, 92.02827284413, 49.27524597414079, 5.069836032006049, 0.18726697552107996, 0.18917612791542085, 0.1486846426081273, 0.11372384480050496, 0.1506324211556104, 0.11128600746873887, 0.17509828171422406, 0.13202603005113142, 0.13529103549738086, 0.16076528226896641, 0.2655591082669074, 0.1407276244173127, 0.14399151137519267, 0.1378952901089384, 0.07991122893027722, 0.18913388582727603, 0.13357078506340905, 0.30918070625874305], [0.025995964139339425, 0.02714682738446901, 0.06934170536096058, 0.015150771491349706, 0.0381734564660057, 0.03887059647710093, 0.010674051478535179, 0.029133718550926255, 0.06379452781871923, 0.035394066494078405, 0.08437153838214376, 0.04734873448708846, 0.0492970914309544, 0.01594206370833901, 0.04823327492622118, 0.5361047747635073, 49.64957737153577, 97.95253446025234, 72.3332755796371, 71.2053745023666, 50.048384358806, 47.06835577564855, 71.6020751768543, 69.86432398519209, 95.53740562931185, 117.65543922301262, 67.0228805849629, 4.773739249475541, 0.25246272794902325, 0.022326922006604653, 0.04896045324482745, 0.040060809828461184, 0.1492629930256836, 0.04296381574785037, 0.1366685075505126, 0.10541561360080397, 0.12340854447815688, 0.7590160134338564, 83.1710667763987, 111.56635961224957, 95.23286496439289, 90.73709134132632, 77.6530215048021, 78.37463563488376, 77.56961622545796, 86.33468581784157, 85.85159101793843, 83.68418339760073, 75.25161312472436, 73.37462563668528, 70.83547930563651, 72.55941590955182, 70.93520948963781, 74.09204283068257, 66.92825732692596, 71.33710338223365, 67.99795827557965, 70.05574349434146, 68.92527718697825, 70.1272875262845, 65.10197824047458, 63.256506996770064, 65.35925826718731, 67.34200462218254, 64.0432167822315, 68.98179854116133, 72.55957280435871, 67.791531778151, 63.356805924446356, 65.54069142187795, 69.08520006364392, 79.91010235201928, 85.49934648698377, 83.87262190541914, 80.97246062371039, 84.18265388857934, 82.28599179175593, 85.7773248610958, 81.5561406843124, 83.16261799104753, 77.76739781902683, 75.49449413053452, 75.56505756993448, 83.4775843158845, 71.86304615389916, 69.86509276974586, 79.14594619504868, 79.63537170040993, 92.28721987816596, 93.12792501141949, 81.29040794987833, 77.28049047531621, 72.75789568501135, 73.97125736359628, 77.06864326230942, 73.99588200353807, 75.99869912670505, 77.76873142488542, 81.30204169980942, 81.43462565637405, 83.38445940325337, 79.3583111609182, 80.98581237177696, 69.39174898209112, 58.84210686529837, 62.825830751849765, 67.35349716678743, 73.88685580222838, 79.16459314284786, 80.88551736647084, 79.82563803272863, 76.91447058031636, 69.59266847179782, 68.21084099431192, 61.46386615691647, 62.221954407230506, 62.34503053849744, 64.7827482992603, 64.15943268806704, 64.50370696283156, 61.931942201429806, 63.76101793781404, 61.234011342448575, 62.09146107396772, 68.30034948164418, 72.566021180922, 73.51691353705623, 73.83868909651234, 70.93116944836032, 79.06860489999094, 80.59210054336056, 84.24837712318667, 83.14100573139807, 100.84376058270855, 16.160644619695603, 0.4059901953704896, 0.21253765740942573, 0.10208044982244892, 0.10464203333662403, 0.12123873832845881, 0.07517876674331005, 0.1650108189712609, 0.24431329911514638, 0.19677850868432753, 0.16567385274796717, 0.5500712930675477, 17.181442437633393, 28.50213819934476, 38.000687091581284, 78.14283140244024, 50.99358927819037, 20.493295692628433, 26.99082151536019, 65.21477383951988, 54.445820239282426, 69.2952194521504, 54.3741036230518, 22.147961278115552, 1.5695758933021178, 0.02792926745549325, 0.061995669102837006, 0.04468279830630749, 0.045127520007231546, 0.07118573262085838, 0.06889210367995886, 0.026513448871311643, 0.017554761143401265, 0.051465311778649214, 0.039866591217897596, 0.04602409951809434, 0.06502450879422889, 0.028811714559372877, 0.03578853665760929, 0.00830201056575583, 0.11718533647757386, 0.05527423199025854, 0.033044509304266785, 0.06980596996483303, 0.04799157418611069, 0.0479454710148275, 0.061130690718850786, 0.051761056191378066, 0.10006424430156909, 0.0646369449133354, 0.016322589156428174, 0.06700157488305723, 0.09106498647240863, 0.025716261607745004, 0.02260205099329112, 0.04978231620043517, 0.08633086187464577, 0.5612569734934838, 62.02726364135743, 109.836453160932, 84.47094025150423, 84.99519640399565, 59.74538556991085, 58.037232583568944, 57.80600493954074, 54.0581920070033, 105.22151008729013, 127.98587968272548, 76.23622217485982, 5.543643639933679, 0.24275959619591314, 0.15378122638550498, 0.02246926880381521, 0.09439841123117555, 0.30083871356421904, 0.4099580098784739, 0.2338053000670287, 0.34338855454998635, 0.22736617784586646, 1.7749558533391647, 94.17530767379269, 115.22000820406022, 102.35446929931642, 94.2871815158475, 81.59683135248001, 82.22381437978437, 83.12499461635467, 91.08841019292032, 90.63673357809745, 91.22323774522351, 81.83318553432342, 77.16607493738975, 74.90579343611195, 78.97955140759869, 76.11726453227382, 78.36229585832166, 72.78355583067864, 76.57514633670931, 72.01839554694392, 74.73228346916937, 72.90861668125277, 72.64143266985494, 69.92624252073227, 68.56900830422678, 70.09082517316266, 70.81933483000725, 66.03452959368306, 71.80512059119441, 74.71941025026383, 70.08112907409668, 67.48342175637522, 68.08250888701409, 72.4816745327365, 84.8306921989687, 89.50769501347696, 86.99861757216915, 82.82724749657416, 85.93088565334197, 86.15306438938265, 86.51074532539614, 86.06517191856139, 88.04919304386263, 81.19278015628939, 79.48755325809603, 79.76995606576243, 86.52570524523335, 74.66735255333685, 74.24150866846885, 82.63491799754482, 82.77985742015224, 93.8961055201869, 92.19177292239283, 85.73120563260971, 79.21424250448905, 76.03834644440683, 78.95349118017381, 81.40184248647383, 77.09666467482045, 79.64871560373615, 78.91411058364376, 85.5522043474259, 83.14404949065178, 84.79693628126576, 82.26042578297277, 82.3922017312819, 71.20870851701306, 63.30475214988955, 65.08307241624402, 70.64465599675333, 77.10485458374023, 80.8694984066871, 83.44421279045844, 85.06991755577826, 83.44778999205559, 74.77990104306129, 71.38985926105131, 64.66595972737959, 65.60775610708421, 66.12573254492976, 65.66030802265291, 65.93927875641855, 66.57675804630404, 65.63538920494818, 66.86192220257175, 65.4013531438766, 64.74771761125135, 71.22704167519846, 76.73477111324188, 77.92594786613219, 76.84523290203464, 72.96658931239959, 81.23512606466971, 85.77646978439824, 88.89928048656833, 88.42054736229682, 105.7494140440418, 23.87511814794233, 0.6312437019040508, 0.21080522617745787, 0.15172786560029755, 0.17706283758724892, 0.4181108707862516, 0.025415399727681955, 0.268825002375149, 0.1669607578866905, 0.5360021189816537, 0.06728275979478514, 0.6148944050073624, 17.003290345591886, 36.377841734117084, 36.890044443068966, 54.078223551473315, 33.7723014431615, 28.016823337924098, 34.24342516929873, 76.78832715557468, 69.4737578976539, 81.65936962250741, 72.7058458328247, 29.730863801894653, 1.7966855389456597, 0.03018993163301099, 0.0790380342533031, 0.042291359089675455, 0.02272042115369151, 0.021131527985656456, 0.06291973201798336, 0.02386897847416901, 0.042933348431101734, 0.007941970308761924, 0.026737638756692893, 0.019232185347185984, 0.027630405064912576, 0.09981167277381306, 0.042016417794530435, 0.05073652084496233, 0.0161195318064382, 0.03196543998896115, 0.16371548686537052, 0.22462381290331965, 0.1603950932621956, 0.22105572775246637, 0.18798538213295324, 0.16013549670817392, 0.1760297526995982, 0.17013574800183698, 0.09968077133019125, 0.115159033917852, 0.13547745533287525, 0.12422190002736547, 0.12554828167682694, 0.14696388655612547, 0.24960462244287615, 1.3011565804481506, 83.52664532199984, 122.54743499140586, 97.45888063984533, 94.59280475493401, 73.1106658135691, 63.100635928492395, 91.7376801275438, 89.64471124833631, 121.0782955538842, 136.34877297186083, 93.32257655359085, 8.183042320512957, 0.3420365319376992, 0.6523310381077951, 0.17422501808933674, 0.45825868905071293, 0.5233150900852296, 0.6762517964647663, 0.5400268385006536, 0.9308905971627083, 0.3856294782411668, 2.1981482159706855, 91.94187087397422, 121.22946370032527, 105.49049838896721, 97.07149951688706, 87.2585451987482, 85.33071594853556, 85.83597213991227, 94.11719383731966, 94.8470449447632, 94.65499785638626, 84.5905254733178, 80.98181939894154, 78.97720583023565, 80.97042099122079, 80.38419923474713, 84.20503493278258, 76.0080579019362, 80.34094333648682, 77.17606129184847, 79.33044664321407, 78.02693320858863, 78.69925883508499, 73.81672382354736, 71.69685532969814, 73.01349301492014, 73.16805008919009, 70.70506049740699, 76.00131926998016, 79.26411936360022, 75.38189072762766, 70.97739850321125, 72.01555575093916, 75.53947587167063, 87.00107297589703, 92.34250176337459, 88.03562948780676, 87.31791419367637, 90.64613157703032, 91.92913101565455, 91.27102790340301, 89.23420383084206, 90.64802215945338, 84.90589187991235, 83.73341698800364, 84.16721543958111, 90.73623626462876, 80.53980750422325, 75.88357756214758, 89.08049398852934, 84.95700036325763, 87.81185826947613, 87.99360521378057, 83.97147347850185, 85.5307960510254, 81.17534129850327, 84.21896719163465, 84.72225435318487, 78.53689624417213, 82.03649766983526, 82.7740680017779, 90.41341735470681, 87.06736887654951, 90.9666519780313, 87.58621215820314, 87.84244491207986, 76.84586832600256, 66.79601069419616, 68.22031744064824, 74.12521039285969, 79.00733747789937, 86.0000370394799, 86.49752693791544, 87.64634993768509, 84.98955603568785, 77.15780658106651, 74.46990828360282, 68.05975914001465, 67.04390448908653, 66.03060722351074, 71.25168200462096, 69.48212039086127, 71.02454539268248, 69.33791837384625, 70.85049413865613, 71.06267867549774, 67.94290388784101, 77.1532330974456, 82.12468824078961, 83.11485136708906, 81.16588054164764, 80.3343302203763, 87.03297753487864, 89.27749110806374, 93.89033179129325, 92.51985565308603, 109.30044558740433, 20.48191885794363, 1.5839589795758648, 0.6353015777084136, 0.4226735066021643, 0.3038569774118162, 0.6445972885816329, 0.3662703138205313, 0.426924099484759, 0.9541069223515449, 0.5545462884249226, 0.41344141167017723, 0.7402015068838674, 26.60667830897916, 46.67766417226484, 55.18825431023875, 102.39852536109187, 71.56451456008419, 31.66470800676654, 43.46407021245649, 93.06016214432256, 83.48218133372646, 96.09673561588411, 88.21954942518666, 41.62247819285239, 2.8401382315543393, 0.14732586310034798, 0.17405670857237232, 0.13755782837829283, 0.15022758965290364, 0.09850064352635415, 0.20565064954421214, 0.23040379307443098, 0.08983431984820674, 0.14430421314412548, 0.16473973109837503, 0.15576033792909116, 0.14839055677575452, 0.3579933466690202, 0.08979138828093007, 0.17337841432421439, 0.302162207062206, 0.09139777506671606], [0.04854435258875451, 0.0021728901323982545, 0.11555161567464953, 0.029977830615074887, 0.1336846716942326, 0.039156171072634964, 0.011554235750208459, 0.06923463691266314, 0.15718994992634944, 0.025878197273179412, 0.07303078643857472, 0.016957976735166965, 0.07567119273927904, 0.12855598883282754, 0.10283946675518829, 5.923169236029349, 77.3241307658534, 93.35666979512861, 77.3941921418713, 46.894139782074966, 50.345688250757036, 72.23849542679326, 85.62187348642658, 90.3389629240959, 109.9783645137664, 89.74816768400132, 24.05777704331183, 0.0367502298115963, 0.10225394575466072, 0.11206997588517205, 0.13199944680015888, 0.20346041949045277, 0.13267847649272413, 0.12869186218707793, 0.3558631625867659, 0.2940658221562063, 0.3623509467128785, 20.352933676012103, 112.97336086150139, 94.83952183877268, 95.20476510447841, 74.68364607903266, 80.6822915231028, 81.43124457328551, 93.74864793592884, 91.68257082662275, 96.75985151721586, 93.73036969092585, 89.70110708667387, 81.4316289655624, 74.7114086151123, 77.08186949453047, 79.6617849411503, 81.40660424386301, 82.2914360415551, 74.53575703405565, 76.94687720268004, 73.16036224365234, 67.71243326125607, 69.26794328997212, 65.4880492917953, 63.46164695678219, 63.93603409490278, 63.394550892614554, 61.95748467599193, 67.52418302720594, 68.24033721800774, 64.07006148369082, 65.27889282472673, 64.38309015766268, 72.69127815000473, 80.67475272763161, 81.74585788480698, 86.17659861041655, 84.61635820327267, 79.50200326981084, 81.98004691831528, 80.58450683470696, 80.52832280435871, 81.67155250426262, 81.46311775330575, 74.84058795436736, 72.16336634851271, 75.52318234597483, 65.35228037065076, 72.98668753716254, 79.4751036551691, 70.15976475131127, 85.82421287413567, 92.66407335958174, 79.61826232171829, 72.79165944745465, 70.93285606753442, 74.16328091775218, 75.51594949537709, 74.53051674750544, 83.92979437305083, 71.98883656532534, 74.57456496454056, 73.31531939967986, 76.40551951623733, 72.27308288697274, 66.71020492430657, 59.66933473463982, 56.974262422130955, 59.13070309546686, 65.16565007548179, 71.67133638935705, 76.32220052903699, 77.22236879410283, 79.84012726814517, 80.21782013677782, 80.41984573487314, 68.86569638406077, 66.71518633442541, 59.66301971866239, 63.02784850520473, 62.301327490037494, 64.15487489392682, 66.97418828164378, 67.11325983847341, 61.33044673550514, 61.98309775321715, 58.393199443817146, 60.428984088282434, 63.39010292483915, 71.46851062774658, 72.86700033372449, 68.42260975991526, 73.61963256712883, 76.82266358406314, 85.62257166831725, 85.1600222433767, 93.83045288824266, 82.87528084170434, 2.4561325532774774, 0.1719863099917289, 0.08877731769556, 0.06293234948609626, 0.028567119922128417, 0.18451612232433212, 0.08808856634723564, 0.4327298508536431, 0.5890952603470895, 0.1843708107668546, 0.07502892760620003, 0.051989105244677876, 27.115033172792007, 26.537191560191495, 88.82007998804893, 76.72903660804995, 34.74628479250016, 26.443439068332797, 32.420003529517885, 56.425365940217056, 56.442679282157656, 66.50925405563848, 58.88027937181535, 34.10957820953862, 2.7644825750781647, 0.06543720035903877, 0.08405221761354516, 0.059298078169024764, 0.0415833329691762, 0.039387357255984703, 0.07887359348035629, 0.08098628777529925, 0.07115518103443808, 0.0029936954078655094, 0.03994732156335827, 0.06739652385154078, 0.05807317252601347, 0.1793852024861882, 0.048414228724375855, 0.02626326179221994, 0.05288941943417153, 0.04093272513860176, 0.014555638960202136, 0.0724968001727135, 0.007274392194249818, 0.037597660951676874, 0.04151936079705915, 0.01850836057846825, 0.024911470921529878, 0.04783287141171675, 0.049598217611351324, 0.05436970814762097, 0.022086211435136296, 0.09046844146665066, 0.12298885853059831, 0.14985968358814716, 7.1462618247155225, 89.98129767756309, 104.96555189932548, 85.42155019698605, 62.418461230493364, 59.07147138349472, 66.36283982184626, 60.02970641659152, 80.98371782610494, 124.54331736410819, 98.52257251739503, 30.092922103020456, 0.0690512890897451, 0.005572116577006396, 0.15618983746295975, 0.3070560380095436, 0.4792406728431102, 0.1288467038783335, 0.2509337237044688, 0.49333620035359943, 0.5862299689362126, 0.4798989875182029, 27.485877583103797, 118.4523863946238, 101.76373681714459, 101.80331353218325, 77.96729749248874, 84.72575310737857, 87.71496003673923, 98.1088722905805, 99.20568466186525, 101.24523870406613, 98.54577725933444, 94.72658895677137, 86.28880193156581, 80.68400167649793, 82.06627630418348, 84.59433017238494, 86.12949878938737, 86.93389846432595, 79.2373295753233, 79.42636428340789, 77.4531610550419, 71.82548553712907, 71.44432529326409, 68.73279079314202, 67.2753635529549, 68.79702352708387, 66.55376511235391, 66.06061335532897, 70.69940443961852, 69.82087196842318, 67.88021656774706, 68.2147398302632, 68.984340237033, 79.34674016890988, 85.98268447383758, 85.00386484207647, 88.63040201125607, 88.1150810180172, 84.91958879655408, 85.39732563880183, 83.1506076935799, 84.54795206746748, 87.11949717613959, 85.17357795469223, 79.45073789165866, 75.45394466769311, 78.6434042838312, 67.13004758281093, 76.8382824620893, 83.99862412483462, 76.15899070616692, 91.75132997574346, 92.22863535727225, 87.43231404212214, 76.04103719034504, 77.36594323189028, 80.11855279245685, 76.88165603145477, 79.88918042952015, 86.96262590346798, 77.037107406124, 80.27788731359666, 77.88616718784456, 77.63520609947943, 72.06905688008955, 70.1559914312055, 61.509079317892756, 60.89750728299541, 62.29083122745637, 69.04031245939194, 75.74445109213553, 80.38876487362771, 82.93621878470145, 82.8649571634108, 83.4583019441174, 83.319622624305, 74.06617872176632, 70.88084543904951, 63.74522255313013, 65.56850102639967, 65.14102935791016, 65.33565736586048, 67.9787935749177, 68.63013452099216, 62.3732598366276, 63.40888715559437, 60.75360336611348, 64.46633069745957, 66.16214782960954, 73.29409937704764, 72.97146874089395, 70.61362220394996, 76.33117491199125, 79.98927147157731, 86.8573102643413, 89.39795494079591, 91.78859249238046, 91.40019939791773, 5.138481922688023, 0.385019181957168, 0.1649533164116644, 0.24678817679805143, 0.17071506369017786, 0.1787736191744766, 0.14993063865169404, 0.5434959910569653, 1.0310855820294351, 0.49582479101034904, 0.09019464164251283, 0.11075200588111916, 31.165953143950436, 34.0224309890501, 73.4628083628993, 60.33096405767626, 30.877980570639338, 35.927679154180716, 49.362628536839644, 67.41907919606855, 67.32251044242614, 76.73036236916819, 73.80311319904943, 40.05740542565623, 2.841504196966848, 0.026165855627867485, 0.09853053627715957, 0.04449821325139173, 0.032052835299363064, 0.04701159068293149, 0.05265205092127285, 0.05801701445072409, 0.029000522673971234, 0.03762194210843694, 0.041565647829444184, 0.08579783321868989, 0.028942843914152156, 0.05482233970636322, 0.051951976793427626, 0.06205867217372983, 0.04993299037338265, 0.24489986199525096, 0.12318027325935903, 0.1887040951799962, 0.10961461046169843, 0.25924111986833237, 0.208132115583266, 0.16374571669486263, 0.19047073989866242, 0.19306469828851763, 0.1251047244295478, 0.2546100877225399, 0.15336006188825255, 0.2672145016972096, 0.32993516193762906, 0.42624831800499274, 12.827086929352054, 107.84854104441982, 115.64636984179097, 102.49733771047285, 66.02328023602887, 72.9607214466218, 89.17839634803035, 106.5950378294914, 112.78114118883687, 126.94966793060304, 110.87708934660881, 37.56759466663484, 0.33481198573304766, 0.23149451841750454, 0.46147334719857863, 0.41113386291169357, 0.8181272350972699, 0.3244754371623839, 0.3803500292762634, 0.6164494409195839, 1.0387654602527618, 0.4900431560893213, 26.86586460759563, 121.70596891833891, 103.74250981115527, 104.57653122563516, 82.9112175972231, 87.71067680851107, 90.23039171772619, 100.79191469377088, 99.31691523521178, 105.4284857165429, 104.17296640334591, 99.22397075160858, 89.29171362230855, 83.12002105097618, 86.65081316424956, 87.38323734652612, 89.93095797877159, 89.86769014789213, 81.93854039715183, 84.93165400720413, 81.90057185388382, 75.2207205372472, 74.55674955921789, 72.65745947437902, 67.81745080024966, 71.9395088380383, 70.39374197683027, 69.79452148560556, 74.54063646255001, 74.49699617201283, 69.89019593884869, 74.65935091818534, 72.66124848396548, 81.97523024774368, 88.25613729415402, 87.72894720877372, 93.06234298213836, 94.15930440348964, 88.44172816122733, 89.54966437432074, 86.45152538053452, 89.33479693628128, 90.48034867932721, 89.82277116467877, 83.30904791432043, 79.3649870349515, 83.22175948850571, 71.95970119968538, 78.79037549418788, 87.54944386020784, 76.73942304426625, 79.24484483657345, 84.75543760484265, 82.73151813014861, 81.79819799238636, 80.44886342940792, 83.99501554427609, 81.28238278050577, 81.09897275124827, 91.16193894417056, 80.04528291763799, 82.1543021355906, 79.0753278424663, 83.2075212847802, 78.73192433388003, 73.73823719639933, 65.2452898794605, 63.33094966027045, 66.232358255694, 72.61223454629221, 80.27706361586048, 83.90139641300325, 85.52315527392973, 85.46970905796175, 85.983900408591, 88.24043212398406, 76.30840947551113, 74.9744035351661, 67.08228880359282, 70.16377341362738, 67.61252264822683, 70.11577929219892, 70.98470980121245, 72.10042799672773, 64.44037637402936, 69.59097400788339, 65.11025444153817, 69.0219557669855, 72.35091055593183, 78.08256810711276, 79.5895819510183, 74.46247931449645, 81.54807629123812, 84.38426371543639, 97.00856116510208, 93.4439346867223, 99.28424189167639, 92.82622414250528, 4.247808244920546, 0.6313158367430011, 0.30057904040140493, 0.25880150797386325, 0.3698473928436157, 0.3210870609168084, 0.2857669755335777, 1.8628594784005996, 1.8840696951073987, 0.2435883194688828, 0.11338976151760548, 0.39953372891872163, 43.286739856966086, 45.4668834132533, 109.30174781430154, 102.69538602521344, 50.9164950924535, 39.512168515113096, 56.255268435324396, 82.90394552292364, 79.20082799849972, 89.07959184338971, 87.74044759811895, 51.8090461146447, 5.200860356130908, 0.15801734020633085, 0.2184211820243828, 0.12754011794083542, 0.09702795440511358, 0.148674315742908, 0.2174879796802998, 0.2087040615057753, 0.149535674361452, 0.08431738362677636, 0.12887796026564416, 0.22897689302842464, 0.13995652627800742, 0.21171495558754092, 0.13432907421262036, 0.17164506378673738, 0.14938126167943402], [0.01211021448515596, 0.04539641303821437, 0.09916170845709502, 0.02438745912044279, 0.15029688996653404, 0.034617766617767276, 0.08315821598854758, 0.0429721431235873, 0.07295919552205071, 0.011303834166497955, 0.01017967195835926, 0.06651553039949748, 0.1208341136694916, 0.14432526524028472, 0.5565424684074618, 25.34761513433149, 90.88012449202999, 80.82304185436618, 61.71146185167375, 47.17583264074018, 61.01876343450239, 60.82363728554019, 95.89108574774959, 94.76261200443392, 102.25429980985581, 65.60173134649953, 3.983494673044451, 0.10583235010985406, 0.05752094570667513, 0.14374642452645686, 0.1113266024678465, 0.13187820572526227, 0.1663061663989098, 0.10017178006350033, 0.4246685221310585, 0.45680811688784634, 1.5460788122107907, 68.53085933193084, 110.84090940413937, 96.71687018486762, 81.76728971542852, 81.47062516981556, 91.40811474092546, 93.02977162022745, 96.89479674062422, 97.20509544495614, 98.37779783433484, 95.00200994553106, 93.56801494475334, 89.72895591489731, 84.03853031896776, 85.740431047255, 86.6019953450849, 89.79324356202157, 86.84736313358431, 85.66006168242424, 80.98728718296175, 77.79286969092585, 71.80493231742614, 67.00557508776265, 61.23597644990491, 60.7086020131265, 60.91424795889086, 57.61717811707528, 58.43256827323668, 62.44341927189981, 64.81446458447364, 61.03602186326058, 61.45255796370968, 65.76879293687882, 73.55110091547813, 83.53452144130584, 82.92974687391713, 82.03095143841159, 84.40794698653683, 78.8840966070852, 82.52236950782039, 83.93320683510073, 80.86099470815351, 80.64927301099225, 84.78308246981713, 74.22636047486337, 71.7992291911956, 65.53137971508887, 68.28873926593413, 77.53045528165757, 77.17250762447235, 61.96923217465801, 75.08054287202897, 86.88419418950235, 67.28337303284677, 69.15258638320431, 72.07627404120662, 75.1298313756143, 78.78644527927523, 76.48543388612809, 71.247312484249, 71.31230615800428, 70.38006074966924, 66.08412404214182, 63.97643058530746, 61.594971379926136, 60.53916346642279, 60.31033631294005, 57.92732384897048, 59.7890180157077, 57.57042738699145, 62.78143344386932, 73.34261125133884, 75.94746512751426, 75.74434911051105, 74.35947787377143, 80.27830308483493, 71.89810429849933, 63.08489937936107, 57.60346158858269, 59.4734162669028, 60.44514425339238, 59.81967918334469, 67.9504583727929, 64.58879493897962, 60.26544478631789, 63.94911912179763, 59.90339040756226, 57.41580755479875, 58.6850747754497, 60.60992302433137, 64.5459940356593, 67.34589561339348, 70.13745430977114, 75.45996158353745, 75.49923235370268, 83.59556921066778, 83.67002364127868, 100.15442755914505, 44.4855809211731, 0.2083637805715684, 0.460393408373479, 0.077905266004945, 0.263836820039057, 0.20236664511744054, 0.35784438853302314, 0.4091866512692744, 0.4979856186095746, 0.6184785933263841, 0.0171464056362428, 0.55565852551691, 6.284594074372323, 31.496279470382202, 51.838738456849136, 103.78247876321117, 73.02938645885837, 24.266288280487064, 20.932340314311368, 35.91644156363703, 59.57759441867952, 64.57440768518757, 68.46401429945423, 60.42687385312973, 37.39226079756214, 3.4548336988495243, 0.07897349134568246, 0.04714772067663651, 0.042900218958816225, 0.05375073208744007, 0.04593998306400834, 0.02307861322356809, 0.03282887853621956, 0.10274546010599983, 0.03751912544811926, 0.06963657260301613, 0.07807779666637221, 0.11198603563130864, 0.012249820602817402, 0.06203170587879516, 0.031122210841145248, 0.031855175038799644, 0.016718467006519917, 0.059621474525380525, 0.03519548501278605, 0.09704632519353783, 0.04569571592935151, 0.04701691882444486, 0.0060383203409371845, 0.07843556738789044, 0.05806402926663718, 0.05940025514592567, 0.0829298528391988, 0.11259323692009335, 0.08339285339799621, 0.5470528453588486, 33.09510423291114, 104.81625080108644, 88.66048659047773, 72.96088618616905, 50.31164600003151, 60.102493839879195, 62.6622090801116, 83.98657460366526, 103.81607778610723, 111.42229880056074, 76.717724492473, 4.873160056529507, 0.32051715278817766, 0.3399190955585049, 0.045912982295117075, 0.1737394715629278, 0.3882024611436552, 0.7172856107354165, 0.6661736340292039, 0.662368260804684, 0.6252416175219321, 2.858773167094877, 75.12687390850436, 115.3448494019047, 100.91006432810138, 87.11542575590073, 86.0045712993991, 97.41891168778943, 97.08452178585915, 105.53286783156857, 102.24068134061753, 100.72470880323841, 100.06386787660661, 101.08606892247354, 91.68961540345224, 89.07371613287157, 89.90647454415598, 93.1996573171308, 94.67792803241362, 91.840116746964, 92.75595095849808, 85.5469326819143, 78.16753448978548, 73.44084308993432, 69.25379137839042, 65.18365375457272, 65.9679905060799, 63.61945175355481, 63.72774054927211, 63.537709559163744, 67.15966147761192, 66.70013227770406, 63.63491765914425, 64.89738348991641, 68.88894819444226, 77.05917466071345, 86.57502512778007, 85.74993887255269, 84.24228960467924, 86.68576148248489, 83.48169495982509, 85.7879937079645, 85.95667131485479, 83.7837488420548, 84.91895337258616, 88.78567295689737, 82.42328259252733, 76.95563977764499, 69.27278349476477, 71.36222224081718, 83.78595321409165, 78.69281045852169, 66.68007327664283, 82.294142476974, 91.85418236640193, 78.28209907777848, 73.94152579769012, 77.33696476105722, 75.00575111758324, 80.63960829088765, 78.55981857545915, 75.42639393960276, 75.48548836861887, 74.83706566595262, 69.87848374151415, 67.37073990606493, 64.14648102175805, 62.739966146407596, 63.49250032055763, 61.078352082160215, 62.38047699774466, 60.33752618297454, 63.4698917788844, 77.07444837016445, 79.9609362694525, 79.43637417208764, 79.21633705016106, 81.8052347244755, 76.58834118996897, 68.8834882551624, 63.82452503327401, 63.7348831853559, 64.47137094313099, 64.20321810630061, 67.59957098191785, 64.4825065520502, 62.74803838422222, 66.76001118075463, 63.0499549834959, 62.14434246863089, 63.126217626756244, 64.29423670614919, 67.27410839449975, 70.01786124321723, 73.7281959287582, 78.5132678862541, 80.93517457285236, 85.98863863175916, 87.57718286206646, 99.36993783520114, 55.818802772029755, 0.0426305215355129, 0.041997254105104555, 0.30289682409455704, 0.3074443220130859, 0.7615618768238253, 0.423316897884492, 0.812534302953751, 1.4364225801921662, 1.5460660645077307, 0.4147570910713365, 0.6205119745385262, 5.935707582581428, 39.1718715237033, 57.98597897252729, 88.24146762970956, 54.47320230545537, 32.636812540792654, 32.13077187538147, 52.80742660645516, 70.88311256900911, 76.20419994477304, 75.29020140247961, 72.74619133241715, 45.60513519471692, 3.768995692653041, 0.023054491030052308, 0.07901515886788407, 0.03291692119091749, 0.042013870552182205, 0.05125153877381837, 0.007880776641785258, 0.048135560411479206, 0.07097571727729614, 0.03204122332165078, 0.08674354577857642, 0.04467690325973015, 0.08450865279883148, 0.05500648426072252, 0.0637878092276233, 0.09150868161551415, 0.11972742305407602, 0.11630847990032166, 0.20577841768822364, 0.15241371347538887, 0.3536034483582743, 0.2025880598493161, 0.2878670676821663, 0.1510632996477427, 0.23684895206843656, 0.11719424608013324, 0.24711263035574269, 0.13753417158319106, 0.2282678633327446, 0.2155983012409941, 0.7478938876621185, 45.349992859748106, 118.38736134190714, 101.6227746778919, 86.86353898817494, 65.39134717756703, 76.91571004929082, 76.4975461652202, 122.86251114260767, 115.28774753693612, 118.88198791011688, 94.23027576938753, 7.1862709810656895, 0.4287518014109904, 0.17875535563836176, 0.5749011219989869, 0.3452049183749384, 0.9666319083302253, 0.8310499126392027, 0.8059833318956438, 1.462820254025921, 2.1522376085481336, 2.7441316025872386, 75.58241013557681, 120.11212164355864, 107.51533569828158, 92.83781866873466, 87.93575809847924, 101.60164094740345, 102.21683332996984, 107.0954381265948, 105.30211479433122, 107.59862330652054, 101.67520892235541, 106.69365406036378, 99.24013876145887, 94.19284066846295, 93.52063271307176, 95.98298688088694, 98.1262013220018, 97.87187484002884, 94.12915706634523, 91.1786090174029, 84.91561935793969, 78.1927239510321, 74.41296331344113, 68.98440299495574, 67.1465999849381, 66.05729503016319, 66.12869001203968, 65.37672065919446, 69.87413775536322, 71.37143196598177, 66.07755014973303, 68.51184368133545, 73.8758731657459, 82.47788198532598, 90.58214987477949, 91.35722591030984, 89.8162364959717, 90.26437513289913, 85.35028857569542, 91.12961861395067, 87.69854099519792, 85.64508607310634, 87.88195102445542, 93.46736692613172, 84.7015913071171, 80.6577374858241, 73.5040795418524, 73.91319059556531, 87.03722938414543, 84.92344840880364, 70.4743702180924, 75.64952188922514, 87.01162415166056, 72.76058643094956, 80.24477466460198, 80.70973242482832, 81.39285241403888, 84.80154898858841, 83.08991293753348, 80.07811315598028, 76.37658026910599, 76.51558906801286, 73.17900919145154, 69.68095317963632, 67.6260862042827, 65.80100736310406, 64.96084743930449, 64.02961792484408, 65.63053723304503, 64.65864450700822, 67.64491358110982, 83.59785203010806, 83.94397766359391, 82.56738262791788, 81.44944437088506, 84.56660686000701, 80.1905361298592, 72.59752565814604, 67.04326122037827, 66.03302340353689, 67.15977130397674, 67.09697415751796, 72.28803496206962, 69.35953847823605, 65.72297180852583, 72.23085464969759, 65.95838854389807, 64.92400461627592, 66.19101647407778, 68.08639987822502, 72.30155929442375, 73.07505853714483, 78.87484765821888, 82.71011767848846, 83.67789191584434, 89.88556831113755, 93.35718754799136, 106.96394458893808, 52.66692338451263, 0.35055864722498004, 0.8717282008259528, 0.2475145507243372, 0.5435150513245214, 0.606371891354361, 0.7066702674473486, 1.5132994421066777, 4.168223354124254, 1.0419648885726929, 0.3719632357599274, 0.7039784183425288, 9.917353103237769, 53.80431659760014, 67.9592131030175, 121.69218570955339, 97.45253424490653, 38.85100595412716, 31.582295087076005, 61.355094909667976, 82.20009188498221, 87.87303155468356, 88.51367227492794, 83.95376789954402, 57.219202672281575, 6.264718444116655, 0.17316502819378532, 0.13863635760161186, 0.1326041812858274, 0.164856881263756, 0.10460716867519003, 0.11511810950093693, 0.1489107764416164, 0.3399867258004604, 0.24682435146983595, 0.18431211311009624, 0.12565011008372232, 0.14328159301752044, 0.23144096887159735, 0.15177916284770737, 0.3493207717134107], [0.025141873779977043, 0.023237252795708277, 0.024820904007121444, 0.0370732584457484, 0.019038623657017466, 0.06891674106760372, 0.12262849843189602, 0.037047483417535984, 0.032535516656935215, 0.019352591386245146, 0.04605018864235571, 0.0982288661743364, 0.0343005602518397, 0.04138278647235805, 0.34642094505890725, 54.33994762359127, 91.80656479251002, 78.4206921054471, 54.48048614686536, 40.84506834706953, 84.15957466248544, 86.6682912457374, 71.27615759449621, 104.0024374377343, 85.68551786484258, 29.031218867148127, 0.12970446188363338, 0.04668877272295856, 0.12844978606388455, 0.010500305610138082, 0.42691309846216635, 0.16996287260084383, 0.2744525616928455, 0.46551489000839574, 0.35967564510722316, 0.13778466701267228, 15.975931382948353, 93.50923430535101, 101.98017320325299, 88.52034814896123, 83.98444867903187, 93.74382342061689, 99.05840750663512, 96.67125301976358, 100.82512147964971, 98.28705772276848, 97.88808207358085, 96.43239636575022, 94.00790875957858, 93.14752117280038, 90.3672275235576, 89.00253295898439, 93.06940324844854, 93.19458177012783, 89.8929266775808, 87.02612123181744, 83.31725351272091, 76.69888142616519, 67.61935541706701, 68.64692226532968, 62.971146721993726, 61.05921483808949, 59.814140796661384, 62.51429257854339, 63.68412771532613, 67.37143024321526, 66.73849305798932, 62.172783574750355, 60.39157252157889, 61.42936106651061, 68.63510024163031, 79.77309396190029, 86.24019592039048, 78.91241611972933, 81.9596976618613, 80.23285850401848, 75.62139065034928, 83.03027722143358, 78.97324423636161, 79.14448707334458, 78.49223613739014, 73.5781103564847, 71.64800613157212, 64.40981326564666, 72.19084647393996, 76.55559724377048, 78.91596978710544, 47.09384333702826, 48.784890867048695, 54.33925336407077, 49.74608336725543, 64.44062740572038, 68.4000482866841, 74.23913171214443, 74.96783748749765, 72.62532741792741, 67.88867319783857, 73.1958753831925, 70.46123812275549, 66.79360235891035, 61.89749202420635, 59.82093826417, 62.067346342148326, 60.998108233174975, 55.98387572073168, 58.253147294444425, 56.584876968014626, 57.51736164093018, 64.93688175755163, 73.50706054318336, 74.65362425773375, 79.66374612623646, 75.9273982817127, 72.61509003177767, 61.31515341420328, 54.3283256407707, 57.2776302983684, 59.03260461745724, 61.47429181683449, 60.89708758938698, 59.84577078973094, 67.4446608943324, 66.6445993608044, 61.22560962553948, 59.5122241973877, 61.13148450851441, 60.812764475422526, 61.719894947544226, 64.64482207452097, 73.4864131865963, 69.60708710455125, 79.67951405432918, 79.44585061842396, 86.38114237016248, 80.01780279221074, 96.70926078673332, 7.185813044348071, 0.5115482553599343, 0.40639386241955144, 0.08598478931573131, 0.29140942760052224, 0.3095942711637866, 0.05822879562695181, 1.5583135427967196, 1.6941322290128278, 0.37203071278429806, 0.05503928431520059, 0.06598225659540584, 18.571975615716752, 45.64573957074074, 94.0979742234753, 86.05136517555484, 44.6213851436492, 19.922114264580514, 22.85230128995834, 33.45853536359726, 52.69378377545265, 58.50206482794977, 60.18989209205874, 57.54730109245547, 38.91804318274222, 2.337160937247738, 0.11730818633711147, 0.07597614935929738, 0.06646661568553218, 0.018302937932012063, 0.010468986978183591, 0.01321946191901882, 0.05443685958462377, 0.0419780942461183, 0.012708162389425261, 0.053607289784497796, 0.04254362035182215, 0.04305651621712793, 0.021450599775679653, 0.049776957415404825, 0.012195531782063266, 0.0316667269855257, 0.0305437091212239, 0.07685069235101824, 0.05882968052080082, 0.07181790071509539, 0.051227644491460056, 0.04128591848477241, 0.0337389258727912, 0.0205016773073904, 0.04189489326710182, 0.035215039407053304, 0.055924020106754, 0.15147295750437245, 0.2337200191592978, 64.90882896607923, 102.53254490513956, 89.89713930314588, 63.36016347331386, 44.60806085217384, 94.69764186489968, 66.16479150710568, 79.0165158241026, 113.96449673560359, 98.39031803992488, 36.43930527471727, 0.06212290481574113, 0.17874361917136178, 2.5483567916577865, 0.3926037281991974, 0.5143318205110489, 0.20371903545193135, 0.6000222482027546, 0.6657395992548235, 0.5575620395041282, 0.03119134261543232, 19.98800616110525, 98.2362473395563, 108.13746283131262, 93.95459590419647, 88.92806283889279, 98.42515653179538, 103.17739040620866, 100.06826877593996, 106.82649689335977, 103.99241970431422, 100.5279548706547, 98.27393347217192, 98.78625777459915, 96.82780265808107, 94.74532219671434, 95.76733496881302, 96.47659363285189, 97.60109009281283, 94.63685297196912, 92.67303205305531, 87.33455288794734, 79.10320804965112, 68.79949462029242, 71.22642194071125, 64.90185106954267, 64.30878477711832, 66.82333392481651, 66.62755274003553, 68.36365653622535, 72.07557585931593, 70.5502837704074, 65.05692197430518, 64.08492334427373, 64.67755817597913, 71.89198540103051, 82.5027576569588, 88.09946213999103, 83.1700312706732, 83.15161966508435, 84.67742950685563, 78.96080247817501, 85.78007836495676, 81.48257270936044, 82.95152387311383, 81.7393232160999, 79.28894796679097, 75.13167488959529, 69.577512433452, 76.47787940117621, 81.37282479193904, 79.81799725563296, 56.322925398426676, 58.57877462140976, 66.13771930817636, 60.31281525088895, 68.22409076075401, 74.29062458776659, 74.81604176182901, 77.94951346612747, 74.77999517994543, 72.40412142968947, 76.19238576581402, 76.92692802798364, 72.94995846286898, 66.98860691439721, 62.181718734002885, 63.31889621673092, 64.73358138915032, 58.45813820439001, 60.951859566473196, 59.15648875697967, 60.108232267441295, 68.7296058285621, 78.16469469378072, 78.18305138618716, 83.15722080969041, 81.29060406838694, 77.20513389956567, 66.96026386753206, 59.45195697969007, 61.902136110490375, 63.51366935237762, 64.40049371411725, 64.24464618006061, 63.956187232848144, 69.57734769390476, 68.7434910189721, 66.51168592514531, 62.25293328685146, 63.89401374324676, 64.01386568623205, 64.31418980321577, 66.01815762058382, 78.50242645509782, 75.03874609547277, 82.91646572851366, 81.88941663311374, 91.00346734446865, 83.42373801815896, 102.78293332745953, 12.802702534583307, 0.7102453239983129, 0.33824482572174847, 1.443993857791347, 1.1548016725047943, 1.105628265969215, 0.2722985063108706, 1.482695148837182, 0.9156322707572292, 0.7527108646688924, 0.1440002141340125, 0.15255841216252697, 20.128364255351407, 55.720229687229285, 94.78877421348326, 77.61045594369212, 38.81643810579854, 28.612529385474424, 31.884498019372266, 45.58540959512034, 62.415213507990686, 68.75887455478792, 68.43432195724981, 67.60048881653817, 46.47204568309169, 2.762872196974293, 0.08597412537182532, 0.062452219201311956, 0.06389142261938223, 0.05967426564424269, 0.05931215886507304, 0.05961428095977153, 0.04596256350557651, 0.030720819073218494, 0.09974595775166828, 0.05869093050639476, 0.018236786239750443, 0.07530764571481174, 0.03996082769346334, 0.06472955728250165, 0.08609214887743996, 0.0725646679019255, 0.141805847205462, 0.21885503293766131, 0.11745080892597476, 0.17807370592509547, 0.22505197944420002, 0.1609079584839844, 0.18754613796068778, 0.15077920360190256, 0.170449813407275, 0.18913270605187263, 0.1878379255292877, 0.31186820398415294, 0.9376205876469613, 82.42810710783928, 114.99189099957867, 103.09796241021927, 78.2180546176049, 59.29343831154608, 95.79453268358785, 99.61475649187642, 95.1213441356536, 119.60672424685572, 108.76509697206559, 46.85423358794182, 0.3264935272595575, 0.13667183237210398, 1.7687618179667381, 0.5668748494598174, 0.965306637508254, 0.3703071988157688, 1.171023860093086, 2.012239391765287, 2.2335211307771745, 0.3869508573364827, 19.958819804653047, 104.05470694265058, 113.82726084801459, 98.01875975824173, 93.23494295920096, 102.01685520910449, 108.4180691934401, 102.8050398057507, 109.90854632469916, 105.55983020413308, 101.55618852184665, 101.56335076978131, 102.09543597313666, 101.37148411043229, 98.59185726411881, 99.27749541498001, 100.03418337914252, 102.31751272755285, 98.10161590576173, 97.77109346082135, 91.4282992578322, 84.93900452890705, 73.73855883075346, 74.98735520147508, 68.85965593399541, 67.04772487763437, 67.52950960589995, 69.40814448941138, 70.83909573093538, 75.13163566589355, 74.35219795473161, 67.77189639306837, 66.4200044447376, 68.74116113108974, 75.32706383735903, 87.09483331249606, 93.37076679352792, 87.19348092232981, 87.60392558190131, 86.4500270351287, 82.57454487585252, 89.1746622516263, 86.61726905453591, 86.74862923160677, 87.61923067031368, 81.13770223432972, 80.56336525947818, 72.8991323901761, 80.71965602136429, 85.04472024979131, 88.41988840410787, 55.84231345884262, 61.8018058038527, 68.76352648581229, 57.45951844799904, 74.83706566595262, 76.5046299657514, 79.29134061259609, 83.00094573728501, 78.23293609003868, 73.70240242250505, 79.11015848959647, 78.82504140177082, 75.05683606670749, 70.08832270099272, 65.67655055753647, 67.58475226740684, 67.99977825533959, 61.75311742290374, 65.43107686504241, 62.48649474113219, 65.67047872850972, 72.59336010102304, 81.85028706827472, 82.05045346290835, 85.85598407253143, 84.70518419819494, 82.26853724448912, 68.49413025763728, 61.569711316016416, 64.3498323809716, 66.818360359438, 68.9706511651316, 68.45228641263901, 67.82618199625324, 75.34290236811485, 73.87886985655754, 68.43594581850114, 65.16858793074086, 68.1562102225519, 66.70827511818179, 67.5837246064217, 70.58531838078653, 82.08088321070518, 76.65802601845034, 86.3055504522016, 86.25261414435603, 94.81395582998954, 87.51142824849775, 107.64372271876182, 10.533933024252615, 0.996135363896047, 1.2848588872340418, 1.0508191489404248, 0.7756318476411604, 1.454745319581801, 0.9055993994397502, 4.611722317434126, 5.600554779652627, 0.3248026792801196, 0.30143237041850246, 0.1911585642805984, 30.513002064920244, 64.4179561061244, 111.98785751096665, 105.66951536363172, 63.23531443072904, 31.11423473204336, 33.77027750015259, 53.08666798376268, 76.15036149178782, 82.21920167246174, 79.84111570542859, 78.49430714884113, 56.73307588023525, 4.052083199062656, 0.3252123524585078, 0.16860781628037655, 0.12976329743621812, 0.11395801489631976, 0.14661715516159612, 0.1354814696335985, 0.1381151420214484, 0.16984737718537932, 0.21282699349666798, 0.13761490192865172, 0.1939142438312692, 0.14385482596774257, 0.13966507578809417, 0.1686534444771467], [0.027860480420772108, 0.08913931722242026, 0.10400559813264879, 0.07675130776460133, 0.12725435182332032, 0.023737148148939017, 0.08872848725126636, 0.020810822513134732, 0.05670904955496231, 0.08586531790393977, 0.02393982820062628, 0.11955195827589882, 0.21413934807623589, 0.559254051937211, 13.080091572576954, 90.37056153820407, 72.9262516575475, 70.56588695895287, 47.29264474684193, 38.33422191681401, 37.938713642858694, 83.21211830262216, 102.12876043012066, 93.07571041968562, 60.754199566379675, 5.371306951968901, 0.16251681973376583, 0.2277929807502416, 5.253216643487254, 0.46944709674965956, 0.2134416258383182, 0.0896670981760948, 0.5999292144852301, 0.9234388292797151, 0.3165418612620523, 0.6836854233857125, 38.65864507613644, 100.68948591909101, 96.1637532326483, 93.08444161568919, 95.78456201860982, 97.1564894337808, 102.66364620577906, 105.4001897381198, 97.97067149992913, 95.94466532430341, 100.03402648433563, 95.32245189912858, 98.46128156108242, 97.0760416215466, 96.13674379164173, 95.0283839625697, 93.57994679481753, 89.43513901002946, 93.26811836611841, 87.08741218813005, 79.01402904141334, 66.79870144013437, 68.16712225637129, 63.56493865289996, 60.573088046043154, 63.20304116895122, 65.76694157815749, 67.67728097977178, 71.5892804053522, 76.87010072892713, 76.48828937161353, 70.69967116079023, 66.03451390420237, 60.811944700056515, 64.39206061824676, 69.64177654635522, 79.61386142238494, 85.36664485931398, 77.93798169782086, 81.20672025988179, 80.03615163987683, 76.58420701180735, 78.36895604287425, 76.40129120119157, 76.88371135342506, 74.52186399890532, 75.51973850496354, 68.31406993250694, 77.2554422193958, 74.97582343316849, 85.26366695280998, 45.14305253182688, 22.121404870863884, 26.18426649801193, 36.110598887166674, 60.85103896356399, 62.684135129374845, 77.75109644859069, 75.47357220803538, 70.34975651771792, 66.00425674069312, 70.01510773935627, 72.64969318143784, 73.02055328123032, 69.87340819451117, 68.27374012239518, 63.83126758760022, 61.90164581421883, 64.83632395344397, 64.25034930629116, 63.55412075596472, 59.45546750099429, 61.50781631469727, 69.0147150716474, 74.61516934056436, 78.86173125236266, 77.895031744434, 69.97572714282622, 61.91079278146068, 52.331956894167014, 57.061350807066894, 57.01827141546435, 58.89381939365018, 59.86309197641189, 65.53116006235923, 70.02099913935508, 76.21516689177483, 69.89116868665143, 62.42886727856052, 60.174555624684984, 59.773544265377915, 61.77517291038268, 69.49666453946021, 72.74869380458709, 73.78925938760081, 78.98638417643886, 76.00145263056602, 84.30580846724972, 81.29287904308688, 92.21622497804704, 51.30554322273501, 0.1681002983522992, 1.0748635232448578, 2.6415363723231904, 0.45088432669158907, 0.5620156456866573, 0.5463208330254401, 1.3985758755476245, 3.221699292621305, 2.349974585156287, 0.07821171649641569, 0.07319760974496603, 3.0247462997513437, 50.00294762272989, 66.01544334042457, 86.08954552681216, 81.67400006325015, 47.8318686639109, 20.217966879567793, 28.656016703574892, 44.11439134228615, 62.35611907897457, 66.32418878616826, 59.209656484665416, 67.81451686736077, 38.809672017251295, 1.2807817060139872, 0.07604462229796956, 0.10877568289757737, 0.02688507237772067, 0.048009642369804845, 0.0974256689510038, 0.05976800799309727, 0.017346266484368714, 0.04597966258804645, 0.030066838540557413, 0.014888727286409949, 0.06598299203981316, 0.04513872404312415, 0.02667456290744726, 0.08704673273548966, 0.08687006519927133, 0.04655104926637104, 0.033715391651757305, 0.029373948402222128, 0.03764262648239251, 0.07246556676804058, 0.040407928097392284, 0.04250799726334311, 0.03848736099297962, 0.09208500956095035, 0.18605416640639308, 0.20436360650966245, 0.6533875652859289, 14.326837524291008, 103.79409682366156, 83.17094910529353, 80.55655602485903, 59.51048266503119, 43.5554692822118, 44.087797672517844, 79.09850120544434, 106.22976318482431, 106.11479851507373, 68.5885730866463, 6.597028999559342, 0.6459728760584709, 0.34067258899731023, 5.832280564692713, 0.5436631820855603, 0.2200808502253025, 0.11392829068485769, 0.6644137768495468, 0.053469263723180185, 0.23949517297648618, 0.8792857501295306, 43.312756938319055, 103.49074071453464, 99.8779945988809, 96.23976092184745, 102.1111568327873, 101.85192738809894, 107.96729472375686, 107.35524808206867, 103.31221795851185, 100.64210368740945, 102.00289941603138, 99.58083583462624, 101.75211875669419, 99.87852804122433, 97.75695723872032, 97.82045256706976, 96.88527322584584, 94.15983784583308, 94.68336443747245, 90.59314820074266, 80.52688721687564, 68.90249606101744, 70.04301148076212, 66.45613731876497, 64.75766081963816, 66.32883287245228, 69.95154965308406, 72.04909201591246, 77.42603394293016, 80.2417387500886, 80.24817928191155, 73.84480014924081, 68.4102778280935, 63.917038056158255, 67.32066692844515, 72.85160895316832, 83.7552567451231, 87.63524963009743, 82.56518610062139, 84.41918065471035, 83.95768242497599, 79.83575774777321, 81.77242802035424, 79.24025566347184, 81.86868298438289, 79.07463750531598, 78.88487323637932, 73.83854789118614, 78.26770397924608, 79.94073606306507, 83.08814787095594, 56.09981313828499, 31.86947730279738, 40.596848995454856, 46.27834727687221, 66.4116733304916, 66.67671572777533, 79.87428326760569, 79.9789870169855, 72.4599132230205, 69.000547470585, 73.6270615362352, 76.98728546019524, 75.11530291649603, 74.4453699358048, 72.45942684911913, 67.84766089531684, 64.55456441448581, 69.67688175939745, 69.81116017987652, 67.11067107415968, 62.3932796139871, 62.92044616514637, 72.67451393988826, 79.3383227625201, 81.89089928903888, 81.74437522888184, 75.40264006583922, 66.4192513496645, 57.02803811719341, 60.32980695847542, 60.03532325067828, 61.72723370213663, 62.13801176317277, 69.0150131717805, 75.1597982837308, 79.396114964639, 73.19945258478965, 65.50049889472224, 63.774126498929924, 63.1763376728181, 65.52376639458441, 72.21737738578551, 76.26570270907494, 80.07066065265288, 82.74039837621874, 79.32070347570604, 87.38726169832292, 85.57261636180263, 92.78943231028896, 61.064431590418664, 0.29766340169214434, 0.532408369885337, 2.7185575039156022, 1.0494501191762187, 1.1402567884614392, 1.0126880111713563, 1.7403091898848935, 1.6629916741963358, 4.5971747367612785, 1.0878488974225138, 0.20944079294079737, 1.8529744926960239, 53.605652470742505, 72.99444598536338, 82.64015828409504, 66.79419855917654, 38.58109197308941, 26.881499175102483, 39.14883936605146, 54.65532971966652, 72.22451609949913, 75.74023062183012, 68.69557534494709, 80.61932963709678, 46.678958554421705, 1.3852669058307525, 0.037865297598463875, 0.06429551484724207, 0.0893839444184015, 0.05453792573403447, 0.026661629428065596, 0.06262555042462004, 0.020171173570317127, 0.018818492122415095, 0.05870173617656674, 0.026123739944230166, 0.1028018135337099, 0.04877026042630596, 0.04466044386067698, 0.11185104327817118, 0.19894230870469926, 0.18571986095799556, 0.1540104398924497, 0.2456668385815236, 0.1030717216311924, 0.21560069143531785, 0.10584762590306421, 0.12559261518500506, 0.18345456960941517, 0.19782179786312967, 0.2862185690431826, 0.45412631885659316, 0.9696906829072584, 20.01461748153933, 119.85286081990888, 93.14849392060312, 95.85053628490817, 68.7585372309531, 59.357902465328095, 48.03547497718565, 100.93227278801703, 125.89091039473011, 111.89496794054585, 83.5547451819143, 10.0076009573475, 0.6918430953256546, 1.0441605578507147, 10.348655946793096, 1.188950440095317, 0.7159198291840092, 0.3567008950537251, 1.7916977549752884, 2.821084092701635, 2.068558743884487, 1.0693604378930985, 45.30974934178014, 112.3179171162267, 103.78298867133357, 101.58577888242661, 104.20023472078385, 105.03594275443785, 111.45154399256553, 112.58375183228524, 106.85180402571156, 104.99806834805398, 109.99166919339089, 103.00799108320668, 108.29851535058792, 103.9930159045804, 103.78207083671325, 101.39180983266523, 102.83299846033897, 98.3888275392594, 98.33940567508822, 95.72476940770304, 85.83940813618322, 73.94467153856831, 75.35357905972388, 70.16174947061847, 67.9889682031447, 69.73330113195604, 73.31906134082426, 75.21514292686217, 78.73612126996441, 82.83575119510775, 85.84644486827236, 76.25992113544096, 71.45515887968003, 67.43068941177862, 71.61716061253702, 76.73401017342844, 88.7417188767464, 93.39510117807697, 85.34920600152786, 86.61123644921088, 84.6914166788901, 85.76853875190982, 83.92253798823204, 83.27815532684326, 84.29102897644043, 84.8529947957685, 81.53015105955063, 76.94964639602169, 83.25717064642137, 84.13160031841647, 94.24375303329961, 54.94632644038047, 32.3252292602293, 42.025117335780976, 44.57018252341978, 73.83944219158542, 70.71117939487581, 84.45090478466403, 81.04315742369621, 76.29422618496802, 72.20059748618834, 75.56439861174553, 78.36762243701567, 79.21753729543379, 77.71348091863817, 75.4213576163015, 69.67672486459055, 66.22922820429649, 71.32113933563232, 72.38730230639058, 69.8287167087678, 65.4983651253485, 67.33895301818848, 77.67025639933925, 82.50903344923451, 84.81732476142146, 83.06207195405038, 78.27604293823242, 69.51142049604847, 59.27279879969936, 62.65363477891492, 61.4958256290805, 64.86935423266503, 66.8088839131017, 71.08679340731713, 78.68710733229115, 83.1862541937059, 76.26480840867566, 68.48484992980957, 67.59227537339734, 67.84351102767452, 69.52641179484706, 78.52870633525234, 78.91421256526824, 83.0988637862667, 85.42000478313815, 83.59904443064045, 92.76083823173278, 90.58522501299458, 97.07550033446282, 62.41502131185224, 0.3286637317749762, 4.147254363183053, 7.193154250421832, 4.8317099194372854, 2.046016269633847, 1.609617531780274, 4.055134312760446, 9.952802504262618, 5.481908475199054, 0.480367343031591, 0.22205659098202185, 4.869456848790569, 69.92814879263602, 77.72233763048726, 104.02742293573196, 99.35485239951842, 67.58828240056192, 31.030394069610107, 42.99849271774293, 64.83624550604051, 83.36633805305728, 87.2632206639936, 79.30826956225981, 91.65390614540347, 55.49008069499847, 1.7622406324071271, 0.22549727571106729, 0.2665222952923467, 0.1962353370242542, 0.18834366613338072, 0.2882800503603874, 0.19075849784478066, 0.09700347789593282, 0.12447815643803728, 0.09265255047789506, 0.18541080576758232, 0.15111188494390057, 0.1632263856909929, 0.19328899351098847], [0.012587147310466297, 0.05544923711568118, 0.06048860944687359, 0.06491214667837467, 0.022214607771245704, 0.038701766020348, 0.02757630776613951, 0.017012962695932197, 0.038307406939566135, 0.0658268096946901, 0.03421849691339078, 0.03994174444326951, 0.08570631635525534, 0.26180604352585735, 40.05418515974476, 84.84024709270847, 76.39444274287071, 64.57707489690473, 39.738587333310036, 33.203985306524466, 28.89385158015836, 55.935822763750636, 98.2418014157203, 85.01855804074196, 26.352016464356456, 0.1336137625959612, 0.058523563277577205, 1.102301115470548, 1.9603897030315094, 0.18214123443730418, 0.14333151130666658, 0.23883279803539478, 0.2132070497159035, 0.47962086695817213, 0.06080683470974046, 2.996605500098198, 52.670316234711684, 97.34704602149226, 100.62275071297923, 100.08660193412535, 98.9093025269047, 100.65153306530368, 104.07739393172726, 98.41440923752324, 99.54373021279612, 94.59738608329528, 89.51054265422206, 89.39769606436454, 93.89699982058619, 94.44017748678885, 97.17267313311177, 92.02532322176042, 88.81076828125985, 86.27471277790686, 87.37339219739361, 74.85307678099602, 67.20737318838796, 62.882359950773186, 65.42279674160865, 64.64876405654415, 62.6499673628038, 64.03221845626831, 68.70223552949967, 68.16040715863629, 73.35595515466505, 77.15773597840341, 79.52295657127135, 70.64103957145446, 67.49467111402943, 63.39537066798057, 62.645158536972545, 64.84582001163115, 74.36865621997465, 79.0959987332744, 81.68126429280927, 78.12769889831543, 83.89661896613337, 76.1892714038972, 75.65940626205938, 73.35244855573102, 76.29048424382364, 70.12945267461961, 74.63611479728453, 69.70301258948543, 75.8033101789413, 74.07527077582576, 77.04128080798735, 46.561326672953946, 20.49106582518547, 17.940054324365434, 32.96457167594664, 59.25835663272489, 61.08574574993503, 76.21424121241417, 77.57448780921199, 67.18269363526376, 62.44069714700023, 70.71956542230421, 73.15711452114967, 77.15149940982943, 76.83436793665733, 76.82916687380883, 73.53759227260467, 71.99244514588388, 71.51513976435508, 76.59769212045978, 73.16965041622039, 69.20687983112951, 63.05790955020536, 68.74791545252647, 73.70079425073439, 75.06441408588041, 76.99154515420237, 73.87490041794317, 62.80537166903096, 54.09943965173537, 55.667528721594046, 57.19948883979552, 57.32656578863821, 58.37158326179751, 71.51465339045372, 78.31667869321763, 79.74521375471546, 68.87815383172804, 65.5999074443694, 60.61595955202657, 59.35379182138751, 59.02703092944238, 69.96396003230926, 72.73804064719909, 75.7808114636329, 76.31557172344577, 80.19751010402557, 75.95170128730037, 83.59485533929642, 81.1325482399233, 88.70873958833756, 12.459593203759963, 1.5902879689970326, 1.4153557751447925, 4.479782610170303, 0.34245754321736677, 0.2880044119252313, 0.1504285191936839, 0.6014044546792584, 2.7877924855678313, 0.9210614439460539, 0.10910015177702713, 0.3865325733298256, 19.07134040709465, 45.49259454973283, 64.29299331480458, 102.7497265415807, 72.01128821219169, 30.124597203346994, 15.4635678568194, 18.375064788326142, 35.52673839753674, 68.00082160580543, 66.42937890944943, 57.96368422046785, 72.5595884938394, 21.71030321428853, 0.2360948764028088, 0.07378272471889373, 0.03518726488935851, 0.06878334217734876, 0.04375584340924698, 0.08246968680572125, 0.0661135257612313, 0.02363216729023524, 0.0958029261880344, 0.03651730460865844, 0.08415624469278321, 0.023944273425806916, 0.05617197978520586, 0.01987518017901288, 0.03401319684100247, 0.07264296974866621, 0.051643197394667134, 0.065297213112635, 0.06084960539855304, 0.03833175321379977, 0.0326121675841991, 0.03415923235156844, 0.03980027098629264, 0.04693446861159417, 0.11939120238586781, 0.04979550440405166, 0.30957901069233495, 46.81699068315568, 96.98351290918167, 80.89996737818565, 78.82032671282369, 44.83017290792158, 31.3578119585591, 26.340139527474683, 64.8389127177577, 108.73720107540008, 98.13831360109391, 31.97326517874195, 0.0921765264243849, 0.017015377788113493, 2.1017468985049956, 4.028623503062033, 0.7282793401710449, 0.39083234905715913, 0.6812917357010226, 0.05122492104888924, 0.7377869203206032, 0.334466633296782, 4.708689191649038, 59.361879748682824, 98.90189709201937, 105.7434206624185, 102.93046151438068, 104.43660459210797, 102.59003900712537, 106.17441854169293, 102.89454044834261, 101.87237078143706, 97.07764194857691, 95.88099741166639, 93.06748913180445, 97.38758763959332, 97.50431737592145, 99.9051138662523, 97.06933436855194, 92.45442267387145, 88.95936335286787, 89.39251853573708, 77.49027452161236, 68.72089816677955, 66.48859885431105, 70.33067026445943, 67.17307598360124, 64.3951710577934, 66.40007880426222, 73.09178352355957, 73.43932121030747, 78.94786650134672, 80.82333210975894, 83.6286191017397, 75.17962978732201, 71.6450329749815, 66.97412552372103, 66.69867315599996, 66.48784575923797, 77.24940961407077, 81.23064671793293, 84.32065071598177, 80.62855505174207, 86.84905759749874, 78.97992795513522, 77.04430103302002, 75.21872797319966, 79.84664624737155, 73.4570973919284, 79.89642112485825, 73.78343074552475, 76.86919073904716, 75.88571917626166, 78.94517575540851, 52.625393329128144, 27.507797748811786, 27.456332329780828, 40.20853434839557, 64.40436509347731, 65.54953244424635, 78.10451769059705, 80.97797547617267, 71.89222074324086, 64.91111963025986, 73.06323651344546, 76.68688681817825, 80.54485167226484, 80.27707930534118, 79.27609043736612, 78.06566269167008, 75.12852914871709, 73.48895488246795, 79.61488908337009, 78.60931888703378, 73.34612569501324, 68.02102181219286, 73.37304099913567, 78.98778838496055, 77.59759841426727, 80.01295474267776, 77.1617603302002, 68.16127008007419, 56.8119861233619, 61.47551559632825, 59.36277012671194, 60.593464759088334, 62.39086735633112, 74.43436376510128, 81.4897741809968, 82.40861292808287, 72.04815064707111, 69.7776552938646, 64.02801367544359, 63.55898841734856, 62.355538568189075, 73.0128340567312, 76.6789871646512, 80.61617605147823, 78.50976128732005, 83.69995132569345, 81.56274595568257, 87.91365946492841, 85.31534810220042, 91.3446351020567, 19.714065867085612, 1.1320445710612883, 2.3082373795970796, 1.9816728513086996, 2.2432696915441945, 0.8850574565510597, 0.48020336957227805, 1.0925496129258987, 2.856773738899539, 2.2475894468445934, 0.475561275116859, 0.3092456092276881, 16.79578127399568, 52.69108126240393, 69.19535590756324, 90.90234864142634, 56.190819971023075, 31.433900056346772, 25.629404091065933, 28.651607959501206, 45.36916540515038, 77.48090790164086, 74.75952825238629, 65.43945504773048, 84.420333831541, 27.098214049493116, 0.1434711844570214, 0.09259205251451462, 0.04151350022443841, 0.03634246419213953, 0.03465134808192811, 0.03582170060385139, 0.051425739506920504, 0.049008977253951376, 0.037529866000817674, 0.032264118518439994, 0.055390256006390824, 0.043057703653410564, 0.02073491086071778, 0.13780820123370618, 0.09851306947248598, 0.2053081622767833, 0.18815902362187065, 0.2044142449214574, 0.15122414746832463, 0.15276133353191038, 0.17665529413329017, 0.32866152544175425, 0.20702461291465069, 0.12546498493681993, 0.24451093447785227, 0.11684771386846421, 0.41394595717710836, 57.494541291267645, 109.9968231877973, 94.84172621080953, 88.09625364119007, 56.836147923623365, 46.59446285616967, 42.713214812740205, 80.8132359289354, 112.53646373748781, 106.9799792382025, 44.34237126381167, 0.43554166932740523, 0.16279756031449766, 3.8095211309771386, 14.468211512411795, 2.291101524906774, 0.8439033971198144, 0.9064451605081559, 1.5289302098174251, 2.0796624835460418, 0.6236377358436584, 4.892907229162032, 62.09462250432661, 105.46870570028983, 110.10778703997212, 110.32039519279235, 106.81707536020588, 106.84297869282385, 110.78609820335143, 109.01750149265413, 104.73350447993126, 101.66211605072023, 97.18078459462812, 96.40621062247985, 102.41967478106099, 103.09057266481462, 103.9336939780943, 101.27619404946604, 97.06028938293458, 94.57727216905164, 95.60040673901959, 82.32158337869953, 72.60536255375033, 67.80015314778974, 73.19992326921033, 72.81811975663709, 68.99486003383514, 69.04900443169379, 76.66551774547946, 74.34960134567754, 82.54242850888161, 84.48069910849296, 88.56814615188107, 77.7463190017208, 75.44406029485887, 70.2371923385128, 72.16024414185556, 70.40448927110242, 81.34474062150525, 86.93411027231525, 88.98078733874907, 82.95124930720176, 90.14698643838206, 82.81163646328835, 82.49608962766587, 79.01772391411566, 83.5215070170741, 76.71111922110282, 83.31601404374646, 77.75980411037322, 82.6596446191111, 80.73412172255978, 86.34979478774532, 53.53664228993078, 25.890278970041585, 26.11965721653354, 40.456118276042325, 72.49901140889814, 67.75816809746527, 82.44374167534613, 85.0323647837485, 73.70227690665953, 66.50284490277691, 76.00772842284172, 77.40159757675664, 83.13889549624535, 81.49698349737352, 82.8750611889747, 80.74938758727043, 79.46864743386546, 79.35975459314163, 84.95335255899738, 82.17043876647949, 76.62092824136057, 70.9881301080027, 75.80355336589199, 81.79322442700787, 80.01894812430106, 83.20520708637854, 80.77986440350934, 69.00155944208946, 58.71401010021087, 62.95985421826763, 63.11800810598559, 64.42302380838703, 64.52545650543706, 77.20113308198991, 83.92871964362361, 85.4871714499689, 74.89288099350469, 72.12858276982462, 65.48248737089096, 65.54167201442104, 65.91571315642327, 77.6435136795044, 80.346387586286, 85.19222490249142, 83.34033273881482, 87.20029015694895, 84.79457501442202, 90.44719680663079, 87.44491269511562, 95.4870423962993, 18.071457647508193, 3.383474263452715, 9.119165482059602, 13.723627982601045, 5.08726361297792, 1.200434649663587, 1.7683431049508436, 3.854736007990376, 6.454232171658547, 1.4199232526363865, 0.6257808208465576, 0.4887214092718017, 28.930908172361313, 67.16720027308311, 83.46911199631231, 117.56336550558768, 87.95516598609187, 41.31705891701483, 24.92170064680038, 31.80525241359588, 54.161821026955884, 85.64990274367794, 85.74927991436374, 73.30428969475531, 94.69786151762932, 31.66311748566166, 0.37980184740116524, 0.18018720461235893, 0.1903820728823062, 0.16974205541754925, 0.14919576114944874, 0.24436189973306274, 0.18881442716285107, 0.18383617332625776, 0.21024084920364045, 0.19428418768990427, 0.17194848057002793, 0.11747576807054783, 0.06555672539698501], [0.04937923137819575, 0.01199688709851715, 0.03709023878459008, 0.047109711224273335, 0.027901194163507996, 0.021075808495703726, 0.01312645501457155, 0.061479762511988806, 0.02828349693558149, 0.03427965371238609, 0.02724237387038527, 0.0625515195180572, 0.035123465087024436, 0.1568515229249193, 64.78171671590498, 79.70215397496378, 64.61905210248887, 44.66904194124284, 48.35901952558949, 27.955746150785878, 45.25952731409381, 93.65022782356509, 101.84802070740731, 63.328011805011386, 5.448349166300989, 0.059870851466492306, 0.06325254742536815, 0.3952473444083045, 1.7819981012613544, 0.1969859346507057, 0.023244296974172036, 0.11695681244976099, 0.04542208847499663, 0.06867921550668056, 0.24456802334996963, 12.331466040303631, 68.71174335479736, 97.83247070927774, 100.02579735171412, 102.67375807608329, 101.6004171679097, 97.38014298100626, 98.88971421026416, 97.62266312876056, 94.11780572706654, 88.97721013715191, 89.21223071313675, 86.20582811294064, 91.24314769621819, 90.81010233971381, 92.3845652611025, 92.56217018250497, 88.30194273302632, 78.59652411553168, 71.69234460399997, 64.8574145378605, 63.65003055141818, 64.19656576648836, 64.85422565091041, 62.53443394937823, 64.27182036061441, 64.00011777877808, 68.38982659001505, 69.26085948944092, 74.07810272709017, 77.3017575663905, 80.44973419558617, 76.41700421610187, 69.05241689374371, 66.54031922740322, 63.39006370113742, 64.18533602068501, 66.60779968384774, 74.08676332043063, 80.35015306165143, 79.87126304257302, 80.53841898518225, 81.72840333754017, 72.37238161025509, 70.25201105302381, 75.50529633798908, 78.07457431670159, 77.00255916964623, 72.3495691053329, 72.68771663788827, 68.0314866958126, 69.58918540708481, 51.21960016988939, 34.129892164661044, 29.824129919851984, 36.26876454199515, 62.90474883971676, 61.38426949900966, 73.0655820908085, 75.23799465548608, 70.45882978746968, 62.69065018623107, 63.45367277822187, 71.42264243095153, 74.06806145944904, 76.29646193596625, 79.02464297509964, 75.13642880224413, 74.10214685624646, 74.77104433121221, 76.46177414924868, 75.96741430221066, 74.57172516853579, 70.49088339651786, 67.16620399105933, 75.30807956572502, 78.24211443624189, 73.85080137560445, 74.27553915208387, 66.19264818006947, 54.882129007770175, 54.89155054092408, 58.50812096749583, 55.08450369681082, 64.91832110189623, 72.88198378778273, 78.6583955826298, 77.34910057437035, 72.80755289139287, 67.01696565074306, 61.38022945773218, 55.8003205637778, 58.85827487514865, 66.88504065236738, 73.18442990702968, 77.2293584577499, 77.43799717195573, 80.55916832339379, 78.17288460270052, 79.56793046766713, 83.14463000143729, 78.65882704334875, 68.54574864910495, 1.260547178887552, 0.6359107708258014, 0.10268396622831784, 0.9116593387819106, 0.9246219141829399, 0.6409589838116401, 0.33296672507159175, 3.931554156926371, 4.242263974681977, 0.2213046450408236, 0.19948042418447234, 0.4472040096598287, 28.014970018017678, 52.644985568138864, 85.80127485336797, 91.93951745187083, 64.9103351562254, 36.95883889352122, 19.312536754915794, 28.049045608889674, 53.5031452486592, 58.48424550025695, 62.14920620764456, 66.07007411218459, 56.60816800209784, 1.8766947811649692, 0.07162977250352984, 0.03743213233387759, 0.052740809868179986, 0.05133644046802675, 0.04640472647283347, 0.06663213664245221, 0.11266607655993394, 0.042816604292320634, 0.14245945810069963, 0.07020518604305483, 0.07213943547779514, 0.05606093534058141, 0.03289249447745181, 0.028686101037648418, 0.040039949254283023, 0.090859628943426, 0.005456760014978148, 0.03787244902923703, 0.004969850330868917, 0.0212974434778575, 0.01379180046158933, 0.03806444598482021, 0.01992092328897167, 0.041237202953667416, 0.08965822687793164, 0.357796584646548, 77.00890556458505, 89.07610093393635, 73.50412661029448, 55.9055499107607, 47.68397177419355, 26.86636863216277, 46.43363783436437, 97.13312779703449, 113.86610015746086, 71.40604296038228, 6.977282195321976, 0.23476286400710386, 0.8423513642722561, 1.7974150997977105, 3.3298005500147423, 0.8523157779728213, 0.17290913950531714, 0.2877454742068245, 0.14103163874918415, 0.11812526507363205, 0.41465189187757434, 15.30361556237744, 73.52727643905148, 101.05972628439628, 106.44485027559342, 106.43792336986911, 103.64099887109573, 100.58522147517051, 103.42049106474846, 101.37275495836812, 96.55056168956142, 91.84871458238172, 91.05617615484422, 90.63636487530124, 94.62813746544623, 93.26389005107265, 96.90981941838419, 94.64689423961025, 91.29648408582135, 80.90831418191233, 75.15086312447825, 67.69966986871535, 67.01951519135507, 66.56275518478887, 69.14984856882404, 65.96640586853027, 68.82098136409637, 67.43112087249756, 71.6712579419536, 72.31618973516649, 75.48389588632892, 83.06757896177231, 83.2493023718557, 79.61985480400824, 72.52388708053097, 70.90223804596933, 65.6609748255822, 65.81712830451228, 70.353514148343, 76.21568464463758, 83.82800102233887, 82.13883230763098, 82.52119279676869, 83.15036450662922, 76.32092968110116, 75.06442193062075, 79.53207215955182, 79.22788450794836, 78.839977787387, 77.5303219210717, 76.20135230402794, 69.56207398445376, 72.0644598622476, 56.087720471043745, 39.797313059529955, 35.66351536781558, 43.583133759037146, 68.46535575005316, 63.94904459676435, 75.75959144100067, 77.77961207974342, 71.89342098851358, 66.92267187180059, 64.28122228191745, 74.3624431856217, 75.65142031638854, 78.84481014743929, 81.82543493086293, 78.44409296589514, 77.52820384117865, 77.78833543100666, 78.7240795935354, 76.50416712607108, 77.06294798081922, 74.4506259118357, 73.8305619455153, 78.50507797733431, 80.4055839969266, 77.09602140611219, 77.0504669989309, 69.38815609101327, 58.7137786803707, 59.07546827870031, 60.452659514642534, 59.910913513552764, 69.75099886617353, 78.5405989616148, 83.12212344138854, 79.92153998344176, 75.19764131115329, 69.26744907133042, 65.65042364981868, 60.27572139616936, 63.48936242441978, 70.00510569541686, 75.92014974163425, 78.05111854307114, 80.25876183663645, 83.32500411618142, 81.28719945107737, 81.10993185350972, 84.75699870817124, 77.5725736925679, 75.41031222189628, 4.758677348013848, 1.1128141706989658, 0.7013599298173382, 0.8379434782170481, 1.0501670548992774, 1.0848410523706868, 1.627551466226578, 3.9716491151240567, 5.637908001099864, 1.3820114611617982, 0.2116168197244406, 0.15254485240626722, 28.299896870889974, 57.95387829503706, 89.50609468644666, 81.25382792565131, 47.42918637491042, 25.315018277014456, 31.390432350097168, 40.23577128687213, 64.33759458603399, 68.78284808128112, 71.61178696540095, 75.19651951328402, 69.8602996333953, 2.1058001777818127, 0.10450801391515041, 0.045127876238116336, 0.04007760630620103, 0.053867679239521106, 0.011184453727647422, 0.04371914779767395, 0.016226345530500817, 0.0609160328824674, 0.0089950769043137, 0.018800387549544537, 0.06599940164315124, 0.04854765442770816, 0.16478889862135535, 0.0762778118012413, 0.09773463987174535, 0.21271002719238882, 0.1370659846091463, 0.10558521014548118, 0.1482038305050904, 0.15353882084450415, 0.11779201682657005, 0.1574705526112549, 0.1193535798079064, 0.13143149985661431, 0.16372789748974387, 0.7633980976477747, 89.0723668375323, 103.53082733769571, 83.2155699883738, 65.26809453964233, 64.35665730507144, 41.54426220924624, 66.00419398277037, 122.51540491657873, 116.99772050303798, 89.63582315752583, 10.135517293407071, 0.2838955146651114, 0.45776551228857815, 2.9091726820315085, 7.007605058531608, 1.0463651750356922, 0.2895611945179201, 0.7315104538875242, 0.6876946985721589, 0.37487164259918276, 1.193763065722681, 15.628642766706406, 80.38181443368235, 109.07609385828819, 108.91509625219531, 111.65880203247072, 108.47109179342948, 101.65787204619377, 107.90312474773778, 105.1601642177951, 101.94056510925294, 97.26879473655455, 98.15870992598995, 95.24617748875772, 102.71429969418435, 98.58723671205583, 100.44309831434681, 100.07195580390193, 95.77488160902455, 86.82234625662528, 79.58327477978122, 71.00324692264681, 69.63447309309437, 70.22038105995425, 73.06066343861242, 70.49704936242873, 73.12193870544434, 72.35477016818139, 75.13781732128513, 76.62189314442297, 79.43242042295395, 85.49941708964687, 86.93357682997181, 82.94297310613817, 75.49660436568722, 75.1480233284735, 68.42266467309767, 72.41013050079346, 73.94745642139067, 80.68330349460726, 89.79633438971736, 85.84701753431752, 86.12108922773793, 88.44459933619346, 81.29698184228714, 78.78515089711836, 83.55280753104918, 84.38801350132113, 84.0860616007159, 81.63945182677239, 82.52101236774077, 76.16937714238321, 76.51503209144839, 58.89662388832339, 39.60893730963431, 34.88307352988951, 44.58421284152616, 74.48390330037763, 67.2028781521705, 80.72270762535834, 82.86352942066809, 74.43590133420884, 71.77754632888302, 66.73084443615329, 78.15837183306294, 78.46456773819463, 82.92758957032235, 85.19266420795073, 81.68193109573858, 81.59429750134869, 83.29844182537448, 81.15983224684193, 82.68682664440524, 81.46562807021603, 78.81714959298411, 75.40320488714403, 82.0362074144425, 82.61187015041229, 79.87931959090695, 80.05836794453283, 73.49219476023029, 61.54629476608769, 61.43781377423195, 63.63424301147462, 61.088871878962365, 72.02175309581142, 81.22554763670891, 86.56099088730352, 83.6813122226346, 79.02745923688336, 72.23862094263878, 69.22892355149793, 62.533002284265336, 67.90772022739534, 73.80561567121937, 79.58595768097909, 84.39508161237164, 84.05715373254593, 88.87738581626647, 87.1539826546946, 85.65177763662031, 87.14921305256506, 80.86146539257419, 77.95411048396942, 3.027322561510148, 3.9500655378064806, 5.315572033005377, 3.9126164634381575, 4.549905763518426, 2.085394782404746, 4.1242918276017715, 13.91962097537133, 8.363271797856978, 0.9608331130396937, 0.2813617248208292, 0.7946707873094467, 45.51272415345716, 70.47485659199377, 100.78847869749993, 108.85887299814533, 84.72146987915039, 51.66674644716325, 33.976354906635905, 42.00169686348208, 73.6559223359631, 81.3993949274863, 82.83036970323133, 86.17641818138861, 80.95169559601815, 2.272871574086528, 0.2523643162942702, 0.13725713886801275, 0.13394759306984563, 0.12361983918855268, 0.11068652834623091, 0.11880210375473385, 0.240065494792596, 0.1440383653126417, 0.21404259117139926, 0.14585597020003105, 0.14725784981443038, 0.3387391362940112], [0.050027778432253873, 0.04074360867361388, 0.024866026585861564, 0.019050093908463756, 0.0354911221732055, 0.06518978460301315, 0.05962207207396146, 0.03858794833743765, 0.0655432805539139, 0.06251228049457555, 0.02366734030205877, 0.1550424675787649, 0.3646740930215005, 4.966242803681282, 82.75479347475114, 71.57585020988219, 68.83721997660976, 57.48764968687489, 26.987159982804332, 21.337381908970496, 59.94399478358608, 91.45492430656188, 88.12261196874803, 29.78901490088432, 0.5051135151616989, 0.0661760768402488, 0.6478504656303314, 2.567190052040162, 2.1379283118632535, 0.7490761145468682, 0.17787829221737, 0.5502302103465604, 0.07236789821857408, 0.27772761821266145, 0.908341320051301, 25.525559340753865, 71.854369871078, 100.84209749775549, 101.67023535697692, 104.89304296432003, 99.81242825908046, 100.6463869156376, 100.54690776332733, 92.59774607996788, 86.6613329610517, 82.20912118111887, 73.5053425450479, 75.63256940534039, 82.9032002725909, 86.84297792373165, 92.25364438949093, 89.65130867496615, 84.0109952803581, 77.47477331469136, 67.7028783675163, 63.097603936349195, 64.1595817381336, 64.66278260754001, 62.20908903306531, 62.03985444961056, 62.96911885661464, 63.672415517991595, 65.81037398307555, 64.44292591464135, 72.44677328294324, 76.24893065421813, 82.12686123386507, 75.67905733662268, 72.4088361186366, 68.93534198884042, 65.46200083148095, 67.29004890688005, 69.45545611842986, 73.62280184222807, 79.40783500671387, 75.41512104772752, 78.2570743560791, 83.31140133642381, 74.18811736568328, 68.59666885868197, 72.8051680903281, 72.69850315586214, 76.47787940117621, 65.98128734096404, 69.07613154380553, 62.708555806067686, 65.48319339752197, 61.80496723421159, 47.759395030237016, 43.60385956302766, 44.4388105792384, 60.03960255653628, 61.220153608629786, 69.44110808833953, 73.17950341009325, 70.80103305078322, 63.217012651505016, 59.64174870521792, 64.35816741758778, 69.38231175945651, 72.57967102912166, 74.45629765910488, 75.70940079227572, 75.60042950414842, 73.82059128053727, 73.58309176660353, 73.15760089505103, 74.34831480826102, 71.78906240770894, 78.20685232839277, 75.78609881862518, 74.26221093823834, 75.27081704908802, 74.77271526090561, 65.04807310719644, 56.313480331051736, 56.154663562774665, 54.647583038576194, 57.56477525157314, 67.52648938086726, 74.46367955976918, 77.49342026249056, 78.17425743226083, 75.49683186315721, 69.63059779136412, 66.95733777938351, 60.70564454601657, 59.01464800680838, 62.493209838867195, 67.63012624556019, 72.46523195697416, 75.7301030620452, 73.65890333729406, 72.75806826929893, 76.63719823283535, 78.7794085471861, 75.23935964030605, 82.27867264901438, 65.00344437937584, 1.7317209152444717, 1.137338422479168, 0.9373599338916041, 0.4500373398825046, 0.08709649780705091, 0.380029957741499, 2.3836844150097143, 4.606835534495692, 1.999172138110284, 0.054915128275752075, 0.5530209154371293, 8.320909219403422, 36.80462306545627, 75.54924257339971, 91.39321757901101, 101.53818484275573, 79.65845092650383, 32.95569927461686, 15.621002970203278, 15.573838430066264, 35.217157486946356, 58.42185628029608, 63.783732383481926, 71.41243642376315, 9.414140466720829, 0.4043676824338975, 0.0396906974304828, 0.04094842994104951, 0.0273805282514302, 0.053285927391581, 0.06124668792190571, 0.08836833399630363, 0.016806207056487762, 0.05141900559406608, 0.1026983303768981, 0.09385814304433523, 0.03908567566184267, 0.07214091402748901, 0.0635790732508946, 0.01444087707392511, 0.03908069609033485, 0.020079262171601577, 0.037032598329167214, 0.018266202100823005, 0.08486039440838561, 0.15965197265388506, 0.04716903707312961, 0.05342465059290971, 0.20651873441473131, 0.492810664037543, 5.395050529510745, 95.35535274013397, 78.1517900959138, 80.74942681097215, 57.351680724851555, 36.597129683340754, 26.26084685325623, 55.29009865176294, 102.98441763847106, 98.52735780900525, 36.186065289282034, 0.25474525627589995, 0.5062511250857384, 3.207583417815547, 5.547054140798507, 2.856654351757419, 2.337333276387184, 1.1520478009216248, 0.2651576475510674, 0.11446871208928286, 0.13737035134146292, 1.42593722670309, 28.728045148234216, 80.8828030863116, 106.59575170086276, 105.3662847703503, 108.01172733306886, 103.07138442993165, 103.19982636359431, 101.8107189670686, 97.8687761675927, 89.58717792264878, 86.11515860403739, 76.63999096039804, 80.38483465871504, 85.87333663817375, 89.40384634079473, 94.86310312824865, 95.95891137276926, 89.4459725964454, 80.44887127414827, 68.61606890155424, 66.08665789327314, 66.55250995389878, 64.97012384476201, 64.37803030014038, 63.75913520013133, 67.03954281345491, 66.99446693543466, 66.00301727171868, 68.46177070371567, 76.08380671470397, 82.50742527746385, 84.20220298151817, 81.91589263177688, 75.9115283719955, 71.93797911367109, 69.98430144402289, 70.32496713822889, 74.33952085433468, 78.86703429683563, 83.31003635160386, 76.4042329788208, 79.9923466097924, 86.10504673373315, 77.34222073708811, 70.383834069775, 76.11103580844018, 76.50167249864148, 77.4670462454519, 70.72986556637672, 72.27758576793056, 64.80145800498225, 67.61775509003671, 65.6889295578003, 52.88095928007557, 48.980785800564675, 49.647055287514966, 64.35136602770898, 64.49620346869192, 72.85037732893421, 76.89310935235794, 75.44308754705614, 65.35774423230079, 62.76573611843971, 67.22529842007545, 69.03880626924577, 73.98726847863966, 75.11964105790662, 78.42833288254278, 77.49616592161118, 76.40710415378695, 76.51060765789401, 75.6654388673844, 76.75998410870953, 76.02523788329094, 81.61633337697675, 77.37657285505726, 76.2565008286507, 78.77400352108863, 78.12485125757034, 68.81262671562934, 57.597550576733006, 57.12843118175384, 59.29754895548667, 61.46598031443935, 70.68915136398809, 77.86452354923372, 81.84501540276312, 80.16425624970468, 77.55060057486259, 71.82652104285457, 68.66378845707064, 64.17338848114014, 61.51294285251249, 66.89840808991464, 70.69473681911346, 75.77377473154377, 80.01555919647217, 79.01044399507585, 78.82319788778983, 79.46221474678286, 82.39010718560989, 79.63201415154242, 84.30209790506672, 78.68433029420915, 6.023942770496492, 0.524086632555531, 0.6277815973566425, 1.5401543172136432, 1.8233076458977115, 1.6396344501164652, 2.876192658178268, 4.174772731719479, 3.3635871112346654, 0.572797138123743, 0.49227253323601144, 6.044802915665412, 44.131563478900546, 77.29619564548616, 92.5544588027462, 81.01369257896178, 65.68057883170344, 28.44277116560167, 21.229857975436797, 22.309945360306774, 43.332988523667865, 69.1529707754812, 69.6464127878989, 86.23060964768933, 13.11974379324144, 0.6331401678823656, 0.07784616998246602, 0.08967262933090811, 0.08623578270236332, 0.04719719463478654, 0.10087608299668759, 0.022102130742202845, 0.06523655427079048, 0.06378014834838049, 0.03394909443393831, 0.033211723315499486, 0.06139817414805294, 0.10535375200091832, 0.12269643510902122, 0.11612308662264578, 0.13036887461860336, 0.20275359612799462, 0.14923719118439382, 0.15492113457331735, 0.20262250316239175, 0.23780073970556262, 0.19936762539850128, 0.13229437532924837, 0.40310100201637517, 0.6653670966625215, 7.895659573616521, 108.62511542535599, 88.59533602191557, 90.57772544122513, 76.89212091507451, 40.802232142417665, 32.45135699549029, 87.08494109492149, 110.31429198480423, 106.38920753232895, 49.78875875473023, 1.0964149861566483, 0.2957682533850593, 3.784350055840708, 7.929590527088412, 8.493614119868125, 1.9790914414390444, 2.0271796997516387, 3.0233994558934243, 0.2507648472824405, 0.6839080791800254, 1.5844669265131799, 30.21351145159814, 92.48242839690178, 110.00171046103202, 113.49957035433863, 113.04332810063516, 109.20195487237747, 109.4947833399619, 108.18166009841427, 102.61509510778613, 96.8270887867097, 91.55896909775274, 81.32705857676845, 84.11392611842003, 90.72541052295317, 92.36282748560753, 100.1862850496846, 98.92080291624993, 92.28939287124142, 84.03528259646508, 76.97452206765452, 69.125992713436, 69.9350521641393, 71.29022321393414, 68.35410948722594, 68.4982644357989, 71.16740595909857, 72.12118517967963, 69.34457855839884, 71.15013968560004, 81.7552480389995, 84.70891829459899, 86.9115331096034, 81.94490248157133, 78.3796170450026, 75.94232682258853, 73.28557214429303, 76.18595307873142, 76.2371478542205, 81.02167067989227, 86.93927211146202, 78.68990790459418, 86.2172971233245, 90.15440756274809, 80.78898783653014, 73.33777104654621, 82.03828627063383, 77.22434566866967, 82.51776464523809, 78.0789359923332, 78.09151111110565, 66.91787873545002, 71.59108469563147, 67.07506379773541, 53.75303160759711, 49.837105889474195, 52.57923487694033, 68.56089684271043, 69.462265353049, 77.43063880551246, 79.71033603914323, 79.7873321656258, 69.31184245694068, 65.39757197903049, 72.30560718044158, 74.07831453507947, 79.48075971295758, 81.07009626203968, 85.45276441881734, 80.10406355704032, 79.21676066613968, 79.92914938157605, 78.02563882643177, 79.34710102696573, 77.65037782730596, 85.03428674513295, 80.18694323878135, 80.18850434210994, 80.956677006137, 83.13005447387695, 71.9034073429723, 61.63366556167603, 63.09635270026423, 62.832569383805804, 63.811922457910356, 74.68921584467735, 80.85395797606438, 83.79884212247788, 85.65351916897683, 78.67184146758049, 75.54728923305389, 71.1874649601598, 66.79179806863108, 63.57452100323093, 70.73297992829355, 73.95638373590285, 79.97377810939666, 83.72489759998938, 83.94004744868126, 82.14667704797561, 83.75939092328473, 86.11888485570108, 82.3755551922706, 88.92050050920056, 75.92101266307216, 3.5006153583526616, 2.5474860254795324, 5.801292369442602, 2.7916638649279073, 1.9554575676879578, 1.9452286391488969, 9.561077356338501, 9.134854962748866, 4.147929010852691, 0.6295686046923361, 0.6690445025601696, 13.328586470696235, 57.560448877273075, 89.14973166681106, 106.51360942471413, 119.1166554727862, 104.02010379299041, 46.595627800110854, 25.990450420687278, 33.127114695887414, 54.802759847333355, 79.7067980612478, 79.42918054519161, 97.30850481217908, 15.063400787691917, 0.8462465230015017, 0.26134246840111675, 0.20799100218761354, 0.2565808948730269, 0.1342971743114533, 0.2447066852642644, 0.16416222337753544, 0.19218728246708072, 0.1630270496130951, 0.21051069601408898, 0.12834625694179727, 0.17740013077855113], [0.05586236152016828, 0.018109692253112313, 0.061250805644498724, 0.02733881476395313, 0.037254380783246416, 0.06830839830781184, 0.06676230264166672, 0.06435582894952067, 0.09288111281010414, 0.08618884449524265, 0.0986915986023603, 0.2613894755561506, 0.5856090699953418, 11.91777071645183, 92.59555739741172, 68.92210006713867, 56.91467377447314, 46.27544864531487, 23.679072203174716, 44.063941817129816, 78.4850581999748, 97.0739862995763, 66.66118314189296, 10.24097707963759, 0.07572291133504722, 0.0828162573217865, 5.542479186288772, 1.798319573844633, 2.474111717554831, 1.0825728192444772, 0.659269894803724, 0.4657480258855128, 0.2593647971028282, 0.06266755119506871, 5.105401142950981, 33.88554419240644, 88.22617038603752, 99.25304335932579, 100.28981993275305, 98.73194863719326, 97.07747720902967, 94.38448767508231, 94.37289314885294, 84.54249212818762, 78.3739923661755, 71.72953651797387, 70.12750717901415, 71.1429068350023, 81.75549907069053, 86.77851769231981, 93.66055150185862, 91.40728319844892, 86.90505335407873, 81.83669997799782, 65.48719813746791, 61.93295417293426, 62.41729236418202, 61.33664800274757, 61.98670633377568, 59.58787102853099, 62.43829665645477, 61.08973872277045, 59.49894305198424, 62.99814439588978, 67.46509644293016, 72.982145432503, 79.88673287053263, 80.45290347068541, 74.77306042948078, 75.13608363366897, 73.63103097484958, 75.2766300016834, 73.33094612244638, 78.28413086552774, 80.84455213239117, 75.94012245055168, 75.9615856601346, 80.17084583159416, 73.26062586999709, 68.2208901066934, 68.68038792763987, 79.04227795139437, 65.34975828662996, 65.64608158603792, 62.91537846288374, 63.15358008107832, 63.08143592649891, 62.95848138870732, 59.794760365639966, 58.01650285720826, 54.16885775904502, 59.684996758737874, 57.25754384071597, 63.63998143903671, 68.0884002870129, 70.79203513360792, 64.13904420791134, 61.90298334244759, 55.91640703139767, 57.6334834098816, 62.63928674882459, 70.4054541741648, 71.59326553344727, 75.24851445228823, 71.39877088608281, 75.00797902384113, 74.64728570753529, 74.59767556959584, 72.2249318707374, 66.53083493632656, 65.54925395596412, 75.95758484255883, 72.85750035316714, 67.71440229108258, 62.098317377028934, 56.691738020989206, 55.11803603941395, 54.38187776073333, 57.08662263808712, 67.83143797228414, 75.76080737575408, 76.599927871458, 71.13514054206111, 76.66089719341647, 70.7751375629056, 67.22347059557515, 64.48901768653624, 60.166208820958296, 59.45578521297824, 60.98984379922191, 68.75305375745221, 74.92380495994323, 77.49706022201046, 78.05577047409551, 78.81933827554026, 77.96972936199558, 80.56817408530944, 82.44865248280188, 88.00054780898556, 76.64189723230179, 5.243908859068348, 0.9663054323004139, 0.4717742880025218, 0.3721562286298121, 0.5067565898981787, 1.9192512717939194, 5.188242581582839, 3.1314825723248148, 0.2847631245611176, 0.047405176014909824, 0.10682496257246503, 19.586190715912853, 48.91505864358718, 81.67221930719192, 93.24256804681595, 57.89642733912314, 82.50771553285661, 67.51662069751372, 61.691355782170454, 35.52130199247791, 54.71722472098566, 62.003078306874926, 71.4806935095018, 28.680904142318237, 0.49519883588917796, 0.1539928658354667, 0.13941925349495105, 0.09723187934967781, 0.16492610496859397, 0.05234861498578422, 0.06220524394584279, 0.0623700256279159, 0.07220973170572711, 0.02132888372626997, 0.029784008455012115, 0.003928111043698605, 0.017219674285320986, 0.034355408316778566, 0.030356525113025022, 0.07458695616092413, 0.11182257545090492, 0.06611430717091407, 0.024515978030620084, 0.037403564915181174, 0.11650932517143027, 0.15276367776095867, 0.12239857246318173, 0.13808811443947977, 0.8722276288655497, 14.735965248077148, 105.2429654521327, 77.87635341767343, 68.009780299279, 54.56948472607521, 38.51130516298356, 38.2028538950028, 70.68869636904809, 113.1352763022146, 74.59540059489589, 12.569729435828425, 0.13426916613694162, 0.7773863115618307, 5.516068397029754, 5.680960916703747, 3.6742782977319535, 2.368140797461233, 1.111911290114926, 0.6446416603942072, 0.5500597711051665, 0.024228461402198, 6.1640243376455, 37.488676578767844, 93.02868120131954, 104.03002738952638, 102.66129278367566, 102.69056150990149, 99.85817878477036, 97.17304183590798, 93.84492643417852, 85.2304837011522, 79.17995314444266, 75.493207593118, 73.08662952915316, 75.77312361809516, 85.36462091630506, 91.45782686048939, 95.54946299522155, 94.44478234937115, 91.18937200115573, 85.69800669147124, 69.03891609561059, 66.1136830237604, 65.89288496202039, 64.92656200162827, 64.52540159225464, 63.11183429533436, 64.84252914305657, 64.83736338153963, 63.33460530927105, 65.9094608983686, 71.00134065074306, 77.37326237463182, 81.02853482769382, 84.13553053332915, 78.63415533496489, 78.5259920550931, 76.02341005879065, 80.81438910576605, 76.44193480091711, 81.33074560473042, 83.17678559210994, 79.2590908850393, 78.94832934102705, 84.03502372003372, 76.91334878244709, 72.93692834915655, 74.36964465725806, 81.2757069064725, 68.34409175380584, 68.47980576176798, 64.30369354063465, 65.11909546390658, 65.49213247914469, 65.8819886176817, 63.45331192016602, 62.79429489566434, 60.253391342778365, 62.4201282378166, 58.8142894160363, 65.25763750076294, 71.3721929057952, 73.43933689978816, 68.35947528962167, 65.31098173510644, 58.74121565972605, 60.169189822289255, 62.971895894696644, 71.50421988579535, 75.02122094554286, 76.19786139457457, 74.66270846705284, 77.77068476523124, 77.75843912555327, 77.51815472879719, 73.52151839963852, 67.8599065349948, 66.67480161113124, 77.59840642252277, 74.9034478587489, 71.89272280662291, 64.31045178444155, 58.785616890076675, 56.641939609281486, 57.509069750385905, 58.493000230481556, 70.74034613947715, 78.74851595970893, 77.63009917351508, 74.81313136316116, 79.53599452972412, 74.49078313765988, 71.53323758033015, 65.73864952210458, 65.18029620570522, 61.789230685080256, 63.563895302434126, 73.18940347240817, 77.83063427094491, 78.57701424629458, 83.16665018758466, 81.31715851445352, 83.17450277266964, 84.10345339005994, 87.35879313561225, 88.80641445036858, 88.89675448017736, 11.279837412218894, 0.3251923115984086, 0.31662153440617746, 0.8104183068198543, 1.3255234471251889, 4.084598912346748, 6.140949033921765, 4.481255460170008, 1.829994674171171, 0.05608485260557744, 0.2054929120406028, 18.987009448389855, 55.38176836506013, 84.71295833587646, 98.79727963478335, 53.06838581638952, 63.72899570772725, 44.44191317404471, 67.66030496166599, 46.15813447583107, 60.48374037588797, 68.82382116010113, 82.41447294912031, 35.34890205629411, 0.5527608745521115, 0.23194079527691489, 0.16806041581496117, 0.11545105897370847, 0.14946767639729286, 0.0643430199594267, 0.1208734522844034, 0.12489436434641962, 0.07448411651796873, 0.04775206445746365, 0.015378265130904414, 0.06495506292389286, 0.1709035059977924, 0.1659482041554105, 0.16773187134775425, 0.17589306729214807, 0.2075973249250843, 0.13834556594731348, 0.15971073159767737, 0.19271577588252484, 0.26306656459646843, 0.41409715228984434, 0.2619709975777134, 0.3379672873885401, 0.9404520486151019, 17.331996733142486, 119.20278287702992, 89.39915518606864, 78.3823391699022, 66.79754041856336, 35.88657663714501, 60.218411645581654, 108.0685075636833, 115.1089031465592, 93.09271781675278, 17.781249323198875, 0.1725380158712787, 0.5333584414855127, 12.014865067697341, 9.241363983000479, 9.592347471944748, 3.5534121769089855, 2.627735758020032, 2.885389635639806, 0.6085983880104557, 0.16558688644680286, 6.669910559731146, 41.68431043624878, 102.48237779063564, 112.09882920788182, 109.53734890107187, 104.22099190373575, 105.29619986011137, 101.91043346158921, 100.6675834040488, 89.69149727975169, 85.93605533722909, 78.87888769949637, 78.0994107646327, 79.55890117153045, 90.56858631872362, 96.89787972357966, 100.89640663516138, 98.3020882452688, 96.17714420441659, 90.02662458727437, 73.37325280712497, 68.74233784214144, 69.55442536261775, 68.43225879053917, 68.47851922435146, 66.60235543404856, 69.02608994514712, 69.74106742489722, 66.32193734568935, 69.49689988167056, 75.0954008102417, 81.04433413474791, 85.64531357057633, 87.14383156068864, 83.11751073406589, 82.30541536884924, 80.39824916470437, 85.2404857450916, 82.24773299309516, 83.19185533831197, 87.38443759179886, 79.5093616362541, 83.33181335080056, 88.82865428924562, 81.5828755594069, 75.36864880592593, 77.20791093764767, 85.9706663316296, 73.59216813118228, 74.7978105852681, 69.12163103780439, 66.61190248304798, 67.05369472503662, 69.17995668226673, 65.09635356164748, 65.30453728091332, 62.31042738883727, 66.195095739057, 64.2826186456988, 72.31378924462103, 75.40562891191053, 77.36582556078511, 70.96410166832709, 68.00180219834851, 62.6050679914413, 63.63311729123516, 68.0986298284223, 78.59653196027203, 79.1801178839899, 80.9454119590021, 75.47186205464025, 81.4361475360009, 79.99954808142878, 78.33311342423963, 76.18062650003742, 73.94429499103178, 69.49809228220295, 80.65565078489243, 79.56728719895887, 74.25356603437855, 68.34449183556342, 63.39545303775419, 58.70376094695061, 60.35829905540713, 63.2413980268663, 76.60065743231004, 85.16684716747653, 83.89630517651959, 78.92000198364258, 84.1140437895252, 76.4472064664287, 74.01137536571872, 68.5682708986344, 68.45443587149343, 66.36172586871733, 67.65460968017578, 75.87960027879285, 82.65456122736778, 82.72406562682121, 86.54920808730587, 83.90473042764972, 86.71005664333221, 87.02259109866235, 90.33207524207332, 94.11717814783897, 87.80675134351178, 7.430235051339673, 2.88507069791517, 3.3442059447688446, 1.9905169380287973, 3.227467137959696, 6.359125971794129, 11.904310122612985, 7.40485143276953, 1.2609515507375042, 0.12341809759457266, 0.36778937424382857, 30.76100764736053, 69.65075092930948, 96.03032204412646, 108.22177810053672, 75.65485631265949, 110.13154091373568, 86.92570071066581, 78.4857250029041, 52.39200838150517, 72.6549256232477, 78.77490566622826, 94.95284695779124, 41.39228605454968, 0.6944050159185164, 0.36006631930508926, 0.28080189840928205, 0.2715214786510314, 0.3482395458605982, 0.10940195977567665, 0.20648761592324705, 0.23562840546571442, 0.12016562534676445, 0.11267152344507557, 0.09820841162675813, 0.16045346916202577], [0.029398518757173614, 0.08001586887985468, 0.03430156382702051, 0.012680663663383215, 0.012679787450319818, 0.0543971149431121, 0.033392068073754354, 0.057072347600854216, 0.04938798776317028, 0.07176101102583832, 0.07309300809978478, 0.13192357345213815, 0.5920050461446086, 18.019845139595773, 88.0785245280112, 61.03667689907936, 68.9969624242475, 42.56219571636569, 28.902833807852964, 34.829733217916186, 79.11441033886325, 89.05332765271588, 37.16162935380013, 1.0069691341730858, 0.08175867294231731, 3.4721970510098243, 3.1466802858537246, 3.87766765490655, 1.8146336919838384, 2.2238242962668022, 0.06192124366099316, 2.6787719226652578, 2.328441263206544, 0.19270429988541912, 14.849668875817331, 54.21925629338911, 88.16554623265421, 95.77425402979698, 92.49727064563383, 96.89688344155589, 93.77426101315407, 86.4535963919855, 76.3129908038724, 71.44560398594027, 71.09615218254828, 69.89014102566627, 68.94100589136924, 68.58836127865699, 77.20976229636901, 90.034924322559, 88.36956439479705, 86.05942172388878, 86.02336729726484, 81.88475685734903, 71.15275198413481, 64.1217661673023, 64.37941881918138, 61.8436025804089, 62.174246618824625, 60.32597872518725, 60.04048901219522, 60.1112211135126, 61.12367506950133, 60.787751520833666, 65.68540334701538, 72.33053776525682, 80.43573133407101, 80.21849478444746, 80.1156267043083, 79.53357834969798, 77.44661069685414, 78.87881709683326, 76.46574358786307, 82.86553767419632, 77.2042239096857, 78.99207945792907, 80.06949178634152, 78.71622700845042, 69.71461496045514, 68.11410750112226, 72.82389348553073, 73.31633921592467, 66.88335403319329, 58.423260488817775, 62.804563660775464, 72.77921768926805, 64.85164080896686, 60.835941760770744, 70.43902966283983, 71.7568911275556, 69.29900846173688, 62.8402493846032, 55.04900624675136, 55.571010958763864, 64.38000325233706, 70.950145875254, 72.22758339297387, 67.38167547410535, 64.32907127564954, 59.216489253505586, 54.21032505650675, 55.22258681635703, 61.13252785898025, 69.26473479117118, 70.80498679991692, 73.06884550279187, 71.36409713375953, 69.70577393808674, 64.96925700095393, 63.80177528627458, 66.48331934405913, 73.38762437143635, 70.54742044018161, 67.96451614749047, 58.90086004810949, 56.603076765614176, 53.867121588799264, 52.44411706924439, 56.084566885425204, 64.52493090783396, 69.1265183110391, 77.02987455552625, 75.03815773994693, 78.05147155638664, 74.44027869932114, 71.71878137896138, 68.39680840892177, 63.6547177837741, 58.893156513091064, 60.78042453335178, 60.11763811111451, 68.58394468984297, 72.75559717609038, 78.66925270326676, 78.38873263328307, 83.49553308179303, 77.74417738760673, 82.41188418480658, 78.94772529602051, 83.54630424130349, 75.76978960344869, 4.13801129787199, 0.7496454710921934, 1.8579617863701237, 1.5265478602340146, 0.10820484014167901, 3.406358596778685, 2.3088181355307182, 1.067625524536256, 0.08890408992526994, 0.2759659224219861, 2.2741539439847394, 29.392202438846713, 47.585394767022905, 59.858942108769575, 88.3075438776324, 108.73400826607983, 111.84797010114117, 47.07980909655171, 23.176757789427235, 57.197735540328495, 49.302369163882354, 70.74445678341773, 37.54994007848924, 0.1407268736511469, 0.03577742838270722, 0.060215767232641104, 0.030963755130106886, 0.04820909719133089, 0.03346145265705643, 0.044016543129879626, 0.026446661326072873, 0.05322434924422734, 0.0663920063825865, 0.06628687613673749, 0.013843014396937385, 0.03700157559867348, 0.09105268310034469, 0.031878138524329955, 0.05577151498366749, 0.04952369257807732, 0.0577883601879641, 0.12963966616699774, 0.03720562311730558, 0.03897848463947735, 0.045763089531852354, 0.06691055597677346, 0.06769306882615052, 0.7045386431197966, 20.793111862674838, 101.40827594264861, 70.26327610015869, 73.4011173248291, 47.44187132004769, 33.8462185090588, 36.969629333865264, 89.13611319757278, 96.50385410554948, 43.92358764525383, 1.2909524118708027, 0.052013953306501916, 4.439683729602445, 3.973639963134643, 4.044142115500666, 3.146550847638038, 4.077013293581625, 0.672607546852481, 4.76487910555255, 2.429905134824015, 0.44488545987875233, 16.589654837885213, 67.74519289693525, 99.84926715973886, 101.07420767507246, 100.6026367987356, 100.68084101523124, 95.6864635406002, 88.5207639201995, 79.91113001300444, 74.44744094725579, 73.3171864478819, 74.37049188921529, 70.479414386134, 73.38505129660331, 78.56456464336765, 90.68999152029716, 91.7684393544351, 86.54189678930467, 89.59521878150203, 86.18853046048073, 75.96258194215837, 66.81783476183492, 67.625591985641, 63.45432781404065, 65.47020642988144, 65.39456352110832, 63.536709354769805, 63.364183902740486, 62.880649797378055, 63.15421550504623, 70.00327787091656, 76.60010045574558, 81.76347717162102, 80.79747584558304, 83.47769414224933, 83.5571535172001, 80.40706665285173, 82.55489380128923, 80.6553134610576, 87.11709668559413, 80.43626477641445, 82.003918463184, 81.2133647549537, 80.17714515809091, 72.08381283667781, 70.24982237046765, 74.90658575488676, 74.63234147717877, 71.49914433879238, 60.270394817475356, 64.42265118322065, 74.53688667666528, 66.88777062200731, 63.018662314261164, 72.15620410057807, 77.13813197228217, 73.33113439621465, 65.56279790016913, 57.45307791617609, 59.30773927319435, 67.91794976880475, 74.56128381913709, 73.33088336452361, 71.65258745993339, 67.66520792438139, 62.158094298455026, 57.36156509768579, 58.20487468473373, 63.07236740666052, 70.70033796371953, 74.28128934675648, 75.82583242847075, 75.36893906131868, 74.79123669285929, 70.81302765877017, 69.09485693900817, 68.18012883586269, 76.56441473191785, 74.25392689243441, 71.7061121233048, 63.021098106138176, 58.32012960987707, 57.06978782530754, 56.27810447446762, 57.108827175632605, 65.23420133898335, 74.21340096381404, 79.4265604019165, 78.79495682254915, 79.68214204234462, 80.21130115755143, 75.16665458679199, 73.86854617826401, 65.85728553033644, 61.203146211562625, 63.02260821865451, 63.361387252807624, 71.22246819157755, 74.28812211559665, 81.34378356318321, 80.45152279638475, 84.30791870240243, 80.86830600615471, 83.0266764856154, 83.69132995605469, 84.9226874689902, 86.11064003359887, 7.8381385053357775, 0.5558371159338182, 0.7622112129484454, 3.640611859098558, 2.5372868824389676, 5.0409536592421995, 3.954225211374222, 3.1939335696158873, 2.3112129876690526, 0.7074295525108615, 2.0087935895689073, 34.21060669806696, 53.38841984348913, 68.4243905159735, 91.58471553556382, 112.12971395061864, 105.06837291102256, 52.47250718455161, 26.404721352361864, 64.12897156130883, 55.26544655522993, 78.61026810061547, 44.932656595783854, 0.07299792892750233, 0.045779361239364075, 0.07634331997964652, 0.03857155405585805, 0.0794552763803832, 0.06471186831233001, 0.020451485141811353, 0.06472964921305258, 0.031825337829368736, 0.040731680684632836, 0.056055775738411376, 0.04507337674318303, 0.09433923859990413, 0.2289265763735579, 0.06819679461900266, 0.237945131957531, 0.17559933386022047, 0.16897216769716433, 0.1784863515246299, 0.18037183180211053, 0.10434777130402866, 0.12399719877829476, 0.13457224584154545, 0.2688243895048096, 0.9914183460416334, 22.744857765013172, 117.81526796279417, 79.05576306004679, 88.62124719927388, 57.11735833075739, 41.60947945810134, 52.227092327610144, 102.55150564255254, 102.48158547186084, 56.973830961412006, 2.96458498604836, 0.22459540636308734, 9.268394997042995, 7.990823628440981, 11.189502285372827, 8.546887751548521, 12.899457600808914, 3.1049872069589557, 4.619716598141578, 3.5450906234402813, 0.4612630713851222, 19.175449917393347, 77.02701122530046, 107.74632407772927, 105.21523429501443, 102.84198068803357, 104.82968099655645, 101.4367994185417, 94.8262877618113, 85.37012007928665, 77.85048146401682, 79.41369502775132, 76.4051821924025, 74.96054972371748, 76.41039894473168, 83.82174091954386, 94.49516911660471, 96.03364036929224, 89.7366516051754, 95.50945481946393, 89.11364586122575, 79.95378971099854, 71.36886673588907, 70.48663154725106, 65.80281165338332, 69.16092534219065, 69.45428725211852, 67.55384399044898, 66.18707841442478, 67.36552315373575, 67.72658517283779, 75.35932925439651, 79.18455800702496, 87.72490716749623, 84.34555776657598, 85.13363253685736, 87.36335877449282, 86.56344629103138, 86.37702388148155, 82.65380028755435, 89.75444347627702, 83.69445216271185, 87.04046141716742, 85.15015356002316, 86.58639215653943, 76.31669352131506, 75.29161345574164, 79.27335262298584, 81.10548388573432, 76.12234792401715, 64.67311020820372, 69.51538993466285, 77.57706872878536, 67.4098067129812, 65.68092007790843, 74.1823201025686, 77.24718955255325, 75.5814609219951, 69.30737879968459, 62.3919616976092, 62.21583550976169, 74.2882162524808, 78.61029163483651, 76.4930275947817, 74.82239600150817, 70.80023288726807, 65.84958199531802, 61.83631089425857, 62.28546934743082, 67.7072714221093, 79.36268852603051, 78.44940385510846, 81.8536053934405, 80.05768545212285, 77.45025850111439, 74.50188344524753, 68.54257937400573, 67.32599350713915, 81.6212441844325, 78.04234027862549, 75.83471267454087, 65.02567245114234, 63.236196964017815, 60.68154158130769, 58.30950783145044, 60.80826551683488, 70.36706985965853, 76.25126838684082, 85.1872121134112, 82.83459017353674, 85.47567106062367, 81.09465029931839, 77.30581329714867, 75.11822115990424, 69.39903674587127, 64.37716737870248, 67.27781111194243, 66.04231157610494, 76.62197943656676, 79.64108267138081, 87.72743317388719, 84.95688269215246, 88.99082076164984, 85.1923268841159, 87.51607233478178, 88.6066246032715, 90.6636175032585, 87.45114141894926, 5.076965430090505, 4.424097701426476, 7.55392405294603, 6.837940975542992, 4.546605579314694, 8.996190351824607, 9.863707826983545, 2.6136431722871722, 1.5452763197883483, 0.4730386395127543, 4.663866306504896, 48.51366289200322, 63.85676691609045, 77.34465260659495, 102.08957595209922, 120.49501557503979, 125.51057384860133, 57.6593828201294, 35.41862218610702, 77.90897969276675, 65.62897220734628, 90.82960436421057, 53.01683802758494, 0.1641304154069193, 0.12140032159344805, 0.2274477968533193, 0.1277430699537358, 0.22188609045359398, 0.2535806494134088, 0.13447342049931327, 0.09675384048492679, 0.14262902400185987, 0.2066023452507873, 0.14746886107229418, 0.10361149186088194], [0.01905086574204747, 0.0335231380567195, 0.02078388494649722, 0.046271833200608535, 0.12056166216010049, 0.0035719206179266856, 0.032192313097297184, 0.01497871867726527, 0.03426010314855845, 0.0558006722900656, 0.025603485804411675, 0.161264005507673, 0.317332218851774, 13.808056019967603, 79.98793786571872, 71.5823927233296, 63.3465136251142, 31.543151793941377, 46.8614193700975, 50.36473135794363, 92.15940552373087, 72.0157910931495, 18.462239465405865, 0.056256008139180566, 0.08315316746912657, 2.3621991420945814, 1.8096027619415715, 4.1993022541846, 2.0807563345278464, 2.3345405488244952, 1.4066669897687052, 4.144664127980509, 0.36779654482679985, 7.231274295237757, 61.16299290810863, 92.74900836329307, 96.74134577474287, 100.24548930506553, 96.5697499244444, 89.57899585846933, 77.48126875969672, 73.76714506456929, 72.12770415890601, 72.27291030268516, 69.96982789808705, 68.32586842198526, 67.76108634087348, 69.38460242363715, 75.14849401289418, 83.47641544957315, 85.80895485416536, 86.4589386601602, 88.52103064137121, 85.37474063134964, 74.11140364985313, 64.06208338276033, 62.54625205070742, 62.857119498714326, 63.20071520343904, 59.307519620464696, 58.711452714858524, 58.087360474371145, 59.26573461101901, 59.52927081815658, 66.37105326498708, 75.3392388743739, 79.28164451353013, 76.03680887529927, 76.58986306959584, 74.79187211682721, 77.79373261236375, 82.23925282878261, 75.88235378265381, 79.99048740633073, 76.87747478485107, 75.05715770106163, 73.65949953756025, 69.85677734498056, 64.14090341137302, 69.3179613544095, 72.76019419393232, 70.92720000974595, 62.08270242137294, 59.27592100635652, 72.48180004858202, 79.52798504983225, 60.32784577338927, 61.7851867214326, 69.19348885936122, 74.51401141382034, 70.52309390037291, 62.24560629936957, 56.98118148311492, 56.2682044121527, 62.232368300038004, 66.74590633761498, 68.67827769248717, 69.95325980647918, 66.409633698002, 63.06045124607702, 58.71735980433803, 55.37848926359608, 54.33638611147481, 56.02984589915122, 58.32209863970357, 63.484847776351444, 65.73075771331787, 68.08767072616085, 70.55508475149833, 72.61050085867606, 73.49318319751372, 73.52467982999741, 72.8390024554345, 68.25459111121394, 63.65946777405278, 53.746744048210886, 55.30685501713907, 53.61632523998138, 54.890828824812374, 55.14501410145914, 63.968558388371626, 71.99948187797301, 73.13907161835702, 75.74396471823417, 73.99514459794568, 73.18927011182232, 70.85852715276903, 65.24241478212419, 62.98078790787728, 56.97610201374177, 57.644756301756836, 57.86464829598704, 64.14380204293036, 66.64017492725004, 70.88840776874174, 72.37432710586056, 76.08969811470278, 72.32163398496567, 81.53192397086852, 79.26099715694305, 89.34551285159203, 51.60946415316675, 0.6058871722029102, 0.704540481730815, 0.6098685005018788, 2.026019045902837, 5.051165549985824, 3.4530556394207865, 3.476537398753628, 1.7150911688804629, 0.08104300126433372, 0.3483436418877494, 11.815754771232607, 36.60044016376619, 62.645213450154955, 98.9616975476665, 125.74160929649108, 87.63634789374568, 31.50089413888993, 38.01130102526757, 36.495740336756555, 56.17215733374319, 63.950872421264656, 46.66016255655597, 0.12325359553459192, 0.05079010869526575, 0.07713128737504445, 0.002291324692064776, 0.10851370381011118, 0.04715103400690902, 0.06182790733873845, 0.046657183087400855, 0.02950069573407452, 0.05983587189186966, 0.03765099599296528, 0.03554511605010879, 0.038549942715514096, 0.04451190324259862, 0.023476300956380945, 0.06378261132105705, 0.08021858340549855, 0.049785028151687116, 0.03996450491549988, 0.024394148983241572, 0.10961130862274479, 0.011786656292726197, 0.14686784977393766, 0.08815024408601946, 0.5729511524400404, 19.037653130869714, 93.51337632825299, 79.84573625749158, 65.99021465547624, 34.42051233783845, 31.31179863406766, 39.71966581959879, 104.99229461916032, 82.04217726184477, 22.248823065911573, 0.11014087456128291, 0.5691595075111235, 5.031441911574333, 2.491678297519684, 7.8782922990860484, 3.1075183614607784, 4.169439779173944, 1.9566503359425453, 3.8684402790761765, 0.10944411759414982, 12.399662329304604, 76.42185226563485, 103.09010982513429, 101.88002724801342, 102.83029202492007, 99.94605556611093, 93.21864943350516, 81.5933169088056, 77.40075034479942, 76.34349115433233, 75.31177443842735, 72.67009735107422, 72.51808197267594, 70.57117431394516, 70.47616666363132, 78.45278493819698, 86.74514616689375, 86.9586721543343, 89.79557344990393, 91.95287704467775, 88.41390286722492, 77.44069576263428, 68.15173872055547, 63.2011035180861, 65.18434016935288, 65.61561261453937, 64.49405793220767, 62.54416927214592, 61.839558616761245, 62.81315757382301, 63.536191601907056, 71.38239891298356, 79.15244164005404, 83.89217099835797, 81.01430446870866, 78.23632501786756, 80.62101625627088, 79.64537374434933, 85.26917396053192, 80.08220811044016, 81.89634353883805, 80.1004942001835, 77.60525488084363, 74.22695667512956, 73.63771469362321, 66.33855250573927, 72.27251022092759, 76.36246758122599, 74.13938583866243, 66.22498419977003, 62.1753841061746, 76.5443321966356, 78.27225392864597, 63.60813963797785, 65.74547052383423, 71.54853482400218, 75.31366502085041, 74.22495626634168, 66.00585706772344, 58.11418164160944, 59.32686867252473, 64.24634064397505, 69.57813216793922, 71.85808043326102, 72.10584086756553, 66.80278070511358, 68.93043118138468, 62.55312404324932, 58.92152701654742, 55.66793664809197, 60.41975475126698, 60.565455113687825, 65.84440446669056, 68.86984625170308, 72.21390216581284, 75.42457395984282, 76.36482884806972, 76.52481448265814, 75.67777079920616, 76.75184911297214, 72.10380907981627, 67.25929752472909, 55.90769936961513, 58.832077364767756, 56.10555941058744, 57.828907658976895, 59.381825001009055, 66.76966805611887, 75.61527959762081, 75.73693583088537, 76.59302449995472, 77.45920150510727, 75.61480891320014, 75.09951145418229, 68.76065531084615, 66.37433236645114, 59.937299297701934, 61.62556978964037, 62.35624459482009, 66.57992732140326, 69.86246478173041, 72.89670836540961, 76.06786620232367, 78.41505173713931, 75.3493978131202, 85.55596197805097, 85.18106183698102, 89.50934240894934, 62.681028612198375, 1.2901240563200367, 0.6166447626967585, 0.8636003756715406, 4.179544785330373, 3.3508087646576667, 4.113594543549323, 4.133699632460072, 5.337123495917167, 0.133073624644068, 0.3706175563556533, 12.071442315655371, 44.44168175420454, 68.24917824037614, 102.07998183465774, 123.48008832623883, 89.40876499299081, 28.266439053320116, 38.91284996463407, 44.17546656823928, 63.059678539153076, 71.08234543954173, 55.32328974816107, 0.14561863616108894, 0.04024447940830742, 0.02262698140956702, 0.10689052437702495, 0.09943380756604095, 0.04087295112830978, 0.033168864526575616, 0.017993710371815873, 0.13510651555993866, 0.04118689779011954, 0.04681895787437116, 0.0624396285462764, 0.1780619694580955, 0.1537263744901265, 0.14444258394500903, 0.2458949029565819, 0.23232702616482015, 0.2726950027769612, 0.16009169180066357, 0.10993842816641254, 0.11777787484348783, 0.14303178706717107, 0.2084209460524782, 0.34702563357930033, 0.8554362685930345, 22.21777162244243, 106.04228173532795, 89.73418051196684, 81.28968623376663, 46.31393494144563, 61.63722315142232, 72.72780326104933, 112.32574616709064, 95.93715006305327, 33.383873047367224, 0.5383690242325107, 0.3227847424005309, 8.338672653321298, 7.032695970227642, 14.53711578922887, 8.229385614395142, 15.878586000011815, 6.52389983977041, 9.498384152689288, 0.4849423281848431, 12.37040242841167, 83.82265875416418, 106.99364477588286, 105.32741408194266, 110.5094220561366, 104.16406262305476, 99.01396705258279, 87.44050395104193, 81.65701620040402, 81.62660998682823, 79.8481995059598, 75.97771444628316, 76.41545880225398, 75.82523622820455, 76.90948132545718, 85.60426204435288, 90.86920461347027, 90.02736199286677, 93.05000320557626, 95.24368286132814, 92.36180766936272, 78.87465938445061, 72.25944872825377, 68.88038173798593, 70.27973436540174, 69.77860450744629, 66.17870807647705, 65.79528462502265, 65.67820972011936, 67.34956695187476, 66.10760334999331, 73.6818099791004, 83.38586361177506, 87.06765128720193, 83.72350908094838, 80.11525015677176, 80.82219462240897, 80.34246521611368, 87.21233967811831, 82.53211267532842, 86.93721678949173, 84.99533760932185, 82.42685194938414, 81.37625294346964, 76.2311387831165, 69.45580913174537, 76.22012476767264, 83.20665051860195, 82.20215505169284, 70.13387710817399, 66.19777079551451, 80.46495299185477, 81.78334005417364, 63.43798721990278, 70.16503641682287, 73.64758337697675, 79.9461881576046, 75.52202132440384, 65.80562399279687, 62.62195379503312, 63.146005984275575, 68.86270753798946, 72.90670256460868, 75.23805741340884, 72.86359571641492, 71.19697278545749, 72.20371969284551, 66.82797801110053, 61.70011443476524, 59.435628152662716, 64.38481600053849, 64.74331278954783, 68.91118018857895, 74.1541104162893, 74.31037764395438, 79.59980364768737, 80.76824634305893, 80.98798536485242, 76.1513420843309, 80.49441783658921, 76.61184403204149, 71.54756207619944, 58.49254915791174, 61.9009986231404, 59.536362463428134, 60.89871145063832, 61.885560174142164, 70.4717500748173, 77.80677841555688, 77.49420473652502, 81.52778194796655, 82.04063969273722, 78.89092153118503, 77.23747776400658, 71.61527003011396, 68.92934860721712, 62.420383191877804, 64.63299220608127, 64.50493074232533, 71.15072804112589, 73.23701320155975, 76.39740805472098, 80.7641435438587, 83.63587548655849, 78.12282731456142, 92.02283643907117, 87.13600250982469, 98.31547921703708, 61.799730870031546, 1.2076460497994577, 5.5314583066971075, 4.3722390647857425, 12.596471175070732, 13.433333366147934, 11.482053245267561, 10.564711862994779, 4.89246400133256, 0.40545978673523475, 0.5116515240121273, 19.314535202518588, 57.27138588505407, 78.32673565033944, 106.82728921213459, 123.56648245165427, 97.95262859713648, 47.60104894638062, 54.66830492019654, 55.2122199919916, 75.35241019341254, 81.50115689923688, 64.4513354762908, 0.31653413909577555, 0.2100954303938535, 0.17627286304148937, 0.16710827577738993, 0.2778071687827187, 0.13570092318038787, 0.23371755235618163, 0.16474299463293246, 0.2776350135043744, 0.19643087330604755, 0.06341136511295073, 0.1429410516134193], [0.03766369006987061, 0.04042208923267261, 0.017124204408197154, 0.027663727974398967, 0.04065376571229389, 0.05378929695354835, 0.04319311352446676, 0.02802745311430866, 0.026171585965541103, 0.012121324675277838, 0.18720469257283598, 0.17792669365242605, 0.6130910953206401, 12.9016060790708, 79.9303182478874, 60.821181881812315, 65.32007771153604, 48.188804349591656, 45.31899436827629, 73.8468554712111, 91.76446207108037, 49.2604939399227, 4.931650440539084, 0.12881724013676568, 0.08219569545960234, 1.6576255040784038, 1.7295506187985021, 2.6726768045656146, 0.8612911415196235, 0.9363202606478046, 0.8770900808515087, 0.038483036426647056, 4.295811191681893, 72.68916791485202, 102.81506538391115, 97.27791032483502, 98.02863628633561, 91.23101188290505, 88.43750769092192, 77.36823389607092, 76.1624502366589, 76.3742111575219, 76.81700752627465, 74.2412890157392, 71.4330602461292, 69.47328721323322, 64.71782522816812, 66.40211059201148, 65.13123127721971, 75.2648550464261, 83.48015739071755, 85.55124728910386, 81.0851110950593, 82.23036473797214, 76.1712206563642, 65.1306389993237, 59.57526845316733, 62.410722394143384, 60.09383716890889, 59.27106511208319, 59.59844573851555, 64.08700612283522, 69.67212000200826, 69.80664945417836, 74.13777766689178, 73.47409694425522, 86.61052257783952, 72.47860723926176, 67.72442786924302, 77.14835366895123, 78.43435764312744, 79.44451701256537, 74.36289818056169, 72.65184264029227, 68.24684835249379, 64.97788621533302, 62.846117250380985, 65.61935847805393, 67.93229779889508, 71.80552851769232, 68.33942413330078, 65.81960724246117, 59.80898287988479, 65.6679174207872, 77.14121495523761, 70.73460378954488, 62.76816798794655, 59.52980426050002, 66.0197893265755, 68.16021888486802, 70.02276420593262, 65.29660624842491, 56.11679307876095, 59.30143210195727, 59.443370911382864, 64.56566472207346, 70.27193669349917, 68.81159905464419, 68.90126443678334, 67.34602112923899, 63.50747592987553, 60.405391031695956, 54.15656112855481, 51.82637906843617, 53.04805224941623, 56.710212384500814, 59.783189373631636, 64.64145275854295, 65.68286949588408, 66.103225984881, 70.25714151320919, 73.76148900678082, 74.41661896244173, 69.66591481239566, 68.12428997408959, 63.972590584908765, 53.36427373270835, 54.24483406928278, 57.22840455270583, 54.136376611648075, 56.065970928438254, 71.79815446176838, 75.10085290478122, 74.5475398340533, 75.02026388722082, 75.2611287947624, 72.78990222561744, 68.75388529992873, 65.9133989580216, 62.55031954857611, 56.886244435464185, 58.64576478158274, 57.10095105632659, 57.705945276444965, 59.687259966327304, 60.50002997921359, 60.663118208608324, 66.39370887510239, 70.99733198842695, 77.20859343005766, 82.07521930817636, 83.37459856464018, 12.761482346442438, 0.7390829572273839, 2.3509576291807237, 3.8482258540968743, 4.246804608452705, 2.4515029307334655, 4.381670403865076, 5.567613734352974, 0.384498548603827, 0.09335660826294653, 1.1888105830838605, 25.28450615944401, 55.65505950681625, 92.41037445683634, 101.24306571099066, 82.93377907045426, 39.70386259017452, 24.533305591152562, 42.804864914186545, 57.583892883793006, 58.87022241469353, 49.27922325749552, 0.15518299874759492, 0.010067179607557914, 0.02101144178830568, 0.08814299689425577, 0.0414316015948932, 0.010547902652873628, 0.0460800584105234, 0.03902015599211858, 0.011777797443491798, 0.0221002614876676, 0.01678935695259321, 0.04051190538091525, 0.03633912021835004, 0.054505508723518545, 0.06899800001373214, 0.05500931495560273, 0.05313306986804932, 0.006232037163910366, 0.0583452524827613, 0.08896363027874502, 0.025367620739064393, 0.027916316739133293, 0.10825426047367435, 0.19178307915647186, 0.7513461862840961, 15.469549471332183, 90.71794233014508, 69.46683099192958, 71.40016724986415, 50.383625415063676, 43.876138733279326, 73.16393160050916, 107.86526603083458, 57.4882851108428, 5.74462196519298, 0.28976641415107635, 1.3334007921718782, 6.10320161427221, 2.380698020419767, 5.678376565056463, 4.551858613567968, 4.306668312318863, 0.2752521123376585, 0.09881293926868709, 8.086130359480459, 85.42810055517381, 108.00641644385554, 100.94935863248764, 101.60612029414024, 94.67077362921931, 91.48878220588931, 81.0727164053148, 78.59242131633144, 80.09727001190186, 79.7195771432692, 78.24111030947778, 76.01963673868488, 72.71029380060011, 68.28332639509632, 70.60244344895887, 68.82638639019382, 76.96569673476681, 86.7067853866085, 88.04552170538133, 84.51448640515729, 84.98630046844482, 79.0596305170367, 67.69082884634695, 64.60368425615373, 63.92785203072333, 63.44663604613274, 62.896821729598514, 63.29607978943856, 68.3612560456799, 71.41916721097886, 74.58621440395233, 77.01328292969735, 77.80076934445289, 92.84303542106383, 77.96800351911976, 72.73607161737257, 78.6187090412263, 81.15449782340758, 80.73958166183965, 78.60823631286621, 75.21468008718183, 69.63082528883412, 67.07445975272887, 64.4121588430097, 68.09769630432129, 71.78354755524667, 76.30974308136972, 72.32850597750756, 69.50423471389279, 61.680196639030214, 69.07678265725413, 79.28792030580583, 72.37413883209229, 61.76369605525848, 63.37281311711958, 67.0073401543402, 70.0260119284353, 70.34843860134002, 65.13949571117278, 58.208467575811575, 63.24356317520142, 61.476492266501154, 66.85905102760562, 73.56500179536881, 72.47878766828968, 72.77887252069289, 70.49558239598429, 66.98325680148217, 64.91142165276312, 58.6403166094134, 54.084354216052645, 55.63512602160054, 59.54290889924573, 61.05136225300451, 66.90031436181837, 69.03519768868723, 69.61423366300522, 72.77437748447542, 74.7166802806239, 75.6415359435543, 73.60135432212584, 70.67354033070227, 67.67655141891973, 55.43255129168111, 57.58911355849236, 58.94517106394614, 56.81449644027218, 58.7634672657136, 72.99067266525762, 76.71670467622819, 77.51311840549593, 77.09366013926845, 79.58598905994047, 74.92934334662654, 71.7429510239632, 69.01388352917087, 65.61911529110324, 60.23190459897442, 61.5885857612856, 59.51582885557606, 60.94432861574235, 60.844268952646566, 63.78852159746232, 62.091845466244614, 68.90368061680948, 71.81215732328354, 81.88415281234249, 82.07866314918765, 87.15693227706417, 15.70618312205038, 0.2326925726787698, 0.7278304126474165, 2.7885816174168743, 2.2870217696312936, 3.4017525084557074, 4.607447424242574, 5.71360239098149, 1.2184502184391022, 0.025923406036811012, 0.8571206814339085, 28.661829656170262, 64.7239637374878, 98.3637635938583, 104.74207093638759, 86.21484956433697, 47.111395943549375, 31.124356408273023, 47.825216324098655, 66.61267126760175, 64.52846104098906, 60.03488002284881, 0.15973460289739794, 0.03517473552135691, 0.04917527579011456, 0.06373807096913939, 0.01881744641239845, 0.02637313220710043, 0.005171333370174492, 0.009547601540332601, 0.03812337729839548, 0.05947648855527082, 0.012044646934936605, 0.038675742013560194, 0.10216711734932277, 0.1743829547758064, 0.17557212241715, 0.17893699508520866, 0.19811415233679358, 0.18686358426367083, 0.11445201137253355, 0.1719549769956258, 0.09514566105339797, 0.17527880267270152, 0.4222888385336246, 0.3658755027478741, 1.0675100597643083, 18.024977560966246, 102.59043908888295, 78.36115837097168, 84.27669663583079, 68.09236188088694, 67.58217134783345, 102.7652983511648, 111.61450278374457, 70.53722227773359, 9.023277259642079, 0.29051282893746133, 1.8779564360457084, 7.539073959473641, 6.161844480422236, 8.960075128463007, 9.418882612259159, 10.374093497953108, 3.566928174226515, 0.4306675421614801, 7.375971511487038, 88.55521801979312, 115.49850433103501, 105.8432371385636, 107.2701483388101, 101.3947751445155, 98.2157725672568, 84.79361795609998, 83.81808527054326, 82.84993448565083, 83.4587412495767, 80.90959287458851, 79.0931510925293, 76.68396857477005, 71.14651541556083, 74.791958408971, 71.57034320216026, 81.18036193232383, 92.13170574557398, 92.84077613584458, 87.10836548959055, 86.67583004120858, 83.80798908971971, 71.84074355709937, 65.98769649382561, 67.00094669095932, 67.46791270471388, 67.2741162392401, 65.45385406863305, 70.78492779885569, 75.96819877624512, 77.26810363031204, 80.27020731279927, 81.94682444295576, 88.43164766988447, 82.54671173710977, 73.73745272236486, 80.06601656636884, 84.17586034344089, 86.47096464710852, 81.57753329123221, 78.3010127467494, 73.94425576733005, 71.39466024214222, 70.28443336486816, 70.83227865157589, 75.20776887093821, 80.21927925848192, 78.03173418967955, 75.31575172178208, 67.34853929088962, 69.37761275999009, 82.72273986570298, 74.75559803747362, 64.39690474540957, 66.37859206045827, 67.93739688011908, 72.11531731390184, 72.85456642027825, 66.89928670083323, 58.02304929302585, 62.821108218162294, 63.47439465984222, 70.76546499806066, 75.86555819357596, 74.98599021665513, 77.86682990289505, 75.70194828894832, 68.85127775130734, 67.60509367912047, 61.859237147915756, 56.79303323068927, 59.38766148782546, 64.01880002790882, 65.61010168444726, 71.16730397747409, 71.71594158295663, 72.33650761265909, 77.27837239542316, 78.83961692933114, 78.3401580010691, 75.46650409698486, 75.07898176870039, 70.43413454486479, 59.277886113812855, 60.30167571959957, 63.56898653891779, 60.22405593625961, 61.97303687372516, 78.3631117113175, 80.89057722399312, 81.15560393179618, 80.63525445999639, 81.04091382795765, 79.06774197855304, 73.34210918795678, 73.09696889692738, 69.07128349427255, 61.96803977412563, 65.10039360292497, 64.3481614512782, 64.42160783275482, 64.6401583763861, 67.9412486476283, 67.15275810610864, 73.93157866693312, 76.38153030026344, 86.23259436699652, 87.77137156455748, 90.28209640133767, 16.953913588677686, 2.3496453512099484, 8.503000351690478, 9.222970028077404, 11.125062646404391, 9.826425698495681, 14.822454490969259, 12.911819930999512, 0.9786154233640241, 0.17940027909653802, 2.2348427243771094, 42.08197993616904, 73.98917475054341, 107.37736240510019, 106.92247729147635, 101.20655628942676, 55.00385584369783, 37.58996394372756, 59.04540331132951, 73.26645451207315, 76.61199308210804, 68.9303135102795, 0.4098098484739181, 0.16372268809185875, 0.10961661761206005, 0.29935642536128726, 0.13968055076416463, 0.17538907336852244, 0.1371263370158211, 0.18421167898322308, 0.10014150426873278, 0.1263583047435649, 0.14243097495167487, 0.09625016831822934], [0.0525379995815456, 0.008125428256819086, 0.07254733133219904, 0.03459330926078462, 0.008647445356473327, 0.036351749177781806, 0.06248694979735921, 0.09940068958507431, 0.09219209333100627, 0.03179054211584791, 0.08442598425092236, 0.09300464448789436, 0.28532638304656555, 7.912798370084456, 75.32187846399124, 64.7684944060541, 62.46436080624981, 46.18879564346806, 32.58838695864524, 64.87636350816297, 86.22136854356336, 29.700379140915413, 0.3418734777838953, 0.05018936169724311, 1.4101867041280194, 3.850353985063492, 0.9304847544239414, 4.656349084069652, 0.7118856101747483, 2.0433711212488914, 1.8683485903086203, 1.5846898887426624, 58.3665547832366, 98.66589592349146, 84.93301114728375, 95.9531847123177, 92.0600518872661, 91.76349716801798, 84.91364248337285, 86.23134705328172, 86.1336172780683, 91.27422071272328, 87.68169049293765, 86.87150924436509, 79.07952477855068, 71.89968893604895, 63.846596210233635, 66.92801413997528, 62.86416799791398, 67.52548525410315, 73.78859258467152, 83.44385977714293, 78.47669570676743, 80.02495719540505, 74.851209732794, 62.5019371125006, 61.14837031210623, 62.06892705732777, 59.12271714979603, 58.94495141121649, 64.99177140574302, 75.06041326830464, 74.13040361096783, 73.76949064193234, 74.20553268924837, 89.56991164915024, 76.96530449774959, 65.83087228959607, 77.6457102068009, 75.68021051345333, 75.68544295526321, 74.89590906327771, 69.88508901288434, 64.49420698227422, 59.84649250584265, 59.83083440411476, 65.42085909074353, 68.39129355645949, 72.8753863611529, 71.34951376145887, 64.41163324540662, 61.31972297545403, 64.34187389189198, 73.07618817975445, 74.00731963496055, 65.77588458215037, 59.70430658709619, 55.98525639503233, 60.921002280327585, 64.23368315542898, 60.24338537646879, 55.044668105340776, 56.994784262872514, 62.080239172904726, 55.314303598096295, 60.082572121774, 63.56239303465813, 68.94448895608225, 66.29673219496205, 66.37152394940777, 66.87875701535133, 64.86115647900489, 57.29120169916461, 56.55071704618393, 54.66267631899927, 54.95220607326877, 53.330223637242476, 56.592274558159616, 61.87324000943092, 66.69657861032795, 69.76213055272257, 70.11323759632727, 68.76693110312186, 74.9387570350401, 69.41918203907629, 64.60372347985545, 57.14734877309492, 55.666352010542354, 53.06101176046556, 56.4979729344768, 54.09934551485124, 59.06335992197837, 69.4225082089824, 74.2822777840399, 73.02009044154998, 75.54788543332008, 74.0285239681121, 70.80529274479036, 64.78079888128465, 65.16815254765173, 61.57220202107584, 60.827547888601984, 61.89965717254147, 61.45765704493369, 59.66884443836828, 60.60486708917926, 62.25339612653179, 68.24287106913906, 69.45136116396996, 82.70647771896856, 75.66983976671773, 92.63321215106596, 28.363252955098307, 0.0439271598213142, 0.2637052061336656, 2.0758896537365454, 0.7917571404287893, 1.9389088427828205, 3.363884230775218, 6.902469358136577, 1.2801977631545838, 0.11960966001835563, 0.19325795162829662, 11.115799969242467, 37.19262784527194, 62.336950455942464, 80.90806315022131, 36.782634258270264, 29.619705792396303, 38.83210797463694, 44.73869146839265, 57.623151886847715, 58.903695921744074, 55.66937223557503, 0.5329075527767981, 0.04301498276031306, 0.06194938207045198, 0.0982532584138455, 0.02037578607879339, 0.03480901280718465, 0.06421966448185906, 0.06565054818507164, 0.053692785196847496, 0.015545931134012439, 0.013334980317121072, 0.053708842399740414, 0.07916448472608482, 0.06228809635485373, 0.062109620851134105, 0.05181716064051275, 0.05426447447990218, 0.03535301950309546, 0.028359234302995667, 0.05231799445145073, 0.027084665095073082, 0.021775562781840566, 0.07493932596257619, 0.09240209335281004, 0.4281723018615477, 10.604722980530033, 89.22392722099059, 74.56919916214483, 68.90229209776848, 48.68208162246212, 27.375164762620006, 68.06641932456725, 95.88182110940257, 35.38554091607371, 0.32544744952071103, 0.19002565813641395, 4.07231601015214, 6.3771061166640255, 2.6288310798906513, 11.051193629541705, 4.915094606338009, 1.3101801156036317, 0.34634571522474294, 2.394370912544189, 68.34770033436438, 102.7826666062878, 95.27849781897761, 99.24268045733052, 97.81343152446132, 94.79665817752962, 88.49208354949953, 89.03784998001592, 91.79780221754505, 93.56700297324889, 92.8233451227988, 89.1997967996905, 84.18464645262688, 76.08972949366417, 67.06004111997544, 69.20252600023824, 66.58283772007113, 69.19581874724358, 76.96525742930751, 86.732359240132, 80.64795509461435, 83.07610619452693, 77.29761554348853, 64.26327351600894, 63.68941899268859, 64.04495046984765, 61.82717961649742, 60.89465964225031, 71.08166294713175, 82.39632021996283, 80.1710262606221, 78.34670835925688, 78.27259909722113, 97.67385790424963, 81.47693234105265, 68.43283930132466, 81.19684373178791, 81.16672777360486, 79.22869251620385, 75.60643857525241, 72.46403955644178, 63.9951128344382, 61.23457224138322, 62.088636967443655, 65.82726370903754, 71.97644187558082, 77.26149835894185, 76.00550051658385, 67.74765614540347, 66.00172288956182, 69.27726284150155, 75.84280060183617, 76.93068565860872, 67.23672036201724, 61.39399305466683, 60.98690594396284, 62.02816970886723, 62.577395669875614, 62.15984367555188, 54.99430879469841, 58.51778960997059, 61.71097547777238, 57.502044785407286, 61.042019167254054, 67.36132621765137, 71.43289550658196, 72.29533057059012, 68.81276792095554, 72.82080265783495, 67.75368875072849, 60.615551625528646, 60.9297138644803, 56.4823305222296, 55.84329012901553, 54.457622651130926, 60.714654230302386, 64.20099412241291, 69.22446773898217, 70.84120596608808, 72.28383802598523, 72.03719154480966, 78.84204879883798, 71.97042495973649, 70.29217612358832, 62.001583883839274, 57.1476351061175, 55.13481201664094, 58.25826990988947, 58.58149282393917, 61.84586578799833, 72.70859933668568, 76.68163084214734, 75.88317748039, 77.27705447904526, 77.00973710706158, 72.48134505364203, 69.12360791237124, 66.26819302958828, 66.08903484959757, 64.48253400864141, 63.318209801950765, 65.54920296515188, 63.583044313615375, 65.75191105565717, 68.31392088244039, 73.94975493031164, 74.91064148564493, 87.29188534521288, 77.52843133864864, 93.4575217769992, 36.20313544427195, 0.12683233696847193, 0.7166042214920445, 1.434434673959209, 3.9070452269046543, 1.7042221585589072, 5.071372130224782, 4.221379314699481, 3.385601168678653, 1.1755869249182365, 0.232597072158129, 10.65119129996146, 44.91800262082008, 67.00601439322195, 86.84282102892476, 43.935919577075595, 27.88223308901633, 31.092747988239413, 50.39696539601972, 64.43976448428246, 67.012525527708, 65.44819016610423, 0.912613945622598, 0.08230523837189521, 0.010865113806850728, 0.09118487923255852, 0.02763711599512927, 0.008081910632280333, 0.05240538976185265, 0.06851619199639367, 0.06686345689118871, 0.06569566310293252, 0.027553980133586356, 0.01623003232863642, 0.1395325885424691, 0.16920703493299025, 0.1652322030596195, 0.15308422427023613, 0.19433203754165482, 0.22439021737344805, 0.2082856396032918, 0.24672790100016903, 0.23882738945464935, 0.14975140472092938, 0.195545107126236, 0.44049669537813435, 0.6561625196087746, 13.695031942859774, 102.74692596927767, 82.0490727886077, 82.01687797423332, 60.933459727994865, 49.28601680263397, 81.78095525310886, 105.19713647903936, 49.03070972811792, 1.1769304592763226, 0.2878630227379261, 4.2971065544313, 12.73525934065542, 5.010575392553884, 17.926114220773023, 9.325998925393629, 11.276553407792123, 6.388051980926145, 2.4608646477422407, 74.57667519969326, 112.2565398677703, 97.13152747000419, 102.95430952502836, 100.82130893584221, 98.90465844062068, 93.01660030118882, 92.37429649599137, 93.57735018576346, 99.02964084379136, 96.49022779157086, 91.64440616484612, 87.25318724109282, 80.04035642070156, 72.02922913335985, 72.68347263336182, 70.92402288990637, 73.29280499489077, 81.78737225071077, 91.9959838928715, 84.97986778136223, 86.09728044079196, 81.08399714193037, 68.70480860433271, 69.5447135740711, 68.53890019078409, 65.79930505444928, 65.08200160918697, 73.6157964891003, 84.89047696513515, 84.25148364036315, 78.70357344227453, 84.59400853803082, 93.06924635364165, 86.58922410780384, 75.74845190971129, 82.22945474809217, 85.90586093164261, 83.15245905230123, 80.798840830403, 77.63023253410094, 69.58492571307768, 65.81696356496504, 66.71624537437194, 70.5103305078322, 75.98564547877159, 81.41346054692423, 82.25351456672915, 74.4021297270252, 68.78223619153424, 70.011914930036, 79.36247671804121, 79.22241672392815, 68.3891676318261, 60.624981003422896, 61.55625758632537, 65.13822094086679, 66.65955143590128, 64.14623783480737, 56.330664234776656, 57.6096236321234, 65.50240516662598, 60.76346420472669, 66.01962458702826, 72.84239922800373, 74.86248262466924, 76.84834726395147, 71.70880286924302, 77.76033755271666, 73.70201803022816, 64.10838696264452, 63.62815549296718, 60.65859179342947, 60.45047475445656, 59.062489155800115, 63.97715622378934, 67.53932337607107, 75.06187239000874, 73.88060354417371, 74.6933029543969, 75.90231080209055, 80.62526810553767, 76.31135909788071, 73.16083292807303, 63.64655140907534, 60.941292701228974, 59.88362558426396, 62.27147040828582, 61.681243911866225, 64.20141381602134, 77.62829488323581, 80.72504535798105, 78.10036782295474, 81.57764311759703, 80.22133458045222, 75.20649017826204, 71.75233333341538, 70.93570370827952, 69.97164003310665, 65.81967000038394, 65.13236876456969, 67.72387089267855, 65.51817701708886, 68.23171584836899, 70.96527053463844, 77.27392442764776, 77.56531730774911, 89.71714958067864, 84.23249936872914, 99.81415410195628, 37.80775746991558, 0.47840707725094217, 4.316812051880745, 7.726276920687768, 7.754363052306637, 8.084191728022791, 10.075987481301832, 16.21795044791314, 4.473749024252738, 0.878837006467004, 0.27097213232228834, 18.18684789442247, 56.32705173184795, 76.5768329558834, 94.82986496340845, 52.80529675945159, 42.66131793299029, 51.838063809179495, 63.52505599298785, 75.56280612945557, 76.739713299659, 81.21073676693825, 1.4530465655749845, 0.3511621406482112, 0.08320143866923549, 0.24895085833005368, 0.08324787891920536, 0.11495769835047184, 0.2337845544060392, 0.2318756165163171, 0.13954884492822234, 0.12466876677447751, 0.11252618124408108, 0.15910961304701146], [0.0025590401022664963, 0.0065873894416126275, 0.030918950477855343, 0.010725166780062982, 0.10192690281978539, 0.032787701310289484, 0.10231123380963841, 0.009305686295603313, 0.06395985342321858, 0.044410002057350455, 0.04559673353909485, 0.060403205965074806, 0.34105713449178204, 5.756148340240602, 67.91965992219987, 58.31377537019792, 60.360589719587765, 57.927927893977014, 61.37320449275356, 83.68919618668096, 68.93220409270256, 11.781819405094272, 0.09501412375679902, 0.1231646603874622, 2.517874091863632, 5.472544797005193, 2.5343174030703883, 3.6983650826638748, 2.5129039585590363, 1.5012812998987015, 0.37569555483998796, 34.934723300318566, 83.81066414617723, 65.43883923561343, 87.95339307477398, 94.40756690117621, 94.71915214292466, 89.84951388451361, 92.27785325819447, 89.83253786640783, 91.13775360968806, 91.06749611516153, 89.94829485493322, 88.72077342002623, 88.09278626595774, 82.4822436609576, 69.78246411969586, 62.70240945200767, 65.52988136968305, 63.67563970627324, 68.38642981744582, 74.77728089978619, 74.71468771657636, 74.90733884995984, 70.66420508969215, 63.00549099522253, 61.75536494101248, 59.765577931557935, 60.69378722098566, 58.621242123265425, 80.17144203186035, 79.71373281171246, 77.38721816770493, 76.22239974237259, 86.89680068723618, 75.09219231144075, 58.58712534750662, 74.74184620764949, 74.08059735451975, 73.24210443804341, 69.02152430626654, 64.11541192762314, 57.89596057707264, 57.74189772144441, 63.64446863051384, 63.89726931048978, 68.37228575060445, 69.92879206134428, 71.96505915734076, 65.2868748480274, 63.504569453577844, 65.14272774419477, 73.3550137858237, 71.85680174058484, 71.85644088252899, 64.11319186610561, 57.12316343861242, 59.84905381356517, 57.38415794987833, 57.81250822928644, 55.29340128744803, 57.51498468460576, 59.24232982820081, 56.61489094457319, 51.690641526252996, 58.56157502820415, 60.52155202434909, 61.26582568691623, 67.04915262037709, 68.14355665637602, 69.17598724365234, 65.11798935551798, 57.47450582442745, 56.71963391765472, 53.782327790414136, 54.00453006067584, 55.48428343188379, 52.62714662859517, 56.321470199092744, 60.67171996639621, 66.88694692427113, 70.9903972379623, 69.26927689583071, 67.99678940926829, 71.20282496175459, 68.30955136206843, 62.47601809040193, 56.01692168943344, 52.496527779486875, 54.11637252376926, 55.41653233189737, 55.57954211388865, 65.2859805476281, 72.8680907526324, 72.94836598057901, 73.29640573070895, 77.29392067078622, 73.36997370566093, 67.76231012036725, 66.14508551935997, 65.73633140133273, 66.21600981681578, 67.88404480103524, 66.86254978179932, 65.99845947757845, 71.94155631526824, 72.21480431095247, 77.86306442752962, 75.22143440861856, 79.7050408394106, 81.4142136419973, 84.76131331536078, 67.15480558333859, 3.050025240067513, 1.1165503508621648, 1.014001269734675, 1.076049304777576, 0.9914918904823642, 2.2911606056074945, 3.558068520599796, 3.313977953887755, 0.6849009291298929, 0.030114642427032514, 1.33735123180574, 29.409486363011023, 31.39416252413104, 75.99930317171159, 49.17670819067186, 49.48490450459142, 43.65119864863735, 37.32616493778844, 55.12567681650962, 53.19300343913417, 52.04261541366578, 1.2127899931323145, 0.01909043992899599, 0.0030342947162177057, 0.04533578100944719, 0.019758365177098784, 0.061220361310387814, 0.032323643550156586, 0.009854314416917342, 0.08833717720042314, 0.08160675770693249, 0.03235274339996038, 0.060204364013888186, 0.09942482135468915, 0.014509643041228336, 0.051622884573354844, 0.06998891942203045, 0.03530211296052702, 0.04845886866772368, 0.05123632043720253, 0.02911895412140556, 0.051351938426734946, 0.02770919720792482, 0.039063099050714124, 0.036066500169615594, 0.2551429478391524, 8.146474553692727, 79.76257416509813, 63.085852515312936, 70.66657420127623, 62.2057040276066, 43.821555029961374, 91.41985047248103, 81.07799591556673, 12.16232559373302, 0.08828843868668042, 0.9386402200306616, 4.510673236462378, 5.239958051712283, 3.7353993663864755, 3.4800567453907383, 1.6676829514964935, 0.715252597245478, 0.4862082731579581, 48.32404375076295, 88.83074883491763, 78.81860086994787, 95.2579132203133, 99.31420879979288, 99.19583166799238, 94.1380843808574, 97.07659859811106, 95.19253515428113, 94.59718212004631, 94.58563466225901, 94.25026416778566, 91.38338811935918, 93.01663952489054, 87.02372074127199, 72.64066388530117, 67.22185457906416, 65.58830115102953, 67.05371825925766, 72.45582611330094, 80.69130512975877, 79.91727244469428, 78.29545867058539, 71.46122286396643, 64.29187151693529, 63.37281311711958, 61.83154129212903, 63.23913481927688, 61.85217688160559, 84.07177632854831, 83.14138227893461, 81.53227698418402, 78.84889725715884, 87.76022418852776, 82.75223608939879, 65.48084389778876, 78.30251109215521, 77.22962517892161, 78.74537806357108, 71.81141991769114, 65.97270519502702, 61.73372130240164, 60.92024526288433, 64.66688148437008, 67.81978853287237, 69.83426294019146, 71.94678875707811, 71.25760478358116, 68.73166899527274, 66.64701554083055, 67.76790342023297, 76.81503065170781, 76.54351634363975, 72.6713054410873, 63.3301494967553, 58.139029856651064, 59.627494812011726, 57.867131156306115, 57.962793842438735, 56.26501160283243, 57.92640601435016, 61.29397261527277, 58.72627927410988, 53.79886058069045, 61.31532992086103, 62.97145266686717, 64.72343421751454, 70.73681600632207, 71.07843091410976, 71.60711150015555, 68.0778020428073, 60.17686590071648, 59.89493377747075, 56.10037403721964, 58.67420196533204, 59.99913154109832, 55.39225286053073, 60.48769020265149, 62.01519450833721, 69.89069800223075, 72.03508130965695, 72.38174823022658, 71.05936035033196, 72.37084404114755, 70.68586441778368, 66.20836119497976, 59.04676829614947, 58.11249502243535, 56.054294032435266, 56.91070041348858, 57.028940262333045, 68.73879201950567, 75.59650713397612, 78.03924945092972, 77.33083801884806, 79.45153805517381, 76.34720171651533, 70.88304981108635, 69.01656643036874, 68.68209023629466, 69.79242693993353, 72.31429130800309, 69.63212751573133, 68.89140359817013, 74.7633643304148, 76.3514849447435, 80.2042644254623, 77.83595300489857, 81.75336530131679, 86.82695896394792, 83.58257047591671, 73.62359416100287, 7.108236897376276, 1.2758254235790623, 0.2582081881982665, 0.9698532774083077, 2.6404790484136154, 4.966471772040091, 6.792632206793755, 3.5655455387407735, 3.1683141185391337, 0.00948092699306266, 0.7098868561367835, 34.14498544508411, 37.073332878851126, 85.10908634431901, 60.37437292837328, 43.19443864207114, 48.06581843283869, 47.07945608323621, 61.55999952746976, 62.11693294586674, 64.08397020832186, 2.0652519406810885, 0.3295247839583505, 0.08640878833830358, 0.02866543581589095, 0.04555343808005414, 0.04607581045298327, 0.0927249534476188, 0.026431640257097544, 0.07701988286909557, 0.028809109860430324, 0.07115501249509473, 0.04430480669402788, 0.19241732334898365, 0.10261530942854383, 0.22686684173682045, 0.1430911588813028, 0.2368224760697734, 0.1864442583774367, 0.13290652554602395, 0.09416254042016883, 0.14217343151329026, 0.16555847990657055, 0.1614468094081648, 0.20040542938776557, 0.40161981698005433, 10.771529616848117, 94.67164439539756, 72.60239724190005, 81.97690902217742, 70.45605274938768, 89.93156986851847, 104.99731525298088, 94.10963935236778, 19.042979709563717, 0.45340156903670686, 0.6661240528187444, 6.21296129880413, 12.371346739030654, 6.703633627583904, 13.855643195490684, 13.962297343438673, 6.2500340707840465, 0.5302706781414248, 48.2872126948449, 92.18815649709394, 84.483272183326, 98.13024920801963, 99.24006031405543, 105.46146500495173, 99.30133558088734, 99.87499790806925, 99.49238638724051, 97.99226807009791, 99.83265199968892, 99.14339742352887, 98.82738774822604, 94.59966890273556, 91.8571476782522, 75.44035757741621, 70.3664501251713, 71.5505587670111, 71.46961673613518, 74.67973155360069, 85.47996213359218, 83.78301928120275, 83.73413870411535, 77.17619465243432, 67.95401988490936, 66.81468117621638, 65.28633748331379, 67.84995155949747, 64.35182102264898, 87.35576506583922, 86.27841549534952, 82.33139714887066, 81.72137445019138, 91.73390680743803, 79.94420343829741, 69.18551860317108, 79.27331339928412, 82.9103546757852, 81.22674788198164, 76.64412513855966, 71.23607881607549, 64.30281885208623, 64.3909231308968, 69.17982332168087, 70.12749933427381, 74.67211431072604, 76.78986472468223, 76.66723574361494, 74.45161434911913, 70.72151876265004, 70.80483774985038, 80.58984910288166, 77.70537730186217, 76.51052136575022, 65.82355314685454, 57.93326231741137, 60.70805288130238, 60.86089587980702, 58.63444482126544, 56.426119035290135, 58.074059717116825, 60.79954216557165, 59.57136569484588, 55.73053767604213, 65.0083944105333, 66.33096664182602, 68.37353306431925, 72.89763404477027, 74.96499769149288, 75.11328681822746, 72.51297504671159, 62.74277848582115, 63.50346334518925, 59.99606816999374, 60.57977960955713, 60.988714156612275, 59.95745635801747, 62.727402794745664, 64.56391534497662, 74.0836803374752, 76.8011611507785, 73.7997321159609, 73.0650172695037, 75.84303594404652, 72.71131361684492, 69.17818377094885, 61.134492966436575, 59.864645235000125, 59.50379502388739, 61.99713983843404, 61.147009249656435, 71.88314437866211, 79.69928279999765, 79.97961459621307, 78.73583101457166, 81.41673964838829, 78.90453215568297, 73.661405809464, 72.11207743613951, 72.90291355502221, 71.8009707235521, 73.78534486216884, 72.85058129218318, 71.64094586526194, 76.97480447830694, 78.8226487559657, 83.93045333123978, 81.36481531204717, 86.825162518409, 90.6670613442698, 89.29971525746008, 75.8156656449841, 6.080126800844747, 2.892895090964533, 5.278366390735873, 3.9253300909073126, 7.960911143210627, 9.688803457444715, 10.490864419168043, 8.73498893553211, 3.868486857221973, 0.1891790543712916, 1.877810940627129, 48.480687525964555, 49.018683741169596, 94.11582100775935, 67.4271906575849, 71.4095966277584, 57.19113026895831, 51.660368673263065, 72.12139698766893, 70.82362590297576, 81.20641431500836, 3.0962292898085813, 0.6203689918883386, 0.12787022522740787, 0.16725623799908548, 0.20062816179087087, 0.2088902821584094, 0.22982656114524413, 0.10514012838323271, 0.17607364953765947, 0.19063144982341798, 0.09484853385196579, 0.1854889773793759], [0.02625149851214261, 0.026336810063390483, 0.0537937977201035, 0.015631400690894696, 0.04549070697037443, 0.04701033812917529, 0.06331327904556548, 0.02621090925869442, 0.01823516404857078, 0.04173226429209594, 0.06379191545889744, 0.047341046794768304, 0.1148659133562638, 3.6073035818915216, 62.17902798806468, 59.843789992793916, 57.683591688832934, 20.608938932418823, 48.938812517350726, 85.57907258310627, 42.77828301152876, 2.17579095113662, 0.04318072971317076, 0.12988824637666826, 6.4070186018943796, 4.697745288572004, 1.2518781279363942, 8.547750672986432, 3.491428677112826, 0.7128317594047516, 53.09160624780963, 92.15778166247954, 70.13914092894524, 89.31867599487306, 91.42980544797837, 92.54447244828748, 94.31324174327236, 94.66501558980634, 89.8289292858493, 92.43091198705858, 92.10711248459356, 93.32546341803767, 91.61416469081756, 90.3613047445974, 87.97591532430341, 86.73494800444573, 73.36954224494197, 63.0969802794918, 66.50206042874244, 62.32000189442789, 64.86944836954918, 69.407179586349, 72.5555641420426, 69.56160330003308, 65.15178841929283, 59.32152248197987, 61.48833782442155, 60.256191915081395, 57.54278644438713, 57.26062682367141, 74.73535076264413, 80.00776936930995, 80.79378097288071, 72.78151619818904, 75.92249531899729, 61.28823418771068, 73.02740958429152, 74.37575570998654, 72.94653815607872, 69.63372784276163, 61.07614771012337, 55.0833309081293, 58.07224365972704, 66.32603230014925, 70.95360540574598, 69.76650791783487, 70.17277917554303, 69.21190830969041, 67.72266280266547, 63.789761066436775, 63.079470819042584, 70.84734055303758, 74.56646134776454, 72.75687586876654, 69.9094077079527, 60.761228453728464, 55.72826270134219, 64.2339067305288, 66.1733030503796, 63.768815609716604, 60.703710817521625, 57.7351983131901, 62.46175635245539, 63.13390154992381, 57.80241989320325, 56.63058042526246, 58.11424832190237, 58.64914194230111, 63.78481888001966, 67.5850268333189, 67.78264368734052, 62.660094922588726, 58.356623341960294, 56.24387394997382, 57.88156547854024, 63.91781860782255, 65.49319544146138, 56.52635912741385, 55.40554185067454, 59.40722627024497, 62.068636801935014, 67.21151521128994, 68.2844481929656, 72.46046235484462, 67.68027767058342, 69.2942153253863, 66.71302118609029, 58.707600947349306, 54.31679387246409, 53.86388563340711, 54.04434211792485, 53.38034368330433, 62.699353925643436, 70.21577619737195, 74.23030637925672, 74.10357459898918, 74.83461026222476, 74.42950002608761, 70.72773964174333, 70.77850295651344, 71.56878209883168, 72.17819290776407, 74.11734996303436, 74.38347493448566, 72.8404615771386, 74.3666087427447, 77.91399248184698, 75.82500088599421, 80.57514021473547, 80.303343496015, 79.1370031910558, 72.15545885024532, 72.91446101280951, 58.646612013539965, 4.7623589827168376, 0.9451359101841528, 2.6648337802579327, 0.7975933820970598, 2.5186281675292603, 1.0576600076690799, 2.4846337206902045, 3.5305986913942524, 0.1682541441292532, 0.3536497813559348, 21.163083545623287, 27.7256344210717, 52.27368616288709, 73.6866972523351, 24.304219561238444, 22.809531765599406, 24.89731723262418, 46.35086013424782, 55.55558035450598, 52.03735159289453, 1.4973276733390748, 0.04032398401308925, 0.04180732175647732, 0.06551668198118288, 0.05007439105200672, 0.13797952913709227, 0.03497294796210143, 0.03085595315262195, 0.03593213600857604, 0.01875788882194508, 0.09787762252193305, 0.0700903877676014, 0.046681353161411906, 0.022866209600901893, 0.04147457912744534, 0.037639941344217914, 0.053523625322287126, 0.0603717235818265, 0.040494469219758626, 0.07062193787386341, 0.05831482347040888, 0.044908870852762656, 0.06339425453916192, 0.01440311564252742, 0.28464441157637105, 6.3022432692589305, 76.99111369348343, 68.3400595572687, 67.2264829758675, 34.691046053363436, 55.45295938368767, 91.53224206739857, 48.4336857641897, 1.9439245736406696, 0.19327730300926393, 1.72009194570203, 6.940798269164178, 6.42042673403217, 2.2994980937050236, 2.4981886965613214, 1.2111649061402967, 2.5066274308389236, 71.3422966003418, 98.31698540718325, 84.55578896307176, 92.44365969011861, 93.39648969711797, 98.48479224789529, 98.22226016752182, 97.58538492264287, 94.40434271289458, 94.0994333451794, 96.32655512902045, 95.59936338855375, 95.9468932305613, 92.60028777583953, 91.33278169939595, 89.0015523664413, 76.0416647695726, 66.00578646506032, 70.5484010327247, 66.31796790707496, 68.94094313344648, 71.68738672810217, 74.33770871931507, 74.2924524122669, 68.18609868326496, 63.933057015942, 65.36535755280526, 63.23904068239274, 61.71327398669336, 62.58646026734383, 78.54771414110738, 81.6230720089328, 83.69062392942368, 76.47904826748756, 79.20245185975106, 70.10601259046986, 74.97989485340734, 77.5245560369184, 76.33601511678388, 71.64798259735107, 65.37432409101918, 58.645968744831706, 62.06364754707583, 71.47742225277808, 74.91861174183508, 73.85048758599066, 73.88473772233533, 74.69677032962923, 71.17243443765949, 68.3065782054778, 66.70132467823645, 73.72010800146288, 76.5762524450979, 75.44755904905259, 69.87421620276668, 62.46316448334725, 57.24610228692332, 65.30335664749146, 66.829696009236, 66.00691610766997, 61.04755755393737, 56.79558277130128, 64.18173136249666, 66.01783598622968, 61.592068825998616, 57.919455574404815, 61.22658237334221, 62.0133823733176, 65.83645774472144, 71.1718225479126, 70.40389307083623, 66.98548470774006, 58.8446956296121, 58.868822128542014, 62.79551867515811, 67.27670500355383, 69.28229132006246, 60.24514259830598, 56.97631774410125, 61.58922902999386, 63.54234972307759, 69.7705558038527, 72.3001786201231, 74.79431967581473, 69.2455465562882, 73.84774192687004, 70.58371805375623, 62.015614201945645, 57.39604665387062, 57.184187673753314, 56.82187834093648, 54.10406412616853, 64.6641162133986, 73.17631844551333, 76.48668119984289, 77.74445979825913, 77.99174170340262, 74.7269098220333, 72.54616614310973, 72.79034153107675, 74.68381866332024, 76.1335345237486, 79.66179278589065, 76.05915069580078, 78.21335561813848, 77.91127035694738, 80.66569205253356, 78.83306657114338, 82.53621547452866, 83.95790207770564, 80.66020857903266, 74.43794096669843, 76.5595902166059, 71.11077477855068, 11.176552580248925, 1.2542825408520237, 1.3587020409684027, 0.8426435195630597, 1.8397760847883842, 4.205020579599565, 4.037501787947071, 4.875400710490442, 0.8151059068979756, 0.5491497812251891, 23.331683566493375, 36.69451821234919, 56.006264609675256, 80.20869670375701, 29.643012515960205, 36.95364567541307, 32.92044108913791, 52.73557662963868, 62.85576628100488, 62.3870744243745, 2.2587880588346914, 0.09505059720287401, 0.03329741024983025, 0.041067725152618466, 0.027103351894766096, 0.05058266357668946, 0.04446292341115975, 0.01811516403611149, 0.022857688787964084, 0.053326579847282944, 0.07327503825147307, 0.04582629944648474, 0.14664280378530103, 0.09556356967697222, 0.11126270307408226, 0.17328626926868193, 0.07320519401541642, 0.18086470212907563, 0.15386963293196695, 0.18395263401250686, 0.137996842724181, 0.12493544964179878, 0.19435348800353466, 0.21683827583347598, 0.38247285891444455, 8.32973062992096, 92.8899940367668, 74.32612988256639, 75.84198474884033, 30.2521683708314, 70.89425994503883, 98.65691369579685, 63.47629308700562, 3.885678360539098, 0.1902166438559371, 1.277823013163382, 17.467122385578772, 11.943578931593127, 7.760109814905352, 26.031374469880138, 11.942597358457505, 1.6031155903493206, 70.08221949300459, 100.38679661289339, 86.73712099752119, 96.75009266022714, 95.14703566028227, 101.62517516843735, 102.40048654617803, 100.7561505225397, 97.27678852696573, 97.62305536577779, 100.12876741347775, 98.75780490136917, 99.01822674658992, 95.49864476726901, 95.29942758621709, 93.62059039454307, 80.91950078164378, 70.87700936102098, 74.32577686925089, 68.92512813691171, 74.56532386041458, 77.03371063355478, 78.64314540739983, 79.0085220336914, 70.35225114514752, 65.94481714310186, 67.72971522423529, 67.75395547190021, 63.600428258219075, 65.34445524215698, 81.84091260356288, 86.31621145432996, 87.5047915981662, 79.32717538649037, 78.70475799806657, 68.25542265369047, 78.94583471359746, 78.75810223241007, 80.62409139448597, 76.04317095971878, 68.95133741440313, 61.36239444055865, 64.55702374058386, 73.27338141779747, 78.42763470065209, 76.224776698697, 78.63739521272721, 79.41614258673884, 76.31421458336615, 75.82800542154621, 68.29308525208505, 76.93358821253624, 80.49907761235391, 78.02909051218342, 72.57770199929514, 62.58920200409428, 59.26915884017945, 67.50940353639665, 70.63695246173491, 65.77528838188418, 62.4757670587109, 59.14548650864632, 66.44051059599846, 65.27916346826862, 62.249391386585856, 61.187872502111624, 67.0301918829641, 66.71243283056444, 71.568083916941, 75.39518756251182, 74.89222988005608, 68.7786276109757, 64.12355476810087, 62.912899524934836, 66.04552791964623, 70.33474952943864, 73.19320817147532, 63.51329280484108, 60.7993931155051, 64.48398528560516, 67.9193147536247, 74.45777247028967, 74.47286575071274, 77.64949921638735, 73.51554855223625, 75.90747264123733, 73.2201313203381, 65.1847049497789, 62.189492871684415, 60.50974569013042, 60.13596734692974, 57.25943050076885, 69.50431316129624, 76.25672048138034, 80.83812729004892, 79.11261389332434, 80.32025675619803, 77.80105959984564, 77.38957158980831, 76.67544134201543, 77.05681339386972, 79.70930837815808, 81.59360716419836, 78.41145100132113, 81.151548201038, 80.63268138516335, 85.54179437698858, 82.5581415237919, 87.53250706580378, 87.87790313843759, 85.23003655095255, 76.30544416366085, 77.21380233764648, 71.98682831179711, 8.522585726553395, 4.777227707447545, 9.063145210666042, 3.7296594679355626, 10.600503490817163, 7.757306300824689, 9.851447478417429, 6.1190121981405445, 0.6385296883602297, 0.35522326466537296, 32.374388325598936, 47.95459178186233, 66.05747545919111, 88.38825056629797, 36.20275889673541, 30.571925870833862, 36.19682827303487, 63.5354345844638, 71.6891674841604, 78.55820255894815, 3.510649761845989, 0.27620190814618145, 0.22261871565734187, 0.10359548062326447, 0.20353715085694868, 0.27352522758226244, 0.2529717780529492, 0.13677655659135313, 0.08413369106429239, 0.13212307806937926, 0.14581000492457422, 0.139241490453001], [0.0544346455905226, 0.0591653227926262, 0.04954191780979595, 0.049585791665219495, 0.07248098811795635, 0.07574931072491793, 0.04388846855069842, 0.04138559418460054, 0.010496259708287976, 0.029957933396461512, 0.053737651136132984, 0.012734300351791806, 0.18470798138408892, 3.135104145734541, 61.9349467369818, 57.146623134613044, 58.89814969032042, 38.79737930913126, 66.88071035569715, 75.49272121921663, 20.942595351126887, 0.12430425447922562, 0.1348156013315724, 2.1518066381254504, 6.445819668231472, 2.9524526048091153, 3.741013013547467, 1.9542301109721585, 3.0180081580915763, 82.35778685539, 108.1358075910999, 95.44009947007703, 100.65451406663465, 97.7289358262093, 93.2175511698569, 92.80217216860865, 94.11188294810634, 91.10379372873615, 95.12794940702378, 91.63716546950802, 90.60270309448244, 89.78203342806908, 89.99538683122205, 86.52555619516681, 90.18640625861384, 85.47816568805327, 76.00591628782212, 60.6296133225964, 64.64787760088521, 61.21027315816572, 64.59971873990952, 66.67273059968026, 67.80282820424726, 67.23006802220499, 63.85936352514452, 59.6220858635441, 59.80516641370712, 58.04294747691001, 59.05978664275139, 57.95244662992416, 69.64279636260002, 75.99561614374961, 73.52929253732005, 79.21618015535417, 74.53593746308358, 67.6159272655364, 74.21008263864826, 75.76296467934885, 73.98025528077157, 66.20159902880269, 63.60708844277167, 55.754868138221006, 67.31960788849862, 73.08534299173664, 75.21918296813965, 75.91564686067643, 74.70215966624599, 69.86199409730973, 63.99293591899257, 61.24845743179322, 67.12367765365109, 71.07018609200755, 73.51448166754939, 71.50226654544954, 65.644171391764, 59.75501498868389, 62.3768723395563, 66.20544295157156, 68.26260843584615, 66.57861724976571, 68.45920547362297, 62.10627978847873, 57.761407590681515, 59.071938145545225, 65.44076511936804, 61.08361590293146, 59.99599756733064, 59.61263295142882, 61.47909672029557, 64.91903497326759, 65.91294396308162, 60.71520336212651, 56.05059915973295, 57.134644216106786, 61.7490852263666, 67.63509196619835, 67.20898136015862, 64.36592586578863, 52.98178772772513, 56.72560768742716, 59.28552296853835, 64.71618175506592, 65.30759672964773, 67.1484434989191, 71.19231300969278, 69.10935401916504, 68.20791490616338, 61.41564846038819, 56.21509552001954, 52.44050456631569, 53.10325960959158, 52.29513760535948, 59.412274360656745, 66.47308980264972, 72.99491666978406, 72.98442825194329, 72.90245856008222, 72.98143940587198, 71.33314963309996, 71.74743821544033, 76.43779277801514, 75.51780869883876, 75.6859685528663, 74.95536435034968, 76.73162537236368, 75.35727393242621, 74.6757621149863, 74.55582387985723, 74.3052314942883, 70.70997914960309, 69.94571316626765, 72.85106766608455, 74.30499615207796, 69.99823370287496, 67.18344673033684, 5.845341076773982, 1.4867811553901242, 0.7451369517272519, 2.872132759901785, 4.250568612929314, 0.7599872290607422, 2.5938018627705115, 0.2130769526646022, 0.28376702639845114, 4.178256286728767, 47.40469901792465, 27.977689850714903, 74.13882886209797, 34.121282562132805, 32.135763091425744, 42.53812020824802, 65.46419735877745, 51.64500082692793, 55.19894276895831, 1.7545977715523013, 0.21665049236147635, 0.027507817590489026, 0.0633460331347681, 0.04102909516903662, 0.04892850354794533, 0.015564486741148418, 0.002877168407130446, 0.038477118397431995, 0.048432044099054994, 0.0365409575733206, 0.05049910253634857, 0.044373697150618806, 0.06738739208348336, 0.019284355934829484, 0.047686563939937664, 0.026122977686745506, 0.017456943206789515, 0.02829163853499678, 0.052274515131308194, 0.08814331099030473, 0.05605482961982489, 0.031046599878238577, 0.03507271559248048, 0.31241914377577845, 5.312691542410082, 73.85438642194195, 61.728473171111084, 67.12345800092145, 24.941702773494107, 62.931393500297304, 87.66718556804042, 24.339503242123513, 0.022675635653638074, 0.44643013828223754, 1.8072090129698477, 7.188348366368202, 3.339493217006807, 1.5314806084479056, 0.6282542429624066, 6.687002778053285, 96.32222483235022, 107.9700952960599, 98.00034030791252, 102.83111572265626, 97.8343612917008, 94.92866162330874, 95.12614511674451, 94.67791234293293, 92.25616255114156, 97.18907648517241, 94.16809051267563, 92.26585865020753, 93.12106870835828, 90.3591395962623, 87.43718562587615, 94.63558996877363, 90.4512603821293, 79.09104870211694, 65.50764937554636, 66.31927013397217, 63.85758669145646, 67.83285787028652, 71.08152174180555, 71.18592739105225, 69.98514867598011, 67.20863619158345, 64.87710483612554, 63.454916169566495, 61.10871907203429, 61.26466074297505, 61.339483876382154, 73.38483164387365, 77.70205897669639, 79.54894619603311, 81.89366848238053, 81.66653971518241, 73.4543203538464, 74.54241721860825, 80.28136253356934, 76.11971993600169, 72.43292731623497, 65.24679214723649, 59.260400187584665, 71.3446343329645, 76.73528102136429, 77.9541418629308, 79.73261510172199, 77.47477331469136, 73.07913780212402, 67.77104131637081, 64.61957770009195, 68.51709181262602, 71.82547769238873, 75.96834782631167, 73.9621574647965, 64.8979796901826, 59.26013738878312, 65.85705018812611, 68.37501572024438, 71.19849466508435, 70.04915391245197, 72.66513947517642, 66.49793409532117, 60.00085346160397, 59.12252103128741, 66.02217412764027, 64.39127222184213, 63.658887263267275, 64.56250721408476, 65.1399899298145, 69.42519895492062, 69.230359138981, 63.20145653140161, 59.496464114035334, 60.288229834648874, 66.39656436058783, 69.62186659536054, 71.24686533404936, 67.02140577377813, 56.32660850401848, 58.63423301327614, 62.032064622448345, 66.79356313520863, 68.31134780760735, 71.51515545383577, 73.73490318175286, 71.12719382009199, 71.40568994706678, 65.16095499838552, 58.55499721342518, 54.38820846619145, 55.01707815354871, 55.96936687346428, 60.74203629647533, 71.11727806829637, 76.65134229967671, 75.53981319550546, 74.40177671370968, 72.48354942567887, 73.54324833039315, 75.7053215272965, 81.00011333342522, 78.75221083241125, 79.04274079107469, 78.75187350857642, 80.5247534475019, 79.73362707322644, 77.49225924091955, 77.00284942503899, 75.89724309982793, 70.80345707554972, 71.82594837680941, 75.72163858721333, 79.00362691571637, 71.39533488981186, 82.12548055956441, 12.144020872731364, 1.2918806652868948, 0.5009235351556732, 1.503614619854958, 4.003349710856715, 2.7833629039026078, 4.000353510341337, 1.2949635256682674, 0.35005085350524995, 2.3627914199906015, 57.64578396274198, 36.17190553295997, 82.8581714630127, 36.47510474728, 23.523591410729196, 45.681919513210175, 72.0321709109891, 59.419158120309156, 63.99243777798068, 2.675861769145535, 0.24835553140409533, 0.02700963252854924, 0.0802419873915853, 0.0788459989933237, 0.05118309264822353, 0.03200588751614335, 0.0234248198478693, 0.02991208877985276, 0.02901084762397072, 0.010778185810082623, 0.043332215939317985, 0.13328950822113023, 0.16073964896701998, 0.21924546198739162, 0.18535938594610463, 0.2423951834920914, 0.1386562299223677, 0.16700250967856378, 0.15985158452343556, 0.1796948399034239, 0.16859172843396666, 0.14519981589288483, 0.18644900812256723, 0.5301421592312475, 8.478411013080228, 90.14271889963459, 73.43238645984282, 75.365918836286, 55.97473267586001, 90.24848953370126, 94.66783185159007, 37.084460643029985, 0.16916966516404383, 0.4893601120960328, 6.318630441542595, 15.931530152597736, 8.808497094338941, 13.910486755832551, 6.975368568974157, 5.131362330528998, 94.81324980335852, 112.05929956128521, 100.9041101701798, 107.51594758802845, 105.53447600333922, 97.44111230296474, 95.18040718570833, 99.16471158304523, 94.00693601177585, 103.95529054826306, 95.7572074090281, 95.13391925442605, 95.09885326508554, 93.83615601447322, 92.11081520203622, 97.642635837678, 94.88684131253152, 83.61871903942478, 67.45088177342569, 71.42679229859384, 67.26721286773682, 73.07197555418938, 74.5245155211418, 76.30792310160976, 74.57695761034566, 71.02564365633073, 67.30872723364061, 65.39982734187957, 64.7415594900808, 65.91110044910063, 64.00477363217261, 76.53273767040622, 81.08303223886799, 81.06192988734092, 86.62408613389539, 80.62445225254183, 72.71401220752348, 78.40389651636924, 82.32075968096333, 80.87865321866929, 71.84682323086646, 69.27190488384616, 61.28524926400954, 76.30431452105123, 81.27652275946834, 82.97650152637114, 83.45599559045608, 83.442745824014, 76.13786482041883, 72.70679504640641, 68.47576572049049, 72.67242723895659, 75.0056020675167, 79.85041956747733, 75.61588364262735, 68.48881936842396, 59.09772772942821, 66.59493430968254, 69.86528104351413, 75.36857035852249, 71.00743601399084, 73.79719042008924, 66.25752418271958, 59.59039311255179, 60.70617798836001, 66.8976471501012, 66.78357678074991, 67.01883269894508, 68.73488533881404, 68.31005342545049, 74.42223579652848, 72.71205102243732, 68.54178705523091, 63.54063172494212, 64.51909834338774, 69.3302462177892, 72.95413970947266, 73.95974128477036, 71.48535328526651, 60.34457075980402, 63.80386590957642, 65.16805841076759, 71.2745729569466, 71.45246028900146, 73.88700485229492, 76.67668865573022, 74.92349117032944, 75.47241903120472, 67.72981720585977, 62.75702061191682, 58.879443906968646, 58.61222851660944, 57.41273241658365, 65.82387478120866, 73.77988492288898, 80.6353799758419, 79.12005070717105, 77.23536752885389, 75.45759247195336, 77.50550900736164, 78.79253279778266, 84.88096913983746, 82.25600919415875, 83.3923904357418, 81.56040822305988, 85.03416122928743, 82.87695177139776, 81.53630918072116, 79.56602419576338, 78.5237092356528, 74.16101378779258, 74.09688303547522, 75.79358270091396, 79.42093572308941, 73.24319485695132, 82.94979018549766, 10.203117382141853, 5.574341579791039, 6.223762525666145, 8.781443526667934, 11.097112817149009, 5.8202888984834, 8.32288021041501, 1.0255561432530804, 0.6325720983647531, 6.192969468332106, 68.40249584567162, 46.08145998370263, 92.12039362999701, 49.61167550856068, 43.05869325514763, 55.7628462391515, 80.82323012813445, 67.31332425148257, 78.7714304462556, 4.026081562042236, 0.46874906807657213, 0.1628104918786595, 0.1521190913814691, 0.20077598611674002, 0.22104966033610607, 0.10589995736917181, 0.10870918646574983, 0.1528876920741412, 0.09109876328899015, 0.07925754142624718, 0.18336686786384354], [0.059736249818196224, 0.04090172539074575, 0.04318220060198538, 0.07699364435768898, 0.09832180030043088, 0.05241107030381119, 0.02412226629413424, 0.07231928227889924, 0.08789368890105717, 0.10129583023128011, 0.07220217041791448, 0.09923146076260075, 0.5542507010602182, 7.22740879943294, 66.01060313563194, 58.445959245004964, 44.67604337200042, 57.15569557682161, 78.65833282470703, 51.60489459191599, 8.341201601489898, 0.09149779550611012, 0.20222395358066406, 4.1780518331835355, 2.2110175125060545, 4.324380265128228, 1.125522527483202, 1.3049474286456264, 93.91564676838537, 102.76417655329551, 89.96030515240085, 94.39611358027305, 95.73790150303995, 96.16001913624426, 97.38511654638477, 94.17044393477902, 93.4805617793914, 91.64003664447416, 92.87794451559745, 91.30316780459498, 92.68521493481052, 89.11711323645808, 88.05301343241047, 84.1350127804664, 88.40430090504309, 83.97925546092372, 77.91300404456355, 64.05554479168308, 62.45326442103233, 61.053998085760306, 64.36497665220692, 64.03807455493559, 69.84593591382428, 65.24428967506655, 58.235673135326756, 60.072346502734774, 59.76502095499347, 57.91385050742858, 57.6373508668715, 57.652161736642164, 60.61137430129513, 69.02164197737171, 73.23738190435594, 76.04051943748229, 74.1443358698199, 66.63993174029936, 76.46721055430751, 73.13480407960954, 74.01844347676924, 75.84333404417961, 67.58091618937831, 57.228565369882894, 71.23672992952409, 74.2607988849763, 73.81617469172325, 71.06774637776037, 70.50458031315958, 68.1633803152269, 61.354710517391084, 62.931797504425056, 65.45849031017673, 72.74238663335001, 68.88919138139295, 66.41598793768114, 59.90664205243511, 61.65628194808961, 73.35326440872686, 70.03503337983163, 71.11513645418229, 71.29536151885986, 72.56961407199984, 69.64766794635405, 69.06559605752268, 61.154034214635054, 62.73234890353296, 59.089800619309955, 53.57439118046915, 58.099590424568426, 63.6164354508923, 64.56617070782569, 64.14344510724469, 62.42809457163658, 59.58871826048821, 60.86936035463887, 63.41384503149218, 69.57126802013767, 68.42067995379048, 64.35863025726812, 55.787580705458126, 57.71643369428573, 57.27098188092632, 60.40658343222834, 64.71803703615743, 70.3347416846983, 66.82599329179334, 68.93141177392775, 68.2994394917642, 67.75088033368512, 57.777277500398704, 52.28758704277777, 53.06832305846676, 52.40939624847905, 56.00220495654691, 68.01569523349886, 71.07191977962371, 73.51445813332835, 73.55627844410559, 71.63193225860596, 75.06647725259104, 73.11940485431303, 73.37038163215884, 77.14917736668741, 75.26115232898344, 75.94484498423915, 72.27988427685153, 70.89931195782077, 71.73908356697329, 73.56813969150667, 71.45896357874717, 74.60570858370873, 74.4860762934531, 80.159392510691, 80.41617439639184, 81.8570335449711, 69.08241518082158, 63.15110898786976, 3.2559508998547835, 0.753061549077111, 1.1237226498703803, 1.742003653799334, 3.816482847736728, 2.8505474665472588, 2.6834375819852276, 0.5280139669775963, 0.9804102754400623, 40.10608596186484, 49.5235163165677, 42.418178050748764, 62.66116572964577, 55.28294032619846, 32.725640496900006, 43.06953860867409, 59.34731991060319, 45.229917341663, 1.2142602690765936, 0.04768087190666026, 0.01406245741001781, 0.05941354677141194, 0.05005429273531322, 0.04893528725651484, 0.03155304911366153, 0.05583932525628517, 0.041355693772915876, 0.04103932627326539, 0.0937806609116735, 0.025821905132503282, 0.06292382675793863, 0.045366593065761754, 0.03675029109863024, 0.06857795400484916, 0.04439756078946014, 0.04351165288338258, 0.035060316459426, 0.0937513427268113, 0.10330575383118085, 0.11463660791876817, 0.0969718844299355, 0.14193504027301265, 0.40623347425172407, 11.896680132035288, 80.93889297977572, 66.01728685440557, 66.04756755213585, 44.20104434413295, 79.89213005188974, 63.5836640481026, 7.995985467587748, 0.2511479372098561, 0.7802864140079868, 5.14038231103651, 3.813638148769256, 0.5913614097141451, 0.8551494452741839, 3.5591157934358044, 106.87442825686549, 104.71033896169355, 97.80444145202638, 96.99204014193629, 97.89465596598964, 99.26210403442384, 99.62576266257994, 97.57204101931666, 96.94684659281086, 94.02767750524706, 96.53224422085671, 91.63023071904337, 95.93540068595641, 91.84325464310186, 91.57099508470105, 85.64481150719428, 92.02162050431775, 86.8831116153348, 79.2506342549478, 67.08840770106163, 66.1754446644937, 65.22373253299345, 67.40016552709764, 68.22871915755734, 71.378539300734, 68.93912315368652, 63.46650285105552, 63.68165662211757, 61.83669136416528, 61.02502745966758, 59.50275559579173, 59.481676778485706, 63.652838968461566, 71.37309505093482, 77.22476928464829, 79.11523403659945, 77.46270810404133, 73.4954503274733, 77.62459216579315, 77.10024972115794, 77.48443803479596, 78.79876936635664, 68.1571751256143, 58.914317700170706, 72.20637905982234, 75.51735370389878, 73.63697728803082, 72.67628685120614, 72.03450864361179, 71.15053192261728, 66.17987694278841, 65.67739386712351, 68.69748161685082, 73.36221525746008, 70.44896894885649, 65.33397466905656, 60.90730144131569, 66.23027155476233, 75.78154102448495, 73.73075331411054, 74.23010241600775, 74.13731482721145, 77.15673969637963, 72.86911056887719, 69.065352870572, 62.00802441566222, 62.66142852844731, 58.1854118839387, 55.13304302769323, 61.996786825118534, 66.41305400479224, 66.3806709166496, 67.98826217651367, 63.72768955845987, 64.06341306624874, 67.28428302272674, 67.53871933106454, 72.55128875855478, 70.58203143458213, 67.50702658007222, 59.1745355821425, 59.63508852066533, 60.23799211748185, 63.302892946427875, 67.75441831158054, 72.58501329729634, 70.98781631838891, 71.29539289782124, 72.51233962274367, 68.89813438538583, 59.94406538624918, 54.6284261826546, 57.22740042594172, 55.56153451242755, 56.77299776384908, 67.4045507369503, 74.38036841730919, 76.08944708301176, 74.88382031840663, 76.01671065053633, 78.50082612806752, 75.67387980799522, 76.52678351248466, 78.55028721594041, 77.51526001961001, 76.55245934763263, 73.80095589545466, 74.50737476348877, 72.65071299768263, 77.65952479454779, 72.58369538091844, 79.58096058137956, 77.92603415827598, 82.60036976106706, 81.5101783506332, 85.8963687958256, 72.00576551498906, 76.24830307499056, 8.128957248503163, 0.214634332805872, 0.4125876526438421, 2.860909878246246, 5.529006335043139, 4.44628115623228, 6.124020574554321, 0.6401911798504092, 1.355882469684847, 40.07461678597235, 56.81035441737021, 45.9275108768094, 62.23602787140877, 34.90721179592994, 47.06322139309299, 49.40635511952062, 66.28454146846649, 52.58898981155888, 1.8731680800837858, 0.06166953398215194, 0.08154131847644046, 0.08657325975476735, 0.07130595479881571, 0.04200317213431962, 0.04914449820775659, 0.08900228707540421, 0.08356929110783724, 0.06914667469719726, 0.025388883509402795, 0.016917912251946908, 0.192841230441005, 0.1243892825779415, 0.17810758233310717, 0.21864768358007555, 0.2031329781898568, 0.2586628154160515, 0.16224573186087995, 0.1860651061419518, 0.22939574394014575, 0.2753524392122223, 0.22362575355556705, 0.28708449354575527, 0.9417643878729114, 15.587266664351187, 91.90368267797655, 73.05632529720184, 59.20296099878127, 83.31191908928656, 98.71227402840891, 73.31294244335544, 14.34399397142472, 0.3713605084246205, 0.8415502814515945, 11.319730858648978, 7.366037128433105, 15.450847610350579, 4.756517592937716, 2.4445333692335316, 109.8291967761132, 110.46850389049901, 100.08754330296671, 102.75348417220577, 103.50077413743543, 104.07979442227273, 104.02624622468026, 100.58840643975043, 101.24789022630262, 97.07388431795182, 101.0584475917201, 96.11589247180571, 101.29357014932941, 95.69898374619024, 94.47623191341278, 89.78308462327527, 95.28593463282432, 90.81756268778156, 85.55475388803791, 71.4039013462682, 71.83649955257293, 68.62261141500166, 72.55347744111093, 72.73978217955559, 78.69913331923946, 74.42953140504899, 66.07443578781621, 66.4977458215529, 65.83907788799655, 64.15557699818766, 64.64175085867605, 62.66030280820785, 67.09196921317809, 76.63919864162322, 81.67785183075937, 83.19653080355737, 78.3443235581921, 70.01404869940974, 81.39389576450472, 79.88622296241023, 79.61368883809736, 83.15294542620259, 75.37363021604477, 62.80990200657999, 77.64683984941053, 79.35086650233116, 77.78074172235306, 75.66790211585261, 75.82616190756522, 75.23272298997449, 72.67908742350917, 70.79125065957346, 71.2704073998236, 76.73070753774336, 73.09379962182814, 69.37205868382608, 60.94453257899131, 65.49036349019697, 78.83563180123606, 77.51920592400336, 79.06145834153699, 75.87126916454685, 82.58779464229461, 74.92251057778635, 72.64472746079969, 62.40715695965675, 64.64003678291076, 64.52287558586367, 62.99083309788858, 65.08337836111745, 69.38482992110714, 69.88491642859675, 72.97924287857549, 67.05617366298553, 67.55048644158148, 68.35785927311068, 69.91060795322542, 75.9563296841037, 74.00961029914119, 70.55459837759696, 61.69945547657629, 65.98138147784819, 63.12717076270812, 66.1820734700849, 72.68099369541292, 74.91319102625694, 74.93659973144531, 72.14689239378899, 73.11589041063863, 74.2879181523477, 62.2055196762085, 58.48592035232052, 60.26376993425431, 57.7323781290362, 60.769088883553785, 72.1438172555739, 78.70076502523115, 80.58241228903495, 80.06727956956433, 78.36185655286236, 83.75434675524312, 77.05540918534803, 78.49990829344719, 81.23903274536133, 81.3459800904797, 81.09566227082284, 75.8891708620133, 75.31955642084922, 75.22459583897745, 77.6097656065418, 74.01274035053869, 80.11037857301774, 79.72116178081882, 85.78433021422356, 85.97512214414536, 88.38978029066517, 76.43944017348751, 75.99357651126, 6.95075765732796, 2.8269852986258845, 6.754053244667669, 8.906874060630798, 8.88743773583443, 10.258766989554129, 7.654600018455137, 1.0114818210563352, 1.2176612091641272, 49.425060902872396, 67.77144139812839, 55.72282237391318, 83.08508842222153, 77.70347102995842, 46.60097399065572, 57.8760035576359, 75.61330272305396, 64.37214674488192, 2.913545144181098, 0.2335417964645932, 0.2299559380738966, 0.20355696189067057, 0.2270820664782678, 0.1425838401360858, 0.15297665020390866, 0.192092226277436, 0.11831424364279355, 0.12951603489777735, 0.14833202765833947, 0.16914625351707782], [0.04297993806821685, 0.05624057912838556, 0.05429602581106367, 0.05466517293825746, 0.06697736650464997, 0.008685423207709627, 0.014757523238058052, 0.08864206487252828, 0.0726220785309711, 0.11869617677744358, 0.14130968270042252, 0.09091566827508712, 0.3503119056263278, 20.597964140676684, 74.90454612239715, 44.562847691197554, 28.01385018133348, 38.729126145762784, 69.18120399598153, 35.16198935047273, 0.9795459444003721, 0.010417559495826643, 0.19351122029606374, 1.1713418172251795, 3.9420906238017546, 2.5401948296254684, 0.07443684123216138, 62.09153952137117, 106.09425314011114, 88.08869915623819, 100.84194844768894, 88.28319380360266, 96.36815578706803, 92.33936386723673, 95.43382367780133, 90.64388798129175, 94.00360984186973, 89.91854759954637, 93.26512167530676, 86.5243245709327, 87.86139780475249, 83.50840630069857, 90.55992572538315, 86.662933288082, 86.53155742153045, 79.18698203179144, 73.7969393883982, 63.150002879481164, 63.73044698469101, 61.237074713553156, 66.0571224458756, 63.827380518759455, 66.06732845306396, 61.95082056906916, 62.43921449107509, 55.99833749955701, 60.43901751118322, 55.54848870923443, 59.04839215740081, 58.350645649817686, 60.92791741894138, 64.85747729578327, 70.73117563801428, 72.80697238060736, 73.4016429224322, 72.25963700202205, 72.72409269886633, 70.60317300981092, 72.58373460462018, 74.58499846919891, 65.46030244519635, 58.35682730520926, 68.32990846326275, 70.67445032058224, 72.66930503229942, 64.51920424738239, 64.27806085155856, 59.44909757183444, 57.69202478470341, 65.32980126719322, 67.15527626775926, 64.95669757166218, 66.12911362801829, 65.30406659649265, 67.94283328517791, 66.48046385857367, 69.54733371734619, 71.42279148101807, 67.89638457759735, 65.15192962461903, 68.37346246165615, 73.22479109610282, 65.46302457009593, 62.10199656025056, 66.05578884001702, 56.83723834253127, 50.571620695052616, 51.497347124161266, 64.1566046591728, 67.51610294465097, 65.2426109006328, 63.32311668703633, 64.931472809084, 63.207783314489554, 67.01058003210252, 66.8484841623614, 67.63980665514546, 63.30621519396382, 59.99872753697058, 56.5188713227549, 58.967344222530244, 61.84447726895733, 64.46942152515535, 66.08463395026423, 68.90148408951299, 70.41083566604122, 68.9254419265255, 66.76751859726446, 67.65380951666063, 55.12227612157022, 50.49728785791705, 54.81334632442844, 53.23593770304034, 63.38487440539945, 71.77738158933579, 75.05923655725296, 72.66055814681515, 73.97277924322313, 69.83496112208213, 73.61705164755546, 75.83140219411543, 76.61188325574322, 71.38430518488731, 70.97202485607517, 74.22446989244031, 74.03524691058745, 73.82460778759372, 76.52176287866409, 75.05599667949062, 77.78842172315045, 74.90049823637932, 79.7045309312882, 74.96425244116014, 82.22306128471129, 81.36956137995567, 82.26284980773926, 53.833652004118896, 2.0399875866789974, 0.49600037836259414, 2.503179177161186, 2.1504779352295786, 2.7460300297506395, 1.5963835773929473, 0.3025074982114377, 0.16959864375812395, 7.468541408738783, 67.10420700811571, 36.75406371393512, 62.29107833677723, 36.570241835809526, 29.985966913161743, 41.054715110409646, 50.46888597549931, 41.643258910025324, 1.1000404819365472, 0.0502445545017479, 0.022430700107267307, 0.054867446963344856, 0.07923469668434513, 0.07339684623143367, 0.07804104742864448, 0.07313874354886432, 0.03825854968219515, 0.05688462924632815, 0.028912330632128065, 0.03465648853190003, 0.03576467301876795, 0.03875653364605481, 0.030662326344979868, 0.058006181967474764, 0.025363692623232643, 0.03285306776242872, 0.030076330369939248, 0.0687063733235963, 0.02805753164143572, 0.05790928716681177, 0.13684636252301355, 0.10832186007211286, 0.4646527653019275, 30.141988992691044, 81.74620305338215, 53.809894207985174, 34.329513349840724, 37.02246366008636, 83.44926480324038, 40.38559798271426, 0.8460014361527659, 0.23540443200017178, 2.5829057635799533, 2.800312936306, 2.260270469611691, 1.1266989933867608, 0.6850456278170309, 76.13641354345506, 107.10354958811115, 94.14968675182712, 100.91963491132184, 92.78423909218081, 98.20558224954914, 94.07852711216097, 99.12184792180216, 94.3034044388802, 96.98014751557382, 92.88519305567588, 95.69882685138334, 88.41657792368244, 88.600035021382, 89.93478621205976, 91.04038469253048, 88.74189146103399, 89.72926185977074, 83.41978426902526, 78.4809632455149, 67.54445383625647, 65.10124867962253, 65.39304948622181, 67.53757399897422, 66.31774825434532, 69.59123288431476, 65.87186890263712, 64.90234921055456, 61.23379168971893, 62.444827402791674, 58.28719346754013, 62.042709935096006, 59.9905768517525, 64.36786743902391, 66.63506800128569, 72.27747594156574, 74.47831784525226, 79.7922194388605, 74.4531205392653, 75.42771185598066, 71.76133909533101, 76.29759157857588, 79.481293155301, 70.43931991823258, 60.44565808388495, 69.50449359032416, 74.6548637267082, 77.10678438986503, 66.00910479022612, 62.14354230511574, 62.253098026398696, 61.44529765652072, 64.85534352640953, 69.03599000746205, 66.04544162750244, 67.14258347788166, 66.1437911372031, 71.35878624454622, 71.50436109112155, 70.83500077647548, 72.21502396368211, 69.130613265499, 68.81599210923719, 70.31961702531385, 71.67252878988944, 68.51373426375851, 65.7375983268984, 67.65261711612825, 59.207291295451505, 52.7990758803583, 55.627206756222634, 65.7127893355585, 68.48463027707993, 68.71886637903029, 67.33091215933523, 69.29743951366794, 66.46186397921655, 69.8754321375201, 67.01359241239487, 69.64121172505041, 67.20186618066603, 62.28429263637912, 59.872423295051824, 61.72710426392094, 63.623283909213164, 65.77912445991271, 69.70032968828755, 70.42055529932823, 71.47428435664024, 71.69436070226854, 70.13047249086442, 71.91573927479406, 56.76386256371775, 53.489946473029356, 56.507002230613466, 56.603433701299856, 65.40691898715112, 75.40144766530683, 76.69952469487345, 74.77341344279628, 75.99052490726595, 70.8893334481024, 77.67732451038977, 76.9196794879052, 78.65629319221743, 76.50561055829449, 73.15781270304035, 77.27796446892523, 76.72012498301845, 75.13001180464222, 80.39982595751363, 78.65194720606651, 80.5365127132785, 76.45887944006151, 81.65129738469278, 79.36126078328779, 83.06754758281093, 85.02248041091427, 81.435057117093, 66.66828263190486, 4.905917731023604, 0.44559507180125485, 0.7327796470734381, 3.703144490718842, 2.9416633902057527, 2.9681800834594236, 1.1631516631572478, 0.16792469567829565, 6.250231169885205, 73.38615740499189, 45.622283797110285, 65.815551511703, 29.745449135380408, 36.02531087013983, 49.04659924968597, 55.72642310973137, 51.46960419993247, 1.549486493872058, 0.10443041686930003, 0.062198326171886545, 0.0599958272200198, 0.0019841004517905775, 0.04009532591988964, 0.0469610327103686, 0.022839695297842546, 0.051984186960204, 0.04556009538411614, 0.020031379761114236, 0.04156919864697322, 0.11251241464408175, 0.14443663910271662, 0.13672317558478925, 0.20880121677633257, 0.17387035002391185, 0.13304002402770904, 0.10550801912623067, 0.14078097478035959, 0.15327104247145115, 0.18356928361519692, 0.2595320800619741, 0.4822992635590415, 0.5844070473986288, 33.40768575668335, 98.07235502427625, 58.58989454084828, 38.015215550699544, 55.9629890995641, 89.01448049852925, 56.143575022297526, 1.6366186377502259, 0.22272795979534427, 2.822915839572107, 3.1661997158681197, 8.23326679968065, 10.391011661098851, 0.5631332147505976, 73.50911586515366, 114.56144225212836, 98.75625164278092, 106.37013696855115, 96.53292671326669, 102.5818177192442, 98.3622181800104, 99.77318102313627, 98.48347433151739, 102.28935010971563, 96.59771642377301, 102.54929342577535, 92.51198737852036, 95.53149853983234, 92.67842138967207, 96.55574706292923, 95.92143704814296, 92.25452300040953, 86.75322624944872, 80.85304014144405, 70.71182266358407, 69.63589299109675, 68.6205639377717, 73.01103761119228, 71.61882369749009, 73.44639716609832, 68.04006884174963, 68.89381193345594, 63.561541880330736, 67.50039777448102, 61.23112840037192, 66.54846206788095, 64.23140425835886, 69.03543303089758, 71.68304858669158, 77.00033910812871, 78.83985227154147, 79.81067811289142, 76.12895319538733, 79.00523508748701, 73.5129362537015, 79.18307535109982, 84.70877708927279, 73.70718771411528, 64.02032582990586, 74.96677844755112, 77.83542740729548, 80.4041954778856, 66.68881231738676, 66.48411166283393, 66.59991571980139, 66.18854538086923, 67.85486236695321, 71.96265082205497, 65.32241936652892, 67.70425119707662, 67.71943861438383, 72.4851889764109, 74.34089368389499, 74.88793096234723, 74.18636014384609, 72.65583561312768, 70.54363143059516, 74.10974056490006, 78.83540430376607, 70.93918677299254, 65.49863576889038, 71.40909456437635, 59.01453818044355, 53.61596045955535, 62.19100298420076, 70.26903413957166, 72.44905610238352, 72.5473036304597, 69.96417968503891, 72.04626006464805, 70.55219788705149, 73.08636280798143, 71.70450395153415, 72.44296073913574, 70.3055827848373, 65.21699390103741, 62.15372870045324, 65.628783933578, 67.33466194521996, 69.05377403382333, 72.63790253669985, 73.0375999019992, 73.9308883297828, 76.55289080835159, 72.63947148476878, 74.80128580524077, 60.28069103917768, 57.676139185505534, 59.83015583407495, 58.64275632366058, 69.36850501644996, 77.99880196971279, 80.60555427305161, 78.68377331764468, 80.10680921616094, 74.8487307948451, 80.71508253774336, 82.12543349112235, 83.1750754387148, 79.04491378415015, 75.44452313453921, 80.17943582227154, 80.59526197371945, 77.90915227705433, 83.34092109434067, 82.1366750040362, 84.50775561794158, 82.5146032148792, 87.31495672656645, 82.99828637030818, 86.0384919566493, 90.6487124966037, 83.63749150306948, 68.73570903655022, 4.144445946139674, 3.5603508497438128, 9.632920469007185, 8.056422327795337, 5.277434337523676, 7.857395381696763, 1.1643451668562428, 0.43125792015944764, 11.308649182319643, 86.5657683341734, 54.31265969430247, 81.20968557173207, 52.382802578710745, 40.96687363040063, 54.770470896074855, 65.08097394820183, 62.49277837814824, 2.1841862941941907, 0.30233843792830745, 0.18850281323877074, 0.21975607491068302, 0.23790973869542922, 0.22435983432637108, 0.19498934098068746, 0.10382346838953034, 0.18563874756857274, 0.16019853042258372, 0.08719642631589405, 0.10956658440972529], [0.05384576146400744, 0.03177826555686132, 0.02121523649792277, 0.11723231298909073, 0.06523768042003916, 0.036822904742533163, 0.04373557272277052, 0.04330097487376582, 0.03680925305572249, 0.08687390329977197, 0.08384379573286542, 0.005114061594565189, 0.011201480989374462, 37.09307416792839, 65.39918799554148, 33.33234487041351, 39.63855904917563, 50.508694110378144, 75.19191465070172, 15.962375671632829, 0.07852905309729039, 0.12678395851605362, 2.7999420271765803, 2.5272147261327316, 2.3407016117726607, 1.6887617688025198, 25.47101486113764, 104.2656441657774, 92.23589174209103, 95.59795918003206, 82.36477651903706, 91.40634967434792, 89.27824420313682, 96.67126086450394, 89.84239870502104, 92.9714459757651, 87.9925932422761, 88.93869246205976, 87.58923238323581, 86.23982721759428, 85.40677070617677, 86.00439087037118, 84.87143778031873, 86.32677831957417, 81.65764377963158, 77.61174248110864, 71.69930288868566, 63.79253810451877, 61.952287535513605, 62.632932509145434, 62.46888722142866, 61.84352805537563, 59.93411433312201, 59.85788306882305, 59.21346510610273, 57.896525398377456, 55.757704011855594, 57.27446494563934, 56.23327570576822, 57.27966208611765, 58.72823261445569, 65.56619075036818, 72.14581766436177, 72.99947446392429, 72.41942651810186, 69.76980270877962, 73.15642418399935, 70.7133210089899, 73.38014048914756, 71.38842367356824, 64.12827730178833, 56.09419630419824, 61.70211876592329, 69.2633854958319, 75.81332006762105, 71.0171478025375, 56.66017470821258, 58.67122880874142, 59.230264617550766, 62.84878838446833, 62.329976481776086, 70.18460904398273, 70.74312317755916, 74.13239617501536, 67.56145338858327, 66.07265503175798, 69.29387015681114, 69.69490897270941, 63.486612842928984, 63.62669637126308, 63.03988233689339, 61.27523545295962, 62.63384249902541, 66.55732662447038, 65.35305699994488, 66.0561732322939, 58.77017059633809, 55.23660536735289, 58.83978874452653, 63.10132234327255, 62.407721780961566, 66.03322736678585, 68.34289935327345, 65.72363468908495, 68.89031317926222, 63.035614798145915, 67.80913537548435, 65.53651802001461, 64.25789202413252, 60.4155578151826, 61.46134407289567, 63.36578815214096, 65.62839954130112, 65.28078340714978, 65.96412304908999, 68.31305796100249, 66.617935088373, 69.67492057431129, 67.94001702339419, 60.59800294137771, 50.20340819512644, 54.09092418609127, 54.689991704879276, 59.370038278641246, 68.85033638246598, 70.0037956237793, 72.85462133346066, 66.37187696272328, 69.96283038969963, 73.24539138424781, 72.00087824175435, 73.59610619083529, 74.76553732349028, 73.57545883424821, 73.26923155015515, 72.3093883452877, 74.8439141242735, 71.57073543917748, 76.46932863420056, 71.04126253435689, 72.78209670897454, 73.30741190141248, 77.0902947456606, 73.560271416941, 81.29801734801262, 71.15390516096546, 78.4486742942564, 33.912102560843195, 0.35189326431962753, 1.3172300856920982, 2.882508409600104, 3.6745996869379476, 3.4048573095952315, 0.46460894507265865, 0.05807020010486726, 0.38716024448794706, 50.64376092726185, 57.051588027708, 47.01532533091884, 63.57508190216557, 44.114399187026486, 45.984871618209354, 40.22220380844609, 51.67899208684122, 1.8995815659722977, 0.1528952610228331, 0.09393934836430896, 0.05453417956408474, 0.07315932833138974, 0.026190002719240806, 0.053673790046764966, 0.023868068744758927, 0.016581825649125442, 0.0310107373872832, 0.08874389327942364, 0.05063966817913517, 0.05363559673329996, 0.046866570238865195, 0.018663682989896308, 0.06831286460041039, 0.02560431509458971, 0.03974034758885542, 0.032706679851417585, 0.02085066866129637, 0.04691487208249108, 0.033156580306709774, 0.03775123093697814, 0.022275077006328973, 0.028665924196942683, 49.54532077235561, 70.06322737663024, 46.18742281390775, 39.91731797495196, 54.67730283737183, 87.67084121704103, 18.326427398189423, 0.062019314406619924, 0.6266989619020493, 4.962316511138793, 3.462096457519839, 1.8443951659625577, 1.3735882937908175, 35.98534976282428, 107.09533614497032, 94.25741072623961, 99.37231479152557, 87.3829706253544, 96.25351275167158, 93.53309800547939, 101.67242403953307, 93.64332445206182, 96.39243525843467, 89.01942268494638, 94.8804243149296, 89.13078661887877, 90.9966031966671, 87.30757482590215, 91.68184911051105, 86.35716884366929, 89.23596105267926, 85.30913506784748, 81.81725286668348, 72.99988239042221, 68.07491517836048, 63.484647735472656, 65.68310483809441, 64.92434194011074, 68.11599023880498, 64.4102172697744, 63.18094645777057, 61.834051609039314, 59.37049719595141, 59.217093298512125, 60.706225056802076, 57.46971268807688, 58.77320258848129, 62.76499086810697, 70.81784432934177, 73.47784673013996, 76.08359490671467, 77.53989250429215, 72.1824682912519, 73.98743321818691, 72.80449344265845, 76.69990908715033, 74.54586890435989, 67.18290544325306, 58.88009502041725, 66.50420988759687, 71.91688460688438, 77.82667267707087, 75.41945918913811, 59.68271393929759, 62.88619995117188, 60.95964547126525, 64.11743587063205, 62.66413888623638, 74.18699556781401, 71.89882601461103, 77.00417518615723, 70.86173565156999, 69.78937533593947, 69.62111350028746, 68.63013452099216, 65.84311008453369, 64.944196977923, 65.01937704701578, 64.39308435686173, 66.0474734152517, 70.00352105786725, 68.99612303703063, 67.38238934547671, 62.70965799208611, 57.277320431124785, 62.78231597715809, 63.272867202758796, 63.20251557134814, 66.89832964251119, 70.50251714644894, 67.99603631419521, 71.10318891463741, 67.01909157537645, 69.91903320435556, 69.93376562672277, 65.99969110181256, 64.49238700251426, 65.23411504683956, 68.18627126755254, 69.31993822897635, 67.9291912817186, 67.7266949992026, 69.91083545069542, 70.76874409952472, 70.91428756713867, 70.77574160791212, 62.541937443517874, 52.80059383761499, 56.713342435898326, 54.788800131890085, 61.220549768017186, 71.5325786221412, 73.1009618697628, 76.3669704621838, 69.89920954550468, 71.43324851989746, 74.19480892919725, 74.67500117517288, 76.42300544246551, 75.94955967318627, 76.07811143321376, 75.44155782268894, 74.9036753562189, 77.70172165286156, 75.613553754745, 77.23399469929358, 74.99363883849114, 76.05318869313886, 75.63721349162441, 80.34365761664607, 78.09775552441998, 81.91402558357485, 78.59058564709079, 78.30023611745527, 44.666072707022394, 0.753487493963011, 0.9104150894188112, 1.420686153634902, 3.25866959268047, 3.3642928927175464, 1.648064113913044, 0.027889649218489087, 0.13274817517207516, 53.39787275560441, 67.32319293483611, 54.231274435597086, 52.236596230537664, 38.04484905735139, 56.96435843744586, 45.82126955832205, 62.77688349446943, 2.4054405766148723, 0.11768443509936334, 0.02839081244723451, 0.053791989752602194, 0.004674987398057936, 0.03734218978112744, 0.048698336261534886, 0.005171039862738502, 0.013639710941201737, 0.08306688298621485, 0.013057826943094692, 0.02226376763334678, 0.21587131965544917, 0.13603210299005433, 0.0835385173559189, 0.1977632074586807, 0.14095794109086837, 0.09745255863714604, 0.18159551936532223, 0.09723776290493627, 0.12557386135261867, 0.1818914284869548, 0.20862118611412667, 0.07154782407826955, 0.0830859509146502, 56.156930692734264, 86.11751987088113, 48.56655213140672, 56.609136827530406, 69.84945035749867, 97.39331430004489, 27.177173322246922, 0.09534479794843544, 0.6590056251133642, 9.670815467834473, 8.802883202029813, 9.924716372643749, 2.8758697980834595, 34.86155148475401, 113.27351631656771, 99.45917175662134, 106.5127072795745, 92.63130587916221, 101.58176237537016, 96.52148908184421, 104.13260521427279, 97.77340765922301, 102.34947219971689, 94.68811835012129, 99.35933174625521, 92.378203176683, 95.34540560937698, 92.08985405583536, 96.19679527897989, 89.46265051441809, 90.46637719677341, 88.3309918065225, 84.77466506342735, 78.92310850081905, 72.43029932821952, 68.0422261453444, 69.1800194401895, 68.81039880937146, 71.4682674407959, 67.98883484255883, 66.94987743131577, 66.41485045033117, 63.10957108774493, 61.064894430099, 62.16118904852099, 62.3534518672574, 64.05571737597066, 65.14743458840155, 75.10035868613951, 78.76327191629719, 79.57399445195352, 77.012341560856, 74.12857578646752, 79.21612524217176, 76.65992444561374, 77.73639540518485, 78.42555584446077, 70.89999445023076, 61.798271748327444, 69.10398037202897, 74.11601635717577, 85.5042729839202, 79.51522165729155, 63.26699933698101, 68.02505400873, 65.04446452663791, 65.44209480285645, 63.599306460349794, 74.5212991776005, 74.1637751363939, 82.54580959197014, 73.75390314286756, 70.97589231306507, 74.44879024259507, 72.23244713198754, 69.03372287750244, 67.48964263546851, 66.45112452968475, 66.42085952143516, 69.49301673519996, 71.31352993749803, 71.29688339848673, 70.55002489397603, 62.639341662007, 60.806245496196134, 68.63946976200228, 68.98397937897714, 68.32748443849626, 71.64615477285078, 74.57891095069148, 70.73279949926561, 74.95363850747385, 69.31560008756577, 74.75653940631499, 72.650038350013, 68.89550639737037, 67.31702696892523, 65.65344779722153, 70.5952262878418, 71.36053562164307, 71.61019448311099, 70.29439618510585, 73.1510191579019, 74.12348454998386, 74.52068728785362, 74.77855959246236, 64.3115931941617, 55.87429646522769, 59.06805499907463, 57.20337983100646, 64.3450863130631, 75.63521308283653, 75.17642913326141, 80.13600733972366, 73.66492025313839, 74.90048254689863, 78.1455143036381, 77.65604172983478, 80.5871348227224, 79.57070750574913, 78.61764215653943, 78.34735162796514, 80.53996439903014, 82.55175590515137, 78.65528906545332, 81.43553564625402, 79.97497050992905, 79.32468075906077, 81.43028751496347, 82.85054637539773, 80.41371114792364, 86.08552117501536, 81.5874804219892, 82.46070984871157, 50.11736708302652, 0.5495851030272823, 5.132650829130604, 7.098940389771616, 9.791992191345463, 11.098366014419064, 1.5052236496440827, 0.1420262507012775, 0.7326305357198561, 63.0783058751014, 71.9050076700026, 64.36221922597578, 83.53794959283645, 57.12273982263381, 61.46833373654274, 55.47818806863601, 72.9626355632659, 3.316495134945839, 0.3234557128481327, 0.1719258043674692, 0.1260537618110257, 0.23666201129315362, 0.08364223799998723, 0.11550281587387286, 0.14358004555106163, 0.1465522368708926, 0.13886711860616363, 0.17089118730396996, 0.14190214445754407], [0.03569800804759707, 0.006925351523433722, 0.03740359172825852, 0.013002705959332807, 0.028087043263498816, 0.0377628754734272, 0.02919868089168543, 0.07793739573248933, 0.02492221147422829, 0.03747072784350284, 0.06141330055411785, 0.2171668203006829, 1.077810448984946, 52.635230633520315, 51.97220494670253, 36.873284155322665, 38.19469536504438, 70.46981242395216, 55.64415139536704, 6.384191388084043, 0.19714990811001873, 0.9295179514634995, 1.8937097778243406, 2.2764634845718263, 1.8371853592895695, 3.58392846199774, 78.71140249313848, 97.48822781347461, 90.82683517086892, 85.20670629316761, 86.29750174860801, 86.89975030960576, 93.82215315295805, 88.87226320082142, 90.93503767444243, 90.08318516515916, 87.50308144477107, 87.15227250129946, 85.23267238370835, 87.74408755763885, 83.3520684703704, 84.91514867351901, 90.76130021002986, 86.67043285985147, 79.21008479210639, 79.35868770845475, 67.46945811856177, 61.802602044997684, 59.880444542054214, 61.31270977758593, 64.7319536055288, 61.26347226481284, 62.21638464158582, 56.73316217237904, 59.05069066632179, 56.53013636988979, 57.361255230442175, 56.992069982713275, 55.461761182354344, 60.83103487568518, 65.03197177763909, 68.57283653751497, 69.1773836074337, 75.96075411765807, 76.86934763385405, 73.08975173581031, 72.37890843422183, 73.72433631650864, 75.71367617576354, 69.52622352107879, 64.33199344142791, 55.04617821785712, 64.34237595527404, 68.06090447210497, 70.09245687915434, 67.68459227777296, 60.27252074210875, 58.22172126462383, 59.27969432646229, 61.74424502157397, 66.35221804341963, 68.78961024745819, 67.33907068929365, 67.70021900053948, 69.98594883949526, 66.99992687471452, 65.94032210688438, 69.81248594099476, 65.68819999694824, 66.81220223826747, 67.48906996942335, 66.8592942145563, 66.44723353847381, 66.20338762960127, 67.20771051222279, 61.414483516447014, 62.20511959445093, 60.7568314767653, 58.307734920132546, 57.71504517524474, 55.03857666446317, 60.2788043791248, 61.85422828120571, 66.09147456384474, 62.58931575282928, 64.05385032776864, 68.08803942895705, 71.63905528283888, 64.02754299102291, 70.53911286015665, 67.55331054810556, 67.57989637313351, 66.90815125742267, 66.93674533597886, 66.1561466032459, 69.4337026534542, 67.46927768953385, 68.78319324985628, 67.16097939398982, 60.0888204574585, 51.123243224236276, 53.666092272727724, 52.884485490860484, 56.37146472930909, 65.11882482036468, 70.59563421433973, 69.22498549184492, 67.95056035441738, 71.98463962924096, 72.17054428592806, 69.22556600263043, 70.58758551074614, 68.33066155833583, 74.08034632282873, 72.82602725490447, 71.92632967425932, 70.62178857864873, 71.96132506093672, 67.74519289693525, 67.68329005087575, 69.20928032167497, 71.39466024214222, 71.1209023383356, 78.36861871903943, 78.58928342019358, 81.64320945739746, 64.4180110193068, 69.42785047715711, 13.492101257847203, 0.5294992582451913, 2.5806690319891903, 2.6797571730229164, 2.5663479681937926, 0.945186717135291, 0.11803731817992465, 0.24357911109203295, 21.082219962150823, 74.59921313870338, 44.27778159418414, 49.267460069348736, 41.654900504696755, 40.720721367866766, 43.56709910977272, 51.09864604088568, 2.663547487989549, 0.1303547632790381, 0.03302560991517479, 0.11720158520244783, 0.018621663067249522, 0.058634818396380836, 0.013022584025748076, 0.03342656884342432, 0.03142331403890445, 0.05358102446001384, 0.017413990572094917, 0.04908447904932884, 0.02612134974990641, 0.030438881480104985, 0.038029412784042864, 0.06781718273076319, 0.017124242712593368, 0.06946803325967443, 0.00515733742260284, 0.020867097416832563, 0.06614370962544795, 0.05070799173066213, 0.09295998156190881, 0.131003302672217, 1.8208176762826982, 68.08403861138129, 57.60654064916796, 51.11007582756781, 35.48147424574822, 72.82672543679514, 65.23098891781223, 7.50180212720748, 0.38341413582524947, 2.559119530262486, 2.834399558844105, 2.8345187008380894, 1.106235252753381, 7.992269021849479, 90.67201137542726, 99.77101587480115, 95.9636966643795, 87.08978129971413, 89.70432343021517, 88.98874975019886, 96.93820168895107, 92.48309519983108, 92.57838526079732, 93.26295652697164, 90.82303831654211, 89.08418101649131, 88.34354339107391, 90.29878216405069, 88.90472473636751, 90.27083919894311, 93.09552623379616, 88.28659057617189, 82.11652186609085, 81.12011432647705, 70.54971110436225, 65.99877326719223, 63.38248568196451, 63.1864534654925, 65.63400068590718, 64.7153619796999, 63.06769978615546, 60.90133159391342, 62.36068079548498, 60.42057452663299, 62.89410744943927, 61.456947095932506, 59.90903077587005, 62.55911742487262, 70.11797581949543, 72.47546149838355, 73.26599167239281, 78.58547872112644, 81.54856266513949, 75.04751651517807, 74.40450668334961, 76.27961927844633, 77.0767076553837, 73.14805384605162, 66.87795685183617, 58.684498187034364, 66.20192066315683, 71.08895071091192, 76.24039557672317, 68.79598017661803, 62.62648413258215, 61.709555579770004, 62.124718850658795, 61.763719589479514, 69.03718240799444, 71.23032862140288, 70.20557803492393, 70.5063767586985, 72.72829747969105, 69.56113261561241, 70.54405504657377, 69.59799505049183, 67.97402397278817, 67.94648893417852, 70.57546538691368, 69.23996894590317, 67.54581097633609, 69.05506057123985, 68.90700678671561, 66.06133507144067, 63.625390221995694, 63.30754879982241, 60.92718393571916, 60.94591325329196, 58.96720301720404, 62.535465532733554, 64.34692590467392, 69.2208356242026, 65.5474575104252, 65.78674562515752, 70.20496614517705, 73.83044427441013, 67.57857061201527, 76.53715425922026, 70.92567028537874, 71.88505849530621, 68.87275665037095, 70.38217098482194, 68.61505693004978, 72.54022767466884, 69.51000844278644, 72.35092624541252, 70.08801675611927, 61.97404100048927, 53.182342437005815, 56.68403056360061, 54.01524597598661, 60.677823174384336, 67.56117882267122, 73.58060498391428, 72.52623265789401, 69.77449386350571, 75.05307059134208, 73.46700529898368, 71.1819108839958, 72.64071879848358, 72.83587240403699, 75.10759153673726, 74.01719616305444, 76.36147914394256, 71.33599727384507, 72.77661323547363, 69.11778711503553, 71.75401210784912, 70.50930284684705, 74.94497791413339, 75.7069375438075, 80.92653751373291, 82.1688227499685, 83.55748299629458, 70.54760086920955, 73.67155690346995, 19.758898558155185, 0.4824221747056131, 0.5641117848215566, 1.6223750407657318, 3.611538515936944, 2.3406589559970365, 0.690141276967141, 0.34712550080110954, 21.219402897742487, 83.45943158672702, 54.80026914227394, 49.489940827892674, 33.95254219731977, 46.688764479852495, 52.88745472508093, 61.74525307070825, 3.9307422263007012, 0.21381271882883965, 0.0409072105802836, 0.10365037082303917, 0.019970085066292557, 0.049527863926825025, 0.03192976135910759, 0.05432131437344417, 0.047489736799991904, 0.018994565940492095, 0.03538460913865316, 0.053650432025953654, 0.11851214713627294, 0.15713033296408194, 0.10228262042566653, 0.14488368205005123, 0.14883511759821447, 0.18615024915385633, 0.21057074198559408, 0.20741219211730266, 0.1816879708560244, 0.21976307695431097, 0.16381222844844864, 0.43177637782308365, 2.077403933771195, 77.36787303801506, 69.80625721716112, 51.609985828399665, 53.81179263514858, 86.7235182177636, 76.91469807778635, 12.946745695606356, 0.4645486692747762, 4.192124807065533, 8.654400898564248, 7.16711804751427, 5.926332627573322, 9.159964995999491, 92.17320442199708, 106.24813556671144, 101.81856370741322, 92.90289078989338, 94.09381651109265, 91.48744075529038, 101.03042617920907, 96.74909637820338, 96.98248524819651, 97.3404093711607, 94.0503409601027, 92.92282427510908, 91.55574490947109, 95.56666651079732, 92.41491656149589, 95.22769528050577, 94.24269399335309, 97.24831996425506, 85.94638686026298, 85.711727142334, 74.47779224764916, 70.70729624840521, 65.22855312593522, 67.68459227777296, 70.71662364467498, 68.74037665705528, 69.99974773776147, 63.493155356376406, 65.05176405752859, 64.63241561766594, 64.09655709420481, 64.65281194256198, 61.89594268798829, 66.74649469314083, 75.56996053264987, 74.57949930621733, 75.90780996507215, 84.7146841787523, 81.34615267476728, 78.22096501627277, 79.0552374624437, 78.9289685218565, 81.09621924738731, 75.56646177845617, 68.81747476516232, 61.31579668291154, 70.6558661307058, 74.29731615128057, 77.85123455908992, 71.68645320400115, 67.77555988680932, 69.80435878999772, 65.84693047308153, 64.68324169035881, 68.59306027812343, 73.2185859064902, 71.95388824709, 72.77724081470122, 74.87024107287007, 69.58835386460828, 73.07254822023454, 72.6570515478811, 71.34925488502749, 70.92343453438052, 72.76889401097452, 69.78242489599413, 71.48846764718333, 71.06118817483225, 70.59231588917395, 66.7863695083126, 67.37531338968586, 66.0781071262975, 64.4783253054465, 63.29045903298163, 62.597470360417525, 65.72964376018894, 66.57161189663795, 72.23009370988416, 67.85909852673932, 69.22149458239156, 73.0613459310224, 76.91394498271328, 69.33256826093121, 73.46262008913102, 74.15958604504986, 74.1076538639684, 71.54731888924876, 72.17248978153353, 73.0687984343498, 76.11711548220727, 72.25048219003986, 76.45673782594743, 73.45132366303476, 65.05093643742224, 57.32043512405888, 59.19488876096664, 57.32655009915752, 63.41062084321053, 71.16495840011105, 77.18539653285858, 74.88818199403825, 71.44252100298482, 79.15192388719129, 77.89075636094617, 75.52333139604139, 77.63577876552459, 76.1832074196108, 79.93062419276085, 78.48438355230516, 80.33265144594255, 76.56824296520603, 78.11342147088821, 74.80440801189792, 74.81972878979099, 75.70365844234344, 78.25672918750395, 78.82231927687123, 84.23476649868874, 86.7725400001772, 86.03618560298797, 75.03333322463497, 79.78178593420213, 20.491732628114764, 1.5910545472175845, 8.532570119827025, 6.197863115418342, 9.063104025779232, 3.8844131510103908, 0.4332003514132192, 0.2867389266048708, 27.453031655280824, 93.1607081813197, 60.3779265957494, 67.54241420376685, 54.749592119647616, 52.83900168634231, 58.54939214644894, 75.115279382275, 5.68352222442627, 0.36776982368000094, 0.11167501925580925, 0.20063386148502751, 0.057862705190575896, 0.15804510323270676, 0.16791234634095625, 0.08801250147723383, 0.09872520687959849, 0.10332794739834725, 0.13655115820227132, 0.12485863400563119], [0.025694439593221874, 0.020734631238625418, 0.012322706207933446, 0.08008744447462021, 0.029094016044250423, 0.0054030337900434055, 0.08200825672716865, 0.05290243143756544, 0.03423833859062964, 0.010036844440976219, 0.10761223282785186, 0.3886188758957771, 6.688818835443066, 67.41871049327236, 56.80333729713195, 40.85166185132919, 53.189689036338564, 81.50683649124639, 30.215160808255597, 1.5628095596067368, 0.07110620503343883, 0.9857292545418587, 1.319257583348982, 2.0762171716459337, 0.8121890118045192, 30.52887393582252, 94.38912391662599, 91.55007316220193, 90.20094256247245, 81.88762018757483, 78.25989061786284, 87.06528217561784, 89.72763015377907, 92.04173441856139, 84.32014080785936, 87.52360328551262, 86.89672223983273, 87.75226177707796, 87.01859812582694, 88.23318358390563, 84.92245212677987, 87.98848259833552, 81.28915279142319, 77.7359639444659, 78.02793733535275, 72.78115534013318, 65.74945565192931, 60.18143153959706, 60.10169367636404, 64.52509172501104, 60.98736093890283, 61.08234113262546, 60.19000976316391, 56.431147513851045, 57.40497789075298, 58.26771889963458, 59.65668901320427, 58.08181032057732, 59.9157537183454, 64.59522370369204, 67.68840482158046, 68.04874512457079, 72.96826808683335, 73.71889206670946, 76.68905196651336, 73.51815300603067, 71.46531781842633, 71.26859526480399, 73.5689006313201, 68.798278685539, 62.53785817853866, 60.17691689152872, 67.19320558732556, 69.48044946116786, 74.8189756947179, 66.0015110815725, 57.64932586300758, 54.93250008552305, 60.86080566529305, 65.69938659667969, 69.715909342612, 72.18607687181043, 70.08757745065998, 67.99352599728492, 67.18646695536953, 68.9406293438327, 69.89417322220342, 64.72072385972547, 64.26008462905884, 66.14026100404801, 64.61724388983943, 65.56327642933016, 65.46620953467585, 63.565856487520286, 64.3730841913531, 68.08640772296538, 62.57655236028857, 57.80773470478674, 61.18435021369689, 56.91478360083796, 60.29633345142488, 58.44696337176908, 64.3302793656626, 63.1793696649613, 65.58593596181562, 61.99571209569132, 67.21074642673616, 65.46992401922903, 78.64543607158046, 67.51482425197479, 65.3811921611909, 69.11766159919001, 66.53396498772406, 67.97937408570321, 65.24519574257636, 65.6115843403724, 64.40297657443632, 64.60480997639318, 63.0845542107859, 55.77015753715269, 53.30425362433157, 50.28105151268744, 54.90434923479634, 52.25467835703204, 63.74519901890909, 66.84513445823424, 67.89504312699842, 68.5918051196683, 69.72069463422223, 68.85490202134656, 64.25878240216163, 61.63547769669564, 66.97130926193731, 69.46327732455346, 70.5022112015755, 67.80838228041127, 67.65144040507656, 63.24154315456268, 62.41872795166508, 64.7616224135122, 70.95802199456, 72.73236889992991, 72.60371515827795, 78.64257274135467, 77.97995890340498, 78.95199283476799, 74.39472429213986, 65.01898873236873, 59.25129636641472, 1.3306714354022857, 0.8282535078544772, 2.1982391659290563, 1.362943716587559, 2.4402832360036912, 0.5034102872014046, 0.08768649276105628, 4.440281891053723, 71.62305985727619, 53.02350605687788, 47.8671621507214, 48.632208685721125, 69.8593347303329, 43.38701917279152, 50.97811552786058, 4.807339252964144, 0.14099621484356542, 0.011121901691020017, 0.09192318880870458, 0.01669888005351588, 0.01820847163006904, 0.0426329730168706, 0.03768463874416005, 0.05090692944283928, 0.014868442235784906, 0.13154705655911278, 0.04801408567976567, 0.03502833994946653, 0.030574973169413787, 0.037326228339225054, 0.025724924146948804, 0.08231060098736517, 0.02201012166727695, 0.047876071109766924, 0.04029589156890589, 0.014061550553437444, 0.14532332458803732, 0.3598475245939147, 0.43984732860999726, 10.140404566641777, 79.90121426120882, 62.49990140238116, 49.05110605301396, 38.14470475719821, 89.5904884030742, 34.28550435650733, 1.1796823696744059, 0.5792666587137407, 3.189331158514946, 2.4521542893302057, 3.107640200084256, 0.11900020643107354, 38.65619359477874, 103.13857463098343, 96.0589082779423, 96.10668274664111, 84.2953122046686, 81.06178868201472, 89.54878576340215, 94.1439522466352, 95.51346348178004, 89.76094676602273, 90.45337846202236, 90.66823805532148, 89.81913120515885, 88.40206515404486, 89.1019650428526, 88.12734234717585, 90.77805657540598, 85.7989606549663, 82.39035037256058, 80.07732083720546, 74.82382374425089, 69.86220590529904, 62.163511091663, 63.96427516014346, 64.03105743469732, 66.53160372088033, 65.82316875457764, 62.52378079199023, 59.81511746683429, 59.20473783246933, 61.93865337679463, 62.77374559833158, 60.97671954862533, 62.1906578156256, 67.57605245036464, 70.77419619406425, 72.1668964816678, 76.90701807698896, 75.8619966814595, 77.74489125897809, 78.18756995662567, 76.27196281186997, 74.82773826968285, 73.29990448490267, 73.15749891342656, 64.03683508596113, 63.59013203651675, 70.35420448549333, 73.19572633312595, 76.99657363276329, 67.73159796191801, 62.07148836505029, 59.64262731613652, 63.26336329983127, 67.4923804498488, 73.6679640123921, 76.47742440623622, 72.8041482740833, 70.66754694907897, 70.11450059952276, 71.53944276994275, 72.78342247009277, 67.42735539713215, 67.05203948482391, 68.1972146803333, 66.82988428300428, 65.65812326246693, 64.79237379566317, 67.71525736778014, 67.57489927353399, 72.63077166772658, 64.61559257199688, 61.27136799596972, 62.68372720287692, 59.92312777426935, 61.65797248963387, 62.211685642119384, 68.08427395359163, 65.79704184685984, 69.13275487961309, 65.72310124674152, 70.58172548970869, 66.78364738341301, 80.10312218819895, 69.80000495910645, 65.97661972045898, 70.88221042386948, 68.02996481618574, 68.11482137249362, 67.10762731490597, 67.2363987276631, 66.84655435623662, 67.83056720610588, 63.902737094509995, 56.19520125850555, 54.7173894605329, 53.71814212491436, 56.262544431994044, 54.949499637849875, 65.99497641286543, 70.9160840126776, 70.35845633476012, 71.42511352416008, 72.7027863840903, 73.52128305742818, 67.29220621047482, 63.88130134151828, 67.96215488064674, 72.48678145870086, 71.4628702594388, 69.82257427707796, 70.7330269967356, 67.54188076142343, 67.46122898594027, 68.29319507844987, 73.70382232050743, 75.05562797669442, 76.4398951684275, 80.29815027790686, 80.79888005410471, 80.17506630189958, 77.47467917780723, 68.45722859905612, 68.22299249710576, 3.2635558853226327, 0.8645082817923638, 1.3728961180294714, 2.6704525755297754, 4.539372238420672, 0.9700810200264378, 0.35007591990213244, 3.878869616216229, 75.68971049401068, 63.78276748041954, 52.80324928222164, 39.19205996298021, 70.14453811030235, 51.22180061955606, 60.21414410683417, 6.542175142995774, 0.28440720011149684, 0.02991845497050353, 0.0457599294191647, 0.03644114780810572, 0.031107532596516035, 0.05072092329482398, 0.02018147936811851, 0.0957183424203146, 0.05501966480345977, 0.03773823808578234, 0.10340166803930076, 0.14452424891773732, 0.09079048950825969, 0.1632647207307239, 0.15096710964797005, 0.18116405864636745, 0.11557282098839361, 0.19824437196216277, 0.156610680203284, 0.14610007645622378, 0.20703167624531255, 0.6104482145559403, 0.6311567968899204, 11.51961386203766, 92.15211775995071, 72.62415070687571, 54.70999187038791, 72.70093502536898, 102.11623237979029, 46.9155990692877, 2.3037749480816627, 0.26767458346101547, 4.879415746658079, 5.142826928246406, 7.891743577295735, 1.8973099007721872, 41.30825319597798, 105.78591562086537, 100.95936852116739, 100.14427646513909, 91.7253952641641, 86.87242707898541, 96.06134799218948, 97.17010790301909, 100.86096409828433, 93.48083634530344, 92.90993536672285, 94.99411813674435, 93.085461431934, 93.07031323832851, 95.762463385059, 90.50874663937478, 95.12575287972727, 90.732462944523, 87.30836714467695, 84.95018328389814, 79.90596817385766, 74.20753309803625, 66.0465398911507, 66.88476608645531, 69.93654266480478, 69.57057768298735, 70.51178178479596, 65.72400731425132, 63.73503615779262, 63.483937786471465, 66.55870729877104, 67.05498910719349, 65.72520755952405, 65.17535794165828, 70.76127590671663, 73.96795472791119, 76.00492000579834, 78.29581168390091, 80.20318185129474, 83.71372668973862, 81.69616929946407, 79.16697794391264, 77.46426136262956, 78.96226159987911, 76.69857548129174, 68.59972830741637, 66.85708984251946, 74.77382921403455, 75.83951365563178, 82.84040312613212, 73.63612221133324, 66.81210025664299, 65.47648222215714, 66.92735518178633, 68.66827564854776, 78.05216189353698, 80.47177007121425, 76.05038812083583, 74.2844037086733, 72.96385149801932, 74.94636643317439, 77.0486548639113, 70.32945432970601, 70.04465103149414, 71.41663335984754, 69.33409798529841, 70.46405438453921, 70.08970337529337, 69.3242528361659, 70.96070489575787, 72.92070542612385, 66.59695040795111, 61.299475700624534, 68.85654941681894, 62.22333900390133, 65.96529976014169, 66.40230671052011, 69.66607170720255, 70.75435684573266, 73.15824416375929, 69.29014390514743, 72.598890642966, 72.67971500273674, 77.72175711970176, 73.86828730183264, 71.12843328906645, 74.95690191945722, 71.19301119158345, 72.6212481529482, 70.86196314903998, 70.04385086797899, 70.14646007168677, 71.139462993991, 68.42213123075425, 60.822178163836085, 59.26848419250981, 56.471057630354366, 59.42347664986888, 59.216967782666615, 69.76085970478674, 74.24569775981288, 72.27285538950275, 76.15408774345153, 75.64032785354122, 77.8840647974322, 70.95648442545246, 68.40754785845357, 71.01084063130041, 77.26684062711655, 76.7732495646323, 74.09922076809791, 75.38252615159558, 71.72822644633632, 69.37641251471736, 70.08640858434862, 78.91609530295096, 78.28307182558122, 80.75298832308862, 86.21116253637499, 85.05338084313178, 83.75207178054318, 79.82562234324794, 74.76270537222587, 72.36234034261396, 3.0052761445122385, 3.246077803834792, 7.203052351551672, 6.522653506648156, 7.271552624240999, 1.3694059440205175, 0.32733407893007804, 5.189513429518669, 85.01694202423097, 65.70366982490786, 65.99499210234612, 65.33117409675353, 81.1253075445852, 56.25414271508494, 74.21968460083008, 7.462688742145416, 0.45430092561629515, 0.20030724755938978, 0.15635381092227277, 0.17033249470255069, 0.16808244850366347, 0.1732934551734117, 0.0762134910591187, 0.20984039972386054, 0.1589265333548669, 0.19321770136875493, 0.13016903292267554], [0.0340109100685485, 0.06571280048979868, 0.0658246263441059, 0.0589853649087731, 0.015355384957435873, 0.07694151207444168, 0.11308114299730909, 0.09163356926893035, 0.2150866004728502, 0.03722324313956403, 0.06235731622925209, 0.4255980319313465, 19.111101473531416, 68.12201499938965, 41.61819496462422, 40.00294723818379, 62.02006216972106, 67.61373858298025, 15.641665035678496, 0.07818334059970034, 0.6695629295802886, 1.1801862716674805, 1.309007449496177, 2.473919276268252, 0.4966296123400812, 54.89590437181535, 95.69151555338215, 92.5280769409672, 82.76328932854437, 74.25762176513672, 75.38297330179523, 82.16864232094058, 88.48427018811627, 95.60250912943195, 93.01944794193392, 85.40468400524509, 92.17642861027872, 87.86687343351304, 89.20706102924963, 84.57632649329402, 84.89563095954158, 81.41147582761704, 79.96998125506987, 81.0437693134431, 74.32190156752064, 68.7287115281628, 63.66727329069569, 58.874631158767215, 59.36311137291693, 63.1930273579013, 63.94701673138527, 62.01859912564678, 58.30069426567324, 58.3065660538212, 56.40137672424317, 55.450523591810665, 56.50697477402226, 59.088784725435325, 63.47290808154691, 68.00293968569848, 71.26341773617652, 74.34618888362762, 73.57272886460828, 72.05568159780195, 71.46931863600209, 71.42601566929972, 72.93262943144768, 70.80914451229957, 71.06998997349893, 65.03019494395103, 60.727233271445, 66.30666363623835, 69.36815984787481, 70.3589270191808, 67.30292212578559, 60.46228893341557, 57.215778443121145, 58.424205780029304, 64.34375662957468, 68.37705535273399, 68.28121615994361, 69.5244506097609, 65.96821015880954, 59.440409521902765, 68.24174142652943, 64.53435244098787, 60.365884919320386, 62.54653053898966, 63.62024407232962, 62.23811849471062, 61.36770925214214, 59.813870153119495, 58.4466064360834, 59.42560257450227, 62.242652754629816, 67.33256739954795, 67.81055527348673, 59.518884381940296, 57.89274031116117, 58.19435881030176, 60.332136846357784, 61.47184425784696, 62.9682324009557, 61.973605617400146, 59.81866328947006, 60.36293529695081, 61.77476890625493, 66.7306875413464, 60.746727451201416, 57.9029933867916, 69.71966697323707, 66.11958226849957, 66.20550570949432, 62.37433064368464, 62.303198460609686, 58.44581411730859, 56.69553879768618, 58.00435919915476, 56.155126402455, 54.50988038893669, 53.00167806686894, 50.06804720047982, 51.50297964772871, 51.63457908938008, 61.82689328347484, 67.45354114040252, 70.07871289407053, 71.65093221972066, 69.9834228331043, 69.14963676083472, 60.35829905540713, 59.31126548397926, 59.54932589684764, 64.20664625783121, 65.17447148599933, 64.81828497302148, 63.291216050424886, 66.44256591796875, 67.06160222330402, 70.20783732014318, 74.59219209609493, 73.82009706189557, 74.21195753159063, 76.39838080252372, 79.92385418184342, 74.79275857248615, 77.10551354192918, 66.71507650806059, 68.37140713968586, 37.57983638394264, 0.2114913958094774, 0.2179208806445522, 3.6777135585584952, 1.7751946276234043, 1.2958597872526416, 0.058293472599959185, 0.22487933386958417, 50.12489411138719, 67.14585473460536, 46.66587352752686, 48.8674214578444, 17.8352838946927, 36.69064291061894, 56.804859176758804, 6.295059448288334, 0.19459095993830314, 0.04129979616752075, 0.054271985971999746, 0.036266165665320815, 0.07739597075288335, 0.007207941248892777, 0.020541513879452983, 0.02312753176797302, 0.08690088491646514, 0.03954536289036755, 0.05814397437197547, 0.01655100593193164, 0.046080740228776014, 0.09204776236607183, 0.018915235620713042, 0.007689453843575452, 0.009610967545379556, 0.059526479622769746, 0.059402197178813725, 0.06974064564752964, 0.1300282259621928, 0.0607367376646688, 0.3904789067324131, 25.150788637899584, 76.72770300219136, 52.490985470433394, 52.22959087740991, 48.651122354692035, 78.46926673766106, 15.229118966287183, 0.06931747399991559, 1.5603461885644545, 4.430191103489169, 2.3919461523332903, 1.2446463805052543, 1.0551685671652518, 63.87933623406195, 97.97656289992794, 96.23607389388546, 86.59782194322156, 77.63852442464521, 78.81201128805839, 84.13365564038678, 92.57336462697675, 95.54401874542238, 96.0030851056499, 90.22323731453189, 93.36937827448692, 91.9544695269677, 90.3738877081102, 89.75021516123127, 88.76007556915285, 85.04432801277407, 84.21151468830725, 85.1754685371153, 76.87711392679523, 72.67859320486747, 67.07860962037118, 62.701479850276826, 62.41088713369062, 65.86313770663354, 66.54010741941391, 63.875013782132065, 60.0102436157965, 61.46194811790221, 59.956558135248, 58.74650693708851, 58.528179968557055, 61.6269543863112, 66.59830754803073, 71.65362296565887, 73.8554846855902, 77.49998631015902, 75.95799276905676, 76.10907462335403, 75.58126480348649, 75.12509315244614, 77.16385487587222, 74.26806311453544, 74.23994756514027, 69.24287934457102, 62.203750687260786, 69.9220298951672, 71.85749207773517, 72.83492319045529, 69.47782147315242, 65.56731254823747, 61.390572747876575, 60.18090594199396, 66.83531284332275, 71.48889126316195, 71.47066008660101, 70.7868968286822, 67.34869618569651, 63.79046317069762, 71.18234234471475, 66.28673799576299, 60.629189706617794, 66.51665949052381, 66.17050247807657, 64.2176838074961, 65.52325256409185, 62.951805514674035, 62.05055859781081, 63.662362483239946, 64.52462104059035, 69.54731802786551, 68.79124979819022, 63.401144396874216, 60.71719984854422, 61.404516773839156, 62.9661064763223, 63.81441316296978, 64.26573284210698, 64.29414649163523, 64.34179544448853, 63.44248617849043, 63.85958317787417, 69.87664807227351, 65.91541505629017, 60.33145043157763, 71.05225301557972, 66.80041159352949, 67.40350738648446, 63.966616815136334, 62.86425821242794, 59.771728207988126, 59.750370902399865, 60.397259958328746, 59.327111859475416, 57.44937127636325, 55.83239770704701, 52.33889556700184, 55.56797112188032, 53.49066426677089, 62.992276530111994, 72.77100424612723, 72.34012403795796, 72.83471922720634, 72.20363340070172, 71.42832986770138, 62.68625713163807, 63.109437727159076, 60.50435243114349, 67.20432158439391, 67.68666328922396, 67.64485866792741, 67.0962759756273, 68.24358494051042, 70.84954492507443, 74.17374580137192, 77.62707894848239, 74.56988949929514, 79.05985016976634, 77.51403624011625, 81.65496087843373, 77.96113937131821, 76.7236315819525, 69.43472246969901, 73.86384717879757, 47.08514744235624, 0.29681730354505204, 0.7472755014896394, 1.7647890698525215, 5.427934210146628, 3.3880109748532696, 0.22423745944134651, 0.1946706330824283, 54.31584858125257, 77.19228421488117, 55.88795415816769, 39.425935206874726, 26.135852682975035, 43.24228763580323, 65.14475560957386, 8.529047831412285, 0.29477325838900387, 0.1354847638116729, 0.01994467009940455, 0.04136518560229771, 0.02540607069198403, 0.030104328968351888, 0.040744144935160875, 0.14114184815797115, 0.03291707823894197, 0.042879465636947466, 0.08507509821004446, 0.14261768590058052, 0.14880277336605136, 0.2239596146729685, 0.1674681992059754, 0.12014223668243616, 0.26014482782733056, 0.22853812383067226, 0.21466041043881448, 0.36614133525759945, 0.19614565877183793, 0.24609903474488568, 0.611388725378821, 27.393311608222227, 93.10077436508672, 56.014646714733495, 53.648794620267815, 80.11813702121859, 89.99690086610856, 25.787985517132668, 0.23348723568262594, 1.335271885318141, 5.559216920406588, 4.983915042492652, 6.574047832719742, 1.7524343392541333, 69.03287564554523, 103.89118333016674, 102.56135079168506, 91.1365141407136, 82.03753317556074, 83.67165534727036, 89.2351608891641, 98.54111748356974, 97.94091639980194, 98.44286995549356, 94.85208911280479, 97.16468718744095, 95.5620224245133, 95.99808016131001, 92.84331783171623, 93.12015871847831, 93.04160933340751, 86.73192777941304, 86.2831929422194, 81.71256480678436, 76.90562171320762, 69.37983282150762, 67.04341027044481, 65.19536202953708, 70.0943317720967, 70.51187592168009, 68.48106092022311, 65.26374855349141, 63.2287170040992, 63.87004806149391, 61.52500414079236, 62.66754350354595, 66.08082140645674, 69.40927413202101, 76.99524787164505, 78.93697800174837, 79.31790290340301, 81.41608069019934, 79.16236523658999, 81.26068422871252, 79.3487641119188, 79.46547031402588, 78.96263814741566, 76.84885717207386, 70.6107274947628, 65.7009437776381, 72.7591194645051, 76.90270346979942, 75.34065877237629, 73.54186765609249, 69.4574486824774, 68.15811649445565, 67.09108275751915, 71.42581170605075, 74.68884714188115, 73.6684896099952, 76.33697217510593, 70.76909711284023, 66.04275872630458, 74.71988093468451, 68.47136482115715, 64.74845501684374, 69.96123006266933, 67.6050466106784, 68.43058786084576, 67.838513928075, 65.42780953068888, 64.10111488834505, 65.53265056302472, 67.06350849520776, 76.50404945496591, 68.7268993931432, 66.0435510450794, 64.75870024773383, 63.708873948743275, 68.41315684779998, 68.89119963492118, 68.895475018409, 69.79252892155802, 69.74992413674632, 66.24965590815391, 69.32787710620512, 72.41965401557185, 65.28798095641598, 65.1991981075656, 75.11128640943959, 71.43040087915236, 70.78013466250512, 65.76099134260609, 67.04440655246859, 64.78122249726327, 64.22883902826618, 63.650724810938684, 64.05566638515842, 60.32634742798344, 59.625357120267815, 55.42475754214872, 59.03162010254399, 57.32541261180755, 66.99450615913638, 75.1350716621645, 75.19376600942304, 76.11359319379254, 75.84320068359375, 74.5257628348566, 65.55543168898552, 66.59129435016264, 64.94061193158551, 70.8628809836603, 70.61527744416269, 71.15643116735643, 69.7841428941296, 74.13479666556083, 74.65558544281991, 78.82589647846838, 82.56479386360415, 79.55476699336883, 80.78956834731564, 81.24472802685153, 85.75799542088663, 81.1045503616333, 79.28112676066738, 70.08186647968908, 76.50419850503245, 47.8525120981278, 0.31323738696594394, 3.3093473507512003, 9.131955350598982, 9.264625599307399, 3.8028734489794704, 0.23026608110916233, 0.3582440106378448, 63.32691746373331, 83.32432946851178, 64.75314617156982, 65.03170113409719, 26.75045867120066, 49.510188102722175, 77.02038241970924, 9.697204193761273, 0.5057652414806428, 0.25565740652382374, 0.22323609059376104, 0.1203302346590546, 0.174398307177809, 0.16278375541010212, 0.21095714141284266, 0.29175916205971475, 0.20908234040102652, 0.13946482040468725, 0.16961178982690459], [0.0034167265262259475, 0.058576718288203405, 0.06782518834957192, 0.08596558349146959, 0.03283288900650317, 0.014635921144227107, 0.023901198217044436, 0.052663358379035234, 0.04366184825137739, 0.008444903200612435, 0.07442973959710329, 0.13569864023837352, 29.937451116500366, 69.78968912555327, 41.76751175234395, 32.23577568607946, 41.95163957534298, 55.24914126242361, 5.321282023383725, 0.010012312390420948, 1.9182611184735454, 3.285506694547592, 1.1013083880947483, 1.599518409179103, 3.787389892724253, 72.97254347032117, 95.10447009917229, 91.71895473234116, 86.43226654298844, 78.90381043957126, 67.5810730841852, 74.00411898089995, 82.4217136444584, 84.61114145094349, 91.61679267883302, 96.56891053722751, 86.93148228429979, 86.29980025752899, 83.32046201152187, 84.32502808109408, 82.85602200415828, 85.2716136747791, 85.04956829932429, 79.3775386195029, 74.47561140983336, 67.1984144949144, 61.99396271859447, 59.336470634706565, 57.911504930065526, 59.92252765163299, 60.45583271211194, 59.72116101172663, 58.44899908188851, 56.19726442521619, 55.11851849094514, 55.40178029767929, 55.00297331040906, 60.867928689525975, 66.1269171007218, 67.6898874775056, 69.66254157404747, 71.96235272192186, 74.80942080097815, 69.7883084512526, 68.5000059681554, 70.70241681991085, 73.90089004270493, 69.39419654107863, 68.28406380068871, 65.11531429906046, 61.782805842738, 67.55348313239314, 68.92738742213096, 74.56480610755183, 63.78330092276297, 60.126118275427054, 55.042616705740656, 57.70528239588584, 66.5559773291311, 68.19135465929585, 65.70702345140519, 65.53083450563493, 66.24234461015271, 68.22612254850327, 71.5299427893854, 60.71214783576227, 60.813090032146825, 62.1651820213564, 66.79820722149265, 64.97785875874182, 63.465702687540364, 65.9925288538779, 68.98090424076204, 69.73548196977185, 65.87143744191816, 63.49730522401872, 63.93829730249221, 60.62108216747161, 55.956485809818396, 59.46893299779585, 59.22277681289181, 61.66084758697018, 60.37133701385991, 58.34117312585154, 58.0261597325725, 57.563939786726436, 64.75136149314143, 62.127821445465095, 52.80200196850685, 65.85886232314571, 64.89820718765259, 61.90492883805306, 58.18645523440454, 54.681201673323116, 54.26414782001127, 53.993625871596805, 52.19980047595117, 53.240244465489546, 51.639529120537546, 54.243021934263176, 50.49265161637337, 51.20487559226252, 52.57293162807342, 51.90719558346657, 58.853454282206876, 68.75324203122047, 69.76362889812839, 70.68440529607958, 67.58822748737951, 65.67489139495358, 56.55652215403896, 56.06325664827901, 55.66128038590955, 60.39331405393539, 63.31206344789075, 65.78616511437201, 64.52609977414532, 67.42240536597468, 65.57953465369441, 73.80088529279156, 70.72087549394178, 75.8733166417768, 71.77356120078795, 75.74751838561028, 72.35040064780944, 78.38037798481604, 70.55981512992614, 82.68182170006537, 63.14822604579311, 75.0528980070545, 13.086624280098947, 0.28410006014089434, 0.8816669352592961, 3.3754083994896185, 0.5984900110671597, 0.22586204081533418, 0.07128206817733665, 23.782499221063432, 81.27205910221224, 46.288859228934015, 46.42397703662996, 28.968019677746682, 38.53453343914401, 54.50066674140192, 8.913348913192749, 0.3073885508121983, 0.16229967977250778, 0.0819321152483744, 0.024114546043077306, 0.07724453815289083, 0.06985051797762995, 0.06805481554399576, 0.05319194372503027, 0.07825741364109902, 0.02015601460551543, 0.026191509997231827, 0.028416522357973362, 0.15581301413476467, 0.11005616821949521, 0.07272825065639711, 0.021759289159109036, 0.008262433505977594, 0.12660483949847762, 0.06333342715797406, 0.07551865697267555, 0.04047476926878576, 0.04077474631729626, 0.14265180745672795, 40.12279133642874, 77.75843912555327, 55.412782546012636, 31.129484907273326, 42.26846510364164, 65.76822419320384, 5.376529097557069, 0.0925864447509089, 2.2678739841907256, 5.302650765065224, 2.6059499334904457, 1.4178160818353778, 5.728757448734776, 81.45117021376088, 96.6454516687701, 95.17521396760019, 88.03255434959166, 81.95331988796111, 72.38012436897525, 78.00685851804673, 86.0813791521134, 91.49835278910976, 90.5709005171253, 96.76265993425923, 88.38868987175726, 90.47488874004733, 85.93036005573889, 87.45974709910732, 87.33948722962411, 87.21124141447007, 89.2447236276442, 83.07507068880143, 77.48683852534141, 70.33109388043805, 64.11417245864868, 64.06919071751257, 61.571272419345, 63.268415312613214, 63.54889223652502, 62.77594212562808, 60.77621190778671, 60.739420075570386, 59.3597302898284, 59.97344786121, 58.38346412104946, 63.838735780408314, 70.93745308537638, 71.83829599811186, 73.07217167269799, 74.16160998805877, 75.09026250531598, 73.4405920582433, 71.27964065920922, 74.0880027894051, 77.29667417464718, 73.71748001344743, 70.26864974729477, 67.49973097155171, 66.14183779685729, 69.28006341380458, 73.34565501059257, 76.15184414771296, 67.05765631891066, 65.65553057578303, 58.87863197634297, 62.69742411951866, 69.62523983370873, 72.43040915458434, 71.00610240813225, 66.35457146552302, 70.91953569842924, 70.50078345883277, 73.57988326780259, 63.61938507326188, 64.96584846127418, 64.26301856194773, 67.7492094039917, 68.91144690975067, 67.083112501329, 70.58428287506104, 71.86918074084868, 73.12095811290126, 69.2280214063583, 64.79923009872437, 65.64995688776817, 62.46839300278695, 58.94446111494496, 62.50623603020946, 61.3547654305735, 66.11011366690359, 61.93957513378513, 61.00853389309299, 62.265186771269775, 59.33676873483966, 67.06159437856367, 65.49056745344593, 60.427371994141616, 66.2896405496905, 68.04552878102949, 65.1334709505881, 60.03473097278226, 56.53351745297832, 55.09676894833965, 54.91996419045233, 54.36763563463765, 55.257178198906686, 55.314229073063025, 56.596608777200025, 53.437422014051876, 53.78474004807011, 56.68523865361368, 54.642715377192346, 60.592892093043176, 70.93527224756056, 70.95194232079291, 73.07980460505333, 70.1721437515751, 68.08169303401824, 59.568341547443026, 58.01537321459863, 58.95161944050943, 63.4499857502599, 67.26551840382238, 66.94563342678931, 66.68827103030297, 69.93786058118268, 68.82699043520036, 76.5530163241971, 73.82631794098886, 77.51172988645493, 74.96502122571393, 79.13137066748835, 74.51552544870685, 79.41741343467467, 72.56919045602122, 82.25316939815399, 67.35730186585458, 81.28102564042615, 21.510795777843846, 0.5022278458120362, 0.3307682672335256, 3.636108978140739, 4.194879291519042, 1.7218995454811281, 0.32328665256500244, 24.37249037527269, 86.38658661996165, 57.21963413300053, 46.33813988777899, 30.17628815866286, 46.915144074347715, 63.10108307869204, 12.587617404999273, 0.3942386517601629, 0.16478339811005902, 0.10531556251789294, 0.12906189797626388, 0.07851235238054106, 0.05248014079106431, 0.08285507499690979, 0.06703070154593838, 0.04058714670639846, 0.08481891840816506, 0.015734370568797233, 0.1729475051885651, 0.26897322506673876, 0.32181585568093485, 0.12931020239428168, 0.17705906843466146, 0.1735599465187519, 0.32678807274468485, 0.1972847242629336, 0.1269030239012453, 0.08745294319646013, 0.20297608338296416, 0.21145644687837173, 44.74488489089474, 89.30159799514279, 56.48959475178873, 42.3727923054849, 57.943170224466634, 80.61548571432792, 9.475907010416831, 0.2731026841267463, 5.223535087800795, 7.934963193631942, 6.55369024122915, 4.190605869216304, 7.555100273701453, 86.52470896320959, 101.88664036412393, 99.80801951500678, 92.99442322023454, 87.02306962782338, 77.8471003809283, 81.76708575217955, 90.85796310055642, 95.59453102850145, 94.09539330390193, 100.2633753130513, 91.82056765402518, 95.00463008880617, 93.4907913208008, 91.80901235149753, 91.40438064452141, 92.39686581396288, 93.94835933562248, 87.53221681041103, 81.08558177947998, 74.74094406250985, 69.74444850798577, 67.89835360742384, 63.807160700521166, 67.20416468958702, 68.43611055804838, 66.20449373798986, 66.51682423007104, 64.61902856826782, 63.64514327818348, 63.93790898784515, 61.20067904072424, 67.67597875287457, 74.80614954425444, 74.67357343243015, 76.49920140543293, 77.54446598791307, 80.10267503799932, 77.7371955687, 76.08720348727319, 79.13014688799458, 80.33513822863179, 75.37408521098476, 74.02409953455772, 71.5426669582244, 69.40745415226107, 73.27120057998165, 76.75722276010822, 80.5750068541496, 73.46974311336395, 70.28120917658653, 65.23234605789185, 68.1961242614254, 71.69621206098988, 75.02399798362487, 72.34673715406849, 71.95064836932768, 73.20281013365715, 71.74572021730485, 73.13389408972957, 66.07332183468726, 67.52640308872347, 66.31291589429303, 73.03982780825707, 69.97291088104248, 68.2230003418461, 72.98746416645666, 73.14202908546694, 76.23793232825496, 70.3286777004119, 68.80275018753545, 69.0175784018732, 63.721460834626235, 62.89706883891937, 65.3144726445598, 65.53170919418335, 69.99264824774959, 66.3266912583382, 64.32504300148257, 64.10940677888932, 63.53140238792666, 70.86084919591104, 70.39330267137098, 58.03237668929562, 70.80307268327283, 71.19570978226201, 67.5338791262719, 65.08066015858805, 59.40683403322774, 58.44947368867936, 59.57655106821368, 56.10202535506218, 60.43259659121114, 58.12302266397784, 62.2041037005763, 56.801470248929924, 57.70174049562024, 60.014581757207075, 56.64546189769622, 64.35999524208808, 75.40890801337459, 76.26213335221814, 76.9622136700538, 72.99551287005025, 70.39741331531157, 64.18468882960659, 60.799110704852694, 61.118254353923184, 67.27569303204938, 69.95124370821061, 70.86033928778865, 70.354902667384, 72.90258407592773, 71.66309941199519, 79.43173008580362, 76.44796740624213, 82.22050389935895, 77.8443233428463, 82.6107640420237, 79.15467739105225, 82.95857629468365, 75.28718902218726, 85.68033249147477, 70.61512839409613, 84.86783704450055, 19.518853425979614, 0.5512705577477333, 5.0135750251431626, 10.99527337858754, 3.40474380600837, 0.6879427884855579, 0.2559493013447331, 29.59407702569039, 94.32619340958135, 62.64459371566773, 66.30564381999355, 41.921468703977524, 53.010334737839244, 76.01352568595641, 15.420400211887976, 0.5978501131457667, 0.3332288803592805, 0.317194905252226, 0.29807537313430543, 0.1243010828752191, 0.17941835877155105, 0.25070588915578784, 0.1672098896796665, 0.13770218998674424, 0.1825570822843621, 0.1494496273657968], [0.020865892743571632, 0.06876615882520715, 0.08774277724085316, 0.08023492406092345, 0.02538236410116717, 0.008816202077263547, 0.02156534059453876, 0.02353921784238229, 0.03895213887576134, 0.04481536216072498, 0.10515915800727184, 0.007947473214083022, 38.88640142256214, 63.77443244380336, 35.53539506850704, 49.15781413355182, 48.12830178968368, 31.871538508322935, 1.4434373715231497, 0.27786134652072386, 2.4450447482447473, 4.892757688799213, 2.1219426922259794, 0.37711566734698515, 7.983636375396483, 82.97750565313524, 92.15857398125434, 93.1373308550927, 89.2634411781065, 83.2111926232615, 77.77334413220807, 66.2975323584772, 71.49899528872582, 82.73423241030785, 84.16706638951456, 87.97598592696652, 86.40950895124867, 82.6327528492097, 83.6618729560606, 81.91786166160338, 83.19300067040228, 78.41891919412922, 77.69296692263696, 74.93022980228548, 69.58834601986793, 61.85692687188426, 59.24966073805287, 58.07169845027309, 59.95212193458312, 58.83438371842908, 59.21725803805936, 57.48728882881903, 56.925679945176654, 54.37478219309161, 54.53547385431106, 56.32367457112959, 57.44188739407448, 63.78910995298817, 66.33219826606013, 69.39949174081126, 70.39658177283503, 75.46217380031463, 70.87249863532283, 69.01071425407164, 67.10475613993984, 69.2528735437701, 72.56709591034921, 66.82485580444336, 65.30220739303097, 62.00623581486364, 68.14203477674916, 70.45801393447384, 73.9211686964958, 69.04217950759396, 57.005657072990175, 60.29190509550033, 55.14032294673305, 62.67463907118767, 70.57855621460946, 67.00054660920175, 65.00338162145307, 67.89417236082016, 72.39734357403171, 60.970082898293775, 67.33524245600547, 66.98005614742156, 72.10089868114841, 63.480980319361535, 63.21398850410216, 67.85855723965552, 67.31951375161448, 63.205496572679095, 58.15368775398501, 57.23226416495539, 70.9359625847109, 67.37135179581182, 63.43890897689327, 60.99348375874182, 55.867467618757686, 58.271041147170536, 60.198584064360595, 60.377832458865264, 60.72691948183122, 57.577436662489376, 59.994169742830344, 55.22565410983179, 58.10640750392791, 63.6857751107985, 52.37909986126808, 62.027365622981904, 66.54880723645611, 59.438966089679354, 59.52923943919521, 52.22831610710391, 50.9729850676752, 50.79136756158645, 48.727996887699256, 50.99304406873642, 56.55790675070978, 53.08098054701283, 52.50267021117672, 50.97235748844763, 50.92706980243806, 51.227915594654704, 60.386908823444, 68.83828686129662, 68.72483622643256, 71.9360100838446, 67.60496816327496, 64.28257157725673, 54.34009275128765, 54.14233469193982, 53.981882295300885, 57.13625631024761, 65.1774367978496, 64.05235198236281, 67.71255877710158, 69.83751066269414, 71.78959585005238, 72.57758432818999, 75.2264315082181, 72.30082188883136, 73.44961350963962, 76.08587772615495, 72.41666516950055, 73.60391955221854, 73.79809256522887, 79.6563720703125, 75.44939471829322, 68.11539403853878, 59.617018161281464, 6.836369575992708, 0.4259815661897583, 4.517646230036213, 3.0110263391848537, 1.800225355452107, 0.6146297675947989, 7.502848909747216, 71.771741221028, 60.808936242134344, 46.56355065684165, 47.86184733913791, 33.34805004058346, 59.273163580125384, 11.48161982336352, 0.25695292249081597, 0.04933863254864851, 0.032869615261593176, 0.08713216686080541, 0.018724292036025755, 0.09620864635273334, 0.045551668416949055, 0.020339774200692773, 0.01549551488771554, 0.049808424476894646, 0.007704212048631763, 0.0851664005688602, 0.07410458123852169, 0.07615865448549872, 0.0448096739578872, 0.03858515977739327, 0.059707793482248826, 0.03457776533680097, 0.023347680539553686, 0.010346027951116764, 0.059610500315865206, 0.015370556371166341, 0.09755879971048526, 52.817291367438536, 67.32451085121401, 53.38366200847011, 38.06650054070258, 49.63845745209725, 40.99256907739947, 0.9578194457196421, 0.0874304048897278, 4.498614889960136, 4.740522657671283, 6.626468839183931, 0.5040203076937507, 10.612745208124961, 89.70989319585985, 96.38337458333662, 96.54012818490305, 89.40779224518808, 86.52859210968019, 78.18714634064706, 70.63637979568975, 75.03047773914953, 84.94670021918513, 86.70298068754136, 91.23203169914984, 87.87228630435082, 85.2241373062134, 86.78688803026753, 85.86430734203708, 84.8420984514298, 82.7132869535877, 80.38208115485408, 77.08486618534212, 72.759048861842, 65.28404289676298, 63.23936623911705, 59.337133515265684, 62.02047009621898, 64.19287089378604, 62.29399265781526, 60.019257222452474, 59.71976464794528, 57.53065063107399, 57.95858513924384, 59.79163031424246, 60.408713279231904, 66.11352612895351, 71.1135047481906, 72.90665549616661, 75.01146993329449, 77.02376350279778, 73.32599609128891, 71.75791878854075, 70.50705140636813, 73.54446426514657, 73.92124714389925, 70.92115171494024, 66.80602842761625, 65.77035011783724, 69.23621131527808, 72.83472707194667, 75.63538566712411, 70.66163201485911, 62.7059042838312, 66.41813739653557, 58.30171015954787, 65.65239267964517, 74.11429835904029, 70.26923810282062, 68.125027379682, 71.16320117827385, 74.12314722614904, 62.321119769927, 67.62859652119299, 70.86066876688312, 71.02647519880726, 66.08937217343238, 65.32223109276065, 69.24054945668867, 67.02134301585536, 63.63836934489589, 57.256265148039795, 54.60478997999623, 70.85904490563178, 70.97673170028195, 64.06821012496948, 63.86689839824554, 55.76798062170706, 63.55243805916079, 62.979046375520774, 63.81366399026687, 61.93780614483742, 61.23578817613664, 61.57496336967715, 55.857241999718454, 59.03063558763074, 67.3123436589395, 56.84272966077251, 65.60879945755005, 69.35829116452125, 63.89281349797403, 62.58420882686492, 56.60398283312398, 52.693779853082475, 53.46029727689682, 52.31263922106836, 52.91381697500906, 57.19287964605517, 54.27767999710576, 53.55242590750418, 54.6846886604063, 54.843332844395796, 53.841786999856275, 63.78664670451995, 72.23330220868512, 73.76218718867149, 72.3969199580531, 69.23404616694297, 66.4828408148981, 55.20208066509616, 56.19780571229997, 55.58204850842876, 60.257435306426025, 67.81192810304704, 68.88755183066093, 68.9958563158589, 74.3729708271642, 73.9170737420359, 76.00404923962009, 77.75794490691155, 74.51366624524518, 74.26583520827755, 78.28978692331623, 75.23567261234408, 74.06788887516146, 76.71058577875938, 78.82699474211663, 81.26132749742078, 73.45102556290166, 69.72983375672372, 10.688781334507851, 1.1437054098613801, 1.6096031906143313, 3.3316325420333497, 3.624710080123717, 0.8311203927282365, 6.091575218785194, 76.3112335820352, 71.84284594751173, 48.73271549901655, 38.885691473560954, 40.2942616708817, 67.7814434420678, 14.406692078036649, 0.1817161782133964, 0.09541006863958414, 0.05133480103986879, 0.06646132967885464, 0.01969296425100296, 0.02570013737215871, 0.06543894703950613, 0.01411902534234668, 0.048841292098645246, 0.04776495771722929, 0.04011696024287132, 0.1343051875911413, 0.15763251892020627, 0.11496997107901882, 0.12757755665769502, 0.14471629183859597, 0.15456825915363528, 0.15272984731822245, 0.2179394965811122, 0.0870300779840158, 0.19438872804805157, 0.17931426274439982, 0.21961062545737914, 59.751100463251916, 80.89226384316721, 50.776737120843705, 66.49982467774423, 68.93933496167584, 50.82404090512184, 2.582159777802806, 0.36404023187295087, 6.753205522414177, 10.825759326258014, 11.700805790962713, 1.0979475297274128, 11.364946961402895, 92.23372659375592, 99.18268388317478, 101.19834284628593, 96.65618327356155, 88.5654789401639, 84.86072186500796, 74.20638776594593, 79.74820260078677, 89.42933390217443, 94.02739509459465, 96.80864580215948, 93.68331693833875, 89.77453385629963, 89.96298020885837, 88.95186378109841, 88.8117253395819, 87.51446416301113, 84.73203674439462, 79.81944068785637, 77.51829593412339, 69.75856119586577, 67.16404668746456, 63.68919933995893, 66.34562846153014, 68.38154254421111, 68.16558468726375, 63.185245375479425, 63.43104070232761, 58.740337048807454, 61.963662409013324, 63.911884061751834, 65.48697456236809, 69.2415222044914, 73.80443896016767, 75.37181808102515, 77.46064493733068, 80.77453782481533, 78.83188201535133, 73.741712416372, 72.26006061800065, 79.0656082091793, 75.98775571392429, 72.92716949216782, 70.77535721563524, 68.7151244378859, 72.55925901474492, 76.41675318441084, 78.11784590444258, 74.20077877659952, 66.65629586865826, 70.47469185244653, 63.27711120728524, 68.70191389514555, 77.65521803209859, 72.78881180670955, 71.10012946590301, 74.44943351130333, 77.49296526755057, 64.64976818330827, 69.1920768060992, 72.76951374546175, 74.74266990538567, 68.30595062625024, 64.5756628436427, 71.54553028845018, 69.29324257758357, 68.15581798553467, 62.34589738230552, 59.73214364820912, 73.89240987839239, 73.12021286256852, 67.85803948679279, 65.58835998658212, 60.15176273161366, 66.66843952671175, 65.76842031171246, 67.81861182182067, 65.04053431172525, 65.6138946164039, 67.3218357947565, 59.611471929857814, 62.63183816786736, 71.20983031488234, 57.886437062294256, 64.29571936207434, 74.9950195127918, 65.71086737417406, 64.62399821127615, 58.1233835220337, 56.37158632278443, 57.36138466865786, 54.45829729880057, 56.284203760085575, 62.17369356463033, 58.677708564266084, 55.97699980581961, 57.72959716858403, 57.38377747997161, 57.10059804301108, 67.05997836205268, 74.61207066812824, 75.45139512708111, 75.19081638705346, 72.10875911097374, 71.74885026870236, 61.582800265281435, 58.75537149367794, 60.170150802981475, 64.438980010248, 72.52546387334024, 71.44105403654038, 72.92584373104957, 76.86144013558665, 79.41139651883033, 81.56771952106108, 80.38929831597113, 78.14179589671474, 78.69099047876175, 82.92662466725996, 78.839295294977, 76.25990544596027, 78.81642003213206, 82.33223653608754, 83.26749432471492, 75.94745728277391, 74.62648145614132, 8.81867858671373, 2.609125582441207, 13.744754848941682, 8.413043733566038, 5.145955018458828, 0.7475699244006988, 9.212761079111408, 87.92986669848042, 74.62631671659409, 63.1483123379369, 65.83925831702449, 45.70774047605453, 78.50927491341868, 16.80614613717602, 0.44866595056749164, 0.31991077887435115, 0.15837963850748155, 0.16766975693885358, 0.1642125093888852, 0.14304989738570106, 0.1719367900683034, 0.18131791974507994, 0.12607345793155894, 0.15938139039902918, 0.12379368752120964], [0.08192241657525301, 0.016529040275922707, 0.0465485020240228, 0.025078667695784283, 0.00882955403217385, 0.016656099788604245, 0.11640645488495789, 0.01848309308350567, 0.11131497325315592, 0.09176400339891834, 0.16759576816712657, 2.1165472269058228, 59.861848585067264, 55.615423956225, 20.645197322291715, 48.49898146044824, 59.44861512030325, 20.491450217462358, 0.13667170979803608, 0.062371622921238025, 1.0142232513716145, 6.212763219110428, 0.7453444083371471, 0.35035863698970887, 20.52157598157083, 92.25499368483021, 92.83493180428782, 93.15932750701906, 89.54127050215199, 86.81060268032937, 85.86262072286299, 69.71263808588829, 65.09323919973066, 66.9010203884494, 81.15412127587103, 81.88054423178397, 84.2494910763156, 80.64930438995361, 78.05926138354887, 78.1928494668776, 76.58061412072952, 73.5682495178715, 74.22069657233455, 68.11389569313296, 62.86370908060382, 60.134331718567886, 60.021587110334835, 59.518853002978915, 58.079821678899954, 57.08159023715604, 55.96848434017551, 57.43352882323727, 54.60921049118043, 53.247963689988666, 52.16608770432011, 55.8626901718878, 56.79237035013015, 66.90648032772926, 71.2220210413779, 69.56811443451913, 71.02840500493204, 71.39650375612321, 72.50884871329032, 70.08437679659936, 67.3912460573258, 67.2114210744058, 71.63398758057626, 63.907659669076246, 63.356715709932395, 65.23599778452228, 66.96903428723736, 74.35812857843216, 70.90054358205488, 64.24553263571956, 61.89315388279577, 57.08742280160227, 53.931797550570586, 65.38748756531747, 68.31628214928412, 69.23479926201605, 66.4923329507151, 71.48853824984643, 65.08493946444604, 58.54860767241448, 67.36797071272328, 67.16741208107241, 63.29800959556334, 64.25646820375997, 65.30366651473507, 63.47404949126705, 62.670865751081905, 62.91908118032641, 60.936868267674605, 54.252243426538286, 51.47701355718797, 66.87424628965317, 69.817977259236, 63.453162870099476, 54.39050697511243, 58.27249634650446, 59.19564185603973, 58.988607391234375, 59.84010688720211, 54.852338606311434, 59.95511470302459, 55.933720373338275, 52.89294604332217, 62.356232827709576, 57.59479707287204, 57.08568911398611, 72.35851210932579, 64.21131780070644, 63.600981312413374, 62.68848896026612, 56.98193457818801, 52.5998822335274, 51.20648768640334, 47.23438186030234, 54.55746266149706, 50.710704018992764, 51.55264862122075, 49.02266886926467, 48.39059068310646, 50.81678059793288, 59.323703319795676, 68.47382806962537, 69.61035051653462, 67.20334099185082, 68.54811776068904, 62.112226101659964, 52.71161094788582, 54.857476911237164, 54.938144376201016, 58.23919934611167, 64.61682419623098, 67.96552811899494, 69.20774275256743, 70.85927240310177, 73.47130421669253, 74.99535683662661, 74.10934832788284, 70.79121143587174, 72.06427943321967, 72.77673875131916, 73.93143746160692, 72.20231548432382, 79.38018229699905, 76.6067841745192, 83.54341737685665, 68.92020948471563, 71.53590479204732, 34.30990542134931, 1.6796459353739217, 2.766673463967539, 8.57280775423973, 6.688143207180885, 0.09684970872777124, 1.0558846448698351, 52.18768035211871, 75.56508894889586, 44.4709740146514, 53.80124930412539, 36.46902115114274, 63.52857043666225, 12.546897319055374, 0.2091075906590108, 0.1099290589110986, 0.05475356416296094, 0.009458700867159473, 0.03491247298135873, 0.011895097953627908, 0.06272518015917271, 0.12634109074790634, 0.028637423810939637, 0.009086147521532351, 0.043428528513158524, 0.0530870701186359, 0.07660369028247173, 0.03797227794665002, 0.04828918785337479, 0.04459972373179851, 0.034497421865742055, 0.06288775550802389, 0.023321733141558307, 0.13416278716777602, 0.0775093058004014, 0.4948305314587009, 4.184250648944609, 70.55166444470807, 65.7481534250321, 35.20881852796001, 43.026129737977065, 66.78112922176238, 22.853893772248302, 0.010261949801426983, 0.6284175116208293, 2.4915912699314857, 8.525073489835187, 4.394744153945677, 0.12786002093625645, 27.300618156310055, 94.6621601043209, 94.62187736265122, 96.77440351055515, 91.97775271631058, 90.91811656951906, 87.43881733186784, 76.85135179950346, 68.72256125173261, 71.2346746075538, 83.52287984663441, 85.48183702653455, 86.93100375513878, 82.26492866393059, 80.94454903756419, 82.16181739684075, 79.35121167090632, 77.67027208881994, 77.63439809122394, 70.88207706328362, 66.36629935233825, 61.95417027319632, 63.64282515741164, 62.31749942225795, 62.1678884567753, 61.41011791844522, 60.99943791666339, 59.27261837067143, 57.73808517763692, 56.93362274477559, 56.30072870562154, 58.92228403399068, 59.5480275923206, 68.91953483704599, 71.42358379979288, 74.91116708324802, 73.90915055428782, 75.82032542074882, 77.11947717974263, 73.5771454534223, 71.98703227504608, 72.24759532559302, 74.58528872459166, 66.79775222655266, 67.69526896938201, 67.67974422823998, 71.0741319964009, 75.27341365814209, 73.39979940845122, 68.62101108797135, 66.17852764744913, 62.21130517221267, 59.45600094333772, 67.00462587418096, 70.2613619835146, 70.65135540500765, 69.52624705529982, 72.41426467895508, 66.52763428226595, 60.4973941464578, 70.01790046691895, 68.4652223894673, 66.73269579487463, 67.93227426467404, 67.32179657105478, 68.72191013828402, 66.46187966869724, 64.38178008602512, 66.70225035759711, 58.04759548556421, 51.54963624092841, 64.43255516790575, 71.11265751623338, 66.34032541705717, 54.13079507889287, 61.1846169348686, 61.80697941010999, 61.358895686364946, 63.22353555310158, 60.13995247502481, 62.70623768529585, 57.145356209047385, 54.72412417011877, 65.44897856250887, 63.18352345497378, 58.45044251411193, 71.8699259911814, 66.9734351865707, 66.71677881671538, 66.62472078877111, 60.70520524055728, 58.12397187755954, 55.27628798638621, 51.331352418468846, 56.49934968640728, 53.71068177684661, 53.78838785233037, 51.38390041166737, 51.8729454471219, 52.52144267482143, 60.722753924708215, 71.521329264487, 69.86293546615109, 71.07314355911748, 69.23530917013846, 65.13309048068139, 54.25702479577834, 56.34938178523895, 58.871175550645404, 61.74432739134758, 67.49241967355051, 72.20122506541591, 71.81611891715758, 74.38712273874592, 74.79672016636019, 76.99751500160464, 74.25053796460553, 73.03603879867062, 74.98986551838537, 77.70952716950448, 74.81259792081772, 75.18935726534936, 79.75661216243621, 81.26443401459726, 83.47214006608533, 73.97105340034732, 73.97775280860164, 46.03094770062355, 2.4555370884556926, 0.37226142782357435, 4.413055248798863, 4.879206390150132, 0.12993318509430657, 0.3911033603212526, 52.52689869173112, 83.38956632921773, 52.067157683833955, 43.88761166603335, 43.81528708242601, 68.80795909512427, 16.665382077617032, 0.3972943926290159, 0.03304236042763918, 0.07417597297218538, 0.02321363430500271, 0.04374864601319836, 0.05897529085256881, 0.016589800624417204, 0.01259480627448929, 0.02172394760794217, 0.08750334412099854, 0.07319486715019712, 0.2220360751474096, 0.1092807110399008, 0.16418941949884738, 0.14725671600430243, 0.10237380021041441, 0.1713700229001622, 0.3443825995970157, 0.21547094678446171, 0.17402411919207345, 0.1542985502390131, 0.49118156274480207, 4.432001767619964, 82.32997725086828, 72.17051290696668, 31.478517017056866, 63.22395132433984, 81.4327899871334, 32.00592871635191, 0.2546382184711195, 0.5740370973944664, 4.460552700104253, 13.873496843922524, 7.308686683254858, 0.8541743072771257, 28.157907070652133, 100.25566393329252, 98.97523756950133, 102.2454744769681, 96.78905748551892, 95.65299003354966, 94.25322163489558, 81.32887855652841, 71.26380212845342, 75.08888967575567, 87.79307011635073, 89.67956542968751, 91.60430385220437, 87.74454255257884, 86.71946248700543, 87.04153614659464, 84.85066490788614, 82.27759791958718, 82.13652595396965, 75.7563280290173, 70.3675562335599, 66.01740452551073, 66.99388642464915, 64.86763231215939, 63.7478191621842, 63.60052631747339, 63.240727301566835, 63.32709789276124, 60.248755101234686, 61.03942255819998, 59.184878872286895, 62.398829767780924, 60.916915170608036, 71.81232206283077, 76.62516440114668, 76.31880375646776, 75.98909716452323, 79.92143015707694, 81.74822699639105, 76.52632067280432, 75.35046469780707, 77.8193849132907, 78.93823316020351, 71.48125048606627, 71.3729146219069, 70.47427608120826, 72.44827162834906, 78.08427041576755, 74.1373069824711, 70.49731608360045, 69.3195773709205, 67.84859441941785, 63.45308442269603, 69.69328511145808, 74.80856572428058, 76.2522646688646, 72.80713712015461, 77.17355881967853, 71.65866713370048, 62.55588539185063, 73.34065791099303, 71.75840516244212, 69.93459716919931, 73.93387717585411, 71.86922780929073, 71.88234421514696, 69.79649051543205, 66.97567878230926, 66.7861577003233, 58.28241209830008, 51.079548020516675, 69.23870594270768, 74.92957868883687, 69.49754315037882, 56.831637197925204, 66.65314228303971, 65.91642702779463, 66.35323785966443, 67.16954585044616, 63.11472115978118, 66.68285815946518, 60.02303838729859, 58.375995928241366, 68.52510129251789, 65.46815895265149, 59.813748559644154, 72.83755902321109, 69.50466617461174, 70.84578729444935, 68.97009418856713, 62.106624957053896, 60.54139137268067, 57.123783173099646, 54.87559041669292, 60.93872747113628, 57.42564485919092, 57.104834202797186, 54.59751790569675, 53.67644340761247, 57.07678141132478, 64.24853717127155, 73.92786810475012, 72.8294240274737, 71.55022144317627, 72.53465006428381, 68.82157756436256, 58.137013758382494, 59.64068182053105, 60.193473216026064, 64.90098422573459, 70.91257741374355, 75.91407006786716, 75.73854400265601, 76.86585672440069, 78.66951157969814, 80.75502011083788, 79.49331129750898, 76.16578425130537, 78.00892168475737, 79.26410367411953, 77.91192147039598, 76.37033585579165, 82.35140908148982, 83.1410292656191, 86.85793784356888, 77.60543530987155, 79.76432354219499, 48.78865242004395, 3.0539387849069413, 6.481033727045983, 19.23404424421249, 14.646177291870119, 0.28935861022722337, 1.587802412048463, 63.43120936424502, 89.72338614925262, 61.53593970883278, 71.49049943493259, 48.722183935103885, 80.45116978306925, 19.674391092792636, 0.5406244483686263, 0.3530667578020404, 0.2127869270982281, 0.13481022339434395, 0.18540397226329774, 0.15522986800680239, 0.12025883526451166, 0.2646440928501468, 0.08556767742359832, 0.1687390318200473, 0.12095435883008665], [0.024176470845216708, 0.04967500643444158, 0.066401865934172, 0.03976431081912691, 0.028576104218260418, 0.01563388185815946, 0.06946998678388135, 0.07945750569624287, 0.054790807527399836, 0.0709930538470226, 0.4207105748355389, 11.355763712236959, 71.7074300396827, 40.552604659911125, 51.88327304778561, 61.233685785724276, 48.304737844774806, 13.460126096202483, 0.259632253718953, 0.15296793212333035, 4.052380563751344, 3.1659675605835456, 2.715119791607703, 0.40262768225323775, 42.629209410759714, 95.50856836380498, 90.47775991501348, 91.19314532126151, 87.57788104395713, 87.77429765270603, 87.68632673448133, 79.3651282402777, 67.04376328376033, 64.66009970634215, 66.31355131826093, 73.42090175997826, 76.8320066698136, 74.62486543963033, 75.53741270496, 75.8416788039669, 72.97154718829741, 67.70666737710276, 62.53686581888507, 62.01135450793851, 61.0845886507342, 59.21419466695478, 59.33712174815517, 59.23721113512593, 58.40868888362762, 57.073419940087106, 54.60348383072884, 54.85600210005238, 55.108171278430575, 53.3120003054219, 53.566695490191066, 54.82717660165603, 62.63391702405868, 68.4349730706984, 69.25955726254371, 72.70373559767201, 72.01278655759751, 74.28770634435838, 63.88993055589738, 71.43177370871268, 63.565872177000976, 68.4987037412582, 68.49675824565273, 65.07476091384888, 65.84518109598469, 68.00539508942636, 70.30386478670182, 71.37962971964191, 71.34991384321644, 66.6961314601283, 63.30157895242015, 55.4372424464072, 60.63877205694876, 68.45638921183925, 67.98359455600863, 65.84367490583851, 70.69885530779439, 64.72880001991027, 53.40831802737329, 57.2751356709388, 65.85967817614156, 65.19013351009738, 64.57275244497484, 65.25609600928523, 61.94291699317194, 66.65124385587632, 65.58323737113707, 64.14599464785668, 68.19996818419426, 67.3973100416122, 59.629832544634425, 54.31817846913492, 64.38845596005841, 66.50963060317501, 55.592132922141786, 56.9704734125445, 56.3247493005568, 62.495225937135764, 58.3322536560797, 56.87268872414866, 61.012977938498224, 57.21660214085733, 51.43659745493243, 55.028739360071, 64.04079667983517, 57.088983904930856, 58.84619005264775, 66.03507872550719, 66.60061390169206, 63.44281173521473, 60.506905894125666, 57.35964313630135, 54.58073800609958, 50.447501213319846, 48.54457509133124, 49.32385983005647, 48.813269215245406, 50.58459197321246, 49.47680481018559, 50.487297581088164, 55.71155340440812, 70.29136027059248, 65.86338089358422, 70.12777390018587, 65.29226810701432, 58.13897886583882, 50.091942279569565, 54.120083085952274, 53.09739566618397, 60.55115022966939, 66.44936730784755, 72.26458703317951, 70.08800106663858, 74.33516702344342, 75.16550140996134, 70.75322720312303, 68.96718378989928, 73.45849375570975, 73.64982697271532, 75.7524605720274, 74.27587647591868, 77.2677113932948, 76.51707172393799, 80.16333057034402, 79.22556246480634, 80.86205374810004, 66.52328829611501, 64.34891846872145, 6.512922106250641, 0.5257267348708645, 2.0687720227626065, 2.791413078385015, 1.0883677534518705, 0.23658189381803238, 26.75279248145319, 83.40363194865566, 49.13958295699089, 49.67469623011928, 34.01692790369834, 56.942687342243815, 18.3254526892016, 0.2095135559718455, 0.09004362272999941, 0.06199797885792871, 0.09191280831733058, 0.046688205817894596, 0.04779402692351611, 0.030346843676881927, 0.021116043433486935, 0.03900946906557487, 0.041576495634451996, 0.06504159255494034, 0.04962338359966394, 0.0648692534154942, 0.04199721197026872, 0.08566973565687096, 0.022034849070252913, 0.02658098335227659, 0.01976671362025363, 0.010044691096540662, 0.0431215685732182, 0.10276275837133009, 0.6640465449421638, 18.341285336402155, 79.64950792251095, 50.70769948344077, 44.10347538609659, 48.158923733618956, 63.016501088296216, 14.794450729124009, 0.10068971678734788, 1.5586927869627554, 5.128737284291176, 3.666996417507049, 0.6670364328930456, 0.9633118058404616, 50.39021891932334, 98.29297265698834, 92.13805998525312, 93.83590498278218, 91.31393863308816, 91.25038839155629, 90.3780689547139, 81.86525483285227, 70.96789067791354, 67.26294532898935, 69.50990646116196, 76.0875015874063, 79.48827497420773, 77.93880539555704, 76.81150836329307, 76.9624960807062, 74.88316136021768, 71.46884010684106, 66.68561166332614, 64.62651637292677, 64.6565499613362, 62.47211140971031, 62.0058161212552, 61.48767494386243, 61.064341375904704, 60.62621655002717, 58.90296636089202, 58.09054936132124, 58.22861679138676, 55.554823337062714, 57.82752698467624, 57.14028850678475, 66.72515699940344, 70.3498741888231, 72.75265539846113, 75.55294529084237, 75.31737558303341, 75.45215606689453, 68.06452089740385, 75.03684766830938, 68.17248805876702, 71.87470343805128, 70.68028680739864, 66.889402327999, 70.43110647509175, 71.504667035995, 73.86174478838521, 72.17861652374268, 74.05588642243417, 69.75698440305649, 67.51893489591538, 58.34109860081827, 63.53053554411858, 70.55619085988691, 71.34716033935547, 67.90694359810122, 73.58534320708245, 63.51539911762361, 54.403211532100556, 60.50522711969192, 68.34423295913204, 69.72846092716341, 68.3789380904167, 66.54222549930697, 64.65547130953881, 67.92471193498181, 67.714935733426, 66.88737838499009, 72.12796303533739, 68.9273246642082, 64.41844640239593, 55.04378949442218, 64.97331665408227, 68.27684663957166, 55.77762572996078, 62.00380002298663, 60.01109869249406, 64.8688639363935, 61.66655071320073, 60.64383975921139, 64.00067083297238, 61.76435109107726, 54.87099732122114, 56.21662916675691, 65.62271210455125, 60.9304787266639, 60.86294335703696, 65.96617837106028, 68.58641578305152, 65.72457605792631, 63.414554980493364, 58.45909918508222, 57.025268923851755, 54.593991694911836, 50.307856990445046, 52.07038579448577, 52.01100895481726, 51.13189989520658, 51.91598561502273, 51.786967092944735, 57.875834895718484, 72.17028540949669, 69.59397069869503, 70.00501940327307, 68.05722528888334, 60.3617036727167, 51.663153556085405, 56.182049551317775, 55.791883545537154, 61.73803590959119, 70.45270304526053, 74.05834182616204, 73.13145437548238, 76.70952673881285, 76.53789166481265, 71.97215864735266, 69.20545208838679, 76.40912809679585, 75.23652768904164, 75.88616632646131, 75.83235925243747, 80.25206242838215, 76.29720718629899, 83.76913409079276, 80.04571437835693, 84.03224668195172, 71.1738778698829, 73.80852606988722, 9.916235227738659, 0.27688734233379364, 0.677791755766638, 4.32264167454935, 0.8875119409734203, 0.31325543599744, 26.813999106807096, 89.01825381863503, 59.846625866428504, 44.5309195979949, 40.0708277763859, 68.60619237346035, 24.239151362449896, 0.15577336142380394, 0.11078941395446179, 0.15705067514171525, 0.129926857208052, 0.029775679164055376, 0.03907113914347945, 0.04128821291810563, 0.03947807355753837, 0.04754294926721243, 0.04398578469971976, 0.015279217623174192, 0.12823633864642153, 0.12888067221689609, 0.2169456966822186, 0.18465631641447547, 0.13877785404122647, 0.12371967576684491, 0.3638035107043482, 0.10879248320575684, 0.2395056683810488, 0.20359555740029583, 0.8690082822595874, 19.706725151308124, 92.73673918939407, 55.11110521131947, 63.8867965821297, 75.10872117934689, 71.4879342048399, 21.271986192272557, 0.5220503095657595, 2.288598072144293, 10.09193289664484, 10.616866638583522, 6.004325526375925, 1.0861306541389035, 55.05157147684405, 101.21023547264838, 100.12125999696794, 98.87247147098665, 95.69589291849445, 96.2857154107863, 94.62417587157219, 85.93552189488565, 74.45357553420529, 71.5631103515625, 74.78292126809397, 81.27880557890862, 83.75724930917063, 80.6749802251016, 80.76813651669411, 82.58653163909912, 78.53110682579779, 74.38698937816005, 70.9194415615451, 68.84741813905778, 67.28260424829298, 66.4002670780305, 66.31743446473153, 64.89268449044997, 63.45350019393429, 65.35745397690805, 61.86810954924553, 60.84432778819915, 61.109782034350985, 59.90950930503107, 61.45872392962056, 60.71100642604213, 69.27456425082299, 73.15862855603619, 74.92651924010246, 80.4284357255505, 78.533797571736, 77.73674057376, 70.65929428223642, 75.07396113487982, 69.9703456509498, 74.0941216868739, 73.72240651038386, 70.59615981194281, 73.25283604283487, 74.76197581137382, 74.27810438217656, 76.97354147511145, 76.76868392575172, 73.20980764204457, 72.01117054108651, 64.7226732777011, 67.19631210450204, 74.67427945906117, 75.21966934204102, 70.9520286129367, 77.36448411018618, 68.09043991950251, 55.185618477482954, 59.69372011000111, 71.59773703544371, 74.05272499207528, 70.49313483699676, 68.30159679535898, 66.3686998428837, 72.43186827628844, 70.52266243965396, 69.4796649871334, 76.0429983754312, 71.97394724815123, 62.41661771651238, 54.99323014290103, 68.47877025604248, 70.9966024275749, 57.77182540585918, 63.69681658283357, 67.18128158200172, 68.35766315460205, 66.94898313091647, 63.177028009968424, 66.29199397179389, 64.4954699854697, 58.06250049221901, 60.51502912275253, 68.4364321924025, 65.64319079922092, 62.26875220575641, 68.06286565719113, 69.43133354187012, 69.56645134956607, 65.0342506747092, 61.89787249411307, 61.003866272587935, 57.39865110766504, 53.186621742863814, 55.252400752036806, 55.875920326479026, 54.60885355549475, 56.2216890242792, 54.586774533794774, 59.24454204497799, 76.38798652156707, 72.63069322032314, 74.27149911080637, 70.66518568223523, 63.151230581345104, 53.88547435883553, 58.30878219296856, 57.80735031250985, 66.9439075839135, 73.63776960680562, 78.45622877920829, 75.2543430943643, 80.1621852382537, 79.5219445997669, 76.12930620870283, 72.58320900701708, 78.82852446648383, 78.31630214568108, 80.37443253301805, 79.10077618014428, 83.49991829164567, 80.2074101663405, 89.12698191981163, 84.7560965630316, 86.2231492996216, 76.84774321894493, 81.47216273892312, 9.891926338595729, 1.4325296277961423, 6.991193371434366, 11.759128493647422, 2.9288041447439506, 0.2206470658101382, 33.950027958039314, 98.7784287237352, 64.20969786182528, 68.38945788721885, 44.79768783815446, 75.80268259971373, 28.73873752932395, 0.49080332981482633, 0.3583485663177506, 0.23497019804293112, 0.2573989542020906, 0.11155288185804121, 0.13254462561059382, 0.14869895313055287, 0.18610701115140993, 0.15960798388527286, 0.1743556973674605, 0.17490625411512392], [0.08752471797408597, 0.05052687322360374, 0.06535159003350043, 0.0588998886486215, 0.04061076519710403, 0.03891203034248564, 0.08582938071941176, 0.03324381473864759, 0.047687816493693864, 0.0439625071181405, 0.2607350832512302, 29.927211769165535, 63.94357681274415, 25.599633301458052, 54.940034958624075, 49.75071960879911, 47.98921454337336, 5.62278236112287, 0.43732919760288735, 1.627961353909585, 3.1030049391331214, 7.08494782447815, 1.991399839039772, 5.407721746352411, 76.00363346838182, 96.78315824077976, 88.53312723098263, 89.46323886994394, 85.77836821156164, 88.86765049349877, 87.58627491612589, 86.18833434197211, 75.5778915651383, 65.34581238223662, 62.65608233790245, 65.0668808721727, 64.88195680802869, 67.9885995003485, 62.676894434036754, 64.28083004490023, 63.49130792002525, 61.60604423092258, 61.75055611518122, 58.61816698505033, 60.379938771647794, 57.730118843816946, 59.42542606784452, 60.2399689920487, 56.917764602168916, 55.63036818658152, 56.25963011095601, 53.841033904783195, 51.39711095440773, 52.92934956089143, 52.26434307713663, 55.8036506560541, 68.91043493824621, 69.12887957788283, 71.75323547855501, 72.00761687371039, 71.50014062081614, 66.47457245857485, 76.46201733619937, 70.88985904570549, 62.74985836398218, 71.61039844635995, 66.97070521693077, 68.7716850157707, 67.59363251347696, 69.6430552390314, 69.06884378002536, 69.3167846433578, 68.08756874453637, 68.62197599103375, 64.69027842244795, 55.50147518034905, 59.040366988028254, 67.04375543901998, 67.01607919508412, 70.77946785957583, 66.92477426221295, 54.95177461254982, 65.82012499532392, 70.34748938775832, 71.07306511171403, 71.72533173714915, 66.27237427619197, 61.551601732930834, 63.377731769315666, 61.625495264607096, 63.84681586296328, 64.66868185227918, 61.2190749568324, 63.89758702247374, 65.07429415179838, 66.1608220684913, 57.711169873514486, 61.56270204051849, 58.877043416423184, 54.650395377989746, 53.982611856152936, 59.69567737271709, 52.417939170714355, 60.0707697099255, 62.547087515554125, 60.82849710218368, 53.59412462480607, 51.26253051142539, 60.55028338586131, 66.55367882021012, 58.457440022499334, 49.59589581335745, 58.919342256361446, 70.79555742202267, 63.206155530868045, 59.947211127127375, 58.06441853123327, 53.58414219271753, 49.22986415124709, 48.38638590228174, 48.730656254676084, 49.08476783383278, 49.51395750045777, 51.45039635319864, 50.01234562166276, 61.57144500363258, 66.92938696953559, 65.4590472867412, 62.23832245795958, 56.991391412673465, 52.63691333032424, 54.78699191924065, 53.36188500927341, 64.98422084316131, 68.34723749468404, 75.43405040617913, 71.2340078046245, 71.61938067405455, 69.77696495671427, 71.4968458298714, 71.87698625749158, 77.68470641105407, 73.873394227797, 75.65314615926435, 70.37984109693959, 76.38274623501685, 74.86644421854328, 82.11569816835465, 74.16313186768564, 82.6346512763731, 71.89191479836741, 76.24749506673506, 27.839504749544208, 0.6882505106829828, 1.6328730193837997, 3.0943338044228095, 0.15432812123289033, 0.20538564440944504, 9.059988683269872, 78.61089567984305, 57.49101900285291, 45.48338090219806, 29.881473010586156, 54.657981241903, 32.10913019795572, 0.3162706048498231, 0.0934935694620494, 0.06523453179867038, 0.07439672886844605, 0.02196161297991151, 0.044260967312560934, 0.014421134030506497, 0.012371750199235977, 0.022406409374408187, 0.029355395667915864, 0.00014687587310852965, 0.04317141408401151, 0.06281840922911802, 0.023169827482272542, 0.02552207364069839, 0.008332301682281879, 0.05179770966811527, 0.07979964056322653, 0.04335079740192141, 0.08148431387399474, 0.09645334249662776, 0.1288011522903558, 40.97048613332933, 69.93091798597767, 41.83192099294355, 41.96203777866979, 43.495209909254505, 60.19711317554597, 3.8268528590279245, 0.3421090038553361, 1.2863314920856108, 5.79188064221413, 2.7946100552235884, 0.9480016918913011, 7.924198248694021, 83.13901316735053, 95.02462633194463, 94.23256643356817, 91.26042965919741, 90.72185685557704, 90.9851106520622, 91.78432495363298, 88.87058442638767, 79.94893381672522, 68.02692105693203, 66.40585253315588, 66.56944674830284, 68.56808262486612, 69.11972476590064, 65.84950354791457, 68.18065443346578, 66.91072433225571, 66.26575331534109, 64.55185013432657, 62.357221264992994, 63.73043129521032, 60.86189216183078, 59.281616287846724, 64.21072160044025, 61.232885622209125, 57.57489496661771, 58.52847806869015, 58.746859950404016, 55.10197393355831, 57.63280091747161, 56.12515557196833, 59.109451693873254, 71.77684814699235, 70.45358950091948, 72.33244403716057, 74.40767595844885, 73.12513935950496, 70.33558891665551, 78.40931723194738, 71.480834714828, 68.0067051610639, 71.16761776708788, 68.80682160777431, 70.18959829884191, 71.30592838410409, 74.17579327860187, 69.40501443801388, 69.82067584991455, 70.5901272066178, 68.35085391998291, 69.04050073316021, 60.83037199512605, 63.948232666138686, 70.83993511815225, 67.62377200588104, 74.81100543852776, 67.61599786819951, 57.43953397197109, 70.99741828057074, 75.97933046279415, 70.328520805605, 73.21111771368211, 68.02833311019405, 63.42302730006557, 64.98407963783511, 63.42675747409944, 65.24914949171006, 65.76204253781226, 64.9013646956413, 65.1380052105073, 66.13705250524706, 69.05432316564745, 59.119249774563706, 61.07982689334501, 60.87966442108155, 57.67442118737006, 56.51874188453921, 61.633108585111565, 56.09860112590175, 64.15792649792087, 67.41925178035613, 62.64827289888936, 56.38493022611065, 53.76731295739451, 63.7934833957303, 69.28987718397572, 60.99476245141799, 52.2587223206797, 58.18146597954535, 73.41771679539835, 67.53178458059988, 62.68918714215679, 62.78831328115156, 57.57088238193143, 51.00008080082556, 53.50605956969723, 52.88153979086107, 50.928917238789225, 51.10476886072467, 54.05066890101279, 51.150185984949914, 63.662256579245295, 70.35554593609226, 66.99387073516846, 66.14122590711041, 58.103528484221435, 55.65898579935874, 56.69636249542237, 57.789864386281664, 67.53185518326299, 71.97618299914946, 77.05565237229871, 71.91748080715057, 73.83168374338459, 70.51601794458205, 74.18206907087757, 76.6724838749055, 79.47095378752678, 75.69162461065477, 77.0376173142464, 75.24620809862691, 78.33641605992472, 76.23251161267682, 84.5576403217931, 76.32862537137925, 83.33965809114518, 75.78271773553665, 81.35398172563123, 34.09169220155285, 1.172400489449501, 3.2292049930941675, 4.601293715738482, 0.9811838403824837, 0.2520472325024105, 7.810910392192103, 80.09540296369984, 69.98656072924214, 47.99836935535554, 29.75778106720217, 63.12129112981982, 40.92417078633463, 0.05428796273566062, 0.011309781881620087, 0.0652559592779125, 0.06302244908687088, 0.006905991045172297, 0.042122570767758355, 0.06900441983053762, 0.033130920191686, 0.023676048806538025, 0.019722728682081067, 0.026954056680082317, 0.14901145571662536, 0.15930360183119774, 0.15491249310153146, 0.2215321578325764, 0.1385000245946069, 0.137486306409682, 0.22679240863409736, 0.15919446494550477, 0.11145934252248657, 0.11580731284113661, 0.30498055260508294, 43.44115180353965, 83.73183235045403, 36.65461986295639, 70.29230948417418, 67.7044237813642, 67.517514997913, 9.817432684283103, 0.865187525989548, 4.5230311539865315, 5.8871707031803755, 18.516842780574677, 6.257370373895092, 7.16319420645314, 88.12981344038441, 100.7580489497031, 98.79787583504954, 97.38987830377395, 94.44825756934382, 98.6905990108367, 97.88838017371394, 93.46667658898139, 84.23637467045938, 72.9412978695285, 71.11844693460773, 71.0499466619184, 72.55531311035156, 74.72122238528344, 68.70872312976469, 69.89330245602515, 72.0320140161822, 70.3513882237096, 68.70170993189659, 66.45567447908464, 65.14108819346275, 64.75525640672254, 64.01558368436753, 67.36658219368228, 64.44291806990101, 60.559034193715746, 61.57068014144898, 61.61593644849716, 58.150883259311804, 60.65681888211159, 60.26359342759656, 61.954997893302675, 73.88225093964608, 74.91003744063839, 76.83629774278211, 78.36900311131632, 76.87270518272155, 75.59875857445502, 78.1129821654289, 73.73952373381584, 72.94395723650533, 73.82037947254797, 73.38011695492652, 73.22053140209567, 74.21762927885979, 75.297881403277, 74.33898741199125, 73.74752536896737, 72.64934801286267, 73.91948992206206, 70.59835633923932, 64.46658957389094, 67.47273722002583, 72.17472553253174, 72.09148499273485, 75.71358988361975, 73.10508820318407, 57.537134308968824, 72.2444966531569, 77.06157515125891, 76.8886927635439, 75.74643581144272, 71.9522879200597, 65.36815028036794, 67.56348517633253, 67.9294187791886, 68.79677249539283, 69.68758198522752, 67.10628586430704, 68.3863905937441, 69.6730064576672, 72.6256412075412, 60.07233865799443, 64.66332781699397, 61.654430589368275, 61.599431114812056, 63.76355178894536, 66.48084040611022, 60.26530358099169, 65.90931184830205, 70.19621141495244, 68.15247612614786, 60.559904959894, 58.199928575946444, 67.39452515878986, 71.75029370092577, 62.799511647993526, 53.09566590093797, 61.894467876803496, 74.33697131372269, 69.14660084632136, 66.31974081839284, 63.893735254964525, 59.800251683881214, 55.96296164297289, 55.82192890105709, 56.632369026061035, 55.258680466682684, 53.73205869428573, 55.65327482838785, 53.9250510738742, 67.91078752087009, 74.18352819258168, 70.9021988222676, 69.65447718097319, 62.981289971259336, 58.445904331822554, 60.13532407822148, 62.418104294807684, 70.38328493795088, 74.44263212142452, 79.71622743914205, 74.9732974267775, 76.73827771217593, 73.52172236288749, 77.68341987363755, 80.16871206222042, 83.70304999812957, 78.29235215340891, 79.8123255083638, 76.1069251644996, 85.0041001842868, 80.15117122280984, 88.14916641481462, 78.47567589052262, 87.01184380439021, 78.58328219382994, 86.79590163692352, 35.51619506651355, 1.6041546507227806, 5.737495508886153, 7.770777681181508, 0.8026967534134466, 0.37619510545365276, 11.400004125410511, 94.09638958592569, 72.82878860350579, 64.50493858706567, 39.069960501886186, 72.15755339591735, 47.502526852392386, 0.41635680523130203, 0.18213437028950263, 0.23530531554452835, 0.15478432659179936, 0.15717214604298915, 0.271415421438794, 0.1261545943036195, 0.20405614478213174, 0.21425617648468864, 0.13822706746718577, 0.1737294511328782], [0.010987074046786274, 0.026767096752601287, 0.033291430933581244, 0.06758962397373493, 0.021331128363888112, 0.05611272671470239, 0.03111893390004914, 0.037825710004976684, 0.06218198551646164, 0.04154519328186589, 0.1087143882027557, 47.77608079295005, 52.697792437768754, 28.1673619439525, 38.422620373387495, 51.4738089807572, 40.010078107157064, 0.3867017868305407, 0.1848221438065652, 0.8837536974780021, 3.348651461062893, 8.127418698803071, 1.2380516505049122, 29.179835511792092, 92.74422307168284, 93.08888173872425, 87.42090778966104, 87.52734522665702, 87.96747438369259, 85.98183724188036, 84.41350106270083, 86.40154653979887, 82.0725207174978, 71.8631402907833, 62.27327077619491, 61.66009056952692, 59.86656719638456, 60.241659533592966, 57.96822632512739, 59.776360527161636, 60.10968746677522, 59.58331715676093, 60.6092248424407, 61.11358673341813, 60.31410178830547, 58.88599034278624, 55.1492698730961, 61.20801387294647, 57.205850924215014, 56.221077134532315, 54.10174600539669, 51.85851504725795, 51.86502618174399, 50.81890652256628, 53.50654202122843, 60.88032730164067, 72.08520135571881, 66.36386748283141, 72.49320630104312, 68.45424759772517, 75.40131430472098, 78.15075459018831, 66.2011597233434, 54.43437084074944, 67.79122583327755, 67.01033684515184, 68.99583278163787, 68.83485086502569, 70.61687777119299, 66.58497148944487, 67.05560099694037, 66.44355435525218, 67.00519069548577, 65.81139379932036, 68.33641959774879, 57.54896025503836, 60.35470224195912, 65.37119403962167, 68.0130672454834, 65.44160450658491, 55.450241181158255, 64.91181781215053, 70.59634808571109, 59.594444920939786, 60.60146247186969, 58.469587602923, 55.9365640917132, 53.11825090839017, 59.84417046270063, 56.65651513684181, 59.49938235744354, 48.91394076808807, 63.84483114365609, 67.53451455023982, 59.58243462347216, 60.46141424486714, 64.20864274424892, 54.783042092477125, 60.260573202563876, 57.58615216901226, 54.119298611917806, 54.5359484611019, 51.82723022276356, 55.468087965442294, 65.36854643975535, 62.71904814627863, 58.69573185520788, 47.38440859702326, 54.82146955305531, 60.28978309323711, 63.79546419266732, 60.24749602040937, 48.22501567102248, 53.47262920871858, 69.02099870866346, 64.47222994219872, 58.61804539157499, 55.77231876311764, 51.36297456679806, 50.42065258949034, 47.607999386325965, 47.34058787745815, 47.426562309265144, 49.818168686282256, 49.62080678632183, 53.50614193947085, 63.580298654494754, 61.98313697691887, 58.152377682347456, 53.263566878534135, 51.79431761464765, 49.833309035147394, 58.73104103149907, 68.95853104129915, 71.24146815269225, 70.03470390073716, 68.53866484857375, 71.77397697202622, 71.06199618308776, 74.47335212461411, 72.91818726447322, 72.81287162534653, 71.9330761509557, 77.16730656162386, 73.48874307447865, 75.0239352257021, 75.04414327682989, 79.77354111209993, 77.69455156018658, 82.04657031643777, 78.56745935255482, 73.61548269948652, 55.907405191852206, 2.725505002083317, 3.604476288441689, 2.0992218727065675, 0.11419373248974163, 0.05916720736891993, 0.8691998042406575, 60.908038846908084, 69.70298905526438, 50.82336233508203, 47.44678997224378, 39.806122702936975, 48.8897083651635, 0.7219285938528277, 0.08372923494466851, 0.0459204325001807, 0.024059860771822355, 0.02088298033472271, 0.07745676749055425, 0.038358949335111726, 0.03376359773439265, 0.06274713240864296, 0.03417663020832885, 0.1865636148760396, 0.010252268365283888, 0.02191479543163892, 0.009492904777758786, 0.04329381961255305, 0.02613711200894848, 0.10449525089033189, 0.004458987471392198, 0.07339762764111643, 0.04827859668782161, 0.055817859472646836, 0.20743948016916552, 56.931845911087535, 60.62315710129277, 38.967343453438055, 32.10743965641145, 62.11692117875623, 43.96252893632458, 0.8994304304642062, 0.1541024317303973, 1.9344261865462027, 3.832016904507914, 9.735751286629709, 1.9091356016935843, 33.82497887457571, 97.8905688562701, 93.41911392827188, 91.4735398753997, 88.6098252573321, 90.55593275254773, 87.83478060076314, 89.71869499452653, 86.66045435013311, 87.03287555325417, 74.9912775716474, 66.6141539235269, 65.6680743155941, 61.79927979746173, 62.63538399050313, 62.06755815013763, 61.82159416137203, 61.68787663982761, 61.823994651917495, 63.0321317334329, 63.86056377041725, 62.0640907749053, 61.12507143328267, 60.4796689556491, 61.87381267547608, 60.648374019130586, 57.26418833578787, 56.862137548385135, 56.24654116169099, 54.76824691218715, 53.14628016564154, 56.35495547325381, 62.37422081731982, 72.9079891020252, 71.17303848266602, 75.74791062262751, 71.64995947191792, 79.17235159104871, 81.18440981834166, 72.14473509019422, 58.537346547649754, 71.49218605410668, 69.55204840629332, 69.44123360418504, 71.82982367853965, 72.13879662175333, 69.95094560807752, 69.67965095273911, 70.64775466918945, 67.52229244478288, 67.38384846718081, 69.06307005113172, 64.26505427206716, 63.9896725070092, 67.91147785802042, 71.57119043411748, 66.5090657818702, 57.745651429699315, 70.19645460190313, 70.69675291738203, 59.023747905608154, 61.889670818082756, 58.87290923826156, 58.14558021483883, 57.45179137875957, 64.56087943046325, 59.99910016213695, 62.261570345970895, 51.463175435220045, 64.13330185797908, 70.05696727383521, 63.89704181301979, 62.7034959485454, 66.51694974591656, 58.066269889954604, 63.77003154447002, 61.20394637507778, 56.81671650178971, 56.040263714328894, 56.47158322795745, 59.513879437600416, 66.2906446764546, 65.35939162777316, 61.749155829029704, 49.50935656024564, 58.39729047590687, 64.16206067608249, 64.84599259591872, 63.66300967431838, 52.19110458127914, 55.09958521012337, 71.34234366878387, 68.10801213787448, 60.44750159786594, 59.95619335482198, 54.814240624827725, 53.05839161719046, 50.48408123754686, 49.3541483725271, 51.85238830504879, 52.32281777166551, 53.444807837086344, 54.77313810779203, 63.63196803677467, 65.30730647425499, 59.43630280033235, 55.45859975199546, 54.32231264729654, 53.597042868214274, 60.903492819878366, 70.78741458154494, 73.62556319082938, 69.26926120635002, 71.51723431002709, 73.37934817037275, 74.25637445142193, 75.33526159101918, 75.81706200876545, 73.77142044805711, 74.6702943309661, 77.15498247454244, 77.49757797487321, 77.37941265106201, 77.78333048666678, 80.65149307250977, 81.04620902769028, 82.40018767695274, 82.2686549155943, 79.12492229092506, 65.23303247267201, 4.438548693733831, 2.418361354258753, 4.339785864276271, 0.5079375910422494, 0.02980780697637989, 0.48076209281721427, 61.73762798309327, 79.87607971314462, 56.29519031893823, 42.06744755468061, 45.0059578495641, 61.57261386994393, 1.4292555518688694, 0.17000062541375238, 0.08504184999413068, 0.043193442942274195, 0.017640235488333048, 0.08617336185829294, 0.07097371778781376, 0.06098424535124533, 0.09488454764528621, 0.08909270843310703, 0.04789723428867517, 0.08131133888157145, 0.10812646934702512, 0.15800748831562458, 0.22763738829282024, 0.09089679186863285, 0.1711538941749642, 0.12976372644545572, 0.2164790265622639, 0.1410437122948708, 0.2203523517856675, 0.4736584659305311, 64.57010092273836, 69.2932661118046, 38.36374559710103, 50.75960028556086, 73.52517404863912, 54.97999998830981, 2.7484748921086712, 0.39782942843533337, 2.621228300756024, 8.019312783595055, 21.198894785296535, 2.617415756948533, 34.51097788349275, 108.02522813120197, 99.14709229623118, 99.04391042647823, 93.07172529159054, 95.99640138687627, 91.20083316679924, 96.3955339308708, 93.68257953274636, 90.40987153207102, 76.78568347807854, 70.43670761969783, 69.65313573037425, 65.6767309865644, 66.0852615294918, 65.60870532066592, 67.45802833187965, 66.28031315342074, 67.1578493425923, 69.52980072267594, 66.48352330730808, 67.71100551851335, 64.8726882473115, 63.67631827631305, 66.17214987354895, 64.14794014346215, 59.924461380127944, 61.70997919574861, 60.375902652740486, 58.23779905996015, 56.08313914268248, 59.00195521693076, 66.2000379254741, 78.17690110975697, 74.80945217993953, 79.61068430254537, 72.89040119417253, 80.28836004195675, 77.66815400892689, 71.78091956723121, 65.06533938069498, 72.93943866606682, 73.42775021829914, 75.42677048713931, 75.43725106023973, 77.32327568915584, 71.86954944364487, 71.23248592499765, 74.13326694119361, 72.83482905357116, 70.03034222510554, 75.92946929316368, 67.64232481679609, 67.57261645409369, 70.11651669779133, 72.8896245648784, 68.78043190125497, 56.667297732445505, 71.65275219948062, 74.60509669396185, 63.598090525596376, 65.8304565183578, 63.71127443928873, 62.03571634907877, 58.335760255013746, 65.48375037408644, 61.16361264259585, 66.65754318237305, 55.666100978851325, 70.63941571020311, 72.6087514815792, 65.76150517309866, 65.81509651676302, 69.17927418985676, 58.07449902257612, 65.63434193211218, 63.52598951708887, 60.169778177815104, 61.864536270018554, 59.04440310693557, 61.38955293163177, 68.85122283812493, 68.20396900177002, 64.73809603721865, 51.441265075437485, 61.31131733617475, 68.83508620723602, 68.65877566799041, 64.73504051085442, 54.34310905395016, 59.60978138831354, 69.95901784589215, 70.01245621711978, 64.50230275430988, 62.553469211824485, 56.54601412434732, 56.56456693526238, 54.91111532334359, 53.56187097487911, 53.75431814501363, 56.554357005703835, 56.39346922597578, 57.65592721200759, 69.45554241057366, 69.34327633150163, 62.3093605041504, 60.86847389897993, 58.233464840919744, 57.124355839144805, 65.27824955601847, 73.38488655705606, 76.67050700033866, 74.14719135530534, 73.98243611858737, 76.14299528060421, 76.7896842956543, 80.96199574009066, 79.36674425678869, 78.99044775193738, 80.21750634716403, 82.26379117658063, 82.26323420001616, 83.17843298758231, 81.94598505573889, 85.18910269583426, 84.63976690846106, 87.0995480014432, 86.31632912543513, 84.69027134679979, 67.35382664588191, 4.611476188705814, 8.432489864287838, 7.264996872794244, 0.5952220025562471, 0.27126342959461675, 2.0186816396251803, 71.92623553737518, 82.23618553530785, 68.16288609658518, 62.438837943538545, 53.0263223186616, 74.92896679908999, 1.4954628314702743, 0.22902321070432666, 0.2146164063484438, 0.06090076858057611, 0.10869679116313496, 0.16742511442111385, 0.22516427261214103, 0.25659745769394987, 0.2538310835558561, 0.1660180407305879, 0.3051765178961139], [0.08305161485388395, 0.13273348160568746, 0.04892397979875246, 0.07379061542451382, 0.040901296381508155, 0.04727391834040323, 0.015573517002555874, 0.02790995054848252, 0.026530862049830538, 0.02676079567942408, 0.8153274595256775, 60.418656487618726, 40.406288485373224, 36.10743353443761, 39.23664554472893, 54.167598678219704, 28.313493767092307, 0.3487052660315268, 0.046533701205325705, 0.7691864128555022, 4.993467484751056, 11.353273007177538, 12.876908875280812, 61.680533962865034, 97.66453835272021, 83.18299862646288, 85.0182834748299, 81.96147841791954, 87.63157829161614, 86.89192910348216, 83.32161518835252, 84.53107803098618, 84.56910148743661, 80.08315732402187, 68.90703816567698, 60.53816326202885, 60.55230732887023, 59.56978105729627, 60.581995748704486, 58.27635988112419, 58.85413285224669, 59.37338013802806, 60.24051027913248, 58.996146186705566, 60.06553334574546, 59.06296768496114, 58.089658983292125, 54.68160959982104, 56.20809016689178, 55.72385787963868, 55.83437065924368, 50.52879233514109, 49.82620562276533, 51.18462439506285, 54.71336118636593, 60.99249924382856, 71.47279385597476, 68.60243474283527, 70.34217065380466, 70.2341878029608, 69.42778771923435, 50.67666569063741, 65.61478499443301, 65.73678247390255, 67.54821931162189, 70.41628776058074, 65.67802536872126, 66.00209159235801, 67.73276682822936, 69.09289575392201, 70.54550632353752, 65.55230555995819, 64.94648764210363, 66.43559978854272, 63.76151215645575, 55.64954857672415, 59.801267577755844, 68.97052564928609, 64.35410776445943, 59.21155491182881, 69.29864760368102, 66.59180425828504, 59.575778361289736, 63.281233618336344, 64.90026250962289, 47.55641237381966, 65.13282375950968, 68.56729030609131, 65.14133138041343, 60.35506702238514, 64.8997800580917, 61.805222188272786, 52.85432246423537, 65.99208170367827, 65.90697411567935, 63.83663731236612, 62.94206626953618, 63.529523572614124, 59.99495813923498, 59.42670083815052, 53.652987633982015, 53.65550579563264, 55.27180079490908, 57.739446240086714, 60.357345919455256, 65.37217070979457, 60.96858847525812, 51.74892010227327, 49.135495847271336, 55.02418156593077, 59.964143999161266, 63.02902129388625, 62.62162431593865, 53.38877677917481, 50.461464851133286, 66.66655678902903, 62.474402073890936, 59.18202730917162, 56.45053971198298, 49.26983310330299, 48.36142786087529, 45.175012003990915, 47.22008874339443, 47.343235477324455, 48.701681706213186, 48.20385840631301, 51.11215860612931, 53.72348439308905, 52.79676560432681, 50.505054150858236, 52.88138289605418, 50.05810791446317, 58.29828200801727, 67.03032524354997, 70.19728614437965, 65.72250504647532, 72.49788176628851, 69.9615752312445, 69.31316821805893, 70.2887793510191, 70.91644487073346, 69.24523276667442, 71.26060931913315, 71.22755942806121, 71.55278667326897, 74.1137727614372, 76.98774045513522, 75.56876028737715, 82.19110181254726, 76.94951303543584, 82.2851602492794, 70.15610910231068, 75.27291943950038, 13.895055170982117, 1.8243914458059498, 4.619841623690821, 0.7842481304560939, 0.09559304874029853, 0.2530503939957388, 32.84857542284074, 84.78153705596924, 46.677232711545884, 52.771544764118815, 32.04721950715588, 56.91412856501918, 4.8837980147331, 0.3364486253309635, 0.11675548454326008, 0.06256169316569163, 0.07090552064079432, 0.03727784988680675, 0.07983521002555087, 0.029513905005108927, 0.03494124724379471, 0.026622986037945075, 0.01959200918434128, 0.009300315061644202, 0.07745977821609668, 0.04682593310492174, 0.10740316743331571, 0.039239973430672, 0.049938873928641124, 0.03515230446693397, 0.08398575948611384, 0.1035423294430779, 0.08326898464151929, 2.176879408859438, 69.93800963124922, 46.70637199955602, 37.30194037960422, 33.78590814528927, 66.2810819379745, 27.72642085629125, 0.4725526946206247, 0.09838699438278714, 1.974742268362353, 4.462451617563925, 17.826183995892926, 17.592079293343332, 68.87265466874646, 101.35770874638712, 87.92788197917324, 88.20058084303334, 83.51254047886019, 92.65558535052885, 89.76525352847192, 88.48223055562666, 87.03078885232249, 87.42305724851548, 82.02320867969145, 72.19145836368685, 63.70305315140755, 63.15161497362199, 63.45532017369425, 64.50456203952913, 60.513522932606364, 61.56604782227547, 62.254066851831254, 63.189344252309496, 61.60602069670155, 62.431734531156486, 63.29896665388539, 60.1821336438579, 58.932929346638346, 58.83128896836312, 58.324173573524725, 57.789185816241854, 55.7228772870956, 52.91651164331744, 53.73234502730831, 55.49317544506442, 64.98910811639601, 75.04665359374016, 72.11360716050672, 73.6552712225145, 72.81025148207142, 73.28313243004584, 53.80067271571006, 65.74753761291504, 72.59027711806759, 69.1409134095715, 71.58510700348886, 70.16996291375929, 69.0603949946742, 70.65476786705756, 71.69796928282707, 73.72872937110164, 65.80465124499413, 67.4190164381458, 70.43203215445243, 66.239300850899, 60.33188189229658, 65.50382506462836, 71.38136340725806, 65.17601689984723, 61.90212434337985, 73.35572765719506, 66.83294373173868, 62.56684449411208, 68.62561595055365, 66.71193861192273, 53.17505859559583, 69.51934368379655, 71.32477929515224, 66.26354894330426, 63.892025101569395, 65.37250411125922, 67.8586749107607, 56.35618709748792, 66.8352500854, 68.604568512209, 64.23134934517645, 65.72995362743255, 66.02886569115424, 61.7661161576548, 59.41506316584926, 58.01369051779471, 57.0867677657835, 57.02362152837939, 55.47199464613392, 63.75829189054428, 65.7634977371462, 62.95249585182437, 55.07001053902411, 50.794211279961374, 59.36655129155805, 62.56082757826775, 65.91921975535732, 66.38522871078985, 57.61924128378592, 53.331529786509854, 70.02218369514712, 64.45877229013752, 61.717204201606016, 60.67150031366656, 52.147680021101436, 50.07768838636337, 49.7769602652519, 49.60424261708414, 51.078175190956365, 50.83975392003214, 50.916636297779704, 54.57339532913701, 55.5788125530366, 55.30956537492814, 54.07778816838419, 54.62211116667717, 53.66793578670871, 61.712320850741484, 68.81733355983611, 71.61228118404266, 68.73516774946644, 74.02335428422498, 73.87326086721113, 72.14024005397674, 73.40874241244408, 73.17916608625843, 71.0333550360895, 73.49931778446322, 73.8616192725397, 73.89792473085465, 75.40640554120465, 78.73874925797986, 76.66506275053948, 83.1618413617534, 78.95318523530038, 85.22980905348255, 73.65718533915859, 83.3776423238939, 17.682888046387706, 1.0657878941105259, 2.538828864212959, 0.9712919905301064, 0.08557971266488876, 0.42217775578460387, 32.53418764760418, 92.21244381320093, 54.55519553153746, 46.84061904107371, 44.75085473829701, 70.64944128836356, 7.555509180791917, 0.3582558083918787, 0.16077864284236587, 0.07675519949125667, 0.1166340213028654, 0.004852949144063337, 0.06753409026010383, 0.007815364703175523, 0.03701135471102692, 0.09275408777137918, 0.025659184226946487, 0.2158719325257886, 0.38156406413162913, 0.1400781503968662, 0.12473336330825284, 0.1073155193138988, 0.1618760025068637, 0.1282389663280018, 0.16398770854838435, 0.23611004494370955, 0.2133008648431109, 2.2790873050689697, 85.2386579205913, 51.485513333351385, 48.832594733084406, 57.23448814884309, 73.83318208879041, 34.95767701056696, 0.719151494483794, 0.17830273557093837, 2.5012711892204904, 12.262614715483881, 23.785058567600867, 19.591089756258075, 73.57478418657857, 108.32441083846554, 90.80919234983384, 94.50270006733557, 88.25722771306192, 96.63270396571006, 95.44897971614715, 91.63642806391563, 90.58032989501955, 93.51343908617574, 85.95962093722436, 74.52323682846563, 67.63453498963388, 66.35873702264601, 67.3776589670489, 69.38400622337096, 65.20261841435587, 65.52595899951073, 65.04319367870208, 67.86620586149155, 66.36665236565375, 66.39278319574171, 67.66389785274383, 62.54798181595341, 60.93238499856765, 61.87265165390507, 62.866352758099964, 63.31178495960852, 57.0882268874876, 55.613741259421076, 57.559487896580855, 61.026776836764434, 67.60999664183586, 80.44073627841088, 76.39740805472098, 76.44341745684224, 76.28036452877906, 69.67398705021029, 56.51603152675014, 70.19246947380805, 71.3510670200471, 72.97867021253033, 76.08257509046986, 70.91880613757719, 70.08300396703905, 71.69279959893996, 72.52856254577637, 78.11204079658755, 70.88353618498772, 71.01158588163315, 73.31791600873395, 69.08053244313886, 64.39724991398474, 67.22094458918419, 72.92547502825337, 67.85758449185279, 62.01934829834969, 77.31608206225981, 72.73287096331197, 66.44991643967168, 70.00720024108887, 69.90739945442446, 53.18767686044016, 69.40565770672214, 72.84715314065257, 68.59215028824346, 64.93774467898955, 67.27697172472554, 67.78587572036251, 60.20021577035228, 69.39004667343633, 72.05972163907944, 67.61157343464514, 69.71264593062863, 68.08535652775919, 64.65050558890066, 64.25636229976531, 61.270838475996456, 60.20082373772899, 57.1184056035934, 59.39846761765019, 65.32831076652774, 68.69228055400234, 67.07882142836048, 57.78990753235356, 54.62792019690237, 60.68322035574145, 67.2052001953125, 69.6697901141259, 66.46599031263783, 60.08408223429034, 59.98109648304602, 68.59520973697786, 62.57434798825172, 63.988405581443544, 62.61348539783109, 53.72564169668383, 53.14370316843833, 52.46690996231572, 52.800872325897224, 52.67699603111514, 52.75609062563989, 54.854193887402936, 57.18024176935996, 59.28513857626147, 59.07870423409247, 56.716821578241166, 59.898840458162375, 54.462298116376324, 63.154756792130016, 70.64723691632672, 74.53443911767776, 69.06630992889404, 78.18869959923529, 76.05807596637358, 75.6377390892275, 75.80000754325621, 78.2264720239947, 74.36306292010893, 78.1455692168205, 77.02116689374371, 76.8646643238683, 80.38705472023257, 82.17472983944802, 82.38284295605075, 88.8899060218565, 82.25171027644988, 88.47440934950306, 77.37170911604359, 88.1501470073577, 17.48554968064831, 1.8833699197538438, 13.433479474436853, 2.866624281291039, 0.24067223642862615, 0.6268278485344303, 40.78528358090309, 99.60111448841711, 59.824691972424915, 72.14818677594586, 46.279480841852006, 81.15654530063753, 8.376790246655865, 0.696262319482142, 0.43713491770528984, 0.18954412591072822, 0.2295517960503217, 0.11548767031560983, 0.1887387223541737, 0.16833899602774652, 0.18830805836666017, 0.1554699599622719, 0.10594508760879118], [0.04055729609042887, 0.06152271323146359, 0.03486025259800015, 0.017638416029512882, 0.008770394807441101, 0.005914047473080216, 0.016304339026852, 0.03856913321801732, 0.04228892676051586, 0.18506664842847856, 4.733345210552216, 58.55783700942994, 37.08802607751662, 44.443144798278816, 31.58575461756799, 67.86273064151888, 15.653073249324677, 0.6343463579973867, 0.17368129484595793, 2.383914363961066, 4.078268697184901, 1.480359009677364, 30.03237835822567, 89.89369546213459, 93.8733087047454, 87.63714805726083, 81.47610079857611, 80.89728447698778, 82.83721816155219, 82.8505777543591, 88.6433615223054, 83.17467535695722, 81.17900479224421, 83.60101346046694, 73.17243529904273, 61.429529728428015, 60.493232511704974, 58.49101158880419, 60.47047099759502, 60.111640807121034, 57.65505644582934, 58.51767193886542, 58.34701745740829, 57.317469812208614, 58.052702411528564, 57.38382062604351, 56.91115933079874, 58.339306077649525, 53.978901293969926, 53.881367637265114, 51.74264038762739, 50.68514977732013, 48.80867611977362, 53.20832813939741, 53.210418762699256, 66.64339911553168, 70.72857118421986, 69.32034615547427, 68.8275238775438, 69.35854219621228, 48.377121263934725, 57.897564826473115, 69.17844264738022, 73.03257926817864, 63.16079724219538, 65.50906927354875, 70.83691489311957, 71.20459787307247, 70.93628421906503, 69.10582388600996, 66.06757164001465, 62.64289140701295, 62.575846333657545, 67.13242453913536, 63.91970134550526, 57.26003454577539, 65.31008743470716, 69.85778147174467, 60.25624682826381, 68.17109953972601, 65.87863106881419, 60.08781240832422, 63.55946694650958, 73.643582559401, 59.37638467358005, 65.56086024930401, 67.57865690415906, 59.98838424682618, 59.231037324474705, 60.46306556270969, 62.196517836663034, 67.9267829464328, 60.62354933831, 56.16996865118704, 65.01410930387436, 58.68439228303971, 62.033029525510734, 61.98594147159208, 61.672493104011785, 51.07743778536397, 51.49948481590518, 50.108431923773985, 50.86226440245106, 54.81930832709036, 63.50505582747921, 60.20049818100468, 59.6860557986844, 50.21145689872004, 46.734173759337395, 54.39920286978445, 59.465045928955085, 63.03777602411086, 63.008122905608154, 58.9667990130763, 57.301317491839015, 52.42449737364247, 71.32337508663055, 62.83207516516409, 59.04287338256837, 53.28175883139334, 46.03359137811969, 45.36344266706898, 46.758170820051625, 46.84205462855678, 49.66430979390299, 50.442708076969275, 50.50826657202936, 49.90691623380108, 51.83024652542607, 50.61481775776033, 51.51266005731399, 52.306818423732636, 58.9876542552825, 63.96015274909235, 68.06272445186492, 70.54102697680074, 67.366393919914, 66.81254740684264, 67.30682880647721, 64.84667508832871, 65.26592939130722, 64.37970515220397, 67.12563099399691, 69.27729422046293, 76.38364053541615, 74.11311380324825, 75.34536561658307, 75.79979573526691, 79.79825204418552, 75.02315075166764, 81.413295807377, 73.08539790491905, 78.55901056720366, 40.613683808234434, 0.33683985111213505, 2.4229323863983154, 1.3395630808607226, 0.09194427920926003, 0.7634836543471583, 12.339890310841223, 84.26379988270422, 54.69727946865944, 40.15033421977874, 12.350358136238592, 54.355252712003654, 14.048407097016613, 0.3854225732145771, 0.07852535289261611, 0.051601924407746524, 0.03512427330978456, 0.12337633048094089, 0.13114280728322844, 0.03817831729388526, 0.05441153654828668, 0.04611295422599201, 0.057716891845507975, 0.03899263811387843, 0.0602300317897912, 0.0132669756496926, 0.06067505226500573, 0.06596302012762716, 0.05919153449095546, 0.015782341079395867, 0.0417303605636041, 0.19786900420102382, 0.23945987164493532, 7.658349804339871, 67.00664197244953, 48.6541308126142, 44.49726173954625, 29.021475699640092, 82.8518250680739, 16.221916944749896, 0.71097016574875, 0.13676383953181007, 3.263021952682926, 1.554022347254138, 1.2845082028258232, 32.28379726409912, 94.51043498131537, 95.3808795252154, 88.93438569961056, 82.15592599684193, 87.85730285029258, 86.07515042827976, 85.8130733428463, 87.348430233617, 86.61227195493638, 86.61860266039449, 87.94736046944895, 77.48373200816494, 65.16581481502902, 62.47815185977567, 61.61407724503548, 64.70886653469455, 63.41588466398178, 61.950306738576586, 62.8971355192123, 62.44761620798419, 62.97347660987609, 60.70269100127682, 61.21519573273198, 59.13033439267067, 62.16921029552337, 58.019401488765595, 57.3536144533465, 53.866905858439786, 52.843892881947184, 52.33064682252946, 56.1004642517336, 55.97455224683208, 68.01669936026296, 73.75079662569108, 72.00185883429744, 71.18017719637963, 73.1577342556369, 53.56895085304014, 65.25963790955083, 70.19139474438083, 73.45625015997118, 68.75572096916937, 67.58998470921671, 72.66386078250024, 72.0423847629178, 71.8502200034357, 70.74315455652052, 67.38986538302514, 64.35008733503281, 65.98768080434492, 68.82819068047309, 68.36495091838222, 60.887058088856364, 69.05196974354406, 72.72008403655022, 61.910357398371545, 71.17235599025604, 67.77608548441242, 63.606468708284446, 69.15096252195298, 75.91912992538946, 59.25709362952941, 66.84089045370779, 66.17599379631781, 61.96426253164969, 62.11082189313827, 62.7143491468122, 63.77715064633278, 69.0452781800301, 64.78877305984497, 59.13040891770394, 65.52831242161413, 60.66517353057862, 66.61359694696242, 64.25156524104457, 63.52635821988506, 52.90092022188249, 53.77297685992334, 52.26275451721684, 51.60771477606989, 57.54260993772938, 64.1657006356024, 63.69752653183476, 61.060364092549975, 53.93699076867873, 49.04626977059149, 57.46616686544111, 63.80879240651285, 67.20065024591261, 65.4051225416122, 61.15154743194581, 60.99651182851484, 53.75739328322872, 70.79966806596326, 67.02776001345727, 62.039517125775745, 56.240614460360625, 48.69398209356493, 49.99090594630088, 50.827151344668486, 49.64640809643654, 51.668515436110965, 54.180397372091974, 50.94238665796096, 54.26419881082351, 55.176185177218535, 52.63275954031175, 53.9322211665492, 54.66516310168851, 62.5551244520372, 65.8050395596412, 69.4675370185606, 71.76410044393232, 69.20003921754899, 68.805448778214, 69.51282470457016, 66.28779703570952, 66.55915444897067, 68.83645903679633, 69.32448817837623, 71.8172642492479, 78.08739262242472, 76.16969877673735, 77.00633248975201, 79.95455065081197, 79.49987734517744, 79.96857704654818, 84.17029057779621, 76.45011686509656, 80.10416553866479, 50.54656851676203, 0.3611686278975779, 0.3370508623699988, 0.3465955518186093, 0.13559192419052124, 0.5980330549420849, 10.324898150659378, 88.62181986531904, 63.760005966309585, 43.918661148317405, 19.757394329194103, 69.65649327924176, 20.301211341734856, 0.2549380499629244, 0.06342961715774671, 0.10750402290854724, 0.020882903725930282, 0.02137294910367458, 0.04693335012322472, 0.07940125952084219, 0.027461768045360525, 0.0557960910842784, 0.05036900548504726, 0.1521720893440708, 0.16524930214208944, 0.1642617075553825, 0.19765950979725008, 0.12817178807792165, 0.26178428662880776, 0.15750404597530443, 0.10773120628249262, 0.23985621489344106, 0.32573111655731357, 8.375513515164776, 83.10477872048655, 50.70896640900643, 55.3140486440351, 44.68032267785842, 92.79097772413685, 18.840701118592296, 1.0160569594271722, 0.34813600141675244, 4.729346844457812, 11.094996698441046, 2.914659097310036, 35.51637941791166, 98.31887598960631, 102.04521394545033, 95.6489892159739, 89.81090207253733, 92.23534261026691, 91.51979246447164, 89.91563720087852, 91.47535985515964, 91.92477718476327, 90.58859040660244, 91.83912046494024, 80.94573359335624, 69.07398992969145, 66.90262856022005, 65.73554692729827, 70.16661320963215, 67.70736555899343, 65.03870648722496, 66.57576176428026, 65.84313361875473, 65.91095139903408, 65.70137523835706, 64.61001496161184, 61.68586838629938, 61.875750326341205, 59.82969691676479, 60.49276574965447, 58.621814789310584, 57.522386197120916, 56.29475101347893, 57.386676111528956, 61.335843916862245, 73.46925673946258, 77.31662334934359, 75.00516276205741, 75.41425028154927, 73.4370933040496, 51.55059722162063, 67.57330679124402, 72.04105900179955, 74.34611828096452, 70.49754358107045, 72.66880296891736, 73.9604865351031, 73.60323705980855, 75.37541881684335, 75.11764849385908, 71.21672584164527, 69.2707673964962, 68.89956212812855, 73.22142570249497, 72.53419506934382, 64.82861649605536, 69.29630987105831, 74.04735918967955, 61.95912030435378, 73.83111107733943, 72.77530316383609, 64.97394815568002, 70.07838341497606, 80.30661475273871, 65.08122105752268, 67.87026943699007, 69.81125431676065, 63.24654417653238, 64.73112598542245, 65.01645488123741, 65.9422440682688, 72.58386796520603, 65.42501288075601, 61.92431319144465, 69.67066088030415, 61.95970865987963, 66.42637437389743, 66.90804927579819, 65.74858096338087, 55.95840777120283, 59.51736642468361, 57.19807286416331, 52.850721728417184, 58.610726248833444, 65.86862118013444, 64.94480494529971, 65.06610424287858, 57.12864691211332, 50.096825630434104, 60.70404421898627, 66.35090012704173, 68.03005110832953, 69.64584012185374, 63.098156990543494, 62.60566026933732, 59.14079927629041, 69.49071038153865, 69.9586412983556, 63.87079331182665, 59.79823558561264, 51.311046308086766, 51.59900711428735, 51.908089883865856, 51.43633465613089, 54.37620993583433, 57.73748897737073, 53.73371785686862, 56.034952825115575, 58.99412224369665, 55.55928699431881, 57.861286824749364, 58.903621396710804, 64.64419841766357, 68.7952898394677, 73.25432654350035, 74.90216916607272, 73.69008618016397, 72.60588815135341, 73.38477673069124, 71.11970209306287, 69.67333593676167, 72.00997029581379, 72.03272004281321, 77.06428158667781, 82.35717496564313, 79.55431199842884, 81.05944310465168, 83.21033754656392, 83.50325230629214, 83.73042814193234, 87.05616658733737, 82.27494639735069, 87.34289969167402, 51.507137360111365, 0.6108068049915376, 8.342097863074272, 2.495383711591844, 0.26582870992922014, 1.0342417417034027, 16.764406234987323, 98.55894857837309, 69.83899331861927, 56.076486802870235, 19.828453948420865, 79.57779130628033, 24.132258930513938, 0.554582080052745, 0.30205483217873885, 0.24852987769390308, 0.19154194532142532, 0.31416199380351656, 0.2506105418527319, 0.11789831152606396, 0.10403549854433346, 0.13501889042315945, 0.20685720738143692], [0.041015087251341155, 0.04350211891916491, 0.11491431479131985, 0.02872027430473076, 0.019045907237957564, 0.03618705942625961, 0.07405385089617583, 0.03645091542914029, 0.039441791633444453, 0.2254342419966575, 10.188801711605443, 66.52817556934973, 26.329700139261064, 40.56617213833717, 34.3462069572941, 69.65909773303618, 11.348388675720463, 0.8528519782327837, 0.17699388967406365, 2.0174101788190106, 0.6548805174327667, 0.126877773643261, 44.39878279162992, 96.78596665782314, 86.07643696569627, 87.3712113595778, 78.61309220713954, 81.55471294156968, 81.49122545796057, 90.14702566208379, 86.45109391981556, 84.39978061183807, 84.85851749297112, 85.13754706228934, 77.97461663523029, 63.64393911054058, 60.36879924035842, 61.267720191709465, 57.593612517080004, 58.894568566353094, 56.36549488190682, 59.62839303478118, 57.93984013219034, 58.52112362461706, 58.668934222190614, 56.18771737621677, 57.48184065664969, 56.71822970913303, 54.85735531776182, 52.21118319419123, 51.44191618888609, 48.922197357300796, 53.736847908266135, 50.65927782366353, 55.61054060536047, 66.00652387065273, 72.43347644805908, 64.50968465497418, 72.392683798267, 60.379985840089866, 56.77705741697743, 68.24080790242841, 65.15351426216864, 69.92325367466097, 73.03359123968309, 67.35100253935784, 69.03671172357375, 68.33708640067809, 62.476916313171394, 64.00170633869787, 62.835738658905036, 58.257638408291726, 63.250792103429, 66.01876166559035, 61.874020561095215, 55.67613047938193, 69.4831088281447, 62.73593394987045, 69.18977829717821, 67.18842029571533, 58.370116295353064, 69.61798344888996, 69.49798245583811, 61.58195303332422, 57.944809775198664, 61.892365486391135, 61.0598934081293, 64.69741713616156, 61.168990212102095, 64.97749005594562, 65.71719023489183, 62.736620364650605, 67.50149603812926, 56.81500634839458, 58.997875951951556, 66.84471084225562, 59.11095003927908, 64.77259328288417, 62.01626531539425, 59.282789076528246, 48.04506909462714, 55.05818459295458, 59.576990373672984, 64.09309756371283, 63.799974918365486, 61.713340666986284, 56.16541085704681, 50.6338216412452, 47.90220460584087, 53.46225061724263, 57.13909610625237, 60.31711809096798, 65.67339304954776, 59.03334594541981, 57.66992222878241, 54.16142094519831, 56.258480856495524, 70.71155594241235, 58.40299752450759, 59.910501664684666, 46.75316587571175, 47.83086845951696, 47.22514860091671, 47.04682980814288, 49.14263063861478, 50.46091964167934, 49.59598602787141, 52.850047080747544, 50.64499647386613, 51.54210921256773, 53.78257097736482, 52.019018434709125, 55.41006042111305, 61.65565436886203, 65.49050469552317, 66.03332934841033, 63.50560888167351, 59.61431172586257, 60.80306837635656, 63.11158326364333, 64.55104604844125, 65.72256780439808, 69.54698854877104, 71.25693013591152, 72.73364759260609, 77.65104463023525, 75.92281695335143, 76.04960364680137, 80.0741829410676, 77.77976112980997, 80.11516386462797, 81.41977556290166, 73.02757432383876, 65.55475311894571, 3.156514648468264, 0.18565030017447087, 0.1252951662266447, 0.13389916099127264, 0.2962571094113012, 2.27270340246539, 76.32186320520218, 58.149969347061656, 49.668004666605306, 24.316057274418494, 47.58257458286901, 22.24331213581947, 0.37887776150338115, 0.1502539124339819, 0.07514887399250463, 0.02907125557202005, 0.08324253928637312, 0.039843003370709, 0.059202121826069015, 0.02404378441673133, 0.042235446162521846, 0.05048167786651081, 0.0527062516419157, 0.035026122124925736, 0.06154252043474586, 0.028787617263714635, 0.016666675632398938, 0.014990212868959194, 0.025444436375231996, 0.12436780147254468, 0.018749741476870353, 0.2714848290047338, 17.158127869329146, 75.84653469824022, 38.79406098396548, 34.78651654335761, 34.95178168819797, 83.77472739065848, 10.243565843951318, 0.8476449092549663, 0.17522050338166376, 1.1753661690219757, 1.4439326933314724, 0.04776354428500899, 51.98863183298419, 101.27121263934721, 90.17368208977484, 89.22866544415875, 79.95440160074543, 84.3744421005249, 85.7155945993239, 93.1017392681491, 89.30802283748504, 87.56296034782164, 88.89675448017736, 85.07787212248772, 81.01868183382096, 67.02499082011562, 60.780283328025575, 63.60774740096062, 61.929376971337106, 61.781833094935266, 58.723345341220984, 62.5784037190099, 61.43044756304834, 61.68991627231721, 61.09956033768193, 58.518370120756096, 59.954232169735825, 58.512262990397794, 58.224961142386164, 55.27931213378907, 53.697200590564364, 53.48292935279108, 57.53758145916847, 52.93511936741491, 58.96075071827058, 68.22679719617291, 75.10281408986738, 69.6948697490077, 75.50104448872229, 64.24855678312241, 61.587169785653394, 69.7490769047891, 67.3165641292449, 72.53920785842404, 75.02698682969617, 71.69156012996551, 68.10099109526604, 70.08229009566769, 64.60491588038784, 65.79948156110703, 65.6554207494182, 62.90110495782668, 65.57744795276274, 69.60078777805452, 66.92718259749874, 58.799470701525294, 69.02989464421427, 64.28796091387349, 70.0204578522713, 66.72364296451693, 62.80783099512901, 73.35826150832638, 69.11942666576755, 65.81230378920033, 63.44260777196577, 66.2530997491652, 62.63685880168792, 66.38706438003048, 65.29704163151403, 68.26991188910701, 67.55069040483045, 64.19756204851213, 69.66267493463332, 61.89250669171734, 59.62390584330405, 69.16997032780802, 61.3873250253739, 65.92116525096279, 64.91581862972629, 60.8303366937945, 51.67142975714899, 56.843274870226466, 63.16990106336532, 66.97339596286898, 64.88065065876131, 65.27941449995964, 57.0932004528661, 53.40265412484446, 50.29713323039394, 55.808247673896055, 60.790446189142045, 63.09863944207469, 67.50930155477216, 59.93559698904715, 59.54172826582386, 58.04996851951846, 59.17703805431243, 73.60767718284362, 61.87260066309283, 61.855730548981704, 50.37961675274757, 49.50632849047261, 49.6365668696742, 51.14214904846684, 51.79669849334225, 53.09221029281617, 51.48662336411015, 55.14240572529455, 53.79145122343495, 53.64362885875087, 54.86980099831858, 53.865336910370864, 58.255551707360056, 63.45465729313513, 67.24860514363935, 66.37543847483974, 64.8709310254743, 63.18533951236356, 63.20813240543489, 66.66920046652517, 66.57561271421372, 69.12886388840215, 71.52258442294213, 74.38279244207567, 73.81028329172443, 79.1620514469762, 77.14043832594349, 76.59720574655842, 80.69119530339395, 79.30883438356462, 79.36610883282077, 83.38716583867227, 74.16146093799223, 71.48824014971333, 4.264926939241348, 0.21675604395568374, 0.24965944369473766, 0.051518922611590356, 0.4197161007792719, 2.1766014108734746, 80.25176432824905, 65.82527898973035, 54.18209968074676, 28.0048228463819, 61.12592258761006, 29.092029333114628, 0.2633535717764209, 0.06640655439226859, 0.04450333837960516, 0.020824964496216947, 0.008248320251192537, 0.049754691069885615, 0.12616396355893345, 0.030823764053263494, 0.017981345712717985, 0.023587356892324263, 0.1934683653375795, 0.2113733263385873, 0.24113368182893724, 0.1377684565921945, 0.07394050818777854, 0.0727482378903416, 0.253837043719907, 0.1810506316682985, 0.19416866163092275, 0.3653931125037132, 17.931656529826505, 92.38392199239424, 36.6297951821358, 56.05904402271394, 51.49300898275068, 90.13169703945037, 13.977532809780492, 1.1997888068999014, 0.4743725211629945, 5.486588353110898, 5.0592402392818085, 0.20420775358234683, 53.52107832508703, 108.44259969649777, 94.1513341472995, 97.10013281914496, 84.14391656075755, 89.37889222175845, 89.15086130942069, 99.51900359122985, 92.59096037956976, 91.8939708894299, 92.47545442273541, 92.07114435011341, 86.07141633187571, 70.05944621178412, 65.14470854113179, 67.72435726657991, 65.55123867527132, 65.3147707446929, 62.34289284675353, 68.74527177503033, 65.72530169640818, 64.69808786146103, 65.30873813936788, 63.10654694034208, 65.10723029413532, 63.53712904837824, 61.19417967334871, 58.69892074215797, 57.12165332609608, 55.00893139070081, 61.08866791571341, 55.67645603610624, 60.5980186308584, 70.7683361730268, 78.42320242235738, 72.80893356569352, 80.04201166091427, 64.8480204612978, 60.827567500452844, 72.73056460965064, 69.21987072114023, 74.90895486647084, 76.52101762833135, 72.99031180720176, 72.18445301055908, 73.84441575696393, 69.55995590456071, 69.0437327661822, 69.59927374316801, 65.71538986698275, 68.6658202448199, 71.63365025674143, 68.83845160084387, 62.17924764079433, 73.75399727975169, 66.50102492301696, 72.32375206485872, 72.44658500917497, 66.6581315378989, 76.54822318784653, 71.14056125763925, 68.68948782643965, 63.61419577752391, 67.96096248011436, 64.22439106049077, 68.68190980726673, 68.32637048536732, 70.92157533091884, 72.71943292310162, 67.23328436574629, 72.16967351974981, 62.002740983040106, 64.77521734852945, 72.52557369970506, 62.14301670751264, 68.95504013184579, 66.59822125588694, 63.05575224661059, 51.54483918220767, 60.95095349896339, 65.41167682217014, 69.11839116004207, 71.89256591181602, 67.67961871239447, 60.46704676843459, 56.79336663215392, 52.679196480781805, 59.38040902537685, 64.61459628997311, 66.36502850440242, 70.2105280660814, 62.77776210538803, 61.33873862604941, 61.82937222142374, 63.63757310375091, 72.49953700650123, 63.805968299988784, 64.61448646360829, 53.22007956043367, 54.16670045545025, 53.44174446598176, 52.37109822611655, 56.92775880136798, 55.688835036370065, 56.045060773049634, 58.51457326642929, 55.23694269118771, 55.62443364051081, 58.972400157682365, 55.61464340456071, 62.36927078616235, 65.7891853394047, 71.7691603014546, 70.74453523082119, 68.51895886082804, 66.62366174882459, 66.75189187449794, 69.86455148266208, 69.8773854778659, 71.1870256547005, 76.13162040710449, 77.6446903905561, 78.07464491936469, 83.49757271428263, 82.06150670205393, 80.59789780647525, 88.65818808155676, 84.87622307192895, 84.64895309940462, 86.7869507881903, 81.5840522704586, 77.04764289240684, 4.361856550939621, 1.2388595361863415, 1.2769461182817337, 0.3324793399341645, 0.7710036959859633, 4.284125960642292, 90.84217163824266, 70.06091317822857, 67.88115793658842, 35.25851495804326, 67.05134914767358, 37.553305472097094, 0.48528096969089207, 0.2987168338750639, 0.182110560276816, 0.23876711365676698, 0.14036235369501576, 0.1271986342485874, 0.2219667748337792, 0.17385274532341188, 0.1373809080330595, 0.09627733379602434], [0.03756289971211264, 0.017021774622281233, 0.002914688281429511, 0.06587898028233359, 0.05262949729278203, 0.027155761884885932, 0.03628659339982175, 0.07227703252987516, 0.06396599744837131, 0.27152141736399743, 16.504221693162, 65.1811630495133, 35.75621666446809, 55.731424131701075, 41.250915988799065, 73.97492870207756, 3.014454245567322, 0.3425800253547007, 0.15274392801427072, 3.0448268738485154, 0.7521525397896768, 4.1764838657071515, 78.16802870842719, 90.24284132065313, 90.3887221121019, 82.69587163002261, 79.37269056996992, 81.96674223869078, 81.9488876096664, 85.68646707842427, 86.35587446151241, 84.26497659375592, 82.39429627695392, 82.56023606946393, 81.41605715597831, 69.2419615099507, 60.62474566121256, 58.147992472494806, 60.047384538958156, 58.51979394112864, 58.907080927202784, 58.137849223229196, 55.97149279809768, 58.43931082756289, 55.50273818354453, 57.98084066760156, 58.09758609341037, 55.56597463546261, 51.82499054939517, 52.09503004627844, 50.96330073571975, 48.53870722555345, 51.85465151263822, 51.51415055797946, 56.19618969578897, 66.46943415364912, 70.50320748359927, 67.17970478919246, 68.85499615823069, 64.82285845664241, 62.503121668292636, 66.14627791989234, 66.24610224077779, 69.61170765661424, 67.11074952156314, 68.18081917301302, 63.338551213664395, 64.69421648210096, 64.79076562389251, 62.11178287383049, 57.389319789025095, 60.141391984878055, 62.07174724148166, 66.9158547924411, 61.93372295748804, 56.922647953033454, 60.27352094650269, 60.59847754816855, 66.37579148815524, 61.11089598747992, 62.40721187283916, 68.10187755092498, 62.61614084243775, 59.56746293652443, 68.89873058565202, 64.65205100274855, 63.31395010794363, 60.34071899229481, 58.234178712291104, 61.46476437968593, 62.94279190801806, 59.89221165257116, 62.098250696736, 66.52114668200093, 54.01933308570616, 62.42846327443277, 62.4969635471221, 59.29394037492814, 61.153018320760424, 54.551343764028246, 53.52714230937343, 54.18309204040035, 62.505545693059126, 61.01041270840553, 62.48464338241085, 55.752318597609005, 50.92995666688489, 47.682096881251184, 47.4898301401446, 51.379970196754705, 57.25688488252702, 61.958688843634825, 62.15267750524706, 66.17574276462679, 56.86124324798585, 58.589012007559504, 50.02849401966218, 58.993722161939075, 65.66470107724591, 60.1820198951229, 50.93620108019922, 48.16391298847814, 46.72168101033857, 46.88398868806901, 47.870284357378566, 49.30971968558527, 51.193869421559, 50.84652000857938, 49.57646439152379, 53.46169364067816, 53.215553145254816, 52.80561054906538, 54.163170322295166, 57.36313404575471, 55.662786576055716, 58.2895076659418, 54.66029936267484, 57.472132790473204, 59.70261212318175, 65.88488332686886, 66.67444859781574, 68.61606105681389, 68.30068680547899, 72.25997432585686, 71.66124020853351, 73.4730379043087, 72.99161403409897, 75.10525380411457, 74.20470114677184, 80.02061905399447, 77.14129340264105, 85.12128491555491, 71.44727491563367, 82.18438671481225, 13.537078096020608, 0.5971328709875384, 0.2532191478436993, 0.07438874623227505, 0.10684598402510728, 0.3780168625375917, 66.1141929318828, 70.15481472015381, 54.01312005135321, 32.427481528251406, 41.889693583211596, 29.79956803783294, 0.5325100450746475, 0.07046019373041007, 0.03510215635141058, 0.018023788898942933, 0.03355502263612805, 0.034387951731801994, 0.019438364505467397, 0.03560372943719549, 0.04793980196418782, 0.060050568032649264, 0.027228781555388725, 0.06346114550627048, 0.018247605316461097, 0.07481536527554836, 0.05844488987819322, 0.06291479075087175, 0.06267839133919728, 0.04001813107019952, 0.026570916956951542, 0.2204841648739192, 25.67587241049736, 75.32223147730674, 41.86790481690438, 45.23268653500465, 47.98741417546427, 81.81438169171734, 2.7643028814946455, 0.6732970872713674, 0.07084377395409731, 0.11449680453346622, 0.6440215581847776, 5.788721173040329, 83.64290437390729, 92.31692006511074, 93.74354885470484, 84.75048757368519, 81.69151736843972, 84.70014003015335, 88.30514338708694, 89.63612125765893, 89.60244378735943, 85.90970485441147, 87.49001995209726, 85.63720210905998, 83.01443869067778, 71.11496386989471, 62.460446280817834, 62.031817513127486, 62.06828378861951, 61.83199628706902, 60.98271685261881, 60.398213094280614, 61.136167818500155, 61.0253647835024, 61.359252622050626, 60.47192227455878, 58.27081757207071, 59.02230055101457, 55.25860201927924, 55.22576785856678, 52.68104783950314, 52.446784280961566, 56.06774776212631, 55.29924954137495, 57.00222107671923, 68.65139376732611, 74.0005417793028, 70.03262504454582, 70.8403979578326, 69.58730266940209, 66.51378047081732, 67.05466747283936, 67.2665931332496, 71.81852725244337, 70.32644979415402, 69.57344885795348, 68.46505764992007, 68.4273793620448, 66.5978603978311, 63.723069006396884, 58.78054134307369, 61.74544918921686, 64.44319655818325, 67.65819472651329, 65.2289963537647, 59.03356559814946, 61.8326513228878, 63.44926795651836, 67.53508721628498, 65.01614501399379, 65.42387539340605, 68.84253871056342, 65.02799449428436, 62.68925774481989, 69.68050602943667, 67.07845272556429, 64.17936225091258, 63.40931077157298, 62.82235553187709, 62.451903358582534, 63.69911116938438, 60.990671419328265, 64.37942666392173, 68.625623795294, 58.3804399736466, 63.32673311233521, 64.83619843759845, 62.575916936320645, 64.60149557359757, 55.717185927975564, 55.82334095431913, 56.39127662104946, 64.28900426433933, 63.81405230491393, 64.06271880672824, 57.501346603516616, 53.4932412639741, 50.9531064956419, 49.9302621810667, 55.45077854587186, 60.68387539156022, 63.38352511006018, 62.338123244623986, 68.74928043734643, 59.227503268949455, 58.82543286969585, 54.93142535609584, 61.08306677110734, 66.94449593943935, 63.34517217451527, 54.820892964639974, 51.138807189080026, 49.3067269171438, 49.60742758166406, 50.465673554328184, 51.57732425197479, 52.68416220141996, 51.19161013633975, 52.28819893252466, 56.246780426271506, 54.44048581584808, 55.41947410952661, 55.56512740350539, 58.759305630960775, 58.140418375692065, 59.22525575084072, 57.74208207284251, 59.62758894889586, 63.94817775295627, 68.79794136170419, 69.78324074898997, 70.7293870372157, 70.27644741919734, 75.55603611853816, 74.82436503133466, 75.67393472117763, 77.2025372905116, 77.62085022464876, 75.82822507427585, 81.99890567410378, 79.95728846519225, 87.49952777739495, 72.87323690229847, 86.53334602232903, 15.573320677203519, 0.6149540372913884, 0.20977044057461525, 0.18958688893866157, 0.3564926417123887, 0.19800098582861886, 69.039198506263, 78.21072763012302, 59.09167158988215, 31.194384444144468, 57.035004246619444, 43.96447050955988, 0.4213181744900442, 0.023864977579984455, 0.05119295603024864, 0.03729743492459098, 0.026245549839410572, 0.027278544711730173, 0.028655888445134607, 0.0915454691576381, 0.041277985644316485, 0.01990519550388619, 0.11605502737145271, 0.1450725993321788, 0.18539813467331473, 0.1853132980965799, 0.12395276567868649, 0.11763336001745156, 0.13743523898864948, 0.1723085725379567, 0.19096555608895519, 0.41683983898931937, 31.004316191519464, 88.09892085290726, 46.99132042546427, 75.67758252543788, 57.89266578612789, 90.68367650431972, 4.083385183926552, 1.2008588785125365, 0.5013547507264923, 6.910205252708928, 1.6765794999176458, 6.627510718760952, 86.24846427671372, 95.8003221019622, 100.60364877024006, 92.03219521430232, 86.50731717386554, 88.5363200403029, 93.76325484245055, 92.2338285753804, 93.11707573552286, 89.85978264962473, 91.89681068543466, 90.11505050043907, 88.92612518802767, 77.22103518824424, 66.20138722081339, 65.0745883295613, 66.44456632675664, 67.45642800484934, 66.56176674750544, 65.81924638440533, 62.8081016386709, 65.54155826568604, 65.42157688448506, 65.02162456512451, 63.357111869319795, 60.337679155411266, 58.3906263689841, 57.07415342330933, 57.042135115592714, 53.6642252245257, 57.57721308738955, 58.0018331927638, 60.16529490870815, 72.22154294290851, 77.16383918639153, 73.40139973548152, 73.48485208326771, 71.5860640618109, 67.47647916117023, 69.71693700359714, 68.85416461575416, 76.30080792211717, 72.54290273112636, 72.48995857854044, 68.73898029327393, 70.46960061596286, 70.30176239628946, 68.70050184188351, 64.6638612593374, 66.60077079649895, 66.99484348297119, 71.7374675504623, 71.1678138855965, 62.345395318923465, 62.50241956403179, 64.95768993131577, 71.15372473193754, 65.17076876855666, 67.59604084876277, 73.32620789927822, 66.64554072964576, 63.41917553255635, 71.36266154627647, 68.96952152252197, 65.19730752514255, 65.88567564564367, 64.37444917617306, 65.68968657524356, 67.21040910290134, 64.04170274734497, 67.28426733324605, 69.48669387448219, 58.61051836321431, 70.83988020496984, 65.60503005981445, 64.19172556169572, 66.18980053932437, 58.13473486131238, 60.18480085557508, 61.04363910613522, 68.7030670719762, 65.67509535820254, 66.46812408201157, 60.38560659654679, 57.95401557799309, 54.42623192264188, 54.615258785986136, 59.33957715188304, 63.70814046552105, 67.178237822748, 67.72835023941533, 71.30653242911063, 60.50337183860041, 60.98163820082142, 56.96921040934902, 61.17963552474976, 70.77004632642193, 66.65050645028391, 58.16349760178597, 54.38068536020095, 51.54146594385947, 53.96605160928542, 54.76773308169458, 54.64859501008065, 56.115126071437714, 54.39901459601618, 52.523482307311035, 60.080846278898186, 59.20916618839387, 60.04827491698727, 58.73370824321624, 63.128374930351015, 62.98158414902226, 65.55979336461714, 62.052370732830425, 63.922243041376916, 65.40276519713863, 72.62050290261546, 73.00528741651966, 75.43688235744354, 74.35706953848563, 79.18131028452228, 78.06044593934091, 78.91851148297711, 78.9619948787074, 82.37457459972751, 81.90649463284402, 86.20892678537678, 84.54023284296836, 93.1864232401694, 80.76788548500308, 93.3772151700912, 17.587876473703695, 0.782697813645486, 0.6192326689920118, 0.5420419561766809, 1.0446887295092306, 1.186624229434998, 79.79713024631624, 82.9894688821608, 72.07617205958213, 47.929743566820704, 58.9452769679408, 51.54980490284582, 0.4636670246479973, 0.15470617030176426, 0.19610200708191242, 0.2114192916140441, 0.08997840566500541, 0.09942707365318652, 0.11166428636399009, 0.17938016162764642, 0.2007150974485182, 0.14832738516551836], [0.03313350573843045, 0.015339515446084402, 0.051539074554438555, 0.017903557144886544, 0.058472583956655964, 0.014536572946986605, 0.009573535531789306, 0.02296272710326218, 0.10496734491279049, 0.21187240197773904, 25.362369129734656, 54.74149634761196, 44.35941396221038, 46.72095144948652, 46.43541074568226, 72.09296764866, 0.6237082772197262, 0.29853566940273013, 0.09219454481236397, 0.20025811067992644, 0.09437117680546739, 14.63522897612664, 88.1035884734123, 85.32354585586056, 85.999401615512, 78.8420880225397, 80.84716443092593, 80.70101691830544, 88.5318563830468, 88.72697860963883, 84.54268824669623, 86.56788641406645, 81.71738147735596, 81.51033524544009, 81.13775714751213, 68.3209889934909, 61.83841328467093, 59.88919142753848, 59.273912752828295, 56.40211412983557, 59.30577416573802, 56.24652939458048, 57.25107585230182, 56.55457665843349, 56.17657000018705, 57.655833075123454, 56.56158593393142, 54.72729736758817, 51.761263801205544, 50.32074589883128, 49.47709114320817, 51.58407072867117, 51.584384518284956, 52.90889832281297, 56.51028917681787, 67.29173552605414, 67.35235183469712, 66.97377251040551, 69.32569626838931, 63.57075552786551, 66.93830643930744, 68.69849358835529, 65.29748093697333, 69.01411102664086, 67.8632091706799, 66.57319653418757, 63.79014938108383, 65.10934445165819, 61.286014126193145, 58.67719865614369, 56.02829656293316, 59.19634788267074, 61.5277890236147, 65.25513895096319, 59.47866439819337, 60.057155163057395, 61.53422955543765, 61.25019111940938, 67.10802739666354, 65.21769208292808, 64.84851075756934, 63.70163325340518, 56.70765499914847, 64.33779462691277, 67.24574181341356, 59.09389165139968, 61.38301826292469, 62.35635049881474, 64.55510962393977, 61.815173241399954, 59.35370160687355, 59.389493234695934, 60.71725476172663, 62.52295317188386, 66.5111917065036, 56.85512435051703, 60.88745424824377, 59.91562820249989, 63.20149967747351, 53.82751741716939, 52.57512815536992, 55.63864046527494, 59.78971619759837, 61.81899755231796, 57.00144444742511, 53.86750598107615, 50.01835861513692, 47.65042374210973, 47.81498286031908, 51.745409580969046, 52.72582169502012, 59.93429083977977, 60.95391881081366, 62.00987577438355, 58.34658599668934, 56.13176084333851, 56.767455454795595, 52.847030778085035, 64.79071855545044, 60.13955631563741, 54.30024147033692, 47.88500501263527, 48.29773641401722, 47.20979644406227, 46.710749364668324, 49.0781194163907, 49.95185090649513, 48.11020397370862, 52.5588934652267, 51.680035437307055, 50.50924716457244, 51.812725297866336, 50.91074097541071, 52.62263982526718, 53.26093496814851, 54.892413462361986, 56.97367406660511, 59.8962869951802, 61.02920478390109, 66.38348717843333, 69.03424063036519, 71.10568354206701, 69.43817415545064, 71.67901639015444, 71.55403398698377, 75.90489956640428, 74.69720963508853, 79.85525192752962, 73.74224585871544, 80.81999809511247, 74.2634190282514, 86.21448086154076, 71.35427551884806, 83.49887494117984, 29.142406294422766, 0.19408002525808352, 0.08835971550715548, 0.14853488774068896, 0.4724428376122829, 0.13718239933011994, 49.8524502015883, 76.06048430165937, 56.03603932165331, 40.72866024509553, 31.010931268815074, 42.050718645895685, 1.4074138335643278, 0.06082385718341797, 0.03764765968005504, 0.13293660215793118, 0.03067715397675432, 0.05998125239726036, 0.08344347648803266, 0.022893549363699653, 0.06360835696180021, 0.017695368921023705, 0.021360057759128755, 0.0691428519184551, 0.06414774414752761, 0.04914801455132904, 0.03425168001183099, 0.044926253387764584, 0.010605904127230809, 0.04450893465189203, 0.0626678537997988, 0.13283040704986743, 36.56002013914047, 64.92834668005666, 49.23046035151328, 42.26440937288346, 58.398388739555116, 75.06475925445557, 0.7357612612747377, 0.3636745627849333, 0.1092827181902624, 0.3390394734038461, 0.07925112927032095, 17.307487803120768, 94.14373259390555, 88.70556246849799, 90.54921765481272, 80.50363540649414, 82.8783481351791, 83.91284188916607, 91.80583523165797, 92.4086799929219, 88.32436300093129, 89.89957901739305, 84.0697523855394, 81.02605588974492, 84.57042724855485, 71.04213330053514, 64.79801024160078, 62.72348826931369, 62.18149908127324, 59.984916871593846, 61.24848096601425, 58.46884627496043, 61.143671312639796, 59.942343465743534, 59.941719808886134, 61.39903330033826, 58.60394054843534, 58.300619740639966, 54.019690021391845, 52.14991184972948, 52.92082625050699, 54.4173595213121, 54.60851623165993, 53.85136542781707, 59.419656261321045, 69.76204426057878, 68.55610370635986, 70.24247184876474, 72.73054107542961, 67.05294162996354, 71.79048230571132, 71.30989782271847, 66.44400935019216, 71.79158056935957, 71.2791778195289, 69.74167146990376, 67.05145897403841, 67.38551155213388, 62.2033662949839, 62.03934846385833, 58.385393927174235, 62.88732959378151, 64.38740084248205, 66.23368401681223, 64.21994701508554, 62.930836523732836, 63.00823665434315, 64.47808211849582, 69.98960448849586, 67.50973301549112, 68.52600343765752, 65.53399201362365, 62.782115936279304, 66.49106210277927, 67.91773011607509, 60.00161832378757, 63.77571505884971, 64.58291138372114, 67.39817296305011, 64.5887557152779, 63.522196585132235, 63.032622029704434, 64.36926380280526, 64.57134823645315, 69.63333560574439, 60.48206160145422, 63.166629806641616, 61.710787204004106, 63.70596355007541, 54.724045722715324, 56.75211114268149, 59.111212838080625, 62.09052362749654, 63.71487125273674, 61.06458064048522, 55.955450304092906, 52.49033043461462, 50.944822449837964, 49.81665072902557, 54.83603331350512, 56.173632144927986, 61.12908009559878, 62.46966777309295, 65.27197376374276, 60.329834415066635, 57.86045528227284, 56.58259022620417, 54.82647449739518, 67.92860292619275, 63.8231796603049, 58.19102479565529, 49.98091959184217, 51.569679552508944, 48.18743936477169, 48.11835073655652, 49.373234625785585, 53.26531625563099, 51.71888651386384, 53.73528288256738, 52.96479602013865, 53.78374768841652, 54.03606983923144, 52.518010600920654, 56.33340204915693, 56.020742077981275, 56.69602909395772, 60.23528175969278, 63.53859993719286, 65.05509807217506, 68.5882749865132, 72.61974980754238, 72.34250883902274, 70.26804570228823, 72.96746007857784, 72.4594739175612, 79.39948035824683, 76.80955502294725, 81.2062809544225, 75.08660685631537, 82.69519698235297, 76.19003234371063, 85.9038919018161, 74.90142391573998, 88.48760420276274, 34.14283990859985, 0.2894312047189282, 0.17833788368490436, 0.28978017309019644, 0.6820101423128959, 0.33628615340398205, 51.693214601086034, 82.32101855739471, 64.41009959866925, 41.77154002651092, 36.07641150874477, 55.32797305814682, 2.3054593609225367, 0.18068453357104333, 0.09957084537393625, 0.036645072752669934, 0.03855620931473471, 0.007943950167241236, 0.03684298773746818, 0.025820219739069863, 0.052745831574523644, 0.039349772982419505, 0.1502460370501203, 0.11387772888185517, 0.24406323269490274, 0.07533612120295725, 0.16602130426514536, 0.1362226903438568, 0.10075445121694958, 0.1276443671855715, 0.18329292505739198, 0.3745112748396012, 50.80872404959894, 71.60525229669386, 56.54650049824869, 66.12014708980438, 65.04588050227012, 84.37449701370733, 1.2121033332040234, 1.341806921747423, 0.20203541934249863, 1.4559487517802947, 0.14183465211141494, 18.441539156821467, 99.74199033552601, 91.61880093236124, 94.62677248062627, 85.93353717557846, 90.084001018155, 89.32401826304775, 97.40710535357076, 97.50031655834567, 92.43875672740322, 94.31155512409826, 90.88825948776739, 85.12842362926853, 89.7809979223436, 75.51932273372528, 67.9723765773158, 66.95365859616187, 66.07507905652447, 64.69464009807956, 66.21936736568328, 63.49023319059803, 66.1528439675608, 63.7229670247724, 64.0499318799665, 65.99420762831166, 63.78005320026029, 61.05436678855651, 57.713095757269095, 57.7676010131836, 56.32996213051581, 57.51747538966518, 57.44887313535137, 56.714703498348115, 62.00996991126769, 72.70604979607367, 71.20578242886451, 74.79111117701378, 73.21938607000536, 69.0454742985387, 72.89483347246724, 73.02462470146918, 69.16853474032494, 73.81710821582426, 74.15380447141587, 71.43782200351839, 68.39248595699188, 73.06368366364511, 66.35876055686705, 66.52524948120117, 64.25689574210875, 66.05487100539669, 68.98593271932295, 71.76796790092223, 67.73290018881521, 66.73839892110517, 66.34828782850697, 66.1788571265436, 74.20851369057932, 70.9573002784483, 70.05076992896296, 69.61307264143421, 64.2854388298527, 69.19850164844145, 70.77756158767208, 65.2160015413838, 66.71637089021745, 66.4951649019795, 70.34320615953015, 69.02259903569376, 65.28706704416584, 65.20730956908196, 67.00930133942636, 67.24975047572967, 72.00538896745252, 62.83883340897099, 65.91503066401329, 64.75833938967797, 66.92113430269303, 56.381043157269886, 58.200897401379, 62.05976047823506, 67.65063239682105, 67.0490663282333, 63.62508819949243, 59.71170809961135, 55.62906203731414, 52.99827737192954, 54.51051581290461, 57.50815191576558, 55.89432408732753, 66.41043386151715, 66.40965723222303, 67.65278970041584, 63.73314949773974, 60.368183428241366, 59.088894551800145, 56.70085360926967, 72.58736671939974, 66.4264371318202, 60.01886498543524, 53.7862580053268, 54.313338264342285, 51.462445874367994, 51.86645784685689, 53.762735551403416, 57.14850587229575, 54.51678768281014, 57.80436538880872, 55.57476466701877, 56.37199424928235, 58.07364786824873, 55.75085163116456, 58.50066454179826, 59.357863241626376, 61.614226295102036, 64.25749194237494, 65.36365524415048, 66.59263580076157, 73.45017048620409, 75.77738331210229, 78.36777933182256, 75.28496111592939, 77.72931944939398, 75.17231064458048, 82.04003564773068, 81.52303588005805, 85.69762229919435, 80.89431132039716, 85.8388590043591, 79.1354577772079, 91.74037871822235, 79.42248113693731, 94.56887045214253, 36.27464809725362, 0.52469662240436, 0.748272457670781, 0.5040121258747193, 1.786850563460781, 0.8085326273595134, 60.11938748821136, 87.06998901982462, 74.80351371149864, 56.78393725425967, 44.700534651356364, 68.86860678272863, 2.197358593825371, 0.1994904905797974, 0.21909547729357598, 0.2149159160833205, 0.14127292580181552, 0.1031353299115454, 0.11329213893341442, 0.24260392712969936, 0.13460825197398663, 0.1484267467692975], [0.05799400499991833, 0.033984208073947704, 0.03991322298984855, 0.04833405379266028, 0.08277050655094847, 0.0946986104451841, 0.0678694988751123, 0.003858399676016322, 0.047110534768791935, 0.09212440946289609, 28.974109157439205, 43.952519047644834, 36.41832059429538, 44.61458767614057, 58.2110563401253, 71.04333354580787, 0.07921650975702271, 0.2563754147699764, 0.01968206856549988, 0.13181930888564358, 0.06412392264352211, 32.89110568261916, 96.53334248450496, 87.05809639346215, 85.9986642099196, 75.37942747915946, 78.64033699035645, 81.81412281528597, 87.90314751286661, 80.57358695614724, 84.95299170094152, 83.30552562590569, 84.72617672335717, 78.7720109570411, 75.17277348426082, 67.23234299690493, 60.92708979883502, 59.78796682050152, 59.76811570505942, 58.037852318056174, 57.076079307063935, 55.01330483344294, 56.01283850208406, 57.36819782564717, 57.027834153944454, 54.75758591005879, 54.317601880719586, 52.699855604479396, 50.43337675832933, 49.16384673887684, 50.59555892021426, 50.97952758112262, 51.94784310556228, 52.81985659753123, 55.089489029299834, 67.27365339955976, 69.6586976512786, 70.01245621711978, 67.01116838762837, 69.19330058559295, 61.46683931350709, 72.40717303368353, 68.51516200650123, 65.26231296600835, 67.97225106147029, 66.87096718818911, 64.22403804717526, 58.914941357028106, 59.88135845430436, 54.5214553033152, 56.58502994045135, 59.76619374367499, 63.6110931827176, 63.23189020156861, 63.692635336229884, 58.019436790097146, 60.145832107913115, 65.97570973057901, 63.58987708245555, 62.84249298034176, 63.833138558172415, 57.97960119862711, 62.511237052179155, 66.64911793124291, 62.098364445471, 59.518782400315814, 65.15622069758754, 64.57479599983462, 61.855887443788596, 61.33074875800841, 64.84045028686523, 61.034029299213046, 60.3069003166691, 61.9046974182129, 63.347996281039336, 64.84119553719798, 58.386817747546786, 59.522614555974165, 60.88831716968168, 57.43914173495386, 49.543422345192205, 54.66823431753344, 58.46442184140606, 60.8915021342616, 56.22764318220077, 52.868886224685184, 51.45953939807031, 47.19844902715376, 49.1358841619184, 50.28511508818596, 56.58252354591124, 56.77264475053357, 59.7616437942751, 61.56227057979953, 59.848869462167066, 56.81802265105709, 56.76636111351752, 47.457600024438676, 64.55949875616258, 62.64181275521556, 56.26560388072845, 49.89274078799833, 47.529626507912916, 46.616059426338445, 47.050336407076934, 47.68763134556432, 48.71700248410625, 50.52191249785885, 52.47455466178156, 50.23908215184366, 51.83731855884675, 49.91980514218731, 49.37235993723716, 50.49356160625335, 51.67831351680141, 54.12380149287563, 57.310358555086204, 62.511982302511896, 65.00254615660637, 67.14430932075747, 70.31934245940178, 70.48783179252379, 70.70397792323944, 72.4721117942564, 70.35701290253671, 74.95312075461112, 72.05568159780195, 76.42263673966931, 75.4026008421375, 80.33892723821825, 78.62520448623165, 80.94192104954874, 72.71089000086631, 76.77275534599059, 45.705077186707534, 0.17702529927895916, 0.07207264027167713, 0.05002303251756295, 0.09246541818063106, 0.5286301468168536, 33.909039189738614, 86.13547648152998, 53.358821638168834, 47.25336613193635, 25.20456433296204, 42.1707510179089, 5.432521912359423, 0.2642133675755993, 0.12249189729411757, 0.014240564233923872, 0.02314468639181747, 0.04833709133128005, 0.0013211823064803838, 0.03710382535392719, 0.04373165801347744, 0.02320787332381212, 0.025296282631555395, 0.060803958049584786, 0.029604314871492888, 0.07885503116995096, 0.06093010974807605, 0.03633840392614084, 0.0382524018266028, 0.08032258750209886, 0.028117575697721015, 0.04214341218973841, 44.55260246030746, 54.14874384480139, 34.04285084816718, 46.784890005665446, 70.47384462048932, 75.01705538841986, 0.12822212005454686, 0.8555877701409402, 0.01832013660591216, 0.1330990740849126, 0.08453691378235818, 36.055136572930124, 98.96631809972949, 88.14084314530896, 87.66014099121095, 75.31545362164898, 83.25626850128174, 84.55116056626844, 90.47216661514776, 85.74989180411063, 87.83014435921946, 85.98442600619408, 88.56205863337364, 82.72050411470475, 79.36614021178215, 71.19121474604454, 64.94988833704303, 62.2474302014997, 62.39589191252186, 61.45844544133833, 61.51067572255289, 59.531051574214814, 59.968584122196326, 60.6444477265881, 59.131515026092536, 59.25170821528281, 57.180104486403934, 56.44306367443454, 51.85606356590025, 54.85831629845404, 54.22519476183, 54.758417452535326, 55.67916639389531, 56.6580330940985, 58.16438797981509, 72.20353141907724, 73.02234972676924, 69.7269468922769, 68.16779690404093, 70.40212800425869, 62.38403458749095, 75.88745286387783, 68.30456995194959, 67.86045566681894, 71.55298279177758, 70.09015052549302, 67.25892882193288, 60.60745193112282, 62.55503423752324, 56.05715736266106, 60.268739577262636, 64.2538990512971, 67.2509350315217, 66.0282616461477, 66.8434399943198, 59.06732543822258, 63.35852000021166, 66.91148527206914, 66.3980156375516, 65.18448921941942, 65.0422562322309, 62.032135225111446, 66.11107072522564, 66.7312837416126, 62.46471774193549, 63.38412523269654, 66.16787449006112, 67.25444163045576, 61.15468140571349, 65.77908915858116, 66.61774681460473, 64.6391660167325, 63.71961732064525, 63.52547176422612, 64.21920960949313, 66.5656969624181, 60.381645002672755, 60.351854601214015, 62.67292499542237, 55.882325556970414, 50.896345876878314, 55.60412753012873, 62.239569771674375, 63.18071111556023, 60.947745000162435, 54.099796587421054, 53.12870010252922, 50.30988093345396, 51.64107453438544, 54.54134956482918, 58.46143691770492, 60.372925573779696, 63.4062905465403, 64.74873350512597, 62.8898242212111, 58.61538602459816, 58.964610330520145, 52.11579899634085, 66.10891342163086, 64.33729256353071, 59.39316849554739, 51.94322255349929, 50.16774992788992, 49.851991284278135, 50.3055545591539, 49.23364923846338, 53.037701114531494, 53.431381563986506, 54.19317253174321, 54.501247252187426, 55.814397950326246, 51.80211528655022, 53.130802492941584, 52.00738076240786, 54.93690882959674, 58.32085917072912, 58.92238601561516, 64.32339952838036, 67.16176386802428, 69.09167981916859, 72.13183833706763, 71.70764969241235, 72.43073863367881, 73.45136288673648, 74.56047581088158, 75.92767284762475, 74.40592658135199, 78.2046244221349, 80.16826491202079, 80.3384957774993, 80.28202149175829, 79.54789500082694, 76.78763681842436, 80.53997224377048, 54.219119010433076, 0.13222006480059317, 0.0720419584503097, 0.23562328799838023, 0.839280822584706, 0.5973431468009949, 36.27930002827799, 90.34007687722483, 60.44223385472452, 51.001637981783965, 33.037202204427416, 56.17490691523398, 7.708726765648012, 0.13357850722968578, 0.1327183130647867, 0.044346968342940656, 0.0660894706004089, 0.05390930462688689, 0.04226186853503028, 0.056132710118207245, 0.031989797754513646, 0.034877271241238045, 0.1647489241534664, 0.18899989704931938, 0.13327777175413025, 0.13921204203319165, 0.21295862272381785, 0.15894246798369194, 0.18061659689391815, 0.23856164887547496, 0.13417574937545484, 0.3351561124286344, 59.05514647883754, 59.30918662778793, 48.51407081850114, 65.61729138897311, 76.27005653996622, 83.37830128208284, 0.20293016407278278, 1.4436561662343241, 0.0831144264027957, 0.6565060947210558, 0.23368038177009554, 38.06080918158255, 105.872678449077, 93.28146226944463, 94.52031150940927, 81.63567066192627, 88.73893399392405, 87.25323430953488, 96.61658302430185, 89.71776147042551, 91.33721397769068, 88.1254360752721, 93.34443200019099, 85.0808923475204, 83.90282415574598, 74.89239461960332, 68.46566953966695, 66.6997008169851, 66.67258939435406, 64.9986473206551, 66.12358308607533, 62.270301541974476, 63.18202903193813, 64.11965200977941, 64.83297032694664, 61.73090111824774, 61.8739225018409, 61.104396620104396, 57.16921990917575, 57.36145919369113, 55.99487796906502, 56.91088868725685, 56.787777254658366, 59.45655007516185, 61.452938433616396, 74.10552009459465, 78.8331057948451, 74.34474545140421, 72.49338673007104, 72.8147465182889, 68.14812229525658, 75.5234569118869, 68.10325822522564, 71.58473830069266, 72.86186202879875, 73.30574097171908, 69.39482412030621, 64.68018224162441, 66.67380532910748, 58.70497295933386, 64.03564660779892, 67.33383040274343, 70.3540397459461, 69.96920031885948, 69.26828845854729, 62.6980830777076, 63.84177561729186, 70.27092472199472, 69.27320711074337, 66.16661148686563, 64.9350147093496, 65.25793952326622, 67.73452405006655, 69.32462153896209, 67.424484222166, 67.17400950770225, 70.24157754836544, 70.31034454222649, 64.9115393238683, 66.6632463086036, 67.85301885297223, 67.41042644746842, 66.3845540631202, 65.38902121205484, 67.4289321899414, 71.14471112528156, 63.040945299210094, 63.2136001894551, 64.05896117610317, 60.56866753485895, 53.73363548709501, 60.131946917503114, 65.01678436033188, 65.12156655711513, 61.97256226693431, 57.61957468525056, 56.308094916805146, 54.80614877516224, 53.75211769534696, 58.83964361683015, 61.83252972941246, 61.441261537613414, 67.79331253420922, 66.34009791958717, 65.75022443648308, 59.266848564147956, 59.004120365265884, 55.06191084461828, 68.28479336154076, 67.06281815805744, 60.93128281254923, 54.804042462379705, 53.28106457187284, 53.0888762781697, 53.156650912377145, 53.55811726662421, 53.665484305351015, 55.569975453038374, 58.39424671665315, 55.704395078843646, 58.33075923304404, 55.183386648854906, 56.26106569843908, 55.7918913902775, 58.56202610077397, 61.95300925162531, 62.286830409880615, 68.2406980760636, 70.92272066300916, 71.35863719447967, 76.09122783906999, 75.09817000358336, 79.11954079904865, 76.01358844387916, 78.23008060455322, 79.64425979122039, 80.84060622799782, 82.00627973002773, 85.19212292086694, 87.02165757456135, 84.9280297371649, 83.52877909137358, 80.9111539779171, 85.25956415360974, 57.99088585761286, 0.25819706460160596, 0.45668618633381786, 0.43010299664831936, 1.888237703711756, 1.398950339325013, 41.65839533652029, 98.75247047793482, 67.63207174116566, 65.18221816708966, 39.22310160052392, 72.1643312515751, 9.259846191252432, 0.3561840002094546, 0.2354591459997239, 0.07851989068571599, 0.18534861474988923, 0.14649848814212507, 0.16186529259768226, 0.11802693768855065, 0.19822279892621503, 0.10053135875251987], [0.0017426692788684443, 0.04632729413588682, 0.050655112511688666, 0.08212950546294451, 0.03766450212307034, 0.07657693849215585, 0.02910614321609178, 0.059655033006903634, 0.0906069348416021, 0.28000820067621046, 31.181950530698224, 36.99239084797521, 40.830665403796786, 46.30962425662626, 61.685272186033195, 62.08317702816379, 0.11477753745331881, 0.6752943091334835, 0.05951018876305992, 0.22448096814895832, 0.15124118526376065, 43.71841238391015, 93.3365245019236, 86.9224843671245, 84.63855097370764, 76.44100912155645, 78.05064001391011, 84.88541710761287, 89.01352344020721, 85.47207816954582, 86.05679373587333, 83.40390651456772, 82.99695276444959, 79.50557262666764, 76.19409591920915, 70.76537086117652, 64.34685137964064, 58.802592908182454, 58.794049985947154, 59.75861572450208, 56.697088133904245, 56.79172708142189, 56.25823766954484, 56.168607588737245, 56.727090343352295, 57.01762814675608, 53.56743681815363, 49.431532813656716, 48.25724186435823, 50.87873443480461, 49.73269631785732, 52.040163932308076, 52.10909174334619, 51.88943901369649, 56.618197502628455, 67.00686162517917, 69.38319821511546, 65.97214037372221, 66.82371047235304, 66.26995025142547, 65.30154843484202, 63.74717589347594, 79.99428426065754, 65.00859445141208, 67.73628127190375, 65.71742165473201, 61.18299307361726, 58.12405424733316, 53.67722003690658, 55.67474196034094, 56.27269944837017, 61.356718770919315, 63.362634566522416, 66.7130054966096, 62.6361253184657, 59.7623380537956, 60.13738724493212, 65.13682065471527, 66.66031237571471, 62.27564381014917, 63.85240524045883, 64.5511519524359, 67.13078498840332, 63.3209829176626, 61.9782026352421, 64.40488676871023, 62.18641773346932, 54.65320379503312, 52.46795723515173, 54.711372544688565, 61.29671827439339, 60.67621108024352, 61.36929388969176, 61.07994456445018, 60.1869228578383, 63.866549307300204, 58.60575268345495, 59.8979579248736, 62.029413100211855, 52.63196329916678, 46.20983523707236, 53.91626496468821, 55.97425414669899, 64.40303148761873, 53.885038975746404, 53.056814824381185, 49.93685960769654, 47.97990283658428, 46.88408282495315, 52.69621172258931, 53.07782303902411, 56.30114839922998, 60.61548886760589, 64.04401694574665, 54.47155490998299, 57.938655576398304, 55.137592977093114, 47.30707122433571, 64.17298447701239, 57.561056844649784, 60.335541463667354, 51.144227904658166, 46.447938796012636, 45.50246715545655, 47.3197953931747, 45.02415372479347, 49.176343410245835, 49.632471915214296, 52.32001719936248, 50.49735061583981, 51.17867808188162, 49.709185631044456, 50.12977746225173, 49.54732902588383, 53.728826661263746, 55.20226109412409, 60.04677657158145, 62.144416993664166, 63.44333733281782, 67.54608554224815, 67.2769089668028, 72.29373808830016, 72.91210759070613, 68.82721793267035, 74.01020649940737, 74.66385379914315, 75.12169637987691, 74.8559558007025, 77.53835493518461, 72.26391238550987, 78.11830089938256, 74.26592150042134, 78.74042018767327, 71.6470882969518, 70.53002865083756, 1.4827571713155316, 0.0601979595188412, 0.014694864906731152, 1.1051119839952839, 0.14993449973483242, 25.597344598462506, 86.43766372434555, 57.38915504947786, 48.31390834623768, 24.63122952368952, 35.520752860653786, 9.49019326317695, 0.05207342854250343, 0.07074589856089124, 0.027995786869958527, 0.04285700010856794, 0.00986864600676082, 0.04096000936002501, 0.03925907966350356, 0.059398014338747154, 0.03250688029032561, 0.05201876816910602, 0.04778585276536403, 0.018414581840437268, 0.09106546910780092, 0.04686360930903785, 0.030079005932014798, 0.07250981600654703, 0.05172384730089576, 0.009319075597299924, 1.3308918235763427, 49.73467319242416, 47.48044390832224, 41.720451155016505, 51.1744733010569, 70.08862080112581, 68.03912747290828, 0.6888253830613629, 1.2705932269173286, 0.04138869301025425, 0.11110177098382866, 0.12241561025861772, 46.18268066836942, 98.09975670230006, 89.29912690193423, 86.4532276891893, 77.40699475811374, 80.86375605675482, 86.91824820733841, 90.90972269735029, 88.86128056433894, 88.12226680017288, 85.29326515813028, 87.28690393509405, 84.05045432429161, 79.77740856908983, 74.75588829286637, 66.18907097847232, 60.698650959999334, 63.003380760069824, 63.83647649518905, 60.96274414370137, 57.97978947239538, 60.34668883969707, 57.73989731265653, 61.777055648065385, 59.176124142062285, 56.757276904198434, 52.972825111881384, 50.493875395867136, 54.0948308667829, 53.77549502157397, 55.98589574137042, 54.61612562979422, 54.15113256823633, 60.01538192072223, 68.89072110576015, 71.69812617763397, 66.8235614222865, 69.20327909531133, 68.4363772792201, 65.7334170802947, 68.29742339349562, 78.6934615719703, 65.51243074478643, 69.6900373889554, 66.81175508806783, 65.50219335863667, 63.208865888657115, 57.52730092694683, 56.66336751753285, 60.50030454512566, 65.20227716815087, 64.89091157913208, 69.87772280170073, 67.14195589865407, 61.057049689754365, 60.40737967337332, 66.60562669077228, 69.17062144125663, 64.57786721567955, 66.5811118771953, 65.68145744262203, 68.4916042512463, 64.96018848111554, 66.78786785371842, 68.06368935492732, 64.86876979950937, 57.48859497808642, 54.11288553668607, 58.09529150685957, 62.89497429324735, 62.350745431838504, 63.607025684848914, 63.324516973187855, 62.589664843774614, 64.28255588777604, 58.82821383014802, 61.86039816948676, 64.62431592326011, 52.970860004425056, 47.29627686162149, 55.60932467060705, 61.41045916465021, 66.06858361151912, 56.29721033957697, 55.269317934590006, 53.10253789347988, 50.01152584629674, 49.639053652363444, 55.40049376026277, 54.331396856615626, 60.24723322160783, 61.4054306860893, 65.9927563513479, 56.99336828724031, 59.135154985612445, 58.38363670533704, 49.91869118905837, 66.50499436163133, 62.202538674877545, 62.78039401577365, 53.39255794402092, 49.612722781396684, 48.12705839833906, 49.12425825672765, 47.68607416460591, 50.24902928260065, 51.5181121518535, 53.55432825703775, 53.62736278964628, 53.94957765456169, 52.99656329616424, 53.94714186268469, 51.262585424607806, 55.07303860879714, 56.59662838905089, 63.609806645301084, 65.97636868876796, 68.83528232574463, 68.76853143015217, 70.07302545732068, 74.42586791130805, 75.8029571656258, 72.52973141208773, 77.85029319024856, 77.20998194909866, 76.51866420622795, 77.78522106908983, 81.11351689984723, 73.45043720737581, 83.13622043978783, 76.9886661344959, 82.28985924874583, 75.39685064746489, 76.75321409779211, 1.8053537318783424, 0.028138472661075574, 0.03563607366935861, 1.620311261184754, 0.22028200959246005, 27.251845444402388, 91.51309305621733, 65.0994247774924, 47.84569501876832, 32.44953113217508, 52.94704729510892, 9.133423297635971, 0.012808761225202152, 0.021037147868604913, 0.05252224115294315, 0.025491085384161245, 0.020863793662659103, 0.029177745623934655, 0.027414548300927686, 0.026784086667542017, 0.007036492686658617, 0.08968612780013392, 0.13990276222748144, 0.12715325886083226, 0.18096987067932085, 0.16497511927398945, 0.3091522077879598, 0.11302753216436795, 0.1362372766579351, 0.214533714817897, 1.596710972728268, 72.79842161363172, 51.930733726870635, 55.097726006661695, 63.887333946843306, 78.72420510938092, 74.78718096210112, 1.5469776478505906, 3.718463552574958, 0.1633069781406272, 0.3670365549623967, 0.3839040950181023, 50.874078581410075, 103.28576549406975, 97.16538536933162, 92.40764448719641, 83.55629844050254, 85.70856571197511, 93.1277681166126, 98.63206155838506, 93.64782733301963, 92.39146863260578, 89.50373341960292, 90.28956459414574, 90.39317007987731, 82.70108053761145, 79.8030138015747, 71.27830705335064, 67.04255519374725, 67.09155344193982, 66.86209478685933, 62.96628690535023, 63.502820076480994, 62.80394000391807, 64.08339361990652, 65.59182736181444, 64.32800439096266, 61.645750384176935, 58.43357632237097, 52.917394176606216, 58.900342295246745, 55.38589469848141, 57.04249989601874, 54.83084401776714, 58.3056168402395, 62.43826527749339, 73.63572212957567, 75.54415918165638, 70.57224904337238, 72.69221167410575, 72.10834333973547, 70.81098802628057, 77.3006671474826, 76.90395862825456, 63.80406987282538, 75.6723108599263, 69.00075927857431, 66.72546294427687, 64.71742906878072, 60.246291852766475, 60.25806680802376, 62.50988775683988, 67.43906759446668, 69.54497245050246, 72.62832410873906, 72.62321718277471, 65.27366038291686, 65.11761280798143, 69.34819498369771, 70.73046961138326, 66.11877426024407, 69.33996585107619, 69.40739923907866, 71.29968397078976, 68.35250131545529, 67.80795866443266, 70.35840142157771, 67.85141852594191, 59.900942848574736, 56.44004344940186, 60.087196596207164, 66.99722043929562, 65.23669204404278, 68.17808920337309, 65.55510220989105, 65.34773042125087, 66.7890759437315, 62.19195219778246, 65.66159456006943, 66.66992218263688, 53.65641970788279, 52.97889301853796, 59.77592514407251, 61.927847246969904, 67.48743826343168, 58.37054775607202, 58.30600907725673, 57.2540254746714, 52.51835969186599, 53.15107330199211, 58.4732001058517, 58.207432070086085, 63.79566815591628, 66.27146428631198, 70.05615926557972, 61.29994246267504, 59.23175119584607, 58.617586474264826, 52.61717596361714, 70.16705251509144, 65.21895508612356, 65.65814679668796, 56.828338484610285, 50.75574459568147, 50.62705947506813, 51.95368351474885, 51.83238029479981, 54.12781799993208, 53.78749355193108, 56.55722033592963, 55.623794294172725, 57.33550487026092, 57.83540702635243, 56.64912146906699, 54.805697702592425, 59.31030450328704, 61.11017819373839, 66.90760212559854, 69.99269531619164, 71.8950056260632, 73.14860297787574, 75.00090306805026, 77.14220339252104, 81.62516655460482, 75.25324483071604, 82.24606206340175, 80.60477764375749, 81.69011315991803, 81.83316984484273, 85.99083515905565, 77.0998731736214, 88.21526619695848, 80.8176838967108, 89.54531054342948, 79.5213483995007, 80.81260834970783, 2.157003288307498, 0.22953681137052276, 0.5145262842697482, 3.4398936360113086, 0.7380592186124094, 31.394794025728782, 99.57330488389539, 70.07779505945021, 68.1980932912519, 37.99157934804117, 68.25336733172017, 13.805911464075889, 0.19190045914823012, 0.20235515379857635, 0.08895759350590168, 0.08682170972949074, 0.09194051771755181, 0.1560455524633008, 0.09713812550950436, 0.13446836431901302, 0.10813814452699116], [0.036523567377439434, 0.02466206333690113, 0.0628399171475922, 0.06994611042882166, 0.08476605068051046, 0.15192853467118356, 0.045955435057441076, 0.05628510032810512, 0.18047931393788708, 2.0244211703538895, 40.99389876088789, 28.882441405327093, 44.63820818931826, 46.26475234185496, 69.37574571178806, 60.852913856506355, 0.04436473392190472, 0.4679303345901351, 0.022085445347212015, 0.06857060722165531, 0.21437242266631898, 52.54494159452377, 95.95273756211805, 86.73933321429838, 79.84953311181839, 73.84092484751056, 77.98563065067415, 81.30808999461513, 86.5037948854508, 84.32341990932342, 82.22454394063642, 81.74950568906723, 83.54417047192975, 77.83436836734896, 77.33783552723547, 72.56453068025651, 67.94723418451125, 59.090549792012865, 59.150146284411036, 56.311319105086795, 57.769966202397505, 56.30776936008085, 54.609500746573175, 53.41748460646599, 56.71964960713541, 59.32198139929003, 53.954300188249164, 45.837951398664906, 48.25307238486506, 50.30622528445337, 52.42189291984805, 54.30386574037614, 53.292306084786695, 49.0133414729949, 59.12257594446982, 64.87821094451412, 67.65435864848476, 67.90294278052546, 65.93593689703172, 68.0794886619814, 67.70613393475934, 58.000272089435214, 60.6293583685352, 83.45972968686013, 64.41692844513925, 67.18030883419898, 61.327391209140906, 58.31671322545698, 55.25019637999996, 59.44528502802695, 57.460432360249186, 61.56596153013168, 61.10153721224878, 66.2669143369121, 61.64990025181925, 57.858925557905636, 53.310203859882975, 63.48340434412803, 60.80648868314682, 59.3224246271195, 64.13180743494343, 62.251423174335116, 65.98209534921955, 64.56416245429747, 62.914558687517726, 63.6537411136012, 58.5626026891893, 57.471591503389426, 50.186859715369444, 54.684951459207845, 56.26436833412417, 52.6801888404354, 59.33756497598464, 64.41392783195742, 58.048066169984885, 61.42874917676372, 62.92569429643693, 57.92499003871795, 60.99243256353564, 53.06722087244834, 43.850007903191354, 52.12071764853693, 55.252298770412324, 59.8704856441867, 55.910150850972826, 53.839398276421335, 51.025282029182684, 48.33728567246468, 48.769236687690984, 51.597438166218424, 52.37837030041603, 59.245169624205566, 60.18852710723878, 62.95248800708402, 59.682584501081905, 64.315970559274, 44.51341405991585, 53.33447156413909, 61.30556321913197, 58.59919448052683, 60.24013373159594, 55.30464280036188, 49.21895996216805, 45.854566558714836, 47.58298250936693, 47.38695421526509, 46.32194049896733, 48.278818822676136, 50.918366063025694, 49.525112721227835, 49.962598200767275, 50.91012124092349, 50.4655009700406, 51.518065083411436, 51.29212087200534, 55.681009907876295, 59.17762640983828, 64.62551616853284, 67.07688377749535, 66.38260856751474, 68.77991414839222, 68.10350925691667, 72.23659699962985, 70.75330565052649, 73.15265086389357, 69.853145230201, 75.45147357448455, 68.97389888763428, 68.12164629659345, 64.03230867078229, 78.0800421007218, 70.59428491900044, 79.27132867997693, 67.65692387857746, 81.76616791755923, 7.35100954771042, 0.2634961867044049, 0.07552981887373232, 0.7873585087157066, 0.3672471678545398, 23.453667317667318, 87.18941734683129, 57.29435920715333, 56.77149549607308, 25.517543977306737, 24.59403172616036, 8.886298287299372, 0.15900911763310432, 0.0901625119149685, 0.08271360920081217, 0.033188759829969175, 0.04590334107859, 0.07880779418853984, 0.029877806345241207, 0.07062667995811471, 0.02216502081512684, 0.03605090261947724, 0.09455260174769549, 0.05457618416497304, 0.08514407676674667, 0.06377268282155837, 0.04899237612863222, 0.01343917593570246, 0.08060911204665899, 0.17094986963896983, 3.6482357209728615, 56.708874856272054, 40.46745392584032, 50.786135119776574, 55.0725483125256, 79.4020377435992, 66.34373003436674, 0.41176119699112834, 0.6266948556707752, 0.03042829989065086, 0.15256041931288858, 0.15980794815526855, 54.662342917534616, 98.17023384955623, 89.63863157456922, 83.10121720837009, 76.03850333921372, 80.86527009164134, 85.74203921902566, 89.17982409077307, 84.19920629070651, 86.15863415502733, 84.11025477993874, 84.18671746407786, 80.75471416596444, 81.88464703098421, 74.56598281860352, 70.80916804652061, 61.142533825289824, 62.250050344774806, 60.38113901692053, 61.0216659884299, 58.26814643798336, 58.21749687194825, 58.32006292958414, 59.89558881328952, 59.28427957719373, 58.544422503440614, 49.511153005784564, 50.492930104655606, 52.39791154861451, 55.698586048618445, 57.551360745583814, 57.61586412306755, 54.61323876534739, 62.46144648521178, 68.20066636608493, 68.7629851987285, 70.99169162011916, 68.81752967834473, 68.43530254979288, 69.99154213936099, 62.00736545747327, 63.21545154817643, 78.66294553202968, 66.12226516969743, 70.99426469495221, 64.32450955913913, 61.0342764085339, 57.10524212929511, 61.220263434994614, 59.93985668305428, 65.53638465942876, 63.215000475606615, 69.8410015721475, 65.13327090970932, 60.75296794214557, 52.95864182133829, 64.43544203235258, 60.24106725569695, 62.55568142860167, 66.91521152373284, 64.18775220071116, 67.98688150221302, 64.96394218937044, 65.49127348007696, 63.28068448651222, 60.766111804593, 58.93464734477382, 52.719455688230454, 57.97294493644469, 56.555925953772764, 52.84691702935004, 59.59646101920836, 63.16528443367251, 61.427443027496345, 62.45826544300203, 66.407562686551, 60.73092029940698, 61.28646519876296, 53.46487076051774, 45.26683076735466, 53.65834166926723, 59.57857108885243, 60.9707457788529, 58.28777005595546, 56.67397752884896, 52.81264728115451, 51.97051440515826, 50.82279359140704, 54.60456248252623, 55.71988059628395, 60.83283132122409, 61.6931483053392, 64.2740757234635, 57.81322994539815, 62.48236448534074, 47.13784840799148, 57.05337662850657, 64.77218927875643, 63.2961307802508, 63.83777872208626, 57.3881430779734, 52.499253826756636, 47.53098757036271, 50.9037003209514, 47.15291423182334, 48.12152001165575, 50.561265637797696, 54.26758773865239, 53.173925030616026, 53.57333214052262, 53.81947263594597, 54.48149027362947, 53.510272195262296, 54.66194675814722, 55.87657143992763, 63.8985283913151, 66.02336652817266, 70.34661862158006, 68.9478543496901, 72.16246420337309, 70.46564686682918, 75.20544682779621, 72.3174919620637, 76.52733264430877, 73.53590565343058, 75.27516303523895, 69.47327936849287, 71.22682986720916, 66.4117988463371, 81.99848990286551, 72.99541088842577, 83.20655638171782, 72.04360854241156, 87.49226354783582, 8.967742381557342, 0.4185272855383735, 0.08918653122119366, 1.3160251826047897, 0.437042067848867, 25.427635408216908, 92.89678758190524, 64.52099677055114, 59.62085031693982, 25.2626742470649, 45.294510933660696, 13.524517686136308, 0.43822717522421195, 0.04956902966143624, 0.12924153027274918, 0.09657607744297675, 0.06232558486742839, 0.06811838551995254, 0.05102521341834819, 0.011215407510227975, 0.029653744779587276, 0.09692790332220255, 0.22593768433697764, 0.09461457059989054, 0.1986527734345967, 0.16211709037663477, 0.28819133737875574, 0.14515643999461206, 0.22913381847883427, 0.2864408264717748, 4.182795939906951, 68.1076120561169, 45.827929742874645, 54.063655868653335, 64.46300452755344, 86.49204346441454, 73.53108113811862, 1.3675553207435918, 1.9437891292956568, 0.14769493361874936, 0.441626766996999, 0.5729495589771579, 60.80867736570297, 103.03409053433327, 94.96270779640444, 89.61713698602493, 83.04638247336112, 86.63008736025903, 89.35666807236211, 93.66004943847658, 88.87044322106146, 90.42894209584883, 89.40077904731997, 89.17945538797687, 83.06302901237243, 87.74014949798585, 79.76425293953189, 75.64385014195597, 65.63764456779727, 68.02926663429507, 63.15908316643008, 63.28402242352886, 63.11710988321612, 61.634873651689105, 60.714642463191865, 64.51412477800923, 65.637456294029, 62.93400579883207, 51.578630401242165, 53.97324915855162, 56.54976783260223, 58.67255849222983, 60.33472953304168, 60.35550632784444, 54.91626539537984, 65.35408466093003, 69.33409014055806, 72.87500196887602, 75.19632339477539, 72.19539642333984, 71.07679136337774, 73.69119228855257, 64.54632743712395, 73.04735875898793, 77.32147139887657, 63.95845828517791, 73.61739681613061, 67.29185319715931, 63.61821228458036, 61.64017669616207, 65.09860107975622, 62.41921432556645, 69.51173428566226, 65.77851257016583, 73.73307535725256, 67.52287295556837, 64.91693258285522, 57.3709003386959, 67.70082304554602, 62.932444695503484, 62.944066678324056, 69.16596951023226, 69.16989972514492, 71.67468609348421, 70.78067594958891, 70.15632875504033, 68.39378818388909, 61.677160724516845, 59.42901111418202, 56.059961857334265, 56.49357595751363, 57.63842167392854, 54.60952820316438, 61.82579109745642, 68.18028573066958, 63.22799136561733, 64.78369359047183, 67.91598858371859, 63.21907189584548, 62.93959517632762, 54.822065753321496, 49.22156441596247, 58.04538719115719, 60.727225426704656, 64.40467103835076, 61.609915610282656, 61.00237577192245, 57.18529770451208, 54.41637108402868, 53.10372637164209, 56.778932309919796, 57.85128870318013, 65.2376804813262, 65.82832274898406, 67.04791315140264, 58.86872406928771, 66.56674031288394, 53.97844629902994, 59.36278189382246, 67.41599621311312, 65.51522739471929, 64.38396876858127, 61.32842279249623, 53.69197207112467, 50.035585664933734, 55.554513469819106, 52.22175398180562, 51.33503944643083, 54.44252544833768, 56.83286097741897, 57.062115669250495, 54.70991734535464, 58.96626164836269, 57.78198826697565, 56.850480264233006, 57.59764863598732, 59.776791987880586, 67.07110220386137, 69.58784395648588, 72.47695199904904, 73.35184451072448, 75.07013290159165, 74.92273023051601, 78.05434273135278, 76.51260806668189, 80.35610721957299, 75.21759833059004, 80.7357926522532, 73.85081706508514, 74.8069340182889, 69.44383021323912, 87.87749521193966, 77.68222747310516, 91.10377803925546, 74.33086026099421, 95.61848102077361, 9.855071748456648, 0.3876324917279905, 0.2919171293897014, 2.2356195988193637, 0.9121913715235649, 28.465218890097837, 105.7723520648095, 65.8999687625516, 83.53540789696478, 37.50825312829787, 56.247678649040964, 20.872108397945283, 0.49948871376052983, 0.3020601947942088, 0.24985939264297488, 0.21582397542172865, 0.1546640507876873, 0.22906939048440228, 0.1528157257745343, 0.1915956327631589, 0.12679387935467307], [0.06402928014135649, 0.13401292504802828, 0.03389780484740773, 0.04483479398092435, 0.18906008091665086, 0.04458627122784815, 0.07421579422248949, 0.1359773123817098, 0.20586956682945454, 6.541316143928036, 50.32428387672671, 38.38618547685685, 39.05400037765503, 53.49641053907333, 66.61437357625654, 57.72799291918355, 0.20143350406039148, 0.7429632232073815, 0.024709503331612197, 0.03958841703171211, 0.04448484118667342, 56.700386847219164, 91.91617934934555, 85.1888281299222, 81.96966832683933, 71.90430948811193, 73.81309955350815, 75.55586353425058, 83.12943473938974, 82.19864060801845, 84.80073313559257, 82.20855635981407, 83.5495754980272, 80.43335437774658, 80.12507961642358, 74.25901028417772, 73.0135008596605, 63.811137983875895, 57.815767718899636, 58.8359252099068, 55.26779605496315, 55.936450342978205, 56.73274640114077, 57.07535366858206, 55.09208956072408, 57.07961728495937, 48.864020762905, 46.364698256215746, 47.24777675444081, 51.20228682794879, 53.12720960186374, 54.1596088101787, 53.07790148642756, 52.01073831127536, 57.48284086104363, 68.45810720997473, 68.88712036994197, 67.29605797798403, 62.82699569579094, 63.385403925372714, 56.80049750112719, 64.92296518818026, 52.20354633946573, 53.99086844536566, 75.9930666031376, 66.9857043604697, 64.51890222487911, 61.181847741526944, 57.54195097954043, 57.72312918016988, 59.45981348714521, 59.48682685052196, 64.97136331373646, 66.36911561412197, 62.46946773221416, 58.36219310760499, 50.96841158405427, 56.825628126821215, 53.493398158781, 62.27680090935, 63.10144785911807, 62.3134397691296, 65.47670579725697, 61.60611091121551, 60.49238135737758, 55.61616920655774, 59.19581444032731, 62.9031995034987, 58.69316270274501, 59.1989758706862, 59.05380502823861, 54.4640161145118, 55.32186200541835, 60.90034315663, 58.748017049604854, 60.11378242123512, 61.75088951664587, 60.83648304785452, 61.449196492472005, 51.62237267340384, 44.980893904163, 55.66179813877229, 58.579241383460264, 61.46998505438528, 56.98345645781487, 54.62393114643713, 52.45843372037334, 49.51715030977803, 50.69898397691789, 50.29675668285739, 52.89285975117838, 56.28569426075105, 55.91156290423486, 54.06618579741448, 54.49396733314761, 43.74433140600882, 46.42880155194191, 59.003873255945024, 59.95896254816363, 61.16613080424648, 61.963376075990745, 58.75121378129529, 50.35768285874398, 45.724332101883434, 47.516325750658595, 45.48617362976075, 45.57233241296584, 45.19309413048529, 49.67533949882754, 52.96379189337454, 50.84310754652947, 48.0145138309848, 51.21093565417875, 50.48208475112916, 54.228838643720074, 54.243955458364184, 60.323578234641786, 60.82933648940056, 66.04414724534558, 64.90336902679937, 70.5714645693379, 69.00072005487257, 69.88236688798474, 68.45207460464971, 72.44891489705732, 71.5962936032203, 73.07033600345736, 71.32642669062461, 74.60966233284243, 68.89512984983384, 76.56380284217097, 70.28732807405534, 78.97088296951787, 70.91389533012145, 87.10974616389122, 18.59463122583205, 0.5507177487015724, 0.17479460446103928, 1.9503155855401872, 0.4957954958081246, 21.430634298632224, 81.32516799434539, 62.04479271365751, 55.47147689327117, 37.248231364834695, 24.557363448604463, 12.2332126286722, 0.3306338647680898, 0.08773681707680227, 0.12478632296645835, 0.15141989825473678, 0.04761473936659675, 0.039116694561896787, 0.02893933331623914, 0.038042428617876385, 0.03408613607227322, 0.044000321218082984, 0.04414666316381866, 0.07053726983647193, 0.022365762664365674, 0.05454422680721168, 0.13292112718186072, 0.06936172323842203, 0.16323639079928398, 0.43395503994918644, 14.427940537852628, 65.18455589971235, 47.59051738246795, 39.142649865919545, 58.403542733961544, 75.15673883499639, 63.59175982013826, 0.4944904803508713, 2.4471196820659022, 0.17216402706840347, 0.05654768845547111, 0.12081109272736697, 59.03951191133069, 94.78837413172569, 88.93043195047687, 85.11970812274565, 75.84945294164842, 76.26384350561327, 79.40293988873883, 85.98716382057437, 84.68381512549617, 85.76641282727643, 87.9690747107229, 86.12458013719129, 82.3561865283597, 82.62330778183477, 78.79098738393476, 74.80885597967333, 68.90999563278692, 60.9719499464958, 61.96913019303353, 57.34721706759546, 60.873953450110655, 58.22740870137369, 60.357149800946644, 57.74041898788945, 58.28636976980395, 53.46857740033058, 49.236834203043294, 49.389367334304325, 53.324469520199685, 54.18266450205157, 57.579150738254675, 54.603060214750236, 54.28680735249674, 59.543097173014, 70.18344017767137, 71.27374141447007, 68.13555502122449, 65.44090632469424, 66.56835632939493, 61.846669873883656, 67.79838808121221, 56.6810142609381, 56.68378345427975, 71.44220721337103, 70.71000268382411, 67.32804882910945, 63.45032699646489, 60.54523137307937, 60.28976740375642, 62.83701342921104, 62.037218616854766, 68.06033965080016, 67.91192500822007, 66.32010952118905, 61.308332412473625, 55.238052721946474, 56.203053843590524, 56.48025558840845, 64.90376126381659, 65.61519292093092, 65.00294231599378, 65.24612142193702, 63.814511222224084, 63.388541821510564, 60.36409239615164, 60.78981860991448, 62.962964657814275, 61.197737263095, 60.72304418010097, 60.1273302878103, 55.34162290634648, 54.436284957393525, 61.61798000335694, 62.262499947701734, 63.426478985817205, 62.291556865938254, 61.264272428328, 63.15120704712407, 55.2758369138164, 46.92323200164303, 58.13716280844904, 61.10502812170214, 64.47351647961524, 59.92077827453614, 56.106226213516734, 54.87741824119322, 51.45617792683264, 55.08603734354819, 53.727736242355846, 55.59987960323211, 57.760128898005334, 58.49954274392898, 52.64222814190773, 52.9007907836668, 48.268655961559666, 51.38767765414331, 63.030158781236224, 62.32039413144512, 62.361904574978745, 63.04263191838419, 59.2580153865199, 53.03208035807456, 48.59145918200093, 48.249189238394464, 49.222996081075365, 47.29728883312595, 46.87516727755147, 52.83132168554491, 54.87695147914272, 52.87285566329957, 50.366206169128425, 53.33315364776119, 52.28742622560071, 57.125995389876834, 55.29420537333335, 62.23276838179558, 63.93574383951003, 69.26009070488715, 67.6270354178644, 71.92865956214168, 71.11159063154652, 73.93420665494858, 68.69338666239094, 75.58023714250135, 72.1726780553018, 76.04859167529692, 75.02973248881679, 78.92835663210961, 71.64739424182524, 79.23802775721397, 73.53796097540086, 84.09958593307003, 73.39778331018263, 92.47261462673065, 22.135217497425696, 0.5173434040719463, 0.1687146395805382, 2.896944938167449, 0.4100887964089071, 23.575784429427117, 92.1233275628859, 67.2169751505698, 63.43196638168828, 37.951582939394065, 45.91840313326928, 26.428330098429036, 0.5124803085721309, 0.11667619444309704, 0.12468449455956299, 0.11462330097152341, 0.03651299536408436, 0.07062520140842085, 0.003747039459525578, 0.015173436202589544, 0.07371373084043303, 0.10161914997884344, 0.22640262309822345, 0.20931791243774278, 0.1364818578886409, 0.19604770676983943, 0.22240424168206033, 0.18157226093594106, 0.3601966768262848, 0.4492215175301798, 13.524355888366701, 81.6015225072061, 51.55868122654577, 49.80225563049317, 70.91505635169246, 83.93639179968065, 70.95892413969963, 1.0472995571551784, 4.31238075417857, 0.29971823336616643, 0.2504007256920299, 0.5008432184976916, 65.21981016282113, 100.76110055369716, 98.32132354859384, 91.04734297721618, 84.646434937754, 80.61643492790961, 85.90222097212269, 91.1226446397843, 91.32990267968948, 91.81552348598358, 90.63167372057515, 89.27678508143272, 87.89720119968538, 87.87830322019516, 83.3290284679782, 80.54370634017452, 73.84957759611069, 64.62222137758809, 65.92613097160094, 60.61131154337237, 62.99508494715538, 61.39026680300313, 64.2441245048277, 61.77788719054192, 62.88453294384865, 55.37756358423541, 50.74237323576405, 52.90103397061748, 57.8877628234125, 57.6494082327812, 58.65742206573487, 58.2060121720837, 57.4934430276194, 63.32807848530432, 73.87854822220342, 73.97367354362243, 71.6505870511455, 69.34289978396508, 71.51733629165157, 64.5049189752148, 71.0954696901383, 60.35855400946833, 68.52561120064028, 73.88156844723609, 72.3871140326223, 70.64685252404982, 68.36606487151116, 64.89478688086233, 62.38942000173754, 66.01619643549766, 65.61265906979962, 70.51002456295875, 68.63712418463923, 67.54810948525706, 65.20880006974744, 58.11490728009132, 60.8495916089704, 57.975380728321696, 66.15274198593633, 68.76865694599768, 70.08864433534684, 70.02121094734439, 68.09604890884893, 65.18064137428038, 61.37208269488428, 61.88849018466089, 66.90706083851477, 62.69936177038378, 64.63726758956909, 63.44418456477504, 56.776496518042784, 58.75344168755316, 64.70600712683894, 65.77081295751756, 65.37612838129844, 63.74910569960072, 65.13287475032192, 65.68490912837368, 56.437136973104174, 48.15873153748051, 61.04188972903837, 63.99597575587612, 67.32081597851169, 64.5509401444466, 59.81784351410405, 58.128866995534594, 53.78249645233155, 57.88265197507797, 55.30694523165303, 58.78516973987703, 62.45173077429495, 61.92991825842089, 58.704196330039736, 56.726576512859715, 54.70488886679373, 54.6162707574906, 64.27802162785684, 67.19426462727209, 65.81318240011892, 68.71528917743315, 63.07969047177223, 56.4063738238427, 51.241126137395064, 53.10091795459871, 52.42476409481418, 51.239627791989236, 50.966466088448804, 54.961764889378706, 58.796548535746915, 56.49962032994917, 54.618345691311745, 56.04966563563193, 55.72295181212887, 59.98502669795867, 58.77412434547179, 64.20925855636597, 65.98017338783511, 72.83248347620811, 70.39028244633829, 75.9887755301691, 75.7808114636329, 77.55521328218522, 72.7822300695604, 78.27955738190683, 75.37090809114518, 79.44714500058082, 77.7896611921249, 80.23139153757404, 74.42859788094798, 82.96272616232596, 78.31739256458899, 89.43481737567534, 78.00132013136341, 98.56611082630774, 23.81389779429282, 0.6871174359994551, 0.5933001637458801, 4.5489202680126315, 0.49303877437787674, 25.862024176505308, 101.53820053223642, 69.24575051953717, 81.62139323449905, 54.167630057181086, 56.891182699511134, 35.40163440089072, 0.5366197084226917, 0.20686730442027892, 0.3533614565047526, 0.2583539900520156, 0.11728124302481452, 0.15048122604287442, 0.152022855416421, 0.15579113466364725, 0.13362602000274967], [0.04710517598376159, 0.006290307247845997, 0.06391656562505711, 0.08268190082162619, 0.0450413542679481, 0.1566326056396769, 0.10081765347070272, 0.1867291358329596, 0.5812729510568804, 19.02463870663797, 53.390004481038744, 35.37644493964411, 52.24587263599519, 43.556736207777455, 75.74213689373386, 58.33316364595967, 0.13002145374494214, 1.2264236615550135, 0.23463788442313674, 0.09709592938663499, 0.4106679282361462, 56.316473099493216, 90.83277363930979, 83.5502109219951, 78.50823156295284, 68.48134333087553, 75.9169412428333, 78.40700303354572, 79.29964819262105, 77.40686924226823, 83.13412589411583, 80.68586872469994, 82.41514759678995, 80.88380721307571, 81.96433390340498, 76.31258287737447, 74.10184875611337, 74.81164870723602, 63.95553219702936, 56.30527081028108, 55.95441479836741, 56.998098665668124, 55.91508127027943, 58.188000648252434, 54.34300707232568, 56.056984778373476, 48.69234646520307, 47.797516545941754, 49.109878847675944, 50.476922911982385, 53.697361407741425, 54.72874864455193, 53.524318202849365, 51.70226350907357, 60.95498177313036, 65.99368987544891, 66.56798762659874, 64.11385082429456, 63.40982067969538, 64.98248715554514, 64.42660493235435, 56.85241399272796, 64.78317191523891, 52.270736540517504, 45.85610412782239, 66.45210512222783, 62.984855405745975, 63.25204333951397, 57.26444328984907, 56.891625927340606, 58.5459836067692, 62.56159244045135, 62.77083912203389, 67.7810904287523, 64.4729555806806, 62.31596969789075, 54.426047571243785, 51.060191123716294, 57.702521047284534, 62.47809694659326, 64.08830050499209, 64.64968973590483, 60.504105321822635, 62.45999913061819, 63.331400732840265, 62.30925460015575, 62.9163198317251, 62.99208041160338, 61.23532141408613, 59.68280023144138, 61.24023614391204, 61.485600010041274, 47.9283275911885, 61.81400829745878, 57.718602764991026, 61.65716840374855, 61.97062461606918, 59.78604878148725, 59.14331351557086, 49.925374907831994, 47.07680456099972, 51.577508603372884, 62.18007918327086, 59.27112394763578, 54.59643533152919, 54.52902940011794, 52.588985889188706, 49.64438415342762, 52.121961039881555, 51.48234405825215, 58.55179655936457, 58.65983432339084, 55.49075142029793, 53.071182466322384, 50.613448850570194, 53.081878769782286, 60.031946089959916, 60.00670956027124, 60.65559902498799, 58.44876373967817, 60.853055061832556, 59.620599285248794, 51.16254145099271, 45.94587149158601, 46.99012018019154, 47.72977721306586, 46.8614899727606, 43.855448230620354, 44.507808992939616, 47.334586651094504, 49.939134582396484, 49.75495576858521, 50.24186311229583, 50.96547765116538, 52.69618034362794, 51.60131739031885, 54.68904641366775, 62.34226918989613, 65.66528943277174, 68.37951860120221, 67.10761162542528, 68.4378207114435, 70.85406349551293, 69.03201272410732, 73.94751133457308, 72.97466155021422, 77.57847293730705, 73.55954185608896, 77.80165580011185, 75.71206015925254, 79.46094389884703, 76.72462001923593, 81.49486541748047, 72.72477519127631, 82.59259562338553, 37.346353377065356, 0.22116503317750272, 0.2946430847289101, 0.9811227372096432, 0.3170773260776074, 16.840702218394128, 78.88310816980179, 66.39312836431688, 50.142536932422274, 33.85178435233332, 22.1147721429025, 21.89645694148156, 0.40697020568674613, 0.04714434605933005, 0.08509072640369977, 0.10132497987679898, 0.06355624000031142, 0.08044586637087407, 0.05146731126813158, 0.026137203939499396, 0.06598138325517217, 0.005547574471547119, 0.02532155778739722, 0.03294889387043734, 0.040134534299854314, 0.10692639261363976, 0.12372362111965496, 0.1357483899881763, 0.16963241291382622, 0.4794398863469401, 24.59698330971503, 65.84855433433287, 41.88312753554314, 48.88585267528411, 48.19164806796659, 84.30622423848799, 62.94456089696577, 0.37714916071103466, 2.267428795176168, 0.1272127532490319, 0.2199397521514085, 0.4352739675631447, 60.559606859760905, 93.71669630850516, 87.85961704869425, 83.52688850895052, 74.03811024081323, 77.04392448548349, 81.06842533234628, 81.56262828457741, 81.51113540895524, 87.35918537262948, 85.34932367263302, 83.24964754043087, 84.77965431828653, 81.57179878604028, 77.89335297000024, 75.86543267773044, 77.22954673151817, 67.2822198560161, 59.050506314923695, 58.882495510962706, 59.549004262493504, 58.94543386274769, 58.624933073597575, 59.07755890200215, 58.75805047250564, 52.549550379476244, 50.25173964038972, 51.58590639791181, 55.10464114527549, 55.017125221990774, 58.10028076171876, 54.905733831467174, 54.503569295329434, 62.22537471402077, 69.07870461863857, 70.53102493286133, 67.1065761196998, 64.72402649541056, 69.8870345084898, 66.6494317208567, 64.35970498669532, 68.54929447174072, 55.08935566871397, 48.38600935474519, 67.2764539718628, 66.99010525980304, 65.52769660949707, 58.60037903631888, 59.15911282262495, 60.92311251548029, 64.06011043056365, 63.4157826823573, 69.2502926241967, 67.37366599421348, 63.52623270403955, 57.707035695352864, 53.224649121684415, 62.297067796030355, 63.172356467093195, 67.28837797718664, 66.08231190712222, 62.1080409326861, 65.07964426471342, 65.15989595843901, 65.44510718314879, 62.90742389617428, 65.62926246273902, 62.95227619909472, 59.52439923440257, 63.04795457470802, 61.159235277483546, 51.620917474069905, 64.57143452859694, 61.93343662446546, 61.87336944764661, 64.9398470694019, 62.23156813652285, 62.17969479099397, 51.71764312251922, 49.00247650761759, 55.512406826019294, 62.912868145973455, 59.284381558818204, 56.833472867165845, 56.08818331072408, 53.98768348078574, 52.64034148185484, 54.00096854855938, 55.73269890200708, 60.97628024316604, 61.18429922288465, 56.93165763731926, 55.7408142858936, 53.9345157531, 56.19959039072837, 61.75589838335591, 63.25702474963281, 62.40345031984391, 61.23391328319427, 64.2680235062876, 60.860617391524784, 54.33542120841242, 48.647184295039025, 49.13306005539433, 49.22641246549545, 48.76463182510869, 48.51395706976614, 47.58153907714352, 51.27068904138381, 52.77302742004395, 52.979708871533795, 52.72821041845506, 52.33235697592459, 55.19152164459229, 54.48106273528069, 56.504931219162486, 63.19391381356024, 68.11552739912464, 69.9207825814524, 74.1612648194836, 71.85771173046481, 73.32785529475059, 70.92693328857422, 76.3014433460851, 76.55704852073424, 79.6516966050671, 75.52897176434918, 79.88583072539299, 76.46692814365511, 83.08149553114369, 76.68441572496968, 85.00577895872055, 74.74349360312186, 84.42389534365746, 43.20497412835398, 0.09142453451791117, 0.04870132400443958, 2.6861239152569927, 0.3599104050907397, 19.089746129128244, 90.26216291612195, 69.88562245522776, 62.59452466041812, 35.402905248826556, 38.50947341611309, 36.138408491688395, 0.2726356769281049, 0.05927452096535314, 0.040063962280269594, 0.03196487499911699, 0.05379603086640278, 0.060158636225687886, 0.04548777668406406, 0.04994670717766689, 0.015417158457210228, 0.08557716159210091, 0.20351654309178555, 0.15559854015948313, 0.15248371858990964, 0.2472285547804448, 0.3322559793389613, 0.19137515265855098, 0.3254898601481992, 0.92672350786386, 30.75069573617751, 80.55481449250253, 45.746085566859094, 69.02740001678467, 59.7089663628609, 93.55713428989534, 70.04939709940265, 1.1793955463555552, 4.149023352130767, 0.39579944865357497, 0.46283584989367, 0.7008302872700076, 66.45257580664851, 101.24754505772745, 99.14389948691093, 89.69523922089608, 79.88803509742984, 84.4237070698892, 86.65441390006774, 88.28105218948858, 86.69359837808918, 92.55223089648833, 90.71168222735005, 89.41932401349469, 88.40723483793198, 87.36311558754214, 83.66810952463459, 79.52210149457379, 82.15645943918537, 69.67824674421742, 62.76273158288772, 60.79555703747658, 63.92465529903289, 62.00492574322609, 64.16532016569569, 60.167507125485336, 61.19826286069809, 56.476160633948545, 54.79476605692218, 53.76637551092333, 58.476106582149384, 58.40727290799541, 60.978441469130985, 59.82932036922824, 56.78785962443198, 66.08985854733375, 72.29366748563706, 72.10514268567486, 71.65942022877356, 67.74802484819966, 71.82761930650281, 69.75124989786457, 65.31608081633046, 70.29875001599713, 56.880435405238984, 58.19801445930236, 72.07101022043537, 68.60182285308838, 68.84808494198707, 60.78046767942367, 62.137254745729514, 63.351922573581824, 68.31683912584859, 68.75153187782534, 72.93597129083449, 72.56688410235991, 65.93407769357005, 61.18753910064698, 55.25088279478012, 62.81296930005474, 65.58285690123036, 69.83372165310767, 67.7441103227677, 63.87277410876367, 68.67742261578961, 68.39605531384869, 67.47348247035858, 65.4811066965903, 67.90666118744882, 64.9311041062878, 62.020497552810184, 67.44328022003174, 64.59117189530404, 50.89352569272442, 67.42357423228603, 63.89213492793422, 63.31708015934114, 67.16613338839623, 65.59466323544903, 65.11673027469267, 54.69804040847286, 50.84354685198877, 59.30759806786815, 68.29370498657227, 63.18691238280266, 60.169848780478205, 61.87470697587537, 58.47671454952609, 56.10707736784413, 56.09698118702058, 59.06590161785003, 65.53498829564741, 65.08574355033137, 59.55465639791181, 58.1544683056493, 57.46593936797112, 57.267871441379675, 62.54402806681972, 65.66428138363746, 65.48350326476559, 65.91900010262766, 67.85724716801798, 65.3136097231219, 56.458921817041215, 50.64734989596952, 51.4329182717108, 52.781032977565644, 52.230551858102125, 51.02330515461584, 50.9743735867162, 53.00746748524328, 55.98809619103709, 56.36914660853725, 55.909032975473714, 55.53162643986364, 60.31080307499055, 57.125924787213734, 59.18547507255309, 65.83424552794426, 71.0779994533908, 74.18097080722933, 76.75784249459544, 74.11084667328866, 77.75947463127875, 73.9830715425553, 79.04269372263263, 78.74475832908385, 83.6308313185169, 78.40756785485053, 84.16636820762389, 80.43529987335205, 86.54708216267248, 82.09026552015736, 89.33932335146012, 79.13938014738022, 93.14263389956568, 46.52901418747441, 0.3361742126364862, 0.2737575667279382, 5.735623557721415, 0.33385903364227665, 21.27957009500073, 101.21242415520453, 73.61026594715734, 71.893020906756, 49.801984986951275, 51.15209225685366, 47.35343756214265, 0.6360515471427672, 0.14737299282944974, 0.13526825204251275, 0.30903487376147704, 0.133161464285466, 0.11552846449757777, 0.16913471623293816, 0.10140527355214281, 0.21220702918306475], [0.05253713390219116, 0.03348350832839647, 0.06340140213949547, 0.019593945471569896, 0.07053847259451305, 0.024375492827065533, 0.1629229076206684, 0.13123245489212776, 0.1901892485517648, 21.370878950242076, 60.38888569801085, 37.97426992847074, 50.438040456464215, 46.6938361044853, 82.63869131765058, 56.61902904510499, 0.356877769433683, 0.2985472832956622, 0.0623587488136705, 0.02309585786274364, 0.6224556928200107, 58.8731877265438, 84.89455623011436, 77.34226780553018, 76.44426468879946, 68.35807892584032, 73.0079310940158, 70.02460771991362, 71.56489110762074, 73.45685420497772, 78.89183936580535, 78.29044588150518, 78.57273886280676, 78.24836669429656, 80.01739486571282, 79.46980845543646, 75.28074849036433, 74.54517072246921, 72.64769277264996, 59.737493761124156, 54.90283912228, 57.62365395022977, 55.508449154515425, 58.58208902420537, 58.345817212135564, 53.0763090041376, 49.51958217928487, 48.250652282468735, 48.73579455960182, 52.40730170280703, 54.05514432537941, 54.95897608418619, 51.71787061998921, 51.7055033868359, 56.77042861138621, 66.23547261761081, 65.8262360480524, 62.32807805461269, 64.53984375922911, 69.7691672848117, 66.57787984417331, 67.00116634368896, 60.909074352633574, 68.55640965123331, 59.07289520386727, 55.66663442119476, 64.8903428354571, 63.93307662779286, 58.37809831865373, 56.0202713935606, 58.5280466079712, 60.54890271156066, 61.23816905483123, 66.88164387979816, 64.63314910088816, 63.185865109966656, 51.21528556269985, 49.71304916566419, 59.031753463129846, 56.2706127474385, 65.53240345370385, 65.68788620733446, 61.393353708328746, 62.117356561845355, 64.94839783637755, 56.93577612600019, 57.566869797245154, 63.34440731233167, 61.503034945457216, 62.03181359075732, 61.5023720648981, 52.429423870578894, 51.456401501932454, 60.51748844885058, 60.428674221038825, 60.30053038750926, 59.098982887883345, 61.82956049519201, 54.517862412237356, 48.35897637951759, 46.91385361456102, 53.232097702641646, 59.79303452276415, 59.148345916501945, 54.715094873982096, 53.77595393888412, 54.35291105701078, 48.09370256239369, 52.71370157118767, 53.569496062494096, 54.232117745184134, 55.24451678799045, 62.66929288064281, 61.80526925671486, 63.436316290209376, 60.35992291665847, 60.59155064244425, 59.555095703371116, 61.58228251241869, 57.465319633483894, 59.397745901538485, 62.34750555407617, 56.98848101400561, 48.804051645340465, 47.24677655004686, 45.93406515736734, 46.22365374718943, 43.10280815247567, 46.00748015988258, 47.2559666633606, 49.18982851889826, 49.50975271963304, 52.02734954895512, 50.83178366384199, 52.71865944708548, 51.73305411492625, 55.295868458286414, 58.06187291299143, 65.3315192653287, 64.46653073833835, 70.75030895971483, 68.39584350585938, 71.88778062020579, 70.73813392269996, 72.5762507223314, 69.95279696679884, 74.21319700056507, 72.8067684173584, 75.18876890982352, 75.26925594575944, 77.0436969880135, 75.43572133587253, 80.49819900143532, 75.70595695126441, 79.20278133884554, 44.587750819421586, 0.36801537018149133, 0.20932548138643467, 1.7290197505104927, 0.6207424750731838, 14.003000759309339, 75.77395516057169, 69.7407457905431, 53.820057069101644, 42.36213914809689, 22.99871748493564, 29.06294691947199, 0.4989677126849852, 0.04425968028484814, 0.048073989925004786, 0.08386159195534645, 0.08809816542892687, 0.06498926108883274, 0.051085952699424765, 0.014400179610557616, 0.04500761958620241, 0.06168497065382619, 0.05369739321571204, 0.04626979540672995, 0.035252240636656364, 0.07231455551640642, 0.038077733779866854, 0.10859618849691846, 0.09562438939728084, 0.18258447758853438, 33.49013397770543, 70.37003517150879, 43.01594334263956, 50.83730636104461, 54.7396332217801, 88.79831083359258, 62.73099960819368, 0.3540840612784509, 0.3584275040174685, 0.026626450670582634, 0.0495651034608243, 0.5210748651335316, 65.42139253308697, 90.20982280854257, 84.69996744586577, 77.19743820928758, 73.44727577701693, 77.1013479848062, 75.58436347592261, 74.98893983902471, 76.9352512974893, 81.97590489541331, 82.90745212185769, 82.81674338925271, 81.26735225800546, 82.71301238767563, 82.91365731147029, 77.74401264805948, 78.62237253496724, 75.54931317606281, 62.7405466571931, 58.037636587696696, 61.05032282490885, 58.83186555677845, 61.35445948570006, 60.76644128368747, 57.63143593265165, 50.76895513842183, 51.57999538606214, 51.671672944099676, 55.01599557938115, 57.892340229403594, 56.14270425611927, 54.626261034319484, 55.457799588480306, 62.29354550761562, 67.6675848807058, 68.30781767445227, 65.72044187976469, 66.87365008938697, 70.27784378297868, 68.76100832416166, 68.74058062030424, 64.90777384850287, 71.04312173781857, 62.7437904573256, 57.825177484943026, 66.74791459114321, 65.54991291415307, 60.680482541361165, 60.19094720963509, 61.62397338498024, 63.18398237228394, 65.89281435935729, 69.05437023408952, 66.00994417744299, 65.3182969554778, 55.8211483493928, 51.68174166833201, 62.50764808347149, 60.52090875564083, 67.47267446210309, 66.65315012778005, 65.29997556440293, 63.19625154618294, 66.76938564546647, 58.352018479377996, 58.7829496783595, 64.82179941669588, 64.05721572137648, 65.63231798910326, 62.2319721406506, 53.17607448947046, 53.26915233365951, 63.11766685978059, 64.58090705256309, 62.33945292811241, 60.293054349960826, 64.10156203854469, 54.37244838283908, 50.3200908630125, 50.734646166524584, 56.6176954392464, 63.28044129956154, 61.80362186124248, 59.56775711428735, 57.48552768461166, 57.53079183640019, 53.34643871553483, 57.36002360620807, 57.81144918933992, 55.89073119624969, 57.233731131399836, 64.03674487144717, 64.34398412704468, 64.80259941470239, 60.00077501420052, 63.48699723520587, 62.77954286144626, 62.260821173267985, 61.783029417837824, 62.85818246103103, 64.04500538303007, 60.71958464960898, 51.85122728347779, 49.59172633386428, 48.79930557743196, 50.628816696905325, 45.475826417246175, 47.62175513852028, 49.496142095135106, 53.56867236475791, 52.46880838947912, 54.25980967860068, 52.84512842855146, 55.56347608566285, 52.61352815935689, 58.140700786344475, 61.827042333541385, 67.9430764721286, 65.20719974271714, 72.80201450470956, 71.56508722612935, 76.13008283799695, 72.46286284539008, 75.05613004007648, 72.08977483933973, 76.38244029014342, 74.97175985766997, 77.76522482595136, 76.23616726167741, 81.30548554082071, 77.731641492536, 82.9921910070604, 77.5940369021508, 84.29978370666504, 49.03869567378875, 0.42735562149074774, 0.11647337266514379, 2.744061735368544, 0.5164012384991492, 15.888493907067085, 84.53656150448708, 75.19583702087402, 65.00778644315659, 45.00932716554211, 37.18511258402179, 43.74418235594227, 1.4460298130589149, 0.14951998488076274, 0.08871888050869589, 0.04924740296818557, 0.05773409051940807, 0.0065805999873836925, 0.0296601205463371, 0.03586233773779485, 0.05742306648302944, 0.12442423150904718, 0.19744796227783928, 0.14910784489925832, 0.1253497193477327, 0.2036001692496, 0.2862887426970467, 0.24035907500693876, 0.32263259733876876, 0.3813211223290813, 40.05160424017137, 81.82238332686886, 48.357442732780214, 70.21955736221807, 66.23657872599941, 97.40885473066761, 69.46119846836214, 0.8984568246429967, 1.0904739436603363, 0.6368218638723897, 0.4027207466142793, 1.374107272394242, 73.02002768362723, 96.8723294042772, 90.9829455037271, 85.2859224811677, 80.58980987917992, 81.65468631252166, 80.84704675982076, 80.77912699791693, 81.2464617144677, 84.75641819738573, 85.90144434282857, 85.73965441796088, 85.59696643583237, 87.32116976091939, 86.92458675753686, 83.30958920140421, 83.74272869479272, 78.33536486471854, 66.59620515761837, 61.47446832349224, 66.85603080257293, 63.46200389246788, 65.7172804494058, 64.05440730433311, 60.8880582932503, 57.077503127436486, 57.19318166855843, 54.18607696410149, 58.46513571277742, 60.291332429455174, 60.37723625859907, 57.2178533769423, 58.89022258020217, 63.78245761317592, 69.516872590588, 70.76510414000481, 70.41624069213867, 71.27470631753245, 74.36897785432878, 71.9371711054156, 70.37977049427649, 67.0044062214513, 71.4970027246783, 63.86764757094845, 63.7474779159792, 67.91563557040307, 68.01837028995638, 62.306803118798044, 62.66266407505159, 65.33302153310468, 65.57160754357615, 69.57521392453101, 72.98138449268957, 69.26099285002678, 68.59063625335693, 55.67067838484242, 53.29407507373441, 63.88007363965435, 63.114254397730676, 70.399107779226, 70.97127176100209, 66.67982224495181, 65.58899541055003, 69.72362856711112, 60.46881967975248, 60.4702042764233, 66.67138914908132, 64.41652836338167, 66.62994538584064, 65.38375346891343, 54.63969122978949, 55.767153001600704, 65.99403504402407, 67.6953003483434, 65.77055408108619, 62.673309387699256, 68.44902300065564, 57.88084768479871, 52.761366213521654, 53.958559882256296, 60.040257592355054, 66.92019293385168, 62.958116608281294, 62.89663737820041, 59.7705985653785, 61.157238791065836, 54.07971797450897, 60.393019876172474, 61.06990721917922, 58.81561125478437, 60.853396308037546, 68.9152829877792, 68.47153740544474, 66.81937233094247, 62.231654428666644, 67.438824407516, 66.44551554033833, 66.84755848300073, 65.29105609463107, 66.24665921734226, 69.76789643687587, 62.413142496539706, 55.9517671985011, 53.76577931065714, 51.03138523717081, 54.39338599481891, 49.8969808701546, 51.336843736710094, 52.226198027210856, 55.889472115424375, 54.29305961055141, 57.43161470659318, 55.35128370408089, 58.28961749230662, 55.294907477594194, 60.38075854701381, 64.55953797986432, 73.18826598505821, 69.78537451836371, 76.0376404177758, 74.22800002559539, 79.63049227191557, 77.75896472315635, 79.73918899413079, 74.91146518338111, 80.69773781684138, 78.47165938346618, 82.12552762800648, 81.54878231786913, 85.34129850326046, 82.54384840688398, 86.53793519543063, 81.95280997983872, 86.65819506491385, 54.428722627701305, 0.657904971270792, 0.3198340475078552, 5.346906377423195, 0.45726473593423445, 17.353587419756, 94.2499896018736, 80.3707141260947, 74.00447199421545, 61.77743219560193, 51.60771085369972, 56.39402228017008, 2.3876884195112416, 0.4834903770637128, 0.344662344263446, 0.31891486457278656, 0.2933079466944741, 0.19588699684508387, 0.18620620421584577, 0.160110414989533, 0.21144287180035345], [0.06339064243459894, 0.06646895225370122, 0.034022209865431634, 0.049326421107135476, 0.022044038294904658, 0.04452815579791223, 0.011734750963026478, 0.029522435394145792, 0.047351944395491195, 36.965279425344164, 48.17871601350846, 43.878476465902025, 42.39277678151285, 52.426105545413115, 80.11463826702487, 61.27809486081524, 0.3356108622204873, 0.48092248098504164, 0.1872775628561935, 0.10750324149886448, 3.809842029886861, 59.91141949930499, 77.89651440035912, 73.24761144576534, 71.31312201100012, 71.10546388933736, 74.58512398504442, 74.08399412708899, 72.4610036419284, 66.99911886645903, 68.90040151534542, 73.76704308294481, 78.07619817795293, 76.66121098303026, 78.32434300453433, 76.00372760526596, 77.5355229839202, 76.3205688230453, 74.41086876776912, 68.26598167419434, 55.102683882559504, 55.4301154998041, 57.4896461732926, 55.78540771238266, 57.04597903836159, 51.95020829477618, 45.45510453562583, 47.59982516688686, 49.102516558862504, 52.456915763116655, 55.21160417987455, 52.69284632898147, 51.849513207712484, 51.710822120789565, 59.82524110424904, 67.27139411434051, 65.03299551625406, 64.47842336470082, 67.52954882960167, 65.72567039920439, 65.29618263244629, 66.09986059127316, 67.33552486665788, 64.33696308443623, 66.93663550961402, 63.32315591073806, 64.48133768573885, 65.1414765081098, 59.958695826991914, 56.11183520286314, 59.70587945753529, 59.28939434789843, 60.218219449443204, 65.51869084758144, 63.138110253118704, 65.44591126903411, 60.60293336068431, 55.383545198748195, 59.585580364350356, 58.33590538271012, 60.9466310470335, 62.9857300942944, 63.38048527317663, 64.76305800099527, 62.32191208870181, 63.062498723306966, 51.566722085399014, 59.60418808844782, 58.60260302020658, 60.4779980259557, 53.401948098213445, 48.56107650264617, 43.3898550464261, 55.15372568561185, 63.60622552133376, 63.03671306179416, 60.97242847565682, 59.12387817136703, 54.14226801164689, 41.2848876368615, 48.96155049723964, 51.55094631256596, 57.96197798944289, 59.79408571797033, 57.791519626494384, 56.75017349181637, 54.27336146754604, 54.30928645595428, 52.207817800583385, 53.3718752861023, 52.646017151494185, 56.744901826304776, 56.30643183185209, 57.759058090948294, 59.48721516516901, 58.70270975174443, 59.007674032642, 57.91947910862585, 61.422167439614576, 59.214563369750984, 57.62977284769858, 62.90210516222062, 57.12053937296714, 48.099288017519065, 46.633208028731815, 47.27444494924238, 49.071851468855336, 44.37521326926447, 43.00781619164252, 44.47526900999008, 48.84467563321514, 49.82065154660133, 49.54188085371449, 49.5621398956545, 50.94837611721408, 52.463795600398896, 53.67255241640153, 55.03196747072282, 59.81980077682003, 64.48634263007872, 65.83722652927523, 66.80812297328826, 66.2787442053518, 66.5624257056944, 66.91569005289386, 65.31894022418608, 68.07438173601705, 66.95475685981013, 72.01663048036637, 75.02942654394334, 76.78007448873213, 75.65342856991676, 78.38273140691942, 74.42185924899194, 81.03116281570928, 46.5719602184911, 0.24195400877825676, 0.22233014565802392, 0.5855568534424228, 0.6498633769731368, 20.64672116310366, 76.6957199958063, 70.96230522278817, 58.75570489514259, 42.97687653572329, 24.351927349644324, 32.29633119798476, 1.0982522488601747, 0.08919925594161596, 0.1499162974857515, 0.04664045172713457, 0.057165216609475114, 0.06115135211016863, 0.020178303933672367, 0.02044683690333078, 0.03824564493111065, 0.12364403224520146, 0.03011844988401619, 0.04069682368407807, 0.046932017130236474, 0.07385741829151109, 0.02203071794112123, 0.019876777472335006, 0.09806329159126168, 0.09399570945289829, 52.24280142015027, 55.67176095900997, 42.6753717853177, 40.5668624754875, 60.11615545518937, 87.92050007850894, 67.0020684888286, 0.12471782704514843, 0.4708317240640041, 0.3166358142850861, 0.1581381216284729, 5.005157128457101, 67.87456835469892, 86.74512263267272, 81.59948287471649, 76.4478026666949, 77.17147211874686, 78.9277212081417, 79.05074242622622, 76.96586931905439, 71.07508905472295, 73.76315209173387, 77.65747731731784, 81.44985229738298, 81.38348579406738, 78.21926270761799, 78.46711727880663, 79.17268107014318, 78.76269140551167, 77.03734274833434, 72.97803478856241, 59.270523824999415, 59.0469918712493, 60.62112531354351, 59.08255992397186, 59.07155375326834, 55.013183239967596, 48.90813173786287, 51.991671669867735, 52.137148457188765, 54.34230104569466, 57.03836571785712, 57.31440644110403, 53.1095903150497, 54.10475838568903, 63.48311016636511, 70.64602882631364, 67.97199218503891, 65.2767276763916, 69.23983558531731, 67.73053107723113, 67.82938265031385, 68.81337981070243, 68.37241911119031, 67.1116752009238, 67.88049113365912, 66.75932868834465, 67.94932873018327, 67.30913516013854, 63.10770403954291, 59.10262676977343, 61.05458251891598, 63.20470817627446, 63.41444515412854, 65.61521645515197, 66.784102378353, 67.0188170094644, 60.8663244401255, 55.922914243513546, 59.81012428960493, 59.7799220392781, 64.34189350374284, 64.39895614500969, 65.6009586395756, 68.08745891817155, 65.53126204398372, 64.29750404050274, 53.41804158303046, 61.711301034496685, 59.737054455664854, 63.826631346056544, 55.58118166462068, 49.68268217579011, 43.056226084309245, 55.07109703556184, 65.8122802549793, 63.26314364710162, 61.20204010317403, 62.9180339074904, 57.1162522223688, 42.68624851780553, 48.38509544249504, 54.953814245039425, 60.715870165055804, 60.709508080636304, 60.89591087833528, 59.71261808949133, 57.623438219870295, 55.33295446826566, 56.16961563787153, 56.36674611799179, 54.74103350793162, 59.88976017121346, 59.710809876841886, 60.93418536647674, 64.3316129715212, 60.90733282027706, 61.84238664565548, 60.73137921671714, 63.374774302205736, 62.54655407321069, 61.095877232090125, 65.21637024418001, 59.396255400873, 49.86568427854969, 48.84779391750213, 50.57103233952677, 50.95030200096869, 46.55466256603118, 46.992238260084584, 46.39830120148198, 52.601698290917184, 52.60742887373894, 52.252940747045706, 51.78330359920379, 53.4160803979443, 54.08622910899501, 56.45887867096932, 57.072247151405584, 63.30945899409633, 67.21858332234045, 68.10201091151085, 69.23625053897982, 70.15683866316273, 69.30979497971074, 69.69530120972665, 68.99421676512688, 71.89840239863243, 70.07435121843892, 76.40262480705016, 77.1013322953255, 79.32884631618377, 76.2629884289157, 81.42984036476382, 75.87270475202992, 84.95735337657314, 50.713732088765795, 0.2018701128901974, 0.25777108907218904, 0.38622546400274005, 0.6813072413206102, 23.0181763633605, 86.63294284574448, 73.47277118313697, 70.06077981764271, 44.34781159124067, 37.20785448628087, 47.14212771384947, 2.863791349434084, 0.17034977764612244, 0.04460459988143656, 0.0019247808273986824, 0.04652160467700132, 0.022305450477306882, 0.0028373979101513304, 0.034302502284727754, 0.06534095673311142, 0.24607715527376822, 0.2019532640734988, 0.12284747700417235, 0.11730591105597636, 0.29857823324780314, 0.08480068551556719, 0.11137262903033726, 0.23722701645906896, 0.11791175636913508, 60.15404947342412, 66.48866945697416, 55.23879404990904, 56.76353308462328, 73.31715506892051, 97.04985587827622, 75.91843174349877, 0.872983175419992, 1.368891255509469, 0.7256992173291023, 0.3619635820148453, 5.041326774704841, 79.24579405015515, 94.3352383951987, 94.41695705536874, 85.78677777321109, 84.29309214315107, 85.68743198148667, 85.75783852607974, 80.9729705318328, 75.35998036784511, 77.00309261198967, 82.9876567471412, 87.47081602773359, 85.12132413925664, 83.34568285172986, 83.35734798062234, 83.41618353320708, 83.58152712545088, 82.52013375682216, 75.26663580248433, 61.4923111854061, 60.53920269012452, 63.54022772081437, 61.97850073537519, 64.2314552491711, 60.73259907384073, 51.55642978606686, 55.098279060855994, 56.39447727511006, 59.31842773191391, 60.69460699635168, 60.24461307833272, 54.82749823601016, 55.957470324731645, 65.60433580029395, 71.41525268554688, 72.14226399698566, 70.60978612592145, 72.90475706900321, 69.42272786171206, 71.22380964217648, 72.94048986127301, 71.8617517717423, 70.07137021710797, 69.97140469089632, 65.63218855088758, 71.1775178294028, 69.61109576686736, 64.56074999224755, 62.05951729128438, 66.38037281651651, 65.89211617746662, 64.77458976930188, 70.41277331690635, 68.87010512813445, 69.45633472934847, 63.97211990048809, 56.904412854102354, 62.357558588827814, 63.8651607882592, 66.98193888510427, 67.21219770369991, 70.10401218168198, 69.98306981978878, 66.1802456455846, 66.63535825667843, 55.575498150240996, 63.88884013698947, 61.672799048885224, 63.515081405639656, 55.952104522335915, 49.408179021650746, 45.27499321968325, 58.94038969470609, 68.90904641920521, 66.04656342537173, 64.5985734078192, 65.26310528478315, 58.00482596120527, 44.33809195795367, 51.63126860895465, 58.714570999145515, 62.990758572855306, 65.62160991853284, 63.498803569424545, 62.0715864243046, 60.899358641716745, 59.88489250982962, 56.8574816949906, 60.036888276377034, 57.556455904437655, 63.844458518489716, 62.76948198195427, 63.387929931763686, 64.94380474090576, 62.131226062774665, 63.30585825827814, 64.70142579847767, 66.61484426067722, 65.24645482340168, 64.21557749471357, 68.7236830496019, 61.801695977487874, 51.94335199171498, 51.317769250562115, 53.52407893826885, 54.73763673536239, 48.66125383684712, 48.50836769227059, 50.84870476876536, 56.33575547126032, 55.90098034950995, 54.841893334542554, 55.24022963739211, 57.273704005825905, 56.72836119128812, 59.006277668860655, 61.949628168536776, 66.62947470141997, 71.78329652355563, 71.54846422133907, 72.7557776051183, 74.89479511014878, 74.55776153072235, 74.21742531561083, 72.57461117159936, 75.29062501845821, 72.77327137608683, 79.51146402666646, 80.30027620254025, 82.9164892627347, 80.26925809921758, 86.88687709070022, 79.32825796065792, 90.171250220268, 56.75140511605048, 0.31285296404554, 0.2521928811385747, 2.8638874475033056, 1.0494982907848975, 25.419096408351777, 95.53137302398683, 79.9845410931495, 78.71770966437556, 58.20899317341467, 45.506581721767304, 62.95222913065265, 4.504653869136687, 0.4066546387489765, 0.2906174152608841, 0.1191426068544388, 0.10876314969913614, 0.13370671970469336, 0.24318152678108987, 0.08757812196328756, 0.1914026245715157], [0.03899795093363331, 0.03140292269357991, 0.05567892176669933, 0.004372227056357529, 0.02978756501820059, 0.08325522570239921, 0.010426273745965334, 0.011695462143829754, 0.7246384613456265, 53.69167397099157, 41.13046000080724, 28.493155971650157, 40.16366243362427, 54.49858004047025, 79.04747901424285, 58.47392182196341, 0.18362390568419812, 0.19894094506819404, 0.4765634713394027, 0.010897673501242554, 19.351309384069136, 65.27492338611235, 66.66890236639208, 67.38241287969774, 69.7299357383482, 74.86310235915646, 78.0147111031317, 79.04460783927672, 78.36807743195565, 70.40420686045002, 65.37564200739708, 74.4904536585654, 70.93047126646965, 74.95324627045663, 72.63656108610093, 76.29080587817778, 74.65556975333922, 73.74226939293646, 71.3635793808968, 69.54553727180728, 61.676505688698064, 54.65597691074495, 55.528684662234404, 56.549865891856534, 56.83303356170655, 49.794481492811634, 43.87338915178853, 48.36351063943679, 48.64189301767657, 54.14365653068789, 54.6928785693261, 52.27199169897264, 52.504819670031154, 52.08318448835804, 60.251645888051684, 66.84471868699598, 61.97441754802581, 62.37243221652124, 67.41939298568234, 62.98967599868775, 64.72299883442541, 61.97205235881191, 61.69772571133029, 63.091790983753825, 64.6652223217872, 63.212415633663056, 64.76510547822522, 64.3396616751148, 64.55603138093026, 58.48110760411909, 55.71704864501954, 60.77414089633573, 62.654215289700424, 62.63577230515019, 64.55050083898729, 66.40699002050584, 58.42977162330382, 51.91809192780526, 57.662622697891734, 62.006074997686575, 59.56228933026714, 64.24316744650564, 64.77376214919552, 63.73858198042839, 65.17157285444199, 54.73991955480268, 48.24017955410866, 57.798615194136104, 60.85554576689198, 61.46483498234903, 56.04459401099913, 49.58867865224039, 40.58456020970499, 39.9008204860072, 59.47628744186894, 62.347501631705995, 58.064971585427564, 63.54910796688449, 57.00990499988679, 45.63867145969022, 42.97961435010357, 50.514165816768525, 59.58770628898375, 60.34996794116113, 61.65641923104564, 59.8546314239502, 59.65203315980973, 55.83439027109454, 54.786717353328584, 50.19722653973488, 49.20473352555306, 54.9396348768665, 59.64039940987865, 59.315238844963815, 61.466772633214156, 58.55009817307996, 57.05091730240853, 57.210110618222146, 61.78425711970176, 60.10603181777462, 55.73144766592211, 60.068016206064534, 59.821950235674464, 50.92448888286468, 46.456030645678126, 48.984900366875436, 45.89512778866676, 46.739394434036754, 43.79780900093817, 42.909054833073775, 45.61541180456839, 49.411418899413086, 50.53796283660397, 50.86057386090679, 50.64519651474492, 52.41918256205898, 52.43637038815407, 51.95019652766567, 55.6089206664793, 57.54206080590525, 56.52018139439245, 57.71156603290189, 58.26858182107249, 56.61587153711627, 58.075130524173865, 61.51835180098011, 63.441956658517164, 67.42348794014224, 71.70321741411763, 75.3711042096538, 75.93729834402762, 75.95572563909715, 78.49943760902651, 76.96513975820234, 74.61451822711577, 50.739913909666, 0.8028138116482766, 0.3691019586497738, 0.853084930248799, 0.4105327903263031, 17.02442015371015, 76.19409591920915, 72.02358092031172, 62.71492573522753, 38.99057957433885, 27.129098792229932, 32.9711220341344, 1.9488024086721483, 0.07202800798920855, 0.08231975573806033, 0.05441964941940481, 0.0880124401901999, 0.014122401874872946, 0.01370186844254814, 0.011809932916695553, 0.010165580728602026, 0.06388188865516456, 0.09979597563224454, 0.03324993961160222, 0.04051588903812151, 0.0727742235927332, 0.04582153437959571, 0.04549774348795895, 0.04619480689026175, 1.0260743864120976, 69.62144297938194, 50.98152406754033, 30.207996599135864, 40.242643279414025, 64.83588464798467, 87.7145128865396, 66.38114944581064, 0.2701901710562168, 0.3913831662747168, 0.5264860199343774, 0.08732086963831417, 22.393813479331232, 75.50271541841569, 79.00039488269438, 79.67638400293167, 77.08695288627379, 81.08055330091908, 82.47853309877458, 82.95943137138121, 84.25127967711418, 72.28101391946116, 69.04205399174845, 76.38211081104895, 74.71722156770768, 76.82283616835072, 76.2520528608753, 77.75269677562099, 77.28248303936374, 76.61429159102902, 74.0351527737033, 73.69250236019012, 62.72917570606355, 58.4246450854886, 58.4024993834957, 57.113231997336115, 59.52419134878344, 52.716490376380186, 47.91738417840774, 51.228931488529334, 53.97423759583504, 56.634847964009936, 58.037907231238584, 56.01575282312209, 54.86361934292702, 55.0195727809783, 62.10683284267303, 69.82670061049923, 64.83938732454854, 65.03248560813167, 68.9735694085398, 66.1361268258864, 66.49066202102169, 63.62315447099748, 64.49567394871866, 65.03087351399084, 65.16322212834513, 64.6334825023528, 67.9951733927573, 67.94936010914465, 63.86614530317245, 60.8453554491843, 57.650428049026004, 63.25937032699586, 64.11087374533376, 64.69167870859947, 67.15608427601477, 66.7687580662389, 59.06340306805026, 53.16202455951322, 58.31386950708205, 63.69424743037071, 61.59079405569262, 65.45079069752848, 69.38959952323668, 67.19271136868385, 66.88271860922536, 54.65219574589884, 47.853080841802786, 57.5550046274739, 61.406089644278254, 62.150249558110396, 57.5648654660871, 47.61765233932003, 42.34582208818005, 40.724937915802, 57.16877275897611, 64.10906553268433, 58.220324900842485, 63.88525901302215, 59.985073766400745, 47.71720209429341, 42.47621343981835, 52.214038679676676, 61.29940509796143, 62.23054047553771, 62.192113014959524, 61.47824164359801, 60.91629935849098, 60.42360259640602, 56.112039166112105, 55.06541352118216, 51.112405715450166, 56.56396681262601, 60.62249814310382, 62.57788596614715, 62.66753958117578, 60.50492901955882, 60.80541395371961, 61.6251697078828, 64.55809454764089, 61.48232483094739, 60.78501762882356, 61.970577547627116, 62.7163613227106, 54.006165689037694, 47.371492232045824, 52.04719674202704, 49.316434783320275, 49.74837010906589, 46.32799663851338, 44.78558340380269, 47.960993089983546, 51.39877011699062, 52.81386321590793, 53.30456741394536, 52.61429302154049, 54.687159753614864, 54.522784986803615, 54.75324384627804, 56.89519136182724, 58.304812754354174, 59.73561494581161, 60.487811796126834, 59.9394997473686, 58.74711490446522, 62.33148267192226, 64.08862998408657, 68.40778320066391, 70.88943542972689, 73.80095589545466, 78.36551220186296, 79.15572858625843, 78.0210574980705, 81.95475547544419, 77.45481629525462, 78.22704469003986, 56.95858078618204, 1.03030527551328, 0.3720046657948725, 0.7684939919460205, 0.3733684248741596, 14.864804321719756, 86.1006615238805, 74.67178483163157, 72.05852139380671, 42.913067417760054, 37.964138446315644, 50.56795720131167, 5.657243815160567, 0.19161499946588473, 0.015505540105814656, 0.03445485035978979, 0.06332511127355599, 0.04445465349201714, 0.04590185869845652, 0.018730395841562462, 0.005862576898277527, 0.1738231436860177, 0.19108949379334528, 0.16310964921309104, 0.11491885769271082, 0.08420299137792281, 0.20920948035294012, 0.12351906798299282, 0.09402213182540671, 1.1288947852388507, 84.30705578096452, 55.00442066500264, 38.741587515800234, 56.26359170483005, 74.95791389096168, 97.17286140688005, 74.60052321034094, 0.3330512092478814, 0.9116428525697802, 1.2366001283930195, 0.3220838025933312, 26.175778488959036, 89.81353790529313, 90.25971535713443, 91.2017039329775, 84.1881295173399, 91.21321216706308, 90.34849428361463, 89.09892912833922, 90.25380042291458, 78.21796832546111, 74.99892619348343, 84.43920827681019, 77.73180623208323, 81.18145235123174, 81.03419873022264, 81.52029806567778, 84.61116498516452, 79.76859108094247, 76.99261988362959, 75.41861195718089, 67.44532769726169, 61.693728816124704, 63.45319424906085, 59.82805344366259, 64.50879819931524, 54.130010604858406, 50.72254957691316, 53.29551850595782, 56.97132064450172, 60.05062833909066, 60.35942477564658, 59.857890913563395, 57.18387388413953, 56.50509203633955, 64.4712140483241, 72.17838902627268, 67.92868921833654, 66.2795522136073, 71.34706620247134, 68.36904587284212, 70.97054220015004, 66.54770897280785, 68.86936772254207, 68.88519056381719, 66.82226704012963, 69.8507212054345, 69.55579819217806, 71.00094841372582, 68.33096750320928, 64.75933959407192, 60.159952640533454, 65.34841683603102, 67.53592660350185, 66.89072808911725, 70.83669524038993, 70.28066788950275, 60.638391587042044, 55.854241386536636, 60.77463903734761, 65.99066180567588, 64.34530596579275, 70.11356707542174, 69.35481594454858, 69.16237661915441, 69.53888493199503, 59.1927981376648, 47.645614916278475, 59.8079748307505, 63.01807788110549, 64.03286564734675, 57.58686211801345, 50.93197668752363, 42.65328099650722, 40.51685225579047, 60.93507182213568, 66.19779432973554, 62.49639480344711, 67.98474773283928, 62.62049467332902, 46.64120181914299, 42.256407737731934, 54.30959240082772, 63.60785330495527, 64.40101146697998, 66.46116579732588, 65.09386677895823, 65.08491200785484, 63.11909852489349, 59.790861529688684, 56.021075479445926, 53.27338457107545, 60.60757744696833, 64.90817785263062, 63.853778070019146, 64.13936191989531, 63.49544209818687, 63.2425041352549, 62.389808316384595, 67.0184326171875, 64.44694634406798, 64.10635517489526, 64.97976895301574, 67.11693117695471, 57.024641344624186, 49.78621313648839, 54.19179185744255, 51.89163161862282, 51.9059443473816, 48.97909525902041, 49.93311374418197, 51.1035176246397, 55.24165345776466, 55.56483322574247, 56.60185690849059, 56.958588630922385, 57.395611270781494, 57.56491253452917, 56.56967386122673, 60.941641792174316, 63.37401728476248, 63.84656875364242, 63.91392369424144, 65.54570028858801, 62.86805506675475, 65.99001069222727, 66.7035133607926, 71.95799104629025, 73.62311563184186, 76.8468959869877, 84.13535794904156, 82.41177435844176, 81.55839212479131, 86.30112601864724, 79.85540882233651, 82.84616116554507, 62.40814539694018, 1.3958759365543243, 0.6732948196511115, 1.5401798126197632, 0.4505509865139762, 20.932524665709465, 96.20068627019083, 81.23142334722704, 81.22143699276833, 54.39860274714809, 52.102325654798946, 62.821084683941265, 7.648529170020935, 0.6515004762238072, 0.2349967200068697, 0.2120531527625938, 0.40836941931516896, 0.18164615777711715, 0.16522851051582446, 0.10988611202206343, 0.2921924613896878], [0.03249210628470586, 0.004265089660146905, 0.05868544531685691, 0.11888351591844713, 0.10465687245971735, 0.03200740245501361, 0.07128481843298481, 0.0646263882217388, 1.436201333999634, 56.379333003874756, 43.246202161235196, 30.329464558632147, 41.87560442955264, 55.16872875152096, 78.51690784577401, 61.85032552288425, 0.4320348252452189, 0.40148847886631567, 1.163331479314835, 0.09108759372705415, 4.096709720550045, 45.08139287271808, 58.43152492277084, 62.34289284675353, 67.57086707699683, 72.8240268461166, 78.807814351974, 83.37761094493251, 80.01650841005387, 75.05215275672175, 63.32014745281589, 63.98463618370795, 68.93378088551184, 71.98428661592546, 70.10376114999094, 68.15737124412291, 72.24726584649855, 73.12100518134334, 70.63167295148297, 71.31307494255805, 63.42539641164965, 54.86085407195553, 55.88494177787535, 54.28051194837017, 57.195131086534076, 49.19574345311811, 45.158679254593395, 48.63811185283046, 52.15064141058153, 55.1516507517907, 55.52635869672222, 52.74004813163511, 52.76668102510514, 52.50342330624981, 59.98515221380419, 65.05662387417209, 64.49005711463191, 63.964620328718624, 62.0936183775625, 63.40049720579579, 60.81969530351701, 59.9981705604061, 51.38632835880403, 52.624750060419885, 56.636613030587476, 58.776528758387414, 58.8382903991207, 61.0200225153277, 58.0597666002089, 55.194353595856704, 54.35687265088482, 57.57550293399442, 62.20902235277238, 65.85086853273454, 62.25537300109864, 68.31286184249386, 60.24656641867853, 52.57963888106808, 58.46370012529435, 60.89811525037212, 57.83816445258356, 62.197780839858524, 64.97439530587965, 66.53418464045372, 54.42386673342798, 51.87212174938571, 59.21252373726138, 45.021635563142844, 47.390107800883634, 46.70073947598858, 47.69076139696183, 45.92740889518492, 42.26550371416154, 41.6582815877853, 47.967825858823716, 65.0600794822939, 60.94929825875067, 56.77699858142484, 54.87021284718668, 45.656031870072894, 45.629877505763886, 47.029975383512436, 56.445052316111905, 62.21301140323762, 61.22314637707126, 61.20391891848657, 60.013797283172615, 56.66989041912941, 57.07658529281617, 54.338245314936486, 52.00943608437815, 54.24540673532794, 56.62813286627493, 57.76949551797683, 59.97734669716128, 59.87207812647666, 60.94664673651419, 61.774592399597175, 60.84895226263232, 57.99821284509475, 56.93001024184689, 60.80994036889846, 57.702579882837114, 52.25915770376883, 45.10242069921186, 50.27734095050443, 47.364216235376176, 46.651890277862556, 44.47027191039055, 42.72152631513534, 44.051319629915305, 50.65977596467542, 49.99431840835079, 51.218497983870975, 47.32418060302735, 50.80076556051932, 51.92061793419623, 51.69208103610624, 52.007823990237334, 51.4891376033906, 53.47040130246071, 52.260734496578095, 52.54675765191355, 56.00997909422844, 59.63296651840211, 63.63592963064871, 67.98907802950951, 70.89319306035196, 74.54531977253576, 75.41818834120228, 76.99032137470861, 77.41144272588915, 74.97883581346082, 74.32883631798529, 68.24817411361202, 57.277681289180634, 0.6457642549949308, 0.1456460621087782, 0.1931699281257968, 0.28084084631935247, 4.130954463635722, 71.47561796249883, 69.57398230029692, 64.48721731862715, 41.006564094174294, 29.171212180968258, 36.566017443133944, 4.265523139507541, 0.36088431734711895, 0.015412108022569409, 0.08042454614394134, 0.02394185067274638, 0.038233104071790175, 0.039015785460510564, 0.10576941598687442, 0.040059212535139055, 0.029987173057311488, 0.03781485070865001, 0.039729549579562685, 0.08577580819086683, 0.029381831446962974, 0.05478565175566943, 0.12277941009210003, 0.055409990431320284, 2.1551798764736425, 67.06051964913645, 49.76002739321802, 33.66851160603185, 51.0296437048143, 64.56451154524281, 88.82942307379939, 69.55670818205803, 0.5316956016805865, 0.6139587971471971, 1.8014162850956765, 0.16770153426595275, 4.316502184637131, 58.755759808325, 75.92791603457543, 77.29014735068046, 77.25947441593294, 80.46554919212096, 83.85614795069542, 87.01881777855658, 83.15092932793402, 80.30375926725327, 67.18467050983061, 68.76297735398816, 72.26030380495133, 72.8446271342616, 73.77309137775053, 73.74917276443975, 76.43805165444651, 74.59420034962316, 75.09215308773902, 72.62542155481154, 66.99946403503418, 57.26279981674687, 59.235049909160985, 56.830385961840236, 58.16128538500879, 52.249626344250096, 49.30382436321628, 51.54806729285948, 54.475167412911695, 55.61856185236285, 57.95989128851122, 54.6659867994247, 53.6339759057568, 55.03156738896524, 60.626887275326645, 67.46406093720468, 66.02175051166166, 65.45901198540965, 66.30372970334946, 67.04687764567714, 62.81945297794958, 60.34664569362518, 56.41687008642382, 54.280072642910866, 58.464621882284845, 60.907576007227746, 61.68566050068025, 61.377044493152255, 60.798965577156316, 58.249350440117624, 56.202787122418805, 60.64598921806582, 67.1228696453956, 66.85807827980288, 64.7351424924789, 70.32016615713798, 62.03737943403183, 52.80146852616341, 60.735301586889456, 63.659063769925034, 60.91072174810595, 66.22556471055555, 64.86190565170781, 66.84325172055152, 54.802775536814046, 51.49718238461403, 60.539139932201756, 46.63332962220716, 47.40511871153309, 46.160946815244614, 47.77741439880864, 46.55468610025222, 42.94033573519799, 42.59499065337643, 48.51312944965978, 66.11066279872772, 63.896763324737556, 59.963061424993704, 57.0104423646004, 45.55169682348929, 46.23642106210032, 47.60204130603422, 58.334387425453436, 63.62625706580378, 62.94822439070671, 64.0604438320283, 62.47427263567525, 60.15832485691194, 59.199120998382575, 57.604967778728856, 54.711156814329094, 56.34186652398879, 59.19079380650675, 58.667522168928585, 61.59645795822144, 64.19187853413244, 61.50229753986482, 62.54773470663256, 63.52202400084465, 60.305860888573434, 60.82945416050573, 62.530237013293856, 60.28407996700656, 55.08322108176447, 48.91908691775415, 52.55613211662539, 48.82133753068986, 48.34248673531317, 49.21810096310031, 44.94038366502331, 46.80479995666012, 51.700749474187056, 51.43564039661039, 53.738895385496086, 50.719847063864435, 54.85448806516586, 54.3889811731154, 56.609391781591604, 54.79404434081047, 55.03052796086958, 56.72074002604331, 54.10555070446384, 54.519109725952156, 59.047195834498254, 62.73065836198869, 66.58795249077582, 71.7927808146323, 74.8194150001772, 76.62515655640634, 78.41326313634073, 81.20515131181287, 80.54001146747221, 76.24394924409928, 76.6529740056684, 72.51666207467356, 63.52034130404073, 1.8927805438157053, 0.34454761493590574, 0.14652266587701537, 0.2540033614082683, 4.044607161514221, 81.69827953461679, 76.09731535757743, 73.83703385629963, 51.264746650572754, 39.21773187575802, 51.09392350719821, 9.418416830801196, 0.33562112779867265, 0.11496656198775577, 0.08094730922171185, 0.04287707161218409, 0.013743735147610068, 0.07764009999171381, 0.06758429966266118, 0.050569663064614426, 0.22729114719456245, 0.11919824015950004, 0.2540714666247368, 0.21559689163921342, 0.17926098899014536, 0.11758595449669708, 0.22220902715719518, 0.1964202706491755, 2.896767205769016, 83.26447409968223, 59.97251433710898, 41.4571032216472, 59.43834635519213, 76.58819998464277, 95.6537352838824, 81.54001189816384, 0.761132132141821, 1.0259173077441033, 3.187530055161446, 0.32273942063893046, 4.91550547461356, 72.85737483732163, 89.57727786033385, 87.83726738345239, 85.39455644546017, 86.06183790391492, 90.8828152379682, 95.03673861103674, 89.26703406918435, 84.82856627433532, 72.30597588323778, 73.20678741701188, 75.97719669342041, 78.90215519935855, 77.16620045323526, 75.25400577052947, 79.06440796390658, 80.15281077354186, 79.54092102666056, 76.14953779405164, 70.80231958819975, 59.23104124684488, 62.672921073052194, 60.419315445807676, 60.99124800774359, 55.39723427064958, 53.04598123796525, 54.22504571176345, 58.44019336085166, 60.261020352763516, 59.30394634123772, 59.4496702378796, 57.558181747313476, 57.472823127623535, 64.36845579454976, 69.37445917437154, 70.39551488814816, 67.15170691090246, 67.09495021450904, 70.7566475099133, 66.72384692776588, 63.35221675134475, 58.89306237620693, 56.83974473707138, 62.7379814271004, 65.37541843229725, 66.63867658184421, 64.43048415645477, 61.69089294249012, 58.15007525105631, 58.30043931161204, 63.263990879058845, 69.91682098757836, 71.1190745138353, 67.54767017979776, 71.87050650196691, 62.679585179974964, 54.4209014215777, 59.465473467303866, 64.56812012580134, 63.04234166299144, 67.0823044930735, 71.07732480572116, 72.67903251032676, 56.8444319694273, 50.54608998760101, 65.94415034017256, 48.81991371031731, 49.63895951547931, 48.70021081739857, 51.87287092208863, 49.056585604144686, 42.90550116569766, 40.86879476424187, 49.167161141672445, 69.91419299956291, 64.29692352971723, 60.33117978803573, 58.62605879383703, 47.979949905026345, 46.136020152799546, 49.65070309177522, 59.751437787086736, 68.53497782061177, 65.68499542051747, 65.55998948312575, 65.78050513421336, 60.438142822634795, 64.30300320348432, 60.327861462869954, 56.70022210767193, 58.160367550388465, 63.1797226782768, 60.825300370493245, 64.43323766031574, 66.73439810352941, 65.5978403552886, 66.12496376037598, 65.36595767544162, 61.15259470478181, 67.08264966164866, 67.06379875060051, 62.358907884167095, 57.727663440089074, 52.871345550783225, 54.669046248159106, 51.526070640933135, 52.02089725002166, 53.8154875078509, 47.88571888400663, 51.99626868770969, 55.9471623359188, 56.383118091091035, 57.56403784598074, 52.32213135688536, 57.26765963339037, 58.934498294707275, 57.12306145698794, 59.19967797494704, 59.51515028553625, 58.98068812585647, 56.76735739554129, 60.060238146012836, 62.797342577288234, 67.7397172681747, 70.52885193978587, 76.02922301138602, 78.08026959819179, 80.88351695768296, 82.6037508441556, 84.58951350181334, 83.23426400461506, 80.15183802573912, 78.23140636567148, 72.66162503150203, 66.6323458763861, 2.782712035602139, 0.5521856957385617, 2.143785881419336, 0.5926652300742365, 6.242507532719643, 91.60515108416158, 82.46806037041449, 82.43428091849051, 60.128875701658195, 50.31674508125552, 69.67044122757451, 13.029758737933252, 0.8071558754290304, 0.3630602215566943, 0.24165443775634615, 0.26257476679259734, 0.10881737340241672, 0.21224657464171612, 0.17859404816502528, 0.1792153914368922], [0.10260541923344137, 0.02410830242649442, 0.0456534048932935, 0.044658448201634234, 0.04038556599088254, 0.07559457628597176, 0.05689345457921586, 0.07932992907421244, 1.1267569709208705, 48.64228917706398, 38.45157138762936, 23.63220968554097, 41.445453782235425, 58.22223901748658, 78.42836426150414, 63.12375437828803, 0.7882570992073705, 0.2990453630205124, 0.12511572545214047, 0.10946641841362562, 0.7532143376527295, 26.05762100988819, 57.48823412003056, 55.93264564391106, 71.82845869371968, 75.25430387066257, 77.41108971257364, 77.58158729922387, 80.16712742467081, 75.77478670304822, 66.28548283730784, 63.096995968972486, 67.17884971249488, 66.65518976026966, 69.1497544319399, 69.51413477620771, 71.77577341756513, 66.97665937485235, 67.85616459385042, 69.65975669122511, 60.50874548573648, 51.8254102430036, 55.647418729720584, 56.183210572888775, 55.29601358598279, 48.577832868022305, 45.67028968564926, 48.11367134894095, 51.422523990754165, 52.057045813529726, 53.01077404329854, 52.65993372086556, 52.829737047995295, 53.677643652885195, 57.82588351157404, 62.30461051387172, 63.06026297230875, 64.54720997041272, 60.96957691254155, 60.81912263747185, 54.551312385066865, 53.65285427339616, 53.97994072206559, 54.223488530805035, 49.593836569016986, 49.543759669027025, 53.39418180527226, 54.540737675082305, 54.61438017506754, 55.64299037379604, 52.40945116166146, 53.9585167361844, 60.13593204559819, 63.29100816480575, 63.34786292045348, 69.62248632984777, 52.572884559631355, 49.542402528947406, 58.47654588760869, 59.70803283875989, 61.75734181557933, 63.85345643566501, 43.38970599635955, 46.578922425546956, 43.78062901958343, 50.59561383339667, 46.619040427669404, 41.11958326831941, 46.73824910194644, 48.23246425197971, 43.02929509070612, 44.43442144701558, 44.06743664895335, 41.2780587903915, 44.05191583018149, 53.70457464648832, 60.117877375695016, 62.277718743970325, 55.468797914443485, 45.20974459186677, 42.67387343991188, 50.053271632040705, 47.48338960832166, 55.75048685073853, 63.2653009506964, 61.5362338865957, 59.415733891148726, 59.49028638101394, 59.55800610203897, 59.24079225909326, 51.70047883064517, 51.864147570825395, 55.53315224186067, 54.92214502826814, 59.427606905660326, 59.34498217798049, 59.017632930509514, 61.87025508572979, 57.951666078259876, 61.245829443777765, 59.32227165468278, 58.476777307448856, 59.040861206669966, 51.79381947363577, 47.20095934406404, 49.94383750423309, 48.39460719016291, 46.571011004909394, 45.542734207645545, 42.47650369521111, 41.353321229257894, 48.25817146608907, 51.85308256456929, 48.49515322716006, 52.1216433278976, 48.55491445910547, 52.75343518103323, 50.94770539191462, 50.97285170708933, 54.69654990780739, 52.33151366633754, 53.46733400898596, 53.93792821514992, 57.806495235812285, 62.95400988671088, 67.24235288558468, 68.96591294196345, 72.04356931870984, 71.1649662448514, 78.25312845168575, 72.69835410579559, 75.69951641944148, 70.55475527240385, 77.45863668380245, 71.36849803309288, 83.42741720138058, 13.1543489040867, 0.5870152397021171, 0.3410939373556645, 0.3861662607279516, 1.9090140082182425, 63.979686152550485, 69.81247025151407, 65.66940792145269, 38.42911581839285, 37.127747920251664, 32.79944381406231, 7.888955752695761, 0.5511655117715559, 0.12522329951846792, 0.07763973993038939, 0.026487593403867176, 0.08360576455391223, 0.01321750935242181, 0.046873533978096904, 0.0776918568918782, 0.041160873783331726, 0.12928769473106633, 0.07852185187080214, 0.03589063702571777, 0.028470724993836016, 0.042016777855854844, 0.05752060096710921, 0.09230158261714444, 2.838813941324911, 60.9354522920424, 44.693850932582734, 24.851325481168686, 48.42550370001024, 67.08486187842585, 86.1975440671367, 73.71480495698991, 0.954893786580332, 0.38868877375798844, 0.5906732176100055, 0.11811136823868561, 0.9099174387031986, 32.33154231502164, 73.01767426152384, 70.38033531558129, 79.41237711137342, 83.31158961019209, 83.51392115316084, 80.40189696896462, 84.11746409631546, 79.3272538338938, 68.81975758460261, 64.86096036049628, 70.78692036290323, 69.47081612002465, 71.77218052648729, 71.85531908465971, 74.42735841197353, 71.60994345141997, 71.85480133179696, 72.06271832989108, 64.23875085769161, 55.062569802807225, 58.93757343292237, 58.427182858990086, 57.943291817941976, 51.464512963448804, 47.776229843016594, 50.17710085838072, 53.061839380571925, 56.52553935204783, 54.98117277699133, 54.892272257035785, 56.602955172138834, 57.101821822504846, 60.69027277731127, 65.4887435513158, 63.23819345043552, 64.24608568991384, 61.80458676430487, 61.233544580398075, 57.13836654540032, 56.65571497332666, 55.50649189179944, 57.07185883675852, 53.55682680683752, 51.06161886645902, 56.42296937204177, 55.95650149929909, 59.217932685729004, 58.21805384851272, 54.2272343943196, 55.6711059231912, 62.47562193101453, 65.25099300569104, 64.75908464001071, 69.88912905416181, 55.72152014701597, 51.04177951812745, 57.41041429581181, 60.78111487050211, 65.1513098901318, 64.50123194725283, 47.0608679709896, 48.25722617487754, 45.07397567072223, 48.69532746653403, 52.27386659191501, 43.323166908756384, 46.386271292163485, 47.812056772170536, 47.88482850597751, 47.16139439613589, 44.4216815886959, 41.051522301089385, 43.59926646755588, 52.49802220252253, 58.615825330057454, 66.56902313232422, 56.102590176366995, 47.15966070851972, 43.64307934238065, 48.98726947845952, 47.588124736662834, 56.81624581736904, 63.02642860720235, 63.46906023640787, 62.52949960770146, 61.35902512458063, 63.33391497212072, 61.39893131871378, 53.09111595153809, 54.20782650670698, 58.14514875411988, 58.869947848781464, 60.026078224182136, 62.12357744093865, 60.634198573327836, 61.66711161213537, 61.14347127176101, 63.934218037513, 60.42082555832402, 60.666573816730136, 62.04001526678763, 55.23459711382466, 50.21975663400466, 53.44431361844463, 51.411953203139774, 49.387531665063676, 49.04091181293611, 47.31400205243019, 44.23681636010447, 50.61444905496413, 53.27247065882529, 51.97686864483742, 53.045008490162516, 51.5473848004495, 55.92546770649572, 55.43255129168111, 53.15728633634506, 57.78775022875879, 52.85970003374162, 56.73998709647887, 56.18106111403435, 61.16041983327558, 65.75096576444565, 70.07104858275383, 71.62117711959347, 75.72046187616165, 76.56799977825534, 81.9939007297639, 74.35532016138878, 77.56199898258333, 71.59886667805334, 80.70493144373741, 73.1373457754812, 90.60100863056799, 21.365199358232562, 0.8899608482756923, 0.4788632672880927, 0.4743489562984436, 1.9338487401123972, 70.69991434774091, 76.11746065078243, 73.85906973192769, 44.959144361557506, 45.4032390348373, 45.398339994492076, 12.371126105708461, 0.33666968766239386, 0.14549632256309833, 0.09266126089759412, 0.02019308560017136, 0.0516761047014546, 0.023944633487131328, 0.0602228726981388, 0.02768371329312363, 0.21318656452480825, 0.19180885035424464, 0.1312751106677517, 0.12873232695123843, 0.12207601114266342, 0.20650420938768696, 0.17859960996335555, 0.2655622032621215, 4.205917331480211, 72.88600813957953, 57.452913176628854, 34.64560147254698, 58.58284604164862, 80.25135640175112, 95.02392815005396, 83.11695375750142, 1.2887095515766454, 0.7624513355474319, 1.8555152079751416, 0.2492895304796196, 0.8908046481590118, 41.001869017078036, 90.82849825582197, 82.48758592913228, 90.82907092186713, 88.54985221739739, 89.075638094256, 87.94226138822495, 88.12765613678964, 84.41343046003773, 71.94900881859564, 69.00090832864085, 73.64826586938673, 75.18687048266011, 77.38884987369661, 75.25665729276596, 79.16939412393879, 74.42086296696817, 77.61937541346397, 76.02544969128024, 66.75368047529652, 56.58046822394095, 63.343917016060125, 62.000724884771536, 60.22800968539331, 55.00129845834548, 51.483477623231956, 54.65470998517929, 57.300246684781975, 57.41186557277557, 55.965832817939024, 56.18052374932074, 60.41669530253257, 59.191546901579834, 62.74518289873677, 69.29613728677073, 65.41060993748327, 69.48248124891713, 66.4351212593817, 64.97262631693195, 59.86183289558657, 58.00473966906148, 58.024320140961684, 57.942848590112504, 53.67355262079547, 56.388530961928836, 58.957263731187396, 58.5495686531067, 61.97844189982261, 60.856287094854544, 55.90645990064068, 58.61156563605032, 66.26206628737911, 68.66781280886742, 69.20047852300829, 73.59066978577646, 57.92049892487065, 51.3200246134112, 59.69104897591376, 63.43852066224622, 67.62970262958159, 68.78536624293174, 47.105641826506584, 48.04907775694325, 46.65992721434563, 51.52946741350236, 56.145340088875066, 44.2107718221603, 45.19103488614483, 48.16272451031593, 51.44668579101563, 48.59404794631466, 43.48669052124024, 41.34521761248189, 44.46742034727528, 55.50437773427656, 64.90259631987541, 71.15117519132554, 57.82369482901789, 47.156287470171534, 43.610021606568374, 48.894191634270456, 49.319058848965554, 61.52319200577275, 67.25608902592813, 67.55899798485541, 63.791275101323286, 65.16524607135405, 66.74287826784196, 63.74294757843018, 57.03167415434315, 56.76146599554247, 61.347199178511104, 61.52550228180424, 64.65683237198861, 64.05268538382747, 62.883364077537294, 65.35073887917304, 64.45887427176199, 66.16280678779849, 67.20560027707008, 64.81452342002623, 65.59570266354469, 56.99564326194025, 52.887639076479026, 56.06241333869196, 54.132544455989716, 51.00489747139716, 53.78740333741712, 48.59415777267949, 47.10784619854343, 54.55026511223086, 58.46879136177802, 52.52208202115951, 56.54288407294982, 52.599415471476895, 58.96281388498122, 57.414775971443426, 56.75404487117645, 61.91721762380293, 55.94669165149812, 59.15830481436945, 61.187048804375436, 63.5592237595589, 68.30260876686343, 74.05230137609666, 76.77459885997158, 77.5403553439725, 78.11165640431066, 85.34124359007805, 75.83113547294371, 79.54000319204023, 74.10225668261128, 83.15299249464466, 74.82400417327881, 92.6309685553274, 20.379464587857647, 0.8550528569086906, 1.1259981148665952, 0.7550758087346632, 2.9166599963941886, 77.925124168396, 84.43665089145784, 78.51938678372291, 54.810137825627486, 58.04657959168958, 63.73626385965655, 17.9074005926809, 0.939670455071234, 0.3692409269992383, 0.48250629115969906, 0.12206378437939192, 0.24107879929004178, 0.1808162853722611, 0.16831567631133143, 0.11238011125955852], [0.010484944589646354, 0.07110399103933765, 0.07707793701199755, 0.06603258091115183, 0.042320539378711296, 0.021837048998643315, 0.040475562169787385, 0.1439793458989551, 1.8066580425347052, 50.53144777974775, 38.330256400569795, 30.164509281035397, 48.97761652546544, 54.61685519064627, 73.49461878499677, 70.35873874541252, 2.333983817408162, 0.3945669051139586, 0.38757996873990186, 0.06680389355507589, 0.2945780285423802, 18.281745718371486, 54.886977057303156, 58.441930970838, 70.60405946546986, 70.01033029248639, 74.71597425399288, 77.05908052382931, 78.17897212120795, 74.6307646843695, 64.34116786526096, 60.3730667791059, 65.36868764508155, 64.757315651063, 64.72335969248127, 63.95879560901273, 65.71744518895304, 64.75045150326144, 64.11337229513353, 63.61610597179782, 56.99423905341857, 53.9829570247281, 54.57740006908294, 55.117620268175685, 56.53115226376442, 49.054059597753714, 42.08713000820529, 48.614377590917776, 50.29111239217943, 53.48994255065919, 52.63213980582453, 52.59882711595105, 54.23233739791378, 54.263245674871634, 55.52508784878639, 58.98663836140787, 58.65534320954354, 58.73726191059236, 58.064649951073434, 54.11629799873599, 51.95674296348326, 53.56384784944596, 55.823148758180686, 55.8325546018539, 57.57689537540559, 55.192533616096746, 50.35287403291272, 53.17338374353225, 50.61959128226004, 52.95397027846306, 53.095767882562455, 50.97842147273403, 52.394012712663226, 61.13266906430645, 64.31877897631738, 63.856813984532515, 48.81429295386038, 44.913864520288286, 51.680729696827555, 55.922510239385794, 58.10346572629867, 46.62207634218278, 45.6292381594258, 44.78521077863632, 46.949233393515314, 45.722049282443145, 45.552328325087025, 46.797978954930464, 45.46151368848739, 42.793352757730794, 44.70792047439083, 43.29457675257037, 43.18161641397784, 42.85072526624126, 41.92101763140771, 45.75537766179731, 41.25374401769331, 47.17645629759758, 52.06823633563135, 45.00460070948447, 44.021529228456565, 46.32389383931314, 50.61784582753336, 55.211090349381976, 56.405295172045314, 59.04827056392547, 59.6029446971032, 61.40829009394492, 57.128886176693825, 55.10679060412992, 48.830923803391, 50.712433784238755, 50.96906269750288, 53.71469436153289, 52.913993481666814, 54.53788218959686, 56.775190368775405, 56.49414470118862, 57.2626115429786, 59.03126708922848, 60.28177753571541, 57.69279356925719, 58.010305512336, 51.81456881184732, 45.5403886302825, 50.11067551951255, 51.397636552010816, 46.503350119436945, 46.954097132528986, 42.469306145944905, 40.94859146302746, 46.3649022194647, 52.410153265922304, 51.589824845713956, 50.67333559836111, 49.192542799057506, 51.129875952197665, 52.01246807652136, 52.94755720323133, 53.04070957245366, 51.39331410008093, 53.81054532143378, 58.34214979602445, 62.094716641210745, 67.28095685282062, 69.43856639246788, 73.8472790871897, 74.74689822043143, 73.81382126961985, 72.57081431727256, 73.88267455562469, 76.42286423713931, 78.64144309874504, 76.32997466671851, 80.49822253565635, 79.44301866715955, 78.50832569983699, 1.7663080077017508, 0.146318641341021, 0.060692791030892444, 0.6786120214289235, 64.47424996283748, 71.05201767336938, 63.90984442926223, 41.93593048280285, 35.43779473150931, 35.93640642781412, 7.815505939145242, 0.0715165140648042, 0.0780478885938083, 0.07325643763667153, 0.07196548755370802, 0.02317212191560576, 0.05243244032645899, 0.051925776586417234, 0.036141209063991424, 0.03277613338263285, 0.07336378187662171, 0.042341426765966805, 0.035352065723629734, 0.03898161793908766, 0.01965463687215121, 0.1258671504535502, 0.12132003557898345, 3.503374255472614, 64.50382463393673, 44.894554691929976, 36.24146484559582, 55.1673480772203, 66.20847886608493, 82.16811672333749, 81.19877353791269, 2.9225979745388035, 0.31534605929928444, 0.5677336646664528, 0.08900430188664506, 0.2937782633929484, 23.575451027962472, 75.38715454839891, 72.24080178045458, 80.90408586686658, 78.49434637254285, 82.00467155825707, 80.42373672608407, 84.20947505581765, 78.83991502946424, 68.72291426504813, 62.94154851667343, 68.31809428430373, 68.1255922009868, 69.02623115047332, 67.87623143965199, 69.19461065723051, 68.79490544719081, 67.84125958719562, 65.01478787391417, 61.07559465592908, 56.976098091371604, 57.85100237015755, 57.0524666386266, 58.58785490835867, 52.106412764518495, 45.56053784585769, 51.4658740258986, 52.89351478699715, 54.779366831625666, 55.42669519301384, 52.451102810521284, 58.80745272482596, 54.836099993798044, 57.04579468696349, 61.802421615969756, 61.09733243142406, 60.23062982866841, 59.978358668665734, 56.61229041314895, 54.78217917103922, 56.788400911515765, 59.55262853253273, 58.10879230499268, 59.382597707933, 58.694264888763435, 53.69065807711694, 57.5757186643539, 52.744445108598285, 54.58316595323625, 55.158232488939845, 53.8249090410048, 54.996371961409054, 64.97651730814289, 63.498415254777484, 67.07103160119826, 50.81776511284613, 44.10544049355292, 52.34060572039697, 59.325397783710116, 59.032271215992594, 47.02116966247559, 46.784572293681485, 45.24596375803794, 47.805675075900176, 47.082711650479226, 46.29520170150265, 46.723010693826986, 45.364183995031546, 42.4049400514172, 44.294322229200795, 43.901869481609715, 42.3691798025562, 43.20135378068493, 44.86449364692935, 44.710854407279726, 41.674598647702126, 45.77957476339033, 55.232486878671956, 46.22670142881332, 44.81138083242601, 47.6920557791187, 51.389379962798095, 56.50761804273052, 58.78669554187406, 61.1505001591098, 63.544228538390136, 62.49681057468538, 60.76316610459359, 58.673139003015336, 52.598540782928474, 53.49815207142984, 54.34993397804999, 55.12502962543119, 56.31104453917473, 57.835485473755874, 58.33132797671903, 56.82453770791331, 61.01544118696644, 60.75067727796493, 63.298131189038685, 60.85549085370956, 61.44151649167461, 54.99799190029022, 49.97188245096515, 52.09943879035212, 52.75048555866365, 48.67681780169087, 49.11111047191005, 46.042244126719815, 44.14720981351791, 49.577923513227894, 54.953229811883745, 53.550096019621826, 52.43945337110951, 51.40979197717483, 52.87891572521579, 53.83887267881825, 55.51062999233123, 56.39061766286051, 55.15428266217632, 55.65281591107769, 62.4614151062504, 64.46525989040252, 71.3251401532081, 73.27911592298939, 76.72338055026147, 76.4394715524489, 76.53396144989999, 74.98871234155472, 76.64320730393933, 78.27320314222767, 83.50019285755774, 80.49748513006395, 86.14088150762743, 82.66772470166607, 91.45432026155534, 3.8879025895749373, 0.1893603873829688, 0.12017780614476051, 0.6879581715310774, 72.48467122354816, 76.24577706859958, 74.25614695395194, 48.29374736355197, 44.313592833857385, 48.97183887420162, 11.084730875107551, 0.23056054998549724, 0.08249303716565333, 0.12273509190568041, 0.0241190736227098, 0.0406587069794055, 0.022595311334777265, 0.09792614653105698, 0.012428851520282128, 0.08887785141386333, 0.17436570247575162, 0.2569137141108513, 0.10557912740736239, 0.15305260016072184, 0.1569239029120053, 0.23684225645997833, 0.27500953825731433, 5.251873231703236, 81.93162133616786, 53.274906450702304, 44.3008529755377, 63.72861916019071, 76.88726502080118, 87.98646650006695, 93.00725721543836, 3.39053820698492, 0.7066062224968788, 0.8080780614287624, 0.2594162475678229, 0.6715329399993343, 27.338349396182647, 93.51876566486975, 80.59046883736887, 90.17692981227752, 83.46770778779062, 86.59058909262382, 84.91230887751426, 88.32535143821471, 84.07786384705575, 71.54620493611982, 65.64145711160475, 73.61730267924648, 70.90918064117432, 72.20796369737195, 70.67367369128813, 73.90558119743102, 72.39315448268768, 71.87981820875599, 68.36609625047254, 63.846957068289484, 59.64915021773308, 61.94828279556767, 60.36213121106548, 61.89254591541906, 56.205403343323745, 48.6785004984948, 53.61343837553456, 55.636969535581535, 60.930039421204604, 59.01730345141504, 54.591222501570186, 61.44256376451062, 56.76563939740581, 59.48798394972279, 63.89898338625508, 63.82273643247543, 63.34738831366263, 64.15501217688283, 59.455651852392386, 58.28479689936484, 58.72935441232497, 63.480266447990175, 60.5574966246082, 62.66690023483769, 59.77988281557637, 56.159393941202474, 59.26869207812894, 55.365074757606756, 57.99143498943698, 57.76168215659357, 56.563484361094815, 58.91305861934539, 69.49726858446675, 69.55372718072707, 70.10692258034983, 52.793953264913256, 44.23487478686918, 51.58780090270504, 59.65979945275092, 62.02690278330157, 46.554050676284305, 45.25611877441407, 45.4449926653216, 48.149635561050914, 47.012520836245635, 45.24121376775926, 48.19358964120188, 44.63978105975736, 43.37278096906601, 44.329227401364236, 42.865751866371404, 41.56998903520646, 44.16606856930641, 44.92752613559846, 46.18068810432188, 41.859510944735625, 45.66588094157558, 58.19312326369747, 47.45033579487955, 42.47711166258782, 48.55605979119578, 53.609680744909475, 58.71026423669631, 60.406316711056625, 63.81144785111951, 66.46987345910841, 66.6154561504241, 61.43246758368708, 61.780244535015484, 56.2367352362602, 55.82192105631675, 58.36827670374225, 59.1280907969321, 60.05191095413701, 61.47442517742034, 62.76510853921214, 60.71013958223405, 63.37684531365672, 64.71593856811523, 67.69998365832915, 64.55494096202236, 65.1142591814841, 56.8112918638414, 50.44968205113565, 53.629990777661725, 55.07253654541508, 51.36568100221696, 52.68300510221913, 48.87290100897513, 47.75542951399281, 53.51696375877627, 58.18907537767964, 56.974156518136304, 57.847040776283514, 53.80245347176829, 55.75196166192332, 57.51189385690997, 59.3835469215147, 61.19246167521323, 59.382146635363185, 59.9689136012908, 63.766815200928725, 67.20632199318179, 74.8327902824648, 75.58426933903849, 80.39315008348035, 78.58658482951503, 80.66104796624954, 78.44355167881136, 80.73305483787291, 80.82495597101028, 85.56022167205812, 82.3515110631143, 89.81669149091168, 86.46713641382034, 92.42829184378348, 2.997955530881882, 0.3467176355902226, 0.2912825940837783, 1.2768599487120107, 80.62810005680208, 82.35409198268768, 81.11134390677176, 60.01025930527718, 58.61415440036405, 66.52117806096231, 17.254557378830448, 0.515016274106118, 0.26187612524917053, 0.2927198669602794, 0.17717935956053196, 0.1776913361203286, 0.19227241015722676, 0.1705390166851782, 0.15820592040977172], [0.03842808877027804, 0.015583165879962186, 0.017882334594164166, 0.0500818335961911, 0.026230639853184263, 0.020697217419623368, 0.10759070575717958, 0.11702894728871123, 2.331115584219656, 41.426359684236594, 35.69085821028679, 20.376869939988662, 47.93201461915047, 59.42365315652663, 69.02696071132537, 76.05326714054232, 4.934764312159631, 0.13530370659164845, 0.5652278217096482, 0.15193785030034282, 0.34434558222851447, 10.77831139487605, 49.91373331316056, 57.8179132553839, 71.31997831406133, 67.74707563461797, 77.22933492352887, 71.34876066638579, 74.73822193761026, 67.8401142551053, 64.29482113930487, 60.87045469591695, 64.32137166300129, 60.076143357061575, 64.49363431622906, 61.381123758131466, 63.7055830801687, 63.17625138067431, 62.17639607767906, 60.29041067246468, 56.43684279534125, 52.01371146786598, 57.41725098702216, 54.28720743425431, 55.723312670184725, 47.13644027709962, 43.73689066979193, 46.86797757302561, 50.07721770194269, 50.55305611702704, 53.79029020186394, 51.92319493139944, 53.49054267329555, 54.04185925760577, 53.71061117418351, 55.91805442687004, 59.59887327686433, 56.78791061524422, 52.95789264863538, 52.12966849727016, 55.48764490312146, 57.860623944190245, 58.49770315231816, 59.85996976975472, 60.44889796164728, 60.63499873684299, 56.283544801896625, 51.99094603138586, 49.85845142795194, 50.3757728299787, 51.569554036663426, 53.18338578747165, 55.726952629704634, 56.161370815769324, 60.44357138295328, 63.20457873805877, 50.3502421225271, 48.29304525929113, 49.1889734422007, 58.42315850719329, 51.28159715283302, 54.158930240138886, 48.161991027093705, 47.929159133665024, 54.399877517454094, 56.116565581290956, 58.4607465805546, 53.503015810443515, 54.14750045345676, 48.201230418297556, 45.13069706578409, 47.67371869856312, 51.86242172794958, 56.707804049215014, 50.25010401202787, 43.1790158825536, 40.80283226505403, 42.27081852574503, 52.35952331173805, 49.45488268329252, 45.695447767934496, 49.79042576205347, 58.686082824583984, 57.361572942426136, 59.75123382383778, 59.75474826751217, 60.845198554377404, 61.12243560052688, 58.3888416905557, 51.134673010918405, 48.05242353870023, 46.90986848646595, 49.74657758589714, 49.15035378548407, 50.570004678541615, 50.26986883532617, 51.133174665512584, 52.312113623465265, 53.95208012673163, 57.22128545084308, 56.190678765696866, 57.00251133211198, 54.87343703546832, 54.70307280940395, 48.23773199512113, 49.83798057802262, 50.10642367024576, 47.401745473184896, 47.7605442846975, 43.63789396901285, 41.4812610995385, 44.34452856740644, 53.21507069372362, 50.10980867570447, 49.16259550279187, 49.45575344947077, 49.60046929697837, 49.778537058061175, 51.80672407150269, 50.68801310754592, 53.71464337072065, 54.499752829151774, 59.24017252460603, 62.10195733654884, 69.3987778694399, 68.72096092470231, 73.49204571016374, 69.5810817903088, 72.72837592709449, 72.35642540839412, 78.00356372710198, 74.90424017752372, 78.71312049127395, 75.10690119958694, 82.09336419259348, 69.83350200037803, 95.77771356028896, 33.957868776013775, 0.29660613906960337, 0.13523030004674388, 0.9949916252686132, 69.05699037736463, 70.61084516586797, 63.20557894245271, 51.178583944997484, 33.91808417535598, 30.246886899394376, 8.728009077810473, 0.21075201371023733, 0.07582067181506465, 0.09483843681312377, 0.007960361206994183, 0.02610929918685748, 0.12410743116971948, 0.061791280675078594, 0.04977799929498185, 0.014534410663820324, 0.04205183403926992, 0.027944840107774063, 0.06283440131453738, 0.025407014895350705, 0.050158457710377635, 0.04049430068041529, 0.2600763395668999, 5.660285122932927, 56.552890039259395, 42.540010790671076, 29.891310314978327, 58.36448769415579, 68.26041975329, 76.51923687227311, 87.82830868997883, 6.441754131547867, 0.15649469449154793, 0.6406612514007477, 0.10725047844912737, 0.776885473920453, 14.660370388338643, 68.62308209942233, 70.6193410196612, 81.39246017702165, 78.60124664921915, 86.29646624288252, 76.14664308486446, 79.39358895824802, 70.62192193923458, 66.70795348382765, 62.96577307485766, 68.0164404838316, 64.35880284155569, 68.85774181735131, 64.4893785445921, 65.96959867785054, 66.18715686182823, 65.01691772091773, 63.02462039455291, 59.98246931260633, 54.76226922004454, 59.58632169231292, 55.74579177364227, 57.13598958907589, 50.24279271402667, 47.213252052184075, 50.924814439588985, 54.401787711728005, 54.60177367733371, 56.66612102139381, 54.2263989294729, 57.151686914505504, 55.5241660917959, 57.37682704002627, 57.22174436815324, 60.71939245347054, 61.048098841021144, 56.98029110508581, 54.629147898766306, 58.832057752916896, 62.475296374290224, 61.604494894704516, 60.97115370535082, 63.090543670039025, 63.01412020960162, 59.875486666156405, 54.46554191650883, 53.76178633782172, 53.24708115669989, 54.52866069732174, 55.36915402258597, 58.09512284494216, 57.341643379580596, 62.94225846567462, 64.65778550794049, 50.043234286769746, 49.67369602572534, 50.42763833076724, 59.026579856872566, 51.423810528170684, 54.670709333112164, 46.026307536709695, 48.81056670219668, 56.05358408343408, 58.312759476323286, 59.332336456544944, 56.57090548546084, 58.202442815226895, 50.23757203932732, 47.06720652118806, 49.709456274586344, 53.61507400389641, 60.34334305794009, 52.98940104822959, 42.91052964425857, 40.88082467356036, 43.70423301573723, 49.02315524316604, 47.282101415818744, 46.8051568923458, 49.878110347255586, 63.36011640487179, 61.22132247494113, 61.548338320947465, 62.71757333509384, 62.38452880613266, 61.766496627561516, 62.65219919143185, 53.197690671490086, 51.35843638450869, 49.75805836339151, 51.479449349064986, 52.57380239425167, 53.47540624680058, 52.80794435931791, 52.12038816944246, 55.30086555788594, 56.54641812847507, 59.18371392834572, 59.169922874819854, 58.558915661227324, 59.30009065135833, 58.99300829056771, 51.776914058193086, 52.19177138420844, 52.97192688911192, 51.205703212368874, 50.30223231161795, 45.94962912221109, 43.79835028802195, 47.52611206423852, 55.495968172627116, 51.43713481964604, 51.840825157780806, 50.66857384097192, 51.88229245524253, 52.63472857013826, 55.74630560413484, 53.3798376975521, 56.20556023813064, 54.65573372379426, 61.67708619948357, 66.1673959609001, 72.12818268806704, 73.1764518060992, 76.39527428534724, 73.05170474513885, 75.21612351940524, 75.64070440107777, 81.1133913840017, 79.0969636363368, 82.11025391855549, 77.17788127160843, 85.70503557882002, 74.90475008564611, 97.63905863608085, 42.70500921433972, 0.1775665557192218, 0.043477833931965214, 1.1686738700635972, 77.79993780197637, 75.40784897342806, 72.61128533271052, 56.11163908435453, 42.00507402420044, 44.29889963519189, 12.767772847606292, 0.1747497729957104, 0.13081921174401237, 0.10484464060995849, 0.05023236221243298, 0.022300750527891423, 0.0398319793654786, 0.028611660274046085, 0.0601803663096601, 0.14474964730681913, 0.12232633037192207, 0.1237239352157039, 0.15098595541090737, 0.14109171536420623, 0.2716192008266526, 0.22791003898507167, 0.3658613760865504, 7.9974877353637455, 76.14521534212174, 49.39033615973688, 30.115815016531176, 61.11000560945081, 80.75227445171726, 82.14062875316989, 98.80697573384931, 7.291753320924698, 0.25081827425427977, 1.6988568464594505, 0.2914551170843263, 1.0662906929369897, 18.181470324916226, 88.15355162466727, 77.92631656892839, 91.07167736176523, 83.18603454097625, 90.56287534775274, 81.16799077680035, 84.26456866725799, 73.56484490056192, 70.84404576209285, 64.79452717688777, 72.10270297142768, 66.33379074835008, 69.75883576177782, 68.75165739367085, 70.27239953317951, 71.89336607533117, 70.57096250595586, 67.78289471903156, 63.12647650318762, 59.333105241098714, 62.88967517114455, 59.42358255386353, 61.07048380759455, 53.85554667442076, 50.9153183814018, 53.61181843665339, 56.603418011819166, 56.459631766042406, 61.26712399144327, 58.55110229984407, 58.90769673931984, 57.95587870382494, 57.771303730626265, 60.2632051129495, 63.716098954600675, 63.31109854482836, 60.83755777728174, 56.69377765347881, 61.4800420115071, 66.16153593986266, 62.68597079861549, 64.51930230663669, 66.2679341531569, 66.41043386151715, 61.79423562942013, 58.54171606802172, 54.74090406971594, 56.92176934211486, 57.60064924916914, 58.1877927626333, 60.994028968195764, 59.651848808411636, 66.56338276401644, 67.44006387649044, 52.18338143440985, 50.07984176758797, 52.81546354293824, 60.66775052778183, 52.206484194724794, 54.66433155921198, 48.75736759554956, 48.96779883292414, 58.94047990922005, 58.6802424153974, 61.744503898005334, 56.52199352941206, 56.780203157855624, 49.44428443908692, 46.931421910562825, 49.0427121808452, 53.419453636292495, 62.66624127664874, 51.88286119891752, 44.26293150071175, 41.71311632279427, 42.25648618513539, 51.88727778773154, 49.53219652175904, 47.99636502419749, 52.24298184917819, 65.767522088943, 62.8139106688961, 66.59040004976335, 65.74329753075877, 65.27530385601905, 65.82452589465727, 64.91604612719628, 56.384804710265136, 53.86455635870657, 52.774988605130105, 54.79884532190139, 54.664519832980254, 55.743689383229906, 54.61277592566706, 56.538651835533884, 59.225632298377256, 59.346582505010794, 62.428263233553984, 61.1208313511264, 61.25610605362923, 62.82670544039819, 62.33119633889968, 53.61051620975618, 55.3241369801183, 56.830939016034534, 55.48765274786181, 54.758311548540675, 50.82852025185862, 48.76028976132793, 50.984418776727495, 57.176252718894716, 55.480408130153535, 54.51829387295631, 53.13543088974492, 55.80463909333753, 56.832045124423125, 59.32464076626686, 56.287000410018436, 60.069812651603456, 58.563065528869636, 64.48638185378044, 70.47843379359092, 77.03068256378174, 76.26902887898108, 79.59955261599633, 75.38716239313926, 78.1617372266708, 79.43632710364558, 83.12291576016335, 81.37634708035378, 85.127137091852, 81.16663363672073, 89.32830933601626, 76.55856255562075, 102.7231877849948, 39.868802178290586, 0.5202388487035229, 0.31858275013585247, 1.5219101478015225, 86.3334620383478, 81.2623159347042, 80.27645957085394, 67.43048544852965, 53.91225630237211, 62.23763604317943, 21.69144053612986, 0.6533095468917202, 0.27215883316051576, 0.2449894636388748, 0.13325393109792663, 0.1756747935207621, 0.3837070265604604, 0.18178118843465083, 0.20540424502424656], [0.07209435120345124, 0.07914002353866255, 0.012284248594134566, 0.10020124380506816, 0.03376746647841027, 0.03345264264592721, 0.1288551308455006, 0.11100518261833538, 5.284648556863108, 39.83930595459477, 32.29522705078125, 32.65804629172049, 37.359924777861565, 60.03543699941328, 71.36681141391878, 78.97919839428317, 19.093539061084872, 0.3664757479583064, 1.0978195624005411, 0.177608935703193, 0.5070161711304418, 10.545626590328833, 60.853894449049434, 63.13735323567545, 76.01301577783401, 69.73901210292694, 77.05626426204559, 73.34888704361455, 72.6017382837111, 62.71319989235171, 58.88164827900549, 55.29187940782117, 62.68592373017342, 60.21414410683417, 60.58646725070093, 58.003421752683586, 62.64691575880974, 59.80384849732923, 61.15801542035995, 55.67137264436292, 54.10477407516972, 51.4924676956669, 52.634481460817405, 52.266884773008286, 55.75762556445215, 49.78104345260128, 44.15208139727193, 47.04211904156593, 49.43036786971554, 51.10440408029864, 50.575331257235625, 52.483583957918235, 54.100988987953436, 51.62383571747811, 50.97767230003111, 55.21929594778246, 62.98484756100563, 58.99285531813099, 52.86142587661744, 57.46552751910303, 62.795044068367254, 60.31228180854552, 59.906991143380445, 58.10127312137235, 63.395456960124356, 62.47308807988321, 59.69728554448774, 53.68216614569388, 51.86060174818962, 50.23472832095239, 50.03183195667882, 50.44517917017783, 52.787842212184785, 54.12159319846861, 59.693104297884055, 58.417216116382235, 46.36264293424545, 52.71323088676699, 56.272546475933446, 48.89882003107379, 45.666869378859, 48.81732494600358, 49.42348018769295, 53.397723705537864, 54.3975672414226, 56.95312084690217, 58.05093342258085, 62.861410571682846, 66.57551857732958, 62.564275341649214, 58.89271720763176, 60.24946505023588, 58.938012738381666, 56.02667270168182, 53.88105384765133, 47.14477531371578, 37.98735103299541, 41.34139722393405, 45.0585646783152, 50.486713147932484, 44.02132918757778, 50.99618980961462, 61.45749622775663, 60.51586850996941, 58.17811627541819, 57.80560878015334, 55.617110575399096, 56.43905501211844, 51.0064781865766, 49.2588230102293, 48.615342493980165, 50.53560156976023, 50.761867415520456, 50.40600645926691, 51.16904866310858, 47.53068947022962, 50.8416719590464, 51.292289533922755, 49.461715452132694, 53.315891296632834, 53.63607829616916, 55.11955007430046, 54.09265787370744, 51.91799386855095, 49.95187836308634, 49.056824868725194, 52.15501877569383, 47.15685229147635, 46.72037878344136, 45.78444242477418, 42.398221031312026, 43.56702458473944, 51.35312941766555, 51.29017929877005, 50.19364149339738, 49.0556913037454, 50.72406361179967, 50.3216637334516, 50.55165190850535, 46.90815048833048, 51.36890911286878, 50.65038188811272, 54.60078916242046, 65.01631759828138, 68.79255986982777, 67.39114407570132, 71.41089100991526, 71.85946895230201, 71.07786609280494, 75.70536075099822, 74.6623868326987, 71.9492990739884, 76.24906401480399, 78.02325402536701, 76.36086725419568, 79.03594724593624, 80.20648448697983, 75.58912523331182, 2.0911160495973404, 0.2729473214957022, 2.028499699888691, 65.4321280602486, 72.86868695289859, 66.56961148785007, 44.702621352288034, 41.925673484802246, 31.43578475521457, 5.966843357009273, 0.13329785857950488, 0.05172384730089576, 0.06472351284877909, 0.01431400333756521, 0.07994625447017532, 0.0009652874829161222, 0.030571422351884748, 0.038621307636100444, 0.08840017261043673, 0.01646171646913694, 0.032730386442234444, 0.06738320924341679, 0.0889331859446341, 0.08524487095494425, 0.0766145304266003, 0.15999067544696793, 8.951103687286377, 59.94654432419808, 36.23340437489171, 31.083591215072143, 44.7106033755887, 71.85473072913386, 79.23729035162157, 91.59508628229942, 21.522145155937444, 0.34676035265288047, 1.1014053441824452, 0.25687119623105376, 0.7522454509331334, 14.363409703777684, 78.51762956188571, 70.89567984304121, 84.96351934248402, 77.27427744096326, 84.79329632174584, 78.48647809797718, 77.77706253913142, 67.48411209352555, 64.0558821155179, 60.51119696709418, 64.87496714438161, 63.61156386713829, 65.61451042852094, 63.35987714029128, 64.39016219108336, 63.20168010650143, 64.75885714254072, 60.100764074633204, 56.787777254658366, 53.74200582504273, 56.71644503070463, 56.85712083693474, 57.55426329951133, 53.4879852879432, 48.315081134919204, 48.620708296375895, 52.88858044532038, 52.773615775569795, 53.18722971024052, 56.06979131698609, 55.66996059110088, 54.64218977958926, 54.317472442503906, 56.081570194613555, 62.422611098135675, 59.843986111302534, 53.60304017220774, 61.21893767387637, 65.73698251478135, 63.80618795271843, 62.81848807488719, 61.94040275389149, 65.87674833113148, 64.69730730979674, 63.39712004507742, 56.137460047198886, 54.99407737485824, 54.645963099695024, 55.85069948627103, 52.25262695743192, 53.74696370094053, 56.2439759315983, 62.812706501253196, 59.13128752862254, 45.6711055386451, 53.542592525482185, 54.98472252199727, 48.3714299048147, 45.006801159151145, 47.885157985071984, 51.48976910498835, 55.47423039713214, 58.21730075343963, 60.027811911798295, 62.056826545346176, 65.61652260441934, 69.19949008572486, 65.0444096134555, 61.64192215088875, 61.93397006680889, 60.542066020350305, 57.737853757796756, 55.90681291395619, 47.24798856243011, 39.58744664346018, 41.42080953044277, 46.18073125039378, 50.56642355457429, 45.49455573481899, 51.533272112569506, 63.30927072032806, 60.5599324164852, 59.53522889844833, 59.794262224628085, 56.34424348031321, 57.59884888126005, 51.886199135934156, 51.75708647697203, 52.30617515502438, 52.525584697723396, 54.88462755756994, 54.89455899884624, 53.76977228349256, 51.817742009316724, 52.891369250512895, 53.698553808273815, 52.83968810112246, 54.88205056036673, 56.483558224093535, 57.2356491704141, 56.355233961536044, 56.25602545276765, 50.136869107523275, 52.11590097796533, 54.966150099231356, 51.15482614886377, 49.73795229388822, 48.24873424345448, 45.385541300619806, 46.43958806991578, 54.97796427819037, 53.67168949496362, 50.725228555740856, 50.998931546365064, 52.58105877907046, 53.883344511831964, 52.266100298973825, 50.799110320306596, 54.30827056207965, 54.98565212372811, 58.18364289499099, 67.89298780502813, 70.92056335941439, 73.68621872317406, 76.93900108337402, 76.45427457747921, 74.69749204574093, 78.83434526381954, 76.9687718729819, 77.26796242498583, 77.48202185476981, 81.50918206860943, 77.52385785502773, 83.45929038140082, 82.11232493000647, 86.6982424643732, 3.15481920396128, 0.33252763411691116, 2.4644830342262023, 74.0360470741026, 79.52308208711686, 75.49792228206512, 51.75561951052759, 49.37614502445344, 52.26445290350145, 15.141771704919877, 0.24637234427275198, 0.03624158190383065, 0.05435406463220716, 0.04816388268203986, 0.05812710894632244, 0.016278175209018014, 0.04315971975184737, 0.017717734857973073, 0.19046582161418854, 0.15456683423009612, 0.1450190344645131, 0.1847200396080171, 0.1587920542806387, 0.18911856406879043, 0.43868698119636507, 0.3691186287230061, 12.785977548168553, 77.48176297833844, 48.63360897187264, 44.57653284072877, 50.94252786328716, 85.62544284328338, 84.08795218313895, 103.60492091025077, 24.285086239537886, 0.30600003177119844, 1.9958185116129539, 0.35841193711084707, 1.4087152024430614, 20.823072887236073, 94.29196680745771, 78.40042914113691, 93.58059790826614, 80.86382665941792, 89.2565691855646, 80.23749474556216, 83.50862595342821, 71.75245100452055, 67.15801408213954, 61.730324529832416, 68.4771385500508, 67.64782397977768, 70.29780864715576, 67.61035749989172, 69.4092192188386, 66.90172641508042, 69.50194404971215, 63.20810494884368, 61.522309472483975, 56.913559821344194, 60.20822525024415, 57.73260562650619, 60.84605755344514, 56.104339553463845, 52.68816301899572, 53.275263386387984, 56.041742447883856, 56.045021549347915, 55.79178940865302, 58.44976394407211, 58.426021837419086, 57.11283191557854, 55.56382125423801, 59.30291083551223, 68.02990990300333, 65.73401720293107, 54.72168837824176, 62.68073835680562, 67.75698354167324, 65.06923821664626, 65.32207027558358, 66.10728171563917, 71.25137605974751, 65.75655906431138, 66.24663568312123, 56.9288609873864, 56.996137480581964, 56.32809508231379, 59.11874378881147, 55.886032196783255, 58.97494185355402, 60.53713952341388, 66.8088133104386, 63.584173956225, 47.374614438702984, 53.1547446404734, 56.62442622646209, 50.35261907885152, 47.431661390489154, 49.170561836611846, 52.59498319318218, 57.122684909451394, 61.46938493174892, 62.01945812471452, 64.75289906224897, 67.25494369383782, 71.27132523444392, 65.83136650823778, 61.538493171814956, 63.391228645078606, 66.05057993242818, 60.49661359479351, 57.07988792850126, 46.04910827452137, 39.07687171812981, 42.31960888831846, 48.23813992161905, 49.88832027681413, 46.6873328147396, 53.65609415115849, 65.93328537479525, 64.59470202845912, 64.0803380935423, 61.79775791783487, 59.42634390246484, 61.359072193022705, 53.890867617822465, 54.397418191356046, 57.36105126719321, 54.388471264992994, 55.19238064366003, 57.077730624906486, 56.136212733484086, 54.842179667565134, 56.14883099832843, 56.92417767740066, 55.684390990964836, 57.118703703726496, 57.79316702196675, 62.957724371264064, 60.52584309731761, 57.835320734208636, 53.80202593341951, 53.48592212123256, 57.149729651789514, 52.75647501791678, 53.14984952249835, 51.36120165548017, 49.646039393640336, 49.87475279838809, 57.79849360066076, 58.42889301238522, 53.788321172037435, 54.62340162646387, 56.53649845430928, 57.24614543299521, 55.864459160835516, 53.32560308517949, 58.71839531006352, 59.08348560333253, 61.64987279522804, 71.96767145587553, 74.12415135291316, 75.56753650788339, 77.35811418102634, 77.66121925846224, 76.8666333536948, 82.01152001657795, 79.57730493237896, 80.70199751084851, 79.86403803671561, 84.57696976200228, 81.73114115192045, 88.02977731150966, 86.40258989026471, 88.05717114479312, 3.1699504823453966, 0.5627436743628594, 2.98120308787592, 81.72115479746174, 84.39793709785708, 82.32141863915228, 63.63243872119535, 61.200828090790786, 73.31926530407321, 22.48549888210912, 0.23099420171591545, 0.16775093161531035, 0.2928241468485325, 0.10012100375587903, 0.20462265148037867, 0.09044096189280672, 0.18251081057373555, 0.15019778883264912], [0.07531224224235743, 0.0176884779601448, 0.030244249182062286, 0.04072937475998075, 0.0774537720867703, 0.02915710913047435, 0.09438708079077544, 0.2955123800183496, 6.371223541998095, 44.198173169166814, 29.841768818516886, 36.65415310090588, 43.224291801452644, 61.21310903180031, 69.82043266296387, 79.7580320604386, 16.310386003986483, 0.3091375295433306, 0.8598861362664931, 0.11246304027736188, 0.5832462096887251, 31.545885685951482, 79.05119742116621, 65.24799239250922, 75.91227362232824, 70.43586823248094, 74.28900072651525, 71.09556382702243, 68.01046279168898, 59.29403451181228, 59.71592072517642, 56.98161294383388, 58.08720750193442, 55.33568443790559, 59.82499399492818, 57.65437003104918, 57.614950210817405, 56.46128700625513, 57.07715795886133, 51.89536571502686, 54.75333013842183, 50.695818624188824, 54.83793958540886, 50.89232936982186, 53.757832588688025, 47.54671235238352, 44.145130957326586, 46.578494887198175, 48.347758400824766, 50.50593276177683, 54.00130195002402, 52.82503804852886, 57.45368196118263, 52.90231658566383, 54.54123189372402, 56.99869878830449, 59.07620960666288, 53.31305934536842, 57.281336938181234, 64.59176025082989, 63.03007248909243, 64.10237396917036, 61.92190093378868, 61.45404454200499, 62.33014122132332, 60.21568167594172, 64.95366557951897, 57.894281802638886, 53.04202748883156, 52.22007912974204, 51.55460588393673, 49.73062138403616, 52.62764869197723, 55.3496676875699, 57.19182452847881, 57.87655268946002, 51.017527503352014, 50.67291982712285, 49.65917541134743, 47.20626631090718, 44.045012458678215, 51.856267529149214, 53.58237320376981, 53.12877854993267, 50.98493652959024, 57.48295460977862, 60.35774992358301, 62.22306443798927, 61.107750246601725, 61.7258922515377, 60.85632631855627, 61.34342193603516, 54.880595361032796, 52.003827095031745, 53.0362694494186, 53.47319795239357, 51.47362855172927, 44.57215939798663, 43.580125301114975, 47.75248773636357, 46.8280949131135, 54.815507550393384, 58.28822505089545, 55.873837547917525, 54.81224021603985, 49.946673377867675, 52.413714778038766, 48.685996147894095, 49.90630826642437, 47.18612494007234, 48.82166308741416, 54.87361746449625, 54.49330053021831, 54.010311634309836, 53.35574257758356, 51.57504927727484, 51.5036189940668, 50.23252394891555, 47.31520229770292, 48.86132217222645, 53.98138807665918, 54.029766590364524, 52.145652155722345, 53.37677040407735, 51.840456454984604, 50.56972226788921, 52.656215313942205, 47.8065497644486, 46.17089786837178, 46.536725567233184, 43.60561678486486, 43.890047457910356, 48.38307149948613, 52.04474133829917, 49.134013191346206, 50.55884553540138, 51.30828888185563, 48.46391154873756, 49.28070199105048, 49.08143774155648, 49.025406683644945, 51.568769562628965, 53.42544309554562, 59.86112294658538, 66.7487225993987, 67.74964870945101, 69.29443497811594, 74.02516641924458, 72.16088741056382, 72.95654804475846, 71.88312868918143, 74.56686142952212, 73.10134626203968, 71.8105334620322, 68.35084607524257, 80.27789515833702, 75.61389892332016, 94.2947752245011, 11.471913918372124, 0.9600120506459667, 2.651745321289186, 64.1473400208258, 73.743100935413, 63.45044466757006, 48.78899366624894, 33.05658263544883, 28.51816696505393, 9.36739463959971, 0.345443784589729, 0.14780842188385226, 0.020718434224686316, 0.0650077084860494, 0.06328611739821012, 0.005279010858371734, 0.018438089248393814, 0.09112016778559455, 0.032296213772027724, 0.023685954323398973, 0.0514224453288461, 0.05746712802999443, 0.04636654082024771, 0.10948532546359686, 0.1319699370933156, 0.3097274785320605, 12.217948725146632, 60.955087677125015, 39.77754039149131, 37.95118285763649, 46.218189885539395, 75.67414652916693, 78.6314175205846, 88.50214050662133, 17.785546279722645, 0.4698766575705621, 0.7705825314887109, 0.17926854261707875, 0.8919752917943463, 36.16976391884589, 94.66343879699708, 73.66619894581457, 85.61222445580268, 74.91723891227477, 82.4333473943895, 74.45397561596286, 73.32000270966562, 62.46540023434547, 63.10271478468373, 59.7511318422133, 61.53863829951133, 59.007634808940274, 62.98465144249701, 60.10979729314005, 61.13573243541103, 57.76547116618003, 58.95400031920403, 54.95530866807508, 58.43514134806972, 53.78341428695187, 57.53917001908826, 54.806717518837225, 56.43025713582193, 51.45395394294493, 47.213244207443736, 49.32040029956449, 51.18445573314544, 53.790352959786695, 55.06785715779951, 55.805411800261474, 57.340717700219926, 55.0449622831037, 55.069681059929636, 60.01810012325164, 62.68528438383534, 53.50392187795332, 61.18831965231127, 66.922044292573, 64.43188444260629, 65.40822905878868, 63.16593162475094, 65.4684256738232, 64.90659713745117, 61.9127735783977, 65.85766992261334, 61.47976352322487, 57.60125329417568, 54.701582308738466, 52.72764167478008, 51.285107674137244, 55.23888034205283, 58.44546502636325, 60.68367535068143, 60.337020197222316, 53.86757266136908, 50.24149048712946, 51.678662607746745, 47.849746827156316, 46.078808461466146, 53.61928662946148, 55.885035914759484, 56.02032630674301, 55.97534456560689, 58.81225370591687, 62.83087099752119, 64.01896084508589, 62.96197622053085, 64.16919546742594, 64.55056359691005, 62.03737943403183, 59.538468776210664, 54.89857158353252, 58.06881550819644, 56.28113646661082, 51.81468256058232, 44.4582223892212, 44.51236286470967, 49.525379442399554, 49.56315186715896, 57.82842912981587, 62.76014281857399, 56.94051434916835, 55.99946714216664, 51.26813165603146, 55.088594728900546, 49.346531129652455, 53.029730858341345, 48.84589549033873, 51.14234516697546, 60.05968901418871, 56.87138649725146, 56.82866796370476, 54.67347852645382, 52.92363858992054, 53.89980669944517, 52.568679778806626, 51.526211846259336, 53.408023849610366, 57.361914188631125, 55.506719389269435, 53.77906437843077, 56.398572229569965, 54.623264343507834, 53.68979123330886, 55.74539169188469, 51.02150870907692, 49.43849502071258, 49.66751044796359, 45.71748756593274, 47.17866851437477, 51.59491608219763, 54.4550338868172, 51.46066904067994, 52.954856734122004, 54.17838911856375, 52.68114589875745, 52.3766601470209, 55.07669818016791, 52.004309546562936, 54.41977177896808, 55.96193398198774, 63.182550707171046, 69.05267577017509, 71.48489829032653, 71.70079338935115, 78.50640373845255, 75.08289629413237, 77.66240381425428, 75.2519896722609, 78.21962356567383, 74.82854627793836, 77.1970538170107, 72.41642198254986, 85.03972315019178, 78.33246231079102, 99.4821176221294, 12.961708557221199, 1.0951894906259354, 3.15841160474285, 72.60763752845027, 79.15406550130537, 72.43268412928428, 56.40023531452302, 37.397897243499756, 44.427600445285925, 22.872466195014216, 0.2615485154092312, 0.14804868237866511, 0.07035732344393769, 0.04716299646984666, 0.08576630870060575, 0.09330983859516921, 0.07391347294493068, 0.00869581327518268, 0.18579112245671212, 0.1702122648637141, 0.14380990257186277, 0.23448250647033417, 0.19602711432643477, 0.16120889314240025, 0.25201928561493275, 0.6149561210505424, 16.04873155393908, 81.11810607294883, 45.600965715223744, 51.92668191848263, 56.53881657508112, 85.414105538399, 82.07849056490006, 103.071164777202, 20.613922303722752, 0.35923529776834673, 1.330298442513712, 0.1418488707032896, 1.2553198851885334, 42.93773912614392, 103.52117830707182, 78.48028075310492, 93.10734825749552, 81.10586043327086, 87.26010630207678, 78.86303347925987, 77.51194169444423, 66.42310311717372, 68.22272577593404, 64.13803223640689, 64.6036881785239, 64.35763005287417, 69.01393059761294, 63.840928385334635, 64.89510851521646, 60.96666651387369, 63.88564732766921, 57.602167206425825, 63.64810859003375, 55.74053187524119, 61.000818590964045, 55.8732609595022, 59.604764676863155, 54.13787103468373, 49.977644412748276, 52.58637751302412, 53.92589046109108, 57.55707563892488, 59.00278675940729, 59.281027932320875, 60.62656171860234, 55.65953885355304, 58.1923270225525, 59.75271255739274, 63.84095584192584, 55.45063734054566, 63.84336025484147, 73.27020429795789, 66.30704802851524, 67.13532709306287, 64.70085705480268, 67.26161172313076, 68.98100622238653, 63.55947086887976, 68.88515134011546, 61.800942882414795, 58.60409352087206, 58.52872125564083, 56.05749860886605, 52.18375405957622, 57.11229847323511, 60.19240633133919, 62.50459255710725, 64.54802974577873, 54.56560157960462, 50.68813862339143, 52.10804447051018, 48.11164740593203, 47.06683781839187, 53.30037440023115, 60.69972961179672, 58.378082629173036, 57.89058692993657, 64.27631539683189, 66.72005791817942, 65.25804934963104, 65.92132214576968, 67.56729772014003, 66.37628570679696, 67.24971125202795, 62.42866723768173, 56.90363622480824, 61.554916135726444, 60.809002922427275, 53.36012386506604, 45.2512118893285, 46.35198585448727, 51.972114732188565, 48.952917360490375, 59.24704059477776, 66.15753512228689, 60.67854096812587, 60.19313981456142, 51.970330053760165, 58.2169085164224, 53.90072061169533, 56.44575442037275, 50.59585702034735, 55.500322003518384, 60.73909844121626, 60.85181167048793, 59.94374767426522, 56.69094177984423, 55.95631714790098, 56.42305566418556, 54.708501369722434, 54.41568466924853, 55.399752432300204, 59.70021163263629, 58.31399894529774, 54.74906259967435, 56.93556431801089, 58.8950784744755, 57.274629685186575, 59.745926856994636, 53.17672952528923, 51.396832466125495, 52.833090674492624, 49.356548863072554, 50.61904215043592, 54.83199327222763, 57.7364730834961, 54.15120317089943, 55.28467401381462, 58.385342936361994, 53.3957350638605, 55.82969911636845, 56.598338542446015, 54.18741449233025, 56.32087007645638, 60.14089776623634, 66.77087614613195, 73.19007812007781, 74.33875206978091, 74.86514983638641, 81.90101900408345, 77.93467906213577, 81.48315322014594, 78.36475910678988, 82.04201252229753, 79.44753723759806, 81.1486142681491, 74.27349167485391, 87.75870230890091, 80.28147235993417, 102.54239789901241, 14.018132282841592, 1.1745050861950845, 3.8519373968724286, 77.57553115967782, 86.83345440895327, 77.2832675133982, 70.28669265008742, 49.11685674421249, 58.738195434693374, 32.34215428752284, 0.5045209921175434, 0.3546749602162069, 0.4024848221771179, 0.2116463907183178, 0.17788656596695224, 0.19241513233752022, 0.12076550283499303, 0.14349551540949654], [0.12429602669491885, 0.037048107779194275, 0.04512755065074852, 0.04535189949937406, 0.11578242264447675, 0.01940458385844625, 0.08247744727639422, 0.2632378618563375, 8.711780271222516, 45.95501453645768, 22.896949629629813, 30.601478968897176, 57.2166060632275, 56.9463312241339, 74.17036471828338, 70.59795625748174, 3.3387354641191425, 0.36441334733559244, 0.28478941669867885, 0.1708270351011907, 0.7605728879570962, 59.54943572321246, 74.1674856985769, 70.87966088325747, 73.87994458598476, 70.93485647632231, 72.70393956092097, 68.499723557503, 67.91797330302578, 58.77116687836186, 58.273739737849084, 54.71557732551329, 57.34864873270835, 56.10026028848464, 55.112254465779955, 55.6341689632785, 54.82317578408026, 52.08665578596054, 52.834157559179495, 53.53012723307456, 53.31249452406361, 50.3671161590084, 52.96822809403943, 52.71350153030888, 53.20313492128926, 48.62264594724102, 45.75496581292922, 45.27136110490369, 48.73567296612648, 50.30818646953952, 50.89899347674463, 52.00368588970554, 56.173043789402136, 53.30880749610163, 56.051548373314645, 56.7161939990136, 62.121435826824566, 57.22365064005698, 61.10811894939792, 62.89795137220814, 61.71724342530774, 63.026762008667, 63.35078116386168, 63.84209725164599, 63.844650714628166, 62.12020812496063, 63.10707253794517, 60.14277658154888, 58.906049343847464, 53.12643689493979, 53.52718153307515, 52.180420044929754, 52.524662940732895, 54.35088319163169, 58.08499920752741, 58.1466470995257, 56.561166240322976, 46.463702801735174, 44.81016489767259, 47.424687416322776, 51.41533820859848, 53.15246966577346, 48.37144167192521, 55.50457385278518, 53.80168076484434, 58.635437180919034, 60.272022601096864, 62.676270777179354, 56.40020785793182, 56.255644982860936, 60.11524154293922, 59.38712804548202, 56.38454583383376, 55.42301993216238, 50.38779097218668, 50.68277674336588, 51.390129135501006, 48.48024822050526, 42.62369063592727, 42.50958496524442, 55.07582349161948, 55.47759579073999, 59.83773777561804, 52.140537385017645, 49.137798278562485, 47.827373627693426, 49.30306734577302, 51.32242902632683, 48.654138657354544, 45.869632382546705, 53.65288565235754, 55.85763815910586, 51.28574309810516, 52.72536670008014, 54.15482744093865, 51.570871953041326, 51.84301384033696, 52.684652497691495, 50.613966603432935, 47.524794147860625, 52.49521770784932, 52.55581440464143, 54.7210451095335, 53.30019004883305, 54.72566173922632, 50.42969365273753, 51.577967520683046, 48.58705828266759, 46.63744418851791, 43.33160392699703, 42.47111435859434, 44.873554322027395, 49.036142210806574, 48.47837332756289, 49.14376420359458, 49.710860483108036, 50.2712808885882, 50.45886431970904, 48.545830249786384, 49.10572113529329, 51.23933361422632, 51.22345585976878, 50.495228613576586, 53.6030754735393, 58.70062305081276, 66.8817929298647, 66.11841340218821, 70.77713012695312, 70.39592281464608, 69.61843844382994, 68.65178600434335, 70.83786410670128, 66.49205054006269, 68.94050382798719, 67.54661898459157, 79.31082694761216, 75.5524040037586, 92.09565131895005, 21.68320159758291, 1.2411428459229008, 4.629103320260202, 69.40797974986415, 72.52757410849296, 63.62986564636231, 49.10130846884943, 35.97519082407798, 30.36703694251276, 14.381240798581032, 0.2427125890408793, 0.013027689044153499, 0.10972666614238294, 0.005452625534211796, 0.03970027735997592, 0.02857573266561714, 0.010773304872395051, 0.07672362134701784, 0.0336944506383471, 0.012401838302462092, 0.052481898962850534, 0.05438699875207198, 0.09000878871208237, 0.03966683379164146, 0.07665213002192398, 0.3074148123062426, 13.93191074171374, 64.83055806929066, 28.01903751588637, 30.785555801083966, 64.0186470554721, 69.51601751389043, 83.23470331007435, 78.81354101242559, 4.103694726382533, 0.38760276751652845, 0.3663658603064476, 0.027564082918087804, 1.0961985203527636, 66.4691831219581, 84.7297303907333, 78.47876671821841, 81.33808043695267, 75.21016936148368, 76.88919482692596, 72.34674499880883, 73.88700485229492, 62.604228604224424, 62.90102258805306, 57.970152208882, 60.82980717382124, 58.99351427631994, 59.322354024456395, 57.62510130482336, 58.489689750056115, 57.20517627654537, 57.07500065526655, 55.941992652031686, 55.826412170164055, 53.85003966669883, 55.67265133703909, 55.010492494029386, 55.155188729686124, 52.45811600838938, 47.17206716537476, 49.01635385328724, 51.56973838806153, 53.3489647219258, 52.34881131879745, 52.324594605353575, 60.534629206503595, 56.90987279338222, 55.699370522652906, 60.251783171007716, 65.30973442139165, 58.79067674759896, 60.98023399229973, 67.16883982381513, 65.60174703598022, 65.78594546164236, 66.08347292869323, 64.74394429114558, 66.26020708391744, 63.8281963717553, 66.9475632329141, 62.712140852405184, 62.715510168383204, 56.18072379019953, 56.748220151470555, 54.550920148049634, 52.14066682323333, 57.62995327672651, 61.03129540720294, 61.319938705813506, 54.93242556048978, 48.68467038677585, 44.36321866127753, 46.39761870907199, 51.857338336206254, 55.63877774823097, 50.15562980405746, 56.64099039569978, 57.570913760892815, 61.51711625437583, 63.85095788586525, 64.44172959173879, 56.919831691249726, 55.55703947621008, 63.78251644872851, 61.575736076601096, 57.014768738900464, 56.673644127384314, 53.44766724494196, 53.81595819227157, 52.95924586634482, 49.87903210424608, 42.40148052092522, 43.58129024505616, 54.66246058863979, 58.08946678715368, 60.71923163629348, 52.9739429873805, 51.82143688201905, 49.55988845517559, 50.39625152464836, 51.92958055003997, 49.01382784689627, 49.48277857995803, 56.14622654453401, 55.61479637699743, 55.13756159813174, 55.75049469547888, 57.31459471487231, 55.233804795049856, 55.87044469771847, 55.52820613307338, 53.84910222022764, 48.80808776424777, 55.505099450388265, 54.49277101024505, 55.08341327790291, 54.65640444909373, 55.835276726753484, 52.765771035225164, 52.89589958806192, 51.45435794707268, 48.27331573732438, 46.17175686743952, 45.4657498482735, 47.34618509969404, 51.29363490689186, 51.108483345277854, 51.96871795961934, 53.084498913057395, 50.26156910004155, 54.536191648052586, 52.649331554289795, 54.83011837928526, 54.6092850162137, 54.49776026510424, 54.1681242758228, 57.893301210095814, 62.579890297305205, 70.44774516936272, 68.36516272637152, 72.11240691523399, 73.20124118558823, 74.63252975094703, 72.53664262833135, 76.12202628966301, 68.65532398223877, 71.9381909216604, 71.10740154020249, 83.25303646825975, 78.23937662186162, 98.90927899268367, 24.21993370979063, 1.770448559714902, 4.9983003350996205, 77.2001995578889, 78.64240800180744, 72.86707878112793, 56.59437302620181, 44.510821373231956, 47.46207152643512, 24.489163237233317, 0.33676305845860516, 0.07081820193918482, 0.06157310266468314, 0.06407624133111489, 0.07773068222788074, 0.03122373472809071, 0.16154237121583956, 0.1877219091740347, 0.19830489290818093, 0.22850849154976108, 0.13198311380561323, 0.23382547882295426, 0.3527150315142447, 0.14177505047090594, 0.21817155993513523, 0.350832293831533, 19.87201383036952, 86.65527682150565, 33.25942408653998, 43.77477292091616, 72.60292283950314, 80.59856460940453, 88.5076004459012, 89.82710930608934, 5.445487306964013, 0.5314636302571143, 0.6897141676275962, 0.4505728659850936, 1.7021509019597885, 72.5774274333831, 92.33389608321652, 85.00362165512578, 86.6685030537267, 79.27594138729957, 82.7688669389294, 78.27053593051049, 79.39081976490637, 66.32856615128057, 68.77795296330606, 61.08160764940324, 65.26491741980276, 62.40739230186709, 62.622428401823974, 59.12306231837119, 64.27277741893646, 60.43025493621827, 61.35323962857647, 60.24380114770705, 60.37794228523009, 57.09557740919052, 58.82420516783192, 58.486979392267045, 57.806173601458156, 55.17846015191848, 51.84537510718069, 53.627868775398504, 53.88843182594546, 56.51207385524627, 55.45889000738821, 55.46962553454984, 63.19062294498567, 58.15887704972298, 58.43847928508636, 61.24949685988888, 66.58225720928561, 60.14012113694222, 64.76230098355201, 69.21362630782589, 66.35185718536377, 67.46151139659267, 70.53249974404612, 69.67720339375158, 70.01433111006214, 67.59399337153282, 68.72234944374331, 65.00791980374244, 63.765054056721354, 58.186502302846606, 60.256152691379675, 58.36989272025324, 56.72896915866483, 60.785272582884765, 65.125182982414, 63.376276569981734, 57.036443756472686, 49.94451999664307, 45.864141064305464, 47.641586642111506, 52.14977456677345, 59.34585294415874, 51.73124590227681, 60.069671446277255, 59.397000651205744, 64.34507846832275, 65.35680286345944, 66.14613671456614, 59.2638244167451, 59.06523089255057, 64.25566019550448, 63.585115325066354, 62.22071101588588, 60.08973829207882, 55.81680628561205, 58.151416701655236, 56.035235235767985, 50.66123508637952, 43.826850229694, 43.262264267090835, 56.8650322575723, 60.886414820148104, 67.29397127705236, 55.43208845200078, 55.0839820215779, 51.494656378223056, 53.01849326779766, 55.99525843897174, 54.05537574521957, 51.04914180694088, 60.18752690284484, 58.44389215592415, 56.60725408984769, 58.08271246571695, 60.486297761240316, 56.624685102893466, 57.423048250136844, 59.19764226482761, 56.56362164405085, 50.877090961702415, 59.02719959135979, 56.557298783333074, 59.252359328731416, 57.17295008320963, 59.24207879650978, 55.50112608940371, 56.42906473528955, 55.38038769075948, 53.35056112658594, 48.236425845853745, 48.90908879618491, 52.110084102999785, 54.18279001789709, 53.59421091694986, 54.465934153526064, 55.88221965297576, 55.77184415632679, 59.26498936068628, 56.13790327502836, 58.009556339633086, 56.97687472066572, 57.802094336478945, 56.799630657319106, 60.3294421780494, 64.64319036852929, 72.18595135596492, 70.7892188718242, 80.14575050723168, 75.53879337926065, 78.01480524001583, 75.79163720530849, 80.36613279773344, 71.53768554810556, 76.56847046267602, 73.82436460064304, 87.54621182718586, 82.28388940134357, 101.01078294938611, 27.786066378316573, 1.6244133249405892, 5.829235824846453, 83.00509560492732, 85.72543190371606, 77.2924223253804, 70.34306495420395, 55.08773965220298, 61.50862432295277, 35.333271411157426, 0.5305563370066305, 0.22855450279049336, 0.194096542113731, 0.19049209842999137, 0.17031397069654158, 0.11521114321846156, 0.24521196621560284, 0.41301341366864025], [0.041903228303717996, 0.027294121194450606, 0.008549569963267254, 0.030476657275651253, 0.07654897628291961, 0.06164174797313829, 0.12328398624254812, 0.3473012107274225, 5.573731651229243, 45.05457562784995, 34.25635722375686, 43.058151968063854, 36.34571360003564, 65.10654780172533, 71.8152089272776, 72.06007465239495, 6.2484445302717155, 0.4740343086661831, 0.30811443444221254, 0.25850962847471237, 4.948191565852012, 77.10339546203613, 70.8215941152265, 72.0022902950164, 71.7158317565918, 69.45487560764437, 68.16045422707835, 66.47172481782975, 63.085087653129335, 56.4346109667132, 56.09935029860466, 57.58910571375201, 54.139694936813854, 53.4667613429408, 56.073866659595126, 54.28344980362923, 53.42539994947372, 52.39791547098468, 49.82093787962391, 52.38202594941663, 51.73470151039862, 52.501591559379335, 50.58458805084229, 51.218749015562, 51.67421856234151, 51.04910650560933, 46.14928560872232, 43.49398220739057, 47.031956180449455, 49.79175936791205, 51.865183076550885, 52.35236498617357, 56.123308135617165, 54.30792931587466, 52.25814573226437, 62.927702549965154, 66.20652552573912, 54.658526451356956, 60.81524341337143, 61.792458795732074, 62.198851646915564, 63.15804373833441, 61.37132959981119, 58.685584683572095, 62.85947684318789, 61.59409669137771, 64.54337781475436, 63.068131246874415, 59.97269476613691, 56.73541361285795, 53.613053983257664, 50.99498171960154, 51.48387770498953, 56.105284844675374, 60.513220910103094, 55.83407255911059, 45.09921220041091, 46.66721497812579, 48.61148680410078, 45.048488109342514, 53.59087690230339, 49.579363023081136, 52.21211279592207, 54.88204663799655, 53.50359239885884, 60.130997703921416, 63.130120385077696, 62.295318418933505, 48.93985979018673, 46.231953482474054, 64.41367287789622, 60.6644243578757, 59.101689323302246, 50.730684572650546, 53.223252757903076, 50.27201044944025, 47.79917570852464, 52.27299974810693, 43.021673925461315, 43.85555413461501, 42.26370334625244, 58.03085480966876, 58.83679597608505, 52.992417350892104, 49.82338936098161, 47.77325668642598, 48.70840072631837, 47.29562182580271, 48.386895810404134, 50.90150771602508, 57.93812997879521, 55.1716273830783, 57.13976683155183, 55.66220998764039, 56.658739120729514, 54.067095787294456, 57.46928907209828, 56.010834170926, 55.207403321419996, 50.6660831359125, 51.75339160426971, 51.375620288233605, 52.21063013999693, 52.005199924592056, 52.58619316162602, 51.044478108806, 51.831274186411214, 47.53487463920347, 44.72153894362911, 44.47649671185402, 42.366132120932306, 44.94438840496925, 50.174414034812685, 49.55913143773233, 48.052545132175574, 49.20562390358218, 49.74329063969274, 50.346602163007184, 50.11618252723448, 49.08887455540319, 49.000162309215916, 50.517425306381725, 50.815552896068944, 52.506349394398356, 52.49862624752907, 59.9995316228559, 63.07398734554168, 66.42130667163481, 67.50362196276265, 66.9286338744625, 66.23631984956803, 66.07059970978769, 62.8303453999181, 65.52413901975079, 69.04964770040205, 83.42475783440375, 75.98419420180782, 96.95101214993386, 28.61129187768506, 1.5901615951330432, 7.092495445282229, 70.77745176130726, 69.81843225417599, 61.086553758190526, 49.74196880094467, 36.84339569460961, 32.34768679065089, 15.52080112118875, 0.16469022649670803, 0.044452393532640515, 0.11752017818751836, 0.015856639159122304, 0.07704142526152634, 0.05818658035188433, 0.04496992039944857, 0.015242850471798693, 0.016432555332299204, 0.06760218781569312, 0.08398064967965888, 0.08503774376285654, 0.0823554401135733, 0.04731952355453565, 0.12761960722385876, 0.4828945445197244, 10.845282923790718, 62.63213234563028, 38.95671383027108, 30.584530407382598, 40.57035338494086, 74.23935920961442, 80.88244222825574, 79.71347393528109, 7.012007919050033, 0.5100306351819347, 0.4303069598972798, 0.4421759294646402, 5.789556637887032, 87.47826068632065, 78.15054278219901, 78.21641506687288, 78.87567135595506, 76.5153694152832, 75.17027101209088, 71.43846527222665, 66.44553907455938, 62.08596583335631, 61.30251553750808, 61.47971253241263, 56.86547940777194, 56.35778742451822, 58.5498510637591, 57.565336150507775, 56.64787807772237, 57.859945374150435, 53.164993793733665, 55.98821778451243, 54.08873550353512, 54.85548042481946, 54.29197703638385, 52.936292156096435, 55.6467362373106, 54.64885388651202, 49.08951390174128, 45.0595138918969, 50.699486040299945, 51.288531903297674, 54.84103041310465, 56.810476010845555, 56.58067610956008, 56.16843500444966, 52.75026982830417, 64.4056986993359, 68.44613613620882, 55.425067409392334, 66.58129230622323, 63.761704352594194, 66.3499822924214, 66.98182905873945, 64.69544810633506, 60.345594498419, 66.09160007969027, 63.76970991011589, 64.87250781828358, 64.99899248923025, 59.72195725287161, 59.851364089596665, 54.81362481271067, 54.541537838597456, 56.841137178482555, 58.44405689547139, 63.94068994829732, 57.540072164227894, 45.1003183087995, 46.50352270372453, 49.93415317227764, 45.61150512387676, 55.85819121330015, 51.74549195074266, 55.0880063733747, 57.66285804010207, 56.888546866755334, 62.140694664370635, 63.23005845469814, 64.00071790141445, 48.454619453799346, 45.923349242056574, 66.00147185787078, 61.12432226057976, 59.802373686144435, 51.873204323553274, 56.55144660703598, 51.444524565050685, 49.64533336700932, 53.364775796090406, 42.812603750536525, 44.019144427391794, 44.048291560142275, 59.07225193515901, 61.99608864322786, 54.23382397620909, 50.7015609741211, 49.72760115900348, 51.04488211293375, 51.28569210729292, 50.856055290468284, 54.39786141918552, 59.458628931353175, 57.527042050515455, 58.730193799541844, 57.58966269031648, 57.431979487019206, 57.533172715094786, 61.36337503310173, 57.303364969068966, 59.732967345945305, 54.37139326526273, 52.34207268684141, 54.963729996835035, 55.99596446560275, 52.25273678379675, 55.517184272889175, 53.443878235355506, 52.86819588753485, 49.03832304862238, 48.317575762348795, 45.66231550708894, 45.119635981898156, 48.41783154395319, 52.247116027339814, 52.60977837347215, 52.62719761940741, 54.39981475953133, 52.58491054657967, 54.48485174486714, 52.42514848709107, 54.100667353599306, 51.6521591524924, 55.09855754913823, 54.77287138662031, 56.63895468558035, 56.11092913535334, 62.751325330426624, 65.07663580679124, 72.26975671706661, 70.590268411944, 72.01470851898193, 70.65819601858817, 69.59393147499331, 65.53838114584646, 69.68603657137963, 71.37056904454386, 86.4630179251394, 77.7806632749496, 101.97368560298797, 31.819359217920614, 1.7601164238106821, 7.600846386724903, 78.42178252435501, 76.20469416341474, 67.97439267558437, 62.615172017005186, 46.81761434001308, 46.3942886167957, 25.359193971080167, 0.10285077421295066, 0.060851834714412696, 0.03673257531538125, 0.08120974796193262, 0.056855337874543284, 0.09889238258643497, 0.0632719026367751, 0.015534216692040284, 0.12069389659671054, 0.1623135766074542, 0.19869795730037076, 0.17970352734048523, 0.21430437873688438, 0.1377465311558016, 0.3381881658588687, 0.7363524360041465, 19.42757202732948, 78.3294185515373, 50.05156932338592, 60.14438083094936, 51.22669573753111, 85.44167195597004, 87.05361704672538, 87.34757515691942, 7.8793974268820985, 0.5354296980846314, 0.747668780386448, 0.5193250590274411, 7.161712531120547, 93.09391021728517, 84.23428796952771, 81.63610212264523, 81.20117402845814, 78.98514470746441, 77.6022425005513, 75.02293894367834, 68.7814909412015, 62.776373586347034, 64.2551463650119, 64.06008689634263, 60.01231462724748, 60.958174582450624, 61.90355600849275, 61.6984905735139, 59.7863115802888, 60.98458390082083, 56.44940614700318, 59.845711954178356, 55.631246797500125, 60.470290568567094, 56.550913164692545, 56.092176283559496, 59.11815543328563, 57.77010348535354, 52.142318141075876, 47.53022663054928, 55.365969058006044, 54.724139859599454, 58.6764455610706, 60.473036227687714, 58.38024777750815, 56.86364766090148, 53.26949357986451, 65.68563868922573, 70.43084759866038, 59.23402617054602, 66.92347203531574, 68.15345671869093, 67.27146471700361, 68.1459963706232, 67.30578545601138, 62.25442770988711, 70.43196155178931, 67.05327895379835, 65.64310842944731, 67.26932310288953, 63.878473312624045, 62.7259240611907, 59.25382629517586, 54.61894189157794, 57.614004919605875, 60.19129630058043, 66.7545041730327, 60.57509237720121, 48.919400707367934, 48.41061438283613, 49.763455544748616, 45.23196481889294, 58.462695998530236, 55.162068566968365, 57.280740737915046, 60.31855760082122, 60.06071667517386, 62.93468044650171, 66.14169659153109, 64.58231126108478, 50.511792782814275, 47.3356496134112, 67.97842487212151, 62.871291022146906, 63.41484915825629, 55.06256195806689, 57.95439212552963, 54.94651863651892, 51.452494821240826, 57.2640000620196, 42.75120689022926, 43.37155718957224, 46.451986682030466, 60.55702986255769, 65.82935825470956, 57.74677714993877, 54.157522109247026, 53.33052173737557, 54.644892292637984, 52.81970754746468, 52.84327314745996, 57.23329574831071, 62.840767137465946, 61.19784708945983, 61.6885434427569, 61.653218576985026, 60.76386820885443, 59.01766430947089, 63.53900001895044, 59.27455994390673, 62.638741539370635, 55.32135601966612, 55.98802951074416, 56.59167835789343, 58.00934453164378, 54.78687817050565, 57.54001725104548, 56.8794979587678, 57.152153676556004, 51.99334259956114, 51.20418525511219, 49.061045339030606, 50.355047025988185, 49.658324257020034, 56.81016222123177, 55.1810920623041, 54.77178096771241, 57.07650684541272, 54.57818846548758, 56.78382350552467, 57.112624029959406, 57.21296610370759, 55.83684959719258, 57.4693557523912, 57.0422645538084, 57.689475244091405, 58.86212664265787, 65.9845821319088, 68.92424168125277, 75.71429591025077, 73.7810302549793, 76.48963082221248, 74.48835911289339, 71.90005763884514, 70.45307174805673, 71.62157720135104, 74.60930931952693, 87.64504771078788, 82.02710751564273, 104.19366082837506, 34.324233839588786, 2.039244542679479, 9.129613695606109, 84.3902257180983, 84.2305774073447, 74.62207271206763, 72.97784651479414, 54.518807703448886, 69.24153004923176, 37.314389982531154, 0.2986707766690562, 0.18647078034137526, 0.21146056843140434, 0.25972078283948286, 0.18737291015924948, 0.24228417735186317, 0.20789683465996098, 0.09806614909921924], [0.03542653330030941, 0.016304381161687836, 0.05628150354530062, 0.06105435388763586, 0.07246004327410653, 0.14669538806042365, 0.08896431209699762, 0.4477634070621383, 5.585852265357972, 47.36451433550927, 34.65198316881734, 55.100416752599905, 73.50653494558027, 57.50917957675073, 72.80153597554853, 72.53211621315249, 5.496261898548373, 0.22191184632960828, 0.36099454207766446, 0.47055415508727877, 17.802316373394383, 86.31487784847137, 66.33975275101201, 79.86191211208221, 67.28306708797332, 73.46032942495039, 65.54421763266286, 67.28340441180815, 58.83292851909515, 57.435709661053075, 54.93945444783857, 56.22225776795418, 51.50853764626288, 52.97923818711312, 51.955103412751235, 50.32820232452885, 51.595171036258826, 51.23248123353528, 50.87701251429897, 52.491107063908736, 51.371215466530096, 53.05997625474007, 51.46690953162409, 51.03386025274954, 49.72034085181452, 52.24753572094826, 46.26705477314611, 45.16680248322026, 45.86648271929833, 48.529360217432824, 50.59463324085359, 53.984549507018066, 54.46540855592298, 55.25558571661673, 57.391920320449344, 67.08236725099626, 65.12066048960533, 55.189399642329064, 62.518952354308105, 59.580198872473936, 63.82349344991869, 61.307712677986395, 65.58057015941989, 61.117752290541134, 60.97989274609474, 60.81622792828468, 60.39046249082012, 58.1896911897967, 59.1709073897331, 57.72762029401718, 58.055879531368134, 56.15105890458631, 54.109692727365804, 61.12976258800876, 60.47502486936508, 50.32994385688536, 49.56368138713222, 47.1698510262274, 45.246430520088445, 52.0013677689337, 52.87826853413736, 49.83709804473385, 53.29012524697089, 55.89612837760679, 57.92873590223251, 60.27831800522343, 59.015103001748365, 60.867410936663234, 44.883752484475416, 43.59250430137881, 67.1422226198258, 57.428543490748254, 63.485294926551084, 53.35902167904762, 54.430503383759536, 51.05630405487553, 50.56499973420174, 52.97734368231989, 50.96592480136503, 47.52171508727535, 48.602418284262384, 49.015028092169, 62.59521499756844, 52.01951265335084, 50.5031047328826, 48.62942380289878, 47.47891418395504, 48.89798848859726, 51.67569729589647, 51.213061578812145, 57.442158037616366, 55.44759358129194, 52.532966598387695, 54.5948899176813, 57.303031567604314, 57.664101431446696, 61.69867100254182, 58.17377421163744, 56.339093408276966, 58.056518877706225, 53.87613911782542, 55.63307069963025, 52.92188529045352, 53.80641114327216, 54.46170191611014, 49.481448896469615, 51.064839132370494, 44.33486776967203, 43.516759410981216, 41.839455866044574, 43.34444968931137, 45.00023118911251, 48.77603415519961, 48.927261137193256, 48.40376984688544, 49.55970410377749, 49.347186165471236, 51.63710901814123, 49.26064691235943, 50.07911220673592, 49.977267865211736, 50.84401361403927, 47.74806330280919, 50.57169914245606, 51.8166123667071, 54.38851048869472, 54.37819073277136, 60.99699820241621, 62.57002161395166, 64.7078388737094, 62.92111689044584, 64.16715583493634, 64.30477611480221, 68.77239104240172, 70.45660188121181, 81.81286765683083, 75.68869067776588, 94.349562891068, 31.413839094100464, 1.264057455043639, 7.813595744871325, 74.05924397130167, 67.01879347524336, 56.82684406157463, 48.91520377128355, 25.26350578954143, 31.09227926500382, 14.428091549104261, 0.1303888541916686, 0.06779659794823778, 0.07779714035531206, 0.15758974057051445, 0.11187825472124162, 0.027796887462177587, 0.09501044653476247, 0.05581898562189552, 0.05973066503722822, 0.06755118168169452, 0.02621615696097574, 0.038951989488616105, 0.0403037861049656, 0.15715559854382471, 0.11821169511324937, 0.3991269362309287, 10.478448156387577, 67.99099999089395, 39.40486815667922, 51.584976796180975, 78.04699220964986, 64.0758156007336, 83.02100473834624, 77.68367875006892, 6.314109909919001, 0.5743854528953952, 0.41935928766765906, 0.6823951474601223, 21.861696897014497, 95.70681279705417, 76.02206860819172, 84.69191874227216, 75.49486283333071, 77.47580882041686, 70.08702047409551, 70.18238113772485, 62.495265160837484, 59.190797728876916, 57.909398617282996, 60.33986391559724, 56.63278871966947, 55.83282132302561, 55.523601270491085, 54.61265825456189, 57.19815131156676, 55.13368629640149, 54.10848463735273, 55.07350929321782, 55.125465008520315, 57.63445615768433, 54.32381099270236, 54.19077596356792, 53.348356754549094, 53.93785369011664, 50.38897945034889, 46.399430844091604, 48.04896793057842, 51.1747282551181, 52.865964058906805, 54.8549509048462, 56.1863523913968, 56.39867028882427, 60.21380678299935, 69.32546092617896, 66.13447943041402, 56.659915831781205, 67.10238702835576, 60.611468438179266, 66.6969237789031, 65.08573570559102, 65.25103615176293, 62.76726192043674, 64.88048591921407, 62.54462034471574, 66.48585319519043, 59.8739569417892, 62.30799551933043, 58.07274964547927, 60.153551332412235, 58.32978256287114, 60.30798681320683, 62.494190431410274, 62.242542928264996, 49.9397268602925, 49.001429234781575, 50.428124704668605, 47.80577705752465, 52.07918367078228, 53.865054499718454, 54.46658526697467, 54.58923778226299, 58.96260992173226, 61.496723851849964, 64.12203681084418, 60.80312721190914, 65.29001274416524, 48.91043024678385, 44.56979420877273, 67.28453405441778, 61.4295611073894, 65.9782200474893, 58.400671558995406, 56.906213222011445, 53.575520823078776, 53.45408816491404, 55.760861519844305, 53.15619983980733, 46.942741870880134, 46.19001157822148, 50.5778572636266, 64.43109996857183, 54.2365853248104, 53.30502633125552, 49.31276736720916, 50.77539567024478, 50.844429385277536, 54.776746688350556, 54.60087937693442, 58.16771022735104, 55.76110470679499, 55.62938367166827, 56.31364899296915, 60.629299532982614, 60.06577653269614, 62.49366875617736, 61.11813668281802, 61.404038244678134, 59.841954323553274, 54.77069447117468, 57.562857212558875, 57.11054909613825, 55.56445667820593, 58.3693318213186, 51.82621432888893, 53.27609100649434, 47.57379239605319, 47.782325206264375, 44.738895431641616, 46.03555256320585, 48.18950253148233, 52.0452904701233, 52.06354125853508, 50.25981580057452, 51.6052201486403, 53.12685266617806, 56.16398703667426, 52.732980020584606, 53.34050024709394, 53.33606404642905, 55.15301965898084, 52.68130671593451, 55.96113381847259, 54.68233523830291, 56.09429044108237, 57.11312217097129, 63.121636298394975, 65.88569133512436, 68.37112472903344, 65.37402991325625, 69.09795561144429, 67.20159945949432, 70.74996379113966, 73.2882942691926, 85.02051922582811, 79.26379772924608, 99.17861246293592, 33.27581959386026, 1.3639767708316928, 9.193346327350987, 81.23606743351107, 73.69141194128221, 64.23316932493641, 54.55010429505379, 39.06398673211375, 50.66722846800282, 21.372644016819617, 0.09024975400778557, 0.047620906374387206, 0.0379038164992967, 0.09660897325844535, 0.04546362959269074, 0.080735286727788, 0.05948907537986675, 0.06141883170893116, 0.13421518758179682, 0.1907339677094452, 0.11449510381827432, 0.07576460183988656, 0.14647720621958857, 0.23319215393595158, 0.20977506774567792, 0.504602381298619, 13.867399519489659, 87.58929514115857, 45.79286767590431, 67.59304415795111, 87.31038324294552, 73.66416715806531, 88.18098468165245, 82.94193760041269, 7.526393427002815, 0.5695872910080418, 0.8870617264220793, 0.7974897457226631, 23.482075083640314, 98.24764574727705, 82.81107948672387, 89.93240925573534, 79.26420565574401, 81.41855178340789, 74.87744254450645, 74.7342368095152, 67.16827500251033, 61.18259691422986, 62.37295781412433, 61.26694748478552, 58.810418036676225, 59.61657885582217, 59.35807112724551, 57.090909788685465, 60.60079174657022, 57.882012628739886, 58.05644435267295, 56.66133965215376, 58.513278884272424, 59.58133635982391, 57.36244763097456, 56.704913262398016, 54.642895806220274, 55.489464882881414, 52.41606035540181, 51.387775713397616, 52.43108695553195, 54.635153047500125, 56.140209628689675, 59.92159804990215, 58.35072017485096, 57.814037953653646, 59.79228927243141, 72.44361969732469, 67.65263280560895, 59.06263428349649, 69.9251599465647, 66.7378419445407, 68.19947396555256, 64.9485743430353, 69.67926656046222, 65.80089753673923, 67.69115048070108, 65.82756965391098, 65.79690848627399, 61.076536024770434, 65.37201381498768, 62.7912550587808, 63.665692575516246, 60.77139523721511, 62.678926221786014, 66.67441721885436, 64.26796467073503, 49.90259378187118, 49.59199697740617, 51.6736811976279, 46.25550731535881, 53.70200157165528, 59.25583847107426, 56.10153113642047, 58.68158386599634, 60.60106239011211, 63.5811145074906, 66.8803338081606, 65.33143689555507, 65.23558985802435, 47.5602327623675, 45.37641002285866, 69.3462573328326, 62.34177497125442, 69.35971106252363, 60.22735072720436, 62.00896578450357, 56.50135401756533, 56.73717475706532, 59.86725361116471, 55.306494159083215, 46.65969187213529, 46.8598464996584, 55.729051097746826, 67.75662268361738, 58.865613629741055, 54.85702191629718, 52.67777658277943, 53.98240004816363, 55.91523032034598, 56.812735296064815, 58.590812375468595, 62.2203972262721, 58.89965588046659, 58.049317406069854, 58.60053593112577, 61.82214721556633, 60.90070009231568, 65.31814790541127, 63.02493810653687, 63.37813185107324, 63.103718911447835, 56.74632564667733, 59.86954427534535, 58.963990596032914, 56.782631104992284, 60.78483327742546, 55.04957499042634, 55.44470279447494, 49.95023488998414, 51.48325012576196, 47.929904383997766, 50.37476085847425, 50.11065590766169, 54.711121512997536, 54.660099321796054, 55.219597970285726, 53.48327452136625, 57.49139555038945, 59.413007843878965, 55.91120989091935, 56.058447822447754, 56.66809005122031, 57.33706205121933, 53.633873924132324, 57.339595902350645, 58.62507820129395, 57.62224581933791, 61.64021199749362, 66.33230024768461, 69.22489919970113, 71.36615245572983, 68.46958406509893, 71.19649425629648, 71.26839130155503, 73.37038947689918, 78.64855043349728, 88.13194720975815, 83.67945301917293, 101.87848183416553, 38.11193727677868, 1.6765809708064603, 10.173887879617753, 86.54911395042174, 81.60849648137247, 71.26289213857343, 68.87103080749512, 38.767773259070616, 69.42388888328307, 37.86593406431137, 0.29360368727676334, 0.2912053417774939, 0.2710614581742595, 0.2417258065073721, 0.16598137576253186, 0.09921668292654139, 0.2589228256575523, 0.1954235136508942], [0.044127740792088935, 0.009447486297557912, 0.04148238939383338, 0.040223377516433116, 0.0428579232445167, 0.07359682582318783, 0.0693729387656335, 0.5546908645379929, 8.319355960815184, 51.530777485139915, 38.81567324361494, 26.852040213923303, 42.4235281636638, 59.39947958915465, 70.75962851124426, 73.21116478212419, 6.807037601547857, 0.5370589525949571, 0.2443759957508695, 0.3287729452694616, 34.91716677142728, 85.62723928882231, 69.6387484765822, 74.92736647205969, 68.20935049364644, 67.82924928972798, 63.03770934381793, 62.900587204963934, 57.77682642782889, 56.654173481848936, 53.40345821072979, 56.597573680262414, 52.71055975267964, 53.18412711543422, 52.15903136038011, 54.027111145757864, 53.07790148642756, 51.71923560480918, 52.47801811464372, 51.827669528222856, 50.73948637131722, 52.27673776688115, 50.653174615675404, 50.04092793310843, 51.32438628904281, 49.047281742095954, 48.05915040354575, 44.66053432033908, 46.58315466296288, 48.250150219086684, 49.35072414336666, 52.94229338246008, 54.12779838808122, 53.101184675770426, 60.145031944397964, 70.33929947883853, 62.7897527910048, 55.577784892051454, 59.9473209534922, 58.541355209965865, 61.832906276949, 63.70765801398986, 61.81380433420982, 62.57830173738542, 59.59290735183224, 59.89847960010652, 58.837090153847974, 57.15842162409137, 60.3281674077434, 56.455693706389404, 58.00384144629202, 54.94230601095385, 59.53635461868779, 56.729910527506185, 59.04293614049112, 56.10732055479481, 45.17007766231414, 48.7054197249874, 48.88908863067628, 49.210550400518606, 50.141944654526256, 53.252384201172866, 54.89984635383853, 57.0135449594067, 55.84349016989432, 58.76465966624599, 60.67633267371886, 60.53024791902112, 53.299668373600134, 51.32978739277009, 63.947875730453006, 58.30058051693825, 60.47418940451838, 52.90214400137625, 56.02887707371866, 49.673625423062234, 51.590409278869636, 49.660873797632036, 49.74226690107777, 43.98481976601386, 49.92585735936319, 54.481655013176706, 55.48796261510542, 59.42575162456882, 52.32663423784318, 48.85571318288004, 53.62515057286909, 51.20481283433976, 51.02222258044828, 53.433613392614554, 54.597321787188136, 55.62494354863321, 58.85117538513676, 54.67762054935579, 57.7940103315538, 56.8116174205657, 59.318196312073745, 59.939240870937226, 59.49392634053385, 60.80682600698164, 59.691484359002885, 52.08949950433547, 51.45604848861695, 54.582314798908854, 54.095799692215465, 49.26414174418296, 48.120217784758545, 43.554257269828554, 43.52328231257778, 42.83835803308795, 42.64529112846621, 45.337394206754624, 49.16691795472176, 49.688098968998084, 47.17476183368314, 48.48755951850645, 50.0358445413651, 51.23803138732911, 50.01671121966455, 51.05425657764558, 50.273285219746256, 51.8892389728177, 49.93876587960028, 52.61200627973003, 51.26950840796194, 53.75488688868862, 53.26124483539213, 53.84257539626091, 56.324533570197325, 59.09916723928144, 58.11027496091781, 59.86116217028711, 60.31549815208682, 68.86348416728359, 70.58922506147816, 80.95417453396706, 78.6463931299025, 89.8542756419028, 28.972918718091904, 0.8961591737404947, 9.732113288294885, 75.27785378117716, 61.85669545204409, 51.98239134204004, 44.12207134308354, 34.06868357812205, 30.222774128760065, 8.563730409068446, 0.16286770332484476, 0.017700478727478656, 0.13526480464685348, 0.018620243889369795, 0.04007877459028556, 0.035134439296539755, 0.03386607731602365, 0.03071969100874999, 0.07119915448129177, 0.07135093948172946, 0.023203778583856843, 0.06488803023051831, 0.009799413683433688, 0.0514929254178799, 0.1250040528154181, 0.5070087860428518, 9.951978806526432, 69.83944046881892, 39.65169114451255, 32.06547029556767, 52.410223868585405, 67.27204522778912, 80.37796266617315, 78.13270384265532, 8.04016508402363, 0.756370619900765, 0.6255956114299837, 0.5363651220836948, 39.47808704068584, 93.0164198721609, 79.1858837681432, 77.69066056897564, 73.08833968254828, 75.25633565841183, 68.82739836169829, 66.18007306129702, 61.54780487860403, 60.521795211299775, 58.008222733774495, 58.047105189292665, 55.150674081617794, 57.146693737276145, 53.601839926935014, 57.129580436214326, 56.38189823396745, 54.58413870103898, 55.19813868307299, 55.06571554368543, 55.687085659273215, 54.25695419311524, 52.911279201507575, 51.66116491440804, 54.625813884119836, 51.42554813815702, 50.452051162719734, 48.491579947933076, 48.15968859580256, 50.66147042858986, 53.708073400682025, 55.31468014563284, 54.72854860367314, 55.20985480277769, 62.18116960217876, 74.02649218036284, 64.51899636176326, 56.32329410122287, 62.484368816498794, 59.65756762412287, 63.59131266993862, 63.83913586216589, 64.34158755886939, 63.55080635316911, 63.08231453741751, 61.7703954635128, 62.053873000606416, 57.98078967678932, 62.85787651615759, 59.132017089474594, 61.3482621408278, 58.493772937405495, 65.73338177896315, 57.75856387230658, 57.97935016693608, 57.35659153230729, 48.50606133860927, 48.73984636798982, 50.999053139840406, 50.71630908596901, 53.529668315764404, 56.44042784167875, 54.793593268240656, 60.707899908865656, 56.41908622557118, 60.21588956156085, 62.49880313873292, 62.041870547879135, 55.487131072628884, 52.75096408782467, 63.96641285188737, 61.56773444144957, 62.93979129483623, 56.59673037067537, 58.25097822373914, 51.58482382374426, 54.223719950645204, 52.58690703299738, 53.751788216252486, 44.574399071355025, 48.668165053090746, 53.50519664825932, 58.41784761797998, 61.78454737509451, 55.35260946519914, 52.16919422149659, 54.97470478857718, 53.11321850745909, 53.38365024135959, 56.95982809989684, 58.87594907514511, 57.420981161056034, 62.2946673054849, 58.986846247027, 58.81309701550392, 58.90900681095739, 60.072852488487, 63.37761409821049, 61.71528224022158, 64.37959532583913, 61.366885554405954, 53.962823498633604, 52.11520671844483, 56.666266149090184, 56.44311074287661, 52.22289146915559, 50.52084169080181, 46.974438544242616, 47.50961457529376, 45.25435370783652, 46.67515385535456, 50.308068798434356, 50.63328427653159, 52.410867137293664, 50.547980570024066, 52.038736189565356, 53.760205622642275, 53.15843166843538, 51.032714920659224, 53.5036551567816, 53.13824715152864, 56.49479581463722, 54.19046609632431, 55.2124043433897, 54.70134304415796, 56.707764825513294, 57.27610057400119, 58.57999840090352, 58.6076158092868, 62.5014546609694, 61.615583435181655, 64.06911227010912, 63.97236308743877, 71.65347391559233, 73.82726715457055, 83.94490334295458, 82.6515959155175, 95.09837473592451, 32.36894015342959, 0.9250632421143594, 11.25691213915425, 81.43954430857013, 68.8254685555735, 57.06768935726535, 52.24699443386447, 43.67900433078889, 47.89949817042197, 21.559295885024532, 0.19276823758357958, 0.05187906054479461, 0.09338798722432506, 0.04326355913954397, 0.09593232609932462, 0.0379828691122032, 0.00035756408725583536, 0.028342539331905788, 0.1615236633487286, 0.16382615592691208, 0.1253651483585277, 0.13171124452304456, 0.32998183201397624, 0.2773666682262575, 0.2586834691464901, 0.7681924597390237, 14.829503970761454, 85.84465626747378, 49.119041504398474, 34.147362401408536, 55.53492907554873, 76.864225018409, 83.6992217648414, 85.25557118077433, 9.116830691214531, 0.8429927943694977, 1.2149835786511822, 0.6689391501488224, 43.310846744045136, 96.92708569188272, 83.71135757815453, 80.18828468938028, 76.24854626194124, 74.371213605327, 71.38730187569895, 67.55546785170033, 66.98382946752733, 64.04694303389519, 60.7534307818259, 62.970009234643754, 59.65981121986144, 60.919252903230735, 58.02865828237226, 62.812494693263886, 60.34112691879273, 58.469399329154726, 59.01285156126946, 57.8313159942627, 59.12544319706579, 58.73517520966069, 56.77850477157101, 55.205975578677275, 58.37668626539169, 52.89931597248201, 53.72160165540634, 52.46320332250288, 52.52270175564674, 53.15871015671761, 57.64049268537953, 58.713896351475874, 57.560288060096006, 56.38025868323542, 64.42589498335316, 76.778364335337, 66.04588877770209, 58.74447907170942, 66.31370036832749, 63.46005447449223, 67.85567821994906, 67.7411920793595, 66.06839533775084, 65.8182030339395, 66.07136849434146, 66.34771516246181, 62.90559607167398, 63.154313564300544, 64.08232673521965, 63.22029959770941, 64.31195405221754, 59.898307015818936, 65.80465908973449, 60.65218264056791, 56.213907041857325, 55.266199650303015, 49.36201664709276, 50.624733509555945, 51.30843400955201, 55.89170394405242, 56.4415967079901, 60.668931161203695, 58.261807887784904, 65.78730652409216, 60.347163446487926, 63.802951997326275, 65.13959769279727, 65.87561868852185, 54.942333467545055, 53.4838628768921, 67.22376869570824, 61.20671164604926, 66.67673141725602, 59.376996563326934, 62.01865403882919, 53.3312552205978, 55.289788784519324, 55.16599878188103, 54.5666527748108, 46.94344789751115, 51.999567401024606, 52.45380532357001, 60.72347564081992, 65.0120932056058, 57.76702834713844, 53.88428588067332, 58.015616401549316, 56.64801143830823, 55.63684794210619, 58.83995348407377, 59.48695628873764, 62.6607499584075, 67.91825571367818, 61.23328962633687, 62.92285842280235, 62.58030999091364, 61.88292434138637, 64.81572366529896, 64.4289348202367, 64.93057850868472, 64.14584167541997, 55.14896392822266, 55.129760003859005, 57.22029309118948, 58.57345196508593, 54.019748856944425, 53.32306923404817, 47.82139201318064, 50.19630086037421, 47.94209511049333, 50.44271984407979, 52.6303865063575, 56.51444688920052, 55.6654380982922, 51.76473902117822, 54.92768733732162, 57.57285141175794, 57.05243133729505, 56.21584469272245, 57.097970054995635, 56.97909870455342, 58.53595802860876, 57.694515489762836, 58.03066261353032, 57.66161072638727, 61.506973005110225, 61.62459311946746, 59.33449768250989, 62.437727912779785, 65.63201204422982, 66.47600804605793, 67.29670909143263, 67.34595837131624, 74.05937733188753, 78.21958434197211, 86.1679615512971, 86.85261126487487, 96.23460692744102, 35.24027201437181, 1.0924240970803847, 13.080213166052296, 87.08208560943605, 78.37803240745299, 67.66545111133208, 64.34543540400844, 53.681687616532855, 62.19675317887337, 34.63872948000508, 0.31941165726992393, 0.11410147252102053, 0.14394818144219537, 0.14990886643288598, 0.1560391479682538, 0.27183061045023704, 0.07156869231332695, 0.13338905368601123], [0.04345419628906154, 0.02708383580489505, 0.03950135879999688, 0.035597815238420046, 0.10110947168281964, 0.04570745239635149, 0.011363858112975234, 0.3105247615566177, 3.9661386753282244, 55.38383937651112, 46.26485432347944, 33.306531752309496, 30.843397032830026, 60.39630682237687, 69.34821851791875, 74.71257748142366, 10.365025958707257, 0.8907073243491112, 0.4401396677619027, 0.3580911301316754, 46.87550852375646, 82.15196440296789, 68.87550230949157, 74.68125343322754, 65.67339697191792, 65.45431690831339, 60.034570155605195, 59.59913607566588, 56.72790619634814, 53.97178611447735, 52.116540324303415, 53.662397400025405, 53.967385215144006, 51.991761884381695, 50.48589729493665, 52.732442655871, 52.68104391713297, 54.068649045882694, 50.787578551999985, 52.066812515258796, 50.30364436487998, 51.69954138417398, 53.303394625263834, 51.66645619177049, 52.116128475435325, 53.48392563481485, 48.97247429816954, 46.93923919431625, 43.84104528734761, 46.6796959600141, 47.49012431790752, 51.6192190877853, 49.68463551613593, 53.417386547211684, 64.9703944883039, 66.01114442271572, 62.456716106783965, 53.884344716225904, 57.3638871408278, 59.52721157381612, 60.35028173077492, 60.47725669799313, 58.03778956013342, 61.02666308802944, 62.32807805461269, 59.53656250430692, 49.08204570893319, 53.307156178259085, 57.17661357695057, 59.63983458857383, 60.664863663335005, 59.87959731009699, 52.026914165865996, 56.38797790773454, 62.51100955470916, 45.94358082740538, 43.26080514538673, 45.10921816672049, 52.08282363030219, 46.59750661542339, 50.794654507790845, 52.84295935784617, 52.76694774627686, 56.257229620410556, 54.917928480332904, 57.394862098078576, 59.459217286879024, 59.48072364253383, 60.608601185583304, 59.946014804224816, 58.90815565663, 58.52848983580067, 54.40989132850401, 52.88699580777077, 54.73157667344617, 53.35874319076539, 52.508600834877264, 50.240360844519834, 50.15013456344605, 43.36842713817474, 48.001213073730476, 52.27853421242007, 62.2321564920487, 56.81266077103154, 55.46624052909113, 51.60307461215604, 54.55918065963253, 55.3981952513418, 54.37462922065489, 55.51695677541918, 56.33475134449621, 57.7283969233113, 53.66671985195529, 58.2967758178711, 57.54666174611738, 58.6137072501644, 59.49904895597889, 61.47045181643579, 58.67957953483828, 58.76114522257159, 58.520621561235004, 55.432570903531975, 47.6715810068192, 52.85818207648493, 53.22934419878068, 48.73359803230532, 47.25050280171056, 45.47026057397166, 42.46912571691698, 39.98740680756108, 43.41271854216053, 44.308599656628026, 47.83847001291091, 47.74833786872126, 47.85933309985746, 51.426254164788034, 48.766220385028475, 51.98497618398359, 49.83631357069939, 49.961492092378684, 48.96160148805188, 50.63093477679838, 51.16367501597251, 51.17564608973842, 51.5762456001774, 52.223687710300574, 53.173874039803785, 54.72722676492507, 55.12908927855953, 56.78565133002497, 57.777936458587654, 60.051004886627204, 60.037221677841686, 65.53228186022851, 69.64525176632789, 79.48341907993441, 74.45370889479115, 86.2700451574018, 32.67240412773625, 0.89048282994378, 9.27152700962559, 74.6510825618621, 63.78735273115097, 51.0762571519421, 45.061251501883234, 26.480893781108243, 28.67136101568899, 15.789094182752795, 0.14253960621933784, 0.10694241151213647, 0.0549196252118676, 0.06385565397419757, 0.03782325469317936, 0.04805934615433217, 0.10165006162658816, 0.10407514359441497, 0.023539853695359443, 0.041461957828892816, 0.08303637736507001, 0.09044084697961809, 0.09945171104083139, 0.0650680915362412, 0.056575585547233784, 0.3074465589898248, 4.735619694955887, 67.37286583069833, 51.152162859516764, 30.301115628211733, 39.46045598676128, 68.80454663307437, 75.81141379571731, 83.68001784047773, 11.32193228890819, 0.9124617086302851, 0.4410512817482795, 0.25277950530571325, 49.863079824755275, 90.8687339290496, 76.76897418114447, 79.57396307299214, 72.09475624945857, 70.66695074881278, 62.647868894761615, 63.3974495241719, 61.46317581976614, 56.830048638005415, 56.44535826098535, 57.304671118336344, 57.17903760171706, 55.86876592328472, 54.964639986715014, 55.39091925467215, 56.907872384594334, 56.283846824399895, 54.1793304874051, 55.945985624867106, 53.81826062356272, 54.405172717186716, 55.54323665557369, 54.89555135849984, 53.00467083531042, 54.034206713399584, 52.17938061683409, 49.94355117121051, 45.88672999412783, 49.37709423803514, 49.998429052291385, 53.53992531376501, 52.50100712622366, 53.33654649796025, 66.91703934823313, 68.79860816463348, 65.35040547770839, 55.94571105895504, 59.842738797587735, 61.42677230219687, 61.75274872010755, 61.12546759267008, 60.224671748376664, 62.96012093943935, 64.96934721546789, 60.27270901587702, 52.226539273415845, 53.6776711094764, 57.1777432195602, 61.28996395295667, 62.59669373112341, 61.35827202950755, 53.92435289198353, 54.504651869496996, 61.678843421320764, 47.396234543092795, 45.03111200947916, 46.909044788729766, 53.069954764458444, 48.877309753048806, 51.01237743131576, 55.07343084581437, 55.27047111142067, 57.84237707814863, 57.73109159161968, 58.654311626188225, 62.256686995106364, 62.90326226142145, 62.6310811504241, 60.15788162908247, 60.57419807680192, 60.62434950182515, 59.05074165713403, 55.69650719242712, 57.14097884393508, 54.487930805452415, 53.92698087999898, 52.44219510785995, 51.31444308065599, 46.47798807390275, 50.88952879751883, 52.339017160477184, 59.93573819437335, 57.73678295073971, 58.794481446666104, 55.38411786479335, 56.894587316820704, 57.719799087893584, 55.410946876771995, 59.027882083769775, 58.41479993635609, 59.51759784452377, 57.07513401585241, 60.71241063456382, 59.436043923900975, 59.56949472427369, 60.015256404876716, 62.468267486941436, 61.45551543081961, 59.91212944830618, 60.22753900097263, 57.959087202625895, 50.87492581336729, 53.12417368735037, 55.97646636347617, 52.53263711929322, 49.147690496137066, 48.55402408107635, 46.17643233268492, 43.379805934044626, 46.17760512136644, 47.20286561596779, 51.07691218776088, 51.75458400480209, 51.40827401991814, 52.353706436772505, 50.32724526620681, 53.85634291556574, 53.85404832901494, 53.757993405865086, 51.93050622940064, 54.7454147954141, 56.29712012506301, 55.9632715102165, 56.01397598943403, 57.063955260861306, 58.45050527203468, 57.30227455016106, 56.59494569224697, 59.504269630678245, 61.502219092461374, 62.23574938312654, 62.808878267965014, 69.47642510937106, 72.8278237004434, 81.74376333913496, 79.75350564525974, 93.07116047028573, 37.28130871249784, 0.8951163135709301, 9.434620141983032, 80.29106647737565, 71.87311095576133, 60.33197210681055, 51.462441951997825, 30.990734984797818, 43.2316227113047, 29.082350884714437, 0.13129971741187957, 0.1546572479269197, 0.017691055846010006, 0.12089552327750192, 0.027818956540056297, 0.0283832932942577, 0.014217398692703536, 0.08147286852040599, 0.1903037327311693, 0.2388899481945461, 0.27938356322626917, 0.10709904584913485, 0.2545606750514238, 0.30538247297367743, 0.16950579390170115, 0.7035509412807803, 9.665566355951372, 80.49500619211506, 62.32891744182956, 44.40204228124311, 45.19637715431952, 79.30047189035724, 79.60478505780621, 90.2377579289098, 13.089781788087661, 1.309236417854986, 0.7839554235819848, 0.4859511740505696, 53.06755819628316, 92.15928000788536, 79.92157136240314, 81.95267661925286, 73.63884433623284, 74.11269803200999, 67.41410563069006, 65.69594667803857, 65.36653426385695, 60.014934770522586, 60.80528451550392, 61.43006317077145, 60.56752612513881, 57.64834134809433, 57.59529521388393, 57.576707101637325, 60.713912902339814, 61.097944321170935, 56.97907909270256, 58.65537066613474, 56.64364584030644, 57.55034877407936, 59.4588093603811, 57.36873126799061, 58.652048418598795, 56.587814823273696, 55.7372998422192, 54.85295834079866, 48.41172049122472, 53.04753057418331, 53.19464691223637, 56.15085494133734, 53.703335177513864, 57.08764245433193, 70.47419763380482, 69.61333936260593, 65.23769224843672, 56.67407558810327, 63.85759453619681, 63.73288669893819, 64.10859092589348, 66.26197215049498, 62.92974218245476, 64.19013307940575, 67.15843769811815, 62.49112706030569, 53.549170340261156, 56.22864730896489, 60.68005892538256, 62.984302351551676, 63.00631469295871, 63.52476181522493, 55.6130156209392, 54.080506370913604, 62.867776578472515, 51.27418387320734, 44.98889553931452, 45.925804645784446, 55.795001829824145, 52.430239723574736, 52.53415899892008, 59.53378154385475, 57.69826527564757, 61.71844367058047, 61.35267872964183, 60.09224468661893, 64.46100804113573, 66.16771759525423, 64.57490974856962, 63.33620955867153, 61.97964214509534, 65.19081208013719, 60.29858881427396, 56.74398006931428, 59.31805118437737, 57.74373339068506, 56.7868084292258, 55.8499816925295, 54.8397046519864, 46.91157863986108, 52.42604278749036, 54.36173246752832, 59.758411761253114, 60.46979242755521, 61.39755848915347, 56.765992410721324, 60.1681778507848, 59.39418831179219, 59.85942848267094, 61.357683673981704, 60.089102868110906, 59.87303910716888, 57.36420877518193, 64.61463943604501, 63.15392524965348, 61.80960347575527, 63.94397297213155, 66.82124722388484, 62.42472917802873, 64.81193857808267, 61.76179762809508, 58.10732141617806, 51.852807998657234, 54.27126692187402, 59.446026355989524, 54.054924672649754, 50.8796012786127, 51.53162471709713, 50.33739636021276, 46.09845953602945, 49.74625202917284, 50.28724493518953, 54.83690800205354, 53.89266798573156, 54.68748531033916, 54.705594893424745, 53.065824508667, 57.91159514457949, 55.92404780849334, 56.37335923410232, 55.19345537308724, 57.68450560108308, 60.70240466825424, 58.39080287564186, 60.473761866169596, 59.5494592574335, 60.608114811681936, 59.18772259066182, 61.63446180282101, 61.96868304283389, 64.84560428127166, 65.76961271224484, 66.71162482230895, 71.74001709107431, 75.9988638662523, 84.00159728142523, 81.93650076466223, 93.55358846725957, 40.27934881948656, 1.103296662049909, 11.893024483034688, 88.29579245659613, 77.33679217676963, 66.78258834346649, 67.20953833672309, 41.85258011664114, 59.89238423685874, 39.801055000674346, 0.3568781065123697, 0.34857221188083776, 0.1941102857310926, 0.14972662943745815, 0.19092452441973073, 0.20889400534572142, 0.2017917420955435, 0.20291942352008438], [0.03499365148825511, 0.04978332360605559, 0.02515033330588091, 0.16187894428449293, 0.07536887146172024, 0.028592534889016422, 0.04526029836626784, 0.06861675635821397, 1.9591463116868852, 52.89558579844814, 47.44840991112494, 44.019246409016276, 51.70192618523875, 57.47349777529317, 70.50549030303955, 76.4650297164917, 11.124470368508371, 0.47317187752454515, 0.4166558553134242, 0.07078830152750015, 47.90598969305716, 80.10422045184721, 73.84430593059909, 73.11872236190304, 61.92382289517311, 60.752203079961966, 58.65742206573487, 56.38462428123721, 53.82869020585091, 55.359316718193796, 53.522980674620605, 52.32564972292993, 51.00935328391291, 53.81546789600004, 52.325606576858036, 56.78591020645634, 56.11966033135691, 57.21155797281573, 56.50766903354276, 54.86236810684205, 55.160727116369436, 55.78556460718955, 54.937877655029304, 54.198726607907204, 53.04940938949586, 50.30380125968687, 50.03364801406861, 47.56289997408467, 44.875856753318544, 46.46459317976429, 47.10985052970148, 47.65532278245496, 51.96821589623728, 53.68833211160476, 59.91647935682728, 68.10875738820722, 60.514056374949796, 56.800383752392186, 56.379301624913374, 54.44790301784393, 56.87951757061867, 52.465140973368, 55.45863113095684, 57.55214521961828, 59.67511238590364, 50.359130213337565, 45.684269012943396, 49.466135963316894, 45.926824462029245, 65.99179144828551, 52.684577972658225, 46.06749242351901, 51.62272960908952, 61.687017640759876, 40.71477505468553, 39.20530580705212, 46.47403040239888, 48.00807329916185, 49.81223414021154, 45.42605546212966, 50.91589104744696, 51.316643530322665, 55.757507893346975, 56.474093544867735, 54.75942550166961, 51.50768256956532, 53.681295379515625, 54.381414921053, 58.12052803654825, 59.95683270116007, 54.665033663472826, 56.11841301764212, 53.157011770433, 54.31547203371602, 56.52562564419162, 52.50815760704779, 52.433660030365, 50.46831723182432, 48.16102220166115, 52.70074206013834, 44.888584844527706, 42.9340011073697, 52.6690100854443, 65.15080390437957, 55.13853826830464, 52.84813688647363, 56.82189403041717, 52.62347136774371, 55.394672962927054, 54.632752556954664, 53.816719132085005, 55.51235583520705, 57.569901789388354, 56.57646740636518, 59.99921783324211, 58.60620767839494, 60.63142545761601, 60.076908219245176, 58.03285521845664, 57.60617194637176, 61.665915289232814, 60.68194558543544, 53.55323391575968, 57.623865758219075, 51.963395303295506, 47.19507578880557, 47.89527377774639, 43.04878142572219, 43.43517411139704, 42.34617117912539, 46.15755004267539, 46.36510618271367, 47.27630415270406, 48.34077658191804, 50.47226313621768, 50.124705837618926, 48.01540028664374, 49.43234866665256, 51.174896917035504, 51.33571409410047, 51.333545023395175, 52.12143544227847, 51.1483463933391, 54.259319382329146, 53.57331645104193, 51.79183083195841, 54.06694281485773, 55.97779996933476, 55.361297515130815, 55.93702300902336, 55.119675590145974, 58.62109307319888, 59.786080160448634, 64.18461038220313, 66.5874739616148, 77.35146968595444, 77.80140476842081, 87.00763117882514, 41.48170824973814, 0.5565043478723496, 7.15769749495291, 78.16888378512475, 60.24928069883778, 55.10226026658089, 43.157882152065156, 39.84047874327629, 38.2922839349316, 20.729706748839348, 0.2115799862170412, 0.020744400774879802, 0.10003218352193795, 0.02452418666272875, 0.03334714467787454, 0.04879484801823574, 0.07796744170087962, 0.017083348939195275, 0.021954857999639168, 0.049572159130606926, 0.08019767686604493, 0.05959946098887633, 0.057890495030029174, 0.032460562614423615, 0.036738401414045406, 0.15413577187686198, 2.0894848339019285, 67.47036026370141, 50.39423150400962, 36.768811825783025, 57.21652369345389, 69.36779898981895, 76.3993457055861, 82.66486921618062, 13.182303636304795, 0.5496859201981176, 0.47769657666644744, 0.08096556509694747, 53.085216706798924, 88.52445879290181, 79.129974303707, 76.59197330474854, 68.39868330186414, 65.26382700089486, 63.45253136850173, 60.461477002789906, 58.28543232333276, 58.295093121067175, 58.20625143666422, 56.10823838941513, 54.6356668779927, 55.91032343526041, 56.176346425087225, 62.296353924658995, 60.81477272895075, 59.34599807185512, 59.547148981402, 57.27474735629175, 57.69395066845802, 58.45726743821175, 58.112691140943966, 57.030685717059725, 55.64917987392795, 53.7302504816363, 53.71865987777711, 50.209695754512666, 44.78540689714494, 48.216115813101496, 50.183325659844186, 50.71388898357269, 53.71587499495476, 55.412429532697125, 62.82794098700247, 70.37772301704653, 64.53678431049471, 58.85121853120866, 58.16929094253048, 55.19327102168914, 59.37395280407321, 56.22372081202846, 57.712809424246515, 60.49382086723082, 60.4759152473942, 54.69877389169509, 48.405860470187285, 50.1537117650432, 46.91146096875591, 63.591442108154304, 54.55377955590525, 48.327099277127175, 50.89141545757171, 58.29425765622047, 43.52008558088734, 42.94277544944517, 47.12844256431826, 46.67190221048171, 51.450353207126746, 48.310052656358295, 55.473685187678186, 55.14784997509372, 56.2701302959073, 57.285482883453376, 55.807537724894864, 56.20503856289772, 59.00235922105851, 57.142649773628484, 59.46636384533298, 60.98503105102047, 57.55629508726059, 58.97256881959977, 54.957646400697776, 55.21494996163153, 60.16873090497909, 55.86207828214092, 53.3415553646703, 52.296122120272734, 51.003085336377545, 55.29334245189544, 44.85739807928763, 46.551379542196955, 54.655443468401515, 62.25082697406892, 56.38359269788189, 58.739976190751605, 58.54583847907282, 54.748811567983324, 58.34067106246949, 58.57655455989223, 56.72847101765295, 57.862298796253825, 58.42189550399781, 57.791613763378514, 61.58770322799683, 61.54294113959036, 62.647178557611284, 60.649727236840036, 59.381770087826645, 58.03605195014708, 64.95010798977268, 61.22154212767079, 55.864227740995354, 58.10530139553932, 56.08287634388093, 51.19187293514129, 50.319977114277506, 47.619233054499475, 44.912742722419004, 43.59355941895516, 47.36580871766614, 48.316575557954856, 49.61841021814654, 52.00997344909176, 53.35898637771607, 53.879402529808786, 51.53706112215596, 52.73237989794824, 54.009903707811915, 54.72681491605697, 54.27158463385798, 53.812726159249586, 55.65990755634924, 57.51859718753446, 56.13836611470869, 56.87669738646477, 56.21028277181811, 58.41822808788669, 59.580414602833415, 60.65051955561484, 59.21586951901836, 62.44311724939654, 62.6450369434972, 69.05936733368905, 69.32259759595318, 80.70430386450984, 81.83895926321708, 91.55615283596902, 45.694435796430035, 0.42457947207074015, 7.71176120927257, 85.44327228300034, 66.9515718952302, 64.22293586115684, 55.10181311638125, 37.019263006025746, 53.15840813421434, 33.30725739079137, 0.0935068304440187, 0.054934096612757256, 0.05572831145517769, 0.06907881462886449, 0.09699122048914434, 0.07731943090836849, 0.04472294897441903, 0.02035735017289558, 0.12705005915655246, 0.19966738028151376, 0.13333349698974242, 0.17325780144141567, 0.3159900634519516, 0.13823866603835938, 0.17010040070501067, 0.24937082773014424, 2.8601418291368796, 86.44809722900392, 58.54215929585119, 59.83499603886759, 70.01836330659928, 77.26457349715695, 81.00816988175916, 89.80457921181956, 13.636642559882134, 0.553745266891295, 0.8295021698840204, 0.304554577075666, 55.23312230263987, 90.56119657331898, 84.44433089225524, 76.39394852422899, 70.80338647288661, 66.54394349744244, 66.82358495650753, 63.52505991535803, 60.74162444760723, 61.93950060875186, 61.55677926155829, 57.12821152902419, 57.90744527693718, 61.264852939113496, 58.59265981181976, 65.30544334842314, 64.64471617052632, 61.2622171063577, 63.111544039941606, 59.9822182809153, 59.369630352143325, 60.96177531826881, 60.48698809839065, 59.46450856424148, 59.94832508025631, 56.673106762670706, 56.33839522638629, 54.43094268921883, 49.25053896442537, 52.475935336082216, 54.55460325364144, 52.99883042612384, 55.50828441496819, 58.06007254508234, 66.51312151262837, 72.20523372773202, 66.82657380257884, 61.192308702776515, 60.23404229071833, 58.94030732493247, 62.834318760902654, 59.09812781118578, 60.071487503667036, 63.73878202130718, 64.7848036212306, 56.03866338729859, 45.854444965239495, 53.30035871075046, 49.556648577413256, 65.27051856440883, 55.739413999742084, 49.2373009650938, 49.99859379183862, 61.26716321514499, 50.34743762785389, 41.70684837525891, 48.66147741194695, 49.57165948806271, 54.53377546802644, 49.48060166451239, 58.12609780219294, 56.93905522746425, 60.066996389819735, 64.26442669283959, 60.51113420917142, 59.31122233790737, 60.92143374104654, 57.8425653519169, 64.82960885570895, 63.85741018479871, 59.52448552654636, 62.7216879014046, 58.28708756354548, 60.0394574288399, 62.43433506258073, 57.467473014708496, 56.67677025641165, 56.04500978223739, 53.787909323169345, 56.2002375818068, 47.35114297559185, 49.4802604183074, 55.987558826323486, 60.566769107695556, 59.36331141379572, 60.402359039552756, 62.04018785107521, 56.77500209500713, 60.442637858852265, 60.55022455030873, 59.1122797227675, 60.62469467040032, 62.02447875853508, 60.52674524245724, 67.4415857561173, 64.04022793616018, 64.81338985504644, 64.09980089433732, 61.313129471194365, 60.20733094984486, 66.85866663532873, 64.74284602749732, 58.925657272338874, 61.45906125345538, 58.47052504939418, 53.67172871866534, 53.8494199322116, 49.66498051920245, 50.30916313971243, 46.612725411691976, 52.466953108387614, 52.4619677758986, 52.80523400152884, 55.61607114730343, 56.658456710077104, 55.47859207276375, 52.90294808726157, 55.57714946808354, 57.700418656872166, 56.39376732610888, 57.26427462793166, 55.85779113154258, 58.68641230367846, 61.64459720734627, 58.992392478450654, 58.87206200630435, 59.62529828471523, 62.17874557741227, 62.228642048374304, 62.946274972731075, 60.495068180945616, 65.98562548237463, 64.40340803515527, 71.74254309746527, 73.83918331515405, 83.29351532843806, 86.16813413558468, 92.37633612848099, 48.34616591853481, 0.558685553410361, 9.440506639019135, 91.52524455901116, 74.07973443308185, 71.96137997411913, 65.77695538920742, 60.192292582604196, 73.08520178641044, 44.68014617120066, 0.2521859863472562, 0.18686018283328704, 0.10620693646131024, 0.15485203344254725, 0.20612580791836788, 0.2069113238324081, 0.16868840873001084, 0.1758777148901455], [0.019472145152488546, 0.06506731012655843, 0.011306421628462212, 0.020045621335626613, 0.03509941758708127, 0.0350551453659371, 0.05144078547375337, 0.09915614665876474, 0.4238111165262038, 45.715667586172785, 52.03311543310843, 37.42742876852713, 38.15326336891421, 55.43795239540839, 67.32011779662102, 82.49481093498969, 19.764156495371175, 0.8444474421201215, 0.32367368018434894, 0.006182441589302354, 49.602222596445394, 79.20351089969759, 73.05249706391366, 75.6717852623232, 66.98677124515658, 63.29553457998461, 61.640635613472234, 57.781376377228774, 55.784164321038034, 54.12920651897308, 52.992648770732266, 50.406590892422585, 52.582800311426965, 54.29206725089781, 55.822046572162265, 57.28123103418658, 62.07716795705981, 62.53142941382624, 59.39043068116712, 59.919452513417895, 59.85914214964836, 59.01465977391889, 59.04851767324633, 59.45059591724027, 55.616753639713416, 50.12827127210556, 52.88624271269768, 46.13479245093561, 43.654450293510195, 43.504658898999615, 46.86648707236014, 48.32078426114975, 48.607282023276056, 54.17910298993511, 58.7090326124622, 62.939108802426254, 61.665091591496626, 51.1021291055987, 58.36487600880285, 52.98749085395567, 51.661564996165616, 49.650389302161436, 52.38828212984147, 52.52115634179885, 53.34973350647957, 48.10787408582626, 44.34017865888534, 43.48436063335788, 51.48981617343042, 51.790783559122396, 43.63266152720298, 46.007797871866536, 56.76298787516933, 41.12736917311146, 36.32227351588588, 48.21729252415319, 45.44944455546718, 48.562641528344926, 51.62029773958268, 48.815304925364835, 54.73986856399044, 53.65448205701767, 53.07787010746618, 55.46836253135435, 50.26771545410157, 50.31119884983186, 52.1969332233552, 50.60396063712336, 55.70570907285137, 54.9408390445094, 50.45433790453019, 48.9235858763418, 52.16593473188339, 51.78714752197266, 53.81605232915571, 51.543972338399584, 52.80563016091624, 50.995558308016875, 49.33779993364888, 51.090279625308135, 42.102207599147675, 39.90407213088005, 39.64659598565871, 47.815771256723714, 63.36263848889259, 54.113058120973655, 51.10762042383994, 58.961260626392985, 54.8579397509175, 56.384789020784446, 54.21678912255072, 55.405651677039366, 50.02147297705374, 51.190154937005815, 56.86211009179392, 58.258846498304806, 54.685273093561975, 53.77176484754009, 56.302587909083215, 54.13353289327314, 61.570389886056226, 55.56036172374603, 53.57162983186784, 55.33334670528289, 51.25705488266484, 48.87645075398107, 45.765034537161554, 43.030946408548665, 41.71308102146272, 44.54098047748689, 46.149105179694395, 45.56763733586958, 48.850421905517585, 50.43003097657235, 52.86278693906723, 51.46227721245059, 51.84188419772733, 50.91960945437032, 52.72270733310331, 53.227410470285726, 54.64213094403667, 53.41564501485517, 56.69460527358517, 54.67685176480202, 57.192887490795506, 56.57300003113286, 57.37894904228949, 54.99444215528427, 56.97800044090518, 57.78204318015807, 62.22665340669694, 61.160502203049205, 63.56298531255415, 63.75482843768213, 66.3360264993483, 70.56397284230879, 75.4948942122921, 82.9774272057318, 52.9333778350584, 0.22091096777829433, 6.99288244208982, 83.21199278677665, 56.473767988143436, 48.91262285171017, 46.62532798705563, 32.58518042102937, 37.46613471738754, 19.03281096489199, 0.18622285896731963, 0.0514036531920635, 0.0131791360082946, 0.0665922234615972, 0.09736950704527479, 0.11198178384332888, 0.04530459740048936, 0.01582453624465533, 0.014710570666788807, 0.09789073794719674, 0.018763080982851888, 0.026523747008233785, 0.00968474468531748, 0.008618671094037352, 0.02872789496435754, 0.043001265956028815, 0.3941591011901056, 55.087869090418664, 54.30049642439812, 37.1666774442119, 52.396068034633515, 65.30126210181945, 73.39575152243339, 89.85929627572337, 22.690032835929628, 0.7428545000091676, 0.2086065691565314, 0.024146285065780246, 51.99209528584635, 88.04142675092145, 82.27120445620629, 79.76194658587056, 70.60880553337836, 66.72738490566131, 62.370694606534904, 61.45187939366987, 59.31780015268634, 59.29401097759124, 58.91942854850524, 56.102927500201815, 57.18601549825361, 57.790825366973884, 61.2988285095461, 61.05414713582685, 65.57985628804853, 65.11210187788933, 64.15427869366061, 62.51446516283097, 62.944709947032315, 62.552504308762096, 61.48767494386243, 61.38474018343034, 58.256802943445024, 51.76580198349492, 54.706963800614886, 49.00570069589923, 46.00940996600736, 47.35311200541835, 49.21238606975925, 53.08531084368306, 53.00182711693549, 57.020416951948604, 61.38565801805066, 65.36653034148678, 63.27770740755143, 56.663214545096125, 59.61429603638188, 55.525295734405525, 53.45558651031987, 51.14562034606934, 54.60015373845255, 54.586358762556515, 54.81571151364235, 52.62620133738364, 46.203229965702185, 45.0026983599509, 52.077497051608184, 52.60969600369854, 44.26444945796844, 48.00067178664669, 55.14936400998024, 42.74237371260121, 43.064443449820246, 46.99047711587722, 45.74839584289059, 50.852772266634055, 52.68421711460237, 50.45713847683322, 58.64517250368672, 55.10322909201346, 54.49015478934012, 56.88482845983198, 53.172410995729514, 52.551742984402566, 56.30318803171958, 50.93616577886766, 57.588066285656346, 56.35995257285334, 53.1353053738994, 50.743396974379024, 53.13851779507053, 53.579482416952814, 55.17833071370279, 55.057396196549945, 54.215212329741455, 53.17580776829874, 50.13307617556665, 50.46406146018736, 43.35100789223948, 42.812070308193086, 41.7592865420926, 46.86466709260018, 59.201117484800285, 57.38768416066324, 53.11654467736521, 59.4340709717043, 56.69563685694049, 59.074644580964126, 57.42136163096274, 57.64760786487211, 52.683314969462735, 50.876114291529504, 57.85808224831858, 59.92897995056645, 57.749679703866285, 56.696405641494266, 57.73369212304392, 56.7503539208443, 63.83245214339226, 58.10090441857615, 57.99910714549404, 58.81689779220089, 55.577086710160785, 51.427693674641276, 48.973046964214696, 46.846898755719586, 45.284638327936975, 47.239869256173414, 49.777238753534135, 48.628427520875015, 51.045352797354425, 53.875605675481985, 56.36381610747307, 55.33935577638688, 54.75037659368208, 54.65365094523276, 55.80543925685268, 56.51519998427361, 56.95441130668887, 57.68579606086978, 59.88353144737982, 58.84780999152892, 61.136152129019464, 59.953788941906346, 62.0863070795613, 58.85518796982304, 60.90852914317962, 62.778479899129565, 65.45330101443876, 64.764030748798, 66.90461327952724, 68.88384911321825, 70.04074435080253, 74.82642035330497, 81.07339105298443, 88.39966466349941, 59.03316943876205, 0.13270780233846557, 7.580052431552642, 90.48565956854051, 63.11867883128505, 58.35386591572916, 56.05393317437942, 38.70811793111986, 52.620651183589814, 32.70901945329482, 0.292265699395249, 0.08153263870025836, 0.03316310354538503, 0.028762382327488838, 0.016612446183458935, 0.07887771503338892, 0.08716363009185561, 0.013805652288870226, 0.1747859783110119, 0.23629997346189716, 0.06053183595800112, 0.149048549693919, 0.08217782262832889, 0.14099716479259153, 0.15282260524409433, 0.2804768626247683, 1.3030481434637502, 71.18067925976169, 67.02838759268484, 50.506070044732866, 51.78274662263932, 74.50539788892193, 76.58776067918348, 96.42419076734974, 25.226541373037524, 1.034518268800551, 0.4645119889849617, 0.0716400227599567, 57.85654860158121, 90.60729226758404, 85.76530671888783, 84.04092296477288, 76.17128341428696, 69.24517000875166, 66.88138500336679, 65.48440933227539, 62.373550092020345, 62.42833775858726, 62.76707364666847, 59.62586702839021, 61.507741789663996, 60.21119448446459, 64.81049906822943, 64.95189266820108, 67.52722678645965, 69.47470711123559, 66.14937659232848, 67.1423089119696, 66.23695527353595, 65.49225015024986, 65.12938384086856, 66.82975876715876, 61.913405079995435, 55.57760054065336, 58.53749559771631, 51.200725724620206, 49.0841834006771, 49.744734071916156, 51.5460668840716, 57.65469951014365, 55.46660138714699, 60.226111258229906, 62.62887285601709, 70.63328896799396, 64.71702506465297, 60.91619345449633, 60.1996313371966, 57.79754046470889, 57.019401058073974, 54.55294409105855, 56.677033055213194, 57.848413605843824, 57.52038186596286, 54.76079440885975, 45.975865856293716, 44.713388258411044, 52.43811584288075, 56.0227503315095, 45.995834642840975, 47.197346841135335, 58.04588533216908, 50.98476394530266, 44.14651163162724, 49.673084135978456, 46.96071024863951, 52.40855686126217, 54.996603381249216, 54.23112930790071, 62.480230715967, 57.84542475977252, 57.95278395375898, 59.8120972418016, 55.5363646630318, 55.5483357367977, 58.11511124334028, 53.19474497149068, 59.24057652873378, 59.940131248966345, 56.89031585570305, 54.27694259151336, 57.021840772321156, 56.74926742430657, 58.76415760286393, 56.264113380062966, 55.70622290334394, 56.24076351042717, 53.31693072472849, 54.23592244425128, 43.82423008641889, 44.88622357768398, 48.31340236048545, 54.43771270013625, 56.93910621827649, 56.85592059166201, 56.99243868550947, 63.31564457185807, 58.958856213477354, 63.50579715544178, 60.280863623465265, 60.66034117052632, 55.31035377133278, 55.74008472504155, 60.971491029185636, 63.95498306520524, 60.86358270337505, 59.60315258272233, 60.66797410288165, 58.673264518860854, 65.42557377969065, 61.80885038068218, 59.72300060333745, 60.68551886466242, 59.076629300271314, 52.820319437211566, 50.89498481442852, 49.91712224098944, 49.96665000915528, 49.93358442860265, 52.8423317786186, 49.738297462463386, 54.881152337597264, 57.3112803120767, 59.776540956189564, 58.39359952557472, 56.61335729783582, 55.957136923267, 58.66710247532014, 59.65528088231241, 59.94884675548923, 59.92278260569419, 62.96295289070376, 60.067690649340236, 61.91438959490869, 62.978799266199914, 65.02193443236813, 59.968909678920625, 61.95158543125276, 64.93456755914997, 68.50223387441328, 68.23678355063161, 70.29478842212309, 70.74539030751875, 73.55052824943297, 76.83093194038638, 83.73696281063943, 89.9733352661133, 61.724641015452725, 0.29930816182205755, 9.269710952235807, 98.3091014431369, 69.86641853086411, 66.47100310171804, 64.21153353106591, 50.90049182215045, 72.28923520734234, 45.8342408364819, 0.31884205557646295, 0.18372821621596816, 0.1301955089213387, 0.15480721729897684, 0.18040336398107393, 0.12576889967726124, 0.11769641671449908, 0.107948261974079], [0.01955855220946814, 0.16049764179173978, 0.03128558866709712, 0.038821049740598086, 0.04175556485631293, 0.006149768418136744, 0.08183920410491767, 0.05145248746679676, 0.03244552047803037, 33.18857823648761, 53.93397446601622, 30.169675042552335, 26.99878784918016, 56.81463372322821, 61.75187403155912, 78.83691049391224, 33.76746908310921, 0.19800441790251963, 0.06635573211937182, 0.17292855217331843, 45.246677629409305, 76.81070035503757, 75.25559040807909, 72.32512489441903, 66.990764217992, 63.161730766296394, 60.080846278898186, 58.46005624340427, 55.32322699023832, 54.768046871308364, 53.32051184869582, 52.945815670874815, 55.88638128772859, 57.191032209704005, 60.65417520461544, 64.6997784030053, 65.13812288161247, 64.16559865397792, 65.35065258702924, 62.20297405796667, 63.44317259327058, 60.69099449342298, 62.972735281913515, 60.54319174058976, 56.97647856127832, 52.10713055826003, 49.19763795791134, 49.32842154656687, 45.75399306512649, 42.89182386090679, 46.97181055622716, 51.910749250842684, 48.91632164678266, 52.28029927899761, 59.36843402924077, 60.146510677952925, 61.529958094319994, 49.78652300373201, 51.45806850925569, 57.51818533866637, 51.66509905169087, 46.702080926587506, 52.49735147722306, 48.093122051608184, 51.10893441784767, 48.774924124440844, 45.04579736340431, 50.95147478965021, 44.0421805074138, 49.82941412156629, 39.747899040099114, 49.67280172532605, 41.073216930512466, 33.98786314072148, 43.56330617781609, 45.81361701411586, 48.83608172016759, 53.08051770733249, 47.99598455429078, 46.89667363320628, 52.4503497154482, 52.61876844590711, 54.98593845675069, 49.59283244225287, 50.326096011746316, 49.83548595059303, 48.45124229308098, 48.06920736066757, 50.81347011750745, 50.120375540948686, 47.180394357250584, 49.962966903563476, 50.54280304139661, 47.98082851594495, 52.4610617083888, 54.32146541533932, 51.413486849877145, 51.9193902323323, 48.15226747143654, 48.61693497627012, 49.526254130947976, 40.541316078555205, 37.894551677088586, 34.439320102814705, 44.08072956146733, 64.84080722255092, 52.22836709791615, 47.66210063811272, 54.461207697468424, 52.730555995818115, 51.166106885479344, 51.30144434590494, 50.211743231742616, 43.23834957615022, 54.445730024768466, 54.10449950925766, 55.6236138651448, 50.063932634169056, 53.024667078448886, 51.61780703452326, 62.80404198554255, 52.96240729670371, 57.28345894044446, 58.32562485048848, 49.76723278722456, 47.58154692188386, 46.99411315302695, 43.31696564151395, 42.5990895302065, 42.40973318776777, 46.184029963708696, 47.55733805318033, 49.856431407313195, 49.733472947151434, 52.30842659550329, 51.875251800783225, 53.05806606046615, 53.61517990789106, 54.19466303240869, 53.043368939430486, 52.74133859142181, 55.51868654066517, 58.919722726268155, 58.19555121083414, 62.63081835162256, 61.537947962361, 60.47721747429141, 61.133104447395574, 63.063106690683675, 59.78611153941001, 63.89963057733352, 66.29590065248551, 67.25579092579504, 66.0415663257722, 69.99551157797538, 71.72903445459181, 78.72280874559956, 82.56695116719892, 61.47088327715474, 0.2668464117713513, 8.093472546146762, 82.89126057778635, 59.14381165658275, 53.879904593190844, 47.83178629413728, 24.126822525455108, 39.60544247781077, 24.95003192655502, 0.21111621190944027, 0.14808758432346006, 0.0528156949627784, 0.022813858982596188, 0.08645148241832372, 0.051180553066754536, 0.029142314057436683, 0.0625365041947413, 0.02404924662363145, 0.10725569550789173, 0.00921084269535758, 0.05011394417153732, 0.08140224287466657, 0.032182112636585394, 0.031139361634550076, 0.012746697569626474, 0.036951737748759414, 40.34163998019311, 61.53038955503895, 34.9548803606341, 40.93711460790327, 66.14845875770816, 66.04926201605028, 89.8057794570923, 37.022793139180834, 0.11437214670642731, 0.16057752944048376, 0.20766941379875908, 49.955020181594364, 85.21645730541599, 79.51113454757198, 77.40893240897887, 69.62128608457505, 69.60196448910621, 63.99827426479709, 64.42193731184929, 57.818603592534224, 57.45183844720164, 55.9000389806686, 57.55662848872524, 57.83844686323597, 60.58927959011447, 64.41992905832106, 68.77434438274753, 68.44160187628962, 68.56041046880907, 69.12680072169151, 65.76585115924959, 66.25820667512956, 64.60382546147993, 65.53155229937646, 64.11706324546569, 60.517304097452474, 55.131187746601725, 53.066616827441806, 53.908016220215835, 48.06692454122728, 46.367392924524125, 49.03596962651899, 53.72752835673671, 52.53809705857308, 55.024860135970584, 61.666876269925034, 66.80265518926805, 62.68222101273076, 54.580082970280806, 53.71500030640633, 60.371286023047666, 53.91644147134597, 50.557237363630726, 53.890436157103515, 52.088318870913604, 52.8860701284101, 53.28945452167142, 44.29000762201125, 52.03083653603831, 44.54893112182618, 49.61670790949176, 42.90885479219499, 49.10880019587856, 42.560105093063854, 40.71955250155541, 46.6206564441804, 45.81649603382234, 50.81113630725492, 55.251420159493726, 50.3367099454326, 48.68087353244905, 55.42764440659554, 55.17978983540689, 56.16434789473011, 52.90280688193537, 50.951506168611594, 53.23783220783357, 51.38680688796505, 50.58539213672761, 52.68508395841045, 52.269116601636334, 51.229068771485366, 50.25036288845924, 53.21652197068738, 51.61466521601523, 54.25392220097204, 55.2701259428455, 52.994574654486875, 53.919355792383996, 49.997483761079856, 50.521975255781605, 50.31199116860667, 39.87164197429534, 42.205236496463904, 41.179211139678955, 46.20559515491609, 60.76338967969341, 54.92016030896095, 48.46213079267933, 56.01707858424033, 54.49044896710304, 54.01041361593432, 54.40800074608096, 53.14760200438961, 46.13201933522379, 56.79837157649379, 56.70091244482226, 57.50588870817616, 53.74798351718534, 54.879936402843846, 53.22802628240278, 63.3102003220589, 58.234798446778335, 60.56423917893441, 58.98064497978457, 52.05680262657904, 50.064003236832164, 50.28903745835828, 45.39951670554377, 47.06621416153447, 45.57078699911795, 49.52111190365207, 51.1551477832179, 52.905525084464784, 52.75566700966128, 55.85561029372677, 56.5980718212743, 56.01404266972696, 56.526272835270056, 58.134570121765144, 58.13621751723751, 56.88666020670245, 59.060990810394294, 62.090221604993275, 61.92954955562469, 64.39815598149454, 64.82494123520391, 64.44399279932823, 63.945008477857044, 66.78630675038984, 65.23137331008911, 68.4842929532451, 70.87181614291283, 72.61938110474618, 71.16680191409203, 75.66521921465474, 75.01616108802058, 81.82179497134301, 87.37650655931043, 66.72769085053476, 0.16871866920301992, 8.519095797692577, 92.66334379872968, 63.68222928816273, 66.25375086261381, 57.58616785849295, 37.229239248460345, 55.326070708613244, 38.15103938502651, 0.18596018273984233, 0.018140019758814768, 0.06541754254290173, 0.018111155481047688, 0.0915314037833483, 0.03629073410505249, 0.026204859079312415, 0.04298839184846129, 0.16729561491839348, 0.14334268086860258, 0.16727663125962983, 0.09253723892353236, 0.13950709313634904, 0.15142599631461406, 0.18465386493311775, 0.11613656977011312, 0.18359410486394362, 60.840185765297186, 72.46196070025044, 40.01177649344168, 37.06858681094262, 76.33479133729013, 71.04370224860408, 94.96113100359517, 39.41389745281589, 0.19711672118113888, 0.24284590366146258, 0.3157499408529651, 53.00894621879824, 89.173767951227, 83.78728681995024, 81.63967932424238, 73.89418278971027, 72.60242862086143, 67.04810926991125, 64.88579288605722, 61.44834141577444, 59.229931216086115, 60.038312096749586, 62.34394796432988, 61.46727077422604, 64.42721289973106, 67.81745080024966, 70.7922234073762, 71.51420624025407, 68.53723710583103, 74.17127470816337, 65.85238256762105, 68.99809206685713, 66.18684307221444, 70.0157823870259, 66.94180519350114, 63.241974615281634, 58.93779308565202, 55.6553929082809, 55.90576956349035, 51.83088979413433, 50.33993805608442, 52.60965677999681, 57.63548381866948, 55.54105974012806, 57.397164529369725, 62.65356809862199, 69.67881941026258, 66.99184679215955, 57.70709453090545, 58.372501096417835, 59.8445862339389, 56.90003548899005, 55.01996501799553, 58.55373028785952, 55.22085312874087, 57.60283400935512, 55.91605794045233, 51.711861548885224, 50.2149478081734, 47.88757416509813, 54.88814200124433, 43.56679316489927, 53.52831902042512, 50.274218743847264, 48.328330901361284, 47.88210245870775, 46.65864067692911, 51.4154911810352, 59.11617855871878, 52.83157663960611, 52.351392238370835, 56.078950051338445, 58.19200538819837, 61.6407964306493, 54.704775118058734, 55.24980414298273, 58.3541993171938, 55.495505332946784, 53.96094076095089, 57.855842574950195, 54.28610132586572, 52.16796651963265, 54.082342040154245, 56.29909699962985, 52.22864558619838, 58.85494870524253, 59.91111355443155, 56.46046723088911, 55.87001323699952, 53.570959106568374, 53.47760669646725, 51.71897672837781, 40.308605778601866, 43.46315630020634, 44.610037726740686, 51.88735623513499, 61.83995869851882, 53.60942971321845, 53.34180247399115, 58.296756206020234, 58.511741315164876, 54.264061527867476, 57.33370450235183, 57.12664650332544, 49.4978718603811, 61.22667651022635, 58.51544403260755, 60.87904468659432, 55.95427359304121, 58.997417034641394, 56.450076872302645, 65.85173929891279, 60.796400347063624, 63.006232323185095, 62.397864864718535, 54.69786390181511, 54.819551514041045, 53.22783408626434, 47.74902820587159, 49.647467136383064, 48.477208383621715, 52.03626901872697, 51.93147113246303, 55.38612611832158, 54.150214733616004, 58.76132957396969, 59.18854628839801, 58.29386541920324, 59.91671469903762, 61.47461345118862, 60.6114919724003, 61.16022763713714, 62.5595018171495, 65.70320698522752, 64.04214205280428, 68.30980239375945, 65.62431243158156, 66.73606903322282, 67.88221697653493, 69.1729199501776, 66.44110679626465, 70.53814795709425, 73.2191821067564, 75.23342117186516, 70.79422381616408, 77.80394646429247, 78.15124096408968, 89.65623517190257, 87.7891634356591, 70.11557532894996, 0.2862517866155794, 9.737068222415063, 98.32847010704779, 72.12149896929341, 75.45338769112864, 66.09702864000874, 40.80300484934161, 70.51348409345074, 52.5866638460467, 0.35020952563612695, 0.26473942483144425, 0.10562346857641974, 0.1611023609556498, 0.1687362739035199, 0.07064879691648869, 0.18246017216194063, 0.19186474412920015], [0.04612734135720999, 0.044249257658638304, 0.008429306608083989, 0.03768916632379255, 0.05648766929704336, 0.050788783363156745, 0.05003121816703389, 0.018763293572250875, 0.2984632894156441, 19.185246036898707, 54.53213591729441, 41.510349396736395, 33.30109142488049, 52.43073786458662, 60.311630695096916, 74.90984132212978, 38.964362452107096, 0.07352793919703654, 0.3044927384584181, 0.3654253494835669, 44.63071253991897, 74.38546749853319, 73.61982868563744, 75.24618456440588, 67.81975715391098, 62.67271318743306, 60.56039917853571, 57.10553238468786, 53.897712153773156, 53.61186550509546, 52.795985052662516, 53.361743803947206, 59.43357675306259, 62.80285742975051, 67.07606792449951, 62.718032252404, 83.81376281861337, 86.10397984904628, 62.47015414699432, 70.58283944283762, 62.01493955427601, 65.41380666917371, 65.15397317947881, 66.04718315985896, 55.84904424605831, 53.32344185921454, 51.61758738179361, 48.66556844403667, 45.47976839926935, 45.88101117841659, 44.95535927434122, 48.47778889440721, 45.768458766321984, 51.330850355086795, 57.056769478705625, 60.88246107101441, 53.80463823195427, 52.90324618739467, 46.46659751092234, 48.10583837570683, 53.5217765069777, 46.92515788539764, 46.28035160803026, 46.091587543487556, 46.36766749043619, 53.046491146087654, 33.20342440758982, 46.033881633512436, 43.77093292051747, 36.88403144959481, 50.847888915769516, 41.12519618003599, 31.382797456556755, 38.79083679568383, 45.68757557099866, 48.9536076976407, 46.9054558200221, 47.235640941127656, 50.73221037464758, 47.4424361413525, 50.50968254766157, 53.35471491659842, 54.77593475772489, 49.961951009688846, 49.89340759092762, 49.62536850283223, 44.8332872698384, 47.869613632079094, 48.06533990367767, 49.420318757334066, 45.02635417446014, 46.193498565304665, 48.32234144210816, 47.56482978020945, 49.83761187522642, 53.341225885575824, 49.256493122346946, 52.10811115080311, 49.61533900230162, 47.91871386189615, 52.92903184890748, 46.08963812551191, 43.80681868522398, 34.22988122509372, 34.61614447255289, 39.47363515054026, 64.00204366253269, 49.352465675723174, 42.49211472849692, 45.51767810698479, 51.887234641659646, 50.10203846039311, 47.43165354574881, 48.9994562825849, 49.40069513936197, 53.683491906812115, 51.667946692435976, 50.52992197775072, 49.894549000647764, 49.6980147207937, 57.32716198890441, 52.12455372656546, 54.97335941560807, 55.13006987110261, 50.54075948653683, 47.648274283255304, 44.93224082454559, 43.612928082866055, 43.960701111824285, 45.402442793692316, 46.58378616456063, 49.141434315712225, 49.85372889426447, 51.162753258982015, 52.65562303604619, 51.93408343099779, 54.13649820512342, 52.545447580276004, 54.447781424368586, 54.64348416174612, 56.13127054706697, 56.13023111897131, 59.42231955066804, 61.19326183872839, 62.94086994663362, 63.53972957980249, 65.26060673498338, 66.04514352736935, 68.89880903305547, 67.16352108986148, 68.713806521508, 67.01810313809302, 69.19488522314256, 70.14172184851863, 73.73345974952944, 76.46299792874244, 75.45757678247269, 82.17480044211112, 66.78143516663583, 0.2440083501560073, 7.703134936671104, 86.74114534931799, 49.47602818089147, 50.64159185655656, 49.58983182907105, 23.096529629922685, 43.9581633383228, 27.313909107638946, 0.22221616709664946, 0.08751916383663494, 0.06434440657856964, 0.03452186773140584, 0.05510272405621025, 0.05046628716011202, 0.07019856704338905, 0.024025066973521345, 0.03180809893585261, 0.03188225624692296, 0.0735495888417767, 0.011174662166365213, 0.03290610785986627, 0.09187937624031499, 0.03443557558761489, 0.1377718733443368, 0.4032009305252183, 28.286531394527806, 63.88401169930736, 38.90930806436847, 37.323356520745065, 64.27663703118601, 64.40926413382253, 85.565932643029, 42.101423125113214, 0.03100689354112312, 0.37478614718683306, 0.9220834052370441, 48.16661550152687, 84.40451883500623, 78.43085888893374, 78.76001634905415, 72.05505401857438, 69.60186250748174, 64.41053890412854, 60.87021935370661, 57.987504774524325, 58.34498566965903, 54.892417384732155, 57.53931906915481, 62.023062782902876, 68.40707717403289, 70.33587917204827, 67.08030408428561, 83.53881251427435, 86.49378499677105, 66.58565398185485, 71.41388770072692, 65.32251742578322, 67.52728169964206, 67.76562844553303, 69.4269718662385, 60.73438375226913, 56.52899103779947, 53.16155779746271, 51.87549106536373, 47.3334962321866, 47.74531764368857, 46.525331081882605, 51.67854885901175, 48.052262721523164, 55.06582144768008, 58.56025711182625, 63.652415352482954, 57.43003006904357, 58.93606332040603, 49.81432476351338, 51.04876918177451, 53.71615740560717, 51.042054084039506, 48.79769740566131, 48.56235519532235, 50.29881592719786, 57.627733215208984, 34.63452862155053, 42.43718585660381, 45.912507810900294, 38.37395552665957, 53.759970280431936, 42.52958905312323, 36.4570971458189, 45.51085318288496, 46.481675101864724, 52.380378553944254, 50.45812299174648, 50.53952393993255, 53.06700514208887, 49.46965825173163, 53.10029822011148, 52.81999388048726, 55.337571097958474, 52.91521333879041, 52.60536178465813, 51.48553686757242, 46.43681887657412, 49.323369533784934, 50.24302021149666, 51.92505413486112, 46.891464725617446, 47.84824455938032, 49.67200940655124, 49.359933868531265, 52.434185627968084, 54.71410643669867, 50.843311509778424, 53.72134670134514, 51.82584562609273, 50.277654740118216, 54.111006721373535, 46.50401692236624, 44.44932645367038, 38.17314586331768, 39.91920855737502, 42.66012553245791, 59.07098893196353, 50.67737956200877, 43.51872059606737, 46.93433623160086, 53.55116290430869, 51.28595490609446, 52.39801745260916, 50.88133888859903, 53.898547618619865, 53.61192041827787, 51.7088766251841, 52.578344498911214, 52.513499875222486, 52.47482530532345, 59.12416450438961, 55.87751673113916, 58.75634031911051, 57.58403408911921, 54.158432099127005, 50.66560460675148, 47.34280009423533, 45.48638543775005, 46.928303626275834, 48.44309553023308, 50.48461075752012, 52.916378282731586, 51.94245376894551, 52.67298736879903, 56.813151067303075, 55.32246997279506, 57.004711781778646, 55.27401301168627, 57.632596954222656, 58.518962398652114, 58.153628918432425, 60.2986829511581, 63.10069868641516, 64.59585128291961, 66.9693245426301, 67.84271870889972, 70.43855897841915, 71.02441987683697, 70.71736889500772, 71.84536410916236, 71.02776958096412, 69.91325163072156, 71.71794199174451, 73.5121831586284, 76.5964997199274, 80.93534715713994, 81.84783166454685, 85.99093714068013, 69.2851624950286, 0.2375821594990069, 9.272932198739822, 90.9831573117164, 55.88310218626454, 59.32284039835776, 57.631243736513206, 34.69685900595881, 56.36076450347901, 39.73859910042056, 0.09384138104055198, 0.07404795201915888, 0.07655988537496136, 0.030141650856803023, 0.03578621541119872, 0.05624837407301511, 0.06027186019045692, 0.031731463330347216, 0.10676424244358655, 0.14952445883424054, 0.1237466803661758, 0.17608336353253934, 0.10165720156604245, 0.1458564298527856, 0.15165522514331728, 0.23617755261159715, 0.5124420961064677, 41.23373600744432, 75.06001318654707, 55.879168048981704, 44.75567140886861, 71.37135351857832, 69.67681115673435, 91.80846321967341, 44.995591025198664, 0.10717844320160728, 0.5423373596802835, 1.0898923297082226, 51.656269796432994, 87.88707363990046, 82.4084246543146, 82.23726810947542, 74.4140458876087, 70.83372992853965, 67.56503059018043, 64.32812206206783, 60.8634767993804, 62.067868017381244, 58.46029158561461, 60.19415178606587, 65.64964309815439, 69.62455734129875, 72.54742914630522, 69.7962708627024, 84.24290933916646, 86.24733463410409, 69.14762066256615, 75.18086925629648, 68.26497754743023, 70.17081014571652, 70.06984049274077, 72.83141659152123, 63.15403507601831, 59.105917638348, 55.61406681614538, 51.63230411468014, 50.82637863774454, 51.483658052259884, 50.768837467316665, 53.68127184529459, 52.17214776623634, 57.564892922678304, 62.26211163305468, 67.95015242791945, 61.318852209275775, 61.16234571703019, 57.072921799075225, 53.07702287550896, 57.47317221856887, 52.20219704412645, 51.05319361532889, 50.116896398605846, 52.291379974734404, 59.563975949441236, 45.55352857035976, 49.477063686616965, 48.23995205663866, 40.8272058733048, 54.11998502669796, 50.90903082201558, 43.33394165961973, 47.454156183427386, 49.41329379235545, 54.21732648726433, 54.85995977155624, 53.69275262278896, 55.35515508344097, 53.424697845212876, 55.866043798385135, 54.650685633382494, 60.33479621333461, 55.758398271376095, 55.444573356259255, 54.99377927472515, 48.595820857632546, 52.40492474648261, 52.55822666229741, 55.693467355543575, 48.28198809777537, 51.40333575587119, 53.182926870161495, 50.19184112548829, 56.44452671850882, 57.37901572258242, 53.121098549135276, 56.31754782892043, 52.961465927862356, 52.37461659216112, 58.576299605831025, 47.15745633648288, 43.83425566457933, 40.1561354052636, 47.19608383793985, 53.54137266835859, 62.32332021959367, 48.85802345891153, 45.4342532157898, 49.08503847737467, 56.56613196096113, 54.02465966440017, 56.36587142944337, 54.25612265063871, 56.79297439513668, 55.51774517182381, 56.467284310248594, 55.86482001889137, 56.468049172432195, 56.412229922509965, 62.20123252561016, 59.01463231732769, 62.020532854141734, 61.25428999623945, 56.693201065063484, 54.55610944378761, 50.95830363612021, 49.350928106615626, 49.45969935386412, 51.07130712078464, 54.22174699844853, 55.8851339740138, 55.44073335586056, 54.76383032337312, 59.78868461424305, 57.706353202942886, 59.935765650964555, 57.841580837003654, 61.04539240560224, 62.675953065195394, 62.4201556944078, 61.013617284836315, 65.59548301081504, 66.78205490112305, 69.11912072089412, 69.36784605826102, 72.71750311697684, 72.55776851407944, 74.91484626646965, 74.72394451018303, 75.01092080147036, 73.449417391131, 77.55245193358391, 76.75469675371724, 80.1922070595526, 84.87854511507096, 82.63060339035528, 88.03056178554412, 75.21120486720916, 0.32417537584420175, 9.774539605263742, 99.45541412599626, 60.84376296689434, 68.1183671951294, 66.8625811607607, 38.513317338881954, 72.62276218783471, 51.923924492251494, 0.23791390621373731, 0.24178562265249992, 0.16001189608247052, 0.1637670445826746, 0.1631494091763612, 0.14010706255512853, 0.1345877514611329, 0.1582853637275196], [0.047636848664091486, 0.02641333075570724, 0.10180200750548994, 0.035926137540128925, 0.06833928697291883, 0.042084929037598834, 0.06053301190296489, 0.05310440668836237, 0.3824370366431052, 19.237391987154563, 55.22485002394646, 40.31222220390074, 47.99655722033594, 54.25051758366247, 54.36705120148198, 72.50106673086844, 42.792046608463416, 0.05035425446206524, 0.6611371881538822, 1.7235529470828272, 48.74159574508668, 76.48765394764563, 74.07468242029991, 73.33919094454858, 64.86984452893658, 63.07026109387798, 58.74735416904573, 57.39568971818494, 50.7715948935478, 52.84132765185449, 55.809816621964984, 66.63127899169922, 65.18150429571828, 64.10685723827731, 69.72391882250386, 74.9159445301179, 66.54595959571101, 60.096076842277284, 66.77544178501253, 64.02633097863966, 64.91978806834068, 65.64743872611754, 64.41855622876075, 64.01284194761708, 60.28431530921691, 52.46064593715053, 49.88728477108864, 49.957640324869466, 47.5085320011262, 45.02371441933417, 45.64854798778411, 48.01342341207689, 46.78830639008553, 51.84903467855146, 55.25141623712356, 54.27096489937075, 52.07200965573711, 56.8132608936679, 44.450605146346554, 45.01714052692537, 49.16186594193982, 49.76131000826436, 44.007087061482096, 47.16993339600102, 44.880900921360144, 53.52744825424687, 41.07072230308287, 37.599373709770944, 44.921944602843254, 43.500501186616965, 44.47814018495622, 32.47567961292882, 38.37315928551459, 47.1543223627152, 46.32971463664886, 45.487558226431574, 45.516736738143436, 49.47627136784215, 48.93589035157235, 46.25925317887337, 51.511844204318145, 50.62759683978174, 51.30804177253477, 47.12237073529152, 46.91693267514629, 47.49006940472511, 44.95990137900076, 42.62292185137349, 48.91792589618314, 49.501347080353774, 45.52220844453382, 44.51914072036744, 48.227133750915534, 45.59172853346794, 49.60858860323506, 50.00199056440785, 53.442485793944336, 50.43900928189678, 47.33916013471542, 46.101467993951616, 53.18325634925596, 47.73204826539563, 45.40762032231977, 44.38377188098046, 39.64294818139846, 33.49781397850283, 35.734318071796054, 66.62650938956969, 45.14312313448998, 47.58379836236277, 46.09267011765511, 42.10057981552617, 55.681308008009395, 48.220159776749156, 48.177911927623136, 47.5232958024548, 50.05356580980363, 49.25122537920552, 49.44816366318734, 50.809182966909106, 51.92528555470129, 48.052631424319365, 58.24216465796194, 54.37617463450278, 46.41799542211717, 47.33825014483544, 45.1447783747027, 42.05711603164673, 45.607182671946866, 46.71626029476043, 47.74629039149131, 49.74713456246161, 52.41675069255214, 53.64832001347696, 53.884968373083304, 54.92896995236797, 53.073751618785245, 52.87323613320628, 53.22268793659826, 52.65729788810977, 53.02733821253623, 56.28488625249555, 56.86762102188603, 61.30863443497689, 65.56419426395048, 64.37234286339053, 64.78181085278912, 65.28050099649738, 67.6328169914984, 67.2269222813268, 67.13292660251741, 66.42953580425632, 67.88984206414992, 68.58439968478295, 71.52853073612337, 77.45265899165985, 78.04799633641397, 85.26404350034653, 63.81191461317001, 0.285295034728704, 13.054883480072023, 83.28287786053073, 55.20305733526907, 48.40464453543387, 46.29867692147532, 29.34183136109383, 42.42329674382364, 32.1831060994056, 0.19354134287324645, 0.1794163822647064, 0.03721315759204088, 0.052264640257964214, 0.043273058629805045, 0.05201044462380871, 0.11446103588828158, 0.05798683441694706, 0.0757273623058873, 0.06765367658508402, 0.04108673562445948, 0.03668351504471033, 0.02549036717673223, 0.09689630985620523, 0.13467223563742253, 0.19657783961344152, 0.6251763468307834, 23.828698858138054, 65.19307136535645, 42.316290563152684, 50.23914098739625, 65.78708294899234, 57.9791344365766, 83.00747256125175, 46.736840971054576, 0.132127613309891, 0.26340195788971843, 2.383949910440753, 53.65954583691013, 84.8829460144043, 78.27701568603516, 77.09424065005395, 67.38794342164071, 66.54042905376804, 61.838291691195586, 62.72100540899462, 55.0751135426183, 57.538734635999134, 59.21070375750142, 68.87382353505781, 69.54871439164685, 69.24100445162865, 71.15129286243071, 74.31564146472563, 68.9927105749807, 64.76699998301845, 69.85346686455512, 67.46162906769784, 66.47335652382144, 68.57517427013767, 67.8850567725397, 66.49700841596051, 62.39055748908751, 55.6558596703314, 51.913922448312086, 52.875444427613296, 50.502685039274155, 48.504790490673436, 48.08021353137109, 48.69149138850551, 48.616040675870835, 54.26044902493877, 55.776409795207364, 56.89208876702094, 57.223478055769405, 58.768323159986934, 52.22630000883534, 46.33917931587466, 51.765574486024924, 49.848229731282885, 47.7548215466161, 50.128361486619525, 49.10444244261711, 56.48433093101748, 44.48925618202456, 39.92643356323242, 49.195237467365885, 44.61582322274485, 46.68465383591191, 37.59885987927837, 44.586946733536266, 51.63990566807409, 50.352034645695845, 48.94737897380706, 48.74632220114432, 53.12799799826838, 49.995899123530236, 48.088525033766224, 53.54303183094148, 52.46855343541792, 53.598360784592174, 51.92025707614038, 49.08947075566938, 49.460809384622884, 47.59646761801935, 45.178094986946356, 52.57186082101638, 51.95627227906258, 48.86722533933578, 45.379359645228234, 50.292504833590606, 46.65258061501288, 50.42961912770426, 54.56360117081673, 55.65202359230288, 53.71229779335761, 49.941652744047104, 48.83950594932803, 52.27118761308732, 48.900518417358406, 46.673930075860795, 45.4590622071297, 44.228371497123476, 38.91612906609812, 41.16562797177223, 63.330384838965635, 46.337904545568655, 48.5913218990449, 44.39033792864892, 46.87518296703216, 59.22944484218475, 51.30063241527927, 50.57579017454579, 49.29576389251217, 49.9253592183513, 49.310300196370775, 52.216694124283336, 53.2527332921182, 56.49338768374536, 53.009781683644945, 62.04192153869137, 54.53370094299317, 50.01573454949164, 48.202371828017704, 48.57951164245606, 45.27125520090903, 47.39879585081532, 48.690436270929155, 51.43525208196333, 51.6832164795168, 55.605884751965924, 57.83810169466081, 57.16255580225299, 57.547987507235625, 57.03591423649942, 56.33119767712009, 54.866988658905036, 57.17834726456673, 56.99965192425636, 60.29409770042666, 60.610950685316524, 63.83824548413677, 66.92154222919096, 69.27912988970357, 68.21127245503088, 68.37325849840718, 73.30052421938989, 70.06815387356666, 71.31790730261034, 71.07170797163441, 72.84636082187777, 74.21429526421332, 75.0685090403403, 82.8723547535558, 82.44271401436099, 89.45725333306098, 63.82244617708268, 0.303230102985136, 16.45259741813906, 89.53763054263207, 65.00548008949526, 56.698013813264915, 54.11751001111923, 35.89978717988537, 53.81796252342963, 44.68633567133258, 0.20725849955793352, 0.16200816799556056, 0.012361736472455725, 0.04929105082767145, 0.019158167847161813, 0.08450449294140262, 0.043247482784452944, 0.03222276509228734, 0.2401255714076181, 0.09057641389869875, 0.16045242728244874, 0.1291206722418147, 0.15743534321025496, 0.1792973628447902, 0.24498422359747274, 0.4350602903193043, 0.714010063919329, 34.47566086246122, 74.27202470840948, 56.79434330232682, 64.89828563505604, 72.88397635183027, 66.57700123325472, 87.17638723311886, 51.16545184966057, 0.2754812032705353, 1.3553170355096942, 3.167743168530926, 54.98392235848212, 91.02615433354532, 80.7501563718242, 80.63818839288528, 70.00736498063611, 70.22997517739573, 67.00708127790882, 65.61775815102362, 59.03641716126473, 59.78065160013015, 60.703785342554895, 71.43768079819219, 70.54251747746622, 69.90761910715412, 73.81995585656935, 72.37466442969539, 70.86856842041016, 72.3077880182574, 69.97424448690107, 69.47902171842514, 66.48717895630868, 71.39939062057003, 71.3952721318891, 68.87815383172804, 65.10848153022029, 58.29774072093349, 52.58340043406333, 56.252813031596524, 52.69835725907357, 51.86331602834886, 52.78132715532857, 52.12355744454169, 50.97676623252131, 55.73780190560126, 60.87763263333229, 60.80049530152352, 59.91529087866507, 61.73659247736778, 54.439207123171904, 53.377849055874734, 55.621193762748476, 52.074500360796534, 50.00241418038645, 53.51600670045423, 50.920841078604425, 59.2273973649548, 45.62280939471337, 42.493820959521884, 51.68416177072833, 46.91158256223125, 56.03684340753863, 41.73117883743779, 47.28580021089124, 55.71382445673789, 55.42216877783499, 52.18808827861663, 52.678196276387865, 57.68619614262735, 53.70457856885849, 52.43575849840718, 56.62830152819234, 55.9957173562819, 56.46345215459024, 54.04153370088147, 52.27885976914437, 52.03077770048573, 51.08312129974366, 46.49715277456468, 56.136820700860795, 55.78172852916103, 53.32973726334111, 48.521048715037686, 52.53775188999792, 48.30892693611884, 52.99963058963899, 55.92647183325983, 57.679273159273215, 56.11916219034503, 51.51672363281251, 50.81282684879919, 56.22412873852638, 50.76329908063335, 47.47107336598058, 45.779900320114635, 45.506828831088164, 43.29540045030656, 52.56176856256301, 65.73727669254427, 46.51579187762353, 48.0270811050169, 43.04215262013097, 49.45817747423726, 63.10045942183464, 54.56256566509124, 53.29818179530483, 52.31934647406302, 52.496115930618785, 52.89897472627702, 55.99524274949105, 55.57224258299797, 60.0374177963503, 57.83275942648611, 65.72730994993641, 58.44581803967876, 50.74535031472483, 50.55437795577511, 50.28246356594948, 48.105402992617705, 50.678787692900634, 52.30311962866014, 53.35651136213734, 53.775679372972064, 59.10296801597842, 59.84460192341959, 61.23882409065001, 59.91263543405841, 58.95472595768591, 57.91770227493779, 59.34146773430609, 57.77155868468746, 59.583713316148334, 63.14667670957504, 63.24115091754545, 66.98402558603595, 71.48912660537228, 69.79680430504584, 70.72870454480572, 71.8149814298076, 77.38542956690635, 72.97677963010727, 75.85960403565439, 73.59523542465703, 76.62612145946872, 77.12113241995536, 77.81210499425089, 86.40145240291473, 86.90095055487849, 89.87217733936926, 72.50345937667355, 0.24090126607446904, 16.628725567171653, 97.51948910374796, 67.46311956836333, 64.19731493919127, 62.43656296883861, 47.84336120851579, 65.97971054815477, 53.13590941890594, 0.26025407196533296, 0.24916851923110026, 0.16003311671797307, 0.1559453481628049, 0.16932986947076936, 0.1333187114928038, 0.1728787411364817, 0.15337786577161283], [0.04423992287728094, 0.008846304544638242, 0.05047451494441879, 0.021934775004704154, 0.02522343150039594, 0.05644247393995043, 0.05154038073434945, 0.13785481002301941, 0.3135123512437267, 13.21255393566624, 56.12077820685602, 36.223374874361106, 28.90608545272581, 53.725849582302956, 55.740606400274466, 71.12286352342176, 52.88978853533345, 0.615042842203571, 0.16208010365165051, 2.9917032728272104, 55.81745739906065, 79.04858512263145, 72.00341209288567, 71.49868149911204, 64.4467306137085, 61.40814496624855, 60.219553055301795, 57.780129063513975, 53.69273693330827, 60.72035343416276, 66.14412846103792, 64.85624567154916, 70.3712667957429, 75.44680595397949, 64.47060608094739, 57.34768382964596, 51.35743618011475, 60.705315066922104, 64.68292397837486, 65.54340177966704, 63.17927160570699, 64.84373723306965, 62.98848752052554, 64.60871273471464, 60.65645410168556, 54.942655101899184, 51.260306527537686, 52.64557000129454, 49.51311811324089, 44.51887007682554, 43.178458905989125, 45.98375374271024, 44.60733521369196, 51.23701549345448, 52.33207456527218, 49.691895823324884, 53.84839619359663, 53.19754162142354, 48.63844133192494, 41.031949673929525, 39.9021384023851, 47.93510544684626, 46.62605362553751, 42.41519312704764, 49.75914485992924, 49.51589907369306, 53.375844724716686, 48.859160946261504, 50.14700451204854, 43.3666895281884, 36.24233561177408, 49.79516398522162, 44.06873495348039, 43.23427031117101, 42.30180132773615, 44.87058508780695, 45.13779655579598, 51.76843781625071, 47.06764190427719, 46.006746676660356, 46.524103380018666, 42.23466603986679, 46.966189799770234, 44.657635688781745, 44.76785429062382, 43.97234662886589, 42.57492772994503, 44.636674542580884, 46.866616510575824, 48.25486883040398, 45.24932130690544, 44.50240004447199, 45.00868389683385, 44.22607691057267, 42.715458408478774, 45.65279199231056, 45.58390732734434, 47.72976152358517, 46.34386654823057, 47.77892451132498, 49.77581885553176, 48.50149962209886, 44.70111908451204, 44.17510571018342, 44.787944670646425, 40.015891059752434, 31.028389738452052, 40.48981535819269, 56.53560415390999, 40.10951411339545, 65.90588369677144, 54.69235689409318, 48.47471767856229, 51.77468222956504, 47.148301524500695, 46.50560548228603, 45.536493716701386, 46.34976971533991, 44.49746962516539, 49.58527403493082, 50.732932090759284, 48.55761697215419, 55.527331444524954, 51.14687550452448, 45.78812945273615, 46.99732557419808, 45.88911871756277, 44.17783567982335, 45.14932832410259, 48.215849091929776, 47.58071145703716, 51.707543019325506, 53.60281267473775, 55.33238964696085, 56.820172109911525, 57.12925487949003, 56.61033315043296, 55.9967371725267, 55.049300424514286, 54.949432957556944, 53.28814837240404, 51.994044703821984, 53.415033125108295, 57.0505250653913, 63.23571451248662, 65.26754148544805, 66.8547599546371, 67.34108678756222, 67.20636121688351, 67.52974494811028, 70.07312743894516, 67.66090900667253, 68.40402557003883, 71.57424988285189, 74.14792091615739, 75.34944488156226, 75.37919998168945, 85.35625842309769, 49.705424078049205, 0.7228027308179487, 18.560126135426184, 82.52734307319888, 51.77668263835292, 49.504453597530244, 44.09694856212985, 28.490443652676, 57.50997581789571, 34.83423217650383, 0.06765621999699263, 0.0318661013678197, 0.017377813985090584, 0.021140870427893057, 0.010518566273423213, 0.07278198406340615, 0.03639601756848636, 0.03283435223443854, 0.04135359852244297, 0.023864178933323394, 0.05540801392447564, 0.08713372968017094, 0.05551018707093693, 0.1062609609817305, 0.06894817365513695, 0.2677316416896159, 0.5781201008827456, 16.57418304874051, 68.16734190910094, 37.447919230307306, 30.468212519922567, 64.24407743638562, 61.63138274223574, 80.07192365584835, 60.89849572027884, 0.997723985102869, 0.16256307612263388, 3.9101662078211388, 59.580500894977206, 87.04076736204087, 76.24303925421931, 74.04110693162488, 68.12578831949543, 66.21636283013129, 63.33437388943088, 60.282805196700565, 57.01277617485293, 62.05328464508057, 68.81362299765311, 70.20568001654841, 71.01481006991479, 77.18510627746582, 67.53410662374189, 60.037100084366344, 54.83871229233281, 62.80624635757939, 67.80192605910763, 68.12001459060177, 66.78574977382537, 66.11043530125772, 66.64247343617102, 67.86820627027943, 64.85240959352063, 57.56951739711147, 53.6176117773979, 52.77107015732796, 51.475656417108354, 47.33134677333217, 46.319383113614975, 48.49660058175364, 47.29546100862565, 53.83748415977725, 54.8360215463946, 50.045587708873136, 59.13129929573306, 56.02802591939127, 54.836849166500954, 48.13893141285066, 41.068176684841035, 49.58531325863254, 49.166392357118674, 43.354381130587676, 50.78399742803266, 53.68887732105871, 53.55424196489396, 52.35134516992877, 50.926155890187914, 47.58000150803597, 43.332655122203214, 52.12078432882986, 49.71035057498563, 45.83832402383128, 46.41231583010766, 46.3648316168016, 47.045056896824995, 53.659832169932706, 50.643811918074086, 48.529999563770915, 49.43928341711722, 45.93573216469058, 49.20716931743007, 46.93346154305243, 46.63083107240739, 45.54043962109474, 44.6794754459012, 46.70655242858395, 47.72019878510506, 50.945552010690015, 46.2228653507848, 46.72512092897969, 47.46775111844463, 45.035273644231985, 44.95753618978685, 47.418607742555686, 50.018488053352606, 48.67497036533971, 48.580256892788796, 51.746037160196614, 51.866963832609116, 48.75894046598866, 46.67621681767125, 46.255503392988636, 45.466448030164166, 44.622444183595725, 38.814143519247736, 42.96110860763058, 50.38372347431798, 44.39564489549206, 57.434246616978804, 49.659873593238096, 52.41107110054263, 52.54767156416371, 50.9226728254749, 47.245325273083104, 51.387120677578835, 47.230118243925034, 46.56706510051605, 50.66069772166591, 53.02396889655821, 55.06076159015779, 57.62596030389109, 54.758743009259625, 47.836163659249586, 48.36752322412307, 47.72898881666122, 46.21685627968081, 47.84320039133872, 49.87334074512605, 50.70342017758278, 53.077775970582046, 56.00971237305672, 59.12967543448172, 59.72652681412236, 60.86781101842081, 59.994914993163086, 59.18130167068974, 59.25486572327153, 59.05486406818513, 55.50956703001454, 55.95598374643634, 56.798579462112926, 59.06321087191182, 64.56779456907704, 68.71057448848602, 69.04561550386491, 70.50692589052262, 72.42241536417316, 73.18270406415387, 73.6469401082685, 71.36524246584985, 72.61432124722388, 74.79015411869173, 78.93966090294623, 78.94556799242574, 79.43493073986423, 88.60261594095539, 51.34681832405829, 0.6066940772917964, 21.2780580212993, 87.72480518587174, 59.638265640504905, 55.07345830240558, 52.77215665386569, 29.111778466932236, 65.80224683207851, 44.56902150184878, 0.15089362649427307, 0.039493851138338934, 0.12047903957746683, 0.09790859545671171, 0.025313939042990247, 0.06873386821919872, 0.023238966917438854, 0.011437580669148555, 0.1827301875117325, 0.18177734267327095, 0.21379946550774961, 0.1465888405519147, 0.2439832377938494, 0.2702692313300025, 0.22182733150980166, 0.5782955043738889, 0.7373553983146145, 25.803478879313317, 78.54122654084237, 46.711831938835886, 40.50463015033353, 71.56690720588931, 67.96422589209773, 83.8694683198006, 64.68629721672305, 1.178222512525897, 0.6118633934567052, 4.596988914474364, 64.62710472845262, 90.13137540509625, 79.68782163435414, 76.68917748235887, 69.55723377966112, 66.6261406867735, 68.19930138126497, 64.7875649698319, 61.10636957230107, 65.58502597193565, 72.7157380503993, 71.64762173929523, 72.75667190551758, 78.0109142488049, 66.8250205439906, 60.45898629773048, 60.077390670776374, 63.15018330850909, 69.44490494266634, 71.67551763596074, 69.3829236492034, 69.48041808220648, 69.37053680419922, 70.05227611910912, 67.76413010012719, 58.845487948386904, 56.569132574142955, 56.74456450246996, 54.027750492095954, 50.37617683410645, 49.19168379998977, 50.28429139044977, 49.10298332091301, 57.630569088843565, 60.40789350386589, 55.26982784271241, 62.74011519647414, 61.090385913848884, 57.12165332609608, 54.162883989272586, 50.60356840010613, 53.9532607601535, 51.87040767362041, 47.92219300423899, 52.626675944174494, 57.49967959619338, 57.73794397231072, 55.09174046977874, 54.769776636554354, 52.68033004576161, 46.24815287128572, 56.124108299132324, 52.09303355986073, 49.20415693713773, 51.058724157271854, 51.05156975407755, 51.33476488051876, 56.81720287569108, 54.263331967015425, 49.68712622119535, 51.63524589230938, 47.17769184420186, 50.965250153695386, 48.80968416890791, 50.52170068986955, 47.41778012244932, 48.5756520302065, 50.17393550565166, 51.66137280002717, 54.4165946591285, 50.25988640323762, 48.76599680992865, 51.49238924826346, 48.43599996259136, 49.02502229136806, 50.975236508154104, 51.23399526842179, 50.88402963453724, 49.7110919029482, 55.051763672982496, 56.64300257159818, 53.3433400430987, 49.343726634979255, 50.29791378205823, 49.03163148510841, 48.88254219485868, 43.316306683325, 53.752517777104536, 52.75815379235053, 45.46752668196156, 59.705267567788404, 50.700360728848366, 55.65481631986557, 55.39503382098291, 54.259233090185354, 50.6591405407075, 53.53549303547029, 49.83140668561382, 48.786244084758145, 54.319453239440925, 57.02713597205378, 57.126658270435954, 63.224127830997595, 55.99764324003651, 52.285049269276286, 50.76653111365534, 51.873306305177756, 49.352661794231786, 51.883367184669744, 51.51700604346491, 51.15342194034208, 57.7589011961414, 60.541297235796534, 61.57564193971696, 61.847634776946045, 63.60234237486317, 63.253455392776004, 62.070774493678925, 61.447145092871885, 60.93292236328126, 57.60063355968845, 58.37138322091872, 61.22480161728398, 61.38960392244401, 67.71088000266784, 72.10016127555602, 72.65680051619007, 73.22261810302734, 74.52446060795938, 73.10497053207891, 75.62506198883057, 73.35021280473279, 75.70831821810815, 77.21380233764648, 81.80589368266445, 81.17182685482888, 83.84307861328125, 92.46327154098019, 57.00328011666575, 0.7384002809562992, 22.345401625479422, 97.20682128783196, 63.44891886557303, 66.14211236276935, 60.60659685442525, 44.13413655373358, 81.08322051263626, 53.46563170033117, 0.27266123362125894, 0.23020600449414025, 0.19018708818381835, 0.26013569605927317, 0.08383247295334455, 0.15577998042346972, 0.129557418967447, 0.11448057113035072], [0.03405023719214144, 0.07350918536465015, 0.033935358477455956, 0.009120045954571858, 0.04616571087089758, 0.09859493362807459, 0.045072151002504175, 0.15716408679802574, 0.323296764925603, 5.332672586364131, 52.27890683758644, 49.18360371743479, 37.585947436671105, 51.26009864191855, 49.77612872277537, 64.72128083628994, 63.638702746360536, 2.302513906071263, 0.12225820983369505, 4.478798585553323, 58.521653144590324, 79.98816536318871, 69.73053978335473, 72.83988891109344, 63.67025036965648, 62.855585851976954, 57.922342438851636, 57.12789773941041, 55.32428210781467, 66.61812336214128, 63.62293481826783, 77.05828036031416, 104.6569319694273, 61.9324952556241, 55.68230036766299, 56.489331952987186, 63.984926439100704, 61.660937801484145, 62.00184276027065, 62.428369137548636, 64.15148204372775, 65.20280276575397, 64.4430906541886, 61.47947719020229, 60.02220292245189, 54.54864517334969, 50.06487008064024, 48.65175777865995, 47.04273093131281, 44.4821802262337, 44.154889814315304, 46.64557526188512, 45.601950230137, 48.519942606649096, 49.73984679868145, 46.00817049703291, 51.62588711707823, 51.201922047522764, 48.13172209647394, 45.445286843084524, 36.278543010834724, 39.75655571106942, 46.95796458951889, 45.39591204735541, 50.797168747071304, 47.66325773731355, 48.68270527931952, 51.54686312521658, 48.980377874066754, 42.01589584350586, 54.1812720606404, 42.496692134488015, 41.5882319788779, 45.77875106565414, 42.92176723480225, 44.360461235046394, 47.256339288526966, 54.61265825456189, 49.67044830322266, 47.819638713713616, 43.77411004035704, 45.51452844373642, 45.866247377087994, 43.17227725059756, 45.46334935772804, 42.97260507460564, 46.18114702163204, 42.17187281577818, 43.548248198724565, 47.01292091800321, 43.25103059891732, 42.92566607075353, 43.17280284820065, 44.257365657437234, 41.96095128213206, 43.504050931622906, 44.1608557393474, 43.17888644433791, 44.119764989422215, 47.63563248418993, 51.409705685031035, 44.66801035788752, 41.7341245374372, 40.95046635596983, 40.77297910567253, 42.26286395903557, 38.46577821239349, 34.04543569011073, 39.040452511079856, 49.9065867547066, 31.698083454562774, 37.51737263894851, 51.946278079863525, 48.5587348476533, 47.69320895594936, 43.3651598038212, 42.5618270135695, 45.305513181994044, 45.246485433270855, 51.3913764492158, 46.650611585186375, 46.96184773598948, 53.565981618819706, 54.44988381478095, 46.32770246075046, 45.41767335707142, 43.686845148763354, 41.636892903235655, 45.86470980798045, 46.46950006484986, 48.61486788718931, 51.38459467118787, 52.01925377691946, 58.208451886330884, 59.61195830375918, 64.58173859503962, 63.393405560524236, 62.92669450083087, 58.80393828115156, 59.31026135721515, 59.12545104180614, 57.36505600713915, 52.64344407666115, 57.520621130543375, 55.44473417343632, 62.01621040221184, 65.29764175415039, 66.17461312201716, 67.31308890927222, 71.57419496966948, 65.01226578989338, 67.46413153986778, 65.74432126937374, 71.76806988254671, 73.62795583663448, 78.29452514648438, 76.66017547730478, 85.10095134858163, 42.53907726657006, 0.9875131362388212, 22.49616772897782, 82.03972970285724, 48.052635346689534, 54.571292938724646, 37.10698289255942, 31.434276603883315, 60.63250018704323, 36.87803414560134, 0.13667011633515358, 0.002555706422783495, 0.04069198966927586, 0.02558378393821899, 0.09636561010753918, 0.02411755676861973, 0.09070909266630489, 0.0761733633736449, 0.03554874347643026, 0.10475317737267864, 0.08329339986366611, 0.016781113846527956, 0.06142068181126829, 0.0963552525988029, 0.09973291893519702, 0.11713348764685855, 0.30782500642441935, 8.735531203208431, 66.16810983227145, 51.042638517195186, 38.50012640799246, 61.72088338482765, 58.569776704234464, 70.82757180736911, 68.01341241405856, 3.0818192372398996, 0.16143036916130976, 5.644732434903422, 62.6595026446927, 85.51614207606163, 76.70460808661677, 78.14360018699401, 67.50717563013878, 67.16745914951449, 61.76606908921273, 60.54084616322672, 60.281397065808704, 70.2181766879174, 68.1523270760813, 78.42240225884223, 97.49755520974436, 68.51722517321187, 59.239988173207934, 60.0438779400241, 64.63361586293867, 68.08946717169978, 63.66823819375808, 68.17437079644972, 67.87618437120992, 67.80587196350098, 67.4198087569206, 65.74684727576472, 63.08411098295643, 57.6066622426433, 52.40579159029069, 51.10847157816733, 50.572624821816724, 47.02769648644232, 46.545354781612275, 51.23141827121858, 46.589944285731164, 52.083631638557684, 50.77335996012534, 48.14213598928144, 54.753141864653564, 57.87970627507856, 50.30161257713072, 49.982531685982984, 43.53055438687725, 42.79614156292331, 49.319054926595385, 46.4004938064083, 53.52668339206327, 49.62715710363081, 50.72805658463509, 52.16448345491963, 52.92348953985399, 45.7933932735074, 54.382713225580034, 45.662950931056855, 43.85577770971483, 47.71684515860773, 47.61931150190292, 45.69025062745618, 54.15954997462612, 56.353182561935924, 52.23583529072424, 50.700254824853715, 48.30906029670469, 47.88543647335422, 48.01381564909413, 44.36723909070415, 45.95523418918733, 44.15452111151911, 44.492868684953265, 45.962106181729226, 47.051583720791726, 49.00284128804361, 44.34474822013609, 46.80123059980331, 44.63627446082331, 46.54562934752434, 43.017061218138664, 45.015485286712654, 45.26403803979197, 44.45148375726516, 45.94627157334359, 50.280239582061775, 52.34455162479032, 45.49860362083682, 44.045290946960456, 44.01232734803231, 42.158564213783514, 44.63116753485895, 43.77355306379257, 41.743738266729544, 36.941478483138546, 52.79203130352882, 32.36597876394949, 31.059211723266113, 56.213640320685606, 48.467724092545055, 51.58284694917741, 44.93510807714155, 45.22818365404683, 46.13091714920537, 47.16293980998378, 49.62820045409664, 47.3605723534861, 50.59552361888271, 56.28956564011113, 57.57833488525883, 49.362573623657234, 47.353594456949544, 47.737327775647564, 43.80966632596908, 49.742008024646395, 51.06004207364975, 51.949259081194484, 54.74410864614672, 55.89182945989794, 61.00956155407814, 64.06311888848582, 64.48299684832173, 63.91122902593305, 66.43954569293608, 62.23959722826558, 63.259962604891875, 60.85405918859667, 60.34248798124252, 57.502919473955714, 59.95747204749816, 59.43326688581898, 66.70887916318833, 69.49740978979295, 68.47815052155526, 69.92289281660511, 74.3111385837678, 68.66808737477949, 70.48870255870204, 68.54785103951731, 74.32270957577613, 75.757277242599, 82.030072827493, 80.93470388843168, 89.7810685250067, 47.93171651901738, 1.1544540524482727, 24.81036416945919, 87.65922315659063, 56.88343209605063, 61.93622935202814, 44.63871809744066, 32.72402251920393, 70.77640056610107, 45.37155412858533, 0.07336515317400617, 0.03319810993308502, 0.03308162626419817, 0.03187989095045674, 0.09630430775183825, 0.040139234249269774, 0.06785961634088909, 0.06825068890447579, 0.09609185624867679, 0.23445279758063056, 0.1025436802076236, 0.1309442679367719, 0.1958101888697955, 0.32364407854695476, 0.2685240830384916, 0.3766603353283098, 0.7566647976636888, 15.381700146582821, 78.91475385235202, 66.48594733207457, 50.599041984927275, 68.39484722383561, 67.41934591724028, 75.56632057312997, 76.96405718403479, 3.058835864067078, 0.2367723432760085, 7.0556781176597845, 66.45279545937815, 90.37813171263664, 80.37203988721295, 79.66177709640996, 68.77315982695549, 69.85757750849571, 64.43160203195387, 62.112900749329604, 62.015935836299775, 73.89553992978989, 70.73979700765302, 80.17458777273856, 86.67518677250033, 70.2808718527517, 62.23093663492511, 63.93781485096101, 67.00278236019996, 72.03038231019052, 65.88482841368645, 68.97265941865983, 68.65470424775155, 70.46021830651068, 68.74438531937139, 67.45540818860455, 66.7288754063268, 60.56649061941332, 55.763230631428385, 53.81159651663996, 54.34428184263168, 51.13204502290296, 49.99385556867046, 53.982039190107784, 48.67569600382159, 55.000043299890336, 53.75757371225665, 50.22250229312528, 59.594872459288574, 60.30537451467207, 55.8752574459199, 50.75645454468266, 47.27970092527328, 47.811935178695194, 52.58437318186606, 50.558021837665194, 56.73819457331012, 52.29810683957992, 53.41504096984864, 55.85179382754911, 56.46918665978217, 50.02312821726645, 57.809221283082046, 47.538738173823205, 46.2681334249435, 51.23371285776938, 51.886520770288286, 50.60588259850779, 56.0459158497472, 58.6324248006267, 56.3320331419668, 53.43440571138936, 51.06126585314351, 51.65670517952212, 50.48935682542863, 46.86464748074932, 51.76341326005998, 48.578083899713334, 49.848555288007184, 47.73746898097377, 53.47663787103469, 51.38331205614152, 48.02464923551006, 48.45689050612911, 47.070799412265906, 50.073573820052616, 46.64297473046088, 47.66082979017689, 47.04911654995334, 47.350507551623934, 50.571605005571925, 52.26439406794887, 57.29211168904459, 51.42656010966147, 48.84667604200302, 47.16187684766708, 45.95373192141133, 48.47081884261101, 48.3488017512906, 49.080692491223736, 50.154249129756806, 55.262167453765876, 44.90727886076897, 39.416023377449285, 60.624824108616004, 54.20765000004923, 52.01180911833241, 48.31774834663638, 50.481288509984175, 48.904401563829, 50.93580492081181, 56.46315405445715, 54.24791705223822, 54.22841895011164, 59.27341461181641, 60.01409930567588, 50.84533153041717, 50.70318483537244, 53.04156464915122, 46.84587893947479, 51.82757146896855, 50.936048107762495, 53.91487644564722, 56.80028569313788, 57.90035363166564, 62.75332966158467, 67.2211956208752, 68.0126436295048, 65.66616019895001, 67.05880949574133, 66.13916274039977, 64.37790478429487, 65.0232994171881, 64.10706512389645, 61.11959580452212, 64.42574201091644, 63.49822698100921, 68.74043157023769, 72.3559311897524, 71.75095265911472, 73.8536725505706, 76.95709889934909, 72.09014354213592, 72.10595069393035, 72.58921023338073, 77.78799810717183, 80.65464665812831, 83.84463971660983, 84.67593900619015, 92.22636038257231, 56.172620173423525, 0.7335958677914836, 25.680392942120953, 96.8444727313134, 60.679392122453265, 73.40268627289804, 49.603595426005704, 47.463679698205766, 83.19751139610045, 53.63170485342703, 0.3328015565151169, 0.1740087208247954, 0.11463100781604169, 0.235004932469418, 0.15303804449016048, 0.15330887189315212, 0.28005487075255764, 0.17389241335613115], [0.06756382213244516, 0.056995179564241445, 0.05553148431523193, 0.061004734372780214, 0.02967713727435518, 0.08805557094033688, 0.009429340547461425, 0.09041988681400977, 0.24402609275233364, 3.3828552644098964, 55.80845555951519, 43.5589680364055, 35.00904437034361, 39.910646023288855, 50.38027963330669, 58.20819300989951, 73.14431974964758, 6.0885368527904635, 0.4725349213807814, 4.972802967794481, 63.67663991066718, 80.9464474647276, 69.90563438784692, 70.95267972638531, 61.83924874951763, 64.37571217936855, 58.56779982966762, 58.21952865969751, 58.82802555637976, 68.80229519259545, 63.43084066144882, 88.41112582914292, 88.0007831511959, 59.06912580613167, 68.87401965356642, 64.72604259367913, 65.30313307239165, 60.03664116705618, 65.70477985566663, 64.53009666935091, 66.83477940097933, 65.89930195962229, 66.10525777263027, 61.27907153098815, 59.086772549536924, 52.6568821168715, 48.653546379458525, 47.50560199060748, 48.91408197341427, 48.66002613498319, 43.439429883034, 47.54238597808346, 43.10657755021126, 44.69471385402065, 46.94283993013444, 46.07609025893673, 49.85365829160137, 51.585278818684245, 50.36220535155266, 46.07390942112092, 43.1664054624496, 34.98592592054798, 40.50272780079996, 41.834894149534165, 48.89450150151407, 49.03436929948869, 53.73625170799994, 52.06839715280841, 44.17937717130108, 47.4178546474826, 42.37737363384616, 41.47495392830142, 43.089781961133404, 42.81609073761971, 44.39785318989908, 43.42599184282365, 48.32274936860608, 54.2302663864628, 51.69590926939442, 46.73860211526194, 46.31773571814261, 47.11363953928794, 46.7931701290992, 44.3021708919156, 42.4691374840275, 43.82151188388948, 44.21575715464931, 42.07934018104307, 44.09182202431464, 50.37167395314863, 41.10863593316848, 46.23815082734632, 45.23235705591018, 44.59432863420056, 44.6069468990449, 44.0856639031441, 44.57838027707992, 43.569997741330056, 44.466875137821326, 46.86188220977784, 51.321064041506865, 47.96854757493543, 39.68429388538484, 43.900135793993556, 41.51941007183444, 40.60019869958201, 36.83380942190848, 34.74353913337954, 28.95404427282272, 43.79973488469278, 32.172780459926976, 31.59818264745897, 50.18954261656731, 45.414280506872366, 49.310300196370775, 41.42212352445049, 43.960575595978774, 39.32625601368566, 45.70813271307176, 44.560494269094164, 43.73607089442592, 47.29932454324538, 50.66222352366294, 48.10354378915603, 47.58109977168422, 42.73560762405396, 44.25623993719778, 43.995229736451186, 48.361345491101666, 48.085367525777514, 47.826624454990515, 52.99752427685646, 58.835430991265085, 58.48941910651423, 61.46753749539776, 62.09686610006518, 65.79930505444928, 68.7785570083126, 65.9570784722605, 64.881599872343, 63.0491901213123, 60.12873841870216, 59.327170695028, 56.468708130621145, 56.755527527101584, 55.56402521748697, 60.16638532761605, 62.673948734037346, 61.25277988372311, 63.422748811783336, 63.25647954017886, 62.80269269020327, 65.11540059120425, 68.97159253397297, 73.02080431292134, 73.73378922862392, 79.35065469434186, 87.22417739129837, 35.826878163122366, 1.3269844074403088, 26.976281289131414, 77.55442096341041, 55.53167350830571, 43.21351312821911, 41.90604202208981, 37.25505236656436, 55.67492238936886, 38.88723688740885, 0.134426842353517, 0.02737801356781875, 0.056192154710691784, 0.030597092043007576, 0.02418284661196653, 0.061802963515923875, 0.15067555190574738, 0.0021448582570414033, 0.012648748440457689, 0.033233966678380966, 0.026666384918855566, 0.04470838564297846, 0.09273295140554828, 0.028578446532088905, 0.07133027809041162, 0.1624999198341562, 0.16715497649725408, 4.794151263852274, 69.64272575993692, 47.49359953788019, 42.37396509416642, 52.4397240146514, 55.57348205197243, 66.35018625567037, 79.5366221089517, 7.8228927427722565, 0.5941443313514033, 5.785751448523614, 67.63328767591908, 86.64321945559594, 76.28908003530195, 74.24541534916048, 66.80984097142374, 68.11967726676696, 59.36256224109281, 60.70047878449964, 63.168842023418804, 70.93429165501749, 67.62015558058216, 86.25840356273036, 96.1085968632852, 59.65856782851681, 70.3223156159924, 66.84867243612966, 66.8710534803329, 63.72380641198928, 68.78970438434233, 69.05194620932303, 69.38708136158606, 66.9656296699278, 67.50668141149706, 64.32680022331976, 59.57612745223507, 55.64332769763086, 53.2617155198128, 51.67779184156849, 51.52506259179885, 50.75301854841171, 47.93412485430318, 47.67569949550014, 47.13558520040205, 47.82490253448487, 48.22766719325897, 49.41801240367275, 53.912048416752974, 54.647720321532226, 52.4370881818956, 48.4109870080025, 49.124960360988496, 41.545023149059666, 46.16219805132958, 42.959488668749415, 51.621827463949884, 51.90391255963234, 55.7395669721788, 53.87835525697278, 48.36339296833162, 48.64155569384175, 46.326298252228774, 43.46244635120515, 45.21747558347641, 45.65015615955476, 46.486323110518924, 45.94724039877615, 52.09303355986073, 54.23733449751332, 54.302179121202045, 51.067675006005075, 50.24095312241585, 48.834916776226414, 47.83356312782534, 46.53587833527596, 46.739841584236395, 46.74918074761668, 47.70656070401592, 44.38692546659901, 46.16040552816084, 52.74200147198093, 45.82951045805409, 45.20388457082933, 45.472778735622285, 48.738697113529334, 45.65677712040563, 45.91072705484206, 46.57466665390999, 47.490618536549235, 46.6369068238043, 50.57049889718333, 54.994587282980646, 50.937746494047104, 43.97641020436441, 45.68925826780258, 44.51227657256588, 42.967266728801114, 39.79241009681456, 39.97986408971971, 36.688246342443655, 45.451064494348344, 36.4224979185289, 37.09067759975311, 51.72136937418292, 48.30505555675876, 51.66904103371405, 45.02053337712442, 47.46746086305188, 41.499578568243216, 50.5682788356658, 45.85216999053956, 49.00391209510065, 51.28375445642779, 51.48845118861045, 52.599411549106726, 49.43013644987538, 48.06670096612746, 48.20286604665941, 45.98352624524025, 49.83387777882238, 50.38875195287889, 52.32076637206539, 56.25499386941233, 60.29408593331615, 62.82963152854674, 65.12980745684716, 64.22098252081102, 67.84586444977792, 69.02518780000749, 68.20607923692273, 66.47621200930688, 67.30132179875528, 66.38689964048325, 62.92672980216242, 59.77806283581642, 58.75694436411704, 58.489187686674065, 62.58849989983344, 65.50272680098011, 65.37999976065852, 68.68061542510986, 66.77887778128347, 65.80360004978796, 68.60907139316683, 73.24256727772375, 75.07782074712938, 77.39416860765027, 80.1541914478425, 89.33513426011609, 36.871609303259085, 1.3193770930651696, 27.759351115072928, 86.2053966522217, 58.581590883193485, 47.28610615576468, 51.26300119584607, 39.11420091505974, 64.32856136752714, 44.573720501315215, 0.062465223543826616, 0.019911454442227562, 0.029828106391153512, 0.018020347248943105, 0.030048098114709702, 0.062641829793011, 0.06356681201366648, 0.05859276783021708, 0.17117143758843023, 0.11134127305159647, 0.12100074545390184, 0.15923486842263132, 0.2592130810503037, 0.23734502464292512, 0.26747840366536574, 0.39546331991591765, 0.4451364915697806, 9.195950781145404, 85.12294800050798, 55.10642974607406, 48.35834487791985, 54.44135658202633, 66.64603494828748, 68.71899973961615, 89.35939804200204, 8.485043741041615, 0.8876956795011798, 7.486641676195207, 71.53679909244661, 90.06860963759884, 78.73265389473208, 76.4905486568328, 69.62856600361486, 71.64374643756499, 65.05964802157494, 62.975818264868956, 66.05410222084292, 70.98841251865511, 70.65401477198448, 80.41261288427538, 91.47367323598554, 64.18094296609202, 70.76362932882002, 68.89342754117905, 68.705247909792, 64.624472818067, 70.4846860516456, 69.06918894860053, 69.81032079265964, 70.63274768091017, 71.84550531448858, 65.68370888310095, 63.50845652241861, 58.05577754974366, 55.36651818983017, 53.73841293396489, 55.58508442294214, 54.43579073875181, 50.194775058377175, 52.17546609140212, 49.020076182580766, 50.2057812290807, 52.21483884319183, 50.39240760187949, 55.51350508966754, 56.622421895304036, 55.17031731144075, 52.48723568454866, 49.14960853515133, 44.433715420384566, 51.46553670206378, 46.55839666243523, 56.59525948186075, 54.11085374893681, 60.796576853721376, 59.859263743123705, 49.33874522486041, 52.76428837930003, 49.92441784950995, 44.22108765571348, 48.24488247594526, 49.76520884421564, 49.50466540551955, 49.77117084687757, 54.85329566463348, 60.765668576763524, 58.924053022938395, 54.04462845094743, 52.0291381497537, 50.83116000698459, 51.62076842400336, 49.635201884854226, 48.633385396772816, 50.085827304470925, 49.92386479531565, 47.12128816112396, 46.92940188992409, 56.311981985645915, 48.15650755359281, 47.7678987287706, 49.9894860482985, 51.63770129603725, 50.6840907373736, 48.342596561678, 48.2532645810035, 48.92100495676841, 49.38517039821994, 53.40130090713502, 58.05884092084823, 55.36758507451704, 48.96392353119389, 46.714577597956506, 47.557702833606356, 43.9864004811933, 42.61961137094806, 44.49349234181066, 42.65042943339194, 52.12712287902833, 35.174140853266564, 36.30574857034991, 55.687124882974935, 50.84466864985805, 55.03929445820471, 48.37132400082004, 50.612554550170906, 43.71248960494996, 51.501324407515995, 49.96861511661161, 55.068304307999156, 54.930856612420854, 57.27819119730304, 53.65859270095826, 52.1583527903403, 49.320819993172925, 49.879389039931766, 48.74043864588584, 52.16835483427971, 52.46845537616361, 54.525244312901656, 57.57074117660523, 63.58879058591781, 66.86724878126576, 67.00469647684406, 66.19733149005522, 71.76679118987053, 72.52705635563021, 70.77785184306484, 70.13757198087632, 71.05995655059814, 67.12607814419654, 65.43502276943576, 61.62860962652392, 63.43437863934425, 61.891098560825476, 66.71692002204158, 67.25290406134822, 70.32080942584624, 71.54930360855596, 71.64584882797735, 69.6568541372976, 71.58459709536645, 75.20030852287047, 79.0002929010699, 78.05142448794457, 86.91249016792544, 90.35324819626348, 53.24670853153352, 0.9601147064278204, 30.34945099584518, 97.38090392081969, 65.00298938443585, 59.43214116557952, 57.161794862439564, 54.590889100105535, 73.26070431740054, 57.77207251518004, 0.3938591930895083, 0.18859371723186588, 0.18247112721925784, 0.19265831928820382, 0.16960638124615918, 0.17783885401102806, 0.2022289178304134, 0.1987203730330352], [0.0397564354352653, 0.030146117149401578, 0.014149595123355188, 0.05171514454207594, 0.043546253244482705, 0.024487441255440636, 0.08523977647024779, 0.07642814889550209, 0.2766779858258463, 3.567231422470462, 61.001763882175574, 47.2259016959898, 41.55719818607454, 36.701707916875044, 55.84247035364951, 52.162467356651064, 79.97263277730634, 12.54128146556116, 0.3394407502585842, 4.461554865683279, 69.5999405460973, 81.78144947175058, 71.06995074979721, 71.96363141459804, 63.321257483574655, 61.65117894449542, 57.46974406703826, 61.44702349939654, 68.39742029866865, 72.21164288059359, 66.09087051883822, 84.53554168824228, 59.255336407692205, 64.94197691640547, 64.22418317487164, 64.59159158891248, 63.747489683089725, 62.73001509328043, 65.59583602413055, 64.81165616743027, 62.63438378610919, 60.193775238529334, 61.19850604764877, 59.52772540430869, 54.574148424210094, 54.84824757422171, 50.32548019962926, 47.253095488394464, 47.15507153541812, 46.92074521895378, 44.70410400821317, 44.30117068752166, 41.30686467693698, 42.3115131162828, 46.18776406011274, 45.73050591253465, 46.04106349329795, 46.54370738613991, 49.19671227855068, 46.50388356178038, 44.558529161637836, 42.021587202625895, 43.198745404520345, 43.41104369009695, 48.095153839357444, 51.40963115999776, 45.99796056747437, 43.83392226311469, 43.85653472715809, 39.27642230064639, 44.737208812467514, 43.78342959188646, 42.05661396826468, 43.72407628643898, 43.79680095180389, 42.0748176882344, 48.612596834859545, 49.024983067666334, 51.405944132035785, 47.02513910108998, 48.840851322297134, 45.24427713886384, 44.99988994290752, 42.340993650497936, 43.874075566568685, 43.47059703642323, 46.137196863851244, 43.621035622012236, 48.2970303873862, 50.97961387326641, 43.84007253954488, 46.35657894995905, 42.935491608035186, 43.72839089362852, 41.343617285451586, 45.06867654861943, 45.10401318150182, 45.73557753716746, 43.860272745932306, 48.1477959694401, 50.017719268798835, 47.68808634050431, 44.265045658234634, 40.725785147759225, 42.24148704159645, 40.686122140576764, 41.77075163010628, 35.47916789208689, 34.84782318915091, 36.35132258938205, 48.835269789541925, 52.69082238597255, 44.68585714217156, 46.90695024305775, 46.061071503546934, 42.96714513532577, 41.956589606500444, 44.540866728751894, 46.01323819929554, 42.05433507119456, 45.10855136379119, 48.55838967907814, 46.57836152661232, 45.80277166058941, 42.30872038872012, 45.477807214183194, 41.150060084558305, 42.698631440439534, 47.13109016418458, 48.4947923691042, 47.519663687675234, 56.07020316585418, 59.2174227776066, 61.308281421661384, 60.00531711886006, 61.92912201727591, 61.07982689334501, 58.67180931952692, 60.34361370148198, 64.18749332427979, 63.36722373962403, 65.40689937530026, 62.96159575062414, 66.98773614821896, 61.26077759650446, 57.82269462462395, 53.84211255658058, 57.209663468022505, 58.23393552534042, 60.418942820641306, 60.14934262921734, 61.176085779743815, 62.78239050219136, 71.46490204718806, 72.60054588317871, 77.69441819960072, 76.64052440274146, 87.89721688916607, 17.950336817772158, 1.7867805736680187, 30.144699350480114, 75.03691042623213, 57.48244470165622, 46.95699184171615, 40.91168588207614, 34.6548504214133, 60.25902778871598, 39.186094037948116, 0.09855310522740889, 0.0027419088808293907, 0.03433793768166535, 0.017930153802397753, 0.02238169920841052, 0.020796364518783746, 0.009475481065530932, 0.052649040195730426, 0.04373929974052214, 0.03876101526041185, 0.017478251942403374, 0.04958894794746753, 0.04352063143385514, 0.05728223270946934, 0.13083186751652148, 0.15961081841059271, 0.31678618202286385, 5.799458661387044, 75.58591673451086, 45.01230032213273, 50.62324300889046, 47.75049124994586, 57.086842290816776, 57.04053871093258, 88.7002908029864, 14.375025803042998, 0.3060524321852192, 5.352940943933302, 75.19489565203267, 86.99839007469916, 75.92296600341797, 76.20823998605051, 66.12536384213355, 63.56292647700157, 59.03568367804251, 66.75155455066313, 72.79610741523005, 75.35504602616834, 67.75426141677364, 89.38106521483391, 69.4277249613116, 66.08943493135514, 69.85895033805602, 66.26982473557996, 68.72723671697801, 65.71745303369337, 70.37678949294552, 67.42355854280534, 67.4866694788779, 63.7671446800232, 64.66873676546159, 59.90676364591045, 58.967104957949736, 57.35133163390621, 53.617129325866706, 50.628463683589814, 50.45569112223964, 50.38439027724728, 48.64932983152328, 46.26312455823345, 45.73040785328035, 44.18794362775741, 47.61659722174368, 47.84564402795608, 48.69938319729221, 50.71513237491731, 50.96930196208339, 50.61285657267417, 47.652659493107954, 46.945864077537294, 48.50347257429554, 46.82451771151635, 52.10255315226894, 53.426945363321614, 49.93947975097164, 47.94628420183736, 45.54739006104008, 42.80850879607662, 44.92003833093951, 44.560690387602776, 44.259197404307706, 44.883324946126635, 44.27023887634278, 45.785944692550174, 52.25746716222456, 50.76154185879616, 57.12760748401765, 51.50735701284101, 49.067713368323545, 47.97920465469361, 47.55273319059803, 44.927737943587765, 46.31408006914201, 46.44765638536023, 50.2177248462554, 45.956956109692975, 50.395674936233036, 51.00886691001154, 45.585146796318796, 46.43950177777199, 46.30799255063457, 44.918606665826616, 44.98265897074054, 47.80882473914854, 47.085292570052616, 48.917047285264545, 48.31370438298872, 50.979692320669855, 53.240903423678496, 52.787822600333925, 46.351899562343476, 42.60646358613045, 43.96421555549868, 44.20781435505037, 42.79154454508136, 40.69102902566233, 41.585564767160726, 39.0345807229319, 47.167466225162634, 53.56153365104429, 47.80684001984135, 50.38938737684681, 49.351861630716634, 45.246752154442575, 43.94177567574286, 47.58361401096467, 47.748251576577466, 47.78966396085678, 50.87786366862636, 48.73207223030829, 49.78614253382529, 46.82350181764173, 45.98752314044584, 45.935308548711966, 45.26610512887278, 46.825325719771854, 49.686424116934504, 49.89872240251111, 51.44401073455811, 55.97085345175959, 61.2836685488301, 64.37284884914276, 61.312023362805775, 66.373304705466, 64.23470297167378, 64.47925882954752, 64.89365331588253, 69.6598429833689, 65.8411410547072, 68.89373348605248, 66.2491460000315, 70.4806616998488, 65.47722355011972, 62.01999156705795, 57.01368616473291, 59.21776010144142, 61.48929488274359, 62.614081598097286, 63.57817665223153, 65.30335664749146, 65.39995678009527, 74.83135469498174, 77.05241249453637, 82.28676842105004, 78.26107517365487, 89.14871185056626, 19.512285417126073, 1.7653948308960086, 34.09468496999433, 84.53364326107888, 60.83429828766854, 51.05018123503655, 50.91294926981772, 38.62751322407877, 67.81302636669528, 49.834501435679776, 0.01123814883026024, 0.037247861375010786, 0.06371144941377063, 0.04683404980647949, 0.037290501828876235, 0.061737091445754615, 0.0682805969770397, 0.005571499876227351, 0.18326379839451085, 0.2721976891400353, 0.1276212926172922, 0.18114265414976305, 0.12479219886083757, 0.13477136741482443, 0.32153414982941847, 0.24774382551831586, 0.4765979759395123, 7.893391463064379, 88.0543391935287, 58.17269555984005, 58.305824725858635, 51.82065240798458, 72.50304360543528, 63.767458469636985, 97.52976571359943, 16.185957635602644, 0.4385157758670469, 6.217838275817133, 79.37240031457718, 88.84712080801688, 76.31292804594963, 77.71015474873205, 69.76111858121811, 69.43571090698242, 64.0310299781061, 70.09208817635813, 76.5354754847865, 77.72158453541418, 72.17167392853769, 83.09028164032968, 70.50010881116314, 67.86492716881537, 71.73576524180751, 69.84877570982903, 69.13208023194345, 68.96505786526588, 72.63318000301238, 69.64547141905754, 68.08534868301885, 65.94617428318148, 67.75306117150092, 64.05817277969854, 61.737373029032064, 60.54501564271989, 56.07727912164504, 50.62527479663972, 52.57228835936516, 52.51115429785944, 52.64962965442289, 48.33228465049498, 47.848978042602546, 47.172031864043205, 51.30747302885979, 50.18496128820604, 51.45815480139948, 52.90952590204055, 56.02644128184165, 53.18031457162673, 51.43178862910117, 49.83874151783605, 51.46501110446069, 51.19060208720546, 56.49936145351779, 58.34072989802207, 51.50531345798124, 49.70200769362911, 49.53783296769666, 46.731404565995746, 48.74144669502012, 48.86067105877785, 45.57909065677274, 47.996204207020426, 46.09902043496409, 46.965558298172496, 57.55263551588982, 56.248690620545425, 58.25288449564288, 56.214817031737304, 52.46316017643098, 49.97879758957894, 52.03450395214943, 49.19312723221318, 50.143537136816214, 51.74011830360659, 54.07294011885121, 49.179316566836455, 52.835279357048776, 55.558902602041925, 47.92764117640834, 50.58061468985773, 51.47273817370015, 49.59935142147926, 48.03505920594739, 52.474240872167776, 48.78642451378607, 51.18380069732667, 50.49586011517433, 53.214819662032596, 55.14601430585308, 56.034560588098344, 50.04985916999079, 44.77393004202074, 46.90641680071431, 45.262704433933386, 48.298948426400464, 41.58081477688205, 43.67266185822026, 45.65254096061953, 57.19496634698684, 58.05688758050242, 49.9719177522967, 53.65397607126544, 52.41251845513621, 48.284486647575136, 47.78259584980626, 50.90756777794131, 54.184123623755674, 52.85776630524666, 53.47968555265858, 53.14949258681267, 51.537288619625954, 48.70452542458811, 47.687297944099676, 50.38586508843207, 46.32355259310815, 48.25512378446518, 52.6078877910491, 52.95682968631868, 53.64892798085367, 59.22527928506175, 64.16464944039622, 65.05236418016496, 65.674832559401, 69.12283128307712, 64.97208502984816, 66.60236327878891, 66.9808013977543, 72.45513577615061, 68.64728312338553, 71.50581236808532, 67.90735936933949, 74.61032129103138, 67.43159940165859, 64.83173085797218, 58.527305280008626, 62.291643158082046, 64.41275112090572, 65.81530832475232, 66.2752454511581, 67.59046323837774, 69.35120736399006, 78.3732706500638, 78.48445415496826, 85.64587839188115, 81.81306377533944, 95.56085355820196, 29.69143613692253, 2.0439722244777987, 37.10156609935146, 91.52887667379072, 72.70952501604634, 64.44144325871622, 57.43804739367578, 50.84818701590262, 80.04193321351083, 57.05169393170265, 0.2586481065279053, 0.18072607085829784, 0.19775666506780734, 0.08162232461355387, 0.1990982535625658, 0.10542982453179937, 0.11518142666787871, 0.16146822922652768], [0.0008527666432200932, 0.01462851211638941, 0.016656164906077808, 0.07426484683228117, 0.04764531010521516, 0.05655213942631118, 0.08577957734345429, 0.05233635374855611, 0.291143503160246, 3.2270288130929394, 59.2335750979762, 46.683092732583326, 35.356130984521684, 34.37511482546407, 57.69916349841703, 52.166330891270796, 79.95957128463253, 21.044698569082446, 0.4744023679485245, 3.8886836315355, 72.26606968910464, 83.03779248268374, 74.97765910240912, 70.28321743011475, 65.73204032836422, 62.97364919416366, 59.104434982422866, 63.14038130544848, 68.09174214639972, 68.41733024966332, 70.88344989284393, 72.60460945867723, 51.56191325956776, 68.55555457453575, 65.49900839405676, 66.14397941097137, 64.49589360144832, 66.13900584559288, 65.05618064634263, 66.3713356756395, 60.64170991220782, 60.275085972201445, 57.54962313559748, 60.468039128088186, 61.835142027947214, 55.36273310261389, 52.72405270607241, 48.1446502285619, 46.78911047597086, 44.607358747913, 43.23914189492503, 42.912192729211625, 42.42494021692584, 42.38417110135479, 47.728129817593484, 43.28960318719187, 44.24372757634809, 46.225144247854914, 45.4877111988683, 46.75580170846755, 47.525813964105424, 44.03491627785468, 47.105284890820904, 46.85839914506482, 43.58294548526887, 45.891954591197354, 44.464117711590184, 43.81020761305287, 40.33741166514736, 40.616056842188684, 42.270700854639855, 43.03013840029317, 45.49838789047734, 46.082872036964666, 45.242759181607155, 43.7514465855014, 47.15877425286078, 47.30924421741117, 53.51794435131935, 47.75307216951924, 48.93352516235844, 45.08115360813756, 42.97833957979756, 41.63643398592549, 42.276729537594704, 42.37432987459245, 42.89924498527281, 45.69764821760116, 46.56452340464438, 49.55845286769252, 42.07723779063071, 45.52278111057897, 41.736517183242306, 41.53999859286893, 39.901573581080285, 43.46121864934122, 41.26062385497555, 47.816104658188365, 46.58100128173829, 50.30889249617054, 48.2756220909857, 48.43141471185992, 42.826849799002375, 42.46419921998055, 41.60236427860875, 42.59809324818273, 39.79446934115502, 39.4837744774357, 38.16177098981796, 39.02770480801983, 40.25066060404624, 47.34700487506005, 45.543589284343106, 46.61560443139846, 43.985517947904526, 42.94544658353252, 41.406818436038115, 38.848605463581706, 41.33174034856981, 44.37685674236667, 46.82940106238089, 47.96113821767992, 45.568853270622995, 43.54571042522308, 43.89581726443383, 44.3741463845776, 44.95841087833528, 44.51054680731989, 48.09754648516255, 47.359685897827156, 47.715946935838275, 51.3690463958248, 60.15442209859049, 62.355471887896144, 60.6998315934212, 64.27937876793646, 62.53907411329208, 64.56416637666764, 60.8693289756775, 61.757981161917414, 63.1323718255566, 65.20448546255788, 66.83051970697218, 66.72537665213308, 66.26941680908203, 66.16294014838435, 64.92869184863183, 60.31477643597511, 55.8695347078385, 57.437168782757176, 58.00964263177688, 61.18697035697199, 64.79639814745995, 71.85018862447431, 75.26027371806484, 78.57663769875803, 77.79516819984683, 78.18363974171301, 13.340109413669957, 1.0367515683174133, 34.49240153835666, 75.6526990090647, 48.89952998007498, 40.442958724114206, 34.37538939137613, 38.17715452563378, 65.80511800704464, 45.380481443097516, 0.04411027781785496, 0.07807806479714571, 0.055348270557700634, 0.04599885309054967, 0.066347565622099, 0.0521568593478972, 0.03861741207900547, 0.05994074549826403, 0.064737708458016, 0.017495396990148772, 0.03343429100970107, 0.023703666276208336, 0.036224992269830364, 0.035687321121053356, 0.0787917523074054, 0.07079357987329846, 0.15282611392678755, 2.9470024714546823, 68.12793777834985, 48.57489501276324, 42.925956326146284, 46.31142462453535, 60.736442996609604, 57.64207732292914, 89.37021593893729, 23.512024341091035, 0.6307767559924434, 3.9661254373288926, 79.03556285365936, 84.63771158649077, 80.42165786989274, 74.12984663440336, 70.04272907010971, 65.5300735658215, 63.61464685009372, 66.57847604443951, 73.20576760076708, 69.36119371844877, 73.8573831127536, 84.83559516168411, 57.56839559924219, 71.81233775231146, 67.96959169449346, 69.22743305083245, 68.47329462728193, 66.17076919924828, 67.5131925459831, 68.71588537769934, 63.36624706945112, 62.269093451961396, 62.2872148021575, 62.6163173490955, 63.84690999984742, 57.603771455826305, 55.73692329468266, 50.75847456532141, 51.39448688876245, 48.91878881762105, 44.83515824041059, 47.26627857454362, 44.878904434942434, 44.66768872353339, 48.90379359645229, 46.28746286515267, 46.17807188341695, 48.49770669014224, 49.11214597763554, 48.747236113394464, 49.32431482499646, 46.39896800441127, 49.38015760913972, 49.14708252876036, 46.55607461929322, 49.416251259465376, 47.770165858730195, 45.391801403414824, 43.616583731866655, 43.13061775699739, 45.31022394857099, 44.57332041955764, 46.55838881769488, 48.489387343006754, 47.56357069938414, 48.90427212561331, 48.40990443383494, 50.60040696974724, 55.31272288291685, 49.63095395795761, 49.58903951029624, 47.560966245589725, 46.94706040043985, 44.43372718749508, 45.5081977382783, 45.33083208145634, 46.19058032189646, 48.29517118392452, 47.506147200061434, 52.2282886505127, 44.822783162516934, 47.23223240144792, 46.98935531800794, 43.51072680565619, 43.49255446464785, 46.43780731385755, 45.79358154727567, 49.09915508762483, 47.90943353406845, 53.16189512129753, 52.752666396479455, 51.21107685950495, 46.17496536624047, 42.54445483607631, 42.948400128272276, 45.33969663804578, 41.42457892817836, 43.16707226537889, 41.08358767724807, 38.313943263023134, 42.39252967219199, 49.06887046752438, 48.61048659970684, 49.24392192594467, 47.87847818866853, 47.03174437246015, 43.76824217457926, 41.982618454963934, 44.74107234708725, 48.898184607105875, 50.16939732336229, 50.69277878730528, 46.648579797437115, 45.70735608377765, 47.33428070622106, 48.28169392001245, 48.08233161126414, 46.250192503775324, 49.4527175349574, 49.94515934298116, 50.83652580938032, 55.957219293040616, 63.02906836232832, 64.53420339092132, 63.06358129747453, 67.18478033619543, 65.50555482987436, 65.70572514687815, 65.92268713058965, 65.48087919912031, 67.10384615005987, 68.7342812938075, 69.72333046697801, 69.98902397771036, 70.56500834803428, 70.4710126692249, 69.14848358400407, 63.38013618223129, 60.55863411195817, 62.86584284997756, 62.898210248639515, 64.14712036809614, 68.38278201318556, 74.6490272398918, 78.51235005163377, 82.8356727477043, 78.71133189047538, 84.13071386275753, 17.16473117951424, 0.8464812523415013, 38.72494882152927, 82.7758958262782, 55.7991595422068, 41.6198698166878, 43.15672897523449, 40.34566825436008, 71.00109746379238, 49.6687420721977, 0.024254395393654708, 0.019245203096239318, 0.034665152986323645, 0.10586708453634094, 0.06033667505929067, 0.04852941770467067, 0.07398401432099842, 0.03984498753843289, 0.12943222487886108, 0.12196656782180072, 0.10870253682256707, 0.13562255238573398, 0.16234429673321787, 0.16529512952171987, 0.32940132122847343, 0.19136744581403273, 0.4835587427500756, 5.501863533450711, 85.07136883274202, 57.59652291574786, 49.169871499461514, 45.6126465335969, 78.59863435068439, 62.99265307764854, 97.49928889736053, 25.37745064304721, 0.8354982481368127, 5.342368195133825, 82.8754142022902, 84.9339525161251, 80.17872195090018, 74.35345311318675, 73.83009126109462, 68.9643753728559, 66.9314266020252, 68.9732869978874, 74.81070733839466, 73.18467309398036, 73.69823686538204, 73.20404175789126, 63.69663615380565, 74.18053934651037, 71.57529323331772, 70.57871310941636, 70.97412724648753, 69.80999915830552, 71.09734458308067, 71.09795647282755, 67.89086972513508, 66.47878508413991, 64.61028560515373, 65.8335316565729, 66.6891182622602, 58.19591206888999, 57.40025535706551, 52.92146951921525, 52.65265380182574, 50.588898735661665, 48.07462415387554, 49.91001882860738, 47.75669643955846, 47.082515531970614, 53.278040424469985, 47.39020586013795, 49.185717874957675, 52.71844763909617, 53.17568225245322, 52.12010183641988, 54.598663237787065, 50.14161517543178, 52.871149432274606, 53.13599178867956, 49.05971173317202, 52.663004936710486, 51.737388333966656, 48.98562600535732, 47.77197407137963, 46.09987551166166, 48.0454574092742, 46.53077925405195, 49.050137227581395, 51.20729569465884, 50.30762949297505, 50.042288995558216, 52.70027137571766, 54.00870346253919, 60.21701920417048, 52.96762797140306, 54.022808305678836, 50.9465600598243, 50.1905075196297, 48.1388411983367, 49.22288233234037, 48.17146355105985, 48.852167360244266, 51.88649723606726, 52.14763687502954, 55.04044763503536, 47.17570712489467, 52.13646204240861, 49.93491803446124, 47.72744340281333, 45.98509519330917, 48.269887585793775, 47.881035574020885, 53.92638860210296, 51.413451548545595, 55.19247478054416, 55.23928434618058, 57.28611830742129, 49.61873577487085, 46.00219672726047, 43.65071227473598, 48.540927287070986, 46.5236170061173, 45.68286872679188, 44.629594664419855, 42.87116081483903, 47.60610095916256, 55.039212088431086, 50.118198625503055, 52.229873288062315, 50.90006036143149, 50.28830397513605, 47.51301919260333, 45.34274431966966, 49.70842469123102, 51.26338558812296, 51.40319455054499, 53.6961611624687, 51.784739186686856, 48.34450283358174, 49.425700249210486, 50.82162080272552, 50.70423995294879, 50.196700942131784, 52.506671028752486, 52.808160089677386, 52.96759267007151, 57.857274240063084, 65.2808932335146, 68.80094589725618, 65.98562548237463, 70.30226445967152, 66.24813402852705, 69.35545921325684, 68.61587278304562, 66.13392245384955, 68.62039135348412, 69.83470224565076, 72.28137477751702, 70.82623035677018, 72.92356091160929, 73.10803782555365, 71.78616769852178, 65.72851019520914, 63.680526979507945, 65.34692633536555, 65.5321406549023, 67.36043976199242, 71.51178221548759, 78.08473325544789, 80.54026249916323, 86.378035852986, 83.39583427675309, 86.56457593364101, 21.28451228141785, 1.238507626037444, 42.109836609132834, 90.9546652147847, 63.396563068512954, 55.6356280849826, 50.60692594897363, 51.49400918714462, 85.52433198498142, 56.86022343174104, 0.16696558424061345, 0.14521247166539394, 0.1505944385163246, 0.22757452311775378, 0.149699617177248, 0.20653413278200936, 0.16047989919541344, 0.1526145970508937], [0.029815257181443518, 0.02545996880789678, 0.06016530119062913, 0.02262231401888834, 0.05567842763998816, 0.029363169545127504, 0.045305489892921144, 0.023448643267094612, 0.027404326772797975, 0.9142615862431065, 48.6807676284544, 58.9091754728748, 48.45170513276131, 32.62917568606715, 52.653791289175714, 43.43372283443328, 79.44057895291236, 31.66418044797836, 0.34094121006707995, 1.6431579642718839, 66.38307140719506, 81.17811049184492, 76.86361312866211, 73.7886239636329, 65.02817492331228, 60.01480925467707, 61.9389985453698, 66.10398692469444, 68.78733527275824, 63.16815560863864, 79.0070629119873, 57.07018006232477, 50.224902783670736, 71.34699559980824, 58.01091740208288, 63.71334152836954, 60.984164207212395, 65.79333912941718, 63.3189275956923, 65.30552964056692, 59.36973233376781, 59.75820387563398, 59.85422741982245, 66.58183359330701, 62.05657943602532, 60.79758098048549, 56.69456997225362, 49.40248766253072, 47.46050257836619, 47.891861315696474, 44.83393446091683, 41.738674486837084, 41.536452770233154, 42.40324166513259, 43.59558728433425, 43.70302884809433, 41.18596153874552, 43.43550751286168, 45.82601170386038, 43.472546454398866, 48.69800252299155, 46.566264937000895, 49.609957510425204, 47.597197178871404, 44.41150696046891, 48.59466768080189, 43.13550110786192, 45.0123042445029, 40.30165533865652, 42.22318134000225, 47.77642988389539, 43.287422349376065, 41.3212715425799, 45.30530529637491, 43.843657585882376, 42.78443328795895, 46.537168795062655, 47.68475232585784, 50.82878697303034, 48.32961351640763, 48.71837923603673, 46.09317610340734, 44.83143591111706, 40.14083423922139, 40.701486064541726, 43.60853110590289, 43.083666986034764, 42.602250960565385, 48.1735816309529, 48.338113292571045, 42.20660540365404, 43.70502533451204, 40.41155230614447, 40.99514215223251, 40.59069871902466, 44.29278073772308, 43.79292957244381, 46.6505096035619, 46.05981634509179, 53.021552716532064, 47.061997613599225, 44.349176576060636, 44.60777059678109, 42.18842914027553, 44.66027152153754, 42.13569679567891, 40.337344984854425, 39.21021269213769, 39.720422837042044, 39.7342295800486, 41.3931332865069, 46.86323934985746, 46.72015128597137, 47.75213472304806, 44.464184391883116, 44.24911299059468, 45.40661227318549, 41.2644560106339, 42.69292831420899, 44.930424767155806, 47.824996671369, 44.03920342845302, 45.19358442675683, 44.77124714082287, 45.30266554124894, 43.175748548200055, 43.37352621939875, 43.86189268481347, 47.54056992069368, 48.654173958686094, 46.9141399475836, 52.0301579659985, 59.245048030730224, 60.70443253363333, 59.53125945983395, 60.475601457780414, 65.18459904578425, 63.03314370493736, 63.02011359122492, 62.934868720269975, 64.47069629546135, 65.4315318599824, 67.59294217632663, 70.14643653746575, 69.68314970693281, 68.35966356338994, 69.5825409120129, 68.98070027751308, 64.26457182053598, 60.85930731988723, 55.66080185674853, 57.87134770424136, 63.75379685432681, 71.86845117999663, 75.29169974788543, 80.53699124243953, 76.54206506667599, 87.94157105107462, 16.150113055782935, 0.8943641990903886, 40.93265487301735, 72.90918150255757, 55.84494929159842, 39.700171639842374, 39.694872517739576, 38.37579119590021, 70.47393091263311, 36.4201876424974, 0.07519783467174539, 0.015590745362363037, 0.060945082936556115, 0.0934763171619946, 0.022586926502446016, 0.05144817056134344, 0.03525358512096348, 0.020123934673686183, 0.012623401463872964, 0.06706774189707733, 0.05960199290946607, 0.01580025891833488, 0.029031723519907366, 0.06491432236807962, 0.003802883917570956, 0.07361403981884641, 0.045416733520405914, 1.221733977717738, 60.38725006964899, 61.762487965245406, 48.07856221352854, 40.33475229817052, 60.90990589511011, 46.851087847063624, 85.58571707817816, 35.7946402026761, 0.20465004678455093, 1.7034371942281725, 72.8092473553073, 83.20636810794954, 79.4370174407959, 76.3311670672509, 70.26998335315336, 61.89921786708217, 64.99813349016252, 67.16358384778424, 74.40023129986179, 64.99019069056358, 84.88970033584103, 71.40377583042269, 53.875888086134395, 73.40804423055341, 59.69832497258341, 69.07202874460529, 65.56341371228619, 69.09588459999331, 65.42442060286, 67.35065737078267, 61.96086575908046, 63.45975245198896, 61.82500270105178, 67.32662893110707, 66.07769919979957, 65.35837573389854, 59.33803958277549, 52.077940279437655, 51.34685754776002, 51.51636669712683, 48.24778502987277, 45.763693086562625, 44.99818763425274, 44.935084542920514, 47.05030895048573, 46.90368683107438, 44.98670685675837, 47.0265668438327, 49.69072695701353, 48.063810179310465, 48.61442073698967, 48.82574235239337, 52.34640690588182, 50.61697113898493, 47.89261441076956, 48.10524217544064, 44.86048498461324, 46.463165437021566, 43.40005320887412, 44.816879995407604, 45.94387108279813, 44.03462210009175, 44.03571251899966, 46.9924343785932, 46.60544941502233, 46.12427657650363, 48.95669068059614, 51.51857499153384, 54.44514951398296, 50.7381998339007, 50.061077148683616, 48.9698306206734, 47.20581916070754, 42.80025612923407, 43.11121771412511, 45.621569925738925, 46.40192939389137, 44.31786037260487, 50.047509670257575, 52.65636044163858, 43.97956771235312, 48.72964428317163, 43.680349703758, 45.42126232577909, 42.77499606532436, 46.31568039617231, 48.58022551382742, 47.52748097142866, 48.761588065854966, 54.99425780388617, 52.551260532871375, 46.572787838597456, 45.991006205158854, 44.348643133717204, 44.97692446554861, 42.4677489649865, 43.051248596560576, 42.2629306393285, 40.24379253387451, 40.76679745028096, 42.82277837876351, 49.09820587404313, 47.43168492471018, 50.08128912218156, 48.18530167302778, 46.81146406358289, 49.570537690193426, 47.38867221340057, 47.08903058882683, 48.571039322883856, 48.68050875202302, 47.10005637138121, 47.579546513095984, 46.5210243194334, 46.57956177188505, 45.799712211855, 47.98008326561221, 46.46497757204118, 49.71209602971231, 51.13248825073243, 49.690397477919056, 56.633741855621345, 62.38208124714514, 64.01415201925462, 62.757444227895434, 63.53190837367889, 67.90434698904714, 67.58424235928443, 65.39679534973638, 66.29394731213971, 65.39585005852484, 68.8881088072254, 68.76417759926089, 73.1157256710914, 71.62562508736887, 73.03774895206575, 70.67236361965057, 71.2562084197998, 69.02023776885002, 66.93831428404778, 59.97236136467227, 61.351050946020315, 66.13295755078717, 75.92815137678578, 76.81793320563533, 85.95580054867654, 78.35758116937454, 93.42191450057491, 19.23579558249443, 1.0647360860340058, 44.785963873709406, 81.99992549034857, 61.3911493362919, 48.736469207271455, 46.47257128069478, 41.90910539319439, 81.11989467374741, 40.16545495679302, 0.10055293944934685, 0.03744971788217945, 0.02112022627355351, 0.05831513373601822, 0.06939007615249965, 0.025237071695887757, 0.07080001501186241, 0.028416143144450845, 0.14629504583295316, 0.1452977985384003, 0.13185379816399467, 0.2515035552243071, 0.13191082574907811, 0.13940083674125134, 0.2919103265289338, 0.17091124348582762, 0.34954495968357213, 3.2634163960333797, 72.89446476967105, 72.54931188398793, 62.403556223838564, 39.87359923701133, 73.20503803991502, 55.70543842930948, 93.6169033665811, 38.127120771715724, 0.40272877521572575, 2.66525175782942, 79.20320495482414, 82.32220311318675, 81.57790983876875, 78.75662742122528, 71.0345317471412, 63.617965175259506, 69.11380198694044, 69.78792405897572, 75.6075603731217, 70.21862383811705, 75.01501575593026, 66.40091819147911, 60.53236992128434, 74.4259463587115, 64.36469424155452, 71.29405144722232, 69.63459860893988, 70.92204601533952, 68.75420693428286, 70.8042101706228, 64.70939605466782, 64.37564549907562, 67.24247055668985, 69.80491576656219, 71.82563458719562, 67.02310023769256, 63.39004801165674, 54.2644694543654, 52.963784048634196, 52.28096215955673, 52.749524577971435, 47.63267109470983, 49.329449207552024, 47.652714406290364, 49.85514879226685, 48.51432577256234, 47.124163258460264, 46.855633874093336, 52.72943419794883, 50.38906966486285, 54.21784424012708, 51.4778607891452, 54.900332727739894, 54.9741635014934, 48.75450034295359, 51.296321730459894, 48.86377365358415, 50.66287071474137, 46.144308120973655, 47.03505485288559, 50.22234932068856, 46.33144047952468, 47.684054143967174, 49.11950826644898, 48.80261213548722, 48.511403606783965, 51.08611799055531, 55.24887846362207, 58.66933430394819, 54.38251710707142, 55.183441562037316, 52.28388040296493, 52.97385277286653, 46.13536511698077, 48.64694895282869, 51.1318685162452, 48.675994103954686, 46.81216224547356, 53.13018668082453, 52.34363771254017, 46.74303439355666, 52.32684604583248, 48.775261448275664, 48.880941867828376, 45.655890664746686, 52.431953799340036, 52.95837510016657, 48.96428046687957, 53.51375918234549, 57.80200019959481, 52.39469912744338, 50.71039022937898, 49.535738422024636, 46.17058015638783, 48.88003972268874, 46.26701947181456, 44.990970473135675, 46.04767660940848, 42.39546752745106, 44.88787489552652, 47.94665290463356, 53.36141432485273, 50.65592811953638, 54.48474191850232, 51.07839484368601, 48.973600018408995, 53.648351392438336, 49.56985519778345, 50.080567406069854, 52.38398321213261, 53.31569910049439, 47.94888865563178, 50.58348978719404, 48.5682269834703, 50.39252919535483, 47.866864050588305, 50.94299854770784, 50.82177769753241, 53.53898002255348, 53.74288443596133, 52.355455813869355, 58.2040862883291, 64.31260124329599, 64.88121155769595, 66.23471952253773, 65.90662110236384, 71.14239692687988, 69.56780064490535, 69.18890753099996, 67.70295681491976, 69.3068532020815, 70.61403797518823, 72.14231106542772, 74.64122172324889, 74.09416091057562, 76.01325112004434, 74.91477566380655, 75.57002329057264, 70.64482858104091, 69.67517945074266, 63.90476888225925, 64.69199642058342, 71.03606931624874, 79.23267764429893, 80.34754860785701, 88.02490572775565, 83.08332335564398, 90.91533953143706, 20.26075993814776, 1.044552181997607, 49.953098220209924, 88.57887775667253, 71.19490961874686, 57.454960653858805, 53.72029550613896, 51.86745020651048, 89.52352569949242, 48.958357687919374, 0.23517221542856387, 0.12911455886017892, 0.2440711387222813, 0.159477427181217, 0.13464263400002835, 0.08363884423048266, 0.16268908226441953, 0.1084295030863535], [0.01908225236430524, 0.03565712959595746, 0.03398035082124895, 0.023489925830114274, 0.05772370236715483, 0.10678425266016876, 0.01188805569038396, 0.014681578069294413, 0.0635749402065431, 0.05926337821649448, 41.16076031038838, 58.747699337620894, 56.12847781950428, 37.380317180387436, 50.92892508352957, 49.6471219678079, 77.35459189261161, 43.447372682632945, 0.08257208211768059, 1.0416009661651429, 53.49918365478516, 85.59470715061312, 71.902968037513, 73.03233608122795, 65.98705322511735, 63.762771237281065, 61.682871695487734, 72.74643451936784, 64.84026985783731, 70.35393776432161, 72.74484203707787, 42.66969611567836, 61.378503614856356, 60.17690120204803, 62.05728546265633, 66.81337110457882, 66.57090587000694, 63.84651776283019, 65.4108884257655, 60.65131971913, 58.18302316050376, 63.8850825063644, 66.65622526599516, 62.57839195189938, 58.67593173057803, 61.231850116483635, 58.40501362277616, 47.602684574742476, 45.63792228698731, 44.59557987028553, 45.40503940274639, 43.59848591589159, 41.9309804516454, 42.28811617820494, 42.81518467010991, 43.04974632878458, 43.83958616564351, 44.8433599164409, 42.387277618531265, 44.71188206826487, 47.50210715878395, 45.58452706183157, 51.67391261746807, 46.11409018116613, 44.68631213711154, 41.78839052877119, 39.45310154268819, 43.14186319228142, 41.12204259441745, 44.354169753289995, 41.797004053669596, 43.35309067080098, 41.31767865150206, 42.888179979016705, 41.82417038948306, 44.40628628576956, 45.40567874908448, 48.4768985163781, 51.391415672917525, 48.33084906301191, 48.8962548009811, 45.23196481889294, 44.934762908566384, 41.801679518914995, 43.47036953895323, 40.46232346565493, 43.55278245864376, 43.447643326174834, 48.48008348095802, 54.09929844640917, 41.53547217769008, 43.0910724209201, 39.83138668921686, 41.32449573086154, 40.330892685920965, 41.09932814874957, 44.38113997059484, 44.340672877527055, 45.25785246203023, 50.62255267174014, 45.88853428440709, 42.70085150195707, 43.20671173834032, 43.007592616542695, 43.02548254689863, 40.428308671520604, 40.011396023534964, 41.31908286002375, 40.91682810937205, 40.25193929672241, 37.91337120917536, 41.221337395329634, 45.66023272852744, 41.7555602904289, 43.59200223799675, 42.78540603576168, 49.1787007547194, 45.23033703527143, 44.20307613188221, 46.36135639682893, 43.68512322825771, 43.619023446113836, 44.99209227100496, 44.23102301935996, 43.67207350269441, 42.7886341464135, 45.6315052893854, 44.82685066038563, 45.057278140898674, 46.631639080662886, 45.864603903985795, 52.59083332553987, 62.838150916561005, 59.893011816086315, 59.42803836637928, 60.56266238612514, 62.6236717931686, 62.936112111614605, 63.7223159113238, 63.51626596143169, 63.82512907828055, 65.99166593244, 65.39527739247968, 65.78971093700778, 68.98691331186603, 69.94183001979705, 69.6105231008222, 68.56692944803547, 70.46576453793433, 69.38201365932342, 65.25275807226858, 61.5207483691554, 60.75270122097385, 68.3990284704393, 71.41932410578575, 77.91212543364495, 76.00857565479895, 95.01190216310563, 23.053481617281516, 1.3251826912164688, 42.99626088911488, 70.87824098525509, 53.06812301758797, 29.299440345456524, 39.884993722361905, 39.78521646991853, 69.67926656046222, 30.703605721073767, 0.23752831883968847, 0.04875789193676845, 0.10307264859758078, 0.06558546135502477, 0.011585793784639288, 0.020365361537363742, 0.02674186181637549, 0.036398469049844055, 0.08504157420247795, 0.04930663688649093, 0.02834954329075352, 0.01527895619567003, 0.04287800623945171, 0.06624259625471408, 0.03802765844269626, 0.03130181249411356, 0.0528338244335065, 0.19046045899871858, 48.98797158272036, 65.47907490884104, 50.21561853347286, 35.7528865721918, 60.98014770015594, 56.052956504206506, 81.83397785309823, 49.05180423490463, 0.11417184535774494, 0.9682267808145093, 59.2618553869186, 86.50905870622205, 76.67468824694234, 76.006528177569, 68.78787655984202, 66.42451517043575, 65.24890630475937, 75.14347337907361, 69.257674524861, 72.78489728127757, 88.92680768043765, 47.941742097177816, 64.36640439494964, 63.07737627337056, 65.76191702196675, 70.38639929986769, 66.47729458347445, 67.16458797454834, 67.37015939527943, 66.05805596997662, 62.57936862207229, 66.10226108181861, 69.58040714263916, 65.82041525071668, 63.466342033878455, 66.36194552144697, 60.618724822998054, 51.509200526822, 48.99045444303944, 47.03350159429735, 48.992372482053696, 44.91168368247248, 43.100705762063306, 42.762577841358805, 47.359815336042836, 45.75878620147706, 45.7253283839072, 45.910601538996545, 44.425125429707194, 46.006228923797615, 51.20979032208843, 47.44464835812969, 54.56162821862006, 48.92468413999004, 46.27451119884368, 43.721428686572665, 42.89387133813674, 43.517783149596184, 43.56631463573825, 45.78128491678546, 43.36254358291627, 45.78548969761018, 43.59400264678463, 44.889031994727354, 45.80310898442423, 46.0038637345837, 48.98323728192238, 52.40283020081059, 53.22622591449369, 51.07948918496409, 50.29437972653297, 48.99574572040189, 49.24177246709024, 43.75802440028037, 47.1792019567182, 45.441972440288914, 45.74814088882939, 46.02173405308878, 50.38376269801971, 55.97168891660629, 44.74785412511518, 46.4506922998736, 45.272831993718306, 48.05091342618389, 43.529722844400716, 46.30356027233986, 47.76767907604095, 47.40493043776482, 48.73727721552695, 55.45101781045237, 51.00682335515177, 45.759688346616684, 45.179699236346835, 44.204213619232185, 44.81242026052168, 42.85707950592042, 42.057920117532056, 43.90369730611002, 43.16325579920123, 42.92071996196624, 41.475620731230705, 45.230442939266084, 48.196794217632664, 45.790831965784875, 45.606229535995, 46.174208348797215, 51.00172035155758, 47.7574142333, 47.023860408413796, 49.93864036375477, 47.11121551452145, 46.43490475993003, 45.864874547527684, 47.417952706736905, 46.1950518238929, 44.23303127288819, 46.70396366427022, 47.54806557009297, 49.40143646732454, 49.52756028021536, 49.61961438578945, 54.0733794243105, 64.42689518774709, 64.20896830097323, 61.76427656604398, 64.14374320737778, 65.64322610055247, 67.13792370211694, 65.24117531314974, 66.76540836211174, 66.75033861590971, 69.1610037895941, 68.86517863119803, 69.57029527233493, 70.40345376537692, 74.21339311907369, 72.8301457435854, 74.1753069047005, 75.25333896760019, 75.50015018832299, 69.75882791703748, 65.93792161633893, 61.880437558697125, 69.35717721139231, 73.64163706379553, 82.27652319015996, 76.33159068322952, 98.6849743320096, 26.578876549197783, 1.0893246891998476, 47.35996830847956, 78.74968482602027, 57.628980528923776, 39.69215039283999, 47.8964622559086, 41.4946363818261, 81.3130243362919, 32.56590981637278, 0.2485935242786523, 0.02580595709713957, 0.0666548817929241, 0.021533074886387876, 0.010574876608687543, 0.055693554046053084, 0.01647698843190747, 0.027221586074559923, 0.14932578159195764, 0.12132409584498215, 0.16265808634700316, 0.1595539746866111, 0.26146871969103813, 0.19099149582607133, 0.133854589995838, 0.19026066326806623, 0.14534814583678402, 0.39169189970820184, 65.43392450578752, 75.57902120774793, 70.26095405701669, 48.51204295312205, 72.0151948928833, 63.439281602059644, 90.04102753054711, 52.5907156544347, 0.2974386008516435, 2.062906608466179, 63.909158014482074, 85.81667407866448, 76.57621322139617, 78.36854811637633, 74.57348239037299, 70.15818795850201, 68.19664985902848, 77.49688763772288, 70.265103924659, 71.46678478487077, 73.19542823299285, 52.097607043481645, 69.27750602845224, 65.20979242940103, 68.4257790350145, 72.88154448232343, 71.0043530310354, 67.28538913111534, 70.56121149370748, 68.21058211788055, 65.634224261007, 68.48499897987612, 70.83983313652777, 68.4635357702932, 65.02543318656184, 66.55224323272705, 62.056477454400834, 53.23579649771414, 49.97940555695565, 47.71911228856733, 51.4185937758415, 48.38468751599712, 46.04629593510782, 47.154365508787095, 50.66219998944191, 49.539323468362134, 47.71840233956614, 49.17291133634506, 47.3758303734564, 50.559806516093595, 55.027017439565356, 51.93812739464545, 57.45074802829374, 52.447392248338275, 49.68124266593687, 48.02167607891945, 45.93939958080169, 47.31149958026025, 47.279567564687426, 48.23942645903557, 47.22005344206288, 47.481208770505845, 46.150783954128144, 46.06792780660814, 49.52583051496937, 50.13075805479481, 54.06223597065095, 55.77919075565954, 59.242106253100985, 55.550787218155406, 57.425476197273504, 51.984505499562914, 52.12264353229154, 47.84431434446766, 52.937719898839156, 48.80448702842959, 50.528494235008, 49.793034138218054, 53.882383531139745, 57.457223861448234, 46.91556376795615, 51.512252130816066, 50.975236508154104, 49.7029451401003, 48.79309254307901, 48.91551756089734, 52.59847410263554, 51.53363297062536, 53.24565733632734, 58.375588001743445, 54.11682751870925, 49.449128566249726, 51.438374288620494, 47.00985754689863, 48.234962801779474, 44.81139259953653, 45.27158860237368, 44.701083783180486, 47.501087342539144, 46.15663613042524, 44.627558954300426, 48.33767398711174, 53.2089674857355, 50.35496857858474, 51.12431010892315, 48.15125942230225, 54.62449596774194, 50.687326692765765, 49.961974543909875, 51.299400791045166, 50.66287855948172, 49.24429062874087, 49.05203173237462, 50.7818675810291, 47.48914372536444, 46.50078096697408, 51.34316659742787, 51.557681022151826, 50.33369756514027, 52.117285574636156, 52.73003432058519, 57.49499628620764, 67.97760117438533, 66.36499712544104, 64.53523105190646, 65.34873847038516, 67.49304725277808, 68.26893914130427, 68.35630601452243, 68.6724647398918, 68.46607746616488, 73.72662698068928, 70.63263785454535, 69.67764269921088, 74.43893724872221, 77.54827068698022, 76.90224847485943, 75.86974728492, 78.75055559219854, 77.43701657941266, 71.93207202419158, 68.84931656622118, 67.04636773755475, 72.15452532614432, 77.8899169737293, 85.33374401830858, 82.7474743320096, 100.71921748499717, 28.683343856565415, 1.541404327557933, 52.21416419552219, 84.16659570509388, 71.27218031114148, 43.910231974817094, 54.18491202016031, 55.20243367841167, 89.36943146490282, 40.87887917795489, 0.2845522665208386, 0.2828500191530874, 0.2702674540060182, 0.11889821714571408, 0.0792185475509013, 0.10604469436070613, 0.09422616402228033, 0.13930072437130636], [0.022367622342801863, 0.004983539364465903, 0.06807428183815173, 0.033636611000063925, 0.024830612256341887, 0.0013238168110312415, 0.055367307842619, 0.01838942734344352, 0.06776068374634751, 0.05442784272975499, 34.9847609766068, 62.15680383866834, 49.723749391494266, 47.89976881396386, 45.405031558006044, 48.063453243624785, 70.88611710456111, 55.7575471170487, 0.32189669327870496, 0.32518388463124154, 45.140546137286776, 79.53273111774077, 68.95449100002166, 77.2509942516204, 63.52535801549112, 63.30596808464297, 61.65440705514724, 70.22032614677184, 63.57508190216557, 77.0738600146386, 42.48537609654088, 45.29737426388649, 65.76917732915571, 61.80289230039043, 68.52330484697896, 61.960132275858236, 64.26433647832563, 62.624244459213756, 60.67887044722035, 58.37276389521938, 63.40721622590096, 66.38653093768706, 62.84156337861092, 59.28381673751339, 62.88370924611246, 62.81554237488778, 55.232486878671956, 47.246121514228086, 47.37433987279093, 47.044005701618815, 46.96530726648147, 42.348112752360684, 45.16597878548407, 44.868278734145626, 42.24415033094345, 41.1327192860265, 43.77709888642834, 42.31964811202019, 42.58423159199376, 44.49852082037157, 46.91540295077909, 48.10385757876981, 52.364583169260335, 46.849518898994695, 43.29928751914732, 38.47516444421584, 40.58947886190107, 41.85199568348546, 43.95593150969475, 43.11863491612096, 43.79063106352284, 40.514310559918805, 41.07105962691769, 42.748104295422955, 43.875679815969164, 41.936365865891986, 44.55510101010723, 49.70395318923458, 49.585729029870805, 48.2157902563772, 48.660892978791274, 47.02853979602937, 46.56411547814646, 42.731006683841834, 41.66982904557259, 43.16207908814953, 44.805187409923924, 44.6304105174157, 50.436679394014426, 55.292875689844934, 43.279844330203154, 43.57214720018449, 41.442688511263945, 41.925830379609145, 42.65547360143354, 41.991883093310946, 44.005467122600926, 44.444270518518266, 47.54743014612506, 49.0966369259742, 49.12552518229331, 45.31616633938205, 43.43622138423305, 42.48145764873874, 41.464069351073235, 39.65689220736104, 40.01303165189682, 41.2062951057188, 42.79277616931547, 39.89862788108088, 39.55172169593073, 43.63855684957197, 42.94506219125564, 39.93077954938335, 41.96733297840242, 46.20131192668792, 49.32324009556925, 46.46968833861813, 45.454108253602065, 40.4142822757844, 44.18067547582811, 44.397186386969786, 45.30100637866605, 43.89107904126568, 43.62120820629982, 43.82747780892157, 42.683710744304044, 44.752702174648164, 45.891040678947206, 48.352163222528276, 45.26281033792804, 53.63316005276096, 60.58723211288453, 62.35098077404884, 58.584960199171505, 55.67682081653226, 64.17297663227205, 64.24514432107249, 62.775840144003595, 64.6426804604069, 65.23644493472192, 63.55312055157077, 66.13912351669805, 67.28982925415039, 66.45138340611612, 70.46949863433838, 71.84455610090687, 71.87817081328362, 69.63709323636948, 73.20100584337789, 68.94241794463127, 66.88901009098177, 61.56606351175616, 62.3129730070791, 67.60836493584418, 77.90970140887846, 74.04535878089168, 94.39059088307043, 25.590653034948534, 0.5695193849744336, 52.492424980286636, 67.21720264803979, 55.41871316971318, 23.936754272830104, 29.74915969756342, 44.95097798685874, 73.39057399380592, 26.465092512869067, 0.17437527857480511, 0.15742565985889206, 0.09559138632950284, 0.06968219313890704, 0.053410305596527555, 0.017797710606828332, 0.037456133868545294, 0.03189001671759592, 0.03073055413551629, 0.05163390091770599, 0.042422249041978395, 0.007511312545712798, 0.09395798728350671, 0.049101930532243945, 0.027283457250544624, 0.016498844920387192, 0.12176658823004655, 0.05578138602657184, 41.477311272774976, 67.88383299304594, 40.08594459103, 51.45651132829728, 57.16180662955008, 55.641162549295736, 78.15280206741826, 60.37374534914571, 0.5439766652641759, 0.5170103703295031, 50.07580957105083, 84.97608661651611, 75.14020996709024, 80.46598065283992, 68.75717224613314, 67.03350236338954, 64.83417057221936, 75.56638333105272, 65.41847036730859, 91.27694283762287, 57.32111761646887, 49.05118057804723, 68.52574456122615, 64.73449922377064, 71.74434738774454, 66.35322217018374, 66.24339580535889, 65.7894402934659, 65.95012803231516, 61.46175592176376, 64.91016649430799, 66.9278964688701, 66.65824920900407, 61.6652798652649, 67.4438371965962, 65.21804509624359, 60.231155426271506, 49.1174647115892, 48.19323662788638, 49.147761098800174, 49.22187036083591, 46.32919688378611, 44.887863128416, 48.28363549324774, 47.233554240195986, 43.80048405739569, 46.26532500790012, 43.394887447357185, 44.55636401330271, 46.80274463468983, 47.75208373223582, 50.6949870817123, 55.33750834003572, 48.16834526677286, 44.367698008014315, 42.0267294299218, 43.4757157294981, 43.4886791629176, 45.675216182585686, 46.38273331426805, 44.24733223453645, 43.28177413632793, 42.13723436478646, 45.055046312270626, 45.412464449482584, 44.89057348620507, 49.74664818856024, 53.35067095295076, 52.426391878435695, 54.48241203061996, 51.977441310882575, 50.36109532079389, 48.45209736977854, 45.29846468279439, 46.774621240554325, 45.33324433911232, 46.767741403272076, 47.09904439987675, 51.00368153664374, 55.92892331461753, 47.54571607035976, 46.135843646141794, 47.984048781856416, 45.5425420115071, 45.7740246095965, 46.530414473625925, 47.062225111069225, 49.41851054468463, 51.24945332927089, 52.583812282931426, 53.26801876867972, 49.178873339006984, 47.5008951464007, 46.083425091158965, 41.74747628550376, 41.611487711629565, 41.61098564824751, 42.577202704644975, 44.128147094480454, 44.11586223110076, 40.75567753084245, 45.64273895755891, 45.48513812403525, 42.623447448976584, 42.01366793724799, 47.65256927859399, 51.58473360923029, 46.84336077782416, 48.01803219702936, 45.020815787776826, 46.28325416195778, 47.05278788843463, 48.628427520875015, 46.45215926631805, 45.48349857330323, 47.088575593886844, 46.25087891855548, 49.37448978424073, 48.35607382559007, 49.89942842914213, 48.80827211564588, 55.488892216836255, 65.45369717382616, 62.98413368963427, 62.15293638167843, 58.10237530739077, 66.46050683913693, 68.00235917491298, 65.94267552898776, 67.56004133532124, 67.59023574090773, 66.16210860590782, 68.5862353540236, 68.88739493585402, 67.81236740850633, 72.51867817294213, 74.13748741149902, 73.37258600419568, 74.08295077662315, 77.87198389730146, 74.55001092726185, 69.86378269810831, 65.48066346876084, 66.57008217227074, 69.63732073383947, 82.33653545379639, 76.6349938607985, 98.85881377804665, 26.1757412264424, 0.3475107204529547, 60.811709357846176, 74.25736288870536, 63.47772475211852, 36.03663475282731, 35.553081035614014, 45.35173831447479, 85.23240566253664, 30.19960076578202, 0.2382782729522836, 0.08997774682939054, 0.07671281950728548, 0.022189997196678194, 0.06748872253322794, 0.0027283888653806985, 0.07176035985110268, 0.03594327109655546, 0.17464141751970017, 0.1360882265913871, 0.1399886100402763, 0.09544257375021135, 0.1838989465707733, 0.16861066612745487, 0.14526897831068886, 0.1763901664244552, 0.28271166367396233, 0.22962878788671187, 51.75725513888944, 77.43002691576558, 63.263010286515765, 63.420360088348396, 62.871169428671564, 63.6128935506267, 81.85356616973877, 67.20906765230241, 0.45674122209029816, 0.800999102573241, 55.074348680434696, 82.69056858554964, 76.89470967938824, 81.59357578523698, 73.34177186412197, 69.85964851994669, 68.92941920988022, 75.42574282615416, 71.32311621019917, 77.5893771263861, 55.53533307967648, 56.69653115733978, 70.39850373421946, 65.19491880170762, 73.01282621199086, 66.48308400184878, 67.60221465941399, 68.7761329835461, 69.87370629464426, 64.03132023349886, 66.33878784794962, 70.80479852614864, 69.46537971496582, 66.6802066372287, 68.10856911443895, 66.53014459917623, 61.005843147154785, 51.57606517114947, 51.10712620519823, 52.89619376582485, 51.66837815315493, 48.16969848448231, 49.60481136075912, 52.79036429620559, 48.096671796614125, 46.773268022844874, 49.00883466966691, 45.62958725037114, 48.505731859514796, 48.92808483492944, 50.869799275552076, 53.68723777032668, 57.460632401127974, 50.895471188329886, 47.319108978394546, 43.031550453555205, 46.519557352988954, 47.02968120574952, 48.952811456495716, 47.84303565179148, 46.41037033450219, 44.96718522041075, 45.86279569133636, 47.87728578813615, 48.249224539726015, 47.292621212620894, 52.808807280755815, 57.42418181511664, 57.52886595264558, 57.10604229281026, 56.47176757935555, 54.54026699066163, 54.421007325572354, 48.73472767491495, 50.82636294826385, 49.85868677016228, 50.72939803523403, 50.24917441029703, 53.70020120374618, 59.00216310254989, 49.605995916551166, 48.82041185132919, 52.66690769503194, 48.86598194799116, 50.34950863930487, 50.34405654476535, 52.66180076906758, 52.956174650499904, 54.61473711075322, 55.92159240476547, 55.71233787844258, 52.92002216462166, 51.962571605559326, 46.53778068480953, 43.70637462985131, 45.15188570945494, 43.965360887589, 45.5578157209581, 48.616695711689616, 47.35260209729595, 45.00007429430562, 50.76900612923407, 49.76123940560126, 47.9573295962426, 47.331648795835434, 51.37693035987116, 53.32488136906778, 50.92621864811067, 52.412949915855165, 46.27285595863096, 49.38839458650159, 48.54551646017259, 50.171613462509654, 49.154252621435354, 48.14689382430046, 46.69644448064989, 49.011305762875466, 52.32570855848251, 52.03424899808822, 52.96042649976669, 51.839703359911525, 57.767683382957216, 65.73171084926975, 65.75215032023769, 64.52047117294805, 58.79416765705232, 70.42392069293608, 69.53113432853453, 66.44941437628962, 70.10065463281447, 70.69955348968506, 68.47451056203535, 71.52962115503126, 71.17581552074802, 69.70565626698156, 75.88294213817966, 79.04612187416323, 76.3618713809598, 76.95796966552734, 81.58716663237541, 77.26768001433342, 73.16335108972365, 69.79085799186461, 68.85323109165316, 73.299206303012, 84.12518332081457, 80.68366435266311, 98.81787992292836, 29.549265907656764, 0.7297282269404781, 64.58523342686316, 82.4389014705535, 75.72722404233872, 35.455323803809385, 38.75506085734214, 61.090566342876805, 94.35633290198543, 36.51091598695324, 0.5179504521431462, 0.3074519216052948, 0.2322073019440136, 0.27777468665472926, 0.15251039377143308, 0.14903719627088116, 0.17562297533356375, 0.17928561105603175], [0.04279895745698483, 0.01524085098231632, 0.06636295632849779, 0.09362709858725149, 0.07334358013805843, 0.0814404936447259, 0.011205184066878452, 0.08645929651515138, 0.028111433587788094, 0.11370523652482419, 30.218590920971288, 59.7206550259744, 48.30043892706595, 23.109193002024007, 41.14147793862128, 44.2849281526381, 61.534433518686605, 74.03990668635215, 3.0631965591061503, 0.7391101686704544, 31.841104838155935, 74.82459252880466, 72.91571617126465, 76.0039472579956, 65.12278249186855, 65.29371938397809, 68.41334512156826, 67.0936950560539, 70.61179437944966, 51.406983560131444, 36.60084416789394, 68.59207184084, 63.50863695144654, 67.61209118750789, 62.7309682292323, 66.12012355558335, 62.12834704306818, 63.57135957287204, 61.03519424315422, 64.58005982060587, 65.17229849292387, 59.97180046573762, 57.979287409013324, 61.816953997458185, 59.5552251415868, 64.83746144079393, 48.709746099287464, 46.47646619427589, 45.797248963386785, 48.32241204477126, 43.97454315616239, 44.68615131993448, 44.22277819725775, 42.04123043244885, 42.52561961450885, 47.883942050318566, 45.161213105724705, 42.69780774270335, 43.72150713397611, 43.18573882502895, 45.52993943614345, 46.038478651354396, 52.14955883641397, 48.10019408502887, 42.193830244002804, 40.34660570083126, 40.36534678551459, 44.651132399036044, 44.302696489518695, 45.8226659221034, 37.51403077956169, 41.2236790503225, 42.97162055969239, 44.37886891826507, 43.526514345599765, 42.357259719602524, 48.620939716216064, 50.674582912075905, 50.31713731827275, 48.583269273081136, 47.98740633072392, 50.129769617511386, 46.029567026322894, 46.029567026322894, 42.11179779421899, 44.406384345023866, 43.509950176362075, 46.277986418816354, 51.16157654793032, 55.2629989962424, 46.767933599410526, 43.21355235192084, 42.343974651828894, 45.11231683915661, 43.30229989943966, 42.540975693733465, 44.09141017544655, 47.144771391345614, 47.53332530298541, 48.52063294379942, 50.03694672738352, 45.17712616151379, 42.39496938643917, 41.25162201543009, 39.04681459549935, 41.02508944849814, 39.49366669501028, 40.38388782931913, 39.06761492452314, 43.654124736785896, 35.68638670829035, 42.804064750671394, 40.0784214850395, 37.2376605772203, 42.04474879849342, 49.03573428430865, 49.316113148966146, 45.026895461543916, 45.62928522786787, 40.80839418595837, 43.31545945136778, 43.59863496595814, 46.81641801711052, 44.235145430411066, 43.56820914053148, 43.4527345626585, 44.82077490898871, 45.477552260121996, 45.23249826123638, 45.27145131941765, 45.47669326105426, 50.79339934933571, 60.21934516968266, 60.312654433711884, 57.864114853643606, 55.62304512146981, 58.82390706769882, 60.08547075333134, 64.88776976062407, 65.39251604387837, 64.44449486271029, 68.07212245079779, 64.67005075946932, 65.15978613207417, 65.3432902982158, 68.05527979327788, 68.32323258922946, 69.96634483337402, 70.31950719894903, 73.57621977406164, 70.79098393840175, 69.97438569222727, 64.98267150694325, 65.18452452075097, 62.64952413497433, 78.57476280581567, 72.80173209405714, 97.78359013219034, 19.215016826506584, 0.014319816029690688, 64.59807134443714, 62.60264788904498, 51.682428083112164, 25.994076651911584, 53.274318095176454, 55.38342752764302, 77.62237994901596, 20.932607035483084, 0.16049077764393824, 0.08624529751438288, 0.022737864975727374, 0.06349298412040358, 0.09059857682234819, 0.044582904271420934, 0.04796565360119266, 0.07133237717132415, 0.06594510899195749, 0.028471952649734678, 0.04411824130182786, 0.03013738566228459, 0.06923197092668665, 0.01707232493396488, 0.06469810937320994, 0.141231986063142, 0.023185624215271206, 0.20051406065542854, 34.28138194545623, 65.5471044971097, 46.2726245387908, 33.400523508748705, 52.433860071243785, 55.858222592261534, 66.22598832653415, 79.30393926558956, 3.9814682785541784, 0.6898110624282592, 39.31337887240995, 79.1238397167575, 75.85977661994197, 77.1104008151639, 69.63635583077708, 68.72189444880333, 72.22344137007191, 69.10805963700818, 83.03936927549302, 64.14738708926787, 42.21972180951027, 71.87958286654565, 64.78056746144449, 69.89421244590514, 65.73418978721865, 68.16283118340277, 66.33925068762996, 65.6030414181371, 63.85697087933941, 66.38022376644996, 67.5534439086914, 63.30980024030132, 59.76137707310339, 64.83800665024789, 59.89651449265019, 66.1755152671568, 52.84371637528943, 48.47598460412795, 48.16548978128741, 50.375368825850956, 48.00707701713809, 45.89615544965191, 46.10028343815958, 46.56060495684224, 46.086260964793546, 49.71927004475748, 47.65889213931176, 46.603139138990834, 46.09569818742814, 47.63903317912933, 47.5730118443889, 48.82909205652053, 53.89981062181535, 50.23150413267074, 45.93872101076188, 43.22301703114664, 42.771995452142534, 46.88725210005238, 44.168786771835826, 47.60215505476921, 41.68338475688812, 44.14964560539492, 44.43597078323365, 47.065076674184496, 45.61281127314414, 47.52126401470554, 50.21900746130174, 53.961254550564675, 54.98451855874831, 51.79935786031908, 51.29557648012715, 50.959029274602095, 50.10360740846204, 47.305384605161606, 47.28879297933271, 48.010685597696614, 45.296581945111676, 50.21405350777411, 51.26718244244976, 57.2730960384492, 47.9618207100899, 45.697754121595814, 45.73901353343841, 48.32891141214679, 47.34823649929416, 46.29222070017169, 48.09649921232655, 49.671981949960035, 50.063093246952185, 52.598685910624845, 52.87427163893177, 45.81318163102674, 46.025338711277136, 43.33849160901962, 41.3774634176685, 43.52618094413511, 40.64235241182389, 43.796612678035615, 40.98967044584213, 45.371510982513435, 40.14015959155175, 43.484227272772024, 43.51533166823849, 40.76427144388999, 43.40976499742077, 51.403272997948434, 52.76371571325487, 47.52470393334666, 45.87616312888361, 43.0553396286503, 45.1205930402202, 45.296440739785474, 49.58994557780605, 46.42211783316828, 46.76011631565709, 46.0848646010122, 46.9157128180227, 48.36825670734529, 48.77291587091262, 48.57581284738357, 48.07138035374303, 52.86597582601732, 63.660522891629135, 62.57066880503009, 61.08823253262428, 56.48708051250827, 60.302256230385076, 61.53126424358737, 67.56470111108595, 70.94113226859801, 69.16481633340159, 70.84156682414394, 68.75244971244567, 70.2261390993672, 68.69432018649194, 69.37859335253316, 71.78389272382184, 70.88418729843633, 73.40517305558728, 75.57982921600342, 74.40609132089924, 73.09106965218821, 68.66107417691138, 67.06260635006812, 67.16821224458756, 81.19201137173562, 77.2631928228563, 102.25910863568707, 18.30118106257531, 0.13395237345849315, 72.2549536920363, 66.4208673661755, 60.31686705927695, 25.92850442855589, 53.93901471168765, 51.22218501183295, 84.15769192480272, 22.80340894576042, 0.33546696026479045, 0.08794931454523917, 0.06447811956487356, 0.006511366706446655, 0.04970399137105673, 0.014942602419684974, 0.022232298656637152, 0.0133105018927205, 0.22342981890805308, 0.1390020266896294, 0.2148107322113168, 0.18118477366384, 0.21563349532023554, 0.22067525784575173, 0.19286545414117076, 0.2629756146380978, 0.16361483823387854, 0.3059762217585118, 45.55940820324806, 75.99119955493559, 62.35975119375414, 33.50058317184448, 55.55524303067116, 63.57845514051376, 72.82302271935248, 87.86670084922545, 3.957686212755019, 0.8314593713129721, 45.866459185077304, 80.12676623559769, 77.82533122647193, 82.43337877335088, 73.81174241342853, 73.1854183443131, 74.88982938951062, 72.44570639825636, 78.65292779860958, 55.04855125181137, 46.99716083465084, 71.69893418588947, 65.74006157536661, 70.49414680850121, 68.14071686037126, 72.4978425425868, 67.16833776043308, 68.94281802638885, 67.38042031565021, 69.2753016564154, 70.58971143537953, 66.14378329246276, 61.74066389760664, 66.0029858927573, 63.56450719218101, 70.69392096611762, 53.73064271865353, 51.38204905294603, 51.02892198870259, 53.23333324924592, 51.17381826523812, 49.34029848344865, 49.94242152860088, 48.0240059668018, 48.283294247042754, 51.75976937816989, 48.09728760873118, 48.33693265914918, 49.64773777992495, 49.984206538046564, 49.86441343061386, 52.43939453555692, 57.456674729624105, 50.95982551574708, 49.81033963541831, 45.840089090408824, 45.249015362032004, 50.41693810493716, 49.18513736417217, 50.88459053347188, 42.44850973929129, 45.56541727435204, 46.13304307383876, 50.66079185855005, 48.3006154337237, 49.40242490460796, 56.84266298047958, 57.24775360476587, 60.370199526509936, 55.68335156286917, 55.387251838561035, 55.74061424501481, 54.80923175811768, 52.110099792480476, 52.7199734410932, 50.632915573735396, 49.39683552711241, 51.542062144125666, 53.22251927468085, 59.88145651355867, 51.178030890803186, 48.08075874082504, 47.7012929608745, 53.256345795046904, 50.971243535318685, 50.320600771134906, 52.884269760501006, 53.8670039176941, 56.874728356638265, 57.485770871562345, 58.56024534471574, 51.85358070558118, 50.05081622831283, 45.709889934908965, 45.13654139734084, 45.9066830911944, 43.18655860039496, 47.479906543608635, 44.184064403657, 49.83805510305589, 43.510044313246205, 47.327177293839, 48.60520316708473, 45.4798468466728, 48.781784349872225, 54.81282072682535, 55.428134702867084, 49.32204377266669, 51.781691505062966, 44.677392667339696, 48.94394689990629, 48.98035041747555, 51.81356468508321, 50.28964934810516, 47.138048448870265, 49.03758956540016, 49.729205408403956, 51.3563810625384, 51.75151278895717, 52.0027131419028, 49.82110261917115, 56.307651688975675, 64.98685667591711, 64.23283592347177, 61.92798060755577, 57.04381389002646, 62.235466972474136, 62.938575360082815, 70.4940918953188, 73.77655090824251, 70.56663220928561, 74.57815001087805, 70.36018217763593, 71.81530306416174, 72.11138709898918, 72.32029253436674, 73.24135134297033, 73.12237801090365, 77.38472354027533, 79.37811913028841, 77.42648893787016, 75.78743242448377, 70.58405537759104, 69.74611943767917, 69.69006876791678, 85.62442302703859, 79.61070783676641, 103.1204846597487, 22.51890963123691, 0.2408144223473726, 78.06934187489172, 76.30127860653785, 68.2957681532829, 37.638330690322384, 78.55569224203788, 71.666213773912, 96.07160106781991, 29.615624566232007, 0.45344030244215844, 0.13608821126962864, 0.22695776105167406, 0.1526618646758218, 0.2589191484355158, 0.2547052051992186, 0.14736093460552155, 0.12897408897838286], [0.08809720015814228, 0.028833331645376263, 0.06448103835986507, 0.0029393596642260113, 0.025768981863474174, 0.03817310789600015, 0.11231225119122576, 0.11799808681732225, 0.17611175475101318, 0.17750434937977022, 20.831417729777677, 66.10209634227138, 43.55266086516842, 33.211810435018236, 27.66461410830098, 49.54728195744176, 53.76088811505226, 81.68886584620323, 9.772939278233437, 0.5486022428639474, 22.182803692356234, 62.37821379015523, 71.8725069107548, 75.59700919735816, 65.16429293540217, 65.6732871455531, 64.86276857314571, 72.28061383770358, 52.084804427239206, 39.122677157002116, 62.384654321978175, 68.58632949090773, 64.27304414010817, 64.9597962440983, 62.10276534480434, 59.84185234192879, 62.98152923583985, 60.90071970416654, 62.91208759430916, 65.6165579057509, 62.907502343577725, 62.955425862343084, 62.83844117195376, 63.42096413335493, 63.42116809660389, 57.63296173464868, 46.300947973805094, 45.76130436312768, 46.167073557453776, 47.85528521383963, 45.49926650139594, 44.9586344534351, 44.45311154088667, 41.54642735758136, 39.97640455922773, 43.39746052219022, 45.90258421436433, 47.23160874459052, 45.79918661425191, 41.97012570596511, 44.87638235092164, 48.736096582105084, 45.93203729198825, 49.326487818071925, 42.98372891641433, 42.09591219502111, 39.79039399854599, 43.70532735701531, 43.54056035318683, 43.97303304364605, 42.75991062964163, 40.841738254793235, 41.96401465323664, 41.13937947057909, 43.979704995309156, 42.836369391410585, 46.378999217864006, 47.64721132093861, 48.55766404059626, 50.45003114208099, 47.6350127497027, 52.207802111102694, 49.072451591491706, 47.927409756568174, 48.760128944150864, 45.99496387666272, 46.43507342184744, 50.922837565022135, 47.16727795139436, 48.952685940650206, 50.6812430966285, 46.725297435637444, 45.024024286577784, 45.72267686167071, 45.245791173750355, 45.45089191006076, 43.9199084620322, 49.10133984781081, 45.199828840071156, 50.37939710001792, 47.92886103353193, 43.651386922405614, 45.592724815491714, 41.69450075395646, 41.40404924269646, 39.96011103353193, 41.86786951557283, 41.820899132759344, 40.781784826709384, 41.00367722972747, 36.64671628705917, 46.35927361826743, 38.33258628845215, 37.58473934665803, 43.12298090227189, 49.8827701230203, 50.152378159184615, 45.15457253302298, 44.09386165680424, 41.36281728744507, 44.33344394929948, 46.32819667939217, 45.28730161728398, 43.81870738921627, 42.44985903463056, 44.87327583374516, 43.720342190034934, 47.58207251948696, 44.44174843449747, 46.347388836645315, 45.746101256339784, 48.05659694056357, 56.73912809741113, 63.373264189689394, 60.20992755889893, 63.6981737229132, 60.68159257211993, 59.459982149062625, 59.05132216791953, 63.93530453405073, 66.79321012189313, 66.78677743481052, 65.53356839764503, 69.06330539334205, 67.06180618655297, 69.60277249736171, 67.64812992465112, 70.10360425518405, 69.4785745682255, 73.20397115522816, 68.27504234929239, 69.83682817028415, 63.827788445257376, 68.43403954659739, 66.00112668929562, 84.78735785330497, 70.58855041380852, 97.16971566600185, 8.902727134766119, 1.1660946665271636, 66.88084371628301, 60.52053613047446, 46.40351795381116, 49.42813211871732, 51.315376604757006, 42.44108077018492, 76.01139191658267, 11.067859780403877, 0.08138520507923058, 0.04313827312040714, 0.040909221561084834, 0.007409046032285739, 0.10134562594635833, 0.02282459762007479, 0.03359217023957641, 0.056464656015797976, 0.10002764828142621, 0.023811219275117885, 0.08009870596710714, 0.04682716267604021, 0.041866027074114937, 0.031021966321033337, 0.11859338309976364, 0.16043183483904408, 0.20265656343150526, 0.2061623962776315, 25.359735258163948, 75.4391965558452, 45.911578209169456, 37.45857631006549, 37.42760527518488, 61.783723677358324, 59.92008401501564, 86.86312321693667, 12.83399030085533, 0.6863438097699996, 25.273441153187907, 67.44210350898005, 73.23966472379624, 79.18132597400297, 67.96578699542631, 68.81953008713262, 68.60054416041221, 76.48752058705976, 59.774811190943566, 43.10283560906687, 66.21221296248898, 70.47220506975728, 69.22504824976768, 68.03109445879537, 65.45547008514404, 64.84924816316175, 65.88668761714813, 65.97824358171033, 65.43643874506797, 67.49563601709181, 65.51146191935386, 66.2962144420993, 66.55134108758742, 66.43603124926167, 65.22963570010278, 59.27356758425313, 47.437882269582445, 49.16429388907648, 47.92728424072266, 49.44632014920635, 48.589333257367535, 48.31206090988652, 46.44347121638637, 43.81291404847176, 42.79901273788945, 46.84715370978079, 49.42739079075475, 49.71612430387928, 47.15857421198199, 45.64106018312516, 46.38886790121756, 51.244193430869814, 48.076381375712735, 51.465921094340665, 44.31089032080866, 47.078467645952784, 44.059097689967004, 45.92731868067096, 44.339249057154504, 45.40029725720806, 43.141161088020574, 43.85536586084674, 44.10465994188863, 43.13884688961891, 46.07947526439544, 45.9489623192818, 49.81286171943911, 51.71548974129462, 51.16201585338962, 52.58674621582032, 51.28124413951751, 53.082471047678304, 51.66668761161066, 52.79715784134404, 52.118803531892844, 49.20516498627202, 49.48240203242148, 53.14631546697309, 50.479025302394746, 48.67238160102598, 52.40502280573691, 50.459342848870065, 47.40386355307795, 48.93688271122594, 48.93991078099897, 47.52319774320049, 48.79925458661972, 50.335831334514005, 50.80357005519252, 52.96540398751536, 51.56210937807637, 49.511294211110766, 46.82998549553656, 43.96343500383439, 43.16607598335513, 43.39199666054019, 44.507240249264626, 43.30273920489896, 42.90913720284739, 42.15430844214655, 41.450568552940126, 47.05102282185709, 41.25079439532372, 41.552083415369836, 47.18725850505214, 51.34361374762751, 53.732105762727805, 45.8593322384742, 46.72592893723519, 43.35991951727098, 45.611850292451926, 46.88431424479331, 48.715445303147845, 44.55381839506088, 45.42802449195616, 47.0635038037454, 45.87529236270536, 48.31912117619669, 47.19270275485131, 49.695673065800825, 48.62156729544363, 48.755759423778905, 58.31687404263405, 66.72556492590135, 63.38754946185697, 66.36462842264484, 63.416633836684696, 62.21023044278545, 60.02732161552676, 66.76303140578732, 69.54453314504316, 68.89943661228304, 68.6102794831799, 70.04686324827134, 69.47212619166221, 71.29664021153604, 69.65046067391673, 70.48149324232533, 72.99079818110313, 76.5411158530943, 71.3680273486722, 73.97494439155825, 67.32515411992227, 73.15990724871236, 70.24656680322462, 88.59181373350083, 74.01628617317446, 100.70265723812966, 8.640323512015804, 1.7346972587608522, 76.74388670152234, 65.95316394682854, 59.24545203485797, 49.43902454068584, 54.30977675222582, 50.885633883937714, 82.87557894183745, 14.529341651547341, 0.2667744301499859, 0.01619677262140378, 0.02579354838798604, 0.03471111443134085, 0.03447899745116311, 0.06288836071748408, 0.048264125286931955, 0.06342232400070756, 0.2787932158718186, 0.12043947113617776, 0.2622549404059687, 0.11402143165469171, 0.20490907643350864, 0.14982127193962375, 0.2558773503668847, 0.28872134764828994, 0.24344057175180606, 0.2869204894429253, 32.570328366371896, 83.68204178348665, 57.49519240471625, 42.085306106075166, 39.77812482464699, 67.42770841044765, 64.5460803278031, 94.5762288185858, 12.92371157676943, 0.7207056723775402, 30.197045341614757, 70.86973728672152, 76.57045518198322, 83.17783678731611, 72.07932564520067, 73.48266340071156, 70.37933903355753, 80.10187487448417, 52.60211406215545, 46.2426576306743, 69.23976498265421, 73.93372028104721, 70.90405018098893, 69.77082252502441, 68.93384364343459, 66.4833507230205, 69.04949865033551, 66.30426314569289, 66.94768874875962, 73.0754743083831, 69.88055475296514, 68.02310851312453, 68.84876743439706, 69.5345546353248, 67.60764321973248, 62.669551757074174, 51.76480570147115, 50.251253266488355, 50.494714783084014, 51.34780283897154, 49.44671630859376, 51.441425892614554, 50.88618693813201, 46.16101741790772, 45.26956073699459, 49.35830216253958, 51.74634702744023, 53.12633883568549, 50.92966248912197, 48.79566561791205, 52.97001277246783, 53.8982730527078, 52.439622033026914, 53.74415136152699, 45.94434568958898, 50.18672243241341, 45.35114995894894, 51.56119546582622, 46.02373053950649, 50.110789268247544, 46.1658654674407, 44.5250399651066, 47.60919178685835, 45.02596585981308, 48.49994636351063, 48.288146218945904, 53.28072724803802, 56.00568802125993, 55.82291733834052, 57.65305211467128, 57.68492921706169, 58.85137150364538, 56.40408708203224, 54.80267747755974, 57.57080001215781, 52.309116932653616, 51.50643525585052, 57.07117242197837, 51.53111088660456, 52.289811026665475, 52.840268611907966, 53.31171005002914, 50.93542837327527, 53.35145150461505, 52.96490584650348, 52.19276374386203, 50.48068838734781, 55.6844380594069, 56.06858714934319, 56.92069461268764, 55.6012563551626, 50.66359243085308, 52.84546183001611, 46.457085763254476, 46.094643069851784, 44.779833209130075, 46.46199657071022, 46.64809342353575, 46.10115028196766, 44.676255179989724, 45.57035946076917, 52.79712254001249, 45.07440320907101, 43.45231094667989, 50.32541351933634, 54.983926280852295, 57.84689957095731, 50.36811244103217, 48.24732219019244, 46.08735138370145, 47.329970021401685, 49.03798572478756, 49.71821492718112, 47.92513870423841, 48.69506074536232, 52.597666094380045, 49.084614861396055, 51.971079226463075, 47.82665191158172, 53.62375028671757, 50.632272305027136, 52.26856746981221, 61.19574077667729, 70.99539433756183, 63.51011960737167, 68.32748443849626, 64.30965946566674, 63.22247651315505, 62.134654214305264, 70.04459611831173, 71.72693206417945, 72.2191502971034, 71.84160647853729, 74.34973470626339, 72.54498943205803, 73.33482142417662, 73.26526995628112, 74.28791030760735, 73.63052891146752, 79.27604336892405, 74.8795606243995, 77.5851958797824, 70.00909082351193, 77.47959783000331, 72.51725827493976, 93.37379486330094, 75.63362844528692, 102.30375305298837, 11.482967157517711, 1.5880930351634182, 85.55256520548176, 75.14862737348004, 66.4206555581862, 71.96097204762121, 75.68248548815328, 57.9466885905112, 99.55291640373969, 19.455801325459635, 0.3584358390540846, 0.1684505077860048, 0.1430719913614373, 0.10348114966144485, 0.1980917825694046, 0.14422559720133582, 0.17586950242759722, 0.14976779900250897], [0.03451946221532361, 0.041171330883498156, 0.03566218194581809, 0.0778519845898113, 0.05357581506212873, 0.03777831597554107, 0.08335498567189902, 0.03805156038593381, 0.23910456006565403, 0.2402577828615904, 12.689489203114665, 63.96035278997114, 56.079628621378255, 41.68558912892496, 18.514077509603194, 37.95801562647666, 53.58438537966821, 79.62511862477949, 25.69815539544629, 0.7609602832986463, 6.65327137516391, 61.079438578697946, 69.71778423555436, 72.23729518152052, 67.06180618655297, 66.33758760267689, 71.38137125199842, 66.2524486357166, 43.78889737590667, 61.29733016414028, 65.21715864058464, 66.11379285012522, 68.26724467738983, 64.19273361083, 61.99181718211021, 62.76752864160846, 62.27931514863045, 60.72688418049967, 63.60561755395705, 62.11255558075444, 62.28637541494062, 61.417048746539706, 61.70396620227445, 61.72503325246996, 56.725164459597686, 46.138263748538115, 46.33021670003092, 45.83925754793229, 48.02142896959859, 48.94606105742916, 48.67662168318226, 47.34914648917414, 45.087849094021706, 43.895024945659024, 44.350368976593025, 44.86425045997866, 48.544010270026426, 46.48011399853615, 45.776617296280406, 43.3906905112728, 42.98283853838521, 48.1709183416059, 49.30337329064646, 49.14053609294277, 43.38662693577428, 43.22937127082579, 44.38603116619972, 41.97256934258246, 43.595940297649754, 45.246626638597064, 41.62839312707224, 40.67483355922084, 42.885716730548495, 44.8363898646447, 41.6260044036373, 44.03825813724149, 44.36417571959957, 48.16230481670749, 47.407699631106475, 45.343097332985174, 48.834544151060044, 48.79616375892393, 48.894795679276996, 51.94222234910535, 51.10800481611683, 50.87895408753426, 49.7198191765816, 49.455098413651996, 48.03730672405612, 47.254040779605994, 51.13104874087919, 51.6861778689969, 48.195166434011156, 50.564882063096576, 49.402346457204516, 48.529446509576616, 48.476353306924146, 48.20543127675211, 49.253484664424775, 47.696680253551854, 47.21001217442174, 44.663076016210745, 44.456731888555716, 43.02765161760392, 39.58837232282085, 42.7597733466856, 40.43597690520748, 40.04399484203708, 41.64445523292788, 40.522402409584295, 38.21605659300281, 46.129030489152484, 34.78846988370342, 37.40765217811831, 42.28721795543548, 52.76573965626379, 49.67635931507234, 44.60782943233367, 42.74132251739503, 43.89659781609812, 44.33835867912539, 50.978892157154704, 48.76773441991499, 44.498611034885535, 42.3400209026952, 45.84378788548131, 46.32449396194951, 47.44442870540004, 48.08191584002588, 47.22526234965171, 45.03413615688201, 47.17759770731772, 48.97007772999425, 61.93429170116302, 61.53465317141626, 62.812992834275775, 63.059949182694965, 66.43239128974177, 61.48061467755226, 60.69489332937426, 56.527006318492276, 61.49120507701751, 60.72464450713127, 67.65659439948298, 67.17928117321384, 67.32776641845703, 66.15070235344672, 68.41252926857241, 71.72977186018421, 73.94172191619873, 65.7374845781634, 71.74883457922166, 63.465392820296756, 71.22776339131018, 66.73208390512775, 80.58475002165764, 71.96245470354634, 92.5792403374949, 1.939377811166548, 7.667917936078965, 74.91292430508521, 59.866767237263346, 35.43502946053782, 84.42761375058083, 64.59341156867244, 33.79996984235702, 74.39094312729375, 8.553250816560562, 0.1069307133495327, 0.05338613552251651, 0.02551806317041478, 0.04891684752017741, 0.03275861295180456, 0.07097269122999522, 0.1410473588733904, 0.09708964746565589, 0.044897946438962416, 0.02123440784822789, 0.029402856730044852, 0.03864774533036736, 0.12188823533154304, 0.03281683563404987, 0.06679702940727435, 0.05683148955746044, 0.2192254670925679, 0.25415136959523926, 13.139591966905902, 73.45773281589632, 56.41390869694372, 40.671232823402654, 22.937532432617683, 49.847143234745154, 59.56307772667178, 85.2124329536192, 31.56396585126077, 0.7859982429973541, 6.429399155801343, 68.83405070151053, 73.53410920789166, 74.9322380558137, 72.0452480931436, 68.65963074468797, 72.79198108180877, 69.17015075683594, 47.56750483666697, 66.46455472515476, 69.49562118899438, 70.44581536323794, 70.61951360394879, 65.85057827734178, 64.51527011009955, 65.74804752103745, 65.75440568308677, 63.311663366133175, 64.4843186870698, 65.38915849501088, 64.76813747036842, 64.76091246451101, 64.60805769889586, 65.04431939894154, 59.6006775671436, 50.47422039893366, 49.565387618157175, 48.12801937903128, 51.36380218690442, 50.96697991894138, 50.82578635984852, 49.51440465065741, 46.091787584366344, 44.67877726401053, 44.92679657474641, 48.87103003840293, 51.895118605706, 50.0485687102041, 48.79338672084194, 45.28041785763156, 46.44894292277675, 49.197951747525124, 53.94447465096751, 52.756726049607806, 46.137236087552964, 46.96772344650761, 47.4202198366965, 44.56711915231521, 45.09261869615124, 46.33181702706122, 44.11921193522792, 43.17757245033018, 44.77116477104926, 47.94429948253017, 45.33377385908558, 45.50773882096814, 48.712699644027225, 51.129821039015255, 49.50752873574534, 48.860635757446296, 52.37986864582185, 54.74974901445451, 53.470946511914654, 54.23378475250737, 55.41325715280349, 53.206692511035556, 51.71974943530176, 51.83298826217652, 47.576373315626576, 46.38027791054019, 51.05543721106745, 55.91691693952007, 49.22518084126134, 54.23747570283952, 53.115364043943345, 50.59366441542103, 52.77070537690194, 52.26192297474031, 53.26530448852047, 52.0782736809023, 51.290563691046934, 46.27539373213246, 47.68545050774851, 45.25608739545269, 40.78760954641527, 43.81184324141472, 42.12034463882446, 41.85037966697447, 43.54210968940489, 44.010424998498735, 41.05038481373941, 47.40971180700487, 38.55107799653084, 43.66275787353516, 47.55347059619042, 53.36733710381293, 52.729681307269686, 46.03053977412563, 44.88470562042729, 45.90978960837088, 46.21179642215852, 54.726916897681456, 51.16797393368137, 46.64980357693088, 44.234706124951764, 49.15473899533672, 48.55159221156951, 50.83823204040528, 51.90503827987179, 49.99194537439654, 47.84724435498638, 51.35995826413555, 49.53697789099909, 61.314466999423125, 63.90399617533531, 64.72459131671538, 65.50275033520114, 68.00260236186367, 65.84418481396091, 64.4421257511262, 57.67628823557208, 65.32103869222826, 63.541898650507775, 69.17207271822038, 68.47966455644178, 67.92986592938824, 67.55138858672112, 71.21838892659834, 75.96499027744417, 77.08354826896422, 68.98233198350476, 76.08140622415851, 66.10010377822384, 75.45450164425758, 69.00249296619047, 85.3135673461422, 74.86969194104596, 94.35918054273053, 1.6728246884961284, 10.012511764803241, 82.74905112481888, 66.35960778882428, 46.721692777449086, 92.42391447867118, 78.78577847634593, 36.514779521572976, 82.76739212774461, 9.858718572124358, 0.1052105165417156, 0.026147197556471633, 0.043089442676113504, 0.01685072825620732, 0.12690041920230274, 0.055107232483644644, 0.16939040573854602, 0.011183421424169455, 0.14550303349331503, 0.08672436293695243, 0.1845040181351285, 0.14656388140734167, 0.18595111225881886, 0.1362325115910461, 0.22210781162063922, 0.2014949136684018, 0.5323086558811126, 0.5827912147487364, 20.375854046114032, 87.33507064081009, 72.54937464191069, 55.787902339812256, 30.286898997522172, 55.21242003287039, 66.17461312201716, 92.39836415936871, 32.2084249988679, 1.0677226031980207, 10.040870501149087, 72.18995217354068, 73.01809787750244, 80.49914821501702, 74.68112791738203, 73.52537801188808, 76.3696062949396, 71.31131772072085, 48.068913182904645, 71.10537759719357, 71.07006057616204, 73.39168794693487, 75.26236041899651, 68.08010839646863, 67.37286583069833, 68.27128471866732, 67.86061256162583, 66.65849239595475, 67.55080807593562, 66.87543869018555, 66.93418795062651, 68.23699535862093, 66.73169166811051, 69.43431454320108, 61.76001687203685, 51.89867227308212, 52.3913808022776, 50.22967630817045, 53.89188743406727, 54.980451060879616, 53.62586052187028, 53.27823262060843, 49.38693154242731, 49.146745204925544, 48.85502676809988, 51.110334703999186, 53.46813025013093, 51.21968253966301, 52.04317239023025, 48.86678211150631, 49.24572229385377, 53.49838349127001, 55.87930140956756, 55.96814309397052, 49.65522166221373, 50.963740041179044, 50.5826739341982, 46.487158575365626, 49.70420422092561, 49.51454585598361, 47.15747594833375, 45.034865717734064, 47.337755926193736, 49.766452235560266, 47.05367434409357, 47.93461907294489, 51.38281391512964, 55.600177703365205, 53.091382672709805, 54.94988010775659, 58.13063598448231, 60.340036499884825, 59.030772870586766, 57.77085265805645, 58.38660986192765, 57.05345115353985, 55.14158594992853, 55.15225087442706, 49.3264054482983, 47.63364776488274, 53.19538824019894, 58.686118125915534, 52.6421183155429, 57.84014917189076, 57.87740776615759, 55.034348349417414, 57.529415084469704, 58.91646715902514, 58.91364697487124, 56.671682942298155, 58.26985266900832, 50.636037780392556, 53.011064298691295, 47.92592710064304, 42.53184049360214, 49.07254180600567, 44.74999966159944, 45.93221772101618, 48.27718319431428, 48.83217503947597, 44.023651230719786, 50.62555720729213, 43.77176054062382, 46.076404048550515, 47.793217628232895, 59.28285967919135, 56.4404905996015, 49.83453673701133, 47.445068051738126, 49.34066718624484, 48.24059532534692, 56.91814507207563, 54.07050824934437, 50.74901773083595, 46.9013883221534, 53.68221321413594, 51.21772135457685, 52.540438713565955, 53.68930878177766, 51.398228829906834, 50.817349341607866, 53.847878440733886, 54.13879279167422, 67.34421683895972, 67.97971140953803, 69.13986221436532, 68.84853209218672, 72.78436383893414, 67.36374239767751, 65.8330374379312, 60.84501028060914, 66.58297892539733, 66.4190395416752, 72.86184633931806, 73.26625054882419, 71.09845069146925, 69.9676235260502, 73.90958201500678, 74.42313009692778, 80.5360028051561, 71.01575143875615, 80.67983611937493, 68.83374475663709, 77.4984016726094, 72.24415932932209, 87.61916791239094, 76.33249282836914, 100.76133589590751, 3.316918750924449, 8.6480603871807, 93.20546242498583, 70.5038272180865, 54.79376193015806, 101.46060820548766, 81.80133588852422, 45.60261311069612, 99.93861090752387, 14.634399394835196, 0.26391054834088973, 0.08521332345422238, 0.1135316716446992, 0.14004018307933885, 0.28296867085079996, 0.11897321715350113, 0.3522577689540002, 0.21400310699978184], [0.0467783015882296, 0.05378777626901866, 0.07532014060885676, 0.041341992290390116, 0.05295309283199811, 0.06936945306557803, 0.05200053527650814, 0.050732564000833424, 0.12386962215626433, 0.0969615575647162, 6.04453178182725, 56.55869514711442, 41.81549018429172, 32.232159260780584, 35.00149773013207, 41.22555786563505, 40.56983170970794, 70.07235080965104, 41.91027818187591, 0.3412846319617764, 0.3754766069112286, 59.097057004128736, 74.34311374541252, 70.97232295620826, 65.63254940894343, 65.12666171596896, 66.24687102533156, 63.15337611782936, 62.45845763914047, 67.82399331369709, 63.613262253422896, 67.80403629426034, 61.66482094795474, 63.091861586416925, 60.99566067418745, 63.86094031795379, 61.20854339291973, 61.933264040177875, 61.58875050083284, 61.821966786538404, 58.69676736093337, 60.278776922533595, 55.86038774059665, 54.38553340973393, 48.84447559233635, 47.43196733536259, 46.15662044094455, 47.38320835175053, 49.44955218222834, 50.49242804127355, 51.88460273127402, 50.326629454089755, 48.35428914716167, 44.99732471281483, 42.92646231189851, 46.34993445488715, 50.58692578346499, 52.450800788018014, 50.744236361595895, 45.062298774719245, 44.283425884862105, 47.199912071228034, 49.964433870007916, 53.02243524982084, 49.631903171539314, 41.29791775057393, 43.326912772270944, 45.159216619306996, 40.84507619180987, 47.074506052078746, 46.121472081830426, 42.097324248283144, 41.79030072304511, 44.57627396429739, 45.352008958016675, 41.716171849158506, 44.15086546251851, 45.00768761481009, 45.461584291150494, 44.52580874966037, 45.97293584577499, 48.65768840236049, 49.052933877514256, 53.45689265958725, 53.872824715029815, 52.787465664648245, 52.58866033246441, 45.952692493315666, 47.23306002155427, 46.73418552644792, 46.30302682999642, 51.69549742052632, 51.35135258397749, 52.42834521878151, 49.674711919599964, 48.6023594487098, 48.639300330992675, 48.022542922727524, 46.9808869208059, 44.76044493336832, 47.22906704871885, 44.41607652171966, 42.46117115020752, 41.496801530161214, 41.15520623422439, 39.89958493940292, 42.35414535768571, 36.79394245147705, 41.5244032490638, 36.53008068761518, 42.48932984567458, 45.473523985955026, 33.13350031452794, 41.42311980647426, 46.61161145856304, 50.99057297552786, 45.32305009903447, 46.80195623828519, 45.91371197854319, 47.23429949052873, 48.6054620435161, 54.19922474891909, 46.64339834643949, 43.797608960059385, 44.67674547626127, 44.82293613495366, 48.59195732301282, 49.93625948506017, 50.99805293544647, 50.60434895177042, 45.36649819343321, 46.667101229390795, 46.45101001185756, 48.43682758269772, 52.82313569899529, 58.64276809077109, 60.65224932086084, 60.30643747698877, 62.89919868592293, 67.69770083888885, 64.32655703636908, 67.68860094008907, 66.6270036082114, 66.7789326944659, 65.17835463246992, 67.9149373885124, 68.39695745898833, 68.98677995128017, 75.14651713832733, 69.48718024838355, 67.40181292257002, 67.10674085924703, 67.67255844608431, 66.5713373307259, 71.65886325220909, 78.16816206901305, 80.29170974608391, 70.37998230226579, 0.31116662066309686, 17.39600589198451, 77.9925654011388, 49.07139647391535, 39.35730157359954, 28.178095509929044, 23.648634610637544, 43.10587152358025, 53.19374476709674, 5.652803692125506, 0.16201677882382948, 0.05512171920629279, 0.10493465594106144, 0.10710941867962961, 0.10242687478180855, 0.04267603098865479, 0.058562300513468446, 0.13741047902693673, 0.010139621839287781, 0.08585417898552072, 0.022404605237346505, 0.08610665858272584, 0.0931405638074202, 0.03646732503247838, 0.010544369072322885, 0.08764454944720192, 0.22341739296192126, 0.3198914734586593, 7.973498029093589, 67.41455278088971, 47.931155620082734, 32.672435506697624, 34.17121433442639, 46.47542676618023, 48.00491579117314, 77.53190655862132, 52.13053534107824, 0.3124853337724363, 0.6681010499596597, 60.385634053138, 76.83376389165079, 77.41672223614108, 70.46520756136987, 67.72912686870944, 68.5828778051561, 67.45426285651423, 67.28139615827992, 71.84146527321109, 66.24260348658409, 70.39867631850704, 64.50402467481553, 65.675993580972, 63.76479518028998, 66.75481796264648, 62.34343021146713, 64.74309705918836, 65.41559134760212, 65.08781063941218, 60.506156721422755, 61.62715050481982, 58.45839708082138, 56.33977982305712, 50.400044456604995, 50.13409206944127, 48.35969025088895, 49.807954834353545, 50.39522386366322, 53.69524332784838, 53.62003580216439, 53.2710389937124, 49.26887604498094, 48.36518549150037, 45.303567686388575, 48.01227807998658, 53.60569169444423, 58.07124737770327, 53.494010048527876, 47.378407370659616, 46.820387455724905, 50.56510171582622, 53.043721952746, 55.87427293100665, 51.3200246134112, 46.117671305133456, 45.727591591496626, 47.62554022573656, 42.01931222792595, 47.36229819636191, 46.835920041607274, 43.47038130606375, 43.41745676532869, 46.71421281753048, 48.06735600194624, 45.57793355757191, 47.606375525074625, 48.57044704498784, 47.568830597785215, 48.62261064590947, 49.527124897126235, 52.81191379793229, 51.7988871758984, 57.668008112138324, 55.99548201407156, 56.048073153341974, 55.14506509227138, 49.157017892406834, 46.910119518156975, 46.170356581288004, 49.7263656123992, 54.50878604765862, 54.72075877651092, 56.06200541219404, 52.263138909493726, 50.873329408707164, 51.91371456269295, 51.131801835952274, 51.414487054271085, 46.75763737770819, 50.88504552841187, 47.825322228093306, 44.68121305588753, 44.757491388628566, 42.10764792657668, 42.96622337833528, 43.62511096462127, 40.3160543595591, 42.45105535753312, 40.74229048144433, 45.20419051570278, 47.94145184178507, 38.493419154997795, 43.77506709867909, 49.23939943313599, 53.70535519815261, 48.67806511540567, 48.09068625973117, 46.84020326983544, 49.71162142292146, 53.98502019143874, 57.632632255554206, 49.71276283264161, 46.84543178927514, 47.11104685260404, 47.239582923150834, 52.02059522751839, 53.138698224098455, 53.3690982480203, 52.352780757411836, 48.125960134690814, 49.358062897959066, 48.407468641957934, 51.31855764696675, 56.50378196470199, 61.87865288026872, 62.911475704562285, 62.5138101270122, 65.36230987118137, 68.76910409619732, 67.51060378166937, 70.37472632623488, 68.25219062066847, 70.70394654427805, 69.07903409773304, 70.32768141838812, 70.07332355745378, 73.84592979185044, 82.72236331816643, 70.5817804028911, 70.86715636714813, 71.09914102861958, 69.51815128326416, 70.8568326888546, 75.17750386268862, 82.68772878954488, 84.93487819548577, 70.46203828627064, 0.32283214792128534, 20.351243134467833, 84.47429780037173, 57.69202870707358, 49.554138260502974, 37.309522321147305, 31.030092047106837, 48.397039059669744, 63.75491472982592, 6.7839838708600695, 0.20300213037238968, 0.09267082167488915, 0.033285003455896536, 0.047181440036623716, 0.11889509150698302, 0.022759650601074103, 0.04527338697845417, 0.020088641003014582, 0.12762991110644034, 0.1945436157045826, 0.11725213168369186, 0.13731229719856095, 0.40083319789940314, 0.1881844270974398, 0.17796858334012572, 0.14926953541655696, 0.4171152629198567, 0.48238175590672805, 10.545464792559224, 80.90892607165922, 56.46911605711907, 43.35359665655321, 46.93604638499599, 59.02548159322431, 54.68407284828925, 83.46450713373001, 55.09449005126954, 0.343652946814414, 1.9440241037837922, 66.68788663802609, 76.73932106264176, 79.25971061952653, 71.85457383432697, 72.2769424992223, 72.49285328772761, 71.82863127800726, 69.91842915934902, 76.23723414636429, 69.22257715655913, 73.83776341715168, 68.6384028773154, 70.36957233182846, 66.80829555757585, 69.2564272111462, 65.11751082635695, 65.35153512031802, 65.78742419519733, 67.62596068843719, 62.91972444903467, 64.27080446673979, 61.9779476811809, 61.007929848086455, 53.12983366750902, 53.69734571826074, 51.308618360950106, 52.07266861392606, 52.685613478383715, 56.147340497662945, 55.05800808629682, 56.91700758472566, 53.06374565247567, 50.81074407023769, 47.373920179182484, 51.40714437730851, 56.04936753549884, 60.76498216198337, 57.90645291728359, 49.640799107090125, 49.39214045001615, 52.611519905828665, 55.33399389636133, 59.59800643305625, 55.614035437184, 48.981703635185, 49.65908519683346, 49.67213884476693, 45.52382838341498, 52.080544733232074, 48.226561084870376, 44.828968740278675, 45.89214286496563, 50.616606358558904, 49.48691668048982, 48.08967036585654, 52.78419833029471, 52.38548940227878, 54.471425471767304, 55.68040978523993, 54.49324953940607, 54.97403014090754, 58.143819070631466, 63.74066083661972, 58.987018831314586, 57.39155946239349, 58.90356648352839, 50.70958222112348, 49.65788102919056, 48.00582185868294, 49.997860308616396, 57.46127959220641, 57.92650015123429, 58.69006795267905, 56.613937808621316, 57.073368949274865, 54.19621236862675, 58.10043373415547, 58.89888317354264, 53.066918849945075, 54.54735863593317, 51.113790312121, 47.85296709306779, 47.33144875495665, 44.706327992100874, 46.060181125517815, 45.87387246470298, 41.98123778066328, 43.65686647353634, 44.05824261326944, 47.266945377472915, 53.63411318871283, 43.504443168640144, 44.75951533163748, 53.43550397503761, 56.691616427513864, 51.572476202441806, 51.92549736269059, 50.454973328498106, 54.209101277012984, 55.8993015750762, 59.665808523854906, 52.13015094880135, 49.80890797030542, 51.64511457566292, 49.910626795984086, 54.415974924641276, 54.28012363372311, 55.62498669470511, 56.63820551287744, 50.94484990642917, 52.73330949967908, 51.237811734599454, 54.659440363607104, 59.60475683212281, 63.53765072361116, 65.23407582313784, 66.40721751797584, 68.46741107202345, 72.02510279993858, 68.12476850325062, 72.6304578781128, 72.3441562344951, 72.57915327625891, 72.30964722171908, 72.68363737290906, 74.04397810659101, 73.26842354189965, 78.78056172401675, 74.94351879242929, 74.18225734464585, 75.54990153158866, 74.00445630473476, 74.56887752779069, 77.33936525160267, 84.90738238057783, 85.60045734528573, 77.79455631009995, 0.6218939358668943, 18.580791142679033, 97.90081408716019, 59.97458534855997, 62.17584302348476, 38.74959307332193, 31.848420058527303, 61.79118402542607, 78.29980465673631, 10.04297681393162, 0.5092835768816933, 0.2762345434917558, 0.2238141652196646, 0.1661541132676986, 0.22203354705725947, 0.16510095687643175, 0.14309944795264354, 0.20647005718802253], [0.0729779340326786, 0.03884275301149295, 0.05741954247857775, 0.08700504989152955, 0.034751946917705, 0.0655024404066705, 0.03878481761221925, 0.09181518573313953, 0.22182521710713066, 0.2131451957768971, 6.624013435456061, 59.337557131244296, 48.89631363653368, 59.33272084882183, 47.03635315741263, 33.114308157274806, 33.152072737293864, 59.79168522742487, 52.49388410199074, 4.14572169703822, 0.20886265702785986, 35.006286944112475, 71.3419278975456, 72.5755682299214, 67.42849288448211, 65.2980810596097, 63.731976709058216, 65.74835346591088, 60.37908369495023, 61.98381554695868, 60.03768451752202, 60.50898475031699, 59.24358498665595, 62.628170751756244, 63.107586368437744, 62.314965571126635, 63.45967008221535, 63.93961914124028, 61.79172139013968, 63.2082736107611, 60.02039863217262, 53.883344511831964, 49.6708248507592, 45.90414139532274, 46.355555211344075, 46.021220222596206, 46.0547996336414, 48.62243021688154, 55.40888371006135, 57.28296864417292, 52.926490153035815, 53.36586229262814, 49.4197892373608, 46.49372854540425, 46.20072357116207, 44.18408009313768, 50.08019478090348, 56.279924454227576, 53.01387663810484, 47.654958002028934, 46.39128015887353, 47.30188192859773, 53.19900466549782, 54.80250489327216, 55.83203292662098, 50.19590862335698, 43.06796573823498, 45.3264743281949, 41.85351364074215, 44.93131514518492, 46.1315211942119, 46.03322659769366, 41.37899706440587, 42.8150866108556, 42.64689930023686, 44.41047537711359, 44.88079109499532, 45.4405015514743, 45.05203785434846, 45.235926412766986, 42.6713199769297, 45.63807133705386, 46.49594468455161, 50.867124219094556, 53.205715840862645, 51.828720723429036, 49.132236357658144, 46.18002522376276, 43.752183991093794, 44.709842435775265, 46.415995013329294, 48.897117722419004, 52.25889098259711, 54.49332014206917, 50.23266123187158, 48.24825571429346, 47.90217714924967, 43.21961241383707, 42.127146028703265, 45.11620390799738, 44.70957963697372, 45.37373496640114, 42.21175155332012, 41.36575122033396, 38.821223397408765, 43.37789573977071, 39.111804346884455, 40.58853749305972, 37.08523334995393, 41.37891861700243, 50.02741929023497, 32.62242724818568, 37.343611640314904, 45.566484159038914, 47.98449200968589, 51.399221189560436, 48.464354776567035, 46.53777284006919, 47.17438920851677, 48.9342390337298, 52.16986886916622, 53.52190986756356, 47.52805363747382, 43.82341815579323, 45.5040047245641, 46.64096255456248, 49.974024065079234, 52.882539995255016, 53.339566722992934, 53.834546304518184, 49.662497658883375, 46.46809977869834, 47.44416198422832, 46.311197127065356, 47.5865714780746, 51.69331266034035, 56.23993196795064, 60.42786229041315, 62.75170580033333, 60.093954840014064, 64.5901560014294, 66.22195612999701, 65.57438850402832, 63.67962875673848, 65.73943399613904, 63.7804062135758, 67.82903748173868, 71.77653435737857, 74.14244528739684, 68.17144470830118, 69.0352447571293, 64.90274536994197, 67.97781298237463, 66.5588249698762, 74.53479213099327, 72.19444720975815, 87.83005022233533, 44.920905174747595, 0.627192261238252, 27.96700531436551, 74.68476003216159, 46.92893905024375, 37.178825024635564, 27.714689047105853, 34.53261759973342, 48.048191301284305, 51.14671860971759, 4.471169085271897, 0.3770015508897843, 0.05666371247160339, 0.07031423865907616, 0.1513232026369341, 0.1401457499953047, 0.033030026412058267, 0.0988333248683522, 0.013651468475619632, 0.08476124730922523, 0.054994560102181095, 0.017740575769435496, 0.07317525529933554, 0.060106488620682116, 0.012479557922380346, 0.10946693935341413, 0.13608061167741978, 0.19573713472533613, 0.4337914342120771, 8.370187917063314, 71.35109055426814, 53.46228199620401, 60.55949703339608, 50.6973522709262, 35.59383446170438, 39.572035651053156, 68.64686735214727, 61.37738966172742, 4.585472835648445, 0.32386244424889166, 33.29046572408369, 73.6568715495448, 75.48789670390468, 71.50073682108234, 70.80729315357824, 66.81958413893177, 68.65153497265231, 62.81120031110702, 67.275661653088, 62.73303924068328, 63.65645147139027, 64.40134879081481, 65.51997738499796, 65.8214742906632, 65.73719824514082, 65.34288237171789, 66.3157086218557, 63.97407716320407, 65.00509177484821, 62.601941862413966, 56.69069859289355, 51.460414086618734, 49.953772867879565, 48.84344793135121, 50.558665106373454, 48.5650263294097, 52.73316829435287, 55.36832640247961, 58.464617959914676, 55.363294001548525, 56.30113663211946, 50.71410079156199, 49.51663647928546, 48.848747053454005, 46.792915175038004, 51.9403866798647, 57.688635856874534, 57.982782240836855, 51.25994174711166, 48.33561474277128, 50.939707679133264, 53.78231994567379, 54.675145533777055, 59.130773698129964, 52.37097271027104, 45.51316738128663, 47.37748561366912, 43.71354472252631, 46.168305181687884, 48.461001150069706, 48.39796081666024, 44.45643771079279, 46.032704922460745, 43.87886478054909, 46.210274542531664, 46.90178055917063, 47.56280975957071, 48.43614116791756, 48.91883588606312, 48.02332739676199, 48.66812582938902, 50.76246361578665, 56.5051273376711, 55.23178477441111, 56.25955950829291, 50.44780323582311, 47.98466459397347, 47.29581794431133, 46.1408721247027, 47.87327712582004, 49.83419941317651, 56.240222223343395, 57.70487054701775, 55.744579761259025, 53.07395558203421, 50.81934975039575, 49.018315038373395, 47.96681388731926, 49.5997711150877, 49.10565837737053, 47.224034647787775, 44.936418148779104, 42.49252265499484, 41.528211870501124, 43.052503755015714, 41.14966000280073, 44.51145287482969, 40.291653294717115, 43.49921072683027, 49.552106472753714, 37.71046700016145, 40.597582478677076, 47.51896158341439, 51.76258563995362, 53.70901476952338, 51.24405614791378, 50.17274702748945, 50.08132442351311, 50.70384379356138, 57.63066714809787, 56.823525736408854, 50.864755107510476, 46.81792028488652, 47.99079133618263, 50.112444508460264, 52.40263800467215, 54.6979501939589, 56.30757324157223, 57.03780481892248, 51.1263575861531, 48.830119717505674, 49.60761585543233, 47.04678273970082, 49.10579173795639, 52.718828109002885, 58.45812251490932, 62.57774476082095, 65.00702158097299, 63.957916998094134, 66.59660523937595, 68.11658643907117, 66.6666038574711, 66.03726740806334, 68.77424240112305, 67.2487541937059, 68.67976819315265, 76.5805435180664, 83.0604402480587, 69.57420979776691, 74.37290806924143, 67.4717644722231, 72.16430771735408, 70.37078826658188, 79.01010667124103, 74.42709169080182, 92.31520991171561, 43.42101435507498, 0.6673622960525175, 31.94185091603187, 83.14588515989243, 50.867269346790934, 44.59585051382742, 33.70584080296178, 40.82142822204098, 59.43259223814934, 62.91324861588017, 7.359753491417055, 0.42512207682574954, 0.14016721577894303, 0.04686426048377349, 0.024923529145458055, 0.06770694267845924, 0.0732001991221501, 0.1629731936320182, 0.08015638472692621, 0.15924485820916393, 0.16185036920491727, 0.15511366779044752, 0.1963289070033258, 0.18017140787936028, 0.18263579015770268, 0.24799283473722397, 0.2836821744999578, 0.30167022539723304, 0.5264673273890249, 10.003539343034069, 84.19418565688595, 62.989511259140514, 75.17870410796135, 59.13266428055302, 51.08651022757254, 47.98056179477323, 74.78898525238037, 66.27654767805531, 5.719117733740038, 0.2972250155383541, 43.0874167719195, 76.30029016925444, 77.69538310266311, 75.82422425670009, 74.17635025516634, 71.63981622265231, 72.185088434527, 65.5760908126831, 69.34936385000907, 66.08929372602894, 66.57912715788811, 68.05679382816439, 69.12881681996008, 68.46658737428727, 70.1840756016393, 68.3266999644618, 70.74768881643973, 66.89782757912913, 69.1570500404604, 64.62520237891906, 58.92709285982194, 55.117000533688454, 53.43891251471735, 50.73621119222334, 53.31479695535476, 51.87614610118251, 54.21060354478898, 58.17582561123756, 59.80267178627753, 57.11446754394039, 58.968732741571245, 55.0837270675167, 53.029770082043065, 51.17555979759463, 50.162823430953495, 53.89163640237624, 59.97421664576377, 61.472428691002634, 53.807501562180065, 50.844017536409446, 55.55960470630277, 59.602124921737186, 61.031550361264145, 61.64461681919714, 54.385615779507546, 50.69819165814308, 52.43451510706256, 47.87850956762991, 50.92261006755214, 49.241521435399214, 47.77194269241826, 47.52302123654274, 48.06114296759329, 48.45168944328062, 49.08716832437823, 50.392752770454656, 53.741005620648785, 52.71798479941584, 54.06869219195459, 50.70527545867428, 54.52361652928015, 53.262547062289336, 59.43899354627056, 58.113981600730654, 58.52425367601457, 52.11197860779301, 50.308782669805716, 47.06626907471688, 46.071285355475645, 50.016993630316954, 53.34806257678617, 58.03880153163787, 62.86774127714096, 59.3813503942182, 58.11153011937296, 55.66891724063505, 53.394158271051225, 53.43764166678152, 53.918590930200395, 52.470695049532004, 52.60981367480371, 47.7440389510124, 44.400465488433845, 44.9356964326674, 46.35556305608442, 44.30290045276765, 45.72220225487986, 43.420398542957926, 45.82339940532562, 52.39994333636377, 46.467460432360255, 45.59080677647745, 49.98854467945714, 52.730932543354655, 55.03077507019044, 54.638114436980224, 53.586660354368156, 53.58384409258443, 54.201166322154386, 58.34400507711596, 56.78700847010459, 54.00878975468298, 50.29326969577421, 49.012251054086995, 50.777380389551965, 55.51540351683094, 57.86974345484088, 57.44331121444703, 59.053914854603434, 54.209807303644, 52.515394380015714, 52.18386780831122, 50.398530421718476, 52.060007203009825, 56.360866485103486, 62.53950557401104, 65.50251499299081, 69.02266179361652, 65.24581155469342, 69.69109642890193, 70.07293916517689, 73.11315259625836, 69.04570964074904, 71.62291080720964, 68.35953020280408, 75.98117397677514, 73.76053979319911, 82.26255170760616, 77.60854967178838, 75.44269531003891, 72.1057310412007, 74.6148947746523, 75.35574420805901, 81.98931940140264, 78.41273753873764, 92.01685090218821, 53.78390458322341, 0.6168392264554577, 33.13718342011975, 94.50155473524525, 57.96426473125335, 55.4052359058011, 41.16021117856426, 49.67797533158333, 67.27876817026447, 78.24701739895728, 9.961891616544417, 0.7239907186838889, 0.18277678097928726, 0.16202925073523677, 0.26050396984623325, 0.30274418873652337, 0.15564332565953656, 0.29029504546234686, 0.15801700312764416], [0.038163007026718515, 0.01698364259585017, 0.01945596920596736, 0.10542826937331308, 0.020430653295930357, 0.07542102672760526, 0.05840976474686496, 0.137115795645983, 0.06527531065887983, 0.18663444736551854, 6.586802890223842, 49.84230302995252, 39.81106096698392, 19.93076897436573, 22.77125727745795, 33.440194360671505, 31.623632946322044, 53.76345334514495, 57.04336673982682, 8.57989743832619, 0.4395723030451806, 3.6728282465088755, 53.23663980730119, 75.81677175337269, 67.06335160040086, 70.54964050169914, 62.41345628615349, 65.5693482583569, 62.88162646755096, 64.36548656032932, 57.28207042140346, 61.15481084392917, 61.43950431577621, 63.7412021237035, 62.101706304857814, 62.26041716914024, 60.769386983686886, 63.632070018399155, 61.15944316310268, 63.10096540758687, 56.113070749467425, 53.93214664151592, 51.80036983182354, 49.75674829175396, 46.90182370524253, 46.770416459729596, 45.561455680478005, 54.03303392471806, 53.71174081679314, 57.42920637130738, 57.8161834901379, 56.56323725177396, 50.75978855932913, 48.80371039913547, 45.453774852137414, 43.97784579184748, 46.31948509523946, 59.766844857123594, 49.5094899208315, 50.88654387381769, 49.195539489869155, 48.79439869234639, 52.14409105239376, 57.41271672710296, 57.39732926891696, 55.41495161671793, 46.510802622764345, 43.38325369742609, 40.55527187162831, 44.99908977939237, 42.41494209535661, 43.40561120740829, 46.72717232857981, 39.95895001196092, 45.581742179009225, 42.00121833432106, 42.90863513946534, 42.92047285264538, 45.019780282051336, 41.558665152518984, 44.377629449290616, 40.91134855824132, 42.67209268385365, 48.113483075172674, 51.76593926645095, 48.61939822473834, 48.68891046893213, 45.036642551422126, 45.52415001776911, 48.3448636916376, 43.794867223308934, 45.914755329009026, 48.29849343146048, 50.98960022772513, 52.6563722087491, 46.17596557063442, 46.14244107277163, 42.847869780755815, 42.188742929889315, 42.86450847502678, 44.14510742310555, 41.99106331794493, 42.047263037773874, 41.14092488442698, 38.26027347195534, 38.308648063290505, 42.51302488388554, 40.26993120870283, 40.74329853057861, 51.21160637947821, 35.872161926761756, 32.815951108932495, 40.455400482300796, 52.83682477089667, 55.57427044837706, 50.391289726380386, 48.70157187984836, 50.29889829697148, 52.89755090590447, 53.827152636743364, 54.8774496201546, 53.27425141488352, 44.64379756681381, 43.61528542733962, 46.20081770804621, 51.61301389817269, 53.476359382752456, 54.9469461748677, 57.5362596204204, 57.11964507256785, 55.79318969480453, 50.62987573685185, 46.02616633138349, 46.534089734477384, 48.90926922521284, 51.0384847271827, 52.45040070626044, 53.72098976565946, 56.02160892178936, 58.99639329602642, 59.78526430745279, 61.75916179533928, 62.83882164186048, 63.84910260477374, 64.13466292042887, 65.35736376239409, 65.7597283394106, 72.82169695823424, 65.09501211104855, 66.77633608541181, 68.4188913529919, 62.81415777821695, 67.358290303138, 66.1982963931176, 76.47298428320116, 70.44376004126765, 84.93719239388743, 17.530627519853656, 0.21808588066168372, 42.13928576438658, 71.29674219316053, 46.38430618470716, 34.86327732762983, 44.2229272473243, 46.05159897958079, 46.84578088022048, 47.71030656753048, 7.0705620415749095, 0.340306582830606, 0.06491581623953196, 0.039823376198088935, 0.08048895881661484, 0.02409606800234366, 0.0458381048613979, 0.08923690916309435, 0.0735051863856854, 0.0668260871222423, 0.04873701604083181, 0.06189975106427747, 0.11919963443952224, 0.021762094956131715, 0.02979595942663089, 0.04967098830327873, 0.09245525219387586, 0.10169691556403715, 0.17735365988506427, 7.596764179968066, 60.19162970204508, 44.748956311133604, 23.778023796696818, 35.22126420851677, 35.65029698033487, 37.51008487516834, 60.782138609117084, 67.67422937577771, 11.835047929517685, 0.7417666551566894, 2.572502657290428, 48.39747444275887, 80.78791310710292, 69.14088203061011, 77.28900986333048, 66.11454594519832, 69.54217972293978, 65.54918335330102, 68.15187992588167, 62.16452306316745, 65.66544240520847, 62.400845866049494, 67.28498904935776, 63.536760345582046, 64.82929506609517, 65.2501340066233, 66.48334287828015, 64.98758623676916, 64.42796599480414, 58.26975460975402, 56.54047966003419, 55.67533423823696, 52.52534935551306, 49.545132498587336, 48.825177531088556, 48.7313191352352, 56.050748209799494, 57.782407960584095, 57.4059388714452, 61.46851024320049, 58.83336782455445, 53.76424566391976, 52.27431374211466, 48.066214592226096, 47.16963137349775, 49.12747067789878, 60.68782129595357, 51.49357772642567, 53.999317230716834, 52.61777608625351, 51.92617985510057, 53.44788297530144, 59.83757695844097, 57.99740875920942, 58.9871443471601, 50.422507870581846, 46.187524795532234, 43.92133228240475, 45.45871703855453, 44.82234385705764, 45.77308716312532, 47.783749026636926, 40.14809846878052, 46.69875475668138, 44.72558682964694, 47.4497474393537, 46.35891668258175, 48.27515925130537, 45.66502978724819, 49.217524374684984, 44.71038372285905, 47.27287207880328, 54.00351024443104, 54.51747801996047, 50.25302225543607, 48.086916861995576, 48.056765602480986, 45.66211546621015, 48.37660743344215, 45.559008121490486, 45.440634912060155, 50.41490239481772, 55.01636428217734, 56.07341166465513, 49.044712589633086, 50.31863566367857, 48.078660272782855, 45.94879757973456, 47.23889650837068, 47.359030862008375, 47.088952141423384, 43.452350170381614, 43.35890362339635, 40.58953377508348, 41.40834031566497, 44.720001374521566, 43.293074484794374, 42.916895651048236, 53.014398313337765, 40.10305396972164, 37.96190269531743, 44.94501598419682, 54.51936860238352, 58.02091944602228, 54.42274101318852, 51.70321272265527, 53.18726893394224, 54.57038687121484, 55.894500593985285, 56.64719950768256, 55.273365820607836, 47.640566825866706, 46.4115313560732, 49.66218386926959, 55.32598441646945, 57.915423377867675, 58.19892444918233, 61.37991959048856, 60.02255985813757, 57.85660351476362, 51.61807375569498, 49.00098992932228, 48.8817459537137, 50.869367814833126, 53.92454901049214, 54.49253566803471, 56.98874773517732, 59.87346272314749, 63.10787662383049, 65.16310053486978, 64.99019853530392, 65.90670739450763, 68.01195329235446, 66.72390968568864, 69.45691524013397, 66.38099255100374, 79.96772981459095, 73.48635042867353, 68.68986437397619, 72.37240514447613, 64.76907883920978, 73.13675741995536, 69.88064888984927, 80.33107465313327, 73.43294343640729, 93.82623241793726, 15.12442796461044, 0.046400547463206515, 50.261357292052246, 78.08958130498087, 51.80669661491148, 45.70833667632073, 45.42853047770839, 41.53786482349519, 58.84508394425916, 59.16183102515436, 11.648429401459234, 0.4191971834628813, 0.14422596492353948, 0.08994018553846306, 0.06256645440214104, 0.030718991953519084, 0.055772913094129295, 0.07652921887535243, 0.08320663274536211, 0.16576224397267067, 0.21220365839619793, 0.18256694949682684, 0.19744164971334321, 0.15272762566324205, 0.16414949099623388, 0.23465266992007536, 0.2170292768747576, 0.24806685415246796, 0.49067021437710334, 10.871837369857296, 74.20678000296317, 57.5615079172196, 31.5322672167132, 32.83669652477388, 52.03517075507872, 46.76721188329881, 70.66626825640279, 74.23794715635239, 12.229042168586487, 1.0677985991201093, 6.1260749159320715, 58.97079198591171, 81.26168051073628, 72.72439079899942, 76.69303709460844, 70.16618959365353, 73.02045914434618, 71.09517159000521, 71.96683206865865, 66.34728370174285, 68.42669686963482, 65.1116664948002, 70.60929190727973, 66.61178481194281, 67.54111982161, 66.73375483482116, 68.03231823828914, 67.66774962025305, 67.96217057012743, 61.5640317240069, 59.99763711806267, 58.57996309957197, 55.62938367166827, 51.35569857012842, 50.32774340721869, 52.236964933333866, 59.22054498426376, 59.08439167084233, 61.02885177058559, 63.57672929763795, 60.45476582742507, 56.645312847629675, 56.98156195302164, 51.96709017599783, 51.199905949254195, 51.14407493222145, 64.54318561861592, 53.44136791844522, 56.46231858961044, 57.00409204729142, 55.151870404520345, 56.311664273661954, 62.142695073158514, 63.228564031662486, 64.28158706234348, 52.184962149589296, 49.5144909428012, 46.46487166804653, 48.890092757440385, 46.84778128900836, 47.85410458041776, 51.56216036888861, 42.501426435286, 50.62015610356485, 46.38387864635837, 50.83099134506718, 50.807759146536554, 53.57678382627426, 50.83513336796915, 53.73228619175573, 50.300635906957815, 52.271485713220414, 59.604768599233324, 57.042186106404955, 53.01228415581488, 50.94152765889322, 49.11879831744779, 46.546331451785186, 50.50536794047202, 44.53960764792658, 49.10637224874189, 52.30666545129592, 57.12444997602894, 61.61474404796478, 56.734613449342795, 58.87785926941903, 55.295189888246604, 53.06537343609718, 52.183110790867964, 51.4001468689211, 52.17828235318584, 47.5288498786188, 46.14555935705862, 41.963740087324574, 44.27620872374504, 47.57272158899615, 46.57895380450834, 44.425337237696496, 55.937811405428, 51.42548145786409, 44.25602028446813, 48.79696784480926, 58.81301072336013, 61.48332503534133, 57.25982666015626, 54.84512928993472, 56.08068373895461, 58.50497522661763, 59.17516708374024, 59.012675054611705, 58.91525514664189, 50.88392765291276, 47.37386918837025, 52.133747762249364, 58.615911622201246, 59.42017793655396, 60.342852761668546, 64.80076766783192, 62.474562891068004, 61.2902424412389, 56.59743639730639, 51.83702045871366, 50.35404289922407, 54.489017301990145, 58.281615857155096, 56.746878700871626, 60.128452085679584, 63.05852928469258, 64.16890128966301, 67.73700298801546, 66.95241912718743, 69.96141049169725, 69.05509979494157, 68.1364179426624, 71.71052871211883, 69.92242997692478, 73.29982603749922, 74.39776805139358, 73.41490837835497, 75.88561719463718, 68.66952296226256, 76.2752026896323, 75.05074854820006, 84.44190686748874, 75.47224644691714, 96.91296515926238, 22.430395464743338, 0.29300092929793947, 53.3096900293904, 86.23561459202921, 61.90642718345889, 53.704115729178156, 61.28069146986931, 63.6830686753796, 67.09953938761066, 74.84086252027943, 13.632008279523543, 0.5302503308461559, 0.2005633967177522, 0.1838691304287603, 0.2742367087593002, 0.25144082794506706, 0.21649028805475082, 0.2950373748617788, 0.27534836362446513], [0.07622485214303579, 0.05341998894789046, 0.03851299812536567, 0.04434970710726996, 0.06868737434307415, 0.04004321661928008, 0.13626226644602515, 0.05369530179567876, 0.1130325347185135, 0.12266668025404216, 3.0087589640771193, 48.670483173862586, 50.59916357840262, 46.83311554693407, 25.608811647661273, 35.720534863010535, 34.79842093683059, 46.524366178820216, 57.9641588272587, 23.271239842137984, 0.1131594984702045, 0.10164701259664952, 7.309233363597625, 71.8489726897209, 69.3692502667827, 69.79732205790859, 64.81662188806843, 69.05034588229272, 61.39851946984569, 64.25407163558468, 62.94361560575424, 62.3837011860263, 62.997999268193404, 65.14565383234333, 64.11248191710442, 63.75514614966608, 59.606604268473966, 62.95450802772277, 61.83733463287354, 60.651311874389656, 60.27174411281463, 60.59156240955476, 51.619850589383034, 50.96965889776907, 46.76609008542953, 45.77100046219365, 52.681851925388465, 57.09464388508951, 58.92811267606674, 61.44854930139358, 56.97919284143756, 59.421903779429776, 50.37923236047068, 52.19409734972062, 46.046076282378166, 45.146614043943345, 44.57318313660161, 54.521341554580204, 54.19891095930531, 55.35572382711596, 52.87941386622768, 51.527871008842226, 52.47294256764074, 59.59333096781085, 55.377124278776115, 56.67584065468081, 56.464071889077466, 47.631102146640906, 45.27809973685972, 42.46263027191162, 44.23243115025182, 40.155625497141195, 44.39539386380104, 42.986215699103575, 41.97033359158424, 44.15163424707229, 42.901692544260335, 42.33770670429353, 44.75769535187752, 42.29394089791083, 43.225629329681404, 40.530941409449426, 40.20897365385487, 47.92721756042973, 50.212331587268466, 52.627527098501886, 50.218681904577444, 50.21865444798624, 48.067826686366914, 42.978986770876, 45.86885967562276, 50.358079018131384, 50.300941851831254, 52.41063963982367, 47.74860458989298, 42.84798745186099, 41.931647254574685, 40.31957664797383, 42.21258309579665, 42.444932537694136, 42.24140467182283, 42.767716146284535, 43.711658062473425, 40.3235343194777, 40.0878155616022, 44.5320100169028, 41.24536191263507, 39.949281369486165, 50.372285842895515, 35.57745856623496, 28.772587583911037, 37.7201513321169, 47.698676739969564, 57.66605869416268, 56.244058301371915, 54.63553743977701, 53.34606609036846, 50.41417675633585, 53.536442249051994, 53.72449636459351, 55.62398256794099, 50.66845616986675, 43.58132554638771, 45.36199139010522, 50.20134502841581, 52.44146162463773, 55.40480052271197, 59.67805416353288, 59.67998789202783, 60.046941311128684, 59.869120659366736, 55.586520010425204, 47.90753902927522, 46.694863765470444, 46.97363053598712, 49.53218475464852, 54.31638594596617, 51.758157284029075, 52.48307404979583, 53.29822494137672, 57.897600127804665, 57.70674151758994, 62.200793220150864, 61.98231720155286, 69.07061669134325, 61.05649663556007, 65.97791410261586, 64.96073369056948, 59.95449496853737, 70.82044093839585, 70.54305876455, 64.31911237778203, 68.43108207948747, 70.11214717741936, 76.72904445279029, 69.17050377015146, 78.13621828632971, 4.904801326413309, 1.290383668195817, 62.277432410947746, 64.44019202263125, 48.900773371419604, 36.977223042518865, 46.72494834469211, 42.686366188910704, 42.20750754879367, 62.22236233372843, 11.937151147473244, 0.37150186696840876, 0.1681367181722195, 0.09773512250713765, 0.05757929862386758, 0.053652439176315264, 0.10845450053532278, 0.13465047874037298, 0.09851985701149511, 0.034308493092295625, 0.08543789446834596, 0.05168999387552181, 0.047979845379989956, 0.11669651109484896, 0.030570529859452963, 0.1665852215862082, 0.0623464722546839, 0.0657306120340382, 0.3338439876754438, 4.570427113963712, 59.728707651938166, 60.85742065983435, 50.59846539651194, 37.53209721657538, 47.259598778140166, 44.063765310472064, 51.65800740641933, 65.31129160235005, 30.80400270800437, 0.07582777345012273, 0.17404820499641283, 4.638215966763036, 70.95515081959387, 73.19537331981044, 74.28651394382601, 68.25457542173325, 75.07314528188398, 63.69296089295418, 69.08897338374969, 65.6104939214645, 66.32940553849744, 66.05306671511742, 67.81405402768043, 65.59070556394516, 64.55851816361951, 59.951470821134514, 64.35175041998586, 64.18705401882049, 63.63472154063564, 61.01212286180066, 63.06959036857852, 55.69662878590246, 53.90550198093538, 48.094734145749, 48.342180790439734, 56.002801156813106, 59.882833265489154, 62.80918813520863, 64.04666454561296, 59.66381595980737, 61.85486370517362, 55.001004280582556, 52.241695311761674, 48.18110865931357, 47.86631884113435, 47.99103060076314, 55.7264897900243, 56.0113872251203, 59.74135337337371, 54.15886355984596, 53.88235607454854, 54.09196753655711, 61.40780372004355, 58.98359460215415, 59.55360912507581, 58.32939817059425, 51.1555713991965, 47.9583925585593, 45.069770889897505, 46.20173162029636, 42.10846770194269, 46.650058530992084, 46.75163615134455, 43.80484181065714, 46.17022322070214, 43.759369773249475, 45.72259056952692, 48.20124218540807, 47.98441356228244, 45.677448011213734, 45.469640839484434, 45.34476826267858, 52.79377283588533, 52.79428274400773, 56.41790559214931, 54.19721257302069, 51.350572032313195, 47.21115750651206, 43.98465502646662, 45.74470097018827, 52.1102370754365, 52.93655495489798, 53.292235482123594, 52.641306384917236, 46.119334390086514, 45.052528150620006, 46.66358286334623, 46.35741441480575, 45.93702654684744, 46.953332270345385, 47.63113352560228, 44.6190474110265, 42.200706158914876, 44.30801914584252, 45.48143148422242, 41.90562232848137, 42.87807595345282, 49.35721566600185, 39.584767664632494, 35.444109747486735, 40.731096036972545, 51.460484689281834, 58.28795832972373, 58.76859380352882, 56.97307394396875, 56.08386870353453, 53.062568941423976, 56.99756914569486, 59.020810050349084, 59.11124421704201, 52.83058427995252, 47.061707358206476, 48.161508575562515, 50.74369507451212, 56.40008234208631, 59.06258721505443, 61.698827897348714, 62.91080497926282, 62.39334237190985, 64.07482716345018, 55.349636308608524, 50.250947321614916, 48.975671029859974, 51.39031740926927, 50.86812050111833, 56.574592513422814, 54.64491190448884, 55.52056143360754, 53.54585201509538, 60.73361889008553, 61.018469256739465, 64.80420366410287, 63.56101236035747, 72.58237746454054, 62.435041089211744, 68.82411926023423, 78.30787689455094, 64.20068033279912, 71.60588772066178, 71.95704183270855, 65.82500442381829, 72.89163281840663, 72.16654346835229, 80.56389870182161, 73.03728611238542, 81.86798480249222, 4.300542060405978, 2.051301786015111, 70.2110928873862, 72.28998830241542, 54.98323594370196, 52.34802684476299, 59.82201299359722, 33.41677388837261, 57.90748842300908, 74.79126022708031, 21.740203442112094, 0.4546443475109916, 0.2117921466067914, 0.10867697246853383, 0.03227496249300819, 0.12139149626056034, 0.067735142374952, 0.08736934768216265, 0.04098763449057456, 0.18753797146341494, 0.17025763259058999, 0.171146126043412, 0.17850438523436749, 0.20878591033960545, 0.12376766351442184, 0.22585234214221278, 0.26840720866476336, 0.27500089678552847, 0.386690755164431, 6.471861264398021, 72.47397099771808, 70.23572537206834, 62.54761703552739, 36.30833733466364, 53.91597078692529, 49.98820343325215, 60.91132187074231, 73.08387602529218, 32.698354528796294, 0.2909112253016041, 0.20466748294570755, 9.795448780059814, 82.57467823643839, 73.88622037826046, 77.06748224073841, 69.59392363025297, 76.20299185475996, 67.90331148332166, 72.05766631710914, 69.17217469984486, 69.5420620518346, 68.42644583794379, 70.8569582047001, 68.0037869176557, 68.47228265577748, 63.513371252244525, 68.78941412894957, 66.96842239749047, 66.64656839063092, 63.70628518442955, 67.12166940012287, 56.72090084322038, 55.608367612285, 52.40328911812075, 51.42991373615881, 59.306358598893695, 62.780244965707105, 62.72600643096432, 67.19101690476941, 61.48176785438292, 64.26645063584851, 56.43183000626103, 58.98924281520229, 51.24151052967195, 49.88152673167568, 49.639849893508426, 60.4417121794916, 57.91056356122417, 61.58291793638661, 57.20920847308252, 58.186090453978515, 57.178908163501376, 65.06843413076093, 61.68407194076046, 61.000069418261134, 61.95721795482021, 53.7337923819019, 51.62169410336403, 49.946732213420255, 49.774810806397475, 46.151117355592795, 45.63172101974488, 47.9553174203442, 46.3322877114819, 48.0551064398981, 47.21906500477945, 50.42332372357769, 52.467914089079834, 52.22890054025958, 50.72244367291851, 50.58745138106808, 51.5883029660871, 57.927296392379276, 57.9921841621399, 59.198426738862075, 56.064382368518466, 55.390107324046475, 49.4476733669158, 46.38818540880757, 47.201767352319536, 57.128992080688484, 55.715169829706994, 58.332536066732104, 55.82874598041658, 53.12419722157141, 51.49065556064729, 52.55660672341624, 52.6794239782518, 50.93805243892055, 51.085164854603434, 50.43431812717069, 48.392398895755896, 44.81910005692513, 46.00317731980355, 48.754971027374275, 46.89424568606962, 48.05927984176144, 54.05469717517976, 52.23545874318769, 41.29739999771118, 46.66217081008419, 56.1727378445287, 63.13701198947046, 62.37432672131447, 61.14930383620724, 59.22675017387637, 57.40758626691757, 59.853466480009025, 61.26856350129651, 62.13059063880675, 55.229831434065304, 50.18637334146808, 51.30396250755557, 54.934276919211115, 57.82942933420981, 60.93670745049754, 65.04156589508057, 66.80918201323479, 64.88034471388787, 65.2762334577499, 59.34111472099059, 54.412393800673954, 53.09665041585123, 54.306654545568655, 55.02171047272221, 60.569287269346184, 55.568226075941524, 59.170028778814505, 55.63687147632722, 63.21493771768386, 63.194427644052816, 67.78134930518367, 67.54429694144957, 76.58001792046332, 66.21538223758822, 70.15977259605162, 70.78507684892224, 68.95906448364258, 75.26987568024667, 76.28100779748733, 67.9991114524103, 79.06745956790063, 75.43124198913574, 86.04933338780558, 73.44135299805673, 90.31825280958607, 6.789130020526148, 1.528675868626564, 77.28020021992346, 78.55102462153282, 63.305618993697635, 54.02054117571924, 66.31775609908566, 58.68887555214667, 63.79356968787409, 83.28770237584268, 26.7354065756644, 0.6109040675144042, 0.3657475660645193, 0.21389217746834602, 0.25542275379261664, 0.1845585482735788, 0.16650648306935065, 0.16408501703652645, 0.16030945995401952], [0.06977058436361051, 0.01709409332233331, 0.04503219951725295, 0.048362180710800236, 0.0260947703293735, 0.07666868518196768, 0.019782755501388062, 0.034160504057522745, 0.07371213737755053, 0.11781380436713658, 3.539535321535603, 53.787254287350564, 46.222932031077725, 42.737870831643384, 27.213159107392837, 29.459824100617443, 30.353720495777747, 48.31211190069876, 56.373237640626975, 44.56260842661704, 1.0191940588335837, 0.2554899090600591, 0.24018724148552265, 14.220575613360252, 64.8425526772776, 65.05703572304019, 70.76459423188241, 61.37991566811839, 65.6125610105453, 61.67566630148119, 63.490095907642, 62.366827149544996, 67.19652391249134, 62.26074664823471, 63.73515775126796, 58.68656919848535, 59.179850393725985, 61.22082433392925, 64.10182483734624, 63.18480607002013, 59.10902415552447, 60.514425077746, 53.85422483567269, 50.39321168776482, 45.3379511833191, 46.81002063135947, 55.128120453126975, 57.990446552153564, 65.09654575778593, 63.159451869226274, 56.57924836681735, 62.50791088227303, 54.50047846763365, 50.883888429211034, 45.55506221709713, 48.76178810673375, 45.59506254811441, 46.743214822584584, 57.46230333082138, 53.395048649080344, 52.39120429561984, 55.6558322137402, 54.85851633933283, 57.85852939851823, 58.62556849756549, 59.14117974619712, 57.39994156745173, 52.38623465261152, 47.28502750396729, 45.2211743785489, 40.069764814069195, 44.06172960035263, 41.72488735568139, 46.55327012462001, 50.41164682757471, 41.541296897395966, 44.67274858105568, 41.66757368272351, 39.57263577368952, 41.29973773033389, 41.778431630903675, 41.0657448153342, 45.035277566602154, 50.384821737966234, 54.30512089883128, 54.662946962541156, 51.877197296388694, 50.11533529527726, 54.155345193801395, 50.98219087046962, 53.43924199381183, 53.2992486799917, 52.642949858019435, 50.94136684171615, 49.251362662161554, 40.694535624596384, 41.37646713564473, 45.67564764330464, 42.52181883781187, 40.53827624167166, 42.80102491378785, 42.76410364335583, 43.19858066497311, 39.363271421001805, 42.492036281093476, 40.65347233126241, 36.74593264056791, 53.1700183499244, 38.405024620794485, 29.140696141027636, 37.66153150989164, 46.41628134635187, 56.557098742454286, 53.59298321508593, 56.559044238059755, 55.40321588516236, 55.17906027455484, 54.757350567848455, 53.16043207722326, 55.2309649990451, 55.88050165484029, 45.85884978694301, 44.1665235642464, 47.105551611992624, 50.014444089704945, 54.06229480620354, 55.29002020435949, 60.53852412008471, 58.14246193055184, 57.59839780869023, 63.971107928983635, 57.05631056139546, 51.646428569670654, 46.2062031222928, 47.59475746462422, 47.93685090157294, 50.87077202335481, 50.15097395066292, 51.569754077542214, 52.31871889483545, 55.88443579212312, 60.14307860405215, 64.6632807485519, 63.267823034717196, 67.69043660932972, 60.97867681134132, 65.07425885046682, 54.29800179696853, 62.37869231931625, 67.76942529985982, 67.00958375007876, 64.73261256371775, 66.06584579713883, 69.1145315477925, 73.194839877467, 76.25453179882419, 56.93711365422895, 0.9942029837158419, 10.002317524725392, 70.98053639934909, 57.95512560875186, 39.2043879724318, 20.543084298410726, 35.705061112680745, 35.81516596578783, 43.72370758364278, 54.99607778364613, 31.03238271128747, 0.25312882607742665, 0.011929541266703559, 0.06754279301892366, 0.006630877859049267, 0.04257132592160375, 0.046558055140438585, 0.06328075478274016, 0.04407605667027735, 0.01989772997706408, 0.05826675911403953, 0.028668638063414444, 0.02930075636193637, 0.02535726131510831, 0.05689396402768551, 0.06574738169870069, 0.04288641788486031, 0.03248185219783937, 0.1261481131997801, 8.28473025752652, 67.05202379534322, 54.80454452576176, 51.905524653773156, 23.632356774422433, 37.74122230468258, 37.32647088266189, 55.70059430214667, 56.97910654929377, 53.4850238984631, 1.502873537040526, 0.35734416376198497, 0.37443757718128545, 12.843377513270225, 63.81848850557881, 68.96070403437461, 74.74089699406778, 65.16080594831898, 68.02865474454819, 67.15486834126135, 68.05313817916378, 64.07750614227788, 70.35100383143272, 63.24444570849019, 65.53655724371633, 58.08537183269378, 60.736250800471154, 63.15590212422033, 65.05745541664862, 66.30821689482659, 63.67586328137306, 63.77511493621334, 59.20614204099102, 52.866050351050596, 48.3005016849887, 49.29157480116814, 56.89400288366503, 60.18322014039563, 67.22600444670647, 64.309027964069, 59.049600247413885, 65.08351564407349, 59.01724461586245, 53.298315155890684, 47.43339507810531, 51.55886165557369, 45.167453596668864, 51.82759108081941, 58.72497312484249, 56.612157052563084, 54.24998414131903, 59.12068536204677, 58.15283659965762, 58.63476645561957, 62.58962954244306, 61.88629757973456, 58.38258158776068, 54.53677608120827, 50.49798211743755, 48.620833812221406, 42.87410259246827, 44.910742313631125, 44.10929226106213, 47.05264276073825, 50.61265653179538, 43.5639847478559, 46.64335912273776, 44.39609204569171, 42.99838681374827, 44.09342235134494, 45.48132558022776, 46.45708184088431, 48.96412749444285, 55.53696086329799, 57.39328138289913, 56.670898468263694, 53.02075647538709, 52.97267213944466, 55.86865217454972, 50.826743418170565, 52.89919830137684, 55.31296999223771, 55.930621700902144, 53.91820653792351, 51.89227488733108, 45.76880001252698, 46.8367672735645, 47.95596068905246, 45.488711403262236, 43.26190733140515, 43.709234037706935, 44.58557390397595, 44.02577715535318, 41.18146650252804, 46.09449401978524, 41.81429386138916, 38.86398115465718, 51.40057440726988, 40.797486074509166, 36.2380249269547, 43.0411720275879, 49.07618568789575, 58.743706364785474, 57.78629110705469, 57.69153448843188, 58.760317602465236, 57.85715656895792, 58.137476598062825, 56.735684256399836, 58.663136959075935, 58.38502914674821, 48.34962937139696, 46.95487768419328, 48.63999459051317, 52.47500181198121, 55.82604738973803, 58.72766779315088, 60.93172996274887, 59.47987248820644, 61.28509236920265, 67.1520128557759, 57.447111991144, 54.62539811288157, 49.255053612493704, 51.02616064010128, 50.48422636524324, 53.83289890904581, 52.533735382941465, 55.49335195172218, 55.78844362689603, 60.97952012092837, 64.45433608947262, 70.33167439122354, 65.89477554444345, 71.29654607465191, 62.170379161834724, 72.36173629760742, 68.46119803767051, 64.46982945165327, 71.23604743711411, 68.49230243313697, 69.63262173437303, 69.48971409951487, 75.13566786243071, 78.00988658781975, 81.83250304191344, 55.57048928353095, 0.8569963913290732, 13.006162739569142, 77.49308293865573, 65.99459202058854, 46.74688616106587, 23.123927385576312, 46.6987665237919, 33.81758128443072, 53.993312081983014, 62.581176834721724, 43.46754543242916, 0.34780112906329097, 0.0069434824305766776, 0.04228390888461182, 0.02935764413597363, 0.024065349791799823, 0.022714424600464203, 0.014586043074697018, 0.008096502692018065, 0.17157490545463178, 0.15276240605500438, 0.1278784606725939, 0.14522232355610018, 0.13631451364246108, 0.1404043659567833, 0.206218826314134, 0.17102546719533784, 0.1687828980145916, 0.29996316699731734, 11.277609505961019, 80.57405764056791, 60.62700886880199, 56.98056567099787, 39.22760840385191, 45.20961907602126, 42.43366356818907, 63.20298625576881, 71.22082079610517, 59.892815697577696, 1.61955755324133, 0.4398869200339241, 0.7677573830850664, 19.109797285449122, 70.94627057352375, 70.4832975326046, 75.0933611777521, 68.5106905045048, 72.9264634655368, 68.8459119489116, 70.53151915150305, 68.65721456466183, 70.82731293093774, 66.70888700792867, 68.70832304800712, 61.86071980384089, 64.12493544240152, 64.67897022924116, 67.02152344488329, 69.83623197001796, 64.60205255016204, 67.74400049640288, 61.03377434515185, 56.226513539591146, 50.362142593629905, 51.239463052442, 56.9831112892397, 63.159804882541785, 67.41812213774651, 68.30125947152415, 61.78896788627871, 67.19308791622039, 61.21150478239983, 55.77302871211883, 50.51207127109651, 54.558062784133426, 48.80342014374272, 52.98592190588675, 63.71770712637133, 59.664635735173384, 58.68261544935165, 63.05342235872823, 59.537233229606386, 62.32701901466616, 64.79074993441182, 66.74483945292812, 60.91025890842561, 55.23365182261313, 53.75894261944679, 51.617775655561886, 45.42225860780286, 48.40033385061449, 46.857912771163456, 48.71613564029817, 54.048342935500614, 47.278873305166925, 51.50355623614404, 47.74510975806944, 45.66467285156251, 49.14616861651021, 50.80768069913311, 51.55943432161885, 55.11585127922797, 59.01281233756774, 59.56254428432834, 61.458519966371604, 56.41759964727587, 55.73737828962265, 58.01198820913992, 54.792844095537745, 57.51327060884046, 59.76846871837493, 58.392489494815955, 55.10424106351791, 55.256272131396884, 49.58763922414472, 50.53086726896225, 54.51956079852197, 51.86759141183669, 47.94203627494074, 49.97199619970014, 47.027084596695445, 48.860945624689904, 43.4397985858302, 48.23438621336415, 45.119141763256444, 40.67626522433373, 54.37373492025561, 53.625534965145974, 42.37655385848015, 46.81247603508734, 53.6555685535554, 62.29642844969227, 59.12897333022087, 61.753344920373735, 62.495990799319365, 60.7467431406821, 62.80730147515575, 58.216704553173436, 59.58641190682689, 61.31771864429597, 51.11617511318576, 48.85093573601016, 51.4509690192438, 55.82576105671545, 58.35525835714033, 59.114797884418124, 63.81933181516586, 62.63197937319356, 65.3327077434909, 69.12268223301058, 60.11940710006222, 58.032823839495265, 52.664256172795454, 52.9460863144167, 53.87625286656042, 57.34607565787531, 54.70217850900466, 57.261077896241225, 59.37148171086466, 63.49457525437879, 67.24151349836781, 71.37573872843097, 69.4534400201613, 74.93866289815595, 67.0402253058649, 71.4589165103051, 58.974773191636615, 71.07413984114125, 72.91401386260986, 73.95141801526471, 71.9009127155427, 74.57158396320959, 75.98183293496409, 83.00085160040086, 81.23248238717356, 68.89857369084513, 0.9217762959099586, 11.56457010776766, 89.11272018186509, 72.65912255933209, 56.98850847059681, 31.391905200096872, 51.32724569689844, 47.748463384566776, 60.49993976469963, 72.76122969965782, 52.504568638340125, 0.6072005533402967, 0.22071397592944486, 0.19842996442269897, 0.23270076981955962, 0.18392015188451738, 0.17747804192045044, 0.24652298780218249, 0.1011045993636212], [0.06787081654634207, 0.02014250272975093, 0.028124300034476385, 0.09009796134646862, 0.07357499997822509, 0.057942213625797344, 0.036477594441103364, 0.0009827803226090186, 0.08269044270198192, 0.20526693142469854, 11.575460568551096, 62.09609339314123, 45.35645300342191, 41.19824247975504, 60.94809409110778, 71.73064262636247, 29.639260768890384, 47.812111685352946, 56.76221516824538, 61.921783262683505, 6.026230002603223, 0.7426444693438469, 0.13147266942166513, 2.2975606879880353, 28.008543214490338, 61.067106646876184, 66.18707841442478, 61.82883485671013, 61.94734534909649, 63.64475104116625, 66.44732767535795, 61.58623233918221, 67.19580219637963, 66.8997573852539, 55.33624141447006, 56.94143218378867, 58.85226972641484, 62.48567888813635, 61.468502398460146, 62.76525758927869, 63.213164806365974, 58.41506273515763, 53.954135448701926, 47.54201335291709, 44.03051930089151, 48.586481694252264, 59.11143249081027, 60.31069324862573, 61.708669124111054, 54.07113582857194, 61.21480349571475, 61.27679263391803, 54.493441735544515, 49.428645949209894, 47.24454079904864, 48.607427150972434, 47.96775917853079, 45.214271007045625, 53.56695828899261, 58.80192218288299, 56.293366416808105, 56.34498873064595, 57.87852956402687, 55.96359314457063, 57.30536145548667, 57.236692520879934, 55.073266106267134, 56.898415550108886, 52.946525619876006, 44.84862373721215, 42.29799270629883, 43.43022015786941, 42.01225196161578, 38.12306896332772, 44.22927364226311, 47.576926369820875, 41.688558363145404, 41.26222418200585, 44.362920561144435, 42.785237373844275, 41.23352419945502, 39.83974918242424, 44.83728416504399, 53.10609940559634, 54.93462208778628, 52.64953159516858, 52.66490728624406, 51.403327911130845, 50.067172511931396, 54.432825426901545, 49.75107262211461, 47.010755769668094, 50.462586649002574, 52.26004415942777, 51.48441506970314, 42.99658252346901, 44.26033096928751, 42.018841543505275, 41.64451799085064, 39.262148795589326, 43.940198882933586, 42.31924410789244, 45.55443856023973, 40.79597988436299, 38.67534652833016, 34.1938817116522, 46.16353557955834, 44.476363351268155, 26.335232642389116, 39.34147873232442, 46.785584265185946, 55.36210944575649, 54.42500422077795, 59.0717145704454, 55.04546042411558, 56.99569817512267, 54.47471241797171, 55.458015318839784, 54.14895957516086, 56.01952222085769, 51.6372266892464, 45.5879944370639, 44.98909558019331, 46.96140058578984, 51.380221228445734, 54.613207386386016, 58.219893440123535, 61.732979974439075, 56.67832743737006, 58.679665826982074, 62.77229432136782, 59.3581574193893, 53.66185219057145, 48.440287113189704, 48.82005099327334, 47.988720324731645, 51.160399836878625, 50.46627367696455, 52.149951073431204, 49.45802842417071, 56.532270139263524, 63.07301067536878, 64.41117825046663, 66.64166542791551, 61.09938383102418, 57.404311087823686, 63.78397949280278, 48.16242248781266, 66.0642219358875, 67.15711193699991, 67.18085012128277, 69.42241407209828, 66.6956215520059, 72.63607471219956, 71.58169454143894, 81.76827815271194, 21.44189150102677, 0.9744111328355729, 26.023765071745842, 72.7943580381332, 49.56261842481552, 39.70932252945439, 40.94399444518551, 45.34902011194537, 26.83072409322185, 34.93802985837383, 61.275243297699966, 36.136859155470326, 0.7604355437140312, 0.09374936621996666, 0.07535492866149834, 0.12476581479272536, 0.02189652040420521, 0.09501668249046612, 0.028326530009508136, 0.03014778339063689, 0.04383783013890347, 0.02538692232431664, 0.020490115125393196, 0.06225822275624641, 0.08021373406893785, 0.00820563574727144, 0.05424609603059869, 0.10534661206146402, 0.10150728582014, 0.23197402817107018, 16.747304701036025, 72.02911930699503, 55.865118119024466, 37.20397526218046, 43.78943866299045, 76.89871834170434, 36.347619871939386, 57.056357629837535, 58.91614552467101, 67.94542989423199, 8.364510286238886, 1.150446248150641, 0.19718808993216486, 2.594391198888902, 28.87821112909625, 63.735118527566236, 71.23729475082891, 66.79325719033518, 66.41546234007805, 66.94777504090341, 67.9665400904994, 65.88959801581599, 70.93544483184814, 66.54161360956007, 57.79150001464352, 58.781980852926935, 62.987459859540394, 65.77093847336309, 64.26916099363758, 65.50046751576086, 63.78490909453362, 61.48420364625993, 55.0455859399611, 47.99701613764609, 48.45322701238817, 53.25934640822872, 61.959936157349624, 63.639773553417584, 63.174301962698664, 57.458275056654415, 62.70517864534932, 61.18457771116688, 58.291884622266224, 52.43208323755572, 50.48551682502993, 50.589224292385964, 48.783941653467, 46.702975226986794, 54.94277277300435, 60.92960796048565, 58.62265417652746, 60.33187796992641, 61.11262967509609, 59.765240607723115, 59.6811685254497, 60.7800244515942, 59.33920452671667, 58.76220034014795, 53.7183343210528, 48.332786713877034, 44.48176837736561, 44.21436863560831, 43.486364964515936, 39.08453210707634, 45.18502581504084, 46.38816971932688, 45.028515400425086, 44.91733974026096, 45.836896281088556, 46.865173078352406, 44.91904597128592, 43.0913979776444, 49.02730118843817, 53.99939960049045, 57.042468517057365, 55.5086374282837, 54.55873350943289, 53.78707385832264, 50.73860776039862, 55.83439027109454, 53.2766205264676, 50.220074345988614, 53.32803887705649, 52.84927829619377, 54.48799356337517, 46.271232097379624, 46.72979639422509, 46.43707383063532, 44.33110621667678, 42.23658800125122, 46.06639415987077, 44.33606409257458, 47.35649701087706, 45.31860605362923, 41.46086085227228, 38.86745637462985, 46.60366473659393, 44.31818592932917, 34.06627132046607, 41.11867327843943, 49.478248242409, 56.877313198581824, 58.111086891543486, 62.24299792320498, 58.38042428416591, 58.976075418533824, 54.35450353930074, 57.737520356332105, 56.16777212389054, 59.37934214068998, 52.473479932354344, 49.05033726846018, 49.38826907065607, 50.44459081465199, 54.01976846879529, 57.53558889512093, 58.15619807089529, 64.29652344795966, 59.71628550560244, 61.29587888717652, 64.78052039300242, 64.55634909291422, 57.49329789992302, 51.57939918579594, 52.324269048629276, 50.91821701295915, 52.5318879465903, 53.60166734264743, 54.72339068689654, 52.92068112281061, 58.87307005543863, 67.92563761434248, 66.91805916447794, 68.9952052024103, 65.09133292782691, 59.141913229419345, 69.70666823848602, 64.30521149789134, 66.86910013998708, 72.308211634236, 69.68966084141886, 74.52960675762546, 69.20606397813367, 76.37233626457953, 73.04284018854942, 84.11202769125663, 19.2758822056555, 0.7334557656318911, 31.710523251564275, 83.80516498319565, 55.78510176750922, 51.237807812229285, 44.41054990214687, 45.71995081440095, 28.726825291110625, 44.19358007369503, 72.66229183443131, 44.94429034571494, 2.3228580144143876, 0.1358650805008027, 0.02646104654207105, 0.08420527431993716, 0.07117420299759797, 0.06209730215731168, 0.08155968160398545, 0.038674251972547466, 0.11560638330035633, 0.09785739013985281, 0.15200117512816383, 0.22576137686208372, 0.2411906787705037, 0.18234409451965364, 0.16060337724704898, 0.25633692651266055, 0.15757714608503928, 0.3719630212553086, 20.85813299302132, 89.12135724098452, 58.90056194797639, 56.03773770793792, 78.38282554380356, 90.81815104330741, 41.6749987294597, 65.6416924538151, 68.39427455779045, 76.85081835716002, 8.736576514859355, 2.869795027279085, 0.44427540874288934, 2.481502443552017, 35.58116912841797, 64.2417436261331, 71.61193601546749, 68.0461798944781, 69.05982232862904, 71.09670131437241, 72.33773139215285, 67.97644015281432, 74.5570868830527, 65.86461251781833, 58.07298498768961, 60.54813784937705, 63.569657264217255, 66.93237581560689, 68.03547966864802, 67.80091408760318, 68.00453216798844, 65.14373187095889, 57.95896560915055, 50.8624291419983, 50.419942640489154, 53.743927786427165, 65.50642951842278, 64.99221071120232, 63.86346632434476, 61.94983997652608, 66.63396973763743, 64.34975393356817, 59.9931420818452, 55.17934660757742, 51.56931869445309, 54.54288321156656, 53.40983990700015, 49.602222596445394, 58.63460563844251, 64.59987563471641, 60.924673618808875, 62.89469188259494, 63.3880829042004, 63.35309143989318, 62.858739437595496, 62.65112838437481, 60.37953868989022, 62.678369245221546, 57.41388167104414, 50.497527122497566, 47.553337235604566, 48.816995466909106, 47.20441495218585, 42.95197732986943, 47.975831416345414, 50.09163241232596, 48.53788745018744, 47.843204313708895, 50.44025659561158, 50.36056972319081, 49.78244766112297, 48.51296078774237, 53.83940219879151, 58.082551648539884, 62.45045992635912, 59.49987265371508, 60.18276906782582, 57.53348650470857, 56.38694632437922, 61.03466080081079, 57.95179943884573, 52.76439036092451, 56.699904395687966, 57.61420888285483, 56.44017288761755, 51.96026917426817, 51.373517897821245, 53.3459758758545, 48.25990123133506, 45.46172157410653, 51.859436804248446, 48.47975400186355, 51.90727403087001, 47.93725882807086, 43.19820803980674, 42.865112520033314, 50.6290049706736, 55.73979054727862, 40.415133430111794, 45.86350956270772, 51.53834373720231, 60.26967702373382, 60.35357259934949, 65.65444800161546, 60.862484439726806, 61.2222913003737, 58.27223747007309, 61.5327625889932, 58.47607912555818, 61.02362717351606, 54.3044658630125, 51.49063594879643, 49.719599523851954, 54.05703490780246, 56.4959607585784, 59.103474001730646, 59.338808367329264, 65.8779642658849, 62.754980979427216, 63.75197687456685, 66.45188546949818, 67.43407049486714, 58.25464171748008, 53.09844686139015, 54.56937097734021, 53.99316303191647, 56.77311151258407, 56.964315291373964, 57.67563319975331, 55.6023742306617, 60.63214325135755, 69.32489610487416, 69.930447301557, 72.82747853186824, 68.14852237701416, 63.58902592812816, 69.19716804258286, 57.72465498216691, 72.12406419938611, 76.50290412287559, 75.9756120558708, 78.89760524995866, 74.35027599334717, 78.74489953441005, 76.16027724358344, 87.4461913877918, 30.36073957720111, 1.0382413335384861, 32.889668133951005, 87.48106910336404, 63.89857938212734, 59.12928711983466, 55.14799118041993, 65.34553781632455, 38.68798440502536, 54.34928678697156, 78.30301315553727, 61.63579933104977, 2.7622985503365918, 0.3030144645562095, 0.3315781753870749, 0.22073934876149703, 0.25038091465830803, 0.32506924723425223, 0.18442993743285058, 0.1509009502948292], [0.08302226602550476, 0.05176657202443288, 0.06239249115629543, 0.05738411857295902, 0.06738353100034498, 0.016056004922927147, 0.046014814532452056, 0.022544651855564406, 0.06304907064223964, 0.04617909059649514, 19.5932823611844, 61.95785337878812, 40.26802493679909, 63.655157089233406, 82.72478734293293, 86.83827892426523, 39.504578728829664, 41.52421105292536, 59.20068602408133, 68.54844723978351, 24.340876071683823, 0.9509029587911022, 0.4951553833821128, 1.5329083511906287, 15.868185835499919, 49.00455144143874, 69.82117791329661, 61.900531861089895, 67.34995134415166, 61.58721293172529, 64.85280183053786, 63.17500798932968, 59.739784425304784, 64.3977637444773, 60.089267607658144, 62.94648285835021, 64.8021444197624, 61.296867324459946, 62.48458454685827, 59.91582039863833, 58.478350177887954, 55.25364022101126, 50.70545196533204, 44.63492124311386, 46.03184592339301, 54.78110836398218, 60.17163345890661, 57.999754336572465, 57.456294259717396, 53.92661609957295, 62.72597112963277, 59.23856043046521, 56.55391770024454, 51.451047466647246, 48.64721175163023, 45.64350381974251, 49.57333434012629, 47.60968600550006, 47.8921123473875, 54.75172196665118, 57.51332944439304, 56.959961460482695, 56.490567499591464, 56.567136087725245, 58.18328988167548, 56.94068301108576, 56.818481568367254, 55.33738674656038, 59.392395788623446, 48.35552861613613, 43.68541348365046, 39.49593382496988, 41.52143401484336, 35.670795286855395, 36.71721304616621, 48.049854386237364, 46.55956945111675, 44.49175080945415, 41.860601363643525, 44.75504382964104, 40.351194873932876, 42.724036632045625, 52.23786707847349, 54.89682612880584, 52.764096183161584, 53.44470193309169, 51.85026630278557, 55.0458408940223, 50.608102660025324, 47.56055439672163, 52.57199025923207, 49.89577278014153, 51.43152583029963, 51.80127589933334, 54.97372811840427, 45.642625208823915, 42.468537361391135, 43.56982907941265, 42.85543603281821, 41.70575403398083, 42.12039955200688, 44.292576774474114, 42.58820887534849, 40.12274426798667, 36.992218263687626, 36.074085543232584, 39.37509736707134, 33.00724706342144, 35.51683833522182, 48.52070354646253, 53.42828681392055, 54.874370559569336, 56.22889049591557, 57.72276047737368, 56.528539965229655, 56.8902099517084, 52.96281522320163, 58.50722274472637, 58.02807384921659, 53.49378255105788, 50.68558516040925, 47.83865436430901, 47.96929282526816, 47.334994577592425, 49.27850546375398, 52.94056361721408, 57.552396251309304, 59.79687452316285, 57.25319393219487, 55.92130607174289, 62.6606793557444, 60.91869200429609, 56.48294633434665, 53.35999050448018, 46.567069022886216, 46.875653651452836, 47.2139855354063, 49.07528354275612, 50.95365170509585, 51.12521225406278, 56.39406542624197, 63.79330688907255, 63.412574183556345, 66.45856134353146, 55.84958161077192, 59.25505791940997, 52.1115981378863, 45.23467125431184, 70.01196199847807, 63.17654163606706, 66.22048916355257, 64.67286309888287, 69.75776887709095, 68.79537613161149, 75.52709687140681, 64.64023682378954, 2.2925839356837736, 0.21432435830994961, 48.535510493863015, 66.54082913552561, 39.31776800463277, 19.212888940688103, 14.176894137936255, 48.37779591160436, 33.56718501737041, 36.161162161058, 52.08921317131289, 44.44948334847727, 3.0696184596707745, 0.023650639585309455, 0.06536376317061725, 0.09497015797082456, 0.03582433211587129, 0.03220887208778051, 0.03841915235464131, 0.010494437376638095, 0.06739136807981037, 0.06890649081117685, 0.09450334229416425, 0.05862812278792263, 0.04349811227932092, 0.1100999961096433, 0.04459672449757496, 0.020136423822071765, 0.010607841372069333, 0.04312104763342969, 26.589565007917344, 71.11437551436886, 46.24956100217758, 49.09498560813166, 79.72895945272138, 90.17312511321038, 44.42101478576661, 46.62705775230162, 63.810086788669715, 76.00511612430697, 27.877851801533854, 0.7912381005383308, 0.41167652895373685, 1.7990542828075349, 18.294640510312973, 50.49312230079405, 73.15921691156203, 65.5677910773985, 71.52165089884113, 66.17924936356084, 68.39084640625985, 65.98880260221421, 62.196443311629764, 65.1698862352679, 61.280558109283454, 64.8029524280179, 67.44112291643697, 63.82379155005179, 65.52803001096173, 63.5326575463818, 62.30527339443084, 56.65499717958512, 51.8356829304849, 47.02513910108998, 48.973545105226584, 57.31031933138448, 63.853228938195016, 60.73251670406711, 58.746663831895404, 57.20544299771709, 64.53913381022792, 60.981583287639005, 57.415846778500466, 53.50154099925872, 50.67820718211513, 49.459503235355506, 51.05632366672639, 49.96094688292473, 48.46443322397048, 54.60915557799801, 58.80495417502619, 60.90327316714872, 59.266083701964355, 57.696551199882265, 58.91437653572329, 59.43328257529967, 60.5256312893283, 57.81215521597094, 61.0929903676433, 52.299577728394546, 46.3311541465021, 43.97440979557653, 43.280307169883486, 38.1141887172576, 39.08726599908645, 49.65996380775206, 48.76153707504273, 45.8877262761516, 43.138517410524436, 45.01816426554034, 45.4187951549407, 45.97484211767874, 54.161868095397956, 57.544814309766224, 54.14902625545379, 54.683951254813906, 54.61075982739849, 54.97282597326464, 53.26129582620437, 49.34906498078377, 53.1115593448762, 51.54075207248811, 54.127355160251746, 52.86945104599, 55.64456324423514, 48.65335418332008, 44.11857651126, 46.46836257749989, 44.854334708183046, 42.560709138070386, 44.83179284680275, 45.749898110666585, 45.1169373912196, 41.291112438324966, 39.69739852413055, 38.73669239782518, 41.35143456920501, 38.53752620758549, 41.29025343925723, 49.84098903594479, 56.36509872251942, 59.607529947834635, 60.07615120180192, 60.1572540498549, 57.88483281289378, 58.008524756277765, 57.36303206413024, 61.31226262738628, 57.77524179027927, 55.35537473617062, 52.65683504842943, 50.599469523276056, 51.42560305133943, 49.89340366855745, 52.04777333044237, 55.44320444906912, 60.696670163062315, 62.951695688309215, 60.00731360527777, 58.997683755813114, 63.4155277282961, 63.402423089550396, 59.58560782094156, 55.966856556554, 49.68300381014424, 51.18761324113416, 49.411462045484974, 52.474778236881384, 51.46048861165201, 54.256146184859745, 58.609459323267785, 64.89554782067576, 67.04640696125647, 69.0526443912137, 57.51523179392661, 63.65294095008605, 57.4355370767655, 60.13846589672951, 71.4308637188327, 70.55246460822322, 68.98763502797773, 72.19167801641649, 71.13467770238077, 74.67365972457394, 79.27489803683373, 63.765159960716005, 1.5096517604204918, 0.3764678633982136, 57.472842739474395, 73.55350925076392, 46.394723999884825, 27.699415337654855, 14.023494162867147, 54.72073916466006, 33.14019972278226, 43.94558037481001, 62.331227717861054, 59.900503543115434, 7.363285095460954, 0.15713928087103754, 0.14377214975895422, 0.11611573983945193, 0.05996352512269251, 0.014933394042835122, 0.029250587178995053, 0.040624692675567446, 0.195379524882282, 0.16053196253074756, 0.23777202673016057, 0.18952394715480267, 0.0847338596659322, 0.15999936288402927, 0.15327101182793418, 0.14629034205309807, 0.16840774475807146, 0.14279354904447833, 33.23833742449361, 85.55122375488283, 54.85007932109218, 86.31294804234659, 93.13093739171183, 95.40907352201401, 53.978403152958045, 55.32545489649619, 69.30779457092285, 82.9865506387526, 30.658800486595403, 1.7913115240873831, 0.820413180176289, 1.6781638923191255, 19.553842929101762, 52.292446859421275, 73.43144509100145, 67.29164923391035, 74.3107855704523, 67.98416722205378, 71.83915107480942, 68.60963621447164, 66.08455550286078, 68.10924376210859, 62.371839938625214, 67.54812517473775, 71.76718342688777, 66.30860913184382, 69.29943992245582, 64.87875615396808, 64.48185936097177, 60.29215612719136, 58.60338357187087, 50.467513145939, 51.47993572296635, 58.02605775094802, 66.07602042536583, 60.40760717084331, 59.96802714563186, 61.9508715598814, 66.29458273610761, 64.1663948951229, 61.27356060089604, 56.19344795903852, 53.45948926864132, 51.57200551802113, 54.129316345337905, 51.58554946222613, 52.57938784937705, 60.43943720479166, 63.3177234280494, 62.98896997205673, 61.43950823814639, 62.62058096547281, 62.549778261492335, 62.04752268329744, 62.26691261414559, 61.015794200281945, 64.70654056918237, 56.34057998657227, 50.75581519834457, 45.80711764674033, 45.90906789225917, 40.99019996581539, 43.03203682745657, 52.25135610949609, 52.2631428318639, 46.767227572779504, 46.4487938727102, 49.7540497010754, 49.821130075762355, 50.005191218468454, 58.03801705760341, 62.40819638775241, 58.052722023379424, 57.209059423015965, 58.168655518562566, 60.595351419141224, 55.669403614536414, 51.79220345712478, 56.11594584680373, 53.960670117409, 56.95697261441139, 54.966828669271166, 59.415573073971665, 52.36498325101791, 50.43255698296332, 50.18705975624823, 51.056245219322946, 47.12613228828677, 47.60550868126654, 49.83952599187052, 48.86273030311831, 43.44029280447191, 43.925760638329294, 42.322013301234094, 45.368981053752286, 45.31449148731847, 44.58171036935622, 56.22589380510392, 61.51290755118094, 60.43500884886711, 61.48406244093373, 63.659863933440185, 60.5410893501774, 60.49862184832173, 58.574660055099, 64.24312822280392, 62.79091381257581, 59.30998679130309, 55.01368922571982, 53.71343135833741, 52.82963898874099, 51.821750671632834, 55.5438171663592, 58.50674029319518, 62.82785861722885, 65.56058176102178, 63.967385599690104, 62.029162068520826, 66.75280186437791, 62.993947459805405, 61.304590471329234, 58.14749040911275, 52.981630832918235, 52.96939303798061, 50.632558638049716, 53.51539481070734, 54.73218856319305, 56.86807993919619, 60.94839611361104, 68.37354875379994, 69.7537680595152, 72.31782144115817, 58.654366539370635, 67.34534648156935, 56.30273303677959, 55.692863310537035, 74.2611675877725, 73.07145780132663, 73.35377431684925, 73.06762956803846, 75.56703444450133, 80.00958150432956, 81.8172764009045, 74.73102831071424, 4.392963397887446, 0.17974644358600342, 66.38420104980469, 77.63565324967908, 56.493650482546904, 32.07349546494023, 21.21931072204344, 75.59747988177885, 44.95127608699184, 54.13429775545674, 69.58458054450251, 72.72829747969105, 10.440485496674816, 0.3662343383316071, 0.30860212601480946, 0.28308128577566916, 0.10008523511069436, 0.11953226215536557, 0.13525688329771643, 0.1462541214160381], [0.05209349238524034, 0.04349967126824683, 0.042996883933101936, 0.07862019457764204, 0.025508563680153702, 0.025931505501390468, 0.02147580406838848, 0.01412249189020405, 0.027656059434276917, 0.11015450326545585, 31.20939535479392, 63.59323070895288, 40.16367027836461, 49.127133354063965, 77.53211836661063, 83.29446454201975, 36.50373804953791, 29.714991930992376, 65.93375605921592, 63.56498179897186, 64.0349405811679, 0.9898570588519497, 0.31083036935137165, 1.4564156364048682, 15.858342647552492, 38.82433775932559, 60.06647471458682, 67.0687880054597, 59.946658072933076, 61.47841030551542, 59.33280714096562, 59.425092666379875, 59.411313379964525, 59.85394500917005, 66.04043668316257, 64.87890520403462, 66.13590717315674, 63.217993244048095, 61.04502370280605, 57.83729760877548, 52.79073692137196, 48.91729831695557, 41.91753456669469, 46.66712476361183, 49.616178389518495, 57.691718839829974, 61.62342033078594, 57.32825240781231, 52.02997753697058, 53.820731716771284, 62.17379162388464, 59.38302524628178, 57.10013128096058, 51.000374978588475, 48.61510715176983, 50.50009235259026, 49.227451893591116, 52.13605019354051, 49.40454690687118, 49.14459966844129, 51.168487764173946, 54.20247247142177, 56.293456631322066, 57.02750467484998, 57.23288782181279, 56.83934073294363, 56.88769963479812, 56.843474911105254, 56.853673073553274, 57.899933938057195, 50.23619136502666, 42.6685429388477, 39.670236110687256, 39.218382989206624, 41.885563327420144, 43.16038070186492, 47.90294593380344, 48.76241176359115, 48.58098645364085, 43.292023289588194, 44.852714769301876, 51.13475145832185, 57.942507343907515, 56.54575132554578, 53.149108194535785, 52.18003565265287, 53.91280543419623, 55.44872322390157, 49.63974398951377, 43.384779499423125, 51.15473985671998, 53.514975117098906, 53.947310524602095, 52.93349942853374, 53.961540883587254, 54.67174483883766, 46.47670153648623, 45.409216726979906, 46.86363550924486, 44.504086663646085, 45.13543921132242, 44.382049960474816, 42.574774757508315, 37.36691836387881, 37.655726402036606, 36.776229027778875, 37.5706462706289, 34.81817791538854, 40.331802675800944, 54.17341947555543, 55.45452440938642, 55.222520136064105, 58.19175043413716, 55.783285710119436, 54.936736245309156, 54.659867901955884, 55.266576197839555, 54.0735637757086, 45.389965734174176, 47.34907196414086, 51.45446385106733, 49.84602535924604, 50.08328168622909, 48.06282566439722, 51.06310544475433, 53.986495002623535, 58.55548750969672, 59.437306927096465, 58.17469596862794, 55.467554523098855, 59.77906696258053, 62.073092614450765, 59.64704782732072, 54.27843701454901, 49.605909624407374, 50.55441325710666, 48.01545519982615, 50.159901265175115, 50.15319401218046, 53.32874098131734, 56.81792851417296, 59.15113472169446, 62.18118529165945, 66.8310139256139, 56.20255962494881, 59.5371743940538, 46.41859162238337, 38.42304398936611, 70.59785427585726, 64.9958545930924, 69.22416963884908, 66.26354894330426, 69.35847943828952, 72.76850961869764, 84.33246489494078, 19.9741994180987, 0.6478797608325559, 4.433183381634374, 57.39952187384329, 50.672727630984404, 30.656235256502708, 18.1212442921054, 42.19404597436228, 47.68973373597669, 42.90332425025202, 36.56665286710186, 55.0861785488744, 58.545728652708, 9.129965728329076, 0.20690626765210784, 0.04088124019965049, 0.15646775884013023, 0.0535538130169434, 0.03839661404790898, 0.009691560952623766, 0.030543850847489895, 0.013511540601029994, 0.02871476038689575, 0.0242826180727852, 0.01874241001543499, 0.1473835648428048, 0.02259999787765405, 0.025256271774490035, 0.0516320048500934, 0.048253200873131716, 0.038072394147034616, 42.357879454089755, 70.88927069017964, 50.76126729288409, 58.43729472929432, 85.57958249122866, 88.18290664303689, 44.17123040845318, 35.44037172871251, 73.72595233301963, 67.72416114807129, 72.24073902253183, 1.2893112676758922, 0.15801634429202926, 1.6940643229792196, 14.702241689928117, 39.830402174303615, 62.40724717417071, 70.48867902448102, 63.745885433689246, 64.93037454543575, 61.10977026724047, 62.454060662177305, 62.65258358370874, 63.22515549198274, 68.88481401628064, 68.08025744653517, 68.83634136569115, 65.10986220452094, 63.47486926663307, 62.70076990127564, 54.687034237769346, 51.21022962754773, 44.88941246463407, 50.11699838023032, 51.199297981877486, 60.297137537310206, 62.632987422327844, 59.60568643385365, 56.02870448943108, 59.875612182001916, 63.34344240926928, 61.02914987071868, 59.74441674447829, 50.96230053132581, 51.397209013662035, 52.41917471731863, 53.26877578612297, 52.64546801967006, 50.00917634656353, 51.41057645120929, 50.59100897081437, 56.53894209092664, 59.78600955778553, 58.87252484598468, 56.73511551272485, 59.87367845350697, 58.216704553173436, 59.20816598399993, 59.34651190234769, 61.612978981387236, 53.455755172237275, 47.42926089994369, 41.49018056931035, 43.534716021630075, 44.20579041204145, 45.16323704873362, 48.16049660405805, 49.62072049417804, 48.46910476684571, 44.86192449446648, 48.86138493014921, 52.681279259343306, 60.173233785936915, 58.83308149153187, 53.940465988651404, 54.992469203087595, 56.20903545810331, 57.136581866971916, 48.6068505625571, 44.72442973044611, 54.97669735262471, 56.376304934101725, 55.472669293803555, 56.59734618279242, 54.74095506052817, 57.363934209269864, 47.470116307658536, 46.76947116851807, 49.17546872169741, 47.42722126745409, 46.82212506571124, 46.95556017660326, 45.3701695319145, 40.406057065533055, 38.91573290671072, 41.399652265733295, 40.44213502637802, 37.99848271954445, 44.91268388686642, 57.256374974404615, 56.11197640818935, 57.74744787523824, 60.64172952405868, 59.202133378674915, 58.500013428349654, 55.131525070436545, 56.3532845435604, 56.14246499153876, 48.0531217205909, 50.62698495003485, 53.627280419872655, 50.5978338949142, 51.56653773400092, 49.39596868330433, 54.421054394014426, 57.02310769788681, 59.74888432410456, 62.226021905099195, 61.69160289149131, 58.10234785079957, 62.55463023339549, 65.26656873764531, 62.29267474143737, 56.362811980708955, 53.53333180950534, 52.49538244739656, 49.97156866135136, 52.5332764656313, 52.23438009139031, 53.93221332180885, 57.93999702699723, 64.15167816223638, 66.35146494834655, 69.31973426572739, 58.567717459894, 62.68704552804271, 53.09401066072526, 51.763844720778934, 73.04050245592671, 68.63575919981926, 71.43731209539598, 70.44483477069487, 72.90037185915055, 76.2385912864439, 81.78488546802153, 13.684554311536974, 0.7311999124865378, 6.507896079171089, 65.49191674878521, 54.22831696848716, 34.27129360937303, 19.018402138063987, 40.023782868539136, 68.76711937689012, 44.14517802576865, 48.293904258358864, 67.56652893558626, 66.93399967685824, 19.262822674166774, 0.20368393330324083, 0.08573622442781927, 0.06705743035361653, 0.04437991778456396, 0.053402135268815105, 0.019235083074759574, 0.06565412581567803, 0.2480576764191351, 0.16154535895874425, 0.2023718085500502, 0.17655899688120813, 0.33991940199367465, 0.12856899700578184, 0.11802606434831697, 0.11537105641177586, 0.19517330933482419, 0.260537279349181, 49.31533651967203, 83.88065491953205, 56.3751752914921, 65.8989175673454, 89.09107654325425, 92.28266208402573, 51.26746093073199, 43.196305690273164, 79.53993258937713, 72.72209229007845, 78.39114096856888, 1.6483938381556542, 1.1508556455373764, 2.745736832580259, 18.00457143014477, 42.81356080885857, 65.50002821030156, 71.0016465956165, 66.0515134565292, 66.76045833095428, 66.55825230383104, 65.49240312268658, 64.42121167336741, 66.62494044150075, 72.78506986556515, 71.45484509006624, 73.1980562210083, 67.84579384711482, 66.5171850881269, 64.74570151298278, 58.229401265421224, 54.28662692346881, 45.8071647151824, 52.77946402949672, 54.916375221744666, 61.76818324673561, 66.56521843325707, 60.082862377166755, 59.81507824313257, 61.19013178733088, 65.39385357210713, 63.916390865079826, 61.46150881244291, 54.044671597019324, 55.350385481311434, 57.04024845553983, 54.591563747775176, 55.514262107110795, 54.93923479510892, 54.8010536163084, 57.12992560478949, 58.14183827369445, 61.77850692502914, 61.91596246534779, 61.49457439299553, 63.14098535045501, 60.40180598535846, 61.73094426431964, 61.88075527068108, 64.54404069531348, 55.13505520359163, 50.331461814142045, 46.391386062868186, 45.86441563021752, 48.64880031155002, 47.07093669522194, 51.61663032347157, 53.974657289443485, 53.30819952872492, 48.45580008722121, 52.32182541201192, 57.547077517355646, 64.13320379872476, 60.3872343801683, 58.19920685983474, 59.91009766055692, 60.29176781254431, 61.054245195081165, 53.33927646760018, 45.42421194814867, 57.21655115004509, 58.65821438450968, 59.58775335742582, 60.94073964703468, 58.23384138845629, 61.72657474394768, 54.45827376457953, 50.92718355117306, 53.126127027696185, 51.73772958017165, 50.39501205567391, 50.47509508748209, 49.97876228824739, 43.31776188265893, 43.594940093255815, 44.81520514334402, 48.00036191940308, 44.943243072878936, 51.857052003183675, 61.4883731257531, 59.34311512977847, 61.16375777029223, 64.96016102452433, 61.004576221589126, 60.19228866023403, 58.572891066151286, 60.00350498384046, 60.30779069469821, 48.61290670210316, 55.554870405504786, 56.68068085947345, 54.24085286355788, 56.580079909293886, 52.84422628341183, 57.30262756347657, 57.97455703058551, 61.6832168640629, 66.4230089802896, 62.441167831420906, 58.745055660124756, 66.73952071897446, 67.91877346654093, 64.66554003377115, 58.9285009907138, 57.40284019900907, 56.06589248103481, 53.4515856927441, 55.11749475233017, 54.93291193439115, 58.00163315188501, 59.7822166258289, 66.6557232026131, 69.42712091630506, 72.51739163552561, 59.79721184699767, 64.84907950124433, 53.38075553217242, 45.538772613771506, 77.58768266247165, 70.94717271866338, 74.78276437328708, 71.97862271339663, 76.57160835881388, 76.95924051346319, 87.43589908845964, 26.26981339147014, 0.6509973709621738, 5.975375492726603, 74.30225049295734, 62.89173441548502, 46.509892632884366, 30.777136433509092, 53.901352113293065, 76.15417403559532, 54.57347769891062, 56.54341359292307, 74.33621037390925, 81.42891468540316, 26.414209565808697, 0.4407993613952591, 0.34438587845333163, 0.19926098595944144, 0.1708579084445392, 0.17032926181151023, 0.08050544502874536, 0.14296288511926128], [0.05629266544635739, 0.04489784301709264, 0.014094169619643401, 0.05987902562464437, 0.08860441931192914, 0.033161793535034505, 0.05764627769108742, 0.015525105033790874, 0.039450241583249265, 0.5222078172429916, 42.5226229236972, 61.680192716660045, 41.6082949023093, 24.275470549060454, 81.17050109371063, 58.61549585096298, 25.861526035493423, 28.080087246433383, 71.16746087228098, 54.44470236378332, 72.66799496066186, 15.683799136069515, 0.6802846671592805, 0.2495968083460485, 11.20314036646197, 34.41804124462989, 58.306934756617395, 65.6753424675234, 64.7828189019234, 59.96705047545895, 54.388451653142134, 61.168029231409875, 61.63081792093093, 65.54499426195699, 61.1666799360706, 65.98160113057783, 62.76515953002438, 60.157352109109205, 55.46969221484277, 52.140604065310576, 47.325584811549035, 45.6711055386451, 45.39812818650277, 47.3317821564213, 52.77492584720735, 59.785511416773645, 61.29077980595251, 57.073047314920736, 49.299568591579316, 59.25279078945037, 60.62592237226425, 63.596305847167976, 55.204626283337994, 50.09374264747866, 47.43810192231209, 51.13136645286314, 50.193433607778246, 49.7878840661818, 49.86574703647245, 51.882621934337, 43.56007806716427, 45.724171284706365, 50.29991419084611, 52.59139422447451, 56.752605361323205, 58.986273580981845, 58.31770950748075, 60.70516209448538, 56.413798870578894, 56.28175227872787, 56.114431811917214, 54.65226242619177, 45.888510750186065, 39.36064343298636, 39.05609884569722, 43.68966925528742, 42.777804482367735, 45.26323003153647, 41.83508242330244, 49.086650571515484, 52.162855671298125, 57.69193457018945, 57.67531941013952, 56.294672566075484, 50.73765462444675, 52.31908759763164, 61.2732546560226, 60.297121847829516, 45.110151690821496, 41.40095057026033, 49.33852949450093, 58.081904457461455, 57.73242519747827, 49.44075822830201, 52.805724297800374, 58.06424202457551, 52.222777720420595, 51.09692412038004, 46.683273161611254, 48.85950611483667, 47.03766322905018, 41.35199546813965, 39.882852108247825, 39.46528050207323, 41.2266835858745, 40.74358878597137, 35.77252195727441, 40.80955128515921, 51.08472554914413, 57.609635399233916, 52.836385465437374, 54.72408886878721, 59.53866489471928, 56.431790782559304, 53.10228686178885, 54.765156084491366, 50.366743533842026, 47.31992090902021, 43.93149514352122, 48.787577690616736, 50.79849058581937, 52.04826754908408, 50.315595826795025, 49.413168276509936, 50.168530479554214, 54.238287633465184, 59.35437625454318, 62.47967373940253, 60.357612640626975, 60.86272762667749, 56.22033188419958, 63.43391972203409, 62.624232692103234, 60.8025388563833, 50.67694417891964, 49.393238713664395, 45.623927270212484, 50.85259183760613, 48.06624989355765, 51.93465217467278, 51.08783598869078, 64.14020522948235, 59.65086429349838, 68.85744371721822, 59.02737609801754, 64.94170627286358, 42.51439771344585, 36.42340006366853, 66.9753336137341, 65.84088217827582, 62.44151692236624, 68.86810471934658, 63.23163916987758, 77.43761277967884, 38.33739511428341, 0.258402529382898, 0.3392111690294358, 12.466336738678718, 70.44339133847144, 62.09038634454051, 38.05598074390043, 17.448881403092418, 37.47765079621346, 35.0572189208, 40.17948527489939, 27.234473266909202, 47.05939315980481, 54.40358415726693, 28.19274948489282, 0.05695186878344225, 0.09270641411985121, 0.059944713833711805, 0.058690631732104294, 0.0786729856965042, 0.10215007955388677, 0.02633324392410296, 0.03277499957250492, 0.05950777941653806, 0.02033424113065966, 0.029156570953707543, 0.036479245360580184, 0.06997192759186992, 0.054070213734502756, 0.08102963303005503, 0.021403571553227883, 1.4056740172447697, 54.533430299451275, 69.56853805049774, 52.273301770610196, 37.04856311121295, 88.38091573407574, 66.36016476538875, 34.45030273929719, 34.42262649536133, 78.33251722397344, 60.24783334424419, 82.43685399332355, 18.27270269393921, 0.5903920326982776, 0.5549278002112144, 9.30140370322812, 37.49949055333292, 58.7540888786316, 68.82968118113857, 65.10743817975445, 61.975515811674065, 59.11803776218046, 64.60647306134625, 64.36406273995676, 68.55595465629332, 64.12304485997846, 66.10888204266949, 65.40913120392831, 62.42011254833591, 58.059652851473906, 53.789709691078436, 49.22935424312469, 50.128420322172104, 49.836286114108184, 49.34928071114325, 56.69551526346515, 62.72015033229705, 62.27052903944447, 59.17438653207595, 51.81188591064946, 61.06450219308177, 61.73350557204216, 63.006514733837506, 58.10541122190414, 51.355600510874105, 48.909292759433875, 53.24351572221326, 52.09447306971396, 50.98185746900497, 52.963058410152314, 54.334126826255556, 47.773193928503225, 49.090376823179184, 52.135791317109145, 53.622499050632605, 56.07290175653274, 60.626620554154925, 60.57749286774666, 61.015703985767985, 59.62028157326483, 58.93103484184512, 58.478973834745354, 58.22207427793934, 47.076063233037154, 41.41103106160318, 41.03828430175781, 47.246964823815134, 45.81291098748484, 47.13681290226598, 46.41546941572621, 49.11054957297541, 53.893574053241366, 58.63388784470097, 58.20856171269571, 59.55119686741983, 52.02158366480182, 54.0182936576105, 62.017575387031805, 61.456519557583725, 45.15804383062547, 41.76671943356914, 49.215578879079516, 58.63560192046627, 58.629569315141254, 52.511001325422725, 54.92937787886589, 58.663901821259536, 53.09728976218931, 52.67510544869208, 48.717783035770545, 49.94472788226221, 48.707992799820445, 44.7156750002215, 41.84683776670887, 43.3176677457748, 41.61937559804609, 43.73830664542414, 39.455121563326934, 44.525373366571245, 54.2694704763351, 60.53956354818037, 54.79358934587049, 59.10751012063796, 60.78899098980812, 58.62376420728622, 56.32166239523119, 56.39148450666859, 51.623161069808475, 48.78027423735588, 47.559260014564764, 50.66936615974673, 52.34294737538984, 54.04859004482147, 52.18608394745858, 52.06861288316789, 51.09154262850362, 56.36429463663409, 59.75226932956327, 65.2565117805235, 64.12784584106939, 62.514355336466146, 59.5983398345209, 66.35698764554917, 63.04432638229863, 62.997355999485144, 52.76511992177656, 53.104216667913626, 47.962067819410755, 52.867285897654874, 51.50856902522426, 56.15412227569088, 53.842516560708326, 67.20211721235707, 62.74552414494177, 70.39251035259616, 60.150484038937485, 68.54374824031707, 46.23301644479075, 43.9700363528344, 69.19455574404809, 67.66749074382167, 64.3781989620578, 74.77156208407494, 67.51636182108234, 77.95782104615243, 34.57205310944588, 0.631417144210108, 0.3380226908672241, 16.728714627604333, 77.40292333787488, 66.14451285331481, 42.738565091163885, 14.493742219863401, 37.369922899430804, 49.92547296708631, 40.41026576872795, 25.34424581835347, 63.351385208868216, 63.77397744886337, 41.67089985262963, 0.03849415619286799, 0.10793013633379053, 0.044530346809375676, 0.04261609226945908, 0.019894656049267902, 0.037966513135019815, 0.046115003511189454, 0.23073858881910003, 0.15405733979517414, 0.07920344795791373, 0.18221156130875313, 0.22213568189932456, 0.212437299891345, 0.2828107648078473, 0.1752258966406507, 0.08188326182144304, 1.6055483178746317, 63.58767271041871, 80.49708504830637, 57.57021165663197, 35.400022306749904, 91.55545465407833, 70.20640957740046, 42.38655198004938, 43.66995542280136, 85.81835285309823, 65.01638820094448, 88.80474352067517, 19.24364620639432, 0.9751365261693156, 1.7906776935823503, 11.691671571423932, 43.57139802748158, 62.021242803142925, 73.36177595200078, 68.73905089593703, 67.96270401247087, 61.74351153835174, 70.41999047802341, 69.54483908991661, 72.70810511804396, 66.32000753956457, 70.70836313309209, 70.12160008953464, 64.8699700447821, 61.57044872160881, 59.29253224403628, 52.207445175417014, 53.72377072611163, 53.72259793743011, 52.88267335584087, 58.68038754309378, 66.05306671511742, 63.621750262475786, 58.470007296531435, 55.64881509350192, 60.876448077540246, 67.70308233076527, 64.84889122747606, 60.65396731899631, 55.49753319832587, 52.88153194612073, 56.4535128685736, 56.031116747087054, 53.119392318110314, 55.86725973313855, 57.25179364604335, 49.752276789757516, 50.434063173109486, 55.62477096434563, 56.99774565235261, 60.9974531973562, 62.1432363602423, 63.18664173926077, 64.81193073334234, 61.42130451817667, 61.7607464328889, 61.36850157091695, 60.96969850601689, 52.93988896954445, 45.995179607022195, 45.0767566311744, 49.40961853150399, 50.060457414196385, 50.12727106771162, 48.574389027011016, 54.303375444104596, 57.50246447901572, 62.83525228500367, 62.66684924402545, 61.63754478577645, 54.614780256825114, 57.967535987977065, 66.58806231714064, 62.99279820534491, 45.44830314574703, 43.97477849837273, 48.79089209341234, 59.9542204026253, 62.43400950585643, 54.62291133019232, 59.95409488677979, 63.96762094190044, 57.28328635615688, 55.896155834198005, 53.96463171128304, 52.983093876992505, 51.37225489462576, 46.748094251078946, 45.540843625222486, 46.203681038272, 48.82838210751934, 46.37732044343026, 45.4892409232355, 52.38548547990861, 59.20292569744972, 62.448212408250384, 59.395945533629394, 63.19718899265413, 63.97912133124567, 62.5289700877282, 60.41351426032282, 60.86595181495913, 55.592580072341434, 51.133927760585664, 50.1999996554467, 54.37082059921757, 53.54180412907755, 56.45526224567045, 53.592139905498875, 54.14670421231178, 54.2214959667575, 58.0188915806432, 63.53516001855174, 69.22794295895484, 65.97683937318864, 63.77304000239219, 60.38557913995559, 67.90165624310895, 67.7319823541949, 63.14752394153226, 56.851747189798665, 55.20788185058102, 49.89707500703874, 57.477549583681174, 53.17975759506226, 56.921522232794, 57.461644372632435, 69.02937689135152, 66.7208267027332, 73.75279703447896, 63.62951655541698, 69.90321820782077, 48.96206040536204, 44.15098705599385, 71.01805779241747, 69.80277415244811, 69.90204934150943, 76.3475468850905, 70.50254852541032, 81.54729181720366, 47.88207892448672, 1.2863437494923993, 0.5988628200946317, 17.286626677359305, 85.76897021262877, 75.08731288294639, 55.687175873787176, 29.752760433381606, 48.170584940141254, 55.89903093153431, 53.58437361255769, 36.67968380835749, 66.17724895477295, 75.69397018801781, 51.87235709159605, 0.17475458402787486, 0.2929544737262111, 0.1345674960964149, 0.14825653735428088, 0.11702052798242339, 0.14168057650808366, 0.21885020658373835], [0.09134833941296225, 0.048547359483857314, 0.08108917338353011, 0.030079819900434346, 0.06758234613845426, 0.06941695051688342, 0.02239415771327913, 0.08281598153013377, 0.15705697238445282, 1.746350865690939, 54.379963644089244, 55.378183318722634, 43.14209068975141, 35.99729730236915, 48.288056004431944, 42.37924852678853, 30.56954303095418, 24.855436125109275, 66.87895313385995, 68.05504445106753, 65.80726746589907, 49.095813228238015, 0.21797384796363695, 0.13447377289975845, 3.911530947492969, 25.06834237806259, 50.688275906347464, 59.417353830029896, 53.95251943219093, 53.17175595991073, 58.030490029242735, 57.3184778613429, 60.06012831964801, 61.02123452771095, 61.905560339650805, 57.62536802599507, 54.14080496757261, 50.94960774144819, 50.74287137677593, 47.96621768705307, 47.79723805765952, 44.47690071598176, 46.27957890110631, 51.45180056172033, 56.99034806220763, 59.37900481685516, 60.322723157944225, 52.10032524601106, 60.46805481756888, 61.292823360812285, 61.19295589385494, 60.294729202024406, 54.892895913893184, 47.81887777390019, 46.58440982141803, 50.41178018816056, 52.05235073643347, 50.084685894750784, 50.69302589662614, 50.993832465141054, 44.790996274640484, 45.73310252158873, 45.86909894020327, 50.9404254728748, 52.67699995348531, 55.882035301577666, 58.884472385529556, 59.27258306933988, 56.47030453528128, 59.25643859371063, 54.28112383811705, 51.422453388091064, 52.49633558334843, 46.285423232663064, 43.115540166055005, 44.97422979724023, 41.729617734109205, 46.086578676777506, 45.970809921141594, 48.406488049414854, 54.413837232897365, 56.79292732669462, 56.66482663923695, 55.525064314565356, 49.074024461930804, 51.231426115958925, 62.862089141722656, 63.08286366924163, 43.787893249142556, 42.63692863525883, 46.37453163823774, 65.83564973646595, 61.685044688563195, 47.740626488962484, 51.7795616580594, 59.7830246340844, 56.3882956197185, 53.979917187844556, 53.89991652581, 47.07808325367589, 44.854142512044604, 43.60284366915303, 41.93454588613203, 38.94241286862282, 39.7643220040106, 40.94177830603815, 37.164045533826275, 47.8745440513857, 46.534478049124445, 54.11436427024103, 56.108669850134085, 52.02780454389511, 54.678887474921446, 53.34793706094065, 53.67816140574794, 49.92100930983021, 45.293906888654156, 43.67923967299923, 44.747014737898304, 52.7125640838377, 51.42571287770426, 51.30698273258825, 53.473668636814246, 49.898008531139745, 48.49873042875721, 54.3131656800547, 58.27086071814261, 58.259670196040986, 60.50201077615062, 60.760369454660726, 59.36599039262342, 62.110296295535186, 63.08653500772292, 61.52534538699735, 53.36489738956575, 50.40000523290327, 47.593521918019945, 49.286805199038604, 47.33489651833811, 50.824033060381495, 49.46019357250583, 57.413658095944314, 60.24551522347235, 63.904149147772024, 65.16930180211222, 66.58625802686139, 55.90544008439588, 32.04260876101832, 56.85446146995791, 65.58633996594337, 62.25724397167083, 69.49467197541269, 60.577202612353915, 56.83077035411712, 5.021819847245371, 0.13272260315716267, 0.05811640669802024, 30.5803648502596, 68.88606917473578, 61.07891298109486, 45.62481372587143, 16.122043594237297, 32.51644676731479, 35.57496786117554, 51.68324785847818, 33.93668013234293, 34.8393234129875, 66.61748009343302, 44.1236206793016, 0.5446255723795583, 0.04181149310522503, 0.0816861167550087, 0.007449991037813767, 0.03658687305306235, 0.06443328809954467, 0.039211061272409656, 0.04171435698686589, 0.06262309894326233, 0.039731545238605434, 0.005932692616742345, 0.040913327792358976, 0.0607052935858167, 0.06074428746116258, 0.07942511549880428, 0.12260926962499658, 2.008559963395519, 64.90881327659854, 63.380124415120775, 49.415145151076786, 41.20986054020543, 60.46778809639716, 45.23309838387274, 46.132168385290335, 31.783514638100904, 74.08866174759405, 72.01245707850303, 72.3520637327625, 56.36937802837741, 0.4906497445077666, 0.3800571078975355, 3.5791252745736033, 25.28736556729963, 49.113444282162575, 61.332760933906805, 58.073239941750806, 56.47495254393547, 61.06164278522615, 60.72457782683834, 62.33604046606249, 62.21643955476823, 62.87168718153431, 60.32453529296383, 56.18831749885313, 53.72429240134455, 54.17144260098858, 51.36189983737085, 50.84871653587588, 46.438489806267526, 49.72121554036295, 55.398097192087484, 58.98137846300679, 60.22766059444797, 64.06991635599445, 54.22622634518532, 61.2622602524296, 64.0054286679914, 63.15788292115735, 61.762362449399895, 58.020358547087646, 51.40487332497874, 49.68155645555066, 51.141733277228575, 54.76726631964407, 52.2192201306743, 52.19051230338312, 51.44553261418497, 46.88857001643027, 47.81525742623114, 48.55870739106209, 52.18978666490125, 55.20310048134097, 58.278509339978626, 59.40346079487955, 61.2959377227291, 59.5762372785999, 60.184055605242335, 56.67458941859584, 56.40836638789023, 56.40758975859612, 49.522453354251006, 45.909938658437426, 46.214479323356386, 45.90440811649446, 46.72550139888641, 48.11858607876686, 51.28862996255198, 53.49111926171088, 58.238865944647024, 58.59620563445553, 56.967967018004394, 49.93392567480765, 54.478446514375754, 63.18652014578543, 61.51776736782443, 44.19582759180377, 42.76168354095952, 44.7678856695852, 65.61745612852036, 62.031641006469734, 49.05802511399793, 52.936041124405406, 61.70105972597676, 56.782336927229366, 54.37786125367688, 53.73712639654837, 49.74127454142417, 48.22510588553644, 47.53799684586064, 43.19684697735695, 42.44047280280821, 41.64629482453869, 44.34621518658054, 42.77024215267551, 48.48077774047852, 50.39252135061449, 57.78739329307311, 58.29186893278553, 56.01611368117794, 57.3623142703887, 58.411775788953236, 56.72579596119543, 50.53698616643106, 48.08735616745488, 47.80759703728461, 46.682645582383685, 56.57710675270327, 52.39114153769709, 53.07048036206154, 56.04733574774958, 53.55974505024572, 51.31467450049616, 56.18558360684303, 60.31105410668158, 61.57954469803841, 63.127696360311205, 62.713635275440836, 63.49029987089096, 65.54067965476744, 64.80990286796325, 61.99341358677034, 56.61592252792851, 53.24755184112057, 52.42805888575893, 51.0620189482166, 50.95826049004832, 53.27346301847889, 52.8296507558515, 58.114530732554776, 61.81820915591333, 66.92329945102816, 66.33139025780463, 68.35731014128655, 60.801550419099875, 38.78997779661609, 56.80758914639873, 67.09778216577345, 64.54489969438123, 71.63638807112171, 65.61590286993211, 54.17190544066891, 4.198193694314649, 0.14133767555317572, 0.12810035037898249, 36.51243786658011, 75.95756915307815, 66.07732265226304, 52.56973097401281, 19.073189804630896, 37.03319526487781, 50.34790831227457, 59.37740056745468, 24.067392733789262, 41.08908291785948, 74.68374806065714, 59.07709998469199, 1.1735224098928514, 0.05696196199184465, 0.05830629691181164, 0.03996701768389152, 0.015598493384107228, 0.05925754445695108, 0.045635972562576496, 0.28809526995305096, 0.20716063948648594, 0.2909172007874135, 0.14740431050379432, 0.18926715448258385, 0.15930248334282832, 0.15101022507634856, 0.20082803413031564, 0.3389023130218829, 2.8220227649134975, 75.132169108237, 73.78092827335482, 55.608249941179835, 47.58731280603717, 63.77358128947597, 56.503138695993734, 50.6811724939654, 40.045673616470836, 79.78763026575889, 77.08139096536945, 80.32072744061871, 58.400549965520064, 0.606450645192977, 0.9024295727572135, 5.986035514262415, 32.08689035907869, 53.771721701468195, 66.28421983411236, 60.64804846240629, 61.85411845484088, 66.66683919968145, 63.79422864606304, 66.36984517497402, 68.68578510899698, 66.56816805562666, 62.76617542389901, 59.11635898774671, 58.29258672652706, 57.4068174823638, 56.63045490941694, 54.50754657868416, 50.496499461512414, 51.354243370794485, 57.638217710679584, 63.423019455325225, 64.24766640509328, 62.58308702899564, 57.15470713953818, 62.46046981503887, 66.31283744688957, 66.77671263294836, 63.13346224446451, 60.293411285646506, 53.362245867329264, 51.656677722930915, 55.45197486877442, 58.16051660045501, 54.85852810644335, 55.7684277719067, 54.1962908160302, 48.69979112379013, 50.993887378323464, 51.49022409992834, 54.17524730005572, 57.19324834885136, 63.36971444468345, 64.79074208967148, 64.32727483011061, 61.19555250290902, 64.31746105993948, 59.21172357374623, 58.765350003396314, 59.97813509356592, 51.833658987475985, 48.61071801954701, 50.46623445326283, 49.55919811802526, 52.70660992591612, 51.78403316005584, 54.31814316780337, 56.91266944331508, 62.78494396517354, 62.94148968112085, 61.56805215343353, 53.802080846601925, 57.132431999329604, 68.152797760502, 66.90571938791584, 44.848153052791474, 44.22663780950731, 45.817288352597146, 69.53790433945196, 64.39562213036322, 52.82668152163106, 56.49446241317257, 65.48801791283393, 61.592747396038426, 59.7742110683072, 58.866806030273445, 52.65493662126603, 51.510883223625925, 51.24808049971058, 47.7551039572685, 46.80521180552822, 45.73147473796722, 48.110843320046705, 52.96844774676908, 55.63311776807232, 52.89046318300309, 61.601160880058046, 58.404307596145145, 58.829386618829545, 60.50742756935858, 58.88773971988309, 58.87308574491932, 53.971609607819595, 51.02562719775785, 49.46948566744405, 49.20677708041284, 59.9128629315284, 56.02980275307932, 55.06530369481733, 59.20018788306945, 56.12176272176928, 53.025024014134566, 60.481088853651485, 62.79460868527813, 62.857025361830196, 65.17191802301716, 64.0721324951418, 65.16396737867787, 68.1790776406565, 69.26877483244866, 66.63250277119299, 59.33360730448077, 55.82708289546352, 54.82804736783428, 57.05138014208887, 54.26601486821329, 57.294629850695216, 53.9602739580216, 63.135431274291015, 65.31636322698286, 70.79699300950574, 70.13091964106407, 72.25864856473862, 60.7635191179091, 38.10753245507517, 62.18197368806409, 71.42504292149698, 67.98876423989573, 74.26455651560138, 66.09405548341813, 62.93747709643457, 6.825338400179341, 0.16334468498826027, 0.2483961187423237, 38.499000687753, 85.85863559476792, 71.40257558514996, 61.59890551720897, 26.017740311161166, 44.99928197553081, 51.92900003925447, 70.7690735786192, 47.042954506412634, 53.875895930874734, 80.401700850456, 73.38350588275541, 3.4597827494144444, 0.31528127890440727, 0.17111880734803217, 0.1740281794580721, 0.08716207493336932, 0.1941791570354854, 0.13056778168726352], [0.044278767365481586, 0.05762379684094941, 0.02534595768778555, 0.08338752908692246, 0.01267451868062058, 0.0652116104479759, 0.00993601865165176, 0.04052563367651836, 0.09496907778685132, 1.7950598390833026, 62.712890025108095, 50.790143782092684, 58.456224087745916, 36.67657336881084, 42.293662409628595, 52.675450617267245, 19.090654157823135, 14.563009315921416, 50.82917921004757, 70.34835230919623, 56.580707488521455, 75.3290093329645, 22.07674280289681, 0.17709056997010786, 0.5662233682890092, 9.591121731265899, 26.218667645608228, 43.429012067856334, 49.47424350246307, 44.763284729373076, 56.832562877285866, 57.27115838758407, 60.4129925850899, 58.38719037271316, 57.85645838706725, 53.40917310407085, 52.39384405074581, 49.10445420972763, 48.55937811636156, 48.089195759065696, 46.35993257645638, 46.75292268876107, 50.94894878325924, 52.671708676122854, 58.341020153414824, 61.51934023826354, 53.32896063404699, 55.34419205880935, 61.98215246200562, 60.67177487957863, 61.17700361436414, 62.62981422485844, 58.68635346812587, 48.330805916940015, 45.75193382078602, 47.16479901344546, 51.97727264896516, 50.66617727279664, 51.29888303818242, 55.812189655919234, 49.531886654515425, 44.90240727701495, 45.49458319141019, 46.7566018719827, 49.88218568986463, 53.53205311682917, 55.949021539380475, 54.69843656786027, 56.81076626623831, 55.428436725370354, 56.20462671402962, 54.73926059661373, 50.71286132258754, 49.832665766439135, 59.69837204102547, 47.21878651649722, 42.50974970479166, 45.49930964746783, 45.48142756185224, 47.059142128113784, 48.78668731258762, 56.65520506520426, 54.410460072179, 58.69194284562142, 49.729938891626176, 54.76495604361258, 61.995880757608724, 60.29436442159838, 44.201487571962424, 41.133943065520256, 48.23924603000764, 64.10067558288574, 60.47314997642272, 53.42879672204295, 51.39557338530018, 59.517268365429295, 56.87319470990089, 59.42139779367755, 52.76260960486628, 46.5932116200847, 44.44121499215403, 41.54131258687666, 38.92799423586938, 43.22513511103969, 46.187010965039654, 46.26159091149607, 34.32426129617999, 43.409917969857496, 55.16379833221436, 51.136296872169744, 53.59997287873299, 54.60342499517626, 55.656742203620176, 53.150430033283854, 49.36848071313674, 44.82182610419489, 45.918391366158765, 43.390612063869355, 46.43526169561571, 57.82828007974933, 51.49416608195151, 49.91986005536972, 51.8403152496584, 50.12424299793859, 47.73673157538138, 52.64855492499567, 56.573913943383005, 60.97566835341915, 62.93741041614164, 61.23854952473795, 60.25833745156566, 60.35301954515519, 64.19511841189477, 64.38345101571852, 57.16615653807118, 53.57297912720711, 50.866571164900265, 46.753742464127086, 47.42287528130316, 50.26220844637964, 51.164051563509055, 53.80821151118125, 57.01805176273469, 64.2152205590279, 63.58041240322975, 63.457912860378144, 68.58234436281266, 56.25458202054424, 54.62735537559756, 65.24292469024658, 61.889086384927076, 63.16166408600346, 57.589062567680116, 22.312665524021273, 0.38315884468536227, 0.18488012134067475, 0.5166835265774881, 53.31302796640704, 64.35543352557768, 66.79629310484856, 35.899991143134336, 19.157936534573956, 25.321868696520408, 29.595247853186827, 48.41731379109044, 42.818467693944136, 56.19967276050199, 46.53973402515535, 66.87118684091877, 3.3042279222319206, 0.12457458392506647, 0.111810241435324, 0.00694080543208627, 0.048101741460061846, 0.06490152869974414, 0.03499336803572313, 0.021141444993836266, 0.09499051292697269, 0.012023080602258205, 0.03631783063493429, 0.026856842037710934, 0.05137625788789123, 0.06922132230453915, 0.07655464533355928, 0.06927001485300642, 2.418232406339338, 72.75302410125732, 60.13743039100402, 56.01070865508049, 41.435024199947236, 60.96136739177089, 51.83314907935358, 34.35831139164586, 33.611594092461374, 53.4180219711796, 82.43069587215301, 60.748708248138435, 82.69849961803806, 27.43603994769435, 0.0916880227985882, 0.6823154130289633, 8.71042509232798, 25.951350273624545, 43.901563536736276, 55.62191155649001, 50.69311218876993, 63.47726191243818, 61.44041430565619, 62.94500412479524, 61.90481508931806, 60.401362757528986, 57.82939795524844, 54.554360066690755, 51.463242115512976, 49.559645268224905, 51.848669898125436, 49.10423847936815, 49.484339683286606, 54.174639332679014, 56.27736706887522, 60.68174162218648, 62.35394608589911, 55.948978393308586, 57.87455620304231, 61.60770339350547, 62.25856188804873, 64.34503924462103, 63.80022202768634, 59.594268414282034, 50.50716438601094, 47.77466089494767, 49.21643003340691, 54.31269107326385, 52.34503799869169, 53.710536649150235, 58.46837951290993, 51.9274232464452, 47.80043086697979, 47.93444648865731, 49.69047200295233, 52.675846776654645, 54.93972509138046, 59.086078290016424, 58.37584295580464, 60.353266654476045, 57.71251916885377, 59.9590527626776, 57.220555889991026, 54.88278404358895, 53.11663881424935, 59.96968238584457, 49.078837210132235, 44.139729853599306, 46.70014327572238, 48.008277262410815, 47.35956822672198, 52.28340187380391, 57.59083155662783, 56.843294482077326, 59.18574571609498, 51.7660883165175, 56.33133103770595, 63.84637263513381, 61.89542493512554, 43.031522996964, 41.70613450388755, 49.0721966374305, 64.10702197782456, 59.75954532623292, 55.6895253735204, 52.106373540816776, 59.26995115895426, 56.66466974443006, 58.622489436980224, 54.68845021340155, 50.21816022934453, 46.30196779004989, 42.92781552960796, 42.317698694044545, 46.220060856111594, 48.61395789730934, 48.43746300666563, 41.48986677969656, 45.6719841495637, 54.1302381023284, 54.254043794447384, 57.86301658999536, 57.613345961416925, 57.29213130089545, 56.41568945300195, 52.16049832682456, 47.25362500836773, 46.90142754585513, 45.2264028979886, 49.40753967531266, 58.619441755356334, 53.97979951673939, 53.127503779626664, 54.0073267106087, 52.446164546474336, 50.21011152575093, 55.35303308117775, 57.49932658287787, 61.59813673265519, 64.71733100952642, 63.22557910796135, 64.22553247021091, 61.78415513807728, 66.16624278406944, 65.18424603246874, 61.621008073129964, 54.41309198256462, 52.763825539619695, 49.79302629347771, 51.5161156654358, 51.6015644996397, 54.16314286570395, 56.967096251826135, 60.927042730392955, 66.40758622077205, 66.47563149852138, 67.0221588688512, 66.81221008300781, 60.09476284826956, 60.50935737548336, 67.18907140916394, 66.05684787996354, 66.99907179801696, 59.66330605168497, 17.133903311144923, 0.2369891001933044, 0.7308573179667996, 0.8785400707875529, 60.5129934126331, 69.27578018557641, 72.1997110305294, 42.7714620097991, 22.98219842295493, 32.20531848169143, 40.12453679115542, 58.36231470108033, 43.64595051734678, 65.17922932101835, 55.534925153178555, 80.90799254755821, 7.944331774788519, 0.14272751226540537, 0.06912116396931872, 0.019726806185058048, 0.035762129606859344, 0.036744097277762434, 0.032468495454879544, 0.13767795096482002, 0.2219099311097976, 0.16067836193307755, 0.25086793207353164, 0.12838257717028742, 0.21581447593146758, 0.23891139865642597, 0.19540158821450127, 0.21411981283416673, 3.4192043590930203, 84.6372252125894, 68.13245634878835, 75.39201044267224, 50.52708610411614, 53.271270413552564, 74.70740779753655, 28.079565571200465, 28.383719882657452, 62.6761648731847, 81.64652778256325, 68.18130554691439, 86.08284611855784, 29.78255279602543, 0.5061727696128431, 1.4829062213820796, 10.736796048379714, 29.904838569702644, 48.61177313712336, 61.17458743433799, 55.137608666573804, 67.91271732699487, 65.51409382973948, 68.25026865928405, 64.50622512448219, 64.54171080743113, 60.50659602688205, 58.48950147628785, 55.48560527063186, 52.80720695372551, 53.43040881618377, 52.565181024612926, 52.53558281929263, 58.755971616314305, 59.85149745018252, 65.6831911302382, 61.860845319686405, 57.72894997750559, 59.81920065418367, 65.22721559770646, 64.1815980019108, 66.67599401166363, 68.54087706535094, 63.935665392106586, 51.96429352606497, 49.26108229544855, 52.603016207295084, 56.79007184120917, 54.74064911565473, 57.174417049654075, 61.74576297883065, 57.74738119494531, 50.539888720358576, 49.55326749432472, 51.249649447779504, 56.10687732696534, 58.0181267184596, 62.189790971817516, 61.03178570347448, 63.706002773777136, 60.624839798096694, 65.0639626287645, 61.947204143770286, 60.01915131845782, 55.49714880604898, 64.16839530391078, 51.60971518485777, 48.47452940479402, 50.34323676939934, 54.50336533208048, 53.44641600885699, 54.88591409498646, 60.12239594613353, 59.09577438908239, 62.846066259568744, 54.13203847023749, 60.1881976281443, 66.28154477765484, 64.13953842655306, 44.132975532162575, 43.01179739736742, 49.78532668082945, 67.33653683816233, 65.27908894323534, 58.829598426818855, 56.2815365483684, 63.368341615123136, 60.60609871341337, 61.656980129980276, 58.37721970773513, 52.898339302309104, 50.75991015280447, 45.885517981744584, 47.039604802285474, 49.348115767202074, 53.54312204545545, 52.88781166076661, 49.136064590946326, 57.8206746039852, 57.60208483665221, 56.8467971586412, 61.916146816745886, 60.39151760839648, 59.4963268310793, 60.5505540294032, 54.35564102665071, 51.975680166675204, 51.22305185564103, 48.10043727197955, 53.11876081651258, 62.852946096850985, 56.05398024282148, 57.00273882958197, 55.63098792106875, 54.339069012672674, 52.046973166927216, 57.76353743768508, 60.472373347128595, 66.18787073319959, 67.29622271753126, 64.22579134664228, 66.57577745376095, 63.50755045490881, 67.33361075001379, 68.29471695807673, 62.2400051547635, 57.17643707029281, 57.11176503089167, 52.047741951480994, 52.43757847816714, 55.651199894566695, 57.64890616939914, 58.661681759742, 64.7932759408028, 70.75287418980753, 71.38318338701802, 69.33306247957292, 71.476669157705, 56.81422187436012, 62.23410198765417, 73.38955417756112, 72.85422909644343, 72.5234869987734, 63.824152408107636, 26.872801319245372, 0.8087600635424738, 0.6128903189974447, 0.9423858996841216, 65.07479229281026, 77.0739306173017, 77.61321729229343, 48.70160718117991, 32.30342480444139, 32.88875618288594, 41.37056789090557, 68.89344323065974, 55.63158412133494, 75.39630151564076, 62.24457079364408, 91.3592576980591, 10.278792650468889, 0.41050548695268174, 0.2892978747765864, 0.15773906642871519, 0.20585456682789713, 0.17769999291387298, 0.1543847044869777], [0.11355304549778662, 0.0427210271628874, 0.023242529226286758, 0.03200545276124631, 0.06132123593781745, 0.029386048760986137, 0.0052739374410931865, 0.025060810186269305, 0.027415366099786856, 0.7457633052141436, 62.03635569541686, 57.70062262012113, 50.40991313995854, 31.440499444161695, 32.06966919283713, 48.398145168058335, 33.40237094509986, 6.9555385362717415, 28.81036981459587, 67.0814415716356, 65.37979187503939, 56.32578480628229, 66.25622195582237, 3.7006895772872435, 0.29877520977489413, 1.0386664204059108, 11.527806712735085, 23.141729062603368, 31.739954756152247, 44.691407295965384, 56.894638307632945, 55.18082534113238, 56.516686562568914, 63.15755344206288, 61.64964137538787, 54.47871323554747, 52.09229615426833, 47.71324442278954, 47.92304808093656, 49.009752504287235, 45.534587444797644, 50.214755612034956, 51.89581678759668, 55.46717013082197, 58.34509157365369, 55.62777157752745, 54.25671100616456, 59.632452687909534, 59.61509227752686, 60.805900327620975, 60.58507480928975, 58.58008077067714, 55.85675170344692, 47.95566258891937, 48.027210543232584, 47.51441555638468, 48.3884451466222, 53.096607269779334, 50.33743950628465, 53.443666427366196, 56.58260983805503, 47.574019893523186, 47.80788729267736, 48.019114771196925, 48.253327338926255, 50.07173030607162, 52.914115075142156, 53.09211615593203, 55.54916335690407, 54.60855937773182, 53.412036434296645, 51.446168038152884, 49.40169534375591, 55.91021360889558, 58.47423953394736, 50.30172632586572, 54.968805543838016, 45.37963813351047, 46.22896463640275, 45.96453805123606, 49.143556317975445, 50.574401655504786, 58.96551639802995, 59.781745941408225, 56.35399057019142, 58.432850683889086, 63.411307257990686, 57.218790823413485, 45.36608242219495, 39.179877081225, 46.7233205610706, 60.81247422002978, 60.47567990518386, 54.992182870065015, 54.96349857699487, 60.44842335485644, 59.915706649903335, 51.71070444968439, 46.19469488820722, 44.215533579549486, 45.50753878008935, 48.159708207653416, 50.232265072484175, 47.658523436515566, 49.75717190773257, 44.108460718585604, 45.42384716772264, 39.08006452745007, 41.356113956820586, 55.466926943871286, 55.319932199293575, 53.587680170612956, 51.27726293379261, 53.38029269249209, 48.540946898921845, 47.33832074749855, 47.98200522699664, 47.826412647001206, 50.11014992190946, 49.971831460152906, 48.69899880501532, 50.95119630136798, 50.91968005703342, 49.875682400118926, 47.714185791630904, 52.89207527714392, 56.01964381433303, 58.08521101551672, 59.154339298125244, 60.82264884825676, 57.90295808546005, 63.05030015207107, 67.05670710532897, 59.130416762444284, 63.72131178455969, 56.98931255648213, 53.917178876938365, 49.85250511477071, 49.29050007174092, 47.826679368172925, 49.45847557437036, 47.39496369515696, 52.4971043679022, 57.398768778770204, 64.83976779445526, 64.13951096996185, 63.69662046432496, 65.32622406559607, 64.87288436582013, 55.41690495706374, 56.139123132151944, 58.97829940242153, 32.784783955543276, 2.0317914264817394, 0.06615284905438462, 1.0070332404105895, 2.4904461829893054, 56.96335823305192, 62.03107618516492, 65.64690136140393, 40.35418372000418, 13.551105472349352, 23.42797971540882, 31.911379983348233, 51.438770448007894, 36.56050259067167, 80.34305357163953, 50.94772500376548, 72.18076598259711, 19.54503720806491, 0.3727789048946673, 0.0843605220377926, 0.18004930878598846, 0.0620397498020001, 0.04007447300659072, 0.04335207676875495, 0.05750715612403809, 0.07670469131440887, 0.027171087473811164, 0.03359833724736687, 0.034136931532092636, 0.017004905366188577, 0.01626660536614157, 0.001265335813513957, 0.08899241220206024, 1.2195858671780557, 70.09315506104501, 65.14227667162496, 53.1075781391513, 34.96124244505359, 33.61650882228729, 64.88580857553791, 25.16866876233009, 20.31815794206435, 37.36267043698219, 69.4325965450656, 74.64169240766957, 60.73891016744799, 77.25111976746591, 5.425582258932052, 0.6170450283154365, 0.6553478310665777, 8.77208180965916, 22.8628485433517, 35.862128503860966, 52.829466404453406, 61.48222284932291, 60.06063822777041, 62.33907638057586, 64.02772342005085, 64.79649620671427, 58.3164974950975, 52.032891858008604, 50.77810602803385, 51.39120778729839, 51.31893027213312, 48.69233077572238, 53.52665985784223, 56.39071572211481, 58.445045332754816, 60.64406725668139, 58.61130283724878, 58.16713756130588, 60.29823187858828, 62.98352572225756, 62.101384670503684, 60.858675818289484, 61.442971691008545, 57.29203716401131, 50.9168206491778, 49.179465616903, 50.52747834113337, 51.64806812040268, 55.43052734867219, 53.27417688985025, 56.13831512389645, 56.50950862515358, 50.03333030208465, 50.63436685069915, 48.32115296394595, 51.59117021868306, 52.541438917959894, 54.75752315213604, 55.29721383125552, 56.93020243798533, 57.40043186372327, 56.59234123845255, 55.57841247127902, 54.69459656746157, 55.81276624433456, 61.35147456199893, 52.04574938743345, 57.34322409476004, 48.75015827917284, 48.46510002689977, 49.09933159428258, 51.371697918061294, 53.3397981428331, 60.411741349004934, 59.19684602368263, 55.802450410781375, 58.84074972521875, 63.34242259302447, 60.76761799473917, 43.100631237030036, 38.77935209581929, 46.56309566190166, 62.39387581425329, 63.95400639503234, 55.68390069469329, 56.25500171415268, 60.913479174337084, 60.59359419730402, 53.43925768329252, 48.38662908923242, 47.95058704191639, 46.52314239932645, 47.67957479723039, 51.2124300772144, 49.68218403477823, 50.38446872465072, 46.421250989360196, 50.15267233694754, 41.101638424781065, 45.32102223365538, 55.65811895555066, 56.33133103770595, 57.250546332328554, 54.77298905772548, 56.3818903892271, 51.48164979873165, 50.2769487134872, 49.38313861047068, 49.99906839862947, 51.559340184734715, 51.85944857135896, 49.99604817359678, 51.22131032328452, 53.35336954362931, 51.62907600402833, 50.95911164437571, 53.45953633708339, 58.416145309325195, 60.87809547301262, 63.662609592560806, 61.28253106148013, 63.18901085084485, 63.96594608983686, 64.95105328098421, 62.552076770413315, 63.758040858853256, 60.65439093497492, 59.28780971034881, 53.45342528435492, 51.44114740433232, 50.208605335604766, 51.65818391307708, 48.860141538804584, 58.16249739739203, 59.17312352888046, 66.26678097632625, 64.45053923514583, 67.71142128975161, 67.43562375345539, 66.0885484756962, 61.08343939627371, 61.673101071388494, 57.488849932147616, 29.932153955582653, 1.2873709201812744, 0.7502204660446413, 1.5135193399844633, 2.9576509710281127, 66.894956404163, 65.36355718489617, 77.79474458386822, 39.31343378559236, 25.56383186771024, 30.196576618379165, 39.118939138227894, 63.457461787808334, 35.75943300800939, 94.29395152676491, 52.437052880564046, 85.04696384552987, 25.877688161788452, 0.24303033166835386, 0.1138666206069531, 0.03335202082751259, 0.030996235342876568, 0.07162860804988493, 0.01412587608360956, 0.27123054910090666, 0.22089710158686485, 0.12239066643580315, 0.12281432837968874, 0.12011204515734028, 0.12059125613661544, 0.240301342620965, 0.11500681990817671, 0.20799129330102475, 1.5936024943667075, 84.53509453804263, 72.27026662518902, 67.78644838640767, 44.593885406371086, 40.19764977116739, 67.36877087623843, 43.73666317232194, 16.049193413026874, 43.114704701208304, 78.30885748709403, 79.1640204768027, 67.54652484770745, 79.34236280379757, 5.477891968142602, 0.9384868185847037, 2.1161748468875885, 12.049038717823645, 26.90219556131671, 43.65784706607942, 58.985238075256355, 65.21965326801424, 65.10126044673305, 64.80398793374339, 68.68718931751867, 68.80470352788126, 62.517995295986054, 56.999577399223085, 54.30575240042902, 52.43351490266862, 56.26927914157991, 52.27689466168804, 57.09640502929688, 58.194613764362956, 60.24213021801364, 65.17022355910271, 61.31269408810524, 60.05064010620118, 61.71243852184665, 64.25867649816698, 64.48275758374122, 63.8212537765503, 63.36044980633644, 59.7004234406256, 53.7084734824396, 52.972946705356726, 53.29238453219014, 53.419539928436286, 59.13617872422742, 55.15114476603847, 58.97082728724326, 59.66638903464041, 54.37748862851051, 53.303022000097464, 53.003615717734064, 53.77323181398454, 56.23959464411582, 57.385358195151056, 58.15440162535637, 60.77404675945159, 61.390004004201586, 60.213190970882295, 58.54628170690229, 55.7675491609881, 59.01751918177451, 63.38445078942084, 56.043699710599846, 62.434766523299686, 52.14541681351201, 51.22856278573313, 53.557285724147675, 54.21782855064639, 57.77249220878848, 61.16880978307417, 64.5255349528405, 60.85955050683791, 63.38915371125745, 67.86773558585875, 63.437944073830884, 43.98980509850287, 38.628662478539255, 48.91628634545111, 64.07012424161358, 64.98451109855407, 58.92219381947672, 59.30615463564473, 65.38548715652959, 62.65374852764992, 56.48668827549104, 51.0728721464834, 51.55743391283097, 50.9716946078885, 52.76300968662385, 53.86170871796147, 53.70824990733978, 53.3076503969008, 50.0006648032896, 54.97034703531573, 51.61568110988986, 56.34496519642492, 60.125184751326046, 58.10986703441989, 59.20810714844735, 58.040884310199374, 59.60464700575798, 54.92973481455157, 50.9909926691363, 52.57783851315899, 51.45364799807149, 53.081490455135224, 53.66020479509908, 52.73726324881277, 55.11076788748465, 54.838857420029186, 55.242418319948264, 53.77453404088175, 55.71671524355489, 61.94742771887011, 63.4371203760947, 65.28838103817355, 62.15168906796364, 66.4482141310169, 64.65741680514428, 68.96346538297593, 66.601727854821, 67.68554149135467, 63.30732130235242, 61.71501944142004, 54.67994651486797, 55.07851815992787, 53.72297056259648, 53.34378327092817, 50.66961719143776, 60.741698972640506, 63.789462966303674, 72.13461537514964, 68.623780281313, 70.61483029396304, 71.85427573419386, 67.5929892447687, 67.08406955965104, 68.98303016539543, 64.67714240474086, 39.088893782707956, 2.6017125479636656, 0.43883364106858935, 2.5923508309548904, 4.101663428929545, 71.94859304735738, 76.20733784091088, 76.2239843799222, 54.024024240432254, 25.30162730524617, 30.11730355601157, 47.55764792042394, 67.87671781355336, 47.651839717741936, 93.02095413208009, 66.94479403957244, 95.41014040670088, 33.414393009678015, 0.5208756822732188, 0.38907865122441326, 0.2491314252538066, 0.3819100907252681, 0.21301204969565715, 0.1132509693683636], [0.10741494220471191, 0.06599727957960098, 0.05679694665295463, 0.07726942068867146, 0.08377579010782704, 0.09608903704511543, 0.1080114565669529, 0.15123562346543037, 0.05410194509632645, 0.2090174067885645, 54.25597360057216, 60.73874542790075, 49.07542474808232, 51.69952569469329, 56.65904898797312, 29.254658645199193, 73.64192731918828, 29.34079193299817, 4.874729004598433, 31.482223656869706, 67.19459410636657, 55.20252781529581, 64.09502344746744, 28.62353555617794, 1.0739660359198049, 0.1660161561542942, 1.5460533168046706, 10.72551727294922, 22.410044247104278, 34.62815869239069, 34.5985447975897, 59.28859810675345, 58.98303370321951, 62.680722667324936, 61.60202380149596, 58.5076149817436, 49.78849595592868, 50.00653266906739, 45.40922849409042, 47.73340932784542, 48.80591869354249, 56.10277452776509, 55.96065921168174, 56.41543449894075, 55.47812923308342, 59.00814079469251, 56.79242134094239, 58.174323343461566, 58.72015645427089, 61.5808508473058, 60.26805708485266, 58.21071117155014, 54.26254357061079, 50.21173538700227, 46.194781180351015, 48.48880683222125, 45.231760855643984, 53.57827432693974, 50.95133358432401, 50.45539694447672, 55.11862439493979, 53.191807116231615, 51.164765434880415, 48.35190042372673, 49.255194817819905, 50.25973343080091, 51.22770770903557, 52.207962928279755, 54.22558307647706, 52.18026315012286, 51.10782046471873, 51.68307135182043, 49.572055647450114, 49.94066038439351, 51.233171570685606, 47.3355790107481, 48.87767061110466, 54.331969522660785, 53.07017833955827, 51.20970010757447, 54.146590463576786, 47.92628011395855, 56.8073106581165, 60.06478025067238, 62.279448509216316, 58.80487572762274, 60.95420906620642, 57.33131577891689, 43.8147928637843, 40.3803067053518, 45.99072771687662, 63.01716396885534, 63.196659472680864, 60.382327495082734, 62.73230575746106, 59.895294635526604, 57.000216745561175, 49.48672056198121, 51.20142782888105, 48.609941390252885, 48.59242408506332, 46.90681296010172, 50.55262465630808, 50.93873100896036, 49.4379537336288, 51.617151998704486, 49.36430731127339, 36.2333220051181, 38.934862306041104, 39.57771916543284, 52.27641613252702, 55.09619235992432, 52.59574413299561, 50.46061761917607, 51.93377356375418, 49.681356414671875, 49.725004549949404, 49.06243385807161, 53.640667469270774, 49.4705133284292, 48.71335075747583, 50.423688504003714, 49.69133492439024, 49.67653582173009, 48.51651445511849, 51.09626516219109, 56.16654442202661, 57.15665263514365, 58.149851675956484, 62.5706531155494, 60.85951520550636, 62.30060969629596, 71.46338801230155, 68.9392408247917, 61.37867619914394, 58.52100595351189, 61.91107126974291, 54.156431690339126, 53.41249535160681, 49.53733482668477, 49.78450690546344, 48.19353472801947, 53.97516327519571, 52.62565220555952, 62.41387205739176, 62.25539653531967, 68.8623623694143, 58.493416001719815, 62.658227874386704, 47.91622315683673, 46.610607331798924, 22.63153852954988, 5.153833589246196, 0.10213871846996969, 1.2887024422807078, 0.6851408065807435, 7.9807750063557785, 65.84089786775651, 63.89393529584331, 55.62161345635691, 16.1152353402107, 10.611024268211859, 35.133618847016365, 28.67188661329208, 59.195716381073005, 30.049587757356708, 20.765772942573797, 53.7114348719197, 64.32317203091037, 28.335006006302375, 0.8177356722374117, 0.24876529651303447, 0.063737538538032, 0.05037201621058968, 0.08246995493649475, 0.05723248679010619, 0.10475211251046389, 0.025402050645601366, 0.07020583721779047, 0.10841726100132351, 0.061633891741474794, 0.03698646068392742, 0.03531681801823359, 0.028725318993712147, 0.03198932278000059, 0.18156947237589668, 62.37066322757352, 69.20053343619071, 55.79799067589545, 59.62247810056133, 51.27240311714911, 42.86659909832863, 77.00370450173655, 18.563722948874197, 6.9146429242626315, 30.064918341175204, 72.6315482970207, 61.8927812576294, 72.71654605865479, 32.00634840996035, 0.3604010077974489, 0.5826849430318802, 1.803223517152571, 9.203482712468794, 22.99308300018311, 40.917902838799264, 44.15809831311626, 64.89682651335194, 61.93737076174829, 65.70042994714552, 63.18870098360124, 60.44985109759916, 52.31916996740526, 52.63267717053814, 48.194758507513235, 48.79379856971003, 50.9987001265249, 56.92880607420399, 59.034373606404955, 59.47979796317316, 57.699045827311856, 60.14833458008305, 57.30799336587229, 62.02818539834792, 61.31221555894422, 64.57682386521371, 61.15987462382163, 60.50942405577629, 57.767738296139626, 51.945638733525435, 49.415215753739886, 48.78484379860663, 49.913282240590746, 54.315071951958444, 52.66834720488518, 53.15989079013948, 57.79541061770532, 56.6396136437693, 52.25916554850917, 49.83916513381466, 52.04518064375847, 52.1254833282963, 53.03802667125579, 55.70688578390307, 56.22734115969751, 58.15210703880557, 55.36380390967093, 55.25753905696254, 52.716043226180545, 53.15531730651856, 54.159393079819225, 49.762992705068285, 50.52945129333004, 54.762343745077814, 53.98509079410184, 52.58445162926951, 54.96380844423848, 50.27480709937311, 58.00401795294977, 61.7009695114628, 64.30174412265902, 59.141571983214355, 61.62965297698975, 57.79663047482891, 43.39809202378796, 38.81667344800888, 46.83858333095428, 63.92385513551774, 63.82141851609754, 59.05021605953094, 62.89920260829311, 61.273568445636386, 57.170710409841234, 51.47962193335257, 50.741808414459236, 49.925461199975786, 51.30063241527927, 47.10264905806511, 51.783884109989295, 51.809257922634, 51.58654182187973, 50.28822945010278, 50.87600054279451, 42.5940453621649, 44.03292763617731, 45.38824381366853, 53.61642722160586, 53.88972228573215, 54.169395123758626, 54.788796209519916, 53.874946717293035, 53.410989161460634, 50.37321152225618, 51.50394847316127, 56.33861880148611, 51.035280150751916, 51.15577536244547, 52.08696565320415, 51.22553471596011, 52.407795921448745, 50.22931545011459, 54.02881345441265, 57.808225001058275, 60.0481572458821, 63.612513080719985, 64.86282740869831, 64.9569486033532, 58.70164286705756, 68.08196759993031, 73.15368636961907, 63.791239799991736, 62.71355682803739, 63.87623756162582, 58.72035649514968, 57.678308256210826, 52.69981638077767, 52.67433274176813, 50.871815373820645, 55.39437486279396, 57.34329469742314, 63.76404992995724, 64.23205929417765, 70.89761749390634, 60.86805812774166, 63.893040995444025, 51.19213965631301, 51.83006217402797, 24.68808231815215, 3.1683655996476454, 0.30109829479648226, 5.717253627315645, 0.866082929555447, 13.182071235872085, 70.55964254563855, 71.09026078254946, 56.83196667701968, 19.63706385704779, 18.669672050783714, 21.621402694332986, 33.333117577337454, 70.29285077125796, 27.875386591880556, 25.84716427710749, 58.090855306194676, 72.1764592201479, 37.910096030081476, 0.5899553625814377, 0.2937867210036324, 0.12909745977770898, 0.15311345818542665, 0.05416244689014651, 0.07063239497402984, 0.22738962013634945, 0.19222218543291095, 0.23405257792722797, 0.20721610425220383, 0.214092371564719, 0.28193684234734506, 0.1577634433464658, 0.2554563237654586, 0.1752674186061467, 0.3223045278460749, 74.33232722743865, 77.65420606059413, 63.551967374740116, 67.2390345604189, 73.7995046184909, 40.755504946554865, 92.18634436207434, 40.41769866020449, 10.436221880297508, 45.21313351969565, 79.23561942192816, 65.73367595672607, 74.54364884284236, 34.96550213906073, 1.9734567115383765, 0.8905745766335919, 1.7159647542622782, 12.912951534794225, 26.685525794183057, 49.36591940541422, 50.89871498846239, 72.08444826064571, 67.04028806378766, 69.96000628317557, 67.75651285725256, 64.69125117025068, 56.279944066078436, 54.00511841620169, 51.516264715502345, 53.25249010516752, 53.92266627280943, 62.15299913960119, 64.12284481909968, 62.05593224494689, 58.798882345999445, 63.756938672834835, 61.30206838730843, 62.51075852301813, 63.677710717724224, 67.57996697579661, 65.51858102121662, 62.04501628875733, 59.39752232643866, 54.30643489283901, 51.415699066654334, 53.16183236337478, 50.34493123331378, 56.3294247658022, 54.773518577698745, 55.6000090414478, 61.0504561854947, 58.71677929355253, 55.70515994102725, 55.27109084590789, 57.1874628528472, 56.57384726309008, 56.9431423371838, 59.37143464242259, 59.110604870703916, 63.055528671510764, 58.08761542843234, 58.923319539716175, 56.56602213459631, 56.494344742067405, 56.764062604596546, 53.71580831466183, 55.35149943444037, 59.280655307154504, 57.38535427278089, 58.16069310711276, 56.906389728669204, 53.98492213218443, 59.11074215365995, 65.66374009655368, 66.95926758550829, 64.87765396794966, 65.37503796239054, 60.966321345298525, 44.67379977626186, 41.04320687632407, 45.45551246212375, 66.83449699032691, 68.10021446597192, 63.53664267447687, 64.64701075707713, 64.88203917780231, 62.5226511493806, 54.12823769354052, 53.74351985992924, 54.6205343738679, 54.20650466795891, 51.648656475928526, 54.4144412779039, 52.8431672434653, 55.38107802790981, 53.279075930195475, 54.67937777119299, 48.499942441140455, 49.63919878005982, 51.984544723264634, 60.53072644818214, 59.756701607857984, 56.742391509394494, 58.18960097528274, 60.16340432628509, 55.58686910137054, 55.00427553730627, 52.100941058128114, 58.97831116953204, 53.38815704468758, 54.58259328719109, 55.68182576087214, 53.11321850745909, 53.361602598621005, 53.63547032879245, 55.673220080714074, 61.20359728413244, 63.64379006047403, 66.40134965219806, 67.17636292980563, 67.17620603499874, 59.24785252540343, 65.5658338146825, 71.14409139079433, 68.52278709411621, 63.977171913270034, 67.58890997978949, 59.4159927675801, 59.74802532503682, 55.92014505017189, 56.0752865575975, 52.36849377232214, 58.71271964042418, 59.33200305508029, 68.00420268889397, 68.97248683437225, 75.74998947881883, 64.12005993627733, 68.46701099026588, 55.26787057999642, 65.1953031939845, 34.643946232334265, 7.764934820513572, 0.2128092662221001, 4.0012956146271, 4.223420908374171, 12.43097068802003, 80.56709935588222, 75.91164604310067, 64.96508359909058, 30.359490302301225, 21.21821245839519, 44.74543794508904, 45.150069652065156, 80.18446430083245, 43.65151243825113, 31.140485194421586, 71.08442429573306, 84.23031068617298, 47.022056118134536, 1.056012489622639, 0.37558358342897513, 0.29243405487748886, 0.3282659789246898, 0.24427029093907726, 0.204556277622619], [0.1276552456340963, 0.015127236312705905, 0.08000325907262103, 0.06499381931198221, 0.04723549137012132, 0.11031602524341115, 0.02338508478245668, 0.0683498589862739, 0.16026335678273634, 0.02821373888441632, 45.49390854374055, 63.09666256750784, 48.41531730467274, 23.65913087321866, 33.8689878679091, 38.68131637573242, 29.480318484767793, 61.64882552239203, 4.43276172684085, 14.44819369623738, 55.785870552062995, 61.7891679271575, 50.44758358309346, 68.55785308345672, 2.978281657541952, 0.3805062192822657, 0.18178659701539626, 1.0309253777227094, 8.275912769379156, 22.390532416682092, 32.22409094533613, 48.035286703417384, 61.796059531550256, 62.740377995275686, 63.68344522291615, 57.77485739800238, 51.47510728528423, 49.15165993475145, 49.663901867405066, 49.914764896515884, 51.897362201444565, 55.406208653603834, 56.04621002751013, 58.938248080592004, 58.25048008272725, 62.88992620283558, 55.7907146792258, 58.748483811655355, 59.45387501870433, 59.537197928274836, 57.73615144914197, 56.039157605940304, 52.51229570757959, 50.90225688872799, 51.76947332197621, 49.49101555731989, 47.78245072210989, 52.07928957477693, 50.718850781840665, 50.25245351176108, 48.51740875551778, 53.76622253848661, 55.96603285881781, 56.41409304834182, 49.594805394449544, 51.35967193111297, 53.739538654204345, 51.436005177036414, 47.947143200905096, 54.443286388151115, 49.49931137023434, 49.72378469282582, 44.441183613192656, 41.65763047433669, 50.820934387945364, 47.62267689551077, 39.30683243659235, 40.80646437983359, 51.46850201391405, 49.89792616136613, 53.314996996233546, 54.24386524385022, 52.81128229633455, 57.80263170119255, 60.56567868878765, 61.090472205992675, 59.417306761587824, 61.11674816377702, 42.16599318288988, 41.60480791522611, 44.1406516105898, 61.96828688344648, 60.909215557959776, 58.88683757474346, 59.38777131419028, 57.0665636370259, 53.10669560586253, 53.041945119057935, 49.38107152138987, 49.0056340156063, 53.6217773345209, 51.93963358479162, 49.885276517560406, 35.642146295116795, 40.00821105895504, 47.779967861790816, 42.98337198072865, 40.537362329421505, 39.788895653140166, 40.27621876808905, 35.94420017734651, 44.25108986516153, 45.73634239935106, 50.95060794584213, 49.418883169851, 49.40348002218431, 54.45469264061221, 52.02924405374835, 51.53237388980005, 46.756833291822865, 48.39458757831205, 48.91577251495854, 49.8229932015942, 48.50474734460154, 47.418917609799294, 49.93477290676486, 53.84190467096145, 55.27584475855674, 57.40854332523962, 61.08705974394276, 61.09970154300813, 69.71105344833867, 76.72982108208441, 73.01081795846262, 62.78200610991448, 60.85713040444159, 60.62293744856312, 58.68336462205457, 55.204210512099735, 52.330493850092736, 50.710362772787775, 43.59357118606568, 47.11395332890172, 51.17548919493153, 63.26706601727394, 59.54150469072404, 64.20920756555373, 59.708028916389715, 64.35171511865431, 44.52352593022008, 20.949402624560943, 4.599626708415247, 0.2956512564372632, 0.22644391523734217, 3.037773716834284, 0.6031422485266963, 30.77793267465407, 71.9653101890318, 52.36653650960615, 28.602405748059674, 7.09202132878765, 36.64686141475555, 74.33924628842261, 36.52948056497882, 46.629148375603464, 41.22572652755245, 42.78642192963631, 49.601363597377656, 71.58248686021375, 34.748140073591664, 0.2139458649100796, 0.07158363868872966, 0.013633819725064021, 0.11807626608999507, 0.06700807896953437, 0.04142949868354105, 0.05448797297093177, 0.0366600995673047, 0.032362258211979945, 0.051666517111082236, 0.03622594987973571, 0.07850311336017425, 0.18681499896751297, 0.060209715138039285, 0.16848895007804518, 0.08163667344037565, 53.016967465800626, 70.6296568532144, 55.86250189811953, 31.97779747747606, 41.72533058351086, 34.24864976636825, 27.853552718316358, 52.05762632431523, 2.507397686281512, 22.09766668658103, 56.16610511656731, 71.34435976705244, 55.18042525937481, 75.01192492823448, 3.9845385138065588, 0.5498764002996107, 0.4432250715551838, 0.6689180674091463, 5.506626761728718, 25.028855877537882, 39.0640926361084, 53.1124379557948, 64.83359398380404, 67.25401801447715, 64.24872936741, 61.80223334220148, 53.62123996980729, 51.83805204206898, 50.79372490606001, 51.221992815694506, 53.578074286060954, 59.196755809168664, 59.053985457266535, 62.72285676771595, 59.134837273628484, 62.47191136883151, 59.50118272535263, 59.394019649874785, 59.56306203719109, 63.664931635702814, 60.33403527352118, 58.511262786003854, 54.48718555511967, 52.19613698221023, 50.932910211624645, 53.77121179334579, 48.82749172949022, 53.58404021109305, 52.598019107695556, 53.82354013381466, 48.684533103819824, 57.46255044014224, 59.24669150383242, 59.93496940981958, 51.71184978177471, 54.908655997245546, 55.708121330507346, 54.7574290152519, 49.6894992551496, 56.138354347598174, 51.976413649897424, 54.72043321978662, 48.319787979125984, 47.18536007788874, 51.561940716158965, 50.77323444427983, 42.815016008192494, 41.707687762475786, 53.753498369647616, 50.06490145960162, 54.25608734930716, 56.09537693762011, 56.43965121238463, 56.94526041707685, 63.524463715091834, 57.63543675022741, 61.51817921669253, 62.515939974015765, 41.004477393242624, 38.54910896670434, 43.93249142554499, 60.956511497497566, 62.54360052847094, 59.676614653679636, 59.73899995127032, 59.26008639797088, 54.86254853586997, 53.63621557912519, 51.33415691314205, 51.52397217289094, 52.542137099850564, 51.10989932091006, 50.02655244642689, 37.99259916428597, 43.363402581984, 48.75539464335288, 45.27768396562146, 43.10213350480603, 40.522508313578946, 43.513821555722146, 42.95425230456937, 44.304139921742106, 47.49834952815887, 50.369955955013154, 51.104258952602265, 53.06107844075849, 54.96578531880533, 56.86707189006191, 51.69318322212466, 49.00628120668473, 50.42309230373752, 49.08895692517681, 50.65577122472948, 51.207232936736084, 51.66496176873484, 51.03860632065804, 55.91850942181003, 57.493878410708525, 57.311492120066, 62.45339385924801, 66.28147417499174, 64.8071611312128, 65.64347320987333, 70.01244052763909, 68.38556689600792, 61.53098183293497, 65.08939135459163, 62.22892053665654, 60.068973264386585, 55.332825030049975, 52.57100966668899, 47.92480922514393, 50.489741217705514, 54.45442199707032, 64.65083899036532, 63.15547850824172, 65.88561288772091, 62.66957136892504, 66.47432142688383, 51.90673274378623, 29.142525926713024, 4.518825882865537, 0.3267596968479695, 0.48659971344374847, 3.8801701270764877, 0.4961749851222962, 38.25700613760179, 75.065520194269, 57.6145109053581, 29.46000845201554, 12.248624601671773, 29.849260545546013, 54.85256610378143, 40.345938897901966, 64.60188781061481, 41.451466775709584, 40.780572814326135, 57.23718673952165, 79.6930697656447, 45.144511653530984, 0.12278986719226646, 0.14423813039977706, 0.006588666893226365, 0.10116078425198795, 0.06809530329079398, 0.004809470302725752, 0.16634770368616428, 0.1483371144821567, 0.23478121947376962, 0.2449253727231295, 0.32413149432789895, 0.190551056556644, 0.37578420653458566, 0.18003587160379658, 0.28215968200275976, 0.114822315292493, 61.84515191662697, 81.26145301326629, 63.65540027618409, 38.341109598836596, 44.85678226717057, 57.366232718190844, 38.67973566055298, 71.51403365596649, 9.044023656076002, 26.78107277039559, 65.64189641706406, 76.42280147921655, 59.38804588010235, 82.40418064978816, 4.16972218982635, 1.4907253437465238, 0.3510954297117649, 1.5423870038601661, 9.855941534042358, 29.767047666734268, 48.916870778606786, 59.98425006866456, 68.48851342355051, 70.5697230369814, 68.37085016312139, 64.48556992315477, 59.02706623077393, 56.40418514128655, 55.50904143241144, 54.822975743201475, 57.19295024871827, 62.25544752613191, 64.33049509602209, 64.02526017158263, 61.40180249367992, 64.92577752759381, 60.82696345544631, 60.546733640855365, 63.891652476403024, 65.597075493105, 62.9797367126711, 60.549800934330115, 56.45306964074412, 54.641589656952895, 55.80230920545517, 54.368910404943655, 53.59729782227547, 57.41264612443986, 55.02599370095038, 55.574399886592744, 52.721181531106275, 60.126455599261874, 61.55289219271753, 63.83187555497693, 52.967141597501694, 58.508838761237364, 59.1366062625762, 56.686693852947606, 53.14408756071522, 61.58114502506872, 54.07969836265811, 56.453465800131525, 52.271183690717145, 55.52803747115597, 53.925239347642474, 56.624649801561915, 46.2614457837997, 46.700296248159106, 57.3969566437506, 55.076509906399636, 57.3866839562693, 62.8297648891326, 58.85797285264539, 59.51012180697534, 66.8981021450412, 61.36548526825444, 63.46112528154927, 69.3089791267149, 42.65615217147335, 39.288393374412294, 46.00745662566155, 63.62689248977169, 64.47537176070675, 64.63694987758514, 65.10679883341636, 64.12732416583647, 56.90080035117365, 57.82878998787173, 55.067880692020545, 53.959281598368, 53.91938717134538, 53.26626939158286, 51.69241051520071, 43.831035398667865, 47.45144582563832, 53.4345273048647, 54.08091037504135, 49.26137255084131, 47.093302049944484, 47.35278644869405, 48.4703246239693, 51.655948162078865, 52.29267043452109, 56.612153130192915, 53.201562050850164, 56.71281291592506, 61.45744523694439, 59.434365149467226, 55.75170670786212, 51.00198315035913, 52.66093000288933, 51.52643542135916, 53.56738190497122, 53.306528599031516, 55.26634870036956, 53.856335070825395, 59.362821117524184, 60.13183316876812, 58.05896643669375, 65.19688783153411, 66.78729518767327, 67.31532466027045, 70.85310643719089, 76.66533731645154, 67.70641634541174, 66.51145058293497, 66.5719021520307, 62.613477553090746, 60.698113595285726, 59.86510415231029, 56.67309891793036, 50.861883932544345, 52.78907383641889, 55.61089361867597, 67.12381101423695, 67.03902506059217, 69.36503764121764, 66.36252603223248, 70.80806978287237, 59.385963101540845, 44.22476683893512, 7.096746804252748, 0.6529929993614074, 0.22592087636791894, 8.028459750836896, 2.73284204063877, 38.98291918539232, 84.37970592129616, 62.94857348165205, 40.089341363599225, 17.172619065930768, 47.613455403235655, 87.84686934563422, 52.2292378640944, 64.20614027207898, 58.96377094330327, 58.904425482596125, 66.63834710274973, 91.71732302634948, 57.01908726846018, 0.21386818359455756, 0.20064469396827683, 0.090152652363383, 0.2502008073873097, 0.2283755752948984, 0.13372453890981215], [0.08702397226325928, 0.10125276076817706, 0.1315745897591114, 0.11378002202799244, 0.0786262926375193, 0.0737816981610752, 0.05057065514847637, 0.12112623065589898, 0.06040455427982154, 0.18518174547822247, 42.167067912317094, 65.47853754412743, 51.065819724913574, 45.94175300290508, 41.824656763384425, 53.83924530398462, 72.38277589121174, 35.01701070416358, 8.24851599431807, 34.84511283136184, 57.38855492684149, 69.55739067446801, 48.11092568982033, 74.84913087660267, 21.37639968625961, 0.9966675192117692, 0.5589047158437391, 0.023340659343727657, 0.055011908163226424, 2.8811581336682845, 13.766751500868029, 52.038755801416215, 65.53149738619405, 64.85832845011066, 62.711536807398645, 56.314813936910326, 52.18640558181271, 48.5326785425986, 49.64731808631651, 52.488949760313965, 56.34123894476122, 55.46398124387188, 62.546177525674146, 62.76295515798754, 68.48677189119401, 62.6851902469512, 55.33968133311118, 56.88872337341309, 61.61948619350311, 62.7179616497409, 57.98084066760156, 53.27732263072845, 57.16535245218585, 52.02346640248453, 49.32259682686099, 46.57793006589336, 46.52863763993787, 47.33219008291922, 51.343994217534224, 54.475912663244436, 51.517335522559385, 50.12792218116022, 55.35852047704882, 54.19788329832016, 56.68386582405337, 59.983312622193374, 56.820227023093935, 47.331915517007154, 52.82539498421454, 48.42819444594845, 44.91141696130076, 41.817117967913234, 33.23829427842171, 33.84609691558346, 43.34266108851279, 33.881637511714814, 19.810871924123457, 24.037437592783284, 29.152451484434067, 44.407153129577644, 53.66777496953165, 49.55542872028966, 52.898460895784446, 56.95666666953795, 59.85849103619976, 61.61318686700637, 63.17247021582819, 59.01995889602169, 42.86657556410759, 41.52882768261818, 43.87806461703393, 63.34743930447487, 58.23768531122516, 59.35908702112014, 56.92615062959733, 54.96065485861994, 52.50276434806086, 50.59080108519524, 48.618460778267156, 48.723901933239354, 43.83323584833453, 39.588258574085856, 29.78656538071171, 21.28597532549212, 24.70672534358117, 38.49119517111009, 31.981696313427342, 34.70824172419887, 28.671472803238903, 35.37200089423887, 34.8068344208502, 33.62625983453567, 34.240926619498964, 43.08722457578106, 47.261975734464585, 55.97819220635199, 52.18804905491491, 52.01893214256533, 47.15727198508478, 50.011019860544515, 47.255056673480624, 50.17901497502481, 46.49141826937276, 49.47007010059972, 46.44204347364364, 49.787758550336285, 53.69968345088344, 58.64317993963919, 58.327597802685155, 62.026400719919515, 56.66579154229934, 72.81924939924671, 37.30986748972247, 27.546537037818666, 57.71376648256856, 52.92910245157058, 59.96458330462056, 56.345212305745775, 57.46944204453499, 54.23593813373197, 50.431905869514715, 46.22699952894642, 49.82671553088773, 52.05771261645902, 57.23446461462206, 60.01475041912448, 63.11912990385487, 64.34515299335604, 59.47837414280061, 46.72157510634392, 6.302487927098428, 0.3653490471263086, 0.48107438089866794, 2.4341283017589204, 6.136090197870809, 1.7818863137114433, 73.72552087230068, 54.15363111803609, 60.4971391923966, 23.84581804275513, 13.280362890612695, 25.368097751371323, 79.01792003262427, 37.3547629387148, 28.618261929481264, 33.18846448775261, 43.04878142572219, 50.033373448156546, 68.17385304358699, 34.071790095298525, 0.17828660175925304, 0.04576175270842449, 0.09858770175806938, 0.10173625417894895, 0.08146211264594909, 0.037596986794303504, 0.05240232541015553, 0.04795290972857226, 0.1721230107209375, 0.05704991271599166, 0.04699978909845795, 0.049433930055989374, 0.10214248762255716, 0.08231233234607405, 0.06966866402616424, 0.12333253323430977, 48.68996166413831, 72.53701917586788, 58.74136078742243, 40.62387412594211, 36.16842639061713, 66.78835422761979, 63.95681873444588, 38.71279731873543, 8.567673371684167, 42.32809689737136, 63.16034616962556, 74.67526005160424, 54.449111107857, 79.1698020504367, 25.987292912698564, 0.8544143073020444, 2.0332794756658616, 0.06573348486375424, 0.3115286738161118, 2.2882369689403044, 17.436037601963168, 58.35505439389137, 65.11502012129753, 69.79120316043978, 64.15057989858812, 61.6684530627343, 52.365242127449285, 52.64835880648706, 51.42075107943628, 54.822277561310806, 58.68372548011042, 60.07399389820715, 62.92105805489325, 65.11758142902006, 68.00862712244835, 62.425639167908706, 55.49277144093668, 57.92933994723905, 63.125935216103834, 65.25757866521036, 60.77332504333989, 56.70412486599338, 57.61975511427849, 53.85042405897572, 50.995883864741174, 48.311531389913256, 47.1163930431489, 50.246048281269694, 51.763060246744466, 56.52214650184878, 53.79235729094475, 52.72220134735108, 56.89339883865849, 53.70836365607477, 57.51060731949345, 61.6393804550171, 57.17369533354237, 48.88765696556338, 53.32737599649737, 48.363804817199714, 48.286573348506806, 44.90354476436492, 39.213695756850704, 38.771589725248276, 45.31595060902257, 39.29502610237368, 23.48802531919172, 30.421000911343484, 31.2336826709009, 46.446479674308534, 56.997506387772106, 48.969783552231334, 51.50227362109769, 56.01040663257722, 60.71024156385853, 60.879997822546194, 61.75919317430066, 59.26420096428164, 39.69798295728622, 42.33045424184492, 44.053676974388864, 61.41608384347732, 58.674292179846, 59.407838159991854, 58.12335606544249, 55.46187885345952, 55.14212723701231, 52.57042523353331, 49.23117422288465, 48.88817079605595, 45.622232806298044, 39.24984432035877, 34.14336550620295, 26.098127326657696, 27.966693485936812, 44.831588883553785, 41.515177834418516, 43.002956374999016, 37.975638835660874, 38.98015391442084, 38.56233519892539, 38.71213051580614, 39.71384894463324, 45.24304943699991, 49.914564855637096, 59.5013003964578, 56.123076715777, 54.006106853485115, 50.68714626373784, 53.39636264308807, 50.64492194883285, 53.20449598373906, 48.44960666471913, 49.84251876031199, 48.6674629488299, 51.97138909370669, 54.511692523956306, 58.41176794421289, 59.09761790306338, 61.659282561271425, 58.473019676823775, 65.29395080381825, 36.068668750024614, 30.338136919083137, 56.16779565811158, 57.45730230885168, 62.30251596819971, 59.88513177441013, 58.71404540154242, 56.91846670642976, 53.02872673157723, 49.80136525246405, 53.579851119749016, 55.86058385910527, 58.26130582440285, 62.94832244996102, 66.16690958699873, 68.7612985795544, 63.58795512107111, 51.81856962942308, 6.533920024671863, 0.1916774049881966, 0.47970017238009366, 2.7595305827356156, 1.8752334531276458, 4.231642686551617, 78.72625258661087, 61.40778410819269, 65.6113136968305, 29.548261780892652, 15.874318461264334, 24.36108216162651, 72.17431760603382, 35.675074592713386, 42.21503065478417, 44.47223309547671, 46.197934765969556, 55.049731885233236, 78.66833486864644, 43.394620726185465, 0.14795897348273188, 0.06217686421868782, 0.15458883627528144, 0.0275812988289662, 0.07780145343032577, 0.06843265010825089, 0.3122723306859693, 0.1919761639569075, 0.3454911901104835, 0.2598656347442058, 0.18708702146766648, 0.1725460138292082, 0.1481743054764886, 0.26650884278839637, 0.168370436276159, 0.3017536676939457, 56.474038631685325, 84.19293834317116, 66.0012286709201, 61.773592195203236, 54.81155772362986, 69.6297505594069, 78.33618071771438, 45.08873554968065, 15.765817857557728, 46.911131489661436, 70.5786503514936, 78.9161031476913, 57.75546519987045, 87.485211126266, 27.31075748320549, 1.744860242451391, 1.5879034130804002, 0.16613391919001458, 0.6749934510838601, 3.8795567664407917, 25.02130727614126, 65.09480422542941, 71.48443545064619, 75.44138523840135, 69.17368873473137, 64.36040709095617, 57.3225571263221, 57.45784751830563, 55.10358210532896, 59.26229861474807, 61.87285561715404, 62.4453765346158, 69.10750266044371, 71.13546217641523, 71.47553167035504, 62.837758679543775, 58.7299741468122, 58.91672995782668, 65.28200326427337, 66.2410423832555, 61.71308179055492, 56.93986323571975, 61.10620875512401, 57.13675052888932, 54.70162937718054, 49.03709926912862, 49.130184958058024, 53.172501210243475, 56.728161150409335, 59.90113896708335, 56.145167504587484, 56.01175985028667, 61.201832217554895, 60.23766263838738, 62.08283185958863, 65.31234671992641, 62.05672064135152, 52.50202302009829, 55.63582812586139, 51.97965745002993, 51.567377121217795, 47.29894015096849, 45.09434061665689, 44.37293829456453, 52.446125322772616, 41.13224075686547, 22.480213488301924, 31.40696317918839, 37.266003624085464, 52.13292014214301, 58.06270837783814, 50.85940891696561, 53.624067998701534, 59.81377993860553, 61.463634737076305, 60.13213126890121, 65.74409377190375, 63.52501676928613, 39.297269698112245, 41.875878995464696, 44.237055624684984, 64.94781340322187, 61.35892314295615, 64.9682411070793, 60.79598849819553, 59.05044355700093, 59.33738846932689, 54.828035600723766, 46.96256160736085, 49.526501240268836, 45.67620461986911, 43.66243231681086, 37.15497309161771, 27.820304747550722, 30.08111772998687, 49.83263438747775, 42.687436995967744, 46.53776891769902, 41.99741755762408, 48.51498473075129, 46.829208866242446, 46.65069003258982, 43.200102544599964, 48.501597681353175, 54.25624424411405, 63.13745521729993, 59.49576985451483, 56.50921052502048, 52.355275384841434, 53.91908514884211, 52.7629469287011, 54.60988121647989, 50.68287872499036, 53.37635855520926, 51.475079828693026, 52.961822863548036, 57.37166127850933, 62.106303322699766, 60.054127093284364, 63.1284337659036, 58.08091209780786, 73.70529713169222, 47.023056322528475, 34.45116173836493, 58.62552927386377, 58.0414334420235, 65.53163466915008, 61.95247580928188, 63.87473921622, 59.91010158292709, 55.93660331541493, 54.23742078965711, 56.184402973421165, 62.208018226008264, 62.57108849863853, 64.61466689263621, 70.06882067649596, 74.26647063224547, 68.86997176754859, 61.13874873807354, 11.869898188498713, 0.496463677695682, 0.6197713820203659, 6.752081273063538, 14.342527004980273, 2.7205865950353685, 87.81677692167221, 64.59218778917867, 72.054089115512, 36.77281264335879, 23.974044246058313, 35.3245480598942, 88.48417605123213, 49.583693319751376, 42.66681709597188, 52.220408608836514, 61.647640966599994, 66.72728292403683, 87.09690432394706, 56.102201861719934, 0.27422576902374146, 0.26617997656426123, 0.22010712704110533, 0.15375965334955724, 0.2460391573127239, 0.20621643611981025], [0.06310763806405087, 0.019284342528290806, 0.05357504131332521, 0.03224100947620408, 0.15076510758409578, 0.1679787201987159, 0.08204246255298776, 0.26565220327146594, 0.0294591163119842, 0.2011456848272393, 32.949847098319765, 68.04007668648997, 45.876437694795676, 43.455115441353094, 50.601022781864295, 38.42532288643622, 72.85913205915882, 48.40037699668638, 1.576261082964559, 48.00358218531455, 65.84997423233526, 59.76177323249079, 42.559591262571274, 57.95797717186713, 41.766091854341575, 0.27362273525326486, 1.6317545310143502, 0.13419716919381774, 0.09502348535123373, 0.2415479975001466, 0.8718391303573886, 53.33785264722763, 70.7797424254879, 63.5222436535743, 67.45929133507514, 57.360902217126664, 51.45223986717963, 50.73739574801538, 51.09026785819761, 53.52040759978756, 57.170431921559, 58.027297219922474, 58.31729765861266, 62.71602792124595, 74.82612225317186, 74.40908016697054, 56.82647143640826, 58.609675053627264, 61.02775742930751, 63.635855105615434, 60.10533363588395, 60.70521308529762, 60.77559609566966, 53.541309910435835, 51.800856205724905, 49.56380690297773, 46.435316608798125, 47.69558198990361, 48.06462603230631, 55.06644510453748, 56.019330024719245, 48.5226058959961, 52.10220798369377, 49.54701131389987, 53.803849835549634, 53.98345516573999, 53.37674294748614, 53.4298518396193, 53.52953103280837, 38.01820047440068, 40.05499709037043, 31.39023230921838, 35.04725217819214, 41.95735839105422, 48.74058769595239, 57.11786039413945, 45.8985363283465, 41.41325112312071, 31.99435772434358, 20.630721815170784, 28.982075491259177, 39.97816962580527, 50.04818039555704, 52.64460509823215, 60.19468522840931, 55.886349908767215, 66.16017095504269, 52.580717532865464, 41.79063804687993, 45.658169561816806, 46.16372777569679, 60.92027664184571, 67.59078487273186, 57.01272910641086, 56.63812314310382, 54.30139072479741, 49.8840880393982, 36.41698306606662, 34.07766188344648, 35.98682457400907, 40.351908745304236, 44.57666227894445, 55.80662773501489, 51.830238680685724, 44.35070237805767, 48.50351964273761, 40.97932323332756, 48.054737737101895, 40.210158209646906, 33.601874459174375, 25.630235633542462, 31.260949027153757, 30.765549752020068, 39.1228065952178, 46.92871547514393, 54.972912265408425, 53.24277439425069, 51.199313671358176, 50.42797565460206, 50.20287083041284, 52.11496745386432, 49.150687186948716, 48.23924995237782, 47.27970092527328, 50.62698887240503, 53.630363402828095, 54.76665835226736, 56.70667048423522, 57.350201991296586, 57.66480353570754, 61.16344398067844, 47.98195031381423, 33.30376648133801, 48.98830498418501, 50.27616423945273, 60.98319538177983, 58.37126554981355, 55.713797000146684, 52.576002843918346, 55.495309214438166, 50.57775135963194, 50.22847606289772, 47.14298279054704, 51.67898816447104, 53.6908620403659, 58.83920431137086, 60.52640399625225, 65.54773599870744, 71.89360926228186, 39.514419955592004, 0.7123749871407786, 0.21568375068806836, 0.12896537089780455, 1.2326713843691735, 1.1915859051289097, 16.795620456818614, 77.52500318711805, 56.56392366655412, 63.19506306802074, 40.8886537244243, 33.499700638555716, 14.442466055193256, 37.94004724871728, 43.780762380169286, 34.95183660138038, 34.03952860063122, 21.464874629051458, 46.20401836210682, 71.821045414094, 36.13691014628257, 0.11215997589451653, 0.11267982783817476, 0.047714227374883435, 0.025020190289304144, 0.12574594002217054, 0.048761212927920204, 0.0974212869280769, 0.02225029597719831, 0.04727918902532228, 0.18258286880389338, 0.16408791284888022, 0.09991922385750279, 0.14542412643711414, 0.20248301387313875, 0.04045541022693919, 0.26029182477824153, 35.67621208006336, 78.43540099359329, 49.31444614164291, 38.94245209232454, 58.95270985941733, 51.30788487772788, 93.6709693170363, 48.71799484375985, 3.6265175573287474, 50.27883929591025, 73.03952970812398, 67.62142642851799, 46.15536136011924, 64.4281699580531, 44.39026732598582, 1.064227893948555, 3.2903174815639376, 0.6194922195807581, 0.09561361054018622, 0.145579197954747, 1.794804762448034, 55.85587701489849, 73.330687246015, 65.42436176730742, 69.54745138845136, 60.330905222123675, 54.970590222266416, 54.927075447574744, 53.60103976341986, 57.93387420715825, 60.90864681428479, 63.24786993765063, 61.85404000743743, 67.18281915110927, 72.11911416822865, 67.0341456320978, 59.21081750623642, 57.67974384369389, 62.1886024936553, 68.61249169995709, 64.29308352931854, 64.14251942788401, 61.05493553223149, 53.46956191524383, 54.56926899571573, 52.87253402894544, 50.23790544079196, 49.94751276508455, 50.997660698429236, 56.274146802963756, 57.52004061975787, 50.87761263693533, 56.34337271413496, 54.54713506083335, 54.75240838143134, 57.56777586475496, 56.83161366370417, 58.57771165909306, 55.19657365737423, 43.47774751724736, 44.239518873153195, 39.11982951625701, 44.21080712349185, 49.78459319760723, 55.17973099985431, 61.618972363010535, 53.46626320192891, 51.70671932158932, 42.206432819366455, 28.74325609976246, 33.78147194462438, 44.648492643910075, 52.022493654681796, 53.30522637213431, 59.30269118278258, 52.95009889910298, 62.55975677121071, 53.259589595179406, 38.904377645061864, 43.31127428239392, 45.64342537233907, 59.289798352026175, 66.95167387685468, 58.38892013795915, 58.35830603876422, 57.35700338117538, 52.24594716102847, 40.170636407790646, 38.48216195260325, 41.36555510182535, 45.20692048534271, 48.45564711478449, 58.724019988890625, 53.718475526379, 46.54488017482143, 51.27528605922576, 50.862221256379165, 55.843066553915705, 54.11360725279778, 50.031953550154164, 40.43448640454201, 35.4986346152521, 36.73010587692261, 43.75071310227917, 49.36844933417536, 56.56720276801818, 57.008065408275975, 53.45444510059973, 53.12112992809665, 53.63398767286732, 55.33728868730607, 49.80846474247594, 48.23413125930294, 49.78758988841888, 52.34537924489668, 55.132666480156686, 56.6650737485578, 59.89815796575239, 57.487834038272986, 58.025387025648556, 63.24593620915567, 45.38048928783786, 37.06928107046312, 48.99355703784574, 52.77805589860486, 65.38808376558366, 59.0159345442249, 58.326774104948974, 54.98374585182437, 57.03201932291831, 52.76022088143134, 51.633982889113895, 50.04571714708882, 54.0794434085969, 55.62424928911271, 63.03744262264621, 63.245453757624475, 66.19436617820494, 72.09757251124229, 47.23406022594821, 0.6116020042569407, 0.21536464442408856, 0.4249440992791807, 3.0858622202950143, 1.299068408627664, 21.531786341820997, 82.92556562731343, 63.01627359082622, 67.66576490094586, 50.02537181300502, 41.76118104688583, 17.797050591438047, 40.70329819956134, 45.044095054749526, 45.14100505459694, 37.251600680812714, 23.820548172919985, 50.75210855853174, 79.91818243457426, 44.89094218900127, 0.12642449474022274, 0.1947907250254385, 0.09026885257973787, 0.1132692252435992, 0.10771919402383989, 0.08718878841928898, 0.18774974880920303, 0.08015903539114422, 0.11331136774031386, 0.41240201421803047, 0.2635135615785276, 0.2898511741190188, 0.32834439568461915, 0.45341391837404627, 0.378969477549676, 0.4248040584066222, 43.797040216384396, 91.49765460721909, 60.43194547776253, 61.27945592326503, 69.92486969117196, 52.142267150263635, 75.15559350290607, 59.732645711591175, 9.215834256141417, 60.673135942028416, 75.83134728093302, 72.65924023043725, 50.84657099939162, 69.90476362166866, 49.97218055109824, 1.3104364179795789, 3.5143713556951095, 0.8941167220473291, 0.5475020180306127, 0.6648568208179166, 4.210938945893319, 62.548083797577895, 76.69433932150565, 69.80623368294009, 76.67572375266784, 66.5559616396504, 61.57184900776033, 61.65097498124646, 57.72499230600173, 64.85448844971197, 65.15656978853288, 68.70084701045867, 63.89924618505663, 72.28038634023359, 76.61040059981808, 72.06403624626898, 60.50840031716132, 59.889269874941924, 63.95951340275427, 68.27960798817297, 64.09889482682752, 66.02917948076802, 62.45728485045895, 58.660536427651685, 58.028705350814334, 52.22454670936831, 50.88922285264539, 52.64540133937713, 52.35858586526687, 60.784029191540135, 60.77972635146111, 53.00390597312681, 56.453748210783935, 55.55449385796824, 60.363264776045284, 62.4430662585843, 61.9483220192694, 62.8430970253483, 60.99017327831638, 48.483790120770855, 48.62829808265933, 44.08582472032116, 45.95412808079874, 53.716235853010616, 65.22339520915862, 62.28869745808264, 47.61801711974606, 49.720313395223315, 42.389760478850334, 35.54933909446963, 39.436600131373254, 49.15067149746803, 53.1462291748293, 52.682228472925004, 62.83810777048912, 56.28828302506478, 65.91413636361399, 54.48091760758431, 39.3359128890499, 44.93756740323959, 46.61991119384766, 59.312277455483716, 69.53881432933193, 59.741863281496116, 58.09971986278411, 58.899000844647816, 51.836063400391616, 42.16930366331532, 44.130406379699714, 50.897636336665, 53.960670117409, 54.26313977087698, 55.199719398252434, 45.49217093375422, 39.66496444517566, 53.34574053364416, 51.32111110994893, 55.852499854180124, 52.07358252617621, 51.14074091757498, 43.45462906745173, 43.879441368964414, 42.02891026773761, 47.900808242059526, 51.37891115680818, 59.55229513106808, 58.76034898142661, 58.70796572777533, 54.77639759740522, 54.52893134086363, 56.75104033562445, 52.7078886185923, 50.39318030880344, 53.996340151756044, 52.10900152883222, 57.87895710237565, 57.778524814113496, 61.421524170906316, 59.77533678854666, 60.223581329468765, 60.92208093212497, 59.02760359548754, 39.26426687548238, 45.9673386235391, 54.10744913162724, 62.984463168728745, 60.97278148897233, 60.729759277835974, 58.6524445779862, 57.993302037639005, 54.18101318420903, 55.23051392647528, 51.35775781446888, 56.06911666931645, 58.056091339357444, 64.430990142207, 65.77151898414859, 68.53951208053097, 77.92331203337639, 55.4027138217803, 2.2376945326405187, 0.47722353269496276, 0.36009454198421975, 5.433484363940455, 5.777313939986691, 20.939584932019635, 91.21145494522588, 66.46425662502166, 73.46020390910488, 50.894400381272845, 43.4521109058011, 25.83070012830919, 47.77477464368267, 56.26667468778549, 53.709104984037346, 46.06337785720826, 33.839774054865686, 64.30932214183193, 87.08869088080623, 57.44944580139653, 0.18303878304939117, 0.23846263967214093, 0.22137553881733651, 0.26467531859394045, 0.1590650726950938, 0.19520589871512306], [0.2591291791008365, 0.14821002049551857, 0.044534663714829, 0.06565123000332425, 0.22384160648911233, 0.25329820811748505, 0.26101400054270224, 0.15719517464599303, 0.3459024873952712, 0.6766733899712564, 22.195061099144723, 66.18071633000528, 51.074766651276626, 34.977814459031634, 19.81273897232548, 54.01162170594739, 21.415070333788474, 31.340973223409346, 6.632265612002342, 37.215103026359316, 71.13480321822628, 70.10239616517099, 67.21694377160841, 58.023359160269464, 63.010240985501206, 2.2797948025888015, 5.013199948495434, 0.8951975188909039, 0.08861795608555117, 0.5399187894598131, 0.6954215226634857, 50.035797472923036, 73.8937121052896, 66.90174994930145, 62.201008950510335, 53.19496070185016, 48.43860833875595, 47.440274915387555, 53.60768818086194, 54.06519343776088, 55.91024106548679, 58.360149552745206, 66.45563525538292, 61.839950853778475, 73.25145536853422, 82.56562540608068, 53.12393834514003, 47.94082034018732, 53.64368769430346, 64.62551224616267, 61.07568094807287, 67.28620498411118, 61.11704626391011, 52.9208811636894, 51.9886161435035, 53.7025938495513, 45.64643775263141, 47.21459350278301, 47.25366815443962, 49.740337094952984, 55.76078307244086, 54.49140210305491, 51.731183144354056, 56.2858001647457, 55.03356387538295, 55.105868847139426, 59.59989701547931, 56.27584911161854, 48.838195877690474, 47.414493176244925, 51.78311532543552, 51.01470339682795, 70.59368871873426, 53.963694264811856, 49.061633694556456, 57.00975202745008, 64.28504659283546, 72.53356749011625, 76.95986809269075, 57.54191567820888, 35.28059397974322, 21.880334038888257, 25.926674642870505, 39.936325780807, 54.555270056570734, 56.46891993861045, 62.17254823254001, 51.429835288755356, 46.39323349921934, 43.72620221107237, 44.89534701070478, 59.2382505632216, 61.730277461390344, 61.293521542702955, 52.52110927335678, 32.82828304075426, 25.43850821833457, 28.902712214377623, 45.01470473504836, 56.66459129702661, 64.70877239781042, 61.47193447236092, 67.9631825416319, 60.62003097226543, 58.79794097715809, 46.77905351884904, 52.33012906966671, 56.582790267082956, 63.8414853618991, 63.1171844082494, 49.30713484364171, 32.954200929211034, 29.239761483284738, 32.886928358385646, 46.47218296604772, 48.758536461860906, 53.54048229032948, 50.902123528142134, 49.328625509815836, 49.03775038257722, 47.444871933229514, 47.52792027688796, 44.4418857174535, 46.109457861992624, 50.21452419219479, 50.64759700529037, 57.78377686777423, 58.21513952747468, 59.60608259324105, 60.14849931963029, 64.79857898527577, 36.17306263216081, 43.16481298015964, 55.13554549986317, 59.49140425651305, 59.94237484470491, 55.99800409809236, 56.83528500218546, 53.29882114164291, 57.302992343902595, 52.59304161994688, 52.72509213416807, 51.45034928475657, 53.555767766890995, 57.00589633757069, 56.203049921220355, 61.45514672802341, 59.92443000116656, 74.50568814431468, 32.24636216317454, 0.427978144538018, 0.11424933515128591, 0.06983740255236626, 0.4408059497514079, 0.3344930480084112, 32.73327735162551, 67.85737268386349, 55.8528999359377, 65.13188631303849, 57.77129196351575, 43.473566270643666, 13.426596695376983, 19.806280789836762, 22.924270899065082, 39.8198196195787, 42.39709531107257, 49.479119008587254, 45.37391539542906, 69.68882145420199, 29.939894753117716, 0.26167059918084457, 0.048069673019551465, 0.15872174273094825, 0.14740231867519119, 0.05844901143122585, 0.08346416086198823, 0.16357844905747523, 0.08752156169183793, 0.07996251085592855, 0.09587807941340631, 0.20412585878324127, 0.13298615272487366, 0.2333628076819643, 0.11815249183846098, 0.26769995629306764, 0.495212686758849, 25.295131860240815, 75.33460263283023, 55.33889685907672, 35.65711405969436, 35.40161871141003, 59.39957764840896, 32.42549092538896, 36.76133578823459, 8.5877735576322, 43.161055349534564, 75.2099810877154, 74.46524066309776, 68.47870749811973, 63.48917807302168, 64.7198844725086, 3.217204501551967, 3.2025287084041105, 0.37613875202594266, 0.1806622250906883, 0.5407506996585477, 0.5764212243018613, 55.61542787859517, 74.98016157457906, 68.10689818474555, 65.58428464397308, 55.49243019473169, 50.634206033522084, 51.66564033877466, 57.10177867643295, 58.979495725324085, 59.85590227188603, 63.22261771848125, 67.50420247354816, 64.34807515913441, 73.16295885270642, 69.43598547289449, 50.71315550035047, 48.709079296358176, 54.53474037108883, 64.17796196476107, 63.99046090341384, 68.84719064158779, 62.885140911225356, 55.124911954326016, 53.933335119678134, 57.4240170755694, 49.15878688135455, 49.03403589802404, 47.32265872340049, 50.351446290169996, 57.003892006412634, 58.019719200749556, 55.88485548573156, 57.844063697322724, 55.8229761738931, 56.54393919052617, 59.891693899708415, 58.20248988366897, 54.7002604699904, 55.700260900682025, 60.74080859461139, 63.833546484670336, 73.6795114701794, 57.15327547442529, 48.794304555462254, 57.674978163934526, 72.03429683562248, 80.33288678815289, 82.5259780883789, 70.16826844984486, 44.6220794031697, 30.77623428836946, 30.939022456446004, 45.93072329798053, 55.04930826925463, 61.29597302406066, 65.634793004682, 50.025226685308645, 41.49642890499484, 41.959758881599676, 40.59156556283274, 55.93870178345711, 63.19913841062977, 62.924329311616965, 56.67998267758278, 39.791641312260786, 32.679240818946596, 33.76126781586678, 48.595322716620664, 62.05248448156542, 65.76712985192576, 63.245489058956025, 68.1475966976535, 59.75191631624776, 60.159434887670706, 49.548807759438795, 49.742364960332075, 56.32676539882537, 65.72829446484967, 73.07472121331, 67.93139565375544, 55.84721249918784, 42.831325223368985, 39.528893501527854, 47.22491718107655, 51.42374384787775, 55.69329869362616, 52.69461924029935, 53.16863767562374, 54.535403251647956, 49.61060470150363, 50.651884155888716, 48.820545211915054, 48.24376460044615, 54.9538024779289, 52.08169398769256, 57.970964139507664, 58.695908361865634, 60.26305998525312, 61.205770277207904, 65.43522673268473, 38.406330770061864, 44.33289089510518, 56.55074058040496, 63.33179689222767, 62.15814528926727, 59.89405908892232, 61.8238809031825, 57.68430948257447, 59.585854930262414, 53.75549093369515, 54.144648890341486, 55.0621344197181, 56.28726320881998, 59.033267498016365, 59.9104545962426, 65.27842998504639, 60.90827418911842, 75.42791581922963, 33.15785823329803, 0.5228008918704525, 0.11374317319883455, 0.2998026868989391, 2.2625304902753522, 0.5802877619862556, 37.907887735674464, 72.9644633877662, 60.22476980763098, 77.7070717657766, 66.7143234129875, 48.61406772367416, 15.74419677257538, 27.35580394344945, 21.342149549914947, 43.606009021882095, 47.52061682362711, 44.67208570049655, 51.51684914865802, 77.62719661958756, 34.904164114306056, 0.531361771206702, 0.162620977047951, 0.14216900352508793, 0.05542180350711269, 0.0675024431679518, 0.22646338919237738, 0.3099241179804648, 0.1772790735647563, 0.18548626542812396, 0.18721907970405396, 0.4237237518593189, 0.49654512816379154, 0.36363025225939294, 0.27028783194480405, 0.6100145475037637, 0.9819417771312499, 32.38839707066936, 91.0885121745448, 69.14117228600287, 52.95085199417607, 31.092418509144938, 78.29680796592467, 28.388201190579323, 39.52300602389921, 14.100874681626598, 47.189541324492424, 82.34008912117251, 82.18778348738148, 77.31229305267334, 70.10224711510443, 70.64831164575392, 3.446539356823891, 13.576769540386817, 1.9287383820741408, 0.25541500098282294, 1.2367225798868364, 2.409885847760785, 61.2986873042199, 78.89372994822841, 73.86297641261932, 68.94416732172813, 62.264492511749275, 56.464840673631244, 56.63715431767126, 62.589107867210146, 60.9797005499563, 63.85628446455925, 65.36402786931684, 71.4939981891263, 65.53335266728556, 80.09870559938493, 74.94144778097831, 51.7932350404801, 52.01562558451007, 58.58958467360466, 70.8224884156258, 64.80476456303751, 73.76126935405117, 64.8207756780809, 58.61755901767362, 56.03317599142752, 58.803961815372595, 49.648231998566665, 52.41192617724019, 50.52244986257246, 53.220707139661236, 58.951792024797015, 58.78578555199408, 58.683780393292835, 59.010180427182114, 57.55863674225346, 59.80279730212305, 63.28413224989369, 65.14686584472656, 58.98097445887905, 59.79070463488179, 63.9565324014233, 66.50598279891476, 69.25703125615274, 60.90811729431153, 53.31957832459481, 64.09861633854528, 68.99587985007994, 70.82346900816887, 73.48555810989873, 63.284367592104026, 54.275742346240634, 44.57429708973054, 33.99132267121346, 47.523817477687714, 59.123654596267215, 64.51486218360164, 68.54235187653573, 51.31921268278553, 42.37458090628348, 42.810301319245376, 41.5905265654287, 58.617319753093106, 64.34716124688426, 64.10355068022206, 53.771490281628026, 38.75309182751564, 37.92722502062398, 44.03371211021177, 55.84197221263763, 63.224092529666045, 60.62939759223693, 56.80254497835713, 65.96985755428192, 60.99191481067289, 63.20652031129407, 53.162997307315955, 52.000497002755445, 56.433245981893236, 60.65903894362911, 62.04872685094034, 58.29648948484852, 53.55872523400092, 45.207830475222686, 47.20405801650017, 54.61640804044662, 56.7860004209703, 57.426135155462454, 57.80595394872851, 56.47197938734486, 56.74635310326853, 51.14594198042347, 52.9117577306686, 48.946661180065526, 49.51878593813989, 54.57116742287913, 55.401144873711374, 61.24190315123528, 63.180161983736106, 62.04412983309839, 65.85356712341309, 65.86775041395619, 43.19780403567899, 45.26890962354599, 58.80700557462631, 65.80294893633935, 64.81751226609754, 60.173198484605365, 62.047361866120376, 57.36973539475472, 60.621270441239886, 54.57276774990944, 56.38551073689615, 57.92441737267279, 58.110322029359885, 60.717937254136615, 60.80921080804641, 66.79587733361029, 64.52595072407877, 77.85994222087245, 39.44905365667036, 0.6903788867977358, 0.33141043277517446, 0.30953571140285463, 2.46581198227021, 0.7224832415100068, 40.00575565522717, 76.91936569829141, 65.88405178439233, 75.55120375848587, 67.72390227163991, 53.10847243955059, 24.062805521872736, 27.808349363265503, 28.235689632354248, 64.11816150911393, 61.413961841214096, 67.769087976025, 59.865092385199766, 91.17543974230367, 49.695331819595836, 0.7729589362298289, 0.2111113702337588, 0.17712139734818091, 0.24321491289283, 0.1582156190828931, 0.26319912845088594], [0.06959120487614025, 0.06812751728800998, 0.10114208404575625, 0.0325078264089121, 0.2100802005659188, 0.11647649830387485, 0.15208637942710232, 0.14770028091246082, 0.3273129349033679, 0.38337999894734354, 11.72525784661693, 71.60547194942352, 46.54209136962891, 44.37196162439162, 25.023719533797234, 47.7593126604634, 32.49025317930406, 14.652023584611955, 10.247488214123635, 46.48005908535373, 70.01794753536102, 64.76929849193942, 66.64579960607713, 59.02210051013578, 64.2945622628735, 10.204908924718058, 2.5213833874271763, 0.9056158856518808, 0.09267046927444397, 0.43661921795818115, 0.3707930211338305, 36.59237969306208, 74.69402467050861, 61.99262126799553, 61.04305859534972, 50.07423277824156, 49.97769148119035, 54.66360199835993, 57.39736457024851, 62.446282602125606, 60.29334852772375, 60.906740542381044, 55.333503600089784, 67.29171199183311, 51.547643676880874, 60.009200265330655, 66.87606626941313, 43.16521698428739, 50.25475202068206, 58.97656963717554, 61.19155560770343, 62.48190164566041, 61.68759815154537, 54.00846419795867, 54.533394998119725, 51.23140258173789, 48.63507986068726, 50.22341620537543, 49.715661464198945, 51.083843015855365, 52.851431677418375, 55.61139568205803, 54.93755994304534, 57.20340336522749, 56.46040447296635, 57.037459650347316, 59.22236888639389, 55.64793256021316, 53.60782938618814, 73.42474568274714, 71.83600533393123, 71.1389530858686, 71.09761914899273, 55.831550475089784, 49.77690535206949, 57.09033712264031, 51.63404956940682, 56.785086508720156, 66.43562332276376, 80.88528202426049, 80.08929191097137, 62.21262308859057, 32.87941309713548, 23.896546056193692, 32.93769559552593, 48.526292923958074, 54.40996585353729, 53.65295625502064, 49.08699181772048, 48.60878821342222, 50.08781594614829, 54.92189007420694, 57.51356478660338, 44.10728792990408, 23.50022977398288, 31.327105683665124, 47.87857624792284, 65.48095372415358, 66.19133026369157, 61.79849924579744, 59.74913143342542, 54.10837481098791, 47.50415855838407, 48.225941350383145, 43.95843005949452, 46.32114033545218, 55.28956128704933, 47.8552459901379, 49.48902299327236, 60.35712234435543, 66.79226875305176, 73.31691188196983, 65.05614926738124, 43.85598167296379, 36.215620348530436, 43.91524476389731, 50.63601424617153, 54.65302728837537, 55.305474342838416, 50.91618522520989, 49.290586363884714, 48.52836785777923, 46.596341671482215, 46.49710962849279, 49.245871343920314, 50.794674119641705, 57.019522651549316, 61.58225505582748, 60.339232413999504, 59.12111682276572, 60.0660942446801, 45.60018908592963, 47.46552713455693, 60.59128392127253, 62.22338999471357, 59.728942994148504, 59.323868059342914, 55.971747752158876, 57.972242832183845, 57.14228499320246, 54.29724477952527, 53.16682554060414, 54.8180414015247, 53.79364382836127, 54.74027649048836, 56.199970860635084, 62.39648419041788, 60.01424835574243, 78.5265568763979, 20.71309747234468, 0.5724572402334983, 0.1802780779619371, 0.6931450770747277, 2.062415086453961, 1.2769231969310393, 50.43194901558661, 59.28355786108202, 64.54597050143828, 45.53917269552908, 51.762970032230506, 45.69517712439261, 11.067610709897934, 14.999205316266707, 31.865048946872836, 53.9694836831862, 29.34992909431458, 28.26540550877971, 45.576678399116766, 75.74685158268099, 16.59459310193216, 0.4676432048361148, 0.169669920578599, 0.17819654046287461, 0.10536322850854167, 0.030269754164281393, 0.034587690005860025, 0.11810362308977113, 0.13213057040927872, 0.01676233511628403, 0.012046437665459611, 0.10381634377183453, 0.07666349110584106, 0.11956071466087334, 0.01742503181430361, 0.44744290651813634, 0.4739516018138778, 15.16958229003414, 81.8913072155368, 54.16642588953818, 44.33399700349377, 35.26297861529935, 58.871658002176595, 30.605273862038892, 23.391234951634562, 12.37867666829017, 57.73389608629289, 75.69273856378372, 70.3722866119877, 68.079206251329, 65.41862726211548, 69.46396766170379, 10.373397277247522, 3.6974614666354273, 0.563261549799673, 0.2040966401898092, 0.31686260695419005, 0.5481110885739326, 39.38506018730902, 73.9730538091352, 66.44121662262948, 64.11694557436051, 53.39735500274166, 50.77276768222932, 55.67627168470814, 59.27210061780868, 67.00058583290347, 64.74587017490019, 66.47047750411495, 57.9688342925041, 68.78538193241243, 48.17526432775682, 53.58506394970802, 55.448134868375725, 39.210310751392, 52.04318023497059, 61.36338287784208, 61.874875637792776, 65.46116536663425, 62.87675488379694, 57.9637469783906, 56.18673286130352, 54.203433452113984, 50.25760750616751, 52.64063958198794, 53.89007922141783, 54.1038836971406, 53.37179291632868, 55.31227181034704, 52.687092211938676, 60.90963525156821, 60.25101046408377, 61.432185173034675, 61.25858499157814, 59.98190841367168, 64.97745083224389, 81.3321105895504, 78.8393815871208, 70.31563974195912, 65.12353166457146, 55.8462122947939, 54.233416049711174, 57.844432400118926, 52.496617994000836, 57.93005774098059, 67.45025419419812, 85.50888569124284, 94.39521143513342, 74.12433178194108, 39.030293572333555, 29.775149322325188, 38.673197069475734, 51.49110271084694, 57.29590462100122, 56.02875548024332, 50.63232721820955, 48.761337034163944, 47.05234466060516, 52.3139649821866, 59.71343394248717, 47.553160728946814, 29.08417086447439, 30.441895377251413, 47.66211240522323, 65.40806824161162, 68.83737687141665, 59.5702438969766, 57.86658986922234, 54.67414925175329, 53.33986482312603, 51.11450026112219, 45.506134571567664, 50.09027527224634, 55.64850130388814, 48.20282290058751, 48.8376820471979, 57.85751742701377, 69.27477605881231, 81.22416696240826, 81.31991986305484, 65.34478079888129, 49.035142006412634, 48.17969268368137, 53.2101285073065, 55.07585487058086, 55.47044923228603, 53.06843288483159, 54.017324832177934, 52.035241357741825, 51.09225257750481, 49.60612143239668, 50.81169720618956, 51.10543958602413, 59.075091731163766, 62.81964909645819, 60.52848677481375, 60.21000600630238, 62.635713469597604, 50.50988258854036, 47.98741025309409, 61.3367146830405, 62.36727429974464, 62.877103974742276, 63.565452483392534, 58.05602858143469, 59.69455949721798, 59.22812692580685, 57.359207753212225, 54.95919573691584, 55.686108989100305, 51.62814640229749, 54.96810736194734, 56.55750666895221, 65.22782356508317, 62.39673522210891, 78.84527298711961, 19.02436217954082, 0.9971880299910423, 0.08935448833771291, 1.05722536002436, 3.253297171285076, 1.4966825660197967, 61.85329083473452, 63.79235375312067, 71.39151450126403, 51.93661335975894, 56.84540863960021, 50.343546636642955, 16.34444982774796, 27.149918733104585, 33.12495739229264, 60.74342089314615, 36.98731137860206, 27.088325754288707, 54.722170829772956, 83.69132211131435, 20.20244606079594, 0.6574973512080409, 0.11277172008469222, 0.038118328778974475, 0.16572692731936134, 0.10454435712627827, 0.07428770689594169, 0.27882385938878984, 0.1759068721965436, 0.17892910437958856, 0.24592180796448262, 0.3698335419739447, 0.180613026924191, 0.23238048378017642, 0.3163321983189352, 0.6879716546785447, 0.6913575181557287, 17.80386570961245, 91.8444391988939, 60.75836512350268, 63.656855475518014, 38.0308775747976, 70.42144959972751, 43.97652395309941, 22.29589346916445, 20.204266040555893, 62.48090536363664, 84.29979155140539, 77.31401105080882, 76.2868207500827, 72.21747936741, 76.64628244215443, 12.30282489330538, 8.392361075647417, 1.7297365636594835, 0.29516868233200044, 0.9462300063140932, 1.238991916179657, 45.00662073012322, 80.69636498728107, 72.78670941629719, 70.5117033373925, 58.410795196410156, 56.49444280132171, 60.16347100657802, 64.93150026567521, 72.12791596689533, 70.84868984837686, 66.95576098657423, 59.37159938196982, 70.0790580626457, 59.14787915445144, 70.39203966817549, 52.635516966542895, 40.410850201883626, 55.04351492851011, 68.52536016894926, 65.44926097316127, 70.28004031027518, 67.16320730024769, 59.914063176801136, 60.32583359749087, 58.33665847778321, 52.38252409042851, 53.861002691330455, 56.16758385012227, 58.3829189115955, 58.073094814054436, 57.706639535965465, 55.57046574930991, 64.13911481057444, 63.11954175272296, 63.42937369500438, 68.87441189058366, 67.15971639079433, 66.64662330381333, 82.30378366285755, 78.7723090571742, 73.79442907148793, 71.0990547364758, 61.033185989626, 59.72994319854244, 62.03732844321959, 56.9620010929723, 63.2008211074337, 63.952174648161865, 74.08297431084418, 76.41916936443698, 78.02275980672529, 52.81396127516224, 38.932579486600815, 43.710606867267245, 52.071793925377634, 57.72392934368503, 57.880235795051824, 53.76192362077775, 51.17814463953818, 47.637985906293316, 52.55978776562599, 59.046995793619466, 47.2150053516511, 32.175369224240704, 44.309239002966116, 51.332952745499156, 57.42002410273398, 58.2773365512971, 57.45368980592298, 62.39045550746303, 61.00463897951188, 57.15710370771347, 56.31006786900183, 50.82286419407014, 56.58917980809366, 54.13935761297903, 51.600215204300426, 48.84243203747658, 56.72566652297974, 61.280295310481904, 74.28182278909992, 71.66409569401895, 64.73680949980213, 55.22133950264224, 56.45203021264846, 59.82546467934886, 60.327802627317375, 59.04704678443171, 57.96568070688556, 53.96085054643693, 54.986997496697214, 54.04591106599378, 52.10993897530341, 52.64470707985663, 52.832820030950735, 61.79629879613077, 66.14785471270162, 63.426102438280665, 62.515602650180945, 64.6641162133986, 50.26290662827031, 47.46468774734005, 62.210473629736136, 64.64530844842234, 65.12667740544966, 63.74912923382175, 59.120022481487645, 61.16896667788106, 64.00947655400923, 59.440178102062596, 58.264694752231726, 57.57079608978764, 54.795950612714215, 56.62526953604914, 58.845523249718454, 65.34891889941308, 63.7515454138479, 78.30084016246181, 24.512124792222057, 1.0911755576249094, 0.36553784183436827, 1.0693210916173075, 5.312093380958804, 2.0142905462172727, 62.665766669857895, 71.34170040007561, 74.76723963214506, 56.66240653684063, 62.22233879950739, 55.59443927580311, 20.92933381757429, 21.87684705180507, 39.758399225050404, 78.4993983853248, 46.4685586960085, 43.20427594646331, 61.40471681471794, 95.90589661752024, 36.70037823338663, 0.5286006677535273, 0.48819348276142155, 0.3032957720420053, 0.287801337338263, 0.14958842717591794, 0.2761541042597063], [0.047203131816199714, 0.11979730559452889, 0.0678946955069419, 0.045711815267080264, 0.20275293729237973, 0.14824532182706943, 0.10812385698720332, 0.1614960841834545, 0.12348125388305034, 0.16548536447507722, 7.215252393676389, 76.72341192922285, 48.53990354845601, 48.10079813003541, 23.9692001188955, 45.507205378624704, 39.50433946424915, 30.149006112929317, 7.476579816110673, 28.238537273099347, 71.2137762192757, 62.030036757069254, 67.49053693586781, 55.969284503690666, 70.23164610708915, 24.924918951526767, 0.5089141079975713, 0.24032447847627827, 0.09164547427527367, 0.15590888237760914, 0.7939656186969051, 20.566265506129113, 68.47530288081016, 60.754862446938795, 62.774114301127774, 54.122883658255304, 47.173581200261275, 50.86896773307554, 58.375976316390506, 62.90312497846542, 65.48448777967884, 65.70206949787756, 67.65245237658101, 53.21026971263271, 49.595833055434696, 26.277205098059873, 69.37314125799364, 60.903386915883715, 47.79093088642244, 59.19501427681216, 60.57120138599027, 63.953516098760794, 58.42175037630143, 52.72239746585969, 50.87355298380698, 55.139620842472205, 52.903473684864665, 50.20178825624528, 52.37627183237384, 49.17631595365463, 51.714799404144294, 55.62020532546505, 56.81164879952708, 57.11869585898615, 59.616590622932684, 58.248440450237645, 56.50604909466159, 62.50050936975787, 76.52657954923569, 70.2094219576928, 59.37370177238219, 60.219231420947665, 63.15200721063922, 57.87381095270957, 58.797831150793264, 54.916379144114835, 57.48012265851421, 57.298301189176506, 57.159194331015314, 57.15426391170871, 64.04635075599917, 80.99517114700811, 83.54529226979902, 48.02253115561701, 25.005127499180457, 29.77906777012733, 45.43071523789437, 46.52626460598361, 43.470353849472545, 45.43928561672088, 44.30388104531073, 45.09883957524454, 32.85790281911051, 25.44118915834735, 48.442413037823094, 68.56005745549356, 64.75036913348784, 54.68374336919477, 52.185193569429465, 57.08767775566348, 48.24930690949964, 50.52109272249284, 59.038095935698486, 53.83727235178794, 50.676183239106216, 57.67639806193691, 58.78001182310043, 57.16455621104087, 53.834224670164055, 51.439868711656146, 49.77234363555909, 53.61295200163319, 66.24884789989841, 74.19778208578788, 63.43505720938406, 56.56934438213226, 55.15953863820722, 54.46710301983742, 56.581954802236254, 54.629751943772845, 50.91423972960442, 47.7636625689845, 45.61284657447569, 48.7758223472103, 48.905335087930005, 50.18663614026962, 56.99284268963722, 56.40786432450818, 60.28012621787287, 62.79376537569108, 65.24207353591919, 55.788243586017245, 50.610667890118016, 58.09117301817864, 58.63486843724405, 60.491302705580196, 57.28667136161559, 58.60697254057854, 57.75286466844621, 55.16162926150907, 55.53591359046198, 57.38682908396567, 55.05465838216967, 51.579214834397845, 54.107908048937404, 56.35857582092286, 71.4381750168339, 62.47330773261286, 71.21817711860903, 9.235597118254631, 0.2731598955729316, 0.1443698822009948, 0.23890307894156826, 2.1498582007423526, 4.02010485049217, 65.82800111462994, 60.046372567453695, 63.85591183939288, 32.127677125315515, 81.47470443479477, 35.62164014385593, 3.637898804679994, 26.94773624020238, 36.85763782070529, 50.34737486993113, 38.11799733869491, 41.694069293237504, 51.926654461891424, 70.21741574810397, 5.757385357733696, 0.3304753458547977, 0.17543005907247144, 0.012237935706282095, 0.044432574838039376, 0.08259338702285483, 0.08377601227332508, 0.14188631708102842, 0.049886542462533524, 0.0460295693858737, 0.06523792556817494, 0.033913697341396924, 0.06766054073288556, 0.08959371461382798, 0.21081725375786906, 0.25737407166630993, 0.21796208085312, 8.371944158307969, 84.38071004806027, 57.67497424156436, 44.43331926099716, 28.0120341239437, 55.86351779199416, 32.55718842629464, 32.243010497862294, 9.979826654157332, 27.82061069242416, 78.24103970681468, 72.61006155321675, 72.79222426875945, 62.01786956479473, 73.50802544624575, 25.536657687156435, 1.6579140434342048, 0.2423356891038918, 0.13647243500717227, 0.2493530851338179, 0.8634754114093319, 24.299657844728042, 72.57689399103965, 63.80203416270595, 64.35434702903994, 58.9839986062819, 50.6605290597485, 55.390621154539055, 60.156995173423525, 63.353648416457645, 65.33579072644635, 68.7437028269614, 70.42550533048569, 57.0058375020181, 52.27711431441769, 26.085587509216804, 60.59117017253753, 52.45283649813745, 45.47976839926935, 59.0282468641958, 64.1774167553071, 65.37815624667753, 63.51076287607994, 54.74678370260424, 51.10305478495937, 53.93541005349929, 53.33412247319376, 56.302442781386844, 55.907495406366166, 52.273603793113466, 52.459661422237275, 57.6113808539606, 58.3171211519549, 57.66548602811752, 60.325861054082075, 63.268462381055286, 63.97723074882262, 69.72175367416875, 77.95182766452913, 70.96004593756892, 57.11905671704201, 57.551054800710375, 60.884700744382805, 60.77807111124839, 62.74691658635294, 61.03111105580484, 61.060062070046705, 57.49209373228012, 55.386306547349506, 55.49546218687489, 63.65108959136471, 88.0571162316107, 96.48670550315612, 57.10360650093325, 28.821307343821374, 34.73711429103729, 48.449912609592566, 50.324025000295336, 47.2194690089072, 50.39967967617897, 47.964134908491566, 48.31480264663697, 36.58590778227776, 28.13817362631521, 48.44659036205661, 68.18442775357154, 65.54850086089104, 54.349710402950166, 50.421476287226525, 56.12520656278057, 57.16069659879131, 58.00703425561228, 61.85416944565312, 54.80754513894358, 56.25498602467199, 59.563497420280214, 59.88934832234537, 59.41509062244047, 58.558323383331306, 52.634963912348596, 50.78287563016338, 52.258341850772986, 68.7798749246905, 83.08523747228807, 77.32217742550758, 69.15890924392208, 58.00065255934193, 54.66963068131478, 55.03237931959091, 54.25772690003919, 53.897555258966264, 51.82637906843617, 49.75702678003619, 49.12608215885778, 51.182714200788936, 51.4910085739628, 60.2157130549031, 59.08711771811209, 61.33158422285511, 63.75043538308913, 64.92564808937811, 56.570077865354484, 49.87515680251583, 59.690107607072406, 62.73523184560961, 61.67118695474441, 58.34825300401258, 57.130776759116884, 58.81539944679507, 57.45331325838643, 60.307963278985795, 59.53149872441446, 56.52614731942454, 50.42882680892945, 54.50989215604721, 57.43928686265023, 72.24928978950747, 64.92523624051002, 73.63086623530235, 11.117021787551142, 0.6425049492428381, 0.04835829664502413, 1.1595557077277092, 2.2345848285382797, 4.606037332165626, 73.11949899119716, 66.13602484426191, 74.35939942636799, 33.80181335633801, 81.12938680956441, 34.03352737426758, 10.805946453925102, 29.112337404681792, 40.05879002232706, 60.28684523797805, 44.06767983590403, 37.28319537255072, 59.3115714288527, 76.50359446002592, 8.457505760654326, 0.6419946733982332, 0.06537468758441749, 0.18127287377513226, 0.07626943079934967, 0.09237714952999547, 0.015954639999225976, 0.25264386177784015, 0.4443327427631425, 0.21962691248664934, 0.2381134567962539, 0.311154792265546, 0.19435868207966128, 0.15615511835823137, 0.3465654598849435, 0.5237059787877145, 0.3157270195022706, 10.446783842579013, 100.07608998206355, 63.16357428027738, 71.38659584906794, 32.51351675679607, 62.68802219821561, 58.61406418585009, 41.959794182931226, 18.702769010297715, 41.86989345858174, 86.65303322576708, 73.58253479003906, 79.77722029532157, 68.03398916798254, 82.0358387116463, 28.777204213603852, 3.294398952876368, 0.8070193892044406, 0.200240460014151, 0.5385668587780769, 1.6477254417634781, 28.890560711583785, 76.22926389017414, 68.88525332173994, 68.37247402437272, 64.299080833312, 52.089122956798924, 58.71516327704153, 63.04956666884884, 68.70124709221625, 68.58369365815194, 71.85571132167694, 74.50339748013404, 58.20490214132494, 52.660957459480535, 34.008518342048895, 74.07057962109967, 53.356503517396995, 46.796586513519294, 61.423328461185584, 68.6796191430861, 68.43234508268296, 66.51025033766224, 58.70468662631128, 54.45285304900139, 56.057220120583814, 56.66922753857028, 57.62254784184118, 60.656646297824004, 55.20080197241999, 58.547489796915364, 61.54212920896469, 61.7770399585847, 62.71805578662504, 62.891828552369155, 67.29017442272556, 66.62927858291134, 71.44087360751244, 79.20322848904517, 72.88251723012617, 61.43014946291524, 63.158592870158536, 65.90622102060627, 65.09290187589585, 66.12192000112226, 66.09843284853044, 62.664217333639826, 60.38734028416296, 62.74471613668627, 62.32154730827578, 62.227802661157426, 71.21996571940761, 84.37259074180358, 69.75316401450866, 43.12976268029983, 42.18524417569561, 50.69764644868913, 48.83758398794359, 47.178966614507864, 49.28632666987758, 48.84247910591864, 49.03541657232469, 38.818603254133656, 39.802165031433105, 61.56861305236817, 61.658549078049205, 59.32105571992936, 56.7679928195092, 57.87195567161807, 65.21067496268981, 60.665181375318966, 64.2130946343945, 70.47861422261884, 60.978500304683564, 58.90402932320872, 63.134183960576216, 65.38293761591758, 60.6640007418971, 58.941703688713815, 55.410966488622854, 53.40136366505777, 52.28094254770587, 60.31452148191391, 73.93506173164614, 73.27381287851642, 70.07232727543001, 67.61628027885192, 58.05678952124811, 57.99687531686599, 60.035958674646196, 54.39681414634951, 53.44822422150643, 50.63421387826243, 54.22217845916749, 53.95903841141732, 53.31215327785861, 61.80957994153423, 60.88144517713978, 64.65920540594286, 65.08481002623036, 68.99359703063965, 57.520617208173206, 49.03185113783806, 60.878373961294855, 61.48317206290461, 62.04654209075436, 60.24787649031609, 61.696898091223936, 60.7585024064587, 60.28302092706004, 62.87720203399659, 61.01275828576858, 59.49418521696522, 54.257126777402824, 58.36638612131919, 59.14611801024407, 73.62357847152218, 66.58778775122859, 74.74936146889964, 14.822395655416674, 0.5830514394948559, 0.14354169518957216, 1.1736833496439842, 7.033285306346032, 5.664178075328951, 78.52683144230997, 70.97639437644713, 79.0555198730961, 39.434030978910386, 88.98717295738959, 47.25291113699637, 11.807685475195608, 36.167755665317664, 47.3508527201991, 68.02477944281794, 52.99324497099846, 57.60225349856962, 63.883289983195645, 92.83759117126466, 16.74873048259366, 0.5867477830859923, 0.36808796467319616, 0.28207792509948054, 0.24202470337190937, 0.2451768640669123, 0.14799819718445503], [0.02333837831693311, 0.09934034483927874, 0.02522741324238239, 0.08884363026628572, 0.2864094475103963, 0.04470147169946183, 0.06649060955932064, 0.0899351829843175, 0.0654289189485773, 0.09607659577722512, 1.3850380600460115, 63.646351368196555, 52.285429739183, 47.86002343700778, 34.172681300870835, 45.02060397978752, 67.0158987660562, 84.47779655456543, 13.823806297394539, 10.545136294057293, 54.2782408960404, 57.73241343036775, 62.09249265732304, 62.636015492100874, 59.58441934277935, 39.35393225762152, 0.3272442627818354, 0.06055710919862313, 0.2528669772249076, 0.29180123560851623, 0.88704603694139, 11.5759842049691, 62.552469007430545, 59.93286701940722, 61.83016846256872, 60.58315677027549, 51.73310510573849, 52.12251801644602, 55.609034415214296, 61.040732629837535, 67.32882545840356, 64.99497205980363, 37.25777841383411, 48.625846601301625, 59.21774048959056, 55.797731799464074, 32.11681804349346, 44.83501703508439, 50.67556742698916, 59.785687923431404, 68.38232701824558, 60.432047459387014, 58.39095977044875, 53.44102274987006, 55.06585282664145, 54.088708046943914, 53.709485453944055, 50.033110649355, 52.61130809783936, 55.00602491440312, 53.079686164855964, 48.85905111989668, 53.61550154224519, 54.50036864126883, 55.241508330068285, 58.6710758363047, 61.57558310416437, 67.85001431742023, 61.12416928814304, 55.62104471268193, 56.06163278702767, 65.29290353098224, 60.0240425140627, 60.241212383393325, 58.6466786938329, 62.719001077836566, 73.62189185234809, 60.37318445021107, 59.772638197868105, 60.42071965432937, 63.6124542451674, 62.155152520825794, 71.35892744987243, 88.80108787167458, 60.34583768536968, 25.7759948315159, 28.527902287821618, 48.10291228755828, 50.84949708754017, 42.67874502366589, 43.821641322105165, 29.33044275929851, 32.883643373366326, 68.7548972714332, 66.52527301542221, 56.5138271547133, 51.67176708098381, 57.023213601881466, 57.59450681747929, 53.67105799336588, 70.05098173695227, 73.53090855383104, 50.74973160220731, 52.17809407941757, 55.94987269370787, 56.735260640421224, 61.21834931835052, 60.4314120354191, 61.30948951167446, 54.122295302729455, 57.09243166831232, 52.91082420656758, 50.96509718125867, 59.10618043714955, 71.62433854995236, 66.78716967182775, 62.32235923890145, 58.40489202930082, 54.74401843163275, 53.00992288897115, 53.15084972689229, 51.42186111019504, 49.37168921193769, 50.74264387930594, 46.34041094010877, 49.635860843043176, 57.41884739168229, 63.975548052018695, 54.358731854346495, 57.55104695597003, 60.70634272790725, 54.00080380901214, 55.59108957167595, 59.80946140904581, 63.18190351609261, 57.617711559418716, 57.98996802299254, 57.859964986001295, 61.90716851142145, 58.61888085642169, 63.55288913173061, 60.03056541565926, 55.420839094346576, 47.76935392810453, 51.99902611394083, 58.15260517981745, 68.86823807993244, 68.32774331492763, 76.07712299593034, 4.033349959119674, 0.978894463229564, 0.0701765266938075, 2.389487071383384, 1.6104029864072802, 11.717650409667723, 62.61265385535456, 60.78721415612006, 61.70330332171533, 52.8177502847487, 63.473433679150006, 4.403594982239508, 23.518676680903283, 30.786077476316887, 21.10612680835109, 48.07159216173234, 42.436397460199174, 52.0137506915677, 49.884794066029215, 57.99705182352374, 2.2009747739761107, 0.14965336078837996, 0.21622941979477484, 0.10541951298833856, 0.03886072543419657, 0.06314487759805014, 0.08531446238198588, 0.054202873349910786, 0.04899935135918279, 0.0683006761415351, 0.25795635977579706, 0.20260253891108498, 0.07091062278637002, 0.06046004585861679, 0.05599775223902637, 0.06190004600812832, 0.13427924785402515, 1.6315129375265491, 72.270949117599, 60.51909269825105, 49.87104615857525, 31.207626365846206, 57.45095591391287, 38.438164726380386, 63.26378691580988, 18.34253853367221, 16.02310965138097, 56.873673239061915, 67.45372156943044, 69.80754375457764, 67.48844239019579, 64.81819475850752, 47.23990847987514, 0.800215425270219, 0.21162507815226433, 0.1353869190619838, 0.21504160046817797, 1.2224616999587705, 13.587523698806764, 66.04650851218932, 64.75273432270174, 66.85159852427822, 61.62495789989349, 54.495971664305664, 54.968774164876635, 59.135547222629675, 63.179522637398016, 65.4448365396069, 66.18204209112352, 34.80753652511105, 46.513975820233746, 62.561741490517896, 58.305934552223455, 30.88788063295426, 43.872683125157515, 50.95038044837214, 54.290227659287, 64.4998904966539, 61.16888038573727, 63.84705120517362, 55.96424818038941, 57.86285969518847, 56.6166324769297, 54.405066813192065, 52.86954518287413, 54.52404014525875, 58.383397440756525, 56.313586235046394, 52.34335530188776, 58.050725536961714, 54.25070193506057, 55.485844535212365, 59.77422675778789, 64.03106135706749, 67.81274395604288, 57.54134693453389, 52.614245953098425, 55.88270602687713, 65.42517369793308, 61.99609256559803, 59.67456717644969, 58.38759045447073, 62.25962485036543, 72.39473127549695, 64.52387186788744, 60.44374396724086, 63.2119567163529, 63.22823847493818, 55.93048834031629, 71.92175619063839, 101.96791971883466, 71.70723392117408, 31.0169207280682, 33.85514974594116, 46.13321173575617, 49.16200322489585, 45.914661192124896, 48.41252457711005, 37.75575076380084, 32.237344634148386, 59.95657774709887, 69.49194200577276, 60.155084979149606, 49.834003294667895, 57.41621155892649, 60.14418471244074, 57.39046904348559, 65.54583364917387, 67.58419529084237, 53.69729864981867, 55.223928266955966, 57.33386531952889, 59.93359658025927, 60.43487156591108, 62.752772685020204, 62.90135991188788, 58.45309795871858, 57.816265859911525, 52.386509218523585, 52.19738037355485, 57.08766206618279, 71.20155411381876, 71.34499519102036, 67.69966986871535, 62.91031076062111, 55.6578718462298, 52.3522198584772, 51.612017616148925, 53.130214137415734, 50.54925926270024, 51.799946215844926, 49.9401661657518, 50.03689181420111, 59.4057632261707, 63.96207471047679, 59.94640311887188, 57.76713425113309, 61.51944221988801, 48.5104347813514, 54.006961930182676, 65.64184542625182, 63.63905183730587, 58.86275422188544, 59.77016710465955, 60.47830397082914, 62.42951839200912, 62.11586998355005, 64.5897323854508, 58.19921862694525, 57.66861215714486, 50.12318788036224, 53.76974874927152, 57.55771498526297, 69.15113510624056, 67.15831218227264, 78.86988978232108, 4.8746481057136295, 1.1009078160409005, 0.10866313692062132, 2.2187087901176947, 2.175351155381049, 15.77918137273481, 65.33379031765845, 65.65362038150911, 63.82120278573806, 58.88513918845885, 63.14011850664693, 6.24792383563134, 22.551433924705755, 27.143615484237674, 31.48964282005064, 57.71221322398032, 52.94550188126103, 50.654931837512606, 56.74256017131191, 68.87255268712198, 4.257760768936527, 0.11030296344430217, 0.17837523813209227, 0.1879415312601674, 0.07558066412926683, 0.01384464041855667, 0.07844790906435059, 0.1601812015137365, 0.24353386593922494, 0.21457109990860188, 0.3231821581721306, 0.31303373015215324, 0.1595059409737587, 0.16023586954801314, 0.24359116931596111, 0.14713640955667343, 0.30080142040406505, 3.0496658529004748, 87.96880014481084, 69.5901346206665, 65.96187945335143, 42.799055883961344, 62.096728817109145, 86.44345314271989, 93.4632876611525, 25.32914077081988, 22.666710422885036, 68.24990780122819, 72.95362195660992, 75.32431817823841, 72.98846829322078, 72.33709596818494, 50.08405047078287, 2.120245041385774, 0.5513005271073311, 0.26954613626003265, 0.7328908830400437, 1.993538756524363, 16.575920658726847, 69.89840153724917, 66.64955723670222, 70.2235346455728, 66.97162305155109, 58.23817952986687, 59.082685439817375, 63.199954263625614, 66.04686937024518, 73.41928574346727, 67.18616885523643, 38.73763768903671, 46.28836893266248, 66.19552719977595, 51.692994948356386, 35.017410785921165, 51.575512116955174, 46.688407544166814, 61.99107585414764, 65.74725520226264, 65.85048414045765, 65.82498088959726, 60.60325499503844, 60.64319649050313, 60.06345841192431, 57.787969881488436, 56.43566216191938, 58.127274513244636, 60.32488438390917, 56.7473493852923, 56.3400661560797, 59.84540208693474, 58.307605481916866, 58.50896427708288, 62.55044506442163, 64.49070038334017, 69.0149974822998, 60.946638891773844, 60.8320939156317, 60.84991324332453, 70.52395682181083, 66.86284788193242, 63.39861839048324, 65.62502630295293, 66.26249774809807, 85.06338288707119, 70.55786963432067, 61.81023889972318, 67.92065620422363, 72.61978118650376, 61.38576784441548, 63.31541707438808, 84.38794289865803, 83.08584936203496, 47.86581677775229, 41.43015261619322, 45.51050016956945, 50.57955564991121, 48.043041229248054, 52.37686411026986, 40.68839711527671, 51.40484194601736, 72.01689720153809, 60.88759937594014, 55.57769075516732, 55.45413609473936, 61.40987865386471, 62.960862267401914, 54.17921281629994, 74.86525966275123, 75.32528308130081, 53.37861784042851, 57.863601023151034, 60.04275221978465, 63.8063487698955, 61.45569978221771, 67.05128638975083, 66.39188889534243, 58.46122903208579, 58.91614552467101, 57.11718574646981, 55.09097560759514, 59.15906967655305, 68.24138841321393, 66.66782763696486, 70.18207519285141, 66.4684457163657, 59.14611016550372, 54.2581073699459, 56.96255806953677, 55.33056966720089, 52.32962700628465, 53.79181600386097, 50.681976579850726, 53.39304431792229, 59.54033974678286, 65.93610163657897, 64.11778888394757, 62.36870596485754, 64.78416035252233, 49.74884079348657, 54.90493366795202, 67.65332314275926, 65.9271429431054, 62.29322779563166, 62.76002906983899, 62.63732556373843, 64.89444563465734, 63.2759697975651, 66.87714099884033, 60.11585735505628, 60.2227968554343, 53.41393093908987, 56.746117761058194, 58.623881878391394, 72.22948182013728, 67.52898400829685, 85.10178289105816, 8.063869928160022, 1.3643147075368514, 0.3231499824793108, 7.478625822451807, 7.849482980466659, 15.387490545549701, 76.97849935100925, 68.37211316631686, 72.3158053428896, 65.58570061960529, 78.26372669589135, 11.864551997953846, 34.27439228180916, 41.82189933715328, 33.61366510391235, 70.73250924387287, 57.12165332609608, 69.00433648017146, 63.0785333725714, 84.18419930242723, 7.7906327189937725, 0.46135953717654754, 0.3714961366307351, 0.28211007014878337, 0.1874654229369856, 0.26331119179244966, 0.23208766965375793], [0.11085617085618359, 0.012852169682211693, 0.07199593954869817, 0.02254990338828535, 0.45415300935987507, 0.1038216527611498, 0.03407148464072136, 0.13260367566779738, 0.04984661395992002, 0.16176694222996313, 0.05430497754845889, 48.0665676055416, 60.79177195026029, 46.7214221339072, 44.756836352809785, 35.1439856713818, 85.05281602182697, 83.47983575636341, 10.641565803558597, 26.269774167768418, 54.79615849833335, 55.490245434545706, 61.42318725585938, 64.44009004100677, 60.862806074080936, 36.46032133410054, 0.5487630600410124, 0.16762952200107037, 0.08350930642336608, 0.02639189178514625, 0.7394968898546311, 4.857944692334821, 53.632787427594586, 69.56992656953874, 59.67548108869984, 61.61781134143953, 49.70896205594463, 47.5770087395945, 56.762038661587624, 61.09948581264865, 60.546788554037775, 67.09356954020839, 41.30265989611226, 52.61769371647989, 42.986804054629424, 41.48882342923073, 59.31088501407255, 30.134862046087946, 65.15813481423163, 57.3357912032835, 62.28849349483367, 58.91331749577677, 66.09375738328504, 56.13679716663977, 51.79473338588592, 49.26231391968266, 52.78320204827094, 49.89011672235305, 53.33171806027813, 53.3015432665425, 50.261749529069476, 51.91062765736734, 53.086354194148896, 52.72467244055964, 55.453696789280066, 57.36447157398347, 59.982473234976496, 58.67325275175033, 56.13534981204618, 52.9254860262717, 57.65944557805216, 58.24815803958524, 58.33517582185807, 63.11953783035279, 62.58889213685067, 49.431458288623446, 70.29812243676955, 58.90838707647016, 57.18217942022509, 60.485921213703776, 56.71724519421978, 63.58233828698436, 65.29977552352413, 65.9790829689272, 96.02893352508546, 71.39964165226107, 35.13128895913401, 31.491778550609467, 41.98314405256703, 44.027000934846946, 38.172953667179236, 44.25315695424234, 84.37597966963246, 73.1812527871901, 59.6198893362476, 53.15710198494696, 59.675524234771736, 58.395807819981734, 61.08240781291839, 48.36679366327102, 57.44432318595148, 57.290142659218084, 46.68387720661779, 63.331953787034564, 52.99208394942745, 61.415981861852835, 59.07930827909901, 61.97973628197948, 58.533294739261756, 54.019678254281324, 50.20079197422151, 58.520441132207075, 58.68625540887156, 52.70872800580917, 50.767233217916186, 55.84499636004048, 63.46064283001808, 60.642902312740205, 52.066585017788796, 46.66490077972413, 53.51081348234608, 54.43235474248087, 48.97798130589147, 50.19413571203909, 48.02473945002402, 48.57764851662421, 57.35708967331917, 61.276976985316125, 59.67666564449188, 64.4549479792195, 51.088247837558875, 62.15093597289055, 70.56041917493268, 56.9739878562189, 61.9606617958315, 55.17658525897611, 59.2638950194082, 57.00632779828964, 58.60777662646387, 66.10583043867543, 64.82398809925203, 58.33512483104583, 52.83531073601016, 51.28065578399166, 51.56767129898072, 62.148056953184074, 65.65973927897792, 71.03625759001702, 56.560307241255245, 0.7785553004472487, 0.2169747773798243, 0.1093671564012766, 1.6593069751416485, 0.5132953035494974, 31.841495113988078, 64.60154264203965, 59.81060674113613, 58.3009688315853, 59.656626255281516, 49.142399218774614, 7.162486218637036, 39.885903712241884, 26.485992862332253, 36.00256896788074, 57.09840151571459, 31.64338600250983, 35.90902436164118, 57.502280127617624, 49.528446735874304, 0.3730949008416745, 0.13736831354758433, 0.055264433725706996, 0.08297045549918568, 0.08903931210478468, 0.10953237092302692, 0.023963536706662947, 0.0728304927507716, 0.05424012820566854, 0.031051106390453158, 0.05765242554667977, 0.32161262787638173, 0.08889709554252126, 0.06611334956100871, 0.061557409353554256, 0.062190515905498504, 0.09424789793669217, 0.14691890187321172, 53.91293487241192, 71.7927102119692, 51.51992428687311, 36.55110066936862, 44.925917963827814, 69.77546661130845, 86.6859576009935, 18.9923870178961, 29.734962678724724, 62.74440234707248, 58.03429472830988, 73.96717809861707, 69.41223944387129, 66.6553388103362, 39.36824890875047, 0.7729822253027271, 0.3993624623023695, 0.055720321158127445, 0.11397563491857822, 0.7047410129058747, 6.179774124776164, 54.66368829050372, 69.66754651838734, 62.852640151977546, 64.5416441271382, 51.747390377906065, 48.0870266883604, 60.10340382975917, 62.42299941278274, 63.70670880040815, 70.52008152008057, 42.70393056254233, 52.708559343891764, 42.77936558569632, 47.074866910134595, 61.74962259108021, 33.72495843518165, 65.69219689215383, 56.95431716980473, 61.377652460528964, 57.40988085346838, 64.98333830987254, 59.29072010901667, 54.56236954658262, 51.90959215164185, 54.227744302442, 52.26667688738916, 55.642480465673636, 55.596518131994436, 51.47378936890633, 54.41446873449511, 56.805926061445675, 51.92364992633943, 57.19791989172659, 59.21892896775277, 56.10626935958863, 57.84027468773627, 56.968771103889715, 55.859842531142704, 56.236801916553134, 56.367267793224705, 59.399103041618105, 64.14303325837659, 62.03822666598905, 48.47265843422183, 74.50705312913465, 63.34356400274462, 60.07991667716735, 60.91408714171379, 58.035267476112615, 61.389831419914, 60.70419719142299, 70.7194399064587, 104.1530486076109, 76.65368003229942, 38.48117743769, 40.62139126562303, 45.3953746826418, 46.053583698887984, 43.32330419171242, 42.80956391365298, 78.50173611794749, 71.96692620554279, 57.488190973958666, 54.106009621774, 63.34938087771016, 64.35844982824018, 59.19255887308429, 48.26651042507541, 55.749702376704064, 60.85192541922293, 49.89005788680046, 63.45297851870137, 52.628009550033084, 61.06723608509187, 62.30008409869287, 65.12070363567722, 57.715092243686804, 55.857132173353634, 50.43931522677022, 58.43221525992117, 61.29128579170474, 53.68265644196541, 48.75100158875989, 52.20401310151624, 63.15327413620488, 64.22244164251512, 53.758315040219216, 49.76754265446817, 54.71305131912232, 52.26415872573853, 49.751813950077185, 51.80789293781404, 51.14787570891842, 48.8956586007149, 60.11858340232604, 60.13520248474614, 63.908530435254505, 62.2356983923143, 54.62487251527848, 55.4267579509366, 63.87258975736557, 57.74174082663752, 60.433506581091116, 58.264883026, 59.930344935386415, 58.12147725012995, 61.73509805433212, 67.31337916466498, 66.45964391769903, 57.145069876024806, 55.45322218248921, 53.9961479556176, 54.115752789282034, 62.39291875593124, 67.48117031589632, 69.9986808530746, 57.549054391922496, 0.7508781984929116, 0.29593581213585796, 0.06376460825483646, 2.331220017325494, 0.8581938786852745, 35.0294916860519, 70.9662981956236, 66.32777383250576, 64.12384110112345, 63.24041743432323, 56.63849184590002, 10.080061843318324, 39.360612054024976, 33.22308332689347, 37.28053992794406, 58.14190495398737, 40.715179058813284, 42.60304327934019, 65.87637178359493, 56.27939493425431, 1.0023550785356954, 0.3259067345530756, 0.0379984398492642, 0.10557037102238787, 0.11597693236845157, 0.013274510124427898, 0.06005339106665023, 0.16901885309526998, 0.1772077507790058, 0.09747207089657746, 0.4871952395525671, 0.415306008390842, 0.22551497234211815, 0.16146963882830837, 0.23652728707078965, 0.20865475608696862, 0.27078612617427306, 0.3585940208886901, 69.37050542523785, 81.09443849132907, 63.9083460838564, 61.08653806870984, 49.190656139004616, 106.58250193442069, 85.6784575985324, 18.556260639621367, 37.18085289001465, 68.75419124480217, 69.86417493512555, 77.5647367969636, 76.60326973084481, 72.9716334804412, 47.455905560524236, 1.5510247984240133, 0.6436967369048827, 0.21917409323636564, 0.4353269195604709, 2.073418805676122, 8.427106411226335, 58.08577583682153, 71.12663684352752, 64.92068629111013, 68.88067199337867, 58.64120306507234, 51.76371136019307, 62.76884263561618, 66.12780355638074, 67.8262133752146, 71.36904716491699, 38.82520852550384, 54.131120635617165, 44.63068900569793, 59.995609252683586, 57.950155965743534, 37.22054727615849, 65.72619207443731, 57.33051169303156, 65.96813955614644, 61.49507253400741, 69.73842374740109, 59.88075440929782, 55.94134153858308, 55.7762921241022, 56.66450108251264, 55.30814155455559, 59.116472736481704, 56.82312957702145, 57.26428247267201, 58.286558043572214, 60.72217733629289, 54.89356271682247, 60.48571332808464, 63.93402976374473, 59.90714803818734, 60.12403157449538, 63.88041096348917, 56.359348527846805, 64.28741178204938, 63.37601377118019, 65.65319284316033, 64.80976558500721, 71.58476967965403, 51.93006692394134, 70.6355639426939, 61.646138698824, 66.20545079631191, 63.53384210217384, 63.76461867363223, 67.03681284381499, 75.68237566178846, 65.84761296549152, 83.89202194829141, 87.3892621071108, 60.01662531206685, 48.52854436443698, 43.871451500923406, 48.06437892298545, 50.16660067342943, 77.38325657383089, 88.59462999528455, 62.0783446681115, 61.71355639734576, 58.9668696157394, 63.81388756536669, 68.7643737177695, 61.13458710332071, 59.00646594262893, 48.59531487188032, 52.25921261695124, 60.4371504629812, 69.34273504441785, 56.5511171279415, 64.39333538855276, 61.450906645867136, 67.84050649212253, 60.034177918587964, 61.80236278041717, 55.108186967911266, 61.66047888417398, 66.15504833959764, 62.147684328017704, 53.711144616526944, 53.746359655934, 63.15600018347464, 66.48522561596286, 57.62970224503548, 51.19883121982698, 55.1274222712363, 56.45270486031809, 53.1722423338121, 53.87112240637503, 51.14405924274076, 49.09593482171336, 62.22738688991916, 65.82578889785275, 65.07683584767004, 67.34917471485754, 53.509593625222486, 53.61580748711863, 63.82181467548494, 62.040552631501235, 65.82702836682721, 62.471158273758434, 62.519332824214814, 60.81757722362396, 63.97104909343105, 72.52481275989165, 69.5859847530242, 62.39083597736975, 57.13509136630643, 54.83441729699412, 55.915430361224765, 65.04738669241628, 68.00297106465986, 72.67649865919545, 61.00235616007159, 1.8324911402117823, 0.4576095367871946, 0.238788380257545, 5.7024780588765305, 3.1363794063368156, 37.741281140235166, 79.46179113080426, 70.65304202418174, 71.96942867771273, 74.18500300376647, 61.81997814486104, 14.186544149152695, 48.5335571535172, 31.709387725399388, 50.93379666728359, 76.93594163463962, 44.62917497081142, 54.75407538875457, 72.84461144478091, 74.60771683723696, 2.840253451178151, 0.9035364778772478, 0.20248800876640505, 0.2384686458014673, 0.17513626435350987, 0.19561782419200868, 0.24417414690458009], [0.013048288190827496, 0.24757920854514648, 0.0520038217937033, 0.06356341441372229, 0.23707146996692305, 0.4651126938481485, 0.037255120058093345, 0.08461635710010607, 0.11747398308568424, 0.2503275336517442, 0.3744487927084969, 26.980813587865523, 61.71199137164701, 52.31804816953598, 36.94294937195317, 39.434529119922274, 29.026313943247644, 35.435390318593676, 13.935064327332283, 13.260260743479575, 80.17571741534819, 57.26169763072845, 63.636616045428866, 58.629906638976074, 65.38866819873934, 47.78657313316099, 2.1561359542031444, 0.057492489370727734, 0.0492532443886082, 0.04511892833116074, 0.08961852820169541, 1.3127958462122948, 44.29311021681755, 62.784630175559755, 69.23708208145635, 59.37718091472503, 57.85942369891752, 48.48151906844109, 54.31292249310402, 58.99474982292422, 64.57949892167123, 63.105283937146595, 74.10372364905574, 54.76889410326558, 59.313509079717825, 34.71748282832485, 48.237763374082505, 62.46204268547797, 55.940086380127944, 64.22855661761376, 61.61772897166591, 63.55214780376804, 58.37800025939942, 58.589294418211914, 56.640162775593424, 53.894519344452895, 52.77416882976409, 53.872557993858095, 52.529597282409675, 50.23955675863451, 50.264267690720104, 53.91709650716474, 51.342080100890136, 52.19053191523398, 55.31550384336903, 59.24589918505762, 55.44687970992058, 51.68275363983647, 56.12346110805389, 52.92266191974763, 59.73516779561197, 54.73754652084843, 57.836909294128425, 57.95949120675364, 60.81154069592876, 62.96815787592242, 55.42151374201621, 60.768802550531205, 62.05917212270922, 58.85651765331146, 58.60534475695703, 58.60514863844841, 63.46360814186835, 63.27775055362333, 59.76315782916162, 93.59055288376348, 73.88296481101744, 41.8673635298206, 49.88895962315221, 44.68442939942883, 63.71880931238975, 87.7166231216923, 66.64237929928687, 59.46974885079169, 56.919066829066125, 55.236087614490145, 54.69335317611695, 58.70080347984069, 52.90065350071077, 64.4547361712302, 53.84496411969585, 57.54321790510609, 64.79393489899175, 56.323392160477184, 55.95362640196278, 54.75048249767673, 55.98435817226287, 56.93947492107269, 55.062138342088275, 54.37981851639287, 54.92560063638995, 56.315727849160474, 55.33134237412484, 54.66785776999689, 53.8879729086353, 54.393727241023896, 53.27549480622815, 52.38678378443564, 49.71213525341403, 41.22079610824585, 42.409262503347094, 53.97445332619452, 49.69630456739857, 54.18559059020012, 51.83114474819553, 55.71118470161192, 54.163495879019464, 59.01782120427778, 58.6880361649298, 62.00149759169548, 54.433751106262214, 62.78466939926148, 63.620750058081846, 63.8559236065034, 59.475977574625325, 59.578790741582075, 56.93734507406912, 61.06319212144422, 61.41489928768527, 62.49268816363428, 60.84545350843861, 56.77193480153238, 51.452498743611, 51.00524263997232, 56.19203590577649, 66.57971551341396, 62.7322429995383, 76.35533671225272, 41.02743502586119, 0.863882173453608, 0.1319255346372243, 0.23331589245748138, 0.5244311269733214, 2.7122574419744554, 45.08117321998843, 63.46727555797946, 53.77980962876351, 56.127834550796024, 65.08891674780077, 47.498302459716804, 7.009618705318821, 33.05733965289208, 16.123071255222445, 52.219298578077755, 95.45258829670568, 39.84297729307606, 38.518004571237874, 59.12209349293863, 39.306738299708215, 0.12471090161031294, 0.03984023396286272, 0.1597146386460912, 0.05834309211481483, 0.12149147073467895, 0.08672853811613976, 0.0294424002734764, 0.15394641026373834, 0.13412494242431658, 0.0804214971140027, 0.05136345272823688, 0.0584112394661192, 0.2506042139664773, 0.05258910147653473, 0.06296676215565493, 0.09123132714340765, 0.4048554965805623, 0.27418201008150656, 27.970782556841453, 73.76588206137382, 56.339669996692294, 37.06746109070317, 52.37864486632809, 40.215241601390225, 49.04226110827539, 26.726812662616855, 12.858849302414926, 87.61928558349611, 65.13020361623457, 73.17467889478131, 64.653517969193, 69.69078263928814, 49.00099385169245, 2.772695527922723, 0.4651934395153677, 0.05004767373564744, 0.029664699836904486, 0.5374738045277134, 2.093468245960051, 48.77332379741054, 61.80211174872614, 72.00625973363077, 63.557478304832216, 62.66693945853942, 50.95832717034125, 57.26993460809031, 60.338769574319166, 65.9096570168772, 65.42336156291347, 78.8045430952503, 56.20865498819659, 58.66547076932846, 34.71074027399863, 47.81682637430007, 64.91852506514519, 60.00502294109714, 64.60467269343715, 65.14149611996066, 62.22031093412831, 61.11229235126127, 62.39421706045828, 58.61034577892673, 56.25731199018417, 54.48654620878158, 61.03976380440497, 60.37261570653608, 51.70687229402604, 51.939896383593165, 53.85368354858891, 53.541600165828584, 53.81845674207134, 56.761014922972656, 59.156527980681396, 55.65818955821376, 55.87306876336375, 54.807466691540135, 55.54985761642457, 60.910478561155266, 57.44158144920104, 61.25888309171123, 59.85793798200546, 61.8099251101094, 60.445971873498735, 51.84996035791213, 55.298986742573405, 66.79122540258592, 62.74063687170706, 57.72567087604154, 55.75266768855434, 63.60169910615491, 62.43866928162114, 62.2245196373232, 100.81114999709591, 77.18276070010278, 44.001529062947924, 50.07517806945309, 47.15562458961241, 57.736143604401626, 72.37556657483502, 65.34148993030672, 61.08934256338305, 62.570853156428186, 58.922911613218254, 57.520122989531494, 59.038401880571925, 58.234586638789025, 66.26858526660551, 47.8670209453952, 53.54049797981016, 64.13054050937777, 59.96439110848212, 57.698853631173414, 54.41579449561335, 52.615885503830455, 58.56315182101343, 57.03725960946853, 57.04282153037287, 56.55141915044477, 56.37253553636613, 55.2346912507088, 54.143174079156694, 55.64250792226484, 57.18955739851921, 55.17328654566119, 54.16091888181625, 52.83573827435894, 43.37359682206185, 44.32222597060665, 54.810796783816436, 50.78466423096196, 54.59908685376568, 54.10965742603425, 57.27220958279025, 56.122272629891675, 61.06702427710257, 61.69806695753529, 61.216325375341604, 57.39994941219207, 57.86713900104646, 56.045809945752545, 66.35923908602807, 60.96627427685646, 62.299432985244266, 57.988465755216545, 62.95562590322187, 64.13592200125417, 64.28349333424723, 61.39088653749036, 59.76799018921391, 52.78032302856446, 52.715796116859686, 58.92183688379104, 67.54293980136995, 64.50434630916965, 78.43271809239542, 40.86024007489605, 3.09479737954755, 0.23691273654901215, 0.24210120491202802, 2.0234684021242204, 2.5190096180285177, 53.721213340759284, 69.68068645846459, 59.14192107415969, 58.87207769578504, 74.39744641703945, 50.82951261151222, 9.342530735077398, 42.659368515014656, 20.654277609240626, 50.347920079385084, 92.94853148921844, 38.144202693816155, 44.315236306959584, 67.98574401486304, 48.359133274324485, 0.5485225697198223, 0.040069347878377286, 0.06669344665903239, 0.06540361506443831, 0.024481827746175473, 0.056825085062413454, 0.16829649346970743, 0.19391130205364, 0.385006403610591, 0.22443121839915553, 0.19844602162559188, 0.4049226671697632, 0.6544220291318432, 0.24536955050162731, 0.2438823899794971, 0.5141107275361015, 0.5208390939139551, 0.45845299959182745, 40.45128199361986, 82.4453890708185, 69.64967619988226, 51.99114999463482, 53.88585090637208, 44.99643041241554, 39.84702910146406, 23.512491103141542, 18.558131610193563, 97.11064477120676, 65.81420221636373, 76.28016841027045, 68.20248634584489, 76.25629686540174, 57.431928496206964, 3.3698675613249507, 0.39631720151632066, 0.1698033271297332, 0.24759859056963077, 1.1195504737477149, 3.605723602156486, 58.12164983441753, 67.68921282983595, 76.28896236419678, 66.69056953922396, 66.0742239798269, 53.61253623039492, 62.151265451985026, 64.28149292545935, 68.16970317594468, 68.40161723475303, 80.18108321774392, 55.315252811678, 55.2451757461794, 36.877637986213934, 56.600405631526826, 59.92979972593246, 63.36123820274108, 65.74035183075937, 67.07566784274194, 66.76580844386932, 63.73378492170765, 60.88046850696687, 61.0227014941554, 58.812088966369636, 59.97368712579051, 61.8669524500447, 64.86232534531625, 56.43555233555456, 55.384902338827814, 56.22680771735407, 56.27452727287047, 56.7755590715716, 62.71160741006175, 61.7987463551183, 64.71537374681043, 59.47477340698243, 60.09401759793682, 63.041047280834576, 65.72305810066962, 62.57871750862368, 64.74703119647118, 65.48109100710961, 67.60163414862849, 70.68118895253828, 56.327545950489665, 69.35354509661275, 67.00177823343586, 66.29533583118071, 63.99821935161468, 61.87968054125386, 67.2743280472294, 70.54695760050129, 56.96114209390456, 80.70071881817233, 87.60948750280565, 63.28310066653837, 67.02376704062185, 55.83323709426388, 83.72490544472971, 74.0202634565292, 59.41890708861813, 67.16627459372243, 64.97919236460041, 63.75343207390078, 59.68924076326432, 62.93866949696695, 58.7316882225775, 71.79806032488423, 63.46592626264019, 64.3957241119877, 70.27359193371188, 62.115234559582134, 60.90693666088966, 58.81279107063048, 57.33599124416229, 63.28273588611234, 62.53537924058976, 62.860312308034594, 62.63829046680082, 60.24395412014377, 61.52923637820829, 58.74991547676825, 57.333480927252005, 57.84955893793414, 59.03123178789693, 55.90261990024198, 53.868102181342344, 49.13988890186433, 48.5157339034542, 58.50877992568478, 53.808678273231756, 60.06446646105859, 53.9028347692182, 56.188843096456225, 58.141806894733065, 61.60673064570273, 63.11223045472176, 70.23086947779503, 58.2638200636833, 66.73197407876292, 65.8730769926502, 68.35290139721286, 66.80343966330251, 63.44875020365562, 64.90028996621409, 69.33130525773572, 64.72772921285322, 68.43496522595807, 65.53449015463552, 60.93446777712915, 57.185972352181714, 52.33452604662988, 59.90880327840006, 68.71114715453118, 69.19816432460662, 78.26907680880639, 47.22280694592384, 4.456330758910026, 0.421496213323647, 0.47808326720710725, 4.265323588925024, 3.8031735102976527, 57.71560607417938, 80.41335813460812, 66.86098867847075, 68.30154188217656, 76.39463886137932, 62.41402502982848, 14.953595015310473, 44.41444873809815, 21.389847532395397, 73.75482882222822, 117.0444045528289, 52.19139091430172, 58.48297465232111, 73.38102694480651, 63.73983713888354, 0.7563644911973708, 0.25216749298476404, 0.18400961563231485, 0.12625824599977464, 0.17917052932804634, 0.1978522268754821, 0.3272802689142766], [0.036884835290332, 0.05395614707301702, 0.18462631641136062, 0.021677622271160928, 0.07502128970959494, 0.08758298662160674, 0.0372921412570342, 0.20214143058946057, 0.14835824318710836, 0.2806999474283188, 0.5953051077742731, 10.138989571602115, 64.70754077357631, 49.8073939354189, 38.665854392513154, 24.618562229218025, 37.61442384412212, 25.55935448215854, 25.962156403449278, 2.0066916894528175, 52.82510865119196, 64.34212100121283, 55.92451064817367, 66.7262944867534, 57.6621167121395, 66.70034408569336, 7.6974553446615905, 1.001569685195723, 0.2606404254273061, 0.04009065661399115, 0.14419152161046384, 0.6506524475351457, 29.88888236784166, 64.5988558184716, 69.84078976415819, 61.6557014373041, 62.78167663082, 53.73676946086269, 47.47850625745712, 53.315197037112334, 64.06698242310556, 64.05295994973952, 61.75575325565954, 67.24187435642366, 54.57480346002887, 51.78387626524895, 38.77308022591376, 58.86624120896863, 64.76199111630841, 57.65023977525773, 61.7186947022715, 60.44002556031751, 60.744362261987504, 61.98065803896997, 61.54593783040201, 58.41780054953791, 57.59017652080905, 53.94728699038106, 54.02144724322904, 51.621239108424035, 52.77937773735293, 53.60028274597661, 52.891977217889604, 51.5804111573004, 53.30604222513015, 56.48606069626347, 56.14279839300341, 55.86423558573569, 53.6483710042892, 58.345746609472464, 53.39748444095735, 55.3352725890375, 55.645406553822184, 58.75767784733927, 56.52024415231521, 58.34902571093652, 60.366061425978145, 59.72955096152521, 59.1121659740325, 60.59026410502773, 59.87499244751469, 57.24782028505879, 56.53885972115302, 58.442978243674006, 57.738571551538286, 65.68526214168918, 93.56479860121205, 69.50964758473059, 55.4107625253739, 41.060006387772106, 66.6286745379048, 62.17151272681452, 55.53892597075432, 51.80146809547178, 54.34611358950215, 56.27902230908794, 52.29127407073975, 52.29598091494653, 56.31524539762928, 56.463554136214725, 61.31531815375052, 56.78593374067738, 56.51790249732233, 58.16120693760534, 51.55227207368421, 53.5808591688833, 55.695542289364724, 55.18936826336769, 56.58980346495106, 54.47561456311134, 51.73778449335406, 52.614618578264796, 56.705254508603005, 52.82009193974157, 52.658247101691465, 50.59018919544835, 51.647981828258885, 50.50651719493251, 50.0887220136581, 40.44769694728237, 25.64574076283363, 47.11364738402828, 55.18080572928152, 47.427150664790986, 55.83795570558118, 55.74508574701125, 58.963970984182055, 57.701987604941095, 60.841699800183704, 55.792773923566266, 64.4843186870698, 35.030711543175485, 32.95782127688008, 62.13499938288043, 54.34973785954138, 64.14188792628627, 53.33287515947896, 58.954306264077466, 56.83225693241243, 60.79476864107194, 56.775888550666075, 58.11224006837415, 52.10103519501225, 53.373797247486735, 60.06839275360108, 68.35217968110116, 63.913390251898, 73.00880186019405, 17.069023386124645, 1.2546746552951875, 0.3626272899489249, 0.052101467360532096, 0.5744890892697919, 2.848150162927566, 61.07679490120181, 59.20947213326732, 52.38964319229127, 48.6319145079582, 71.92720828517791, 19.448870497365153, 6.797285608706936, 41.99875900822301, 22.440213157284646, 62.19982831708847, 83.80747918159732, 47.833735712112926, 42.19667004000756, 64.34224259468817, 33.85846807110694, 0.11601102328108204, 0.15904820343900114, 0.08902081108141331, 0.038771706017395186, 0.03978379243504136, 0.027571483327436353, 0.02980150015754325, 0.15129779916136496, 0.08284331554727209, 0.02939678931368455, 0.09378338052380471, 0.07169489763797292, 0.06370988276396548, 0.028683436966891733, 0.07056936892049928, 0.10245384107674323, 0.35776863775907025, 0.7342841824696911, 12.77499883405624, 74.05031665678948, 57.87945524338753, 34.935064546523556, 29.499908762593424, 45.42144275480702, 18.608896886148763, 25.29026616004206, 3.507598403000063, 55.27800990689186, 72.72550475212836, 62.90547447819864, 72.86137565489739, 64.29832381586876, 70.89062783025926, 7.481306272168314, 0.8416476052614951, 0.5184474287013854, 0.037828770526234186, 1.4524377401798003, 0.8181684199840793, 32.84144259268238, 65.11195675019296, 74.35411991611605, 64.37853236352244, 67.23086818572014, 55.6889997759173, 50.62492178332422, 56.62084118012459, 66.51910704951133, 67.83778436722295, 62.25734987566548, 68.57691580249418, 55.039549412265906, 54.23606757194766, 43.28695166495539, 60.32813602878202, 65.37683833029963, 59.509078456509506, 65.4984357280116, 59.24568345469814, 62.62405226307531, 62.640828240302305, 61.48547841656593, 58.878859473812966, 61.03585712371334, 55.22274371116392, 56.75000875226913, 54.969182091374556, 54.90567107354441, 54.593203298507206, 54.10879450459635, 53.368431445091005, 53.640487040242846, 60.40386522969892, 56.96420938737931, 56.991881708945, 55.50653503787134, 57.73290764900946, 55.99892193271268, 56.539361784535075, 58.24696956142303, 59.450521392206994, 59.64276852146272, 61.22066743912236, 58.28647959616877, 61.65057097711871, 61.82474774699058, 62.4615994576485, 62.56428318638956, 59.30862965122346, 53.00733412465742, 60.94053568378572, 61.48118342122724, 67.46009934333064, 90.96806403129332, 63.21710678838915, 61.08358452397009, 46.338618416940015, 60.74967707357099, 53.69983250094999, 53.53952130963726, 65.01210889508648, 58.77751719567084, 59.14902056417158, 55.12637107603012, 54.53552876749347, 54.94596558232462, 57.81587754526446, 62.42152852396812, 58.44036594513924, 59.05208310773296, 58.02228050847208, 53.524679060905214, 56.497341432879054, 56.51211700131817, 53.65379171986734, 58.46277052356351, 56.12766588887861, 55.209650839528734, 54.01948213577271, 55.88905242181594, 54.61573339277699, 53.711768273384344, 52.98389796287783, 54.477873848330596, 53.30437914017708, 52.686715664402136, 45.63558847673478, 29.101590110409646, 48.812982882222826, 57.957000501694225, 50.513789269231985, 58.58406589877222, 55.90216098293182, 61.959665513807735, 58.82676647555444, 62.958112685911125, 57.14070820039319, 67.26443582965483, 34.97067966768819, 34.46619618323542, 66.83296726595971, 57.48056980871386, 64.2238772299982, 57.03465907804428, 62.20663362933744, 60.04432509022375, 64.93117078658074, 59.84490002355268, 60.94277927952429, 51.603678657162575, 56.285329480325025, 63.208187318617306, 70.00943599208709, 65.80896192981352, 76.32238095806491, 18.150279637305967, 2.819724746288792, 0.283673441097621, 0.13963573462059423, 1.0214545697935167, 3.272731289748223, 66.25682600082891, 64.13030124479725, 57.876580146051225, 51.648985955023, 79.7641509579074, 25.058797290248258, 9.733861684799194, 45.490605908055464, 27.464328081377094, 60.46430110931397, 93.80660487759499, 42.999567447170136, 42.990067466612786, 74.64017837278305, 35.47795980207382, 0.29587961192573276, 0.16853529839746414, 0.10523459468517574, 0.036599502012494116, 0.056018072721217914, 0.012905020172887994, 0.07398061289061462, 0.20723525645031085, 0.24135020891985587, 0.319328582695415, 0.13728628085265238, 0.20536060865607955, 0.34125941234730905, 0.19978302891456312, 0.47432094812393194, 0.3195558043737566, 0.5546944804729954, 0.9758282729214238, 17.79287326720453, 87.38197434333064, 64.71715058049848, 56.697747092093195, 39.288197255903675, 54.88372933480048, 31.459003225449596, 35.45042084109399, 5.298420488834381, 62.986820513202304, 76.33031199055334, 66.93266607099964, 73.49466585343885, 68.91343162905785, 74.96498200201219, 9.028372418495918, 2.5811816367410847, 0.6958635247522785, 0.15320590967612882, 3.122254951346305, 2.094473598464843, 38.807193079302394, 64.40224701358427, 78.25154381413614, 66.36700537896925, 68.69012325040757, 58.98704628790579, 53.699032337434836, 58.698650098616085, 71.67358782983595, 69.3948398097869, 66.6400807903659, 68.84733969165434, 55.7852037491337, 55.6105915961727, 47.32685565948487, 63.815648709574056, 66.1876432357296, 60.92361850123252, 66.96556691200503, 63.110096685348026, 63.446388936811886, 64.22049614690965, 64.02231447158321, 62.49277053340789, 61.89950812247492, 58.147298212974306, 60.14337670418524, 56.157303317900634, 56.617558156290364, 58.013874869192804, 57.14050423714423, 55.38068971326275, 58.935820133455344, 63.35302083723007, 63.13166187655542, 62.034084643087084, 59.14837337309315, 61.290666057217514, 56.61574602127076, 60.19656012135168, 64.23828017327094, 65.59090168245378, 67.12641546803137, 62.90456448831866, 65.36060756252658, 62.0423569217805, 68.51101213885893, 64.30754138577369, 65.59327471640803, 62.071147118845296, 57.94761819224204, 61.91679400782432, 69.51844938339727, 62.467949774957475, 77.50423031468546, 79.05224077163204, 70.6278839418965, 48.55862894365865, 62.306567776587706, 55.89870929718018, 64.97701544915476, 68.6765596943517, 64.17625181136593, 62.39983781691521, 60.716635027239406, 59.304719048161665, 58.40847707563832, 58.137170653189386, 64.86402765397104, 61.2250683384557, 62.79564026863345, 62.1448366872726, 58.37241872664421, 59.30889245002501, 62.18784155384187, 56.853335749718454, 61.761848618907315, 60.47110249919277, 58.51496158107635, 56.57203512807047, 62.598254834451986, 57.0336784855012, 58.53712297254994, 57.86558182008805, 55.94149058864963, 55.547657166757894, 54.50564815152077, 45.950872513555716, 31.235934111379812, 51.84127230798045, 60.231053444647024, 51.64557741534326, 58.92250368672033, 59.368261444953184, 62.545020426473315, 61.90540344484391, 65.55833032054286, 61.50843997155467, 66.29306085648076, 45.51770948594617, 43.40513267824727, 66.34809170999836, 61.55589280589935, 69.17455950090962, 62.78012729460194, 65.48511928127658, 62.007051667859486, 63.75584825392693, 65.26433298664709, 63.68989752184961, 53.92196416854859, 57.23320553379675, 65.29242892419138, 71.04008582330519, 67.61449167805334, 77.26156896160495, 26.69896971794867, 5.060264468193054, 0.795104822083827, 0.1541467422559377, 2.572754179277728, 4.193138739755077, 70.23122249111053, 70.76632007475823, 63.595952833852465, 57.05888363622851, 84.32692650825747, 30.739854305021225, 13.158854726822147, 52.06602804122433, 29.181190690686627, 82.71679355252175, 94.00557102695589, 63.763198775629846, 55.76297567736719, 83.85701871687367, 52.138827231622514, 0.37280213268053153, 0.31475503778746056, 0.3084357010741388, 0.10257421647228541, 0.13122816479975177, 0.0725461055915202, 0.22259827643152208], [0.03792764949462107, 0.08333198771241211, 0.20484233485354533, 0.044570378733858954, 0.015825367450053175, 0.2313693549724356, 0.09902242601158158, 0.02775789933249114, 0.08369444689202694, 0.025976585945294752, 0.26071013942841564, 3.2455678957123912, 58.44203687483265, 49.78104345260128, 56.7119146931556, 37.17371417630104, 41.16939344713765, 40.72679319689351, 61.311046692632864, 6.274177239787194, 18.047719463225334, 77.74602874632805, 41.80017332876883, 57.282686233520515, 58.19351942308488, 65.54155434331587, 11.60762792633426, 1.0145277253562406, 0.3810889057574734, 0.014448822363309804, 0.894401032597788, 0.041461563293611815, 20.738934124669722, 55.49516408674179, 61.428282414713216, 69.17837204471712, 62.152155830014145, 58.180387327747965, 51.192147501053356, 50.68653829636113, 59.09320131424935, 66.97750660680956, 67.76540879280337, 62.956116199493415, 66.35785056698707, 51.036150916930175, 45.8283180575217, 50.24885669831307, 61.92736479543871, 61.51064042122134, 62.578286047904726, 65.50247576928908, 61.528726470085886, 61.60638939949774, 62.90534896235313, 62.37429141998292, 57.55882109365156, 51.19257111703196, 56.646277750692065, 51.42212390899659, 52.40397553290091, 51.535594155711514, 52.44554873435728, 51.69518363091254, 54.400771817853375, 54.13276803108954, 57.06086051079535, 52.676450821661184, 53.055477296152425, 55.31847699995964, 55.62763429457142, 55.86682042767925, 53.56937839138893, 56.284992156490205, 53.98581251021355, 54.26743868858584, 54.59059492234261, 55.16760303128151, 59.112546443939216, 56.188113535604174, 60.238823659958385, 57.87308923659786, 58.369453414793945, 55.04519370294387, 59.05982194408294, 55.47175538155341, 69.82801068213679, 82.58693956559705, 48.78107832324121, 43.29599665057275, 52.97204063784692, 61.76797536111648, 54.30889029656687, 55.89832882727347, 55.90650696908274, 54.03375564082977, 53.522090296591486, 58.48199798214821, 57.254343186655355, 57.75871292237313, 53.81649947935536, 58.128345320301676, 57.106097205992675, 51.72846101945447, 52.58358478546143, 49.62785920789165, 51.30128352872787, 53.25198411941529, 55.25451490955969, 53.83593090118901, 54.60202078665457, 49.17272698494696, 53.82368133914087, 53.270038789318455, 50.75011991685437, 50.382786027846805, 49.91781650050994, 51.12474549201227, 49.49556942908995, 56.62110005655597, 25.670651735798007, 29.432126283645633, 62.368482389757716, 54.01546562871626, 57.44099309367519, 56.169568569429465, 58.35269312704764, 56.377391430639456, 60.94274397819274, 55.98974358650946, 61.484980275554044, 42.73550956479965, 33.14787580120948, 67.97677747664913, 59.497919313369266, 60.6783526943576, 56.113106050798976, 59.20822874192269, 58.008183510072776, 63.38373299567931, 60.897252328934215, 56.65434998850669, 51.75980860187162, 57.28303140209567, 59.99005517651958, 69.85724018466088, 67.48102126582977, 61.19591728333504, 12.349518749021716, 1.2243195551057016, 0.6539024989451132, 0.0951189628892368, 1.0073165703685054, 5.272503918217075, 66.48785360397832, 53.84685470211891, 70.10907988394462, 57.69773967804448, 65.0645274500693, 16.356696448018475, 13.222813875444475, 34.70733565668906, 21.391541996309837, 49.14335627709666, 38.96113041908511, 30.221599378893455, 47.01640398271623, 63.75540110372729, 10.152524690474234, 0.48766570946862625, 0.3819731550831949, 0.057694506756360495, 0.06413921758893036, 0.08283715620036088, 0.10431161961488186, 0.05957629449004608, 0.024264354536670352, 0.07329438197156114, 0.054976292735626625, 0.049321476009584246, 0.03948551993216238, 0.09850578397632608, 0.0741702656171495, 0.042276217361852046, 0.13139681139540288, 0.16166453159624533, 0.12654116227021142, 2.44790391095223, 63.953563167202866, 60.05707279328377, 51.73771781306113, 41.56624709406207, 50.661976414342085, 28.745493811945764, 61.02699648949408, 8.43662698422709, 25.66091052947506, 79.56261173371347, 49.95096052846601, 68.37093645526518, 64.92868400389149, 73.29341688463765, 14.398598267186074, 1.143187044128295, 0.37503687244269157, 0.05098813859325263, 1.3450584440462052, 0.03283075162119443, 23.513081419852472, 57.0451553406254, 65.1819436011776, 72.81973577314808, 65.1551498905305, 60.32569631453484, 51.49269127076673, 53.33521289210166, 60.034872178108465, 68.77035140991211, 70.13265332868023, 65.21464047893402, 67.63327198643839, 51.82238217323057, 48.57809174445368, 53.028216823454834, 63.33802561606131, 62.89089895063832, 64.51382275550597, 67.24322365176293, 64.12082087609076, 64.37750078016713, 63.24025269477599, 62.34155139615459, 60.28377402213312, 53.57750946475614, 59.820577406114154, 56.66690941779845, 56.29642586554251, 54.26264555223527, 53.83131427149619, 55.80051275991625, 56.967127630787516, 56.317367399892504, 56.87958032854142, 54.361371609472464, 53.90897327853788, 56.013395478648526, 55.952602663347804, 58.992035542764974, 55.88311787574522, 58.82440128634053, 56.40763682703818, 57.012144673255186, 54.23054095237486, 57.46769266743814, 59.87833430690151, 58.37568998336793, 61.833961394525346, 58.66228580474854, 58.08410490712812, 55.889723147115404, 60.254815163150916, 60.44870184313867, 66.82815059538811, 78.4482192993164, 58.365425140626975, 47.37219433630667, 52.80562623854607, 58.269366295106956, 57.13112192769205, 56.327922498026204, 61.422669502996634, 54.39853214448499, 57.119845113446644, 58.42379000879104, 61.40835285186768, 61.46175984413394, 56.387824935297814, 55.62978375342585, 61.22529583592569, 54.96026654397288, 54.180071815367675, 51.2327048086351, 53.94365879797167, 54.66386479716147, 57.19767278240573, 56.5083436812124, 56.35168029415993, 53.28443781022103, 53.02280003024686, 56.34312168244393, 52.63306156281502, 53.58154166129328, 51.11672424500989, 55.37803819102626, 49.45561224414457, 61.97679842672041, 33.11885026193435, 31.211623261051795, 63.959411421129786, 56.466570438877234, 61.365332295817716, 58.18366250684185, 59.728990062590576, 60.257078370740345, 62.86221857993834, 59.41753425905782, 63.81458574725736, 48.65323651221491, 36.489943073641875, 68.43347472529258, 62.258106893108746, 62.75907985625729, 57.18436810278124, 62.591759389446636, 61.45029867849043, 64.54346018452799, 63.41602194693781, 57.837929110373224, 52.620933594242224, 60.90947443439115, 61.7775067206352, 71.7088185587237, 68.10014386330882, 67.24931901501071, 14.69159245491028, 2.010881025944987, 1.351843041277701, 0.10299911947860833, 1.5116144163954643, 7.258791683181641, 69.91787218278455, 61.84199440863825, 73.07049289826425, 63.001423497353834, 69.79343891143799, 22.555715191748835, 15.04607960101097, 38.32535736022457, 21.53225898742676, 48.05333352858021, 53.487134133615804, 33.33636529984013, 49.37676868131084, 74.1415588317379, 10.986686329687796, 0.5611488018785754, 0.17603485484517392, 0.0599606599538557, 0.10787833346835068, 0.011973191999019155, 0.05455520867760624, 0.03464846759133282, 0.20170666037067292, 0.22413324084012742, 0.3915369967299123, 0.15181113935766682, 0.1574980245242196, 0.26983982372668486, 0.15387306500586773, 0.15974534345009636, 0.20272761042560303, 0.33098531526423275, 0.3045719825933057, 5.113355709660438, 82.1151255023095, 63.71931922051215, 79.56370215262137, 46.895602826149236, 65.81924638440533, 52.38027657231977, 74.75244445185508, 13.079547343715547, 28.98995553293536, 84.71369574146887, 54.17549833174675, 68.28378923477666, 68.86943832520517, 78.33178766312139, 14.799846929888572, 4.442726017967347, 0.9149720255405673, 0.19545316125356382, 3.779638553819349, 0.25968033339708085, 30.14772742025314, 61.01562946073471, 69.50871406062957, 76.20362727872788, 65.98087941446613, 60.719561115387954, 53.24759890956264, 55.0501908025434, 64.61452960968018, 72.02568331072408, 75.37181023628482, 64.63438072512227, 69.43457341963246, 51.11151925979122, 49.82231070918422, 55.615933864347404, 64.41734813874768, 65.35750496772029, 64.73148292110812, 71.02415315566525, 68.13207980125182, 66.47258773926767, 66.51167023566462, 64.95974525328606, 64.98576233463903, 55.470351173031716, 62.3401471876329, 61.10422403581681, 58.80674669819494, 56.193177315496634, 57.408307983029275, 58.12874932442942, 61.074606218645656, 60.31212491373862, 61.41780968635314, 58.56607006442163, 58.86421726595972, 60.47899430797946, 58.689452140562004, 61.23424668465892, 60.49117326736451, 62.26812462652884, 62.221577859693966, 61.939288800762554, 57.17393459812288, 62.80908223121398, 65.24852975722283, 63.823618965764204, 64.85175455770185, 65.51064606635802, 61.415036570641306, 61.73074030107068, 63.84455265537385, 67.45335286663425, 57.691769830642215, 81.63416447178011, 65.54884995183637, 49.37371315494661, 60.36899928123721, 66.75528080232682, 61.683648324781856, 69.53932423745432, 66.78283153041717, 59.995224860406694, 63.28283786773682, 65.58702245835336, 63.76295166630899, 66.69862608755788, 62.91493915742444, 61.733482037821126, 66.08349646291425, 59.21095086682228, 58.7124764534735, 55.96987285921651, 57.439075054660925, 57.94121688412082, 62.758832746936434, 61.42108486544702, 61.442650056654415, 54.65148971926782, 57.96503351580713, 59.89263526854977, 55.71975508043843, 56.06879895733249, 53.588001804967085, 57.565889204702074, 52.72704939688406, 60.658179944561375, 28.344680532332394, 33.18841349694037, 66.9152036789925, 57.3395880576103, 60.8757891193513, 58.321482827586514, 62.67797700820431, 60.82574752069289, 64.3227562596721, 61.323966979980476, 65.579365991777, 50.181227191802, 36.360136155159246, 71.05248835779005, 65.05772606019052, 66.60996483218285, 60.05033808369791, 64.53661172620713, 62.781237325360706, 66.25473145515689, 65.31864996879332, 61.260075492243615, 55.495936793665734, 62.28132732452885, 63.518238913628366, 71.24190745815154, 69.79113255777668, 72.62083238170993, 19.025972312496556, 3.3466910114211426, 2.0623815011593605, 0.3599386277698702, 5.205162705913668, 6.979308099515977, 80.14801763719129, 64.32551760827342, 80.42378379452614, 66.98823821160101, 76.53235327812934, 27.713208352365804, 22.409563756758168, 46.51311682116601, 29.009008446047385, 66.86394614558067, 50.95763291082075, 45.27666807174683, 61.02956564195695, 85.67501375752111, 21.300244908179007, 0.8843997853898233, 0.4021361602410194, 0.15638990898526486, 0.2277162034184702, 0.22562925733866232, 0.18995370715856555, 0.23217250623049276], [0.016145170854044058, 0.07494903995745605, 0.12813401994325463, 0.0405646045692265, 0.05926534323202026, 0.08314277165599408, 0.026799339478114442, 0.06950050006590544, 0.05895859013581949, 0.035737748858669115, 0.05304470928686281, 0.2749389049506957, 40.517801469372166, 51.52326222388975, 44.11765475426951, 23.767509883449925, 36.44578110787177, 37.14002493889102, 38.45814528003816, 23.28912388893866, 31.101426232245664, 65.71326394234934, 58.76125112656624, 48.72244673390543, 56.072066291686035, 64.6929064104634, 23.488648976049117, 0.5424098622414374, 0.7256293501104079, 0.09299562763302557, 0.31468670274461474, 0.14217101067544954, 10.807756627759627, 51.82867757735714, 68.03283599115187, 67.88380161408456, 65.82697345364478, 58.4826647850775, 52.37220825687532, 53.49664588128367, 54.03828205600862, 60.121784056386645, 63.07164176817864, 62.56222001967892, 67.91955009583505, 58.53806041902112, 45.77183200467018, 51.8758362339389, 56.47781195179109, 63.37626872524139, 60.323633147824204, 63.88207012607206, 62.577230930328376, 61.49870072641681, 61.06044253995342, 60.086090487818566, 51.24035343047112, 57.546885321217204, 56.96883778418265, 53.74414351678664, 53.564291077275435, 52.96880468245476, 52.464689900798184, 51.32847339876237, 52.64736644683346, 52.94917714211249, 52.65827848065285, 51.81873436897032, 49.81731360958469, 55.95892944643575, 54.886977057303156, 53.87179705404467, 51.66493038977347, 52.93223642533826, 53.612014555162006, 52.0965087798334, 53.36004149529242, 53.72679095114432, 54.54056509079472, 55.792679786682136, 54.69561638370637, 54.89627307461154, 54.08718616731706, 55.030331842360965, 52.9747784522272, 55.91451252660444, 54.24759934025427, 71.4950180053711, 54.828270942934104, 41.75674484622094, 54.727167929372484, 50.09660597770445, 53.37775099662043, 49.7999845781634, 50.22809951536117, 50.81919285558885, 53.88989487001973, 50.86205651683193, 51.86543803061209, 50.82092654320502, 52.25983627380864, 48.773853317383804, 50.28017290176884, 51.876428511834916, 51.50889065957839, 51.42854090659849, 51.061791450746604, 49.234014018889404, 51.17862709106938, 52.05955220806984, 49.81011998268866, 52.44425042983025, 52.03580225667646, 50.70298871686382, 50.638622622336115, 51.1040000761709, 48.70501179848948, 50.87105443400722, 47.681822315339126, 56.69035342431838, 41.81157958122992, 20.2384396906822, 53.82021788627871, 56.85799944785334, 60.26092621587939, 58.921060254496915, 56.944326892975845, 57.377466386364354, 59.16468258826964, 60.53807696988506, 63.95526547585765, 57.296947971467056, 51.627640416545255, 53.68859098803613, 60.71166538423108, 58.93950323904715, 59.875859291322776, 58.48188423341321, 56.851958997787975, 62.078901644675966, 60.58596126494869, 58.2327627366589, 52.19624288620488, 59.26580521368212, 64.08981061750843, 67.32885683736494, 67.99011353523501, 50.781302759724284, 8.848174810409546, 0.8745822154225842, 0.6674348599007053, 0.11663834969963759, 1.0354777786039537, 24.11714799942509, 66.56322586920955, 55.9228357961101, 64.4658717801494, 52.14915090991605, 70.8466580606276, 24.42281830695368, 12.847801946824598, 34.65773336348995, 26.653417271952478, 70.15057856036772, 31.66113276635447, 25.402718551697273, 51.747531583232266, 53.79765641304755, 3.913848823116672, 0.14150520366045738, 0.12389337854279626, 0.0755724286840808, 0.042189254891127355, 0.0456033640300795, 0.06629236898715458, 0.0642624466619905, 0.07025760943971335, 0.03864577265396234, 0.12906162218461115, 0.03258255828592566, 0.02621568773212212, 0.05481698858221212, 0.07321295448608937, 0.009376959285638746, 0.031188356787747437, 0.11759860260832695, 0.1072444876415595, 0.253179035479984, 46.42641282850697, 61.532629228407345, 45.38127376187233, 30.51102322916831, 50.243031978607185, 31.905616060380016, 49.71175086113715, 25.743929455357215, 37.694146017874445, 75.62128082398446, 61.37622079541607, 50.69807006466774, 63.44150166357718, 70.8792608014999, 27.096035172862393, 0.48857401395517014, 1.8841239954194717, 0.16810918497222085, 0.3340942839220647, 0.1636244602982075, 13.697690329244061, 53.80400673035653, 66.37151610466742, 70.68436607237786, 67.66490982424828, 61.192991195186494, 54.7101487651948, 55.823827328220496, 55.07557245992846, 61.30527296373921, 64.63418460661366, 64.70795262244441, 69.66323975593814, 62.40408182144166, 48.4709051347548, 53.19381536975984, 59.11362901810677, 64.32674923250752, 63.133972152586914, 64.30685104862337, 63.69620469308669, 64.06452309700751, 64.03820791552144, 60.63591657146331, 53.60111036608296, 62.28368074663224, 59.078621864318855, 55.79399378068986, 55.62339813478532, 54.08374232630576, 54.35944964808803, 53.398876882368526, 53.839327673758234, 54.96680513505013, 53.168484703187026, 54.02123151286956, 53.40845923269949, 57.96875192273048, 57.325973510742195, 56.356826443826, 53.0722140496777, 54.05890195600448, 57.895870362558675, 54.26477147686867, 55.931390485455914, 57.07452997084587, 55.389358151343565, 56.34950337871429, 58.10443847410141, 59.41915027556881, 56.090022902334894, 57.6617205527521, 56.06903037717266, 59.12355261464273, 58.71456707677534, 65.48317770804128, 51.20427939199632, 47.27557851422218, 58.83186163440828, 53.44608652976252, 55.85807354219499, 55.421447061723285, 54.28395186701129, 55.33135806360553, 59.72424399468207, 56.064778527905865, 56.783697989679155, 53.82856861237557, 58.4492697254304, 54.37013026206724, 54.85315445930728, 53.70831658763271, 53.9252354252723, 52.40976887364542, 52.28768117966191, 53.144417039809696, 52.75713005373555, 53.518669989801225, 51.76909677443966, 56.35629692385274, 53.78245722862982, 52.76008752084548, 51.2549211132911, 52.263997908561464, 49.952521631794596, 53.130512237548835, 51.90883513419859, 58.38787678749331, 52.18901788034747, 23.972975400186357, 55.02367950254872, 61.606048153292754, 61.0850985588566, 60.51348763127481, 60.663118208608324, 60.87094499218849, 62.53304543033723, 64.05438769248225, 64.9546383273217, 59.93131768318915, 51.447980173172496, 56.89461869578208, 62.660189059472856, 60.503501276816095, 61.358056299148075, 60.46098278414819, 58.605984103295114, 63.11164209919592, 63.30361466253958, 61.998296937634876, 54.51527364792363, 59.83305838800246, 66.76257641084733, 69.9441755971601, 69.41132160925096, 54.08527205067297, 9.327615922497166, 1.100178010040714, 1.1751596317175896, 0.3127000835393706, 0.7657654319078692, 31.162936841287923, 70.98543151732414, 61.47589214386479, 68.25775254157283, 57.53178811842396, 74.07572577076574, 28.171447092486968, 13.694614210436422, 46.13127016252088, 22.60911826164492, 73.41778739806145, 42.25632536795832, 24.755615726594005, 58.16882418047998, 61.67351292025659, 4.481356951498217, 0.3600387401398151, 0.24727304916708703, 0.04910450841810915, 0.045969569379644054, 0.07916030188601825, 0.01846484869958893, 0.096515127487721, 0.184102634028081, 0.10147065915648015, 0.20161269202588067, 0.14925197668133244, 0.18587087220962972, 0.16416167179422994, 0.17658495194008275, 0.16074692680230065, 0.12617330983160965, 0.20525288137216724, 0.2124800935627953, 0.33636579590459026, 66.5819198854508, 68.89975824663716, 61.923473804227775, 33.49034970806491, 52.93441726315407, 50.313383610017844, 50.1421368506647, 36.3357586245383, 44.96312948965257, 79.69863953128939, 71.09141395938012, 59.16035621396957, 67.23886197613132, 75.948437875317, 29.14875465054666, 2.0283511401184144, 2.6633839741829903, 0.7622198544202313, 1.4305895254496606, 0.6466698934954982, 16.228903666619335, 57.74541216511881, 68.14547861776045, 74.55201133604973, 71.34391261685279, 63.61681592079901, 56.160496127220895, 57.92818284803822, 57.571415824274865, 66.82006266809279, 66.315214403214, 68.08734909180673, 73.78208929492583, 62.4463688942694, 50.18094085877942, 57.62027286714124, 61.08213324700633, 67.09156128668016, 65.60294728125295, 67.25695194736605, 66.19813165357037, 65.82753043020925, 67.7577680157077, 64.1090419984633, 55.85559068187591, 64.13318810924407, 61.955727454154726, 58.595213274801935, 57.32411038491034, 57.17972401649722, 56.43744684034779, 57.508355879014545, 56.48231875511908, 59.66139977978122, 55.634439606820386, 56.41496381452007, 56.059608844018754, 61.475813696461344, 60.33957758257466, 60.778588864111136, 54.93812868672033, 58.49502809586064, 61.508757683538626, 58.71120952790784, 60.202063206703436, 59.72346344301778, 59.010984513067434, 59.410870152135054, 60.837761740530695, 63.085001360985544, 59.516731000715694, 62.36907859002391, 59.93564797985939, 63.7600883360832, 61.55853256102532, 68.39334103368944, 60.67479902698148, 50.99586817526048, 65.88022355110415, 58.9950361559468, 63.00499285421064, 56.74928311378726, 58.8334462719579, 59.51901774252615, 65.32432956080284, 58.435439448202814, 58.13074973321731, 58.161740379948775, 59.926563770540305, 54.1162823092553, 57.68939287431779, 60.76862996624362, 58.86765718460084, 58.255838040382635, 56.30026194357104, 56.55248603513164, 55.9402197407138, 57.66223830561484, 54.260994234392726, 61.16587977255545, 55.38596137877434, 55.80011267815867, 53.5684331001774, 55.59130530203543, 51.88105298626808, 56.32230174156928, 52.7056920912958, 62.931872029458326, 43.28858337094707, 21.663721146122104, 59.846084579344726, 62.642483480515025, 64.40614977190572, 62.945208088044204, 62.07997245173301, 63.01472425460816, 65.6596294526131, 64.65239617132372, 66.78422789419851, 60.76502923042544, 52.32738733291627, 60.84614776795911, 61.553664899641475, 64.00925690127958, 64.83175046982305, 63.06587980639551, 61.11173929706697, 65.20493261275753, 64.42344350199546, 63.85848491422592, 56.81098591896796, 63.39342909474527, 67.87747090862644, 71.2688776754564, 68.79643517155802, 60.50664701769429, 12.381016362097956, 3.067182422645631, 2.012280086355825, 0.8687709788641623, 2.7649731164978397, 31.75801923198085, 77.29067294828354, 65.68437568603024, 74.12139000431185, 62.9883933836414, 79.68910817177066, 35.83586431318714, 20.43667235682088, 48.88298542268815, 35.9396110042449, 96.73327353692825, 44.04717760701334, 38.59911918640137, 65.3079850442948, 78.48884720956126, 8.96358564976723, 0.5610498233187584, 0.40668932721018797, 0.26177589030515763, 0.14938262531593924, 0.10838033556337319, 0.13136898708199302, 0.19584835537018316], [0.01605291088532296, 0.19043363059961027, 0.08616486594321267, 0.031184097338888436, 0.023216865280823364, 0.06355330588356142, 0.13547918669158412, 0.10198851161065603, 0.04634410210494553, 0.23011217404517437, 0.2054456290939162, 0.2642518251893982, 19.996231371356597, 62.24467669763873, 47.75826538762739, 24.011565639126687, 36.73289468211513, 35.997638548574145, 41.14440402676983, 9.33409175565166, 20.44651750595339, 62.815169749721406, 63.027879884166104, 70.2541212881765, 52.25052456701956, 68.94053520694857, 37.57066196010959, 0.6284531806745838, 0.7083345168540556, 0.14162972359166992, 0.18641847185790542, 0.2531064103447622, 7.796327510187703, 49.730189923317205, 65.55567879830637, 67.6950728508734, 67.77966268600957, 63.90470612433649, 52.8297645045865, 53.31340451394358, 52.11377113096176, 55.26526220383183, 64.20268466395717, 66.74955414187524, 64.4126687511321, 66.92640596820463, 57.193385631807395, 51.37965248477075, 56.576620378801906, 55.6503918863112, 62.05850139740975, 67.25251182433098, 63.69126642903974, 63.56655859178113, 61.14156499985726, 56.45585844593664, 60.562368208362216, 60.938558809218875, 57.08504192290768, 54.214714188729566, 51.89810745177731, 50.528976686539195, 52.076245815523215, 48.69019700634865, 51.341672174392215, 50.35015975275348, 51.51750810684697, 48.12354003229449, 51.53271905837521, 54.358088585638235, 50.99274989097349, 55.29071054150982, 54.812436334548465, 55.6369460013605, 54.22347676369452, 54.93968586767874, 54.84309357981528, 51.78587667403683, 52.64416579277285, 50.65874045894992, 51.409082028173636, 50.060810427511896, 52.205554592993956, 52.866748532941266, 52.245366650242964, 52.759354037623254, 52.66251464043894, 64.03348538183397, 53.91337025550104, 46.144790572504846, 54.49136680172336, 51.1284403647146, 49.1510872687063, 47.351256724326845, 46.8820628043144, 47.21334226669804, 51.79018735885621, 49.50759933840845, 48.52727743887132, 49.48704611870551, 50.79248935945573, 49.12068497750067, 52.28488060735887, 49.68454530162197, 49.93035239558066, 51.859546630613266, 53.107283961388376, 49.77930192024478, 47.83988206617294, 49.793677406926314, 51.249323891055205, 49.3457035095461, 48.97546314424085, 50.96041387127292, 53.2195931865323, 51.037237413467906, 50.09170693735923, 48.50795192103232, 51.06621588430097, 52.85343600857643, 55.41760706132459, 22.262215998864946, 42.546643518632465, 61.63206131227555, 57.058730663791785, 61.56627924211564, 56.13716194706579, 59.27199079144386, 58.288609443172334, 53.45348804227768, 50.65451998864451, 55.49820392362533, 39.18326993142405, 91.36779277555405, 97.67386574898997, 51.640348895903564, 60.82990915544572, 54.413217498410134, 61.36053915946715, 59.708703564059356, 63.824666238600216, 55.352523173055346, 54.05872544934673, 53.897480733932994, 65.59566343984297, 65.53838114584646, 75.23507641207787, 37.70976881827078, 6.177373634230706, 0.5726228377992107, 0.4024560785581989, 0.12317635088918671, 1.7985498905181887, 48.49699281877088, 60.30217386061146, 54.294279467675, 67.62632154649305, 54.70806990900348, 71.79656982421875, 20.264990214378606, 18.851507248417025, 25.914189738612023, 26.8034008626015, 58.611043960817405, 23.670903867290868, 52.83667572083012, 51.429368526704856, 46.86550255744688, 0.31465814298679756, 0.1597495722554384, 0.1270084222778678, 0.03698232380913631, 0.022304670982843926, 0.04891344992023322, 0.07195847784920086, 0.11600507077791038, 0.02907037840134675, 0.09875716040692023, 0.03693020301720789, 0.02514159607310449, 0.045954071420935855, 0.01581859619041244, 0.06938772426257211, 0.10808552960835158, 0.09348220071725308, 0.16739785701276796, 0.42132338388792934, 0.31717051301271687, 21.20731023050124, 74.01634893109723, 52.40252817830732, 22.94234125844894, 48.02913250461702, 38.08901494549167, 50.016491566934896, 16.50158978277637, 18.46013511380842, 74.36479660772508, 65.81839915244811, 74.55883626014956, 56.065723819117395, 76.32757417617306, 40.39524701333816, 1.417231403531567, 0.8796402956208876, 0.19129540290563338, 0.14583668010609765, 0.30398580275716325, 9.622553644641753, 54.14362122935634, 64.76794919660016, 68.91795804423671, 67.29295930554791, 66.44393090278872, 55.35172693191036, 56.79440606024958, 53.39680587091754, 58.34935126766082, 64.53724322780486, 69.77652565125497, 65.32352155254733, 69.6043885138727, 60.87098029352004, 56.67076510767783, 58.27946639830067, 60.786790540141446, 62.80711320138747, 69.8343570770756, 66.28044651400658, 66.13580519153227, 62.13153593001827, 62.47926581290461, 64.39530834074944, 61.6977963139934, 58.02804247025521, 56.70298737864341, 53.63236773398615, 54.28143370536066, 52.89355793306905, 52.176815386741396, 54.128284761982584, 51.915601222745835, 52.895785839326926, 52.6155952484377, 54.11684320818994, 54.92245097314158, 53.55894880910074, 56.76601986731253, 56.33515534862396, 56.22763533746043, 57.368264505940104, 56.52135810544414, 53.791776780159246, 53.140663331554784, 54.90654183972267, 53.22196229811638, 52.94603532360446, 53.64961047326365, 55.26441104950444, 55.672914135840635, 53.45972068848149, 57.20990273260302, 56.95735308431811, 62.57259076641452, 50.150095339744325, 52.05370395414291, 56.977914148761386, 57.76715386298395, 54.522839899986025, 51.12986810745732, 52.33481237965246, 52.42863939654443, 53.94713401794434, 53.297762101696385, 52.89925713692942, 55.29816304483722, 53.84274013580815, 52.25551774424892, 53.09869789308118, 51.6035766755381, 53.209830407173406, 52.32068400229178, 54.92913469191521, 50.01735841074298, 51.284786039783114, 50.71422238503733, 55.83379014845818, 51.56185834638534, 49.99365945016184, 51.97433087133592, 56.282901533188365, 51.06128546499437, 50.486458193871286, 48.86225177395729, 55.11428233115904, 51.993954489308024, 68.62050117984896, 31.558078373632124, 42.880441142666726, 62.30435948218069, 59.39212122271138, 63.10377774700042, 58.851081248252626, 63.61904774942706, 60.197321061165106, 55.20517933753229, 51.61527710576212, 53.3312120745259, 41.89703626017417, 77.28471879036196, 82.71921757728823, 60.1473500651698, 59.908222767614554, 60.66704450115081, 64.62323727146273, 62.36008067284862, 63.8297966987856, 58.958816989775634, 51.69159466220487, 58.859035814962084, 68.61487650102185, 69.03849247963198, 77.50449703585717, 41.43227069608627, 6.268393214671843, 0.7038621568391401, 0.46499468566429236, 0.19720655265114, 1.337680098029875, 54.511304209309245, 66.25839494889783, 59.93026648798297, 72.92306669296758, 65.83458285177907, 77.15427644791143, 22.656982944857692, 23.843121413261663, 34.77176058676935, 21.480154222057713, 68.1796032382596, 26.72087223299088, 47.53095619140133, 61.40091996039114, 51.433596841750614, 0.26428115103513966, 0.05592483215995374, 0.07390012769328971, 0.040868327787686745, 0.0172450011520977, 0.014595107810061066, 0.05993897583515895, 0.16806504298602382, 0.2854922564039307, 0.2682157479707272, 0.2615810894677716, 0.1749846402315363, 0.15146649172229154, 0.10344502861581503, 0.16552959839182516, 0.1989712208629616, 0.20745624217294878, 0.3331882164122597, 0.5169740271183753, 0.29955134877274114, 34.73285067465998, 83.2993047468124, 62.54416142740558, 38.86026274773383, 50.42322566432338, 57.53302758739841, 50.56549787521363, 18.72259463033369, 30.251434887609175, 81.36221870299309, 73.11406258613833, 83.83660670249694, 62.83657412375174, 84.10982331921979, 44.36299900854788, 1.8618363526559647, 2.853657170649498, 0.4818130122317422, 1.2455562478111637, 0.36662112080281783, 12.66392711670168, 59.36489605134534, 68.08340318741338, 74.36467109187957, 71.88522323485344, 69.44739172535559, 55.993285486775065, 57.70378405048002, 56.03268177278581, 62.118588186079464, 66.02111508769374, 72.43819898174655, 66.91132837726225, 69.6885076645882, 60.699356986630356, 57.77078205539335, 60.36960724861392, 62.83021203933224, 64.13596514732608, 75.22216396947061, 65.95525849250056, 67.54808595103603, 64.8020463605081, 61.73613356005762, 64.96700556047502, 65.71617826338738, 59.862617369621034, 59.72089429055492, 55.09043039814119, 58.03672267544655, 57.628176443038456, 53.657996500692065, 54.8605324376014, 55.863392276148645, 54.91957979817545, 56.245023204434304, 61.537426287128085, 61.806022351787945, 57.33468117252473, 59.921625506493356, 61.08775792583343, 62.86056726209579, 61.549640547844675, 61.54224688006986, 61.242389525136645, 55.78234434127808, 61.302954842967374, 55.64970939390121, 59.322510919263294, 55.23989231355729, 58.54697204405262, 59.64023859270158, 58.589702344709835, 59.87924037441131, 60.1968542991146, 68.78050250391807, 59.11631584167481, 58.53108644485474, 63.202072343518665, 64.39005236471853, 57.50418639952137, 58.08778016797958, 58.04761117504489, 58.28034893158944, 58.882797533465975, 59.15501002342471, 56.99663169922368, 57.50137406010782, 62.29756985941241, 55.633780648631436, 59.74661327177479, 54.888957854240175, 57.80469879027336, 57.21093823832851, 58.69976797411519, 52.96773387539772, 54.860379465164684, 56.66452461673368, 57.26525914284491, 54.75881361192273, 53.468463651595584, 55.09529021478469, 59.62467070548766, 56.77769676331551, 53.29146277519965, 52.69012028171171, 56.596640156161406, 58.341161358741026, 61.44552907636089, 25.926939402857137, 47.30636127533452, 64.33143646486344, 62.221511179401034, 66.96111894422963, 62.544663490787634, 64.16437095211398, 62.749332766379084, 58.76696601990731, 54.80556434200656, 54.54038858413697, 42.76953612604449, 71.17299141422396, 86.93015652318155, 60.310956047427275, 62.2160041716791, 61.9539035520246, 65.10807752609253, 65.62008019416564, 67.10739197269564, 60.64818182299214, 57.94392724190989, 60.12843639619889, 71.71829500506001, 67.10951005258869, 76.93070919282975, 47.22405818200881, 8.621217646906453, 1.0542340624716975, 0.6367219047200295, 0.5097816259630266, 2.2613687332599395, 58.633099448296335, 70.81130966063469, 66.52275485377159, 77.955671587298, 65.59250985422443, 82.58298581646335, 31.305654241192727, 28.852843200006795, 35.03258251374768, 39.57386347555345, 83.17202383472075, 32.78548605980412, 73.81021268906133, 64.18353565277593, 71.30543416546237, 1.4850005219059608, 0.27812062131781734, 0.29471972416485515, 0.16525247374609595, 0.14258068385383776, 0.0946374536461888, 0.34665095529729323, 0.318627979966902], [0.02303352703400437, 0.07670449213154855, 0.16832267835495934, 0.09206222610608225, 0.11286137535447076, 0.06844847748476653, 0.06397787564163727, 0.08915371967539673, 0.04617913273133097, 0.20108038349257362, 0.12294229570656054, 0.6439277277358118, 7.432381078120201, 62.22346059737667, 52.17691736836588, 44.97366889830559, 52.34715607858474, 42.6461148262024, 28.4062833170737, 13.352005962402592, 3.7325340749755984, 50.13933235599149, 54.52103560970676, 66.09996257289764, 58.123587485282656, 59.96869394856115, 47.508857557850504, 1.5283119462190138, 0.032671830511742064, 0.20618983754707923, 0.22918352226336158, 0.4339476855051133, 6.7976067527647945, 54.47363768854449, 65.06382926817864, 71.49234294891357, 63.20306862554243, 62.54558132540796, 55.571469876074026, 56.59136064590947, 53.27776193618775, 56.19301649831957, 55.56966166342459, 60.148809186873905, 60.59320196028679, 63.67658107511459, 69.61717544063445, 58.923445055561686, 55.52473091310071, 58.23664980549967, 55.257056605431345, 60.55712399944183, 63.55248512760286, 62.9337037763288, 63.39908123016358, 65.5807113647461, 63.535944492586204, 59.56909464251611, 56.08959144161594, 55.52522120937225, 55.18980364645682, 53.770635204930464, 50.12845562350366, 50.208322924952355, 51.38464958437028, 48.81264948075818, 49.18071685298797, 48.25448051575692, 50.07498979568482, 50.45995866098712, 54.19614568833382, 53.00877755688083, 57.633526555953495, 54.031551268792924, 55.614651249301055, 53.03146846832768, 53.339727540169996, 50.61348807427191, 50.14953444080968, 51.4409944318956, 49.845872386809326, 46.7988811000701, 52.509436299723966, 50.435224194680494, 49.55266737168836, 50.9778723409099, 53.93449614124914, 52.77883645026915, 48.991125168338904, 46.340461930921, 50.46315931504773, 48.00146018305133, 50.816368749064786, 46.55861239279471, 48.09235718942458, 45.9551243628225, 47.39874486000308, 46.22895286929223, 48.8284723220333, 44.45344101998114, 46.17583613241873, 43.4001277339074, 48.6682984136766, 52.02904793523973, 50.297337193642896, 50.05233026319935, 50.10724344561177, 50.55828071409657, 50.588596713158395, 50.83192879153837, 47.917568529805834, 49.59876306595341, 50.70784068876698, 49.78314584301364, 50.91516148659491, 49.51488710218861, 50.460162624236084, 47.9073154541754, 53.07895268163374, 52.17967087222684, 60.01552312604843, 43.952217025141564, 30.137884232305712, 56.12237853388633, 60.33040315874162, 58.51646384885235, 59.16720859466061, 57.516451651050204, 60.58718504444246, 49.70186648830291, 49.49321208461639, 45.79210673609088, 58.09394221152029, 56.849766392861646, 42.241891045724195, 62.214733323743275, 57.337544502750525, 59.2872723456352, 56.50077350677983, 56.97807104356828, 58.26267473159298, 56.646968087842396, 53.53701883746732, 57.390261157866455, 67.98667753896406, 64.99598795367827, 71.25365103444746, 40.282169003640455, 3.5868984316625907, 0.9066886538940092, 0.8128080108473379, 0.3543344800991397, 6.856034869147885, 61.08935433049356, 50.27876477087698, 55.58063253279656, 65.9741956956925, 47.85243365072435, 60.25434055636006, 10.428832134892865, 19.60119378182196, 23.94857825771455, 36.73404393657562, 60.38689705633349, 31.615050800385017, 45.03069623824089, 57.60539139470747, 32.131042518923365, 0.5455324979078385, 0.1334971640138857, 0.039457021461379145, 0.05522911324195805, 0.1742669077770364, 0.09570706560606919, 0.15396536327898502, 0.023255160100938334, 0.07651020457307178, 0.10735687274005144, 0.038473061961872924, 0.13343140302646544, 0.04866084008808098, 0.040717672766937364, 0.06058254331770924, 0.09714073020844691, 0.12298682839759897, 0.19957286035341604, 0.36019002718310206, 0.5219711267179059, 9.0463545245509, 71.76624990278675, 56.36107044835245, 36.752428085573264, 64.04335014281735, 50.362428926652484, 33.3118151849316, 21.922972163846417, 4.754234283201156, 63.46961329060217, 65.6092466077497, 72.44899334446077, 62.6717875080724, 67.48262159286007, 54.64152689903013, 2.813282008132627, 0.11640561984912043, 0.1494924363590056, 0.6233688083387191, 0.3554321002335318, 7.96011588265819, 56.230596726940526, 66.29703029509514, 73.94775452152376, 65.58775594157558, 66.85424220177435, 57.02459427618212, 58.934906221205196, 55.87555946842317, 57.814896952721384, 55.49262239087013, 63.95052725268949, 61.31876199476181, 67.06975290852209, 71.54661286261775, 60.3192557827119, 55.99045745788082, 59.52348139978225, 57.07418087990054, 62.640847852153165, 63.68395905340872, 64.05665482244184, 63.832405074950195, 69.54329367606871, 64.76876897196617, 64.3249959330405, 59.758231332225186, 57.80782884167087, 57.07797381185717, 56.224140505636896, 54.235165426808024, 52.548252074949204, 53.0132451365071, 50.3000436290618, 52.40081802491219, 51.767978898940555, 49.95725985496275, 51.10918152716852, 54.665931886242284, 55.518541412968794, 58.67683779808783, 53.51389646530152, 56.55809110210788, 56.00465643790461, 55.059376993486964, 53.00617702545659, 51.85543598667268, 52.981650444769095, 49.905849349114206, 51.6304252993676, 54.529860942594475, 57.01409409123083, 55.00854307605375, 57.266824168543664, 57.046465412262954, 54.849557645859264, 52.45783359773698, 56.33766174316407, 56.31115044316938, 57.170800624355195, 54.442662731293716, 54.23222757154896, 51.311081609418316, 52.75122688662622, 51.22441291809083, 50.977248684052505, 51.58340000337171, 50.77906700872606, 51.32019719769878, 51.792136776831846, 51.36332758011357, 53.49606537049817, 53.82905890864711, 53.05929768470026, 54.091861632562455, 51.45726834574054, 50.15365685186079, 51.61349242733371, 51.63662656661003, 50.383182187234205, 52.967777021469615, 50.142517320571415, 55.83648089439639, 48.873171652517016, 53.26974853392571, 48.67473502312937, 57.00000885994204, 52.834902809512236, 65.25807680622225, 59.53431890856836, 36.69057230795584, 58.275763680858, 63.15287797681747, 58.26304343438918, 63.401838656394716, 58.080566929232695, 64.08496256797545, 54.08289117197837, 54.13134028834682, 46.14450816185244, 56.86592655797159, 53.05033114648635, 42.82292350645989, 64.96858235328429, 60.537233660298014, 63.4544768641072, 58.938585404426824, 58.968065938641956, 60.20114537208312, 57.25989726281936, 54.55516807494625, 60.268959229992284, 71.28641067012664, 67.4652611824774, 75.62172797418411, 45.97195133086174, 3.1413007551623933, 1.0386593111099736, 0.7859554646476623, 0.5265968881787793, 10.471440842074733, 67.68125041838616, 55.033363834504165, 63.576286069808475, 70.25866339283606, 55.76306589188115, 63.75074917270292, 13.830402743431831, 32.77215980714367, 28.4461816664665, 32.11914204782055, 74.62305330461072, 34.65467783712572, 44.41910851386286, 67.73042125086631, 30.706769112617742, 0.38525244040835294, 0.08409454397136167, 0.07678791144562346, 0.07839571549406937, 0.008939640866892954, 0.054846559576089346, 0.1904833497058961, 0.03484865019638692, 0.18092176035767604, 0.24832439759085256, 0.3347600756152984, 0.4024741582332119, 0.24874551612282955, 0.20813974581899183, 0.19377939703483738, 0.17849931373230873, 0.2917181916775242, 0.3805710303206598, 0.5713811624915369, 0.9348895761274523, 15.776120943407859, 87.04521532981627, 66.54361401834797, 67.70469834727626, 65.24944759184315, 58.49205493927003, 37.934595154177764, 22.91253516750951, 9.126598373536142, 67.14996537854596, 65.23965735589304, 80.63791382697322, 66.5536395965084, 75.38363225998418, 56.1835753533148, 4.260622137977231, 0.3364138755827181, 0.34971607308233943, 1.309150125711195, 0.8172990021205718, 9.333854452256235, 64.0322066891578, 69.85141154258483, 79.64859793263098, 69.50118310989873, 69.93607982512444, 58.86950462095199, 62.1121790332179, 59.02513250227898, 59.25310457906416, 58.69833630900229, 67.4052567635813, 64.03508570886427, 69.39789141378095, 70.62740541273548, 63.11827874952748, 56.594180830063365, 61.14206706323932, 58.99160800441619, 66.68279540154242, 66.36003140480288, 67.60649788764216, 66.64727441726193, 70.28586895235124, 67.94258225348689, 67.2806195289858, 60.44232406923848, 62.19123048167076, 59.234261512756355, 58.81670167369228, 53.45681028981363, 54.78510133681759, 56.219006123081336, 52.665201464006984, 52.67777658277943, 55.58216225716376, 54.53624263886483, 54.98824481041201, 57.17160863261069, 56.86645215557468, 61.778142144603116, 59.12493721131356, 63.74602271664528, 60.33606706127044, 58.885441210962114, 57.37949032937327, 55.652502121463904, 54.98875079616424, 51.800573795072495, 52.48148941224622, 59.05354615180724, 58.85686282188662, 57.442483594340665, 58.175735396723596, 63.954010317402506, 59.024959917991396, 57.49329397755285, 60.78073832296557, 65.02406820174187, 60.8605860125634, 61.699588837162146, 58.810327822162265, 57.05118010121008, 54.317013525193744, 58.418588945942545, 55.79542152343258, 55.199864525948804, 52.06987588636337, 53.980831100094704, 54.40438039841191, 59.029627538496456, 56.114392588215495, 58.48618315112207, 55.998259052153564, 55.55561173346735, 52.70890059009675, 55.232008349510934, 52.815867547065984, 54.993606690437566, 53.81183578122047, 53.43183263655632, 50.88797161656042, 58.60996923139019, 52.291811435453354, 55.20559510877056, 50.687365916467485, 57.411034030299035, 55.102468152200025, 66.74704382496496, 44.461776056597316, 36.790937915925056, 60.63868576480497, 63.13604708640807, 64.23325169471003, 63.29599741966494, 61.83923306003694, 63.65283504609139, 56.643441877057484, 50.76080445320376, 47.67653496034684, 53.694364716929776, 64.33062453423777, 58.96428085142567, 63.68078977830949, 62.25250574850268, 62.06507136744838, 63.45129189952728, 62.788619226025006, 65.54982662200928, 61.51571989059449, 56.478533667902795, 61.12697378281624, 73.37704966145178, 70.46416421090403, 70.52027763858919, 50.13639057836225, 7.090372952722735, 1.3430830403681726, 1.4157212910152253, 0.6199510756038851, 9.844641185575917, 74.91924716580299, 64.91544208218976, 67.20152885683122, 76.64811811139508, 58.419000794810636, 74.0341329574585, 17.646123670762588, 30.994382789058072, 30.24701241523989, 53.205962950183505, 86.20544372066375, 44.98463976767756, 61.91111049344463, 70.77468256796561, 52.96283091268232, 0.7656750948198381, 0.32090390461587137, 0.25947974093498727, 0.19531344213793356, 0.21776729533749245, 0.285093829396271, 0.28279590270211624, 0.15170600145093857], [0.056757351398588195, 0.02895169797533703, 0.08305692384319921, 0.055626854600925604, 0.02490447845400101, 0.05050520825710508, 0.025363342138007287, 0.07925431619608596, 0.04976439357344663, 0.04041474244947876, 0.10257233189599169, 0.16603504788250695, 1.9851598383918887, 58.5823675124876, 55.882909990126095, 41.965089382663855, 27.15811060320947, 36.17225854627548, 36.55209695139239, 17.20312726113104, 6.202684688952662, 41.459660606999556, 50.64228611607706, 63.13583527841876, 65.79494730118783, 58.599814215014064, 62.12399713454708, 6.066994215211561, 0.1122268553703062, 0.07504026570747938, 0.5596888221559987, 0.07624764325878314, 2.6143175748086747, 48.47083845446187, 62.94398430855044, 70.05468445439493, 63.68344522291615, 66.65325995414489, 52.53280578121063, 59.45223939034247, 56.68375599768854, 61.98531781473468, 58.44774392343337, 57.49859309965565, 61.00267779442572, 67.4098773156443, 62.082306261985536, 62.04524770859749, 55.46141209140901, 55.3167825360452, 43.94119124258719, 55.10656310665993, 63.45421014293548, 62.271360581921, 65.3113269036816, 64.09306226238128, 60.54212093353272, 57.4675710739628, 57.769358235020796, 58.852022617093986, 56.41336348748977, 58.950972249431, 51.82166045711887, 51.43738977370724, 51.44516391138877, 47.53043843853859, 48.98291564756825, 45.08801775593912, 48.75348444907896, 49.417074957201564, 52.14118457609608, 52.542097876148844, 54.626135518473966, 55.2785002031634, 54.645908186512614, 53.568103621082926, 53.20651208200763, 52.23647463706232, 47.693632571927964, 46.948303791784475, 46.22847826250138, 43.99222520089919, 47.06209959522371, 50.046874246289654, 52.07372373150241, 48.417611891223544, 53.43777110499721, 49.78528353475755, 44.27259622081634, 46.93960789711245, 50.14282718781502, 46.22771340031778, 47.668313672465665, 47.279967646445, 45.576301851580226, 44.133136349339644, 45.37933218863703, 47.031850276454804, 45.94329057201263, 45.42033664641842, 49.10936893955354, 50.77163019487935, 50.294736662218654, 47.041024700287856, 49.986575649630645, 50.18909154399749, 49.40658261699062, 48.04868944229619, 48.516290880018666, 47.624116405364006, 46.99618416447794, 46.65885248491841, 47.01330923265027, 48.75301768702846, 47.505233287811286, 50.12584724733907, 49.297034740448005, 49.95848363445651, 52.932981675670995, 52.52511401330271, 54.07704684042162, 69.14718135710686, 62.29095674330189, 47.23231477122153, 58.41399192810059, 54.12119703908121, 60.85352574625323, 58.73519482151155, 59.822750399189616, 57.30949563364829, 60.84256664399178, 48.25713596036358, 52.12567160206457, 14.579589174639795, 37.82290174115089, 65.58950531867244, 57.992250842432824, 57.706392426644605, 56.904232425074426, 55.82253294606363, 55.41726189274942, 54.77623678022816, 57.219575297447946, 59.27542678771481, 64.55996551821309, 65.16000186243366, 58.36035351599417, 26.951842961772797, 0.8649698957320183, 0.29315448396148225, 0.23958121997214135, 0.03914241213351488, 9.63156234833502, 53.80133559626918, 51.79094045392929, 62.1849193880635, 61.52321161762361, 50.23776423546576, 47.912826384267504, 1.997844415806955, 31.545252223168653, 23.80226992791699, 51.52019100804483, 36.72858007492558, 29.97950088593268, 61.882896884795166, 53.31081574962985, 11.668367789637658, 0.6764875676843428, 0.199757089177447, 0.12709202545304454, 0.07840610364632261, 0.07597998745979802, 0.10847417367321831, 0.03886079821254938, 0.19161942745408705, 0.05076079817128278, 0.01748677658578081, 0.06458172529575325, 0.06421437081430229, 0.06494184790719902, 0.11640545897065632, 0.18237515172410398, 0.05190920227417543, 0.08036842254260856, 0.08954437089062507, 0.34349216028086604, 0.2655785669001841, 2.3005907189461494, 63.727222796409364, 65.37854456132459, 36.52331852143811, 33.53263678089265, 49.52378696010959, 33.54324679220877, 27.209607401201804, 7.77692158376017, 44.80323406957811, 56.46013775179463, 73.79255417854556, 70.40183774886593, 64.75850805159538, 66.58028033471876, 9.044239386435478, 0.15232536821596085, 0.2816333795987791, 0.24240197103110053, 0.21032747842611807, 2.680469818653599, 55.505652504582564, 63.17662400584068, 73.4226982055172, 63.11459956630584, 68.89186643785047, 55.8881934227482, 62.5252438360645, 61.5770814495702, 64.01315965960103, 59.9868506000888, 60.21774092028218, 62.157329436271425, 67.54328496994512, 62.388929705466, 62.28563408697806, 55.34296043457524, 57.464872483284246, 50.71607374375867, 57.713433081103915, 62.979524904681796, 64.4850011794798, 66.54355910516554, 65.74375644806894, 61.35690312231741, 59.30475042712305, 61.89547200356761, 58.21249192760837, 59.33555672245642, 58.34143984702326, 54.21314131829047, 53.184978269761615, 53.56435775756837, 50.26736636315623, 49.888202605708955, 47.61834659884053, 50.07583702764204, 50.735446330039736, 53.9185477841285, 55.28885526041831, 55.350138371990575, 54.91816382254324, 56.419658891616336, 56.878027069953184, 54.3392925877725, 52.19579573600523, 50.505320872029955, 50.31631362053656, 48.17466420512046, 47.80063875259892, 53.88445454259073, 54.7172051091348, 56.982660216669885, 54.003612226055516, 56.96752379017492, 53.000046360877256, 50.25044133586269, 54.45131940226401, 52.565235937795336, 56.48135385205669, 55.63626350895051, 50.552012766561205, 52.3071635923078, 48.89209316622827, 49.0854307143919, 49.40141685547368, 51.864735926351244, 52.18343634759226, 50.08957316798549, 52.43841394301384, 55.57426260363672, 50.5349543786818, 53.55223371136574, 52.25058340257215, 50.81260327369937, 50.20318069765645, 52.4641917597863, 50.637838148301654, 49.26183146815146, 48.79678741578133, 49.435062946811804, 51.101764325172674, 50.52958857628607, 49.096201542885076, 51.44986683322538, 50.519782650855284, 54.08031417477516, 56.12419066890594, 55.703614527179354, 74.16677182720554, 77.67905819800593, 51.57827738792666, 62.21219162787161, 56.25554692360663, 64.43296701677384, 60.067388626836966, 64.1053157467996, 58.56605829731111, 63.48018800058673, 50.28345984797324, 51.5246585876711, 19.532116920717304, 43.41083972684799, 67.36404834255096, 60.56537666628438, 59.978692070130386, 58.788488065042806, 57.61763703438544, 59.388512642152854, 55.386322236830196, 61.48776123600622, 61.32185282245759, 68.67265301366007, 66.1069522365447, 63.173031114762836, 30.456561119325702, 2.1736981215015536, 0.35617060899253816, 0.49889723259595137, 0.3217644052159402, 13.322074355617648, 61.24628443871776, 57.17620565045265, 66.95757312159385, 68.70514592816754, 55.04724902491416, 47.733221054077156, 5.249358992422781, 44.09160629395516, 24.908395967175885, 55.5274098919284, 45.614905818816155, 30.0863697836476, 63.972214037372225, 64.28077905408799, 12.322515191570407, 0.8050640263865072, 0.31523540555950136, 0.07091724178603581, 0.063118543325653, 0.12483166004981726, 0.09369627632681402, 0.022594512688116204, 0.06292601010852283, 0.14528626125426064, 0.16461996091229303, 0.23050856325895558, 0.28250074434664946, 0.1334845082413766, 0.18746853325395815, 0.2202216265422683, 0.26285723873203803, 0.19698048010468486, 0.2685672291103871, 0.5221934147900151, 0.43870340612146164, 4.865498196694159, 80.81863311029251, 69.42995286756947, 64.07321506930937, 35.31998242101362, 55.41155092177853, 49.254782968951815, 27.41986213191863, 12.912878970946036, 53.67516079256612, 62.331314010004846, 77.6723038765692, 76.03951531071817, 70.94224622172695, 74.80742039219027, 10.499961376190186, 0.24726639952390428, 0.3854845344058929, 0.8674480369494808, 0.45241215116074013, 3.7655050283478158, 63.14561766962852, 66.29578298138034, 74.72300314134168, 68.28300476074219, 70.84223362707323, 58.69017385667371, 63.428404869571814, 61.80439064579626, 66.80976252402029, 64.5663550592238, 61.912244058424434, 65.30807133643859, 71.44881248474121, 65.35406897144934, 65.10444541131297, 56.11068987077283, 59.91264720116893, 50.92819552267752, 63.104252353791274, 65.45871388527655, 65.27751999516641, 68.73005297876173, 68.92137835102697, 62.73012099727508, 61.961662000225445, 64.89837584957, 61.80681859293292, 59.61146800748764, 61.51289186170025, 56.013375866797666, 54.77951980406239, 56.03893795321065, 53.18249933181271, 54.59347001967892, 49.72090567311933, 55.60446485396355, 54.092430376237445, 55.50156539486301, 57.988504978918264, 58.31145332705591, 58.61110279636999, 57.56614415876327, 61.16709178493869, 57.86831571209816, 57.19000454871886, 54.68071922179192, 54.46685983288673, 52.18957485691194, 50.62449816734561, 56.403333986959154, 59.904476904099994, 61.93069096534484, 54.58520950809602, 63.715455685892415, 57.7034741832364, 55.98325206387428, 60.501073329679436, 60.560371721944506, 60.69687412631128, 60.8901136152206, 56.88322028806133, 58.663905743629705, 53.01737539229855, 51.67943923704086, 55.962534104624105, 55.32153644869405, 53.681213009742, 57.46198169646725, 58.72839343163275, 59.2479976530998, 52.69193633910149, 57.19326796070222, 55.19336908094345, 55.27163213299167, 51.907701569218794, 57.31440251873386, 52.49832030265562, 51.902743693320986, 52.11489292883104, 51.4081092803709, 54.6205343738679, 52.77423158768685, 52.57099005483812, 55.41915247517248, 51.07649249415244, 58.59089082287204, 57.72059532903857, 59.65104080015614, 66.28280778085032, 69.26353454589844, 58.31453631001135, 62.84056317421698, 59.41415317596928, 66.4610481262207, 63.770329644603116, 65.32631428011003, 60.73743143389302, 66.21017332999938, 49.48065265532463, 55.06813564608174, 24.462740190567512, 42.25512904505576, 69.31691015920332, 61.83739346842613, 62.28314730428881, 61.37127860899895, 59.44235893987841, 61.72885756338797, 59.95765247652608, 62.57111203285956, 63.682900013462195, 70.51470002820416, 69.30888498983076, 63.276491472798014, 33.507882702735166, 3.893339239781903, 0.5285235686648277, 0.7070566821963556, 0.4396134572884729, 14.6276617434717, 63.032563194151855, 63.70126847297915, 72.79095342082363, 74.2584611523536, 59.78868069187288, 61.555002427870235, 4.778749096778132, 43.64489147740026, 27.211154776234782, 76.4643786030431, 52.12897031537948, 44.59153982900804, 76.76455759233045, 73.04385216005387, 26.3099725784794, 1.158072929228506, 0.4673953294273346, 0.3224218005855238, 0.28987525992335816, 0.3082011249517241, 0.28993722111467396, 0.19912449973485163, 0.3499080547161641], [0.0663736432550415, 0.07463419314233527, 0.06446567829698324, 0.04168160672810289, 0.08281224302106327, 0.11032842054602601, 0.033613999914978786, 0.09254132983304801, 0.05365736129122877, 0.02609320367956835, 0.05411577681379934, 0.021489009508983265, 0.1123567685605057, 38.94562136742377, 61.794565108514604, 45.689944682582734, 35.79349487058578, 41.036444710147, 46.82957364666847, 28.52659025499898, 1.709664079450792, 46.33108746620917, 56.30874603025375, 50.7477351157896, 67.35852564534834, 51.96069279024678, 69.79347813513972, 19.38749324890875, 0.18284165330471533, 0.2060224013703485, 0.36218050747148456, 0.5633896397006127, 0.3498728146716472, 36.48984109201739, 58.830669233875895, 73.06651561490952, 66.61652303511097, 62.53185695217502, 58.91649069324617, 63.59917309976394, 64.96434619349819, 64.26918060548844, 60.25165373279203, 59.513699008572495, 57.295041699563306, 65.07814199693742, 62.028161864126886, 63.9342886401761, 49.82088688881167, 51.47158499686949, 56.378976068189075, 58.44339401491227, 62.66018513710269, 60.670480497421764, 64.14084457582044, 61.98884402551959, 60.68525214349071, 61.97403315574893, 61.088189386552386, 61.76219770985266, 61.133724181882805, 61.13596777762137, 55.87721863100606, 49.83696076177782, 52.35753074769051, 50.350748108279326, 48.25850878992389, 45.29489532593758, 47.74669047324888, 48.9786716430418, 50.939754747575336, 50.61070711381974, 51.392572772118356, 52.46612156591108, 54.495810847128595, 51.78223279214675, 52.37452637764716, 52.132159202329575, 51.76140892890192, 50.04407759635679, 48.68883986626902, 46.677530811678984, 48.13289880752564, 49.12544673488986, 52.90196749471849, 50.132142651465635, 52.575614529271284, 46.444267457531346, 40.54961581383982, 46.62947000995759, 45.26751325976464, 48.380827903747566, 47.34709116720384, 45.9758815457744, 44.02452199689804, 43.74086795314666, 42.14605185293382, 45.239283961634484, 46.76325421179495, 45.79720189494472, 50.57955564991121, 50.027776225920654, 47.1593665307568, 50.33348183478079, 50.184502370895885, 50.69972922725063, 49.287656353365996, 46.75220881738971, 49.342302814606704, 48.36160044516287, 46.49338337682909, 43.11624619268602, 47.06927753263905, 46.36296064622941, 49.29998436281758, 46.442518080434496, 48.53591449799077, 48.13049439461001, 52.83152957116404, 53.707755688698064, 54.794522869971495, 55.194796823686175, 72.33906499801144, 73.5559646544918, 59.11378983528384, 59.39742034481418, 57.7159708546054, 61.352725798083895, 59.5683023237413, 59.55656266981556, 55.17800123460832, 57.40367566385577, 45.103715081368726, 42.027753168536776, 61.22016929811048, 58.05549513909125, 60.36231164009341, 59.058351055268325, 55.6436336425043, 55.79402908202141, 54.52443238227598, 56.864796915361964, 57.69114225141464, 63.0380819689843, 64.36837342477614, 65.21438160250264, 49.4231193296371, 12.22012662118481, 1.4305972476159374, 0.49576638446700194, 0.27583691321553727, 0.41913454811419215, 28.46250657112368, 65.05771821545017, 53.782206196938795, 69.23188101860785, 44.77465568050262, 61.24907716628044, 31.652025022814353, 4.41729974362158, 48.923644711894376, 14.193769155010102, 49.26004678972306, 35.7954756675228, 32.11642188410605, 48.01949524110364, 54.725830401143725, 3.7211361575511197, 0.4792935941969195, 0.04238181492133487, 0.16010523623516484, 0.07416081209216388, 0.08678895180984851, 0.040650122964213935, 0.09876646837520023, 0.06489867119178658, 0.03533299013431515, 0.04485988336044454, 0.06507718499990241, 0.008440894645548636, 0.06482755524977561, 0.04012895334932593, 0.047028486752101493, 0.1293026028020728, 0.0816217577084899, 0.04719612977257179, 0.08374578244383298, 0.16874758136128226, 0.07063433317647827, 39.8826716792199, 70.4961472172891, 46.07998909488801, 35.550100034283055, 61.404787417381044, 40.08558373297415, 37.01727828671856, 4.575137880540663, 43.68369156314481, 63.14233072342412, 59.33153629302979, 75.90828064949282, 57.23071090636715, 75.88709985056232, 23.297886463903613, 0.18241160218754124, 0.690211511908039, 0.6462304654621309, 0.5243947224751596, 0.48438320657418626, 41.21855251250729, 63.08142808175857, 74.80543567288306, 69.16959378027147, 63.704135725575114, 61.39320073589202, 66.80946442388719, 67.14231675670993, 65.83032315777194, 64.40759712649931, 61.40304588502454, 59.77967100758707, 67.47555348180956, 63.3730798382913, 64.6024134082179, 50.504465795332386, 51.215842539264315, 57.00003239416308, 60.96477593145063, 65.64293584515973, 62.32257104689076, 65.08849313182216, 61.99820280075074, 64.13894222628686, 61.1600628975899, 61.89410309637747, 61.75474128415508, 63.5159678612986, 61.38748584255096, 56.044150783169655, 52.388274285101126, 54.9048512981784, 52.10208639021843, 51.79728292649793, 48.71833608996484, 49.93536910703106, 50.85299976410405, 51.031342091098914, 53.74017407817226, 54.00035273644232, 57.28770686734108, 56.73826517597322, 53.79216901717648, 55.38509061259609, 56.630956972799, 54.31739399510046, 53.69068161133797, 48.82239264826621, 50.750959304071245, 52.172983231083045, 56.73724535972842, 55.16086047695529, 54.863427146788574, 54.313750113210375, 50.01054133138349, 45.455806639886674, 53.82357935751639, 53.57339489844538, 55.125782720504276, 53.37905322351764, 52.41779796538815, 49.284502767747455, 48.16195964813233, 49.53378508167882, 48.26909918938914, 50.398542188829, 49.90810471196329, 54.768580313651796, 52.07086824601697, 51.60093692041213, 54.24296702108076, 51.355757405681, 51.984858512878425, 49.30400086987404, 49.43023450912968, 52.10999388848582, 49.83584680864888, 47.25877508040398, 46.42331023370066, 48.62368929770685, 48.85585046583607, 50.26625241002729, 50.5518441046438, 51.64633443278652, 51.74360529068978, 56.44923748508577, 54.588500376670595, 58.94223320868708, 55.451719914713216, 70.68919843243015, 74.46040045830512, 61.03776339561709, 60.77469002815985, 59.98849015082083, 62.07741506638066, 60.41009003116239, 62.40004962490451, 56.71193038263629, 60.08531385852445, 48.077307055073405, 43.48297211431688, 63.381995385692974, 62.44973821024742, 63.5257149511768, 60.018986578910585, 56.265380305628625, 58.56352052380962, 58.93179578165854, 58.057373954403786, 57.76751472103981, 65.08693987323393, 66.29988578058058, 66.20755318672427, 51.06678462797596, 14.429668341913532, 1.79644676466142, 1.539971314130291, 0.5255355806119981, 0.717336172538419, 32.095674507079586, 67.83197925936791, 59.015440325583185, 74.75150308301373, 53.05799545780305, 64.01382254016015, 35.84965928908318, 7.7900301448760505, 51.728829722250666, 14.620157268739517, 53.206994533538825, 44.450918935960345, 30.77230799582697, 51.86484575271607, 67.35003763629545, 4.55416496722929, 0.39727248251438146, 0.09157143953827121, 0.0691193713235759, 0.09405539536307897, 0.11508191950739392, 0.06748964183873708, 0.04198344153982978, 0.054388473471326214, 0.12868057005107403, 0.21464852075422966, 0.18447049412756197, 0.11595333686038373, 0.17836356295212624, 0.13619912547930596, 0.10372357052420417, 0.1813699217933801, 0.12406119776348914, 0.12852937493833805, 0.15293301383574165, 0.20864991441128716, 0.2989229115266954, 58.01635380714171, 79.05813217163086, 66.60630133844191, 49.0091759158719, 58.449665884817804, 63.56495826475082, 38.539397178157685, 7.161625258384213, 54.9642163707364, 66.5171693986462, 62.60165160702121, 80.16095361401959, 63.22388856641708, 82.41099772914764, 24.263024868503695, 0.32553021766005025, 1.0842683863255287, 0.8264804739625224, 1.1504350939104635, 1.2000058855741256, 46.1032134486783, 67.25264518491684, 78.5541311387093, 72.58909256227555, 68.13205626703078, 63.99378315094979, 70.6052989344443, 70.8928478917768, 68.9700706543461, 67.11023961344074, 65.35116249515166, 62.105573761847715, 70.37458512090868, 67.23635950396138, 66.83368898207142, 51.18604429306523, 51.451212206194484, 56.37483404528711, 62.7020368268413, 67.4608838173651, 64.14044449406286, 67.42263286344468, 65.83115470024848, 67.32647988104051, 64.3015911502223, 65.1658461939904, 62.9592070271892, 65.64419100361486, 65.49021051776025, 58.708542316190666, 54.98981768085111, 56.16816828327795, 55.8764341569716, 55.283014851231734, 51.9841524862474, 52.41759007976901, 52.835389183413604, 56.117189238148356, 56.84350629006663, 54.723763312062914, 59.12283874327137, 60.56152489877517, 58.302635838908536, 59.71323782397855, 59.92081749823786, 58.2547240872537, 55.3859809906252, 52.721499243090236, 53.15095955325712, 56.45804320612262, 59.85434901329779, 60.924975641312145, 56.98046761174356, 63.16064426975866, 54.408667549010254, 49.51625600937874, 58.97569102625693, 59.28237330528998, 61.802939368832504, 60.219678571147305, 56.53376848466935, 54.97760734250469, 53.10589936471755, 51.897256297449914, 51.55504126702586, 54.721868807269686, 53.16724915658274, 59.37687496985159, 56.56157024445073, 53.97929745335733, 56.610458666278475, 55.45590116131691, 55.65982910894579, 50.28173400509743, 52.13875662895941, 57.20789055670462, 53.810231531819994, 50.20850727635045, 50.09456634521485, 49.4901212569206, 50.69029592698621, 52.192093018562566, 51.598187338921335, 52.95067940988849, 52.11666584014893, 60.199564656903675, 58.58133200676211, 60.521132330740656, 60.532260094919515, 65.84152544698408, 76.13820998899399, 65.64254753051266, 63.57433272946266, 61.51290755118094, 65.32787930580878, 63.86274460823306, 64.86793041229248, 59.26780562247, 61.45647248914165, 47.36158824736073, 41.16198016751198, 65.1866465230142, 64.25413439350744, 64.42085473768174, 65.09291756537654, 60.59160555562666, 60.351889902545565, 63.26183357546407, 61.931640178926536, 61.20129877521146, 66.19913578033447, 70.44522700771209, 68.24157668698219, 53.50758537169426, 21.567309287286577, 3.8884519665471973, 2.4775567843068034, 0.7390761543666163, 0.4965375592150996, 35.572312416568884, 73.13246634698683, 62.989315140631895, 79.19947870316045, 57.120347176828695, 72.22881501720798, 41.34810447692871, 7.211225590398235, 63.257522890644694, 18.43905237413222, 72.77321646290441, 47.80549856924242, 48.408857160998934, 58.66842431406821, 82.59426655307894, 9.23031662741015, 0.7308339676068676, 0.13930685307470062, 0.22908180110877563, 0.16145152850977837, 0.1658338425500739, 0.18342864519405752, 0.19341837043964094, 0.19222885039785217], [0.0829693140281785, 0.02484176841173922, 0.03185682212783685, 0.028447416768739783, 0.07336638657556427, 0.03188358157903197, 0.09428083205655699, 0.053799405483709234, 0.08231231702431556, 0.017927692744941, 0.1623277492340534, 0.27415881293915934, 0.5982592040973326, 15.083911841915501, 65.84218440517303, 46.30058319337907, 40.02564991674116, 33.309422539126494, 35.18315053755237, 34.27900106676164, 2.4816208501015944, 23.3379848541752, 82.47239066708474, 53.45895582629789, 60.015915363065666, 62.18894373986029, 56.500761739669315, 47.470041782625266, 0.1967184933563394, 0.337793845082483, 0.5300960713817228, 0.1611849758774042, 0.6690633789666238, 20.09799530429225, 65.57401195649179, 64.3057567073453, 71.24932073777723, 64.24587388192454, 61.01179338270619, 63.706520526639885, 68.52680360117267, 67.30034120621221, 67.69261744714552, 63.312698871858665, 63.21412970942836, 63.92415715802101, 62.53149609411917, 66.39333232756584, 50.912306001109464, 48.03301565108761, 52.82998807968632, 60.345720014264515, 62.99590864489156, 63.06342048029747, 62.390071115186146, 62.033582579705026, 63.445020029621745, 60.90288485250166, 61.910357398371545, 60.6821495486844, 61.596061798834036, 61.83060384565785, 56.65475007026427, 53.05598328190466, 51.69174763464159, 51.54452931496405, 47.67113777898973, 43.85361256137971, 45.04370281773229, 46.0332501319147, 47.0575104221221, 46.70334000741282, 50.07927694628316, 54.514045946059696, 55.05908281572404, 55.99852969569545, 53.60639379870508, 54.18505714785669, 50.73506586013302, 50.47940184993129, 49.34564075162334, 45.0563681510187, 49.41785158649568, 54.04926077012093, 49.387123738565755, 42.42790160640594, 44.232690026683194, 45.24595983566777, 44.839484614710656, 42.40478707898048, 45.897759699052386, 46.72376771127024, 46.22264962042532, 48.34625613304877, 45.81325615606001, 42.68558955961659, 42.96985549311484, 46.36238798018425, 46.40540853623421, 47.597569804037775, 48.77238635093936, 51.50463096557125, 50.21364165890602, 48.36436963850453, 49.820859432220466, 48.97611425768945, 46.933151675808816, 46.99760798485049, 45.59758463213521, 44.8713852513221, 45.45435144055275, 44.847101857585294, 47.39575993630194, 48.108827221778135, 48.54303752222369, 49.37669807864774, 49.75798776072841, 49.98142165522422, 52.01656695335142, 55.00182405594857, 52.629115658421675, 56.859772359171224, 54.746634652537686, 63.08406391451436, 58.74394955173616, 57.84196130691036, 56.47517219666512, 59.449532954923576, 58.7883900057885, 58.433121327430975, 58.446257345138065, 56.704195468656486, 52.79245491950743, 52.88152017901021, 59.12825945884951, 61.407297734291326, 60.05791218050065, 57.58451261828023, 56.17651508700464, 60.909090042114265, 57.061029172712765, 60.19205724039386, 59.45027428288614, 63.29684072925199, 59.66571438697077, 69.05317783355713, 42.281506984464585, 3.3379110309385487, 0.5688813869510928, 1.6352878510951998, 0.4361348971724511, 2.5916982466174714, 43.23130107695057, 52.214697637865626, 56.22031619471889, 60.58261156082154, 42.04695317053026, 67.77685426896619, 17.866507922449422, 14.199385008504315, 44.10470308796052, 21.113785236112534, 62.832196758639434, 25.401669317676177, 43.12347119854343, 52.45410734607328, 50.256850488724254, 1.2026657428472274, 0.12682902746863906, 0.0635639162013127, 0.05447260907761032, 0.09213629914748092, 0.09794947390835132, 0.0683167869705827, 0.039223793653711196, 0.08239224297745575, 0.07622477553424335, 0.09493943784506091, 0.03613651677545521, 0.03481729421764612, 0.05161544585961008, 0.0013042065162857574, 0.08943466709986811, 0.13046485011375722, 0.11169558105569695, 0.01896594489564098, 0.15076112392688953, 0.13281971246244448, 0.4404839476750743, 12.639674121333707, 76.00649679860761, 48.87487788354197, 31.76914111260445, 45.35449574070592, 38.304188328404585, 35.16013406938122, 6.51234551783531, 23.181980425311675, 89.77543600143926, 56.195224792726584, 70.26325256593766, 68.14220736103674, 62.652952286504934, 54.52595426190285, 0.27230996698621784, 0.21241584942946512, 1.3440850833731315, 0.3874805918143642, 1.179196608643378, 22.373607389388546, 69.46524635437997, 64.538839632465, 74.93598784169843, 67.5660268722042, 64.73975519980154, 65.644285140499, 71.7813902516519, 69.5676515948388, 69.77186587549025, 65.7158487842929, 65.35606545786705, 66.94854382545718, 63.25521653698337, 65.66932947404923, 53.02709894795572, 48.048869871324115, 53.39493882271552, 61.762684083754024, 66.69267977437666, 63.83851612767866, 62.79056864400064, 64.65539678450554, 65.34885614149033, 61.29574552659066, 63.218334490253085, 61.25408995536066, 62.252690099900775, 62.046420497279016, 58.760607857857984, 55.19162754858694, 55.41149600859612, 53.53221001163606, 47.94123218905541, 47.96286013818557, 47.24729822527978, 49.5166168674346, 49.322730187446844, 49.31963935975106, 52.42346186791697, 57.84328706802861, 57.81272003727575, 57.090949012387185, 56.3981564583317, 55.3682557998165, 53.884179976678666, 51.7347760354319, 51.78746915632679, 50.575335179605794, 54.01515183910247, 57.30940149676416, 56.28176404583839, 48.116299336956395, 48.08386525800152, 49.644239025731245, 47.65095718445317, 50.64689097865936, 53.96097606228244, 53.76383381505167, 55.590261951569595, 52.04111706825995, 50.46491653688493, 47.841478470833074, 46.59980904671454, 51.21057087375272, 51.17565393447877, 49.64503134450605, 52.32600665861561, 53.039536783772135, 54.66692032352571, 51.87612256696148, 52.67510152632191, 51.16356126723751, 48.30735014330957, 48.47763199960032, 49.02491246500323, 48.50460221690517, 45.7519220536755, 47.89411667854556, 47.90245955990207, 50.31301882959182, 49.873599621557425, 50.70405560155069, 53.33941375055621, 54.574772081067486, 53.718506905340384, 56.18283010298207, 53.983270814341886, 59.59374673904912, 54.79574272709509, 60.67878023270638, 59.93457325043217, 60.034797653075195, 57.53465537101992, 61.74842626817765, 61.422112526432166, 62.73875413402435, 59.656579186839444, 59.14455690691548, 53.91674349384924, 54.82893382349322, 61.455507586079264, 64.3818546110584, 64.2605710029602, 59.336203913534845, 59.644541432780606, 61.85356932301676, 61.03819877870622, 62.660797026849565, 62.726249617915, 64.80726311283728, 60.82867753121161, 70.812682490195, 43.27851464671474, 4.736766497935019, 0.5864081916309173, 2.4022102596298343, 0.5758085378235387, 3.335126638412476, 50.541245860438195, 57.386942832700676, 63.666586875915534, 65.92125154310658, 48.286718476203184, 68.48216702861171, 23.866773305400727, 14.353515525018016, 48.05201561220231, 18.77301669889881, 71.12531108240928, 31.97794456635752, 40.73866621140511, 61.72120501918178, 53.96528674710182, 0.7377301072401385, 0.12946504408553725, 0.022019343450665477, 0.09282143456080268, 0.05289650574747113, 0.040398083867565285, 0.005075817527775203, 0.026576821579627936, 0.03641354566019389, 0.19386506098653042, 0.3116047003817174, 0.12439200985095195, 0.13008629542685327, 0.1461294482672407, 0.13404905375453735, 0.2006592189953212, 0.1672473820226808, 0.28677392150125197, 0.22979764898698177, 0.20568504689201234, 0.3431126096796605, 0.704891901583441, 24.3920414293966, 91.42351396622198, 56.780968020039225, 60.91482454730619, 43.901779267095755, 55.41131165719802, 41.354584232453384, 8.398417215193472, 29.945311546325687, 94.34178090864613, 67.75244928175404, 73.43698347768476, 70.14294562801238, 69.5319894052321, 60.44750552023611, 0.4301922918567735, 2.5508354844585543, 1.5056325567345468, 0.6494745107427721, 1.187480286725106, 24.73022230209843, 73.78625485204881, 69.25959648624544, 78.08359576809791, 68.76626430019256, 66.43257956351003, 66.72589440499583, 74.2955118610013, 70.59998020049065, 73.24560319223713, 68.08824339220601, 68.83726704505183, 68.41023860439178, 65.72061838642244, 67.70926398615684, 54.86905182561567, 50.682227611541755, 52.71525090740573, 63.69515742025068, 68.89531027886176, 65.48895928167528, 65.59620472692674, 66.25159355901903, 68.14232503214191, 66.19854742480864, 66.03293711139311, 64.74150065452822, 64.8841651024357, 65.1355694186303, 59.03140829455469, 57.4389220822242, 57.01591014862061, 55.98083196147796, 49.39636484269173, 49.15333086444486, 50.837655451989946, 51.042003093227265, 52.178670667832904, 51.11961503182688, 55.20088826456378, 60.19752110204389, 60.92228097300376, 61.95169525761759, 58.91440006994433, 60.84094670511062, 57.5568599085654, 56.33260188564178, 56.19982965530888, 53.0770738663212, 60.69299097984069, 65.51903209378644, 60.08684750526183, 48.23140913440336, 51.514232927753085, 54.1671750622411, 51.61748540016913, 56.70583109701834, 61.65699581946097, 60.054142782765055, 58.438879366843935, 57.86678206536078, 55.80023034926384, 53.451189533356704, 49.393168111001295, 55.19296115444553, 54.63359586654171, 53.728203004406346, 56.86514992867747, 56.53908721862301, 57.45758864187426, 56.15660513600996, 55.39299811086347, 53.80171214380572, 51.427623071978175, 52.169755120431226, 51.90197098639704, 50.76645658862207, 48.46739461345058, 48.7274242216541, 50.750527843352295, 53.117646863383634, 53.710536649150235, 55.17564389013476, 54.96380452186831, 55.764658374171105, 56.431892764183786, 58.98714826953027, 56.42105917776785, 61.24653547040878, 58.265267418276885, 62.60751162805865, 61.34674026120094, 63.20340202700708, 61.53892071016374, 64.3448745050738, 64.63564372831776, 62.38421893888905, 62.1537483123041, 61.38284567863711, 53.20007547255486, 56.73002819861136, 63.61301906647221, 66.13297324026784, 65.93396786720523, 60.61959166680614, 61.48044601563485, 65.95612925867881, 64.42211774087721, 68.13501373414071, 66.41241073608398, 66.98623780281314, 65.38332200819447, 73.26575633018248, 50.690464588903616, 8.735268404406886, 0.8116138942780033, 4.668313293687759, 1.3107340278164035, 3.4375740443506553, 55.92101189397997, 63.04222399188627, 67.06050395965576, 72.89588466767343, 53.22783016389417, 78.45724075071274, 26.78138459882429, 19.180166567525557, 58.22324314425069, 28.889774276364236, 92.86243546393611, 35.32559925510038, 63.93607331860451, 60.0491770621269, 76.30885662571077, 2.4244383313963493, 0.18934299718708764, 0.12118469848628007, 0.13767752195558242, 0.14258497394621372, 0.14027054571817, 0.18910321166678784, 0.10653212546340882, 0.1583224423830548], [0.10143643800890255, 0.047003573572803894, 0.06960539282449792, 0.017568931854780645, 0.06738217502471901, 0.01335808169847775, 0.045127263367776914, 0.05611890138337209, 0.04104740083998731, 0.070399580853841, 0.0979014708390159, 0.2017015888686142, 0.27464003872967535, 1.5986823314620604, 47.95819251768051, 56.015839115265884, 42.64675809491066, 35.18315445992255, 38.73069509383171, 43.55922299046671, 8.160839744152563, 8.612265817580685, 71.34987461951472, 74.17489897820258, 46.37867758350988, 55.33103250688123, 54.96718952732702, 58.72828360526793, 4.308706964215925, 0.8821686922061829, 0.8382092187962226, 0.33312714388293607, 0.6197663564835826, 2.3157695560686054, 58.78851159926384, 59.16784401862853, 71.42754539366692, 63.06827637457079, 67.10216737562611, 65.15060386350079, 68.948011244497, 64.58100511181739, 66.86106712587419, 65.16686208786504, 64.97263808404246, 63.452594126424486, 67.91310171927175, 59.96259074057303, 55.43757977024202, 58.730852757730794, 57.6281842877788, 58.744541829632176, 65.37900740100493, 62.69476475254182, 63.26974499610163, 62.47593964299848, 64.43588918255222, 63.62587267352689, 61.34954083350397, 61.317922607544936, 57.53224311336395, 63.50250628686721, 55.115855201598144, 52.7866223550612, 52.54413358626827, 50.88112708060972, 47.74896544794883, 46.11270950686547, 46.47449716444939, 45.33748442126859, 46.72173592352098, 48.202552257045625, 48.32458111547655, 49.38726102152179, 51.883422097852154, 54.332577490037494, 55.81855174033873, 53.00790679070258, 54.14849281311036, 53.53403783613636, 48.28882871135589, 45.76313610999815, 50.263428303503225, 52.56833068786129, 51.43025890473397, 29.98918325670304, 37.68605809057913, 48.22165419978481, 39.1682590207746, 40.892960486873505, 43.674183737847116, 48.85939628847184, 48.03752637678578, 48.81783877649615, 47.620978509226155, 48.02217421993133, 43.90241469106367, 43.95348395070722, 46.18785819699688, 48.2953163116209, 48.224211585137155, 49.070694369654504, 51.15793266604024, 50.88041320923836, 48.36798998617357, 47.515113738275346, 45.836202021568056, 45.38629439569289, 44.33344787166965, 44.20036185172297, 43.78797561891618, 46.871801883943625, 46.687744663607695, 48.000985576260476, 46.22054723001296, 49.57118488127186, 51.285876458691014, 52.82261794613254, 54.13240717303369, 56.87859973599834, 54.549151159101925, 54.716114690226895, 59.402099732429754, 57.69832803357033, 52.227249222417036, 58.6261058622791, 55.848820670958496, 60.236062311357074, 59.50041394079886, 59.95651498917611, 55.80472538548132, 57.63452283797726, 49.94968575816001, 57.351986669724994, 61.556410558762096, 60.66241218197731, 57.86526018573392, 57.392438073312086, 58.70634971126434, 63.02975869947865, 59.536197723880896, 66.951658187374, 58.82644484120031, 66.18109287754183, 61.358126901811175, 63.93741869157361, 6.6511993831203835, 1.689563403206487, 0.2923655666170582, 1.028402558257503, 0.43283290500121735, 14.199306561100869, 63.10046334420482, 57.05356490227484, 58.814693420164055, 60.96094377579228, 51.468290205924745, 68.1745433807373, 9.701770813234392, 27.54006120466417, 41.34332703005883, 24.52476070773217, 53.36535238450574, 15.796870281619412, 45.283551831399244, 54.343414998823604, 26.588498123230476, 0.2606913243089953, 0.021713038515900413, 0.060287917393349835, 0.04843991182203736, 0.07303431810390565, 0.0827558359671985, 0.017899458574491645, 0.09047311460298878, 0.020216667701700525, 0.017811128636822104, 0.04037886655198471, 0.008491833746853856, 0.04533702590232415, 0.034844723995774984, 0.043202126548895915, 0.030809616324521845, 0.08031557013671245, 0.06695815301950901, 0.09669686652599804, 0.1018885141538997, 0.3036074472531196, 0.20037962754647579, 1.2993278979293763, 51.991279432850504, 64.29819045528289, 39.27648505856914, 35.01603011162051, 51.23128098826255, 34.905309446396366, 14.87812763260257, 8.72942211166505, 76.9659948348999, 76.26358462918189, 50.36894790587887, 62.21773785929527, 62.943921550627685, 66.43839251610541, 5.576398372650147, 0.5705570970331469, 1.7207827731486292, 0.32990994232316173, 1.5467051656976825, 2.870031350081967, 62.202970135596495, 63.12959478747461, 73.62159375221499, 64.07402307756486, 68.982269225582, 65.85427315004411, 72.6292968565418, 67.34548768689557, 69.64114112238731, 68.48754067574778, 66.03095239208591, 63.66488456726075, 69.97723333297238, 61.52131711283038, 55.84587497095908, 57.39062986066265, 57.599868697504846, 59.28237330528998, 66.74598478501844, 65.27734348850866, 63.871648388524214, 62.22379399884132, 65.77992070105769, 64.84363917381533, 63.11707850425475, 64.13922071456909, 60.235489645311915, 65.2478825661444, 58.3230713875063, 54.79165561737553, 53.830231697328635, 52.41714292956937, 49.626039228131695, 46.90008609525619, 44.89978321136967, 48.5633828563075, 48.568917320620635, 48.70320750821022, 50.133091865047334, 53.6214086317247, 54.4943791820157, 54.8600656755509, 56.93606245902277, 57.432246208190925, 57.56097447487616, 55.4872291318832, 52.511291580815474, 50.66964072565879, 54.508644842332416, 58.08761542843234, 56.154306627088985, 34.17506217956543, 41.10376434941446, 51.627569813882154, 43.734388197621996, 44.90364282361923, 51.78327222024241, 55.398179561861106, 54.406439642752375, 53.28132737067438, 54.09702347170923, 51.44426961098948, 48.935753068616314, 49.65314672839258, 50.523881527685354, 50.31596452959123, 52.81704425811768, 53.08283190573416, 54.20198217515023, 54.43062889960505, 49.75223364368562, 50.210946990597634, 47.58711276515838, 47.79710861944383, 46.093533039093025, 45.45831303442679, 44.16371906957319, 48.43611763369653, 49.19892057295769, 50.96235152213804, 48.41253634422056, 51.46789404653734, 52.44356401505009, 53.56157679711619, 54.69080755787512, 60.060151853869044, 56.745505871311316, 58.0512942806367, 62.29743257645638, 60.4863565967929, 55.39387672178207, 60.632041269733065, 56.5886777447116, 62.05576750539965, 62.89282091202275, 63.0358854416878, 58.394662487891416, 60.651598207412235, 49.58952980656778, 58.416486555530184, 61.90744307733352, 63.17409015470936, 59.19208426629344, 59.25860766441592, 60.89975872347432, 67.17764946722215, 62.4955750280811, 68.65644578010806, 60.3260846291819, 69.41438890272572, 62.13546614493094, 67.23050732766428, 7.301847050266882, 2.4524668532033123, 0.5647001403474039, 1.2943886532898874, 0.29763885623505043, 18.781234064409812, 69.13173506336828, 60.80120525052471, 65.25140485455914, 65.95928284429735, 58.39912614514751, 72.43280180038946, 12.88260905973373, 29.35091949278309, 47.44788823589202, 23.49225167305239, 63.24253551421627, 19.951210406518754, 44.691548501291585, 61.098583667509025, 20.39074532447323, 0.48022981492742417, 0.13520564733734056, 0.09514176932674262, 0.1121887501569525, 0.05665302554505968, 0.06397289990056908, 0.049675569509065924, 0.02804354479115817, 0.031145475016185836, 0.12945559056055161, 0.23041134670136437, 0.13381112216701432, 0.13581681696157302, 0.13740323183517303, 0.24598574566264308, 0.20676806539056763, 0.2441052449566703, 0.2573628561390985, 0.18543524397236688, 0.33392620423147756, 0.5600338068700607, 0.5151241392858568, 4.53251838684082, 76.4396833604382, 71.58204755475445, 64.35524917417958, 43.696666763674834, 58.84515454692226, 56.07776549554641, 13.991349358712474, 14.892502138691565, 85.5356284110777, 80.37750767123315, 60.783919365175315, 64.5028361966533, 67.84591936296033, 72.82405038033762, 5.656484836532224, 1.6168038042322284, 2.7854488693898727, 0.9314598924209996, 1.9821456194885316, 4.311035871505737, 65.65521678616925, 70.30177808577015, 75.28482775534354, 69.9590649143342, 71.09223765711631, 69.63853666859289, 75.22998517559421, 70.02364281685122, 72.83074978859194, 70.7197380065918, 69.01185958616196, 66.51663595630278, 72.3981123585855, 62.136631088872115, 58.6769986152649, 60.61171162512995, 57.40202042364306, 61.182577302378995, 69.93348321607037, 66.68827103030297, 67.76846824153778, 65.18638372421265, 70.28085616327101, 68.24305934290733, 65.54659066661712, 65.8074322054463, 60.907148468878965, 69.37101533336025, 58.510937229279556, 56.819156216036895, 56.073474422577895, 55.873480612231845, 51.07097764169016, 48.07675007850894, 49.069282316392474, 51.57956784771335, 48.311821645306004, 52.830517599659586, 52.53728905031758, 56.41007654128536, 55.74031614488172, 59.53366387274958, 61.63272419283467, 59.72575802956859, 60.60645957146922, 59.753881423704094, 56.65469515708185, 54.02364377052554, 58.13591157236407, 60.58382357320478, 60.75904369354249, 32.14905796512481, 43.18125947829216, 57.24900484085084, 45.35042824283723, 48.242038757570334, 57.31237857572494, 62.15893760804207, 58.19872833067372, 58.55436571182744, 56.8162654292199, 57.799689923563314, 53.07895660400391, 52.919449498576505, 54.09458375746205, 56.098899226034845, 56.189607958639826, 57.85430108347247, 57.909076982928866, 58.06051969528199, 50.827045440673835, 53.843422628218136, 49.22740482514905, 50.29128105409684, 49.29260246215328, 49.25431228453114, 45.818806309853834, 51.88818385524135, 51.54982843706685, 52.67934553084835, 50.8742315538468, 54.20878356502902, 54.33324429296679, 57.034733603077555, 57.76013674274568, 62.347431029042895, 58.004798504614065, 62.20809275104154, 64.12939909965762, 64.46005098281368, 56.6915693590718, 62.97613205448274, 58.54834095124276, 64.02541706638952, 65.44879421111077, 63.79221254779447, 60.30693169563048, 61.308081380782596, 51.86808955284857, 60.525305732604004, 63.68322949255667, 64.21028229498094, 61.58172161348405, 62.36994151146182, 63.25640501514558, 69.40713251790693, 65.87208071062642, 72.66899124268564, 63.559792503233886, 73.49833719192013, 66.78112922176238, 73.39991707955637, 15.102127328995737, 4.265795253938244, 0.643887033145274, 3.767803046972521, 1.6660800504107631, 18.132791749892696, 75.10428105631183, 69.14584775124827, 69.37031715146958, 72.10594284919001, 64.17375326156616, 82.18406508045813, 15.559522759529854, 36.44466715474283, 51.219180476280954, 38.06628088797293, 77.76392259905415, 25.618956858111968, 62.36469730254143, 65.90473836468112, 45.4488601223115, 0.6281233338579055, 0.36283198864229266, 0.36832796469811474, 0.20191641524434092, 0.23977741508954958, 0.1785423678736533, 0.1873062298663201, 0.29800084810103145, 0.15427653287206927], [0.041659547226323236, 0.059433059030843366, 0.05023240817770843, 0.06551447564796095, 0.12808257713913918, 0.07407995151175607, 0.021782764008328803, 0.03495057436427282, 0.09652465762149903, 0.04140157094826141, 0.0829218318986316, 0.18202891062584617, 0.015392012578705627, 0.1260921351551529, 24.243018819439797, 54.010958825388265, 47.06772427405081, 37.665708834125155, 41.61700648646201, 53.093183040618904, 25.356642469283074, 2.3458509483645043, 51.91136506295974, 75.00543732796946, 65.13726388254474, 43.36088442033337, 44.40094401759487, 63.2712511862478, 27.119641957744477, 0.8631073827705077, 0.5079657217908291, 0.1423124458280302, 0.6158955287068122, 0.6006166098579284, 22.189838463260283, 65.58303733025828, 59.27783904537078, 75.39942372229793, 63.41241336637928, 67.24669102699526, 66.04752048369377, 68.72637379554011, 68.0717380585209, 68.4183265316871, 66.9817663008167, 64.53550169544836, 65.9123085391137, 58.698791303942286, 57.44397409500615, 64.8132682615711, 59.19720688173848, 64.97436784928846, 61.40809789780648, 65.51252095930039, 63.04489120360344, 62.4559747788214, 57.74579263502552, 55.93696025110061, 61.62595418191726, 59.60449403332126, 59.66590266073904, 60.81862057408979, 56.153651591270204, 52.703264144159135, 52.98458437765799, 54.14399385452271, 47.543786264234974, 46.41897209229008, 45.64306843665339, 45.080274997218964, 44.166096025897616, 46.68877232459284, 46.503048096933675, 49.34514261061146, 50.3945178370322, 52.09368075093916, 54.88311352268342, 55.33010682752056, 53.56285548979237, 51.372839327781435, 45.98807619464013, 43.752058475248276, 54.44123498855099, 49.06336738217262, 51.81682025232623, 20.92505451171629, 22.712109896444506, 45.27211419997677, 39.75590851999099, 42.65688957706575, 38.96518222747311, 44.75807974415441, 47.046104169661, 51.44607782363892, 47.65136903332126, 49.82178511158113, 46.34202695661976, 42.53551183208343, 45.357021747096894, 49.158567228624904, 48.529964262439364, 51.5126012217614, 53.4002967803709, 51.884791005042295, 49.36030257132746, 45.36601181953184, 44.86965156370594, 45.75516193143783, 42.308802758493734, 42.244993640530495, 42.34935614370531, 45.14166793515606, 43.10537338256837, 46.64108414803782, 49.351128147494414, 49.44641036372031, 53.322061184913885, 54.91726167740361, 53.93289189184866, 55.73787250826436, 56.21047496795655, 62.02720480580484, 59.49418913933539, 58.336517272457, 55.80807508960847, 58.71233132577712, 59.30244407346172, 56.96829649709887, 56.63056865815194, 59.731739644081365, 59.3284886114059, 53.2335489796054, 51.609758330929665, 56.591541074937396, 59.177924509971376, 61.19454053140456, 57.459918529756614, 58.083493017381244, 62.62000045468731, 60.24354619364585, 61.31140755068872, 60.108553901795425, 67.49564386183216, 62.30042926726803, 61.42626631644465, 20.02969115011154, 0.911595109970339, 0.26765080409184583, 0.17938837409019473, 0.10399039894823106, 0.10067619533548433, 36.203464923366425, 59.00106876127182, 53.00078768883982, 56.935999701100016, 53.8708007720209, 68.1291223341419, 41.63549653945431, 4.2511133320869945, 45.43828541232694, 20.43112220302705, 39.2480557195602, 37.97264998958957, 33.00460338592529, 51.22651530850319, 50.54809431875906, 5.8334886547057865, 0.8410391475885146, 0.08361998314578688, 0.24058113325267072, 0.026408353099419225, 0.22038656527236586, 0.033799056113967975, 0.10277008983276545, 0.050694661800779646, 0.04820077364603358, 0.00904555635286435, 0.05665459219486483, 0.046558055140438585, 0.10257192586939182, 0.05207912057578083, 0.05570047565044896, 0.057500165571729024, 0.09360148826794279, 0.061109519879063295, 0.08995007573356552, 0.062267434963535886, 0.16602743296853958, 0.013475413809740737, 0.17172452242624375, 24.56627115126579, 61.4167231898154, 47.2728406998419, 30.8739189563259, 57.21242089425364, 42.70391879543182, 34.48143851372504, 4.649303526647629, 55.15704401077763, 85.84987301980296, 65.80554162302326, 47.70950640401533, 49.282165035124756, 73.1771735222109, 31.275516709973736, 0.03519616300059903, 0.6713347377315645, 0.3591646338182111, 2.2811416464467205, 1.1887137495702313, 25.45259737199353, 69.6786311364943, 62.82521101736254, 78.03349925625709, 66.15988069964995, 70.12960172468617, 69.21954908678609, 69.82948549332158, 68.02470099541449, 67.46119760697889, 68.06820792536583, 69.39289431418143, 66.63888054509317, 60.42130016511487, 59.54479948166878, 63.95517918371386, 63.40889500033472, 67.01257259615006, 64.23907641441592, 66.22669435316517, 65.55545914557673, 62.9620546679343, 59.126721889741965, 61.509004792859486, 64.81441751603158, 60.652386603816865, 62.858598232269294, 63.262284648033884, 59.61101301254765, 55.91834468226279, 53.320688355353575, 54.137929870236306, 49.63157369244484, 46.32485089763519, 45.82344647376768, 47.24343861303022, 47.20186148920367, 48.73361764415618, 48.606411257097804, 51.04938891626174, 51.3695994500191, 54.54231839026175, 56.272773973403446, 57.73651230719782, 56.599585856160815, 55.24358718625961, 51.442990918313306, 50.071224320319395, 59.457966050794056, 53.95024445749099, 56.55543173513105, 25.117097439304477, 30.080768639041533, 52.29381576661141, 42.15432805399741, 45.827411990011896, 45.45973685479934, 52.89519356143091, 55.719143190691554, 55.27377374710576, 53.939128460422644, 53.411091143085116, 48.82290647875879, 47.72139903037779, 46.872468686872914, 54.749133202337454, 50.826119761313166, 53.97163314204062, 56.84620880311536, 55.050586961930804, 52.25439594637964, 49.633899657957016, 46.384506225585945, 47.24146566083355, 46.498733489744126, 44.767869980104514, 42.41434981746059, 46.296970690450365, 46.31334266354961, 49.33957284496677, 51.31313300901844, 51.66726027765582, 55.18036250145205, 56.41371650080527, 56.761873922040394, 58.24081144025249, 57.12780752489644, 62.331851374718454, 61.80580662142847, 61.20849240210749, 58.34802550654258, 61.601764925064586, 60.4111373039984, 63.19557297614313, 60.12585547662551, 60.38681860893004, 62.25656540163102, 53.6983851463564, 51.001532077789314, 57.9213696910489, 62.12983362136349, 61.73163460146997, 60.48637228627359, 59.40473948755572, 64.08442912563201, 62.18652363746398, 62.042890364123934, 61.762484042875236, 68.8104772567749, 59.76075341624599, 63.01089602131998, 19.99177948121102, 1.765495341631674, 0.45689113017532135, 0.6989772125117241, 0.6451082998706449, 0.5020163749014178, 45.41681043563351, 65.47475637928133, 59.672743274319565, 62.331902365530695, 60.02043393350417, 73.83519818705898, 41.71215926447223, 7.90690157682665, 52.69045368317635, 21.313135777750325, 40.28529121029762, 47.37932520527994, 27.48585993243802, 54.55618789119106, 59.168601036071784, 4.961450157626983, 0.4049014005689852, 0.10475405071291233, 0.14393220084809488, 0.11103898241755464, 0.05992610172759141, 0.026277677651735085, 0.07327621036599721, 0.01218459013128473, 0.01862892366555189, 0.12740732426004064, 0.1717251199748247, 0.13639335941162803, 0.28407502438752885, 0.2432990446686745, 0.16745031871382268, 0.204680843519107, 0.32599063650254284, 0.24068795655283237, 0.19229041322344737, 0.1982056998437451, 0.34495293673488403, 0.2344368935953225, 0.26642301029736, 48.18408966064454, 68.3220951018795, 64.8522723105646, 53.97464944470314, 58.16928702016031, 71.94783210754395, 35.63643532414591, 6.446801241367094, 68.17124858979257, 83.25029080913913, 73.0748624186362, 57.03643591173234, 55.83776743181291, 81.20974832965483, 33.58764410018921, 1.7351886581990028, 2.550211827601156, 0.3086769881267702, 4.265860463342359, 1.0322407200451822, 26.69107202560671, 72.16096585796726, 69.77312887868574, 82.73948054159843, 71.14597412847704, 72.41505699772989, 69.46050028647147, 72.13416822495, 73.02849215845909, 71.21803591328283, 68.70018805226972, 69.89736603152367, 69.01614281439012, 61.04250946352559, 58.45525133994318, 65.38127845333469, 63.74361830372965, 70.48984004605201, 65.91980811088317, 70.93353855994441, 68.0126985426872, 65.43881962376257, 62.39673914447908, 63.996603335103686, 68.9516668934976, 62.53342197787378, 64.31241296952771, 66.89753732373639, 61.073825666981364, 55.78237179786929, 56.72340723776049, 59.27063757373441, 51.987808135248, 48.74216448876166, 49.05579328536988, 49.24562815696963, 48.74934634854717, 52.07643016692131, 51.90028044485277, 54.62339378172352, 53.747030381233465, 56.45315201051774, 59.61422543371878, 59.91516928518973, 61.87930007134715, 58.98609707432409, 55.34914993470716, 51.68928438617338, 65.31234671992641, 55.08642565819525, 61.433773732954464, 21.635268272892123, 30.058983795104492, 55.65413382745559, 45.25196498440158, 52.65268125841695, 49.514341892734656, 59.348022014864036, 59.63740664143717, 61.33754622551703, 60.832015468228256, 58.85686282188662, 55.680668661671305, 51.71504259109498, 50.4785506956039, 57.775226100798584, 52.36329270947365, 56.963311164609856, 59.42684988821707, 56.7122833959518, 54.18732820018646, 50.56954968360163, 47.01960463677683, 49.812128236216886, 48.67304840395528, 47.659162782853656, 42.803170450272106, 49.30469120702436, 46.04704510781073, 50.10145402723744, 52.98669069044052, 54.04271825667351, 55.1887995196927, 59.37381159874701, 58.300941374994096, 60.88973706768405, 59.2781763692056, 63.88601210809524, 63.24931336987404, 63.88469026934717, 59.019217568059126, 65.35943477384507, 62.55514014151789, 62.26910521907192, 61.19583099119125, 60.565415889986106, 63.99093551020469, 54.252902384727236, 51.8861363780114, 61.20973187108194, 61.72818291571833, 64.14031897821735, 60.68638963084067, 61.759330457256695, 65.75890856404459, 64.94529524157124, 64.01235557371571, 69.02621546099263, 72.98915078563076, 65.25770418105587, 67.58135549483761, 32.67099991921456, 2.866180072869024, 1.0673513263463974, 1.1664289260102858, 4.057365651092222, 1.1521852064517237, 45.84956553674514, 68.81065768580284, 67.14005747149068, 67.11259303554412, 65.61637747672297, 78.68809576957457, 55.77860240013369, 7.1799951887899836, 61.08789913115963, 23.67181189598576, 61.496151185804806, 53.52969969472578, 47.209969028349846, 63.475006549589104, 72.2754127748551, 13.583420899606521, 1.4271929980285707, 0.4197364787180578, 0.40445247304535686, 0.2817664950365021, 0.5063051189626417, 0.17953791445301426, 0.15948300430130574, 0.14995524539582192, 0.12801003627358906], [0.10044181073505072, 0.09011840823316768, 0.13804853833731145, 0.11642294109708841, 0.10504208445068329, 0.07601136642117655, 0.03249261573317551, 0.08744049426769057, 0.10010234951492279, 0.051779262270898595, 0.06364362381939447, 0.15263627733915083, 0.12329814354738883, 0.3466795150551104, 8.275684291316617, 56.89622294518256, 50.25201420630179, 39.91047343900127, 31.662060406900224, 39.5368912143092, 46.2087252063136, 2.1280000575127143, 12.626387092374987, 67.76521267429476, 69.8889329356532, 64.34474898922828, 55.88906811129663, 55.09281912157613, 52.30482978205527, 2.269362278522984, 0.3596512222241971, 0.8590474844940248, 1.5078705140659887, 3.9360369357370564, 0.17688510518881584, 52.05270374974897, 59.701894329440215, 65.53824778526061, 73.62932082145446, 67.22883639797088, 63.59748648058984, 63.10424058668075, 65.57055634836998, 66.27750473637735, 66.26928344849618, 68.42241364140665, 63.601389238911295, 67.10768222808838, 65.62503414769327, 62.64850039635936, 61.80654794939103, 63.4411447278915, 60.725119113922126, 60.58944040729154, 58.4476968549913, 56.75144826212237, 58.964896663542724, 41.87974253008443, 44.15396805732481, 59.35514503909696, 61.268845911948915, 59.81903591463643, 56.28443125755557, 51.65205324849775, 51.820609261912686, 53.381230138963275, 47.52566099166871, 46.02858251140964, 45.31224004683956, 44.5743167015814, 44.16089888541929, 44.86719615997807, 47.450614283161784, 49.31478346547773, 50.79678435479441, 51.40688550087714, 54.335805600689305, 53.17963600158692, 55.05364248829504, 48.50463751823672, 45.52879018168296, 42.41677776459725, 53.82308906124484, 49.6091651916504, 54.45474755379462, 20.21186367157967, 12.7653556869876, 41.586549282073975, 37.31630802154541, 45.134701805730025, 34.83521276904691, 35.90136005032447, 45.62338206075853, 47.17503247722503, 49.291582645908484, 48.60252811062721, 48.45037937164307, 42.30155029604512, 45.869271524490856, 48.8092174068574, 47.92338540477138, 50.40369618323542, 51.70791172212171, 54.39127183729603, 50.38883040028234, 45.17429421024938, 42.27821219351984, 42.7854609489441, 40.99667972134006, 42.737172649752715, 42.79081498422931, 44.328317411484264, 45.62876747500512, 46.09081483656361, 49.35381497106245, 53.43492346425211, 56.07854996958087, 56.07429812031408, 56.13625587955598, 58.789378443071925, 57.72357240799935, 51.77468222956504, 53.57993348952263, 46.83441385146111, 50.375086415198545, 56.44425215259675, 55.880984106371486, 58.750174353199625, 56.54335083500032, 54.918709031997196, 51.096755458462624, 50.07903768170265, 51.87391035018429, 56.74722386944679, 59.93446734643752, 56.60786990196475, 60.50445833513814, 60.8152198791504, 58.50321408241027, 64.49062193593672, 65.37530076119208, 66.83257502894249, 63.425015941742934, 59.24810747946463, 23.36701039345034, 1.1383880242224664, 0.29892410662385727, 0.36755145797806404, 0.5431261850941567, 1.8672119609771238, 7.286545393928406, 52.11950563615369, 53.2410014829328, 56.97802789749638, 60.235132709626235, 62.67441157371768, 45.8842275219579, 3.588780188752759, 14.677653331910411, 55.1259631495322, 18.50010798823449, 44.79134144321565, 26.872185507128318, 28.270847797393802, 50.826013857318515, 40.13759043908889, 0.810585742996585, 0.06675870968930184, 0.07257649629947639, 0.07047871007553994, 0.09064764475389835, 0.08343695707979702, 0.05372644326980076, 0.07251274246241778, 0.03243798217285545, 0.08022421415174201, 0.008241782648368709, 0.17208907302589188, 0.021118441288689935, 0.0694056353982418, 0.04846462198803502, 0.07845958424431664, 0.06859807913462002, 0.13645135226749605, 0.056000245855219906, 0.009068643370072448, 0.0339333972923698, 0.16332565536422117, 0.02549276503193523, 0.5263671230885291, 9.2773840888854, 66.48589241889216, 53.16955551024407, 36.5570548272902, 47.62341822347334, 41.42800707970896, 44.99766203664964, 6.4233969488451566, 9.559250512430745, 75.88378152539654, 73.64896405127742, 67.18085796602311, 61.09138219587265, 61.52941680723622, 60.04939279248638, 2.863618519998366, 0.4781740026608591, 1.6833587038901545, 1.5369730298557591, 5.787234594745021, 1.2101572247282153, 56.835237933743386, 62.75632635239632, 67.32902157691218, 72.84722374331567, 69.32828503270304, 64.41642245938702, 62.19259938886089, 66.80420060311594, 69.22846855655794, 67.83290493872859, 70.92512115355461, 66.1374290527836, 68.04433638049711, 64.1827041102994, 64.94911955248925, 64.58255837040564, 64.59938141607469, 62.57221029650781, 62.87177739604827, 59.88721063060146, 55.397575516854566, 58.68187019901892, 47.72654910241404, 50.14441182536464, 63.830177168692316, 63.26125698704874, 65.01542722025226, 56.67480514895532, 56.04328393936158, 52.7471633111277, 54.82417991084438, 48.31280616021926, 48.96565721881006, 47.13515766205327, 46.50887281663957, 44.95175461615286, 46.800351988884714, 50.87107012348791, 50.22029792108844, 53.39989277624315, 54.4381441608552, 56.51760047481906, 57.63138101946924, 58.10303426557972, 52.26790851162326, 51.000661311611054, 45.464059306729226, 57.89359538785873, 56.80526318088655, 58.44601415818738, 27.048856904429776, 18.623015457584014, 48.01935011340726, 40.11473086572463, 48.068340516859486, 44.073728130709746, 46.989986819605676, 52.615387362818566, 54.9212585726092, 54.67467484935638, 54.06677023057015, 53.52759338194325, 46.944612841452326, 48.481436698667466, 53.53882312774659, 53.45355472257061, 53.592300722675944, 55.55702770909956, 56.35727359402565, 52.86149647928054, 46.93081786555629, 45.97934107626639, 43.670834033719956, 43.638705899638516, 44.864532870631066, 43.905454527947214, 46.01379517586001, 47.72344650760774, 48.95780855609525, 51.846622420895486, 55.77568023435531, 56.06527274654758, 56.84709133640413, 57.30380427452826, 60.933800974199855, 61.72273866591915, 54.7671486485389, 55.946879925266394, 47.858984008912124, 51.741938283366544, 60.230716120812204, 57.47234459846251, 60.26928086434642, 60.56453335669733, 57.1569585800171, 53.18322104792441, 52.48512937176613, 52.212610936933956, 58.60765111061835, 62.435394102527255, 60.5483300455155, 61.28713200169226, 61.66507982438611, 61.00265033783452, 65.23332272806476, 66.48875574911794, 67.51448692813997, 64.06558213695403, 61.311737029783195, 25.081535270137174, 1.7658810822233078, 0.9267621799822777, 0.7023900422838427, 0.6778803155306847, 0.7542384439899076, 12.284638824001437, 61.43817855465797, 58.43059532104, 66.00412338010727, 63.50464005624095, 75.60234362079252, 44.80922352883124, 6.4171770503444066, 21.958665732414495, 60.76375838248961, 17.876194215589955, 52.31306675941714, 32.60956579639066, 27.09175978937457, 60.85512999565371, 38.820850772242395, 0.7743567096129541, 0.17162442537805728, 0.10293365726547857, 0.15475673210476676, 0.002247468313022006, 0.08334454389349108, 0.07295443811604092, 0.021731732976472667, 0.07323081199560436, 0.059372066940751776, 0.17555198962649993, 0.36595339856801495, 0.2831225625930294, 0.20054090437629532, 0.2536949497317114, 0.4501287801371467, 0.15031412694483035, 0.20651709498657336, 0.26131482794880867, 0.1270030520015186, 0.23127941625012507, 0.38332545348713476, 0.319099644980123, 0.6357784521195197, 21.298132711841216, 81.02740518508419, 66.27168393904164, 58.29132764570175, 46.474881556726274, 59.70472628070463, 58.544744137794744, 6.263237259080333, 20.675538816759666, 86.36553918161701, 77.0122709581929, 76.01495342869913, 65.04651200386786, 68.84927734251946, 63.77801749014086, 2.991564273834229, 2.452433022760576, 3.437383319101026, 2.1156333146556734, 7.223443283188728, 1.9803774885592924, 56.899670708564024, 68.05192224441036, 75.86413045083323, 77.644164792953, 71.61759207325598, 66.40851974487305, 66.39955320665914, 70.99404504222255, 73.06074188601586, 68.85184257261216, 72.49000564698251, 64.23089435023647, 69.01884924980902, 65.69149086552282, 70.46666668307397, 67.61620183144846, 67.08934906990298, 65.2597281240648, 64.24796842759656, 61.20768047148182, 59.531812514028246, 59.807790479352406, 48.407841267124304, 53.679036094296364, 66.04610058569139, 64.98017295714348, 68.66927193057153, 60.038170891423384, 56.69604478343841, 53.21893030597318, 57.806354030486084, 49.29566975562803, 49.08314005021126, 46.165685038412775, 47.51814180804838, 45.30577598079559, 49.085646444751376, 53.66451155754828, 54.72867019714848, 57.40972788103166, 56.488249378819624, 55.97124568877682, 58.38228348762759, 63.26800738611529, 53.30992537160074, 55.38881686425979, 46.98422093545237, 62.87333065463651, 56.37239040866975, 66.52601826575496, 20.671720389396917, 19.080406965747958, 55.22437149478544, 41.4727456338944, 54.017124791299146, 45.0341243897715, 47.22621940797376, 56.50575883926884, 57.58635220989105, 59.105113552462676, 57.627803817872085, 56.875940369021514, 49.9034841599003, 51.34699875308622, 56.026496195024066, 53.646888348364065, 57.914874246043546, 59.76583288561914, 57.75990140053534, 54.36763563463765, 49.627196327332534, 45.66464931734147, 44.990240912283625, 44.924298024946644, 47.94902986095798, 45.25667575097854, 47.43190457743984, 48.29098209258049, 47.98664146854032, 54.0423220972861, 56.552607628606985, 58.41796136671498, 61.300009142967966, 61.171582898786, 64.52391501395934, 61.5185518418589, 56.630407840974875, 58.4450335656443, 50.422386277106504, 52.69934569635699, 62.24628094703921, 58.131926444269, 63.35491141965313, 62.15175574825656, 58.97303558165028, 53.81522078667918, 52.556857755107266, 53.42789457690332, 57.75024060280093, 63.198761863093225, 58.65664543644075, 64.26243805116223, 63.70104097550916, 61.93533897399903, 71.68529218243015, 69.69992176178964, 70.03504906931232, 70.822629620952, 69.35198399328416, 34.03679470862112, 3.920557547000147, 1.1573675154678285, 2.485308123211707, 3.1193335210123374, 3.441918069316495, 10.742588408531683, 62.54635010996173, 61.897001727934814, 69.52046548166584, 71.2004009369881, 75.22139518491684, 54.31796273877544, 9.459806661452017, 20.25438608661775, 71.7072888343565, 23.56630406072063, 69.64644416686028, 35.861430321970296, 46.213090804315385, 62.846709528277, 63.100365284950506, 2.0459809683022963, 0.2980486213439896, 0.18929312486321698, 0.30585726362562954, 0.22684606543231398, 0.33643376322523244, 0.10536065445311608, 0.16130922001696404, 0.23716827283703515, 0.20517602743160343], [0.0647129561571825, 0.05531164389404078, 0.05140644175210788, 0.09558361819795064, 0.06959442244542223, 0.11563062232228057, 0.12958708189187512, 0.16042878580910547, 0.08690765713371577, 0.1187242768825062, 0.018959758735652414, 0.0599426185832389, 0.03452781257369826, 0.16266703425395876, 3.3703304010052837, 50.32887697219849, 55.85916396110289, 42.271042100844845, 26.75373188910946, 37.29421331036476, 59.763098993609034, 31.71741681714212, 1.4466475863610546, 29.17243007690676, 69.58851075941517, 70.16668381229525, 62.37063577098232, 59.03297724262361, 45.40973055747248, 21.815981672656154, 0.4475404448326557, 0.7149351916966901, 1.051299394138398, 9.916894185927607, 11.123933003794763, 6.022406181981487, 57.579990125471554, 62.22017757354244, 67.9649946766515, 64.55337201395344, 58.41104230573101, 58.9929533773853, 63.44751857942151, 66.2754572591474, 66.60663081753638, 67.24029756361439, 66.69053816026258, 63.895786654564645, 62.63322668690836, 61.80100564033755, 61.6015217381139, 56.946664625598544, 58.70240772924116, 61.60675417992377, 63.1092494533908, 61.33125866613081, 57.40466017876902, 56.2455488020374, 48.55453398919875, 47.056149359672304, 58.39641186498827, 63.65643578190958, 56.06029133642874, 49.43331749208512, 50.58650608985655, 51.045407710536836, 48.43699624461513, 44.59908254684941, 46.569959809703214, 43.91320120903754, 44.901187419891365, 44.435001957801084, 47.8775760435289, 48.073208178243334, 49.10528575220416, 52.455236988682906, 52.77889528582173, 52.48216798228603, 51.55774770244476, 51.56591407714352, 42.93835886063115, 43.39348323883549, 49.41717693882604, 50.56774147095219, 50.38655934795257, 30.829651086561142, 11.066658554538604, 36.29356961096487, 37.42669920767508, 48.15982980112876, 11.077279352372694, 16.86967088330177, 52.66267545761601, 42.19838411577287, 53.61291670030164, 46.167183383818596, 51.49357772642567, 42.38293947712068, 44.31371050496256, 46.6863129984948, 51.010835939838046, 50.17206845744964, 53.909475341919936, 53.86749813633581, 47.14478315845613, 43.847725083751065, 43.03279384489983, 43.77179976432554, 41.914298611302534, 41.00269271481422, 41.73677605967368, 45.232474727015344, 46.269463108431914, 48.49080724100913, 51.33403531966671, 55.29508006188178, 54.967118924663914, 55.932367155628825, 55.63147037259994, 49.13452702183878, 45.95232771288964, 48.2788109779358, 48.81151199340821, 50.49843711237754, 50.37634941839403, 52.152430011380105, 55.75355806658345, 55.57426260363672, 54.50372619013633, 53.73310204475157, 49.12537613222676, 47.173969514908336, 51.02316787165981, 55.966899702625895, 58.296485562478345, 56.66982373883648, 60.616995057752064, 62.264582726263235, 62.185284168489524, 62.578180143910075, 59.22874666029408, 51.74318167471117, 39.50833243708457, 14.971009358283013, 0.8220418218162753, 0.904076110211111, 0.1939934726443983, 0.6407384730635152, 1.2142883385381391, 22.950076172428748, 47.07589457111974, 52.668751209012925, 53.293573010352354, 54.612171880660526, 56.138119005387836, 50.57148733446675, 20.070426925536125, 2.5750306248664856, 51.19932151609852, 45.9986077585528, 23.57438022090543, 45.34426619929653, 21.579774579694195, 49.128667000801336, 57.11758975059756, 14.85859226795935, 0.5404484932941775, 0.22693612672869237, 0.020449652276452512, 0.07263803614243385, 0.06023442147359733, 0.06424521734457343, 0.0704774153869479, 0.03265874956043498, 0.046773310525402914, 0.09160201410732924, 0.12401033718619617, 0.04821250628259394, 0.0667631606601419, 0.018977436214505185, 0.06926538002106451, 0.12852087136237852, 0.14967907069911882, 0.1463908221452467, 0.09217856421826348, 0.11445791791042975, 0.03912210314264221, 0.12475783215655435, 0.031591020261628494, 0.1806564487877392, 1.2877094697567726, 56.49448986976378, 60.68420094828452, 44.13296768742223, 31.03329662353762, 48.28294123372724, 54.88955405450637, 43.97634352407148, 3.9445237190492697, 29.267643651654645, 76.7670992882021, 74.20171230070054, 68.03099247717088, 66.17992401123047, 51.04919279775312, 26.78350660108751, 0.41132517038814487, 0.32416725531220436, 1.1327445915629788, 11.589637975538931, 15.258983892779197, 6.8395790553862055, 62.072931797273704, 66.06117033189344, 69.41698551177979, 65.82998583393713, 58.91314883385935, 56.89643475317187, 64.36704374128773, 68.29236353597334, 70.4799242942564, 68.44088800491826, 68.72311822829708, 62.67396442351803, 64.3848866032016, 62.18828870404152, 64.78740415265484, 60.184145819756296, 61.26329575815509, 60.74797476491621, 64.26095147286692, 61.55707736169139, 57.87898063659669, 59.7703436113173, 53.44250148342502, 51.754948785228116, 63.62700231613652, 63.681209471917924, 60.737266694345784, 48.900306609369096, 53.152618715840006, 54.34331301719912, 50.552973747253425, 44.681315037512014, 47.66911775835099, 44.50910337509648, 45.03405378710839, 45.456230255865286, 51.21101802395236, 49.26911530956146, 49.59198913266582, 52.97832427486297, 54.180071815367675, 55.46326345013034, 53.773004316514545, 54.728662352408136, 46.33538246154786, 45.52539733148391, 54.10880234933669, 57.78573413049021, 54.424800257528986, 47.386106983307876, 20.572227508791034, 40.77063745067966, 40.31218298019902, 51.83817363554432, 20.967514168831613, 24.137401157809844, 59.54089672334733, 46.334303809750466, 57.64217145981328, 54.027464159073375, 55.899474159363784, 45.297099697974424, 49.55847640191355, 50.35114034529656, 52.9921623968309, 53.11381470772528, 57.224176237660075, 57.02755958803239, 49.690166058078894, 44.895323476483746, 44.51641467309768, 46.56743380331224, 42.89308686410227, 43.787073473776545, 44.31249849257931, 47.35357876746885, 48.69398209356493, 48.752692130304155, 53.26223719504572, 58.97229033131754, 57.174436661504934, 57.50546116982737, 59.22121570956323, 52.50060312209591, 47.550305243461366, 49.50679133015294, 49.43917359075239, 51.12092510346444, 53.58416572693856, 54.099847578233295, 56.34290987445463, 56.6829401446927, 54.72175898090486, 55.18850141955961, 49.70521619243007, 48.17214604346983, 51.31951862765897, 56.70014758263865, 62.3927971624559, 59.46471644986061, 63.69503582677534, 64.29818653291272, 66.12674451643421, 62.32961562372024, 60.56859300982568, 51.58963657194569, 42.1875269951359, 17.065148084394394, 1.4163165106888742, 1.1563659627591412, 1.2377583307604636, 0.5008839743752633, 3.3241555238923723, 33.44137499409337, 54.057972354273645, 60.43385567203645, 61.466043072362105, 62.91214642986175, 62.032515695018155, 58.29368106780514, 22.080620065812145, 8.271007845478675, 60.98007317512267, 50.07786097065095, 23.834584374581617, 55.491516282481534, 25.56074300119954, 43.68457409643358, 65.62773273837182, 14.6161005573888, 0.6357164296411699, 0.14772706334629368, 0.04624516567996433, 0.03520521815986403, 0.05774509920287998, 0.03256584224741786, 0.14057846709845528, 0.05489861525054421, 0.03179153994536929, 0.07076128160641079, 0.42743560107004264, 0.13651790998635754, 0.1337731088842115, 0.17247620789754778, 0.2315027768453283, 0.40923270847528215, 0.3990347298883623, 0.4598048383430128, 0.200134510054223, 0.3795996308326722, 0.2998094897597067, 0.23373958504488393, 0.2105730708928839, 0.3824041561493951, 8.014689780050709, 74.11111339446038, 67.18454499398509, 64.6971151136583, 38.53640833208638, 58.052063065190474, 74.39430067616125, 42.52467040092715, 6.092510704071292, 41.976072019146336, 86.48932133951496, 80.91270723650533, 75.53687926261657, 70.83690704837923, 70.24459777339813, 33.918539170295965, 0.7048022386527831, 1.4058959988817092, 1.9636029822211114, 16.95570807303152, 14.798853589642434, 10.800506126496101, 67.99995083962718, 67.11776271943124, 78.92276333224389, 65.39165312244047, 56.485248765637806, 57.05173315540437, 68.82769646183138, 71.55425363971342, 69.50607038313343, 68.9282895672706, 69.64201188856556, 64.63747155281806, 67.20026585363573, 66.00103255241149, 66.42717453741258, 59.45114897143457, 64.40539667683264, 62.351223960999526, 67.15718253966301, 63.629041948626124, 61.43200474400675, 56.8407763204267, 52.90410518646241, 56.00054971633419, 67.31578749995079, 68.75696043814384, 64.72999242044264, 52.57844255816553, 55.32003025854788, 57.257461470942346, 51.25212054098807, 46.0822013116652, 48.76995448143252, 44.603918829271876, 45.74295159309141, 47.791005411455714, 54.124625190611816, 51.69858432585194, 54.57006131449054, 57.80508318255025, 53.56449896289457, 54.974500825328214, 56.58137429145075, 59.92692855096633, 49.80588382290256, 49.416094364658484, 57.86311072687949, 59.43989569141019, 57.660967457679014, 39.200128278424664, 13.502903465301761, 43.56543994718983, 43.55454360285113, 57.23257010982883, 17.30785846710205, 23.420478182454264, 66.99524356472877, 48.079464358668176, 65.03408985753214, 56.26881237952941, 60.95102802399666, 50.22751115983533, 52.568824906503, 52.854181258909165, 55.83140926976358, 54.23677752094885, 59.70853490214194, 60.05793571472169, 50.56678049025997, 47.6945621736588, 48.180179057582734, 48.8475428858111, 45.527601703520745, 46.26529755130891, 45.24155893633443, 48.07342390860281, 50.6687464252595, 52.06333729528612, 55.49594071603591, 58.35717247378442, 57.893854264290106, 59.18140365231422, 61.324308226185465, 55.699280308138945, 48.46208372423726, 46.37735574476181, 48.31939181973858, 52.55707740783692, 53.395205543887236, 54.02393794828846, 59.080779167913626, 58.458479450595, 56.12051933042465, 55.334539105815274, 49.2385482788086, 46.36079157552412, 52.09390824840915, 58.6181709074205, 61.74816739174628, 58.45558081903766, 63.698483590156805, 66.15447567355248, 67.30586390341482, 64.5264410203503, 60.86503005796864, 56.54270364392189, 51.973503251229566, 23.049304293048, 2.141989435880415, 1.5906640262373033, 2.443137005452187, 1.381386701137789, 2.8897277770503877, 29.898876567040723, 57.61229868858092, 63.53355184678109, 62.26715972346645, 66.54275109691005, 66.31533207431917, 62.638580722193566, 27.16252523083841, 8.32044049616783, 63.78045720438804, 59.07098500959335, 34.90811786343975, 67.48385321709418, 31.354903521076327, 66.05600849274667, 68.40753216897288, 32.716779862680745, 1.5685603671496915, 0.3687761261338188, 0.1823407543763038, 0.27494350147824137, 0.10078691036230135, 0.15269687489396142, 0.2761279653397299, 0.15963522597186028, 0.1656886535666643, 0.2594535100844599], [0.02659761512111272, 0.026584501611068848, 0.046346270133771246, 0.06912031361172277, 0.10462144855409862, 0.07132362844722887, 0.036514964210049766, 0.07189594975282108, 0.04636888887973563, 0.14596901413413788, 0.09913439742259442, 0.02363165209610616, 0.18662893153246374, 0.1274410704331052, 0.11989678977237594, 34.42934943783668, 53.75811499934043, 43.879508049257346, 42.46800784141787, 25.767763737709295, 38.843149446672015, 49.8731210923964, 5.503324616339899, 11.774062918078515, 63.36636866292646, 71.45806143360754, 60.07190719727547, 65.90690351301625, 53.5267932184281, 71.86772946388491, 36.91077416942966, 6.783925525603756, 0.3514793010488633, 5.73172668295522, 26.90624148614945, 9.26366069624501, 13.398384067320055, 46.01253217266452, 63.965424414603945, 64.61851866014543, 60.663808545758656, 59.0247324205214, 62.24721054877005, 69.956374168396, 66.85105723719444, 65.59210585009667, 61.78217434114026, 63.254596802496145, 61.08560454460883, 58.33786264542611, 59.172970556443744, 60.753893621506236, 59.495569813636045, 59.876271140190866, 64.08489588768252, 64.02997093815958, 62.33842134475709, 58.76247882843018, 61.875609121015, 52.3051514164094, 57.65225195115613, 60.62105471088041, 60.91096493505663, 51.65319073584772, 47.586979404572524, 51.27301108452582, 49.26214525776525, 45.01539899456886, 47.18326553221672, 44.47576322863179, 43.6928738317182, 44.30969792027628, 47.344784813542525, 48.15766857516382, 49.205113995459776, 51.745033033432506, 51.795490403329175, 50.887485242659054, 50.87630256529778, 47.481295062649636, 40.91900110244751, 40.06416366946313, 45.832083532887125, 51.81989146817116, 52.95650805196455, 42.61864254551549, 15.768164415513317, 33.36569678398871, 27.11721204942273, 40.45637323010353, 10.297626891443807, 20.0872205534289, 55.15175665578535, 42.61358661036338, 56.10973281245078, 44.32517559297624, 50.60410184244956, 41.98012774990451, 44.487271462717366, 45.553591328282515, 52.724978385433076, 49.50490467010006, 54.236377439191266, 53.01182131613455, 46.09845169128911, 41.14010510906097, 44.05361029409593, 43.53132317143102, 44.26904647581039, 40.195845480888124, 40.92538279871787, 42.77572562617641, 46.02982198038409, 47.06827340587493, 54.35542137392106, 56.64505004882813, 59.36733576559252, 57.51153692122429, 48.343231985645915, 48.74480424388763, 54.41818321904829, 51.22262823966242, 55.499949378352014, 56.60011929850425, 56.78255265758884, 57.663246354749134, 57.237418159361816, 55.439756685687655, 55.819442118367846, 58.28012927885979, 53.028730653947406, 48.81914884813371, 46.81742214387464, 55.527009810170824, 58.620547863744925, 60.088926361453154, 60.7450290649168, 64.87842667487361, 62.2351178815288, 56.79573182136782, 45.03594436953145, 26.72850516534621, 13.145685368968596, 6.949790793080484, 5.75758392772367, 0.8683695487918393, 0.5844747695711352, 2.783295243017135, 32.01313018798828, 56.26699239976945, 53.67931066020843, 55.50415808154691, 54.003219989038286, 55.9208942228748, 59.8719879119627, 46.33313886580929, 17.509625188765988, 7.5907668759745945, 41.75639967764578, 40.495745981893236, 29.66799605277277, 36.24523032096125, 25.389474668810447, 50.09541357717207, 48.82816637715986, 2.218375388653048, 0.3201414632701105, 0.08004152516443884, 0.010428037663410989, 0.02714295097957215, 0.03226907510731009, 0.042259302140483936, 0.045977394967790575, 0.11919666967925527, 0.07092472646505603, 0.029128009280670556, 0.03193427936264104, 0.06705625057821313, 0.03749356109408602, 0.031113619165074442, 0.0426105304711288, 0.03493693799922063, 0.12651944367755807, 0.023537718225270513, 0.031178391899072358, 0.05769988852402857, 0.12775770223308958, 0.027469361891909957, 0.10681091251993373, 0.06034979814543359, 0.1392386252841642, 34.27187804252871, 61.69887104342061, 44.02677735974712, 32.1801447099255, 34.37163568312122, 39.4882381346918, 58.70228613576582, 10.61009172470339, 13.510196132044639, 67.13174204672536, 75.66020642557453, 64.05403075679656, 69.19941948306176, 62.63820417465703, 80.81055302773753, 42.967333409094046, 8.771710165085333, 0.10546170145032868, 4.845777990356569, 34.59036273341025, 14.718237115490822, 18.937697410583496, 50.715657972520404, 64.71484814920734, 63.52855082481139, 62.96731848870555, 58.62725511673958, 63.43615155066214, 71.10800558520903, 68.16578080577236, 68.15924613706528, 62.69008144255608, 63.32138692179034, 61.19805889744913, 60.51408383154101, 60.134319951457364, 62.34577578883018, 62.86115169525147, 62.96044257379348, 65.09361574726721, 64.81832811909338, 64.75091042057161, 58.1011672173777, 65.16245726616152, 55.87470831409578, 59.84276233180877, 61.0685932251715, 63.61608243757679, 54.82205006384081, 51.41242388756045, 51.057547446220156, 51.87740125963765, 46.75202838836178, 49.04284554143106, 44.66502935655656, 46.25431491482643, 43.66668808844782, 48.07338076253092, 47.25955563206827, 51.296278584388, 54.35668829948672, 53.20062460437898, 56.87981567075176, 52.81341998807846, 51.35628692565426, 45.20144093421198, 43.927576695719075, 48.33302597845755, 61.4206769389491, 53.05673637697774, 63.36133233962521, 35.89693169439993, 37.3198381547005, 37.65120390922793, 43.62153376302412, 14.111906347736237, 22.408008536984845, 63.12720606403967, 46.803234930961366, 60.93163974823491, 48.779419160658314, 55.95925892553022, 43.84869390918363, 48.7814901721093, 47.952473701969275, 58.966234191771484, 53.64604111640684, 55.500016058644945, 56.083068540019376, 46.95692123905305, 42.97600576954503, 45.617557341052645, 47.8516334872092, 45.62471958898729, 44.07029997917914, 44.290611667017785, 45.36799653883904, 49.017867888173754, 49.254798658432506, 57.152824401855476, 57.041578139028246, 61.99270756013932, 58.42935192969538, 48.85260274333339, 49.85347786257344, 54.49114322662354, 54.98431459549935, 57.07280412797005, 59.75512089267854, 56.60356313951554, 56.86209832468341, 58.25306100230063, 56.208917786998136, 56.34568299016645, 57.74103087763633, 54.33941418124784, 50.32273454050864, 50.71703864682106, 55.23857439717939, 62.159980958507916, 62.75685979473976, 61.88100238000194, 66.8746228371897, 62.70314293522989, 58.12501915039555, 49.67437851813532, 30.27918173420814, 17.12068296247913, 8.942035167447983, 6.516331626522926, 1.8410737764450813, 0.7688780777877378, 4.747102923931615, 42.29722392174506, 64.06702949154761, 60.430282392809474, 63.053336066584436, 61.559387637722885, 62.285265384181855, 68.11133046304026, 47.881804358574655, 19.005523035603186, 14.187056018460183, 41.65371987127489, 46.61596136708414, 31.46566341000219, 45.48108239327708, 26.23235671750961, 50.612021107827466, 50.5759431469825, 2.1338490468840448, 0.34764739053864635, 0.004576120399794872, 0.06448464663398844, 0.04917939734314719, 0.01400876709545452, 0.12755717871890915, 0.01835048326381272, 0.08886047653974065, 0.0035883536827074547, 0.04935801840357242, 0.29060647552532537, 0.25514573639919685, 0.2168207937070439, 0.10321239069584878, 0.1960335647867572, 0.26583958837774496, 0.2422977524298814, 0.24590559754400487, 0.1797749880220621, 0.473504237109615, 0.21590383242695563, 0.18491897732019427, 0.4695926840987898, 0.29174656757423956, 0.5174241803826825, 63.050339375772786, 68.44142144726169, 63.28063349569998, 58.506446115432254, 42.144510361456106, 51.614641681794204, 59.529765036798295, 12.62187832786191, 19.836900772586947, 78.56966372459166, 82.32809451318558, 73.65281581878662, 80.39784123820644, 69.82969730131089, 89.16475434457102, 44.6547802032963, 8.534588179280682, 0.49634272773419663, 8.706252671057179, 39.40200090408325, 15.209351201211254, 23.105829569601244, 57.17649198347523, 68.69785816438737, 67.30629536413377, 64.92933119496992, 62.694882423646995, 67.20413331062564, 76.72939746610581, 70.02954206159039, 69.86239417906731, 67.87874960130262, 65.15454584552397, 64.63524756893035, 65.82690285098168, 61.81307085098759, 63.38558827677081, 65.78471383740826, 65.71903374887282, 67.66049323543426, 66.66930244814965, 67.45835781097412, 62.939948189643125, 62.26917189936485, 59.31988685361801, 65.59484758684712, 67.1411322009179, 68.89135652972807, 57.26124263578846, 53.05224526313044, 52.462014844340665, 53.605562256228545, 47.34236863351638, 49.029776204016905, 44.70393142392559, 45.895696532341745, 46.67848002526068, 49.48774037822601, 50.704534130711714, 54.94960554184453, 56.931206564749445, 53.401285217654326, 54.79671547489782, 53.27486722700058, 53.52079591443462, 48.069838862265314, 46.20070003694104, 48.886597925616854, 63.31541707438808, 58.67618668463923, 65.12211961130943, 21.497191036901167, 34.416299712273386, 37.267466668159734, 47.5465319233556, 13.363398486568084, 20.638827393131873, 69.18807598852342, 49.36626065161921, 66.92156576341199, 48.061472446687766, 59.94365745975126, 47.646062066478116, 52.53839515870618, 51.86495165671072, 61.51698289378997, 55.390032799013206, 59.3583692273786, 58.06224946052798, 48.612863556031265, 42.396408896292414, 48.384879712135564, 48.292186260223396, 45.982749615946126, 45.77160842957036, 45.678193261546475, 44.26100169458697, 49.02819156646729, 51.694936521591686, 60.62311395522087, 56.59198430276687, 62.74523388954901, 60.205110888327326, 52.62091006002119, 50.5125262660365, 53.45989719513924, 52.95636292426817, 57.86847652927522, 62.86305012241487, 57.21145599119125, 57.373394966125495, 59.435314363048924, 57.61787237659578, 55.59506685503068, 59.69959974288941, 54.30206145009687, 47.94493098412791, 48.73359410993515, 59.98630539063485, 63.98222784842215, 60.85536533786405, 61.48783968340967, 69.56835762146981, 63.22768542074389, 57.91620392953196, 53.92500008306196, 36.55840804499965, 19.45837832266285, 7.429869290321105, 7.626118217745136, 2.2550640135042133, 2.0986457745875082, 4.280271251355448, 42.281114747447354, 72.79941005091514, 64.67621280301002, 64.73669967343731, 63.59616464184177, 63.116964755519746, 73.83599835057413, 55.065880283232666, 24.994780286665886, 13.706339155474017, 51.958206007557536, 51.248002052307136, 46.06122055361348, 53.34801158597393, 37.2381430287515, 66.76249796344389, 69.80817917854556, 10.251619450507626, 1.1075789096855349, 0.6296728539370722, 0.1536257565021515, 0.23912990225418923, 0.2957848621712577, 0.3122453643910347, 0.10995952622784723, 0.3871586203815476, 0.14702463732852092, 0.25645510323586007], [0.06867961387240118, 0.030176009900207003, 0.12167531651474776, 0.0630881181437402, 0.01491906724104117, 0.07001278306087179, 0.029698878849646258, 0.03262707948564522, 0.12601404015215176, 0.22733666813902317, 0.06598851553374721, 0.10712297843588937, 0.21597874050419177, 0.22027073277821466, 0.39735837629245174, 11.120201849168348, 56.69451505907121, 58.20321159978067, 49.365429109142674, 38.754511725518014, 28.00784503259967, 39.89426228307909, 18.7191076432505, 5.664236910881535, 58.58305784963793, 76.24987986779983, 67.09032181770571, 56.70443865560717, 62.75536537170411, 48.05342374309417, 50.15896381870393, 65.73723746884254, 9.012824143132857, 0.06131800304677698, 17.647773027420044, 23.542867898941044, 11.505481562306805, 29.337987438324962, 37.755868434906006, 57.517844092461374, 59.26946086268271, 63.88806743006553, 69.50078302814116, 64.59312915802002, 64.76417979886456, 64.4745441406004, 63.19949534631545, 59.497209364368075, 57.18451323047761, 55.949715798900975, 56.033525082372854, 55.3528840311112, 60.236364333860344, 59.87642411262759, 63.4232351856847, 62.05154311272406, 62.034547482767415, 61.42989450885404, 61.11000953182098, 60.83152517195671, 59.28671929144091, 58.62611370701944, 56.27590794717112, 53.80239071384553, 48.29770895742601, 49.644862682588645, 48.996330153557565, 46.374790514669115, 45.014057543969926, 44.65356819091305, 45.00369856434484, 40.5422378355457, 45.65705560868787, 45.9894411794601, 48.56873296922254, 50.24466760696904, 53.97794815801806, 50.57373485257549, 47.40731916119976, 45.568853270622995, 40.613397475211855, 42.04949094403175, 45.66550831640921, 53.51222553560811, 51.75226196166008, 51.6792352737919, 17.332796896657637, 20.407211434456613, 32.67932907227547, 39.757752033971975, 22.670226827744518, 35.08208282532231, 51.118665818245184, 48.81663068648308, 52.273191944245376, 47.576993050113806, 48.99118400389149, 43.39700160488006, 43.341492222201445, 46.10156605320592, 49.25940744338497, 50.168365740006976, 52.810482132819395, 50.004171402223655, 43.81958600013487, 40.84953592669579, 43.17348534061063, 42.98561949883738, 42.61185684511739, 40.655966958692, 42.017947243105986, 44.3431596602163, 46.18944675691667, 47.59769924225346, 51.38161759222708, 56.73744147823703, 55.91721896202334, 54.81200095145933, 59.94715229157479, 59.629903147297526, 56.90293804291756, 56.6695648624051, 55.54336609378938, 54.49651687375961, 56.44445611584572, 53.0515706154608, 56.780646385685095, 53.04439267804546, 53.89533127507856, 56.80996218035298, 56.83984279632569, 58.51038809745543, 55.67606379908901, 47.68783138644311, 51.56682014465333, 58.428053625168346, 59.01714263423797, 53.51939170591293, 49.433227277571156, 38.89436383401194, 22.322224340131207, 20.496904273186964, 25.821886562531997, 15.842709060638184, 4.191918392335215, 0.36164645225771014, 0.6914932689359111, 18.70939193233367, 48.8757525720904, 45.532285013506495, 55.33772014802503, 50.02414803351126, 56.75372715919249, 46.349973678588874, 55.712224129707586, 33.0767906865766, 2.121048391826691, 17.681530906308083, 73.08872407482517, 39.47190930766445, 33.57196638661046, 31.460660426847397, 27.53882173568972, 56.64953331793509, 30.23680836923661, 0.43182390591790604, 0.15846122687141742, 0.0585537011765184, 0.06748913622070705, 0.05232308893614719, 0.045627388547384934, 0.11901433309239727, 0.02720587552645274, 0.037900526151661916, 0.022845946575304674, 0.040744156426479744, 0.11112447782990434, 0.037241085327320525, 0.09101808656968417, 0.04389514500695852, 0.01674704017087577, 0.04407306892737266, 0.04476472374893004, 0.05972874981741752, 0.09093990729701135, 0.09561125865025867, 0.047008530161673986, 0.12128699420680925, 0.17045759686058568, 0.29954993917096046, 0.35829644169538255, 9.131210100266243, 63.39425279248146, 61.062411569779925, 43.52023463095389, 45.32522309210993, 35.43606496626331, 34.750469961474025, 22.176522016525272, 5.619048264718825, 63.30045323218069, 79.52210149457379, 69.79438028027936, 67.29191595508208, 70.79621638021162, 57.681661882708156, 56.24896910882766, 73.04262838056012, 10.951494824501777, 0.0756123035605396, 16.66679216969398, 25.34732880130891, 20.661224126815796, 38.08128003151187, 45.91320991516114, 60.94598385595507, 61.41650353708575, 66.41051230892059, 70.86152384358068, 68.52797246748402, 66.81677572188839, 66.84136898286881, 64.94882145235616, 60.42740729547317, 59.78469948614798, 58.131200805787124, 57.69065979988345, 57.923487770941954, 60.11180946903845, 61.90202628412555, 64.75592320965183, 63.1031854691044, 63.918516789713216, 61.94518412313154, 65.04974011451968, 66.86224383692588, 60.74343658262684, 62.39501722397343, 60.22043558859057, 56.535400190661036, 49.55783313320529, 52.32952110229, 50.010431505018666, 47.55242332335442, 46.39270005687591, 46.84407072682535, 45.77871184195242, 43.646444735988496, 44.87449176849858, 46.80707885373024, 49.94522994564426, 52.24368003106887, 57.61373035369381, 54.633905733785326, 52.658925671731275, 46.54434673247799, 45.42421587051884, 45.56638217741444, 53.07921155806511, 57.36294184961627, 56.04329962884226, 58.77162579567202, 60.50550560797415, 40.01076059956705, 34.70768867000457, 39.93201509598763, 38.94352289938158, 58.39891433715821, 56.74358783229705, 53.66402910601709, 57.1624695101092, 55.24891768732379, 55.64337868844309, 46.356555415738015, 44.74384546279908, 52.002222845631266, 54.3324911978937, 54.80283044999646, 52.63639165509132, 51.472891146136874, 46.92701316648915, 42.94807457154797, 44.608202057500044, 44.150124134555945, 43.418672700082105, 42.460606328902706, 43.37947645495015, 43.940379311961514, 47.658896061681936, 50.099747796212476, 53.72326866272957, 58.20769094651746, 59.49518542135916, 55.384274759600245, 59.782655931288204, 59.40408837410712, 58.95755790895032, 58.77537558155676, 56.609854621271936, 57.034698301746005, 57.72008934328633, 54.121526518175685, 58.945088694172526, 52.32096249057401, 54.48878195977981, 58.019009251748365, 59.59535883318994, 61.42076715346306, 56.60194712300455, 50.68730315854473, 54.35907702292166, 60.02190089994862, 61.1122452828192, 55.27441701581402, 54.84559212961505, 46.67431054576751, 27.195022067716046, 27.026664133994814, 35.67909109976984, 16.39951304081948, 3.7661321172791147, 0.827935244287214, 0.9791859443629942, 22.21742645386727, 57.79864657309748, 53.792902500398704, 64.46679353713989, 56.19334989978422, 64.80011263201314, 51.183451606381325, 65.94382870581843, 29.292988046523067, 6.613798602934807, 22.986964102714296, 66.29623797632033, 44.84164976304577, 35.2789387395305, 47.76562375407065, 25.715166714883622, 64.34196410640594, 35.04338079883207, 0.7492800165087946, 0.2586685457537251, 0.056010936612203244, 0.0347121256674009, 0.02165716963880245, 0.12938432906183506, 0.07063664676200959, 0.025855404242212256, 0.0429156058347754, 0.04080192711684973, 0.10956711301039304, 0.2509775592554962, 0.22506874144798328, 0.285223696621195, 0.11107046097036331, 0.10059616213003475, 0.15792999086120438, 0.25210606805499525, 0.19914201250480068, 0.3606583520529732, 0.3379497899403495, 0.20353880560686513, 0.21263453688833023, 0.42990022849652076, 0.5766765460852654, 0.7845605104680985, 21.964821892399943, 76.37251669360747, 74.85814448325866, 68.8365061052384, 55.70866261759112, 46.069233955875525, 48.75926210034279, 26.409930259950702, 10.933478397707786, 74.41674447828724, 87.30979488741967, 75.49318405889696, 73.92520089303294, 75.24123453324842, 62.298636744099284, 59.05490721425703, 78.75242264040055, 11.217558999215404, 0.20348062888989527, 26.265881215372396, 28.203230057993245, 30.515967376770515, 42.9498984736781, 50.706816950152, 66.71435479194888, 62.73378841338619, 68.37925188003048, 75.43335222428846, 71.75372185245638, 70.66601722471177, 70.0559788365518, 70.01178156945014, 62.43761808641496, 60.645663661341516, 62.07236697596889, 61.40304588502454, 58.41401546232162, 63.79258517296084, 65.72579983742007, 67.56268501281738, 67.7689467706988, 64.62355890581685, 62.71037970819781, 68.2329474726031, 65.51339957021898, 61.68144787511518, 66.00459406452795, 63.83844552501556, 58.24080359551215, 53.10666422690115, 55.56304854731406, 54.239962485528764, 49.845182049658995, 46.10413128329862, 48.23848116782404, 46.14100156291839, 42.038257275858236, 46.736523259070616, 49.0556207010823, 50.889709226546756, 56.32559653251403, 59.503379252649125, 55.226532720750384, 52.14040794680196, 50.67093118544548, 48.50573970425514, 49.53080408034786, 54.60500178798553, 63.227430466682684, 58.919342256361446, 65.7931233990577, 42.487117628897394, 24.201049458596017, 40.162273914583274, 43.609397949710974, 32.676132340585035, 51.28472328186036, 61.13056667389409, 57.17229112502068, 62.784343842537176, 57.37489723390149, 58.64786717199511, 48.925962832666215, 51.6105467273343, 55.435265571840354, 54.77693103974866, 55.68199834515972, 56.77781051205051, 55.37977972338277, 49.177802531949936, 43.499952054792836, 45.58027129019461, 46.19992340764692, 46.09754954614947, 44.28944280070644, 47.030030296694854, 46.51945929373465, 48.040774099288456, 51.47915517130206, 54.685449600219734, 58.951062463944965, 58.87952235437209, 57.08797585579657, 59.87230170157648, 61.76697123435236, 62.61228123018819, 60.23603485476587, 58.4276064749687, 59.33783169715636, 57.62768614676691, 54.040125569989605, 60.703000868520434, 54.21595758007419, 55.91663845123784, 62.575811032325994, 59.015456015063876, 59.697509119587565, 54.59007716947987, 51.92275170356997, 53.53736792841266, 58.29247690016224, 60.51113813154159, 54.73522840007659, 58.20018745237782, 52.46621962516539, 31.08657417758819, 35.53885459899902, 44.88350145278439, 23.096882643238192, 5.054060259172994, 1.5078057949581456, 2.5781964678918166, 24.610974404119677, 61.78465720145934, 57.641602716138294, 66.72334486438383, 60.64748756347164, 66.19445247034874, 54.51891752981371, 67.71644192357218, 39.92096577921222, 6.380568588933637, 26.240174001263036, 86.0511298333445, 47.426793729105306, 50.5671727272772, 46.30824750469577, 41.8148979063957, 68.49232596735801, 53.813043871233546, 1.081299519827289, 0.5008517986824436, 0.2130189444869757, 0.16382482293392384, 0.08910680445091379, 0.22924575924633012, 0.21237910785261663, 0.16918710132520046, 0.12809828194158693, 0.259606666382282, 0.18586911020740388], [0.04411635672553413, 0.07419993620245688, 0.05200304421446016, 0.05883357224745616, 0.10477609106249387, 0.045160599683801976, 0.05613439168120104, 0.103062559219618, 0.059229383064854535, 0.14135371743431016, 0.029029482712728844, 0.01166988438325784, 0.16093941405415535, 0.12971573869787878, 0.07666898395625815, 0.9088031791390911, 48.722007428446126, 48.07628331645843, 55.252043816351126, 42.225236661972545, 28.00663890377168, 45.72759943623697, 64.23181610722696, 5.995453615342417, 14.224096921182449, 55.807447510380904, 67.62083807299214, 62.35986494248914, 57.79907018907609, 69.73843159214144, 52.78956021032026, 59.766950761118245, 38.609729197717485, 0.24875326893262326, 1.1287193817477073, 16.636829183947658, 15.376217653674466, 27.20004858509187, 42.59856785497358, 50.03763314216368, 58.54735643632951, 68.92094689030802, 68.18547110403738, 65.25731978877899, 62.31470277232509, 64.16061724385908, 58.37543502930672, 53.47118577649517, 59.043375445950424, 53.57860380603422, 53.05448493649883, 54.10554678209367, 57.062402002273075, 56.340756493230025, 59.58086567540323, 60.42745828628541, 60.4305334245005, 59.885021948045306, 59.913051205296675, 59.215653788658884, 60.349195234237186, 60.04782776678763, 56.121841169172725, 51.47145163628363, 47.188752928087794, 48.77000547224476, 44.25134089685256, 47.050532525585545, 46.139601276766875, 45.124731140752, 46.26574862387873, 43.69895742785546, 45.84273669027513, 44.91106002561508, 46.68691312113116, 49.360396708211596, 49.41981277158184, 49.41382331232871, 46.244862002711145, 44.966894965018, 41.73541499722389, 44.23290967941285, 42.663687044574374, 51.79551785992038, 48.09173745493735, 61.426180024300855, 18.245108819776966, 20.434650374997048, 49.093051879636704, 40.609475105039536, 37.272204891327895, 41.73223395501414, 52.807716861847915, 48.186415626156716, 52.16248696850192, 47.05072472172399, 48.485641479492195, 40.89912645278439, 43.612928082866055, 41.757392037299375, 49.25438680956441, 48.29733240988947, 52.54456504698723, 51.44854107210713, 43.28106418732674, 44.62213039398194, 41.227738703450854, 44.35566025395548, 40.64099919411444, 42.44813319175474, 40.59544086456299, 43.25987162128572, 46.158620849732436, 47.524260705517186, 45.298507828866285, 53.28409264164587, 57.91603918998473, 59.25574041181996, 55.4000779890245, 52.86910587741483, 58.54161408639724, 52.81985267516106, 55.327063068266845, 53.10163182597007, 53.424160480499275, 55.4490723148469, 58.55171026722078, 55.44903701351535, 55.60250366887739, 53.754482884560865, 54.86998142734651, 58.96800710308937, 55.51949454892067, 53.07967832011562, 55.48153777276316, 51.30361341661023, 51.84703034739341, 49.81767054527037, 43.67707844703428, 24.99161493393683, 11.031520981942455, 13.179360878083015, 11.75903827913346, 3.8442375390760364, 0.6507613545944614, 0.9508292304892695, 1.8687517364178936, 26.79404404855544, 51.11390013848582, 53.1725835800171, 55.80794957376296, 58.727781541885875, 53.677353397492446, 50.12953427530105, 57.05488281865274, 8.138623929792836, 5.4648123345067425, 42.597504892656886, 72.68541812896729, 26.56933342256854, 39.95139944937922, 18.98339302309098, 24.86190607470851, 57.69115794089533, 21.87613121924862, 0.3433210162385818, 0.02776673424147791, 0.05252029528961547, 0.18902157733757652, 0.047668292742943576, 0.03106004855174932, 0.01987075027559073, 0.040336712563951174, 0.038230461068451405, 0.030332088823460286, 0.02788143292550118, 0.0637979407404219, 0.05126055945912677, 0.03128110896795988, 0.01817463544167338, 0.033133842817117135, 0.03639906276798537, 0.04597356069772955, 0.07385113637053198, 0.01346898920488574, 0.036598176680385106, 0.04833940491681138, 0.1435934214462196, 0.1480607099590763, 0.030644020674029188, 0.22315932858374812, 0.432424457563508, 49.76412627004808, 54.569743602506584, 54.20315496383175, 51.36480239129836, 35.71883647672592, 35.93906579479095, 64.32787495274698, 12.58080424800996, 11.217051052278089, 56.49631377189391, 74.57599270728328, 66.18206562534456, 65.25113421101724, 70.74333498554846, 58.94460624264133, 65.51351331895398, 44.263837568221554, 0.15118624143783124, 1.5995472140850562, 13.199101186567738, 15.149977303320362, 40.61204817987258, 46.00989633990873, 54.66805781087568, 59.666008564733694, 69.4426299679664, 69.94071606666812, 66.52752445590112, 63.873397765621064, 65.4899634084394, 62.47659075644709, 58.16317204506167, 60.21146905037665, 57.473517387144035, 56.36713443263885, 56.83247658514208, 58.97835823797411, 59.46956449939359, 61.17195552395236, 61.90368544670844, 64.72370486105642, 61.67798049988286, 63.426137739612216, 62.23693786128875, 63.81763342888125, 62.165460509638635, 58.90976382840065, 53.782347402264996, 49.380385106609715, 50.19139397528864, 47.13671876538185, 49.380188988101104, 45.08850020747031, 49.50306900085942, 48.01814202339419, 45.32345410316221, 46.75460538556499, 48.25240950430594, 49.3626206920993, 51.62643232653218, 53.05799938017323, 55.60786947127312, 49.74540479721562, 47.10340607550837, 44.79321633615802, 47.07911483703121, 47.776778974840724, 57.063884658198205, 56.45836876284692, 59.67062911679668, 49.18107771104383, 36.03859593791347, 46.332574044504476, 43.72443714449483, 52.798946442142615, 55.66927025395056, 56.259885065017215, 56.35136650454614, 56.9354780258671, 54.70908580287811, 54.56881400077574, 47.496772735349595, 45.24148833367133, 48.727518358538234, 55.258390211289935, 50.867018315099905, 55.154184602922015, 52.84574031829835, 47.39453615680818, 44.65452132686492, 43.82947821770945, 42.55952850464852, 43.98085817213982, 43.91068696975709, 43.590821604574884, 46.252687131204915, 48.35611697166197, 49.83955344846172, 47.60213936528852, 56.062244676774554, 59.68932313303794, 60.43765252636325, 59.190354501047445, 56.259888987387384, 58.11233028288811, 56.04730044641803, 57.80786022063225, 55.17618125484836, 55.83865780984202, 57.238457587457475, 57.87769409918017, 56.290444251029726, 58.109055103794226, 56.93772162160566, 56.72406619594943, 59.91482803898474, 57.443515177695986, 55.237036828071844, 57.60491678791662, 54.593560234192886, 56.601013598903535, 55.499694424290816, 50.063716903809585, 28.196077615984027, 12.978637506884914, 21.888818125570975, 14.452765218673216, 2.88469978878575, 1.0626752482306574, 0.8906614203606883, 2.4786361715485974, 31.96437708793148, 59.47020776810185, 58.09675062856367, 61.51381361869074, 67.09145930505568, 60.764633071038034, 56.68809021672895, 60.42550886830976, 10.611373359157193, 14.461224790542358, 39.91388590105119, 82.00928426557972, 26.333094950645204, 48.733472516459805, 26.62391712588649, 22.539437355533725, 67.88934000076787, 21.817401570658532, 0.35343987326468196, 0.05652453727839936, 0.051024887830980366, 0.07681732922191582, 0.012764133730783098, 0.014466907783982255, 0.09814013787094625, 0.036381189936711904, 0.016475649693259792, 0.09824326862731288, 0.11440331882406628, 0.23612555056329698, 0.15840878049212118, 0.1711460187911026, 0.13241842028594789, 0.13625149524980976, 0.28019319558816574, 0.23750276214653449, 0.28478803774041517, 0.16863698890853315, 0.30647102262704606, 0.12146529351030627, 0.256455133879377, 0.2862881911137412, 0.28681905940175056, 0.6330693813581622, 3.9740437221142555, 73.68322987710276, 61.94286992472988, 66.47659640158376, 56.435242468310946, 40.19182112909133, 54.6113952513664, 74.51021455949353, 10.595146513754322, 20.07149773259317, 65.45294407875308, 79.90662713204661, 72.29562082598287, 69.94237130688083, 81.13465063033566, 68.70449481471893, 70.55533578318935, 47.10340999787854, 0.23611804290163904, 2.986075407074344, 19.69929422101667, 25.14137494948603, 55.296794137647076, 56.276590439581106, 59.7489353149168, 60.43325947177026, 69.00336373236873, 74.36718140878986, 70.94766693730509, 68.19231956235825, 68.18861684491559, 66.07572232523273, 59.04415207524454, 63.168645904910186, 58.09899422430224, 61.23904766574983, 56.30101896101429, 61.87114546375891, 60.12614180964809, 63.33555844522292, 65.79771257215931, 65.5949495684716, 63.73654627030896, 65.9714186576105, 64.88656951535133, 65.7800030708313, 67.5830578034924, 64.05907100246799, 54.90116427021643, 52.62247508571994, 52.50621211144232, 49.10289310639905, 51.376259634571696, 47.60335922241212, 50.19786980844314, 50.07080854908113, 47.4081781602675, 48.258069484464585, 46.83542582296556, 51.46361081830917, 55.254075604100386, 53.366078022987615, 55.64488095621909, 50.539163081876694, 50.04270476679648, 49.59233822361116, 53.27371405016992, 49.09494246205976, 57.79728943301786, 58.147604157847745, 67.35320691139468, 45.75338509774978, 33.31982858719365, 55.67372998883648, 47.30675351235175, 55.74104570573377, 59.61624545435752, 61.63451279363325, 59.27957665535712, 60.6769641753166, 56.488567090803585, 56.90407945263771, 49.10079071598668, 50.42024466299242, 50.39296065607379, 57.66913775474795, 50.48465390359202, 57.9496499799913, 56.08042486252324, 49.20380000145205, 46.738307937499016, 45.94003892713978, 44.66936749796714, 44.18648842842349, 46.769973231900124, 46.367377235043435, 46.920937415092226, 49.654472489510816, 50.01764866613573, 49.503418091804754, 56.31202513171781, 61.81849941130608, 61.62393416127851, 59.74138082996492, 61.841998331008426, 63.377076733496885, 56.34522407285629, 59.56428581668485, 60.28379755635416, 58.42872827283798, 59.098249404661125, 61.41219285226638, 59.181513478679044, 59.13726522076515, 59.57376618539134, 58.606462632456136, 62.223040903768236, 57.65799822345857, 54.494728272961034, 57.32480464443084, 54.4095814612604, 53.58269876049411, 57.80431439799648, 57.942436741244414, 31.66139360397093, 14.007284968130051, 29.753113446697114, 21.201763999077585, 5.88950353284036, 1.0827365781991714, 1.8238048063170527, 3.278086795922249, 33.554739336813654, 67.21024436335411, 64.80212480791154, 65.96476631779825, 67.55699757606753, 65.37683048555928, 60.92520313878214, 66.24745153611707, 12.993724903752728, 10.965832068074135, 54.84578432575349, 81.97100193269792, 33.78144841040335, 57.02036596113636, 29.280046186139508, 35.91430387189312, 73.02606813369259, 41.816568836089104, 0.36378867924213415, 0.2994136368074725, 0.21481940432661967, 0.2814816635462546, 0.14907979075947117, 0.09199553815227363, 0.18071379812975086, 0.11640078583431822, 0.1296222300058411, 0.23580097443153783, 0.1726177656241963], [0.049493010756709886, 0.07172728017453225, 0.006631779448775154, 0.06774726954679336, 0.03072818309339064, 0.08142899466498245, 0.02439425432033116, 0.03830610842053448, 0.054828748031849825, 0.10959315999981858, 0.09232910049538459, 0.05035143142806427, 0.04301024067606177, 0.1164961407982534, 0.19756678251489518, 0.1724909780727279, 20.993072332874423, 54.19682425837363, 55.42291402816773, 44.34310082466372, 31.74647177419355, 36.95218655370897, 71.90936934563422, 34.27904029046336, 2.98128423190886, 14.936609191279258, 66.78252558554372, 64.12720257236113, 60.2667470132151, 61.70408779574979, 56.22152036236179, 54.93975254797167, 53.70931679202665, 2.4659120027096044, 0.12597199724686722, 0.5740736244666962, 9.007937850490693, 15.259474189050737, 51.53604130591116, 48.54044091316962, 60.11621036837178, 66.57353385802239, 68.54855706614833, 64.53392882500926, 59.23377121648481, 54.04125129022906, 53.10167889441214, 50.24328301029821, 55.70326935860419, 54.19302740404683, 53.201362009971376, 53.052817929175596, 54.402372144883685, 53.79963720998457, 57.57261999191777, 55.85314312288838, 57.163610919829345, 59.861621087597264, 62.52356506163075, 59.32886123657227, 60.1500133545168, 60.347434090029815, 53.128817773634395, 48.18863176530408, 46.211788577418176, 46.97857272240424, 47.514419478754846, 47.952956153500466, 45.7441871396957, 43.16646429800218, 43.56722462561823, 42.809697274238836, 44.14464066105504, 46.11704372590589, 45.610677503770404, 45.712690507211995, 47.24568613113896, 44.612732395049065, 45.49724255838702, 42.84597527596259, 43.402681196889574, 42.38610482984974, 44.044165226721, 44.22819891283589, 48.71306442445325, 53.262174437122965, 51.022069608011556, 49.636480577530406, 49.36849640261743, 47.987006248966345, 48.569631191991995, 53.15104584540091, 50.18107814173545, 50.77994954201483, 52.53994449492424, 51.87431827668221, 45.37246804083548, 40.77783892231603, 42.3885327769864, 44.641985431794204, 48.298658171007716, 49.18488241011097, 48.30392983651931, 46.84564751963462, 41.72442059363089, 41.546235161442915, 40.15009103282806, 41.37377246733635, 41.66010941228559, 41.123262451541045, 43.1295822512719, 43.8567308456667, 44.176811941208385, 46.12824209274785, 45.862854526888945, 47.53666324000205, 52.30531615595664, 53.668716338373, 55.54071064918272, 54.278589986985736, 52.001544275591456, 53.85123991197156, 53.64930845076039, 51.31371744217412, 49.88971664059547, 51.23579955870106, 53.03084873384046, 52.42903947830201, 52.57206870663551, 53.80954511703984, 55.9623654427067, 57.98685366107572, 57.14867061184299, 56.75767698595601, 54.73207089208788, 59.23359078745688, 58.61361703565044, 48.40289515833701, 35.78809768922868, 16.900365391085227, 4.712134503549145, 10.776763039250529, 7.4175878590153115, 1.6981633223833579, 0.379386872894341, 0.48676230794479775, 3.801008361962534, 40.27003711269748, 51.54249752721479, 54.83628434519614, 55.3517504661314, 50.93143540043985, 44.316793487918, 60.74347188395839, 31.155568668919226, 2.411086093033514, 12.562790762993599, 66.9491792494251, 25.97858132854585, 26.56350870286265, 32.82678469534844, 23.031790910228608, 42.561030772424516, 51.829936658182454, 8.348896311175439, 0.595347763549897, 0.038516583416851304, 0.06594986639796727, 0.019800494267274777, 0.06370721294754936, 0.04092970675218009, 0.08991412322727904, 0.09229225932710594, 0.07431706338520012, 0.04747356085347072, 0.06397463125927795, 0.018936982941663554, 0.07853112153468594, 0.04758307312224661, 0.060542178144978906, 0.06348382936970842, 0.027671076672812624, 0.10132200745565277, 0.05995537777761779, 0.01114100217819214, 0.08319698003751617, 0.0312374247192976, 0.06727282363440722, 0.044342701233202414, 0.08968963648282713, 0.10214128486451604, 0.38766993810572936, 18.80196575195559, 63.498505469291445, 56.28461953132384, 46.458674323174264, 40.24450640524588, 37.92819776842671, 69.80846158919796, 48.17154984320364, 7.943383541799362, 13.461090018672328, 69.28094202472319, 71.23214860116282, 67.5925656287901, 67.72968384527391, 63.02121185487317, 59.63766944023871, 58.48563401929794, 2.683140217296539, 0.44949887200228633, 2.2658311647753564, 8.046071683206867, 23.636230114967596, 60.10831463721491, 52.83153349353422, 63.39357814481182, 69.64147060148179, 70.92242256287606, 67.01080752957252, 60.63314345575149, 58.70206256066599, 54.431503588153475, 53.11623088775143, 58.86842204678444, 54.73068629541705, 55.96797443205311, 55.63243135329216, 55.486040653720984, 55.17534971237183, 61.730277461390344, 59.92338272833056, 58.74421627290788, 60.999837998420965, 63.21907581821565, 63.26230818225492, 62.344022489363155, 62.118694090074115, 56.15306715811453, 48.62879230130104, 50.473302564313336, 48.19261689339915, 49.220838777480594, 49.55329102854575, 48.199182941067605, 46.5864965223497, 45.754299009999926, 45.81287568615329, 45.83906535179385, 48.08224139675018, 45.63152097886609, 50.023822476786954, 50.08358370873236, 48.50324899919572, 49.083206730504195, 45.75513055247646, 44.629665267082956, 47.953489595843905, 48.992568600562315, 51.315576645635794, 55.41892890007266, 59.17764602168914, 48.08631281698904, 49.36302469622705, 52.32739910002678, 49.678147915870916, 56.01781598983273, 57.551768672081735, 57.26957767240463, 54.30033952959123, 55.31166384297033, 56.18187696703019, 50.859193186606134, 46.1762793602482, 46.45112376059256, 47.59898577966998, 51.805190424765314, 52.573959289058564, 53.864979974685184, 50.8157294027267, 46.25384423040575, 43.94632562514275, 42.394212368995916, 43.72588057671824, 43.48063830406436, 41.96184950490152, 43.73784380574381, 46.507754941140455, 45.84677280918245, 48.14924724640385, 47.15969993222145, 49.98482627253379, 53.987102970000244, 56.04360165134553, 57.49873038261168, 55.301379388378514, 56.19379312761369, 56.9524658110834, 56.15317698447935, 51.613676778731815, 54.70209613923104, 53.438139807793405, 54.840810760375, 55.32340349689607, 55.14894823874197, 54.7498353065983, 58.772108247203214, 58.90486086568525, 58.226737976074226, 60.26462893332205, 55.58162881482033, 62.09287312722976, 61.19898065443962, 55.418721014453524, 41.43533406719085, 21.093061393307103, 6.127704170442397, 10.332888018700386, 7.839469169416736, 3.229099089099515, 1.0669272200715159, 0.6873141060913763, 4.459907960507178, 46.91873696542556, 55.42609507037748, 61.89900213672269, 63.32664682019142, 57.91742770902572, 50.74336167304747, 66.27208402079921, 31.1531779842992, 6.50658747842235, 16.220588241854024, 66.01266630234258, 32.43075670734529, 25.84062960840041, 41.031898683117284, 18.125819736911406, 45.49838396810716, 60.67008433803436, 7.769035168232457, 0.3519512112102201, 0.13639142887005884, 0.13426092303087636, 0.11406814769631433, 0.04877290342964473, 0.06072480584524813, 0.12892024831906443, 0.0442737763026549, 0.018984614458355694, 0.042854173244127346, 0.073040607685764, 0.24714961708072694, 0.2535701233653292, 0.18293620387633003, 0.11654251210031011, 0.13866969774807655, 0.190917844133031, 0.2912066288052067, 0.15804637493866106, 0.1246544639129312, 0.20183801380617006, 0.22981954377985772, 0.2112026419490576, 0.1505077633285715, 0.34926864709104266, 0.41301292337236867, 0.4800015207259886, 42.58975821156656, 72.94177639868953, 68.56030848718459, 59.00501858803534, 46.55306616137105, 48.96580234650643, 81.09668993180799, 45.64868134836997, 7.249890844668112, 19.19156301406122, 76.21376268325314, 77.85470193432224, 74.28847512891217, 73.78856120571014, 68.85092473799183, 66.0707095361525, 64.47065314938946, 3.878833579440271, 0.8705934713925085, 3.51141756580722, 14.53538602398288, 34.64276167654222, 68.5933348440355, 63.26410462779384, 65.16291618347168, 71.48444329538654, 75.50531202746977, 70.98940095593854, 63.72670504354662, 60.93924522399903, 56.953599376063195, 55.98309909143756, 61.653771631179325, 57.063829745015795, 57.286110462680945, 58.60013192699802, 59.52726256462836, 58.38258943250103, 63.59471728724819, 61.27949122459658, 62.08128252337056, 63.31745278450751, 66.50592788573235, 65.57007781920895, 63.789459043933505, 66.3223688064083, 58.16782789845621, 51.56717315796883, 50.67070761034566, 49.709401361403934, 51.466560440678755, 52.69694912818171, 50.409120821183734, 46.38268232345582, 46.506382111580145, 47.49048517596337, 47.59128224465155, 49.41050106479276, 46.260100410830596, 50.83430574786279, 53.37993967917658, 51.00930229310067, 49.86505669932212, 48.610274791717536, 50.18617330058929, 49.43301546958185, 51.1314017541947, 52.99219377579228, 58.48959169080181, 58.609780957621915, 58.23109965170584, 62.34693681040118, 54.990166771796446, 55.59622395423151, 61.483317190600985, 64.1174437153724, 58.56327341448877, 61.07522595313288, 59.23823487374091, 62.593387173068145, 52.403140068054206, 48.645066215145974, 48.690436270929155, 52.20319332615022, 55.09214055153632, 55.33209939156809, 53.4569279609188, 52.84886252495551, 48.9462257969764, 45.766725078705825, 44.091096385832756, 45.25014500464163, 45.15922446404734, 44.29306314837548, 48.58670526935209, 48.33273572306479, 47.05396067711615, 50.99463655102638, 49.82972791118007, 51.691159279115745, 55.185351756311235, 57.23755151994767, 61.59639127792851, 57.663014934908965, 58.55888820463612, 58.62956147040091, 58.48413175152194, 55.52118116809476, 55.858344185736875, 54.298170458885934, 57.2509228798651, 58.533741889461396, 57.86603289265787, 56.87862719258955, 60.81769489472913, 64.31032234622587, 60.415126354463645, 60.75351707396969, 56.63841732086674, 61.643377350222686, 61.761134747535955, 58.16903598846928, 42.83151349713726, 22.998866535002186, 9.115402948471809, 15.593546378997067, 10.194041998155656, 3.54313948942769, 0.7150629138754261, 1.702934027679505, 4.9671174922297086, 52.459947755259854, 60.73174791951334, 67.48240194013043, 64.3071452263863, 64.1052019980646, 54.65496493924049, 70.80011521616291, 37.884981093868134, 6.155290690160567, 19.54051079288606, 80.26766561692762, 32.05764908944407, 40.35377187113608, 46.43279452477732, 35.38776489996141, 58.876788462361986, 69.86445734577795, 19.47397758883815, 1.1010305126828532, 0.3029635656745203, 0.4575433161470198, 0.26182792299697477, 0.19262358486171693, 0.1991419205742498, 0.2322152692584261, 0.21810350068394216, 0.18188666342006576, 0.3340633952569577, 0.19156885032932605], [0.06209434888836357, 0.024998645981653564, 0.04375205510446141, 0.024752484694603952, 0.04112545370815262, 0.07760766382899977, 0.028514010876777674, 0.046204394480634126, 0.030191829615843394, 0.03027948922657919, 0.03446140807242163, 0.08500368349374303, 0.030768670840188864, 0.024320813301470012, 0.08273336660837935, 0.16779351078214186, 2.55673227771636, 49.918828472014404, 49.31825476308023, 46.52227555551837, 41.138877407197036, 23.713137988121282, 57.036212336632516, 72.82887489564958, 19.612445100661247, 4.670484815874408, 39.18291299573837, 70.49629626735565, 62.50190573353922, 60.43350265872095, 60.41103140000374, 57.96776740781723, 51.630970508821555, 8.037813623105327, 0.5310641613698776, 0.34043117937061096, 0.3499711803611248, 3.0637170085983896, 14.706588656671586, 40.66998943205803, 58.37301884928058, 67.1477766959898, 63.812138188269834, 65.26696097466254, 57.29080946214738, 54.95589702360092, 51.62971535036641, 49.47762066318143, 50.82321720738565, 53.964961190377515, 54.84350542868338, 54.36784744262696, 51.59667330403482, 51.58030917567592, 53.75715009627804, 52.60398503272764, 55.37537097930909, 54.42529055380053, 55.72767434581634, 55.23713096495598, 54.15517653188398, 50.019217614204656, 49.86469584126627, 47.25043219904746, 46.330722685783144, 44.82237915838919, 45.47109603881837, 46.16967016650785, 45.63092085622972, 44.24136238713419, 43.588217150780466, 44.53708948627595, 44.71481992352394, 45.19511022875386, 44.91246815650694, 43.25365858693277, 45.37289950155443, 44.25720484026017, 43.6997458242601, 43.16523659613825, 44.9782149253353, 43.579838968092396, 43.41809611166678, 46.987166635451786, 47.143986917311146, 49.750837279904275, 50.907505020018554, 50.3721171809781, 52.94494490469656, 52.75011293349728, 51.661564996165616, 51.16288661956788, 50.194398510840635, 50.78640968568864, 49.69887764223161, 45.50507553162114, 42.71333248384538, 42.08516882311913, 41.855149269104004, 43.36433610608501, 43.8044927197118, 47.30649463592037, 46.72416387065765, 44.78408505839687, 42.81191733575637, 41.178069729958814, 40.644474414087114, 40.602591345387125, 41.25332432408487, 41.43824054348854, 42.76864574801537, 43.58300824319163, 41.84837925818659, 43.53391193574475, 44.71900901486797, 43.00920863305369, 45.2579426765442, 46.53325819200086, 47.850390095864576, 46.1944713131074, 47.05631017684937, 47.84724827735655, 46.70875680062079, 48.13633872616676, 48.62611724484352, 50.28607999124835, 51.58224290417087, 49.19484130797848, 50.84183277622346, 51.18766030957622, 52.72304465693813, 52.7142075569399, 55.45477936344763, 55.47677993774415, 58.46049554886357, 58.155660706181685, 60.40137060226933, 53.69145431826192, 40.95845622401084, 18.057713662424398, 4.448882668249069, 0.4149236385860751, 0.6402929776137876, 0.3670088225795377, 0.3356967253550407, 0.677308201068832, 6.55743855622507, 45.351903054022024, 54.064283447880904, 56.88079626329484, 50.76490333003383, 57.471791544268214, 59.422723554795795, 56.445695584820164, 9.74744583329847, 6.7109674792135925, 47.86592268174695, 44.08180036852437, 20.84476555547407, 35.30746613779376, 24.983485821754705, 32.06289329836446, 42.95074178326515, 49.870959866431456, 1.4659583953119095, 0.06267645313674886, 0.05706095204298055, 0.026977073791767323, 0.08919599240705853, 0.07933126972807993, 0.0234694559607775, 0.040315503419767466, 0.0407135090790689, 0.0174343723413204, 0.03862108164016278, 0.04089068606375687, 0.03282307542019314, 0.004251507878859318, 0.02570046487474634, 0.044820583049928954, 0.0492566266667939, 0.10658523067831994, 0.042964359670276606, 0.08741622460224936, 0.056552085800156485, 0.019462258787825704, 0.0752305006608367, 0.035117903288694165, 0.03488658687039729, 0.05426629393872234, 0.0847469597694374, 0.16188104336540546, 1.5792346072773782, 56.01197950301632, 56.41703482597106, 43.51087585572274, 50.514114825956284, 29.179103989754957, 57.30229416201192, 65.29480588051581, 30.370072857026134, 7.967088385935753, 40.74264349475984, 77.70644418654904, 66.7399678691741, 66.53649883885538, 65.99943222538118, 62.749117036019605, 58.611420508353945, 10.094537350439257, 0.7867026148784546, 1.833250731710465, 0.3621632551714298, 3.0753946400457814, 18.863609721583707, 49.546705369026434, 63.79378541823357, 70.44673319785826, 64.96011003371208, 67.53478127141153, 60.24624870669458, 57.81142957748906, 55.08116575979418, 53.51901515837639, 53.9508524248677, 55.939282294242616, 55.78145788561914, 56.91705465316773, 53.38737257065312, 53.49596731124386, 54.87575123386999, 58.38306796166205, 57.66764725408247, 56.95000648498536, 58.74757774414555, 57.079072075505415, 56.67206733457504, 54.41156618056759, 49.99290243271859, 49.101108427970644, 48.53318452835084, 44.6631387741335, 48.49960903967581, 48.39754896779215, 48.01698100182318, 45.47553616185343, 46.17339641817155, 45.25813487268264, 49.69300977645382, 46.65738944084414, 49.456773265715576, 47.34756969636487, 48.19048312402541, 45.56452297395276, 45.871895590136134, 46.9234202754113, 45.67727150455598, 47.60785818099976, 47.70977704755722, 50.11510779780727, 52.70911239808606, 53.136752728492986, 59.03152596565985, 60.543721260563025, 57.60740749297604, 56.450684839679354, 56.24101846448837, 58.03405938609954, 55.657083449825166, 55.33474306906424, 53.07124522424514, 52.02433716866278, 46.30571365356446, 46.751361585432484, 45.52980607555759, 48.271009383663056, 49.022449216535016, 50.10681982963316, 50.56243450410905, 47.83565767349736, 44.30245330256801, 42.69511307439497, 43.81935458029471, 42.114598366522024, 44.218887206046816, 43.55160966996224, 46.29312284531132, 44.66745338132305, 45.70916429642708, 44.0377599962296, 46.572364222618845, 44.17452519939792, 47.418364555605, 48.763066799409934, 50.75709389102075, 48.10565010193856, 50.274128529333304, 50.85765169512842, 50.365884534774295, 50.64073285748882, 52.40771355167512, 53.90003419691517, 53.848274600121286, 54.03906653004309, 53.98250987452846, 55.63825215062788, 54.150053916438935, 56.41384201665079, 57.28077211687642, 58.693609852944654, 59.0943701805607, 59.628353811079464, 61.68831594528691, 57.90386807534003, 45.32032797413488, 21.62667828221475, 6.010533657766158, 0.6349403519303568, 0.413112698663627, 0.5764994878442057, 0.6450657666690889, 1.3766287435447018, 8.167165546647965, 50.37967558830015, 58.99080391853087, 62.92145029191048, 54.251906102703465, 61.64520125235281, 65.32196044921875, 60.096449467443655, 12.409915404935038, 12.9830599792542, 43.3558363299216, 48.02863044123496, 21.007265429342947, 36.286599559168664, 28.367598941249234, 25.6480686895309, 50.863864729481364, 56.236852907365375, 2.2582440751214183, 0.15957914833580295, 0.09454250470885346, 0.05702612568594276, 0.022215528991974653, 0.03234643466590393, 0.0542876371482928, 0.05569761431205177, 0.10815270019755249, 0.042527674231678254, 0.013114645769218765, 0.051415615655001135, 0.17445709676511828, 0.06962301284675637, 0.157802069499608, 0.1420339115805203, 0.17998371633791155, 0.32448735749048574, 0.10275030944256053, 0.30863329047156923, 0.11277498361924965, 0.11988961152852544, 0.17350841944496478, 0.19760862623731937, 0.17245985958124363, 0.17803687241769608, 0.24715301851111077, 0.7100144557414517, 9.073404169851734, 74.89853705129316, 63.91493958811607, 62.13740771816623, 58.30385569603213, 37.10417447551605, 68.23313574637136, 82.7093175149733, 27.79601154788848, 8.824416033683285, 48.0697564924917, 81.68204876684374, 69.97587619289276, 73.3938923189717, 72.76305752415811, 67.90219753019272, 62.31932724675825, 10.878887830242034, 1.4900549861692614, 1.69748168799185, 0.9141849161636446, 4.602421397163022, 22.68209788107103, 52.90119478779455, 64.99995739229264, 73.20795628332323, 69.07255434220838, 71.47506098593436, 62.42667075126403, 61.55704990510018, 59.53704887820829, 56.097632300469186, 57.60262220136581, 59.95267498877741, 60.800232502721975, 60.25163804331134, 56.56188011169434, 57.911469628733975, 60.10378429966589, 58.878035776076786, 60.72573884840935, 59.728244812257834, 61.32821882924726, 61.258557534986934, 59.654829809742594, 56.114631852796, 53.777475818510986, 51.376471442561, 50.609542169878566, 47.35304140275525, 49.03116080068773, 50.36235047924904, 49.67745757872059, 48.776422469846665, 48.11511085879419, 47.153934048068145, 52.081741056134625, 46.811209109521684, 51.47751169819986, 46.80081875093522, 50.33801609469999, 50.6435412745322, 47.13082344301286, 48.9104655481154, 49.34398551141062, 49.45303916931153, 52.04654955094861, 55.70252803064162, 55.07955366565336, 56.42776250839234, 60.36459838190387, 60.85531434705181, 60.68806840527443, 60.22993556914791, 60.14478875744728, 59.30864534070415, 59.66727941266952, 59.87389810623662, 55.83944228387649, 52.71395652524887, 49.823220699064194, 50.604121454300426, 47.30873823165894, 49.25557528772662, 47.768345878970244, 52.620360928197066, 52.812247199396936, 48.99680868271859, 47.579330782736506, 45.33790019250686, 46.06571558983096, 43.492440715912856, 45.93393179678148, 46.671913977592226, 48.49108965166154, 47.35240205641716, 47.10056627950361, 48.21048328953405, 50.02271244602819, 47.39299858770063, 50.33978116127753, 49.53398512255762, 53.69131311293572, 51.29327797120618, 50.415612343818914, 53.08745245779715, 52.37435771572975, 52.86091204612486, 54.96556958844585, 54.51019417855048, 57.1769077547135, 56.013218971990774, 57.044468925845244, 57.85541503660141, 56.91634470416654, 58.28423207806003, 58.838106047722604, 59.24101583419308, 61.07788139773954, 60.36928953662996, 64.06968493615427, 59.75668984074747, 47.401443450681626, 24.75027345841931, 7.921014264706643, 1.102141278886026, 2.2351511207319077, 1.5755974669610302, 2.082218643157713, 1.9291274321656076, 9.291316347737467, 59.0416927491465, 65.57028962719825, 69.65427321772422, 58.35992990001556, 64.35954416951826, 69.03678232623686, 66.74338817596436, 15.013552365764497, 13.119274089413306, 58.3578549661944, 54.800955557054095, 25.079803543706095, 56.081319162922526, 34.785128024316606, 47.55478851256832, 54.650685633382494, 75.0745730246267, 5.966960537818171, 0.3920062409052926, 0.20781880094399377, 0.27240906812010274, 0.11957340107689943, 0.12678587373586434, 0.1272089611138067, 0.2708114377192913, 0.23124845097622565, 0.06987253534457377, 0.1274369182365556, 0.16877454765621694], [0.05318106910694511, 0.0581007746739253, 0.039476679277516184, 0.016125880760110674, 0.05166809908264587, 0.042945107880739436, 0.06783840336626576, 0.0350273861700008, 0.043851864869676294, 0.10669232210925511, 0.038742069906044396, 0.043990266314076806, 0.025337281742043076, 0.0296020261838191, 0.017598862909982284, 0.053295763960528764, 0.013345555203305859, 29.898998160516065, 56.745011652669604, 42.67204169304141, 40.06716036027478, 28.506707760595507, 31.123462107873735, 81.55727817166238, 29.48131084442139, 3.939605066853185, 35.79923329814788, 69.76657067575763, 65.5468495430485, 60.346182853944846, 55.83379014845818, 58.02945060114707, 56.81605754360076, 8.169729796148117, 0.45350502155000166, 0.7313646520337751, 0.2388092484926024, 0.24222871258614526, 9.605970844145745, 42.603941502109656, 60.1192972736974, 69.53377016129033, 65.97809453164378, 63.318507902083866, 56.661982920862016, 52.66555055495232, 50.96733685462706, 50.66482013271701, 48.460557922240234, 51.51299345877863, 51.44621118422478, 50.32412698191982, 50.721435623784224, 50.77760004228162, 51.234438496251265, 52.11628537024222, 53.38962401113203, 49.16734549307054, 48.62927083046206, 51.17120988907353, 48.66696088544784, 46.20615213148056, 46.643406191179835, 46.29125971947947, 46.28562719591203, 48.16917288687922, 47.68271269336824, 48.097558252273075, 46.67283573458272, 43.36072752552648, 43.44050853483139, 43.67086541268134, 44.013523670934866, 46.584841282136985, 46.63369440263318, 44.185586283283854, 44.60030632634317, 45.07421493530274, 43.97649257413803, 43.395263994893725, 44.371173227986986, 45.692988441836455, 47.104924032765055, 48.7565399754432, 46.28937305942659, 46.595682713293264, 53.44754565146662, 51.00001019816245, 53.78881539067915, 54.76061790220199, 54.53106903260755, 55.10140518988333, 53.031354719592684, 50.416624315323375, 47.5189458939337, 43.58120395291237, 40.03543623032109, 42.656379668943345, 41.05406007459087, 41.68243554330642, 43.101282350478634, 45.44795013243153, 46.19595396903254, 42.13489663216376, 43.749010793624386, 40.736481451219134, 41.69211987526187, 41.47600904587777, 40.52671309440367, 42.10930708915957, 45.153364443009906, 42.311313075404016, 40.76818989169213, 41.96401465323664, 45.281320002771196, 43.39032965321695, 44.07238668011081, 42.72047904229934, 42.035939155086396, 43.5645378020502, 44.894664518294796, 44.84880416624008, 46.52642934553085, 45.28498349651214, 47.73670804116034, 49.30271825482769, 47.57244310071392, 47.60777581122614, 49.116433128233886, 50.71167284442533, 52.717792603277395, 55.60388826554822, 58.09357743109427, 56.00565664229855, 56.41955298762168, 59.785154481087964, 60.30590403464533, 56.23168714584843, 46.664767419138265, 27.47335541632868, 7.820089228691594, 0.3315412499491246, 0.18857546901750952, 0.9700144010205424, 0.6609995374756475, 1.4025976532889952, 16.7269201432505, 49.540660996590894, 54.97038625901746, 49.54689364279471, 49.46770883375599, 41.64929151535034, 63.983965458408484, 32.67399072647095, 8.481269440343304, 21.14912775255019, 67.10503855059224, 38.635452101307536, 24.87530489121714, 35.00225082520516, 43.97522564857237, 42.62471829691241, 49.460825074103575, 37.99376410822715, 0.1647854359039376, 0.030553277559398167, 0.010018598141839669, 0.036718889154613986, 0.019646845757961273, 0.08082871881103323, 0.06881818385614503, 0.012169228153183095, 0.007178241935288234, 0.022680151741951707, 0.03710814992025976, 0.08049681121783872, 0.02344747689822989, 0.03536918395829778, 0.03210445621892089, 0.03734843339771032, 0.016790684199922027, 0.05651641674640198, 0.049962676280448516, 0.022471749013470068, 0.0759545686624704, 0.0644959694135093, 0.032897171444229545, 0.02259097527712584, 0.025633037646090793, 0.010099495111423875, 0.0687294249092379, 0.02371118159874553, 0.14608371281816115, 30.07588136580683, 64.52686463632892, 39.606842763962284, 43.873483288672666, 35.528440706191525, 34.728775332050944, 79.1119941588371, 29.53421969567576, 7.583850756768258, 39.29613613313244, 76.1695497266708, 71.06386323128977, 66.42627239227295, 62.71959727810275, 65.13982126789709, 63.66219774369271, 9.547281399849924, 0.5634536233640487, 1.3548315196268021, 0.516626161913718, 0.0693291108754854, 11.143834129456552, 44.42015578669887, 64.58378999463974, 73.23222006520918, 66.45179917735439, 66.4929840641637, 59.4402918507976, 56.40121982943628, 55.17881316523398, 52.965709932388805, 51.845535924357755, 52.87695061775946, 55.107798653264204, 54.83084794013731, 52.68107137372417, 52.39640143609817, 55.960125769338305, 55.213180972683816, 55.93024123099543, 52.02708675015358, 49.486857844937234, 52.468396540611025, 50.92539887274466, 48.65113412180255, 49.45123880140243, 47.10482205114057, 47.71540172638432, 50.003139818868334, 49.69392368870397, 48.98123295076432, 49.8497437661694, 46.13231743535688, 45.992806573067945, 46.89117447022469, 44.282817917485396, 47.776853499873994, 48.023896140436975, 46.52452307362711, 46.51614096856887, 47.12364158322735, 47.752197480970814, 44.711466297026604, 46.03139092845302, 48.01036788571266, 49.86485665844333, 53.11723109214537, 49.337717563875266, 50.12843993402297, 55.75901800586332, 56.339136554348855, 58.17275439539264, 58.80822150937973, 58.43091695539413, 59.0399355273093, 56.70803939142535, 52.991028831851104, 50.647287138046764, 47.07613775807042, 43.12754261878229, 46.35594352599114, 43.70674333264751, 44.54950771024151, 46.88135285531321, 46.80362324560843, 48.475941458056056, 45.066366272587935, 44.82861964933334, 42.70868839756135, 44.928326299113614, 43.05984250960812, 42.73705890101772, 45.64149556621429, 46.095745255870206, 44.59731355790169, 43.92207361036732, 45.620961958362216, 44.24324904718707, 44.93095820949924, 47.811295832357104, 44.443289925975186, 45.09614490693615, 45.03785456380537, 47.10744611678585, 46.6354477021002, 49.81390506990495, 48.06604593030868, 50.7458366886262, 50.24271818899339, 51.61611649297899, 48.930363731999556, 53.75852292583835, 54.4621176873484, 54.2646812623547, 57.71532758589714, 61.37629139807917, 60.08440779101465, 57.697351363397416, 61.03256625513877, 62.98711469096523, 60.463885338075706, 52.41649966086111, 33.50057924947431, 11.667735307447373, 0.9566376478441301, 0.28887536196458724, 0.7371296168815705, 0.5913311952064114, 1.6872537400453322, 18.82566667372181, 56.45757644407211, 61.14678567455661, 54.55245379478701, 53.78640705539335, 48.271527136525805, 69.03514277550482, 34.535712349799375, 11.52169369882153, 28.634033779944147, 62.67480381073491, 48.26122307008313, 23.407312746970888, 40.52845854913035, 50.558143431140536, 44.581153392791755, 58.6788970424283, 44.575575782406716, 0.26188096692485197, 0.04098904409235524, 0.024371840502886523, 0.047885716156733614, 0.05334926371072089, 0.03255098397212644, 0.008556410170821174, 0.03936489172760518, 0.026172434407917243, 0.03349075552016016, 0.017439403623763113, 0.04395100047751781, 0.15942519530653954, 0.16271345918217014, 0.12262322008609773, 0.13015846090932048, 0.15312531722649453, 0.11674361784131297, 0.16833021666013426, 0.11700542838943583, 0.2151370703453018, 0.18517025415935826, 0.15330741632609599, 0.1276157997668751, 0.08902956746638784, 0.1786195742146623, 0.12939445674419403, 0.1449532275118174, 0.26462972104068727, 57.26527875469577, 73.06550364340507, 59.15634362928329, 58.80236148834229, 43.80168430266842, 41.58598053839899, 96.20305538177492, 36.27593855704031, 7.817282772833302, 44.45064829241845, 83.32624358515586, 78.07945374519595, 70.84315146169355, 68.5216417620259, 71.49223312254875, 69.03280504288213, 11.540355355508867, 0.9471686172389215, 3.5697907690078985, 0.8724932468706562, 1.0310269916249861, 13.791783086715208, 48.82058443561677, 64.65598514003139, 75.05914242036881, 70.73221898848011, 68.18382370856501, 63.93376696494318, 59.374427410864065, 57.0758714214448, 57.88547215923187, 54.67431399130053, 57.073223821578495, 59.20827581036476, 57.36212599662043, 54.526456325284904, 57.69128737911102, 57.21963413300053, 56.492046233146425, 58.14803169619653, 52.57654805337229, 53.201507137667754, 56.20154373107418, 52.97852431574176, 50.47644438282136, 52.06757345507222, 49.37370138783609, 48.74658499994586, 51.63743065249536, 51.839683748060665, 51.000018042902795, 53.33820958291331, 47.81728136924006, 48.41796098216888, 50.117276868512555, 47.25625691875335, 50.248437004704634, 51.81356076271304, 50.09598232084706, 48.51066620119157, 50.17939152256135, 50.26724869205106, 47.354108287442116, 50.89185868540118, 50.9873370201357, 53.483792274228996, 56.51615704259565, 52.682083345228634, 53.75261583635884, 59.900731040585434, 60.4305334245005, 61.289779601558564, 62.20538239325247, 61.41784891005486, 64.07714528422203, 58.47660864553144, 57.76721269853654, 54.40967167577436, 49.62115979963734, 43.96944407493838, 49.01608320974535, 46.350452207749896, 46.315241090713016, 48.013003718468454, 48.37645053863526, 51.69652900388164, 46.1389736975393, 48.45635706378568, 44.887302229481364, 47.40583650527462, 44.93692021216116, 45.70700699283231, 47.300924870275686, 50.10608242404077, 45.10251091372582, 44.377005792433216, 46.94434219791044, 46.76992616345806, 48.36274969962336, 50.223478963298184, 46.997043163545676, 46.56568834858556, 47.54142107502107, 50.37133270694364, 49.54722312188918, 51.959488622603885, 49.19226823314544, 51.80256243674986, 53.77907614554129, 51.386014569190245, 52.371051157674486, 55.12450795019827, 57.80840150771603, 58.343122543827185, 61.04238394768008, 62.672564137366514, 62.818790097390455, 58.628388681719386, 64.31090677938154, 64.17357675490841, 64.0247541858304, 53.96891101714104, 34.20906912895941, 13.102909961054403, 1.3950923205383363, 1.2182234564135153, 2.1872847214821847, 2.181498980329883, 2.403389177014751, 22.10964168271711, 62.33957844395792, 65.18102968892744, 58.776866082222234, 58.74774248369279, 52.678533600222686, 75.51836567540323, 42.22442473134687, 12.42934584617615, 30.213168244208063, 75.79440639865014, 47.176683795067575, 32.82075209002341, 53.6371922492981, 53.280417380794404, 57.95518836667461, 61.75971484953358, 60.799212686477176, 0.6291735484715432, 0.16068590023825247, 0.12126952740213565, 0.1477627170782897, 0.15582818267566545, 0.17687666289989026, 0.09948683617215964, 0.14668555149147589, 0.12142574805165492, 0.25963467455679373, 0.15633738599717617, 0.17697352705703628], [0.027719807525676106, 0.018745912952468764, 0.006643715577440397, 0.110161796422495, 0.04888071881366834, 0.040163764384605234, 0.030322135426104072, 0.05945675029990174, 0.018721233429988066, 0.04250697453596419, 0.049053054122674855, 0.02539036588953628, 0.06359921370242393, 0.12792272523285883, 0.03202485393792872, 0.02204942389301235, 0.23616710317230996, 7.911303456752532, 55.52109879832114, 45.10028300746795, 30.31754251449339, 38.036247299563506, 22.81409348210981, 57.68185015647643, 75.5855715659357, 10.695320906177646, 20.580431146006433, 65.84148622328236, 63.69486716485793, 65.16282989132789, 63.4510761691678, 59.351073618858095, 60.70722918356619, 16.3254939932977, 0.5736535631360546, 2.4578047087115626, 0.5804809387172423, 0.2042297249840152, 4.074054600731019, 41.362448584648874, 61.42931007569837, 71.4796030905939, 63.453253084613436, 63.56727638552266, 54.55383446908767, 52.40537581905242, 50.349712602553836, 52.43267943782192, 47.907829284667976, 47.797296893212106, 46.511798904788115, 49.1994853942625, 49.29186897893106, 49.979821328193914, 49.399177182105284, 49.97954676228185, 48.563802549915934, 50.7140144994182, 48.754618014058764, 47.95474475429904, 46.37571619402978, 45.54748419792422, 46.51150472702519, 44.20622579513058, 46.827498712847316, 49.976432400365034, 49.238865990792554, 49.687083075123454, 46.41024874102685, 45.42563184615105, 45.79214203742243, 45.072532238498816, 44.93325671842022, 47.4808753690412, 47.530607100455995, 46.61484349158503, 44.48166247337095, 43.86978841597035, 44.254953399781265, 44.75766789528632, 44.56515796722905, 47.43812153416295, 47.88943336855981, 50.098696601006296, 47.857803375490256, 49.62266206741334, 50.81720029154132, 51.47114569141019, 54.92497305716238, 54.05118273150537, 53.918767436858154, 54.182515451985026, 53.366431036303126, 53.41916338089974, 46.551395231677645, 43.586416782871375, 42.79229371778427, 43.544486645729314, 41.714143983779415, 41.779267095750384, 42.87434577941895, 43.07910134715419, 43.567965953580796, 41.106631602010424, 41.96413232434181, 42.846230230023785, 41.83911069746941, 40.28900961722098, 43.624604978869044, 42.532236652989546, 44.92946770883376, 45.01652079243814, 42.80785768262802, 43.72027943211217, 42.89973920391452, 43.02082277113392, 43.79059183982111, 45.22508105924053, 42.37976627965128, 40.670930800899384, 40.97158831934775, 43.79152144155195, 45.25516171609202, 43.82236696058705, 47.27638652247768, 46.60068373526297, 47.52165625172277, 47.32290191035117, 48.924911637460035, 51.42980390979398, 52.462030533821356, 56.79410403774631, 58.82809615904286, 57.60396365196475, 59.857553589728575, 56.48929272928546, 59.40182124414752, 58.57388342580488, 59.84768098400485, 51.28914771541473, 26.416513958284934, 3.9395898676687673, 0.04082138191968684, 0.19102298203975926, 0.014056378502338646, 1.0623906312450286, 19.708754977872296, 51.2909088596221, 52.023599763070386, 59.81953797801849, 62.84961992694486, 61.93939078238703, 63.449726873828524, 28.90162964021006, 15.85068912275376, 44.42276808523363, 51.35800884615991, 28.504811294617195, 33.324507974809215, 37.26226952768142, 54.571904828471524, 42.54620029080299, 58.750872535090295, 20.49730239375945, 0.706631534041897, 0.1937345349259915, 0.10050865190644419, 0.05663468156971278, 0.014431966513755822, 0.0481521500454795, 0.06393413585160049, 0.028189609030021295, 0.04586399097235934, 0.03973283226631823, 0.06495979734726491, 0.09378066857255275, 0.02797187343540211, 0.04453792341894681, 0.0464518370497371, 0.012791871859301484, 0.03267461524134682, 0.0362794611212467, 0.04457796300430933, 0.09063635261789446, 0.033075781013335914, 0.08846030285161349, 0.026196238674944448, 0.04370009902143671, 0.09786401680039783, 0.09742543146374727, 0.0506419281385118, 0.030436261459403945, 0.27593776102988954, 5.040369226086525, 66.71730441431846, 47.01076361440843, 32.96017469898347, 46.86282357861919, 28.23607990818639, 61.50145423027777, 69.77569410877844, 12.334786326654497, 23.300941990267848, 70.88810966860864, 69.5883224856469, 71.4598108107044, 71.01448843556066, 63.37280919474941, 67.14771393806704, 18.248623263451364, 0.4537464618202179, 1.5267850410553718, 0.5209106771695999, 0.2747239713226595, 5.728475528378641, 45.15017163368964, 64.23094926341888, 72.8002651276127, 66.37597976192352, 69.14215287854596, 57.83319873194541, 55.47189658687961, 54.224053352109856, 54.599428099970666, 50.177889254785356, 49.28143155190253, 50.58770633512928, 51.921837791319824, 51.730112337297015, 52.57555177134853, 51.5492832276129, 52.9986656865766, 51.82506899679861, 52.40798027284684, 51.82421784247122, 49.75165313290012, 48.32314552799348, 47.271495326872795, 46.20781913880379, 46.474646214515936, 48.53935049426172, 52.08930730819703, 50.89953084145823, 52.133045657988525, 50.17094273721018, 47.79809705672726, 46.354429491104625, 47.597479589523815, 45.66110741707587, 48.737147777311264, 48.40231072518134, 45.59021449858143, 44.57293210491058, 44.940568016421416, 45.60573139498311, 48.49629855925038, 47.17458924939556, 50.78813945093463, 51.60969557300691, 52.658180421398534, 52.34970169682657, 54.299233421202636, 56.63273380648706, 57.23881844551333, 60.03562527318155, 57.77501821517945, 55.13068568321967, 57.35655623097574, 56.97767488418087, 57.359851021920484, 50.01456960555046, 46.939855006433305, 45.5437736357412, 46.063868153479795, 43.089707436100134, 45.485310708322835, 46.20454395970991, 45.93169996815343, 46.63786780449652, 45.91333543100665, 45.09428178110431, 44.737118597953554, 44.29319258659117, 42.37024668724307, 45.15461960146504, 45.70968989403018, 48.382043838500984, 45.442360754935976, 43.420402465328095, 45.69113708311512, 44.64034980343234, 44.94694186795143, 46.15778538488573, 45.20530839120188, 43.94221890357233, 44.088672361066266, 42.913781289131414, 46.34775361707134, 48.23983438553349, 47.66559546993625, 48.965272826533166, 48.563802549915934, 49.6687420721977, 50.15789693401706, 51.687201607611875, 52.97880280402399, 56.86020774226035, 57.46297797849102, 62.02745975986604, 59.39937368515999, 62.60946496840447, 59.97755066041024, 62.36410502464541, 61.32474360927459, 62.22245254824239, 53.91593548559374, 31.177692797876176, 5.705330602584347, 0.1622838064307167, 0.34600783980661826, 0.453013867259987, 2.123622937548545, 23.31396229805485, 55.34059132299116, 59.5443444867288, 64.90654614663893, 67.00271960227721, 64.39246854474469, 66.34282004448676, 32.694155631526826, 22.41034430842246, 41.19551643248528, 52.19521130284956, 38.43610940441009, 28.039937865349557, 51.58986799178585, 54.20324125597554, 44.16539392163677, 67.79697602795017, 21.26838545645437, 0.6505877284273025, 0.12917907878516183, 0.04859179258346558, 0.05348868022162107, 0.04314212271222665, 0.04336964316485871, 0.06348115189241306, 0.03663593332373327, 0.029121478381116065, 0.062193235517629696, 0.04511224804446102, 0.1211497342334159, 0.14567888131545437, 0.15662955660973826, 0.1514022169454444, 0.20899669177109198, 0.17545987521448445, 0.2068368754079265, 0.11777418229969279, 0.27549781205673374, 0.10195438239362933, 0.1494981973401962, 0.11797236158482491, 0.23346527960271607, 0.18846659260171075, 0.18066801671539584, 0.32498871607165186, 0.45320511344940434, 0.7664060039866356, 18.20620871359302, 83.67706821810815, 59.51200062228788, 48.917765079006074, 56.925374000303215, 34.78733239635345, 71.60144759762672, 90.3024378130513, 16.793620048030732, 27.718884022005145, 81.07891375018706, 74.55846755735337, 76.41881635112148, 75.32940941472208, 69.5403911221412, 73.67852303289598, 21.94907553734318, 1.2235877879204289, 6.250522896166771, 2.266882605129673, 0.9356980133921871, 7.2348103119481, 50.91108614398588, 65.28106189543202, 74.2347151233304, 67.87159519810831, 72.82873369032338, 61.30280579290083, 58.00903466440017, 56.96045567912441, 58.19800661456201, 52.66037694869503, 53.52253352442096, 52.717404288630334, 54.54853926935504, 53.086479709994414, 55.263705022873424, 53.94421969690631, 55.06159313263432, 54.99607386127595, 56.74222284747709, 54.42101124794253, 52.76249193376111, 51.01509171147501, 50.717760362932765, 48.59036091835269, 49.92337057667394, 51.22647216243129, 58.335403319328066, 52.732944719253055, 53.15627044247043, 52.065820155605195, 49.02863871666693, 50.95783687406971, 49.01222751986597, 47.67543277432842, 52.09505750286964, 51.32421370475523, 49.18934998973724, 49.24413373393398, 49.0764053406254, 47.99224653551656, 51.49796685864849, 49.11990834820656, 55.447260179827296, 53.51886218593967, 57.425080037886104, 57.34578932485273, 57.34624824216289, 58.87456840084445, 60.335078623987016, 63.970127336440555, 60.29329753691151, 60.0000846770502, 60.11124072536346, 59.42178610832461, 60.785296117105794, 54.30220657779325, 49.2211486447242, 49.607690380465606, 49.53015296689926, 47.14300632476807, 46.08813978010609, 50.14215646251556, 48.92918702094786, 48.55664030198128, 46.75821004375335, 44.9754810333252, 46.031281102088194, 45.9543595006389, 45.12390744301581, 47.20907080558039, 46.89748948620212, 51.11037785007108, 47.97211693179223, 47.12761102184173, 48.53786783833658, 47.017725821464296, 46.49870211078275, 48.65940640049596, 48.076969731238584, 48.023162657214755, 46.268568808032626, 43.916703885601414, 47.17200832982218, 50.38794786699357, 48.28002299031904, 52.6772274509553, 50.10713361924695, 51.342817506482525, 51.45595827410298, 53.42674140007266, 56.04225627837643, 59.652260657279726, 62.1820992039096, 65.06199752130817, 60.359362017723825, 64.66776009528868, 60.39823270613148, 62.46269772129675, 65.48489962854694, 66.16523865730532, 58.242749091117616, 30.597248692666334, 5.586532796582868, 0.5391830386173341, 0.7256030579728465, 0.5538774017364748, 2.7058117620406614, 27.48432824688573, 60.720290676240005, 62.12366373308244, 68.36793976445352, 72.88589831321471, 71.65516837950676, 71.08683263101886, 37.24832942408901, 22.449973975458455, 53.80772121490971, 59.70314948789535, 35.76308865700999, 46.6186874143539, 54.330380962740996, 63.19928746069632, 55.62999556141516, 74.08726538381269, 37.71638585675148, 0.839676920685076, 0.41772791875466225, 0.31809505856325554, 0.27757323617416046, 0.16876808187413603, 0.11579180722154918, 0.172708056746952, 0.16407240722929278, 0.10579373161759108, 0.18062732212485808, 0.1057134839075227, 0.31170364829801744], [0.015855269776957653, 0.01855553052718601, 0.06662017034907496, 0.05924699542623374, 0.07503527847509231, 0.05631003649004045, 0.02799609905078767, 0.06714534660380694, 0.11166782569020026, 0.019364295294508338, 0.010538552549757786, 0.04357019732255609, 0.07561955841318255, 0.031103849628820058, 0.02448119763885775, 0.005757346582193409, 0.05090607142436409, 0.223343113076783, 41.73958055434689, 51.072523055538056, 26.291349164901245, 41.254905039264315, 29.29116806676311, 39.64292464717742, 76.71239006903865, 26.06055494277708, 10.858710177483099, 58.462229236479736, 65.29973237745224, 63.25866822273501, 57.836983819161695, 61.890976967350134, 62.540635216620664, 33.43583660741007, 0.3011030445416128, 0.7670439407229425, 0.38317631149003584, 0.24542115418420685, 2.710599014835973, 40.13045957011562, 67.26355721873622, 69.667766171117, 66.56082537866408, 64.27466800135952, 57.4614364870133, 51.00920815621653, 51.88262977907735, 52.52046600464852, 49.45556125333233, 49.74640107923939, 45.09129685740317, 47.73704536499516, 46.3187280777962, 48.80841332097208, 47.56800297767886, 47.80315691424955, 47.24482713207122, 46.483169524900376, 45.92124685164421, 48.07275318330335, 46.17232561111451, 45.427114502076186, 44.10564837917205, 45.25199636336296, 46.96709194490987, 48.521570390270604, 51.412059107134425, 50.085501747746626, 48.95292912760089, 45.752945792290475, 45.35852009250272, 44.925470813628166, 45.80452103768626, 45.344109304489635, 46.2255286401318, 43.79057222797025, 43.01841835821829, 44.664127211416925, 44.087672156672326, 45.97582663259199, 45.61943615636518, 49.043073038901056, 48.849355020830714, 48.49929132769185, 49.55177307128907, 49.02343765381844, 51.014405296694854, 53.72202527138495, 54.0083896729254, 53.18036556243897, 54.69015252205634, 54.39974023449806, 52.334420142635224, 53.79799373688237, 50.987517449163626, 46.24332835597377, 41.12520010240617, 41.96855283552601, 42.92872944185811, 41.908575873221125, 42.92498357834355, 43.74825377618113, 41.69410851693923, 42.42439108510172, 42.8934791011195, 42.53942243514523, 41.91426723234115, 40.89316837249264, 43.18799026550786, 43.285661205168694, 44.485828030493956, 45.30118680769398, 45.67943273052093, 45.15487063315607, 49.550286492993756, 49.619532016015825, 49.43829105746362, 48.806369766112304, 45.09206564195695, 43.6522106201418, 41.277493969086684, 42.60789917361352, 43.988710757224794, 42.28538620856501, 45.67882868551439, 45.83495863022343, 45.44967597530734, 44.58564058426888, 49.507889593801195, 49.850422336209206, 53.39850033483198, 56.41470101571853, 58.762529819242424, 58.76662085133215, 58.90494323545887, 56.33038966886459, 59.13951666124406, 55.892892422214636, 62.416904049534956, 61.34867398969589, 56.57805596628497, 22.311630018295784, 1.1872176104976286, 0.34886347850964916, 0.6083102163768584, 2.611401292585558, 21.099647052826423, 46.2363112357355, 53.330725700624534, 53.25170170876288, 56.05680434934555, 60.36699495007915, 55.79832015498992, 16.381326971515534, 20.21649402956809, 73.48752713972523, 41.08152058816726, 19.619740709181755, 35.155509594948064, 31.35837481867883, 39.91329754552534, 45.3573473038212, 57.12389692183464, 2.197193118833727, 0.252632845433489, 0.22406925717669152, 0.026561961389116706, 0.05222983305312453, 0.03602021313723057, 0.07028654458061342, 0.04630195194735162, 0.07241862090004068, 0.09148337007049592, 0.10868113998684192, 0.018561107647274772, 0.035448094844938285, 0.022833105026473923, 0.04311982189275084, 0.0670776857183345, 0.04515093548463718, 0.03825068962009203, 0.03894080077448199, 0.007366191552606442, 0.03322801417520931, 0.06725880422539289, 0.11130851513195424, 0.04408372137995978, 0.14439546953766577, 0.023011484769203013, 0.057597837951635165, 0.0201410299257165, 0.09048146496136343, 0.05905617824605396, 0.5424553985076567, 39.87255196417532, 61.54304312121484, 27.418271610813758, 50.247275983133626, 38.2004024136451, 43.31965638745216, 77.38304476584159, 29.765247298825173, 13.935252601100554, 62.57974516960883, 73.60611607951503, 69.039198506263, 64.07725903295702, 68.3432052981469, 68.76746454546529, 36.01616390289799, 1.0489774735704547, 0.4608321928929898, 0.31257928679547003, 0.06869538762276212, 3.7507243117978497, 44.42914193676364, 69.25723521940171, 71.46436860484462, 72.82352478273454, 67.36369532923545, 59.27519144550447, 53.29589113112419, 53.29858972180275, 54.24286896182645, 52.5700722202178, 50.99027879776494, 49.69222922478953, 49.75122951692151, 49.520688287673465, 49.80229485419489, 49.56573670910251, 49.32093374190792, 48.013678366138095, 48.0018328082177, 48.1659016301555, 50.96230053132581, 46.95180254597818, 46.4009056552764, 46.0692653348369, 46.49607804513747, 50.10635698995283, 50.047497903147054, 52.64597792779246, 53.577827176740094, 50.93962530935965, 48.46092662503643, 47.6582488706035, 46.231596546788374, 47.3473108199335, 47.22695289119598, 47.22291677228866, 47.03637276926349, 45.476128439749445, 46.7103139815792, 46.667830790242846, 47.61095685343589, 47.425636629904474, 50.798953425499704, 54.56524464391894, 52.31362765835178, 53.392389282103515, 52.903242265024495, 53.614332675933845, 59.24357321954543, 57.74062687350858, 57.790562568172334, 57.68602355833977, 57.54821500470562, 56.729479066787235, 57.881353670550936, 53.83662516070951, 48.166180118437744, 45.843674136746316, 45.87193873620803, 46.42981744581654, 45.21893078281034, 43.887960756978686, 45.74204552558161, 45.245112603710545, 43.01650816394437, 44.78953715293638, 43.96106589225031, 43.78791678336359, 42.862468842537176, 44.50172147443218, 47.04694355687788, 48.2791639912513, 48.20881235984064, 47.39397525787354, 45.97443419118082, 48.54920348813457, 48.90654317794308, 49.81427769507132, 51.47551913415232, 46.89725414399178, 45.359818397029755, 43.66888461574432, 45.8798344673649, 45.92254907854142, 44.976030165149325, 47.76753787071475, 47.63729556914299, 49.40893996146418, 47.094353245150664, 51.771081493746856, 52.91642535117365, 56.438631396139826, 60.21456772281278, 60.99688053131104, 62.42000272197109, 61.26446462446644, 61.208355119151456, 60.66942145747524, 58.48704215018981, 64.45468125804778, 62.70264871658818, 61.116928592804946, 26.363777691318145, 2.638047424054915, 0.2482816498846777, 1.0701890385920003, 4.553080922172916, 25.408984538047548, 52.2938314560921, 60.74519380446404, 57.817262141935295, 59.78679795419017, 62.48294891849641, 60.01153799795336, 19.505817428711925, 24.51888695839913, 64.53289331928377, 52.278969595509196, 22.2859404548522, 35.11716842651367, 43.110370482167895, 35.90476859000422, 53.341135671061856, 59.383178218718506, 3.4172485672658492, 0.39547361613762, 0.13220026908862975, 0.138915688580563, 0.04835700961731134, 0.017955245097137747, 0.04686602248599933, 0.07083147058203336, 0.0381642940544313, 0.06869297444580064, 0.11846740760149495, 0.044760069764790036, 0.07877244689171353, 0.14101368164823902, 0.1413859237706469, 0.10698718169043142, 0.1175687941271932, 0.1598345160844826, 0.11619127610878599, 0.17996281745933718, 0.1700967541264911, 0.18617715416175706, 0.18114066232115994, 0.16075117092940117, 0.18571538700451776, 0.2622226114955641, 0.10205021999295681, 0.0755025767871449, 0.1845326391799796, 0.24311198131932368, 1.1638782822316693, 66.4800480873354, 68.9487486500894, 43.37263191899946, 59.33171672205771, 43.37693475907849, 51.72173023223878, 90.03678352602067, 32.27202819239709, 16.481666103486095, 69.85213325869653, 79.59219424955307, 73.5550703540925, 67.52048030976327, 75.6113572274485, 74.20174367966192, 39.22749857748709, 1.7616012860690395, 4.272407879752498, 2.4593395811896173, 0.4069683977192448, 5.486505002744737, 48.32016060429235, 71.66378974914551, 72.10737059193274, 75.29769312950873, 69.51764137514176, 60.33289386380104, 57.00208771613337, 57.75539067483718, 57.337901438436205, 54.50823299346432, 54.14542159726543, 51.757565006133056, 53.475045388744725, 51.74957906046222, 53.19911449186264, 52.65972191287626, 53.4941630209646, 50.59319373100035, 49.43525514295025, 51.76413889854185, 53.517246169428674, 50.60905971834737, 49.710523159273215, 48.012748764407256, 47.55023071842809, 52.74167591525663, 51.50127733907392, 55.91476355829547, 57.06461814142043, 53.94213299597464, 49.81482290452527, 50.89248234225858, 47.07436092438237, 49.36220492086103, 48.203458324555434, 49.01660880734844, 48.180602673561346, 47.32705570036366, 50.025513018331225, 48.26295283532912, 51.32391560462214, 49.931721302770804, 55.4147005850269, 57.27364124790315, 54.77542092723232, 56.96029486194734, 55.796107938212735, 57.78778945246051, 62.77117252349854, 61.38432833456225, 60.47583679999075, 61.176744737932765, 61.72240526445451, 60.5166490616337, 60.21494034797915, 57.65277754875922, 52.35203942944927, 47.74861243463332, 48.666670630055094, 48.83004127010223, 49.97053315562587, 47.663873549430605, 49.15725323461717, 44.7611548823695, 45.641342593777566, 46.37091521293887, 47.24099889878304, 46.49912964913153, 43.41429141259963, 46.72949437172183, 49.73575184422155, 49.4142508506775, 50.9963192478303, 50.90328847208331, 48.3508570732609, 53.627904076730054, 53.88723942541308, 54.47364161091467, 53.46768309993129, 48.80733074680452, 47.353339502888346, 46.671094202226215, 47.57534957701161, 48.043115754281324, 48.25285273213541, 50.12054812523627, 50.85021880365188, 51.22337741236533, 48.698441828450854, 54.62941069756785, 56.415952251803496, 59.8963575978433, 62.23487469457812, 63.53938833359749, 63.66484534355902, 63.60224823797903, 62.318244672590694, 64.71888819048482, 60.77927527889129, 68.57398971434563, 65.45170068740845, 63.599714386847715, 26.088333168337424, 2.520349842886771, 0.4238250286829087, 1.3518742976650115, 5.4559036512528705, 29.1029001820472, 56.17114143986856, 65.50764937554636, 60.822229154648326, 65.5047115202873, 69.69819591891381, 66.4861983637656, 22.219203287555327, 26.41716311054845, 83.34896195319392, 50.95566780336442, 25.193544433962916, 53.10544436977756, 42.32317824517527, 50.63185653378887, 57.4787223723627, 79.92436408996582, 9.312131385649405, 0.8608825408643292, 0.6939361088218228, 0.23581370681283936, 0.18352816001542155, 0.19916642006606827, 0.1310508614105563, 0.2060069417160365, 0.17965288892869027, 0.21695570179050971, 0.2180412943444906, 0.24688465791123532, 0.13936291538899945], [0.08137561365841858, 0.008553912724188019, 0.0516080760937785, 0.040136836394066774, 0.11020139550730107, 0.06257970389279147, 0.027932688038075165, 0.03881184136374824, 0.03622828261746514, 0.024104267058353272, 0.011794856306345714, 0.07136801558156168, 0.034872682374571605, 0.058805062285354065, 0.07926249035423802, 0.13010874180303467, 0.24849777860987574, 0.5066418605706384, 13.274435208689782, 57.87371289345526, 39.34591885535948, 34.56764044300203, 38.887954681150376, 21.679932302044286, 62.679247856140144, 38.48165988922119, 8.666936793634969, 46.63416116468368, 70.50924008892429, 64.40046233515586, 61.75292914913547, 62.603240166941, 64.61376474749657, 39.3789844359121, 0.8917684480547906, 0.3271880932152271, 0.20856900020472466, 0.38342954951428604, 4.882057953265406, 43.22197760305097, 75.32394947544222, 66.47958524765508, 71.31924875320928, 63.78761160758234, 60.42850555912141, 52.088334560394294, 51.172825905584524, 53.52231387169131, 52.71398790421025, 52.13060202137117, 51.09901082131171, 48.11787612976567, 46.81037364467498, 46.36076411893291, 47.209400284674864, 47.50881833414878, 47.51358793627831, 45.45821889754265, 46.99650972120224, 45.64854014304377, 44.88130492548789, 43.74894411333146, 45.61768677926833, 45.88013648986817, 48.08700707650954, 51.10583574541154, 53.12436196111864, 51.79492558202436, 49.2742379250065, 46.41014675940237, 44.25394535064698, 44.432487718520626, 45.46160782537153, 46.71693494243007, 48.80970378075877, 44.46815775286767, 44.14323645253336, 42.43489519242318, 43.59881539498606, 44.20480981949837, 45.76549345447172, 50.17522204306818, 48.970975952763716, 50.70760926892681, 50.50524634699668, 48.44941054621051, 51.792387808522875, 54.105072175302816, 55.74054756472188, 51.93842549477854, 54.85719057821459, 56.13858968980851, 53.34090817359186, 55.40142336199361, 51.65009598578177, 48.330766693238296, 42.99167956075361, 43.93642164045765, 42.14907207796651, 42.208680337475194, 42.82545343522103, 41.876522264172955, 40.97341222147788, 42.63397901288925, 42.19095122429633, 43.455491988889634, 41.72780167671942, 39.63170274611443, 40.696728229522705, 42.89050202215872, 45.46147838715584, 46.943989184594926, 48.44636286458662, 49.07752321612451, 51.77957342516992, 52.78394729860368, 54.88919319645051, 53.17410153727378, 49.65531972146804, 47.28086194684429, 43.58688746729205, 43.72252695022091, 47.62093144078409, 42.85840918940883, 43.037347716669885, 43.43949264095676, 42.96818064105126, 46.236405372619636, 46.88846019006545, 50.12827127210556, 52.37623653104229, 54.824328960910925, 55.810546182817035, 60.63464964589765, 58.66370570275092, 58.90049919005364, 53.6330266921751, 54.70367293204031, 56.39321427191458, 65.04735139108473, 59.87025422434653, 47.93600759198589, 11.12774750878734, 1.08192244124028, 1.493589409416722, 4.379781782627106, 30.621383036336592, 49.82314225166075, 59.493161478350245, 57.0312270041435, 60.4282388379497, 58.92760669031451, 41.47572271285519, 12.513807223689172, 46.800810906194876, 59.681976533705196, 21.73007784351226, 28.615147567564442, 34.44530171732749, 25.09760718191824, 36.08853163257722, 54.03858407851189, 22.47746586799622, 0.261153734980091, 0.08828895962646893, 0.05430407739514786, 0.04103128235006044, 0.031828758411950646, 0.03382854666861315, 0.07330093202331374, 0.025880305930190993, 0.038129031027276675, 0.03797611604715067, 0.017808859101346424, 0.06317028873449852, 0.05696517956112662, 0.02603751483313259, 0.04009473603218794, 0.04164424845047536, 0.031471472241044525, 0.11414127844956615, 0.060825117398053415, 0.03647490930292876, 0.06744860250863337, 0.049760992143062815, 0.05936783430497012, 0.024234318144379124, 0.030120072075195854, 0.040216524859950434, 0.029797422654566266, 0.038018281526503064, 0.22854311872393857, 0.10807522572577001, 0.6999000726688294, 11.885409201345137, 69.07402130865282, 40.990623581794004, 40.37796505035893, 47.5795582802065, 28.037390285922637, 67.65233470547584, 42.27527433826078, 11.729868592754489, 49.17515100971345, 74.77449601696384, 71.30198247971074, 70.20472295822637, 68.00822704069077, 71.71106215446227, 43.978563585589015, 1.009848766749905, 0.2828204175156932, 0.02845530555914006, 0.4230735577162235, 6.590815474910121, 43.957578905167125, 75.40154180219098, 69.56358017459993, 73.09372901916504, 65.71217744581162, 63.088386366444254, 55.32183062645697, 53.36294797159011, 56.248192479533536, 56.30418431374335, 56.13720901550786, 53.23095237055133, 49.48434360565678, 48.9949651687376, 48.85175551137617, 47.47504672696514, 49.246902927275634, 51.7215419584705, 48.31054295262983, 49.31783506947179, 47.629607723605254, 45.94094891701975, 44.170038007920795, 47.45898854347968, 47.14576767336938, 51.326131743769494, 53.52279240085233, 55.1018484177128, 55.15068977109848, 50.62149755416378, 49.21336666230233, 47.020294973927165, 47.2516167548395, 47.25267579478603, 48.350774703487275, 50.29006119697325, 47.64918427313528, 44.978085487119614, 44.419202650746996, 47.98551182593069, 46.694397003419944, 50.24148656475929, 53.720895628775324, 53.475233662513, 53.04443974648753, 54.45701076138405, 52.49895572662354, 56.89388129018969, 58.48635965777982, 61.03108359921364, 57.28561624403923, 57.90818660489975, 58.16126185078775, 57.9559414617477, 61.14847621610088, 56.670008090234575, 50.06783147012034, 46.84114856104697, 47.571505654242735, 45.11323859614711, 42.2669824477165, 45.764999235830004, 45.943510224742276, 44.94773026435606, 45.43336676013085, 43.25113650291197, 45.76900789814611, 43.45244430726574, 41.856141628757605, 42.85142344813193, 45.73491073423817, 48.13268307716616, 47.87912537974697, 49.3606085162009, 50.636273122602894, 55.52899452947802, 54.96593436887188, 56.45468957962529, 54.87095809751942, 52.27169359883955, 49.94545352074408, 45.12586862810197, 45.90508668653427, 48.41852188110352, 47.035556916267645, 44.98854252599901, 46.35290761147776, 45.63828706741334, 48.33489302665957, 49.054518515063876, 52.088369861725845, 55.3480242144677, 57.31743058850689, 57.684391852348085, 63.33909642311835, 63.52646020150954, 61.41449136118735, 56.07157599541449, 57.058440408399036, 59.41023472816714, 65.67825286619126, 61.42461892097228, 52.79146648222401, 15.43579355362923, 2.0923395839429673, 3.118986391252087, 5.734423802744958, 35.59123393028013, 54.99183770148985, 63.73176490106891, 61.33672645015102, 65.06758297643354, 61.32046038104642, 45.08433072797714, 15.076374027036852, 54.344874120527706, 61.47940266516901, 30.907237529754642, 23.594564737812167, 40.64121492447392, 27.450727262804588, 32.00515404824288, 64.40844043608635, 18.624321606851396, 0.28695995829278426, 0.038416287185804504, 0.06985097763038452, 0.12311026814483828, 0.04560490003636768, 0.05447275846475556, 0.05327915134389074, 0.016904224175959826, 0.046849655017497084, 0.027516428418757937, 0.01656630279255971, 0.01532789580749288, 0.05442624543643287, 0.1320749064607005, 0.11234618888627138, 0.22650261289410054, 0.17931070809643115, 0.16895488475359258, 0.2293271331056472, 0.15838797354409773, 0.16774697860162105, 0.18565201621142127, 0.20514935225007996, 0.14031412079930305, 0.15397130812127746, 0.256767084882144, 0.10064932097110058, 0.12295760980416691, 0.36530470595725123, 0.32403239319401406, 0.9585607123951759, 28.379844580927205, 80.47824198199858, 53.44110511964368, 54.1661395565156, 55.98008278877505, 32.45504598463736, 75.57413393451323, 45.62238577873477, 14.354041122621107, 52.78489258981521, 82.5580709211288, 76.14605472933862, 75.11663652235463, 72.07202219193982, 77.4574678174911, 46.15034857103902, 1.921083999256934, 2.270542911944851, 0.7111797674048332, 0.790280613207048, 8.625799955860261, 49.577241020817915, 78.3367298495385, 71.79019205031857, 75.94620212431877, 69.92725449223673, 67.28818970341837, 57.6998891368989, 56.20653690830354, 58.57189870649769, 57.8717517083691, 56.63737789277108, 56.978094577789314, 51.85394156363703, 51.77871050373201, 48.995259346500525, 49.908595008234826, 51.437123052535526, 53.44749073828421, 50.982704700962195, 52.25485486368979, 48.80825642616519, 48.049944600751324, 45.70932511360415, 51.47535831697526, 49.71810902318647, 55.87384931502804, 56.18831749885313, 58.68678492884482, 56.5942749669475, 53.6807031016196, 52.64682908211985, 48.42901422131447, 49.86657857894898, 49.612593343181, 52.318173685381495, 51.58148588672761, 50.20844844079787, 45.457873728967485, 45.078223597618845, 50.09469970580071, 49.11737841944541, 53.16276196510562, 56.672392891299346, 55.73391875913067, 59.57828475582985, 57.49167011630151, 55.97626240022721, 59.36098152591337, 61.03304086192962, 64.16320208580264, 57.23378212221208, 60.297996536377944, 61.541313355968846, 62.48025425018803, 63.647457476585146, 59.117202297333755, 54.24617551988172, 51.205805193993356, 51.242589181469334, 47.41509329888129, 47.72100679336056, 46.66434772552983, 48.712472146557225, 44.21720058687272, 49.62747481561477, 45.320865338848485, 48.22473326037007, 46.118565605532744, 43.87367156244094, 45.03032361307452, 48.64115168971401, 51.51289147715415, 51.575472893253455, 50.696881586505526, 54.71392993004092, 58.08435593881915, 57.55788756955055, 59.98288508384459, 58.114456207521506, 53.240621013026086, 52.86121014625796, 47.802643083756976, 47.240665497318396, 51.76949293382707, 49.15567251943773, 47.30061892540225, 47.26849079132081, 50.10931053469258, 51.36168802938154, 51.44589347224082, 54.53887062688028, 56.98150703983923, 59.18404732981036, 60.92008052333709, 65.69575055952996, 67.55513837260585, 65.45817259819277, 58.90630429790866, 59.44801107529671, 60.91551880682669, 71.56030977925947, 62.87649600736557, 54.051229799947436, 17.46051319183842, 2.7796241496839835, 4.199158597377039, 8.935663277103055, 38.72953799463088, 59.57789251881262, 69.76436630372079, 67.10914134979248, 70.14991175743842, 67.38956728289205, 49.52119819579586, 17.482731457679503, 57.361114025115974, 69.76556654899352, 30.03611637699989, 40.274967532004084, 51.442155453466604, 35.009444452101185, 51.34939139889133, 68.03452261032598, 39.72687905834567, 0.7224432210768423, 0.2441665779558882, 0.13714161280903125, 0.2849343605339527, 0.13477498334982704, 0.14888371821613083, 0.16509539507810148, 0.1926471344045093, 0.14132316584788984, 0.08501818553814966, 0.32691380309481777, 0.11046399512598593, 0.11726707039821534], [0.026729039419742844, 0.05436178296804429, 0.030390656245271527, 0.03170161846003706, 0.050013261066088756, 0.05467451155005444, 0.16322398017491066, 0.031140821032045834, 0.10307808782184318, 0.00912712652221202, 0.01982590348850335, 0.03433152552573912, 0.02922113109830647, 0.041807068947462306, 0.06850550506984995, 0.029991177781935663, 0.049830066460755565, 0.1441615369291075, 1.8241454396517047, 47.22861597614904, 42.77593743416571, 25.243586032621323, 46.41567730134534, 20.936725524164018, 42.82856779713785, 74.3858205118487, 18.39405494351541, 37.44711514442198, 70.3486268751083, 63.618753571664136, 54.34217945221932, 61.38776433083319, 65.66801940241169, 39.58438719472578, 1.2642893651800773, 0.27450272513012736, 0.3370828542017168, 0.19264871254563334, 5.453559544778639, 46.06821413963072, 77.83314458785519, 67.17024403233683, 69.97790798064202, 69.88114310849097, 63.220723213688025, 49.028242557279526, 55.72512480520434, 56.28176796820856, 61.43135755292831, 59.21347687321325, 54.04431073896347, 49.48641069473759, 48.014090215006185, 46.76306201565651, 47.70688233837005, 45.55577216609832, 45.70854456193986, 43.875715117300714, 45.982733926465436, 47.30842836441533, 47.28563939371417, 42.79085420793103, 44.33192206967262, 47.086006441423976, 47.83640684620027, 50.71962741113479, 52.114508536554155, 54.65271349876158, 50.85698881456929, 49.34446796294182, 44.81757033255793, 44.96751469950522, 44.550755023956306, 44.366968447162265, 46.05032420927479, 46.600726881334865, 43.911243946321555, 43.62001188339726, 43.765182725844845, 44.25077215317757, 46.6594918312565, 49.74327887258222, 49.56084943586781, 50.66050552552747, 50.4321765130566, 49.63770827939434, 53.71913840693813, 57.78138029959894, 54.51612480225102, 56.44810392010597, 55.32963614309988, 57.82843697455622, 55.72455213915918, 51.77977738841888, 53.24309210623465, 53.24084851049608, 44.21532569393035, 44.77105102231426, 42.96158321442143, 42.284248721215036, 43.094559408003285, 42.441316112395256, 41.37530611407372, 43.16198102889523, 43.15670151864329, 42.58926399292485, 41.45642465160739, 41.39176437931676, 42.60019171622492, 42.39126274662633, 44.69985215894638, 48.81825847010459, 49.9422489443133, 55.44670320326283, 54.23727566196073, 56.818214847195534, 55.32287397692281, 53.9408346914476, 54.05311253763015, 51.16416923461422, 46.17536937036822, 44.54814272542154, 44.71805980128627, 43.303021615551366, 41.49987274600614, 42.37147046673683, 43.3262106680101, 42.43246332291634, 47.205674033011164, 48.37560722904821, 50.7898299924789, 53.34028843910464, 56.18678385211576, 56.82048197715514, 56.39337508909164, 54.680813358676055, 50.28258123705464, 52.324237669667895, 55.015164036904615, 59.072044049539876, 61.15083748294462, 56.84105873107911, 22.28481669579783, 1.8110819857928062, 3.187604089898448, 5.159234692973476, 28.75389945122504, 55.44252980139948, 53.62437786594514, 58.15521747835221, 54.934563252233694, 54.50942539399671, 20.504860801081506, 19.003369654378584, 31.887749664245117, 53.15541928814304, 25.643630527680923, 29.715268458089522, 30.92567070837944, 29.6792414880568, 42.11553581299321, 52.28639856461556, 3.6120996600197213, 0.3682622037106945, 0.17849225040164687, 0.006825147701742789, 0.0770607306772182, 0.07313134313951578, 0.04932608402844879, 0.017538092985388734, 0.06455311191178138, 0.03126147221924076, 0.11041840523361199, 0.06364352039752469, 0.03418083986147277, 0.048784019365426035, 0.03460674261253688, 0.06603769071760678, 0.06073298383383982, 0.03865388935552009, 0.04077905173143072, 0.0389895546099832, 0.07031583212195866, 0.08454483513149523, 0.053668159300521504, 0.03333496771031811, 0.0502955261617899, 0.021291150065559535, 0.04779512242924783, 0.028226067154337803, 0.06904176661684629, 0.06412666523829103, 0.11188969241395114, 0.1595455630412025, 1.4717952498505193, 53.562973160897535, 48.844165725092736, 27.91624003841031, 51.44319880393244, 28.294807595591394, 47.252095284000525, 74.68356763162922, 22.321767384006133, 44.76761110367314, 74.33530822876962, 69.88753657187186, 62.59355191261538, 68.07559767077046, 72.07767824972831, 44.38508587498819, 1.6684112866078655, 0.2249925769865513, 0.9062281431209658, 0.1126173533679497, 6.8950688262139606, 47.501903195534986, 75.40415410072573, 68.71188456012358, 73.63403551040157, 72.22852476181524, 66.40207921305011, 53.493296177156516, 56.52938719718688, 62.28948585448727, 65.31142888530609, 60.04404267957134, 56.07028161325763, 51.86727369985273, 47.99845956986951, 48.625485743245775, 50.60428227147749, 46.627473523539884, 48.33798777672553, 46.56401349652199, 46.64753644697128, 50.27337543426022, 46.96239686781361, 46.913861459301366, 46.667116918871486, 48.326828633585286, 49.61396617274131, 51.789677450733805, 54.95311214077858, 56.552235003440614, 53.93287620236797, 49.01748741826704, 46.89205308114329, 45.926200805171845, 46.28191271135884, 47.87184938307732, 49.04932137458555, 47.02472725222188, 45.77412266885081, 47.543405794328265, 47.523209510311005, 48.181551887143044, 50.8819664678266, 53.56846840150895, 54.6829039819779, 55.08189532064623, 54.01194334030152, 53.34735262778498, 56.420145265517704, 59.81918104233281, 59.338110185438595, 60.71297153349846, 60.39835822197699, 61.95632757679109, 58.48211957562355, 58.43527078628541, 58.211428965291674, 54.055956256005075, 45.26788980730119, 47.249777163228686, 45.401979954011985, 45.90442380597515, 45.04826061187252, 44.266489090458045, 44.107923353871996, 45.15984812090474, 46.123397965585035, 44.976281196840354, 44.11570533629387, 43.96601984577794, 45.37380556906424, 45.127610160458474, 46.992979588047156, 50.657304871466856, 50.426414551273474, 56.0693363220461, 56.80195662283129, 58.47657726657007, 58.88220525556996, 56.26463505529589, 54.31292641547419, 52.77074852297383, 47.41300659794962, 47.16421065791961, 44.907659330675685, 44.79674254694293, 44.39159308710406, 45.92451418599775, 46.3041486278657, 45.00567151654152, 48.580594216623616, 50.873651043061294, 53.29955462486514, 56.741265789155044, 57.94304078625095, 59.9598176248612, 57.83507754725795, 56.646042408481726, 52.319334706952496, 54.1675280755566, 57.3780547418902, 62.19649038007183, 62.453260498662154, 60.573225328999186, 26.523586819248816, 2.157144248485565, 2.4202526721262165, 7.874173810405116, 32.86638886697831, 60.147506959976695, 57.68569800161547, 65.20372452274447, 57.43778067250406, 59.23962339278191, 21.220373684360137, 23.58696318441822, 30.778064074054843, 61.709441831035, 25.332388493322558, 25.147260465929588, 41.11773583196825, 25.43766098637735, 48.95308602240778, 56.92993179444344, 5.189521764555286, 0.6930399698115165, 0.12615072555960188, 0.08757035383173535, 0.0748337360639726, 0.07611088124254058, 0.03073517556091951, 0.04181499795747861, 0.021721174369656274, 0.07768746720807207, 0.005530452885244403, 0.10955611198780038, 0.03962638434923945, 0.049708511289809985, 0.1262766244490781, 0.18165242437633777, 0.14536984144679962, 0.1307005906898168, 0.12739535030578414, 0.234855851759353, 0.21144982787870595, 0.20946126281013414, 0.17171669300765763, 0.1528741936049154, 0.14913464265484966, 0.157020567886291, 0.16700313787066168, 0.19563619498043291, 0.16402201396563362, 0.30007700766286544, 0.32668777651363806, 0.5535272689115617, 6.19573473930359, 75.64422668949251, 58.38164021891933, 39.45679249302034, 64.49157899425876, 33.472836325245524, 55.54179714572046, 86.32310698109289, 25.14272032245513, 49.93641637986707, 82.30093602211245, 75.70382318189068, 69.37429443482431, 73.27397761806365, 77.08557221197313, 49.76557362464167, 2.5795668459707692, 0.9056826272318441, 1.8633798053187711, 0.419826785162572, 8.856823636639504, 53.07964694115424, 78.43473419066399, 71.16766483552995, 75.89765102632585, 76.23506115328881, 68.98684270920293, 56.6319767890438, 60.346327981641224, 64.36107781625563, 67.40324851005309, 66.90966529230919, 59.25714069797147, 56.20409719405636, 54.18846568753643, 49.946139935524236, 52.23622360537129, 49.79429321904337, 50.50726244526525, 47.58245691176384, 49.14562732942643, 54.034222402880275, 51.7976124055924, 50.229252692191835, 50.14419217263499, 51.45804889740483, 53.131618345937426, 54.41223690586706, 56.7182767775751, 60.545768737792976, 56.07143479008829, 52.9189121338629, 47.75001664315501, 49.02115875674833, 47.83153526244625, 49.17841442169682, 51.12185862756545, 49.05062360148276, 47.449719982762495, 50.715532456674886, 51.084470595082934, 50.23481069072601, 53.49344130485289, 56.450327903993674, 55.85963856789374, 57.590898236920765, 56.89205738805956, 55.843443101452245, 60.68450297078779, 64.85683402707501, 61.02637675500686, 63.90708308066092, 62.66093038743543, 64.34833011319562, 60.69227318609915, 59.88076225403817, 59.431635179827296, 57.79716783954252, 47.991768006355535, 50.70551080088462, 49.954435748438684, 48.902001073283536, 47.956576501169515, 46.760182995950025, 45.74797614928215, 47.433787315122544, 46.99591744330622, 47.42740954122236, 45.61863599285003, 46.21393411390243, 46.94607196315643, 46.62350016255533, 50.37331350388066, 52.72372714934811, 52.40889026272682, 61.37403995760026, 60.20222794625067, 62.402642311588416, 61.58150980549475, 59.38843419474941, 56.96328370801864, 54.999294127187426, 50.67731680408601, 49.27110395123882, 47.13695018522201, 48.405166210666785, 46.87537124080043, 48.06581843283869, 49.72820128163984, 47.096526238226126, 49.84763745338687, 52.6390157207366, 55.63204696101528, 58.52553629106092, 61.105647856189364, 61.99741048197593, 59.43196465892177, 59.97200442898659, 55.76249714820616, 56.74070096785023, 61.63004129163681, 64.21839375649729, 65.55922069857198, 63.46823653867168, 26.511047001807924, 3.2946318436053494, 5.997879601293995, 8.873064210337978, 36.414833607212195, 66.38157306178924, 61.639329464204856, 69.11357448947045, 63.05576793609127, 64.75229893961261, 27.475685304211034, 27.770869155083936, 38.11195296625937, 64.3269806523477, 32.246073868966874, 43.875075770962624, 42.906328785804014, 42.49722165446128, 56.12177841124996, 75.24802023364653, 11.467461047634004, 1.0150236600349027, 0.4115417281225805, 0.2757490888958977, 0.23086825686116375, 0.24262812018634813, 0.14956987252639187, 0.2249479753475997, 0.1413431147774381, 0.15623051673173904, 0.23449255754390072, 0.2959099796510512, 0.1476768079784609, 0.12533039861028233], [0.056778905282337824, 0.05586972745556024, 0.017473904393433083, 0.08048161969430025, 0.05841626117246286, 0.020301843272341837, 0.0240600657003421, 0.044897555734121034, 0.012799835343274378, 0.03890020194493475, 0.0763912464401895, 0.07982828459071536, 0.03269875084140128, 0.046794136625624476, 0.030527404854975404, 0.025668436653851986, 0.08570789449637936, 0.03706954674975526, 0.17095910865933667, 25.6230184724254, 53.049558439562404, 33.976425509299006, 35.86996932183543, 32.089212402220696, 22.03565009178654, 61.8860661598944, 28.620813431278354, 28.788233918528405, 59.103140600266, 72.93677145434965, 64.4822947440609, 59.96146502033357, 65.21571520836123, 36.591461858441754, 1.8155223539760037, 0.14229006073888273, 0.23231170440633453, 0.5897863329418245, 10.497321621064218, 50.022751669729914, 76.36184784673875, 69.38194305666032, 69.63701478896603, 69.31394484735304, 64.51266565630513, 52.39554243703043, 54.07892957810433, 63.726861938353515, 63.67066614089474, 60.48508967122724, 60.627303046564904, 54.119228009254705, 46.859269911243075, 46.2942877892525, 46.69595026200818, 47.34913079969345, 47.654977613879794, 46.65629117719589, 50.57184427015243, 53.01599079562772, 52.23748660856678, 54.10285603615546, 49.90730847081831, 47.179374541005785, 49.09821371878348, 53.97866202938942, 55.98257349383447, 55.61950714357438, 53.26184495802849, 46.15030150259695, 44.7319685259173, 46.515901703988355, 46.556568837934925, 44.87002811124248, 45.356362788907944, 43.2427740097046, 42.82288428275816, 44.20449602988459, 44.178596619636785, 43.16618188734978, 46.52637835471861, 48.4633820287643, 49.65544523731355, 48.64148509117865, 51.82835986537319, 51.89719353952716, 53.87030655337919, 54.675176912738436, 57.05328641399261, 55.51429348607218, 55.072050171513716, 56.98222483358076, 56.88038441442675, 55.20092356589533, 54.09493284840738, 54.22574389365412, 45.07201448563607, 41.603431163295625, 43.39147498530727, 43.68071448418402, 42.65221803419052, 41.5872827652962, 41.94930968746063, 43.785751635028475, 45.15035990745791, 42.90779967461863, 41.793548445547785, 40.279741056503795, 42.91809197395079, 42.77190915999874, 47.51979704826109, 47.47763549127887, 50.44697561571675, 52.02781631100563, 54.19033273573845, 55.348710629247854, 51.846492982679806, 54.00205504509711, 54.06692712537704, 48.91920066648915, 45.20701854459701, 43.11084116658857, 42.80168387197679, 45.98792322220341, 45.64937560789047, 46.5062330615136, 44.64815924244542, 44.708752016867365, 45.45454363669119, 46.60932471675258, 48.641944008488814, 48.035161187571866, 53.53293957248811, 51.00280684809531, 49.60431321974724, 48.03385111593431, 49.8344700567184, 49.46574372629966, 54.5951723283337, 57.71288394927979, 62.22335077101185, 56.14348088541339, 35.470158207801084, 2.701110311092869, 0.2065959407557403, 9.47447926767411, 39.67396628472113, 58.14868673201531, 57.927763154429776, 55.2931071096851, 66.60401851900163, 52.45020458775183, 39.649945689785866, 49.07260064155825, 54.33009070734824, 45.478070012984745, 24.756810088311475, 38.53818908814461, 27.196314488687825, 35.458014549747595, 51.033197372190415, 19.462432092235936, 0.16269887286809184, 0.06558577545107373, 0.056773063861915184, 0.02151150376565995, 0.024834931077015017, 0.12307230848819019, 0.03887138937810256, 0.055644888310663165, 0.032354336862842885, 0.017021977635581168, 0.008791156747799006, 0.028696849251226075, 0.04448673725428601, 0.08305078747892573, 0.04582761328727488, 0.019810610458314903, 0.10675063672205133, 0.005971875141239575, 0.053001927106731364, 0.04112129385072378, 0.02958923634592324, 0.06790469295435375, 0.03513207208485373, 0.019729092957512028, 0.06711882463986836, 0.08201052434742451, 0.011436944816171402, 0.023928093648846113, 0.015057711918357641, 0.05919744485929128, 0.1389866130005929, 0.02173283422786382, 0.3905804287041388, 29.191365318913615, 63.5887788188073, 34.15032771325881, 45.972767183857584, 39.92627666842553, 26.517371823710782, 65.21032194937429, 30.15351683862748, 33.49252662351055, 62.608794243105, 80.58619345388105, 66.60990991900044, 66.89184204224618, 68.6744337697183, 41.11800647551014, 2.412981088123014, 0.18965694001845776, 0.276352490388578, 1.7102052439605038, 11.811448989375947, 55.51596049339541, 75.99817352910196, 71.46836942242038, 72.20106032586867, 72.48460062088506, 67.91922061674057, 52.60013326521843, 55.517490217762614, 66.84982561296033, 63.97594813377627, 65.59620080455657, 62.22978738046462, 57.28096431301486, 50.96257901960804, 49.24130178266957, 47.46044374281361, 49.148278851662916, 48.22705530351209, 51.015244683911725, 52.92849448419387, 54.315389663942405, 54.29441282826086, 54.942835530927105, 51.95019260529549, 49.08938838589577, 51.16869957216325, 55.02394230135026, 60.87106266329366, 58.2607880715401, 55.83412354992282, 48.62630944098196, 49.13194217989522, 48.53758542768417, 46.8088125413464, 46.43825838642736, 46.73539753883116, 45.43993280779931, 46.24071605743901, 46.348694985912694, 46.144112002465036, 46.2833639883226, 49.92930904511483, 52.499916707315755, 52.793490425232925, 51.25420724191974, 55.23565223140102, 56.263187700702304, 58.50736787242275, 61.20262845869988, 60.3666772380952, 59.10898885419292, 58.208165553308305, 59.81013997908562, 60.7837938493298, 59.8412286850714, 57.94478231860746, 58.96096252625989, 48.471881804927705, 45.073230420389486, 46.307329670075454, 45.174298132619555, 44.6151642645559, 43.70468408830705, 45.05696042891472, 44.5970154577686, 46.35543754023891, 43.35751902672553, 44.3813164772526, 44.152442255327784, 44.47925413808515, 46.48948454087781, 48.37459525754375, 49.70733819469329, 53.32747405575168, 54.89654371815344, 55.876543983336425, 55.69701317817935, 55.13848335512223, 54.51869787708406, 56.827232376221694, 51.79222699134581, 46.00276547093546, 45.630179528267156, 47.14261801012101, 48.418929807601444, 50.76122022444203, 49.80001987949495, 46.32649829310756, 46.243846108836514, 48.50686934686477, 49.597547131199995, 49.32020810342605, 50.56396815084642, 53.945655284389375, 53.311894401427246, 51.96431706028601, 51.20873520451208, 51.93333425829488, 53.91927734498055, 56.392261135962706, 61.90161051288728, 65.9236441889117, 61.53263707314769, 39.98033085177022, 4.223138988018036, 0.416059838908334, 12.379123818489814, 45.29185156668387, 61.95968120328842, 62.56674643485778, 60.86249228446715, 70.42800780265563, 60.71556029781219, 43.540795695397165, 49.88286033753426, 52.945105721873624, 55.03790593916371, 21.279472035746423, 43.568605299918886, 37.112752699082904, 31.738770200360207, 60.922767346905125, 21.998205184936527, 0.8417513642099597, 0.16343935813394286, 0.027155108794930483, 0.06286214518871519, 0.052861342311746655, 0.07380255873525336, 0.05183676866093471, 0.014590876131889322, 0.03618772975319336, 0.07443779884206672, 0.029772450103454536, 0.04262102970613107, 0.04046985864519112, 0.04932363637753072, 0.17462441036778112, 0.1483803371628446, 0.19062932009898848, 0.10243730123845801, 0.13523526429649324, 0.17305743880569938, 0.10127308508080822, 0.12940603999360917, 0.15798396941634918, 0.1831966431270684, 0.19628672620221493, 0.15318563898965237, 0.07088033166984398, 0.13712884978421275, 0.09082865600864734, 0.1401359747133909, 0.3479393006813142, 0.14299414150657194, 0.3637690980347895, 50.31688236421155, 72.68858740406652, 51.277423750969675, 53.85583300744334, 47.1810297812185, 32.002396622011744, 73.5499869623492, 36.377394583917436, 38.825326196609005, 68.9312078106788, 86.24224339762043, 74.08483351430586, 74.21170649989959, 75.03504337803011, 47.29627686162149, 3.5215446352958684, 0.3730256464933196, 1.0892922070718583, 2.174627232936121, 14.109176378096304, 60.2329832507718, 77.81393281875118, 74.49105770357194, 73.61189765314903, 75.35293579101562, 70.70943001777896, 57.06849736552085, 58.49336501090758, 69.8133017939906, 68.68229419954362, 67.24469061820739, 64.64648515947404, 61.2133365292703, 52.403112611462994, 51.31439208984376, 49.86028709719258, 51.29517247599941, 52.21230499206051, 51.887466061499815, 54.78461496291622, 57.76556922543434, 55.24627793219782, 58.12104186704082, 56.13746789193923, 51.94636437200731, 53.79943324673561, 60.07396251924577, 63.86649047174762, 59.90883465736144, 59.168334314900065, 50.50786256790162, 48.19002812908542, 51.767390543414706, 48.87091628966793, 48.92071470137566, 49.235900678942286, 44.79037654015326, 48.496643727825536, 47.67910411280971, 50.35698467685331, 49.251754899178785, 52.0277496307127, 54.13724345545615, 55.77038503462269, 54.86933423626808, 59.27776059796734, 59.00147276539957, 61.41328327117428, 62.16024375730946, 60.58622014138007, 60.1580895147016, 61.11550085006222, 62.77354555745279, 62.76417109274096, 64.47004518201275, 61.068240211855986, 59.99715858890165, 53.21963241023403, 46.46524037084272, 50.000464762410815, 49.22857761383057, 48.65838266188099, 45.03836839429794, 46.37764992252473, 47.41335568889495, 47.813739468974454, 45.75570321852162, 46.56068340424569, 47.13220803968368, 47.57245486782443, 47.85755234379923, 50.90081345650458, 52.4130871988112, 55.9041182456478, 57.40779807490688, 58.23291178672545, 58.91956975383144, 56.50146384393015, 57.49303902349165, 58.064394997012236, 53.394927055605, 47.72143040933917, 47.55887954465805, 48.51089369866156, 51.84913273780577, 52.96923222080354, 51.69340679722448, 48.63039262833134, 50.76054165440222, 49.798847090813425, 52.3051239598182, 52.683868023657034, 53.35200848117952, 58.350433841828384, 55.83918732981528, 55.96332250102874, 53.87198140544277, 55.91027636681834, 54.270733479530584, 58.08908239487679, 65.01548997817501, 69.78287204619377, 65.14816022688343, 43.44286980167512, 4.005271917389286, 1.0024131786438728, 13.428820679264685, 48.8233575513286, 68.08587428062194, 68.87961295343214, 66.84653082201558, 75.00314666378883, 62.284622115473596, 46.1289010509368, 57.86925708093951, 64.91810929390692, 56.80931891164472, 31.36362687233956, 57.1562643204966, 37.71092983984178, 55.29629991900537, 65.89173178518972, 49.42118167877198, 1.1783403062051343, 0.2950599897773035, 0.44330575593536903, 0.2916029414101955, 0.1477779469062244, 0.22813640264493806, 0.09262101829893167, 0.12795484729952392, 0.06567880916859835, 0.11813739224547341, 0.20474950031888103, 0.1697904262090883, 0.21216532335646693, 0.14240426912663445], [0.05251121331727313, 0.07027421822591175, 0.08866913841977235, 0.025687318805965687, 0.03527382133348334, 0.010528260158495078, 0.04605043379049148, 0.06016902437794113, 0.049744678300715266, 0.08756054790630456, 0.0108620303029555, 0.042594534555269827, 0.050634259598389755, 0.04215523675684968, 0.06148908197158768, 0.040970715438766826, 0.06563650579341958, 0.04547946463008562, 0.21366964424810103, 5.940710565736217, 49.92510818666028, 38.29058162627682, 28.07813978964283, 36.514261768710234, 20.47620592578765, 51.84580656789964, 78.52089297386908, 30.08659531993251, 47.011650070067375, 65.72740016445037, 69.78004793966971, 65.1610295234188, 66.55724817706694, 36.37549615675403, 1.9441600384250766, 0.3738137058192684, 0.7602655947689088, 2.7237372388762813, 17.96115275352232, 65.33012682391752, 72.01688935679775, 72.42875391437163, 69.324095941359, 70.71921240898871, 64.50667227468183, 48.6839408259238, 53.428082850671586, 63.675537724648755, 62.86492893772741, 67.47501219472578, 61.50346640617617, 62.590515998102006, 57.765777111053474, 52.2361098566363, 49.45199581884569, 47.46193816584926, 46.69269469476516, 50.901641076610936, 52.34507722239341, 56.74290533988707, 57.60668185449416, 59.774011027428415, 59.09807682037354, 56.94255790402813, 58.2905274821866, 58.46274306697231, 57.7203913657896, 59.10630203062489, 53.34085326040945, 45.03952941586895, 46.771338216720096, 45.941639254170084, 43.869580530351215, 44.42789462304885, 44.15816107103902, 43.57373968247445, 46.03688616906443, 45.4394817352295, 44.32996480695663, 44.2843476418526, 49.10668996072585, 48.76260003735943, 50.99148688777801, 51.128236401465635, 52.3152397524926, 52.989828586578376, 53.426910061990064, 57.33002924150037, 58.466014323696015, 57.28922482459777, 57.684995897354625, 58.18421556103615, 56.40084328189973, 55.13407461104855, 53.64719821560768, 56.07980120566584, 48.4727604158463, 45.498325132554584, 43.68198925449003, 43.112437571248705, 42.38363765901135, 43.5236902390757, 42.179599885017645, 40.26177660111458, 43.94428207028297, 42.83545155679026, 42.519241840608665, 42.03106364896221, 42.56548658494027, 42.10103873283633, 41.68947227539555, 45.59916534731465, 48.34485976926742, 50.2860446899168, 54.45884250825452, 56.57849527174427, 56.0133287983556, 53.79096877190375, 55.97862366707095, 52.50356451157601, 48.7725079444147, 47.22370909106347, 51.28760622393701, 51.399256490891986, 49.613464109359256, 46.6417391838566, 48.18619597342707, 44.332169178993475, 44.009193374264626, 45.60480571562245, 46.45086880653135, 47.53090127821892, 48.759677871581054, 46.75524473190308, 48.026657489038286, 49.15927717762609, 48.35450879989132, 50.06240683217203, 53.717953851146085, 57.978326428321104, 62.034155245750185, 57.66478392385668, 40.784546175310695, 10.300219578127708, 0.7708210606248148, 13.828291527686583, 44.61830216069376, 55.75290303076468, 55.58711228832122, 55.822634927688114, 55.95740364443872, 55.35515508344097, 57.555208590722856, 64.75956709154191, 59.545631024145315, 40.47729123023249, 20.263535015044674, 31.11623121846107, 26.148035564730247, 41.05720581546907, 45.65402753891484, 1.6273391679410012, 0.6494851133996441, 0.05185835701864093, 0.04011417934370618, 0.063749922349328, 0.0066949501014014175, 0.06127685263392426, 0.0657998740432724, 0.05645269738329996, 0.04103777877565834, 0.05456452430676549, 0.05498611015237628, 0.04822868222911512, 0.080507957797137, 0.07899777633288214, 0.034254108510550954, 0.039525735717747486, 0.041190961886557846, 0.025467269625815175, 0.02530159736653009, 0.06015235813514841, 0.06343234443075715, 0.07085127395487602, 0.03272206289693713, 0.13348602509546664, 0.022765216229844, 0.05941361954976475, 0.029536956590750528, 0.06377620299557044, 0.11856447094150128, 0.045041457689817876, 0.08881435804669896, 0.09064562228177825, 0.2470046579236946, 5.366278473407992, 58.69711252950854, 42.616085160163145, 35.06901741027832, 42.211069060910134, 25.747916544637373, 58.03696586239723, 74.44747232621717, 34.75620838903612, 53.77089800373201, 70.45031039945542, 73.25175346866732, 68.5359505684145, 72.1603931919221, 38.686160502895234, 2.7933544064721754, 0.4582828667856032, 0.6846911436127079, 4.099283285679356, 20.405883712153283, 68.16969533120432, 75.97860874668245, 74.73907701430782, 72.22668909257459, 75.82576182580765, 67.64409772811398, 53.8345580716287, 55.45900767849338, 66.48073057974538, 67.90171115629136, 69.11339406044253, 63.96593040035617, 63.71596559401482, 59.69435553396902, 52.989691303622344, 51.11990528721964, 49.98371231940485, 48.449877308261016, 52.75216041072723, 53.64107147339852, 58.47798539746193, 58.51503218373945, 61.11535572236585, 59.33949085973925, 58.704725850013, 57.67830041147048, 61.17992578014251, 61.22330327187816, 60.01097709901872, 57.29571634723295, 47.80793043874925, 50.22890752361667, 47.4440090117916, 47.10035839388448, 47.71463686420072, 45.88214082102622, 46.92395764012491, 47.96505666548207, 48.098880091021144, 47.22964755950436, 47.44809219914098, 51.73108116272957, 52.39978644155687, 54.14111091244606, 53.94197610116775, 55.44105106784452, 55.96625251154746, 57.86601720317718, 60.19907043826196, 61.18178498360419, 59.67029179296186, 58.14550568980556, 60.56781638053156, 62.51441417201873, 58.82742935611356, 57.44949286983859, 57.89227747148084, 50.08070076665571, 47.176738708249985, 45.5736424846034, 45.52682115185646, 44.0210703111464, 44.297691545178814, 44.71580443843719, 44.83957090685445, 47.41157885520689, 44.39472313850157, 44.085503085967034, 44.8766843734249, 45.37667674403037, 44.01629286427652, 44.17063420818698, 49.038934938369266, 50.57403687507876, 52.44861602783204, 55.29132635362687, 57.20852598067253, 57.444264350398896, 55.92727984151533, 58.01636557425223, 53.85992403953306, 51.415451957333474, 49.02978404875725, 52.537406721422755, 54.32545054343439, 53.015488732245664, 49.47984072469896, 50.629491344574966, 47.648897940112704, 47.795531826634566, 48.20332496396957, 48.87075547249087, 49.38508018370598, 50.57582939824751, 48.15931989300636, 50.288049021074855, 53.84527790930964, 50.76021217530774, 53.80411263435118, 56.981518806949744, 60.35938947431503, 63.93686563737931, 60.48092019173407, 46.070959798751346, 13.301114190009333, 1.031019637180913, 14.342019058042958, 50.413239309864665, 60.82958359872142, 61.643965705748535, 62.86459945863294, 62.37701746725268, 60.134939685944595, 60.73913374254781, 68.20456520203622, 63.13049693261424, 47.080201333568944, 19.285925434481715, 42.957798127205145, 27.488599708003385, 44.8433324598497, 55.326227603420136, 3.830218742932043, 0.5111163962752588, 0.0761067673503872, 0.04157392923990565, 0.046214617923983646, 0.018367427213477994, 0.011550378497509707, 0.04034517400507485, 0.09263542075190814, 0.01221511586223759, 0.01613436709909189, 0.03570252796635032, 0.036929927225555145, 0.02477004151460865, 0.09600299004946025, 0.27358390991726234, 0.22856217899149467, 0.22003269393838223, 0.13089505444851615, 0.09286230535156305, 0.21042152337970274, 0.21853145272020372, 0.28773995837376964, 0.18155180638836277, 0.272013797394691, 0.09466230553845245, 0.23365484039870002, 0.1879445190030721, 0.21487244825449683, 0.19877694096536408, 0.14530746656800472, 0.3468511493936662, 0.33533090304943824, 0.9770528491466277, 18.388661684528476, 77.80006331782188, 52.447753106394124, 44.11164176079535, 53.10132588109663, 30.48924230760144, 62.84993763892882, 90.44685163805562, 39.63573494265157, 58.05089419887912, 77.34308365852603, 80.96199574009066, 74.69298916478311, 78.3238644753733, 43.86973742515811, 3.4975372783599363, 1.246882744373814, 1.0120886852664333, 5.362542906115133, 24.214281574372325, 73.87845408531928, 77.00781514567714, 76.21680644250686, 75.10860350824173, 77.82117351408928, 70.65022576239802, 56.632725961746715, 57.73959529015326, 71.1108140022524, 70.24498216567501, 73.69585206431728, 67.1608538781443, 68.64067785201534, 63.83203637215399, 55.29231086854012, 54.80164589420442, 51.40888983203519, 50.0173270317816, 56.60634802233789, 56.7624818894171, 61.045796409729995, 62.166068477015344, 63.767870318505075, 64.73367552603445, 63.442341050794056, 63.510609903643214, 64.78521939246886, 63.95090380022603, 63.405600209389966, 58.98084894303353, 50.171385965039654, 53.467569351196296, 49.711170350351644, 48.27494352094589, 49.79199078775222, 47.8214979171753, 48.95011286581717, 49.41316043176959, 50.53963376629738, 48.91079502720987, 49.669538313342684, 54.6482341520248, 55.09397622077696, 57.05738921319285, 57.87573683646418, 60.27867494090911, 59.618026210415756, 59.58232087473716, 62.12225952456075, 62.662311061736084, 63.33293045720747, 60.49442883460753, 62.54202765803184, 63.498811414164884, 61.77695758881108, 60.56146998559276, 61.10601263661539, 53.48469441936862, 50.39956592744397, 48.915407734532515, 48.477584931158255, 47.87515201876241, 47.33142522073562, 45.95320240143807, 45.777672413856756, 49.39221497504942, 47.71176176686441, 46.91322211296328, 46.90736209192584, 48.46276229427707, 46.14430419860348, 46.159836784485854, 51.089389247279016, 52.9267607965777, 54.20637522974322, 58.12897682189942, 61.43948078155518, 59.494859864634854, 59.6976032564717, 58.748146487820534, 55.19420454579016, 53.33984128890499, 52.804041600996456, 56.4429420809592, 56.81936017928585, 54.80918468967561, 51.65356336101409, 52.68476624642649, 50.498601851924775, 49.84100472542548, 50.23493228420135, 51.17691693767425, 51.1886840481912, 53.326999448960834, 51.76744937896729, 52.39864503183673, 56.76519224720617, 54.58715500370149, 56.113470831225, 60.19164146915559, 63.35929662950578, 69.29102251606604, 64.01337931233068, 48.0764009875636, 14.015152262103173, 1.6312696280017978, 15.49635494908979, 55.5004906654358, 64.72700357437134, 66.84207500949984, 63.42985614653557, 65.7864514473946, 62.936433745968735, 68.35428991625386, 73.96728792498189, 73.87708125575897, 48.53967212861585, 29.905776016173828, 46.3518681833821, 38.24785132561961, 55.81082467109927, 71.27245487705355, 16.478994969398745, 1.6563430116061242, 0.28435501420209486, 0.19837129740945755, 0.32169980868216486, 0.18287263390037323, 0.16466984855792216, 0.33672518307162874, 0.20258131827558243, 0.2293111371897882, 0.2703440321549293, 0.16163414854916835, 0.11922519113267623, 0.20717594592321306, 0.20035339669594843], [0.007496477731864059, 0.02541956341555042, 0.012244526935260625, 0.05521908515102922, 0.029451884441978993, 0.025036013835380157, 0.021888357737372, 0.08636854573964112, 0.029629898377724236, 0.0361506357758997, 0.05185241217634851, 0.03921796755504705, 0.08112141036338384, 0.025831944714750976, 0.07571233166081291, 0.10031747466494, 0.03141191273537134, 0.022204579680316874, 0.13989114833454933, 1.3726705817445632, 36.35849268205705, 56.71912793190249, 72.69999365652762, 39.85624274899883, 27.551616507191813, 32.96208489325739, 89.32172759886711, 51.11401388722082, 31.67299793612573, 63.03009210094329, 71.47859111908944, 65.98651193803357, 68.46513609732351, 51.54084228700208, 8.318030199696942, 0.5881302959976659, 1.916157502320505, 7.472410826913773, 44.81997082310338, 72.5927403665358, 73.36637296984273, 68.4789820640318, 69.43593840445243, 68.50919215909897, 61.5343354594323, 48.099327241220784, 54.43972879840482, 65.14925064579134, 64.07902802190473, 62.271607691241854, 65.76407432556152, 62.09570507849417, 62.85622127594487, 60.27461136541059, 60.69111216452814, 58.50068415364912, 53.58906476728378, 51.64084311454527, 56.55996599505025, 57.47575706051242, 60.8333686859377, 62.42413297776253, 63.81605663607198, 63.587515815611816, 61.44033978062292, 60.63652453884002, 59.728939071778335, 56.6513454529547, 52.008914409145234, 47.3045216837237, 44.721374204081876, 43.68708441334386, 47.25932028985793, 47.82081934713548, 43.131053140086514, 45.5122220900751, 45.589355499513694, 45.247160080940496, 44.15512123415547, 45.335362419005364, 50.15120537050309, 49.156425614510816, 50.438236574972834, 53.91809671155868, 55.07630594315068, 52.923744493915194, 54.40601994914394, 51.77882817483718, 58.482645173226636, 60.29592160255679, 56.665156118331424, 58.625309621134114, 57.09378880839194, 57.02335480720767, 55.17402395125359, 56.48266000132407, 52.30886982333276, 44.151571489149525, 43.49238580273044, 44.25492594319005, 42.50837687523135, 40.8129951261705, 39.65113416794808, 43.3542360028913, 44.518289566040046, 42.05927333524151, 43.9365000878611, 43.57037036649643, 44.362316516137895, 44.39995558031144, 42.90066880564536, 43.35327502219908, 43.177419477893466, 46.49936499134187, 51.23919240890011, 53.94073663219329, 58.32858623996858, 53.54518521216608, 54.53880002421718, 55.8095734350143, 52.59370057813583, 53.08481662504135, 54.09965930446502, 57.32446732059602, 57.1420535733623, 53.073143651408536, 50.186926395662375, 46.74386201366302, 44.44472159108808, 44.9041291975206, 46.10719857677337, 44.00111329170966, 47.871978821293006, 49.197516364436, 49.387778774384536, 48.34409098471365, 50.132660404328384, 50.42474362158006, 57.05180768043765, 57.63664091787031, 58.03646379901517, 52.23138732294883, 43.15473641118696, 17.691113256639053, 1.8727969258062303, 15.667083955580189, 51.48932979952905, 54.21617331043367, 54.616882647237475, 46.67955083231772, 55.99209308624268, 59.59173848552089, 55.16703428760652, 62.34440688164004, 66.27400598218365, 22.80887672978063, 25.328336684934555, 38.53844404220581, 35.688500865813225, 50.84702599433161, 31.059880487380493, 0.6342983702498098, 0.0823992143775667, 0.13127650494777388, 0.08682577765636867, 0.0390091702912844, 0.03171043421682571, 0.03711573419071013, 0.04482929730006764, 0.05711566604253265, 0.04981218596860286, 0.06420545738130327, 0.02378233776037251, 0.09838370786559197, 0.052884581588929704, 0.05229694618573112, 0.02946777693596819, 0.015299949877625032, 0.03818698940918811, 0.03737269923271191, 0.043367275953172676, 0.02715391944342804, 0.06089338732342567, 0.05622768586861992, 0.038024406399457686, 0.06214562315313567, 0.028613180958575783, 0.14207707297417427, 0.004757728245514896, 0.11293055309403328, 0.08302941362583831, 0.03555094214877294, 0.06077473945615273, 0.19970655801796144, 0.05999424524845616, 1.0003194909903312, 48.42938684648084, 62.96564363664197, 61.536214274744836, 46.46260061571675, 32.58467051290697, 36.56551145738171, 90.97474775006695, 50.57027532208351, 36.25620511270339, 67.27506545282179, 77.30500528889318, 70.44602717122724, 75.10544207788284, 56.620958851229766, 10.375844836235046, 0.43804564302967447, 2.467125240833529, 9.373614538100458, 48.500621011180264, 75.24620809862691, 75.74911871264058, 70.01030675826534, 71.00820479854461, 70.29942466366676, 64.74982392403388, 51.79083847230481, 56.702818716726, 68.08134002070274, 67.17073825097853, 65.11556140838131, 68.61999127172655, 65.01555273609777, 64.88843264118319, 62.02367467264976, 60.56134054737707, 59.07882974993799, 54.94232954517488, 54.40097970347251, 57.81586970052412, 58.26179612067438, 62.68572761166481, 62.660134146290446, 64.77979083215037, 63.0993180121145, 62.94822439070671, 60.91279275955693, 62.5842833518982, 58.59369139517508, 54.573132530335464, 48.73157016692623, 47.20060633074853, 45.70903093584123, 47.44915516145768, 48.714821646290446, 46.61740872167772, 45.78995335486628, 47.326314372401086, 45.46870339301325, 46.79914782124181, 49.20377254486085, 54.4400582774993, 53.083377115188114, 52.454491738350164, 58.10036705386255, 58.69812450101299, 59.531031962363954, 59.70008611679078, 57.70318000547348, 62.40958490679341, 63.69290990214195, 59.980688556548095, 61.34819546053487, 60.3697092302384, 60.982614870994325, 58.811076994865175, 59.82864179918843, 54.28599934424124, 46.39342569535779, 45.799727901335686, 46.24962768247051, 44.65900459597188, 44.53979199932468, 43.58117257395099, 47.40426363483552, 46.65938984963202, 43.89089468986758, 44.97119388272686, 44.922462355706, 44.49145663169123, 45.50541677782613, 44.813616583424235, 47.18086896404144, 48.03980527385589, 47.841549073496175, 53.718816772584, 57.64475237938666, 60.45191034193962, 56.33819910787768, 56.34379633011357, 58.910144298307365, 54.38868699535247, 54.99232799776139, 56.88007062481296, 59.74909220972369, 60.51615484299199, 55.51158312828311, 51.793992057923354, 48.24302719485376, 47.3609685128735, 47.28221516455374, 47.36072924829299, 47.69359727059641, 49.266369650440836, 49.82715091397686, 50.88826187195317, 49.20232911263743, 55.114592198402654, 52.742197590489546, 59.44446525266094, 59.99476202072636, 62.15724706649781, 57.606246471405036, 50.50355188308224, 22.417233951630134, 2.715745899946459, 18.720435365553826, 57.74465514767555, 57.6583198578127, 60.65410067958217, 49.93106234458185, 58.81146138714206, 60.93272624477264, 61.590590092443655, 65.06606501917686, 71.33910379102154, 24.19304782344449, 26.813444091427712, 42.529828317703746, 32.35827130656089, 59.83660813300841, 37.54614714653262, 0.7088020143489684, 0.07402330697063478, 0.0804214051834518, 0.10775582834837899, 0.03062244763808145, 0.032118670980355916, 0.009511731388497978, 0.025004383980206428, 0.010735784758693509, 0.04431216113810097, 0.06162208632656163, 0.020928723444681496, 0.041705179253533, 0.024285142332495704, 0.046492278831259864, 0.18703213892877105, 0.0973650713961932, 0.12544231639514047, 0.14028090322690626, 0.09312802294809973, 0.06719757847848438, 0.16873183059355906, 0.15083713517073663, 0.13128326184326602, 0.21346102318456098, 0.12106507385690367, 0.36581875095444344, 0.1694255385307535, 0.2014830852708509, 0.21292753487585053, 0.14416671568347564, 0.1823267043237725, 0.4474733968175227, 0.2754353605691464, 3.3296103150613847, 73.42804831843223, 71.07601473408361, 76.34326365686233, 58.9244491823258, 41.37095620555263, 45.25473417774324, 101.51839256286623, 58.484500454318145, 41.899554421824796, 73.4464285450597, 84.20098704676475, 76.82207522853729, 79.31889918542679, 61.16504038533857, 11.46287383571748, 0.7947700110173995, 4.013073756810158, 11.57073607367854, 53.985777208882, 79.38845849806263, 80.27906402464836, 71.35890391565138, 75.4907992578322, 73.83517465283795, 69.64740122518232, 53.95955224190989, 60.483265769097116, 72.01361025533369, 69.72237340865597, 69.779553721028, 70.99598269308768, 67.53893898379418, 68.29365007338986, 65.32134855947187, 62.39828848069715, 64.03127708742696, 60.792513278222856, 57.284168889445645, 60.295572511611454, 61.802009767101666, 66.77004460365542, 65.7838156146388, 66.75353926997032, 67.70023469002017, 67.38433484108218, 65.03957725340321, 64.69896647237962, 58.045002798880304, 56.489712422893895, 50.814156532287605, 49.75174726978425, 46.438332911460634, 51.41153743190151, 51.697062446225075, 47.41140234854914, 48.82998635691982, 49.39525873430314, 48.9117834644933, 47.78372157004572, 52.40552879148915, 57.73688493236419, 56.68524257598385, 55.03594083170737, 61.05206435726535, 62.41841023968112, 61.948525982518355, 62.04308648263255, 57.350806036303126, 62.2650416435734, 66.6595043674592, 61.67991422837781, 64.22703473798691, 59.956287491706114, 63.36920453656105, 61.0839649938768, 61.59859172759518, 57.84456968307496, 47.47344247756466, 50.24158854638377, 49.46703418608635, 47.624865578066924, 45.86614147309334, 45.50131790099606, 47.488622050131525, 49.33779601127871, 46.108936186759706, 47.29408817906534, 48.11286334068545, 49.70531425168438, 47.11518495313583, 48.446170668448175, 49.60928286275556, 49.2129744252851, 49.74991944528396, 55.76805122437016, 59.736109164453325, 64.04649588369554, 57.34249845627816, 59.72881747830299, 59.90972895776073, 56.60745805309665, 58.34499351439938, 58.22150945663453, 63.093108900131725, 62.746069354395715, 58.87982437687536, 53.23773807094943, 51.21503845337899, 48.60329297281081, 49.48396705812024, 49.66356062120008, 48.801062799269154, 50.66542810009372, 53.32690138970652, 55.28754518878076, 53.7721884635187, 57.14060621876871, 54.77844899700534, 62.06065870100453, 63.41389994467459, 64.50125940384405, 62.139694459976695, 54.33444061586934, 22.165086346287882, 2.8146131625098567, 19.11760868564729, 63.50077652162122, 62.18742970497378, 67.99835835733722, 56.334723887905, 66.49815374805083, 68.73985105945219, 66.36411851452243, 71.21674153112596, 75.99185851312454, 27.440068221861317, 37.817661454600675, 53.96805986281365, 51.47860996184811, 66.17552311189714, 58.51415749519103, 1.2252804132238513, 0.3754257080295394, 0.34146003545291964, 0.19508073527005412, 0.1029762211105516, 0.13175648967585257, 0.1610148583929385, 0.14666878948769263, 0.0925995831588103, 0.1388792840824012, 0.18904668969973443, 0.10901422735543982, 0.2732342673886207, 0.11869141171055457, 0.11217222564042577], [0.041523612585038915, 0.022154190247097326, 0.0197882924018608, 0.03643047620332049, 0.02154965877472874, 0.005794709647870473, 0.027509606405792218, 0.04941972295543359, 0.007076365647897606, 0.030794687186097427, 0.04629752395914928, 0.02874556286711126, 0.05515671793311354, 0.03239313155532845, 0.06149586184971756, 0.06563812223893982, 0.011863487250652286, 0.03320979660436992, 0.03857556069570203, 0.03779080320870684, 15.929500326033562, 52.46758853235553, 35.58378142695273, 44.209438216301706, 35.10962963104248, 26.373587539119107, 72.19105828192927, 71.41055368608045, 53.981199802890906, 54.46057619587068, 70.54712234004852, 71.08189044460174, 67.11115744806105, 59.21485754751391, 25.286649734743182, 4.435227426790423, 0.6113330767520013, 11.619865721271886, 58.11760587076987, 76.20985600256151, 72.56151829996418, 67.37951817051058, 66.85067284491755, 65.68880404195478, 57.752711696009484, 48.95123858605662, 53.23318419917938, 63.68914834914669, 70.15247698753112, 64.30397987365723, 61.74435877030896, 66.48504518693494, 62.1573765047135, 64.72043752670288, 62.910459810687655, 62.452385810113725, 61.45656662602579, 57.259418733658336, 55.134306030888716, 57.56309647713938, 55.954599149765514, 62.42932619587068, 62.330600138633486, 63.40840470406317, 61.166742693993356, 63.310396440567516, 61.95878690288913, 57.1056971242351, 49.576778181137584, 45.06270670121716, 44.95053868139944, 45.578745488197576, 46.244289336665986, 44.890938266631096, 44.24344124332551, 43.657886289781146, 45.20863063873784, 45.137553368845296, 45.84514894793111, 46.948731330133256, 51.10162311984647, 49.26358084524832, 52.241671777540645, 54.732871055603034, 55.402839337625814, 53.612928467412154, 57.36207500580819, 54.24696783865652, 48.2945514494373, 59.941151065211145, 57.638680550359915, 60.53648840996527, 58.68570235467727, 57.326440272792695, 56.15238858807472, 56.559330571082334, 53.541364823618245, 46.05215203377509, 44.34021788258707, 43.75840879255726, 40.971419657430346, 43.91682155670659, 40.9816845001713, 43.65562308219172, 42.81996211697979, 41.709597956749704, 41.92244145178026, 43.37453426853303, 42.79654948942123, 42.807865527368364, 43.42973378396804, 44.619467104634936, 43.661600774334325, 43.97019324764129, 47.422369295550936, 56.97023414796399, 57.31717563444569, 58.008061916597434, 56.61942128212222, 61.05712029241747, 54.095838915917184, 54.27378900589482, 56.28518043025848, 57.21584512341408, 58.84434653866676, 55.113572382157855, 49.4323290548017, 48.112522094480454, 42.424359706140336, 45.7016529575471, 45.84785538335001, 46.89045667648316, 46.30048513412476, 47.424675649212254, 44.838021570636386, 50.20514580511278, 48.79209233868507, 52.804422070903165, 52.86178673467329, 55.67894674116566, 53.63143420988514, 56.48964574260097, 49.36666465574696, 33.41553834176833, 7.085557262743674, 19.10482568125571, 53.01573976393669, 55.11634157549951, 51.7200553801752, 50.867677273288855, 64.75887283202141, 66.06010344720656, 64.51044951715778, 56.17737408607237, 42.26251094572006, 13.597947397539693, 40.010113408488614, 35.85103604101366, 36.89647713015157, 53.52862104292839, 16.30003486910174, 0.6139849667106906, 0.01808269914510029, 0.0148421855297901, 0.05780790692135211, 0.053113339273559476, 0.03267162366800251, 0.07645599619154969, 0.024323783807396412, 0.017418052753313415, 0.09423485912022092, 0.028181183978074023, 0.043455824225900636, 0.039900456134590416, 0.05841494733167272, 0.08583337969837651, 0.009807974715987522, 0.025554214859561577, 0.05393760008437019, 0.05440071938679584, 0.015060546443677478, 0.051667329164281975, 0.05341192970292703, 0.02078200803108273, 0.04075600780666836, 0.07253306677504893, 0.05632126350857078, 0.028240634316217997, 0.05251184533981066, 0.014265894931140206, 0.084182552152103, 0.06364628597493134, 0.1457038557817859, 0.06225161141745987, 0.049979074392467744, 0.07655656821424923, 18.73330858445937, 63.65046593450732, 37.505378030961566, 48.50727335099251, 45.839963574563306, 30.94169555171844, 83.04176976603847, 72.6671947971467, 57.36442842791158, 59.192025430740856, 76.88426832998954, 77.62572180840277, 73.41448476237636, 65.71602136858048, 27.414425726859804, 6.440670576787765, 1.035318922611975, 12.761988332194667, 61.515872863031205, 74.26261101999592, 75.15296551489061, 70.37777793022894, 70.73208562789425, 66.20022619924238, 59.97311838211552, 51.612339250503055, 54.767140803798554, 66.0986368117794, 71.8157188354, 64.33846927458241, 66.28168598298105, 69.6975055817635, 64.13345875278597, 66.5037235136955, 65.95580762432468, 63.94397689450172, 63.972480758543945, 59.502598700984834, 59.49279669792422, 60.201384636663626, 58.728299294748616, 63.405690423903934, 63.91298232540008, 66.27548079336843, 63.72180992557157, 65.54261730563256, 62.78030380125969, 58.7810081051242, 53.06303178110431, 47.81581048042544, 47.32851482206776, 48.414756405738096, 47.67724098697786, 46.456626845944314, 46.78864763629052, 45.161817150731245, 46.16424552855953, 48.703285955613666, 45.92510646389377, 49.82029068854548, 53.62444846860824, 51.96884347546486, 55.91560294551235, 56.09090935799384, 58.91167010030439, 56.58045645683043, 61.84466946509577, 55.6874700515501, 53.87014181383195, 62.45469216377505, 59.543705140390706, 62.074838069177446, 62.38010045020812, 60.763934889147365, 61.197658815691554, 60.94286949403825, 56.980322484047186, 49.2487346741461, 47.12780714035035, 46.5641664689587, 43.800178112522254, 44.513300311180856, 43.464811540419056, 46.07080290394445, 44.075712850016934, 44.35946887539279, 45.94148235936319, 47.2687182887908, 44.762323748680856, 44.01501417160035, 46.06042039009833, 46.15012891830937, 45.05532087818269, 46.58677501063193, 49.34412671673683, 58.308621375791496, 59.177834295457416, 59.08427399973716, 57.51190954639066, 60.614072891973684, 57.8989847244755, 57.841867170026234, 60.2521675632846, 59.6493463362417, 61.04403526552262, 60.1261967228305, 52.21719226529522, 50.57092251316194, 46.15410227929392, 49.149828187880985, 47.799493420508604, 51.13239411384829, 46.87459853387649, 49.71363752119003, 47.409805943889005, 53.46333711378036, 51.394910504741055, 56.53224268267232, 56.00074583484281, 59.575382201902336, 58.67571600021855, 60.95325985262471, 55.84341564486104, 38.619142886131044, 8.725844910067897, 20.68894547800864, 58.00381006733064, 61.634963866203066, 56.73016548156739, 54.32814521174277, 67.7296289320915, 69.43622081510483, 70.76715161723476, 61.72748865619783, 51.463638274900376, 14.181734342728893, 45.490299963182025, 37.61586727634553, 38.323109842115834, 63.22819925123646, 15.27927823605076, 0.6388697701115763, 0.022744120083629124, 0.09909130497685364, 0.08709727155585444, 0.026461004407235214, 0.054465982417065295, 0.03602420445531607, 0.02984081004415789, 0.04013939895817349, 0.01465250694778778, 0.010080897369452063, 0.037278558518136704, 0.04002761523870211, 0.04402986539888286, 0.020458406746207226, 0.16573423579815896, 0.15812243214778363, 0.16551757081141397, 0.15713531253558977, 0.08399113742334229, 0.09985789851916414, 0.06849455767341199, 0.14485161360954085, 0.07262633797983009, 0.11172099985302457, 0.17756842497375705, 0.12632745438285414, 0.2808550649112271, 0.09440064054703522, 0.15079604221447823, 0.2447283042654876, 0.30868605860779363, 0.10567044508793663, 0.11296763174956846, 0.13266886975015366, 43.60420473160283, 74.43394799386301, 51.09808121958087, 59.87775771848617, 53.40589792497697, 38.211891035879816, 87.52102236593925, 81.89639060728013, 61.60823291347873, 66.1712791073707, 80.88058302479406, 84.54341780754828, 77.50043346035865, 71.21155615775817, 30.53411618355782, 7.641949884353146, 1.4569316732306636, 15.814935738040557, 66.32735021652715, 79.53522574517035, 78.72472286224365, 73.32070873629662, 72.63348594788583, 70.467145212235, 62.83038070124965, 53.988326749494, 58.392242385495095, 70.56706367000457, 74.3678560564595, 66.82505192295199, 68.32036141426333, 71.66071461093041, 67.63968113929995, 70.26849285248788, 67.92041301727295, 66.7390892582555, 67.4288615872783, 63.564448356628425, 61.44254023028959, 63.375331278770204, 60.70751943895894, 67.54116689005207, 67.65755930254537, 68.55705291994157, 66.34133738856163, 69.32298198823007, 65.709318037956, 61.41924135146603, 54.57305016056184, 51.22636625843664, 48.08897610633604, 49.56109262281849, 50.17096234906105, 48.83970599020682, 48.54858767601752, 48.06207256932413, 47.50271904853083, 50.631511365213704, 49.53412632788382, 51.83143892595845, 56.44830396098476, 53.941583864150516, 58.28900560255974, 60.28068319443734, 61.70769245393815, 60.35947184408865, 63.16303691556377, 61.10621267749418, 55.462737852527255, 64.18231579565233, 61.8195309946614, 63.51762310151131, 64.80997347062635, 61.83899379545643, 64.17408274066064, 63.395327521908676, 58.71545745480446, 52.72238962111935, 51.17844273967128, 48.39625066326511, 45.33256969144268, 48.19840631177349, 44.995343915877804, 49.912603670550936, 46.10635526718632, 47.35745799156928, 47.00196181574176, 49.25359056841943, 46.104394082100164, 47.4580079509366, 47.89875292008924, 49.18652588321317, 47.495913736281864, 48.12096303509128, 52.574900657899924, 62.02667136346141, 61.79277650771603, 61.110813617706306, 61.8901885709455, 62.87437008273218, 60.21979624225248, 60.20542075557094, 62.6316342046184, 63.2094346323321, 62.42131671597881, 62.11244183201944, 54.44183118881718, 54.23649903266661, 48.14381476371519, 50.87505525158298, 49.588404086328325, 53.03727749855288, 49.87415659812189, 52.64411872433078, 51.1071732736403, 58.04251209382088, 54.026522790232015, 59.320887058011955, 59.908936638985914, 61.4326637021957, 60.93420105595743, 68.41399623501685, 60.63106852193033, 41.605694370885054, 9.121799353630312, 24.030908807631462, 61.87215743526336, 66.16949050657212, 63.40727506145355, 59.86107587814332, 74.13048990311162, 75.87320681541198, 74.90685247605848, 66.85384212001678, 53.75258837976764, 20.469441798425493, 57.0119446323764, 51.79219561238443, 53.06067835900092, 69.09756337442707, 32.275940756643976, 0.8816587840837817, 0.15471884139603184, 0.25488730429882006, 0.21933103400853374, 0.16281047655690103, 0.2809088442835116, 0.14430413653533306, 0.16040586445841098, 0.15579779962858847, 0.20575401012695607, 0.17840163752196297, 0.11829976458102466, 0.1269262746697472, 0.11487032602270765, 0.19015958562733667], [0.02118824147469094, 0.039294082220763936, 0.03542616557810576, 0.031447568382587165, 0.10297334828083554, 0.06529309155960238, 0.028625631802565152, 0.058049615322341847, 0.01591198422360204, 0.0495715998864222, 0.09169329348350726, 0.01103724131450778, 0.1367830989822265, 0.05476079603296615, 0.03493087824373957, 0.08424484276122625, 0.07087869990256525, 0.0906005839727098, 0.10708481193550172, 0.20813890312227512, 3.604880537717573, 59.024924616659845, 42.998057334653794, 30.274435666299638, 47.387322918061294, 22.657204558772428, 54.84889084292997, 73.30771784628593, 69.47226739698841, 66.29162526899769, 67.70240768309563, 70.33030156166323, 67.80975510997158, 67.84528393899241, 34.40309701427337, 9.891444867657079, 0.9015385818577583, 9.915802786427161, 63.402729034423835, 76.37277557003883, 71.16033784804806, 65.79664960984262, 61.4395631513288, 58.2859932222674, 54.67569466560118, 51.64779747686079, 53.19673753553822, 63.7562208790933, 67.2363987276631, 69.74100466697448, 63.6650610739185, 59.41611436105544, 68.30274212744929, 65.41010002936086, 66.29761865062099, 66.64353247611754, 63.294565754552046, 66.17482493000647, 62.82741538939938, 59.970886553487475, 56.30096797020205, 57.52771277581492, 60.70456981658936, 63.630838394165046, 61.87028254232099, 59.50037471709713, 60.89982148139708, 53.91221315630021, 46.22214363467309, 45.3271254416435, 46.87500646037441, 46.5262096928012, 48.30293355449554, 45.678691402558364, 45.149999049402055, 45.525067852389434, 46.10213479688091, 44.841033950928725, 44.30226895116991, 48.00899505615235, 49.75353587058283, 50.6108404744056, 53.142369562579745, 54.174317698324884, 54.69177246093751, 59.005991335838075, 56.20193204572124, 64.41594393022599, 50.95404786448325, 54.04000789888444, 59.76261261970767, 59.90243727161039, 60.0255722384299, 58.70707142737604, 59.760474927963756, 58.604360242043775, 56.84618134652415, 46.573054559769176, 44.33415389830067, 43.180522072699766, 42.23626636689709, 41.252963466029016, 42.45612305979575, 43.1008626568702, 41.578916349718654, 42.98810235915646, 44.24406490018291, 42.17329271378056, 42.66086686042048, 44.289866416685044, 44.04625192765267, 43.79740107444025, 46.083907542690156, 45.39248781819498, 44.20211907356016, 52.978532160482104, 57.68782000387869, 60.376671437294256, 56.05062269395398, 58.83872185983966, 58.375623303074995, 58.670216837236964, 56.3945008093311, 51.38466919622114, 56.53404305058142, 54.622679910352154, 54.60458993911744, 51.05132264475669, 50.29745878711824, 52.63286936667658, 54.33913177059543, 51.85386703860376, 47.17558160904915, 47.05010890960694, 48.56323772861112, 47.638911585653986, 49.54628959778817, 49.68266256393925, 52.2625191750065, 55.97908650675128, 54.13789849127493, 57.65626453584241, 56.56038961102886, 45.51700345931515, 14.097955457625853, 17.220844607199393, 44.997642424798784, 57.00205241480182, 51.15683048002182, 56.596593087719334, 57.43890247037334, 62.35202804688485, 54.897638059431515, 43.530919167303274, 13.777511542843236, 23.484281416862245, 45.48827994254328, 32.400044548896055, 44.45184461532101, 50.39938157604587, 1.492571431782938, 0.2795122659975483, 0.017295356111360655, 0.05380977065332475, 0.026622578096125397, 0.025620198012479854, 0.05247911040280616, 0.024508186916430152, 0.011779667655636948, 0.07342127677533897, 0.038056635718432166, 0.085413096202237, 0.03648515189847639, 0.03552022202300929, 0.026467079484474756, 0.09643563820469765, 0.03445190092128131, 0.0293985340789321, 0.02901051629094347, 0.08226461272927062, 0.03504223295397336, 0.015790122617486746, 0.0665403210047272, 0.0988902758446432, 0.07437165481068435, 0.046867550831408276, 0.05114666133698437, 0.043648702182596734, 0.03202329494900281, 0.019159041187395493, 0.04653974563904828, 0.020135629005850326, 0.04888779746608869, 0.07082550275710321, 0.047511325157698125, 0.1374575781125215, 3.596573202840744, 69.5897110046879, 50.90319825756935, 36.964118403773156, 55.99470538477744, 29.340839001440234, 63.75895869347357, 79.76186029372677, 74.49625876642044, 73.31861419062461, 72.43479436443698, 77.13071084791615, 72.44882076017319, 73.16848939464938, 39.98470037214218, 11.623078142443012, 0.8638940018511588, 11.264828462754528, 64.99912977218628, 77.82535476069297, 72.10196556583529, 68.07650766065045, 63.28179059490081, 61.14284761490361, 57.366691635501006, 54.22896808193576, 55.875194687997144, 65.67700947484663, 68.25122571760609, 72.24834842066612, 64.04322070460167, 62.31014497818486, 71.45618654066517, 66.30636553610525, 67.0448144789665, 66.59694256321077, 65.03091273769256, 68.10195599832844, 64.50261262155348, 62.51151161809122, 58.00115070035381, 59.718438886827045, 62.29559298484557, 64.86665564198648, 64.7446777743678, 62.29359649842786, 63.17166612994287, 55.903039593850416, 47.9191453226151, 47.994760774797015, 49.688008754484116, 48.36094933171427, 49.10577212610553, 47.93290891954976, 47.277982927137806, 46.43477924408452, 49.66015208152033, 48.59586792607462, 47.045719777384114, 50.18614192162791, 53.891585411564, 54.649116685313565, 56.555725912893976, 56.96257375901746, 58.54794086948518, 59.345900012600815, 62.059254492482836, 63.91597509384156, 55.27054171408377, 58.05964500673356, 62.94514533012145, 62.61543481580673, 63.260535270937034, 62.31037247565485, 62.740397607126546, 61.94947519610005, 59.299941601291785, 49.52776424346432, 45.74665038816391, 46.65268651900753, 45.65805581308181, 43.887556752850934, 44.475967191880756, 46.189717400458555, 43.975566894777366, 45.76245753995834, 46.096674857601045, 44.19147768328267, 45.4299033072687, 46.440505904536096, 45.80525059853831, 44.47268416804653, 46.52515849759502, 47.59173331722137, 48.770915462124734, 55.31686490581882, 59.50189267435382, 62.59409319969916, 59.04093965407341, 59.63504145222326, 60.00557207292127, 60.13948963534448, 57.945449121536754, 55.99689406733359, 58.98889764662712, 56.47665877496043, 56.06415879341864, 53.326787640971524, 52.521132807577814, 55.7007315851027, 56.735417535228116, 52.791137003129535, 49.61297773545789, 48.49045030532345, 51.53743374732233, 53.15714513101886, 52.768426479831824, 53.78324954740463, 53.69533746473251, 58.93269008205783, 59.869085358035186, 62.34682698403636, 62.702425141488355, 49.3694495385693, 16.09224534803821, 21.086134487582793, 50.328410210147986, 64.16723428233978, 54.23772673453055, 62.70886959568147, 63.82513692302089, 68.43472988374772, 60.68765655640633, 53.89202079465313, 19.641084286474413, 24.520136233299013, 50.22202376396426, 33.549428447600334, 50.468077967243815, 51.91459317361155, 1.3265039170942, 0.23158588206335423, 0.15892489392670894, 0.08934181724344531, 0.02504159670112835, 0.05528705247167138, 0.0713509624643672, 0.068816889167553, 0.01726780950482334, 0.10260633087807125, 0.026893217807575583, 0.07293270420162909, 0.005180687303729957, 0.03637061409291722, 0.008235854085444683, 0.03835990694501708, 0.17380103438852296, 0.10456132597380108, 0.11257590801124612, 0.1926414193885942, 0.133024120042401, 0.14826160885633963, 0.11134246814875834, 0.20131163479339695, 0.10715064953171438, 0.11225453412701046, 0.1709735570775886, 0.13438375756865548, 0.18698911543094343, 0.16299844389000248, 0.22106766340232667, 0.26284770859825995, 0.20581287632305778, 0.18692638815170337, 0.500304137747134, 0.6009275802681523, 12.11472272872925, 88.71866318487352, 54.877104451579434, 50.24785257154896, 63.37962235173872, 35.67851058898434, 67.89604725376253, 85.92057766452913, 80.84015907779818, 78.92391650907456, 79.662961652202, 83.13232160383656, 77.05905698960828, 80.58232599689116, 44.76925065440517, 13.374398773716344, 1.1618847375915897, 13.978594791504646, 70.35458887777021, 81.68008758175759, 78.98741968216436, 70.22455446181759, 68.84573151988369, 65.11279221503966, 61.04835771745252, 56.88519716262818, 59.80389948814147, 68.47764061343285, 73.2403079925045, 76.70501601311469, 66.4384788082492, 62.46504329865979, 72.3744918454078, 70.18170649005522, 69.98100665307814, 70.28462948337679, 66.88666451361873, 71.10144738228091, 69.43706804706206, 66.07338459261003, 59.875090506769, 62.104487265309984, 66.302490234375, 68.21191572373914, 67.61857094303255, 64.22211608579083, 65.07655343701764, 58.780447206189564, 50.122728963052076, 49.68372552625595, 49.95603215309882, 49.770802144081365, 51.51547239672754, 50.36541777272379, 50.24295745357391, 49.36063989516228, 51.22893933326968, 52.007859291568884, 48.65860623698081, 50.381185700816495, 55.76200292956445, 56.00584099369665, 59.11544507549655, 59.37248583762877, 61.51690052401636, 63.3510047389615, 63.54656234864266, 67.38564491271973, 59.75611717470231, 60.111350551728286, 65.87645807573873, 65.78868327602264, 66.12227301443777, 64.96519342545541, 66.66694902604627, 65.53260741695281, 62.47918736550116, 50.6275733055607, 48.34982156753541, 48.16137521497665, 48.11881357623685, 46.39968187578263, 47.92588395457114, 50.36104825235183, 46.12189569780904, 47.823596385217485, 49.12463088189402, 46.89664617661507, 45.18641041171166, 47.610176301771595, 49.85045763754076, 47.64889009537236, 50.75059452364522, 48.82777414014263, 49.95139591155514, 55.47704273654569, 62.27140372799289, 64.13525519832488, 61.56535356275497, 63.6682068147967, 61.53176238459926, 63.90902073152604, 60.850846767425544, 57.632349844901796, 60.695618967856134, 59.45642063694616, 58.60348163112518, 55.06530369481733, 55.750984991750414, 57.762870634755785, 58.91949915116834, 55.728698084431315, 51.50914561363959, 51.221388770687966, 55.30150490422403, 53.951389789581306, 56.65077670927971, 56.93875320496098, 55.35674756573093, 64.17429847102012, 63.78476004446707, 68.10953401750135, 66.91554884756765, 52.00273275375367, 17.301645432749105, 24.55539441877796, 54.47288067110124, 69.97280889941801, 58.58928265110139, 67.8082646093061, 67.92278997359738, 73.55190107899328, 64.80589420564714, 56.446703633954456, 19.413218113683886, 36.02289861248386, 61.75433335765716, 49.776062042482444, 56.44466400146485, 74.35713229640838, 6.068163571819183, 0.7002655272522281, 0.38493209308193577, 0.2329045492074182, 0.1618194805398103, 0.14256108732473466, 0.15090749268570255, 0.18363994756533256, 0.16375535408095007, 0.1825871895397863, 0.13709681198721932, 0.1850682112478441, 0.13299139276627572, 0.11536608450114728, 0.10948054507494935, 0.20133412713485382], [0.026414192604622053, 0.08874532586384205, 0.05280685047769258, 0.06973655473801398, 0.0542111087950968, 0.04559096872746464, 0.004400740848899249, 0.06796728233776747, 0.01588669757644135, 0.026989725733836813, 0.038856822216222366, 0.027238007169216875, 0.0485546947757323, 0.07541900425548516, 0.027211360715990587, 0.12844053172175923, 0.0221389374365249, 0.015981906026061025, 0.09736874095735051, 0.03167939616457349, 0.29795374901544663, 35.2884034187563, 64.95125724423316, 38.596550033938506, 48.30449465782412, 30.836352456000547, 39.92989309372441, 65.04861047191005, 54.680189701818655, 69.96121437318864, 68.64454530900525, 68.98105329082858, 69.72773136631136, 68.19253921508789, 53.87463292767925, 14.459360684117964, 0.6833397032272431, 7.767047507147636, 66.24182685728996, 78.88623037645894, 73.69805643635412, 68.60791037159582, 66.57386333711686, 58.15335435252036, 57.271476099568034, 49.82511128148725, 53.27753443871775, 59.93833480342742, 68.28593084889074, 66.63193010514783, 67.09996300358927, 63.09033186204972, 68.68702457797143, 65.43857251444172, 66.59421259357084, 68.350445993485, 65.82927980730611, 63.134988046461544, 62.579890297305205, 59.66130956526726, 54.840810760375, 51.814051058984575, 55.54541357101933, 60.28766109097389, 61.637799739837654, 59.60335262360112, 53.75061542757096, 47.99696514683385, 46.720280724187056, 46.59082289664976, 46.652235446437714, 45.43989358409759, 44.29762486488589, 43.8926911354065, 43.16270274500693, 44.754498620187086, 45.57714516116727, 48.53623220997472, 46.08489990234376, 49.908861729406546, 50.90643029059134, 51.91876265310472, 54.91618302560622, 56.705595754808, 54.58422891555294, 56.026770760936124, 57.936431592510594, 61.6617379649993, 61.31001510927754, 49.82094572436426, 63.106982323431204, 60.035637040292066, 60.14257261829992, 60.12503570125949, 60.35518469349031, 57.99875020980836, 57.24579241967971, 49.2487346741461, 44.43996767843924, 44.405835213199744, 43.664326821604085, 42.011122319006155, 42.76713955786921, 41.48310461351949, 41.205793042336744, 43.26293891476047, 42.99467232919509, 43.03882252785468, 42.30080112334221, 43.42042207717896, 44.354507077124815, 43.39886865308208, 43.141906338353316, 45.74195138869747, 44.61621153739191, 49.34314612419375, 56.87273579259073, 58.042343431903475, 58.377156949812374, 59.41620849793958, 59.11065978388633, 58.703411856005275, 55.12857152569679, 56.437670415447606, 58.74231000100413, 57.494274570095925, 53.31173358425018, 57.33463410408267, 56.42107878961871, 56.15911153055007, 58.40341329574586, 54.063993192488155, 51.36636349462694, 48.4467472568635, 46.61891491182389, 48.690863809277936, 49.76414588189895, 48.82040792895902, 50.859836455314394, 52.22391520777057, 57.345408854946015, 58.68325087331957, 62.01973661299675, 52.324684819867535, 21.331476780676073, 16.723982287991433, 47.95707856455157, 52.958096611884336, 47.98382128438642, 59.31250495295371, 62.49308040065151, 61.669088486702215, 57.207666981604795, 24.524809737359327, 10.024461265533201, 29.858036848806567, 43.477041490616344, 34.55782275046072, 51.82714000824959, 16.357474057905137, 0.2881177929380248, 0.09407902151466378, 0.07680282717750919, 0.05528368168480455, 0.03360147054697718, 0.05931773215472218, 0.04677009678656056, 0.01725775651603697, 0.03878227036987101, 0.048867312274993434, 0.08690099216877453, 0.061336745387844505, 0.04130707400280141, 0.04653258654739588, 0.032329339413873615, 0.0017387245245645906, 0.02455751340265476, 0.0659516973481063, 0.04351992280252519, 0.008753387655522074, 0.04104008086987081, 0.08033757984277703, 0.04655651147327116, 0.04534324653626931, 0.0649083928475457, 0.023199168649772485, 0.04391247008536612, 0.012403623287325666, 0.023218227002108772, 0.025040462891000415, 0.004912371711520058, 0.025253188270594806, 0.041065032353564616, 0.04310835738696399, 0.17301551847448274, 0.07572896342964903, 0.500075230675359, 34.871992834152714, 76.59311863683885, 38.49941645899127, 49.164074236346835, 38.92320502188898, 46.61025824085359, 77.35339164733887, 61.66652325660952, 78.1839378418461, 73.18202157174387, 74.58605750914543, 73.87385706747733, 72.95283748257545, 56.68964739768737, 18.30248917302778, 0.5443347041164676, 8.657588804921797, 68.90901504024383, 80.10429889925065, 74.5606876188709, 71.20568829198038, 69.61618700335103, 61.56649105010494, 58.43989918308874, 53.381912631373254, 53.32517554683071, 62.03897583869196, 70.77512971816525, 70.21831789324361, 67.36771968103224, 63.83125974285988, 68.90582223092356, 69.16855042980563, 67.81142603966498, 68.98881958376977, 65.99746319555467, 65.24755308704992, 64.74730968475342, 61.54314118046915, 58.23726953998689, 55.32835745042371, 60.21052375916512, 60.880139027872396, 64.51876494192308, 59.598492806957616, 57.30019177159956, 49.49889559899607, 49.37406224589194, 47.47213632829728, 49.27375939584548, 48.78245899754186, 48.25319005597023, 48.35832526606899, 46.910048915493874, 47.20623885431598, 47.1874193222292, 50.28932379138086, 48.13915106558031, 54.77509537050801, 53.71203107218589, 56.40932736858245, 57.91150100769536, 60.4763545528535, 57.357889836834325, 59.35032836852535, 60.4905652999878, 63.54640937620594, 60.89633841668407, 54.84703556183846, 66.51547493473177, 63.58627242426719, 63.18176231076641, 63.67873445633919, 60.96321090575188, 59.636324067269605, 59.629585435313565, 53.41704530100669, 46.433673135695926, 46.929798049311486, 43.993166569740545, 45.54096521869783, 45.605397993518466, 42.77853012084962, 44.91212691030195, 46.11676131525348, 46.30458008858466, 45.27713875616751, 46.499357146601525, 46.828141981555575, 45.667708766075876, 45.56660183014409, 45.54322450391708, 47.19533858760711, 47.399713685435636, 51.44350474880588, 57.455835342407234, 58.79728201896914, 60.36001313117243, 59.88171931236022, 60.865112427742254, 59.93399273964667, 56.80482779779742, 57.01218389695691, 61.11038215698735, 61.90888258718676, 56.470331991872484, 59.489046912039484, 58.509584011570105, 60.08601204041512, 60.704730633766424, 56.971085302291385, 55.52995551017023, 51.07930091119582, 50.31795317126859, 52.02056384855702, 53.273514009291134, 51.259129816485995, 55.26339907799998, 55.546711875546364, 59.64047785728209, 62.19429777514551, 66.83741523373511, 54.753212467316665, 24.056057083991266, 19.821880056012063, 51.186103128617816, 59.77116730905349, 55.99559576280656, 61.92340320156467, 67.83397182341545, 68.63799495081749, 62.65878485095117, 32.50517583662464, 16.017795820390027, 32.631915461632516, 51.77822020746047, 37.85994068268807, 61.58917019444128, 18.152097655880837, 0.6162112182186497, 0.046471031382679946, 0.0636185037963573, 0.05145300840658527, 0.08175871124671352, 0.04411352603065391, 0.04420986158713218, 0.026068744407365882, 0.011105967062194983, 0.0354386643025904, 0.07322302854229366, 0.04704629063546177, 0.04235606287576018, 0.03484748574274202, 0.054919583077031764, 0.0107415639344723, 0.17207249488321044, 0.1610178461358432, 0.13362943675489197, 0.10818731204997148, 0.1545219261559748, 0.22810425759563524, 0.20060232930606414, 0.1702730769231435, 0.12292474463221528, 0.13295871145542593, 0.11335560931794106, 0.07704506417916668, 0.11838156744957933, 0.08795436306466019, 0.08353310877517348, 0.21558641155640926, 0.2622647463313995, 0.11520147518885714, 0.18358299658904154, 0.20850487864546238, 0.6777905300259591, 59.825460756978686, 84.9974713786956, 58.04357897850775, 64.06039284121606, 46.82950696637554, 51.57473941003123, 88.20768817778557, 68.99999049402052, 81.50197275223272, 80.66773168502316, 82.64606537357454, 80.94567868017381, 78.5792499972928, 62.730717197541274, 20.665874096655077, 0.9446649193283051, 9.622922347437951, 71.12779786509853, 83.83684988944762, 80.07436337009554, 76.69317829993464, 74.46694297175254, 64.5093983219516, 63.01339457111975, 56.007727653749534, 55.89101752927227, 67.15195009785315, 75.18650962460426, 71.35864503922002, 70.06379219793504, 66.30792663943383, 71.30987428849744, 70.96698068803357, 70.36559504847374, 72.47557132474839, 69.17719533366542, 68.51760172074842, 67.3849702650501, 65.22720775296612, 60.81695748913673, 58.771429677163404, 59.57198935170328, 62.88074785663236, 67.63920261013892, 62.85001216396209, 57.710102988827614, 50.69768567239085, 51.88426540743921, 49.86866527988065, 50.64268227546446, 50.164592419901204, 48.132808593011674, 49.974381000764915, 48.62091225962485, 48.495980847266416, 49.173252582550056, 53.439885262520086, 50.86431580205118, 55.607147755161414, 55.966154452293154, 58.50466535937402, 59.7613613836227, 62.83277726942494, 58.98465756447085, 61.89085929624496, 62.937830109750074, 63.82178721889373, 65.61980955062374, 59.70580885487219, 67.75918006896973, 64.37717130107265, 65.72161074607604, 66.44184420185705, 64.16888560018232, 62.13720767728744, 61.76575922196912, 55.746242846212084, 49.82082020851874, 50.15963062163323, 48.25453150656916, 47.07383924914945, 48.15214195559102, 45.751502360067065, 47.30889120409566, 47.68776862852035, 49.903797949514086, 45.81932798508675, 49.100072922245154, 48.73852845161192, 48.0555732019486, 46.51708233741022, 47.549830636670514, 48.07995465493972, 48.29045257260723, 51.96386991008636, 59.90682248146304, 62.32413999495968, 61.72674340586509, 61.03569630653628, 63.812420598922245, 63.05188086725051, 60.6241298490955, 58.70229005813599, 62.66055776226906, 64.5393495405874, 61.15965889346216, 65.03832209494807, 60.74025554041709, 61.88440699731151, 63.2717610943702, 59.345456784771336, 56.04786919009302, 54.84328577595373, 52.636572084119244, 53.536869787400775, 56.35625770015102, 53.10867248042938, 59.773920812914454, 58.63519007159818, 66.31858764156219, 66.60492066414126, 72.46364731942454, 58.63553131780317, 26.479069878978116, 22.1529838731212, 56.650572746030754, 64.72583470805999, 57.976027919400124, 67.39472127729847, 72.68640656625071, 73.33356626572149, 67.51051748952558, 34.14549927557669, 14.354035239065848, 42.71595262712048, 61.3740203457494, 49.88658266682779, 67.66989907910748, 35.52848385226342, 0.5282423224660658, 0.20637975074350837, 0.3085218706438619, 0.16253067060343682, 0.12770123389219085, 0.122784236446023, 0.16786697861408034, 0.08625829036557868, 0.17511835321784022, 0.16399207524955273, 0.16251127325719403, 0.11679359741749303, 0.14715622059039532, 0.2157052011499482, 0.15971534344698154, 0.13403169420217315], [0.1272301128013961, 0.026749850198205923, 0.05255896357759353, 0.06515632188248058, 0.0344207402949612, 0.04581188933262902, 0.013432325194439581, 0.035207730928255666, 0.0647624607588495, 0.04779248708678831, 0.07251700957215602, 0.05786090871439346, 0.030018848877760674, 0.07295256886150568, 0.038871646017557195, 0.05270839285766406, 0.046472015805662646, 0.023973603101987994, 0.13309758787433948, 0.09588337308096309, 0.5407416291775242, 5.613608917882366, 57.08521842956544, 49.20075624219833, 45.85631985818186, 37.46369500314036, 22.954396663173554, 57.04978373742873, 60.39576161292292, 75.34294943655692, 72.67308619714552, 69.05641771131947, 67.36743727037984, 65.848875968687, 62.28510848937496, 25.123377153950354, 1.6942095732496631, 4.385708974253747, 51.394926194221746, 83.3720019555861, 69.51244031229328, 72.37511942463537, 65.49430547222015, 64.93955681400915, 58.48066829865979, 59.264675571072495, 55.14303330452212, 63.24589306308378, 67.2563635918402, 69.40417505079701, 66.41316383115708, 67.32874701100012, 65.85104896176246, 65.91652116467877, 64.83023643493652, 65.75609622463104, 65.18159058786208, 64.64865030780916, 62.93683382772631, 54.580816453503026, 47.963346512086936, 48.15731163947813, 52.87096508087651, 53.57952556302471, 53.6365685924407, 54.00687956040906, 47.62914880629509, 46.862141086209206, 46.20969403174616, 44.76709727318057, 49.610667459426395, 46.14025631258565, 46.38953862651702, 43.75709087617936, 43.118842801740094, 44.67845955202657, 44.815330659189534, 46.80736126438264, 49.37834155174994, 53.8414575207618, 54.30566218591506, 53.76219034194947, 55.543322947717485, 55.42616567304058, 58.16661588607296, 57.5553576407894, 60.23624666275517, 56.84565574892106, 62.723923652402824, 52.79577716704338, 56.86546371829126, 60.4664074220965, 61.13300638814127, 62.65301504442769, 58.706977290491906, 57.905389954966886, 56.78302334200952, 51.62361998711863, 45.957187529533144, 43.419778808470696, 45.04889211347027, 45.73688760880501, 42.2004904285554, 42.93632707288189, 42.56989140664378, 43.325359513682706, 43.65761564623925, 41.67099398951377, 44.61811780929566, 43.61605028952322, 43.34672466401131, 43.19519958188457, 45.3546408684023, 43.71291322092856, 45.2151535403344, 42.317710461155066, 48.055788932308076, 54.71475362777711, 55.54743359165808, 54.7312040482798, 59.529678744654504, 57.98569656187489, 60.21854500616751, 58.585285755895804, 54.143989932152536, 58.62780817093388, 60.6003132174092, 58.53986078693021, 58.792139791673236, 57.81930569679507, 61.24556664497622, 57.35966274815222, 55.81385666324247, 50.26124746568742, 48.7271692675929, 49.256940272546586, 49.038923171258745, 48.471862193076845, 48.63816676601287, 52.07408066718809, 56.51655320198306, 62.41752378402218, 64.96931583650651, 60.420029317179036, 23.966493683476603, 12.18110001856281, 47.89336358347247, 53.59557590176983, 55.36558858809933, 62.71535327357631, 63.091504650731245, 58.55886467041508, 58.54359880570443, 14.632283276127232, 13.502139583710703, 36.774840508737874, 36.36126972013904, 33.52064609527588, 58.23375901868267, 3.8468917579420157, 0.23139910982741466, 0.2423032222976608, 0.04327991894716698, 0.0462372136873103, 0.10766438809373688, 0.04706011469205541, 0.07351722928785509, 0.10791859138877162, 0.06974672838564842, 0.018694179034942103, 0.03850304664322927, 0.02307097915740263, 0.042890707977236285, 0.05662012206871183, 0.044022120249968384, 0.06473575493380909, 0.08489882137866751, 0.06138737996919982, 0.013657906487013304, 0.029240480564053983, 0.029935427648465962, 0.02153633459050569, 0.012255064474659101, 0.03375733113517204, 0.05741351719705328, 0.023474132927555232, 0.060679158496279875, 0.03191940385037132, 0.07109361054796366, 0.018507826232141065, 0.056102717775971665, 0.04526847635485953, 0.03984927763080886, 0.01774856032082631, 0.0886191588435923, 0.018656131278182712, 0.38662107180683847, 4.49211944495478, 66.02902258596113, 53.355220902350645, 47.87480292781707, 42.8711647372092, 28.645657723949803, 71.26055440595074, 66.43308162689209, 82.53823941753757, 75.9308970359064, 75.66984761145808, 73.8139703196864, 71.9951045128607, 67.08370085685485, 29.42490912252857, 1.7514873320056548, 5.1153340551161, 53.23989537454421, 87.56184639469271, 70.78423746170537, 74.70619970752348, 69.13695181569746, 66.00368407464796, 60.86169604332217, 60.458790179221864, 55.03209298656833, 65.91861571035078, 69.62066635008782, 70.94783167685233, 69.77116769359958, 68.23937231494536, 68.55572715882333, 67.3148069074077, 65.75585303768035, 66.52619869478288, 68.43473772848806, 66.61834301487093, 66.87032391948085, 56.74186983416158, 49.18434112302719, 49.60176367913523, 54.787639110319084, 56.374359438496256, 57.653620858346265, 56.66457952991609, 50.42107620546895, 48.042754896225475, 49.13994773741692, 48.196186250255955, 52.62039230715845, 48.05537316106981, 48.701242400753884, 47.11755798709008, 46.783948636824086, 48.25468840137605, 47.257821944452104, 51.18272989026962, 51.353141184776064, 55.93961569570727, 56.87356341269709, 59.0351188567377, 57.687792547287486, 57.47847918541201, 61.588577916545255, 61.04870680839785, 64.20250031255907, 62.10672693867838, 63.360473340557476, 55.51776870604485, 59.61165235888574, 62.47984240131994, 63.87391159611364, 63.6606405627343, 62.22519820736301, 60.95803729949459, 59.17470816643008, 54.64727317133258, 48.04907383457307, 47.99362720981721, 46.40060363277313, 47.45938862523725, 45.76623086006411, 44.8401867189715, 44.85145961084674, 46.2616301351978, 45.92700489105717, 42.89445184892224, 47.28961275469872, 46.39118994435957, 45.17314887815907, 45.35166378944151, 46.769988921380815, 46.56570403806625, 46.63423961208713, 44.881881513903224, 51.895381404507546, 56.14677959872831, 58.46225669307094, 58.34981410734115, 60.80509624173565, 59.88289602341191, 62.188504434401, 61.45987710645122, 56.324925807214555, 58.91122687247492, 62.36661141918552, 61.28331553551459, 62.933531192041215, 59.95966073005431, 63.26628546560965, 60.395624329966886, 56.85083327754852, 50.953522266880164, 49.982139448965754, 49.82460137336485, 51.42383014002154, 50.97080815222956, 51.0552175583378, 56.759681317114065, 58.71744609648182, 65.09634571690714, 67.4976364258797, 62.15975738340809, 24.88417729254692, 14.655680214205097, 52.24317012294647, 60.46475610425396, 56.91584264078448, 69.09710837948707, 67.9883720028785, 65.7275374474064, 60.11979149233911, 22.480717512869067, 17.284649802792458, 41.99339320582729, 42.78590417677357, 38.24855735225063, 64.88652636927944, 3.516034685796307, 0.46437360286231966, 0.04966019795486524, 0.11116915607764838, 0.041153274191122864, 0.048870594961748975, 0.029873020210934263, 0.048312273912972985, 0.034076127133542494, 0.009086332340244084, 0.07572614422608769, 0.03548519265267157, 0.04803136862333744, 0.05081451242609371, 0.05511552155498536, 0.025138462773494186, 0.0710669889925949, 0.15438039907284323, 0.10314806995372619, 0.09316599026562707, 0.17815022278697262, 0.1373191613463625, 0.0878674197461336, 0.1417142690549935, 0.16514111520542255, 0.2395944886149899, 0.1460228394716978, 0.20822937810613265, 0.188555795879614, 0.1375017507422355, 0.10145713004373735, 0.1335292171326376, 0.20870787662363824, 0.10181517655690832, 0.18144441618313714, 0.19278550520539287, 0.2575840410445967, 1.254275921852358, 16.90185785293579, 84.37908618680893, 67.58111230788693, 66.1334753036499, 54.03235927704842, 34.25842823520784, 72.22746572186871, 75.73379009000718, 86.76140046888783, 82.59043831979075, 82.0195451859505, 79.44566234465569, 79.22910044270178, 72.44019939053443, 31.561235881620842, 2.685635580170539, 6.633455561053369, 55.61359220935453, 89.32208061218263, 73.74555633914086, 79.00332881558326, 71.7217388460713, 72.21452190030006, 64.91555190855458, 64.24736830496019, 61.02325062597952, 68.26979421800183, 71.95101707212388, 74.93584663637223, 70.24071462692754, 71.38149676784393, 70.40739182502993, 71.90029298105549, 68.04934132483699, 71.71238007084017, 72.23315315861856, 70.98479609335624, 69.70975122144146, 60.17859566596247, 51.06331333037346, 52.183161781680205, 56.66192408530944, 59.18554567521619, 59.58065386741393, 57.26525914284491, 51.96816490542505, 52.035296270924235, 52.27958540762625, 51.258902319016, 55.59323118579004, 51.05681004062776, 52.562725620885054, 47.207827414235766, 47.52264076663602, 50.44404168282786, 50.50031985006025, 53.01091524862474, 55.26936500303207, 57.737818456465206, 59.69358282704508, 62.24900699430897, 61.22234621355611, 58.87926740031089, 63.757319142741544, 63.20535144498272, 67.21146814284786, 63.28963141287527, 62.51384935071392, 60.20886459658223, 60.166459852649325, 63.341920529642415, 65.91768218624976, 64.09829470419115, 64.98502492904663, 63.2905767040868, 61.66892374715498, 57.366515128843254, 50.485603117173724, 49.99805250475484, 50.4291876669853, 51.22392654418946, 47.79366477843254, 47.75107960547171, 47.9411066732099, 48.608870583195845, 48.49793418761223, 44.118282333497085, 49.8169723633797, 49.881177640730336, 47.81467691544564, 47.6087877827306, 48.57267495124571, 47.27356633832378, 47.91859619079098, 44.51990950492121, 53.37171839129541, 59.306770447761785, 60.36028377471432, 60.7634053691741, 62.758173788747484, 61.919037603562884, 63.31993172245642, 62.971236936507694, 59.0916637451418, 62.163424799519206, 63.47191572189332, 63.79904139426447, 66.70689444388113, 62.27566342200003, 65.84402791915402, 60.71998080899639, 60.95196154809768, 53.88594112088604, 52.98274870841734, 53.10404800599622, 54.677051805680804, 53.27452598079559, 55.214443975879306, 59.16372160757742, 64.78809056743499, 69.40527331444525, 72.44195661237164, 64.45967051290697, 28.98486233526661, 17.026848100846816, 57.18093210651029, 64.16157430218112, 63.971735508211204, 73.60810864356257, 75.93076367532053, 67.42889296623969, 68.87099942853375, 19.452753643835745, 18.21755809168662, 55.77957122556625, 50.22230225224649, 49.042982824387096, 77.7816987806751, 9.804264307022095, 1.0458922842817924, 0.27207572794248985, 0.20724248832031605, 0.20098350401366913, 0.2302910096102184, 0.2970667111296808, 0.1960168487482494, 0.27048048773600214, 0.1425053620891225, 0.16952312281054838, 0.17108848558798914, 0.237651260629777, 0.16326372481642232, 0.13618749626461538, 0.22879842518558427, 0.14819215532512436], [0.04901693307704503, 0.0555677394262485, 0.048742497399930036, 0.05340902622969401, 0.0576352498554174, 0.04559924247704687, 0.07981263341442232, 0.05903555132869271, 0.04040512421558942, 0.014127238762504874, 0.022799964062869552, 0.024085273823490547, 0.07683612135869843, 0.05419799720027274, 0.032443819762838465, 0.05697750591582829, 0.049802985252632256, 0.041636112596719496, 0.009292990303478174, 0.1416662659856581, 0.11488686586099287, 0.5830477009857855, 38.2067644980646, 71.05127242303664, 42.523254425294944, 87.72718998693651, 19.915261883889478, 33.820856463524606, 91.70317895950811, 62.843552020288286, 76.17090686675041, 68.34788860813265, 61.88910207440777, 55.56932433958977, 70.87307130136799, 26.233833489879487, 2.7758996140572334, 0.7729398759622729, 40.44645747830791, 82.39384128201394, 70.85811922627111, 73.27967289955386, 67.773481030618, 67.57431876274848, 58.64172866267543, 58.093114591413936, 50.88867372082126, 58.86208741895614, 66.85449323346539, 67.80674272967924, 66.18080262214907, 70.50206215150895, 69.74447988694715, 63.742802450733805, 58.91903238911783, 56.16060987595589, 55.49459142069663, 53.15983979932724, 51.3695719934279, 48.90235016422887, 47.25298958439981, 49.227130259236986, 48.44526460093837, 52.40457957790744, 50.00474406826881, 49.08808615899856, 45.710992120927386, 47.73464095207953, 47.44691156571912, 49.719168063133, 46.73674291180026, 46.716840805545935, 46.802364164783114, 44.856586148661954, 44.19440769380139, 43.86223000864829, 47.36864851367089, 49.50818377156412, 53.25358052407542, 56.227352926808024, 54.72543031938615, 52.00897324469782, 57.9413620118172, 56.09725183056247, 57.78973887043615, 57.24812622993224, 60.01258919315954, 57.577244466350926, 62.97030341240668, 58.81701938567623, 57.375234557736306, 65.37136662390925, 59.55663327247866, 59.89487886428834, 56.42660933156168, 56.285364781656575, 54.59449768066407, 51.94342651674825, 44.680279531786525, 44.39940252611714, 43.57788562774659, 43.68742958191903, 42.44328906459194, 42.699274709147794, 41.330587171739154, 42.90245348407377, 40.81833347197502, 43.17787447283345, 42.71883164682696, 43.64446786142165, 44.31187483572191, 45.109830056467366, 45.97030785775954, 48.33464983970889, 48.91334849019205, 47.13729927616735, 46.55530975710961, 46.789510557728434, 49.58523481122909, 52.340123268865774, 55.16834828161425, 59.14945986963088, 58.85825918566797, 59.61752022466352, 56.39667380240656, 57.48290361896638, 57.61824107939198, 55.72108084155668, 60.5095927176937, 59.157885120761016, 59.82793185018725, 62.03049175200924, 56.45904341051656, 49.10487782570624, 47.674644377923784, 49.79828226950861, 52.53148002009238, 52.656164323129964, 52.857993802716656, 53.27665582779915, 57.45225814081008, 64.94094141067998, 68.01101976825346, 66.31441423969885, 23.82035989915171, 11.942864079629222, 44.414103569522986, 55.36620440021638, 60.31155617006364, 55.643092355420514, 58.00704994509297, 51.645628406155495, 43.9604304682824, 6.8748019395336035, 34.93091467888125, 34.87280084240821, 30.4744843898281, 43.44686669688071, 39.30528310037429, 0.3740838284213697, 0.14144569395049927, 0.020562135051154805, 0.06413437591324891, 0.02381811406643641, 0.03461176048844092, 0.004345260761422856, 0.004283700808657393, 0.049578498508180344, 0.05448480902780449, 0.04297212780182881, 0.01998542023131684, 0.05227854475378991, 0.054378445380397385, 0.03207038637370833, 0.0717873874330713, 0.05865451068647447, 0.03482133150100708, 0.014082674470339573, 0.045325186013454394, 0.10218479865861517, 0.024333488226177234, 0.08123145889370673, 0.11056070606554709, 0.02563813787644669, 0.030658951727673415, 0.07430863641803304, 0.04871979821473361, 0.027995436384733167, 0.07011989747444469, 0.04472691347942718, 0.09827352910032196, 0.08319693407224071, 0.03435082711099136, 0.04568813931978038, 0.05180620941363516, 0.11671059179089724, 0.11801070428543514, 0.748455583328201, 44.4236506185224, 79.62155711266303, 42.11575938809303, 84.05298817542293, 26.187255344083233, 46.83243697689426, 94.16001043012066, 71.0185912347609, 81.83698238865023, 75.3374973420174, 69.6833928938835, 62.75934657742901, 75.31651266159551, 29.976057044921387, 4.172847828557415, 0.7597175048243615, 41.925100818757095, 85.98219025519587, 73.82944799238636, 76.9519841286444, 72.08779796477288, 67.50577142161708, 60.947745000162435, 59.92311208478866, 54.04501284322431, 62.237945910423036, 70.28786151639878, 70.74887337223177, 66.82308289312547, 70.64440496506231, 69.9927580741144, 65.66497172078779, 62.54286704524871, 60.26976331587761, 57.83364195977488, 57.78254524354012, 54.989170489772675, 49.61392694903959, 49.26174909837785, 50.4210409041374, 52.011228607546904, 55.64889354090537, 51.65934885701826, 51.17674827575684, 49.57402467727662, 49.80587597816221, 49.838125705719, 49.94821879171556, 50.1084436908845, 48.64999271208241, 48.854560006049375, 47.56470426436394, 46.80361932323825, 46.38844036286878, 48.31869756021808, 51.27695698891917, 55.17040360358454, 59.07397777803483, 56.36660099029542, 57.31587732991865, 59.98161031353859, 59.98664663683984, 60.83807160777431, 61.82449671529955, 63.15358400344849, 61.35620886279691, 64.98032200721003, 58.60952600356072, 59.57215409125052, 66.43331696910244, 63.92391004870015, 64.38695761465257, 60.66506762658397, 59.19125664618708, 59.13697888774257, 54.54664084219164, 47.89505412501674, 47.70976135807653, 46.72082985601118, 46.014434522198094, 46.37505331347066, 46.138228447206565, 44.98371801068706, 44.20748879832607, 44.69654952326129, 45.29063563193045, 45.60152661415839, 47.04063246327062, 47.28995400090372, 46.841748683683335, 45.82379948708319, 50.39684380254438, 50.87689092082363, 48.41470933729603, 48.16348152775919, 48.50785778414819, 51.23298721928751, 55.734726767386164, 56.3733043209199, 59.454569278224824, 59.92546550689205, 62.74952104014736, 57.064739734895774, 60.755878340813425, 59.520194453577844, 57.79607349826444, 62.47305670092183, 60.74836700193344, 62.72923454161614, 64.33982249229186, 58.02596361406388, 51.47011410805487, 50.85771837542134, 52.67925531633439, 55.07134806725287, 56.9526070164096, 55.256660446043945, 56.99723182186004, 60.661510036837676, 66.1754446644937, 69.44466175571566, 67.3108688477547, 25.56931338002605, 13.028202537567386, 51.58581226102768, 61.33631460128292, 64.03090053989042, 61.08645177656605, 64.71183184654483, 59.70065093809559, 48.90288360657231, 15.055917885995681, 31.486859898413385, 43.878084228884795, 31.874556772170532, 52.82832499473326, 42.337361535718365, 0.48922540319542734, 0.05928109016930384, 0.04804181423218501, 0.01355020888900805, 0.038117493743137006, 0.0428111037810243, 0.05410864836566391, 0.13095104015402256, 0.013322449033899654, 0.05817182549846269, 0.024432292500991496, 0.07623681843641304, 0.016572653661451994, 0.07354748209998493, 0.047901692920394486, 0.07453862367378128, 0.03621953389336986, 0.18068016686987493, 0.12468610334420398, 0.1488179265851936, 0.19063737934395192, 0.15034541397565795, 0.15561516426744001, 0.19768256904377093, 0.16281867369769082, 0.14780310523365775, 0.17232204036366555, 0.14036054572751447, 0.1393523280538859, 0.16339910787440118, 0.1802028021624973, 0.1447067923483349, 0.11792800509400907, 0.1767247170209885, 0.1309253455650422, 0.14715658831259898, 0.23891746607278627, 0.2143104308314862, 0.8463445822558097, 61.69496436272899, 92.03942022015973, 58.42002061105544, 107.0862990040933, 30.03868356827767, 42.96232062001383, 108.95657923913772, 76.54763483232068, 86.25725823064005, 82.22098242851996, 74.7795166507844, 68.37569036791402, 80.21309760309036, 33.479731852008456, 4.65402017677984, 0.7507857776457264, 45.117604194148896, 85.48910910083403, 77.87823615535613, 81.6381182209138, 78.24756653078141, 70.77986009659307, 64.12731632109612, 64.46591100385113, 55.37021306253249, 64.94533838764315, 73.59152486247402, 74.73385241723831, 67.84411507268106, 70.67248913549608, 76.08549333387806, 67.48841101123442, 65.72469765140166, 62.02070151605914, 60.274395635051114, 58.47024656111195, 58.93206642520044, 52.85199649872319, 51.49629200658491, 52.886838912963874, 53.85685674605831, 60.76855544121035, 53.15219902223157, 52.288846123603086, 48.97291360362884, 53.86441907575054, 52.490714826891505, 53.65927519336824, 51.87402017654912, 50.86078959126627, 51.11232334567655, 50.41574570440477, 49.6207675626201, 49.22234496762676, 51.74995953036893, 56.55613776176207, 59.868481313028646, 62.3686549740453, 59.196343960300574, 60.74156953442482, 63.16242894818706, 63.75382823328819, 62.39209898056523, 63.58549579497307, 64.53651758932298, 63.894409902634166, 63.85699441356044, 59.239682228334495, 63.77973156590616, 69.72187134527391, 64.70467744335052, 65.21869228732201, 62.710854314988666, 62.214862761958955, 60.920017765414336, 57.57001553812335, 49.46433167303763, 51.4599943930103, 49.706459583774695, 48.2538176351978, 48.10044119434972, 49.7422472892269, 46.40823264275828, 46.85032298488002, 46.92938227807322, 48.74375697105162, 49.15518614553636, 48.64523879943356, 49.262286463091456, 48.7605917838312, 48.25116219059114, 53.93163673339352, 54.16054625664988, 50.00474014589864, 50.85440005025556, 51.05727680267827, 53.210709018092004, 57.35447345241424, 58.05309072617562, 63.363473953739295, 61.13929394752749, 63.908530435254505, 58.00892483803534, 63.59372492759459, 63.48560871616487, 60.41417714088195, 66.13389891962852, 65.6862662684533, 64.38405506072506, 66.61310272832071, 60.86393963906073, 54.976477699895064, 51.318067350695216, 54.86306236636255, 58.7259929410873, 59.73690148322814, 58.52653257308468, 59.89491416561989, 64.99431702398485, 71.04348259587442, 72.48500070264264, 71.22088355402794, 29.73507054390446, 15.056253248645415, 55.60327245343117, 65.20294004871, 72.34112031998174, 66.6504672265822, 69.68803698016752, 63.91499450129848, 54.22923088073731, 10.703460804877743, 50.85579641403691, 52.353078857544936, 40.84727664147654, 59.417785290748846, 58.97599697113038, 1.0594003142849093, 0.3254097579948364, 0.1819799116422092, 0.22265815386368384, 0.15975294304230522, 0.171177520326549, 0.1318989207427348, 0.2289515814834064, 0.2136078056308531, 0.2705182711924276, 0.20083806988212372, 0.131866775693432, 0.1196578163052759, 0.16573414386760804, 0.11632573220037645, 0.14073746098626044, 0.1682220910105013], [0.052940391094213536, 0.04313119063754717, 0.02719928908552374, 0.028390339387941266, 0.0890406221151352, 0.027970908164617517, 0.035739468726059126, 0.08296298614192395, 0.04040403254029732, 0.0163781113787404, 0.05124739423814801, 0.020107052011054852, 0.04064456499632328, 0.06517272382493942, 0.02792109521256099, 0.04832541998175364, 0.02392505802544615, 0.09772134058537985, 0.017799683283233357, 0.04682510956040314, 0.1665514677522644, 0.09640164688349732, 15.373640656471254, 64.1086301495952, 41.01560515742148, 65.08210751318163, 39.940405045786214, 8.050202429294586, 59.43244318808279, 69.3880384199081, 69.94006495321952, 75.58338288337954, 70.72774748648368, 66.50488453526651, 69.23680751554429, 38.77650445507419, 6.38519355366307, 0.10929069316555416, 25.804547725185273, 83.85199023831277, 69.59697523424703, 75.9233739299159, 71.12649563820132, 67.91648280236029, 59.222725822079575, 55.927785827267556, 51.449302011920565, 60.31970293291154, 65.9360545681369, 71.32116286985337, 69.84384136815225, 70.79019946436729, 67.78138852888539, 66.61906473098263, 60.395816526105335, 53.607507751834014, 48.253503845584014, 53.62598211534562, 53.77606768761912, 54.530217878280155, 51.66429104343538, 49.82412284420383, 48.28455725023824, 49.66676519763086, 48.48163673954625, 47.612074728935, 47.612937650372906, 46.44456555766445, 50.27406184904037, 49.36728831260435, 47.375963734042266, 45.412801773317405, 45.32711367453299, 44.756922644953576, 45.09292856339486, 44.29981746981221, 47.435815180501635, 48.58203764884703, 56.764725485155665, 58.707459742023104, 51.713144163931574, 55.05298353010609, 54.97186891494259, 55.75294617683657, 53.85112224086639, 57.214354622748594, 61.87552282887121, 59.967850638974106, 62.01661440633959, 60.443151689344845, 55.94236527719806, 64.0912030589196, 61.85467543140535, 61.377044493152255, 58.204509904307706, 58.60412882220361, 55.97850207359561, 51.3003735388479, 46.652211912216686, 44.7106308321799, 43.29289797813662, 41.92638735617361, 43.755247362198375, 43.34399861674155, 42.287229722545995, 44.32795655342841, 43.84366935299289, 43.3835361080785, 43.8390488009299, 44.844760202592425, 44.84436404320502, 47.94051439531388, 53.628543423068145, 55.74045735020792, 55.209027182671335, 52.759330503402225, 51.341660407281694, 49.91066994205598, 47.77865779015326, 47.99664351247972, 50.94631295050345, 54.09376398209603, 58.44795965379285, 61.22878282300888, 60.22851174877536, 60.58738900769142, 58.71800699541646, 59.96093942273048, 53.6715365225269, 59.93289839836859, 62.89754736808039, 58.85498008420391, 58.199018586066465, 50.0672431145945, 49.49980166650588, 53.64869263864333, 61.54840107887023, 63.27305547652706, 61.65012774928924, 63.80654881077429, 62.07233167463734, 67.72996625592633, 69.94458352365803, 62.76031932523174, 16.37501097494556, 13.248425972077156, 42.84728534760014, 60.23470124890728, 60.92014328125985, 62.791921861710094, 48.11749565985895, 64.44611872396162, 15.590157451168185, 16.755649543577626, 43.801888265917384, 39.33063730116814, 37.71224775621968, 56.03266216093495, 15.43014043761838, 0.3903324307212907, 0.03760561677477053, 0.028669572690682068, 0.06211493367088899, 0.08407615020029968, 0.023611186057209008, 0.08155503145028507, 0.015166257958739035, 0.03376255968525525, 0.06325202265514002, 0.030340854784533865, 0.05204360473961119, 0.036361267820240996, 0.11257903364997719, 0.026415366634366014, 0.012445866333080396, 0.017742399058695284, 0.01086376453449409, 0.023606482277353926, 0.025908337087340416, 0.04518696076927647, 0.016332396997078773, 0.0668837352385444, 0.009078377474760337, 0.007961948924217253, 0.040510867331777854, 0.020480420282711426, 0.03880806838072116, 0.03938221680601278, 0.05693811750520141, 0.01889646646656817, 0.0743127656319449, 0.07439301334201329, 0.09484523201301213, 0.07469374881756884, 0.1113452873523197, 0.08568649766065421, 0.06181206464046433, 0.1045636012549362, 15.941577303794125, 75.05858544380435, 42.621576478404386, 74.00709213749056, 45.33903767985683, 17.54432051412521, 77.41190556556948, 71.3562680828956, 77.99495804694392, 83.55193676487093, 75.1678862110261, 67.95503185641381, 75.99869128196471, 41.128063432631954, 8.354298395495261, 0.09595772191401451, 28.355771033994614, 85.35133977090159, 71.21846737400179, 77.41222719992362, 74.09973852096066, 71.99467305214175, 62.027753937628965, 59.04190847950598, 53.37766078210647, 63.14499401277112, 66.81818777515043, 74.4244009448636, 69.9881689010128, 71.11765461583292, 70.79135264119795, 68.10135979806223, 60.16703644106465, 55.14959150745023, 49.51108632549163, 52.98865187552668, 55.511190891265876, 56.25227566688292, 52.27081891029112, 51.203381169226866, 51.12093687057496, 53.299401652428415, 51.07311925580425, 49.707871637036725, 51.02494470534786, 48.97784010056527, 52.21840427767847, 51.410152835230676, 51.84122916190855, 45.88454523394185, 48.83100617316462, 47.59058798513105, 48.417043147548554, 45.69778942292737, 49.0557187603366, 51.889391945254424, 59.76270283422163, 61.37582855839884, 58.04121771166402, 58.361090921586566, 58.71984658702728, 57.919114328199825, 59.03582880573889, 62.76566551577661, 64.28685480548491, 62.97566921480241, 64.84647504744991, 61.124969451658195, 59.29224983338387, 64.94842921533893, 64.31966543197632, 64.89989772919687, 62.890067408161784, 59.97580128331339, 56.81307261989963, 54.22231966449369, 48.88373459539106, 47.468919984755985, 46.34692991933515, 46.396987207474254, 47.12766201265397, 45.15558450452743, 46.40133319362518, 46.56329178041028, 44.60617419212095, 44.71754989316387, 45.72359469629104, 47.093870793619466, 46.76820032058224, 49.32882947306479, 55.68139037778301, 57.42285997636857, 55.93173173166091, 53.46388624560449, 53.30415164270709, 53.0562892267781, 49.55647599312567, 50.95433419750583, 53.684703919195364, 56.460988906122026, 60.43631499813449, 61.57929758871756, 61.380715831633545, 60.92178283199188, 61.530060075944476, 61.466862847728116, 55.422070718580684, 61.571817628798954, 64.0893477778281, 61.35183149768461, 60.07998727983045, 52.176368236541755, 51.06885171705677, 54.82789047302739, 65.02386031612274, 64.60571212153282, 63.98097661233718, 66.41565061384632, 64.43003308388495, 69.21298303911763, 71.82049628226989, 62.8504789260126, 18.014089061367898, 14.785157653593249, 48.547324672822036, 65.18246919878068, 66.87103779085221, 68.48630905151367, 58.95361984929731, 63.784112853388635, 29.066571189511208, 21.493168646289458, 37.93329684965072, 47.404667638963275, 38.10286483457012, 63.07927077816379, 14.500579891666291, 0.5492783001353664, 0.10091529137665227, 0.05075631272648612, 0.02882060309451434, 0.08791540749371053, 0.04187856027255616, 0.04482961522655622, 0.02952609154876442, 0.060792685065779, 0.07175621531543232, 0.05672590348929648, 0.019672557583919937, 0.010834366868009732, 0.016718242925802068, 0.04904738124159556, 0.02417232247910673, 0.07876787334680557, 0.1351912142408471, 0.11169028738814016, 0.09192778533625026, 0.19227342139328682, 0.20685356080291734, 0.10860356592362928, 0.14859661910562746, 0.26309760647916025, 0.10755935743931802, 0.13683980481038172, 0.2613468504240436, 0.10956570340861237, 0.17721357304723034, 0.15822482745974295, 0.146959044880444, 0.1882087886934319, 0.24872785013529564, 0.18855093888217406, 0.22314210692721032, 0.35126850429561834, 0.4981769260860259, 0.6001492349370834, 33.79341163942891, 83.72857678321101, 61.43295787995862, 78.31449785540181, 53.58902946595223, 13.86052066279996, 70.63702306439801, 84.51158385122977, 81.11861598107123, 89.41671171495992, 82.23582467725201, 79.52882443704914, 80.25078373570597, 49.50984293414701, 9.393730413529182, 0.12174336044418237, 32.19622838881708, 87.280392800608, 72.94605962691769, 81.90070521446967, 78.2229575803203, 74.63574609448834, 66.51596915337348, 62.524800608235026, 56.05270547251548, 64.28977697126328, 71.08104321264452, 77.17308813525786, 72.87894002852902, 75.89272452938941, 72.76410087462395, 71.61112016247165, 62.912762241978804, 58.92577102107387, 52.27939321148781, 58.25085270789362, 58.65520984895768, 60.19878410523938, 55.589532390717544, 54.21979758047289, 52.90402281668879, 55.81882238388062, 54.39268389055806, 53.892522858035186, 51.80032668575164, 49.539339157842825, 55.58612777340797, 53.05462614182503, 51.98438782845774, 49.77086490200412, 50.583230910762666, 49.84839447083012, 51.93828036708217, 47.9626993210085, 52.26431169817525, 53.913170214622255, 62.540454787592736, 65.43222219713273, 59.26121996295068, 60.760212559853834, 62.03567712537704, 61.06552985406692, 60.112389979823945, 65.01258350187733, 66.80854658926687, 63.26997249357162, 64.57217585655951, 59.10574897643059, 62.592065334320075, 65.20550527880269, 66.260834663145, 67.61473486500402, 64.49508559319281, 65.23204795775875, 60.91431071681362, 57.506445684740626, 52.540117079211825, 50.655932041906546, 49.836517533948346, 46.15742452682988, 49.1876555258228, 48.27841481854839, 48.97465905835552, 50.29468567140641, 47.751122751543605, 47.648772424267186, 48.11093745693084, 50.342173807082645, 50.09061259608115, 53.30675609650151, 58.160151820028986, 60.964269945698405, 57.159437517966, 54.2408646306684, 55.202002217692716, 55.10257013382451, 51.262605036458666, 53.61860021468132, 56.22996914771296, 59.20296884352162, 61.76203297030542, 66.13229859259822, 65.53159152307819, 63.410307053596746, 65.23469163525489, 64.48633870770855, 58.8393259048462, 64.13791456530171, 67.26688338864234, 64.8388538822051, 63.97843491646552, 54.19727140857328, 54.35648825860793, 59.016793543292636, 67.7587172292894, 70.89567199830087, 66.01377241073116, 71.51287263439548, 65.78681230545044, 74.41303391610423, 76.12646641269808, 69.16339643539922, 20.04607096795113, 17.845234947819865, 52.464725202129735, 70.7467866713001, 70.5617606255316, 77.15298206575456, 61.486223666898674, 75.61152196699574, 23.5919387109818, 25.70374869531201, 64.95608568191528, 51.73661562704271, 50.58359569118869, 69.55442536261775, 31.478748436897035, 1.0134543442437727, 0.15520999568604654, 0.12795337641070928, 0.28137529989884746, 0.2569573811225353, 0.1924189780989001, 0.1869748049085179, 0.17342139185676653, 0.14316425899103766, 0.13009570298656342, 0.2793947787534806, 0.06762034409949857, 0.17141315365029922, 0.23174613233535524, 0.09987521976713212, 0.13777000408980156, 0.14785542903888613], [0.08366978652174435, 0.057524630589590925, 0.014939481569003436, 0.028894203076619777, 0.0060472739935522124, 0.0337839373687823, 0.05440021376876582, 0.02797801937577465, 0.015252108644363622, 0.05587627367687322, 0.021373081253841523, 0.06541269320634104, 0.042233665008097894, 0.10057923158690815, 0.0452379554119562, 0.0571903404629519, 0.027482130662387902, 0.062020716347521355, 0.11719102851085125, 0.10160234967066396, 0.21801179995940578, 0.18979005545618075, 1.7417808141439193, 62.95467668964017, 50.93282391948085, 18.95083538947567, 42.5212618612474, 21.29968793161454, 14.706423917124349, 88.46559970609604, 60.46825093607749, 66.2469651622157, 72.8368216176187, 73.50503660017445, 61.165318873620805, 40.0169304878481, 7.800281749617669, 0.02495558609464957, 15.85769937884423, 72.06078067902597, 68.4849754456551, 78.12354118593278, 70.51756335842994, 72.7665876573132, 57.559719316421024, 56.95155189883325, 51.805135511582904, 61.35904865880167, 64.7825208017903, 72.67754200966128, 70.87175338499009, 69.57254671281385, 69.35735764042025, 67.990341032705, 64.14892858074558, 57.19350330291256, 52.78323342723232, 56.74876536092451, 63.190983803041526, 63.908122508756584, 61.92375229251001, 56.84214914998701, 51.72406012012113, 49.21338627415319, 49.0911965985452, 48.00570418757778, 51.33249775055916, 51.7002748673962, 55.55761214225523, 49.716944079245295, 50.92612451122653, 46.69709951646867, 43.74841851572837, 43.64478165103544, 44.54035682062949, 43.19030446390952, 47.539789369029386, 49.40093440394248, 61.6467898122726, 55.455391253194506, 56.62719934217392, 56.84266690284976, 55.4896649237602, 54.881238629741055, 54.67839717864991, 57.51091718673707, 59.429548478895626, 60.3373339868361, 61.73194446871358, 63.46787175824566, 53.17832592994937, 62.110476724563114, 59.116919886681345, 61.31130556906424, 58.924394269143384, 54.85084418327578, 53.77127847363872, 51.99622554163779, 45.52597784226941, 43.02262313904301, 45.45251969368228, 43.101866783634314, 43.53978764626288, 42.03709233191706, 42.62303952247866, 42.285554870482414, 43.95332705590033, 44.09528155480662, 45.206512558844786, 44.254439569288685, 51.108942262588016, 54.1819388635697, 58.207377156903675, 57.280081779726096, 54.07056708489695, 56.56996803898966, 54.00569108224685, 56.29925781680692, 55.45204547143752, 50.20254135131837, 49.95814631062169, 51.75094404528218, 55.13944433581445, 58.86662560124552, 60.551848411560066, 62.41468398801742, 62.243688260355306, 62.853624666890795, 63.00299636779293, 56.551878067754934, 63.29737024922525, 62.56513041834678, 56.6660229621395, 47.98158161101803, 50.35023820015692, 58.705192612063506, 61.95477039583268, 64.56632368026241, 66.18413663679554, 65.63199243237896, 68.70520084134995, 67.94516317306027, 76.68961678781818, 54.75708776904691, 13.786160369073192, 19.510626254543183, 47.11802082677042, 57.72654948696014, 61.56377284757553, 47.949390719013834, 58.798866656518754, 52.18777448900285, 4.884367248704357, 38.20707436530821, 42.54663959626229, 32.67571068579151, 40.20332544080673, 43.139733345277854, 0.7764253308696132, 0.11741710105730642, 0.030961039348415313, 0.03672074308739074, 0.04600425784085547, 0.05137572545678385, 0.024131315707739805, 0.007918812907225783, 0.097263878842275, 0.06845332682132721, 0.03497880087384293, 0.06269702259751578, 0.052869807583309954, 0.1057970257956655, 0.030802104832424276, 0.05333718633459461, 0.043673561735739636, 0.03993913974432696, 0.0059231864232119295, 0.010417092182192831, 0.002089786590189643, 0.004117480796506448, 0.022200624751407775, 0.05004044186564223, 0.03237386444403279, 0.03265292729221044, 0.04518656240355584, 0.02356112029613747, 0.023823212381572496, 0.04199865604600599, 0.0934319836538165, 0.1441413122079065, 0.0646864878193986, 0.0024355936517578463, 0.05134440778243927, 0.06692466731633871, 0.06347889193303644, 0.07362661132168385, 0.14255724156335478, 0.25994552239294977, 1.6520264432314904, 70.86603456927885, 57.17375416909495, 24.044466480132073, 51.64889574050904, 24.50436438283613, 32.97633486409342, 90.50649519889586, 69.63983105074975, 74.60379446706465, 77.106305860704, 77.21701083644744, 68.80399750125024, 44.43768485899895, 9.303124643141224, 0.1211644277998036, 18.628642097596202, 75.66128899974208, 70.37977049427649, 79.6870057813583, 73.30542718210529, 74.55174461487802, 59.67028394822152, 61.191312420752745, 53.90445470809937, 64.25613872466549, 66.23198170815745, 71.97548481725877, 72.59243442166236, 71.38207727862944, 71.11723099985431, 69.99092240487376, 66.74188983055853, 60.52590193287019, 52.572868870150664, 59.78325997629474, 64.05057122630458, 65.7890441340785, 63.72199427696967, 59.29880411394181, 53.74547712264523, 53.21298399279195, 49.15033417363321, 50.29775688725133, 53.724104127576275, 54.684469007676654, 57.316308790637606, 49.823448196534194, 53.720256282437234, 48.8813497943263, 46.70474029356434, 46.75533886878721, 47.15330646884057, 47.329648387047556, 50.863954943995324, 52.42625851784983, 64.46513437455701, 61.58929963265697, 59.62579250335694, 58.41702784261396, 58.16478413920249, 57.10849377416796, 57.96084834683327, 61.78652424966136, 62.756514626164595, 63.585538941044966, 64.53832187960225, 65.89385770982312, 57.884366050843276, 63.411181742145175, 62.65512920195057, 62.00240758157546, 61.41010615133471, 59.15288017642114, 57.37008840807023, 54.11369354494157, 49.7614041451485, 44.9698563544981, 47.58684996635684, 45.89270768627044, 47.426350501275834, 45.08919446699081, 44.68115029796478, 45.15295259414181, 47.15138842982631, 47.29418623831965, 46.91789757820868, 45.66450418964509, 53.608966873538115, 55.45614434826759, 59.47205128208284, 59.25768198505525, 58.157994516434215, 57.984457092900435, 58.09045130206693, 56.60810132180491, 57.53510644358974, 52.686276358942834, 51.64961353425057, 53.563879228407345, 57.02603770840553, 59.93493410848803, 62.21058345610096, 65.29687296959662, 62.915241179927705, 64.23111400296612, 65.91859217612975, 57.917494389318655, 66.09378876224642, 64.41191565605902, 58.294328258883574, 49.28287106175577, 52.69358765694403, 62.23192507220853, 63.12360140585131, 66.41438761065083, 68.5477255236718, 67.41216797982493, 71.38967883202338, 71.03293926485124, 75.70425464260963, 54.213733596186486, 17.046473680004, 22.72350242061, 54.19482777195593, 62.37633497484269, 68.96581096033897, 55.42622058622299, 67.0101171924222, 57.1286782910747, 14.891315621714439, 27.525658261391428, 48.15190661338068, 33.54283886571085, 45.41218596120035, 48.25822245690131, 0.6203371226306885, 0.09563140676266725, 0.05076995675241755, 0.035723970767350934, 0.006545375743430229, 0.042873091785417455, 0.012801980389462364, 0.02482488383388808, 0.013257991353560601, 0.0689444428069457, 0.031100247100356127, 0.0015296142420641358, 0.02831988228154519, 0.06381413966958081, 0.09803634061808549, 0.05816434081944247, 0.010200699156660949, 0.05297086990228104, 0.08218325419171203, 0.12452391486975456, 0.10587329750940686, 0.20153957659438734, 0.2044459762832811, 0.19877121062769046, 0.17902244453228291, 0.12809171656807586, 0.12171267862281493, 0.1572462267452671, 0.09214219036361865, 0.193907011961264, 0.2454068283400228, 0.3149879285164418, 0.22200005369320994, 0.1540357820809849, 0.22601944124025686, 0.17987554472300316, 0.34119426423022825, 0.30686614013487296, 0.6993028918100942, 1.1156501669076182, 4.743228602793909, 85.75627742275115, 69.00025721519225, 32.172323503801906, 62.55596776162425, 33.17283384261593, 22.14681790721032, 104.53635831033031, 73.32518023829307, 79.48258753745787, 85.02355514034149, 85.24886392777967, 72.8105809611659, 51.504230883813676, 10.881954143124243, 0.30867916381647514, 21.43398596394447, 79.93653128224035, 71.45318200511318, 85.35597601244527, 78.34654361970964, 79.49975967407227, 61.78059754833099, 63.90733411235195, 56.48365628334784, 68.9876271832374, 69.32637876079929, 77.78041224325858, 74.38159219680294, 74.27954781439998, 75.98200551925167, 73.09061465724822, 69.51067524571573, 64.17405920643961, 55.23031780796667, 62.33060798337383, 68.34439769867929, 69.53836717913228, 66.65828058796545, 63.87592377201204, 58.23298631175872, 55.564625340123335, 50.267939029201386, 53.96421986241495, 58.684462885702814, 58.37810616339407, 61.66652325660952, 53.18901438866892, 56.97719635501985, 52.14981771284535, 48.09183159182149, 47.11964861039193, 50.27194376914732, 48.31914863278789, 52.556998960433475, 54.346541127850934, 67.09140439187327, 64.0004551026129, 63.37273859208631, 60.84962691030195, 60.46778417402699, 59.0331341374305, 60.63927019796064, 61.65765085527974, 64.0384981709142, 65.01825132677632, 66.35701902451055, 62.9212071049598, 57.12591694247339, 64.87359823719149, 63.88806743006553, 64.17807179112589, 64.94603264716365, 60.24758231255316, 58.920275780462454, 55.74052403050085, 50.942876954232496, 48.77849740366782, 52.41981798602689, 49.6264079309279, 49.59830022627308, 46.254558101777114, 47.36787580674695, 47.193671580283876, 49.29062558758644, 48.67432317426128, 49.18622778308008, 48.41102623170423, 54.89698694598291, 57.04030336872224, 64.42574201091644, 61.2402282991717, 60.66732691180322, 61.57000941614951, 59.5003511828761, 60.89640117460682, 58.93574560842207, 54.92872676541729, 53.765481210524044, 56.65086692379367, 59.748943159657145, 63.488715233341345, 65.8895823263353, 68.62181909622686, 67.80769194326093, 68.02957257916852, 68.93717765808105, 63.12101264153758, 68.47924094046316, 69.06919679334088, 60.439570565377515, 54.12524100272886, 53.97772066054806, 65.88001958785519, 67.93731843271564, 70.00480759528376, 72.38369372583205, 70.76260951257521, 74.85426133678806, 76.01085847423923, 80.41579000411495, 60.811642677553245, 20.829907617261334, 24.440092425192557, 58.13475447316324, 68.08516040925058, 70.35385931691816, 59.56600381482033, 71.39148312230265, 62.26852863065658, 8.211424591079835, 52.28927758432204, 63.08315784700456, 44.92478832121819, 52.806347954657774, 65.14926241290185, 4.357276693467171, 0.4135033422179761, 0.18919645988893127, 0.18490543288569297, 0.16380228462719149, 0.1252922014663777, 0.12384339130573696, 0.1212856075876663, 0.275325013264533, 0.22962232210463096, 0.18012003402315802, 0.1565677486360073, 0.12043469074753024, 0.2935048312910142, 0.17555994161915395, 0.1476333401496372, 0.23012895137071612, 0.18141204130745706], [0.099715911783278, 0.07907819258229387, 0.05001662419207635, 0.02399516656183668, 0.05444557766520208, 0.05477821687236429, 0.08343403828480551, 0.08361696475936521, 0.09370520125113188, 0.031216294099126133, 0.051930403757479884, 0.08999580352176582, 0.11690496361904568, 0.09381843670721977, 0.06463787954060302, 0.11232979460469178, 0.039424163950306755, 0.042161491864751426, 0.08578628061279174, 0.028569538844749335, 0.17380713244840024, 0.18027086141369036, 0.19848818710494429, 31.013931881996896, 59.59453121308358, 43.790862483363, 31.97853292188337, 54.00423980528309, 9.164628694134375, 42.386391162872314, 76.81748605543568, 63.51798788193734, 79.46037123280188, 65.48316986330094, 70.16305169751568, 45.47938008462229, 14.908690740985257, 0.15500440833068665, 15.428512653996869, 71.70569635206654, 74.18301043971893, 73.76328545231974, 71.27039955508324, 69.87794245443037, 59.08583902543592, 55.90199624338458, 52.347344352353005, 57.4625700519931, 63.416331814181426, 68.02964318183162, 72.69844039793938, 72.76628171243976, 71.79448312328708, 73.69995486351752, 65.32003064309397, 61.16332630957327, 54.45593210958666, 60.739329861056426, 64.10558246797132, 68.133130996458, 65.58492791268134, 67.01325508856004, 61.48084609739242, 51.42102956771851, 48.85333230418544, 51.47584076850645, 54.52250649852138, 54.862858403113584, 54.986299314806544, 54.493155402521936, 51.622808056492964, 47.84840537655739, 45.449068007930634, 45.44744806904947, 46.44944106378863, 46.45295550746303, 46.277237246113444, 51.120230843943936, 66.12125319819297, 55.802846570168775, 57.16756074659286, 62.58579346441454, 55.82893425418485, 57.19459372182047, 57.693158349683216, 58.69590051712529, 59.075680086689616, 63.574662208557136, 60.92965502892772, 64.02456591206213, 57.381329920984086, 57.9244722858552, 61.389188151205744, 58.36225586552774, 58.258191462486025, 55.410378133097005, 56.497090401188025, 52.98816157925514, 48.12730943003009, 42.65766620635987, 44.389788796824796, 45.53784693441084, 44.049181938171394, 42.99005962187245, 44.11876086265811, 43.743378270056944, 44.82402263149139, 44.807164284490774, 44.551508119029386, 51.30039707306893, 57.67555475234986, 56.659719713272594, 57.97004630488735, 57.617464450097856, 57.42834737223964, 58.40431544088549, 54.582793328069876, 53.73123107417938, 53.93971289357832, 51.06136783476799, 49.062367177778675, 47.59631464558263, 48.085504808733546, 51.930400325405984, 52.9846667474316, 53.03109584316131, 57.896513631266934, 58.951776335316325, 61.395499244813, 58.312312326123646, 62.1088057948697, 64.40130172237274, 58.60187345935453, 50.47177676231631, 51.27564299491144, 58.470348542736424, 66.27470416407432, 65.10375115179247, 68.13644147688343, 68.80042029965308, 71.65513700054538, 71.9764026518791, 72.00957805879655, 25.608382148127404, 2.6575651380323597, 22.19119364215482, 51.74133816073018, 55.84983264246295, 63.776283802524695, 53.67126587898501, 65.27918700248965, 15.481427388806498, 11.551559605906087, 47.29399011981103, 34.01848116228658, 24.38336514657544, 51.39083123976185, 21.556889510923817, 0.21229738159285438, 0.018104739494681842, 0.0613970939640797, 0.06297635357646693, 0.001935712423273212, 0.08710447278234267, 0.02130290568475762, 0.05834626371882135, 0.026913923248949072, 0.052923292011743596, 0.10713059334985672, 0.08222623172426417, 0.07583571778189752, 0.05416665654329043, 0.01219946085550492, 0.07292104434342155, 0.03764578276464055, 0.10602685983382887, 0.09994244398248774, 0.013308371210681095, 0.06508686835126531, 0.0396447551376637, 0.02010354332836165, 0.047265330494772044, 0.04332643963636891, 0.02549941275989817, 0.02535814231622123, 0.03270879042364898, 0.051343427189896186, 0.009579971627963167, 0.012968536522690088, 0.047210264094774766, 0.030801536012140494, 0.06734393191553893, 0.10426113442067178, 0.09734394269124155, 0.02273317077197135, 0.14734625636089235, 0.16548444516956806, 0.10664355295199542, 0.09565569941074618, 28.858875805331817, 73.30814146226453, 38.463287507334066, 39.98359818612376, 42.06525494975429, 18.440780178193126, 67.72856989214498, 75.49915390629923, 72.06631906570928, 81.68473951278195, 73.78363470877372, 74.97656868350121, 55.32527446746827, 16.19867592088638, 0.0921065136489849, 16.931454097071004, 77.19505340822282, 75.4639624011132, 78.02283825412874, 73.6980172126524, 72.64772415161133, 61.60260431228146, 58.662195590234575, 55.32367414043796, 60.6688174124687, 64.93171991840487, 72.29507169415875, 75.27969729515814, 72.73749151537496, 73.88242352393367, 74.13074093480265, 65.60211573877643, 64.42387888508459, 58.24568694637668, 61.33633029076361, 64.46902144339778, 69.01537402983635, 66.86208694211899, 65.85394367094963, 61.98239172658613, 53.19671400131718, 50.96723487300258, 53.460156071570616, 57.488124293665734, 57.63167911960233, 58.496000843663374, 56.92893943478985, 54.31588388258412, 52.02603947731757, 47.90429130677254, 47.5124857502599, 49.75199830147528, 47.9002316536442, 49.856823644330426, 54.062020240291474, 67.83095159838277, 59.64516116726784, 59.367665244687, 64.31464087578559, 57.33879573883549, 60.20624053093695, 59.383680282100556, 61.781644821167, 64.46612281184044, 66.68100680074384, 64.54966537414059, 66.91106950083088, 61.234650688786665, 62.572186762286776, 63.84357206283077, 60.10230556611092, 60.223942187524614, 57.2359315810665, 58.189145980342744, 57.14553271570514, 51.21638774871827, 45.56169494505852, 47.88906074339344, 47.56703415224629, 46.476254386286584, 47.492599333486254, 45.52553853681011, 45.97011958399127, 47.98193462433354, 46.72651729276104, 47.6282976519677, 52.176172118033136, 57.18660385377946, 58.149632023226836, 61.09793647643059, 58.827637241732695, 59.96829386680358, 58.948673740510024, 55.87745789558657, 56.4144499840275, 56.18414409698979, 54.00474971340549, 49.38272283923242, 50.53405223354217, 51.958829664414935, 54.294848211349986, 55.541875593123905, 55.803234884815836, 60.83231356836135, 61.50294080857308, 62.43396243741436, 62.52275705337525, 65.50152655570739, 66.54610080103721, 59.36320550980107, 52.41484834301857, 53.50360808833953, 59.459644825227805, 67.21164072713545, 69.36717141059138, 68.6231448573451, 71.04858167709844, 72.46618901529621, 73.38942866171561, 73.73764884087348, 25.17035145913401, 3.8999079840798534, 25.966353339533654, 57.93126190862348, 63.141244226886386, 67.97335716985887, 59.428054055859974, 67.01364732557728, 28.22007271551317, 17.524532156605876, 32.990533844117195, 41.55223246543638, 25.351615951907252, 58.89396452134656, 23.518543320317423, 0.16529698345449664, 0.06913623291878931, 0.03111898944142365, 0.028552202275022868, 0.01697156330450408, 0.022221343599319942, 0.01130268790744125, 0.019374491924780513, 0.06923278297988639, 0.045202056531824415, 0.05035622713847026, 0.11058803242180618, 0.11077375511728949, 0.09862838868772793, 0.02457627298070058, 0.044984514374406114, 0.016498013714989348, 0.06476567832813149, 0.22055174915059922, 0.2449481714997561, 0.212803551206185, 0.15114545491674256, 0.14310358482743465, 0.17752733201749865, 0.23404070356440163, 0.18137839472582265, 0.19824262528169542, 0.12180282418886501, 0.10092523519790943, 0.1845129353985671, 0.17911431379616263, 0.3363482984563997, 0.159650961417825, 0.3448647140495239, 0.2448154084624783, 0.271920058876276, 0.1574101848828216, 0.22895381846014531, 0.45068863719221086, 0.39633243134425533, 0.3112972233324282, 51.869474149519405, 80.30130386352539, 64.23793500469577, 47.12490458642283, 73.63381585767193, 11.603499631727896, 56.1538790887402, 90.31686429054507, 77.59309553330945, 90.2927730929467, 78.26296575607793, 82.71039224440052, 61.43800597037039, 20.576626446939287, 0.3208253039948402, 21.705982723543723, 81.5660172124063, 78.49211062154463, 82.24663472944691, 76.35797254500851, 75.38076108501804, 64.01106903629919, 60.82379418034708, 57.34594621965962, 63.128355318500155, 69.05778269613944, 75.33917611645114, 77.70974682223412, 76.97560464182209, 78.05744140378891, 79.24964581766437, 68.64981697451684, 66.53826390543293, 60.807704617900235, 65.67832346885436, 67.9787935749177, 72.98289852757608, 70.9178255450341, 70.03278193935272, 66.36095708416354, 57.31728546081051, 54.019697866132184, 58.758732964915616, 60.01753530194683, 60.417942616247366, 60.447019146334746, 60.160078156378965, 57.332465033377375, 53.73002690653647, 50.07913181858678, 50.89918567288307, 52.430973206796956, 51.01203618511077, 50.10891829767535, 55.74789024168446, 71.6638760412893, 61.3329452853049, 60.5760141341917, 66.37841163143035, 61.35327100753785, 64.88364734957295, 62.86676852933822, 63.6079199852482, 65.4516496965962, 67.75303763727989, 65.39426149860506, 65.22437580170171, 59.6266907261264, 64.7625716270939, 64.46881748014881, 62.56687587307346, 61.41393830699306, 60.25558787007486, 60.6060516449713, 60.68622489129344, 51.84413563820624, 47.8069184672448, 49.4477165129877, 50.5261133563134, 48.20675311550018, 48.99068978524978, 48.50650848880891, 49.14738062889346, 51.22376180464222, 50.00182974723078, 50.1171709645179, 54.96459291827295, 61.070832898539884, 60.01348349355883, 63.36731003176782, 62.403285580296675, 60.63311599916028, 62.60778619397072, 57.262348744177054, 56.18118270750969, 59.022877139429895, 56.77849692683066, 51.2724619527017, 50.76608788582587, 53.2958754416435, 56.534921661500015, 59.49589537036035, 57.76081139041532, 62.419971343009706, 63.16861844831898, 67.46910510524627, 65.4291235246966, 70.16754673373315, 69.00727041306035, 63.43988172469601, 54.98989612825456, 58.74251396425309, 62.33726032318608, 70.86250443612376, 70.63471671073668, 71.94058356746551, 74.26692562718546, 77.58903980255127, 75.33206878169891, 80.58271823390838, 30.546277492277085, 6.335908482151647, 27.50503443902539, 63.75953135951873, 64.32006159136373, 74.35237838375953, 64.08542148528561, 77.3787223139117, 22.261490360383068, 16.435002646138592, 68.96792904023202, 48.21080884625835, 39.86252246364471, 64.11910287795529, 41.89476913021457, 0.17722172422274468, 0.19555794675984692, 0.1680183422661597, 0.11875639894917128, 0.10741615262363227, 0.1946792592324557, 0.09159913361673394, 0.12818746989773167, 0.21626921040156197, 0.18317808847754233, 0.2774375466810119, 0.2794274753860889, 0.1677250071999527, 0.18408443177900008, 0.11479245318520455, 0.1493858582069797, 0.26667048734041954, 0.2757310705079187], [0.02849758212124148, 0.04227314534927568, 0.024080650482867515, 0.061603861094843, 0.026170831368935686, 0.0028450666896758544, 0.03359341513245337, 0.098842847341251, 0.01887212210755435, 0.0701241952276999, 0.05278315154775497, 0.044776310828784784, 0.03886519555723475, 0.0452740534749483, 0.022673737670805667, 0.06330183752241635, 0.032500517930114464, 0.15677623180372102, 0.05222486114249595, 0.0665748256048368, 0.03308660200526638, 0.07834007452812888, 0.24849666012150629, 3.7239031445595527, 71.47071499978343, 45.43168014095676, 43.51286841977028, 61.67300301213419, 38.48846912384033, 7.26478849687884, 84.34892316018382, 75.69850444793701, 78.46062183380127, 73.93687386666575, 63.95069199223673, 51.89909981143091, 23.60330770092626, 0.35620566517595326, 11.081527279269311, 72.30426572984265, 77.9353380203247, 74.62859953603437, 72.3561429977417, 63.49180606103713, 58.569078522343794, 56.81137815598519, 54.95222176274946, 53.551457082071614, 60.64336907479071, 67.57770769057736, 70.0757711164413, 73.94349482751662, 70.46935742901218, 71.486616288462, 70.274823557946, 61.05090333569435, 58.716551796082534, 60.32537468018071, 63.7726556101153, 68.07119677143713, 66.1209237190985, 67.03493010613226, 68.02054328303184, 58.95925237286476, 53.33716623244747, 54.080737790753766, 57.637111602290986, 60.38315119281892, 58.16841625398206, 55.54923788193734, 50.11269946252146, 48.21473513880084, 45.08514265860281, 45.86025007309453, 46.19088626676991, 45.97031178012971, 45.83810044873146, 53.86835713540354, 65.64922340454595, 55.82623174113613, 54.939623109755985, 62.32553243637086, 61.355526370386926, 58.25119395409861, 57.40185568409582, 59.57573521521784, 62.38213616032755, 63.75828796817411, 60.179227167560214, 65.63218855088758, 66.35990588895737, 55.629148329457934, 59.180870209970784, 58.033894646552305, 57.125356043538744, 55.964938517539736, 56.18661911256852, 50.10589807264267, 49.29454403538858, 46.21354579925538, 44.412075704143895, 45.13580006937827, 43.1190546097294, 43.812815989217455, 41.63948951228973, 44.398845549552675, 44.36054360482001, 45.960803954832016, 48.62474441528321, 56.69280098330591, 60.743005121907885, 59.02550904981552, 55.52334239405971, 55.670917649422925, 57.93628254244405, 55.75143606432023, 55.67969983623874, 53.39825322551113, 51.19326145418229, 51.47342066611014, 51.07046773356777, 49.16584714766472, 50.240039210165705, 49.48635185918501, 50.18049763094995, 52.749936426839525, 57.477545661311, 62.52156073047269, 64.13638484093451, 59.92403776414933, 59.4748479320157, 66.74275275199645, 58.87870650137625, 52.906450763825454, 50.605211873208326, 59.12425471890358, 61.177509600116366, 68.25745444143972, 68.7629851987285, 66.44912412089687, 67.78807224765902, 69.01314612357848, 25.284135495462728, 1.542923633129366, 3.813479292777277, 26.822391017790768, 48.42280510933169, 61.31048187132805, 62.817785970626346, 71.50956999871039, 47.332092023664906, 6.479817792292565, 38.66605051102177, 46.50351485898418, 30.58522858927327, 34.72333500462194, 54.41644560906195, 6.193795127253379, 0.19659294686730833, 0.09473617939699082, 0.03651029490415127, 0.08568007784384875, 0.1222107353650274, 0.04129111639133865, 0.08408621659562474, 0.06178956463812821, 0.046089423835397735, 0.06563982295413172, 0.017630826013403076, 0.029156331551231207, 0.04142401732444283, 0.06508933515438149, 0.040054263607148206, 0.04443085880108899, 0.07068643481620858, 0.006461932010302741, 0.028023682046501387, 0.09046953697238239, 0.05444797552040508, 0.04451747653224776, 0.03288787879770802, 0.030395204892321944, 0.05658112436292633, 0.021977942144017548, 0.006913423534452676, 0.07271104432161778, 0.024569673133232904, 0.027482854615476345, 0.029968836742843834, 0.04224573855378455, 0.02330819445271646, 0.08338409701302167, 0.013717377892575197, 0.028294082355475234, 0.06485803788828273, 0.05970723040762448, 0.08112802170217037, 0.1000070481771423, 0.48280757821856013, 4.866012027186732, 83.80087391022714, 50.29485433332382, 39.13873534048758, 56.69691162724649, 25.268726464240785, 25.909029860650342, 88.43367161289339, 79.10356106296663, 85.30315737570487, 80.84030812786472, 69.98558013669907, 58.340035638501575, 27.405308177394254, 0.390390622760019, 11.907370551939934, 75.12778389838435, 81.58342469123103, 78.32348008309641, 75.59851538750434, 66.62791359809138, 58.74349455679617, 59.100426320106756, 57.54720695557133, 57.00649253783688, 62.18473895903557, 71.17313261955016, 72.78168878247662, 77.07348346710205, 72.38672179560508, 72.68387271511939, 71.74723425219136, 64.06134205479776, 60.0594497496082, 62.222256429733775, 67.7807217259561, 69.94261449383151, 68.71266903415804, 70.32624583090507, 67.9054452526954, 60.63120972725653, 51.89005482581354, 55.574109631199995, 61.90298334244759, 63.366929561861106, 60.55719460210493, 57.96893627412858, 54.663590231249415, 51.74626465766661, 48.190012439604736, 47.61347893745669, 49.01759332226169, 47.62909781548285, 49.32186726600894, 57.400784877038774, 68.89365503864904, 62.18181287088702, 59.44436327103646, 65.43353226877028, 63.67267439442297, 63.69285891132971, 60.759926226831254, 60.818220492332216, 63.24497522846345, 68.28615834636074, 64.50177323433661, 67.30852327039166, 68.45525956922963, 58.4430645358178, 63.920870211816606, 62.235718004165165, 60.750387022572184, 58.95190577353201, 59.120681439676595, 53.95006795083323, 53.09796833222913, 46.49966701384514, 46.35695549749559, 47.40465587185275, 46.16948973747992, 46.43519109295261, 44.355111122131355, 47.82644010359242, 48.17727650365522, 49.077358476577274, 49.19062868241341, 60.68907645440871, 63.39244850220219, 61.54006996462422, 57.10335154687205, 58.57509151581795, 59.62358028657975, 58.20183092548002, 57.10833687936106, 55.54732376529325, 53.85904935098464, 52.062270410599254, 50.52443065950948, 50.21323765477827, 50.845445279152166, 51.953436405428, 53.08873115047332, 54.945008524002574, 58.11825306184831, 62.608382394236905, 66.34935471319383, 63.207206726074226, 62.14886888380974, 70.21716471641295, 59.41744012217368, 54.91191548685874, 52.48090497909054, 61.60892717299923, 62.61146929956252, 69.67840363902431, 73.75350306110998, 69.36634771285519, 67.29419877452236, 69.78162473247897, 26.362689233595326, 2.3265474938577224, 4.888584286935868, 30.490791643819502, 53.222546731272054, 67.8288648974511, 66.08649315372591, 75.96850472111856, 52.503317402255156, 18.812591452752393, 27.729397935252038, 43.82003315033452, 37.16034281638361, 37.22616411024524, 65.72795714101484, 5.41436771231313, 0.29447917255663103, 0.07635677248359689, 0.09627109784032069, 0.062161891030207764, 0.04840837198219473, 0.06299964647980467, 0.058846718316236814, 0.04921281026796468, 0.02046338823293486, 0.030430117434251214, 0.011670084523728058, 0.018758942192840963, 0.024895093876928575, 0.09825865167283243, 0.039413963489594965, 0.05432129522124606, 0.04007602050419777, 0.026002359058287357, 0.15585844314867453, 0.20570332574988567, 0.1480184372274145, 0.13768472318207065, 0.23508209284515152, 0.14175980532121274, 0.17547395591053272, 0.18943776226332112, 0.1150446723125154, 0.2337025676763827, 0.13501429389561379, 0.13838272121164108, 0.10174762292374527, 0.1894448102722245, 0.3078314722065003, 0.24642033202032892, 0.1304394006729126, 0.20666033810665532, 0.2082126161023494, 0.264919608711235, 0.18982506567432036, 0.30277008250836407, 0.922548818972803, 10.489009138076536, 98.80797201587309, 64.63746370807772, 58.51206687188918, 90.80959243159141, 49.26306701475575, 13.580520306864093, 99.98636184200164, 86.52772134350192, 90.52929201433736, 85.54252393784063, 75.51088179311445, 62.583632238449596, 31.46145078443712, 0.5495026719666297, 14.536510763629792, 78.15957207833567, 85.50017018471995, 82.27187910387593, 81.28301035973334, 67.04259441744897, 63.63520006979666, 63.966314792633064, 61.79634978694301, 61.02500000307637, 64.75093395479264, 76.39499187469482, 76.35328139028242, 78.82657897087836, 75.55351011214718, 74.34770291851413, 76.08309284333261, 66.2719585049537, 62.96684780428487, 64.92668359510361, 70.11366905704622, 72.76537172255978, 69.19296326175814, 73.53663521428263, 72.0074599789035, 66.62701929769209, 56.456191847401286, 60.02614098210489, 63.4798663662326, 67.85254816855154, 61.403410665450565, 59.65285685754592, 56.16241808860533, 53.44289372044226, 49.856411795462336, 49.57555440164382, 52.2030834997854, 50.41924053622831, 50.69211590674616, 61.026576795885646, 71.22913622087049, 63.44206648488199, 60.0799794350901, 68.09689614080614, 66.69610792590727, 65.67938250880088, 61.19434833526612, 63.510076461299775, 64.66907016692623, 67.35513671751946, 65.25357000289425, 69.05024390066825, 64.36074833716116, 60.96743529842746, 66.15908053613478, 63.48300034000028, 62.08567165559339, 60.94614075076196, 60.51441331063548, 54.74297115879675, 54.78097892576649, 51.57394316888625, 49.3993733006139, 50.80249140339514, 47.110340825973026, 49.54950594132947, 45.638828354497115, 50.01177687798777, 50.62103471448345, 51.20829982142295, 51.31146207932503, 60.57820673911803, 63.41974427623134, 63.28459116720385, 57.86079260610766, 60.25869438725134, 62.162765841330256, 61.2587458087552, 59.05139669295281, 58.50762674885412, 55.076666801206535, 55.563825176608184, 54.39140912025206, 52.74936376079437, 53.60100446208831, 53.96407865708875, 54.967468015609256, 57.49153675571565, 63.17322723327145, 67.3476920589324, 70.2969535704582, 68.28193003131499, 68.88228016514933, 73.27501312378915, 62.42771802410003, 58.097593938150716, 54.87648079472204, 64.54382888732418, 67.39783563921529, 72.24255900229178, 76.15244034797915, 70.80060943480461, 69.38859539647257, 77.05941000292378, 30.195978456927886, 3.9541869682650415, 5.838946142504293, 32.24198872043241, 59.11175804753458, 72.59349346160889, 72.50427522966939, 83.64479495633034, 58.13362090818344, 11.165620934578682, 52.92869060270248, 66.50445307454756, 46.89206877062398, 48.48809688322006, 76.17639818499165, 15.260078234057273, 0.6382113635059327, 0.2270009684106035, 0.12845848882270436, 0.18057988596058663, 0.29438675170944584, 0.27713668863138846, 0.1918102905995423, 0.14184836508525958, 0.11765818126619824, 0.11092278220119978, 0.18127566233517664, 0.12336570484143113, 0.08094951555493378, 0.2156231071679823, 0.18255225593043914, 0.13013910952835314, 0.20666032278489685, 0.12676534257949362], [0.03117258112216669, 0.05474529807425795, 0.06924626612735373, 0.04652677960092983, 0.03003066195355308, 0.06182356362020778, 0.08604389299908954, 0.06615158500930955, 0.03210915999877597, 0.03085494957744114, 0.02171355179480968, 0.04084864315847236, 0.0777842241129087, 0.0409834708027061, 0.03265419516772513, 0.04534604275719293, 0.05223545613848875, 0.09872932843263112, 0.05239857157932655, 0.04301977080983981, 0.04281123784641105, 0.050451260345477256, 0.12527226785858794, 0.2721664021092077, 52.480234253791075, 56.96544101161342, 69.75339935671899, 70.04292518861833, 73.35786927130916, 14.531336176779963, 26.201485703068396, 83.92800577225225, 64.70238677916988, 75.81096664551767, 64.79233849433162, 65.01603126525879, 32.97416187101795, 2.3423534199114773, 1.2220953260698628, 59.418318733092285, 82.4852168175482, 72.02608339248165, 70.57987413098736, 63.59126952386672, 68.97435388257428, 61.56158808738955, 63.72637164208197, 57.24971478985202, 56.56064456509006, 64.70579531884962, 70.18247527460899, 70.96836920707457, 75.7560299288842, 75.39780770578693, 72.24660688830961, 63.61056758511452, 58.56803909424813, 55.373492163996545, 62.13801568554294, 67.5668348804597, 68.23825051707607, 66.83144538633286, 69.3476458518736, 60.25869046488116, 55.21515000251032, 51.80450400998516, 60.86421028260262, 62.41036938082788, 59.11946942729335, 57.40094569421584, 49.4563300378861, 45.90395704392464, 47.92611145204114, 46.27471123972247, 46.324478272468816, 44.62179307014712, 45.3603086933013, 52.978724356620546, 61.88236344245173, 63.60604901467601, 55.0851861892208, 63.641734738503736, 60.29470959017354, 63.89445697107623, 62.26294709790138, 63.630234349158506, 63.98245534589214, 63.08657423142464, 61.41474631524856, 63.38323485466742, 64.21696993612474, 60.41645996032223, 59.68988010960241, 57.694519412133005, 56.09164676358623, 55.947036820073286, 52.04665545494326, 53.88681188706429, 51.93532682234242, 48.86379326543501, 43.88499152275824, 46.14250775306456, 44.77428697770642, 44.959540520944905, 43.34185700262747, 44.30176296541768, 45.12979099827428, 45.82326996710993, 54.07499151845133, 57.03531019149288, 60.68024327678066, 57.93775735362884, 57.22034800437189, 55.13339604100874, 53.35631524362872, 52.92492904970723, 47.37255519436252, 50.160556300993896, 48.4492418842931, 48.64952987240207, 52.063356907136985, 53.949573732191524, 53.861767553514056, 54.772486994343424, 53.61179882480253, 53.95579068891464, 58.48601841157483, 62.58804490489345, 63.53152005903183, 62.77296504666729, 60.02372087970857, 66.05490238435807, 63.03310055886546, 54.29950014237435, 52.68101646054176, 55.138338227425855, 63.41473148715112, 67.50328463892784, 71.70482558588829, 69.27855722365841, 68.9360950839135, 20.422012498301847, 0.7874235342587195, 0.6977512879717735, 6.944975593397695, 35.37554671687465, 52.508314501854684, 63.17557673300467, 66.15620151642831, 67.16086956762499, 15.27295635592553, 14.461708222666095, 47.7780576675169, 43.147095634091286, 26.19276039062008, 41.18987998654766, 44.48898946085284, 0.5593643685983074, 0.10874290199529742, 0.04612516566750504, 0.04038853458158913, 0.013457571621984245, 0.06410662820863147, 0.02812308195467678, 0.04285764745286396, 0.02155136140514045, 0.026978311023765036, 0.02749886968353343, 0.013950577929555891, 0.04334890516474844, 0.10382896123994743, 0.095450135038024, 0.06550404919131149, 0.029934527495154933, 0.07715229350592821, 0.015032447296224776, 0.020317973253587564, 0.07184339612121544, 0.03294378789442201, 0.07460565636715583, 0.03491040454396317, 0.024956834817966147, 0.051655213483759475, 0.08934073705947207, 0.0318175831043552, 0.05882845094968235, 0.03568159844425898, 0.04879079158267668, 0.008913812212525837, 0.01857582802673982, 0.04708980442956091, 0.05654372395046296, 0.033287604324399464, 0.06953001743362797, 0.09814579926070668, 0.014933070370687113, 0.02257532793127241, 0.0719208476103602, 0.23053336918594378, 0.4375581659616963, 59.77806283581642, 65.99884386985534, 64.6987154406886, 82.15838924531015, 42.196948528289795, 17.510962716994747, 48.16911405132663, 85.46827347047868, 75.74659270624961, 82.34685913208993, 72.31607206406133, 68.8264177691552, 39.378176427656605, 2.916007412056769, 1.809347685306303, 58.981249024791104, 84.24493328217538, 77.06093972729099, 71.85999454990511, 66.52502982847153, 71.0280284573955, 64.4635497370074, 64.84729482281593, 58.69073475560835, 59.02058255287909, 70.71964386970767, 71.88952999730265, 73.46062752508348, 75.81734441941785, 76.29607754368936, 72.28447344995314, 67.73731677762925, 62.737510742679724, 59.18331384658814, 62.9163198317251, 67.27035860861501, 69.48320296502882, 69.46603867315477, 70.24328770176058, 63.451778273428644, 58.664156775320734, 55.51880028940017, 61.82418292568576, 65.16258278200704, 62.4155939778974, 59.55145182148103, 52.62527958039315, 52.13912140938544, 49.943017728867076, 47.64135129990117, 49.4475321615896, 49.45995823029549, 49.78457358575637, 55.58251527047927, 67.51043904212214, 65.6001074852482, 60.39336504474763, 65.99263083550238, 64.09976951537594, 65.98104415401336, 66.22253664078252, 65.0062527964192, 67.3606986384238, 66.03576121791717, 66.28971899709394, 64.50148297894386, 71.20342900676113, 65.42453435159499, 61.28981490289012, 61.378754646547385, 58.40593537976665, 59.27509338625016, 56.005123199955115, 55.04822569508707, 55.73086323276643, 50.202243251185266, 47.41615626119798, 48.90446432175175, 48.55360046509774, 48.77417495173793, 45.81020455206595, 45.822316831158055, 47.489210405657374, 47.102919701607, 54.79600552589663, 57.50583771736392, 62.42322298788256, 58.96659897219751, 59.08908282556842, 58.98800726859801, 57.34460084669052, 54.61758475149832, 51.72863360374205, 51.69207711373606, 49.92352354911066, 50.896059543855735, 53.77801710559476, 56.05599634109005, 55.587637885924316, 56.6308157674728, 55.95517966055102, 56.845953849054155, 61.49694350457961, 63.16293493393929, 63.464396538272986, 63.322681303947206, 63.306980056147424, 68.52231640969553, 64.2833991973631, 56.159888159844186, 53.63489374037712, 54.34782374289728, 67.89294073658606, 70.0893582067182, 72.48911134658321, 70.96166195407991, 70.67601926865117, 20.277800675361387, 0.9410828760554715, 1.154895564240794, 7.7753693057644755, 39.70776927086615, 57.56910554824337, 67.37252066212316, 70.20201652280747, 73.96958643390288, 24.569312949334424, 19.21289090187319, 31.040082323935728, 50.5144246931999, 28.89532639134315, 46.76161858343309, 49.49223149207331, 0.1616146133070992, 0.08648917394419832, 0.029553199569965084, 0.0610442491879146, 0.03544442145334136, 0.10022719120306355, 0.01908780075609684, 0.06552116359553992, 0.04928366957052101, 0.03617793531908143, 0.06787301521868476, 0.031107745185915022, 0.027814995865487767, 0.12715674456088774, 0.06684909274260845, 0.0374365373394422, 0.04009956238611091, 0.005303004732160199, 0.029911297794070937, 0.1940322366933669, 0.21070984823088493, 0.169749241322279, 0.16856508389596017, 0.06494151082851234, 0.15201321803033352, 0.106603785327846, 0.2054145259241904, 0.13532010087322804, 0.16170177879112382, 0.10460586632571875, 0.13652025421540584, 0.1723975000242072, 0.12710016130680038, 0.16189300965878273, 0.2524728556313823, 0.11995259161678054, 0.19983273269909047, 0.2862270572973836, 0.12227867970303183, 0.14189734874713805, 0.1538420997319683, 0.32844751111922726, 0.8733547587067851, 82.27169083010766, 73.79116565950456, 89.98647520619055, 87.94022960047569, 101.72018281875118, 16.810060662607995, 36.727952495698005, 95.67089957575645, 81.07594843833678, 88.67995723601311, 78.63573212777415, 76.6799363782329, 43.09003299282443, 3.7388157508065625, 2.6556039529462017, 62.97795987898304, 88.21471706513437, 81.55738015328684, 74.69238511977657, 70.2987107922954, 77.69574396071896, 67.66523930334276, 72.13581562042236, 60.27413283624957, 61.175728844058135, 73.62672421240038, 75.92681777092719, 75.52459439923688, 80.16730785369873, 81.11767461222988, 75.1026964187622, 71.2276614096857, 67.27610095854729, 60.83857367115637, 65.6955740528722, 70.31920909881592, 71.70216621891146, 70.3623394812307, 73.647748116524, 65.97757677878103, 62.42676881051833, 57.7509662412828, 65.72029675206831, 67.21357837800058, 64.47499129080003, 61.56925632107643, 55.23515016801896, 52.67686659289945, 53.25703220982706, 50.2580899576987, 49.729566266459805, 50.06003772058795, 51.298459422203806, 56.295880656088556, 67.8694143602925, 67.01735004301995, 60.91775455782491, 68.56034771088632, 64.13075623973724, 67.47722441150297, 68.81279145517658, 68.77956897981706, 67.83537603193714, 67.15901036416331, 66.5494034367223, 67.48971323813161, 66.562849321673, 64.12050708647698, 63.9976506079397, 63.05001774141866, 61.33874647078976, 62.15935337928034, 58.53617768133841, 57.33723463550691, 56.25884563692155, 52.15220643628029, 48.883601234805205, 50.641046647102606, 51.02252068058137, 50.619226501834014, 48.770856626572154, 47.25852797108312, 49.48203332962529, 49.83725886191092, 57.91581169251473, 61.04865973995578, 65.44014146251064, 61.321527265733295, 62.8194922016513, 59.64223507911929, 59.61646510708717, 57.5312860550419, 52.4959864924031, 54.21367476063391, 51.21549737068915, 53.527687518827385, 57.72720452277892, 56.19170642668202, 59.04096711066462, 58.07158470153809, 59.08321103742046, 58.86990470270957, 62.82398723786878, 65.76412531637376, 67.70261949108493, 66.67993207131663, 69.07663360718759, 71.22399791594475, 66.30939360587828, 57.99261562285885, 56.966688325328214, 57.19594693952992, 70.29310180294898, 73.81870854285457, 75.95185818210726, 70.40135921970491, 75.28810685680759, 25.537216624905987, 1.6481420710202188, 1.4369621512389954, 8.328350936212848, 43.50575716264787, 61.86067665776899, 73.53666659324401, 76.6349938607985, 79.8517688628166, 20.504280290296002, 19.342933162566155, 68.65289211273193, 57.47903223960631, 40.23806587342293, 53.78991757669757, 69.810807166561, 2.2768973967721386, 0.4433195148744891, 0.11383962366850146, 0.160602274080438, 0.10612335626877124, 0.2125835767196071, 0.16823759663008875, 0.17993551408571584, 0.22239026823832145, 0.12169263010183651, 0.1629891742261187, 0.18342086174074682, 0.1511645764713326, 0.25467404074245886, 0.29910919346636344, 0.12876825647488718, 0.10835775895224464, 0.16089602283412413, 0.12844132079232123], [0.09178813516853318, 0.024118974031279647, 0.03158744646146173, 0.15885660484913858, 0.03310012728756955, 0.006758835131017071, 0.012252783447864556, 0.06250349346608405, 0.026155285529732227, 0.03896340802912751, 0.020763233131278428, 0.034465793925788135, 0.041174540791900895, 0.046063185323991125, 0.04358660692589418, 0.00424747777757265, 0.033162172748557026, 0.05863950302403781, 0.06519218245821615, 0.015888428935150228, 0.11001540468104425, 0.09989562068855572, 0.3353985026478768, 0.5716379551637558, 13.034792119456878, 69.87864063632104, 47.07682417285058, 54.33333450748075, 47.966413805561686, 55.77819839600594, 4.538463719429509, 60.31850661000898, 75.8033964710851, 73.7670587724255, 73.3626074944773, 63.954673197961625, 42.56433733047978, 6.736605561548664, 0.9081751709022831, 43.57243745557724, 87.82608078372094, 74.62808962791198, 75.5694741587485, 75.48200530390586, 75.28390992072322, 73.75120455218901, 71.59794884343302, 60.421833607458304, 57.80060383581347, 60.93269878818143, 67.25295897453063, 72.21735385156447, 76.56073554869621, 75.88689588731336, 73.36946379753851, 70.75332918474751, 61.720448001738525, 56.066559283964104, 61.30115839742846, 67.72230978934996, 68.48734455723917, 68.89284703039354, 68.32608807471492, 62.54453405257195, 61.030377572582616, 60.26431122133809, 59.022873217059725, 62.357589967789195, 61.84346921982304, 58.984720322393606, 50.48155130878572, 47.56191153680125, 46.99681958844585, 48.09644429914413, 46.46265160652899, 47.8186777330214, 47.44589567184449, 54.67303529862435, 58.608741529526256, 66.38283606498473, 57.60810175249654, 54.482321816106, 65.01928683250182, 60.359632661265714, 62.36248508576424, 62.22010304850917, 61.18185166389712, 60.27838076314619, 60.83251360924014, 63.275934496233546, 65.60286883384951, 62.68224846932196, 58.59891206987443, 57.74607504567793, 56.04709648316907, 54.7234534448193, 56.0844688261709, 55.77837882503387, 54.67413748464277, 48.94253484664425, 45.56432685544414, 45.192984304120465, 42.765021477976155, 44.16394656704318, 42.430317786432084, 44.76912513855965, 43.210532126888154, 48.61180059371456, 54.21065845797139, 56.500510707978286, 59.81138729280042, 57.11251420359458, 54.286670069540705, 52.7296224717171, 50.89040348606726, 48.79577544427688, 48.899180889129646, 50.226150097385535, 54.88017174505419, 56.017690473987216, 59.419707252133286, 59.01054912997831, 59.60295646421371, 55.774142665247766, 57.00953237472042, 59.23610502673734, 62.17981246209914, 64.38491798216297, 66.0977425113801, 62.51463382474838, 57.42799435892413, 65.82238428054318, 63.51149635930216, 56.601684324203006, 50.900836990725615, 57.60799192613172, 60.88987827301026, 69.30208359995197, 69.18976260769752, 77.43055251336868, 40.33268520908971, 0.47708949795173067, 0.11237979716350956, 0.5156930668219444, 12.262288178167037, 38.47486242171257, 57.386232883699485, 52.99415496087844, 66.63793133151147, 30.459948085969497, 7.327643988593933, 39.87790992183071, 52.91112230670068, 34.46656096366144, 33.63865060191001, 59.98674077372397, 20.88438541658463, 0.31123575243738394, 0.05183792545370037, 0.05292947817173216, 0.012100909389705669, 0.06012873964444284, 0.05602761051587521, 0.09934555423716385, 0.04510915687968654, 0.014431243518277284, 0.08337312663394598, 0.03614565620439188, 0.10296957912824808, 0.028503197545726455, 0.08723497586024385, 0.017987056898193497, 0.033404949842201125, 0.021925135703396895, 0.049626187481466806, 0.0612576736227399, 0.043124307337547504, 0.08043803695228793, 0.03584169932911473, 0.09493824274789903, 0.038944569927069454, 0.03259392703072198, 0.019732450337840185, 0.03257076053189174, 0.05707797451665806, 0.010939360175642275, 0.04731555904952749, 0.0035662163751229888, 0.015281940108135104, 0.08602995019886764, 0.004591392362565404, 0.08168947222011705, 0.028116922607765566, 0.11260489677830089, 0.07856648415327072, 0.017257197271852244, 0.039787737787851406, 0.1481839122190591, 0.18553108157169435, 0.553004184076863, 16.712374033466464, 84.94382904421899, 46.37091521293887, 61.006576630377005, 47.02092647552491, 31.729868381254136, 16.583875225436305, 72.54078465123331, 82.55021049130349, 80.23489029176774, 80.1880415024296, 71.9577713935606, 48.55644810584284, 7.9325318144213774, 1.123745326072939, 44.83415803601665, 90.33765285245835, 78.22422842825614, 78.89692275754868, 78.35189373262467, 76.06640708061957, 78.30733560746717, 72.25067830854847, 63.436245687546275, 61.36947824108986, 62.81850768673805, 71.96586716559626, 72.85249540882727, 77.33605477117723, 76.65377416918355, 75.68794542743315, 70.90259105928483, 65.21748027493878, 59.36168363017421, 64.99759612544891, 67.55278495050246, 70.62050988597255, 71.463011464765, 70.7482457930042, 64.35772026738813, 62.02824815627068, 60.97205192812028, 63.848400500512895, 64.8451022178896, 64.46115709120228, 60.179956728412265, 51.68065124942411, 49.05163557298722, 49.977377691576564, 49.12067713276033, 47.74893799135762, 50.36509613836966, 49.44141326412078, 58.32879804795789, 62.84667030457528, 70.24480173664709, 62.80640717475646, 58.77079033082532, 67.2952264355075, 62.4223522217043, 65.4881630405303, 63.06011784461237, 64.34098351386287, 64.41320219347554, 64.0195256663907, 63.847706240992395, 65.43820381164551, 68.676771502341, 63.119259342070556, 60.87727569764661, 58.558025283198205, 57.22216798413185, 57.67861027871409, 58.19742218140633, 57.024535440629535, 52.046439724583784, 47.057216244359175, 48.38757830281412, 46.6166046357924, 47.01452516740369, 45.3451761891765, 48.04609675561228, 46.192447370098485, 51.10498066871397, 55.01598381227063, 59.513416597920084, 58.420252030895604, 58.94382961334721, 57.118723315577355, 56.240991007897165, 52.04774979622134, 50.379452013200336, 51.10660452996531, 50.805029176896625, 57.573341708029474, 59.02949417791059, 59.727248530234064, 61.39051391232399, 60.55138557187973, 58.166074598989184, 58.942060624399495, 61.048953917718705, 63.05589737430696, 62.98789524262952, 65.81370799772202, 64.21350256089242, 61.555347596445394, 67.7629533890755, 66.58940376773958, 57.91123820889381, 54.530755242993756, 57.42200882204118, 62.22943436714911, 71.96422761486423, 71.98625564575195, 77.66651445819487, 42.18684058035574, 0.32196842975193457, 0.7377046731210525, 1.0761389064212, 14.093452576668033, 42.80275075666366, 63.69900134301955, 56.48114596643756, 73.52420130083638, 38.46595079668107, 18.168659863933442, 29.582356983615508, 47.88530703513853, 42.098748068655695, 33.14304344115719, 73.16502201941707, 18.424545488049908, 0.4008997862617816, 0.0203915196095383, 0.057421446207069585, 0.027076944844016147, 0.008135675640416243, 0.05820970471587874, 0.14371539796552352, 0.038551949865875706, 0.014624151160880445, 0.020972691145875764, 0.09427275748983507, 0.01265756132441663, 0.06368226912473479, 0.04984976641172844, 0.005066764762534971, 0.016741702453263344, 0.04947628322688322, 0.07126307685769374, 0.04040209433784889, 0.1625949913455594, 0.11692894217107566, 0.16126055811201373, 0.3272788593124959, 0.11232365824041829, 0.09344808682198487, 0.08605316266297333, 0.18649889576819637, 0.11592035677524344, 0.10036091951112594, 0.11961015031462717, 0.12739241618903416, 0.166028045838879, 0.20687973036641077, 0.25244506196148936, 0.2179109827885705, 0.08571295833755886, 0.19470113870357314, 0.191342118947256, 0.15293235500012675, 0.19729906542887612, 0.3137040877294156, 0.5151420350997679, 0.8205808615011554, 29.034382258692098, 96.68913902774935, 64.1953694435858, 68.81204620484384, 73.58455873304798, 73.41521432322841, 8.128882233173616, 75.49879304824337, 89.92738862191477, 88.77737322161275, 83.27553518356817, 79.25944389835482, 52.59683062953334, 8.745516577074605, 1.6854126775457015, 48.32149813252111, 91.89715585400982, 83.96227944281794, 82.55301106360652, 81.71201567496024, 80.85221644370787, 83.59425129428988, 74.97964382171631, 66.41630957203527, 63.46151359619633, 66.36400084341726, 74.17609137873497, 76.9590679291756, 81.36078311551003, 81.62388786192864, 77.99661328715663, 76.53331818119173, 69.0482670261014, 61.3890391011392, 67.41540785758727, 71.8052774860013, 73.74921198814147, 73.81375066695675, 72.85701397926577, 67.48557905997, 66.46210716616723, 65.60759528990715, 65.31369601526569, 65.81615555670955, 68.55345218412339, 63.26712485282653, 54.10048300220121, 52.281770167812226, 54.216863647584, 51.37422000208209, 50.01730349756057, 51.5060979320157, 52.3951070539413, 58.361804792957926, 64.77819050512007, 69.6299780568769, 64.5846176147461, 60.49958675138412, 67.99673449608588, 63.86970681528892, 66.70010874348303, 65.47873366263606, 63.84100291036791, 64.8053333067125, 65.61671480055779, 64.96921385488203, 67.32330276120094, 68.80897891136908, 63.81085557322349, 62.577556487052675, 61.37261613722771, 59.19551241782404, 59.955338278124415, 61.35162753443564, 61.55955629964029, 55.2026847101027, 51.91762516575476, 50.41475726712135, 49.67125631147816, 48.88607232801376, 47.17362826870334, 50.17887769206878, 48.34680526487289, 52.58747577667237, 58.36349141213202, 61.4526834795552, 63.73176882343908, 62.34364594182661, 59.69228452251804, 59.18708716669391, 55.23723686895063, 53.64062432319888, 51.8504035857416, 54.23662062614195, 59.6503661524865, 61.638815633712284, 62.27251768112183, 63.42014043561874, 64.48366365125104, 59.71709351385794, 62.10818998275265, 63.661860419857895, 68.96610121573173, 67.61184015581685, 67.62403872705275, 66.89378753785165, 64.23031383945097, 71.14232632421678, 68.66685575054538, 61.3124587458949, 57.87749405830138, 61.16507176429995, 66.69317399301838, 75.19488780729233, 75.35977640459615, 81.51954497060468, 47.67577009816324, 0.8525476881092595, 0.4298813827335835, 1.2353318545126146, 16.16104764323081, 47.8738497918652, 67.50533996089813, 62.1191490850141, 79.18997087786275, 39.67468407846267, 11.076840046913395, 52.84610902109454, 75.41797653321298, 48.01345871340845, 49.440252242549775, 74.3088871432889, 35.11026897738057, 0.468110365252341, 0.10315957659434888, 0.2145897005234034, 0.27774370605907134, 0.13936547412266656, 0.14090111268864525, 0.2637262888733418, 0.1804633027002696, 0.11405519314951475, 0.15319876973667454, 0.22995796054601672, 0.1759080672937055, 0.14984247725336783, 0.14562016833693753, 0.1024587746829756, 0.1189797059182198, 0.17666652498226013, 0.1829806216541798, 0.11477854102849962], [0.047427821573951555, 0.06034800166925115, 0.04829487605621258, 0.01748815171360489, 0.015404305417060614, 0.03265088566789224, 0.05236415890976787, 0.06240260734733555, 0.020566559208917524, 0.02787711027438843, 0.08199069033106489, 0.05092006785074069, 0.045046107843518264, 0.04570546056774836, 0.06507071921782148, 0.045783666653498534, 0.07937397912985857, 0.025041499024918003, 0.04799173123413517, 0.02530140775976883, 0.04336566333809207, 0.024117748290600798, 0.07178337313234806, 0.04335841231588875, 0.12799225537286651, 48.26121914771296, 54.7641166563957, 46.42087051945348, 40.980550935191495, 61.695474270851385, 20.17450701805853, 13.386743453241165, 76.74658529220089, 71.04579679427609, 67.1177234957295, 66.57662468571817, 59.17648892248831, 15.695503488663705, 0.2819747483778385, 13.943182652996434, 72.96028214116251, 82.17023480323054, 76.91225836353918, 75.89543096480831, 82.23219256247245, 80.30835628509521, 73.44209824838947, 69.9810694110009, 58.474031648328236, 59.04780380187496, 69.2366349312567, 73.73386767602736, 74.25206768897273, 76.87094796088435, 72.6079434733237, 71.13728215617519, 62.50231366003714, 56.81324520418721, 59.87285475577078, 67.15542531782582, 69.54246213359218, 73.18466524924003, 67.61252264822683, 65.44179670272335, 65.4654799738238, 65.90921771141791, 62.75775409513905, 64.63790301353701, 63.50216504066222, 61.19638012301538, 52.9029167083002, 49.56454430857013, 49.120182914118615, 48.320929388846125, 48.17401309167185, 47.8990549425925, 48.59784480064146, 50.98142993065619, 59.50777230724212, 61.43675865665559, 70.62266718956732, 56.10244897104079, 55.64364148724464, 61.64455013890421, 62.801582659444506, 62.357680182303156, 62.94589842519453, 60.93946487672868, 61.01690030867054, 61.939410394237896, 62.703958788225734, 61.339876113399384, 57.4494497237667, 58.07728390539847, 58.41444300067041, 57.49629459073467, 56.24945156035885, 55.61972287393386, 55.95459522739534, 52.38010398803219, 45.209293519296956, 46.00145932166807, 43.94516068120157, 44.85149883454846, 43.96522360463297, 46.63697742646741, 45.38587470208445, 48.98284896727532, 53.89106765870125, 56.754566546409364, 53.81985310585269, 57.84474226736254, 53.00471005901214, 52.15448141098023, 47.25425650996547, 51.45957469940186, 55.03932191479591, 59.99743315481371, 62.17910643546813, 63.372530706467174, 61.39853908169655, 64.30547429669288, 59.51538955011676, 56.316382884979255, 55.07075971172702, 57.913073878134455, 62.135203346129394, 66.10143738408243, 63.86302701888546, 62.735224000869266, 60.366296768188484, 67.83816091475948, 67.27264142805531, 61.80921908347838, 53.063800565658084, 56.957039294704316, 60.957174378056685, 74.29617866393059, 63.98853894202941, 80.71061888048726, 20.475386150421638, 0.8372292391234829, 0.2504149289621461, 1.5078902484909182, 9.022128985774133, 32.7579882837111, 61.0730843390188, 59.55157341495637, 60.55510790117326, 12.500226997560071, 13.111271473669238, 44.39343660108505, 39.796920822512725, 30.69814382060882, 45.61606291801699, 54.847682752916896, 2.8158359614110764, 0.15823003685762807, 0.10130146097752357, 0.027826107970829454, 0.06735857951665117, 0.04620132246805776, 0.03480794028409066, 0.02142136969092873, 0.04808837705622277, 0.014757231167036922, 0.0385941498191847, 0.027970004180866866, 0.03280586142453455, 0.016749461008716496, 0.016090234688993905, 0.06678328578991276, 0.027193733032852895, 0.018680263047797546, 0.07891388970517343, 0.04144337253584977, 0.03222003015839765, 0.04409069278007073, 0.01644489700875936, 0.06377205462946046, 0.09602590373927548, 0.013673034808298033, 0.04951628833828915, 0.013022264184039688, 0.04897628828222233, 0.026600365376760884, 0.0926476551760589, 0.01605483663884262, 0.05341170370698937, 0.058460763219984314, 0.0162755417817783, 0.10909654350290376, 0.032474068744528684, 0.05012966812618318, 0.04482464714636726, 0.08084943382850579, 0.049740606543397715, 0.02080530284964029, 0.07149527810754315, 0.022734212651548368, 0.23568693458312945, 52.659031575725926, 66.21344458672309, 44.98391805156585, 54.23328268912531, 39.04011126487486, 25.364626453768825, 34.50678486977854, 80.94915390014648, 81.53193966034921, 81.13668241808492, 71.68370754488053, 65.03559212530813, 18.630258114107196, 0.23151463588639615, 15.917528271675112, 72.15634530590427, 84.24538043237503, 80.89627250548332, 78.51491528172647, 84.00374674027967, 80.34997263262349, 77.06680759306877, 71.87741771821054, 60.49696660810902, 62.804563660775464, 71.36628581631568, 74.90759772639122, 78.59646135760893, 75.30083102564659, 74.80366276156518, 72.2223666406447, 66.03943255639845, 57.70026960680562, 61.81450251610049, 67.67611211346042, 73.01689763222971, 73.27815886466735, 70.15745055290961, 69.33990309315344, 67.24857376467797, 65.80134468693888, 65.45468561110958, 66.57984887399982, 65.8689663487096, 64.3686362235777, 55.26927086614794, 51.37664010447841, 51.72941023303617, 51.36926997092463, 49.052149403479795, 50.224224213630926, 50.1971951607735, 56.14571663641161, 63.66958748909735, 65.68123386752221, 74.11652626529818, 57.286161453493186, 58.55849596761889, 63.43651240871799, 65.59539671867125, 66.03241151379001, 65.60111553438249, 66.38122789321407, 64.04668807983398, 65.37703444880825, 66.01119149115779, 64.67576565281038, 61.74636702383719, 60.412843535023356, 59.95476561207926, 61.837668034338186, 59.29154772912303, 58.67059730714368, 58.471999860578975, 56.53711818879651, 48.72282328144197, 47.589046493653335, 47.83308852103449, 48.755473090756325, 46.632941307560095, 48.93688271122594, 48.82501279154132, 50.54640769958497, 55.64726183491369, 59.7943445944017, 57.20628238493397, 60.10199569886731, 55.10764960319766, 54.82208536517236, 50.044140354279556, 53.099121509059785, 57.217990659898334, 60.34397063716766, 64.11076784133911, 65.22514850862565, 62.74206069207961, 68.18116434158819, 62.194925354373076, 59.37631014854678, 58.0192171373675, 60.50083014272875, 63.22760697334044, 68.63910105920607, 65.66190050494286, 64.83454711975591, 65.37743060819565, 70.40331256005072, 69.04974968202653, 62.128888330151966, 54.940639003630615, 59.38005208969117, 62.73534559434461, 79.17392053911763, 66.57816225482573, 84.96479019041985, 24.254907523432088, 0.7387968693529406, 0.8369209040557185, 2.7695125245278884, 13.222204927475223, 37.12759494781494, 67.48313934572282, 62.07856039847098, 68.44538304113573, 23.02786461768612, 20.37068828459709, 28.483706981905048, 44.00516117772749, 30.969758149116274, 49.52456358940371, 56.987010125190984, 1.9115691872373706, 0.16430653902071138, 0.08864122217581158, 0.0824138543177997, 0.06000613110260137, 0.026269239193249135, 0.05864163657890693, 0.020674623571516528, 0.05365153136212499, 0.04826001139477857, 0.05483147147442064, 0.06796807140832947, 0.04574931527097379, 0.024220800522955197, 0.05851229029377142, 0.06514592606934809, 0.010876118659883017, 0.02485457548661338, 0.09556832708298199, 0.034699772499621875, 0.13398143883434036, 0.18528568828778882, 0.14647314595358987, 0.24876768670735822, 0.14213129667745483, 0.1678212584867593, 0.18468581079956026, 0.21262937345572058, 0.15614374961343505, 0.1427305459735855, 0.2774452994908056, 0.13650431958658082, 0.14736741570936096, 0.1512740351139538, 0.1441096880983922, 0.20407967900316562, 0.16560335733717488, 0.1202585747946174, 0.1596332954302911, 0.18229236826300624, 0.2550549243366526, 0.09036593124150269, 0.2893269554741921, 0.1615433977736581, 1.0203317913316912, 77.28255364202684, 73.81847320064422, 63.13798865964336, 60.96117127326227, 90.97870934394099, 25.391422125601, 24.040196980199507, 87.70691133314564, 87.81198378532164, 80.86239107193487, 82.53565849796419, 74.72301098608202, 22.380514683261996, 0.6279537526349868, 18.720723659761493, 77.93840531379946, 85.62587430400234, 84.62701920540103, 82.21572645248906, 85.33768207796159, 84.78531822081536, 81.61450555247646, 75.42924158034786, 64.2947623037523, 65.47409349872221, 76.44774775351249, 80.3662504688386, 80.41056540704544, 80.90197563171387, 77.51108661774667, 75.9088219365766, 70.70719426678073, 61.83084703260853, 67.20763990955969, 71.1754075942501, 73.77210294046711, 77.52255562813052, 70.07469638701409, 71.98139975147863, 71.0196267404864, 71.07170012689406, 67.06188463395642, 68.17591621029761, 69.17040178852697, 67.70041511904809, 58.511015676683, 53.4448705950091, 55.39681457704114, 53.429318397275864, 51.81358429693407, 52.8945424479823, 52.4324127166502, 56.90218494784448, 65.60487708737774, 67.33928249728295, 69.43693468647619, 62.39950049308039, 60.383021754603234, 64.78962421417236, 67.50068018513342, 66.89315995862408, 68.44025258095034, 66.59039220502301, 63.587519737981985, 66.31826600720807, 66.0322859979445, 67.15026347867905, 61.77085830319313, 62.00747528383809, 63.60446829949657, 64.12681818008423, 61.71676489614672, 62.831000435736875, 59.37486671632337, 58.01705198903238, 50.41310594927881, 49.46069563588789, 49.911254375211655, 50.841989671030355, 50.34611186673565, 51.296604141112304, 51.89105895257766, 53.25607122913484, 58.67986979023103, 62.120455234281486, 57.5390366585024, 63.84548617947487, 56.20505425237841, 55.99075163564375, 52.15801938887566, 56.1190523639802, 61.09725790639078, 63.10502506071522, 67.36280102883616, 67.14956529678838, 64.64956029768913, 68.9330199456984, 65.7361823512662, 59.865292426078554, 60.675273633772335, 63.81711959838868, 66.82912334319084, 72.04797021804318, 69.15754425910212, 66.9233072957685, 67.78060405485093, 74.48860229984408, 72.40667097030148, 65.22685866202077, 58.332641970726755, 60.538300544984885, 65.709318037956, 81.63360749521564, 68.81945948446952, 88.42847839478524, 29.948294508841734, 0.8514990669585044, 1.02203042276444, 3.2735792571498505, 13.034211608671374, 40.891548433611476, 72.82779232148202, 68.57242861101705, 73.40822465958135, 18.584229100135065, 16.428483666912204, 63.42888732110301, 57.597072047571984, 44.020227001559356, 60.65152368237896, 73.69062746724775, 7.060238853577645, 0.7988920543463001, 0.20329178821656013, 0.3165557121317233, 0.23937544875567962, 0.1528985552009075, 0.1809460453448757, 0.25480445955068837, 0.15179244681231438, 0.2184059675182066, 0.1800380779370185, 0.20019343753735866, 0.22800671928111585, 0.07953269722601099, 0.09136237414373506, 0.1439237585591693, 0.10566267695638443, 0.1107751877017079, 0.2393445907340896, 0.16379221823186646], [0.030541979677734837, 0.006620817688188606, 0.09919281162682081, 0.09045868150649533, 0.060565467217877034, 0.005726228090709136, 0.021611840216322772, 0.01479186217165402, 0.033073160992634874, 0.031217033373973066, 0.027216575859535127, 0.03348359259806814, 0.022901830774161126, 0.028739296267890645, 0.0714948031330301, 0.05507158641252787, 0.009063100723940279, 0.01360377375667374, 0.04412614732920643, 0.039522859057591814, 0.08060005688739401, 0.03673649002467433, 0.08587950585229744, 0.12200003054233328, 0.5107467128865181, 8.251379324543862, 69.80016969865369, 46.38619676713021, 51.16775035858155, 48.72577290381155, 63.03062554328673, 4.835630818720787, 38.49209339387956, 74.12805803360479, 44.571708325416814, 70.78961895358178, 60.02959266785653, 31.46674990653992, 1.4445556147444634, 0.5199344972929647, 22.40568845502792, 93.09390237254482, 76.8070133270756, 81.58170669309555, 79.1460560214135, 82.81478220416655, 75.53865217393445, 70.63104537225539, 60.75189713508853, 63.352671746284734, 64.62853639356553, 75.5592446173391, 75.96723387318274, 76.8245541664862, 76.16667855170466, 73.48109445264264, 64.19852302920434, 57.169427794794885, 58.864970361032796, 67.86669223539292, 69.50004562254875, 72.29420092798048, 70.61389676986202, 69.41322003641437, 66.88716657700078, 69.20375762447235, 68.08894157409668, 69.26474263591152, 66.20410934571298, 59.70670315527148, 50.053303011002086, 49.4056216362984, 49.87042250171785, 47.66165348791307, 48.4115400621968, 48.431803026506984, 50.747656668386156, 49.90062082967451, 54.30329699670115, 60.45778213008758, 63.05942750746205, 72.43766553940313, 59.89536916055987, 60.41835446511546, 60.035778245618275, 61.67969065327799, 63.6649198685923, 64.00698584894981, 63.02212576712332, 64.65933484415855, 63.948165985845755, 61.790140674960234, 59.775736870304236, 57.702521047284534, 56.09108586465159, 57.70798490893457, 57.955274658818404, 57.15493855937835, 56.87276717155211, 54.900050317087484, 46.05365822392125, 45.12988513515842, 41.553919084610484, 43.38120622019614, 43.613822383265344, 45.60670806515602, 46.680292160280295, 52.2223384149613, 54.21503974545387, 57.176754782276774, 55.669097669662975, 56.83016238674041, 49.88651598653486, 46.814041060786096, 47.9673747862539, 54.192697924952355, 59.455224314043605, 63.79378541823357, 63.20597117946994, 65.45804708234726, 63.544134401506, 63.318794235106445, 58.43405877390216, 57.51125058820171, 56.05743977331347, 62.00354114655526, 63.77176915445636, 65.98879475747385, 65.67667999575215, 61.854141989061915, 62.60619763405093, 66.95672588963663, 66.92377013544883, 64.41912105006557, 54.40322722158125, 58.60595272433374, 59.10316021211686, 71.94692996240431, 66.20097929431547, 76.71242144800003, 17.271564775897613, 0.5774290895750446, 0.28241003953641464, 3.332745514569744, 10.53359373923271, 44.87711191177369, 58.44959920452487, 60.37875421585576, 35.767285593094364, 8.121349321257684, 35.933974558307284, 46.84256453667918, 46.76543897198093, 32.45445762911151, 53.10802921172112, 20.527553673713438, 0.13405057060862743, 0.04849425426894619, 0.033031321100650296, 0.058308825001961766, 0.05515753764719252, 0.05484084456017422, 0.09038629385853007, 0.08325128034958917, 0.051778588113525224, 0.05863289168525127, 0.055910333945986726, 0.03895126936596729, 0.012042062345802063, 0.045071794771619385, 0.023169919412823457, 0.06697001206057687, 0.034889930844186776, 0.013586136497436993, 0.0300372158357453, 0.0197458760287132, 0.07478466813242243, 0.0148805933478739, 0.028176552976571748, 0.04966259197962861, 0.014422422015829193, 0.01772723434823415, 0.05770358489826322, 0.022317497209916194, 0.02793624460126364, 0.0456765101050898, 0.06453669464756405, 0.04153600405721415, 0.032472651481868765, 0.05838587429494627, 0.05592859365166195, 0.08058769988917536, 0.10586587411742057, 0.05544975039459044, 0.048483869947132566, 0.06666898547161011, 0.08331629057084361, 0.030584461168356003, 0.151332885988297, 0.060205670193799084, 0.7221001362608326, 9.555830205640486, 83.72311684393114, 50.100049818715746, 57.78404358894595, 47.529202891934304, 32.940704053448094, 14.861803708537934, 54.13021849047754, 80.94989130573889, 56.832633479948974, 78.69722704733573, 68.1997642209453, 35.252960881879254, 2.034685400224501, 0.5194204216522555, 25.072294166011197, 93.30076033069243, 80.98343541545253, 84.82183548711961, 80.40818845072101, 83.8026782005064, 75.26467461739817, 75.27073075694423, 62.71938939248363, 63.733690784823516, 66.0436922504056, 76.8234480580976, 78.16138421335529, 80.18365629257696, 75.81641089531684, 76.75377107435658, 65.45262636676912, 59.72371839707898, 59.955695213810095, 69.82622208133822, 70.73926356530959, 74.84768744437926, 70.69184995466664, 71.141785037133, 70.1692255081669, 69.96181057345483, 68.30642131067091, 71.09876448108305, 66.48297417548396, 63.557015465151885, 54.93267659218081, 50.979139266475556, 53.100796361123365, 51.05461743570144, 50.86882260537917, 49.73873676792268, 52.16125926663799, 51.80410785059775, 58.359455293224705, 64.6796448769108, 68.33046543982722, 76.12235576875749, 59.86269189465431, 63.12637059919296, 63.91485329597228, 65.843549389993, 65.90133374737155, 65.28794565508443, 64.49062585830688, 66.70788288116455, 65.71014173569219, 63.76664261664114, 62.5614433903848, 61.60557746887208, 58.932921501898, 61.214681902239406, 62.03937592044954, 60.89989600643035, 60.007360673719845, 58.77165325226323, 47.99194451301329, 47.902985157505164, 45.186798726358724, 47.240222269488925, 46.533924994930146, 47.306027873869866, 49.396462901946045, 54.447393109721524, 56.709012139228086, 60.651688421926195, 58.06463818396292, 60.09296248036047, 52.63051986694337, 49.583053973413286, 48.388590274318574, 56.79491989074215, 60.267704071537146, 65.55064247500512, 66.24602379337435, 70.16341255557153, 66.76110159966254, 67.64254446952575, 61.25717686068628, 61.6314455001585, 58.82574273693947, 63.86331335190804, 66.43925543754332, 68.77429731430547, 67.84600565510412, 65.3476127501457, 66.2482124759305, 70.01164036412393, 67.79082575151998, 66.05289413082984, 55.90897021755096, 62.11658385492141, 61.411380921640706, 74.92116128244709, 69.5477024201424, 80.52957796281385, 20.770926936980217, 0.44373856496907055, 1.3296334781954366, 4.601539354170523, 13.935745839149723, 49.09496991865097, 64.97863146566576, 64.69010583816036, 43.2907328298015, 17.107864656756004, 27.41337060928345, 39.22310160052392, 58.75226497650147, 32.27267342229044, 63.50871147647981, 22.60196189726553, 0.1384153718789739, 0.03765849982418361, 0.11826067111424862, 0.017221807840190107, 0.08247809845112986, 0.0319738975996452, 0.06448055572447277, 0.042162035787177664, 0.044638185176037015, 0.09992398892439182, 0.03749404755991794, 0.022463224370092637, 0.0619798110828044, 0.031944445349396236, 0.024447805781458175, 0.08228402539727189, 0.023740394446518154, 0.04515703737495407, 0.05047519293223178, 0.04239350542305939, 0.12861531468168383, 0.06742629402827832, 0.2240170099802556, 0.11786697086908164, 0.11255925325977226, 0.12464466564837964, 0.11755642180721607, 0.14600600085912213, 0.08540987863295502, 0.12515871064557185, 0.17114126904597207, 0.1334834203965241, 0.10778788912801013, 0.135656627976606, 0.15316786574980906, 0.2694868410546934, 0.13909133721984204, 0.10103663970385829, 0.12866149446175945, 0.21097136000471733, 0.13659767506103362, 0.200371966667233, 0.2582408541873578, 0.2449815882550132, 1.2284092388806807, 20.375916804036788, 100.8137309166693, 61.53699482640913, 69.81597685044812, 74.7361195471979, 81.16028724178192, 6.178481213508114, 49.614252505763886, 86.65407657623292, 57.045484819719874, 83.09943645231186, 76.08387731736707, 38.75400573976579, 2.66723427080339, 0.6268553664126705, 28.614249344794985, 95.21555946719263, 81.36828268727949, 86.71612062761861, 84.35280630665441, 88.85971946101036, 80.04594187582694, 78.54377608145438, 65.94900623444589, 67.04698747204196, 69.91602866880356, 82.25361654835363, 81.5713987042827, 81.88280351700323, 79.80188415896508, 81.33550736211961, 70.34925445433586, 63.16809677308606, 63.61621187579248, 73.55376028245496, 73.59612188031598, 76.74683632389193, 71.51373555583339, 75.69065186285204, 70.07189581471106, 73.1014560884045, 69.85051724218553, 73.40177628301805, 69.4024335184405, 66.80191778367566, 54.539419758704405, 53.34304978770595, 53.723888397216804, 54.59798859011743, 52.103969127901145, 51.26681766202373, 53.75893477470645, 54.79700573029057, 58.33569749709099, 70.51101300024217, 66.79240211363762, 74.49991441542103, 63.34581544322353, 66.95052070002403, 64.56413107533609, 67.87300725137034, 68.31749808403754, 67.40699829593783, 67.22471790928995, 69.41402019992952, 67.88174629211426, 64.51401495164441, 63.29728395708146, 63.51318297847625, 60.5667769524359, 63.83440940610824, 63.808000087738044, 63.518435032136985, 62.083271165047925, 59.952396500495176, 52.19689007728331, 49.2602821319334, 45.766191636362386, 50.041237800352036, 50.179171869831706, 49.2886330235389, 51.35569464775824, 57.19165194419123, 57.74811860053771, 63.63775745514901, 61.89768814271497, 63.62852811813355, 55.315335181451616, 51.80920693182176, 51.99212274243755, 60.18937826156617, 63.940799774662146, 67.81522289399179, 69.86604982806791, 72.295942460337, 68.78199300458355, 68.84054614651588, 62.297832658213956, 63.53943147966939, 60.67449700447821, 67.33304592870897, 70.1541792961859, 71.60435015155424, 70.08407085172593, 66.0620960112541, 68.7035769800986, 72.75476563361384, 69.36833243216239, 69.56584730455953, 57.970336560280096, 64.93732890775128, 64.83635533240535, 78.74023975864534, 72.39263672982493, 85.01785201411094, 23.843537184499926, 0.4351388296533016, 2.206557042175724, 5.5138468646234085, 15.341203635738744, 52.11439478781916, 69.67940776578843, 70.97575110773887, 43.96044223539291, 11.326227284246876, 45.188952107583326, 68.582807202493, 64.87396693998768, 49.67622595448648, 70.94266983770555, 41.66555366208477, 0.22226568702007496, 0.14482928980742732, 0.24219675139794428, 0.16911268354423586, 0.18931429953344409, 0.11190048659280424, 0.25859886239613256, 0.2643384850553928, 0.2482675998321464, 0.16981480312683891, 0.21136643154726875, 0.18040684202025015, 0.19266843164880432, 0.14892012271429264, 0.1369573839850003, 0.1515682128768775, 0.1677896190554865, 0.08133917085586057, 0.12732761281151928, 0.11905354147236194], [0.05048057086946023, 0.03588809744424878, 0.060480412306083794, 0.08677940635431199, 0.03506864383516293, 0.05830252392878456, 0.01244883588139689, 0.09357733351569023, 0.033801764234780304, 0.034465644538642905, 0.033936170530655695, 0.043505681228012814, 0.05035039720936649, 0.061667411918601686, 0.04554324528022159, 0.05737771790835166, 0.038391301228154096, 0.07628128217953829, 0.026964492712830825, 0.060410081604195226, 0.12208374096981942, 0.07617911669395624, 0.0665571442955444, 0.08692007541896836, 0.01193906469721227, 0.1792469082940971, 50.18394539433141, 58.02668140780542, 47.12105281891362, 49.804573751265, 73.05572909693565, 33.019178913485625, 8.465566231358437, 69.27927893977012, 58.019381876914736, 69.52525077327606, 67.61653915528329, 48.99533779390397, 3.8479243218898778, 0.1322494212898516, 0.0833927997718415, 45.081577224116174, 92.36139189812445, 76.0642497770248, 85.02174300532188, 79.19303032659715, 77.62106203263806, 69.17882703965711, 61.77351374779979, 59.276909443639944, 69.75859257482713, 74.24020644157164, 77.81365040809878, 77.53940613039079, 77.82507235004057, 73.49901183958977, 67.35710574734595, 56.31682611280873, 57.728393000941125, 65.45908258807275, 72.76883125305176, 70.1895433856595, 63.69998978030298, 67.14151659319478, 66.4772004465903, 66.59081582100161, 71.95977180234848, 67.6409206082744, 65.71000837510633, 58.765075437484256, 51.919037219016786, 50.6979759277836, 52.56902102501162, 49.44042090446719, 49.44100533762286, 50.01558942179526, 48.52302166723436, 49.501147039474986, 50.45644029494255, 56.08793227903305, 60.87725608579574, 63.85023616975354, 68.60355654070455, 65.13249820278537, 62.49398254579114, 60.292148282451016, 60.38052712717364, 63.67747537551388, 65.62340244170159, 63.8391201726852, 64.77376214919552, 60.96984755608344, 61.55904246914772, 56.59443970649474, 58.47556137269544, 60.90781527180826, 61.32099774576003, 60.02962404681791, 59.59446061042048, 57.96467265775127, 47.6217512161501, 45.61304661535448, 46.00031791194793, 46.22620328780144, 46.84990329127158, 47.39790155041603, 50.976668173267, 53.58083171229209, 54.23996640789894, 54.86044614545761, 55.37742237890921, 55.12209961491247, 49.63802991374847, 47.74095204568679, 49.10498372970089, 52.83059604706303, 59.23115499557988, 63.94474960142567, 61.78979550638507, 63.106335132352775, 62.41880639906853, 64.04539369767713, 58.47586731756888, 58.15818671257266, 57.714394061796135, 61.78926206404164, 63.67329412891019, 71.7831317840084, 64.86443165809878, 63.94892300328901, 62.32948226313438, 65.7418344866845, 67.98159414722075, 62.38598400546659, 57.0732512781697, 64.01712125347507, 61.75891076364825, 73.78521934632333, 65.12528888640865, 80.75627526929303, 14.60025025952247, 0.18543293038683553, 0.46026495075033563, 2.506115806679572, 18.373138904571533, 50.88728127941009, 50.401523190159956, 50.396035794288885, 16.105717708987576, 16.866701649081325, 57.51342750364735, 38.3868444350458, 33.0258547875189, 38.26003812974499, 58.957840319602724, 8.921159332798375, 0.4116292153635333, 0.2051064053610448, 0.1170332373810872, 0.02951587768151395, 0.17765306236763156, 0.05618018841731453, 0.01875325015956356, 0.02032064115478387, 0.09970959921878192, 0.013238549957262173, 0.018791554555777582, 0.021784388114728277, 0.049794523811508576, 0.09272715978084073, 0.030777005876805034, 0.04429323876637124, 0.019736840021646312, 0.07260182316625312, 0.013282584691149815, 0.05112773513481502, 0.029131426032812848, 0.003434208173853075, 0.04137463529684371, 0.09764593455099291, 0.018150857987723524, 0.02476561544162612, 0.02636342204266018, 0.08693440892403165, 0.11844555111301523, 0.018163534827650558, 0.06788809948991384, 0.028566405545139027, 0.03134196699266473, 0.10744720216720335, 0.027695719806116917, 0.013877284382620167, 0.04312073736782036, 0.04244224776724174, 0.04514918114329058, 0.03866549941801256, 0.024509156017654368, 0.011073401622143726, 0.030336346357099475, 0.09570521933417167, 0.07642758199043813, 0.3622139395485002, 59.40802643376013, 66.99671837591356, 48.49841271677325, 61.01239350534255, 47.76829881052817, 27.97519914565548, 22.042702513356364, 80.21176399723177, 56.33211943411059, 78.63060166758876, 76.1334639210855, 52.537426333273615, 3.7671916475219116, 0.0749074720266846, 0.15979181434358322, 46.960623956495716, 93.04440990571054, 79.26731217292048, 86.08977302428215, 78.34712413049515, 79.19622313591742, 70.83397311549034, 63.52474220337407, 63.789208012242476, 69.37394926624914, 77.10953789372599, 81.43282136609479, 77.29668201938753, 77.51538553545552, 76.23983075541835, 69.81508255004883, 59.4628337121779, 59.785221161380896, 68.21567335436421, 73.20655207480155, 71.51294323705858, 68.79921220964002, 71.68562950626497, 70.94092830534905, 69.811034664031, 72.73382017689367, 71.31764058143862, 68.09036931683941, 63.45093888621177, 53.8642268796121, 53.81883328960788, 51.620831181926114, 53.4846551956669, 51.848795413970954, 52.11346126371815, 49.491239132419715, 52.77369030060307, 52.52771846709713, 60.535484283201164, 63.45737549566454, 70.16448728499874, 73.7425910272906, 68.11255424253403, 65.75403698029058, 66.02356264668127, 64.84388628313619, 66.24956177126977, 66.94444887099728, 65.53608655929565, 68.283797079517, 65.18166903526553, 65.28600408184913, 61.30585739689489, 61.63561497965167, 63.66859512944376, 63.236569589184185, 63.24401424777124, 61.80042120718188, 61.004776262467914, 49.984226149897424, 47.72920062465053, 48.87624286836194, 50.1043918824965, 48.82389491604221, 48.98196251161637, 53.25132908359651, 54.853103468495036, 57.351025689032774, 57.942562257089925, 57.52988969126056, 57.87747836882069, 51.298694764414144, 52.13015094880135, 50.04529745348039, 55.57434889578051, 60.40687368762109, 66.39927864074707, 67.30347910235005, 65.7674357967992, 66.38027867963238, 68.01441654082268, 61.91321680622717, 61.70851615167434, 58.25837189151395, 63.90387065948979, 66.26335282479563, 73.07620386923514, 66.88177724038401, 66.91662357699487, 67.46914432894799, 68.34775524754679, 69.40779147609588, 65.32227031646237, 59.68986834249189, 64.96040421147501, 65.02407212411204, 74.88815845981722, 67.89463520050049, 83.23764508770358, 15.272823975932214, 0.3113696033195142, 1.9967186955675005, 4.160945886565793, 18.637465469298824, 56.26111276688115, 59.467791588075706, 57.25753207360545, 23.017688028274044, 22.353005140058457, 36.559902468035304, 37.10126799921836, 37.95865889518492, 40.622866076807824, 68.84188759711482, 8.89081979951551, 0.4319700448503418, 0.13371695463936176, 0.06918014507860908, 0.022399353704625563, 0.11419892656586825, 0.11449095928260397, 0.03422428470765872, 0.06882397548085259, 0.0997520098462701, 0.0042747002331570035, 0.034455325334302844, 0.04074433645714195, 0.0558010476731485, 0.08425083356879412, 0.05401193359566312, 0.08586567030438493, 0.031930535107911114, 0.020516204249654568, 0.04498056902159606, 0.12703626191303616, 0.11862018851623421, 0.16123869396265478, 0.16530882717380602, 0.21767504302965057, 0.12678915259218024, 0.19500507642665219, 0.19315218552947047, 0.21489284151504118, 0.16378702415573984, 0.1108869752516189, 0.1669117895465705, 0.11198972051422443, 0.09609180262252208, 0.2009745867502305, 0.1873554280328174, 0.10452657622555572, 0.13329894642435736, 0.25354588434340497, 0.12577291397798446, 0.09609397831222705, 0.14896630249436826, 0.20037352948659853, 0.11592323726583874, 0.20439875462362844, 0.20914626277742848, 0.9673928481436546, 78.89554992798837, 77.58223841267248, 62.578089929396114, 71.54979782719766, 108.17792600201024, 40.35394837779384, 12.089775473840776, 81.66972467976233, 68.90812858458489, 84.23596674396147, 80.52651851407944, 58.291382558884166, 6.563115696753226, 0.13493071370307477, 0.46182053824586256, 49.22238026895831, 96.01388731310445, 81.46782459751253, 91.37879894625758, 80.71309781843617, 82.50090629823747, 73.41386502788913, 66.93644723584576, 65.39790538049513, 74.33121327430972, 80.0817060470581, 85.75906230557351, 80.10930384359052, 81.96248254468365, 83.71161645458591, 76.59484447971468, 62.629684786642756, 61.96213660701629, 70.51379788306453, 79.65207315260365, 74.24163418431436, 69.34951290007561, 70.4330990391393, 74.04788478728264, 70.80854831203338, 76.29057053596743, 73.32518023829307, 70.37442822610178, 63.669332535036155, 56.994780340502345, 54.34299530521516, 54.99297911121, 55.43146087277321, 55.753106994013635, 55.817963384812884, 52.19598793214368, 53.15401507962135, 54.34675685821041, 61.720483303070075, 66.03519639661236, 74.08356266637003, 71.78827793367448, 68.08720788648053, 68.03746438795521, 67.36820605493361, 64.84229380084624, 67.14837289625599, 69.25719599569999, 66.94644143504482, 68.74334196890555, 65.71424061252226, 65.60298650495469, 62.68352323962797, 63.06660544487738, 69.13597122315439, 64.6459399500201, 66.88156543239471, 65.32253703763409, 65.88202784138342, 53.309454687180065, 50.974557938114295, 50.83341929220384, 52.551315446053785, 52.02807126506683, 52.23847112348003, 55.521306683940274, 58.013235522854714, 60.03352288276919, 60.56090124191777, 58.0522866402903, 61.14223572515673, 52.397048627176595, 53.71777734448833, 53.69636512571766, 58.35483474116172, 63.49432422268776, 66.69357407477595, 67.23148007546702, 67.19872828452819, 65.55854212853217, 68.79254418034708, 62.875931186060754, 63.27122765202677, 61.40183387264129, 67.3840759646508, 68.96862722212269, 77.7368974685669, 70.15730150284307, 67.91699271048269, 69.91372231514224, 72.6997269353559, 70.79883652348673, 66.93865160788259, 63.852836701177786, 69.15144105111399, 66.1868901406565, 78.72178108461442, 69.32373508330315, 86.67630072562926, 16.660810555181197, 0.36221433791422075, 2.965210113794573, 7.475598242975051, 23.013753890991214, 58.84482899019795, 62.103165426561915, 62.13957678887152, 20.78199390442141, 21.402461874869562, 81.15174431954661, 51.906418954172445, 50.15217811830583, 49.58744702800628, 79.35720505252962, 16.526094790427916, 0.6274261938468103, 0.36411573749876797, 0.17365560025697754, 0.14536025002598763, 0.2009536112628637, 0.20298022025775528, 0.12399557467189529, 0.15406018964225246, 0.2671972493971548, 0.13462908956552708, 0.1297885630159609, 0.13177532011703139, 0.22325384851184585, 0.18785822685928116, 0.1044943928718567, 0.15670582832347962, 0.14233063275535263, 0.1097628637968052, 0.07924560577638688, 0.24049355408116696], [0.030804406926636736, 0.030409254944853248, 0.015177127788774671, 0.03287894621251091, 0.07584624382997714, 0.017194582990580992, 0.038508600780680295, 0.07336702242854141, 0.06160907049272811, 0.011513614895633392, 0.03881323947421005, 0.026721008903076573, 0.054228054659981886, 0.016702959471712672, 0.07349393255407773, 0.055867080621781855, 0.08664206977212623, 0.018249260066377542, 0.025343153805982684, 0.05234080088895656, 0.04896371677938489, 0.026498370345741994, 0.05598636434203195, 0.12154563315092556, 0.06699481798756508, 0.834118125419463, 11.660471077888243, 76.7699626184279, 48.14512875772292, 54.56865318359868, 52.822233553855654, 72.86219935263358, 12.44618065895573, 31.096750767000263, 94.74975447500907, 66.21578231934579, 64.00740946492841, 49.68472180827972, 8.058615423017933, 0.34333115924269925, 0.09738351113253063, 3.5100138475818023, 87.3782402469266, 79.03284072875977, 85.13268332327567, 75.28240373057704, 73.6436374725834, 66.21200899924001, 65.9163878040929, 61.36903109089021, 69.63677160201534, 75.06488477030109, 78.15677150603264, 79.02961654047813, 77.36140897197109, 75.15461291036299, 70.68908076132499, 58.45427859214045, 55.48405593441379, 63.09914542782692, 67.9584913869058, 70.73102658794772, 62.30609709216703, 63.54971985663138, 67.85792181568762, 71.11981191942769, 69.96805498676916, 67.54751328499087, 68.27159066354075, 54.79136143961261, 49.970082083056056, 50.06948671033306, 50.24555798499815, 48.82519322056925, 47.39441456333284, 48.07042329542099, 47.25442517188288, 48.26500815729941, 51.02618025195215, 51.61594390869141, 53.21798501476165, 59.66634196619834, 57.245156995711795, 60.55439010743172, 61.44023387662826, 60.50945935710784, 56.8049729254938, 62.192214996584006, 63.15052063234391, 64.49016694099673, 64.66454375174739, 64.47340665325042, 60.8582208233495, 57.25481779344621, 58.49044676749938, 64.12932849699452, 60.750885163584066, 60.01013378943167, 61.14697787069506, 60.10170152110439, 46.919121357702444, 44.74886217424947, 45.59328963679653, 43.02700834889566, 41.85147793062272, 46.416348026644805, 49.138492538082986, 55.09745928548998, 54.49965476989747, 54.580475207298036, 53.57654848406392, 53.2673833447118, 48.44418202677081, 49.801537836751635, 49.56489339951546, 50.393949093357215, 57.17275004233084, 59.10582350146387, 62.03605367291359, 59.311387077454604, 50.71080600061725, 51.898323182136785, 59.72358111412295, 60.42335156471499, 58.35760393450337, 63.7163225297005, 66.63640160714426, 70.1220315502536, 69.36352360633113, 64.99680772904428, 62.322363161271625, 63.60161673638129, 69.30323677678263, 67.47060345065209, 61.35898590087891, 65.19533457294588, 67.84638220264067, 69.69225745047294, 72.57188120195943, 60.5627526006391, 10.144624056354647, 0.08381765681288897, 1.4958593585798818, 2.9848158359527592, 22.76677400835099, 37.45334779062579, 55.48519734413394, 35.99851715949274, 7.780399255214199, 37.69044330043178, 43.14617387710079, 48.46168756484986, 35.28446928147347, 46.979843570340066, 51.45395394294493, 1.595579246359487, 0.13432426318045587, 0.009099478409024737, 0.05049355605977678, 0.023275919168466525, 0.03086546221898208, 0.04849038169448895, 0.08692819595096574, 0.03197523250785326, 0.08292502648527585, 0.08583996039364608, 0.0281733947791039, 0.035154709983016216, 0.047775644643773, 0.034511567679263895, 0.02810174832120538, 0.04101026089741819, 0.048241073701290355, 0.018434373721961054, 0.055667154656182376, 0.10215194114754278, 0.029504824947986393, 0.010952542633599332, 0.021829723282867385, 0.005010065158844115, 0.04975955955864442, 0.054355366981678435, 0.05133872341004111, 0.029921143939117753, 0.02523249240532037, 0.0297583406791091, 0.04271341224892005, 0.06326107398396538, 0.09909620027868979, 0.050258397710539644, 0.033226068311881636, 0.06674890376387105, 0.0216898949997079, 0.058426488446252006, 0.026052198823421233, 0.010191169980492805, 0.08784811433044173, 0.0817338670153291, 0.036185653654918555, 0.0711242770475726, 0.05410280311480165, 0.7563185872089478, 16.079646695044733, 91.0228987663023, 49.52495582642094, 63.57864733665221, 54.301284820802756, 44.97350808112852, 22.773085101958245, 48.331409961946555, 91.05926698254001, 77.94956837930988, 71.3669369297643, 57.377109450678674, 9.660280962144176, 0.6928847910415742, 0.05902153958055762, 4.685479056450629, 90.2951265150501, 83.3831101079141, 87.40765017847862, 78.64203929901123, 77.13485287081811, 68.74529530925136, 68.55634689331055, 64.66243743896484, 71.18404465336954, 75.75953652781826, 80.72552388714206, 80.64101249940934, 81.46962104305145, 77.0335380492672, 69.92498736227714, 61.38808596518732, 60.707864607534106, 64.97920413171092, 71.85125550916119, 74.43592486842986, 65.4971884142968, 65.19189073193458, 70.34601457657354, 74.04201692150485, 71.83389509877851, 69.18504007401006, 70.54661243192612, 59.58435266248642, 52.29036800322994, 53.08499705406928, 54.19017976330173, 51.42672877157889, 50.47208270718975, 49.99635411847023, 49.46292354214577, 50.55903380916965, 53.2928159929091, 55.797355251927534, 58.66194848091372, 63.68551623436713, 61.56752655583044, 66.07047419394216, 63.410201149602095, 64.40244313209288, 60.054805663324174, 66.30441219575944, 65.99595700540851, 65.80968364592522, 65.71297760932677, 65.7260783257023, 63.6839904323701, 60.78387621910342, 60.88024100949688, 65.64297506886145, 65.87142959717782, 62.75543989673738, 63.954669275591456, 62.62285201780258, 49.157943571767504, 47.66913737020185, 47.745847163661836, 46.77053805320494, 47.40468332844396, 49.23281377361667, 51.46181437277025, 56.73838284707839, 57.2818664581545, 57.85881180917063, 55.882376547782656, 55.81785748081823, 51.76540582410751, 51.83368252169702, 50.47740536351358, 54.36505471506427, 59.672464786037324, 62.05065273469495, 63.85202869292229, 62.61774509183822, 57.50697912708406, 58.68982476572837, 64.97696445834252, 63.87175821488904, 63.61917326527258, 65.51043818073889, 69.43314567688974, 73.09262291077646, 72.09255187742173, 67.01080752957252, 67.66991476858816, 67.13151454925537, 70.1411727166945, 68.44913282702046, 64.15708318833383, 68.15927751602666, 70.23840042852586, 71.3406962733115, 72.75348694093766, 62.81049428447601, 11.290174818808033, 0.37427979371240067, 3.675697215141789, 2.830142806614599, 24.916003404125092, 43.20837874566355, 65.51421542321482, 41.433470941359, 16.85990810394287, 33.725444809083015, 31.50439485426872, 53.2143646670926, 34.06903266906738, 52.63308117466589, 57.511172140798266, 0.724284406150541, 0.11379415635019542, 0.13528760342348006, 0.04440970328305999, 0.025723198533899365, 0.05260286807653405, 0.041659459126211947, 0.060309816016665393, 0.050105203108321276, 0.0506379368204263, 0.04705823777664093, 0.022114857377844955, 0.025412731826485648, 0.028122731469451424, 0.025196095568037806, 0.021461208178211125, 0.01026618914047797, 0.01656477444715077, 0.013583140136043151, 0.036605707324680783, 0.033470883199404326, 0.09081406969456904, 0.20334452570926762, 0.07065147822422367, 0.21010211068055323, 0.22493084562161278, 0.17087093193925199, 0.15107347329537715, 0.10341106793813168, 0.18622238399280658, 0.09904012264263246, 0.28728756813272355, 0.1643114419834268, 0.12465548280987049, 0.12036679237480126, 0.1554562163449103, 0.1566301541583192, 0.179006356685873, 0.22058593199378063, 0.1294169490856509, 0.11508670755692067, 0.23629982024431231, 0.2407662047734184, 0.2046237852905066, 0.13777512155713575, 0.19209755824938898, 1.2012102983651625, 27.067597989113104, 106.18163570280998, 61.73958916817943, 75.05498470798616, 79.50592563998315, 95.33599976570376, 16.22410366612096, 41.79064589162027, 105.61207617482832, 83.71935921330606, 78.52976537519886, 60.5442625476468, 10.513574942465752, 0.3626743583909927, 0.15046720663386007, 5.212775045825589, 92.78370564983737, 84.84358895209529, 91.84716132379349, 81.7860935580346, 81.34403459487423, 72.11033590378301, 70.89383632906022, 65.86594612367692, 75.70663159893405, 79.89960608943817, 85.22216043164654, 82.16364522134104, 85.27114299035843, 81.21139572512719, 76.36861785765618, 66.11188657822149, 63.42018358169064, 66.66545068064045, 73.71697795006537, 76.16263066568683, 67.92857939197172, 67.33573667464718, 72.97269252038771, 75.54649691427909, 73.46368697381789, 71.57589727832426, 73.47246523826354, 60.4408767146449, 53.366611465331054, 55.6484503130759, 56.288592892308394, 51.33525125442013, 53.336126804351814, 52.220765544522195, 51.031177351551676, 52.41952773063414, 55.513128542131, 58.34229100135065, 60.3540668179912, 64.6046373921056, 62.579199960154874, 65.36954272177913, 63.82147342927995, 65.87611290716356, 59.63519050228981, 68.65198212285196, 68.673060940158, 67.44226824852728, 67.45445897502285, 68.81221094439107, 65.39429679993661, 61.84629332634711, 65.12322179732784, 68.83227779019263, 66.91940061507687, 66.60884303431358, 66.01403128716254, 65.97226588956772, 50.84144838394658, 49.32320087186752, 49.590843800575506, 48.60782723273001, 48.94551584797521, 51.09994826778289, 54.4932887631078, 59.305680028853885, 59.1203127368804, 60.457091792937256, 57.151702603986195, 58.659469542964814, 54.05005701126591, 55.91693262900076, 55.32839275175526, 58.54316734498548, 62.35714281758955, 63.174796181340376, 67.30757405680995, 63.80517990358415, 60.30048331906719, 59.515860234537435, 65.29894790341778, 65.37595187464069, 66.09535771031534, 69.48839618313697, 72.81635469005954, 75.51483554224815, 77.28289096586167, 70.15942742747646, 69.58880101480793, 72.71721286158409, 73.51145359777635, 71.82036292168402, 64.76197150445753, 69.08943622343003, 73.43753260950889, 74.08393921390658, 76.72698913082, 66.16137120031541, 14.605235592011484, 0.2410324509706228, 4.882824776634093, 9.549805445055808, 28.024095412223573, 46.341615107751664, 68.22567539830362, 45.756989755938136, 12.082975064554523, 50.69686197465467, 62.40805518242621, 66.16181835051506, 49.792692892013065, 60.46445408175069, 75.20767473405408, 4.352307540755119, 0.42780332327369724, 0.3219961008477596, 0.28644628101779573, 0.09405682028661813, 0.13050559066957043, 0.1626975245533451, 0.21740741787418244, 0.051471846508643324, 0.12241751015666993, 0.10721237323577366, 0.11502037966443647, 0.06831747644971456, 0.1483294382811554, 0.0841650853474294, 0.2152785974284334, 0.13673607650543415, 0.20336824379140334, 0.12789088661872572, 0.12434193834422097, 0.23771149046238393], [0.024026398051289782, 0.027721012198937037, 0.0507277989339444, 0.038412993007730094, 0.01047585016837524, 0.013403684997390355, 0.03254891936517051, 0.05166188610957996, 0.05678370482318344, 0.061563526565629634, 0.00787258189502022, 0.028870019596070055, 0.05437458429725901, 0.08002975039304265, 0.0501938701246775, 0.015979518704566986, 0.0055689775317366574, 0.030426522566666527, 0.0056370554563228885, 0.05232099751611391, 0.0976030872533879, 0.037222055703281395, 0.059189144296631704, 0.017290518266118823, 0.06939330138266087, 0.20384337152204207, 0.42461121875432234, 52.515480672159505, 59.841362045657256, 56.9652448931048, 64.84263112468105, 63.38656886931389, 38.511301240613385, 9.473415324764868, 72.3817325407459, 75.21742574630245, 56.13217661457678, 50.24038830111104, 11.62552668202308, 0.31554104399777233, 0.1968496935742517, 0.0407886584740012, 53.733121656602435, 93.72821238733108, 76.67321343575755, 81.86163056281306, 73.71849198495188, 72.54729578571936, 69.51794732001521, 72.70726573082709, 72.38637662702992, 77.67224896338679, 80.76505353373867, 78.89945660868, 77.9678701585339, 75.17846092101067, 71.62629973503851, 58.87706695064422, 57.087454180563654, 65.05222689720893, 72.66486490926435, 65.09733807656073, 58.43139548455515, 70.45298545591294, 75.56786598697786, 69.50913767660819, 70.51583751555413, 64.88188620536559, 56.67885695734332, 50.732308433901885, 52.5333902143663, 50.67327284043836, 55.01198691706504, 54.03059421047088, 49.78165141997799, 48.92720230164067, 48.933038788457075, 49.744949802275634, 51.40153146559193, 51.201243477482954, 51.16472228880852, 51.04505469722133, 55.92952735962407, 55.349710833641794, 58.93136039856942, 58.585019034724084, 60.22638582414197, 61.3741615510756, 64.66573615227976, 64.32312104009813, 65.88923715776014, 61.89231841794906, 64.69839380633447, 61.492750490865404, 56.24950255117109, 64.54294243166524, 58.62431726148052, 64.25388728418659, 64.26320291334584, 60.01541329968361, 49.54864694226173, 44.77231402550974, 48.02998365894441, 46.94683682534003, 45.232898342993956, 48.03733025827716, 51.683545958611276, 53.725669153275035, 54.772875308990486, 54.539098124350275, 53.879245635001894, 48.402757875380985, 48.4561844794981, 48.03616531433598, 49.869194799853915, 50.88243715224728, 55.76659210266606, 56.17072174626013, 62.87277367807204, 57.9183376989057, 39.88204017762215, 23.84389215900052, 53.52012911150533, 63.816554777083866, 59.36027942165252, 59.023536097618845, 67.32836261872323, 70.41773903754451, 70.20717051721388, 63.49827797182145, 64.90489482879639, 58.43102678175896, 70.2852649073447, 63.556854647974816, 67.3322065414921, 69.08130122769263, 71.67541565433626, 69.82478649385514, 72.95026440774241, 33.425893399023245, 0.3904872111255123, 0.15418083316856815, 1.941756483527922, 1.9066984615018292, 26.26986634346747, 51.21773704405754, 59.25009219877182, 24.692471450374974, 21.597942998332364, 49.064112632505356, 38.69209897133612, 66.25437844184138, 73.90581653964135, 54.62332317906042, 31.146172631171446, 0.3786353099971049, 0.0694618892345217, 0.05213725898835448, 0.0021944782507020023, 0.022088927216827873, 0.018122725323924137, 0.08824456483125688, 0.04949055927535219, 0.04690753679061609, 0.03712714123990267, 0.05735730932604882, 0.044071904473727753, 0.02348218259641961, 0.004368874464078897, 0.13170873175465292, 0.04593991794653478, 0.03470583225510294, 0.06334178900766758, 0.03266343035765233, 0.060938096214686675, 0.04327072589207561, 0.02316954786018018, 0.035526638009375146, 0.06307579561947815, 0.03599569449321397, 0.060048966908887516, 0.04244454603101458, 0.040836849234878056, 0.10571245734970416, 0.050275362727622834, 0.03628770422731196, 0.024943547022919503, 0.0329562253318727, 0.05731762980201072, 0.039237437679642634, 0.03511218061189979, 0.033767098756206614, 0.04840413934641308, 0.0051337850069807425, 0.0072645388671287135, 0.04054912959315604, 0.054594313635701136, 0.028164776289955746, 0.03213250844348823, 0.08516860690208213, 0.06149353677286737, 0.08177431645773112, 0.5011641480509312, 61.422720493808875, 69.85410228852304, 57.14424225591845, 77.36860259886711, 43.21606266883112, 32.87158208508646, 27.116486410940848, 78.84369619431035, 78.07535094599571, 64.14733217608544, 58.77766232336722, 12.860976207640864, 1.1840163435666793, 0.4391601170984007, 0.11134729450268131, 56.52175818720172, 96.54569795054775, 81.33973567716538, 81.41551586889452, 75.49770262933548, 73.73858236497449, 70.92034370668473, 74.37976437230265, 75.70662375419371, 81.21237631767028, 83.28772591006371, 80.37760965285763, 81.90953054735738, 78.07108340724822, 74.41766231290757, 61.977261266400745, 59.91518497467042, 67.53506368206394, 72.12546056316745, 70.2966711598058, 66.96158178390996, 74.1625278226791, 77.25657186200543, 70.65297142151864, 73.04404043382215, 67.86929668918734, 61.669629773786, 53.50590659726051, 54.33387187219436, 52.537069397587935, 55.3286555505568, 53.84826675538094, 53.190787299986816, 50.669644648028964, 51.33447854749618, 51.83043479919434, 53.72974841825424, 54.44103102530203, 54.03193173869964, 54.7989002350838, 59.34145988956575, 60.17734835224768, 61.36672865959906, 61.949824287045395, 61.93012222166985, 65.49571360311201, 66.98545332877868, 66.97479232665032, 67.53321232334261, 65.85021741928594, 67.52569706209245, 64.90563223438879, 61.91447588705248, 67.8347876764113, 63.294189207015506, 68.06221454374253, 67.33096707251765, 63.07560728442285, 51.50050070977981, 47.63393409790532, 51.4913341306871, 48.39820400361092, 48.28810307287401, 48.963154746640114, 53.50140371630269, 56.42534632836619, 57.675225273255386, 58.000574111938484, 55.99341492499075, 52.085424161726436, 50.10174036026002, 52.53475912155644, 51.11577110905802, 51.09540616312335, 57.363969510601414, 58.39633341758483, 64.51670569758262, 61.59047634370866, 48.630765253497714, 31.07135145894943, 61.65032386779786, 65.7646744481979, 61.70354258629584, 63.55894919364684, 70.26786527326031, 73.25282819809453, 73.80584316868936, 66.6394296769173, 68.99238109588623, 63.08373835779006, 72.64556684801656, 67.6534172796434, 71.73953071717294, 70.32478670920096, 75.77535152435303, 70.96743568297356, 77.59902615700999, 34.85578952297088, 0.6290187374238045, 0.12196783186687578, 4.294378055680183, 3.012269485381342, 27.55367182916211, 56.72626664561611, 63.704575031034416, 28.028478660891135, 26.10689970754808, 32.084027028852894, 39.84029046950802, 74.74331317409393, 67.8496063909223, 65.69054557431129, 31.189956088219922, 0.31968996169105657, 0.06667239456287315, 0.023221906139365128, 0.057912071896416534, 0.059254181330963496, 0.010761230369098486, 0.03712475870645816, 0.08460691889687892, 0.02523809633848648, 0.03968190274111206, 0.09000609208258892, 0.024704385864278002, 0.05072330965870812, 0.06332955841395645, 0.08744492225589291, 0.05036962984670555, 0.07067731836990965, 0.07341386870511117, 0.02569511949625467, 0.10313268690820664, 0.016551710732821977, 0.11521065292219002, 0.1617533518301864, 0.17646207143702816, 0.18118034567563765, 0.1935634521707412, 0.20287966355681422, 0.19285266047283528, 0.17949299105713445, 0.1360877056515986, 0.15010460189753963, 0.168852765233286, 0.14002116877705822, 0.14207567869415208, 0.17904213299193691, 0.08228203356866876, 0.1422142793214129, 0.1767723983333957, 0.10468589953116833, 0.1156834977108144, 0.1657649712456811, 0.3085130453109741, 0.12886709713887784, 0.21727088568431718, 0.17050373067538585, 0.11012438834915239, 0.4611314881232477, 1.8836970699410287, 86.28741341252481, 79.85602855682373, 74.2562646250571, 87.92869783216908, 92.76887124584567, 49.69293917379072, 16.923209274968794, 84.41569758999734, 89.53188034795946, 70.86723481455158, 62.80559916650096, 12.998972054450745, 1.737174112950602, 0.49890274842900617, 0.14537266065036097, 58.75253562004336, 99.03546948586741, 84.54771672525715, 84.36947637988676, 79.03380563182216, 77.84075398598948, 74.77358602708387, 78.33775751052364, 77.93460845947266, 85.34375390698834, 84.8353127510317, 81.09765483487038, 84.39625047868299, 84.32107433196038, 78.55231115894934, 65.28189343790855, 63.45798346304125, 70.5467301030313, 75.00248770559989, 74.58493571127616, 67.3986985606532, 77.54453659057617, 81.81164387733706, 73.33271118902391, 76.57129456920009, 69.2402042881135, 62.58746439410795, 54.72193940993279, 57.509481599253995, 54.88945599525206, 58.97997033211493, 57.643830622396166, 54.87215834279215, 54.18259782175864, 54.15822813587805, 54.74816045453472, 57.03463162145307, 57.043613849147675, 57.02358622704783, 56.196028878611905, 60.720612310594134, 62.811765132411836, 65.490728270623, 63.4878719237543, 64.47400677588679, 67.2755910504249, 68.09425246331, 68.13080110857564, 67.97303553550475, 66.13938239312941, 70.0021796072683, 64.07965952350249, 63.15091286936114, 71.14334614046159, 65.88933913938462, 70.66095736718947, 68.37503925446542, 64.33302110241306, 54.24127255716632, 49.53444796223795, 53.4827567685035, 51.54751031629501, 51.34266061167563, 52.324645596165816, 56.56793232887023, 58.474372894533225, 59.808472971762384, 59.873776512761275, 58.54991774405203, 53.25733423233033, 53.78815251012003, 53.75538110733033, 54.86178367368637, 54.55706257973948, 61.41470709154683, 62.64930840461486, 67.45475707515594, 64.89521049684095, 53.33024717146351, 41.55527230231993, 65.03592552677279, 67.60780795927971, 65.49515662654754, 65.71326786471953, 72.20940712959536, 77.58626276446928, 76.69237813641949, 69.72718223448723, 72.24796402838923, 68.79518001310288, 75.55311787512996, 69.63992518763389, 76.11857460391137, 75.16564261528754, 76.77167277182303, 74.85114697487124, 78.89868782412621, 39.34510692473381, 0.9580535009022683, 0.6316067050060918, 7.339865603754598, 6.8920843928091, 31.039290005160918, 62.242240905761726, 70.4410457611084, 30.83564642936953, 27.749782493037564, 62.07170409540977, 60.666522825917895, 79.3042608999437, 78.06647854466593, 69.79420769599177, 48.74173695041288, 0.2673900584059377, 0.20290659920823192, 0.12795081001616296, 0.11189903102574811, 0.11311376302112496, 0.1111755146074199, 0.20408403038257555, 0.19776844750008277, 0.12081554369820703, 0.13229943150954862, 0.17173051323381164, 0.14632443296572856, 0.1361547689884901, 0.1122075422937351, 0.15957062943808495, 0.14884077132709567, 0.19783615435083068, 0.13212264906014168, 0.10194740333263913, 0.14011673058473295, 0.11663488698221984], [0.07000501492931958, 0.10841384424918121, 0.043407097203476776, 0.042036408858914534, 0.04027226158688146, 0.035580999608482086, 0.0523004318857866, 0.026454362424931703, 0.018361670062727025, 0.03423139017315642, 0.032643240110407916, 0.030002299463376406, 0.031789297222970955, 0.016057776501252046, 0.04536404965385314, 0.07363712204800499, 0.044497194354452436, 0.02666172710427594, 0.0586150341757363, 0.056421073273785656, 0.11001594860347048, 0.11475637810485018, 0.10714049886671767, 0.11217995546758176, 0.11309569100699118, 0.02494531094036516, 0.4454047449173466, 15.542605576976655, 75.15589160303917, 47.15262397643059, 68.06365797596594, 69.52873383798908, 76.76742092255624, 12.234009850409723, 38.278430123482984, 94.25579470972862, 76.16794155490014, 68.65738714894941, 23.947203466969153, 2.319634316429015, 1.019714324464721, 0.08975321411966317, 45.57584685664023, 101.56456670453473, 78.61007982684721, 88.2303124089395, 78.04081055425829, 78.61979161539386, 75.88487978904479, 77.64334893995716, 76.31899203023603, 79.81882095336914, 82.10477828979492, 77.11728065244614, 78.98248534048759, 76.17318968619071, 70.64634261592742, 59.539923975544596, 61.019077224116174, 65.60699908964096, 71.91006752752489, 57.59938232360348, 57.60488933132541, 77.26203180128529, 73.54924171201645, 68.04742720819289, 62.36244586206252, 54.69962896839265, 54.73152568263393, 53.31723274723176, 54.22071149272304, 49.14770618561776, 52.10012912750245, 55.49794112482379, 49.46052697397048, 48.63799418172529, 49.4446413747726, 48.99684398405014, 50.95580900869062, 50.43636560440064, 51.348771664404104, 49.909077459766024, 51.805257105058246, 53.278436583857385, 53.150128010780584, 57.30192938158589, 59.03006684395575, 62.15817274585847, 66.76396492988833, 56.36733839588781, 65.17045497894287, 63.023149505738296, 66.02818319874426, 63.55174379964029, 56.850370437868186, 65.19396174338557, 62.120886695000436, 67.05997051731234, 63.705288902405776, 62.30753660202027, 49.35223817825318, 46.180876378090154, 44.990848879660334, 46.52878276763424, 48.74241552045269, 50.179815138539965, 53.91928911209107, 53.81023545419016, 53.95553965722361, 54.263382957827666, 49.553530293126265, 48.496533901460715, 46.94880585516653, 49.300388366945334, 49.26103130463631, 51.27562730543075, 54.345183987771314, 54.27220436834521, 56.27136192014141, 62.00006984895276, 56.920259229598514, 34.3671053455722, 40.893552764769524, 64.9163285378487, 62.300111555284076, 61.294164811411214, 68.21717954451039, 66.60415187958749, 71.18473499051987, 66.2448392375823, 64.82565118420509, 52.71400751606111, 60.31635322878438, 71.54958601920836, 68.87889123732045, 73.02730760266705, 72.54872352846208, 70.35176477124615, 62.14378549206642, 7.401205099398091, 0.10361234987935714, 2.245329671329068, 1.8773203992074536, 1.919060178822087, 23.172827574514574, 68.83122659498646, 55.741210445281006, 24.387373808891546, 49.32642898251934, 46.76845527464344, 37.01124568139353, 28.941506416566913, 44.41452326313142, 54.31165556753836, 4.221465606843272, 0.15611171181644165, 0.009134986584315137, 0.10734401012380278, 0.04158388455248168, 0.04010893547186448, 0.023618122983363368, 0.04961326357818419, 0.06066841028270222, 0.030771735191885984, 0.05347364191566745, 0.10396263592185513, 0.07924339944316496, 0.031556906366360285, 0.028859970437723304, 0.013666618821932184, 0.050065799375935915, 0.02476944396602771, 0.02328734728507698, 0.05782419395062232, 0.05580253005328198, 0.04297813010071555, 0.013456988437551887, 0.07654082510740527, 0.04775500240465326, 0.06920370228228069, 0.025802595886371793, 0.04483942115198701, 0.055516334926529284, 0.02848821478114734, 0.017562598222866654, 0.018443945990574938, 0.010792741480643952, 0.08485641841205858, 0.0378557981082028, 0.024235059334445867, 0.03244267063095205, 0.11638121994873209, 0.03970629498062115, 0.013609019543735251, 0.04730563438046844, 0.03989870562368343, 0.11962586277795416, 0.11308846679786522, 0.07859001071342538, 0.10687025369054849, 0.09429699651175931, 0.05174589531135656, 0.6137873773132602, 22.603105268170758, 88.47535856308477, 50.72144739089474, 76.14493293146934, 66.283278465271, 37.241790833011756, 21.271682208584203, 60.063858493681884, 97.6295429660428, 78.98319921185895, 71.14564464938256, 24.999008601711644, 1.9077628947073415, 1.0663197429910785, 0.14868770695982442, 48.20430163414248, 106.11046821840348, 80.90907512172576, 90.93803436525407, 78.78890068300309, 80.61690561233029, 79.1395527316678, 78.11718694625363, 80.73853046663346, 83.11037986509263, 84.50147198092553, 81.40818103667229, 81.85996747786, 78.47944136588805, 72.92745974756056, 63.54542486129269, 61.621466990440126, 68.41684387576196, 73.00615033795758, 63.88655731754919, 63.84022628107379, 77.32182441219207, 72.25192562226327, 71.72002084793584, 62.640365400621974, 58.54870965403896, 55.304834996500325, 56.47515650718444, 56.45132026364727, 53.14793932822443, 54.132418940144206, 58.50488501210367, 50.95353403399068, 52.37901749149446, 50.50115923727713, 52.17800386490361, 53.04041931706091, 54.090559405665246, 54.68837568836828, 53.72952876552459, 54.9937439733936, 57.210769576411096, 58.12049665758687, 59.88887371555452, 62.898390677667436, 65.83430828586702, 68.27859601666852, 61.64925306074081, 65.95642735881191, 66.9632762478244, 70.20130265143611, 67.94808926120882, 62.15667832282282, 66.2507620165425, 65.80380401303692, 68.82499787115282, 66.10311615851619, 63.252153165878795, 51.565992524546964, 48.27401784158523, 47.84367499812957, 49.78344786551691, 51.21626223287275, 53.44098352616834, 57.25091111275458, 56.3490209271831, 55.86956608679987, 55.491516282481534, 54.272478934257265, 49.73302187458162, 51.33239576893469, 52.724319427244126, 52.95994012586532, 54.07789015000867, 56.09913849061536, 57.51583191656298, 60.04755320087556, 61.38274369701263, 61.069883684958185, 41.518762880756015, 45.9016820692247, 70.29066208870181, 66.57438108997961, 67.52128831801876, 69.88146474284511, 72.45832074073054, 74.24732162106422, 69.66261217671057, 65.54316251508652, 59.763742262317294, 64.25581316794118, 75.72200729000953, 69.99773948423325, 76.51667164218041, 74.4072288082492, 71.45807712308823, 61.19258719105875, 7.081597630054721, 0.053239061962813146, 1.9599468429242413, 5.483713746070863, 3.236760948934863, 26.071782727395338, 74.27740620028588, 57.84818218600366, 31.323249993785737, 42.45449527617424, 33.68840194517566, 45.55241853960099, 33.22840598321731, 50.992761658084014, 59.00701507445305, 3.03266556512925, 0.2412854438467372, 0.022893723648702426, 0.08834298414688918, 0.03950439250817703, 0.07720046511460697, 0.05291117250078148, 0.015936531595915796, 0.05695557664899577, 0.028037678472877994, 0.033632006811639, 0.033931447598602504, 0.0584669532104125, 0.048135411024333975, 0.0237394540735911, 0.05267476925866739, 0.01680347212259808, 0.04562142838333403, 0.020189324108463143, 0.08051554206758738, 0.005542491478169518, 0.04099157601294499, 0.12178444573956153, 0.3466670431437031, 0.16161423026313707, 0.13764695504740362, 0.21964195845348222, 0.12564996452701668, 0.1791174394348937, 0.2035197913045845, 0.0779103834722792, 0.10957373967093807, 0.19328433569640885, 0.12523809267628577, 0.18465535114369086, 0.09150167191100698, 0.1374478794394001, 0.22607574870269145, 0.14582330421093972, 0.09351743310089074, 0.17615119295735515, 0.10485633877256226, 0.19030714948331157, 0.20992260095813584, 0.20661359142151572, 0.3163183168057473, 0.2265077610049517, 0.13213303721239492, 0.48453461619154103, 37.95814898706252, 101.21258105001142, 63.081718337151315, 85.88016156227359, 102.85727793170561, 96.74944939151888, 17.210762154671457, 50.277548836123565, 108.45804599023636, 88.87528342585411, 78.40242954992479, 27.008552589724143, 9.410552478605702, 4.840053781386345, 0.20910276430508784, 53.46717319180889, 109.02191808146816, 82.57560391579905, 97.71221868453488, 82.8201715407833, 87.51477795262491, 82.40232144632648, 83.7745548063709, 85.4725488539665, 86.47898197174074, 86.72063135331678, 84.26358807471492, 83.77773192621048, 82.6917217623803, 76.23215075462096, 67.95349428730627, 64.50143983287197, 71.50729502401045, 77.96602664455291, 68.43152922968711, 68.01933519301876, 80.32659530639648, 74.35912486045592, 74.47941610890051, 65.42489520965084, 59.79439166284377, 57.99545934123378, 61.19249305417461, 59.53207139045962, 55.011669205081084, 54.84888299818962, 61.61581093265165, 51.897523018621634, 54.94528308991463, 54.04459314961588, 55.426295111256266, 55.804862668437345, 57.37166127850933, 57.813610415304865, 56.16943128647343, 58.87176390617125, 59.19460242794406, 57.944343013148156, 64.56688850156723, 61.67239504475748, 68.20676957407306, 72.11575661936115, 59.684012243824625, 68.04887064041631, 69.19767010596492, 70.34571647644043, 68.09931232083228, 60.13837568221554, 69.31071281433105, 68.38077375965734, 69.93537379849342, 67.26260016041418, 67.02448875673356, 53.35961787931381, 50.59817906348936, 50.925493009628795, 53.645833230787716, 54.065993601276034, 57.60287715542702, 60.21314390244023, 59.26980210888771, 59.48483428647442, 59.69008407285137, 56.507610197990175, 52.358362290167044, 51.86172746842908, 56.88156112547844, 54.39877925380584, 56.90229869657948, 59.60538048898021, 60.63168041167721, 63.231133184125355, 65.74841230146347, 64.01777628929385, 52.24690421935051, 52.72864187917402, 69.81998551276423, 66.05469842110911, 71.86417579650879, 73.83016186375772, 76.69870099713727, 76.99831516511979, 74.07291735372236, 68.64354902698149, 66.37338315286945, 66.40310687403526, 76.74546349433162, 73.98507979608351, 78.21570119550152, 76.45060323899793, 74.48020058293497, 67.82501312994188, 9.295296572869825, 0.1589798837179138, 4.798433021191628, 12.104215679630158, 6.361551467449435, 28.089661752024007, 82.80620005822952, 66.81304162548435, 33.98196781835249, 58.807566473560954, 69.1825532913208, 50.36990888657109, 44.91432343759845, 60.31021471946471, 76.98255508176743, 13.530912130109726, 0.9149120868213716, 0.3145337303078944, 0.2798647583732682, 0.22487401721938965, 0.19635087840499418, 0.16085837727352498, 0.19338165950630942, 0.1890915211650633, 0.1185196931023271, 0.15971448542850633, 0.15160991870347532, 0.17409914984337746, 0.1456412663983722, 0.09211336247502797, 0.11434140359802593, 0.18259596890739857, 0.09405548729362989, 0.18196465117075752, 0.15123862653009354, 0.2952178958202562, 0.08736623736519007], [0.05564055608345136, 0.04269570795698993, 0.028040302324018655, 0.029885645339926405, 0.024610160880031127, 0.01603170461396897, 0.025983116844849243, 0.04507585120717845, 0.05747811373082861, 0.02656501233427515, 0.01173588764598413, 0.0809423066675663, 0.06252186808494792, 0.01575886431495629, 0.09605213458980284, 0.031320627613533894, 0.055687551747166344, 0.0671021162622398, 0.04746320334473445, 0.004777752826245683, 0.07637327401748589, 0.019012452178304235, 0.07791191564812776, 0.07431972171029738, 0.041283915164850415, 0.07725737012562252, 0.1275250413304856, 1.4577197019130954, 81.07889021596601, 57.07978986924695, 65.60373175528743, 67.72697740985502, 68.49748780650478, 49.42848120966266, 8.419019464523561, 71.6659470527403, 90.00031332815848, 73.79842204432335, 24.19831556658591, 0.1526959249449353, 0.7528483314860253, 0.02492542904351027, 24.61026445511849, 98.08642848845452, 87.2648053015432, 87.35760857982021, 86.47318470862605, 84.4346583274103, 81.44782835437407, 83.33875594600555, 78.12802053266957, 77.3966867693009, 79.89279685481903, 87.3605582021898, 78.89729146034487, 75.33832103975358, 67.35914537983557, 58.80331462429416, 62.30202959429834, 69.607832354884, 77.07709989240094, 60.12077208488219, 68.40977576471144, 77.68918575779085, 72.94929165993968, 64.08574311963974, 55.27167920143374, 56.1477719583819, 55.50361287209296, 54.69590663909913, 57.154059948459754, 53.46169364067816, 54.731462924711174, 51.8547534942627, 52.80366113108974, 48.601457303570164, 49.15069110931889, 47.397607372653106, 50.07671171619047, 48.76856988476169, 48.6756803143409, 50.35281519736014, 54.416531901205744, 51.659748938775834, 55.3229602690666, 54.44052896191997, 61.872506526208696, 63.80367371343798, 66.22739253505584, 42.41916256566202, 60.68669557571412, 65.97197563417497, 64.93240241081484, 62.82799197781471, 61.18336177641346, 65.95852974922427, 64.35592382184922, 66.1523497489191, 65.83406509891634, 58.916851551302024, 49.63808090456071, 46.760504630304155, 47.21737446323518, 48.11708773336103, 48.78377299154959, 50.95711515795801, 50.02857246706563, 52.48063041317848, 52.230214534267304, 49.35365023151521, 47.902381112498624, 46.99676859763361, 48.463374184023955, 50.030663090367476, 51.68915494795769, 51.43085902737033, 52.26657882813485, 55.269588578131895, 55.05059872904132, 57.48675930884577, 58.985222385775664, 57.473842943868334, 48.19519781297254, 62.005631769857104, 67.87325043832102, 61.385893360261, 67.17736705656975, 71.7742358484576, 70.08064270019531, 69.71388539960309, 67.6952297456803, 50.40085246486049, 47.4319947919538, 63.93177832326582, 70.49158942314887, 70.86515595836025, 65.6956015094634, 52.913381591919936, 16.08424077110906, 0.4966221046784232, 0.08107333068525599, 0.34233239509405633, 3.387391975810451, 1.0415812317402133, 30.600188509110485, 71.45993632654991, 33.39750720608619, 10.637380634584735, 35.640326315356845, 40.431783891493275, 38.176970174235684, 32.47261820300933, 60.978582674457186, 20.67749019592039, 0.6816152086661709, 0.07075331429199827, 0.12649619290905614, 0.019320417608645175, 0.053919811522768396, 0.05862360669960899, 0.07695666529358396, 0.03744249367305348, 0.05299000677862956, 0.050842294604667736, 0.006753551518364299, 0.03904615318582904, 0.0189341273489258, 0.027753653290170818, 0.10727067252681141, 0.06892181256966246, 0.05681979905573591, 0.05456857308144531, 0.03296743702864455, 0.07563366209186854, 0.015864875561918224, 0.048108877569076516, 0.04332033774605201, 0.03547108897398557, 0.053948279350034656, 0.016628507216791474, 0.026674629940140634, 0.04414946704562153, 0.03323312781210388, 0.06537775959699385, 0.015027599874883892, 0.03597503693233575, 0.05319852058986022, 0.061916490085423, 0.11373119924457804, 0.0474302270900338, 0.027152986731380228, 0.04631012227506407, 0.038342723592875466, 0.12825342240713297, 0.03753230982129613, 0.059506994176415674, 0.06104602651189893, 0.025502201319942554, 0.015112963137066653, 0.02801887675999634, 0.00988383561507949, 0.08461345362687304, 0.17527032974025897, 3.2289750441428158, 89.5583720361033, 65.37347293669178, 61.82095481503395, 77.84645711222004, 51.98349745042863, 31.67473162374189, 26.392169767810454, 90.19806354276596, 92.97954174780077, 78.24475811373803, 26.308523262700728, 0.9446986271969734, 4.175053181186799, 0.16458608450428133, 27.088943527590846, 97.78053852819629, 89.22281326786165, 88.50757691168016, 88.02686691284181, 87.02113197695824, 83.9738739690473, 86.8842883263865, 81.44940514718333, 83.32373326824558, 85.42589618313698, 89.71879697615101, 83.78234463353311, 81.99317116891184, 70.64219274828511, 62.8647171297381, 64.6659440378989, 71.2825902815788, 78.93474225075015, 64.81993236849385, 72.61449383151147, 79.7426171456614, 74.61203928916686, 66.67865337864046, 58.69870108942832, 57.2748532602864, 56.137495348530436, 59.065073997743674, 60.33580818483907, 57.64896108258156, 55.826506307048184, 56.45029652503229, 54.409471634895574, 51.78396255739274, 51.87387112648257, 52.161220042936264, 53.06509494781495, 51.20665634832075, 52.20725690164874, 54.55416787055231, 57.333229895560976, 55.535780229876124, 57.8111118655051, 57.273252933256096, 66.15995130231305, 65.97086168104603, 70.16271437368086, 46.524440703853486, 62.58851166694396, 69.28389164709276, 67.36418954787716, 67.10652120651739, 64.79528811670119, 70.4176841243621, 68.07027109207647, 67.69616326978131, 66.6692553797076, 62.718699055333296, 52.5401053121013, 50.65734409516858, 48.5049944539224, 51.584192322146514, 51.980226193704915, 56.130756716574396, 54.24870544864286, 54.12711197330106, 55.10106394367834, 52.474762547400694, 48.9796914592866, 50.26973155237014, 51.7824799014676, 52.56354931862124, 53.474719832020426, 55.59632985822616, 54.09930629114951, 57.72065024222098, 57.82349086576893, 60.59224490196475, 61.757926248735004, 61.96157178571148, 54.817237315639375, 66.62888634589412, 69.60107018870693, 66.08487713721492, 71.23593761074927, 74.19669166687997, 71.94549437492125, 72.54451874763735, 68.45474181636688, 57.16321868281211, 51.78265640812536, 68.34978703529605, 72.28041771919497, 74.08806554732784, 68.02035500926357, 54.85089909645819, 16.03874716066545, 0.6148958146091431, 0.5222610143884536, 1.0940428102208724, 2.7690376725889023, 1.7235491472867228, 33.775482485371256, 77.69523405259656, 39.0328235010947, 14.357697752214248, 23.89452015199969, 35.80909805913126, 41.78856311305877, 34.848046764250725, 71.88449367400139, 23.72849798971607, 0.9094100433491892, 0.1370054789848866, 0.052028432368270816, 0.056180713187542655, 0.057329416064725774, 0.06894329367505928, 0.0485856753713902, 0.06320938220127456, 0.045903731783431385, 0.0630087246217074, 0.016119110458079847, 0.07154904215806915, 0.04288935966248955, 0.034894431610741926, 0.01266280711147814, 0.06554597718340736, 0.06185447909839212, 0.0694150506188312, 0.030100329989387147, 0.033444610214041125, 0.03041003252409639, 0.023221235812431382, 0.2074892605624853, 0.265273142966532, 0.1462804288753579, 0.10531290419279568, 0.11144238899672225, 0.1588783311026712, 0.12665753102590963, 0.1223750688856648, 0.17667138197970006, 0.12776769968050142, 0.19214940708010428, 0.1471327170128784, 0.2144419374845682, 0.10301578955184068, 0.12781233196297, 0.14893253333866596, 0.16889850068236553, 0.15040867751644504, 0.1395207448231597, 0.3039813900907194, 0.12226137377682234, 0.09791587329199238, 0.20006759993491635, 0.21846826578820908, 0.16715701429113267, 0.20825058341987673, 0.5397401990429048, 6.567959823916036, 107.67595675683792, 77.32430335014098, 78.6929516638479, 84.2742726110643, 101.80336060062533, 64.11089335718464, 16.043741318487353, 84.07367475571172, 107.53983482237786, 84.68701577955677, 29.67439736089399, 2.497452271561469, 6.646232191593417, 0.3480929166318909, 28.9050813259617, 100.7722871534286, 91.5296454583445, 90.80921588405486, 92.5495715295115, 90.58738231658937, 90.35713134273406, 91.46236896514894, 85.67801044833276, 84.03860876637121, 83.59061917951031, 95.71614803806429, 88.85677768338113, 84.99080334940265, 75.19334239344444, 65.26871427412956, 68.34504881212789, 76.63257768077236, 85.56061390907534, 69.66006263609856, 78.40756785485053, 82.4012702511203, 78.8801585474322, 67.39909864241078, 61.88035126655333, 60.245656428798554, 58.62727472859045, 62.08684052190473, 61.70253845953173, 61.13414779786141, 60.48694495231875, 58.29770149723176, 59.28532685002973, 55.826235663506296, 54.938391485521876, 53.243009736461026, 57.12022558335335, 53.961517349366225, 54.584291673475704, 57.52996029392366, 59.24575405736124, 56.83160581896382, 59.18219204871886, 59.67335516406644, 68.64396479821974, 65.72531738588887, 71.20624526854485, 48.04669295587848, 63.83690403353784, 69.12939733074558, 66.90663722253615, 65.89596010023548, 64.57759657213765, 74.53112863725232, 69.83314898706251, 71.31805635267689, 68.83733764771493, 63.91824614617133, 53.53290427115656, 51.30570403991207, 51.049777230908795, 53.68338992518764, 53.76915254900533, 59.24501665176884, 54.83200503933815, 57.46009895878454, 57.76345506791146, 54.31812747832268, 52.03405680194978, 52.658964895433, 52.34435942865188, 54.37998717831027, 57.0275007524798, 57.66127340255245, 56.49411724459741, 59.36171500913559, 60.349767900282345, 63.88667891102453, 65.92240471993723, 69.23820387932562, 62.899355580729825, 69.2692925853114, 72.19441583079677, 70.13932920271351, 75.39099847116779, 78.27911023170718, 78.8863794265255, 76.00867763642343, 71.70929708788472, 62.7163613227106, 58.28513814556984, 68.72520492922875, 75.182861820344, 75.27212712072557, 70.35563222823605, 57.91514881195561, 18.791993125792473, 0.9594395071748765, 0.31672045167896057, 1.098655517543516, 9.026905452051471, 2.5947971642017365, 36.91544571230489, 85.08395964099516, 42.310638427734375, 17.429014598169637, 50.86210750764417, 61.32424939063288, 53.98586350102579, 46.82385483095723, 78.14202339418473, 45.3710755994243, 1.2497074637682208, 0.21996800547405598, 0.22708194390419992, 0.15389293732662357, 0.34062699144405706, 0.196584795691794, 0.18628350248740566, 0.25582801430456104, 0.19653405002768964, 0.13667334922619406, 0.062371040694415576, 0.1657706096528038, 0.09579436132504095, 0.1846215819879886, 0.21216936830070712, 0.14488784956835932, 0.12357657820346857, 0.2258381695156136, 0.12029648848599005, 0.18598825220138798, 0.12670723481043694, 0.19433265041199424], [0.08084034036484458, 0.04798154226474224, 0.003470904024828586, 0.018415200456436125, 0.03170140395541826, 0.014956518406829527, 0.03069070798735465, 0.01269153540863866, 0.033715885778468464, 0.029528562182320223, 0.028865968906170422, 0.06376530539484755, 0.01002763127607684, 0.06747454224574952, 0.09170242525156468, 0.07882277120745952, 0.050002524343829964, 0.020891981867833004, 0.039029682295457016, 0.01120263490931041, 0.05162322548248115, 0.019829054025091955, 0.06894376864957233, 0.053341265752791404, 0.030616108260508028, 0.027033220375737837, 0.05440949875440809, 0.11982025758874033, 23.940321668501824, 81.9547397859635, 49.05473032305318, 85.94076218143587, 57.40451897344282, 65.04437431212395, 20.7549334726026, 20.444101325927242, 80.1577372704783, 80.59883133057626, 30.52520455852632, 0.7925702967951376, 0.8686517142961103, 0.14897069983905362, 4.9821284028791615, 65.32153291086998, 94.04683436116865, 88.16881748937791, 91.20043308504167, 91.46466747406991, 87.35078365572038, 75.43073208101335, 71.99792861938477, 52.060128796485166, 68.16202317514728, 88.9958570849511, 77.39707116157778, 74.17681309484666, 65.41478333934661, 66.26672606314382, 64.13974238980201, 73.86008170343214, 72.97514792411559, 68.0559544409475, 78.31929883649273, 76.36806088109171, 72.31040031679215, 62.97213123690698, 57.00081686819754, 55.677938692031375, 55.30030073658113, 57.699649872318396, 57.18423474219538, 54.609806691446614, 51.317004388378514, 49.99971951207807, 53.27726771754604, 49.602650134794175, 48.233962597385535, 49.77070408482706, 49.89460783620035, 50.434686829966886, 51.54260343120944, 50.51936295724685, 53.44188959367814, 55.494328621895086, 54.78164572869578, 56.275076404694595, 58.97330622519217, 64.19897410177416, 68.47604028640255, 50.21771307914488, 63.16357428027738, 67.72299228175994, 66.93110496767106, 67.50461040004608, 61.012334669789965, 63.7402529101218, 64.33295834449031, 66.70869088942005, 62.218051648909054, 57.46119330006262, 49.38045963164299, 48.246780903108665, 46.795962856661895, 46.66659916600874, 50.710362772787775, 51.50895341750115, 50.969600062216486, 51.16250614966116, 49.014941800025206, 50.18996623254592, 48.878964993261526, 49.81807062702794, 46.400733070988814, 49.421283660396455, 49.213315671490086, 52.878354826281154, 53.15124196390952, 53.76222564328102, 54.41566505739766, 58.16704734679192, 57.15085929439914, 64.15123101203673, 63.47612442508821, 62.19027734571888, 68.7980668775497, 65.96251487731934, 66.3680487294351, 71.19372506295481, 70.19235180270287, 67.29777597611951, 63.57037898032897, 52.54458465883809, 34.20402496091781, 45.38054420102028, 59.09669222370271, 59.12065006071522, 47.99327027413153, 24.784017609011745, 1.7520308254226562, 0.04435530337955683, 0.1792558562010527, 0.9181295335292817, 2.037736759070427, 1.2273478700268654, 34.32055465636715, 66.50599064365511, 22.49405553264003, 21.217837872043734, 41.50832153135731, 50.60706323192966, 65.01807482011857, 45.18255472183228, 43.16880203062489, 0.9561220400275724, 0.1421461281396689, 0.04068024554139665, 0.02170073705905628, 0.03130574060994531, 0.056457228793372075, 0.04788210405217064, 0.05433344537572515, 0.04147144582783503, 0.010530273054516124, 0.04149632070273642, 0.05885773083014835, 0.018993386165088704, 0.03747953785463207, 0.01856407623798136, 0.0654544066938181, 0.048697596986687956, 0.059365953559116016, 0.03561374220636583, 0.039811823592190786, 0.018419145809246168, 0.030775027454740582, 0.06328690646877212, 0.06387265346523735, 0.03954941166504737, 0.010921919226436125, 0.019648014042045803, 0.06317203924540551, 0.009363953027904276, 0.05896051301650944, 0.058876067144616004, 0.09036713399954381, 0.03987889075952192, 0.0323199050410861, 0.03701895047279616, 0.09111859730534977, 0.05583123536780477, 0.08122339198786406, 0.022072988757563215, 0.025950408720922087, 0.011703826866352992, 0.02264104295341719, 0.02965703512722206, 0.02496304204537263, 0.03217683812122672, 0.05948718314269378, 0.03690110699784371, 0.055825045377376585, 0.11383780804012092, 0.024475206831289877, 0.2489603118550393, 32.882576488679454, 93.43937689258208, 54.08390314348283, 94.76028211655156, 66.80204329952117, 32.42846408197957, 26.252607914709277, 41.12893812118038, 87.40040948314052, 87.15137820090018, 35.09572090641145, 1.0465715897660102, 2.616612651655751, 0.27374913976077114, 5.841853599394522, 69.09047957389586, 94.841122165803, 92.73717065011301, 94.01031709486439, 96.89557336991834, 93.60619529601067, 81.05189646444013, 80.21443905368929, 61.922281403695386, 72.47239420490881, 93.04633971183532, 80.52003091381442, 77.15894406841647, 68.79707059552594, 68.51225160783338, 64.20241402041528, 74.54214265269619, 74.71410720579087, 70.95211490508049, 77.56623514236944, 78.94120631679412, 73.91556755188974, 65.07023449867003, 58.762051290081395, 58.538629162696104, 58.06639932817029, 62.819166644927, 60.72960238302908, 58.872422864360196, 53.56014120963312, 52.601341355231504, 56.189909981143096, 53.02847962225638, 53.19243861782936, 52.81822489153955, 52.36243371040591, 52.402504644086285, 54.680295605813306, 55.330420617134344, 56.600225202498905, 59.28502874989664, 58.75870158595424, 59.71664636365829, 62.442862295335345, 66.99591036765807, 70.47131861409834, 50.32892796301073, 62.98130173836986, 69.03124393955355, 70.60145501167544, 68.20351400683003, 65.2646428538907, 68.10898488567722, 67.47007000830867, 70.33722846738755, 67.22909527440225, 61.27243488065658, 51.48685870632049, 51.14922892662787, 48.88040058074459, 50.62929130369618, 52.988428300426854, 54.21022699725244, 55.757935431695756, 55.134827706121634, 52.88860005717124, 52.21420734159408, 52.9341858433139, 52.34659910202027, 50.47268282982611, 51.65313582266531, 52.73625519967849, 56.414187185225956, 56.220037706436656, 57.19189905351209, 57.64781967286141, 61.52503944212391, 58.31980797552294, 66.79677947874993, 64.79748856636786, 65.61635394250193, 70.45618610997354, 70.92731768085112, 69.9779393596034, 75.56675987858927, 75.3850600027269, 74.37863472969302, 65.43251245252549, 57.379172617389315, 38.87219852016818, 49.9137568473816, 61.05869708522674, 60.81918931776478, 48.117209326836374, 24.616069562973518, 1.892746835947037, 0.2617501803944188, 1.3169638548166522, 3.716844349138199, 3.5406237792584205, 0.84496648201058, 39.97137608066682, 73.93910177292364, 29.287057422822524, 20.95542150159036, 30.347642783195745, 55.17041537069506, 68.91900139470255, 48.83372045332386, 50.05992004948278, 2.8829244259865057, 0.1641535206187156, 0.05348357041516612, 0.011295300904631374, 0.021763129174829494, 0.012629755205594966, 0.03183172317221761, 0.05787089467048646, 0.025684658565648624, 0.02716345340764571, 0.052292744193466446, 0.07493092963892607, 0.05354326398622605, 0.027576999160491174, 0.022051254843151378, 0.026476764751057473, 0.03389590111891589, 0.03423656892752455, 0.021011508820999055, 0.04135895347703369, 0.1071472864057268, 0.007420060940222034, 0.1160247439158059, 0.2166446088062179, 0.22720468651142814, 0.10284948718523788, 0.1280533508848279, 0.19188340603103562, 0.14297230800072994, 0.14321728759715635, 0.16122781551412999, 0.21274384231336657, 0.10688851722666334, 0.12984116261284198, 0.1600955988490774, 0.1378103156363772, 0.14345603123787912, 0.23007897179453607, 0.23250374732719314, 0.11453509360792176, 0.11694488446077994, 0.15855214618627103, 0.1392322361108757, 0.09354741778224708, 0.12457755634621268, 0.1526441220794955, 0.0864355324677402, 0.170424792975668, 0.2505329984330362, 0.11845465989843493, 0.3043683870665489, 52.38592870773808, 107.37792722640499, 67.15922217215261, 92.75230315423782, 79.59715212545088, 92.6438025505312, 29.667978402106996, 30.327921105969338, 92.44416175350067, 95.47118817606281, 38.25530382894701, 3.0814198909267305, 3.7708779400394814, 0.35818376548347935, 6.742868115825038, 72.08918648381388, 97.10189788572251, 96.23281832664244, 96.85891489828788, 100.84355661945959, 96.22576590507262, 84.56062132312407, 80.38902375005907, 62.56788784457792, 76.21388819909866, 94.19477831932807, 87.37731456756593, 83.62218641465711, 72.82969074864542, 73.14884616482642, 68.64930706639444, 79.88483444336923, 78.76771988407259, 75.59027841014247, 80.53550074177404, 81.80521119025447, 75.6953194833571, 68.30249894049861, 62.64406027332429, 62.795844231882405, 62.22387244624477, 65.08571609374016, 62.410612567778564, 61.22328758239747, 54.856810108307876, 54.91144872480824, 59.246546376136045, 55.53733741083453, 56.89712116795202, 57.76225090026856, 55.48300081683744, 56.25779051934519, 57.307448156418346, 57.31839549156928, 58.53919006163075, 62.421469688415534, 59.259721617544855, 61.876158252839126, 63.024345828640854, 70.09048784932783, 73.07632938508065, 53.25092115709859, 65.2106906521705, 70.02951068262901, 70.43508375844648, 68.50071983952677, 62.940999384849306, 70.56134485429334, 70.16779776542418, 72.69864436118834, 67.70319215713009, 63.548617670612956, 51.92235946655274, 53.12969246218282, 51.99936343777565, 52.59788574710969, 56.053348741223736, 58.94082115542505, 58.70185075267669, 56.51242686856178, 55.118659696271344, 53.96878157892535, 54.62115410835513, 55.82453727722169, 53.04729915434315, 53.28099004683956, 54.448742405060806, 58.7780467156441, 58.88737493945707, 59.85392147494901, 59.74334985979142, 64.08877511178294, 62.458481173361506, 69.96867472125639, 70.30608484821936, 69.35500421831685, 73.16901499225249, 73.0118848431495, 74.30738879788306, 81.56764107365763, 79.60721692731305, 77.79992995723602, 70.11982717821675, 62.37634281958304, 42.07677495095038, 55.11643571238364, 60.78823789473503, 63.82530166256813, 51.862700216231815, 27.00989600150816, 2.801271220368724, 0.44031583734097024, 1.6557930217635248, 5.567705910052023, 9.809117259517793, 1.808177715828342, 43.261428802244126, 79.93216176186839, 33.195469840880364, 29.524486334093158, 63.26287300355973, 65.36477311964958, 79.00154805952504, 56.774888346272135, 81.2028371134112, 8.214767921355463, 0.39898570026120833, 0.18588519805381376, 0.1592643474859576, 0.12436256909202184, 0.12292517364145288, 0.12783962001483287, 0.17266774520037637, 0.12075877658301785, 0.10303498771522315, 0.23895531081624571, 0.21445922042813995, 0.14676871799653576, 0.1342833540852993, 0.10216877209923922, 0.11131016222099144, 0.22006154480961063, 0.1439637023835413, 0.1496439532286698, 0.13558887516058263, 0.2723946963106432, 0.09526988987119929, 0.24065060210564446], [0.07273625627520584, 0.03072495211756999, 0.04445053959986375, 0.05387451274380569, 0.06267545339200767, 0.05338528899536018, 0.04866295066031237, 0.03666043281555176, 0.05173052758759549, 0.07215223680700987, 0.02484564673185589, 0.05735768853957134, 0.02422867207637718, 0.12346823804921682, 0.026464172180802114, 0.06400814760596522, 0.053034022360319094, 0.07543827902766005, 0.03901315777893028, 0.0067797048024893294, 0.09509038014878189, 0.031764608124391205, 0.13739423796294198, 0.01064648476218985, 0.09406004551677935, 0.013952033496612023, 0.05518411323728581, 0.144326031328209, 2.5775576118500005, 70.3885958271642, 56.38900949108986, 37.006625129330544, 68.94099020188855, 56.77437451577956, 61.80388073767386, 15.607065808388496, 46.19482040405274, 93.12169628758585, 32.39090934876473, 0.35320817763286255, 3.6680625667495117, 0.12103796200526339, 0.0655134644119009, 24.536412108329035, 68.06078680099981, 78.31048134834536, 82.82598449337868, 86.41220754192722, 73.63773822784424, 67.4557533571797, 46.33533539310579, 40.0540517991589, 79.49441740589758, 86.24092548124253, 73.46879389978224, 69.35090926385695, 69.00403838003837, 70.42318328734368, 65.2632543348497, 72.09786276663505, 74.47790991875434, 76.32134545233943, 80.15203414424774, 77.38320166064848, 72.17736136528754, 61.642400680049775, 56.1913691028472, 54.59613330902592, 57.74364317617109, 59.57454673705563, 62.03559083323326, 60.12536910272414, 58.04725816172939, 52.05546902072046, 50.699509574520974, 49.99045879610124, 47.71285218577231, 49.23705385577295, 49.21061315844136, 49.613703373939764, 51.669821585378344, 50.73752126386089, 54.16644550138905, 53.696251376982666, 55.59702411774666, 56.943471816278276, 61.654489424920854, 65.63718565048711, 67.6453136628674, 52.12547548355595, 66.40444047989385, 67.8706459845266, 68.65693215400943, 67.01847968562957, 63.854994004772564, 63.6250215191995, 65.07086992263794, 64.82507459578976, 62.91007541841077, 55.2722518674789, 49.746408923979736, 49.01233342386062, 47.64042169817033, 48.55801313154159, 49.43977763575893, 49.537393662237356, 50.41720482610887, 51.22897071223105, 48.52922685684697, 49.58337953013759, 49.31386955322758, 49.22004253633561, 49.34753525641657, 51.55088355464321, 49.375356628048806, 51.06600407631167, 52.35189822412307, 54.406494555934785, 55.758900334758145, 54.87097770937028, 57.17100458760416, 59.26983741021926, 60.020520225647964, 64.01758017078524, 67.62290908444312, 68.21335915596255, 68.10078713201708, 70.97161692957725, 66.85084542920514, 66.739669769041, 63.27703275988179, 50.79220302643315, 33.099156041299146, 29.596402991202574, 42.9919070582236, 34.42823940707792, 23.49678004941633, 3.564615937009935, 0.03638370270510355, 0.3259420358846265, 0.856870998057627, 0.8375678499860149, 0.4268564998863205, 1.7882851703513054, 43.76723804781514, 53.030405506010986, 18.651205532012447, 16.66932405964021, 44.826740834020804, 79.48388191961473, 59.12978133847637, 55.43883885106733, 14.340101019028696, 0.7619225510185765, 0.13535655133666533, 0.05493742526478826, 0.025685016711753224, 0.09759455303391142, 0.023339552346677072, 0.016799745104846456, 0.0419108891829608, 0.008746205581231944, 0.023582735466921044, 0.026288513965424032, 0.011036654299635802, 0.07957578967175177, 0.10411485759240967, 0.06966468802983723, 0.07401658071865959, 0.050870613044788765, 0.03304383897733304, 0.08907769310979113, 0.03806164593345696, 0.028985641416042086, 0.05762260940466678, 0.0337620310845875, 0.06499261655394109, 0.011430173556530669, 0.014639331193100062, 0.04807515054821007, 0.025247500067757025, 0.03372056657568582, 0.04526584867327925, 0.050755730499663664, 0.06597183013875639, 0.048183402602350524, 0.04271094927624349, 0.03876288068450747, 0.02443972546907683, 0.1616368451786618, 0.08243063164334144, 0.10123691806990294, 0.048325741738681836, 0.02549844940433339, 0.056487872310343294, 0.05254708538432756, 0.06992910327690263, 0.011861141106384176, 0.0656554971130625, 0.02697936247944111, 0.12445356501566789, 0.06612282606863207, 0.126179630056985, 0.2555729529910511, 4.218826832309846, 85.88091465734666, 61.18071025417697, 42.492499120773815, 74.11775788953229, 48.83324976890318, 38.06780276759979, 26.348958976807136, 58.269491810952466, 97.9137186850271, 35.96345509252241, 0.5472247554890571, 3.0028896274105197, 0.7731223274623195, 0.04433979392952977, 26.848698354536488, 70.61844671926191, 80.40698820544829, 85.58094747604864, 90.13946333239156, 82.0709047009868, 76.25049960228705, 53.28131168119369, 47.44764897131151, 82.6479559559976, 88.97855943249118, 79.22533496733635, 73.30977316825621, 71.13233996975806, 73.02670355766051, 67.87493705749512, 75.59129038164693, 75.61098067991196, 77.8905680871779, 81.03824661624047, 80.03980728887743, 75.98633581592192, 63.26486948997744, 59.02538353397001, 59.66489068923458, 60.058331874109086, 63.20825399891023, 65.15219634579074, 62.13159084320069, 59.20887985537129, 54.91917971641787, 54.205123993658255, 53.20683371636176, 52.974856899630645, 51.79263491784373, 52.24498618033625, 52.97756333504954, 53.335001084112356, 53.7417547933517, 58.876698247848026, 57.8020158890755, 59.939044752428615, 58.7982508444017, 64.32047736260199, 69.08710633554767, 70.8763425580917, 53.814954065507465, 69.4963978182885, 69.87798167813209, 69.65456347311698, 68.25874882359659, 68.06728224600515, 66.22665512946345, 69.10023058614424, 68.16412556555964, 65.82612622168757, 57.253915648306574, 52.32533201094597, 50.554687823018725, 50.986023026127974, 51.47842561045001, 53.13707044047695, 54.18291161137243, 54.07820001725228, 52.17224582549065, 51.67872144329933, 51.62731093745078, 53.12433058215726, 53.0065300387721, 53.75432991212415, 54.26828199817289, 53.69665538111041, 54.56500537933842, 56.914305071676935, 57.277645987849084, 60.45336161890338, 58.61260114177581, 58.83359139965427, 63.98616198570498, 62.10262021710796, 67.96026429822369, 69.51528010829803, 71.39218130419331, 73.20392408678609, 78.31389381039527, 72.33034164674821, 71.7527961730957, 67.3428596988801, 57.22466261156144, 35.77038818790067, 32.00133562088013, 44.43226806579098, 34.33622060283538, 24.235925212983165, 3.554371196416117, 0.16606924604744683, 1.4086915456479596, 3.131918936006485, 4.735217652013225, 2.7693338115369124, 2.0470829091725813, 48.769577933895974, 58.70354521659113, 27.061281011950587, 16.365073650114, 46.91020973267094, 84.33584597802933, 61.849203725014966, 65.50531164292367, 22.80851391053969, 1.2808345354372457, 0.09264914904751125, 0.15520924491988075, 0.016465347725898027, 0.04388274587390404, 0.04866354437845369, 0.022088061537473433, 0.04941660114714215, 0.03693930414174834, 0.04839304256282988, 0.03758268393275719, 0.048350076521596605, 0.04896687689207254, 0.05888633272280136, 0.08009615489431927, 0.014431300974871605, 0.02745961725351311, 0.044634469649604255, 0.03915991724258469, 0.039754006936545336, 0.044110752792368015, 0.06101878825575114, 0.042313330491343816, 0.18486216423972962, 0.15660596110167044, 0.13531446246610535, 0.14317080138191102, 0.15867519522866896, 0.20744226872920993, 0.20052234972676924, 0.1032540428962919, 0.1845362857584992, 0.16667595703996, 0.11006478670864336, 0.13383972789010695, 0.19746161396464995, 0.3447945403956598, 0.2090767326374208, 0.18249046327846666, 0.1667897517402326, 0.2172920450327858, 0.14526793643111183, 0.18442783835193804, 0.172158143513145, 0.10015658853996186, 0.1884942330540188, 0.12739115980483834, 0.31238846961529027, 0.1320712752039394, 0.2422821242362261, 0.45151748303924844, 7.2222798101363646, 105.9650973350771, 71.66746893236714, 57.915423377867675, 85.16457219277659, 83.84456911394673, 80.75338056010585, 22.75287508964539, 56.76173663908436, 109.51812928722752, 41.245526652182306, 1.3175321081953666, 6.606691268182571, 0.26973125374605583, 0.18885608702417345, 27.65939343360163, 74.08266836597075, 79.01396628349059, 88.78150739977437, 90.71150179832213, 86.03747214040449, 80.07166477941698, 54.69527513750138, 55.80848301610639, 87.22937845414685, 93.22605486839049, 84.0478341810165, 79.1571798632222, 77.1779832532329, 80.75036817981352, 71.49774013027069, 80.20547251547538, 80.23302324356573, 81.49983898285898, 83.75721793020926, 82.57509400767665, 79.7887912873299, 67.08120622942525, 62.91341335542741, 60.44546196537634, 63.806815531946, 65.43690550711848, 68.62703584855603, 65.24369347480037, 62.69255253576464, 58.07488733722318, 56.55036403286842, 56.583060910624845, 54.94720505129907, 53.21716916176581, 54.490625473760794, 55.12722223035751, 55.9981256915677, 56.33322554249918, 59.530780930672925, 59.54734902228079, 62.69594146359352, 58.857764967026256, 64.76912590765184, 69.5780066520937, 70.39159251797584, 54.90461595596806, 68.88297834704, 71.2465201654742, 70.82415150057885, 71.01822253196471, 67.55643275476271, 67.83001022954141, 70.44343056217318, 69.37311772377261, 66.71113060366723, 59.87694578786051, 52.216749037465746, 52.294870884187766, 52.676038972793094, 53.44620420086769, 54.885321817090436, 56.93751373598653, 56.14541461390834, 56.22436800310689, 53.72962290240873, 54.97426940548805, 56.13658143628029, 55.032755867127456, 54.82771004399946, 57.25481387107604, 56.481938285212365, 56.77659065492692, 58.44037771224976, 59.133746854720584, 62.13050434666296, 61.18548770104686, 63.12818665658275, 67.08665832396477, 66.50344894778344, 71.15368550823581, 72.73591472256568, 75.37184945998654, 75.14395975297498, 80.59696428237423, 77.0628224649737, 79.01487627337056, 71.30650889488959, 62.21976572467435, 41.891799895994126, 35.841818471108716, 47.29345275509743, 37.72643889150312, 24.87698954920615, 5.172398167271768, 0.24156256849246643, 1.983969153896455, 3.3014599546309444, 7.823711537545728, 7.20216001233747, 3.4525817680743436, 53.16555861503848, 67.2124252011699, 29.280444306712, 28.599183520963116, 62.715851414588194, 87.66206295259538, 73.20074696694651, 73.661633306934, 35.24364525272001, 1.621646460506224, 0.20172089428430606, 0.43226220014114536, 0.20245520488148738, 0.16980515041899297, 0.08306696725588653, 0.0903723050930327, 0.2328041610458205, 0.06976155984786249, 0.16625273942707047, 0.13054093796639674, 0.1391501268071513, 0.19469902430090213, 0.26200617633519635, 0.16065248348299535, 0.17039836294228033, 0.20478015915761072, 0.18805575496967764, 0.1471057660397022, 0.0998235088322432, 0.08716961323854425, 0.19170314554245244, 0.16739166702233976], [0.0308513987599121, 0.02494126408090515, 0.04704945457858905, 0.009506414738303472, 0.03974281056153198, 0.04921897344531552, 0.057795967441052205, 0.008634606680472293, 0.024543426960947055, 0.041809861337946314, 0.053458343139819564, 0.1009053475553951, 0.03641993100304277, 0.019863993380098574, 0.03709722167601989, 0.014635891458320041, 0.058412771641967766, 0.036888455055774226, 0.03593429637652251, 0.004660947400430639, 0.08319552447046004, 0.023080685491403265, 0.06398113534575509, 0.03891206481644223, 0.03503291732481411, 0.10622740633064702, 0.03970219641022625, 0.028327160116825855, 0.24070415165155168, 39.31370442913425, 92.49334827546151, 65.79273508441064, 97.76762608558901, 59.534613086331284, 64.05384248302829, 31.890511012846428, 22.02091374704915, 91.00074521956905, 49.996432565873675, 1.1692934819767553, 3.354406313550088, 1.6766518186176977, 0.23167680137820784, 1.9667106025641965, 18.930282169772735, 44.32406948458764, 53.169429994398556, 56.35392388989849, 44.68410384270453, 31.354197494445312, 25.342610189991614, 65.73548416937551, 84.30310987657117, 74.19931965489542, 69.30675122045702, 72.22988190189486, 75.80507524551885, 75.92465262259208, 69.12438454166536, 71.20357021208733, 75.87658005376016, 78.34026782743393, 82.94474601745605, 76.41262685098957, 71.56723668498378, 61.815220309842026, 58.24659693625666, 56.96701780442269, 58.09412264054822, 59.68148623743365, 59.22598138932259, 59.68255704449069, 59.263679289048724, 53.81794683394894, 53.36603095454555, 50.39483162664598, 50.42504956645351, 48.15075343655002, 47.95219521368704, 49.66441569789764, 51.0117773086794, 51.423508505667414, 54.11271687476866, 54.16923038421139, 55.398057968385764, 56.966147038244436, 61.84552846416351, 66.3285739960209, 67.25626161021572, 43.86801942702263, 68.91582427486297, 69.31542750327819, 67.5780842381139, 67.95734605481549, 64.72083760846046, 64.55978901155534, 64.91458308312201, 65.42997860139417, 62.67627469954952, 55.850766166563965, 50.39789499775056, 48.51082309599846, 47.61935072560465, 47.32218803897981, 50.71425376399871, 49.69129570068852, 50.2451265242792, 52.07226460979831, 53.23282334112352, 53.103059568712794, 51.731398874713534, 52.917484391120176, 50.820844173431404, 49.621257858891646, 49.14730218149001, 51.9017787902586, 52.56296096309539, 56.817869678620376, 56.68128098210981, 57.57321226981379, 57.251326883992846, 61.744284245275686, 62.77107054187406, 66.4001258727043, 66.52216649824574, 70.36564996165615, 72.58176557479366, 73.24412053631198, 68.93680895528486, 61.94149317279939, 56.33719498111356, 46.38286275248374, 28.991781396250573, 22.1539193584073, 22.265834385348906, 14.248796086157522, 2.7603452099907786, 0.1984409960888086, 0.4293214337479684, 0.3676902731099437, 2.5749681120918644, 4.635425200385432, 0.8847641980936451, 1.7699648824430283, 47.33224499610163, 53.61660372826361, 20.779528694768107, 43.9313147144933, 55.3960693267084, 63.87457447667276, 43.41675858343802, 62.25351772000713, 9.356187447424858, 0.31697549767071204, 0.18600118376554983, 0.07185358509060837, 0.060052414304546775, 0.11961161354256254, 0.03961251815780997, 0.07415161903707251, 0.029419710664379022, 0.005338929946564379, 0.05964015174897448, 0.09207733335994905, 0.12770200764099437, 0.004595168697227154, 0.06856303827296342, 0.05483429833886124, 0.08327154337518639, 0.018857282984461037, 0.045536511367367166, 0.04508571075876394, 0.015248447701695467, 0.02214092926512803, 0.0453560593568029, 0.029480660619634776, 0.04124144708076793, 0.037474546791805376, 0.03329468680725944, 0.013924707140352939, 0.030998388049943797, 0.01990552300647382, 0.06670954216632151, 0.00742612021689814, 0.014394560355633019, 0.07598859062718769, 0.04552163393987764, 0.05256607287353086, 0.03436775382367834, 0.04636063428235151, 0.0391204905275616, 0.034804125166227745, 0.03041499677384573, 0.0483510417923812, 0.019308585380654664, 0.01102296622364872, 0.04323963804410831, 0.024358244357450355, 0.02729639647558572, 0.024044326423937758, 0.031962783579083706, 0.12668451264260278, 0.047512026128148845, 0.016402028643736438, 0.21749625342988202, 46.619142409293886, 101.60888948748189, 63.01506942318332, 94.76405543665733, 65.62645012332548, 46.413014011998335, 30.46430583923094, 37.36232134603685, 93.47671001188218, 56.1388603333504, 1.772100980724058, 4.731210460585933, 3.3126193429193194, 0.5920313995692038, 2.5039719862322656, 23.313493574819258, 47.48040076225035, 56.73660601339033, 61.98317227825042, 53.80922348268571, 38.36016447313371, 33.798216542889996, 69.3192086681243, 86.98414402623331, 80.72523363174932, 73.93161789063485, 75.45650205304547, 79.18154562673261, 78.84029942174112, 70.555782933389, 73.44691491896107, 76.90749660614999, 81.57099077778479, 82.96744085127308, 79.9231638446931, 75.19909258811705, 64.18774827834099, 60.78939891630604, 61.06575342916674, 61.889780644447576, 64.32277587152296, 63.462062728020456, 62.629241558813284, 61.20382085923226, 57.83747019306306, 55.892178550843276, 54.909691502971036, 53.01348440108761, 51.780667766448, 52.71043423683413, 53.08708767737112, 55.884051399846236, 54.53576803207398, 57.536094880873165, 58.05729550700034, 59.48351244772635, 58.52585400304487, 64.17593017701181, 69.7857589106406, 69.07883013448408, 49.33680365162511, 69.45596602655226, 72.7589782591789, 71.31988417717719, 68.82419770763767, 68.71406539793938, 69.0695890303581, 69.66403207471295, 68.72678956677838, 65.10303335805094, 59.771708596137266, 53.060156683768, 51.872470840331054, 50.27219480083835, 50.591899348843484, 52.97775553118799, 52.82864270671722, 52.95899875702397, 56.070822900341405, 55.7112592266452, 58.03680504522016, 55.47126508528187, 55.10814382183937, 52.388242906139745, 53.890545983468336, 51.67823899176813, 56.80813043348251, 57.286463475996456, 60.08326245892433, 59.49975498260991, 61.61208468098795, 60.855318269421986, 65.80209385964179, 65.38972331631568, 67.30918222858061, 68.75950997875583, 72.0822831123106, 74.85954084704, 77.96530492844121, 77.33302670140421, 71.75274910465365, 61.50845958340553, 50.1821764053837, 29.9438073173646, 24.890984565980975, 21.44364283930871, 15.121307719138363, 2.3813363861653114, 0.2525831722924786, 0.9253512298868549, 2.426268852526142, 6.164879414343066, 4.0738871645542885, 0.7150116779150502, 3.0948128238801034, 51.9915775329836, 71.55131970682453, 21.64511734439481, 39.87889051437378, 62.87266777407739, 63.100671229823945, 49.578237302841686, 70.61717587132608, 10.70436687238755, 0.5705248600532932, 0.2676211411674177, 0.0515228143382457, 0.03372722387974782, 0.08308721495972526, 0.03706499235704541, 0.06556166666409662, 0.170434353752963, 0.059312480622001236, 0.0919642664432045, 0.057062323340365005, 0.11833279829231963, 0.06898289275986534, 0.06473305830431562, 0.019079458058601426, 0.057904541252120856, 0.019327482854526852, 0.06997829378252068, 0.009574389719824878, 0.07824477319034838, 0.01992000206824272, 0.013503797367335328, 0.04222539125851566, 0.13135190332128158, 0.1947141621982859, 0.13865998375319666, 0.13142822100029838, 0.0878630530449652, 0.11931372025320608, 0.14862252819922664, 0.18984489202980073, 0.11882162367504452, 0.1936191314410779, 0.12455316410670358, 0.19203319154199094, 0.1538671354853338, 0.1522339432830772, 0.13274262869550338, 0.08297195703151726, 0.1551423348005741, 0.14019268054154613, 0.11668239209440448, 0.19990845282952632, 0.14726673643435204, 0.1529141987163213, 0.24561224715603938, 0.15602397942735305, 0.24483713471601087, 0.19699368746049944, 0.21538201929821124, 0.10231235229800786, 0.1932674511185577, 65.71194602597144, 111.8704923506706, 81.15532936588411, 107.60199654486873, 78.22724080854847, 88.96022627430578, 41.514126639212336, 30.188272960724372, 103.96291563587805, 63.643931265800234, 3.4078748379984214, 11.274704990848418, 5.431752147213106, 0.7454840814875019, 3.391419024236741, 24.430596367005382, 50.83485095731674, 56.708855244421194, 65.32645548543623, 53.81646025565363, 39.084849819060295, 40.11094185613817, 81.96689128875732, 94.02036620724587, 88.08018761296427, 80.32697185393303, 81.04804469693093, 86.770076751709, 83.59391397045505, 73.49037478047033, 76.05398101191368, 82.15201147140996, 85.11756650863155, 85.21466870461741, 81.2486582417642, 75.53152130496117, 66.33003311772501, 63.65325866207, 63.75292216577838, 65.45459931896579, 67.1161388581799, 66.99150946832472, 63.50473419312508, 65.19449910809918, 60.617759919935665, 61.51945006462836, 58.42579826231926, 56.974548755153535, 53.5549597586355, 54.04851551978819, 57.62702326620779, 59.534165936131636, 57.25482171581638, 61.246794346840154, 59.595299997637355, 59.84960686775946, 60.789963737610854, 68.29883544675766, 72.52656213698849, 69.82204083473452, 49.42679851285873, 71.23399995988416, 75.13280453220491, 70.64241240101477, 73.56821813891011, 67.1512911396642, 70.21543102879679, 69.55567267633253, 72.10130660764634, 67.0718474541941, 63.077882259122795, 56.73615494082051, 53.61118693505564, 51.1807922394045, 54.805128958917436, 55.39593204375237, 56.12268447875977, 54.3118909097487, 58.31155530868038, 57.950014760417325, 59.78795897576117, 58.3167681386394, 56.812770597396366, 55.45195917929373, 56.33814027232509, 53.26604973885321, 58.51047046722905, 58.59470728904971, 63.090025917176284, 61.05732425566643, 62.99898770547683, 62.19399967501241, 68.27742715035716, 67.21928150423112, 71.3406962733115, 69.72630362356864, 75.30280005547309, 77.76760178227579, 82.98412661398612, 80.05540263268256, 77.26452642871489, 65.7361235157136, 55.26698804670765, 32.21852902443179, 28.927499632681574, 24.099105096632435, 17.821486957611576, 3.318942203637093, 0.5155301658857254, 1.0678082824714723, 1.652411325804649, 7.987533250162679, 16.730687579801007, 5.929843148877544, 3.6626357224679764, 60.09186813908239, 71.20233858785322, 29.287928189000777, 64.38384325273576, 67.88624132833174, 77.77033175191572, 57.39263026945053, 82.15430998033094, 17.54702106598885, 0.8213012905851488, 0.43745171038373826, 0.24198025495054262, 0.25819562435630833, 0.22305262785765434, 0.1276239815859064, 0.16264969002335303, 0.11314689632385008, 0.23410602022082577, 0.1966602553523356, 0.1335302590122146, 0.18982379396836604, 0.13378170439072196, 0.1374233799475816, 0.11676568117353225, 0.1806248399999834, 0.10835467161790979, 0.12865993164239392, 0.10793132377007317, 0.2413396522282593, 0.1921139218874516, 0.13198591768741608, 0.13029404315015963], [0.01633342738533693, 0.0374710074655952, 0.054897841501740686, 0.052288097870205684, 0.060022916089022355, 0.023621558887703765, 0.013473997504690723, 0.03819921617245963, 0.0264762687091265, 0.044849736525887446, 0.043535512691784295, 0.021613083193979917, 0.021705672580508456, 0.03259653556010416, 0.055297609163267966, 0.03519151284689865, 0.014075016463926483, 0.04059876826020979, 0.022882496630172097, 0.0454716045679825, 0.05215367242213219, 0.030048320280207746, 0.1252297729614281, 0.09889655010474306, 0.06732083436462187, 0.08672619388709146, 0.12411319981178931, 0.07102554363589134, 0.992664434015751, 14.649398538374133, 90.40486658773115, 68.5722089582874, 78.36377066950645, 57.63456598404915, 51.22245957774501, 45.32769418531849, 16.632726384747414, 59.30875908943915, 63.95916038943876, 0.2040520385508576, 3.1882208826080447, 3.7876161644535684, 0.16033605852675054, 0.30631516969973044, 2.578044721195775, 13.41879019814153, 20.32657927082431, 20.61913121131159, 15.97660505002545, 13.296906467406982, 36.75727221273607, 76.08201811390539, 73.7135027300927, 80.2087280827184, 72.47096646216609, 79.44298728819817, 81.15621582154306, 80.6939801862163, 68.77345792708859, 72.75132963734289, 76.27484183157645, 79.37497338941021, 80.77898579259073, 78.69568163348784, 70.057736058389, 62.31329464143323, 56.78824401670887, 56.60794050462785, 52.02492552418863, 56.02822203789988, 60.73038685706354, 65.08631621637653, 63.30700359036846, 59.521222114562995, 56.87713669192407, 52.525584697723396, 49.40717097251646, 51.01132623610958, 48.529003281747144, 49.27247285842896, 50.54166947641681, 53.589323643715154, 53.553418267157774, 53.51848171603296, 52.11166089580905, 56.04963425667056, 64.54035758972168, 64.71719764894056, 68.26411462599232, 37.820658145412324, 67.50592831642398, 69.73654100971838, 63.91697922060567, 68.82211885144635, 67.40553917423372, 68.10954970698204, 64.82919308447069, 61.975602103817856, 57.25346457573676, 53.56845663439844, 49.52248081084221, 51.749708498677904, 51.03122441999374, 48.5135373761577, 50.32546451014858, 49.711609655810946, 53.254259094115234, 61.063698107196444, 59.77573294793407, 61.331399871457016, 57.36356158410349, 53.99914464642925, 52.0780893295042, 50.33678839283605, 51.33587098890736, 50.66174891687209, 50.863896108442745, 54.76527375559653, 59.036605435033, 56.70825119941466, 58.32160834343203, 58.010646758540986, 59.894690590520064, 64.65252168716924, 68.18957390323763, 66.84061588779574, 69.99128326292961, 74.76938909099948, 67.77220233794182, 64.8301697546436, 54.58164407360939, 35.324379397976784, 18.777213634983188, 11.132867182454756, 7.358408118447951, 0.9585612026914474, 0.3644988733914591, 0.20281745721736263, 0.35503906648485895, 1.3261381560756316, 6.11474956235578, 1.9429503549491207, 0.3486405775672005, 1.0824371297513287, 49.88253478080996, 14.095711861887287, 28.817655617190947, 47.266431546980336, 26.170275403607278, 35.900281398527085, 58.92261743545533, 36.35447617500059, 0.10969878820281838, 0.07644021478030952, 0.04787594470525942, 0.07181418518866263, 0.059122774269311666, 0.035357451321737426, 0.02407399700924514, 0.039406532436729445, 0.03300036731806975, 0.018477611724407445, 0.03593958621363967, 0.018412262509246508, 0.023233713469498103, 0.06663350027895744, 0.05378753878176213, 0.005222960035391753, 0.03730660116660499, 0.03258603249466227, 0.022843188658777266, 0.033629597465117136, 0.05880909190783578, 0.030317113719760414, 0.0799502764317778, 0.029580545078422275, 0.03405277294317081, 0.02357999861781155, 0.0598606854797371, 0.03429022189530154, 0.024887015479767037, 0.06203188207901775, 0.03979678528623716, 0.023935122505551385, 0.014006698658058961, 0.03971815402168901, 0.015007799374870958, 0.019512766964673516, 0.06972028303050226, 0.043808856693607186, 0.05527386426805489, 0.028124108512495315, 0.014589050927409723, 0.12159918269683277, 0.03662816902262069, 0.014107066709848662, 0.05256811066740944, 0.05872147443193582, 0.022798297821634242, 0.07924176001500699, 0.07206630472454333, 0.09579390167228638, 0.08942640867204436, 0.19380385056138041, 1.0299266442175836, 16.120428558318846, 98.2080533427577, 73.83429604191934, 84.3067341466104, 70.52977761914654, 51.5761749975143, 30.49223311485783, 26.373589500304192, 72.93017402771981, 65.06555511105445, 1.2769582531144543, 4.345005558383081, 6.069591314561906, 0.8475349603160736, 0.6860794787926059, 4.049353474570859, 14.432765053164575, 23.204332051738618, 23.750298523133804, 19.644433990601573, 18.08364249044849, 43.398974557076734, 81.03525777016917, 80.96507872304609, 83.32212509647493, 79.47314247008293, 86.36843389080417, 84.86946875049223, 82.73493059219854, 71.65432114754954, 76.85322669244583, 78.46203388706331, 82.89079773810603, 83.21392259290143, 82.44668345297538, 73.93763480647918, 64.98797455141622, 59.98348520648096, 60.80103266623713, 59.60795356381325, 63.021011813994384, 64.12507664772772, 67.45749488953622, 64.96065524316603, 63.12143233514602, 59.86682607281593, 54.30682712985624, 52.086746000474506, 55.40409449608096, 50.21457518300703, 51.760157692816954, 53.38314033323719, 57.896474407565215, 58.39974195726457, 57.53365124425581, 55.874190561233036, 58.89876942480765, 66.54735595949235, 70.74196215598815, 72.99374780347271, 40.41303103969943, 68.92802284609887, 71.24322537452944, 66.947265132781, 70.52496094857493, 71.1165092837426, 70.30329212065666, 69.41627164040843, 67.11486801024407, 61.755337484421275, 57.65284815142232, 53.85310303780341, 54.258895766350534, 52.5088361770876, 52.432918702402425, 54.328670809345866, 53.8163935753607, 56.353970958340554, 62.52858961782148, 64.48979431583037, 64.82228971296742, 62.57227697680074, 56.178342911504934, 54.93304137260684, 56.33233516447006, 54.234251514557876, 55.328506500490256, 56.13299638994279, 59.27108472393405, 62.82065714559248, 62.172999305109826, 62.7643358322882, 63.39653561192175, 63.04789181678527, 68.28912365821101, 71.19321515483242, 71.5023842165547, 74.46456601542812, 79.72920263967207, 75.16293617986864, 73.00245546525525, 61.513805773950395, 37.022812751031694, 19.58917760079907, 12.066148096515287, 8.09961203605898, 0.8644433788234188, 0.7449262469045578, 0.8518480353297726, 1.7372821007044086, 5.27593550182158, 3.8399665682546558, 2.5820207788098246, 0.11614631440850998, 1.427932609954188, 55.482094749327636, 23.91057441311498, 30.619543444725778, 56.085080715917776, 32.23080015951587, 43.0136134547572, 66.88787260363179, 37.992108868014434, 0.2809268320279737, 0.01842426136136055, 0.04269221076561559, 0.0556380394846201, 0.13816024927843001, 0.06145331715684264, 0.029236653954872203, 0.06706218009874707, 0.0186582054612377, 0.02276221508040063, 0.01339350560409648, 0.1233165909446055, 0.04422643206893437, 0.13012354262173176, 0.03858242867394321, 0.08069413248449564, 0.02694087805256488, 0.04047750037223582, 0.020014847583708265, 0.08669596405759936, 0.028585594132422443, 0.06411520073250418, 0.09020787964184439, 0.0735410699440587, 0.23409973829984668, 0.10311836872490183, 0.1596715998265051, 0.15462393842397198, 0.07816869299858809, 0.2556046996746333, 0.12763008730666292, 0.07817212507248887, 0.1038729117041634, 0.08782505508392088, 0.07070905739261259, 0.20737422479977533, 0.12902244444816344, 0.19202599031550271, 0.17483016626248438, 0.1508460064688998, 0.11358147502065667, 0.29058968287802517, 0.12417417274968279, 0.14295603629321824, 0.14225178698618568, 0.12367377943930127, 0.2894700300549307, 0.21238551234766362, 0.29003619967449096, 0.2597667174714227, 0.4009831366279433, 0.3732012032020477, 1.2186275831153317, 25.240491282555368, 113.33302651682209, 85.53346326274257, 89.7642650911885, 73.50900603878883, 75.98403730700093, 62.0820983763664, 24.092850877392678, 70.18082787913661, 76.90680626899966, 1.1162788493017997, 11.019319468928922, 11.964660690676782, 0.4854744528570483, 0.7749152796403055, 3.80930491032139, 14.33612177448888, 23.649599513699933, 22.801932173390544, 21.00341562301882, 21.531433328505486, 53.24424920543548, 89.45965382360643, 89.06347874672183, 94.0717649459839, 88.48947909570511, 96.029310072622, 92.64894085545694, 91.4136609723491, 77.19688123272311, 78.5731154103433, 82.01729374547159, 85.87078709756175, 86.51463631660708, 83.79426079411661, 76.92593959070022, 68.91156458085584, 61.35717768822948, 65.23475047080748, 62.71713795200471, 68.50850182194864, 65.53711422028081, 71.99882291978406, 68.84893217394429, 66.53964457973358, 63.76273985831969, 59.30692342019851, 54.79125553561796, 59.05589957391063, 53.481140751992505, 54.46183919906617, 56.89115132054975, 59.91404356495027, 58.98273560308642, 61.14997848387688, 56.39489304634833, 59.87060331529187, 68.75272427835773, 70.91331481933594, 73.65394546139625, 43.63160640962663, 71.65593716406053, 74.40509503887546, 69.0772690311555, 71.52091349324873, 71.26538676600303, 70.85979800070487, 68.95253765967585, 67.45659274439659, 63.79465226204165, 59.60870665888633, 54.812204914708296, 56.799328634815836, 55.884000409033995, 55.04275398869669, 56.324941496695246, 54.05020606133246, 58.781639606721946, 66.7432705048592, 65.96327581713277, 67.7159712391515, 63.2860149875764, 59.92708152340305, 56.439792417710834, 57.449649764645486, 55.03735288496941, 58.969458380053126, 57.73416280746461, 60.611060511681345, 65.63591480255127, 62.4512130214322, 65.92782543551537, 65.31422553523895, 66.2141663028348, 70.73371733388593, 73.26175551260673, 71.62299709935343, 75.56410835635278, 82.13910687354304, 76.95470625354399, 75.63055330707182, 64.39053481624973, 40.789111814191266, 22.000431130009314, 14.126857442240562, 9.458681921805105, 1.9847104818590227, 0.6526835611270321, 0.813179410273029, 1.16342622906931, 5.108373809245325, 13.785012095205246, 9.277051668013296, 2.6494458317756653, 1.655359477285416, 58.51112550304782, 26.213845091481364, 45.954598765219416, 66.01860477078345, 37.89690117682181, 53.15853365005986, 74.10740283227737, 55.67012140827795, 0.5694367700526791, 0.21091010361429186, 0.14963753341186434, 0.2111490770813919, 0.2689852679689085, 0.21424050232575786, 0.11266989167779685, 0.1575871358715719, 0.12769843767126723, 0.10471312629599726, 0.0951372723906271, 0.1965596526861191, 0.16252198316637548, 0.24460301824635078, 0.09842847804388694, 0.18226360932232874, 0.1160148996859789, 0.16128292787940274, 0.06525618910428978, 0.1829501619983104, 0.09953192044650355, 0.08638285626206668, 0.21878936388079198, 0.22661668338602592], [0.06508170491865566, 0.012361388860060083, 0.05599618941966084, 0.01435475729991712, 0.05213682997911688, 0.12887154044883867, 0.06990314055714877, 0.05658376353582548, 0.004225224838592112, 0.017747740606747327, 0.08237839210778475, 0.022759095187329, 0.042831171454200824, 0.08535798383696426, 0.048705974158139966, 0.057240572848146966, 0.03479541091608905, 0.06468331621539208, 0.04679784449117799, 0.026163607159809723, 0.02883696481735716, 0.03228353501688088, 0.07869760776239057, 0.0632735497258123, 0.039831029416452494, 0.118860763107096, 0.017103962450017853, 0.1438262662099254, 0.11840202199715762, 0.19241645000875, 53.153885641405665, 82.01715254014539, 44.117729279302786, 35.72688910268968, 59.393325390354285, 68.01430671445786, 24.513395640157885, 27.523428393948464, 70.34667353476249, 1.286335537029851, 5.441028062374362, 2.2261706090742543, 0.5766845746867119, 0.3646892615624013, 1.5768867010070433, 0.826851444378976, 1.9312145008194832, 7.7751628910341575, 10.35708708147849, 23.578430068108347, 48.874242459574056, 71.50665175530219, 80.05948974240212, 77.89358046747024, 77.38750057835733, 78.23488158564415, 82.21825245888003, 81.32025718688965, 75.66993390360187, 72.06049826837355, 77.61045594369212, 77.06345004420128, 80.16843749630837, 78.4906985682826, 73.75900222409156, 61.97518241020941, 57.986473191169004, 51.6903434261199, 49.46880709740424, 53.94552192380352, 58.256834322406405, 64.32871041759368, 64.5094963812059, 68.175947589259, 65.97576464376142, 63.95220602712324, 56.76031281871181, 52.09932504161712, 49.31213978798159, 49.78158081731489, 50.061081071053785, 48.76464751458938, 50.97980606940485, 53.579658923610566, 54.787639110319084, 61.45964960898123, 64.61595343005273, 65.07055221065399, 71.35652695932697, 35.179451742479884, 62.024314018987845, 70.89611130376016, 64.92703660841912, 66.89073593385758, 61.738047676701704, 65.71022018309563, 63.326607596489694, 60.576135727667044, 56.80130158701251, 52.95211107500138, 49.22088192355249, 48.67205212193151, 49.717030371389086, 49.88433907108922, 49.912788021949034, 54.32978868484498, 61.795647682682166, 66.69066367610809, 67.46703409379529, 64.31446436912783, 60.38830910959552, 57.73289588189895, 53.51445344186599, 51.723322714528734, 48.8490451535871, 51.846818539404104, 50.140960139613, 53.87606459279215, 56.97400746806976, 59.83683170810823, 59.23637567027923, 63.825701744325706, 62.62332662459343, 66.53378455869614, 64.6053591082173, 70.99796741239487, 72.66262131352579, 74.15320042640933, 74.71401306890672, 68.51337340570265, 46.950692515219416, 25.2994268555795, 6.758275185861896, 2.9173032651024484, 0.6319765722559345, 0.09346009141975835, 0.05056222052043004, 0.20324010792518818, 2.538870784544176, 3.8782145803974526, 4.787238086423566, 1.7289379936072136, 0.26113583916617983, 7.632300363432977, 47.86580893301195, 19.41101178046196, 57.47410574266988, 34.43529575101791, 35.23128978667721, 48.08781900713521, 63.62628452239498, 4.758806786229534, 0.4804734002438284, 0.2044803736310813, 0.06948437391509933, 0.033632183011861584, 0.08012319013716714, 0.04643008398312715, 0.03894815904899471, 0.04954062695164354, 0.044669656067966454, 0.0217999454452506, 0.03970219641022625, 0.05157368640685755, 0.029015323492668332, 0.058725052062542214, 0.08952993779413163, 0.007972112995752645, 0.045858865844145905, 0.05815001497525842, 0.09857958888695126, 0.015176896047177575, 0.02155209876476757, 0.05457904933380985, 0.043832092140350616, 0.06423057740434043, 0.05778849808379047, 0.019057417709019878, 0.023679132310433254, 0.02392183088006512, 0.042823284579020356, 0.045562431952285196, 0.023519617482839573, 0.03311675139552644, 0.051055630939381744, 0.02379503566771746, 0.044415904764807036, 0.02029114293925945, 0.04414935979331213, 0.027458560052177602, 0.040405415329000646, 0.027953550527473132, 0.02670403430989433, 0.08698363773404591, 0.056670886885014274, 0.049401130001511306, 0.037499371870991685, 0.06843811231515101, 0.03362267969116088, 0.036173928679237445, 0.023416222426139062, 0.16503237668545018, 0.06127394916069123, 0.16197185542794967, 0.09076320145639682, 0.11707547946923202, 54.72907027890606, 95.31513275638704, 47.860141108112956, 42.63389272074546, 64.88997021029073, 51.94573287040957, 25.380006067214477, 40.886115950922814, 74.53993828065934, 1.106386386579083, 0.5647621628257536, 5.000926361929986, 2.585061105989641, 2.0852991746317957, 1.5778574876246916, 1.040704336858565, 2.972357652841076, 9.453425945774201, 12.186770785239435, 23.76534277392972, 52.736706272248306, 80.86641542373165, 84.28718505367156, 84.6673333260321, 84.81297093053018, 85.00945814194219, 85.81126905256703, 85.70772632475823, 78.2418006466281, 77.40784199007096, 80.93426458297238, 79.5191675616849, 83.56975217019358, 79.27728283789851, 75.89147721567463, 65.38364364254859, 62.827344786736276, 59.096664767111506, 56.78477271910637, 60.09351161218459, 60.76864565572431, 66.77662634080457, 69.07531569080969, 71.58825274436705, 68.95939396273705, 66.54966231315368, 58.275485192575765, 54.47405738215293, 55.59703196248701, 54.290537526530606, 53.46045024933354, 53.54408694851784, 54.699319101149044, 56.51086184286303, 56.62225323338663, 62.07203357450424, 67.46446101896225, 68.73462646238266, 74.15935070283952, 37.73833936260593, 65.6644029771128, 73.17048195869693, 69.76176184992637, 70.26208369962632, 67.83838841222948, 69.94019046906503, 67.49166657847744, 64.71411074361494, 61.09522611864152, 55.98709206427298, 50.905936071949625, 53.308956546168176, 52.395993509600245, 55.37137408410349, 52.15472067556074, 56.89697211788547, 64.7387118493357, 70.93942211520287, 71.88429755549278, 69.30048327292167, 65.42988446451002, 60.754505511253114, 58.18660036210091, 58.07532272031231, 53.92789479224913, 56.54575132554578, 57.03347844462241, 58.49467116017496, 62.952570376857636, 66.14608180138373, 65.40016858808457, 68.09949274986022, 65.90146710795742, 70.2124814064272, 70.45185581330331, 74.00857479341569, 76.2153551655431, 77.43755786649643, 79.88983154296875, 72.96291012917796, 50.772959878367764, 27.654955271751653, 7.519722455932249, 3.8371451583600815, 1.3249690446161455, 0.7131159473811427, 0.891392145666384, 1.4936060794899542, 5.180368423461914, 7.05680726997314, 3.9278864956671193, 0.8473962064712279, 0.372754788446811, 9.544093493492374, 56.82140373414563, 19.738984684790335, 59.9423473881137, 46.354394189773075, 37.42821716493176, 52.80654799553656, 70.13671690417875, 4.27482896274136, 0.2300756469729447, 0.20533370364817882, 0.028275807328041525, 0.01535976219231323, 0.07507804150302565, 0.04347638602578833, 0.08587648746587577, 0.03985395459758659, 0.004527441736671233, 0.07755197689778383, 0.009414872019401482, 0.06342769810749639, 0.011919153114450316, 0.05004773502268138, 0.06380134983168495, 0.0419065224817924, 0.07847797035449937, 0.031238263585574688, 0.029073458074802355, 0.03131651372138051, 0.023816737023392515, 0.037501742913117336, 0.03174289144695767, 0.013766189184670728, 0.14254768078605976, 0.11869502764555717, 0.19820435152899837, 0.10030295729877488, 0.1515329575106021, 0.3343287681139285, 0.14152429457153046, 0.16339923044846905, 0.07548448945125265, 0.1073138569031031, 0.1608927286560497, 0.10267299584924214, 0.10609675769604023, 0.1822857799068574, 0.14598047480948512, 0.13875698580616905, 0.2175790062474628, 0.1535775236064388, 0.12335425948784237, 0.11820510675710057, 0.21038881142533597, 0.17095062040513562, 0.20871677856531837, 0.10038410899259391, 0.16911473665987292, 0.21427863818262854, 0.12567054164866287, 0.1726630260987628, 0.19951463767117072, 0.20696914814893277, 75.99926394800987, 103.59138088841593, 62.052817883030066, 55.595345343312914, 78.8729884547572, 92.65818195958292, 36.54235378388436, 37.66007238818754, 84.14271631548482, 2.295924814478044, 12.49743034762721, 10.037383514065898, 1.9543175062825604, 0.6719440534230202, 3.278068900108338, 2.0353349202102233, 2.348307332684917, 10.45056991038784, 14.373164638396233, 28.731649806422574, 63.54058465650005, 86.7949838023032, 93.08976034964286, 90.37444468467467, 93.51469424463089, 91.64110352916103, 93.50059724623158, 90.13739232094058, 84.65296176172073, 77.79479165231028, 85.14627825829291, 83.96074971845074, 85.19583348304995, 83.78171705430555, 78.15700684824299, 68.93458104902699, 67.84324430650281, 63.28166900142547, 63.08419727510022, 64.70765059994113, 62.6372588834455, 70.07423354733375, 71.86962789104831, 76.19765743132561, 73.36234077330559, 70.81643227607974, 64.91278271521291, 57.83346153074696, 56.526096328612304, 57.508516696191606, 57.40293433589321, 55.446765961185584, 55.771310713983354, 60.30668458630962, 57.90579788146481, 65.17347520397556, 68.91782468365085, 72.2661324470274, 76.8602712692753, 40.37305032053302, 66.9684773106729, 76.17980280230123, 72.71642054280927, 70.43709985671505, 66.5705136329897, 71.88965551314816, 68.15108760710686, 64.97635256859564, 65.0027697317062, 58.4867871961286, 54.12284051218341, 55.12007567190356, 53.952393916345414, 57.84453438174341, 54.412888019315666, 61.11332001224641, 64.82423913094306, 71.89366417546427, 73.26557590115455, 71.22249172579858, 65.51103830337524, 64.02535430846676, 60.075323581695564, 61.23679230290075, 56.79862260818482, 59.803083635145626, 60.02559185028077, 63.09605460013113, 64.29367188484439, 68.70212570313485, 64.78240705305531, 67.98825433177333, 67.82073774645406, 70.31809514568698, 69.97869245467648, 72.69015635213545, 79.44881593027424, 78.58938540181806, 83.39064105864495, 76.78817026076779, 51.55369981642693, 30.250781812975486, 7.797591493975732, 5.013705443951392, 1.2116826590030425, 0.37478896639039444, 0.5554791996555944, 0.9027692867863564, 7.841874072628637, 13.498442749823294, 11.560460444419615, 4.2443796030936705, 0.9992277850547145, 9.5418724513823, 63.696985244750984, 32.128673407339285, 74.29632771399714, 47.40386747544812, 50.74522872124949, 61.32741474336194, 88.06416080844018, 10.793777300465493, 0.7778601216212396, 0.4045391941983854, 0.1660944809836726, 0.24860630262522931, 0.1459558067783233, 0.12229040850915256, 0.11739246366966156, 0.13171331296044012, 0.11961778821123224, 0.14744941776077594, 0.12202011736770793, 0.09952091942391089, 0.16565024191814084, 0.19625484162280638, 0.21243374524337633, 0.07058073000441636, 0.1442949588020002, 0.10088519944298653, 0.2249129498077016, 0.10187737523548065, 0.22357632556269247, 0.15137731908790528, 0.171146126043412, 0.10594959220578594], [0.047849694702533946, 0.015563726398883568, 0.028567365070264188, 0.06267360328967053, 0.018358958111475074, 0.04602950809883975, 0.04460581030035692, 0.047910043278769146, 0.02774933829993731, 0.04402705385620075, 0.017130028591641498, 0.026593671683522484, 0.04835509822794026, 0.0144603117669542, 0.07205390176104923, 0.03503696609949393, 0.09527503032117121, 0.029889464288228945, 0.057612880088028416, 0.030912124634450002, 0.003920616788579331, 0.09051578570037119, 0.04129504642239021, 0.054297266873501004, 0.017195190115260984, 0.07436979321702834, 0.05541408900171519, 0.06133338226185692, 0.10545005691387963, 0.22428055954796655, 2.0219991067724843, 71.3406805838308, 96.46081786001884, 51.168778019566695, 54.21421997008785, 73.39569660925096, 45.664143331589244, 18.627649737942605, 52.87067874785393, 2.2938204628805963, 1.2913835048675537, 5.77208443995445, 3.8000022740133352, 1.630397513508797, 1.8001076843469375, 0.6024174067762591, 1.2431718144685993, 2.4380543491532727, 9.472201351196537, 26.146743143758467, 53.012813675788145, 66.86224383692588, 76.50996438918575, 81.19345480395903, 81.22905423564296, 74.70406593814974, 82.43396712887673, 77.95935861525997, 72.87843012040662, 73.73385198654668, 78.25348930974161, 73.05783148734801, 81.41465294745662, 75.44904170497772, 70.99696328563076, 56.75073046838084, 54.07561125293855, 49.61166374145016, 53.686821999088416, 56.88924897101618, 62.71509439714494, 67.92602985135971, 75.6078584732548, 72.71118025625907, 73.26086121220743, 70.56452981887325, 67.45566706503591, 58.78562473481702, 52.0158766162011, 48.702917252817464, 52.398633264726215, 50.15146424693447, 51.11002875912575, 50.48110808095625, 61.837970056841456, 63.582989400432965, 69.0848627398091, 63.82298746416646, 71.08305146617275, 27.618328179082564, 60.26881802466608, 67.96617923244354, 65.76452932050152, 64.31528022212368, 61.84454787162043, 61.31301180008919, 59.7986239002597, 55.369907117659054, 52.153622411912494, 51.10947570493145, 48.77172739275041, 51.427572081165934, 51.67648176993094, 50.84041680059126, 55.3648276482859, 63.98429885987313, 64.74196349420856, 64.6323646268537, 68.83528232574463, 64.44350250305669, 62.752325534820564, 58.622222715808505, 53.53591272907873, 51.67136699922624, 50.27993363718833, 51.19868216976043, 49.193903861507295, 51.03897502345424, 48.30487905010101, 49.33144177159956, 56.210898583935155, 60.40185305380053, 60.31956957232568, 64.47944710331579, 67.26956628984021, 68.21417500895839, 72.95341799336096, 76.42652773088025, 71.69975003888531, 61.19204590397497, 38.82904460353237, 10.19665135491279, 1.2859689179928073, 0.42328999287659125, 0.5299269191680417, 0.25885219235093365, 1.5909968148316107, 3.172052872757758, 4.730702513648618, 7.260513603687287, 1.5962439655296266, 1.02227728693716, 0.13907299707493476, 13.182578202216858, 25.41693126001666, 40.42134254209457, 45.57169698899793, 34.72249169503489, 47.80634972356981, 66.91063804011192, 27.9725613517146, 0.3688265347192365, 0.18175029976954385, 0.05418410802620554, 0.042075712999869744, 0.018412199306992755, 0.08078423974614951, 0.026047085186526663, 0.080202916907447, 0.03159913313274663, 0.04266609865871649, 0.07982738826784395, 0.033779670259044055, 0.004100822693397922, 0.013243601349512897, 0.03289427563187576, 0.020957507283216523, 0.024857613025233153, 0.06341134979119224, 0.06370811693130002, 0.0397319321130072, 0.01040087505844572, 0.05038959792845192, 0.004381046643585808, 0.04007890099479307, 0.07119036745280027, 0.031800489767544696, 0.040673852537668524, 0.04198254138651875, 0.060817230522872946, 0.06684877098568025, 0.05643656357161461, 0.06427319104512853, 0.046307843163489334, 0.05332680584322061, 0.047608001623302705, 0.015612860405517202, 0.013030517823813904, 0.015631975256837904, 0.10109626432700504, 0.0347465957935539, 0.07983737805437657, 0.07055635308666576, 0.03841317686883192, 0.06884034677979446, 0.0352080948200197, 0.02280556033515642, 0.04415030591189862, 0.04893061028973711, 0.030700222799374215, 0.06141203267860317, 0.050793755273785324, 0.026281167182230183, 0.06836259136757544, 0.10182319749747554, 0.15040867751644504, 1.5452880868988654, 78.82072679458126, 105.76069478065737, 43.16479336830878, 64.8959949708754, 77.37412529606974, 34.23410169539913, 28.81036981459587, 62.658745627249445, 3.170575855239745, 0.18281670948190076, 2.817421824701371, 4.094554378140358, 6.09760586292513, 4.589203990274861, 0.8753073023211572, 0.5678631028821391, 3.468532821824474, 10.406754093785441, 27.125039139101585, 54.64846949423514, 75.03381959853634, 83.5255313688709, 86.6013442316363, 90.58866100926554, 84.64894525466427, 89.95486090260168, 83.53846734569919, 79.79116824365433, 78.62231762178483, 80.53426911753994, 78.6537201173844, 86.08036718060895, 80.56548333937123, 75.44144015158378, 64.75180079860073, 61.00241499562418, 57.18004565085135, 58.63169523977465, 62.02372958583217, 65.39241406225389, 70.87951183319092, 75.57629908284834, 74.4169641310169, 75.65406399388468, 72.8773553909794, 70.99958342890586, 59.78915529866373, 54.757958535225164, 53.578945052239206, 55.970857374129764, 52.31334917006954, 55.589230368214274, 54.785089569707075, 62.54624420596708, 66.97559249016547, 72.18956778126379, 67.7801255256899, 74.62639516399753, 31.012912065752094, 64.5006004456551, 73.0311123017342, 67.89663560928838, 67.82166342581472, 63.477909103516616, 64.906820712551, 63.980003864534446, 59.7231065073321, 55.50457385278518, 52.79936221338088, 52.168080268367646, 51.84193911090974, 53.741605743285156, 53.919944147909845, 59.196430252444365, 68.02413617410969, 68.73938821977185, 70.6647228425549, 74.98297783636278, 70.37940963622063, 66.24720050442603, 64.3280553817749, 61.34572828969648, 59.03202410667174, 54.51834878613872, 56.086684965318256, 57.58901549923805, 58.656970993165054, 58.600171150699744, 58.587976501834014, 64.43829359546785, 67.5118040269421, 67.00876789708292, 69.05791605672529, 71.09361833141696, 72.40536089866393, 74.72361503108856, 81.49223742946502, 75.56482222772415, 67.0490663282333, 40.765326561466345, 12.435118594477254, 1.4103198195657423, 1.1889808384641525, 1.9129341720573365, 1.5343468804513256, 4.892163940014378, 6.156837574897274, 7.017145243383224, 5.280802182612881, 1.8020785527844585, 0.7246112499025561, 0.06990829632887918, 14.81581489886007, 30.26607905664752, 43.81199229148127, 56.53316836203299, 42.19161410485545, 45.890279739133774, 78.93421665314706, 27.023559578003425, 0.3212236084284321, 0.17077184612712554, 0.02005752634196993, 0.06627976684080017, 0.056092888867903146, 0.14643265054591242, 0.08809002957517102, 0.048671481049349236, 0.05031143014709796, 0.03560616176635508, 0.11613624801318492, 0.04335743938422492, 0.012267505742549416, 0.04511911219226257, 0.012848870716087762, 0.012351759134851878, 0.03699088867212977, 0.05689982076986663, 0.0636861914949071, 0.04186692339698634, 0.006565358189325179, 0.042108114688627185, 0.031143586609452486, 0.05067885357646212, 0.024014200016315428, 0.12172212448692131, 0.12759512305379878, 0.14240494328400782, 0.16235805567233794, 0.13877169469431525, 0.1317287726147521, 0.15640345341976614, 0.21270886273874393, 0.1301157438466626, 0.13713372210341115, 0.19662135340754064, 0.20378616007585681, 0.13507861463773635, 0.14652064340489526, 0.26461078334719906, 0.16997008914909056, 0.1642401958064687, 0.13177685229287994, 0.10724163013360194, 0.1340305910355622, 0.12493266874263365, 0.22071523231364068, 0.14947366720486074, 0.16884386329160583, 0.19899374384793544, 0.1502242188660368, 0.21851885823472855, 0.2803642170563821, 0.2727635829679428, 0.8856613176964945, 5.758973917653484, 103.24966399900376, 114.59059330724902, 70.28120917658653, 69.21322622606831, 97.6406511183708, 67.50897992041804, 26.938336280084428, 66.5307015757407, 4.8028358817100525, 2.836462970702879, 15.680760279778513, 12.31177378085352, 4.204946054566292, 3.695347799408821, 1.2721622975603228, 2.168003820603894, 4.04967216714736, 12.92683574461168, 33.34411198093046, 56.87131197221818, 80.49313914391303, 90.53627383324408, 92.1788840140066, 99.2379657683834, 91.42449455876505, 98.48906763138311, 88.12782872107722, 83.00153409281086, 81.07994925591254, 84.80040365649809, 79.99807327024399, 86.44069963885893, 83.08829692102249, 80.3475642973377, 66.2363120048277, 63.602585561813854, 61.991185680512466, 65.71984567949849, 66.70851046039213, 68.58482330076157, 74.87341819270965, 79.12973896149667, 78.15328844131963, 79.58879747698384, 76.67834389594294, 75.66867090040638, 62.67656495494228, 57.718728280836544, 54.725120452142534, 58.819188456381525, 56.01974579595751, 58.09920995466171, 55.95193193804834, 66.46427231450235, 67.59178899949598, 74.00826884854224, 68.00645412937288, 75.0488736552577, 33.950753596521196, 65.57556521508002, 71.98102320394209, 71.00835384861116, 70.54167809024935, 66.13452649885609, 66.17190668659826, 66.79595578101375, 61.68783349375571, 57.95067764097645, 57.141045524228005, 53.37780198743267, 55.91208457946778, 56.58225290236935, 57.7256198852293, 62.02999361099736, 70.58860532699093, 69.90285734976493, 72.19908345130183, 75.4251858495897, 71.6174900916315, 68.69362200460127, 66.67933587105044, 62.899441872873616, 60.75223053655317, 58.673299820192405, 58.86814748087237, 61.16133374552573, 64.14520625145205, 63.49000569312804, 62.28990554809571, 69.16559296269571, 69.83671049917899, 69.09364100425475, 70.23474477952527, 73.69422820306593, 72.8762492825908, 75.85215937706732, 82.69197279407133, 77.95454194468837, 67.037291372976, 43.64757437859812, 13.889729572880654, 1.900782301541298, 0.8115359984578625, 1.4750852604066174, 0.9141990734684853, 3.262022483733393, 7.988349103158521, 13.786396691876075, 18.422990268276585, 5.266136440538592, 4.220934615981195, 0.32118417022209017, 18.173786401748657, 40.95571056489022, 55.75842965033747, 60.786982736279896, 51.33109354203748, 63.750772706923954, 83.88764458317911, 47.568763917492284, 0.4318076342103943, 0.29628542402098257, 0.14045817597258475, 0.18370051447662616, 0.12696470164002913, 0.17876612683457715, 0.15536140530340134, 0.15003614428062595, 0.19042057646138055, 0.13548985063549013, 0.2447762000825136, 0.10871041986730792, 0.1700051912977811, 0.15932439345746272, 0.09935415740455351, 0.16091522099750658, 0.12768756688362168, 0.1929550557847946, 0.13361572378104733, 0.1731439454541091, 0.09976121822311994, 0.14810574060726553, 0.12868844543493566, 0.17864366001900167, 0.15959877550842302], [0.06813736917871623, 0.04193423571245324, 0.0749121068586265, 0.04834811916695007, 0.04695033812294564, 0.03608938704635348, 0.03357665695910973, 0.0250026430453985, 0.06762644982025509, 0.012220689151886732, 0.05747349039020558, 0.06571812480087243, 0.07443429015937351, 0.04578919780831184, 0.027084170968361923, 0.056741137147670796, 0.03957552760238609, 0.06549242763750016, 0.030169706911809986, 0.009209736655916899, 0.07474127691239119, 0.031145683775145202, 0.07708238032195838, 0.06858650354608413, 0.0835935531123992, 0.03468088077140912, 0.022660292827734546, 0.16574457798513675, 0.11023931685955295, 0.11443318859223398, 0.5805400194179627, 14.655572349025359, 90.89987754821779, 71.54367892972886, 43.17830985592258, 67.69971693715742, 81.05204551450669, 21.910304869374922, 37.46841361445766, 9.045994647087591, 0.22018917505779576, 2.7162437958102075, 3.0867207290664798, 17.616543116108065, 0.8088029644662335, 0.1744334399700165, 0.22665932383989135, 0.7472485351947047, 6.019232984512083, 20.893316653466997, 42.71935332205988, 60.78747303255143, 73.76275985471665, 72.89616707832583, 74.27022826287055, 73.01006486338954, 70.66087891978603, 83.80359603512673, 74.8521589463757, 80.74961508474043, 69.09375867535992, 65.4079976389485, 78.09331540138491, 77.21333165322581, 66.58584225562312, 59.12678072529455, 51.423665400474306, 49.08690944794686, 53.2522233839958, 55.375092491026855, 60.19476759818293, 68.56128123498732, 75.07829927629041, 75.45439966263311, 77.1951553898473, 74.30138757151943, 76.3648602270311, 69.51649604305145, 62.3403040824398, 51.5702247619629, 51.963752238981186, 50.81331714507073, 50.73169262178483, 52.019857821925996, 62.888478848241995, 65.84838959478563, 71.13461494445801, 65.72404261558287, 70.07140944080969, 20.646101428616433, 58.625682246300485, 72.835417409097, 64.48469915697652, 63.887388860025716, 58.35699988949684, 56.605434110087735, 52.38516776792465, 55.23743690982942, 48.882997189798665, 50.05516613683393, 48.804459571838386, 51.40110392724314, 48.132875273304606, 54.69307076546454, 64.6896626103309, 65.00039669775194, 66.68825534082228, 68.82742189591931, 66.72803601910992, 68.27698784489786, 61.3128549052823, 59.44381806158251, 51.06876934728315, 51.902382835265136, 48.66965163138605, 49.18084629120366, 44.954123727736935, 44.300092035724276, 38.62511665590348, 38.78640059501895, 47.113145320646225, 57.854595261235396, 60.533578011297415, 65.74446639707013, 63.371589337625814, 72.26835250854492, 71.16519374232139, 73.80255622248497, 74.62177461193454, 58.9908274527519, 19.881558918183853, 8.546239579877547, 0.21861742310706647, 0.6419026202732517, 2.223736778382332, 3.797385072515857, 2.7586585908166827, 4.1128142370331675, 4.9009098449061, 4.443545793333362, 1.1956176113697792, 0.43001311921304275, 0.1266310243837295, 12.63404748132152, 35.828058796544234, 42.55164454060216, 42.22988074825656, 37.143060853404386, 63.2802059573512, 56.721096961728996, 0.578113359309012, 0.19642578648223033, 0.09364518592314375, 0.10217208159907211, 0.15982650280479463, 0.09672147327012594, 0.10850156131651133, 0.029540331208056984, 0.073883855985778, 0.023506969371209704, 0.05132498362311914, 0.17713232176198115, 0.042295875177989085, 0.072586769538541, 0.014387306460599988, 0.02074873683253123, 0.01812232887342332, 0.03632219733610269, 0.06296082497424176, 0.042307895097521045, 0.028044916088542635, 0.05669913637722212, 0.053292749404546716, 0.10861193926464166, 0.021962944057679946, 0.08901019310278278, 0.015827298949232266, 0.0793716961878442, 0.011476667432655251, 0.05751015535826164, 0.03483287644602599, 0.023998493298647866, 0.023003337424128287, 0.08522444705088293, 0.059041132279221094, 0.044106370769441135, 0.056426401415299025, 0.06257207748750526, 0.045672890339647575, 0.025094194382789637, 0.017322194086568012, 0.0523972194341402, 0.1370331807242286, 0.05411725919393282, 0.046598382008772705, 0.026456222103367892, 0.0383630785490236, 0.016628269729534947, 0.08234340487228287, 0.06075303618525786, 0.08157298855123021, 0.049337395316650795, 0.059465265367180116, 0.08666755751736703, 0.03444696731504894, 0.040931484076164426, 0.485694105586698, 16.385027727773114, 103.44871644050845, 74.3505976277013, 44.160698844540505, 75.83774858905424, 70.73527059247418, 21.30081169066891, 51.71041027192147, 9.839114566003124, 0.2682598439916488, 1.7609276189919443, 4.084785470078069, 13.537124183870132, 4.681522855835577, 2.550984779673238, 1.5035621581539031, 1.2674299579474235, 6.4710199159960595, 24.254413304790376, 46.31026360296434, 65.53938919498076, 80.36590530026345, 82.44908394352083, 82.23791922292402, 80.71369401870236, 81.45008763959332, 89.93639438383042, 80.4432701295422, 82.72999625052176, 75.44270315477925, 73.3930293975338, 81.42545515491118, 79.89747232006442, 71.91562160368889, 63.22564186588411, 57.846162165364916, 58.50074691157187, 59.52203404518866, 61.01961458882978, 62.90953020895682, 69.82496692288306, 78.63642246492448, 78.92393219855525, 79.3667991699711, 79.14127857454362, 77.50183766888034, 72.76227305012365, 64.21020776994767, 54.43049946138936, 55.51598794998662, 52.92141460603284, 53.76354748202909, 53.76199030107068, 65.61451435089111, 69.72695473701724, 73.51819222973239, 69.10524337522446, 74.1063359475905, 23.034303188323978, 61.58229427952921, 74.53219552193919, 68.10002619220366, 66.47541184579173, 61.75714569707071, 60.69862350340813, 54.53411279186126, 58.1547232597105, 52.63044926428026, 52.83162370804818, 50.8624291419983, 54.65117200728386, 51.71822755567489, 58.53946070517264, 65.6982373422192, 69.74014174553656, 70.80871305158063, 74.00244805120653, 72.08032977196478, 72.29806838497039, 66.29529660747897, 65.76763583767799, 59.50105328713695, 60.37464357191517, 55.155290711310606, 57.758756068445024, 52.69461139555901, 54.403054637293664, 48.650247666143606, 50.30929650029829, 57.945770755890884, 66.81872906223421, 64.77387982030069, 71.30991351219916, 69.1258671975905, 76.07955486543717, 76.11688798473728, 77.92331203337639, 78.0559273689024, 61.47595097941738, 21.60337155865085, 9.971792659451886, 0.501790348320238, 2.9098970947727083, 3.9856502606022746, 6.015780808464174, 5.883792071573197, 7.60851118833788, 5.136272647688466, 4.981424337433231, 1.652865830448366, 0.14152674605288815, 0.052773138778584625, 15.987205255416134, 46.80121491032262, 42.4806417957429, 50.00129238251717, 30.664215318618286, 71.95226438583867, 59.48199449046966, 1.410339308842536, 0.2599961454829862, 0.09342213942398948, 0.11958761200789483, 0.0952365114203384, 0.028307222678596457, 0.13963633216917515, 0.021379947316862886, 0.07904869819720907, 0.03769226897988589, 0.05413300996165603, 0.04864150402887214, 0.05386720809544768, 0.08800911536860852, 0.02944630540667042, 0.04916913176496183, 0.062359430631923105, 0.04289771385130383, 0.036994190511083415, 0.029226162380749182, 0.04813588599884703, 0.06907241779469675, 0.03227844436262404, 0.13434758289687096, 0.02106522499102979, 0.05341493659802983, 0.07371622062618695, 0.1639907422565645, 0.2124842151158279, 0.17151403210816846, 0.20224373397086898, 0.13226158676608918, 0.17120871542682572, 0.16075346919317401, 0.22892970201228896, 0.2366391512294931, 0.12723087888932036, 0.2466146578832019, 0.1634533775429572, 0.2826781090228789, 0.14406574529505548, 0.12021771932561552, 0.23203254196672674, 0.16242035394234045, 0.15203036307807893, 0.04262241632527402, 0.16617364850976776, 0.16989228525950065, 0.23189083102249333, 0.1232904060593536, 0.11499549712865584, 0.1255064992414367, 0.12134434354882087, 0.2894754539574346, 0.19126714958298593, 0.21589912864710056, 0.6168030671054318, 29.239432004190263, 116.68892014411189, 85.69306450505411, 65.44364806144469, 82.43040561676025, 109.71817016601564, 32.10125407864971, 53.37839034295852, 10.841946947959162, 0.2980286417709243, 7.020145856565045, 13.788656957687872, 33.57576324093726, 5.514752932133214, 2.101549799403837, 1.3924110128033547, 2.552158303799168, 8.161900745284173, 26.070547180791056, 46.549132024088216, 67.14506241583055, 82.26635640667331, 83.7887930100964, 83.35222536517729, 85.47188205103721, 87.31500379500851, 94.45424310622677, 86.20216461919969, 86.26391841519265, 76.85078697819864, 76.70702426664292, 83.99718069261121, 82.14042478992094, 73.46080795411142, 67.65441356166717, 63.258625076663115, 64.42044681118381, 64.73372651684669, 63.59106948298793, 64.81995198034471, 72.60489186932965, 78.7831191093691, 81.05530892649006, 82.97963157776864, 81.15399576002552, 79.95852008942636, 76.05361230911748, 68.55451906881025, 58.025461550681825, 57.73039733209918, 57.52037794359269, 56.29111497632919, 56.18314389259585, 67.44776741150888, 70.51224462447628, 76.26795414955386, 72.01464576105919, 74.8059142020441, 25.599290094067975, 64.64958383191016, 76.421263910109, 70.33775406499063, 70.62757799702307, 64.75340112563103, 64.09795345798616, 58.15980272908365, 60.08944803668607, 53.76578715539748, 55.9491039091541, 54.1203341176433, 58.34031804915398, 53.59727821042461, 62.352239854874156, 68.14230149792087, 71.14425613034156, 72.9369754175986, 77.12315636296427, 73.09483512755364, 73.05092027110439, 69.92704268424743, 71.20180514550978, 60.519116232472086, 64.86880902321109, 61.743484081760535, 64.33665321719262, 58.584054131661695, 61.865571775744044, 58.053180940689586, 60.16975464359407, 63.26900759050923, 69.2496572002288, 68.10643534506521, 71.83084349478446, 69.6267617133356, 77.81276395243984, 78.462983100645, 80.85168300136444, 79.52709074943297, 65.36833070939588, 23.30326403340986, 11.610139223837084, 0.5293677975573848, 2.568153729361873, 3.57517029969923, 8.114912221508643, 7.880997753912403, 15.103471721372298, 16.982605726488178, 10.71884826306374, 4.8276772326038735, 1.4047359579032468, 0.20723680394791788, 23.33451944012796, 49.36361697412307, 52.91797076502154, 59.76861776844148, 51.51872011923021, 76.80760168260144, 78.38936805725098, 3.9597167747635997, 0.725400197890497, 0.2458924667969827, 0.20877153853014593, 0.4469408431360799, 0.18440788942238978, 0.20348755432473076, 0.10317469916997418, 0.3596754306026044, 0.1439756227116431, 0.15381010790025035, 0.24364307943371036, 0.128731177819352, 0.2069966966706899, 0.1614582241182366, 0.13686715414927852, 0.22085792385041716, 0.10725562655997854, 0.17070276031811393, 0.12595652993167603, 0.15386780964270716, 0.22600951274075817, 0.1457490243258015, 0.2971602964305109, 0.11279195246677245, 0.17944765397377554], [0.012584242879623368, 0.05923071605784278, 0.10073954314594308, 0.0835157875272055, 0.055493072666708505, 0.02443817605624997, 0.023288917765321753, 0.020668000741411122, 0.04843351498786961, 0.0009540501102286902, 0.036698817650997834, 0.012087804498150946, 0.06848836002210457, 0.03511459378886127, 0.06357146216736687, 0.022939357591132005, 0.03294004938535152, 0.014000128496498352, 0.06443334172569937, 0.04629174382576058, 0.09146342114094766, 0.03561410992856949, 0.027299497216459245, 0.039587750535217986, 0.11037302984585685, 0.06300816154708305, 0.011667426198630804, 0.037293711737278974, 0.04984733025212923, 0.16217610979032132, 0.07553297515598036, 0.06624294865515924, 57.52442975198069, 101.98756294865763, 67.51271401682209, 46.37588877831736, 93.16539149130546, 57.60313603185839, 32.47727405640387, 12.694068570290844, 0.15108350904718523, 0.7295434465331416, 2.920062407370537, 8.123426216263926, 10.17145699070346, 4.803904237285738, 0.5966577126133827, 0.787845679348515, 0.6997504710189758, 8.800574887183405, 29.136975772919197, 42.50091260479343, 51.277388449638124, 53.717024249415246, 52.07173508982505, 58.566634885726444, 69.01797063889043, 75.43817673960041, 79.73132071956512, 74.79013842921104, 61.40780764241373, 54.76863914920438, 72.32702332158243, 67.06412822969499, 60.225240492051654, 48.2569476865953, 48.8218984296245, 49.753151478305945, 52.57522621462422, 57.092568951268355, 65.9766040309783, 73.12086397601713, 80.06965652588876, 80.28941123716294, 76.94026408656951, 70.16625235157629, 76.20645922999229, 78.71496400525494, 68.84388016116235, 59.79867096870177, 52.96530592826105, 50.99567205675187, 51.7230442262465, 51.520363592332416, 66.88871199084868, 67.87324259358068, 73.0695515294229, 66.7781089967297, 67.1873612557688, 21.592388922168364, 56.014219176384714, 74.06060895612164, 66.41026127722957, 69.00643887058382, 62.91535492866271, 58.756591350801536, 52.533182328747166, 52.847226896593654, 49.13493887070687, 50.36786140934114, 48.4182551599318, 51.866069532209835, 51.24340503446518, 64.87033482520812, 65.79229185658117, 66.14480310870756, 65.45704295558315, 61.90568193312615, 62.72900312177597, 65.65799774662142, 60.57569642220775, 57.163383422359345, 52.01963424682618, 47.968041589183194, 45.561047753980084, 40.09388739062894, 42.035492004886756, 36.937928738132605, 32.96120628233879, 26.182364148478356, 33.177493618380645, 41.61344497434555, 49.505661687543316, 55.831177849923414, 63.05924707843412, 64.74572112483364, 69.4346518670359, 78.8936044323829, 64.47128072861703, 52.06618493603122, 12.185260672723095, 2.384650298664647, 1.5629870468570342, 3.8963043064840384, 3.0754745583380423, 3.7595349357974146, 9.880888788930832, 7.636853254610493, 4.315952562516736, 3.874169391009116, 1.2965055074422591, 0.18332940616434623, 0.08287916080124917, 12.520614497123226, 39.624430671814956, 79.39028632256293, 37.50214992030975, 51.062164075912975, 64.45064513914048, 15.568423598043381, 0.4821042788605537, 0.08711080066859724, 0.029987301377038804, 0.008331957900325858, 0.10800281509516702, 0.07355271448050776, 0.10191560302290226, 0.08304904079845837, 0.028459113016123735, 0.08194739104158456, 0.06075742586906399, 0.03526389283398467, 0.06564134746910104, 0.029576337340498166, 0.022187110960423466, 0.05477732821037212, 0.08225843806060092, 0.030292870867396557, 0.043363633205092726, 0.009860504407345528, 0.06312493249894151, 0.0379020813101482, 0.12429737500966558, 0.020126976042745576, 0.058055560164634264, 0.08383625742769049, 0.04306398557438966, 0.050884820145344546, 0.023041653311661175, 0.037381114708560134, 0.005812817093570747, 0.023538763935287154, 0.04861569835714275, 0.03292584228479574, 0.03711015707062137, 0.04570626879050847, 0.028382883437218207, 0.032573319265558835, 0.04125036434420655, 0.014938902215010699, 0.04822016716183675, 0.08580707989993595, 0.0014345834290819064, 0.0746100383900827, 0.141702042291722, 0.028436630250765916, 0.030424925273344405, 0.03282807797433869, 0.024753034362689625, 0.042701396159827716, 0.10247097080273014, 0.02940823083683368, 0.07020675652329961, 0.022404796759327574, 0.07947283511560771, 0.08373235292252033, 0.036921155518822135, 0.12745047799281536, 60.843378574617454, 113.5059089045371, 62.35198882318313, 55.66197856780022, 103.04115080064344, 45.33976724070888, 39.38879036134289, 16.256082750135853, 0.17262709657511405, 0.6565645625514369, 2.8873934765015883, 5.089417484498793, 8.236031090059589, 5.3811908345068655, 2.5001935180156463, 1.3680648611437891, 0.679547445427987, 11.187236136005772, 31.493471053338823, 48.83955694014027, 58.69590051712529, 60.05324063762542, 56.8853775916561, 65.77084433647894, 72.86544707513625, 85.52074693864392, 85.68519623048844, 82.16836775502851, 66.12712106397076, 64.1522272940605, 82.33779061225154, 77.16762035123764, 70.47630786895752, 59.98531695335143, 57.79485756351102, 58.357635313464755, 58.71381790407243, 62.14320105891075, 71.4098084357477, 75.4341523878036, 82.78907499005719, 81.94501230793615, 80.53404162006994, 74.77978337195613, 80.36051596364668, 79.11476335217877, 72.10016127555602, 62.47576313634073, 54.80069668062272, 53.94488257746543, 56.32252923903927, 56.06519822151431, 70.88885491894138, 72.4705820698892, 76.61134981339978, 71.71981688468688, 70.90906297006916, 22.684102212229085, 60.85570266169887, 78.70456187955796, 67.3942505928778, 72.48920548346736, 65.08090334553873, 62.25596920136483, 54.66215072139617, 53.0434238526129, 53.73133305580386, 53.38769420500725, 50.56317975444179, 54.34949075022052, 54.936771546640706, 64.96625246540194, 71.05833268934681, 71.63934553823164, 68.96575604715656, 69.0473727257021, 68.55984564750426, 72.46322370344593, 67.151149934338, 66.14434811376756, 59.69610883343605, 56.909523702436886, 54.43405312876548, 51.62322382773123, 50.913690597780295, 50.62734973046088, 44.20815167888519, 40.63953615004017, 46.213800753316576, 53.24581423113423, 59.726601339155636, 66.72178376105525, 69.00493268043765, 72.8773710804601, 75.67304826551869, 83.59369431772541, 66.98824605634137, 55.27082804710635, 13.996584742299973, 2.9197165033509656, 3.8260774554744845, 6.840502773561786, 5.669805695933681, 7.326366276510301, 6.040066163386069, 4.017429303738379, 2.4232383312717563, 0.6902176406114333, 0.7773820827564886, 0.21659309705418928, 0.23171680648961376, 24.793335199356083, 42.700396507017075, 87.36379023521178, 45.48485571338285, 49.91310181156282, 73.2627361051498, 14.527795257106906, 0.3036774064023649, 0.07155765298633807, 0.08607265960064628, 0.05933934349506613, 0.036576733879384496, 0.0794825874148838, 0.07654965810117222, 0.05036623607720098, 0.07844112918622072, 0.04860364779409382, 0.09770130738615991, 0.03671337332155916, 0.025637256875333768, 0.04602213067212894, 0.0319458166467807, 0.04290326798875486, 0.10289181354305438, 0.04103928030798993, 0.027694342763073025, 0.0675684493035078, 0.044189062299987966, 0.02781940661671181, 0.04764301184144232, 0.030127641023887746, 0.010923592170940773, 0.007735431567961051, 0.094445594586432, 0.19397105691173386, 0.20231320282384274, 0.18790808386139332, 0.13768334422380696, 0.14105474396098044, 0.12035327092293771, 0.13312080033844517, 0.1030322221378165, 0.13239704643286046, 0.0985520173825564, 0.11341303526874512, 0.17173176961800746, 0.11829199644947246, 0.196554443288234, 0.2181085568642424, 0.13832832896901717, 0.25236613958353, 0.2241643440098532, 0.1745733429467486, 0.2054993778226837, 0.09960030145462483, 0.2122662937448871, 0.14373502513814357, 0.19827440260879456, 0.2286478429431877, 0.20139829465939155, 0.0675612174335026, 0.2498912159353495, 0.2588292403567222, 0.12601780164385998, 0.15191770218793424, 88.5447923598751, 116.71930282346665, 92.33417849386893, 64.91428498298892, 111.09642828664472, 82.16384918459, 51.13986622902655, 19.741842131460867, 0.21875772444951921, 2.096693169686102, 8.382983669157952, 20.649711970360052, 19.884184945014216, 10.155533148396401, 4.817288344906223, 2.1940875822497956, 1.4673926344802304, 12.469013756321324, 32.39110546727335, 47.43708602843746, 58.68077978011101, 60.958833540639574, 55.25736647267496, 61.07509651491719, 76.1533111141574, 88.12591460443313, 88.71983989592522, 80.54050568611392, 72.71862491484612, 69.01641738030219, 84.75447270178026, 78.87870727046844, 76.9566595938898, 67.35014746266027, 64.84640836715698, 64.18961924891319, 63.780472893868726, 67.4450139076479, 75.25801443284558, 76.76856625464656, 85.24432966786047, 83.59572610547467, 81.26331221672797, 75.54308445222917, 84.74272912548435, 80.42073219053208, 74.9386707428963, 64.59698092552924, 57.89771387653967, 56.01953791033838, 59.47241998487904, 58.8882770845967, 74.47878852967294, 74.35144485965853, 78.70846856024959, 72.71362781524658, 70.24662171640705, 26.778132953951438, 61.46299931310839, 78.94837640946912, 70.34508105247252, 75.70894579733573, 69.94463059210008, 64.02680558543052, 58.45960517083445, 57.2114206898597, 56.99748285355107, 55.915908890385786, 53.29304741274927, 56.671000449888176, 59.549321974477465, 70.2568277235954, 76.37991428375244, 74.7802697458575, 72.77039235638034, 70.2605696647398, 71.98256077304964, 71.30969385946952, 70.69373269234934, 71.08929587948707, 65.99966756759152, 64.36682801092824, 62.68772802045269, 58.20911868926018, 58.43594935632522, 60.77812210206063, 58.31569340921218, 52.21964374665291, 58.003457054015136, 64.22849778206118, 67.60579970575148, 70.1809141712804, 73.85440211142264, 73.1710389352614, 75.76290976616644, 86.81948292639949, 69.05612745592671, 57.56308471002887, 16.47525695062453, 5.719797284372392, 4.954745846409952, 5.490274890776604, 11.770999546973936, 11.008691806947033, 23.60915203248301, 19.11748709217195, 11.834596856947869, 6.819485243289702, 3.723818813600848, 0.4494147555482003, 0.299644106698613, 21.216178709460845, 53.23314105310748, 92.81124853318738, 56.965668509083415, 68.51273013699439, 85.0190757936047, 32.10413702072636, 0.767013542354107, 0.3837960459772618, 0.18220442136929882, 0.14291757867941934, 0.29664116460950146, 0.172415794203839, 0.21080141105959493, 0.20717737084675222, 0.1619400014920581, 0.12850460731574606, 0.2635888220562089, 0.12838870587368167, 0.13315374211918923, 0.11062209269091969, 0.09815246422564793, 0.13345561140487272, 0.2774102739509075, 0.14547114891390647, 0.1183163810281023, 0.13163846617023792, 0.17698026863076996, 0.09650064076507285, 0.2681592413254323, 0.09844449694238364, 0.1398070778457388, 0.26130931211575387], [0.06091747312776505, 0.028250057197686647, 0.048293968242022305, 0.12588516118065005, 0.02754776907574025, 0.010059771537330123, 0.047436865241897684, 0.08761055812600159, 0.05070920981046173, 0.03479914942515954, 0.029691553133870327, 0.009022514343321806, 0.05988533818914045, 0.04633227753783426, 0.05348194630876665, 0.01785748653234013, 0.07061240007920612, 0.04888795834455279, 0.15368286069602738, 0.07838128239757593, 0.037647200027300466, 0.03975766500638377, 0.10397394337961752, 0.02398186727547117, 0.08548405126578386, 0.10839090757672826, 0.06351634214121489, 0.21998553356576353, 0.051059158774273056, 0.1940559700972611, 0.2484088970889007, 0.14220781353933198, 3.8295933700376943, 88.11614005796372, 84.08318258100941, 48.357654540769516, 75.11501266110328, 85.20774964363345, 49.399620409934755, 15.19298315048218, 0.1268886674135443, 0.47894165340450506, 0.9996258443401707, 4.438582524176567, 4.088160424463211, 4.069598788215268, 3.7775469499249614, 1.3513131535822347, 0.2138017944150394, 1.6371128563919377, 8.192449144778713, 19.67642484172698, 21.744521971671812, 11.679649506845783, 15.721239139956815, 23.245675794539913, 50.5587435537769, 61.66186348084481, 68.20738930856028, 54.58402887467415, 33.350787854963734, 43.43074967784267, 63.18035417987455, 63.434782643472, 54.476803041273556, 47.64146897100633, 45.62659448192966, 47.31383339051278, 52.7811820276322, 56.09994257650068, 63.537564431467366, 68.96479898883452, 77.6464319229126, 76.46064450663906, 74.9525559333063, 73.01679565060523, 68.3554038693828, 76.92394702665268, 76.15244819271949, 65.56437861534857, 61.34231975001674, 50.85181913068218, 52.62744865109844, 55.49264984746134, 68.10230901164394, 63.92330600369362, 72.99223376858619, 66.789883951987, 74.58441011367306, 33.18927249600811, 48.72982078982938, 73.98309507677632, 67.9179262345837, 70.53440601594987, 65.4791533562445, 65.07736144527313, 53.63981631494338, 52.764429584626235, 49.752386616122344, 50.586831646580855, 54.01072348317793, 54.25964886142362, 56.950567383919996, 67.85773354191934, 65.91860002087009, 67.46716745438115, 62.690905140292266, 63.12926138600996, 58.6928528355014, 61.36892518689556, 58.83089673134589, 50.578418162561235, 48.537185345926595, 41.027133003357925, 39.76734222904329, 37.50273043109525, 35.202880059519124, 32.97106712095199, 28.455467877849458, 25.278883441801995, 27.0645659969699, 32.93549514585926, 40.78169068982525, 47.53778896024151, 55.096674811455514, 62.884364281931234, 72.19787536128875, 71.14096133939682, 65.18737608386625, 33.499739862257435, 7.926450179469201, 0.7473343370422241, 2.40246202676527, 9.796091068175532, 6.400170633869787, 5.970861334954539, 4.8318388673567005, 3.467537275245113, 3.043517537655369, 2.274943320981918, 1.3783912360668185, 1.0126848855326254, 8.536943562569158, 26.33042185537277, 76.61115369489117, 45.08653902238415, 39.066771614936094, 66.15005908473846, 40.79649763722574, 0.4209647628088152, 0.016334499908430923, 0.08936789487638781, 0.06612900073730177, 0.03109413371872037, 0.060935353619917754, 0.05079482013600008, 0.026840342419041742, 0.02855851866995856, 0.05039602157569701, 0.09964518654610842, 0.03324014134705067, 0.028120458103536118, 0.023634367877797737, 0.06334764958028832, 0.10493773561451705, 0.057320004674575986, 0.04989441018551589, 0.03918057480346292, 0.03818132418898806, 0.06747689413567705, 0.03852434771796388, 0.06925759656775383, 0.011418653509369301, 0.016650628005605073, 0.049395089398228356, 0.026704319677646124, 0.0615341164502165, 0.02165323577731127, 0.06715083945422404, 0.046105442733894435, 0.034687997728225686, 0.060373780527903195, 0.02547163058132414, 0.036308089826977065, 0.030157244576501752, 0.059774347370670694, 0.03534775264861603, 0.06736078584987311, 0.07019359513276047, 0.055750141130580064, 0.03629466413610405, 0.007115287702500581, 0.16177598206746965, 0.015359858910913671, 0.09994904766039503, 0.047110890999676726, 0.06144069585829012, 0.05614002625788412, 0.09110144459672513, 0.09776248716779294, 0.08193812137770076, 0.14868000011530616, 0.08084899715838895, 0.22303008955092202, 0.04237103223380062, 0.2996766501136365, 0.2514181823860253, 0.4504984328823705, 4.0778509647615495, 95.53526401519777, 96.30243255246071, 43.56359251083867, 90.47934455256309, 85.35580342815769, 58.69869324468798, 17.163866296891246, 0.14463922339341334, 0.6524296489454086, 1.0779821752540528, 5.123401389968011, 3.9097651454710194, 11.048179288064281, 4.990921376212951, 2.5367897220196265, 0.48401260387993633, 2.0807011761972984, 11.328237498960188, 24.102146894701068, 25.970724821090702, 18.509970788032778, 20.576259705328173, 27.605851119564427, 59.821279510375, 69.97012599822014, 74.51113239411386, 63.355790030571725, 44.218565571692686, 56.23498585916335, 71.17747076096074, 71.48398830044654, 62.04887197863672, 54.873319364363155, 55.507448950121486, 58.81885897728705, 58.415572643280036, 63.5691983469071, 69.22482075229769, 73.87457093884869, 80.6117045494818, 78.09716716889413, 76.50016630849531, 74.48430338213521, 72.5985925428329, 80.80903899285101, 77.49425964970743, 68.81340334492346, 64.96123575395154, 55.697946702280355, 55.28876504590435, 57.686796265263716, 72.43734390504899, 69.77695711197393, 75.56352784556728, 68.99819404848161, 77.78187920970302, 33.165836334228516, 53.08518532783755, 76.84876303518973, 72.1965652896512, 74.47718820264264, 71.08992345871465, 69.14468672967726, 56.89578363972326, 55.891452912361395, 53.26275102553829, 54.843352456246656, 55.94200441914221, 54.987350510012725, 60.62786786786972, 71.58554630894815, 71.7640612202306, 69.76864953194895, 68.30482098364061, 69.54162274637531, 67.52535973825763, 69.8732199207429, 65.81698709918608, 61.94252867852489, 59.456506929089954, 54.62290348545198, 53.25015629491499, 49.867931796658425, 50.024281394097116, 47.16649739973007, 42.825296540414136, 38.09046230008526, 40.09070242604902, 47.09811087577574, 53.03660285088324, 58.23917581189064, 64.01496002751013, 71.63002598670222, 77.40509633095034, 77.5662116081484, 69.04228933395879, 37.939839363098145, 10.385941997651132, 0.3089608083809576, 5.5053456175711855, 8.942105770111084, 6.569288036515636, 6.7271840283947615, 2.336773358045086, 5.06578520421059, 1.7547389768785047, 2.286419685809843, 1.475231491269604, 1.5358968295397297, 18.29498567888814, 35.49297071272327, 73.28040246040591, 58.07067078928794, 33.31589052754064, 75.15098864032377, 45.64349597500217, 0.5354179309741144, 0.18012853759911754, 0.04291556753037919, 0.048839411352791136, 0.10578062385320665, 0.043529671271361654, 0.07358327372780732, 0.006850068541919633, 0.01379021465958607, 0.023697761653531945, 0.12190930274946075, 0.023869612411926353, 0.015267373903864815, 0.00842374097931409, 0.026152627204634973, 0.0663869961675617, 0.029680887274744532, 0.029826809787341667, 0.016464878497044408, 0.015191939141180728, 0.06087112097790646, 0.008246766050316153, 0.06945386063307524, 0.01605901947890919, 0.031658813297267885, 0.031491865501588875, 0.03279366913521963, 0.23581435032669576, 0.14449092409303113, 0.19072189416375854, 0.22081096266065875, 0.2265475822552558, 0.25236719678486547, 0.14815807973425235, 0.19483138897245933, 0.16672127880156043, 0.1622377951899844, 0.12319248470087206, 0.1689716620791343, 0.18574935534308035, 0.11370904398180785, 0.1645662121835255, 0.09128851560695518, 0.24101204238832, 0.15134563369135703, 0.31994148367835634, 0.3183573364250122, 0.12499713504146184, 0.15185774814698005, 0.2186663914471865, 0.11539145733319944, 0.14522616931748006, 0.44222526552696384, 0.2680082607173151, 0.2611672487710753, 0.17132876140456046, 0.35863627829859335, 0.45838080346584326, 0.6763518781911942, 10.245778060728504, 119.7021084447061, 106.74071465769123, 69.17361028732793, 90.11137916195779, 107.40503864903604, 72.31284787577968, 26.487659869655488, 0.31284591603663664, 1.1947229432482873, 3.659643199174635, 13.381476690692287, 11.92675490533152, 17.877259139091738, 5.89058953908182, 2.961525292165818, 1.025511710153472, 2.2154529777265366, 10.87943402028853, 24.619735017899547, 26.078289939511208, 17.734933976204164, 20.49983036133551, 27.671191923079956, 55.003271410542155, 71.53640685542938, 75.47824767328079, 64.6583934753172, 48.7830630425484, 62.63787469556255, 77.0942484947943, 77.20842869051042, 65.80121917109336, 64.80328582948255, 64.79888100777903, 66.67368765800231, 65.1607471127664, 67.57743312466529, 70.91689986567344, 75.67318947084489, 83.53184638484832, 78.29579599442022, 78.96774507338002, 75.60344972918111, 75.1990847433767, 82.7890593005765, 81.27206694695258, 71.42636083787488, 68.79278736729776, 60.37798150893181, 59.55590371162661, 61.285853309016076, 72.62269942991196, 71.0292600816296, 77.58685896473547, 71.70882640346404, 77.67802269228044, 39.70480788138605, 55.35399406186996, 76.1556645362608, 74.67375386145808, 76.68654164960309, 71.6795341430172, 70.1851660205472, 60.85696566489435, 58.69992879129226, 55.01512089083272, 56.59146262753395, 59.17798334552396, 60.35063474409042, 63.88884798172982, 73.92444779795986, 73.41676758181664, 71.99487701539071, 72.37768465472807, 74.27743757924726, 69.50106543879356, 72.7528593617101, 68.92242954623315, 66.41774515951833, 66.33426143277076, 62.019211015393665, 62.9805015748547, 62.3658347898914, 61.47389173507691, 60.20706422867314, 55.753750262721894, 52.27139942107662, 55.57125414571455, 62.41704133249099, 65.38636184507801, 69.81574150823778, 70.78380600098642, 77.37653363135554, 81.29551487584268, 82.48374985110375, 70.96011654023202, 41.554095591268236, 13.397668234763609, 1.5212340292430695, 5.5682878917263405, 20.796438032580962, 21.386725325738233, 18.720858981532437, 10.613122736254047, 12.877868875380486, 10.073557572980082, 5.629280747905855, 3.836684034716699, 1.9377912124318464, 15.152384658013622, 41.1555435580592, 93.20965151632987, 59.561391107497684, 54.20468076582878, 79.8739145648095, 66.7016149336292, 0.7297165211169951, 0.2890947695461012, 0.20957472043172007, 0.12034035468053435, 0.19668317670303007, 0.13773660265630291, 0.2583223352989843, 0.15293623140502363, 0.08917506288496718, 0.13657648506904804, 0.27610709710467246, 0.08900334427673971, 0.20023986246557007, 0.08382438306486414, 0.13846866095498686, 0.19358690978298265, 0.1534909556709951, 0.0951731023228457, 0.11833695814974847, 0.07486205067365401, 0.19748868751189402, 0.08424539434453172, 0.22132128447053895, 0.07199126641236006, 0.12709997744569856, 0.17287483408806786, 0.17011586035932266], [0.01510144021707557, 0.050870184035551165, 0.056838035778773416, 0.038926279577877254, 0.019297339209926226, 0.041700854687200445, 0.03535047226074723, 0.0584637854368456, 0.03726863384907765, 0.06514934282149039, 0.005237422817792263, 0.044194191258641026, 0.12270242591658909, 0.011758264116642457, 0.06532877593511535, 0.12845605266310517, 0.03232666576701788, 0.0805493878320821, 0.02709621004009199, 0.07129028830076418, 0.02479528411171369, 0.03637721777082451, 0.07131539300204286, 0.036263989975615855, 0.07414740555348896, 0.10277234213126284, 0.10899718189912458, 0.09645463718521981, 0.12166123581869949, 0.0817485069555621, 0.05591322209746127, 0.18383543788185044, 0.1570756496080468, 19.215234518051147, 83.51520769057736, 71.3976961566556, 46.81932841577838, 79.73583929000363, 53.58509140629923, 17.99236697535361, 0.09944186681100439, 0.10062243894583757, 1.5173869195484346, 0.6552407626182802, 4.974238064981276, 5.063012578795034, 4.114938935925884, 1.7229607917608756, 0.5603026730879661, 0.15995851507590664, 0.16430914371965394, 0.9398331108593172, 0.5293784615012908, 1.070820662763811, 0.11614749418391336, 1.3777756690979006, 10.923091961491494, 31.863478037618826, 39.17567230040027, 25.479275372720537, 27.024724521944602, 40.29925877048124, 48.56395159998248, 45.795499586289935, 36.9538967071041, 34.135614902742454, 41.224439990135934, 47.78953452264109, 52.95646098352248, 58.78842922949023, 68.64619270447763, 75.75355883567565, 80.48310572101225, 79.91760192378875, 77.58864756553405, 75.59902529562675, 74.39800339360391, 71.20810447200653, 74.80741254744991, 69.56827132932602, 64.53082623020296, 57.63423650495468, 49.89917347508092, 53.70619066299931, 64.67287094362321, 69.6375560760498, 73.6031743018858, 69.63134304169687, 71.1102334914669, 45.774538440089074, 43.27418042767433, 72.39328784327354, 65.81384135830787, 75.06629682356312, 71.3651797079271, 72.1401616065733, 57.92966158159318, 51.767445456597116, 52.32713237885506, 55.77421719028104, 55.89394361742082, 55.69551091040335, 63.976614936705566, 73.9413453686622, 67.70535730546521, 67.7602469536566, 60.06852611418694, 62.6585259745198, 56.58834434324696, 57.80418495978079, 54.8751118875319, 49.37061840488065, 41.44223351632395, 38.013485785453554, 33.10583191533243, 32.27856089991908, 33.678039043180405, 38.919918075684585, 36.52738994167697, 34.722158293570246, 30.311649153309485, 31.654129374411802, 28.841633066054317, 35.28031156909081, 38.56086431011077, 52.39640928083851, 59.235904985858554, 71.73128589507073, 48.2910801518348, 21.376980197045114, 4.121144615834759, 0.24541225224252672, 2.1305209157928346, 10.58799603293019, 2.578680390311826, 6.336624314708095, 2.3034439980983734, 1.4957067538653652, 0.32122599862275586, 0.13279982481993016, 1.1652589565323246, 8.24370030433901, 29.08346679902846, 71.85063577467396, 53.46200350792178, 46.221523900185865, 58.76395363961497, 66.99900119535386, 16.499485431178925, 0.7933050057580395, 0.28509073440105687, 0.1401655610290266, 0.08291709747525954, 0.14266449387275404, 0.2113098636149399, 0.03480150131508708, 0.10714965361741283, 0.010055917157461087, 0.054314860082682104, 0.10808719968002652, 0.04232601307693028, 0.06978114105520711, 0.11747710106353607, 0.16056678888778533, 0.05819737453073744, 0.11558739198071342, 0.04658489503086575, 0.04133605893941657, 0.05375041799139112, 0.04804407802200125, 0.04242914766373654, 0.04845786892298249, 0.01756350220661731, 0.013038227541161882, 0.029752951250561786, 0.03713879343723098, 0.0871871106867348, 0.03758017882524479, 0.03534914692863822, 0.03460482356228656, 0.04937319843579204, 0.020562142712034045, 0.013711533599322843, 0.07031069167198674, 0.09919331724485082, 0.039202538544252034, 0.14060333431247743, 0.051226437902979316, 0.04299471590427622, 0.06836764754787569, 0.042823384170450514, 0.13421961556999915, 0.03150073105409261, 0.09944505373676939, 0.04025491352583613, 0.08556568559499518, 0.06513284128760138, 0.039223487218541485, 0.05016811041822357, 0.028973196317712148, 0.06199535117634843, 0.005878176363635689, 0.07758794472582879, 0.06473033869218442, 0.1442281712567614, 0.0940280536850614, 0.025472908032937877, 0.03652801451783988, 0.2607420393295827, 20.38951370023912, 98.10374183039512, 67.70070537444084, 52.26683378219605, 100.24133159268288, 58.42040108096216, 33.76184048191194, 0.12238721137926464, 0.2900692946728199, 1.1989262531841955, 1.029045581817627, 3.187515836569571, 3.3735967547662797, 6.6270895542637, 3.8007904252698346, 1.3142294725102763, 1.0058630257844925, 0.32229864429081645, 1.647676412136324, 1.9842456809936033, 2.3348050636629907, 0.8115276634212464, 3.4106280967112514, 15.75206014417833, 38.46305216512373, 45.9637967232735, 33.151590285762666, 36.69904462752804, 45.25061961143248, 58.265663577664284, 59.88737144777852, 50.823374102192545, 49.92772048519504, 52.4504909207744, 60.01507205347861, 60.92175929777084, 66.5483836204775, 74.20285763279085, 81.19639658158826, 84.7650944802069, 83.42960588393673, 80.23331349895847, 79.69473285059776, 77.37297996397942, 73.96736637238534, 80.83849599284511, 72.05838803322085, 67.5236338953818, 61.01752788789811, 54.58198924218455, 58.753598582360056, 71.114014656313, 74.30085412917599, 77.37079912616362, 73.62212719455843, 74.72339537835892, 49.44776750379994, 47.09492198882565, 73.76658808800482, 68.6390853697254, 77.73104529226981, 69.86146849970665, 73.4451106286818, 59.87501598173573, 55.42889172031034, 54.10353460619527, 58.14967516929873, 57.07847587523922, 59.00264555408109, 67.68940894834458, 75.73120917043379, 73.2210805339198, 75.36575409673875, 68.98404213689989, 69.67306921558996, 62.14566430737896, 66.43246189240487, 62.192556242788996, 60.491255637138124, 54.631163997034875, 50.39089748936315, 45.314158085853826, 47.73761803104032, 49.161524695734826, 53.1981142874687, 52.299597340245406, 47.64658766408121, 44.215392374223285, 44.829925798600726, 43.44715695227347, 47.94551541728359, 51.325857177857436, 63.184194180273245, 70.82240996822235, 78.43045880717617, 54.15537657276277, 21.490407297688147, 5.95167359036784, 0.6761796003387821, 3.2424417666850553, 7.625621547622066, 3.5961064407902383, 1.8279822531246372, 3.91240073307868, 1.2790138202328838, 1.7077590332877253, 1.108427489957502, 2.4376402939519575, 16.82323786520189, 42.004065975066155, 62.47244481117495, 69.93092583071801, 45.14187582077519, 58.52298282807874, 74.86395743585403, 16.590419700068814, 0.7379121910179816, 0.29702077649774095, 0.10272310566036932, 0.17217643769277682, 0.14386711401804803, 0.09390527277343697, 0.058572623548248125, 0.10967513140771659, 0.027318881156163353, 0.06235478430866234, 0.0745007559476841, 0.025293549612885522, 0.004890720151560081, 0.08729106115718042, 0.04731137620946092, 0.012889187050712927, 0.0985965117691986, 0.0036709563949355677, 0.0500940756812211, 0.07846671652289168, 0.046552838081674236, 0.0215669589552788, 0.025729319576414365, 0.05950221378776816, 0.035673225103246595, 0.09353796425726145, 0.03829156807173164, 0.24364660343816205, 0.14780491320115907, 0.12058272191713895, 0.129469579326049, 0.14143440181449538, 0.19192353371650944, 0.11184217964088726, 0.18460480466244683, 0.20742555269070212, 0.17856138217593395, 0.22600038097270075, 0.11678311733468888, 0.17524471176007103, 0.12125317142495226, 0.08903662313617046, 0.16086753968509937, 0.12139944059233512, 0.1585554710078624, 0.12593518672210555, 0.1329553100250421, 0.15752627784686704, 0.17658870577091174, 0.20107057756714283, 0.17077895542306287, 0.20892720759635974, 0.1752011979659719, 0.25596705926281793, 0.14648068425876482, 0.26882301054654584, 0.23233381370382927, 0.2066052104196241, 0.3063687345673961, 0.4220163257371995, 39.452517109532515, 109.2437751831547, 92.82193306953677, 67.32257320034888, 94.95458849014776, 74.75239738341301, 32.563799581220074, 0.240765561259562, 0.4376187481947484, 4.903031847169323, 4.400707137200141, 12.660145951855569, 14.092322934058405, 13.582664862755808, 3.606816472545747, 1.0465296694347936, 0.8828119609144427, 0.6791428284298989, 1.7320376466358862, 1.795887704337797, 4.591615757634563, 0.4208081131500583, 2.942075974518253, 15.268333842677457, 36.41316659988896, 44.689803046564904, 38.14062156984883, 40.57652327322191, 49.47905232829433, 64.26463065608856, 72.11643911177113, 65.63592264729162, 64.50391877082087, 65.37581851405483, 70.5294559847924, 71.07143340572235, 73.8991641998291, 79.06529441956552, 86.08889441336356, 86.9553695186492, 86.1135425875264, 78.94940407045426, 81.53297516607469, 77.66271760386806, 75.9381377312445, 79.86468130542387, 74.80389810377552, 68.66778142990606, 64.62120548371347, 56.61651480582453, 61.538477482334265, 71.07243753248646, 77.71106473861202, 77.92672449542631, 76.10683102761546, 72.90041892759263, 53.37899046559488, 49.31397937959241, 70.86322615223547, 68.77251655824723, 82.39996802422309, 74.95501918177452, 75.32751883229902, 62.61528184337001, 59.674582865930375, 57.691059881641024, 61.46891816969841, 59.930360624867106, 61.95292295948152, 70.84761511894965, 81.77525212687831, 77.65641827737132, 79.48437613825645, 71.91554315628545, 74.57557693604501, 68.16893439139089, 72.06398133308657, 67.16574899611935, 68.89719301654448, 64.93383799829792, 64.16611640684067, 58.88601387700727, 61.65074748377646, 61.116222566173924, 66.71823009367913, 64.44882908175069, 59.36235043310351, 59.236509030865086, 60.242906847307765, 57.06241769175376, 65.03927915327012, 63.28341445615215, 73.36342334747314, 73.48032566808885, 83.52563335049538, 57.14549349200342, 22.642311319228142, 8.00558841036212, 0.7173509427135991, 5.504242450960222, 27.881019115448, 13.64501976197766, 13.946076381591059, 9.220855870554525, 6.60982475165398, 3.3904173489539855, 1.5864255375439122, 2.7061338866910627, 14.787853302494174, 46.86241957449144, 91.52157322052987, 68.5879768863801, 62.53944673845845, 73.7474076978622, 84.32132536365141, 31.675045413355676, 1.3585792217523822, 0.3046062420452795, 0.15058391246824496, 0.33006622425971494, 0.42554636696173304, 0.2925534726631257, 0.08950285658600832, 0.20937129344430663, 0.11257043048258751, 0.16273978196324843, 0.2687649104383684, 0.09574684855197707, 0.16199096166078122, 0.20641252398490909, 0.30979094125570794, 0.16177094120892788, 0.26416519596692056, 0.16041240684928434, 0.13535227656604784, 0.2427850916020332, 0.1858575576015057, 0.1838844675090044, 0.15497863713291385, 0.11736024201156632, 0.20120758473152117, 0.19849810028268447, 0.16058102280141848], [0.07710698706608626, 0.022967980551202933, 0.10050797774907082, 0.05452621991055147, 0.046686865164027105, 0.027221158980542136, 0.03338798865555756, 0.0554628428372164, 0.05953127150273612, 0.03338422333340972, 0.014060317151879352, 0.028832596200968952, 0.0806174164397582, 0.044022671833273866, 0.049040532415552486, 0.052645596630510785, 0.004435359883392531, 0.03356906119734049, 0.05644975560567072, 0.026565899081047506, 0.042394129784717675, 0.03774448553280484, 0.012833823791644987, 0.10328320020269002, 0.10506552674116627, 0.07955195667642741, 0.08954109203430916, 0.03328077082011489, 0.08801378084406739, 0.02102531372539459, 0.0442996739049352, 0.043489064780935165, 0.17821152514267355, 0.3999760987297182, 51.092170207731186, 97.05555900450676, 61.52070130071333, 47.671322130387836, 106.36128025670206, 37.28612146069927, 8.890270667691386, 0.5535058797367158, 0.6341038452040765, 1.0251484619032953, 1.8845416052687554, 4.080631189769314, 4.351455896131454, 3.7595905844242345, 1.7094273889257063, 1.8774597659226389, 0.348943519375978, 0.792388703313566, 2.4677805218004414, 3.838471654922732, 0.38978627131831267, 0.4259378991780743, 0.1719466113154927, 6.205853964051893, 17.71874635450302, 19.004618929278468, 16.830911982444025, 15.4445610315569, 46.26614086089596, 42.642188533659905, 41.667040240380075, 41.27003754338911, 41.09458992558141, 50.401884048215805, 62.23034043465892, 62.19229736635762, 66.29712443197927, 71.1333127175608, 76.34640939774053, 75.83892530010593, 73.46032158021005, 72.97173546206567, 74.20222220882293, 73.52009850163614, 71.92738871420585, 73.71157292396792, 67.76769161224365, 61.227645335658906, 56.42987274354505, 52.985678718936065, 60.40335139920635, 64.66852495747229, 67.91348611154865, 66.85169266116235, 74.95855715966995, 43.68607244183941, 40.260470451847205, 71.70675539201306, 66.64063776693037, 72.03406933815249, 67.84367576722177, 73.4743558206866, 60.974075871129195, 54.46121946457894, 54.66801858717396, 57.42289527770012, 59.4237002249687, 58.110302417509025, 64.77793555105886, 70.22135380775698, 70.29108570468041, 68.89334124903526, 65.73825336271717, 63.10282068867838, 55.43744640965616, 49.619583006828066, 48.21618249339443, 40.94019366848854, 36.34766694038145, 31.846878567049583, 30.7113229843878, 33.21630939360588, 38.421267155678045, 56.87126098140594, 70.31928754621937, 64.27116924716582, 64.21196499178487, 62.51919946362896, 58.179355744392645, 50.31427791041713, 40.779862865324944, 42.43194949242377, 55.32163450794836, 65.97377207971388, 40.98889773891818, 8.996029534647542, 3.305795644560168, 0.24887971940540501, 5.426146099644323, 2.272215802823344, 4.451402791084782, 0.5069406961481417, 1.0146277457956345, 1.3151138444100658, 0.8224971231914336, 1.8937829545428677, 9.309307279125337, 30.89604896883811, 59.403558854133856, 67.15764537934335, 33.24887291077645, 53.98906023271623, 67.93734196693667, 58.03960953989337, 0.2265143800046175, 0.06173813715577126, 0.009027395281009376, 0.07170307179612499, 0.0476084306325403, 0.0502413522542244, 0.0329792769175143, 0.05103358675936057, 0.0197747977630746, 0.026572767059288682, 0.06949856186345701, 0.11582303296534285, 0.025025054947623325, 0.029047673470490885, 0.029761583146248615, 0.02207453242473064, 0.026103063231153835, 0.09987438473129466, 0.05214346430054115, 0.07145835266959283, 0.09019955226610746, 0.09320391161787896, 0.06331991336698975, 0.04689861186629823, 0.04197510267277399, 0.06554075246376377, 0.03026561345905066, 0.027236697158866355, 0.055313516979015646, 0.028252420578933055, 0.05556379024299884, 0.05681219946352705, 0.03251877763578969, 0.03459655747358357, 0.025047323208362348, 0.04379018713089247, 0.026663086910341537, 0.09882626919856957, 0.08138110650883568, 0.03523065610938976, 0.022533233315053008, 0.021667864226225405, 0.02052267960783455, 0.04420080642786719, 0.012927629342753322, 0.06862714451046721, 0.03896009086841538, 0.05584569144693594, 0.02047871190664028, 0.09172357693915406, 0.20956515965442504, 0.0660251115538901, 0.039437241071174224, 0.13747456994268203, 0.15477822853192208, 0.07845297290553009, 0.0915327980633705, 0.07681961982480942, 0.15900657422119574, 0.03923064247975427, 0.19435434602200988, 0.6288152644711157, 58.05700525160759, 111.88823715333017, 48.75669687025009, 65.56059745050246, 110.62692842175885, 43.76534746539208, 16.443822095471045, 1.6451090982844754, 1.014371565993755, 0.7582248591126934, 0.30962120681520433, 4.171435775295381, 6.018603444099427, 4.237715496170906, 3.69836361177506, 2.9755382047545527, 1.8990824443678704, 0.8054490928207675, 1.6624264851693185, 8.529644031678478, 2.011344846217863, 0.8599302016438977, 0.44797377480614575, 9.351108958644252, 22.64915389399375, 22.965249861440352, 21.320562785671605, 20.91341095585977, 48.109537170779326, 48.38009049815517, 45.3787987462936, 43.92688635856875, 53.40205007983793, 61.49872426063784, 68.48191599692068, 67.67766537204866, 72.77628375637916, 77.11826908972957, 81.74718364592522, 79.92779224149643, 77.02763095978769, 78.37273720772036, 79.10457303447109, 77.56494076021256, 77.39077183508104, 77.58806705474854, 73.92971946347144, 65.39586182563536, 61.14784079213297, 56.76639641484907, 67.28595395242014, 68.68449857158046, 74.23768827992102, 71.95282136240314, 80.67845544507428, 47.302050590515144, 45.719821376185266, 73.86208211222004, 69.23546606494536, 75.02123663502356, 71.5631809542256, 75.90526042446014, 62.656392205146055, 58.11407573761479, 58.13035749620008, 60.53720620370681, 62.623942436710486, 62.48629862262357, 69.4166011195029, 73.98205957105084, 74.08299000032487, 72.63106976785969, 70.17110824584961, 67.94934441966396, 64.28119482532625, 58.0409941365642, 57.12229267243416, 51.76589219800888, 51.87198446642969, 46.39359043490502, 47.276716001572154, 49.55202410298009, 56.90373820643271, 69.00241451878702, 76.94008365754159, 71.41235013161936, 71.28000936200543, 68.09579787715789, 62.19734937913957, 56.31424911560551, 52.20360909738849, 55.54624903586603, 68.94474783251363, 71.4707620682255, 44.933903909498646, 9.94726215639422, 3.5082355430049286, 0.42168620312886856, 4.926986252107929, 1.7887532807165578, 2.6748958854906024, 2.3201452051439593, 0.4498954910424448, 0.883920091775156, 1.067760723733133, 2.2082588605342375, 14.446214860485448, 46.74002201326432, 50.81266210925195, 88.71601166263704, 36.97939211322416, 54.10445244081559, 74.78811448620212, 64.31453497179093, 0.256152774297422, 0.03394766567995952, 0.031990967953817985, 0.13366689845438928, 0.04073389084829439, 0.04956232256165916, 0.06250607135194926, 0.05454331516258178, 0.030057337135076526, 0.04405699640272125, 0.10336168591053256, 0.043390882952559384, 0.009608741102349615, 0.07697943342669357, 0.11644523425568497, 0.015461054337661595, 0.04945715401141394, 0.05858383524501997, 0.049943730926081065, 0.07976898172449681, 0.02456074054803579, 0.03844424556460112, 0.05697853247364683, 0.029025280720464168, 0.09558411615510141, 0.10770205663697374, 0.04759125111083831, 0.024063013223630768, 0.19634969862959079, 0.09855140451221697, 0.12112030879624429, 0.1694611003321986, 0.14731556687864567, 0.12882228099530743, 0.12906637192974169, 0.12245286511437548, 0.08970105119289891, 0.1720447625003515, 0.14463438171773188, 0.09951624628757277, 0.15403337656490265, 0.11694745851620553, 0.175643996786206, 0.1099144725970203, 0.06082120268876034, 0.12789447191021136, 0.17154767868980286, 0.12181509691741198, 0.12569962234626855, 0.1828437217421109, 0.28247754720430224, 0.21520699885103012, 0.15206684418503316, 0.13121351719863955, 0.22833173974387108, 0.1736126533679424, 0.16981890935811306, 0.1426987226812109, 0.20301607317261158, 0.09322257351971443, 0.29945387174525573, 1.0656655651907767, 85.58552880440989, 115.29465875317975, 83.2220026754564, 67.02060561026296, 123.31546645010673, 57.501009279681796, 16.07658724631033, 1.316062077399223, 1.6811345974283836, 3.562850625284257, 4.512426535929404, 14.692179829843584, 18.590718661585164, 15.97669428394687, 4.552760268411329, 2.69899909534762, 1.5179568889640993, 1.2457225808212835, 8.568265649580187, 8.930014083462378, 0.9602203039873032, 1.1664155654368864, 0.4125117792958214, 9.37097772475212, 23.837051545420003, 24.025217448511434, 21.659916447054957, 23.524668101341497, 56.08666535346739, 64.66141370034987, 61.74236620626142, 62.73070543043075, 69.78447237322408, 76.38657446830504, 81.2462342169977, 75.95772604788505, 77.46689719538536, 82.41541431796166, 83.72569776350453, 80.9360061153289, 77.97429500087615, 79.9696517759754, 80.05883078421317, 78.87341991547616, 79.41501294412922, 78.94576411093436, 76.7568854362734, 67.3868686922135, 64.37376276139291, 59.729299929834184, 68.80788064772084, 72.8667728362545, 75.33290816891578, 74.58863058397847, 80.82727801415228, 51.64217279803369, 52.87900593972976, 76.18613350775935, 69.41657758528187, 77.7168070885443, 73.24084927958828, 79.60512238164102, 66.0175221966159, 60.23431293426022, 60.4102155470079, 63.8294711420613, 67.04888589920537, 65.20637996735113, 72.57342661580732, 78.58694568757089, 78.38864634113928, 78.77093622761389, 74.90867245581843, 74.2164368783274, 68.49053736655944, 64.91567350202992, 65.67658585886802, 60.16225114945443, 63.00833863596763, 60.17374369405932, 63.522659424812566, 64.4788509030496, 70.10838170205393, 78.87223535968413, 86.38097763061525, 82.3781047328826, 80.17919263532086, 77.96018231299617, 71.22622582220262, 69.10745559200164, 65.26252477399765, 71.45887728660338, 78.77796511496268, 78.25879235421458, 48.563178893058534, 11.895555392388376, 4.410450304708173, 1.2922325754357924, 12.068545645283116, 9.08952413066741, 11.763797094745021, 9.082785498711372, 5.089242939026126, 1.9672162205942216, 1.3615132772153424, 2.698841710244456, 13.046390568056415, 49.34381292712305, 75.08376706031062, 87.37554950098838, 46.80677290885679, 74.60011528384301, 76.62949469781692, 88.73229734359249, 0.8561456660109182, 0.10053919583198526, 0.18853659771623152, 0.1514823037770487, 0.12657211988323158, 0.11893591633246792, 0.11907368958477052, 0.25382634913248403, 0.10908828507508002, 0.19278621000628318, 0.1520876970983321, 0.1543315533067911, 0.14013833426419767, 0.13841227688375982, 0.16273973599797295, 0.16068816785850834, 0.13411985560049935, 0.15442041950600763, 0.10287934929252633, 0.24358762998975095, 0.20032995440546544, 0.14874231370706714, 0.1960452706102402, 0.16646954230964187, 0.17561768932688623, 0.26108797399267075, 0.16976975715689122, 0.1205745860633831], [0.03668757531070902, 0.009455017899463495, 0.019779700725789995, 0.12104704780804536, 0.015329397339824469, 0.01802766147340017, 0.06991675393956323, 0.061562002050660314, 0.015128162321484378, 0.06669862541340052, 0.08436229936177693, 0.01679863810779587, 0.035621043024284225, 0.03636182706442572, 0.048920011463304686, 0.02788430383999742, 0.07311457347485327, 0.10663745489211814, 0.07043978514810724, 0.012660028127532814, 0.07624676991854945, 0.04042912958069675, 0.0502102644062571, 0.02134527800784957, 0.11420283361428207, 0.09638287006847321, 0.08570256252442637, 0.05472096712178281, 0.042350026102916855, 0.09895062825131802, 0.08011205887962734, 0.25069809038071866, 0.6162815757336155, 0.7610718869874555, 17.549327419650172, 94.32327516617315, 81.79869221102807, 42.60268242128434, 50.126023753996826, 96.85296858510664, 38.83248844454366, 12.821727010511584, 0.4744213056420127, 0.5180776840256107, 0.3093562323239542, 3.2661220960078703, 2.089190165842733, 3.900945450990431, 4.272044570215287, 2.720656462254063, 0.6469872990442861, 0.4518180652972191, 1.4998754979141298, 1.3644067606618329, 2.0997303099401536, 0.6028820850676107, 0.4427417007184798, 0.19074285432936686, 5.959976267430091, 10.544715619856312, 6.559437494124136, 9.19594587818269, 33.06265446447557, 43.41849619342435, 48.45915763608871, 56.49657657069545, 65.57591822839552, 65.36189017757293, 71.2065355239376, 66.52639481329149, 78.71406186011531, 76.080119686742, 80.27012102065548, 71.91150311500796, 71.05353955299624, 70.8487133825979, 74.78442745824015, 72.56364422459757, 71.70199363462388, 67.20567087973318, 67.3455818237797, 63.54662510656542, 57.95194456654211, 54.15920872842112, 59.21086065230831, 64.58461369237592, 72.6743648898217, 66.93863591840191, 73.58156204223633, 44.60968863579535, 27.72336336874193, 65.72352486272013, 69.82136618706488, 75.57580486420663, 66.75368832003686, 72.10766084732549, 59.23152369837607, 54.83906138327814, 58.90659455330142, 62.68863408796249, 60.717046876107496, 65.12836794699392, 66.04202916545253, 75.13818602408134, 71.69951469667497, 67.24134091408023, 60.8128821465277, 54.94020362054148, 52.45068311691285, 45.962765139918176, 42.11314316718809, 34.54664399546962, 32.09018515002343, 27.466373597421956, 29.2338583161754, 31.741613918735137, 56.717394244286325, 77.98281438889043, 72.6931530429471, 64.78865146636963, 64.06224027756723, 70.27087765355265, 70.05440204374253, 70.31194486925679, 62.036896982500636, 42.47114181518555, 47.12093907017862, 45.77880597883656, 9.536510571356743, 0.8357198620515486, 1.7543449012502548, 2.8717809723269556, 5.751944049712151, 3.614635717484259, 1.4439163909804438, 0.25745573663903826, 0.9876001638270194, 1.2539816215153665, 1.4711324918654658, 10.331231797895125, 30.791876700616655, 62.51580269105973, 66.9092809000323, 27.56861213714846, 50.8537293249561, 60.2218476418526, 73.18817969291442, 7.76752652660493, 0.40973005275572505, 0.11781261693085394, 0.04649545809614562, 0.09033639855202168, 0.061187499968875805, 0.05190009731919535, 0.01751814022540085, 0.019060953204790433, 0.06604938888021054, 0.002910595696096519, 0.08060919631633066, 0.06384261132728669, 0.033888033395933534, 0.05440711239052396, 0.050773538213463566, 0.0899791717529297, 0.11678528536351458, 0.0339035275242021, 0.0032234885082054405, 0.012480812391356356, 0.042295162716219505, 0.09487460382402906, 0.01863886940202886, 0.02896011153596544, 0.013799108940386965, 0.03788540357603662, 0.029136394113001805, 0.055821000433136383, 0.04538928075963932, 0.0074056393350474545, 0.06331414855535954, 0.01607763254263949, 0.06464141886681318, 0.024729984692267837, 0.023104775126182267, 0.014387622471868753, 0.04864291363065282, 0.046064587264892556, 0.04809494626017348, 0.05693873420598046, 0.09636767854493472, 0.0680785029826145, 0.03322675013013425, 0.04375617665749404, 0.03742071762380581, 0.06695728734015458, 0.09079339298149271, 0.008053517498586687, 0.03454772702928993, 0.024340595606894746, 0.039461300062436255, 0.057948928386453664, 0.05571512708200082, 0.11727694527155931, 0.07355241570621729, 0.11640568879703361, 0.0779640019660996, 0.1336733642364702, 0.0696921369601642, 0.3547881880114156, 0.5376165420297654, 0.9319213224995522, 21.90771414387611, 106.26571562982376, 87.1423645942442, 34.51830094860446, 75.8566544132848, 100.86125435367708, 48.46872037456882, 20.60154330345892, 1.5492748084568209, 0.8419510986535781, 0.4670063712664189, 1.4986741494747902, 0.6848892845934438, 5.742315611531658, 3.4137503033684147, 7.610264487804906, 2.2353327755005132, 3.1381099070272143, 5.499857731403844, 5.245200789743855, 6.629296868078171, 3.2452112051748463, 1.614013650724965, 0.4430622931930327, 7.451840937137605, 13.095398622174418, 8.955793861419924, 10.957679421670976, 38.255484257974935, 53.685825717064645, 62.02221947331583, 59.44151955266153, 67.51113722401281, 69.0150131717805, 79.47926136755174, 72.97754841466104, 83.67924905592396, 82.31411518589144, 85.6298594320974, 77.014891101468, 78.50099086761475, 77.45536542707875, 81.1646959858556, 78.6957130124492, 77.75585820597988, 69.79149341583252, 71.07734049520185, 66.78825224599531, 65.05596099361297, 57.50927763600504, 63.303567594097515, 69.40694424413866, 77.1777714452436, 71.76233537735479, 79.13799162833922, 49.05659344888503, 33.65629734531526, 70.04350569940382, 72.91874424103769, 76.98981931132656, 70.19617219125071, 77.42237829392957, 61.60307499670214, 57.63506804743121, 62.00986792964321, 64.64888172764933, 62.79285146344093, 65.33859914348972, 70.10504768740746, 77.22605582206481, 78.23048853105115, 72.01743064388153, 66.720457999937, 63.904537462419086, 61.967188619798236, 56.611407879860174, 53.4409599919473, 48.666545114209576, 44.73764419555665, 43.124600841153054, 43.32907399823589, 49.81780390585623, 68.98812924661945, 79.41023549725934, 71.9788972793087, 64.32581178603634, 65.04844573236281, 73.01030020559989, 75.7266592210339, 76.65511561978248, 67.27821903844034, 52.19874928074499, 58.70223122258341, 47.950673334060184, 8.904644193187837, 0.9474616918352343, 2.076509633371907, 5.41053016339579, 6.817583874348672, 4.896076994557535, 1.8939826276994522, 0.1739783837429939, 0.7982557723599096, 1.0636826844946032, 1.7578480681104047, 15.253139561222447, 50.269131429733775, 54.288042899101015, 90.06693870790544, 35.33229081861435, 48.27573191735053, 63.648383155945815, 81.93656352258499, 7.131114611702581, 0.31431328084680343, 0.08479112473827216, 0.05888810621634607, 0.08557865546355325, 0.17086647330753266, 0.058150390358341325, 0.04843785104552104, 0.01298637871044658, 0.03785241966045672, 0.07632257431865701, 0.04466248931543482, 0.038261977925656304, 0.04044828560924338, 0.04836201217145689, 0.03130744324035702, 0.032999114764313546, 0.06045036633769351, 0.04996865176625791, 0.01637914751265799, 0.032366023534127784, 0.03703126533617897, 0.026411224013915467, 0.04930857508893936, 0.11278677371240432, 0.10770676807770807, 0.038522168197819305, 0.05316894959598299, 0.0644897947448396, 0.19755368241138999, 0.09264118173309872, 0.09597295174194921, 0.14963218611815285, 0.11936597511052124, 0.10964798125168009, 0.17385332755023436, 0.10336088151821207, 0.14557043390889324, 0.17165372058028178, 0.19640543918696143, 0.15532310090718732, 0.1734976329269909, 0.15412558290746906, 0.14891799298986313, 0.18522453914967277, 0.19814194600668647, 0.21005058360676612, 0.12950621365058806, 0.14284610267608397, 0.16849464977220183, 0.08868002452917638, 0.10732444423821666, 0.06949791068872137, 0.2125263959169388, 0.1965153574823372, 0.1809797225700271, 0.2612990158940515, 0.2162618253139719, 0.4022754963126875, 0.3545419979960688, 0.4218464074355941, 0.7689584863762703, 1.3037386031881457, 34.44190886712844, 124.84618709933375, 101.26879645932107, 64.47985895218389, 66.16273618513539, 120.40329487093034, 62.217071056365974, 23.56140894274558, 1.4003931586780858, 1.6793057923355412, 1.643008914205336, 5.780078720661902, 6.622145896957767, 13.781251522802538, 12.727826449178881, 7.779243626902181, 1.667132103635419, 2.0956262849992324, 5.803623728213772, 3.1664774687059465, 5.913136793721107, 2.8846458561958808, 1.4402847664971508, 0.6058940976377457, 10.104221682394705, 15.595297717279005, 11.266653345477197, 14.088580992914016, 41.79667849694529, 65.64311627418765, 80.86627421840545, 75.51632604291363, 84.6776177806239, 81.4572028190859, 92.75541751615464, 81.24432794509396, 93.08000149265413, 87.04768642302483, 88.78550821735014, 79.32635168875419, 79.77792632195258, 79.63235147537725, 84.15657797167378, 80.07647360524824, 79.23976928957048, 72.69026617850028, 72.65851851432555, 69.58089351654053, 67.57134560615786, 60.87401620803341, 66.42358949107509, 72.30966291119977, 81.62799850586923, 73.82404296628891, 80.29529479242142, 51.54440379911854, 39.02606917965797, 77.10112833207654, 74.3229684522075, 80.35027073275658, 73.16863844471594, 79.81706373153195, 68.06547011098554, 62.13289699246807, 67.5011351800734, 68.64485909861904, 67.35687824987596, 69.15782666975453, 75.08190001210859, 84.1558954792638, 82.10174237528156, 76.97276484581732, 71.80532455444336, 69.76485267762216, 71.17592534711285, 65.43046105292537, 65.8841694554975, 58.71714407397855, 58.594554316612985, 57.772374537683305, 56.206081913363555, 62.40138715313327, 79.2129010538901, 85.67582961051696, 79.50252102267358, 70.68788051605225, 73.1487363384616, 80.87732745755105, 92.41679145443825, 91.01543841823455, 79.10994668160716, 64.53559583233249, 69.02396402051373, 53.816024872564505, 12.796316915942779, 1.1968717892323772, 4.002441682161824, 6.884907926282575, 11.749510841984904, 11.770700466248298, 7.5294028655175245, 2.1242188926666015, 2.326923796246129, 1.8909980717205235, 1.8821628103333137, 13.853878128913141, 51.21957663566836, 76.2070083618164, 84.90342863144414, 40.842150103661325, 71.28157831007435, 69.95218507705196, 97.87424395161291, 15.111336073567792, 0.6587292205902838, 0.2538702153270283, 0.2310509075440707, 0.27441922154638076, 0.20951168671731027, 0.19917783477614004, 0.1411252853370482, 0.1557340917568053, 0.12514882045046938, 0.15617943398894804, 0.1803131188235937, 0.2076855782539614, 0.1879938091001203, 0.2255712644827943, 0.1280319846926197, 0.22099888402848478, 0.13800068848556088, 0.14521470864213284, 0.13525763406388222, 0.08072395628738789, 0.09730827363748705, 0.19243457564903846, 0.12016228520341458, 0.20194045508340483, 0.3145997364434504, 0.16666532373957096, 0.15743215628448995, 0.16691439424551305], [0.02228438688982879, 0.040853910012951786, 0.08886946275109246, 0.06736646256139202, 0.02387976690736269, 0.08214886450479109, 0.06383836336974656, 0.03455765935922823, 0.04086766512163224, 0.015314413617635447, 0.07907865989592769, 0.07361195605969237, 0.09375466754840267, 0.05035335430875421, 0.07989240614997764, 0.08696612496409686, 0.11185380885557783, 0.16104473582198545, 0.06775300754534622, 0.08925282847016089, 0.07757584053662515, 0.02803475393222705, 0.036213428172613346, 0.013384570146069653, 0.14440404972241772, 0.03041899000715104, 0.14896659360777947, 0.109825614058683, 0.04718776026199903, 0.048026454169303186, 0.08999153641202758, 0.04385258499232512, 0.10558893333279318, 0.37410889481825216, 0.13652023889364737, 56.2028302684907, 82.595929638032, 79.91360895095333, 41.04339907246251, 65.62618732452393, 82.86475320016184, 39.94982265656994, 18.28951201131267, 0.0487268309018785, 0.45779303016681827, 0.3484573906227466, 1.875671042549995, 0.3462368081654272, 1.978298509793897, 7.692532279799062, 4.438979173860242, 1.450794144503532, 3.582811567091173, 8.360805607611134, 7.071554891524777, 2.4344195377442146, 1.5464141748605238, 0.200236736826839, 0.7883654546833808, 3.4895187279870434, 2.2944451003305377, 6.258265164590651, 17.78104143757974, 25.83977060933267, 33.51054991445234, 57.01600428550475, 74.80046995224492, 83.18195527599704, 79.57915629110029, 71.98798148862778, 64.49723112967708, 67.93638490861463, 68.63526498117756, 65.6996964639233, 66.70479205346876, 66.14267718407416, 68.21968986142066, 69.71418349973618, 67.5338791262719, 73.2956918593376, 67.88078923379221, 63.72499881252166, 59.82787693700483, 56.085457263454316, 55.17098803674021, 61.09394742596535, 68.23839172240227, 66.408245178961, 66.42121253475067, 42.96877291894729, 1.068085545013028, 55.24712124178487, 74.55943246041575, 66.56449671714537, 70.2466687848491, 66.57348678958031, 57.57128246368901, 60.460696451125614, 62.47420987775249, 64.90599309244465, 68.36261318575951, 57.94504903977918, 61.81476531490203, 73.6882975793654, 67.7425099957374, 66.55223538798671, 62.87801788699243, 59.95854677692537, 51.82332354207193, 41.234955864567915, 33.06223084849696, 29.299697260702814, 23.620675956049276, 23.525164281168294, 28.46332242411952, 39.667047223737164, 48.82777414014263, 40.90381368514031, 24.880972716116137, 14.784522229625335, 11.31270589367036, 15.991463968830725, 23.96848624752414, 41.11883017324632, 65.23861400542721, 60.029090604474476, 29.65768021921958, 3.714614236547101, 0.1721104468789793, 0.04554055248116774, 0.3319940385558913, 0.4342805047429377, 2.7959615568960867, 1.1854754652707808, 0.5231450185660393, 0.5368159495053754, 0.21533750958981054, 1.0036845168759747, 14.5913553045642, 27.360685333128902, 59.631221063675426, 66.90366406594553, 28.196791487355387, 45.967079747107725, 49.504743852923, 71.00691041638775, 21.803210435375092, 0.6991222789210658, 0.21085019553861312, 0.10504406861840718, 0.03042956202050611, 0.23638173036517637, 0.020638021805714217, 0.1240919025674943, 0.033622626065006184, 0.026148409890611807, 0.0687332017227046, 0.01636428732214676, 0.04570749836162694, 0.07370826097265368, 0.07227314846409906, 0.06115826222324564, 0.004511966760600767, 0.08904587747829576, 0.17017861828207972, 0.05491340074748282, 0.052296287350116245, 0.03160880882323029, 0.10763098666023825, 0.046418948895147735, 0.05518895491296726, 0.02135808508272373, 0.04371218022800261, 0.05793201699552517, 0.03686200203974882, 0.04526480296326261, 0.06101958881763201, 0.012183899694542972, 0.09049760643392803, 0.01197641244113085, 0.044152232623028184, 0.05949911879255407, 0.04209610242997447, 0.06436390351624259, 0.0104166928588623, 0.030607037779484546, 0.017399670473570307, 0.03976279396503683, 0.09970286530592751, 0.07891522269816169, 0.15158823841521818, 0.030081647020133755, 0.07148508913815022, 0.11723202953655874, 0.13418321107183734, 0.10496487044879507, 0.011392384354445723, 0.04476794897909126, 0.1025801383319401, 0.02236487591759332, 0.0958054312955468, 0.030350580270732605, 0.1228544484042833, 0.08917836472392084, 0.09884686164197423, 0.0433999955684187, 0.07857827424642541, 0.1037019745056187, 0.15859049654776053, 0.22076490545465102, 0.07051458597303399, 62.526549985331876, 96.55989693057154, 77.03636215579125, 33.532970182357296, 93.25635125560146, 89.29008976105722, 49.82730780878375, 26.243759047600534, 0.24377224185774404, 0.20012353967514732, 0.8117792466955801, 1.5007074081128644, 0.2822495900815533, 2.8652149246584986, 4.889278056160097, 4.417150203258761, 5.5185944034207255, 5.9429046415513564, 10.050742126280262, 13.904847368117302, 6.764736310128243, 3.9636109529003023, 1.22591853382126, 0.767149844717595, 4.792320497574345, 3.8974582187591063, 7.725665030940887, 20.278120348530432, 34.04137995935256, 50.43992319414693, 68.85996187886884, 79.88513254350232, 83.61656958057036, 78.55203659303727, 78.18286311241889, 74.02424858462426, 75.50023648046678, 74.58641052246094, 72.84143432494133, 70.50588254005679, 72.80559955104705, 75.5556752604823, 77.06729396697014, 73.70000977669993, 78.60381187931185, 75.33421824055334, 70.52099150996055, 65.28338001620385, 58.73228442284369, 60.47819414446431, 64.79445657422467, 72.7102388874177, 70.99590424568423, 74.84080760709702, 46.29457019990491, 2.821299823061113, 66.50775571023264, 78.65638732910156, 74.74161086543914, 75.00817514234974, 72.7865525214903, 61.507651575150035, 62.56957838612219, 66.45319554113573, 69.11400595018941, 71.77825235551404, 62.59367742846089, 67.79219858108029, 79.6483390561996, 69.8683326475082, 69.87749530423072, 68.18561230936359, 68.38364493462348, 60.735227061856186, 52.311203633585286, 43.661008496438306, 43.23137560198384, 39.16200284034976, 43.64732334690709, 47.371868779582364, 54.3970847898914, 53.18589610438193, 42.88684637315812, 28.850001442816954, 18.90222937830033, 14.668405363636634, 18.928097409586755, 34.32166076475574, 47.65147885968609, 67.94064460262176, 66.5857873424407, 31.470146679109146, 3.5681617596457085, 0.0827974115588492, 0.6831713477450033, 1.3166997077003604, 2.6213788217113865, 3.927759999229062, 3.2108532036504442, 0.34907338660090204, 0.6487363084189354, 0.341440484889092, 1.5131655912245474, 21.62148310292152, 51.41508717690745, 46.08554317105202, 89.53684606859761, 39.03322358285227, 40.03225911048151, 50.12300745133431, 80.99155472170922, 20.34601265384305, 0.6042728717288663, 0.23747832394174992, 0.08674460297991192, 0.10871206695634512, 0.1530563539915508, 0.06945874827403216, 0.06764793092565191, 0.0625691510316345, 0.014782295648699567, 0.06391860724937531, 0.025126912082815846, 0.09315370221532161, 0.020836049788481286, 0.08095330002927974, 0.016776739484480312, 0.02492818696003768, 0.08537476882338525, 0.14184133239811467, 0.03746321635140527, 0.06472510631166159, 0.04182142926560294, 0.02115991728891048, 0.07848954594303524, 0.02632944412799853, 0.04615994605926737, 0.0320036064893488, 0.04938733658843464, 0.04755811397767356, 0.04488041068637564, 0.13850826770067215, 0.12125826590964872, 0.18889462124676476, 0.09026257831963802, 0.12416045977583817, 0.2342699323931048, 0.2619696186194497, 0.11504720040266553, 0.08872529266462212, 0.05296238547851963, 0.23038041207098195, 0.19222918747653886, 0.2338063725901227, 0.15282619053557997, 0.13979402370750904, 0.2278052381570301, 0.22735107059199966, 0.2164955127743944, 0.2026916502584373, 0.19167962664317703, 0.11060504723460444, 0.1301548143308009, 0.2230771579929898, 0.1257908174527749, 0.19948097576777782, 0.16190309137586625, 0.2733154114215605, 0.162729577672097, 0.21753981318925658, 0.15520251866790558, 0.20117044478895205, 0.3363857754776555, 0.52805692918839, 0.3706506819974992, 0.26432184562567745, 87.4128669308078, 106.27870651983447, 102.99168971277054, 61.038755755270685, 84.97104244847452, 102.33492020637759, 62.376511481500444, 29.297820406575358, 0.20637486310255146, 0.4327687374766796, 3.97110709259587, 2.9867353458558363, 2.262783973447738, 9.215396911867204, 21.736747833990282, 15.862167939063042, 7.784876640765899, 6.8003627081071185, 22.783079301157308, 23.1517271841726, 7.075573359766315, 3.8475793984628495, 1.6595865665904939, 1.4755190500328619, 5.158560535600109, 3.8362013380373683, 8.58392277071553, 24.465683929381836, 38.988292832528394, 59.44544192283385, 81.46109381029683, 88.7892972269366, 93.47406633438604, 89.42319147048458, 89.34572465958135, 78.35556507110596, 79.20764507785921, 76.9226683339765, 74.83972503292945, 75.49673772627308, 75.75258608787291, 76.70474144720262, 78.3769106095837, 76.0151417024674, 81.22215870888003, 77.51315762919765, 72.10879833467546, 68.17575147075038, 63.38089319967455, 64.44074115445538, 69.06297591424757, 77.6885424890826, 77.23506158398044, 78.63665780713482, 48.728710759070616, 2.2815875709056854, 68.32949269202449, 80.96155643463135, 75.56585773344963, 79.33290989168229, 76.23225273624544, 63.54160055037468, 67.08393619906518, 70.40059827989148, 71.80956071422946, 78.4295488172962, 65.72550565965714, 70.91908070348924, 82.82733378871795, 74.8397328776698, 77.05788027855658, 75.31282563363352, 75.7360258410054, 67.65319762691375, 64.51101826083276, 55.95514043684929, 57.350468712468306, 54.219315128941695, 56.311554447297134, 59.17861092475153, 69.64376126566242, 63.349353421118956, 48.02698696813276, 29.322256772748887, 18.841983733638642, 13.109196539848083, 17.28948804640001, 32.96497960244456, 51.933173441117816, 71.89869265402518, 74.76625119486164, 38.91745482721637, 5.443454538622211, 0.2741844002758303, 0.3857469041982005, 1.5295128043620818, 2.336486044429964, 7.536884786621218, 6.5701612541752485, 2.5502434517106702, 2.322854337192351, 0.29307073522959987, 1.134095602939206, 19.82295870780945, 48.036479103949766, 73.66135874102193, 83.10819118253647, 40.42602977445049, 67.52720325223862, 60.544329227939734, 97.41659748938777, 35.2348473764235, 0.7536842866290001, 0.2823431140953495, 0.2221040118245348, 0.23673526462047334, 0.23255761863002855, 0.13073797578052168, 0.20041866738709713, 0.13208717918924748, 0.067557065236953, 0.18460348699121706, 0.19117973895082552, 0.2489634068502534, 0.17720044230020818, 0.17280006390665809, 0.1479595863530713, 0.1737225256980427, 0.23177268494281078, 0.22824097364660234, 0.11400625545291171, 0.19280784432926487, 0.11942464978464189, 0.19286465740972952, 0.16764890402555468, 0.1230401864215251, 0.14580977509819693, 0.22948796560447063, 0.1498858378298821, 0.1038034888164651, 0.22385004877803788], [0.017857886813280564, 0.11490635513778656, 0.030201424867095008, 0.0339700162951504, 0.05391915268715351, 0.10112291652589075, 0.035455093058126594, 0.014976730679101763, 0.07688456109815067, 0.028139198529383833, 0.10808623440924192, 0.07726930577548281, 0.042706076957045064, 0.026690198761981823, 0.08402512874454261, 0.041784875380295905, 0.03629086433999962, 0.03336551163585917, 0.029622545848870953, 0.051747538569954135, 0.02223650064890183, 0.014614804888204222, 0.06787532880421608, 0.08487075957800112, 0.026276894326832508, 0.028181821746270985, 0.08242732980438779, 0.0505409692414105, 0.037065566922988624, 0.024938670873281457, 0.029018726838271947, 0.11467262937296784, 0.10227934156935062, 0.06650220813049425, 0.12234245652272818, 1.5155789520471328, 88.17563456873741, 74.10355106476815, 87.00306553994456, 43.62263987141271, 50.217289463166274, 81.85088326854091, 43.72722987205752, 27.223061130892848, 0.768900202406991, 1.5010351711703886, 0.39114779342086087, 2.2809511663452273, 0.13125980423102457, 4.12867997923205, 2.964314832802742, 4.795317188385995, 4.702061366650367, 7.747380743103643, 12.190878487402394, 5.952266848856404, 4.739404291875901, 1.9599016130931917, 1.0570218870716712, 0.7754757495657091, 0.3809629302592047, 0.7569432246588892, 2.480431881643111, 4.169023027343135, 10.79994228578383, 23.760449617139756, 40.651315027667636, 51.81685163128761, 61.7140898396892, 70.19089268099877, 65.17016080117995, 66.82416546729304, 67.84460929132277, 71.42699626184279, 69.71256748322519, 66.67415049768263, 62.50318050384522, 64.72347344121626, 64.07979288408833, 62.3656935845652, 64.07558025852327, 62.79565203574396, 61.10601263661539, 57.72385089628158, 57.89696078146658, 61.74071096604871, 67.45205848447739, 65.63226699829102, 56.3368066664665, 36.75502861699751, 0.01822112165691872, 46.49952973088911, 75.27005610927459, 73.71851551917293, 71.00578077377813, 61.574276954896995, 62.123130290739006, 62.54534598319762, 66.68668639275336, 69.51867688086726, 72.31870789681712, 78.43309463993197, 67.31165332178917, 68.3252408427577, 67.7263576753678, 66.77763831230902, 61.59605003172352, 51.18926063660653, 50.55958294099378, 42.07999521686185, 38.855701031223425, 31.115382025318763, 25.777771665203957, 30.254468840937463, 32.44883491146949, 20.92176168195663, 8.967101074034169, 5.749464131170704, 2.6760855893934927, 1.045029240269815, 0.5804445342190805, 0.6626199666530855, 0.5590302316892533, 1.4950855484893246, 2.648209059430707, 5.497702388994155, 0.7657697220002452, 0.140841219934725, 0.020725643112053795, 0.12273490804457858, 0.9186415254108368, 3.232129365205765, 1.5990501762397829, 2.139436463194509, 0.03553574679479484, 0.15605891303670022, 0.6908352913395052, 23.958892130082656, 29.318885495585782, 51.9944251737287, 77.6822510073262, 32.61075231336778, 59.84210337361982, 49.488207140276515, 77.33210886678388, 29.398356637647076, 0.13473827241649552, 0.03726608660672942, 0.049004442013439634, 0.034438421604253595, 0.04264623782927952, 0.03800412805210199, 0.0669828133897916, 0.0038806198168576007, 0.048507932768834215, 0.02812332135715312, 0.026248618021547317, 0.09203606420346806, 0.06523342863205941, 0.040398011089212475, 0.025466641433717265, 0.050750314258039005, 0.045860493780985, 0.012999660759833793, 0.04151142795660323, 0.07036486940999186, 0.0355765639594005, 0.03975267777399671, 0.11834859502531829, 0.02857379446316871, 0.0474041341353328, 0.041390409047204646, 0.017358280658241243, 0.1188723770000281, 0.04612219707679845, 0.0778575157446246, 0.10320803931643886, 0.09941663187477859, 0.01634735103336073, 0.07361436923665386, 0.08385072116770091, 0.010034691733908991, 0.039573727295764034, 0.02476862616716854, 0.07210861576060135, 0.05952731082816759, 0.05628338429115473, 0.06408563739950619, 0.06252811936241004, 0.05807420291427163, 0.028490369403434378, 0.03078459397769503, 0.022998468935369484, 0.09252884259988224, 0.018887110617792895, 0.04434861926241748, 0.03488800413305721, 0.05900013891439285, 0.021925815606429692, 0.06516812729739374, 0.042786317006234205, 0.011398755333146021, 0.018759235221472, 0.024310595603779923, 0.04373917716645426, 0.024683927486260093, 0.10561383885121155, 0.07565404769153365, 0.052497730169805794, 0.12841145102415355, 0.04888814986653386, 2.3972357136587945, 98.02368625517815, 84.43504271968719, 80.29789924621582, 39.60452464319045, 84.66908270312895, 89.45904193385955, 58.49546740131994, 43.45362494068761, 1.1776415114441228, 0.8397865631887991, 1.0731125526851224, 1.0088282150606955, 0.6996924321978324, 2.3844024538993835, 2.917745267191241, 4.0269248716292845, 5.612844055698765, 6.499818938393747, 9.350199949356819, 9.277357612886737, 8.396332475446886, 5.430024833448472, 0.8560421522105894, 2.0692927174029814, 1.0310999231953775, 0.8682573322326907, 4.727050787018192, 7.301487172803572, 17.136311646430723, 35.3871294759935, 49.94580653405959, 60.48069661663425, 70.4725580830728, 76.26968783717003, 76.02311195865755, 76.73535946876773, 74.78671812242078, 80.7018876844837, 78.00086513642343, 76.91228189776021, 73.79304055244693, 75.9943845195155, 73.54022026062012, 70.11956045704504, 70.13953316596248, 68.81628236462994, 67.64613736060359, 64.53237164405085, 64.83904607834356, 67.64712579788701, 77.40821853760751, 72.83792772600728, 66.68158731152936, 45.38517259782361, 0.2097760330164625, 52.44667053222657, 81.88282705122425, 77.95726406958796, 77.85862430449455, 63.87530795989498, 65.62165306460473, 64.7502475400125, 70.58181178185248, 71.01684185766405, 74.65464407397856, 79.00858479161417, 68.17871678260066, 71.75576932968633, 72.69680084720736, 73.64484556259649, 70.41234970092773, 63.47115870445006, 61.080152450069306, 54.580388915154245, 53.30063327666252, 47.729161400948804, 43.110743107334265, 47.13312587430401, 40.91393732255505, 21.30415943361098, 10.52973412698315, 8.510238105250943, 3.7075939293830626, 2.104683282875246, 1.2360508739948273, 1.8064588596743925, 0.5139051401807416, 1.020369298996464, 3.9044998538109565, 4.8500862236945865, 0.6868177424034765, 0.4599176371289838, 0.06665839047561731, 0.518597949656748, 2.345826678699063, 1.8884317384612177, 1.2702192534362118, 0.48170652601026726, 0.5927874364199177, 0.40431981726038846, 1.3970769172714603, 35.48926015054026, 52.76854415093699, 34.96425874771611, 99.05236705656975, 40.69960724922919, 45.30240666481757, 51.78677489680629, 86.01204733694755, 30.887660980224613, 0.1297226488109558, 0.05211045740232353, 0.05169027732805379, 0.0686373794451356, 0.1071361015220323, 0.10395323602302421, 0.021508736273033485, 0.09307995859173038, 0.020640532658886046, 0.07822659392390521, 0.07137772191556231, 0.08714234050843986, 0.08469400011123189, 0.026432245466557723, 0.03873259339842104, 0.04380829361898284, 0.09865307970152748, 0.05478303939584763, 0.02718571400750549, 0.06843146267196826, 0.07152006105189362, 0.1071897583202489, 0.009944437000329697, 0.04366786204158299, 0.1418255509868745, 0.04210906846809291, 0.05761575291774446, 0.04458333711109815, 0.031757952735549023, 0.012591401971275768, 0.13248790446068012, 0.22576745960020253, 0.15810453633387245, 0.1924782886259979, 0.22084355204095765, 0.13494641850552253, 0.1769714892631577, 0.10606253654846262, 0.2209538074150201, 0.11432320900982428, 0.11859142957555673, 0.20354790673140558, 0.1534355062270357, 0.10128747987290544, 0.20982602791440105, 0.1700937817053449, 0.15234635902508614, 0.2673342872050501, 0.22225788824500578, 0.14404317634480615, 0.1444257912977088, 0.10135186190206198, 0.13114703608857048, 0.15083840687669095, 0.09992742099829259, 0.15820291734510855, 0.11548531076480305, 0.11289994788145828, 0.1623985510800154, 0.09803402703255416, 0.12991093790098546, 0.17887250580374273, 0.17066378176452654, 0.20933357127491506, 0.2454037639883257, 4.799360171441109, 126.65273666381837, 94.26138800959434, 116.76340595368417, 61.30350789716167, 71.0383992041311, 99.29714648954331, 65.90189856867637, 41.516197650663315, 1.4466599663419109, 2.436287811686916, 2.058987670367764, 4.656500585617558, 2.5969745699436437, 13.05946873080346, 11.716393290027497, 16.962752649861, 17.7268676219448, 25.080376209751254, 34.12043925254576, 25.450665604683664, 10.521406935107324, 5.854905776439175, 1.107564813667728, 1.5095702486653484, 1.36447356352883, 1.882637294550096, 3.81513306210118, 5.207405811355961, 15.163862493730361, 31.423148839704453, 46.30926732094058, 56.15783676024407, 69.60121139403313, 80.64404056918237, 82.74943551709576, 83.43883129858202, 78.84856777806436, 84.82174919497582, 80.51187238385602, 79.91957095361526, 76.04681876397903, 77.71302592369818, 75.19675485549435, 72.87898709697109, 73.63283526512885, 73.5037265285369, 70.75033249393587, 66.95423910694738, 68.11050676530408, 71.66706885060957, 81.60964965820312, 74.37453977523312, 69.24177323618244, 52.190186746658824, 0.4576718350571971, 56.23404841269217, 87.96078282017862, 83.10677912927444, 80.90960071932885, 68.95006656646729, 70.31426691239881, 68.97923331106864, 74.21344018751576, 76.50781493033134, 79.77885200131325, 86.81598417220577, 74.52797505163377, 75.7460121954641, 78.22953147272911, 77.73734461876654, 78.71438349446943, 72.52015298412692, 72.23023491521036, 66.65293831979075, 65.12272757868614, 62.95061311414165, 58.74050178835469, 62.839005993258574, 53.45880677623134, 27.970596244258267, 13.203395201313882, 9.178173618931925, 3.9065304158195375, 2.4291140417898855, 1.7805299090762294, 2.642012204854719, 1.1001668558005364, 1.6728375587732562, 3.364913852945451, 6.812158255807816, 1.2019776120301218, 0.9452099449211552, 0.16489160036848438, 0.7926264970052628, 4.501983715641884, 10.47828341684034, 7.026672680531779, 4.294582018929144, 1.371584698077171, 0.4216542725841846, 0.962776831321178, 33.90723882182952, 48.352288738373794, 61.36837213270126, 96.36941879026352, 44.34850585076117, 73.7295844477992, 61.581764759555945, 93.88650355800506, 45.70164511280675, 0.27304541139352706, 0.13542139301857642, 0.24801384086810777, 0.21284010892193164, 0.1564520233941655, 0.17440845018192647, 0.18744078554934074, 0.1743799670329017, 0.166990589350462, 0.14708996930670354, 0.16097529761252866, 0.27974003925919533, 0.14235741518918546, 0.10089239300859552, 0.10038449203655606, 0.14647032675002852, 0.2123763652578477, 0.12787836108116374, 0.11630131697822964, 0.1548050416092719, 0.14179470828704296, 0.2844561071645829, 0.2530523398590665, 0.11754209596303203, 0.2458993769100597, 0.14248910570336928, 0.10105054419968398, 0.186582338064909, 0.09610229802708473, 0.14471566364649804], [0.033800224398052504, 0.10691238852638392, 0.042552108606023174, 0.022519457138954632, 0.07838911181616207, 0.05761446589003167, 0.08631631386496368, 0.03455304750992406, 0.04602069808771053, 0.007615798798900459, 0.07092939960139413, 0.03607977647334337, 0.03305284817132258, 0.02658180115113576, 0.035831142637518146, 0.17544571790964375, 0.10025617230923907, 0.06484168191109935, 0.011302320185237595, 0.031596197100776824, 0.058762804875450755, 0.06532065540311799, 0.055700958285841255, 0.05095333521885257, 0.012130554119545606, 0.09973188471649924, 0.021894526660382267, 0.043536746093342384, 0.026442474655566678, 0.02005605736837512, 0.09619022959903364, 0.10204868015622902, 0.07674691041991596, 0.04219728349257381, 0.2404079360947494, 0.15400690056623953, 8.211899197870686, 94.9391814201109, 70.7901837748866, 71.36951784933768, 32.74451494216919, 51.0827604416878, 83.25029080913913, 43.01412728524978, 34.916095964370236, 6.83093071945252, 1.4830808894288157, 0.34156416212358787, 0.55357170201117, 0.8952062829367576, 0.6193812287622883, 5.236181299532614, 6.3795664233546105, 3.2163499151506736, 4.575049136915515, 7.032825408443329, 9.75290185020816, 2.7211261660821977, 1.1614241042444784, 2.241758353287174, 0.35785109946323984, 0.21956015558492756, 0.3766989768032105, 0.2302804835621388, 0.4099978464505365, 0.11803676659661917, 0.6229421892954458, 3.3220043490009927, 6.317902841875631, 10.737320665390262, 13.385070562362673, 12.036441045422709, 13.923228575337319, 16.450378337214072, 35.74008787831953, 44.30548921708138, 48.15394624587029, 47.34825218877485, 48.348723303887155, 57.56341811149352, 59.49564826103949, 63.35419362591159, 61.31857372099354, 60.76176581844207, 64.53033201156124, 65.09175262143536, 65.02162456512451, 61.47899081630092, 58.8520343842045, 29.9035696829519, 0.42868073909513416, 45.46718543575656, 78.28932408363589, 76.03342779221074, 67.08956087789228, 62.679408673317205, 65.76765544952886, 74.60271189289709, 73.54014181321668, 78.25990630734351, 76.07814281217514, 76.44142489279471, 76.19668468352288, 77.63237414821502, 79.03062066724225, 71.57405376434326, 59.081085112787065, 55.334876429650095, 43.622624181932025, 29.612210142997007, 24.42196911381137, 18.377116187926262, 13.823847482281348, 12.983594402190178, 7.281734606912059, 1.738829720885523, 1.3488616722245372, 1.0421443370080765, 0.6905987233884874, 0.8393541831643352, 0.6199440275949817, 0.8758375577388272, 0.9541880050974508, 0.8197511576356427, 0.04738150006760994, 0.366583674425079, 0.08114459984485181, 0.2680723363113019, 0.1928127166484633, 1.7112735995361883, 2.562381471357038, 1.1268404438611002, 2.540399528318836, 0.1353975523623728, 0.07037639903325228, 0.07708314640988266, 33.04138737340128, 29.429527713406472, 41.56832202788323, 100.80387792279645, 26.749670274796028, 58.6434192042197, 63.9899274610704, 55.942835961618734, 45.51967067103232, 0.5387443460283742, 0.05465674980153, 0.06098430663827927, 0.06789965209581199, 0.029591176463591478, 0.10112204318565708, 0.04629983754468061, 0.05177013050284117, 0.06523806346400131, 0.04922045199500938, 0.05929211417453424, 0.03776801592339912, 0.028212038169224418, 0.07314818175209147, 0.0494916164766877, 0.05574213934221095, 0.0153365439825481, 0.018430627552011324, 0.08814979975502338, 0.08625514174420988, 0.019256125594819748, 0.025171762700342847, 0.06530837501369177, 0.059890903817910346, 0.06763327566366042, 0.013685525871903427, 0.01913469874360148, 0.021431595049498063, 0.08425117830836004, 0.04237801129479082, 0.006881508311527151, 0.034850810564333395, 0.0613778000397067, 0.03777132925367163, 0.011626760336390186, 0.07478462216714699, 0.013646166189573707, 0.07532899658526145, 0.01862179330219665, 0.04024099753869157, 0.01729067339892349, 0.026715632881067937, 0.06037275780052428, 0.03632525402692057, 0.02125115069981304, 0.10479096082910415, 0.0918832449843326, 0.10508310845902852, 0.058046911031969135, 0.07227041353020938, 0.023232183208869352, 0.04020980243841487, 0.005949069661343651, 0.06083100861419113, 0.018047280985140995, 0.03951329828029679, 0.042111803401982596, 0.030484793129407113, 0.022092931941452048, 0.03646841287733086, 0.03930714018943329, 0.02672884215210234, 0.04635175149286947, 0.040982145470597094, 0.04138624535933618, 0.23351150534806714, 0.20968974087267153, 11.037900717027727, 110.7307457154797, 80.79878591722058, 66.01454904002529, 29.77519835195234, 86.63713193708851, 80.78079008287, 50.31005744011172, 64.02287144814768, 5.660458687813052, 1.3845687239400803, 0.41939630503616027, 0.7481267783910998, 0.6693460960542003, 0.6290822307909689, 2.250577312323355, 2.6680251186893833, 5.21508090919064, 6.3563376568978835, 8.09005714231922, 5.903397548583246, 5.376071651135722, 1.7211003625585188, 3.5698655391893084, 3.4913418946727632, 1.348316707918721, 0.3302575317361663, 0.5404679212839373, 1.0575238278796597, 3.0986854289808585, 2.6390758204844693, 7.274038426337704, 12.995482125589925, 17.6438408513223, 20.60522640905073, 19.535913775044104, 20.790954559080063, 23.415918427128947, 42.512542432354344, 54.111469561053866, 60.091974043077045, 63.40375277303881, 62.21536482534101, 70.72014593308973, 73.25712711580339, 74.1821082945793, 70.8779977983044, 69.10361951397311, 70.23020267486572, 72.55066902406755, 70.32331974275651, 70.1068990461288, 72.79368339046356, 38.29476679525068, 0.6095701552206471, 53.62029075622559, 89.09589321382585, 85.34508751284692, 72.8724681177447, 68.32528791119977, 70.85373401641846, 77.49687979298254, 76.87652557126938, 80.66244433003088, 78.80024417754143, 78.78759061136554, 78.57404108970397, 78.90340251307335, 77.53384420948645, 75.83275933419505, 65.89959221501505, 65.66469715487573, 55.34558450022052, 39.67502140229748, 29.038406610488895, 20.93207359313965, 16.102153255093484, 15.693462875581558, 6.610876437156431, 1.696501095448771, 2.45089765998625, 1.4872132289794184, 0.8638541039920623, 0.9394023855847697, 0.682507302732237, 0.8487012525719981, 1.05793874109945, 0.6408689531587786, 0.16923587048246017, 0.19252685860039728, 0.10932027948118987, 0.8422384122687002, 1.168876484997811, 0.7206660196665795, 0.23850508094314607, 0.26875976232751725, 0.4013393981562507, 0.07046413908322012, 0.13704214395294267, 0.3839685383342928, 48.776736259460456, 55.33739459130072, 27.69970363186252, 105.71339884111958, 45.569924077680035, 47.62560690602949, 66.68362694401895, 61.307693066135535, 52.47984986151419, 0.42024099358147193, 0.1491591881119436, 0.055131257000950076, 0.0767701305449009, 0.17133870522581762, 0.08369844587099168, 0.022776240235074394, 0.043540764224505236, 0.014690283700943956, 0.10072097317465853, 0.052491206931130546, 0.021372677142461462, 0.015441469299877364, 0.020318641665301496, 0.07618825612289291, 0.0879797971837463, 0.026092744026813778, 0.040841066548901225, 0.05207310295513561, 0.07335832733060084, 0.060004326965539694, 0.01803694837426226, 0.04788756625907076, 0.032981119358972195, 0.03863919195869277, 0.020732093572376237, 0.026179892273860115, 0.015352188455571812, 0.050658728446691274, 0.016382382318918264, 0.07909538359531472, 0.10480304203567006, 0.21729921561575707, 0.13047269485410184, 0.10121350642293693, 0.1493335956887853, 0.15569659941379102, 0.2642538783050353, 0.15634676291336938, 0.13479784341348758, 0.07900080238018306, 0.11863550261384058, 0.14179686865498944, 0.1371976904450886, 0.24896038846383173, 0.2058129529318502, 0.2342433338203738, 0.17809503381290745, 0.16304284634609378, 0.1498047091187008, 0.13709569349884987, 0.18596208263789454, 0.11044322648235869, 0.12434050575980257, 0.1560680754482746, 0.09125146759493698, 0.15047685934170602, 0.09116103091547567, 0.11030965905276038, 0.11402551490332812, 0.12404976773165888, 0.16229704443004825, 0.14653058722615242, 0.222040472492095, 0.10691615767897138, 0.49732243161528344, 0.40847017519897033, 19.35156826050051, 135.25990732254522, 89.74895215803578, 101.6205624611147, 45.79635074061733, 71.10718188747283, 96.2046870877666, 64.66455944122808, 55.048284530639656, 12.338483160541905, 1.7482334807995827, 0.6570184543248146, 1.482120153884734, 2.9422397334729475, 4.272842282249082, 12.409780083164094, 15.791573120701699, 15.419182315949472, 18.452555133450417, 22.92367862116906, 31.65891270483694, 11.958760465345076, 3.908013071744673, 6.516542453919688, 5.192886667866861, 2.2874625459794076, 0.4856048410217609, 0.4000022070061776, 0.5532652668414578, 1.6121540795410834, 0.6771482419102424, 3.7323139319496774, 8.509136899825066, 12.603111747772465, 17.914133341081683, 15.508685900319009, 17.80784103178209, 21.22258590113732, 43.8360874114498, 57.08850929814001, 69.11854805484896, 70.96906738896524, 70.9836664507466, 78.37862076297884, 77.61573545394405, 78.08684349060059, 74.43518746283748, 73.00528741651966, 74.45050824073054, 77.842495518346, 76.22657314423593, 74.81615943293419, 81.49170398712158, 41.836086550066554, 1.1086831794631098, 62.1408123354758, 92.83338639043993, 88.20110644063642, 75.03553759667182, 70.57333946228027, 73.10718274885609, 82.37682604020642, 81.39405265931161, 84.38880582009593, 83.34677327063777, 83.50835138751616, 82.90820521693077, 86.47676975496354, 86.11251492654124, 85.83758815642327, 78.26144387645107, 78.8096421764743, 67.92068758318501, 47.436117203004905, 36.16075423456008, 27.09888673597767, 24.799305046758345, 24.133321892830637, 10.876269648152014, 3.5696365708304993, 3.4608491438050426, 2.36208563850772, 1.4395621923669693, 1.2268331815158169, 0.8692815611439367, 1.2039856204102117, 1.0729421747307624, 1.3147831395749123, 0.28491208269711465, 0.39410915225744253, 0.22708545258689314, 1.019886908752303, 0.8107729748852792, 3.849637907358908, 8.436897627768978, 4.841357479172369, 4.969786174835698, 0.3580432036711324, 0.3791934203717017, 0.3270340788989298, 47.69527212265999, 45.40375286532987, 52.30846581920501, 117.32931767740558, 42.26755119139149, 70.26604529350035, 84.12359868326496, 72.9025605417067, 74.44056110997354, 1.4804684683199854, 0.38697148042340435, 0.21374490472578236, 0.1505373343224487, 0.1881282115655561, 0.25816066010344413, 0.12481112889344655, 0.13295121911552646, 0.20486639001436774, 0.2584021923042113, 0.15934354565556974, 0.1421798972953712, 0.07022868195969252, 0.12700602442266481, 0.15505826431176356, 0.12947313397401763, 0.10379537594534698, 0.12613372606856207, 0.29570895817972004, 0.29476035746835894, 0.11094299160064229, 0.10207116483680664, 0.15447240623254932, 0.12570764328683579, 0.16514281592061444, 0.10077836848194562, 0.09738585536157894, 0.14832877944554054, 0.36209927150799387, 0.21234012929902923, 0.2540161244330868], [0.052202797810276674, 0.08635733787330889, 0.05740065075036499, 0.04984657182508419, 0.043821895510078444, 0.08159880571427845, 0.02579829621789677, 0.03026657681461544, 0.024258179868000652, 0.1054374011413705, 0.06715764231499165, 0.034320064850391886, 0.06359778494844515, 0.17056137113080871, 0.02362263141079776, 0.061451765828795975, 0.04392756584791407, 0.12274865166194017, 0.07774901471190876, 0.07051126881232185, 0.08471624730455299, 0.04569139519345857, 0.04240460220664259, 0.065329427109851, 0.002103160809530246, 0.09454010685365047, 0.025269511689041412, 0.06754082417295826, 0.05348005024115405, 0.03837996695731436, 0.03093498278289072, 0.1583227488182245, 0.0535691156232309, 0.051902242365383336, 0.03726332102932277, 0.11665115102885232, 0.38055393123818987, 20.720285215685447, 107.96967168008129, 77.30196937437981, 79.03619827762728, 48.12525410805979, 54.726685477841286, 105.21339078103344, 41.56901236503355, 37.853190283621515, 18.96390864926, 0.3426261438477424, 0.2793072608690108, 0.27110328657492516, 0.38848324768966247, 0.5199588895324738, 0.7876797753476328, 1.129496991634369, 5.94642791055864, 3.0054560832438932, 4.861532190153676, 7.968439152163844, 1.256923889440875, 3.6304747385363427, 2.0647449743363167, 0.9368185242337566, 0.7856230437755586, 0.1253746708314265, 0.14845714513813296, 0.08931535656654066, 0.39951669112328564, 0.0040685335238043584, 0.833352527791454, 0.3133538936174685, 0.18232151024764587, 0.2910618381875177, 0.17526757182373157, 0.26723019117789887, 1.7902024739211606, 7.2360860628466455, 17.068772354433616, 27.97664453906398, 29.404183318538053, 31.45378451193533, 42.96546636089202, 55.91666590782904, 65.22619578146166, 67.12760786856374, 71.24728110528761, 64.60286055841755, 69.64907215487573, 59.01043538124331, 54.702562901281546, 26.944110008978075, 0.18512833382814162, 55.50318925611435, 63.41352731950822, 69.03222453209662, 72.34974168962049, 75.96415873496764, 75.72874592196557, 76.12455229605399, 80.22522557166316, 82.23525201120685, 87.0943469385947, 91.07084581928869, 91.46574220349713, 88.97134227137413, 87.29275611139114, 78.9207786129367, 64.62262538171584, 39.83269676085442, 21.53189616818582, 9.833111378454394, 2.7524234931315146, 1.337731211416183, 0.7877184474660505, 0.8521231528251403, 1.5622214492290252, 1.3021946602290677, 1.234863989295498, 0.3853018684012275, 0.15268872371844708, 0.08467165332648062, 0.09803804899415663, 0.019535904735206597, 0.09583042874451607, 0.17181387892173183, 0.8770655047508978, 0.1622905786479673, 0.15413289138626668, 0.14989783476677634, 1.3477441644476307, 1.24457013943503, 0.5607266567887799, 0.7405374211169059, 0.08946151848161414, 0.05920519000820576, 0.579593196030586, 36.571512683745354, 22.283671363707512, 38.246690304048606, 90.71359634399415, 33.07237409776257, 32.22003325339287, 37.905640217565725, 50.72261625720609, 53.30400651501071, 2.2686886114458886, 0.14396479022839379, 0.09884260219311523, 0.024971740973752835, 0.05322916027639182, 0.043838366400450475, 0.0373953026569178, 0.02538260924930294, 0.03627640443042882, 0.05789486173119757, 0.11148862240295257, 0.0481327488687971, 0.0652377034026769, 0.058018899027017824, 0.06415303015420515, 0.011158946830208504, 0.035805873227335756, 0.06704261421316093, 0.051835508446299264, 0.03408534317127159, 0.02752368135618106, 0.038227557595218384, 0.044512585060851234, 0.06565531325196067, 0.034686568974246906, 0.06037951852645605, 0.02939173696382392, 0.003239325700222605, 0.015744536555552437, 0.04825766333529065, 0.013743206546942313, 0.036716717295348644, 0.068995219114567, 0.07541977034340944, 0.061193429489409736, 0.03736240301100958, 0.030199925249983228, 0.052042175985632405, 0.020718212059188276, 0.06749426134892049, 0.07881404546600196, 0.1006409323083297, 0.00578154394808676, 0.02726118324414617, 0.03668760595422599, 0.0818687750987949, 0.019145048591458512, 0.07386839633146602, 0.0446730651592295, 0.09092087001209298, 0.11458646746412401, 0.054998903820711764, 0.07682135884439753, 0.0360595211086254, 0.005095837320456462, 0.009348931958928946, 0.013619468983022437, 0.03632420065602468, 0.034807438496500254, 0.051296224682441646, 0.0587376312262589, 0.07505894293107333, 0.020949340785943696, 0.16079997073017782, 0.030580316632685643, 0.13365362981154075, 0.02821722649969161, 0.15243936209909378, 0.23383695482005998, 27.60383894366603, 120.49050484934162, 82.69110987263342, 62.36852553582961, 39.406797962804, 96.14541222972255, 94.4262295384561, 37.09676511826054, 74.43966680957426, 18.52745475307588, 0.5791972205042839, 0.32595849145324, 0.19667914708054837, 0.3029447505551, 0.04541792861756779, 0.675150039455583, 2.1928515453492445, 2.3611369152222914, 3.1948592489765537, 9.356198233942832, 2.3751694396618874, 3.586299534766905, 5.337865314176006, 6.2473227324024325, 1.3923750986014645, 2.28674671342296, 0.1539738208896691, 0.026720217917294755, 0.15191705867407784, 0.3588702415506686, 0.09129661315631482, 0.17860972232395605, 0.5291976647511606, 0.41746662148544866, 0.20121976552951723, 0.2684872188875752, 0.836947012332178, 3.4251972504200476, 11.278290037185917, 25.6758527986465, 38.893924528552645, 45.764175538093816, 48.104281194748424, 58.64851044070337, 69.12351377548711, 77.88524935322424, 76.43077958014705, 82.51458752539851, 73.577161142903, 82.43111164339128, 68.14901659565588, 66.54373953419348, 33.49815130233765, 0.11183327769920712, 66.92401332239952, 71.99821103003718, 76.4911134781376, 76.3151559522075, 79.99510011365338, 79.67692529001545, 79.25993027225618, 80.14191442920317, 81.34059075386294, 86.97283191065635, 86.92457891279652, 88.84970172759026, 87.19395945149084, 86.7341007724885, 82.33673157230501, 68.19578693759057, 50.74805675014373, 27.981155264762144, 10.669499943333289, 2.2943418929653783, 0.7052383571863176, 0.17438758194686907, 0.4323058977963463, 1.8858100017232282, 2.080035108712412, 1.4946256505866207, 0.5099096239334153, 0.1640351447126558, 0.09019347718886792, 0.01778999993187045, 0.08914157718179688, 0.02474848763085902, 0.5089685615272291, 1.139495726073942, 0.7817994070149238, 1.11887447776333, 1.4941541081474674, 1.3519320300509854, 1.9938513203974695, 0.46792901691890537, 0.4516760325960575, 0.13418578512726292, 0.1549034992293004, 1.0104757331071361, 57.106865990546446, 48.466782723703695, 21.919334165511593, 95.87976578743228, 59.90689308412614, 30.96131132495019, 38.11797772684405, 59.95831143471503, 65.72155583289363, 3.8889900667052117, 0.1127978283611517, 0.11944131985787423, 0.006960880287337087, 0.017617584183631886, 0.06247235199196204, 0.019701557842293577, 0.034282905755624656, 0.07456159098975121, 0.016109086197590636, 0.07362748466191754, 0.02941033949384526, 0.03744432845363214, 0.018870758471049128, 0.08252175014105537, 0.019222758635277712, 0.07428090403517408, 0.0675926270383981, 0.037304758725147096, 0.0639607880504862, 0.043412053792346875, 0.045971649308358474, 0.040944549705713026, 0.024589941904489553, 0.025373500463883245, 0.051832612633945487, 0.03421123823030822, 0.03993491093898493, 0.042071013050454284, 0.06463456237989088, 0.051965226284078056, 0.10596576432186751, 0.13108043240443354, 0.1756585064914919, 0.20226645613870314, 0.1112399809062481, 0.12110353147070255, 0.19481637364914342, 0.20575877519384508, 0.1237357253088586, 0.20583815722455903, 0.1814122098468004, 0.15254425485768627, 0.16265033353720942, 0.13026588175806308, 0.2953059959315485, 0.07508188726440554, 0.15966818307436284, 0.13720622466456506, 0.2569676620224791, 0.25252939292019416, 0.1293760706340113, 0.3385383906143327, 0.2662545322410522, 0.15969881126957555, 0.18734897757249494, 0.1896776703576888, 0.18116021288498757, 0.10758001116975661, 0.14544019896176555, 0.10618823625507856, 0.15649864750523723, 0.10668715867664545, 0.2925891110733632, 0.21454270869012804, 0.21193071659053528, 0.12401612115002449, 0.1924662610455867, 0.36040064007524525, 40.39005379523001, 140.98619122659008, 93.76227424990748, 107.1594355183263, 59.38265654348559, 81.29274568250104, 121.44371924861785, 61.519312781672326, 58.55519333193379, 27.888555949734105, 0.2977806437880762, 0.45864467479048243, 0.7770852083640715, 2.1627282327221287, 1.414572526851008, 7.278385393081173, 7.631899791379129, 15.099395398170719, 16.578497655930057, 20.356589325012703, 23.147820503480975, 9.55138517964271, 17.094546248835904, 6.401273800480751, 2.1484189360372485, 2.8908780121034194, 0.17024376639916053, 0.35625261104395317, 0.2745270254390855, 0.7566837353571769, 1.491193699259912, 1.877713003946889, 0.8620675869526402, 0.6202310960619681, 0.5082398586936536, 0.4889281917243235, 1.1983262531218992, 4.002573571858868, 12.75081349957374, 29.75880872818732, 49.31530121834048, 58.287660229590635, 59.13879886750252, 69.02980835207048, 77.44408469046317, 82.88152525501867, 81.49346905369913, 86.9465990989439, 80.7733375795426, 88.10078005636893, 75.85722707932996, 72.14851625504033, 37.31984992181101, 0.9871756285429002, 75.77370412888067, 75.07037608854233, 78.72273029819613, 79.22209508957403, 83.35342561045002, 83.14091159451394, 83.1028881380635, 82.55120677332725, 83.3075652583953, 90.38430552328788, 92.97737659946566, 97.38351621935445, 92.94517394035094, 94.44857920369795, 89.4067253605012, 82.2191781382407, 60.605671175064586, 32.89750502955529, 12.925430555497448, 2.1544892941751788, 1.1178658157587051, 0.6614349818518085, 1.9572931143545338, 3.419389936231798, 3.3021240609307445, 2.46296483182138, 0.6679226434038532, 0.3090769473102785, 0.1501541524644821, 0.21722833716100265, 0.22335235209714985, 0.2014074877144829, 1.429489300616326, 1.9963787976772556, 0.6279899119850129, 0.7271105351467287, 1.6082082977218013, 4.117621346827477, 6.862308700238505, 2.5959971643263295, 1.281230204528378, 0.4248336906875334, 0.3182843129240698, 1.26904352297706, 53.48919337795627, 34.42701954995432, 49.188769478951734, 108.1142423998925, 52.20907295903852, 44.76686977571057, 55.49199873401273, 67.19570021475515, 86.41899324232533, 5.671297177191704, 0.4789002846565939, 0.2649656352737258, 0.17674486513339704, 0.1278017905931319, 0.17327295466055795, 0.09891203274169276, 0.0794168494101013, 0.23221261859420808, 0.18407154618011368, 0.1311675672449412, 0.15722934216741594, 0.2402962098318723, 0.11227550195349802, 0.1488035854192511, 0.2477792494239346, 0.15961912280369192, 0.22784182651629373, 0.14221173590950428, 0.21902738739886593, 0.12765086361116942, 0.21250799448499758, 0.13685123484221198, 0.1551780038543286, 0.2050205728700084, 0.10902502153429294, 0.1644723970563181, 0.2025727074473135, 0.11770855920809893, 0.14695915213275343, 0.13113932924405222, 0.165457907883871], [0.08763821390006812, 0.0660836176886674, 0.029284373571675633, 0.07956878762812385, 0.01909582552710368, 0.10680771793328947, 0.1506732076766991, 0.0215994602354664, 0.03192467453529037, 0.10488256962308962, 0.037254062856757836, 0.06250337089201616, 0.11602685065759767, 0.08295131862283715, 0.10192053662913461, 0.03651197263670545, 0.012922580823332313, 0.02991135525066526, 0.03347972385405052, 0.03860848332424799, 0.024227295033333283, 0.041284125839029594, 0.1597092147435873, 0.0762280926949555, 0.03035651553692597, 0.044301646581340226, 0.030235094431367134, 0.040479434744244626, 0.06113752422313537, 0.0437599458100815, 0.043457976932967865, 0.046320759405892704, 0.02856840886506102, 0.10564606050930678, 0.07097398591858727, 0.028820545637920022, 0.12676075371282716, 0.13979452932553907, 34.16924530459989, 93.90038090367472, 76.80865287780762, 65.13343957162672, 28.113935339835386, 44.51172351837159, 106.53733191951629, 50.17698318727555, 40.257850308572095, 41.653190351301625, 0.6951183357065724, 0.5595831633094819, 0.14349712419413752, 0.252974106960239, 0.16038234555913558, 2.1639186720694266, 2.1730624523855027, 2.8469008880276836, 3.4097335511638276, 1.7629020420774337, 2.8941504945678096, 4.007560375236696, 7.644987760051605, 0.686106016078303, 2.396618920949198, 0.4909891521017398, 0.6319725885987282, 0.16103024143845807, 0.7946812673922509, 0.10828407661568736, 0.3842054127204803, 0.5052835253938552, 0.7810569758857451, 2.887391515316502, 0.7115134753046498, 0.4743870768335558, 0.6361279107870594, 0.07528401956322693, 1.0541421319207838, 3.762888317146609, 11.675853633111524, 26.635821519359467, 39.98075446774883, 55.07902806805026, 65.3028271275182, 65.02892017364502, 67.80235751982659, 64.5076411001144, 69.45806841696464, 48.86757050791095, 52.902320508034, 7.915505786095896, 0.1843191764407581, 45.28805078998689, 65.05472152463852, 71.42923201284101, 72.20811274743849, 81.59483094369212, 84.14366552906652, 89.61022576978131, 92.60807760300176, 91.06471907707953, 88.2331600496846, 80.70557471244567, 82.23162774116763, 71.98927587078464, 68.00883108569731, 62.95151525928129, 47.14422618189166, 21.144413063603064, 5.489931193090254, 0.3776949217482921, 0.45802962876135306, 0.08612397216981457, 0.9297306787583136, 0.8251398813820655, 0.38817102089524275, 0.24056342129986133, 0.04055998122860347, 0.08858498366129014, 0.09204256828994521, 0.0212140241637826, 0.07637584807291146, 0.09131753501752693, 0.06810851064660857, 0.1331408871638198, 0.48695551531930126, 0.39379588358344575, 0.2603980658515807, 1.9146305971568631, 2.457882910966873, 0.3696725102922609, 0.06360235466291347, 0.2316419290558946, 0.4170281434011075, 2.776148929711311, 38.06782237945065, 20.5540257500064, 46.68567365215671, 98.74579460390153, 48.73184081046812, 43.91892394711895, 46.49180658401982, 53.96634578704835, 76.15289534291914, 7.684600266718096, 0.1785180982082121, 0.05872510185825729, 0.07401573036106364, 0.05192735855798087, 0.059302797270638336, 0.07860867261526086, 0.028364269415878003, 0.013869215561557683, 0.07920822834656124, 0.013246978839649069, 0.0640372436253294, 0.051385006611986514, 0.02464422689480407, 0.08397334886174049, 0.14188193505810154, 0.052898972550587314, 0.050095941105316726, 0.08114390270484072, 0.10780076706601728, 0.04028651848315232, 0.02772891056543637, 0.0324319415695725, 0.054298151705053546, 0.012200580301484274, 0.06652525971613585, 0.03531493727237948, 0.05837165570307163, 0.04989755880688468, 0.039312437687429695, 0.10405610630949659, 0.05286531064719443, 0.07320885591569447, 0.09071303801911493, 0.014939860782525955, 0.04337197973302776, 0.046793048780772, 0.009914088427209327, 0.10425178814799556, 0.037919053988110636, 0.07170510192912433, 0.08104501607557459, 0.009715158375911415, 0.10803473797897178, 0.02484897921432651, 0.05948034197752995, 0.15421834083334093, 0.017852076036374898, 0.05411039504613127, 0.058046692696910714, 0.12697189520563812, 0.09615698138311987, 0.03825862246054796, 0.03987761522312799, 0.013105542729458502, 0.05115256404444095, 0.057242212276304924, 0.056296040063663844, 0.020653305259803613, 0.07798898409331038, 0.08995786684775546, 0.044743487791668986, 0.010385664382709131, 0.06607705231515631, 0.023467504351790396, 0.07202420053222487, 0.021804074659162474, 0.06854296676934728, 0.009675495131241699, 0.16659711127079305, 0.06445261649787426, 43.643075420010476, 109.64095438680341, 79.91798631606564, 58.20220747301656, 29.33585955250648, 89.81898215509231, 108.00140365477532, 31.755075493166526, 77.21817970275879, 42.55061687961702, 1.057470263011994, 0.497151532721135, 0.17094504328504687, 0.3082345570287397, 0.34959092495902894, 0.5261732722001692, 0.6079725861068696, 3.156055976306239, 4.278500301222648, 6.6096506964775825, 1.8702951890807, 2.74713049973211, 9.588103467418302, 4.177015346865501, 1.3450134593632914, 1.0297987994647797, 1.2222350605072514, 0.848133918498793, 1.1114760295998667, 0.3089697869314302, 0.4024775596635957, 0.2658068304581027, 2.3351369942388227, 1.662316413656358, 0.6358407197460052, 0.6519885048750909, 1.1418240204934151, 0.2287959430607096, 0.8202648655541482, 4.812447649817313, 16.81252391107621, 40.56512878787133, 57.21066759478662, 69.74819044913016, 77.01087459441155, 70.89566415356052, 76.9338627784483, 73.2658112433649, 78.00561904907227, 58.603665982523275, 69.65617948962797, 10.351432004282552, 0.08011229636688387, 54.950695960752434, 80.21673756261026, 79.73546274246709, 81.61348573623165, 89.49774788271996, 89.02095240931358, 95.02868990744315, 96.18558514502742, 96.7551838967108, 94.1115064005698, 86.76985709897934, 89.5860404352988, 84.59451844615322, 82.16471210602792, 71.4071726029919, 52.071931208333666, 28.193945807795373, 8.500126234946713, 0.7172457741633539, 0.7841568127755196, 1.224635428478641, 1.3123819135850476, 0.7092435261414898, 0.2757697732698533, 0.17386992101467427, 0.10296669863765279, 0.07512673405149291, 0.11043810135414524, 0.018056874321172797, 0.0495359653066243, 0.09507805379408021, 0.10920480704836308, 0.19477440735265134, 1.8388336127804172, 0.27663162218466886, 1.7406809570327884, 1.8775965585823984, 0.8077350991868204, 0.3568821208130929, 0.16920547211362472, 0.3086791025294412, 0.5571120701009228, 3.6209674035349204, 65.47037509179884, 37.09122673157723, 17.203727383767408, 95.36923793054397, 71.8698553885183, 42.91770365930373, 41.134456896012836, 53.947400739116055, 85.2056158742597, 11.475908852392628, 0.37340256175206554, 0.12878895617060124, 0.1100588342054717, 0.010213534002222363, 0.1554187393236545, 0.03128075082185528, 0.07866631307068371, 0.05940456439049975, 0.07535615440217719, 0.00953821409043045, 0.03146439358862418, 0.022107951095207565, 0.039247484922769575, 0.012393805870576011, 0.011557619943613968, 0.027954896927000056, 0.0748018974498395, 0.0961686029369312, 0.05645517950817462, 0.08462070081863673, 0.03841855097562075, 0.018755174955473315, 0.07935609097682661, 0.021295706373489192, 0.020064961225275072, 0.07505246182723392, 0.05250161040514227, 0.014723762700844918, 0.044821207411587245, 0.06099097160322051, 0.03794647227492064, 0.04739476104957923, 0.19889905538049438, 0.0959190421347176, 0.09458006599978094, 0.16919638631084274, 0.09416195819334638, 0.1788636038620626, 0.19557198149061975, 0.3335682266662198, 0.19518651669063877, 0.2817204991175283, 0.195306608633649, 0.09794340649199101, 0.2138360998322887, 0.2261469642361326, 0.17200638149534503, 0.2214651711044773, 0.19612601627745938, 0.3152316670504309, 0.1858937782385657, 0.15105326389593465, 0.22643545762665812, 0.10304754389630211, 0.2011234223121597, 0.20120747747921175, 0.16585449628051252, 0.11109145944036784, 0.18010128019077165, 0.1639355992477748, 0.19049925369120416, 0.1348769190090318, 0.1950573389448466, 0.127493187394594, 0.1440479414116952, 0.18819224119426745, 0.17610836864238785, 0.16885936891119327, 0.2865882830754403, 0.3043408998318257, 58.52744256296466, 127.27448724931287, 96.25431291518673, 97.86923116253269, 40.18690639926542, 68.6356258392334, 127.37354278564455, 67.52777591828378, 63.963604434843994, 61.14893905578121, 0.8548659927422001, 1.1052660595986152, 0.33490311955252006, 0.8434273807271835, 1.3970743432160349, 4.285494377536159, 10.103084195044733, 12.876115575913461, 11.791980305025655, 10.307530876128904, 14.931400283690422, 15.187221188699047, 19.376844013890913, 6.912629767771691, 7.427709535244973, 1.459706995275713, 2.1797182242716513, 1.6748326968762184, 4.856494886259879, 0.7593236743442474, 1.4000575508802169, 1.074522767336138, 4.674081629322422, 5.987367649232188, 2.2337052370271375, 1.4071520153553256, 1.0526707528098938, 0.1641126574888345, 1.160148108197797, 6.206777682227473, 22.051665129200106, 53.21770652647942, 76.31804281665434, 81.79508363046955, 86.10962806209442, 78.78718268486762, 80.97862658962127, 74.93685076313635, 85.23410012645107, 68.90044073904716, 83.68239479680216, 13.55062007904053, 0.31206695783522825, 65.1304115018537, 83.02786104140743, 84.553176664537, 80.86253227726107, 89.84039045149281, 90.60162836505522, 97.51810058470696, 97.20359709955032, 96.45426750183107, 96.91049406605383, 91.89273926519579, 97.4463604342553, 95.83774935814643, 96.17974865821101, 79.21676066613968, 52.42317553489439, 28.82960315673582, 8.807342936915736, 0.796904209400377, 1.1222754178508636, 1.5781037389270722, 2.8093216399992667, 1.6223957557832043, 1.01094666267595, 0.3898030026785789, 0.12123292372111352, 0.21458727968556268, 0.17520426231766903, 0.16693248924228454, 0.32597700013749065, 0.20828796851058162, 0.3740347375071818, 0.2647341541465252, 2.801142272449309, 1.8291463390473397, 1.6743803985657233, 5.3184049648623315, 11.968873316241849, 2.1564798970376295, 0.4807275575735877, 0.500740715933423, 0.8631373521301055, 4.38483085363142, 56.5019541402017, 28.697662468879457, 56.867291542791556, 113.7088837162141, 68.14937745371174, 52.02490983470794, 65.1511686848056, 64.58518243605091, 102.3834320806688, 17.11226555608934, 0.6940983968877024, 0.22178967062744404, 0.14991539350200087, 0.12965635156198857, 0.2671201809519722, 0.23625705721637896, 0.25838307074962125, 0.17481878219592958, 0.19477192522777667, 0.12484888936723433, 0.12353990557453326, 0.126394402806557, 0.10801059088759846, 0.13433705684879135, 0.14305417215631855, 0.1228314504447964, 0.15552407641324306, 0.16968559473752978, 0.18701805823272277, 0.23078107605538062, 0.09507862836002343, 0.13928239954815758, 0.22172121301053033, 0.13145350190179964, 0.15639329509389016, 0.16719193257872136, 0.1869019652686773, 0.10101715042706459, 0.19428224182657658, 0.09954894292018107, 0.12184400141479508, 0.16422894963574025], [0.04652502909002285, 0.07052609261365668, 0.07240794163437621, 0.03084762960732464, 0.039744277619906974, 0.0013383462670214115, 0.07131641955986139, 0.08460486578124185, 0.13043573877263454, 0.06302398126271945, 0.11361350515677084, 0.14223212917004863, 0.17216203523980034, 0.04825717686945873, 0.08943456750843795, 0.04114652112607033, 0.021658138740026665, 0.04979126027695114, 0.05259987650318973, 0.06976803329082266, 0.03125829103913519, 0.04887729823108643, 0.0409063334096103, 0.03908941417091316, 0.020774285864805984, 0.04255708051665176, 0.04122820908143636, 0.06839386307664456, 0.02568456855031752, 0.03153100684886018, 0.1128656271424505, 0.03144422632401749, 0.0645437196738297, 0.05244658613998083, 0.12429721413120148, 0.025642489255856604, 0.060911658520419756, 0.0367493181669664, 0.09041029539319778, 34.014562714484434, 98.12637390628939, 68.44423770904541, 68.49172976709181, 35.7532121289161, 24.6245732615071, 88.64688381072014, 44.33951185595605, 28.68092767653927, 47.24911428266957, 4.759223047764071, 0.4826645036378215, 0.17773679577775542, 0.2040935605163536, 0.3778425928565764, 0.2845846567182772, 1.758857955855708, 4.632453514683632, 2.4889789713967234, 0.4182395429140137, 2.1140074922192484, 8.857120756180056, 4.289673662954762, 0.5866257606014129, 2.337019241625263, 1.1613373218044158, 1.8993832411304599, 0.30858809128403664, 0.25413595590620275, 0.3563067581384413, 0.21879844968357395, 0.5027956701815128, 0.07111981075497405, 0.10465304202009594, 0.2831973021309222, 0.9618679446078117, 0.662850528474777, 1.2524037255394844, 1.3014921882460195, 0.6861973337588773, 5.049782914500083, 20.86118655820047, 45.39097378330846, 68.57126758944604, 72.87558247966152, 61.79499264686339, 63.60952815701885, 51.67268491560414, 32.25260461530378, 9.96688675495886, 0.030361916456792145, 0.16595814797666766, 18.003549652714884, 47.91880799878029, 68.87968355609526, 76.4625507785428, 86.71183739939045, 86.08635271749189, 87.29370532497283, 86.22315714436193, 92.23981411226335, 93.1470661778604, 87.11539437693935, 69.6076205468947, 46.13324311471755, 19.945028751127182, 8.404946980937835, 1.6111466432771377, 3.7998375344660977, 1.1116976435146024, 0.28546541268306397, 0.43974819683259536, 0.05864465879576822, 0.16133739673081907, 0.11088433224828013, 0.052544955659898064, 0.05206947552881414, 0.030944357783864104, 0.0928057604018719, 0.04727644643055336, 0.015884510395417533, 0.035457368339261705, 0.06748550496394597, 0.13685446773325244, 0.3931834728967759, 2.2887682049505176, 0.6719046458601953, 2.62756954758398, 1.3283620173892667, 0.19929061824035263, 0.5216737620292172, 0.09861843720559152, 0.225276121449086, 8.146935432187973, 43.47931646531628, 21.860049501542125, 55.24963155869515, 110.7960061104067, 50.6575676702684, 40.64880078838718, 51.20818215031778, 58.10539161005328, 70.07648498781266, 14.097930942812274, 0.19480238488364607, 0.12319209399603068, 0.09285668226619882, 0.02665926604681919, 0.09683702231174517, 0.07773487272882655, 0.034069412372886174, 0.012981019925416238, 0.029490755743256984, 0.03592873840863186, 0.12602190787513412, 0.005343496788202996, 0.03303749193888038, 0.07413847296829186, 0.01438630480063899, 0.06058574556523274, 0.02764046379935838, 0.1117377925003248, 0.04404887587072388, 0.0708104491293911, 0.05168360087179369, 0.01029033623185129, 0.03953631156154218, 0.06344334545334981, 0.02841392148947043, 0.04330058416892444, 0.04636759419114359, 0.02855627977799985, 0.04921954801125873, 0.10936444445002465, 0.11420944495306862, 0.15033752327003788, 0.05219508713531879, 0.01564597742887394, 0.07714341454688581, 0.031119033491479296, 0.03703897601113685, 0.035367073386066386, 0.06253661910792993, 0.12734362404913674, 0.03980285270259746, 0.08570373463895052, 0.041328842391169844, 0.19271640407462276, 0.19293996385268627, 0.08876083914430873, 0.15322565942281677, 0.04809514544303379, 0.09716849323482284, 0.057869102024743636, 0.024545188963172898, 0.023097367055954474, 0.045315786114623474, 0.04501677050645794, 0.044085732360761014, 0.025640279092195056, 0.029927406707898747, 0.040041964065523884, 0.03746135475774927, 0.02518601002051465, 0.03537846894394006, 0.08831523644227175, 0.02652296751377083, 0.02590556576427433, 0.044978596345191045, 0.02954521501857427, 0.09222358720557344, 0.026108793568827456, 0.013855522697521074, 0.008963857863789365, 0.006370101529624194, 0.04801910738610933, 47.21808833460654, 111.98088353680028, 68.3415186789728, 49.20615342355544, 28.737370583318896, 64.2278152896512, 112.97488274112825, 31.55884127463064, 69.95676640541323, 66.2928568932318, 4.694717218798976, 0.3673986387589286, 0.12295755617801221, 0.3651389551739539, 0.41867918545199984, 0.40386598677404467, 0.7398151534218943, 0.7376446118277888, 2.8408898557386095, 3.163164536799154, 3.9906544694977426, 5.566024684136914, 2.867132228228354, 4.718248007758971, 5.047708961271471, 1.9962030264639088, 1.9656611233949663, 0.8442280345386075, 0.2485436979200571, 0.47543257234557984, 0.5837841872726718, 0.4805140948343662, 0.3323135278638332, 0.07434304142671247, 0.4435713739404756, 1.5931942001465829, 0.8962702258459984, 2.220275531853399, 1.543446411528895, 1.541703653431708, 7.230408432022219, 25.750030702160252, 52.911640059563425, 77.2462324942312, 84.13078446542063, 76.75397503760554, 80.99586148415843, 67.39167751804476, 41.29025343925723, 11.84337119902334, 0.20960496558297068, 0.8165953043968448, 26.58446788787842, 65.39860748475598, 76.71815595319195, 84.85983540934902, 93.94428791538363, 91.12363307706772, 91.52446792971705, 89.26134663243448, 97.5049763341104, 96.73537592734061, 93.86520508796939, 85.78049413619503, 68.48622275936988, 36.94690704345703, 14.936023777531041, 5.570712897085375, 5.62561676386864, 1.0533341236652867, 0.22414319998314305, 0.9643566884821462, 0.33035307822208254, 0.2542028353819924, 0.20867986844912653, 0.01839014172043291, 0.06370603317214597, 0.045772259604306, 0.08210702078236688, 0.09784548513350949, 0.03252047835098159, 0.12720084824268857, 0.059839422709398696, 0.17271427738089717, 0.21213774419119283, 2.600929544818017, 1.4303109145933584, 0.7698888848385503, 0.7459306801038404, 0.2959897447257273, 0.4097664266103699, 0.14353285453492595, 0.35249589972438355, 11.019209642564098, 74.32638875899777, 33.8869248667071, 25.70093635589846, 105.88086051325645, 76.46452765310966, 41.070239851551676, 44.43455872997161, 55.78513706884077, 81.48734231148997, 18.07434255076993, 0.43307587744728215, 0.017291803378611803, 0.03308158795980196, 0.10135026843917948, 0.031694424894428065, 0.05735204630200902, 0.08800585949493032, 0.03546700955578878, 0.039315563326160756, 0.02172718049898263, 0.11150317041263466, 0.02099560100525137, 0.10963911761439617, 0.06870676402843769, 0.03339497537742699, 0.053513761940262014, 0.029636410125080618, 0.016219297521597436, 0.06371107020024812, 0.04814731603067729, 0.06791400092263376, 0.037002406804071325, 0.0632755185717777, 0.0645187528683774, 0.047234709960438555, 0.0242189580814973, 0.03380038144607698, 0.004622674605343491, 0.01467332347191029, 0.04152918204424843, 0.05505393574675245, 0.13162064696511916, 0.05910893106051992, 0.1440341977943336, 0.12865089180488742, 0.19619713988034956, 0.12443651189847339, 0.14501397828421286, 0.177703179839638, 0.2197961566308814, 0.21098502701328647, 0.3150751706092589, 0.17632685691839264, 0.22811455381733758, 0.20070354484262007, 0.4097957830996283, 0.20464981695817364, 0.23793048435641875, 0.23769393172715944, 0.166516243029506, 0.11593150335454172, 0.15020053142741804, 0.129986489492078, 0.14904968350404693, 0.18095868579562635, 0.14153333440903695, 0.13413252669476694, 0.16798587545992869, 0.14775713995820092, 0.14514376890034447, 0.13876665383577347, 0.17978444154704773, 0.11017921726189314, 0.1726604980086127, 0.13668473329274886, 0.12125465763552536, 0.1952782787022091, 0.2005056643317784, 0.21092089013226573, 0.11863977738445806, 0.1968955669191576, 0.2279225721835129, 64.415602684021, 128.58950891802388, 91.23695819608628, 95.08632521475516, 46.47164167896394, 45.853727171497965, 116.39171431141516, 59.49684850631222, 49.12957306831114, 75.71949697309925, 7.791539276799849, 0.6429399033227275, 0.32293063618483087, 0.643302416128497, 1.6690041773742246, 1.4624000701212114, 3.9333197138001843, 12.65032825931426, 11.78795595322886, 8.896452323082956, 13.592813995576675, 24.815777040296986, 17.43755752040494, 9.888320699814829, 7.307358470655258, 4.153921902179718, 4.217680029330715, 0.428018685910971, 0.4147455997524723, 1.5969263353655416, 1.0878009709619707, 1.4237215778520032, 0.6086579590074478, 0.35265665561441456, 0.8856964964539775, 3.958478286381691, 1.871398233117596, 3.4726164994701265, 1.4417956144578996, 2.2258935916808347, 8.581846856301832, 28.944903189136138, 59.54123796955232, 80.3795551484631, 87.3042800349574, 83.67043156777659, 93.02082077149423, 77.65222918602728, 53.64846906354351, 16.84318703989829, 0.8351824973379413, 1.2503420297176608, 35.644017265688994, 77.57178921853343, 79.91785295547979, 88.01122450059461, 96.84513168950235, 92.61712258861911, 92.50377393537953, 89.9204852504115, 98.83569532825102, 101.53070096046694, 102.11086657739456, 91.23286324162638, 71.90258364523612, 32.589944139603645, 9.802887555091612, 3.7618072138678644, 5.842030596348548, 3.019500129645871, 0.497382584839098, 1.422988217203848, 0.6057307064052552, 0.4446790451484342, 0.33277688848395504, 0.1311254936961397, 0.1871887732657694, 0.1427468483246142, 0.2599372179998506, 0.1987818132845625, 0.08173025874120575, 0.2773491401345499, 0.24793652727478938, 0.31511660064420394, 0.6266310558684411, 5.286247413004599, 6.610375354366918, 11.1576202800197, 5.506881225493647, 1.9013694313264664, 1.112561668119123, 0.37788524863220035, 0.46184958829995126, 13.115315437316896, 68.04574843375914, 30.685804044046712, 67.15827295857092, 129.07959338157409, 68.84500195903163, 51.13610075366113, 68.6806546488116, 66.60106889663204, 96.91612658962127, 27.053226424801736, 0.610004557717231, 0.23267093835578812, 0.19753715023398402, 0.15933635975083998, 0.23151206183097056, 0.36202067088696266, 0.2647707425057888, 0.09123461366060281, 0.29641948940773166, 0.10850546836492517, 0.19931645072515936, 0.1448923541653541, 0.16986073775877877, 0.17906102472014968, 0.16279038973152637, 0.16692511947645297, 0.1526106746807214, 0.2352211837686839, 0.18583754738492353, 0.14341594951768077, 0.060459613018939574, 0.1066509073960685, 0.20787638011238269, 0.2053539743346553, 0.1840637474050445, 0.12734511025970982, 0.10888776922177885, 0.1797730728022514, 0.15930478160660114, 0.1497181565050156, 0.2293948552781536, 0.22021562041294193, 0.14633773225209407], [0.22482333284231926, 0.07769574861853354, 0.020958907308898145, 0.048614392177231854, 0.05623713556316592, 0.012999891543820983, 0.0724784906713232, 0.03331405350998525, 0.00831098624339868, 0.060134305273212736, 0.04538684460004011, 0.07106980053527702, 0.030929014957960577, 0.03751349853231542, 0.03281527281468434, 0.035578785614380916, 0.018828035662731817, 0.08392763639529867, 0.01682013070451156, 0.0818574982845495, 0.02947719407177741, 0.0164849940507162, 0.1321949984037107, 0.039109853396732966, 0.10783788402594867, 0.06274027592172066, 0.023087231712716243, 0.044729253878035856, 0.041002366361358476, 0.00953549735112897, 0.017152262378423926, 0.06782544881946619, 0.036054231271508246, 0.039447330449137, 0.009481216191254076, 0.040154636446987434, 0.03949256411062614, 0.08664871175442973, 0.05445047679747786, 0.25916095642793563, 48.77714810832855, 105.63539074313258, 68.73926270392634, 77.8849277188701, 51.11016996445195, 35.03908188112321, 82.68972919833276, 49.829347441273356, 20.74198768984887, 42.90389691629718, 13.19041019485843, 0.42156093243149023, 0.24673530140951758, 0.10970225092023612, 0.1922307502959044, 0.37324689268585176, 1.1635706213212784, 2.965693791066447, 0.6572866463853467, 1.1559087614859305, 3.874076725013795, 2.2323086280976576, 1.453703930301051, 2.2856550687743775, 2.0857713299412883, 0.4974107462311945, 0.3887289474087377, 0.1430705204726227, 0.18310431421043413, 0.034798371845916394, 0.08141404828957974, 0.0726444866027563, 0.10805941367101286, 0.022450991861161687, 0.0631266868402881, 0.06495168447614678, 0.10906273604280527, 0.3963879267534902, 0.7866576301955408, 0.9829025739623655, 0.5949208993584879, 2.658762931823731, 7.719416204960116, 18.676500897253714, 11.026240491097974, 5.084718975328631, 3.0417676702622445, 0.24619874874911002, 0.1864105964740438, 0.11748471597750341, 0.06260506140308515, 5.308825066012721, 24.11974264729408, 62.7325410996714, 85.13852765483242, 95.67155068920505, 102.51304288064281, 105.03226357121622, 101.68503838200724, 86.87048942812028, 62.925792355691236, 41.175355449799575, 22.175080545486946, 8.35179494273278, 1.0502608240612092, 0.08443772837880158, 0.5439118235822648, 2.6367402941949907, 0.13559721019719878, 0.14815734428984506, 0.048606712145790945, 0.02881713271621735, 0.03882628595156055, 0.08113274080378395, 0.034600805431123705, 0.02253463525595444, 0.04621418125386681, 0.015068931276008729, 0.09539093176323561, 0.02220757891454043, 0.10766186766446599, 0.07465062572831109, 0.09719585789547813, 0.07321605714218271, 0.586809805564342, 0.4075531985971236, 2.185701554821384, 0.4821351981691776, 0.22268607010764463, 0.26853407282502423, 0.08070802165856285, 18.141987746761693, 36.05416774749756, 21.040611459362893, 64.21981365449967, 96.42923493539134, 47.023291664738814, 28.422600376990538, 31.927042007446293, 53.93806549810595, 68.8436605084327, 11.330845875124778, 0.18810794087907962, 0.024021834082480882, 0.0485307315454608, 0.04409390268847347, 0.026718940465681018, 0.030638171592727307, 0.07841621600692311, 0.10830100715881395, 0.04071947690399905, 0.07107956049543235, 0.030950884852978974, 0.07282210408800072, 0.028603549318147764, 0.068491087295115, 0.038118378574689554, 0.01147831547930236, 0.04071112271518477, 0.05461556491472068, 0.006382287594474733, 0.038807505306096814, 0.0159170959452768, 0.07817535030265009, 0.047619401011616, 0.053760656756499124, 0.02286972402925453, 0.013579822017721111, 0.007761713171813398, 0.10194443091149293, 0.03859879614244546, 0.04319636556770533, 0.06387950612172004, 0.07116399104556731, 0.0995639122782215, 0.03913248363401621, 0.07149033684043155, 0.06486747609150988, 0.04194016523298718, 0.0687553416637163, 0.027406349244918075, 0.02532566976433079, 0.030716756891999996, 0.04551501494021185, 0.03956223214646021, 0.048474270865441337, 0.07513567429756926, 0.06741160046189063, 0.05483209966651855, 0.03266036983639483, 0.02850896618779629, 0.020477986038332025, 0.0222129070560538, 0.08840159753397589, 0.035928152351369785, 0.024289524355422587, 0.008335142910871054, 0.09359906743010206, 0.1324524652333029, 0.024178711652395227, 0.11274860721201667, 0.03988213897232087, 0.03729249748791899, 0.054844889504414414, 0.017781833434597622, 0.03134912799953694, 0.02653637788288536, 0.05163618385972035, 0.06081404359710794, 0.06970522940279016, 0.05454215070893688, 0.03850000144373025, 0.09410965737075576, 0.04824088600974891, 0.06677528783198326, 0.6369659496891884, 65.21405996814852, 120.73293870495213, 68.53365990423387, 57.29311189343853, 31.35377583965179, 49.25845038506293, 97.15709347878733, 25.461414860140895, 47.14917229067895, 71.40357186717372, 12.704547182206186, 0.6283121592094821, 0.23429122963739982, 0.03000291233371583, 0.14316297196332486, 0.24543886613701624, 0.6224969389938539, 0.8659524494601835, 0.5892235341091311, 2.927528148697269, 1.2548219893247852, 3.378351402859534, 1.8863726166948196, 3.8132564531218622, 2.495208675822904, 1.7742380595976308, 0.43148667401363777, 0.03928760494736414, 0.36884764810242965, 0.08558758804875036, 0.05125729975500896, 0.05186327913355443, 0.03915423287018653, 0.07677956108724879, 0.1399518531416693, 0.08983822689662058, 0.21636771398686597, 0.435449279123737, 0.6880305515181634, 1.524060096952223, 1.2081505646628719, 3.0879410764863415, 8.607064754732194, 23.286486094997777, 13.399447029636754, 6.047754989516351, 2.959749684218438, 0.03559034971159793, 0.15686289166971562, 0.16598011937833604, 0.1403021851494428, 7.328233324712323, 40.77733685893398, 77.77274793194186, 94.81620727046844, 99.95669303401824, 106.63021364519673, 107.98675752455189, 111.6525968428581, 99.24772462537213, 79.6899083352858, 55.97947874376851, 33.27116766283589, 12.549850863795127, 2.0264365331780527, 0.42321506947759663, 0.7382688202684926, 5.1980387010881985, 1.6794088771266324, 0.5036540870224276, 0.12986668866247902, 0.09062168969502372, 0.056431825317802935, 0.06390485214069486, 0.04795808082206115, 0.05803466511649951, 0.02153448257294874, 0.039697741608946555, 0.03933435163250373, 0.022849305870852644, 0.05839849942393842, 0.02692350700888182, 0.050604665621874795, 0.08863304035678025, 1.7865405736431, 0.6927452404652873, 0.9634971378311035, 0.1326942579039643, 0.33699257840071956, 0.28996259394672613, 0.06975703992910924, 21.564828388152584, 65.5946240117473, 28.057055088781542, 32.47269076685752, 99.68155445591097, 64.39575156857892, 27.5473960368864, 30.041162506226573, 55.668489702286266, 81.33047888355871, 18.422274435720137, 0.2920864041774504, 0.03636115673749197, 0.06625400330390661, 0.027101655010013815, 0.01702612791691096, 0.01128602549508815, 0.055467266994979114, 0.06619920503468284, 0.08711467707349409, 0.0543106351077797, 0.0724889784150066, 0.07599958398890111, 0.02881868404426402, 0.04835776038347714, 0.027963929103627324, 0.04277766404312946, 0.01612433134728382, 0.040206485277702736, 0.08770198305888523, 0.06233739028234155, 0.05538092888591271, 0.029418375756170963, 0.009938338940452424, 0.017257417522130475, 0.03459253168154148, 0.07367232378812567, 0.11705572206166484, 0.044923978106629466, 0.06225135094756561, 0.032340141253605965, 0.060265156921119466, 0.07556718098179949, 0.04814933084191815, 0.06315705839604621, 0.3315767964288112, 0.2011249391662498, 0.09857593464755243, 0.1573179785402552, 0.268963388497791, 0.14422231834501992, 0.30549343314863026, 0.07688354220121138, 0.11631129144300377, 0.14027163356302247, 0.14237181764216195, 0.11831949134507488, 0.2637315289147439, 0.13149723020051757, 0.10923361195431602, 0.17773526360190686, 0.08847504238327665, 0.15430097107685384, 0.1266732588109951, 0.2147978619341889, 0.15817565993676264, 0.16723855668979307, 0.25108753883790585, 0.10910687036812307, 0.35545088470943514, 0.13993040267978946, 0.1233572012654716, 0.14146251724131648, 0.08194046560674906, 0.20125344275466858, 0.10483641282565172, 0.20450894871065695, 0.10583948238842911, 0.14684281402057217, 0.1830279965314173, 0.1451311590931108, 0.14996615448786368, 0.33913045400573366, 0.17955164274861737, 0.6349059699043151, 79.28741824242377, 135.4753552713702, 87.71368134406306, 101.02145964099516, 73.89629302486297, 51.706421221456225, 112.53457315506475, 63.66664571146812, 34.314070978472316, 74.64606977278187, 23.820734485503166, 0.38592825253163615, 0.19583730838231503, 0.2177223106545787, 0.37646133632909873, 1.806223885186257, 2.8356500594846668, 6.809863669257011, 9.106209893380443, 8.94812660832559, 11.760361098474073, 11.148791024761817, 8.640441183120974, 10.787740772770299, 5.940637511591758, 1.8707183147630386, 0.7322692486547655, 0.32585837908329507, 2.0396701198431755, 0.2670645936121864, 0.4072613497414897, 0.21853203494702617, 0.17858255684616106, 0.1872271083055004, 0.3045607670660942, 0.16137427620349393, 0.39923955115579796, 0.9161556620270976, 1.10411950176762, 2.0484825824537585, 2.108085203555323, 4.10081301004656, 10.19897633983243, 29.095835993366858, 18.752718433257073, 10.736892146448936, 5.788924155696746, 0.3776156163263706, 0.7445910068288927, 0.24172663388233034, 0.16288539995589565, 9.381769145688704, 61.09555167536582, 85.55313787152691, 94.73173510643744, 101.38062323293379, 107.60769182635893, 106.92600742463144, 111.68654887906968, 97.95624502243535, 75.55941720162669, 52.2339839320029, 27.419156105287616, 9.99291560342235, 1.0712626648526038, 0.25505357602190587, 1.3321987082881313, 16.909977159192486, 2.251718722043499, 0.49482440275530665, 0.16622057905600918, 0.18714743516137525, 0.17288742857354303, 0.22896446708229282, 0.16073905141843906, 0.1559534227295268, 0.09443031879322183, 0.18843112273081658, 0.16665524202248744, 0.10546760032734565, 0.1843611274154917, 0.13470041235127758, 0.19778680296674853, 0.19383961154568582, 1.9713713589214512, 2.668780174947554, 5.521942636659069, 1.4505683630704882, 0.7308611177629041, 0.33895483600997156, 0.17650524815244062, 25.169472848215413, 56.813398176623934, 28.96546425357942, 78.05525272123276, 115.64257298746418, 65.29129143684142, 37.58542183906802, 47.398391846687566, 67.97836211419875, 96.7269898999122, 28.65985082041833, 0.39742876445093467, 0.11534442719552787, 0.1260681336204852, 0.09168160298178274, 0.14764795710723247, 0.11930769880212123, 0.18890537712122166, 0.17316813851075788, 0.17951450280604825, 0.16713064554477894, 0.19709637388587, 0.17606364442936837, 0.10297543970086884, 0.16437773923239402, 0.21412957279432207, 0.18759063234732998, 0.10311913481282611, 0.16962530361788888, 0.27196914979046394, 0.16850964977375923, 0.2007545050113432, 0.19534045439814368, 0.1719119688195567, 0.11709722104452311, 0.0867995621275998, 0.15753945455916468, 0.2302361730365984, 0.22497933898721972, 0.1161148205339428, 0.20646235034350427, 0.19416483119130137, 0.10243269705003309, 0.1665180203534903, 0.15409637963579548], [0.0774002378626216, 0.08824978189002122, 0.02695792159366031, 0.06466945768484185, 0.07370420070665498, 0.052485231445321155, 0.004621321023742278, 0.005769794553353061, 0.09291148819630185, 0.00820405186048799, 0.037476427537659486, 0.03177432020405128, 0.0605494789628973, 0.03285883640449855, 0.035540672740147966, 0.06753427412120566, 0.06297631910251034, 0.03749205956175443, 0.09051053033721063, 0.04825288677708276, 0.03611757908196699, 0.03906289603741419, 0.10173580984795287, 0.10961791996153132, 0.062259624697147846, 0.09001137808926644, 0.061295361318174875, 0.06611468255399697, 0.03957588766371051, 0.02586204813973558, 0.022775736532264182, 0.04307012193866315, 0.07055463704971537, 0.02133937146995337, 0.08367011593955179, 0.0645325501118937, 0.13511704160801827, 0.12688587119262065, 0.05644618563594357, 0.06211296865536321, 0.8573191288498141, 43.28558275776525, 90.07563852494764, 70.95471151413457, 73.13952661329701, 69.02373652304374, 29.356740290118804, 106.09104464131018, 75.73433922183129, 26.97344541549683, 44.7885565603933, 27.19812466252235, 1.5673712761171403, 0.7522776266259532, 0.06213733791223457, 0.16168667153725702, 0.36738708615303045, 0.18398051961295067, 1.0497476064389752, 2.106940361761278, 0.6460826411362618, 1.4654472614488294, 1.7098647331999195, 5.752643702491637, 1.1221725782079082, 0.9372017520569986, 0.3826335841609586, 0.26702175397546063, 0.061738282712476875, 0.11119046864370186, 0.3619513246080568, 0.04521405346871865, 0.02856111379280206, 0.024135082945107453, 0.14782909093604935, 0.11021457988047793, 0.07488474985885044, 0.06595070909468398, 0.03309667223103104, 0.22008846513926986, 0.7615450228894911, 0.932721057005467, 0.9284869196914858, 0.8363479315753907, 0.9113556002416919, 0.07325585540984908, 0.7978672738517485, 0.4146792565382296, 0.40299151273023703, 0.2721120711536177, 0.1197257912867973, 0.1675513503892768, 3.6787230785815948, 30.23629846111421, 66.5402094010384, 73.47868611735683, 76.06901937915434, 54.49380259360037, 32.5167997806303, 16.256193557093223, 4.252511166757153, 0.8677805803956524, 0.4981167422186944, 0.608910093865087, 0.3503314868336724, 1.2226373485980497, 0.9121658148304109, 2.3473583642513525, 0.2089504353822239, 0.2343132623261021, 0.04714797731609114, 0.11358437083301046, 0.04311961504901129, 0.04091946032619284, 0.020896574564939065, 0.07841249281961112, 0.04057504251719483, 0.05287755656266405, 0.04491183944346924, 0.05811060358199382, 0.0560635821743598, 0.06619201146907384, 0.12117419542083818, 0.056273946087927594, 1.3616237164505067, 0.10478362936766879, 0.5253327205296486, 0.08704359177500011, 0.41052583424795064, 0.8887935754272246, 33.16470276924872, 52.20236178367369, 31.0239201976407, 71.84366964524793, 93.14767022286692, 41.876110415304865, 26.52410653329665, 49.19129548534271, 66.12351248341223, 74.26544297126033, 17.83907094309407, 0.19177053063627214, 0.024206001619477908, 0.08916704194439996, 0.0273171000017394, 0.0911292152839803, 0.08052391540859977, 0.04047689899321526, 0.053137183760202704, 0.033175445221845186, 0.07106890421240561, 0.030996662436894355, 0.08189883638894366, 0.06600740726195997, 0.02334683975805679, 0.0027421348767670533, 0.05244808384187279, 0.033340943196127494, 0.030243318385234287, 0.02146829640673053, 0.04884952754383126, 0.08333427831530572, 0.02597128270163892, 0.03399887482725805, 0.0631351521118514, 0.07105734394562822, 0.011470178667936596, 0.08240884410277491, 0.025776734673267892, 0.03611482882631883, 0.05111476143581733, 0.04666420045278726, 0.05377504005727749, 0.07107880972926656, 0.020901105975011186, 0.0819244007429769, 0.021155458657191168, 0.07259660610748876, 0.03866618123626517, 0.10298125430821412, 0.03671872827614989, 0.0775717496271095, 0.023171802073897376, 0.012113471316444057, 0.048437092618476, 0.05414365858380353, 0.014281738587024232, 0.0349715996473547, 0.05783574655652047, 0.08344810365909532, 0.059264515857062036, 0.008344587817367527, 0.07823761792913561, 0.04649792106882219, 0.09712224450683403, 0.033413238913541844, 0.025945153357761524, 0.0646155940428857, 0.017446353956456148, 0.06684939151689892, 0.02274636472124727, 0.08755840286011658, 0.031174293328677456, 0.03263799623856622, 0.01982713114440201, 0.03129520307054683, 0.03377536867534922, 0.013298983760778944, 0.04157852193701171, 0.10638624700086732, 0.07907993926276123, 0.040913067322464726, 0.04161750815147835, 0.016118183491691467, 0.038329079566944035, 0.16337609459315577, 2.289110431748052, 65.7404185110523, 106.23202247004356, 71.57078250761955, 70.71435651471539, 62.40019083023072, 61.235313569345784, 114.00107675983061, 38.56380608774001, 38.099899522719845, 78.11009530098208, 29.495325473047075, 2.2553287734908443, 0.7323025275141962, 0.06279619267931388, 0.05576650859908231, 0.4112191438194244, 0.15291825898232, 0.370306953667633, 0.3028769058085257, 1.7111830173000213, 1.7901788171260589, 4.452917806563839, 5.573074654225381, 2.2593928392856353, 1.2075662540812646, 0.2500239789726273, 0.6399248264008953, 0.19161444788257923, 0.8139809833899622, 0.5090660691982316, 0.1222463354708687, 0.026581785829377272, 0.033368989675035404, 0.12465239547553564, 0.05769947100610984, 0.18893124024954536, 0.14326340609019803, 0.10697694675576304, 0.1491474822884606, 0.7139074081374753, 1.1021118611097336, 1.0983430762444775, 1.1533343383381445, 1.3624633488155182, 0.7172444871356412, 1.1235758061370542, 0.6875009089708329, 0.04871047109425549, 0.1888213372759281, 0.018216967545149308, 0.25459717148013655, 6.567367055723745, 38.802341107399236, 72.11305018394225, 79.23419167918544, 82.39949733980241, 63.5706574686112, 39.93251715936969, 21.504916144955544, 6.905221391108729, 1.903682403987454, 1.2252596982063786, 0.5674999772060303, 0.6453177176656262, 1.0987217075401738, 4.178089095700172, 6.624212495742306, 0.8472147968507583, 0.047992233021725575, 0.024042518456436457, 0.06013824679558316, 0.1681557784397756, 0.1284552712534224, 0.038267474606513016, 0.036719999982104186, 0.03804992861865509, 0.07297636355243384, 0.01850868042017664, 0.1023749646640593, 0.05777165181033554, 0.016145601778501467, 0.06765445033388753, 0.4588653387561922, 1.085333800123584, 0.0721214936986085, 0.5295732316951598, 0.15383704355166805, 0.36754450189971155, 1.4295804957228324, 37.92153366150395, 69.83930710823306, 24.265594020966564, 44.86743542455858, 101.80526687252907, 63.75955881610994, 33.61049190644295, 40.64845954218219, 64.39521812623548, 83.59358449136057, 24.074862887782437, 0.24762661406590095, 0.07072627904915041, 0.10107836851309385, 0.011150949829888922, 0.028593109454959634, 0.0776015121429678, 0.07616787818410704, 0.053833825814147154, 0.014630148671717655, 0.04513859763861664, 0.05121217717626884, 0.06818053057237018, 0.053309971061084545, 0.04543749067271429, 0.03542095234978103, 0.07799266897622617, 0.03966637413888689, 0.06613790267898191, 0.05168188866528292, 0.010155559340942531, 0.004990475333010357, 0.027807836773835366, 0.012111469911741874, 0.031342844163338025, 0.006150955854419379, 0.08178663515155354, 0.0413964688026857, 0.03204424170807245, 0.03257989229994916, 0.09155125312146642, 0.024489519268935247, 0.03781798783869993, 0.0518204816316645, 0.10955197511300926, 0.07601262280537237, 0.21408454214613284, 0.21626170273990403, 0.18283364002502736, 0.21020651314287417, 0.18243714355893675, 0.18158315470622433, 0.09663758664241723, 0.09311962662444961, 0.2022886420449903, 0.18330403333229406, 0.11527714935401756, 0.15957988378021026, 0.15807580803671192, 0.11717690951040677, 0.12768736003988213, 0.0766638205236485, 0.1564763083813652, 0.08843322164349018, 0.2296564436607784, 0.12566008454849645, 0.13093798601579282, 0.15389007215778674, 0.21564843403475903, 0.19718370790923798, 0.2575895875211685, 0.17690827168764608, 0.21149314248994475, 0.18181927832624606, 0.1486553474059028, 0.06741761425209623, 0.16835612575373343, 0.08593829543960672, 0.19172389120344194, 0.17707555464679198, 0.16672201424596772, 0.1731859270723597, 0.1382021083226127, 0.19978244668774067, 0.1439044837869944, 0.2744965964267331, 2.0068907497390627, 69.80300949465844, 123.0235165934409, 92.62275511218657, 99.0095583085091, 80.18804934716995, 40.795120885295255, 136.84244248174852, 96.72205555823543, 39.26674189106111, 75.97511783722909, 45.99257123085761, 1.9775444341282693, 0.9902217779909411, 0.21091269299147591, 0.23170684734659813, 0.6751901824628154, 0.42881011602378666, 2.653850163182905, 5.34717555007627, 5.988576719837805, 7.508696183081597, 14.110377603961577, 14.231776921979844, 4.302045308774518, 3.818151325948777, 0.6242219851382318, 0.9946259868241126, 0.3012372018589128, 1.892493352774651, 1.667602542907961, 0.2872629307450787, 0.08401917624137095, 0.15200235490356723, 0.416196141271822, 0.13831686829366993, 0.20615608371313543, 0.3402415266440761, 0.2279603403181799, 0.31402376089845935, 1.5033634655898618, 1.445763459609401, 2.029799843026746, 1.3794204905148477, 1.92059223209658, 1.0857550871949042, 1.6517105698585512, 2.4202686067550414, 0.5266139872612492, 0.47890696494329366, 0.14886275805052251, 0.2063022839326051, 8.323482294236461, 51.86761102368755, 73.2660936540173, 77.42828538340908, 78.79361537195022, 59.36804963696388, 35.71457286034861, 18.77258327699477, 5.2195484888169075, 1.9124745193027683, 1.2612224394275298, 0.7747458209914546, 0.3389791976059637, 2.111829351032934, 6.627470514466686, 16.131862267371147, 4.007313020767705, 0.6229437827583283, 0.16360213649609398, 0.270394348809796, 0.23555265469176156, 0.19384466772598608, 0.11628565814105735, 0.14623673122015693, 0.1934644276456487, 0.16706447086987958, 0.2731773317340882, 0.19641852396870815, 0.14957512788955243, 0.14891949452219472, 0.31964779621170414, 0.223265401117744, 3.8805268176140326, 0.1577869775674997, 1.1302133144870883, 0.39283517868288104, 0.47540882361992715, 1.1062301046425298, 46.860391709112356, 75.4785300839332, 42.2538621194901, 87.18640496653896, 114.53627632510279, 59.623701880055094, 40.621403032733554, 64.36946384368404, 80.12396566329464, 100.10655110882175, 30.74762648151767, 0.3831594575557017, 0.12836425234713864, 0.20500370361391576, 0.11038848950016884, 0.20549275882301793, 0.23050191361577282, 0.13495358908849378, 0.15801289689637002, 0.08544486586845691, 0.20055333032242714, 0.11764461384905923, 0.14166012196050537, 0.19866218099430685, 0.17665025327474843, 0.20848278466972614, 0.32519108585772977, 0.15465113454528395, 0.15911044042196967, 0.16218700356060461, 0.09891637646022344, 0.10300830487282046, 0.16719495096514303, 0.17618036558551176, 0.19384138886967014, 0.1747902224381124, 0.15366861146063576, 0.1756815963815297, 0.14712835031171, 0.0998084781871688, 0.12600009735192985, 0.15680967920249508, 0.1838578536145149, 0.1944983552300161, 0.28456001933063235, 0.15037297781917358], [0.05209657971957519, 0.05703749060029945, 0.03486576077017573, 0.02624423216818081, 0.07355272980226625, 0.03443360674164949, 0.01839394343175715, 0.02768220218469299, 0.05814843300369479, 0.025678363238130848, 0.029453742205195373, 0.02791465241311779, 0.04055393296444128, 0.03339189953441101, 0.01809102460561741, 0.004332627013941566, 0.062449982224573056, 0.03900415241538037, 0.10346110880134568, 0.005259376503677378, 0.06823624048622386, 0.01254400123857082, 0.02865570075359316, 0.027479583420039668, 0.04694052070619599, 0.03927211464953519, 0.030584240918077772, 0.03346719831648854, 0.02498770816131465, 0.017150979181150758, 0.04464948497292015, 0.04345027008844961, 0.09303754030336296, 0.017519666655589978, 0.04283768703199683, 0.014780367979960097, 0.025138702175970522, 0.08960504505422809, 0.07537156043033447, 0.07143482610943817, 0.02717793246941461, 0.09846564862997302, 28.4775076758477, 95.5476116365002, 64.2677999311878, 44.069931276382945, 46.680382374794256, 20.99690252734769, 76.62973788476761, 81.35817081697526, 41.52237538368472, 40.21931694399926, 42.119379735762074, 7.6341615280797415, 0.8215472354523597, 0.46581516583119675, 0.16383577799124105, 0.17364654509771257, 0.26973125374605583, 0.36457771916062603, 0.5200890019055336, 1.070266995699175, 1.3039016266984325, 2.2547463015202553, 0.7868777119344281, 0.28431370674121764, 0.25630671200492694, 0.529768921194538, 0.35638499103726884, 0.5128020348568116, 0.35044155834663304, 0.15839402563869953, 0.049620813374677976, 0.005842407718451033, 0.1075930729688656, 0.04663547598606637, 0.0961957530929677, 0.0521688333021537, 0.04965780776054148, 0.04759383665758276, 0.022008076212519122, 0.05330874915084532, 0.1968470275882752, 0.3138466720138827, 0.4399928240285766, 0.4600756351024874, 0.36954653479399224, 0.043198165874327385, 0.012376114985184565, 0.102377952406964, 0.05261255525833657, 0.17590595289103447, 0.06888130950110574, 1.982009194550976, 4.787485195744423, 6.844654112092911, 3.0117429071857087, 0.7224062037083411, 0.7876366905627713, 0.18034586142147743, 0.27254059009494325, 1.105393046332944, 0.3200430669371159, 0.42995529489651807, 0.6531529585199972, 0.5373168484337869, 0.391424473735594, 3.258326875586664, 0.8309539984310828, 0.0734873441979289, 0.07106347264902246, 0.017036083229486982, 0.10573247522716561, 0.03134817996573064, 0.11015533830129332, 0.08776497846889882, 0.0853764082515432, 0.017820879020878387, 0.0629578793661729, 0.05075088499354259, 0.0994344587407766, 0.07141211160248326, 0.007374637193166681, 2.599559166739064, 0.44454859569668775, 0.028338283713486408, 0.3627574023219847, 0.23029316997816487, 8.006421423727467, 50.73921180540516, 58.86855932974047, 47.09654192770682, 85.78656596522178, 72.77509135584678, 34.10437322431995, 25.404305150431973, 43.448388576507575, 68.24989995648785, 52.91120075410413, 10.475790750595833, 0.14027034653530968, 0.10217980376534885, 0.05678756973676144, 0.01657225912617099, 0.022658048190116402, 0.04654530360693893, 0.04788073275478617, 0.018095291715355653, 0.036105666414744435, 0.03607821365397784, 0.06145322139585211, 0.022156747065544612, 0.0699910031811845, 0.03646948156998523, 0.06795310205028904, 0.06926677430108671, 0.037573498538545066, 0.02834138062392031, 0.02309382964496411, 0.007369905163819392, 0.07110071984390098, 0.04668687665534597, 0.0905488960204586, 0.08806768279041975, 0.03535527180159285, 0.03301262472485823, 0.01405442497813173, 0.08497146949652704, 0.06709872249273524, 0.08712986859703258, 0.005981816568471973, 0.015731829072108433, 0.027396267527834545, 0.06454734326971155, 0.05509706649688944, 0.03423098414655655, 0.01716803421356505, 0.02595257483452799, 0.027097403222034057, 0.06753371487702094, 0.06488911807537079, 0.08243384155174417, 0.032137851906760086, 0.024092662741520235, 0.06467139588729029, 0.056445875370334235, 0.034026411857696316, 0.010587128269816599, 0.05012921230386823, 0.020075628999620676, 0.03671454160564369, 0.03195738265921753, 0.041146739461128755, 0.05729549369143863, 0.019212280467693365, 0.012822557511108537, 0.01430119434747124, 0.026301820912668784, 0.0422354385016426, 0.07349665982708817, 0.023369908580676686, 0.01742311850971272, 0.03630160872313765, 0.05677457305512602, 0.05569881323965327, 0.03093052798161103, 0.060380966432632945, 0.04250957540446713, 0.030456717922202045, 0.053328866619736924, 0.0860664542884596, 0.05043090538932912, 0.0299193091585391, 0.04531689694211368, 0.05208413079080563, 0.13102631595346237, 0.03046556240728786, 0.9121299619155546, 50.25301441069573, 109.69575774285101, 66.4216910639117, 44.193391799926765, 34.530185730226584, 50.44488107004474, 109.72278287333828, 59.95721709343695, 41.675598852096066, 68.67233922404628, 53.41458989727882, 11.995706250590663, 0.9761774251537939, 0.18664603061493368, 0.1512214201953142, 0.2924152704015855, 0.2173140011126957, 0.6415745507805579, 0.3707853908981047, 0.6905621350292237, 1.7418803442870419, 2.599137757093676, 0.3698642467779498, 0.14540134298224605, 0.9115824235543128, 0.8176040889755373, 0.22036453258366356, 1.0600804777876025, 0.7050472642144849, 0.06309265721469157, 0.04847019144724454, 0.04111179819090232, 0.03458036237486428, 0.007968467374842974, 0.037886625486275846, 0.017599967991813056, 0.025987989164047667, 0.03248820689717128, 0.07127664427483274, 0.012227034275119585, 0.1767647374541529, 0.5297992582763396, 0.3478254906592831, 0.37345241875417773, 0.25628238105245177, 0.15314050108915375, 0.014375594891457549, 0.1369718477250107, 0.034544287294509916, 0.09345122778247442, 0.217103372898794, 1.5424948690399047, 4.661058379757789, 6.76910779168529, 4.235132615412436, 1.0652633996740466, 0.9120445277902388, 0.26785657530830753, 0.6229336091106938, 1.3127569902327754, 0.829162884864115, 0.4361511382364458, 1.4969333525626891, 0.23016648967900585, 0.11696216740435171, 3.5570871926123098, 2.013350770838799, 0.13683421236853446, 0.07770599887496041, 0.06460673806648101, 0.1395383188801427, 0.018634724866358504, 0.05202621454373003, 0.028746014858986584, 0.07059125605249597, 0.05424939403911272, 0.014898254547358282, 0.04021321919055716, 0.11843490249086773, 0.04036106649906405, 0.018667277857480992, 1.899220217620173, 0.34938723750172124, 0.039119858505024065, 0.5020443524324125, 0.1543473193962728, 13.231002803771728, 66.54170774644422, 73.71315756151753, 43.57694425890523, 76.42601782275786, 92.61131748076409, 54.26765834131549, 26.267010857982022, 38.546402531285445, 73.61752233197613, 67.79709369905534, 14.526816625748912, 0.10452102974898393, 0.13356834890380984, 0.03844185153983774, 0.023664611113828518, 0.0232417133426474, 0.0653143581603804, 0.07074579130858183, 0.02760157143066247, 0.056276650378300305, 0.039312169556656194, 0.13505172495159412, 0.03765980217365488, 0.06822145498928524, 0.02690242426920562, 0.04433676022134962, 0.043300614812441414, 0.013032478051290158, 0.07098152422376218, 0.018652147620976455, 0.05418973494200938, 0.03839268784729704, 0.01309597429128424, 0.09886896327858972, 0.049783070797040585, 0.027746469300660877, 0.027203021848934795, 0.02547714641437896, 0.09452820184730715, 0.05264805194230811, 0.06919058685701701, 0.01393314942927851, 0.043915511454425515, 0.06215777713805438, 0.030710302601237933, 0.06609708551437625, 0.040652681697881034, 0.1451866391805872, 0.22042381246724438, 0.15097947430706796, 0.18058693396949, 0.1838364491179105, 0.24213388622287782, 0.16486589045774552, 0.09091009115499836, 0.17007037005837888, 0.1530761497035142, 0.11773364858761912, 0.06171887387491523, 0.18192928855217275, 0.1981028295572727, 0.05821404460396978, 0.12796888969117595, 0.12254834265237856, 0.12961018710367142, 0.26340971069951213, 0.14105538747483684, 0.15285589942528358, 0.10109617239645413, 0.14095449369520913, 0.1891003924632265, 0.10798386207992032, 0.18211659704965932, 0.1394532677987891, 0.1839992581235786, 0.1091819010194271, 0.20267038365765927, 0.24101306894613853, 0.14855286016339256, 0.17231065629711076, 0.08803163835358235, 0.14979744660517863, 0.13377264923145696, 0.12257574561743007, 0.1420497849223114, 0.4206533633893536, 0.21351435822584938, 0.14046010651415394, 0.7318585642403173, 53.136415404658166, 127.03468922645816, 82.79875539964246, 63.32192428650395, 57.482844783413796, 32.49704084088726, 103.9436960220337, 107.78102920901392, 59.43274128821589, 69.19858794058524, 73.42188235252135, 16.045076885531028, 0.6951606237599928, 0.29474908065411354, 0.28071851739960335, 0.3288618727557121, 0.4845723383609326, 1.6089620056652254, 4.244765956555644, 4.662608206272125, 4.38075747220747, 5.3196655165764595, 2.976236386645225, 2.066118294192899, 2.950074177595877, 1.320785223957031, 0.45725327525888726, 3.2882405865576962, 4.773364172827813, 0.36948996686166335, 0.16509492010358842, 0.1463253522712377, 0.23574315011501315, 0.18379549405747847, 0.19837586329348628, 0.23653007563083406, 0.1593584996918517, 0.06836469810936721, 0.13541293540789237, 0.12083372296465021, 0.49169637382991854, 0.8055008190774149, 0.6506054403801119, 0.7398659603730325, 0.6898200103352148, 0.333536081616917, 0.13855328302710287, 0.2129328974913205, 0.2706680873468999, 0.38172576997068625, 0.2796472200462895, 2.4718943526667934, 6.344179780252519, 8.929373756531747, 4.661697235799605, 1.5656048612248514, 1.8856244245844505, 0.871462827968982, 2.0595463629691833, 2.4289206199107634, 2.1689572017039023, 2.1078724149734747, 2.5600461902156955, 1.3841425339060447, 0.5326922514265584, 8.158451511013894, 12.133893312946444, 0.2520436318891664, 0.14512522957257687, 0.2579910788805254, 0.37251567708388456, 0.10621216884183307, 0.24587594994133521, 0.15733729927770554, 0.21131674308449994, 0.12105458611322027, 0.16455891902648634, 0.20941399518520604, 0.28396528995325493, 0.2453122777684081, 0.09257087784428751, 5.877416258858097, 1.1168953968632607, 0.1527807002346362, 0.5056593068424733, 0.2577682698686277, 11.174828698558192, 73.99090843815958, 78.41450260531518, 59.501684788734686, 107.63277930598106, 96.44917626534739, 52.96151299630442, 40.23371988727201, 59.18249407122212, 86.34890048734604, 79.34454364161338, 18.168828525850852, 0.3901307657361031, 0.23539330840351122, 0.16882630455638134, 0.07919869055190394, 0.12870672429280897, 0.25617091525946895, 0.15408862682600177, 0.12959227596800174, 0.13526048391096054, 0.21787568145701963, 0.19905898389556717, 0.19161270120211188, 0.16082408717803418, 0.09861650666402233, 0.20230149700035974, 0.25863842317654245, 0.08756891358643772, 0.15529748292699938, 0.17317170848048505, 0.10756231453870574, 0.17444916009422273, 0.18429738890019157, 0.23924521380855193, 0.19976626691077987, 0.10952395927761832, 0.09750820726396577, 0.1312483741991943, 0.22126198926519966, 0.20764329020054112, 0.1694575916495054, 0.1849490539321015, 0.11706563523940502, 0.2137012070705814, 0.13842928403567883, 0.17636189778004924, 0.09697389924117635], [0.024196002256846236, 0.021931252915472276, 0.02318413225903867, 0.1012056463608338, 0.06810317101377635, 0.02242357932001112, 0.06120193689580887, 0.028620100647751844, 0.017605995188557336, 0.050470132921491904, 0.0489639159622452, 0.07246061784004973, 0.06255597048889726, 0.02666372084809888, 0.02094944612303328, 0.08177568775511558, 0.019918837614597815, 0.04221040657871673, 0.009295572019783, 0.07881082023584074, 0.10493817994551313, 0.021090850632096973, 0.02277869171643209, 0.05620841109644502, 0.06552720802926248, 0.0335278456670142, 0.035124637201548584, 0.04006551360831626, 0.019612433088402596, 0.018611543045769778, 0.06287244907129677, 0.09313944531905075, 0.09156653657555582, 0.03821617352866358, 0.06963114870051224, 0.06367892132050569, 0.01757665210583758, 0.04645530359759446, 0.07746061325193414, 0.047950875765133294, 0.03249801665304169, 0.08436943164035197, 0.13834312978771426, 26.273800480750303, 92.18523825368574, 93.97996579447101, 84.33100577323668, 62.25524356288295, 24.23742355838899, 52.41536609588131, 92.64296316331433, 50.22569902481572, 31.961445116227676, 42.30381742600472, 33.118006952347294, 9.684407461074091, 1.849337229805608, 0.16337375036410748, 0.020987333001328573, 0.1456204134850733, 1.0779355971082565, 0.6635891598078513, 1.2536416010510538, 1.9091754382656467, 0.19363517332221233, 0.11932587806856441, 0.8851727374619054, 0.5692595279505176, 0.06693654167916506, 0.489232175412678, 0.31571902154434117, 0.12889925750993914, 0.05494419365159928, 0.06758066074502084, 0.06672650335296508, 0.09354646783322097, 0.05679107458901502, 0.03176757479987798, 0.0361141968037813, 0.05987906775948021, 0.032245563868913925, 0.011998273717660097, 0.15039674186658475, 0.04260824752911445, 0.10901755983791045, 0.09595170046292967, 0.07605228317721237, 0.03396803595786614, 0.0219932179372277, 0.03822702516411101, 0.05693334477743315, 0.19481907027863687, 0.19112006070152407, 0.9761623485434441, 0.4219941091873954, 0.5195830774403388, 0.6998962728727249, 0.5427609756588936, 0.4347541615847619, 0.19615180279699065, 0.12071477249264718, 0.11454479228104315, 0.04569897563346932, 0.042222150706595955, 0.07564498487138942, 0.07091276017167876, 0.09622871019547025, 0.334515601636902, 0.9212546819640745, 0.25932152845686485, 0.0770698394626379, 0.16534527763724327, 0.04167306484774717, 0.03280513364100649, 0.10847138511317392, 0.02820996590138924, 0.050607059646638176, 0.04274011041308123, 0.029224070960715897, 0.06936988973569486, 0.16360693220649997, 0.19632106226298118, 1.196150318268807, 0.541530944887669, 0.19974359070822117, 0.3023877739906311, 0.7455280855778725, 24.262369832684918, 42.73677649036531, 44.90797704265964, 49.14801997523154, 75.13492261209797, 47.55957380417855, 28.27345813474348, 33.376244037382065, 58.11453465492495, 73.22865070835238, 44.22824205890779, 1.7102905555117516, 0.19845403490527985, 0.06984831164440802, 0.047069372864620346, 0.05921247167392604, 0.0019418983438593007, 0.04772113748796044, 0.04994968342925272, 0.025952647612880797, 0.028710924201614918, 0.061968461490206184, 0.0458829018527702, 0.0820838466226574, 0.052456112443319255, 0.08343596116549547, 0.025650381876696503, 0.023013601087093837, 0.04999841811255582, 0.03429524743208482, 0.01536511140124452, 0.036002098988260955, 0.03730678885814644, 0.06696792830142283, 0.007667779300977747, 0.0670690059421524, 0.01996178450363298, 0.03068830438649222, 0.09304032886340734, 0.0759180952163954, 0.06229017628356815, 0.049838144857917106, 0.059864332058256677, 0.03967054165719498, 0.0310250919597644, 0.030535741806811387, 0.03916556331058664, 0.058283383221996415, 0.02025352993739709, 0.02428196306760994, 0.06516376059622535, 0.0689978314743888, 0.036749329658285264, 0.04596917101392343, 0.039738922665316256, 0.0036949773212038585, 0.08414708994208805, 0.059309898905696413, 0.09244201419454429, 0.052288699249226245, 0.02927494685976736, 0.051377292106589006, 0.05263563365705552, 0.01890725489976185, 0.011588195470281908, 0.018926941444196047, 0.007582997786812485, 0.020205057639208053, 0.03318923097404261, 0.05364914882868048, 0.037310393301830176, 0.10542118306001348, 0.05436510395919604, 0.03860328158724212, 0.014099177919448385, 0.05339433266330631, 0.037442440046898784, 0.007458794345673655, 0.03569624604537122, 0.014754202246906297, 0.0556158114434971, 0.054369489812562545, 0.016870495239873568, 0.022812761561644655, 0.03968819615341002, 0.033843366639508356, 0.0119670077542504, 0.06350743636909513, 0.11042814987200884, 0.037956745513985236, 0.09772536254698232, 0.5747740126905904, 44.33846458312004, 108.2874934904037, 83.35360603947794, 48.33106871574156, 35.638757367287916, 42.5841413774798, 88.27725533516177, 90.7662816201487, 44.237232131342736, 52.371247276183105, 61.129699830086004, 37.71096514117333, 9.47036470136335, 1.2195112195707138, 0.5813355864055696, 0.06548277492965422, 0.0840266302768742, 0.7292634873620926, 0.01665892665304484, 1.449172612159483, 0.6810584772498377, 0.6272571029201631, 0.2778958204773165, 0.3753662902501322, 0.17772121354937556, 0.38206965151813727, 0.3798427564963218, 0.5305570724510378, 0.06607962637058189, 0.03654302984115578, 0.057228235002126426, 0.01985570430875786, 0.048891581940434636, 0.04449029190225467, 0.010162739500012851, 0.03228002633418768, 0.021142011898900234, 0.0312153575566387, 0.081990314947982, 0.12544526583364896, 0.08016274325669774, 0.14569752789553136, 0.1757416576747933, 0.07523517379717481, 0.08084346600357564, 0.037198889204451156, 0.07874551124029583, 0.03556264031137671, 0.3599446645427135, 0.27137248987151735, 0.6829031556844712, 0.18768702152996294, 0.9516192203567875, 1.4377070338495317, 0.8654590275499129, 0.13271295044931675, 0.5370366441146021, 0.2603725398019437, 0.15271198214782825, 0.09342980796411153, 0.025324265908209548, 0.10528072849997591, 0.019023200391881892, 0.08264801675273527, 0.1008251304888437, 0.7862885596771395, 1.1386232438587374, 0.13998042822124498, 0.06749252232933237, 0.1967080592388107, 0.12261216543735036, 0.06607247877024836, 0.0125804363802496, 0.09295589831327239, 0.10250433393183256, 0.06650398545447858, 0.10173803150293328, 0.09748360818071712, 0.4725486803199015, 2.253724524090367, 0.42766245502618055, 0.2918470783099052, 0.6924605009055907, 1.5120252846710145, 40.37903977978615, 62.68940287251627, 56.92913163092829, 49.382628702348285, 87.85692630275604, 72.29403618843325, 41.901142981744584, 32.56981649706441, 49.554263776348485, 82.67916233308854, 55.57899298206453, 3.1187858600770277, 0.4293996666467959, 0.2664159622884566, 0.016836948249669328, 0.0058025668371438745, 0.04777372176308305, 0.08340011591151839, 0.03396790189247939, 0.05460010909084832, 0.060917465466885805, 0.02131624519073915, 0.04895618996552883, 0.10691066482855428, 0.0324106443252775, 0.04346525093780891, 0.007344631444392426, 0.01863088676585786, 0.04528852870627757, 0.01585876505311218, 0.01747001266677774, 0.07891309297373218, 0.018866617765818394, 0.022558186713966633, 0.021392216214970238, 0.04426338815040166, 0.024659441400980277, 0.044411319728580215, 0.05602275734887489, 0.02994033444162098, 0.01653109147633997, 0.0773158532777621, 0.0414653362766389, 0.07335148616543702, 0.034368856990289305, 0.0526738231400809, 0.04282165281174164, 0.06022203383186172, 0.08665872452360007, 0.11473071415938678, 0.17155814345084852, 0.18096841511226472, 0.13862134227829595, 0.10302614706057696, 0.13972852318998308, 0.09436158538465539, 0.2317506216105915, 0.11512838274000153, 0.22624704596256057, 0.09142540019726561, 0.12183621030060515, 0.14993263048029717, 0.11854017063254312, 0.11531127857104426, 0.16513002225227896, 0.17894680101063945, 0.17248504855219396, 0.13273668385321094, 0.10629190327299219, 0.1553200212337317, 0.16271338257337772, 0.2609949709186631, 0.17560307236929096, 0.235250341075082, 0.11202725116163494, 0.15803243213843915, 0.15419852979961904, 0.08051954870743137, 0.10589989608213787, 0.10995269272356265, 0.16036221276848547, 0.15900430660093987, 0.12024378163679955, 0.1801697684512023, 0.23788615850911987, 0.15579191607333, 0.18592005505436854, 0.13961383982771827, 0.22565703568679674, 0.16220705974246227, 0.2731635421514511, 0.7098370910652223, 41.295195625674346, 123.83304672856485, 118.22429272436328, 106.20711541944935, 84.48211900649532, 40.588062886268865, 75.6990614245015, 127.39611994835639, 74.37079783408873, 49.55190250950475, 70.98330559269075, 59.11487633182157, 13.553672663627134, 1.2677571081346082, 0.5357168278386516, 0.07768873125314713, 0.20082714546832348, 3.1278004473255527, 1.0299489526979386, 5.928297735029652, 8.673824475657556, 1.1537619992609949, 1.1834623087798397, 1.0779836461428673, 1.0771318789451354, 1.3889872739391944, 1.6803213184879673, 2.992708625332002, 0.19451225206496256, 0.15508518464142276, 0.22892954879470412, 0.1547977790957497, 0.2466458529834786, 0.2046971305483772, 0.1762181030766618, 0.12751825379147647, 0.13700880380647798, 0.1218541520797918, 0.17479336339860194, 0.35667466420319777, 0.3683409575493105, 0.3622667689717585, 0.36525849553365863, 0.29395142990735273, 0.21090054283699683, 0.17370743376593437, 0.28428306322424646, 0.20824630864925925, 0.8836886719349892, 1.598625334520494, 2.3094256126111556, 0.65625463402079, 1.5771412873460402, 2.1396264529997304, 2.046648751824133, 1.0796180487640443, 1.0857555774911758, 0.2474207662406468, 0.2663365649359842, 0.2839612450090147, 0.11302743257293779, 0.3467539175143165, 0.23968159281198056, 0.42396010530571787, 0.5553237144504825, 4.985625195887781, 2.4523577622828947, 0.17651200504793277, 0.28860021382570267, 0.16837389899357674, 0.16374164110710546, 0.19674322267453517, 0.061670794196787386, 0.16619013472189828, 0.12215075834143548, 0.19828059259922276, 0.45889245826871167, 0.4281275010397358, 0.37134288840236207, 4.1573279903781035, 0.7150333122380319, 0.33983553068772443, 0.933068186765717, 0.8272159183698317, 34.59036665578043, 75.72824385858353, 61.37310643349925, 67.73006039281046, 99.35163605597712, 68.80364448793473, 47.073137144888605, 50.83201508368216, 72.52607576308712, 96.15869337512602, 66.80628730404761, 4.419898804157011, 0.6277734461811282, 0.4017960478461558, 0.15594265153331144, 0.22142587079396173, 0.2044970896695891, 0.1856830887376301, 0.16979177452383504, 0.1367840489312526, 0.11654687114059926, 0.16111395952682342, 0.12205430787176856, 0.15205089423444965, 0.11556181996580094, 0.12019974690291191, 0.12402993371529926, 0.049307268909028465, 0.1575823401611659, 0.15667998051691442, 0.11632524956498416, 0.16112765717890956, 0.13169595340807594, 0.23554816541652526, 0.1576150214720157, 0.14029340578183053, 0.1252622167850214, 0.17670608576266997, 0.16505018056881043, 0.0815237520803367, 0.15910288679503626, 0.17849981935033876, 0.16643321442027248, 0.16969656511660547, 0.08845083400486939, 0.18802339541575602, 0.20824830047786239, 0.12185230580789429, 0.15095839156739174], [0.030454346880076394, 0.026760096624193173, 0.08847560162746138, 0.02325422547367071, 0.09767244119317302, 0.017013497042259382, 0.037938960782823064, 0.02378479498738964, 0.04214037848155826, 0.04458631336268398, 0.01373307599175361, 0.021149663202043985, 0.02523370282424073, 0.0234596308831486, 0.07217542628847784, 0.01736991561859125, 0.00025444320624134684, 0.0030785504185910067, 0.11653251465289824, 0.05376080997408398, 0.06942088820881422, 0.013304530237350735, 0.04956762772053481, 0.0292925822037843, 0.03065487422469643, 0.048925584752953825, 0.09057169479708518, 0.02758378861472011, 0.08609543539463513, 0.020270293856400157, 0.017918084087150715, 0.05887384548963559, 0.03846957626181745, 0.11814896017313005, 0.03920151964731274, 0.04661344329736406, 0.07302103413929863, 0.060676772132395744, 0.040466162270956466, 0.08767703157519141, 0.023693735861489852, 0.027115371814298055, 0.015191917116152904, 0.05554025985240456, 9.12323788289101, 70.74779864280455, 88.61366133536063, 81.37876326037993, 66.18839633080268, 28.923159530085904, 37.5606716832807, 88.32093484940069, 70.58339641940209, 38.69436610129572, 37.95120639185752, 48.182473644133545, 22.16889692891029, 5.424499684764493, 0.6975263645572047, 0.13328128043682347, 0.09146755801573878, 0.11439485355250298, 0.21482027766685333, 0.389642154857997, 0.23226336425831243, 0.12586796250674995, 0.34134429488931933, 0.015152207906207731, 0.5990673349268976, 0.553241610046356, 0.06555363806265016, 0.0628975652638943, 0.06950963949484211, 0.07898080748535934, 0.04648973541935125, 0.028312826611762567, 0.07323871802298293, 0.02761520013483542, 0.04120986893652909, 0.03552410991922502, 0.01709365282177685, 0.0068618844905417534, 0.08837275432362672, 0.005596180356317951, 0.06807700145028292, 0.09535247414943673, 0.11416492758378868, 0.0034777732000821422, 0.028811287465355093, 0.07394597039467866, 0.036367936615621856, 0.061758024798285585, 0.48015406415347134, 0.17927689297545343, 0.02106352810627751, 0.11725145752631849, 0.0994875256512915, 0.11858021404834525, 0.053033861481854995, 0.034594580966738925, 0.03773280652239919, 0.06115105333587816, 0.021433450897494634, 0.03719465273822989, 0.03214614863898004, 0.016777130189321695, 0.10083528881471965, 0.1355063981346546, 0.050527532059218616, 0.2605363906871888, 0.1926386461503083, 0.0898640057552726, 0.30921502699775083, 0.0431706058612514, 0.06560063755680477, 0.035997448834560575, 0.04840921467891143, 0.008436911945952284, 0.09180234609952859, 0.07595637662997169, 0.49997858102283177, 1.7870191028041227, 0.429377204948856, 0.30150199248906107, 0.07824384622396001, 6.895004107106117, 45.76492078842656, 37.16194706578409, 30.795304852147257, 63.65492174702307, 72.00114496292608, 38.18694083921371, 24.407173933521396, 43.57082928380659, 67.86757869105186, 54.9435454799283, 17.88679442098064, 0.6156458453305307, 0.2525695818927019, 0.18856423816853957, 0.005260018581118916, 0.16701055360176872, 0.05529066457623436, 0.04375698871069378, 0.04513798859871684, 0.03159891096724859, 0.039879139738097306, 0.050002486039433754, 0.0688666618999935, 0.02755776077749268, 0.026856324928362044, 0.05313966971551699, 0.06338255637655817, 0.0188100460030499, 0.026574086645738255, 0.06836747900853235, 0.037046288320374106, 0.0271650449553084, 0.04158764987462952, 0.06114788556231126, 0.0194922358083028, 0.04675249974693983, 0.04018034252728667, 0.02196008271928276, 0.09380539022986928, 0.05998199550254692, 0.09008964163161094, 0.003928962119501986, 0.038971942248603994, 0.056966271236418724, 0.04210945151205506, 0.03587122052727688, 0.03683528472338954, 0.02063259981843012, 0.04722775005164647, 0.022067087965326446, 0.010757699661377457, 0.04025755652917489, 0.018230266831514817, 0.02979421274616353, 0.06345755638434522, 0.017846669370849288, 0.009698204850147088, 0.026946368987762162, 0.04343011814560141, 0.05005528098873554, 0.04885846012902837, 0.030377801289902102, 0.03763083255879822, 0.052357256457570105, 0.047260408379858544, 0.011425845159758485, 0.03272549880127753, 0.03215935982523426, 0.0354564911685884, 0.04956861214351751, 0.009268027328465496, 0.026892930524603977, 0.04447977734549392, 0.026970540976993022, 0.01870211953627727, 0.007300646506219863, 0.042536445938411264, 0.027025180282972516, 0.08719342325123088, 0.0424566310680201, 0.03754652075229153, 0.06426364175915238, 0.04081118145897504, 0.0048079448301465285, 0.02118357599923207, 0.016419035795655464, 0.020677220609579838, 0.03110484554312162, 0.03333550014142548, 0.0755655185710038, 0.06633891648943387, 0.02551986539225665, 0.040893275440940936, 0.24041263987460446, 21.764104404757102, 98.58486760047175, 99.8654979275119, 68.28006298311296, 43.3555539192692, 38.34030551295127, 75.54872482053696, 96.87995449189218, 54.592583564019975, 48.258975551974395, 60.969474930917066, 63.10485639879781, 34.40425019110403, 5.715622411620233, 0.9735913574695588, 0.2847395596965667, 0.3864386815938258, 0.18864460079179657, 0.45216427575195994, 0.17452665754864294, 0.10459016918415025, 0.049067016075094866, 0.29212360540705345, 0.0467440114927388, 0.7563978926308694, 0.6363980027456438, 0.06807412862056686, 0.03345142839656722, 0.019570631500814232, 0.02497418096379167, 0.02881516578547176, 0.029303474058847756, 0.055338073927428455, 0.04665675790860288, 0.0462102244097379, 0.06420216320322887, 0.06800870471183332, 0.06446633713259813, 0.12574801612044537, 0.07715839922668473, 0.10452178051514972, 0.16921023718051373, 0.10898297096812919, 0.03187093346740209, 0.03731538436465687, 0.13435034081339836, 0.039098438686661185, 0.23915483075524532, 0.631999493606629, 0.06295712860000711, 0.10696320313840144, 0.07326445857723875, 0.0927687660160084, 0.1618484233415896, 0.038862123544658386, 0.07643934144007583, 0.04594210895799822, 0.02300738045314868, 0.014048816256916091, 0.0729835341354051, 0.07542520190679258, 0.06736096205009569, 0.04920101251393076, 0.08188535324147633, 0.06304173151992502, 3.154545618641761, 0.5513928253804484, 0.1355475983432224, 0.3055962115045517, 0.11741213680755709, 0.06408787820668471, 0.09889219872533314, 0.07823433907281968, 0.02111364366306413, 0.056075073493224, 0.06494543319868465, 1.1213762144888602, 2.733403920165954, 0.40113206412042346, 0.5185263664011033, 0.21820001244064302, 16.15516997152759, 62.68159735587336, 50.94796426834599, 35.882650344602524, 60.4227553644488, 92.98602934806578, 61.049220638890425, 32.419566185243674, 38.93157535983671, 67.58579561787268, 76.0282345741026, 29.324635690258397, 1.136831701282532, 0.5169890424416912, 0.17753310832044772, 0.04032541276706804, 0.08516010332612262, 0.017695255923054872, 0.11079224081890238, 0.03805827514659013, 0.05788987066837088, 0.04281800240278245, 0.04006847836858323, 0.03648103417588338, 0.013640545977039203, 0.03736048396075926, 0.028577190147893086, 0.04783808464004148, 0.09906455318653777, 0.028986551145452167, 0.07280695086885845, 0.05290207520668065, 0.06477256545857077, 0.027539173569229823, 0.06560693479954235, 0.026589898700495402, 0.040485597921595465, 0.08050847107604628, 0.04604934211519938, 0.05178264837952391, 0.035320242431255124, 0.0508908071224728, 0.08378486824972976, 0.04227990224476784, 0.026658860020219322, 0.04865123717595012, 0.049367609824384415, 0.026371611522570736, 0.028890207928094654, 0.05390840447357586, 0.0027589821078318863, 0.08016802160249603, 0.15388264110492123, 0.11559917441298885, 0.1701192311461895, 0.17033378173026348, 0.10491243173037806, 0.1586480144291155, 0.1158411356229936, 0.15963375508304567, 0.11250799431675866, 0.16596030834461414, 0.07093040317657494, 0.12775034778901648, 0.10588024592688007, 0.25433769750018276, 0.08718816022719107, 0.1191406380084734, 0.1496097703854884, 0.13218369094594834, 0.1359439875570036, 0.15772069564029095, 0.09047729744305534, 0.1347600139917866, 0.11010182705978233, 0.12101897068562047, 0.14750977016745076, 0.1926274765883723, 0.14604493344743408, 0.20752039437572803, 0.18169566237878415, 0.18301508028901395, 0.1521777277511935, 0.13344962059730484, 0.2773882719057222, 0.12546601915551772, 0.09655945333501986, 0.22809278159852953, 0.25154365226626396, 0.16224970019632773, 0.17887497260685892, 0.12338530903141345, 0.08530411253412885, 0.11449564774070056, 0.1932508423323593, 16.658529696925996, 98.66497024413079, 120.26606682808169, 105.44043325608777, 88.95086749907463, 53.40337584095617, 63.50787601163311, 117.11611332431917, 96.04255983906408, 57.19199319039622, 59.01542855847267, 86.32222052543395, 44.023419810879616, 8.16601138922476, 0.872436066067988, 0.6512699756891497, 0.6626568614475189, 1.1080478780692624, 1.4555831133357942, 1.1713941563521664, 0.6516483618367104, 0.3774328583911542, 0.9421830396017722, 0.14267672063602557, 1.5114452641817833, 1.4824218086657988, 0.27753946701845816, 0.16622522154883032, 0.13799048419440949, 0.11432760635450964, 0.1774328427329179, 0.08313748564931654, 0.21986165714840736, 0.18056741404917934, 0.15945712585122357, 0.24771008700613054, 0.13461920703130384, 0.10908802460518577, 0.244708186796596, 0.211663780914199, 0.18747496839252212, 0.3495129065648202, 0.19410832454600643, 0.05971760323811924, 0.18795337497947678, 0.24136396785897596, 0.15820628813197538, 0.3058306650528985, 1.6221475432957373, 0.4235265608276091, 0.22245543167716075, 0.2186244098289359, 0.15969763149417218, 0.3342487885346336, 0.1208361208198532, 0.29357521944949705, 0.13953755279221844, 0.12200425168679607, 0.11314220020487425, 0.17324045721080997, 0.19500775773438717, 0.20394074129721812, 0.25526199790258564, 0.33002301690078556, 0.21341347976798014, 8.11206409046727, 0.6185743236734021, 0.274193256252235, 0.5286628740929789, 0.14271648059929573, 0.2809493856564645, 0.213805440993559, 0.3031191428101832, 0.1985972780253618, 0.13393714363055845, 0.15713715114660803, 1.3389477590399406, 4.399045523135893, 0.617173363364512, 0.6592343483240374, 0.33940416189932054, 11.05705168939406, 71.62064367725004, 60.48313240851126, 42.24605268047702, 82.75307547661566, 94.52730901779668, 61.10229030732186, 43.40926293403872, 62.82195545011952, 89.69913805684736, 90.33394229027533, 37.03089675595684, 1.6507190682234305, 0.8647888538337524, 0.2849113166091904, 0.15295438768882907, 0.32232628474312447, 0.1652460232857735, 0.14373284944843862, 0.1301217806195059, 0.10415781980320331, 0.14673001523460114, 0.14593530626546952, 0.11539789247176341, 0.0903992024400542, 0.1193156584556545, 0.16018520049270124, 0.10402918597983737, 0.14125875317521636, 0.12453259464593665, 0.1906290749508527, 0.24253833468162247, 0.2167538376224618, 0.1288959939753817, 0.16995092162922507, 0.10233964034987074, 0.20639832071479292, 0.12977707169709668, 0.2167442308798913, 0.18222567264831838, 0.2235287974678701, 0.2221371221446222, 0.16065824446418595, 0.16618253512968942, 0.11873325543297876, 0.1533237033553662, 0.17422861870258086, 0.2105397460681777, 0.1442013428576531, 0.12980360898279375, 0.10731368836375976], [0.003023457444918853, 0.0635053372881826, 0.02777515737820537, 0.03153092066396869, 0.014074805789747307, 0.026421753892434702, 0.02038188413867066, 0.02522377623996187, 0.05093669195869758, 0.06129874742680019, 0.016772286598420432, 0.051459531645260514, 0.05535633363310368, 0.040536247824709264, 0.019500007770294626, 0.03173556956162136, 0.02166350327071644, 0.030089769467350938, 0.030720143000625318, 0.06983541072376313, 0.01181676354815042, 0.02766152355639685, 0.03597587579861283, 0.06684644973926968, 0.03854989291979902, 0.05407224003706248, 0.027681135407258427, 0.035958340046026056, 0.06064578004541898, 0.04354539522600751, 0.03198390079271649, 0.08624009577737701, 0.006883835782402105, 0.046695575583726175, 0.08386136212896916, 0.028270398747296106, 0.06819498665150135, 0.009294431506385727, 0.05268907595065333, 0.006367283283672746, 0.050747939385473735, 0.07063853899918257, 0.022135390449435483, 0.11151454681831022, 0.12635183130060473, 2.866204832830737, 32.92672080378379, 85.60685865340695, 80.41612732794978, 68.98186129908409, 34.97972073093538, 21.894019188419467, 71.04280794820478, 86.46342585163733, 64.81078147888184, 43.715207807479366, 40.058821401288434, 42.71285003231418, 23.530743852738414, 1.5242513124981236, 0.6206313003936123, 0.05862482860984822, 0.20934745278810302, 0.36650461415129326, 0.14654400908658582, 0.052561660207086996, 0.13396161247886, 0.4249546712925358, 0.02992039125773215, 0.20969093596983343, 0.06645105643979003, 0.012785309358620116, 0.02010051919628055, 0.09289235131995333, 0.04361717766451259, 0.011317326890064344, 0.04601939956867888, 0.08221305501196655, 0.02722499516582297, 0.07626715551821456, 0.053421364075714545, 0.042947716410121614, 0.07591960440960623, 0.034924090704730446, 0.02445730144127963, 0.08129972498863935, 0.11595990989477405, 0.0428638834085676, 0.0357883413051886, 0.06030079916179661, 0.029690342714949965, 0.32744788895210913, 0.1433872825075542, 0.04952174288431003, 0.05490366760040483, 0.030351679606903947, 0.06034027950297441, 0.03203815130907441, 0.0401892253167687, 0.06704482820726211, 0.031857287526250846, 0.02051025749214234, 0.055233299912464236, 0.09854411901605707, 0.024120345328664108, 0.20274048070273093, 0.024709834664639448, 0.0913780406417866, 0.07340649127840035, 0.23807070909007905, 1.6704863430030885, 0.16849570697353733, 0.34678103702683605, 0.03708786774246443, 0.11468221313290058, 0.06130215651806324, 0.07940459966419205, 0.1570872328574619, 0.6587295270254535, 2.341077914161067, 1.1412648375957244, 0.0329758218609758, 0.2161495934330648, 2.1688816960780852, 23.84779883969215, 46.27995937101303, 60.15444563281152, 51.87611472222113, 87.24623680114748, 78.47333815789993, 33.8039118243802, 32.06252263438317, 50.5261565023853, 61.93914367306618, 38.697049002493586, 6.508559940322754, 0.22529698968414338, 0.08432289945983118, 0.16959790831371663, 0.06405748366828888, 0.1344905349035417, 0.04555712679340955, 0.06060580940796964, 0.027824932025865685, 0.05361683907047395, 0.062319548094585064, 0.08830310927043039, 0.038973945568525986, 0.05828951575583028, 0.018147558063989686, 0.047748268491798834, 0.06295840413640104, 0.011428559026230248, 0.02263651345856488, 0.0022226587949966594, 0.05035735328771895, 0.06380662434704362, 0.05047730350446317, 0.062074461245849255, 0.03362631094792197, 0.0811525824810228, 0.016436720935387478, 0.01730225281789899, 0.046159888602673046, 0.07743969139072203, 0.08603346654244008, 0.01851805542115002, 0.06910179726659291, 0.03307756982863911, 0.03529971510532402, 0.06332889191746231, 0.03459387233540897, 0.016937575813743378, 0.03222652658399555, 0.06562644705897377, 0.05507545515654549, 0.03048461884440434, 0.037806530993792324, 0.019203139123536887, 0.02574471985891221, 0.04788665078400124, 0.03654309112818972, 0.10445374424659437, 0.06225048143777156, 0.01409363623092612, 0.009802301834908225, 0.0451019365010002, 0.04424852604467062, 0.028048060879471804, 0.03720230595659345, 0.05556672819018845, 0.011239354461131078, 0.013946800158479282, 0.06542502722192196, 0.01973826111474585, 0.03302482850549202, 0.024709989797444116, 0.06610082402344673, 0.03918269686701317, 0.06201770945241856, 0.07692850390148741, 0.044598107286278284, 0.01991344627083069, 0.011744689996234112, 0.09634959886992171, 0.09335816342143283, 0.03591412145103659, 0.09394858738467579, 0.04710002787291043, 0.03941639581875455, 0.04543821845624236, 0.05470937621148844, 0.04880899383175758, 0.038741617914169066, 0.09703399883883615, 0.03008477265886482, 0.06848991518059085, 0.022558027750722343, 0.07715792425217168, 0.0350279952099006, 0.19401162892820376, 8.814510087813101, 59.36038532564717, 98.86131625021659, 75.19476229144682, 55.29568410688832, 39.544994831085205, 56.07553366691836, 92.07756919245567, 73.30301884681948, 55.84171725857643, 60.79664745638448, 57.68763173011042, 56.84619311363467, 21.514910344154607, 2.027626482229079, 0.3904783551491076, 0.15684611434417386, 0.25576738610623345, 0.3867048511822378, 0.349490781945567, 0.19909531178493656, 0.22877450792058823, 0.192485106808524, 0.08204738083746164, 0.09273743301990534, 0.08240391049654254, 0.0825963364613633, 0.010538521906240814, 0.05328621467455261, 0.07802196417845066, 0.04016964793986371, 0.05391100917251841, 0.03336705147258697, 0.0031092418160574933, 0.03504872554913163, 0.015159551816571866, 0.09337163890802092, 0.04642562535140784, 0.03655388147660321, 0.045777641371974064, 0.08823532581089005, 0.1450865268106422, 0.06759584460768008, 0.00813411665149033, 0.03126931121392596, 0.032733044767331694, 0.5042171310032568, 0.1760580826310381, 0.05715680879450614, 0.06913867673926777, 0.026705189187440182, 0.05053426597207304, 0.043005621165878354, 0.07620866470519574, 0.09588540321396244, 0.07425601383851421, 0.13520987614268257, 0.00932454067702976, 0.12481729590123701, 0.10932015690712199, 0.1313100442770989, 0.09978763293474914, 0.06626403139483544, 0.013129944545066646, 1.0119612082358331, 6.919478716388826, 0.4258145896657821, 0.41704652951129023, 0.05115742487232051, 0.14647498456460817, 0.0726406408413764, 0.07340829924590166, 0.16487925103114498, 0.5498050009050678, 2.3526253719483656, 1.0659520207874238, 0.17730106028818315, 0.2758241042254433, 4.791732142048498, 44.89087550870834, 62.771505924963186, 68.14165822921261, 50.4330551239752, 87.02472486803609, 100.32936526883034, 48.80673454653833, 35.35470716414913, 46.51261083541378, 69.18834270969515, 64.82880476982363, 13.282704545605569, 0.29104801796136365, 0.2073555016109059, 0.1115646030032827, 0.06963757617819695, 0.10400621866386744, 0.001981587922801414, 0.06393097573891282, 0.07610950228427688, 0.038664426894918565, 0.023488589006686406, 0.050359900530067184, 0.04322107956414262, 0.07429735960378762, 0.07409417776450997, 0.023662990837868665, 0.05558711378985355, 0.04022135887475264, 0.03140197465977362, 0.0313033753134791, 0.044248924410391244, 0.01365053576357182, 0.060659979485095515, 0.12518258960617165, 0.0341195106926945, 0.07897474772987828, 0.054537048563361175, 0.0040657124050231955, 0.05001403481489228, 0.0401017802106517, 0.06393067313418274, 0.04365180483869007, 0.08118891803127143, 0.04583962937636722, 0.011318171502000863, 0.0481207212883859, 0.06848803060429712, 0.031667272823171756, 0.018111530864130587, 0.027661877872061827, 0.09360978500016275, 0.10600052939187135, 0.1507050462908322, 0.13158044267085292, 0.1440536717493688, 0.13666754227972802, 0.09474616152264419, 0.17562928789805982, 0.12817182638231786, 0.09838189989809068, 0.11751081659308366, 0.14601453507859863, 0.16971947114554145, 0.10362634630573374, 0.13719251169072044, 0.1702390932628224, 0.1310461882742182, 0.10032256914963646, 0.11325156691694453, 0.1737869230489577, 0.14772787539949342, 0.1714215806174663, 0.253092743336193, 0.09735606220220366, 0.10973236583653959, 0.21210204449392137, 0.15291950004475732, 0.2089064619353702, 0.10519386945112098, 0.1726305592925318, 0.22321577394200912, 0.13639325215931863, 0.197053243135733, 0.21059073688041782, 0.14635605707524285, 0.16280140607587754, 0.16132642635174338, 0.195026021270502, 0.1134057650943437, 0.18897354362472413, 0.1823197635671785, 0.22390379750680542, 0.2325245849187336, 0.10868642599351945, 0.18912052525387657, 0.32324225010891117, 5.260812313325944, 53.02168607711793, 115.98032043826197, 107.42875329909786, 91.70229250384916, 63.10905725725236, 44.011903732053696, 92.23714690054618, 111.96689636476579, 96.60866768129411, 65.03982436272406, 62.82070421403455, 68.18478076688706, 36.058984418069166, 2.9482267412447163, 1.498567632609798, 0.5493162980964107, 0.38791278797772627, 1.8953047115956585, 0.5163392773078335, 0.2824350140027462, 0.7249233234793909, 1.3496275150006818, 0.20289251851218365, 0.2671074332489122, 0.2646557680301128, 0.17498269436820862, 0.17042188184155574, 0.24504371798567234, 0.1778400797517069, 0.11564362283435561, 0.2558261297282673, 0.2430592591483747, 0.13282518233022383, 0.20837278976555795, 0.11513654923727436, 0.1876967661683598, 0.3013009403742129, 0.16589820925747195, 0.20690891831632585, 0.4016252102390413, 0.3440257251983689, 0.1138379306141888, 0.16294670231159658, 0.17182429771750204, 0.1695487561124948, 0.8972540053148425, 0.47069444110797304, 0.08797071904184357, 0.185081112168489, 0.20937002173835234, 0.2416130843301935, 0.1455864451465107, 0.14699103671216196, 0.17343872076561376, 0.18032077970283647, 0.1329212650776871, 0.16063291759740922, 0.38173916118760265, 0.1559641939257422, 0.6605975558200191, 0.20633171703065598, 0.2654595168367509, 0.2785642475130097, 2.479769491380261, 8.722981579842108, 0.18784187854297701, 0.7591075149755325, 0.20382915293016743, 0.3655608244720967, 0.25440286093902204, 0.17989460499055926, 0.4032265178618893, 0.658639557659626, 3.518096136469995, 2.086034373890969, 0.3059764362631306, 1.0946928205028659, 3.0634049350215546, 35.4656082584012, 65.53071291215959, 75.74348618907314, 62.56305156215545, 105.24749971205189, 99.19913430367747, 52.580835203970636, 48.98329611747496, 70.82847395250874, 91.60405282051333, 78.34826161784511, 17.635078276357344, 0.38967564822204653, 0.4103136278929249, 0.22202173398146707, 0.17794270489004352, 0.2222843795654274, 0.19504305906593802, 0.1642176268562194, 0.12803252861504594, 0.13618017246405925, 0.17444220401587027, 0.14290362055743897, 0.1614520494495669, 0.1317239922261046, 0.22564736765719232, 0.1135785102603897, 0.15097976542047917, 0.09128147525893104, 0.13330800158362235, 0.16168630381505336, 0.17405603441499895, 0.16196529771531784, 0.19618757910305457, 0.13043134142794918, 0.12459912938216042, 0.22857039145404295, 0.18457092825443516, 0.13107997275167896, 0.12279857761196553, 0.2512759811455204, 0.18954118413309898, 0.09366754802965349, 0.22566863425797035, 0.22086429770194718, 0.12878576924483623, 0.2290823373703226, 0.14843471408371003, 0.07054319169612662, 0.12059117186694376, 0.16975238228276854, 0.14849217067803108], [0.06936668748817137, 0.08722373735039465, 0.0234645166088857, 0.05120786027081552, 0.04144532989049631, 0.016550988694953344, 0.06811123791961901, 0.08174532769067634, 0.034298330935980045, 0.025222460483951915, 0.03211254227696167, 0.030385755197775942, 0.12625070769459973, 0.07326527063043849, 0.045444408446670546, 0.023164966654392983, 0.017843141535957976, 0.014130270555465212, 0.02506177737227371, 0.027955310614479166, 0.05613813019027153, 0.014246037932142857, 0.004247857469900121, 0.01531437818606895, 0.03560413546379536, 0.031828294928756454, 0.0247897376351419, 0.018794594009617166, 0.05127115828555919, 0.06565271621389736, 0.03158551208945292, 0.03513022581295621, 0.04051211605509443, 0.08316692640824665, 0.06612536181966144, 0.03765964512563041, 0.023275166487080917, 0.03169826682536833, 0.04536196206425948, 0.038659221327473084, 0.07984166048587331, 0.05357413349913494, 0.07989934690657162, 0.041293276759285125, 0.11217043299468295, 0.12959898689821844, 0.04529704377355595, 17.892503430766446, 65.12464954007056, 83.34726748927947, 74.28884383170836, 51.684706980182284, 24.173388904140843, 38.152314155332505, 71.78186878081291, 82.16833637606713, 63.729536994811035, 44.97725786701326, 47.5771067988488, 50.06160666865688, 11.678054082778193, 0.1887885180692519, 0.2615424479928709, 0.5042358848356432, 0.11129595128999603, 0.17788100416862196, 0.17111543656116532, 0.09579287511446784, 0.09458253280289712, 0.21173986876683853, 0.014490367311443535, 0.08069585618232528, 0.04093370956158446, 0.059100733919730114, 0.03378539293583843, 0.04349237428076806, 0.03126053567675333, 0.0799959352720649, 0.05738161729588624, 0.042589083839688575, 0.06996696334212057, 0.016620626087270437, 0.10513186995540896, 0.024914378225202524, 0.05098332373064853, 0.056705736224689794, 0.06714399062818097, 0.026914145414447112, 0.06032047613013176, 0.019837117100495006, 0.02594716816900238, 0.5523006089272038, 0.04364890136545704, 0.12656958413220223, 0.01229291879421761, 0.0529046262794685, 0.08983461096161797, 0.006113605716476037, 0.07837955103886705, 0.139588589569734, 0.07963800367208258, 0.029293819435782013, 0.010936018117072602, 0.08142402275435387, 0.05852360924285266, 0.09592435112403286, 0.035747566275418766, 0.06848753264714634, 0.02526376794482912, 0.14641890692855083, 2.033653203998843, 3.7971963084513143, 5.137493485404599, 0.23258190361722825, 0.14998717594050592, 0.09494178207410921, 0.36360178443212665, 1.0495197412467774, 1.535674112458383, 0.2159042154709178, 0.16992165707051757, 0.23640336468815806, 13.37161094911637, 40.80618589155136, 43.952997576805856, 53.413519090221776, 70.06583183042466, 93.04091899625718, 61.21479172860423, 36.47324554381832, 45.55001412668536, 60.111048529225016, 56.53691030317738, 21.42158735182978, 1.2679689161239134, 0.3681250433287313, 0.07945871611516322, 0.16492653397783158, 0.04701401152077222, 0.10604693899832426, 0.042973636995039644, 0.058519047189263575, 0.02746115134458148, 0.05601128518220879, 0.05843612966277908, 0.04430492926809577, 0.04633926042926408, 0.0515102313440894, 0.04837218964953096, 0.03403595731323285, 0.03259640149471741, 0.049478493390544775, 0.03574183210730553, 0.013732148067755325, 0.04155862280317853, 0.06551202416660325, 0.023264339749491023, 0.04318108211361593, 0.015240599130911213, 0.02093614109100834, 0.031926386741801135, 0.02947269139000245, 0.05036702897820262, 0.03468810115009546, 0.03544972661221701, 0.024455558591251893, 0.06704179449908196, 0.02670272621476362, 0.023439318061836308, 0.049530886143686316, 0.03690348187040898, 0.027777220069941495, 0.0478499360202301, 0.019502669925831502, 0.039635343747513915, 0.037802520523508715, 0.043694510410029086, 0.07684846303515858, 0.06245488518728845, 0.023421226895504424, 0.02140533547067354, 0.01878130429935071, 0.03181659102049326, 0.015042997284552023, 0.05083257294890862, 0.026722374454801603, 0.08485499348851942, 0.049414057735233545, 0.0334979031204937, 0.026490537096716227, 0.04342680864576851, 0.01966251991689205, 0.04774272967610629, 0.007650820029553988, 0.018613412300305023, 0.01967701813085906, 0.09191761934949506, 0.06418501815548347, 0.0220756164391435, 0.016925059852280447, 0.06825307909879955, 0.07213194313789568, 0.054923520768962564, 0.03444114504682441, 0.09191680729629532, 0.03983977047966854, 0.07311611331158108, 0.027301349234016194, 0.059621918856376604, 0.018563689363579598, 0.04686602248599933, 0.04263336372171198, 0.046607755094526276, 0.03472842801842959, 0.03701627682594042, 0.04667684856441714, 0.006456647918845017, 0.0456673285413173, 0.03737494387033005, 0.1014783276966022, 0.11621510144323112, 0.11465813498944046, 0.7229637931431494, 37.27168713846515, 89.19022621647005, 84.74876173080938, 71.04274519028203, 42.81352158515684, 50.63598678958032, 71.6103906016196, 98.5185952340403, 80.17683921321746, 52.413165646214644, 50.224204601780066, 66.02967369940974, 51.09625731745074, 7.748097556252634, 0.23316164831480674, 0.3494528759150736, 0.29872948964757307, 0.5179393591900026, 0.18920660289304872, 0.2268209071048806, 0.8493978409997879, 0.14472294148177872, 0.16503023163926217, 0.06013182697877769, 0.05269651849483771, 0.055428637011397275, 0.04281284663105204, 0.04983426462258062, 0.0330720731477824, 0.043171544318958636, 0.03962964405335727, 0.12033051811158658, 0.05768724424283832, 0.021016553509980444, 0.05876221881818868, 0.07084279336155423, 0.09180251463887193, 0.03407499715385418, 0.06434115070489145, 0.07999326162520917, 0.04654307046063966, 0.09313159291782687, 0.11262046368492228, 0.008272038333328261, 0.4600200784062186, 0.16518686597626056, 0.043403921769030636, 0.05302240080650776, 0.1347424705783206, 0.05637804594551844, 0.05717765787736543, 0.05947053988253879, 0.10647517448711781, 0.0165819252405556, 0.07296600604369756, 0.06722401617275131, 0.06752779301736625, 0.09162831390576978, 0.14207983089070167, 0.1037094362020012, 0.05488443113262615, 0.018661336845628197, 0.24464849322553606, 4.734666068707743, 6.859819956364171, 7.6491621425074925, 0.8034640670784059, 0.7764429202483547, 0.38814031609123756, 0.1999233915440498, 1.8164754899278766, 1.7993634146067405, 0.3137549866111048, 0.23988788496823082, 0.5982459048109671, 20.06640257373933, 68.06653699567242, 46.32624726141653, 42.3009305615579, 73.56045969070928, 104.13080876873386, 80.67050087836482, 47.590011396715724, 42.68877844656668, 59.24746813312654, 75.13962945630475, 44.13970631937827, 3.2526136982825498, 0.65975749444577, 0.14238864093297912, 0.12375867730307004, 0.01252265515617065, 0.08519725092957098, 0.018797577922082236, 0.05505871996583958, 0.03087313650476356, 0.010983515568377991, 0.06663884757266891, 0.07387955823252279, 0.017897108599783915, 0.06704846712490244, 0.05045823940646745, 0.09320122264926473, 0.04060372484907989, 0.08723727412401669, 0.04595188423991204, 0.0190159532001182, 0.026209168323886492, 0.03033885529505149, 0.03272038133394334, 0.039956541431526986, 0.025490958979653738, 0.055629045612389044, 0.06878646781607982, 0.016579952564150575, 0.02303904095183938, 0.0221036437658533, 0.01001553283253264, 0.03840711711335086, 0.03665629211032102, 0.055888741757840886, 0.008957008080136393, 0.05751928712631907, 0.02744162376339157, 0.012232393060149926, 0.027610931109877366, 0.01759418594320455, 0.029178764520873948, 0.07160282153035365, 0.1465686311524722, 0.1723651251485271, 0.19444805389690786, 0.12098078120259509, 0.10075398390331577, 0.12456037299407106, 0.183974850562311, 0.12081591142041069, 0.1438180537473771, 0.16515559426719145, 0.19782169061082025, 0.20170650715308808, 0.1689889450227061, 0.10707863726683202, 0.1533236114248153, 0.14002817082068614, 0.18103313422010792, 0.055360524134049495, 0.10695250855097849, 0.14673168530627606, 0.24448116430111472, 0.1743836136114213, 0.1761325923425536, 0.06375096422890503, 0.12204604178306558, 0.19496372300049952, 0.07926222222346453, 0.1473106332724133, 0.2099503333409948, 0.16150414342841796, 0.3185486439014635, 0.1308846662962629, 0.1946185544253357, 0.09817624359481758, 0.12961614726772233, 0.13339555011160914, 0.12291952757345093, 0.14938696137359067, 0.11611228478291344, 0.148692931679468, 0.1651707474863337, 0.14345272173804624, 0.18623516233938356, 0.1715058962544126, 0.16761240759684196, 0.32733303705050104, 0.2957821348982473, 25.50756350640328, 94.73911700710174, 113.70394937453733, 101.42289069391067, 73.52670377300632, 49.3931955675925, 60.27474080362628, 98.51513570354831, 109.58274641344624, 79.2473316192627, 58.12265788355182, 62.71337247663929, 74.97661575194329, 19.155010446425408, 0.3509448474693683, 0.775360836377067, 1.123297072706684, 1.4028435368691723, 1.2629709585059075, 0.31070463900123874, 2.0365729182958603, 1.1150960095467106, 0.5015247303151316, 0.139365520087942, 0.12316417775206989, 0.16088754990168158, 0.19309609257165464, 0.1361319089248296, 0.10110493644230789, 0.15649451063044612, 0.17632809798083, 0.4004159251288061, 0.14973283474964483, 0.15580354528802057, 0.18977450387131786, 0.3121560998260975, 0.2825137984848792, 0.29963381047691073, 0.23575943714428335, 0.2202857021362551, 0.09336746372883359, 0.3531341122523431, 0.261114327417266, 0.1783491145338743, 1.701201688378088, 0.3297827410842142, 0.2543629630799255, 0.13128174498917597, 0.24337605182682318, 0.24333158808369793, 0.38944386065967623, 0.17445125917513526, 0.18950153142213824, 0.1891724660151428, 0.2005213384907092, 0.22452052892936816, 0.15758764148960192, 0.16055914333030102, 0.39701639464305294, 0.11036133934413234, 0.2634624788357366, 0.09570839093817819, 0.4403432020016255, 8.137792877612576, 11.372705409603736, 6.1355302795287106, 0.40142271787889544, 0.8044709517590461, 0.4457473087935679, 0.9216666534062355, 2.8584625644068566, 3.1598714618913593, 0.588845576970808, 0.5334055099275805, 0.35871745297505014, 21.53266691392468, 65.32285082724788, 56.91292047500611, 59.52752144105973, 85.52071555968254, 114.85935411145611, 80.0528609368109, 55.84902463420745, 61.55108005769792, 82.98359317164268, 95.07798625576882, 50.274556067682084, 3.910642775797075, 0.9276230789480672, 0.2577993423948365, 0.2040129833884778, 0.1793813873683253, 0.18523832873230983, 0.22813703083703596, 0.14291281361253033, 0.1240394255446811, 0.1329050699789678, 0.145182594236347, 0.13636812447540222, 0.1429025939996204, 0.13573498344950138, 0.23274895674999685, 0.1493768030477147, 0.09243751725842876, 0.1573154044848296, 0.1459135953336954, 0.16936212177238158, 0.12321490043353651, 0.15333939283605547, 0.14604462701226437, 0.11814488458537287, 0.16494632968979497, 0.16880891436050016, 0.14437761968903004, 0.0873086122315257, 0.14644201214034713, 0.13704470268660976, 0.172435482663493, 0.12126802586980405, 0.15320592499788732, 0.1424685285817231, 0.11487549711619655, 0.161517933011055, 0.17547349625777814, 0.1345761375682008, 0.12707751574775866, 0.10390314919453475, 0.16513497118026982, 0.17728040655774457], [0.07690078684038694, 0.08565542513444539, 0.08052425248728645, 0.043886752513748024, 0.009258632217684101, 0.028920391792311307, 0.08896180698948522, 0.03219685599868817, 0.02972122371917771, 0.012237848563780709, 0.08721422253837509, 0.032458999795058084, 0.03986068084956177, 0.05952115914213562, 0.0322358422131548, 0.02649539217893635, 0.07462090917772825, 0.013194590874557054, 0.031587942503392696, 0.04198794230638493, 0.07295910359149979, 0.023884652633099787, 0.042343996990952766, 0.06256186936591422, 0.10384492651228944, 0.05779248557143635, 0.02891259110202232, 0.051708502559772426, 0.08905644183077159, 0.026204278767709772, 0.015076698449951027, 0.00804916516156687, 0.03993670358472774, 0.04880186921406177, 0.04169264222465215, 0.08569117845787157, 0.06696864842407166, 0.030085517679371183, 0.043321318338595094, 0.04051541023316883, 0.03516985171083962, 0.05388993792416108, 0.027066313458846945, 0.12242286511126066, 0.04300297050166034, 0.1859628027605434, 0.12321056437588508, 0.10730489367438902, 4.205794267116055, 49.73568908629879, 75.81843483832576, 77.49245535942816, 67.06666992556664, 38.13351031272642, 31.208416723435928, 48.768981733629786, 91.74721148706253, 92.33974041477327, 67.1552998019803, 53.29402408292217, 70.41461683088734, 40.376870709080855, 5.230358050715539, 0.0610865946979292, 0.13996083169214188, 0.3287429452663468, 0.4837972412426626, 0.14481894762044953, 0.04732006747696189, 0.2594154814798986, 0.025767353926635077, 0.02966273865181833, 0.06406766114636295, 0.052626551684713176, 0.08606596399218806, 0.04080966843532459, 0.0336116939903267, 0.06488790765645043, 0.036253571179845644, 0.012545509474171747, 0.11176824449531494, 0.019102423459351547, 0.03242225438776997, 0.016829344827020844, 0.053968331701452696, 0.11900373809640447, 0.05148582378282182, 0.06536662067857481, 0.05556705760799589, 0.06540576011062631, 0.029339344210682378, 0.5698132563021876, 0.11761343407054102, 0.1963216904550791, 0.04950131131936947, 0.09583812792815509, 0.027342130009445454, 0.03460300027302677, 0.06643596450768172, 0.12258162151180929, 0.09598410598212674, 0.07996725294017985, 0.02773751181760623, 0.0879036633658313, 0.07324784213016111, 0.1240060853982164, 0.07255750497983349, 0.09321302040329865, 0.040890264715398514, 0.2534483000636101, 0.27689681118053777, 2.2337569632837853, 9.543693411734797, 8.046039323652945, 3.632060111530366, 0.7823378748951421, 0.6439227634860624, 0.050198079777821425, 0.2688085161630185, 0.01997315707886892, 7.693793812105733, 34.636266231536865, 64.59048155815371, 56.426119035290135, 74.77289568993353, 87.08734158546694, 62.12191043361541, 47.63732694810437, 41.243714517162694, 63.76354394420501, 71.4360490922005, 47.49876137702696, 6.763311999459421, 0.3109542610904863, 0.054976786862337784, 0.22541234720378156, 0.08208126490635258, 0.03411039041595594, 0.05509161578130819, 0.03897431329072964, 0.016020950654731886, 0.057598282282631245, 0.042572566984041084, 0.012486939179530789, 0.03671623082951673, 0.0211684400170681, 0.012058730503814596, 0.07712533487187279, 0.045724141621781934, 0.0676409671864202, 0.0037405827747387516, 0.05252227562689974, 0.009645064203669469, 0.010457921795727266, 0.07796823077144162, 0.07990051902109578, 0.028948524456110694, 0.016896390926934058, 0.057347783022710395, 0.0034528573873573018, 0.06869102858247296, 0.042778322878744335, 0.10909210019294294, 0.08229318780884629, 0.028289933989365256, 0.017881421034314463, 0.08341906126588584, 0.062083750061931155, 0.026602090989810326, 0.054248428768328125, 0.02585241649930756, 0.059031966037207076, 0.05556127747460719, 0.08436447505148188, 0.0520484196022153, 0.003967516451901306, 0.05672701048634707, 0.0916946954244087, 0.030240047189797607, 0.03784628712662286, 0.0725959166283569, 0.059730270501947215, 0.0002058616208218624, 0.12554660394427278, 0.08325979158642792, 0.030570537520332203, 0.05160092849344496, 0.010252181222782502, 0.012383523055412357, 0.01777784977739136, 0.03845232779220228, 0.038548567587690014, 0.07552497719805087, 0.045082006723650044, 0.01325472686139326, 0.05850023590028287, 0.06174225870880389, 0.03579866050952866, 0.04605833598743043, 0.04562349682072959, 0.07524940771080794, 0.11307288456948535, 0.037850263122949875, 0.03151086831255065, 0.09424563797731554, 0.044937633623879765, 0.01721583043916091, 0.033261457743543776, 0.022082074560345184, 0.03332152669768661, 0.046388784183129195, 0.055981177926784566, 0.057096398931237004, 0.1364869906777336, 0.06496844647993004, 0.03771622837971776, 0.08937965432602553, 0.09413012724009254, 0.028955331147317926, 0.05971206059198707, 0.03322964594248803, 0.07325445346894764, 0.00834198407603488, 0.26440528792239004, 13.412396734760655, 76.52998416654526, 92.18785055222051, 77.41311365558256, 53.47572788115471, 46.49259498042446, 52.67567419236707, 80.86400708844586, 98.62302441750803, 81.125621334199, 54.201895883006436, 70.86919599963774, 72.27343590028825, 25.88862765219904, 2.3721590205546352, 0.1094411451730036, 0.3861601013810404, 0.12491232144736475, 0.16476570147900813, 0.08868235343646619, 0.056049758117766156, 0.04114007832662713, 0.04090289367483028, 0.09786985439038086, 0.03309833081138711, 0.0666259236693863, 0.08919020844323021, 0.04975992728084807, 0.029012783911199342, 0.020896436669112697, 0.041591802071179115, 0.028363129860090635, 0.04774176440532169, 0.06956269874447776, 0.0826574013298077, 0.027853428581429106, 0.09707250241791049, 0.06563780814289086, 0.06173597678782479, 0.09232456525487286, 0.05365297543786226, 0.05582899839106587, 0.03253178963918359, 0.9207513315543052, 0.11975900119831485, 0.24070957555405556, 0.17175159597348783, 0.11132751411247639, 0.01156299309279289, 0.05748875852253649, 0.1391010512147219, 0.09962740564538587, 0.008666184824711133, 0.0766598675099592, 0.004834821588555051, 0.02818677258948165, 0.08928711856565169, 0.14190514752220723, 0.06642702426160536, 0.11357654907530355, 0.028672211863581213, 0.3185389605501006, 3.56035158518822, 3.3283551566062437, 8.761571818782437, 8.431765206398504, 5.028822748891769, 0.7945393266216402, 0.13501401810396102, 0.5744322761893272, 0.3644480664403208, 0.03837462732448213, 13.51322518241021, 52.3258379966982, 77.5209709905809, 48.553176849119126, 64.3874361438136, 102.74998541801207, 87.7990556532337, 64.36477661132812, 50.31229711348011, 63.940050601959236, 80.58667198304208, 68.86177401388846, 22.803212827251805, 0.48167793560893307, 0.4062989288039746, 0.15657232984179453, 0.06566500426420281, 0.03376686126895009, 0.17011045177857723, 0.04699782408293217, 0.060110797865256194, 0.06568064011873738, 0.017393053389124332, 0.0459396000200462, 0.07740456625939378, 0.098755007699853, 0.011950780096794329, 0.0313669472046557, 0.06371161795311397, 0.08059043482306504, 0.0512042251836148, 0.03400383907700739, 0.027840809198096398, 0.015639287566075164, 0.024088290294692404, 0.09180475927649007, 0.03946258709014904, 0.07028903436636733, 0.06202883687951873, 0.0265202957821349, 0.06236397353331409, 0.04207047678890728, 0.05073074837245288, 0.077670774152202, 0.025754123588182756, 0.04583929229768054, 0.04935161390852544, 0.018209419663875334, 0.041510746138350624, 0.04216259503136239, 0.04792370645689869, 0.08769726395727166, 0.04071489952865147, 0.037899166345596313, 0.08090181892076809, 0.06888892441507309, 0.2108516051403938, 0.2505037491960872, 0.17093479302862, 0.12435707624160475, 0.14696031658639833, 0.14644689978130404, 0.10033253595353135, 0.2734737464737508, 0.17439996192772544, 0.07245493346765157, 0.20026678279522928, 0.14777796222798287, 0.060378189363907424, 0.19111368684999405, 0.15244907609397365, 0.09588122803477511, 0.18990856925806693, 0.15141410663002922, 0.12048117696277558, 0.21485772404459216, 0.16552043598025076, 0.07331328902153239, 0.14149138343430337, 0.15164970931026245, 0.17455563099393923, 0.26690252005092563, 0.17881959977169193, 0.2076612013362108, 0.18121089726205797, 0.18697630644084948, 0.14048566320730796, 0.10736742177076879, 0.0688341414676078, 0.09402500465512277, 0.1315259584976781, 0.14421001497295596, 0.16388549709752684, 0.29278501507736027, 0.11535565804449782, 0.12787594790420226, 0.2492323649987098, 0.258874133109085, 0.08271669653514702, 0.2072009203895446, 0.15933651296842485, 0.449406604372686, 0.18490756261012248, 0.27212414469930435, 6.917553813226762, 72.35230691971319, 107.73043847853138, 103.62557611157818, 90.29121198961812, 63.208281455501435, 51.648997722133515, 67.63740616460001, 110.23316952490039, 115.39574607726067, 84.51008550582394, 72.40572175671979, 92.02486038208009, 57.50398243627241, 8.352549998990952, 0.1845530937275579, 0.8834435237992195, 0.8883281616914658, 1.3970607374944997, 0.1936138913996758, 0.22819381327398364, 0.36120641135400344, 0.28498394174441216, 0.28599716963306554, 0.17638679563758836, 0.2318105756515457, 0.22852696959049473, 0.09780316643657223, 0.12935175500329466, 0.14628090384987094, 0.15382883108911977, 0.12320396069797779, 0.14337752254739886, 0.23307229181931866, 0.30086362674351663, 0.2187111922689984, 0.1781258611909805, 0.2159084442762598, 0.1451515063883797, 0.23223757773878115, 0.16925998693031652, 0.1819044060163921, 0.12303085547060737, 1.596222392493679, 0.2652290163020934, 0.6110659265710462, 0.39467115435869465, 0.4697219690968914, 0.21017073683681028, 0.1847220774018957, 0.19207063791972978, 0.26561279570864094, 0.1689707274518667, 0.22282998738509996, 0.15216916288820007, 0.16896069170005862, 0.2768053402823787, 0.4376830995803879, 0.2709783529562335, 0.2751492726947031, 0.11725312759799343, 0.8437304451100288, 7.465343696455802, 6.136336816895393, 14.084591942448771, 13.056453408733493, 10.696245604945767, 3.218674900070314, 2.2487769444142622, 1.0579604367094657, 0.3870405815541745, 0.09019823459487769, 13.160996340936231, 56.65402443178239, 89.45287596794867, 69.59635549975981, 83.62330036778604, 107.99979548300468, 85.70265077775525, 67.16316023180562, 62.798036836808734, 84.03224668195172, 99.6427700596471, 81.6980363476661, 21.655252748920073, 0.5350058982449194, 0.7103972545554562, 0.4469659708199963, 0.24894411675632003, 0.18375247055965085, 0.3847808060386489, 0.15668845344935695, 0.174158199900581, 0.1776784658432007, 0.09153493544867924, 0.21367047162305927, 0.224107040633117, 0.21746550266060138, 0.1729382508464398, 0.19274474932782112, 0.11050095886833246, 0.13111971739319064, 0.1336699628060864, 0.11941998430918302, 0.25206089951097965, 0.15160314648622467, 0.10552496499111576, 0.1149566181664986, 0.12780364452590867, 0.2529299649740419, 0.15996556308481003, 0.15319311600779334, 0.1695732402825548, 0.12371759966857011, 0.1779518826233764, 0.20874725354294624, 0.1962427680771197, 0.16269332639152007, 0.18046478891084272, 0.14829105727614897, 0.11787748159540277, 0.2324579199475627, 0.12339096276029465, 0.2183620860019038, 0.11088955696792373, 0.1810944978628428, 0.20938502173990975, 0.15265297805590017], [0.05470304066435464, 0.06473929426001926, 0.034020275493422826, 0.03551781267648743, 0.02840127720828018, 0.04433591752463291, 0.01491674024897117, 0.06142206459997162, 0.006347414793356532, 0.0504883696445294, 0.010162975072049567, 0.04870670960254727, 0.0062815417655773705, 0.013787140731789894, 0.023182693928960833, 0.02923446102818895, 0.006950537142749395, 0.07582600378701765, 0.048877964727580554, 0.047128411430505016, 0.07800528644433907, 0.0735048646287572, 0.009699470810441962, 0.07630635623729999, 0.09749631757938093, 0.003416614485867021, 0.009548665444937446, 0.02349493987557869, 0.03580484666951722, 0.03271506085330921, 0.10479279177924318, 0.029651534615925727, 0.08180900491894254, 0.01530845249597464, 0.05783812525952536, 0.015567512788449325, 0.05982294415814742, 0.044291093720183264, 0.04093072947955901, 0.04308179328818956, 0.08442901795910251, 0.09318364859228173, 0.07135652426269747, 0.048870127648115165, 0.014079862927657463, 0.22981398198152744, 0.08737107137999228, 0.13287048877006577, 0.05327994424489237, 0.612761248503962, 21.122400722196026, 67.37531338968586, 92.4091899010443, 82.16857956301781, 63.27131002180038, 39.1849918519297, 35.184515522372344, 68.41221547895863, 82.86004635595506, 76.45050125737345, 60.049047623911214, 70.62915478983234, 61.64509927072833, 28.613329548989576, 3.765318470616495, 0.05739386321135587, 0.15917667638390295, 0.21530397026048553, 0.1670777854780036, 0.3479848675910504, 0.12358539587547704, 0.2133564368611382, 0.02388268953279382, 0.059437222718711824, 0.07447586575102422, 0.028574051102623347, 0.07632890220491156, 0.05286269062649339, 0.060249681945049, 0.046218456024484295, 0.017200968333429868, 0.06838778033852577, 0.02657025046045742, 0.26174990460276604, 0.06876559192014318, 0.034921202553255905, 0.08539991182906014, 0.03660793281010082, 0.04462536086418456, 0.07319911893817686, 0.1524988871308104, 0.25502287121790074, 0.14878746692932424, 0.14945017894910229, 0.23724117376390966, 0.030794848064561526, 0.06580364319585985, 0.04159564783255901, 0.23189515175838626, 0.11705605147947228, 0.014002884497805951, 0.04888156151038505, 0.019285572099409277, 0.004289000221873604, 0.08029221977678039, 0.0810134838966112, 0.05296632700089005, 0.14368242554126248, 0.0685389984338995, 0.2563587140532271, 0.30578378047193255, 0.04190288356415207, 0.03920702781948832, 0.027823039788692713, 0.1384684004850926, 0.09474803843805868, 0.3223439660524169, 0.1809025162290181, 8.208868186320029, 37.2575391492536, 56.40434203609344, 52.56935834884644, 71.80626592328473, 91.36532952708583, 85.94218207943825, 52.03693189928609, 41.920295915296, 53.229332431670166, 74.39507730545537, 64.5008122536444, 23.50823337031949, 1.2259081150254896, 0.3094131373349698, 0.055457016738552245, 0.03903871447208428, 0.15406567483179032, 0.05983811269904818, 0.07786174454996664, 0.10089249260002568, 0.07487724985807173, 0.035459088206651716, 0.09183077562239864, 0.023886872372860392, 0.01582166916059871, 0.013825142523273827, 0.020989985580766396, 0.042038611361696836, 0.03672285749006175, 0.08741348966835968, 0.055063006227775935, 0.045963762433178006, 0.04305528664600946, 0.16232131409548944, 0.035627294301746354, 0.021219434659747828, 0.015334059942453621, 0.051480553097902775, 0.03008425363429612, 0.04749108128429902, 0.04459036979824305, 0.021970501515052972, 0.018809752974418864, 0.07132580413693382, 0.047309736781302965, 0.005947367988541843, 0.1031737722035858, 0.0633636263439492, 0.017160444197455244, 0.015901250374172966, 0.06124761105785447, 0.030154088294253718, 0.013370903137500488, 0.07509786019762678, 0.05710990889178169, 0.02064949780281994, 0.04414641035480365, 0.005971490660862577, 0.07273797997303548, 0.021238521740381277, 0.03279360018730645, 0.016739737437737566, 0.053132667671889074, 0.023273389163096587, 0.08734549936507979, 0.024705376032920136, 0.07653755391196859, 0.02231040515095717, 0.06232454681829099, 0.022541717738814415, 0.06208187314651667, 0.019349069297013265, 0.022325138936960892, 0.024401187416045897, 0.06657147013972844, 0.06979673094446621, 0.06075532678815146, 0.09157569132625096, 0.012755490343777404, 0.043798901381031166, 0.04505208332932765, 0.028324609044038003, 0.035579436789116556, 0.03793069469412008, 0.006331570179862601, 0.05890713200994557, 0.03796220389044574, 0.1441139169037342, 0.016329060684168534, 0.004720407314673668, 0.049760214563819676, 0.04218758864989204, 0.0716765881365826, 0.021113254873442556, 0.03797113647564285, 0.023481050701511484, 0.09601045940672198, 0.013604566657675371, 0.06689520357477088, 0.027140332874090924, 0.021264978586846305, 0.044832036064396945, 0.07447997964317761, 0.08107791189104319, 0.02425377869287566, 0.11907349806278945, 4.347988030602855, 44.969581788586034, 86.57445246173491, 93.24789462550994, 70.80546532907795, 53.10889997789937, 44.046526493564734, 62.51879153713104, 92.74346997660976, 94.52501835361605, 70.57135474297309, 71.88972611581126, 84.57624804589057, 63.59927900375859, 15.271682566212071, 2.0684342086315155, 0.06131111208589808, 0.2509704959248343, 0.43013388531342633, 0.03902082248861271, 0.32827017708651485, 0.21849454260401188, 0.20790590514098445, 0.09900885859444257, 0.19399806917194398, 0.0328657005523001, 0.041991592715344125, 0.0851856217148804, 0.02398637761812537, 0.025155669108273524, 0.04556743450643075, 0.031091362395654285, 0.05543052924857025, 0.09396048473013986, 0.07516993374954309, 0.11055376530895311, 0.1344856472625848, 0.16741564557436975, 0.04279717247212126, 0.047802342807934176, 0.026177682110198566, 0.08869120175199163, 0.15639076700374005, 0.2171686435899427, 0.2641573818700929, 0.17215817415666196, 0.05851314065136737, 0.10996904870074604, 0.07372582736875742, 0.1358859334141016, 0.10563711260235119, 0.052401072856399326, 0.06979952716538984, 0.05204063997934422, 0.04933092953456987, 0.08986613547970211, 0.10356482944541401, 0.07180227252144007, 0.09989764316067581, 0.029890500422146533, 0.5483436115807103, 0.37603704619311523, 0.04688188050603194, 0.11673108464287174, 0.14947302369100435, 0.08949162573703835, 0.1697212331477673, 0.29235502524722007, 0.5945627992191623, 14.193637755609329, 49.64870660535751, 66.8706298643543, 64.33352708816528, 80.12427160816809, 100.57586269993936, 104.36490366535803, 63.91067597173876, 46.34711034836308, 57.18999278160834, 80.15484256129112, 83.4139399374685, 46.31538621840939, 8.09498461984819, 0.46832413442673226, 0.06878357966460528, 0.007943202273905157, 0.048730554089190505, 0.100997822028735, 0.04690618464542974, 0.09164902892324234, 0.08003713548063271, 0.009813057709365122, 0.048632065825645006, 0.051880224998439514, 0.025710316765452587, 0.042920298123311613, 0.05883328879492418, 0.02600274976312874, 0.09174164895328785, 0.031913960795669306, 0.05360915903903304, 0.04793628945105499, 0.0707326299180427, 0.011439120505876359, 0.017559215944680958, 0.07420176715259591, 0.03889110848127354, 0.021049853436829104, 0.032284956109980424, 0.03874197797549348, 0.02196344393005054, 0.012471169259609475, 0.048663326043395266, 0.02940781714935457, 0.05184005517812987, 0.0536737249292914, 0.0822759738131877, 0.007367009351465612, 0.04305077055769582, 0.031138993912346424, 0.017148709645675077, 0.04501063797262408, 0.011827875653492107, 0.03712881514201722, 0.0344041315087628, 0.029966933014351996, 0.047373731936057734, 0.19265824267941137, 0.17812966098708494, 0.12300746680627908, 0.19152221089649588, 0.14392818654737166, 0.16349399552470253, 0.13160543245894293, 0.12122823526301693, 0.10859157664761429, 0.14707251782378844, 0.1264837286585281, 0.13273080029795248, 0.047863606859238884, 0.18415420706714355, 0.12738201271502242, 0.09993967074420183, 0.11102409732918586, 0.1561882133565603, 0.2562766507147782, 0.15363099654355358, 0.23365549923431492, 0.16038107385318126, 0.20946426587479733, 0.17730136672335287, 0.12936229637313273, 0.2809773938309762, 0.11673182008727906, 0.10241290133806968, 0.12840008227935723, 0.2040133970759569, 0.22620321041153324, 0.1346719751675283, 0.18809105630122847, 0.13732461589238337, 0.16197013939099927, 0.2276339255754025, 0.14026441701477574, 0.12233884058772557, 0.14651544932876864, 0.11637540534138681, 0.18523889563737378, 0.15600665051850582, 0.16392490466035184, 0.13061993695314855, 0.14387981575583259, 0.26184155936202697, 0.17738505416820127, 0.21772630963354342, 0.13000679082207142, 1.177588927169, 33.26027524086737, 97.4595945112167, 118.53961206251576, 103.98473970351681, 86.2657227054719, 61.8958838524357, 55.50751170804424, 84.75189178220688, 102.53074061486029, 94.23972083676247, 78.6312763152584, 92.70564263866794, 81.10094178107478, 43.097532564593905, 6.409713760499032, 0.18016961523361746, 0.7890236774279226, 0.853024133511128, 0.3640777701812406, 1.3848643725918186, 0.5234081850897881, 0.40619336188800875, 0.39025487197983655, 0.5719686599989091, 0.2895280995195912, 0.16587968525146285, 0.2893624406668448, 0.13003447723965492, 0.18664318076785535, 0.19041077053594976, 0.08830975891361315, 0.2845553615160527, 0.3198425970490902, 0.42008838886695526, 0.2773162902843568, 0.34853384619758976, 0.2268732921971429, 0.20167328958069125, 0.20084419858551797, 0.27295709677761604, 0.5246939870619005, 0.5210677558375943, 0.7341940905297957, 0.5601342563186923, 0.7883235956391981, 0.1286685731141798, 0.12911797561232122, 0.18216527427636808, 0.3651068714116851, 0.18191444176820018, 0.22158886366073163, 0.1903727112878715, 0.1126289519391233, 0.22218681060739104, 0.20633496524345493, 0.23171135194359288, 0.23132728142363412, 0.2699281689861129, 0.15085072557051338, 1.1376007309844418, 0.7075637711151954, 0.10307955871065778, 0.16469064018418714, 0.26660276516791315, 0.24239250218435643, 0.21709247912851073, 0.9902458637952806, 0.3831917251790724, 11.633628337613999, 55.09754950000394, 78.54501555042883, 71.77542040424963, 87.79001851235667, 107.79007419463127, 107.24268390286355, 72.20923454530778, 57.95804385216006, 73.49730168619465, 100.25032166511782, 97.2694693842242, 44.83867268408499, 5.844131515872094, 0.625838001649226, 0.17732352198612306, 0.2627374838677145, 0.361034409293244, 0.18884116363140846, 0.20522810608869602, 0.29984126708680586, 0.17326017631398094, 0.22615140754609342, 0.34993290660842774, 0.2059480601981763, 0.10393786829926314, 0.22422566168731262, 0.14625537780023393, 0.13972787967612668, 0.2673222749463974, 0.12290926199526557, 0.1929627319857959, 0.10402690303782303, 0.1708895325540535, 0.191824447904383, 0.10476261557590578, 0.2801955857824895, 0.15720802960136246, 0.1690501401260976, 0.21069800451157555, 0.09435647557820044, 0.157176558709433, 0.08533301703151196, 0.1248467902863218, 0.11808190449711778, 0.1880693147259374, 0.17153002802402745, 0.2506941833323048, 0.14932205840464563, 0.14767689990901178, 0.10091807993669664, 0.1767399315271647, 0.16907532909704795, 0.12048975714752752, 0.19094707804822153, 0.07803352444522804, 0.25138517931824733, 0.13527454928525035], [0.041347638358392065, 0.010182645337115373, 0.02223660981643104, 0.01619343630849354, 0.01683251068536793, 0.04740679246043006, 0.017072660097431754, 0.04714771684619689, 0.020126715572851322, 0.015208153392098125, 0.04459074901176557, 0.0075171640210394425, 0.05772449909859608, 0.016166923920654, 0.06754262447958032, 0.05551012578390299, 0.09284421801567079, 0.06187496045904775, 0.02843200691014288, 0.09634506362940996, 0.03418265548985332, 0.06642874029855575, 0.018499131134200483, 0.009440601082338441, 0.05264543192160707, 0.0242147158696166, 0.01714117325571997, 0.0498119599726652, 0.04651836029464199, 0.020078294985597173, 0.022965285836929278, 0.04039399295804962, 0.03537106853459151, 0.04145187611180929, 0.04544753791584123, 0.007459630339121026, 0.012072658939887921, 0.10341751839845412, 0.0810277484537613, 0.019549385967454123, 0.0272939411637884, 0.033703865858936505, 0.03942737768914911, 0.01166846137493849, 0.060380253970863364, 0.14629930528181215, 0.042618080267622586, 0.10740117560471259, 0.06132269150487358, 0.0903967509586965, 0.09912155778898347, 8.830765370399721, 42.85473785092754, 72.55119462167063, 85.51990755142705, 87.50789811534267, 66.11554222722208, 54.507644637938476, 49.8504380256899, 76.08335171976398, 81.00335321118756, 80.27226263476958, 63.192980289459236, 55.49692130857899, 54.759437268780125, 18.55587036378922, 2.7122066963103513, 0.28476621955633163, 0.39834368793714436, 0.18836280300972924, 0.13520468206655595, 0.10714800652837563, 0.5402771960343085, 0.09191827818510995, 0.13157319547908922, 0.020948419565214746, 0.032116704049610326, 0.062363525371878385, 0.03727392368619481, 0.03713473317123229, 0.035163259524251186, 0.24526344732411448, 0.0546438105764889, 0.0534884350734853, 0.05050110202583094, 0.1457210161512898, 0.21904555900442987, 0.08008776623154841, 0.11911334229573128, 0.06752144214847396, 0.0509690553430588, 0.28744234853694517, 0.03730499621240362, 0.2490124671209243, 0.24994974505276452, 0.28514141877812726, 0.1742329547602323, 0.22491129505778515, 0.33697695020706425, 0.17835846080655055, 0.17233716293929086, 0.15766595099722186, 0.08558205689393705, 0.1323312854454402, 0.14781871810555458, 0.03686718079411695, 0.15230417822397527, 0.3108468249199852, 0.5835293557855391, 0.45027461263441276, 0.09723660611217061, 0.08455324677690383, 0.25342874949978245, 0.0920647771788701, 0.30467163531049607, 0.2684351861957581, 9.024161754115935, 28.365090585524037, 62.52048992341565, 59.35042250540949, 57.87209687694427, 54.53425399718746, 69.3747494297643, 58.50932905750891, 51.059508631306315, 54.21188615983533, 66.17524070124473, 65.09484737150132, 40.307181958229314, 4.820976843757014, 0.2620521416106532, 0.28092422732903116, 0.05581790160748267, 0.09804302090478521, 0.04171503497467887, 0.06024849450876636, 0.06902769358167726, 0.04679523979223544, 0.03722990810450527, 0.06341370934199902, 0.05695050897737665, 0.05100838246665174, 0.0417892765554209, 0.060243361719673684, 0.0989693284575497, 0.009206955756751761, 0.024246092915775317, 0.03561847662973789, 0.020305899707900903, 0.06720125570052093, 0.03130465084987302, 0.0514641473250043, 0.01970257673923287, 0.009783325837023798, 0.02420898553194298, 0.030115781982819882, 0.03733434887122243, 0.05693040299980391, 0.03333866791499238, 0.04041060557468765, 0.068381414147875, 0.09971508440831978, 0.008548931237460386, 0.027876338440804716, 0.017094633414319927, 0.05181448699365701, 0.04703745764169482, 0.10483954612526203, 0.076923348129757, 0.033876626346741, 0.07808179564533696, 0.019907376939250578, 0.02710932355013586, 0.038971536222004124, 0.023322794173333435, 0.018307791099012382, 0.014615516392363897, 0.039572068715407964, 0.007278941320105186, 0.007992741828333707, 0.04359250580291114, 0.0582161590066408, 0.13648859946237457, 0.030287887465449113, 0.01903565315109107, 0.027001584774904677, 0.0859322969711596, 0.00568843888862419, 0.05097130381111657, 0.02312876708475092, 0.011888189755770709, 0.045662191921785, 0.005351591464732924, 0.0364253778881844, 0.009267350298262412, 0.045949333167124184, 0.016159194093498013, 0.03291892451083949, 0.0721646627531417, 0.02917483065938277, 0.08034534031344999, 0.0063124447948329394, 0.024339775892815763, 0.09575849308842614, 0.03464921452705899, 0.04696497423273902, 0.05043008567525014, 0.042076130517788475, 0.04987022478974635, 0.07527864928687773, 0.036870574563621514, 0.03676590014008745, 0.03959585191501726, 0.02071281305454191, 0.0767083149102907, 0.04475629678176296, 0.06998107468168582, 0.043992284955757285, 0.02666645386676875, 0.07998992148185931, 0.027602128759627382, 0.09211798198521139, 0.05021065894153811, 0.05115122722101308, 0.09813652959682288, 0.0751490501927272, 0.3249686445680357, 22.42337638331998, 71.08519308028683, 95.67300196616881, 92.70061416010704, 75.54620665888633, 56.88999422134892, 65.4514104320157, 67.8845468644173, 88.64310264587404, 86.03091393747638, 82.53059079570156, 68.31241469229421, 78.19519504424065, 50.40982684781475, 11.718904587530321, 0.5178102886965198, 0.11822610522710508, 0.19307599042452153, 0.23740052005216, 0.05720645895287876, 0.1441281048520919, 0.2447160468586991, 0.09393194029408117, 0.09564911871547661, 0.06543665643661253, 0.0528821645815286, 0.10652556775077697, 0.013074536278333156, 0.06313556196889089, 0.061916938246858705, 0.02156009480747725, 0.152532824825856, 0.1238809296140267, 0.036175763459816095, 0.21341560949240962, 0.3269762852259221, 0.15611701314487766, 0.07020848788200848, 0.17466899668497426, 0.12607108305899367, 0.21688998676836493, 0.11672127105656172, 0.0853064644240564, 0.10607877761245736, 0.4781177718072169, 0.21628410315080998, 0.16819046690098702, 0.5300526188746576, 0.13021375713569502, 0.18412025405033944, 0.08493222281216614, 0.07852447189150319, 0.05432496478240337, 0.04289412472937857, 0.42631613210805, 0.26422645235734604, 0.18162532018557673, 1.6630540643968892, 1.057115656233603, 0.2400063221613246, 0.1339785123784696, 0.2655832553582807, 0.09229325524140751, 0.30981582379148853, 0.4128208191644761, 11.53758223979704, 40.00856407227055, 70.49989700317383, 72.02395746784826, 67.9310191062189, 69.94959631273824, 90.62915555892452, 72.59515654656195, 59.02519918257191, 57.757822544344016, 71.08979794286913, 81.61219919881513, 61.47493508554275, 15.49595977029493, 1.0973748636822547, 0.32385435436041127, 0.04141198208315238, 0.11379328300996173, 0.04813267609044429, 0.09916178506588745, 0.02965515438136795, 0.060751086491490566, 0.020209426255596262, 0.07632461977341483, 0.037784115261127876, 0.0539607972267174, 0.014026259755595558, 0.025750578516313148, 0.007354819456175451, 0.08439520283812478, 0.04922195352734097, 0.09267486661912934, 0.03564075829701559, 0.027201234948851412, 0.027769264246847843, 0.0431929603068819, 0.01931742986574048, 0.030176015645866434, 0.04910785622233826, 0.04956794564702338, 0.060078936268485365, 0.014631382073275747, 0.02349183147382592, 0.018613636381022872, 0.042447736787219206, 0.0483095734530399, 0.020676287897532026, 0.036282724655804136, 0.028397958132348237, 0.03277501106382378, 0.0526822884116442, 0.020344612045934605, 0.02309244111060135, 0.01595958030872768, 0.04751067781340211, 0.0353796755324208, 0.01479727266761925, 0.006949678166664296, 0.04137409137441747, 0.02415880294246299, 0.13840722070345957, 0.19708079165749012, 0.10585160189939123, 0.170693643871815, 0.11079902069703226, 0.1577810174034488, 0.15692601731467634, 0.13102679092797542, 0.06229495667221566, 0.16252726917305302, 0.16653249941525922, 0.10456288879316662, 0.18627222567316026, 0.08454638262910229, 0.11412090817165953, 0.16607270876486457, 0.19120794630819754, 0.09327012459717451, 0.14755170582042587, 0.16364546642909128, 0.11079905134054924, 0.2506677073336417, 0.17598852184751343, 0.14302850821085517, 0.2117770393529246, 0.1231334116610308, 0.13217560105746792, 0.22486961987470427, 0.1414367307217852, 0.1957690039829862, 0.18858274685279017, 0.13543286901568213, 0.18236621913890685, 0.18682630642527537, 0.1578042298675545, 0.12297697650689272, 0.1251420405723395, 0.1664384084963991, 0.23692821152508262, 0.09856326355328483, 0.20356123666128806, 0.10575529698642994, 0.1831784715215045, 0.1756614482691211, 0.21768336274450828, 0.3775247582985509, 0.1502003628880747, 0.2221287104992136, 0.20408452067884708, 0.11270731507289795, 0.12571659119379136, 11.895882910297765, 60.77916545252646, 109.14927744096326, 119.47414813503143, 111.0304932440481, 89.65665094314083, 79.4588807321364, 71.12134948853524, 94.52879167372181, 100.5207141753166, 104.40373513006396, 78.09319773027974, 78.87445542120165, 77.75028059559484, 28.9953056458504, 3.998363642923294, 0.34612989293471463, 0.6797732268610309, 0.2768363821650705, 0.25121542955598525, 0.18386119375786475, 1.5098553559472485, 0.38257762909896914, 0.5294629763210974, 0.14844865688393194, 0.25501516437338245, 0.3929384166915571, 0.05080320496833132, 0.2034945563683587, 0.5899890704501061, 0.39673959175425194, 0.43450411048627674, 0.5223572963187771, 0.44588627714303236, 0.691619029929561, 0.4602245013079336, 0.28793803806747165, 0.768031397413823, 0.7896954446069656, 0.2449815882550132, 0.8096577347286287, 0.22224340918323687, 0.44029463202722613, 1.1755599586233016, 2.693434968110054, 0.6361213530744276, 0.38933409558188536, 0.6229758971641142, 0.2754886190016424, 0.3563117530317076, 0.2576075752656306, 0.2347580070096639, 0.41794150406795166, 0.571960324962293, 0.8646949620977525, 0.5868376911647859, 0.9710829404573288, 3.9975955938139274, 1.2480748997580622, 0.23643946275115016, 0.1797418777019747, 0.677923645463682, 0.2798008972839002, 0.437714968838038, 0.2586201289969106, 15.576596836889944, 42.47505241824735, 83.6848972689721, 78.35491395765736, 76.59009056706583, 71.75132136191093, 91.46571082453575, 77.8085748610958, 70.13390064239502, 72.91284499629852, 93.86874306586482, 97.55876771865353, 62.295334108414195, 11.10279437034361, 0.45599106879484275, 0.5892207761926036, 0.17931220962876276, 0.22839671932160857, 0.17571047789627509, 0.2512264765438534, 0.09662973424119335, 0.1445729261444461, 0.1325938697423666, 0.19199694026141398, 0.1083365076732251, 0.07417558992822325, 0.16572911833082477, 0.11315754494599758, 0.21841577344363738, 0.16185370934826715, 0.10737167355874855, 0.193631787213587, 0.11930772944563821, 0.25702632903572054, 0.15533304472844447, 0.14210647542870816, 0.11862959607594437, 0.0928582527464436, 0.13904619931934342, 0.12646091456014302, 0.13567458507755112, 0.12488996700173426, 0.19923739045137362, 0.305784362698755, 0.1207291826065029, 0.18889857426045403, 0.11659875827571077, 0.11660296409841507, 0.17763979372478303, 0.14187646519032218, 0.2666818560852159, 0.17774241886311964, 0.1591186069192425, 0.09769537020474674, 0.11316000408823453, 0.13670691919903602, 0.1811975366886585, 0.13285821604151882, 0.13342288412874745, 0.1499167264949891], [0.0424541068083096, 0.07337111333805708, 0.0249239485785966, 0.02332961427107934, 0.043909666203563257, 0.05018391481210148, 0.05159761899361207, 0.049691239837557084, 0.03134607322393887, 0.09293037226363536, 0.005505332383402293, 0.0640815043551547, 0.03844958136699373, 0.05468466604549078, 0.03649173642418558, 0.04812563574242015, 0.07947773041744387, 0.014069797489942323, 0.05740327077106603, 0.08566372186666535, 0.08526020803518834, 0.02828368654234275, 0.07277672103936635, 0.024131589584172736, 0.0361683898635449, 0.11256492231041194, 0.03677231229601368, 0.05177988663255688, 0.10716106832748461, 0.06177538052021016, 0.06515066049272014, 0.08530948281047807, 0.019891166518772804, 0.04516410070561594, 0.061250487718010144, 0.03655698796313617, 0.09012709567022902, 0.039562312585692254, 0.04750359150010252, 0.0100836782686172, 0.09927022481156934, 0.041455917225609866, 0.08481744751935044, 0.05174764582226354, 0.07704167040966212, 0.12607761012810853, 0.09381759401050307, 0.07400222423095858, 0.06209953913405057, 0.020178708045052427, 0.08419025133574203, 0.10539473770486732, 0.306869265773604, 11.59349464601086, 31.463959140162316, 64.95039824516543, 89.07539490730532, 80.33520883129489, 73.48953539325346, 64.30378375514861, 72.76250054759365, 60.81722028793828, 95.97686798341813, 78.61059757970995, 63.76294382156865, 66.62027282099571, 42.33545134144445, 17.164209504281324, 4.099962100867303, 1.4408652772826533, 0.34411180283754106, 0.1431333243606552, 0.8402752659974561, 0.3382385131572524, 0.08339130590038915, 0.015483086068753996, 0.06792666435602211, 0.04042104735309559, 0.07969537599673195, 0.11946437910439507, 0.49391505638918576, 1.2422387806638595, 0.09230751979855761, 0.418068919811518, 0.19734495409554054, 0.8766892636495253, 0.4903704288505739, 0.368858986203709, 0.033516216452323624, 0.1673841900041988, 0.22066021187891885, 0.02911963785487798, 0.09131451663110526, 0.30076308536433405, 0.42927540718547763, 0.5617264934605168, 0.35431299899374286, 1.0348428449323102, 2.300397051918891, 0.8098265192201062, 0.4134132809215977, 0.4163576019627433, 0.35844003721590967, 0.32106714263077707, 0.3453175945868415, 0.514426447691456, 2.8867553559041794, 2.1902779802199337, 0.15270046018544706, 0.22038605965433583, 0.04430315577455106, 0.06203814484779874, 0.16186510873658044, 1.3722477012103604, 12.469253020901835, 44.84156739327216, 70.60936250994283, 79.66253803622338, 74.39858390438941, 67.42071874680059, 59.40269201032577, 48.95439217167516, 49.546524939998505, 52.208927831342145, 63.95355532246252, 83.65239650972428, 63.40827134347732, 11.131085445803981, 0.7474795873126676, 0.1339710660038456, 0.04231890761143258, 0.06101989908324135, 0.05052066408097745, 0.026159370693588452, 0.012130943866777084, 0.06735200648226085, 0.09285276755690576, 0.042971802214460994, 0.09908509200378772, 0.05651485392703645, 0.012350983470828544, 0.024171527662885287, 0.021435228221478964, 0.01449122916035835, 0.022073883165214813, 0.0607693998233205, 0.05597611791604469, 0.06635101301775825, 0.03387400632603996, 0.007977983623277396, 0.07385702758666969, 0.04026549703051006, 0.07989483464869761, 0.05718322350613533, 0.03594963728720623, 0.06720466479178398, 0.0693215036223973, 0.04582999965115901, 0.038765064035091674, 0.024167078607265028, 0.035934403628831914, 0.024400545817409313, 0.029156546055850004, 0.029795969002729947, 0.014912316091208449, 0.08511632140124999, 0.04442263101678222, 0.020640881228891593, 0.05776832315830454, 0.093408556685092, 0.018126919655309572, 0.037264186708677205, 0.09697481854668549, 0.028987769225251772, 0.06074103924836363, 0.04600577852538517, 0.059335225772473126, 0.018269295180817286, 0.037395923188136476, 0.014036510969632337, 0.017836499553654465, 0.016199067054737, 0.016826734382418856, 0.10831166344184069, 0.06219094108429648, 0.03589680403350823, 0.07712125928411562, 0.05934007510903382, 0.05113279131511527, 0.018009269617558006, 0.02525455573753965, 0.0492087155280094, 0.023285062427842812, 0.036159376839115735, 0.06964601846712251, 0.037101890981918385, 0.045872498378758474, 0.009803666429023349, 0.03132962914664419, 0.006891577579681912, 0.058380358461891456, 0.015906440619859966, 0.030414246007679935, 0.0356891903755886, 0.0918733471283509, 0.0690651246376576, 0.09620184349196573, 0.10645759276925557, 0.02818032787481864, 0.04204022780721707, 0.09671529094057699, 0.13113077970281725, 0.024280392587365165, 0.0352587255709354, 0.06999140920778436, 0.02604156552303222, 0.02072404007307224, 0.08748989927792743, 0.031500009016223976, 0.026511543227599996, 0.05051880248732144, 0.03865165237878119, 0.043589491246929096, 0.05265694239266938, 0.031202318740167448, 0.048099037169689135, 0.06169980977691951, 0.27350944617102224, 2.949705965095951, 30.44324467259069, 67.72653810439571, 88.17260649896438, 92.43997266215663, 78.00445018276092, 72.10267943720665, 72.77294189699235, 83.81379419757475, 86.38868116563367, 89.69677679000363, 73.64641451066541, 84.05488660258632, 73.26322247905117, 46.11572188715781, 15.2240090985452, 2.0447200488659645, 1.1786168333022826, 0.3802516022997518, 0.2728805799157389, 1.0780629515647888, 0.13944510130151627, 0.12297617211457222, 0.18031615253177383, 0.06108731099013841, 0.119315390324881, 0.07345283959781931, 0.24652039842499843, 0.7084853442445879, 1.7544435733749022, 0.8335438046243884, 0.10115516882750297, 0.14950420346952256, 1.5316732948826206, 0.23652949340401158, 0.6499239898497059, 0.27142136628108643, 0.13948119936450837, 0.256662804993891, 0.04241882462895686, 0.09971017378472513, 0.5796183237145024, 1.2713799072850136, 0.6251825981082455, 0.45643448048541624, 2.3469246971991757, 3.122788883986012, 0.9615116217924703, 0.6789209080799934, 0.3601298433157706, 0.2333640027791262, 0.14674417253944183, 0.3821361173064478, 1.5563399777297051, 4.4981951963516975, 3.4299031140342837, 0.39622309527570204, 0.39941924473931717, 0.14731431049444985, 0.07041126369468628, 0.11646373527905635, 1.5752067008326132, 15.378422025711307, 57.44902610778809, 83.4314807768791, 80.28505740627166, 86.10391709112352, 73.26632899622764, 77.73292802995252, 56.278606537849676, 55.35606899569112, 56.11762854360766, 72.67301559448242, 93.40205161802231, 82.13931083679199, 24.021022473612142, 2.808926461204406, 0.28194762886531893, 0.2814432365759727, 0.07540866206850737, 0.014237997839377533, 0.006225034162672538, 0.023791528900244066, 0.03393285720038318, 0.0554030305225282, 0.0809110043149802, 0.06140870019613255, 0.04097836099625115, 0.043959182296549125, 0.10042583780182947, 0.008018837177059463, 0.05606722492243975, 0.004156949167560426, 0.0658817535206195, 0.06463125288005798, 0.09223075012766546, 0.05909437922039821, 0.018636756914577658, 0.047907940367416996, 0.017783424982260314, 0.047971284347436124, 0.012735427458650403, 0.07822025071589217, 0.0342983041229027, 0.04111783496374565, 0.07869036823150613, 0.03587683978220148, 0.10375062108881052, 0.08067110388149178, 0.06455014715151441, 0.1003766089918152, 0.021570546161984245, 0.05103848972207597, 0.07237116941401074, 0.019399682810950666, 0.06934649341048733, 0.08600653855190163, 0.08449615790478646, 0.057786632659694845, 0.03256239868219822, 0.036661172090398694, 0.014389194867333338, 0.04543169904800673, 0.07970028662032659, 0.149668759155658, 0.1469481051448853, 0.10864909452896927, 0.10577876225955064, 0.22711457924977427, 0.10823077987879516, 0.15654240644747214, 0.1755160294593342, 0.11960338575825577, 0.20656086925056674, 0.07393313842194696, 0.22079314345554, 0.13828685296879661, 0.17433078418816292, 0.16471765244439726, 0.06757010405342426, 0.1892612556055669, 0.11636045130510485, 0.1270838206513755, 0.16819627384745306, 0.3185150279633461, 0.0835562369696075, 0.13694472821249118, 0.11227753208649736, 0.2036872581248322, 0.20104099125150712, 0.12327198164477465, 0.10961419677421932, 0.19852630764005647, 0.13884451901239736, 0.18342827747185386, 0.23593061183008457, 0.10786187789973714, 0.24155751231216618, 0.20691178348516265, 0.36830387889377536, 0.3698616420790073, 0.10359277633289177, 0.09899777330217824, 0.11634219542986925, 0.1651418046845544, 0.30582950059925357, 0.17056791352168207, 0.17934813915241152, 0.2977464149796194, 0.21256102309111627, 0.1298609583248054, 0.17334320492321448, 0.10547330002150229, 0.18427227653803366, 0.2355119294577068, 0.2983513792916652, 0.6786514289917485, 17.280378341674805, 59.11932822196715, 102.91587814208, 120.1495175207815, 104.21318638709285, 93.88444039129442, 88.99937937336584, 94.3340067709646, 76.92280169456237, 112.2557867726972, 99.19294480354556, 90.0303194599767, 92.9127202495452, 66.38507966072329, 33.35667533259238, 6.81030297471631, 1.7532674751935469, 0.6779764748869405, 1.0187219648111252, 1.8171634981709144, 1.3909236990636396, 0.45257811644865625, 0.3664379032148469, 0.2053583103923067, 0.2797561577491222, 0.282360672830574, 0.5715659428988734, 1.650738557500224, 2.571872381433364, 1.6614566791442134, 1.561201632984223, 0.8619619893931574, 2.597671526093637, 1.2019674383824872, 0.9326139272701357, 1.2091720969446245, 0.7323321291515905, 0.45681384722551993, 0.3252083075142676, 0.14921868250014322, 2.238753572587044, 3.241356495888003, 1.3428986889700736, 2.1221361141051016, 4.21373559582618, 3.4922808120327615, 1.0633009888472096, 0.6581494452491884, 0.5114870602565428, 0.44591437724809496, 0.8937138823732254, 0.7077019120897017, 1.7139088194216452, 5.366234346743553, 4.692451559728192, 1.0676637676454361, 0.5397249385714531, 0.16565750443166302, 0.12820226305554952, 0.14575184352936285, 2.1434777302126733, 16.29460140582054, 61.527941996051425, 90.01829347302838, 104.97518524046868, 93.05990326789119, 84.70662763041835, 77.98068061951669, 65.23833551714498, 66.32473007325204, 70.2906071755194, 88.14727583239156, 114.8034054233182, 87.29272473242976, 19.682757508370187, 1.1526529490947723, 0.30559369873616005, 0.19601150145453794, 0.17934721984690238, 0.16740873546129273, 0.12961784798291423, 0.21434248395023808, 0.32978531513963977, 0.233369518612181, 0.14966485210724417, 0.29631772228787023, 0.2436830692233578, 0.15373271769813954, 0.2543024268121489, 0.08208712547897332, 0.26919312294452424, 0.13297037131363346, 0.13060686749316033, 0.16108251927841097, 0.1903041464186484, 0.14622560762349637, 0.07059728516446007, 0.18154950812458995, 0.14025762947576662, 0.16114412806928158, 0.16562350544958346, 0.2105850984732951, 0.18716986621579818, 0.22427533482832296, 0.1937552959087395, 0.1617005377286865, 0.1941525431409959, 0.1528642804271752, 0.13833713898014638, 0.18459463101481238, 0.10375725541023478, 0.10914450826784296, 0.15921403083109087, 0.14948791644025236, 0.21370943485488816, 0.29782952019764536, 0.2217515807358488, 0.114639189635073, 0.2393078644789996, 0.2012958074168813, 0.09894815378732259, 0.2104850320686256, 0.09822472163866605], [0.04977197018301776, 0.018478772347612728, 0.008168080202003401, 0.05531059818402414, 0.01868792201182054, 0.061870402235898285, 0.038448753992035505, 0.002745846333357716, 0.017340346539933837, 0.035179611670994954, 0.1030525004851722, 0.004389733123037243, 0.06516597459032651, 0.044940475810078845, 0.01986313727684319, 0.027123810272784005, 0.021227392398061293, 0.04577862962539639, 0.04073684028680286, 0.048408850787147406, 0.04759977000855631, 0.02336465321751612, 0.052176754651290756, 0.03327022178939754, 0.04046723096361084, 0.053472488953341404, 0.0972603012116686, 0.06518573965877295, 0.02478169945759639, 0.009802501975378443, 0.03060966737628464, 0.03216050129624144, 0.028645412192770073, 0.048557801262265256, 0.03690972548699187, 0.013749587101741664, 0.004216193619574751, 0.06316235589404261, 0.08030037095229473, 0.05867599945275053, 0.031528773702560894, 0.010059412433615616, 0.04283608590823509, 0.03608395931340995, 0.05918109271254751, 0.11732724660466756, 0.08159009529457939, 0.063999732130117, 0.013130585186093325, 0.07373751787048194, 0.05312926241106564, 0.05072985971046071, 0.0371893935446297, 0.17406260744938928, 0.4316439365427341, 12.36527196822628, 39.874564140073716, 71.75210583594539, 94.98529280385664, 81.77489126882246, 74.72810222256568, 66.67936725001182, 61.895326875871234, 77.25770150461506, 62.24970517619964, 63.42841271431216, 63.14060880291847, 42.5061881926752, 28.701896667480472, 13.981072748861006, 5.692004840220175, 2.010954202663514, 0.9802005512099113, 0.21316149812792579, 0.300142431571599, 0.07032569167354415, 0.07966834841476333, 0.28929085741120003, 0.47444070298825547, 0.11042060390595468, 0.42419140257181664, 0.3965530340229312, 1.0749297132415156, 1.3933759158657444, 1.4856162114489464, 1.0329815577114783, 0.2831585380819536, 0.24161548984627573, 0.1494165170457094, 0.5066130556646855, 0.13021524334626813, 0.0950822213123883, 0.0943126017227769, 0.24433098042443877, 0.10733742942853321, 0.02558871754445136, 0.13181774606627802, 0.09400048218066655, 0.1826370465418985, 0.8780893046529064, 1.3615186704743294, 1.2428098532461351, 1.9144701477020019, 1.4904694090927801, 2.763340920209885, 1.12368906457578, 0.08923002203265507, 0.02788711346745972, 0.07317785999827808, 0.4866409902611087, 2.3680873551676354, 6.730035101213764, 27.52755472736974, 55.69984512944376, 66.78485547342609, 58.7304134522715, 80.41531147495394, 99.53506961945565, 63.3926171641196, 70.03592768023091, 45.882854692397586, 63.71345135473437, 65.1638065615008, 83.01025744407409, 82.60280947531425, 27.594060474826446, 2.4218939388951948, 0.1834412090360157, 0.007305158764093875, 0.06788411583270758, 0.024498329280064474, 0.09113335215877141, 0.0633638944747227, 0.050393298133126194, 0.028901218526786374, 0.07286764801509919, 0.04238373780202481, 0.050950922041891084, 0.06903480287761458, 0.08302199789473126, 0.012803381372753893, 0.027317996324610808, 0.021872942133115667, 0.023562889959242557, 0.035050602464546124, 0.012807781590268979, 0.05210776460326968, 0.045695156685166785, 0.03478043772760899, 0.009814950904148, 0.0062586338214215735, 0.041257849023226774, 0.10663663517803916, 0.030994777860600623, 0.14123017809564067, 0.0558927177541679, 0.06318526575341821, 0.12569813613569544, 0.07911840453743935, 0.10197047024003922, 0.025191587140603412, 0.03878295601856324, 0.035188440834322286, 0.050363033829677495, 0.027165826364991166, 0.03942255899610539, 0.09914295462470862, 0.049923605796310215, 0.005892168959572671, 0.039863431105209936, 0.014671647654575928, 0.031839487473330194, 0.02666115828399216, 0.03986301741773083, 0.05050213624452872, 0.04215468134310457, 0.024087005182199424, 0.011867799368056079, 0.06988232594824607, 0.048485961367165854, 0.0374250115466214, 0.03891786793246865, 0.049701712259481994, 0.0529660129048411, 0.0645179637978154, 0.011664398236110086, 0.08574237611385123, 0.018428685519123272, 0.010115067763704686, 0.06976862317852436, 0.034462752556728746, 0.031642882498882474, 0.050042966125352736, 0.0015618976659982676, 0.09502013754700461, 0.07647172397663517, 0.007037304261053402, 0.033805613826599815, 0.09187476439101082, 0.02853224568459536, 0.010143507820283695, 0.06351386384677983, 0.040115550641090646, 0.13417786377812588, 0.018648001170086286, 0.0428834454637141, 0.009237691204273894, 0.0907018454745412, 0.025460506984663588, 0.03049843907055836, 0.072480030508051, 0.020900498850331194, 0.04423215091528912, 0.03809335431264293, 0.019373534314875162, 0.025333480030718832, 0.007787233475790991, 0.01786139741119358, 0.03618235181596491, 0.012862367270093773, 0.04259681366684456, 0.07029292609302268, 0.016080700724776235, 0.07752735483189745, 0.09085831893307549, 0.05053816152916801, 0.042878297352862936, 0.07455043674957368, 0.027568876713273988, 0.9525496801061015, 2.6217752262469265, 30.336489523610762, 73.0077898886896, 92.93841961891421, 97.49900648670813, 84.18636445076235, 78.62699308703023, 64.70277509381695, 87.94365775200629, 90.91862647764145, 79.36759933348625, 84.94724150626891, 78.55092263990834, 71.41762179713096, 50.27021008153116, 25.237598534553285, 6.423673475942304, 1.6505931846557127, 0.49651206380897955, 0.7801050043875172, 0.7314590340660465, 0.11528602831305997, 0.04062928920311313, 0.0736429060118333, 0.48782432031246925, 0.34561483670146237, 0.4668084754338188, 0.49448383070768853, 1.5850382442435913, 5.968451528779923, 2.6775074485809576, 0.6607744914870108, 0.37131555438522373, 0.0931813503285089, 0.07901207919442847, 0.31006483301039667, 0.21078182985225033, 0.0993226558691071, 0.10868113232596267, 0.03799414592644861, 0.03192088048484537, 0.07724255398516694, 0.20794405631961363, 0.06285161531019597, 0.3654798949437757, 0.9366341115486239, 0.9760696212610892, 1.2416077693623881, 1.9699280492721067, 1.876881584044426, 3.390165826966686, 0.897510981848163, 0.12197736966153308, 0.0762975692088085, 0.11790208833953066, 0.18942556614356656, 1.557826433450945, 7.808401546170635, 27.378638021407593, 61.739451885223396, 86.90853641879174, 73.47996481003301, 96.11894407579976, 111.37130798832064, 74.88871543638169, 82.58593543883293, 51.14640089773363, 59.77727836178195, 68.29318723370953, 91.43724226182508, 94.71795189765193, 47.620782390717544, 8.314247073665742, 0.33191773619863296, 0.16077568574297815, 0.057303744458383134, 0.13844419210668535, 0.025951004354283217, 0.038107442669570446, 0.031241473493977424, 0.07087905230301042, 0.09242208058675451, 0.04670440474705351, 0.026162814258808093, 0.0751738561197154, 0.15756729419433302, 0.05767962549843135, 0.04379886307663495, 0.006103852938394994, 0.03660226375946114, 0.05481509634503915, 0.024384848675840808, 0.015831206955256003, 0.07075034187085207, 0.06092989524345725, 0.026337516779500632, 0.10679551415265569, 0.0514171669830478, 0.040997314011497844, 0.12534323058301403, 0.14936440774509985, 0.04448651125834835, 0.05536454992609159, 0.05891783808868739, 0.07986042197913894, 0.0416945651053421, 0.039718996718405716, 0.08516791742295028, 0.024784618252587896, 0.060494929672248905, 0.011683281345833695, 0.05677138995980063, 0.04358024456568303, 0.0657734593316432, 0.01670601999297017, 0.07153463204421344, 0.09269886815379705, 0.08018451547550579, 0.0753028959696812, 0.03408882887132707, 0.023772223484552196, 0.01999087860777734, 0.2199266980131788, 0.10592700027289892, 0.08962336987737687, 0.10705205401585949, 0.09574042107429236, 0.16796197351669112, 0.08426302202766942, 0.13470192920536767, 0.11587659783300855, 0.0650570675310108, 0.20543367812229743, 0.11805795658860477, 0.13930671517887425, 0.21659804598218013, 0.08735300702673775, 0.19621725734924117, 0.10004183622978388, 0.10035133575119319, 0.1523510015179073, 0.1479368948287541, 0.22188480342588118, 0.0828574728521128, 0.19848158342703698, 0.10516589192012626, 0.1715428370141214, 0.13704837990864632, 0.17605154024016473, 0.21171376049037904, 0.10324076659256413, 0.11124432462477878, 0.08772516487947396, 0.13180412502298433, 0.07152078117454244, 0.105111331138159, 0.137174355406915, 0.13820161802634118, 0.15340215075881253, 0.10153686447489647, 0.26696766816800643, 0.24717780911634046, 0.10340562871386928, 0.13652632163176615, 0.1300372811214578, 0.13863458027762754, 0.17220587079082766, 0.1771159581239185, 0.15796708483849803, 0.15721025125634286, 0.19959005136643687, 0.11914189439266921, 0.18846968759692487, 0.20811778973908196, 0.13990856917394748, 0.3374555100116038, 0.6683799059640977, 18.16339800434728, 62.596987908886334, 104.31987485577984, 124.03564499270533, 105.58175625339632, 98.81135309896162, 87.82711628944644, 82.9689391966789, 93.44390330776092, 78.81860871468821, 83.1790291878485, 94.7541710638231, 85.56481084515973, 71.19960861821329, 42.21596417888519, 16.05718622284551, 4.782695491467753, 1.8840571925524745, 0.7992442709303672, 0.5458417522811121, 0.1880989163633316, 0.13856388568397493, 0.414435088995003, 0.9372520687118654, 1.461414697189485, 2.089887857437134, 0.8293144476990547, 2.429364092888371, 6.479212276397213, 4.852580360827908, 2.883893986863475, 1.1126017498393213, 0.8852981920203856, 0.3169071319843492, 0.9525132756079397, 0.545926021952783, 0.6754274245712065, 0.3075828307097958, 0.5103761714793021, 0.16078400545783583, 0.2912924306527261, 0.2833440539336974, 0.20396125713183036, 0.898712146426401, 1.9726487032828794, 1.4718202549603678, 1.167352889334002, 1.9626847798785858, 2.802056920143866, 3.861426590911804, 1.5844246384597596, 0.26106637031320606, 0.276061805986589, 0.3589980556599556, 0.8057411868245372, 3.5189771988699516, 10.126797864514014, 36.885125790872884, 73.0393414343557, 92.86620093930154, 75.88828440635436, 104.77760761014878, 112.55777005226382, 80.4205439167638, 96.48696437958749, 65.111184043269, 78.5734841131395, 84.60062165414134, 111.9896774907266, 107.47689647059288, 41.35040690821987, 4.538561778683817, 0.363830354425215, 0.19003569388822203, 0.1477335291283746, 0.211463586817826, 0.18010374699388781, 0.127486246638, 0.0933317257271659, 0.14260585750302962, 0.35814300960590767, 0.1787880063056946, 0.15953134444932784, 0.2098727133125067, 0.27926439058876806, 0.1366328691402751, 0.23569540751557197, 0.08619702631427396, 0.12114933586769527, 0.12435442557738674, 0.112964651667543, 0.14012685826709195, 0.15481245734037893, 0.18176975840282056, 0.2284117959319584, 0.16252851023549036, 0.15943532298889854, 0.16942282657950156, 0.22003390435730258, 0.19017694517970088, 0.16983326584581407, 0.1498986161764591, 0.2034398270470481, 0.18242945203617697, 0.15462340216242498, 0.1743295278039671, 0.2353497792876536, 0.21114244275996763, 0.20771223811372636, 0.18513899777204762, 0.1752941397529456, 0.1332081037182962, 0.17202501275366353, 0.11050165600834355, 0.33620047413053056, 0.1482948570722534, 0.1856497485911654, 0.1489319817553605, 0.1714645734717769, 0.11049653854100935, 0.0993405363612598], [0.009002526151767422, 0.024099879289766955, 0.08454246025892996, 0.03669087331922304, 0.02736535971052945, 0.10814922215837626, 0.03655484291694818, 0.06103111844089243, 0.052992232264049595, 0.020407906230238658, 0.04704637873557307, 0.0748312845826149, 0.07082557170501641, 0.027174320364851626, 0.011348913652792333, 0.07350528597711556, 0.02960082342577798, 0.04090138831205907, 0.02121285204925845, 0.028405488776643912, 0.07297279358270668, 0.02163835834982174, 0.04914723314164628, 0.05130134598021546, 0.04279055347245547, 0.0265415930264299, 0.14122702181339264, 0.12179430529114701, 0.0034735822203313753, 0.04107434032184463, 0.003873178709088074, 0.029379406778682626, 0.06121976376180688, 0.04977347171534935, 0.024077237561164845, 0.04557057163648067, 0.06996851850060687, 0.13152215870157366, 0.05790879687054023, 0.04618068405937764, 0.10417629018305771, 0.03250724418208965, 0.10733678591467681, 0.0662576345606677, 0.06183801586889933, 0.12032678726339534, 0.058144054811207525, 0.06876414401396629, 0.029461945091644605, 0.01978739033332996, 0.03329705784938509, 0.02192250036093737, 0.05196593874584764, 0.10729368580805679, 0.08550383165598878, 0.1404256632010783, 0.07957354503413362, 5.240589063013754, 40.45413355673514, 82.61142300021264, 94.59300871818297, 83.11415318519839, 77.56165381400817, 68.40494340465915, 66.44585286417316, 59.89736564697758, 49.307001483055856, 55.305548867871686, 54.62270344457319, 28.977043090328095, 14.371909479941092, 13.407072117251735, 7.430328207631265, 0.29545115427144114, 0.03439762742228566, 0.8182545282667684, 1.842232469108797, 1.7734177939353453, 2.2849340881070783, 1.993018307032124, 1.1718882524198102, 1.1293210978469541, 1.5439145218941475, 2.1397274540316675, 2.361988804994091, 3.300710536779896, 4.543032300087714, 3.144330295824236, 5.19597553437756, 3.440674677971871, 2.6073333044205946, 1.835604766684194, 3.153039183347456, 5.374011916498985, 9.976245530190008, 12.147193089608225, 12.191188354646007, 10.018532603017746, 7.16907678111907, 4.446431677187643, 2.9274862283660523, 2.7721988577996535, 3.476818093369084, 3.1532051486353723, 3.1224910290010515, 6.137194835370587, 7.547282989948028, 12.292889529658902, 21.084096816278276, 34.90073596277545, 60.3270338427636, 83.25629988024312, 82.97270467204433, 71.44559614119991, 56.49585093221357, 71.3548638743739, 55.021420217329464, 49.678045934246434, 61.56521235742877, 58.844950583673295, 58.522798476680634, 86.33152438748269, 90.75088239485218, 36.1151998273788, 5.799710183374344, 0.1864506169072082, 0.1421694325343255, 0.0359702680350071, 0.03726831209214945, 0.06765462653411013, 0.07202283689571966, 0.07035550781555715, 0.01604732706196486, 0.01123863721131197, 0.007828895731138126, 0.13134775112473196, 0.039331815881474365, 0.057562031002054294, 0.04501032770701474, 0.04571636199891087, 0.026803315474441456, 0.0287065900591833, 0.05660656231245207, 0.017786372505548983, 0.05225321022613395, 0.12035573006517465, 0.01421877382052762, 0.030166014368014953, 0.04510545667501227, 0.031242796910866618, 0.09834099846381335, 0.07883245455882243, 0.053202293572887305, 0.023914740736325903, 0.05925368337381271, 0.03998121329312844, 0.07869429826255768, 0.043511917183716456, 0.012791059806101747, 0.004316213580163857, 0.06819745345461754, 0.008692704873429912, 0.11286443204528863, 0.1079498554369615, 0.04431449770627003, 0.025372627123649565, 0.05996869621618141, 0.054977706167846925, 0.0663677903433, 0.06654664123010251, 0.06871468537757475, 0.027298263814901153, 0.014321515787272684, 0.0417075043303832, 0.041891430549684076, 0.08258225576531503, 0.03369964471447372, 0.01853599528511686, 0.051930733175287326, 0.10342340961459184, 0.042417058796291394, 0.0802057973980423, 0.04571090745288999, 0.04875269403020221, 0.07243941252630565, 0.03184966495140426, 0.0485058183661632, 0.01899036394822742, 0.026008127700357188, 0.022008371156369968, 0.0386853908909665, 0.06426679421096079, 0.005202463831782582, 0.019527297737377308, 0.037708487061242905, 0.026771978647898764, 0.04695660089172664, 0.09598972906749095, 0.03684304902450212, 0.006216103013890285, 0.046787889178601966, 0.07635112641559494, 0.1269020739522192, 0.07306196621709293, 0.0075062726447809374, 0.06591562992863118, 0.0017108001409196147, 0.05721547197730792, 0.09558042361130638, 0.06438723089353693, 0.025194230143942183, 0.0769516627394384, 0.07285712962789882, 0.0373592390678823, 0.0663639445819201, 0.0406967394144064, 0.04016715049323055, 0.057297198237070156, 0.04304101442798011, 0.043218919196196144, 0.020818447003201134, 0.06035508798255075, 0.071073807175121, 0.0324056685842093, 0.021255613161971974, 0.015228282352308593, 0.053460763977660294, 0.039697124908167514, 0.013295495187893752, 0.15480689554204866, 0.2306999626659578, 0.7423833252922182, 0.5014605627905938, 19.504887826981086, 70.68853162950086, 95.55100056432909, 97.07046401116156, 84.17511509310815, 67.91127389477145, 69.59376673544608, 64.28841198644331, 70.43826872302641, 75.07714609945975, 75.89896894270375, 77.00994891505088, 57.67237763251028, 47.81471221677719, 34.484333222912205, 18.82684926832876, 7.835654664424158, 1.4879789491814952, 1.959175361740974, 2.368575199957817, 4.102874460720247, 2.9324024290807786, 2.948430459345541, 2.026676655777039, 2.325725021862215, 1.7380720905719267, 5.153967930424598, 5.518259040770992, 7.674023105252174, 7.696299716349571, 5.916489929922166, 4.903941346753029, 2.559938079887821, 2.5747955278042824, 2.3855036593252614, 4.497340609950404, 7.174135658048815, 12.237867501474197, 13.42520719574344, 18.16522975121775, 15.418048750969673, 10.124554268775448, 8.901007175445557, 5.993000663095906, 5.845094457749398, 5.901131399216191, 5.133551503381422, 5.251274089659415, 7.418542956152271, 10.267928665684117, 18.156706440833307, 25.528867859994214, 36.761076911803215, 61.93580181367936, 85.16175593099287, 105.45072555541994, 92.40871137188327, 67.75958799546765, 71.50847957980248, 74.67496195147115, 69.89167859477382, 67.21330381208851, 70.33659304341963, 66.96907351093908, 92.42155321182744, 102.08073492973082, 58.09762139474192, 18.202001971583215, 1.5232023236251648, 0.5127545067619893, 0.027850617038746996, 0.08636469231738199, 0.04733398729454606, 0.027028288684725284, 0.08478034588117754, 0.02183698196594994, 0.00872282745061262, 0.01352439555639942, 0.10469536837791243, 0.08702178125179584, 0.07830093509607738, 0.07796880533738483, 0.03192043615384929, 0.051982731393147866, 0.08402086163480436, 0.05764947227773167, 0.01738913867983126, 0.03407733755246286, 0.06848957044102492, 0.06987166966521932, 0.07463774779030392, 0.0070884018467979575, 0.041060160034366196, 0.010667006342461514, 0.03717368874218195, 0.04339917968477934, 0.04200229879408594, 0.026076156308033296, 0.03824242353138905, 0.07427737236984315, 0.07385426967014229, 0.04816308212015898, 0.03138632539870038, 0.03290695821746223, 0.06321736100700594, 0.11992682041900775, 0.09144330367205605, 0.038497798940947944, 0.009470516815781593, 0.03710744511936942, 0.038052341795616576, 0.08561148999198791, 0.041228055863851504, 0.038658236904490384, 0.06110570093076076, 0.06757306115281198, 0.06074288935070077, 0.031221197061841528, 0.07093388887663042, 0.15724068026869528, 0.11035001656461148, 0.24326457071208188, 0.1453578445099054, 0.14789296734717586, 0.3351945700424333, 0.20042326391464282, 0.2164769274813514, 0.1444464297063889, 0.06287974222833592, 0.0960555819854621, 0.178196111453637, 0.23057600963980923, 0.09772125631570817, 0.06851477473373375, 0.21836289805510353, 0.2297638798312795, 0.1040237314338165, 0.07251902438339687, 0.09283340085417995, 0.15313754398976603, 0.22732500828081564, 0.13923848738833783, 0.07020155478629374, 0.2074819980489631, 0.12014451962445052, 0.30743754979583526, 0.12740104233906155, 0.208247120702459, 0.12167850344051277, 0.07494230604460163, 0.1895339216195768, 0.13946684287680736, 0.09316831917291687, 0.13542474848368477, 0.14569317651612146, 0.2338703868970756, 0.15423608342966727, 0.1726582457101153, 0.15132802899085707, 0.13171050907863727, 0.15539099161903705, 0.2311153355385027, 0.221833904544192, 0.1306998246018925, 0.22161762260140913, 0.26532744327860497, 0.20756156394077888, 0.10467162731313899, 0.3622720396566776, 0.34055053586921386, 0.17922901248018588, 0.09209433285098884, 0.26842449160833515, 0.26328704470107633, 0.29598903992483694, 0.20437226330320682, 8.547840887500394, 57.71500595154301, 110.79509612052672, 117.90876157822149, 102.16628182318904, 95.74846836828416, 89.19182654350035, 89.15548186148368, 80.72505320272138, 69.53475859857375, 79.85905662659677, 92.70252043201079, 77.42541420844294, 75.28454534469113, 59.58673354118102, 37.346337687584665, 20.20713133196677, 7.8126455506970816, 4.557429850101471, 4.502436259100515, 6.867107229848062, 5.324730767357734, 4.340113872481931, 2.012301291669569, 1.862325913483097, 1.1869165685869034, 3.165584148899202, 3.2543118394190267, 6.075718547067335, 7.670092890339514, 9.861937857443287, 11.242071851607292, 8.539080273720527, 8.130821845223828, 6.851400098493023, 8.431801488322597, 12.105880725768305, 20.644006882944417, 21.208902712791197, 20.756272962016446, 17.331747662636545, 12.074417433431073, 10.124750387284065, 7.983622156804609, 5.6483272871663495, 6.319208010550469, 4.972556348769896, 5.860419158012637, 7.931798821495426, 11.297336086150139, 21.12765669822693, 31.3559704057632, 50.564458447117964, 84.68838076437675, 107.04733417880152, 111.17023160380703, 92.6464540727677, 69.07729256537654, 81.94371008103894, 68.23006060815626, 70.69137927024596, 82.03726645438903, 77.54045732559698, 78.37381193714758, 113.5705574097172, 121.18003399141374, 52.958637898968114, 10.339578601621813, 0.7909026766015638, 0.5963918494601405, 0.1278012313489472, 0.2170606864796531, 0.22062792893378969, 0.21851371012387738, 0.1839291764002654, 0.18358892610957547, 0.1305235171269986, 0.13293729163706303, 0.28402584154279004, 0.13967207783172209, 0.3093911352897844, 0.1448300405735931, 0.10858663538050269, 0.09574380718291768, 0.20989872965841525, 0.2447541673938113, 0.1143596901167785, 0.10395927279586754, 0.25221017940390494, 0.1904102955614367, 0.1610043323448589, 0.09008770342916252, 0.10953434742987157, 0.21907102376703294, 0.1373107497009539, 0.16216065013600936, 0.2293591862243991, 0.27318042672930226, 0.16158709542885905, 0.1782522503767283, 0.1407218634361221, 0.13171467659694533, 0.13491231227113357, 0.15814250365139979, 0.1403680533891724, 0.2333618730546967, 0.11165069596421336, 0.1436452396334179, 0.12064126635631248, 0.24873564891036481, 0.2586896284934013, 0.18800782850913464, 0.1592562729192357, 0.15574950544584185, 0.18415969225668138, 0.1226905438928835, 0.16816602869620248, 0.11281179414401132, 0.2797506112725504], [0.009374803705741803, 0.03519985171395444, 0.022786697335240823, 0.04367979386100366, 0.04629528315197076, 0.05119825352824504, 0.04339980787687725, 0.08748552491587978, 0.04188538228552188, 0.06270018654064306, 0.10072463507493658, 0.1259770764098052, 0.13709273639946215, 0.018157021165074363, 0.0695589295918903, 0.07359334012313236, 0.015327890061833447, 0.06351405536876091, 0.08396247807409495, 0.06383056459467738, 0.057701493478229934, 0.03824372971129995, 0.06070594476055234, 0.027138465534775492, 0.12473468097948259, 0.023425147350456928, 0.05006309125512358, 0.024763190773345774, 0.017271318187516545, 0.06436076255575304, 0.024736103819563024, 0.05017904249290305, 0.035867516492162986, 0.01679079528267105, 0.05755237063332912, 0.020887201479185494, 0.02829411682943183, 0.017504362134082664, 0.07792631810110423, 0.003242732636863366, 0.06277450473017751, 0.02975501011185829, 0.08941194493203394, 0.038031665082540245, 0.03137921610276305, 0.039704372099931204, 0.005313639947769022, 0.04334266537860517, 0.07450581212798435, 0.03037454541622391, 0.06347944734678154, 0.08667250644535789, 0.03426892465100654, 0.09882177226245405, 0.14577736957899987, 0.07345733653393484, 0.0723691546027699, 0.10793749077786362, 0.035638866059842615, 7.160037679056968, 41.64824816488451, 84.30410615859493, 85.49940140016618, 86.90808142385175, 76.5728792067497, 74.38334941864014, 55.324442924991736, 51.47512689713509, 42.74978306985671, 36.127712188228486, 38.626022723413286, 31.30035511908993, 15.057729040422748, 4.929772605819087, 2.3759664162512752, 9.602451497508634, 4.761912322813465, 0.901825282602541, 0.830127542778369, 2.3774586329537057, 4.908933053093572, 4.751842127692315, 13.45644691298085, 22.72922908106158, 32.41952107798669, 37.69007459763558, 40.38082053584438, 38.51995398921352, 25.973745046123383, 29.044484323070897, 24.606740205518662, 16.944535201595677, 14.27532405622544, 29.42486793764176, 45.23405936456496, 56.40226710227228, 41.00969022320163, 42.24257353813418, 39.55580096090994, 30.207535720640617, 21.498342252546742, 11.21758351402898, 11.785906514813824, 21.91753968115776, 31.913074447262673, 42.55490403021536, 52.377989830509314, 57.96585721354331, 65.51391340071156, 80.17908280895603, 69.35745962204473, 63.625707933979655, 61.65061412319061, 49.546917177015736, 57.5774327401192, 66.10410459579961, 65.50857113253686, 67.96806197012624, 71.82010404525265, 72.35251872770249, 85.68733784460252, 60.994064269527314, 14.504769963602866, 0.5443961750115118, 0.3393808421829055, 0.10355673189605437, 0.05739502383456115, 0.039052641950547695, 0.03872059263108719, 0.01710676058616129, 0.034449594996629224, 0.046231694023815856, 0.02166801169815083, 0.015926269848170062, 0.02517551844639163, 0.0701983985040457, 0.06045847537837202, 0.03380978517534752, 0.09588708860739585, 0.046150132472957336, 0.036028241738677025, 0.01020141161843053, 0.02403654297062707, 0.0111323865618737, 0.04718764917925001, 0.031574200801250916, 0.06024369879836037, 0.018864949609363274, 0.04153127346428172, 0.013030801276345889, 0.05254459559857365, 0.027838893978285695, 0.0683699228290108, 0.09286509391160742, 0.04415864860939403, 0.05778100574389101, 0.07844580232255882, 0.0190269963575467, 0.04882199434383262, 0.09045157987143725, 0.03262756978191676, 0.032533386932505716, 0.029415650398380337, 0.03753911651250336, 0.04960135474140125, 0.10388528402414053, 0.06520302260234472, 0.04959937440411699, 0.12160123581246984, 0.01460800873070595, 0.022828087150569887, 0.03925574718103294, 0.014264260291031772, 0.0718737944900509, 0.047397446187753836, 0.019542887626636415, 0.031123647256003275, 0.012692912451682553, 0.06001693294233373, 0.04726970485681969, 0.021341108574321675, 0.06337087353571288, 0.0765528756704542, 0.04263386550930239, 0.013578655648856394, 0.01329063914806372, 0.05254609330046562, 0.13987909011062116, 0.046723181562077616, 0.06318193710138721, 0.15768565477863436, 0.10795360160691124, 0.07972000572349756, 0.07561179028163034, 0.07879094025420566, 0.06340716312068605, 0.04146514858509745, 0.03854794705647134, 0.047531105547903046, 0.022765041944841226, 0.12072258658947484, 0.10575843028604023, 0.11012047363985931, 0.030831009329807375, 0.03815263419622376, 0.016043523435420808, 0.030100437241696545, 0.03898014321983342, 0.024209657774096536, 0.03837230990851118, 0.04055302898069063, 0.019605821749616056, 0.05622259138392345, 0.03512590507706327, 0.03216998929518365, 0.03372753031491753, 0.05851468431853479, 0.0348996524999459, 0.026155003992420052, 0.04955392240756943, 0.06520354354213323, 0.08437333102788656, 0.020384182402443503, 0.09953628714767196, 0.24051508115183926, 0.03245034300151371, 0.038696863057632605, 0.08127144102247492, 0.06479622991455179, 0.09510256094677795, 0.06003335403699068, 0.06686666679959144, 0.20983774905964253, 0.3358374710284895, 0.7511653895339658, 23.733812801299557, 75.57165499656432, 99.91468444947274, 94.43219938585835, 85.64778466378489, 70.34671275846421, 60.30426056154313, 57.37777625360797, 68.069259120572, 71.84753710223784, 68.28953942944928, 65.94018090155818, 55.370691591693515, 39.56239838753977, 31.290111849384925, 20.607550413377826, 10.71730382980839, 12.099645137786867, 11.264554877435009, 12.553102508667978, 11.738531147280048, 22.98690526716171, 24.89340074600712, 35.69988358405329, 47.53796154452909, 58.00165668610604, 61.66446008989888, 70.33864836538993, 72.29183966113676, 55.34087373364357, 51.56701626316194, 44.76953306505757, 45.01316324357064, 40.56814509053385, 54.91557898059968, 66.23388013532086, 80.4312833662956, 63.992516225384136, 69.62056436846333, 69.91915872020107, 55.71726045300884, 48.91764348553073, 35.10269095820766, 35.640039982334265, 43.28659472926971, 51.503822957315755, 67.65110308124174, 74.47699992887436, 78.20319667939218, 91.73988449958064, 99.07199459691202, 102.57139990406652, 98.75756171441849, 79.22266775561918, 63.011578513729965, 67.90385277040544, 75.74872647562336, 59.370399136697095, 65.70727056072604, 80.83731143705307, 80.91901440774241, 92.16851326727098, 82.5837859799785, 29.332205864690966, 2.6051098108291626, 0.484039600818388, 0.15719810110186377, 0.04986609174539486, 0.05297217608219194, 0.17090277055338507, 0.06654094153594586, 0.0326145118132474, 0.021808144501260212, 0.032735699261989326, 0.019098660052423517, 0.03740173779548176, 0.028501058245197903, 0.04663100969346781, 0.012010267781724614, 0.07645416524141066, 0.033879962659651236, 0.013737208078495197, 0.03696621298008869, 0.03858191539503394, 0.0592369290309087, 0.030670669042475285, 0.05087875272898425, 0.056733821007993915, 0.06532519830450897, 0.05731848399004629, 0.14042154164804568, 0.0250530956808718, 0.05749312522370489, 0.06291056960640896, 0.14422720598597683, 0.04412825024055858, 0.09494447104272344, 0.08123955644306638, 0.07167246658354998, 0.05106038068451228, 0.017167421343225627, 0.03131523243932715, 0.03846083519860141, 0.022564018558290218, 0.010386930343004004, 0.015928015571027514, 0.04567572486496741, 0.07980279684547456, 0.07304505099572482, 0.028909270110870564, 0.06214842703493853, 0.03305515792641429, 0.011934783223325448, 0.04151631559756014, 0.009942250776915781, 0.07343120527483764, 0.08166455904081946, 0.13928497360358316, 0.09629032664722013, 0.20710620127858656, 0.12077183838212684, 0.10795819047357767, 0.13131920668867328, 0.18417892106358083, 0.1840628893865693, 0.10786318791008766, 0.12491614422610692, 0.2586743067349157, 0.23982865104992546, 0.20273473504329884, 0.11916861553946811, 0.21229231009079566, 0.19209408021021276, 0.1946665881381881, 0.3058755884487783, 0.32131878719214474, 0.20925460293168024, 0.21287162577913654, 0.07110176938435725, 0.21263384740919838, 0.12827646633189532, 0.24507186405601042, 0.13674289468796025, 0.19039023937957902, 0.0942760210243925, 0.1131602492363703, 0.12760468383109377, 0.1674305230018593, 0.17727911953003178, 0.08957332135328362, 0.10456200013117445, 0.0908371136193314, 0.07486771206341444, 0.16997080927173938, 0.15297950005098698, 0.10120692572766736, 0.14324883509787822, 0.2690225611290624, 0.09205418218287731, 0.1357901111365326, 0.1539676462209994, 0.13750961080433863, 0.19373248181035443, 0.10580271016806365, 0.2372818070674135, 0.25065574104026445, 0.14128035685468104, 0.14758869254541013, 0.20659992441294656, 0.16948780615723905, 0.17414365955177816, 0.2815015205452519, 0.159825062559497, 0.32748355800586365, 0.32342038087306485, 0.16121624758647335, 10.754800708063188, 64.99576437857844, 116.62549541842554, 117.10633877784976, 110.35017382714057, 98.11825460003269, 93.85476373857068, 82.60794778023997, 80.71375677662512, 68.36572754767634, 63.699805428904874, 75.1549659236785, 76.91602383890461, 73.91669719449936, 65.7368766107867, 50.04249688117735, 45.67049757126839, 35.06502051507273, 31.87626692556566, 32.53186560446216, 32.47963140087743, 43.564561336271225, 52.083090351473906, 57.29091536614203, 72.61785138037898, 76.47763621422553, 79.92703914642334, 91.12251912393879, 82.64121732404156, 68.88682226980887, 70.18839020882884, 66.2051683856595, 56.95521539257419, 59.72980983795659, 80.45360165257608, 91.25853123203402, 101.49120269283172, 81.70763046510758, 82.6644769791634, 88.99249169134325, 77.2541243030179, 66.95776139536213, 54.507040592931936, 51.46136330020044, 61.80624200451759, 70.7534154768913, 86.87747909176736, 94.51183918983706, 95.59659419521209, 97.75343495030558, 107.33885257474839, 86.74115319405833, 82.46823295470207, 79.2952629827684, 66.36501281492173, 77.49529515543293, 89.42144993812808, 83.58110350947227, 84.81938008339175, 89.50147413438367, 95.88485702391594, 113.10287752459126, 81.80613686961513, 19.8132037731909, 1.0978955583226297, 0.7203282668225227, 0.1463449334785823, 0.16367384232580662, 0.3131972133151947, 0.2731872908771038, 0.12011330920241534, 0.09645078376296068, 0.18152341516988893, 0.10752505968294798, 0.12235874355199838, 0.12758367770021, 0.14571052074672716, 0.12233223690981827, 0.11363395204346989, 0.2980601739498877, 0.15232051121852092, 0.16067574191237652, 0.11454348227069264, 0.17148752546598836, 0.1065776540687488, 0.1658574687016587, 0.13843035655877284, 0.11735079614745995, 0.18841201649798503, 0.13069925769682855, 0.1843475983027489, 0.14789517368039778, 0.26217845418760855, 0.21314015491835533, 0.20691889278109998, 0.3159275506773303, 0.2139883521463602, 0.1783588132069957, 0.2124147002975787, 0.1364976239781226, 0.24614709910125504, 0.10723321082731409, 0.13557647985796775, 0.11273929158285742, 0.0989699183452514, 0.15229366749765413, 0.15671705917244957, 0.2234392571112802, 0.2170814474624011, 0.3083892148588934, 0.15069118009940272, 0.13782166905941504, 0.2226393387442635, 0.11752516541990543, 0.19507739512670427, 0.1665391337366835, 0.16508739712017198], [0.11240841054748144, 0.04003743265545176, 0.0919258394729226, 0.03208059066485974, 0.08496805274438474, 0.07233016072742401, 0.036860841416543534, 0.024411855190391504, 0.057538102245739395, 0.01357723359814695, 0.09404325286947912, 0.05783846233821204, 0.10656564181009609, 0.07192192013345419, 0.08712769290732761, 0.08625438331716484, 0.015339689731087177, 0.005822952436808978, 0.052364859880218585, 0.09101293079795376, 0.03595709132270948, 0.030818522096641605, 0.043922153436729026, 0.026941347281418504, 0.03943627580038963, 0.08031164776654014, 0.06651022907106147, 0.08669381135053213, 0.05884186131879688, 0.05895922215835703, 0.023664383202671044, 0.045676150043765386, 0.08424210782733657, 0.035318886455629146, 0.060272480721675584, 0.04621572109059461, 0.05527733464635188, 0.06837708575110282, 0.04518000852136363, 0.07844093766423964, 0.018643046496436, 0.03652052217794042, 0.019805039083885572, 0.0923403236834753, 0.02308102448530976, 0.052003017401382814, 0.07933765124048918, 0.051467675159895615, 0.02992673829618481, 0.06827274457581582, 0.037852967413322586, 0.004615503543567274, 0.08009103742698509, 0.05707809709072594, 0.03126451550351997, 0.15467328980805414, 0.09693065357785072, 0.07675642523193553, 0.012305913560633219, 0.32137008443955456, 0.07686594516159066, 9.106898269345685, 51.091299441552934, 94.00245666503908, 96.06635293652936, 90.52893900102185, 78.939268665929, 71.27442390688005, 66.64896888117637, 59.54206166728851, 37.37385311434346, 32.07650588404748, 40.47720101571853, 30.312845476212043, 13.707273660167573, 16.124415647599005, 14.087525875337663, 15.810145543467616, 15.324506105915194, 20.29805579493123, 22.601336279223045, 28.626189039599513, 31.50822897111216, 35.672862375936205, 40.57159677628548, 50.72628759568738, 38.827554102866884, 22.597466861048055, 24.539755928900934, 22.104681845634214, 22.356800033200173, 14.923601631195316, 30.929704866101666, 33.707990261816214, 46.88776985291512, 43.827952415712424, 38.22805120098976, 39.9738589409859, 50.474408672701934, 39.926963083205685, 39.1504632273028, 39.897953233411236, 37.40367489476358, 51.27549002247473, 55.69209452598326, 53.4590813421434, 54.18040913920249, 66.71943033895185, 62.51598704245783, 55.4450205064589, 40.071686775453635, 52.105341957461455, 62.45384100944766, 70.42377164286953, 75.60919207911338, 69.10049730731596, 78.749951547192, 91.0217377447313, 87.0353937149048, 61.709253557266734, 15.533016362497884, 0.40460038930177694, 0.09252294372286528, 0.2170911461355225, 0.024347323774089737, 0.06520460840434798, 0.05861305000801241, 0.07741793449367247, 0.015364614401703641, 0.12069342928307673, 0.08908824980138771, 0.0795536727133778, 0.05822984516740807, 0.0952788760825511, 0.04704707587558416, 0.12732115469031757, 0.07935167831038276, 0.04821277441336744, 0.059106035248166135, 0.0622773711239138, 0.020521980552603642, 0.043913519625822385, 0.02161928467572697, 0.04801936785600359, 0.04296717121295872, 0.04971960424295357, 0.060304928375708486, 0.0627029674398082, 0.03863170727967255, 0.07111456305269273, 0.018300427078840234, 0.031439080128386136, 0.04395050252036702, 0.054604035291460254, 0.03422087944683529, 0.06052522078877496, 0.02737778565666128, 0.06611090574053026, 0.03146883306814538, 0.041242665160567536, 0.04841032167596202, 0.13313633660154958, 0.02238585140496012, 0.03084811607315656, 0.006632155789467957, 0.010666959419576152, 0.11692866637942292, 0.05340226550376224, 0.07580994658412472, 0.06369312842106147, 0.16806620743966874, 0.043460558649272694, 0.09882430035260417, 0.05212297910944589, 0.009599090309723491, 0.025785533193078254, 0.0476768154711012, 0.05380503239951307, 0.06337586459853957, 0.029669499377750104, 0.03353294781258991, 0.059359633333740704, 0.026414100674071142, 0.06613595681565423, 0.03245451435026142, 0.021279982418843338, 0.02782995181698953, 0.053671058943314906, 0.0712619583693243, 0.05897795300810568, 0.19129970831976784, 0.0804665047795542, 0.09457049756160668, 0.07573834800672147, 0.039226463470127315, 0.061383032420229536, 0.049419251811360164, 0.08167619591638928, 0.20009750800748027, 0.10748549890253814, 0.030724431177781477, 0.10771492691410166, 0.033254697017612, 0.06935234632222884, 0.03044045004512995, 0.01873320546902476, 0.02138118837930022, 0.09405513489318472, 0.06203359428552851, 0.03301269367277142, 0.011600552468500551, 0.0859890640863488, 0.06831189166874656, 0.08467613494083767, 0.0660815952165473, 0.07228891455358075, 0.04163331637579588, 0.07312932066739568, 0.012628288147219969, 0.06216795078568882, 0.02052544327002139, 0.015572173475858667, 0.07152844205378525, 0.006641119018182039, 0.026623822989002354, 0.10494925757689823, 0.01087380315913188, 0.01735816191461298, 0.07450444083059989, 0.043014894660201766, 0.049915906612671194, 0.12434275039742071, 0.15545019489382544, 0.04593886074519927, 0.10001532958760377, 0.5488911499419521, 1.3005044864070032, 31.32164574438526, 79.17340278625488, 104.84191094675373, 100.52169476785969, 95.1984343990203, 75.02914413329094, 61.71223455859769, 49.000107396033506, 41.25753302727976, 53.49928563640964, 61.306355537906775, 78.6757089245704, 66.36857432703819, 48.87060250005415, 54.687089150951756, 43.72986962718349, 49.27333577986687, 42.64905660383163, 48.61640545629686, 55.348761620060095, 64.0197531638607, 66.93233659190517, 69.88995275189801, 70.28236235341718, 83.0735880328763, 77.84361731621527, 57.652906986974905, 59.37783595054381, 65.22544660875874, 59.3814641429532, 47.987367107022195, 69.78848103554019, 66.74145052509924, 77.08610565431657, 68.90604972839355, 44.84830210285802, 54.30064939683484, 70.52616903858801, 63.40128952457059, 67.26027027253183, 68.91998198724562, 70.4038538471345, 76.86504871614518, 93.84189051966514, 90.28545395020517, 80.77688340217837, 86.32279319147911, 84.5843751968876, 81.67065035912299, 46.36536898151521, 51.042038394558816, 64.96180057525635, 67.23244497852941, 71.2359219212686, 76.31295158017066, 89.6644486150434, 97.731046061362, 92.98481341331237, 81.09037491583055, 32.10393894103266, 3.4572518400607573, 0.6246881956054319, 0.2476248673854336, 0.05681497653225257, 0.02798989565382081, 0.12154927972944514, 0.069291741106539, 0.019746929399609085, 0.07183267855115476, 0.0735535801598622, 0.07929331007143182, 0.052512833593232985, 0.03417236692903023, 0.046053494311748974, 0.0564178059087886, 0.11785783910102422, 0.03512175671095329, 0.04815026546918577, 0.0389998814752025, 0.02587270825320194, 0.07359317924466825, 0.03181680552511206, 0.028790702682829676, 0.009671950059372091, 0.028132926184503783, 0.03360981324447259, 0.06151447012539833, 0.03881682476569568, 0.0693937916789324, 0.04297295517678704, 0.09890133049339057, 0.026688051800574028, 0.05288776468425509, 0.10763831812167361, 0.04343303311015329, 0.06460859199925777, 0.10884578760352828, 0.06257776185990342, 0.0024133586679630343, 0.07092678724157234, 0.06653914889020306, 0.026162253099403558, 0.0828759279102087, 0.1894712403056122, 0.05696061367709791, 0.034556357009756955, 0.008525437236042514, 0.06682051000215354, 0.059754735519809116, 0.025168255932869452, 0.1339048147201538, 0.04501452203840018, 0.02003635167174282, 0.04381920654146422, 0.022859822342833205, 0.1674196445533345, 0.1383923892412455, 0.2122624326617487, 0.16850344446157256, 0.1557414462008784, 0.1422092691063881, 0.08861960317458838, 0.2035137085664657, 0.1075265305717626, 0.10935937294796591, 0.13645916636432373, 0.1268863614888922, 0.23457992221078566, 0.17726880798657096, 0.2526857821090568, 0.12091852889786806, 0.1450371294612846, 0.24364263510271428, 0.17831480911662503, 0.32148364931344986, 0.24291471367882145, 0.18307632135768093, 0.33190799156023615, 0.18816423301975574, 0.14065625566628673, 0.25669602256628776, 0.19402741033944393, 0.1234289147560635, 0.09738664443214094, 0.12067895788218706, 0.12762226554895603, 0.17912582043678532, 0.1531404551238783, 0.16248796886253744, 0.1346261631096563, 0.17486572806392947, 0.18909077039889752, 0.16184005766145645, 0.16935207069881503, 0.17958332814516562, 0.11705197589171511, 0.17207920581342714, 0.08690394926816226, 0.18933901352988136, 0.09932510735046479, 0.12198051828290186, 0.16466316827122243, 0.1391507703210077, 0.13064219946822814, 0.17503342471055447, 0.08572298642848769, 0.15784501638864318, 0.19941630262521007, 0.1354818679993191, 0.08327884419310479, 0.351982253092912, 0.3474340810170097, 0.22240433361261125, 0.1365193502316552, 0.5589287403610446, 0.32437609088036323, 17.257332455727365, 76.26960938976657, 123.48756436378726, 128.43281022963987, 119.29397013879593, 101.81204472818683, 91.03642309865644, 89.06101549825361, 93.98359790925058, 78.96731361266106, 74.45412466602941, 92.07443129631781, 71.89892799623551, 63.310682773590095, 60.99724923410724, 63.97702286320349, 77.47935464305263, 67.82878645004766, 80.89502519176853, 71.71104646498158, 72.39029899720224, 83.2429716663976, 75.2521308775871, 69.72536225472727, 88.24699817165252, 69.97436215800624, 58.60641556401407, 74.82286668592884, 72.51586191115841, 69.08658858268493, 62.51424158773115, 81.83837090769123, 80.15109277540638, 91.83182485641973, 89.20175014003631, 75.20619992286929, 82.27917471239644, 95.86178564256238, 74.82217634877851, 80.29946819428476, 87.71074741117417, 83.66839978002733, 99.69291363993, 100.26396366857715, 90.48952702553042, 84.05180361963089, 96.05133025876938, 85.97414939634263, 82.04682134812879, 62.14536228487569, 72.24540664303687, 85.91293688743346, 89.13597199224657, 91.32092829673522, 86.76053754744991, 108.39584504404377, 119.82178780340381, 114.4308194806499, 83.13442399424892, 22.629083125822007, 1.2713620114711024, 0.5780039619534247, 0.37433492139943186, 0.12865459967044093, 0.2096324068524184, 0.2866850246585185, 0.1897773077531207, 0.10639616783948676, 0.19973524034984652, 0.19075946311556524, 0.17152962965830681, 0.2149389140428074, 0.19478206823189415, 0.14973427499494246, 0.20926644665098962, 0.15724273338433237, 0.10517313911188995, 0.14117272150131965, 0.08345965626499346, 0.11163981751568856, 0.18784624524414542, 0.11586737413440021, 0.10608648445697562, 0.10075285775406707, 0.1849989109342137, 0.1404413067164921, 0.3335081040859223, 0.18010967651442175, 0.16852690207381404, 0.13729204183384297, 0.14175352340023364, 0.1319738901070049, 0.16010010344607217, 0.15735560877909585, 0.23252018757404821, 0.20256976566968427, 0.13166622919661383, 0.22396465553151024, 0.11540562995979864, 0.1819948043914572, 0.22482161680536888, 0.1259648496465337, 0.13345809352974738, 0.1989153117662476, 0.1293019899317334, 0.20997775928868403, 0.09073948337426109, 0.09205060455227092, 0.21962285222065067, 0.21201593621123224, 0.1546886575318152, 0.1302305191394783, 0.13812687848844837, 0.08145338690449154, 0.09819829926615763], [0.058189625551383344, 0.0486667313042187, 0.06368726018756148, 0.03243563028292791, 0.07526967073640517, 0.11885502510854315, 0.11046723567790563, 0.06441640352169353, 0.10426699499329252, 0.040654662035165295, 0.034674602680869644, 0.06734708053690773, 0.08487560125368257, 0.04211581004182658, 0.05361060311477031, 0.08101912996461315, 0.10907551438938226, 0.02312033245670459, 0.0361192261710042, 0.07233207594723472, 0.021788000219291257, 0.023026787375490514, 0.059245968868415204, 0.05983756877662194, 0.013570161648995936, 0.036395446832982764, 0.10688257238437092, 0.016548839818325736, 0.09958013802045777, 0.03753101513270409, 0.02139034312999537, 0.0659992867299626, 0.08556112737184571, 0.0625837181935147, 0.04705433838910634, 0.036431966244333217, 0.02808216519864096, 0.03625309620533259, 0.0253627541655254, 0.11084052734076978, 0.03418303470337584, 0.00939433990542086, 0.05805913013436141, 0.03685388916863069, 0.07808763323531998, 0.06091485310706401, 0.025810856229415344, 0.216005660833851, 0.03162683487208861, 0.07977800624024484, 0.012909122573722516, 0.03639200326776312, 0.05273032212449659, 0.03576865284553459, 0.03290595847272104, 0.08492760330198273, 0.03856428388145663, 0.05523844419287578, 0.05380659904931823, 0.03544210786781004, 0.026387969414973934, 0.11119747834820902, 0.6955498577125612, 9.835184351090463, 51.89913511276246, 91.42145864425167, 99.98386721457206, 91.96662887450188, 72.26080586833339, 69.79889100597751, 65.0970438987978, 64.03206156146142, 57.93763183778333, 45.36551367851996, 34.9384456296121, 16.679873274218654, 19.893722188088205, 18.44049580635563, 31.125497817993168, 26.33812931276137, 25.712519115017308, 36.12773572244952, 50.62143087387086, 54.683825738968395, 38.880004036811094, 49.033914304548695, 40.89521192735241, 52.90266567660917, 39.91026947575231, 38.92310696263468, 31.38292101121718, 52.60199246868011, 39.03931110135971, 39.238453757378366, 39.65170683399324, 61.21619593712592, 98.06277659631546, 52.42758035659791, 45.012547431453584, 38.45052019242318, 53.58683293865573, 42.94886296795261, 41.32200502580212, 53.44840072816419, 36.19014063189107, 58.732437395280414, 49.195166864702784, 44.906109994457616, 54.15842033201649, 60.4322906463377, 76.88011846234723, 76.4456061393984, 98.2199538138605, 95.43958171721428, 89.92362314654936, 85.21613567106186, 55.3654513051433, 50.38943052291871, 17.316109172759518, 0.7548432857278855, 0.5132161819886777, 0.09724808977015557, 0.15910245778579868, 0.07642091702549689, 0.16461962383360634, 0.028072064329359322, 0.06973809457474178, 0.07080005331625862, 0.060733841852315014, 0.018991007462083813, 0.07229041608591234, 0.08312639269617297, 0.025220798073156227, 0.022380461976412806, 0.06609822698538342, 0.014481539105726107, 0.04059684920995947, 0.04028055831910141, 0.06795942227566434, 0.06868740498659111, 0.018356008672966592, 0.04641347902736837, 0.026972352774933945, 0.05686499441282884, 0.05520860506822506, 0.016702691340939175, 0.04251245972550204, 0.01447251075953846, 0.03588905505415413, 0.046136136046580734, 0.02805793766803559, 0.04567757496730455, 0.037837875481214256, 0.055324111975008444, 0.04399904568168906, 0.08389968950782092, 0.003183754879207681, 0.0808141631404719, 0.03050835607873817, 0.06575152623437105, 0.009219403727911413, 0.023672821661156994, 0.09624563307771761, 0.06329296622425318, 0.018726412184356202, 0.06957713950185046, 0.011658445732938427, 0.04501031621569588, 0.04545814440315289, 0.06598872237748678, 0.04730009556477589, 0.05943815351553983, 0.1037344566336082, 0.029683524532423868, 0.03437529212885326, 0.040766154641225454, 0.05996595362141248, 0.04124019069657211, 0.07634652988804926, 0.05317062732853717, 0.04987213617911743, 0.011929708848436995, 0.05225424827527135, 0.01828284727619781, 0.15288165530129788, 0.06582592103269792, 0.011585970942471779, 0.005818734165175908, 0.010163022952544834, 0.056688143015508695, 0.12585180571242688, 0.05712302048660575, 0.059587904552538554, 0.09076314016936288, 0.05502672430368201, 0.0226654926495206, 0.11438618143720013, 0.05688827582484773, 0.02703360533491979, 0.14216115878474328, 0.008297798039782192, 0.057504344581355976, 0.0483667734079063, 0.05968853403183241, 0.12247004846651709, 0.03918820503918875, 0.03591658442371315, 0.06662407739748878, 0.012535857723935718, 0.10263168838836494, 0.05001785759363444, 0.05105297644472411, 0.009887142242082666, 0.014294194219063127, 0.020762919035229473, 0.04111588526997836, 0.09606092927917358, 0.02093660074376291, 0.05663463943487695, 0.015677802636468365, 0.06438696276276343, 0.04388714321858941, 0.0187047740309349, 0.12684615719462597, 0.05320106017132921, 0.026382099266254136, 0.027073168030549443, 0.012905877233753282, 0.037015250268121885, 0.03622429896025889, 0.06844219556378742, 0.034412822776263764, 0.04106939139385377, 0.10776042487592467, 0.09571311003979176, 0.022773422946732853, 0.12869857311729463, 0.26148722837528876, 4.663654498515591, 29.62696609958526, 79.84242577706614, 105.95866464799451, 104.38529999025407, 100.73194949857651, 90.21270182824905, 82.90331794369607, 68.36817510666387, 59.92037427040839, 51.786398349269746, 35.55627384493428, 35.720625077524495, 37.67431843665339, 49.452784215250325, 48.287840274072465, 67.95365118211316, 66.23138550789126, 54.77408339900356, 58.23142520843014, 64.85021306622413, 57.04290390014649, 39.79454778855847, 51.6887430990896, 37.24776852515436, 44.70622208810622, 49.62666680735927, 40.14967918395996, 43.19265396364274, 53.06518123995874, 52.305253398033884, 61.36130794402092, 59.53295000137822, 87.24276158117479, 124.3678697463005, 69.77919286297214, 66.65849239595475, 49.549462795257575, 65.44227523188438, 62.92347031254923, 59.97154158930625, 77.38752411257836, 56.260936260223396, 71.91198164416899, 56.499122188937285, 55.60706146301762, 53.24683012500886, 59.941558991709066, 73.05445040425947, 74.07291735372236, 84.21815918337914, 96.44665025895642, 95.03972745710804, 94.97202734793387, 80.97825788682508, 76.52646187813052, 35.42121095042075, 4.502437729989329, 0.4311409538551685, 0.4014176616985952, 0.08815244275836215, 0.051928025054475, 0.10065857531322588, 0.1035692114683409, 0.13573446250971288, 0.06922432536920232, 0.06671582408730062, 0.025736836814171365, 0.040994360742549744, 0.03569120518682945, 0.032333005144591295, 0.03641182196236426, 0.034516734942313165, 0.03894666900798198, 0.027339764712979237, 0.13928155685144086, 0.04635920552837272, 0.03794908080430281, 0.012896322202117694, 0.023693686065774773, 0.03307770772446548, 0.05431268439297715, 0.051292363599303274, 0.0601077756483949, 0.0661131656999069, 0.06148530515812098, 0.06039060381872039, 0.04175020224084297, 0.0539217267425791, 0.025858759707320603, 0.0017490136838938682, 0.05205110090995028, 0.05539420902008011, 0.034120893481397824, 0.07708409635890877, 0.07109416979214839, 0.035921927886985006, 0.0645745930171782, 0.08007455121485457, 0.034804286044691844, 0.06307910128887143, 0.04679157023107813, 0.02925967489699683, 0.04802478026718863, 0.026416567477187323, 0.1294935119128035, 0.07677593749136695, 0.13174256219738914, 0.09071214935712277, 0.07191365404475121, 0.06555411303716321, 0.03142465852321156, 0.013845789550443091, 0.038862751736756296, 0.11161753201797125, 0.26031275430033285, 0.12920878767486543, 0.13779047395913832, 0.17079132008216075, 0.13846651590879888, 0.21040129865850174, 0.12428438981934903, 0.4105250375165094, 0.22880047830122135, 0.21821930253457641, 0.1883535946328794, 0.14583044415039403, 0.2802594468718575, 0.2097395212659913, 0.1637904409078821, 0.19428735929391078, 0.24141667470816644, 0.09766237479784796, 0.10313778905378235, 0.18623551473982874, 0.1944129670699758, 0.29463162405356286, 0.16069101770558666, 0.1613269166480149, 0.10231740081742888, 0.20625611947428799, 0.1453207811761287, 0.21114297902151463, 0.08872806590290801, 0.17120883800089362, 0.1890846416955033, 0.21932646812450504, 0.3120420752994476, 0.18320551442523159, 0.22719590714381588, 0.19615316643349587, 0.0849725190369833, 0.08032235767572157, 0.26531690190876683, 0.09083047163702788, 0.10926672993528266, 0.22296927749149262, 0.18470231233344925, 0.13477622441226436, 0.1733789505857614, 0.1708792976193851, 0.27538718896046765, 0.0643189647986043, 0.16931208090916758, 0.13369999345271819, 0.08870987897558559, 0.1319158512858614, 0.1752934809173307, 0.1532275439991105, 0.1743439915439775, 0.23851891649105858, 0.2724302121468129, 0.1570569110974189, 0.1403128184498318, 0.19813889697674783, 0.24976501061070353, 1.1114121685104987, 14.255072859025772, 68.9992452436878, 118.44103505534511, 132.82959107429753, 130.60253989311957, 110.18443799787953, 103.69348802874165, 92.18445377965128, 94.29143336511429, 94.04972122561549, 82.04267932522683, 82.68913299806657, 70.63728194082938, 78.85198024011429, 62.50257253646851, 95.16797327226209, 84.08621065078243, 74.31783799202212, 90.55500707318707, 93.37361443427302, 101.88384763656124, 76.32138467604115, 95.88920301006686, 78.12765967461371, 100.27311848055933, 91.51987875661543, 83.924357967992, 77.83663549730855, 111.17586412737447, 86.43119181356123, 90.47348453152566, 83.03310917269799, 109.24635610272809, 137.85228021683233, 92.41178651009837, 94.39234026016729, 80.43106371356596, 106.43593865056192, 90.70908561829599, 87.74493478959607, 96.36637503100981, 73.26142603351225, 94.75544975649927, 81.87258182033416, 76.25140174742668, 80.30980756205898, 83.9113356990199, 97.49295819190242, 96.89081945726949, 111.8966624044603, 118.63614159245645, 118.13966366552539, 119.6429983262093, 88.99614734034385, 69.4576055772843, 23.694636168018466, 1.6917647108916314, 0.9117045073259262, 0.3403687891700576, 0.25359954114162153, 0.1731345991814329, 0.2515125490965382, 0.16915425147500732, 0.2710613662437085, 0.1667980714550903, 0.13303365017617905, 0.10865256490726626, 0.20313248789358526, 0.15562276385964888, 0.22164242852839733, 0.13251571345233149, 0.23731859460953744, 0.10659419390703402, 0.27209285766847674, 0.21551548713637939, 0.21753912371012474, 0.168318281010274, 0.05274829837763983, 0.14520854929522162, 0.11577788740396501, 0.2281081493222906, 0.12378784993122663, 0.17312923656596294, 0.2248642879027513, 0.13644626544367883, 0.23816133729152142, 0.19182175127488954, 0.2445444278419018, 0.0564928480514115, 0.20939974594981442, 0.09560869225571234, 0.18596303258692065, 0.20351980662634298, 0.1159448869105789, 0.1673008243162786, 0.16259371963960512, 0.16907332194668634, 0.2973922065669491, 0.07352482888006395, 0.21561213678890662, 0.12330054906347107, 0.06463506033704167, 0.13120095335668133, 0.13940495829428398, 0.216969215581494, 0.11655349014026505, 0.17107016076484036, 0.11639464947004473, 0.27875791454026777, 0.16758259145482896, 0.1329093294278268, 0.125440156027194, 0.12929405326083784], [0.040433638008131136, 0.03359538397841877, 0.04673970990904397, 0.07410416755104259, 0.018665326248493888, 0.014460401782285304, 0.01913500134833157, 0.05667326941845879, 0.0855598556658914, 0.03200324451280458, 0.05484055727720261, 0.03505928224072822, 0.0110861579436929, 0.013767578676643391, 0.02303404797379288, 0.04716713334463778, 0.057389124957544196, 0.071480002314333, 0.02499099084807019, 0.06936916961304604, 0.06203861982231179, 0.017913116006961754, 0.03545765945267293, 0.05007285887615816, 0.07735166022734297, 0.028521842210583633, 0.09365064046916463, 0.03813914721831679, 0.0754334373519786, 0.09154606670621904, 0.019610299533533476, 0.023325630613873084, 0.017878705252622886, 0.052158437489021214, 0.0062257356119282065, 0.022246695363954194, 0.005043667690422867, 0.05719356186267349, 0.003285202636165665, 0.018097373559289885, 0.028950165799488465, 0.015439666120425589, 0.029053070559917443, 0.021709351717764815, 0.043837358994830045, 0.017599908619998925, 0.028801102326401783, 0.04662523339051874, 0.02087146028756134, 0.07235873580699967, 0.018047093293599544, 0.03839945623410806, 0.04102718761010517, 0.05240635120219762, 0.017036937417522553, 0.11480655686389055, 0.08013113446894192, 0.04162015498525674, 0.10244257192337707, 0.011210111927451387, 0.014275081282962235, 0.045165395394207976, 0.04372358727719515, 0.22413599875665483, 0.07480137651005099, 2.2099739168920824, 20.006437378544963, 48.06134300847208, 85.71983860385033, 93.37963135011735, 92.08863812108194, 73.53840812560051, 59.52463457661291, 55.0714147475458, 50.542457872821444, 54.693490459072976, 62.160785044393236, 56.777280992077245, 50.38468837738038, 43.45669615653254, 54.15165032109907, 50.11176986079062, 52.69798071153703, 60.7021693260439, 62.018606970387125, 56.3475892620702, 58.44193489320817, 61.972130806215354, 50.5995205140883, 51.112244898273104, 52.57653236389161, 47.87741130398166, 57.032486084968816, 52.76647313948601, 48.54615972888086, 51.31544328504994, 45.78053966645272, 50.491129736746515, 54.990402114006784, 53.67024998511038, 52.93940259564308, 50.00170423138527, 56.451147679359686, 49.3171408099513, 51.096822138755556, 58.61385237786078, 64.26078281094952, 73.38691834480532, 78.88726588218444, 89.08036847268382, 95.37211695025044, 117.08898621220743, 101.25739020685997, 66.85148085317304, 46.729910142960094, 18.548839515255345, 2.103578155079196, 0.31411596724102575, 0.2798455142446103, 0.03471024492154679, 0.03125127175852897, 0.043618073987384, 0.047248622117143486, 0.058622714207177205, 0.0905205660890187, 0.04940824695832787, 0.05116686690598727, 0.0559204041717514, 0.07015990258585061, 0.0216270221637622, 0.08394939329234824, 0.08584545324406317, 0.02341493348320646, 0.028998456151795485, 0.029754297650088708, 0.023592880386258328, 0.064880384673034, 0.049375408599453594, 0.0028457920791791574, 0.03220146784799234, 0.0663650707311688, 0.027319321656719815, 0.015428637327145667, 0.017856747257493196, 0.07336595756632668, 0.030420097004201625, 0.02213463968326969, 0.006315631241792994, 0.022411844768230955, 0.06551789240010324, 0.05371155818143199, 0.058377861015258305, 0.03193061171670354, 0.06972939181592196, 0.03618981734278702, 0.051452138896791205, 0.06152331078004453, 0.12855638719854817, 0.09959743628578802, 0.06972664922115303, 0.013671298661539632, 0.005496902064600539, 0.03156718343586451, 0.06782968528568745, 0.047439435466883645, 0.056299962433836157, 0.057554021552805944, 0.0582462432794273, 0.055142192906069185, 0.06497435301782624, 0.0782825566467739, 0.017593561581546263, 0.061145797972717596, 0.042282426504478346, 0.016767559835927624, 0.028897277004415953, 0.011905948631465437, 0.021416652504534974, 0.057723499353854894, 0.05477986779184111, 0.014483467732075483, 0.020807748585338556, 0.03583144524224824, 0.04824453641870811, 0.06031337449507368, 0.021240015611833623, 0.08266336915473785, 0.024157385679803068, 0.027057338738814, 0.03888431328138517, 0.031638466001998995, 0.033816829353811285, 0.05432605645769546, 0.06060359158342885, 0.05895533043170168, 0.01225319043207433, 0.00864454667128983, 0.07552129997601432, 0.05077820751936205, 0.06051878948065062, 0.06500631420602722, 0.04608159824725121, 0.08565044556293758, 0.06602921778516424, 0.10136558253678585, 0.0420597592188466, 0.026791186387380286, 0.02333389287213645, 0.02216709116774221, 0.06351623488890548, 0.01245919339013316, 0.04673435878489287, 0.02690940716063544, 0.012307157495900268, 0.012150869813687619, 0.0335309061882717, 0.060110319060303515, 0.012525219635497178, 0.027381447556939338, 0.017904413248141928, 0.08042319016831537, 0.049918392567985484, 0.042938661250856616, 0.024908088643344182, 0.01065825761836623, 0.13630040230289583, 0.028335763284215526, 0.049528097583641933, 0.04421016802230189, 0.024526329793696924, 0.02106861301487492, 0.07461232133209705, 0.04890191263609356, 0.10375281976115319, 0.1970056537538767, 0.0671501882794884, 0.07876824872988848, 0.043875912369619456, 0.09350801021942208, 0.4446221401374187, 1.026672486576342, 13.661186791235401, 47.404938282505164, 79.47963791508829, 98.91241688882151, 98.73507084385042, 96.69715635238155, 88.40101395883869, 86.59042435307657, 83.49867097793087, 69.37948765293245, 63.51584234545308, 65.26640792046824, 52.248112309363584, 54.72361033962619, 49.7028313913653, 51.96630962433354, 59.25601890010219, 58.69397463337068, 66.5336747323313, 64.12459419619653, 70.13683457528391, 65.20966299118535, 72.84183440669891, 63.95394755947975, 64.99643118150773, 67.79922746842908, 61.756286698002974, 57.20899274272304, 59.72461661984844, 59.992957730447095, 65.1329178963938, 64.04460922364267, 62.3497530721849, 66.46575497042748, 65.55429027926537, 62.08045882563438, 59.279619801429014, 56.201124037465746, 54.83651576503631, 47.78889125393283, 59.130573657251176, 68.09583710085961, 71.15311284219065, 75.6009001885691, 93.1769467938331, 96.41100375883042, 118.2283562998618, 124.32484134551018, 95.75813308838876, 74.69974348621984, 42.1799607430735, 8.266784433395632, 2.296696540809447, 0.4783771998218952, 0.10668532772650642, 0.049216790094731316, 0.002713387427408429, 0.023111022573204774, 0.09777361842533273, 0.08961269827259165, 0.05618507222783181, 0.10926881369443671, 0.05371855256418067, 0.01580271039969258, 0.032658646138565194, 0.030410653055315057, 0.006832835872867897, 0.05805893861238034, 0.08785889318753635, 0.06391424437864654, 0.028061116932921355, 0.021037038701075702, 0.03838975756098667, 0.01878116257308472, 0.17886075401498427, 0.002321359887343621, 0.03818253843834804, 0.04385789398164038, 0.010194320517081407, 0.08362324668034431, 0.03885252063252753, 0.05818714342650868, 0.029487729695956075, 0.07269704789524117, 0.02205016508307909, 0.10069739298834916, 0.09101660801999031, 0.12107229806602963, 0.023312898232571544, 0.03666188072172865, 0.04668311133319813, 0.07674215301390618, 0.08643118874920953, 0.06813501728878868, 0.07617470402751239, 0.05958868596222132, 0.015239409779408767, 0.032011577634200934, 0.030927398512440345, 0.049676086618414814, 0.060954570935498324, 0.09636370254860771, 0.0247284391098806, 0.07294675425416039, 0.07396771963084899, 0.12612751309549616, 0.10870399238962321, 0.08280687274471407, 0.020248598246384534, 0.03600029485119927, 0.019966802379537015, 0.08956191430409109, 0.1296106314346675, 0.1904146622626051, 0.14572418775529633, 0.17678064143946096, 0.12368064358710282, 0.23203194441814579, 0.13176703104569068, 0.2854829714182885, 0.1010600513508243, 0.1286510909877477, 0.08243347382954053, 0.1039455215176267, 0.17196090651615975, 0.07836329465311381, 0.15209623131780856, 0.20242361141549003, 0.18546273120709006, 0.124159571113846, 0.14491221116435143, 0.18928736388202638, 0.19374631735826695, 0.2564198325478262, 0.14442669528145946, 0.16411320907213997, 0.1519402251729081, 0.16888495624786423, 0.19483472911580918, 0.2107828104447934, 0.31054639587959937, 0.12478995422321944, 0.07816895346848235, 0.09892647349906546, 0.14241589834132504, 0.08617555286975638, 0.12695282727720278, 0.07980194648787861, 0.16019508302692445, 0.12413262780154906, 0.07386780644376433, 0.1284927176311612, 0.1636301293488472, 0.1384658417514255, 0.16225722317974414, 0.24912286039081313, 0.15260964812290284, 0.0860394650108872, 0.12814492903529637, 0.06317698051251712, 0.15134874400832962, 0.14589289563798136, 0.21461830624649603, 0.12970798588808508, 0.27205792405912954, 0.11016820857842123, 0.19850171621768706, 0.1396148817072953, 0.1780561012245955, 0.41634660094015064, 0.24244487195486025, 0.17490006412469572, 0.12589125924052733, 0.10726239877722918, 0.4819475985582798, 0.2015104499315062, 4.273261485561248, 29.63891952268539, 70.87438921774589, 119.82400786492133, 131.43329005087577, 139.90218931628812, 121.73695564270021, 114.11491963171191, 103.40491925516437, 92.3826511444584, 89.77534970929547, 96.70107872255387, 90.47484167160528, 88.8209193752658, 77.97958235586844, 85.60782355646934, 85.11748806122812, 81.03722679999568, 98.66013003933816, 98.707473047318, 91.74324204844814, 93.68639207655384, 100.3459333604382, 89.10547948652699, 91.04222036177113, 97.29510599567045, 86.18895407645934, 89.19411720768099, 87.66046262556507, 78.76946926116943, 84.9814602636522, 79.63741133289953, 81.43369997701338, 88.38480672528668, 84.77471997660976, 79.1618396389869, 71.49058572707638, 78.69910978501844, 74.3451141542004, 70.84111967394429, 83.96700982124575, 85.42032641749229, 93.56451619055964, 99.90215639914237, 117.84156353242936, 128.24623092528313, 150.23132754910378, 141.09286400579637, 95.3664138240199, 65.90400095908873, 29.771562314802605, 4.128060244744824, 0.7624445326866642, 0.5046946182847023, 0.24929443344233498, 0.1138116384766275, 0.17737527888628746, 0.15930570091211027, 0.2013428452154321, 0.2190479798422706, 0.15055283994203614, 0.19678420837848418, 0.19936636901430546, 0.14042299721510182, 0.12001918764003824, 0.13698638807381355, 0.13879066303132043, 0.16661260156862198, 0.15755808581748318, 0.13539445736715872, 0.14140981039212597, 0.11872868954895005, 0.2776236141160611, 0.08677263413706134, 0.32131152467862256, 0.19245812519183084, 0.26221338779695574, 0.11963801293243324, 0.08707078023543281, 0.22808381836981545, 0.15565759021668665, 0.15617250855411255, 0.10119510499099571, 0.1351182673486971, 0.12196332726988102, 0.35526052718200996, 0.3543643268846697, 0.2279051207005978, 0.23759901343334108, 0.08163753911973008, 0.16254567060499422, 0.1857338497234929, 0.30520317775587885, 0.17147709134845965, 0.19022393701297624, 0.135043864889491, 0.10793872417942171, 0.07620664223307565, 0.17323670337998098, 0.14398982598175927, 0.20934179905922184, 0.17554693344619968, 0.2106396286117454, 0.1894594885168537, 0.15932721266102406, 0.23990895238614854, 0.20776125241912183, 0.13858418701396835, 0.1688686079315601, 0.10415782746408256, 0.19528480577132395], [0.02863674773834646, 0.03476515044307998, 0.09415392959189993, 0.039502500271004055, 0.05897259422307534, 0.056624235960865216, 0.043252573438709786, 0.043982272186586936, 0.07082475965181667, 0.05520128892854818, 0.017508251945518197, 0.050033558565642566, 0.043298757049225034, 0.15355627232741925, 0.042684274094720046, 0.02137258329669074, 0.01661710591325837, 0.07900006693577574, 0.049376255126609925, 0.093297021944196, 0.0734639861771176, 0.059854664028652256, 0.06501891635238163, 0.11549831893775733, 0.03762257796141409, 0.09325219813974635, 0.056584464506276196, 0.05370578187848291, 0.044065185882631815, 0.02592632483180252, 0.03547490792228811, 0.052229296791577534, 0.014505361567341514, 0.029745874513361244, 0.011279134534209246, 0.058110795103974884, 0.04650194303042466, 0.03906231381059174, 0.05176332381163394, 0.04201577045023442, 0.02678185160602293, 0.036072502468502333, 0.08411243978527286, 0.04027165637742128, 0.020101281453765208, 0.05167243130985768, 0.06517627081202884, 0.0833416863855335, 0.0321382655942392, 0.06375177628210475, 0.0452983767665442, 0.02788547978496119, 0.028868575520332784, 0.02929222597289951, 0.05667675511851426, 0.026567289530630075, 0.03439087818767275, 0.030893931961468155, 0.08934936320949947, 0.03104013218093784, 0.057429206677742546, 0.05041594752260754, 0.03074501404508708, 0.034111727239383806, 0.05581158138210735, 0.08897260116833834, 0.2350910713956241, 0.06385586464837675, 3.0657377646815394, 10.215608169955592, 28.681241466153054, 55.17805222542056, 75.36200431085403, 82.16806965489542, 90.28601092676963, 100.05540340177475, 92.7564844008415, 79.78270376882246, 76.10789791230233, 71.43864570125457, 84.87476395022485, 77.9225040251209, 77.64061897031723, 98.35116494086482, 105.56126579161614, 105.45062357379545, 115.02356021634995, 102.63104346490677, 91.7482783717494, 86.45838168359573, 84.5944635329708, 93.20114781779628, 88.7122069635699, 83.0778398821431, 99.71499658400013, 105.68594224991338, 105.53361308190131, 98.14372647193171, 98.827113182314, 105.10984805322464, 113.91938947862195, 109.10022427958828, 100.10180504091325, 98.89078109495102, 107.5786505976031, 111.25295439074117, 113.70271775030322, 103.9306894425423, 105.36848914238715, 94.84681744729319, 66.61224765162315, 31.63124038327125, 8.37024086906064, 1.9354701498823783, 0.2953198161577025, 0.48977288026963517, 0.19193350818128357, 0.026460381960796735, 0.052399847115720474, 0.06280005759289188, 0.02590002120292235, 0.05750888365230734, 0.04720232742387922, 0.02854185817282527, 0.005245110031307465, 0.04334851829034667, 0.0269297850994213, 0.01666006812405202, 0.14662150654100603, 0.02692216827023414, 0.05100724482608419, 0.05510527895943773, 0.021316176242825967, 0.04835975221208027, 0.024619177734899907, 0.019299809843482032, 0.020405636694762978, 0.030427060743433335, 0.0615095786540018, 0.07984096334586221, 0.006010511828090755, 0.03048053368054811, 0.024363836799297604, 0.036012778253925425, 0.03289888365074031, 0.0399471836675319, 0.06632989197368584, 0.03553748198394333, 0.0681893942096541, 0.03975729728418012, 0.056261202215307185, 0.031130589927817066, 0.0253051960645544, 0.05150052501008876, 0.06837673335065765, 0.04717205162911166, 0.011051118997256122, 0.08165623166508253, 0.09243099785019314, 0.04790582596474598, 0.0588391800110619, 0.028975322211702025, 0.02835833798012426, 0.029081199393277208, 0.11452073712022075, 0.05613106302917004, 0.025920650035503413, 0.06160476124815403, 0.15153845802189844, 0.021449322324065913, 0.09109733836545099, 0.06366248107365062, 0.041358980290111036, 0.095733625874404, 0.06432534631101355, 0.03426528190292659, 0.009505963704038051, 0.04992853557210296, 0.035919012922433116, 0.02180535211077621, 0.03081856040103782, 0.021087035514234055, 0.06620349512705881, 0.03733920586866237, 0.026918876007379546, 0.06666606667661859, 0.05946944054636744, 0.01997191984687121, 0.03173948235569462, 0.08407063436724486, 0.06581417690481871, 0.012442894869544094, 0.021489040152500236, 0.07039717533775876, 0.10052955844589781, 0.0834006215295484, 0.02189725967905214, 0.007671076830686822, 0.034762913466341076, 0.024470629455942302, 0.026831986315007654, 0.06640921271736584, 0.11821131206928723, 0.09516018608044233, 0.11614076027105893, 0.04015094007275278, 0.04765390944216521, 0.0429662557378892, 0.057093407357892687, 0.054959649475471634, 0.017569265103027705, 0.07462135350872433, 0.025947141355925032, 0.009281630177171001, 0.017720280185101495, 0.016408226295043866, 0.041149934047773, 0.0876127261548273, 0.02339917696982382, 0.022555815671840986, 0.03565710278288011, 0.05194351918274357, 0.045369714874053196, 0.018880282859167746, 0.013019434446769377, 0.021018311681766665, 0.031232134882180445, 0.053276535153629324, 0.016521367905361038, 0.07185219081058618, 0.05124965802796426, 0.04356561994720851, 0.06928817113681186, 0.0132766044172909, 0.06507721564341938, 0.029072465990940412, 0.018088538650303118, 0.028373924038943746, 0.11035337202971983, 0.03853930558468546, 0.16197585440691442, 0.10233274555855221, 0.9062998489506784, 0.8612407022906888, 13.569306250541443, 33.44615244096325, 62.44853012023434, 83.10530431808965, 94.29276697097286, 90.37778654406148, 96.74315790976249, 100.57483503895422, 105.82597870980541, 100.29752346777148, 93.96798687596475, 91.8662161980906, 96.41924073619228, 91.85696724922427, 97.24518206811722, 110.29529202368953, 115.22433065599012, 114.50721940686627, 125.7367612469581, 121.84234188449, 111.65849608759727, 106.46333248384538, 105.31166184333064, 113.82620180806806, 110.77349955035795, 105.37267038899084, 113.99262797447943, 118.09443873743858, 120.33706172820061, 115.48568602531188, 117.40502726647162, 118.2128550929408, 118.77303231147029, 116.42343844136884, 109.23242384387602, 108.74870930948566, 114.61997185983967, 114.82037359668364, 116.09082145075645, 123.69466550888555, 119.76958890115063, 114.58204254027336, 95.2157477409609, 59.030200204541615, 24.28909294066891, 7.4095205241634, 1.6994309833934231, 0.42816669409794195, 0.32143639701028026, 0.19566149120369267, 0.07706165764360659, 0.07072049508532209, 0.10897415329612072, 0.03915010365627466, 0.039012376369247516, 0.021759451952792948, 0.03207919255439793, 0.018905376069127552, 0.08963987141126588, 0.07711661679129447, 0.0665956785181357, 0.027991414423130696, 0.011933228064839159, 0.02167937661250753, 0.033120202621625315, 0.020297375064523473, 0.016271268926380623, 0.01186515061905788, 0.035490114767585075, 0.03575040846161785, 0.0506094077061261, 0.040633671226040016, 0.0673745830933894, 0.052587925531570955, 0.05340264854772438, 0.046818176464688395, 0.037826755714993325, 0.01750167316546844, 0.005367105702809509, 0.07901485243271436, 0.02000702199556174, 0.04861031275903506, 0.025474997537751353, 0.06816317868088523, 0.06942464203964319, 0.06702111778600563, 0.02012217841711977, 0.021122976529201674, 0.005936335364822299, 0.043726299228447105, 0.04347560461610556, 0.033677075764224414, 0.06943704500313728, 0.12917693373897385, 0.04879120527015579, 0.00881857599221891, 0.17988133634771072, 0.028888260149547172, 0.018895817207052343, 0.10474925500250633, 0.1637275297675402, 0.08681387265002535, 0.10854813180142835, 0.07330101629298541, 0.048439004007847085, 0.11067542773220809, 0.04884023489730974, 0.05766274858145945, 0.12285811030456137, 0.1535865634439453, 0.18789814004013616, 0.08502318809229521, 0.22442145843900022, 0.09642450694715786, 0.14336376360827877, 0.1761316423935275, 0.2076073147116169, 0.16937995629925884, 0.14371909050931855, 0.102976328362861, 0.16657636560980352, 0.2871768837494235, 0.1389469909331491, 0.20658690091823378, 0.13700554027192055, 0.15355130807766992, 0.17749506439412796, 0.18895581635015626, 0.1595984690732533, 0.12511858296009803, 0.13730195501158315, 0.15446051654796447, 0.13929315542261447, 0.14776481615920223, 0.1965701634124402, 0.1150297642415089, 0.1170285642447491, 0.08796387787667975, 0.12817748011119906, 0.1644516360735701, 0.2015487696494787, 0.16665680484185297, 0.13555967188890905, 0.1503784936522284, 0.20121832528421957, 0.2049270028909368, 0.2038575135051243, 0.1506666959293427, 0.20391700789332393, 0.1315831086568294, 0.13012441596196545, 0.06340336715502125, 0.1124204304670134, 0.2612528667574929, 0.17713768437745112, 0.1629545470519412, 0.16281292803825873, 0.29372528075210513, 0.13334425286419932, 0.15345570030471972, 0.11990198384850256, 0.13338798116291725, 0.19620614907433911, 0.13832246073551718, 0.1783876640782241, 0.195408268501201, 0.22483952794103856, 0.09002172027624424, 0.20865198284868272, 0.15093297277006412, 0.1095019419106745, 0.18845853335674734, 0.18104130071738075, 0.26025925071970113, 0.5894341163577572, 0.20428667596030622, 4.841156947997309, 17.566470138488278, 46.91064511576007, 80.65266978356146, 110.84107414368661, 129.79013073828915, 139.13199270925216, 147.62688944416664, 144.46319980006066, 137.1965854398666, 127.8888951578448, 128.82910297762965, 137.64048791700796, 126.33839007346862, 134.1604983422064, 148.95966376027755, 154.48041546729306, 151.75791402016918, 161.9548683781778, 152.09875229866276, 137.60251937373994, 138.28964018052625, 140.35548979236233, 148.07000744727353, 144.5062360455913, 137.62417085709112, 146.96419715881348, 152.7329367976035, 150.68542818869315, 147.91154369231194, 144.07623444834064, 147.33923850520966, 151.88333572879915, 150.16009730677453, 146.27070642286733, 139.32975861334032, 147.82134486782937, 146.82346251703078, 148.78908772622387, 149.3594160387593, 142.01716269216232, 125.87683693055185, 89.63650564993583, 43.77994652717344, 13.232339351407944, 3.1035668186603056, 0.551963897962724, 0.612774976799565, 0.34342688958971734, 0.21299634489320943, 0.1365890642327647, 0.19200100052741267, 0.3229029038019719, 0.13817834427520154, 0.23964020874231096, 0.1495249950957875, 0.13966290009838922, 0.25905186550751813, 0.13638989669421028, 0.17363588115380657, 0.2525834480841314, 0.12783990346736487, 0.2187157734747856, 0.17402641745584627, 0.10737989368217607, 0.1387087069451809, 0.0801391477486299, 0.0832662114032334, 0.10225019192383175, 0.11610291552759948, 0.1789677305327308, 0.14973036794652864, 0.17985216371955412, 0.17463697420973934, 0.15667719195687002, 0.19454455033185022, 0.11223221032489693, 0.11392985350422322, 0.17613093759263718, 0.18147263886226764, 0.1772329703934731, 0.1442086973017262, 0.16398390875227992, 0.1867530071326802, 0.14577281901672964, 0.13646863521106783, 0.20885332607694213, 0.12149598299255296, 0.10952794293482458, 0.19585543402260353, 0.16735368438305395, 0.18347644908053262, 0.1424781200025351, 0.23699777230860727, 0.1574929989874363, 0.07890603730394956, 0.29594990815366473, 0.12671710968378092, 0.14102345693015284, 0.25073089426563633, 0.29660901956019864, 0.16940486947855643, 0.18192437026769886, 0.1257430135662998, 0.13213807807093667, 0.16368351035541104, 0.16919508396137148, 0.1550078557263459], [0.046158180226601904, 0.043890356957431764, 0.046746443821898395, 0.05493554834937377, 0.057422009281693935, 0.027988242819124175, 0.04282063774524197, 0.02901070589770473, 0.12289220887807109, 0.0373694586807922, 0.017474419587562164, 0.02614270828123535, 0.0367715998342441, 0.04485256339032804, 0.004033929811069562, 0.004755633952651894, 0.0472904313656111, 0.05149677117925979, 0.0295163162668506, 0.15898008290077412, 0.011935740833230799, 0.049054176441483924, 0.07266134053709046, 0.037485494188243346, 0.10996644400180348, 0.04117938246758234, 0.022821787992612492, 0.05107479845924724, 0.04252645232143902, 0.07151020150030814, 0.0016963561516134971, 0.015242887818585, 0.06327309007305773, 0.08086720706834909, 0.026290762433481794, 0.023493871182924318, 0.03048377806290744, 0.04772637752936252, 0.05928485549145168, 0.03373970345203434, 0.06921206796241385, 0.037114734445968946, 0.017313347686262383, 0.04284768447940869, 0.0254130631595129, 0.08092630309082809, 0.010576007545985764, 0.11360234325571407, 0.020893542771978725, 0.04701376254219682, 0.07310695856088593, 0.06545843631629983, 0.05017554147108909, 0.059909370367325125, 0.050259071867913015, 0.1073043727346005, 0.08225544265681699, 0.020782180400865696, 0.057786176837379896, 0.010566686171167081, 0.03548750240776328, 0.07047688678628014, 0.14908225756258736, 0.05890456178495961, 0.08672118367206666, 0.11493231785754043, 0.1052949394309713, 0.05797213702011974, 0.038750339825187004, 0.1892527520296074, 0.15142440285173156, 0.11900308692166883, 2.115286184895423, 9.81082643232038, 24.812972545623783, 37.41890153577251, 40.237061746658824, 51.23051220370878, 58.44131515872095, 70.06863240272769, 68.32224415194604, 47.521675863573634, 42.16498513375559, 44.66493521967242, 42.6319315356593, 29.86392040406504, 28.355194445579286, 7.232028861199656, 2.5455003255797974, 7.621478053831286, 11.866912284205037, 15.449757191442675, 15.311362243467762, 14.017350750584757, 26.69299202580606, 28.274226919297252, 23.319606588732814, 17.156054896693078, 9.826498262343868, 10.776845409024148, 25.856401458863292, 29.551980187816007, 40.613166055371686, 38.43446593130789, 35.62951234079177, 34.534610163780954, 28.787718126850745, 15.332924492897527, 9.664789726657252, 2.5895004935802954, 0.6278691765281462, 0.3338272869586945, 0.26238637045025826, 0.018783619800101847, 0.06180693185137165, 0.03994410782451591, 0.06344124254199766, 0.01829995784998661, 0.07688815405051555, 0.0350085940332182, 0.05078393402659605, 0.06028860687248169, 0.03233963180513632, 0.04615456812203892, 0.055345750128429745, 0.08798631659198193, 0.08409038411393281, 0.03274042985492176, 0.05714779193963736, 0.0640000883610018, 0.019928833146789865, 0.04889674154260466, 0.1146752340719104, 0.02809177385643125, 0.03467628807430306, 0.054454456624244495, 0.004028935396608206, 0.04470717905449771, 0.10712169906905583, 0.13546009578051108, 0.10326882073235127, 0.02713010368508197, 0.03401655613655045, 0.05535464823967027, 0.060765174848418084, 0.07198454782126412, 0.02474368042913416, 0.05640148440556181, 0.047753703885621605, 0.05687254037888301, 0.024259857600554827, 0.06623337255610574, 0.062023792190537344, 0.05195693338229772, 0.1049003045585367, 0.07356059752524861, 0.06866462153172301, 0.023496608032033812, 0.04465377889573575, 0.042295898160626816, 0.03995143545551166, 0.010927816188233274, 0.05832680891598425, 0.06349975633765421, 0.04957763665926553, 0.08652581592961665, 0.09828965525112807, 0.09119723623077716, 0.02006194858451284, 0.06833099024069887, 0.025123573854685794, 0.025838567544856382, 0.08413610424125388, 0.09995571262533627, 0.07802155049097154, 0.04570279841221148, 0.053030218733775045, 0.012738624918124369, 0.05577872004059534, 0.022355761386514194, 0.027794179341365254, 0.07248080425685452, 0.027177647101662816, 0.0447863006153174, 0.003525738204423819, 0.014996505323647252, 0.04303698097505877, 0.036789453513319456, 0.058932975986071175, 0.030747212717429768, 0.05363871471115178, 0.024601308734066064, 0.018246237849516254, 0.07593176988584381, 0.018413132019040566, 0.07833750813358253, 0.027875292730788072, 0.043610528021329836, 0.04876447646247764, 0.019893064501605207, 0.04630934469582093, 0.08395241933964914, 0.060292061929020195, 0.0898857320088052, 0.07624425715015781, 0.025181463288684047, 0.02298520795340019, 0.04665249845974388, 0.02837562475413565, 0.02026205458077452, 0.04982273882975982, 0.08193753148999908, 0.04246609991476421, 0.07844194123942046, 0.04082100270616432, 0.0622882342506801, 0.03931697292794143, 0.04823515950251491, 0.04595569169689571, 0.013082025745402903, 0.021655413382236036, 0.05007162930503969, 0.07408918287124365, 0.07922161190259842, 0.10265057245569845, 0.11774612815990565, 0.03662787407876984, 0.07204349062615825, 0.011935489939435596, 0.07550407065859727, 0.06823306888221733, 0.03903158602394885, 0.05583208572540072, 0.02527630305849016, 0.0804025594205145, 0.041245216233355385, 0.035535865538423105, 0.07335532426593766, 0.09664627407947857, 0.034881431098666885, 0.1476680592543656, 0.08021760281295547, 0.1225501582807591, 0.07969903789701001, 0.11591415912393602, 0.2983916448729654, 0.9943309510427137, 2.017658636454613, 10.901614043020434, 29.864749985356486, 50.50416769519929, 70.0537666197746, 71.5362342711418, 83.03889859107234, 91.84249370328843, 99.0575602746779, 99.79349890062886, 81.10814325271114, 74.07036781311035, 75.12199448001, 70.4845997595018, 53.96614574616956, 46.18923102655719, 13.831582396261155, 6.268718771396145, 13.578098243282689, 20.094294548034668, 28.443549756080877, 26.267922809047086, 25.877876435556722, 39.309429045646425, 41.3221070074266, 35.17252483675557, 29.66877660443706, 19.173188670989006, 22.113624849627097, 44.999725203360285, 50.18138800897906, 62.01004443630096, 60.77696108048963, 58.33771359535956, 59.14557280079011, 53.95491207799604, 34.22998712908837, 24.23262061611299, 10.9223682841947, 3.418181355922453, 1.3567913563982135, 0.5907687640959217, 0.46419216259833307, 0.09284381198907092, 0.08828280794043696, 0.10552291187547869, 0.0077508064737964065, 0.10760017460392368, 0.11777353878583639, 0.06558391385741773, 0.033586420749704686, 0.016154375400454286, 0.04671225714827738, 0.11727988704918854, 0.04999640330131497, 0.056180069673686266, 0.02213057750205119, 0.07099823260139074, 0.04431573876870736, 0.030274076815394145, 0.009745447577217655, 0.012040656574461009, 0.030576300416742603, 0.022817605152545918, 0.028975090470104933, 0.07536652723267194, 0.02725157267113607, 0.0498642914387728, 0.09025148536649444, 0.045135563930436495, 0.04208513971177801, 0.06450958279592377, 0.083016688905416, 0.02291093764436101, 0.023929869057610634, 0.03651706712140191, 0.045733032072143215, 0.08342732735458883, 0.07190299776172446, 0.059471137431119724, 0.12526838379281183, 0.04571971746401922, 0.08436771560340159, 0.03958280926810638, 0.07373216291589123, 0.03436083604972209, 0.01188185420863691, 0.022479777614916527, 0.03283377383805571, 0.026060032072447004, 0.02078697228083207, 0.03847301982703709, 0.0805981416675833, 0.08862281308299111, 0.08165682921366346, 0.0554320958983754, 0.041453530861725735, 0.012814682127246934, 0.10807485800356635, 0.05532652898240955, 0.01400487632640908, 0.08175861165528336, 0.053724662115376805, 0.01765812747180462, 0.0211339162647604, 0.19046572968363765, 0.11397631673683083, 0.13698189879857725, 0.10891465124704185, 0.16272542547554741, 0.22621156076990792, 0.09563561258537155, 0.12519977295831328, 0.2486486826092005, 0.06733369698087055, 0.09757245139729592, 0.10636498806096854, 0.14502170045048962, 0.16257836723760252, 0.127578912633321, 0.09008592610517818, 0.11425121972757964, 0.2253537108340571, 0.14094994313293888, 0.2850395903712319, 0.09878680800958987, 0.1618573559267867, 0.22148236211749817, 0.12018759674843281, 0.2758298345631169, 0.16530176384314416, 0.0986175025783239, 0.3478364610383588, 0.24812673158462972, 0.2351139467810431, 0.04092370828373298, 0.07766964800295331, 0.18494407436059368, 0.11963491793721916, 0.2668282401657874, 0.1983389991425699, 0.21555256579191456, 0.18329640309656822, 0.13371292501688004, 0.18675745044264103, 0.12821936213801946, 0.1856057904660702, 0.13401522331180113, 0.15854241686963266, 0.12753044225035176, 0.21452108968890485, 0.19224631720252577, 0.25080420887999, 0.10077683630609706, 0.2138424890055772, 0.22958741913880074, 0.1606506142284601, 0.10417620591338604, 0.22436335833082277, 0.2151743328619388, 0.19068751213771684, 0.1464909958022256, 0.11574591855488478, 0.1650920702565101, 0.16936129439742337, 0.16883013499600275, 0.18660093867971053, 0.3088629329877515, 0.14229487177104722, 0.36037848481247503, 0.30078205370133926, 0.19895433628511047, 0.07849042694414816, 0.20491428583139376, 0.5584180355072021, 0.45324688056303614, 0.4283232518261479, 4.0794098617569095, 16.46110111667264, 35.1028831543461, 53.9521703412456, 61.9724210616081, 79.83423586814635, 96.12016785529353, 105.10216805242725, 99.45578282879245, 78.47361272381198, 75.80767185457292, 69.38474362896335, 64.76073595785326, 48.74380796186386, 42.75529399994881, 10.674273467832997, 3.986513672336456, 10.128313860585614, 17.607886445137765, 25.589739122698386, 25.61298897189479, 28.305382305575957, 40.396608075787945, 38.51411358002694, 30.7771207440284, 25.51380988090269, 15.119800548399649, 16.71910285949707, 37.64042523599441, 42.77500783243487, 53.87873180450932, 53.606899784457305, 51.36350016440115, 51.816973224762954, 43.38215151140767, 25.62473843174596, 14.224335205170417, 4.275689432697912, 1.1411629785453121, 0.7113606867290313, 0.39033659823959876, 0.3630532041913079, 0.24211989745738047, 0.31801354680811206, 0.32248357791573773, 0.15744072114748342, 0.22783362937550392, 0.22295104459889475, 0.15966885723173618, 0.137396857983643, 0.11248040749060531, 0.16843157009251658, 0.1784621125027057, 0.19254449394441422, 0.17912554464513258, 0.2184083883560473, 0.295148917263554, 0.12486631020663247, 0.18585794064546787, 0.13351469210559322, 0.2206910239352334, 0.1741162489258474, 0.09771812301609786, 0.1150173612780148, 0.11597408252137324, 0.16614266791410987, 0.1337368116383591, 0.2517026921193446, 0.13117711270047774, 0.12609329194791857, 0.12064880466148739, 0.20601330024580802, 0.16963212180041498, 0.22272800576061974, 0.14291667469566868, 0.20413993947928954, 0.22003497688039658, 0.17669393560819088, 0.10268782731145622, 0.21288553793584147, 0.19922859576200286, 0.1631142457406367, 0.19336595470386167, 0.22832743432973662, 0.19146970323016568, 0.10998233266535307, 0.12598168825910938, 0.1266706464511733, 0.12184459896337603, 0.05399322572855219, 0.1143783903230102, 0.17336277080880058, 0.3159000940861241, 0.1887147438021437, 0.1910041975638559, 0.13927061711588215, 0.07501224987208843, 0.24871755391359332, 0.08474102258802423, 0.15559881595113587, 0.3638401297071288, 0.20827534338158948, 0.1760114278764494, 0.08149592776692684], [0.015956722800770116, 0.018200130847793435, 0.03947544204551847, 0.007408993842545898, 0.015960166365989757, 0.05093349354161371, 0.017467643539871902, 0.0026228980794023244, 0.031919610694110874, 0.03867563859169041, 0.019776781930798487, 0.05812114112139229, 0.08317833345743918, 0.04401584982030815, 0.03210421490122474, 0.03589437936522788, 0.006841015297874448, 0.029454893252301603, 0.10777695705333065, 0.055253264163770986, 0.035502690100862135, 0.05286667811413927, 0.05086544195129987, 0.02836587437007937, 0.006861847622560398, 0.016503908761566686, 0.04203552785780161, 0.038310789217751835, 0.0302228466006777, 0.028644140486815767, 0.030124639874444376, 0.021230050723158547, 0.03215377887470588, 0.03269744849193, 0.02599714774518244, 0.007112880271198529, 0.08144034042714104, 0.018722855621167732, 0.0554598895682683, 0.04531222380577557, 0.007750775830279435, 0.03804254353106503, 0.02631710628197799, 0.04947313843595405, 0.04422488840176694, 0.09766512505349614, 0.025942805298273603, 0.06437454447751084, 0.020244317730107618, 0.03507917371368216, 0.03143334212983328, 0.030415012095604214, 0.08673420716677943, 0.03661977269897058, 0.03743270306938118, 0.02552948362614599, 0.045681673537699446, 0.017786569773189483, 0.002629995165813354, 0.1020736086572851, 0.03507699802397721, 0.02743074914530641, 0.01983064940319427, 0.13976387048680938, 0.007528190899099554, 0.017958056639819857, 0.01588936547763766, 0.02989654485586911, 0.054448710964812394, 0.0824181673928134, 0.03459179623713417, 0.006157126692649458, 0.04044688366834195, 0.20461168110130296, 0.2652313758529002, 0.10240446671002335, 0.0839834995267372, 0.08188928327252788, 0.527485121161707, 1.123091638568909, 0.2755593748823289, 0.19915071526362052, 0.06989309714446146, 0.03387360029944009, 0.31944358781460797, 0.3256208305397342, 0.6549262375600877, 0.2643475555364163, 0.04223588283263868, 0.1921297952292427, 0.4217444258111139, 0.22006129966147486, 0.1661999100038121, 0.18530770565473265, 0.3507152968837369, 0.1191175327966771, 0.0801427253792363, 0.4171450484183527, 0.3109515644609928, 0.12352564867826239, 0.49338817175838257, 0.5304648354649544, 0.4403702295835941, 0.26646925136446953, 0.31903688705736594, 0.3120878567138026, 0.14081040787841045, 0.1909520116544539, 0.1473808988568283, 0.034643675711366444, 0.13202002392180506, 0.18123616284180075, 0.05189012285442122, 0.058848438183626825, 0.024654103683367855, 0.09218297688470733, 0.023316682706917488, 0.07567742869498269, 0.08580678112564549, 0.014405779713284106, 0.019188468539786917, 0.026054958655168454, 0.054301388426533634, 0.03897447799963336, 0.07289742585271597, 0.031026965044739268, 0.04718820459299511, 0.024329391571002144, 0.05489838925460654, 0.03887177625250432, 0.04558693527454331, 0.013977978021777688, 0.030286565963779728, 0.04342741002478907, 0.10761033292979964, 0.0257671604894342, 0.03405076962324881, 0.04459755953341242, 0.04915962844426113, 0.03590819193050265, 0.027883610530425946, 0.03129820038955058, 0.021933884427492178, 0.010483510090008138, 0.061226666214004646, 0.007265479240055768, 0.025655773220463626, 0.04558546821616831, 0.02251371914040177, 0.0644061609261459, 0.005177145583495017, 0.037176167036617, 0.062205657633321906, 0.025128122501736207, 0.1033357768169334, 0.02749794080192524, 0.07717393548978914, 0.03211434066836392, 0.04097913857549429, 0.007399187917115108, 0.026817576201151938, 0.008958347776393977, 0.06198931823394472, 0.019118373409935066, 0.02110911799865144, 0.02873220995459105, 0.012759791927472239, 0.04902797623447353, 0.047802074677160675, 0.04064819242264475, 0.03478513001614521, 0.07170412133658124, 0.024335962690172658, 0.04590941232538993, 0.02843325754867927, 0.039761081758526065, 0.021707951692083192, 0.04135618023874779, 0.07266954533875951, 0.051040768833650704, 0.004423248990919561, 0.026801141699956312, 0.012406124564398442, 0.03902749128399357, 0.026228948714091416, 0.13452818046414083, 0.014680743991066853, 0.022498270977408658, 0.06790893708145426, 0.009334749756230703, 0.05777213827616746, 0.007661001338067675, 0.0711884369112311, 0.044319573038768385, 0.023880169103522936, 0.019889990573809035, 0.02095880197180856, 0.03976506158529271, 0.040149392575145736, 0.010483910370948575, 0.040123537107701265, 0.07293412912516825, 0.031014983429603522, 0.08392169155300626, 0.06524549451686683, 0.04083597206420476, 0.019262407515798847, 0.02137184402184381, 0.009565245502838686, 0.022599275839785417, 0.10589495481502627, 0.025437384535888993, 0.021411356921758384, 0.03296691991929566, 0.006248717770851668, 0.014906760996147512, 0.023612877196301858, 0.032642776627213724, 0.1336327922200003, 0.03043957862011608, 0.04754352383315564, 0.069360681358845, 0.03361667739227414, 0.037485815945171544, 0.02331171079628891, 0.041393722377477155, 0.03359874710440636, 0.030863870671319387, 0.0362240155077269, 0.07275859539907786, 0.06723762955516577, 0.05879406892364064, 0.05617851451519997, 0.038710874805767695, 0.05229540634900332, 0.05234162826391478, 0.03376478900111491, 0.02785051744731684, 0.04749784584067041, 0.05003347046553128, 0.07463316658451673, 0.05391274436166691, 0.02781864052878753, 0.04667883656258064, 0.05003255882090138, 0.04325953334750187, 0.034573272231125066, 0.1283487314057927, 0.09501241538072787, 0.3458712003644436, 0.7699627357144511, 0.8561850735737432, 0.8224499934623319, 1.4777778449558443, 3.805204807750641, 4.639111738051138, 2.4513673638143847, 1.2237524048935984, 0.1883083341583129, 0.4591600987459383, 0.8814017462634272, 0.15500341241638507, 0.7018987041327261, 0.5562492712370811, 0.15882407675587362, 0.2514108739072277, 0.42873586678216535, 0.2533963439805854, 0.10129380775916, 0.1497866141219293, 0.2387808266306116, 0.09502835767043215, 0.017995719437397296, 0.2092877592170431, 0.4228728120365451, 0.37656331795357895, 0.3209633223952786, 0.1012351943720733, 0.12007089857492717, 0.318285140299028, 0.345584315758559, 0.7060422592105404, 0.45359943422579, 0.3732249212841834, 0.1661085616797209, 0.16477538483037105, 0.18258361957005917, 0.08089404312833663, 0.11641524957432864, 0.03923338507452319, 0.07222100851997253, 0.11769907503959634, 0.032245759221334616, 0.02437522086585241, 0.046026229242523836, 0.044579767141371004, 0.049597455353866664, 0.020837455559822343, 0.026062211592591582, 0.05135313735433644, 0.08646017751626431, 0.01311947691119126, 0.04045277105404004, 0.03072643449770347, 0.02313611195272496, 0.04951881642843928, 0.01839778919313704, 0.043646005553103266, 0.04112745319763499, 0.022167715529400497, 0.034273027051841064, 0.030041189916852503, 0.0392964915672858, 0.08581654874668007, 0.021642029826198856, 0.11421644699669654, 0.022850700150874835, 0.030008652247488502, 0.02983694896101952, 0.02676929542494397, 0.07350706330109989, 0.08730597688906616, 0.03696748085560338, 0.05248367245639524, 0.03561969470953749, 0.014072252801739642, 0.020063300729699193, 0.055416371943729545, 0.10281225531211785, 0.009049975722577543, 0.039463674935001525, 0.057661423249350446, 0.045552606874656294, 0.06731099013479487, 0.04614742052170538, 0.06704908765612111, 0.03636964116125338, 0.03086998788339477, 0.018563045849723202, 0.06073071621358395, 0.007739877750751593, 0.0065029943230441745, 0.04980063336270471, 0.07669804933210535, 0.023710723861210772, 0.03328623302701501, 0.06766950396159965, 0.019037614336177226, 0.025918443702281486, 0.027452450500981464, 0.0429116872950427, 0.08606270045763062, 0.15907723817133135, 0.10231921644580942, 0.18027654578608854, 0.09409109506035045, 0.10873528708133007, 0.19863378977583301, 0.1278507742550104, 0.11031450072844183, 0.13942092356662597, 0.1671246087719356, 0.15840251389290058, 0.18059955909848216, 0.2129319628640529, 0.10311081509796843, 0.13434464111924171, 0.10377289126476935, 0.15968134446490198, 0.1541720844444729, 0.19675828396312653, 0.2016988003085698, 0.16499322959251944, 0.17663370577558396, 0.12093651664233017, 0.0524500526878382, 0.14548332971190253, 0.15945937814972094, 0.08242643348151639, 0.19031304836032853, 0.09500038780031667, 0.18269546840700412, 0.16613169753503415, 0.09591561006081682, 0.11631025722430599, 0.12067783939381763, 0.2233226891727217, 0.140912021780687, 0.2018190148256479, 0.11420536936531145, 0.07989717887774592, 0.15480851964844813, 0.10977964878322617, 0.12660216585162187, 0.187371822314397, 0.11389226156977877, 0.1228242722009459, 0.1615289033901307, 0.07250622305418215, 0.14762806946471815, 0.15701934214561217, 0.09710990283037386, 0.09523134798772874, 0.11374349495576275, 0.1622636429965496, 0.1651727546366953, 0.11379199598224894, 0.22320848078496996, 0.14256759907209104, 0.11802447088543447, 0.17555460964720096, 0.20171943871724993, 0.11136693699705986, 0.2629998230165051, 0.10859439585117564, 0.2190553189645852, 0.10396527126431467, 0.18114893607074217, 0.22552145344595756, 0.09415864103263426, 0.11642743803320393, 0.12437090412863802, 0.0883366332779969, 0.20080408622180262, 0.16970831690536392, 0.3772008869676821, 0.43234450862773005, 0.36473050773624455, 0.19423731843069678, 0.34690489812243375, 1.0037157119762514, 1.3576721736500341, 0.6718893853887435, 0.43577829856545697, 0.14550917751846776, 0.1730863662857202, 0.6037390003761938, 0.6831709800227996, 0.9548752778960813, 0.37528339953672507, 0.28483915112672314, 0.20383479133729013, 0.4905493257026519, 0.2814817554768055, 0.17872892560497408, 0.453517462817892, 0.38849188916144833, 0.30209902013021134, 0.27262394046110494, 0.5111965903591725, 0.4365473282673667, 0.46740274515844166, 0.730197869481579, 0.4782020108353707, 0.43644580629564106, 0.5012398068943332, 0.4096340466170542, 0.6306714648681303, 0.37483974269801573, 0.28840222606255167, 0.23513080071537729, 0.14710921343536149, 0.2989719105103324, 0.19992576641661508, 0.3151707477386921, 0.12844768698297201, 0.13781590807822444, 0.29834460707441457, 0.1131580658857861, 0.1501280441880226, 0.11826706028753713, 0.1261190171804159, 0.2806572303656609, 0.10629229397783357, 0.11708795138063932, 0.12234170575656238, 0.23673416145386236, 0.16982001252472403, 0.2207222343572686, 0.1564958895887098, 0.18349673508876757, 0.2107519371014449, 0.1257698955915628, 0.0735620454314255, 0.1331398299624843, 0.09977099350503377, 0.2288713107907003, 0.14195649073489253, 0.08664085169232662, 0.2140923868864775, 0.15259231921405564, 0.18787930959895735, 0.08468905884412029, 0.19689688459038737, 0.17828508490516295, 0.11277665369092457, 0.17326083514959584, 0.13781439122413436, 0.15315710987535217, 0.09911591172098153, 0.07363856229330264, 0.07837538352055896, 0.18282596382402605, 0.1374145392929354, 0.18295616812763676, 0.11971677443192852, 0.17280800057755363, 0.15804416860543913, 0.2282844567971845, 0.15321891784908312, 0.16787018086160385, 0.14334471866248116, 0.1572769775145477, 0.10260905049020246, 0.13023367542172634, 0.12340021710241995, 0.08527381375672356, 0.13857067322298405, 0.1263342878871387, 0.11768142437382091, 0.115142248931431, 0.16606359231856563, 0.17320340919879176, 0.18329870136034104, 0.0738732073636305, 0.0822769390839723, 0.15254042441806487, 0.21388342874425076], [0.08194046560674906, 0.011219808685352967, 0.05006037930387163, 0.030434836535864783, 0.042486929845425396, 0.03513447760093597, 0.03344554484130875, 0.08782831861847833, 0.03879158216859064, 0.02945357175063222, 0.04143968382249436, 0.020012468880703373, 0.008310306340365881, 0.009506233750031361, 0.02167822748062111, 0.017959803320287217, 0.05474025721571619, 0.07345690752469725, 0.007591871479000416, 0.036519997407712286, 0.05413612027862861, 0.03714037923923424, 0.014229954873782494, 0.010988950962200763, 0.03912233679945912, 0.05441064405585489, 0.0494846182634994, 0.038890614354562376, 0.011087819396878683, 0.02284762430785885, 0.02197925598480769, 0.04227668084504624, 0.026882770283508207, 0.009061362661962068, 0.04984272989414392, 0.07488594495601232, 0.04929489658905133, 0.014665855072258462, 0.04125648921716117, 0.0309271935839206, 0.018410008295529315, 0.05501335223896369, 0.02123962107655262, 0.03368875477463007, 0.03166824383961578, 0.021809567509579564, 0.08130537871752055, 0.013232899101210699, 0.03214446707598625, 0.03566415462222311, 0.03055550687525782, 0.04153205487396448, 0.028674749529830394, 0.07414314610462996, 0.0132793067924438, 0.019803250268582376, 0.021007304913514567, 0.02767412570275126, 0.05958049265187114, 0.04922159346601656, 0.021227806085540403, 0.052809110437069214, 0.0275628648382882, 0.03566866688009712, 0.029532848444256573, 0.022953398067564256, 0.045138049885750785, 0.049407894557882706, 0.033049098170933225, 0.08677272606761226, 0.1627932549003632, 0.040706055043565656, 0.05669871885930339, 0.06447217472258114, 0.09749112350325431, 0.11531571422012583, 0.027855064179147446, 0.020785263904760924, 0.029129010940631552, 0.026208854227837537, 0.03690718590552288, 0.03631193175791733, 0.10601343031251624, 0.1468626097325356, 0.28220920192618526, 0.1111151468789866, 0.34825878998925613, 0.23161647961505, 0.00782350582378586, 0.08338931407178603, 0.06539353334735479, 0.017922916186733112, 0.08258952593971645, 0.15936617589285298, 0.09940013800176883, 0.03838971925659045, 0.03201411721566993, 0.01977337666997506, 0.0889061047365108, 0.10321261286134682, 0.19967111879058425, 0.15223936718558112, 0.18581231244869773, 0.24188106188610678, 0.1554127638378451, 0.2132829843509582, 0.1295151462357852, 0.06496118396640786, 0.0575021114350567, 0.031082807108759884, 0.07563375402241945, 0.06531208287924528, 0.0709404159457453, 0.013390290907644218, 0.02259150004735397, 0.06268353561960882, 0.03163073042918357, 0.062080429070779396, 0.07134441241261459, 0.0411409669886193, 0.023776835333856366, 0.02009909427274139, 0.04206153271239131, 0.010505386688295874, 0.04481468034247237, 0.04807199426596204, 0.050432307330230554, 0.08835715677348838, 0.023606694866752913, 0.02958392161094854, 0.027268415114151377, 0.04687779725739553, 0.07741003612717313, 0.04822741435360044, 0.06678654932447019, 0.03632680535496723, 0.06488362522495371, 0.036445292343776074, 0.031437971216115745, 0.1487028448572082, 0.02150131671148683, 0.05001378200587727, 0.055008004945252216, 0.09976570749835623, 0.0408598548552442, 0.05841735284775496, 0.034236021174658696, 0.018956847601540146, 0.005802952275130778, 0.021170142647479812, 0.05632012586800322, 0.034246949418898553, 0.050131985542154124, 0.043723112302682096, 0.030902761124795487, 0.08877207765415793, 0.06578410795379071, 0.019213977352445646, 0.005460997917614277, 0.022080063579543945, 0.0535940824286832, 0.011656277704112714, 0.08117855286165591, 0.02260613807236716, 0.03352139137625214, 0.027431800600982485, 0.012363848959906928, 0.08314382119645035, 0.01840973058865676, 0.0726790831334168, 0.0074677192699915225, 0.07124317389342093, 0.0702025123961991, 0.02110059335527401, 0.0437655842172042, 0.005747406591375869, 0.020569110281705376, 0.048896454259633064, 0.08141098393788261, 0.05725765660885842, 0.04051395849655232, 0.030719355845283118, 0.018457919434313814, 0.05284938750968826, 0.09104603345716193, 0.04081078692369404, 0.09693978534590814, 0.0347017451760269, 0.018216770277508808, 0.0458951247856021, 0.0335876043555477, 0.03525280371128071, 0.014025208299919484, 0.004039029083815554, 0.03425639145256531, 0.019380486562788006, 0.04765868983081272, 0.031688619863181826, 0.05132255512439916, 0.023086607351057956, 0.038686111013615326, 0.07089943024179629, 0.08675298398180355, 0.10756907909507714, 0.043601514996900674, 0.04146774562316076, 0.022175569845844182, 0.04030762037502662, 0.048950976737204104, 0.01765421850817098, 0.05480767678349249, 0.026477952187340108, 0.05310380147890218, 0.03796594239951622, 0.050428737360503406, 0.07174134554882204, 0.03594815107663313, 0.017145428874139345, 0.011059497126318034, 0.02578704621672871, 0.09756497437915496, 0.09850191523230846, 0.0684379131322907, 0.042286157352669586, 0.07630221170162962, 0.015307653849313577, 0.08188891555032424, 0.07292121288276489, 0.0431298001879646, 0.07270108517860213, 0.06665244563332488, 0.041287653673920906, 0.025035956378785834, 0.007349206425715239, 0.0326543522157496, 0.010853362018092266, 0.010904696612288396, 0.08082453597096667, 0.07899518695569809, 0.054862429087440816, 0.00748155529670898, 0.05381800992895038, 0.040094146144486247, 0.01764725093849965, 0.10113328935638552, 0.13034477349250548, 0.052987555297271866, 0.13343771559096154, 0.09461033413366926, 0.06353620680109148, 0.12391210939254492, 0.018247187798542362, 0.0434875134528885, 0.02007022233409507, 0.10706833338425045, 0.03832082879999953, 0.10434610123235373, 0.11293599997917492, 0.18039748042581544, 0.046088945030445055, 0.13793618388233647, 0.13469201602762745, 0.2428214194914026, 0.21704456798972624, 0.10053181074439518, 0.14320060220216552, 0.15490662486803147, 0.03499528708597345, 0.036136398031826944, 0.09487883262937108, 0.11138509328086531, 0.028238680792011084, 0.05391462893796064, 0.005185605109398884, 0.06709166682295262, 0.11203961582073282, 0.19006316580118673, 0.0914708215502962, 0.16023291244862542, 0.04796838853508235, 0.021339172287093058, 0.04809355581059091, 0.0781554320166188, 0.0595645580230461, 0.08315883651976624, 0.04686867698065696, 0.05302268425903974, 0.03447203754237102, 0.01761139610842351, 0.07242782161601129, 0.05641126351791525, 0.03807338623089656, 0.017316195618120894, 0.09255780072342004, 0.04390728750055836, 0.07292335026807363, 0.05897675025006456, 0.034977862416135694, 0.035069386940449476, 0.009495616729010739, 0.022289619270351627, 0.04408627628318725, 0.03812597816689842, 0.041257086765742114, 0.04808715897642317, 0.00606341690253166, 0.02228394255883271, 0.03437781638856377, 0.021234867500982458, 0.08371287130660589, 0.09814549282553697, 0.05251263441037267, 0.04627970092359089, 0.016886956554146546, 0.0530138167913162, 0.11315775945061639, 0.08472278969542635, 0.04335980276547132, 0.08230036605269679, 0.08077476323852617, 0.07035375347421055, 0.031334292706883246, 0.026845205162141113, 0.021004328661928737, 0.06318543429276155, 0.05011009841015743, 0.022232091812897595, 0.10562218154870695, 0.03275272173566684, 0.05111007297772074, 0.052984617350082246, 0.013294784641343982, 0.03366741922593886, 0.02127316998197667, 0.01690101043711747, 0.014678279103170482, 0.028714160923095002, 0.052279778155348, 0.048625190186524586, 0.023227146180767207, 0.02489846657901522, 0.04690125486963699, 0.03413639527054564, 0.07527920087018321, 0.06527469012766116, 0.06458978454071669, 0.05523922943299817, 0.05484317346746403, 0.021016319853163535, 0.01541204194748594, 0.03484855826583601, 0.034964689534277685, 0.18524202127610484, 0.09459044649115494, 0.1747776432743957, 0.13001815956686774, 0.10443646896390185, 0.11857284428251368, 0.09703170823594255, 0.29904416792335053, 0.16253872984840026, 0.13413284845169515, 0.18385768507517156, 0.1557091785775077, 0.12086763001617887, 0.15676040442720537, 0.07428256644596977, 0.18066954889124442, 0.09428326055527696, 0.14999923416443411, 0.1350977515140849, 0.19223203732361718, 0.12139387113312561, 0.15056572554092254, 0.13825607155599903, 0.15172487785739286, 0.13889756294027453, 0.15770060881491632, 0.19398461666799363, 0.27988942640443004, 0.09061651094065559, 0.09649103402250236, 0.07389655772356257, 0.11359901843412269, 0.14907004612107433, 0.10278751833304282, 0.12634325877673205, 0.1776379091484893, 0.2107803896069527, 0.21379600279033187, 0.15312548576583787, 0.14838127179011223, 0.21313836227261254, 0.16537828070502128, 0.13957351295938417, 0.14529758403378149, 0.18768286933341335, 0.17766317472823207, 0.18622877316609507, 0.18926548441090893, 0.17800518702114784, 0.1327235224626718, 0.16825794392535764, 0.1374368937385659, 0.13984142922826354, 0.17489707638179103, 0.13438682192035262, 0.14582414690765644, 0.12527700228195998, 0.13464001397932732, 0.09770676193218078, 0.09729695085796619, 0.17838663752040557, 0.1581358693299755, 0.18393866056876798, 0.1493324159133819, 0.13759806331607605, 0.15979751403773987, 0.1156136075094823, 0.15500503652278455, 0.12844588667634996, 0.22332567691562638, 0.17683022264992038, 0.19655105717960866, 0.14807727277999924, 0.16604715207171056, 0.28167695467991216, 0.23483205706842486, 0.1535127891768371, 0.11635619185624585, 0.19208577581711356, 0.1524505469827883, 0.1581151083472275, 0.29344648603470097, 0.3600422641442668, 0.25390231441105565, 0.4247377151923795, 0.3660015701766937, 0.36124241748644464, 0.25957672766620116, 0.15338094544506845, 0.23843671525678328, 0.20526045032085913, 0.09191173579423659, 0.12642781956181412, 0.2547404452437355, 0.17867909924637887, 0.16427261664742426, 0.21499911323189738, 0.10818103778987162, 0.2892917460731922, 0.18643632170654115, 0.37196351155158014, 0.3174474997626197, 0.40217608874363286, 0.20481339205176602, 0.16940295425874574, 0.30514293260151343, 0.21733404197279485, 0.14468990777048374, 0.1322499575513986, 0.08962118652679267, 0.21499816328287127, 0.1454741979438451, 0.17664236256912833, 0.17758036062361734, 0.1506439431179916, 0.17972320047838075, 0.14231437636959937, 0.3624054308860533, 0.16401599251454876, 0.11480251191965035, 0.14042912591849604, 0.12439039340543172, 0.267316268817071, 0.09128755033617059, 0.11581162591615032, 0.15076758970897045, 0.1245179087404282, 0.15369508745929888, 0.22142318948622675, 0.066604680051246, 0.11017815239967839, 0.13410442658970434, 0.198613565054632, 0.15137307496080477, 0.12012104669045057, 0.14793277327572146, 0.12677822817838, 0.08487550932313166, 0.23377096400626246, 0.36334667715334124, 0.179163420032109, 0.15023436187015426, 0.21030325472595232, 0.1834308974925549, 0.1551145258089227, 0.16814188160482915, 0.1997238562832917, 0.06393613917152248, 0.1999796990064844, 0.10025739804991793, 0.1904720728916507, 0.1940561846018799, 0.18577227669377483, 0.12845215327557058, 0.14669540338218212, 0.15554794771296365, 0.12182174656059473, 0.049821367532375364, 0.07563933880338747, 0.10350921912299049, 0.10641667601321975, 0.26831950691919176, 0.12948125450601503, 0.10848429369469804, 0.1308242985678296, 0.09512866922323743, 0.13030403293669224, 0.13714521342227537, 0.17715171910822394, 0.15275125181482685, 0.10788416339745445, 0.1477032073683316, 0.11579472601654069, 0.13944459568348624, 0.07601331994538346, 0.10748941361183122], [0.02646744146101898, 0.04161213404468952, 0.017705469790305343, 0.006865135576170419, 0.015055844579042207, 0.043757877372685945, 0.025350345456371867, 0.05163600765949777, 0.03116498727561726, 0.03339408671543483, 0.05062359948492339, 0.03143755369819701, 0.03081829610070394, 0.025701792122075157, 0.023259720239307613, 0.04254653914681366, 0.03113090402386602, 0.04645680512992605, 0.05688427684588298, 0.03366834619232724, 0.014746136298673529, 0.04665142976708951, 0.05965877917685336, 0.012951611725222922, 0.05816628285233052, 0.05370408882417026, 0.022944764256657615, 0.04654258782524736, 0.019394574919715524, 0.01035065895261904, 0.0533179460363763, 0.06755250701380354, 0.04354418863752677, 0.03357243964508657, 0.10505945166392673, 0.030260024847643032, 0.02569647547188065, 0.04529217911523677, 0.03506764792086136, 0.040676288697267735, 0.02630965033125493, 0.05279922024196675, 0.020591755840747107, 0.050392397979815165, 0.02587010738469901, 0.03375818532320761, 0.03507249725742206, 0.12761324869408724, 0.03516416350800184, 0.018168301809759393, 0.031593638367109725, 0.02492108149453998, 0.03346367048159723, 0.03380091004674474, 0.012882020298181283, 0.050737708281244964, 0.06339600888050853, 0.043364349497301925, 0.02171586921078063, 0.05432606794901433, 0.08325956176005064, 0.023014438038151112, 0.024000872001652757, 0.08482822637644508, 0.024002340975247567, 0.01864052415194531, 0.03691901813351339, 0.03681781408827632, 0.05348926244844353, 0.049215843976144834, 0.028445269807331988, 0.10352555211753615, 0.011697341932073958, 0.043667141918934164, 0.11920914925154179, 0.02711823123747543, 0.028188599709181056, 0.057655436272222194, 0.06779551776426454, 0.07360341417933665, 0.08447853022164876, 0.060312141093515584, 0.08852201123391429, 0.08998025193690293, 0.10085973468038345, 0.03117848191440346, 0.27002475735160614, 0.13665094881528808, 0.029854802640094876, 0.08861828550335862, 0.07082614627095961, 0.055675102818396785, 0.05749924626621989, 0.07526377952026744, 0.16285166144371033, 0.021233274038099957, 0.030509384551776514, 0.013751949525378166, 0.11484814777729974, 0.024567215906215772, 0.1147153617573842, 0.1861158824495731, 0.0880948789117317, 0.048137602035797415, 0.0763069308032432, 0.11873176922240566, 0.05084915109159005, 0.07138966522630184, 0.044233365164649104, 0.04384212789215869, 0.060380066279321916, 0.02522746112287766, 0.02692929671836957, 0.012926461058668794, 0.051969949216131246, 0.05617385670062035, 0.04383767692131862, 0.01285461541790996, 0.10122417802772216, 0.047490560344510505, 0.058449727723435055, 0.017195437178616563, 0.03515516963577078, 0.022923670025662552, 0.015641979407519102, 0.019037106802927393, 0.024379679497571725, 0.0374042505638734, 0.011661027449243253, 0.06697356670854554, 0.0624003780314759, 0.062147756708004785, 0.038129475358272755, 0.05092247336682293, 0.02857304752744254, 0.06774166178318762, 0.0427627636330022, 0.05352036178772969, 0.027693762451470382, 0.06010003816035967, 0.027639232313020096, 0.07486895312585178, 0.022298578668626088, 0.035052594293149254, 0.026208718247230978, 0.07823042436352662, 0.038131467186875885, 0.02761649099298783, 0.032207343742371566, 0.02201684025837289, 0.04838882907924633, 0.025094698085599852, 0.03578204023201139, 0.0969562792189179, 0.029655269294556592, 0.03735370025218975, 0.02080951441800402, 0.003878031157880962, 0.025729601113726536, 0.022071157807424184, 0.044605220412655223, 0.07364076096564531, 0.059474086869628205, 0.01405184421943681, 0.05748762471240856, 0.03809908848075617, 0.006628636094260842, 0.03194695237212845, 0.04930741446573408, 0.06549042048713853, 0.02275385514592692, 0.030086322071691676, 0.042299690295852004, 0.013114351782977823, 0.07024468553643073, 0.05759346742002715, 0.06390482915805713, 0.03678205310397091, 0.028052006232281847, 0.01310082458545484, 0.04676019126969961, 0.041497508139019056, 0.015458761819548186, 0.05017122839607539, 0.04281610633516985, 0.025587009168380213, 0.04421984754322518, 0.033175410747888594, 0.03223026126262642, 0.08889812976121904, 0.030499279852055257, 0.04366626091782124, 0.06931804090497956, 0.09233774962804972, 0.01642472974415268, 0.023257213216575406, 0.042158281956348694, 0.05905150510971585, 0.04239653530079992, 0.0676268635077342, 0.021804622412028334, 0.04109220166179923, 0.056991146111320105, 0.05266806215889031, 0.07222545182993335, 0.05023248478650086, 0.016917601986337575, 0.004131002248369999, 0.00952824345609594, 0.03191525931470096, 0.07485473453397713, 0.040806527474835035, 0.07175589355850412, 0.00596532556829193, 0.06918959860359469, 0.027485537838431138, 0.010719935357150052, 0.029459665980069872, 0.044600543445877494, 0.0246752132361214, 0.012681563816694243, 0.02993681809804853, 0.039415258178186995, 0.06984620490261624, 0.012469098906994108, 0.01324522162547275, 0.038304392383584095, 0.017531968112434113, 0.019849544961846644, 0.03948127197462224, 0.013004743753211393, 0.004953107000478814, 0.09036717996481927, 0.05825171697764628, 0.0541719310586491, 0.033141201091629845, 0.0396979101482899, 0.04973125260984225, 0.01959253586978922, 0.06573397516002578, 0.027268445757668347, 0.08615111466497184, 0.04611295422599201, 0.07322052343478126, 0.08724629097888548, 0.03784965408305007, 0.046201628903227474, 0.0900199965784146, 0.07396229572834508, 0.07632836594336456, 0.03239493952282975, 0.04109354231566672, 0.12046295173105695, 0.07543730609599622, 0.029409969856421796, 0.06789150092029764, 0.027646469928684737, 0.023407856746005918, 0.06045751393802705, 0.06503570133880263, 0.06603759878705587, 0.18153660720394504, 0.2515730087555224, 0.12080972909086174, 0.07536696390278878, 0.1743789098315662, 0.13527998850951273, 0.08512926828717032, 0.033713154675018404, 0.06442951128607796, 0.06124596779925689, 0.04412985902519957, 0.06068859286906739, 0.06727758870129624, 0.035718412799460274, 0.05786963445585101, 0.1625908697925268, 0.1224167364078664, 0.10398281467778069, 0.09067029031294008, 0.02213806409629122, 0.04456901126691411, 0.08631963868655505, 0.05687159426029652, 0.05780889134433481, 0.03398483243560599, 0.012970474725138518, 0.059390889721051346, 0.03519635835301972, 0.035640382913932685, 0.0424012927068097, 0.03883428007905041, 0.04673026404493759, 0.0311067569324927, 0.05385151861475841, 0.011791560213051498, 0.05649251863360406, 0.0846803637461797, 0.023300960667491443, 0.05346864319196152, 0.026160900954217203, 0.0220772271390043, 0.019057306626270858, 0.0436056365499333, 0.05110298283398152, 0.07011664926164574, 0.030546771557701212, 0.03339773712439403, 0.01333891705144197, 0.05969252534991792, 0.07342650149498256, 0.06859444787785893, 0.02580346539616585, 0.052153492391469984, 0.028525366215035323, 0.02570171551328273, 0.018515100236982107, 0.04414736413426938, 0.020828835155454375, 0.03761770947265529, 0.0417521404432914, 0.04678958989379387, 0.016694007734317454, 0.021972144773650556, 0.050933279036994905, 0.01180863631288371, 0.0360399054273242, 0.042638366275857535, 0.11560800740675581, 0.024842076762128743, 0.030895849096498666, 0.08327351988203104, 0.011454519830764303, 0.08016812119392619, 0.057882006775828145, 0.032372987273359494, 0.023827778265601205, 0.006814642721081093, 0.03694835164013409, 0.04555392454588606, 0.06103051323143225, 0.0055465531805830625, 0.026578596988392454, 0.04233450516157093, 0.024557224204463345, 0.10492936993438391, 0.025040891900238012, 0.006215322083012472, 0.06981534688102622, 0.023666574214134487, 0.022049521569222696, 0.04239316451393309, 0.14384054608883398, 0.13910960075595688, 0.09532202981532582, 0.09183897276318843, 0.07551426728886944, 0.10482004152670985, 0.1184986103626509, 0.10916900775966146, 0.11504357680678369, 0.09329056382299432, 0.1960260264815823, 0.12625771739910688, 0.09973793681110106, 0.12914762321499088, 0.12106720358133317, 0.1350485686693461, 0.1679199612549236, 0.15311710476394624, 0.09189845182962957, 0.17598533492174842, 0.12480205841242306, 0.14220559188435156, 0.16696045145152077, 0.1575104657921099, 0.12483523001954441, 0.13682552493147312, 0.1467394994031037, 0.18230738358632212, 0.20240156340502924, 0.09896041119411107, 0.1436479975499453, 0.20987905652051975, 0.11055126020144071, 0.08064700275539391, 0.21319721314695575, 0.1448283398584012, 0.15986952630262222, 0.1457817056366513, 0.16795737698914545, 0.1567834789954847, 0.101142612646424, 0.1085085173948638, 0.14361966761850542, 0.20184394332670397, 0.052015883848071105, 0.11112193441799573, 0.2387888245885411, 0.14011080106419904, 0.0959228189481843, 0.0655936814784523, 0.11182221538958051, 0.08949330346959253, 0.06107664704623242, 0.1014265861181963, 0.14044576534821143, 0.18272811907433695, 0.15767089992521272, 0.18266772070238668, 0.1766333380533803, 0.1663076372877244, 0.2756642982844384, 0.1667208804358398, 0.13776732278206658, 0.21919848547587473, 0.16547853097079263, 0.09866984936618999, 0.19228040811515626, 0.13112065202045825, 0.171259522377964, 0.21301736634585167, 0.11736935845786527, 0.1772982410846218, 0.08598588482146302, 0.34774449984392813, 0.2943142797918089, 0.11485233061736631, 0.22959823630029158, 0.15749659960068044, 0.19206139889936294, 0.0973960673136096, 0.13691408469551994, 0.4021163951725729, 0.3131432500818084, 0.2479958837671626, 0.38854906996411664, 0.3137410131673659, 0.4060590207096069, 0.22055980839556266, 0.19849702775959047, 0.14775386110188501, 0.24913583792025046, 0.24671262520695889, 0.13832472835577306, 0.24591799284661972, 0.2155690213605281, 0.26398997633687915, 0.1629730863797088, 0.1885949736160617, 0.277494941988299, 0.2827568015744609, 0.23007397690126974, 0.40191135940051853, 0.2703750740376211, 0.18718550973121198, 0.23946420770258675, 0.18846594908785438, 0.2568460225818619, 0.2702286286700157, 0.10235994934074341, 0.17671440547752768, 0.14202523946521745, 0.18965546912964315, 0.09331114094464049, 0.13724716440323861, 0.18202042237164515, 0.15676032781841295, 0.11310723595201008, 0.13725477931720598, 0.2735939609908289, 0.09096123518482332, 0.161565292566534, 0.2278575006752245, 0.14695135335768425, 0.11923799246189096, 0.20220503120893435, 0.1442246472523097, 0.14693630739085137, 0.11727047182859913, 0.09608005849464286, 0.22158127939028127, 0.16685555869292829, 0.21714474164670516, 0.15978450586478557, 0.19017271637435884, 0.1775651920827166, 0.1308534711959862, 0.11466515235482685, 0.17330790359166362, 0.08472349449631669, 0.13729058626678683, 0.16673456276616744, 0.15120453561746305, 0.10685778944002045, 0.13338615787365746, 0.09403015276597393, 0.15505224286067873, 0.17239533965626072, 0.16778584990289905, 0.1428393764241088, 0.10185364183158645, 0.15792657410906208, 0.07673047783394014, 0.13332335398562495, 0.14894396337049623, 0.06679230264478153, 0.1939087126764559, 0.08218305500885172, 0.20929865298732636, 0.1454467260308804, 0.3253192370457034, 0.12367786268793768, 0.14692035744026785, 0.22507943603540623, 0.18165029465190827, 0.2501889943115173, 0.14118557645668908, 0.08445726362087073, 0.15614353510881626, 0.18175691876920963, 0.17593091203560754, 0.11486228976038196, 0.07503085048688997, 0.18515932974555802, 0.09493735408590687, 0.1843178894130453, 0.13296510062871442], [0.05880037382725747, 0.0539650030494217, 0.0036262376881730294, 0.029172718171931566, 0.021809816488154957, 0.0487351889211324, 0.013556491767597056, 0.030400678590540926, 0.02273585782536576, 0.06901762718635221, 0.03583448661130763, 0.06782498150583237, 0.027085570994043545, 0.02171928979336254, 0.032609114723820845, 0.01382445591697169, 0.03995996584454852, 0.03682423007464217, 0.014046659719409242, 0.08539677852944982, 0.00925370148428145, 0.04979925823488063, 0.019932223085854805, 0.07283034719406598, 0.018001687262327443, 0.0335242833581663, 0.045452777957243305, 0.009198479951479504, 0.08633788690091142, 0.050054005452341614, 0.033394010106642405, 0.009764719476562836, 0.04530113851351123, 0.028820846327430302, 0.06079932321764289, 0.017633149175033454, 0.035250666325971965, 0.050430671732512214, 0.05663617544116513, 0.04354828720792167, 0.12257887891704038, 0.02111739174823367, 0.03732015326198551, 0.01596904436742226, 0.06408164608142068, 0.017556341199745095, 0.053974912396722266, 0.05279546258069816, 0.01271362076588576, 0.05871733372670509, 0.061578656802134174, 0.04127329718621989, 0.01209011042280303, 0.01876898752074809, 0.08533625758343166, 0.021582177291894634, 0.03785042017097435, 0.04017229860408172, 0.048958430772707354, 0.023373187436992605, 0.06573112531294746, 0.03608507780177939, 0.04242753504865593, 0.01839387639906378, 0.039189384814592144, 0.030657919424195445, 0.06205290736209962, 0.04077186582670097, 0.03670228036841558, 0.009904849406842504, 0.05745475187957768, 0.07485207620887988, 0.025927209663355065, 0.028426142507082516, 0.060469020578649745, 0.06785284412363846, 0.07406939482015949, 0.08066525096975027, 0.010688296883487174, 0.043580156465571736, 0.10300052141950977, 0.03225478756752226, 0.06863418485849135, 0.01759350412495194, 0.09052159264683725, 0.016360937602697842, 0.1569882236541279, 0.05485436601203777, 0.016664453977418524, 0.16760365887274667, 0.02470825460829562, 0.035355141566645716, 0.02796936449745009, 0.034697853449371555, 0.07121069942631068, 0.018785207517324917, 0.037160829956372904, 0.06856816340117686, 0.06993605169437586, 0.013284927962588207, 0.055420504988081036, 0.13377062675933685, 0.02292989449004733, 0.09331623542933695, 0.1607789186340186, 0.11515681992375082, 0.0339038492811303, 0.10812111439243441, 0.04763768753036857, 0.06708958306379857, 0.02225452861297996, 0.040841939889134905, 0.044584704578043, 0.009914708000818088, 0.030297545918954477, 0.030760232381702914, 0.03457805261977258, 0.07396830951855068, 0.04520684458135117, 0.04027478201615234, 0.051818026319867184, 0.00915281823836267, 0.038753848507880204, 0.06409312207852641, 0.04398068255414406, 0.09389336776709366, 0.014166348508649297, 0.0517648559874825, 0.05161949846472952, 0.07071815851715303, 0.012671391126669705, 0.049818069523861336, 0.02863944436783993, 0.053625863586221977, 0.024317614884386142, 0.045385028971659566, 0.005367200506190139, 0.02314608258705947, 0.032781744976678205, 0.038996629431963935, 0.09284265519630525, 0.03350127390736053, 0.038349798414856195, 0.018861159389357895, 0.028145499602561037, 0.060707097722878384, 0.04239385016262532, 0.010345918783587555, 0.025602756105663798, 0.03034332733330948, 0.03641985822468996, 0.04877515189770249, 0.07124744100315918, 0.03672270044203728, 0.08854805056246058, 0.04743300798919894, 0.03891319096569092, 0.12440513293709486, 0.02651507489293093, 0.0068997531742488434, 0.04731708356449681, 0.020064315796198866, 0.062081658641897866, 0.06328365825597318, 0.040652815763267784, 0.10365436980200392, 0.029957784009316278, 0.0627099120268418, 0.054134503833108374, 0.01577294022295504, 0.04592486048838304, 0.028921268962984605, 0.05070999505058412, 0.05199279395803329, 0.008468110876668607, 0.03649493484126945, 0.09209900598732695, 0.013480331136604712, 0.049334836582983696, 0.06171789328237215, 0.07174992573357399, 0.0373467288520788, 0.06815816080498119, 0.03184692427185515, 0.03857420855051568, 0.017807279045002598, 0.04080060178474073, 0.007437801621328559, 0.009751536060995873, 0.035762106624221614, 0.03096163881221606, 0.09311331405995354, 0.053124313483074795, 0.008678901884254188, 0.020069908238046115, 0.014082098946786456, 0.05174011134752824, 0.017228072524190913, 0.053562213171033136, 0.026184235992390784, 0.0363745134804518, 0.05151067184464586, 0.05119218228144511, 0.051496300035186356, 0.04373520117012724, 0.04561100958756382, 0.06978799754212942, 0.03236836393273646, 0.04148185313228638, 0.10423202307954912, 0.0378256410570635, 0.010315069380486685, 0.008727871181984103, 0.019914315780624747, 0.03647456456336283, 0.02815981587064603, 0.051468299521553906, 0.04494791835426323, 0.02321575828377278, 0.03165690956877605, 0.06572879640565765, 0.03320389772735296, 0.037844479159121557, 0.04862328645803275, 0.08545457220245754, 0.1163484313855729, 0.07644799823362021, 0.018635431582468654, 0.017968676533670198, 0.04745397198524687, 0.08419068034497962, 0.04783401671316355, 0.04332131067771585, 0.03766850493247471, 0.13707048920614107, 0.028300666881184426, 0.04573704254242682, 0.12749661946849478, 0.029820596814275752, 0.03515272198485271, 0.10850317010115232, 0.039918026361133785, 0.04872390827644737, 0.07128347777911732, 0.04338343657793538, 0.046651119501480175, 0.030821959916201812, 0.00631813970094006, 0.002304854762417475, 0.02409967053080759, 0.07615903752946085, 0.03460816753607604, 0.049891253903267846, 0.10107018669406254, 0.046372975958811666, 0.056212436888487115, 0.13138152028043426, 0.007919346774748016, 0.09381214712536144, 0.021127845017960476, 0.037774117813716014, 0.07717863160876498, 0.15837412267442674, 0.07400370278065244, 0.044117938697097764, 0.15045125668327655, 0.04747956315235746, 0.05400581638358774, 0.061475966546324, 0.0293082601931547, 0.06125013148712535, 0.018849857677254948, 0.06679107690410269, 0.06917053067515935, 0.036738646562181176, 0.10131871327757837, 0.021665217392447016, 0.11608803043923072, 0.05869892080344501, 0.024426560248098066, 0.06467774675618257, 0.04382239729766885, 0.008972855566460039, 0.06879913124946818, 0.029095854655268694, 0.033826313522313876, 0.04360663246423487, 0.07120090116175913, 0.08104048083506285, 0.018779412062177737, 0.04574040566841441, 0.053559658267805656, 0.03422672852813717, 0.05988078762687022, 0.04533249066181241, 0.06956390150251889, 0.03504489127907061, 0.03243950668782477, 0.04067881678741786, 0.07332652702086395, 0.03430857353152768, 0.033353120163683934, 0.0217071836889391, 0.03121338296501387, 0.05605872517691986, 0.04486546431097292, 0.04207968133531752, 0.06899907253682613, 0.026709555888608582, 0.11989731071216446, 0.03053447201607689, 0.027504783882308873, 0.024809157964022412, 0.025415334610208392, 0.04378943636472668, 0.02868580609379757, 0.050208130851387985, 0.010343859922291051, 0.00816666772739301, 0.08028445164522818, 0.043856430753705, 0.0793260373475571, 0.01578405998917597, 0.03030989525629388, 0.046158980788482774, 0.024780983165387186, 0.03191874501475644, 0.028001704899173592, 0.04763133283103666, 0.03379732092481948, 0.022260383439941273, 0.004625273558626613, 0.07638088127057399, 0.09300460618349815, 0.05749173860456194, 0.04953860447952344, 0.02212954519857322, 0.024424723552299604, 0.09649563055004805, 0.045373281013340726, 0.10208408107921, 0.0602428637625229, 0.04159360237780117, 0.06235854580037056, 0.035904338508243525, 0.00659597872365867, 0.05636043741457886, 0.09272335232385705, 0.10185511272040107, 0.014231929465407326, 0.044722834061230385, 0.04493958331764706, 0.2562534382506724, 0.09260257090171499, 0.13396516712682863, 0.14790309502953483, 0.23293304767820144, 0.18019848142660436, 0.12179452745664505, 0.08842043563603394, 0.12503324842621244, 0.18320310890914934, 0.09737740541177412, 0.14470493841555812, 0.0794183892468291, 0.18695848723573072, 0.1467815729519052, 0.14803886113147582, 0.1160256555604358, 0.15518857586768367, 0.0703235542882354, 0.10460631831759408, 0.11544977194599568, 0.1280629652882776, 0.14264583197091857, 0.14426365644941408, 0.16892436381068923, 0.132774451987878, 0.175703092808685, 0.2895835336417921, 0.17980252122206075, 0.16326314258959987, 0.10475894601474847, 0.13806913078071612, 0.14139024450653984, 0.09051809162502328, 0.13171384922198712, 0.12273241059794543, 0.06247089259446629, 0.15379958185217074, 0.24207209357090537, 0.10073833272702272, 0.184849493145462, 0.13600660758393426, 0.12114024240403407, 0.09639344974270753, 0.21628542082203975, 0.1616067379232376, 0.12047938431703276, 0.13697518786836055, 0.18742751690649218, 0.17506448191500482, 0.16025355085730553, 0.12950376216923037, 0.05791081551222071, 0.137022654676149, 0.16833389388217082, 0.15071154271643009, 0.16800613082464666, 0.12273760467407205, 0.3276693190057432, 0.2186527397603758, 0.11306321653988093, 0.2449367874332013, 0.14109382976687726, 0.17226849081775836, 0.19559770672311708, 0.12384354452332183, 0.1971383248606036, 0.16860677440079952, 0.13143825675210646, 0.14785783455496834, 0.14712960669590583, 0.17297327638633792, 0.1147436763670656, 0.14508061261186678, 0.21368882708972503, 0.15801574674344834, 0.15927332603643019, 0.16404130405956702, 0.09628258149830565, 0.16668826041202392, 0.2511076563067975, 0.056218282139349374, 0.21524064543266452, 0.15507519485489016, 0.2046064257381424, 0.18695346169894744, 0.2746644922562184, 0.2102996541127082, 0.15919187556832068, 0.19702284476689755, 0.17891419630858207, 0.19091542329519026, 0.2247271428425466, 0.11728498919476425, 0.316667836760321, 0.15654550144268622, 0.12703912708187295, 0.20247311601715706, 0.1832931242402523, 0.1905221750418986, 0.1151077596530799, 0.2187475967671602, 0.17755275081482627, 0.17420935925216446, 0.2839469038430722, 0.23341447265157778, 0.09242462399866312, 0.2591335611237634, 0.11022635465187412, 0.12051514530133818, 0.12123111575361221, 0.17298086065678828, 0.11628866886659978, 0.17044572249775933, 0.19628536256570972, 0.11175327513727451, 0.17370055429637435, 0.1570406087463902, 0.1617364059653013, 0.21855840369337992, 0.21381461872689186, 0.2360203207260178, 0.09167729756764828, 0.17369327646109367, 0.1401448919768295, 0.24339630719154115, 0.12390460173088698, 0.1317382567832547, 0.2506623447181717, 0.21063012912148432, 0.15837945464637973, 0.1088229888269017, 0.1165277649077677, 0.36805937427186197, 0.23603432481327366, 0.09335565065304119, 0.09369938664378659, 0.1052905880515614, 0.09416342142128176, 0.20642660468095736, 0.21165823443762719, 0.14718497953107282, 0.11132843341798553, 0.2018151843860265, 0.14217110260600044, 0.2153254054006069, 0.08496825192724505, 0.13167847128164384, 0.15508149209762775, 0.08057234748717278, 0.1400356631605856, 0.23725916150837179, 0.21235557363158275, 0.17000074798782028, 0.179283726479738, 0.13289129571808925, 0.14010916163604106, 0.2697856459886797, 0.15460627243643807, 0.20714327993412174, 0.2079175803209505, 0.08182547580931457, 0.1942456994325884, 0.18400223054472478, 0.1797688286751509, 0.1882579715381707, 0.13138234765539247, 0.17813804198897656, 0.15393168605383367, 0.09043009876604043, 0.18288507516826355, 0.14409399861770292, 0.17680910926672722, 0.13075581030739894, 0.15549236037317785, 0.13054751100078707], [0.10529652523297457, 0.04723723805058868, 0.02942689656910877, 0.029566824443698413, 0.018199579264487953, 0.012067916855636624, 0.05857595220027913, 0.029178314444218433, 0.041448781116595196, 0.05210951128373704, 0.0641504101335041, 0.04931818183150984, 0.014062526357930996, 0.07167540070029997, 0.0063184169290076584, 0.020672867314950116, 0.1058605804498638, 0.020086852187711387, 0.02781885694862614, 0.03198033848386859, 0.05086502443338114, 0.018807132953717824, 0.023009437399225372, 0.04190986262514226, 0.0862357980241218, 0.09165222350988658, 0.067336929871911, 0.023416894668292616, 0.027697267303723964, 0.042018938223801316, 0.013837568469405656, 0.040986389597697605, 0.05284172663044545, 0.03517389665507982, 0.049513675978467356, 0.01716030247118925, 0.06381090677854034, 0.033241252174540874, 0.05062466817757776, 0.01853419306327499, 0.05895588584544678, 0.08768357396606477, 0.015587798796684272, 0.02394288489144416, 0.08764550705710727, 0.015980797113790628, 0.0203779177184427, 0.06750093397474097, 0.059543149696002086, 0.050951573216626724, 0.038362097956480525, 0.08026765899792795, 0.01420901960603172, 0.02072390409246568, 0.03864675324650542, 0.034132848283456224, 0.08290746008917209, 0.0244289466119822, 0.02089502515211221, 0.02865782856280285, 0.020172751711441145, 0.06736941966077975, 0.03375111050122688, 0.07526064622065715, 0.050213125744654294, 0.022065174660735556, 0.03987100388434145, 0.051897592211682955, 0.030635969089945, 0.09443751235883083, 0.11517328315324361, 0.0473087944931561, 0.047971663560958645, 0.03626942153899901, 0.062223974795591455, 0.01646777430939819, 0.029582734174665906, 0.0276065701543684, 0.04812493860240906, 0.05233803531154991, 0.02541714066248988, 0.032257422909981785, 0.041825899388641126, 0.09100720046028014, 0.022598653393346938, 0.025560544661035942, 0.08545759058887921, 0.013141797840475075, 0.029929787326123447, 0.05908826583876245, 0.0845389209327198, 0.01683318867318092, 0.10759045294816456, 0.03866114803860265, 0.09051230766119496, 0.061329831444327874, 0.007259014894389698, 0.05892290959074613, 0.03801471155677592, 0.03210010483951098, 0.12862936473421513, 0.07073634544447546, 0.15371054711361087, 0.05368935695338634, 0.05960946609716743, 0.012289028982782077, 0.06080987990923947, 0.09068938122401315, 0.09448880194536141, 0.015151140171163266, 0.02256411240406094, 0.054210687446738445, 0.0703549255887347, 0.0440766197449017, 0.016539715711147557, 0.025862590146942005, 0.0374440181880228, 0.030520579011570063, 0.017560169724146688, 0.021776198634817716, 0.008070471024351015, 0.02133530545829525, 0.025134260781229507, 0.03756501028434404, 0.03039267680217182, 0.03491648728208196, 0.04087163345708002, 0.03121181248476909, 0.0312295320984577, 0.10329122114325724, 0.024976304942561735, 0.06862602602209776, 0.03186151250115326, 0.07128520147694696, 0.04590683826996435, 0.028573857665422465, 0.021197241092581424, 0.05082574327506366, 0.04095942713320255, 0.04340162733569742, 0.02229500869889894, 0.024550656915732452, 0.03868461714216298, 0.07590720910699138, 0.019440245251321507, 0.06018003689185266, 0.021329314650727377, 0.0525793070424228, 0.026497776627600677, 0.06297369142093005, 0.012690224440678233, 0.031090287957340482, 0.06000694698624073, 0.02214808644156062, 0.06684216730777295, 0.034772891761554826, 0.017492610345324202, 0.023321478417323484, 0.002409536128623351, 0.007159750966820867, 0.07634346553635213, 0.024019058928975177, 0.01641392790442032, 0.03598287784224076, 0.033602723100733374, 0.03571200830441329, 0.022231130372552622, 0.05033708643168212, 0.026856512619903492, 0.042337305212934176, 0.05454020867604883, 0.04460592521354557, 0.06694140633748424, 0.015489022292557265, 0.046419600069883375, 0.0604024896728656, 0.030501654724620526, 0.02961762373395745, 0.029778015732224432, 0.01694856534501718, 0.050434345124109145, 0.04806368604242321, 0.04049656447023153, 0.053270693733206684, 0.05193160268508139, 0.05867868459092514, 0.024823600636614908, 0.041986846800653205, 0.07418605468926892, 0.06330106760405245, 0.040728792533158295, 0.02502790862514127, 0.04226981669724469, 0.029630857902849396, 0.12303074055741872, 0.03975689125758025, 0.08762200347959034, 0.01825865038910941, 0.020533981319937496, 0.03041177345890432, 0.088850517396725, 0.06319891744022889, 0.020973156544289762, 0.026691976085966154, 0.025255229894913016, 0.05124392385985102, 0.010987315364482423, 0.0534104205097162, 0.054682995973815846, 0.055692470031640226, 0.016693459981451594, 0.036028287703952486, 0.03014557131175553, 0.03816115692438137, 0.08476953638056595, 0.02792333793495932, 0.05951624085766174, 0.07468854708056297, 0.018064180884750623, 0.07823426246402726, 0.0430842524304265, 0.06962397045666172, 0.04392763479582725, 0.029085993188463395, 0.027880672583236333, 0.03158196127192388, 0.08696775673137558, 0.04845259440762382, 0.10798076708470622, 0.0642420610623254, 0.018167551043593598, 0.07184994617296804, 0.04660765933353574, 0.029397808210623842, 0.04192436083910927, 0.01758061278040611, 0.017934717771206653, 0.062204186744507284, 0.03420767592146032, 0.06725014743184851, 0.026928733643745224, 0.04621438043672712, 0.07810789626091719, 0.032440560058720654, 0.04483038897535974, 0.09074744302779437, 0.15010268667772894, 0.053234622483291937, 0.031876809361781326, 0.018315047866875128, 0.05568445292151263, 0.07184782410941778, 0.008184386383471711, 0.05369086231615755, 0.05367719913802801, 0.04505616274752444, 0.04907283068244015, 0.017934045529053096, 0.06055419423407125, 0.02993814917581697, 0.05792512220420665, 0.13878715434862723, 0.08711935787071144, 0.0146716964926811, 0.054971887730062015, 0.05891061771000105, 0.04553363470721149, 0.03740345383243215, 0.09335270887541194, 0.037338895603053035, 0.032419201527391715, 0.01663186459711963, 0.04240659786568534, 0.10289894582162942, 0.03229114993084823, 0.05866129439504397, 0.03255521660790809, 0.03104562503135493, 0.05728994721486684, 0.05717375848983085, 0.06598272390903966, 0.05710517829884926, 0.07335484163054536, 0.039083530615654685, 0.11636102587104806, 0.03004219349203331, 0.0277542948888074, 0.020924379726150827, 0.003959482823002843, 0.07535908851892718, 0.03885310285934999, 0.03494556797968765, 0.07515641995855878, 0.04822668657007237, 0.012214503949508073, 0.046194148054646875, 0.06271185022929023, 0.01375330358578433, 0.01962717070484594, 0.0952722877264023, 0.04088011788084142, 0.02314644264838388, 0.04654942515997156, 0.034426179519223596, 0.06471363031455586, 0.08078767948092953, 0.0401170100385864, 0.03755479450187376, 0.054181223705170624, 0.04886765318411974, 0.07079272185482326, 0.04277048196883933, 0.0821504962720698, 0.007211947409931811, 0.05304190157462032, 0.022296297641831542, 0.024148299877021103, 0.018545875904120265, 0.04187426251930095, 0.02504397157369362, 0.039851709959968444, 0.04840941769221137, 0.02951817211484717, 0.04092992891767814, 0.06955134532143993, 0.07508508185104978, 0.011352540121503897, 0.09562685620039703, 0.026795131740190332, 0.015114760570858997, 0.021745321461029594, 0.09545559724492413, 0.03494184862281527, 0.05319073713654953, 0.017784348118209073, 0.04676696731738987, 0.07131583733303894, 0.0416328911969979, 0.006959805849023284, 0.02181555831714744, 0.09356174362643112, 0.03933883324686078, 0.016697453214756904, 0.03739508432185939, 0.03914184905889054, 0.0670878517050897, 0.027260191160284226, 0.09861996938144008, 0.04849932960144455, 0.05235737520119837, 0.07027563548857166, 0.04118759493013063, 0.1855431704391395, 0.14570054628195303, 0.1051945359476151, 0.14519822243000233, 0.13911631168617358, 0.2789513977064241, 0.21431380161835303, 0.1260155187018456, 0.1866940183625106, 0.12081992572113393, 0.20940726893323086, 0.12721853721286022, 0.1326435735268939, 0.1571969060047019, 0.14829571509072859, 0.19553013776819553, 0.19682782942489271, 0.12689059795511345, 0.22360421116313628, 0.08529476626145263, 0.24812245681401224, 0.12951298586783871, 0.14425199659120652, 0.13419496286059582, 0.11837067367929606, 0.13575560653642302, 0.16485171783114635, 0.20691752914459477, 0.12242151679651392, 0.15292094029005499, 0.17193254594120289, 0.11427484587916445, 0.14414901905242475, 0.13162542735376667, 0.154435450151082, 0.09187811219523992, 0.2286956774731798, 0.11474479485543505, 0.15939908703008007, 0.06569120447121321, 0.2004774876179234, 0.2383867663241202, 0.08412489637492165, 0.22236794443620791, 0.14926807984950083, 0.12695438243568907, 0.23087821600417938, 0.12400912676727581, 0.1390236456908526, 0.05334433776536777, 0.1346701518782685, 0.27061792390961803, 0.16577522150210797, 0.11210472563341742, 0.12853907361145944, 0.18507700593721482, 0.20326097616024558, 0.15021597575997153, 0.1861707190231931, 0.12458121058561149, 0.07911848114623178, 0.15077287571564799, 0.09980281679740838, 0.14069581644669657, 0.16399160027503967, 0.1088148836166628, 0.27559014097336804, 0.16274218747933067, 0.14494126121844017, 0.15447165546638353, 0.248182870507721, 0.14276714965460763, 0.1317221842586033, 0.16118269293538987, 0.24276296698278, 0.25435006215928063, 0.10995447004754698, 0.16227190142437337, 0.11776655206396697, 0.16372248890899843, 0.09360210879916146, 0.1343495747254741, 0.11647256061194405, 0.12486802624358286, 0.1492612923104917, 0.2955734219041563, 0.1447290242198975, 0.12914975293942038, 0.13242384418845177, 0.2260157793399788, 0.19009402382277674, 0.1490236518363799, 0.17215353166384084, 0.15761667622193215, 0.24033650605668946, 0.2707404979775029, 0.12281667260873703, 0.2893016132856569, 0.126418917620134, 0.1108935789295262, 0.15662545037846412, 0.10140447682070156, 0.27122497198081785, 0.15669165569688046, 0.20218077686525163, 0.12685413983079696, 0.2438467056039841, 0.22165614150224194, 0.25052337636870725, 0.08100259778720718, 0.19959432613705436, 0.17457017134274208, 0.14250678701266167, 0.17291681570631845, 0.2293758869411484, 0.19347074021014476, 0.19449884552628766, 0.28278036643901183, 0.15261781462017568, 0.11738379921523795, 0.14852066914881432, 0.10604274083649921, 0.30477288149056897, 0.14470383524894714, 0.12308617467961966, 0.14810695102618587, 0.20343965850770476, 0.13731632682104267, 0.11962216257327989, 0.17606388957750413, 0.22443601410956154, 0.11234405150096263, 0.1268870050027486, 0.150016900151968, 0.135619871077999, 0.18251770536505407, 0.14392383516796176, 0.10092020966112615, 0.10334988815649863, 0.17700250050233257, 0.09281174354856053, 0.15248866751790047, 0.1392081809500533, 0.19676903983758343, 0.10271500045013043, 0.15415366769077318, 0.09150266782530854, 0.1189783116381976, 0.1423846266322559, 0.20667051175428977, 0.0860362780851222, 0.1739173725007042, 0.0928654846164488, 0.07175308967670126, 0.13330256235935997, 0.2522012774622248, 0.13196846620450098, 0.226791734476724, 0.07483363647254244, 0.12539226787104724, 0.10713653819214915, 0.1610421158012844, 0.10912079784658649, 0.1317337675080184, 0.17257841934840526, 0.14306938666249477, 0.09050165903904746, 0.15835558334665914, 0.2282892525075905, 0.15273473495917936, 0.11605819131457999, 0.157004096995919, 0.10409373654833726, 0.0971448441006003, 0.19629248718340553, 0.1595751646785967], [0.012683047154437632, 0.007632378856801699, 0.026211435944142363, 0.052531273329570416, 0.027075678883721272, 0.050074214851784135, 0.041665549525209976, 0.021953344975988713, 0.06558898535947646, 0.023611498238038153, 0.0851411120064797, 0.02381478732962522, 0.03325889517943705, 0.020376542590618617, 0.02881655623505433, 0.057517038658261306, 0.018210120634326053, 0.020428454623587673, 0.06457087749074544, 0.010901322952591845, 0.006328788801892511, 0.04899740549585512, 0.0862616228480493, 0.04560645519485397, 0.032850374963374875, 0.009928131776471293, 0.06205575720917794, 0.029193207193466447, 0.013925399492314507, 0.040568856357206265, 0.03749078019492088, 0.020087696799647906, 0.05556574759764537, 0.059564358840185794, 0.05116204821294354, 0.026442518705622326, 0.03124802737616964, 0.03254943264407977, 0.027060738253977992, 0.037386699489528136, 0.034259459634702054, 0.04476568901971464, 0.0406589214840243, 0.01632069500403539, 0.08762001165098722, 0.0636203462378152, 0.06703612544844229, 0.038113628829559015, 0.07544198689321358, 0.06394090806885112, 0.026201223992111704, 0.10635266936714612, 0.011353457511793221, 0.0535256784379242, 0.03619650145992637, 0.04268728482026247, 0.08040931631600665, 0.026529561615579074, 0.05096477291156208, 0.06798061992852919, 0.015397539903079311, 0.03212029891719501, 0.012466708712670352, 0.05215887032869843, 0.03517149879987683, 0.01696396179707541, 0.0488808375572966, 0.010385262186548883, 0.047306959712577444, 0.02718330849142325, 0.07214161882837934, 0.05148437587664493, 0.04766301056670566, 0.04164594916566726, 0.0066111089601632094, 0.03497469464256879, 0.07395975231643646, 0.05654609499258861, 0.014381348211768896, 0.03071621488479357, 0.0436721061686835, 0.03892632171271309, 0.07867974259199635, 0.0059570048958243384, 0.11230072922884457, 0.03330170417264585, 0.08292999839590443, 0.10459774579372137, 0.049687022523533915, 0.020425842263765877, 0.03699935394369307, 0.05373848617197045, 0.016999353143957355, 0.015109613417617738, 0.06569613041656633, 0.005709060539130963, 0.0290514521991774, 0.04741037009103645, 0.05586891923280013, 0.02054707759300307, 0.024474678230622125, 0.020781986963664813, 0.047713625995862874, 0.0816786703803847, 0.03846178897806714, 0.04424580643253942, 0.017598152363432512, 0.02920567718965392, 0.020546075933042075, 0.010529778927804963, 0.054795273819998394, 0.0236569655563442, 0.06327456096187234, 0.06607371983268569, 0.03308935609135417, 0.12169364133789656, 0.02337989453676968, 0.017715880925196315, 0.026277735108329404, 0.08665477917079004, 0.037071320243299975, 0.040112662489616105, 0.06569727954845275, 0.015289958175872604, 0.07915984223326368, 0.015683435297931637, 0.024406394898711194, 0.062406004947279735, 0.0660928720307927, 0.09107979495198497, 0.03006830559893241, 0.019955981387606552, 0.07728847329534831, 0.05912883785523235, 0.061395140439872785, 0.030137747638828816, 0.06356164092017759, 0.05044970901743059, 0.03119311610897703, 0.041717681808457266, 0.10665220208466054, 0.007096260951291169, 0.07292078387352728, 0.03400459750405243, 0.053574750199913986, 0.05613725685003785, 0.06662068362798422, 0.01771611458201322, 0.03325622919346056, 0.01491830115311689, 0.09163852585780044, 0.07903326152553482, 0.02926325061238341, 0.02949200446657356, 0.12336979575094678, 0.0562774202966642, 0.037427589432486606, 0.026126882819939527, 0.05454927149619307, 0.05732113082382468, 0.038178604576856866, 0.04857692664729492, 0.04102375553620439, 0.02191378611079868, 0.03650936027688365, 0.010197407851416257, 0.026527742156758908, 0.026588456539977944, 0.06287908339272104, 0.04945542265270506, 0.0585795987787987, 0.07541757167106675, 0.038286837478799206, 0.02998239266866398, 0.05772937524823412, 0.07789359848585822, 0.023098205922231562, 0.058992600609217925, 0.019469867956133622, 0.017727690170549096, 0.06858692489444249, 0.08026905327795014, 0.03865678133743425, 0.0663882831952745, 0.022597571294153893, 0.045726351785443486, 0.04234010909473704, 0.05891386209236038, 0.023911142038301598, 0.012319297116670397, 0.03540496026436168, 0.0057492672274219656, 0.05075641231791628, 0.0912609211199226, 0.026448549732806224, 0.020376071446545182, 0.03332136581922251, 0.033089938318176616, 0.023131153448635054, 0.017456039223038865, 0.012049420620314779, 0.038983333976038044, 0.07436684377851986, 0.022297716819711273, 0.03713981233417027, 0.041507674125774253, 0.03847499633388173, 0.010728807612923125, 0.03130760794926075, 0.03487848549059803, 0.059993034829535795, 0.025913718855008486, 0.05137706611065134, 0.029102379809163754, 0.057017668075258696, 0.05185963638547448, 0.02703145454307237, 0.03407338836921319, 0.05666114224661743, 0.029749894559743906, 0.014528537642270809, 0.04095358954321954, 0.03009323601520831, 0.07684727559887594, 0.037304375681184956, 0.042264224255397435, 0.05588386560820284, 0.03812524655293073, 0.05454506184304914, 0.06732003763318062, 0.03956851789787893, 0.04970450848040562, 0.05392879007324096, 0.09422226463474574, 0.03996517141199401, 0.056404108256702466, 0.00572735280354297, 0.01662652687950721, 0.019331478003051975, 0.0027713608916758773, 0.07458065891818655, 0.020182504010717237, 0.04907199564660269, 0.021241821664115115, 0.02917996536369526, 0.08444460018748239, 0.035555339493458314, 0.08365412002369281, 0.06838384264659497, 0.020935623981659452, 0.04691007637208508, 0.04529026772586569, 0.01699614323555462, 0.12499054668531304, 0.0355287600729254, 0.014864674998417258, 0.05444491499914758, 0.00722366807636835, 0.0437050900842634, 0.0752478065870462, 0.09161761931834683, 0.02792663977391297, 0.028865788875508214, 0.13285685240501358, 0.014272296553357475, 0.032062970642601295, 0.04913502936101249, 0.05841506607530098, 0.10052028112113477, 0.07912021250494065, 0.03399289551100904, 0.031517443262160785, 0.024728693834115422, 0.03568245263229455, 0.04211401739608377, 0.04732051563839759, 0.056592313077060453, 0.061136068656079234, 0.02194738098149819, 0.051199831669369054, 0.07514697409445241, 0.12255591160107045, 0.02283902305568899, 0.05533242402898689, 0.07914383099564622, 0.02246921517766051, 0.05348276602284563, 0.03567062423474366, 0.03158156482142306, 0.027557588407709718, 0.05057410254413563, 0.14782821759581566, 0.05286661682710533, 0.03753596406069495, 0.03644657554104924, 0.053845290319934014, 0.03258842268898603, 0.021413431104813373, 0.07031130454232616, 0.04105186330214624, 0.06144410111911355, 0.040425950315810984, 0.06512026978476394, 0.015452647480302522, 0.01260645368376807, 0.06447940659258636, 0.030052120076312177, 0.023140616549719727, 0.03334347128627762, 0.010683373810963766, 0.07327866950823415, 0.043792075537625826, 0.013765009409267337, 0.06440901077322422, 0.059764001353253285, 0.03219454241315684, 0.09294564805684552, 0.0162662357287181, 0.01617541217485503, 0.008632371618953204, 0.032919499076782696, 0.04113514855083439, 0.0023670888725563044, 0.09392912109051982, 0.0714503470507841, 0.04448991651917177, 0.057952766486954306, 0.0024694343888005546, 0.008772466117666375, 0.05658755567105067, 0.09679109534068454, 0.044759296015986515, 0.04292643831802472, 0.05687112311622309, 0.013163142007655435, 0.00687277969723988, 0.01857953397707353, 0.11061202629559463, 0.011342571402389196, 0.0747222549492313, 0.04484138233707317, 0.024234038522286762, 0.030181583189856143, 0.021534953717022173, 0.11072602017872757, 0.030037529931794253, 0.0112384993154856, 0.041236295139477144, 0.10726350960471939, 0.036053534131497145, 0.03222111800325013, 0.04466067751749389, 0.04449406105484213, 0.11709654688714974, 0.07215669543872918, 0.14954828416868565, 0.1500515273261455, 0.18170559087828284, 0.15427388220785127, 0.23183424776840597, 0.09339587792994515, 0.12990528417210426, 0.22226502818446006, 0.11816549235053601, 0.11450870187893031, 0.16038458253587448, 0.08800692435714506, 0.12756423438869177, 0.17979414022016912, 0.16833605425011727, 0.1513343875206286, 0.09071863812184142, 0.12806855773012485, 0.17157400147088114, 0.14511622037858735, 0.12512048285815025, 0.121593099958714, 0.12546987257777684, 0.20339464318127404, 0.08879126049578191, 0.13333293008467845, 0.10511323869709047, 0.11697890642549723, 0.12022735671170297, 0.22620884881865597, 0.1374457650367291, 0.22735759766111452, 0.12909880809245572, 0.15912760079147356, 0.0904183699599197, 0.16580011935964709, 0.1513783609674823, 0.08762832370496566, 0.16372556858245405, 0.17566587625732347, 0.12926892557692143, 0.20657338712724949, 0.10283266389442068, 0.19496569950734416, 0.1426497543410909, 0.22654378245915138, 0.12335543160236652, 0.09581173619916362, 0.19991750798879132, 0.12349669821560384, 0.13677770572323955, 0.08376829010704834, 0.09443437139834128, 0.1433228545131222, 0.22676938003109348, 0.2606571567875724, 0.194499014065631, 0.11049380360711968, 0.10556344558755237, 0.11185920977544402, 0.27009474714436843, 0.12585048038031788, 0.1471088763566748, 0.11007213349183721, 0.15907993480082483, 0.10712192889543311, 0.1519687542872083, 0.1459062868548978, 0.3877185387236457, 0.2545443880221536, 0.10321032225845322, 0.12505984699894346, 0.19797052617274946, 0.10930366303411224, 0.23734373761521232, 0.10689929608375796, 0.06381895836262454, 0.22990673990739932, 0.16807956801306817, 0.23404775157330499, 0.2219429341775756, 0.1942280334450545, 0.13840476922210188, 0.3208959679449758, 0.24597057712174233, 0.18905090318331796, 0.0861039849358701, 0.2643332756575077, 0.1690424639250963, 0.20300240616404241, 0.13832462110346364, 0.16348592095798062, 0.19967384606359467, 0.08247855810388442, 0.1514537440192315, 0.1551435145759775, 0.10451180605037559, 0.126374967155918, 0.1800701157340119, 0.17636582015022156, 0.18360076982888485, 0.1372945546022346, 0.22395262795109905, 0.10286167564411318, 0.13273073901091853, 0.11971293633142788, 0.09613348546648219, 0.12015166722478406, 0.2063715076374431, 0.14892531679041926, 0.11196374247271208, 0.1886556477796647, 0.246996782539833, 0.19436773723892628, 0.08594817797382993, 0.08362176813065045, 0.16164737122674144, 0.12604467600824373, 0.13145296564025263, 0.16064275416635698, 0.18044882363850073, 0.13990153648680256, 0.28012464604070114, 0.1876844168310204, 0.13290735292098216, 0.16840049756630776, 0.16727545148422643, 0.0801271201682187, 0.18058743958752002, 0.14191899839187824, 0.10723621389197727, 0.20503013364730344, 0.11398053788129361, 0.1611050422633848, 0.15271496989073294, 0.1719461516627381, 0.16842515027571112, 0.2390420166475158, 0.1250745329044519, 0.1874909643083811, 0.16118470008575148, 0.16442073208670463, 0.12858824113443976, 0.1464420274621056, 0.17743235243664635, 0.16559701412916183, 0.12807922167403082, 0.25973371440364473, 0.20186724772136058, 0.09126017801463605, 0.1270502123741373, 0.2010025949247422, 0.13282611695749144, 0.10850310115323913, 0.1665331735726326, 0.08143773572819848, 0.15332664513299543, 0.14241595962835898, 0.21448008866319734, 0.1354739926154575, 0.11643191198668174, 0.10154761268847412, 0.11516353851484677, 0.14003359472319005, 0.07794069757144298, 0.15135828946386615, 0.14559531644467386, 0.1207472239771197, 0.21461161063803783, 0.1921074407836122, 0.13336551946497735, 0.18765328301777764, 0.18418938582462652], [0.03845303642353223, 0.02946468385597391, 0.03330496770720328, 0.03764228940370583, 0.03010408573543593, 0.05677625078768019, 0.05509487165498638, 0.006736485473436094, 0.010193534319349115, 0.05168152860395851, 0.07725615970670216, 0.0062179741836453405, 0.037029262016256975, 0.021887880847639134, 0.08869386773796813, 0.04213939405857556, 0.015957928431640952, 0.009722089556406343, 0.03198331665067423, 0.05340258726069043, 0.0430843060565812, 0.015235763200889192, 0.014882295978285614, 0.02071289349377396, 0.03930701761536541, 0.10570445939177468, 0.033586543323772575, 0.050527298402401714, 0.07613945632211624, 0.03638257272541523, 0.016126505121768966, 0.05654345581968946, 0.036159587513294913, 0.04963097170055394, 0.006518612940600443, 0.024026520625357668, 0.017454761771425124, 0.05540439415903342, 0.04194064403793985, 0.04098460078239441, 0.0502245098112091, 0.052674895663174896, 0.03939410266015799, 0.03425354543592661, 0.03108271326298916, 0.02557517502516989, 0.06298573432309974, 0.017718784398429336, 0.013789902478756924, 0.08679006263733872, 0.03486271174023709, 0.031066456877235925, 0.020783331447971926, 0.061413714241596966, 0.01672201973926877, 0.12059592927295355, 0.08545838732032046, 0.046923440775924155, 0.10612998292931627, 0.06658995584134134, 0.032554201541408416, 0.03496318034106686, 0.03633048257700378, 0.03889976144437829, 0.014059007141528832, 0.01811170706435317, 0.02757950235278376, 0.05736405473022212, 0.0312203505346852, 0.029985437868162993, 0.03869651448762706, 0.022912806898896253, 0.04652570707783584, 0.029165731450062127, 0.02633994144778098, 0.03317129685573521, 0.01316824894128067, 0.044206460156748374, 0.034473064100189556, 0.05816670803112849, 0.04275450137473884, 0.023271732497960333, 0.09640321736374209, 0.028762907097716967, 0.02559639757589227, 0.05392925738687477, 0.06356966952162404, 0.028091409964667215, 0.051533351877644185, 0.0954172392225554, 0.05454839815595939, 0.05668255440410107, 0.03332582828138144, 0.04333295904460453, 0.055885164127234495, 0.04603375605637989, 0.01715977961618093, 0.009602073264578658, 0.010458598825930348, 0.01770720306423403, 0.12676883594042834, 0.0070290592397683335, 0.05383687101364617, 0.04234328069874356, 0.04353508751298632, 0.024353735930015965, 0.015044596493093958, 0.05524805476588588, 0.10232316179861946, 0.061398204791569905, 0.11413092094082987, 0.05457752864928015, 0.05651435213944605, 0.02978806106013156, 0.08707506266692955, 0.033421922520163565, 0.04879531916230918, 0.041991420345561165, 0.10881779475077506, 0.030356860276491895, 0.0017067286230045401, 0.008561622441535997, 0.05465053299802446, 0.008161253400988156, 0.02181786424179952, 0.028168145161602768, 0.003707322588701162, 0.015342810581768713, 0.04884490803364785, 0.0437046074488711, 0.03237365376985362, 0.0729214656917799, 0.09956752055234487, 0.03989142395796315, 0.06114563326381388, 0.02514082040908116, 0.024554159852766225, 0.03708894792643767, 0.022216082490499944, 0.07243103918529327, 0.08349796066120749, 0.02363560894023507, 0.05347575631833846, 0.03170401631524006, 0.04336575909908261, 0.04156196294652839, 0.025348945430690245, 0.03563187167709393, 0.03492101103127484, 0.07329202242075436, 0.03216620099039809, 0.029516659091196717, 0.03887780153402879, 0.12268074562833195, 0.019574105709550843, 0.022830128774888093, 0.03242944029249972, 0.04610104538920907, 0.10366008481791905, 0.05425696681824423, 0.0407643734868015, 0.05471927023703053, 0.049616523282302004, 0.02841675409957046, 0.028422697026643063, 0.029143250599924116, 0.01656965634244825, 0.0178584479726851, 0.027770112689223983, 0.024597179520154194, 0.047667691363923015, 0.032999915326194416, 0.012006801233867244, 0.022234985710031564, 0.05413279162659761, 0.02507243174008064, 0.013714664026103435, 0.018082224170587236, 0.0776009758814208, 0.04993941019018812, 0.0713241187435004, 0.024247701700416305, 0.04139183014030418, 0.07118650636966191, 0.008198703609166608, 0.029892388828879887, 0.08432686779527895, 0.035854048666454134, 0.11920050777975591, 0.07802792434250155, 0.01908187506600253, 0.026074047651021712, 0.06291870929060445, 0.014247955067173369, 0.051358584239478075, 0.07198141452165381, 0.04037199474330391, 0.024816274920838977, 0.028668879381110592, 0.01916556251085093, 0.04277281853700838, 0.004387193541568254, 0.08964972330197211, 0.0419268353031047, 0.07700875161155578, 0.03188728561414586, 0.04264967756405954, 0.03135328594174597, 0.010587259462373632, 0.029309323140149637, 0.007575161664957001, 0.005792990259285416, 0.03339495239478927, 0.008433167691222362, 0.007161318574235925, 0.021059090541976116, 0.010955250754411663, 0.048957997933030135, 0.032280068469023517, 0.04308410687372089, 0.040487137758323265, 0.04999892756102547, 0.02085426927454049, 0.041208654687169104, 0.024466350854885195, 0.07368753829430189, 0.015686640418284846, 0.05141366213079422, 0.045110520516191764, 0.026838519129781958, 0.030713248209306793, 0.013143193078107171, 0.0637316320001358, 0.04228761675016534, 0.005456545031554396, 0.016970509933608196, 0.08465744239548523, 0.07516791893830223, 0.046214824767723206, 0.017294183996836507, 0.03726605979365207, 0.04455994461633025, 0.04615980050256176, 0.016722291700481888, 0.08423925798025825, 0.02498078847213859, 0.05072412937278709, 0.009784456774322017, 0.03436250612139702, 0.005434269588741084, 0.03326442250381074, 0.04854049533605576, 0.04438800384260474, 0.026226160154047034, 0.057457191869616515, 0.06489888569640537, 0.041678381497941674, 0.043168089262420134, 0.036479969313668634, 0.040670420463767745, 0.038648296913672844, 0.009637660921491202, 0.05775837167616814, 0.0898766768495402, 0.03603977519237707, 0.03610502290088804, 0.03347035842917619, 0.023017232343854926, 0.01186878570625859, 0.06639530822154015, 0.027364329322271293, 0.1261413716260464, 0.023226406905920278, 0.03271271279382129, 0.10015996698770793, 0.03115064994011435, 0.03956665630422292, 0.04882787789909109, 0.050206177327181065, 0.054257652466936465, 0.01875467699832253, 0.0814452893551319, 0.022876235776610916, 0.06345185669018857, 0.03618452367523024, 0.030859986605543285, 0.1825106573561507, 0.025390214587171233, 0.07868957150006488, 0.024701246819008264, 0.07607932608093947, 0.029783395584672693, 0.039027912632351926, 0.027878935478868026, 0.05799615770698555, 0.044331822784677635, 0.023142631360960585, 0.033472028500851125, 0.04906275279579624, 0.029336624598551183, 0.05272743014258243, 0.005100757041345201, 0.04935792264258189, 0.011742046992895345, 0.040638915097881714, 0.016274792930832314, 0.0156700239712072, 0.06473347199179473, 0.0416125247495309, 0.02442719993151484, 0.01963781741177363, 0.010538339960358797, 0.0470911450834284, 0.02570685021759522, 0.026833715758496718, 0.027170087729069977, 0.027949972896866744, 0.038513308390975, 0.07466676720087567, 0.030812628965284077, 0.05606996368676905, 0.008637991831487706, 0.06016311017916568, 0.02508573294166596, 0.03630404488273686, 0.07142551814115818, 0.02954261415007134, 0.04013578685361051, 0.06055465771726543, 0.0774364278561646, 0.006741869156323975, 0.014551232039417713, 0.02320199168377346, 0.00705169857434568, 0.05537252490138335, 0.09694645797172863, 0.039773285539159854, 0.0419925005295344, 0.007424552130678128, 0.05833637352371889, 0.03168683104787863, 0.0007910233680083747, 0.049319533976696195, 0.04111272898773032, 0.06469926616597561, 0.11462241997041049, 0.08287438041260166, 0.03406033423098345, 0.054500785791465355, 0.05729123424257963, 0.016485710342925404, 0.03291363084328271, 0.14036756309290088, 0.176205110225466, 0.1372070367177648, 0.16308564001754408, 0.1819052487131088, 0.15834779989334846, 0.1357586096010862, 0.1354727515530202, 0.13235884928895583, 0.19256798220017265, 0.14420708851708522, 0.14665783443037542, 0.1403705048705301, 0.10633821328801495, 0.2087196284123967, 0.10365944896494189, 0.14763010725859674, 0.11979984134555825, 0.14660780888891992, 0.17634464547999446, 0.12791782993102266, 0.09037500938340541, 0.1742953602825442, 0.09677347531842609, 0.10362472219933426, 0.14448543890349327, 0.31871503819861724, 0.2343470468035629, 0.12849838668180089, 0.12567624900369875, 0.09469664926009794, 0.16939832708768307, 0.12979700530488647, 0.0955493740677353, 0.09219577821392207, 0.11696202184764609, 0.1812085223894927, 0.18496768519042, 0.11038716416805984, 0.14324647554707143, 0.08287897694014734, 0.2066209765091058, 0.06667519078379677, 0.07667538845130513, 0.20685596631899958, 0.13457308853826216, 0.1511302710540833, 0.12700425475955973, 0.2039210834810811, 0.1391571901378132, 0.22545227570639503, 0.1910923436404236, 0.16457178930361427, 0.13304478909459808, 0.16530824494698357, 0.26947090642586835, 0.16795844951223943, 0.1444343255171853, 0.1639662580865045, 0.17948660188384596, 0.10179393293876803, 0.18153257758146335, 0.15555243698819993, 0.11699196056372697, 0.09427013746913403, 0.11140099726617338, 0.1273301102581524, 0.10107842213924854, 0.2542123348722535, 0.12469764828922288, 0.1415836663856622, 0.2952058835616035, 0.08719740690843714, 0.12770745452613602, 0.12575988282239245, 0.19301793628161956, 0.22036307701660743, 0.20286077182860146, 0.14810316655183994, 0.23875202172465865, 0.07184633023796544, 0.10706041969599263, 0.20722862212888657, 0.09924366454323454, 0.25143679832258536, 0.1502046529804507, 0.23156161239791304, 0.0990231614559889, 0.11176378586359563, 0.20733199803338898, 0.13584384454354165, 0.14316254295408726, 0.14072298192449156, 0.1427864550702995, 0.12705565159839968, 0.2071753790181491, 0.14095912086627177, 0.10666409176924538, 0.15327646637395506, 0.1935495093705193, 0.13769981511417898, 0.16308793828131693, 0.2281564894703127, 0.10822374719165026, 0.18485468722158865, 0.21103479208484774, 0.0979425254908781, 0.22380238278738915, 0.13573285372507188, 0.15685691618390624, 0.2719134705201272, 0.08831649282646757, 0.13376592297948178, 0.09952599858684887, 0.13203007499537162, 0.17090388904175452, 0.08658866578292462, 0.10044133576053767, 0.17614759234411104, 0.1425215725096003, 0.08718667401661796, 0.15225617515463985, 0.21507815818392464, 0.12539549310120846, 0.16745873035923128, 0.10955007521495705, 0.21852848029905753, 0.22506972204052636, 0.11703043349928434, 0.1624403028718887, 0.20564928590770692, 0.16674415418697944, 0.2415754694131113, 0.12785856536920034, 0.17959307278356246, 0.11913041839556349, 0.14834613899790472, 0.09735465260042299, 0.158989766252137, 0.16156736100392957, 0.18690772624986787, 0.11593416934051823, 0.2246257894101643, 0.13080295535825914, 0.19336468299790738, 0.08842077271472062, 0.13524289453221908, 0.13496886488170395, 0.2118648789943226, 0.17056252026269514, 0.09228003256383444, 0.08846920479329363, 0.15830860683514228, 0.26955226496342694, 0.1117947971027705, 0.1846380528783606, 0.14354983104332802, 0.13611195999528133, 0.18637969248717834, 0.20074646108813826, 0.11311036159074116, 0.10084454315684496, 0.15978344866345007, 0.1369197690679181, 0.14791553629742515, 0.08493366305746379, 0.13883684281139605, 0.16127350499793408, 0.12573955084888205, 0.22831986538104473, 0.13278536107991973, 0.12159198913122378, 0.11576971324581294, 0.14814652712835422, 0.1316082516625043, 0.13178993707462666], [0.008111315002034028, 0.0960489936293133, 0.03453409449467736, 0.05736690840774006, 0.047719528703319455, 0.01928530971429521, 0.01905969107493518, 0.07806286561272799, 0.05298688880077774, 0.05447937746442134, 0.0064507629271716846, 0.06960251999478187, 0.014482991799952523, 0.002509954215530607, 0.036613268612493435, 0.025385353759291674, 0.059722594300945925, 0.023077917998776804, 0.08353922981768848, 0.03817547510768618, 0.03556176697114303, 0.09850189224967072, 0.028657715564834017, 0.039015720343037, 0.011808959027421812, 0.037344357809953155, 0.024259014903838118, 0.10554594047848256, 0.01065044352153857, 0.04267565560557189, 0.018804867248681766, 0.04267192092694102, 0.04139517794453329, 0.029191766948168798, 0.009179026106252305, 0.027174582749965693, 0.14405672077930745, 0.033282065508706916, 0.060125889797364516, 0.05493287087207841, 0.0799015072745181, 0.11597299467652075, 0.05607420015299032, 0.07123434089965398, 0.04589726983179008, 0.06707723372645917, 0.014935093800417118, 0.06308497335281103, 0.06280759589806681, 0.04784787524371378, 0.03518861320410525, 0.057212327186378746, 0.06835217257180522, 0.03080476890318096, 0.01148136163641128, 0.0046677263209506156, 0.04878448284862023, 0.052291223508936745, 0.06547120700199759, 0.028337050311928316, 0.03873181198873828, 0.0608489542238174, 0.05025215792439638, 0.05220339152841799, 0.031207692846956275, 0.013518610634961197, 0.05909381231533424, 0.019962242241167737, 0.016589291175947558, 0.02185735798951599, 0.0198596305093698, 0.07416091168359404, 0.08754358671966099, 0.02762798805751147, 0.025808975483561238, 0.06843847237647542, 0.03178679211545856, 0.05222507564711475, 0.058397507340076475, 0.05696665044994124, 0.09799972927618412, 0.08068111665066212, 0.054547026858574925, 0.02573976327004212, 0.02694196972785698, 0.05116608932674412, 0.0342574984496159, 0.0038783514783943015, 0.04478588692783829, 0.026404145361495115, 0.026819895532342698, 0.026834903194779353, 0.06925792598556127, 0.03148448807487805, 0.0845230475909287, 0.024540747568431883, 0.04379612048186603, 0.025577741419716228, 0.059824905343233585, 0.020648124590215665, 0.004808402088876333, 0.026138067703634024, 0.00931104795346337, 0.033711997882252744, 0.05988477128407648, 0.08793860463605774, 0.05897123058657012, 0.02807779849747256, 0.0746993795638123, 0.03766221152017674, 0.033524765993558595, 0.03061543410313466, 0.0778629013427323, 0.03930375791124759, 0.020361665163129088, 0.024390747552857767, 0.04810349580140845, 0.03348939188365494, 0.05905946476324912, 0.0309615736947425, 0.04280568753939964, 0.09454003790573728, 0.028493259470128728, 0.06007796333682153, 0.02745164419344116, 0.041416333462562294, 0.08841391622779832, 0.04679818923074392, 0.050509582619152726, 0.06011551313643014, 0.02242971951472423, 0.005446113786855412, 0.101583136185523, 0.12086818159948434, 0.03433068665946203, 0.08794800453488866, 0.07434841936394092, 0.03166927422787393, 0.01994154254545368, 0.0067837085695036, 0.013965649751856202, 0.03216245099000874, 0.04569941613402578, 0.0771542776736521, 0.06906235139937171, 0.028279900152776993, 0.04550385686959471, 0.06152436032050079, 0.058686387605003776, 0.046142421797999454, 0.03510327483978003, 0.03698164582132332, 0.07073257629188799, 0.031166958036802472, 0.02716817825491871, 0.07096102371090843, 0.061236755591967416, 0.0639030326818747, 0.028808945151526603, 0.07302369246439588, 0.02330016393605019, 0.007214771880347643, 0.06505513698944161, 0.027952843811362985, 0.03414981713097903, 0.07464045974155588, 0.06027369114059595, 0.012990048271603884, 0.031146750552579764, 0.045590727409768494, 0.03236820688471198, 0.0409238729926367, 0.03880755893225151, 0.012731370065481433, 0.03438450050570312, 0.02294985682613427, 0.03587967813796094, 0.03745550950688701, 0.03407524230198995, 0.040480940107015834, 0.02957310253423789, 0.037986703382264224, 0.012593137160424265, 0.025165827434149482, 0.08433196227997543, 0.12427363394489213, 0.02706415309090047, 0.03479823778052965, 0.10857340504205036, 0.037024083261888836, 0.028380447277618993, 0.057675645671664715, 0.020841341540818254, 0.07887504138653317, 0.025153767295001496, 0.09838223697677737, 0.029526095379204042, 0.04227516782139579, 0.04584591512778594, 0.05582663884025909, 0.10063317183765674, 0.03490230699460353, 0.06259585685667492, 0.0417679793111259, 0.04105898791984205, 0.020311861787171617, 0.051724199701340935, 0.01833504276169885, 0.012541891623949333, 0.0364006255873509, 0.01684174204485551, 0.035446934221733006, 0.024183187521092837, 0.00727397898557566, 0.035815123739021446, 0.014163044754475837, 0.029421656527706695, 0.05043426851531671, 0.04064127081824888, 0.031276489457776474, 0.07718868268233153, 0.0326948169799101, 0.04774209765356876, 0.02721010624701458, 0.0699570884687766, 0.0394166907626054, 0.029193211023906068, 0.03280700672598135, 0.05093457372558694, 0.06857151120540596, 0.05447367393982507, 0.02718194293969822, 0.06506459051442724, 0.03523021177839368, 0.030163559056217634, 0.032669294760712696, 0.04335512579869359, 0.03427700304816808, 0.0315673787882852, 0.04271106418943213, 0.027397709688352003, 0.020928334655059923, 0.006959271981501051, 0.020493489742699652, 0.010101866153549525, 0.011597619309360463, 0.01643740658407971, 0.01914815699321128, 0.04529112957478051, 0.050774438366774595, 0.009353440386363336, 0.0364999182432169, 0.029916535920253205, 0.027695384642650044, 0.020264965714886785, 0.03578230836278489, 0.04786728025083581, 0.009039193035043296, 0.03384577981646984, 0.0438526539402383, 0.058459139113584836, 0.0621398660023847, 0.0399634706968021, 0.05411394203322069, 0.03528365024155186, 0.06431062976198812, 0.0016701162037920329, 0.02478323163344495, 0.04585214342261034, 0.009909533076889573, 0.03394508779409432, 0.04981857131145174, 0.03235471224592578, 0.024067973642940485, 0.08933774165568814, 0.03463309986757175, 0.10766350709262396, 0.062172888222360806, 0.052741388264562816, 0.06483732287081019, 0.036142178165215644, 0.020857777957233693, 0.050969250695479494, 0.035528277437533104, 0.07635396094091478, 0.054783713553221, 0.04229012185767774, 0.047127411685763836, 0.051804213754592404, 0.034583311813372763, 0.019306459486664786, 0.09734811020954963, 0.046745800308042, 0.024200470464664604, 0.12571521223552767, 0.06841392691938147, 0.022929172452178695, 0.04914135341682742, 0.05649463303627507, 0.019782205833302393, 0.01874570993916883, 0.06849177677424685, 0.02119214852310477, 0.05910482482924577, 0.07787351932136283, 0.05085493505541837, 0.011468864827146454, 0.027090383941427838, 0.05552173967683508, 0.04925103039450703, 0.031857494369990406, 0.009331730412199132, 0.050839184287695155, 0.03999866860648317, 0.04525320056164938, 0.013632673466007316, 0.012853109097528844, 0.03724425310088742, 0.09343658018136218, 0.05555232573721198, 0.03172353048989129, 0.003939555439677451, 0.014531073393300177, 0.03737562185814304, 0.021498486016606613, 0.09572332199182242, 0.010867613168703693, 0.015505519038396738, 0.0029782563421664942, 0.04257049471620591, 0.03624621290533293, 0.02324236068694342, 0.03280637470344382, 0.01854249745637419, 0.16355062474406537, 0.036032164108849345, 0.01181332572859021, 0.037386776098320564, 0.06466605625445805, 0.0574914091867545, 0.007294261642175937, 0.06138600101093612, 0.04427264632296659, 0.006503607193383599, 0.036212872758868246, 0.09452747406377908, 0.026122945128008727, 0.03377616540679047, 0.017296970641661077, 0.0520518746587538, 0.0905154103172883, 0.05559344933698735, 0.07232876644740183, 0.1745902581681167, 0.20905336695573024, 0.21314729485780964, 0.13650458005647506, 0.21328131427928326, 0.1468887946177875, 0.11899490510263752, 0.16244123749915632, 0.2469748417816816, 0.15791384172776055, 0.10537727856107297, 0.16785717268864955, 0.10864876511116182, 0.1705394610161743, 0.1662343839604047, 0.1013080186901554, 0.10271160668062587, 0.20462605291076247, 0.11747739983782654, 0.11522950634600655, 0.18272856340533306, 0.08096146652655256, 0.21738475699338222, 0.24767127699188649, 0.18095548354810287, 0.0931976909839338, 0.2127651089141446, 0.1433565164165151, 0.12484799304436292, 0.12072499210555708, 0.10402514869647642, 0.218820221902382, 0.13296963586922617, 0.11568574234843255, 0.14497306918905628, 0.1802582516064567, 0.19790393781037102, 0.13405107622665746, 0.09769766846851957, 0.1828207084608655, 0.2184448234977261, 0.13000525864622287, 0.14843882031498418, 0.1581872125426608, 0.21832379692744827, 0.11913359766044926, 0.18669777219333958, 0.11764467513609318, 0.12563982918377847, 0.07812958421005357, 0.13131107083491741, 0.2325218116804477, 0.15266106794438056, 0.16245996068802573, 0.20536178843148295, 0.21549342380416012, 0.19648590906252786, 0.1687661819760838, 0.10924394648041456, 0.13483821624709716, 0.13153263878437782, 0.17535882821727186, 0.11297419712307954, 0.0668817817143375, 0.11868454756275301, 0.08150061622502343, 0.0743074489817504, 0.11708016792732863, 0.1343189924955368, 0.09644832462072374, 0.14242222622757958, 0.1846265768812549, 0.19475459631892944, 0.28255703648732555, 0.22826726578416365, 0.15104780934991377, 0.16191138044720696, 0.11300503216203182, 0.26602761699788036, 0.2924145043136612, 0.12590908610652532, 0.2275906722511976, 0.08913629883599859, 0.1495643107280616, 0.23793252215029734, 0.19305404966637013, 0.1795215661367101, 0.12408028867456222, 0.15115071027990312, 0.15045873370141755, 0.0989711900512057, 0.12719111126517096, 0.07275548508210529, 0.16627115618077018, 0.1535659097135067, 0.09534570193218608, 0.08336971754268294, 0.16926444556203582, 0.2044484124428803, 0.29198040825224697, 0.10811503165431562, 0.11479343377774763, 0.1448213378147733, 0.09820867975753161, 0.18236077991464447, 0.17896321061397755, 0.15856788163223576, 0.1871887885875279, 0.17471958913149374, 0.11057375254289759, 0.11049728164629591, 0.1765464790045254, 0.17364636123661073, 0.14792984681985072, 0.18213308326178984, 0.13739722570584667, 0.08017716869231194, 0.23422229704597305, 0.13800939124438072, 0.141121776654355, 0.17467198442787896, 0.15640231960963819, 0.12952199506182827, 0.11253129105053603, 0.15164353464159275, 0.13059955901436268, 0.20090565415880374, 0.13768237895302235, 0.14081212391536083, 0.11301070121267151, 0.10374450004629551, 0.21932098293496718, 0.16875845980980705, 0.1257895074424244, 0.21000650290760303, 0.1739877300156701, 0.1472434473614539, 0.222204415307891, 0.09304136308210512, 0.10360360115526185, 0.11720478744997133, 0.19702221657479965, 0.10276139473482486, 0.1535798525137286, 0.1568986679757795, 0.14963811563868679, 0.1382657855508789, 0.08893183762988738, 0.17379571773832844, 0.13273757251520313, 0.1326436961009618, 0.1309561269778398, 0.0961393383782237, 0.10042622850667085, 0.1830905093060386, 0.11185281294127626, 0.11764144990593196, 0.2478154240957191, 0.15215566441897424, 0.13422410484523545, 0.16741236671805385, 0.15861750880797065, 0.19975558764511542, 0.11961233366521136, 0.11230589266145423, 0.11371972324747233, 0.07620417542995946, 0.119698962887689, 0.27997856839529933, 0.13550770048412586, 0.11651933027972138, 0.15254993923008442, 0.11307031817493901, 0.14784068950722296, 0.16856758134259334], [0.09223720058798791, 0.03371042740200797, 0.03480116806684002, 0.013237047467320679, 0.06109263913165178, 0.01215951607352303, 0.02132093173361594, 0.023931435707415787, 0.035567393886946866, 0.04135898795099028, 0.015416089764555857, 0.11603993543934439, 0.027575562745633147, 0.049730111138835076, 0.044543523521673296, 0.048032805038195465, 0.048807967273939046, 0.0509412425209678, 0.03852027596064633, 0.06828513221755143, 0.021548879280265783, 0.02333872497171885, 0.008287556401844467, 0.018014894618142038, 0.026991120013859005, 0.11201010611388953, 0.027812266677257516, 0.013639900547962998, 0.0836237446374951, 0.014006894010479653, 0.024575939732453516, 0.015801965379186215, 0.04992717576603736, 0.07839769200091401, 0.07379694331076837, 0.0751501610202174, 0.040875846940663554, 0.061260044664865544, 0.022344264321990555, 0.015989170454803015, 0.034623343737856034, 0.12388209406767162, 0.054928550136185465, 0.11192953664689295, 0.008756771848927583, 0.06485310428205036, 0.053952044672182495, 0.042508598642363664, 0.043433864315551136, 0.019447593949735165, 0.01791993418948785, 0.033817139619420615, 0.04644208475046101, 0.03311858617610509, 0.039018945573198224, 0.0840530832928996, 0.01847577311338917, 0.01463103924892963, 0.08317540700156843, 0.014616860876671009, 0.017762595051599127, 0.02144381989754977, 0.029412748840367122, 0.010569276505961053, 0.06041991051226374, 0.104052743183509, 0.017198735187130592, 0.07608360085155695, 0.05960101231692299, 0.02385758866195477, 0.056452034717245456, 0.01329464866073742, 0.04179285418602728, 0.038229154888540506, 0.03759422121689685, 0.05941899365655357, 0.04528671307789703, 0.019225369079879696, 0.035808278743418, 0.046782955572369604, 0.0684884213091385, 0.020733757898391738, 0.0312800747492621, 0.01269553726043312, 0.013619773502972339, 0.023372013407248645, 0.057216180608637875, 0.07586645322941965, 0.029526882534546238, 0.036946716042415756, 0.05148269048321152, 0.03365439573122609, 0.0865382801801447, 0.0592410276013036, 0.07456382030561086, 0.028463962352684433, 0.02504211189525743, 0.02865381234685981, 0.0690488912345421, 0.019799693705393903, 0.03264641937529368, 0.1235246834074778, 0.026710873559838342, 0.08261908161183519, 0.02344243987012775, 0.0710701376139637, 0.024826866086392153, 0.02305444506477685, 0.04099710716775829, 0.02122795738790545, 0.023250387373170065, 0.01855037092501598, 0.022446447044550892, 0.05178092468169428, 0.046104615358936216, 0.05584150477642975, 0.03612118352565073, 0.004402542591936166, 0.08247251367016185, 0.03651181175824135, 0.0569697569364742, 0.05535190564490134, 0.04059923940428323, 0.017883456912973238, 0.024982862655193578, 0.031831133284515915, 0.043963537506398656, 0.035614021828458194, 0.08113022803539231, 0.06594949101488437, 0.06028800166302151, 0.002624331382028158, 0.031616555887364575, 0.05864358627267423, 0.021703209607831894, 0.02252187989201517, 0.057194810585990075, 0.026577723648158774, 0.08718267503765323, 0.022864229263617628, 0.05577217764972199, 0.031116522638307467, 0.034152506099593256, 0.03931307354040685, 0.04972190250672641, 0.045336573910448826, 0.03758063081712012, 0.031718769253441886, 0.032326359331848166, 0.044145874093256654, 0.09594302834762682, 0.030119587524583744, 0.04824049913534715, 0.05528309945798209, 0.036625706049944126, 0.026741637735657638, 0.04907667261338042, 0.005895608215547738, 0.026969236712301933, 0.03824679023255745, 0.048204941164341666, 0.08285333597732168, 0.0336744059478083, 0.04551729405178659, 0.03021673130382213, 0.02066171307477259, 0.056089027784764774, 0.01702455743666618, 0.04241600925583513, 0.04237645996674415, 0.02755259734488303, 0.02260310436418701, 0.08402772578260592, 0.051456034453886176, 0.017962501865000497, 0.02585140143280789, 0.05684906744488305, 0.04343916947442678, 0.02438499997820585, 0.08568367845709286, 0.03232550897425221, 0.05064975755709795, 0.06709872249273524, 0.0342844877271883, 0.05611325148493052, 0.012523822482645273, 0.008037595318690425, 0.031975812819455905, 0.04339734873464031, 0.032920644378229495, 0.09776800300084776, 0.0827586628316391, 0.04402522290606172, 0.02858158174691902, 0.021803800782729543, 0.04504797326761388, 0.01002510414353662, 0.015447970513524789, 0.020570627135795452, 0.04078377849392353, 0.05296130912498601, 0.019107443250475392, 0.030260197217425996, 0.03821776699154608, 0.06294119397118207, 0.026770779720297264, 0.0323663491214956, 0.019939035522721468, 0.05464541936112989, 0.05512935327245824, 0.07396784986579612, 0.050593434772904844, 0.03491028196989529, 0.07392450461104032, 0.04601022949622524, 0.0264375027449381, 0.061710125150819944, 0.036581399354843364, 0.06376656177904337, 0.049469231387540225, 0.027951418887823824, 0.04631170424662771, 0.05370832912083115, 0.010165129694336606, 0.054221006651078506, 0.05523464822721097, 0.043066042520466356, 0.01206421856618216, 0.043016028470329704, 0.05820066104793261, 0.031851530375499884, 0.020655823773854685, 0.05231145206057737, 0.022652283378486193, 0.07295720369344758, 0.07361557965557422, 0.01469178427566564, 0.07647017647902812, 0.053308680202932134, 0.05736846739666597, 0.03771414845100334, 0.060208458753843466, 0.04473833201993858, 0.020851172364106583, 0.06515454455849624, 0.022923809836708733, 0.030761502172437408, 0.09390765530688149, 0.017265557206325957, 0.0370794331144181, 0.03689243871298048, 0.0474791954301538, 0.04962218467206244, 0.07116333987083166, 0.022477483181583307, 0.010893694632085822, 0.04052345415637378, 0.03665619634933049, 0.011548294738355664, 0.02062437586456297, 0.030437464217445066, 0.0311055752418695, 0.08303404079690095, 0.03606037529666097, 0.04072988037801078, 0.026785716519600926, 0.020972124240811796, 0.010646502956778053, 0.04785550930987924, 0.05774717530115478, 0.033389164600521326, 0.047605358619963935, 0.09560862330779915, 0.0885886455615682, 0.0813510069142907, 0.037380501838220705, 0.06789019090994712, 0.0720994993143024, 0.056426424397936756, 0.05662987819842755, 0.03436136081995022, 0.06028195722929894, 0.05058321515999494, 0.020261836245716102, 0.06352604464477589, 0.030041203323391177, 0.030921323435200803, 0.03460891830224184, 0.08887556847184898, 0.045771451381545876, 0.03713037796138275, 0.039547500275676294, 0.0382293847149178, 0.03550642094905338, 0.06015735302841472, 0.031282124034459555, 0.05412171016477289, 0.03286767705914474, 0.004486171622580339, 0.056270671062051296, 0.08854671756947234, 0.04058338904512986, 0.0434999700425373, 0.03039807006115875, 0.0509488306218578, 0.08704761373660258, 0.022814889370854345, 0.06693301001383413, 0.008900353005306135, 0.07431850363049777, 0.01846807776018977, 0.03206480925361956, 0.05327688755407449, 0.031727849310564424, 0.05182967468675587, 0.04992812954550309, 0.01748214366905872, 0.02228104866169874, 0.06982541327635128, 0.04649712050694131, 0.0824164666776215, 0.048737801280954195, 0.029151495621209184, 0.060357842068638534, 0.04477495102271919, 0.03935675970428894, 0.01655404347055141, 0.057278647417983705, 0.023604339146385753, 0.08124678065219233, 0.07451724982069385, 0.019287638621585026, 0.024068109623547045, 0.04369125453635089, 0.03643712967694287, 0.013159866981779136, 0.006706987257911674, 0.046516759170880245, 0.02965523290538019, 0.05523788111825144, 0.11532992515112124, 0.035725717447818287, 0.08716381395295744, 0.028896712014571797, 0.042525092515373425, 0.04779324934427296, 0.050546343348199324, 0.015181859339317007, 0.03182929084305802, 0.03911347699261481, 0.010188031892832971, 0.032370623892113086, 0.12376123603673712, 0.10653218675044276, 0.1659604462404405, 0.20411608350132743, 0.1566648885848061, 0.1720098288910043, 0.16465693231551878, 0.1407934160482499, 0.17820525854345293, 0.09130919232003151, 0.09538963707464357, 0.1485162258388535, 0.11312764453431291, 0.1321392272028231, 0.3573912628475697, 0.16487695276737213, 0.13159593296868186, 0.18604757805024424, 0.16711973645273717, 0.13800022883280633, 0.14077202687340398, 0.17191181560197186, 0.11133450849522507, 0.1825888136461858, 0.21217860732107394, 0.23568601527762031, 0.10291336359636438, 0.09990108289545584, 0.1661734952921829, 0.06428769308953516, 0.17043910349809355, 0.13082901766944316, 0.10014181070390249, 0.18098664800486258, 0.19253732336144294, 0.17097613113301416, 0.21073304537323215, 0.17712559551000598, 0.16663392945643396, 0.15846314209122814, 0.17054033435640797, 0.1838483694460123, 0.12109923371744734, 0.16588492529286494, 0.11751791822814173, 0.2134096799718757, 0.16098700343601166, 0.18488222042158728, 0.193272982273371, 0.12268287535276144, 0.10977457728116743, 0.08209577461163844, 0.16358378102942822, 0.2012194897378645, 0.16074078277714793, 0.16561233588764745, 0.19999411678121937, 0.15087194620601593, 0.15985906154157656, 0.10417068241945199, 0.12478118251648643, 0.1238160496277194, 0.12577642266067768, 0.11763594173375638, 0.1852538037083803, 0.1395404486045722, 0.14416584234324195, 0.10541819531710879, 0.18902376834903994, 0.1304168317226633, 0.13008307785757128, 0.26640790304349315, 0.22892907382019106, 0.17855263345183867, 0.14313723140906903, 0.14261934065049695, 0.25713716663660546, 0.122252150078214, 0.10292895348562349, 0.21490990995399414, 0.18921391137184637, 0.09216261426767997, 0.16090970516445177, 0.14570318162441254, 0.11838409553972945, 0.1053431187005293, 0.23892872756527317, 0.16910289294056355, 0.08665793545303807, 0.13045853754926112, 0.11640655447638805, 0.1363701622692808, 0.13735650047179193, 0.19501728786816522, 0.13562526433698593, 0.13205088194339507, 0.1572292962021405, 0.1440457044349563, 0.20902214121193657, 0.10799715370540658, 0.17939229646036703, 0.17546208154770637, 0.14041604113674935, 0.17590924706910888, 0.14576908050765916, 0.16548744823423125, 0.1394950961994548, 0.12079714992714506, 0.13608695488543282, 0.13039697472366596, 0.085333775458557, 0.1332076440655416, 0.1878993044937811, 0.1116414339612088, 0.16839878152935736, 0.124873457806966, 0.08217510301619768, 0.09549861308187248, 0.16900866412587706, 0.11840843415308384, 0.22790875195735888, 0.16092919444124545, 0.09900519669416452, 0.12303339122163674, 0.19166274206532588, 0.15391061863591596, 0.11154876030500858, 0.1256130084455494, 0.12169821488280451, 0.16782248422743815, 0.09221380426278038, 0.15820222786597668, 0.0871089697184582, 0.19298608234572798, 0.10860742700676765, 0.13715808369940327, 0.2195892975695672, 0.1428394989981767, 0.19818743630763025, 0.1343321079208005, 0.1417084314650105, 0.09934904759809857, 0.10684577718136773, 0.12274111335676526, 0.18263909965753558, 0.1505040094977425, 0.12091772450554757, 0.12117122299969198, 0.13969648539298965, 0.18763828301622024, 0.25254859108357663, 0.11801707047608592, 0.16232024157239547, 0.17568207135604275, 0.19853891744729013, 0.09162839051456222, 0.1168978236795914, 0.11209389315016809, 0.07041687911917126, 0.088675910637023, 0.12700056987664393, 0.14668824812096937, 0.17739265376041013, 0.11726272667968467, 0.19246374827719506, 0.10504324124344896, 0.19365334492777625, 0.08730586963675677, 0.1723072089014515, 0.1838895696545801, 0.1757450437834186, 0.09187621995806695, 0.186904953011582, 0.13054338944775443, 0.11325172779540862, 0.11340547398093248], [0.043621586500516826, 0.03629084518780151, 0.005968072472305428, 0.014084482437840874, 0.08064606046724705, 0.06951114868805294, 0.01738350984880761, 0.02773483434031087, 0.020314458825234926, 0.016507082280793017, 0.024472498710477547, 0.028828602967663642, 0.027951263755019155, 0.030007932124839678, 0.02789424383081496, 0.034066861300098325, 0.06208967575202547, 0.028347813847264456, 0.027666920645823403, 0.06945292600580762, 0.022631076149522297, 0.019955931591891476, 0.028092126256876418, 0.024714212857126713, 0.04465395509595833, 0.07039594959707991, 0.01887469233254031, 0.022692472350993947, 0.018694315015548663, 0.02958806231617928, 0.05024055169234353, 0.10988822642473445, 0.04180478217500833, 0.021393955234558355, 0.035325532268372276, 0.019470475080813614, 0.06007400649269262, 0.006940285928712617, 0.038639969537935914, 0.044606151209483226, 0.07910230136927097, 0.03107158009022955, 0.04168236132470831, 0.05201687593193305, 0.01677199931544883, 0.09448275751163883, 0.029515747446566824, 0.02587855733450382, 0.02769882054699044, 0.034601406810144265, 0.002278377806144436, 0.0665472847439589, 0.09625847271132855, 0.03218074133920093, 0.04180492390127432, 0.046231900867555416, 0.040814824207055, 0.041883202765377305, 0.04164802526394206, 0.046235053319363825, 0.0323195296580032, 0.04443975308188989, 0.005721738815472852, 0.04520787880004895, 0.004280476536106078, 0.028803701279684905, 0.04258694262394021, 0.08365367569269673, 0.0606847471076875, 0.011323494855464708, 0.022256618117793434, 0.030130402770854776, 0.02932631497031018, 0.06801815823681893, 0.007874444446286127, 0.03230916831882731, 0.02491886750043881, 0.02073800202549225, 0.055532893917012605, 0.038585730512896856, 0.0787415505657273, 0.01442668816795753, 0.10865176051494577, 0.033026904603766824, 0.05584340467448196, 0.02782636461028409, 0.09860401176997731, 0.024275562403002576, 0.03277494594635021, 0.020623125226026582, 0.06383254493196165, 0.04057839415186355, 0.025930971155063282, 0.010424977142153489, 0.07081922083612412, 0.033350745291118665, 0.01912443316541612, 0.0513525742797121, 0.0677027138731172, 0.016167645958522638, 0.0939090725695414, 0.027737096214907307, 0.17241778603244215, 0.004374321828025484, 0.08421946992917408, 0.03350064571526262, 0.03439178983230264, 0.012857782233866953, 0.07568600121885538, 0.043789371247253114, 0.006505422342959191, 0.025572779085186702, 0.04382046675609966, 0.07022063803648756, 0.045421195982564846, 0.03301726338723975, 0.03872502828016877, 0.059503067975803736, 0.11548315039685658, 0.018276299139665022, 0.09075102065840075, 0.06303568708620245, 0.05751752895453284, 0.028473804667291623, 0.005101303357796203, 0.01139521504932594, 0.039065247927341736, 0.06952022682995566, 0.07598100635673731, 0.05273324858036734, 0.02329242836323477, 0.014131154429407851, 0.019891147366574696, 0.017769305981815826, 0.03566772076151064, 0.014270338241101034, 0.0415708419055708, 0.022682775593092366, 0.009866200271062553, 0.05301062986555119, 0.07020230555245954, 0.07729501568622167, 0.028736042309432264, 0.022174738640446338, 0.021419720686671716, 0.024910873372948943, 0.047505774850686716, 0.018812780936939583, 0.022233160505551967, 0.05003093471450191, 0.10194629250514893, 0.023034434848194642, 0.01149201791943802, 0.06640240219571898, 0.029124445056602843, 0.04393654439838664, 0.010194628867470931, 0.05487033511481939, 0.04166919993416917, 0.05239233945406253, 0.06670666933660546, 0.011810124438676623, 0.017126738244006713, 0.07836295757442713, 0.027128483409122117, 0.033398242742424054, 0.018280301949069388, 0.030117612932958913, 0.018993897528778163, 0.02232366613292646, 0.0831549447931109, 0.03387811638775372, 0.06176136877207507, 0.04288964694546115, 0.1526887083966886, 0.052886925817978, 0.04381771650045149, 0.05569262324922508, 0.03657796728094259, 0.0759679752011453, 0.018493781925269195, 0.07048519117937935, 0.011257806646397278, 0.011012950581648659, 0.009349243182148184, 0.03524850978846512, 0.017056773349101988, 0.07144801048261505, 0.010932917376199077, 0.09563229542465941, 0.026215540260196697, 0.016965731460180496, 0.07274975474443167, 0.034856962250365366, 0.009166444069705904, 0.016940982989786614, 0.03280222250689422, 0.022694519720971588, 0.05183318719988869, 0.025574158043450406, 0.0461376873746274, 0.012793754520375403, 0.0031310542544815694, 0.056085327580090494, 0.06349203034093784, 0.03350320827936934, 0.04435430746525527, 0.047471220454862045, 0.030406138882221236, 0.021848195577941595, 0.032956148723080274, 0.0823591786226438, 0.041482783929114385, 0.06914138102964049, 0.03705416753467533, 0.035137499817797256, 0.045583652587787765, 0.0662907985069098, 0.04238429704620954, 0.04189390884411912, 0.06280360841042092, 0.06367733551850242, 0.05727123551731629, 0.05767514005363469, 0.03676527577842917, 0.03593586302632767, 0.0032992675316505017, 0.09036531071028403, 0.07329291874362577, 0.02993249544693578, 0.025226731424129782, 0.012093448650933081, 0.042872034584081946, 0.03419945962847241, 0.07998914773305578, 0.026018148130406777, 0.06528881678898489, 0.029006396653130654, 0.062547332847551, 0.014846502435243419, 0.037238587880687374, 0.04112843762061769, 0.046836715792455984, 0.07525414979505925, 0.02107076189150253, 0.06296162553612264, 0.037817712047047196, 0.011070760534024768, 0.03233480545121335, 0.017826536580199198, 0.06914973138801514, 0.04409574129949174, 0.03046337522626404, 0.03996511012496006, 0.09008368146756003, 0.006404098117678997, 0.04586988218849705, 0.06375529262567721, 0.04764141837855981, 0.03397064448724832, 0.041750922363491795, 0.02205574220316785, 0.03558657672857085, 0.04973004985180113, 0.025451877004196568, 0.012066427772233804, 0.013658826750132346, 0.01156034242857488, 0.03702114531469922, 0.06442960321662888, 0.022245676467014898, 0.024234272179103667, 0.03257828351530818, 0.03348091512077278, 0.023660033738480944, 0.12037186387686, 0.04161265115403841, 0.05253734457637033, 0.054081812305676366, 0.07375376659535593, 0.043886641430999004, 0.035885021601232796, 0.06484730499646356, 0.08163481184671964, 0.03282931137589678, 0.08324309086967861, 0.04810691255355074, 0.03209554853158132, 0.023220042630489317, 0.07263759181143777, 0.02334884116275897, 0.023230099449715307, 0.014415655544237986, 0.048462036441290574, 0.017703562231373884, 0.04534997661868411, 0.03895952396335141, 0.01426978282735593, 0.025535349944426168, 0.05961696609794613, 0.010033345334382068, 0.03239693901231212, 0.014362498618391974, 0.07535590925404141, 0.03992820383920785, 0.04291643320973362, 0.039899609607434085, 0.007494588846325755, 0.06434734835619889, 0.04502766810718083, 0.03384199917256352, 0.023404677481120153, 0.07246156778907584, 0.0521942291168436, 0.08524681681827193, 0.047338204608569225, 0.0699584138008856, 0.05579701805066678, 0.02241584566241551, 0.03972913972252319, 0.021291270724407608, 0.03680643768260076, 0.08478008541128329, 0.002819736231861997, 0.049211427479261355, 0.0446578698052514, 0.02136187913316873, 0.056543153214959375, 0.024596474719263857, 0.030064115097986597, 0.019477844846645193, 0.06976424115559748, 0.039429710426878546, 0.02099477746073277, 0.012653667682541475, 0.05176485215704288, 0.0914026856903107, 0.021443425362268766, 0.02616980098067753, 0.09526134032996432, 0.03387924636744204, 0.051248309713217526, 0.05816371645778418, 0.03816500651620088, 0.05456349391850734, 0.03722515835937473, 0.02196216073277737, 0.0629575384570466, 0.020986432848017544, 0.03361814445064914, 0.07360438711100048, 0.05769454123031709, 0.1519407461126966, 0.12522552883432758, 0.0732404493816918, 0.143221914768219, 0.12917961504670883, 0.3433552144035217, 0.13161454890524188, 0.2092281422547756, 0.11337598725672692, 0.089758982761733, 0.14307278809287857, 0.16371508849964989, 0.14538709374685443, 0.17499746454338874, 0.1289247375943007, 0.08655930163278695, 0.13238353264187613, 0.13622455959839208, 0.11362651332972512, 0.18208267467637218, 0.12866164767934432, 0.11803857456412047, 0.12715324353907378, 0.1445573745595832, 0.10953648481518032, 0.1164627087212378, 0.1452367872961106, 0.261813826979168, 0.1924583703399666, 0.15809705931573145, 0.16419513451476253, 0.1912620474374102, 0.0941740240781538, 0.13874517273037665, 0.12870416555914188, 0.17840496234355435, 0.16774282640507146, 0.16840760686224507, 0.17565824602159763, 0.14002610238329058, 0.19860587353187226, 0.21998668269764995, 0.1261970125919869, 0.16887720343807053, 0.1584729633384174, 0.22912381337054316, 0.10578122140178758, 0.29949790647914337, 0.14433867177895962, 0.07678784249771027, 0.11121074699105755, 0.1926647084614923, 0.21404036951641883, 0.11846601332147276, 0.1563939998947805, 0.19816079176962378, 0.14866873862281924, 0.2705666266622082, 0.14870920338697974, 0.21001663058996203, 0.1327810403440268, 0.15350359612174574, 0.09385586010232087, 0.1573345720046951, 0.19174763992909463, 0.14701714498862145, 0.2145819323918512, 0.1512004753514644, 0.12927680096078303, 0.18103521797926198, 0.10496481682264036, 0.08102519738097345, 0.24189264513552192, 0.1316548910953345, 0.10202487780442161, 0.13429276164500945, 0.13693613270598073, 0.12133098297542143, 0.14152214952534245, 0.12197983646464926, 0.16516550744493164, 0.21055163575276253, 0.15177761535010031, 0.12190135075680672, 0.21753157008319132, 0.12242752292584028, 0.22513551367146356, 0.1029565709552938, 0.19201993822090088, 0.11180664848295913, 0.10397428811918344, 0.10693065972337801, 0.14295896274908898, 0.12270844736767393, 0.1920974509970796, 0.10156239818541274, 0.08809310924862662, 0.11974214726398069, 0.20751230448724764, 0.1943605819777135, 0.13968039754657977, 0.07834737534604727, 0.19790805936340364, 0.20682906131109885, 0.1451283858548249, 0.21037659998382294, 0.22231701491100175, 0.1615766000242964, 0.22452630523231723, 0.15009966829130728, 0.1453686923149132, 0.09450063800379153, 0.11134508050858014, 0.13459202623175037, 0.13539166880711434, 0.15222332530444668, 0.13019897163875643, 0.14184217509483138, 0.10826422727756924, 0.12943692865871614, 0.16073641607597952, 0.11056781536148441, 0.2338178792307454, 0.1412666898461119, 0.21953533433618086, 0.09391890913848916, 0.13246555001504962, 0.1769569182708379, 0.18625325733615508, 0.21667583455001155, 0.18279775646665405, 0.07828318483887181, 0.12573676228883768, 0.22243768908083442, 0.18004512594592187, 0.15062397886668483, 0.12515128725358557, 0.14531638383144332, 0.12271218587674441, 0.16229310673811745, 0.2142900069274249, 0.11188719496731797, 0.12459228055611735, 0.10827287641023436, 0.10044610848830593, 0.16616186607749234, 0.14588747173547745, 0.07240894520955701, 0.18857848740393118, 0.18761441171649965, 0.15843055271092923, 0.09707820977294639, 0.10386425491061904, 0.1694389757129454, 0.15360098121868027, 0.23904541807789959, 0.1030305214226246, 0.18986245076502525, 0.19885086845005714, 0.13216789421294967, 0.22157657561042618, 0.07158043644120617, 0.11012265699044352, 0.2270543953824428, 0.06277513292227542, 0.14074792574730613, 0.08667285118492381, 0.14417295163917926, 0.1632199811959459, 0.1263618134262581, 0.20666597651377802, 0.14791386622575023, 0.08283855048038306, 0.09578149870879228, 0.29746847828069045, 0.17472875154306813], [0.10210743910002132, 0.00516996398800984, 0.11733528286699327, 0.015726136081221125, 0.06056013524592404, 0.01635669539081714, 0.030054998651687658, 0.04786529991355154, 0.012171106026207489, 0.019050959587818193, 0.021787345214116, 0.013918619614184625, 0.045730067311876246, 0.04928616318671454, 0.01573535594938984, 0.034402281406425664, 0.06593214678427865, 0.04630537252993353, 0.050705904141068465, 0.013880551747617223, 0.06773367914701663, 0.0655189419405595, 0.038282811686757116, 0.013617294250927387, 0.02148974112295095, 0.04296864593221296, 0.05715045409517423, 0.043858951182975885, 0.03380603517495817, 0.06657743796465859, 0.05581419757236877, 0.06552101037795506, 0.03699543157352075, 0.010482342763533516, 0.01201604791511331, 0.02552761628683056, 0.0219140580720118, 0.05704176154047732, 0.10185591711272156, 0.045316916094311786, 0.048647762967213515, 0.03913737510541274, 0.05655878523905432, 0.08118935470138827, 0.0339693536290959, 0.05762845082508941, 0.009406160642092508, 0.02919070591639367, 0.06032809870497835, 0.0385946516067751, 0.03491669412582152, 0.07289832217558738, 0.07956751592216954, 0.010231181795168067, 0.06075408189527451, 0.06925289278789874, 0.013098182539725977, 0.038529645215960286, 0.05644163890411297, 0.045031088689762744, 0.058924828640996456, 0.10497006452492169, 0.024597401685652234, 0.04269527128687309, 0.0196550294922124, 0.06013803612140398, 0.03355223024564405, 0.06112487994194512, 0.08495173507159756, 0.04500542474429935, 0.04191015756899311, 0.037674779192574566, 0.037196119796604886, 0.04707356336556616, 0.027135420335276474, 0.02526567741898039, 0.054354026327810945, 0.05352580101199208, 0.012195954088031525, 0.047059409891165076, 0.04349689036908169, 0.02016424047460239, 0.046199499178797974, 0.01538702343109875, 0.0675844298976083, 0.04863957348730295, 0.062417557553177884, 0.05316133851245527, 0.09215480783173154, 0.02398121418551572, 0.01636630787904705, 0.018554569086841038, 0.054108610061267694, 0.04405406228597126, 0.03598421466566863, 0.022997700932225393, 0.025820547241657495, 0.05001489283336748, 0.051101439166814096, 0.06169603679389243, 0.049664434421086506, 0.05713148958860867, 0.004374991676154277, 0.0260736512005209, 0.0074708037314966565, 0.0041375063348471405, 0.0381234156027917, 0.0541012556171946, 0.059975602498818795, 0.06196756516733478, 0.005691081413158006, 0.08600680668267512, 0.05582433674604662, 0.04614189702777132, 0.011260791516472256, 0.012724276091302595, 0.036773832980543375, 0.0414891233066878, 0.008516298764715753, 0.04237919490063383, 0.09410525236519114, 0.03812547254886839, 0.032374213014038346, 0.04947291627045601, 0.03491262236850397, 0.050656353574126005, 0.04445315195968555, 0.10709275626727652, 0.0710783883809082, 0.033738370459046096, 0.04004999266697034, 0.08279330532757506, 0.0391207241843785, 0.017412588631193486, 0.05281289108097554, 0.013543363893404605, 0.01856419115117, 0.008889216959716813, 0.018834150959587386, 0.052921215913468794, 0.004486253498227246, 0.03721799926772233, 0.021220708280921947, 0.03800929148471163, 0.01828451734787274, 0.008501750755033666, 0.022046110562739835, 0.06021893117576838, 0.022203599087773793, 0.023448953532703945, 0.04846870906711106, 0.08088556253501485, 0.092249350742467, 0.008098212983309021, 0.020093815926943096, 0.08703334917945248, 0.020740407541574492, 0.05024058999673975, 0.04385698999788973, 0.03641661001189101, 0.03435740014538169, 0.07004626110316285, 0.036046041791597684, 0.039090850585771185, 0.01888436227736454, 0.10296785543041845, 0.035355474814892776, 0.06765467249938557, 0.043915017327714356, 0.025844470252312964, 0.02318418780041318, 0.03600585281908993, 0.05535087525664319, 0.07481522737972199, 0.0929277292602966, 0.04683599566980716, 0.044042846758759795, 0.010657091249501514, 0.04620395781051728, 0.06423014073422359, 0.10338754903885627, 0.037333261026369954, 0.04993119006676059, 0.03453668387186143, 0.02097713062539697, 0.05900360163181059, 0.02495593849509474, 0.028537479980338006, 0.005505036960746492, 0.0465844392085508, 0.1293623423384082, 0.04255404680847161, 0.05486044108927731, 0.03163760223786437, 0.09216226952811403, 0.028408091560366656, 0.051712367473350423, 0.053035581349245006, 0.05261566557530915, 0.06886132226716127, 0.09337225943923959, 0.03878919580470651, 0.0697477626043462, 0.03960032969893467, 0.03580525652655671, 0.0779152328088399, 0.03971921888390376, 0.01712547419893165, 0.08439233766928797, 0.016083322660697084, 0.0341094174842921, 0.029550445483877297, 0.05707852226952392, 0.03905451886596219, 0.05824849557792468, 0.019563043399924235, 0.044724557759060014, 0.04109750299023525, 0.0966498057448095, 0.08600541240265293, 0.023687520973204125, 0.04051178663728699, 0.022336511512196833, 0.036005910275684255, 0.014797003579235848, 0.04758852000738825, 0.01558283741976465, 0.02041886511799549, 0.031382261302262064, 0.05647848007239162, 0.038127947012863816, 0.04115713910470086, 0.018207017978232716, 0.03938616981970207, 0.05966835910634649, 0.07023144753709917, 0.03920010621509245, 0.05510623273890346, 0.050311418655779094, 0.04663707710982812, 0.07083783677268414, 0.013637766993093877, 0.023016274733949574, 0.03321145135428637, 0.08469144903844403, 0.04088071542942236, 0.09171289001261035, 0.019040791685843182, 0.04680253677971421, 0.013430694384770769, 0.04234674341616131, 0.07680506415424809, 0.04005914358722587, 0.08522279996184573, 0.06804558418450818, 0.039815022009274656, 0.06069355711881673, 0.009874869513535693, 0.03714128705342451, 0.02401964307101744, 0.03930347445871561, 0.07298367969211071, 0.012214286572059557, 0.06270973582661922, 0.08627132918204992, 0.02035418048410887, 0.02790562981258958, 0.04287830118330256, 0.139530566070349, 0.020352745984470653, 0.05229865839224189, 0.0740630975774219, 0.023365484422913963, 0.037910515938194535, 0.08888512158826475, 0.059870093039447264, 0.08391875743625626, 0.056601157562146266, 0.025915187828603293, 0.0704657631896196, 0.0205630466957847, 0.04348493939746292, 0.0637341907338029, 0.055138098166113904, 0.05569210613987619, 0.023446063466009595, 0.03356851727491425, 0.0755478908878661, 0.04980843213777389, 0.04245267805433081, 0.04014493394342642, 0.07571316669665037, 0.05524859868831212, 0.05988976617734279, 0.016696899716231613, 0.021826176295777964, 0.17090928230074146, 0.027894950546925108, 0.04910331332094727, 0.04217583686113358, 0.05448107817961324, 0.03689095250240738, 0.031425769350701765, 0.07614594508683489, 0.03998286038216564, 0.031199721702104135, 0.035961726154651374, 0.08025981425758331, 0.0913606810894224, 0.08810793304996145, 0.038640816065092246, 0.04471698114948888, 0.030607438060424985, 0.030792883049035748, 0.013042993565660813, 0.08143548342970111, 0.03440092160036007, 0.008960490907362152, 0.01725272906403388, 0.059647211249196724, 0.11262727420656912, 0.035641623976370024, 0.04454669895611944, 0.0775070151975078, 0.026574308811236295, 0.037832022569472754, 0.06595738172050446, 0.037368788353858456, 0.05027180807965417, 0.03156579298628194, 0.017161518635769046, 0.06139225994927749, 0.01736406462206956, 0.036678887873647675, 0.042673709742244215, 0.044749072572636994, 0.05236624266892191, 0.0958450916673868, 0.06019971769062742, 0.03926761771341966, 0.00946953718084842, 0.029818202789512374, 0.013902907150857633, 0.013509291175362325, 0.023851674463179325, 0.0185331569293574, 0.07836989067014187, 0.04141634878432078, 0.03277342526182052, 0.015274840388296834, 0.03706425691263811, 0.06988657007534659, 0.24742824325878776, 0.08163003145807213, 0.1090789771068, 0.15026687464166075, 0.2879092944485526, 0.12705171390646888, 0.1302062341522786, 0.13238627523664506, 0.12430427746186334, 0.15994092569716517, 0.11071570097438752, 0.11331306845550576, 0.10387427534066862, 0.160687999319165, 0.338689248648382, 0.11403764973604873, 0.16997820968108793, 0.08989100269372426, 0.20684429113903355, 0.24447636859070873, 0.20213136419413552, 0.13821272630124323, 0.1595436478213918, 0.17621497743793074, 0.24394474953653353, 0.23465892119753748, 0.1646396646937055, 0.2357783595160131, 0.08418163284659387, 0.18299580551683906, 0.13026461005210876, 0.1429666849153657, 0.1357023940692025, 0.15492712538088524, 0.0989752349954459, 0.13645293040862008, 0.134494457273714, 0.10569527399756255, 0.1706757480579038, 0.0903969654633153, 0.1428438503775866, 0.16951996652830034, 0.20331242662524024, 0.21643486925430838, 0.14682398357939336, 0.14471940215556853, 0.09192230014671242, 0.09349288764379679, 0.10028224994218159, 0.17954364479068788, 0.11561769075811872, 0.22531649428269557, 0.13754033093010226, 0.2197360953376178, 0.07431137135192271, 0.12133886602016226, 0.23211256751129705, 0.151170015695595, 0.13578652584504697, 0.18335525397091143, 0.13953819630607484, 0.11102479446919696, 0.12567462489729928, 0.11996838068889996, 0.14470202728144585, 0.15070720665877865, 0.1125312680678983, 0.13859080601363413, 0.19169078088335453, 0.10481490107673792, 0.2619845113686977, 0.12706600144625674, 0.11836799237156108, 0.1439434623405818, 0.13237847646157588, 0.19336013243563716, 0.14923751294132204, 0.17375425705986638, 0.1607917889111465, 0.12384939743506333, 0.2016450362580438, 0.19651465268144686, 0.1524167625053275, 0.07822352957220809, 0.15838755985661862, 0.12425597561823747, 0.1286265148871368, 0.23347828777567034, 0.19933788586528073, 0.09397776767371163, 0.09033077546665746, 0.11861756083465393, 0.25681666609260345, 0.14929400426485848, 0.1760657588320394, 0.1475214606691753, 0.12458042151504949, 0.07547860589599417, 0.20888398491567184, 0.0963225023400399, 0.11040626274001215, 0.1441548413206493, 0.09118461110178502, 0.146551271600108, 0.16169257041427398, 0.10233769448654306, 0.1542612877223761, 0.23865250690329462, 0.198214310672014, 0.12729195907952326, 0.13048490629561488, 0.2780722045610028, 0.25435605296684854, 0.12675750550002823, 0.0892685792378841, 0.09596626379437025, 0.15376728358528308, 0.14765298264401575, 0.16061417908678133, 0.11447386786101327, 0.4474002507425124, 0.15643996517023734, 0.12536202271979663, 0.11300086464372375, 0.11729862555981645, 0.1859157036749586, 0.10865059606130086, 0.26929084512014545, 0.25460400498442115, 0.23435924292331745, 0.11807419765259951, 0.2169425097564536, 0.2245868415000939, 0.18477142878597785, 0.1758896352182473, 0.19349139394058337, 0.15443105280639666, 0.13194316998124123, 0.11795797445360692, 0.17162261741055598, 0.10162218368702358, 0.1311022965537925, 0.19450731845873018, 0.19458188945727964, 0.17148464497539306, 0.10286621854550416, 0.12860920130004808, 0.15787241169281546, 0.19891132810904136, 0.1395965875276635, 0.19956872347862492, 0.1481582482735957, 0.24357796196014653, 0.09395646276853739, 0.14366118958400143, 0.2439806484166653, 0.061547028862180254, 0.14435597004428988, 0.12295997701585294, 0.1435150353298072, 0.13521353804296063, 0.1973174055737834, 0.1613087297206925, 0.11503717997261595, 0.09833063329419783, 0.31453143204412154, 0.1574151644543294, 0.14634859537886036, 0.12502106762821638, 0.08158873931895341, 0.12686727823869837, 0.17904279182755178, 0.1314541913809315, 0.186604140927234, 0.1774068417087678, 0.12046151914663854], [0.009260241959934995, 0.1021001306212237, 0.027904057417124994, 0.07731684919206366, 0.07173261980736448, 0.02217636466206562, 0.067842417666989, 0.03466625615293461, 0.06013259306670197, 0.04884927090437663, 0.11177179148240436, 0.031536497784057455, 0.0199153806428395, 0.0539190071304479, 0.057895562701648286, 0.06822452700186162, 0.019106512453647393, 0.04470663513207147, 0.028977360005580613, 0.0441532017242524, 0.023760098227930647, 0.05154354467747673, 0.014134333694293616, 0.029342973552223657, 0.025561335646817764, 0.04250102586323216, 0.05349701142779762, 0.03840232906382411, 0.10157313873811115, 0.0516680492869308, 0.05006330575974238, 0.0657816028462783, 0.10894949292583812, 0.07075454003267712, 0.05438579216359123, 0.05257968625594532, 0.010880399176159935, 0.06628874539127273, 0.05287608567384943, 0.055220444957094814, 0.033368671748546824, 0.034483456082882426, 0.07320720116577803, 0.06782983084239307, 0.043043105848013394, 0.06090536510812179, 0.0331508040037607, 0.0462385734933759, 0.005827945893660429, 0.06358572289407735, 0.018609248612436558, 0.02597767762058685, 0.05462401869496512, 0.045514061160746126, 0.014857146269341391, 0.02519595001133219, 0.042407413749324704, 0.03345868707964978, 0.03710400921502902, 0.030761705185737342, 0.03617970498218652, 0.0813933332721072, 0.013711932922653375, 0.06709326028583512, 0.05419209449281616, 0.04093937861222414, 0.019664952246051644, 0.030722868358415943, 0.023221593958535985, 0.08809293304840404, 0.05468900976402145, 0.09138259886493606, 0.014422108877390144, 0.03440674769902422, 0.026148951897818237, 0.05422282227945905, 0.04060976928280246, 0.026995030892712456, 0.0420521519657585, 0.013269020146840524, 0.04912864401816361, 0.08993311454692195, 0.05051106882972583, 0.04507993445581487, 0.04772055909157761, 0.024975215182489446, 0.034322443553396774, 0.03452074924303639, 0.01940974537583609, 0.029431847412319436, 0.005364326718864182, 0.06865460876255267, 0.020591478133874557, 0.021386838277741786, 0.04884282810493343, 0.11159643395653657, 0.010338459002424874, 0.04846777443984344, 0.02089256600987527, 0.02469224528589797, 0.10926666864824873, 0.044363060019790165, 0.03389913400995635, 0.03803932979222267, 0.036898433350987976, 0.01021469366781774, 0.045989276991496165, 0.05118649790904695, 0.026723609771579507, 0.012094734721035968, 0.07017664160699615, 0.03215796937565169, 0.044593346049828876, 0.06486885504977358, 0.04173588405753817, 0.015285324301540613, 0.022574923819892352, 0.016262449339152347, 0.03963898266515425, 0.02843241868240218, 0.025474652798185428, 0.046367061760036216, 0.04986169823114911, 0.018288573783431804, 0.05412023161507903, 0.09006520342682639, 0.038123790985874595, 0.0405840938460202, 0.03517130344745613, 0.051103814039379365, 0.033113966665921674, 0.025560383782571843, 0.04667011848200233, 0.014363742553659025, 0.02037234442879356, 0.016050294695061543, 0.0436593814482612, 0.06308449837829798, 0.03241673472427553, 0.015542827520309197, 0.05780180503103522, 0.028745612662826336, 0.0515292379854908, 0.07548690262821413, 0.009569121907735545, 0.01700364706677295, 0.09388503273047748, 0.05698616653981228, 0.03216718924382041, 0.09831428497789368, 0.012394848707762939, 0.03218391294320745, 0.01122756053753678, 0.011055280769904776, 0.056517274764877175, 0.02780984009375736, 0.020113648028082905, 0.030785773753098426, 0.0805511421734287, 0.08582100737839939, 0.015791768748914043, 0.019854110845875357, 0.04314278920872077, 0.13735078545587678, 0.08672685272270635, 0.10736018990076358, 0.0558108919029755, 0.02402324368426156, 0.008224785072548736, 0.026724923612369646, 0.021459587902251272, 0.057541384932494936, 0.030165918607024417, 0.05710828478538221, 0.04407562000016051, 0.029209865775379925, 0.017920384266143365, 0.03428611183358777, 0.044989087919314066, 0.02977014417880245, 0.019586047105070566, 0.023337955053354946, 0.023801304182157885, 0.04879363376887576, 0.0202303366254895, 0.05231023398077777, 0.027671904047770847, 0.06459900057844578, 0.035423442135534944, 0.06337376168718742, 0.05468298065205736, 0.01841497254527865, 0.030796826486625982, 0.0032422521560933563, 0.0073582754703238615, 0.014410055441511496, 0.009858232956650037, 0.03238390019584087, 0.023690968368863387, 0.03408354286464953, 0.046115888342742, 0.043850336524267355, 0.07321106990979565, 0.008710757735365582, 0.09214954480769173, 0.058528041061494625, 0.032390526856385896, 0.04610094196733929, 0.04383270884112966, 0.06372050457303563, 0.003333803254082018, 0.08737553767259083, 0.12477273256668162, 0.018905136666651216, 0.029821835961493275, 0.027964432806437536, 0.03498898984323587, 0.03748354066403643, 0.03420978649369171, 0.09536036485505682, 0.03266729527123032, 0.08762437069127638, 0.0683358472381388, 0.09224323736083123, 0.035642018511651025, 0.02565066341400868, 0.018243702098486886, 0.04245400338643982, 0.06748229505554323, 0.0545251703700952, 0.07250878944872849, 0.04018545999462086, 0.03909139450819742, 0.04752496918362956, 0.05688888486474753, 0.025136603095057993, 0.0214691142055897, 0.016741474542105873, 0.03170310658582997, 0.03488813053756472, 0.03924884855927479, 0.012916315181721604, 0.08865331104325672, 0.04914400408104543, 0.03743644540889129, 0.08357052450939532, 0.03533908053331318, 0.04259938772227015, 0.03239436495688654, 0.06382521730096591, 0.07369912154371701, 0.05649514631518433, 0.07434288820912761, 0.039577550074506196, 0.008367616420371399, 0.020296706652809537, 0.015803126960001405, 0.05404501327223355, 0.05083285257100098, 0.08231259281596831, 0.03692469101459269, 0.03017100734606145, 0.03799486604909744, 0.02476050180473155, 0.05014215152890933, 0.06645815041396888, 0.024024850553682735, 0.10826470991296154, 0.041427920542417035, 0.013519112422551601, 0.04233973371165414, 0.053433885782836914, 0.006647271661823917, 0.024342415065714912, 0.03800459153529617, 0.020676446860776316, 0.012712950438952014, 0.028611976285314852, 0.03446470991137528, 0.04534693908006434, 0.03523521816297885, 0.05524932264140057, 0.03541556292123372, 0.006111543024739912, 0.07184700439533881, 0.002652919628740018, 0.07210024241958896, 0.014785423202650442, 0.07970768702967514, 0.048207599489438924, 0.014903089519770396, 0.012222729818595034, 0.07464394544161136, 0.051098822976552674, 0.035706615045426354, 0.03548228917943855, 0.09159607692591606, 0.03424920171739594, 0.0841462012800959, 0.04352645370207968, 0.016498006054110104, 0.06488385505133099, 0.01074284521652566, 0.03763066018901525, 0.03097103296538755, 0.037781522053504185, 0.039753489827196446, 0.024541381506189227, 0.06150044688594438, 0.03362840236795526, 0.03434322368834288, 0.030492249080130172, 0.05800532011855995, 0.01971538764454665, 0.05280842095793736, 0.030771788818040685, 0.06980349550083761, 0.03774968343937109, 0.03734590147712058, 0.06834411332684179, 0.03922337996623209, 0.03897163581343428, 0.013697259466073686, 0.05959215634051831, 0.0250176947578908, 0.05693094692223015, 0.024792752191123944, 0.021346046010993665, 0.005643910506830341, 0.03711781411942455, 0.07283553360931336, 0.0850770593951306, 0.031115972970221794, 0.05258283870775373, 0.06467252203653898, 0.05277518806378207, 0.046958067950101635, 0.03593498585565436, 0.10507224533226221, 0.04998342194143803, 0.11614104372359092, 0.020651372803014614, 0.04897897725083655, 0.015067052445374431, 0.016283041782557003, 0.032044950339402405, 0.019921520837552605, 0.10889635706741004, 0.03142279692955556, 0.06035675039334644, 0.03891708652278589, 0.02542715534688004, 0.13935110231320705, 0.19117851321014667, 0.09104273927908751, 0.1556876821503524, 0.1461055769675201, 0.12567791907537368, 0.15771951586488756, 0.1414144528849471, 0.18893157732823204, 0.1363560202861986, 0.18508668928857774, 0.11681833439656805, 0.15538884657284907, 0.16718730540765872, 0.09755876140608903, 0.1841868424127179, 0.16567483334051025, 0.13643313469665666, 0.09998005123869066, 0.1664269018557764, 0.14219826808379543, 0.12675467863558762, 0.10022795729098782, 0.13925645981104146, 0.17753415020002475, 0.14440060232675847, 0.15809813183882546, 0.11219793555116463, 0.2180976018069252, 0.154015434785716, 0.14161023431487624, 0.22814585616992367, 0.19398685364473253, 0.09241032879799606, 0.08377126252819454, 0.13585881390158208, 0.18800838009244014, 0.14668113882503203, 0.1292416222033001, 0.146466618884475, 0.10272511281073095, 0.0758145584334289, 0.1431698514328849, 0.16203468995949916, 0.12199160357516621, 0.20800846899228714, 0.12674347843013464, 0.3484868696860729, 0.07443288821847209, 0.21329547158412396, 0.08596598185719022, 0.1163344732635925, 0.1376208927362196, 0.10567891035949993, 0.19866420346642696, 0.17797670387212308, 0.20352144605450093, 0.1010307714703583, 0.12216091666731144, 0.08291103005889924, 0.1152984542591918, 0.1722543794781931, 0.0906837351560112, 0.2354756168900959, 0.18216315987369708, 0.16032940888356778, 0.14172018325376895, 0.13938442713791324, 0.1501858838263058, 0.16777434326227636, 0.12252321496846215, 0.2038074726419103, 0.200728626561261, 0.15547103248536587, 0.1451481968885468, 0.20033246717385708, 0.1633317993893739, 0.14759241573272214, 0.1551867372566654, 0.07572071266270454, 0.08354173492520087, 0.23585378853303773, 0.14378384026067872, 0.14221158269191944, 0.17322692809806717, 0.09782967307875234, 0.1806999166165629, 0.08605802732129252, 0.19565562297019268, 0.13336357360164966, 0.15232523032013448, 0.2566269061137592, 0.12956173970333992, 0.12614380012476636, 0.19054247637189206, 0.17898138221954146, 0.16184733549673713, 0.1485209909057425, 0.17141342944195195, 0.12003277803981498, 0.188279498608843, 0.0851867861685253, 0.1509117214910446, 0.09469859512342561, 0.2042178046559134, 0.20926414838721677, 0.14558359529943238, 0.14187140901002193, 0.18818954456477396, 0.1039369106893578, 0.12307470634339318, 0.1435152345126675, 0.20896745785590143, 0.0952609419642437, 0.10503852214183539, 0.0784112364354153, 0.11284943970461046, 0.08882473087719372, 0.15370847867621532, 0.13686908469084771, 0.0942073105984638, 0.11174540741429215, 0.19373589856249673, 0.12423159103960761, 0.1312683844157765, 0.18825279278380258, 0.14697966796736564, 0.11950338830149944, 0.14822123602273005, 0.1309400238096714, 0.21102006787494307, 0.08999048687157132, 0.25763843328722064, 0.17241832229398912, 0.07646936442582838, 0.09657019388771827, 0.21170426100011797, 0.15248282992791745, 0.1718206204954655, 0.11886050263720176, 0.14343185350298882, 0.15277046529996782, 0.08266417354705834, 0.13328557052919943, 0.13744840037918862, 0.11337150564236988, 0.2151912787268239, 0.20185897397177838, 0.17437175457035342, 0.2764374648611392, 0.1080055883334529, 0.20224986267426323, 0.17106711173490172, 0.08063883625812109, 0.14497478522600668, 0.1496515068556032, 0.08322572365643517, 0.12324683863909976, 0.17596371592052523, 0.1723863151405127, 0.11230226906557238, 0.14843298272500116, 0.19748793674572823, 0.2473899695060907, 0.2242400334967721, 0.20511916838586333, 0.21689197859696804, 0.08945608691823098, 0.12086253553148239, 0.13826230751170268, 0.09331014503033892, 0.2154050632229736, 0.12093479294450053, 0.20857669172748444, 0.1546430753003205, 0.09948531165719034], [0.1523437390043851, 0.02581081026413989, 0.06980019366188396, 0.03948731640834482, 0.05278181855476672, 0.012769921525051037, 0.022369395836346576, 0.01836657302544242, 0.07225301567344897, 0.0416774736837514, 0.017126558213344505, 0.08694932465591738, 0.03474240146216846, 0.020390443256004684, 0.010546450916257118, 0.03858398766286912, 0.03041019340256049, 0.056189040563279585, 0.03683685137319469, 0.07937434685206221, 0.02763401716947556, 0.03966386520093487, 0.05670099030999888, 0.01698830998652885, 0.033277748603253596, 0.04717045433578953, 0.03231468415188213, 0.09790864908286641, 0.012493843546948366, 0.061067963439610705, 0.05266973989144449, 0.04101048306291623, 0.028878904300771897, 0.026895502664809747, 0.05906930516263651, 0.007402732988984715, 0.03353720726144891, 0.007063398652169253, 0.06886835495430617, 0.01694480002286934, 0.014798904434897968, 0.013620198681770314, 0.04298775216504451, 0.006868564777241479, 0.04609994605303772, 0.007814187321796893, 0.04244699368193265, 0.02023004359685846, 0.027628131698997273, 0.04573246133663962, 0.0567404208554616, 0.018026433817501512, 0.006027668367155017, 0.01177434717500282, 0.061583479325617516, 0.01116796464268719, 0.02434585097005531, 0.020788701724321134, 0.03108859873346744, 0.05789448634811467, 0.05400660545414975, 0.041164328839870236, 0.029182939700061278, 0.03017078709578322, 0.035357727113390164, 0.06815961637203732, 0.015934741823002696, 0.004673052547244175, 0.04511402919888497, 0.04617421061641747, 0.07491389950436932, 0.03446925664320588, 0.03140631071742504, 0.044688475017826405, 0.032339991866460735, 0.04744043904206446, 0.08683128582854426, 0.050649788200614915, 0.037030629483201814, 0.06269679660157812, 0.03254718800646163, 0.04340925374098363, 0.006854182434073019, 0.020180707534534797, 0.03959438868708188, 0.03228148956212305, 0.025973669065523054, 0.03020282106233701, 0.06973161347090237, 0.07996653281753102, 0.028682898790124926, 0.0487623927033236, 0.027198074836163755, 0.018703804929710684, 0.03921776837218673, 0.02427273553856198, 0.012093214036506272, 0.0628766970288369, 0.030254306001288277, 0.018112614878543445, 0.03969009988190186, 0.07786149940183086, 0.0967725100476415, 0.04412581408095937, 0.024640120663529923, 0.0460124243381283, 0.031018348470810923, 0.03612025272882274, 0.062409927317452055, 0.03228644232055353, 0.0647251446160578, 0.0587680564081717, 0.03214714455328161, 0.022166411264709408, 0.03762333638845913, 0.06957964460936285, 0.07935029935211906, 0.024127224798224146, 0.06782471337505887, 0.04468665172856662, 0.019924156180012132, 0.02888672031281937, 0.045752571144651984, 0.036666718566970485, 0.0800856901332736, 0.03796180935516473, 0.05821827723975143, 0.025256650988012556, 0.02020070817501795, 0.09020960333967402, 0.010824875038627897, 0.14185850808937706, 0.049287622584210294, 0.05963913668247481, 0.06878075280016469, 0.024783817690707026, 0.023354527450376944, 0.03634109289475507, 0.0025153929609880456, 0.04455086264398791, 0.032868558060257666, 0.01718567338802161, 0.024857178270336122, 0.07171699161370916, 0.05414866879882832, 0.021425590835391514, 0.017071055143230388, 0.12308381512881288, 0.014124971142249003, 0.023092425788842866, 0.06513998122705568, 0.02412854629989353, 0.024693599346304135, 0.004921539868753885, 0.08066865240013407, 0.04893419175078312, 0.019117503900141008, 0.007841024339394344, 0.05957680010807611, 0.06624510902310572, 0.057514418637560266, 0.04892691008506283, 0.05064305045732087, 0.011918590039825969, 0.10001015849411489, 0.05457613819969758, 0.006299672193915373, 0.021237230882228866, 0.05634508118213666, 0.01719772203585073, 0.020595655228281697, 0.07023528563759981, 0.04311617148379165, 0.053947038287597324, 0.03212717838675505, 0.017657920628065066, 0.04866008549147556, 0.051997604990197774, 0.03272319670706507, 0.02928231087993951, 0.0795616400277903, 0.03145485579396688, 0.045064241144685976, 0.04317356679107874, 0.03831651189454621, 0.023500110969067584, 0.003811089198044952, 0.051785440770007914, 0.013860532912545869, 0.03325732086875266, 0.019804589007230058, 0.01064394326550105, 0.042617708714979316, 0.05676518464761396, 0.008548236970279005, 0.0390730083980147, 0.03683477144448027, 0.0376961185717054, 0.04622517844601985, 0.04316350422619332, 0.03232265529673427, 0.04146316824781318, 0.007720707836861332, 0.013236211473873306, 0.03679395044943498, 0.09272917459208159, 0.13051158147713832, 0.025273945422903187, 0.06303075347997009, 0.01257079707894234, 0.005197320030175991, 0.006762486497586173, 0.06041944702906955, 0.03318387601945189, 0.07008445058618823, 0.04048793448976452, 0.0367262665813248, 0.01959244968489774, 0.06526508338509068, 0.03752651819658857, 0.06329754359960076, 0.007717157019332292, 0.048127332627172434, 0.01688347085409107, 0.023970220823802298, 0.04782937038990279, 0.05537310329776618, 0.03394466261529634, 0.0381883836892103, 0.032871794781737754, 0.06108893126609826, 0.04694273470029716, 0.040434561144079895, 0.04206464685980351, 0.04845699941318843, 0.006851381903904821, 0.06859663888932237, 0.06499278509328443, 0.01634216653333316, 0.009390553515855103, 0.10264228338435774, 0.061315620513332475, 0.05811571721888839, 0.028144651160184896, 0.005015570458189975, 0.008084438722430459, 0.019790006523591377, 0.021797041972017577, 0.029378560251526298, 0.04986711064233415, 0.06682984095307128, 0.020290014874790947, 0.0501231755310249, 0.030198170908636628, 0.012801593515060604, 0.09557707580707728, 0.04879098693509737, 0.05160515346834737, 0.006736460096773602, 0.035860196522046486, 0.0931954003810402, 0.019721981746354894, 0.07198750492065184, 0.022202647223527876, 0.02756896481338528, 0.03697712590257007, 0.028202831707594377, 0.04926768897642051, 0.05725101079611529, 0.029634157826583234, 0.028467356122188994, 0.030904666768507134, 0.04502578736132672, 0.04938736340151199, 0.036320086763871294, 0.010319596002509278, 0.031010601406676636, 0.07508200217759417, 0.05926713204732346, 0.06288028232032253, 0.031542132360740535, 0.03525667245529833, 0.0262275142144532, 0.010648439244006672, 0.02757778440061356, 0.019079446567282565, 0.05564651624750226, 0.03529007388879696, 0.05535050370399991, 0.009507549506041312, 0.02083934013611607, 0.09301396011705361, 0.062302372403322696, 0.020223878504287814, 0.07893131054457157, 0.035514411246103626, 0.030164434311671123, 0.024048220065812913, 0.012333358660520566, 0.038473785914961374, 0.042404636680599184, 0.04790879838589219, 0.04411220069854491, 0.05850014396973195, 0.01148535103927697, 0.08911934531023426, 0.025215379916311755, 0.07360543665145675, 0.054994793758998, 0.03721878833828434, 0.03274909047890575, 0.042121226283451246, 0.028740715445770372, 0.02141797975186379, 0.014445745562683913, 0.025690861962615483, 0.051658189735345306, 0.022439789740488898, 0.024837304034360477, 0.07297585027352457, 0.07029909310081313, 0.0688978723220287, 0.03168897992450624, 0.0983595148089432, 0.01371802619448112, 0.04767062165023339, 0.0321281168444623, 0.04906187179468332, 0.04546893475156638, 0.019374419146427707, 0.04292061221936057, 0.03960869537906782, 0.0062970191356726, 0.06409845022003978, 0.030453737840176593, 0.04423521526698624, 0.07234792630638807, 0.021534518962125146, 0.018984309938405792, 0.06884696577946026, 0.04677391190442347, 0.025759405764420668, 0.0330512776910778, 0.0349665166539771, 0.024483413548178734, 0.04429115883765682, 0.04022119799628854, 0.08054892051844828, 0.02939801696958321, 0.03352213448153869, 0.037413114201157324, 0.035448106336257154, 0.23244652055924941, 0.12302310266081365, 0.18239264917229453, 0.12900624934944416, 0.20737181928369308, 0.10015580713027909, 0.12292606996432429, 0.12785851174304563, 0.1353024808509696, 0.09344794126527925, 0.10392202560098902, 0.2466312666694003, 0.14830480089351056, 0.24157229780910477, 0.09276614599530736, 0.1255193848403231, 0.16940442514756035, 0.15113427003304805, 0.10397446431940603, 0.16464294355002143, 0.11203506525846259, 0.1753412235167719, 0.14374371257520493, 0.12691003360575245, 0.16725757099207372, 0.14021796144304738, 0.14648402440211467, 0.17339027336528226, 0.05841296699438846, 0.14637589875248172, 0.23079789934619782, 0.08799995295703412, 0.13344565226185706, 0.08326328494736264, 0.12214842943414567, 0.09067018306063068, 0.12385373349271475, 0.10703009027507036, 0.15484078727181882, 0.11302127322602658, 0.17486303143443602, 0.11212112757587626, 0.21580307654315428, 0.16096372968487202, 0.14845835555705333, 0.12104750746079992, 0.06493022635338769, 0.1986247805818435, 0.13228876756564265, 0.1848750651603745, 0.19370969835548632, 0.15718510825066798, 0.10122439253234095, 0.1039541629894126, 0.21186926101724948, 0.144452206009338, 0.12845758483895373, 0.11032170961580931, 0.14072236905415214, 0.1571711501286876, 0.1580684842361558, 0.1243654955478926, 0.160689577460289, 0.10762465877398368, 0.1525785143096601, 0.21122003214493876, 0.20298823353744325, 0.17287750007404437, 0.24051132732101027, 0.17028344975363824, 0.14469341645317693, 0.09776308471637388, 0.07937637698506156, 0.11481101549560986, 0.14266374310658825, 0.09694400649037092, 0.19506538286805156, 0.08875270329055288, 0.13362159201454732, 0.1502377479787796, 0.19153906483083002, 0.13642711324557183, 0.1366034513639827, 0.22216100876610126, 0.13695588245266868, 0.12753669352781388, 0.19447584756680075, 0.09362208837222669, 0.19003213924025336, 0.12371613644063474, 0.21784410331278078, 0.17065959892445998, 0.1027839330415572, 0.1280097374992986, 0.12009388887353482, 0.12564354471021122, 0.10223366740730502, 0.18924702169193378, 0.10863779473208612, 0.05529220441296216, 0.0839636348668606, 0.18796148018971567, 0.14761391215987746, 0.20665293769730678, 0.14278202708209717, 0.20342752367498415, 0.14697565366664242, 0.12776351684043485, 0.324843741592861, 0.12814050870797328, 0.21309141640461263, 0.11206770826491619, 0.19837685920778783, 0.0976447854191065, 0.11611592370055376, 0.1526322630384276, 0.2349646975316348, 0.09742905505962911, 0.14360950929262947, 0.20289801902347998, 0.1649407832132232, 0.1363721081326085, 0.1503846683208981, 0.1455603368700512, 0.2639671162732186, 0.09440559713590531, 0.17202043154787633, 0.1951723134205226, 0.09689509943728486, 0.18436341035750606, 0.12457551089145484, 0.2797806725626992, 0.1559280958627501, 0.16748641677681478, 0.18596997334351464, 0.10834703372130472, 0.07366200458378562, 0.10433228866707894, 0.17467092722654345, 0.08728909231121502, 0.14524035726583776, 0.11868548219002063, 0.06279437322049372, 0.1710364682179305, 0.16507081897749057, 0.12281114911480297, 0.1324063620620197, 0.21546100296320456, 0.09301608218060387, 0.16812945565869733, 0.17796418599544034, 0.13272719968470836, 0.0926129360713305, 0.12147237982360587, 0.1323114744117183, 0.134271418435439, 0.16922500735569387, 0.1301559787844458, 0.16608810713214262, 0.1515495662968005, 0.18294787905629606, 0.1305356519597192, 0.11193547382830613, 0.10753905610932459, 0.23754891128309313, 0.14883854967211524, 0.06640218769110019, 0.1663086944890599, 0.17898383370089918, 0.15772031259632882, 0.11246029768259296, 0.1824404837022866, 0.0874574477934549, 0.2025450363514885, 0.21317173306259418, 0.09609397831222705], [0.06793586507199273, 0.050378424536076286, 0.06851248413084016, 0.022441829449587294, 0.05674218668812706, 0.031196950379038052, 0.020510215357306506, 0.04732548754902617, 0.05946129703173234, 0.042906309357814254, 0.014809859492215178, 0.10312744686680456, 0.04983766605296443, 0.08168790940075152, 0.052230943880614736, 0.018205983759534937, 0.06942828861816276, 0.05621283908464736, 0.03128765518927286, 0.02806173746414002, 0.04294389746181908, 0.02667049115012971, 0.02355317787958249, 0.020024425597981583, 0.08015721976276367, 0.021536242659954775, 0.02075388877382202, 0.053126577272891044, 0.046334767323588176, 0.08705060914038651, 0.043520259881211866, 0.025545671063986038, 0.06319976396738522, 0.016072428890413815, 0.0526292406533274, 0.041568034193328315, 0.0683749330440356, 0.02332879072656074, 0.017951585112079498, 0.05345594911505619, 0.03107501216413033, 0.017899567742020856, 0.035696452889110775, 0.05341547285957683, 0.030350398324850588, 0.03716347295971167, 0.01256400475188369, 0.12537233426325745, 0.07361774002352069, 0.06246665995868464, 0.025717766970516216, 0.033986778298933665, 0.00737167674214429, 0.06671261417889787, 0.013341494937307172, 0.06504153892878564, 0.008717897674819876, 0.07194239766367021, 0.028201747693181522, 0.021996979428935918, 0.03859756274088737, 0.03845964393187915, 0.02318369558892183, 0.017360469754484874, 0.05236494798032988, 0.0556468992914644, 0.053638239736638726, 0.05191652224429193, 0.05060873354875273, 0.018891919734737566, 0.061452279107705246, 0.05894369738657148, 0.049374508446142565, 0.03296815715129337, 0.0832640280526492, 0.05792600320531957, 0.014523909513598249, 0.007562850153208861, 0.035952743773739186, 0.010405512763217334, 0.03191205323673785, 0.045933574738521735, 0.04695295814364668, 0.04721661496366705, 0.054430922403210596, 0.03930226787023487, 0.06666868669731964, 0.028878048197516513, 0.03363165824163345, 0.023099301427963282, 0.061684905536352634, 0.06058669168381922, 0.018385700325691895, 0.02961519140479786, 0.06766746616772107, 0.02349441510535056, 0.04722568161425091, 0.1121315693542842, 0.036156741496656215, 0.03776745284877477, 0.06826875325773032, 0.041344600819772294, 0.03160430805667514, 0.05867607606154296, 0.065988477229351, 0.04672985035745848, 0.015726800662495436, 0.07493905017092344, 0.02657587163060183, 0.05896047854255285, 0.04675063049240459, 0.04775397967727435, 0.07733919597681492, 0.04454960625979208, 0.05061401572499064, 0.004407797476291777, 0.0311837334471244, 0.05559398559853435, 0.045566392626853726, 0.03398045041267911, 0.04750952485107607, 0.024852780925650752, 0.04830503438208853, 0.044078596251746344, 0.04016050851092704, 0.06432035141774724, 0.03760624113642881, 0.029284748954758532, 0.04707210013763078, 0.0037792970279922652, 0.0892566435880238, 0.01256701164698649, 0.02102831870527758, 0.041441020645922234, 0.027302718616180846, 0.04345254920002434, 0.0812966376543045, 0.019851644042759173, 0.022623244815716342, 0.031137827543481707, 0.017225237998871074, 0.033545641889495235, 0.035876759342969425, 0.025600517213705088, 0.02978866243915212, 0.05707551537442112, 0.12264549026205657, 0.011416125419219176, 0.0562537060449681, 0.0626000588489396, 0.11589323726272392, 0.014332896023387871, 0.03815593986561702, 0.027443958416340813, 0.04683684219696349, 0.06686145740170633, 0.07391946375249855, 0.013444086559297097, 0.051302226981328386, 0.029694586842050476, 0.0773181821850519, 0.04416595708819167, 0.043017169941336884, 0.037804316999691154, 0.0010429063742424572, 0.041570163917757814, 0.0062098124744220376, 0.04786974705395199, 0.0277192693489093, 0.0951332810725416, 0.026597082690005342, 0.031490808300253366, 0.003956214739798358, 0.008212267195865994, 0.056954128742818876, 0.03588557318453828, 0.04013091070397247, 0.07367105208217137, 0.05312938115469391, 0.04005774930720368, 0.010311647840294867, 0.025506635053804325, 0.033423512152606444, 0.05357400326418781, 0.09700479556716259, 0.11065750127477993, 0.028683996211076458, 0.035615986843983975, 0.01038071736993809, 0.053248856396925066, 0.06580229488111312, 0.03500671711780372, 0.05718004041080994, 0.01974507929727195, 0.03137683931497797, 0.03138486025554519, 0.05607642180797073, 0.035727452636966785, 0.028156115665971756, 0.019118641540708563, 0.07058896544960237, 0.05971248577078504, 0.033774058664998705, 0.020003563108583613, 0.053470198350447806, 0.04385040547218054, 0.03184568895507724, 0.0398709770712641, 0.018995761037653974, 0.025791541237624425, 0.03213175576210263, 0.024954986630848823, 0.07174568160647346, 0.03445897191282242, 0.03488654090512184, 0.13457739395239662, 0.025388872018083933, 0.06926311240080865, 0.08776118633367362, 0.037999631115986456, 0.020530530093838612, 0.02590233670367349, 0.06741898554948068, 0.03673314222044522, 0.015003355107300225, 0.01915908332223133, 0.07166330417197558, 0.041189464184665875, 0.03259354781719946, 0.07562854462453435, 0.03903823949757122, 0.08517027697375706, 0.0755111646327761, 0.13774161287132772, 0.009575064834808151, 0.0846388264589252, 0.04017129119846129, 0.06226617474890044, 0.021458883101360935, 0.07205585528525614, 0.09089562741498794, 0.08825191161445073, 0.029685855354933493, 0.05787663649947894, 0.0589349486624762, 0.036647014785557985, 0.06321779001624354, 0.06171223189261171, 0.017405385489485437, 0.026381645359159, 0.007192137333819824, 0.020574428847119696, 0.04759538798562942, 0.06232375774772898, 0.021335236510382067, 0.026109040632183035, 0.08130349414122683, 0.016163461203236255, 0.031243216344005162, 0.02837166216434731, 0.020872504082358172, 0.10592867034457384, 0.0932783906858775, 0.03142195423283885, 0.026674773581626437, 0.05580479001265861, 0.012462329562573184, 0.045611419444603306, 0.007532881272415961, 0.020220559428355867, 0.021628630948403192, 0.060132390053402034, 0.016182086715895324, 0.0616804086002371, 0.041760839371671604, 0.04333072206786564, 0.04832411380184274, 0.05733600442087459, 0.04841138270773715, 0.04308903281907401, 0.0547141642610152, 0.05937001765555432, 0.043595225415042335, 0.07318448665882311, 0.08384420175946529, 0.04148584061993226, 0.04235142038293904, 0.06194753962899409, 0.04460718159774139, 0.07686253607032761, 0.08016208442108286, 0.016983673239367145, 0.08601544049358176, 0.015720623120996022, 0.07875784525587674, 0.03303551160159611, 0.03844341052876365, 0.01156347955862481, 0.03524914564144227, 0.05263701644575885, 0.0731924846167526, 0.04426455260404656, 0.043081816270827286, 0.057096755162121794, 0.052537719959453236, 0.01814079733805791, 0.006026092620055762, 0.04510603124095548, 0.03095141728408635, 0.06603431993073995, 0.04580783672750958, 0.023434656416817058, 0.02749071276235965, 0.04650629440983457, 0.02256467930912491, 0.059933567254413525, 0.036244121485299645, 0.0643405148519143, 0.033363726650995594, 0.03990730496063348, 0.0483224782041244, 0.005892939835546479, 0.04119222593163291, 0.06386773518076347, 0.05383058143178782, 0.03704154623612281, 0.13198338959726597, 0.055073945963334654, 0.05164110597463385, 0.036020477437564445, 0.02750122157346097, 0.012538315908562754, 0.045950516772967194, 0.010280303352872932, 0.04852489778591741, 0.012932273750794272, 0.05387472341798487, 0.022785146007194154, 0.0351855258697704, 0.030777712592915184, 0.03022760592190729, 0.02579865244878156, 0.06502421001993841, 0.030711675813842206, 0.0459957619257752, 0.02327429889250667, 0.05303040642531649, 0.053990881499503894, 0.03108041882965594, 0.05720254424358568, 0.012998350749483273, 0.05025786910987189, 0.14250795146630657, 0.1406460513751353, 0.1765274034152108, 0.09447348018687579, 0.1916800709741731, 0.0857218066530843, 0.15201265112526957, 0.19046571436187915, 0.16767265275120738, 0.24776555177184845, 0.09741369499674729, 0.19218146019885618, 0.1886793811835589, 0.165531360394051, 0.15227290651490613, 0.09302044122089302, 0.15957372443329904, 0.1291221431306293, 0.09363462157066792, 0.11242513424686848, 0.12079488230688919, 0.16723759141900849, 0.1784224904352619, 0.0783935398043644, 0.14125110761773202, 0.19599061789772204, 0.20780118092173533, 0.09754497948433123, 0.149691634541077, 0.15563897428012666, 0.12598807743239787, 0.12006035720508908, 0.13650378332503382, 0.11417590562374362, 0.1625089596716627, 0.20762655884027484, 0.2876234210787281, 0.08584595886209319, 0.09069262177593286, 0.2481895814379377, 0.18895837508382338, 0.21988022711969193, 0.16595039516687393, 0.2608890669240106, 0.13462248588761977, 0.17692131050411733, 0.13996726683070584, 0.18045495234189496, 0.15263434679758164, 0.1645991079989941, 0.1944199078265698, 0.12020406763880484, 0.1632834592413518, 0.1544021559698928, 0.08930689129497736, 0.1851129354608636, 0.16370425601640057, 0.2885600401749534, 0.09292376092484883, 0.25730846389647455, 0.10508938271912838, 0.19888960185550875, 0.07870700000034225, 0.26605945561201344, 0.19526871792491407, 0.17767275082728556, 0.1293308101594448, 0.21505283131714792, 0.21415356666811053, 0.14512867696823614, 0.16200502703507103, 0.1117817123210238, 0.11797888099306053, 0.16760983354141637, 0.16181517512567584, 0.12869325646710011, 0.15431659927050914, 0.13564817036592192, 0.09695284714501712, 0.06480310938411182, 0.22992019241134967, 0.13717429411988105, 0.11339983557380977, 0.13903096949140872, 0.192595852478858, 0.20039566942761022, 0.2251658201097481, 0.11233529511598811, 0.08512440362885114, 0.14037910037704054, 0.1741934399450979, 0.1809810862065323, 0.11525074996414686, 0.08337936258964962, 0.14928402980008434, 0.16263570125785567, 0.08736748608850664, 0.16053714128511568, 0.14455460132129733, 0.12541608554461312, 0.18165173489720593, 0.1291579194366932, 0.14350624064043646, 0.14303331924301965, 0.19421272700832737, 0.11122515710491328, 0.0992852861001607, 0.16172730484076087, 0.11811461645148455, 0.17488009987338898, 0.1846952490027874, 0.13533385981234813, 0.1415354028464325, 0.21090800453337932, 0.20507141046466368, 0.11210700857543177, 0.11751998666553728, 0.13405207214095902, 0.15160389725239048, 0.19315249196464018, 0.15126737014901254, 0.19270630703578073, 0.13454357883141888, 0.19708569462020553, 0.16418911306367767, 0.24251374325925307, 0.09203329096518217, 0.1319135223785716, 0.1208131918082795, 0.10691977361397398, 0.1578624525497998, 0.10133306210440013, 0.15261721707159473, 0.15505826431176356, 0.09287506071550232, 0.09994992866150795, 0.12945664776188712, 0.1828565920192388, 0.1211292413814414, 0.1613310994880815, 0.10163676234022265, 0.21443573217238152, 0.1291344158591763, 0.14269860010714303, 0.1059565099797422, 0.16293404653908747, 0.21926291347030671, 0.2395471750247863, 0.11038463607790971, 0.15579047582803235, 0.29455847797855256, 0.1364527005822428, 0.1731251150129303, 0.17825133107121915, 0.12183518374278662, 0.17674697953606808, 0.14914389699697495, 0.06605051502945923, 0.2684902525957554, 0.13459907424065376, 0.14272616395065862, 0.14866967325008687, 0.12208270675112164, 0.11657711629184986, 0.08382788408667811, 0.14222914142714393, 0.14478346242779686, 0.1648942510327024, 0.1243145966662034, 0.16260830595368342, 0.19083973380827135, 0.12116898602295308, 0.2735633787608916, 0.1846992786252691, 0.12377432081848384, 0.11473268300535218], [0.06998510430416754, 0.008465343384042142, 0.04810610433079062, 0.06039914952951574, 0.016824167987872517, 0.05242343113246945, 0.09884807972177383, 0.052091492895757964, 0.04293186605096825, 0.014042575513162922, 0.06182963869744732, 0.040996781580390475, 0.06084319324262681, 0.02838682879002825, 0.025106239200179136, 0.04392378520400774, 0.07411840146467571, 0.0545256530054875, 0.07114883782642503, 0.026293415012919617, 0.00978008336988428, 0.026309418589657834, 0.017518640097771442, 0.024049049355990948, 0.02836726865010156, 0.07610625407147793, 0.025125249672020157, 0.017447349870757713, 0.038302189880801786, 0.013762054225099424, 0.03948857279254064, 0.04158169354101823, 0.009063673374663678, 0.01878650029069714, 0.024902680062598763, 0.03145268584992136, 0.02417886103954046, 0.04926374745405009, 0.0584432389587164, 0.006318671174437529, 0.13440805787761367, 0.03741260475268768, 0.02834820646732565, 0.034755401974243504, 0.012865904681084138, 0.06893154188630081, 0.026336461493384936, 0.03441554621883458, 0.02025131785851573, 0.012357307526643478, 0.027494186971096263, 0.01130860114860679, 0.009531077981415776, 0.07073975453573851, 0.015395677351813405, 0.10146484454913486, 0.011902308756215198, 0.022254779506775162, 0.06771814288391222, 0.006522290641441942, 0.07050631222345176, 0.017384446391295043, 0.01619673814744719, 0.007738881357645075, 0.04813455300585878, 0.01896545842980906, 0.028175892225737055, 0.05610033141208753, 0.039779766642999266, 0.017195831713897568, 0.04708954395966665, 0.0050445328909723515, 0.017697992772164366, 0.07028069932975116, 0.015791681606412655, 0.007190144547606789, 0.04706247807330182, 0.043623827307695345, 0.0497826264660445, 0.033003914305159164, 0.0924713860055612, 0.05579490364799577, 0.019918343487886653, 0.020059160024468458, 0.07137414428495592, 0.023801216082046592, 0.04761451720109871, 0.03464920686617975, 0.0422668481065381, 0.010234525768957552, 0.010075998237176288, 0.022629536312794494, 0.016978159321532134, 0.039419057974291426, 0.07223537266855279, 0.047776609914557594, 0.05676364864132578, 0.03479306285660114, 0.030710185772829482, 0.04879472927460748, 0.05573199250765386, 0.03580455172566637, 0.03157719428981504, 0.039404111598888715, 0.044213335795868794, 0.003290650239514728, 0.02769762928026819, 0.039533166770613005, 0.023590124384950728, 0.03287517322948383, 0.02762093430294866, 0.03929941802315655, 0.0179548065118011, 0.036527650626075846, 0.03487764662432094, 0.05367637176306979, 0.03554747177047595, 0.02625972438122957, 0.05282836988748563, 0.029902001317109794, 0.047884260589677485, 0.08238868066860784, 0.1080988671991133, 0.03198159678328422, 0.02863241168069503, 0.02579920403208704, 0.049947128526025245, 0.0712715191466193, 0.033510727432346156, 0.058172756295290694, 0.026512790035696763, 0.08423937289344688, 0.06012416609953489, 0.04265105652232324, 0.03982293952797209, 0.039383113128884185, 0.009524797018046581, 0.029333408944489017, 0.024245497282414187, 0.008311833728164917, 0.05743112955843249, 0.049385333268512646, 0.033491502455886335, 0.0764169103856529, 0.02078159434360362, 0.021602748667881377, 0.08451847404602074, 0.013768973914275487, 0.034926120837729786, 0.028196752799915212, 0.03692444969689654, 0.027372836728670427, 0.07366166750509894, 0.038139748597337354, 0.030987076761741793, 0.03593552594764098, 0.03637548641211564, 0.007666472163456943, 0.011329341063936873, 0.08392592035834828, 0.033333535125899705, 0.04418420147210841, 0.03330869855539453, 0.01072915043726924, 0.059935620370050596, 0.013240567641332747, 0.053918520664615985, 0.046241840858372955, 0.0475410646909187, 0.03982041909870121, 0.027821865758948752, 0.014118800304018924, 0.025116922296283227, 0.0630913203912637, 0.04977769285981214, 0.08821608934311137, 0.043612056366738775, 0.05523781983121749, 0.07766731143478425, 0.05941930392216291, 0.06340517129208292, 0.02717323443521896, 0.0830164897225557, 0.024528329283179297, 0.029827441809879198, 0.03756324062123895, 0.03672142873608297, 0.03986654525262214, 0.06411609705537558, 0.03338657139289764, 0.07485495669947517, 0.05598215468888802, 0.029470632528705947, 0.0015740014960981847, 0.11839124314006298, 0.03640288171628791, 0.03274809073416456, 0.021498811603974433, 0.11206403104287964, 0.01830732761581819, 0.023650451893768003, 0.056373441757093516, 0.056948632061962164, 0.04942224338470448, 0.0026569032859462766, 0.06285714263456964, 0.022732527258114952, 0.017597729099854346, 0.020702210397669868, 0.06408572166917786, 0.039134889150098454, 0.0805761626050357, 0.08560664831630646, 0.03779415484337557, 0.022410438996889902, 0.05863769122609689, 0.017275284607744506, 0.08986567582694754, 0.04517796306660579, 0.061547473193176334, 0.05961767472927609, 0.025695395287907413, 0.10692540436021744, 0.05438214175463204, 0.05117488784655448, 0.03764110962830244, 0.054007869499224814, 0.03702143642811045, 0.05067117354502121, 0.0309976545207563, 0.03521421203209508, 0.06986007109404573, 0.034459446887335474, 0.06399970148660003, 0.01367065227485352, 0.004813763746736391, 0.050342391590557756, 0.018882000811337944, 0.018195517083269455, 0.03782289080141533, 0.050988563772050605, 0.014955763810224112, 0.01901702380799238, 0.11368591578737383, 0.025737840389352173, 0.05145754364709701, 0.03966269691685035, 0.05756802564006179, 0.01975458836363208, 0.035305836147839026, 0.031034085831995455, 0.04145250813434682, 0.03940769689037435, 0.06249918805194959, 0.045688070371867194, 0.04006556340403134, 0.0839735097402046, 0.029229778315751787, 0.005705489611793911, 0.0364267913204047, 0.07430792395626346, 0.0016392170049760852, 0.019282584356504585, 0.01771415339692706, 0.08828423286397612, 0.025895989665220824, 0.016898051422509937, 0.008531663615647103, 0.058743185363709934, 0.03526933205824706, 0.06987893983962075, 0.07619762537820686, 0.06247648886675316, 0.023761515490590565, 0.04599078235426738, 0.030477990268639503, 0.05171250536917679, 0.023476565256714824, 0.013662487692800502, 0.02074084612691114, 0.025324627884753773, 0.036698951716384584, 0.01735931296171921, 0.013513608080815646, 0.01615825180535115, 0.016010320227172588, 0.09336004799772656, 0.03537993217187543, 0.026645214079068075, 0.03207648060314598, 0.0033784206935970657, 0.037041710945026535, 0.07341838862386442, 0.008099447342477018, 0.03654142105651479, 0.024015429587433898, 0.028224475606675112, 0.037415017929649165, 0.0388270826830018, 0.03901696140547434, 0.059197460181049766, 0.04792028204387715, 0.035740786397288886, 0.0630272486277165, 0.029164842788069963, 0.09292995091527702, 0.08800805050639376, 0.05663120736097617, 0.07575579182875734, 0.045771095150661086, 0.06831463426351547, 0.03197007482090304, 0.052604147443367597, 0.066811500808164, 0.026403295003899166, 0.06245657441116149, 0.021156278371270147, 0.046703094736702984, 0.05089273766404198, 0.03517287392770091, 0.04715565351709243, 0.03118689355981206, 0.09160068111434098, 0.047336530706454674, 0.03083197651581178, 0.1067964641016818, 0.1246883096774259, 0.07741283234809676, 0.037961361193729025, 0.03219663766362975, 0.011140205446750888, 0.02101160458198959, 0.05364374790881431, 0.04187041675792106, 0.07228864642280726, 0.07078123819683829, 0.032392434415317355, 0.03280275876844122, 0.06591347722156395, 0.023132145532496998, 0.0670996647808821, 0.019584907549283197, 0.05991739896877159, 0.027856600185435627, 0.02573084409138368, 0.035132091237051834, 0.024432865151714896, 0.036935416245532614, 0.08576626273533029, 0.04662910596497598, 0.03420932301049752, 0.09699485940678466, 0.1545059455618743, 0.19075777772213184, 0.18852901344578113, 0.130620519179971, 0.1512092853625936, 0.21787460893392566, 0.20110120576235557, 0.15398943376156593, 0.1860055657884767, 0.1492148673822803, 0.15578028685863943, 0.08572857120945569, 0.2095197306405152, 0.08992048941792981, 0.12208494372786054, 0.23565912559147806, 0.15636580785916698, 0.14389803332667198, 0.22683124929185838, 0.12034046959372298, 0.11777279568054985, 0.1532961395118506, 0.1566810530400084, 0.10443518193618906, 0.06216402458507688, 0.236961858106717, 0.22175328145104073, 0.11907729785889389, 0.16308622224436653, 0.1083627078802355, 0.1263596300756739, 0.1002215987612163, 0.07955497506284907, 0.1386042585175845, 0.1255588000640273, 0.30448841772252516, 0.1189841645499391, 0.18678774155916708, 0.18542188339896742, 0.15149103717938547, 0.2673212024233034, 0.20268998018676238, 0.12262037789989864, 0.19278614871924926, 0.16940684598540107, 0.11487447821925725, 0.33000202609166024, 0.2209797777956532, 0.0840940153706939, 0.13791942187855322, 0.14109300239191902, 0.07602418307214975, 0.12408961962547996, 0.13611268011793015, 0.123947701837507, 0.2055954452483885, 0.2808033386545797, 0.14766930031680292, 0.12977806761139823, 0.10015397618014006, 0.12834587389783514, 0.18687456996450502, 0.1459181918612411, 0.20120623641677443, 0.21426733072486617, 0.1155644246647435, 0.062158753900157834, 0.2133157729141174, 0.1160162250180879, 0.09428621765466468, 0.07930644847933324, 0.1686232759346885, 0.11180339260928093, 0.10994867076196017, 0.1359402184044161, 0.1110888011152706, 0.13853606137056507, 0.11318205209869532, 0.1716583783948614, 0.1366596822176249, 0.2437186310248029, 0.16875743325198853, 0.08220915562443196, 0.1040352227526807, 0.17349731117006273, 0.1853757036188918, 0.135534682100819, 0.11671993806357346, 0.21788133518590083, 0.09207009382906461, 0.07961815433396448, 0.09390328860571308, 0.12093824800103904, 0.11523640113732508, 0.22517916536138904, 0.27478602444452627, 0.19360940212443953, 0.14007010647366125, 0.09951572534778427, 0.20309308033076026, 0.1088463621694715, 0.12318004343298175, 0.12327929778445153, 0.15276821300147042, 0.10124149161481089, 0.08279014138444778, 0.16314956239394604, 0.09482881474879482, 0.09571228266483355, 0.10266887429620951, 0.14442758394345162, 0.07238532671885145, 0.07785255915575451, 0.15941105332345734, 0.1392147693062021, 0.09724458874834162, 0.2194151811061367, 0.16833822993982225, 0.12337376408639456, 0.10464575652393604, 0.1331063212766763, 0.1776412952571146, 0.20218278401561324, 0.13819640862845606, 0.15016181334372491, 0.15822709507999883, 0.19216053067676483, 0.1341220159684458, 0.10059964016921098, 0.171444256820025, 0.15751348417853156, 0.23160710269885681, 0.15959468459890735, 0.16244756538541089, 0.13695048919368175, 0.09077382709590659, 0.18017154577518665, 0.13233569811188406, 0.11701560969794951, 0.13218172976086218, 0.1424496674970273, 0.17847823099263255, 0.07030944294867016, 0.19865286536514762, 0.12836916297073328, 0.11018239652677891, 0.2243439456628215, 0.1020677021193889, 0.09895334020256998, 0.2284308561995145, 0.23177283816039565, 0.19020003506973868, 0.19751566912858717, 0.1154418659186171, 0.18690147497240575, 0.15916323920171108, 0.08822719761801344, 0.10678294264981825, 0.15724144635661957, 0.12798833300269422, 0.15628035841209276, 0.11396150825725448, 0.07968848120541343, 0.2181892718879446, 0.16172068584109509, 0.2005381771032849, 0.16716521143192248, 0.13797292545918496, 0.16034721276692807, 0.09964407571861822, 0.12760011794706508, 0.12103128171856366, 0.17303831725110932, 0.12938158646706613, 0.15906658954918385, 0.2097823302592001], [0.016620074503964955, 0.06355600634349451, 0.03141423398178191, 0.07612125407303534, 0.022018853154393937, 0.030729282429561983, 0.015218533883472125, 0.022793806631178148, 0.06970237955571183, 0.02496104447111007, 0.0467140497940202, 0.04960647603917507, 0.06572376320799513, 0.027469614700924967, 0.04369733344403006, 0.034540587089835637, 0.005522206906349429, 0.041208126086501345, 0.05532770875781294, 0.07225070974879688, 0.033567486886656096, 0.06782281347700665, 0.06782901112831409, 0.03125183291793351, 0.0191485898328885, 0.05238169466235465, 0.05778891177126958, 0.0369360750811475, 0.094259787621277, 0.00742029459703894, 0.024991848866545388, 0.047154672924549355, 0.046440663657361464, 0.03744757666643109, 0.0038904980418362446, 0.03168548656357152, 0.055441993754357106, 0.043912853129328265, 0.02001833328376374, 0.016382307625345646, 0.046093671792937864, 0.011562367773524696, 0.055766290264023896, 0.04837833367468369, 0.012479684326887853, 0.06192158073967984, 0.06994694546465913, 0.092322550443632, 0.021216356901512034, 0.04252705753089921, 0.024076165038070852, 0.025406704629741372, 0.00940689129845029, 0.02197125994209801, 0.024635148752901345, 0.014219353174520357, 0.0166778011442793, 0.022564639089508884, 0.02763113667888026, 0.03255965991786892, 0.04024104733440665, 0.04243963540741994, 0.04796245901454841, 0.05116749509808518, 0.03329625728750422, 0.04216649058845736, 0.01933922506718626, 0.025040960848151196, 0.03876733165534754, 0.049796630553300344, 0.052749003178530166, 0.06453585195084734, 0.10393396125084932, 0.07393556692066693, 0.03137518264984172, 0.03896921497559355, 0.03623063067695306, 0.019734545588313092, 0.09229242786644928, 0.052128456638104496, 0.02261065224546098, 0.01638871020517282, 0.05023865562473094, 0.05553965081250476, 0.03563636861320946, 0.033254141603866895, 0.08616136492139871, 0.018168585262291374, 0.01569281221412483, 0.08358160214078042, 0.01853933542846672, 0.013074587031658138, 0.019457786749567718, 0.06081165340278418, 0.04055102566076864, 0.027935053334541382, 0.035403339988401825, 0.05569821186063271, 0.0695802957840985, 0.04133006813184869, 0.09172348500860315, 0.03771799421238323, 0.022416154012805032, 0.007761962629193741, 0.030809677611555786, 0.05180704444947262, 0.03160741262798829, 0.07591009725846591, 0.025784803494330377, 0.014953829438215303, 0.01399937485750284, 0.05911820838528295, 0.0466547392669224, 0.0585608602681708, 0.048843705275606726, 0.03871024278323016, 0.06658657739359526, 0.06057040465454902, 0.06557694245730677, 0.04915758681994292, 0.003768338379637909, 0.07996607316477645, 0.03134307973537474, 0.0726372240892341, 0.04888439603570489, 0.027633377486058784, 0.017256867854044806, 0.019754172760933157, 0.10440915026852202, 0.020784208618645227, 0.020497134405999415, 0.06334214140811274, 0.03750460808195415, 0.020728454654735905, 0.02578090410679579, 0.04697928092472496, 0.035456077481109294, 0.03327310994087208, 0.17706755668886248, 0.025911380371619618, 0.09561539552504979, 0.0347426044754684, 0.0295868672190174, 0.011328621898897955, 0.026125044208921255, 0.03502358254345675, 0.057953892636203, 0.026551343410486178, 0.02100154584754379, 0.03863843736208735, 0.03868519170810619, 0.008252759730713743, 0.038989703997128436, 0.018452210164058114, 0.055589381410109426, 0.026420892043519887, 0.06220232132041167, 0.036407133504267664, 0.03191884269096679, 0.024492074172162724, 0.005393783757162671, 0.029646911275302692, 0.04018116224136564, 0.010125408035462663, 0.1553140763914393, 0.046941608551048467, 0.04520441225219158, 0.04285803815770534, 0.03777216811994872, 0.02254042305022238, 0.05020695873686383, 0.017494209553866137, 0.053143147754693226, 0.016604812117293477, 0.04727758407112091, 0.07142077605690687, 0.025207182775521954, 0.014454416720376862, 0.03845895828318693, 0.01445843963958924, 0.04118848359212279, 0.04082584438184577, 0.030736202118738048, 0.0607698135107996, 0.04935276304041186, 0.01678812546625493, 0.06359857401900715, 0.03911351912745065, 0.0067910175271061884, 0.0472001402428554, 0.006216680452663211, 0.048937899616336634, 0.06542318861090368, 0.015981640768117242, 0.03302843294917576, 0.038141725104182, 0.022939924496195974, 0.10218112143657862, 0.04664347777443548, 0.020285008490205775, 0.015120118398279434, 0.0327192475238154, 0.08421380853941364, 0.05049464390462926, 0.06749090588381214, 0.06377211974693403, 0.027753609240115173, 0.041272672824561596, 0.02320046525358433, 0.03899716952395055, 0.05189744665497734, 0.019115634645605763, 0.007780475143883979, 0.05347937225334106, 0.036552697870760195, 0.04234099392628959, 0.04438847115623855, 0.023256209641394597, 0.007818052714179841, 0.03649406916191501, 0.025898360707346472, 0.03311415435746312, 0.017376479076882525, 0.10474439034418714, 0.030111940051879615, 0.050017800137040117, 0.0663886968827536, 0.07831263325868115, 0.03821867863617597, 0.0324603098054086, 0.02279791860811172, 0.04065172408797568, 0.05185939123733871, 0.02407502931272311, 0.005357017282456641, 0.0011403522794059808, 0.07674209172687224, 0.02866007894608042, 0.032063769289262356, 0.026343720176467494, 0.024812251044016694, 0.08051172694972447, 0.012269488952663398, 0.05057855734541532, 0.008097871116572812, 0.0009493211931135926, 0.023871259500963554, 0.015620658222976473, 0.032892287633712256, 0.007013169618608851, 0.019629549407850833, 0.04005562724365343, 0.032361924963732885, 0.08888651586828694, 0.010542999690158233, 0.013487283384517558, 0.0399532510838922, 0.01888394858988543, 0.016700856560360522, 0.07105054874573985, 0.007423056344005971, 0.04644427576192445, 0.031067535145989353, 0.022549459057289268, 0.01823791621943876, 0.13390544291225173, 0.019581781910552133, 0.038592744047843644, 0.03901449460235815, 0.03173683935235585, 0.041671061527825175, 0.060031013638382, 0.019305210763348207, 0.06563637555847246, 0.017488513690149112, 0.01014677327006094, 0.03383260693461184, 0.03803393653323574, 0.06919027276096806, 0.014328158727186102, 0.03484792241285886, 0.06139727399474191, 0.053648428706031655, 0.06259345134059269, 0.02169691236509431, 0.0019233033550159647, 0.10238961226517156, 0.04539184715418566, 0.04509355166866895, 0.021206254117010583, 0.04017729732778765, 0.08174928070436563, 0.06839824509957144, 0.06296091690479268, 0.07581716313237145, 0.04471102098543798, 0.01752686022119897, 0.045747220020500884, 0.02149372094971759, 0.11405323962530783, 0.06371728317331403, 0.05651047956498881, 0.07357575840527013, 0.03484925540584711, 0.013858769952710119, 0.043049414582069845, 0.05465257079190305, 0.02708265794471147, 0.028229154488672654, 0.012192111199481354, 0.015762418962924952, 0.013263809791345511, 0.03687654238855166, 0.022262172255244468, 0.05247151847147653, 0.036156029034886634, 0.012084119615235157, 0.027527837383170283, 0.0400014839796049, 0.03778921740670358, 0.07713589156346937, 0.04197198852536179, 0.030266308683841944, 0.018008773575627038, 0.08346851990227738, 0.05504827818743164, 0.031707180258367336, 0.028980098769909916, 0.044772074362563516, 0.021606351196345304, 0.04033292042872599, 0.04303281728719031, 0.051164304341880545, 0.01562480275864683, 0.0067423417368122655, 0.01599505209484168, 0.0779610142231949, 0.06035599579674102, 0.049093480582439133, 0.027732177930433425, 0.030183900605827093, 0.1041736931449944, 0.02307378878486493, 0.05058201240195383, 0.010239329140242791, 0.07592722698445283, 0.010931802718269249, 0.0481216176112573, 0.016620258365066785, 0.006152512928125479, 0.10654214589345841, 0.019291455654667753, 0.08758798917575229, 0.15314077688080652, 0.06443914867216541, 0.2091634078251739, 0.13739567820823964, 0.06187064355359443, 0.10034673922364751, 0.1281217395538284, 0.15522488843529456, 0.09621017086770266, 0.11527429184605999, 0.1988304751895128, 0.2221156257174669, 0.07689014587911867, 0.1434383805721037, 0.20137356534119577, 0.1387365925456247, 0.09368601074862866, 0.08887988154686267, 0.14484759930881763, 0.13644056574952218, 0.24473576596187008, 0.1163425095259182, 0.1427922926602825, 0.12945151497279445, 0.1282315735795325, 0.22778035562124946, 0.1760540530085564, 0.2116516154379614, 0.10895778965805808, 0.20205887695474012, 0.1478046374095063, 0.233819886381107, 0.18330912015611128, 0.23187471253256645, 0.17497071275307288, 0.1952406791068854, 0.10623348140788656, 0.09136700897567696, 0.12780018180849093, 0.08622313459073344, 0.10344708939233135, 0.18094054483357938, 0.14151076545878766, 0.20471888744542677, 0.15109873887511993, 0.2023018494008049, 0.17467716318224707, 0.09929139948179645, 0.12239147848900288, 0.10775765163763877, 0.15677620116020405, 0.10692471488108558, 0.1285562493027218, 0.16063535375700844, 0.26919937422198637, 0.12083075820438324, 0.10599162745019121, 0.08453610172915844, 0.07928612416670208, 0.19067471846938136, 0.1794079706192978, 0.15681652802853815, 0.12384122327691126, 0.11297406688813241, 0.20375200787619238, 0.14671775782781263, 0.16048615047287557, 0.1118893476743852, 0.15828858129680157, 0.10758459237554382, 0.07947293470703787, 0.19444327350826035, 0.16107419956355326, 0.09893354449060657, 0.09692660097273127, 0.2591496183266563, 0.13152457953941438, 0.21084795856187422, 0.10235556731781653, 0.10259866999882845, 0.13880673555597184, 0.16386279025145117, 0.15202002089110114, 0.11157997838792302, 0.1172127471035046, 0.1523183814940914, 0.12109663667938403, 0.1033007359552768, 0.15575416326042146, 0.17279465532591268, 0.06693719285390069, 0.1887797693451566, 0.18239724569984023, 0.09622260447471373, 0.15117102693165504, 0.14237601580398698, 0.12757437739280925, 0.1398722412845781, 0.08504537399858238, 0.14494084753096104, 0.11382971815164052, 0.16529185066540397, 0.1184034699033345, 0.0912370651419605, 0.1812311066615005, 0.14996201761307257, 0.13696665364888408, 0.16310450110223987, 0.0738376455621854, 0.09885538053969223, 0.147420612854823, 0.1594655987836661, 0.12568478322317525, 0.1595641789777625, 0.14267767058505168, 0.1344080119123382, 0.12859784787701023, 0.21011882671906104, 0.1495595150176556, 0.16969745377859763, 0.17053026796108292, 0.10765221495662006, 0.1398137887759555, 0.10223658620229653, 0.14161438651142583, 0.20195554701551316, 0.12155350853478718, 0.2631329384542281, 0.17628804690414862, 0.15730544534181395, 0.10555391545377432, 0.09143888334473295, 0.10802470988804296, 0.19824968861235728, 0.08384361953264283, 0.08679662801084981, 0.11661850802239873, 0.26839485932742396, 0.0938417257801179, 0.16742807152050157, 0.13534225613599823, 0.14935429538449935, 0.1659430100792839, 0.11404090560972692, 0.1408729512965487, 0.11254210055114762, 0.11638332669052387, 0.15562991912086166, 0.12984669376765529, 0.13223463579291297, 0.14809686930910235, 0.11251895703495511, 0.14198785437451256, 0.16967851608510942, 0.12492611869088105, 0.13713232782338897, 0.07921732947110169, 0.11093854062980223, 0.12771283246336446, 0.20588000094698322, 0.1670941491160662, 0.11018205178721298, 0.08071454872767772, 0.2536183562610419, 0.1625203743817345, 0.15481654824989458, 0.1643996953123039, 0.10166211985051633, 0.10210294982478504, 0.07893535548881178, 0.11622677662319715, 0.17792488568492476, 0.060430788960788524, 0.2263079193090239, 0.21923236188388642], [0.04595235155354585, 0.04019799702350171, 0.03502193162397992, 0.03856221544406107, 0.014925145191110432, 0.0353938328372615, 0.03749281798879947, 0.02892540583777572, 0.015772765937952266, 0.022994776391574455, 0.015937858843244612, 0.015558408791079156, 0.039245370520098556, 0.04593440594391958, 0.02426587905163967, 0.12020915446262206, 0.032238661416716156, 0.045062544259933696, 0.10031566669743869, 0.060269929648887735, 0.022590500302612785, 0.0623186594325929, 0.017640363808060368, 0.05148031178020662, 0.041595984911245686, 0.04739484914969053, 0.024645199826467904, 0.0675112301964433, 0.05335868659218954, 0.0184092900881003, 0.0441202178086725, 0.03382336791424501, 0.07988719675209253, 0.04498256468063882, 0.039034964471694925, 0.05087770318852798, 0.06665415400939603, 0.06260709536652412, 0.03703738637869397, 0.04279141532137029, 0.07222605703939354, 0.05699296173970065, 0.0654504306974911, 0.03797764822299923, 0.0600224411145093, 0.03612340135019153, 0.044574956109206525, 0.0044715000812204616, 0.04550908925011755, 0.014929356759474164, 0.050127469453840494, 0.043764852603236516, 0.06273833005839298, 0.03946014710011021, 0.0333771868158252, 0.08047498537287598, 0.04978072656799228, 0.05356836102662548, 0.03589143375715902, 0.036335952444783146, 0.015523695432010199, 0.030058352201576197, 0.07596218357643775, 0.04465171045834019, 0.02251382064705174, 0.022868674488798268, 0.014094234737116965, 0.012639457709155979, 0.024962387040197372, 0.03323421565695636, 0.10999702623174076, 0.060824010401002826, 0.07593161666825896, 0.019119049482528242, 0.006261803989013237, 0.04495844057190322, 0.05080591691958328, 0.03741792906376143, 0.020133531840157606, 0.05251653379790726, 0.020646331944472848, 0.13614350749600318, 0.12441517634978219, 0.040551657683306166, 0.035262092527362614, 0.03971294845424352, 0.009459359702774355, 0.018392909213059375, 0.023699443216525742, 0.023658202788341912, 0.01069014124016488, 0.04665535979814107, 0.04223088027849313, 0.02503012453446225, 0.08457918651401998, 0.09168581646536628, 0.0669054231876808, 0.04113065544515848, 0.046741437437313224, 0.012169678229838611, 0.006604007803910082, 0.0031301569740002557, 0.018573466560713226, 0.11970218811785022, 0.02015623677101347, 0.059058131770260876, 0.09717005605418837, 0.028196247181885188, 0.029845462113078085, 0.049675852961597905, 0.03468790196723515, 0.11447541535862031, 0.07311404487418552, 0.049903997775888255, 0.029598400672717445, 0.04884233780866189, 0.03973343364533879, 0.00944301138647021, 0.04126732553085012, 0.05650730413054267, 0.0026030111550954323, 0.08204766428999363, 0.039700327155691, 0.006750323415373362, 0.04721951077602083, 0.05894470479219191, 0.04045263698865329, 0.026500138093627272, 0.09143827813527278, 0.007648793726994266, 0.023910753248680024, 0.013950130725730092, 0.08974428153446606, 0.045523093337373394, 0.04654298236052837, 0.03406257503816197, 0.027387696919181657, 0.017730361902185025, 0.007707495214192258, 0.07035511711071576, 0.024522757908749967, 0.022225490050210107, 0.0287959867742874, 0.04994031034349915, 0.01893620536242041, 0.009086424270794998, 0.07114955028819461, 0.07186011982060249, 0.029169983238041885, 0.021875209753371535, 0.032813591251690546, 0.06228106366770883, 0.030666748587522778, 0.03873634722925002, 0.04490559582688636, 0.04022862521871444, 0.02375425680750801, 0.060996663636497916, 0.015469073363009001, 0.03045796089985919, 0.14965732912382773, 0.046127942736230554, 0.058985908831199335, 0.039327407045470136, 0.03710814992025976, 0.050349244247040445, 0.038414885244903066, 0.029899850525262377, 0.07037714979941807, 0.017557635888337128, 0.014282294958379241, 0.03618433215324918, 0.049180649896903385, 0.11662377104643853, 0.02162570066209282, 0.09035609467255493, 0.03369850324346654, 0.041956253079397064, 0.06521403894669588, 0.028405358541696787, 0.02238142916241721, 0.025301139628995332, 0.0914876065367172, 0.01370989895921441, 0.0907357601869491, 0.028453070497620973, 0.06634668462098607, 0.02479762834076199, 0.050009545539655996, 0.018681182353306684, 0.038082334137852156, 0.0828055167690881, 0.04438238075724052, 0.07668798293678031, 0.044442897872819055, 0.03806516993790865, 0.008592849142939575, 0.02990889419320851, 0.02700129940715288, 0.014381774348176777, 0.02753373242974762, 0.11768538504838945, 0.03830954432487488, 0.05497092245927742, 0.07868915781258576, 0.036126664884748964, 0.07279694576056735, 0.0112173447550665, 0.037466809303770145, 0.013947766386873782, 0.028258457351776383, 0.017721624669408607, 0.034993881314632394, 0.05178989940172723, 0.020014548809417797, 0.0384685113996027, 0.02387072706985618, 0.042508667590276855, 0.04845118863628276, 0.018304336042473876, 0.05374230512027299, 0.037648368311384996, 0.05698683686674603, 0.009986485651273642, 0.049174865933075074, 0.051194158788289756, 0.038027014928839864, 0.04293666176137425, 0.023295036892616944, 0.06190592573294717, 0.038240339772235, 0.029345758281828418, 0.14159569396607338, 0.026407506572262898, 0.05025707237843064, 0.004067266127094626, 0.040747688091810674, 0.022300147233651053, 0.02961311913696268, 0.058311173061449686, 0.013424635586899616, 0.008101583770175856, 0.08505931679880427, 0.029836129246940537, 0.020674646554154255, 0.030450930127934105, 0.037623520249560956, 0.03897879490508668, 0.0607699552370656, 0.029736059011831403, 0.06319787556065187, 0.00194115188693808, 0.057613102253526456, 0.03163340407603931, 0.03570226366601644, 0.056320719586144534, 0.021674634528256232, 0.07065982092171907, 0.06816040544259934, 0.049101329153223384, 0.03882812456257882, 0.03837788319816032, 0.05466084454148527, 0.022129501148517576, 0.027060420327489416, 0.022379232405294335, 0.017869669245555997, 0.06383837486106543, 0.0334764986238893, 0.016769023063863, 0.04108855125284003, 0.030283223905210054, 0.06659845941730085, 0.07666569743906299, 0.03282142067027669, 0.07382825332423372, 0.03578426954787105, 0.018361850093389233, 0.11525508602179828, 0.04740103530967909, 0.04693948648749821, 0.05719752253724202, 0.06511353587190952, 0.0726789758811074, 0.07500743883992396, 0.0544689012120568, 0.053048145191203204, 0.05526074118191197, 0.04195770481601358, 0.04977496175636208, 0.06333264191785166, 0.10476103743478175, 0.00963120854594895, 0.01717723875997528, 0.00564112721364044, 0.03354029842622338, 0.02018476205487405, 0.11282395195936966, 0.009102407737725205, 0.049239339892782515, 0.01377456731373264, 0.04827241052783305, 0.025025667817962748, 0.08030372641740308, 0.07169832205099445, 0.018224827607252428, 0.04795715002523315, 0.041678810507179274, 0.018659004107898763, 0.025208119318009387, 0.021529208057590073, 0.014337634277199546, 0.02598398826986311, 0.04419323747917529, 0.0513281628880049, 0.02534778863792458, 0.033253352533304886, 0.03724378578725361, 0.050542045594944116, 0.03271436754373774, 0.014075121801016072, 0.04045756676444604, 0.05473446942144825, 0.018881728850124825, 0.009742749032504376, 0.03608197897612568, 0.008745226903908677, 0.025697367964312438, 0.05761145899492887, 0.05528696437156009, 0.008338705219718958, 0.05974867576432805, 0.06630772138915716, 0.034492032437194745, 0.05280107417474351, 0.01093604109971033, 0.050392999358835726, 0.021721448246089202, 0.05876476989097654, 0.015971799411119956, 0.04055347331168671, 0.04205625819703264, 0.054401523779116334, 0.02648183242267659, 0.02624306196887647, 0.07810849380949814, 0.01677304119502585, 0.015357030131253264, 0.03324997408555881, 0.0715572469597382, 0.019356743582794746, 0.030871998864196004, 0.18267087698463472, 0.12566619026925296, 0.10046529899080915, 0.10048673413093052, 0.12283040856521939, 0.12820145100234978, 0.2073579530922636, 0.134207526702554, 0.24798669071207124, 0.1943727168104341, 0.12223112096469249, 0.07662325616805785, 0.11395152613160112, 0.08495474579713999, 0.1557683665305376, 0.15285419871009168, 0.06434298931590973, 0.18845136277377608, 0.2588271259540512, 0.1973451992436763, 0.0882922308219056, 0.24865712489812608, 0.07058174890135566, 0.1680788019251439, 0.07850897393279499, 0.20765717171372908, 0.10612816730093573, 0.1419893252633272, 0.17468640220261392, 0.12792810317008727, 0.14588394773102578, 0.13893203689686714, 0.17293393011054686, 0.27578653527363656, 0.1898141719040371, 0.10250799583211061, 0.22035183084587898, 0.20584638500886582, 0.12909120850024686, 0.14577130216263956, 0.21183644181057332, 0.10747527928962823, 0.11466693733969044, 0.12769282990766148, 0.09624522705111774, 0.08039970957343617, 0.18829970800828552, 0.07091109010000383, 0.25416903558277315, 0.14248827832841104, 0.08280711789284984, 0.1840268985758866, 0.1551191223364684, 0.16270467981455788, 0.1491064812627531, 0.12466764828610806, 0.1793920972775067, 0.23209513135014043, 0.10462945417290735, 0.15763054241336164, 0.10987485052957652, 0.14948364166963488, 0.22588018177738114, 0.20208421914327532, 0.11214218733291473, 0.17047509430877625, 0.21562411840404236, 0.11645799728050349, 0.13943333419099932, 0.06683538742964307, 0.2158269018775994, 0.11327208275155676, 0.15492786082529253, 0.08015887451268013, 0.08155495484149264, 0.19201230798517505, 0.13267630080301918, 0.1521760423577601, 0.139747767318641, 0.1207346601351615, 0.12962036075130587, 0.21424499160099417, 0.22764327184807873, 0.11687150855939235, 0.22435005904445726, 0.17925518204367932, 0.14309517318202605, 0.08246935738791382, 0.13418918655764672, 0.1117243859616499, 0.11997722134354616, 0.16091086961809667, 0.12190460663048491, 0.1653657015413046, 0.15380316714365638, 0.21968329655787638, 0.18054824652931384, 0.1812882568206518, 0.13112972250148175, 0.09488716000510801, 0.10341637692744694, 0.15584319799898133, 0.1773639407850081, 0.12387204299410506, 0.15319680855158838, 0.11522717743871674, 0.22695042192935946, 0.18353719985292805, 0.20025702283507396, 0.15777326459365507, 0.10227566434731407, 0.32861981961515646, 0.20766382135691183, 0.16776089075832598, 0.13305300155714636, 0.3125904103921306, 0.189831332273541, 0.1887341411483865, 0.10964032037243729, 0.1556450876617624, 0.13792234833442396, 0.25793469480929837, 0.2024003529861089, 0.13851234328842935, 0.13136670413997867, 0.18526200084917008, 0.11706195801736848, 0.13631347176288405, 0.1552815789416913, 0.08341432684251378, 0.10525485771077295, 0.12024320707085634, 0.25384494974728555, 0.13403157162810528, 0.11868065583609766, 0.15176371851515386, 0.06505316814347621, 0.09205998912934335, 0.13210627010032056, 0.13243709750954183, 0.10060538582864309, 0.152276752276286, 0.16177429667403623, 0.11118520561966205, 0.13287805771875766, 0.13771034116225858, 0.17041239767305313, 0.15890261608987086, 0.07168612593123991, 0.0872798532908482, 0.14665441767823312, 0.26884344977236563, 0.1068643318308938, 0.2088851800128337, 0.15896062426749738, 0.1592275293003167, 0.1587792912558202, 0.22438785782264126, 0.1364801724952075, 0.1649723000704281, 0.25296960236324423, 0.10325146884086633, 0.20543577720320996, 0.14595539309084415, 0.17096974195972567, 0.1004951764198561, 0.15315265124363286, 0.08330695961992587, 0.18017056518264357, 0.1269064942795423, 0.15223443357934877, 0.12171189721313216, 0.18117224046539876, 0.158255118576269, 0.20406446449698942, 0.13083215862993272], [0.02937092235492122, 0.014833825595316388, 0.047509268211621436, 0.016722864351205288, 0.022672875821890853, 0.11382721304412811, 0.00861304896628304, 0.05724510808865871, 0.04801232367753983, 0.006306154734169644, 0.023878246222832994, 0.019417620759697694, 0.018539427359017636, 0.013140665945566952, 0.028365207873585246, 0.04779014668817963, 0.05551209846030801, 0.02659715355313834, 0.02294931098848822, 0.025041470296620846, 0.06429326254874468, 0.017868001089100877, 0.05594621367392041, 0.023254815361372406, 0.07456994900900511, 0.0369440577173185, 0.04068173175196975, 0.004852636005624288, 0.07820270730242615, 0.04061398659682563, 0.014385124067625692, 0.023135748060960925, 0.08572828775692372, 0.012537885941715251, 0.045505821885120486, 0.12720887684413504, 0.021585887072667963, 0.09917714512876927, 0.01327626638099431, 0.07872914760223321, 0.04244806620502665, 0.03976094003226008, 0.01992322346796432, 0.06051271440341108, 0.015489717517348548, 0.024061839193886807, 0.016114736096032204, 0.04716872680752028, 0.023284579792450515, 0.04631276527840284, 0.02183358819644538, 0.02492515325185753, 0.07287292636089748, 0.0785714024377446, 0.028469390085627957, 0.06267589772300375, 0.08697875775396825, 0.0404708928638889, 0.02510103554795346, 0.03970246837143937, 0.03344012476924447, 0.06295864545409718, 0.06651765246304774, 0.05300704457406556, 0.01923069722139307, 0.004151771849607148, 0.04175030566271275, 0.049968973523186105, 0.03037984674465993, 0.030242711260554292, 0.026242958547006694, 0.09176323731099406, 0.03815065385893949, 0.039381500513803576, 0.018462843464447126, 0.013540043859862754, 0.06151140194326159, 0.0036141047706722373, 0.04965457486950102, 0.02095883836098496, 0.008193447288396138, 0.014567440544675677, 0.017769394081927115, 0.00938453589520988, 0.004405286623119948, 0.06236149906931866, 0.04866167129347882, 0.02246214610133921, 0.026691596872443636, 0.012592150822221752, 0.029366268370781216, 0.05801586531883767, 0.020835230074402307, 0.023479273377527154, 0.15006263560104757, 0.023778022770139, 0.036446050770821116, 0.08286775375205664, 0.06207665608775231, 0.014530307305375896, 0.05367545628800027, 0.028627363161274025, 0.04087614571495403, 0.05466733330620393, 0.03759760349508255, 0.06090415851964105, 0.026401379784088463, 0.02845521937424858, 0.09190758359768698, 0.022844883628309737, 0.048824648838490255, 0.10373456388591759, 0.05859307426538679, 0.03533223936814935, 0.04178560699426359, 0.05605236664714833, 0.027422910150621208, 0.04273012828742785, 0.05327797922936659, 0.031937592692913554, 0.0732344202697277, 0.019166384140149723, 0.014859372712371331, 0.07519218860374344, 0.014307512657626743, 0.07262432316858923, 0.041705838089147886, 0.06371624895461625, 0.0549031773041333, 0.03333497920163697, 0.043403236120338404, 0.031038245689424298, 0.007446074413300883, 0.04532050138579742, 0.0557042409725968, 0.0779208712159626, 0.026027023259009567, 0.04018650187419788, 0.12855761293922702, 0.051309681016831636, 0.062246953602880246, 0.09002966460801902, 0.05537778792542316, 0.059066164202146956, 0.034945571810127266, 0.024164747784755403, 0.05249494160976141, 0.016621872895367203, 0.01441703067206207, 0.021417813127740257, 0.006493630334584704, 0.009762285232183435, 0.013329951907508077, 0.022880533529866128, 0.03778018906051594, 0.022965933181225293, 0.01766651230413587, 0.023902558023110036, 0.059106418292128274, 0.04463895509440092, 0.054486797025967995, 0.019971502328952475, 0.024216968168113983, 0.04142346957157697, 0.03042267489006683, 0.02166606966526278, 0.07263078128979092, 0.0673180841089737, 0.006401758197875273, 0.026622627891840476, 0.05995591020872516, 0.004412390173397838, 0.06285652210335098, 0.052163600921630866, 0.03391237200928792, 0.0052863997764014195, 0.07423843212065197, 0.021190612516816587, 0.011347556719556453, 0.018680067695376855, 0.03258042090061692, 0.03754970001717729, 0.026967298509853504, 0.03832218860606513, 0.02664747020800508, 0.08510791741672062, 0.006486787733006021, 0.05612112686879212, 0.018077932162991455, 0.03441555771015344, 0.07856725024119501, 0.035101938016352155, 0.11225291002061098, 0.04454191473703231, 0.07030878411305529, 0.011368002648645592, 0.055034515417871945, 0.02472824758789953, 0.057364119847695676, 0.029345509303253026, 0.0331559942494477, 0.05363548182011132, 0.022197853428341692, 0.02294650136102592, 0.11074326481790313, 0.06629287460518461, 0.03748785373905013, 0.03845047768986514, 0.06237294442290741, 0.039427630498164126, 0.07990049603845804, 0.0894606528022597, 0.024821355998996767, 0.08947403635829689, 0.027454329331615762, 0.016635526497397694, 0.04418033655853041, 0.043181334922630946, 0.035480224572482615, 0.04334867150793153, 0.035903905668566306, 0.012976525862130427, 0.02260792497245054, 0.020303938522814743, 0.032985758021353714, 0.0732672241546454, 0.020192024568396232, 0.048121537172025254, 0.014524657406934328, 0.05177630900195049, 0.04969597043048951, 0.04102452162412867, 0.05315892150505416, 0.08678969491513507, 0.036358946573830424, 0.015947750953566885, 0.020962643902748827, 0.08580915599821076, 0.023450702128391114, 0.07336507656521375, 0.004392958353198464, 0.01442340931164161, 0.0025225649803741687, 0.06540900832342525, 0.08498270800637622, 0.052614424512871814, 0.040603054522146145, 0.009849875895006042, 0.01752269653333051, 0.0964489451519424, 0.045634053512326175, 0.037143903243685925, 0.029712858039044568, 0.04441505057677146, 0.02270298882297451, 0.017178788172802138, 0.0461724792577086, 0.04537093678429242, 0.022346076119931477, 0.053483658515277414, 0.029379385711264708, 0.030776676458997593, 0.054627734221397876, 0.03163099281429764, 0.00937852785066371, 0.01308219715757596, 0.0865859768143104, 0.012465932091037113, 0.020788391458711798, 0.08660404116756494, 0.08315199535460242, 0.024240517710906365, 0.0387208454401022, 0.05009829299524427, 0.08315610158587657, 0.027333565146451997, 0.06793524454077406, 0.054546180331418594, 0.06327375656955185, 0.04963350362114368, 0.09766989012038517, 0.04086154407911724, 0.006323162364893623, 0.012089320394631115, 0.06851299740974942, 0.06297335817268299, 0.029309196735642133, 0.05494729630769261, 0.011809001162257648, 0.0344159790585118, 0.058361796151486144, 0.021890611951089194, 0.03317805758166698, 0.07103315088897943, 0.05115039984605486, 0.015859630732466618, 0.02801436641734214, 0.002792700510209186, 0.05581160819518471, 0.00949934853481189, 0.05737338185070023, 0.02070631088328458, 0.05623141288637154, 0.04395593025331055, 0.04630523080366754, 0.03064036451941056, 0.02939765882347861, 0.008072991453621897, 0.0907612479321899, 0.020293205630995577, 0.06501893167414012, 0.07945339946496872, 0.031604072484638424, 0.06338110847038127, 0.018020019746355472, 0.020833659594157533, 0.08915004245336018, 0.03862056070037427, 0.026086563612484646, 0.04446083582156608, 0.021096623104606426, 0.025625164177449002, 0.03420504057900079, 0.059393586350544814, 0.05203869794645617, 0.03356884669272169, 0.036655254061183626, 0.033218970507263176, 0.018530931443937363, 0.04757105703315428, 0.02070689311010703, 0.025908448170089436, 0.03205015016118846, 0.05996015433582568, 0.02152713387453508, 0.06057551829144359, 0.00705869104187455, 0.028963953466905706, 0.019057787346443342, 0.016066275289162033, 0.04250549215583071, 0.0028083978911801694, 0.06352733550292831, 0.021948432437174266, 0.01527653823065902, 0.0306981083967032, 0.08289084364209445, 0.039303520423991066, 0.016134868886682297, 0.008679491771955886, 0.019814178512822238, 0.029066710755409255, 0.10790432683162152, 0.11855070434150197, 0.12486205841865271, 0.11582073470157002, 0.16527922553641183, 0.1683549000130546, 0.22579606532329516, 0.16487270864027162, 0.1879424046004011, 0.12494299560785295, 0.11964778055346782, 0.1047671814599345, 0.12434397613809955, 0.13704039727247533, 0.143268263087638, 0.17754671404198294, 0.13680151573592617, 0.09940778355925314, 0.16864386837809317, 0.12051053345203401, 0.10861104294177025, 0.11370311446127393, 0.16246406691929988, 0.15094346817462675, 0.308318305760622, 0.1522227737211412, 0.13459771060414855, 0.06141516214777386, 0.18414843076419446, 0.1844206524472083, 0.1468901735760512, 0.09482910586220604, 0.1643992509813078, 0.13408228664869262, 0.15747039939367002, 0.20333835104059791, 0.12423473200009716, 0.2065398477979245, 0.11480438883506483, 0.18602108672982265, 0.08221327717746459, 0.18315528970091574, 0.1413776346993062, 0.14070785934886626, 0.15831217680486942, 0.1019373216155556, 0.10151094005953881, 0.09376508634417288, 0.11985319170860514, 0.16092464387897523, 0.10458114466840222, 0.10102104981459918, 0.1393105915837711, 0.18252404857306712, 0.12362959914870801, 0.08749439621404295, 0.23149209757966382, 0.2877814496957487, 0.19547468832423612, 0.1532170179510309, 0.1323710913739858, 0.19467961163290087, 0.24581450968980792, 0.11177408974617721, 0.06210578658107308, 0.07507780401576912, 0.06315741079649137, 0.18063288392318835, 0.0641130403645577, 0.18494525413599708, 0.11161586960717557, 0.11783652653497075, 0.1591037141699945, 0.14512843182010038, 0.17019623830433817, 0.16019139048312941, 0.17578894062147987, 0.1174149330284807, 0.21136077781838758, 0.08444085401753265, 0.17419601400052348, 0.13474758804565476, 0.16897740773856643, 0.22042611073101723, 0.14777289072592414, 0.1225171935173773, 0.24279739497409714, 0.16687019097228206, 0.12483202011114168, 0.11945326316861377, 0.18259868085865053, 0.0926511255543559, 0.1227942415543141, 0.19277952971958345, 0.29810503605873356, 0.1310402127884088, 0.15086768675715695, 0.2087360073722178, 0.21114636513013996, 0.08632244256835792, 0.1450254236378016, 0.08623545328455587, 0.3384946623156148, 0.14364337037888267, 0.19948551100828957, 0.12969957424267647, 0.08669310654964178, 0.11997018865640126, 0.1332448299733862, 0.15060798295082586, 0.17465500791947688, 0.20273556241825705, 0.1552297454327345, 0.1176622185495592, 0.11999311766797498, 0.10260597081674684, 0.1278523294134967, 0.20695076203875004, 0.18488853298608335, 0.0923270243971098, 0.1979954087085301, 0.08988518042549973, 0.12695438243568907, 0.18235092802393824, 0.158917386265051, 0.15101767145097256, 0.21639140142548471, 0.2336401774758293, 0.18334883415410597, 0.1434690394108334, 0.2210492313268685, 0.1371472971814294, 0.2095653128720099, 0.22236302615173403, 0.20753455168056875, 0.2182784138788139, 0.13370906393374168, 0.15358889235123513, 0.2599206398571691, 0.1555368241163031, 0.14720174153485607, 0.2181971625935647, 0.12003195066485675, 0.15521200283640815, 0.14371751236819452, 0.12891853228211403, 0.15256952043742905, 0.1726251047465109, 0.14717183346229215, 0.08866071145260528, 0.07985441584981258, 0.110902312331863, 0.0828263313779908, 0.1371758262957296, 0.12755257453048421, 0.11021950582583105, 0.08400996020364185, 0.1256837719871152, 0.1422373845332092, 0.1236555848510996, 0.14307024468096996, 0.05861198897623728, 0.11041420707178694, 0.12668484206041022, 0.127200672042466, 0.10575307533144952, 0.18561309894486783, 0.1655592766380118, 0.0843174602355688, 0.08510606348394387, 0.1362295085263829, 0.1106284665424497, 0.15320405574335208, 0.10992412530486623, 0.13614942169477864, 0.09076113301900127], [0.013693368697028249, 0.08045646902774611, 0.06294285255153814, 0.02753512096411038, 0.06460917422608023, 0.03444271935750881, 0.04759313568713204, 0.03305641048017048, 0.03937699591680881, 0.0474049576798514, 0.03992365710737725, 0.03804707494113715, 0.03803243117046453, 0.056431170312627676, 0.04724911624385465, 0.03914509344124987, 0.0419372885728315, 0.028064989507378593, 0.09045505024973424, 0.03113160882475636, 0.015526705199942715, 0.03081692480331948, 0.047367369575846585, 0.02235279662624723, 0.023224020542036143, 0.01733284653915513, 0.04193251201462361, 0.02158374968735922, 0.04923918667519766, 0.032232402478374785, 0.038305805815804395, 0.0757427376905276, 0.025782116440935962, 0.01920860324565682, 0.00861488183164188, 0.05036943832472448, 0.01795678301864574, 0.04281692987968845, 0.028084714356209003, 0.04036064515070569, 0.0516826011270525, 0.05242474497325959, 0.033946393974005215, 0.01992912426020109, 0.048612641666324875, 0.050262074932576194, 0.012562804866672285, 0.02214303026126037, 0.017555439131214254, 0.0382330006499204, 0.015851284204531583, 0.032710372395212614, 0.043630335224612106, 0.008293247477511966, 0.06804379919964461, 0.09645370255795219, 0.11934247919388356, 0.03201505375815736, 0.04654827219764552, 0.04426071833398554, 0.05310934029459473, 0.1239971528130193, 0.03703542136316819, 0.07108607224278873, 0.0358112320123661, 0.06262675318266116, 0.02391803491440031, 0.010370218134935825, 0.017430823439011173, 0.03681424411854917, 0.06610607172572805, 0.03371716897574163, 0.06984899346266063, 0.05967626896416468, 0.0349419252316077, 0.15209091466761407, 0.08776333137986161, 0.05136487382133642, 0.023927304578284105, 0.02209630081309907, 0.01542003128692628, 0.11187977923621094, 0.09698150649426446, 0.01651776537689711, 0.028332815760926857, 0.06410998750417944, 0.08207200290334803, 0.008902493263444593, 0.020882675814772808, 0.02647123742668379, 0.08616347932406972, 0.03762459660309457, 0.025727166869347135, 0.02509792331576107, 0.013003828278141878, 0.01474800842603849, 0.023490475498199947, 0.019371356709950396, 0.01826198861723946, 0.011940342148826008, 0.07665628987935282, 0.019441009424025976, 0.06348725761316958, 0.08261836915006561, 0.03135656479806189, 0.08525840772856629, 0.060221317539652514, 0.06401358299978799, 0.023730077157397906, 0.04732653708948244, 0.021955472785198403, 0.053941392219595374, 0.025012822438692375, 0.030148315821744265, 0.03856009721095043, 0.09873505877030474, 0.05324744679514439, 0.050776652360875765, 0.034527881521611445, 0.029623340665092392, 0.027922154329116308, 0.020537547459225022, 0.06360487126174473, 0.0320331008744336, 0.032736599415300355, 0.04611863859839017, 0.06955162877397192, 0.031585713187533046, 0.004728177840250635, 0.015124832711843474, 0.06748029556606086, 0.07734264337247418, 0.049028585274373336, 0.049575269447579506, 0.049538366992266915, 0.013978140815461596, 0.01346666795847517, 0.01976427554543461, 0.017470686824151108, 0.06507139337519485, 0.05652988457211083, 0.03170217770422178, 0.032740805238004655, 0.04673819305495389, 0.02013121442418666, 0.11087163817137481, 0.0009427219441521073, 0.053539333955174497, 0.026324363049840736, 0.09391810474616867, 0.08926452663276466, 0.015324265508341695, 0.028134308973207112, 0.04465098267481212, 0.02423842437565327, 0.041894138670496406, 0.009820045388844467, 0.030211334214395577, 0.05165129494402678, 0.009337701109958994, 0.022474945515334126, 0.080441951661581, 0.023935764104187972, 0.020237926641599308, 0.05732526003773655, 0.01002959629160262, 0.02330778268045716, 0.01535775408434171, 0.0646396492037081, 0.08627927351382472, 0.03245271787407898, 0.05523393193500177, 0.016369713139870477, 0.07759950499260619, 0.025745330814031825, 0.04445225180637452, 0.04296880681067706, 0.05340648664822502, 0.036585088068198775, 0.06672006821440113, 0.05279259358142173, 0.04635517973633063, 0.036511114618230256, 0.0036570301134845307, 0.06733909023985749, 0.04926246808721654, 0.04405225431846996, 0.03499232615614611, 0.059378957901630676, 0.037157914991821014, 0.026109473471860253, 0.0397284425825121, 0.024296873053836248, 0.04710430264352791, 0.01572392304472986, 0.03253552048737484, 0.06400977171236469, 0.03280219569381687, 0.018721331106198412, 0.03343776521843768, 0.02130203617496356, 0.0067731355985386245, 0.07662829702659961, 0.04203913230148535, 0.03431484779162753, 0.041727537529603134, 0.060198840519954125, 0.02591566663355597, 0.020826697770145633, 0.03280557031112333, 0.0452882835581418, 0.028807803680519425, 0.04881650915429477, 0.09240297435392296, 0.06737567859912111, 0.023423984812031833, 0.036282257342170325, 0.0772483456098745, 0.053712665178482576, 0.04659735545095417, 0.03191867606684325, 0.015265745009415814, 0.06689222349274544, 0.06696416680971462, 0.02990049212389896, 0.08123395634033988, 0.02677389769814909, 0.005240989914689694, 0.07080232093651449, 0.012251102842480667, 0.04019139717603403, 0.04870097160399441, 0.06362526069184946, 0.030606181676229163, 0.026374779296137636, 0.08302687787480893, 0.014164154624356138, 0.04421335111762728, 0.08646259069322579, 0.07149340119212866, 0.03910122724670557, 0.01205147565117166, 0.016500608837832848, 0.019446414174331773, 0.03679118487202833, 0.012059789620369915, 0.016789912366338314, 0.01723203128353963, 0.044845764360000054, 0.020022221179979465, 0.036830282169243986, 0.046134473635785045, 0.0471326134227697, 0.0633111876255322, 0.026460650091570233, 0.024688275035230384, 0.006191032307763254, 0.027677573098410523, 0.05739714589811141, 0.035624616824451, 0.027019340777769688, 0.04146644327368948, 0.028621717093272075, 0.038741200396250335, 0.05305928410962225, 0.06099704285002044, 0.0662885615301709, 0.044075543391368086, 0.06991555118152211, 0.08330963326678162, 0.022773938140861934, 0.03651372697805205, 0.08132146656393044, 0.025882173269506425, 0.05621949638870936, 0.05342891004176871, 0.04439118693793013, 0.06601011155233269, 0.03570910483118027, 0.01631135064657898, 0.069017588881956, 0.038851298722288305, 0.050888336488916996, 0.07869221450340363, 0.027312267902157, 0.01990743056540528, 0.00921749712658986, 0.038834483092350346, 0.02594473200940317, 0.03719702761079516, 0.01161831708985471, 0.030792226128640677, 0.01720348684748094, 0.06424163971396704, 0.06213361089448295, 0.019499521304462707, 0.03154569466958844, 0.04733627789743966, 0.04390973898191606, 0.023194009047602455, 0.019828684387668487, 0.011601585729588425, 0.03197951302413018, 0.04917217696446085, 0.03785304785255463, 0.04481400618509901, 0.031931590394026814, 0.04827879970112155, 0.05319875807711675, 0.05018824320887366, 0.11621815047316975, 0.008100019993200418, 0.0427171622493094, 0.04651809216386849, 0.028115838593352708, 0.028447891743252837, 0.06579481786297214, 0.02260079077865568, 0.043712130432287534, 0.04208890120348623, 0.013336364063434305, 0.050096052188065746, 0.028629818473071344, 0.037312998000772736, 0.017613487528456796, 0.046482254570770654, 0.042484604768575206, 0.08891522884368898, 0.01676615597980638, 0.047090501569572, 0.0831348273242193, 0.007961258966280449, 0.06776657496248523, 0.02633712607465925, 0.029967992130907315, 0.02966315233929744, 0.037465123910336726, 0.03075885916909864, 0.06114737611384161, 0.05732351718770881, 0.09857807969374043, 0.019689806053535115, 0.03361216513440013, 0.003072114561819622, 0.03171716621446033, 0.02717924247976513, 0.06684474136319853, 0.03487954269193354, 0.03140309314814306, 0.07247315869937021, 0.10069327143531653, 0.04374878007858511, 0.19739474981061875, 0.20593764140240609, 0.21967876131736466, 0.18565233796834948, 0.1537631926757674, 0.10128292164975598, 0.096622908397788, 0.12738804948786575, 0.13980364577183801, 0.1429068840919964, 0.1131449121561262, 0.11821940961864688, 0.12772275330198388, 0.13336389535857787, 0.12394023248024526, 0.10974252416241555, 0.14206673078719648, 0.12063780363889472, 0.13323931414033138, 0.15541072604396652, 0.1852584615229599, 0.219080553900811, 0.12344189994638005, 0.1368727159476088, 0.08847164861377209, 0.1974058734072793, 0.18147381863767104, 0.12053643488475393, 0.1331131241374439, 0.09320666187352712, 0.12893727079274195, 0.10288445143810204, 0.08383972780598749, 0.14997809013772398, 0.1368049937751024, 0.11262724356305216, 0.20084252851384304, 0.18839666409598244, 0.18206641829061895, 0.15863186529567166, 0.1320061270868586, 0.16506069129513157, 0.10652880064181744, 0.12969972746026132, 0.19572355964731789, 0.1454249231685554, 0.20748970489348137, 0.18461827248815568, 0.2154405177721093, 0.25427337675806017, 0.09908206595648682, 0.08567276170417186, 0.1264710192598643, 0.21847903698442445, 0.1017466270094437, 0.2801954632084216, 0.2599698839889419, 0.16004348954846784, 0.12529941801462444, 0.18413552984354958, 0.12054449412971736, 0.1925710159083528, 0.12251563835889102, 0.1586181982871025, 0.17171843968812497, 0.14268683299662607, 0.22516470162137864, 0.07903837133198977, 0.16274591066664265, 0.11977297464205373, 0.20295903026576967, 0.12242553109723715, 0.22246454812345967, 0.08877181718426366, 0.08849844636936342, 0.28553911034137974, 0.18635438094216009, 0.11132390583835303, 0.07732491609790633, 0.11323073698628335, 0.12820300616083607, 0.1863061327246889, 0.26367606414902595, 0.1937181559661704, 0.10324688763507914, 0.17159499228000644, 0.20394904569031733, 0.13074385933578014, 0.15804160987177204, 0.12662504123704088, 0.15783491934980118, 0.13386349193751812, 0.2175146701835817, 0.18049904836281655, 0.10385153019019674, 0.11724446314356982, 0.1285045460287121, 0.09707928229604038, 0.09395660066436376, 0.16666861791764537, 0.09014884490639934, 0.11596870458414478, 0.14065464688164575, 0.23487488138339213, 0.12385740305387205, 0.1599485406111325, 0.14827405012422992, 0.16122804534050728, 0.13618262394541694, 0.12431173915824584, 0.11080950844071566, 0.10428070796713715, 0.09221147535549057, 0.12013223157414507, 0.13764461081835533, 0.13621847686027327, 0.12215176957749552, 0.15095551107679644, 0.19877654259964345, 0.08943331878512137, 0.19264610784669078, 0.14881172127300693, 0.15121463265630508, 0.11605662849521446, 0.203110393917849, 0.13786156691851156, 0.1649380099749373, 0.13096050900076667, 0.09221492275114983, 0.1566212062513636, 0.1728474234621371, 0.1280948728503239, 0.1853390692943527, 0.14720753315956364, 0.19120112812567144, 0.08546522848548428, 0.1001909399224866, 0.08884349237045935, 0.11767008627254157, 0.11544244814543955, 0.1685848796079236, 0.1345117402172858, 0.08266175270921762, 0.14977539859471783, 0.08662015199661256, 0.1879943606834258, 0.09011527493355737, 0.19605279359365665, 0.13336253172207263, 0.16536286701598477, 0.16902813808091227, 0.12459487759418066, 0.09477110534545877, 0.09461943525820972, 0.2489290248242117, 0.1196591416373849, 0.2069904147497108, 0.11250775682950213, 0.06681584452669467, 0.17252955826059466, 0.0879908594933729, 0.1735485624521971, 0.1953913379580744, 0.09187638849741028, 0.12216710665773962, 0.0771060064735432, 0.09871505621460178, 0.12447786532462606, 0.19855244656003293, 0.2439567005081523, 0.12582252583196088, 0.20353062378783382, 0.09399517319135128, 0.21109132937365965, 0.19885892769502056, 0.06973559712810863], [0.03182399717550124, 0.07397863638376997, 0.04810881245160296, 0.03690355464876179, 0.05633906356149143, 0.031824491302212404, 0.11379193469521501, 0.03758228173659694, 0.13586399265595023, 0.012675864122537597, 0.12004435362835085, 0.00963228394187266, 0.054043657296607574, 0.004563356896171406, 0.03147050697025994, 0.035975772376743057, 0.09388003017633192, 0.04081041154061114, 0.027916157775889003, 0.026754015801294197, 0.020699285857018926, 0.04764540969664532, 0.009867490171605061, 0.02615396594328265, 0.004330952633022061, 0.05027029888644334, 0.0668530917215732, 0.060641405683371334, 0.03696823545220879, 0.014467997544054544, 0.03919277475365708, 0.029470509954638062, 0.031072319365076484, 0.018273432055608402, 0.04628416721618945, 0.040101186492510384, 0.023775370190701178, 0.06999439695068906, 0.013936534580293924, 0.015455299102130438, 0.029226683320537693, 0.039742691817903714, 0.028235350224760272, 0.0507861441902576, 0.04848270166304804, 0.009091935315800291, 0.007670079001165446, 0.013191208596371356, 0.06717349267414502, 0.02743178910966362, 0.0567981762240731, 0.03183293550635778, 0.06898303065569171, 0.01865374299907877, 0.019290178203054013, 0.0978851838097457, 0.01548071215379863, 0.030674313705775048, 0.01910099279015295, 0.009223938010813249, 0.02805755270885364, 0.05592960488772201, 0.04365772286790513, 0.07253763265907764, 0.040335950306466514, 0.04619211409120791, 0.03300308693020094, 0.030654127288970257, 0.03178798721262044, 0.023351309881094965, 0.030780459018123728, 0.07573935158190227, 0.03984566169580625, 0.022449337111245242, 0.11905565587503296, 0.0584970566353971, 0.07055507371983222, 0.028560035524048635, 0.07537347565014517, 0.09606019383476627, 0.030762115042776834, 0.011398679681963498, 0.027700080761625886, 0.025537575429846204, 0.0688016593396183, 0.08099392567190432, 0.014724334393958411, 0.022930806134677222, 0.020595019375304544, 0.07987215844613892, 0.016871098534113938, 0.05438688766932296, 0.033424848976034316, 0.028073460524601322, 0.03019145997841993, 0.056050336514148986, 0.0677866158225844, 0.020850683983054855, 0.06405039735498928, 0.010363679574502092, 0.051140919507991885, 0.057982808624904965, 0.03693653856434169, 0.009718434359397619, 0.0453633984791175, 0.008780429601639269, 0.016322725137034734, 0.06703548959546513, 0.024856341319278847, 0.03663861463146825, 0.02002469947441451, 0.06912048215106611, 0.03426119865429017, 0.041903243625476476, 0.026051273772252664, 0.06262844240653419, 0.04999591300504343, 0.06535687604017797, 0.02384092816482148, 0.013964001705209094, 0.059920811890474254, 0.13332085653899178, 0.024860455211432233, 0.03861526320237787, 0.025244631068480593, 0.05096434390232448, 0.03976948574305542, 0.045059479908236576, 0.011613095243040834, 0.021958408817168207, 0.03749649904127564, 0.05529670900995693, 0.09078915651527145, 0.007854209670181116, 0.027704841998075286, 0.019631966415251938, 0.061651320241752176, 0.06535744294524193, 0.020442420406447306, 0.08168656108600479, 0.04191808274856979, 0.0682756557099281, 0.07473372328545778, 0.013999876645093244, 0.04676011466090718, 0.05944292241286847, 0.019772623988589453, 0.041806873595041615, 0.02177961921739963, 0.05441258608874294, 0.05750566608302536, 0.008267483940618414, 0.09822796985146501, 0.016371752848968874, 0.03406383142235779, 0.03412226094834266, 0.05720397299756447, 0.03650851374972732, 0.0013590500325775677, 0.07164037516040188, 0.026910878049450058, 0.05230589792312634, 0.04681461415584049, 0.0723481101674899, 0.030744849336183364, 0.07217551055814951, 0.014129534153447998, 0.007470565286630224, 0.018933110367206317, 0.04599981453089465, 0.022088011741758357, 0.025500793633381688, 0.04229715837526225, 0.02101272690079866, 0.046666655764584584, 0.03184070172269018, 0.05148339145366223, 0.01202223311749197, 0.044745701785770156, 0.043317553016447255, 0.11924415180880217, 0.01537655867005308, 0.09044053288356912, 0.034664819738076585, 0.07020126367288251, 0.07631535010953104, 0.022435700746193048, 0.03566528460191142, 0.05081995931123534, 0.03078617594925867, 0.009345663636321984, 0.07399762004253364, 0.005005633819007105, 0.010316683910787106, 0.012700497679742835, 0.01988607203407634, 0.006486363511817951, 0.03535267476352953, 0.0798674316836461, 0.054304176986578016, 0.009094962320711103, 0.04558740258817712, 0.0460641122903795, 0.08710278738890925, 0.028276330183049845, 0.03729892113516408, 0.035230012595533364, 0.014815147414112525, 0.043776995096836364, 0.03795963366545978, 0.11032526426377798, 0.041147808153783126, 0.016673514882342953, 0.03124916693195701, 0.05328439138529282, 0.041461701189438184, 0.044836896892276504, 0.022359750789379882, 0.005095677399602269, 0.04040635378670789, 0.06447517778724432, 0.025287441976909197, 0.030064222350295995, 0.03914065396172866, 0.0341452474165107, 0.020280616891179836, 0.04540802693114646, 0.05252585708794575, 0.04919325970413704, 0.021622326044786363, 0.010205040002361903, 0.13290647958074847, 0.06653966216911232, 0.013596907693652377, 0.006347748041603595, 0.018535292399446332, 0.0435230216281789, 0.06103769530572238, 0.0288699027676616, 0.0693243304868379, 0.07000598786098343, 0.056665041634152015, 0.051051915412948984, 0.028589457130780625, 0.08192248552316621, 0.027455704459439845, 0.029045819537714127, 0.02273517026145372, 0.046079227205125556, 0.013956817715699154, 0.04849955942782183, 0.0408086686905834, 0.07649541141525393, 0.01195438645569788, 0.06907667724355575, 0.10851843057260399, 0.031438821573711695, 0.03475530621325297, 0.01757353795842538, 0.010019618953998772, 0.06061842687608254, 0.020050009104212927, 0.09432465228582583, 0.03521172224634117, 0.050210199288783536, 0.06402114045716102, 0.034689376686489394, 0.0378900001035823, 0.021483976311320742, 0.030774184758023872, 0.02113353513601807, 0.025584166982181133, 0.03358462044308263, 0.03379074789042916, 0.027812050257418907, 0.06240857134182608, 0.06465751437410232, 0.020097090952819394, 0.055312570860429164, 0.0291463436799184, 0.10062682096876445, 0.023481405017176465, 0.03513524368886025, 0.04971190505931455, 0.033850870470726685, 0.07317838859894583, 0.08966744291566073, 0.04065701775553246, 0.039690004120911324, 0.02354975346656096, 0.017674177013818296, 0.06477173808361254, 0.03309220593843249, 0.027874208716375214, 0.04300898429186594, 0.040689917401440685, 0.026985630993881536, 0.04118179564454383, 0.0201589621288041, 0.03047320987999199, 0.03930818972988956, 0.015074360924172065, 0.04456694282951855, 0.009885437696451142, 0.02868323778403142, 0.018933872624690977, 0.03186435851779196, 0.005901281575431988, 0.021127553904549252, 0.05694362184693737, 0.03137974278821099, 0.05095420089820701, 0.022548296518864173, 0.06774064288624833, 0.09935186680165992, 0.07440559250572998, 0.027119449317275036, 0.022348443331617503, 0.08305746010474621, 0.03231623164948917, 0.019157735007484595, 0.08207548094252426, 0.02358993286296966, 0.004633192992543862, 0.12254378442922909, 0.07256916483804103, 0.02431285173271693, 0.02232985420813484, 0.03940542160923924, 0.06278562066595882, 0.06265176595338891, 0.04950583889900197, 0.051835592715970935, 0.04398707555787217, 0.07084385822376899, 0.07005052055202185, 0.022627810699745052, 0.03169064042008212, 0.0986776021759837, 0.0668959390191782, 0.015063631862792519, 0.07021283160053915, 0.04460679855377925, 0.027971545932814482, 0.020372884520780177, 0.08061681123029801, 0.09944299296025308, 0.014759308222921626, 0.04585536482233194, 0.027516851682336103, 0.039106053600628535, 0.020915096655728358, 0.11483079588581478, 0.11738487939921119, 0.10281133600660872, 0.13045118310518805, 0.21136519048483143, 0.1891067663147565, 0.28746974384111745, 0.07924907615468388, 0.22389863407419575, 0.10431454607075262, 0.198050367856218, 0.13523665857651543, 0.16538788744759175, 0.07713395336102094, 0.10582372395982666, 0.15069923934436616, 0.18017168367101302, 0.10904569824736927, 0.10478508493472492, 0.12618198960779176, 0.11379865328631095, 0.08823786922279866, 0.19913537818337643, 0.1006488076921913, 0.07101720859927517, 0.1940575942036606, 0.2672783014995437, 0.15159182370670382, 0.23725879378616813, 0.093988822322459, 0.13394950828965635, 0.09763075834921292, 0.18637115826770184, 0.10591804470506408, 0.24486672103164658, 0.1572263084592358, 0.09564106713139242, 0.15957332606757843, 0.09677632516550441, 0.090962108525057, 0.18254364510217022, 0.24313237457986803, 0.15833975597014352, 0.13984970297784577, 0.22029319447615456, 0.11621477968630292, 0.10282549331144941, 0.10928968959037336, 0.1331283233218616, 0.1059700237707265, 0.11234939879467411, 0.11355076255577226, 0.2079700726655222, 0.07533712477813806, 0.18085693399752342, 0.24635777328043218, 0.13239739883330562, 0.11244383445310016, 0.1288974035771624, 0.09059102319541479, 0.1648659211012625, 0.15888888779426777, 0.14512553600774658, 0.13280717926400323, 0.18711611748703066, 0.20010156827347897, 0.1433750251007657, 0.14969336589978588, 0.17152664191540212, 0.11269898003628177, 0.125447096783788, 0.13298052963950943, 0.1237247932341791, 0.0732860699175827, 0.2444343256854242, 0.20467886701226237, 0.12555615706068854, 0.0866708976607169, 0.18568452898292773, 0.16577142170600354, 0.13126164284204284, 0.1276649443072177, 0.15617604788032272, 0.14147934053213368, 0.17294434890631707, 0.13692194475762307, 0.15108628228547114, 0.13093297580076804, 0.13120449268289153, 0.16498596707899726, 0.0877524835748538, 0.15968474589528578, 0.1832949168859951, 0.10025400428041335, 0.08512062681538445, 0.10768337941337978, 0.23207198017306868, 0.2959310317472104, 0.15291393824642704, 0.1167569401103162, 0.15665770268007634, 0.1592709818073819, 0.18427570861193443, 0.15909361713115247, 0.2337452540955236, 0.0908665926826577, 0.11244754231865368, 0.17271596277433057, 0.14995386643755823, 0.2692669431769079, 0.20507571587879814, 0.17944022292091003, 0.09702480578374478, 0.10528688018600788, 0.1297705752714988, 0.17166449177649715, 0.1105209767457939, 0.13369171970313595, 0.12762987280204413, 0.10592550640144657, 0.10274460974840388, 0.20212237032190447, 0.11281433755591994, 0.08889369411213745, 0.152146348789815, 0.15443048590133268, 0.2099296796105562, 0.14854689999934167, 0.1294783893371782, 0.08453848426260295, 0.14449993328702065, 0.13607350238148244, 0.1598999093496992, 0.09002288472988913, 0.13352371662134124, 0.11043299154769029, 0.17683437484647, 0.16785611548731405, 0.21635717261702786, 0.23313584647351698, 0.1302141095361402, 0.17657140750558148, 0.14572651666258613, 0.12352131262061097, 0.1029538130387664, 0.18907267540212602, 0.1549689844250679, 0.10608652276137184, 0.15375769216447108, 0.2758260041234955, 0.09306577830425194, 0.10621681133465422, 0.19763363134716788, 0.10816999846288275, 0.10965480709508543, 0.16235402604985624, 0.18603067815063462, 0.08293093302317205, 0.17094962449083406, 0.19343798229050255, 0.11992826832518463, 0.14187246621135743, 0.19585184873111788, 0.13891158234928885, 0.10040684648218656, 0.19468705800752487, 0.09383562772024064, 0.10042415240839606, 0.2520534991016311, 0.1446228750771092, 0.15960340267948567, 0.11512046139086447, 0.15802336165741568, 0.084607899489422, 0.1697121933102608, 0.16169091566435753], [0.041812320480183254, 0.03295061373782735, 0.041442483873857607, 0.029790072040932796, 0.045509043284842086, 0.0443177497495086, 0.03013590902781054, 0.024596878830643914, 0.04489590864508383, 0.08903240965258691, 0.023420872579839443, 0.020440524338834712, 0.03782392885055273, 0.021946295051865523, 0.01984185343908687, 0.04803257521181818, 0.059249852934191306, 0.007171623414427403, 0.04648635697160517, 0.011932468680184216, 0.08064677292901663, 0.041087256564248, 0.017469865194852316, 0.028766528778379003, 0.03209099030843185, 0.017599797537249905, 0.003656410779278245, 0.04719911368503686, 0.033148126526465344, 0.09071442463825788, 0.006654118572647173, 0.06484007312645836, 0.051041029303544955, 0.012638732798457628, 0.031082891378431555, 0.034236059479054906, 0.08473318550855884, 0.07358874359558668, 0.027018178239344593, 0.04575948891860824, 0.01885186482761656, 0.016654536969238715, 0.029582065762951974, 0.022594413096686045, 0.04733846124802386, 0.0605299705339055, 0.033443694738971616, 0.043787957815032814, 0.06085627036349428, 0.018536744136062842, 0.03913095528860727, 0.04861988119720932, 0.07345497698312806, 0.08134024337895455, 0.03163486730397469, 0.0101184347201319, 0.03385969963405402, 0.0450127370535366, 0.029240348413887046, 0.004383254413222594, 0.027918682035599506, 0.014834110963068184, 0.045900617636019186, 0.05901525765957852, 0.057454522053200396, 0.08060540418110548, 0.030488897445461446, 0.08489211810933006, 0.01854225039301861, 0.017936734497667323, 0.05065493248102646, 0.062083344035331285, 0.02711663968981274, 0.052709415585042975, 0.022739705501965458, 0.05409985750673279, 0.007509660668626068, 0.03628489651506947, 0.03419752908690322, 0.010771703748633305, 0.05369016900658608, 0.02589654890940555, 0.024252957063576868, 0.02738623560646609, 0.06913467776030302, 0.0618926149552628, 0.03418589604177302, 0.03025737226820521, 0.06259707876691414, 0.04348800374916004, 0.059298396095513344, 0.07610289860636958, 0.021342037455929865, 0.051064981042497584, 0.12006415700119351, 0.021326662071289557, 0.04122399942829244, 0.012033906382238193, 0.04658312153732104, 0.0723531203825147, 0.038299780534279924, 0.03351617814792741, 0.060136385201927156, 0.052696166094392545, 0.04154368408865506, 0.012799260777331168, 0.05522080884885885, 0.027835471480483973, 0.022173177736300616, 0.03480766449243792, 0.04199330875229451, 0.08013682650221933, 0.01982928959712867, 0.15200934162543667, 0.0537142624718047, 0.03160050059969147, 0.015253043271631244, 0.04800822127670531, 0.031462945682447285, 0.03296632237071472, 0.04405751351207014, 0.04447428066463721, 0.04478597119750996, 0.02832137806821735, 0.03819294191235977, 0.044807973242695295, 0.03664281279329331, 0.020454733354610302, 0.02060487701167022, 0.06649974132737806, 0.002124475051401063, 0.03468333991364606, 0.03932377578870904, 0.033485216704467614, 0.08000977081997741, 0.005521552858784074, 0.02591346796121328, 0.02708889006997549, 0.02332266968404574, 0.03462796707847907, 0.06580528262401782, 0.028811109349912697, 0.022479476925406246, 0.05803446976407882, 0.029217944172541463, 0.04493036727991797, 0.0674425580749108, 0.05790952848450792, 0.01629914495072538, 0.06340284621523273, 0.039032317637916536, 0.044893506959441214, 0.024209347508487203, 0.031584127385529785, 0.04048461732905238, 0.06314788832359257, 0.0355773875039191, 0.025858294308906602, 0.06886505311535251, 0.034544965282322905, 0.04487712416918047, 0.0005479579140815223, 0.06190477660106075, 0.052805245523491216, 0.049850743173831896, 0.04041188111108157, 0.051318678719502304, 0.011267869211282703, 0.011521700953674174, 0.005020048242107395, 0.06818000197170243, 0.03669821627197727, 0.0244675325455084, 0.0611386044071086, 0.027653123402307113, 0.04312651367076943, 0.03825388420673628, 0.03654042514221322, 0.01594104576900962, 0.02905688759300017, 0.06514035661013858, 0.03427083987081724, 0.032997283814174515, 0.016597754532291044, 0.06274213368493704, 0.054080008168614684, 0.010847235229917833, 0.08434349956411509, 0.009382565134024669, 0.053493770875877915, 0.03069909665012552, 0.03513000364745817, 0.03247201562889161, 0.024472002668546575, 0.011491922158447486, 0.015840462254991215, 0.012628843560965072, 0.004068436805203918, 0.05587743046963888, 0.03538092425573738, 0.048234094640300165, 0.044796141014704784, 0.033965641933102766, 0.01376674076797621, 0.0334666543940623, 0.021101591184795387, 0.11270418177328764, 0.06762200651029426, 0.04361298333312716, 0.058136133462070465, 0.01990482012080329, 0.052955597939510504, 0.0845060097954927, 0.03386171444529488, 0.05674701304205003, 0.05660138355808393, 0.01899807079274568, 0.040162274343592506, 0.03320030477498809, 0.012928540987383216, 0.03012225351056024, 0.03353639520824917, 0.09259728489503746, 0.0573740751602717, 0.025576465883322304, 0.04328980531182982, 0.018895056864787495, 0.042281775329742706, 0.04652076198028461, 0.11217109183029783, 0.058680703232605616, 0.041573385317479415, 0.027546420760993517, 0.008831201121211052, 0.05278305961720405, 0.024344016189476656, 0.04021978839450786, 0.06150906920553215, 0.07808826142741788, 0.1185570628712735, 0.01919317615008162, 0.04268489079549909, 0.04298066968218454, 0.08343177066454965, 0.07594134598489731, 0.04453284808644845, 0.03623629972759274, 0.051751878458045186, 0.030163878897926023, 0.053469508871315956, 0.05268536042422057, 0.038909532895852486, 0.026212814902406067, 0.03702916625526644, 0.0732465704242068, 0.007853251581470813, 0.034681623876695676, 0.06209396584440143, 0.019675415091877504, 0.03043494378817418, 0.04092283877393892, 0.08928822939314189, 0.029401751648214076, 0.02799247353968601, 0.019407719073276368, 0.06347592334232985, 0.02006878208879742, 0.08366614760410401, 0.04257799088654499, 0.030331939436315052, 0.025770847287569797, 0.04744962443627658, 0.062432059597584515, 0.034009312775226376, 0.041199400345043796, 0.020804124989456708, 0.015456306507750867, 0.020864831711796504, 0.06197970000005538, 0.03113920650174541, 0.043702385793890686, 0.057230042969627734, 0.023321704413261146, 0.013471402381847223, 0.018157281634968617, 0.0176536669248655, 0.06173773112917139, 0.07098015292637772, 0.02542869709882765, 0.038014110177755356, 0.06472976412624121, 0.004231099775361439, 0.02442408003844321, 0.004569818847812712, 0.01271551970632807, 0.017511856389201937, 0.04206426381584137, 0.01649023026167866, 0.06343342461473038, 0.03489628554351869, 0.041467109770183606, 0.08458904606560547, 0.016327162701336127, 0.01206028278947117, 0.02848594333045185, 0.05517257595314615, 0.049132045448547414, 0.0938488657195722, 0.041209543349161264, 0.045041101458933086, 0.030615863112372257, 0.030948458269478816, 0.039907396891184395, 0.02470301265167373, 0.03276856060350134, 0.05263024039806859, 0.02836822626000691, 0.032745083839061766, 0.09342752502209718, 0.01767593901604414, 0.05367493151777214, 0.02951385329417404, 0.02242403705754588, 0.08341892337005946, 0.03423466902947234, 0.03570734665939405, 0.019011157489712202, 0.01635626063592011, 0.07329950709977458, 0.011545512881580622, 0.06496138314926816, 0.04071797537166746, 0.074927804000195, 0.03828672256561057, 0.05645977986615993, 0.06397897497780862, 0.01954235711074885, 0.00827738754225955, 0.07320698666115923, 0.022794662734433528, 0.02543160823293992, 0.05534154430572545, 0.025156033000037558, 0.01896384581472845, 0.056622021966764045, 0.0036410669957648123, 0.08085897162316308, 0.045134361172395374, 0.04128170500118886, 0.024872400437391577, 0.02806104606978836, 0.025799878189460407, 0.09141938640706002, 0.13908557623865145, 0.12571142010030248, 0.15123956115736117, 0.188245928636001, 0.17091439976807565, 0.11217355863341402, 0.10735325680504884, 0.15175081759450898, 0.17512759223820704, 0.12275507913962488, 0.15888338728297144, 0.16378688625991344, 0.1507632689730775, 0.06483687087893486, 0.20625700813628015, 0.11167249116565912, 0.08093242413334309, 0.11252406684141006, 0.28525504493905657, 0.1514775999971936, 0.09863524517465024, 0.13814915632528646, 0.08870288459283691, 0.1861645443545234, 0.15087456622671697, 0.17848717889958815, 0.10774060618132354, 0.1573066710824928, 0.1642073153127586, 0.2729284757327649, 0.2404924355927975, 0.11074550179464203, 0.19569124605867172, 0.1213025764351891, 0.10713526648619484, 0.16704700406520598, 0.23726996334810413, 0.1857995800673962, 0.303933861995897, 0.29700340162361827, 0.09682295693745537, 0.12803956130219082, 0.06632686592638493, 0.11617426129598772, 0.17372543683215497, 0.13808204702311946, 0.1088808514478226, 0.13773208273754967, 0.0844502768990013, 0.06608455997681426, 0.1333362702280283, 0.18894582656362366, 0.2517896890640259, 0.14597491301115484, 0.15139277874221727, 0.14541830416888962, 0.12539389963832595, 0.16563873527751816, 0.11259963375426109, 0.20045046003595476, 0.18806038214074028, 0.14130792069819667, 0.24515208878344108, 0.15741734014403436, 0.2086471411730013, 0.0998021962661897, 0.16278329575734754, 0.1466345453574773, 0.10575130566834443, 0.11478626319477636, 0.1534987391243058, 0.07820394070398423, 0.13072052429760658, 0.14327650619370325, 0.13844967729622318, 0.10551793996485011, 0.09113734347685691, 0.14032245583591924, 0.10098430057687145, 0.1958620377005108, 0.1163716821540748, 0.1669967486973732, 0.22297742866700698, 0.15761264659945043, 0.30786953145457857, 0.15652854025604265, 0.17036626385825296, 0.13830539229656422, 0.1489441165880811, 0.1078698528750289, 0.20713485296695464, 0.22789185205774926, 0.11460391894703913, 0.27828925259170995, 0.10142706109270935, 0.13958990724096376, 0.10077636899246324, 0.13000907376408577, 0.16385899045534674, 0.1288752329926337, 0.13717692946234059, 0.1187080281576322, 0.24572594992576108, 0.1844893398904993, 0.1554553583264351, 0.2016360730293297, 0.1048555956672757, 0.1677559877956106, 0.10772883907080659, 0.17980514124276178, 0.23057630075322044, 0.1071679937623201, 0.32964279214220665, 0.19226618952328162, 0.12935409923234295, 0.11117545332038596, 0.15272952556129427, 0.19260250212204075, 0.11799370479439536, 0.16932953239208268, 0.14783030135496972, 0.12454402467776692, 0.08498531270531878, 0.11619459326949813, 0.10890686013285192, 0.11351959809901253, 0.08857366088176928, 0.08316630587702797, 0.10825609142381339, 0.15573232975457946, 0.12601381032577447, 0.09633098293336169, 0.11753595959875854, 0.12577937209918616, 0.2999309913044976, 0.09741952492585106, 0.2414745449899666, 0.21521570160984996, 0.11276803520177642, 0.0778789738673837, 0.1781830573154073, 0.15845335148755582, 0.10252326396444153, 0.11868129934995406, 0.1677781430583808, 0.10751880840548586, 0.24871569998081655, 0.13577857385239295, 0.11627255803755215, 0.0891317559346076, 0.09194817093591537, 0.1512171760682137, 0.08623629598127258, 0.12000424892551477, 0.20042427515070285, 0.22710938517364765, 0.1722407890784164, 0.15407577187063234, 0.15474439808918586, 0.1073750290238569, 0.11554216981054315, 0.17323858795627473, 0.10375492650294497, 0.09196978993713857, 0.15422404052749758, 0.1037349928951552, 0.10550158398766672, 0.1133404024726441, 0.1170066234865977, 0.1641472386977365, 0.1561032388839991, 0.10426249039629776, 0.17321010480724996, 0.06508053280413151, 0.13494157682984106], [0.031130748891061356, 0.02867642917760438, 0.019501354169821548, 0.02765234773828378, 0.05169315781864909, 0.02941320466268207, 0.03363272693428782, 0.002291080740941388, 0.029425898739587397, 0.02444286834478619, 0.10046038836721452, 0.05141335952606413, 0.01416699872577503, 0.05710235909528791, 0.040947809409830845, 0.041267677931295293, 0.07977164771047332, 0.10448218143034367, 0.01692668778911954, 0.04932508811414723, 0.035814928386600754, 0.05084522489097811, 0.05703024723897538, 0.0586902218750648, 0.030667738756164912, 0.0558067741803825, 0.038170388283868956, 0.04868113375719517, 0.02459719101147306, 0.10855233762413265, 0.014862076045134136, 0.023889800743950952, 0.04063505784518296, 0.008181675389829663, 0.0590071103145038, 0.07222594978708415, 0.027107668800219416, 0.04496083076622698, 0.0163081867034517, 0.07409246938843882, 0.06906017570966674, 0.028454196646869667, 0.058560910063885876, 0.050038848402759725, 0.006376021952864024, 0.03286868446476517, 0.03584904228186896, 0.036216346967604854, 0.04532152028273671, 0.025070612281260472, 0.030526669410568093, 0.03029930026030108, 0.028059048495525797, 0.030115935200404738, 0.016527262951938376, 0.05102354334667326, 0.012665542045367822, 0.02406378314199467, 0.044922392304626205, 0.05748656368063343, 0.017156383931456555, 0.06009203254155094, 0.070184777460752, 0.07573968866058896, 0.04985525543170591, 0.055801231534250324, 0.04364995090591331, 0.06447655674550803, 0.030317887468563936, 0.0635597831569612, 0.06427171249543467, 0.018112208851943576, 0.026377646380194256, 0.020390337918915098, 0.05603663120118361, 0.011869185029589122, 0.051916464787697604, 0.02464011108743087, 0.0816190380963587, 0.06138954799802554, 0.007325645870408945, 0.020978319976899414, 0.03078461121467333, 0.01303584692293718, 0.03573229814308786, 0.07141046451344606, 0.06859822469132562, 0.004921113732346004, 0.02768148972292341, 0.04504627255242198, 0.012620791019270978, 0.006695921117845442, 0.046209033143015645, 0.06079985181831064, 0.01841098314241296, 0.02801170043136564, 0.02256834503984259, 0.02056202396840578, 0.023183086549022028, 0.006227720258457046, 0.007624202783429816, 0.030935214524487817, 0.07361396321005399, 0.051578539573857864, 0.026626751360092914, 0.03086956270459679, 0.026684029838971557, 0.013606851514909538, 0.10911938824480581, 0.020088541411584424, 0.042162376696303974, 0.057477588960600484, 0.06993641175570027, 0.033772177919144594, 0.07317194579950265, 0.08551257271920482, 0.03842486737055644, 0.06678250438022999, 0.03870643915668611, 0.034386856226070274, 0.019801348455310352, 0.05559699249363715, 0.0303306773064598, 0.04350843148366098, 0.014782228616006194, 0.053295246851179874, 0.04140665777207863, 0.11046043281713802, 0.03597933085515134, 0.04529465740967182, 0.06979447864596883, 0.10321655821415687, 0.013355154284997093, 0.02262853273761369, 0.036921906284987926, 0.03584030504909254, 0.011433249399546656, 0.10540491135250177, 0.03798856497592023, 0.020963409990673105, 0.01566154625071513, 0.06534153129905462, 0.038052318812978846, 0.0546047400923506, 0.06508053280413151, 0.04962360576516198, 0.04258654042777996, 0.03325670416797361, 0.010666761194325743, 0.010149942958847651, 0.048899468815615105, 0.045015774592156374, 0.03791873223118244, 0.019262422837557334, 0.07700657592185083, 0.037901326713542786, 0.04624353391268561, 0.021958860809043534, 0.05890276530877717, 0.032457425484373685, 0.07199081442048473, 0.05933127275878384, 0.0586332900509719, 0.016102515078420122, 0.0945224485269958, 0.08700448298646558, 0.005691381145058381, 0.033130904869927515, 0.04911527195344529, 0.07043830659841338, 0.051106916695472696, 0.023296270294175036, 0.0772114048501657, 0.017539027612656355, 0.032095889440707626, 0.03977569871612134, 0.02162419912976123, 0.03470644129500274, 0.027848498805636362, 0.040271736816653324, 0.013710687072166513, 0.06678848752691861, 0.06399497855454683, 0.061557302101244854, 0.028333601001049244, 0.030331202076687932, 0.10500557270021209, 0.05626709726188452, 0.010610254549030817, 0.061843807493606885, 0.08278941360091971, 0.04479867676573415, 0.03458041217057936, 0.03291302563382253, 0.02374825259340146, 0.07148421579791654, 0.04083346695669236, 0.018503340787344405, 0.03849113780644633, 0.028119653711215626, 0.03792148248683061, 0.06568037964884313, 0.04872492717338666, 0.0717307965181047, 0.012998185082969647, 0.04338803693592068, 0.0357760111200473, 0.06586440162913454, 0.006709579986730411, 0.021185935550038854, 0.05055129993706942, 0.02868457843789891, 0.03582502159500315, 0.059745695682302605, 0.05627891033767693, 0.01977829878488856, 0.059683719169228315, 0.04886427856681328, 0.054168652202333176, 0.058039208017890496, 0.017853866766897902, 0.09227565820178679, 0.086377723472974, 0.02853180326881909, 0.009874094807122265, 0.05936980315093553, 0.08168840735790231, 0.025276975300643715, 0.04101933520888129, 0.04511605167100507, 0.032337176493339004, 0.028813968773090073, 0.04621389780133482, 0.04355638475728132, 0.11883664665923965, 0.023174774495043585, 0.026233434158888076, 0.04069494676866359, 0.026170369800961307, 0.04028258079122152, 0.01979129546652398, 0.038973907264129776, 0.030424228133333307, 0.04077400704244933, 0.06475157464944548, 0.05158539223034055, 0.054861578729844866, 0.05120152089324209, 0.01909080573597983, 0.048431438889594815, 0.02670545157255425, 0.04418088048095665, 0.023174040965856086, 0.016963343181076552, 0.11263510362515528, 0.04052216712866099, 0.04624867436265753, 0.02788328494305813, 0.0202793394395661, 0.026585991652081573, 0.061852874144190745, 0.03081619127413198, 0.08825259343270334, 0.03175935850689008, 0.04115791285350438, 0.03860354205713638, 0.03945648519983215, 0.04277291429799892, 0.07158255850475642, 0.061344555654232545, 0.04668704902512893, 0.038707136296697205, 0.02188387995345458, 0.027478043583311865, 0.07337070731145721, 0.02779031442778726, 0.02497634516217776, 0.047324460991207636, 0.05262746332934307, 0.004080102887875851, 0.0740860955369088, 0.07437478044941541, 0.03606004204841391, 0.052746187805408434, 0.011135677867118391, 0.014201249559259704, 0.016266243389597344, 0.04700328245939267, 0.021932325438566266, 0.13103817499453022, 0.08340832071318742, 0.04031625035549364, 0.0124630659645904, 0.019990068469797413, 0.061646340670244354, 0.03086346847515914, 0.025112055722744237, 0.05858716389705097, 0.06138094100019625, 0.06085541234501909, 0.04561543374532654, 0.06409410267106949, 0.03548818805645551, 0.031887969347618283, 0.004432145665745221, 0.02848987527672322, 0.02532585362543262, 0.06671832153393377, 0.02934270925188978, 0.03232495356050711, 0.01989135037987463, 0.03350659821843428, 0.011377902419847107, 0.04224558150576007, 0.03498865276454918, 0.031786997043978305, 0.04990494772491436, 0.07209405242916077, 0.018445798008131887, 0.049300232391443946, 0.02205041597687429, 0.045702415368249344, 0.04426750204255504, 0.05465227201761258, 0.03526323399836979, 0.07548108802086885, 0.02062619723860295, 0.05823200936579417, 0.03205528103506133, 0.05323155047071557, 0.05495850034358521, 0.0322954208710261, 0.039499190771171165, 0.03146188082023254, 0.059442079716151765, 0.01129939851741637, 0.0016242840361120482, 0.032530200006740714, 0.03481102378798589, 0.013919537004473952, 0.06735109483763095, 0.053635535446266015, 0.04553904328795691, 0.03171070809325865, 0.04672595863080314, 0.0547384339264564, 0.024020974148785876, 0.017044964103749203, 0.010842947052761672, 0.07080193023167311, 0.02837701711893803, 0.03360871773874087, 0.08905569872548504, 0.1296506671895904, 0.1270967062502619, 0.12099519897733005, 0.14902245673921802, 0.10917766455320582, 0.11010693686623728, 0.15947722799835667, 0.19825834540590165, 0.13762244023382664, 0.3276513312612811, 0.17824622892564346, 0.08688026949042275, 0.1274490913736724, 0.20651020019525484, 0.16486590577950402, 0.13723339014236005, 0.15918911765179328, 0.10824096118730885, 0.14239919762457573, 0.11098582357648881, 0.0667394655606439, 0.16227948569482373, 0.15713050150342528, 0.11880003531733829, 0.2124740108246765, 0.19943194614062387, 0.13721710311308985, 0.11576405951693175, 0.320879849455049, 0.1569612880027102, 0.1585253637524382, 0.17959339454049067, 0.08508927849752289, 0.17117750500479054, 0.2247808149625217, 0.149148631420347, 0.18266263387856946, 0.16249674823014967, 0.14756004085704205, 0.16460554313755807, 0.12068192264245403, 0.1787533944532756, 0.2370209694509545, 0.12238093711916478, 0.2772842065220879, 0.141296383414057, 0.1469786414095471, 0.11792798977225058, 0.11689441458832835, 0.1405141616780912, 0.14996002578446943, 0.06916661596586628, 0.13381404862288507, 0.17098327107246847, 0.1607174937042498, 0.14432710385130298, 0.1049811268345483, 0.15140883594511018, 0.1645427086060086, 0.1933831763603995, 0.16602078332535683, 0.12195519141612515, 0.08511856603886812, 0.12155913928103064, 0.1808187368536188, 0.10205448710269506, 0.1249311212450266, 0.16489227452585775, 0.11724179715759332, 0.11765295654655465, 0.12501310031380386, 0.1618818707403637, 0.17157948666041897, 0.09211609740891764, 0.16919796445196675, 0.12154542630718601, 0.17287642755095037, 0.18251338462916114, 0.09819069201306951, 0.09883034478632674, 0.16164190135896206, 0.07257587576825773, 0.13035958963296107, 0.195187880327144, 0.14033379393719858, 0.14759839121853152, 0.07071795933429273, 0.12830072067557804, 0.1524172221580821, 0.11722386303928592, 0.08191656366351151, 0.24320507632388225, 0.16024448037628206, 0.12618916785164228, 0.08147466882702806, 0.13423843068941949, 0.11297312459998554, 0.14822115941393763, 0.09307838045060636, 0.07756315412059908, 0.15988023621180367, 0.17456557481519638, 0.16597754532291045, 0.20666692646280413, 0.1502805110067129, 0.07340074561896824, 0.181192756300011, 0.180617822634597, 0.2285022862375744, 0.10492988321329318, 0.18586745545748742, 0.16711825024216406, 0.21498009892961673, 0.3288017501754146, 0.1642424174614491, 0.08883671249232947, 0.22677635143120445, 0.15313357565431826, 0.15259352963297598, 0.128809962301485, 0.1161467127742306, 0.1452788455231536, 0.19102201676897465, 0.09091687869400748, 0.16862463957119375, 0.21196514458185245, 0.29965912202192896, 0.09290406480431558, 0.11306461848078236, 0.12651028892686292, 0.13860021357334432, 0.11598649314574658, 0.12079442265413462, 0.13957668456339067, 0.16820758130521546, 0.06668146504389663, 0.19957025565447348, 0.08569163811062613, 0.0785436777157649, 0.12353952253057111, 0.27829694411446976, 0.17063860811533468, 0.14938948946374078, 0.15290577174915423, 0.119146904607694, 0.11019437814191466, 0.11833777020294821, 0.14431573510650667, 0.1671962686363728, 0.12741166031769208, 0.15145901470415055, 0.10654242934599038, 0.14645284462359645, 0.18288496791595416, 0.10609450539754284, 0.17291094747281846, 0.07091703494229624, 0.31177152368810873, 0.151513360981499, 0.10643582055044752, 0.12531048032425104, 0.1783922606057698, 0.06261967069980118, 0.19007021381009012, 0.16194004745733354, 0.1504079727155547, 0.0919422720588984, 0.1519557614360125, 0.21269030808921785, 0.13010832811555556, 0.1372365617463666, 0.14077420256310894, 0.13569412031962028, 0.1278673294150541, 0.06283001929161049]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.016338495056956046, 0.07976647661698442, 0.09640032155138832, 0.032160976270754496, 0.020459772297932256, 0.019133534289956577, 0.03674692414220303, 0.038973443780935584, 0.02288338529216426, 0.04357380176623983, 0.04242051002239028, 0.0228482773978143, 0.072657035122956, 0.03300938417293853, 0.05570251344432754, 0.04269704094997818, 0.058945804128363255, 0.017017329397100597, 0.0292672936414038, 0.05553228104667318, 0.10164308256559795, 0.0953201452390321, 0.030902805174851132, 0.03864438220437977, 0.06947843673368616, 0.07828844786291161, 0.021029473582823432, 0.024933501695012374, 0.04584273586290018, 0.021773080656965895, 0.015382230593522471, 0.0747750154245765, 0.035360182425187486, 0.08228865256833454, 0.028623479095497922, 0.04957315504490849, 0.020855058345102498, 0.0029312094463215723, 0.04907974462595679, 0.02114342533112053, 0.015582110593846489, 0.006887482839726633, 0.0492043833007976, 0.0859173889001531, 0.0688855612890855, 0.07443599853544466, 0.07031441485929875, 0.07607978573369403, 0.09677273221313955, 0.037317502597767505, 0.025664290202961817, 0.014007668716893082, 0.028675327926213225, 0.07725348605984643, 0.04105295880787796, 0.026708079254134532, 0.044699138961732394, 0.062298848398871, 0.019963278375085325, 0.019689154878799475, 0.04540430374383446, 0.0455805269490567, 0.004310891663114871, 0.026860781644861546, 0.030488757634415265, 0.0746849924325943, 0.02423102588152453, 0.057576962055698525, 0.04306804200994872, 0.045798662824616324, 0.038074006762115226, 0.061888129510466135, 0.035902036414031065, 0.07065733113596517, 0.10868946736257885, 0.04351774711282023, 0.14032193489613073, 0.031309628506161036, 0.02443061285321751, 0.023598447930248036, 0.0451866083688313, 0.06208850746794094, 0.12613614690640282, 0.051764982391990004, 0.016332580858180602, 0.0418403018416176, 0.02449624552091043, 0.060795435321427164, 0.0008599649968786136, 0.07742011784425668, 0.04895061284544007, 0.05238184021906026, 0.040693966176120505, 0.031609754941816774, 0.07562590928207483, 0.052448719694849946, 0.06925636316619574, 0.1200453265600147, 0.027442022129112197, 0.02924951848634068, 0.0894363831368185, 0.05213341322697459, 0.016542033127118504, 0.05090747719570514, 0.02651723334565759, 0.036046286939733455, 0.04019854860680719, 0.02892400964253372, 0.06103357375268975, 0.04387281737440536, 0.048528329859818184, 0.02240951203050152, 0.044036744868442904, 0.03213597116090598, 0.0553585744402822, 0.03771262393603402, 0.020473230547542055, 0.02773664230781217, 0.006759170773288897, 0.00034127226993610574, 0.018119007882271564, 0.01710599832867663, 0.06321626550127422, 0.04662734779318975, 0.04838072769944707, 0.06589126067175981, 0.08371587437126907, 0.0029634564810793007, 0.059201409364299434, 0.0453840866835127, 0.02297158116444705, 0.00843588921857337, 0.09206552028415665, 0.049229560780429074, 0.052894655645133994, 0.03148536716077117, 0.04040564515537793, 0.049478976025937066, 0.019143667717974995, 0.027328752199067708, 0.05118606889980936, 0.021127597954604897, 0.08204336653673842, 0.022461747735618584, 0.07293776804280859, 0.01851799987977551, 0.06375444609852088, 0.04696741422277786, 0.04404809063060149, 0.04113173562913172, 0.06984839591407968, 0.023463302359525717, 0.023857305209422787, 0.08241043756565741, 0.059626687753705256, 0.03564357750057694, 0.03423218307415805, 0.06486881674537737, 0.04353380048527353, 0.009346274591441597, 0.02808645337579712, 0.0792082053639235, 0.04295621998608113, 0.09423150365511257, 0.015549684007231508, 0.06403693719015968, 0.05458799341032582, 0.005334985072559287, 0.039253992839686336, 0.014099917194295316, 0.06765724655481116, 0.012098227124360782, 0.039209391200734724, 0.03065326735527525, 0.05277828688943579, 0.02408183791915015, 0.021749125087573644, 0.018467399772376786, 0.06100388784562388, 0.01254719390999526, 0.026870830803208297, 0.01048062002331379, 0.048221978959777666, 0.058474947337902365, 0.018419002167760365, 0.04653444814105188, 0.05745767833544843, 0.04416062511623867, 0.07215951464229053, 0.04698257893323899, 0.05185977045086123, 0.008853728894234426, 0.0725318793387663, 0.06514201136005503, 0.0344219392225627, 0.01393060984780952, 0.07728280424470864, 0.07440740813411052, 0.012966409671090305, 0.02323157799940917, 0.05316243018774737, 0.013013096026805861, 0.07047074276112741, 0.04941057586561769, 0.08339849180511891, 0.01285054557581222, 0.027013443815972538, 0.056574919050739664, 0.04592977111197768, 0.06607634751426597, 0.036972100365786784, 0.02280962634681454, 0.013087584670903462, 0.07553880508508413, 0.062007811596436854, 0.0387808722594092, 0.047489143081850586, 0.06464541784577793, 0.04860143379999265, 0.03274909430934537, 0.04387079873272488, 0.04214406719491367, 0.02919394838353319, 0.10731345853738247, 0.02105697422408529, 0.03062149768905534, 0.018819258210339376, 0.060649721567789396, 0.02380552724184048, 0.0630980313214804, 0.040535309367002025, 0.03397500352753747, 0.042591336138185956, 0.05390628624046522, 0.031716162639279524, 0.05447326025234596, 0.05126340164532585, 0.06361639322412592, 0.023794633471557212, 0.03741740046309368, 0.022056567662906264, 0.0375922791840088, 0.06238113773325759, 0.05241498118266464, 0.025117868414869713, 0.022327138426443262, 0.045497655387847655, 0.015491509205481459, 0.06353008192813685, 0.028130543651059273, 0.06162177223051268, 0.11275612253455386, 0.05272106778237128, 0.027800317620858554, 0.09820072010399834, 0.021731501234875574, 0.03790152206596348, 0.019582025143468094, 0.026761935235211448, 0.050338764164236285, 0.04065138317884938, 0.045803263182601625, 0.048502520357649175, 0.07718079197671145, 0.03030918470974411, 0.04039036936216778, 0.04454124057965894, 0.005563122225970391, 0.11249579053612487, 0.05208588130171261, 0.0180832200848888, 0.05183956871229795, 0.01605806569944346, 0.08195132873351536, 0.023123994356982654, 0.002608647886400802, 0.030490567517136375, 0.09469404456115539, 0.029663956731617935, 0.013737068267449016, 0.033146061919509404, 0.0422220702673639, 0.022786653285185178, 0.043393736630077326, 0.05273681471965486, 0.0373195059176895, 0.05690250590804124, 0.013609026247004588, 0.030759477785097498, 0.019772240944627314, 0.05773573377800565, 0.07936825645306418, 0.04521133385658745, 0.015326051450815174, 0.07764981398659368, 0.04192005159453519, 0.030214335363838943, 0.018027006468224912, 0.054635054191514376, 0.03598504204062685, 0.04188728984445334, 0.05542515514178142, 0.03289910581623835, 0.03500964740411409, 0.008580314029278535, 0.015711345796232984, 0.05165894816239035, 0.00830659943242227, 0.043210124506825404, 0.042753302447137334, 0.0659133086822206, 0.07720374397092289, 0.05783144114238601, 0.08268213064800348, 0.02364202301138111, 0.0604512052039706, 0.04653632505646637, 0.02431348567047427, 0.004923659538279378, 0.017029458484161767, 0.02112064762191186, 0.016144674812113086, 0.030835180678555084, 0.028939139879038258, 0.036337898308110815, 0.03270657642954781, 0.026301443614366076, 0.019942940655915488, 0.02580329685682251, 0.05114712865061818, 0.04469557665288449, 0.024866423036362377, 0.011084987744388562, 0.02645824074504837, 0.0471413123511499, 0.05068753718308384, 0.04048681217095545, 0.03178740690101779, 0.04328066588289315, 0.01129562553438929, 0.034369557960740024, 0.012312110254330742, 0.03384413655787226, 0.054904303453381986, 0.01739467941074362, 0.014938399469810388, 0.06363577524861021, 0.011862068072772555, 0.023971883234597986, 0.0032524650657339204, 0.09795889678981998, 0.01757470624250991, 0.06898231053304288, 0.1067763849371864, 0.18358684235042144, 0.09751943045205648, 0.16566634508630923, 0.09862509450965351, 0.17161848053576487, 0.11794623032572771, 0.08163613717882864, 0.12788950766046203, 0.19940372346149338, 0.17708730643555043, 0.22871073876177112, 0.10177830474511271, 0.11174778994773665, 0.20402249820049734, 0.23435380369905504, 0.09974788063235822, 0.11437094394838619, 0.12258644786573226, 0.2800333283601269, 0.2837785177173153, 0.1155657499968525, 0.13488914577230332, 0.19724281925347545, 0.14725026554398, 0.18295288927132086, 0.25688714618163727, 0.25835484807049075, 0.09839172880615919, 0.11782672827041919, 0.19806317684631194, 0.2605208850676014, 0.2327080323330818, 0.11553761924827292, 0.12633247225875818, 0.11843634273616538, 0.1487762973673882, 0.13644667913115796, 0.13128315459095663, 0.10368634631196338, 0.13831749648576783, 0.11039222034836009, 0.1803866632643246, 0.15268360625111288, 0.13416159207061415, 0.18684504493590326, 0.21260556344303394, 0.22481924193280362, 0.24274467280314815, 0.08625611467587371, 0.11419382442029254, 0.06475200365868307, 0.19462823777669863, 0.2719266472324249, 0.19209742035356261, 0.15413111406228236, 0.11171915358112705, 0.07149526278578466, 0.11078489403570853, 0.09262176906509746, 0.25198438264910256, 0.162371845254975, 0.2544262112989541, 0.15458160440527624, 0.19680406537748155, 0.2859862911845407, 0.13379405372806136, 0.13223596878590124, 0.12134507133234894, 0.15407126727363757, 0.18184763890120292, 0.1539838259979602, 0.23839588277041915, 0.24074375839723697, 0.23989667965760156, 0.2689639400810965, 0.117260497363825, 0.13677471798033486, 0.19423852884961715, 0.1373742124246013, 0.12518188480528133, 0.2341449528091377, 0.21905677453164132, 0.12192254074879232, 0.12675745953475276, 0.13017064170731654, 0.14272423340908943, 0.06510778255159817, 0.17793227077251483, 0.11493502214791314, 0.12309552095229588, 0.1172915469073961, 0.16655638603673828, 0.22203691784412632, 0.16284778503881348, 0.17151395549937604, 0.22622815423434783, 0.0865700651681231, 0.16347864312269997, 0.17790732694970024, 0.22266500268972692, 0.1952999743122247, 0.10870770025517672, 0.1579230194610934, 0.14070476435365217, 0.10489710997189246, 0.20480628275582868, 0.19112199124309326, 0.11798618947185817, 0.14576719593136542, 0.1359165003222804, 0.1909986664090426, 0.14053061724670474, 0.1512013027264226, 0.2161740929248833, 0.15209731916266103, 0.2194380871350727, 0.2567754505622772, 0.12098956057020735, 0.11850405724779253, 0.11045127040556363, 0.21332075248562524, 0.19280710888485755, 0.2093237347059673, 0.21657670277260968, 0.081235695359928, 0.07402356744052903, 0.11176396972469746, 0.13093616272653305, 0.12543477808996556, 0.19098342125934942, 0.20799524631471406, 0.07483121563470171, 0.1260157638499814, 0.1687672544991778, 0.12034937153540312, 0.1917354284875816, 0.1254669844263023, 0.14212034162013762, 0.1678752217201456, 0.08581368357784326, 0.13928452927258708, 0.19394412126031615, 0.15722690600781672, 0.09498644500009476, 0.13350050415723555, 0.16579719290377634, 0.13729064755382078, 0.14573765558100518, 0.14826288056229392, 0.06350852038350797, 0.11494436842058936, 0.2694933987673252, 0.17511323575050602, 0.1061709379897483, 0.08777031810173104, 0.13353700058594828, 0.18270452356626912, 0.2202435519786612, 0.12447460179006863, 0.12665145594867008, 0.12799544229863152, 0.13013992158155288, 0.09233578078208432, 0.12039503803656948, 0.16976525255989644, 0.10848029471573331, 0.113948714588919, 0.19150538760567867, 0.16076681444481497, 0.11207538446591747, 0.13148759281443012, 0.17210238763401586, 0.18037662751251654, 0.12920334845060302], [0.02148213961552228, 0.027884116148455974, 0.003342895520730846, 0.013291943412754807, 0.046313412622698856, 0.07945749803536362, 0.04215949237526905, 0.03331024605300158, 0.06948219822539438, 0.03462660727241347, 0.014544131361969538, 0.04988289205357433, 0.006315191698846438, 0.018664659751999765, 0.047620527160864685, 0.011356962364046805, 0.03459479547135773, 0.06154853805539109, 0.004655832327121208, 0.040527338222149885, 0.06140624488433523, 0.0444874343942971, 0.03643157170905221, 0.049475111112359076, 0.047952005744821606, 0.012846863565726147, 0.05733618445153679, 0.02422720501800218, 0.04428663891890357, 0.07086094964535967, 0.035031162983467506, 0.127985360581548, 0.018342634693028468, 0.05247377460041354, 0.027370729986878655, 0.020736883537122802, 0.046771330188118646, 0.07777948202865739, 0.04200111901868255, 0.04274962522510079, 0.036895813330286936, 0.03704577887190446, 0.03402040189793033, 0.07364348823865575, 0.01637906707342594, 0.028550549440326232, 0.06924415938556194, 0.057741004462924704, 0.06504969010429998, 0.04534701185841714, 0.024854249899245562, 0.08076849663930555, 0.04696674389584411, 0.01439769269763342, 0.03280224931997157, 0.009173514103637108, 0.06268475369940843, 0.039476158337727676, 0.028598575492299376, 0.05141549691137287, 0.018437302093051614, 0.03875843737454664, 0.017208108272884163, 0.03715405390868264, 0.06857046932582894, 0.035778393653491815, 0.07712290637315282, 0.05114071266425233, 0.08841803778083095, 0.027523162331612363, 0.017448349615498897, 0.07570879999548197, 0.04887860058055771, 0.027496270730250308, 0.02534972684037301, 0.024295990137503515, 0.03802308106734868, 0.009792303429886458, 0.025857721658183203, 0.038260989672233986, 0.03808770058376174, 0.039186607745866624, 0.017729869690693675, 0.033460709551769885, 0.05155660647658571, 0.031050916783691897, 0.038780650093911156, 0.02016167982571548, 0.02510706657513736, 0.05424765118908498, 0.032300913721443184, 0.0664883112955478, 0.12119586804821608, 0.057664154352800506, 0.06210149648869711, 0.03652609546758956, 0.0013384246713324121, 0.057680835917351715, 0.0569379183223411, 0.022216218471106504, 0.06626723364235894, 0.04309979252397053, 0.008605938712735812, 0.10148177509226146, 0.051481330677145914, 0.005044975785553576, 0.055890599521057266, 0.10181459433008587, 0.016831265792490977, 0.022566360872118704, 0.058423355146641695, 0.008675023564137518, 0.08438199548231018, 0.05113179923125333, 0.060791938130052826, 0.04199011033521064, 0.030290072731253122, 0.020940007919806148, 0.042043361106827375, 0.026547830897353353, 0.06547012681802435, 0.010241098803347878, 0.01854596591945137, 0.08402767981733046, 0.024103786338180788, 0.031276661827559435, 0.06432425080528183, 0.015643816103317564, 0.024577190370989904, 0.008083195744773314, 0.015596558054488514, 0.027106519668332996, 0.03743611982152347, 0.029410672742092324, 0.10212215564904675, 0.04025269953173496, 0.04554809844722191, 0.09888618493512755, 0.04628792870789767, 0.01637104421763891, 0.037619965601592295, 0.021231709303514614, 0.013207623945368875, 0.0063286959137316915, 0.038464642655585086, 0.011968948829528547, 0.03877107399485765, 0.11045161514512955, 0.03701454546723155, 0.05177383070751544, 0.04722722528141834, 0.026026008192509897, 0.032964338202990835, 0.056104341882371137, 0.01574387867754746, 0.0635574734018695, 0.043853316606292804, 0.06085836178352756, 0.06847172825326843, 0.009922072978600139, 0.052821210795833226, 0.016334172405843294, 0.03652971140259216, 0.048606555097766464, 0.034389878442931565, 0.03519363108000929, 0.057868079297364726, 0.02681425137956056, 0.0379532483226109, 0.0016519097651677929, 0.05055894549455374, 0.04878074816998936, 0.06016009562318364, 0.06689046915139883, 0.07014952209447661, 0.0570584392745889, 0.03158256265094444, 0.03359215108737831, 0.032227813611708345, 0.04864685898346286, 0.1273081082129671, 0.036599639908320485, 0.019167192362909837, 0.010799630526303044, 0.07471280908512493, 0.023771149046238393, 0.05525458949588, 0.04925101890318817, 0.006844971663198404, 0.04041830092788704, 0.04537282519102578, 0.01148748076370647, 0.04847735819977619, 0.08305352241281541, 0.051892842466552416, 0.09340712410067359, 0.0391195788829317, 0.08268474300782527, 0.06273387142667367, 0.09127940682153549, 0.058834564331318104, 0.0488511631415496, 0.03507736574618086, 0.029258449156317982, 0.013432996478983232, 0.018330538164704077, 0.01639914815314114, 0.08866074209612224, 0.0492956779987341, 0.027791961516824462, 0.0014920874250932568, 0.03158198425456161, 0.10136437977874473, 0.04530085889141887, 0.06101458626348646, 0.07308440493239511, 0.04441509654204692, 0.0412615415670218, 0.057324103244970885, 0.015288116692024616, 0.051900262028099074, 0.06828846470002206, 0.06184173522577171, 0.04202475283114661, 0.03822044063840182, 0.08560795066577774, 0.010004871761456374, 0.058255964935186415, 0.06021979685512282, 0.03461906130635931, 0.04506751617056228, 0.04794266713302463, 0.015580266237168785, 0.014812279372446, 0.03484119616088367, 0.023582294966364582, 0.0743767646171393, 0.036540946082001736, 0.05156805183017447, 0.036948332487935984, 0.056060927679702166, 0.03127760028526668, 0.044653499273643385, 0.025378581542041034, 0.049420998491827524, 0.05289138828013694, 0.04413601454167117, 0.04018676234409213, 0.051371561768915386, 0.03496667370200157, 0.03921648134447394, 0.10062350380805232, 0.018948815169654066, 0.025887578019812226, 0.0420586675435545, 0.01760675361560237, 0.03328827465133321, 0.06046550806551691, 0.048914476478051756, 0.028657993271706567, 0.021777721234567223, 0.01068883314503417, 0.03487878043444888, 0.040952681729029265, 0.026196412959947225, 0.03249757998292485, 0.059030809244441415, 0.09197820924342641, 0.08512624223986942, 0.04927576354314243, 0.0492001774780933, 0.04474046940524732, 0.01300764243839489, 0.03807323684375133, 0.09574448134029105, 0.03931229213072408, 0.01340857168073736, 0.04297998786393193, 0.035066445162820245, 0.08255427057344107, 0.04580974045600142, 0.03980751817805633, 0.030767358914618532, 0.01772316450613641, 0.03404849051167408, 0.014014838342254442, 0.02627540045538016, 0.047262082281973095, 0.00483464060028294, 0.066929945662137, 0.08884666397446588, 0.015065326832324989, 0.05690391550982191, 0.023265703385996244, 0.04144249919561609, 0.01079306515279196, 0.040955240462696364, 0.04744934098374459, 0.04303127362002288, 0.02584487436369302, 0.06502083923307157, 0.06253190766719562, 0.06348723463053185, 0.032782890278125004, 0.05018619392367621, 0.021833651398699132, 0.03648891722062423, 0.04648096371261824, 0.04148278009867476, 0.03169594366373795, 0.052285922180500724, 0.043549918975200386, 0.018856156835212343, 0.06917801535417957, 0.016612247000598622, 0.03152232132701865, 0.05855714474173804, 0.034329380479551135, 0.008824484445334924, 0.01530987358907418, 0.0452880499013249, 0.061745526073800946, 0.04053353204301769, 0.12373626157040558, 0.04924187947425151, 0.021602559061120116, 0.1445290599499018, 0.02945941125583505, 0.014743075777416029, 0.03793559382639585, 0.02122487388401022, 0.01995619780744516, 0.0061066721419563465, 0.020917322141148394, 0.05967488234502174, 0.04788691508433512, 0.017501514202224153, 0.024203860403729544, 0.06347909494633637, 0.015393326419495769, 0.038900064049108375, 0.054582565677382296, 0.060001090244059606, 0.04088075756425819, 0.011763663121288823, 0.02576008566745347, 0.08594825458262237, 0.08974714670330287, 0.019245218417997804, 0.04241301768249081, 0.04526830398507657, 0.09116730517557553, 0.1338959893872661, 0.19902591954075521, 0.12983144861796211, 0.10574586644408204, 0.29445358521996007, 0.14847741582460944, 0.13295587693010608, 0.12231598052406505, 0.20675764659479742, 0.09068742769980624, 0.13399069317646567, 0.10927634433873239, 0.10272652241251162, 0.06546770598018362, 0.17429284751415255, 0.1259347806955057, 0.115555101374705, 0.16803565585324842, 0.08538206964130364, 0.2622614674750836, 0.1492167059932986, 0.3467050411047474, 0.15801508790783345, 0.2588041433163228, 0.16581587012737029, 0.08173123933374882, 0.173984665663973, 0.17984649466891445, 0.14225799229837235, 0.12249059494464629, 0.13877241481696406, 0.21942241297614193, 0.21117543050598717, 0.13518082608859386, 0.15062915762105297, 0.1489730593898604, 0.20230123653046547, 0.20006920871955736, 0.12501982656577904, 0.17549396612711493, 0.08458342298024124, 0.12063951201496587, 0.14561117446470648, 0.16724978753876302, 0.1348653204378582, 0.21167902606389216, 0.21974374089510212, 0.1154622668400407, 0.18078023327454446, 0.15813994491773267, 0.15492838176508106, 0.2247919998462162, 0.14800329933003073, 0.10932417120784522, 0.11606300234674446, 0.12427069216726289, 0.20054583798252767, 0.11712731297818885, 0.14584691504076605, 0.11816130951046945, 0.11222824198944915, 0.1030185857727643, 0.12634957134122812, 0.1751459323831143, 0.13375443166061757, 0.16551150339505366, 0.1593970492362015, 0.10583323111096699, 0.22574626960821692, 0.09330822981052822, 0.10023076883366994, 0.20911310649206563, 0.2839940642156909, 0.14260210367220064, 0.10714525627272745, 0.16322751950112083, 0.24303357988115282, 0.12111942779513137, 0.0980354672778518, 0.09865039073291326, 0.1486360879554864, 0.10727817252759012, 0.15875195723868188, 0.10166164487600328, 0.1235800026164901, 0.1146204358026866, 0.08614505490949077, 0.1355098761738308, 0.08998809667724757, 0.1497789532426865, 0.17644368532684543, 0.21622689170462472, 0.2553432798313518, 0.12161380731530728, 0.22982660711051958, 0.19949140988530653, 0.06897274975574787, 0.16964185111705335, 0.21113043050131491, 0.09773316898293073, 0.1230069688491283, 0.21225674828935057, 0.15655584362966402, 0.21460952687888377, 0.08029536839814917, 0.0891700909743386, 0.21859287764997254, 0.188316730481963, 0.14379442759579228, 0.137394207319425, 0.1870630429156365, 0.11210938344799704, 0.15294079728905233, 0.11525085721645625, 0.3130908190242706, 0.11680366381281808, 0.14210166439654368, 0.0896775322936235, 0.1407170830474746, 0.1649891233612453, 0.11757257860153915, 0.2455528293766322, 0.1410515263916985, 0.14382888623062642, 0.15342286577628506, 0.15365105272541124, 0.17480963510611366, 0.11868485399792272, 0.14347824778768326, 0.11021146956350535, 0.08676694976466318, 0.08247371642820298, 0.11183248096776587, 0.08250950805602536, 0.16943431789836577, 0.15006188483488175, 0.13962421265821304, 0.2403026296486778, 0.08515081834048034, 0.05151966954731653, 0.1766566730915539, 0.1481263943377041, 0.10302479874583022, 0.10590991651218747, 0.1947121703696828, 0.09384357205201542, 0.133235453057193, 0.19364358496762094, 0.15549064433622747, 0.09468625344696546, 0.3508628454179533, 0.15506883632511864, 0.1245840757544483, 0.14592154732634946, 0.16449723362682328, 0.22963962036996122, 0.1498260063629958, 0.08306116797029973, 0.1887026242911816, 0.08204807797747274, 0.15809790201244817, 0.10033795219515601, 0.11115428631103809, 0.10847791984316804, 0.1044351359709136, 0.1451044379463119, 0.1781271482186933, 0.20783997561422088, 0.12417574322992757, 0.13265109651031035, 0.1401472515276363, 0.21427027250249542, 0.13991351810193833, 0.16154500655829906, 0.28406105094378997, 0.22116434369837085], [0.019387965496148796, 0.02359688128044288, 0.06621963659962339, 0.04461659681833079, 0.02197452730709507, 0.042544884396897215, 0.06018170696352759, 0.03894195756724766, 0.01938278865700047, 0.0290992560856525, 0.04183488559999293, 0.043747496881311944, 0.08882554293039346, 0.030350409816169453, 0.023980377234458446, 0.03579635075443695, 0.02465510151288923, 0.03769027715128276, 0.0767148113358886, 0.018776190662456137, 0.031040392650832093, 0.022399715681169784, 0.07506502566919213, 0.016721046807604934, 0.05810247155867758, 0.07019311249736818, 0.02398486842491454, 0.03037555473706415, 0.00997625167421516, 0.023761050092176567, 0.07209666478898256, 0.042782379314303405, 0.013896217288058853, 0.047831415844660614, 0.03741060909364493, 0.048180054798121416, 0.07419382282082113, 0.011355422527319001, 0.054075419301948244, 0.026275902242970564, 0.025982381400441932, 0.05861373948714426, 0.03591273483189364, 0.055060436002789974, 0.04843556810350669, 0.0068457516364663126, 0.028452122463814677, 0.037551419884567304, 0.024360778193259915, 0.1320278533403912, 0.047963558350719755, 0.02144936637412156, 0.058071019818946246, 0.039303704285092896, 0.012721799712087358, 0.04154428929811524, 0.038113939095168345, 0.012165192785041948, 0.04685535854209335, 0.03986796251528206, 0.03851885103710717, 0.049470365197668155, 0.026524926783637177, 0.06421571146816978, 0.015210097340205985, 0.04492947095704656, 0.017828585865396648, 0.08180204884059007, 0.039550315648798025, 0.01708807953212771, 0.01917460043313763, 0.051278190972704085, 0.03270402918719957, 0.08511257523130025, 0.04609696214057265, 0.022595091084499034, 0.02926478470345178, 0.03793395822867751, 0.06438818850344227, 0.0384156781459047, 0.010449403855619172, 0.004747950090771361, 0.019406841902603066, 0.02746259925075837, 0.07116104926793806, 0.07436678249148593, 0.05554124427538726, 0.04086822819625659, 0.016868804100780718, 0.029267517722121654, 0.0350640932728927, 0.03454470098198902, 0.04146660415215358, 0.0661818378214394, 0.013542562373913826, 0.06090997312698634, 0.022154307075505777, 0.02575421360351386, 0.03766965406436113, 0.026064712869664355, 0.05472643698956217, 0.034890850149695916, 0.01145081675326031, 0.051861896344851104, 0.07671950745486444, 0.0296830112535146, 0.048534244058593634, 0.018673793435277, 0.04597068403757388, 0.03759117218695822, 0.0649905787600625, 0.07387641727203324, 0.09331725432627624, 0.06861889374352272, 0.0395231616623219, 0.022764285433015997, 0.0664610002610472, 0.03618307576905336, 0.07450684634668213, 0.08505553998533757, 0.034940749286643924, 0.03467617699155404, 0.02274489957809208, 0.04890690369892025, 0.05244937470002521, 0.06553493785641848, 0.019506174778085084, 0.025047125940721844, 0.02357593069093362, 0.04653714860098497, 0.037632169382226084, 0.05820474812700864, 0.03843920853649897, 0.05503206010607462, 0.041443246131342266, 0.009889805355229446, 0.1196340139534685, 0.04319594421934697, 0.02674792731751598, 0.03698785113350999, 0.06527658236483413, 0.08218222763389349, 0.03612070472069806, 0.03791405143396508, 0.006741417643253602, 0.028764161566692977, 0.06885464198046154, 0.021543114468635573, 0.017171020041249933, 0.043989335517248804, 0.08584543026142544, 0.04038167043378757, 0.04600312403072754, 0.05045691407435844, 0.02890224125416529, 0.06549149301023253, 0.051481759686383514, 0.06630952935665846, 0.0761871989215574, 0.034873283753592166, 0.05654496884333992, 0.01935328278059681, 0.043614431239304044, 0.0443908958245189, 0.03866684007188005, 0.03905590548510513, 0.048317785915588184, 0.07302193046217004, 0.07045836278027104, 0.03425926811272099, 0.020352608088644284, 0.0674916336673402, 0.02425527830998744, 0.03774493369424055, 0.043422545366469896, 0.02857933327886126, 0.06191119641786622, 0.04184616624467796, 0.025658889283095638, 0.02265109785742337, 0.06363107912963437, 0.040310608117931315, 0.07050484133463714, 0.04990435017633343, 0.05258003099551124, 0.04361878644915358, 0.005138352806229265, 0.04031467604480925, 0.01694238876112767, 0.03640835158406727, 0.023458491327361237, 0.03424695324933818, 0.035820857907134684, 0.04114637556936472, 0.08844093614888769, 0.03236168747647636, 0.02303396370412121, 0.02438368805263552, 0.007960029395161978, 0.01971268335417394, 0.07747359078137145, 0.007800644323710473, 0.06274056320469226, 0.008584771703387941, 0.0239642261857948, 0.02789004375377009, 0.07397385599512248, 0.029303194436755393, 0.043349698065750064, 0.08870846937380492, 0.08822770323604347, 0.03891402217108877, 0.05886080284272471, 0.03594618223066773, 0.004857319675671358, 0.025197327054376085, 0.08807693713254507, 0.06060929510802512, 0.024338000484051246, 0.00982916853841274, 0.03465505211704201, 0.040830096169825525, 0.016248696145691698, 0.04464735907893028, 0.04199297550404745, 0.07861907608927259, 0.040403867831393596, 0.011928225510693606, 0.03020995142569225, 0.07773297283077434, 0.06631990218715322, 0.04397613582231345, 0.07529423151525759, 0.04048389720640356, 0.059082577635924664, 0.052350131839874296, 0.020518401006777442, 0.03563320083964256, 0.00419028548358549, 0.07314844988286495, 0.02219301558309986, 0.02713720340492024, 0.016798459992353475, 0.03778617603764419, 0.015266626968138642, 0.03804044061971288, 0.06955662366723822, 0.043863497914806496, 0.07712397889624681, 0.06336482910199032, 0.0599557914650969, 0.030937403620731448, 0.0415947515096876, 0.009797980141405378, 0.06690153912190469, 0.01943405717611313, 0.04417981178830228, 0.06351207503147664, 0.05661706537789395, 0.03578733389956817, 0.04533698759792794, 0.12186119242781594, 0.03138952381578425, 0.024461783055636673, 0.029649324452264175, 0.03053284024879817, 0.0994609500611982, 0.031801995130315903, 0.05579997131961489, 0.09700687932631663, 0.013688240695985095, 0.013200791398694199, 0.054927971739802635, 0.08715914081661932, 0.021005956598767833, 0.01465094795886187, 0.03673077883919881, 0.019671153727798693, 0.03711416371046536, 0.050951841347400224, 0.02827336350756307, 0.06617207786128407, 0.08604956204972922, 0.05696871122645755, 0.013728714078634739, 0.011999048424073526, 0.025413867551833395, 0.07025449146186152, 0.08448491939493726, 0.05194112515798019, 0.04184345429342601, 0.034072051545785326, 0.054593536056457996, 0.054392051101932605, 0.04635530231039851, 0.02350886926926192, 0.059621191072848544, 0.007334253347043189, 0.024667192295554186, 0.061059256850351254, 0.05624841620785095, 0.05225786804071358, 0.022532201011575038, 0.06217236345213267, 0.05639709472175568, 0.07725082773474917, 0.015063943086011757, 0.031165738041783055, 0.017433499001086723, 0.06388460060641651, 0.019515118854601058, 0.015232752475346771, 0.07551220651235312, 0.01793323922151279, 0.01925919377695649, 0.04521563160984267, 0.02515654053328739, 0.07046439189223513, 0.03779108666123883, 0.014934773958708732, 0.0034402798994579505, 0.0087459470265575, 0.015201645475181361, 0.04735882769549086, 0.009947618180435273, 0.03777616326847384, 0.02229710586459166, 0.02508243493315193, 0.018010715608515086, 0.016237817697166916, 0.03991157207037172, 0.019393443024807402, 0.039083986437969634, 0.0826978660939682, 0.11632182515196263, 0.016724325663920854, 0.02663826566159485, 0.036965921866677465, 0.013687656553942832, 0.062359947741271994, 0.02840600205555318, 0.03463329905043206, 0.07919101435090266, 0.040256185231790434, 0.02850198138114666, 0.009563507440860474, 0.03171175954893472, 0.029720967079723076, 0.061306799010884386, 0.034330303615499894, 0.04484750721002779, 0.02359785995776615, 0.1508630289425773, 0.08888991729867074, 0.09034990468212674, 0.10740901268417798, 0.19073951418601698, 0.1597539083130898, 0.18176424256976575, 0.14830097045388915, 0.09333212409288653, 0.10297934674928266, 0.15988400536439112, 0.2269219541020932, 0.16827754045446075, 0.21131832122562394, 0.08731882418355635, 0.11370768800618188, 0.10403198986164025, 0.07399872320914462, 0.1307692781331078, 0.0953734802803205, 0.14012129646876167, 0.11641995335418372, 0.1395017151991206, 0.0989218999541575, 0.21154169714258564, 0.2079177948255693, 0.19930434653595572, 0.09686809483795397, 0.16267818849413626, 0.1423771649358734, 0.16571060964657416, 0.19164202704785332, 0.1159646443181461, 0.199404121827214, 0.15482756459424574, 0.11955729790873106, 0.13406768501285585, 0.0772505289604587, 0.14896985714233693, 0.1334942682015319, 0.14541428986816637, 0.13980672544529363, 0.11618975159381667, 0.140527154529287, 0.1538913898290165, 0.0979850510315549, 0.2448545708771675, 0.0945359240135839, 0.13839379884302616, 0.21321417433359932, 0.17530731646524322, 0.12552991854928194, 0.11092400794187862, 0.1729393233695338, 0.1422857246812313, 0.14199497899220836, 0.1959912920550954, 0.09262495599086247, 0.14671213474244843, 0.10527532758010973, 0.1668235055741764, 0.09094140116846369, 0.09463219062214899, 0.13156846105571718, 0.13734785900000604, 0.3003786011568962, 0.15638974044592152, 0.1551138056862739, 0.06432420484000637, 0.09057731788244941, 0.18890280306579607, 0.1316422200010669, 0.12154461425398627, 0.1410447848179648, 0.18662464144008775, 0.08892315785370528, 0.1555254094062313, 0.11988486944427414, 0.16144331604723008, 0.11801444279450564, 0.09159952432157532, 0.11240236611375887, 0.13869278763811435, 0.11146601514830706, 0.1218305642326032, 0.20433336135841187, 0.13450372693759782, 0.16486322447176904, 0.1690793280760127, 0.08210001107785972, 0.2042455830040478, 0.07660349876049065, 0.09830863890989174, 0.12386098068447844, 0.09613776789797891, 0.1289673320828907, 0.22880407891446547, 0.17838348123815753, 0.12866181621868766, 0.1577217988069019, 0.20683414813491607, 0.15606396921700047, 0.09781687941041686, 0.21776226980070915, 0.15725995504087018, 0.2012044590927901, 0.1115640284373395, 0.14070180725426445, 0.15205961231502796, 0.08893065785448398, 0.1750358455483952, 0.1978047141024182, 0.16945146294611116, 0.14031700128989835, 0.09421910835249771, 0.07695576897071255, 0.14112021383498946, 0.11747885540488268, 0.14367234382417896, 0.24724661913369936, 0.16847307673625408, 0.2035859966230008, 0.08962016762985338, 0.12216583495178532, 0.16529296915377342, 0.3029507260409094, 0.1680794301172418, 0.1384936507430769, 0.17699880795853754, 0.1919140801915238, 0.10983535103620061, 0.11435849501961663, 0.11436769573558724, 0.1692613658885802, 0.08980801238888696, 0.1513731515695972, 0.19478850337045808, 0.07420095509939617, 0.16634891410508465, 0.12930742915599577, 0.13904884998356143, 0.10601294767712394, 0.1426017206282385, 0.1551850365414735, 0.15221004133983967, 0.056788512024908304, 0.10525386179647139, 0.20584344323123657, 0.07765258722487958, 0.14624488239567127, 0.21603158524920865, 0.08949804555384383, 0.19525586296954464, 0.08377313178272978, 0.1084943064638684, 0.11972399864105449, 0.20987113517138267, 0.14236907504739302, 0.253403652459383, 0.18555279250346846, 0.0878018272980567, 0.11403494544567601, 0.18719410523772242, 0.19516111321506963, 0.16992530364903713, 0.2117980148402914, 0.20931887770852736, 0.12416052872375136, 0.13140655603379975, 0.10264145600939951, 0.10361745202493283, 0.14376065844009, 0.07146579904421684, 0.1469535290473892, 0.15466518459781525, 0.14297322730623907], [0.06537492507167401, 0.018607662810433297, 0.01333588717370144, 0.04670350076330285, 0.012067901533878139, 0.02092143603330178, 0.08186710502711997, 0.010568711516116897, 0.03791455705199511, 0.05152127067107828, 0.009418170027915508, 0.03461731845633157, 0.024628119896196073, 0.029962503110929847, 0.07507761249378805, 0.02904791287296722, 0.09388044386381104, 0.060054138002376405, 0.024111891548419674, 0.042721092280360966, 0.0709704848967733, 0.06717806621905296, 0.033107148483395576, 0.04465534937598052, 0.04281523682537579, 0.010583823558033235, 0.018652915624120546, 0.08137195175814052, 0.015548679474440795, 0.038007452873693365, 0.010041549178441207, 0.012120071163911735, 0.15017071528540504, 0.0352913532556305, 0.07766931092426663, 0.05508917579126935, 0.022229571383626714, 0.02049384214314482, 0.054835267440085454, 0.0602896832260153, 0.006959727803815998, 0.09160255036887624, 0.0802471584850742, 0.04012469773090655, 0.02236378232708141, 0.04346123663708568, 0.07730985480931497, 0.008884481578734855, 0.024998128872304678, 0.04273469417145656, 0.05787803844038037, 0.022852954364592032, 0.03984198064333008, 0.03846103438146172, 0.014771259194540401, 0.024550034469293974, 0.059796770764214385, 0.03803131268209508, 0.028456102290581313, 0.0696996905870976, 0.11305498109469492, 0.03649837074560985, 0.010407517040749232, 0.04157735748336681, 0.030408044525932883, 0.056062088302907445, 0.022115975866214405, 0.04697706693062379, 0.01222950873911501, 0.10613207434934956, 0.053444568878941, 0.05747002767278783, 0.006634503848955877, 0.0319360624322848, 0.031638416206283916, 0.027728299610316757, 0.018999421022712223, 0.04929305414759344, 0.0445503608563975, 0.034533933616213264, 0.023094118843155525, 0.06765641917985293, 0.013786752899778227, 0.04009537571560472, 0.030080032489833333, 0.041947443068267844, 0.01098737952434608, 0.0454645527286395, 0.07582932094772978, 0.0370705196814191, 0.02967956960351477, 0.022804619962229364, 0.007016306269853827, 0.019384711537690415, 0.03086535496667268, 0.07902726305708771, 0.011298270452947868, 0.03167160313516375, 0.029270342671342438, 0.02843336671620848, 0.08530685512889778, 0.06023473173920667, 0.0421483687786085, 0.0563980293490233, 0.034323067915055065, 0.09603866676409399, 0.02543991454125893, 0.010826605439726866, 0.032908157145063725, 0.021996259306287094, 0.007623556396743704, 0.007548438124133335, 0.016458209701663545, 0.07615838635472522, 0.08908564510244517, 0.042190526597081654, 0.049986478632255915, 0.02568197151225421, 0.11387728455085909, 0.02150188553177061, 0.02414607630682088, 0.0438068188997286, 0.07016937143259472, 0.01686050353812114, 0.04699038153874779, 0.039110420301796935, 0.03312981702507504, 0.014947299496270718, 0.014827653799476403, 0.019188922446882053, 0.07997412474886065, 0.04801500498527481, 0.045319413540944944, 0.03369005329366173, 0.06070947642588328, 0.06378443461031684, 0.04100148536024555, 0.024707532570426984, 0.024149297706542477, 0.09214214439834319, 0.05114120296052387, 0.015638426674770254, 0.018468290349588763, 0.030324270896193002, 0.05343645983826249, 0.08103054467468493, 0.033960834731377905, 0.05755336271719106, 0.10940222024557092, 0.021286291152899785, 0.06134794559329749, 0.0324313516818708, 0.04658947240621333, 0.03224228884303763, 0.04246893060964443, 0.030709262636880723, 0.030262407381087545, 0.029662164085875117, 0.010624435794119154, 0.012588554997027162, 0.037229375673397895, 0.09682633538520145, 0.07455284992653517, 0.017564695388559374, 0.016828484893325838, 0.06814482321421947, 0.03491100592298373, 0.07096699919671783, 0.04001814256151838, 0.021145080081036976, 0.046106044112914996, 0.007323768954994458, 0.0165099244669921, 0.03423327474945015, 0.033022637494028576, 0.0870612194581378, 0.02615398509548076, 0.056110210115871126, 0.017154039702408256, 0.060379993500969106, 0.03323990385979414, 0.028986574128089897, 0.04130835336963496, 0.07112505079637613, 0.04424197599291802, 0.007514679023335058, 0.013419536314153624, 0.013476857885478005, 0.011122514561359442, 0.03980027864717188, 0.058166677387611526, 0.005458543563426863, 0.020113270729780197, 0.00961050501979527, 0.0007875462864420467, 0.028441625144032222, 0.0035318922844805546, 0.030881952261552218, 0.023338690497762254, 0.03872676346931727, 0.08899715428631153, 0.03696592569711708, 0.11562506052395029, 0.03735320612547859, 0.10090403754504458, 0.05376943612411138, 0.03139756007810995, 0.022065584517775044, 0.04422777272280186, 0.04062164747606843, 0.03322805631004515, 0.1370637476324074, 0.05522439030990486, 0.04496136702777398, 0.07153165196218798, 0.02482155135141746, 0.018038762087422996, 0.042027721421853195, 0.04421752246637498, 0.033771994058042765, 0.050526080322602106, 0.027677712909456705, 0.058897567402210936, 0.06690841093058549, 0.03714913179376914, 0.034265657286009485, 0.05230821916953691, 0.046298194286083026, 0.04625592155442123, 0.12155189208926694, 0.07107737714484816, 0.038333473081189784, 0.01736030121514153, 0.04877980205140287, 0.0976397752040817, 0.024971714160675486, 0.06572969272852906, 0.031177104871359565, 0.04893403470275864, 0.09396152660971689, 0.025016185564679966, 0.038002569063176075, 0.005794087680236947, 0.03593606220918798, 0.028355643265850605, 0.024149745867978183, 0.04422091623587955, 0.042564998035349196, 0.006897095327956543, 0.021370541672372532, 0.014788994129987494, 0.02539107260564643, 0.04077730505096336, 0.02945789631696478, 0.03405420935802883, 0.009517629307905033, 0.034093850577670726, 0.09237842123594978, 0.03668772469785425, 0.025439539158176032, 0.03307444802034767, 0.07205716529560667, 0.017583403255670302, 0.039466689490983566, 0.038156403348811214, 0.04071161301145631, 0.06209675823488544, 0.020476946073974815, 0.022973661093161474, 0.024423938312177217, 0.006412064474481609, 0.09394350056085857, 0.03427866928940339, 0.048272391375634945, 0.046497825307831656, 0.01983188471997217, 0.02869312223347445, 0.02933371729487854, 0.06253288059885945, 0.051094701423520045, 0.019399006738357486, 0.030788947272324757, 0.015740110482569906, 0.017134563832153237, 0.024994292687023842, 0.040281010310976736, 0.023808440291172555, 0.03930478446906613, 0.044554164482941555, 0.047808682185507594, 0.03558589491031824, 0.03836480224685323, 0.0765936621915429, 0.02602973712548133, 0.07900150718107339, 0.05309101930188556, 0.09363110522709547, 0.06069160359460981, 0.023651788717195876, 0.02114697997908919, 0.05163163712788975, 0.02366428744168051, 0.004406565511148543, 0.018687270837084904, 0.033293664079880526, 0.04239220307358811, 0.06552139342191719, 0.08823187075435154, 0.014939495933152016, 0.00978473831163419, 0.06608491237725943, 0.014605844532319856, 0.024492568298873883, 0.04601469961926342, 0.025111998266149915, 0.029960528519305012, 0.10523177548161439, 0.1177440980269063, 0.0012467860717386488, 0.09232717761469465, 0.035490003684836055, 0.07663399672075626, 0.01725379392624863, 0.017699270223778103, 0.06940460117954401, 0.060450814499129216, 0.05775078357527814, 0.04547199527282388, 0.03271953480678701, 0.010894366874239378, 0.05397776224380059, 0.03749147733493197, 0.03290294774717862, 0.05256616097364215, 0.06377321525266574, 0.08551649508937713, 0.036856597289443016, 0.028927376598960934, 0.00835595656216385, 0.04485980675165211, 0.04642647570900379, 0.0551702585371752, 0.013884011592205255, 0.024364664174255826, 0.03135375134015997, 0.02509564994984577, 0.09089655438137632, 0.05472634505901126, 0.04874605970877794, 0.01954885928200618, 0.03861614037305117, 0.033588267021602204, 0.2239147678858811, 0.17721994689876036, 0.12607402483662292, 0.15976682455549318, 0.115752077901796, 0.1676902880952243, 0.13968965188870508, 0.1534251487182994, 0.1323727154803853, 0.10152496712943239, 0.10277019708507484, 0.17968569281360797, 0.1388477672251963, 0.12388760990072643, 0.1481615577734286, 0.12887137190949532, 0.2756302839806003, 0.14952401450324446, 0.10886587442890291, 0.12877712777305034, 0.18029093291730652, 0.12769301376876332, 0.09621760958144743, 0.18858063245011916, 0.1541584480794207, 0.09779971138003374, 0.13781871196002732, 0.18017035067802478, 0.1824197380412971, 0.21714253531348324, 0.14300388614496878, 0.22857889503000245, 0.20482636958120332, 0.19269191990456275, 0.17691959446716696, 0.14513848289366693, 0.12210874607966793, 0.11746390136860071, 0.23394992214537438, 0.13581240429512917, 0.1252108046244229, 0.22587826655757046, 0.17380906298996943, 0.1298506467813446, 0.1758581183610424, 0.16662677419522118, 0.1722213764104151, 0.18718406948591435, 0.11418624781072141, 0.12420524527589161, 0.16434043075048155, 0.10417823604638539, 0.12835364969026658, 0.23303032552282657, 0.1926424765899297, 0.10279936971323145, 0.14844960683295805, 0.0823674293895883, 0.15875304508353436, 0.15279735498611005, 0.20285165538230251, 0.12769137434060537, 0.1745342571408518, 0.3569309052921111, 0.10595025870228007, 0.12093414943064414, 0.07383113381482902, 0.190681460043115, 0.17620285792696863, 0.14599359023474878, 0.11400793318546588, 0.12143813569339053, 0.1510148522474112, 0.10228199223356862, 0.14290150615476793, 0.09075993792183938, 0.13063702071386, 0.1517303783686892, 0.08967026211922208, 0.08301773078499303, 0.12901702054565953, 0.18464887003985145, 0.09963202515556928, 0.08987445519455979, 0.1031660576981883, 0.12735713784012104, 0.09614477760248608, 0.1280228376028038, 0.3101161302578065, 0.1763269182054266, 0.1205706483714523, 0.1370526393575053, 0.09141399314807308, 0.0760283965557333, 0.08016902517767684, 0.38843112306729444, 0.08445556290567884, 0.13600096917681156, 0.09008017278486684, 0.09732031653965674, 0.1428558626362393, 0.13410261862220305, 0.23845197572823496, 0.19582394780891557, 0.09704573530583613, 0.16877411864697936, 0.15810072121600952, 0.14004401351896026, 0.2292802025594058, 0.10625293238028403, 0.16602780069074324, 0.12689220673975446, 0.15126350906587419, 0.13857991224335087, 0.11581266779572734, 0.13321528962302592, 0.13529937053399702, 0.09634546965600983, 0.22079297491619665, 0.17082233132133562, 0.15105133335436546, 0.1932617054591256, 0.11794394738371335, 0.1356958976436046, 0.1530906440870416, 0.12845176257072918, 0.11106994769145405, 0.15435429079638374, 0.19261065329755508, 0.10787615011776648, 0.1742734961331852, 0.1476969254473525, 0.14881394292798736, 0.1771428018447853, 0.2590450932902675, 0.2206516470159254, 0.17889345064759257, 0.12813448725688842, 0.14313805878402727, 0.11511841593610664, 0.13549588740833346, 0.1656399763399555, 0.08295203874548597, 0.15560926539042305, 0.18067687269180052, 0.22723174473691374, 0.12247584009122466, 0.09251404944206439, 0.327386295482997, 0.18924769584930715, 0.16388908238901248, 0.12357911395449793, 0.0643247104580364, 0.1237861415551555, 0.12320917775674213, 0.06695717242696593, 0.11384407463934153, 0.1711848747706221, 0.16940604925395983, 0.15913279486760018, 0.12423424170382562, 0.20538435738173225, 0.13701055048694535, 0.12793502860492276, 0.12613661422003664, 0.13224330790821584, 0.20073605761412652, 0.1721707073551032, 0.08155094820164865, 0.10886438055745057, 0.2351013982608434, 0.1288151870211286, 0.1693011871388843, 0.09066721830036371, 0.16025908201211886, 0.18107557549111306], [0.021134829824610103, 0.01124269460448094, 0.04243213157620161, 0.03675063583819616, 0.06423246581107378, 0.044800676255216526, 0.04179968002943262, 0.022056709389172254, 0.018290657542585846, 0.05565478616664487, 0.0073581639087698875, 0.013029121628571904, 0.02518483024511126, 0.034575118503022584, 0.060272109169032306, 0.010059476593479274, 0.014965889577363289, 0.056817604213832855, 0.021602202830235326, 0.0769462771413307, 0.06065968071080505, 0.07666039611062697, 0.02308818166174235, 0.09194670770798, 0.02699670671004682, 0.03385645908213431, 0.04087669729825951, 0.06878433809165033, 0.027936754049733285, 0.03355994475104156, 0.051588943047869595, 0.013782560483612602, 0.03375595600734796, 0.025822828268452037, 0.04633492437161265, 0.008401895024543329, 0.01765706644002949, 0.020204078961884784, 0.028008463709885557, 0.01583252175365605, 0.042530910953158335, 0.03882447032318, 0.04660216648311866, 0.019368345984407974, 0.09205563774993343, 0.04692580032673094, 0.030170802417541706, 0.045814459557614984, 0.09248288498530466, 0.03184755246395306, 0.02405793980635222, 0.03645010720638018, 0.044452834033196977, 0.008389415452256799, 0.04685854163741873, 0.030157551011671464, 0.07878292697451769, 0.0331182490974184, 0.025045930843559966, 0.07461736985151807, 0.032098448174374725, 0.05610781609110775, 0.028705781836423184, 0.037930878555221904, 0.06453579832469264, 0.09609070711679037, 0.054477289874827674, 0.128385940296275, 0.11674042325466873, 0.018046846230243965, 0.041328386568854895, 0.0504444498238304, 0.03072099718866089, 0.045342974575056184, 0.03191849412096124, 0.03877991847994347, 0.04563867685294921, 0.014775806883980912, 0.03166972621974926, 0.01656091719445202, 0.01944793102842185, 0.02047272492951203, 0.07515583773173633, 0.016448453571947835, 0.038115157174967954, 0.07658276842125962, 0.020326884771366755, 0.02580919956427909, 0.03933409116260948, 0.07126522956476097, 0.0329243139393868, 0.010861154089892104, 0.03357712810318317, 0.023165907027320038, 0.07369406536341676, 0.026078965935495593, 0.0775910243992844, 0.02584522484891838, 0.030324583077022148, 0.025121775463283546, 0.07823322824532948, 0.042837062670338544, 0.026853511470460126, 0.0031271476848726914, 0.0026792615620164022, 0.013142137791991476, 0.010496086380895107, 0.045398745775943807, 0.031012363408902482, 0.10949176826304007, 0.03519183077338723, 0.03913435288855145, 0.04601180763734926, 0.0355369916876718, 0.03499954653483245, 0.03876196903987758, 0.06738603610785739, 0.008357865078705213, 0.12406884332097347, 0.06244436296964846, 0.035155104518297224, 0.03157245412078356, 0.057956037682390986, 0.008073130307058174, 0.06774607444963149, 0.02880986062659612, 0.05203259222569966, 0.013542551840204867, 0.03572734921509701, 0.011570578320853172, 0.03412243331812563, 0.02102570443023597, 0.009344896590787797, 0.0035106467511204463, 0.03237885167641986, 0.030536620892704498, 0.029993158119219928, 0.01498565560341963, 0.036073027238730467, 0.05351408369719021, 0.04169505540161364, 0.09638452481838966, 0.015722150508795055, 0.06413994920289805, 0.028865206648685762, 0.07506697919339904, 0.03550226492206416, 0.024182779579273155, 0.05047336581253237, 0.09090683528132017, 0.03250687262944637, 0.007176210844678985, 0.015394072397612037, 0.03432007251127112, 0.019218047194543387, 0.01673786243754289, 0.019658471142212232, 0.0564071036604864, 0.06434895714083988, 0.07713880269758164, 0.008707213621105879, 0.03649810261483635, 0.10441710226117604, 0.0350687281048346, 0.0635724006250741, 0.039884280188069235, 0.033519575747871594, 0.057590291985581, 0.06718842372778924, 0.09917231877484631, 0.02411843393929303, 0.13392822636711982, 0.05095295217489043, 0.01962790614925325, 0.018723577659036365, 0.06155903729039335, 0.04985706339920721, 0.04488257488476173, 0.03427180131116221, 0.05905192262763458, 0.06344973845707794, 0.07675422655959284, 0.03429319431644774, 0.040566063966722264, 0.03651444327026125, 0.05190375921947341, 0.022059203005365787, 0.034169743077889565, 0.030601943294788082, 0.05135873745706293, 0.09182371229173676, 0.03557863239679606, 0.03480194564608317, 0.10118603450997223, 0.08119916828769831, 0.035254182669544415, 0.060440434007755214, 0.041746509697047934, 0.012315324950783003, 0.09376018338145749, 0.03646417641110959, 0.019407801427728227, 0.023362100229508454, 0.032641052929384094, 0.03345070444347878, 0.08951864565812773, 0.044337779118288914, 0.02975924083242013, 0.021687445433570013, 0.12859610119654288, 0.061608109052383134, 0.07823271496642022, 0.053403192470150615, 0.03477862976010769, 0.04330121236102235, 0.016124151316621614, 0.04219624927387603, 0.05692899339802324, 0.0308718015965555, 0.026955755480054407, 0.06827261434086869, 0.009398703733759542, 0.017395866847026254, 0.031063645334553816, 0.06406566931775982, 0.02010144999310855, 0.041865184377398224, 0.02897530880516335, 0.03218084859151033, 0.07811547287048833, 0.0946295629405687, 0.04226615862740625, 0.009196967885438955, 0.04933843719622782, 0.016048193698929205, 0.0434123449057581, 0.03235184707708898, 0.03365790058347968, 0.03647293662652373, 0.04849870140934664, 0.07573355229631548, 0.03419269124166139, 0.05576944654627193, 0.01685954592821579, 0.04891884700965978, 0.02039837992690023, 0.05798458211844968, 0.013993312229192065, 0.09162838285368297, 0.06831986664403832, 0.035966537186815854, 0.02933391073207942, 0.033209302477658756, 0.09377742802063305, 0.04583370368627291, 0.03242896914842629, 0.0750905440579499, 0.04519491659237012, 0.15910190620249318, 0.010241719334566546, 0.015569360975566653, 0.016063105600375324, 0.030341394876520482, 0.058698874838169546, 0.023225305654529124, 0.058494934571846846, 0.006940789152717879, 0.032916756482013775, 0.07198923627936071, 0.04183363687667636, 0.07568255382319612, 0.03869436178055983, 0.10004798025493661, 0.01893055163353922, 0.05094446775112903, 0.056476358008841356, 0.02673841825115585, 0.02019852865487337, 0.013686901957337416, 0.017667445016183683, 0.0453753341289778, 0.009296722109279325, 0.008957930258475244, 0.02965823788526318, 0.09245092379710368, 0.107788831416157, 0.007138731429398421, 0.07738224245728025, 0.059843594058146404, 0.07408948930641336, 0.0693422263007491, 0.051623106738852884, 0.10230046261342303, 0.01845026047029082, 0.07193488234113302, 0.026916734791631182, 0.01592184952084696, 0.020654216904433507, 0.022292538065343134, 0.025430589336000627, 0.03467576713451455, 0.094025295768534, 0.057568029470501415, 0.025728220240243023, 0.051383470605698325, 0.03777981750787266, 0.03070897726912893, 0.017421906175572547, 0.014723405512350221, 0.043944458086644454, 0.04259997377953222, 0.05176125537423838, 0.07414152965910974, 0.023443715406521678, 0.02741633328579126, 0.02292483639452727, 0.021648681384601423, 0.04046042044196398, 0.017727171145980398, 0.03139468724839389, 0.03890032451900263, 0.03134578019530783, 0.02454333311517633, 0.017476729342653867, 0.038864253269087885, 0.020536553460143266, 0.019634980971233982, 0.020036200369377772, 0.027954699659359553, 0.02820871143241323, 0.06510037448137038, 0.04641803725051784, 0.031212957786215894, 0.031307477714313615, 0.03987289612151442, 0.03687680668888554, 0.013506444201113717, 0.013478971330539114, 0.04214752225145217, 0.023270765311955925, 0.01785129654191194, 0.046449615394756685, 0.08048969426102216, 0.029656994907606034, 0.0344821269203338, 0.05075500654657522, 0.07003749705730908, 0.018192598288277947, 0.07269831194031624, 0.026650046178650473, 0.08443869364958617, 0.0533431081942493, 0.09519419272340114, 0.08166423728389126, 0.11655977972212339, 0.19313125600737913, 0.1502068439919141, 0.12091128936698362, 0.10804453624352332, 0.09320140651036656, 0.1703318665104528, 0.20631406636488056, 0.22488098861950062, 0.06553503744784864, 0.12487973972794511, 0.17745346581983953, 0.12722674201452924, 0.15312554705287182, 0.08283781503597576, 0.1779259122427433, 0.14858783973801523, 0.2860644015093004, 0.12897502360565047, 0.12513382044891197, 0.16304871457959377, 0.1329552027727327, 0.15862987346706853, 0.11331990195979035, 0.12148243089717244, 0.1513760014166755, 0.0915168864171832, 0.2477124618786958, 0.15569702842302863, 0.16258815784127484, 0.09214270364252791, 0.2710240730835546, 0.11156023630211431, 0.09138385524913188, 0.16653202444074616, 0.15051985219601663, 0.08967182493858761, 0.13081156618652806, 0.11299059906553839, 0.16838704506235738, 0.17044463465290685, 0.15272070022840656, 0.17698072828352454, 0.10709839467439922, 0.14151499426412967, 0.12926998277825694, 0.1885485486878503, 0.09664498705176577, 0.12408738264874106, 0.09556029848153554, 0.08486413291745609, 0.21615495604853477, 0.23986047434230007, 0.09235182266321876, 0.10102266626011941, 0.13816798676646527, 0.13003648439001653, 0.11288407453966719, 0.143142594024539, 0.19323936633525357, 0.15035172654015405, 0.24312224689750905, 0.19468057690368545, 0.14708750250358738, 0.0931047875013563, 0.28286984550856775, 0.2687513966473841, 0.21474331647398012, 0.10695342019560838, 0.09878035754926744, 0.19723278350166737, 0.12517944098480288, 0.16859577337820686, 0.14123233846358715, 0.0989152426500955, 0.18071916074522082, 0.12204443299842459, 0.1273264713405121, 0.14964019939784082, 0.09713198914523087, 0.3511131110210573, 0.09309438402734457, 0.1556090968510797, 0.20804039953697115, 0.16747811238371557, 0.13303515170851063, 0.10887587953719402, 0.24609584781912067, 0.19331225194036963, 0.09403690200058684, 0.11736960360600103, 0.09137870713828072, 0.22570686204539192, 0.14737178241052937, 0.18583053001953712, 0.1336022253118215, 0.24405670562578788, 0.20482882106256103, 0.262741222376785, 0.14845688466823873, 0.12935206143846437, 0.10989833112445571, 0.1035166118714598, 0.08634616831137289, 0.16002125767690523, 0.08492666101383586, 0.2451022317813289, 0.244321143855491, 0.11857869719425518, 0.1658999712596978, 0.13925051496874902, 0.17934725049041933, 0.1515115376922392, 0.11575577044559103, 0.22638966089054463, 0.12505233167640625, 0.2537785912112844, 0.1753940222965133, 0.2191998031471045, 0.07564361357400495, 0.09027162581802377, 0.08417178095588762, 0.15039079702429234, 0.15086042424363477, 0.14716055664804675, 0.08475471257923112, 0.1301245998230673, 0.12208073790515624, 0.11341154139729277, 0.086890374190144, 0.10879960782345265, 0.09736794422590926, 0.14693548001589316, 0.15609450548166232, 0.21707559455065958, 0.08320818790384839, 0.1015489686641001, 0.09803906789109593, 0.14407115387580088, 0.22346680563303734, 0.1109754047807186, 0.17233901687206762, 0.11423166150287276, 0.1531874163136367, 0.1387627008220842, 0.11799953472349914, 0.09355764505603621, 0.1537681262819998, 0.09327278292227177, 0.08706410760961233, 0.09173810962707767, 0.1320848043166822, 0.11842733354217584, 0.19173077067300198, 0.09873020177286479, 0.13646242989888116, 0.08980064262305537, 0.1936670425798624, 0.17195015064170285, 0.10792508015349027, 0.17182331712495896, 0.18768426361343554, 0.1611121668810806, 0.2350529355387534, 0.19194757355557335, 0.12228889931594172, 0.1437350098163851, 0.17137875630249902, 0.1424013426707637, 0.2883887122715673, 0.14756972420840495, 0.11283450865096624, 0.2780536652332352, 0.2585020288825035], [0.08112226072097979, 0.006645183114620347, 0.04168452169265478, 0.027249291644341526, 0.030394000219061013, 0.07001876620756042, 0.05022926721721888, 0.014073490033737354, 0.04560143348851031, 0.056781758959855766, 0.08166060602713017, 0.040482993222652905, 0.05489644722171849, 0.05848292997407337, 0.012656498377421692, 0.05117648897031623, 0.0396641026881914, 0.05402242516978614, 0.007500265557844673, 0.029316694821201028, 0.02580275484961608, 0.04043416277835927, 0.016968274872089108, 0.0065947702199581175, 0.0342290421136685, 0.02431753061471447, 0.025230370341770114, 0.04170645862036655, 0.12158255092799665, 0.022403203296445073, 0.007877488688175237, 0.010090678397025312, 0.04556151647721568, 0.01705844725121654, 0.02068620490571184, 0.02161184979242183, 0.014990155412364873, 0.004309407846566531, 0.01270253547362142, 0.02208627463739005, 0.02813140933041371, 0.029492272597347057, 0.022938570435789805, 0.04331091486458336, 0.011729361534479165, 0.10669885683924922, 0.05794211020392757, 0.014994224296852708, 0.027283269559003176, 0.013849125863353332, 0.03395867819387106, 0.043995632759986386, 0.01700559676054024, 0.051902882048800114, 0.019669253829746478, 0.036903784475139076, 0.030169952059945757, 0.015344599397071909, 0.037878064453722014, 0.04950568568141711, 0.04326299223448, 0.0056719292150509935, 0.007067157749852707, 0.019292409434133483, 0.11166671486271006, 0.039490442047075885, 0.0179893666532852, 0.05314294091095367, 0.01367194983627527, 0.024012200526833057, 0.011570452873955571, 0.06946032641515618, 0.07098664935197561, 0.05049650932872488, 0.03267903556866992, 0.023378249362952287, 0.04491051411136024, 0.051682658583646825, 0.018407524255434835, 0.09275938909981521, 0.02397023614556078, 0.00965009165567256, 0.025011500937022993, 0.018283553992307956, 0.04998089385128791, 0.032765948243679545, 0.02717099937369987, 0.038075910490607066, 0.06567799711539861, 0.051078536968317725, 0.05160913712555363, 0.08227340741864136, 0.01077491365703604, 0.03310264388640081, 0.022240168294839324, 0.041325866139584014, 0.048771715993362094, 0.03392670551435121, 0.032862456169940775, 0.018176286361150203, 0.025628416220687573, 0.08721461324321647, 0.025287464959546927, 0.007670042133184091, 0.02168814831924054, 0.026753347389580264, 0.062354278690632314, 0.07067797720552453, 0.03459537386774056, 0.0428429079212008, 0.0517930441926564, 0.11554928676735972, 0.09692096256560857, 0.016333138187145515, 0.03577506883190044, 0.0949133065859637, 0.07028252261901094, 0.03689336567936886, 0.033743859479023565, 0.014055926510463319, 0.03713736468325219, 0.03292772686108947, 0.0569622224617389, 0.053202293572887305, 0.0644160587821276, 0.040576720249749, 0.023451908716871857, 0.04897019405278468, 0.014325165238621977, 0.04939896963356484, 0.039681377970883926, 0.03145622134569191, 0.03965000667038464, 0.019787869138282635, 0.0420150694797837, 0.048137759083821896, 0.028840525210985256, 0.038249919701728134, 0.036932030136907296, 0.023864456640195944, 0.020377825787891785, 0.05575143581917209, 0.0472687932121898, 0.047158905560331005, 0.0704694863769316, 0.014214598641340292, 0.07097006354841494, 0.06600939142968386, 0.0441378110178536, 0.09339253778659529, 0.06439595663499448, 0.013891861120599413, 0.09381789278479354, 0.010933959255776098, 0.03288970208696781, 0.04996694722062638, 0.037590724025522514, 0.07193170307624726, 0.04434322600343055, 0.04502019108903985, 0.058810106974335453, 0.03542315485256334, 0.0263078730072706, 0.042223652238927545, 0.08453808589688233, 0.07113505590466723, 0.04909351122595611, 0.05304157981769212, 0.050891048440168944, 0.021326437990571705, 0.007238713085591313, 0.1212537153473785, 0.03986008713142045, 0.09678888900746262, 0.05557070418651547, 0.016434039627652497, 0.08497493221394478, 0.01220630489349846, 0.039323005870345144, 0.011097235575077996, 0.07413264303918808, 0.015362622573100513, 0.021358537074599056, 0.014787167967897991, 0.04419399973665995, 0.004836853636774205, 0.052032626699656255, 0.047844132904203675, 0.0367939351276765, 0.016379419473871108, 0.07081708345081537, 0.012364693571843449, 0.03232657766690658, 0.016887714981191584, 0.007871662110706132, 0.016783965608826088, 0.10322778140224757, 0.06373103445155487, 0.017041936141228484, 0.019638185133977283, 0.03855037172475169, 0.01808133359337526, 0.09848569715095144, 0.07724052385216759, 0.04669048875990895, 0.05467170766825157, 0.04346858725071915, 0.06740973120735538, 0.0375013598691552, 0.08998025193690293, 0.05486363567592156, 0.013062911851692104, 0.024349526276872046, 0.05887030233298579, 0.014820673780876302, 0.02806888889491318, 0.10048891748151473, 0.04424809703543302, 0.054688707159291354, 0.02431618996084698, 0.03589541741436528, 0.024838717466580774, 0.0338137535107953, 0.039177514282205415, 0.009382116014979059, 0.05781273327527508, 0.025869105724738013, 0.05416060444868861, 0.009050571355938671, 0.0346331266806491, 0.043826572476856174, 0.026069872471834385, 0.02882458866694041, 0.036638515040038094, 0.02619592074845587, 0.024269330277738553, 0.05107941796943065, 0.019601815109772068, 0.03062600228605011, 0.05607708064358562, 0.028995780589719935, 0.07384008172178462, 0.042683534819873116, 0.05263847967369422, 0.017364677492408984, 0.036911265323719675, 0.03436237971688952, 0.053242865589357195, 0.04257656596300583, 0.015316259889532963, 0.1125994039278838, 0.09375351075563701, 0.097529795621672, 0.01731456959650161, 0.0541157155267654, 0.03388711792086402, 0.019512950825775345, 0.05002492092429631, 0.040337513125832045, 0.010355742903606547, 0.04343171543892353, 0.01586464956598056, 0.012793288164351498, 0.02008790172816765, 0.03544874218923431, 0.03359161865627093, 0.03654855333508984, 0.03146450658659301, 0.03424551683448015, 0.01740891140915694, 0.02036041835503232, 0.06141774386407868, 0.018073169011322242, 0.015375491892618519, 0.060079204399258866, 0.018235177455109455, 0.023085850839232726, 0.02964547869088429, 0.0074863979300003386, 0.05867971497918329, 0.13073480417651515, 0.018769609967186567, 0.07298319705671842, 0.01733833364391279, 0.01791394529713979, 0.07803867255607921, 0.05750491531685956, 0.04942265707218359, 0.07721777870169572, 0.03903961079495569, 0.024609415859524763, 0.05502899958481712, 0.053912713718149936, 0.04866010464367367, 0.028079713717283263, 0.03866676729352724, 0.04873680153621301, 0.04077115336493139, 0.030605492197097312, 0.05207266628501877, 0.04241183790708742, 0.03245660960073433, 0.03492014918236002, 0.07499469113686393, 0.024125303832754016, 0.014522987335259396, 0.033017849444501826, 0.004697929337365373, 0.08849425586841761, 0.03802906421403732, 0.020240971841098323, 0.01576229830407688, 0.016265473471233444, 0.03133743941303223, 0.03313774986553096, 0.012950115938550763, 0.010489090082926616, 0.03308040818439857, 0.05500940688615365, 0.055807544098746394, 0.01659364638579709, 0.03175954811365134, 0.03643265189302545, 0.03654366569413293, 0.03690946118665799, 0.07115795427272398, 0.01810153341671873, 0.023513109565922813, 0.038573082401266987, 0.035885810671794804, 0.030565540711846084, 0.019579606220847177, 0.04400218664217861, 0.046727215014998956, 0.03596159975014387, 0.0736188508510109, 0.042556582559500976, 0.02992960538024143, 0.04172722343355418, 0.03421631356280658, 0.04288498147000228, 0.028003177703208024, 0.06746980782237745, 0.03458999976095173, 0.02126229727911132, 0.028312194589225036, 0.10297658883275525, 0.08558915086811589, 0.04548678460020212, 0.032615944397665804, 0.028073060243660887, 0.034259260451841744, 0.1836258209040088, 0.14419002007813225, 0.17791724012744042, 0.12338880239234817, 0.14653824810539523, 0.16989582458571081, 0.21793387349574797, 0.09067416671783694, 0.13872205219682188, 0.10883518494665624, 0.1576737957375665, 0.10223162195254719, 0.14372917222640208, 0.13836359965705103, 0.11266038452665653, 0.09745040593007881, 0.14850571511253235, 0.1923908779938375, 0.09581431025458921, 0.12146220617597142, 0.13996640881223066, 0.16166453159624533, 0.08279654587949477, 0.11812357201931939, 0.18005761317908767, 0.14157269600658648, 0.1383844066050745, 0.11336074976791298, 0.26691054865237207, 0.12402869265286193, 0.06857578597602344, 0.18897512176584816, 0.1991130543812629, 0.2755948294314646, 0.16906179998430515, 0.15103844775547906, 0.12779910928539692, 0.09260441717361251, 0.18630239421561842, 0.2065825342170654, 0.11774707044805251, 0.0749127886768791, 0.10889461804782191, 0.08803047389993746, 0.14443144502659, 0.14283461135721978, 0.13601403863679978, 0.11599631439293585, 0.1323455806461073, 0.17454285264736222, 0.10782993203329463, 0.14263260929334548, 0.07702153761901202, 0.09354320429866353, 0.09200466992033106, 0.11068841292252464, 0.23912049469447907, 0.1029104141578559, 0.14166390643485133, 0.09848104699725106, 0.10397767422780876, 0.2749267088309411, 0.11015766720858314, 0.10878227891460543, 0.2671037866703926, 0.1872641716392771, 0.1444053367501305, 0.22589942590603906, 0.12422412934322512, 0.12771267924577961, 0.091138576878415, 0.13791450359407934, 0.1268660831415365, 0.17618369040710313, 0.29833461728788196, 0.13452317024911606, 0.1960607302645522, 0.17014857231368943, 0.09124294103633973, 0.17809290408847794, 0.07502950983302248, 0.10108628986223091, 0.10987701855840222, 0.06924795918166637, 0.16977439964971236, 0.10559730667380557, 0.058745276783743215, 0.10558672699957125, 0.1984811237742824, 0.07997373404401927, 0.17457314376388827, 0.23000030988647094, 0.097020331830267, 0.09602096247216386, 0.1286761267411132, 0.16521766271081664, 0.09727239007911376, 0.15412801906706827, 0.1344067402063839, 0.12287685647606851, 0.12262317412082227, 0.11791073747219578, 0.10203754889868921, 0.14979680309132223, 0.15332963287590012, 0.07649357280423565, 0.1535505726332626, 0.25810963864768705, 0.14648627670061204, 0.09514504818305855, 0.24272935104466256, 0.20427644102563783, 0.23420194975070416, 0.14382985150141103, 0.2087339849000977, 0.20354052164381553, 0.18248577482037007, 0.07810706122507972, 0.12437133313787561, 0.08569451860122143, 0.1315954733159273, 0.16087418932828212, 0.12094799263943588, 0.14193432015036384, 0.21219297913053345, 0.09234200907690872, 0.08954482288250039, 0.13411443169799545, 0.09562102627129325, 0.16904436382314852, 0.12680111122467827, 0.11668804582328567, 0.11060892363950131, 0.11021338478331605, 0.09526125606029265, 0.13973460592810186, 0.10142936701736144, 0.16874100832689196, 0.16943580410893888, 0.10377580239888161, 0.11524756303838185, 0.13418158696543786, 0.13204640798991726, 0.1548784941194519, 0.17089419036863313, 0.139997435373164, 0.2386407091492607, 0.2064634994753907, 0.17831211248713155, 0.09767854691392953, 0.25327959218092505, 0.15391804968878148, 0.14296486162610594, 0.07634164990797158, 0.12074957586704724, 0.13165234768342587, 0.21203680444628964, 0.17113684105776972, 0.18328910993952907, 0.14956441798037098, 0.23169639790731095, 0.06944518851777239, 0.15339513339342611, 0.14214375326710363, 0.15513784552533783, 0.12070747933560803, 0.14230608729825867, 0.0882222333682641, 0.17229882789955986, 0.152016987182921, 0.19923086338225873, 0.1982308275276615, 0.10321417568071235, 0.2755431951053681, 0.11659998401638963, 0.12505990828597738], [0.017312968472739863, 0.08181310348933743, 0.03142245602042925, 0.06349012278200639, 0.025734400654572154, 0.058304826022997025, 0.08517670445144178, 0.05135979848883806, 0.04682427835500529, 0.03396990904284101, 0.04864916107767532, 0.006606643625174559, 0.030705200455662225, 0.07111687663822405, 0.07484275291884139, 0.047834637244382215, 0.0461297047384564, 0.13396058592104143, 0.02233349504099498, 0.014055220751963077, 0.02350717238450964, 0.046807091172424056, 0.018428580182033683, 0.03975366602741903, 0.028333296481099342, 0.027268464909866456, 0.03965840682447438, 0.06333156173387844, 0.017981043107987895, 0.026562957303418268, 0.059017352910051425, 0.024095606434369282, 0.06439535908641354, 0.017581639338224646, 0.03764340406163566, 0.028578911930502906, 0.023767759107173454, 0.05508754019355101, 0.0038009526577943396, 0.07133542620126279, 0.03248320434302573, 0.019184507865218386, 0.042989380101883606, 0.06439234069999188, 0.012240576794401053, 0.022029061275984974, 0.039284031147197376, 0.015493867798678338, 0.025071071934015043, 0.047075440280980645, 0.013125198630375728, 0.09363553321529781, 0.022807826040192478, 0.008209854976514415, 0.015921950069887024, 0.00901751466200597, 0.015271321171894671, 0.0414968531338438, 0.040843491217181574, 0.009908682719293621, 0.0112561461508214, 0.013015521652696115, 0.05826679358799612, 0.05409555975347758, 0.02138276843564405, 0.020620780996978283, 0.05740123680762707, 0.022402450615059466, 0.05195881029771221, 0.018463322269399802, 0.020703533814559062, 0.07077780612293752, 0.03271976463316429, 0.05071836073071726, 0.12911365487642829, 0.03278655983928231, 0.09728542123470577, 0.03610460155252968, 0.024663342703734676, 0.03968456106620931, 0.018942968003571998, 0.042022151962643674, 0.07962524830814331, 0.048702925128201326, 0.038110579799620375, 0.026918918142215382, 0.022604628879156326, 0.03459817008866418, 0.010950161057764725, 0.044900727338127555, 0.027986475071238897, 0.021099936434878938, 0.06604876834899187, 0.04824396951364414, 0.035369007758075194, 0.012233405253819883, 0.043622513466905204, 0.024684672506766456, 0.08506428104855361, 0.04839247565776591, 0.020004049574415532, 0.027827412235520543, 0.050904723109617356, 0.07636161415927833, 0.022391572166534684, 0.03583325320974954, 0.028459122592222788, 0.046804903991400235, 0.019555070339852286, 0.08125575920266491, 0.013751336655038741, 0.04529919265018356, 0.01610040450618873, 0.026074756282351674, 0.030558636344428507, 0.017656480382767417, 0.036832189728175445, 0.04590110410185111, 0.04063898787623452, 0.035975554041684635, 0.020835329665832465, 0.03290331163894265, 0.0037642467519148227, 0.0319408945318672, 0.02917914373439647, 0.03564017607019313, 0.013235161933417042, 0.012022168000018405, 0.021824726474381263, 0.07137408299792199, 0.0977768513163732, 0.05865088709059262, 0.009304103366429768, 0.022540955481329755, 0.006694612543909781, 0.035006016147353, 0.049137346776983434, 0.050292680145151196, 0.03688869254303075, 0.037662866525352, 0.024934915127232674, 0.10530169632646347, 0.02677168944970735, 0.027824275105470614, 0.024605629469959006, 0.0499752554441652, 0.06281372843190067, 0.09033726423137611, 0.02015747208779137, 0.04335331783119229, 0.041888186167324745, 0.0425066719312341, 0.004738759908509711, 0.08192938797536396, 0.09100265755888917, 0.01060076080442917, 0.02837734845196528, 0.049140077880433494, 0.017934411336036942, 0.036465586012890266, 0.047707240653013995, 0.042055771731200724, 0.013559061992583017, 0.04604258521970722, 0.029389505732744455, 0.041783550048186895, 0.012276333948266844, 0.010442056114815417, 0.029879056983777595, 0.032884167101714885, 0.05534233337628746, 0.03209013612039628, 0.03067095441022708, 0.014967888109235754, 0.023472583514728376, 0.0516800232411873, 0.02494416563891836, 0.08231490640149963, 0.014392456486670962, 0.05825726345421807, 0.026762494479396173, 0.025545111819801312, 0.07876885393934865, 0.025415369084164984, 0.016246148903343468, 0.009862214698636485, 0.05221396354177306, 0.04209602965162166, 0.02436915344949211, 0.033051825443943667, 0.09417036217787574, 0.007616329793592976, 0.03489117956750336, 0.08683602025191631, 0.05103708012029529, 0.022703218649351792, 0.03607850093694945, 0.03622391974673637, 0.01668637558337181, 0.009315966237937252, 0.08378905108979634, 0.038198193445080714, 0.05072660383678252, 0.024083538634342053, 0.06718561984598637, 0.012750204337099868, 0.030007514606920943, 0.00782918301410973, 0.03290980040366131, 0.014895239991376237, 0.030125317862257365, 0.06499136016974527, 0.030110076543003805, 0.016029502111186665, 0.04349365747804123, 0.057876693956073255, 0.022702442985328457, 0.03695153473545948, 0.0607198071215422, 0.06664539762442151, 0.05703359887364411, 0.04647971498930166, 0.02967181104806162, 0.04353701039367626, 0.05588433675227627, 0.03412659700599409, 0.007087319747604911, 0.01059974765314931, 0.050095925783558246, 0.010410389870465284, 0.054328649665319154, 0.10547929082907016, 0.03247448243200779, 0.03254092906812026, 0.07344436666537678, 0.018848754510643984, 0.004793972344017558, 0.01325470196353572, 0.04541831166152993, 0.020619984265537034, 0.01829912281414915, 0.026743679359975844, 0.05379246089667563, 0.020374248157285398, 0.06087947133628111, 0.008276735409914006, 0.03031748910284331, 0.06861580640918787, 0.04814143630585844, 0.023082707963523366, 0.05854696343322435, 0.010266503236526925, 0.04714767088092143, 0.04513607337890614, 0.026385724777355794, 0.0956382709104688, 0.02241341141803611, 0.07725970669379158, 0.05659941471211853, 0.046118653920148654, 0.03757177101027581, 0.015914342816798918, 0.006108188517241469, 0.02637449201316603, 0.029103804732702916, 0.06457983305858028, 0.05869704388803052, 0.02876160091780607, 0.04181774055224754, 0.08394183966541484, 0.044407676980500264, 0.023765746211152405, 0.02429647660333543, 0.010463095762045875, 0.03092404687777162, 0.05184011263472419, 0.008643087273794077, 0.056974747999300884, 0.019817556960568316, 0.04537570568162107, 0.04641300788329494, 0.05199377838101599, 0.05261604095839205, 0.008104077386369389, 0.049429142006462624, 0.029122460888878956, 0.05302651086822153, 0.060363522610597076, 0.03341303590024191, 0.039461303892875874, 0.04079687093654948, 0.07986353229611151, 0.041431436885989485, 0.03233653297948261, 0.026403517169397206, 0.018370056810278087, 0.03456361952327913, 0.014111643127586334, 0.019593326855571042, 0.05902248569914411, 0.016929968560655272, 0.019466954906801545, 0.036071667432664864, 0.033895276757257606, 0.045228084369051846, 0.0667665774122842, 0.058881318677336945, 0.011575014927544662, 0.08869492493930364, 0.028144894393100858, 0.03826861224708058, 0.04439751099374506, 0.07060457832149922, 0.0420637505369321, 0.12764766902452515, 0.024568039450734377, 0.056512808472278624, 0.07655587107423814, 0.050369974586271474, 0.03366544271909422, 0.0684297696176556, 0.051676162158048926, 0.07805476806336835, 0.04251643572182905, 0.0467927270238438, 0.03569030886395805, 0.006309716085407643, 0.025992434389228304, 0.04074269702898399, 0.10980962580370326, 0.05309426368424489, 0.04068581500060616, 0.07365492593136526, 0.046511208863868836, 0.051237435095132365, 0.023088438301196983, 0.04999262648784826, 0.024471349578591126, 0.04006186319935707, 0.031204881304274165, 0.024351290194317702, 0.03695532304024504, 0.04992422249708926, 0.013723012469258281, 0.024954557621611223, 0.04010606264214843, 0.006246100622980345, 0.04086420240421449, 0.0421610934990308, 0.07889210982548614, 0.03129731172755842, 0.09100526225783172, 0.20932191141670753, 0.16547033383000284, 0.10688323888086504, 0.12379060784775404, 0.10544608857843185, 0.09934515587144321, 0.12909235763213328, 0.19148594429416044, 0.15999035369003975, 0.07480699193453597, 0.12927370596556895, 0.15183965315020856, 0.1111201953984076, 0.15012329444289207, 0.19885980103525425, 0.2050794697096271, 0.14755533707718696, 0.26814554367334614, 0.1769453043779058, 0.13763200101112166, 0.11552529289357125, 0.15338851439376033, 0.0924404743578165, 0.10477796797790837, 0.14974450992961086, 0.1221719713160588, 0.10126800591787023, 0.27048376659231804, 0.13681738907771726, 0.09808894021496659, 0.14197624048158047, 0.170229961494765, 0.1679947007928164, 0.1234720991323552, 0.1470211439675862, 0.17423414985739416, 0.09149513718101288, 0.11457339800413578, 0.09168369440181602, 0.16845484384365622, 0.06758678178753584, 0.1061440559644853, 0.12499901961775557, 0.151846639872078, 0.15947388785500682, 0.17220793922822322, 0.13394546334541615, 0.14258463686752704, 0.16475522139620397, 0.20129876451626902, 0.09797826349254578, 0.16805445565091026, 0.11819259654129706, 0.0580026273195061, 0.14929847821833628, 0.18314746028232962, 0.12892043218016624, 0.09964085814933624, 0.20210344795017474, 0.10425167323480691, 0.11903428968282477, 0.07570293176198199, 0.1437747238143798, 0.15429312633650918, 0.12750890751880023, 0.09146938896587781, 0.22222332235786224, 0.1510557766643263, 0.10439827948087647, 0.12321458633748755, 0.09198865102183434, 0.14624753305988927, 0.19675436159295423, 0.05374850660202004, 0.26025633958558886, 0.10721046567684221, 0.15207502600406447, 0.1307350799681679, 0.11664548963909188, 0.18171980947015748, 0.12588041909639874, 0.16337563494040122, 0.22023222919914032, 0.1620614877150905, 0.1002543873243755, 0.14336079118713257, 0.13531392620455834, 0.1639281222296338, 0.18821314007284182, 0.12506802881797477, 0.16571411832926736, 0.19013341606384326, 0.20193604241696098, 0.21625221857140142, 0.11034705946522375, 0.12341306439691013, 0.09774303619539547, 0.09196780576941468, 0.15183570013651926, 0.18229656642483127, 0.15100673171541384, 0.18398116312680707, 0.15160830991883434, 0.12563845022551476, 0.10158130523538399, 0.1451914348909932, 0.12108426435940689, 0.14664813575725402, 0.11856611036965925, 0.1418036255504816, 0.10689119087351907, 0.11619751972536888, 0.21514767300217383, 0.11005554768827655, 0.13868747098791984, 0.11580679956222735, 0.23314491695454045, 0.12916125958004307, 0.17448360340729838, 0.1110673966186662, 0.12435079432062565, 0.06391051353045529, 0.07581673412313385, 0.12650792937605612, 0.06689414637343538, 0.14743035749321984, 0.1394109797453688, 0.06668935574951672, 0.20313216613665705, 0.14463412124783764, 0.23344652577032968, 0.15086658359054597, 0.21899251507655268, 0.13053015144842287, 0.08991693476996115, 0.1463958323602715, 0.23389770559245543, 0.1247537412470387, 0.2624507831229318, 0.13019295018767157, 0.13176401265926901, 0.1677105128164253, 0.1960948211771827, 0.13867711347918357, 0.12234611842300623, 0.1647737300804546, 0.24372764021879245, 0.28255351248287386, 0.1404312096776501, 0.11466323713501615, 0.06801880941155457, 0.10202956626251822, 0.09624335013570325, 0.18560511630869683, 0.18489620918708463, 0.11700664646923543, 0.2653968202010278, 0.13061216882159635, 0.09079114834387457, 0.11925666202460566, 0.15449367283332735, 0.20267116506734204, 0.159430036982221, 0.14606961680035438, 0.13775403881745954, 0.1219613737456741, 0.12237430279774052, 0.12438198942090235, 0.10636443647766307, 0.14597312036541202, 0.10404444645128905, 0.10105776840880995, 0.12227000758772898, 0.14996148135152557, 0.12193577108724464, 0.1626951956460553], [0.03542749474065439, 0.04147419991392282, 0.07942696943158105, 0.06417452275092084, 0.03812816534792224, 0.03529437547249179, 0.014657127415581096, 0.02964769460020527, 0.05204633201262163, 0.035891100508911956, 0.03364334874335797, 0.05116343483208649, 0.026058607148907842, 0.0716795222533326, 0.03683068053496461, 0.0525932843166013, 0.01928464704824071, 0.02281927139378123, 0.022368874896558064, 0.04103790134972623, 0.06383599232762091, 0.06810998153542319, 0.07978533004080096, 0.029325757641345266, 0.02918493535910403, 0.07974720184480952, 0.06632017797880596, 0.02747875029942201, 0.031991337591241446, 0.04267586627975107, 0.05351416030598264, 0.03889844377314852, 0.06273084154893314, 0.08465551951479527, 0.047972318566133904, 0.022305649660167196, 0.05983926949181384, 0.029019483350097176, 0.061064443265598636, 0.0322344632548911, 0.008100458578537069, 0.01133549562279856, 0.02480737680959846, 0.04744465635608762, 0.06162364914592716, 0.06984088059154249, 0.13291795557785419, 0.00418579860237397, 0.08880407714675512, 0.03424799895935482, 0.04521684585920265, 0.0364442044989236, 0.046852202259845314, 0.035179784040777914, 0.09666178735994524, 0.05272103330841469, 0.08174417089791068, 0.044556267394293705, 0.019346336278343396, 0.04977759326838198, 0.013693502762414997, 0.05302291408541703, 0.0037893533684133043, 0.027834695816460638, 0.04005374649779932, 0.011464231910424368, 0.06836008626006304, 0.06262470772790332, 0.022657502352470354, 0.012303417071609968, 0.0251602464836211, 0.041523915189769, 0.009730714748823836, 0.011221806259615528, 0.026055659625619173, 0.028242099459373185, 0.04738940992542813, 0.07127053855407624, 0.027613507080522758, 0.0121096849268783, 0.07704678021611706, 0.00687054080528117, 0.041022361256182194, 0.01691330806352198, 0.07876623391864762, 0.03511216145970168, 0.10556263353435263, 0.05173817697551943, 0.015946215904888608, 0.04990160375112488, 0.1020224033404262, 0.09478393731819046, 0.03577675422533386, 0.007544918907731171, 0.03656450711611298, 0.09988492610113275, 0.015944057452161948, 0.02655326437595631, 0.056649221918515624, 0.027410149041022507, 0.017961797064110156, 0.017311545464420514, 0.014024289952020251, 0.00437029603598339, 0.04597763628548673, 0.030413474174096223, 0.0067864626555913885, 0.04730254704613359, 0.020867174025624994, 0.07441511497862878, 0.008353788533338137, 0.05636986795692675, 0.013909182368567394, 0.023380886620631623, 0.014992191291023648, 0.030458707835585363, 0.07572417538012229, 0.027626681877600572, 0.01684788415478843, 0.03687924284848475, 0.05191843746410263, 0.03156153545264275, 0.01606788215858321, 0.04655811259703291, 0.030851111476940495, 0.05767690588630015, 0.03647346905763111, 0.05413972472231235, 0.03674829927002711, 0.027915684716595758, 0.06019549271572502, 0.006560985742497348, 0.06983910326755817, 0.03574120391520762, 0.02526366260773953, 0.09179093905033604, 0.07648146095415277, 0.04333927160910061, 0.11317184014666466, 0.02737312209642222, 0.013577337020016728, 0.043492642411541556, 0.08495540463275487, 0.05674602861906733, 0.030053297936495756, 0.07140278831244477, 0.026359394335398273, 0.0619761415216471, 0.01707923887748151, 0.03493811011374478, 0.007817705101784199, 0.0497025894301553, 0.0042965275145346125, 0.04776412268139182, 0.06684966730855166, 0.03349280097491799, 0.02664208460989739, 0.057999842589901346, 0.0473136629819149, 0.055601401329641385, 0.09900409352755356, 0.06033205171866764, 0.03720212975637086, 0.022157825334298036, 0.005915909066736218, 0.029409383799159722, 0.02300031712248681, 0.04277258488019148, 0.058335618927113475, 0.030409218555676843, 0.02315493281780472, 0.06505838520224057, 0.04982462340605356, 0.03350752518482266, 0.04784860685768147, 0.05012379606224356, 0.018186915831099597, 0.04514862189910585, 0.03698719612833473, 0.023090179236004912, 0.03758459532212827, 0.020740788670316822, 0.04472805495043436, 0.0394046631821942, 0.03232034171120294, 0.04983355216081104, 0.06921319411166253, 0.04512223400055401, 0.06469245564432875, 0.10354164762482529, 0.02810186131917421, 0.028693717866835576, 0.03191497203172936, 0.051109808677386855, 0.027758753520526716, 0.025898996560323625, 0.06383412307308567, 0.017374002697667288, 0.0319889320751592, 0.022894865119709604, 0.05505692348965714, 0.12428923149503047, 0.05555739340883109, 0.02831862781256918, 0.013968382770526073, 0.0722153471302121, 0.01877324505438728, 0.03316473531266374, 0.04436590220598925, 0.018461495149700392, 0.04830229944819885, 0.020516324908502644, 0.06743146512176722, 0.08622974592951999, 0.0333852575521075, 0.02510185334681263, 0.056542957862538684, 0.04327750577020549, 0.028516140601207173, 0.016504806999657905, 0.013603317934358794, 0.11902051542194621, 0.06053635204631475, 0.02819868717192402, 0.004082009010392452, 0.022842792208276452, 0.07100890420617596, 0.026244552009889198, 0.038389581360764084, 0.026709820188942458, 0.01616855951837234, 0.058467838041965044, 0.07126947369186148, 0.015118013571707473, 0.031137718375952497, 0.03859057601901793, 0.012704876829840004, 0.01871226062517493, 0.05956904346784277, 0.027628183409932162, 0.030754772090022604, 0.012290777578469247, 0.06452858943732516, 0.03913099742344311, 0.004731146909762174, 0.07678569745152228, 0.019862139447321816, 0.03521515815068157, 0.034176224181728984, 0.07992341738915251, 0.02851266256203094, 0.016386099760570837, 0.04521195438780612, 0.06890341113772123, 0.022501320007347295, 0.03252727355086996, 0.07604071524955573, 0.04806165973986349, 0.08106029952966398, 0.050296211810482126, 0.02580548020740671, 0.021321594399670442, 0.13420129074685036, 0.04476754678293102, 0.03517306161924236, 0.024698977283532583, 0.08202270514542058, 0.01514961948663357, 0.03140630497176561, 0.04221314151260642, 0.04968501920361192, 0.011664728611527432, 0.022484433514276342, 0.013788400946425335, 0.04130527752661898, 0.03267193010317222, 0.03332085254031324, 0.013197580532681559, 0.04521655474579142, 0.010960834577769763, 0.04407174742570327, 0.012220915147824394, 0.09347789530311862, 0.053993168271957874, 0.023434859430116993, 0.021202326001178835, 0.05130640216051571, 0.03826097052003588, 0.05915533683653321, 0.0309790596516142, 0.034575378972916834, 0.04398475048102198, 0.052374995223456816, 0.06443788462709035, 0.04584347513774711, 0.07045706809167901, 0.05242752204198511, 0.05344748384349289, 0.05976939461224022, 0.07505090666874763, 0.07058023970814482, 0.011435472012136974, 0.04397620093978701, 0.01720921910037437, 0.02375814278850392, 0.03736718339965709, 0.14192966233578422, 0.08812076502269314, 0.07819017410398492, 0.004862390220120189, 0.06878722624312486, 0.06288738395538061, 0.025472354534412586, 0.031561924242264325, 0.12738003620817778, 0.0110085197206166, 0.03639606353376181, 0.01456680947974805, 0.08572962074991196, 0.05360998641399126, 0.047329838928436084, 0.0579923349282434, 0.02773344006028868, 0.004125792850484891, 0.021050211582933704, 0.06333263808741205, 0.05293248889727458, 0.050826279536610654, 0.03201336261906451, 0.03214979138706, 0.006444173134608015, 0.01925353813285549, 0.06920348011678265, 0.08274377774327032, 0.06344006276659428, 0.03481990657746792, 0.027987335004933903, 0.032112731883722934, 0.05120424050537329, 0.037499260788242665, 0.028239755230324886, 0.0627306538573917, 0.04866787277522588, 0.03704574822838749, 0.026569147293846455, 0.034091701701043114, 0.03823367863773339, 0.03955888051179148, 0.01471661318529157, 0.03973224237861653, 0.04086493018774256, 0.0554167932920879, 0.16088566532538784, 0.08928488158891279, 0.19566601112244592, 0.1264280340664329, 0.19551996412056108, 0.12254618994531133, 0.08686780523989471, 0.11342193721042526, 0.09282099789068585, 0.19995386652167768, 0.1141558571027652, 0.09331211387630432, 0.21361034904276172, 0.2061206444857582, 0.12048493079360455, 0.17272153989441935, 0.13944955993323557, 0.1994965579961577, 0.09931800571540672, 0.11587844410490607, 0.2768451462109243, 0.20270297303795817, 0.24284331428427852, 0.09014498382326096, 0.19020112291459115, 0.20736705421680407, 0.14149833951265584, 0.22500691815249382, 0.07469187956303358, 0.16201811181681772, 0.12294679264267608, 0.14545893747239344, 0.17081326084031215, 0.1234413713457123, 0.20629489884501506, 0.12572489558689057, 0.15350027130015437, 0.1412682833089944, 0.10778025123140506, 0.1509755672586541, 0.10847331565474311, 0.12008437406151526, 0.19185515270838815, 0.15920545064633893, 0.2279621636074397, 0.2359336608600232, 0.22516807240824546, 0.07711300851717111, 0.10885296584737879, 0.18496143391295788, 0.1605099758073207, 0.16422341848092695, 0.11716399326800339, 0.12997331277978036, 0.17313792400302427, 0.1501865273401622, 0.19467847782277292, 0.19525727257132533, 0.18940143437395174, 0.10469417328075056, 0.18131183700696116, 0.23999797180294993, 0.13766022369025216, 0.16147710052469086, 0.1788418622867715, 0.10766107093302474, 0.2800383538969102, 0.13674419703743151, 0.10109575104809577, 0.20265242655671414, 0.15804236063793783, 0.14293991780329135, 0.14978644558258597, 0.1000747703496487, 0.11906366149384169, 0.0991799260279344, 0.24481035228217804, 0.15778268747512372, 0.1283182487672856, 0.061270513256350835, 0.1931970629600748, 0.10137131287445945, 0.1790980267668924, 0.17111405760290163, 0.1167346546125989, 0.09905745155147969, 0.20052064901157735, 0.127578912633321, 0.18970425360866133, 0.11517444760688852, 0.11727757346365722, 0.09216276748526482, 0.18983594412284513, 0.12555878474226884, 0.1888341003007466, 0.22535594781079601, 0.1061456494273678, 0.15290511291353934, 0.0976065040055302, 0.091736952834312, 0.09751607498694813, 0.12407442810194147, 0.17042866938056486, 0.09708626135703056, 0.14571427457755612, 0.09059918969268761, 0.11813766803712615, 0.14192479001658578, 0.07913145101478986, 0.12053031384223893, 0.1314566428622892, 0.13727543304764456, 0.20064774299821547, 0.12679396362434472, 0.13979785414713045, 0.17579195900790154, 0.1564439335056851, 0.16016762643571825, 0.19841750783305015, 0.11868571967727716, 0.18154557043265912, 0.13918435561560816, 0.13156581039149917, 0.1403031197767104, 0.15156620572651588, 0.11914456803952495, 0.1483154954809335, 0.085975251521074, 0.13155004430201747, 0.1029736087507298, 0.2164014218555343, 0.16039798907454939, 0.18229062158253886, 0.18629456479703227, 0.09197622507570252, 0.1827317962963735, 0.10138543953578319, 0.15675403057567536, 0.2747093543650643, 0.14357972379413345, 0.206504715005717, 0.0975776378125433, 0.19549250752935488, 0.15827895923247262, 0.0575602421867511, 0.1115841459062311, 0.09459838316205049, 0.1273168952414586, 0.10676323886840575, 0.14846025545510555, 0.14918331988155842, 0.11158193957300917, 0.13230494734260345, 0.15090908614858506, 0.16484232559319467, 0.14085160808697825, 0.2130613091491884, 0.15829166097025718, 0.3328825779739888, 0.1418843252524253, 0.1792524241271519, 0.1450355513201606, 0.1318207797744582, 0.13790668949725168, 0.1504984783429292, 0.10281476808050949, 0.07472231623626525, 0.13986251196793972, 0.15525695687580496, 0.07905592240633504, 0.2000245457935718, 0.14549655238947562, 0.2157327803152223, 0.11212467456296568, 0.1239436568932668, 0.10030619785069458], [0.03942164352103587, 0.07076825300652174, 0.028462050963313352, 0.017589279150049535, 0.06564342356737583, 0.034416932837977525, 0.052880249361717896, 0.023274097794426546, 0.08358128038385222, 0.06092850479387468, 0.05308918069086729, 0.0757866958156228, 0.04046178790890882, 0.07093873055231187, 0.04398139501591364, 0.05764761451451529, 0.034944499287033276, 0.04362006581598713, 0.025913153865164327, 0.014525697371291538, 0.05199329574562369, 0.019304638112624808, 0.0337115612121359, 0.04107199992323595, 0.048801103126137495, 0.09643640429262193, 0.017403387915222876, 0.05852518738397668, 0.02517234684238511, 0.08556682706600235, 0.018126486815632354, 0.01224401078352164, 0.056810238278440894, 0.054499146363307396, 0.01767610180972805, 0.03387402930867768, 0.07658590172086993, 0.015668033100213977, 0.013271756995950016, 0.02931151032117346, 0.05934978527347407, 0.025883404755844705, 0.0437903173658396, 0.020125736895528053, 0.040137376486053394, 0.05712791961888152, 0.1078690484827084, 0.03476579395693637, 0.07632757687280256, 0.10330597599667889, 0.06326087480110508, 0.06999988980110615, 0.05867920936115327, 0.032599914007850235, 0.029709728569873882, 0.04898851121505422, 0.0427440251223743, 0.021555911967410676, 0.10744889522151602, 0.03760174803075291, 0.01916531927793497, 0.05705467778288069, 0.06316000400411506, 0.07559839140383467, 0.0530120088238149, 0.05286363674507988, 0.04705516193362494, 0.021244828559217915, 0.06997985660188621, 0.08433364001252959, 0.007538702583030588, 0.04236965710597654, 0.03298370490571664, 0.04291792708118597, 0.07089608243756718, 0.13210938041729312, 0.019236011956367764, 0.06827786204315002, 0.012526657965575016, 0.0506975882566504, 0.01636374531494033, 0.024683333768118775, 0.1240241037861955, 0.04721478784396764, 0.041560335009689295, 0.045601686297525326, 0.0711012944098442, 0.07036212681522293, 0.006433617879426288, 0.04662030744516561, 0.025664830294948433, 0.07557108036933408, 0.07466566403426471, 0.029856162446160472, 0.05498122251141937, 0.029786222449113286, 0.012610890290459559, 0.024695181317867774, 0.030650624351936485, 0.052109392540108775, 0.027531528011745507, 0.03243920025265506, 0.020441307663737286, 0.025762891464476145, 0.022683032232547, 0.0299105929931806, 0.04210774313598391, 0.06450020587973057, 0.051695107512416384, 0.014694125631884223, 0.04399177550728764, 0.048054749626786485, 0.1300324700892933, 0.05027834664008791, 0.03129036139486538, 0.07423651690084128, 0.0574765892158593, 0.02860825309800285, 0.055605423291243856, 0.13005497775250865, 0.02772741477876421, 0.09506336788857177, 0.02346819383092225, 0.04031789361409122, 0.05998982875157268, 0.04107957653280708, 0.023307464753968582, 0.039821985748506365, 0.038438147504723845, 0.008942855563345216, 0.019190291829046704, 0.023075631226322824, 0.03941748749404665, 0.022529816562910716, 0.08560803493544941, 0.04575198125695029, 0.055053682937737436, 0.020590194936601386, 0.010141417357860314, 0.051271315333583665, 0.02911408754786657, 0.052766458491884896, 0.03179450662085607, 0.02546686934487474, 0.04418955259625951, 0.059046590655681595, 0.023214580423589197, 0.07374935392891208, 0.007208745641213272, 0.09094839555121238, 0.03704713101709082, 0.008700365752672717, 0.040067317745377945, 0.025968969116107594, 0.04470953094442526, 0.023155116678906545, 0.04269918216572654, 0.030387365897636742, 0.0414325668656778, 0.03194902847040325, 0.029163030990129037, 0.026302973874994827, 0.08647308609778843, 0.02575924680117638, 0.0019429381885152732, 0.010151894567834755, 0.06075585155837959, 0.11744471852697673, 0.05978568547195005, 0.09441314310195947, 0.0380389046134247, 0.056096516294224616, 0.05687217265667935, 0.05359633855762021, 0.05002733027081817, 0.019480920689661178, 0.02570234945104007, 0.033745790020592754, 0.022567699610766385, 0.04294726441824629, 0.02385327750216088, 0.07981813392571865, 0.03183846474595128, 0.018039738849526452, 0.030959083908988588, 0.047465095581907424, 0.04937131768993793, 0.05999706062157789, 0.013596352279907273, 0.08170857845294861, 0.028302028602469834, 0.033926291826872096, 0.04425165934428092, 0.035739250391000704, 0.01469110054219322, 0.033756898295494824, 0.023293567919022134, 0.03307031114555655, 0.006720473757013679, 0.03858193454723205, 0.042262033243933995, 0.033424347188443906, 0.017582717606978073, 0.10507496494439342, 0.057759566773330016, 0.04431401507087773, 0.08714872968172835, 0.020190094026827046, 0.04323645494878293, 0.05034536401170397, 0.004803626967083302, 0.027334614686908263, 0.03946124643628155, 0.020310335356982488, 0.05223193596447668, 0.0365351238137772, 0.13899589798623516, 0.023734983950552922, 0.05392249283050338, 0.03483432052176326, 0.03505470103494102, 0.024979579968438036, 0.04815337578615835, 0.039673529400099675, 0.07258141458395027, 0.06036573277425863, 0.032013184503622116, 0.05754506981541073, 0.01736941191578104, 0.012583284312108112, 0.0455675340978609, 0.00804226941263844, 0.035869707503626426, 0.06528634232498946, 0.02273258088426965, 0.02473956270654115, 0.08821650303059048, 0.008265497857674716, 0.026900692910496748, 0.051828950733667424, 0.027688556884024895, 0.027488100402537855, 0.07489444853197183, 0.08124055235736793, 0.01972057980545346, 0.09395778043976716, 0.062259073113842364, 0.06068584644385885, 0.03319679609229488, 0.058558029573290586, 0.039344176710132635, 0.01122666229944556, 0.06181232127991896, 0.01273989566646877, 0.018040238721897046, 0.024809023898635662, 0.03159182465394899, 0.01659735425135061, 0.07395867979334247, 0.03274736678107612, 0.03489659580912802, 0.012535665244344744, 0.03351756476707036, 0.05383085339300094, 0.00964483533490209, 0.03348628922756161, 0.017058211679179824, 0.07685935680544184, 0.023180728913435054, 0.020392701300161502, 0.08097707939844939, 0.06162281794052932, 0.019422788022746964, 0.05755869085870444, 0.034902808782193935, 0.019269191224368352, 0.09163017549942579, 0.0710378853123515, 0.07048231068878405, 0.04810143885533175, 0.08969458541081798, 0.04472695944470264, 0.030327833205040906, 0.028078463078746875, 0.08565741696304853, 0.02193017847715847, 0.048485961367165854, 0.04649619737099256, 0.08452438058391695, 0.09271933036225458, 0.031938540726719845, 0.054435882822520314, 0.04998144543459339, 0.05005107899647086, 0.05189712106760952, 0.02275328824086295, 0.024088627373379086, 0.0701180741851849, 0.015342996358090352, 0.016283989816363302, 0.025739998842078834, 0.015110887038791853, 0.02368629714774509, 0.0020664541854432997, 0.045091058052475416, 0.03593221261736847, 0.009105759372393931, 0.0300496187992394, 0.07671757691329525, 0.060963143459371025, 0.05483897530563897, 0.009403060858828888, 0.06106378826042337, 0.004361328976829687, 0.03387340111657977, 0.021769363215313326, 0.007786570330931535, 0.030320584098057404, 0.03022010975156821, 0.012944335805162067, 0.013248820323497059, 0.03577527184520037, 0.05029074577314239, 0.03504369618190873, 0.029535943439470667, 0.004346482671662084, 0.014325522427116672, 0.04285810710561853, 0.0435247759695255, 0.04714803860312508, 0.03281912623694347, 0.017326290741743102, 0.07130954009030135, 0.006678336527153489, 0.03626117843293375, 0.03185624756189364, 0.023772644832910552, 0.07633278627068767, 0.03717210677061831, 0.02753189573394916, 0.044841148680256265, 0.027110503325539253, 0.03667410748500017, 0.017942918742436077, 0.04141285159294644, 0.011118769349019614, 0.03360617049639264, 0.055226818808624824, 0.03490892982470893, 0.021542760152970592, 0.024017580379281315, 0.04523235913966933, 0.09300836767520636, 0.12365304910007024, 0.21435564534077722, 0.08715009331823358, 0.1834703969859308, 0.2162376629008401, 0.14132287473447863, 0.13256103521393192, 0.17665949229511524, 0.25005011789260373, 0.15581514385919418, 0.10526493942785649, 0.1251660727505242, 0.1087489311072615, 0.13574100490058624, 0.1798192679040855, 0.09904174674903193, 0.10984911763619994, 0.09910335553990257, 0.184801627971953, 0.13975257835080548, 0.09091822700875421, 0.09048998385908143, 0.16981227503668878, 0.2099363905407729, 0.19494208867751783, 0.10620630826921233, 0.20097360615768742, 0.11659336501672385, 0.16685869965341785, 0.17666267922088025, 0.14322003019192528, 0.13076100438352556, 0.14910674173264735, 0.21275859716678822, 0.0926413196289251, 0.12239603671215235, 0.10034411920294647, 0.0990592978233772, 0.11258394427357182, 0.2506590811836143, 0.14753889683033192, 0.10080026327482156, 0.0949998745214074, 0.1269704779429782, 0.10209883593263165, 0.25256185972642514, 0.12740780689543293, 0.1022926178730784, 0.12729756684312898, 0.14844291122449985, 0.261276155830391, 0.16830461400170482, 0.11875122019480314, 0.17453843998091836, 0.1834473683829269, 0.12355671354359198, 0.1868733135803092, 0.30103569009131004, 0.14795201740437938, 0.23368068820526525, 0.12826875948737707, 0.12173262755236319, 0.14176780327914223, 0.10155690533499565, 0.122835066379799, 0.17355030913266445, 0.14572161369987074, 0.20512518983694816, 0.1667692052621034, 0.1576729377190913, 0.1326213263335728, 0.1251778398610411, 0.20377465343523413, 0.2673927550354312, 0.1740121222551792, 0.14085724649410095, 0.22775550372898581, 0.1176504054737668, 0.10818332839276522, 0.12853679066944507, 0.10409386678328438, 0.19173726709859987, 0.15010167544166889, 0.15806480701411926, 0.13743260364618995, 0.14058456515833256, 0.1964707251998686, 0.14136162346168873, 0.2134982703794395, 0.08960181216318762, 0.23315781787518533, 0.16994762745115066, 0.2846512144371387, 0.18547383948199211, 0.17216957354497525, 0.10537665036897506, 0.15466126222764293, 0.1252968362983196, 0.10454238061943363, 0.18554723070513818, 0.16483285674645057, 0.16183513937698257, 0.14968585823812794, 0.25826818820449615, 0.1189195909988015, 0.12442567175434482, 0.29476431048204826, 0.2332955451622125, 0.18765743521432723, 0.14174426905810833, 0.11679143704954656, 0.2827692734858682, 0.18052935480110108, 0.09727912399196818, 0.1256667571743169, 0.18799017784335922, 0.19055002999882545, 0.1628390516364767, 0.14302496888464497, 0.07849248772066447, 0.22828759775767404, 0.09858534986814184, 0.21955535987452154, 0.14864096027468482, 0.11189247331311626, 0.08295470473146246, 0.14767979572136558, 0.09743994882991237, 0.08407520791215282, 0.1299448449525141, 0.21426811213454894, 0.15851486834787554, 0.09031110998964118, 0.27507128494401134, 0.11965710384350632, 0.11206405402551736, 0.0753298852472536, 0.1138762120277651, 0.1996550922312083, 0.1257181003870022, 0.14614386604197566, 0.1307956775229785, 0.129720825521696, 0.18024864486388623, 0.1525758636454421, 0.19656693052139976, 0.15418754409878485, 0.15737390295872766, 0.24038889114895176, 0.07409941780591205, 0.18554450343212775, 0.13660020315118376, 0.10005741845816375, 0.11015451858721434, 0.12090746658824145, 0.17959826685968908, 0.13463999865756882, 0.10741697233771125, 0.11842008635041215, 0.08477764159080484, 0.17244236213305306, 0.1716801812571864, 0.1087435455091538, 0.17156068686275713, 0.10766946725667485, 0.14614495388682813, 0.22951306264487006, 0.22551638194389884, 0.14858639949271757, 0.13631592324424174, 0.21942504831860143, 0.15224275329420645, 0.07480737497849811, 0.13397146436956622, 0.15549321839165303], [0.08479295568841119, 0.03610814470917948, 0.004114119106933716, 0.047108048813477646, 0.04054929047162014, 0.05574022795283987, 0.024295767972005472, 0.042364493673366886, 0.07838761028383048, 0.04595767969505922, 0.04668991419396574, 0.02165323960775089, 0.03274280855792665, 0.0648193734307443, 0.014177802480727196, 0.0944654975507048, 0.08180567243647191, 0.07204934353789977, 0.04156600789076859, 0.02960612283899419, 0.03820976903361659, 0.009428203864503772, 0.03640003953008883, 0.01255437981472501, 0.06297966307629982, 0.055431099984073834, 0.04361358471214772, 0.030476032913992965, 0.04061817709777144, 0.01916689358861937, 0.06249754862379163, 0.10726129561061822, 0.07314709390723899, 0.05190831744262288, 0.037734135684947816, 0.025400485911016023, 0.06687120970098243, 0.10200972458527935, 0.06285691280819236, 0.015009215679920971, 0.018934583171240745, 0.04714780494630818, 0.05383891263796438, 0.018858568096954017, 0.01884650412736641, 0.042921918399271466, 0.014787773177358172, 0.048378946545023116, 0.0484964222977719, 0.031444124817367525, 0.04620095857629373, 0.04490071967724831, 0.02468408453428457, 0.012944147156010713, 0.03186695555585527, 0.010207929111446344, 0.03718888026572043, 0.07220074549437532, 0.025992595267692403, 0.017932476964028134, 0.03754715660526868, 0.01060679566205269, 0.06580954973375605, 0.0487878612963663, 0.03467283684820418, 0.016149072156798457, 0.03750440123821459, 0.04874540087316306, 0.013451163296497638, 0.04128584187597998, 0.031590907263659665, 0.06389076378376735, 0.025314230156401475, 0.03356597769344526, 0.04730139791424717, 0.060937272670168074, 0.020299374554005843, 0.044171423125531406, 0.049050974193960435, 0.06589666925250523, 0.034115810488020225, 0.05235000543536679, 0.059412321030733094, 0.02483075206738807, 0.02915898796110865, 0.02531822338970679, 0.014222248029264231, 0.05463506185239362, 0.06157001149990867, 0.03614881248663991, 0.027830512976394068, 0.026371550235536792, 0.03464958991014189, 0.04085197564094298, 0.009061775391831273, 0.007316541394233825, 0.05364821420141286, 0.02175435172243705, 0.05275821921625926, 0.029555698931818048, 0.008911814638263276, 0.03356804613084082, 0.007464060242543178, 0.03550537523903674, 0.03423252015284473, 0.06268226774409413, 0.02900762047858969, 0.06739701414781232, 0.03755984302129477, 0.009932181508761021, 0.049361680303850484, 0.05192588000828701, 0.06917502761127488, 0.051327584491622065, 0.08414516706139812, 0.059853913262486465, 0.030826094875773116, 0.027486030049922488, 0.09828657557767245, 0.03371644502265319, 0.002655067787160196, 0.03868323052302003, 0.04012275952845812, 0.04683902554754769, 0.0020102827036152446, 0.031612643093291315, 0.03666145937337029, 0.027218263168188355, 0.07446004603538783, 0.033887604386695934, 0.0795693698549463, 0.039892806746666475, 0.07472935658428939, 0.041071934805762385, 0.017260746174161474, 0.02778009673009717, 0.07942778148478077, 0.1462485902612248, 0.043075354319185986, 0.005429783186334516, 0.05879765038468665, 0.04739159710645195, 0.10977702110164589, 0.020169984218814684, 0.0213328980269932, 0.0963837817131031, 0.026246702801736615, 0.03024778276261303, 0.022171501918966253, 0.09958905528389639, 0.05440744563877102, 0.01662066247644684, 0.02086178076663806, 0.04967513283894909, 0.033246687568363645, 0.06618553036523443, 0.04466220203246321, 0.040855484323636185, 0.010170701068765935, 0.06166744256211866, 0.06934473906914074, 0.04243174087136023, 0.016532248269105633, 0.04848857755742727, 0.05587382602595514, 0.05490991887786696, 0.030490109779601617, 0.031530949392265854, 0.0512653436782139, 0.030602111834131425, 0.025934016354562297, 0.02528274968837298, 0.026594952965575843, 0.035967594388151364, 0.010519675185693609, 0.022229517757472013, 0.023765656195821303, 0.014794427608590455, 0.03615404103672312, 0.039008649351495894, 0.07233313314857022, 0.11584053041353343, 0.021770539160277096, 0.025089760648927865, 0.04136822314091748, 0.04466575668043187, 0.06227335682319057, 0.042760641569451946, 0.04026929682661449, 0.036792506373697714, 0.018950014097255566, 0.014246283080278626, 0.1322611424350931, 0.02748475068308894, 0.05543117276242664, 0.028928500832989815, 0.06396213253479331, 0.016684835746644006, 0.033502809913648714, 0.0706112892517159, 0.13919505020303113, 0.04596377392449687, 0.02456619700927648, 0.021186577148675438, 0.047318125444073836, 0.00937838995483734, 0.022202783204134435, 0.10135008457807765, 0.036086858956203345, 0.0281706023886199, 0.034794874654542056, 0.03962166141718626, 0.046136844677910696, 0.02804887101745173, 0.03533246153364739, 0.046804900160960616, 0.014487862203931137, 0.06725726438866508, 0.062135602723086075, 0.02328680719309036, 0.046982735981263464, 0.006291570814116108, 0.09279031606931841, 0.05141566928115584, 0.07002835762837241, 0.05008567935757099, 0.02360343324741529, 0.030202941721185084, 0.08772865824040868, 0.018859904920381886, 0.013094875912722802, 0.014491468562834687, 0.030782910499481425, 0.015138677835855034, 0.044163157036828424, 0.03133359939731177, 0.04227680341911413, 0.03740346149331139, 0.004934899484543431, 0.019700370406010942, 0.031803933332764336, 0.057607333611456625, 0.023937572071689273, 0.006892112404814051, 0.03529549013042162, 0.00937744862430038, 0.017095665717797897, 0.021470242270058202, 0.022564851678907875, 0.048152770576698166, 0.03527109406047291, 0.03014401615326924, 0.020941059375482223, 0.017762392038299192, 0.04308892173632499, 0.02360470686858941, 0.019954181080984495, 0.030219816722937172, 0.011765295846177446, 0.059489588658776016, 0.041357356183711565, 0.05263319366701669, 0.05549033773281882, 0.0481828433581658, 0.031006330466498772, 0.09286212149046122, 0.03096641920086357, 0.0225273440141351, 0.0338209126024477, 0.045322244235825156, 0.017897491643746054, 0.06094949177256035, 0.03211227031574855, 0.04830321109282875, 0.042536641290831956, 0.057095563895399534, 0.057811296860417055, 0.04065925856271098, 0.02282208102124353, 0.019865267001272693, 0.008831974870014575, 0.018898575123579755, 0.0018506023292091766, 0.05992530499615016, 0.12487740315977605, 0.02269554436357031, 0.030770976764840946, 0.08337559343706216, 0.06767231550428175, 0.05049151443545857, 0.06801263474288487, 0.11526838530816379, 0.01551899931303436, 0.03355755838715742, 0.020961044694206888, 0.012321233403899018, 0.06823905202890597, 0.03606394909682774, 0.04241237799907404, 0.0456113275140524, 0.007219594882635941, 0.06691637824499799, 0.046096287983199286, 0.0666119808691644, 0.032156123103754174, 0.025919018268224694, 0.11838475437534433, 0.028891876084549777, 0.026791073389411457, 0.05599590596712886, 0.018475430289043054, 0.005239037826897637, 0.04309790411723718, 0.05649077961401594, 0.04492970461386346, 0.06118435517794663, 0.028820695025065256, 0.02855636979333095, 0.044366181828081615, 0.03833837604390518, 0.026578629547129237, 0.018116768990312854, 0.012097507001711957, 0.07417025795627026, 0.013029196322144521, 0.010793644506784697, 0.01483104278093144, 0.01950018780095683, 0.024006215464924614, 0.03180632352708809, 0.09662407285143292, 0.043208266743609024, 0.048495824749190966, 0.02276808905956005, 0.007758676111998578, 0.027425497612585465, 0.064303053152417, 0.06348791261834484, 0.007765975972307065, 0.048011189867411895, 0.008318264078679345, 0.010850380978456909, 0.0969708655329962, 0.03675031408126797, 0.04921585163702408, 0.014437089726749449, 0.04565288395350499, 0.016036147923929798, 0.037333437226592533, 0.049250421354607235, 0.034831654535786766, 0.02038253148296668, 0.20372635925248747, 0.13779025945451953, 0.1184083192398952, 0.12888001338128122, 0.14927281427287287, 0.15762213076795303, 0.08698555295385661, 0.09132595432381477, 0.12349367216830293, 0.1469842798166698, 0.20129424459751577, 0.09054700378328563, 0.14051607689790188, 0.19480183330034057, 0.07599047520348141, 0.21926153451204303, 0.23563123999103425, 0.11231523893413045, 0.2439359548471628, 0.12487400172939225, 0.1612313088750647, 0.1446786769215138, 0.1615504151390445, 0.12825749799489014, 0.3366528030845427, 0.19445516319284517, 0.10355061085353937, 0.12317736212524677, 0.11406506036197948, 0.11082855338651328, 0.15750478141971175, 0.1904247899449641, 0.15866758031470163, 0.19266924370200406, 0.15724045044231802, 0.11154807082587674, 0.1313675008714199, 0.12661696667031896, 0.15414841232761262, 0.21144693206635215, 0.11145901310467914, 0.2581096080041701, 0.15569797837205474, 0.14403479534291452, 0.07404267367336058, 0.12558791906602923, 0.13809690912885053, 0.09550762993674125, 0.2294517909326861, 0.1351143603002833, 0.05540448608958433, 0.13579507538628194, 0.2104791638351256, 0.0748222983712631, 0.1142753208536775, 0.0966746116717977, 0.2842057189874111, 0.2639484850149001, 0.21046609437513739, 0.12361479066913167, 0.13766174054434224, 0.10115414993056368, 0.12204221900432341, 0.09855882790420326, 0.1571881879241236, 0.1638857575674211, 0.177168664973109, 0.20425051661028018, 0.16846435865567577, 0.09288475172774446, 0.17941080514461766, 0.08992425090963803, 0.14314964203344238, 0.14642229303717613, 0.07989674220762907, 0.1670603033515715, 0.15175598102711862, 0.1628955582817716, 0.11750415162814241, 0.17324905271732038, 0.09868247449518212, 0.15793428095358034, 0.172607469402494, 0.26805493079366227, 0.0626546464439842, 0.1340634715292723, 0.18001259785265694, 0.16481733580510463, 0.15647350449956235, 0.21769284691301086, 0.16147734567282662, 0.09006462886088318, 0.12293356230422375, 0.14795259963120186, 0.12558803397921786, 0.06805758878228164, 0.203144469508721, 0.08843602552529305, 0.242536174313676, 0.13359583613853301, 0.15547869336460868, 0.17817944138040467, 0.12301941011701861, 0.10573027655482294, 0.11584505799316591, 0.16170652853625436, 0.10171520974366896, 0.1240556589477966, 0.27289513558630024, 0.07813687736709272, 0.1686258653118726, 0.2504771506233562, 0.1427765418925593, 0.20053056218931753, 0.18691538712911068, 0.19008020359662273, 0.08689955958435613, 0.10744046825434893, 0.2122617125390999, 0.07881317212576829, 0.1400766488645346, 0.1701026223599911, 0.13483317538855538, 0.11052390320166466, 0.1066436218999086, 0.18565664338248392, 0.10790640292989631, 0.23327789449643707, 0.14072626078080747, 0.0879716536691112, 0.2056234381011417, 0.13109278174177294, 0.21739716761775557, 0.09486819932898206, 0.19319851852713094, 0.13254453368004293, 0.18081682163380808, 0.2949813278692384, 0.14622127156584494, 0.13138331292617705, 0.1646463756239222, 0.10826604290594978, 0.2412459596751198, 0.08770490185387673, 0.12537359064745326, 0.12493109826238886, 0.08302446469784745, 0.0864715769045776, 0.10886069567453478, 0.16218516494958632, 0.08452356853071721, 0.08947224371255406, 0.12370223194480905, 0.11741140902402902, 0.2369648611713802, 0.1490727274288093, 0.097820985641691, 0.1368685790728177, 0.10469813395531909, 0.16662136561447577, 0.19177356434445228, 0.13115449778495297, 0.07986227591191569, 0.19511594467105406, 0.19155682274891486, 0.11523796395669061, 0.17338078919677966, 0.1103911478252661, 0.16688581916593737, 0.07408372832522278, 0.13433086685836315, 0.13481627548894576, 0.07737215307931747, 0.10928195210233813, 0.15443077701474392, 0.13083235781279304], [0.012666164491806301, 0.012168564529518687, 0.00914444585496019, 0.02485045201836094, 0.06076511739182377, 0.09190760658032472, 0.04913720505071744, 0.023777854230795658, 0.02508762709405874, 0.019587933596584107, 0.03745809505363146, 0.10297925481873174, 0.032572162472793174, 0.06775593400121697, 0.044361841939990564, 0.01713345108944322, 0.03350765158933017, 0.08859619918850162, 0.05958795817869325, 0.05258414488766463, 0.025912521842626796, 0.06352392258122563, 0.03332099809701885, 0.012910845313942241, 0.04516177945920537, 0.04959762772364963, 0.0625282189538402, 0.06146093207080999, 0.017188400661032048, 0.06996447355636666, 0.03926332379060407, 0.022185415990890998, 0.057482855815079906, 0.03120041118123599, 0.029178484898781585, 0.029854067195687565, 0.04883342437566288, 0.013721654578412493, 0.08726862244187825, 0.0557345244282436, 0.055237666613632636, 0.03795269290886579, 0.11987564574566581, 0.05473097606051353, 0.03640711435206956, 0.04088975526692887, 0.05594918992550624, 0.04145653009594929, 0.020655249207911473, 0.015212164819991637, 0.042753620373625914, 0.052423576689175064, 0.0181618781625143, 0.08203423476868099, 0.03518372556314834, 0.015765689200751724, 0.030434053210962205, 0.0633424555041617, 0.10559410442628207, 0.043099754219574314, 0.03092987106121596, 0.010090372919465506, 0.014084057259042899, 0.024942106777621854, 0.03281264130266444, 0.030941726271844203, 0.026022957247351448, 0.05776337423031369, 0.05140613531693817, 0.060724032096444606, 0.03303852232713853, 0.010800676236319686, 0.037549106299035975, 0.03804165486907286, 0.021695341884849534, 0.062005769972118645, 0.036437171811778704, 0.020251438517363805, 0.025766001781448725, 0.03940116216038023, 0.01720733069364102, 0.02792174638729663, 0.0368914044942827, 0.0472229236977235, 0.05305086863377402, 0.005495762987618125, 0.048031403097294034, 0.05109805305818877, 0.02949790525881033, 0.05185322039910863, 0.05098840672402613, 0.03942808249003945, 0.03199573876636644, 0.010762686893764523, 0.08988615335716356, 0.02855103207571853, 0.0240799859015932, 0.05271764336934975, 0.056217627134174115, 0.04533670414539595, 0.08119688534568395, 0.09787084264380318, 0.06675803553192847, 0.02735274415763636, 0.0593909893124815, 0.03843379995575355, 0.05636862689448942, 0.04746962316153992, 0.0866069523016772, 0.02007661916826281, 0.08038117024566858, 0.09790740035954984, 0.06678633481985138, 0.04450323495773539, 0.09424884788571827, 0.0304079047148867, 0.08441481468898636, 0.051201934580721205, 0.07704325621166537, 0.012693646938479956, 0.0490812691409261, 0.042639695438406164, 0.053698235912428754, 0.02141099302999435, 0.10223447946050476, 0.02189671192618628, 0.041846533966881615, 0.02370206132200697, 0.032670524331831166, 0.046224190192597533, 0.038918737442262714, 0.00928022536343985, 0.010719378985795043, 0.029683131912362673, 0.007904388429221488, 0.051311358749385805, 0.017276362876497933, 0.043782223646919576, 0.059876784817465854, 0.061457829414716655, 0.029158080146918376, 0.0556416554196227, 0.02659455843029484, 0.03003831517191664, 0.0829164463005239, 0.021050947027341015, 0.02787124778654787, 0.09155159786103234, 0.017365311430166327, 0.008729569024346288, 0.06038355197937739, 0.034741363413031065, 0.043679357190886815, 0.01744784016702925, 0.027289574462620002, 0.07310137377991792, 0.03912063608426721, 0.02185243970504211, 0.020818399122705864, 0.0075003991444264695, 0.08168083840921041, 0.02524666886235918, 0.012061792940291907, 0.008017360542585414, 0.010299223809382849, 0.0405047003239874, 0.044666882829680565, 0.03703769281386368, 0.09243845954657563, 0.060522853577088934, 0.04387761691525098, 0.05824704767174779, 0.053139727172111316, 0.05110919580704743, 0.03214006973130088, 0.023386027070603544, 0.036033271105899926, 0.014070352903687426, 0.034264515815002304, 0.0837338161504557, 0.03541451338077745, 0.08614441905651363, 0.03347377901175811, 0.016320740969310847, 0.02035604399298468, 0.017719184679369775, 0.05259018166050796, 0.024462692785046758, 0.023205619110094926, 0.05414683784868929, 0.036659731845101046, 0.05198885243566287, 0.019810643017051682, 0.032335318730122624, 0.025471567379070387, 0.023353759447232853, 0.01616643170916265, 0.08171836905662092, 0.005941851676682071, 0.06631261669099331, 0.029150507367786863, 0.08027370343165052, 0.08066086128594414, 0.02452014746414798, 0.0519993286880274, 0.06712346713268949, 0.08036586380894147, 0.05385328061698426, 0.04431167850270868, 0.0296974903152835, 0.013146833910967314, 0.028340813718856345, 0.00950174160196536, 0.0042103617752511655, 0.01512103387334895, 0.0763709834145923, 0.024060567487932505, 0.03611773229955185, 0.02418119952292933, 0.0665768327551984, 0.02257995127189544, 0.03445639019651759, 0.023999447078113596, 0.04970502175931489, 0.045889635765624624, 0.04788910609579856, 0.027902762728532957, 0.005174233970577799, 0.008506871095197576, 0.07082259162299095, 0.015577783154684211, 0.014287926662232608, 0.03366396799983998, 0.043667942480815035, 0.05501276618170162, 0.05365726553023823, 0.008100713302771892, 0.021385445912939408, 0.026610148319553946, 0.03448410725761806, 0.013170482087579947, 0.03748364791634583, 0.04448474542568288, 0.11093619640075392, 0.023313758166266546, 0.03345263881548759, 0.0464122494562499, 0.02502577698549196, 0.02997220752971067, 0.0408752991877977, 0.03239871633629645, 0.02754088194530097, 0.05849795678870813, 0.04269860376934371, 0.033617347719207887, 0.05240227561444045, 0.001539578412531785, 0.04788906396096272, 0.024894984709399364, 0.012376639755412698, 0.09903656033378455, 0.013037925894041697, 0.02768952790046892, 0.019839823306087526, 0.06877556638491732, 0.015627312654208754, 0.0501666663424863, 0.06560713398240267, 0.05638859114579617, 0.03551151543374985, 0.07189927457441246, 0.008678307208502966, 0.032408169861282074, 0.05267047916629142, 0.05740843803411531, 0.050826007575397535, 0.041628532156708746, 0.03450971757692676, 0.03259876104552419, 0.02310120515645512, 0.08510980199301436, 0.05909319944499482, 0.015053056976607731, 0.037252599628822464, 0.0405879779117963, 0.06292952645209528, 0.00230607092699727, 0.04280696307579356, 0.03870453159775465, 0.07856020989317088, 0.04719216909800326, 0.020793545315222397, 0.018462029496027578, 0.03976241475151431, 0.042895656905227134, 0.022582061844126835, 0.05614787482866838, 0.040077184957842675, 0.044092987213403954, 0.04467801408722036, 0.1195797136413955, 0.046458253036102945, 0.02614723203042823, 0.03606285359109602, 0.03242375975054118, 0.08777832372053977, 0.057328983225048556, 0.05719085374186116, 0.06276824579183614, 0.07645474746823311, 0.051783939237676324, 0.04137501834080585, 0.012191655377166407, 0.021566198613013954, 0.07648432612298958, 0.05372485363735788, 0.03817597306483696, 0.05671269230304226, 0.06972131724920004, 0.027498207017478925, 0.0063581543884450396, 0.004416600784151665, 0.057665770798320734, 0.12281212970734605, 0.010294639730765935, 0.06518797663551185, 0.02566585876798678, 0.008511783634012025, 0.04334392559324061, 0.032251286545708295, 0.03883465929257293, 0.0511083492798911, 0.04134256302589371, 0.04507923348536415, 0.03921103445933231, 0.014568909518270483, 0.03302750598278738, 0.07356386105980604, 0.005622088013502259, 0.037542904817288926, 0.032907505970328085, 0.047385070037337086, 0.033072448530865294, 0.0410792394541204, 0.09475995876616049, 0.014511688495986165, 0.06188067930540251, 0.06909457305746694, 0.028627780679192756, 0.052521176290728395, 0.09615394001406047, 0.0193500594656554, 0.1428007196274496, 0.15428823869555228, 0.12920737807308474, 0.16248974618652176, 0.11231273382661805, 0.23412584657630614, 0.09839025791734458, 0.11390972837445237, 0.1468488507934155, 0.06535046388425174, 0.13184368580339417, 0.20547291714577906, 0.10558852730619331, 0.12978494708095828, 0.16640174352834303, 0.15127377464405953, 0.09679206827234837, 0.17683131049477285, 0.18116513116946145, 0.095963322016741, 0.09441706547213179, 0.20123994428544276, 0.2307921690085242, 0.15724029722473315, 0.14654172614457148, 0.1793059889948176, 0.15212764092270406, 0.1575475138041281, 0.08923742244200361, 0.1812269391431924, 0.1983118489865334, 0.17057414947738572, 0.14603238492723436, 0.10198588392907575, 0.10415312368422748, 0.0912851524809676, 0.0879937399839682, 0.1273069131158052, 0.17947330259748046, 0.16643281605455185, 0.15398895878705288, 0.1824573223148623, 0.21313672284445456, 0.1787180624782078, 0.11949742047656929, 0.060367866329127745, 0.1674548692760929, 0.1702245069487441, 0.2036287902944511, 0.15408939291392604, 0.11590724901085901, 0.13971749152387344, 0.09324834471748722, 0.15010287053883076, 0.1055157029881112, 0.13545830313476825, 0.14181568377440976, 0.19499075058246815, 0.18008819540902493, 0.1680690113214716, 0.09953293934344284, 0.11790557403958614, 0.07274666741009682, 0.17213776557435914, 0.10784865522216405, 0.07576857783621357, 0.18407814985802098, 0.22201650926182348, 0.12891862421266495, 0.1545205318759526, 0.24250851853960947, 0.13992203699965633, 0.13965202164986443, 0.1438859751027438, 0.11071111210772108, 0.12475367996000475, 0.19161429466499438, 0.12247595500441329, 0.11615296405169273, 0.21051478692360465, 0.1363629303992756, 0.18140199023389048, 0.15512244715805978, 0.12227184619874724, 0.1209213481014294, 0.12847892038764494, 0.17946211771378595, 0.08263071848740501, 0.1228615347175829, 0.12401699449025816, 0.07424243109961672, 0.18389906914484117, 0.21889508401434268, 0.09147103605491501, 0.157468315634516, 0.08487319573760034, 0.1633711763086819, 0.08194480932527974, 0.10943352259815702, 0.2003584222327317, 0.19480270664057425, 0.19502376897200463, 0.13112932413576112, 0.1532673958929316, 0.16965328114888362, 0.14469381481889756, 0.2038816759182561, 0.1324295898478839, 0.15565984251518405, 0.18277230702580946, 0.17621336865328974, 0.28843109225553853, 0.14150348762350698, 0.13029690831899643, 0.19811629738298156, 0.10700256473595098, 0.1805014385571403, 0.16840192248984692, 0.20127700761921946, 0.11082584143526132, 0.19805346285143208, 0.16603673327594035, 0.1564448068459188, 0.13682003974193527, 0.308877366084245, 0.09386172067494163, 0.08926794338490694, 0.0717268588261739, 0.18192003421004743, 0.16476565551373268, 0.13795556590682076, 0.14011771117727603, 0.14863536783283757, 0.23358904876776282, 0.13173362961219204, 0.135680039623572, 0.0830272839014088, 0.1544952969397268, 0.17410728569713332, 0.1739507892559613, 0.16261262668957635, 0.12195771950627528, 0.14300144998536957, 0.12921591229256124, 0.27941819040044663, 0.08111570300834794, 0.09330910315076191, 0.20712849443718312, 0.068507588829004, 0.12743982937066786, 0.18647828800303323, 0.11857848268963637, 0.1004335752898647, 0.12319732637655352, 0.14141964696107373, 0.14633998455059144, 0.1059794006869197, 0.11575351814709364, 0.1320527665196888, 0.13588933484448543, 0.18145558574507314, 0.18024106059343586, 0.13626905398503428, 0.08962033616919672, 0.10106237259723487, 0.15139306985562848, 0.10952495519191989, 0.1277000924211837, 0.27294542159765, 0.13383534586718007, 0.11186837984789764, 0.19244563795866507, 0.09031524686443229, 0.1825397227319979, 0.17313058488070968, 0.10176987777794562], [0.03806489797669553, 0.03146926016216317, 0.027016194071620706, 0.059393942581429604, 0.057987160004314885, 0.02483669116402105, 0.036870643511534705, 0.07305454282510666, 0.020956888667217666, 0.051639577629224914, 0.07392087335427923, 0.010652758064679803, 0.05030458515149452, 0.10917394902677306, 0.033047573655963905, 0.020950465019972577, 0.06149065628227207, 0.02277652560282619, 0.03186622011144796, 0.02627591756472905, 0.056104452965120157, 0.06257898377014265, 0.05379661309322523, 0.06093469095386325, 0.04202379522124126, 0.020899640831855998, 0.015186775708571078, 0.017796216735375986, 0.162751411177939, 0.08377454904538971, 0.03867692944984283, 0.011717586763082974, 0.0413967905596139, 0.012520203674812953, 0.023874747116238843, 0.01719736580496594, 0.030093827818129814, 0.023876748520941026, 0.08709095133047912, 0.050656820887759815, 0.011242931134127563, 0.009938479709108512, 0.02896798883504685, 0.052235938773881045, 0.02831444114206299, 0.038283872718532244, 0.034081585510002996, 0.03297885173871633, 0.013895764338573622, 0.06501494801693386, 0.05212113283754838, 0.023578723081417625, 0.02535286780086256, 0.03949009730750996, 0.019557366688405315, 0.030513096247769655, 0.04141773157302411, 0.054934234508583625, 0.01864047435623023, 0.014583269836411122, 0.035790436555661505, 0.006227122231071154, 0.06943742804709943, 0.09588839861774638, 0.038369896731549696, 0.027393095923828024, 0.049188732124504544, 0.06195954422676756, 0.05744567756811458, 0.035281604786794034, 0.027029717438704064, 0.04627916849248352, 0.02440212012809371, 0.02783398526991087, 0.03545296716413671, 0.1288112493291978, 0.062081413493762096, 0.028838701921725468, 0.02248901855050316, 0.008022558449151656, 0.01486726341799142, 0.02715761007200326, 0.059271318717829646, 0.023943725672941056, 0.0694531175277887, 0.015445957617503742, 0.0545670677186741, 0.05423780695925798, 0.032713532507900274, 0.10282648156487173, 0.0985722574255159, 0.06637945020150754, 0.06555758341546021, 0.048832780861806487, 0.055627655162806475, 0.034020681520022696, 0.0243458490548355, 0.02571032634155164, 0.054569132325630036, 0.03980168441851293, 0.028051801303762103, 0.08924143674272685, 0.05008046229880664, 0.015152851420064128, 0.016762224033535007, 0.040647771074286396, 0.05750287752298098, 0.06902023188529477, 0.0694017360107072, 0.0577727894509031, 0.006970711110625417, 0.009677169990966157, 0.029365575061209744, 0.0636987706586238, 0.05045064747513783, 0.06225048143777156, 0.03390802062987801, 0.019975711982096397, 0.05209324723710457, 0.057927841816337845, 0.031057953301276413, 0.013595810272700846, 0.10449809307653098, 0.035663779239140214, 0.0231102220113239, 0.07566162430110478, 0.005301025352485839, 0.05123831609624529, 0.052808616310358054, 0.06092408063611197, 0.01618803347340755, 0.05053002184497253, 0.03259380828709372, 0.02866477889549588, 0.05738122276060524, 0.015448962597386732, 0.017165559749569625, 0.07166400897286593, 0.017355367608909166, 0.03810650421186321, 0.05686284936664086, 0.030654037273639155, 0.06923513486981392, 0.027970731964394934, 0.06318426600867702, 0.08143140784194393, 0.034619563093949715, 0.04306673199959821, 0.014975635173370042, 0.05848334366155248, 0.056718874632591204, 0.025092784781008962, 0.011686472102038322, 0.07473120285618691, 0.07788402238680471, 0.03625691898407475, 0.07663409631218641, 0.021664449389302926, 0.07369481612958255, 0.07675499264751712, 0.07714344519040278, 0.05717475823457203, 0.05570462784699856, 0.018670154517636667, 0.023514369780558254, 0.12315699184734015, 0.06295129484046372, 0.019747957872647433, 0.012305314096832469, 0.05493982311999125, 0.04063202796744243, 0.02823968436719189, 0.03053920069378951, 0.08130477350806037, 0.035198602990637866, 0.01984668745388908, 0.02314733705603548, 0.08121202324306773, 0.03293889259258586, 0.0020754071198508988, 0.06816155457448575, 0.040021666565970074, 0.03912534752500154, 0.024235850320227688, 0.03572429635471875, 0.011378028824354612, 0.06634817849243842, 0.016405569885166425, 0.04318754406525724, 0.029141569036930322, 0.031532215352560726, 0.011630724841398338, 0.055284413298772234, 0.023002837551757697, 0.0210402773377756, 0.049827519218407335, 0.04263408767480043, 0.014050374288232097, 0.029798780545412056, 0.03847919066526717, 0.050262676311596755, 0.015465825150210052, 0.029023691088021285, 0.01546569778809264, 0.022505663725877964, 0.03661916748951039, 0.0189326775275291, 0.004523979498058437, 0.014773827504306553, 0.05730099037229534, 0.0519524555983803, 0.025960092072284995, 0.03063757787458599, 0.03144997389866941, 0.03979341832980995, 0.06129349206363963, 0.03923595529950915, 0.04016539615188395, 0.04091733060176334, 0.0762724951510468, 0.034099427697759484, 0.0522356974561849, 0.028589181339127884, 0.11777428189112295, 0.022542273152559515, 0.017654980765655637, 0.08196471995043178, 0.046367774221805796, 0.037997390308807936, 0.01656742702658859, 0.016043532053909956, 0.03679154110291312, 0.023046221110909697, 0.03796773504525904, 0.007281412911270896, 0.02779001182305717, 0.06987661093233094, 0.034669412435182644, 0.06844728238760464, 0.025370526127517227, 0.0513033761132148, 0.07041107217270522, 0.04977888412653439, 0.06614698848176388, 0.07299106477970078, 0.049645194122868205, 0.06316645063399788, 0.0364095198681518, 0.02941689146081767, 0.008820196268178763, 0.05505585096656315, 0.09714383286454024, 0.05073616461407754, 0.018846795240777637, 0.014803392752524347, 0.012387862943503405, 0.03847453285068755, 0.07261470110426027, 0.021814928209829717, 0.009734120009647263, 0.07461944594979286, 0.05237566171995094, 0.05701430494927111, 0.04585195573106889, 0.05256640612177792, 0.04166484472431964, 0.10148585068001863, 0.0600430948449479, 0.0695872058971755, 0.05807797972773833, 0.037265209436056115, 0.03913512663735498, 0.0417129818590418, 0.026809511210529074, 0.03471519384953765, 0.061211516825302, 0.0563052139665571, 0.047622407906718796, 0.020566976726836255, 0.009751348369454425, 0.0518988179523618, 0.04454437004882963, 0.03772665866680684, 0.026743438042279695, 0.014764041688683775, 0.05178537565253435, 0.06368102806229746, 0.03193105987813925, 0.04904534344771697, 0.06436463129977066, 0.03212509845804063, 0.05300663471702607, 0.02236585842535621, 0.02357849325504034, 0.035937268797668724, 0.06269814874676448, 0.003997920566396187, 0.06029858899813506, 0.011632402573952512, 0.02830723608513513, 0.013986278584437266, 0.028664813369452476, 0.023119200561796466, 0.18060424755657875, 0.027405744035457893, 0.053257589799261866, 0.024049317486764445, 0.06447332385446757, 0.024011660434846437, 0.0297656070230709, 0.030089639232403813, 0.014029439978091227, 0.01696503623538921, 0.01841745658537313, 0.07820548820159129, 0.08275507754015346, 0.027166002565213752, 0.031888840772632154, 0.012460446901499264, 0.054357385623358914, 0.07356468077388502, 0.027529013328134056, 0.01934236028201638, 0.0696725557528196, 0.03568578511476517, 0.055565628854017106, 0.07026591383281254, 0.033998721609673196, 0.02636708202771843, 0.066964557514556, 0.03673758553040605, 0.0634104458074416, 0.07800809032614194, 0.043428551495796254, 0.06914971606625665, 0.04577844576429456, 0.06339543814500494, 0.013305021491232178, 0.0832827665632771, 0.019613884825019107, 0.0410686444581276, 0.05042707878014734, 0.0371656792929336, 0.049783748784853574, 0.014741622125579706, 0.07018289288445827, 0.006502562919781814, 0.05565638729040662, 0.07798479359236457, 0.026536330002390092, 0.06755108209026438, 0.015844725534289835, 0.07486508438183416, 0.1155774558203355, 0.08036759516765034, 0.160381349644834, 0.14188263985899188, 0.1243285394664253, 0.10635361931617222, 0.21408112539399057, 0.10279074356320406, 0.17418922646151436, 0.20370637967942223, 0.0630369856052341, 0.15222473490622737, 0.257385716202759, 0.1008503117989148, 0.11873094950832667, 0.18979143441444446, 0.22569894069625487, 0.1373371644125831, 0.11693838803518204, 0.16689680486677155, 0.13702899788416203, 0.17693393563310947, 0.13566059631205377, 0.20014471434537442, 0.06227414206331296, 0.13272327731453604, 0.19105258367715344, 0.27534260264327454, 0.13313190861334726, 0.10413413236458456, 0.10900005472884064, 0.08359211286710155, 0.25260764114078016, 0.1416305203231112, 0.14507371782054826, 0.2845477925673608, 0.10355832535893687, 0.20652403574316733, 0.23716738417504296, 0.09247489468825441, 0.15904904613571783, 0.11399059661573942, 0.16449649818241596, 0.16506303552417986, 0.12685243911560506, 0.09702272202459075, 0.16588904684589756, 0.11690012194336423, 0.14441213961089813, 0.1489562514208017, 0.15119590946743566, 0.07624182865143785, 0.18121580022477335, 0.10098826891231923, 0.09426258384220063, 0.09560490012048714, 0.18951044868557684, 0.09696386348936828, 0.1559206494881261, 0.14464017334243945, 0.16637275476128827, 0.2532970896291156, 0.1383589418424714, 0.20972263668814015, 0.11569334960152065, 0.17403896597604598, 0.16832597253303375, 0.16888432805576634, 0.15686195704244799, 0.12201536762257739, 0.162703515360913, 0.085141058380325, 0.11942852618953875, 0.14249342643926222, 0.2330025165311752, 0.16439813249293836, 0.22268847562372687, 0.10114427505721969, 0.06792663371250515, 0.11116691144003023, 0.19478494872248944, 0.23729591840697875, 0.1335451977267381, 0.29750187971418907, 0.14385949910408066, 0.19585860562661003, 0.14648721132787967, 0.08766076752855893, 0.1924024765650111, 0.2035302407438717, 0.2752774545261937, 0.16368364825123743, 0.15269397908160764, 0.2295539257747512, 0.10063435161306013, 0.12885100929246796, 0.11260226143584137, 0.15527071581492502, 0.21801192253347368, 0.1418925990020075, 0.1558252255762777, 0.1481697395924599, 0.13497707734425224, 0.15754360675571427, 0.13662894677010276, 0.12569045993469416, 0.18985564790425763, 0.16356107418335256, 0.23533081095064842, 0.17858012068656184, 0.13344695461132836, 0.08298721750296893, 0.1216200892362864, 0.20483432157385736, 0.15645813677580128, 0.1231512921531835, 0.15597268217994323, 0.15375039900743193, 0.16017423011362553, 0.08527939087681233, 0.13199362453193436, 0.13905416663375594, 0.08855462359685091, 0.13743010619955678, 0.13321826204417214, 0.07881077427056529, 0.29402610815821156, 0.15497797829729898, 0.1398636151345507, 0.10812579518965176, 0.10399229118540403, 0.1044633050238894, 0.1305012699336775, 0.17071900138210866, 0.0828747634565638, 0.1833764592846555, 0.11851020127294526, 0.13768677629770773, 0.19271493318580812, 0.13957898282716352, 0.13572128579741524, 0.177059528087416, 0.13047362948136945, 0.20362741133618742, 0.12933654049711843, 0.1002246937564304, 0.24806185925920166, 0.05704358099929749, 0.19261154195954724, 0.151925960615758, 0.1421308063811833, 0.14804523498300584, 0.2665278724124355, 0.12986515648663044, 0.16401357167670805, 0.23539749124357778, 0.12795818744287377, 0.14211084212987654, 0.1797334660565661, 0.12444506143970836, 0.10497373408607899, 0.120806266373444, 0.12152311016595173, 0.07638419843128613, 0.2531534174997961, 0.11265917410773617, 0.11497649048725445, 0.18283627536748687, 0.14674294679876299, 0.13185882370077795, 0.1789984966237699, 0.14673899378507368, 0.1967994228846604, 0.09575686898202666, 0.12554308760070032], [0.06965172582215841, 0.03691409984903951, 0.05179836467329053, 0.06122473184199584, 0.008511404420489506, 0.09474506601691247, 0.04927302477881313, 0.009490582573738311, 0.0906620242242371, 0.02006788002026658, 0.042674579252038276, 0.051591612864285714, 0.022404055569260832, 0.06269483924693157, 0.018165773719609268, 0.029053907510974718, 0.054587989579886205, 0.08330711283751073, 0.035535076467861096, 0.0581956661546663, 0.018951419868596622, 0.014639585917334885, 0.07133453753927062, 0.021682456285963138, 0.03665901555289184, 0.012021677703746866, 0.024604694842691385, 0.042896886476345604, 0.02897456761509661, 0.043717159799510436, 0.008589287791701575, 0.034259088082058776, 0.035372179362081715, 0.035824523637852365, 0.048476894716581995, 0.07299994373874319, 0.04618353773689559, 0.1624717277985427, 0.07571287558323915, 0.013077192688210598, 0.05111309519458202, 0.023658476664774844, 0.038289089777296594, 0.040202302437636166, 0.010289105703122914, 0.040770099994035504, 0.06811928184282395, 0.02968309360796646, 0.01651403261348605, 0.007482806414050321, 0.09770350605850259, 0.02506399711203431, 0.04029829708498813, 0.03281095590923102, 0.09727667251061048, 0.02782669594331134, 0.06428797654206715, 0.06765847229549, 0.04534803075535644, 0.012340035116780671, 0.060013382124804684, 0.05268681216083708, 0.028876571563042464, 0.04340608213697711, 0.04027775826773817, 0.02268647771298645, 0.06628348236723293, 0.041955954305106596, 0.07836938505211184, 0.06356092462796839, 0.012926839314581407, 0.07680791400132642, 0.03582600984842547, 0.028989954491055785, 0.05428723495213255, 0.04863430280238391, 0.037309776601051135, 0.018783539360869798, 0.008457147200862247, 0.036406773442943255, 0.04184923059637508, 0.041927758439053456, 0.06865111540161795, 0.053516960357345884, 0.005356726169045414, 0.03268137979771822, 0.04413428318296229, 0.0733510188518032, 0.05462863820514852, 0.06901270890187833, 0.06419404650167113, 0.04008848475472581, 0.10857112976091524, 0.018900884878671458, 0.026111304421999285, 0.023101827602893598, 0.03392464856827452, 0.07291674659016632, 0.04159123899655477, 0.06525316305698887, 0.03285181903911214, 0.018035500468085372, 0.05951219591342154, 0.010838063242244384, 0.06454342089953923, 0.05886197112680924, 0.03591989392354604, 0.05308787068051677, 0.022550893556927482, 0.042211119040486314, 0.030431069298497135, 0.02006028808893696, 0.06915074262407518, 0.04881591926659307, 0.07710014590092244, 0.07167652684954867, 0.032781967142176245, 0.023375859168628534, 0.06591749918316642, 0.024499099198428374, 0.024899902993873246, 0.03171959854361992, 0.12906658643436048, 0.0059863628214976245, 0.03314635686336025, 0.04495862060256543, 0.034615847567516955, 0.026034846931936282, 0.02005135741895966, 0.047177395092383514, 0.05792032266336103, 0.08093875201959765, 0.10177573835056636, 0.03420176172268487, 0.032173375403808976, 0.04684885828605583, 0.06812905712473778, 0.031141018299686334, 0.06428948573527798, 0.0467228023485551, 0.0503852810229986, 0.026485216616082097, 0.06193272731897812, 0.014146145812476115, 0.05788839977955627, 0.03003137441532266, 0.030340439181834943, 0.03125128899550727, 0.04574586021443529, 0.004649536999603433, 0.020988028226119858, 0.03666796729028706, 0.022594303929156834, 0.01378408308336211, 0.009040309608192935, 0.026804545045559926, 0.05112339141628435, 0.10955949043554646, 0.055724255019618626, 0.014110877039662052, 0.09201459075895049, 0.02883286241652264, 0.04098893684004584, 0.05903139530170349, 0.008345106841936227, 0.012064052899668535, 0.05105739294160759, 0.04409324385285859, 0.06159719229946214, 0.027962653567233396, 0.03987671123937734, 0.02042490380605863, 0.048022554781768596, 0.05749440842097806, 0.05180296120083621, 0.034255449164418444, 0.0902071825018333, 0.030626843067547007, 0.035001886933441126, 0.029382486452138232, 0.04353237173129474, 0.04119520601365836, 0.039751620572661205, 0.01009046868045604, 0.05563517431578329, 0.05810735153875524, 0.007728113034259409, 0.07766924963723268, 0.05843262098008587, 0.07549100885948828, 0.02524041566967724, 0.01575460295087748, 0.034117679742555466, 0.04929586952071517, 0.06487909764532121, 0.015070537187820001, 0.0274144429638381, 0.027946153948564204, 0.006774663465142611, 0.026423094546302196, 0.04906096015005343, 0.02095669906045641, 0.042049780923632846, 0.031239617645980853, 0.01517283578117889, 0.07203845742849574, 0.015219472341179369, 0.02543098387128163, 0.004842219603878837, 0.04725719464101619, 0.04400680615236202, 0.020068257318569288, 0.029450779360148217, 0.04746496534696029, 0.0645001752362136, 0.03259059454825136, 0.05494044748164954, 0.003177352299380507, 0.026467148432387944, 0.09710547484217152, 0.0352695005975904, 0.03258932667273668, 0.010890593891212297, 0.0671590825602893, 0.010635633126742417, 0.0026695518763811, 0.07325563324435104, 0.002771923008690318, 0.029141419649785085, 0.030481746014688286, 0.050362298385270184, 0.06427859962587396, 0.05382394327992394, 0.04575847002166895, 0.05274507314747861, 0.04541136324405671, 0.04292620466120782, 0.11957893223171273, 0.044452887659351674, 0.02660476846710569, 0.04227655444053873, 0.058510129925824945, 0.034207691243218805, 0.04999485963414754, 0.057099474774252985, 0.06686914126358687, 0.07566765341306887, 0.024037776372185158, 0.03597633162092778, 0.05941536239979248, 0.0459401018076366, 0.05574363704410292, 0.03222862183446846, 0.04566416459819002, 0.036795766077815525, 0.07309179001998517, 0.06220080446632159, 0.04764167501801445, 0.02970527376859419, 0.06829143712116827, 0.04398933168680918, 0.05897855821756586, 0.08285439317865718, 0.0709253316745162, 0.021761719573048816, 0.11588062745549026, 0.03243741143735186, 0.020103300095445687, 0.11713315056817186, 0.03535277435495969, 0.02895964996799106, 0.04162880794836148, 0.05794385305395531, 0.07849704594381395, 0.017343127439098976, 0.018126490646071972, 0.019376847645147674, 0.07266511735055717, 0.051404580158451875, 0.02233947244202418, 0.01843616445248406, 0.10595688536282509, 0.029951607425426765, 0.05175986109421619, 0.019844017637472962, 0.010862540709035052, 0.03794941788298949, 0.053741600319382646, 0.0694289397928984, 0.07138081691077641, 0.030278060472600406, 0.034193200690131036, 0.07385213994571278, 0.0168127111429649, 0.031208464680539987, 0.037542019985736384, 0.07290467304447967, 0.0677258190849135, 0.05651651250739252, 0.027848211522664756, 0.02762383203052225, 0.03185871628022963, 0.02538722301382692, 0.09295394478906548, 0.02722117238708081, 0.014258493564181752, 0.03682038048282266, 0.028340082104888656, 0.0605902846361841, 0.07680518672831597, 0.01647717995388854, 0.032828920671055396, 0.04463155085461275, 0.023815346573809945, 0.05491505932783889, 0.03581669804970584, 0.017398132552062313, 0.03051466864323424, 0.10830115271551956, 0.06405452273846154, 0.07058244604136675, 0.04331342380253538, 0.08382806794777994, 0.04097340057694143, 0.05404758349721951, 0.007826486863421217, 0.012071799963802822, 0.020880404364077315, 0.049867853747620705, 0.055393098192589904, 0.04640882121278875, 0.0356045376599556, 0.02423069454849728, 0.04751188057144323, 0.023029983877354575, 0.013426215643243445, 0.06323966182648175, 0.042081592724688595, 0.07255910610359523, 0.047747912260914044, 0.005223389523434303, 0.05249688364264946, 0.054597450765751065, 0.03883031940448188, 0.05156690652872767, 0.0343564348745971, 0.029700782578138095, 0.008826351784650356, 0.007483764502760624, 0.05115092844672261, 0.01433569128670159, 0.039073847264291785, 0.18047104018830484, 0.10761098410453528, 0.1579671308037735, 0.1126844703309959, 0.09849955568150168, 0.28078939585435775, 0.1319062598650494, 0.06418619793088687, 0.28227382910347754, 0.18446586695649933, 0.1083500367859679, 0.14471897314633095, 0.1270428349474265, 0.10932621666260305, 0.09599790322564303, 0.12693142278059838, 0.1599913496043413, 0.1080962012131368, 0.1535082386145669, 0.0965424385222216, 0.07672970408513662, 0.1383428846395785, 0.09418469568293902, 0.13803697040965482, 0.11649622506792508, 0.13634480475898714, 0.13785507049291365, 0.21366708551443395, 0.07071209876167198, 0.129498859206515, 0.09450533412276738, 0.10202029659863442, 0.06575711867621829, 0.10616158405619283, 0.22415786290601378, 0.14330446840293948, 0.09843204801361408, 0.27476420626044273, 0.20466850950352608, 0.0859604660241354, 0.33225797116756445, 0.11789102602990405, 0.11447476418388468, 0.19977829449119108, 0.09934078150939557, 0.10694926799905878, 0.15996309628169383, 0.14854758947847352, 0.11414859458924302, 0.10730552952736618, 0.17513916016586367, 0.14226225174723134, 0.16756745355744518, 0.09756075323469217, 0.2293083026644684, 0.13472842052578926, 0.24645414714130665, 0.2219083223251566, 0.11493904410951561, 0.1403753159026946, 0.14812300822907878, 0.2175390624230908, 0.17700861388396832, 0.10800653828247901, 0.19509739002152798, 0.13298901789371045, 0.1406306223643403, 0.10871860168633923, 0.20269396384396862, 0.14468013248856992, 0.18714018796961154, 0.14240505053631722, 0.10613175259242136, 0.21446357180754985, 0.2508880035771478, 0.1241499950147925, 0.11473266002271446, 0.08599774386253088, 0.13988698081624124, 0.22784125961122975, 0.13346920180464947, 0.11488436075348048, 0.15469619583699012, 0.32456522266710963, 0.15331633358953461, 0.10790532274592309, 0.16534596711637514, 0.1420694733819654, 0.08700216174005501, 0.16035317293097898, 0.2150004768684026, 0.11153339258124752, 0.21694670791827866, 0.14329188923922279, 0.08845306332072905, 0.10359737286043745, 0.11324487896936555, 0.1847545442081267, 0.13838486625782906, 0.18130855815064523, 0.11596977710723878, 0.18908162330908163, 0.09687719596249443, 0.06492622737442294, 0.15314828454246446, 0.1320622353664329, 0.15333154809571084, 0.13630625521463735, 0.12329037541583662, 0.11416528764511309, 0.11835852352481697, 0.0908921646975702, 0.14941559774020027, 0.186267200136377, 0.22263678001059642, 0.32469009499876733, 0.09493022180733182, 0.12278554645637352, 0.1733163305588307, 0.12378832490573968, 0.13070553961780765, 0.14781383046459767, 0.18183106075852148, 0.11966602876782419, 0.13879919725079692, 0.1489987233353238, 0.19545504582985757, 0.16839769368450488, 0.11084750640175997, 0.1308015151129615, 0.12053718565091973, 0.1336110659664677, 0.13858429426627775, 0.16625839315595167, 0.1972495914707261, 0.10572523569628116, 0.16728185597927342, 0.10511297822719622, 0.1439750864500961, 0.1452583909755753, 0.13820121966062054, 0.16705500202313547, 0.1996114252195243, 0.1500466243634301, 0.17204949692372354, 0.08925881927772876, 0.12664867504950494, 0.15782235550784296, 0.25977379612384305, 0.12732574355698403, 0.08097479645643504, 0.2071298887172053, 0.11735887071418187, 0.12626206877851678, 0.1145410767546104, 0.12096592675774329, 0.08736557852957519, 0.19349271161181314, 0.11847707563109937, 0.1806340943421087, 0.14822252305044284, 0.13278448773968604, 0.3077835457459573, 0.10940043526070733, 0.0775531719949457, 0.14050277761153637, 0.16105996564992014, 0.1353345339697215, 0.21373522137441944, 0.0988049413107576, 0.17027186650422313, 0.14837590917464227, 0.17393407321745352, 0.16682995603449885, 0.22045289316485006, 0.13623468728075105], [0.009011654089385224, 0.016492291038194974, 0.041314152655221766, 0.0768197423988773, 0.04546529583392605, 0.025983886763213143, 0.04682215629145504, 0.004650650699923356, 0.012327006834018375, 0.001656256835333132, 0.02795540446024989, 0.007899433755571204, 0.03230688154637333, 0.06515538725521296, 0.020183099644078363, 0.029323806032358162, 0.023375068182846712, 0.04725650133144471, 0.06329261765424764, 0.03661443306613834, 0.025707738879587383, 0.023939253634683067, 0.043898400880636713, 0.047891197515831846, 0.05527408260311331, 0.03344634923362925, 0.06238578405651835, 0.07112730309487351, 0.009767997375268851, 0.049000117447107076, 0.015947306622570802, 0.01964975880729335, 0.013933348612138822, 0.01551089410279547, 0.009421289920987142, 0.03893863274565628, 0.03172170528541169, 0.05052695749327541, 0.07048700680775989, 0.045715821906924255, 0.049274166249820305, 0.04770309994778326, 0.035504482746604955, 0.07197823525676805, 0.0019304741773897062, 0.08005765897612419, 0.0353427883988667, 0.042859401794210564, 0.08002739084223587, 0.059076916246164235, 0.047619665311949874, 0.04516685479170373, 0.04770944698623592, 0.037527445162976944, 0.030760559884290543, 0.05467311343959263, 0.0677059697467954, 0.09295196828222083, 0.13382642860374144, 0.0763541984281713, 0.027813542213651444, 0.03544343703035866, 0.010051717080416219, 0.028443051982791196, 0.005289591969020906, 0.07522126164046988, 0.04524286986599046, 0.060433002954889695, 0.06972208333712432, 0.048825165947839144, 0.011649221076720185, 0.021055978309783726, 0.018505872707934152, 0.026744522056692553, 0.01865793158480477, 0.08595335672819808, 0.03281614615491802, 0.024722929022485213, 0.03579867583128714, 0.030753649771213535, 0.061332539565140204, 0.046745509194630774, 0.039768807755242434, 0.054552033243160096, 0.04371106173963316, 0.028957671545926603, 0.054075530384697264, 0.05531975293471929, 0.04654215881600977, 0.0484409766842521, 0.05930699926290301, 0.04070225907790084, 0.04960994641747206, 0.01816884381696582, 0.021528158517133807, 0.04105529537604701, 0.019274044391368667, 0.02137373242857716, 0.03442111184760448, 0.07767162450979795, 0.06577751959764189, 0.0017224673009026917, 0.03745573167238505, 0.06680711112435787, 0.11607337517723923, 0.04976971022364113, 0.01463753758974734, 0.012492741337947309, 0.03639147849753499, 0.03372114114162903, 0.03305392069441657, 0.07814460719424872, 0.028520220019403967, 0.031208757709171024, 0.015255659461892663, 0.04285621103800593, 0.06489354606357313, 0.01801176323375154, 0.042077471171655965, 0.04011159762740135, 0.03540070081550268, 0.03387001500795445, 0.04212349773414674, 0.034781245950369105, 0.013984619046471292, 0.04299567351418157, 0.05137978955322216, 0.022522735995270556, 0.1348741304489874, 0.03576127541882377, 0.054379046759417946, 0.082573231249567, 0.03494660985926467, 0.06590655944760769, 0.039767708419071096, 0.0759234654927446, 0.04350347106435126, 0.023449388287600972, 0.013292196221769819, 0.023812008345679894, 0.018546511757097418, 0.08778277469137985, 0.05293376443366851, 0.027091912286836776, 0.05381558909110966, 0.04409534676421074, 0.052703106850986524, 0.060033503424135916, 0.04532929607516816, 0.025200469930085446, 0.055471924809558745, 0.03629055024395066, 0.05440030569931673, 0.034770934406908295, 0.05126601017470803, 0.02409169172507621, 0.01711244878899907, 0.02010500464107721, 0.025473112961457624, 0.03982850132630237, 0.05841643737268545, 0.032600136173348275, 0.07084188171692433, 0.017602065157505776, 0.036998300572797176, 0.03120735193782997, 0.037495016661142154, 0.03405972519108365, 0.028535595404044278, 0.018966778016258633, 0.08565919428703286, 0.03542861705946346, 0.029969194888948437, 0.02954903396687681, 0.019476469718821107, 0.021581422695289218, 0.023634490451865622, 0.029404536377818837, 0.00513389896255948, 0.04075577798029108, 0.03148090852905185, 0.04043137804875451, 0.10545623158254933, 0.030397514647413647, 0.023953037471660686, 0.036000130142295556, 0.016817608360020865, 0.04249455625071161, 0.031244045634183194, 0.02867722590904563, 0.00899007818060777, 0.055541933754519116, 0.07986848122410237, 0.023811717232268666, 0.022439870179720947, 0.02508524073017461, 0.04752702996014588, 0.03833468350011014, 0.0695978008931683, 0.03481273216405704, 0.019056967632364363, 0.041401310478367155, 0.06340967205863807, 0.005919823297224338, 0.030482483374315406, 0.04238745332845757, 0.07487466814176691, 0.07224063569259259, 0.02803423299243854, 0.020318731680632602, 0.0408405073047165, 0.026981779486842217, 0.06918947602952681, 0.04227510270392222, 0.025059289501739607, 0.022076259952999895, 0.05867625609220517, 0.03708190757841353, 0.02833891382080413, 0.06584373257693744, 0.10616051919397809, 0.08113850944585378, 0.03209556576855962, 0.014287562770468575, 0.017716118412452842, 0.027560095430441925, 0.016039807908988048, 0.046447332452742324, 0.03368781631692283, 0.08684293802587256, 0.026173830603159247, 0.10290166543376061, 0.017174927089663766, 0.01627852952468299, 0.09385054345212637, 0.05297203052548632, 0.03901175200758923, 0.020401369585024736, 0.050682580594213746, 0.03319004685768197, 0.034543712728566704, 0.008959766954273708, 0.02585929213842798, 0.03299881215958345, 0.004407621276069192, 0.01004622997565856, 0.04914669304965966, 0.017850055479474606, 0.05439347602547177, 0.03114635984773838, 0.010502895944932056, 0.011860688156898946, 0.023986438905159314, 0.06347063350521269, 0.06661077045024404, 0.07877355771920375, 0.08611860955434461, 0.026699271158225117, 0.019871175454388705, 0.0329385248703822, 0.03297721231055837, 0.014612557377756364, 0.025721463344750867, 0.05672024976041529, 0.058266567592058456, 0.05122663708583963, 0.05382508475093111, 0.018021000338898554, 0.03080567288693161, 0.024247920035474727, 0.033224543796912316, 0.04882117462975364, 0.004794318998803295, 0.01219860379463963, 0.05640087919610162, 0.013363032541688413, 0.022761291944451874, 0.08148061366932047, 0.03199829750003354, 0.07802302904066541, 0.04236814025188646, 0.019739523244601105, 0.009891078018793657, 0.06852267310023308, 0.0567605919505079, 0.041854512772613, 0.05514651747240175, 0.02645039791992355, 0.016010523240472523, 0.07164217546702394, 0.05108298027827855, 0.012670174004480004, 0.04610048231458472, 0.0394489583859761, 0.026341862413251114, 0.05415511542871114, 0.036059582395659345, 0.01059608575287125, 0.020932266601331292, 0.02011002443220106, 0.026180093371940237, 0.020894632532051014, 0.04209275462574536, 0.06802078591839922, 0.05717562391392647, 0.02597969626226733, 0.044229262763814586, 0.06267710048104487, 0.03506642984106176, 0.028615766505320227, 0.017853652262279106, 0.04556518603837298, 0.0572449816841512, 0.05758255066710615, 0.05584199124226167, 0.047537069542393576, 0.028126671076602036, 0.01806392999095542, 0.07438811037929789, 0.028613403124073823, 0.04478730802093783, 0.02804577985267726, 0.02871929179696787, 0.021308904153204734, 0.028142408437786565, 0.010522106557243295, 0.02101914671760413, 0.0945028136934965, 0.022113275406281316, 0.05346356019858391, 0.024276981580882304, 0.04030390484859386, 0.021564084210342938, 0.03456360037108103, 0.061983070786922216, 0.06221587724623181, 0.04380534418047436, 0.03407471753176182, 0.060076971252959584, 0.04193211747934261, 0.02067233296862293, 0.039444622328324665, 0.016541259378314983, 0.01657463399873626, 0.009240882918088427, 0.01160732468575119, 0.021637647803271973, 0.02677335952138228, 0.039629452531376196, 0.03353918759873317, 0.03433111183826001, 0.07334838350934368, 0.09521504563670005, 0.08102129799343886, 0.16823280091968276, 0.1663661051181055, 0.12255414193796536, 0.10800144379778255, 0.21525708567951957, 0.10685369086962555, 0.10830186517728914, 0.09211913877797705, 0.07881858070651371, 0.15469290165891572, 0.11094363511449869, 0.23020484004049535, 0.18696083146477901, 0.10425405576825143, 0.12547503601038648, 0.15264818234549415, 0.13139570822879193, 0.1683843637546224, 0.1297814077547481, 0.10519413758189448, 0.15450968407094479, 0.18999290021677173, 0.1480870020966376, 0.09566203495787998, 0.26239826013484313, 0.20941396454168906, 0.12525483935831055, 0.18195499846291158, 0.19111626090541964, 0.11336328551894236, 0.14441575554590072, 0.16865182037074722, 0.08989814263317855, 0.1745992980056232, 0.16163332117421014, 0.1113777541585507, 0.12135393496963287, 0.12201255607989528, 0.21315919986415297, 0.12281161642843678, 0.19145960619132366, 0.3007692447112453, 0.241410760509391, 0.14268867160764434, 0.19679315628543978, 0.18367318045948783, 0.15926189600459992, 0.098968738569848, 0.10088290884009293, 0.0951249766794424, 0.12625915764440454, 0.1515711699762652, 0.12441986480787878, 0.18351208749077014, 0.23282473816746668, 0.12103791603998793, 0.16721451685072916, 0.16269033864861535, 0.21729271919015916, 0.1333899576697619, 0.19973134862319117, 0.11978367689035593, 0.07401055926757474, 0.31135933774132885, 0.21405486389994624, 0.16398873510620288, 0.15937282553603574, 0.08647441142989744, 0.16985013510190672, 0.0738847676304079, 0.2106456807063472, 0.1585903280084172, 0.21852681022738257, 0.20481303965132083, 0.10908646178582024, 0.23927749675368112, 0.15870832087051484, 0.15386966357548393, 0.18327293016256826, 0.10720747027305827, 0.08576302218341059, 0.17881688782043997, 0.13287244995515193, 0.15713445451711455, 0.1447698873497786, 0.11619881441396092, 0.18297283820086913, 0.10482960230400486, 0.16690567616493474, 0.1776933739142072, 0.1334817043595737, 0.15555507233065946, 0.12661620824327394, 0.16674006327746377, 0.11138464894986923, 0.14917510741901013, 0.2346424809506824, 0.20763369877972912, 0.16423861766534467, 0.16764135039862127, 0.2005303017194233, 0.22047071236996885, 0.13578908457871408, 0.16207748363094945, 0.12554062079758416, 0.17186529874320955, 0.13673915617888974, 0.20575849940219235, 0.16838344444911327, 0.13280000868103198, 0.11449840565722798, 0.20685336162005702, 0.12758478086682098, 0.08024719678947041, 0.12827074365510097, 0.10125444616161047, 0.09286987430025494, 0.19829379995503735, 0.1790113669008978, 0.14324411599626466, 0.11582781335399037, 0.10645114230893313, 0.06394962614942944, 0.2252354421803067, 0.18895495833168108, 0.13391095874530656, 0.2177484036092797, 0.15521022551242383, 0.14106815049965538, 0.18272251131073122, 0.16148701370243104, 0.13426646950744814, 0.13279780234781005, 0.19401599562937216, 0.16804160069554083, 0.09119083173573019, 0.11924410584352671, 0.12116073525600857, 0.11950597767868351, 0.26100223343218526, 0.17260451230310625, 0.13050090221147384, 0.1505602250296262, 0.11293275942725521, 0.23471288443092378, 0.15750825945888797, 0.20567115005706588, 0.08367350204817711, 0.13737982018820702, 0.14399912628916003, 0.18750741987699465, 0.2011458074013072, 0.11656231547315275, 0.10001978821932309, 0.10608435473254613, 0.15130964288067433, 0.10992902060670239, 0.2201711413480582, 0.10721369090700343, 0.10219335586072938, 0.1775070460092637, 0.10095418566056799, 0.0903655405366613, 0.15017829955585543, 0.1642242305341267, 0.14553142471178887, 0.07918274826219968, 0.12392542400066892, 0.18181872674294058, 0.14429960129482133, 0.07874246987123644, 0.108652304437372, 0.1305418266283889, 0.1721638738508186], [0.06096846394000515, 0.024822656433248234, 0.027930945188047427, 0.017323601773128878, 0.032559836118091504, 0.025169274829808744, 0.012523447099562376, 0.06531974375848809, 0.01675583677546632, 0.04139505537046541, 0.01449709260580881, 0.03402709367594892, 0.03750632411890453, 0.0363514618948102, 0.02588977860737472, 0.020673528065784805, 0.01653778708479818, 0.02401693878064473, 0.030843492732533527, 0.03200940385971579, 0.1066117832857755, 0.01971752119941577, 0.06103979821707453, 0.018182809599825454, 0.0517076024064614, 0.06537733058775626, 0.04554540181772844, 0.04774492834844897, 0.04959806056332685, 0.03380798103828584, 0.029935793455449805, 0.01565993555085433, 0.048382328823208816, 0.044304783711390155, 0.08425403581631762, 0.03794833003813702, 0.04149789884386044, 0.02457958631097309, 0.08328337177273729, 0.09623210396497481, 0.07987019726105275, 0.06942285705477962, 0.01584233150952646, 0.06728510402383343, 0.01713189210051731, 0.007023653053047677, 0.02544796995578274, 0.02144222834988708, 0.04194596451857398, 0.03996908229084746, 0.06581741745673841, 0.05671910445896849, 0.04207052658462236, 0.06931204243653244, 0.06328629742887232, 0.05877306279275687, 0.030331623425046285, 0.025120551637824506, 0.04771042374833938, 0.020497925391781236, 0.06638224642243117, 0.012309150282113303, 0.02562608922861757, 0.05684236800598522, 0.08400445203146628, 0.028456682602183956, 0.0048176176478004745, 0.13821513181732548, 0.012237694388585947, 0.007379292613721543, 0.05096515978596384, 0.018006417855259874, 0.030130781984377294, 0.05104289089720096, 0.050965041042335575, 0.05096188859052716, 0.05544107061840835, 0.02572353944302567, 0.032089963750613314, 0.05705232589295315, 0.04655694431294838, 0.03598580429811151, 0.08836300202435063, 0.04847889037562474, 0.09181741504899918, 0.1238047574917155, 0.04160375304279789, 0.026222594014759508, 0.021092624125641682, 0.07356474972179822, 0.014891391357166633, 0.03549571870075118, 0.030562639153832873, 0.039800730639047203, 0.024792821139037132, 0.026436600676407258, 0.10409160682390775, 0.10004451753751886, 0.019755116964299834, 0.08374256487455099, 0.04173727450712074, 0.04312338803203837, 0.03498855700355864, 0.010503975171295386, 0.03596633417351592, 0.031117451519915656, 0.07658633839098677, 0.06870537740929474, 0.005366559386358507, 0.04510690075074954, 0.02261442139804844, 0.05196334170778433, 0.04143832018598914, 0.04457442750853877, 0.01568472807130386, 0.09253783647211329, 0.09672364129895165, 0.0430725466069435, 0.004931497575354673, 0.04427518590443558, 0.007017261006929462, 0.0316949324276779, 0.008477834447647535, 0.09020761151107089, 0.09538085770703132, 0.0224342068747407, 0.045239636974949995, 0.01079502825309793, 0.012090032856400696, 0.019749156800248933, 0.057001243150162126, 0.06705415915817985, 0.02241615018236541, 0.06151760725544826, 0.050531554020821094, 0.016991079394375126, 0.0059793483289409316, 0.09553345476066875, 0.032508171148478024, 0.02572753076111117, 0.05174119919238072, 0.027835184197512366, 0.029420677850383426, 0.02031905918322023, 0.0689608370885253, 0.028482896215733022, 0.041337993311425375, 0.03802868117007517, 0.03485865530467803, 0.07756669344680925, 0.06315180303288565, 0.0460283704582722, 0.05121232656341407, 0.04058977438797874, 0.045807802253552986, 0.01442407868096545, 0.07121822240972711, 0.037876045812041535, 0.027053797497384013, 0.022501023148276636, 0.08839693205851702, 0.07551954563466773, 0.014744064988448255, 0.05380818102088186, 0.028319081719664317, 0.03298175138150973, 0.03561430528099018, 0.014705356480854173, 0.08598196245129071, 0.04937571886506292, 0.04239615225683778, 0.039982733977658134, 0.018910625686628685, 0.08589036131818449, 0.06064750374324861, 0.06334462736342704, 0.04901651172868667, 0.020874122443098216, 0.03381423231574797, 0.026820077478224714, 0.0617199425675696, 0.026566659423312353, 0.01786434684970206, 0.026044878853304733, 0.012689441115775657, 0.00840214591833853, 0.006852208800058091, 0.05646053446276535, 0.02895386791938255, 0.049710407357422576, 0.10094074081749686, 0.04019367245716914, 0.03617591284696133, 0.07071798231693045, 0.01756105455569923, 0.10973927594961659, 0.08176131594565608, 0.039154757640414664, 0.053698285708143834, 0.0317778499541624, 0.018591078922092434, 0.03364178975443206, 0.0653737606180291, 0.016732608989602136, 0.02654346036574533, 0.020585523715483087, 0.02172138887427507, 0.05526788495180588, 0.031591156242235054, 0.03732088870639282, 0.039071855435688654, 0.12178528843627823, 0.05212084555457677, 0.014649366944908135, 0.017832322459247325, 0.02768037506499358, 0.02190239438336463, 0.05261800980435745, 0.03724611086410381, 0.032156552112991774, 0.08250887986392745, 0.06734819902527718, 0.033600899811473586, 0.03952156436899978, 0.04683817135951212, 0.15764617060701694, 0.02596215476402112, 0.08763324198943954, 0.036638400126849456, 0.016060116899860723, 0.03852960691156407, 0.061439094734528375, 0.04381981558136402, 0.020733775135370034, 0.0456944978495519, 0.04099449097749688, 0.056112607971074126, 0.07618421883953196, 0.012033013889806406, 0.06108403596426211, 0.030577018624171618, 0.019608562429165168, 0.04923914837080145, 0.06932648319390512, 0.044309487491245234, 0.01833483208751967, 0.008809200033635623, 0.03198099157382404, 0.013633063213238794, 0.08461474831546507, 0.03715970763756383, 0.04730141323600565, 0.14586056672757672, 0.049214058991281256, 0.03457671196590509, 0.042046272240939646, 0.0630419077201476, 0.03487960397896748, 0.05990315356381959, 0.04271380678420106, 0.07658579446856054, 0.06546471823727892, 0.008523665657717614, 0.05961174137830254, 0.0048409134239679385, 0.06936078095027516, 0.030475678598327987, 0.06616042566395576, 0.04267146127418645, 0.08490056039825564, 0.02628348076776151, 0.04553024859858617, 0.06074494246633784, 0.019700671095521222, 0.05261550852728467, 0.011245216948971634, 0.06067574174413758, 0.03379613731897647, 0.06268297254498448, 0.03389300913700173, 0.05618457810112065, 0.0215233072653533, 0.05092670217216496, 0.04077712885074077, 0.03712353679621893, 0.0334070029578382, 0.055695522892018484, 0.031153779409285036, 0.03891178519434987, 0.025082220428533135, 0.011763105792323909, 0.049194504597014, 0.1428209596704091, 0.02299230575801865, 0.030939006659713005, 0.03451325690313693, 0.06776839825174502, 0.027907315206022996, 0.03532835147193363, 0.04256716989461453, 0.07495785762946452, 0.09477358747033343, 0.0317454214523276, 0.044458012787565115, 0.011629856289214185, 0.013839529654491815, 0.0650631885735258, 0.036716207846879, 0.033802978484140295, 0.0261824490923074, 0.08614218207977473, 0.0334422966285098, 0.04507127383183088, 0.06907188153314976, 0.03395784698847321, 0.0633989927929736, 0.010671102040026699, 0.02352356858130905, 0.04571275372478751, 0.014266626545107894, 0.039181612852600314, 0.07649738792209856, 0.036768884052552527, 0.022921333457493497, 0.039217492580533996, 0.07193365660045417, 0.03820343348648279, 0.027026658832666375, 0.018098367558371638, 0.04703306795788869, 0.05338292561411377, 0.021784715617315906, 0.04801854048104537, 0.05010795719440907, 0.02885528197962671, 0.008328794914808485, 0.12136679758588154, 0.04817879458348598, 0.04780756369713814, 0.061822843497558955, 0.040807741724195025, 0.03515650262875903, 0.028010915191243255, 0.037181682869671814, 0.05975141452865736, 0.04768232364327677, 0.04944264430612807, 0.02250729740837649, 0.051854109061100793, 0.10965353538913113, 0.02235228143211815, 0.021990061654979666, 0.14536480058825788, 0.14141722612323301, 0.157171793642544, 0.06188929396411104, 0.12566829701104473, 0.13810300718872778, 0.1234175843156634, 0.1548960681764349, 0.1505910983729747, 0.18804512166928863, 0.10620145893265164, 0.14426584746087753, 0.18596828795008122, 0.1489602810432834, 0.13288118335748875, 0.06228585937811483, 0.1071287470779592, 0.1424616031468876, 0.1332476798204645, 0.23994483594452184, 0.21740590102009236, 0.09016026727735035, 0.2432951069767437, 0.1628267789079297, 0.28979362559414684, 0.13580665863569708, 0.160616661211656, 0.15491338176352365, 0.0881943860722165, 0.17511636138923709, 0.07658842981102006, 0.1238238713854263, 0.16728050766452668, 0.1417120780435301, 0.20545537373231304, 0.1696311412078719, 0.15355498529970646, 0.14259335494810535, 0.19311725192012327, 0.18242298625409606, 0.125770753610038, 0.19812555172510687, 0.1806485887256361, 0.1723489300498078, 0.18309571870392372, 0.13591907437770598, 0.13813234835622773, 0.10549327959456753, 0.0857691279041671, 0.34709053654824534, 0.14628628178709938, 0.13531714377384033, 0.09157799725090304, 0.12091290581250384, 0.1366825576030439, 0.23033323637660474, 0.18092727619073085, 0.08219381088330861, 0.12322770176275123, 0.12544413968440027, 0.18875303287659922, 0.10040349867795745, 0.11380413081496955, 0.1996265477951496, 0.19512349829798747, 0.12532401709787308, 0.10503712020093396, 0.18845860996553976, 0.2428164858851702, 0.1270835908249982, 0.1459436566238442, 0.13453178107738495, 0.15446885158458065, 0.13739483551152293, 0.20258078201403543, 0.12250832221921414, 0.2876210002408874, 0.1301075467058728, 0.12014186896023252, 0.1532474776069003, 0.12177018884329066, 0.1400161892055504, 0.16948791340954844, 0.15411018454019101, 0.15963969992533808, 0.16964794917693063, 0.12500826629900164, 0.10105456616128645, 0.08901077532960523, 0.24301982094203275, 0.09449231062805462, 0.10797951836138965, 0.0765262617759647, 0.14428902928146625, 0.0982154060095068, 0.08232560098892258, 0.2120618555214136, 0.16206916391609177, 0.10744431401572882, 0.26690607469889427, 0.20738962316705337, 0.13903634742863719, 0.14413381986800702, 0.11612383738881159, 0.16075870923457608, 0.1961703880900337, 0.14848896843050757, 0.22407495687084816, 0.23870308402805562, 0.2553329223226155, 0.1579931011844066, 0.2467216497227069, 0.11071496552998021, 0.08396550412139586, 0.1522647400176333, 0.14487934599239982, 0.3011628913302576, 0.1368232113459418, 0.17851080505117295, 0.1256613102891753, 0.1775350388620169, 0.2091530503164376, 0.15021352427861384, 0.1496473546590536, 0.23133897192535863, 0.21439296914444816, 0.11703270111954021, 0.18045827716348634, 0.17950760801472973, 0.1336118167326335, 0.15066003096440148, 0.09915862112276017, 0.1513844130620841, 0.13647159231045555, 0.334764733429878, 0.1050468648393308, 0.11620227713137866, 0.17314785250252293, 0.10713941868274443, 0.14624295185410208, 0.18766871202857266, 0.141987394721758, 0.11313862257426786, 0.08584448031239933, 0.1442787483815224, 0.08636119895644727, 0.22065301065243062, 0.14810630751232948, 0.21914668261043488, 0.144538436866095, 0.12585029651921603, 0.15969369380224138, 0.09526363859373717, 0.23065127011749054, 0.12905256702534615, 0.10181851670025818, 0.20279444393611726, 0.07969218907096694, 0.10954433721640419, 0.13585279245049725, 0.15432988323511618, 0.14773838612581455, 0.17535383332400553, 0.12258304643534845, 0.08033147412202052, 0.1106125548962624, 0.08704943702586236, 0.1087304454056486, 0.1367375933595242, 0.1433087891388324, 0.21018768270169536, 0.1404143863868329, 0.06248768524176652, 0.1338511885654542, 0.11221156425533757, 0.17798480908236197], [0.08552479182159708, 0.0734378932224166, 0.041869275286913886, 0.06801510154600106, 0.05809780608321871, 0.060698605638237736, 0.03159007988870144, 0.03570788292094104, 0.04027567833902375, 0.04703197245215697, 0.018084541586558187, 0.04650792617711329, 0.044746931356888626, 0.00630821934112558, 0.06265381523858636, 0.006307422609684328, 0.027873639896091436, 0.013259469903254462, 0.0357086988045804, 0.06514982545688268, 0.025919826490984812, 0.029562145561700868, 0.036257677411119786, 0.07213758154501838, 0.024456711553577936, 0.03995776717220584, 0.08424730190346319, 0.07225070208791765, 0.012857032425311065, 0.012712041667151838, 0.06913100819914572, 0.02774694427517393, 0.03344939443312826, 0.055492494270325675, 0.021583766924337517, 0.033577208542415214, 0.10277516899570342, 0.020823587453173056, 0.071769077931681, 0.012332378067977488, 0.035239025619962526, 0.023782958291591178, 0.016861072358404918, 0.0210645106140404, 0.0372965615843573, 0.036254172558866204, 0.06318246570205496, 0.02512129857355068, 0.017605514468384847, 0.06014210787872153, 0.038553501193922375, 0.020077316308273904, 0.06403637794597496, 0.02875862275100043, 0.05901371399241109, 0.05125179924371262, 0.08666381900829655, 0.06620017030546743, 0.040657910247964245, 0.025104157356244904, 0.01954418040000864, 0.007163994615116427, 0.035248881341108394, 0.04793707469117738, 0.03114059695132798, 0.051131603878832636, 0.009060753622062264, 0.05469904551582952, 0.04145703954441894, 0.03432171960030833, 0.026941768629776857, 0.0543369080931429, 0.0339981853481262, 0.017034646814628955, 0.053948129962889425, 0.024947597712819135, 0.07373920326391536, 0.05742018599243415, 0.038801185080721494, 0.06139084268661757, 0.004476276639428351, 0.06499607161047959, 0.06787489979497849, 0.037593711768427206, 0.059244597571030747, 0.036123700124481996, 0.021959492831581065, 0.0857004174782384, 0.02474009896808815, 0.018047738722675753, 0.07266794421499775, 0.030625058082683437, 0.02331198658794165, 0.030111909408362645, 0.03097545520793046, 0.07670663717773653, 0.010219108249481407, 0.08345369610094255, 0.014471669978041564, 0.06693158509029497, 0.05791039033342273, 0.06660830364712785, 0.04101217994766851, 0.017454604723400647, 0.02310180653547568, 0.05033859562489295, 0.029098057158051, 0.03938335061614071, 0.028075682179581736, 0.04164835085130988, 0.10932977897145095, 0.024252520393460028, 0.1144086201525023, 0.026854894259163452, 0.04588679740986517, 0.04551555886263809, 0.0633285127039398, 0.037430542701434706, 0.004204960855384988, 0.03438189580676056, 0.012131244556287364, 0.014179853681144456, 0.046209806891819166, 0.0384438663510786, 0.037684780470426046, 0.08810129106765793, 0.03350147309022085, 0.03516404476437358, 0.04317626342057221, 0.06447844132180176, 0.04878867718000566, 0.030317073500144388, 0.08105450790495643, 0.06397825868559942, 0.061837027615477005, 0.03263269107969057, 0.023228291482214006, 0.017713622881039497, 0.018569936810602105, 0.028531199974578716, 0.07408091678254067, 0.037685213310103265, 0.05883806535313207, 0.04998807592557804, 0.02614311622305503, 0.04613889396310814, 0.04277093013027503, 0.01605284481023949, 0.013655086325842046, 0.04022056597375101, 0.026344622244998336, 0.027717652903389067, 0.06979410326288593, 0.09576872036221529, 0.037904157408423005, 0.046333736935330015, 0.021560629153804436, 0.023053634926796924, 0.02346530950988733, 0.02374027570288989, 0.055981266026895855, 0.04585555634431301, 0.05178896094401998, 0.01587445357619154, 0.07871807763172735, 0.05752871383822734, 0.08153279957872245, 0.03139462979179958, 0.02307302652738027, 0.0468732658473234, 0.039838161695027546, 0.010482875194640891, 0.041006081887791236, 0.004457056929823011, 0.03799156421014378, 0.05467696686185176, 0.11169043294484578, 0.03151772671469277, 0.02021313603636959, 0.019625655765975678, 0.050189124209986585, 0.057722174021745884, 0.017451509728186557, 0.03340774223268513, 0.029304044794351346, 0.010550628010664257, 0.07104560747862824, 0.03248084862265856, 0.04401432530533883, 0.013809106387798826, 0.016772072093801636, 0.020706580929277886, 0.04615366030784865, 0.040427781265950015, 0.03711504471157828, 0.08016895622976365, 0.0715504824033668, 0.06947841375104843, 0.018300101491472414, 0.023319168662231778, 0.036447835755684686, 0.05398846449210279, 0.039347792645135236, 0.06398698059661735, 0.028018890166535016, 0.04117464804421029, 0.05084106886398889, 0.06833545653329742, 0.09524686126819543, 0.01386751293114597, 0.03841943197673367, 0.015024573827582984, 0.02332818360188075, 0.06473256800804408, 0.033877737174231204, 0.019938171758586844, 0.0174732627947965, 0.05300502210194546, 0.021813365390464183, 0.08690431699036591, 0.04569812527587337, 0.036473449905433004, 0.04875210414250051, 0.033898942487975287, 0.02693023134563719, 0.09054960082134894, 0.01841336567585747, 0.03952173290834312, 0.055019285589937246, 0.023908380291334564, 0.07309519911124822, 0.05488960605655467, 0.05121565521544507, 0.08807644683627353, 0.027960962428140546, 0.007038311666673831, 0.02383396442558977, 0.03193058873406582, 0.008555717818859604, 0.04750474829286818, 0.04231019719173351, 0.023377360700960123, 0.03007176831635016, 0.012240953135093855, 0.05693918619785578, 0.04050039107941332, 0.053068086459872224, 0.009911077701666904, 0.009326783399428091, 0.05077218989871683, 0.020042302259694666, 0.013023784868569385, 0.09285575529981045, 0.04707345228281714, 0.03154096599187582, 0.03991236114093373, 0.08673422248853792, 0.048976372551894, 0.0749961696865578, 0.04619260438747945, 0.08184139511638111, 0.033103593835426916, 0.054116236466553905, 0.0676817537075089, 0.02312551695673216, 0.05342345932618745, 0.024968850907058488, 0.022851406866984985, 0.04115977061672076, 0.0488673429185104, 0.058421248404849926, 0.03919057225087478, 0.021770813036710027, 0.0705230895489935, 0.026118113028426326, 0.024231142709932985, 0.036285811990138986, 0.06103625889086436, 0.023081221752950264, 0.0265437763770141, 0.012761158436807174, 0.02029031939474085, 0.008903640480111203, 0.03712720252693661, 0.034129255331091346, 0.02990094794621391, 0.020575939955550338, 0.06257277845795597, 0.0303717338735418, 0.07767216843222419, 0.08049996750008676, 0.02452331332249507, 0.050664056588204644, 0.008690035057013795, 0.02588297957704673, 0.0452891952027717, 0.038762677671207536, 0.03126814484506125, 0.029569099724833525, 0.04834703132209759, 0.010856885064934051, 0.010691463699444168, 0.05236320129986252, 0.03861823562352407, 0.023648107664719708, 0.057243958956772284, 0.04405737178580415, 0.0676557143789626, 0.029859895209571528, 0.015944228864335004, 0.17267816399614658, 0.05249928149785246, 0.025990164853752624, 0.02192121141800477, 0.013061725373019376, 0.04730378810857092, 0.05901199795546071, 0.01244691395831685, 0.02040208970767356, 0.08272431144911437, 0.030658110946176514, 0.0017264429381259928, 0.012349638028911526, 0.05018356241165631, 0.03725261878102057, 0.03105591933783745, 0.05723038387875404, 0.04063708414774268, 0.05207555826693293, 0.01780203708838071, 0.03646582733058641, 0.024005591103266326, 0.043797943771125815, 0.026195621974165403, 0.03222788639006115, 0.05412677400595239, 0.09354044638213613, 0.03796878458571531, 0.007677160526415514, 0.061902765620259516, 0.03774619773931561, 0.07768864698347547, 0.08610161772418408, 0.04770589233826726, 0.021294425091435833, 0.03429741163047091, 0.03584791613262027, 0.041541378164002975, 0.04493358101876033, 0.02319376964512612, 0.05613951680941447, 0.024375774364377704, 0.25126242138926064, 0.14142287985211419, 0.14798059248395506, 0.2584751238746028, 0.24323254823684695, 0.18660440139712828, 0.09488117685841937, 0.16856584998388446, 0.11452327287125011, 0.1665626526359589, 0.08715386247082103, 0.1093072559864771, 0.15918819834628414, 0.12156380475648951, 0.06524306601814686, 0.2074212319548092, 0.13191735281819297, 0.13998470299186247, 0.12928772537458327, 0.14621977003351336, 0.09269285436359145, 0.11750209851250534, 0.15077834558342734, 0.10578155848047427, 0.13146381344526045, 0.1464877016241512, 0.23626870175282802, 0.1895087020051095, 0.074557293236496, 0.13029968155728233, 0.1187783473682019, 0.17165586562646976, 0.16743470584192585, 0.24401625618338588, 0.14791238001517712, 0.2512494745033403, 0.1457421908215169, 0.11924179225799539, 0.12281720120940479, 0.15721910723274754, 0.07758002337669173, 0.11725410819053651, 0.12007511205851071, 0.23121822114673354, 0.1594450369837784, 0.14133272662518487, 0.1455700355431726, 0.13674583646558947, 0.10528854259680356, 0.3519199241793925, 0.15973844865877784, 0.1647238117913085, 0.15391072588822535, 0.1045909659155915, 0.17169783192296184, 0.0861406575648054, 0.21062148764969843, 0.22282499249183366, 0.1595239440399793, 0.1332218166921408, 0.12057635572648819, 0.0854205042724648, 0.06782906475446879, 0.32080866456512486, 0.09844569203954551, 0.16923317385296668, 0.1108617939415478, 0.09529073512361896, 0.19070879406025334, 0.1584668039915062, 0.10200700497314816, 0.16514027250870583, 0.08643450590992167, 0.18323344599095084, 0.1323383334543436, 0.1116937118011617, 0.1455828138897496, 0.1656390110691709, 0.16262853067488442, 0.1483134730088134, 0.17065328635996388, 0.21591084979234204, 0.14720025532428296, 0.15439740622476225, 0.16979859270636113, 0.10904376770580008, 0.1379409489492255, 0.15582360146987825, 0.14583012239346582, 0.1932295297663058, 0.13591881390781174, 0.1163414370028242, 0.13913868145356256, 0.18197995760748464, 0.12263586053684836, 0.15628173737035644, 0.14921445369480119, 0.16856056397720692, 0.11589486136912339, 0.11573893949389459, 0.10418031214466018, 0.13678184259803067, 0.14340076565502152, 0.12022883526139683, 0.1313166326332477, 0.09072675099295956, 0.23383016728105085, 0.17873130047753935, 0.11682497637887156, 0.17492569742664216, 0.2512817268049525, 0.2888840340798901, 0.24865456616445897, 0.13616610708976948, 0.16574626337857018, 0.13832376308498845, 0.13701064241749628, 0.1216286464384006, 0.08078885159545368, 0.17429977294898805, 0.10655020513842184, 0.08842828803725782, 0.16046188080743437, 0.10319367516785861, 0.15583058819174767, 0.1479024208721615, 0.20321429076213993, 0.12173153204663147, 0.1532424673918755, 0.12428851137238166, 0.11934342914290967, 0.06968876617329736, 0.169014593646411, 0.17276384326959812, 0.3415436003237002, 0.11128111216690272, 0.14149944267926678, 0.16505914379752454, 0.11644482056820586, 0.11332667417704098, 0.1431716747221447, 0.14358698630765562, 0.1733162386282798, 0.20275736528058208, 0.15127159895435457, 0.12260006124814674, 0.2104512782346818, 0.10332630797018928, 0.1665380612135895, 0.1074544953242425, 0.16413438374236708, 0.12149053610741131, 0.1381055659223949, 0.21061296875198043, 0.138112384104921, 0.15374050115145024, 0.11963684847878835, 0.07358826862107362, 0.14360062267270782, 0.13038473263863595, 0.18100374708733252, 0.15617807035244283, 0.08486134435741172, 0.18413750635039422, 0.12328685141138493, 0.19754966811066677, 0.13562725616558907, 0.09698249474768678, 0.11188058362853144, 0.1330839208657703, 0.19486836037568508, 0.11985139906286232, 0.16047190123748395, 0.13804807868455687, 0.1139646415568648, 0.10072700994750185], [0.025617118339024247, 0.03906012662956792, 0.07964574882099706, 0.01446127991056851, 0.01720924782867153, 0.06386167925572203, 0.06303360332704841, 0.10902231724392022, 0.03288225188190418, 0.015956267936065072, 0.05044420467569463, 0.04777690868884806, 0.0319203135797814, 0.051770685916586276, 0.05379967361448273, 0.029011929723163767, 0.03424057556736854, 0.043351479220174016, 0.009746999862874228, 0.020350775223285444, 0.10208221182467477, 0.029374249091732408, 0.030778832996504444, 0.08161720714621967, 0.03855779128629835, 0.03637082093665677, 0.0230358770087121, 0.04149973745487871, 0.06940743570486385, 0.00673455541067186, 0.027229869400241205, 0.05474333305873218, 0.02015678260865952, 0.038809696317560254, 0.01607844459583923, 0.03529131112079467, 0.005743267801364945, 0.01973611798377768, 0.01708802782119282, 0.02587303767100938, 0.017303168292968504, 0.04069597332648212, 0.0057583195138572445, 0.046666717051618525, 0.015395007982489564, 0.03281993445970359, 0.019236845076985417, 0.038336698311351, 0.026279943356771144, 0.02749158227215371, 0.03775779631048922, 0.004773010263189433, 0.04315859360259868, 0.044306591678891456, 0.05490410044008205, 0.026672368065544197, 0.03454378550691951, 0.026543410570030252, 0.02555442553374075, 0.008145788001016745, 0.05802210510498094, 0.06623918716345104, 0.05623494455170247, 0.05054124503306324, 0.06757516023372451, 0.07380578396541458, 0.047601938037382024, 0.03500237339927304, 0.06926724927559977, 0.02190083922487834, 0.04372737558198072, 0.025657751642528082, 0.0252004258800298, 0.020743741939264922, 0.041338682790557225, 0.04419604519141778, 0.03722336571363192, 0.03145662737229178, 0.013941173242675442, 0.06643830873673001, 0.026552760673146096, 0.033243795586449486, 0.06082433981881027, 0.07289907294175318, 0.025018711739610282, 0.020857507911240383, 0.062750288690891, 0.04801235049061718, 0.03856115441228594, 0.06874925126471827, 0.00820200640573016, 0.01461397080997666, 0.021638670530650887, 0.031205775711925763, 0.017941909421595837, 0.04863479309865544, 0.03277191223817007, 0.019393837560088407, 0.016327371460295493, 0.04340134771360506, 0.0201076514748556, 0.017088650267631296, 0.02144308828358208, 0.04825438830941435, 0.02095131920800815, 0.027908033413452007, 0.023583807990015037, 0.05474242907498152, 0.03899308244487451, 0.11984028312708102, 0.028101968571483612, 0.05971078122515352, 0.007385842665474141, 0.03635973564439243, 0.03864412173448551, 0.032619437758600524, 0.002990752193821414, 0.0692187176055966, 0.03126405968120502, 0.025861649774014953, 0.04329404560849071, 0.03685099718671653, 0.07815340188361945, 0.015234603535293814, 0.09921503583750418, 0.04154027116695239, 0.09616366933069884, 0.055683047150171576, 0.05157809141242216, 0.06401097063996619, 0.06273856371520989, 0.01815753444398363, 0.01297332074177722, 0.026394584584200097, 0.031025639712630265, 0.04821843580312787, 0.0330232848383246, 0.021124441672356862, 0.039324545707072944, 0.007931812461690918, 0.04692148725171724, 0.008168050516096335, 0.02659243253630496, 0.05639546295447696, 0.03999976411221489, 0.055783389346493836, 0.019595575323628805, 0.08945208793926625, 0.05996004708351628, 0.012598449022569244, 0.020781900778773333, 0.001240704171528529, 0.01482345084960182, 0.05830776013974702, 0.021000413952635664, 0.04173122241251892, 0.05783265922218562, 0.049324502056885156, 0.017557791021141796, 0.01711684230324482, 0.03510134429821084, 0.04480714203729745, 0.04197177402074299, 0.02786829451759977, 0.060797021123430425, 0.096894157149138, 0.015353025406629089, 0.05424999541813328, 0.08915407207584189, 0.10512670652279932, 0.050563476904625856, 0.02752555444115593, 0.034761442577526454, 0.027937177313311447, 0.07709346561422271, 0.013493141084308586, 0.03506687417205784, 0.0336448387843707, 0.012198035931965757, 0.05183303781274346, 0.0290586649169845, 0.06237307848829416, 0.06971898068103098, 0.014977098401305417, 0.043626091097511595, 0.07162573522016888, 0.02156610859768285, 0.07641357024230304, 0.048476450385585915, 0.0842500061938359, 0.051687113384926514, 0.03597706706533509, 0.054355301864204876, 0.042221794475711165, 0.05319269449119607, 0.06393798161298037, 0.03696323672850286, 0.06995413136938888, 0.03675750381643734, 0.07744769700953076, 0.05376813760507972, 0.007814701558316067, 0.06846113325727564, 0.05005530397137327, 0.014010445785618598, 0.030372484639707594, 0.03437724182262056, 0.03860454946275681, 0.05759859254824058, 0.03214919766891868, 0.042849745255925005, 0.0482952207957785, 0.029353964998717272, 0.021804955660275394, 0.034488071762626214, 0.02154097708332683, 0.013056224861723042, 0.019490546584429762, 0.01033685500583341, 0.024208372661603555, 0.021506832544541648, 0.03209285764774728, 0.01626740784324225, 0.06623986132082439, 0.03142907693531485, 0.03627103032363999, 0.027298733043754776, 0.044046428219805804, 0.027962159440522234, 0.04389751221864455, 0.043734170781869086, 0.07480072533531536, 0.011743666311245293, 0.05455066194577564, 0.0569912342114314, 0.03983590173565092, 0.028421490438162323, 0.04498647938993189, 0.04603434594408159, 0.0850019981003096, 0.01920076616619143, 0.11084418924104784, 0.022751595186550292, 0.01948308297282746, 0.05068161532342915, 0.08732144420425739, 0.009209326798877409, 0.031012271478351568, 0.046028964176413514, 0.022282105863034245, 0.008600167197836264, 0.031356231549814824, 0.0654825757467939, 0.00722999117457338, 0.021261525445527608, 0.03376440595715277, 0.05490447199272533, 0.028820018952472076, 0.08408168901599224, 0.050900245325699936, 0.0257976220605234, 0.01724415462494137, 0.007943501527000579, 0.024471408950405258, 0.038751186352343335, 0.03472960013295374, 0.03689161133802226, 0.044114836041004434, 0.056536832989584056, 0.03134983854608671, 0.05177416395576251, 0.057808259321797284, 0.05944923114692492, 0.019602234542910612, 0.026652152920442245, 0.0763184221221074, 0.007005698346127306, 0.06461144950721534, 0.04653540575095723, 0.08072882094570706, 0.04512010427612451, 0.0630720647712869, 0.0346562510446435, 0.018651689883441697, 0.05328122744216554, 0.043142034612115354, 0.039251755862947435, 0.014816490940809732, 0.01146333558755296, 0.04202261161539824, 0.045723881151887684, 0.04233073983942309, 0.030074102969299403, 0.03969373496910257, 0.022494227948388266, 0.03973224237861653, 0.008520364776373872, 0.06879338559003607, 0.036469033408549525, 0.05725476079650464, 0.11665036961916955, 0.022178042394619797, 0.06285159232755823, 0.03899988530564212, 0.04564235407498576, 0.08093848388882414, 0.027296565014929063, 0.03198762014958888, 0.06107161001813027, 0.037577263860692905, 0.04404950406282179, 0.06764642939332031, 0.028289483912709742, 0.031006403244851582, 0.019425689580760176, 0.07278483391048447, 0.03237384912227431, 0.06780104891907784, 0.05427123903627357, 0.06493345924442814, 0.014925421940373077, 0.01749241499290351, 0.023849454723418723, 0.13122660198038624, 0.0692185031009778, 0.012270821945651645, 0.054904675006025264, 0.005841919816204257, 0.01596520147887209, 0.10457008235877562, 0.0453121395361039, 0.01938978112452934, 0.051047587016176794, 0.03481530621948262, 0.030634180274641806, 0.11678206013335336, 0.023953600546285033, 0.052847602524824684, 0.03000690173658152, 0.04772250112446566, 0.07145860547860784, 0.017105873839388934, 0.014494665064698747, 0.04736789434607472, 0.006840941083106783, 0.013917627530322682, 0.06335628722163458, 0.02996068365210968, 0.12657474756481188, 0.042764000864999915, 0.05130094378405521, 0.030778390580728173, 0.08246078486404113, 0.1451041161893837, 0.22302774532187372, 0.12092622042062784, 0.1128454024212495, 0.24444446868954167, 0.16180268789251007, 0.21708169261053686, 0.11384079578302561, 0.19495445333661574, 0.12416362371896544, 0.13373488109678994, 0.22152046733085187, 0.11427819368339355, 0.1597723250667895, 0.1765667803345188, 0.16227297394746737, 0.1182624407773537, 0.13734055052120842, 0.11333217468833733, 0.1478897191343769, 0.18885990214203635, 0.11990256607532503, 0.15430604257891256, 0.14265821195177494, 0.15194367256856736, 0.20050970927601863, 0.14515006614308204, 0.13378509049934725, 0.24148545408200836, 0.1349872356701282, 0.09010624275693009, 0.12700865976512432, 0.07986582289900511, 0.1350556932870419, 0.13389134689444496, 0.07777512298836824, 0.09447643728626352, 0.18513104577939357, 0.18321052464025636, 0.14130838035095122, 0.07656173930773813, 0.18264220997450814, 0.16556293853828985, 0.10298975788417364, 0.07983636681831653, 0.13797053526486122, 0.14369393218188517, 0.12654180578406782, 0.1273798446861967, 0.09836424157143601, 0.10562611924063776, 0.11429610481906323, 0.15867416867085044, 0.1526835909293544, 0.17057646306291704, 0.12591994157241237, 0.11023913299845112, 0.12392823554335103, 0.1341348249585398, 0.19323208849997292, 0.16900644247089663, 0.13590473321176347, 0.13206730686849164, 0.17615149939252486, 0.27152252053060844, 0.15152780939975094, 0.22239727028194936, 0.14396630708248387, 0.18642417155206206, 0.11180803510210208, 0.17524468111655406, 0.12289901939971794, 0.14935503082890667, 0.09096010137469539, 0.13020594303886737, 0.12164740027078699, 0.1380487988072057, 0.11803936363468248, 0.21278370952894612, 0.16987216779060904, 0.12758552397210754, 0.22185799034853138, 0.1906977470723852, 0.1475373033674494, 0.11576068873006491, 0.12333593466469359, 0.15850935251482073, 0.10443253127197105, 0.10860332843637276, 0.1132247155351985, 0.1354913521678217, 0.13932064265733765, 0.10945226876966416, 0.15818108383926655, 0.14417232344708136, 0.12211139674388594, 0.2331526391208172, 0.2214896859180543, 0.1299305037865716, 0.22724164259289542, 0.14050996351626613, 0.13472950837064174, 0.1968890704935597, 0.1512765785258624, 0.20106164498194573, 0.15207721701552793, 0.15874858645181503, 0.11016552727068625, 0.24331405999199038, 0.15843799908555325, 0.20570545547431518, 0.14769939225046866, 0.1326021588137073, 0.12595814637719624, 0.126260781750804, 0.1322506776740474, 0.09331807404035523, 0.1517267471119281, 0.10428516659885646, 0.10879546328778229, 0.21251203942923777, 0.16980893489333893, 0.19602860053700788, 0.21267909256200637, 0.20915078269618176, 0.1740297116339207, 0.158001727334434, 0.12040552578025288, 0.226133726236801, 0.07729324602311657, 0.1297771483058891, 0.11302316546319954, 0.11154680678080167, 0.259904827802412, 0.17397012531517014, 0.1088318141597894, 0.12223491309991769, 0.08497103282641019, 0.10538798080937517, 0.15724112459969136, 0.14796582230877492, 0.11741103364094613, 0.18407658703865545, 0.10992806299679703, 0.1625093733591418, 0.11621629654039299, 0.2454084524464223, 0.13169791459316207, 0.16947107479697274, 0.11419474372580168, 0.07676009479309283, 0.08704910760805493, 0.13405021820818225, 0.14223114857750555, 0.11295510621200647, 0.1027338921783432, 0.07706174957415751, 0.13189585639103768, 0.17048396560693943, 0.19086437119591623, 0.09359348264913406, 0.21708120231426534, 0.17749705622273107, 0.3021056697733941, 0.20463161470909275, 0.07689193086398226, 0.15350643064706557, 0.1699155590106403, 0.20366510286206202, 0.18594507548597553, 0.107185659749854, 0.20497266173122392, 0.10292889219858956, 0.1463161898596633, 0.10580990373367265], [0.06463260885568396, 0.06222040482586431, 0.019755143777377183, 0.024180253404342843, 0.09318178699862573, 0.03272264512375959, 0.04990167652947768, 0.029648112118124004, 0.0029818002170237203, 0.06437077532492338, 0.056899154273372506, 0.05539565309581738, 0.03905874767130421, 0.03652301579413395, 0.01863236723077153, 0.04613786357484999, 0.024338866163405682, 0.013199444999167276, 0.045866469266794385, 0.049464753603622805, 0.036601620245604746, 0.022083503314323967, 0.06978016812354326, 0.06794786200888696, 0.03214288510442261, 0.029338241044071414, 0.027982460770515666, 0.06058672998821544, 0.07410042904197209, 0.06395566292227277, 0.03445381231065239, 0.03175751223499256, 0.008668176653314262, 0.07506884078705504, 0.005517894788945635, 0.020665443922963836, 0.022097915343399492, 0.08610104315824087, 0.03308444546775953, 0.059126049295187964, 0.03791932977976338, 0.022714596970247167, 0.06191689611202287, 0.04904527833024341, 0.019167510289398414, 0.044768730388774026, 0.029726023260023327, 0.013677161149380189, 0.06198273370823553, 0.023197467934580582, 0.04919129851905089, 0.06096421598246502, 0.06924179217387592, 0.007409265803759017, 0.010469381513464595, 0.07159490784209582, 0.028721061460072958, 0.05085944731329238, 0.038535467484184814, 0.015472516928228642, 0.043145550955687804, 0.023489152081310753, 0.06021787397443287, 0.07851278905065791, 0.0427486063281615, 0.02595300192854578, 0.020663003932925004, 0.02564531803551701, 0.04427125970382364, 0.06177213230741121, 0.03908243894036259, 0.02920321038653774, 0.1044213004230011, 0.024396238488055045, 0.01883893900911414, 0.006516044630834292, 0.010813710264741414, 0.09852854444855645, 0.025636186267459588, 0.032555526873517426, 0.04266566198859965, 0.07203101871475097, 0.10316078701326925, 0.05807306527370407, 0.027716574634635643, 0.04193097217789581, 0.07006414159531556, 0.0338360543302711, 0.008554618482688263, 0.02973913868528701, 0.06026827872941091, 0.03470457970134674, 0.11962973918285101, 0.046550256365369407, 0.04153518434313517, 0.028593134352817174, 0.11415656956453478, 0.026033579056421598, 0.08544376270184595, 0.09774589370335303, 0.005381801663221972, 0.038347446524928656, 0.01996025998866366, 0.025437934203974666, 0.049630519708678614, 0.047662719453294436, 0.012226384057993851, 0.02903211230952894, 0.07023521668968663, 0.05712043877030092, 0.07831878494471312, 0.025251435844468016, 0.011532717298025326, 0.031131790770638375, 0.01267192930343651, 0.016460096193177086, 0.06703488438600494, 0.0573117922120277, 0.026643126489474412, 0.008710510672010001, 0.029816756798555295, 0.02576225561149899, 0.06859140650879952, 0.05264492247313742, 0.0652254076914922, 0.036543102619508584, 0.047025123626113906, 0.04418754161545827, 0.016619059437465285, 0.02027208075648354, 0.012829512631851099, 0.0054514357039043984, 0.016123479074468056, 0.034976594540621006, 0.04299468909119887, 0.01752817023154949, 0.026641778174727678, 0.017022760960483746, 0.051137904952009844, 0.03849059388402008, 0.03208276826978451, 0.026993243992629073, 0.008354069113040404, 0.051345491796852126, 0.027041001913828716, 0.010017026703984988, 0.038223742477355466, 0.05621072468197635, 0.018639013043514664, 0.057388182669397325, 0.03136462212780551, 0.040532222032667174, 0.058005454183946696, 0.019148386819588564, 0.06868044890823864, 0.027954873944362326, 0.013756298031958361, 0.033826945544851404, 0.018576113394491615, 0.04310387960304657, 0.04655058961361647, 0.017336546743829406, 0.03791349218978036, 0.030336482337706035, 0.0153461191239917, 0.0355342184493859, 0.033263587467973275, 0.06228727664077475, 0.03451762360430533, 0.04777427717682816, 0.031730680005444635, 0.023177109147992828, 0.03138831531208369, 0.02316670950442072, 0.0406545547828559, 0.07244216278195381, 0.04979126793783038, 0.02861312541720127, 0.010759677125832007, 0.023533184899978583, 0.009103128817983934, 0.07708620310070054, 0.05599843022683936, 0.019881400812958038, 0.06422376688269359, 0.0275938090447697, 0.07682607794601111, 0.0552208548141343, 0.012649672534016353, 0.037533236787684505, 0.022458798297110106, 0.10419818497593365, 0.04179661950817512, 0.04671111950770982, 0.03786393779239828, 0.026169025316654194, 0.015122426238151328, 0.030065559173723864, 0.04171138456571968, 0.026947085279971365, 0.019097348126853188, 0.00871717180651162, 0.017267434121740442, 0.06514751187135136, 0.03540289948784536, 0.02913949868431495, 0.006974239424321681, 0.03549520159140229, 0.06257185149156759, 0.040558069839232394, 0.03498900899543397, 0.07065234390357811, 0.017975013996023807, 0.1068107822849866, 0.011553821105119443, 0.019826357395598487, 0.009922594875998555, 0.06475719007393045, 0.06402342339917537, 0.0294209057615409, 0.039329291621763865, 0.021256160914837834, 0.04031632313384645, 0.01446365478313378, 0.04779809868083366, 0.028601178276022116, 0.03717002301146427, 0.03896567181894376, 0.050131039423567635, 0.043398593627517267, 0.04261333818337129, 0.029398277439477465, 0.012167088852654542, 0.04157700891336126, 0.05174293055108959, 0.06461061447137786, 0.02992957282150465, 0.020896488380047585, 0.022882404699621182, 0.037647483479832454, 0.02271588974361939, 0.04007749905389163, 0.052222700774549484, 0.03054192796679995, 0.022129070224060167, 0.053224130909168915, 0.019500961549760356, 0.051258092656010584, 0.06097242078413406, 0.05031554403925135, 0.021728729911809488, 0.13021725049662974, 0.04061407852737654, 0.0012945494991952495, 0.03522653072591751, 0.04935368617636062, 0.04775851874822571, 0.04299546284000239, 0.08521912273980918, 0.11774851069335016, 0.03434161107326227, 0.05391169099077102, 0.017973732713970448, 0.04692468183836149, 0.04695422984960099, 0.02594506525765023, 0.06676529804545064, 0.06198480214563109, 0.057013397135080836, 0.0345372699291235, 0.048560800496488817, 0.055749463142767075, 0.08153655340955143, 0.012270143000228752, 0.02036289281902775, 0.07409253067547276, 0.03861143659319609, 0.07051883776101374, 0.02681131917803038, 0.05542204865524846, 0.040653072402722416, 0.07575233677221883, 0.022968501490991444, 0.023265988753748038, 0.07446052867078012, 0.0343350303779927, 0.033693642415586984, 0.04797196233524911, 0.06572035411673208, 0.03480893236795261, 0.051185731821122675, 0.019753207490148566, 0.08054607833224921, 0.03829660126939416, 0.01209434305858468, 0.01130218516224094, 0.054169571507842317, 0.06094011868680678, 0.03228055876529506, 0.09965370544382643, 0.01984333007356092, 0.029154954508187312, 0.03706140323512016, 0.009940820107717189, 0.018621890978406996, 0.017150259058501933, 0.04758875749464478, 0.005060009303457675, 0.02724387157227724, 0.07188356211108547, 0.011417104096542443, 0.029881899169976675, 0.03473407791687116, 0.039278143761499275, 0.06720882464921282, 0.0990623238706781, 0.028154198530941244, 0.00896302665839152, 0.04113202291210333, 0.043558579599184376, 0.005136725827000074, 0.0353704403424936, 0.011094688332729764, 0.029516927221970215, 0.059596538363445195, 0.022113267745402072, 0.020386976708147316, 0.03500626895636801, 0.024441996919772318, 0.03161905907965716, 0.09273256836158615, 0.060167572641324614, 0.037974434484156876, 0.04836611457229142, 0.04809199299122538, 0.016316219135337783, 0.034204703500314106, 0.030901573688512853, 0.016187970271153797, 0.05889585519570017, 0.07053355431003917, 0.020688868976468523, 0.05550125831617944, 0.040648115813852324, 0.038150450845639554, 0.024790291133667194, 0.0954008985671305, 0.030532681285553885, 0.024369092162458167, 0.017879429205711332, 0.02255604358299846, 0.06535754253667209, 0.19764112368706735, 0.16487771885529642, 0.09400153172112281, 0.0746054188798993, 0.16714397547466142, 0.1259638613931114, 0.15504848902984975, 0.14038429445316716, 0.2412749177986576, 0.19984883586725882, 0.14159523431331883, 0.20883826478835077, 0.08643995279506331, 0.2226213663215599, 0.19659064860353548, 0.2173395271623327, 0.08873729726239558, 0.1718738789279615, 0.12141383538443236, 0.14130678688806875, 0.050234714102360516, 0.08826934777560734, 0.275377229817452, 0.17306044187036254, 0.09298494070648186, 0.08392892342301146, 0.1200314756903437, 0.20269108335337332, 0.15762565477240473, 0.15265844792367952, 0.1009231744213931, 0.10286043458167585, 0.12213460154711239, 0.26306564529095927, 0.18423643894493583, 0.0943961819153159, 0.1615571260692612, 0.14175180736328327, 0.11291877066175784, 0.1184960516289838, 0.09164155190510136, 0.13909355887482244, 0.1418917869488078, 0.1744521631588859, 0.15460333065880885, 0.15618013878983839, 0.09819600866326401, 0.10001421109923433, 0.10622411981345185, 0.11293125789492361, 0.17728535548573543, 0.31545763234457663, 0.20003723220959788, 0.10256738296800083, 0.12022240012283288, 0.12209050552619082, 0.11574322192539131, 0.17511833789608172, 0.09199122507725993, 0.15538693135303838, 0.1252029292405613, 0.22091461435681392, 0.21431485881968854, 0.248374515062859, 0.17038779092892525, 0.12030640932460947, 0.230025269031044, 0.13749623490918067, 0.13531285368146437, 0.2737743287317215, 0.1414114957855594, 0.1649354359195117, 0.19258724165058907, 0.16650680482627886, 0.07304298255832926, 0.15558124189415287, 0.16808212674673528, 0.22607312868199042, 0.2130317075117942, 0.1252837668383314, 0.18523314997794169, 0.1339960711136941, 0.276108659924038, 0.2514647145665461, 0.12873359865719272, 0.14792256898457004, 0.2142602673942043, 0.12024683066673818, 0.1709839605516003, 0.166730762970063, 0.20069355505608744, 0.2011724979045891, 0.25347722754363095, 0.10312052143196906, 0.10459479635521289, 0.1494223852792094, 0.19123042332789592, 0.11580159782522148, 0.12808473750708566, 0.18371062683722666, 0.23837538225756538, 0.17495808762408074, 0.14405020903195107, 0.1624555173780649, 0.11076689096948794, 0.13803948317804646, 0.18002038130596762, 0.14018275204204744, 0.1885268224343177, 0.14009478982658158, 0.3071477234123215, 0.18145923232359273, 0.23681383459798752, 0.13074119334980366, 0.11074013917917207, 0.13166780733773786, 0.18564171998971896, 0.1737602172239173, 0.17493239303510036, 0.08413212058404762, 0.11329629112996402, 0.220402377327123, 0.13630142886071436, 0.17056846510498755, 0.12801555976752313, 0.12273089374385535, 0.1221802220830033, 0.13599994261899304, 0.07470706342569283, 0.12989665802207687, 0.0676806811844149, 0.13079665811552157, 0.12983169376609788, 0.1197724690240237, 0.10878257768889589, 0.08794612761947417, 0.14865254352409996, 0.11737456785575037, 0.18203594331299106, 0.2100458185398771, 0.08395171453875881, 0.0821294671585483, 0.17875549353418813, 0.13842781314686423, 0.09435256852978662, 0.11120843340552623, 0.11284199332998646, 0.08312489116384138, 0.11836144231980848, 0.18566413572238338, 0.10234269704068862, 0.1657763706339944, 0.1001344409380709, 0.2380658520926391, 0.17549180575916845, 0.1448761590666348, 0.1591860992653716, 0.19756382541550746, 0.13588066272918256, 0.07040000220219936, 0.13973218509026114, 0.2292494058248497, 0.08241562398090478, 0.32159464013191963, 0.13939293071387276, 0.12427345774466954, 0.10573505694347043, 0.21769384282731244, 0.11703033390785418, 0.29553055162391356, 0.2882438603668444, 0.08324348157452, 0.14522584756055187, 0.13081734248947713, 0.08112587665598239, 0.23062015162600627], [0.11609718518992586, 0.039911752101033926, 0.030107703585658344, 0.01925903098327258, 0.03156107196944856, 0.02614544129990522, 0.035046986529543515, 0.07542862631981412, 0.042442362680430376, 0.045574428889179425, 0.045900617636019186, 0.037905854293175285, 0.023139890681411472, 0.0769516091132837, 0.03964509221635038, 0.015420670970343055, 0.03493410347390079, 0.035338471493413376, 0.02042333715625348, 0.05439081003949527, 0.05948321097680639, 0.01277406510311149, 0.011615543851568814, 0.02071324972465875, 0.06611904159428612, 0.03960465809570686, 0.0098977793729113, 0.0545147171003684, 0.06777131704673653, 0.05547047307294223, 0.04161406075581909, 0.04538477233220493, 0.04802921974670984, 0.057604889790978164, 0.032030938591267315, 0.02903788095159877, 0.007150778162007731, 0.02031938668580786, 0.004206250277122543, 0.07605526325923782, 0.0703742386653058, 0.03600797488264019, 0.04663964350437445, 0.026724077085213318, 0.047892503695742744, 0.057788601505660245, 0.06740521128860212, 0.041487495369848706, 0.017895061229806275, 0.07147826329474488, 0.0254165354530297, 0.05863300659843992, 0.04008469644994025, 0.04075267149375812, 0.09056200378484304, 0.054759279178876075, 0.06385684524091982, 0.037880389530572205, 0.024791522620005474, 0.004146793714514182, 0.017024950056727377, 0.03731844488591437, 0.06211159352753913, 0.03565351366095486, 0.047192157606684396, 0.012948476510392803, 0.07115494354718155, 0.011765848387092834, 0.020999843217132073, 0.021971355703088547, 0.005986160287002643, 0.012861644274615234, 0.02892327802856603, 0.013242217603199666, 0.13362732235222094, 0.07230440485140971, 0.11032066007535304, 0.010735985856773633, 0.03751108918579356, 0.06303680174413227, 0.03823058747295891, 0.0543876652485661, 0.03262959608447648, 0.04351111662183558, 0.026102105621248487, 0.05803869090854161, 0.020427240374227686, 0.019903130896930254, 0.04198266779102626, 0.059317414228233604, 0.04315594293838067, 0.04700842290936459, 0.049312175702183485, 0.07314305662387803, 0.032811798605947726, 0.02848138702252219, 0.05056247332944505, 0.0710361692754011, 0.04298024833382618, 0.04167419099699586, 0.038747681500089746, 0.02012401702813804, 0.021972748067890926, 0.09581545938647563, 0.04818989902794842, 0.07227464999643064, 0.0665267535875882, 0.06421761136622199, 0.05884454262653186, 0.033725967495552, 0.0115305109648034, 0.02965354176628734, 0.07289425424870945, 0.023128590884528333, 0.020706460270429813, 0.04647006994233497, 0.039020190466075175, 0.03367533291419668, 0.00639216821347814, 0.06331869528719014, 0.027678287475399917, 0.016316701770730076, 0.032447362919488264, 0.06066639164102174, 0.06398363662282787, 0.04426392824238828, 0.03920736106773538, 0.055529940648064505, 0.008423662455301852, 0.019287950802414168, 0.05535463291791178, 0.048460423826209964, 0.08621736594866361, 0.1018170687940813, 0.045916697821549834, 0.05506294111030237, 0.011533718957986322, 0.01494734833437589, 0.023291055150630496, 0.040536872186367555, 0.039846799336373806, 0.06915772168506538, 0.08684743496198809, 0.058606737443516334, 0.06181087720418169, 0.013381329594149947, 0.025243096977412224, 0.038853183298582034, 0.01192049089548809, 0.07688416273243005, 0.02305400456422039, 0.03283191607483933, 0.006201697688084097, 0.011427335200771209, 0.09076807377559525, 0.025439027794486573, 0.026428307774626923, 0.05729673475387597, 0.03254726844569368, 0.00872725352359515, 0.046705664961688945, 0.04440748545851919, 0.02911242130663126, 0.04662130335946718, 0.03431721883375318, 0.03531396434071564, 0.05384637050390725, 0.03869397873659769, 0.07407653475961379, 0.08898504243622865, 0.022936973142467683, 0.036922067163452026, 0.030894175194384112, 0.040140107589503454, 0.0739439019572831, 0.04708747935271071, 0.021088090800349752, 0.03568710661643455, 0.02271419668930673, 0.011609111585834575, 0.0441234928345488, 0.00939603104451371, 0.040689116839559815, 0.05064651700517824, 0.03562177463825192, 0.035485230957067786, 0.053927970359161984, 0.08877075232204892, 0.015250146501667559, 0.07248410609580817, 0.06494674320903517, 0.04246657488927726, 0.04213326152474169, 0.0265751151187766, 0.03010736842219147, 0.08338888506254843, 0.10575268462660814, 0.019243917983746337, 0.034085722384794105, 0.0049419537179111956, 0.06508096181336911, 0.023436205829643918, 0.005642374500542158, 0.01429581257980317, 0.08484406141383995, 0.06629905693473355, 0.030462488479491685, 0.031838983770519975, 0.06264498607525903, 0.05411732431140639, 0.005188140381623301, 0.018069600956814907, 0.04087495061779215, 0.08052511816664089, 0.022618359089979244, 0.06962793113123025, 0.02493236213922501, 0.023729341712990598, 0.05282307621992884, 0.07701345539141087, 0.05036696386072905, 0.03429894763675909, 0.05728335119783879, 0.02008942624313697, 0.04104053286174613, 0.044016144764159, 0.06521824476940018, 0.01360064332989315, 0.022398610599339012, 0.04832439725437472, 0.045011649208684126, 0.0020703992988508678, 0.05309185433772303, 0.0813338618665453, 0.043692702442527785, 0.08772433750451573, 0.09184196050609313, 0.12586776332388963, 0.04854282424334557, 0.06269330707108302, 0.029589776437909856, 0.08371680133765744, 0.07965319519562107, 0.024537698538493247, 0.10029516618458495, 0.1839518526028241, 0.005899436739949329, 0.052296892559576424, 0.015061626627650714, 0.06519720033412019, 0.09386764253459631, 0.06719109737464497, 0.021920966269869, 0.0128337366491436, 0.003765032710244639, 0.019891562969273618, 0.024625919308633577, 0.012076034514804282, 0.008807030089590098, 0.043035341546900814, 0.03989654908617658, 0.00840601178952643, 0.06972933052888802, 0.03897324459807527, 0.008224605999496436, 0.042928993221252196, 0.006646614741428846, 0.026625060221000064, 0.009523208343213605, 0.047109098353933905, 0.044171584003995505, 0.024023925502514167, 0.06943869209217449, 0.015964753317436384, 0.01861665668266435, 0.06537166919799582, 0.12221213730592882, 0.045233772571889624, 0.017655901986384587, 0.04379592129900571, 0.044215155254688956, 0.06942435092623196, 0.07257792122301555, 0.03910543689984949, 0.029593321509779464, 0.09093904927853616, 0.027393164871741208, 0.0327501017149658, 0.10209106780107945, 0.07027912118862714, 0.024284334109735586, 0.03501815481051322, 0.007052140511316999, 0.07833867258722745, 0.06026127285534336, 0.08708784101350654, 0.08877264455922189, 0.0771575718517265, 0.023259806424199093, 0.025608003807945118, 0.0025261263316121675, 0.05544899196754541, 0.03485625744947503, 0.0651688704026803, 0.0823833027313794, 0.022184868238025138, 0.06349026450827237, 0.021054222053217313, 0.08855697548677845, 0.03427809089302056, 0.015318556238085994, 0.06721429451699219, 0.03360379562382737, 0.02096743769793501, 0.0239272317999313, 0.029897443093960325, 0.02192611246550035, 0.09787966031581165, 0.013911987207980167, 0.04715605571325268, 0.050587796365782145, 0.05729393470251272, 0.05434147397717161, 0.04610949150857426, 0.004302998084665066, 0.03979064892196367, 0.051653026302735654, 0.02364175679582742, 0.013110788516520012, 0.05554482190599365, 0.03400909827060757, 0.027334492112840378, 0.04179566955914901, 0.05741771535887834, 0.04179866113249333, 0.025672127282427206, 0.048945008912273956, 0.061417284211324114, 0.047514535066100864, 0.030136947076947942, 0.05346135386536199, 0.002377242649785213, 0.01579166245421455, 0.03588939979372006, 0.0162095547984204, 0.0686894964066244, 0.08677605855008287, 0.02656937712022374, 0.040953578051900676, 0.09209648555805607, 0.04880361972496875, 0.029141875472100034, 0.11675841866001008, 0.09999066155644194, 0.11179781548919217, 0.09822232378346306, 0.11515147263003934, 0.0602951224502777, 0.13243440088004838, 0.10833155108435501, 0.1990950513150423, 0.14242804849580412, 0.10823766700923444, 0.1565594595646666, 0.11122737875989369, 0.23031829766208128, 0.0927484723468942, 0.09041898283025912, 0.194569815911593, 0.09576957071981124, 0.11477444245810471, 0.15420130303790494, 0.1891854282228216, 0.060811377611131444, 0.10306275074159908, 0.10502813398958215, 0.23192389537730526, 0.1258122219493793, 0.18511052994478136, 0.13965435055715425, 0.1706609472392067, 0.17053769901394847, 0.11065151812809129, 0.10781489372734102, 0.11641137316943177, 0.13578690888900913, 0.09650044158221253, 0.10682666328765693, 0.09900871303773696, 0.11235299174703899, 0.09354598519782867, 0.2672932555358256, 0.1849520569967647, 0.1595896284186071, 0.11155806061240936, 0.1447696881669183, 0.1153583929783875, 0.21882270402725668, 0.1549123552057051, 0.116529856327801, 0.18970149569213393, 0.22504991100680447, 0.1627852569424337, 0.06881240755319595, 0.1134550015652372, 0.21086827521362614, 0.2656034800794817, 0.12011763759918752, 0.12421115947466706, 0.26816834244997273, 0.23239801187188397, 0.21129998108071668, 0.19489278325871115, 0.12479312582722596, 0.15881086940005903, 0.11057579033677617, 0.06148190755817679, 0.14948206352851084, 0.1474633145957224, 0.1255739532831696, 0.18397137252313478, 0.22548207652664956, 0.12797655057041876, 0.10747625988217131, 0.13218686254995485, 0.17519712237821472, 0.36947443059855894, 0.1588571104671686, 0.2088649552916327, 0.07159778833269112, 0.1748149211127912, 0.10922270286227427, 0.07367444585167593, 0.22137176966474903, 0.16397079332701622, 0.18871747107515413, 0.16178158983107538, 0.14521855440351272, 0.14608682313513371, 0.19806265590652344, 0.1266778093732653, 0.15326106800667702, 0.13712167920124146, 0.16327124779983876, 0.16380726419869931, 0.1911860515153216, 0.1180976935692372, 0.18132962556856294, 0.19128006582538928, 0.2585965947758767, 0.21883807175101774, 0.17978441090353076, 0.16972648851092786, 0.0875941102182673, 0.17737837388150154, 0.27461855762427856, 0.12122540839857633, 0.13773442696659796, 0.14393338062349828, 0.13120199523625836, 0.123215704825857, 0.21767234640015712, 0.12033233373996713, 0.08938700110921938, 0.18866940671878477, 0.14267437640697728, 0.13047361415961098, 0.22166899645761137, 0.1296512187728959, 0.1550974114046943, 0.17863227595244685, 0.16073946510591816, 0.15344900469626152, 0.1736820762556407, 0.09328487945059616, 0.08903948830500727, 0.14252718027320602, 0.13557188333042208, 0.11817233351569985, 0.12183943553076637, 0.1953748364241854, 0.07278122563636111, 0.1678909878096273, 0.17982944155171995, 0.18634754743787552, 0.27528355258607096, 0.09185110759590903, 0.12406158080745129, 0.10430562114643474, 0.07224370770516896, 0.10738912504166366, 0.1217869661688324, 0.15080120564708788, 0.20250120080046116, 0.2973323597783043, 0.11772582682991221, 0.13734606635426322, 0.18152373692681714, 0.21117310159869734, 0.10647079246419092, 0.12932249044458713, 0.11032909470339937, 0.12125129450953777, 0.06577893686030181, 0.14821421865734363, 0.20174496476688694, 0.09473053332898887, 0.11640070922552578, 0.20413330515786526, 0.16478485367711515, 0.07743111886684934, 0.12462428770959379, 0.161997580660447, 0.2204442363713057, 0.13733074459577763, 0.19972304423009196, 0.153251507229382, 0.09935382032586683, 0.1510792955636017, 0.07909356796693418, 0.18547561680597646, 0.20943282562638485, 0.18719441167289214, 0.16139327518401608, 0.09682932312810615, 0.15666600707317554, 0.16420895474091654, 0.13791116345072948], [0.02763751819128952, 0.06713590840057981, 0.08791579819855191, 0.041841427990866285, 0.04588633392667098, 0.07889108326766761, 0.024700097687121843, 0.05178472830823833, 0.008577125188293717, 0.028704010258098284, 0.0558712941053654, 0.013990964169704146, 0.0182130107010204, 0.02564176338754835, 0.018147833855642427, 0.048464652631551995, 0.045482892873546774, 0.06314001677017059, 0.025703665207050024, 0.06590447568845365, 0.014094300812200434, 0.03513334762124765, 0.044917654050814534, 0.04532572993588063, 0.04397964450500665, 0.013824995051348403, 0.03682633298599432, 0.08969532085522529, 0.0742452196596611, 0.046911309773643176, 0.0272682580661269, 0.06918197602874811, 0.025008886661981384, 0.01566769889435701, 0.013664347371236693, 0.033419608934632236, 0.023839844150408625, 0.04197374286670839, 0.025611071990081863, 0.011136676654249672, 0.04894218587827298, 0.04450077198505883, 0.054549535796526945, 0.029517044050378666, 0.02606811813048778, 0.0159115657480734, 0.09326937383100872, 0.03395813427144482, 0.06973685351230445, 0.008998367251948485, 0.05295760508987212, 0.023250682317020915, 0.05820547974097633, 0.06259406038049249, 0.07534521466661846, 0.008559866184969584, 0.0064731317369507695, 0.015510011186462738, 0.01910769031383097, 0.1007962259914606, 0.04212946555907688, 0.06073690620401214, 0.03543912012490534, 0.022861540295003403, 0.024535963349344752, 0.03670412280987348, 0.0013606114155282419, 0.0055545865700790484, 0.04128341337726001, 0.05386728087380048, 0.08805780025619654, 0.038770403667923906, 0.048942840883448246, 0.024610017238545324, 0.08249575677778452, 0.04172959830611945, 0.04846814982292633, 0.04610361944463465, 0.045943307885599714, 0.05399764988631491, 0.04296768449186798, 0.024666853301647692, 0.03980969386776129, 0.036465122529696074, 0.10613758252152514, 0.07054420293218668, 0.04325273048673426, 0.010046920412400318, 0.04749902944651343, 0.049096046976985476, 0.0503835458338501, 0.018764743393647577, 0.050235403581492366, 0.1283406032129161, 0.03461285599417264, 0.025839835420371066, 0.017358918426438205, 0.06849973642778012, 0.027065350103282163, 0.08032729894283318, 0.05053531551252931, 0.016158472055629376, 0.07214290585609213, 0.01882828847174683, 0.048321869164224596, 0.06403485726144525, 0.08351906638352141, 0.009468831422348178, 0.03352978769990225, 0.035034411196266456, 0.03613169042153224, 0.04390009393494937, 0.03177589259951586, 0.03510997810911748, 0.006009983706227955, 0.015928028977566188, 0.042219446416223244, 0.031439216108992696, 0.04781085021433331, 0.02947951723340779, 0.04941327632555077, 0.1726306665448412, 0.01948729071075157, 0.007072693692715539, 0.09452745108114136, 0.042040787051401796, 0.03705378832115281, 0.03409859649236164, 0.03368268352783015, 0.06252413953564341, 0.04931945736790377, 0.052744303229114706, 0.06417205211736503, 0.00806496859783487, 0.022827503008527622, 0.03788016353463454, 0.04645588965485654, 0.08271043759680564, 0.023472183233787938, 0.012032550406612217, 0.04828486711748185, 0.06169838485338035, 0.044258496679005124, 0.03519217168251353, 0.04649123312124322, 0.03772108920759732, 0.012959039905258726, 0.0841563136406964, 0.069980890820584, 0.05376683908604807, 0.07461561551017147, 0.04936517749522482, 0.024953140358951305, 0.09688255857796439, 0.04616095729532742, 0.04458517955255605, 0.05433498904289258, 0.040445297866338686, 0.06229993241328386, 0.03168469366256989, 0.02696016048561902, 0.022237684254744844, 0.029975279542287032, 0.012886385084129872, 0.018411647723687273, 0.056114959861001665, 0.03646938197855507, 0.05864242947990856, 0.005510106547585419, 0.02227821030593928, 0.019561932572434028, 0.027078488511183572, 0.008843355106129762, 0.047003795738301934, 0.052425101204144384, 0.028680518171900225, 0.014533187795971191, 0.11086189353297796, 0.03806966687402418, 0.025332478370757836, 0.0346556420047437, 0.04626720602954588, 0.06201118621374331, 0.07412722679756342, 0.026205845417514927, 0.06052517099305988, 0.09655691758399049, 0.03836605480060943, 0.010376585283196502, 0.042076548035707206, 0.03959669078129434, 0.042161108820789286, 0.0846110481107908, 0.07306345242766604, 0.02156367626852326, 0.026208469268655585, 0.020077839163282228, 0.07553784747517879, 0.04203691830738418, 0.02443511553499247, 0.04126418840080019, 0.04093575118590267, 0.05532205885937137, 0.01800534150172626, 0.05915357483430736, 0.0367403511078127, 0.023614290628522158, 0.04401417974863322, 0.027305419076113936, 0.024402763641950105, 0.04804222025878487, 0.010311306931168563, 0.020688556795639378, 0.030708228418182944, 0.05421414633371657, 0.015160633915764912, 0.04227473498171857, 0.04018832133301804, 0.011891799945113881, 0.04813814595822365, 0.04236742779011688, 0.04034525827474652, 0.018998739204459617, 0.03150830957888356, 0.06834776756624061, 0.047301853736562115, 0.067345195960614, 0.017871184184426264, 0.023022083595635432, 0.06407903755203852, 0.04673648850932237, 0.021386420759823055, 0.027057076353699933, 0.03636875249926121, 0.012994665866567483, 0.07507485457726064, 0.039074896804748044, 0.021138470657470248, 0.035326382625968225, 0.10357612158141791, 0.026823115016844486, 0.04000242243731215, 0.07173075821370849, 0.05588249048037876, 0.019781757671866688, 0.0415139637076326, 0.04234897273202096, 0.0027787993660181643, 0.01856236020103097, 0.05549864212591803, 0.016106556192220702, 0.04106708163876207, 0.10302744174916899, 0.01608051877889422, 0.08587577500410619, 0.04992717193559774, 0.025448414286778822, 0.0690045960307602, 0.04764556291423017, 0.003805120894309855, 0.032848371643452876, 0.07971291174931873, 0.07304192535699376, 0.08259345597076802, 0.0959681713533017, 0.0286259803725707, 0.028275472164574652, 0.045719280793902375, 0.020504944672387455, 0.07775675219994399, 0.03768998220743191, 0.05469344158266341, 0.05885337562029881, 0.03158283461215756, 0.04250841861170146, 0.04647025763387642, 0.028602222070818948, 0.041528362330169453, 0.018108077722811894, 0.0694845654370804, 0.03868703031912446, 0.06344484315524179, 0.04578556655155075, 0.04191024949954402, 0.03186152782291174, 0.011478565415487656, 0.07056364624370491, 0.09968335304649607, 0.042219519194576054, 0.03469148725872079, 0.05994932185257635, 0.0400267725419854, 0.023791502087166714, 0.01732800486347368, 0.03135585616673193, 0.03346601854108515, 0.01702623899965998, 0.038329167667055325, 0.019993816554966955, 0.08601513405841205, 0.04902701096368894, 0.014571973869967607, 0.051498134815765005, 0.01030112274982516, 0.1046281211799191, 0.05847845219015595, 0.013409233389181957, 0.055773855382276166, 0.04422162486720951, 0.015743035023220848, 0.016244549694801533, 0.042088556463920304, 0.03801469240457781, 0.056948467353058446, 0.004416459536690626, 0.024130444282725937, 0.02304116876104907, 0.017653218763429793, 0.025426025367191723, 0.06841712150602572, 0.03742439867628198, 0.0065747456392273316, 0.024254081297605753, 0.06464165635406971, 0.04911447905244366, 0.009774825133894001, 0.030185218277056853, 0.05896328242435571, 0.011111887964239765, 0.054942167349039554, 0.12551511773058485, 0.05522740103544728, 0.12468006657136065, 0.07118778573649545, 0.055399567805110454, 0.015323053174201521, 0.03773079171115833, 0.035252481954352516, 0.04206416805485084, 0.04975848703555042, 0.06148684499484878, 0.12214826855568156, 0.038481006293647715, 0.05894460137032213, 0.03897609061471397, 0.037389775332544124, 0.02998474647381133, 0.07500324833897815, 0.043692951421103174, 0.05487917576946559, 0.03186540039736898, 0.0315071547013377, 0.09139240479036685, 0.16043900542201536, 0.19755435656876336, 0.10982698535606747, 0.16846495620425672, 0.19647552091027462, 0.12305601379804074, 0.1671936026503963, 0.11901777282717729, 0.10273095040071396, 0.2191909624924583, 0.1612647562738388, 0.07844274563174095, 0.16592394981172778, 0.07716059023814817, 0.13184981450678843, 0.2472281257712072, 0.22586400200042034, 0.18339954917469334, 0.2257728988244649, 0.11685069395048965, 0.17381433367488847, 0.16283885245361637, 0.1409309901176922, 0.09671380473000389, 0.10367997246043337, 0.1319456674278744, 0.187171122599994, 0.20411956154050367, 0.1446960977609119, 0.18239807307479844, 0.09827441010143488, 0.09835526302096345, 0.2766345946058151, 0.11123115557336039, 0.09843181052635755, 0.11098548649780213, 0.1389150603884651, 0.1357218833459962, 0.11497046137529035, 0.08851249642189472, 0.15348110378028887, 0.12950098893094447, 0.14237555615123243, 0.11323720276836427, 0.09578791852559775, 0.22013254583843295, 0.10778352242684174, 0.2420006328893285, 0.14436015288435644, 0.22999165309292657, 0.0599609089324311, 0.17555139207791898, 0.22433254627450822, 0.20437609374282822, 0.09370985906571151, 0.13712688859912658, 0.14240730283481462, 0.157247896816942, 0.1969626455778076, 0.17475878218969992, 0.13810806336902803, 0.18026597377273346, 0.15354067477728092, 0.13726608677496835, 0.11333961340208208, 0.11906890153524377, 0.14929585819763525, 0.2322810915328803, 0.182039758430854, 0.18930193487434618, 0.11869878147638614, 0.09067635006842115, 0.12060991803845092, 0.13448206197109916, 0.06306571007195501, 0.1272148140255482, 0.16159694731956528, 0.17264796481017144, 0.17489048802564222, 0.12386367731397191, 0.13983318612219828, 0.1835730374460259, 0.13932808903196167, 0.234875034600977, 0.1944912306123203, 0.1479415679650922, 0.22430420102130985, 0.21076682985069292, 0.16225337741836426, 0.11205572664978043, 0.15773324416049067, 0.11589477709945172, 0.2351061786494909, 0.1209384931491748, 0.17998733227291416, 0.22040469091265436, 0.14885770187022226, 0.193889437904281, 0.16815309713204063, 0.2556009764873213, 0.19062187372436448, 0.18555607135978439, 0.3190670402780656, 0.12634758717350422, 0.2227869332437554, 0.2278429296829047, 0.1577009305718445, 0.13916592354014998, 0.14934786024593538, 0.21531785177367352, 0.18963887566520324, 0.13091167855647304, 0.13368107108098845, 0.1343141048545799, 0.1421435540842433, 0.08019503386270616, 0.12293623595107948, 0.1826651466469611, 0.2518640302361981, 0.14541825820361415, 0.23565626042264126, 0.11353475131815481, 0.19493029092348393, 0.17824432902759124, 0.1193718893092967, 0.08939483818868477, 0.09414109761916822, 0.1383713218233278, 0.11670416431321252, 0.17211807711470514, 0.1961062971742884, 0.13040731691064375, 0.1024416296352302, 0.09482144498296323, 0.1223505310894501, 0.11436226417220409, 0.17093952745199206, 0.1376680531088383, 0.13569035116703282, 0.09988448943101591, 0.18923779799332544, 0.10458240871347728, 0.15464263096932443, 0.18399299152435797, 0.12233915468377453, 0.1624380505733913, 0.1537514868522844, 0.17432154516779608, 0.08854336976524323, 0.22932809837643178, 0.17186621804871868, 0.17998092777786717, 0.1681084188842966, 0.2060483717509816, 0.17445105999227495, 0.2610766358913914, 0.19086271644599978, 0.23172515684798842, 0.15104002589660306, 0.11579711621086444, 0.11882321713792703, 0.15397876981765996, 0.08578966672141707, 0.14872651697406847, 0.2579674527289406, 0.17014258150612155, 0.14046491754631843, 0.11279995042470195, 0.11928772688993525, 0.21842346496639714, 0.12562420865100238, 0.1501546887260291, 0.19255321202499254, 0.1589537754414543, 0.1934352550174921], [0.07373950969908508, 0.032720258759875456, 0.02173725647040673, 0.08139747014689831, 0.14333607719069527, 0.05144478828315774, 0.05649543359815594, 0.040095869842315876, 0.05443240095290446, 0.05778189057544355, 0.04375680484959195, 0.01999519934367028, 0.0802301896375514, 0.021591655714737795, 0.022125477271695292, 0.025119777889020985, 0.05926870635800785, 0.062316027920572996, 0.010087722255247495, 0.05756681905158105, 0.04612493584112776, 0.06035939722712483, 0.046075944518370014, 0.02513697656292108, 0.08577034598396671, 0.05860005332637699, 0.05986092679743325, 0.021590485515433456, 0.07637515859377962, 0.03038299345080891, 0.07727563366173737, 0.0629588637891556, 0.10385059556292911, 0.01892476575449109, 0.058345275465399034, 0.03695662538971632, 0.06836158013151539, 0.05413348493616908, 0.020946305162543734, 0.08926862520315955, 0.008955214476783671, 0.042559202580202016, 0.08111460750261623, 0.04030302384748094, 0.052321066464027094, 0.047006526841751994, 0.054921636192668835, 0.04463042853580368, 0.0021370920407090097, 0.04031089540090292, 0.07331816900161005, 0.02591624886037842, 0.022319655662642855, 0.031205645476978634, 0.04772849576247316, 0.06481680703619797, 0.04909336183881087, 0.03198929596692324, 0.011850325860113147, 0.038267436302116806, 0.025046516900822043, 0.08735359691443943, 0.04882459521233555, 0.037343790904889186, 0.02210779979284252, 0.09506368964549997, 0.02216406320522149, 0.09794567411224689, 0.1606098430291299, 0.029737328802565896, 0.019150799996550047, 0.034373936153227286, 0.05842584876283523, 0.030175058035961086, 0.024022355022269393, 0.0455318458919083, 0.09684658308904018, 0.018144514779710484, 0.017607161557422053, 0.021480165023897446, 0.08542483266923698, 0.01566204899591544, 0.03802110456050404, 0.028135408309378454, 0.06918627378200332, 0.033325897229294625, 0.028658878103259112, 0.09995904510780688, 0.05004162547148524, 0.06329794962620063, 0.05757432288279938, 0.028266047367886193, 0.08272085639257586, 0.038021307573803974, 0.03158846535840102, 0.02441536578830452, 0.05251685172439583, 0.027208078029235045, 0.04285347610411625, 0.06464815277966761, 0.04932118489617302, 0.10413122123047229, 0.047071969902683655, 0.025743850349118153, 0.029847871459599946, 0.0363697522440024, 0.03994793443369769, 0.05042369650196164, 0.02656890980658993, 0.018233153067769545, 0.05235223092078682, 0.03898796880797994, 0.08718366329107555, 0.06340067818640702, 0.023069376118421074, 0.09376504803977667, 0.009078824678586136, 0.026628582310231946, 0.009198397597027643, 0.007194087985197023, 0.007002151359037887, 0.06252930296825306, 0.026528933423481164, 0.035540971514438434, 0.03227209732417138, 0.04897539578979054, 0.06430797909777011, 0.019664841163302624, 0.03679932838666343, 0.03149603301989696, 0.039688743906275886, 0.007664690051423086, 0.04703189584336454, 0.046757563588119326, 0.043079234554522464, 0.06539403896538482, 0.04829360435025827, 0.023909090837884336, 0.031793033816821636, 0.015523744270115372, 0.07068894758460022, 0.05155266878465491, 0.014051984030482991, 0.03135965404761655, 0.10616878528268107, 0.06958595717385893, 0.009690406075077913, 0.0913572796590386, 0.02529155012340315, 0.037694364230358796, 0.04642782402375052, 0.02465649387769161, 0.05398304825047812, 0.03101296095748342, 0.05198362005514003, 0.016306072300780686, 0.06331765723805274, 0.044873393320989226, 0.04056579200550914, 0.03647224714739188, 0.037696382872039275, 0.08186892831637975, 0.01399024883510485, 0.03090612999644251, 0.04258249548353976, 0.019782722942651283, 0.06602917948076803, 0.03937319229026476, 0.02125731962282331, 0.08036692867115622, 0.05536747638196234, 0.03971069998618576, 0.029596031545811606, 0.016079720132233157, 0.04318241510660418, 0.021680646403242024, 0.008321767015713117, 0.06096796215241475, 0.03852069730900469, 0.04042990332950027, 0.013650925510803298, 0.15009769178446264, 0.025076754391193393, 0.20282067478664462, 0.028960515647345496, 0.027873222378172705, 0.07208502025253351, 0.043747201937461094, 0.07296433597202263, 0.062373465362695925, 0.09905909097963765, 0.020720123448559356, 0.04994802867933627, 0.04069779661574191, 0.008427935310699528, 0.04704519129929043, 0.06480330856697214, 0.045659690644712224, 0.04121097593357967, 0.05595984237809336, 0.007864930591876469, 0.04269625187941617, 0.08834700610849165, 0.012621098412050596, 0.052272450524352254, 0.01720968641400818, 0.04862967563132125, 0.0521427748214093, 0.0698268152172527, 0.0246218609578547, 0.026786618588131764, 0.0393186851344522, 0.05604153799433863, 0.02146712429220638, 0.034525552614321636, 0.022465507312106992, 0.025106968898927013, 0.04882347289352648, 0.12403850623917197, 0.044844519467123097, 0.05513618677674283, 0.09088097215299645, 0.04741441503527665, 0.08033864470499177, 0.025471745494512782, 0.028985135798012058, 0.02334646054453427, 0.05803358110208666, 0.08915045614083929, 0.04852145422069777, 0.0026778531572481078, 0.0364583618037643, 0.05963857743829008, 0.06821753261911292, 0.0632154917524707, 0.024442960275337103, 0.06253391098711761, 0.07194147069728182, 0.05148676224052907, 0.04609435361119048, 0.03220957688867085, 0.058493659035452915, 0.005382958934792588, 0.07090998693339287, 0.13014637204187532, 0.03621706325981406, 0.05481485119690338, 0.06331487250844799, 0.05684536340976915, 0.016849410584977558, 0.05566527774076789, 0.08270199530788007, 0.01552171796755565, 0.03201393910022753, 0.0264878653650803, 0.028272775535081184, 0.028306132918524168, 0.045391747562755505, 0.025533178085160833, 0.005346891994122417, 0.07293586048387712, 0.06480667169295973, 0.0386709118291976, 0.01636783430923618, 0.011144188146347241, 0.021623032760896513, 0.06903148571690244, 0.06506665129094355, 0.026472505302198475, 0.03301962676848615, 0.058964404743164785, 0.0774723650406926, 0.028419849094784552, 0.056719227033036376, 0.05246990968683555, 0.10440819265861666, 0.04307849144923591, 0.11546426632952307, 0.06712155957375804, 0.041889009711843346, 0.05434593260889092, 0.04144613428281681, 0.018825157087356336, 0.07133253038890901, 0.07636924439500417, 0.04704186264725943, 0.07791158623032032, 0.012276953521875605, 0.0399846606887877, 0.03341196337714791, 0.0844514949788009, 0.04983001666504049, 0.012814470495457852, 0.053366669228360544, 0.031387179586735946, 0.08711422508161876, 0.0728081229833826, 0.041563449157101494, 0.01591772796781433, 0.09186616122362115, 0.044026486951136784, 0.03845404382915266, 0.04272551260768406, 0.09079880156223813, 0.036564901651393984, 0.021472695666635712, 0.02283274496514951, 0.008763916576431404, 0.04241684046123297, 0.06444484070544282, 0.019411233501629006, 0.08045486024310512, 0.04213256821517022, 0.02341723940785854, 0.061218204772880966, 0.026094927377397978, 0.057909647228136185, 0.09578820197812973, 0.035754648758278745, 0.05692268083352716, 0.06115709776960074, 0.053295124277111985, 0.07069881479706495, 0.033466704189777374, 0.05550518451679138, 0.030830170463530288, 0.020799541868449702, 0.04385240113122329, 0.015190219273790719, 0.03657812815940669, 0.026312368028166316, 0.01476692409449888, 0.041194616125956665, 0.026170829453715877, 0.07958915790603047, 0.05083162299988251, 0.03349988345777796, 0.025794879465754476, 0.01611734079497476, 0.06811200400754329, 0.029981458041396354, 0.05477020742311593, 0.0653037095382329, 0.05126552753931573, 0.02956119561267476, 0.030617552336245298, 0.045857674577423645, 0.014856735454691995, 0.04568479534599089, 0.04015058384186799, 0.029227809469786384, 0.04029713263134322, 0.11816531615031343, 0.20338197208700642, 0.15779929626132214, 0.16998568669922892, 0.3533804861287917, 0.3009715532102893, 0.28967592384546037, 0.19481493340384579, 0.0984430950014822, 0.2183961615927758, 0.15892921466260188, 0.09274307908790727, 0.2618144092059905, 0.1752219742704784, 0.1757959733086248, 0.16731171808656187, 0.11509315801724312, 0.2609502313838851, 0.11923698888671015, 0.1307209379850857, 0.1826871946574219, 0.1561196484873372, 0.14199874814479582, 0.10782053979534297, 0.19625107247021892, 0.22270129993557933, 0.2063132696334393, 0.11179207749063931, 0.17484050844946217, 0.0931012251925084, 0.16236769305842538, 0.08786423282036859, 0.1857062858799773, 0.07494127182590385, 0.18836081118112613, 0.11322936568889888, 0.1429499841986164, 0.0962459165302496, 0.14251627118116425, 0.1600971923119599, 0.10422721970826389, 0.1754076586615655, 0.18716841064874204, 0.23353229697433212, 0.18646816032067423, 0.32554737802955414, 0.21091113017211038, 0.16467813762926287, 0.0839582262861152, 0.2232507228731148, 0.13954763450930197, 0.179438108518239, 0.15627812143535386, 0.21435038997761666, 0.12887613697638436, 0.22414212746004905, 0.1212038200408701, 0.17448349615498898, 0.13464536127303878, 0.09998709924759404, 0.1928225225738941, 0.16739951176268442, 0.21047531807374573, 0.22459650952969828, 0.08946917936085694, 0.14647345238875958, 0.1076023426327494, 0.18333383415254856, 0.22887670404968724, 0.11929744088481511, 0.13545586697516904, 0.1898471749718151, 0.20003268164732765, 0.09911835554145998, 0.23505851265884217, 0.20156810570868755, 0.2855645751039828, 0.11708166945966021, 0.05442196683537576, 0.08612260087243012, 0.21620734114079707, 0.1501492648235252, 0.15640493963033925, 0.11434411554927788, 0.15963822903652347, 0.14156367149083846, 0.0770313588662013, 0.18542280270447656, 0.15872742710334642, 0.17605912451061512, 0.15701555767126624, 0.18861938117732927, 0.1648299456123383, 0.11656844417654699, 0.14093080625659035, 0.17282234174349617, 0.19106453464877224, 0.10319025075483708, 0.11676116125477899, 0.13794966702980382, 0.1289638234001975, 0.341137052784043, 0.08859409244670984, 0.13224997287315707, 0.13376253687085646, 0.09904704041658871, 0.1433855817923623, 0.1546798321989275, 0.15413995471692857, 0.20673002146424788, 0.1181606047095791, 0.12173138648992586, 0.18108697487942635, 0.15197725786316782, 0.14156664391198467, 0.1793439869558619, 0.1307264538181405, 0.08421722529155594, 0.16921544657839885, 0.15974980208181566, 0.13493615292733716, 0.12535347317856166, 0.07231347533243318, 0.15640746772048936, 0.15004552119681913, 0.17060526796887, 0.1840327821311451, 0.17236285752827124, 0.09009793070295165, 0.1333290383580231, 0.1598082392686798, 0.13728255766534037, 0.14091315559081494, 0.21512715716756162, 0.0767879037847442, 0.20772437294644697, 0.13035951302416865, 0.1380521083070386, 0.08708686042096346, 0.11874021151133123, 0.11029477396439161, 0.24152155214500046, 0.13284540705142484, 0.11758921803125452, 0.3438272777824633, 0.33648928927798427, 0.1308649471930919, 0.14787039839692656, 0.18303409459129458, 0.1775866578663549, 0.09170496866347329, 0.11805560469867722, 0.12711027366740088, 0.1402611534802183, 0.13568198548689966, 0.08822702141779085, 0.1325493600339659, 0.06666462643132096, 0.17499516627961592, 0.12547780158779315, 0.1239084168487499, 0.1645407780644394, 0.15501012334660177, 0.2506137134567384, 0.14173562758632247, 0.1375873534068946, 0.14917236482424123, 0.23762896747118045, 0.09978793936991885, 0.12192344473254298, 0.1955925586122659, 0.14095754272514774, 0.2172326425751371, 0.17464515602877065, 0.20713491425398858, 0.09462757111196557], [0.02729521670018233, 0.02774484136382178, 0.04324821056798101, 0.02313015753433349, 0.07339087840650352, 0.04210987669085303, 0.05197286035024351, 0.018104862068749724, 0.015387217825909537, 0.03625352521457019, 0.09373103373593862, 0.03763969236564252, 0.06170152964430952, 0.044310667266648625, 0.043693368939021905, 0.07750310048821472, 0.021035902975727955, 0.036086981530271234, 0.016273887031861854, 0.011515202612856464, 0.04270365994964396, 0.029255470989512342, 0.08631103551916539, 0.01832652960964028, 0.04972381006565787, 0.015867934167955913, 0.03451825562684286, 0.04347756580119172, 0.06823670779985767, 0.01261922532707573, 0.010327267415461042, 0.03168273439270354, 0.0795950184786512, 0.0800023780715081, 0.03427495376297063, 0.008771017253879578, 0.030244059575301026, 0.03247643978665433, 0.033952645251467344, 0.026311234218038382, 0.006583230062988737, 0.020478604654330882, 0.010053420668437837, 0.012665975842654947, 0.011383849177359334, 0.03141801845612786, 0.06573500171784433, 0.006154417614227222, 0.03447845352873687, 0.02441941456298434, 0.03722158455920797, 0.025982934898967226, 0.02931055462648792, 0.02664776323663612, 0.04003115839535191, 0.013046514697282786, 0.0633710535663751, 0.029962878494012742, 0.06208651563933781, 0.030515030619778463, 0.10883269516090233, 0.028341846022334312, 0.0608041227584885, 0.053923887110525565, 0.04930452248381992, 0.061150042099818114, 0.04263668471286374, 0.023910667063788544, 0.06822752240564554, 0.11083367085384746, 0.09567994609354966, 0.028919932139556737, 0.02135683444418734, 0.05902188815056317, 0.04503344441012991, 0.030256104392690525, 0.07563935412514596, 0.056676912166538744, 0.020683979420291803, 0.06301393018915288, 0.032308363926506815, 0.03786631266496355, 0.04536863852051958, 0.046021445023436705, 0.14202333956716523, 0.01523404812154871, 0.033753994822261796, 0.04954081081274537, 0.09561604669978542, 0.05286728715403907, 0.024727037168979168, 0.029760547012331027, 0.045567220001811945, 0.10505339190844568, 0.10277533753504677, 0.03474973675404345, 0.10878217932317527, 0.02862262682268216, 0.0336440880182049, 0.07718560300887593, 0.09062335210581941, 0.09389639381439456, 0.04212664635551553, 0.0174251735405696, 0.05389603598403835, 0.051479855957891674, 0.05390437102065452, 0.05498017297096311, 0.05392977066578404, 0.043851186881863305, 0.03265078607646208, 0.02862148152123536, 0.04436461517827646, 0.008221123172270675, 0.0773695637021334, 0.008773656426778725, 0.01473137282676274, 0.018373107755436532, 0.014153848826554755, 0.039369235446135846, 0.002085070840210744, 0.04155980257858192, 0.06541709821190565, 0.06121860313860159, 0.012620573641822464, 0.04947584655676638, 0.051337459364966045, 0.04570123559284595, 0.06689319642440927, 0.08273541972401642, 0.02826934920683984, 0.055688497865752834, 0.03944839531135175, 0.007925428555256898, 0.050949849518797094, 0.047257922424544255, 0.016189305179361856, 0.08359140806621121, 0.04694086544576192, 0.050386556559392524, 0.021537958696905165, 0.048071580578482924, 0.028432976011367097, 0.02214497037892861, 0.07922864458974331, 0.04497866912354385, 0.020874358015134934, 0.016843008005150387, 0.03918103828665711, 0.10317842235728618, 0.0586256483239272, 0.01991268209812622, 0.04295227463327108, 0.015381214569412894, 0.05704629678098906, 0.0373586300279825, 0.07023259666898558, 0.025313986923485517, 0.027628279170922698, 0.04506396918347286, 0.07506861862155699, 0.027090265197799574, 0.04386283524875199, 0.033128552979999976, 0.03969499135329839, 0.0595239132282234, 0.024827697291789998, 0.010047485402244474, 0.03385602241201747, 0.021175011136238615, 0.03519244747416627, 0.007745178121577709, 0.10887013387776191, 0.013619242987084775, 0.028564844640993306, 0.058970311281060984, 0.03456492953362965, 0.024172916197248047, 0.06968227740857871, 0.050890581126535134, 0.09095157481609814, 0.016215555182087327, 0.016402622361877756, 0.01753906591705257, 0.0464982275039919, 0.05221155036481158, 0.05122518917966274, 0.06261784358010178, 0.056551790856305635, 0.0217041767938363, 0.02699126748578443, 0.03141846661756356, 0.022087735950105616, 0.05171017646188698, 0.03472632510707744, 0.043155824194752404, 0.05291208031497175, 0.026414926133809552, 0.07631042416417792, 0.010679064566389689, 0.15447928570210934, 0.00804015213713771, 0.036723554630072854, 0.01808291364971909, 0.09208802028649277, 0.009497266690877658, 0.055687229990238146, 0.024322910467162732, 0.09984849862033322, 0.01713247049690014, 0.05021605603096466, 0.01942276887054886, 0.03435671066624984, 0.032077867222288926, 0.020842651551168774, 0.05848371138375613, 0.02516962339981429, 0.038420998626538826, 0.04635128417923566, 0.029884323838257024, 0.021530474017884944, 0.01172148040495813, 0.02726219256498641, 0.03821266484597037, 0.06786696312408294, 0.05794487578133422, 0.028584203682839874, 0.03321229405100307, 0.037442819260421305, 0.043524615091061404, 0.011834852799262491, 0.09067680972117571, 0.03428178726725521, 0.04488236804102217, 0.023292183215099, 0.03482488614897575, 0.01903150286976128, 0.02800563684544496, 0.03483383788637096, 0.04475834223652079, 0.026853727890298735, 0.05163390091770599, 0.022189290480568044, 0.082891333938366, 0.10825223800155426, 0.03719070738541984, 0.029126588187571016, 0.08783887531007491, 0.058570738971954396, 0.01656368277185867, 0.032901009544730186, 0.11417592860638134, 0.0668720294150614, 0.013189132498096556, 0.014603453380386195, 0.07791877979592932, 0.0360859741246508, 0.10381438258674838, 0.033252885219671076, 0.016206996064753305, 0.05300041025264129, 0.03663954925873587, 0.028378237113957445, 0.13258702091632352, 0.030554177712709196, 0.01048105860865044, 0.035883056585707014, 0.07229773988646847, 0.04435207048851637, 0.039095991035743106, 0.05502381700000936, 0.07910002608813586, 0.11896659815383535, 0.03936538968475596, 0.04491971482733085, 0.10261854231958428, 0.06519710840356928, 0.034056814056971384, 0.022656546657784812, 0.026815946349093032, 0.05801252900592743, 0.1258087822145993, 0.10501172438624407, 0.05160411541920997, 0.07228770413466039, 0.03508683842336459, 0.03297455398546111, 0.008260729917955976, 0.04142215573078683, 0.10082916011132541, 0.006797015037943399, 0.018412827499090664, 0.026426563009379372, 0.026014884595849344, 0.02708989747559592, 0.026073045991060716, 0.015402555863763538, 0.0764277735124192, 0.0660205839742576, 0.023113521935057738, 0.043983379183637525, 0.04788365154977768, 0.06439250157845598, 0.014317929538177147, 0.0386992953867922, 0.057871266223129735, 0.01935907632052418, 0.06844797952761573, 0.017891646392883796, 0.030253197089017882, 0.06001625878496036, 0.013597231365800386, 0.008969451263246518, 0.06821400861466123, 0.09802240547874282, 0.04982770690994878, 0.023434807719182105, 0.034053810992308205, 0.07206029093433773, 0.010078469828341999, 0.0023656993805836407, 0.011715728999866594, 0.030946979719784953, 0.07619499769662658, 0.03502912902002854, 0.013362961678555416, 0.02320385519264927, 0.019658616698917844, 0.034086530607554226, 0.005843004788227019, 0.054997264392553806, 0.024954821921945102, 0.03138330701227871, 0.0454692948128908, 0.0335257159425847, 0.0670537761142177, 0.039063562533908316, 0.04026781444648101, 0.02676139897366445, 0.04503589206104798, 0.02383458687202825, 0.07000028816682678, 0.04096205864522246, 0.012827161699533464, 0.07346266084500859, 0.04493807412443623, 0.01668397006728957, 0.032656068252699996, 0.047309870846689715, 0.04911941265867603, 0.02502687249122368, 0.08796954692731943, 0.14114786960905598, 0.08781404640044897, 0.2236789200575121, 0.13366988619729397, 0.12287651939738183, 0.09320054849189136, 0.16713682021344864, 0.14135460609630232, 0.17130953259766105, 0.16596217759914939, 0.20141606789923486, 0.10465757726060768, 0.11139582617268448, 0.13656274145168645, 0.1297046610664937, 0.1269891245230552, 0.07951594288310698, 0.15209338147073023, 0.12638077410238405, 0.09247851828413625, 0.1488077222940422, 0.17169761741834302, 0.17458224488842874, 0.1258124900801528, 0.41722331196069723, 0.12379066147390874, 0.20973682463649782, 0.08258434718534832, 0.2319947891538182, 0.13927994806679989, 0.1818274295017604, 0.14372949398333026, 0.2173864883520911, 0.14138909537465344, 0.10125755647858305, 0.11518771624973706, 0.1633532958165292, 0.10368092240945948, 0.11129445741854369, 0.15470735007716765, 0.12582876178766453, 0.13014628011132442, 0.09196329351154067, 0.10716070826616018, 0.1592757468742709, 0.12196534974200111, 0.23065827216111848, 0.11990241285774017, 0.12322171095518336, 0.14624456063874308, 0.08711596410120688, 0.1575363595639506, 0.13182117814017882, 0.08826389322958647, 0.11590389354575066, 0.26261218252681917, 0.14637573021313838, 0.12547096808350858, 0.15542486802704875, 0.163979021111323, 0.20428791702274354, 0.17724029419402923, 0.12232348818572299, 0.130970805222469, 0.20715262620679795, 0.11985911356825983, 0.16653063016072397, 0.1933511232416476, 0.20926243235026637, 0.2192220503404256, 0.09458273964663667, 0.15456752370922797, 0.22341517130694083, 0.12468873102578426, 0.13671094882151774, 0.22477257185645644, 0.1365191510487949, 0.12429067940120736, 0.06429949850444833, 0.204860812894279, 0.1000717289805893, 0.15885268247896628, 0.11878059200582006, 0.1274806541961528, 0.26426818882746084, 0.11834327837512379, 0.13949535666934906, 0.23627061697263874, 0.2522540762419662, 0.1411195549993746, 0.16808448629754205, 0.17400325095701605, 0.22516468629962016, 0.23075763376489764, 0.21550005812558437, 0.21864301044373743, 0.2439588455543403, 0.2718331232186287, 0.13147774092372388, 0.1807902077393186, 0.16807301030043634, 0.20557689059886242, 0.09671495386189032, 0.0755791396142975, 0.12380093471297335, 0.16548387826450411, 0.1762694309675886, 0.14996233937000075, 0.18444167389985056, 0.14579370257354554, 0.31815116684282985, 0.15205146113951362, 0.1853192429388723, 0.14913439750671387, 0.18011215863929642, 0.13884516252625373, 0.12867393572964977, 0.09275548971228062, 0.0900266538824766, 0.10801822878420354, 0.1667146904454116, 0.18732149033777176, 0.19499789052192243, 0.13946417689083085, 0.17325102922416505, 0.12285647853728264, 0.20801697256824664, 0.15631886199116707, 0.2046671305452624, 0.1878058111235019, 0.10205724501922246, 0.12136131239634369, 0.13946102060858281, 0.2435539374428411, 0.17524641247526293, 0.11986200171973437, 0.11233012402249921, 0.10774141823452328, 0.20236440814070164, 0.1738408249953101, 0.10233044729477937, 0.11537582913954413, 0.14686751269525097, 0.09523018353408384, 0.14172263473512667, 0.1729500945657492, 0.11424748887938839, 0.13870705219526447, 0.14520343182788742, 0.13255901274181184, 0.08878267265015072, 0.1711318921297789, 0.11016449305198847, 0.060345105856897376, 0.1603450677207401, 0.10319048058121436, 0.17612551369013327, 0.12109880470820975, 0.16416706505321688, 0.2050071663313335, 0.219558087147532, 0.12046405489766791, 0.1026495612196384, 0.14301617419527424, 0.1566156750965503, 0.1317232414599388, 0.13228363477654997, 0.10191215562724298, 0.1242628014616428, 0.08723749628951473, 0.10153023781435144, 0.15418987300607467, 0.24770264063150654, 0.10304557505033671, 0.11852372272480881, 0.20432602223609725], [0.006380860276910807, 0.040483866562886585, 0.018408455052262834, 0.016352263572175178, 0.030678804896231142, 0.01851614786221856, 0.004890478833863933, 0.05728040558976993, 0.033598245316815954, 0.0737818590395393, 0.04330551394471719, 0.02186887995189717, 0.04995434507427197, 0.04524533283866702, 0.035919334679361314, 0.07339202753838993, 0.10074329697677206, 0.029703486868510806, 0.08579571115513963, 0.05534383490861905, 0.03483506745748943, 0.07697513567343836, 0.05070576241480247, 0.06371372086446613, 0.006876199322211887, 0.02098470148930867, 0.05026035506518618, 0.04337061226608292, 0.043378185045214436, 0.03348995878871891, 0.035515223299303365, 0.055333569330433686, 0.03461097141787891, 0.0451274395679995, 0.04589467279372677, 0.056246807423209956, 0.0306412493509631, 0.02056540050093205, 0.02620544896701411, 0.0366299961423201, 0.013984301119982718, 0.03566209767614642, 0.008441225978575887, 0.043586698856445096, 0.02537040355344934, 0.06670925105291028, 0.046147539265333645, 0.03794317426640661, 0.08666787161341599, 0.02599417149359661, 0.022814412481121482, 0.04194167442619801, 0.018482633430751103, 0.03482546071491895, 0.07102234904924709, 0.029104293113754644, 0.0496311976964916, 0.04600515033328726, 0.011801628523596354, 0.03651735823481314, 0.024182990253452333, 0.03205108095801646, 0.10258321034451647, 0.0881350908668772, 0.011691426775688607, 0.030254654571293827, 0.022982427054235054, 0.0627709960474843, 0.06281972690034779, 0.06533553283060752, 0.011459168069244874, 0.06069356477969597, 0.08353008272787256, 0.0777588819243735, 0.01762717560444388, 0.08853108171493777, 0.07602459675962887, 0.022776736277005365, 0.007525656105680092, 0.04014615202322602, 0.011359598664116236, 0.022853505947897514, 0.05391974257485521, 0.09326381203267844, 0.06945028300246886, 0.0621014581843009, 0.06858009905103715, 0.012365206850752717, 0.1055775186227214, 0.013515939860935173, 0.017626840440977006, 0.12363742090641491, 0.048950582201923096, 0.035442015937259125, 0.0623370225601379, 0.06147889683263437, 0.04496913515932618, 0.10939234537222695, 0.05810072487821022, 0.12166433847479283, 0.08662241195598919, 0.027468680073657346, 0.047174763580363606, 0.028367260989222317, 0.037441823346119736, 0.02707132750431136, 0.010548159292328262, 0.03784101644170381, 0.017565484459121383, 0.04204984604110641, 0.03912893664692679, 0.02920480193420043, 0.08653521582844757, 0.08261592532958716, 0.02774732540391626, 0.04856508675842516, 0.030292187133924137, 0.022411266371848124, 0.04694225206490486, 0.045226904593648455, 0.042237552904313615, 0.056229463192604245, 0.009188547621541207, 0.029691072413697842, 0.04064022510823223, 0.01676716530064662, 0.016159088756408424, 0.05896268104533515, 0.029204911101729642, 0.04284262829910844, 0.013278838521200082, 0.051225208331860846, 0.04678181793180205, 0.05336951907543887, 0.02255785729615919, 0.10701772561597248, 0.027206877186413736, 0.013825978516721198, 0.040322513124274637, 0.03521047735346421, 0.01948923082841981, 0.0785865403351284, 0.024298663784359253, 0.042186994931750724, 0.008452949996647096, 0.027955802825970516, 0.043478791541870565, 0.0871032623634223, 0.075113327512818, 0.02578544509296696, 0.02928054313205423, 0.05895303982880808, 0.07011847255090553, 0.003242076195273248, 0.03866438092964311, 0.03491667497362341, 0.007434470575272798, 0.020241521509183992, 0.026279945271990957, 0.02851097142293809, 0.08922386268574385, 0.07250687422891779, 0.049249034735464284, 0.041474368453266165, 0.04835611329443994, 0.04397684445364341, 0.026188989567960945, 0.02127046377638415, 0.05108286919552953, 0.017862113703402783, 0.042120379756294915, 0.02552000520330283, 0.05414651609176109, 0.02965670379419481, 0.10590473009694008, 0.05062598584880752, 0.0747783785505641, 0.030637621924641634, 0.019863740571083564, 0.04358342000012917, 0.007563790526135915, 0.024270366411656145, 0.06039223941643873, 0.07578820500883364, 0.02337976238660274, 0.012532810609216892, 0.018234171964708838, 0.014682023357900401, 0.01580050215125084, 0.07727521231337901, 0.04394600175381188, 0.04961835806288066, 0.03670678113497073, 0.041384946840304526, 0.018400269402791897, 0.05814811890764583, 0.013564610384374618, 0.012147600533470753, 0.027827394998542247, 0.03340474299846157, 0.014630927208570704, 0.019758127689842257, 0.034531964770247864, 0.049864632347899104, 0.031027397884416486, 0.03182760161918498, 0.04266332925087021, 0.01612436199080079, 0.030631701980206757, 0.01575518230487022, 0.048129753465013164, 0.0328835618922547, 0.029584706851070928, 0.09596723672603408, 0.06998049245486337, 0.027247497083378897, 0.03676496934325945, 0.013742816799710837, 0.03361256733056038, 0.023736924068221164, 0.06104540981111988, 0.021935221250920046, 0.03280710631741151, 0.018796700751408935, 0.034302896820008755, 0.05440413230849851, 0.00541963970341209, 0.012607640162440798, 0.021275709563445662, 0.033781842118309396, 0.08312428595438119, 0.06271661146573963, 0.042055338891523505, 0.05896521679636452, 0.06532253997941172, 0.07641265859767314, 0.08847043053397248, 0.026918525522154187, 0.05715374444280902, 0.05982036627228222, 0.018390697134178013, 0.00731537550417406, 0.04546374450587938, 0.05445936341739951, 0.07265740284515966, 0.038128969740242734, 0.016404160283385746, 0.033366308367300423, 0.010258770536541218, 0.023563918432280905, 0.041737021698105725, 0.14798710423131145, 0.12271491314975486, 0.06672176892959303, 0.08434547607095973, 0.022050618990174225, 0.07758995953706965, 0.03303118320482393, 0.03386497797985231, 0.07574774024467315, 0.015572493317567054, 0.03251494336572867, 0.04634204515886884, 0.06323399660628169, 0.06988359765420038, 0.045284058583239396, 0.028632884739988276, 0.09330923338570903, 0.11969272693198536, 0.06363835696491503, 0.045878489186326345, 0.06076045574680452, 0.061254789301704984, 0.025342328346244274, 0.044776149950320684, 0.10861429881544844, 0.11678097228850089, 0.08394860422178622, 0.03077349527889202, 0.01642292943753062, 0.10385885399075286, 0.039636550335994655, 0.09772394528432239, 0.06637850025248143, 0.027593774570813103, 0.07303573536656557, 0.03558054761660676, 0.047576055756860205, 0.06779422307567251, 0.05169899157819249, 0.02362858774440904, 0.10456341739383437, 0.048889168763473156, 0.025488407906865882, 0.04168788481864237, 0.013146751556515455, 0.03243500209083, 0.04112230508678383, 0.019584518759661627, 0.04289519725247257, 0.03580131500418629, 0.0781806516310861, 0.03228843797959628, 0.0465607785830094, 0.01510180889688913, 0.014656265566666282, 0.034655301095617395, 0.07686289613165202, 0.0335193803954509, 0.042772427832167, 0.03805038827140966, 0.07955099906652205, 0.04160571422788405, 0.020815093453312596, 0.017099865794842763, 0.057991404131415396, 0.04939526559845094, 0.027953960384512623, 0.09164316835062158, 0.024402208228205, 0.03619430661802331, 0.005121454343034496, 0.027963559466203856, 0.02278321929606459, 0.036532672332419504, 0.10000473459161098, 0.050207701842150385, 0.05285933899182466, 0.015953760913332865, 0.023653215555954846, 0.009962064683467392, 0.06202225235380954, 0.009925760734345644, 0.03531219084717093, 0.04579285204771065, 0.08229702590934693, 0.025267196188290274, 0.028089937160632787, 0.10590360394769138, 0.03613324941045815, 0.03744794438863474, 0.0394041077684491, 0.10140807743394568, 0.03575802720602482, 0.03503259939832553, 0.04695356335310687, 0.010148475900472654, 0.01782463476692717, 0.060803329857486876, 0.030896314494912664, 0.02350168719497179, 0.05319767789314351, 0.13956864064018573, 0.08804230229748834, 0.12754554184333933, 0.2043327944533479, 0.08173585884393224, 0.04742756493449692, 0.20993311168445697, 0.17676113684090877, 0.15146252338684377, 0.09161182769363926, 0.1508662618336178, 0.07441879220066533, 0.13818281822867934, 0.17724315936286605, 0.1368032011293596, 0.17848400729558161, 0.21626697342482307, 0.07966264872060669, 0.20112357552974455, 0.11813430491113856, 0.16586129914128012, 0.11964153693688494, 0.21803896543720078, 0.17739669870465033, 0.08732050191611053, 0.10790023592210586, 0.13182179101051825, 0.12596903248660027, 0.11270957503227458, 0.18046207695959077, 0.19322026010242202, 0.11773103622779732, 0.12000928978405653, 0.11886959610086296, 0.1580482595149548, 0.14489428470692328, 0.14233253265340484, 0.25769031276145293, 0.18278295564795696, 0.12529612383655003, 0.23591093869218904, 0.17578095798530888, 0.12541681332814117, 0.1812345080918843, 0.15901112478346596, 0.11792543869946273, 0.12759842489275242, 0.04562001112067411, 0.1923286716543859, 0.13940883469918083, 0.15665425528441707, 0.13469609161538465, 0.11819418234330033, 0.15954712586056802, 0.23253239901556125, 0.12545158605902426, 0.12652532723281654, 0.15429052163756665, 0.1893253465213122, 0.21430713665341178, 0.19196677171895582, 0.1801899931724033, 0.18595288958280318, 0.20628359138725266, 0.15290304447614378, 0.09118752989677653, 0.17319404760435705, 0.11748791822502691, 0.16307658485827908, 0.175822357376737, 0.22014861836308436, 0.1719544560558373, 0.20367115495666382, 0.17445285263801777, 0.15076899931075113, 0.15716531253870458, 0.29145634282500515, 0.11797703472116303, 0.2325849526471669, 0.07767934667607469, 0.2337613112984165, 0.08634258301988726, 0.2005349595340029, 0.24634312567931993, 0.16262191167521864, 0.17404930816302377, 0.19260487699460602, 0.2649117333273734, 0.15653404076733898, 0.12605943852254461, 0.14303903425893477, 0.24743069474014545, 0.2261547170459263, 0.16020985320210457, 0.19410720605763698, 0.2073756497233145, 0.20290822331463138, 0.2107197920521421, 0.19310675651556064, 0.3149367844866168, 0.2446728241780112, 0.09487936123003883, 0.179372102382683, 0.1463175534961685, 0.21996558463621527, 0.1541484429711296, 0.17802590203862037, 0.20485681391531424, 0.0823555626876412, 0.20265964310496085, 0.22019043144199157, 0.13283166343406325, 0.20876792259514335, 0.17254468083621996, 0.2152519528904269, 0.1678260388754068, 0.17643757194520968, 0.13695553005222352, 0.145340163200613, 0.21217404143704524, 0.07610428522551253, 0.14690255355690757, 0.12525788072736996, 0.10406529936458796, 0.1697825508252267, 0.19705086826316773, 0.13682370164221333, 0.12417608030861425, 0.10318848875261123, 0.13104422708913205, 0.15026477556074821, 0.13561417138384235, 0.08499029993770585, 0.14973090420807564, 0.13363181162745724, 0.18858127596397556, 0.12272410620484622, 0.10477171670044623, 0.13649842070956386, 0.28569297144009226, 0.16933871012541557, 0.18577849732771998, 0.11065347931317746, 0.1289527457688124, 0.13547877300410502, 0.13038704622416727, 0.12142179503796563, 0.17112107496828804, 0.17790338925776944, 0.1200648541412046, 0.17652276092238967, 0.10028043431380104, 0.2022835245776561, 0.10954350984144597, 0.09511104154009974, 0.14454948385396313, 0.058997461437097484, 0.13657702133059502, 0.1453063021143598, 0.20521889771184615, 0.1692751248277003, 0.1389635997193475, 0.15635137476267355, 0.1874013933082742, 0.14210626092408934, 0.12878094289091327, 0.14946810540653047, 0.10583164530896372, 0.12280749487540416, 0.1317972149099073, 0.15194816184380364, 0.16453069634735584, 0.09395731312613334, 0.11429331625901884, 0.1581000010933607, 0.1568732185349349], [0.010020343864697122, 0.00891756029769538, 0.03352047973162225, 0.04083425602725437, 0.03132532181728992, 0.012020845540739115, 0.03410358755518833, 0.2063597864922016, 0.05014233155957153, 0.01702889540953742, 0.08595280514489259, 0.029532203015180367, 0.028633589540878614, 0.006784834718752292, 0.027180106243899754, 0.024348817645542087, 0.05012271587827033, 0.030654043019298586, 0.03864318710721789, 0.024714613138067148, 0.0653375706244861, 0.04135407349695602, 0.015725479160826054, 0.018324650779005983, 0.031345797432286125, 0.032302717858504866, 0.019429841777309775, 0.008171351397440078, 0.04815594218070469, 0.04084405046136629, 0.05462694515083587, 0.07388349592445359, 0.011576157356161746, 0.02832187219492851, 0.024874909375343594, 0.019749509200694102, 0.04097543070994077, 0.08095668613790505, 0.020429714838223114, 0.018112069040897395, 0.02083955464073487, 0.07452845768702608, 0.0598754862984342, 0.058250675098069256, 0.034792427003623984, 0.02593703091054434, 0.053145844384186694, 0.0055800934675179666, 0.045046218926267284, 0.027409988162558407, 0.04134033754047367, 0.04287726313416516, 0.02578505630334539, 0.0844827437052323, 0.056283453239067915, 0.03258808944073897, 0.025197214056407253, 0.06768899323839335, 0.06316157448435984, 0.0626028320872255, 0.06022123710042047, 0.0309336363833638, 0.06612722341331743, 0.024175427050419876, 0.0748621579259634, 0.01369283913875059, 0.03136783778186768, 0.07684650951095166, 0.1733529648833698, 0.054569404286843155, 0.07362800560170606, 0.08074571318443745, 0.006048335025327341, 0.02964872881890305, 0.06329500401813178, 0.12823397909561474, 0.21005432211583663, 0.12379423910451513, 0.06731699626412123, 0.045788316807198914, 0.029268722395382585, 0.009800965011480355, 0.03362983878281328, 0.03187089516300588, 0.044745245963455214, 0.03966627837789636, 0.004756620290854405, 0.10496348382965212, 0.020588417612617056, 0.07730535787319945, 0.0909065748114259, 0.05959037135565474, 0.09804937943455674, 0.10298071038578788, 0.0447481073018524, 0.06823757347921211, 0.03269241529426748, 0.1067162853395266, 0.007308410807332445, 0.2292831596587935, 0.051923953297157446, 0.12931649963701927, 0.10071734191789743, 0.07671740071307268, 0.0750508453817137, 0.05411324106276997, 0.06845583958971886, 0.06689398549497128, 0.029292158940206134, 0.08429741171459038, 0.07085174126850982, 0.048446446552031466, 0.055536364295309594, 0.03672330182105784, 0.042503994453938744, 0.10446071564670532, 0.015844147137907005, 0.022199937187495734, 0.08288416335539472, 0.01572782147465454, 0.061342966021789666, 0.08925901846058908, 0.008780414279880784, 0.03977093747967193, 0.0526573216061919, 0.010172012994336265, 0.08272597385991005, 0.0542171034331043, 0.02315900457512227, 0.041330156231959986, 0.02025159173494866, 0.03220602990158143, 0.030068433918659727, 0.04287146384857836, 0.03750552355702366, 0.01719244943571187, 0.02577909996973411, 0.06716870462461826, 0.0989614530736881, 0.023767104101998192, 0.02239082140036889, 0.06941124316184752, 0.0492179315657385, 0.04011656953802994, 0.011300538073203737, 0.024726441535618038, 0.031154882575896, 0.06758487422860439, 0.025405000084109848, 0.025922078789482196, 0.02098044012522986, 0.04685497549813121, 0.017816339949927023, 0.018395330050900098, 0.0423018736464362, 0.08004313394907983, 0.08215005960195296, 0.06976860785676588, 0.04371162864469713, 0.06206452891591096, 0.09823933859626133, 0.036014747099890825, 0.06904166702541613, 0.025140561854406714, 0.041854612364043156, 0.026240438117735812, 0.02753733687343136, 0.046857947919277415, 0.02517729193993634, 0.02055122787433286, 0.03247524085905283, 0.028464284109612627, 0.04580531246779908, 0.015905801894053096, 0.024488144141111164, 0.06727956520814089, 0.016595006191862688, 0.050902731281014225, 0.05147661540597197, 0.02531560911466518, 0.021531655708508148, 0.018199699923336025, 0.045574785120064215, 0.0632381143288747, 0.06884139632025073, 0.034975575643681714, 0.0371844714297162, 0.028868686603081804, 0.06515379379233045, 0.01258371523656552, 0.027999111691549904, 0.031863255351180994, 0.05207119156576453, 0.059641749042296605, 0.01991059833897218, 0.031171508599072698, 0.04921819586607237, 0.06357499766313741, 0.03753694848367765, 0.03142488643436903, 0.04476569668059388, 0.01777467817338484, 0.024238682930327715, 0.02524302994471885, 0.05414118028936848, 0.0201858269170888, 0.03460627529890307, 0.012928576418949712, 0.05715446839589746, 0.01585745504276166, 0.015625345723463163, 0.02727490004843041, 0.033120765696249665, 0.08254291715040322, 0.047009008966626666, 0.040057760798522545, 0.014269130695010386, 0.08103272802526913, 0.026282084572519508, 0.02406642997577306, 0.056433142989032695, 0.07480018907376836, 0.020296679839732188, 0.05762568141724314, 0.006948210629484346, 0.12411617223293551, 0.02915784265966185, 0.05080646467244914, 0.03891679923981428, 0.047617003156413, 0.05410457660834636, 0.058687494602054364, 0.0258657751574872, 0.033601110485652765, 0.030093144084657394, 0.027826274594952984, 0.03966041780527561, 0.014780718465185454, 0.04780395159257516, 0.055454618883349245, 0.10262512301485385, 0.0030401165056372845, 0.052670406387938615, 0.04237277125338874, 0.11529181993776753, 0.03289734764445213, 0.13186746517256384, 0.03906506023580029, 0.0600031127161797, 0.025645515303157514, 0.04533075164222429, 0.12713220676467304, 0.251646920918457, 0.04746505344707159, 0.0571375799876067, 0.05525480017005917, 0.09219390895938681, 0.03711336314858448, 0.015554757424510054, 0.009561034892084859, 0.06198460296277077, 0.006139236624397699, 0.019352424762121612, 0.15904417381651942, 0.03767281800748841, 0.05901942134744698, 0.050783187090869875, 0.10713075422832083, 0.09887739790663605, 0.10659699778883688, 0.07165920560158069, 0.08429047861887563, 0.10347084577886329, 0.07935735502190168, 0.08230084102720985, 0.18773994288377224, 0.07160998445244567, 0.14134309945567963, 0.06728537215460693, 0.023503209794721296, 0.020864236078435378, 0.04074489953176629, 0.0832193574657844, 0.07391099848093526, 0.03752464128117408, 0.05139130002428448, 0.09877382281927333, 0.04110039497214941, 0.07083294913172722, 0.021651943003939047, 0.051851354975013, 0.05538428435102106, 0.06041858134971512, 0.07014247408557324, 0.024785399662270665, 0.025350094562576666, 0.03819270059466362, 0.016742730926301692, 0.024226670671674996, 0.031081882057591315, 0.02362091728906718, 0.10061978828161956, 0.003782786797889839, 0.033909866901775526, 0.04492663643172672, 0.0352207659142873, 0.05676124695568316, 0.04968351767128033, 0.04172379519009302, 0.019545567019151586, 0.02312576402008774, 0.059895186249407074, 0.02315387178602959, 0.028420481117322084, 0.04276580117162197, 0.01931296931880136, 0.0365678932247383, 0.049360263041190566, 0.05899487205991342, 0.022571219784778454, 0.11974169527210536, 0.010203187027195049, 0.008227249960445108, 0.061557853684550336, 0.018737867114044005, 0.01433237125315974, 0.04079525449102925, 0.05389769839483404, 0.03913538710724923, 0.06656749414340143, 0.01504709489733702, 0.040025604257900874, 0.020841718839120962, 0.0393145329379026, 0.03566685891259582, 0.051432971376925714, 0.02045322416139947, 0.045115929096937187, 0.022051919424425692, 0.025600840885853095, 0.0955429695726883, 0.028968965597150308, 0.0514328794463748, 0.10265077163855876, 0.019833589265603694, 0.03597361200879659, 0.05278809281486658, 0.0081149251913772, 0.048294163594442996, 0.048006382665687033, 0.035147072086411144, 0.025622243467237682, 0.07962658130113157, 0.11759052804160504, 0.09247694780389148, 0.19313724681494698, 0.13553466677906054, 0.12732002088018965, 0.18372384951479975, 0.2354037578427984, 0.14211940699287, 0.09199088799857325, 0.21624019099099023, 0.060704427906462265, 0.10591869587979971, 0.15221868281162557, 0.09637805903630872, 0.16997228016055402, 0.227242638507197, 0.18136739370323, 0.14551781899025365, 0.10770473794470872, 0.14118635786637185, 0.12527753088262775, 0.08244704124667952, 0.17354094753822974, 0.17343657571942578, 0.150810643850315, 0.2402825887885786, 0.10925007518380882, 0.12973443124323122, 0.10763480177810116, 0.1765659529595606, 0.17758121864209253, 0.17157326602647383, 0.1740558045886217, 0.11135959021386602, 0.16711106433743433, 0.1701984446375601, 0.20465479652968147, 0.1644897412869238, 0.09030645217506156, 0.12043763252515947, 0.2127332703000115, 0.0838666098312505, 0.13259720988571644, 0.16581849014807135, 0.12000883013130197, 0.09060061461622677, 0.10824983248547201, 0.1077549013819906, 0.16780575286717186, 0.12065353908485944, 0.16508522143046703, 0.07632210700502319, 0.18747533611472578, 0.20886786642574498, 0.23598005514471765, 0.13498351248281618, 0.2218754111879295, 0.15957783066457318, 0.13496489654625618, 0.1988024670150011, 0.12890273554911538, 0.15054536292389517, 0.1986406232801176, 0.21087497082208434, 0.08060499049362638, 0.25937055808401877, 0.12894182135501217, 0.3696111619712845, 0.1615188982818396, 0.21787194294794915, 0.2527837034675383, 0.12465149915266423, 0.16914515035046687, 0.18420778725656772, 0.2572358694047697, 0.38451037700137786, 0.3253950491066902, 0.0902192100822445, 0.12237961178705578, 0.14557890684133576, 0.12601345026445004, 0.18078394114009796, 0.10748227367237692, 0.11356827532572132, 0.1325732006901695, 0.14753993870990892, 0.2685865958131129, 0.09754687938238345, 0.2535758537030028, 0.17633226549913808, 0.17145207091685266, 0.33428795094932284, 0.23365842569018566, 0.1987508480106631, 0.17767112672088609, 0.2669695987095756, 0.31724059473603006, 0.1715234856331541, 0.29387696616111264, 0.16565532874195807, 0.33429864553674576, 0.21110496573871185, 0.14498298236679646, 0.109094436761112, 0.192185903508817, 0.19664874871171292, 0.16180599739234294, 0.10948176315474896, 0.1866461072237261, 0.22890589199960235, 0.24628736980019078, 0.15568136958585632, 0.1969589377122541, 0.17119524760111687, 0.19829194602226058, 0.09967044446497195, 0.10491666819659934, 0.1892578694969416, 0.16697166697873225, 0.2024697452302902, 0.3410378290760902, 0.0597254901132997, 0.14160635790997936, 0.14451088834433787, 0.15006157839971204, 0.17723422677766892, 0.1562986066264491, 0.10232925219761749, 0.23138187284911835, 0.18842585204589754, 0.11660378381249406, 0.20924807586256536, 0.09707686145819965, 0.09858427734504785, 0.09385809707905977, 0.0795900772115396, 0.14196622005153087, 0.16805301540561263, 0.16683462917083697, 0.09687827614646766, 0.21262992503902606, 0.12651760506653978, 0.17999511572622484, 0.12604304424096502, 0.128846182938545, 0.18383566770822773, 0.2501091373062903, 0.13737223591775666, 0.12939039647819536, 0.14540859017400973, 0.19305789542775, 0.16664195805788043, 0.1553401387026233, 0.173006187523565, 0.16477881690427182, 0.17780338414013389, 0.14315426920450505, 0.18843293069831787, 0.15030923930387344, 0.1547381468117237, 0.19135057655794008, 0.12363237238699391, 0.11928358235426488, 0.17114493094625013, 0.09883392241693313, 0.09618678220337439, 0.20537723276403644, 0.13313333353688642, 0.09628004574727628, 0.07360559752992085, 0.11308193972875034, 0.11379437851569346, 0.2291298501433865, 0.1778121941512631, 0.12295044688207489], [0.017862638473630916, 0.023750378487391338, 0.030953292284281026, 0.033614444245974866, 0.05635616264396137, 0.05725207948876966, 0.045454880868595456, 0.03802796487786597, 0.029415050934579585, 0.044526129495352514, 0.052971390842069546, 0.03657959521778169, 0.01229687372312671, 0.023712834433442163, 0.008093942043131158, 0.012535697803081525, 0.026836079139743122, 0.026902814974047007, 0.06174755237636067, 0.03041057644652263, 0.09787438197001334, 0.06401481640134608, 0.010481740426903051, 0.02340346323176017, 0.02424632082693279, 0.03794404760664029, 0.04931719740852714, 0.04983917141573564, 0.015380341229179214, 0.03242696965894392, 0.06717904681159605, 0.036577905993908644, 0.023382610318461255, 0.003733030105415251, 0.011808728243434622, 0.08038017433136702, 0.021045157317853263, 0.1391324761413759, 0.06515632954335983, 0.03750077764233274, 0.018587277210768194, 0.054225806191924124, 0.056945939262908314, 0.037952945717880805, 0.08106494202248513, 0.0285844411700964, 0.03014644082154959, 0.03235506081593133, 0.02799888186517262, 0.024855791651193174, 0.00580846667177074, 0.05113399790359601, 0.0252203633182592, 0.018329565233040242, 0.06253368499117994, 0.04120559799635122, 0.02322452999050579, 0.027610490609320904, 0.07500352413063088, 0.006074599392201391, 0.08189253914620608, 0.0902991590180224, 0.037373499794592785, 0.050110853006762844, 0.0452070820686077, 0.07909409656760194, 0.060505459550768144, 0.04339608468956525, 0.06481031061060007, 0.07475410888512289, 0.02241426752129149, 0.025202097866924542, 0.09721699426130903, 0.029457034468049967, 0.15825389283559016, 0.1022645024462573, 0.12599396098765636, 0.0678548589348793, 0.03485616934936374, 0.06518824476628535, 0.015345975482505898, 0.06453022886548312, 0.05027864158393876, 0.1004986851025493, 0.03292034943437865, 0.01726586364149567, 0.059349792934353315, 0.03813469624747673, 0.03137847682791612, 0.04231347221760981, 0.062337409434539665, 0.14755378957957993, 0.30286357587864327, 0.11628984864200316, 0.18417921217699207, 0.01923791760007941, 0.10588969179098645, 0.04490679858492748, 0.027138450213017005, 0.14513123570190323, 0.15670331555508799, 0.11444114824576725, 0.15229426504623506, 0.03271857336644204, 0.0511433020414364, 0.04427768335106873, 0.07890066702760036, 0.03695595123234295, 0.02913118279989689, 0.0758193005176802, 0.08129720455936848, 0.038247901060047655, 0.037180610346577825, 0.01779717817572096, 0.05419717748619376, 0.030242418231923255, 0.057049590959063465, 0.013031339453112696, 0.013756603509518168, 0.03827400550606751, 0.07822336103286474, 0.06948739996240025, 0.027250498232822266, 0.030926354717643514, 0.015322110886054655, 0.022417278246833913, 0.04864693176181567, 0.026711653054301298, 0.018917683271631118, 0.04054986886800297, 0.013687105928247255, 0.03398163401852212, 0.026711513243255117, 0.013912142340784833, 0.0486870632777291, 0.07613194099957905, 0.0573556392543739, 0.05410829596521874, 0.008054957743884336, 0.023105401403060364, 0.018712816038920034, 0.061128204763536496, 0.03645457349897873, 0.04462642572639931, 0.06765016024151156, 0.030656680276977922, 0.02026303708853741, 0.06309269934952741, 0.03292804095713842, 0.07120151403209857, 0.022681750950493643, 0.05701269999506974, 0.019666323543436105, 0.04212653527276651, 0.038984946591118654, 0.003926486697896654, 0.02413438772031617, 0.004430613968701613, 0.05081889827946021, 0.020951690760651426, 0.03515020155558183, 0.016178486102651206, 0.03603001906266136, 0.026942341280500257, 0.1014168874450749, 0.022554701013911157, 0.04365792588120507, 0.05390259369667019, 0.05595844043719192, 0.037210353710238016, 0.019580611711247795, 0.05693262848522394, 0.025076537971354784, 0.043160091304490646, 0.03562476238115661, 0.021706580394698728, 0.02251645024385183, 0.01715568296100584, 0.047145832269903154, 0.025904460682443557, 0.05254311321844017, 0.008976077923791544, 0.024776354079104723, 0.03713667903455996, 0.006364934745379874, 0.028431420852880807, 0.031325461628336104, 0.04474549877247022, 0.014060983648373476, 0.06224244900588548, 0.06137408834371356, 0.04682588330920666, 0.038197354578803626, 0.025650190354715434, 0.042321278653558225, 0.04292312115731259, 0.05105326372769572, 0.058603178965108055, 0.031848343449734876, 0.0884237221532291, 0.08537574175504908, 0.0075438842102284395, 0.03605565236460778, 0.012983699317931408, 0.025940870926264795, 0.029382674143679684, 0.06268114925572468, 0.008196562393418243, 0.0633219626521872, 0.026186057366430763, 0.0608447484011131, 0.034566419574642376, 0.053422126333199205, 0.05161214785109605, 0.04687118974904861, 0.0634793860597476, 0.04196816957705925, 0.04050922407318027, 0.05074297896616402, 0.03391938171379509, 0.0687350633163606, 0.038174559632616664, 0.021096682476420558, 0.028949280967935923, 0.009499541014402865, 0.05895400509959268, 0.01615505913392671, 0.022979847253150037, 0.02877271876880719, 0.04479276639739833, 0.022839340982177568, 0.048061150291393843, 0.07828564398110875, 0.013328217675969487, 0.029426379459759885, 0.03568979175460916, 0.05143909241944071, 0.03886969249335028, 0.042771271039401336, 0.11811289275365493, 0.061569027076925964, 0.0527666385225471, 0.07144251763219796, 0.043308156948055954, 0.14484946856335287, 0.09143034146437723, 0.15782986316950093, 0.023573266620176937, 0.03711237489516216, 0.03681236337269506, 0.08664331083456356, 0.14014115346775902, 0.16024179906854708, 0.1490106589851841, 0.11261693201959135, 0.04004910400497817, 0.040951118909663735, 0.12249658575221417, 0.0916929793874583, 0.03616014675747964, 0.07262466024727592, 0.026400617526603803, 0.08780574200734978, 0.019235460373062282, 0.07964198732928884, 0.05112664345952292, 0.06241615944271607, 0.16259460830159728, 0.3557403740142623, 0.09340548467251564, 0.12818036060179436, 0.07534458647452055, 0.1202776350621735, 0.08098336898030774, 0.025291310720926812, 0.18009124443896357, 0.25512528185161854, 0.2030137289435633, 0.06406523264764298, 0.04661335519725277, 0.02872620191004488, 0.11771454235478757, 0.014990414924649222, 0.05693728246936395, 0.05592832169044883, 0.03876563860103488, 0.0886415669153775, 0.06714933792189245, 0.02683009024739506, 0.017254213359387174, 0.009105279609831351, 0.0718893307531553, 0.0542116986827985, 0.037788792227905606, 0.02968989263829445, 0.001585812656670779, 0.043793209347753756, 0.01239221432291332, 0.05181301993528201, 0.04378230408615163, 0.007101967348717154, 0.01478085348818211, 0.04582198254103142, 0.0561654718682891, 0.024998621083796028, 0.042827356336337906, 0.01826742018062261, 0.0435090252018023, 0.05967283689026391, 0.02065529325796712, 0.049628451271283056, 0.03627658063065141, 0.024311809853139906, 0.06494344137008153, 0.03895636002022413, 0.02818732608800694, 0.01854244383021949, 0.055737324479606845, 0.03285722761985756, 0.04654883910270949, 0.08124068259231507, 0.030734890193167715, 0.02256448395670422, 0.09656187417286058, 0.028306263153471296, 0.04247706263296066, 0.0431915813486182, 0.007050248274144026, 0.028140577487647537, 0.03732037925792318, 0.043437591333302765, 0.02627419578211923, 0.02091515985798211, 0.004057051302234252, 0.07658903502048024, 0.03278719569225946, 0.04379864091113691, 0.034453172627235615, 0.0741946425349001, 0.042876550672395576, 0.07861294738587835, 0.037954313184825644, 0.025456730171196887, 0.02215791343440933, 0.03195272675985771, 0.00881240323876902, 0.011406663275744406, 0.07481961706352812, 0.005936459854109994, 0.030453395015830477, 0.017618513065240076, 0.02665891364637402, 0.19129806889160988, 0.13973770092331594, 0.09903116707479763, 0.1000583224419144, 0.19620538298641482, 0.16807169262920657, 0.1367982981666442, 0.15194679820729842, 0.10222455096100608, 0.12667253102746703, 0.15979498594758973, 0.18445511108204243, 0.15359342759174688, 0.15830624728433548, 0.13970425352454185, 0.13266246525510667, 0.058250058397290215, 0.18707286416282579, 0.16994293899305407, 0.17064194825868453, 0.15055932104587555, 0.15241824871590062, 0.0991082125373425, 0.20314819269603301, 0.14031746094265293, 0.0796586420807627, 0.18980868671449924, 0.15309802917463167, 0.0870743042398845, 0.2023797758644627, 0.18208909449317764, 0.15067570512333225, 0.16190960312322264, 0.13804522883747855, 0.11386996841118222, 0.1524516961146747, 0.11833679727128438, 0.2904583141207695, 0.3708964123600914, 0.15359695159619854, 0.09866661647514952, 0.16685816339187085, 0.15666861177211808, 0.1926499382863122, 0.1830614286084329, 0.12687205862734588, 0.08603723569502754, 0.1603367326841239, 0.07071369988543373, 0.14164717507458505, 0.12572352428950612, 0.18036011065686905, 0.13567466168634354, 0.08058389243219169, 0.20202889227338378, 0.140498916528398, 0.25852562439057136, 0.14254323747609893, 0.2388340544195906, 0.11093450334644127, 0.1561773349080355, 0.23002652541523982, 0.19263101591458245, 0.1764177302679708, 0.14057906464703623, 0.13331397706943174, 0.2102417225438741, 0.1470834269158302, 0.32260100387277146, 0.22881972242987927, 0.1949985800010543, 0.19862504105173773, 0.20029313621982453, 0.1719589146875566, 0.3572363598692802, 0.21702414408566492, 0.24259884030588214, 0.16006484807979676, 0.2676211105239007, 0.15119773275669546, 0.14939290621588308, 0.26650243829334935, 0.36168929189443594, 0.28702789496990944, 0.14919839649190828, 0.118108005112698, 0.23945227205272646, 0.17201395044403692, 0.15941572645979543, 0.08395570585684431, 0.18200465628216345, 0.28299508556242914, 0.518288204987203, 0.16191029260235448, 0.2496947756698055, 0.20719566502638403, 0.34634121062774814, 0.14000940166654127, 0.18342807828899355, 0.3044407976971519, 0.3025177025025891, 0.27706967125977244, 0.18978927404649798, 0.09584002016532807, 0.13635522355475735, 0.17308564616307137, 0.22331962482102458, 0.2699673007572851, 0.11954609004239883, 0.20523527667166727, 0.163193260049147, 0.11655873018166713, 0.20046345288715056, 0.09446892196372633, 0.09510412376614348, 0.16586143703710649, 0.14523344715276074, 0.12485160131848629, 0.07718708921944903, 0.1859352235952693, 0.1469371347658096, 0.22983822100345166, 0.12840554448625735, 0.11940368961903358, 0.1253435829834592, 0.10023870550456548, 0.1527311956329692, 0.13738787943317046, 0.07087543636800782, 0.14749026556889858, 0.17133770931151607, 0.12575032204509745, 0.16237988917817994, 0.14253733859908196, 0.12949683673439488, 0.20061532215725994, 0.09611004317599921, 0.16033369897594377, 0.09686332977106495, 0.19210377888333416, 0.09875189738288041, 0.2082428459318415, 0.11770013224093184, 0.1257700717917854, 0.19961599110355302, 0.1387603565930359, 0.14817991324009436, 0.16449331125665098, 0.18981476945261802, 0.19582399377419105, 0.08105614733311438, 0.09259886303616148, 0.09643857232144765, 0.20616221241652968, 0.16932669786676285, 0.1471892543016903, 0.15340814156638038, 0.08426924266161458, 0.20265345311453267, 0.12159230322727274, 0.14729258424091726, 0.12818080493279044, 0.18444116828182053, 0.08632780518382789, 0.18884680203853116, 0.14586759941472163, 0.17712626966737932, 0.14388070441782475, 0.1569424269180144, 0.1592580962084955, 0.10203708158505541, 0.16915457323193553, 0.14773581207038897, 0.0965269405635134, 0.1513571709754967, 0.11859660832992486], [0.03215072601432762, 0.01337996308481501, 0.020439380952607722, 0.03840448177089134, 0.06933278043664272, 0.10680312906662304, 0.04997795973453791, 0.020626543893388683, 0.03714634323372476, 0.02265445715297134, 0.01843029621898407, 0.04730593315475891, 0.11558755285917752, 0.058597222631496776, 0.055677561960633726, 0.009423781621960864, 0.059839139256866715, 0.050928529291864366, 0.00762351809234749, 0.04842646314852661, 0.06954473398265339, 0.0293408514886734, 0.024698238008685654, 0.030501815603084625, 0.0409291896428312, 0.04098524812669043, 0.051307286992068254, 0.05515955245843338, 0.05860389908775688, 0.06326396596587955, 0.0322207004853314, 0.06621427398415343, 0.07112117439147926, 0.004038809312342276, 0.010729137988340472, 0.07808584058957715, 0.015399677288388054, 0.04538703612202118, 0.059697301908125805, 0.03667704543218978, 0.026227073713896737, 0.057552443411681926, 0.09623630212679987, 0.02372740734098179, 0.04561641050743, 0.03751382028924362, 0.02547777460647687, 0.049861077699930444, 0.05089616207706352, 0.04947523368642696, 0.051890383324315476, 0.05782944931378288, 0.0035519494239481227, 0.04695166345505465, 0.04550080783965607, 0.06054617329350403, 0.049431850127274954, 0.015219172609278993, 0.06510965946701265, 0.021427749288118175, 0.08837876811383233, 0.06878964708096559, 0.1076737879925678, 0.04518297711207021, 0.049054505859291365, 0.15479440830888289, 0.09723172613209295, 0.12566724747058847, 0.13093931900878109, 0.10156487264940817, 0.05942846250329768, 0.05096657321818414, 0.1979892340398604, 0.3319087576481604, 0.3317582060492808, 0.4252818214797205, 0.27513140752430887, 0.05601284034069508, 0.9492695980495023, 0.8024809004799013, 0.38944058180336033, 1.6123092583110257, 2.18286273940917, 2.8760222802239084, 1.7956681741822151, 1.7422747876374953, 0.9232993399904621, 0.7436729883474689, 0.7098950685993318, 0.7864024922732384, 0.7070656301033112, 0.014590148348361255, 0.23707136271461365, 0.11094194972106527, 0.07362111081038752, 0.2864285997085033, 0.5406677170145897, 0.3953535241946098, 0.07262145033887318, 0.031148840057393237, 0.14743446372449398, 0.07275304892250607, 0.0308901283349241, 0.02923700060965794, 0.01871105020625457, 0.1715409064725522, 0.1562576209225001, 0.11698150346356055, 0.08075952574971222, 0.11001794809295286, 0.05116673667104014, 0.02464210483125381, 0.060496281817435264, 0.08115251353310962, 0.03455114761187184, 0.039058138631404414, 0.05573926268205528, 0.0061874178091755085, 0.057388561882919846, 0.02939692529429111, 0.12149542374836823, 0.049926831026471434, 0.06596174842167286, 0.052786315490882245, 0.050639020834839156, 0.01818850737876229, 0.08093777142705456, 0.033005955929477374, 0.0286581598958301, 0.03853491590087933, 0.032120779637367494, 0.044270378702710715, 0.0025395958331383525, 0.03532628686497769, 0.04461377761476944, 0.061965343512354366, 0.025939193193710623, 0.00907045133757375, 0.034668918308471484, 0.017498869283665574, 0.06593744045183544, 0.011800149973902491, 0.08724799935495661, 0.015176355955190958, 0.04691675282834519, 0.05911598289986292, 0.024726433874738794, 0.08879424057780735, 0.07249145287900202, 0.028740064271034736, 0.03251115889138272, 0.08509058084699415, 0.02013788130434771, 0.04113606785634353, 0.017912577830194946, 0.04424516674912265, 0.12852270231251756, 0.049176723696291454, 0.0214322098350573, 0.051320276012824434, 0.030850035123406883, 0.04346890517720773, 0.06164209271270422, 0.014495011719484484, 0.020589472898732752, 0.02538559316176801, 0.08510391077687664, 0.0568348297008103, 0.04223507844031819, 0.032268787824338487, 0.10357412209193553, 0.01324162963071778, 0.012203004969764623, 0.05990919416710254, 0.1042570052067599, 0.015348677857658796, 0.04915515449078334, 0.050815489188197165, 0.0196753250765464, 0.10349043464708714, 0.04892304134104521, 0.07130731077444169, 0.04344560844343036, 0.03643617972791676, 0.0691639729625275, 0.02029013936407864, 0.037217022505618876, 0.04851121162515014, 0.04498423858275337, 0.09362648571691207, 0.01733603729535976, 0.04570287502100391, 0.02186019443005564, 0.05375267412032812, 0.01787937557955663, 0.016191369786317793, 0.03944944868224763, 0.03911806968972087, 0.022466765611522624, 0.01806559814741054, 0.06546417431485269, 0.06026659333597749, 0.02231001061567616, 0.011440029277676537, 0.05209040122046586, 0.06093587072926664, 0.0751151508020778, 0.052217104502262614, 0.022925127507938493, 0.031907971903321244, 0.08217958463055473, 0.0347327602456414, 0.03975680698790858, 0.039889129524629925, 0.0318848590306457, 0.03776295591265925, 0.08816475379130534, 0.016114739926471826, 0.1395603668906035, 0.024839420352251302, 0.05177863024836106, 0.06866139630156179, 0.04708916091570451, 0.06123843715496122, 0.07313171852259867, 0.017314035250174425, 0.06995691226855402, 0.05467797426747219, 0.027979287251289335, 0.05346623001500003, 0.05538519216521133, 0.08487447510443388, 0.08120685981045808, 0.041622418775072986, 0.060222137253731496, 0.04774995005479263, 0.12626780677706967, 0.094270168112651, 0.026626002509146932, 0.01409492996190825, 0.06857044634319122, 0.15559944414323376, 0.031940816007854964, 0.12201323789814789, 0.10918475086650542, 0.16954567643903917, 0.13239978902762936, 0.11572906462055062, 0.03698412794619799, 0.27637841480393566, 0.30153772282984953, 0.6397531614188225, 0.4127414218120037, 0.05191836468574982, 0.5925044128971716, 0.4645037152353795, 0.2901674765011957, 1.5450450225222496, 1.7119024045044378, 2.9864063570576334, 2.0001193905068986, 1.552499732182872, 0.9068691442089697, 0.7952540560114769, 1.3187381144492858, 1.0834112258688098, 1.0949827081734136, 0.0562247479214303, 0.2493049748121731, 0.047180727574854135, 0.02464582035768657, 0.2743428579020885, 0.6650934500559684, 0.3600686175688621, 0.015609206166118385, 0.1497652249470834, 0.15296410168370894, 0.08307092026957581, 0.024582001403154388, 0.03453770276880072, 0.00739703185841321, 0.07288410358371274, 0.19660387128110857, 0.17548207644253008, 0.15219782989832664, 0.08101480156784097, 0.035602986331908934, 0.04935952376634364, 0.09574393741786481, 0.03572543016484669, 0.04394234751441306, 0.07346479823031733, 0.04983674674745529, 0.03453130593463298, 0.07194338591709253, 0.09438518089272323, 0.029529680670689673, 0.024348995760984482, 0.06515445262794534, 0.03810069343495754, 0.008400018109128842, 0.0928725326253522, 0.042645268728055304, 0.03141791694947789, 0.014787057842758876, 0.04725300414007037, 0.08897303017757593, 0.044227347544003884, 0.021349213784560565, 0.012002208536761183, 0.05943412389305811, 0.08580065242225125, 0.0364893960255769, 0.03839844499804801, 0.0805898909006388, 0.017048359788473577, 0.015318702752401513, 0.009290823232262366, 0.025177665407799428, 0.046514928220741214, 0.042375479374201074, 0.05495133742149319, 0.017768901870435765, 0.018758149291839332, 0.12769823848840692, 0.08808805306832637, 0.05749400239437819, 0.08061822083207869, 0.07799266131534692, 0.05249469646162564, 0.06876109498402766, 0.012384424166333292, 0.06051538038938757, 0.05765033412664648, 0.022347897493971453, 0.016815034304595283, 0.020595563297730782, 0.03673228420197003, 0.04265397914775437, 0.0461697596455774, 0.049808512577005935, 0.04013737265561377, 0.029514150153244698, 0.043369601030022874, 0.032021109683198795, 0.06325650426949705, 0.0793314076239063, 0.04319658390276375, 0.024909952152219993, 0.02239410025668481, 0.026328980644804337, 0.035812212604909174, 0.1527122119742055, 0.19193174617905773, 0.09274127878128521, 0.17517433892334663, 0.20644094584689987, 0.34528238518584164, 0.1622416256296058, 0.10032788579983097, 0.19137480025810583, 0.084904957742941, 0.08627861467820984, 0.1244546068952449, 0.16117976647951912, 0.1656928976937648, 0.11492737659042883, 0.2459877681347632, 0.12248831200263194, 0.16136990950232552, 0.09969865182234396, 0.15211668586538685, 0.19287656241607284, 0.14635533695259403, 0.10389484480143556, 0.10932613239293137, 0.1210652577180055, 0.15876360177513094, 0.11987282654210446, 0.13056755186088626, 0.24653691528064592, 0.14283802810936205, 0.150485378239424, 0.18225594844308593, 0.13910353333959657, 0.10439310072650833, 0.16055983280943287, 0.15050793186791483, 0.13073314942659872, 0.31548505829226586, 0.1922115827760389, 0.163664955705885, 0.288785116807107, 0.11930603639132555, 0.2089854762438805, 0.1469555668412678, 0.11613647017868296, 0.08600267746876325, 0.1695928214898994, 0.1019114431654734, 0.14283156232728114, 0.14134821692301383, 0.2318526185568302, 0.24193648068654924, 0.17805596332876913, 0.13898056090599106, 0.2194205130780897, 0.18330587194331233, 0.3050608692630645, 0.10307984216318977, 0.14201673588925792, 0.17252500769832443, 0.2677445119667438, 0.13647215921551953, 0.12403381778107536, 0.21245577793207862, 0.15709411232702195, 0.4558805682726445, 0.17709761797901125, 0.30141257470653904, 0.20838555279037646, 0.3038422378801531, 0.31923266848729503, 0.16704845963226211, 0.471233184779844, 0.49101446364675805, 0.6042001853066107, 0.45802227431728, 0.3520552459503374, 0.1275301587978198, 1.8872822388525934, 1.8783147200461359, 1.3487880052097383, 3.56876261772648, 4.417489978574938, 5.642371168059688, 4.2573773572521825, 3.4153668101756804, 2.463111920702842, 2.3879534246460086, 2.7961186968511154, 2.411306726355707, 1.8080593092787651, 0.16445062483751005, 0.2802745847692413, 0.12776407608461957, 0.15292916807436174, 0.4973628504141685, 0.9933763442020264, 0.666703766872806, 0.15538895382515847, 0.2582977285548564, 0.20461459223541523, 0.2198049666420106, 0.1283584300789141, 0.09210566329138895, 0.12345329167381411, 0.2841998354321526, 0.24656775798047745, 0.3242740173253321, 0.22894770507850956, 0.2783843700683886, 0.1943379057751548, 0.12235179513452515, 0.2647757680425721, 0.22793260793532097, 0.15416941845849638, 0.1980272473226632, 0.15318563898965237, 0.08493456704121444, 0.12092744616130668, 0.20849894912492847, 0.16035757027566433, 0.21026275931827484, 0.163244909697002, 0.1438260363835481, 0.15051695638366286, 0.16026047629214105, 0.22522071797040202, 0.1583783055144933, 0.0929130356939089, 0.11422419214561103, 0.18367800681341082, 0.13963279284296498, 0.1131947921408761, 0.1299951922508978, 0.16294840302678848, 0.15507087411899723, 0.11960375348045943, 0.10641919644249064, 0.18252889024874858, 0.12627599625698022, 0.1867312962009061, 0.14574692524488897, 0.11546101045584488, 0.17794359355203568, 0.17421063095811876, 0.24004776751802814, 0.15521921938465488, 0.12641154019342316, 0.2747039917495943, 0.1168196137634016, 0.12875048323504387, 0.22815952317849283, 0.1525460321816706, 0.12190156526142552, 0.11039287152309572, 0.12433885100988612, 0.20353518967186252, 0.15286507715861644, 0.12589223217219114, 0.09880859555015642, 0.14070511675409733, 0.18314997305072125, 0.23677050466499022, 0.18848663346180994, 0.1859132828371179, 0.14303638359471676, 0.12028985416456578, 0.15012118004022107, 0.12555081742785631, 0.07519338370090531, 0.22503340947291545, 0.1705128471216848, 0.224908766967635, 0.16794199394362588, 0.20030940792733626, 0.07194428223996394], [0.04652635059169224, 0.05301663982531717, 0.025502911866492322, 0.03164018203894938, 0.015634022626815545, 0.0468734267257875, 0.011316691994697098, 0.06122464757232417, 0.08153607843503838, 0.04565620111421712, 0.005568345030394173, 0.044920863959217266, 0.04654436897967131, 0.057018863172420574, 0.03346326828543698, 0.028604522249811602, 0.027956201191691142, 0.03516695589848584, 0.09831449182163324, 0.035648645172196056, 0.03335088701738465, 0.045020409424098275, 0.059138954046272466, 0.03273304859777132, 0.030946435797358715, 0.020031519572160417, 0.017639042306390983, 0.04326713293971073, 0.009687791800036306, 0.018595470521118374, 0.06945173090864575, 0.02273790136490378, 0.0699300455650495, 0.027315134986213623, 0.06009228918100557, 0.015214769518934192, 0.10350964813222809, 0.06863240753450701, 0.03467870891214379, 0.06814752750459217, 0.04771640689502801, 0.064280147123481, 0.04787820083419642, 0.009596727886086991, 0.029155013880001444, 0.03402229030466369, 0.02251862976399641, 0.04949221785570826, 0.03949746324290191, 0.02868449416822724, 0.008325135887360141, 0.026522699382997332, 0.036634148338869695, 0.06733018829817734, 0.0440644312860264, 0.03195556320039736, 0.019690570226239584, 0.04138696165154538, 0.0825792603615311, 0.07298907295109765, 0.2923555461870086, 0.15092312087935789, 0.052342566721622026, 0.10171667297160435, 0.08607713355412407, 0.05909499209073763, 0.08735665360525732, 0.2423169199497469, 0.33921754288096584, 0.13275761337530229, 0.08598409983659945, 0.3245383176592089, 2.7652033105973275, 14.372121287930398, 27.013486931400916, 40.478456174173665, 55.98436209463305, 57.80545188534645, 89.00327036457678, 81.19750268997686, 92.60533978862148, 103.66406240770894, 107.34580301469373, 104.08079854903683, 116.73965207992063, 107.86622308915662, 96.92036274940737, 102.42107114484234, 99.7468932982414, 101.79999520701747, 103.85385021086663, 74.54361746388098, 52.10108618582449, 57.29599483551518, 42.5902053617662, 32.84421963076438, 22.57403854400881, 5.983383011433387, 0.24601058223314826, 0.08261588702519095, 0.26793919023006196, 0.6209895231070057, 0.20241377484654227, 0.04152863812182219, 0.07444978811808171, 0.11760423335457042, 0.19223133252272684, 0.13775083656993606, 0.010690697611519888, 0.10179084560443317, 0.08982030043919241, 0.05358802267320214, 0.09725880734021626, 0.06569386279631047, 0.038650522399092876, 0.04960464508903604, 0.036415790297812035, 0.07272643502801657, 0.07356950712780799, 0.018397863886709657, 0.03092856105086544, 0.05234312979624637, 0.047406872899662104, 0.06304330966104904, 0.05027235200208041, 0.010757890225748622, 0.023327880997150656, 0.06351633448033564, 0.14570561778401175, 0.0631663089077319, 0.10567172445477017, 0.04517877511980553, 0.040438705679750254, 0.024456506625058192, 0.017773770359194568, 0.036763069445207235, 0.00421063277885438, 0.039191219595170794, 0.026861294923770814, 0.12990413504021783, 0.05358080612495542, 0.010165792360391107, 0.021329465953092423, 0.010315569252857279, 0.028206631503698808, 0.01788857821074705, 0.042108474749951594, 0.037457271509112856, 0.01854105338063692, 0.06995203994935559, 0.008112273569549284, 0.0276355282779062, 0.003227087206229748, 0.03888520960425658, 0.03529123068156262, 0.02206969649470862, 0.057834792777054736, 0.0211397864134802, 0.033714158250199217, 0.012021412445803084, 0.04151893178782156, 0.04795339236396456, 0.015943864014961066, 0.0999335267190491, 0.03568473174386928, 0.02963092493554277, 0.0714400738117195, 0.005940952959785899, 0.05988091786181735, 0.04759301694350378, 0.03268156748925967, 0.014003491622485943, 0.0693454132265141, 0.02020526639816742, 0.05997444187561351, 0.06996050522091889, 0.0764969818954987, 0.025886620409906875, 0.06616414119038852, 0.05624994072282026, 0.06107893764912602, 0.025463299375147592, 0.043488053544875116, 0.054684252358011665, 0.09669264538153526, 0.09791461690779656, 0.025168125697922324, 0.022569716337227055, 0.01644806478232626, 0.0800869771609864, 0.041596708864334135, 0.03543734663136063, 0.023578887790321343, 0.02468041880356689, 0.06479927894449042, 0.017041903582491705, 0.015938288810092117, 0.05355021240369928, 0.0048273766503459025, 0.02642453096116022, 0.031135207522780668, 0.03304853509630888, 0.05064376291909045, 0.029094628914589846, 0.0411328234739842, 0.01748019972095086, 0.07584143279781265, 0.0067241959867157764, 0.04543248811856874, 0.06190740811308065, 0.013841519567875132, 0.04203919741895892, 0.06293945495159396, 0.09148802788507554, 0.027224242484437364, 0.0841957058817629, 0.05530225548652872, 0.062678950583382, 0.031502322601755305, 0.03488618850467667, 0.013681178322933136, 0.011339088575163437, 0.05708518340402553, 0.11336998878827981, 0.028756648159375595, 0.04825823790123386, 0.017024639791118044, 0.05310424580989827, 0.021978401796772115, 0.026778670425917354, 0.019230563156006318, 0.10331327681459727, 0.04167862281563782, 0.03954208786449125, 0.09308735134019967, 0.0713867387704311, 0.1687035772709116, 0.06510035915961189, 0.02158017205675283, 0.09058997365495852, 0.13151052948688308, 0.06812129665406481, 0.0616135789201625, 0.26003782066606707, 0.45930369426646545, 0.15566229399654175, 0.08935639589664437, 0.2144486330930264, 3.005789729856676, 15.890570802073325, 32.3643333296622, 45.19632616350728, 62.264257169538936, 69.07979503754648, 102.98308403261247, 97.10413363672073, 110.48735480154716, 126.12960230919623, 128.17877400305966, 126.42369377997615, 137.40552225420552, 132.88098981303554, 116.62849210923719, 123.9030610361407, 120.55290191404282, 122.4005030047509, 124.57378633560674, 90.74940758366739, 66.51170161462599, 71.19749053832024, 54.81986138128466, 42.019284771334746, 29.828654373845747, 8.974541810251052, 1.0712665872227762, 0.056728676727582375, 0.37373222470764195, 0.5360670219505987, 0.05904446859213133, 0.07289359541309458, 0.013361328953666794, 0.15346555219542596, 0.22341068203170455, 0.14726560262422408, 0.05845263885754732, 0.18773675595800723, 0.12109429245033573, 0.002337328511320295, 0.05164088380913581, 0.030707389551905856, 0.07496986988811724, 0.05103122720855379, 0.04611872286806184, 0.05990621025463747, 0.048502543340286905, 0.06671514992992725, 0.029902794218111425, 0.03778366326925255, 0.06007764924077257, 0.04219954728239006, 0.012178501647506512, 0.06275393143897096, 0.04923227273168103, 0.039984886684725364, 0.005919886978283044, 0.0352718984527934, 0.02961576022508164, 0.0564971266524686, 0.07053879435144125, 0.055264422234388134, 0.025146470307522727, 0.0491659410087572, 0.06959613082149337, 0.03620417766092766, 0.016577014616960963, 0.0819966504951158, 0.028960927419604796, 0.05132709419535053, 0.08441291479093414, 0.04788626007915986, 0.07998936223767458, 0.05791205274421842, 0.05858916338653334, 0.04228205495183507, 0.06932654448093907, 0.04954297118069184, 0.04274277639905772, 0.03996174316853285, 0.05885778445630305, 0.04571117175322387, 0.01709609281181568, 0.012197944001414844, 0.0224621441861194, 0.0827585402575712, 0.03522311780421484, 0.030306788769760923, 0.02608048662002529, 0.09017300731953114, 0.019937085828954176, 0.036872133552547426, 0.050339932448320815, 0.02967145673239664, 0.03342482216295696, 0.023972091993557352, 0.06072630737757972, 0.10730217406225782, 0.040286177574026014, 0.03912246320396662, 0.056975682626568505, 0.11116366322723129, 0.048670289782626976, 0.019504648347895955, 0.16251899542347079, 0.1408626091095709, 0.17963153039736135, 0.20047656831241426, 0.11990052828144644, 0.1428714295428607, 0.13275988099555816, 0.1774506006510027, 0.2937458119084758, 0.1957898415745266, 0.15677373435708786, 0.11555194509245696, 0.18864843123141797, 0.10543708704532155, 0.15225498005747795, 0.11295005003170622, 0.15543096608692603, 0.19474126638904696, 0.216098296185655, 0.17720048826548362, 0.09485140668168184, 0.12793756435595213, 0.13802756284994466, 0.14518332968075431, 0.17583570262837797, 0.0821668369274947, 0.11328676865706522, 0.111397136183035, 0.1450142693976241, 0.12153990281325196, 0.211529623596899, 0.09099123518793814, 0.13659674043376602, 0.14651984667345402, 0.18026108613177655, 0.18735067828768687, 0.17649899687497847, 0.17497233685947236, 0.11357949085293279, 0.20088837121523198, 0.09934756138752546, 0.2246736852271903, 0.20490235018153347, 0.17147776550583302, 0.11200153359001684, 0.10133343748748304, 0.19535885583008492, 0.18379515697879178, 0.08571188581446487, 0.14248973389546718, 0.14808110321962065, 0.11448445519612682, 0.15672637480160884, 0.21303241231268455, 0.11941302056995132, 0.28580243008271344, 0.13463750121093568, 0.19090215465234173, 0.23849818615182755, 0.19734656288018151, 0.47980043796762345, 0.16979168259328412, 0.2196553956356741, 0.3271155293670393, 0.31149070649858446, 0.17220708120974804, 0.30710381125250175, 0.499640828178775, 0.4675685878722899, 0.21385661566690092, 0.13858247097701798, 1.1278558474394584, 5.442578869481241, 22.631646394729618, 44.94412952853788, 62.232078044645256, 79.33444746078985, 90.12400134917229, 128.0373098004249, 122.56692917116227, 136.4647025446738, 148.96984623324488, 153.84084947647588, 151.20421655716436, 164.4402547036448, 154.0037847334339, 137.02682525880877, 145.98969213424192, 145.68186452311855, 146.17812279732, 142.5264903037779, 109.30482295251663, 80.10804084039505, 88.28399396711781, 67.4368553776895, 51.059508631306315, 36.59474880464616, 12.025632954412892, 1.6298345308150015, 0.13236762865656806, 0.36747745388457853, 0.7399919052277842, 0.3041505423044005, 0.2851933288958765, 0.16375875551133387, 0.34243468315370623, 0.4324196465313435, 0.45130708465172403, 0.17212032941320252, 0.2828605298794085, 0.3486532639832266, 0.18875068864755093, 0.3233675208062895, 0.2199358451029947, 0.14879241585731506, 0.15443915801663555, 0.16078386756200946, 0.12930094805215636, 0.2385909900429749, 0.16752360268465935, 0.08073302676841136, 0.15283262567414393, 0.2013640658509347, 0.16971283682411717, 0.1979936160627873, 0.13527435010239003, 0.1298863005133406, 0.1576883973734033, 0.18029271024129084, 0.12215022974076772, 0.15969082863340456, 0.14607272711732697, 0.1275656899557479, 0.09643299520135888, 0.07454810018140463, 0.15619627260152372, 0.304739878422791, 0.20933899517741897, 0.08996516000479461, 0.2171686589117012, 0.10447358592383324, 0.16978530874175413, 0.18804602565303927, 0.17264232640304875, 0.19763082746536503, 0.16874359770407601, 0.13636270057289832, 0.12820103731487067, 0.15520958199856744, 0.1486538765170882, 0.0770332204598573, 0.0939342002534578, 0.17361289851607817, 0.10269309799637526, 0.1564285044948901, 0.1382752697193815, 0.09342423850490202, 0.18010907896584083, 0.11390496330756335, 0.11113476639072742, 0.14985312587551533, 0.18585348201374854, 0.176378138844044, 0.17782694900468474, 0.23138463076564575, 0.14323354398290958, 0.1337180731277312, 0.13194264904145273, 0.10216251316089785, 0.12688159642200317, 0.13026367542484116, 0.1386274709816902, 0.1450975278332349, 0.18901397774536766, 0.14102641402954055, 0.18586296618225115], [0.030205732196449276, 0.04953746300851626, 0.021294980505180937, 0.07039091639941739, 0.011682498978541024, 0.04521460888246375, 0.026837573011195468, 0.0396079944086171, 0.006529036524420184, 0.06269512652990318, 0.011870195308039266, 0.006549475271435034, 0.044388375395248016, 0.026615821200633244, 0.06083886484585463, 0.028108750364833304, 0.011470717802313308, 0.02565182403721396, 0.05214630265630061, 0.013724052433615491, 0.03974807358557179, 0.021891376123793667, 0.02146182487899017, 0.14710421854209516, 0.04404239859732409, 0.04114444502779553, 0.08725742223642527, 0.0795070869067023, 0.08335546830729132, 0.03937004366889596, 0.05034193193780319, 0.04163821167763203, 0.10009740824781119, 0.09984374121432343, 0.01708474704965709, 0.048310343371403795, 0.05560942993108785, 0.05539519344306281, 0.023420501027196165, 0.051755214770955425, 0.045503508299589164, 0.03102511111196251, 0.014645332534376894, 0.060562046635295116, 0.06557521875947714, 0.04864097925864401, 0.07456574318630081, 0.019001960604181214, 0.03632856735719308, 0.021767336912753604, 0.09919176974724378, 0.016777978631697835, 0.008837039668803975, 0.08877996835977801, 0.04326870341995551, 0.1268960831446513, 0.02977804063008197, 0.07853389477297183, 0.14668818683393542, 0.0357312677548297, 0.07277771695366791, 0.0222015421416971, 0.37814939574849227, 0.4325003921985627, 0.39212375879287725, 0.1021791832341302, 1.0776719402882362, 7.33571965848246, 12.515327142130944, 28.858483568314586, 59.111232449931485, 82.21283174330189, 86.5464702729256, 120.63280843919324, 122.28815847827543, 113.30854308220648, 114.13977961386405, 117.56259672103391, 113.29649356103714, 106.22275783169655, 108.81327936726233, 106.06590224850564, 104.24258847390453, 107.76818736906975, 103.40562528179538, 100.75240073665496, 108.04479291362148, 109.65865996576126, 107.0374184270059, 108.74994093371977, 118.24000573927357, 125.10695411312966, 131.59464067028415, 122.7234866542201, 141.09592345453078, 140.2903470685405, 128.1552162478047, 117.67657295350106, 93.77331179957237, 81.96274926585536, 50.88197039019678, 15.30083852429544, 2.5035493508461983, 0.329196316099936, 0.25574976608397504, 0.20558588447109347, 0.5736406928589267, 0.5560082293325855, 0.0063618464534351184, 0.0686932732200911, 0.11274643152231172, 0.04737366298814455, 0.21053423023512288, 0.1173752726566407, 0.017999015530691515, 0.050098009542712284, 0.013476948858419014, 0.02468277260871424, 0.05919648341894631, 0.02673517578401633, 0.05440306744628376, 0.07195413413067019, 0.06087320856750012, 0.08455201337534575, 0.09454114107234825, 0.09973928512584779, 0.07631073059934763, 0.035091932908061056, 0.08591353547789397, 0.058965278083398465, 0.01562233499792074, 0.02292347658846167, 0.053490706524180795, 0.03162014117885021, 0.07980732442510706, 0.08477360430744388, 0.09809566646694176, 0.028949799992504622, 0.026884633792384018, 0.01517995561082517, 0.04333745981115968, 0.01467310513685187, 0.08187694159606773, 0.05790146540910487, 0.029140787627247554, 0.08190815967898216, 0.02874995638135701, 0.018376823281869292, 0.011716491257351254, 0.023418499622493986, 0.010508474980240629, 0.10115850897085282, 0.03798503714102892, 0.05110475632752623, 0.00972228586643694, 0.029737359446082866, 0.013356152114518469, 0.03055566200806249, 0.052968081342236656, 0.07857177782082751, 0.10795154083039492, 0.06948082692800991, 0.03639031787432971, 0.06155758938421646, 0.040327645913367315, 0.03821131653122364, 0.030517708097073822, 0.029072010168625467, 0.01703523478711084, 0.035376166849727594, 0.03157611602106162, 0.06496162063652469, 0.032491964558439876, 0.024495550296119144, 0.055536287686517166, 0.04970795587606488, 0.05829629946439978, 0.07620033732945881, 0.05769615001495808, 0.1163989931885754, 0.032161665749886346, 0.02496178183073719, 0.03748454423921724, 0.06430512925069179, 0.0163250636204236, 0.06078374481970265, 0.07576756660015353, 0.027617234098274383, 0.020522815588441108, 0.015566659558023659, 0.04992079808406773, 0.0665568761647709, 0.037980233769743674, 0.030847384459188873, 0.03794941022211025, 0.04649443153832709, 0.05095084160265904, 0.041673091660824516, 0.09256200654612434, 0.07561710693182484, 0.04324160689007371, 0.019909612000769666, 0.04946585293979414, 0.03816541637324038, 0.026646955013876, 0.018704626559009476, 0.027396074090633663, 0.015481468665623858, 0.04980264817394557, 0.060759957789653735, 0.006410107119835072, 0.05101843737065793, 0.0333500175075906, 0.09007952927101044, 0.04419528293393312, 0.11299305054689608, 0.04555188675200747, 0.039265828898116466, 0.05059477925721196, 0.04901344737698955, 0.047068970668460094, 0.042177211988957665, 0.06528435815726558, 0.054332560544172605, 0.05278957136456044, 0.026131517651881424, 0.07155358505946013, 0.10446522790457934, 0.05262094009066782, 0.0552239153353918, 0.053347934548172264, 0.09823189222163732, 0.0637462183142141, 0.019069558287399913, 0.15762046069627808, 0.05294766126861496, 0.06695281338667677, 0.036656353397354964, 0.12564859322963223, 0.41177694775885154, 0.4234360092349591, 0.0736821526961942, 1.633111303371768, 8.918018494882892, 15.40230239591291, 35.128268734101326, 73.14251545936831, 95.20668706586285, 104.83448982238771, 146.23837040316675, 141.9588762714017, 134.30524949104557, 132.36918326347106, 144.39469952737133, 128.99777273977958, 129.36420056127733, 137.10966571684807, 122.62273665397399, 125.23291710884341, 125.95296229085616, 126.45980311978249, 120.20603103022422, 131.18477652149818, 127.0964430224511, 128.92790748227029, 130.53096448221515, 144.487973490069, 149.87213257820378, 153.81737801336473, 151.1820786999118, 173.8160687108194, 169.935573762463, 154.42241145718484, 145.9618276165378, 116.09055472958474, 106.0292673110962, 68.49305552821006, 21.20496661432328, 4.113162102237824, 0.7020183977100157, 0.5066653947916724, 0.24981439263830263, 0.42309939020103027, 0.6030792454558035, 0.041898198936495094, 0.21116171753214252, 0.13016881841805675, 0.006687480744139682, 0.10019030406950943, 0.05708389254587312, 0.03961506923059783, 0.051397838584718206, 0.050163513890677885, 0.016891572233890335, 0.037714868573652166, 0.04113217612968818, 0.05514357952521213, 0.016305930574514692, 0.01852744574388189, 0.058848790584072, 0.1551406187636237, 0.038286638295938896, 0.025003173561286063, 0.013844344517095916, 0.09086668461320863, 0.01896205125376582, 0.06720051259523438, 0.0947778775627094, 0.03647554515590591, 0.0718751198221599, 0.03110366385249842, 0.06525938369093404, 0.04909886235010721, 0.022986529455069574, 0.03138450593988021, 0.03607580430745598, 0.04372432655204208, 0.018756059787025856, 0.008586466672920413, 0.014743875381686996, 0.05053490948592944, 0.05366255153691577, 0.04055957903244323, 0.01581810014848147, 0.05435831642018692, 0.010885162327829148, 0.009821719290959019, 0.06009489387994813, 0.004018171382467113, 0.0209478028644357, 0.030959160517781015, 0.04208892801656358, 0.028997228495896827, 0.04498880446678208, 0.019043178049727313, 0.07247824552318743, 0.07459811040110166, 0.04354806887286325, 0.060664840312975074, 0.04616130586533297, 0.009482884347709197, 0.03586537527641462, 0.05185390221736124, 0.012031792937177084, 0.044567352686558044, 0.1045292575332907, 0.023605011388539307, 0.07017691739864888, 0.0380052580317903, 0.003375362087559376, 0.07606572035940425, 0.07098124843210944, 0.16550445538615027, 0.24865255901409736, 0.1751391295223467, 0.19864589396503665, 0.06920494334471804, 0.15760656386133165, 0.18760376309435214, 0.16332176363756581, 0.08331592284863995, 0.13956160795304084, 0.18627469247627645, 0.0943127089750863, 0.12418845262859138, 0.10263174967539888, 0.09761573536501778, 0.10026395576254976, 0.15723980692846162, 0.1832382723448738, 0.13868405423577757, 0.1537011395539007, 0.1334065358124433, 0.08107804978686957, 0.1047814460170846, 0.150928835895273, 0.10346953576851277, 0.14072475924847588, 0.1512574110059969, 0.14116850801773612, 0.15135150192485702, 0.13298679623873005, 0.10168262036337007, 0.13600873730836377, 0.17509013053870973, 0.20121408115711906, 0.06957440456796078, 0.14352433563720796, 0.12366092448393184, 0.1689867846547596, 0.1186757222298653, 0.19849132806543382, 0.12772944124956287, 0.11530135007154559, 0.1768353247954961, 0.15524025615905562, 0.159065900070052, 0.14051322705082356, 0.16686741773399616, 0.09213720313123158, 0.09857497703764709, 0.14887883057517393, 0.27660854761638953, 0.18114833852216122, 0.12894393575768318, 0.14764386619771683, 0.16665479769149136, 0.2678151452733625, 0.17334030911086068, 0.1813033027874847, 0.3795203866977846, 0.0985534116625786, 0.3827058722174937, 0.11115754984559552, 0.6753128178177342, 0.5946993467307861, 0.5066718605737532, 0.39876476050384585, 3.703339138338643, 12.90008027707377, 21.95994442509067, 46.32803586221511, 88.40546977135443, 116.2890580392653, 124.89097272196125, 161.53652406507925, 158.63194619455646, 148.71686904661118, 146.3435213027462, 154.09958470252255, 142.3109325285881, 135.67009310568534, 137.74731759102116, 135.29117645755892, 132.5458311265515, 136.58769238379696, 130.90785718733267, 130.60150438739407, 140.6446312319848, 139.64960436667167, 137.13389027503231, 142.90195526615267, 151.22751543598793, 159.5974611466931, 172.48610281175183, 165.7007475822203, 184.92161658502397, 185.82288311373804, 175.30225476910994, 165.42503633806783, 136.6741414223948, 122.22518874752907, 80.98430618163079, 26.728465941644487, 5.134597305328616, 0.942718749565463, 0.9482103742418752, 0.34089861557848994, 0.610585926521209, 1.0648462801210343, 0.2128280200544865, 0.29593155268699894, 0.3211574184317743, 0.13275454902360517, 0.40388421966664256, 0.2078958693891764, 0.14326066349542912, 0.2568355884643332, 0.14458118457226984, 0.09559037509344279, 0.15324779936382849, 0.19838320241580087, 0.26241165135175953, 0.15273413741059844, 0.2811595388958531, 0.18103866537492122, 0.23013697997216256, 0.1289656313676988, 0.14913301854845018, 0.1246269230520533, 0.22843704618994268, 0.2081224169101446, 0.15815336677816608, 0.1275211955691057, 0.11224830583218606, 0.1831397840813283, 0.14699894273954053, 0.20829711560039751, 0.1306051667779684, 0.1533092089718388, 0.11718047181925467, 0.13954604104641946, 0.07921565939942676, 0.13189875220339145, 0.12250258422066128, 0.10744853516019161, 0.2466223340842032, 0.14692175172029004, 0.11427725139524668, 0.17421665240920362, 0.14221132222202518, 0.09726495136536899, 0.1467811592644261, 0.19542883030108868, 0.1509068032065707, 0.08717762651823222, 0.11721375833956466, 0.0934227522943289, 0.13959277240980056, 0.12108633279680245, 0.14313252762921397, 0.17745225540091916, 0.1795484251793354, 0.15018327912736326, 0.11939226724808255, 0.09500995623849093, 0.11175715920305061, 0.12974602981440483, 0.20707810117352396, 0.14127933029686252, 0.12272361590857468, 0.20096067459352557, 0.11089390834733365, 0.1677967436731823, 0.16409137556629796, 0.13951814012421718, 0.17135289317417532, 0.16384121721550343], [0.0276535504963249, 0.06537550729849646, 0.003040184974745517, 0.041783266595654914, 0.07365386873002976, 0.08117584857128321, 0.05911531640336879, 0.029001903547454747, 0.016803866657879085, 0.09699247687334016, 0.06408814633745821, 0.011333671375928868, 0.07074236689556031, 0.022647336365715153, 0.06513294853991078, 0.023010869983643777, 0.035926604853762735, 0.02060760811512028, 0.013846536486169264, 0.0260467155491032, 0.046814644799357465, 0.0780489994212985, 0.03668975866129322, 0.07518500269901368, 0.0895588729350317, 0.00433545004794254, 0.0302573167268307, 0.02493417202194612, 0.026843376127221895, 0.013849502204046136, 0.017247075335152687, 0.03473069180824584, 0.02450345440827791, 0.059082623601200125, 0.05899817772930669, 0.024905752075175126, 0.06471627331789463, 0.01978482202356381, 0.03224431514559734, 0.07025934079842222, 0.06608360236690891, 0.02909707656550792, 0.05323869424060949, 0.058178636020109545, 0.07374571501127175, 0.14588308971255057, 0.03501758790544925, 0.05744125341035186, 0.025385800005507567, 0.04325579483843139, 0.007302178682068424, 0.03958337617317035, 0.024823502960404562, 0.06359992999463313, 0.05316074862475357, 0.14956630255666473, 0.037995164823387904, 0.05220399290743855, 0.1585792197335151, 0.22082099841246683, 0.35711822911135616, 0.1973706333627624, 4.801023746690443, 15.538788130206449, 26.735720365278183, 62.75541636251635, 81.64164835406889, 94.39856898400092, 102.52565722311698, 119.95419917568084, 108.83820995207756, 102.82886428217735, 102.90046322730281, 59.431082125633, 61.73685919853949, 82.00029419314477, 86.09961032867433, 72.98387912011916, 98.40250876642044, 60.493875780413234, 77.81113224644815, 89.59026875034456, 72.04186701005506, 91.88647131766044, 86.30328332224201, 98.07273941655313, 81.54917455488636, 115.11473178863527, 89.48136806488039, 88.64454607809745, 91.07956917055192, 77.37159144493842, 96.48071212153282, 97.12060759144445, 67.7016310538015, 87.05994775218349, 94.08119432387814, 107.64444443487353, 120.1845678206413, 106.74291902972807, 125.2663435474519, 111.65361665910291, 98.13046101600894, 87.0934683276761, 72.07908245824999, 49.58312849844656, 32.53193032357001, 12.834213875955152, 1.6515611520697995, 0.5909359551245167, 0.34678351915171074, 0.07461074319097304, 0.2617181272756669, 0.027602975286783713, 0.08667393136889705, 0.042355744949271606, 0.06452867370699683, 0.028981625200099045, 0.035279191609832554, 0.07222016582325583, 0.08918257820750437, 0.10489818249498645, 0.05167449591681362, 0.007175351389788933, 0.03176507543802502, 0.0693213427439332, 0.035744501923721646, 0.013220645524861832, 0.03706888408370076, 0.03176953598496414, 0.0673867026043515, 0.057617840507338126, 0.04286558029331988, 0.033334519548882405, 0.0826352077626413, 0.065902246372594, 0.05527441202092075, 0.05333756937855675, 0.06720468011354247, 0.07035933825517855, 0.03536728789068518, 0.027841820434156447, 0.0324984303405208, 0.04306917582007666, 0.013815093364927077, 0.02449356804361507, 0.04792005987837911, 0.020864259061073104, 0.06579580611639446, 0.005452684906025928, 0.047057245692778985, 0.025017198715959827, 0.027822547577201363, 0.007482580418112658, 0.03642769530415535, 0.015004570314270115, 0.04852274507885018, 0.04669762486892362, 0.061317750237761974, 0.0401754089210543, 0.016157420599953305, 0.047025801613926894, 0.036078922285307805, 0.018303407160865686, 0.007187575759035686, 0.055963117403969656, 0.06996328612008403, 0.0514598150977925, 0.01903497133283846, 0.027913537755187963, 0.02888342230430534, 0.021621491008948897, 0.02402459199900829, 0.07848213021192821, 0.057976863782612555, 0.033923817362876675, 0.06750689413879188, 0.06440257563466026, 0.061909828950921376, 0.06370716698227391, 0.04286123657478921, 0.02277272963716138, 0.11701659029049259, 0.01913354769649525, 0.02149519949941145, 0.03933007686188625, 0.034246505087902473, 0.07369553625223137, 0.01539898589403639, 0.10154839409815689, 0.023579674945663542, 0.02864139214638741, 0.04023487649617657, 0.039047746648711544, 0.019966923038385088, 0.042562477606078314, 0.018141130586304975, 0.07393628704331576, 0.02181430767861105, 0.02406115354519458, 0.031101057238336054, 0.026924663801647486, 0.032883971749294194, 0.03138928058286829, 0.016617013982707457, 0.034722885372297424, 0.022470371970426173, 0.04190127094907146, 0.05266886655121081, 0.12502839908965174, 0.03914738404414347, 0.07359402960226422, 0.025985713882912553, 0.027443293835066503, 0.015604165307576618, 0.009547513440221308, 0.04438984245362301, 0.03729299927550939, 0.034701787310862736, 0.019108441079996766, 0.018890393304548437, 0.0711375916556966, 0.022284528616094784, 0.05656573748696716, 0.018884318227308895, 0.02741930953737709, 0.012650092924764801, 0.01864091294156688, 0.07409901944019141, 0.04844935768614373, 0.05731919262137625, 0.20064150704251182, 0.07620014580747775, 0.020582700681482113, 0.048315434025660645, 0.24000166434674497, 0.3568409972133175, 0.14036650589156535, 5.512359305735558, 19.106875119670747, 32.484079368652836, 73.85881085549632, 101.3353120127032, 112.58153961550806, 121.08744252112605, 144.68724558430335, 127.88585924333142, 130.65362484224383, 120.56653607276179, 84.5160710427069, 104.05043940390311, 114.68357701455395, 135.35442075421733, 105.87287456758561, 141.3266372680664, 96.08230129364999, 103.2170847923525, 144.52211380004883, 117.56842536310997, 139.23897927807224, 135.20318984985352, 152.5327076450471, 110.52973208888885, 159.55706073391823, 131.41971865007955, 123.47827619121922, 139.3898807033416, 120.159362669914, 130.52587324573147, 124.30767705363613, 101.649227142334, 115.98417220577117, 123.12816542963829, 134.00380749856274, 142.769802770307, 123.9063322928644, 143.815883205783, 135.3043399318572, 122.10810599788543, 111.51263883036953, 93.09216084018831, 63.88604740942679, 46.42538908989199, 17.740488052368164, 3.0259610087640825, 0.5403081459864494, 0.25140572579637654, 0.025371265402364156, 0.263700487032052, 0.024180186371649467, 0.027206545853386485, 0.01091862313314191, 0.03321777924054092, 0.027431836990158887, 0.1202360058443681, 0.04163324742788269, 0.022318125402014104, 0.14296381974652891, 0.0592223427168304, 0.06135790473631313, 0.04532568397060518, 0.07869616751709292, 0.04768283692218604, 0.03169637650341517, 0.04208525462496666, 0.09092296909300551, 0.07128005336609579, 0.061269911877330274, 0.02462069267377017, 0.040975449862138885, 0.02284808779105304, 0.0626871821981284, 0.035979943725490765, 0.0970516188610946, 0.07177675413268228, 0.025888175568393162, 0.044242968076779965, 0.044882394854099526, 0.022784701676198074, 0.0379451775863286, 0.045574811933141564, 0.038233188341461846, 0.060960102090311635, 0.023287529230958993, 0.028844761677206527, 0.09975863650681512, 0.03793842835171569, 0.0396995036111724, 0.07365969099825428, 0.01365066599851895, 0.07726166021799849, 0.018570884844408404, 0.056199041841131066, 0.07329966797823868, 0.05303296898942321, 0.05021635097481551, 0.014892460049821005, 0.05152218997658742, 0.09019238168313619, 0.03714718210000185, 0.07783886916454762, 0.017000776152276707, 0.0128528687374426, 0.013376766582950951, 0.06173390068954999, 0.015537964777209827, 0.02061164539848124, 0.04064958670266694, 0.021383283629773125, 0.12122796713224343, 0.029811995562105894, 0.0379091676234478, 0.1402116488785513, 0.16357667173349089, 0.14880393781969625, 0.09199150086891267, 0.1937172826259367, 0.25058964297415753, 0.23395137771243052, 0.10401883613198035, 0.12083397577366523, 0.16194729464909724, 0.10720906373594077, 0.13055769997018, 0.13285217926867549, 0.21216443469447477, 0.08228715103600295, 0.10171978328857692, 0.11643971842263015, 0.23005382878886116, 0.12082120508796747, 0.1548421049430486, 0.11503465954334506, 0.13886290512258007, 0.1432577983265923, 0.12850637697885114, 0.13291901277918972, 0.04513937138742016, 0.1614336326958672, 0.06426422781641446, 0.1615684028835066, 0.10246111891202389, 0.09152432513092795, 0.09778342435076352, 0.15276767673992342, 0.15956013403352232, 0.13692772106057213, 0.1503157816947468, 0.14896590412864763, 0.11118779499684611, 0.10045749255486074, 0.15304936726968135, 0.1870982982819119, 0.14731195094364305, 0.10104429292222185, 0.17910150480606865, 0.14257432532406625, 0.26542338813024186, 0.19013269594119442, 0.2878700094597955, 0.0838406777550136, 0.15426413756945442, 0.15426684952070638, 0.11624920767762008, 0.21845518100646236, 0.16912022184941078, 0.21652851584217242, 0.47187829209912213, 0.3243064688098046, 0.18194739887070271, 0.28255280768198354, 0.4694838076829911, 0.41905340408125236, 0.5553675959667852, 9.574754661129369, 25.389817876200524, 41.74048269948652, 88.91917474808233, 120.021193258224, 131.09162022990566, 142.59288818605486, 159.1429212016444, 140.65304079363423, 134.55603015038275, 127.71695413897116, 80.82524622640302, 86.39293301490046, 109.47969790427916, 114.50747828329764, 95.71748948866322, 129.2856825551679, 86.45229416508829, 102.1520200852425, 122.40116196293985, 99.91630831072408, 121.37488949683406, 118.33045559544718, 127.77027483909362, 106.31836168227657, 145.52318111542735, 123.26306358460458, 117.20264081032046, 118.83868494341452, 106.59018977995842, 125.9496988788728, 125.49548056817825, 89.84759192312919, 111.26061085731753, 123.89441613228091, 136.5028436722294, 149.27125684676633, 138.72866322917324, 158.48962691522414, 155.74928652855658, 138.77091500066942, 123.51003954487463, 105.80289163897115, 75.43450540111911, 56.09876586544899, 25.0619508758668, 4.536660900039058, 0.5985720131185748, 0.6699370256354732, 0.19908754365338435, 0.5635823261353278, 0.18918489196127464, 0.20628337688263387, 0.23276003438138196, 0.1561321970075369, 0.13405841534897206, 0.16490750435379245, 0.2223888126712653, 0.1926809188819701, 0.2375040032089718, 0.13207328235430102, 0.15052015863118634, 0.139724891933222, 0.22731563136462243, 0.1246928908832131, 0.11724738193856132, 0.16440547161525296, 0.2234434246295883, 0.1346980681222293, 0.1340208923624408, 0.14742119508164545, 0.134971484902405, 0.16942915446575613, 0.14260092389679727, 0.18492449315324908, 0.15619804992550806, 0.22454950237466445, 0.2015405878304474, 0.1113491024701826, 0.18154341006471267, 0.08615877554421464, 0.1959992900130249, 0.19627256889737424, 0.09963539594243612, 0.23357774131000045, 0.08219262344702598, 0.2260651766893364, 0.15801861191228514, 0.10305770222217807, 0.10804261336283338, 0.19775401440358933, 0.0973271806874583, 0.17510206618857, 0.11833984630122302, 0.1338049781418616, 0.11698624554781184, 0.10336646629918007, 0.06195608917022906, 0.08226439056377258, 0.18695503984007145, 0.17719121860159984, 0.0892744857757803, 0.20809658442533788, 0.06718472352311497, 0.1325381751502714, 0.16720619713587148, 0.15290327430252107, 0.12749539372781593, 0.1363582572629375, 0.10369301893778386, 0.13553102020054095, 0.1576453738755757, 0.1616200372096031, 0.12294368232570349], [0.010624555495357322, 0.011375056403208406, 0.014484221371070994, 0.0324144211387442, 0.07921070281055667, 0.04536070568006366, 0.07129806409319563, 0.00940028379010337, 0.051639554646587184, 0.014221217641006074, 0.0324818751804771, 0.06491568600458485, 0.0489918896628003, 0.0153295103377933, 0.04094754893993659, 0.04910098441365746, 0.05424857432503374, 0.027940967533316825, 0.0917003721359276, 0.06626557889244249, 0.056838407331416686, 0.008739263867028058, 0.0483949079869255, 0.06275041126495888, 0.03806284486105846, 0.04810155759896002, 0.07268287526864199, 0.05706108227792767, 0.023442190891552358, 0.04096136150521137, 0.044784117264733206, 0.03185855157132591, 0.02346265310000989, 0.0527701816791969, 0.06584982297593547, 0.0632324069738388, 0.07649090681825915, 0.1039541629894126, 0.035789812194003214, 0.03549466916029492, 0.028449092586074146, 0.04220487159346381, 0.021587457552912737, 0.05221590174422149, 0.06574618660153882, 0.004188924719909988, 0.052465179093903115, 0.08252552695452206, 0.08800379105753477, 0.055696062984005104, 0.021595091619078192, 0.009933826682578412, 0.03589359412510549, 0.04572533671894381, 0.04414521142720215, 0.0773289380595088, 0.029528349592921235, 0.29568520945406734, 0.031099827667217583, 5.78857506475141, 31.722804192573797, 56.44058473648564, 81.86541957239952, 98.87921794768303, 102.06094264984132, 100.87991699095696, 95.77566608305901, 85.06696793340868, 81.80699194631269, 62.133634398060465, 81.6406677615258, 48.07213344881612, 64.63759706866357, 65.64651304675688, 46.26631736755372, 46.47584645978866, 30.567042519969327, 54.460046675897416, 36.42487879722349, 55.464859854790475, 61.701961871116396, 28.96661154685482, 23.3279396641639, 31.493724046214936, 26.91247020998309, 29.479790925979618, 39.4252174131332, 13.905746571479307, 24.92251846098131, 46.98866498085761, 42.48057903782014, 37.924930434073175, 44.30584615276706, 68.42736367256411, 63.85109909119145, 61.68590761000111, 48.220520634805005, 56.990344139837454, 69.02009656352382, 80.80729746049451, 85.12077500743251, 102.12356721201252, 109.59346232875701, 113.74198852046844, 110.5499009163149, 123.87418454693211, 110.50054181006648, 117.76235518916961, 84.54567709276753, 43.37431069343321, 7.396509041709285, 0.06720744569094912, 0.6671770866359434, 0.42841263896515297, 0.09757760716902633, 0.007788291634736403, 0.015883696426997985, 0.06422435293995565, 0.030238398185540593, 0.04501497786071512, 0.06507376824776012, 0.1290050542522823, 0.006146380394291614, 0.024058418611304897, 0.023424298908080787, 0.030550213207701044, 0.060948465214741815, 0.04028947941297966, 0.043946243071508025, 0.06926888870375772, 0.07665576893956431, 0.025606684221495545, 0.06429875539916177, 0.05412883861290832, 0.018923248900401018, 0.02275956441618262, 0.09824999487928807, 0.034755915253152775, 0.04517995872564855, 0.08805926348413191, 0.07034000985684895, 0.09584566623333002, 0.026865006619763952, 0.015954218650867623, 0.015739579009072437, 0.03735724340883955, 0.028803057765828508, 0.06129120912162527, 0.009844482636019107, 0.05001080958473106, 0.09741531144226752, 0.06487317578566652, 0.04610362327507427, 0.026547601070976066, 0.03475285856233489, 0.059050061033978585, 0.015376483018870558, 0.06609880921220587, 0.06937307666145986, 0.05744930499443605, 0.0329447340130085, 0.02166607541092221, 0.020839043277045412, 0.034196939199201526, 0.09419365891165311, 0.035184185215902906, 0.04010945641165299, 0.01578496205770681, 0.05426149822831635, 0.09305555869134204, 0.024284675018861893, 0.05709210117798179, 0.024669892755487276, 0.028637770465725375, 0.009891653542346772, 0.07963631827864917, 0.032991170432538755, 0.036468504807881774, 0.010584423021833983, 0.025099466982928496, 0.0062086049283313904, 0.04684140425055258, 0.0857865947088407, 0.008702945553757733, 0.04389677294379762, 0.018395642231729244, 0.02997740735149672, 0.04825044295660431, 0.026885051310302752, 0.03824448813834498, 0.024518107755049586, 0.043379491225125334, 0.017559960965187322, 0.08966814771655107, 0.028402594879509944, 0.05362861767230977, 0.03214207305122287, 0.04705241933885602, 0.021776280989269578, 0.03884247338940059, 0.022972251491380796, 0.07195824802282356, 0.028278567159788746, 0.061405275783111016, 0.052191160934706854, 0.08629877045149766, 0.012961893582776671, 0.03702154368041985, 0.059168835305759025, 0.027374066299788898, 0.021499468524369503, 0.05161584039489108, 0.07497568449546253, 0.07826105255873934, 0.017447788456094362, 0.11435463393647825, 0.034242666987401825, 0.03492445459649448, 0.07641943081492379, 0.025530098411705227, 0.025151934429642656, 0.06987612829693864, 0.017655296776924404, 0.09361461135408572, 0.02649909046839082, 0.030740216419461276, 0.005088190805362237, 0.051097110770041906, 0.015386273622542862, 0.030870495416644602, 0.11372668698670403, 0.12483437200106921, 0.07050720854632317, 0.1788938183697962, 0.018319598429145354, 7.1757330433014905, 39.93658465723838, 70.50365463379892, 103.27170771937217, 124.29612959584884, 119.29699820856895, 122.72446724676318, 111.68237547720634, 115.89511086863857, 108.25174500865322, 89.56262388537007, 114.54609794001426, 80.31187857350996, 106.76123649843278, 74.63924484868204, 57.309825112742764, 72.63174441552931, 49.11857474234797, 58.087199657194084, 57.61857448085662, 54.14339765425652, 69.86983099291402, 41.69319852705925, 35.697679212016446, 45.717970017463934, 41.916047988399384, 40.49258062916417, 53.32221807972078, 35.35824121967439, 50.6767519827812, 68.15040511469688, 61.25541963884908, 57.94648070489207, 65.03843976605323, 104.07396578019666, 84.28139563529723, 93.27319391312139, 91.1325054783975, 107.91943396291425, 109.34174030057846, 123.05458960994598, 125.8199704077936, 126.66587660389563, 144.70884999921248, 137.19305530671153, 138.27812410170034, 143.50192100771014, 129.50013422196912, 141.58292493512556, 104.90323328202771, 58.20117981203141, 11.075551548311788, 0.1406851525027906, 0.5391136616949113, 0.29607030653184463, 0.07594906815117405, 0.006007154926567549, 0.0194632240586103, 0.004275143127738228, 0.030216032248591224, 0.04005615584432118, 0.07672819489192578, 0.14451444299230654, 0.0459549562524884, 0.02643081671257894, 0.016019400284295122, 0.06958041069728714, 0.025932428637339223, 0.04699809221370567, 0.03259930496795043, 0.02655709098513809, 0.07257476494076752, 0.04875904872953411, 0.05064329943589626, 0.03963856514723551, 0.019696313970451875, 0.0179701091180886, 0.026183715052602273, 0.05977063950511718, 0.02571960941197411, 0.055399766987970764, 0.03813833899555668, 0.10277060311167471, 0.02013441475649034, 0.060630676621991786, 0.07210847020389573, 0.021790151011138674, 0.0558461127952943, 0.027370548040996638, 0.03287332312714669, 0.044932910691826575, 0.013802076573483648, 0.05787221234171622, 0.08438158945571031, 0.0817613006238976, 0.01710231727620046, 0.025818779493772218, 0.027034005615860227, 0.009487599618883144, 0.0683263783913947, 0.011658747380058612, 0.01004237846861924, 0.059166311046048525, 0.014954519874957061, 0.02082922394507595, 0.03383076066271432, 0.057222872386656465, 0.08309591771854509, 0.0694572544025798, 0.03503508535363982, 0.029936691693541025, 0.048638550759924036, 0.06708782872245198, 0.03234563027358344, 0.03909437459022288, 0.027550672548973275, 0.026098177505416736, 0.12060024234796725, 0.13978997876326885, 0.08431758280963668, 0.17445489043189635, 0.10716518221963799, 0.13572375260053143, 0.17409398641076781, 0.112740004044627, 0.1364144881165797, 0.12642832517984415, 0.1228611593345, 0.11292725125507963, 0.30112192094806706, 0.10248281452203951, 0.12559721171255075, 0.151891318119822, 0.15972914835137708, 0.20112202803213752, 0.18825006551079213, 0.14252825279630002, 0.17157122823259524, 0.18292904861511725, 0.14501025509690085, 0.07922306746965455, 0.13332480955268108, 0.19590910614257862, 0.2502151025879768, 0.1752205799904562, 0.1229111465715593, 0.2149367996401364, 0.12818295763985765, 0.1501053986289809, 0.15109251824117478, 0.13692111738266485, 0.10426306496224097, 0.1775326027024177, 0.21938317395266027, 0.16995334246706578, 0.07495300063202459, 0.2412046522142426, 0.0961140344940847, 0.16858808185544708, 0.11311052246920525, 0.13850825237891368, 0.1462133502167079, 0.1838645492229731, 0.1112761862215496, 0.13993256304773594, 0.21741351593405972, 0.11547909013085789, 0.06756209843461553, 0.1579565741121769, 0.16643292330686124, 0.1919876859192887, 0.19648387126864927, 0.2603826521625442, 0.18037120361001263, 0.5092771417431293, 0.11109199570191484, 9.646281042406637, 52.33751097033101, 87.11638281422277, 119.92569138926845, 137.6209702030305, 136.98487158744567, 131.22730285890643, 120.97232095656858, 109.05102206814675, 101.751067561488, 78.95550727844238, 103.84535435707339, 65.90799393192415, 83.62532431079497, 89.56860942225303, 62.81346744106662, 64.41360619760329, 40.13671967291063, 76.88587650176018, 54.62036571195049, 77.40362151976555, 83.71243230758175, 42.00200280835552, 32.74793524895945, 47.842906213575795, 38.02877518438524, 40.025053716474964, 59.72977453662504, 19.182066955874046, 36.459317207336426, 66.39658789480886, 56.65496187825357, 53.111849600268954, 61.98441959196522, 93.48606094237297, 88.31888737217074, 89.05896802102366, 73.3876714398784, 78.12877362774265, 102.40755465722854, 112.57840956411054, 111.5422684146512, 125.37088255728446, 138.57197238552956, 141.780879112982, 142.6745362435618, 159.54989064124325, 146.0613303030691, 156.9967257591986, 117.72637136520879, 69.03601354168308, 14.094175273372283, 0.3604150731717387, 0.8505526112933314, 0.7773055352510945, 0.22427781695319762, 0.18600365056866602, 0.17777750569005168, 0.13968926884474295, 0.14818239536496902, 0.2260751817976275, 0.16562672301886544, 0.2905452497784169, 0.16707564043181558, 0.14194107704585598, 0.09334662613729316, 0.14391268092778423, 0.12078270916977238, 0.12531334549308787, 0.18855122999558527, 0.14255699641521902, 0.15560083842325598, 0.13268060621715363, 0.14196059696616667, 0.13369109151103806, 0.11354460320886105, 0.09590395020260926, 0.2910964347181782, 0.12767101172357798, 0.16270471045807486, 0.16405530814682284, 0.1480419714484484, 0.16256686059697983, 0.08678920461886352, 0.15804493469336342, 0.18474345125498312, 0.10143594771263101, 0.12840802661113201, 0.25703452617651035, 0.14911961200977528, 0.12719833547429693, 0.1651525299154943, 0.13605595896801642, 0.15509638484687577, 0.16516173829234418, 0.10261182372848834, 0.13262318026634956, 0.08234510558747477, 0.16626971593547255, 0.14484170043180067, 0.13058296554992277, 0.2438749436048731, 0.16911985412720712, 0.09289310208611912, 0.12725353977012058, 0.21832896036005792, 0.17667395603512565, 0.17974077453536375, 0.13296418132320528, 0.1427315418878871, 0.17344579941803412, 0.10915186271191606, 0.1502268695302548, 0.11316242492607526, 0.12577328170018812, 0.0936059468996621, 0.12412164210071489], [0.035120760796651725, 0.12221063577359724, 0.07979146640507445, 0.048218562207635374, 0.018563438469784397, 0.055262074174900214, 0.05114057476842596, 0.02417995079961275, 0.026513831915273785, 0.02460284474035425, 0.022350475379836657, 0.023866969408587586, 0.020466751358922453, 0.0953936513753668, 0.036364519863479564, 0.02551574383922402, 0.01896930419118895, 0.05828888756373237, 0.011508968572372632, 0.042343322833579396, 0.058591086267223286, 0.023016851215112596, 0.009933903291370842, 0.11064549667700646, 0.028668172665000446, 0.05031825216006368, 0.051007014999706904, 0.0427288489205943, 0.014479506099897047, 0.019659687306792028, 0.04724435883784487, 0.07031157267309966, 0.052380212282221165, 0.04333508493859441, 0.0292257716759078, 0.020433058812012597, 0.026655845464237278, 0.01163854085344581, 0.0026661583462790138, 0.0471909586790829, 0.03289219187272172, 0.046993633581986355, 0.025986646594960364, 0.03179326364319892, 0.062285794260641264, 0.05219197298790659, 0.07945120079262603, 0.14846400928593453, 0.029329113106453614, 0.09662058715137745, 0.035750960044923334, 0.029902949350916093, 0.05880500482875974, 0.03655502294761039, 0.1838234562667147, 0.2835328179982401, 0.3810269445661576, 9.006778790104775, 39.346652338581706, 81.59676859455725, 88.72668050950574, 86.19453168684437, 96.67815639126687, 77.82368383099957, 77.9971859532018, 69.74650382995605, 75.84361645483202, 39.554443820830315, 47.09923267364503, 50.407853895618075, 38.47287378003521, 58.355191676847404, 49.72357288483651, 55.57288977407641, 79.06198393914008, 68.71423013748662, 110.2396571251654, 93.15323214377128, 101.68505407148793, 106.20883341758483, 76.25687737618723, 129.87281430152157, 127.64803809504356, 115.02355237160961, 120.95187756323047, 145.57564673885224, 85.56834882305515, 115.10840108317714, 108.31531093966578, 82.20568518484794, 110.22463444740542, 103.12525426187824, 76.68905981125371, 55.981181052423295, 58.047140490624216, 52.662985324859626, 72.7672544602425, 53.74816786858344, 52.2338427266767, 28.308894788065267, 37.71125931893626, 55.851464348454634, 48.14867850272886, 59.083454224371145, 48.87591338926747, 84.04691634639617, 83.4330105012463, 102.25047942130797, 101.07679643938619, 118.41990132485668, 93.4903363258608, 52.52116026416902, 26.698895192915394, 9.485994365907485, 1.4264183299195383, 0.07141205797632856, 0.35546868859279546, 0.07761959947886006, 0.06308441410862631, 0.036940541373746055, 0.03813206473545682, 0.048830662628695856, 0.024976417940530567, 0.08754758569862574, 0.11412146741584425, 0.04519458334412306, 0.040691824960372144, 0.03413954006147481, 0.04886743867950094, 0.06473018547459956, 0.016804904707016486, 0.029559073549124504, 0.025350770635169842, 0.016662429590078614, 0.021758494342887597, 0.054298580714291146, 0.06501633463607681, 0.08071767436640878, 0.05024873351137485, 0.06813519348901126, 0.06056584260095993, 0.03595731731864714, 0.022753998787412723, 0.06534763701981114, 0.022491592605928742, 0.04271107951119062, 0.0438670602236544, 0.012974370282233484, 0.08152218926097117, 0.022980103892604672, 0.05033038316234466, 0.04548373173982386, 0.05467222860804009, 0.062023336368222395, 0.04051727565726446, 0.04677486951432882, 0.004644690057067502, 0.02485878705497711, 0.042610794771462686, 0.038193688848085945, 0.02990041168466691, 0.01907132412006538, 0.11203069089641494, 0.007864706032353664, 0.055371065503887595, 0.012238394401426758, 0.057376875211634946, 0.029132046564031514, 0.06349840802290747, 0.10481288626549706, 0.029894001443960497, 0.014858947533573356, 0.05428448086604477, 0.056837166268979354, 0.010813431600258957, 0.07896976815837045, 0.10526629540348247, 0.07510874630703081, 0.13821887032639596, 0.02464477847810955, 0.03985583151300107, 0.04176442466315724, 0.03828869907245521, 0.005174051067085877, 0.059587697708799, 0.025644655369462508, 0.013534778920603136, 0.07656131795937977, 0.027830311878313942, 0.07322105203544901, 0.028835524572059516, 0.018644641874538317, 0.04232917318961794, 0.03386814575341921, 0.060927099022533626, 0.006923189719072393, 0.03313232596302706, 0.022278658467374986, 0.038752232062359976, 0.10057124895073714, 0.058922208620295416, 0.033301256011210145, 0.021487253252416853, 0.026812619612281843, 0.027749150608395858, 0.02694245427846909, 0.06401358299978799, 0.054297695882738604, 0.06766328332765449, 0.08542769783807379, 0.055111526406460234, 0.035598554513266975, 0.03128173716005779, 0.04626688044217806, 0.05163559780245827, 0.011871430624817169, 0.0365772356669749, 0.078990483175843, 0.011444195838374718, 0.029633548786683433, 0.04432269484705983, 0.043829682793828754, 0.07175171071843756, 0.11221768529785257, 0.05532102847111322, 0.09667816631976636, 0.029577545844198718, 0.03509669414451046, 0.037503788367875164, 0.07490646079062455, 0.009432507363418418, 0.16619424095317242, 0.6383814963121569, 10.887139516492045, 49.60536049258325, 99.26291204267933, 108.10795876287646, 101.82726352445542, 108.28884278574299, 95.40895585090884, 105.60461582676058, 102.97312905711513, 116.40128489463561, 66.69058522870465, 61.7382751741717, 53.37075741060319, 48.454960700004335, 43.46970665839411, 35.835672117048695, 44.90994999485631, 39.69222491787326, 36.09650188876737, 44.315871730927505, 65.13787969466179, 54.745532466519265, 78.03982996171521, 52.773290218845496, 56.45322653555102, 54.194333553314216, 62.4249880544601, 47.70483093876993, 59.181921405176965, 54.24222177074802, 31.632821098450695, 35.60478571922549, 46.73025923390543, 51.896934663095784, 42.56312139572636, 46.35261735608501, 39.933717404642415, 37.37237830315867, 43.545110302586714, 43.91250302714687, 35.804171562194824, 53.08281621625347, 40.53178864140665, 49.41366641752182, 85.53430264995944, 93.3612903471916, 101.82008558704008, 87.96211642603721, 120.20763135725453, 117.38337578312044, 119.31566869058918, 123.40046421174081, 135.84073189766178, 114.98659579984604, 72.6733293840962, 36.00128243046422, 13.747062183195546, 2.323324776464893, 0.06194247578781459, 0.25452445441436383, 0.02252635767593259, 0.08307015418165153, 0.0628416906411369, 0.041807279621641484, 0.15420409159794932, 0.03602463346455367, 0.11670375828661265, 0.11477731528782076, 0.013838444682469052, 0.005595149489254841, 0.08540332092032318, 0.02818716520954284, 0.05081355098574873, 0.01751912847882317, 0.010271682948504966, 0.055617960320124706, 0.013300469013742142, 0.05017841813124476, 0.045204714856921666, 0.0348023823162, 0.0463666825465137, 0.0683179131198314, 0.0350189208984375, 0.06281075984119408, 0.01635043453725596, 0.016531415148487976, 0.05926404088254898, 0.03541570847793933, 0.03108388920795293, 0.03574272459973732, 0.015559294580241606, 0.03255422069360653, 0.04231225030737058, 0.058119700876094645, 0.026260507706132148, 0.052614608373973644, 0.017114237604302265, 0.011303866725234736, 0.06612367642622802, 0.043620345438079494, 0.029341684609291055, 0.018409598438489824, 0.053177372732710455, 0.022377012665533734, 0.05407409396983924, 0.04140760772110474, 0.01667667882547023, 0.029736721677885904, 0.050789706499105504, 0.019876482528484157, 0.0282351759397575, 0.054759317483272285, 0.04716799902399221, 0.03238144105360393, 0.01878458315566663, 0.022431211470956766, 0.07030398074177004, 0.05765565077684099, 0.09356182789610279, 0.1636975297644254, 0.21621431254090803, 0.20892582863809603, 0.1753046964445422, 0.1351418168914895, 0.10577493181992924, 0.17215552349244395, 0.11461743273802343, 0.19273377894874544, 0.15224132837066728, 0.1807118369446647, 0.1353448608349408, 0.12050108758792763, 0.21251231522089054, 0.21107810669608656, 0.14206300759988447, 0.1178631863947357, 0.13647113265770097, 0.13323614253632485, 0.12097921072235032, 0.13477604055116255, 0.17478919588029387, 0.13759539733009954, 0.21591540035461226, 0.14981361106038094, 0.1573537395245606, 0.18330127541576663, 0.16154883699792047, 0.08393411749913808, 0.15121443347344476, 0.19453433071894033, 0.19463651152628084, 0.17021117701886163, 0.1705428777683166, 0.11608058406460671, 0.168567949064797, 0.10092638432979585, 0.09419169006568771, 0.145356128472955, 0.15183389216901796, 0.11169485327216888, 0.1893517765546999, 0.1605671719317475, 0.15163202800097006, 0.21343082399858584, 0.20280081778764728, 0.11365521098336867, 0.2391598562920286, 0.15163637938037997, 0.19084583186814863, 0.15476157378044822, 0.19891592463658703, 0.11318919969902885, 0.16029827507032504, 0.2722574133546122, 0.4569725806434309, 1.2684843400793693, 16.147720409977822, 63.84019097974224, 118.60782992455268, 119.2059599968695, 112.12546210135184, 118.87524927816084, 100.5122575452251, 98.80914872692478, 87.69248485565187, 97.94330904560705, 55.8140645488616, 69.82521010983375, 74.15645599365234, 53.49110357223019, 81.16132274750741, 72.12190689579134, 83.14239425043907, 121.7994546890259, 103.89934186012515, 166.66907095140027, 132.6194775489069, 136.67283919549757, 145.5225221572384, 113.81321091805737, 181.01685001004128, 176.46967764823668, 165.06279760791412, 169.5931508464198, 189.98770283114527, 120.60779156223421, 155.40623603328584, 146.57773387047553, 113.79756066106982, 147.51987149638515, 139.45420757416758, 103.36994740270801, 74.7363470446679, 82.15134466848066, 72.52211416921308, 96.73856873666087, 68.66900520939981, 70.11797581949543, 39.704090087644516, 53.14525642702657, 78.6272519634616, 70.23313660775462, 82.77131449791693, 69.8604408387215, 112.52880727091144, 109.43886603078535, 130.0729257829728, 127.10386414681713, 150.42721071550923, 129.2049523322813, 83.21756255242133, 44.03350422459264, 18.07846300063595, 3.4993560323792123, 0.19592430532699634, 0.5072668350992665, 0.21853853137262408, 0.16092357135588126, 0.2272338131743093, 0.12135307695115767, 0.16997683072282424, 0.15877995009143508, 0.19078244575329367, 0.2098575754151229, 0.2063962982426728, 0.12971927802408897, 0.19010130165805741, 0.10937602769943977, 0.13470559110564573, 0.12638247481757595, 0.09336426148131009, 0.2929093051821955, 0.1132393554754315, 0.18867331376719862, 0.16692275992564617, 0.14975460696845286, 0.19637617462825394, 0.13117473782791247, 0.12611132565765612, 0.23095834880105912, 0.1195317488764563, 0.1623884233976564, 0.1872781297612575, 0.10890126769100467, 0.17413644300353143, 0.13085992165630864, 0.05709585117837114, 0.16443389347724377, 0.16130612502174993, 0.2699492210822721, 0.13091855802603308, 0.15435960744657826, 0.138163466847712, 0.08420833867163428, 0.13099299112875618, 0.1302522453930109, 0.14018103600509707, 0.13865639846171104, 0.1845816228418581, 0.11379035655409099, 0.11042634956538679, 0.17587371591118076, 0.11577627861932402, 0.0951392412365925, 0.15729246781237666, 0.21792730046135766, 0.12299661900127128, 0.12619782464518664, 0.18107079510246554, 0.06098488886510173, 0.14605339105811813, 0.07047887095400403, 0.18254575950484123, 0.11956211660177478, 0.17734399185545985], [0.061431686664300586, 0.01942861795185074, 0.05288607162994243, 0.02030750849254189, 0.07963028150580584, 0.04772058590465496, 0.04565396413747822, 0.01807349076825044, 0.07095019888853835, 0.03152674931522099, 0.06456008331189234, 0.05210412185518973, 0.04673499846830965, 0.10514669375674379, 0.014172183225802598, 0.06556371211885445, 0.030913557218868407, 0.02803177768064122, 0.021749540690272566, 0.00870266976210499, 0.0789006210623249, 0.07260694829446655, 0.05888685366258987, 0.029910468503892906, 0.0707195298145375, 0.04844314854351744, 0.045243191622918656, 0.0719342158446389, 0.04450047321076836, 0.03006128057266676, 0.05278598990351443, 0.05606802548432062, 0.049742870333213965, 0.025308704747247602, 0.022647761544513128, 0.01608399873329026, 0.018584896592543493, 0.0793961267317495, 0.08070317232200215, 0.03722912286438289, 0.04051248377729808, 0.05515202947501695, 0.013367501707116683, 0.032201080973590576, 0.04701102377786752, 0.04845661636922629, 0.053112691929263454, 0.018917510901848157, 0.01254225455810346, 0.0370512793832008, 0.029877120696548975, 0.03527475979119059, 0.0614146335471061, 0.20571592023536084, 3.211107667415373, 24.964746698256462, 57.249491214752204, 82.3184690167827, 85.24863643030967, 79.62468716406053, 93.50470004543182, 78.39713435019218, 59.25265350649434, 76.00746170167001, 38.21914349832843, 39.20798086350964, 31.877274974699947, 66.9219030872468, 85.49854632346862, 62.87728832614038, 82.94276129814887, 86.98914897057318, 111.77459824469783, 62.714976726039765, 62.30015862372614, 77.46400248619818, 66.49178381889098, 54.146272751592825, 60.456064131952104, 38.74779662778301, 45.04908823197888, 41.7430636190599, 49.063845911333644, 41.552581556381725, 56.88338894997874, 52.02316437998126, 53.77800926085442, 95.76694273179578, 93.02496279439619, 82.54293841700401, 95.32348740485408, 88.35003099133893, 86.68762068594657, 121.31561463879002, 110.45078262206047, 129.38424387285787, 131.57810395763767, 164.1004833098381, 116.99275478239983, 96.71944325970065, 95.22626753776305, 58.46931695938111, 67.28640894736013, 48.029920901021654, 46.469476530628825, 34.90681171417236, 44.27107434118948, 59.4770013132403, 67.34929238596271, 80.67761605785739, 87.46201422906692, 109.24561869713568, 104.34681369412331, 93.61892730959, 75.34363977370724, 40.06889797026112, 8.558691143989563, 0.41954884846364304, 0.14389267071120201, 0.3136970703640292, 0.11271463121257483, 0.13406126519605038, 0.07193891962449397, 0.06751254020679383, 0.0465312841979246, 0.0852188239655187, 0.026327691701871735, 0.058787718054748354, 0.014546707332614931, 0.06065793403033769, 0.026114826511231162, 0.10168432873944122, 0.02460263598139488, 0.033835579355758046, 0.06768527771196059, 0.022117295452663978, 0.014023146565793263, 0.07049223918828272, 0.061738910904574784, 0.03335292481126324, 0.06169842315777656, 0.04529807799225373, 0.04021140356217662, 0.059630759511022806, 0.052084306991028215, 0.023456495668318485, 0.10366225284674477, 0.0730668078927744, 0.08260009029219229, 0.047233541676354025, 0.0088811787821713, 0.06248902206519439, 0.009648905176999829, 0.034274402179665146, 0.030550805010622552, 0.16429877088915917, 0.03906404899974023, 0.051126846472822854, 0.00980833765014165, 0.08093839195827324, 0.0620414313649939, 0.024257201190677383, 0.04599444808498506, 0.024456408948847846, 0.06545351803182595, 0.06711211370965166, 0.02359430914023711, 0.063841090642757, 0.05063968350089366, 0.04158025329572059, 0.06226433613788217, 0.07396628704643057, 0.0832875622736831, 0.06832007348777787, 0.04378543738576193, 0.036815155763179064, 0.026398698476353483, 0.03177724665992203, 0.03867561177861306, 0.041162563007204764, 0.12575076637609353, 0.03200337283253189, 0.03634610310977986, 0.032887660462649605, 0.06298111481291634, 0.025895974343462337, 0.04015428021610264, 0.01335148280861998, 0.03909833909523103, 0.06474321663019157, 0.02213696476011988, 0.03811055681698265, 0.03209989799577142, 0.03253442881208274, 0.0574079362465249, 0.07006625599798656, 0.04823334387413437, 0.06628493027340981, 0.046606686401871905, 0.01907061548873542, 0.03281384789114518, 0.01294265232694846, 0.06156697779172852, 0.09828599335085, 0.04946796351202554, 0.05437085727950739, 0.0042580148381661746, 0.013007049677863479, 0.045024676533836516, 0.015471169571091813, 0.038934959354059356, 0.047689781509219646, 0.03744813974105543, 0.05504757721698093, 0.05094189369570344, 0.031525759146578854, 0.047227217620539094, 0.013607151246809912, 0.022635762692399086, 0.05353670627359421, 0.044316064356075185, 0.024845392007621068, 0.06764063776861276, 0.0751422473319596, 0.06336736102258006, 0.06986290561936556, 0.0026451380906491392, 0.06900394485602457, 0.020915337973424507, 0.17253646837367168, 3.4361085487950236, 32.50198302730438, 71.67654529694589, 103.47168584023754, 104.25932130505963, 96.73803529431744, 116.48087763017224, 112.50249601179554, 100.5327715412263, 103.63499764473208, 72.64458625547348, 61.679106220122314, 41.30515452354185, 42.32863033971479, 65.5824960431745, 50.60899696042461, 52.94843973652009, 76.58595638890421, 87.08622763233801, 69.16106654751685, 72.0324533216415, 83.64598735686272, 78.1411918517082, 66.10004886504143, 64.75681751005112, 48.727020217526345, 53.85083198547364, 49.43162695054085, 51.47550344467164, 46.69081980182279, 57.999895541898674, 60.49655475924092, 55.60922661135274, 83.51484683252151, 82.4079147461922, 78.99081645473358, 86.26956662824078, 83.52845745701944, 86.52966683910739, 92.87526161439958, 86.58829842844318, 96.46542272260113, 108.33870395537346, 116.27682808906802, 84.52274691674018, 56.58623803046442, 51.90430087427939, 43.180114146201845, 32.94391647461922, 40.00624595149871, 42.6488487182125, 60.50088897828133, 76.44088360571092, 100.08926914584254, 108.32124156336631, 112.6664589297387, 108.93065237229871, 121.28623608619937, 124.49497022936423, 116.23461554127356, 98.24876754514634, 53.07111970839962, 12.569337198811194, 0.9072495528286504, 0.048979885065026825, 0.2291810707820039, 0.055748022897469426, 0.11231075731977341, 0.09824165218179265, 0.08652990683913232, 0.04853354691858253, 0.037837224306478616, 0.042502604004356175, 0.012122363682025144, 0.045370048122300256, 0.02622814432177092, 0.030321241018452474, 0.11705799734279995, 0.02154640481627036, 0.008259999261598193, 0.023596268410103458, 0.018794511655165304, 0.04514212930394758, 0.020034848224191416, 0.07649883582827545, 0.015535487440384686, 0.03596854433717747, 0.08907334173038121, 0.05772829889470051, 0.021739675393027645, 0.030717122698983843, 0.09679751515749002, 0.05182049695342299, 0.019331035587275704, 0.097661018822222, 0.033698652630611774, 0.025797147086010348, 0.030491306791983308, 0.04126832527559131, 0.02843762808028729, 0.03990776844382767, 0.02932009242114521, 0.04284528279376607, 0.0029875300758923857, 0.021264333157770095, 0.016692559828140562, 0.011542723363926335, 0.026078096425701535, 0.052190777890744715, 0.030319616912053, 0.06265306064198095, 0.022538002212381652, 0.04933665221136424, 0.02929400521210365, 0.08476805016999284, 0.0827692961320281, 0.028156255477017937, 0.06527079840100582, 0.025491673356643128, 0.010570428510677191, 0.12394591685264342, 0.03213283403085605, 0.15497843795005353, 0.10168782976125518, 0.27442391000447736, 0.09263606426576454, 0.14782515324411855, 0.1402757551160551, 0.1847301519686176, 0.17387205073910375, 0.15124553664317056, 0.08385983761399986, 0.174514859794609, 0.20634619609242488, 0.1421188554095645, 0.17512065148161304, 0.17743792955673512, 0.15839699805984575, 0.13356975850559052, 0.1748570865921436, 0.18470064226177432, 0.11331655415556124, 0.12638393038463208, 0.18589587731947824, 0.1588358132228736, 0.11988771163047322, 0.11007216413535419, 0.2210157839280944, 0.2170361716660761, 0.1613187501507421, 0.1574973810103632, 0.1349804174876021, 0.08474342044322722, 0.1518510985037973, 0.1655807730651671, 0.11627776743543726, 0.06762854124028837, 0.13028924743975365, 0.10699335635910112, 0.1319096766171917, 0.19012223118014876, 0.1979388867414767, 0.1918458677227459, 0.1480616599081024, 0.08586486591206444, 0.1419315775555949, 0.20083790134278037, 0.14618089873223536, 0.18346610689355483, 0.1954761898565677, 0.1528351077990186, 0.18452123979166632, 0.12089019896642816, 0.17259899647005145, 0.1586404454804236, 0.3823345953658704, 6.8865999387156585, 44.65402710822321, 89.91454678197061, 116.53601046531432, 113.57884930026148, 102.24501163728776, 116.53916405093287, 103.74783638984927, 80.08550290138491, 97.11958777519965, 54.84245815584737, 56.51640415191651, 45.04443237858434, 94.55994313763034, 113.23463778341971, 88.14227088805168, 119.68480294750584, 127.54098092356037, 159.37987942849438, 96.94074338482272, 95.30040033401983, 118.32653322527487, 101.43610123665103, 81.10935918746456, 94.29513608255695, 58.749750737221014, 68.73781927170293, 62.98820118750296, 73.57334859909551, 66.40577408575243, 84.633710768915, 79.93487604202764, 82.14783022480627, 141.85722412601595, 138.71272271679294, 119.96008273093932, 145.9176774178782, 127.14894002483739, 127.8120167024674, 170.38553237915042, 160.10081106616607, 182.03536402794623, 182.7413122115597, 227.05306545380625, 158.2065886835898, 136.13947529946606, 132.38142105840868, 80.6725012871527, 89.16080059543734, 64.63030146014306, 61.5712018166819, 52.86224957435362, 58.470615263908144, 80.79302787780762, 89.4904052057574, 106.6009606084516, 111.58915642769107, 134.97956768158946, 135.9528018582252, 132.11482540253672, 113.64576493540119, 68.81846320244574, 16.081569637021712, 1.3072770713798463, 0.18425025917108984, 0.521602669069844, 0.1540455573628987, 0.2202818410531167, 0.2463066292506072, 0.3394881251358217, 0.14504771679639816, 0.1804463108701091, 0.15358228867332782, 0.1332106471302048, 0.11669842631465967, 0.10862829524182505, 0.09590061005925941, 0.27111232641243166, 0.23190675032955987, 0.11803110520685874, 0.1391521799227884, 0.10276182374406247, 0.2188705998442827, 0.2325929046398209, 0.1666821317086297, 0.08748909488560692, 0.2746699161587223, 0.13745656687646143, 0.12367458383162176, 0.10755818532479387, 0.11589483072560643, 0.25341834602577074, 0.23070612201286902, 0.13686001420982424, 0.22148150409902298, 0.12933951291826465, 0.2366922870879212, 0.10745563679524969, 0.10159668828090353, 0.07937261549335334, 0.18772675084971613, 0.3655776477629139, 0.163911436834643, 0.08814720271696007, 0.1604001800860128, 0.2532846177177083, 0.12033200432215968, 0.12116463464354316, 0.19125233344253034, 0.14814859556574977, 0.17346004865342574, 0.15321815176115883, 0.1154715748083207, 0.16842177948884426, 0.2872905711973867, 0.16350657468841923, 0.13748960058775642, 0.12452442814866382, 0.18051437012130217, 0.16224634473121938, 0.179251259673507, 0.20476376487603112], [0.05226278632518746, 0.024875453297769832, 0.039286777572405916, 0.07232776287222102, 0.020346657500692436, 0.027450115848032218, 0.017318107007491975, 0.02049692564704005, 0.04435820302235023, 0.012811218452219282, 0.0699181635413439, 0.054319655793088104, 0.0625470838689756, 0.011815821260003554, 0.04576761711148485, 0.047282023550642115, 0.01065548342247043, 0.01266135345964182, 0.022338371190633026, 0.03994937850943497, 0.0819998910470355, 0.055251705174845074, 0.023954678815038457, 0.05687735141104749, 0.09281941974956183, 0.06912908531845578, 0.02020185156124494, 0.02620145190326918, 0.028986893969798283, 0.05083076115096769, 0.027352952916595726, 0.027083797500498837, 0.035104312888917424, 0.05161019432688913, 0.02071055117994547, 0.03277192755992855, 0.055794892156676906, 0.08016845061173362, 0.09792008677557593, 0.047717820327248306, 0.06340583395813743, 0.04624993074685336, 0.05048571898031139, 0.07595113658856961, 0.015848252411571243, 0.05145930564932285, 0.01576844807488904, 0.11979994093698841, 0.07327248717868522, 0.046095908769676765, 0.11629809174806842, 0.21950588591637152, 4.167744824963232, 16.38466392793963, 53.22872446429346, 72.20766559723886, 82.04828831457323, 78.40151171530448, 73.78213636336788, 56.06286048889161, 58.225016055568574, 31.542182968508815, 27.330020243121734, 43.5956931883289, 55.82201519320088, 69.67022157484486, 90.18471963943975, 99.01545755324825, 84.76872659498646, 60.74784140433035, 44.782080727238814, 19.956574247729396, 9.167602831317533, 6.7748241559151685, 3.686785265322655, 1.3636818576243617, 0.8257115668346806, 0.34018388618865325, 0.8501769217752642, 0.23669168953934025, 0.6132889298662063, 0.8767906936907, 1.7708306230844992, 1.0119414125238697, 1.6271219666927093, 1.1671201211790885, 0.814281412430348, 2.3371888841352155, 1.7138981554777393, 0.5054718604491604, 0.5806055965442812, 0.7813351577328098, 0.8737561274920741, 1.2664802540694515, 3.9512804919673554, 7.32783716532492, 5.977238618558453, 11.940301791314157, 25.647456799784017, 51.88024105564241, 57.55124699684882, 93.68489373114802, 139.41843555819605, 125.40521898577292, 118.18832458988314, 78.69669360499229, 61.9799873136705, 41.51830396344585, 57.68179132092384, 41.76738231412826, 48.12980405745968, 61.3113251809151, 86.78426004225209, 89.03081324792679, 80.20680612133395, 97.63377128108856, 90.24575171932098, 58.51274544192899, 29.24005173867749, 11.53518763280684, 2.304114233101568, 0.512710134949415, 0.01549995149440703, 0.07330807962364728, 0.03779794697860076, 0.026590126611652876, 0.07495335303246975, 0.009646207589896457, 0.05752261960878969, 0.008061995219078757, 0.05595435718855551, 0.024473829788245985, 0.04502652663617365, 0.027037338098330845, 0.05297219140395042, 0.04416274717978893, 0.016693218663755446, 0.05266895848176172, 0.03569888521827037, 0.12378277842916789, 0.06085750376505237, 0.02833506422898462, 0.08017189800739288, 0.013243573578825642, 0.1436568688481085, 0.057234965084541234, 0.031890081835069486, 0.06918567623342238, 0.019488020409499447, 0.04733611318853594, 0.045890911302018556, 0.039777541157579234, 0.07427450720100634, 0.054111360316915866, 0.012447839967095324, 0.09471522689226175, 0.026732887096342542, 0.04567440719373765, 0.022354296243359006, 0.0598842924791238, 0.0764518286732416, 0.05079305430333461, 0.029705063094415014, 0.06299051471174726, 0.01911265073314069, 0.03177383756865898, 0.0246274093496463, 0.06108459520844683, 0.02571490946255865, 0.02952262308568724, 0.026294259624856136, 0.03352998688276257, 0.017007611571781097, 0.04169698594318282, 0.046195132477629575, 0.0500795966194522, 0.064884107860346, 0.06552398279910127, 0.013952817779124506, 0.01870247768238187, 0.07156366677654367, 0.04500029195520667, 0.007849664853570323, 0.027093787287031452, 0.0387291498332014, 0.08933158996965616, 0.03452388637308632, 0.06583177394443943, 0.041534085006963824, 0.040774884213122635, 0.03433997547554393, 0.04058146999487954, 0.02713406819009012, 0.068270162859511, 0.021398965449583147, 0.05290514338881739, 0.05823293250174292, 0.015610690461471679, 0.0343362293055942, 0.07541880507262484, 0.07544058495231214, 0.047846952107765024, 0.0317004099563365, 0.09336886566973503, 0.018925780820990765, 0.040702588495708285, 0.040765610718799215, 0.031133784514461315, 0.072027264883922, 0.04899497316669553, 0.013284671323133573, 0.017001233889811465, 0.009250071185130266, 0.048609749684410716, 0.01092963373183363, 0.028276138661068775, 0.05850776271413892, 0.022959905984481017, 0.06633021373061404, 0.042421042453497655, 0.0292587747436858, 0.013060450794235354, 0.04727107615420415, 0.08632852530647671, 0.041426675649540085, 0.013979072569899503, 0.07970236271860139, 0.14092726693038019, 4.059026039415791, 21.182509083901685, 74.44876670837402, 92.6142906373547, 98.4138757951798, 88.38792893194383, 94.78760534717192, 93.16528950968097, 93.86625628317557, 54.42306656991282, 31.287083779611898, 42.93262827780939, 29.731862045103508, 29.129791951948597, 45.55883161483273, 85.62615671465474, 98.10708368978193, 65.57664778924757, 53.182730751652876, 25.562260958456225, 13.238281742219003, 8.547239784271486, 4.823053738763256, 1.0266761637983783, 0.45643159999482097, 0.3045802869864049, 0.5758291915539773, 0.5137539450680056, 0.5905217160620998, 1.2208665210393168, 1.4912470189794418, 1.0641673423590199, 1.426585766096269, 1.428194673311326, 0.9610254930392389, 1.5442777088572903, 1.2422833976245697, 0.42159721435558417, 0.10465207674931135, 0.2206267185148693, 0.2231241191827482, 1.2657687116053797, 4.4590901463262504, 8.316428892074093, 7.73679034363839, 13.534960016127556, 28.45618174922082, 53.14080453688099, 65.96678241606682, 83.03060670052805, 108.6787106913905, 89.14587989930185, 74.37181765033354, 40.60026537987494, 24.971969742928785, 33.849383861787864, 60.51608031795871, 69.20713870756089, 85.84097708425215, 103.09014120409566, 101.23409132803641, 106.50428202844436, 91.21219235081827, 117.23708706517374, 111.79747350754278, 78.74307170990976, 38.94135775104646, 20.850443186298495, 3.912940304125509, 0.42407235250838343, 0.012313640514959492, 0.1700274384911022, 0.0531496748238081, 0.057434224553646586, 0.09129944002075542, 0.04164797929866661, 0.054892827456276265, 0.03347371772472416, 0.047208345044524445, 0.05732564691213831, 0.02973818490582128, 0.025697860175803788, 0.005850028378077813, 0.016933904337366263, 0.014139376468055192, 0.03528162393899214, 0.03877761638573101, 0.08579660747801104, 0.10299028648484139, 0.01599540832572647, 0.0806730957100949, 0.02468167518776271, 0.11265325224808148, 0.05336235998378647, 0.005162936088914473, 0.03201813534683278, 0.041440124323050824, 0.04037893549989789, 0.032237102427790244, 0.10188437727910858, 0.052973447788146236, 0.024050953084482782, 0.010257330291243571, 0.013475564154495877, 0.008311821279236147, 0.021360450379189946, 0.06453736880493742, 0.0571949408209372, 0.04534885046943542, 0.03786723580091231, 0.03217161340158313, 0.04616275760194948, 0.02311961999493501, 0.0329126808942566, 0.03349983366206288, 0.047952499871532765, 0.03822211071007675, 0.0552923001739527, 0.02333922292886963, 0.04709039048682298, 0.020078589929448023, 0.038209803507573185, 0.03460216140674968, 0.06178101892733286, 0.25223395877307464, 0.09946131778340186, 0.10190312345061572, 0.12781620070698763, 0.17444817950167965, 0.1383768376563826, 0.07207715252955114, 0.10274227318023482, 0.10760801934426832, 0.16869633007914792, 0.14425464725542453, 0.16374262169964854, 0.09608249465424208, 0.11068024642525182, 0.12724531964669306, 0.14186852851942663, 0.0856030400421831, 0.21540573738034696, 0.08185587417815002, 0.19579236966467675, 0.1578150776725623, 0.1598165283400205, 0.12940410945203998, 0.12646060046409408, 0.34699400946978604, 0.16772358227641354, 0.19198465221110853, 0.12362941528760618, 0.08807269300544456, 0.13015793996953195, 0.09021853592487113, 0.1446612254385987, 0.1599765487856442, 0.18286471255123618, 0.13119393599129495, 0.1107095416274763, 0.1526800822466612, 0.21044162552683585, 0.16268019564449787, 0.09830262511968614, 0.25048346318785225, 0.11439288470653758, 0.25322844815110007, 0.2136397668190541, 0.2753127865012615, 0.14528577095798909, 0.2059797762382415, 0.20604513885994113, 0.13272696985833107, 0.14016124029313365, 0.20011905039991104, 0.44318584785346066, 7.727116307904644, 32.45601481006992, 96.08223853572723, 105.67784647787772, 109.28502282788678, 99.34260675984045, 96.7627776053644, 76.87509782852666, 74.21948848232147, 42.71372864323278, 38.7554060259173, 59.61417052053637, 77.62178374874976, 100.09470555090137, 138.09907574807445, 137.56232292421404, 117.6439231441867, 91.40623200324275, 69.97069081952496, 30.856066288486605, 13.671196679915152, 11.160745428454492, 6.723174875782383, 1.976344679151812, 1.178916526898261, 1.1725817764959028, 1.0973345368139207, 1.0710526954743171, 0.9501517023290358, 1.136684857549206, 2.2995566841094726, 1.364135259101468, 2.2118510161676714, 1.4858603789921732, 1.1186374195160405, 2.5659255779558614, 1.9835520343434427, 1.1600050642605753, 0.6620255437108779, 1.1298828548000706, 1.2812851177107905, 2.730632765639213, 7.450170988036741, 13.107491289415668, 9.456147090081247, 19.31398803187955, 41.55316991190757, 80.4473650840021, 86.07975529086205, 137.48149071970295, 196.57753575232724, 176.66019501224642, 160.99175391658662, 112.22452548242386, 85.40636277967884, 59.7986239002597, 72.1741371770059, 51.771085416117025, 64.92583636314639, 85.56961967099099, 108.89052652543592, 110.41850936028266, 102.57446719754128, 127.17473353109054, 127.75809980207875, 89.98036415346208, 49.81557599959835, 26.86887698788797, 5.104560775141563, 0.5658194867353286, 0.17669421139984362, 0.20532135431083942, 0.204357722954404, 0.15264694128305684, 0.20143351938214996, 0.22557449737383475, 0.19783419316574452, 0.1262216040143563, 0.16051861727910657, 0.19027034661942915, 0.10693367044892042, 0.1545960221800112, 0.12599842728025493, 0.09952793678929729, 0.17988709732890132, 0.17398374635846386, 0.14125274704589, 0.2610882804278405, 0.24122601074557154, 0.09986362119595851, 0.15568633383560568, 0.13361601489445857, 0.198831302564471, 0.14818097044142986, 0.21467475160475702, 0.1782151717211931, 0.08284444935740003, 0.13405001902532193, 0.1919998054302508, 0.1630554867968444, 0.10948063700550026, 0.1414676040651337, 0.09787214499327446, 0.23146513128472915, 0.08945784892045683, 0.09467308439554707, 0.15488546551956286, 0.1308979962261454, 0.29419121542765253, 0.1497092239198185, 0.1364921694321017, 0.1837865001852474, 0.0757294230824036, 0.11195236606703651, 0.14917763550916027, 0.20080290644639925, 0.09085700126184572, 0.13334451333409356, 0.0732395913632166, 0.19463277301721035, 0.1714430770446216, 0.1910086715173337, 0.14185599532098542, 0.2188246958558598], [0.038615167441387335, 0.029196717791379462, 0.047788419159910375, 0.03671254211616132, 0.0929038732823345, 0.03919191673518189, 0.021327261535090306, 0.015033376177832966, 0.0988252196581133, 0.07018947357972784, 0.03430504186619674, 0.03146542589210215, 0.01070983736069813, 0.05572542330370315, 0.053797831173024835, 0.022988663009938695, 0.04411568639860038, 0.03684149769645545, 0.021336552266392018, 0.04952996300773756, 0.05410620454518546, 0.051729956852091905, 0.04822772844964939, 0.016544708689194054, 0.014894921107277756, 0.044036928729544726, 0.06785771644283688, 0.049157249741256244, 0.043978878417082375, 0.029052455774358207, 0.01890591807633398, 0.033689992006627784, 0.05660744331356499, 0.054076131763717825, 0.04335566972111983, 0.012649334497719765, 0.07065875605950434, 0.02337972791264615, 0.03936393794813945, 0.03311227361160902, 0.06193996301942295, 0.01313171708100145, 0.08141177300844463, 0.061411144016611005, 0.08212136194830941, 0.06445727431245389, 0.12186822511496083, 0.1352700140447386, 0.021915333608405727, 0.10947730452302964, 3.3997572477786773, 31.604168184341926, 55.51643117781609, 59.80334251157699, 73.68110395246937, 75.53251758698495, 72.73724832842427, 79.98974215599799, 57.8160854308836, 24.971932480412146, 53.07405756365869, 68.36091872184508, 92.02072620391847, 75.57822104423278, 96.28733142729729, 92.95280687270626, 54.524801085072184, 24.215613219045824, 4.62750054174854, 1.6344104659172798, 0.5452853272999487, 0.3814120416439349, 0.38162768007286135, 0.366669905281836, 0.1878649684330148, 0.12506217590623325, 0.23454995285118782, 0.10075208400526356, 0.4463676561511332, 0.39518884593440645, 0.18598295087295194, 0.515393250651898, 0.5876089271999175, 0.49579957139588177, 1.0238809234672979, 0.5515388110952993, 0.43731694019609885, 1.1473033264760049, 0.8317747543896399, 0.3681837256637312, 0.1548130089236844, 0.22865754161630908, 0.2725252070494237, 0.03075880171250432, 0.422773925407279, 0.23881113306889612, 0.16843489491410796, 0.33621971825918845, 0.8278659899388591, 1.4325880956265236, 0.5762094775995901, 0.43099956466786327, 4.752963435265326, 23.3386653854001, 56.57308632327665, 104.04272017940399, 113.09944937306066, 106.06741628339215, 83.71440133740826, 62.987314731844016, 34.57868583740727, 28.095606104020153, 59.98361856706681, 61.012746518658055, 62.25808335888771, 72.171430741587, 79.11699910317698, 89.76224114817958, 97.99397037875269, 97.91062001259097, 75.42823745358375, 24.602180450193345, 0.9364311901792404, 0.5196741499727773, 0.11411965944834294, 0.048112654382543224, 0.047090386656383355, 0.08972267019412211, 0.07205700441714256, 0.017924756712971196, 0.03491011343055195, 0.018079977617749286, 0.04005908613063155, 0.016911758650695125, 0.014416415886502835, 0.07880078448403267, 0.022696955880570798, 0.004784262179577303, 0.006714534181575742, 0.022353426733564948, 0.0680513681483365, 0.047272930086980906, 0.014980785199441017, 0.07858090958888493, 0.04126068354854661, 0.026503424610822435, 0.06890623034128258, 0.08595977654500354, 0.011709896197933103, 0.036853299280928994, 0.037229559534499725, 0.011570102388730213, 0.054119925179909316, 0.0340008168601461, 0.03921929288715605, 0.0713575125161198, 0.03535587701105303, 0.03681101505794833, 0.01568478361267837, 0.0483094662007305, 0.0707592974386869, 0.01942747265040394, 0.04896064859724814, 0.039290293915978367, 0.06354016747566, 0.06313334031391048, 0.019997581877114794, 0.03295090102079896, 0.06703145231210417, 0.02549246434242495, 0.020060653895920804, 0.015167483699417885, 0.042473389241363735, 0.0507090604233165, 0.04905431433731029, 0.03626841030293896, 0.04671506869095949, 0.013085865761123359, 0.047690719966926885, 0.0371032890923802, 0.06957121764219577, 0.05258527486735294, 0.003640188149274177, 0.020479520129400398, 0.03215146145873493, 0.030494572241760554, 0.0795109020245652, 0.041819506384913004, 0.009000506552477038, 0.034012809966600714, 0.033478053782375596, 0.03197344752298969, 0.049442720914920496, 0.048946633018673434, 0.03993798295156129, 0.005736202076678315, 0.020500798221497286, 0.031868443681648186, 0.07046941742901841, 0.033269800441039186, 0.035936112004903056, 0.023970843270240773, 0.06589979489123629, 0.03851087989225503, 0.05379005921103301, 0.0425721762791997, 0.04248838924292115, 0.024122496120511525, 0.06668446810855981, 0.04817409846451014, 0.015592773580142568, 0.017941244840321523, 0.021517609486416466, 0.06957363848003649, 0.019271491403361003, 0.04665847394555327, 0.013365185248755641, 0.03187531165988936, 0.01700788927865365, 0.06472224880370402, 0.05622617284496946, 0.021671415043754444, 0.09153011675563552, 0.16423824994314104, 0.04180364453444078, 0.01652271047444834, 5.523492953469677, 44.650261632857784, 79.26943809755387, 81.21600843244984, 88.99194255951913, 97.7391653676187, 107.34246115530692, 126.05954877791868, 95.25952139208394, 35.0207918690097, 40.43749486246417, 34.31298448193458, 54.182358557178134, 55.65782870015791, 77.90821875295332, 88.77361559098767, 65.0211303464828, 29.875683592211818, 4.722683227831318, 1.2097861930247278, 0.5784536862084942, 0.7645523163580126, 0.683175944272549, 0.49283937701294506, 0.19915761005493904, 0.041922767376226765, 0.06437872731757742, 0.23582426350443597, 0.31726081945723106, 0.6182545279302906, 0.21667231054555988, 0.6046138114986882, 0.3449681972063357, 0.37715997787252553, 0.6676613154911226, 1.0381793110601365, 0.885367017359503, 0.9491128258166776, 0.63422795144781, 0.3435332838806414, 0.11046884446254662, 0.07623296501415391, 0.16035024647510823, 0.09170909787738517, 0.28022846627619963, 0.6800005404699234, 0.23405771071632064, 0.40869883712260957, 1.0378786368716149, 1.789338694464776, 0.7350148464883528, 0.48282522888433554, 6.0810671890935595, 26.881779624569802, 62.02845604188981, 105.03067893366661, 97.08987974351453, 71.95430401832827, 45.11841220240439, 33.428846943763, 32.382564506223126, 37.95052782181771, 97.27612172403644, 100.64102895798223, 96.42030762087916, 95.19723415374757, 93.09828758239748, 105.8847358149867, 114.5649645405431, 117.60217343607258, 95.68724801463466, 36.9624121727482, 2.3481867198021185, 0.5362127012302799, 0.11237248102383268, 0.036211535935440374, 0.0380017685012952, 0.0710267540548117, 0.10024259723122082, 0.029092721355658387, 0.032947955412730094, 0.030880950601591222, 0.029717037048671516, 0.03336412501671622, 0.029446709518050476, 0.014375846742862656, 0.04385730792437831, 0.032547670641853925, 0.03501846507612256, 0.06320389701173672, 0.04234865480553239, 0.038762332931641615, 0.019636842564889984, 0.05604903033423809, 0.05731116785036941, 0.021198307870015986, 0.015389147409868818, 0.015382292838166318, 0.055636495817452676, 0.0118747113963529, 0.03512401667032992, 0.0406266538606536, 0.03621808215675335, 0.01667802139455753, 0.005372914564495366, 0.04161157863094442, 0.009853192098108272, 0.04182803677394987, 0.04148892029338787, 0.05031708004553953, 0.08567811665876258, 0.06781926648991723, 0.050443856105689085, 0.03650472544494175, 0.07563466566704935, 0.01915576041585976, 0.06144701225322582, 0.030705876528255405, 0.033247963104757576, 0.03611849072659689, 0.022945509277163975, 0.06714149318154781, 0.008348539873446909, 0.04905410749357074, 0.016271653885562575, 0.030586267220637495, 0.1862757956428874, 0.11119900286317834, 0.1294522963824772, 0.17457766368264155, 0.24929086347260784, 0.1598386989245492, 0.10813160979699706, 0.06238198426041392, 0.2069282543755347, 0.11767822212629742, 0.10766701577531715, 0.12825149186556378, 0.08537740416584477, 0.09845383555418062, 0.1460791775776494, 0.08104797317496232, 0.14408454509271731, 0.14144803817954757, 0.15330278915503334, 0.15131264594533753, 0.1611641536076223, 0.15451945935285863, 0.14655349325508843, 0.165810844590587, 0.09741248457782692, 0.15630263624893082, 0.19883619020542792, 0.1120707726166133, 0.09851351380348207, 0.10446229378782934, 0.09789385592504855, 0.15434324380851563, 0.1376585842620942, 0.17286144287115143, 0.21829634033624204, 0.15104356522281326, 0.09623823266836906, 0.14861226262104127, 0.15438760029933146, 0.10351197703951791, 0.10569538124987196, 0.07473271204939774, 0.13631411527674045, 0.17875342509679257, 0.18089062654443328, 0.13072866015136242, 0.1964145249897434, 0.2708311108571868, 0.1266628246934664, 0.14995780412948903, 9.697332651384416, 61.373388844151656, 102.60829371790733, 101.35978760257845, 97.7566905175486, 104.13084014769524, 98.23174445859848, 103.38317363492905, 76.45343519026234, 35.69023063105922, 72.78369703600484, 93.91011622644241, 131.24578506715838, 112.28172932901691, 146.22934895177042, 139.1046145654494, 79.60748364848476, 36.888224463309015, 8.309635346935641, 3.1243360138708547, 1.0586088535285767, 1.0205146718409754, 0.6394820275806612, 0.7518066357701056, 0.5254401567001497, 0.2438385237849528, 0.2429780078631255, 0.3709018056190783, 1.0416599242917954, 0.9870624926782424, 0.5512066966583652, 1.137097932157978, 0.8981814619994933, 1.0685405399530166, 1.5043483482253168, 1.339564919471741, 1.2867142908996152, 2.314062344451105, 1.136449637912935, 0.7978049449382291, 0.2942358323883626, 0.4966008993646791, 0.5242508818064967, 0.21529932776766442, 0.6334935489200777, 0.7233728840947152, 0.3106939137702988, 0.5940485397173513, 1.2903271615505219, 1.944539895461452, 1.0296085645114224, 1.1150815458067003, 7.337658289940127, 35.58244782109415, 84.95275635873118, 153.76346895771644, 161.76775563147763, 152.49611977607975, 122.22896206763484, 93.97950295479068, 49.72281194502308, 39.081994333574855, 78.91265930668001, 79.56689496194163, 86.5839445975519, 96.34134246457009, 99.31573852416008, 115.82584181139546, 127.22267273933657, 130.95926377081102, 111.59731495764949, 41.68951542146745, 2.5837326482419045, 0.7118191750299546, 0.26175548172285484, 0.11938059206811652, 0.15047701255929086, 0.2540083716232931, 0.1588169981034533, 0.15645976088220076, 0.15862864772638968, 0.14185423331875957, 0.1678328417361744, 0.10418688517905052, 0.1938870017446818, 0.15695923488707314, 0.12308159347383246, 0.13474086179367958, 0.15246718641250365, 0.16769744335643708, 0.15569135937238895, 0.1393510563479316, 0.12568705084343113, 0.24598013789903736, 0.15624830529334086, 0.13396110686082996, 0.22203370027484434, 0.1353727464353846, 0.11216903871466076, 0.08434188311859485, 0.09971667787120228, 0.11010968712188544, 0.1276417165213535, 0.08525060129261787, 0.10623937262402428, 0.13415201597156065, 0.10126003860345772, 0.15430051142409926, 0.19599380482348705, 0.23610619918232967, 0.15297557768081466, 0.11806319663000685, 0.12530545478746777, 0.13316077480633415, 0.2615364112200276, 0.09904087340879826, 0.19436864122267694, 0.16534507845438298, 0.13587718469000634, 0.1121523303370322, 0.15241234983888366, 0.2082574322459198, 0.19839002059832697, 0.15325455625932063, 0.13804896734654903, 0.10238594270401424], [0.0005393563626585678, 0.02539238453121676, 0.024368398852886695, 0.06586897517404249, 0.030269614353235212, 0.012776612345459721, 0.012203950130741202, 0.04756566377416734, 0.017610451905056834, 0.0017615709422839686, 0.03397041083043141, 0.04863660489659637, 0.02563332301384259, 0.029839733690624277, 0.04407583067433969, 0.011162501478177166, 0.03024357310946911, 0.02513094170529756, 0.023371500128339377, 0.04199892800721911, 0.08184452075511217, 0.10837442902547699, 0.07603955079591082, 0.07781150450389232, 0.02783590048972157, 0.02677879491520505, 0.05327083162903305, 0.030777331464172854, 0.042233052137758464, 0.032433090701458916, 0.0449481098762443, 0.038273453922762025, 0.06429952148708605, 0.04510733742086638, 0.045008895122596336, 0.012417303702433505, 0.03950980491936207, 0.03198578536901022, 0.022362591060359153, 0.02876457525417209, 0.012353031798416089, 0.021548802671473355, 0.05084175451268112, 0.04315982317371715, 0.05346022771611329, 0.04788447509429628, 0.06132528854293689, 0.15328809558864565, 1.4962095526918289, 14.827975226986794, 53.51821499486124, 70.74793200339042, 67.28234537186162, 72.16539029152163, 71.82238686469294, 50.24706809751449, 42.6058046279415, 30.349358820146133, 36.28892552468085, 65.77054623634585, 67.27310426773565, 82.02975119313886, 58.55673090104134, 50.83928323561146, 26.758613278788907, 4.7946856867882515, 0.4881097340295392, 0.2448962154167314, 0.03911063480641573, 0.047569180117739786, 0.16833079888695673, 0.13375657670680555, 0.15184224252739262, 0.2796399575327673, 0.37710861933808176, 0.33263767498635477, 0.43687794117196915, 0.041838302352135225, 0.18623320115429742, 0.21261965946084072, 0.41866695868872833, 0.10965017226314354, 0.49679922420651684, 0.22200785246827912, 0.8021514213854267, 0.41235390389638565, 0.30814489409808193, 0.6298279101329466, 0.6596825404032585, 0.16221882685297923, 0.1594589951057588, 0.26756730050809924, 0.19446441753497049, 0.16561518573472578, 0.13618551975777074, 0.20940972041458855, 0.28974471854106076, 0.3402221292978333, 0.3621675759073227, 0.3722626229207362, 0.22075796469805703, 0.02938176249904979, 0.09751709388388742, 0.44304507153649486, 0.21485496612806476, 4.2703535383747475, 15.880100034898328, 45.15953040892079, 71.38322261071974, 95.02606976416804, 95.98124534853044, 77.68516140599405, 24.380268435324393, 18.923635713515743, 27.313006962499312, 52.96379581574471, 70.18127502933626, 67.26243542086694, 78.31344666019564, 78.4819987512404, 76.00409630806216, 91.08708443180208, 54.557188095585, 7.480594361982039, 0.22869334856588996, 0.03824826878225131, 0.06633304059505463, 0.011035608589619158, 0.04598887479533592, 0.02450044942839492, 0.05986672608302005, 0.12055846757345623, 0.05122882426686345, 0.02613699135010041, 0.04709480698370645, 0.0360822509373388, 0.024227570824986024, 0.07752633593495815, 0.12369352152510998, 0.003315558391360326, 0.023050329257403652, 0.03306814694717046, 0.025623662645117413, 0.07013188675045967, 0.07283394014643085, 0.030737764938103578, 0.01819471652138858, 0.014033498328870103, 0.0195179897690973, 0.04023227945811326, 0.04661843819063037, 0.03437100203647729, 0.04045950113645485, 0.019189397421395107, 0.025164785554572463, 0.009003317137549241, 0.04881991058467858, 0.01989473265806033, 0.009580094202031052, 0.040976166154348084, 0.08718311170777006, 0.027154434637557116, 0.0037150378123060952, 0.0616449348989033, 0.03313274348094579, 0.04138549842361001, 0.04979382284105786, 0.0430273742324883, 0.036807475731738155, 0.02556230666326179, 0.018502743238763466, 0.04309007469865103, 0.0409282933199598, 0.008905702214237423, 0.06919044896119064, 0.027815666192421512, 0.038578755282346285, 0.03043976822687734, 0.021306448841407415, 0.050324024632573135, 0.04337722360486946, 0.026284158755574497, 0.009913136562963408, 0.057060170633297776, 0.03222956795305495, 0.05709027405828238, 0.06404614556700954, 0.036341525734432285, 0.045587812445216605, 0.031384743427136735, 0.06838806379105776, 0.021010443958784306, 0.05261960326723995, 0.07991480656088361, 0.03522834252385843, 0.030433693149637793, 0.05219488029157923, 0.044301650411779844, 0.08416011343680083, 0.032690726070394444, 0.04648100584745408, 0.014179042585554623, 0.02706315909181872, 0.047338622126487956, 0.006414248303870761, 0.01087573274309116, 0.04719815224469189, 0.012235771507896002, 0.014146934883038123, 0.0980499080352245, 0.033424603827898546, 0.005464511388357008, 0.014617121346565265, 0.0358924143497021, 0.07885040399888832, 0.02053647876657065, 0.0623552784353735, 0.1332155654146787, 0.07281334004214696, 0.0763431744229409, 0.04275953074196174, 0.05554019856537062, 0.05411096195119524, 0.29418658825658983, 2.0385774946020496, 23.502230182770763, 73.89248048105549, 86.32444843169182, 75.53476902746385, 93.43850612640382, 108.20366459508097, 97.88941567943942, 65.80175261343679, 40.2441063234883, 32.437850313801924, 30.866899874902543, 49.308374312616166, 69.4627046585083, 67.16477624831661, 59.868159678674516, 31.370744013017227, 6.216336988633679, 0.3846498050035969, 0.36469863847859446, 0.13249254695350124, 0.04175310188363637, 0.14084687366360618, 0.12416186937761885, 0.22024433338834395, 0.33317687831098036, 0.41122683534218424, 0.13958904922248858, 0.5924323393452553, 0.4645526835754995, 0.7854432889050054, 0.7629602630772899, 1.28460111396928, 0.5635451249057247, 1.5346960939707295, 0.8157813512990553, 2.0753772941327866, 1.7526599981131095, 1.460669569430813, 1.1779165676524563, 1.8174293613241566, 0.6089860285001417, 0.5857448207755244, 0.6088173052956981, 0.7740337882311114, 0.413316018398731, 0.15922469477499687, 0.27727617792064146, 0.3624236331351342, 0.07780549071368673, 0.34156131227650954, 0.6949210527443117, 0.2523520742092402, 0.06282449962811605, 0.2542954094467625, 0.7098633832027836, 0.30814749879702447, 3.7320964855532495, 17.870769577641642, 56.14829363361482, 77.71830543395012, 82.28696453955867, 56.15118442043182, 43.46034396079279, 19.76748070409221, 23.676967851577267, 40.05229065495153, 90.6945885381391, 116.41609576440628, 103.00260174658992, 98.45679436960529, 95.4707488706035, 89.64221662090671, 107.35852718353273, 73.05643512356666, 14.11346745106482, 0.18712655160455935, 0.043774647037348444, 0.049643669607898885, 0.021959845232026234, 0.04390336513038605, 0.03669327117442604, 0.027392080857328353, 0.03304311119380497, 0.045326143623359745, 0.018329212832595074, 0.059352864946929686, 0.09523993583335992, 0.07689393801434387, 0.10240386916144241, 0.09656217294715105, 0.015087545297348933, 0.025054057121216774, 0.018451478550090425, 0.06103717053549425, 0.03268215354652174, 0.07964491378515959, 0.02479309310025025, 0.010048632618911084, 0.006251031356382996, 0.02170682937327412, 0.020504825928759192, 0.07655332766232953, 0.0038172698517765615, 0.06522190666967823, 0.05837388501893129, 0.01676400901839858, 0.03517062545964315, 0.062544793266082, 0.07211853659922077, 0.005058833837298857, 0.029468753698071646, 0.03977726536592649, 0.03735245918975242, 0.025207349399645484, 0.06395315398432075, 0.01095550260581677, 0.037607635416451006, 0.030144512195200212, 0.056034926655552084, 0.04385181890440084, 0.04233284275077524, 0.038483147509396076, 0.03461679751654306, 0.03232607587931618, 0.06186450335888132, 0.06782912604150272, 0.025565612332655058, 0.18855947310165053, 0.11221881144710126, 0.11405320898179086, 0.18753101538506248, 0.1083191098164647, 0.16050746303892907, 0.16914525760277627, 0.11009520806011655, 0.11481440926511442, 0.10642181646319167, 0.16416256045622213, 0.09967782955256202, 0.12532109830288157, 0.07990679328119563, 0.1697869175263951, 0.16228087997484594, 0.11682068628649558, 0.18009646915860716, 0.11956868197528586, 0.12729798819148733, 0.14215884519921196, 0.16096209025671407, 0.24036334977755625, 0.16126342328085055, 0.24518801830708983, 0.11672512447882084, 0.0885720367753698, 0.22755239849850056, 0.18434928369618234, 0.08209894621564497, 0.15731250867247581, 0.07853056995138046, 0.1448624307710317, 0.15411125706328502, 0.1364009590038369, 0.13267014145610795, 0.11837727735720335, 0.11378082642031294, 0.14485332964649125, 0.21040865310257484, 0.15182520473195663, 0.16737734117815573, 0.14827783459857588, 0.16992812285259848, 0.1666490979973347, 0.17761978350820082, 0.18107346108844205, 0.341326521649476, 3.1772549161987924, 33.706401701896425, 96.24722911465554, 102.74980498898415, 91.84480005694975, 99.03126470504269, 100.55314433190131, 68.761016168902, 59.11539408468432, 37.5497478823508, 55.77795128668509, 95.73074709984564, 106.16754654915103, 121.34286726674726, 88.19998464276715, 78.02922387276926, 38.818089423641084, 7.520688339587181, 1.1591154216758668, 0.4702157587293656, 0.24189333461465376, 0.12796761798522166, 0.5104246801666675, 0.44677800348689484, 0.4564126010142988, 0.794850358318898, 1.2427267480281092, 0.5256152537561233, 0.6514154098206951, 0.5435196478520671, 0.6358841722530704, 0.511962647639936, 0.9205891047754596, 0.3059031676140524, 0.8637743082738693, 0.44872696180978133, 1.0695250548662678, 0.6699789459666898, 0.5665820200116404, 0.739969780608531, 1.0583366165238044, 0.32822267963520946, 0.3848734413904529, 0.7838163020149355, 0.7265701673684583, 0.4088590414293351, 0.6484994953197818, 0.7725217758167175, 0.6440387185542815, 0.6335686255366572, 0.874730407470657, 0.9413860630123847, 0.43185730735140465, 0.14869771206811552, 0.46844903740190696, 0.8559200684389762, 0.5353070014426785, 6.03678608132947, 24.839387747549242, 70.67592513176703, 106.93102021371166, 139.95430977113787, 144.57340271242205, 123.07252268637382, 38.89185351710166, 28.429599846563033, 38.299591310562626, 68.66292553563272, 90.25817778802688, 89.34477544599964, 97.78961489277502, 98.69438017568281, 96.87420429721956, 123.10325837904408, 85.67659055033039, 14.91295631854765, 0.33818856422458926, 0.1290415660027535, 0.20676932177476345, 0.1709434957874398, 0.12172784716371568, 0.14795981617944856, 0.2039189537566516, 0.15304331517507955, 0.1392269960694736, 0.060689159774131356, 0.13507597929527684, 0.14520635828375816, 0.17646867511493547, 0.16229371960845687, 0.21004175827387842, 0.13529878830717457, 0.09775381505249009, 0.09440051031208808, 0.24993865209962093, 0.11547883732184289, 0.1547653122895187, 0.15762977632543734, 0.14318705776766424, 0.10486061354317974, 0.14351155729063098, 0.08762571134514387, 0.16483733069992837, 0.11255950606878727, 0.1605392556877867, 0.15286432639245065, 0.07965835862823072, 0.19450013255400045, 0.14039881948021152, 0.21379739707035406, 0.10255775324279263, 0.12670165769034816, 0.2218969382586018, 0.14640352388303127, 0.15274734476641302, 0.13025693385110748, 0.10293866748050337, 0.15288721709962816, 0.11156144672103467, 0.13858993267340047, 0.09698035736237803, 0.10200341968166252, 0.18486084656849985, 0.15313922938319946, 0.1654004053242745, 0.1769256159182518, 0.16244543566098138, 0.13175696465036563], [0.06661924338268657, 0.07096671574418584, 0.024085946065644105, 0.02237361506558955, 0.015583616914227607, 0.057161079734684005, 0.03302521154945416, 0.052587825940140796, 0.04947455186817435, 0.05200604344868372, 0.0039744521810432835, 0.02347705172254674, 0.06330806198680113, 0.05875335518090476, 0.03608349199977613, 0.0825571204205194, 0.07458023756982819, 0.09922789845375285, 0.035411150254789865, 0.0029611187158978636, 0.029904709437922127, 0.034461454037697084, 0.06940296941226529, 0.0791737160855724, 0.018246348932265274, 0.05253213517848523, 0.03226777275783881, 0.00924098729756811, 0.0397057663799534, 0.0314964160638591, 0.050036661221735904, 0.02046707311585065, 0.06188795331024355, 0.022765513088914658, 0.04283525853327686, 0.037283894320529316, 0.0696353851667335, 0.038847276760685834, 0.027517001069481337, 0.0666184772947623, 0.020886280258456548, 0.11299505003637846, 0.04295046666576978, 0.0546085169058173, 0.06344769300232012, 0.10550201299690432, 0.4805937373349744, 20.057614503368256, 42.55641806510187, 69.21210442819904, 56.7919938025936, 67.36680969115227, 77.77851381609517, 53.8910755034416, 28.914812726359216, 31.959884012899092, 54.935630136920565, 67.70844028842065, 72.27513820894303, 62.514335724615286, 53.090256952470355, 31.11286190248305, 19.247529352864913, 2.8447845241715832, 0.04975561803627399, 0.10338450766979687, 0.0583037649912219, 0.027959922463783336, 0.06767516535136008, 0.13796517264939126, 0.16856945059712858, 0.009028180521131765, 0.06547155174156351, 0.07327656276644239, 0.1443465778063382, 0.11695665923217613, 0.04078392405062914, 0.02593085815709445, 0.14455297721489785, 0.20203154293760178, 0.11814434066294663, 0.1218903956994895, 0.38678348244678595, 0.14338207310966908, 0.5081700527619931, 0.562569619186463, 0.9459319674680311, 0.5055668859952881, 0.4274918319236848, 0.17813942094724025, 0.19026778788576204, 0.03753777968907549, 0.11154680678080167, 0.17240571248675549, 0.07272825065639711, 0.08841126556358031, 0.13454757781038362, 0.05623672570612642, 0.19409744609748164, 0.37804389011956036, 0.20898415857265074, 0.17544737265956017, 0.03813900166161118, 0.05991904605780879, 0.038841025483223705, 0.09574074283122055, 0.18251159198341832, 0.6378609855328837, 7.264864002504657, 28.520236015319828, 71.48725171242991, 71.0562224541941, 100.41750092660227, 84.05405506010979, 68.76563672096499, 29.213850305926417, 24.910131615977136, 26.856011613722774, 55.057898259932, 70.76784195438509, 77.41248607635498, 75.17217728399461, 82.21786806660315, 75.4522737379997, 22.365329227139874, 0.17191535492818202, 0.11353551740607909, 0.04441699260965951, 0.04511867169170611, 0.031731084116824695, 0.0826363185901315, 0.032625857575405995, 0.05876351350678071, 0.019631253953482357, 0.038655850540606246, 0.013940531644038858, 0.009848301584321645, 0.07653230620968728, 0.06986029325954377, 0.030180746238798867, 0.003713147490352933, 0.06245339514627572, 0.02552341237934607, 0.060093660478390036, 0.0077316466148101524, 0.027760661079458175, 0.012592610474976321, 0.025337143846216704, 0.0064277841198828916, 0.03195446577944583, 0.06000161884472736, 0.04806387373396466, 0.04152617131870601, 0.018894101170101957, 0.05474348627631703, 0.018669434394987843, 0.030276670023017836, 0.03493065990868115, 0.012098738488050239, 0.023985979252404744, 0.01414169388402614, 0.03337531756128996, 0.10669209994375707, 0.0351418741798449, 0.016177359953402512, 0.03760044951172125, 0.006889885961784111, 0.022237519545841123, 0.0410949710696455, 0.04479522553963527, 0.02996713602765193, 0.037087940520817236, 0.047105834819376476, 0.04300441840783723, 0.014716148744487475, 0.021433736265246427, 0.05850979284713826, 0.04237632973179702, 0.02798762994878475, 0.009686206955642951, 0.03146297632596426, 0.027439197179891413, 0.018465789072515986, 0.026068675459452698, 0.03989254627677222, 0.04354883113034791, 0.02753961981544572, 0.013217379117474682, 0.01151562587643463, 0.03361090875020431, 0.06599832145917801, 0.07069164421409369, 0.022949257362333518, 0.062497797602367025, 0.018791818856111458, 0.008454392157164554, 0.06838142180875426, 0.026437269088121194, 0.03248983483401037, 0.07114807173850075, 0.019357268353022875, 0.11987209875857639, 0.03197435533717996, 0.03573348174893087, 0.07256413930125775, 0.07172634554726463, 0.07641951508459545, 0.04510179094429459, 0.023747838905922348, 0.07455822020288437, 0.02831586415038234, 0.05651185469281289, 0.03908446141248269, 0.06510638827157599, 0.12414048020277293, 0.05765878790689092, 0.07262434615122695, 0.07539645062699434, 0.046410131223139264, 0.02992042573168874, 0.06661912846949793, 0.14928199200620576, 0.7618512129110675, 28.497031273380404, 61.53604169045726, 91.16812844430247, 74.24570560455322, 92.38181175724154, 120.1587115564654, 97.03522543753348, 49.859800723291215, 27.74157101108182, 40.683160751096665, 30.23889114779811, 48.72431770447762, 59.02091595434374, 56.74911445186984, 38.10781878809775, 21.669285028211533, 3.3336496208944633, 0.15208912202187125, 0.24728821770798778, 0.048772788516456084, 0.055469048149403066, 0.27375419594107137, 0.6400024157858665, 0.8705538186815478, 0.37553798587572196, 0.44700942332706145, 0.624691259957129, 0.38858155209210615, 0.4143844046179326, 0.031196109597541155, 0.25539402549545615, 0.8841673849571137, 1.2918500217699236, 0.6745671997627904, 1.0116624339453637, 1.3193292891786945, 1.6924709826707842, 2.626319782387826, 2.8670025448645315, 4.346975078505855, 2.282720890737349, 2.001551913638269, 2.0910030363067507, 1.5148550296022048, 0.7211033639407928, 0.5805174657894719, 1.249585747718811, 0.8321180230667515, 1.044881048221742, 0.7546741948012383, 0.27261195884596917, 0.7438813642628732, 1.0708145340604167, 0.9750590593584123, 0.6008930143810088, 0.08398062669702115, 0.44078612339592754, 0.09446381215727138, 0.06997032646810816, 0.16464625304985434, 0.3923313073333233, 7.9076630069363505, 31.200315067845008, 74.81582210909936, 72.35150675619803, 64.56555489570864, 37.13139180214175, 40.60739232647804, 30.904387927824455, 33.06865961320939, 47.54482961470082, 93.17114168597807, 105.77747468025454, 104.83061452065746, 92.95714501411685, 99.11482687919371, 93.0071238548525, 35.14808454821187, 0.6072904614190902, 0.135283435905172, 0.0676062634034503, 0.08954549703987376, 0.03939488023940114, 0.0819939308829846, 0.01724896374188604, 0.040379582844193906, 0.06853925124291452, 0.02342072893835364, 0.047900846393238154, 0.021413377478658673, 0.03904259853786038, 0.08322822876394757, 0.019201076431800763, 0.02551418676551792, 0.02435022150166333, 0.012276551325715358, 0.03185532442594488, 0.036965021713366436, 0.035094813398656347, 0.013586215021449232, 0.018156232094512354, 0.03120412862288856, 0.029768679035647266, 0.04372058421253197, 0.11573395992238676, 0.03088572141413968, 0.033896805102666544, 0.07009787244662162, 0.015953186347389656, 0.03363893224647449, 0.04035904402694395, 0.04327692737382266, 0.03299060352747479, 0.04631619735230361, 0.023490312704516035, 0.05335545370114907, 0.04685292238249414, 0.07965516404158647, 0.042792763636117025, 0.04865406787083034, 0.05533239721590954, 0.034166816622018814, 0.03747615557644637, 0.07360093971534122, 0.040082696960457874, 0.0121052818365335, 0.008805812009790493, 0.033703532610689445, 0.03412724818072973, 0.18309363494476966, 0.15866531269444575, 0.13998899308423843, 0.14428887606388138, 0.14368299244632646, 0.12212064342513201, 0.12855673959899333, 0.10582164020067263, 0.11374920231079864, 0.18422775150787446, 0.18166477371367717, 0.1822499269920011, 0.11565558146685363, 0.17566900189605453, 0.14358746128216868, 0.20259789641826384, 0.13161249578960482, 0.17200662664348082, 0.1892966029023932, 0.06958260936962982, 0.23547949329499276, 0.13266218946345393, 0.1501149747280344, 0.22056397591387072, 0.10038225505981715, 0.18114850706150457, 0.09046713911717938, 0.16547552790612946, 0.1337042529015772, 0.13695194476073788, 0.18409298132023505, 0.16128291255764424, 0.09815563582965443, 0.18576997843000198, 0.12717621851592295, 0.16746507356724433, 0.1740514072439363, 0.23350511617477865, 0.2816294265850898, 0.18967549466798383, 0.15277405059145344, 0.25587589479982853, 0.19224165938794616, 0.13810029523747583, 0.32982447755432903, 0.299475904433958, 1.1239447540813878, 37.681347324002175, 80.67702770233154, 109.4289973474318, 86.36917129639657, 95.50739949749362, 108.25292956444525, 74.94592712771508, 38.47586654847668, 45.73370656659527, 87.76149503646359, 111.11676185361802, 112.84805682397659, 98.17795307405534, 76.33557581132459, 50.585764761893984, 31.614368307975035, 5.470888576199932, 0.6366837841849173, 0.40030297312525015, 0.19450143490347171, 0.17261293927027335, 0.47427237814953255, 0.4817183237643012, 0.6654736135275133, 0.28606302255103666, 0.33114371160345696, 0.38074088733523126, 0.18554025930502724, 0.2613415490956076, 0.16826298478389942, 0.1625738166753323, 0.4371889422257101, 0.5849648206945389, 0.3101516767374931, 0.5458038768941357, 0.5437939073289595, 0.6249059484370294, 0.5721623883132012, 0.5338538858679034, 2.2929862237745717, 0.8266834566189397, 0.6067403490024229, 0.6539382292859016, 0.6639500178637043, 0.2973652402720144, 0.18146067256889037, 0.3640409366738412, 0.3310237728780316, 0.49561675217363144, 0.33026393623121325, 0.1986093209275315, 0.38606210341376646, 0.6508074424439861, 0.5356921291639728, 0.4810620928483625, 0.24405324290837013, 0.5016545362530217, 0.23902295637995968, 0.23792982552080388, 0.2384822515230025, 1.4380159205006016, 12.352308534806776, 43.49091883628599, 104.68020731402983, 102.92445244327669, 143.65944339383034, 118.56921026783606, 98.77431807979461, 41.99442086681243, 31.556111304990708, 37.77359754808488, 74.73597049713135, 93.37850955224808, 101.43017061295049, 98.90745116818337, 108.46949146639918, 113.95373375185075, 41.594692122551706, 0.7052472438062392, 0.36866829159759706, 0.12723827163778967, 0.21492702435822258, 0.1221066469987554, 0.21819558445244067, 0.12095679498968587, 0.15561821329737865, 0.12233786765606174, 0.14310104141552604, 0.15549737058820265, 0.11752663630872004, 0.08547651296060893, 0.12745063121040023, 0.15841325444559898, 0.13784592340309776, 0.13374007517291656, 0.08571023106454842, 0.14951195627931627, 0.15398413243312992, 0.08061041439613027, 0.09371692239637337, 0.11596841347073356, 0.15622742173652496, 0.17549252588181727, 0.22856144354708735, 0.17334354200190114, 0.11147163057279204, 0.06178191141976465, 0.15183559288420986, 0.0989368999557149, 0.13416562169309587, 0.10129025311119134, 0.06858670272894445, 0.12267420323745859, 0.2363387987978997, 0.10913683206684167, 0.20415363713137566, 0.09320706790012699, 0.10411313389458003, 0.14715654234732353, 0.12145977001637222, 0.12683930070770363, 0.07974986783078603, 0.1306028225489201, 0.16198101783952407, 0.08966585711365746, 0.16018057332163857, 0.11357444233351177, 0.1931869505994743, 0.13912221056319055], [0.06462196023353646, 0.02299528200960448, 0.05923237080775923, 0.061219656509497476, 0.04766952997494129, 0.0492239453559441, 0.0252272715161164, 0.025376949774762316, 0.04049646487880138, 0.03719412030712251, 0.05836492562065682, 0.03262570818826076, 0.025588108504551555, 0.03533379069619602, 0.0509188344491826, 0.04917300050897945, 0.016526324494231134, 0.033905833448854186, 0.027679547690035358, 0.033542443472411365, 0.04975833764840519, 0.05327884873916065, 0.03350962426573519, 0.042182463521678606, 0.01592251122929156, 0.02569877182043368, 0.06060816895877642, 0.05193513818085194, 0.055964622766740864, 0.006313935793455571, 0.047481911211845376, 0.03891591057782212, 0.014607152627450565, 0.018567663444686803, 0.04315955504294365, 0.02270633279676399, 0.027819906489082405, 0.04626099305647997, 0.03797391354436836, 0.0362875510097271, 0.12259842181998877, 0.04231156848911797, 0.00787148112243402, 0.0417119246577063, 0.09435563288148373, 3.1494472728621576, 21.79131388664246, 63.735063614383826, 67.72184694966963, 66.00807712924096, 59.175786818227465, 44.68752807186496, 20.380251023077196, 30.88104198055883, 57.593361485388975, 79.57632433983588, 74.61897403963151, 56.99942442678637, 51.955162248303814, 29.651663303375248, 8.54931765987027, 1.0470938778692678, 0.23823373260036593, 0.18732276204372608, 0.009319495988048373, 0.0500475051963041, 0.07477635607844399, 0.04390042335275681, 0.045774098215324265, 0.3271483485737155, 0.10508183675307421, 0.1907030943660967, 0.22703803174438017, 0.455103877691492, 0.6292402287644725, 0.2303214845878463, 1.0253538960410704, 0.7220273885515429, 1.2861744747046502, 1.5469195477424131, 2.0523613162579077, 1.8247185959931345, 3.641977579362931, 3.58726934079201, 6.777173165352115, 7.348070711858812, 7.50945516170994, 3.264856641331027, 4.055919031943045, 3.4175903037671125, 1.8704382330179217, 0.7264414033101452, 1.89506471157074, 0.9722863113687885, 0.25679354555904865, 0.2324716635649243, 0.2396990289731372, 0.170174588659598, 0.2005632741436843, 0.5458714764925742, 0.1017727199641447, 0.11115164330769932, 0.0751438944209968, 0.029716736359161236, 0.10588424490584482, 0.1411715876911917, 0.1448119608985801, 0.10545407121460285, 0.19357232346890435, 0.09777783956979552, 2.995741843215881, 24.251085173699167, 44.208728267300515, 70.49835943406629, 58.82795495371665, 108.58334218302082, 93.41144961695518, 46.38259210894185, 26.17234837624335, 25.22054014667388, 43.92018695031443, 54.47093909786594, 69.50589779884585, 75.23420564589962, 75.2197556341848, 46.39184498017835, 11.45333561205095, 0.3972198369522249, 0.25731131374355287, 0.08072212533724886, 0.026914289055932916, 0.08967682749273316, 0.0418130444332717, 0.05628252627267953, 0.04936672116239225, 0.008141177109322481, 0.03913290498237457, 0.028652762806403543, 0.06303256144747138, 0.06046166996501627, 0.10169575111039224, 0.014954765980702736, 0.05003741581834132, 0.05149655667464099, 0.016768846863640413, 0.02222639594918057, 0.05002244262986126, 0.11216475628316404, 0.0860677949423271, 0.01229467792361374, 0.04389899459877803, 0.09344220326672639, 0.03195463240356936, 0.04718414432699642, 0.010931633221316002, 0.04521044136415567, 0.019175270760071375, 0.03266783536321694, 0.02513388731336642, 0.04294546028118461, 0.038175003963612744, 0.02445701990396746, 0.07652385625988245, 0.025517061510453784, 0.02829371654849139, 0.06680509631311701, 0.031540104142961004, 0.007188579813021446, 0.021295501444969448, 0.06657310190700716, 0.04260185835582595, 0.03681423645766993, 0.03084328205835435, 0.03197186363620624, 0.04672002911026921, 0.02334922037628149, 0.05592753645032645, 0.04869069070405057, 0.036505790307156505, 0.03385334110428249, 0.05343125044037739, 0.02041097249715559, 0.016975868718638536, 0.09625584502974827, 0.009958850944625034, 0.05055311173501034, 0.046210867923594294, 0.016920520781329083, 0.08257759028985616, 0.11045037408269222, 0.03160277588082658, 0.029906751062240333, 0.13065473266666935, 0.016288726154955167, 0.07521234437703125, 0.038640375564535784, 0.05067540235036323, 0.04101464292034507, 0.03395130842803948, 0.03715139175314577, 0.06378081867531424, 0.013545376789425651, 0.051128344174714825, 0.02814348287610037, 0.07718941812673885, 0.04068097715536433, 0.028963685336132205, 0.01444597060101167, 0.03658295451332966, 0.029482619889501124, 0.03827930300406391, 0.06439372731913483, 0.04912028599890971, 0.08364190092130054, 0.012788951149090164, 0.0571171943879416, 0.0369017658334586, 0.04112410922384551, 0.013551087017291257, 0.0710543332200858, 0.05389990472805597, 5.70295560744501, 32.599302914834794, 82.79769635969593, 88.0884010561051, 91.32886717396399, 96.81710243225099, 84.70916148154967, 44.68597089090655, 39.95273697760798, 32.12661808536899, 39.913019057243105, 69.01143597018334, 63.558050970877375, 57.72505114155432, 35.74427304729339, 11.945216521140068, 1.179888539256588, 0.2910550353267501, 0.5004934533949822, 0.060922249685972936, 0.13058524849193712, 0.4047728510152909, 0.3725485269340777, 0.8923268342210401, 1.3572696404111002, 0.6740801517040499, 1.333639689030186, 1.9169619559280335, 2.8666144753656084, 2.6680633617985636, 1.6791970691373272, 3.486059442643197, 3.2609825653414575, 4.410050713246869, 4.6462033833226855, 5.613009775838544, 4.860284386142608, 6.485197813280168, 10.769660607461008, 13.666419233045271, 13.185416037036529, 12.849163009274392, 7.746504093370131, 8.618229781427692, 7.358349773191637, 6.134324150700723, 8.713341374551097, 6.200990225038221, 3.1685651502301617, 2.4038029870679303, 1.751799037860286, 3.2123155122803104, 2.0919071426314693, 1.7501969947930307, 2.741606821936946, 1.2205697692209676, 1.5994235368505603, 1.0290774510752771, 0.7144141906211454, 0.6567118352940006, 0.24904718622565272, 0.12586185678599343, 0.15005336593716376, 0.4717455750271198, 0.14585682821850623, 3.192220474443128, 26.624607463036817, 56.05125027318155, 73.40193317782494, 56.43236344860446, 53.91307607773812, 52.581101925142356, 36.303610878606, 35.5569798715653, 50.33328571627217, 75.35332018329252, 84.47126188585835, 86.63206423482588, 89.53144104250016, 94.30299651238226, 64.16759514039563, 19.002381217095163, 0.7791687836570125, 0.39489730351394225, 0.051395536490505746, 0.044623388187779535, 0.04558577465133802, 0.05383085722344057, 0.059514348620488766, 0.030247328855517893, 0.045192694937389706, 0.010896474573641055, 0.09926693829437418, 0.041548770912472284, 0.05122143917927339, 0.07102938939727123, 0.031690935363932964, 0.013932282792314166, 0.06417448827696424, 0.019359578108114582, 0.04204120839976015, 0.06678851050955635, 0.049146635593065334, 0.014857094558406503, 0.05393186208581733, 0.015272308467707087, 0.04047288852293165, 0.007715351924660706, 0.055770783369699796, 0.006497937185134018, 0.03458567902505879, 0.0512095571555678, 0.06486518548861628, 0.07332170832782023, 0.02041451948424501, 0.0499855631571864, 0.12521232913939223, 0.01843649003985188, 0.0183521973855433, 0.0414510908716869, 0.03304964592379909, 0.04628563427456445, 0.0030397605141549706, 0.019682016854564992, 0.030648117329204277, 0.032602154815028754, 0.020620805894835822, 0.012332241129761022, 0.07204678480423267, 0.041874507667436715, 0.01860325014398944, 0.1705309574402148, 0.15878669166516873, 0.14546492827996133, 0.20506889769627204, 0.220174006516895, 0.1743004624281199, 0.2154091081672138, 0.2358696771965873, 0.13663061684177769, 0.19267688925948837, 0.12328744895996586, 0.16260636009035573, 0.14487065855533848, 0.15760541472944523, 0.15876625243934894, 0.18933308400934745, 0.22293026829438828, 0.0979647726841992, 0.11220943453090806, 0.10407339691394761, 0.11308995300843833, 0.12282324564312735, 0.14398996387758564, 0.0895753744689207, 0.21712312264548195, 0.14458686894466802, 0.2210639861802901, 0.1773856823602992, 0.12866296535057406, 0.10673514642422238, 0.0917571392511168, 0.1750897321729891, 0.10214928282244552, 0.14153397792289335, 0.15613074144048078, 0.1686227549949, 0.11136136753785034, 0.2342573991946636, 0.12579485473613586, 0.11920918755593801, 0.2040433970790717, 0.21456923065406663, 0.15805993469492083, 0.22490637677331127, 0.1795026284432219, 7.860939733443722, 47.249600656570934, 106.20908444927585, 99.12044371328047, 94.19161688896918, 81.61551752398091, 60.867905155304946, 24.835161393688573, 44.62720201861474, 83.82811869344404, 118.39810863617929, 107.01590030424057, 87.5091689632785, 78.39787175578456, 47.161512067241055, 17.848684672386415, 2.180920921025738, 0.8448786576909404, 0.9164318214020423, 0.16904603389482345, 0.1770621021428416, 0.2903410107378037, 0.23973313520752618, 0.3133900836110115, 0.7545310282899488, 0.48894366670039396, 0.7833722774540225, 1.191507948021735, 1.8044110147222396, 2.9472135439995797, 0.9683955040189528, 3.354347723145639, 2.6854164177371613, 4.270145162459343, 4.405376228594012, 6.760184889839542, 6.120190870377326, 10.707990161834225, 10.574333437027471, 17.033688714427335, 13.02613054552386, 17.245728123572565, 8.941914554565184, 9.872586111868582, 8.583158889124471, 5.70822335058643, 3.6489584176771106, 4.974238555277548, 3.159119102262682, 1.323086306933434, 0.7409682076784873, 1.5507139505878573, 0.853974940555711, 0.7453282898472202, 1.6777171098416852, 0.7216840585873974, 0.7332149688755313, 0.44841026106188375, 0.3320677362142071, 0.5736924191155742, 0.34211001509139616, 0.28110833357899423, 0.18009479908693224, 0.6764406218163429, 0.4368140494390842, 5.84475125035932, 38.52022463275541, 71.35132589647847, 105.44914876261066, 87.28648816385578, 147.61065083165323, 135.18756312708703, 66.32028995021697, 37.52184806331512, 34.2635900743546, 55.34556096599948, 74.90821746087845, 91.6164553549982, 95.75272021755096, 110.72516810509467, 76.47536123952558, 20.13999016054215, 1.0626450950099577, 0.6642020914343096, 0.29457413681572486, 0.1336356727105956, 0.18767726156980763, 0.23932986652418492, 0.12587619029105673, 0.09477603895169112, 0.15379660943102452, 0.12819374415783152, 0.19446363612528772, 0.13120499830092155, 0.12046138891169142, 0.255407462677648, 0.10135507181046471, 0.1539785093477657, 0.23517929408098423, 0.0890820368283218, 0.1004725385216936, 0.16491747881856658, 0.30794402584433556, 0.1709727909896643, 0.14037416677080816, 0.07864537588771313, 0.19117698103429812, 0.14730459649956998, 0.11544651607231748, 0.09148369182742412, 0.12303617978168112, 0.17809481930828866, 0.13245471753180027, 0.11951688677072526, 0.08664217702443562, 0.15355683923248323, 0.29128832442145197, 0.150268176991132, 0.1037786445850807, 0.15146816179396647, 0.16377400066102707, 0.1348695952084757, 0.13105976335223646, 0.10536326681293788, 0.12658846819953573, 0.09857028091867125, 0.06831658012684315, 0.10581991650284299, 0.18466045328926656, 0.15957746294236955, 0.1080458922191493], [0.04185821297728727, 0.03436509549858109, 0.016733647038739537, 0.048619126600603906, 0.020069747359582016, 0.015090152869121203, 0.05571972743998613, 0.01422628148218557, 0.01796858077267966, 0.05920986314454387, 0.03846878336081582, 0.03502313821246067, 0.11525860236537074, 0.019241319030463215, 0.049304154761616266, 0.07644278883573509, 0.10200885890592491, 0.09082493282133534, 0.03435604800019534, 0.04113979870453477, 0.016443449102582473, 0.036587777036813, 0.0023025117303815583, 0.06529728206054819, 0.03950978959760359, 0.01947270056623365, 0.05901967032602238, 0.028727755153311357, 0.09684562547913483, 0.0403943645106929, 0.04941533710206709, 0.05315391895090861, 0.06543274172731946, 0.01353907858907816, 0.08294836152344942, 0.05075289214390421, 0.0689409724286487, 0.13351804757070157, 0.02710828741621827, 0.0922822465579356, 0.006373925265976258, 0.03670893767247758, 0.018982434938211116, 0.38786195038307103, 12.435599084823364, 60.59641830382809, 84.9525837744436, 75.30953084268879, 60.43290253608458, 45.34368568851102, 47.0729253368993, 40.68010130236226, 55.123629339279674, 70.82912506595736, 63.50348295704011, 52.53968561849287, 45.57736089152675, 21.28384351730347, 4.404988404243223, 0.02462699183172757, 0.03975465428084135, 0.15843113493775168, 0.14508001506328583, 0.1543387851767963, 0.11808902145393434, 0.020025749014870777, 0.05596338553474315, 0.16632179459256513, 0.1992925487819218, 2.403667175000714, 1.2667144931131795, 1.361806596959791, 1.5953352013903281, 4.153604680492032, 2.9582729118485607, 2.455312042467056, 2.9717031073185707, 1.972178631732541, 3.591830812154278, 4.984522519573089, 6.422595804737461, 3.022920681584266, 4.114222122776893, 9.186267429782498, 18.66389439951989, 23.635996733942342, 12.149084652623824, 7.858436280681242, 9.236486515691205, 10.354506161905105, 7.638267759353885, 4.546462412803404, 6.567574451046606, 5.1368864986204334, 2.6379501002450145, 4.537285047192728, 3.834376455314698, 2.288310513381035, 2.9341797530651097, 2.426446584924575, 2.3688470692403856, 1.6001326278332741, 0.7260260610811172, 0.46684248973765685, 0.17242615171257528, 0.09564930257657844, 0.1292107488599516, 0.23705936577771944, 0.04884262509163349, 0.13485493228560494, 0.07167697118054475, 0.4136447007617643, 1.6875868963618434, 18.447238360681844, 41.47321631831508, 74.01285802164386, 69.68765258789062, 61.08087808855119, 72.48087436922135, 46.92852720137566, 26.21872648116081, 35.47876388795915, 58.116809629624896, 57.872744068022705, 72.82333650896626, 66.011811225645, 81.15751804844027, 41.593962561699655, 5.550423947072798, 0.25910926081480523, 0.08587181432953767, 0.12140370004119412, 0.0025008791858600757, 0.030796066144361135, 0.017216943181870926, 0.04486776257474576, 0.040761810922694784, 0.02280551053944134, 0.09305036461521542, 0.02792980563226006, 0.07815593763464883, 0.05708957308783166, 0.03396926552898461, 0.025681492707301534, 0.06886398059225853, 0.02606300832403283, 0.07639431845276587, 0.04835345496934268, 0.03810140972716674, 0.012101324034794685, 0.004380906832539627, 0.02585180937462757, 0.0476304977951992, 0.06876588303355441, 0.021699513233597242, 0.02365070853322264, 0.07972742911548385, 0.0024668809219879372, 0.08441945718180749, 0.04882979694934142, 0.013529084014496016, 0.07145532662229193, 0.045099327971618024, 0.14548498446181898, 0.04108623383686908, 0.07062582960051876, 0.013710795282085818, 0.01594475554978295, 0.03705272728937768, 0.02296316760381864, 0.025692934230450663, 0.026631773066436572, 0.013874422086613073, 0.0075075591936887755, 0.035649078011873274, 0.10890050160308039, 0.042191641255011486, 0.0694811640066966, 0.033267885221228484, 0.057745493738160986, 0.010842180007227488, 0.021348480255373066, 0.020160758604986534, 0.0422229819119938, 0.023308763273000237, 0.03865355993771265, 0.042994302216797106, 0.04587210001303785, 0.10979585920370395, 0.05103651704567094, 0.09787550811926204, 0.07179265811799035, 0.06542953181891673, 0.0034453420648201103, 0.06741627359822874, 0.07452449701245754, 0.06659248393149146, 0.015132544344411263, 0.04342102851237982, 0.021797522692190065, 0.09104608708331663, 0.06542437604718632, 0.010170305575875026, 0.015288561980630604, 0.024069182146641038, 0.05424218515174524, 0.01584884612971256, 0.0134380555321132, 0.04227010398021629, 0.01666111766450828, 0.10239297539115914, 0.03267752254501947, 0.024067944914643324, 0.09742777569279557, 0.007252716215237254, 0.014446776908551975, 0.02652236421953046, 0.04111939012223194, 0.06660979751858019, 0.6654286288445996, 21.707365359029463, 84.64057491671655, 113.59696280571723, 106.18129053423482, 93.24708661725445, 83.44946876648935, 63.75924894886633, 39.3004350508413, 24.46367959822378, 34.16541707131171, 52.87664467288602, 54.71258063470164, 55.313872137377345, 25.01044427194903, 5.964987095325224, 0.3140474789805951, 0.6991236885228466, 0.22355539604060112, 0.2752394259216324, 0.22301222438052778, 0.8032004102583855, 0.710568858250495, 0.8719120006407461, 1.6357439492017993, 2.7470682321056246, 6.47984181680987, 5.516143902655571, 4.797068526667934, 6.315513628144418, 7.229494029475797, 5.310320959937188, 5.535466969013215, 6.379780682825274, 6.815185835284572, 9.677216775955694, 10.737468734864267, 6.627522485871469, 7.584299868152988, 8.827979506984834, 14.216593427042808, 17.17498621632976, 20.615410843203147, 19.33534533746781, 12.377453869388951, 12.245275878137159, 10.360621137003745, 13.477328631185717, 8.039415911320718, 9.56848769418655, 10.742383464690178, 10.658746765505883, 7.656109150378936, 5.6259526168146445, 5.485860753443934, 5.260138646248849, 4.617813758311733, 3.6509857927599265, 2.3794306045578373, 2.14063425698588, 1.245884010868688, 0.5617289449418745, 0.1347104940683611, 0.7298992790522114, 0.4721074136755159, 0.20521243192976524, 0.15962405640992428, 0.1342555450936479, 0.6155703397047135, 1.0177570004617016, 19.575743482958888, 47.23905732554775, 77.28321260021579, 62.534535931002715, 37.07858885488203, 47.266357021947066, 27.255714862577378, 37.02497789936681, 58.34348732425321, 96.71810180910173, 85.99195695692494, 88.28301337457474, 84.64765871724775, 100.3967986568328, 62.79804468154908, 13.305333679722203, 0.30582233001628234, 0.05627871115481662, 0.04203678041155781, 0.032352701265124545, 0.0338602512173595, 0.03105123279496066, 0.030955393280413364, 0.01644830610002241, 0.014651281207108931, 0.030725543920491493, 0.005407904194022019, 0.022429916782364733, 0.022914559325023044, 0.016495610114126917, 0.028898916432573914, 0.0375863726461126, 0.0338284126032264, 0.018784353329289346, 0.03557569444960645, 0.03773295973998405, 0.015042569232924331, 0.06730231035861277, 0.05707320561932941, 0.01576313238230444, 0.0958991238486863, 0.0689201041935913, 0.04045818346522508, 0.023340174793115547, 0.028998322086408738, 0.026160577282069192, 0.06645486389677371, 0.02003152148738023, 0.10421605780720712, 0.023790937097322558, 0.09982704815845336, 0.05137035901087427, 0.01831177667143845, 0.03735946889425959, 0.0472569456624408, 0.02680215293601636, 0.04883914705245726, 0.07914468901412142, 0.023095273720701377, 0.050949910805831035, 0.014383896411727033, 0.05900352885345778, 0.06517414108759935, 0.1298016324759491, 0.15197158881252812, 0.10525446700593157, 0.15705171702129228, 0.10352275589661253, 0.11317288202624168, 0.14364188416830956, 0.06061196109400161, 0.132591295686941, 0.11568096195978504, 0.10787174511220186, 0.087190366560413, 0.22368428267298207, 0.11944724937840817, 0.27138949702343634, 0.22448839920182384, 0.19265363083010723, 0.18450365041292485, 0.1428143559925018, 0.11528393689302668, 0.13177717404980815, 0.08827900048345329, 0.09009776216360832, 0.12242710157748192, 0.15404240108065068, 0.26705377645069556, 0.18159155102987445, 0.11006320090664011, 0.12516028878669586, 0.117897208359453, 0.15678311127328104, 0.09639313564665856, 0.14367795158778468, 0.20703464866645876, 0.2272439255349098, 0.16142284617789332, 0.11282397494200738, 0.28225596393308333, 0.21486114079673446, 0.23996061735576202, 0.09385755315663354, 0.13253141825477924, 0.1224591317135961, 0.9370350513246752, 29.845222465453613, 106.1065144692698, 126.69193683132049, 104.97956260558098, 85.88818673164614, 70.71598822070708, 64.06609204507643, 59.465296960646114, 83.38844453134845, 106.34708912141862, 94.31786229533535, 77.8134072211481, 76.8845272064209, 36.4644084438201, 9.359249837936895, 0.7631681486964227, 1.2860120640647028, 0.33704329342130696, 0.6046353232476019, 0.46999389966649396, 0.5472979322075844, 0.5407151531788611, 0.322499298039944, 0.8829591110829385, 1.9562720723690528, 6.123049787936672, 5.550494059439629, 6.927793160561593, 7.989987183001734, 11.966204143339588, 8.357554943330827, 7.704000309590371, 9.74105433110268, 9.41333834202059, 13.429536511821132, 18.6531255322118, 17.342830319558423, 17.801702522462417, 18.043398972480528, 27.54136931511664, 39.34916657786216, 58.707491120984486, 36.24925859512822, 29.78572010993958, 30.66905160104075, 34.20391121218282, 26.42547461294359, 17.309419570430634, 23.593699855189172, 18.543656103072628, 14.0647663224128, 16.524245392891668, 9.368396805178735, 6.479143144622927, 9.803767146602754, 7.470818834920084, 6.977595494639489, 3.972380637161194, 2.663126813788568, 1.9452407739816175, 0.5078162733585604, 0.4165393486618996, 0.3025845666566203, 0.4825259949411116, 0.27154418549710707, 0.23368292518200415, 0.24131702199097604, 0.711375885913449, 3.9709318116787946, 28.485348493822162, 65.25662945162865, 112.73364128605013, 97.61648931810933, 88.13455166355257, 102.44877876773958, 63.02426345886723, 42.10754986732237, 45.526515206983014, 76.45967175883632, 78.45171805351012, 92.51548613271406, 91.75165945483793, 117.9180968192316, 77.59437422598563, 18.86458246938644, 0.5965743622472209, 0.22139516598995657, 0.17084883796351572, 0.0911350681957218, 0.09492600832374827, 0.14174040797496998, 0.1891678848093556, 0.12671687985740362, 0.11773442233642263, 0.12409876671529586, 0.08771306835114957, 0.11757132987822257, 0.17957309321049722, 0.09316759138938882, 0.11114353043658119, 0.27615778148174286, 0.22850046294831464, 0.14397645008660134, 0.11519415904918026, 0.11804403677102059, 0.10987487351221424, 0.16588060455697198, 0.19267679732893744, 0.17045597275418622, 0.1002773316577077, 0.17445423159628146, 0.11016984034569995, 0.16515855136657917, 0.12185915463393736, 0.14031830363936965, 0.1420129360931535, 0.13568164840821298, 0.21309775961262567, 0.17550375673078722, 0.2723180875182152, 0.13189463065035884, 0.1927111333897037, 0.12354271711721537, 0.13010229134271223, 0.09204247635939429, 0.11833410830267015, 0.18842274172892495, 0.15587681393709876, 0.08524549914704216, 0.10399923960287726, 0.15163639470213844, 0.21203115071740844], [0.0568914742419316, 0.038547127342392365, 0.029945446163295742, 0.058030034114997235, 0.07138266318267392, 0.04177494688079723, 0.09126701151892062, 0.03815554916077564, 0.03235857332906416, 0.027187753716603886, 0.02102899669309057, 0.06061790976673365, 0.037401450512510155, 0.04922867977931615, 0.0065554785279316775, 0.006593261505552238, 0.013592088042998747, 0.0595370133317286, 0.027140313721892816, 0.06489711603330028, 0.017593019574339834, 0.05320537707678253, 0.043524538482268976, 0.034451019920168385, 0.025123686852654623, 0.08700531036142381, 0.016459077296237794, 0.046909474993064526, 0.028444394551878496, 0.010943786248624807, 0.04084120061428797, 0.04195102452931385, 0.024122792979582183, 0.0351931331228585, 0.029967716339254574, 0.050994638849290154, 0.027714835615047527, 0.0707986513753572, 0.0748885726375926, 0.02737604280663354, 0.02048733805666768, 0.1093594802002753, 3.9160904576701507, 46.90678550351051, 73.12496677521737, 73.18879942740165, 43.91071442634829, 41.24191807162377, 34.62354206269787, 37.55219151896816, 52.84618746849799, 65.52519805969732, 75.20445054577243, 70.68209109767791, 50.341726656883, 27.605478494398056, 3.596496226326112, 0.1776406670650167, 0.2016329014253232, 0.019458466652600516, 0.17856351190036346, 0.03734294820817248, 0.05833749201208834, 0.05570173203464478, 0.21129202908806263, 0.5035644853788038, 1.22812878941336, 0.7900960166608134, 5.786755575287727, 2.0563628692780775, 2.8550844230959496, 2.980839042894302, 3.586810668629985, 4.823652880807077, 2.747762001329853, 5.051467082192821, 5.676100609763976, 4.80214701544854, 8.036783510638822, 6.289566659158276, 4.983293346820339, 6.3555173912355984, 4.753024722299268, 13.384965638960562, 13.96497534167382, 13.00927317911579, 9.383433211234308, 8.409395929305784, 10.50021731084393, 6.347206379136732, 7.758966934296393, 27.81965755647229, 8.576811513593121, 4.873728800204493, 5.5388387364725915, 5.165423212512847, 10.671006133479457, 8.427890885260798, 6.945172692498853, 6.174644154887046, 3.101880934930617, 5.742711280622791, 2.9965162661767777, 1.7730423495654137, 0.4262002689703819, 0.21534019089754552, 0.2757705087142606, 0.47031749520571003, 0.0737375638357574, 0.11131894158860368, 0.08131824133376922, 0.11615225925080239, 0.1502693414447769, 0.39100383017813006, 1.9968812287815156, 17.492794298356582, 54.869310702047045, 70.34521441305839, 63.495457787667554, 81.00171366045552, 62.20008719351984, 35.44601209702031, 22.453678654086207, 42.322366314549605, 53.07790148642756, 59.101018598002774, 48.386585943160526, 61.843928137133204, 66.8948701120192, 21.807158300953528, 1.0679062191517124, 0.19148283397718785, 0.07518081219806787, 0.04235484479596058, 0.0527899582389622, 0.03955197805959371, 0.034012488209672516, 0.023709124652668837, 0.04097277621528314, 0.0607642287298316, 0.021548526879820614, 0.043443091844599095, 0.019660945606207656, 0.10591494970984998, 0.04112064267598814, 0.01439479880049945, 0.0033005612626326305, 0.03795417145855966, 0.014922114355759996, 0.03820502311892567, 0.019141915291848204, 0.02695294585259211, 0.017637433521749995, 0.032442785544140686, 0.030085931366850293, 0.0660231427079247, 0.038305821137562875, 0.04482209224313979, 0.06139461950008428, 0.017701252476282178, 0.05960566247062338, 0.036177150078959046, 0.04951245406822813, 0.06893863586047966, 0.02649456671919794, 0.050899065550296545, 0.03289018855279973, 0.019113102725016016, 0.03523252919436463, 0.03708268132721705, 0.06288432726456274, 0.06452308892602883, 0.12004397058438872, 0.040104568770696084, 0.02476998022757471, 0.050507150289993134, 0.019042488570595463, 0.014116375635738575, 0.03542038544471707, 0.03812645314141147, 0.050771213136613376, 0.05444491116870796, 0.04680055644242995, 0.07388990041950057, 0.031366328588656844, 0.04268011040685158, 0.0808431212640097, 0.011587842112226833, 0.03400565853582756, 0.030055965837692062, 0.05053169191664746, 0.01214360346972582, 0.04669899233586846, 0.00900343875400722, 0.03290076822703404, 0.010548434126371098, 0.02217818220566598, 0.034398899128239964, 0.10453691075165426, 0.035660458247988455, 0.015715080474863852, 0.030707173132067247, 0.07280175679273183, 0.031129837246431463, 0.06921105672635379, 0.03286076694606774, 0.04044636655899306, 0.03155306826585964, 0.01564002588331219, 0.02621260805866651, 0.03913975380841763, 0.07596939246380523, 0.01680792117821834, 0.02723676993721916, 0.09685276541858913, 0.04590222642066018, 0.018076237193458987, 0.1164415340510107, 8.370839030511918, 68.22346318152644, 94.68847920817714, 94.62072418582056, 68.39439222889563, 71.22966966321393, 67.60237939896123, 41.030270899495775, 38.18947076797485, 37.55597268381427, 53.660938278321304, 63.264743974131925, 57.325977433112364, 33.62836222494803, 5.150591260002506, 0.05852707579071003, 0.4085090618220068, 0.03733313079142282, 0.10259550605570117, 0.20906406154315318, 0.331059533862337, 0.9617286391796606, 0.9184381137451819, 2.209503967915812, 4.760517429920935, 3.0679673869763655, 6.339535203672225, 4.928938121564927, 1.5835145260057144, 2.058569202500005, 1.658747547095822, 1.0745955763324615, 0.14387642964720726, 3.5536364874532147, 5.182067790339071, 7.055191253462146, 9.915871427905175, 13.96679041847106, 12.368636381241584, 17.365625173814838, 13.790034690210897, 16.804614451623735, 19.617265693603024, 13.29214471001779, 10.978649393204721, 10.333503830817438, 5.343352710047077, 8.013146327387902, 7.786401462170386, 22.481994244360155, 19.913914549735285, 11.99836757875258, 10.65821038138482, 3.8141657075574322, 1.477188263689318, 2.2168052148434425, 3.467235988186252, 2.426455165109327, 1.653343011294642, 2.410263866186142, 1.6741999695377967, 1.4268151021772817, 1.5386529074561213, 0.6514675037995462, 0.18459893642894684, 0.5937658226297748, 0.18995061216335143, 0.5733030625889378, 0.591008089963467, 0.058623966760933406, 0.23113637231290343, 0.5107632603856825, 1.8740688769086715, 21.24757924387532, 59.59439785249772, 59.54810996209422, 44.09315170780305, 49.088984381768014, 22.53536201292469, 24.573741305258967, 33.17044119681082, 70.51228384817801, 90.65980495945101, 84.94438602078347, 66.1138242290866, 77.30888059062343, 91.61429020666307, 43.11912913476267, 2.563766803472273, 0.23386795073747638, 0.09070786692562605, 0.029745740447974497, 0.0640371018990634, 0.0778021046050614, 0.0608800956979394, 0.04221388078745335, 0.026346510651731686, 0.023388398112729195, 0.09508117943281129, 0.00911807232055693, 0.03678047496284689, 0.03449444944459585, 0.06123908832969685, 0.04688742315216411, 0.027330056463758794, 0.019833478182854674, 0.07045501497604194, 0.013625435850342676, 0.016723023314449578, 0.021298581118425055, 0.021766932801373547, 0.01251010184792141, 0.04486998422972618, 0.07362538558100501, 0.05560482957310254, 0.0838737344489463, 0.05094236100933725, 0.02001545662360807, 0.028206016718139573, 0.01760579026003759, 0.05401401352437754, 0.08530524634425679, 0.030928323563608914, 0.06219212469013949, 0.011294070375903, 0.1101518449403586, 0.030688312047371463, 0.00941580951949882, 0.07343579414150408, 0.06334737378863559, 0.09577585264079033, 0.04854005866593892, 0.026373329474740935, 0.0037194294113320333, 0.12968514114618301, 0.11655395745389885, 0.12735194376399442, 0.1976485394181744, 0.20516282007578882, 0.10631772809691968, 0.15074990839967806, 0.20406922956387843, 0.1067677204827628, 0.09469789032253528, 0.22907066219035657, 0.14693811535835266, 0.1613446132790658, 0.10051427499180841, 0.18186242439814154, 0.13906371208929247, 0.16790169771880875, 0.1667269478522001, 0.09082611259673873, 0.19492534199549308, 0.10576636695693578, 0.11631550492658732, 0.17088098301281854, 0.15484277910042196, 0.19114711892700967, 0.14260411082256225, 0.14009632200243013, 0.2920194480928683, 0.10816606843183119, 0.18976328834410638, 0.09298141670203017, 0.16205330589605918, 0.15018979087471962, 0.1460136157730895, 0.12455469628255214, 0.2686341239079353, 0.17439751044636773, 0.22042074811554727, 0.16428291286912658, 0.13115921688656654, 0.18631298155073198, 0.28060715885892995, 11.73375468100271, 83.81675166468467, 114.10731023357762, 103.90297397490471, 61.0301108514109, 57.64763139909314, 48.007402573862386, 54.405117804004306, 85.33161024893485, 100.26092775406377, 115.92562690857919, 102.49247397145918, 77.57862198737361, 45.67841291427613, 7.423097318218601, 0.374080335060435, 0.6652732662135555, 0.17260768390711279, 0.6724315917780322, 0.3170329236215161, 0.26654399090236236, 0.39754916282911457, 0.30654852008146627, 1.7372398126509883, 5.361254407513527, 5.9851005192725895, 12.625649686782593, 7.782672759025329, 8.324463867372083, 13.12835829873239, 14.683938930111548, 14.621666400663315, 13.121500034486095, 16.219961643218994, 19.868607251874863, 17.33055330091907, 23.06483099537511, 19.053048433796054, 19.883900573176724, 16.753078429929673, 20.850715791025472, 33.57871286330685, 32.724151957419615, 38.294723649178785, 31.63845362201814, 27.026158148242583, 27.387226050899876, 25.86821956019248, 24.324884568491292, 52.758600942550174, 26.662183769287605, 16.325962716533294, 25.76259993737744, 21.712907668082945, 29.514141082763675, 23.260433712313255, 25.354604797978556, 19.306696345729215, 14.937385820573377, 18.351444275148456, 14.259775780862379, 12.209542105274817, 8.072561410165603, 3.4803923531886074, 1.4738763123750689, 0.8604013763608471, 0.1516615836730888, 0.21858261207178717, 0.3490247859829857, 0.3982225847580741, 0.2993110423126529, 0.7052036074380721, 3.9500174887718695, 29.39230638165628, 84.17265184463994, 99.38953399658205, 93.51674172186083, 124.85699715152865, 85.73618704272856, 52.771238819245376, 29.435923137972434, 54.110030051200624, 74.2511655438331, 85.44396262015067, 71.22586496414678, 87.87144691713395, 109.88073672017744, 57.463413361580145, 4.497510252460357, 0.4896055360234553, 0.24168368699329518, 0.11348412056723911, 0.1276357946616988, 0.1591823913998181, 0.12010354924226001, 0.19708725743957106, 0.11470776982605459, 0.1395425936507602, 0.18527741453820662, 0.11068057584305925, 0.06678477200048585, 0.20630183960160903, 0.12448034744950072, 0.07582493126392365, 0.14926835564115357, 0.18773386014565346, 0.17629855763046973, 0.1445506942728835, 0.11918037498910582, 0.19024327307218508, 0.10318748517743043, 0.0746369893632589, 0.11864826563865909, 0.20660306537343612, 0.16771707052905716, 0.2742533175454986, 0.12716896366328, 0.09236071694401965, 0.13723990188971644, 0.1140806349294801, 0.14453702726431433, 0.1748154420525797, 0.05882434088796858, 0.22160207101654625, 0.1626191537586912, 0.22800702571628556, 0.15543398447334766, 0.09414602356452136, 0.15788191118307654, 0.10171614437093658, 0.2433835748102396, 0.1339006931671212, 0.2181606508430935, 0.1374744780121311], [0.08304293507770186, 0.023915474265513402, 0.0281830953674451, 0.03332405478783673, 0.021909402172651984, 0.09166078071200079, 0.033492532844144496, 0.01631938499368487, 0.06459366094561354, 0.024140949263387633, 0.004414735838860995, 0.020398661464212403, 0.03013825325685884, 0.030683343967182503, 0.0697135414567686, 0.02004802302126923, 0.01803140572813009, 0.012711858763659914, 0.03293901899709337, 0.10129157844330035, 0.031631810613156806, 0.0675674993544817, 0.0499106818930276, 0.027838374953716997, 0.0478928905701445, 0.0503784436882744, 0.07000456293744427, 0.03519776412436078, 0.02237094524917343, 0.058835475975948, 0.03327070825522946, 0.05204085448396303, 0.09252550245653238, 0.032730057024427, 0.03757756646542299, 0.04358774073602211, 0.0600763468913013, 0.07568375658123724, 0.1338507442344581, 0.04460258123975608, 3.2643352112462445, 38.13397707477693, 71.19996947626915, 73.72367735831969, 69.83045824112432, 67.73967019973263, 79.37759353268531, 80.71243886024722, 58.79463441910283, 69.66750729468562, 50.640956432588645, 50.626157329928496, 42.59099768054101, 27.05613486228451, 5.164142068355314, 0.20620931150211444, 0.20311037859609052, 0.04919873340235603, 0.015002025944751599, 0.08257673227138097, 0.11740038501879863, 0.09218240231876412, 0.07636080976695785, 0.5607225505575058, 1.8084473787776887, 1.353688148721572, 4.429726792920021, 4.298229823189398, 6.057823223452415, 10.700353307108726, 7.276392829033637, 4.896480998685283, 7.114298920477591, 6.932872629934742, 4.948937796777295, 6.702808458958903, 6.698669868130838, 6.835744448246495, 8.913101803871895, 8.137605584436848, 3.903359424683356, 14.164040530881575, 5.977152326414663, 8.858284719528692, 10.390325246318694, 11.703110183438948, 13.430512201401497, 8.102840146710797, 5.622844138453084, 4.755981208816652, 10.087613386492576, 3.9282211228724453, 5.769220129136117, 8.770874700238629, 9.77714111728053, 5.938087480683481, 3.4842691258076703, 5.136913464915368, 4.637642810421606, 6.356788239171428, 3.828231081847222, 3.5521253943443303, 2.7090722322463994, 2.173685128650358, 1.814800147568026, 1.1097059374855411, 3.6364904286399966, 2.824156289139102, 0.2421303009313922, 0.15973055795315774, 1.4918565798190333, 0.037756769752670685, 0.04754882516159166, 0.05671827325357064, 0.11484688373222468, 0.2797278431394408, 6.2080004811286935, 35.87497818854548, 67.50144112494685, 52.82733655744984, 71.46924803333899, 84.93867504981257, 71.14822556895595, 34.85402445639334, 26.52343776918227, 39.5847951212237, 72.17262314211938, 68.2393095570226, 52.8786450816739, 61.300703402488466, 33.39377703205232, 9.73112779278909, 0.35216786087520663, 0.09783694325315376, 0.030502097140396797, 0.009639207461488344, 0.0780019616227477, 0.015731325369298218, 0.013283746271965005, 0.022523253104619445, 0.08461103278903231, 0.01191878156180704, 0.07638302631676197, 0.04111311586213209, 0.03990263948517461, 0.023462833130672097, 0.08070934699067185, 0.046951736233407454, 0.03996596814343526, 0.056707283722296845, 0.007960048547360085, 0.03524026668239986, 0.014659453450041193, 0.07609317695061046, 0.04997664589374777, 0.07812580739658687, 0.020292855145770217, 0.05753057926232296, 0.028027087307324814, 0.047354698481578986, 0.0023325926515333838, 0.03538201593102948, 0.016907328747272972, 0.015461197979147396, 0.0249749202386386, 0.029395666994875478, 0.013164380197263053, 0.0522062566972548, 0.10847095610393633, 0.07794733189286725, 0.032183380512100075, 0.020638969839520512, 0.06218791120655595, 0.010200084371101713, 0.034238951460969065, 0.03750497197371818, 0.04613235540267441, 0.06510836477842062, 0.03864094246959975, 0.013530723442653976, 0.04759670182641956, 0.04732711165542564, 0.038441483817634084, 0.04383435209972724, 0.04114482807175767, 0.016044873665387354, 0.03862668557332889, 0.037501842504547495, 0.016941285594516707, 0.014979736616594658, 0.04256959456289488, 0.010149962111045758, 0.041085586492573066, 0.03119129090449743, 0.028536786670766534, 0.06945767575093816, 0.05023901185561573, 0.018475150666950692, 0.03768756903047043, 0.09450773963884962, 0.0184402879207365, 0.026104256413095904, 0.006026218545758316, 0.0412248344641299, 0.06285002184731346, 0.10674636195143385, 0.026976164062357238, 0.06305681962159372, 0.0516151815592762, 0.01741125563820524, 0.0684182476552744, 0.0629968387675622, 0.0110520277690563, 0.08195705907118898, 0.2213496910107713, 0.018801931216711962, 6.772015248575519, 52.49837521583804, 94.58205746066187, 94.17872013584261, 87.64187843568864, 109.52820977857037, 101.0244563318068, 53.84904730704523, 37.48101618982131, 43.74962268337127, 44.913527196453465, 47.866189402918664, 51.215042375749164, 33.320028628072436, 7.209182035538459, 0.1272511802193138, 0.3746047069228465, 0.056391981084861105, 0.05855123437340221, 0.3875431965195364, 0.6971047710507148, 1.1541242056315946, 1.6163796979573466, 2.5486813677895457, 1.8627861791080045, 0.7779915210220122, 1.5682588349426947, 2.1905657841313273, 2.262234841623614, 3.0734028114426524, 5.124242738369973, 9.444713381028945, 12.85949355171573, 8.416567002573322, 5.703897466582637, 0.4429663483413958, 0.6854715114158969, 2.4559629107675245, 2.583579185508913, 3.8454635249030207, 11.048682332038881, 23.724814884124264, 15.625409753091875, 22.284848074759207, 9.768591330897424, 4.809481847670771, 1.8851522692749578, 2.6568488151796403, 2.6332216830022874, 1.920371721348455, 2.3886601867214328, 5.032995660458842, 5.32770392394835, 4.232549734653966, 0.47611046822801717, 2.400991628246923, 0.8106809830473316, 7.38222376954171, 8.703000045591786, 11.934513353532362, 8.102471443914599, 8.892206357371423, 7.009875130268836, 6.624579237353418, 8.729440742923368, 5.779930160891626, 3.9369532994685636, 1.73059850450485, 0.7419072476125533, 0.7042613805782411, 6.108670378884962, 0.4415781050920487, 0.6226741810960155, 0.04826698279488952, 0.44339900415751243, 0.20328069526341655, 6.744357145601704, 43.582455188997336, 68.31115168909874, 46.72111226666359, 48.38374222478559, 40.26436536542831, 22.6681322820725, 24.795074770527503, 41.594872551579634, 72.70601057237195, 101.64222178920623, 105.2135084521386, 76.41591379719397, 79.91844131100564, 57.709726441291075, 18.486981776452836, 0.3131189497728502, 0.01459329218168052, 0.09456980808247482, 0.06185112363328377, 0.03126989152552861, 0.10585520251263535, 0.027618607310878656, 0.04561105555283927, 0.018541474728995276, 0.11466941180368585, 0.028981311104050087, 0.04203238306687244, 0.03257802304541392, 0.02976722346859113, 0.039487837348133326, 0.03402779081596002, 0.010231619422894814, 0.03011367524102811, 0.022471681980776693, 0.03327975958405483, 0.03422754824221615, 0.04108790773898363, 0.10756584620403667, 0.05020569852222839, 0.01436095686644436, 0.0400380302040327, 0.06840241261787953, 0.08832468996725737, 0.02635829308400712, 0.016265408353759878, 0.0186332386557854, 0.06983130449248899, 0.03366946468069669, 0.016478696807978616, 0.04098440926041334, 0.04218530187743806, 0.025237630940072482, 0.005215291495269706, 0.06297979714168657, 0.03618951856849655, 0.05379847468688123, 0.05178158351730916, 0.03986228963420276, 0.04577552696930305, 0.13509611208592692, 0.11372922273773341, 0.1678305128288846, 0.15676766694072755, 0.10899543521865722, 0.28250117335588704, 0.18783628610112976, 0.21003889310504162, 0.15319947453756488, 0.10502431887171923, 0.1122783977658518, 0.13001636692112492, 0.14731516851292503, 0.12945352212315606, 0.2500954090106872, 0.0999280491903905, 0.1115766995316071, 0.06722249931866123, 0.1403342995552286, 0.21804590619379477, 0.1594820849957966, 0.13208635181428927, 0.13862114309543563, 0.26609160066131626, 0.15285433660591805, 0.15256273289841993, 0.2505407972081054, 0.1395581299138646, 0.14872044955770816, 0.14818979577431757, 0.13403184741975802, 0.22437606006860736, 0.16545473627986448, 0.13392203637669164, 0.2315017043222343, 0.18802964669321814, 0.12118640686235121, 0.2799570872899025, 0.4212316371981175, 0.15462905589130618, 8.629589946039262, 62.731874296742106, 112.93416853873961, 104.3677277718821, 98.34315546097295, 94.5258185171312, 112.87050062610258, 98.83098063930389, 82.71535796503868, 107.95460193387925, 74.1753775073636, 75.4490573944584, 68.04471292803365, 45.8212342569905, 9.174012964771642, 0.5383353776508762, 0.5781932163142389, 0.09197567349239703, 0.214854720979929, 0.4855149942300012, 0.7381148672392293, 0.4918004698570698, 1.428710955285257, 2.9635242300648845, 8.007532435078776, 7.980810797983601, 11.762024183427135, 16.274156051297343, 16.216305013625853, 27.602252344931326, 22.98463813720211, 21.134775800089685, 23.01235752720987, 17.655623651319935, 13.915003365085973, 18.281588823564594, 16.523986516460297, 20.74725543299029, 26.890957970773023, 24.886746445009788, 17.15687074968892, 33.0420071078885, 22.308533307044737, 27.62457259239689, 33.4978885035361, 29.75528055621732, 29.28110718727112, 27.496099279772853, 19.85862874215649, 20.100739002227783, 31.78184763077767, 21.1731130461539, 21.41508602326916, 23.9902122559086, 32.08034000089092, 22.41470794523916, 20.646297547125048, 19.914334243343724, 12.302894515375938, 15.89059727807199, 10.090400230500007, 13.127706204691242, 10.01134584026952, 6.49595344258893, 8.979810533985015, 5.7589714661721265, 11.681768567331376, 8.410284346149814, 1.8720682229726546, 0.6725370667634473, 3.5844817613401725, 0.18389603543666103, 0.3626215596112513, 0.14302257869032123, 0.39510025552684264, 0.7075788477255452, 11.755416950871869, 57.40029458076724, 107.28618298807453, 77.84451161661457, 109.5149443226476, 115.50784741678547, 105.93611886424404, 58.371473435432684, 37.20105309640208, 54.08885317464029, 98.42734521435153, 96.69627774146296, 78.04666273055538, 98.76593989710655, 77.77772149732037, 23.71554240103691, 0.67642456461345, 0.24120722626966817, 0.1665695780707944, 0.11706794116405711, 0.24957405553469736, 0.226225289065511, 0.06922162873970886, 0.09446247916428313, 0.21343684544967068, 0.1965915832308031, 0.1317621127612168, 0.14145732316518986, 0.10029538068920375, 0.17116704024374488, 0.17500426740415637, 0.16921610541401372, 0.15094910658174945, 0.10194535787788131, 0.09025150068825291, 0.1538729883970753, 0.10294197698033626, 0.10871263386140909, 0.2277688336588683, 0.18961076023838214, 0.1272436648967766, 0.10584600945754398, 0.15303787595081716, 0.14493916213752764, 0.10443413239573279, 0.1260436341286667, 0.24137915172163518, 0.12986546292180015, 0.13000269991255578, 0.10616714585452311, 0.11194143399235704, 0.10296446932179314, 0.1292256416091996, 0.19777560276129555, 0.17377081988078935, 0.16207550712410482, 0.16845302055439643, 0.1182834852126337, 0.19314130708094568, 0.16549870972671818], [0.02779673041415311, 0.08976983822762005, 0.027227542408171202, 0.030692582987549327, 0.010441199053950127, 0.038957497660791686, 0.02479443566933755, 0.013859232478294403, 0.00856007685914876, 0.07534781170468177, 0.043746857197895166, 0.024751017636228955, 0.10015008445348471, 0.03776875902868567, 0.02588262143094213, 0.06450641885279648, 0.027450753616229184, 0.11637224905913877, 0.05466369821900322, 0.04948641473968183, 0.09930118242458952, 0.07709793956770052, 0.053263814263646646, 0.03348402543774536, 0.10226866230368616, 0.024694145183950186, 0.034735629244917826, 0.03902543433791688, 0.03021230331561979, 0.08631229956424044, 0.05159781817647238, 0.032989113486462066, 0.08178245997236622, 0.08795430943850549, 0.03095668988422521, 0.09679217552465778, 0.060123396181170984, 0.18245323140534664, 3.7066209364321927, 33.159580153803674, 86.14490585942423, 90.96082333595523, 69.32383706492763, 77.41035230698125, 52.45201280040126, 31.597972800654752, 35.51320622044225, 83.54951274010443, 104.14111675754671, 45.80772169174687, 50.16154866064749, 34.04047389184275, 9.20155780930673, 0.2881415110201605, 0.30910005252207484, 0.07977663494286039, 0.06708375313469479, 0.10873061394499195, 0.11469271619834247, 0.09827478548451778, 0.17617861890504438, 0.5588094757929926, 1.2783579263956317, 4.208463440018316, 8.829287617437302, 6.041654233009585, 6.23293302712902, 5.2599037943347815, 24.171733663928126, 34.08631463204661, 59.78918667762511, 73.9113784605457, 82.7020219064528, 85.72878160784322, 69.40782285505726, 43.780640786693944, 17.057679891586304, 4.282275582513502, 4.226842686053246, 9.217442427912067, 10.396628495185606, 13.176942736871782, 10.582405674842096, 14.557666067154178, 13.61458315003303, 2.620652202636965, 4.960014079847644, 4.824712901346145, 3.3124210180774813, 3.343646516723018, 2.2705470794631593, 15.304900138608872, 20.48632367964714, 8.20267084144777, 7.65681125463978, 6.620928491315534, 23.674049608169064, 61.046545582432906, 86.46512816029211, 99.9729787149737, 99.18091097185689, 91.73855089372205, 87.47101214624222, 95.68205479652651, 107.59616005805232, 108.6893246250768, 80.07700704759168, 34.1309315927567, 0.43423907470799267, 6.359011242466589, 21.1551191729884, 2.081669266185453, 0.31383891920408896, 0.40731601777576637, 0.0959587025065576, 0.10840390042792405, 0.3800035736733868, 0.3370034874927613, 12.674467505947238, 46.523993553653845, 41.66007411095404, 51.9962961443009, 86.15921466581284, 106.51901445081158, 54.776479967178844, 24.914134394737985, 22.107739333183538, 28.195093101070775, 49.290351021674375, 59.21994093925723, 62.45681416603827, 49.918828472014404, 14.385184741789296, 0.8658459938822255, 0.03615003056643951, 0.03795748095839255, 0.025042477702241273, 0.029570388667766127, 0.04657770529569638, 0.02629109951216848, 0.02988966921674869, 0.046089730270567446, 0.032273242625618176, 0.006966100697736106, 0.06765366126332553, 0.03448916343791831, 0.03285468037750933, 0.013958331696959514, 0.051553637885879126, 0.038939774216663454, 0.07066821724536919, 0.0638648929945644, 0.05862410082632016, 0.04306048072213608, 0.06187698676160747, 0.030012406078317476, 0.04565877900008233, 0.07075791081954395, 0.06937778044131494, 0.062380306527859745, 0.059466031455104394, 0.08763034617708576, 0.020826184491236365, 0.024349819305503083, 0.0302340142473939, 0.01508835160488924, 0.06541428666922354, 0.011871677688172749, 0.055833411057509726, 0.05450175872312919, 0.013774907265249041, 0.035056164262876395, 0.03254207820000668, 0.021182629880645586, 0.0272266288483215, 0.02984361201074095, 0.028142486961798805, 0.045109976593765526, 0.02339390436968496, 0.030905409873793685, 0.07813254897032054, 0.04026173936924146, 0.01759522590756176, 0.027718746493900978, 0.05403835596817155, 0.05359189141721976, 0.019423624973804243, 0.017340833005765756, 0.0743906537912065, 0.061897931605457306, 0.07564488527995926, 0.08633093082255895, 0.040301679363173824, 0.08520472794771196, 0.04369940188142561, 0.013028914784832347, 0.051433055646597385, 0.055259611202223655, 0.08596954416603812, 0.058577036214691985, 0.08277291206703072, 0.03039135338528262, 0.05901007507477076, 0.026948366562024723, 0.08754468222539272, 0.07382764811477355, 0.07637197932889385, 0.025896378454842398, 0.09415418240091494, 0.08773826498297915, 0.04974163310121625, 0.18780104605661285, 0.0899823586786947, 0.19666071500509016, 8.144468261349587, 47.793378445409964, 107.17450526452835, 115.29891844718688, 91.95972550299861, 105.72210650290214, 101.9236126253682, 58.7400624828954, 53.51104490218624, 85.15766882127332, 71.79871928307318, 46.84760870472078, 56.48676672289449, 42.411349204278764, 13.012872934341432, 0.2677561258596759, 0.4027110019758825, 0.011974595855140399, 0.04192560190154661, 0.376693154534986, 0.7641115400098986, 0.958445554058398, 0.8308247440764982, 0.30642772333756574, 0.7491507008671762, 3.7901946325455946, 1.8785080193511903, 0.707182994773311, 6.403600256289206, 13.4776924310192, 30.38644090775521, 45.524942336543916, 77.28150244682067, 90.04269846024053, 97.54298410108014, 101.8636788091352, 84.92756689748457, 58.125936985015876, 26.161942328176192, 7.848005227504238, 0.4167871934271628, 1.299776519017835, 1.7215667568868207, 10.430852155531607, 17.704729764692246, 5.3713952052977785, 1.4710200914452154, 0.6903152708565036, 1.936363837411327, 3.99308045544932, 5.270243652405278, 3.664465753301498, 1.7734450053784157, 1.9554051059869029, 2.003983905719173, 0.44204716540632716, 2.9623818397521977, 11.72356338270249, 36.47330045700073, 79.63071192464521, 104.76700936594318, 121.50246066431846, 117.70060923791702, 108.7984214290496, 103.3652013347995, 112.28514179106682, 127.22432013480895, 124.02397201907252, 99.23976221392232, 48.780446821643466, 5.415635618471331, 4.005679353590935, 10.894769507069743, 0.8348482378548192, 1.018772036317856, 0.4720208763835892, 0.23595701121995527, 0.03781907568355242, 0.9556197927844141, 0.11082222550025872, 12.63113316028349, 53.9518996977037, 45.11494874954224, 54.36152065953901, 73.62425311919182, 73.86017584031629, 33.3641827491022, 26.29236701996096, 44.53330832142984, 50.786256713251916, 84.86960995581843, 87.43804070257372, 79.27135221419796, 73.55785523691486, 30.6940233707428, 0.8703717961907388, 0.1280419361747561, 0.0628981206776394, 0.07399676202405846, 0.1562742297086985, 0.03295700291111585, 0.03941962870979502, 0.07201202739510806, 0.13763734830483315, 0.027826872143533923, 0.034549469879317674, 0.010107681718504718, 0.026756335132484956, 0.023480485711667328, 0.03698214377847411, 0.033420447800909324, 0.018250250235019673, 0.07194812034046458, 0.04024199345299313, 0.015703714602897247, 0.010940674016432417, 0.04691845354353709, 0.013842172657830581, 0.019937001559282505, 0.048316039235120824, 0.023918891017655694, 0.02382956325046478, 0.08189550390647304, 0.09736799785206396, 0.009890925758818706, 0.028835334965298255, 0.013954434224644737, 0.011731304524977122, 0.09702529608001632, 0.06041759309629279, 0.10161363414578861, 0.076879428309058, 0.04347153668922763, 0.0025676748707830427, 0.010284493853818747, 0.045464376528416915, 0.024530568175138007, 0.047969070353334954, 0.18368853286149042, 0.17878530967620113, 0.07465085555468837, 0.14566878427661237, 0.22681209709375139, 0.17936807276020128, 0.12348571251476965, 0.1230375357573071, 0.12531784242920338, 0.13519892108536538, 0.10094419587403537, 0.15707675277465777, 0.21516066585336963, 0.26751842409853016, 0.21175572678687113, 0.2165953953179621, 0.18391912532669885, 0.22274590157453092, 0.16510684043169022, 0.21494176388988573, 0.1575366506773618, 0.21127595656341125, 0.11850450157878861, 0.17984963562940398, 0.21064007294274148, 0.12079868976387287, 0.20949693186388862, 0.2110764519461701, 0.1853445238403736, 0.2303412496562927, 0.1836765206028377, 0.1464701275671682, 0.2064339897685474, 0.2194063710950075, 0.26519019096609087, 0.3300654888153076, 0.16837984383586915, 0.1983862820892565, 11.315717293370156, 60.01511519955051, 126.12288721146123, 127.52856269959481, 93.78831878785165, 109.87467273589104, 80.52243924910023, 47.00639801640665, 44.73674989515736, 103.17056548210883, 151.91725638604933, 71.55270822586553, 81.08352645750969, 56.479847661910526, 16.79785228544666, 0.6111850685650303, 0.6688357589225615, 0.17214475229622858, 0.38364169458227776, 0.47332901747957357, 0.311168551204666, 0.5991801643563855, 1.2107597988459373, 4.512262286678437, 9.336108834512773, 17.434554946038034, 20.934113225629254, 19.042312906634425, 21.34875678247021, 17.22342356558769, 35.487804951206336, 41.956605295981134, 73.19189025509742, 83.47873749271517, 92.15032915915214, 97.67254783261208, 79.4650702322683, 51.03680987511912, 22.303869608909856, 11.904164014324067, 13.314940544866747, 29.085388760412897, 24.281561989938062, 36.03743883871263, 31.89813021690615, 31.97786415776899, 38.679935701431766, 19.42848790076471, 14.577403433861273, 9.79526246747663, 8.353564912273038, 8.837526555984251, 10.64075485352547, 37.28933780424057, 46.025605432448856, 28.806292510801747, 21.4309069033592, 12.211989664262342, 27.271219991868545, 70.2328698865829, 97.60014087923112, 118.8303852081299, 115.34855211934736, 99.59712936032204, 96.84149957472279, 104.59173433242306, 119.76022228117913, 117.42772994502899, 85.48792454504198, 37.76799640347881, 4.170717491257576, 13.837823867797853, 33.984862527539654, 3.687777379828115, 0.512463148202627, 0.7460572378289315, 0.34152484649131376, 0.22309817944563207, 1.1781536258997456, 0.7880226150155069, 20.662004678480088, 75.06313539320423, 60.25456020908972, 79.75761628920033, 110.98428772341822, 137.2895142339891, 83.53048140002836, 39.08009198404128, 31.829969229236728, 40.3565606763286, 73.70999613115865, 86.13052645037251, 94.08826243492865, 94.80902148831277, 43.226107858842425, 1.8186096270238201, 0.36012273401983325, 0.13753228700689732, 0.1792871279101218, 0.2235950334298034, 0.12009457835266668, 0.1702495427021096, 0.16594579863932826, 0.22036569703730846, 0.11703077057797102, 0.07467412930582801, 0.19624028595224505, 0.1333427513318677, 0.08269957447003934, 0.09514762989936337, 0.14284930492360748, 0.19470709886762405, 0.1297180676051686, 0.1702970248316565, 0.14433608240177556, 0.10788407146690354, 0.18853080609152395, 0.09087162588032023, 0.1036727482513074, 0.11944128155347802, 0.11311494279652835, 0.16317395463345513, 0.3476181566234558, 0.16731793872050701, 0.13784961594689277, 0.07478575597727492, 0.10483538626783317, 0.09363033147829194, 0.23072181149355828, 0.1577257518205912, 0.21992996154773622, 0.14070165403667959, 0.13505396192833302, 0.15082394313668052, 0.0939629974985315, 0.11466335970908405, 0.1487083760120215, 0.09875065632044308], [0.09509786482780211, 0.05438780314439247, 0.09765171851482123, 0.041033392922291835, 0.019363849048292445, 0.020754832977188692, 0.044390244649783264, 0.022232258437021125, 0.03105299862762613, 0.022147860445622957, 0.09251545138296582, 0.04434994842496611, 0.05908319433670371, 0.012350728746593721, 0.041584508914139964, 0.03281480933149015, 0.07248012243860191, 0.03488522323389207, 0.045097470208401644, 0.031340051772854025, 0.007698611945905273, 0.06931520637965972, 0.04735402815464524, 0.0688752880500209, 0.029216164933337323, 0.029991342490839384, 0.01629338205431498, 0.04509922071930863, 0.06940134530586582, 0.03909863020864226, 0.07030607982268257, 0.10491609363065613, 0.030048774187302882, 0.015895866691285086, 0.052585462558894396, 0.11545177143547805, 1.6230729775082682, 28.632125546855313, 83.4946152471727, 100.9039140516712, 80.14790781082647, 70.90325786221412, 64.14234292122626, 38.60597941183275, 21.054828090052453, 44.183723157452, 60.39937019348145, 31.105356447158325, 35.056846295633626, 37.73295002598917, 18.109463453292847, 1.9579236353597336, 0.326959339361037, 0.06855672570846735, 0.13808249135411557, 0.11551000177860261, 0.17890903287597243, 0.15954643638143617, 0.22991351212464997, 0.7702583843661893, 0.7489219776565029, 5.229791758521911, 7.762706914255697, 13.929529863019145, 21.83669767072124, 46.76167349661551, 83.1925456754623, 105.02942377521147, 116.31656169891359, 127.77728019222137, 128.24670160970382, 122.3374705160818, 124.66491083944999, 124.63732088765792, 134.95826136681342, 132.93999794990788, 130.7817529862927, 82.61510218343427, 29.19295584001849, 2.1963860911707727, 5.932658430068724, 22.784818872328728, 14.789980207720111, 20.094392607288977, 3.2054947556987887, 2.4112677478021194, 16.845199215796686, 44.38754127871606, 59.80420151064473, 36.8675692619816, 6.627665652382759, 0.7804666591748115, 0.6107543432904828, 2.122114541069154, 14.873507080539582, 82.7400924313453, 120.62184933693179, 131.60878473712552, 119.1596289603941, 119.0571217383108, 120.6666349595593, 133.9661527449085, 121.80435765174128, 121.81758388396233, 122.11873562105241, 120.40827628104918, 131.29681510310022, 145.53471288373396, 108.12757845847838, 18.889256138955396, 1.1985867230161544, 4.706159753184165, 3.2400118583633057, 0.25200817734003067, 0.05999884943688109, 0.311766988447597, 0.07259918016291435, 0.044299191269542904, 0.16821746383943867, 3.4899001784863013, 37.52514677663004, 37.36386675988474, 43.78157038842478, 73.86124272500315, 86.7938227807322, 76.29305731865668, 75.65593888682704, 77.3361881317631, 32.77001230947433, 46.731137844824026, 45.83918694526919, 56.87378698779691, 50.74005903736238, 25.497581074314734, 2.706699933736555, 0.14223188402191286, 0.022613555718694004, 0.06345428135846892, 0.06633482557991821, 0.02018032449057266, 0.10465037603411945, 0.05772473658585261, 0.024918292934495597, 0.06472522888572947, 0.029860023529298847, 0.03865450222585951, 0.03125090786676494, 0.04962445229231831, 0.027777290933074492, 0.05258527486735294, 0.01586507857521816, 0.02500119130878199, 0.07091550276644769, 0.0980404238667219, 0.032253435422335906, 0.043211043812334544, 0.04541633515468529, 0.06352973718857093, 0.054436595284289895, 0.03563486325043825, 0.12485841950101238, 0.015200431225821378, 0.0858494675447864, 0.049344148381703326, 0.030990545224818974, 0.018047254172063643, 0.04782339107365378, 0.028485430051542582, 0.05942537899940245, 0.0373961070492383, 0.03440120505289205, 0.017398438987232024, 0.02671196331991063, 0.045186420677289854, 0.05700464841098555, 0.06290476649038254, 0.04732056926455229, 0.05125926477053473, 0.037624700024964354, 0.07905179319242317, 0.023558762660550497, 0.04881901043136755, 0.06054197513167897, 0.022522663216917746, 0.029901488038200526, 0.05515408642109364, 0.10632039408289617, 0.04973900158919635, 0.09328349283145321, 0.07480169826697919, 0.061496639428960706, 0.06660000691490789, 0.09267783904027554, 0.06040622052105685, 0.01067614577139818, 0.026890457975828362, 0.06614816825716727, 0.10108642775805728, 0.06865349793506247, 0.04971550567255867, 0.0517865477670585, 0.04322098380315208, 0.05986628175202397, 0.008270444870445757, 0.044963872135286374, 0.048783417986405474, 0.03749705062458112, 0.08106372394268552, 0.05942373574080487, 0.03426147061550329, 0.1952287741005421, 0.14516862079260812, 4.477123733489744, 45.6889013321169, 105.96425794786023, 123.208966255188, 99.37390727381553, 90.765104909097, 106.56568281112179, 80.34834877137216, 34.614995218092396, 24.898631226631906, 28.572991894137477, 31.78079643557149, 42.756180455607755, 48.12746632483698, 24.050371608426495, 1.7543612036012834, 0.5159793998445235, 0.0782560346828353, 0.18645175071733613, 0.0915816591511811, 0.7666114994114446, 0.8727347790714234, 1.1420203841501668, 0.7576335005221829, 1.2849176002125586, 5.740888849381478, 11.151495498995628, 21.84592308536653, 32.856125985422445, 64.13350189885786, 98.84259869975429, 122.32830785935926, 130.83018641318046, 138.31378629130703, 132.02570915222168, 125.66181259770548, 128.31712384377758, 127.22855629459505, 137.55985967574583, 139.5772131027714, 137.40167833143667, 97.1416001166067, 41.94757207747429, 5.461221894910259, 0.5394324768454798, 0.8198752638793761, 1.40142964499612, 1.3886526467338687, 1.0225804126070392, 3.1766587159326, 25.714321444111487, 60.978123757147024, 80.9048624961607, 56.7740568037956, 13.722500301176503, 1.7960671527731804, 1.063167505687283, 3.660925569072847, 25.24208180366024, 96.94559927909606, 132.59195819977793, 136.9528336678782, 121.15455427477438, 119.55242295419018, 122.5799749743554, 132.4107760767783, 118.48910762417702, 121.1996772212367, 123.42182543969925, 122.38061658797727, 133.61026825443392, 149.1632975301435, 130.30544388678769, 30.300174259370376, 2.2574375377547358, 2.1494465970223953, 0.7532664316315806, 0.1995336060081759, 0.17261462466370675, 0.29940622107636544, 0.047982994001358754, 0.06347259469029885, 0.48582915156599016, 3.039699600588891, 45.07111626286661, 43.47291907956524, 47.778151804401034, 76.26645580414804, 68.06905515732305, 44.848062838277514, 56.85456737395256, 39.52968974267283, 41.708884085378344, 77.27754085294663, 72.15958518366661, 79.17839204111408, 72.67261551272485, 49.19929319812406, 5.262481772130536, 0.13894824731734493, 0.09264764751517966, 0.10290702804923059, 0.047760617829138236, 0.015448044249487501, 0.11403888313760681, 0.06191130750061524, 0.03982788462552332, 0.068660645535396, 0.020973108663794496, 0.02364519078494801, 0.04816751776924057, 0.0735746092733837, 0.04304666049598206, 0.03241587287536071, 0.03370873051725569, 0.01836244381153055, 0.09704240282336551, 0.07253626902257243, 0.022060806044347344, 0.01657266515277086, 0.0557457093119381, 0.028760285161796118, 0.025802854441046238, 0.054189455319917014, 0.012372217512869788, 0.07627668565199261, 0.05992363875491485, 0.11880333715629195, 0.04992938976013853, 0.06894856435997833, 0.07517999248398889, 0.04412209855452661, 0.050875416416074, 0.028292109679070213, 0.048891899866923216, 0.05870887994646065, 0.0719878190167008, 0.0248458631516945, 0.034839863167895425, 0.04866562813760773, 0.1965426148906831, 0.19174946321835443, 0.23258401801989925, 0.10812886720222813, 0.1295654782124104, 0.10403425748189611, 0.17468198953617006, 0.0879270903345558, 0.09231441458987613, 0.1299240839697661, 0.22087571241201895, 0.16257844384639494, 0.14763576098747794, 0.19754841172647095, 0.15480067490810348, 0.1515893722253461, 0.2096571055270972, 0.18775039232305943, 0.17901312890312365, 0.13545340017205285, 0.1914139167075196, 0.2216520505927263, 0.16773637594474902, 0.1499969205789028, 0.1852221642771075, 0.16564183027273224, 0.1459720938075935, 0.09165579347961372, 0.22657471708953383, 0.11436173557153634, 0.11901708334804544, 0.19749683868740836, 0.22750709205865863, 0.12090351357455216, 0.25778579796033524, 0.41991819477369713, 6.452093499322092, 59.78995153980871, 130.1329537360899, 137.04199698663527, 104.79375208577802, 92.95363057044246, 90.06496967807894, 56.65061981447282, 33.33362356308968, 65.87310052687123, 92.74537624851351, 50.289123750502064, 58.14433682349421, 62.134061936409246, 31.62670220098188, 3.002378248399304, 0.8733565360307695, 0.21703148320797952, 0.41777979822889455, 0.2803431956037399, 0.7687880471348764, 0.4272802997260325, 0.5248692066919419, 3.5894187996464395, 8.748347547746475, 16.962785990007465, 15.617846442807107, 22.46800118877042, 28.124843451284594, 56.47422298308342, 96.1119544121527, 120.95770620530652, 132.88721853686917, 148.3647814104634, 146.70248093143587, 138.22176748706448, 141.4432571780297, 134.46385445133333, 147.96717859083608, 145.0478369189847, 144.55412034065495, 93.1003664385888, 39.2621527179595, 6.365975901003807, 20.919614184287287, 40.68543572579661, 36.97519909950995, 44.37200084809334, 14.876349818321968, 5.1107350760890595, 25.32646767554745, 65.43162991923671, 88.67452083095428, 65.52145611855292, 15.34660081709585, 2.9638262525681527, 9.648253014010768, 6.180286484379923, 20.711246113623343, 97.56618099827921, 139.54735602101974, 149.27577541720484, 130.21115795258555, 131.4831276862852, 132.51944142003214, 142.44037074427453, 122.23404545937817, 127.47990177523707, 133.12802068648801, 133.06463518450337, 146.97084949862574, 165.12665379431942, 125.47503717484014, 22.343181563961892, 6.064208842092945, 16.596956329960978, 8.003987593035545, 0.27431371591744885, 0.19878104719663822, 0.530865652666938, 0.33992951435427515, 0.09550474178526672, 0.6980901439824413, 5.752431404206061, 62.17612935650734, 60.04765910487021, 62.97828151333717, 87.41787187514767, 109.71362021661575, 106.03573922188052, 92.32634159826463, 102.89396778229745, 48.16074371337891, 65.88803691248741, 74.66875676185855, 86.68516528221869, 91.91429661166285, 65.66410879934988, 8.210992640064608, 0.2895803467160271, 0.18631917154116018, 0.14650501521123996, 0.20938028731653768, 0.07344111845257782, 0.2553746128274549, 0.1286862391017137, 0.08744369651521407, 0.09713976493766231, 0.09448188417140516, 0.08702004223220772, 0.1831491916410385, 0.19888632299919284, 0.15706395910632226, 0.09610069690332299, 0.14083542831001744, 0.17810099397695836, 0.15144954585740644, 0.21559991002563508, 0.0895098892731532, 0.13188935996543977, 0.16848728000637025, 0.10454005171214381, 0.1892743557090721, 0.20132013836935644, 0.17835426264472548, 0.17742564150642964, 0.20934782051030668, 0.27187351137399673, 0.13552679139519894, 0.10004864675143074, 0.23873806360267827, 0.13943190926746016, 0.08785090289048611, 0.13984280818652722, 0.17272484939425223, 0.15542218671931377, 0.206774071519894, 0.13669429407004388, 0.10920607875431738, 0.17157153466776495], [0.04911658579423543, 0.03649548642457493, 0.021572597362401507, 0.03932633069193652, 0.050977106927142996, 0.06814620217248317, 0.03685944330608172, 0.1558622735882959, 0.10938630859938361, 0.06570513961055587, 0.0764589686126959, 0.08876078551815403, 0.04293841993316047, 0.017154556811757146, 0.03978712491751198, 0.02750679677832992, 0.029871457391568733, 0.14448565340811206, 0.06712764231187683, 0.06431765478825377, 0.04091499786403391, 0.028691009746023247, 0.03375287250345273, 0.03556334128182742, 0.09073386028889688, 0.08946210070843659, 0.04182160546582553, 0.06444979729431291, 0.052249996487291596, 0.023597268154844645, 0.07948156085706527, 0.0986049387363657, 0.07623924693513302, 0.05654956154044598, 0.22521059028804305, 6.42869460005914, 82.03266943654707, 100.34214435085174, 94.47542390515729, 69.405791067308, 72.79997487221995, 72.35450344700968, 45.601671741854766, 36.20479460685484, 62.353118465792754, 81.87198562006797, 66.30173713930192, 43.48354085799187, 34.504015676436886, 9.63894130722169, 0.017940978624767834, 0.4098736176327352, 0.09202232058610647, 0.1725603856386677, 0.29745131791118656, 0.03837784106332449, 0.31577568140722095, 0.4234306159759722, 2.694856091853111, 4.8529868164370145, 28.18229832956868, 54.80035543441773, 94.26355315792946, 109.21522817304059, 125.39965706486856, 126.52776995012839, 114.68675413439351, 109.42822856287803, 102.46996741141044, 93.92058111006214, 98.38783910197597, 96.56911450047647, 103.33586985065092, 111.34210202001758, 108.99065679119481, 108.14995950268163, 108.39499781208654, 119.9597454071045, 118.93530861023935, 68.44765801583567, 10.65178357785748, 1.3349197300211078, 9.982185959815979, 0.6873949436891464, 2.4852299209563964, 40.8868690459959, 86.85363108111967, 93.86121995987432, 100.66390422082718, 108.43327230022801, 78.2774628362348, 34.417264615335775, 9.243108457134618, 40.29660724824475, 104.93458086444487, 116.1084250480898, 110.30979694858675, 112.27753239293253, 108.98219231636294, 97.72859850237447, 109.4230745684716, 119.8131742785054, 115.54995798295545, 115.1747440522717, 114.20998219520816, 101.99881230631183, 102.40356168439313, 97.61969781691029, 118.42653013044789, 129.34476913944368, 71.56015288445258, 19.844769047152614, 20.329656370224495, 7.571506077243437, 1.6035936292140716, 0.3584467175026094, 0.04544802055123352, 0.07013652924328082, 0.024678030524462945, 0.20859774382364368, 0.331622761704268, 19.378044259163644, 35.37175378491802, 47.813484514913256, 62.27118015289307, 60.30477831440588, 154.91358633964293, 180.20946933377175, 54.060396379040135, 25.544667167048303, 43.405069920324514, 52.171798675291, 57.76047014421033, 61.59167266661122, 43.17047688268846, 10.507531550622756, 0.4317367251121229, 0.07507706091048257, 0.03727663180700714, 0.050406900024221796, 0.039722267913842396, 0.013122870680695821, 0.02811557046257921, 0.049257860068352, 0.04075972333310112, 0.027640126720671693, 0.015763125679035102, 0.025420702971337784, 0.0288189847337743, 0.02700451123077543, 0.2587191688437616, 0.07684549061401237, 0.06481579580013791, 0.08033155839169219, 0.06176003960952644, 0.17501088640382215, 0.28063556539916223, 0.09565376120829776, 0.12315889174539237, 0.08544248333501239, 0.03217013868232889, 0.1320453354668233, 0.10965957216197446, 0.07170458865021506, 0.04138521497107802, 0.04136982809511885, 0.047442729644958055, 0.1026677787904778, 0.04717643365203854, 0.05944865275054209, 0.0445023424653036, 0.1053953965404822, 0.17943858349275205, 0.09181118675417478, 0.0121325574394676, 0.03436433707153605, 0.004376231780981705, 0.03787634841677162, 0.03287588186081379, 0.06239538313820959, 0.047075547533290046, 0.10644502892729737, 0.04829644270601773, 0.014640743667710454, 0.0730749514074095, 0.0343517272643024, 0.12768852449352705, 0.015232542758777499, 0.007314624738008265, 0.06732782874737056, 0.03720858021669331, 0.027532924206987507, 0.04294598888185236, 0.09882895050630455, 0.07250937933643019, 0.061032574007948565, 0.028520089784456838, 0.04343395241566243, 0.09515689956324716, 0.028464816540720004, 0.0688395653701117, 0.1467545300481781, 0.052710016964063536, 0.10399064409636682, 0.009666869938824206, 0.09555615394586518, 0.15217778903822746, 0.06072165722387934, 0.016795227101313013, 0.09088250432884501, 0.2710003243579019, 16.33746800884124, 105.33586286729383, 119.95568183160599, 109.24044901324858, 86.80279716368645, 111.51766730893044, 119.1336864040744, 61.088495331425825, 25.844206809997562, 28.419535044700872, 60.84032304825322, 64.77673530578613, 53.672203325456195, 45.685324130519746, 11.510650265601374, 0.19475193033295293, 0.4939257509766087, 0.09391976715696436, 0.10073689248172507, 0.775640795548116, 0.5152964171382689, 1.0109857638036053, 1.3287541318324305, 1.940626963492363, 7.98197623222105, 33.01797866821289, 67.15924570637365, 106.77156802146666, 122.41247407851682, 133.63372402806436, 133.42219844941172, 119.59880105910764, 113.04102174697385, 106.15589710973926, 100.07713333252939, 106.0385476389239, 105.53812380759948, 112.03752256208851, 117.02230591927807, 116.25937354180121, 115.00384638386389, 112.05809931601249, 118.84932241132184, 121.37708602413055, 80.8901849869759, 17.207447751875847, 2.920336482986327, 0.5169197268063023, 0.5843615111324095, 6.555361661218829, 57.97352544723019, 103.57773104021626, 104.03337709365353, 109.40812249337475, 123.41842866713002, 107.8202215317757, 47.002322673797615, 16.172964784406847, 52.91176949777911, 119.13592215507262, 122.99572267839987, 116.38610532206874, 119.19598148715113, 115.96024574772005, 106.80499446007514, 114.63188017568281, 128.06508802598523, 120.038082984186, 121.08443798557406, 122.60766690777196, 106.9724718216927, 107.22511168449157, 101.87356318196943, 120.04169940948488, 139.74782051578646, 95.10811790343254, 33.00186557154502, 30.22967161670808, 14.4303527955086, 4.520438957598902, 0.2892178645537746, 0.22645462514652362, 0.07432959658364136, 0.036072464164106116, 0.10157375160845057, 0.14414399351564147, 21.776710902490926, 45.204908309444306, 51.133284491877404, 57.19810424312469, 45.33865328757994, 108.61119101124426, 167.3903634471278, 35.23116034846152, 37.96480132687477, 75.23509994629892, 85.33842732829433, 80.64221274468207, 81.40283092375725, 67.09074543368432, 18.94210027110192, 0.52695382386446, 0.20099156325863254, 0.03724154498007509, 0.04678762104782847, 0.035460298625572075, 0.018744231389474966, 0.026941929508240956, 0.04849034722053236, 0.01993493503710676, 0.06691965710131392, 0.13833168443412552, 0.055041467665784785, 0.10524877497265417, 0.05258126056662971, 0.17434333270836264, 0.10101849108093208, 0.1193195578431891, 0.10359051637351514, 0.030803824699814283, 0.12114920563274816, 0.18917336999889345, 0.08242645646415411, 0.06411151584958838, 0.1480124923851221, 0.08711975623643206, 0.05978170947562303, 0.13858545871992267, 0.04698688817781307, 0.03949230747117151, 0.030828347174270503, 0.04227350924103972, 0.06556281579598304, 0.03638753697516457, 0.04556378026703193, 0.07878036824085059, 0.16613292327571302, 0.19868831991428332, 0.09900572529483227, 0.16611870468383835, 0.03176498159225429, 0.1729262079442701, 0.2187873260869134, 0.12578026076117832, 0.14065738947641465, 0.1169412991692943, 0.2731567699342005, 0.11041039195392402, 0.20629155870166518, 0.25604167622664287, 0.11561400587520293, 0.23292886483813488, 0.14487312535845465, 0.11229494526501625, 0.1811965867396324, 0.19753073041717853, 0.2621733980073083, 0.12163225471252397, 0.23634521861470517, 0.12782830489619126, 0.20394573619048442, 0.2130118198692799, 0.17762453325333136, 0.17467782201786197, 0.1335818014077602, 0.296508570111567, 0.2917709291702317, 0.2005914968228148, 0.20579297335878496, 0.16295845410035503, 0.23397500386401532, 0.2633148690144862, 0.12779196168506338, 0.13749574461290914, 0.1940401120772285, 0.35285853510422094, 24.988029887599332, 127.65460414271202, 136.5193646953952, 116.69893787753199, 91.04087106643185, 96.53272275001773, 93.80615772739534, 61.48605500498126, 49.81263422196912, 97.07972864950858, 128.14460231411843, 105.19112740793537, 72.65396072018531, 59.429266068243216, 17.006037965897594, 0.4849941463720414, 0.7086169887934962, 0.2123794602530618, 0.6008210634031604, 0.620581535322051, 0.3681160341347418, 0.7367811388065739, 2.1015480833668865, 12.238505867219741, 12.787921082588936, 34.962787858901486, 64.34685137964064, 110.65730325637325, 128.6857560373122, 146.24652893312518, 145.7994258019232, 132.0141616944344, 125.18594280365976, 114.97824899611936, 106.77323895116007, 112.05696182866251, 106.83205096952378, 112.24281941690754, 120.63245542587774, 118.67608701029133, 116.30078592608052, 112.42711590182398, 122.36207162180256, 120.2990225822695, 77.96830946399321, 13.863842910335912, 9.74414319761338, 24.59195286996903, 2.7812029036783406, 4.776897738056799, 67.33283412071967, 113.90355094786614, 107.15471298463883, 110.55784763828402, 126.93410396575929, 125.94663943013839, 53.283943591579316, 12.712462525213919, 51.102725305864894, 124.81864421598374, 130.58595611203103, 119.70621124390634, 123.29698424185477, 118.088939574457, 109.92768749114006, 120.18549350000198, 134.56985258287, 118.92915048906882, 124.37718145308958, 124.33908739397604, 109.86452948662543, 108.76031952519571, 104.57915921365063, 130.55866426037204, 152.2427817313902, 92.2466625705842, 24.823696305674893, 28.227246730558335, 11.915094679401768, 4.463767082460465, 0.4692180058167827, 0.23517906425460694, 0.2430437994940627, 0.17741588154627433, 0.4110063552375763, 1.0130043135535334, 33.07372731547202, 59.179920996389086, 72.56284406108242, 84.08155871975808, 88.42647798599737, 189.42556442752962, 194.91153255585704, 68.56162640356249, 42.75982433749784, 61.875020765489154, 82.72623077515634, 82.37392348627891, 95.23388478063768, 86.2560187616656, 25.12651308890312, 0.8547466056000802, 0.32787751106004565, 0.12754692080160304, 0.10772845602684444, 0.1772418263698778, 0.10927205424635641, 0.15469467898290004, 0.17455497215832436, 0.15911845370165764, 0.13633447789376782, 0.1491333096618614, 0.09375289788529759, 0.2221688841499629, 0.1518518645917216, 0.28544454444800654, 0.16215954696939838, 0.1641790926336281, 0.1597944956513182, 0.11532948082012516, 0.26181229480331947, 0.261487994463213, 0.18245168390773958, 0.1827665307228604, 0.22126569713075317, 0.22391299056189679, 0.2055037751673691, 0.23406696505844596, 0.26885690227631603, 0.1548216503954703, 0.10443824628788619, 0.22487885889507112, 0.23362462589096641, 0.22427924187673678, 0.1684692309748742, 0.21831656505744304, 0.23422983535114797, 0.330615570588458, 0.2532401539745831, 0.25358795789220645, 0.14530974951001907], [0.04026916659166736, 0.06372466060002485, 0.052596582325115326, 0.008988772958306777, 0.027181460304305922, 0.0528744156021745, 0.05374182248488069, 0.12653946155501952, 0.06418384987139894, 0.0471403815543219, 0.09907700977618657, 0.024520760334487406, 0.05630560084095886, 0.06773078333466284, 0.03788367987820699, 0.04436707815095302, 0.027748512840198896, 0.18266447248958773, 0.05270103075271172, 0.04541535073170259, 0.08219671435654163, 0.03620425426972009, 0.03262202713578459, 0.270886269187735, 0.18980554575400968, 0.04499409813433886, 0.042574003398899114, 0.06269529506924652, 0.08650660244447571, 0.05566404050877018, 0.023299926448793664, 0.0054458169277847536, 0.01464992618909286, 0.3602638167719687, 17.824977867064938, 103.4813819393035, 96.35015995271745, 87.24360881313201, 72.45017790025281, 69.58908342546033, 44.34770960961619, 30.864138526301232, 57.517895083273615, 85.78426745630081, 82.541777395433, 46.36620444636191, 41.11244847697597, 19.651898261039488, 1.3034978677188198, 0.31105461860856704, 0.04063720289137095, 0.16912078875447475, 0.1418224559916604, 0.25330697216333886, 0.08818587483537775, 0.3095272231486536, 0.500310542242181, 5.097790273927874, 15.625599988045233, 57.07485552757018, 90.93924245526715, 103.93138762443297, 96.33217196310721, 94.27899945166804, 90.57763130434098, 96.83973450814524, 98.64630760685091, 97.86222580940493, 103.63647245591687, 106.41722110009964, 110.15078406180106, 117.63140293859668, 114.58070893441479, 119.87066838049121, 115.78686914136334, 117.03250408172609, 118.1224601499496, 107.02089740384011, 105.95037275745024, 122.11045157524848, 89.39513083427184, 26.57141031757478, 3.257066323872536, 11.935411576301822, 54.434555192147535, 82.83102081667992, 94.1927465315788, 93.98208387436406, 99.49346896140807, 105.68610698946061, 110.23891187483265, 83.6145221033404, 77.92697552711734, 94.90608446059689, 109.28918838500978, 108.80107295128607, 119.18183742030975, 124.63222965117424, 126.15119103462466, 113.26828387475784, 98.30968195392241, 122.05545994543262, 121.45715728882821, 115.49121656725484, 116.66726081602036, 109.6897957401891, 92.84727942559027, 105.82196220274895, 111.92715491017988, 102.6620380340084, 110.93186132369503, 118.3886008108816, 114.82833600813343, 102.26355660346248, 81.66629652823173, 37.30099116602252, 0.2747408865440277, 0.14529977504524494, 0.056727531426135576, 0.028685957396162615, 0.15712683960314722, 0.40317883654948206, 2.8505317770665695, 19.554958843415786, 45.5659899403972, 53.280091824070105, 42.17507346983879, 25.850564972046886, 42.75727087451566, 38.64366554444836, 21.37377562061433, 45.919371958701845, 64.50524453193911, 53.75244325207126, 56.2283060627599, 51.297137583455736, 20.933071836348503, 1.5440229999442256, 0.09463812014268291, 0.0648929485149922, 0.05766822227967843, 0.07941266657003472, 0.03769522990971323, 0.10599235523371928, 0.04419822471156236, 0.19506066376643796, 0.05519460481140883, 0.00928004245994793, 0.09307728494487463, 0.10257715058903541, 0.2450337894861737, 0.24561560262114773, 0.059039937182059216, 0.05413012947106073, 0.09313613581921786, 0.14933882040842889, 0.06989548733878521, 0.19538131752802482, 0.07647389966634012, 0.17580659128725531, 0.13812595918293924, 0.11416675853392771, 0.037311113424479, 0.021309986252397783, 0.020481379807836587, 0.06442301486048006, 0.027634653022452712, 0.12467981376234563, 0.05401029416750516, 0.08783877571864475, 0.12580361878198962, 0.2613867789266571, 0.15041603196051814, 0.10929622432036747, 0.07462447914745539, 0.09528282909624039, 0.051251462165025935, 0.13558486085985938, 0.02251764534101371, 0.05740308690996421, 0.04508903941079494, 0.04483854015087409, 0.01712533438788547, 0.08695091045792065, 0.09317759649767991, 0.04513369467590125, 0.058610587035335844, 0.05391065677207324, 0.08493639799135347, 0.031727665449462594, 0.07257217556358346, 0.04032736246083533, 0.07858942082572369, 0.06009487472775002, 0.042143396867979924, 0.03636809366364633, 0.08213779453428523, 0.025039131813231977, 0.02616362822722764, 0.26607955775914655, 0.07986930859906059, 0.11672585226234891, 0.11083168668612359, 0.15463490880304767, 0.08038459465869012, 0.11196625524110372, 0.03722016729654805, 0.04602742050924609, 0.15240504136008604, 0.12302827375430254, 32.63035631948902, 126.9492913830665, 111.78529062578755, 102.79161745502104, 100.62821849699944, 115.31952658007222, 73.94362818810248, 35.48328638076782, 31.105529031445904, 51.93431092846779, 70.63503050035047, 51.6735399923017, 50.69509690807712, 23.599769723030832, 1.3016891647731106, 0.631737552823559, 0.17190919558127082, 0.19012419236523492, 0.4188244357224434, 0.6815146979305052, 0.9165038949539586, 0.17671555460941407, 0.33892241516901606, 0.3552410685487332, 19.745978270807576, 65.54904607034499, 100.23376926299065, 107.57966256910755, 104.83718056832592, 99.65367424872615, 96.04804331256499, 103.72722825696393, 106.62332596317415, 107.53249214541529, 112.76483981840073, 111.89019049367597, 114.5614657863494, 122.81160662251135, 121.27475923107518, 121.4353253764491, 120.73519014543103, 123.14874218356226, 123.19656372070314, 112.44617862086143, 108.10398932426207, 120.71098912146785, 100.57503900220318, 37.35715166214974, 6.784043196708926, 19.31070500804532, 70.0175552983438, 101.90982941658267, 102.69314242947488, 101.68342236549624, 108.32814493486958, 110.29016156350414, 119.68421459198, 105.1802702872984, 89.15703512007191, 105.61577104753064, 113.55027875592633, 112.49565539821502, 123.95471080656975, 126.51293554613669, 129.57668319825206, 117.5749521870767, 98.76259803771974, 124.58935814519083, 124.22424824007096, 119.15547124801145, 120.25138147415655, 114.13446087991039, 95.98301825984832, 111.315320076481, 120.0592637831165, 107.24291924507388, 113.41319976314422, 127.63882836987896, 127.17275665652369, 117.04089795389484, 99.3331773819462, 52.66379333311512, 2.730939445957061, 0.21727578864703256, 0.04953349850350811, 0.05587559185862061, 0.12031671320719105, 0.7549420804266007, 2.072081522595498, 23.613649029885572, 52.12579319553991, 58.37719617351409, 45.51392832110005, 37.283885709701046, 38.28808699884723, 28.198574204598707, 35.89366436004639, 75.29323731699299, 91.48680533132246, 77.37105800259498, 72.05738390645674, 75.17277348426082, 39.23490401237242, 2.8867043650919393, 0.10944641585792265, 0.08690562700071643, 0.06619559676055947, 0.1418977624346172, 0.0340213633382753, 0.04467129932656404, 0.03098097104098528, 0.1905055968992172, 0.07830042947804736, 0.13685371696708665, 0.19121913119189202, 0.22128840397682883, 0.20133853980129768, 0.19453259936023146, 0.044181056681179234, 0.0982951557624244, 0.12305554648440693, 0.14481668000019368, 0.0850298453963572, 0.10973168401828698, 0.07267709896569291, 0.14308461649042947, 0.05128803137209147, 0.09731752797961236, 0.10679537625682932, 0.046675894784951405, 0.04115684416085001, 0.034844831248084386, 0.02420912342776935, 0.084472416840013, 0.09636461419323761, 0.05258416787030236, 0.19088439673425692, 0.2072099755488096, 0.21775333721551204, 0.11350400054887419, 0.043222362761415785, 0.21049759591058378, 0.1104095109528111, 0.30380276903029413, 0.13945771110874994, 0.14184836508525958, 0.08955085199446448, 0.22797031478295404, 0.1497385038002845, 0.18690573442126476, 0.1606051545710333, 0.17496821530643972, 0.139372997106083, 0.16455858194779965, 0.2112169218279662, 0.0879102134175839, 0.19554159844354277, 0.12061779342231252, 0.20289268705152697, 0.30510370889979027, 0.18517388541611934, 0.161248009591814, 0.19154412101113028, 0.21126708526524807, 0.07959673451560159, 0.3554839797077641, 0.18050183692286093, 0.17758601435249854, 0.16925316874779042, 0.329925662447368, 0.17169576348556628, 0.24537345755004117, 0.07662955341079543, 0.16188326502038589, 0.1918690342215761, 0.3365897693701329, 50.230605909901286, 151.22214963359218, 123.45590299175633, 111.39959612200337, 99.38551748952558, 95.87014813576975, 59.075005439019975, 40.975165520944905, 87.2079780024867, 140.43327823761973, 116.57409667968751, 71.68755931238975, 64.46448718347858, 30.774294676319247, 2.498184774191149, 0.8748789059538996, 0.38330921242314003, 0.4244856109782573, 0.5475128658356205, 0.29234301298856735, 0.5763262293992505, 0.9125354369321178, 6.2839346258871025, 19.305264680616318, 24.506254965259185, 66.94465283424624, 105.66826804991692, 120.62560696755688, 113.24770712083387, 107.31395336889453, 102.50864982604982, 109.3443996675553, 108.93648101437478, 110.53057147610573, 114.30175781250001, 119.77117353870024, 121.50925420945691, 131.10051616545647, 127.44087419202252, 128.04392291653542, 126.34767040129631, 129.65280855855636, 127.97733676049018, 113.91778130685131, 112.73280189883326, 123.1055647327054, 101.4215257090907, 35.77638156952397, 6.793660358075173, 16.697080712164603, 92.14379449044505, 106.55717911258822, 105.19770914508452, 106.27517638667938, 112.153577650747, 115.27878099872221, 121.06060566440706, 124.87027829693211, 102.84814665394445, 114.17262554168703, 120.37167272260113, 118.96674248480029, 131.0421669867731, 136.66005226873583, 136.21641651276622, 125.1255226135254, 107.03830488266485, 134.4156720561366, 131.5690197483186, 122.80965328216554, 126.77381238629742, 122.54852541031377, 107.0143235114313, 120.34896219930341, 123.65051531022596, 110.0705715917772, 120.56223715505293, 137.79143641071937, 131.85028506863503, 114.7675157362415, 92.93718014993976, 45.776460401473514, 1.9578856373986893, 0.32767783790346117, 0.275337852898144, 0.17933756713905644, 0.27630324625680525, 1.0289156533056691, 4.698985738138999, 33.95124389279273, 71.55752489643713, 75.2855573161956, 62.40112435433173, 40.76948819621917, 56.84955850724251, 55.57933815063969, 35.194788209853634, 68.04024142603721, 92.77473911162346, 79.13146480437248, 83.10804997721027, 95.40192696356004, 51.015613386707926, 3.64444695653454, 0.29320293136181375, 0.40424136985694215, 0.23863540782082468, 0.2597416817180572, 0.2176143382225306, 0.13901338011266726, 0.13115941606942685, 0.22166584017536334, 0.08373726354611498, 0.1631467431903847, 0.28802092878087876, 0.4566006296344342, 0.32825629557332686, 0.33756168979790907, 0.19267678200717897, 0.19112444272445095, 0.19743758944734452, 0.3457508326297806, 0.18867719017209547, 0.31073721305977914, 0.14831256902506276, 0.18839513192013388, 0.17500478834394487, 0.18954282356125696, 0.19101941207003212, 0.10975711047649385, 0.17626970675924133, 0.1335436655508895, 0.09090148032672944, 0.20318234489569742, 0.13066771019610668, 0.17184227014020567, 0.36585757629044596, 0.31070139078843984, 0.2800143600231217, 0.24092625586255906, 0.2746160448558869, 0.2669392616277741], [0.06358581865506788, 0.19603972413366844, 0.1094528509964866, 0.04926146068159611, 0.01124057349854059, 0.031525745740040176, 0.037248110353586175, 0.10003193837380218, 0.15334614973154762, 0.11894532389217809, 0.11048693945931812, 0.042209724760464126, 0.05237399547871563, 0.17504868518200614, 0.14683221136370014, 0.026078197932351502, 0.058395687881256306, 0.08877010114731328, 0.038239010609686375, 0.1756445483695115, 0.009522603133753424, 0.02520578466506014, 0.14934750784549022, 0.017507183252863826, 0.022506807112104954, 0.05138994787909812, 0.09705527310049343, 0.043522347470805536, 0.06260423019768731, 0.09127807382854725, 0.030842730475048867, 0.0761500436572298, 0.44838629783161227, 43.88350102209276, 107.69268174325268, 91.94954303003128, 77.16447461035945, 89.2501521879627, 56.112427480759166, 25.76867568877436, 51.4288233172509, 77.2221883650749, 76.00390803429389, 62.819052896192005, 42.68595041767244, 40.09259693084225, 11.094158291816713, 0.10672655091771197, 0.07287487222422516, 0.11630176130922572, 0.05380679440173892, 0.2724019894676824, 0.1323603661430459, 0.2012784478645171, 0.606766825001086, 3.322938608546411, 3.8059579028237254, 22.44766958298222, 67.09442461690595, 97.35923674798782, 91.44740904531172, 96.66114114945935, 97.8256771641393, 102.43101043085899, 106.38970959571101, 103.01742046110093, 99.41555500030519, 95.79759213232225, 96.40787370743291, 102.53450609022572, 107.39242430656188, 108.59169683148785, 115.0191750064973, 102.93486241371401, 107.32892113347208, 104.64001870924427, 107.52594178722752, 109.71693854178153, 114.58525103907432, 105.25758020339474, 120.85512838056012, 80.70439800139397, 44.8819834955277, 70.31860505380939, 62.40827091278569, 95.20067015001851, 101.83055047065982, 102.93303458921372, 111.2687615425356, 103.93319975945258, 127.59605884552003, 98.4456705277966, 76.81796458459671, 115.37655784237771, 109.78695284935736, 105.81908318304248, 107.337660174216, 112.98615563300349, 113.95102731643186, 115.1037334626721, 94.78996661401565, 103.0149729021134, 115.56178785139515, 114.51919832537251, 112.30971936256655, 108.98846810863866, 100.18843450853902, 82.46297697867118, 104.38180123606037, 119.8164612247098, 111.50567270094349, 104.29623080838113, 106.84959180893438, 106.17455974701913, 106.85858188136932, 124.20919418334962, 90.27060385673278, 3.6000148375188155, 0.06059085537168769, 0.22193597809922314, 0.09147053809776422, 0.5784220008119461, 0.38942446331343344, 0.1504341729225651, 4.172987562994804, 26.632795410771525, 56.0285593617347, 59.979692274524325, 45.155168733289166, 52.7153411219197, 54.28526586101901, 28.44352622185984, 37.01080637593424, 52.215376207905436, 56.871912094854544, 55.632658850762155, 57.32307880155502, 31.633407492791456, 3.0014118744480998, 0.23328725609087178, 0.029510595505276037, 0.14832504093647003, 0.037392629010062066, 0.10387630547366797, 0.09263067866765684, 0.06998163392587055, 0.12907484486218423, 0.16568934304579613, 0.3154623208026732, 0.060911325272172696, 0.09726780887332656, 0.09884896072288675, 0.045571280267810634, 0.09574698644780344, 0.09654409327213803, 0.07898466090761846, 0.08510352007203525, 0.047663615776165846, 0.05304106270834323, 0.13837441681854187, 0.01913120155222714, 0.060607245822827664, 0.09453084485064592, 0.06536780811485744, 0.044420727288290385, 0.08457596128385875, 0.06707517294994286, 0.02310760007540305, 0.09199737676329191, 0.07280457599629318, 0.19473052583634856, 0.09634906260837471, 0.12972929845413855, 0.07892570278096585, 0.08463757007472938, 0.11378177636933905, 0.04067491356944365, 0.17740913997254065, 0.08825340548590307, 0.1152290313714935, 0.040772141618353706, 0.018818059282737876, 0.07506439747709422, 0.08781289726856255, 0.12246016593229388, 0.059215038068472385, 0.08175353249234539, 0.05825772693741226, 0.0153828980476265, 0.07823582528339279, 0.11290620681979965, 0.08442422990957577, 0.06884442236755164, 0.05989061653493874, 0.07371109549797351, 0.05871792361440678, 0.028611032081948175, 0.06490239437909857, 0.09944180552397044, 0.06791202441578911, 0.03625205815619519, 0.0695510159036325, 0.08670013923678668, 0.008295863667773384, 0.03717148623939964, 0.06909019103454006, 0.0197847128560346, 0.028279894407117562, 0.4911418487468074, 61.91072610116775, 127.15370178222658, 107.54768740746283, 104.31617213833718, 117.96431802934217, 93.76246252367574, 38.75418224642354, 29.567565725695705, 32.75710771160741, 64.9964351038779, 66.82835455863707, 51.81545134513609, 51.562317263695505, 15.17863021742913, 0.12608729347947145, 0.07883453831797646, 0.11967649352886986, 0.1405291463578901, 0.5938610626805214, 0.2643494860779855, 0.5580590160623674, 0.9855732177534412, 1.786883535885042, 3.136079590166769, 30.06645787146784, 81.23550261220625, 105.84210749595397, 102.43021026734384, 104.05150628858998, 103.44453519390476, 107.94314076823574, 113.75596000302224, 107.91672752749537, 103.47491787325953, 99.70650857494724, 103.90488024680846, 107.09015861634286, 114.96117884112944, 113.764832404352, 119.88423193654707, 108.7944676799159, 113.28185527555405, 110.50794724495181, 110.06560587113904, 110.25954354193904, 116.89026324979721, 110.86243537164505, 120.54482183148785, 89.06170583540394, 56.05232500260877, 83.21937468744095, 75.38858229114165, 104.44747740222563, 110.43059810515373, 107.90494472749772, 117.27749532268895, 109.31211071629679, 130.17548007349816, 102.54992100500293, 83.95066922710788, 118.9474287340718, 115.1016781407018, 109.23724835918797, 111.8271658497472, 118.8930646834835, 118.10175003543978, 119.70880000822007, 101.6883723966537, 107.50659665753766, 119.37330399790119, 117.08811544602918, 116.24048340705134, 117.3287763903218, 106.30546492915, 86.45601257201164, 107.47610415181806, 126.93710850131129, 117.66444498492827, 111.16089636279692, 110.25982595259144, 110.21883718429073, 108.96654990411575, 127.9955130238687, 109.59728271730485, 9.145668937313943, 0.07687152994255866, 0.29300325820522927, 0.34779297788777663, 0.7121443640320533, 0.3508339179379325, 0.5305380121834817, 4.599629159896605, 30.495994667853083, 63.24592836441533, 61.202577467887636, 47.417682063195016, 42.69830196134506, 37.48020425919564, 37.352880201032086, 67.17382907867432, 82.02922559553578, 85.08473627028927, 73.72604646990376, 77.80689608666205, 55.881431256571126, 7.244339710281742, 0.24189699651493182, 0.028912525984548756, 0.06942657258121238, 0.1375776700555317, 0.08998655684051976, 0.04077878743109684, 0.04813519651971517, 0.0725601556440515, 0.2542541785946777, 0.08957381931043441, 0.056200099042466575, 0.11572128882811916, 0.04215097730799068, 0.03407418510065444, 0.02430845821847118, 0.11970388883304213, 0.07812845806080489, 0.11371470537156829, 0.12770776862218497, 0.07505862883502439, 0.16339590562687767, 0.022641148290506775, 0.06804499429680648, 0.05893291852947685, 0.0505754393675635, 0.017330837473573706, 0.04010767142678942, 0.007951490387635967, 0.014789326420624652, 0.09309317360842422, 0.07111293128541402, 0.09578106203867544, 0.2018024979700004, 0.11278502703193696, 0.06743947074057595, 0.042999078775005, 0.024780845269560817, 0.19262870232905113, 0.3443883605782063, 0.2545994697439094, 0.18259793009248473, 0.11802802553340314, 0.11651369187259868, 0.21449487416013596, 0.19004911574865543, 0.19348016309161342, 0.1642681886592219, 0.18463249108003033, 0.10906956954708985, 0.2240294206046289, 0.33315913571465405, 0.3151491134157104, 0.11459189136662792, 0.2507077430885646, 0.21497827564035693, 0.13240699025411762, 0.17284366963130815, 0.07863281204575494, 0.12298020173705394, 0.2526966912010985, 0.2342480376002289, 0.2031918443859585, 0.21463807131494247, 0.329423047482006, 0.16421897517096612, 0.22188509453929242, 0.2593512526683269, 0.0964690089946793, 0.2670305486648314, 1.6538290174738055, 85.37652138740786, 147.98297789789015, 118.51728593149494, 107.27327839020761, 119.20025687063895, 74.414030198128, 35.96563985270839, 74.69992391524777, 116.82213167990409, 114.53316196318596, 85.82113773592057, 68.79299133054673, 66.16418746209914, 22.72182756854642, 0.32611075908907, 0.16791113592203588, 0.3580299043847669, 0.3264890839495967, 0.47411146904191664, 0.3207947524084199, 0.7881431666112716, 4.322642164845621, 9.267684067449263, 11.130146038147712, 30.492082103606197, 83.75102843007734, 115.35108597047868, 108.28792495112266, 112.44119721074259, 109.20741481165733, 113.01589504364999, 118.68911712400376, 115.5243056820285, 111.37997642640146, 107.29604382668774, 109.86634162164505, 109.6251315455283, 118.50926076212238, 118.29684872781078, 122.99461657001127, 112.92340555498677, 116.79018789722075, 112.89481147643059, 114.03655852040937, 116.32216284351965, 120.93255596776163, 114.7119200614191, 121.88082818062075, 90.03739541576755, 61.92700001501269, 92.93193986338954, 86.12745915689777, 113.30880195863786, 117.92187798407771, 113.5982414983934, 122.70171749976375, 119.68554035309823, 139.50089946869883, 106.94902389280259, 90.33832750012799, 126.40678836453347, 121.70910681447675, 117.5088131812311, 116.44178728903495, 120.70795320695447, 122.88420969440092, 123.42351990361368, 106.34596732354935, 114.25965509107037, 126.37861790195589, 122.52969803348665, 118.06802549669821, 120.33141351515248, 107.85166325107699, 90.29944896698, 115.03061263791977, 134.29908352513468, 118.81343272424515, 111.0485439915811, 117.64473899718254, 121.09659733310824, 117.60553882968043, 139.0461241814398, 105.43896628964333, 6.364184848723873, 0.15872935764491558, 0.4025648017564128, 0.43462043327669947, 1.1363892088974676, 0.7455014870051415, 0.6950597453021234, 9.122326912418488, 44.620522222211285, 78.98130862943589, 86.97422827443769, 68.79634887941423, 77.94745029941683, 73.84953052766862, 45.4605919314969, 51.62565177486789, 73.05843553235455, 85.92181713350358, 79.91288723484163, 96.39139975270918, 75.60948233450614, 10.25171947094702, 0.5973270283110681, 0.2016364101080164, 0.31269055340559254, 0.24329896805988205, 0.28622414616327135, 0.1904561995498596, 0.17112202491731415, 0.2776501514017582, 0.36140541035321455, 0.4637486283336917, 0.07684360603771864, 0.2301725111300907, 0.139218584424065, 0.18667924818733048, 0.21077211585737046, 0.227412449556493, 0.17586369548113118, 0.24296159825978741, 0.19164029568914445, 0.13448785359580673, 0.29029860011031555, 0.063978829421103, 0.21378461872377705, 0.27491840443784193, 0.1786572504187784, 0.09435473655861232, 0.2475975027247783, 0.14585768623698145, 0.19564380989440028, 0.18692562206377908, 0.21594881710986938, 0.3173629849428131, 0.44009839094454245, 0.267444052282841, 0.1554125646549848, 0.2866140849167301, 0.20691103271899686], [0.026018768661625447, 0.0489371411892916, 0.05984201208658277, 0.05285526723450711, 0.014083399381037923, 0.07501061044393048, 0.09337104135943998, 0.07633646349272422, 0.048560608974507743, 0.11200518016853642, 0.1567303431370566, 0.0364792300388217, 0.05922635318711401, 0.11558759116357374, 0.0033397799369037874, 0.03269567882882492, 0.011548842491221525, 0.019717149646772493, 0.02420518765105836, 0.10023671367596235, 0.019791464005867322, 0.10803332071631186, 0.03930522496962259, 0.023509683237681468, 0.05060474223066723, 0.042580116780534874, 0.11362975388164483, 0.03241331414169362, 0.13322648982847893, 0.03829573942047935, 0.0661067765266184, 0.49543607799756917, 40.940970297782656, 119.95789404838317, 88.96660404820597, 83.28041461206253, 73.77378171490085, 61.02544715327602, 30.888015954725205, 72.52971572260704, 76.93293709908762, 89.8867371774489, 73.73281648082119, 47.230200613698656, 26.81423052664726, 4.170798390142379, 0.5830366693196759, 0.06468680191544757, 0.11825687897902344, 0.06706647019112302, 0.04532814694328174, 0.67320276652613, 0.38867801788353157, 2.8445599684792184, 5.464185735871715, 7.0166794619252615, 59.1204539422066, 102.69404457461451, 103.65182461277132, 98.45855159144249, 103.33279471243583, 103.19395065307619, 96.05938680710332, 91.48438915129631, 88.53720649596184, 88.39374188453921, 92.81938352892476, 95.06830584618353, 104.81609390627955, 114.84787725633191, 118.39886173125237, 103.83581515281432, 112.11279284569525, 109.10122840635239, 114.28252250917497, 112.44558242059524, 108.29519702542214, 101.56421369121921, 99.86236787611439, 103.60133586391326, 111.78233315867763, 108.13321098204582, 64.64361006213774, 53.8599475737541, 100.43743441181799, 97.43993559191304, 92.60431997237667, 92.70590151509931, 93.5550868126654, 87.58333313849666, 109.82492139262538, 96.26429926964545, 100.30245780944826, 114.70554228751891, 100.37157781662481, 92.3769715524489, 102.96100108854233, 120.133435803075, 120.84432617310556, 119.29646476622551, 103.83391672565092, 90.03150401576873, 104.18253698656636, 110.4190977158085, 109.39734382014122, 112.85575251425468, 113.07936683777841, 105.25229284840246, 87.32888898541852, 108.71274117500552, 113.9827436016452, 120.4968120205787, 106.82457493197535, 102.56373559274982, 93.75615535243865, 90.2114466697939, 109.29813138900265, 106.53172293016988, 4.069104569573557, 0.03682529493685692, 0.41346163639137823, 0.35822210052321035, 0.0767656719131816, 0.05062083773795636, 0.25417511832089196, 0.6014572841025169, 8.993495683516226, 37.26895324645504, 75.41331675744827, 60.11043271710796, 49.80320092170469, 50.24190625836773, 23.64729316003861, 30.062084428725708, 36.29831960124355, 51.85616946989491, 55.89513209558303, 55.18686971356792, 47.947092210092855, 7.341831201507199, 0.09667255089528139, 0.1744871120899916, 0.015947373655264177, 0.0923406990665582, 0.024394897834187555, 0.13226947747170925, 0.024137716372347167, 0.07415658328682184, 0.11362780801831715, 0.043156770313338894, 0.021934713717670213, 0.04801048506652156, 0.01492215266015621, 0.013438408890168273, 0.06924202966113245, 0.049271852664288976, 0.059068550566031094, 0.11391653889609922, 0.11801024463268057, 0.12484660642521998, 0.016677954361864155, 0.024582644917010784, 0.14165506578020512, 0.0968347010653346, 0.044544507944655996, 0.02522377815518168, 0.0524588397163297, 0.0473658335695584, 0.08290034313235553, 0.0930206174211156, 0.060211917640821594, 0.21566980788784645, 0.05397281714624936, 0.0027756186647175424, 0.04127354233435566, 0.03594743861486355, 0.04436240118417529, 0.05273927769233143, 0.1211657148275164, 0.0440358140716149, 0.0306261076231397, 0.05507096971174883, 0.10874524622434571, 0.0689672262618138, 0.08702038697177365, 0.030475230436892282, 0.06960130191498226, 0.07989043730401224, 0.09114118157735757, 0.14313592905959777, 0.01250594294810247, 0.1347130528020282, 0.04091595164349964, 0.07510549043335261, 0.039753562605549256, 0.026880883791994666, 0.061680462226391806, 0.16714360775245776, 0.05085965798747155, 0.080571313268475, 0.06318882040138687, 0.032226128218274926, 0.12774701530654586, 0.038420876052470944, 0.11838053323088155, 0.14244566851806256, 0.05620801273072439, 0.31192756047652614, 61.07502983462427, 137.2013864209575, 106.26536261650824, 107.30664207089333, 105.30565277222665, 104.81262653104721, 42.99558231907506, 40.49263554234659, 52.91077713812552, 90.78225351149037, 81.60248741026848, 57.69101673556913, 34.28449630737305, 3.982465050874218, 0.9881241066801933, 0.03312445057916545, 0.21713839843869212, 0.18441008043385324, 0.12158974449360564, 0.3107992661816459, 0.3921682838230364, 1.0078583477485565, 1.1799645351786767, 11.206960755009806, 73.71419306724303, 115.54729077123828, 111.62415965910881, 108.71201161415347, 107.95455486543717, 109.01467738613006, 101.37066041269611, 98.16190273531022, 93.178264710211, 96.2064992227862, 101.31073444120346, 101.84904836839246, 111.42315387725831, 118.58834358953662, 120.78360003809776, 110.74712553331929, 112.86478965513169, 110.55256812803208, 116.16682129521524, 114.7244873354512, 110.29763760105257, 104.07191830296671, 103.49126631213774, 110.79816341400148, 114.21523817123906, 113.49666780041112, 70.22837485036543, 62.39679013529132, 110.13656154755624, 106.10274899390437, 99.22644968955748, 101.29466056823732, 104.46961525947818, 97.96203444080969, 114.96469328480383, 100.48254951353996, 107.05535934817408, 120.80952690493677, 105.64478089732509, 96.64429064719909, 107.159451207807, 124.68307925808816, 124.43254963044198, 123.13155435746717, 105.9625634839458, 91.30869834653794, 106.41631111021965, 113.2310684265629, 111.09706371061264, 117.31692298766106, 120.03991865342664, 109.78317168451126, 92.54648070181571, 111.58816799040764, 116.6224673486525, 122.11358947138633, 114.35032459997363, 109.05718803405763, 100.42602815935689, 95.62725928521927, 111.57301979680216, 123.38238992998679, 9.162788121931015, 0.08284662504710498, 0.64859087428739, 0.5491919467045415, 0.10622338436904455, 0.08255075422986861, 0.5253487777325415, 0.01729267288840586, 8.448132276535034, 43.26302128453409, 67.39208544454267, 53.502301939072154, 46.85566525305472, 25.234309627163796, 20.653599039200817, 49.33645848304995, 62.69449803137011, 85.45628670723208, 80.14006307048183, 71.77622841250512, 74.41776429453205, 16.256553434556533, 0.2239912234607243, 0.38516979484308156, 0.062430362712832234, 0.08571939347612281, 0.013396424399087987, 0.07220903456571602, 0.08782298664652533, 0.07343323540783699, 0.023285763398293528, 0.07698662699230256, 0.20189488817366863, 0.053478257595411235, 0.024695317298474333, 0.06799909796926283, 0.02237146235852232, 0.0712454951398315, 0.058827424391863815, 0.019734465149081042, 0.0728664682396958, 0.032046804272179166, 0.040995134491353266, 0.06076730457284759, 0.0985009039962484, 0.10963566255785766, 0.03882555816803248, 0.018698430822921858, 0.048725513230648734, 0.03476202480434891, 0.027452067457019325, 0.05724713822165805, 0.1390469960507847, 0.15765193158820753, 0.08608777451539233, 0.06948764511053601, 0.016168588246669502, 0.05885150636576357, 0.1519521148574929, 0.17363902211429613, 0.2684642975368808, 0.14329210374384158, 0.07236704786097811, 0.1301747172950737, 0.13149703101765725, 0.14580997428105724, 0.1891522259721833, 0.18408829286213846, 0.23813297671656455, 0.2619212631496691, 0.20232081773781008, 0.34139124075731925, 0.09776036510424269, 0.17996306260747297, 0.18916387050863237, 0.14907905531506385, 0.12777352194872596, 0.23402600999801393, 0.15560649215213715, 0.30865988904430025, 0.08438005727986175, 0.32618914520548237, 0.14263693002923844, 0.12419700216982635, 0.33236908456010206, 0.1165529079134426, 0.23082072876634138, 0.25806900534418326, 0.1958409856043516, 1.1911967324633752, 87.16338065362747, 157.46329953593593, 116.17330105073991, 117.4216345817812, 99.24460241871496, 79.09272747655069, 49.339666981850904, 110.80432937991236, 117.26278643454276, 121.29048793546616, 97.74752786082607, 73.69258080759357, 45.41951294868223, 6.176276841471273, 1.4891649758623493, 0.18398583626314519, 0.4070439339885789, 0.27486269452398826, 0.16416574738198714, 0.9399905572495154, 1.5302228759373389, 7.845687597028672, 11.871644623817938, 8.587816703704096, 74.28612170680877, 123.83652979327788, 120.41149262459048, 112.28690685764437, 115.30819093027424, 114.19680303142918, 109.79600567971508, 105.52477990427326, 100.70235129325621, 99.39409179072227, 103.78902127665859, 104.99864101409914, 114.33308970543646, 123.88097809207056, 126.31771133792017, 116.26737517695274, 125.48813004647533, 114.03305976621567, 121.5546517218313, 119.74607821433776, 115.04022244484194, 105.73818037586828, 109.45806211040868, 112.48244485547467, 122.91787147521974, 114.3701090351228, 78.71577201351043, 80.39063192182972, 118.71315340841971, 116.31235691808887, 103.17638627944454, 109.65126237561627, 113.32203603559925, 107.89714705559516, 120.97116777973791, 108.86635688043411, 114.09986557499056, 127.09965936599241, 110.28544687455701, 100.4011211087627, 113.53429117510396, 129.1664032782278, 127.21886019552909, 128.16572819986652, 111.98292316928988, 97.63348887043615, 113.15891250487297, 120.01512142919727, 113.86875952443769, 122.3628874747984, 126.90788684352752, 117.53066078309091, 96.13506501720798, 118.56207939886279, 124.57855593773627, 132.24774668293617, 117.79786832870977, 113.57771965765185, 105.49544057538434, 98.50273316906345, 123.08760812205654, 120.27443716602941, 6.85883249967329, 0.21682172833431154, 0.8075101144852177, 0.8404726715337846, 0.2893308165573305, 0.16882584490362676, 0.6827460770164767, 1.489367713370631, 17.58660366458278, 55.101895486154866, 97.84760321340254, 83.34004248342207, 79.34757171138641, 74.69975133096018, 36.77611920141405, 41.442617908600845, 47.57563198766401, 79.04972260998142, 79.22433868531259, 86.37454494353264, 91.92695017783873, 21.4654492562817, 0.4938450053093895, 0.4076484692913871, 0.21159388305198765, 0.14487720094621181, 0.21549244321161704, 0.1900365978719727, 0.21633121755815324, 0.19428277808812358, 0.24788942818920462, 0.18944945276504566, 0.3562021718150185, 0.17065322507292996, 0.1884230328423362, 0.23789257832592536, 0.11838099288363611, 0.14625481089516995, 0.10937841023288428, 0.2339635125451511, 0.19021584712449582, 0.21465893954999987, 0.18612265466682373, 0.15380256959507543, 0.2826097126929991, 0.1995953373731144, 0.1142856323971383, 0.15007938228307233, 0.2383051013513919, 0.12732961230100165, 0.16801936882397822, 0.22923527916352596, 0.19702669052827745, 0.402753044881167, 0.20469872401125971, 0.16123861735386236, 0.13087011062570159, 0.18873525963675594], [0.042986499611288316, 0.05441310702853146, 0.052028106780903, 0.03884085694388036, 0.09224795646244481, 0.04375882349127243, 0.022314676091135032, 0.1006002530395504, 0.08552017231141368, 0.018750204960064545, 0.09780247695744039, 0.044847679579810756, 0.10640495486797825, 0.05934085651871659, 0.05667327324889841, 0.0359458374911018, 0.04115890493736633, 0.02283137941342448, 0.022623208426539938, 0.09814681049676673, 0.04767455934216419, 0.040661154630323576, 0.05344172669274192, 0.08199982209912232, 0.04124957527364454, 0.07751408618904891, 0.06039989263480229, 0.030482443154699383, 0.11697853104241433, 0.023769812222810525, 0.5204360090917157, 42.19280258301766, 108.70500626102572, 85.3968471096408, 70.48919677734375, 67.04103331412038, 51.71095155900525, 25.735135501430882, 65.46961415198543, 59.628118468869125, 87.08787502781038, 76.46364904219105, 38.48427611012613, 16.70333100903419, 0.0926841133003754, 0.2031735502063267, 0.2989026561619774, 0.07681310807745304, 0.07316859799527353, 0.32161149406625383, 0.2044409813900148, 3.598174510463592, 2.053531898606208, 5.661734929007869, 57.633706984981416, 118.04093760828819, 116.75222719869306, 94.61888851657991, 100.54565260487219, 101.68693680917065, 96.91963318855532, 95.64647105432327, 88.46945147360526, 88.45646842833489, 89.63861588508853, 98.98774993035101, 97.33054068780716, 101.56422153595956, 105.17716377012192, 108.7265871417138, 105.72880591115644, 99.6380239917386, 97.02745129985195, 107.23399977530204, 103.72721256748324, 104.33740785045009, 99.75029007081064, 103.55619722797026, 96.30717077562886, 101.24622714134955, 100.3360019191619, 116.03430794131373, 88.97359371185304, 48.992584290043006, 102.60277886544506, 98.53206465321203, 96.1342256299911, 86.79765101402037, 91.71886844019737, 100.15925207445699, 101.30583932322841, 82.166853720142, 97.8086619223318, 111.64748991689375, 103.55159236538796, 89.64198912343672, 102.24569412969775, 107.75773817493071, 120.82036833609305, 115.4795749725834, 103.18962035640594, 88.62596188822101, 89.73597695750576, 106.54356064334993, 108.23640069653912, 104.56621539208197, 108.35702142407818, 108.37582526668426, 91.19380427945046, 90.89939901905676, 102.02431555717223, 95.82700990861463, 91.40966015477335, 87.14966020276471, 86.39363904153147, 96.72233796888783, 91.60706520080568, 104.8487437155939, 107.49911277524888, 4.787773980248359, 0.35446940350436396, 0.24095109243306423, 0.10678916328376341, 0.11723418990450522, 0.20745405116148535, 0.19588361073645855, 0.17070533437353952, 2.8138301593642083, 27.842436721248013, 57.64840018364691, 51.60471808525824, 53.784951856059415, 77.9706471966159, 31.510425498408658, 24.061875920141897, 24.706272309826268, 47.04741816366873, 53.44908714294434, 49.897204445254424, 58.325542480714866, 28.685542345047, 2.435685973013601, 0.14113544366292416, 0.03383474431992058, 0.14434097004273247, 0.13933950374203344, 0.0984072650692636, 0.029308520663048954, 0.06438501689943575, 0.09104322957535906, 0.09596606461150993, 0.028661724119897813, 0.13551804267110365, 0.03164085236588313, 0.06299093606010561, 0.09507404715423623, 0.01033564841735267, 0.01512100897549141, 0.023228339362709273, 0.03138580637413167, 0.04244010272105375, 0.004758353085978138, 0.07118914171212143, 0.03299175265936121, 0.029576444592807564, 0.02516081721912469, 0.034086668503380595, 0.014257391355180693, 0.03783493753402464, 0.07372578906436121, 0.058575917726322535, 0.09629597271522207, 0.06385165499523282, 0.05188602811446594, 0.0978174769589978, 0.06351133192619009, 0.04209483455445978, 0.027265103699098674, 0.03971083022113289, 0.04130797032567282, 0.0015475630836238364, 0.009373379739812546, 0.06837965214564916, 0.07587484955306976, 0.09761896825605824, 0.03552321359635361, 0.030220320425747387, 0.03851790491852068, 0.044430701753064517, 0.06463712877443721, 0.08356304749125436, 0.03369373817657752, 0.08368799643170449, 0.02582152591898076, 0.0072995538733178576, 0.053117031817354506, 0.03752161140343355, 0.0747293412625309, 0.03394328748747226, 0.05581585998316446, 0.06810253516079919, 0.052916205698444005, 0.05082642892375589, 0.09621672091945525, 0.0769518772440572, 0.04880523234004936, 0.22434560041273796, 57.97121517119869, 122.57345599512901, 108.2661008834839, 102.83716401746197, 91.70859967508625, 83.5868223251835, 36.84211307956327, 26.668359541123916, 52.6672254070159, 92.53553728903495, 83.92773120634018, 49.60339930749709, 21.27431804134, 0.10406619568745937, 0.10078956868739859, 0.5817484158662058, 0.21302055327161667, 0.04158175482805218, 0.20284483719977642, 0.03669896703814307, 1.563241633196031, 0.6552033775275754, 9.117067014017413, 70.94856123770438, 130.59559729791457, 125.94513323999222, 102.8857151154549, 107.96789092402305, 108.581616340145, 104.89159953209662, 101.32024226650115, 94.02290005837718, 92.96182047936225, 95.47821706341159, 102.50693967265468, 101.76720419237691, 108.34400699984644, 112.88312281331709, 112.97090545777353, 109.31133408700268, 107.0050588730843, 104.94917208148588, 111.55508672037433, 108.48328251992504, 106.64265540338333, 102.65214581643383, 107.09392409170829, 100.25675435220042, 107.12052560621693, 107.5700919858871, 120.94966534645327, 95.72640111369472, 57.067606987491736, 108.3085487734887, 105.25536014187722, 101.84831880754041, 95.2001916208575, 100.20486139482068, 107.50458055926909, 107.35136493559807, 84.89917678217735, 102.43294023698377, 115.5064667424848, 108.73700495689147, 93.93831806798136, 106.32074648334135, 113.75119824563305, 125.8647717199018, 118.00746410123764, 110.23046308948149, 92.56326844615322, 92.96610370759042, 110.71125938046364, 112.26303531277566, 103.95330582895588, 112.32100009918214, 114.1632196980138, 95.12232472819667, 96.53984577425065, 108.97952510464577, 100.80325034356888, 93.32078795279227, 91.17995046800183, 90.85986937246015, 100.53025337957568, 97.84466928051364, 104.89743601891303, 119.66680711315526, 9.533043196124416, 0.46270631974743265, 0.299108549952507, 0.17838570289313796, 0.25164419364544655, 0.1632947360555972, 0.3334197894700112, 0.18027515150606635, 2.243294696654043, 33.42473237745224, 54.87575123386999, 35.714902339443086, 43.182553860449026, 41.811501133826475, 17.03876033906014, 32.46603842704527, 51.24818248133506, 80.78397504744991, 78.83560826701503, 63.37559407757175, 80.2163061018913, 47.9916032668083, 5.760683090456071, 0.29553291117472036, 0.11588851816111034, 0.10022472439994735, 0.05796816102379273, 0.059649360125824336, 0.02657208332581626, 0.10655313925517183, 0.04271716607974903, 0.028595212366311785, 0.031764682817963824, 0.042121502075103984, 0.04396667080600897, 0.11274643152231172, 0.034331904739261634, 0.04326155198918235, 0.022710814411121032, 0.009021021429479362, 0.005663916414167973, 0.07984369061887264, 0.019725237620033084, 0.015273606029128837, 0.045644131398970084, 0.019949753092782154, 0.06852407504113452, 0.027624040789481615, 0.04127266899412198, 0.05642427935174877, 0.03523074037906143, 0.01661894069383702, 0.1248791651620019, 0.05281233949767006, 0.1224140321174937, 0.12916561095945298, 0.07327996419682618, 0.162797192592294, 0.14411897308403446, 0.2653985362379782, 0.10520727598979589, 0.21718612571637477, 0.1135245317052449, 0.2083957264380109, 0.1431796420365572, 0.2686818665073764, 0.24014103106193005, 0.19102232320414436, 0.15259685445456736, 0.201309964721722, 0.23271956961722146, 0.18281427332230155, 0.12746277370400008, 0.16632836762695544, 0.10526045781349945, 0.1545407719189121, 0.1969352962389108, 0.27625740355541634, 0.21923337311994648, 0.11028948029683483, 0.18453216420546656, 0.181972679772204, 0.1533057922196965, 0.15533840734391444, 0.2682060646193643, 0.31296315813256853, 0.13034412997864908, 1.2987727599759258, 86.74824483932989, 144.76060959600633, 115.1383444570726, 103.01178793753348, 90.83665678578039, 68.84937932414394, 39.527359854790475, 100.50384798357564, 94.92399400280368, 113.96284934013121, 96.51436605761128, 64.22575604531073, 31.125923395156864, 0.9530317026280588, 0.356837319991281, 0.8101602884069566, 0.6418424976929542, 0.24287285463463879, 0.5184685114410617, 0.4324512706408578, 7.4848305217681395, 6.183957332564939, 8.802326225465345, 67.92651622526108, 137.02197720927578, 134.52248604066912, 105.88155869514712, 111.74255248039, 112.55007436198574, 111.074172758287, 108.03552827527447, 100.55852582377773, 96.90439870280605, 98.99569665232013, 108.17374475540655, 106.4439324409731, 115.7270843751969, 118.43351194935461, 119.08857914709277, 113.9089559739636, 109.60835949067148, 109.3239248952558, 118.82560776126002, 112.9917803118306, 112.40562915802003, 107.55754824607604, 111.37464984770745, 103.49138398324291, 110.87151173622378, 109.60056181876891, 127.0753877393661, 98.70656305743803, 64.88363950483262, 116.15851371519028, 112.78025473317793, 116.45594704535701, 105.39177233173002, 110.1222998096097, 115.69146140929192, 114.63819519166024, 92.69870788820329, 107.17831780833583, 120.7637293108048, 114.01644460616575, 101.60419048801546, 111.2012497071297, 118.25001562795332, 125.32230008033015, 121.31560679404967, 116.45943795481037, 97.41682498685776, 98.96580034686674, 115.9134832505257, 117.76726599662535, 106.66540515038275, 114.39081914963262, 117.71513769703527, 102.895732848875, 102.9758982504568, 115.14201579555389, 105.97582893986856, 101.19074913763232, 97.35391801403415, 97.33859723614108, 109.1572633866341, 99.94887182789465, 115.87795442150487, 120.03707885742189, 7.44692228494152, 0.5473556645935582, 0.5180121681863262, 0.3967471913464608, 0.3439301480689357, 0.3570414058143093, 0.811895385624901, 0.3424793614014503, 6.703375731745075, 45.904161007173606, 84.53933069782873, 74.64919197943904, 80.99760301651494, 119.05642355642011, 49.333191148696415, 39.850406262182425, 33.82366095819781, 70.98703184435445, 78.23525028844034, 72.70008779341175, 98.80427714317076, 54.922223475671586, 6.891778447935659, 0.4473993314370033, 0.1413328951645282, 0.28755686335986663, 0.25180741633859377, 0.2162051654510921, 0.09105255286539755, 0.21468812749991495, 0.18049624448101367, 0.16807936883020788, 0.12913622382667758, 0.24266139904577888, 0.2063687343991572, 0.2501324570227054, 0.13060591754413423, 0.1562815688310131, 0.061852245952092835, 0.31939792897432084, 0.1744147167811471, 0.21605490496562374, 0.10314564911588546, 0.2651799253879055, 0.12962336381596903, 0.1340988341478571, 0.1745863357979444, 0.16514080877025283, 0.16986131998560122, 0.1351866330350599, 0.2518639383056472, 0.18024469185019695, 0.18274321100644528, 0.2671019174158573, 0.1659202113026573, 0.20617471497145393, 0.16288441936335257], [0.1308953302401689, 0.05402951914396498, 0.08982360227814606, 0.060885542583081036, 0.022235527717237993, 0.09871107255739552, 0.04978726512842602, 0.09705388648135048, 0.08802949330739437, 0.02007735652788993, 0.02500316398518701, 0.061037791066712914, 0.08435630089332981, 0.11067043283894179, 0.04557432546730965, 0.03834261634056607, 0.040175891556446595, 0.10473390260050375, 0.018411427473409042, 0.08638372960230035, 0.03848764061507198, 0.051005046153741504, 0.05866233244418137, 0.18182770529341313, 0.04466599799812802, 0.029056123420295697, 0.08112563916872587, 0.07072642460585603, 0.04355643455299639, 0.16250175844517448, 42.523662351792865, 102.04919122880506, 94.03690291989236, 72.73028219899824, 49.9501838991719, 34.54107422982493, 33.43911178650395, 75.27969729515814, 62.03163316172939, 105.75976910129671, 81.94963285999914, 42.985109590714984, 13.512675069993543, 0.08612047114800062, 0.012392565765748582, 0.2880444017148787, 0.38097151044395666, 0.18636654641839767, 0.4027667118897362, 0.75448285668127, 0.6600595782360723, 11.234642882500927, 57.11809965871996, 118.24372414619693, 126.08726424555626, 100.20830523583197, 95.85435667345601, 102.44941419170749, 96.75741180296868, 92.6128315156506, 90.86176779962356, 84.98587685246622, 85.55239262119417, 84.01087760925293, 84.36710726830268, 90.70900717089253, 98.089307508161, 104.18089743583434, 106.74648838658487, 106.8089403644685, 105.41874254903486, 108.83598989056004, 107.06078006375222, 91.61106601838144, 101.16749732725083, 100.43372384963497, 99.98462815438548, 94.5945070635888, 95.79082996614518, 96.58055213189895, 103.49337654729044, 97.2923917155112, 105.17979960287772, 69.47612700923797, 85.37918859912504, 104.74695036488195, 86.20292555901312, 77.45942115783691, 76.80280070151053, 90.96535759587442, 85.82350684750466, 87.4008801675612, 107.52254501465829, 101.19286721752536, 89.90763556572699, 86.29819993049868, 94.65186780498874, 113.16996574401857, 108.39454281714656, 119.57819292622229, 111.43177524689706, 98.71306634718373, 82.74027286037322, 94.52308070275092, 107.22493910020398, 102.75247220070132, 96.02541908141106, 108.30542656683154, 104.44163307066887, 86.17074643411945, 88.81891896647792, 88.09943860576999, 86.13645707407306, 86.26373798616471, 84.71506072628884, 78.87366310242685, 96.23302228989141, 97.44376382520123, 100.75364805036976, 100.65936996090798, 10.08544529637983, 0.615501759513732, 0.14020742007320927, 0.1344990538012597, 0.10668293753218268, 0.1293779705320635, 0.1659470397017656, 0.21263885762422316, 0.46070633996878907, 17.11000038731483, 68.33360333596507, 78.72799411896737, 47.94781000383439, 72.20258220549553, 46.140385750801336, 32.83828116232349, 19.623192394933394, 43.58531067448278, 62.07827014307823, 62.40067720413209, 72.382030640879, 54.64364890129336, 7.249416728173533, 0.6355179822252643, 0.14014769585863238, 0.1321707593817865, 0.056069124820491964, 0.05506374933306248, 0.0334517999492105, 0.04299311478051447, 0.0773609911782607, 0.020811891205789104, 0.05250485861794122, 0.06452890353337412, 0.10287836103910401, 0.04698640554242077, 0.030216499562225038, 0.04653783041923758, 0.008931686959019112, 0.145489243910678, 0.05907400511205197, 0.047057441045199676, 0.06615025967720055, 0.013691424748920386, 0.06850133755154188, 0.006137432966140971, 0.025192648172378544, 0.03269778940105631, 0.025949324706509232, 0.10354563128203155, 0.07619618513290921, 0.04240415021476727, 0.0450707414007235, 0.07494442810815188, 0.08534296085276911, 0.1086023172003127, 0.05470239332005863, 0.04292892810377864, 0.02663724484943575, 0.06510077284709101, 0.09122792571302384, 0.05006097685245257, 0.034378685898357825, 0.11523625558061946, 0.07935822836213535, 0.039900188003816915, 0.06532341331964539, 0.06602847467987769, 0.07870594279900675, 0.08012587910578137, 0.058054242493404504, 0.028167995774457534, 0.01982224158822529, 0.06788524964283552, 0.034761216581588796, 0.06966107209483463, 0.028119318547748753, 0.07600375916808844, 0.06459918443954761, 0.2072597099768539, 0.07495195875244756, 0.03432455029518854, 0.032708403549247214, 0.07852163736618335, 0.06307151318798143, 0.12073494358769349, 53.60033765915902, 121.00112684311406, 114.66214518393241, 98.37426770117976, 67.5051595318702, 67.05382024088215, 43.437288268919914, 28.570316837679957, 54.250548962623846, 106.83179993783276, 92.09080326941707, 55.766313614383826, 16.375871935198386, 0.21537147792837313, 0.02570584855763422, 0.16745735140096757, 0.21104930179013362, 0.2952282533289925, 0.21008023120943578, 0.7112614017340445, 1.5521830007914574, 16.914058385356782, 69.57424117672828, 130.91654131489418, 133.79989131804436, 104.76271829297467, 100.52513860887098, 110.40059981807586, 102.31274312542331, 98.8234418438327, 95.6741943667012, 89.64533882756388, 89.60462462517523, 88.98149336538008, 89.92409383097004, 95.40912843519642, 105.70084725656818, 109.7445990962367, 111.32365903546734, 113.15764165693714, 110.50302074801539, 113.6929432038338, 110.12828534649266, 97.58210582117881, 106.62832306277369, 102.52357836692565, 103.80327516986479, 99.38259924611738, 100.17660464009931, 98.85927661772698, 108.48831884322628, 101.40687173412692, 108.82338339282622, 75.84534229770784, 90.68058567662393, 113.40268781108242, 92.31342131091704, 88.53458635268673, 88.06052869366061, 99.02944472528274, 90.67334498128584, 94.78758965769123, 111.44864143863802, 103.71281746895083, 93.06206057148596, 88.9787006378174, 98.70894001376246, 117.38019866328086, 109.2741813967305, 123.16112902856644, 114.14896580480762, 101.25069079860565, 85.01811089054232, 96.78937911987306, 110.91632873781266, 107.84963146332773, 98.03231546955725, 110.46398532006049, 110.71350297620221, 87.73054753580402, 88.24271494342436, 92.03329347795056, 91.99892567050074, 91.27422855746363, 91.52632713317873, 83.22685856972971, 100.87604168922671, 105.65648524991929, 102.47335633923932, 113.20582405213388, 18.635914171895674, 0.44043099567774807, 0.11479717994769735, 0.17272691783164779, 0.28506073439794205, 0.13334028452875155, 0.06773184053599834, 0.36441417471055065, 0.30083377995798666, 21.069127090515632, 69.14904056056854, 73.86275675988966, 50.16028173508183, 36.004141838319846, 27.603054469631566, 24.01165585364065, 28.722453809553578, 77.46389265983336, 100.57050474228399, 79.85330643192415, 84.67602529833394, 80.29901319934477, 16.419429855961955, 0.6012998377123188, 0.06610614067364125, 0.08932041274684091, 0.04691682560669799, 0.017351594625882084, 0.04306651749497941, 0.04554805631238607, 0.0659721902000808, 0.040810760110616684, 0.10330587640524873, 0.06291661787057115, 0.030667313577366934, 0.0834954938580913, 0.07791868786537841, 0.06975726975548653, 0.02863841397958177, 0.07053353132740145, 0.027293973722525185, 0.039805821293304046, 0.032879605048125794, 0.020277418474095966, 0.09363072218313333, 0.04442638101717157, 0.01970758695425766, 0.017412613529051026, 0.013998414374767773, 0.07877795506388911, 0.059652562373347824, 0.027526397137872638, 0.02760633075189206, 0.08594631638017394, 0.040043354515106454, 0.0819807388489285, 0.2658340725446901, 0.14842636372533538, 0.13948726678086867, 0.16180653365388994, 0.20862872441930158, 0.19505283434785184, 0.10553613455305177, 0.20969858152731774, 0.3125500835237965, 0.18251123958297316, 0.14239544379374675, 0.20861821369298045, 0.22739731165910923, 0.1497265528286657, 0.16637087018499452, 0.15707492948539797, 0.19875261001288894, 0.1887762759842219, 0.14379657264198029, 0.22082619248859345, 0.1446302295211823, 0.10819649744418361, 0.17963661722117857, 0.39658818213689717, 0.33767497888015163, 0.08009653027740218, 0.2869638500194396, 0.22740475803373322, 0.1877921594366912, 0.8152767751486072, 79.5096440469065, 140.56798811881774, 122.64132868859076, 107.27321563228485, 74.75115791443856, 49.642881885651626, 51.59087996329031, 114.99263624991141, 98.72706136395855, 131.38266009669152, 104.59443292310162, 71.71896965272965, 23.905436108189246, 0.36577784185928686, 0.15672741668118587, 0.46496440986952475, 0.5149443231282697, 0.5653511312219405, 0.5534331320274262, 1.8084794931834745, 4.49229448072372, 14.113131107822543, 64.77585277249737, 134.33695793151855, 143.30749696300876, 108.2460654166437, 102.89150453382923, 114.66143131256105, 109.3023910830098, 104.52179062751033, 100.32019476736747, 94.38910038240495, 97.21323828543387, 97.52142675461309, 94.90662574768068, 101.29720226410898, 110.5348547043339, 111.91598399992913, 116.49986974654661, 119.76091261832946, 114.99246366562383, 120.39463427758987, 115.31606704958024, 101.91703088821905, 112.68721611269059, 108.99943505564045, 109.72519905336442, 104.05039233546104, 105.583615456858, 105.56912622144146, 113.32661736396052, 106.20495811585458, 116.54237254973381, 82.37250358827653, 99.0955601969073, 123.07351896839758, 101.07161891075873, 98.16571527911772, 98.06199212228098, 105.46289274769445, 98.22346041279455, 102.4388159475019, 118.19685966737809, 112.9072924583189, 97.69033185897335, 94.49357663431476, 105.41909556235038, 124.95074964338734, 116.37446372739731, 124.49783355959, 119.52865339094593, 108.14721384356099, 89.42439956049766, 104.89354502770209, 117.28275129871984, 113.20878936398415, 100.72241813905778, 119.14339819262106, 112.03437682121032, 93.58233944062265, 94.46002467986077, 97.9526678208382, 95.34325615052255, 95.18312146586757, 92.03220305904266, 88.2304536142657, 106.6725830877981, 107.65841591742732, 109.5934780182377, 112.53656571911229, 13.59944280116789, 0.911339481751765, 0.29920918326224055, 0.3782377410079203, 0.5419169306274384, 0.4652035212324512, 0.2539755983818924, 0.7321520678458676, 1.0135783279134383, 32.45974106173362, 101.95703121923633, 103.23548070846066, 73.7921933204897, 108.66203277341782, 69.18199631475633, 50.213759330011186, 26.471629142761234, 59.85706329345704, 88.44253616948282, 81.52284760628977, 103.0412135585662, 94.17955167831914, 20.350456699248284, 0.839714244488747, 0.2978401228545174, 0.4572036021178769, 0.18436322649640424, 0.17845897154221613, 0.18999673065639314, 0.21099307093649142, 0.2194426683408599, 0.0889796644990002, 0.22205934889854925, 0.27644071307393814, 0.13423610178212966, 0.12391242348859388, 0.18977202174644317, 0.14110722098379366, 0.09698600343037998, 0.2727831641752874, 0.1796443393874553, 0.1632361916164237, 0.1958875943936648, 0.13299243464585275, 0.0851917427573954, 0.13159286861698474, 0.08460381624078558, 0.10392485246542962, 0.18762322172762888, 0.18838717992747986, 0.21041406168332025, 0.09608034960805409, 0.10340154546523288, 0.19158288506009888, 0.14036474388933953, 0.1498072831741264], [0.14335443265736103, 0.03371256861775633, 0.05531100038018438, 0.05210819361250728, 0.013507528215526574, 0.064663436233757, 0.030842454683396126, 0.07226074550060496, 0.022170722424503297, 0.036236778532545415, 0.008128451431290278, 0.07202315865264786, 0.020795064084532282, 0.11166151312570419, 0.018867006555439967, 0.01587199826439422, 0.02705993960731693, 0.04646396805201808, 0.05670644102558013, 0.03432038277688046, 0.036312877876503814, 0.05246134482384209, 0.12070829138880777, 0.06372225508394261, 0.13695249634404338, 0.14582284455818517, 0.15178728337970473, 0.014946954756704791, 0.319510635829741, 30.3322337519738, 99.87573531366165, 95.36024785810902, 80.68834766264885, 83.26307773590088, 66.14701532548474, 33.30622188506588, 71.56771521414481, 74.8283972278718, 90.61508209474626, 65.7306831882846, 38.009579104761926, 13.129457542973181, 0.19632178238563, 0.08054654564588301, 0.06883687640149748, 0.039923844798918695, 0.08769778489706018, 0.1347632162393101, 0.7254651008594422, 5.908207845303321, 71.57295550069502, 124.08361557991275, 126.54041567156393, 108.18333102810769, 97.46437195808657, 102.09322375635948, 94.28201183196038, 81.86254055269303, 83.48552319311327, 83.58442183463805, 80.62730773802727, 85.29856035786291, 84.77368447088426, 85.80632686614992, 92.05423108993038, 97.26657467503702, 97.59631264594294, 102.71711595596807, 100.74169266608455, 100.13130126460906, 105.0912638633482, 99.065961991587, 94.12223800536125, 97.1464010976976, 90.66717901537496, 94.60675270326676, 91.64259402982651, 93.78225480356525, 96.01794304386263, 95.72588336083197, 94.37202238267469, 99.613540557123, 100.54981816199519, 94.35441878534134, 62.11059439566828, 89.38426586889452, 85.06167273367606, 88.90299889349168, 93.75934031701858, 99.19746337398406, 77.7228004701676, 91.12117767333986, 97.31781651896816, 96.21150416712608, 84.97649454301404, 81.13598423619425, 83.58719887272005, 101.02085559598862, 107.55251976751514, 99.88652967637586, 114.13704964422412, 103.97786771097492, 90.3814265035814, 80.8421673313264, 91.46151388845136, 105.20149030993062, 99.93479836371638, 94.36980232115715, 108.6946668932515, 89.13304590409803, 80.62125159848122, 83.63676978695779, 84.81281403572329, 88.07309596769272, 92.90432637737644, 98.59717599807247, 92.62495163948306, 97.80118588478335, 101.24545835679578, 95.93554189128261, 98.31051349639894, 30.782119804813018, 1.0863222374070076, 0.19206052555912928, 0.21994725981306648, 0.0449329681484209, 0.028965311357751492, 0.05740567245670865, 0.08400276663803286, 0.22579096317771943, 12.04521538749818, 63.103201158585094, 81.580851616398, 49.253535655237016, 58.016369496622396, 76.01703228489046, 56.22763533746043, 26.21618086291898, 20.315010240001065, 57.21924974072365, 61.144294969497196, 76.6588261819655, 69.8356043907904, 6.683425576456132, 0.36869124359180855, 0.053038818070725094, 0.026142064767378955, 0.06728099013168005, 0.02729106450363273, 0.02708400051379877, 0.03931221552193165, 0.06724250953524344, 0.047071456623774384, 0.02442973951298383, 0.0955949946036262, 0.034043426670494585, 0.04692487719078218, 0.04984389817822845, 0.03584166868559776, 0.057954428897749995, 0.02897243214500768, 0.0242566132181955, 0.025869191909629493, 0.03272869338792178, 0.003489793837821532, 0.08719418167827592, 0.050989322199095646, 0.032743203093207655, 0.022950584609662334, 0.08711433233392817, 0.011625662915438656, 0.011609598051666493, 0.08713522355162329, 0.060738158757768335, 0.01954011821879014, 0.022735057263484886, 0.07105835518168827, 0.023578675200922355, 0.0819130013546636, 0.023771700629543875, 0.035027608335498846, 0.05016471664871901, 0.03260102100490082, 0.04938473955037133, 0.07933465583670525, 0.03481449033584326, 0.04434357840387572, 0.02478269345667814, 0.0067169741716145755, 0.06248740178923454, 0.018650860593263662, 0.025984070624314973, 0.0530508456511363, 0.06877276250311444, 0.06666579088496585, 0.0559428658696913, 0.032068135990430756, 0.035439778960520224, 0.1341500241429575, 0.2262062441197134, 0.19231710372672928, 0.034056109256081046, 0.20470633892522705, 0.0619463253796341, 0.18713295609960634, 39.61966499205559, 123.07405241074102, 106.14140002958237, 101.06257392514138, 95.78052982207268, 92.53300343790363, 43.974233288918775, 22.968413252984327, 64.64293149209792, 99.86874565001457, 80.77269431083434, 45.9161909164921, 14.78933301664168, 0.39851636415527714, 0.09548892206963032, 0.04822405505805247, 0.1348160150190515, 0.10938439337957291, 0.13724181710952713, 0.33840944269491785, 10.745426243351353, 86.34482122236683, 135.24387267328078, 135.51864254859188, 110.77222085768177, 105.5853020760321, 109.62558654046829, 99.97346508887507, 87.04720004912346, 87.75268539305657, 88.65821161577779, 86.4613313059653, 90.8673454100086, 88.01418981244488, 89.50073672879128, 96.12848328005884, 101.45621515089466, 100.29262834979643, 105.57011465872489, 103.74380419331213, 104.91722829880254, 109.58779842622819, 102.95867120065998, 98.64090258075346, 102.31193511716782, 96.7727404256021, 98.68662172748198, 96.78718259257656, 98.51664973843484, 99.2861246293591, 98.41287166841569, 97.94884743229036, 106.17974512038693, 104.82684120055168, 100.68022912548435, 67.6923664154545, 96.92792507909961, 92.1768286920363, 94.80987656501033, 99.6038366133167, 105.62484741210939, 83.7485965605705, 95.31666248075425, 103.73638306894611, 99.7697214926443, 91.11319172766902, 84.58820343017578, 87.91253766705914, 103.08234353219311, 110.6780682840655, 103.03285891009916, 117.44316839402723, 109.93875641976635, 95.55240477285078, 84.41147711969192, 96.49929631140925, 109.48138452345326, 104.97773478108068, 99.0809376009049, 113.43478848857265, 94.80898226461103, 85.51955453811154, 88.66197709114321, 89.40437193839782, 92.20884307738274, 98.22790053582962, 102.72518819378269, 98.639663111779, 102.45696867665937, 105.78946928824149, 96.1826982805806, 112.36976300516437, 47.81616741611112, 3.2572143933465405, 0.5598957884696223, 0.3549492503366163, 0.2471807662157282, 0.06626554058804628, 0.10140115199911018, 0.15768907153077666, 0.2504858074169005, 12.44075405982233, 69.22721339810279, 81.5309198441044, 54.804807324563306, 40.22538092828567, 31.59613124785885, 23.872386217117313, 22.24492422996029, 43.173571632754424, 90.35822960638231, 80.90968701147264, 85.93162305893438, 92.36166646403652, 17.30145323661066, 0.20093609849291466, 0.10362743415058621, 0.008089309126409072, 0.06286729329956636, 0.025918244519421173, 0.030679147720577258, 0.03822134462215247, 0.021656775103521445, 0.08820590803459769, 0.022750915283517494, 0.01748064022150732, 0.03935519305448379, 0.013248279273900534, 0.0382645366593234, 0.021965022071174557, 0.013433064469286512, 0.09522046953920396, 0.027513203188596715, 0.021440784274149808, 0.0835665102086721, 0.05757665562052881, 0.10366046020100195, 0.010357798892073333, 0.051064303054684596, 0.04187539632942888, 0.06902762463376408, 0.033917041315186414, 0.022723416557475444, 0.07149277300003075, 0.04959260218686635, 0.02359141524310314, 0.07868702808815627, 0.27432946668517205, 0.12200533187076931, 0.15427133879594265, 0.11659463672267815, 0.13648041764334326, 0.20448005187415308, 0.12335421352256691, 0.17256554907127736, 0.22782267431818673, 0.11480808903973912, 0.18064938545707734, 0.17828007469013815, 0.08095985008103233, 0.19532940741027557, 0.12326485702707884, 0.15854646181387289, 0.16960342414677146, 0.17958087666380793, 0.24234353384423643, 0.16049117600965887, 0.16418745831376122, 0.17056837317443665, 0.3717692010104657, 0.3668799053036398, 0.19356720600157015, 0.22160038562311282, 0.46327337802898505, 0.20980091555224312, 0.38946261449206265, 65.94477007465979, 142.93838624031315, 123.96723101215979, 109.11479196240826, 103.87504669927783, 90.32212026657598, 51.32385676906955, 105.774548592106, 121.2936572105654, 112.73928949909826, 88.60049786106234, 61.45585275465443, 22.186667226975967, 0.735506429787605, 0.3254348856787528, 0.3310717912691255, 0.30698093074944716, 0.2850590183609917, 0.6739865664032199, 1.6400641947984698, 9.389206940127957, 82.5399652604134, 137.82195245065998, 141.90887389644502, 116.77926801866101, 108.5825655537267, 116.32125285363968, 106.26470365831929, 92.66518731271067, 91.553830792827, 93.58857600919663, 92.65787601470949, 95.32995931563839, 93.93160297024636, 95.18048563311177, 103.49041123544018, 108.83093003303775, 107.39163198778706, 110.5017577448199, 112.50477883123584, 112.07200019590317, 118.65842065503521, 108.57398340778967, 102.37008817734258, 105.41078013758506, 103.34029428420529, 104.20912281159433, 100.83691996912803, 103.35628186502765, 103.75710887293663, 102.85247695061469, 101.94971207649478, 111.57848758082237, 110.79460190188502, 104.25283370479461, 73.75236557376, 102.34259236243464, 102.52712418956142, 104.954114267903, 108.59339129540228, 112.3576742602933, 90.35601738960513, 98.7067513312063, 107.96135625531598, 105.08400747852941, 96.23424606938516, 90.68498657595728, 90.04946847115794, 106.47656656080677, 116.1217297277143, 107.1561642616026, 118.46955068649785, 113.83370137983754, 100.16040525128766, 89.60500901745212, 103.6882398974511, 115.4867450652584, 104.6585479859383, 102.34057626416607, 123.53899448148667, 100.90097227404195, 87.7337952583067, 91.34753765598421, 92.86739333983391, 97.16770741247363, 103.27887781204717, 106.48517224096484, 100.33758655671151, 105.24207115173341, 106.8047042046824, 99.40367806342341, 115.20471880512854, 40.39385457192698, 2.6047759190682442, 1.2188024963102033, 0.5423191574312026, 0.44400479584451646, 0.18343955428609926, 0.23450725111028842, 0.2094797255291093, 0.4701454931449506, 19.5828115940094, 85.6579279130505, 103.17466043656873, 73.63525144515499, 94.12154766821092, 118.1765574793662, 86.78239299405007, 37.19178845805507, 27.65787155397477, 78.0195277737033, 83.57613778883412, 95.59398974141767, 108.8659881776379, 20.737610324736565, 0.6153737921868602, 0.2465238458206577, 0.15325924471741723, 0.20705585398020285, 0.11550673058316593, 0.13537633172687025, 0.1320189973639865, 0.1947015064257768, 0.20788635457715682, 0.11599904932682553, 0.3289457134181454, 0.21809361814971895, 0.12648518422558425, 0.14535104164913779, 0.07638154010618887, 0.14982030666883916, 0.1705004977843454, 0.12982608600249215, 0.21954218316222393, 0.22111316902502892, 0.10950645416854851, 0.3038449651531635, 0.15266537335851502, 0.11222783596284928, 0.14790481106648523, 0.1956290703627371, 0.08940720284778265, 0.1667687915746243, 0.23260798125017076, 0.17234001278636918, 0.112031165870928, 0.13484652064019634], [0.026478768070979465, 0.014931689497203597, 0.09875130749517873, 0.1151660666049969, 0.07578482656108756, 0.02910272454872968, 0.09300031609112218, 0.016021663116501467, 0.053254038981732824, 0.07160629190865063, 0.048264753479029865, 0.020949042011653225, 0.03820847434502456, 0.11905695056362499, 0.08786416387245541, 0.025035868278674545, 0.0210067380084506, 0.024948438494316032, 0.02150976283085202, 0.012119000556037552, 0.1089092196836587, 0.022409580978414705, 0.07570124636854857, 0.1405779155151498, 0.09304731558527678, 0.06474654145178295, 0.285747547543818, 0.586594810649272, 19.627375602722168, 93.10821902367377, 91.54197739016627, 99.1474453095467, 99.44950703651675, 85.64863189574211, 27.667893209765037, 59.74749188269339, 78.21412440269225, 80.89258547752135, 66.02207214601579, 31.696141881327478, 8.951421399270336, 0.6039448635232064, 0.10973856348784701, 0.035310919141216625, 0.08749787425321918, 0.12158831957006648, 0.1895685487937543, 0.28710177648932705, 6.192604687906081, 107.52643600586923, 120.25366429359683, 98.85106317458614, 98.50411384336411, 105.2260757261707, 97.5661103956161, 81.8763159167382, 78.8350748246716, 83.19947258118661, 79.6880962002662, 82.53267749663323, 82.22142173397927, 80.07361027502245, 80.10556190244614, 81.71429064966019, 84.99631035712459, 90.31779781464608, 94.44822619038244, 100.63625151111235, 100.56864553882231, 100.42370611621489, 99.86314450540851, 96.69115512601792, 93.05845983566778, 92.70637219951999, 87.37431003201394, 92.68572484293293, 93.89983961659094, 92.2698437783026, 89.80741900782432, 96.19524202039166, 90.91233499588506, 94.73744607740834, 93.05047388999694, 100.75324796861219, 65.28155219170355, 70.56667927772769, 100.11514109949913, 75.99480029075377, 86.33874939334008, 73.78190886589789, 74.00448768369614, 94.79614826940721, 103.10336743631672, 97.00719618028211, 96.06801602148242, 76.28076461053665, 82.86775773571384, 88.7331759545111, 109.37257797487321, 99.65218374806066, 100.1827549165295, 114.36730061807941, 97.92956506052326, 83.76045780797159, 79.48203840563374, 95.90242924228792, 105.8902192884876, 107.25234077822779, 102.6441441812823, 83.3628785225653, 81.04464007962136, 92.2080272243869, 98.0165946099066, 98.52929545987038, 100.59811822829708, 99.67504332142492, 100.88890706339191, 99.59124580506356, 99.29177284240724, 100.41299020090412, 91.79757472007506, 108.11832166487171, 77.28016099622174, 5.454119463120738, 0.2834148404579009, 0.232465059887017, 0.06999776007667666, 0.19317826316241296, 0.032393652495116956, 0.059572364458994526, 0.19121396775928237, 7.629623836086643, 48.36441278457642, 66.13470692788401, 63.67569461945565, 77.52944331015311, 98.46917336986911, 125.39086311094223, 65.1307096019868, 19.692437917955463, 37.80922051398985, 54.360814632907996, 67.31028049222886, 73.0650878721668, 19.67372625104843, 0.6939635041259951, 0.037048329944692315, 0.02763702981023779, 0.08846022624282107, 0.03793351389768143, 0.06470966197910809, 0.04963712721702553, 0.046670409595413555, 0.03690074310607968, 0.042594718416371656, 0.044104819441394466, 0.08572215905352946, 0.05550567864350254, 0.07229682824183857, 0.043214992995584206, 0.03688776557664237, 0.023411202635015213, 0.09375573241061742, 0.01694599512003122, 0.06008891456369912, 0.09411533408227468, 0.022919987057966572, 0.05859375225319978, 0.05801071337754688, 0.05031652846223405, 0.08717671487360232, 0.08907200107651372, 0.04212868797983374, 0.058955092944445155, 0.04098508724822633, 0.04251033766195179, 0.0838121333189549, 0.026848122041912812, 0.10125672144274558, 0.046406817892866756, 0.03729971786660533, 0.04527819418017903, 0.012005311192854518, 0.03430553599290791, 0.03974128221612304, 0.08252171183665914, 0.07012961146932456, 0.045882511147928816, 0.06832886817714862, 0.05909815603386491, 0.13259327219378564, 0.021281146872488242, 0.03748115813059192, 0.017306713364838112, 0.01875779497617435, 0.07505636887564775, 0.06496483054492744, 0.08066999305400156, 0.06058188448209436, 0.09101969535432516, 0.10391743673432259, 0.05896278446720493, 0.29705408600068867, 0.12229145804960882, 27.283165570228334, 112.60884715664773, 106.15616383091097, 123.3071667148221, 120.59196087621875, 113.58365812609273, 52.93008304411366, 38.88240060498638, 58.95051725449101, 92.7296789230839, 76.94925415900447, 39.37308519117294, 10.486728279821335, 0.8304850913343892, 0.0840695312006339, 0.03965445764122471, 0.30641056296806185, 0.4899400100111962, 1.5210607095110802, 0.7828347901663473, 10.223545085999275, 119.73430325908046, 123.94889785397439, 101.04404464844735, 103.41738454757198, 113.22102715892177, 103.37358736222791, 84.1246263442501, 82.39745770731281, 88.97648057629986, 86.9396565037389, 84.8433614546253, 87.55596283943423, 84.88402074383151, 85.42489205637287, 84.95971464341687, 88.35116847868889, 95.70023890464537, 98.4089885219451, 106.45677428091727, 103.73840701195502, 106.70404834132042, 106.0367355039043, 99.68526501809397, 95.03951564911874, 93.7431017045052, 90.35583696057721, 94.92567277723744, 98.44857308172412, 97.33023474293371, 93.70537634818785, 99.99735232322448, 95.35402697901573, 99.0936617697439, 97.29221128648328, 105.48226141160535, 72.53671323099445, 73.57913017272949, 104.85273668842932, 84.14685049364644, 93.82578526773761, 78.07710032309257, 81.57758035967427, 101.61262358388593, 106.65034324892106, 102.81708932692005, 100.43304920196535, 79.16897050796017, 85.0290935270248, 92.1538906712686, 111.98189550830473, 102.47104214083765, 102.4565529054211, 113.90725366530882, 103.68562759891634, 89.14605248358943, 81.05916069399926, 99.47899541547223, 109.12721803111415, 111.4412909169351, 106.45675074669623, 86.9139414448892, 84.72908712202504, 95.82060860049341, 102.99514924326252, 104.65231141736432, 103.5757149419477, 100.85420193210726, 104.67579856995614, 105.26080439167639, 101.99084205012169, 104.30537777562296, 94.90571575780069, 111.9407969136392, 94.81074733118858, 13.574377875174246, 0.12756277882163564, 0.21653701941813194, 0.10020597056756098, 0.19544459639057038, 0.030914147106570103, 0.0418287952009949, 0.1872601420167954, 6.265722080584496, 56.44343237723074, 74.35675574887183, 68.62835376493393, 77.79214797481414, 97.92712534627607, 86.32222837017429, 32.30035162741138, 32.21827407037058, 68.8528702335973, 78.9017080491589, 78.33545115686233, 91.77214207187777, 35.80139060174265, 0.33042493726938005, 0.058216032602133296, 0.05929669154988182, 0.10572381843362125, 0.04372701935109593, 0.053142190144787875, 0.0305010418542811, 0.022417714916950753, 0.03203223136463954, 0.10945102770722683, 0.04489393213823919, 0.06037797102884901, 0.057008068993567466, 0.05011493625539926, 0.024492135459196665, 0.08463602257712234, 0.020407080770500248, 0.087707276726442, 0.0765763409435749, 0.09714714236437313, 0.055399567805110454, 0.019791942810819998, 0.07676018672364374, 0.07706012546775803, 0.011071930733329106, 0.04045582008397868, 0.03489692905737508, 0.01891384134069085, 0.1071384993772353, 0.09896565123551315, 0.041016489192242586, 0.15375010789402072, 0.13953366106556309, 0.2960378550473721, 0.21003284101043979, 0.1290951921574531, 0.1441271549030658, 0.1261467419023956, 0.10978412273670397, 0.16598794879692216, 0.16116139569109486, 0.21949097784536503, 0.17104714748359498, 0.13677954433425782, 0.18601246057979523, 0.15193650198559608, 0.09620466269552709, 0.10503907372514087, 0.16563948604368395, 0.0844967401316089, 0.15919906147305043, 0.19744152713927532, 0.133568701304255, 0.1578139132189174, 0.2228215144526574, 0.1812809176983372, 0.24083250202238562, 0.6574142459900149, 1.5096065305894422, 48.07729921033306, 137.72728212418096, 121.67942231701268, 129.1169971035373, 124.12843258150163, 111.0863713295229, 39.58061387462001, 99.21772633829426, 124.30444502061414, 100.16502580335064, 95.2014389345723, 54.815629143868726, 16.298067800460323, 1.2343364305073217, 0.5753626746516074, 0.23260681679652584, 0.32198136131609645, 0.2798104580611952, 0.6850492437520336, 1.613775121588861, 8.766205118548486, 122.90015020678122, 133.12514951152187, 106.70865320390271, 109.54290297723587, 120.06343718497985, 110.72676843212498, 92.07820461642359, 86.27323796672206, 93.92961040619882, 93.41548965823267, 90.76030392800608, 92.21340871626332, 89.74983861369472, 91.05814518467074, 91.3824075268161, 95.21623411486226, 100.81311902692242, 103.65492328520745, 110.54449589021745, 109.0734423360517, 112.21173071092176, 112.32859380783574, 105.22645227370724, 102.46659417306225, 103.25718710499426, 98.82477544969129, 101.79044031327771, 105.60079543821274, 101.92437356518161, 98.6699281200286, 103.73584962660267, 101.94658986983761, 105.06748645536362, 105.10449009556925, 110.36992688332836, 80.58579337212348, 83.34225470019926, 109.11873002206127, 93.15687210329118, 101.75738257746544, 88.79412958698889, 85.74096448959844, 108.02587924465057, 113.89765954786732, 108.34410113673057, 106.2947411690989, 83.15948793965002, 89.65430536577779, 97.38126477887555, 119.03120271621214, 106.00028099552279, 104.36139706642398, 117.0780820231284, 109.93682661364156, 93.48343295435753, 87.58235254595357, 107.48623955634334, 117.11574462152298, 115.47982600427444, 111.65195357414984, 90.34141832782377, 89.1144460247409, 101.72464647600728, 108.63014390391689, 107.60067078375049, 107.05721855163576, 106.1903747435539, 111.14369284722113, 106.7572670598184, 108.45372353830646, 104.74964111082016, 96.67911344958891, 114.65892884039111, 86.10565862348004, 9.002362201290747, 0.8539671571024003, 0.5649685162690379, 0.27151749499382516, 0.4121254871208822, 0.2397994324564934, 0.23647479472621796, 0.5908076813624752, 13.842395390233687, 73.00411855020832, 86.2188268476917, 92.37172342115834, 103.87209707690825, 136.61417622720043, 168.72367120558218, 81.69556525445755, 25.99622218839584, 55.59592585409842, 78.43648356776085, 87.38622619259743, 107.54535751958048, 40.902962530812914, 0.7480934382446351, 0.14648662910105723, 0.12999772034104795, 0.22905783787850412, 0.2009050719319813, 0.11506766261112307, 0.15753556283250933, 0.1381649683800436, 0.12115967039379383, 0.23896972859098067, 0.11726515517840463, 0.11959357217194573, 0.0967154901234373, 0.13767781306899365, 0.22975467145442965, 0.27826188793105466, 0.08735790998945314, 0.1536258484327024, 0.10715064187083514, 0.15904990415419304, 0.1458437740802765, 0.14201785437762737, 0.10968051700582428, 0.25503276907388245, 0.06563410027733733, 0.1299923424038195, 0.188691531338038, 0.18779908487152672, 0.22012629456097083, 0.1354395186588649, 0.09043878620310176], [0.0308375459750213, 0.0856075676218156, 0.04984137774895757, 0.0366969675486607, 0.053732277029344154, 0.011508560630552953, 0.03814352924124368, 0.017236746554713578, 0.06797000961077791, 0.07896701790272229, 0.024490570724611322, 0.14068155188954648, 0.04772707466937361, 0.034599353694507194, 0.03206615373792668, 0.04008273909529371, 0.011907482722533808, 0.04933883939238806, 0.08213512854830873, 0.014673954536837917, 0.050978313515623735, 0.061666576882764224, 0.077352165845373, 0.14287657765371187, 0.14786670585313152, 0.0818082847962937, 9.17650955338632, 56.59549090170092, 113.3610636188138, 95.47019189403903, 84.96685335713049, 63.611818821199485, 55.29890437279978, 24.442483109812585, 61.84958811729186, 73.71757415033156, 52.63543459676927, 73.64188025074621, 30.316055936198083, 6.0465253264673295, 0.5820275170187796, 0.3508542652332014, 0.2167595832818939, 0.09464087805921033, 0.20122813120965036, 0.15214300864646513, 0.45986284652063925, 0.87940777261411, 74.36442006018855, 112.53061156119071, 88.5800309335032, 97.0891894063642, 89.50058767872473, 85.94286457184823, 77.81685890689974, 87.22600521579866, 89.24076203377017, 89.43327980656778, 83.50544883358864, 76.70593384773501, 76.39074002542804, 75.95014802871212, 78.60097208330708, 76.56524627439438, 81.16860266654723, 90.98933112236762, 99.1447388741278, 102.20950634248796, 98.46984017279841, 95.74212197334536, 92.66263777209868, 87.95669571045907, 87.46425782480549, 84.05301170964395, 83.0637977969262, 84.81568521068942, 88.84595978644587, 97.81441996174475, 93.91251671698787, 95.49432231533913, 91.81313084017847, 90.89544526992306, 94.72363148966144, 96.4157106030372, 82.41674792382025, 41.0526676331797, 63.683307939960116, 91.6532079635128, 82.67844846171718, 67.807966509173, 84.87369706553798, 99.09927860383065, 96.58534526824953, 106.0446822258734, 103.53492229215561, 88.17353217832505, 74.85561063212734, 81.08954337335403, 88.7551804511778, 104.42686926934027, 93.51558070028983, 104.86018134701638, 106.62600886437201, 86.96574026538481, 75.47914197368007, 80.65686671964585, 89.92634527144894, 96.66822494999056, 91.90094486359628, 81.4390657794091, 80.5485543897075, 91.29256956038937, 96.79848686341317, 101.90707591272171, 99.98218059539796, 102.79958771121119, 97.86190417505081, 100.15948741666733, 99.79811945269185, 97.11342180928877, 105.9765192770189, 92.24823936339348, 103.71357840876426, 108.28412809679585, 10.97963979167323, 0.368412816596608, 0.1120788625050937, 0.037935318034743114, 0.07329763784523934, 0.025857417138233304, 0.10111793695438294, 0.053209513951573646, 6.933904703586333, 61.552527412291504, 93.74544728186824, 95.23382986745527, 110.82875790134554, 120.28024227388444, 147.55907950862763, 69.15686176669213, 14.144340426691118, 44.91223673666678, 67.82804904445526, 68.50550513113699, 74.98957526299262, 29.87626410299732, 0.6106305434819191, 0.18234714354959228, 0.07780994168452679, 0.07005602106331818, 0.009684120323659192, 0.06806256835378947, 0.048841407011833884, 0.032909064959254, 0.06861451172059582, 0.05741274344824976, 0.05694934835417136, 0.07430767114724844, 0.05582511815572939, 0.02854281769795043, 0.014966897940593622, 0.04577628156590847, 0.06256510608739431, 0.03599924148030339, 0.07450302356793996, 0.057767947775221644, 0.02335257201095022, 0.028773582532941818, 0.12828742138921254, 0.0706855614759749, 0.02115636264094182, 0.05730146151636878, 0.042101729345778306, 0.05795321464839001, 0.05940829140825137, 0.06217355854929455, 0.026345543465727282, 0.06701767039034637, 0.1121100193009742, 0.1365695902777295, 0.05475303556229319, 0.04543142708679361, 0.08986166918710356, 0.029588328531732964, 0.034901196167113326, 0.033751451410353184, 0.05120096164905737, 0.009276526116375482, 0.005563586187969533, 0.02523757348347816, 0.04734549393516876, 0.033588596439409646, 0.04400997775636854, 0.08721697279402325, 0.05097296622191226, 0.04371431378287174, 0.13348588719964027, 0.048163683499179544, 0.03139648755501596, 0.1531385552258261, 0.2879209083414847, 0.08321716645432096, 10.62429560768989, 67.75065283621511, 129.68446208584695, 114.12503150201614, 110.15542814808508, 96.54704724588703, 95.69046435817596, 55.08734349281558, 37.45241426652478, 41.1560534661816, 69.69736437643729, 82.43066449319163, 40.431783891493275, 6.794859132459087, 0.7710103762726631, 0.15152606271928357, 0.05265999142260802, 0.11263622977440396, 0.93706404009173, 3.092515540699805, 1.410356346637972, 1.0179525673870118, 85.83985528638287, 119.35924622320361, 94.5027236015566, 102.671020261703, 95.58430148709206, 90.69117607608919, 83.75746111715995, 94.35859218720468, 94.89326615487376, 95.35410542641917, 88.13987039750623, 81.77047468000843, 80.90950658244472, 82.52326380821967, 81.46230974505025, 82.07059091137302, 84.67356989460608, 92.75155005916473, 102.12448504663284, 107.64706457814863, 99.99767395757861, 101.3579519333378, 95.72327890703755, 91.65964849533574, 89.51076230695172, 88.05635529179727, 87.81178766681303, 89.98328239687028, 90.99617173594814, 101.98830819899037, 99.95837965319234, 100.94252586364748, 95.24780919474941, 95.76792332433885, 99.36490935664024, 102.18577600294545, 89.12273007054483, 46.57565509119342, 62.788960472229995, 94.6488711141771, 87.46080613905384, 74.30454115713798, 90.6902817756899, 102.3063418173021, 101.11619272539693, 111.50482546898627, 108.40389374763735, 92.51561949329992, 77.16180739864227, 82.9755444680491, 93.1146909344581, 109.71075688638996, 98.46084225562312, 109.22926241351713, 111.00982235324, 91.88523969342633, 79.20633500622165, 84.30662432024556, 94.59635842231013, 100.02161610511043, 93.8095074315225, 85.58109652611518, 83.30842033509286, 97.04295250677295, 98.81063922759026, 102.6727068808771, 102.5996409693072, 105.91872707489999, 99.75046265509822, 102.12173938751222, 103.3996868133545, 101.23383245160504, 107.87309508169852, 96.8533137536818, 102.52214277944258, 119.69671910808934, 21.32509900677589, 0.10857443926074814, 0.1594365334078189, 0.07529960945248604, 0.06276893910140761, 0.04818226496178297, 0.09434473911120046, 0.041192329353502685, 5.860083795362904, 66.50424126655825, 99.85757473976382, 96.42063709997363, 109.79499370821061, 125.39491099696006, 118.02982161121984, 59.54643903240081, 30.256249596995694, 63.28175529356926, 89.41043592268421, 77.20414546228226, 90.13067722320558, 51.341138732048776, 1.1501861459785894, 0.21501903151792867, 0.08733507290843033, 0.02324220172369913, 0.01250922850768773, 0.0701647136180151, 0.02425105141986522, 0.15487077195317517, 0.040735212349963766, 0.03537451209981115, 0.008942985798292344, 0.06439220280416551, 0.0484846092219795, 0.04283555347712771, 0.06966913133979806, 0.02274566375079655, 0.006231018745776026, 0.06115715905663468, 0.10680548095655058, 0.06386035009317341, 0.03867817051228016, 0.015373356422529587, 0.01949054466920995, 0.09555415445638281, 0.015159004063706006, 0.07108241800338992, 0.04549914925930001, 0.04316335483904808, 0.010706277924679942, 0.023457809509108626, 0.10599481437595622, 0.11793367414464874, 0.11931155988525961, 0.30950044071482075, 0.16953219329157185, 0.12257133295098621, 0.2570733361907544, 0.1368273788642499, 0.09104875306929312, 0.2481666907307602, 0.1341554633672199, 0.20066439774968933, 0.11573543081120138, 0.10983278464165427, 0.14529121018225147, 0.12259259189088499, 0.12664436197449125, 0.19340484132689817, 0.16775175899026856, 0.14184191462493714, 0.2603715898529176, 0.18178242949708817, 0.13769964657483563, 0.2767977406901698, 0.4699598853626559, 0.11328684526585764, 19.56434899760831, 100.51799989515736, 155.8878403325235, 123.76640565933721, 116.87429135845555, 88.08737339511995, 71.50233714811264, 37.285701767090835, 83.26544684748497, 109.02795853153353, 77.77667030211418, 100.95672484367125, 53.30751703631494, 10.9538080423109, 1.556872439480597, 0.5334886764326404, 0.5527952565781532, 0.21633798977540386, 0.45386002669411324, 1.1580626330068036, 3.085210616550138, 3.0946500455179526, 89.532256895496, 128.3709858309838, 99.19866361925679, 110.7321342345207, 102.47625104842648, 95.29160638009348, 85.24196840101673, 100.77149483465381, 99.97270414906164, 102.46307972938784, 93.12515581807783, 86.39472161569904, 86.82308366221767, 86.32203225166568, 88.70382878088182, 87.07110297295355, 90.30784283914875, 99.6704149246216, 110.17223158190328, 114.0873061456988, 106.75570595648982, 106.1044591472995, 100.27575431331512, 97.29339584227532, 93.97127382216915, 93.53984448217577, 94.04597928447109, 95.20285098783432, 95.89844411419284, 108.33956687681138, 104.23805421398532, 105.63247249972437, 99.06139635270642, 101.85393564162716, 105.10726713365125, 106.76031866381246, 90.52817806120842, 57.024284408938506, 76.39923587922128, 101.91097474867298, 93.91229706425821, 82.66235889927034, 96.98090845538725, 105.8607073753111, 104.80930036114108, 114.26840197655463, 112.78343969775786, 98.98958559959166, 83.37227652149816, 88.44546225763138, 97.75167772846838, 115.1508411284416, 103.12871379237022, 112.2013678089265, 115.36776388845136, 98.7193186052384, 84.3809610797513, 87.20232978943856, 98.65346985478556, 108.26292376364432, 101.06236996189241, 89.69436845471783, 86.92506528669789, 101.15136069636192, 102.50938723164221, 108.36715682860344, 108.40088921208536, 109.52449921638735, 101.6189621340844, 106.26642165645477, 105.0956569179412, 106.0888873377154, 115.09224876280754, 99.8779945988809, 111.32339231429562, 119.13323925387476, 15.684315908339718, 0.784948579967022, 0.36421719818345966, 0.13579803248566968, 0.2828856575633249, 0.2653666363368111, 0.22523220928926624, 0.18699070889382594, 13.110658603329814, 82.80179915889617, 106.29631011716782, 103.46966189722862, 114.06745110788654, 140.24748340729747, 189.9564180066509, 93.26489417783677, 21.159729919125958, 58.86677857368224, 91.54634691053822, 86.89150548750355, 107.76853253764492, 57.69137759362498, 1.4075254985401708, 0.32417632579322786, 0.2704780362546444, 0.1481193769723177, 0.1177057629871753, 0.18967431489258044, 0.16673856174513219, 0.2466951584022853, 0.11913865384074951, 0.1339076952107491, 0.17689774563956648, 0.13244491160636948, 0.18700713381892253, 0.11723815823995298, 0.23300807832950549, 0.12263925430635292, 0.2325643908472792, 0.1581999755674793, 0.22021269395707116, 0.19633548003771614, 0.08721464388673345, 0.06522799706867626, 0.2802442170439228, 0.1279742982719214, 0.10098937207893019, 0.11060389044183878, 0.13986381431741102, 0.10735396926681842, 0.17950576940371146, 0.15025429547794406], [0.1003799721178028, 0.04901483016569288, 0.02694705272123458, 0.01328905909171989, 0.038622977707775376, 0.07779335588096611, 0.02623910512474756, 0.06163574184381193, 0.0652011763304472, 0.014201018775272516, 0.05765288902987396, 0.045252445965043964, 0.04949470764146217, 0.0635602466401554, 0.016389250297159437, 0.09601260445290997, 0.07356174665713504, 0.029915208672924392, 0.02566143269500425, 0.052213155319012945, 0.07370478293347744, 0.026845927200009747, 0.06689839050053589, 0.5371256941749204, 5.515946803554412, 44.587036948050226, 100.60309179367559, 117.474257100013, 93.50461375328803, 93.4733053945726, 90.86133633890461, 55.02592309828728, 36.39794780362037, 74.09919723387688, 102.70323076555806, 65.64427729575866, 51.31545112979028, 38.213816919634425, 3.4278632363965436, 0.2124315389101544, 0.17448542669655817, 0.04489594694948004, 0.18100481961042653, 0.29843574089388697, 0.06242504223219811, 34.96963239485218, 3.365143801896803, 9.149733493405005, 121.12233592617898, 95.38903805517381, 106.74934387207033, 77.25904295521399, 84.77228810710292, 78.39177639253678, 96.99292659759523, 85.89837704935383, 92.98257766231414, 93.2872595325593, 95.38397819765153, 87.12476884165119, 85.91839682671332, 76.40257773860809, 75.36847622163835, 71.65035170893516, 73.0446837025304, 75.51868730975737, 87.33856939500379, 92.6023744767712, 96.11159355409684, 91.31566447596397, 92.34425898521178, 85.90585308690225, 86.67016613867976, 77.86150332420104, 80.4857337090277, 81.60011045394405, 92.17875065342074, 93.78989558066093, 96.01977871310328, 93.49891062705748, 98.66169898740708, 90.27101178323069, 89.5347672124063, 91.19878568956929, 97.95656665678948, 54.07487776971633, 26.24549077403161, 35.8916796407392, 50.6020269086284, 66.0616017926124, 87.88865827745008, 96.31140693541496, 98.68941445504466, 99.91439419407999, 99.61474080239573, 85.16718449131136, 77.1651335685484, 78.82410003292945, 82.57307790940808, 94.93827143023091, 98.37112196030156, 97.06606311182823, 104.65382545225083, 92.5472887100712, 81.18855184124362, 71.51129584158622, 80.473676343118, 84.64619175080331, 79.06389805578416, 75.97175244362124, 79.93755109848516, 93.34280813893965, 96.43384764271399, 95.01630306243898, 97.90413241232596, 94.8995654813705, 102.3824671776064, 93.70161871756278, 97.44400701215191, 96.4176090302006, 92.47397176681027, 97.78886964244228, 93.42105942387735, 94.08372817500945, 104.31108090185352, 6.221440972820406, 0.1069359380691763, 0.19961710959192247, 0.08207046306662022, 0.148803677349802, 0.050540103562056064, 0.16696264246298423, 0.029400623583745573, 4.542534649372101, 49.466579191146366, 95.08099863606115, 105.56634133861911, 106.13488105035599, 78.80735935703402, 72.93060548843877, 42.53235432409471, 29.397376045104, 39.84269488242365, 74.07262709832962, 68.07373846730879, 79.94321500101398, 53.8402964991908, 1.9081887170191736, 0.12582046505544456, 0.05810162503152125, 0.04038499142493933, 0.04660176811739803, 0.1040932615738242, 0.06317862760155432, 0.02479505811577603, 0.0749326916411519, 0.019531541864477822, 0.08774494526967888, 0.032727360394933534, 0.10174477307666695, 0.07648680824786425, 0.07600065651199511, 0.08645611725026563, 0.10391827177016005, 0.026501373410405173, 0.06689997630253916, 0.08455029733839535, 0.027861095206331343, 0.036862492336020354, 0.13150489107976038, 0.09129685064357135, 0.0893639188800608, 0.05795193145111684, 0.04821331450535406, 0.04319564927549612, 0.05927404599084009, 0.06458410782919777, 0.06837741516891026, 0.05886609267984187, 0.005463479563683993, 0.009904547759722318, 0.06277365820302118, 0.029699982016257225, 0.04411266801217872, 0.04896187050748737, 0.01798784022309607, 0.06836921036724122, 0.037017575344972076, 0.03780855346591242, 0.027874120616263924, 0.00849101307516497, 0.07683090429993407, 0.09774252291648619, 0.012100924711464154, 0.056538518383017475, 0.08426443929032934, 0.07147279342696553, 0.05051596030112236, 0.02745020011770389, 0.4231838743773199, 4.569346500981239, 53.34664267878379, 120.05769483504758, 134.6870373141381, 109.71259255563061, 106.13801110175349, 111.82513406199794, 91.29949646611368, 42.49544482077322, 28.19909195746145, 51.72927687245031, 72.76445388793945, 60.41443993968349, 46.24993362734395, 4.550045988252086, 0.5894816750960966, 0.049785840204886855, 0.36590047721420565, 0.13426221005858915, 1.4342140406370165, 0.8026146287879636, 35.03605381135018, 1.7548092118194027, 12.274127852532173, 126.84927094367244, 100.58023222031133, 111.33537907754223, 83.42738582241921, 87.43895853719404, 85.25530445960261, 103.84710373417025, 91.95790552323865, 97.84498307012744, 101.06564906335647, 100.22672468616118, 94.14800797739338, 92.49521532366353, 80.55959978411275, 80.39258526217553, 76.25316681400423, 77.3087158510762, 78.83061901215585, 90.37955945537936, 98.50264687691966, 100.45551653831237, 96.22953922517839, 95.20899341952418, 88.40637191649407, 89.9929000485328, 83.37524183334844, 82.29438566392469, 84.89272056087371, 97.14411043351697, 97.90588963416316, 102.5862656870196, 97.95100473588514, 102.9671827439339, 94.0136589542512, 94.88136568377095, 94.35994148254396, 101.69158089545466, 60.7903677417386, 34.83467148196313, 39.4459589066044, 54.22155480231009, 72.00916228755828, 94.12357945596018, 98.8130554076164, 105.2357953594577, 103.91889879780432, 103.68816145004766, 88.24051841612786, 79.24205995375111, 81.38610593734249, 86.3274843462052, 98.74966990563178, 99.20932462138515, 100.0298373929916, 107.19748250899777, 99.83888072352256, 84.58462622857864, 74.8990704936366, 82.84915001161637, 86.7068716787523, 83.95862379381734, 77.93256882698306, 82.93348097032117, 95.75431269984092, 101.88200412258026, 99.83629195920884, 98.45745332779424, 97.00887495471586, 104.09748431174987, 98.09251600696196, 100.18034658124371, 97.94397584853634, 95.91170957011562, 98.86599171546199, 100.04323620950022, 94.0866699526387, 118.7587627287834, 13.005263536207138, 0.3449634168176882, 0.2576405170463747, 0.3363562964143292, 0.09629282409385329, 0.07656599875659713, 0.20764284586954504, 0.14697196112284738, 3.9838163073985813, 53.475669045602125, 102.84398109682145, 108.80924717072519, 110.57460400366016, 84.9152506551435, 50.25529330776584, 35.07663465315296, 45.88303119905534, 58.315524747294766, 96.0467646198888, 82.76905521269768, 91.45688549164804, 81.3698673248291, 5.652326633853297, 0.052200373141996326, 0.05096114548524061, 0.060666265236514236, 0.05726100058264791, 0.08476388265168475, 0.05795408415818407, 0.04025239309656524, 0.030127721463119796, 0.05803458850770708, 0.028495841186433554, 0.029397628179961638, 0.007004586561027194, 0.058651549756647124, 0.049697142545013666, 0.045628074196077166, 0.06742421026912428, 0.028708495702894948, 0.08842480999808158, 0.04012451386980472, 0.015007828103168117, 0.0300791131843242, 0.02755978133439297, 0.020110447695779226, 0.04542012345947085, 0.018907567080590996, 0.032723411211683866, 0.05416965577751399, 0.0710103597732321, 0.19539351364777935, 0.16051791247821626, 0.11380660527896498, 0.11974138117605641, 0.1895211585947583, 0.1801817041010626, 0.14915020956147104, 0.14452293124650756, 0.16548741759071428, 0.21605744837753235, 0.1668317180367247, 0.12376941785576845, 0.271692254971112, 0.21981238237311765, 0.06465705472134775, 0.2170033064941245, 0.13495106099834367, 0.17187332734465602, 0.15711832070542922, 0.14998230362130752, 0.1705293486555738, 0.17221317926962532, 0.2181946957904485, 0.4895521243733745, 10.419544942917364, 79.18382844617291, 147.94089871068155, 149.5979275241975, 119.60507685138334, 126.73644788803594, 117.1414989040744, 72.37952816870906, 50.798306234421275, 103.4815937472928, 157.24403904330347, 106.4760801869054, 72.86507837234005, 64.81827320591097, 7.5361253176966025, 0.7841799792743499, 0.2895243916540377, 0.8357804136410837, 0.42773008526813605, 1.022237695513233, 0.22647278143032906, 44.47426488322597, 11.088639516984264, 11.08428764727808, 137.13089358422064, 103.26797362296813, 121.05328652166553, 86.65771653575283, 93.61327909654187, 88.69120659366732, 110.30274452701693, 96.17831307072794, 103.68630224658598, 104.55617412444084, 107.62432267588954, 95.89800480873355, 97.34563396823023, 84.65765291644682, 84.77805399125623, 81.81810794338104, 83.36226663281842, 85.11563670250678, 97.23223824654856, 104.241301936488, 104.01903690830355, 101.32275258341144, 101.63224327948787, 95.96053523402061, 96.37840101795813, 92.25817864941013, 89.13882747773202, 89.19882405188777, 104.1637880571427, 103.28423576970255, 109.02025499651509, 104.04110416289299, 107.47593941227083, 97.83911520434965, 102.31542602662118, 100.75236935769358, 109.88442374813943, 64.5889675232672, 38.99386652054326, 50.74944134681456, 68.24888798498338, 79.91234594775786, 99.41183659338184, 104.66953846716113, 109.54231462171002, 108.8714716511388, 108.58611922110282, 91.88617321752733, 82.74454824386105, 84.94148346685594, 91.10564508745748, 102.77701054849933, 106.6884216185539, 104.77427359550231, 109.02738586548837, 105.16688716027045, 89.09325738107005, 79.99051878529211, 89.53737951094105, 92.7625483851279, 88.48234822673183, 81.72493596230784, 87.89065868623796, 104.4265397902458, 105.47880972585371, 103.85596044601934, 104.74965680030085, 103.12823526320919, 111.5025269600653, 102.17468354009814, 105.72642895483203, 103.10005695589128, 100.72524224558185, 105.60012863528345, 101.74479961395265, 101.78585898491644, 119.19138446930917, 10.065780493520922, 1.0605286085797896, 0.8821527575773578, 0.42111393544943104, 0.25170166556152607, 0.24681040866961404, 0.2444053675618864, 0.24969235483196475, 9.039551173487018, 72.46054864698841, 112.01431782014909, 114.73736839909708, 109.18311965081, 93.76495715110534, 101.54560596712174, 58.754826284223995, 41.94302997281475, 52.06714591672344, 99.12009069996496, 86.67374334027691, 106.01827682987337, 91.16329608425018, 5.926929808432057, 0.2610732344610076, 0.13500831840980437, 0.1886312555401556, 0.2139913245675064, 0.22005734664778556, 0.18626534620360022, 0.14106350800683423, 0.15414701804759043, 0.1334270822905725, 0.22022654482674217, 0.17350984436850395, 0.15655544526394338, 0.25563401019861626, 0.17823438520633406, 0.1307257183737332, 0.15197751833306206, 0.3110308392393974, 0.20232999547114297, 0.14187926907212506, 0.08402414049112028, 0.1696461718529463, 0.1270440913316223, 0.22865015652871903, 0.21170341830340125, 0.1534310322735579, 0.22444502330355107, 0.11114627303135012, 0.2065529325796712], [0.03379637863667261, 0.01895010219736686, 0.031921562303097985, 0.021961383153534225, 0.007454031672809394, 0.06332067179403479, 0.03748009709881679, 0.024903618520306006, 0.07179152430786241, 0.05461330495534405, 0.08394508787821378, 0.04977585424879386, 0.06432457256221003, 0.05129039092289825, 0.0850933617461593, 0.04644627525140682, 0.013645506396348919, 0.03751385476320021, 0.05825562785649973, 0.04082569882514016, 0.07029818145618325, 0.03716536136644502, 0.1700137101954991, 31.814048328707297, 111.36432616941391, 116.73845183464789, 100.06087118579497, 96.71633674252419, 91.16462969010877, 104.72755816675003, 52.35471448590679, 39.903464163503344, 93.86864892898068, 128.21119631490402, 76.45182701849168, 63.871075722479056, 39.31806218239569, 4.244398234351989, 0.32429111640780206, 0.11347265223101263, 0.22291019679077212, 0.16110591560361848, 0.35193058812329847, 0.2277945742131241, 21.71197610516702, 75.4155211294851, 0.9462307417585004, 49.92800681821762, 121.76031727944653, 100.804960496964, 96.67825837289134, 95.84815932858376, 97.86669731140138, 96.69595610710883, 96.01010614825834, 97.90230458782565, 96.66016055691628, 98.19022224795435, 99.00163512076102, 98.12095319071125, 91.91226482391359, 84.2023677210654, 75.87643884843396, 73.28031616826212, 75.21842987306657, 74.78356453680223, 74.28330544502505, 83.49441912866409, 85.89324658916843, 85.96348054947393, 82.52067504390594, 81.88393315961285, 79.77852252221878, 75.05561228721373, 77.1771752449774, 83.7607245291433, 90.73213346542852, 98.41782169957315, 94.72509845610588, 95.88594744282385, 95.89554940500568, 93.75288409571495, 91.83396647053381, 92.39613625311083, 93.88644080008231, 95.37712973933067, 96.01693107235818, 53.10486778136223, 29.925121145863688, 70.86918031015705, 94.65336615039458, 91.03010023793867, 93.6301923567249, 97.59402198176231, 94.60161439834103, 89.3553658454649, 74.59412190221971, 73.74532884167087, 77.53209483238959, 87.74703718000843, 98.99195471117574, 98.25375680000552, 98.13988254916285, 96.5238425039476, 85.58122988670104, 75.58301418058335, 71.69841643302672, 76.57313808318108, 78.12546314731722, 75.0280458696427, 74.28961261626213, 84.13414985902848, 96.08978517593877, 92.44902549251434, 95.769405980264, 96.09773189790788, 90.16572752306539, 89.58695042517878, 93.28057581378569, 88.76193477261452, 91.93214339594688, 83.48439355050364, 93.54431598417221, 96.556288350013, 100.59565497982888, 77.21976434030842, 0.9243438549099431, 0.2603430300951004, 0.11817647039049095, 0.03400157528719114, 0.058598900364050945, 0.053675601844705885, 0.07447038056148637, 0.1806543343850682, 2.582319369239192, 45.73920965194703, 77.10194418507238, 88.58220392657866, 47.496643297133915, 81.94843261472641, 69.3554513685165, 24.92648397722552, 26.776693444098196, 41.884582734877064, 64.55196780543174, 74.04330345892137, 85.25972889315698, 69.65194332984187, 4.048095129189953, 0.24729849860793163, 0.04627996905436439, 0.022536598356260408, 0.05237282719463111, 0.0227145490897519, 0.048762021150680325, 0.11205764186959113, 0.07756749783912975, 0.026652309968466723, 0.1742776636514933, 0.041434240767792355, 0.06127016085590567, 0.051042936862476414, 0.09673634303673621, 0.006764965749631126, 0.0897901778620097, 0.055360252172836376, 0.04617100453845436, 0.1173888017693835, 0.04956875770022312, 0.03187957493918798, 0.04573212808839256, 0.07424857512476944, 0.024260707958150777, 0.05210858431734866, 0.015770574926488822, 0.039011246389559204, 0.014804178950256638, 0.040875797144948475, 0.008414587186228846, 0.06586823972963518, 0.004436554980554408, 0.04451789021972687, 0.05456653911800635, 0.07627762794013947, 0.06875333451335469, 0.0070504177710972735, 0.05904277170737905, 0.0422613897300776, 0.028374515841865254, 0.04148032095643782, 0.10072336336898227, 0.028474519044281017, 0.0726212205124959, 0.06148379213447052, 0.03876461587365597, 0.06270551468215643, 0.07466540356437046, 0.059248646345710566, 0.12571461468694672, 36.60016559785412, 130.097856367788, 133.46013561371836, 115.47824136672483, 119.20277503228958, 121.64797275297104, 124.1102876970845, 88.8079127957744, 52.419774839955, 41.48803895519626, 97.91727235240322, 79.49401732414, 74.36034079520934, 50.26638577061315, 4.809364666861873, 0.704942953682715, 0.15633799886751562, 0.3947089378151202, 0.10456123404325017, 0.6873229927112979, 0.6942459147784018, 19.902188624105147, 57.55487518925821, 0.5039471309752234, 57.38911582577614, 127.42641633556737, 105.72846074258129, 103.43841629643595, 103.6571119677636, 103.85960040553924, 102.72888306648501, 99.98917025904503, 103.04064089252104, 101.09956187586631, 102.84362808350595, 102.71734345343806, 105.33115602308705, 100.4960189327117, 89.27349029048797, 79.84517143618676, 77.18955424524124, 77.38519422469601, 79.02375651944068, 77.92757957212388, 85.58093963130828, 88.16246324969877, 89.5177205916374, 86.7689706433204, 86.48767394404258, 82.33414280799128, 79.62377717418056, 80.87713133904242, 87.97226752004316, 95.71101757787889, 102.7260511152206, 99.5400510295745, 99.20643775693833, 98.12667200642248, 98.91178930959394, 94.18410162771903, 95.97380068994339, 96.4130590808007, 101.7724209447061, 104.61188747036843, 63.58219708165815, 36.90392963347897, 76.6792146621212, 98.66762961110761, 91.39539057208647, 97.46044958791425, 102.1568210663334, 98.6528971887404, 92.0412088209583, 76.87156769537157, 74.97762772344774, 80.48289391302293, 90.21043469828945, 103.5175540370326, 99.51365347831481, 100.06965729498096, 101.55003040067612, 88.93421311532298, 78.14087021735408, 76.4937493108934, 80.82983539950463, 80.15242638126497, 79.57887388044789, 77.50152387926656, 89.50986800655242, 97.35191760524627, 97.37331021216609, 95.37246211882561, 99.73552626948204, 92.87579505674302, 93.59421637750442, 96.51138505628033, 90.9653340616534, 93.21966924974996, 87.97091037996354, 92.30493330186414, 102.33603415950653, 101.70281456362818, 92.2590337261077, 3.637444054888141, 0.36047709565008845, 0.2541640866547823, 0.2889381505308613, 0.1610185049714581, 0.05264631292271999, 0.10127316168960064, 0.29979530181134906, 2.139864246691427, 48.7193480614693, 84.83396345569243, 100.09618036208614, 55.905875467485004, 60.49759026496642, 40.452372412527765, 29.31295879425541, 39.8013021099952, 65.76373307935654, 85.29406532164543, 85.91005786772698, 90.5939640537385, 96.47128274363857, 7.4984367335996325, 0.2337339772812782, 0.06683254524344398, 0.07289090644448035, 0.05822460129556637, 0.10336666548204038, 0.036378589068208976, 0.09361294128241078, 0.0575982018433992, 0.02155788847425532, 0.022431184657879417, 0.04411181765458277, 0.03805084026328499, 0.0785462900755867, 0.02702476276505378, 0.05132719378678068, 0.05789157138356279, 0.05175532968414407, 0.06383129620864507, 0.07080277292838982, 0.06179563205448851, 0.05056263420790915, 0.034104591130369136, 0.036637687665079875, 0.05208090939108403, 0.02703232405286643, 0.03161196319025851, 0.03375908930695826, 0.10754588195272993, 0.14514036746996065, 0.09616324798234048, 0.16917036996493418, 0.13306513638986697, 0.17251469615486362, 0.13909159768973628, 0.12211897335345707, 0.19349640415560818, 0.07313672873762346, 0.25882231492188673, 0.1225781664552708, 0.1453124767830295, 0.21114382171823134, 0.16127958773605286, 0.23312797108965538, 0.17582876187178398, 0.16791199394051107, 0.17010553349410334, 0.1500165017862474, 0.15840795311716296, 0.1865743707504965, 0.24046969810320487, 51.32364496108025, 160.56617675289033, 149.36669595779912, 128.64291591029016, 125.06786377199235, 120.55887176144509, 127.03873711247599, 72.58655871114424, 55.16151943514424, 134.05669673796623, 196.4387779851114, 108.74456728658369, 82.12809285809918, 69.81545125284504, 6.859590988005362, 0.7716551158697375, 0.3530084738327611, 0.5198081847160093, 0.23040811381032392, 0.7090732094741637, 0.22223801592424994, 33.4380409794469, 98.200867560602, 1.3085476741675408, 63.84653737468105, 129.99069721468035, 114.05015345542662, 106.27347407802459, 107.16529553936375, 110.2893457105083, 107.54039179894232, 104.34521336709301, 110.7140834869877, 106.88676018868725, 108.86609800400274, 107.50012474675333, 110.66717978446715, 104.97651884632727, 94.11174958752048, 84.3705197303526, 81.26467720154794, 81.29525599941131, 82.38456095418623, 82.63532592404275, 92.11424335356682, 96.68346728048017, 93.56096252318352, 92.03205400897612, 92.77279361601799, 89.8447991955665, 85.09029034645327, 85.55237693171348, 93.95843982696535, 101.06349175976169, 107.58007834034582, 104.42464920782275, 105.12227412193053, 101.37346882973948, 104.85476847617858, 97.78153481022005, 103.53786406978485, 101.02910041809083, 103.07602851621567, 103.29728157289567, 62.37785293209938, 46.190662691670084, 82.71016474693053, 103.22250550793063, 97.19265368676956, 101.1004561762656, 104.55657420619842, 101.47951402971822, 99.44866764929988, 81.95239420860045, 79.83511447906494, 86.41600439625402, 97.35634988354099, 107.94735339380081, 106.60354152802499, 103.59591514833512, 105.72151814737629, 92.95454056032243, 81.70634392769107, 78.0899892314788, 84.53251361846924, 86.44172729984408, 83.58309607351981, 80.90774936060753, 93.46694331015311, 104.97622074619417, 102.22926724341609, 105.05872388039867, 105.05160870090609, 97.67599951836371, 97.20177711979036, 99.35949648580244, 97.65910979240172, 99.22330394867929, 90.7611511599633, 101.4368700212048, 103.67978326735958, 109.25112570485761, 93.11561661381876, 2.277727468359855, 1.3769647190647742, 0.5710997937187072, 0.2461589428205644, 0.2832512960078255, 0.16848066100670447, 0.31319519084307457, 0.6610974128688536, 6.200014045161586, 63.10917492835753, 88.72979487142256, 104.90178200506396, 68.01043141272761, 108.92844015552153, 93.0413112332744, 38.939243593523585, 37.51890628568588, 55.325090116070164, 86.30777835845949, 94.64274437196794, 107.56501643888413, 111.59737771557225, 10.164315335212216, 0.366443173899766, 0.19987734965980056, 0.10187015868723394, 0.31650625349533174, 0.17423030409601428, 0.20719753428091928, 0.21864546192509515, 0.16345158489721437, 0.11731210870728379, 0.24170283919140217, 0.12734261281307668, 0.14257427935879077, 0.2246116474270821, 0.24898649674029122, 0.19353559721381436, 0.1987217673130574, 0.19104777264498896, 0.1817711067175673, 0.24049352343765, 0.15341024064729292, 0.1695645988107689, 0.2077645772407132, 0.18189977884532946, 0.1607736173055826, 0.09756284465472545, 0.14627859026433962, 0.17111468579499953], [0.0768963588521846, 0.08776697795838119, 0.08355401531462708, 0.03899209802189181, 0.05399395351208026, 0.04161569635353742, 0.0714056917856778, 0.02171172084467065, 0.025716757649675976, 0.029877469266554522, 0.09310200660219116, 0.1149489189828596, 0.06947259914370314, 0.02821223543686492, 0.02611642763499291, 0.047684185236932776, 0.04649443536876671, 0.08602287154644729, 0.06915586009140938, 0.028593088387541717, 0.09485944294400754, 0.16993296452827994, 28.92423425951312, 128.49066518968152, 105.45627963158393, 102.06455123039984, 88.40736035377749, 76.01070942417269, 41.334117304894235, 73.12656710224768, 53.345434588770715, 75.23368789303687, 101.85570070820471, 86.00916831724106, 79.96186979355352, 46.98759025143039, 4.533101839403953, 0.37075557475609167, 0.17168251016447622, 0.22845011564993092, 0.13402331320028152, 0.10562496244787209, 0.12274584778013731, 3.3047446945021233, 28.50427589108867, 6.4327959283705685, 3.6228545538840757, 104.18516497458182, 97.77243491142028, 112.32845260250954, 103.31668161576795, 106.57667329234462, 99.43508840376332, 106.23278340985699, 100.25887243209347, 101.06641784791024, 95.59974778083064, 101.08021674617645, 94.96074661131829, 100.85610820401101, 94.31484991504301, 94.6891930795485, 82.37099739813036, 74.29071872465073, 70.57017018718105, 73.26086905694777, 73.59355665022328, 76.10476001616448, 79.48469777261057, 87.93534232724099, 81.37469184014105, 80.03710869819888, 70.73134037756151, 73.64002889202487, 77.56773348777526, 86.55924151020666, 91.85975997678696, 95.34964961390342, 89.48065419350901, 92.44468735110377, 92.38534973513697, 94.37768628520351, 94.95236842863022, 93.94839071458387, 91.99835300445558, 91.90827185107817, 86.8391026220014, 103.7304759794666, 44.11243407957016, 60.46308909693072, 93.28234872510357, 84.14045703026557, 95.90867365560224, 96.45951563312163, 96.32734744779526, 84.33359453755041, 74.141629434401, 73.52253821588332, 75.14488543233564, 78.5318442313902, 94.08631693932318, 94.61083196824598, 89.03664189000284, 95.69386897548553, 87.98224602976154, 82.53004950861778, 77.16111706149194, 76.09314195571407, 71.61759991799632, 74.2530639709965, 70.9462627287834, 78.84198604091522, 91.881772318194, 92.78451365809288, 88.54360780408307, 92.9730619922761, 83.98932810752623, 86.78539752960206, 81.72608913913851, 84.94182863543111, 78.82282918499362, 87.465771859692, 77.44078989951842, 93.54196256206882, 89.5473737101401, 102.97445481823337, 58.645843228986195, 0.4299575625167739, 0.6671792929691653, 0.19691530134408705, 0.08759417150530123, 0.08199004681720849, 0.09173050237398955, 0.09991229076178805, 0.2720257790098267, 5.227580032040996, 44.91235833014212, 82.08065571323519, 88.2283120001516, 60.068086808727635, 76.64517633376583, 54.75378513336182, 32.45776222598168, 32.654584800043416, 39.3728929950345, 56.06140921192785, 75.14449319531842, 88.23459563716766, 62.09201805053219, 3.7580240878366657, 0.12752276604935048, 0.018080383644349152, 0.09476742046254297, 0.08391284323748081, 0.05009209534393684, 0.06731717246434382, 0.099338996524532, 0.05016819468789524, 0.032829104532157226, 0.03958005518201859, 0.06178741193106098, 0.09508939189535957, 0.030764524389298695, 0.11545764732985728, 0.018171260824366924, 0.048012886752164176, 0.05758846103544197, 0.12284348568608686, 0.02674773771075472, 0.06143940500013771, 0.04106700502996964, 0.036503131982059255, 0.06128359803809755, 0.04374825147791736, 0.05608837277958951, 0.05319482038518595, 0.08640542521231598, 0.03559180527865406, 0.048879370498921604, 0.00977001601694933, 0.03105944334228914, 0.038016029228005684, 0.02934358259212346, 0.007326127548191337, 0.004128573270845077, 0.048717097754800515, 0.025383471098217755, 0.05572527008611829, 0.06018109792362779, 0.07721257696468985, 0.0654124174146883, 0.045841460326506246, 0.05528548582186622, 0.12384788058097325, 0.07729187472573212, 0.08895601536477767, 0.06943030342940362, 0.2878222362168374, 38.23090276410503, 154.2029313118227, 118.23414571823614, 114.20448303222658, 104.29395583368118, 104.66831468766736, 58.32396176553542, 86.68174497542843, 62.13683897449125, 34.25262704972298, 89.46214845103603, 95.92703819274904, 90.77713874078567, 61.0051606547448, 5.0130896318343385, 0.6859073848012955, 0.2988474671879123, 0.5909719306134409, 0.27141113134641803, 0.9015518811441238, 0.9679227971261548, 1.4813718392002968, 13.871423871286455, 2.440423460737352, 7.197504649239202, 110.78126584329914, 101.46051406860353, 118.3790066934401, 109.84730243682863, 111.40671130149596, 105.1537315307125, 113.45323931786322, 107.31538111163725, 104.33579967867945, 100.28750573435138, 104.80517402771981, 99.63240715765185, 105.73955320542859, 100.52213407331898, 99.64773578028526, 87.6897156623102, 78.27621552252, 74.31246434488605, 76.1937193716726, 76.39369749253797, 80.75328642322172, 83.96781782950126, 91.17674981394123, 85.3441853677073, 84.80677358565792, 76.38881021930327, 76.4232329399355, 82.04506412629159, 90.93098194368424, 95.74521280104115, 99.8298357379052, 94.13924540242841, 96.0402770196238, 96.37176436762657, 96.47168282539614, 97.04826339598625, 96.48654860834922, 93.58922712264523, 95.9860541743617, 88.07653980870401, 104.2878604704334, 51.826528118502715, 66.24298787886097, 98.6980672036448, 87.59306846126434, 103.03956616309382, 99.04423990557271, 100.28103382356706, 90.00749911031416, 79.18016495243197, 76.21157400069698, 78.50816096028974, 82.49914123165993, 95.43118000030519, 97.15879578744212, 91.3432465830157, 99.46645167566116, 92.13447493891563, 86.92468873916134, 80.36752131677444, 77.98924707597303, 75.61441667618291, 75.67610771425309, 75.79464174086048, 81.56377361666772, 95.09335410210394, 99.40731017820298, 94.12767441042008, 95.66543963647659, 88.89403235527777, 89.71097577002742, 83.50798268471995, 86.85875369656472, 82.2898357145248, 89.09594812700826, 82.84987172772809, 93.56852485287575, 95.81580761940249, 103.54270427457749, 76.0851324758222, 2.049174145344765, 0.5527899246062002, 0.2826223991090252, 0.5811660664696848, 0.17889625452939542, 0.06669275717990053, 0.01869076036758, 0.3522361346310185, 4.748463005788865, 51.455703320041785, 85.47017974238243, 95.15852036014681, 70.23317583145635, 53.67725926060831, 33.11376294782085, 35.285532243790165, 55.1162709728364, 55.966950693438136, 68.50078259744953, 86.79084962414157, 96.71248497501497, 89.38224192588561, 5.611098600972084, 0.219262607035137, 0.10009072796111146, 0.012728057692818826, 0.03518785094662059, 0.05884576453677109, 0.028706390876322988, 0.028031884932950623, 0.08307377011665414, 0.03930826633868199, 0.06303131272415481, 0.021041660126478925, 0.027655235889758316, 0.03674997317214166, 0.08490807572079283, 0.025829422370260282, 0.05845357348481494, 0.06414282586305373, 0.11262673028414288, 0.027003105459434372, 0.08728867096285667, 0.06881198620483761, 0.04923715654219832, 0.14011938124895096, 0.061114430502657933, 0.08417509045572051, 0.017330153740101287, 0.20319412732797287, 0.30739308605271004, 0.1946526453379662, 0.1642045114309557, 0.16512066065784425, 0.09408622274115201, 0.16816288773571292, 0.11652557389630426, 0.125823697946485, 0.09636510448950915, 0.20664717671611618, 0.24052508626013036, 0.20759599193209605, 0.19212345202122966, 0.21369515497597957, 0.1520523191579888, 0.12942736788142112, 0.3427971959594758, 0.29725008193523655, 0.12747061078346547, 0.16016482255391537, 0.3918200508961755, 51.60999759551018, 173.5465861905006, 128.26925523819463, 130.2364258612356, 118.91593994632845, 103.67531961010349, 58.302243601891306, 93.91204603256719, 65.854430044851, 109.02797422101422, 155.49654468413323, 99.77792709104477, 105.10133650995071, 81.06753887668734, 9.259882473176527, 1.2215084414328299, 0.6530114467586241, 0.6379421908528574, 0.7897499287801405, 1.4293810677143837, 0.6484920795886748, 6.724500146604354, 47.089305154738895, 9.55120671179987, 7.282392584508465, 111.45434456486856, 101.18393990301318, 121.83713297690116, 115.49973595526912, 115.82691654082268, 109.26235937303113, 117.30749360976682, 112.6481963742164, 109.90210579287623, 103.2114758030061, 110.28856123647383, 103.63939854406543, 112.23461381850704, 107.07442991195187, 104.27685429972988, 91.9147123829011, 83.62213934621504, 79.54216834037535, 82.05916896943124, 80.9829568862915, 85.10592491396012, 87.35771840618503, 97.67465806776478, 89.22949698663528, 89.90537628050774, 80.9884560492731, 82.33029104048207, 86.5968962638609, 96.42210406641807, 100.55938874521564, 104.824275970459, 98.35668763806744, 102.28203881171443, 102.80337672079764, 101.00825694299515, 103.73869726734777, 102.70532531123008, 101.36145853227185, 102.58861126438265, 95.28060020938997, 108.15490953383907, 55.77952023475401, 73.47040991629325, 103.05631468372961, 95.08349326349075, 105.55062832370882, 103.56342223382767, 103.62354432382892, 93.78435719397761, 82.74168491363525, 82.79740610430318, 83.32915398382372, 87.28461327091341, 101.5295320941556, 105.58458820466073, 96.6109505007344, 103.12833724483367, 98.43422505163379, 91.54288738004624, 85.87343861979824, 83.54106395475327, 78.33312911372032, 79.48570974411504, 78.83047780682965, 88.20709197751938, 101.19052164016232, 102.68543889445644, 96.88029181572699, 100.67741286370062, 92.73465248846239, 93.51099152718821, 91.74900793260144, 92.54577467518469, 85.51023498658212, 94.32700926257719, 85.50338652826126, 102.42722926601287, 100.65937780564832, 110.51141462018414, 71.56921355955063, 1.6672346981302386, 3.1546581416360797, 0.5550736633519973, 0.7187020766638941, 0.2534423245778007, 0.30147046031009767, 0.26275001706615575, 0.530233170476652, 10.945902505228597, 67.42525300671979, 96.80563342186713, 101.2194138188516, 82.32800037630143, 101.92016878435689, 71.65538018749606, 46.78700024081815, 44.25678514665173, 51.715211253012384, 77.66761272184311, 100.13186608591388, 109.368953704834, 108.53861931831607, 6.753967933116421, 0.32728360905762643, 0.2312138238020482, 0.18349748585493336, 0.12910731166841524, 0.10620739611406481, 0.2369968070378227, 0.17007656004880706, 0.1524289279815651, 0.09340664912616053, 0.2517757002985285, 0.19914256408810618, 0.12338226766235406, 0.1265542930172336, 0.1832408617220579, 0.09286760667999906, 0.23353281791412064, 0.17006134554263086, 0.21891342415924997, 0.1366443451373808, 0.2902613375936785, 0.27995200046608526, 0.15575633895012642, 0.2826291713262758, 0.21393409779956266, 0.1947841213475312, 0.16977944050825414], [0.04980606109564824, 0.07450247964551372, 0.03961450232553386, 0.03557772458260579, 0.008905827661135025, 0.03600179638353086, 0.05561677288384207, 0.051742888416253754, 0.08015060076309789, 0.03071905707099265, 0.04759863619842837, 0.08491184487338028, 0.01938131010730661, 0.043354470793518333, 0.034337719346606926, 0.0230676083705358, 0.033723071683198214, 0.09910444338475505, 0.12583568722250002, 0.059104284737259156, 0.261602999582406, 22.576166429827293, 131.32578572919292, 103.54666586845153, 116.19392487310596, 96.80029899843278, 94.28809935046782, 58.01278052791473, 89.54401616127261, 191.0849152841876, 160.30750428476642, 120.92993582448652, 114.34549223992133, 108.63877311829599, 46.00174565469065, 5.566442416560266, 0.14162756322372344, 0.08836414349535782, 0.06080331453572839, 0.06448203427416664, 0.2849490694220989, 0.11317886517293031, 0.528049452170249, 6.488830418356004, 2.3735139543010346, 5.927941289640242, 90.16764948444983, 106.92655655645557, 102.2989599166378, 104.37622362567534, 104.75266918059319, 105.95605234945975, 106.8226686600716, 102.36700519438713, 104.11008296474334, 103.93978149660173, 100.47555200515255, 94.58888238476169, 98.66933976450275, 97.42485015623032, 94.10715256967853, 95.09084378519367, 91.67114103994062, 78.84695176155337, 73.81739062647667, 71.59498353158274, 71.1183214187622, 72.94521239496046, 78.99906127683579, 78.54100688811272, 76.46506109545308, 71.63692935820549, 69.73529369600358, 73.20195505695959, 81.17788299437493, 86.69357484386813, 91.34723955585112, 95.97567558288576, 94.97838943235337, 92.67564435159007, 90.79808419750583, 91.73299681755805, 90.58102807691021, 97.80509256547498, 90.79504828299247, 95.07733514232021, 89.0006031528596, 93.08404937867196, 75.96852041059925, 62.06730319607643, 98.12416953425254, 81.35056141884097, 92.74683537021761, 94.44015395256781, 98.75659681135609, 85.9489913140574, 73.53750598046088, 68.0476547056629, 72.110108406313, 73.26678399116763, 84.51356857053696, 90.59720393150084, 91.1645826216667, 94.73950924411898, 92.67096888634467, 87.3073551731725, 83.79746144817722, 75.2700404197939, 75.0772951495263, 71.90074013125512, 73.44399667555287, 71.33167482191517, 79.91959448783629, 88.78460607221051, 87.4491959233438, 87.73236751556398, 86.7919086640881, 81.36119888674828, 81.65853023529053, 77.50872535090294, 85.87898485122189, 74.30504322052002, 82.46391834751253, 77.50967456448463, 92.57718501552459, 88.56242733616983, 109.35373490856541, 38.96112257434476, 0.9098707379833345, 0.30879064493121644, 0.24274202213893015, 0.20043602693946133, 0.08720869904444103, 0.06294069984447091, 0.07572546240783508, 0.17722589174105277, 11.830719594032535, 37.683951777796594, 79.71286204553421, 92.8779915840395, 84.46695512340915, 82.31031048682429, 54.105072175302816, 28.026303706630586, 27.30331086343335, 47.1460343945411, 83.95944749155353, 79.2527444901005, 80.14630748379616, 36.38659646434169, 1.4499561056014032, 0.20294168603516397, 0.024556274255437237, 0.03620073792614764, 0.014103995654882203, 0.07596644302529675, 0.02808058322707732, 0.04884994889218961, 0.09889329423106487, 0.02074704760865819, 0.0372395416601531, 0.01250422786876199, 0.062261260294866186, 0.034602257167740215, 0.050219633661571055, 0.08821502448089662, 0.012503692564824897, 0.04291178688647286, 0.07734248249401009, 0.013391350024199535, 0.016687149332175334, 0.06693962135262067, 0.02235234654959171, 0.05693120739212441, 0.07872801379210527, 0.042828417368113034, 0.05600776500819672, 0.02851758276172463, 0.055878468518776286, 0.05998140944528484, 0.030508348417858926, 0.022853594048008807, 0.03654282299741622, 0.02224002465335352, 0.06036686658438656, 0.055405669695427345, 0.018014314306539395, 0.10121000540112296, 0.023724967350942955, 0.04447337285044693, 0.0727973671089257, 0.010975486966931533, 0.09005841588781727, 0.004344753228173021, 0.12620232924218142, 0.08680108664256912, 0.3005595817681282, 30.57262405272453, 152.74075015898674, 115.71432098265618, 131.41563938510035, 119.62395914139287, 109.75764489942982, 75.94805348304011, 77.30503666785457, 170.20780194190243, 108.1866728874945, 81.17782808119252, 126.135219143283, 114.03304407673498, 59.269900168142016, 6.600196313473487, 0.24787243635904407, 0.19863778875479776, 0.4704951663171092, 0.26101516499634714, 1.3307881259149121, 0.38402158226217, 0.7456542142937261, 2.04242313340787, 1.0616163308581998, 12.477922439575197, 102.1162166903096, 108.40682768052625, 100.93138633235809, 105.94068450312461, 107.85487959461828, 109.32632538580127, 111.1899140573317, 107.45222476220901, 105.81705139529322, 107.90816107103902, 106.39123147533786, 101.07297605083835, 101.4516338225334, 102.0617114343951, 98.53811294801774, 100.05010820204213, 96.64456521311115, 85.62877685792985, 76.92546890627953, 76.87672953451835, 74.03636870845672, 77.4592956419914, 82.52440914030998, 82.75669190191454, 80.73384715664773, 75.52365303039551, 74.01781589754167, 77.17285279304751, 85.89414873430806, 89.95784974867298, 94.87508989149525, 99.68796360877253, 96.6584582482615, 96.47254574683406, 95.73281811129664, 96.20610698576897, 95.04099830504387, 102.29297437975484, 94.94321361664804, 98.56476153096845, 97.18230647425499, 97.35126649179767, 82.13027369591498, 68.22370636847712, 100.05988274851154, 84.66504266185146, 96.7958902543591, 96.9342871635191, 104.21620661212553, 90.61000654774328, 76.0475326353504, 71.32261414681712, 76.38140478441792, 77.7436988584457, 87.91815450114589, 94.42446447187855, 94.21478240720688, 99.16067154176774, 99.58711162690194, 91.83574722659205, 89.67881233461442, 79.91604082046017, 79.37440072336506, 74.18389689537787, 77.57822190561603, 73.59525111413771, 82.63575738476169, 89.87805304988738, 92.4957016975649, 90.13958884823708, 89.85317737825456, 85.49844434184413, 87.06591759958576, 81.31169857517366, 90.456602650304, 78.18935855742424, 84.17497388778195, 79.41987668314289, 97.48788264489944, 91.57314454355549, 113.52892537270824, 54.237303118551935, 0.8769046875738329, 0.5042230452020322, 0.7455764410476531, 0.4920910010414739, 0.1489911697083904, 0.037628450025353706, 0.06125265574683586, 0.3928181102439281, 12.509616171160053, 45.01743470468829, 83.13531829464821, 103.46532375581803, 80.52778936201527, 43.6723716028275, 25.281966424757435, 29.89739783348576, 43.291721267084924, 65.8426550895937, 93.43477987474012, 90.58882574881278, 93.15644848731257, 58.18762410071589, 1.7715704801582524, 0.1294342167074642, 0.051102438911555276, 0.08722692427615966, 0.019082978232613495, 0.06803972361188743, 0.1000514506332336, 0.10079691547059244, 0.04000718367376155, 0.03768539334076547, 0.015635713765908395, 0.0649847794744757, 0.019833911022531892, 0.02892900645101984, 0.0664800605286033, 0.03506034710294297, 0.00722385959834942, 0.0492889670685174, 0.05380832657758748, 0.037807147694571365, 0.04096641768551162, 0.04248370078482455, 0.04638146038257307, 0.08765768785510333, 0.04962300438614142, 0.03378238221029601, 0.16354480247584083, 0.19166885544696163, 0.08750114544865586, 0.18213412514136684, 0.15774920943283266, 0.09330948619472404, 0.14199671035091724, 0.131788496829329, 0.2134006248126107, 0.17528172912857226, 0.14096740993761248, 0.2666856252378033, 0.21795743836029885, 0.15271067979835695, 0.20098612403437016, 0.22483750546891845, 0.25264577699765084, 0.220600962638855, 0.16510515503825682, 0.26455314289177617, 0.4022050775106876, 42.56578468507336, 177.23438293703143, 126.15037518162882, 150.0078465861659, 125.26743396635979, 120.83266104421308, 76.77939984106249, 103.11046692632861, 189.9072785531321, 183.91475985127113, 172.71408665564755, 130.2509307861328, 135.3337577081496, 77.76698204778856, 10.675708074723522, 0.43122347684637197, 0.5059216766347808, 0.5167285112604019, 0.7958669876379352, 2.074686956982459, 0.38736252234347407, 2.781142842385077, 18.41496706008911, 7.061119915977602, 10.083141884496136, 102.59701298129175, 109.39450402413647, 102.72074022600728, 107.71686707773517, 110.13178410068636, 112.5223510496078, 115.07600230555381, 111.31601825837167, 111.24027729034425, 113.94151949113416, 112.26651053274833, 103.67804957974343, 105.99078885970577, 105.84852449355587, 102.85588941266461, 106.00663523520194, 100.25567962277321, 88.64704855026739, 79.88680347319573, 79.74081285538213, 80.27458467791158, 82.72973737409039, 86.74505203000962, 87.05615089785668, 87.28735893003403, 81.1822368252662, 78.61214299355784, 81.94348258356895, 89.98230180432721, 94.85651354635917, 97.91710761285599, 105.1544689363049, 101.04949674298688, 101.67384393753545, 99.03722670770462, 98.72094246648975, 97.50103827445739, 105.384123709894, 98.10407915422994, 104.10526629417174, 99.99179824706047, 101.60318636125135, 83.09592200863747, 72.2386444768598, 105.943492920168, 88.97484887030818, 101.09004620582827, 101.9515085220337, 107.41149487033968, 94.56177880687099, 79.13455563206827, 75.15123182727446, 80.16268730163574, 82.24601499495968, 94.10607784025132, 100.3856748150241, 98.71203084145823, 101.70519151995259, 103.6450546018539, 93.33748940498599, 90.95060948402651, 83.27027920753726, 84.12474401535528, 79.02909878761538, 82.35214648708221, 77.0101293440788, 87.44920376808413, 95.36855543813398, 98.16666449269941, 96.33937343474358, 94.85073981746551, 91.98809992882514, 89.53138612931775, 85.67651994766729, 94.63783356451219, 83.24971029835363, 89.56056071865945, 84.9761885981406, 102.72474888832339, 97.17689360341718, 120.41941581233856, 51.394071117524184, 1.49723059467731, 2.8288839709374214, 0.4113583879605417, 0.5586913756785855, 0.4465535703685976, 0.36853897595597856, 0.37819900760246866, 0.4889814501568195, 20.76221731401259, 57.057499039557676, 97.82433571354036, 109.34305037221601, 108.53206111538796, 115.87172569767122, 72.91944242292836, 37.99332872513802, 39.79951350919662, 63.52311834212273, 106.00789039365708, 102.7190379173525, 107.76142520289268, 73.62059747019123, 2.183878388135664, 0.2898605816787289, 0.13609882924825917, 0.2547185810943765, 0.11094719742334659, 0.19333393222862677, 0.14009953957171212, 0.15431857577735378, 0.16889174378687338, 0.18878445780325323, 0.0839262650979142, 0.12231822516168318, 0.14568024495195958, 0.1463451326614426, 0.15100660914134595, 0.16586830118490806, 0.07797310309064004, 0.15030836596363975, 0.19474011725716053, 0.1073288186002643, 0.1019097041458853, 0.12919136683546728, 0.09145758355096464, 0.1737497831063886, 0.2155918201371547, 0.10252305712070196], [0.07549129997289951, 0.09655025261904925, 0.10537363964343265, 0.023835126964014866, 0.043540879137693875, 0.05599454233062364, 0.04247083816857588, 0.1015330033917581, 0.09806196625915267, 0.09662126896963005, 0.05985904222113952, 0.06297047002120845, 0.065387986870783, 0.05330564266431236, 0.0660570957247288, 0.038464424320526665, 0.05070443325225384, 0.1467148007284249, 0.08654255495076218, 0.34446720634737327, 2.7392654120922093, 111.49309758217105, 102.04500213746103, 105.28568006330921, 79.02094810239731, 51.49611157755698, 50.22258074052873, 30.821163077508253, 34.33716981641708, 86.54723121273904, 101.68782326482959, 111.71072636881183, 109.0358268060992, 39.82431857816635, 4.567170075831875, 0.25788373464057524, 0.030920375401394504, 0.13701180687114117, 0.1634666768293227, 1.2686110816655622, 0.908103832794774, 0.4647703138330291, 4.925687947580892, 1.5805449240630673, 16.80413592246271, 119.51072031451811, 107.82151591393256, 112.875882117979, 103.83111615334789, 110.69700548725744, 104.59968889913252, 106.51957142737605, 98.63208509260609, 99.99370451896422, 95.58347778935587, 95.4747026197372, 99.38532137101697, 104.81504271107336, 101.65709541689966, 100.31609196816721, 97.46980051840507, 96.08310930190548, 88.33360410505726, 80.40341100385113, 71.41513501444172, 69.8416526855961, 67.50938000217562, 69.30915171100249, 77.12359566842356, 79.24545672632034, 77.41585931470318, 74.33588873955512, 70.21908667779738, 75.53385903758388, 81.831263572939, 85.64800431651454, 89.67023803341775, 90.34775687802224, 90.53108845987629, 95.0816026810677, 90.46878553205921, 94.44166798745432, 90.58347563589774, 97.60687951118716, 92.32403524460332, 89.93448811192667, 85.0071753225019, 91.04485619452693, 91.73505998426869, 79.13256306802073, 86.38969313713812, 82.39491601144114, 87.3853946501209, 95.93189408702236, 95.2803413329586, 90.49827391101469, 76.29842312105241, 72.17853023159888, 71.78820733101138, 77.11165597361904, 78.66618540979202, 89.09819956748717, 94.21783401120095, 93.49277604010798, 95.0511101753481, 91.65176453128939, 87.77136371981713, 86.04509722801947, 76.55941763231831, 72.51591682434082, 68.85457254225209, 75.0167102198447, 70.696501885691, 84.16266549018123, 83.93773325027959, 81.37634708035378, 84.44936721555649, 83.41208073400682, 78.7275940372098, 83.59833840400943, 75.54482598458567, 78.17854066048899, 74.20314004344326, 77.35291311817785, 79.86831342020344, 92.35033865897887, 90.12438574144917, 105.44969004969444, 24.299914759974328, 1.4574292013722083, 0.9360306181253927, 0.9097306358237421, 0.255378719058729, 0.05182281436939394, 0.07109731841351717, 0.04079045495018363, 0.04789234664771826, 19.98668039998701, 27.80868668710032, 70.23494874277424, 97.81037992046726, 91.85331944496401, 83.06862231223815, 84.26065414182602, 24.853245481368035, 25.59055301450914, 57.747612614785474, 64.95813315914523, 68.60693762379309, 73.2016412673458, 22.493894715462964, 0.5682759323427754, 0.08921958791512637, 0.06214273500166113, 0.073569759936823, 0.03569928741443061, 0.03112715402347667, 0.021325329078301307, 0.03425832965501374, 0.07153176687537663, 0.017571362268720424, 0.029209319937733874, 0.0200515431952813, 0.013287411045072781, 0.028948692995454037, 0.04538427437505415, 0.030139270238578323, 0.05480594925522324, 0.03665940625773322, 0.07236812804495135, 0.042353029167580034, 0.031299270997424765, 0.016673244836349643, 0.07409953271910068, 0.020659045173576283, 0.01188630709469679, 0.07245510200699491, 0.09439317885065272, 0.061165923102488445, 0.005071202326836366, 0.12985771011200645, 0.05270572304124794, 0.011673184306991678, 0.07559070754195414, 0.025254011815113407, 0.031962122828249014, 0.03171063148446622, 0.014148370340286244, 0.10344286058698932, 0.02065692694046565, 0.0646411890404359, 0.09268023689547855, 0.022632478090423732, 0.08882792546383797, 0.08952281317643582, 0.29825506671782465, 7.098244659362301, 130.8515711753599, 115.87085493149297, 119.31836728126773, 93.53999353224232, 76.03485553495346, 92.08325662920552, 59.406481019912235, 53.0623806676557, 103.71097395496984, 86.62161504068683, 119.0438876613494, 119.26253626423498, 49.52213956463722, 4.95185358870414, 0.28159329787858073, 0.27754427805062265, 0.2202984651610736, 0.12396018140979352, 2.39188707163257, 2.0507558411167515, 1.6184116082806743, 6.3388585948175, 0.2886373231247548, 25.352421998977665, 130.60161421375892, 109.68516734338577, 116.375867935919, 109.0379370412519, 114.37409416321786, 107.118023134047, 106.16368693690147, 99.51938798350673, 103.52413577418174, 98.71766336502569, 96.50381488184776, 102.45945545934863, 106.29431755312028, 104.51456562165292, 105.00526197495, 99.96038790672057, 99.13906712685862, 91.6727727459323, 86.31914538721885, 72.7838303965907, 73.04158503009428, 72.36581556258663, 74.24871014010522, 80.95404901812154, 82.540388876392, 81.08959044179609, 77.38356251870432, 73.80363095191218, 77.59606868990006, 84.79108410496866, 89.28941511338758, 93.06420218560004, 93.61102765606296, 92.45080624857258, 98.57914094002017, 97.02676096270162, 98.31953494779526, 93.41227331469136, 100.06840998126616, 98.455672571736, 91.66666953794419, 89.93583740726595, 94.83682324809413, 95.56942785939863, 82.44362400424096, 92.12331971814557, 84.18052796394595, 91.97565817063855, 99.07914900010633, 97.61932126937374, 95.13020084750269, 79.98623555706394, 75.68536450785976, 74.06892438088694, 79.33921706291937, 82.99868645206575, 91.32685892043575, 98.20574698909637, 95.39882829112392, 98.37667603646555, 96.47712707519533, 90.75212970856698, 89.67476444859659, 81.16231118479084, 76.60785105920608, 71.79813092754733, 75.33378677983438, 73.2934404188587, 85.5691489865703, 87.34095419606855, 88.65011584374213, 87.84457083671325, 86.79824721428656, 82.48535802287441, 87.05804148027974, 78.33576494647612, 83.19536978198637, 78.08299956783172, 79.53061303784771, 82.32586660692769, 97.2337365919544, 92.73487214119204, 108.19439995673396, 38.50000481451712, 0.9874528910844558, 1.2094980213911304, 2.9450866387736414, 0.5214204627179331, 0.12287736209409854, 0.14377650113836413, 0.03755633050816194, 0.1791056110373428, 23.05435826701503, 33.454777732972175, 72.71678924560547, 103.55331036352344, 97.56441593170167, 57.849354974685184, 32.15931496312542, 27.67268438493052, 44.946204462359034, 76.09804491842948, 77.20613018158944, 80.40539572315832, 91.24382234388783, 38.23227951603551, 0.6394163891673088, 0.020613024356744943, 0.14462656762090423, 0.04562144753553214, 0.07164461928750239, 0.0030528089067252775, 0.11939198379555058, 0.06843491772850675, 0.03466193541704166, 0.0568439576384281, 0.0381731883352322, 0.040983482294024966, 0.05779182673582147, 0.09657646048693888, 0.08664829040607137, 0.026730705660978155, 0.06047049529790398, 0.08001750064713341, 0.06287788063467992, 0.021181455850901625, 0.02688354403231173, 0.0398472819717661, 0.016258410140571576, 0.07426625643406184, 0.01927421676115163, 0.18538066786864113, 0.2655672594424217, 0.16071301975077198, 0.1223584600994664, 0.23255199554466435, 0.14412792099099006, 0.1578197661306589, 0.1934376145682989, 0.2445444125201433, 0.2618033162528469, 0.2186590216813549, 0.11736520626131566, 0.14262018334721366, 0.15694087942040738, 0.1207972801620922, 0.25776088478103765, 0.216128081684151, 0.24354031639954737, 0.22323321010316574, 0.5584621621716408, 13.323701158646616, 160.4741579486478, 128.45748978276407, 135.21064235318093, 106.82750102012389, 78.08307801523517, 74.08172699712938, 42.62381615177278, 44.3771352306489, 101.75603328212615, 142.56466281029486, 131.80888052909606, 134.90391300570582, 60.38129983409759, 10.369417052115164, 0.7238396461452208, 0.3070347101217316, 0.39529594502622084, 0.3757797019375909, 4.474672252132047, 3.79058490837774, 3.486928983080772, 16.374159820618168, 4.429212472131176, 21.23646716917715, 139.3550814351728, 116.35559712686847, 123.78148325027959, 111.58255900106123, 117.26486529073408, 111.70589400875954, 109.19822862071376, 101.23228703775715, 105.33099912828015, 103.50387280987155, 99.0080128946612, 104.3129950184976, 110.73069864703764, 110.37302555576449, 112.91332506364392, 104.87172096006333, 105.13553173311296, 96.78551950762349, 90.16868499017532, 79.25103433670537, 78.7996244430542, 74.50985370143768, 77.11401724046277, 85.89400752898186, 88.06420787688225, 85.99034094041394, 85.03875824712938, 78.55662576613888, 83.57259196619835, 90.91882259615006, 93.20609000421341, 100.30930626776912, 99.88763578476446, 99.19980110660677, 105.24811944653912, 100.42929157134026, 103.10562672153597, 97.14630696081348, 107.97295078154534, 104.168392919725, 97.98259550525297, 95.42650453505978, 101.93062582323628, 101.13952298318186, 88.88736432598483, 96.59388034574448, 90.13049679417765, 97.58627922304215, 103.30936247302641, 100.53654486133208, 100.09562338552168, 82.83346837566745, 79.81383169850996, 78.51948092060705, 84.60546970367432, 87.62746764767556, 95.11666082566785, 102.61881351470949, 98.9191084523355, 102.84343980973767, 102.55887185373615, 95.80670772060272, 95.86457052538472, 85.82224384430917, 79.71935749053955, 75.49893425356957, 82.96172203556185, 76.39901622649163, 91.7636069943828, 92.38597731436454, 92.9027182056058, 93.29085242363715, 92.66106882402974, 88.15875268751576, 91.77164000849571, 83.85571648997646, 86.98671710106635, 82.33947723142563, 86.4020093794792, 88.14084314530896, 101.0968868194088, 97.6545363087808, 111.56663417816164, 33.99801031235726, 3.058351451350797, 4.5752119152776665, 2.4473623787203143, 0.8868518796178603, 0.2619719168832225, 0.5116554463822995, 0.10406110886364214, 0.7187796660488652, 38.8324688326928, 42.82459835852347, 88.3832456219581, 112.72506698485344, 120.74313686740015, 120.31220959078883, 110.25795105964907, 33.58116826703472, 37.872833513444476, 77.16273307800293, 88.13157850696196, 93.65311468801191, 106.49172259915261, 48.558825062167266, 0.8479064210287987, 0.18272347658151583, 0.21342348487627125, 0.17515627457009209, 0.1322351567327015, 0.1578173146493012, 0.1697787357073638, 0.24478093450588567, 0.13203742943944471, 0.26121673805098383, 0.25596085395063123, 0.10094061824342898, 0.15841573657047364, 0.13264395657085604, 0.22435873115976013, 0.09569000482799546, 0.14393483619055442, 0.17389331733988178, 0.12710767662933758, 0.09310946829857365, 0.2640940110769964, 0.11597689406405534, 0.12073309731579597, 0.2607691588421022, 0.1506473445483754], [0.09265654945685979, 0.04089126062970008, 0.0322151884827162, 0.02808131867148463, 0.09629552072334675, 0.061139106194699006, 0.012099007576433642, 0.09115498648175309, 0.07494232136636012, 0.08880107408209194, 0.06321514318246516, 0.1144972488644623, 0.05562909540810412, 0.012384768905899218, 0.057790321373050256, 0.022927552176218842, 0.06280178895160075, 0.07267404993575427, 0.06202455061758238, 0.14813050056897825, 61.98777321846255, 108.14258544675766, 105.89662059660881, 82.4990314052951, 63.261617845104595, 40.94923080936555, 25.418213875063007, 45.22692065085135, 51.685401239702784, 63.20299410050916, 107.21854563682311, 116.88065344287504, 46.94684859245054, 2.556807783342177, 0.6566121825768102, 0.16048887774588602, 0.12577267649072793, 0.20066928539064624, 0.7977623504496391, 0.1978286926544482, 1.155613357982328, 0.9681990177881334, 5.401865647685144, 9.87804408996336, 121.4768397423529, 95.4057316626272, 106.29643563301333, 104.491941390499, 108.41733963258805, 103.77405351208103, 109.52395792930358, 105.06673336029054, 109.07845512513192, 99.63629814886279, 101.7952177601476, 101.47880800308721, 99.36257162401753, 97.47458581001528, 101.63190595565304, 97.61950169840168, 95.2625180828956, 91.70529703940116, 89.54356116633262, 78.7180705224314, 72.33537797004946, 69.8546749545682, 70.66979054481753, 70.45912004286244, 73.11246225910803, 74.18000590416693, 73.18114296082528, 67.82342849239227, 69.96970238224154, 70.33423962131624, 76.96128799069312, 78.9665291386266, 78.1533904229441, 80.68609622216995, 80.16257747527092, 78.8503485341226, 82.31071056858187, 84.91073208470499, 87.2496335737167, 86.01075295479068, 85.84187138465144, 81.65173669015208, 82.9505354358304, 83.7182217259561, 88.02294454266949, 73.42964864546254, 92.7836899603567, 79.65239478695779, 86.49830356720956, 92.41096281236219, 92.83845409270256, 91.04131037189116, 79.24243650128766, 69.22335378585323, 69.48046515064856, 69.6179912936303, 73.9146810962308, 81.82406994604295, 88.463026631263, 91.0612673913279, 93.15080811900478, 91.376555350519, 89.76275105630198, 82.86960909443518, 81.39078140258789, 71.03938764141452, 68.88595150363061, 69.6782075205157, 74.59442784709316, 72.60813959183233, 83.75302099412488, 81.9697859979445, 81.31886866784866, 80.44401537987494, 82.19888379496913, 76.54052749756845, 81.92142317371984, 74.90365182199787, 77.02481469800396, 74.66007263429704, 76.37907489653557, 81.89999918783866, 92.67635037822109, 88.43278515723445, 110.03647050549908, 13.9444838993011, 1.6251317315524625, 7.593065875191843, 0.06693058151511416, 0.20921243745232784, 0.2105547613914936, 0.16295761140363832, 0.27446641256251647, 1.7731942188355232, 19.214410820314964, 18.98338321716555, 59.62559638484832, 80.39560548720821, 74.51116377307524, 87.95296945879537, 64.89418675822597, 26.46891486260199, 18.6132977854821, 44.769776252008256, 72.40659252289804, 74.29469600800546, 72.4104364456669, 7.7077358768832305, 0.46131130428083483, 0.08797769810283378, 0.08721264439725107, 0.016614252235740423, 0.032780599675231406, 0.09573328113483806, 0.0727887409588983, 0.15627131857458623, 0.07972664004492183, 0.1426545347297384, 0.024002005811780695, 0.09805789833227474, 0.02552286654170002, 0.04828301318470509, 0.03968876688891361, 0.05026478305338852, 0.06018039695317707, 0.0691062329156745, 0.03172119775216185, 0.07222536756026168, 0.03672800560091292, 0.037764285075207876, 0.06143198926903068, 0.04171044227757281, 0.05346662838072066, 0.06751354378197463, 0.05793449912039984, 0.03830167660189252, 0.05395607046422459, 0.07604709676196499, 0.04224671148544839, 0.03109613320820274, 0.003977926150377419, 0.023021851854038336, 0.052079561076337294, 0.04977497707812056, 0.002948948212208287, 0.052151964046061046, 0.04641655870082398, 0.031812841020103906, 0.06756244317418145, 0.02888412518997587, 0.040499609669730555, 0.052248743933535395, 79.65952565593105, 126.07911356033819, 118.91711665738015, 99.46312550575503, 73.66670100919663, 58.53262793633246, 35.44372143283967, 18.006840521289458, 37.98115368812315, 63.28233188198459, 112.92768093847461, 128.1259161426175, 58.14452509726248, 3.541831133827087, 1.2103580010514106, 0.11458667430786357, 0.44671876956858947, 0.18873662327326116, 1.2014222289285352, 0.5909093565517857, 2.017558983737423, 3.680790903106813, 2.4232101392361427, 15.835721358176201, 133.4172405735139, 98.97843822356194, 114.94833700118528, 108.84831397764145, 115.03129513032975, 106.10527500029534, 113.53646416817944, 113.01019976215979, 114.03862953186037, 105.06256780316754, 106.24851211424797, 105.16318444282778, 103.45864788178476, 99.35660962135562, 105.66243156310051, 101.51621172505041, 102.621716068637, 96.92463028815486, 93.55331390134751, 83.61727560720136, 76.91422739336568, 72.5862527662708, 73.33323678662701, 73.43538315065446, 77.4356202156313, 78.73985536636846, 77.85558838998118, 69.74265990718719, 74.26664321653305, 74.70451308834937, 81.28652480340774, 83.41921944772044, 84.02308402522918, 83.74297972648375, 83.88348687079646, 81.8619208182058, 85.17796316454488, 89.9124522362986, 89.68690810665008, 87.0132480129119, 88.99850860718759, 84.18619186647477, 85.8416203529604, 87.30453891138878, 93.39816062681138, 77.5185626552951, 97.55586516472601, 82.29719408096807, 88.17670145342427, 96.95192998455417, 95.24681291272564, 95.46194707193683, 83.96177737943589, 71.5050906519736, 73.43221387555523, 74.17491466768327, 77.70820925312658, 83.1760246522965, 92.33030319213869, 95.51449898750552, 97.47229514583465, 94.48650852326425, 93.10208443672427, 85.69226434153896, 83.74416428227579, 74.97223054209064, 74.31706920746835, 73.35844978209465, 76.96472398696407, 73.44972333600445, 86.04649359180083, 85.29787786545293, 85.69911279985982, 82.39179380478399, 85.6102083575341, 80.4044621990573, 84.95173654248639, 77.25028822498938, 80.34874885312973, 77.25123743857108, 78.6829496199085, 84.76041117022115, 98.23569820773218, 91.17775394070534, 114.58021471577307, 24.02250905190745, 0.9206166226536998, 2.7915731601176725, 0.12674897894143097, 0.4466296888647541, 0.403424903990761, 0.10847432689080316, 0.30481317771538613, 0.6220621074880324, 21.801874868331417, 22.330477006973762, 63.42145835199664, 85.51771102413055, 86.10921229085615, 73.27070636133995, 45.366517805284076, 35.04353769363896, 41.29415227520851, 54.51504222808346, 83.18787805495724, 81.54676621960056, 92.63096071058705, 13.920698646576176, 0.5333510870414396, 0.10069880259012985, 0.03537884049658333, 0.09619222142763677, 0.03837099989816066, 0.09497404203660066, 0.04493892065159256, 0.09025733061735669, 0.027690548712628025, 0.0590383054147805, 0.09144104371267943, 0.03171694787940191, 0.034156210134707155, 0.08229930119048204, 0.06199481108436181, 0.08161959734054343, 0.010079367108823312, 0.09992701497169272, 0.06802081656191619, 0.049251604960450245, 0.014494212115213517, 0.1497078296397963, 0.03486945331397076, 0.003272129585140295, 0.1493083607525595, 0.16031094616459263, 0.11805157507619551, 0.11343107663936193, 0.2188377806376065, 0.19996238541939568, 0.2217226379340695, 0.18965047423637685, 0.09423374063185147, 0.15684061383287753, 0.1693518561941962, 0.18292052971739925, 0.15739903064264407, 0.07657562082092609, 0.25193578203118616, 0.07237031905641479, 0.14681316641790254, 0.11949413395937412, 0.1530983968968353, 0.43922428462293844, 107.49879114089474, 141.33832593117992, 137.91834862001483, 110.95758422728508, 93.60552849308138, 62.07342209354524, 36.245108727485906, 63.567821594976614, 74.73065176317769, 96.6618001076483, 130.87569375191967, 138.73829657031644, 74.70019063641949, 5.720750910620536, 2.6549427884240306, 0.6015926671604956, 0.6269667249533438, 0.36933699442494305, 3.3526331570840653, 0.887020418961202, 5.282113725139249, 8.382920911235194, 9.687561046692634, 13.093776722108165, 144.5170617872669, 103.19216989701795, 122.93900520570817, 116.64891981309461, 122.41775358876875, 113.29778009845366, 119.43303385088522, 116.28254690477925, 120.93738832781393, 109.4952932480843, 109.48254554502427, 106.38495568306216, 106.07841460935532, 105.0852861712056, 111.01592556122812, 105.07155787560248, 106.04248569857691, 101.18889777891098, 100.65872669219972, 87.53678244929161, 79.92274807345483, 76.45915400597357, 78.57716329636114, 80.49131916415307, 83.71706070438509, 82.68005663348784, 82.77036528433524, 73.80578825550695, 77.7546501159668, 79.38757204240369, 84.70589022482596, 87.36231542402699, 87.92992161166283, 90.17885177366196, 89.78792482806791, 86.23923101732808, 89.48802040469262, 95.2226040440221, 94.19338980028706, 93.2093926398985, 94.07297303599697, 87.7539405515117, 92.06055395064816, 92.98369946018343, 97.66888433887114, 84.26958930107855, 102.249796928898, 87.88593615255049, 95.20487493084323, 101.14617532299411, 98.42696082207465, 99.07654454631191, 86.32018873768469, 74.96369546459567, 76.40787293834072, 78.72029842868929, 82.01221035372826, 88.06223884705575, 101.61716568854548, 99.79363226121473, 103.88937119514712, 98.0201796562441, 99.23628699394965, 89.5672836611348, 91.13006576415032, 77.63063261585852, 77.58270909709316, 76.56992958438012, 81.89184850262058, 80.15511712720318, 91.67860138800837, 90.29697002903109, 91.70164139040055, 86.85068145875009, 91.08287180623701, 83.20207703498103, 90.73361612135365, 81.39704935012325, 87.04832969173309, 80.8908204109438, 83.62535568975633, 88.08076027900943, 105.56903992929767, 95.06974143366661, 121.33560303718814, 18.31495838780557, 3.334682429990461, 16.547820798812374, 0.31669939958280136, 1.0921422992983172, 0.4778011936333872, 0.3850694373250008, 0.6040209820193629, 3.9960023760795598, 39.27881886882167, 36.7581037552126, 78.26278532705, 92.79579439470845, 99.62242864793348, 129.65913141927413, 87.44914101016137, 37.16353954807405, 30.937243661572857, 64.12032273507887, 96.69317906902683, 94.2279851052069, 109.92371020778533, 17.022868856307, 0.7268286760776275, 0.3766895385999834, 0.28170612730806877, 0.24763991335226646, 0.10431637702089164, 0.28423859948112123, 0.1317543293079061, 0.28784154163252923, 0.26197265232762984, 0.14641896821558475, 0.15366957673142034, 0.18479505493756265, 0.18282388006487202, 0.20021358564976724, 0.14495855948377043, 0.23168103018354988, 0.10487468657834877, 0.11515089806409613, 0.1386482166426797, 0.12477021979828998, 0.19229859504247868, 0.312348295964541, 0.12291634064768592, 0.1512877480877984], [0.043812913129166256, 0.057396310862273946, 0.10065626938857379, 0.05320512809820714, 0.04623744734412721, 0.05022047252784814, 0.009975984501051567, 0.015696610095009448, 0.051643649386542465, 0.09138319641351701, 0.01093088820080964, 0.028832262952721892, 0.09249989979810293, 0.04102839419858591, 0.1237125511491491, 0.026126168442950137, 0.14422463193055124, 0.09842428754294112, 0.6870091418104788, 19.364617986063806, 120.88288307189943, 103.20214056199598, 93.77288033885341, 70.11916037528746, 37.0487827639426, 32.16221163349767, 75.78300799092939, 134.0284086042835, 88.40647389811855, 101.42977837593325, 112.31994105923562, 58.897435818949056, 7.603617050955373, 1.1968668862696619, 0.3899390292504142, 0.1277641680151705, 0.3717842469772985, 0.05705514892695412, 0.05363226042038972, 0.31452438403521815, 1.2192496465098475, 2.2213804145013136, 2.9276977912072213, 104.19617899002569, 101.35150355677452, 104.67839517901021, 99.11424636840822, 105.38117408752443, 101.34842057381907, 102.43639192273541, 100.01971767794703, 98.93930865872292, 96.8931571898922, 100.22768174448322, 107.0106835519114, 99.4516251164098, 98.87139674155944, 95.7488606053014, 90.7671602310673, 97.05567667561193, 94.3823068372665, 92.19323988883727, 84.48408803632184, 75.95321532218688, 69.60952681879844, 68.25039417512956, 67.50448488420056, 71.83061599731445, 73.21832703005883, 73.31588422098469, 68.67875622164819, 68.83837315344041, 69.37811482337214, 68.76021600538685, 72.21313338125907, 69.16499676242952, 68.46672073487314, 66.96091498098066, 66.86072980203937, 67.15799839265885, 65.32612600634175, 67.10219090984714, 65.04237782570624, 66.02098172710788, 70.94452119642689, 70.52619257280904, 77.25257104442966, 89.88172438836868, 87.66969588495071, 69.04653333848523, 86.42033469292426, 80.16332272560366, 82.56629220900997, 88.46729417001048, 90.85798663477745, 91.45762289724043, 80.37506795698597, 67.7099072548651, 69.48979254691832, 70.01190708529565, 67.68276445327267, 71.88942801567816, 72.7583977483934, 76.60485436839443, 83.34269400565856, 86.55673903803672, 87.3868694613057, 82.32594505433114, 82.16110352546939, 75.05846777269917, 68.15670444119361, 71.7120505917457, 69.17915651875158, 72.11840029685729, 72.08054157995409, 81.30034723589498, 79.10029765098326, 80.9744296535369, 78.11106804878482, 83.27381718543269, 75.37736431244882, 78.2922266375634, 72.60551944855722, 74.70526618342247, 69.5852630369125, 75.37238290232997, 88.30289979134837, 90.85806508218089, 91.91847785826653, 94.88285618443643, 7.068649886115906, 0.42894234279951743, 0.4086702773647924, 0.2984958328306675, 0.051548114391945066, 0.0778778630398935, 0.06598244811738692, 0.22488221436017947, 1.9426928268324946, 2.4255687094503835, 21.493339269391953, 68.32881804435485, 90.0076638498614, 66.44398581597113, 70.83541654771375, 44.09033544601933, 22.70510454331675, 31.458010865796, 55.513901249054946, 68.9153535904423, 79.86081384843396, 59.315878191301906, 2.9884906065079475, 0.07859618538209508, 0.1488259398648816, 0.051710299035954865, 0.10849868848679528, 0.023817939781433633, 0.0687593483035603, 0.0671254896048096, 0.034421962205200426, 0.014701346010570566, 0.07571130510299437, 0.0870319395776718, 0.039049738477314674, 0.037815095856785774, 0.04587052570235345, 0.03774275417409597, 0.01789452688347909, 0.08406380086296028, 0.014069125247788767, 0.04271184176867528, 0.06224170590059892, 0.014919850565943749, 0.1122741919431475, 0.010047203864932302, 0.06568109211061271, 0.05574071441867179, 0.015031147819583215, 0.07169068415438937, 0.021739430244891875, 0.061423715519448446, 0.022784929587355545, 0.01836945734647734, 0.010717755837005474, 0.04494532514663954, 0.038269589009184035, 0.07653180825253648, 0.009090664567455891, 0.037684029704260255, 0.08752222818833205, 0.05051295723645918, 0.1528030700020252, 0.1672278927458871, 0.6932329626814012, 24.951579301587998, 142.20562473420176, 114.96431673726728, 111.31511611323204, 85.26274127344932, 66.34816231266146, 47.40711912032097, 29.719802718008722, 75.33900353216356, 76.92528847725161, 111.38404000189998, 123.07265604695966, 71.65345822611164, 8.837959977888293, 0.9394558278783676, 0.006807609555131246, 0.06709049470842847, 0.3088578461639343, 0.7604963404517021, 0.22742846079411047, 1.8364448893454768, 2.344394523289896, 1.5854198173169167, 5.552853365098277, 117.3175270326676, 105.29143810272218, 111.70507031102335, 101.1160985885128, 108.89291917124103, 106.10974650229178, 104.54901972124654, 102.82983702998008, 102.50741820181571, 99.11677237479918, 104.82479372332173, 110.07358397206953, 103.34585620510964, 102.46262473444786, 97.4657840113486, 93.67852380198818, 98.90488593809067, 99.87416636559271, 97.71393668267035, 90.20374313477548, 79.77187018240653, 72.97801125434138, 73.60629650854295, 73.15455713579732, 73.66880339960899, 77.09706475657802, 79.90716057439005, 73.87150364537393, 72.16654346835229, 73.64239015886861, 72.75037257902085, 74.45014738267469, 72.16595511282645, 72.09699200045678, 70.63483438184186, 70.94549394422963, 69.55971271761003, 69.59002479430168, 68.63946976200228, 66.88227145902573, 68.1887972739435, 73.46361637115479, 73.58026766007947, 79.01407610985541, 92.25276577857234, 91.99847852030109, 71.95278213870141, 89.65450148428641, 83.21091805734943, 84.74926379419144, 95.15563349569999, 93.22634512378325, 94.43701605642997, 84.55836203790481, 73.07565473741101, 72.60007519875803, 71.9674910268476, 71.71187016271776, 75.19225981927688, 76.1465254137593, 78.90533231919812, 84.89607810974121, 89.9803327745007, 90.0824712937878, 86.9542084970782, 87.64499279760545, 80.14087892347767, 70.5439373754686, 73.6078497671312, 72.48301598333543, 76.27729723530432, 72.79197323706843, 85.29162560739826, 83.61714224661551, 85.27095471659015, 80.92511761573054, 86.59848874615085, 78.48214780130695, 82.78314436635664, 78.14440035050916, 77.82960660995977, 73.08983018321376, 78.4569897190217, 91.28275579021823, 96.66300819766138, 91.73189070916946, 106.19232808389972, 12.805737468504137, 1.467951081933514, 0.6874135749474649, 0.633141883919316, 0.5172187462449074, 0.2043680191761063, 0.10344993923940968, 0.6093335259825953, 1.9185237947010227, 1.2293971858678328, 23.95165535711473, 72.61257971486738, 95.18472963763823, 76.17158151442005, 55.32197967652352, 43.34438693138861, 29.572837391207297, 41.626071083930235, 66.4961298050419, 78.84369619431035, 90.11072020376884, 76.7676954884683, 4.096716094401575, 0.10426594545283627, 0.17809147916493878, 0.06207727278853136, 0.0869297128050558, 0.043093085424193454, 0.021293222333394715, 0.0889272794067379, 0.04930977018610124, 0.06483201388149493, 0.04460954114854817, 0.01098782672817188, 0.015569050709957318, 0.07952643062679038, 0.026561666445265857, 0.05392793971564501, 0.05112088630877195, 0.07266416740153106, 0.0335857427618917, 0.05079321518179871, 0.05771940078345999, 0.00972248983734678, 0.027795960495789206, 0.025469759411569086, 0.09420533409161914, 0.16686967003249353, 0.1849238343176342, 0.15591292732184933, 0.17693577424412776, 0.17829292964550758, 0.17527302636975245, 0.15968837715204687, 0.11803738712783783, 0.145780939548727, 0.10578375715281695, 0.25045988300154287, 0.34685160904642076, 0.12089317138757437, 0.2560028662123988, 0.14249878905473218, 0.27262087610940783, 0.3814147076299114, 0.7986031472682954, 35.38743934323711, 165.68563861231652, 130.96842642753356, 126.92109738626789, 99.80296750222483, 62.91582169071321, 47.49218356224799, 109.76734884323614, 181.91422554754445, 129.78283512976864, 125.5912648477862, 129.5741650366014, 86.18350198191982, 12.916806244081068, 2.096064364717853, 0.5577079026449112, 0.29604422889890214, 0.6736338595228811, 1.183561838922962, 0.3007749750489189, 2.855246466013693, 5.421514761063361, 6.1656928158575495, 4.5835685249297855, 123.34384087593325, 107.59325750412481, 116.21231294447377, 107.37269478459513, 114.42725012379309, 112.73291172519808, 111.3816708903159, 108.93828530465404, 107.44101462825653, 103.56101389854186, 109.25179250778692, 115.10522396333756, 110.37145660769556, 108.29463220411732, 102.78909144863006, 99.17902823417418, 103.780972573065, 104.8098808719266, 99.86665110434257, 96.58048937397619, 85.60060639535227, 76.95588296459567, 77.62682791679137, 77.18574170143374, 79.8941461501583, 82.59344285534274, 82.78958489817958, 77.66827168003206, 75.13126696309736, 76.41289357216128, 74.9956000235773, 78.90229640468475, 75.76525534352949, 78.21115124610164, 75.5286422852547, 75.5544279467675, 75.48835954358502, 74.22877665488951, 74.36559677124023, 73.20463011341711, 74.15299646316036, 79.2587378717238, 79.58115669988817, 85.24474543909874, 99.6351920404742, 94.71467279618787, 77.0827716396701, 94.53874664921915, 89.12833905989125, 91.30539571085285, 97.48327778231715, 95.87754572591474, 99.33303617662, 87.78526459970783, 75.9691793687882, 75.79749722634593, 76.53863691514539, 76.56685444616502, 79.9993048944781, 78.4530673488494, 83.62192753822573, 92.10521405743015, 94.88316212930988, 95.83549007292717, 91.53944353903495, 91.45902710576212, 84.16807836101901, 74.75927722069525, 79.12556555963333, 75.65293435127505, 79.34725792177262, 77.1985835413779, 90.5620438052762, 89.26568477384507, 90.80450119510775, 87.36491203308107, 92.32558065845122, 82.67483988115865, 86.83810633997764, 83.13537320783063, 83.24654886799475, 77.73780745844688, 82.43770907002111, 96.09853990616338, 102.1512669901694, 97.19259877358714, 107.90689806784354, 8.696139820160406, 4.6109471590288225, 4.554773915198542, 0.869590018785769, 1.489773310961262, 0.26260583931880616, 0.23637478960858238, 1.1156638952032214, 4.174153487528525, 8.655237344003494, 37.10468830600862, 90.7164518294796, 106.44346960129278, 84.48014997666883, 97.10503578186037, 60.59089560662547, 34.01821051874469, 47.188607800391416, 76.24793437219436, 94.29178637842979, 102.37759559385239, 91.52758229163386, 5.450789861140713, 0.3142485617389602, 0.2882760054161472, 0.15454307018268496, 0.2218116267073539, 0.18450043284364287, 0.1581269367447784, 0.15686955663465685, 0.11828586008519897, 0.13989419736448797, 0.1430999229271566, 0.1911613221971258, 0.11508888324662564, 0.15637978130290586, 0.19765137394349422, 0.09180447582395808, 0.17333137652566358, 0.17662118789890122, 0.14701447900264494, 0.2393688757212893, 0.17357853181179494, 0.20474369337241496, 0.1602568756788969, 0.09980431066886072], [0.07679033994434342, 0.11121994004614892, 0.04461019615372343, 0.052720022072354635, 0.02013340926608972, 0.05997545694211318, 0.019177268334333936, 0.037364494431042866, 0.028635585199921366, 0.028512268026749936, 0.03286673094055826, 0.061570130243536934, 0.049701907611902685, 0.07761278895721321, 0.02883996213636091, 0.0465311233194605, 0.03895103953959, 0.07706477562145841, 0.1383770521610014, 56.11944460099744, 108.18398214155629, 95.79764704550468, 64.46178074805968, 66.91455256554389, 30.34620131215742, 43.747226115195986, 130.44711205267137, 68.70680116838025, 94.93728299294749, 123.8530743506647, 71.7278185198384, 14.607372303162853, 0.17232761748375433, 0.22752920135615334, 0.15868120135799532, 0.17436839910524507, 0.06728546408515784, 0.22093459392987916, 0.20726127279621942, 1.7198539068621976, 1.3172032419712314, 0.2983446377179315, 71.11562282808366, 116.76558679149998, 100.0253737357355, 100.01341835145028, 84.62365381179318, 92.57872258463215, 92.79893229084631, 96.40993687414355, 89.91017726159866, 100.17130159562635, 94.78281221082135, 93.32489075199251, 93.90415422378048, 97.38287295064619, 96.66345534786102, 96.5817916008734, 90.56808425534157, 91.79487612939651, 94.8618793487549, 92.41639921742102, 84.93609413023918, 72.78998067302089, 68.69235115666544, 66.68394857837309, 70.14857030683949, 73.75123593115038, 71.07394372263263, 70.02816923203008, 64.89349249870547, 66.0059747388286, 69.04302673955118, 69.88391230183264, 66.96876756606564, 64.82768297195435, 66.02102879554995, 68.14384691176876, 72.28993338923301, 71.80992941702567, 75.1883609833256, 73.4167597370763, 70.0697934242987, 70.73753772243377, 72.40120318628126, 73.41377873574534, 79.26240921020508, 83.77515100663709, 87.58490993130593, 61.603784945703325, 89.78346117081182, 78.18975863918182, 76.00028376425468, 89.98947189700219, 90.77691908805602, 88.77848717474168, 81.95442599634971, 72.18931674957275, 67.445312007781, 66.38424027350642, 64.10849678900935, 66.70814175759593, 63.809851446459376, 66.06938377503427, 69.35855788569297, 77.40128378714286, 82.62188003909203, 80.8109531094951, 80.41110669412922, 73.25588764682894, 68.53040433699086, 65.87844279504591, 66.43661176004719, 70.15665038939446, 66.57442815842168, 73.3911309703704, 77.13199738533267, 80.72594750312068, 77.04299880612281, 79.25599221260318, 78.80838701801916, 76.72088592283188, 75.43681959952079, 72.27685620707851, 68.39349792849633, 69.51473882121425, 74.43057475551483, 90.3499298710977, 89.12462065296789, 98.57477141964821, 65.78531003767445, 0.8463054198411204, 1.7859337094330021, 0.3038335657648502, 0.1282236981956709, 0.01329134969461349, 0.2347183236551862, 0.12498924433584176, 0.12511388684112218, 0.17517925720782052, 0.06774700141601986, 19.163276841563565, 37.908707511040475, 58.795458116839015, 100.32429756656771, 71.23931869383782, 49.80580145312894, 31.082755750225438, 37.458403725777906, 58.33539547458772, 72.89207212386593, 75.14615628027147, 30.257965633946082, 0.6908338817377245, 0.09787066644358058, 0.03184998862355227, 0.07947470437014297, 0.0342971051953012, 0.17704204596098394, 0.03901726784064405, 0.0803880114108324, 0.11256638553834732, 0.0795044209207258, 0.047395837403112845, 0.04682810879462669, 0.08365584372152245, 0.019026603737485506, 0.05905566113670507, 0.03108886303380132, 0.02157620946696449, 0.06209105854072879, 0.012890500891503068, 0.03387644248563917, 0.013456356415014355, 0.01807919812328633, 0.021649236798346527, 0.032556266148364356, 0.0635208888730455, 0.07798075630900361, 0.04861510846944106, 0.06214058995547314, 0.10719855300961964, 0.0359964337680609, 0.006697414031687885, 0.06389829442806302, 0.030865561810412237, 0.057377848143298785, 0.0885835434159925, 0.01835864401542612, 0.03154079936775229, 0.07757992378526157, 0.05203211725118661, 0.11879493317176258, 0.04461958073079587, 0.08180376487754046, 69.134551325152, 127.99842342253655, 107.57737190492692, 87.6468441563268, 82.5807971339072, 46.03080649529734, 40.66441574404317, 111.9060133349511, 83.1896980347172, 96.72763316862046, 127.72932529449464, 85.04149606150966, 17.11002980509112, 0.2052302358131255, 0.10402200007510763, 0.258744265884161, 0.02852907982624827, 0.0750050486456002, 0.2550169263756083, 0.719860585466508, 1.3744273132854894, 0.7556373205396437, 0.4988736677314005, 81.59028883903258, 117.91988542003017, 107.53709700799759, 104.07724488166072, 91.79272667054208, 93.60437531625071, 95.4927376777895, 98.04926010870166, 93.70981647122292, 102.29260567695864, 100.57288169860841, 97.02497236190304, 96.561614928707, 103.57641312383838, 101.62573214500182, 102.06717137367495, 95.5013119789862, 93.27079342257593, 99.96629499620008, 96.67872905731203, 87.99769232350012, 77.10528604445919, 72.10744903933617, 70.17832540696668, 74.95936516792544, 75.57374169749599, 75.45222666955765, 71.21804375802317, 69.98988689914827, 71.08857416337537, 73.37475899727114, 73.4288877056491, 72.23749914476949, 68.39733400652486, 70.51837136668544, 73.53887881002119, 75.166427089322, 76.22243896607431, 80.34715637083977, 79.60931931772541, 75.34760136758128, 74.83414742254442, 76.78349479552239, 77.04041788654943, 82.79395441855155, 87.65647749747001, 91.13500795056744, 63.58334241374847, 93.80925639983147, 83.13447106269099, 77.497664267017, 94.25080545486944, 93.27672404627647, 93.98158965572235, 84.45070082141508, 75.3648990200412, 69.82422167255034, 68.95469496327063, 67.08109640306043, 70.49780245750182, 68.1443803541122, 69.52205796395579, 72.22599875542426, 78.19049604477422, 85.8131988586918, 85.80829589597641, 83.69451492063462, 77.28926873976185, 73.61824404808783, 70.31885608550041, 68.73397534893405, 73.48015308380127, 67.66530990600586, 76.88231498964372, 78.7224635770244, 83.93432078822967, 81.72306891410582, 83.28847116039645, 82.14850487247591, 81.61515666592507, 77.35407413974886, 76.43756528054514, 72.93506130095452, 71.37879817716538, 78.71004535305885, 93.10738748119724, 94.41673740263909, 96.42616764191659, 80.36605435032999, 5.325780491675101, 1.2725448512261914, 0.08011121618291063, 0.32460757200756385, 0.2829543603283744, 0.34846024046982493, 0.022554858061935634, 0.27100660627888096, 0.2435604185466805, 0.3658538684248925, 19.616443957051924, 41.43121557850992, 61.3803667406882, 90.42134054245489, 46.320202888980994, 56.99677290454988, 42.92574844052715, 44.65253268518756, 67.47151344053208, 82.75335004252773, 89.32217474906676, 48.06937994495515, 0.5418525792417989, 0.04339688908188574, 0.03678546602567358, 0.05806328999179025, 0.02691983936294433, 0.10503022540961543, 0.08197762087107667, 0.03635071112864441, 0.06344285515707827, 0.06006314719636595, 0.05330745829269291, 0.03974268415702447, 0.004486998997538561, 0.022476818600308993, 0.044546982408651424, 0.027563431743352164, 0.08030429332246704, 0.027656710609012557, 0.0434771865876692, 0.0833199218276047, 0.0128750613469991, 0.011571578065594359, 0.007900622149463743, 0.14391807418677116, 0.17865634643502776, 0.23488458005651353, 0.1840883388274139, 0.15313680854535874, 0.16472860750171447, 0.13396853791369548, 0.13461153083030256, 0.11161203916755416, 0.16126216689665474, 0.1362631857515343, 0.21036118629478642, 0.13517391597551687, 0.13941860998109465, 0.15630326444102874, 0.14302095458392175, 0.18750781824271526, 0.15320707412977375, 0.36046398022482473, 89.86776859529557, 144.09074721797822, 125.12484796585576, 97.13403778691446, 92.2184685737856, 44.63925938452444, 65.94587618304838, 171.48635341275124, 89.25046597757648, 114.2789766865392, 134.29644769237888, 102.60851337063698, 21.888953447341922, 0.5041248020866226, 0.7515913957068998, 0.6371775125303577, 0.5028348019526852, 0.6752741456993165, 1.4137056830429262, 1.868109325728109, 4.575411465860182, 6.055444796239176, 0.7550138475433473, 84.49612971275084, 121.55320044486754, 114.70182388059555, 108.15312877778085, 94.88849655274423, 102.53630253576465, 103.50490831559705, 105.52172045553885, 98.6451622747606, 108.6013380173714, 105.95984920378655, 101.56517074954127, 102.75499036235195, 109.52329897111463, 107.36619149484943, 106.15683063384026, 97.65672499133696, 98.09439089990433, 103.91533728568785, 101.90896649514477, 92.98022424021076, 80.04446706464215, 74.77764960258239, 73.98999060353925, 77.77729788134175, 80.17039868139452, 79.57726570867723, 74.88600900096279, 72.93630861466931, 74.3666950348885, 76.88582943331811, 76.42619825178578, 76.42899097934847, 72.99020982557728, 75.12419100730651, 76.89420761600618, 80.75377279712309, 78.80865373919087, 84.1977785479638, 81.8666119729319, 77.08160277335875, 78.06104998434745, 81.55023359483289, 82.11157183493339, 86.80897881907802, 93.28435697863179, 94.1222615395823, 69.67423023716097, 97.69015927468577, 85.9449512727799, 82.29417385593538, 99.08612297427271, 96.60174862031015, 99.01103311969389, 88.74073043946298, 79.45569576755648, 74.45719195950416, 71.56169045356013, 71.56724452972412, 75.36309472976193, 70.57630477413055, 72.20706155223232, 77.75271246510168, 83.86414958584695, 90.4110796220841, 91.37080515584638, 90.23061921519619, 82.35821831610896, 77.3795695458689, 75.29792847171908, 71.66225218003797, 76.05646779460292, 73.96139652498307, 80.90739634729202, 83.56068365035519, 87.84159768012263, 85.90261320913993, 88.31327053808397, 87.61353538882348, 84.1138162920552, 84.59768772125244, 79.89900988917198, 77.22355334989487, 74.9054168885754, 84.541134988108, 99.5443734815044, 99.07774479158464, 101.27184806331512, 86.68612234054073, 4.093407084864955, 6.498446599129708, 1.0595820916275824, 0.5212850796599542, 0.6775172511416098, 0.41060063507287736, 0.35578842304887315, 0.4406614042818547, 1.171364616001806, 0.453728290214654, 28.875261506726666, 58.64481949037122, 73.62826178150793, 121.46647684035764, 91.29224008129489, 67.96501036613219, 43.430224080239576, 53.73003475127682, 83.39535574759208, 97.50348583344491, 103.59535817177066, 60.27108907699586, 1.0222936505752227, 0.2653019785160019, 0.1313668573575635, 0.1454690038677185, 0.12844631568558756, 0.24033757857978347, 0.16059499624515736, 0.14913467329836663, 0.2265453759220339, 0.1820384714031412, 0.13904976928907056, 0.20606547083345153, 0.20828335666127745, 0.052228802664866375, 0.1617592047419279, 0.13166547843044804, 0.1475846782446869, 0.13793172525061717, 0.14115245081484318, 0.18802590818414766, 0.081395662179397, 0.07798994170321573, 0.08310890290886165], [0.018697365960707108, 0.0939337712442202, 0.07228824805708663, 0.08064426016062498, 0.0721826658193623, 0.01821913557397502, 0.08518549147993328, 0.06727129145855866, 0.036722585528848634, 0.06523456244218735, 0.0978207711370722, 0.08852077783235619, 0.012896107697498896, 0.033191835672985164, 0.01949734752997756, 0.09961587602212545, 0.08238818271145706, 0.21378247367758907, 1.8792606241280034, 88.75285056329544, 108.83948080001339, 86.61336237384428, 59.40980326744818, 39.8742268162389, 47.14808971651139, 113.13586465774046, 108.81684087937879, 116.28337060251545, 158.2868874457575, 92.77734356541788, 25.90755701065064, 0.26828353143026756, 0.05161558375543645, 0.12067771681974973, 0.08026401241940838, 0.13336050924995255, 0.08012163497868084, 0.6360442539857281, 0.4474745612711676, 0.5078118300485996, 1.2444332242012024, 34.38551695116105, 119.09261134362991, 103.09005491195187, 111.79815599995275, 92.6742244535877, 84.7824784248106, 75.7072199544599, 82.27214582504766, 81.31682903535905, 88.84618728391587, 84.9928508266326, 88.48687464191069, 89.07199028999575, 97.8682113462879, 94.7594976425171, 95.73033917334773, 91.6959539536507, 96.54161868556854, 91.26898042617306, 99.03185306056854, 89.58386744222334, 80.88497607938706, 67.06887429760349, 67.90733583511846, 65.81781079692226, 71.68597467484014, 69.9481293462938, 71.319060479441, 69.44966670005553, 68.4761893364691, 66.76099961803806, 70.3193110804404, 65.10802261291012, 68.64591813856556, 67.53656202746977, 72.33360505873158, 73.75307160039102, 81.01237466258388, 86.34222461331277, 86.88549641639956, 87.68589527376237, 90.35153804286834, 79.85391832167103, 78.65490467317643, 69.15341792568084, 73.04828443834859, 89.56114907418528, 84.34673447762766, 51.96232841860864, 87.25712530074581, 77.49196114078646, 74.32763607271256, 85.50700295356013, 89.08133337574621, 85.7539475348688, 86.30271850093719, 79.06625147788756, 71.52100763013287, 65.96144014789213, 65.14336709053286, 64.905318444775, 67.7757324710969, 68.08200682363203, 65.75074218934583, 65.05028532397363, 71.06985661291307, 74.82987988379695, 74.93968271440076, 72.60588815135341, 71.28197839183193, 67.6315696777836, 69.15321396243188, 67.12107319985667, 67.23158990183185, 67.17135798546576, 71.60669572891729, 79.04204260918402, 78.01122019367834, 79.47162843519642, 79.87018046840545, 77.21683825215986, 74.94992794529085, 66.89591346248504, 67.64857707485076, 63.30540326333816, 73.11211709053286, 80.09213170697613, 91.3390810258927, 87.63251966045749, 87.64366703648722, 53.9895740632088, 0.20159288099215877, 0.2948596118198287, 0.5140238225219712, 0.118011393764567, 0.08600939605985919, 0.1402264650190069, 0.39144095994772454, 0.08139889507043747, 0.039843677528082364, 0.08877397755221014, 17.45587302792457, 24.09097206208014, 60.46567393887428, 80.73345491963049, 39.066787304416785, 24.396424678064164, 30.350200168548096, 45.60242875929802, 59.128149632484686, 75.3276365034042, 69.6429689468876, 13.417152608594588, 0.44451023001343976, 0.11253641617874946, 0.14237169506809405, 0.0600592363175125, 0.050375567028118726, 0.052931596404842796, 0.03902077269289763, 0.11403931980772365, 0.09380176663398744, 0.06710622249351395, 0.03600333622025867, 0.036036484844742284, 0.11323377835534273, 0.08807427114656857, 0.06180818440512784, 0.06533381679365713, 0.018292950060699257, 0.01827619188735562, 0.06424980238080025, 0.055051848157158786, 0.025864057205317002, 0.03322689185640024, 0.03254898448264407, 0.10004978056155867, 0.023930658128172643, 0.026126582130429246, 0.007474104134035447, 0.014257480412901891, 0.05172835572833016, 0.07325603161007166, 0.07399919052277842, 0.0859796871701556, 0.04024656316746147, 0.09600180261317762, 0.05017919571048791, 0.06973863083628878, 0.0395275283634903, 0.0773927225400844, 0.07525086327786408, 0.2779700084319038, 3.2719553958985115, 107.68577052700905, 120.49889872151037, 103.28742857902282, 70.14885271749189, 62.40588611172092, 38.871017886746316, 59.950258808751265, 126.58811953759964, 120.92512699865527, 152.55878356195265, 109.27888039619693, 30.153471731370498, 0.09320910569400558, 0.07974459714586697, 0.34319911632807026, 0.0384605287634317, 0.06989376364095558, 0.02624075987466401, 0.3628394656604336, 0.5593649201816129, 0.6723440738935625, 1.0478253999064047, 42.79633768143193, 123.26634268606864, 109.16454330567392, 116.5635141249626, 96.87038390867173, 87.79587068865376, 78.53147552859399, 84.106504994054, 85.57459323636948, 92.28850641558248, 89.16407185216104, 90.9242590012089, 95.20970729089554, 100.48524025947818, 97.05453918826197, 99.26560278861754, 94.98227257882395, 99.97446137089884, 96.31018315592121, 101.49595660548057, 94.98466522462907, 84.3317824025308, 70.84438308592766, 71.86011222101027, 69.8592798171505, 75.11288673646989, 74.22176345702141, 75.31754032258065, 74.04701402110439, 73.59180727312642, 70.79816972055744, 72.63640419129403, 67.59837073664512, 73.96964134708529, 71.78099801463466, 75.89456019863006, 79.56496515581685, 85.5763190792453, 89.17658421301073, 91.30543493455457, 89.75554173992526, 94.09223187354304, 85.70378042036488, 84.21279338098343, 72.13838869525541, 76.81805087674049, 91.2680547468124, 86.28160045992944, 55.22677590770107, 89.19879267292639, 80.75305892575173, 77.47460857514413, 87.11395878945628, 91.53948276273667, 89.64293049227807, 91.17980141793528, 85.07079616669687, 75.37680733588435, 69.10772231317335, 66.39381870146721, 66.61889214669505, 70.16411073746221, 69.9321888339135, 69.9221004978303, 67.37522709754207, 74.16094318512948, 78.27334434755387, 77.39798899619811, 75.83869780263593, 73.40398849979525, 70.91401300122662, 71.14213020570817, 68.613127123925, 68.7285154096542, 68.93906039576378, 74.26939672039401, 81.81277351994669, 82.11191700350854, 82.4903315882529, 81.56703702865109, 79.63885476512294, 78.26893560348019, 71.56945674650132, 69.74858268614739, 67.07118849600515, 76.99014879042103, 85.5180875716671, 93.25860269608037, 90.8472942536877, 96.02979644652336, 70.6530184899607, 1.6362369421028322, 0.4527942145303373, 0.10417422174566215, 0.22096886870361146, 0.18662018280836845, 0.22583675991383292, 0.5754469443232783, 0.06511921258342844, 0.021524856678180156, 0.11345561443557663, 20.602241485349595, 24.45165361127546, 55.85148788267567, 61.63164946340746, 34.66652731741629, 33.40807407133041, 40.94463771389377, 54.01294354469546, 72.59856116387152, 85.07511861862676, 87.62369432756978, 22.679216900179465, 0.506717917779761, 0.12801866242361645, 0.1387214852917579, 0.16637834720313552, 0.07197392218175434, 0.05014610071215899, 0.04615885055353565, 0.08880220023134063, 0.12849145358608616, 0.062068730908175634, 0.048230467213978695, 0.10031226526705489, 0.03151625582587815, 0.07191730828415002, 0.1117677005728887, 0.03878656429268661, 0.022476326388817643, 0.03019727841620484, 0.08429738873195264, 0.05481893827597942, 0.018542208258182775, 0.08598400790604853, 0.09792511997323844, 0.1538524572407046, 0.13915434029073487, 0.11266167921524857, 0.13344549904427222, 0.10335336619567487, 0.2067928100305219, 0.1718578830121025, 0.17135601881290638, 0.17925266927528768, 0.17348951239499355, 0.2767245946151595, 0.1384715874108576, 0.20126104234687744, 0.1557302766389424, 0.19393449919598718, 0.1071453175597614, 0.5608249611912236, 6.370334634857794, 130.855807335146, 137.56081673406786, 119.19019206877678, 85.72968375298285, 57.814696911842596, 65.20470511528754, 156.4948820298718, 119.18237086265319, 135.22157792122135, 171.29200781545333, 121.57777017162694, 38.68414832699684, 0.4379952344442568, 0.22486182109963512, 0.6135068665589056, 0.26625811753253786, 0.3335416893805227, 0.8652282205800857, 1.600572668736981, 1.5029300436858208, 5.455405019944714, 3.6951779117507324, 43.923783763762444, 127.55368155817833, 115.21527782563241, 122.06594836327338, 101.1130391397784, 93.22720020048081, 82.24587378963348, 90.01798752815493, 89.07210011636057, 100.87316266952023, 95.78813137546663, 96.86646153849941, 100.8913153986777, 106.21468559388192, 101.33535123640492, 103.53347101519185, 97.9902990402714, 104.83190105807398, 101.00584860770934, 105.90987820779125, 98.08193345223704, 90.26382600107502, 75.48688473240023, 75.4091041318832, 74.32791063862463, 78.61561036879017, 77.68656561451574, 80.79129419019146, 77.21490060129474, 76.6078196802447, 75.21274243631672, 77.47009784944596, 73.61198394529282, 79.38691308421474, 75.40096129140547, 81.0916457637664, 85.17800238824661, 90.72796790830552, 94.36304015498008, 93.97404301551082, 94.53842501486503, 102.19384824076008, 88.73181881443148, 90.37420149772399, 77.48545000630041, 81.12846897494408, 96.14232924676712, 91.6589738476661, 61.82157454952117, 96.69749367621638, 86.83125003691643, 82.15853045063635, 92.51232470235517, 93.41181831975138, 92.68979626317179, 97.90799202457552, 88.35543601743638, 79.67432083622103, 73.76807074392997, 69.5535389069588, 71.4293183049848, 74.27344460641184, 73.82745542833882, 72.9999843720467, 70.70713935359832, 80.18039288059359, 84.27524535886704, 83.22880406533518, 80.0929867836737, 79.73396439706126, 76.34844903023013, 75.54353944716915, 74.15849562614196, 73.25707220262098, 73.92774258890461, 78.4848463919855, 87.1566027979697, 86.15595125382947, 87.34740257263185, 86.72242779885569, 83.2923464621267, 82.51812550329393, 76.6428856695852, 73.93816040408227, 72.43877164779171, 81.81418557320872, 87.31054798249276, 100.03412846596011, 95.80543687266689, 100.30194005658551, 65.97242278437461, 1.2144087062728022, 2.6121477686589767, 1.171676689578641, 0.6898794587581389, 0.543036399589431, 0.5348244273374158, 1.0749430738149153, 0.3271831596089948, 0.1308525978557525, 0.22177870024836835, 29.90827064360342, 38.465480112260394, 79.25784357132451, 102.04588859311997, 50.77774124760782, 35.10552290947207, 47.39248475720806, 65.07547870759042, 87.66205510785504, 97.97246794546805, 103.44817515342467, 28.867403038086433, 0.9868270891808695, 0.22250953280637342, 0.29513227783383866, 0.2865294781663726, 0.2787675978916307, 0.16636406732422693, 0.17965917084966937, 0.3016504909723036, 0.1892852035140799, 0.2517479679156696, 0.201540480578138, 0.2629031733639779, 0.3014258127058706, 0.12809062106234412, 0.23928328837838866, 0.10905944186473086, 0.11944515795837488, 0.08106403803873448, 0.1780488846763488, 0.1625667993099459, 0.16791505829220818, 0.20972165609559706], [0.10528147160526245, 0.10089355746224042, 0.027296741215151646, 0.08860956742278031, 0.022892049746587876, 0.08102538890295452, 0.047456657123421474, 0.03870154768528958, 0.11192232009864624, 0.06660838025592028, 0.02573709153840619, 0.07874708938141985, 0.09349277273060815, 0.15050405546301796, 0.07040057676814257, 0.11204173022340383, 0.03726652710728588, 0.23054101474342809, 18.413019603298558, 99.86668248330393, 90.45190365083756, 78.64054879834576, 65.37766987277617, 50.160470008850105, 47.93230095217305, 104.18012865128057, 78.8196599098944, 95.14557653857817, 97.60362394394414, 48.940758012956195, 0.3928748007503248, 0.041301642439418265, 0.18734078043170516, 0.013208275120104513, 0.10804376249471981, 0.07768454841308056, 0.1455960059238057, 0.11350265223412745, 0.2323109842836857, 2.1286492097762326, 10.941503567080344, 104.63386058807374, 96.85361969855525, 112.59941777875348, 99.99495183267902, 98.03201736942415, 77.70077243927987, 76.96519467138475, 72.8754726532967, 80.38711747815533, 80.24028747312485, 86.8264098321238, 88.94722753955473, 88.51752404243716, 90.77316145743094, 89.53555168644075, 90.48433380742227, 90.44867161781558, 91.91454764335387, 93.69873185311594, 92.776959173141, 88.86969012598838, 74.24711765781527, 68.71976067942958, 66.92294643771264, 70.11894856729816, 69.21958046574747, 71.69284666738203, 68.23530089470648, 65.32440408583611, 67.2757871689335, 66.72245840872488, 67.92789689956173, 74.92506796313872, 82.92667173570203, 83.63090976592034, 86.30739396618259, 85.28932709847727, 85.54202971919891, 88.84288464823078, 86.18678892812422, 87.02357169120543, 82.69044306970413, 82.45974494564919, 81.00637343622024, 68.31590560174757, 75.38569542669481, 86.23899567511775, 79.0881069244877, 44.01984260928246, 83.09223498067549, 81.26200214509042, 67.97298062232234, 81.93963081605973, 84.61432641552341, 83.95033190327307, 82.94327905101161, 84.75779887168639, 79.02540391491306, 73.63529066885673, 67.69798324954125, 64.33383303303873, 62.806183599656634, 68.41657715459024, 67.11875115671467, 65.65586789961785, 66.67550763776227, 67.99128240154636, 68.05892759753813, 65.75520584660192, 63.23465547254009, 65.31357834416052, 65.04165610959454, 64.81742989632392, 63.299217685576416, 68.00706601911976, 62.748136443476525, 71.53705796887799, 76.93256839629143, 76.63442119475334, 77.54651346514302, 78.09441366503316, 73.00062764075496, 70.90372854663481, 62.45379001863542, 65.30653768970122, 64.78395638927337, 80.89417011507096, 79.15164932127922, 94.0797979600968, 90.03320632442352, 106.75752593624978, 25.222617041680124, 0.9823842082292804, 0.38388111238037387, 0.4163859165724247, 0.0814186754606424, 0.10187945133375545, 0.04590185869845652, 0.3575238267019872, 0.06223467321345403, 0.012276146256725394, 0.08218112446728253, 27.441454779717233, 26.34963950803203, 52.952248357957416, 68.26989619962632, 31.256716789737826, 20.774659072199178, 39.64858854970625, 62.43800640106202, 59.72900182970109, 80.892350135311, 35.46185847251646, 0.7367891061209864, 0.08103556255058897, 0.04569144881961327, 0.06411510880195326, 0.043437430454838666, 0.04867943687244289, 0.04749432949709797, 0.041590262234451315, 0.049132547236137816, 0.044906702823936946, 0.023057086152895805, 0.026060171883493185, 0.03183768716670814, 0.04647481968746551, 0.02130471365225892, 0.015258420251249788, 0.06323513424684925, 0.05140382556184646, 0.02933406969532371, 0.04271029427106823, 0.05716777917358184, 0.034613288833849856, 0.049106101880991654, 0.026109295356417858, 0.05127151068600436, 0.06790399581434266, 0.04013574471877467, 0.09486770903271052, 0.035655804263848456, 0.02067509663080977, 0.010479942993110707, 0.03057656088663686, 0.05620319020724105, 0.07668560806421504, 0.10064241085802356, 0.08331364756750484, 0.036539609258573864, 0.11557710341989033, 0.06011594980654698, 0.3534581061572798, 24.67401473752914, 118.04223199044506, 100.95452047163441, 97.40524615010908, 75.36060794707268, 51.700000301484145, 47.1040964126587, 105.16508286999118, 84.93399958456718, 102.58648533974926, 116.17080642331032, 55.01509735661169, 0.47929834394205006, 0.03649870016341729, 0.1412402751344827, 0.4135402676559264, 0.050992152893975864, 0.2579186988934394, 0.12274281407195715, 0.1568117016746152, 0.5565096798443026, 1.464394717927902, 16.045392636329897, 116.06704404277187, 100.52396189781928, 115.20150246158724, 106.21895313262941, 101.8017916525564, 82.49416766628143, 81.43923051895635, 77.276638707807, 83.40777397155762, 82.12588848606234, 92.52428793138074, 92.18660323850571, 93.66041029653242, 93.15043157146823, 94.95057982783165, 97.10705188012894, 96.37250961795931, 94.26797759148383, 96.97355793368433, 96.32671202382734, 93.45170882440384, 75.61379694169568, 73.72268107629591, 69.66410267737605, 74.22312059710103, 73.94195725840908, 74.32912657337805, 70.46498790864023, 68.93862109030448, 70.65131618130592, 71.31829169488722, 72.36496833062941, 82.97831366139074, 89.0239804790866, 89.7874306094262, 88.79883643119567, 90.23618113610053, 90.78255161162346, 93.55344726193337, 90.07142589938256, 90.06339288526966, 87.4289486485143, 87.66963312702795, 83.49745504317745, 70.98653762571274, 78.0370686131139, 90.28001754514634, 82.58380951419954, 48.610561124740116, 86.77421092987062, 84.8602198016259, 69.9810694110009, 84.77130751455985, 89.74395505843624, 87.88777182179113, 87.53542530921199, 89.8800220797139, 85.47698113226122, 79.99333504707583, 73.08546850758215, 68.87822443439116, 65.81466505604406, 71.16287954391973, 70.0236035931495, 67.9801977834394, 71.64508004342356, 69.51519381615424, 71.40505452309885, 71.5667110873807, 66.83251227101972, 68.88642218805128, 67.60270887805571, 67.03123523342994, 68.24371830109628, 70.86561879804059, 66.18929063120197, 75.96414304548695, 81.22962690168812, 80.86807066394438, 81.26645011286583, 82.07028496649959, 75.81666192700787, 74.17298486155849, 68.41010524380592, 70.3162359422253, 67.31753687704763, 81.9067378197947, 82.67896621457993, 97.08183103992094, 89.44572156475436, 108.72952891934304, 37.056768709613436, 0.6738322456517528, 0.0730684932862078, 0.26041093612870864, 0.15350465332308125, 0.05131272621633065, 0.12074170814406489, 0.40271045039257697, 0.10475382088653504, 0.050605312966170816, 0.03947276839866273, 30.57027259180623, 26.124218933043945, 39.322639588386785, 49.12977310918993, 37.343325307292325, 37.81619448815623, 52.56867193406629, 74.0182944267027, 71.13098282967844, 91.5810049733808, 48.515290675624726, 0.8847678753156817, 0.08971667172567499, 0.07970376465950282, 0.017591502720249758, 0.060645033109692804, 0.017519655164271113, 0.04310301009325251, 0.017738963154354886, 0.045670404384333285, 0.10131215556494652, 0.007375747541851936, 0.06553426369904511, 0.05466449878088409, 0.07988899705871459, 0.025441052181826487, 0.07711268676024291, 0.09057341849491482, 0.033214419944992954, 0.09888486726389778, 0.04496929603779028, 0.06402582125437838, 0.055546882682509964, 0.1688534853559348, 0.14531232356544466, 0.2472611441607437, 0.13551577505084778, 0.18597398764423786, 0.2682485058903694, 0.11542888072830056, 0.18689254238720865, 0.22527874146978702, 0.11404658998212508, 0.21974190228408386, 0.1557204553917531, 0.29513855975481773, 0.16906530866699834, 0.16336366864702395, 0.26418551261867246, 0.34323693042801273, 0.6326083190018131, 35.49140568702452, 137.93497946954542, 117.01541039251514, 108.83126735687257, 93.65150651624127, 63.25408297200357, 74.81727338606312, 133.98940455528998, 94.11189863758703, 117.63410152927523, 117.90799279366772, 70.26923810282062, 1.0604960038777322, 0.16875364877764257, 0.44579676742995944, 1.0214784717367542, 0.3357508111624949, 0.4329264596585305, 0.33553048427547183, 0.25491859132964767, 3.792370077102415, 5.511415975709116, 15.959395650894413, 122.73520669629498, 104.80020046234132, 123.24240838327717, 108.63651383307673, 106.61952910884735, 84.5930750139298, 88.52679652552452, 80.49473947094333, 91.28597997849988, 87.15153509570708, 100.3854630070348, 98.0005991843439, 98.11663073878135, 97.83954666506861, 101.20001377597933, 101.79368019104005, 100.5443896016767, 98.2033778775123, 102.09089386847712, 100.4509352099511, 98.35446757654991, 80.50073285256663, 77.04439516990416, 73.91474385415354, 78.44785844126056, 77.88028363258609, 79.31361967517485, 74.61124697039205, 71.82597191103044, 73.53475247659992, 73.61506692824825, 73.110595210906, 85.58400692478304, 90.35337371210899, 94.8278880888416, 94.16346996061264, 95.69863857761507, 94.72764799671789, 98.73272526648738, 93.58615982917048, 95.77350877946424, 89.9525780831614, 91.85344496080953, 86.4625786196801, 74.75625699566257, 82.39832847349106, 96.80167967273344, 84.87031598244944, 54.88341554518669, 92.62991736012121, 89.23530993923065, 73.69674636471656, 90.11495636355492, 93.35313966197353, 93.56044477032077, 89.40221463480304, 91.0075544541882, 86.73317509312784, 82.89954462359029, 75.87700366973877, 72.38563137669718, 69.58907558071998, 77.12258369691911, 73.9846561801049, 71.1160699782833, 73.88163120515885, 74.69874720419608, 75.27467666133758, 75.13843705577236, 70.59351613444667, 72.72205306637672, 71.43480962322604, 71.30089206080284, 70.28793211906188, 75.0714272837485, 68.37042654714277, 81.47406116608651, 83.92786456692605, 84.9360627512778, 86.63513152830063, 86.070922113234, 81.48487121828141, 79.02363884833552, 72.6745060951479, 75.7868048452562, 71.87158907613447, 88.77891863546064, 86.02758776757025, 102.23255418962049, 93.21459370274698, 117.15709424787953, 32.94530107129005, 2.2025005759731417, 1.032552916196085, 0.7771847997942279, 0.45459586946714314, 0.32967346630269484, 0.2133212274601383, 0.8689286091154622, 0.33424348720619756, 0.23626108683886068, 0.22647868030734603, 47.194852213705744, 43.64114169151553, 70.90064556367936, 91.21457715188303, 45.532355616169596, 30.921775794798332, 58.25256286128875, 86.1442155222739, 86.97298880546325, 105.47388322891729, 66.20156764984131, 1.6940486334985303, 0.20352922950781163, 0.24369716524116455, 0.11639477970499186, 0.21283967991269406, 0.15601385174499405, 0.12004293636569094, 0.15938017998010884, 0.18456803244208136, 0.15845857620719941, 0.11758657502791575, 0.16446168714713666, 0.11238447029984767, 0.28817616883785496, 0.1601087908831335, 0.21249916915210987, 0.23620629623051614, 0.12190884309670619, 0.24696405526370774, 0.13590197529523604, 0.13258809343941752, 0.1384325475702363], [0.02569652909803535, 0.08919928658513293, 0.02687745171809389, 0.07898312107089066, 0.043851075799114285, 0.054523013832588355, 0.061122570186853416, 0.03823345264179572, 0.025776640827497168, 0.022683648933326046, 0.05346768558205617, 0.10406066453264606, 0.028483905536573262, 0.021519789006561044, 0.09611375870243197, 0.14025545378606166, 0.07405182842405574, 0.6076594093634237, 41.44922317997102, 93.94396628102949, 95.83464284096995, 59.31470540262038, 63.52909211189517, 71.39458179473877, 39.61885306142992, 67.7327746729697, 112.55411440326323, 112.67747294518256, 76.73482602642429, 5.645380116278126, 0.18925195529816613, 0.21657497141390078, 0.07200015303228172, 0.30917047132407466, 0.04268361525910516, 0.13865730244546168, 0.06039293272601021, 0.3617101601294933, 0.5511958488533574, 2.8422695494467214, 91.62855978934996, 94.24795781412433, 114.24685247482793, 105.93517749540268, 106.52407430833387, 93.00702187322801, 79.32072700992708, 75.68767086152108, 72.8179628618302, 70.14785643546813, 77.71249248135474, 79.62289856326196, 81.42445102814706, 82.58307210860714, 87.48329700962191, 86.97615808056247, 86.1100124543713, 85.94288026132892, 89.70226810824487, 89.59572868962442, 87.51836299896242, 76.19326437673261, 65.89091593219389, 63.914614031391764, 65.03769843809067, 69.20612673605643, 68.84635909911125, 70.63158665933918, 66.82555398633404, 65.83306881689256, 63.81400131410169, 72.56432671700755, 87.4751227901828, 90.90482757937525, 89.87518187492125, 87.5193985046879, 85.50697941933909, 82.82065006994432, 86.56718038743543, 88.7904582485076, 82.4655814324656, 84.7805799976472, 82.70637573734408, 76.48137031062957, 77.81049682248023, 64.08853584720244, 73.78026931516587, 81.93822660753804, 86.32692736964073, 42.74719430554298, 80.8035162956484, 80.52185089357438, 70.29245068950038, 74.00638611085954, 83.59137227458339, 83.26669416119977, 84.68055955825314, 88.39256517348751, 85.07317312302129, 83.53729847938784, 80.40940438547443, 72.60811605761128, 67.22123484457693, 62.561741490517896, 65.29053834176833, 66.90478586381482, 68.68103904108848, 69.34195057038339, 64.42397694433889, 63.58700982985958, 65.11823646483883, 65.6407863863053, 64.14512388167843, 63.217761824207926, 62.249124665414136, 63.81058885205177, 64.86779705170663, 63.878135988789225, 71.87905726894256, 76.53579711914062, 76.63486050021264, 78.03421312762846, 71.40246575878513, 67.0444457761703, 64.13942860018823, 61.89927670263476, 63.88846358945293, 72.72544983894595, 79.73176002502441, 82.18166458991267, 81.11800409132435, 87.81319187533471, 88.08154475304389, 3.0187771877934857, 0.3128156095983521, 0.17710583044155953, 0.07416807460568606, 0.22657490095063565, 0.2850714902723989, 0.08029402008340245, 0.1099579634084817, 0.14276236926596012, 0.3273600033454357, 1.548555053530201, 25.20270120713019, 30.397411777127175, 77.28040418317242, 42.249610270223315, 22.690874184331587, 17.85785517384929, 52.705190027913744, 63.74225724127985, 63.59525072959162, 55.72979634807956, 5.874471049154959, 0.39164958101126457, 0.08766552493456872, 0.0605671257982331, 0.15314733459343835, 0.0037068188858909476, 0.07917308023259526, 0.011803956473276261, 0.042196931092128645, 0.03687789836417764, 0.056576072013065706, 0.11309879366308452, 0.03589442916094296, 0.09267190951974162, 0.02361006948405937, 0.06404910266639725, 0.024600226634873018, 0.01952531356965342, 0.03997783867582198, 0.04762355703860522, 0.03972759988579539, 0.11502220295369626, 0.02377313512918209, 0.09099375561720903, 0.053360234089796586, 0.10444266661520928, 0.019171582046715964, 0.05239533485784646, 0.06670446300338354, 0.056176334995055394, 0.03910390855444055, 0.0476065690388843, 0.07004731830449835, 0.044308365172436165, 0.04756398221117355, 0.04158836616683872, 0.09011873765097511, 0.14387279839044617, 0.04755963849264288, 0.3971093977170606, 57.03360396046793, 107.77764812592538, 107.74724975708993, 72.66754781046222, 68.19100164598035, 75.35780737476965, 41.900695831544944, 76.30247885181059, 114.82866548722791, 115.85286694188272, 89.31402406384869, 6.630211760920863, 0.3393253467736706, 0.1302222147463791, 0.11644351055785535, 0.16933032912352394, 0.08189937265049066, 0.26556575791009013, 0.1865439110946271, 0.2551358691867321, 0.3485412925722138, 5.113080163155833, 104.22209801212435, 100.33159317508822, 116.79968003303775, 109.52829607071416, 109.95554416410386, 96.13850885821928, 82.33559408495503, 78.51981039970153, 75.05077208242109, 74.12725787008964, 80.84299102906259, 82.43526935577393, 85.35648592056768, 87.50497987193447, 90.94268629627844, 88.96281503861951, 88.49261699184295, 89.53632831573488, 91.59251320746638, 93.04133476749544, 88.77745951375654, 77.72353787575999, 70.30698699335899, 67.54253187487203, 69.21167296748008, 74.42383612355879, 72.42648678441202, 74.14541059924711, 71.14717437374976, 67.46084459366338, 69.38871306757774, 78.64438487637427, 93.49183467126663, 94.58536009634696, 93.23676293896091, 92.28483507710119, 89.86794902432351, 86.43750682953866, 90.3275723611155, 93.01668659333261, 87.23723103923183, 89.02306264446628, 85.34642896344586, 80.11099046276462, 83.00553491038661, 67.7160418418146, 74.76381148061445, 87.31392122084095, 89.9888913862167, 43.39710358650454, 82.8476438214702, 84.95627864714592, 74.3570303147839, 77.37854188488376, 86.53698598184894, 85.3985180393342, 88.79620059843987, 91.30634492443454, 87.97717048275857, 86.96442234900691, 85.35245372403054, 79.35689910765618, 72.97208847538118, 66.47662778054514, 67.5169344871275, 69.0532249019992, 72.03043722337293, 72.86276417393839, 68.09084000126009, 66.83325752135246, 68.15558264332434, 68.49559722408172, 66.7767910803518, 66.33353971665906, 66.84644452987179, 65.93381097239833, 68.1825920843309, 68.07604482097011, 74.55159556481146, 80.16636648485738, 80.63864338782527, 81.22109182419317, 77.0740718226279, 71.78701493047899, 66.2973754636703, 65.9649859705279, 67.20833024671002, 74.99728664275139, 82.66204510965656, 85.12643890996134, 89.76664989225327, 86.72562060817596, 99.11187725682413, 6.18221236813453, 0.7492062882069619, 0.18737281822869856, 0.07659476535815386, 0.1683644454685911, 0.30533966398046863, 0.1519602200677318, 0.2690795887141459, 0.21835545168047954, 0.34236404984708757, 0.8207247634568523, 30.462834950416322, 28.842990206133937, 44.98116062533471, 26.71258426481678, 27.746668131120746, 32.09866531433598, 61.96770245029081, 75.10196685791016, 73.41792075864731, 77.21901908997567, 13.773496016379326, 0.5668389965449611, 0.17511850643542506, 0.12652984715156979, 0.11289532837127486, 0.03166071511053991, 0.0497411581267032, 0.056762763809773235, 0.008465411374345422, 0.055334764427595565, 0.024141014380861196, 0.0469416506858843, 0.014147754597117104, 0.08623680926018185, 0.06000011731239577, 0.07945136167109013, 0.02733326637216153, 0.06944659045867382, 0.04377463554602958, 0.02324517222962553, 0.022568316311545433, 0.08175783790647984, 0.0982050791442875, 0.1939427729455694, 0.20642829007439076, 0.24058025991243703, 0.18068516176314126, 0.10804856586600504, 0.16147729970755118, 0.11748935080944531, 0.1696019839014738, 0.16920940980555552, 0.17425930818482754, 0.3140689907295089, 0.20404695172704038, 0.13516240933489415, 0.22914382358712537, 0.2629683214810587, 0.19562838088360526, 0.6743020107669215, 77.68943678948187, 127.38263483970397, 126.10246735234415, 91.47998825196298, 87.55761807964694, 88.31142702410298, 62.361677077508745, 82.81589615729548, 138.02233849802326, 133.65234744164252, 103.9265238854193, 10.537217028679388, 0.596930991497732, 0.5596967894704111, 0.4250413618020473, 0.8729991100488171, 0.30966324972048886, 0.7954268854471945, 0.3561692300342745, 1.1516794658476308, 2.1927576536132447, 4.1237505405179915, 107.95870473307949, 105.04394438958938, 121.54505760438981, 116.58518129779448, 115.33636139285181, 101.93417164587207, 85.01368645698794, 84.09733449259113, 78.04052029886554, 79.2033540048907, 85.4450059706165, 89.18779434696322, 89.03062497415851, 92.81777535715412, 97.19347738450574, 96.5726681678526, 92.56784977451449, 94.9325918382214, 97.03094220930531, 100.8277573124055, 94.83142606673702, 85.45667109950897, 72.96003110947149, 71.4775634581043, 71.74576728574692, 78.08985587089293, 75.90038099596578, 78.80657488299956, 73.14768514325543, 72.3050109801754, 71.83301648785992, 82.09720811536236, 95.28715056757774, 99.89593552004908, 98.53385325401061, 98.40661941036102, 94.4731959988994, 92.06343297035464, 94.45126210489582, 98.96227021371165, 90.88271325634372, 94.71902662707915, 88.56088192232194, 83.9977612033967, 87.06528217561784, 72.67727528848957, 81.35732358501804, 92.21865684755387, 95.38247200750536, 49.750903960197206, 90.16535882026919, 90.85530373357958, 79.3722277302896, 83.70545048867503, 92.50811207679011, 89.49046011893981, 91.2242889404297, 93.6949271540488, 90.74398686808925, 90.06390279339206, 89.61373236871536, 79.9968808697116, 74.2924367227862, 70.49441352967294, 73.36825570752545, 75.46599418886247, 76.52884667919528, 76.54252006161597, 71.6977810090588, 69.05337395206575, 70.66116917517878, 73.23363996321156, 69.966321299153, 70.51508442048105, 68.82342107834356, 69.82269194818312, 72.80055538300546, 69.76793566057759, 78.70020020392634, 83.73294630358296, 83.82023472939768, 87.10870281342538, 79.59780323889949, 77.37986764600201, 70.87742513225925, 71.77697366283786, 70.2242563616845, 79.58620871267011, 88.25678056286228, 89.88989076306744, 93.23696690220987, 92.3635805806806, 103.6400967259561, 4.372462639885565, 0.9140859988908615, 0.5675436135741972, 0.3007201537970574, 0.7467238568971235, 0.4953608788069218, 0.4333378488738691, 0.35716079295642916, 0.6330270933047418, 0.4715618977863943, 1.9762944237839792, 44.040482121129195, 50.640568117941584, 98.37551501489456, 56.87867426103162, 30.216602279293923, 31.11344829682381, 70.42068081517374, 89.7007619180987, 87.64629502450266, 93.78529856281897, 20.435960446634603, 1.1537687408347284, 0.3097360280732955, 0.27810125461509155, 0.3343975321660119, 0.1885886763733241, 0.2457693871110678, 0.18064716380209694, 0.16460502219776954, 0.14143069394894187, 0.1385677467671133, 0.1668917486864713, 0.07943230140353404, 0.20530016431885384, 0.15658195190612348, 0.15553107845687097, 0.1119857598396559, 0.13803579063425142, 0.1309924242236922, 0.24303820705221546, 0.2022408534802737, 0.25342908657846913], [0.03251911088403675, 0.026833261851401582, 0.0158020161325112, 0.04488886446662007, 0.02708441037083826, 0.028343284352412148, 0.0652700629565985, 0.01526746391919592, 0.04554291586241415, 0.13176366025882383, 0.06038946234771322, 0.02060692055120824, 0.03831293426393982, 0.037757260048942226, 0.04813593196412248, 0.012007699471958464, 0.037037593222433524, 2.0917090629377673, 71.3602767452117, 94.39383860557311, 83.90953925348099, 74.8582229306621, 72.74026855345696, 52.587683662291504, 73.57326230695172, 61.17227323593632, 95.90568480953094, 98.47038930462253, 17.130900736778013, 0.08733947025311571, 0.20204084324500254, 0.024103638866255363, 0.10124676229972994, 0.05497592884386259, 0.17202200968900036, 0.195744198055998, 0.1493295507445451, 0.17465342977835288, 0.45247637997231177, 66.46504894379648, 119.14467688529723, 107.84615624335505, 107.57867413182413, 102.6428968675675, 103.04204510104273, 83.66956080159834, 77.44282953200802, 71.83100038959135, 75.20594104643791, 75.23153843418245, 71.87705686015468, 72.94951131266933, 76.1533974063012, 77.27167298716884, 76.75657164665961, 78.42231596669843, 78.36413152756231, 74.88063535382672, 74.66394009128695, 71.32113149089199, 69.35400009155273, 65.45355989087012, 70.21883564610636, 66.59716221594041, 69.17160987854004, 67.35467387783912, 67.72051334381104, 66.97403138683688, 66.94823788058373, 62.66786513790008, 68.7689785803518, 81.38233261723673, 88.09162524438675, 81.83145184670725, 87.10864790024297, 85.51337288271996, 90.20171919176656, 87.16453383045813, 87.63724219414496, 81.71911516497212, 75.29583392604705, 72.15612565317463, 72.88130129537275, 71.49926985463789, 71.59735264316683, 63.27027059370472, 74.05479600352626, 81.76695239159369, 84.76878935290922, 38.00627254670666, 76.40646088507869, 83.63987630413425, 69.11289984180083, 67.5945189691359, 74.48245986815422, 81.46889932693975, 83.86209426387664, 84.62526982830417, 84.40219679186421, 82.97320673542639, 82.96692309841033, 80.8520987726027, 81.0227140303581, 70.491456062563, 62.29594992053125, 63.76641511917115, 67.4505836732926, 66.38021592170962, 65.30101107012841, 64.04686458649175, 66.95600417352492, 63.55234784464683, 66.13406365917575, 61.31649094243204, 64.50078871942335, 62.343363531174205, 66.5223861509754, 61.61444987020185, 66.9195967335855, 71.8892240524292, 77.71668157269879, 71.69954607563635, 72.85400944371378, 63.80628601197274, 62.35175740334296, 59.339863484905614, 63.790314120631066, 64.77766490751698, 77.97394983230099, 78.13348831668978, 88.64038836571478, 78.12122698753112, 100.30488967895509, 45.34349741474275, 0.21198046634033804, 0.2934214502813355, 0.033961842136998335, 0.08445366300762662, 0.08757123483284827, 0.33769747122160854, 0.06241511373269943, 0.23482969751761806, 0.1882132626469097, 0.15693433702953402, 6.574415064627125, 22.342536334068548, 66.4710815491215, 75.1463523987801, 39.4353606623988, 25.39332251394949, 23.187832601608772, 55.815806081218106, 60.343672537034564, 70.05186819261121, 40.26029002281928, 2.4359784347395745, 0.11802568896523408, 0.036950446890606996, 0.09541290316490397, 0.023544551729555094, 0.08216813927696598, 0.01541188106902184, 0.04813619626445636, 0.0271164175243147, 0.04969772860227574, 0.06166232509478446, 0.09926018905976128, 0.054013109540626894, 0.019909732659617742, 0.08963045619067647, 0.05036676467786874, 0.0533857409872355, 0.06558317075213117, 0.06989025495826237, 0.08047323869240862, 0.0072565930989390666, 0.054646300362242814, 0.021741577206299673, 0.02614166448643852, 0.04165031203639604, 0.08254863982719761, 0.07288625629077997, 0.06405196400479445, 0.03162140139348565, 0.05784710380999793, 0.027516888071512504, 0.07279801828366134, 0.01314225845083955, 0.03723915095531172, 0.048550691966327934, 0.041278973897738803, 0.057721319833710316, 0.1016523445686025, 3.1259172193465696, 85.89742783577212, 105.34930090750419, 99.04823287840813, 83.50326799577283, 85.43752993306806, 54.915304414687625, 65.44355784693073, 76.89940867885467, 104.94244129427018, 113.39044217140444, 20.53393929235397, 0.1347452131730895, 0.14663774760500078, 0.05956476869722528, 0.1886841615722064, 0.08755959029639922, 0.13320261852875834, 0.3055827896441183, 0.10050482912770203, 0.23507734310002099, 0.5789349119990104, 80.72381373374694, 121.09034507505356, 111.64251635151525, 110.26730199013988, 106.11406110948133, 106.49329154722153, 85.51512225981682, 82.81896345077023, 76.62957314522036, 79.53649659310618, 78.95981404089159, 74.38083910172986, 76.58907075082102, 80.71875387622465, 81.3318830920804, 78.9383194523473, 80.09262592561784, 77.91706762006207, 78.86403760602398, 76.95137223889752, 74.1398722125638, 72.60494678251206, 68.90775988178869, 70.889984561551, 69.596724202556, 73.18867391155612, 70.17498354757987, 70.9819955210532, 71.61980429003316, 69.52217563506096, 66.262905674596, 71.17622344724595, 87.38339424133302, 91.53805501999395, 85.27033498210292, 88.72803764958536, 89.76216270077614, 93.24620016159551, 90.93749307817029, 88.25746305527227, 84.74815768580284, 78.44941954458915, 76.65196203416394, 74.57564753870811, 74.72638422443022, 76.39003399879702, 67.39361516890988, 78.92877240334788, 85.0660736330094, 86.54742733124765, 42.641325612222, 81.50896241587978, 88.89382054728847, 73.49587394345191, 72.37009094607446, 76.41530190744709, 82.43247662821125, 85.62852582623883, 87.65528509693762, 86.54029646227437, 85.77618737374583, 87.99886118981146, 83.89632086600028, 86.24297295847248, 76.27299831759545, 65.05150125872704, 68.77192820272138, 70.4135891699022, 70.43868449426466, 69.15755994858281, 68.04457172270745, 68.9109605358493, 66.71845759114912, 67.7800392335461, 65.37532037304294, 66.81317498607021, 65.04333880639845, 67.50817191216254, 63.54046306302471, 70.73897330991684, 75.21942615509033, 80.4724996320663, 76.69491983229115, 76.79355959738456, 67.92730854403588, 67.45637309166693, 63.56739405662783, 69.07764557869204, 67.71813638748662, 82.35484507776077, 81.63610996738558, 90.12080069511168, 82.57652175041937, 99.59732547883065, 58.455800471767304, 0.2197171270006126, 0.44690330482779017, 0.02550587279631967, 0.1658320652260896, 0.06757196564708026, 0.5112403493014075, 0.12994789398245274, 0.30168003132266386, 0.2844712450619667, 0.2074043014116826, 5.671783551093071, 26.690207142983716, 44.13783927117625, 49.764938200673754, 31.643531130206203, 33.05129528045654, 33.16220421944895, 65.90422845655873, 73.96313021259924, 83.90758591313516, 61.46253255105788, 3.5032950726247605, 0.11820024209878138, 0.02249022896942352, 0.07606854722384485, 0.06635217747140316, 0.022945886575466683, 0.05783261708734978, 0.019862440136832096, 0.014524007189808594, 0.07253151161656265, 0.01894584466372767, 0.061392248457958626, 0.01632574543867621, 0.03268298092147997, 0.021921113741794424, 0.09558596242699893, 0.05720305369205533, 0.05395919610295565, 0.030054353222611453, 0.043320257306819966, 0.07403213230352249, 0.13118101974889157, 0.19635686921256204, 0.10849921708746303, 0.18650572927248094, 0.21018340793107787, 0.130619982918424, 0.20343198230670345, 0.12583091449473174, 0.12475322796812943, 0.22210715278502435, 0.11499725147000245, 0.22117350610994527, 0.21715252510001584, 0.11709186608993238, 0.15222176248508115, 0.16552065048486958, 0.27810324644369466, 7.041918933391572, 110.52229527504214, 120.46748053643012, 113.5913851953322, 103.72576129051947, 96.92046473103186, 69.60961311094223, 107.04931105336836, 91.90348655946794, 115.8055474681239, 122.6366924470471, 29.110658630248043, 0.2352699222824266, 0.6726838492097393, 0.1771251358572514, 0.4570189749281253, 0.3674498134322705, 0.6152700332383956, 0.7955918088555337, 0.27390425724367945, 0.6399782686944931, 0.9916533818168025, 84.4558391263408, 123.44841910946755, 114.50521899807839, 116.3509608853248, 109.63389412049325, 113.04809770276471, 90.92428253542994, 87.30965368209347, 79.85868007906022, 84.7797170762093, 85.34596612376552, 81.41083255890878, 81.44540432960757, 85.65853195805704, 87.2488961681243, 84.25195432478382, 87.43243171322732, 84.75855981149982, 84.33597933861518, 83.55954616300522, 79.7135131589828, 77.55981030002718, 74.50557831794985, 75.81827794351886, 72.84885544930735, 75.79711283406904, 75.28948753110825, 75.57209430202361, 73.55697662599626, 74.38426725326046, 69.36896001138996, 75.81927422554263, 90.45240571421962, 93.80048598012617, 89.61319892637192, 94.38620567321779, 94.23887360480525, 100.6379145960654, 95.94644608036165, 95.26702880859376, 89.69052453194895, 82.93945081772344, 82.46054510916434, 78.80116985690209, 78.58117980341758, 79.91719399729084, 68.83784755583733, 80.94062666739188, 89.7310112368676, 91.81042440475957, 48.943931210425596, 86.44165669718097, 91.37513545251663, 76.97795806392547, 75.72304279573503, 81.48589103452622, 87.5932724245133, 90.97684229573896, 94.77409670429846, 90.78992566754742, 89.24200934748497, 91.10476647653888, 87.20416545867921, 89.97619075159874, 78.65892902497323, 68.27847834556334, 70.32692832331504, 73.01358715180429, 72.61128533271052, 71.65036739841585, 73.47754078526651, 72.63645910447644, 70.81294921136671, 73.51994160682925, 68.48419881636097, 70.66621334322038, 67.64506263117637, 71.32375947890743, 66.20530174624535, 73.08722572941934, 80.13485416289299, 85.12617218878962, 79.67855699600713, 81.91108380594562, 70.53355093925231, 71.48217616542694, 67.34238901445943, 74.51354857414, 73.82170523366621, 88.62536568795481, 85.59306759988108, 97.54206626645981, 87.61589665566721, 108.3796299657514, 54.33620176007671, 0.3508796993522875, 0.7927291527871163, 0.36633785213193587, 0.316246212610314, 0.25330010801553726, 1.126169718561634, 0.282649181542858, 0.5203053451353504, 0.5592400784934721, 0.17653437481532175, 10.510280151521007, 40.00517514444167, 90.17984021094539, 102.58332390939037, 53.49805008980536, 37.22014327203074, 36.39013836460729, 83.22496798730667, 86.08354430044852, 99.00155667335757, 75.53561625942108, 4.035567814303983, 0.33946489734995755, 0.19777169571288172, 0.16881516563796228, 0.1226927655478639, 0.13018038634571338, 0.20187688510744803, 0.19512550544834908, 0.09213128893245613, 0.1437624664075913, 0.16430873003217483, 0.2547718701703895, 0.11972055890627446, 0.07778298305047136, 0.12650302641334074, 0.2348760918023125, 0.16732567620854225, 0.20820417381342382, 0.12202673636737371, 0.1912672874788123, 0.22516264850574158], [0.055250448790649255, 0.0553431109555306, 0.05548739595518959, 0.10906490407163098, 0.05379251069239071, 0.17281382284577818, 0.02924509049813834, 0.05530107571112533, 0.0040951555579780575, 0.07575643534261374, 0.05035713878310016, 0.03500695843549986, 0.06911970074138335, 0.022140394918800845, 0.06291497461197358, 0.027556734219674143, 0.0453939309133397, 35.34770573339155, 90.78721923212852, 84.64303816518476, 75.97939322071691, 83.02347583155479, 30.891903023565973, 36.22204911324286, 63.505299014429895, 89.61261057084607, 110.85094282704016, 51.5568494796753, 1.2524283629271293, 0.07630631793290377, 0.15825111959730426, 0.0580843459183891, 0.09179319900971267, 0.043202911789018306, 0.2322693550658803, 0.18442147982216653, 0.1571635045712033, 0.7080267946566305, 40.480829208127915, 122.91787147521974, 101.88201196732061, 105.69498723553073, 100.06660569098689, 100.9904101587111, 87.09210334285613, 79.12193344485375, 71.99919162258026, 76.15496635437012, 70.35631472064604, 71.57475979097428, 68.879746314018, 67.5638303449077, 68.1048350180349, 69.0947941810854, 67.86462906868228, 66.96388813757127, 64.69818199834516, 67.65094618643484, 64.90001540030202, 65.86203159824495, 67.50198241203063, 67.43410971856886, 65.8674366243424, 64.41366895552605, 62.37396978562879, 62.562918201569595, 66.44065964606501, 65.51536467767531, 64.02452276599023, 65.32040719063052, 72.43950905338411, 86.93607930214175, 84.76677325464065, 85.97474559660881, 86.05886474732431, 82.34026955020043, 80.87498972492834, 74.1201348458567, 69.85251765097343, 67.09199274739912, 62.63199114030408, 63.38301520193777, 63.78244192369523, 67.04669721664922, 64.82399986636254, 66.02135042990407, 72.34774128083261, 81.18074632460072, 81.34615267476728, 37.63960153825822, 79.51911264850249, 80.23630234502977, 69.75231678255143, 65.25051055415985, 70.4493925648351, 72.20444140895721, 73.34978134401383, 79.32694004428002, 80.62144771698983, 80.15306964997323, 81.03946255099389, 79.46468583999142, 78.55576284470098, 80.24985021160495, 64.6250533288525, 63.8604578664226, 64.32399572864657, 65.30356061074042, 62.88558413905483, 64.08066365026659, 59.245703066549, 63.115482099594615, 60.556433662291504, 62.864799499511726, 61.23720415176884, 62.86263042880643, 61.7283005868235, 63.070523892679525, 61.32481813430787, 71.75838162822109, 70.47830043300506, 74.19040018512358, 68.16745173546576, 66.1725813342679, 59.67211569509199, 60.90262989844046, 60.560693356298636, 63.5460328286694, 68.66626739501953, 81.10821385537425, 76.5619436387093, 85.48944642466884, 81.70572419320384, 100.90360026205741, 15.529416607272243, 0.45997916931106203, 0.20373956660830206, 0.12120613362640144, 0.16123777465714564, 0.046013313000120466, 0.1147333648236048, 0.08992410535293241, 0.2021814357008665, 0.022259196003658638, 0.0962873159216777, 16.15101323973748, 25.83502454142417, 58.409889128900346, 60.66735044602425, 29.30142310357863, 27.354970439787838, 40.31645836368684, 58.447598795736994, 57.22672577827208, 64.41976431877383, 25.393879490513957, 0.6340667052615074, 0.05607115878393093, 0.03458872039411818, 0.1239802758960474, 0.07733472968421637, 0.021826019247753486, 0.013021397547075346, 0.045721946779878876, 0.049103566129962285, 0.029808530929468335, 0.017936477858212688, 0.04319554968406597, 0.08450572634296072, 0.08890881668776275, 0.03089211824830742, 0.04201907995006731, 0.07966715331760146, 0.01528735156171024, 0.05058018911269404, 0.027981602752040473, 0.01286209818171037, 0.04351878516195763, 0.014569181479483604, 0.08721174041350042, 0.007318280892626893, 0.15060349367558956, 0.03895559010186023, 0.037940753428565885, 0.04037550725643674, 0.0520022819569755, 0.10835294025920092, 0.07145130466068945, 0.1253335625534096, 0.049805314159922065, 0.018588995162938392, 0.05386861386678873, 0.06638506562599251, 43.06905615714289, 112.41730213165285, 95.14550593591507, 92.93921978242936, 91.86959728117913, 46.863298185410045, 51.82301759719849, 69.44268488114881, 99.9544886619814, 123.60031681676065, 60.30940278883904, 1.4178436610006517, 0.024379926560927304, 0.2238916473523263, 0.19002904424503927, 0.07931200261678427, 0.22176089636500806, 0.12901391022868697, 0.19395584240555766, 0.07081181276589632, 0.6539821720892384, 50.88557112601496, 127.1804758810228, 106.47679405827677, 111.55289019307783, 105.5430659940166, 107.38250071002592, 89.24589249395555, 83.32252517823251, 75.76870702928113, 78.70764486251339, 75.07793841823455, 76.54528925495764, 74.32876571532219, 70.78995627741661, 70.54670656881025, 74.22876096540882, 69.54672182759931, 70.08198415079426, 68.61260152632191, 71.89916333844586, 68.77940424026983, 70.573606183452, 71.72872066497803, 70.75699267848846, 68.98106898030927, 69.78107560065486, 67.04554403981855, 68.21352389550978, 69.409956624431, 67.78272213474398, 67.66377233689832, 68.54672139690769, 78.70311844733455, 91.43905439684468, 87.39630668394028, 88.09524951442596, 88.42165347068541, 85.6558882805609, 83.82010136881183, 76.95457289295813, 71.69179547217585, 67.41042644746842, 64.94283983784338, 67.27711293005174, 67.97759332964498, 71.07358286457678, 68.50903526429208, 69.47152999139601, 77.21617144923057, 86.09578209538614, 83.85989773658015, 41.550996918832105, 84.14153960443313, 86.35578032462828, 72.47509279558736, 65.72326598628875, 74.9337677801809, 75.63851571852162, 77.38745350991526, 84.54673613271406, 83.24745101313438, 84.69027919154014, 85.41487432295277, 85.09061982554775, 83.00715877163796, 81.5682529634045, 66.83965098473334, 66.92642165768531, 66.55283943299325, 66.96011481746551, 65.60708930415493, 67.29148449436312, 62.48920509892126, 65.21741751701602, 63.79059653128348, 65.13107046004265, 64.63150170541579, 64.88074087327527, 63.80536817735242, 66.91988698897823, 65.28101090461978, 75.44043602481966, 73.24149254829653, 76.44378615963844, 71.85731164870724, 69.09123266896894, 64.12058161151025, 63.59146956474551, 65.78505900598341, 68.22209035196613, 70.73110503535118, 85.27185686172979, 79.52752221015193, 89.02984834486439, 82.23668759868991, 107.1514887963572, 22.796515380182576, 0.45018635930553563, 0.2983355672369081, 0.14803440249975652, 0.14712180792083665, 0.05712996124319973, 0.3511881263506028, 0.1258668823227767, 0.3522389844780968, 0.013840928722563532, 0.04633969709938092, 17.197337842756703, 32.82307413316543, 41.834392086152114, 43.88630943913614, 36.457426624913374, 34.94698462947723, 52.59033518452799, 69.1163750617735, 69.12381972036054, 81.80694487787063, 40.80470323562622, 1.0724924504756927, 0.06954178454414492, 0.011999808766338374, 0.021433996735140685, 0.08420715889623089, 0.0015801883742941785, 0.08247482725569318, 0.05125247723152561, 0.07780431093828333, 0.03394995628285312, 0.044100211422529914, 0.042821093567556916, 0.019347778438860853, 0.06586371215000268, 0.06643649310834947, 0.05524204097568028, 0.02407746355710251, 0.0826057670037112, 0.05526041942498377, 0.036099824994321794, 0.11335405415945476, 0.1822823937982321, 0.08426667626706824, 0.23118701072469836, 0.07451111345642036, 0.22215575340294072, 0.09721508670237758, 0.11168728432347698, 0.1336287472757601, 0.15527096096306078, 0.29867184919215023, 0.20596417868810318, 0.21846644249894928, 0.1942353572456106, 0.12041134804847742, 0.19161867668792126, 0.19582474454035684, 58.72672642430952, 128.0365017921694, 113.95204713267665, 109.3963396933771, 112.56640711138326, 50.53944941489927, 52.22851222561252, 87.58541983942833, 111.48217770361133, 133.7837625318958, 75.00856737936698, 2.7167039388610474, 0.08627592570959561, 0.575339692013879, 0.25017754895792854, 0.44696817715321824, 0.5422055925573073, 0.5196757434356598, 0.518721504317176, 0.34375514294351306, 1.6945820758419654, 51.50233245665028, 130.9726155188776, 109.37767705609723, 117.54268677003923, 106.02699233639626, 113.59492317322763, 94.17890056487053, 88.15974896953952, 78.03043980752268, 82.73689962202504, 78.44523829798545, 79.9888635450794, 79.98323102151194, 75.2568220323132, 73.97314010127899, 76.13609975384128, 75.61880973077591, 74.8817414622153, 71.29960552338632, 76.38506043341853, 73.31431527291575, 73.58103644463324, 73.97522680221066, 74.82409831016295, 74.09889128900345, 73.74183008747717, 70.2273158104189, 71.51796387087914, 75.20427796148485, 72.11232846783054, 73.14232718560004, 72.32962777537685, 80.7604016027143, 96.58944806744977, 89.97936002669796, 94.3471545557822, 92.54740638117637, 89.80840744510775, 89.86668602112802, 81.71269816737022, 77.53006304464033, 73.43621469313099, 68.61371547945085, 71.17264624564879, 72.25636574529833, 76.07475388434626, 73.51326573279597, 74.05198758648288, 80.51720680729036, 90.37940256057247, 89.12527961115684, 46.03254410528368, 86.35857305219098, 93.50786932053106, 76.05319653787922, 69.64375342092207, 79.33103499873992, 80.14845694265058, 80.24908142705118, 88.99490002662905, 87.00636817562966, 87.94390878369732, 85.6772259742983, 89.84645443577921, 86.43651839225524, 86.82247177247079, 70.27824386473625, 69.87359646827944, 72.76068841257404, 70.42199873155164, 66.96231134476201, 68.31443863530313, 65.91585436174947, 69.08971863408243, 67.10396382116502, 68.40547684700259, 66.98084062145603, 67.80856270943919, 66.4610481262207, 69.75431719133931, 67.57005906874134, 78.39061537096578, 80.47904214551373, 80.58431071619835, 76.94484541493078, 74.44779396057129, 67.95913465561406, 69.94288121500324, 68.59350742832308, 70.55519457786315, 75.90427198717671, 90.0973919899233, 84.76253709485455, 93.83370845548569, 88.43549159265335, 112.53254136731549, 19.835467146288966, 0.622131729558591, 0.39849969408204483, 0.45533517495759074, 0.5261551312381222, 0.22690176002440915, 0.9430700468440211, 0.3057153534985358, 0.30570861192480214, 0.15449970960617065, 0.19878273259007162, 28.08152871747171, 45.8041327230392, 79.82854843139648, 81.05914500451858, 40.02677563698062, 41.44631670367333, 60.650370505548295, 85.56175139642532, 85.58380296153408, 100.58375450872607, 49.659073429722945, 1.2916059768007648, 0.23902700132419988, 0.20959974086332708, 0.1271493441515392, 0.13260499333902714, 0.1316093088638398, 0.13596363005138215, 0.24346174642203317, 0.13054869077619047, 0.09893168289695056, 0.14114736399102595, 0.13630951874919478, 0.24693819213538404, 0.13224955918567796, 0.13134840996034686, 0.09424182285945262, 0.19099713423319403, 0.14596604171299166, 0.20078577672041234, 0.16194999127859072], [0.05527607826215606, 0.0998246732858881, 0.0837605526190131, 0.07079063809566921, 0.0714273644130557, 0.06448886011757198, 0.03137654628634694, 0.03153259456608325, 0.0536101894272912, 0.02899275837285865, 0.02975047487134655, 0.04453342648283128, 0.04481355419322368, 0.10733417355485501, 0.08883093618938039, 0.19397188428669207, 4.2093307741226695, 66.0580010567942, 78.68188273522162, 64.11101887303015, 46.55861239279471, 37.26845118307298, 27.517640936759214, 40.89268984333162, 87.80325258931806, 99.18648858224192, 76.64905948023643, 13.079766996445196, 0.35610196751452267, 0.4139260082475601, 0.15491146654371293, 0.13973866619410055, 0.05557264621940352, 0.13042484500235127, 0.2423406073883657, 0.4602153388963592, 0.5643069840246632, 15.670403261338512, 122.11684503862936, 100.50726044562556, 108.28184527735557, 98.10632274996851, 97.74529210982784, 88.12283946621804, 81.15025381888114, 74.05328196863975, 74.25066348045104, 71.88469763725035, 73.94488334655762, 68.54781966055593, 69.25601928464829, 70.19880802400651, 70.07226451750725, 67.17676301156321, 65.87998036415347, 68.20596941055791, 69.0224499856272, 67.51794645863195, 67.23120550955495, 67.43640822748985, 65.7907150637719, 63.90877362220519, 67.94865408251363, 64.7715695442692, 63.03959208150064, 64.35311148243566, 67.08806253248646, 65.15605988041048, 63.319080568129024, 66.81985086010349, 80.00521198395761, 83.03281891730525, 82.50872750436106, 83.4000704365392, 79.14789953539449, 71.73836969560193, 66.7691110795544, 69.01525635873118, 66.97133279615834, 68.02892931046026, 64.33205619935067, 63.28917641793529, 59.399852214321015, 63.51153166063371, 62.358539181370894, 69.39080761324975, 77.74909603980281, 83.10288029332315, 72.82147730550459, 47.31080139836958, 88.15523039910101, 73.40254506757184, 68.16449426835584, 68.7665859345467, 77.01034899680846, 78.2551210157333, 80.39056131916662, 78.68335754640641, 80.30761887950283, 78.26477789109754, 80.66200502457158, 78.1778032548966, 81.36192844760033, 76.1357153615644, 63.61587847432783, 66.30325901892878, 62.130480812441924, 62.23959330589541, 62.02808341672344, 63.855335250977554, 62.322775010139715, 61.22888480463336, 58.86824161775651, 60.55614340689875, 60.49398560677806, 60.95724105834962, 60.82872852202385, 62.17532134825184, 62.605934835249386, 66.61177696720247, 70.30428055794009, 67.82701353872976, 65.27907325375465, 63.66454332105575, 60.8535022120322, 61.427109626031694, 61.63841947432488, 63.40634545972271, 67.16043026216569, 77.81939275803106, 80.94818115234375, 83.05877716310563, 82.10164823839742, 92.29591185046782, 74.65101980393933, 0.20759352512897986, 0.020221392548973524, 0.018323700829979875, 0.03262490379594026, 0.12840909147334675, 0.14319850312125298, 0.096124897620851, 0.42851679627933814, 0.028309980595123865, 0.13697022361861122, 0.6453845818196574, 26.07117279883354, 38.788008766789595, 69.21256726787936, 36.13059513030514, 27.52557981398798, 35.954657216225904, 53.26431997360722, 58.215990681802076, 63.71648334687757, 56.05485493136991, 12.848028463702049, 0.13304653577506542, 0.032563279683311144, 0.03707734169438481, 0.06065409592983704, 0.04495381340084057, 0.018743061190170628, 0.048707448877394206, 0.018709104342926896, 0.02768078300681326, 0.04287943116299087, 0.07764500295442921, 0.05387857300980438, 0.006837079521163457, 0.05696484631287956, 0.04191483453577084, 0.15111608310572563, 0.07689872606387062, 0.046333859509397904, 0.041942915488635345, 0.03942113790300585, 0.060443460055056124, 0.05148999896200915, 0.06106433984372885, 0.07633133836451077, 0.01573600903934529, 0.05156975254536637, 0.054362637156079856, 0.03705694460340085, 0.06045276419289651, 0.07495825599518514, 0.04226455367320488, 0.032329132570134055, 0.05279071666600724, 0.04843700834880433, 0.26878210145138925, 5.564490056806996, 84.54006810342112, 93.32515747316423, 79.83874659384452, 64.84140342281711, 60.92921180109824, 40.069694211406095, 27.315036789063488, 79.91610357838293, 112.00954037327921, 87.9447324814335, 14.97168302536011, 0.6682926332277637, 0.022731797559367075, 0.78070463672761, 0.16319278507463394, 0.3236696352401088, 0.11441294088839524, 0.602591094230452, 0.1404957142808745, 0.7417889023500105, 23.15042103490522, 130.58837229205716, 104.11547230136011, 113.65399406802271, 99.15397213351343, 103.00198985684304, 91.59853012331071, 85.77545781289378, 75.996581046812, 79.87964907000142, 75.6637522482103, 79.0372024043914, 70.39700538881364, 72.12483298393988, 74.079146077556, 74.8048786963186, 68.72471855532739, 69.35353725187241, 70.02967542217624, 72.3105650563394, 71.45377036063903, 71.54265911348405, 71.58130230442171, 71.72213108308854, 67.59688808071998, 72.25125881933397, 67.50866613080426, 65.95905534682736, 68.50070415004608, 69.81997766802388, 68.11468016716742, 64.77063209779801, 68.98902354701873, 84.86893530814879, 87.05028303207891, 87.83626325668828, 86.2218862964261, 82.75556225930491, 74.932904858743, 71.35462068742322, 72.90511792705905, 70.04645532177341, 71.05861509999922, 68.24724058951101, 66.37329686072566, 62.190940226278, 66.26642011827039, 67.48917979578819, 74.07081496331, 82.04183993800994, 87.95135344228437, 76.43043441157188, 50.428485562724454, 91.99636828514838, 76.90826539070376, 71.00526302091538, 72.90999735555341, 82.04266363574614, 81.83552326694613, 85.11755081915086, 83.21916287945163, 81.21640851420742, 82.36060311717372, 84.3293034645819, 80.39056131916662, 86.03742507196243, 77.62058350347704, 66.4299907991963, 67.92826560235792, 65.65867631666123, 65.44742530392062, 65.67618185474028, 64.70562665693222, 65.32416089888542, 64.88253339644402, 63.295550269465295, 62.48683990970735, 63.21108202780447, 62.70995216984903, 63.60246789070868, 64.0809735175102, 66.28441595262098, 67.68462365673435, 72.925671146762, 70.67886690939628, 70.85447142201086, 66.25898330442368, 65.64747794981926, 63.62746123344668, 64.58695926973897, 67.2150767234064, 72.25535377379387, 82.27321270973452, 84.0841474840718, 84.93526258776265, 86.46505755762901, 91.126598388918, 85.85605467519453, 1.4718865675310937, 0.3285785427977962, 0.009619772768459253, 0.043153460813505996, 0.3392975837472947, 0.1609425550146449, 0.3907702040047415, 0.45626762653550795, 0.19431826328077625, 0.3354225271651822, 0.2731483429670334, 30.536206806859663, 38.12512036292784, 43.1169443745767, 24.4088880092867, 38.65846072473834, 47.90551900863648, 64.0292884457496, 74.89791731680594, 74.62867013869747, 74.3330724777714, 20.528318535897043, 0.14567184862830948, 0.025917698681775122, 0.013387898798100652, 0.0197634864748726, 0.03700920583439931, 0.045002230157655095, 0.026808771935682145, 0.020257802792794762, 0.07952174216869377, 0.05017252691510705, 0.06400042160924885, 0.018136574278375315, 0.04397954874401612, 0.02176260631982117, 0.028542934526358883, 0.06232546229336051, 0.05349796903770297, 0.025894158715081793, 0.06117976631128019, 0.18148762354206655, 0.3048057313407621, 0.11617294362475795, 0.12851926257773755, 0.15097555193689563, 0.18212741421115014, 0.14228353366976784, 0.24861169588421625, 0.19371559723250328, 0.08184367805839547, 0.1489393055559166, 0.10009416769589148, 0.2000707715389229, 0.2504601741149541, 0.13949538731286604, 0.4340412095189095, 9.36078936822953, 101.02349142874442, 107.06172927733391, 97.26295824973815, 75.32681280566801, 58.83043389166556, 40.58281475497831, 58.56324988026773, 116.22982240492298, 120.79167227591239, 103.23085231165733, 19.990014414633475, 0.8583144915680733, 0.6626403139483544, 0.5871199179560908, 0.47665209239048345, 0.3548417835225982, 0.4333371134294618, 0.8224018218536532, 0.7392165016743445, 1.0803266494504868, 19.72205573512662, 134.88204186962497, 107.84889405773534, 118.60146784013318, 105.55114607657157, 108.15864363024312, 96.63876010525613, 91.6103756812311, 80.33436159933768, 83.85057818505072, 80.09828982814666, 83.77741029185634, 76.53305146002, 77.46517135250953, 79.09817172634986, 79.18562489171183, 74.69934340446227, 72.35540559214931, 75.72530208095428, 75.61721724848594, 74.02458590845909, 75.1300588730843, 74.14729333692982, 75.78147826656219, 72.32129666113084, 76.64541952071652, 72.77000011936312, 69.5361549623551, 72.26459487791985, 72.61737285121795, 72.73985278221869, 70.15916855104508, 73.38203107157062, 88.01850441963443, 91.79587241142028, 92.32669461158015, 90.13494476195305, 87.40808163919758, 79.45073004691832, 76.89231703358313, 75.90854737066454, 74.05078734121015, 74.73577437862274, 72.25566756340766, 69.80615523553664, 68.210205570344, 70.57672839010917, 70.63394792618291, 78.29443100960025, 88.6364346165811, 89.18431912699054, 81.25847985667568, 56.66054341100878, 95.03818204326015, 81.18338215735652, 75.6693926165181, 76.60965534948534, 85.64997334634104, 85.94513954654818, 87.96261064467892, 86.6109226595971, 85.54838395887806, 86.39796933820172, 86.91296869708647, 83.62302580187398, 90.36850621623378, 83.02414263448408, 70.29921285567745, 71.21496861980808, 66.65022403963151, 69.59832452958631, 68.85153662773871, 70.8980332651446, 69.89590690981957, 68.49889201502647, 66.27450020082536, 67.05647960785898, 66.33912517178443, 67.98034683350595, 66.46845356110605, 68.15934811868976, 69.9069679937055, 72.86780049723964, 76.93873436220231, 75.7460984876079, 74.55856953897785, 70.79169780977311, 68.40643390532463, 70.10214513347995, 68.89711456914102, 71.6060838391704, 75.41650172202819, 87.55611973424112, 89.1687394726661, 92.46327154098019, 89.81542064297585, 99.88925964601579, 86.15204457313784, 1.1533088429320244, 0.8796673232028562, 0.14473257886786617, 0.2951324004079065, 0.5665875971317291, 0.48249054039197586, 0.5761511323432769, 0.9633939917529784, 0.2494466857564065, 0.40574461822548225, 1.1255976653868154, 43.46947523855394, 58.9847360118743, 93.47502339270808, 47.67058864716561, 40.433690163397024, 52.81656572895666, 76.10225754399454, 88.3725061724263, 90.88287799589096, 91.50982964423396, 25.17067309348814, 0.2892905816195473, 0.10517660949018695, 0.08696649268630051, 0.16356285150733688, 0.15056958662406092, 0.10613986546353948, 0.164611978276122, 0.12279408067585, 0.2254123165602646, 0.13456276167304287, 0.1584188775309632, 0.11949093171185064, 0.10125091449627954, 0.15578132873821646, 0.2941029314552584, 0.2224669842830589, 0.14080550491569505, 0.20893542005890803, 0.16284536420097276], [0.09303394735099808, 0.02113403309316885, 0.05267381930964128, 0.03260501232298632, 0.12773697189385855, 0.07921788105440718, 0.01294471023063506, 0.05534555860644868, 0.0916864293357057, 0.11622558152603528, 0.050754903124705444, 0.021090419707639564, 0.06297487119633345, 0.03450134806635399, 0.10048462738913876, 0.28891912090682215, 13.217790299846282, 84.30281962117841, 86.35454085565384, 73.55731394983107, 51.169774301590465, 27.640326792194, 29.711036220673595, 106.9457918597806, 109.54859041398572, 104.64233290764594, 51.53849278726886, 0.4047478765489594, 0.055234540974901575, 0.08341611182737736, 0.3238192675334792, 0.19608657807111743, 0.12352403223274216, 0.06840230536557014, 0.21285374528698384, 0.3187394610816433, 2.8853236907912843, 98.22366437604352, 108.2079242890881, 101.40126274478052, 94.29823475499308, 89.56591867631482, 89.71792620997276, 79.66221640186926, 75.53509066181799, 74.92224385661464, 74.5313169110206, 76.10703499086442, 72.21985632373442, 69.66871538469869, 68.50150431356123, 68.28440896926388, 67.12832173993512, 67.17886540197557, 65.85035862461214, 65.15722482435166, 65.64753286300167, 66.9064332592872, 66.83091194398942, 67.8154190125004, 67.9642572710591, 64.62269206200877, 62.43415855592298, 60.66864875055129, 61.05310770773119, 63.27821339330366, 63.15282306363506, 62.59558370036464, 64.21988425716278, 76.94822649801932, 83.841274323002, 85.36297352083268, 82.57871827771588, 81.82712939477737, 72.52226321927964, 66.47425866896107, 65.99547847624748, 73.51679586595105, 74.54178963938068, 79.07248804646154, 75.61094145621024, 72.56080442859282, 66.3900375366211, 61.524376561564786, 60.15230009632727, 72.65177203762916, 76.27484967631679, 83.46405998353036, 63.463647365570075, 55.61972287393386, 83.62384949961017, 69.31141099622174, 68.27302625102382, 76.8232362501083, 81.42817727981075, 77.55175375169324, 79.81858561115881, 77.36092259806972, 79.15585410210394, 77.19125655389603, 79.67825105113369, 76.63836709914669, 74.51318771608415, 67.6637331131966, 61.399664801936, 63.34285405374343, 64.31688054915398, 59.47808388740786, 60.057567011925485, 60.11594756957024, 64.78848280445223, 61.41144367956347, 61.873769529404186, 56.01035171939481, 60.75625488834997, 57.94087956028601, 60.62266680502123, 60.057637614588586, 60.60203121554468, 58.96308452852311, 67.26821699450093, 64.46794671397056, 66.29823054036787, 58.93390209444108, 62.43352313195506, 59.10052045699089, 64.227446586855, 60.284750692306034, 70.26413117685627, 72.90634955129316, 83.58603000640869, 74.68484632430538, 89.1062012026387, 75.76389035870953, 105.2529831855528, 23.290714410043535, 0.6279962858365429, 0.12436160382123725, 0.04500360528547918, 0.10333609091298235, 0.04104844271956433, 0.0374418884635933, 0.563489414991871, 0.13625619902966485, 0.15750829010240494, 0.20483372402527641, 6.743782028075188, 23.4313686432377, 40.672742935919, 84.59138055001536, 21.05316108272922, 23.94211615285566, 36.936057767560406, 54.60933600702594, 61.099940807588645, 57.62369709630167, 52.79198423508675, 10.799402959885137, 0.23772342611224423, 0.03960837362213962, 0.040315158680201545, 0.029089333331813256, 0.07691623117294043, 0.08188335375199396, 0.03952654777094722, 0.013488468905580382, 0.0670046468956336, 0.06050240285995026, 0.0194943119065776, 0.03681598696857691, 0.05148646729667822, 0.027454857932283517, 0.07467845004172095, 0.027654494699691574, 0.02742567189758824, 0.04545804864216236, 0.04525784688491014, 0.01385420119585169, 0.049791792708058516, 0.02170147824912302, 0.040450909460384044, 0.06191247961513939, 0.04360388220858671, 0.06675897782007534, 0.05785998940888432, 0.14329435604233898, 0.03775923655578687, 0.03204875971160589, 0.04039757441909563, 0.09124868669577184, 0.08063250071098728, 0.3145558855706646, 20.419470802430187, 101.72187728266563, 95.5235831968246, 87.66856624234109, 57.43277180579401, 36.61403117641326, 39.819584277368364, 73.16375901622158, 112.34269080623504, 115.65732894405242, 60.56249372420773, 0.3876956480164682, 0.1287527048900243, 0.28087139790577276, 0.9765731555319602, 0.6932990301039912, 0.5622098642972209, 0.3678774130680869, 0.3026325237606802, 0.2757280367997385, 5.163173242922753, 111.50672389614968, 109.34054005530574, 105.80994406054097, 99.33195360245244, 95.33011621044528, 90.05357127035819, 84.42841391409598, 78.35198786950882, 80.58669551726311, 77.31180667877197, 82.04138494306996, 76.9771186767086, 74.5269944590907, 71.93360959329914, 71.05895242383404, 69.65962333063926, 72.22986621241417, 68.65928557611281, 69.24181245988416, 67.4019855068576, 70.07057789833316, 71.40761190845122, 69.65490864169213, 70.60143932219475, 68.55921806827669, 66.36383610387003, 65.49629803626769, 64.85488068672919, 65.92770776441021, 65.481122386071, 66.1556916083059, 66.0286303489439, 80.7302228866085, 88.51737499237062, 87.94553264494866, 87.64557330839096, 85.06726603354178, 76.66020685626616, 69.83733023366621, 69.76733161557105, 77.31975340074109, 80.0809137282833, 84.86316157925515, 80.02049353814895, 77.61820654715262, 71.56888408045616, 65.96388770687965, 62.31479298683905, 77.25988234243086, 80.02049353814895, 87.78905360929429, 67.90283295416063, 62.36890208336615, 87.30560579607564, 72.46896605337821, 72.82937695903163, 81.17963237147178, 85.17250322526502, 81.7193034387404, 82.03135152016917, 82.16879137100713, 84.34463993195565, 80.41865333434075, 81.02879370412519, 80.51295495802357, 77.10873773021083, 70.14386346263271, 62.6560744931621, 67.48985444345783, 65.87926649278211, 62.0468911816997, 64.19735416289299, 65.00945737285, 67.65445278536889, 66.04051513056602, 66.52714006362423, 60.4595079729634, 63.230191815283995, 60.7428325376203, 64.07783169900218, 62.867050939990634, 66.21925753931846, 63.4219172693068, 68.91980940295805, 67.91670245508995, 70.46046149346137, 63.17131311662736, 65.15493416017102, 60.81334106383785, 67.50258645703717, 63.10864933075444, 74.66804289048719, 78.01100054094869, 87.83638092779344, 78.18718556434878, 92.04232277408724, 80.01873631631175, 109.8909584168465, 31.72938592972294, 0.5074293989567987, 0.24172438158383294, 0.22041846517353292, 0.1902794477439696, 0.14290731310123397, 0.1650385053888444, 0.5742666173365809, 0.8806242589508334, 0.11436769573558724, 0.07114678471078796, 6.05238534750477, 32.7472625624749, 31.328717777805945, 48.59483242034913, 28.453263505812618, 38.60882313020768, 46.612172357497684, 64.19132940230831, 74.11141149459347, 73.36869501298474, 68.52681144591301, 15.829734840700704, 0.24567287535436694, 0.11329537948533414, 0.04885783576737008, 0.12182759947233623, 0.05426380032252881, 0.015381383108756235, 0.021536775091062152, 0.031509839839512305, 0.06659383990711744, 0.026637750467465773, 0.07016001749903926, 0.013149768985327215, 0.05937402429539831, 0.011843018338925416, 0.07907478349103082, 0.06888061236109465, 0.014120349716845781, 0.01560846976410117, 0.13086578988980863, 0.21195190658252086, 0.18000458457296897, 0.0779348676423392, 0.2373346211689134, 0.2431375226907192, 0.10756435233258432, 0.21657140144417364, 0.18901336487502823, 0.2591747460105727, 0.1824555296691195, 0.2309891608573737, 0.15298936726345172, 0.20256498528103675, 0.19520753814328104, 0.4765169544806404, 30.914956754253758, 121.50714397430421, 113.51958228695779, 106.15279843730312, 77.88574357186594, 42.51751599773284, 45.36603535375288, 151.81831852082286, 132.05763724542433, 120.42137699742472, 74.79495509978264, 1.1447412833090753, 0.20807075194053112, 0.2632638782022461, 1.592114567756653, 1.2818389073494942, 0.8776389675274973, 0.28989956023231633, 0.6457215379322729, 0.6984288161320071, 4.0810197495645095, 109.55459948508971, 115.36243730975737, 108.65924004585513, 102.48175021140807, 99.04817796522572, 96.91615796858265, 88.57077413989653, 83.85107240369244, 85.119488470016, 80.27371391173332, 83.46798235370268, 78.66304751365416, 77.94495567198723, 75.99192127104729, 75.63631134648477, 72.87077365383026, 77.88256645202637, 72.79780187914449, 72.14498612188524, 71.94846753151187, 74.45116719891949, 75.07822082888696, 73.97375199102586, 75.09015267895114, 70.70906131498276, 70.02427039607879, 68.95195714889034, 69.49984165929979, 68.22144708325787, 70.70595479780629, 71.54359263758506, 71.01459826192549, 84.60051967251687, 91.43313946262484, 94.68958531656574, 91.42153709165513, 89.47277022946267, 81.8393515002343, 74.19389109457694, 72.44026999319755, 82.73540912135955, 82.98650357031053, 86.75880385983376, 84.02662984786495, 79.34865428555396, 75.67820225992511, 67.33341463150518, 66.15756650124827, 80.84721934410834, 85.26522021139823, 90.29151793449157, 73.00799385193856, 65.26402311940348, 90.60806105213781, 77.33442306518555, 76.49554575643232, 83.98622943509011, 88.34247650638704, 83.6158400197183, 84.81226490389916, 83.31191908928656, 87.94397154162007, 84.75612794199299, 87.46291637420656, 84.11086666968562, 82.29856691052838, 75.74732226710167, 66.45761212994977, 71.1588316579019, 71.08125502063383, 65.65735055554298, 67.49438085863667, 68.59255821474137, 71.55595594836821, 69.37365116611605, 70.29583177258893, 62.19967534465175, 66.46483713580717, 64.31567245914091, 67.37120274574526, 64.24986685475996, 69.16427504631781, 66.44145196483981, 76.17381726541828, 71.82265358586466, 75.52788134544127, 68.31950633756577, 69.27018688571069, 64.34558053170481, 71.56957441760649, 66.74908345745456, 77.54246557912519, 79.89793515974476, 92.6685840852799, 79.77469428893059, 99.59528584634104, 82.33812793608635, 116.52749107730006, 28.87027813542274, 0.7044462222726114, 0.40516211561137633, 0.27011696369417254, 0.4406356637275988, 0.21672821964227387, 0.4597134287318876, 2.0228433969520756, 0.52864252679771, 0.23050462556702478, 0.27248304157007125, 11.41704192084651, 41.54476427262829, 59.90045647467337, 112.9486656188965, 30.497987231900616, 36.477803337958555, 57.4044797497411, 80.67046949940344, 89.79783273512318, 88.66296552842664, 84.51520812126898, 18.905043678898966, 0.7163015248314027, 0.16731268335734645, 0.12850141272910182, 0.14762667518469597, 0.181393992275961, 0.11624782871935638, 0.1485189837553809, 0.10051576886326076, 0.17507923676842646, 0.20406881587639933, 0.23057052445027137, 0.10417380805818305, 0.2537871560742778, 0.14679153209492085, 0.2200123006778379, 0.14703815111950522, 0.19203112310459539, 0.12071141702753883], [0.12143894774659027, 0.029680073306324984, 0.03577885713668601, 0.02358622691263595, 0.022305122974719253, 0.006769722676835955, 0.03156622199551954, 0.07850353470853261, 0.06565659261879421, 0.0802567499058862, 0.11457028768716321, 0.07654283991864613, 0.04684410471048567, 0.042022125149566325, 0.14184091871063556, 0.7371165627433408, 42.88217875265306, 86.59744539568501, 64.08213846145138, 60.81211728434409, 49.80063961398218, 41.679521222268384, 58.39569014887656, 88.9805833755001, 97.79381967359974, 79.26105991486581, 14.26564854960288, 0.08251657904756647, 0.07605380769218169, 0.3288018114624485, 0.4955296939419162, 0.7271212603776687, 0.7008755171010572, 0.7146138637777298, 0.2679607326224927, 0.13814152608956062, 57.25971291142126, 113.85999694947274, 97.10098789584254, 103.67775147961032, 86.81644701188611, 85.62526241425546, 75.98271939062303, 78.05158138275146, 83.22510134789252, 78.6036471397646, 80.95487271585773, 86.5131458159416, 81.17268977626678, 79.41665249486124, 71.72628879547119, 71.69802419600948, 69.59548473358154, 69.27025748837379, 67.7328295861521, 66.71142085905998, 65.32468649648851, 65.16703467215261, 65.51953415716848, 65.34796968583139, 64.65291392418646, 63.31340097611951, 62.41024386498236, 63.550559243848255, 61.600501921869096, 65.32855395347842, 61.59059401481383, 62.59068858238959, 67.79653672249087, 82.86582792958906, 85.46313516555294, 76.6498282647902, 77.72034506643973, 79.98038338076684, 73.23901361034763, 63.56190666075676, 66.14346165810862, 74.98490764248756, 77.81354058173396, 79.63610126126198, 80.27696947897635, 85.47705173492433, 77.09276583886917, 68.91928380535495, 59.3437623208569, 76.2557634230583, 75.30634587810886, 79.95421332697715, 62.10152195345972, 66.58782697493031, 82.94122372904133, 70.05656719207764, 70.5935396686677, 78.31536077683973, 74.66584636319068, 79.2403341108753, 80.54700113111927, 74.14884659551805, 75.65604871319186, 73.57815742492676, 69.81310567548199, 68.84999905863117, 67.47367074412685, 63.49379078034432, 60.20852335037724, 61.62820954476634, 61.89629570130379, 61.34298263057586, 60.15789339619299, 58.34713120614329, 63.3610224723816, 66.05831484640798, 64.69098444907897, 60.12042299393685, 57.738500948875185, 59.31643909023654, 60.30841435155561, 60.09508448262369, 58.07525996238955, 60.36449247790922, 60.30457042878675, 59.65852468244491, 60.30940671120921, 60.05191095413701, 59.325735107544936, 60.89613837580527, 60.068047585025916, 60.546043303705034, 66.58654043751379, 76.11338923054358, 77.35601179061398, 80.04875813761066, 79.48857307434082, 82.87972880947976, 87.665969633287, 78.28699419575354, 0.5891545861959457, 0.08635470253084937, 0.1169831428917185, 0.21694168238149536, 0.029682287300426154, 0.18562727157146702, 0.4517865637617727, 0.7999474170707888, 0.05709056134125399, 0.0597626798515839, 0.15370360635701688, 19.257594154727077, 27.043079253165956, 58.93166242107269, 49.599045476605816, 19.610250534549838, 31.65490012015066, 51.31061092499764, 51.77915373156148, 67.32404016679334, 53.283355236053474, 43.43164397824196, 9.110813775370199, 0.09402819924176702, 0.026290193613198017, 0.03363142841525617, 0.005360861128616718, 0.0359426160913802, 0.04975868238797111, 0.055466462602658625, 0.08131926789158776, 0.03642116057416124, 0.03530279477877963, 0.048835806909107396, 0.021010225623725884, 0.03785676720942702, 0.04168253369449128, 0.03147292780810066, 0.03425955539569259, 0.0383949363153548, 0.13412857368107767, 0.011268354719504716, 0.039010656501857505, 0.011118429397503215, 0.012467640467108259, 0.017463278753923315, 0.02622874761601129, 0.0976049105426477, 0.10351265119689126, 0.02537676016800106, 0.021210708918290275, 0.05818006860452795, 0.05216219898072943, 0.025197248530363845, 0.10022418813840037, 0.5439524568857685, 61.14311433607533, 99.45956399363857, 78.77306215224728, 75.1326790163594, 59.71154728243428, 49.43644754348263, 59.44318263761459, 86.3705990391393, 107.53493970440282, 92.4022473058393, 17.255620341147146, 0.2108224325122372, 0.16127345903265863, 1.3406981167293366, 0.6647423366385122, 0.8611275051389972, 1.104939399707702, 1.3420100269779083, 0.5053648839314138, 0.5068676113601654, 70.49756711529147, 119.43661105248236, 104.75559526874174, 104.58017118515508, 90.61716879567793, 89.92871438303303, 80.58223970474737, 81.65241133782172, 87.44213565703362, 84.19838259297033, 85.44422934132238, 90.84424264969365, 86.63789287690194, 83.21498947758829, 76.16683544651156, 75.65741369801184, 73.23420478451636, 75.55523595502301, 70.89813524676909, 71.54880938991424, 69.07246020532423, 68.94742288897115, 68.43341981211017, 70.08553781817037, 69.45378518873646, 68.15240552348476, 66.17632327541229, 66.53147820503482, 65.57014057713171, 65.73118525166666, 64.50489544099378, 66.91179121694258, 70.93363269682854, 85.68394891677364, 88.56782451752694, 79.61298281146635, 81.44037585104667, 85.17607258212182, 78.55342511207827, 67.34152609302153, 70.1982432027017, 78.64260412031605, 82.01377145705685, 83.20901178544568, 85.18469395176058, 89.3094898039295, 81.24788945721042, 74.95786682251962, 64.3891227629877, 78.72287934826267, 81.39360550911196, 83.39682271403652, 66.39331663808515, 69.73661161238148, 85.67124043741535, 73.81859871648973, 74.65950781299223, 82.4629455997098, 76.12885905850318, 82.51128488971342, 79.64945300932854, 77.92786198277628, 76.77253569326093, 76.28888391679334, 74.48346399491834, 73.03678404900336, 71.12779786509853, 65.71368755832796, 64.99292850494385, 64.63329815095472, 64.67384761379611, 64.08292685785602, 63.14237386949601, 62.81471475478142, 65.7673102809537, 72.51361831541985, 67.97906814082977, 62.61500727745795, 59.69434376685851, 63.14562551436886, 64.35139348430019, 64.57767894191127, 61.27286634137554, 63.28498732659125, 64.96222811360514, 62.66695907039028, 61.384214585827245, 64.36438829668107, 63.528880303905865, 63.6577497759173, 63.58761387486612, 64.96693495781192, 70.01397025200629, 82.08147941097137, 80.53369645149478, 84.46800631861534, 83.04746504752868, 86.5241284524241, 88.22440531945999, 86.1995287864439, 1.403070666616963, 0.15495297318745047, 0.07832506686569222, 0.6620918562816036, 0.3920470274263813, 0.8535598434748188, 1.6417325504364508, 1.5388877593701886, 1.1527006304071796, 0.14298012209755762, 0.042353446685498765, 21.268501166374456, 35.550719768770286, 43.47350351272091, 37.10382930694088, 25.582347416108657, 37.703077254756806, 64.73518956092097, 62.780903923896055, 80.18949277939336, 68.29729787765011, 54.48774253168414, 11.590724472076664, 0.061441358524344625, 0.09091071934709627, 0.037540028157133254, 0.08571641339409737, 0.038710296409384864, 0.024588901940132343, 0.02660685222625973, 0.019793664593429818, 0.029145016432589585, 0.04315377107911533, 0.03536836041377918, 0.058041632686170845, 0.05475725287631635, 0.017301356495027582, 0.03394929744723824, 0.1320689769401666, 0.042224119552561355, 0.2468879674110682, 0.1408755100302158, 0.1094013928706127, 0.13276204136350464, 0.22677072834584022, 0.1177077854592954, 0.1263280366096766, 0.14974694608921005, 0.2208225152665569, 0.20814294806651532, 0.1861087425101188, 0.13121449779118263, 0.1537773806241251, 0.22991832315681443, 0.2722651661644059, 1.0432472584709045, 82.01385774920064, 118.52149855706, 93.40742526515838, 91.58204832384664, 74.74696097835418, 57.8382585894677, 81.64012647444203, 111.23136566531275, 114.97900993593278, 109.39373523958268, 23.38083870949284, 0.2872996416784102, 0.21380815294481095, 1.6477167390046583, 2.8805663460685365, 1.5228609548461054, 1.071826873287078, 1.953491969935356, 1.493595660694184, 0.5062188268188508, 67.02607339428317, 122.40982255628033, 107.66599393660023, 109.95435176357147, 93.40446779804846, 93.75796748745827, 84.32715400572746, 85.86739816973287, 92.87307293184342, 86.85883998870851, 88.96854954381143, 96.08365058898927, 89.66463688881167, 87.7756469480453, 80.2206991564843, 78.74147138287945, 75.69796316085323, 79.37166290898477, 74.6266540404289, 73.82165816522414, 72.88943629111014, 73.29773149182721, 71.0918140411377, 73.08163242955362, 74.33648493982132, 71.58248686021375, 68.15737124412291, 71.67529013849074, 69.04756884421073, 70.60864863857147, 68.05230663668725, 71.53933294357793, 74.1508234700849, 89.30297866944345, 92.46739002966112, 84.15154949311288, 84.0990524907266, 90.21964442345404, 83.22699977505593, 70.48987142501339, 75.97351751019879, 84.13109825503442, 86.69051539513373, 85.68205048961025, 87.54071266420426, 94.09450684824299, 85.54537942332607, 75.03397649334323, 66.23843008472075, 84.07132133360832, 83.21202416573801, 87.13426882220854, 68.05782148914953, 72.88279179603823, 91.4519040815292, 79.21052409756568, 78.58891471739739, 86.69462603907432, 80.1044636387979, 86.86525698631041, 83.5617583797824, 80.99888955393146, 81.18972070755498, 78.6823534196423, 78.9023748520882, 77.45021143267232, 72.9243532303841, 69.12778915897493, 67.12277550851145, 68.07741765053042, 68.85025793506254, 67.74815036404517, 66.20122248126616, 65.51697284944596, 68.25233182599469, 75.62289684049546, 72.50279257374426, 66.89990643532046, 63.22365322420674, 65.55276447726835, 66.25689660349201, 67.2271340893161, 63.80629777908326, 67.06699155992078, 68.0078818721156, 67.17771222514492, 68.36899095965971, 66.36413420400312, 66.7832394569151, 67.18049710796726, 67.12686261823102, 67.89862817333591, 74.16325738353115, 86.35626669852965, 84.24669050401258, 91.058560955909, 87.05373471783054, 90.16927334570116, 94.41539595204016, 86.93163133436634, 1.4688994374967392, 0.2092925396056906, 0.3247199111407803, 0.6136183476736469, 0.4932372524372993, 1.1098949466982195, 1.6847980911693268, 2.7901868474098945, 0.8739689773609562, 0.22330627956938362, 0.3796335225624423, 32.479266620451405, 46.25175360710391, 81.48469078925349, 67.34569165014452, 28.60188211164167, 47.27102464245212, 76.34992384141492, 76.27299831759545, 94.76780522254207, 82.17015635582709, 65.11975442209553, 14.979850380651413, 0.27597667829644296, 0.17931004926081628, 0.08435525135287354, 0.19956657843243694, 0.2529520436280197, 0.2400799585326064, 0.14765734934518415, 0.11918648070986233, 0.12508740318157982, 0.1415280790458764, 0.10989992458733822, 0.1518177583573326, 0.08667077508664901, 0.16157520574427423, 0.29963451527780105, 0.2200203752445598, 0.17881774583891516], [0.009564728393489796, 0.02531861409454817, 0.09569994098837338, 0.1115005120875374, 0.08946691940148031, 0.120309833737631, 0.03792171614364751, 0.04806883415327438, 0.02923782032373692, 0.08519995521994368, 0.1387688754907539, 0.03783272737036309, 0.0826317373843443, 0.09488169779820789, 0.3975703987863756, 8.845007496495402, 79.78131524978146, 79.25137166054019, 73.23073740928405, 51.5028109858113, 36.059878718468454, 35.47922280526931, 65.91404222672986, 104.21121735726635, 100.90041529747748, 46.0470490301809, 1.5748804086639037, 0.06030577107242519, 0.11229882166991312, 1.051777065280945, 1.5590613671848852, 0.39863455620023514, 0.2985381208840878, 1.6931489398402555, 0.8847733298617025, 15.509681201750233, 111.86785651791482, 100.98459720611574, 102.51986780474263, 86.12702769617881, 82.90725600334906, 80.2981424331665, 83.41748576010428, 81.89630431513633, 92.01485833814068, 91.09381521901777, 93.15558556587466, 91.61195247404038, 89.57124525500883, 83.76659239492109, 83.517270857288, 79.14509111835112, 77.1138289666945, 74.01419162750244, 73.51874136155652, 67.41014403681602, 65.31643382964596, 64.61920507492559, 64.59610231461065, 67.16379565577354, 65.20908248039984, 61.2317559795995, 60.39289828269713, 59.54025345463907, 59.135457008115715, 60.64558521393807, 59.174731700651115, 62.58911178958032, 64.10910475638606, 79.46070855663669, 82.67533409980037, 83.50031837340325, 82.93997641532653, 78.98147336898312, 73.49527774318572, 67.4922392445226, 62.17614112361785, 65.16609330331126, 69.09580615258986, 75.65790791665354, 77.87107390742149, 80.64097327570762, 78.7593024776828, 79.67687822157338, 63.26232779410578, 71.27055644989014, 75.76161538400959, 75.31393174202212, 76.21223295888593, 74.48763739678168, 77.01894683222618, 71.75745594886043, 67.3574116922194, 75.72419597256568, 74.36071734274589, 78.30313082664244, 72.82309332201558, 71.74133500745221, 68.0066345584008, 70.07964641817155, 66.43750606044647, 65.97589015960693, 62.0240943662582, 60.702067344419426, 59.30670768983903, 58.31136703491212, 57.32117252965128, 60.04327781738774, 56.14739933321553, 60.06189338622555, 63.618702580851895, 65.9531561020882, 65.57675761561241, 62.9467103558202, 58.522402317293235, 57.019220629046046, 58.93411782480056, 59.68136072158814, 58.21661826102965, 62.050362479302194, 56.55980517787319, 58.64131289143717, 57.89305802314513, 59.10878096857379, 56.20135153493574, 61.23882016827984, 58.64001458691013, 59.08325026112219, 62.38483867337627, 75.47510977714293, 70.61570890488164, 79.74452341756513, 73.25829598211473, 85.26667933310233, 78.1366026786066, 106.473248235641, 16.51255672977817, 0.9205089413350629, 0.05570406094193459, 0.033695538483199575, 0.23481819087699538, 0.11855143212503004, 0.18590157701363488, 3.040404646627365, 0.3783994468469774, 0.14024777758506038, 0.6014229633635091, 4.1853038053358755, 26.509276051675123, 29.48212081386197, 86.78699785663237, 32.17168023509364, 34.87320092416579, 19.027319646650746, 44.797146551070675, 55.97649774243755, 60.30583343198223, 53.51516339086718, 38.75686906999157, 11.214002390061657, 0.18456993234013358, 0.04274690561296959, 0.07379217824387936, 0.08993714416940367, 0.03139075338690272, 0.017723804189553185, 0.014857354070690852, 0.06685623268206274, 0.009962558810178553, 0.025566531638164195, 0.017814158514562636, 0.019418425152018186, 0.04895285365261859, 0.024458910225920623, 0.03466468184225021, 0.1211176428102678, 0.031250078576586904, 0.015497518207637534, 0.04739761472709718, 0.051503757901129224, 0.008827776708189518, 0.026175138698289954, 0.03000894910655916, 0.039451141736560294, 0.0022252275835677625, 0.04665786873609309, 0.10684791456667647, 0.090054715683143, 0.13287113228392217, 0.18335798124392189, 0.3679969840713086, 11.848653651052906, 97.69509361636256, 92.77438609830796, 88.57288437504923, 63.74004502450267, 46.51045353181901, 40.37127740921513, 53.612034167012865, 108.96367088440927, 114.71873714077859, 53.48105838221889, 2.076129653761464, 0.5545095774915911, 0.6848799689642845, 1.2372078506215927, 1.105706958520797, 1.2135829247774617, 0.8296623741907458, 2.342615483268615, 0.46536179499760755, 22.236926517178937, 121.1858077203074, 102.93714523315431, 108.21696142996512, 87.9961782886136, 87.0784221156951, 83.16770922753119, 87.57344092092207, 86.94678737271218, 95.29021001631214, 94.14852573025613, 96.67213163068219, 93.35656781350413, 94.18474489642729, 90.18113459310224, 87.59789297657629, 82.049284596597, 82.31799048762169, 79.0980697447254, 79.82315909477973, 69.69716041318833, 70.50715338799262, 66.24800851268154, 69.19237490623229, 69.54684734344482, 68.61207592871882, 63.88028937001383, 64.15939346436532, 62.6373294861086, 62.14272252974972, 64.25986889869937, 63.52762906782089, 64.38376480533232, 69.68111007444321, 81.27837411818966, 86.9949697679089, 86.81981240549396, 85.50224119617094, 83.40638545251663, 78.99862981611683, 72.21085840655913, 65.54309583479359, 68.85022655610116, 73.23274566281226, 76.22977379829653, 80.9023129555487, 81.48265115676388, 83.51358382932602, 83.05090888853996, 68.54104180489817, 72.72213151378017, 80.78757578326811, 78.78926938579929, 79.1452637026387, 79.35735410259616, 80.87928079789685, 75.59394974862376, 70.77534152615455, 81.07028453580796, 77.02559132729807, 81.22642624762751, 77.16781646974626, 74.55473346094932, 72.71804440406062, 71.67448997497559, 70.26767699949204, 69.36718710007207, 64.25354211561142, 61.802119593466486, 61.804096468033336, 60.76280524653774, 59.501594574220725, 63.08665267882809, 60.22931583466069, 64.13523558647402, 67.32219665281235, 69.08545109533495, 71.06021542702952, 66.95646701320526, 61.18589954991495, 61.450228075827326, 61.327014661604366, 62.388396263122566, 62.09905478262133, 63.17253297375095, 59.73454806112475, 61.75649458362211, 60.93933151614282, 61.89698603845412, 60.05121669461651, 65.50354265397596, 62.69270550820136, 63.71041936259117, 67.38279727197462, 80.60986103550081, 75.85224566921111, 82.90780513517319, 75.24387036600422, 88.6670369486655, 80.00802040100098, 110.03080660297026, 21.3521731668903, 0.8102623926055047, 0.09406994337276106, 0.9602242876445094, 0.7740359332772994, 1.0159744670794857, 0.6259355093202283, 2.6255375146865845, 2.040708812494432, 1.01008839905262, 0.5241191146835205, 3.050455475045789, 35.92201525165189, 31.499217325641265, 55.086566863521455, 33.447858671988214, 48.9216717596977, 28.44890379136609, 55.956274001829094, 70.15907441416095, 74.82896204917662, 67.5983315129434, 50.7720341990071, 13.789470849498628, 0.2721157790191712, 0.08574481993432968, 0.025005772514569185, 0.0730689759216001, 0.039381929523041176, 0.017696521883349747, 0.044851310836571845, 0.051009868677224846, 0.1153437530381545, 0.02387643059445245, 0.03876785259513605, 0.022781765644228267, 0.034452789583273476, 0.04387715726249641, 0.020370998029266636, 0.060410885996515715, 0.1025445382260988, 0.1059023705461333, 0.19818830964786394, 0.23155942138644958, 0.14000570912274624, 0.1349275727425852, 0.11332996069423615, 0.21518079864401973, 0.07113496397411631, 0.2044101846554587, 0.21555598254405686, 0.18990863054510088, 0.3722626229207362, 0.30104240102152674, 0.6737322864993927, 17.55733689954204, 117.51606172130955, 106.42773305216144, 104.5644973939465, 79.55486113025297, 54.90480030736616, 48.88860225677491, 88.25550971492645, 128.78858489374963, 123.41158020880916, 67.28491060195431, 3.2970367468172506, 0.47301651489350105, 0.8214218421809135, 3.9761868071171547, 3.6086036024555086, 2.126541916401156, 2.1149606281711213, 8.19139696897999, 1.4751872420310976, 19.818638217064645, 123.65729316588371, 107.36808207727249, 114.81447435194447, 92.6118273888865, 92.13192539830362, 86.28356948975595, 90.26622649162047, 89.41997512694329, 101.19433418396981, 99.0045847431306, 100.36013234046199, 99.56922561891618, 97.10181943831905, 92.72933375450873, 93.18192035921159, 86.79824721428656, 85.68507071464293, 82.35064029693604, 83.96631163935508, 74.5889679078133, 75.19538987067439, 71.34751335267099, 72.00535758849114, 73.75843740278675, 72.01942320792907, 67.79666223833638, 68.75823913082, 66.13686423147878, 66.82132567128828, 68.50657201582386, 65.82987600757231, 67.49815417874244, 74.17457734384845, 86.44726568652739, 92.02821793094759, 89.90165002884405, 90.7219353029805, 86.58259530221262, 81.68841085126324, 74.92207127232706, 70.85680130989321, 73.84187406109226, 77.40905792482438, 82.12067173373315, 87.99460934054467, 86.73429689099713, 86.40398625404605, 86.84699443078811, 71.50215671908471, 78.75591354985391, 84.76838927115165, 80.94186613636633, 73.50285576235864, 75.80902899465254, 82.42328259252733, 82.41356295924034, 74.33061707404353, 84.95955774860998, 78.66196493948661, 85.224333424722, 80.6048325569399, 79.13879963659471, 75.71275049640288, 76.68580424401068, 74.68046895919308, 74.0901836272209, 67.5105567132273, 67.1021830651068, 64.84325870390862, 64.90971934410834, 63.969519369063846, 69.0029401163901, 64.43364950918382, 66.8696100481095, 72.05428523402061, 73.49272820257372, 74.33146430600074, 69.2847075000886, 64.91704240922006, 64.24150828392276, 64.96052580495035, 66.52790100343766, 64.39920717670073, 68.03335374401462, 62.91918316195088, 64.2438538612858, 65.22552113379201, 65.44655846011254, 63.57700778592018, 68.27178678204938, 65.26423492739278, 66.12168465891193, 71.57526185435634, 84.44055757214947, 79.88961973497945, 87.79172082101145, 80.18669220709032, 92.83111926048034, 84.32376507789859, 117.65186986615582, 20.282880144734538, 1.0310690345302707, 0.19261232336923, 1.1782433501174374, 0.6349936103628528, 0.832419861708918, 1.5518841652139541, 7.3986212380470775, 1.5810848628321004, 0.6680332052130854, 0.8469969214450929, 6.861763000488282, 45.48284353748445, 46.709372612737845, 112.49360792098508, 45.69899359057027, 50.10290922657136, 33.15755621079476, 69.5306714888542, 82.10726507248418, 89.51233125502064, 81.95534383097004, 62.33326735035066, 17.33594459872092, 0.6710503658940715, 0.20383382606650555, 0.1661310233776608, 0.23836917694537874, 0.07853581765366179, 0.11352008839528407, 0.20034495440702285, 0.11939128665553948, 0.17631516641666814, 0.10938099961006835, 0.092662455994756, 0.1331927513162936, 0.12773779160793752, 0.23123089224100116, 0.14187764496572558, 0.16756339329144648], [0.13252460007225314, 0.08703574703465547, 0.04545091636358731, 0.054552918074712645, 0.03198363457716281, 0.08996551240523977, 0.0420335743335947, 0.0203464008612378, 0.10970805786670217, 0.06587494299897263, 0.1357676494385927, 0.02656552561318442, 0.1227843436983324, 0.10241477825348416, 0.20798491944949474, 32.58657286244054, 84.97833805699503, 73.56471938471641, 67.56878822080552, 36.442929544756495, 38.679688592110914, 55.62550444756785, 95.19146826959427, 88.70626849512901, 78.28114986419678, 16.624330551393573, 0.052710855830340624, 0.10972845112724651, 0.4255326693096469, 0.6274553051879329, 0.5713972196944299, 0.32406401730352835, 2.289861810784186, 0.8517840516663368, 0.39306181813440016, 59.56611364118515, 112.35531299344956, 99.63259543142011, 92.83792065035914, 80.59969425201416, 84.33150783661874, 85.34027868701567, 89.43529590483635, 92.32689857482912, 92.34171728934012, 91.76977296029368, 92.75478993692707, 90.22988965434413, 94.05458496462916, 94.69870874958654, 93.41058669551727, 88.21798832185807, 85.1746448393791, 83.61099981492566, 77.48261021029565, 68.83647472627702, 64.78481931071128, 62.290595885246034, 64.30935744316348, 65.38540870912614, 60.081544460788855, 57.73850879361553, 59.4857011302825, 60.12209784600043, 60.24035338432559, 59.82500183966852, 62.28301394370295, 61.7452177693767, 61.24465665509624, 70.25692970521989, 75.51269392813407, 82.98202422357376, 80.74806967089253, 80.84989440056586, 76.46834019691714, 72.76610912815218, 62.404089666182, 61.287351654421904, 60.376651825443396, 66.73701040206417, 74.696150595142, 78.24694679629418, 81.44964833413401, 78.44435968706685, 65.69384036525604, 67.56142985436225, 75.88355402792655, 68.34853972158125, 92.84607133557721, 82.43349644445604, 75.61614251905873, 69.44970592375725, 71.18199717613959, 73.37122886411606, 79.33735001471736, 77.85565899264428, 69.09622976856848, 64.36892647897044, 61.55948569697719, 60.70523661951865, 59.00137078377509, 59.70544407444616, 58.223403961427756, 58.1990852663594, 59.49736625917497, 60.56113658412811, 61.22125579464821, 58.874599779805834, 55.6342670225328, 56.24730602387459, 63.819912325951364, 67.88088337067636, 67.92505710355698, 64.63229010182043, 59.8697913846662, 58.084312792747255, 60.67623461446455, 57.98738318104898, 60.05404864588092, 60.22354995050738, 61.0764693444775, 59.45079988048923, 57.57022342374248, 57.51964446037047, 58.90207598286291, 58.9549259985647, 59.7473349878865, 60.41841330066804, 65.59032901640862, 75.07476914313533, 75.3142455316359, 76.786240454643, 77.27240254802089, 85.32661314933532, 78.86311977140366, 94.42609617787024, 48.748071578241166, 0.08317251118921465, 0.35345157908816494, 2.3620790195080543, 0.6504201696765038, 0.700958683606117, 2.203357613855793, 2.0529907340964964, 1.664075351530506, 0.3889357911482934, 0.30241734498450834, 0.1766193952531584, 23.014059835864654, 42.18786431897072, 72.85606476568407, 59.09403285672588, 8.360381991632524, 20.89827649054989, 46.82256829354071, 57.48526096343995, 63.361418631769, 67.9053040473692, 67.52229244478288, 51.375902698886016, 12.339767736773338, 0.380394033366634, 0.05054504482916767, 0.021899762871344725, 0.0794959020230078, 0.08276318275039235, 0.0399496887750443, 0.08764916129650609, 0.06065092815627014, 0.07591411155918915, 0.034019635810006055, 0.07430342702014793, 0.012415071513744132, 0.03406611053393253, 0.05247305830820434, 0.11141916121085806, 0.0631870354165233, 0.06070686406606148, 0.01587914586472776, 0.12522938991746596, 0.05884784446548551, 0.06436092343421713, 0.020557795163063754, 0.03900140599017182, 0.012832717752204308, 0.047240957407461065, 0.00935645685756519, 0.026007254360123508, 0.08782767510462193, 0.04394869455286572, 0.12549257942385253, 42.26340132374918, 100.6477754346786, 83.76762005590624, 82.91608918097712, 47.52597870365266, 52.86445002402029, 55.918179942715554, 70.09977602189588, 98.20788075847011, 87.36106026557185, 20.244744900734197, 0.22195873091057425, 0.42711454894273515, 1.5357442248252131, 1.4248284216850036, 0.9742592635654634, 1.3466531326693874, 1.0270221291049835, 0.10388756696615489, 1.4121268064745012, 71.25896192366078, 115.01831208505939, 103.28658919180594, 94.83366181773525, 86.88830483344294, 86.80857089258011, 89.52297656766831, 94.998730844067, 95.69321001729658, 95.29736441950645, 93.85787025574716, 97.17512853683965, 96.96150841251497, 96.69696023387294, 97.82777955455165, 96.14673799084079, 90.5161520742601, 90.68140937436013, 88.51655913937478, 81.0242437547253, 74.64938025320731, 69.39938191444644, 67.13938282382104, 68.8769849654167, 66.72739275040166, 63.60852795262491, 61.840845154177764, 63.64437841599988, 63.06785275859218, 64.80744746423537, 63.91217823951476, 64.52759027481079, 63.33112616692821, 64.74326179873559, 72.01932907104492, 78.28547231612667, 85.31539517064249, 82.84403524091168, 82.20155100668632, 80.8990260093443, 77.47078034185594, 67.3598357169859, 66.02579055293914, 64.3951004551303, 72.77880191802979, 78.22453437312957, 83.06747698014783, 83.77008330437445, 80.43895552235266, 66.83586981988722, 73.83284476495558, 80.81429496888192, 76.75829748953544, 93.65804118494835, 87.78655113712435, 83.3285342493365, 71.58751533877465, 73.43271593893729, 78.0123576810283, 81.12638227401241, 80.73485912815218, 71.98267059941446, 67.11193407735517, 67.9656301006194, 66.48000886363369, 63.91677917972688, 61.29183492352886, 61.07527694394512, 61.00847897991058, 63.08046710106635, 64.742155690347, 65.30920490141838, 61.578038507892245, 56.88685632521107, 59.98596414442986, 65.58490045609014, 70.2260684967041, 69.81413333646714, 68.88641434331095, 62.9759398583443, 62.373208845815356, 62.334950047154585, 61.789426803588874, 62.49208804099791, 61.18400896749189, 62.63546636027675, 61.899425752701305, 60.59029940635928, 60.8923101425171, 62.371137834364376, 62.29616172852055, 62.46162299186953, 64.8706486148219, 73.9909476618613, 78.53348378212222, 79.98742795759632, 80.76106056090325, 80.59417939955189, 87.2837346599948, 83.21138089702976, 96.5697342349637, 56.48487221810126, 0.027999287891772487, 0.730885755150549, 1.353144165008299, 0.8140520763493354, 2.4089221704390744, 2.342407842797618, 3.000914223732487, 5.866935685757668, 1.7536615508217968, 0.30987833656610986, 0.1665133778606692, 20.55653214454651, 56.424942324238444, 55.90713454831032, 42.38877988630726, 18.374454859764345, 31.42034434503125, 56.75746125559653, 70.58417304869621, 72.55325778838127, 78.99685690479895, 81.3027241922194, 65.19404411315918, 15.929355198337188, 0.478223032288013, 0.01813967310402903, 0.06945924623118294, 0.039086629441308404, 0.030225031866481712, 0.044318787798646, 0.05556585101951515, 0.015711687662969195, 0.01589028382553689, 0.027096524136140946, 0.029856714029465953, 0.037908907153553544, 0.020288986401752602, 0.009850732955871331, 0.11158632159593607, 0.21373364323329544, 0.15115247228212897, 0.13896652617521826, 0.3064148837039548, 0.13490367079934767, 0.2643539906749802, 0.09964560023358754, 0.17034804628741357, 0.1275301434760613, 0.15005987768452014, 0.1349001314731375, 0.1631357574895505, 0.22712305218221682, 0.2489264507687861, 0.22339427242836646, 55.90826026854977, 120.32121535270446, 98.13009231321274, 94.37077506895989, 57.72568656552223, 60.39696970293599, 76.5306745036956, 123.53575460372434, 107.84228094162481, 101.52058124542238, 29.572821701726607, 0.44422668555090505, 0.7922459045244802, 2.012072445884828, 4.425645566755726, 3.4249106722493328, 2.2264620902076846, 8.548964646554763, 3.5822072769365008, 1.198800124468342, 69.09207205618583, 119.84987981857793, 107.30654793400919, 100.81591959922545, 90.02002716064455, 92.40525184139129, 94.22086208097397, 97.34666162921538, 99.09876869570826, 102.57980946571597, 100.37813601955291, 103.8164072652017, 101.99889859845563, 102.74765553012972, 104.28950786590578, 99.12293049596973, 92.76916934597878, 95.07953951435705, 93.9830566221668, 84.26168180281117, 77.84010287254088, 73.63951113916212, 68.65193505440989, 71.922407304087, 71.21074814950266, 67.72039567270588, 65.8081146978563, 67.33765863603162, 68.13111489818942, 69.19927043299522, 66.1232457622405, 67.76174529906243, 67.99220808090703, 67.83962003646359, 79.16917447120913, 83.15518117720082, 89.94196414947511, 86.25182967032157, 86.45771488066643, 85.17153832220262, 79.15154733965474, 68.13735931150376, 67.08044528961182, 68.1019167746267, 76.54382228851318, 81.87997156573881, 84.77695572760798, 89.31349846624559, 83.61092921226256, 71.20744551381758, 76.0262498547954, 87.29555668369417, 75.41909048634191, 83.04623342329457, 80.60581314948298, 83.01986725099626, 75.95904396426293, 78.84026804277974, 81.55946685421853, 84.15649167952999, 85.9226094522784, 76.08416757275982, 70.35017228895619, 70.07397467090239, 69.19693270037251, 66.41200280958607, 64.63122321713355, 63.74510880439513, 63.9723317084774, 66.24978142399942, 68.31861203716647, 67.69621033822337, 66.9656296699278, 60.44829783901092, 63.62991663717455, 70.72854764999883, 75.02738691145375, 74.42980597096106, 72.0222080907514, 66.70312112377536, 64.50865307161885, 63.86994215749926, 65.71610373835411, 65.14884664166358, 65.47689014865507, 67.07783299107706, 65.295629578252, 64.60338223365046, 64.16659885837187, 64.49213989319341, 65.23214993938323, 65.87888210050522, 67.51764051375851, 74.73784539007372, 83.14245700836182, 82.18561833904636, 83.40072939472815, 84.54307263897311, 91.805858765879, 86.57583313603556, 101.42725236954229, 56.17261232868318, 0.10275596317144171, 1.441882642046098, 4.402115268092002, 2.6990282679757764, 2.665439786449556, 7.935216186508057, 5.075093478925767, 9.077737408299601, 1.182380102334484, 0.3614649813502066, 0.23888438639621581, 34.294121803775916, 61.24956746255199, 94.9382165170485, 73.72070420172908, 15.658111533811017, 34.56488693914106, 66.22395653878489, 80.15795692320793, 87.13146040516516, 93.32900924067344, 92.72956909671908, 74.97051254395517, 21.450506987110263, 0.5563380761492638, 0.09985720137915305, 0.18312974832952025, 0.24834688993230944, 0.15322097096472018, 0.175894231745793, 0.22179593722666466, 0.08993581883729466, 0.17993876229851477, 0.15158446926263072, 0.10718254943288143, 0.09039739447255289, 0.08246349681529307, 0.14992486234874497, 0.19429436133753872], [0.042921723046850775, 0.03672620146385124, 0.045930460591109536, 0.07299243607708523, 0.046144068887036656, 0.09850527835829605, 0.06798665670137252, 0.07554126422732108, 0.0645677365302559, 0.03609432065258584, 0.03468712821843163, 0.061181164421742006, 0.032679073873066136, 0.21248542553474828, 4.582110874114498, 69.4088662055231, 78.71843138048726, 68.67124880513838, 55.14273128201885, 67.83840410171017, 34.86140635705764, 51.282785630995235, 86.88082095115416, 69.15638323753112, 54.33721765395134, 2.916382488704497, 0.04504673220517655, 1.1318711287552312, 1.0716334514079557, 0.4687490374330552, 0.1333374500034317, 0.8543834799239713, 0.7279436710861422, 0.44593708409417065, 13.23698736006214, 94.45464318798435, 104.5894750472038, 99.93482974267776, 81.2827907070037, 86.43783630863314, 88.62430664800829, 95.5112434202625, 96.1890289860387, 91.00837815192439, 92.05993421616094, 92.91846259947746, 88.48268555056664, 90.44483553978705, 89.65363071810815, 89.07305717468263, 91.26454814787834, 91.8262472460347, 86.8489242369129, 86.52129650115968, 80.76306881443148, 68.08337965319234, 63.684645468188876, 64.63725582245858, 61.849490058037546, 64.84383136995378, 60.12079169673305, 56.38735425087714, 57.38653098383258, 55.06911231625465, 56.77609643628521, 60.358295133036954, 61.43711559234127, 60.74801006624776, 61.29904031753541, 65.45054751057779, 71.17415243579497, 78.89704827339419, 80.86454837552964, 78.65471639940816, 76.63480558703023, 73.86096031435075, 68.33892991465908, 59.79801593288299, 59.46591669513334, 70.91751960016066, 76.66581584561256, 77.09786492009317, 77.92799534336214, 75.75360590411772, 65.70817270586568, 72.89339004024383, 73.8311424563008, 63.02500870919997, 86.1886324421052, 73.11247794858872, 70.21324234624063, 67.81552099412488, 71.31938995853548, 72.94882882025935, 74.8251102816674, 71.16902197560957, 64.90733846541374, 57.90999481754919, 56.178056578482355, 57.71267606366066, 59.53661741748933, 61.4696006621084, 60.68094930341167, 60.753917155727265, 63.85924585403935, 66.40830793688374, 67.9291912817186, 64.02900211272701, 57.68017922678302, 57.543531694719874, 63.6944474712495, 69.3963695341541, 69.29383877784976, 68.51416572447746, 62.13628199792678, 56.249157382595925, 57.13533455325712, 58.420636423172496, 61.84843101809102, 58.641956160145426, 60.56228976095877, 58.10304603269024, 56.710706603142526, 56.24439954757691, 59.33796113537204, 60.200580550778305, 63.1994600449839, 64.3666358147898, 75.22925561474216, 73.78332091915992, 76.76793083067864, 76.2351474454326, 79.50099914304673, 79.95076164122551, 82.99598001664685, 82.94745245287496, 75.63770771026611, 2.9046903935170945, 1.5493634295079017, 0.21129204440982113, 0.9814822469507495, 1.7448402628783257, 0.26805854672866486, 0.842450465406141, 6.530517368547379, 3.1155023459465276, 0.21442586495991678, 0.2309207951710109, 4.343030154705048, 41.15763025899088, 37.21393416004796, 85.85803154976138, 46.67218854350429, 20.446772460014593, 28.309936177346017, 38.37209240082772, 42.595939866958126, 58.99295729975547, 63.073583341413936, 68.51014921742102, 54.099027802867276, 14.009717818229431, 0.05375434802244267, 0.05510274703884798, 0.09556887866628748, 0.033081894394971674, 0.07848920120346932, 0.03402201834345057, 0.08258523584734048, 0.036524145773822264, 0.16129490949453848, 0.10002346544135964, 0.023252756500075904, 0.11065172497183086, 0.11921468806723434, 0.01862465847103346, 0.05769296308919307, 0.04090229612624934, 0.06349573054561211, 0.1042851742597357, 0.026984098818032976, 0.014836901438332375, 0.10420746996157593, 0.07794369297522692, 0.02979974773141646, 0.09554089347441351, 0.08456630857601281, 0.06170015451648544, 0.04639486692124798, 0.26179381676258584, 4.882086880745427, 85.76187072261688, 90.52134529236825, 83.83221364790394, 67.87497628119685, 74.61166274163031, 43.668049150897616, 44.17498803907826, 83.77301723726335, 82.4048552974578, 64.27668017725792, 3.071744139156034, 0.07380121808138586, 3.140975933882498, 4.46733889079863, 0.9417193419029637, 1.667337415199126, 0.7192869388288068, 0.5252754784399464, 0.13265947751220197, 18.148881312339537, 101.00729203993275, 108.13022213597452, 99.91781450087025, 84.81539495529668, 92.35219786244055, 95.38254261016847, 100.4847695750575, 97.0093221049155, 98.44418002713113, 96.14538085076117, 99.35322069352674, 93.42072994478288, 95.64484719307193, 93.86012954096641, 93.44890040736045, 93.39361852215183, 94.92965006059217, 91.83472741034724, 91.08650392101657, 83.42857822295159, 70.9805913125315, 68.02368117916969, 67.42388802189981, 65.75067943142307, 67.9713410715903, 63.709003386958955, 59.77272056764173, 61.67916505567489, 59.400722980499275, 62.17821605743901, 62.43042445951893, 64.10304077209966, 64.60089937333139, 65.36386705213978, 68.99675846099854, 75.17398157427388, 81.62486060973137, 84.91575271852555, 83.30614536039292, 79.43435807381907, 78.25294802265783, 71.69995400213426, 64.3396734422253, 62.92009315183086, 75.43325024266397, 84.4069742387341, 80.60572685733919, 80.30659906325802, 76.87397603065737, 67.93124660368889, 75.55685981627434, 77.0079641957437, 70.8937971053585, 92.54470779049782, 82.95907051332536, 78.70421671098279, 72.93825411027478, 75.34994694494432, 77.67235878975161, 76.75020171749976, 75.4993421800675, 68.44575958867227, 63.04407142823743, 60.55913225297005, 62.110335519236905, 61.25076378545454, 64.43654029600083, 63.69868755340577, 62.65403093830232, 68.55646456441572, 68.69571655027329, 73.15756167134931, 67.98942319808468, 60.323880257145056, 61.34229229342554, 67.36324033429547, 71.161906796117, 72.63889097398328, 72.1712895362608, 67.66784375713718, 59.93808769410657, 61.87085128599598, 62.40243834833946, 61.679608283504365, 60.903437906695956, 63.57592128938245, 59.5998421022969, 61.362547412995376, 58.36167535474224, 62.77552635438981, 63.37210316811839, 63.059556945677734, 69.10463933021792, 81.5295313250634, 78.83549059590986, 81.82752947653495, 78.9081407362415, 84.85229661387783, 81.27012929608746, 88.51423709623276, 84.31527706884569, 84.03391761164512, 7.644171416759492, 1.7132476548994742, 0.6651487922476185, 0.6654958607208344, 0.9720018782442617, 2.264084484307997, 2.298444447017485, 4.2648362344311135, 5.189623255883494, 1.4463236230996348, 0.5159950893252127, 2.158025065737386, 43.187672553523896, 43.41194583523659, 57.68732186286681, 40.455635824511134, 34.00740831129013, 42.200600254920225, 49.80105930759061, 51.881045141527736, 70.57624986094814, 71.97929736106627, 78.31558042956938, 64.33053039735364, 17.59957298155754, 0.10782777166534817, 0.11025526681013646, 0.11830314302877074, 0.04765210913554315, 0.0434785119197782, 0.04092480761990432, 0.04547386452735913, 0.046120147791601, 0.05990238747589531, 0.026966925041990417, 0.019463574543835658, 0.036200086751412, 0.122213815038483, 0.05750745489832856, 0.23086932938425775, 0.1332557850307034, 0.17132111584707616, 0.18139817511602757, 0.161877274212818, 0.1751126228801666, 0.17905506455609876, 0.18330326724436977, 0.12197034463526742, 0.12290090397601167, 0.19843882039910365, 0.23301800682900414, 0.24594606230816535, 0.657317289902318, 8.042373868726916, 105.45547946806877, 105.39416497753513, 97.78031887546663, 81.58055351626489, 97.50922033863684, 55.89810917454382, 69.03790412410613, 109.81686484429144, 91.13085023818478, 83.96693921858265, 4.567957981940239, 0.21288553793584147, 3.4072036224026836, 5.2519207904415754, 2.6091562259581784, 1.7339754200750783, 2.7307783836318604, 4.835306732885299, 1.0112658455487222, 16.60326350119806, 106.15150405514626, 112.84429134861116, 104.27358304300617, 89.23818111419679, 94.4498343621531, 98.35862528893256, 102.86578947497954, 102.64517184226744, 103.1064582640125, 102.18063769801971, 106.33063870091593, 95.76380483565792, 99.61834153821393, 98.74551219324913, 98.29484754993071, 101.2812303727673, 100.68702267062281, 93.08157828546341, 94.28756590812438, 89.60183189761254, 73.65061929149013, 71.27927195641303, 72.29991189895138, 67.40243265705725, 73.70570505819013, 66.4618012212938, 64.82090119392642, 66.10268469779723, 63.302681138438565, 65.76774174167265, 67.14401122062438, 68.67240198196905, 68.351607015056, 69.71400307070824, 73.29974759009578, 78.70965311604162, 86.31814126045474, 87.91864087504726, 85.56931372611754, 83.79156220343806, 79.78501012248378, 74.33155059814453, 69.30104809422647, 65.65709167911162, 78.35586317123906, 88.7655511979134, 83.60328843516689, 84.80084296195739, 80.72667706397273, 72.071912365575, 78.73557998288062, 80.64520159075337, 68.9185542445029, 80.28157434155865, 72.76935685065486, 74.73441723854312, 76.25972501693234, 80.29827579375237, 81.26359462738037, 80.15356386861494, 78.61300591499575, 71.97539068037464, 64.37178196445589, 61.955303838176114, 65.50308373666579, 63.87522166775119, 67.39038313588789, 65.62736011320546, 65.5388988987092, 71.6290218599381, 72.58952402299451, 74.80030521269768, 71.49342552308114, 62.461352348327644, 63.48000364918863, 70.60790338823873, 74.5932903597432, 75.88870017759263, 76.13229505477413, 70.26548831693589, 63.73296906871181, 64.32461938550396, 64.51476804671749, 66.07514181444722, 63.227210813953036, 66.53312560050719, 63.69632236419186, 63.39904592883203, 62.22374693039925, 65.77125618534704, 68.08048494400518, 67.84267164045765, 70.25696108418127, 83.4890611710087, 82.08666478433918, 83.8386384902462, 82.98961008748701, 86.8180630283971, 86.34628034407093, 90.81716260602398, 88.50407031274612, 85.43302705211025, 7.645403040993599, 2.991592711017978, 4.440963893167434, 5.250218972083061, 4.851276663041884, 2.0896606051152755, 4.179848769018728, 12.71317933836291, 5.128942228132679, 1.335865756677043, 0.43832275235364515, 6.283696832195406, 58.77220238408735, 54.206336006041504, 110.18755235979634, 60.71025725333922, 33.27918890983828, 41.37468245721633, 58.21573572774088, 65.3198423693257, 83.05937336337182, 83.37739913694321, 88.9442700724448, 73.41520647848807, 20.886317183894498, 0.22028021694671726, 0.2563983667641878, 0.27647282747972396, 0.1606519012561729, 0.21345760643241868, 0.15651023075465234, 0.30324631340561375, 0.11682656984175406, 0.156926354393363, 0.20579153311348733, 0.19648984675445866, 0.1991716907509873, 0.3569293118292286, 0.17252641730010512], [0.17576955859699558, 0.021765435099481575, 0.029473225736329635, 0.13551792009703575, 0.18719628092742738, 0.13842012162410444, 0.10691861682120832, 0.11828009144312913, 0.08225479148208134, 0.14886736989982668, 0.07921938258673876, 0.15154555199607728, 0.07546963500640086, 0.7401869818568231, 16.967492834214244, 72.89704568924444, 73.24735256933397, 52.64952375042824, 64.90973503358903, 43.86643478947301, 36.78793338037307, 103.57405185699464, 96.40322962114888, 73.04226752250426, 25.839466625644317, 0.01087517062607672, 0.19045529556610893, 1.6151799429808895, 2.4117271554085518, 0.563346738776853, 0.4417822522021109, 1.588621206821934, 0.28800741498989446, 0.2587607520962915, 50.464689039414935, 98.75718516688194, 101.52007918204032, 91.15141130262806, 85.1105768449845, 91.20062135880994, 95.4371576924478, 93.74613761901857, 87.46352041921308, 90.65890281431138, 92.41849376309304, 93.81706191647439, 91.2222336184594, 94.6502596332181, 91.08342093806114, 92.47918851913946, 88.46840027839907, 87.74720976429602, 87.21219062805177, 88.41473440970145, 76.44294677242156, 64.30416030268516, 65.85779543845885, 65.99844378809776, 64.91505376754269, 62.79414192322762, 56.149513490738414, 54.09565064214892, 54.918195201504616, 56.697692178910785, 57.961169981187396, 61.39464809048561, 59.82041266656692, 62.109974661181056, 63.55521117487262, 68.58208548638129, 69.07650809134208, 72.88924801734187, 78.18377310229887, 81.84382300223075, 77.9019586501583, 76.30345944435366, 73.31851220900013, 61.159509843395604, 60.6769210292447, 68.97816642638176, 76.26850328137799, 75.17898651861375, 78.96004153836158, 75.64188111212947, 66.68097542178246, 73.1395423027777, 81.19641227106895, 46.56541770504367, 64.87945433585875, 58.1925388305418, 63.482298235739435, 68.87671824424498, 69.96883946080362, 74.34131729987361, 77.20744025322699, 71.16997118919127, 61.48858885611258, 53.8741151748165, 54.716738347084295, 58.14744726304085, 56.60542626534739, 61.74054622650147, 63.874127326473115, 61.739385204930464, 66.49552576003536, 69.20884886095601, 71.17861609305106, 69.01105942264681, 67.33368919741723, 64.11541584999331, 68.56242656707764, 70.78910120071905, 73.36325076318556, 68.19396695783063, 62.062462991283795, 56.48071058334843, 53.84505825657999, 56.59734618279242, 59.31358752712127, 60.42171985872331, 60.583282286121005, 58.06475193269792, 58.4524586123805, 58.02757570820471, 57.67853967605099, 59.80971244073684, 63.0549991515375, 71.60556608630766, 75.80938985270839, 82.14722617979973, 80.82883911748087, 77.3288611442812, 80.15113984384845, 79.87225932459678, 83.3465143942064, 74.51186195496591, 75.61709173264043, 53.584922744381814, 2.852712124586106, 1.1537072086526503, 1.192799510975038, 2.2708189487457275, 1.1014351296809413, 1.2102047834665546, 4.490384286449802, 1.3238380536917718, 1.3016521474046092, 0.44171943299231997, 0.5033738520597258, 14.898795581633046, 31.376900173002678, 62.50334524339246, 71.64069483357092, 26.703245101436494, 12.994822186808433, 16.886629250741777, 29.049359829195087, 41.965501231531945, 62.495382831942656, 65.28809862752115, 63.61243855568671, 61.10678142116916, 2.753746557620264, 0.05918892596157328, 0.13537996298363134, 0.06014184357838766, 0.04054818730500918, 0.08172921686162872, 0.0924101755804112, 0.06528936071141113, 0.14808900924699922, 0.20219159402674247, 0.06541568861012498, 0.12255559750502149, 0.06305779638369718, 0.045037075666891, 0.10487558290122018, 0.04578033800146753, 0.04143680716233869, 0.09512589598495154, 0.03940912564435313, 0.07778217099727162, 0.027578175105454943, 0.018969070534372044, 0.038467044341227705, 0.08726417147103818, 0.09698919035614499, 0.07826233958645214, 0.03710778602849572, 0.643127809368795, 23.254375611582113, 94.68505890138688, 81.77940983926096, 70.5802506785239, 70.3599468354256, 67.77375559653005, 48.38130251053841, 71.55039402746385, 104.74979016088672, 82.14060521894886, 29.274474459309733, 0.13222924253392604, 0.7042607064208677, 3.820156392551238, 3.551200205279935, 2.516670414517003, 1.3607221841812136, 0.962017730118767, 0.39962455630302435, 1.0480542456911457, 58.73818366758285, 104.14646687046175, 103.96881488061722, 95.55429535527384, 90.65004610246228, 95.55607611133208, 95.89864023270147, 99.19678088157409, 95.87865967904368, 96.22233775354202, 96.34692791969546, 95.44975634544127, 94.50157826946628, 97.71375625364243, 92.51976151620188, 94.24319605673514, 92.94198113103067, 92.70197130018666, 90.44268608093263, 90.99940376897013, 76.74816992975052, 67.36658219368228, 67.37577622936618, 67.8585337054345, 70.13404969246157, 65.14513607948058, 60.693744074913766, 60.24511121934461, 60.35243511199952, 63.19001889997914, 63.14168745471586, 65.73549201411586, 63.78260666324247, 66.31635189056396, 67.19831251328992, 70.43755485165504, 73.47654450324275, 76.79093945410945, 80.74028768847066, 84.47476064005207, 79.13277487601005, 80.27281961133404, 76.53216500436106, 66.48280943593672, 63.8846000548332, 74.39361818375127, 77.08497601170694, 78.70023942762806, 81.36348170618858, 79.60462816299932, 68.12361532641997, 76.60325404136412, 81.50148637833135, 59.825656875487304, 72.67184672817108, 69.7785182153025, 71.12651132768201, 72.91271163571265, 74.86482035729193, 75.32754236652006, 80.50864819557437, 75.09637355804443, 65.8347789702877, 58.41174833236202, 58.09329109807169, 61.54270579738002, 61.589483984055065, 65.35235489568403, 65.68425801492506, 65.73624903155913, 68.98501488470262, 70.33769130706787, 71.95850095441266, 72.58182048797607, 69.75785516923474, 67.73084486684492, 74.08684176783409, 73.39948561883742, 74.87039796767696, 71.99342573842695, 66.32784443516886, 60.573527351502456, 59.20836602487872, 59.6084987732672, 61.44772168128722, 63.5576508891198, 62.696361157201956, 61.165907229146654, 61.282593819402884, 60.871348996316236, 60.90664248312674, 62.085977600466826, 64.59899310142764, 75.1895220048966, 79.18545230742424, 83.47126929990708, 82.5272960047568, 81.86825936840427, 83.80901675070487, 83.9838917024674, 84.07975442947881, 74.47524270703717, 79.04106201664095, 68.43343550159086, 7.736153939077932, 0.143749488878154, 1.3361594441436953, 0.7940734838766437, 1.7470371578970265, 1.2333375744281279, 5.839565876991519, 3.3474661698264465, 2.7526198567882663, 0.9436819978779363, 0.4658110902434396, 11.227740491590193, 42.76145212111935, 55.382246894221154, 45.58986540763609, 28.561213016510013, 22.115854717070057, 26.746430397033695, 40.38212668511176, 54.030096069459, 72.30092387045585, 75.19912396707844, 74.60996827771588, 72.54749974896832, 4.997444768105784, 0.09867625386123696, 0.09578850075242021, 0.038114073160555095, 0.028366960299712037, 0.05274062217663854, 0.07227142476626942, 0.06746218524753086, 0.055545181967318065, 0.05343381683492372, 0.06243647992490761, 0.05013047634894329, 0.05538287474924038, 0.023436292014535398, 0.23819034138033468, 0.0826616607786667, 0.09172521636731203, 0.2091630707464872, 0.17163102905596458, 0.3045704504174571, 0.25637995001048813, 0.21716803071960328, 0.1272550106589352, 0.2175357682450164, 0.40203451569522586, 0.2935082940084319, 0.28522771092191823, 1.0978786431012617, 31.060031498632124, 110.154675053012, 96.23091989947905, 80.34644249946841, 91.00434595538725, 74.22212431507727, 53.40987913070187, 130.36959817332607, 115.53343695978965, 95.23769732444518, 39.29282565270701, 0.12363264051776741, 0.37011708643647934, 5.467240281643407, 7.734025072666907, 3.2924157044579907, 3.1496245149643194, 3.68804017862966, 1.5158731298100565, 0.6916608276867098, 60.41728758042859, 107.93458215651974, 109.5470214659168, 99.88863991152857, 95.60134810786094, 97.83775021952968, 101.75505268958308, 106.04348982534101, 99.90343509181854, 98.19723544582244, 100.83738280880837, 102.56816787104454, 98.67283067395611, 103.88431133762484, 95.96652077090357, 99.70343343673214, 97.5647924792382, 95.95717768515311, 97.30923437303113, 96.25752925872804, 81.39369180125576, 72.53916863472232, 72.9771012644614, 72.76546585944392, 73.69342803955078, 69.72349520652526, 63.43015816903884, 62.9342842871143, 62.80077465118901, 64.01042576759093, 65.56737530616023, 70.99307229441982, 68.55481716894334, 70.26282894995906, 70.40286540985107, 76.66683566185736, 78.08979311297017, 80.33782112982966, 86.98638762197187, 88.82356305276194, 84.1244145362608, 84.01427438182216, 79.34209608262586, 67.13174204672536, 67.02168818443053, 75.56306500588694, 81.39993621457009, 81.88152482432704, 84.48180521688154, 85.66652574846822, 73.78205791596444, 80.0034704516011, 89.61194376791678, 55.02440514103059, 68.07684498448526, 64.5467588978429, 67.515898981402, 79.58139988683885, 78.13504942001836, 81.48329442547214, 82.94866054288804, 80.23922058843797, 67.12646253647344, 62.37897080759849, 61.09684605752269, 65.6071481397075, 64.09223071990475, 70.08061132123395, 70.73943614959717, 70.52831849744244, 73.65477700387278, 74.64114327584544, 74.84898182653612, 74.52164434617566, 73.79889272874402, 71.09728966989826, 74.21379320083126, 77.19266860715805, 79.01854761185186, 75.29902673536732, 67.68006586259412, 63.532233930403194, 58.68081508144256, 62.67907919422273, 65.28034410169049, 68.81249335504347, 67.92622596986833, 66.06434745173301, 66.35374776778683, 64.28286183264949, 62.53955656482328, 65.56637510176628, 69.78579813434233, 80.10632284225957, 81.1204045818698, 88.21109279509514, 86.9637006328952, 86.76588766036495, 88.28240148482784, 88.04429792588758, 87.88215498770438, 76.53271413618519, 78.29172457418134, 67.84989664631506, 4.996390140825703, 2.941924718118483, 6.437033559045484, 10.055079287098302, 5.509202778339387, 1.9277077793113648, 10.785730558056986, 7.851909947010779, 2.507814438112321, 1.0631507130399829, 0.7461296178160176, 23.379977749240016, 52.758640166251894, 86.61948911605343, 88.09925033200173, 35.81248698696014, 20.02663758493239, 28.875200709988995, 49.83789428587883, 66.91552531334662, 84.00893211364746, 88.09197825770225, 83.2726247849003, 82.26972180028116, 6.475334032889336, 0.23089447238993263, 0.2023307155937918, 0.13990109215580648, 0.22259447663541765, 0.1867667507500418, 0.19053962652481374, 0.22643083045559548, 0.4538648990133117, 0.22029092685589868, 0.14586536243798273, 0.29316766067377986, 0.19846715033054355, 0.18972349773731925], [0.09619055135596184, 0.08721780016898148, 0.018992296405016415, 0.08800172262013921, 0.13661650550221244, 0.18828388063176987, 0.11958558187489549, 0.026324497115227486, 0.06595641644971986, 0.09380926663476614, 0.26681776008298325, 0.060437859952329635, 0.08956480245556563, 0.10298311590187012, 53.11362251158684, 77.38085608328544, 67.14911814658873, 46.96496602027647, 72.10700973387688, 44.94282730164067, 39.63421698539488, 97.86029600328015, 95.88855189661827, 59.09046742223925, 6.728722578094852, 0.15364693117237863, 2.0056453972093524, 2.3162765224133772, 4.506173297282189, 0.7682509275694048, 1.7654111332470372, 0.3408899128196701, 0.14359751235573523, 10.648409358916744, 77.42555541376915, 101.39801502227785, 94.7417449951172, 89.36395583614227, 97.10227443325905, 91.57038319495418, 88.91821768976028, 88.9961394956035, 96.33541968560989, 90.35772754300027, 85.82979832926105, 85.10550129798152, 81.42089736077094, 78.05762183281684, 77.37495683854627, 82.96383227071455, 89.73716935803814, 88.65548949087821, 86.56860028543781, 85.59714686486029, 70.7147644412133, 63.77292625365719, 63.98636202658377, 64.26048471081641, 63.707595256067094, 57.93640413591939, 57.473109460646114, 54.591779478134654, 57.49784784932291, 55.158914981349824, 58.92003259351177, 62.72788916864703, 63.510715807637865, 64.27400119843023, 64.97141822691887, 68.15602979352398, 68.94739151000977, 73.12266042155605, 77.08055157815257, 79.78977972461333, 73.53188914637413, 77.64669864408432, 77.81402695563533, 67.78302023487707, 61.90368936907861, 65.83465345444219, 74.12557909565588, 75.5873130982922, 79.1858131654801, 67.3172152426935, 73.65750697351271, 74.02768458089521, 79.0699306611092, 34.18390320193383, 35.633054241057366, 39.04852867126465, 48.71549237158991, 66.80708746756277, 68.05353826092136, 76.20193281481343, 75.73062081490794, 68.13952445983887, 59.06863158748996, 55.82808702222763, 53.812635944735625, 54.75841353016516, 56.85625399312666, 60.87453788326633, 59.74151811292095, 63.287595702755844, 65.47812569525935, 67.54898025143531, 74.457074288399, 75.75232721144154, 72.00185098955708, 70.09299032149777, 69.9154560027584, 74.01507023842105, 74.10312744878954, 69.66695031812115, 61.43038088275541, 54.01150011247205, 54.45900724780176, 54.26184538872012, 57.00681809456118, 60.2438795951105, 59.40205266398769, 61.54762837194628, 61.20210678346696, 61.25895761674451, 57.57393398592549, 59.82657078773745, 63.63055206114247, 70.81583607581355, 76.02574779141334, 74.00054962404313, 73.85127206002512, 75.95147378983037, 74.55707903831237, 73.30906714162519, 72.96397701386483, 78.8647279431743, 79.27580018197337, 83.45224580457135, 83.5685754591419, 24.6946071809338, 0.3423431509685132, 0.6036212679839904, 2.6700782343264553, 1.5522727250091493, 2.218646522491209, 6.5139443739768, 2.345994850320201, 1.0741939011120027, 0.05589896137075079, 0.41600596760549857, 32.6266614467867, 35.754800688835886, 76.88809656327771, 67.9131801666752, 38.15925282816733, 27.99248306981979, 17.971629404252578, 31.721317614278487, 48.988838426528446, 55.9604944721345, 64.36061105420514, 70.63182984628986, 29.00227765883169, 0.10656448501733043, 0.11814829367663592, 0.0345575291242811, 0.03144579105860284, 0.05269693218231682, 0.05275420874597565, 0.019168253394684965, 0.15511239608449323, 0.16538702942911657, 0.12920140258727536, 0.08732533593091273, 0.05272202922271625, 0.02359529356321981, 0.025530318661983457, 0.07412653731843157, 0.030703693177671205, 0.08342640804907969, 0.12904577948633703, 0.1626047972709902, 0.046660086560633876, 0.015419828273626346, 0.023322524127340125, 0.0022898566760798738, 0.11891602102907435, 0.14707089371738896, 0.09883776051743377, 0.055348638279904286, 67.71987791984313, 91.61108170786213, 78.36426488814816, 58.63756702792261, 82.01266534866826, 51.531079507643184, 27.54811775299811, 96.34469216869724, 105.60531400865125, 67.8094962335402, 7.469941204594028, 0.3742962492810142, 4.3334183865977876, 5.480673909187318, 5.751245867821479, 1.6874390720359742, 1.4399449911809739, 0.2724924184862645, 0.11704095188648471, 15.713891560031524, 87.78615890010711, 103.79943124709591, 99.42394102773359, 94.19469987192463, 99.70301766549387, 94.6900873799478, 94.50306877013176, 98.68906144172915, 100.12584917006954, 91.32293655026345, 89.75906402834, 88.86429294463127, 81.81683709544521, 81.328141150936, 81.38794945132348, 88.0746021578389, 91.71110999199652, 89.40338350111439, 89.37653095491471, 92.32026192449754, 72.17978539005404, 65.587355859818, 66.75285677756032, 67.58013956008419, 65.26519983045517, 61.92295605136503, 60.59527689410795, 60.833749155844416, 62.38499949055334, 61.03107575447329, 62.14382079339797, 65.49476046716013, 66.00507259368896, 68.63990122272124, 70.44047309506324, 72.05936078102359, 72.89784585275959, 78.10738102082284, 83.11928364538377, 83.56437852305751, 75.98274292484408, 79.92327367105793, 79.30922662058185, 69.56327422972649, 66.18420723945864, 70.62636206226965, 77.59908891493275, 78.14417285303917, 81.70996035298994, 72.26425755408503, 75.0449748193064, 79.05365282489409, 78.5706207829137, 48.262074224410526, 48.689365463872115, 53.26483772646997, 59.078351220776966, 71.18230312101304, 73.46351438953032, 77.80465249092349, 77.21720695495605, 71.27194496893114, 64.0647937405494, 60.40722277856643, 57.44984980552428, 58.20018353000764, 60.44799581650765, 64.36914613170009, 63.81045549146591, 63.88136802181121, 67.72432588761853, 69.36886587450581, 76.29035088323778, 77.52683101161834, 74.37545760985344, 74.68130834640996, 76.21114253997803, 78.83247037087718, 77.66081917670466, 74.2074389611521, 66.24426657153715, 57.96449615109352, 57.50587694106564, 56.09411393442462, 60.00343045880718, 62.26962297193466, 62.7437630007344, 64.19267477527742, 64.59446668624878, 62.37473072544221, 60.62786394549955, 62.54961744431527, 66.12505789726012, 71.8055049834713, 79.45837866875434, 77.65620646938201, 78.07168745225476, 79.83948399943691, 77.77720374445762, 76.71570839420443, 73.6957343932121, 80.37718603687902, 81.92700862884521, 89.21752591286936, 93.73729659665017, 39.20402711437595, 1.3064973777340305, 1.4707305714968713, 0.6641477298352026, 2.105090964225031, 3.61304200945362, 4.623727711939043, 2.650155535628719, 2.4697949040320615, 0.08397851995522938, 0.15399545521265076, 32.26429523960237, 46.08559808423443, 56.90638188392886, 49.16568240811748, 36.09892983590403, 32.351436576535626, 26.06371048958071, 40.234476904715265, 60.9381587274613, 64.23868417739868, 72.73581274094121, 81.66388034820557, 39.124352009065696, 0.07051728260252746, 0.13805644436469003, 0.03971716576826669, 0.07972573606117118, 0.026222940669545246, 0.02251292623940014, 0.09217540793601545, 0.1153006912359307, 0.045118035838728955, 0.10780815981448659, 0.10542800124253958, 0.07376011746424822, 0.008099689617783071, 0.12263473438759967, 0.18257787391062708, 0.19899116979250986, 0.21516564542487746, 0.4381162763362931, 0.2825450855157068, 0.30007948978774013, 0.14232445808668293, 0.21757339848385704, 0.16273539994032155, 0.34489480598318967, 0.23136184731077766, 0.3414326095052304, 0.6255423529974876, 81.19929129077543, 107.94537651923396, 91.85103662552373, 70.98984810613817, 91.37380184665804, 56.95777277792654, 57.36201617025561, 128.58813608846359, 109.11153639516523, 89.5098993855138, 11.31113596500889, 0.26629538004917486, 6.668047433899296, 7.763455106366066, 11.224943841657332, 3.900118076032208, 6.655593908602192, 1.9431287002178932, 0.16322522123734798, 16.457188552425755, 87.78350737787063, 110.53066561298986, 104.2728142584524, 97.57889732237786, 105.63188414419852, 99.27468699793663, 102.40441676109069, 101.60517108055853, 105.3407972089706, 96.68186695344987, 94.80612677912559, 93.2235445514802, 88.74251904026156, 86.15579435902258, 84.45143038226713, 91.20345331007435, 97.22959456905242, 93.74058354285457, 94.75722266781716, 96.39371395111085, 79.20442873431791, 71.18745711541945, 68.73277510366133, 70.93697455621535, 70.68660966811642, 65.2419009516316, 65.02470754807996, 62.70906179181991, 66.68431728116929, 64.43487721104776, 64.92842512746012, 69.87802090183382, 70.36165698882073, 72.03817998209308, 74.93035531813099, 77.69512422623174, 77.55109479350429, 82.32121467590332, 85.85812568664552, 85.70175647735597, 78.44970195524155, 80.96809110333844, 83.44349107434674, 75.12423023100823, 68.46838381982619, 71.88365428678452, 81.32032778955276, 81.60921035274383, 85.216002310476, 75.27161721260318, 83.1396250570974, 83.96549578635924, 85.5967624725834, 42.2809107841984, 49.64665520575739, 50.156120100329005, 57.1636736777521, 78.84337455995622, 75.7633412268854, 80.8120592178837, 81.6582792035995, 77.15380576349075, 66.2562298005627, 62.32512058750276, 57.53536924239128, 61.01549610014885, 61.919445530060806, 68.89683215848862, 66.90975158445298, 68.78313049193352, 72.12939862282046, 72.89655931534307, 78.35962080186414, 81.060360939272, 78.12274886715797, 77.38604930139358, 77.82744146162464, 80.96980125673356, 80.58877437345444, 78.16656958672309, 68.30908067764776, 60.621490093969534, 59.59093832200574, 58.218328414424775, 62.96849912212741, 66.25469223145517, 66.39348922237274, 67.24105850342782, 67.98499876453032, 65.27302495894894, 62.23159559311406, 67.33541504029306, 70.89975910802042, 77.487011109629, 83.37971333534487, 83.15216879690848, 81.77752710157826, 82.42866408440375, 82.19033302799349, 79.85054508332284, 76.49248630769792, 80.7406642360072, 82.44261987747686, 91.60111888762444, 91.71309471130373, 31.171619007664344, 0.9208589515859081, 4.93080860184085, 9.007072967867698, 7.435951905865823, 8.900977757669265, 20.42576620655675, 5.804008610786931, 2.8568041372683743, 0.1519222221066875, 1.0256969808570802, 50.7980473579899, 55.37641825214509, 98.40346582474248, 84.85623467353084, 53.2174672618989, 39.992160720209924, 28.80092670840602, 48.35091198644331, 72.2126470073577, 76.5116588531002, 82.65503191178846, 93.12670907666607, 48.09316912005025, 0.24976851929339672, 0.2795545846944855, 0.11450232802740029, 0.23909127610104702, 0.14350938160092602, 0.1814804682808538, 0.17158514038930017, 0.299702666459545, 0.3180974181140623, 0.4177786644187666, 0.13830963642366473, 0.18766975390814966, 0.10374649953577789], [0.026033554158564058, 0.06905087540226598, 0.06738468013223141, 0.007026829923908677, 0.08881618899683799, 0.15573976080744498, 0.07592695119280009, 0.09113708300696266, 0.06855448107084922, 0.02925164246511075, 0.055576453676387194, 0.07129300025201614, 0.3110496543588177, 2.254687465967671, 71.841873199709, 79.61872516139861, 68.1447333674277, 41.69912130601945, 40.7532613508163, 95.96435562256845, 89.99832076411094, 92.55680438010924, 81.70270396817116, 32.058633604357325, 0.24738491332579046, 0.16408388322639852, 3.3199164223286415, 1.721685653732669, 1.7373018351293381, 1.9111883496084523, 0.9002045469899332, 0.4929296834574592, 0.32763135168821583, 32.87088978675104, 98.67473694585986, 97.31549447582614, 90.87087554316368, 93.45330915143414, 93.21475844229423, 90.06311047461726, 90.3380137105142, 94.86737851173648, 87.19304946161087, 79.40122189060335, 77.87096408105667, 71.95990516293433, 69.52418388858919, 66.80370638447424, 68.48815256549467, 77.53748416900635, 83.96685292643886, 84.88386384902462, 83.00531525765696, 83.91709373843285, 65.06622191398375, 63.16020888666954, 65.99241902751308, 63.8533309198195, 60.909819602966316, 57.90545271288965, 55.984103218201675, 55.89862692740656, 57.15570342156195, 57.60497954583938, 61.360197913262155, 62.94837344077326, 66.48043247961229, 65.41887437143635, 65.60252366527435, 69.79908712448614, 72.75889981177546, 74.90748005528604, 76.35796470026817, 77.53469144144367, 78.39218431903471, 74.55350183671521, 75.56372396407589, 68.2594705397083, 59.902425504499874, 60.46236345844885, 72.83316596861809, 75.17722145203622, 78.48627413472822, 71.82740749851351, 71.24266055322462, 72.58239315402123, 75.43361894546017, 32.796947225447624, 14.22662292757342, 26.546077689816876, 43.62449123013405, 65.98191492019161, 71.34058644694667, 76.70685952709567, 72.26905853517594, 69.22720555336245, 66.03104652897005, 65.44073766277683, 61.52303511096586, 58.938334372735795, 57.52328441989038, 55.44676203881541, 59.20348659638436, 60.70258901965234, 60.736262567581676, 65.40341238821706, 70.84798382174584, 74.04504499127789, 72.41655534313571, 71.1374076720207, 71.57121396833851, 70.379668512652, 73.27124764842372, 70.98652193623205, 57.72109347005045, 52.90578396089616, 54.64624158797726, 54.83322097409157, 59.01998243024273, 57.883871832201564, 58.98713258004958, 60.990338017863614, 62.46321547415949, 57.95626309610183, 56.437454685088134, 60.4302353243674, 58.502382539933734, 66.44133429373464, 72.44507097428846, 73.65993099827921, 82.95479512983754, 77.77428550104942, 75.93237184709119, 72.48456924192368, 77.84160906268706, 79.95974386892011, 80.32256310985935, 77.76332639878797, 81.88474116786834, 100.06543682467554, 49.40685718290268, 0.5887954441770431, 0.8402309554719156, 1.4050677659050113, 1.4371565537106608, 3.7930153069957613, 3.5983037035311427, 2.038363235131387, 0.09703340129025521, 0.33317427361203783, 6.837393314607683, 35.265508544060495, 56.39170415939824, 100.13586690348964, 64.33821824289137, 34.654842576672955, 17.490789967198527, 22.353216948047763, 28.730628028992687, 38.62407722780782, 69.24258908917828, 64.32794163303991, 60.78567266464234, 2.4006800449663594, 0.07718878993464094, 0.03744512518507339, 0.06352301093659575, 0.015010315016092313, 0.06318745293444203, 0.021417564149164868, 0.07352757913571212, 0.14940741592116896, 0.15542914279766623, 0.06699711625133792, 0.1027585372268673, 0.025780806430585446, 0.08736815258500077, 0.025896788311881885, 0.06855251988576305, 0.024635022348393838, 0.1297938643443969, 0.14720790088176727, 0.0219343536563458, 0.004345565760177711, 0.02138206363475371, 0.06220849215864174, 0.12211954791940029, 0.18843565797132833, 0.4985125032403777, 3.419594634925166, 85.9044881020823, 88.7644450895248, 83.14550076761554, 45.54710765038767, 60.727425467583444, 83.65569914540937, 69.86790118678924, 101.10562586015271, 90.65573353921214, 36.44879348816411, 0.017352820366560932, 0.27290901709948817, 3.489840607489309, 3.8945132542041043, 4.921308621283501, 1.3717147491631971, 1.6165467664118738, 0.4206523521532936, 0.7277320469579389, 41.74733508017756, 97.37303564625402, 100.25029028615644, 91.98199672083702, 95.34617439393075, 96.82236625302224, 96.7436364389235, 94.95734983874907, 98.57965869288292, 89.87902579769012, 82.6753419445407, 81.39719055544946, 75.82023912860502, 70.84842312720515, 71.88148129370906, 73.09866336084181, 81.79335778759372, 85.85830611567344, 88.40249661476382, 86.21020547805294, 86.15608461441533, 67.48525742561587, 67.13890429466002, 69.1201562266196, 65.56869322253813, 64.33833199162638, 60.932157501097656, 60.035013383434666, 58.86739438579929, 62.022972568388916, 62.795840309512236, 63.66887754009616, 66.20683931535291, 67.10708602782219, 68.62519233457505, 71.0955402928014, 74.35630075393185, 77.55592715355658, 79.69720394380631, 81.53747804703252, 78.94217906459686, 78.58815377758395, 76.84524074677499, 81.97888589674427, 71.78409668707079, 62.673325077179946, 62.864854412694136, 74.9687082536759, 78.93100030960576, 81.55464233890658, 75.66955735606533, 77.40346462495866, 76.6918368493357, 77.34248745825984, 44.878174874090384, 25.83626793276879, 37.264822990663596, 51.88221793020926, 69.43300447156354, 74.34356089561217, 77.25136295441659, 75.78352574379214, 73.80440758120629, 71.02425513728973, 67.86745317520635, 66.79727369739165, 64.23470297167378, 61.86278297055153, 59.465834325359715, 61.93497027120283, 64.93397920362412, 63.29243982991865, 67.58314409563619, 72.18240553332915, 75.75822645618071, 75.14562283792804, 72.4002931964013, 73.15578091529109, 73.93434001553443, 75.16583088905581, 71.66699040320613, 61.77522782356509, 56.75041667876705, 57.34156885454732, 57.715500170184725, 60.32444900082004, 61.073574635290335, 63.11673725804975, 62.887784588721495, 64.58057757346862, 60.553276154302786, 59.659697471126435, 62.06803275692848, 62.8530284666246, 68.91900923944289, 73.69058824354603, 78.5925546769173, 84.95768285566761, 81.2547379155313, 78.95374221186485, 78.09964610684302, 80.23225445901194, 82.17202340402912, 83.58490820853942, 81.64664545366841, 82.16168403625488, 99.01978000517815, 68.29915708111179, 2.0124432324401798, 0.49763784533546823, 0.9229664288220868, 1.9508859226780555, 4.848417255186266, 3.646558172279789, 2.6028348361292197, 0.6261724449934498, 0.32384988040693347, 5.55468560226502, 45.26095505683653, 53.99199808797529, 80.43435065977036, 50.42222545992944, 34.53880709986533, 27.473822178379184, 35.06844474423316, 40.69919932273127, 48.3589332334457, 76.42854382914882, 72.05350860472649, 74.83856401135846, 3.9245463523172566, 0.14550485678257483, 0.13659553001484565, 0.09163648040304262, 0.03664185135294834, 0.062024186725818345, 0.028128580550753304, 0.07596637407738356, 0.16322603329054772, 0.08181322606340533, 0.017984136187982176, 0.055382307844176415, 0.08243125217456011, 0.16587459842764563, 0.15170057754843466, 0.2674543791480603, 0.09742294167799335, 0.3690128166589045, 0.2901009494258512, 0.23327617845948667, 0.18056264898229032, 0.19950403501429867, 0.2744610499470465, 0.2418120526858876, 0.309246743037816, 0.5096865391298648, 4.138601614582924, 102.996867241398, 100.95095895951795, 95.41370976355769, 60.67098648317399, 59.3669278390946, 100.98407160851264, 123.04657228531377, 109.29203602575488, 101.77587263045773, 48.60954130849531, 0.36992084535379566, 0.3438470428509097, 8.930053307164101, 8.704928871124022, 8.002738808431934, 5.665858320651516, 6.341400780985433, 1.835604766684194, 1.2122658664180388, 40.04590111394083, 108.0159007349322, 104.12182654103925, 100.14179752719019, 101.04406818266838, 103.57394987537016, 100.847777089765, 97.72857496815344, 103.48546904902305, 98.00404302535519, 84.55880134336411, 86.7248361341415, 79.05960698281565, 75.50750071002592, 75.80430646096507, 76.20398813678374, 86.62590611365535, 92.88025871399911, 92.01911018740748, 92.47488175669025, 89.81989214497229, 72.49956838546261, 69.86938384271437, 72.73138046264648, 70.90099073225453, 68.35414871092766, 64.92910369749993, 64.49662708467054, 61.14751523540866, 64.2662819739311, 64.30059094582835, 69.02678812703779, 70.41978651477446, 71.73065047110282, 73.58517846753521, 76.30848792291458, 79.24463302858415, 82.89854834156652, 83.40862120351484, 83.24957693776777, 80.73413741204047, 80.02184283348822, 78.8615272891137, 87.45601300270327, 74.41810161836686, 65.84160389438753, 66.47028923034668, 78.2042714088194, 82.56589997199275, 85.66581972183721, 78.66977045612951, 78.28772375660559, 82.51872954830047, 84.10407312454717, 38.86837028688, 23.358359606035297, 34.502960558860536, 53.675290230781805, 76.1857020470404, 77.96201013749646, 83.32145829354563, 79.20980238145398, 76.72703619926207, 74.82134480630198, 69.74689606697329, 67.61874352732013, 66.44448787935319, 64.5472570388548, 62.86874932627525, 67.05413403049593, 68.55478578998198, 67.02950939055413, 73.19783656827866, 77.69131168242424, 81.83116943605485, 78.42489688627182, 77.23011155282298, 76.94674384209418, 75.30072119928177, 81.24400631073983, 77.38272313148745, 63.503137788464954, 59.20421615723641, 59.893137331931825, 59.69459479854953, 63.83804936562816, 65.3880210076609, 65.96165195588144, 67.89567070622599, 70.24637068471601, 62.23804004730717, 62.30509296540291, 65.80849124539283, 66.76139969979563, 72.50131776255947, 78.8179026880572, 81.74912914153069, 88.96264245433193, 83.0055505998673, 82.34459984687068, 79.76933633127521, 82.65795015519666, 84.7634078610328, 87.25513273669829, 83.78403909744756, 87.69861944260137, 107.8119610201928, 60.9766685578131, 1.001284271478653, 4.7433580410095955, 7.629973907624522, 7.207594946507485, 9.367977111570298, 9.544771082939642, 3.464524404656503, 0.330184355017639, 0.4990214614137527, 12.024135589599611, 56.03287004655408, 73.56906537086734, 118.00522050549908, 83.51206194969916, 49.17915182728922, 29.758518472794567, 34.241063902455, 47.36984091420328, 58.5571623617603, 88.16705242280038, 82.76498379245882, 85.07983330757388, 5.396967587932464, 0.36659608504945235, 0.27858131595196267, 0.19374081684697061, 0.1778817089695123, 0.2244902531346006, 0.16113576238914845, 0.32269054422936133, 0.2957871910785475, 0.30432585386499283, 0.1541899496148671, 0.27080316396970905, 0.1464901837490259], [0.08581882402781518, 0.029219744479163524, 0.06161965399740204, 0.11682362806412483, 0.03618248588135166, 0.11087725359585979, 0.1481065220169483, 0.018709069868970304, 0.022912017828334245, 0.024172937264665965, 0.15420357065816082, 0.0623055593290877, 0.5518526619961185, 11.673239373391675, 78.93373812398603, 75.41916108900502, 62.49093486416725, 55.71740165833504, 26.047922949637137, 47.01379952892181, 77.65737533569336, 89.53657150268556, 67.84219311129662, 8.978028797334241, 0.09080968001076291, 0.03778066403502899, 0.536575643045287, 5.114393666867287, 4.385717309290364, 0.151928611279976, 0.49562710968236773, 0.2764278734403272, 2.048811203529758, 68.84406843493062, 97.16517356134231, 102.39785855816257, 90.44474924764326, 94.32493040638586, 88.22285206087174, 93.1536243807885, 87.28677057450818, 82.31952805672923, 77.38184452056885, 75.29952879874938, 69.87713444617488, 68.82626871908866, 69.77250914419852, 68.47029793647029, 66.0639081462737, 73.97193201126592, 81.44869912055232, 81.46995052214592, 82.87524946274297, 75.49814193479477, 62.70792430446994, 65.13132541410386, 63.0874881436748, 60.80100128727575, 60.48013964006978, 56.18478344332788, 56.90777432534003, 58.614895728326616, 57.46891252456173, 59.71513232877178, 59.72181996991558, 62.127872436277336, 66.8535989330661, 69.76901039000481, 70.46249328121063, 73.97861573003954, 72.54758604111211, 76.1010729882025, 80.12929224198865, 74.04460568581858, 73.76115952768635, 75.83975684258246, 77.19241757546702, 70.04663575080134, 56.622029658286806, 61.2733958613488, 69.82220557428175, 72.4002775069206, 78.34197798082906, 71.62665274835402, 71.17427795164048, 69.44091981457126, 67.61574683650848, 33.91389116164177, 14.746551725172228, 21.31016262115971, 43.928004234067856, 62.43668848468412, 62.20346435423821, 70.25804365834883, 70.62902927398682, 71.2286106232674, 69.70082390692927, 72.54282428372291, 69.96057894922072, 71.41321305305728, 66.30560459629183, 58.900428587390536, 54.189183481277965, 55.54682170191119, 56.590760523273104, 60.22797438406176, 65.47347768660515, 70.97728083210608, 73.05496031238188, 70.95151086007395, 68.38662593595444, 70.50700433792608, 72.67403541072723, 67.21192313778785, 58.58651738012991, 52.02027359316426, 54.489570356184444, 53.97822664630029, 56.24588612587222, 55.07545086645312, 57.63517002905569, 63.47497909299789, 60.90814082853256, 58.08656423322616, 60.41805244261219, 55.522679513500584, 56.20013560018232, 62.854856291124904, 67.70148200373497, 72.04630713309012, 75.14324588160362, 76.40613925072455, 77.30833930353965, 78.62701662125127, 81.99405762457079, 77.03000007137176, 78.55665714510026, 79.85164334697109, 81.00897004527431, 72.24674809363582, 91.9661738795619, 47.322497906223425, 0.09398981057588132, 1.1609590582309233, 1.6863741485341903, 0.6211068877770055, 1.8424366775058933, 2.2069684007475456, 0.18531389564516085, 0.027505007963026726, 0.07424542650340066, 21.64995558800236, 40.381361822928156, 74.05368205039733, 79.82956824764129, 46.5211655247596, 34.47493130160917, 16.339164433940766, 20.317695102384015, 30.47440202005448, 50.126706246406805, 57.409943611391135, 68.98731339362361, 13.96230616877156, 0.2970134526971848, 0.15767958736227405, 0.07245573785997207, 0.03441623569796643, 0.00847096263896674, 0.07056783674465072, 0.05231953045773891, 0.16726884780631912, 0.12263647340718778, 0.0705312330636286, 0.0788911522155808, 0.07859970938654677, 0.08413112466974605, 0.04321714187221181, 0.07357823286926554, 0.07383155516318737, 0.05590888603980984, 0.08486078511322699, 0.07469652205585472, 0.012750718573619042, 0.04628357349804813, 0.05792801035568119, 0.16991730569110763, 0.212298346863639, 0.6034717889082047, 14.758438467979433, 96.5464981140629, 83.22706253297868, 77.39701624839537, 58.425433481893236, 36.02958233125749, 53.1159092533973, 84.91236379069667, 99.967863944269, 77.58159514396422, 10.569114723513204, 0.1582275394109949, 1.5673139114533703, 2.666010981605899, 2.3503942787647247, 5.918544271299917, 2.574985517609504, 3.3996944898559205, 0.44489152729511267, 3.8377594995883206, 74.3491541954779, 98.04227044505458, 105.36708493386547, 91.15310576654251, 94.67510392588954, 91.77941414617723, 97.21499550727107, 90.41193469878166, 86.01116872602894, 79.5192930775304, 75.1426810602988, 72.08899036530526, 71.98358058929443, 72.00604008090112, 70.45489957255703, 70.05171914254466, 79.6286879816363, 84.10828575011223, 85.35991407209828, 86.25925079468759, 78.53126372060468, 66.32980562025502, 68.78757845970893, 64.15057597621795, 65.241818581858, 62.267540193373165, 60.10858135838663, 59.78304424593526, 61.644040230781805, 59.57942616554999, 62.70392740926435, 62.706167082632746, 66.81310438340711, 71.12957077641641, 72.92259600854689, 73.90318070688556, 78.96845894475138, 77.39136019060689, 78.49784512673655, 82.16482193239274, 76.31034712637626, 78.16571451002552, 77.94839166825818, 77.80375034578385, 73.52403656128915, 59.79275211211174, 63.78991403887349, 72.76088453108265, 77.04463835685485, 81.78319100410708, 75.25646117425735, 76.96934453902706, 72.02407513895344, 68.65257832311815, 40.77469318143783, 20.03202299917898, 31.48038798762906, 50.384837427446925, 65.05580017643591, 65.75164825685563, 72.71048991910874, 71.96945221193376, 76.20481967926025, 74.31279382398053, 75.40225567356234, 74.30563942078622, 74.85191575942501, 72.12537427102366, 63.07463061424994, 55.2355698616274, 58.20995807647706, 57.76416109454248, 61.48919682348929, 67.84744124258718, 74.39816813315116, 76.0864503922001, 75.20039481501426, 70.31725575847011, 72.58901411487211, 76.71161343974453, 68.8541881499752, 62.43774360226047, 55.62401394690237, 57.32803275508266, 56.22755689005698, 59.38335864774643, 58.47564766483923, 60.27032029244208, 64.84737327021938, 64.4881586874685, 62.2345648273345, 62.48318426070675, 59.34605690740771, 59.02256334981611, 65.61281988697668, 70.6950427639869, 74.22188112812658, 75.44854748633601, 78.41496544499552, 78.88965852798955, 81.59524671493038, 82.03085730152746, 80.01308810326361, 81.2440533791819, 82.32461144847255, 85.31737988994968, 78.52438388332244, 90.68195850618424, 64.4615493282195, 0.7359742950047217, 0.5791665769873128, 2.7468630431159853, 2.33871738276174, 4.384461660538951, 5.489705656805347, 1.019488788179813, 0.4377695142982468, 0.0438429361149188, 23.0170996727482, 51.3415035124748, 64.39980337696691, 65.60208435981505, 40.48828563382549, 31.899701126160164, 21.93364493308529, 30.613805017163678, 35.39223640195785, 57.620123817074685, 65.36060364015641, 79.6221690024099, 19.943173470035678, 0.45332768751728925, 0.20373455639327728, 0.07205372556082665, 0.01974874885842925, 0.01532084971380931, 0.09317823235065707, 0.0731061848120824, 0.15830678354588248, 0.042057123876387076, 0.11143643649355059, 0.002981265391891582, 0.04030321153902239, 0.1373796363271052, 0.10486390772125415, 0.19208632740041903, 0.19026959585326333, 0.2218448596015092, 0.257957462942408, 0.2898721342846271, 0.18588892124112577, 0.11703110765665771, 0.1834785788049621, 0.3183845785115996, 0.3794314898550511, 0.8270011073158634, 17.339990523553666, 116.50633381259058, 94.39156363087316, 92.52081271140807, 73.55884367419829, 41.80175404394827, 54.53581510051605, 104.68073291163292, 100.21282380627048, 98.80495963558074, 14.51273923920047, 0.4066873353815848, 1.3458469630249086, 4.427296884598271, 11.763419566615937, 12.799076303359001, 7.167776515406947, 3.5514242706760286, 0.4514790560689665, 3.8437359659902515, 79.26049509356099, 108.43171119689943, 112.2860517809468, 98.85045128483927, 100.8578654258482, 97.032573915297, 99.85152644495811, 95.61048723036244, 91.13135230156684, 85.17242477786156, 80.75635371669647, 77.82650793752363, 77.47744837114888, 75.49907545889579, 74.28004203304168, 71.09252006776872, 81.54726828298261, 88.58886411113124, 91.22125302591633, 91.44155686901462, 83.18984708478375, 71.28013487785094, 73.42563213840609, 67.30447538437383, 66.22466256541591, 66.99941696659212, 64.22485782254127, 65.96943393830331, 64.03734891645371, 63.48311016636511, 65.94168709170434, 67.87236398266208, 69.71711743262507, 75.12190818786621, 76.24365898870653, 78.32514316804948, 84.57530667704921, 80.21709842066612, 81.32823528782015, 84.20553699616464, 77.16621614271595, 82.09629812548238, 80.94896562637823, 82.97966295673002, 78.71250860152706, 65.06913623502179, 67.17286417561193, 76.02235101884412, 78.93404406885948, 85.70015615032565, 79.73245036217475, 80.95530417657669, 80.01559057543355, 75.62397156992267, 38.91011215025379, 17.571041660924113, 28.241457477692638, 55.42206679621051, 72.10324425851145, 69.59329605102539, 77.73664643687587, 75.1036770113053, 77.61528045900407, 76.99981351052561, 77.36653943215647, 77.37810257942446, 77.46175889045962, 74.3898448636455, 65.2482944150125, 59.628765659947554, 61.75850283715033, 61.9565393847804, 65.09763617669383, 72.8412695853941, 77.33981240180232, 80.86856488258609, 76.07662877728863, 74.22031218005766, 74.38338864234187, 79.70581746870472, 71.84264982900312, 64.04720583269673, 57.304663273596, 60.29189332838982, 59.375411925777314, 62.54630696388983, 60.23941201548423, 64.38768717550462, 71.07136280305924, 67.99224730460875, 65.26794156720563, 66.0989349119125, 59.791571478689875, 63.37527244321762, 69.41687568541496, 76.73998786557105, 77.5108277413153, 80.72943056783369, 81.95104491326117, 84.72991081976122, 84.62161417930358, 88.40705440890405, 82.83664549550703, 84.8738931840466, 84.471936533528, 89.18414654270296, 78.80096589365314, 102.61715827449676, 59.68927606459587, 0.5744206929399122, 5.699095995195451, 11.38876163190411, 3.391977471690024, 6.645369270155507, 8.989595866972401, 0.3471328552451826, 0.37903683199997873, 0.283232695393024, 36.396939754486084, 60.864202437862275, 89.28933666598412, 94.09321246608611, 62.684076293822265, 49.224690544989805, 28.31922042754389, 35.10461291959209, 45.71481643184539, 71.13812154339206, 76.40619416390696, 91.36503927169308, 23.95936085331825, 0.5895732992118405, 0.3398574714458758, 0.2361525781452656, 0.22428704065180596, 0.0852663903647373, 0.2699615704196115, 0.16687725430294392, 0.4421948978016454, 0.2643664625863875, 0.23082840496734267, 0.1588839235445184, 0.2336530477529572], [0.028142958105872237, 0.032230111875481186, 0.029339118214744716, 0.037882071093566, 0.07306404997624698, 0.04458578476201623, 0.10574058809828375, 0.011957824275258088, 0.12620890993745099, 0.054841024590836424, 0.21133747342373096, 0.16627497129863308, 0.5898620837157773, 18.08419554464279, 81.30358711365731, 67.05859768775203, 63.25532244097803, 36.37264851600894, 36.75864504229638, 29.43134180961117, 91.36439600298482, 90.05935284399217, 35.789317546352265, 1.2021471319660064, 0.07287973688254434, 0.21946604934430894, 1.8445306103075705, 2.1067692483625104, 3.0537186418810203, 0.8724502846598626, 1.4857352308688627, 0.0975990423091477, 18.484555790501258, 100.18492006486463, 98.31990365059146, 97.88703087837466, 86.79114772427468, 87.87887588624032, 83.84745597839355, 83.65791136218657, 73.73617402968868, 70.12801708713656, 67.11136925605037, 71.20942238838443, 68.4938007785428, 69.02671752437469, 65.57415708418816, 66.09087836357855, 65.09480030305924, 69.51627639032179, 76.0945696984568, 75.3976821899414, 77.22291792592695, 71.5519472860521, 60.228770625206735, 61.77914234899706, 62.099372494605284, 63.06121610826062, 54.939929054629424, 56.83234322455622, 56.05511773017145, 56.83599495118665, 59.00097070201751, 63.39719849248087, 68.36098932450818, 68.74858225545576, 70.83150202228178, 73.49126908086961, 74.44869610571092, 73.67761304301601, 74.92407952585529, 77.86147194523966, 73.16694398080149, 73.78217558706962, 76.2419645247921, 77.50732114238124, 67.78305161383845, 63.76225740678849, 58.08623083176152, 59.9630339684025, 70.58574199676514, 74.62180599089592, 75.60453230334868, 68.72815455159834, 64.99489361240019, 66.95221516393846, 62.27040744596913, 38.96785728393063, 25.351170762892693, 28.021316412956487, 46.57934996389574, 56.61468698132423, 56.8115193613114, 61.37205916066324, 67.47171740378103, 73.47365763879591, 70.9061525714013, 74.59457689715971, 70.25336034836309, 70.67867079088765, 68.1386693831413, 67.75684233634703, 54.64424117918938, 53.66400164942588, 56.05854588170206, 54.02090987851543, 55.85657127441899, 67.05820545073479, 71.22191905975342, 73.0284058663153, 70.22245991614558, 69.82079352101972, 74.18693280989125, 72.14637464092624, 63.55010424890826, 54.93289232254029, 53.70375487112231, 54.60892808052802, 54.35233839096562, 54.48043123368294, 55.52318549925282, 59.68110576752694, 63.89324495869299, 62.53203738120295, 59.96596005655105, 56.60751296627907, 54.872664328544374, 58.36170673370362, 61.085035800933845, 63.771929971633426, 66.56648143645256, 72.02260032776864, 73.04966511264925, 76.22036795462333, 74.55359597359934, 78.11448835557508, 73.45017048620409, 74.28506266686225, 71.03440623129569, 88.9764178183771, 75.32509480753254, 87.81668278478807, 23.16794030127987, 0.5205880622229269, 0.4753992934861491, 2.613521823959966, 2.1909602274817805, 3.689909923461176, 1.9459985268692819, 0.21261196793808093, 0.07074106454608903, 4.735640287399292, 33.60703629832114, 43.40946689728768, 62.87047909152124, 79.49356232920002, 122.3784435949018, 63.6449706938959, 22.912199804859778, 25.890543730028217, 42.52421148361699, 57.905405644447576, 69.32635522657826, 31.229530842073505, 0.2375572309979508, 0.17506250540816015, 0.05502123528370454, 0.036212554832379666, 0.055698993270315474, 0.14247954492607426, 0.03256046047974979, 0.07808863681050078, 0.10727474045368934, 0.02598516229960707, 0.005409049495468818, 0.044940598384146734, 0.06333020958869208, 0.03211999631246492, 0.050167252399748376, 0.010926660353077516, 0.11247626295493496, 0.07640713510373909, 0.10785587943129002, 0.06254275930264304, 0.09958063597760855, 0.07001116661535156, 0.23991869702454538, 0.16496028781177538, 0.7728890690111345, 23.4803060946926, 100.10375838125907, 75.64057888523226, 72.50978223739132, 40.23224115371704, 38.276217906705796, 38.128246491955174, 97.65341451091152, 96.13273512932562, 40.752935794092, 1.0417612930459361, 0.17014895535765157, 1.1080421170880719, 5.674696891538559, 4.136014811454281, 5.644529942543277, 1.7079577258517666, 2.513592334524278, 0.11035635977262452, 22.98559323433907, 102.84416152584939, 99.87968906279534, 101.34525129871984, 88.58254125041347, 92.40770724511917, 85.72530638787055, 86.40987765404486, 77.08236371317219, 73.8833256690733, 70.93912401506978, 72.69097220513129, 72.74660710365542, 72.09478762841994, 69.41100781963718, 69.91307904643398, 66.93324658178514, 71.88727071208339, 79.09929352421915, 79.16757414417883, 78.48599956881615, 73.66587731146043, 63.51869783093853, 64.2149656049667, 65.80196049905592, 65.3184263936935, 58.64800837732131, 59.1130445849511, 60.16501249805574, 60.73940830845987, 63.85221696669056, 68.40935214873284, 71.61147317578717, 72.80638402508151, 76.1336600395941, 77.58394072132727, 80.88137534356888, 77.16152498798986, 79.91703710248395, 78.71756061430901, 75.92713156054097, 78.98437592291063, 78.57206421513712, 79.92041818557247, 71.63908666180026, 65.06377043262606, 60.08905579966884, 63.473543505514826, 71.7496504322175, 76.40194231464018, 79.22377386400777, 74.90318113757719, 68.77278327941895, 69.31761618583434, 63.75185135872134, 43.74956777018886, 28.782621006811823, 35.62437403586603, 51.916597504769605, 63.22701077307425, 58.6959122842358, 61.71600787870346, 69.3672106342931, 75.77684986975886, 72.98341628043883, 75.17424045070526, 72.8710089960406, 71.24672412872314, 71.80742694485572, 71.69859686205464, 58.40622171278923, 55.997313760942035, 56.0113166224572, 57.48928923760691, 58.61424461487801, 68.67946224827921, 74.65156109102311, 77.10300322501891, 73.72008446724185, 73.62559456979075, 76.15633918393043, 74.05660813854587, 67.0327571130568, 57.95180728358608, 56.550877863360995, 57.407641180099986, 56.70886308916154, 57.25859503592215, 58.75468900126796, 64.49799599186068, 66.47727889399376, 66.58679146920481, 62.9379830821868, 58.495945930480964, 59.15507670371764, 60.73265790939332, 62.16951231802664, 66.83625421216412, 69.08116786710679, 72.41778696736982, 75.60752114941998, 78.77812985450991, 76.28023901293355, 79.96405847610967, 75.87021012460032, 77.39358025212442, 72.73685609140705, 91.11333293299522, 79.21426603871008, 92.30687879746961, 33.32040909797915, 0.071069831178794, 0.5693265146786167, 3.9248091511188017, 2.8235549407620586, 4.094489659032514, 1.790477897851698, 1.1066342313443462, 0.0956845349602161, 3.05693204364469, 40.69720283631356, 48.14060626491424, 53.48445123241794, 68.24669930242723, 90.3791436841411, 46.031991051089385, 28.967598022953158, 31.39468223817887, 48.517820604385875, 65.27149131221157, 78.96437183503183, 40.67923445855418, 0.24194256342466802, 0.18911897775626954, 0.12190137373944446, 0.031183306353106618, 0.020640191749759743, 0.03964858174684548, 0.023530729588181264, 0.10980185767215107, 0.14127600547527114, 0.02309437931304978, 0.11811854648253611, 0.019044378892548623, 0.14347683818590257, 0.14809942804276943, 0.15273312617453838, 0.20575499071949915, 0.20193840196776777, 0.14974098592515916, 0.3796239617851473, 0.15600314183581263, 0.15948651298399896, 0.20607952088598283, 0.4692130109235164, 0.4068428205866968, 0.8865266906157617, 28.24703508807767, 117.26888964253088, 85.7885036160869, 88.27496467098113, 53.77267091504989, 50.369846128648334, 41.00625030456051, 117.70060923791702, 104.07457766994354, 58.31261434862691, 1.696533209854557, 0.14269676149612473, 0.6890569867626314, 6.595264423278071, 7.100102391935165, 11.09893475809405, 7.1983597259367675, 5.5192969979778415, 0.6981559049698615, 22.90897757776322, 110.97190087841405, 104.799282627721, 107.99086032375213, 93.68166954286637, 98.23177583755987, 91.85076205961167, 94.78362806381719, 81.02266696191604, 77.61753189948298, 75.76856582395493, 77.9763581675868, 77.40625735252135, 76.90062461360809, 73.52898659244661, 73.97477180727067, 71.27816584802443, 77.93816212684878, 84.04645350671585, 83.66045305805822, 83.64523426178964, 78.71235955146052, 65.69281270427089, 67.717712771508, 70.02452927251016, 69.86991728505781, 60.95747247818978, 65.21519745549848, 63.415582641478515, 64.66460650967014, 66.69591180739864, 71.44832611083984, 75.62434027271887, 77.1541509320659, 77.73306139053838, 82.29678615447014, 83.01479170399328, 80.2120699421052, 82.31230305087182, 82.16548089058169, 78.67799174401068, 83.21302829250213, 83.35840702056885, 85.99034094041394, 74.36226275659378, 70.24306804903092, 64.87657923852244, 66.67772769927979, 76.29259447897635, 80.98749114621071, 81.78109645843506, 77.9102897644043, 74.28113245194959, 75.61477753423875, 69.75143032689249, 45.27777810250559, 28.689884408827755, 34.80091948663035, 56.64236322526009, 67.58223410575621, 62.773969173431404, 64.71747221485262, 73.48080419724988, 79.56770297019713, 74.41228082103115, 79.40543451616841, 75.59383992225894, 75.17996711115684, 74.5632214700022, 75.1204647556428, 60.05910458103303, 59.05802549854402, 60.48977690358316, 61.488255454647934, 61.35783664641842, 73.74856871943321, 79.81687545776367, 81.93541034575432, 77.04852934806578, 77.3361018396193, 80.30803465074109, 77.40135438980596, 70.33813061252718, 62.201326662494296, 58.49460447988203, 60.40776798802038, 60.68794681179909, 59.887540109695934, 63.680577970320186, 66.80736987821518, 70.63383809981808, 69.7275274030624, 66.6740563607985, 62.81023540804463, 61.78776371863581, 64.23768005063458, 67.27614018224901, 70.80447689179452, 73.20499097147297, 79.77346266469648, 79.4023044647709, 83.76246606149982, 80.68568045093168, 85.33358712350169, 78.8507172369188, 81.94790701712333, 76.99295720746441, 98.70934009552003, 81.72364158015098, 98.80945467179822, 29.21849831458061, 1.9655148925319796, 5.577705502510072, 11.42321082853502, 5.095481468785194, 10.172405223692618, 3.7066616310227305, 0.602282268866416, 0.17660635643668715, 8.363264933709177, 54.32506222878733, 62.145099486074145, 82.21196882186398, 94.57920981991677, 134.4544250734391, 78.02002199234502, 36.578965187072754, 40.56732139279766, 61.922552047237275, 75.37392831617787, 89.20913204070061, 47.42010216559134, 0.5032365078166608, 0.29953881557429995, 0.21232566555901883, 0.1816288748335454, 0.16934782657171452, 0.15816560886319608, 0.2206924182152556, 0.22017169293136368, 0.2385135845191056, 0.07207770411285662, 0.10416434687231818, 0.1882604383412869], [0.02495779817353093, 0.01897269413025389, 0.02125374582265654, 0.05124766619936113, 0.029552852915179346, 0.04176389223204986, 0.07193816885832818, 0.029726775941408934, 0.11986285207733033, 0.055269210283914884, 0.07337001783232536, 0.06894196068207104, 0.35773459281171527, 24.462426400953724, 79.8578171576223, 66.91164216687604, 59.78264808654786, 40.886594480083836, 32.578443750258415, 35.01182533079578, 92.03075178207891, 66.72296831684729, 18.298637405518566, 0.04137368151737798, 0.30172869322761414, 1.6490472805115486, 2.863531002113896, 1.9167621601973812, 3.9362592850961997, 1.1653605704346013, 0.5252382159233093, 1.0344050103618254, 64.02880991658857, 106.51971263270225, 94.85765887844948, 93.3135001890121, 87.29488988076487, 83.5915840825727, 76.7030312938075, 79.07305286776635, 74.2730131456929, 77.97265545014413, 76.6378415015436, 78.59471198051207, 72.3020927367672, 67.83599576642438, 67.92543365109351, 66.316830419725, 65.66425784941643, 66.76482785132625, 66.27915213184973, 68.21217460017051, 66.77170768860849, 66.22214440376528, 61.17448937508368, 63.16022065378005, 63.934986822066776, 57.933019130460686, 55.3018069267273, 54.12236198302239, 58.227828394982126, 63.291820095431426, 70.23963205275997, 74.18433620083717, 72.05878811497843, 72.81571926609163, 75.17925323978548, 75.62754092677947, 74.53542755496117, 78.49014943645847, 78.33560020692887, 75.7015795861521, 73.63096037218648, 74.38098030705606, 68.88757536488195, 63.1069117207681, 56.669957099422334, 55.83684175245224, 54.40177594461749, 61.13448512169623, 68.05685658608714, 72.10489165398383, 73.23542071926978, 62.27323155249319, 63.63347030455067, 60.736552822974424, 52.487043488410215, 46.64872492513349, 38.850194023501494, 37.997294241382235, 48.80666394387522, 60.11169964267362, 55.06404853636219, 68.1866164361277, 73.37370780206496, 68.79780015637799, 72.34873756285637, 71.59707807725476, 71.66001642903974, 69.47942180018272, 70.83172951975178, 66.68185403270107, 56.82035646130962, 54.2060810519803, 50.70876244575747, 55.33363303830547, 54.91908165716357, 54.17452166157385, 62.29280417965305, 65.26670994297152, 70.85884094238281, 69.2533677624118, 70.8083757277458, 69.31796919914984, 69.6455341769803, 63.70965450040756, 52.86279870617775, 52.64376571101528, 53.45960693974649, 52.26197004318238, 53.11761940679243, 60.812030992200306, 61.33727558197514, 62.85245580057945, 60.83646735837383, 58.20559640084544, 58.45598482316541, 56.73214627850441, 56.38637365833406, 59.27634462233513, 58.37811400813442, 62.06777388049711, 63.81772756576539, 65.32081903949862, 65.58573592093684, 66.99338436126709, 65.93224202432941, 63.490750943460775, 67.89083050143334, 69.09325661197786, 80.1422203740766, 81.70927001583962, 68.76840591430664, 1.7136341309355152, 1.6351303434179676, 1.3806432894160672, 3.3135335003176047, 4.402508975998048, 5.005232634082918, 0.8521051957241951, 0.10324145607169598, 0.01801905064513126, 16.685115521953954, 31.220152454991496, 44.855833053588874, 101.31948132668772, 132.2453461923907, 104.0630223674159, 32.316817737394764, 25.136195459673484, 38.43661931253249, 55.189768345125266, 65.13968398494106, 40.00170776920934, 0.06440674315296835, 0.04950684630462239, 0.0653093479453556, 0.07378986465834803, 0.03227734885689232, 0.08427193163022881, 0.03184734178977388, 0.1307180574944904, 0.028266981995153814, 0.03670777321883267, 0.022093918279654557, 0.02790640547661291, 0.0621602516020498, 0.0791215608196874, 0.02410889614463574, 0.05759166711340508, 0.04567151904226311, 0.08573198796159799, 0.023144617443904284, 0.12109159582084227, 0.06254873861889206, 0.09427925391543297, 0.04509481954418364, 0.1346937780298533, 0.5459564203216184, 32.69168453831827, 93.97630230073007, 76.2366065671367, 71.18395051648541, 52.12146289886967, 42.886434524290024, 38.802945152405776, 99.73269431821763, 75.10312787948116, 20.067542022274388, 0.1219991188977034, 0.9830878446659735, 5.000168854190457, 3.9389541985527163, 2.7069369919838446, 3.941188478662122, 0.9680568931564209, 0.2606976062299744, 2.4712952106229724, 77.8409501044981, 106.25801993954568, 100.66359827595373, 95.74662485430318, 90.88761621905913, 86.12810242560603, 81.63459593249907, 81.49327293519052, 79.84564996534779, 81.35514274720224, 82.27202815394249, 80.91876337605139, 76.83706652733588, 71.05552427230343, 70.00432906612274, 66.51689483273414, 69.87148623312675, 68.14970693280621, 70.57706571394398, 72.66320182431129, 70.11203735105454, 68.42942683927475, 65.03852605819702, 66.22066174784015, 66.50281352381553, 59.949333129390595, 59.50734476889334, 57.3668485303079, 62.01957971818986, 67.76929193927397, 77.00006454221665, 78.02639192150485, 75.84290258346066, 79.7168157946679, 81.12633520557036, 80.53095079237416, 80.72280176224248, 80.25907562625024, 79.94477610434257, 78.76415052721578, 76.2881386664606, 77.5824894443635, 71.34275944002214, 63.58464071827551, 57.880020064692346, 57.756755659657145, 59.478938964105424, 65.08932075192853, 72.39726512662827, 74.86735420842325, 75.31538301898588, 65.01157545274305, 69.90434000569006, 60.88908203186528, 55.43529695080173, 50.08425051166166, 43.55621061017437, 43.080344738498816, 54.7352127105959, 65.38645598196214, 58.65773193297848, 69.82231540064659, 75.7053921299596, 72.05436368142405, 72.88581202107092, 74.9682846376973, 75.08961139186736, 72.48984090743527, 71.11552869119953, 70.92688622013216, 60.26402881068569, 56.491328439404896, 54.65338030169087, 57.67504876659763, 58.71664593296667, 57.213354418354655, 63.761680818373165, 67.15082045524352, 71.07671291597428, 72.111951920294, 74.4951291238108, 72.92693414995748, 72.87573937446841, 66.51510623193556, 56.40941758309641, 57.334528200088016, 57.22710232580862, 55.6180440995001, 55.50426790791174, 64.65463584469211, 64.392339106529, 64.99186162025698, 65.5352589391893, 60.579002980263006, 60.586883021939194, 59.29567798491448, 59.86239771689139, 60.27625091614262, 62.2028563868615, 64.52153021289458, 67.90361742819509, 66.4223970905427, 69.54665906967656, 68.86086402400848, 67.27796016200897, 63.053159559926684, 71.11477559612644, 70.53247620982509, 82.22192379736131, 84.38206718813989, 77.57192257911929, 3.5046299042240268, 0.987946619429896, 0.9908462928668146, 2.2714671204167027, 3.993051773117435, 4.045708366940099, 2.0761397048350303, 0.17823983975235494, 0.0963743664925137, 17.413733043978294, 39.97549849171793, 51.15018990732009, 97.5983601231729, 124.39057242485785, 86.52705454057264, 33.037096300432765, 36.988954851704264, 47.882788873487904, 61.77383145978374, 73.51001016555294, 49.772794708128906, 0.06394971424954073, 0.025730805786987467, 0.047838057826964125, 0.05868468305937225, 0.0139580070672016, 0.022524203053645553, 0.04659371653331384, 0.04709484528810267, 0.01925176463931078, 0.0629627823288883, 0.05088097821440428, 0.029170937017507614, 0.17958593284410818, 0.13704720013324292, 0.13625054530078365, 0.09910622070873938, 0.08176829500664627, 0.16502500691961858, 0.09292229769691344, 0.2931710008171297, 0.28956946826750235, 0.3614871059694598, 0.2638718149354381, 0.27294027348679883, 0.6660647269698882, 39.98526519344699, 109.0045419816048, 86.26686803756222, 81.2897019232473, 65.08902265179542, 48.8081975906126, 52.45706873555338, 109.91829733694755, 87.64466331851098, 29.094822060677316, 0.18191773594627458, 1.3669768937172428, 6.947066706995811, 9.991462365273508, 6.128044436054846, 13.148142733881551, 4.899845901996859, 0.9978129125891194, 1.964783125346707, 81.22237836160969, 113.8456096956807, 107.30919945624568, 101.47807844223516, 96.78548812866212, 91.58485674089002, 84.65154186371835, 85.0146984284924, 84.11228656768799, 83.90668376799553, 83.72925927562099, 85.28793073469593, 80.35356552370133, 75.04707720971878, 74.72766291710639, 70.82604208300191, 73.83868125177199, 74.2915581118676, 75.10460269066596, 77.2598352739888, 74.88003915356052, 71.75722845139043, 68.6786699295044, 68.97851943969727, 72.32601919481831, 65.59885624916323, 63.15181501450078, 60.40686584288075, 66.19941034624654, 70.65417951153171, 79.39940975558373, 82.31608421571794, 79.64713881092688, 82.13512959018831, 84.65881393801781, 82.61940894588348, 82.5779494931621, 83.4651033339962, 83.84761287320046, 83.66105710306476, 82.374449083882, 81.19299196427869, 77.43072509765625, 70.44707052169308, 61.725245060459265, 61.00306218670261, 61.805041759244865, 69.40040173069124, 75.57942913424584, 79.31858539581299, 79.81303937973516, 70.38890177203764, 74.93430906726469, 66.74896578634939, 58.54961964391894, 52.29104657326975, 43.94503908772623, 45.494061516177275, 59.07518979041808, 70.72035774107903, 63.20313922820553, 74.55176030435871, 80.80046469165434, 76.26100370960852, 77.12834173633208, 77.10504285750851, 79.35161959740424, 75.71883017016997, 76.65175807091498, 76.29137069948258, 63.35823758955925, 61.259345931391564, 56.19309494572302, 60.57034238692253, 61.74274275379797, 60.866536248114805, 70.16076103333505, 70.59740712565761, 75.32628720806491, 76.92685742532053, 77.77771365258002, 76.53003907972767, 74.98329947071691, 70.87206717460387, 58.24992702853296, 60.256086011086744, 59.70826818097023, 57.715143234499045, 58.2582385309281, 68.48132764139484, 65.95743933031636, 69.72400511464765, 67.89512157440186, 63.40325463202692, 63.83699032568163, 62.342990906007834, 63.6317797630064, 66.44269143381428, 65.88110216202276, 69.49529955464025, 72.53685443632065, 70.37204342503702, 73.66524973223287, 74.76669834506127, 73.1298226694907, 68.51065912554341, 75.39588574440249, 75.1536636967813, 87.94617591365692, 90.07049237528156, 79.38746221603887, 2.3685935860679996, 5.4444620974602245, 7.514431668866066, 9.736782869985028, 10.450267887884571, 13.721424591156746, 1.7995046199329439, 0.2518415991817751, 0.35429994485551314, 29.241824649995376, 50.54035940477925, 63.133525002387266, 108.00778927341585, 134.0033995720648, 117.69921287413567, 48.47836156045237, 40.64403118625764, 58.30774276487289, 72.69392967224121, 85.02717941038071, 58.045002798880304, 0.20125901987475736, 0.2050545565303295, 0.1815081087331618, 0.1501625641098907, 0.15528197730741194, 0.14451111817071516, 0.15299212517997912, 0.27967421698474115, 0.1152289777453388, 0.15505685470998287, 0.1939423592580903, 0.10735174761183801], [0.014505959115922453, 0.0384754023604816, 0.03486089611185655, 0.11444978205667389, 0.06421877581986689, 0.08664210807652244, 0.08111067747156467, 0.07553232398124472, 0.05716576436234098, 0.07618509217976563, 0.062484574924793944, 0.0675267281551515, 0.19779739030186208, 32.2404452677696, 85.18835744550152, 61.8766014806686, 45.84439585285802, 28.39942897519758, 41.48993738235966, 75.54675579071045, 74.46958664924868, 48.93976957567277, 3.091912966582083, 0.026844314584929137, 0.2116279739646181, 2.636439987728673, 5.35975557181143, 2.570949398702191, 3.445084647786233, 1.1848851485598473, 0.21436934299286337, 23.29167146836558, 105.42997621720838, 98.30133515019571, 103.44529613371819, 91.9344497496082, 92.96813549533968, 86.34544095685406, 90.63926742922877, 85.86781394097113, 91.88157619968538, 89.11741133659118, 90.63238759194651, 86.6152137325656, 85.4302578587686, 73.09527443301293, 68.01622083110195, 64.53749818186607, 66.48644939545663, 61.68221665966896, 63.23258838345928, 63.22691271381994, 64.5407106030372, 60.935993579126176, 64.610928873862, 60.418189725568226, 59.36229551992109, 55.968076413677586, 56.388483893486764, 52.07190375174246, 65.13216087895056, 76.57043164776218, 77.15564927747174, 75.51165057766822, 76.43922052075787, 78.8555182180097, 80.10918617248535, 76.11197717728155, 77.13208367747646, 76.24274899882656, 76.84618211561634, 75.10089212848295, 72.37123627816477, 60.92446181081957, 57.858733361767186, 52.14162780392555, 54.73039211765413, 56.95144599483859, 55.521306683940274, 63.037556371381214, 68.20265108539213, 74.49403086016255, 66.69308770087459, 59.072471587888664, 60.69450893709737, 56.299826560481904, 56.20832550910212, 52.32014663757817, 51.927435013555716, 50.472196455924745, 50.69484587638609, 54.81122824453539, 60.11293126690773, 64.5577807580271, 69.29841226147067, 67.88622563885104, 64.74778429154428, 60.72972789887459, 65.10160169293805, 63.25375741527927, 63.7616180604504, 62.43707679933118, 56.126195000063994, 54.555230832869015, 55.316849216338134, 52.89051417381533, 52.94827891934303, 52.337573728253766, 52.78463371338383, 53.997512940437566, 64.48653874858734, 70.57750501940328, 69.71922766777777, 68.08757658927672, 72.16651993413126, 68.03540122124457, 61.90690963499008, 51.31652585921749, 54.55793726828791, 53.390628137896144, 57.91243845416654, 54.865494235869384, 63.88878130143689, 62.05867790406751, 64.93442635382375, 59.72371839707898, 58.181775846788966, 55.05556444967947, 55.7201708516767, 53.5353635972546, 58.98950561400383, 54.367110037034564, 58.74236099181637, 55.17672254193214, 59.44836408861222, 55.09698075632895, 59.55865721548758, 60.644910566268436, 70.5142136543028, 75.6315338996149, 81.83003979344522, 75.28294501766082, 87.61942678882231, 13.854763603979542, 0.4282493090196964, 1.647469874831938, 1.085559704130696, 2.0227368800870837, 0.8207767348616355, 3.6739593600073173, 0.4205515043389413, 0.19493216017801918, 3.733007701173906, 30.019448264952633, 33.99152271209225, 85.62854936045986, 96.06089299724948, 84.18796477779266, 36.53820783861222, 18.10285229836741, 34.31233729085615, 58.95884836873701, 61.374961714590754, 57.11628752370035, 0.5165764581291906, 0.0170106012299056, 0.05866525123917288, 0.02428276554471062, 0.020906504979657552, 0.0614373442236214, 0.048070190128900354, 0.09940051338485173, 0.023833525840253122, 0.03994446788584033, 0.04204192086152973, 0.038116068819597844, 0.06549995062091658, 0.05228929679780718, 0.04329092380019926, 0.023727596947743047, 0.04715902047351964, 0.05711663131331725, 0.018425797367648735, 0.1503971095887884, 0.10513168609430713, 0.1349561478221609, 0.059914633391364935, 0.10005793173707302, 0.31614551801354657, 43.72014999389649, 94.91196801585536, 73.29874346333166, 55.81693964619791, 41.35259166840584, 31.347160762356175, 58.27372797073857, 87.60917371319186, 54.87983834358954, 3.53272682236087, 0.22272524784409234, 1.3572019795256278, 5.957652753399265, 3.6173705900869066, 5.091724818752659, 5.663821629939541, 1.4202377776945792, 0.16125249886705031, 29.99081300150964, 105.14843633097988, 101.27391907476611, 105.93116098834624, 94.93755755885955, 97.23052809315344, 89.2387459355016, 95.52826650681035, 88.58271383470105, 95.59353474647769, 93.04039339865409, 95.10098703445928, 90.67309394959481, 89.69169339826031, 76.8484414008356, 68.48213564965033, 68.14995796449723, 69.00476794089042, 65.88315748399305, 67.17958711808728, 64.76332864453717, 65.31537086732926, 65.73889663142543, 65.57946797340148, 62.66810832485076, 61.93896324403825, 57.45281511737455, 58.70576135573849, 57.149478620098485, 68.49316535457488, 82.19544779869818, 81.37588424067344, 78.52431328065934, 80.61604269089239, 84.3697666352795, 82.4855149176813, 80.21734945235714, 77.3984989043205, 78.53380541647635, 79.38991761976673, 78.68400865985502, 75.39659177103351, 64.68036267065233, 59.326970654149214, 56.012630616464925, 58.94719892932523, 60.814709971027995, 60.41527148216002, 65.73972817390197, 72.67709485946163, 78.58551794482817, 69.38706567210536, 62.21558055570049, 62.71899715546639, 58.48889743128131, 57.32554989476358, 54.86050890338037, 55.12005606005269, 54.367874899218165, 55.154557228088386, 57.92413496202039, 63.777852750593624, 66.78205490112305, 72.77100424612723, 70.19120647061256, 66.3554657659223, 65.22701555682768, 65.73536257590017, 65.43073169646725, 67.03440450852918, 65.02165202171572, 59.64889918604205, 57.59932741042107, 57.79537923874394, 55.52859444772044, 54.6436724355144, 56.25246394065119, 54.932707971142186, 55.96299302193427, 67.54362229377993, 72.66820676865117, 73.2544049909038, 72.77207897555444, 73.65677741266066, 70.72489200099822, 65.89006870023667, 53.577642825342, 56.29047170762093, 55.08808874314832, 59.4855167788844, 57.452540551462484, 67.59288726314422, 66.59818203218522, 67.73264915712419, 64.0973964814217, 62.33839388816588, 58.70657328636416, 58.471411505053126, 57.94616691527828, 60.4006096624559, 58.032929743489916, 61.5876090911127, 59.746236724238244, 62.69346252564461, 57.73681040733092, 63.7162087809655, 66.51254884658321, 74.43867052755049, 78.39304724047261, 86.725871639867, 78.17024092520438, 92.42112959584883, 15.920843655063262, 0.2689778828813184, 0.37428212261969046, 2.2188590659249217, 4.736418387582225, 2.09091846019991, 3.7538955480821676, 3.9337266597055622, 0.2996802047616051, 2.599153691722501, 36.736044345363496, 38.763584167726584, 88.92133989641744, 97.44904333545317, 83.70074364446825, 36.1298773365636, 22.304579557911044, 40.032019845901, 65.77648862715691, 67.98870148197298, 68.70702082110991, 0.7975241277487048, 0.07110342413427369, 0.13419502414762974, 0.05685010166358083, 0.049474107537178263, 0.023419616195643624, 0.015550736420517488, 0.024576508552737297, 0.05899859524722542, 0.029420641461207025, 0.049268700212480566, 0.04004709685461656, 0.13370118854988006, 0.16436065547168255, 0.20962865302158942, 0.18175851223209213, 0.11075693948735153, 0.13236759801305112, 0.14315754806082095, 0.2593084130316012, 0.19391919275926006, 0.2189811922970318, 0.2074111042724502, 0.19516336551356703, 0.5621900072982234, 54.68271570820963, 112.20119522463892, 81.38396432322841, 68.11198942122921, 44.64058906801286, 53.10795076431767, 103.28618911004837, 93.01098346710206, 72.8731192311933, 4.823114535500927, 0.2670145527489724, 1.2240831097287517, 9.96037660106536, 14.492409594597357, 12.082472020579923, 11.822925844500142, 7.93897234624432, 0.6413685037724434, 36.62892049358737, 113.42394705741637, 105.174206303012, 110.4060911363171, 100.26872542596634, 102.99691430984005, 93.53004640148532, 99.38301501735565, 91.96165530912339, 98.7926826169414, 96.18942122305594, 97.9480786477366, 92.48857867333197, 95.26183559048562, 79.44487002588089, 73.92156093351304, 71.15001416975453, 73.82304668426514, 68.22904863665181, 69.50198327341388, 69.63766590241464, 70.70852002789898, 68.07830410618936, 71.18801409198393, 67.35297156918433, 65.7945982102425, 60.86097040484029, 62.05443389954106, 58.98741891307216, 71.82216721196329, 85.16455650329591, 83.72744714060138, 81.80588583792411, 83.06777508028092, 85.84570746267997, 87.02183015884893, 82.98153784967239, 81.06160825298679, 82.59799280474263, 82.96325960466939, 82.8557631277269, 78.74325998367803, 68.13462149712348, 64.71309484974032, 58.04795634362006, 60.66353790221676, 63.02603244781495, 61.14557366217337, 71.28051927012783, 75.89016714403706, 81.22920328570952, 73.73327147576117, 64.1407229823451, 68.56905537266886, 63.100169166441894, 59.55134591748638, 56.73182856652045, 56.98903014582973, 56.328310812673266, 58.08164950340026, 62.50236857321955, 68.4436885772213, 74.84943682147612, 77.8998484150056, 74.687591983426, 70.0974069103118, 66.58930963085544, 71.83166719252064, 69.34680646465671, 72.61214825414842, 68.38297813169419, 62.30213549829299, 60.425520635420284, 60.25186554078133, 57.045931969919515, 57.00666512212446, 57.97992283298124, 58.559594231267134, 58.87936938193537, 70.4846154489825, 75.75582596563524, 76.13559769045922, 73.94443619635798, 77.0897142348751, 73.02362057470506, 69.44259074426466, 57.74061118402789, 58.93063476008754, 58.77453619433988, 64.36412549787953, 60.898021113487985, 71.50276076409125, 68.5723501636136, 73.74892173274871, 66.60714857039913, 65.94232251567226, 62.62095359063918, 61.528651945052616, 59.59751613678471, 64.91565389017906, 60.24138104531073, 64.81159340950751, 63.00426721572877, 66.95473332558909, 60.41065877483737, 65.96877498011436, 70.50755346975019, 77.2441771722609, 81.89337822698778, 91.47262204077937, 82.74985128833403, 97.30638673228603, 17.25727754254495, 1.006907969713211, 5.075571027494246, 9.283965826034546, 7.203310737686773, 5.486325554309353, 9.47004012523159, 2.745594156365241, 0.20255136423774306, 5.985220151562845, 53.134583657787694, 52.814102480488444, 97.51988918550553, 97.12153327080512, 96.52285406666418, 51.45384019420993, 27.95613446543294, 51.08844003369732, 75.39102200538882, 78.2845623262467, 78.42364172781669, 1.006041493627333, 0.15516519486423463, 0.23826267540214524, 0.16964018104537842, 0.1672631174686455, 0.12999376732735865, 0.25337340730813246, 0.1774066425259075, 0.18186106076163633, 0.12742555715263854, 0.14359941225378745, 0.15549661982203686], [0.03751681952346717, 0.05134561820135963, 0.03787051848766785, 0.05119634596931358, 0.12377842704975799, 0.08121515654267804, 0.09109137054052084, 0.060285676586171316, 0.0929298053585714, 0.06913346734138266, 0.0635783416369269, 0.06662480518101685, 0.06813876345873841, 40.32126326714793, 79.65510906711702, 63.741111909189534, 53.96472584816718, 42.16425557290354, 68.8767025547643, 78.09897930391374, 54.98111786380891, 23.16492792098753, 0.21936454269434177, 0.23902913104862938, 0.18796255271280968, 4.139929827182524, 2.7341224493518954, 2.0918549260785504, 3.92857143955846, 1.8710200921181712, 5.843204855918885, 73.22662676534345, 85.48894436128678, 105.81527063923498, 95.38135805437642, 98.91312291545253, 92.35822262302523, 95.08766666535409, 93.58074695833268, 95.50675622878536, 94.34706041889807, 93.30802456025155, 94.26719311744937, 94.50530452112999, 87.87016822445779, 88.24921823317005, 71.38907478701684, 63.193317613294056, 60.692908610067065, 64.55508216734856, 61.529707062628965, 62.685080420586374, 64.15989945011755, 63.43085242855934, 61.40639166678152, 62.48118777428905, 59.298160845233554, 54.93628125036917, 55.256931089585834, 58.70602807691021, 75.83774858905424, 78.64260412031605, 75.42608799472933, 77.92969765201693, 77.15440980849728, 81.15332111235588, 77.87885588984336, 75.28187813297396, 76.22710658657935, 74.06450779207292, 71.2004009369881, 63.9561793881078, 57.3595372323067, 56.051156136297415, 55.08779848775556, 55.36121906772737, 57.01801253903297, 56.54305665723739, 58.164948878749726, 63.85225226802211, 68.80443680670955, 71.04995450665875, 62.00043855174896, 58.84713534385928, 54.55425808506628, 55.863478568292436, 55.39426111405896, 55.0819698456795, 53.94554938039472, 53.64168728551557, 54.27309474637432, 54.13546269939792, 58.05240431139546, 59.70942135780089, 63.74848596511349, 66.83898418180405, 64.18932899352043, 63.31245568490798, 60.43031377177085, 57.22990289811165, 59.434098428295506, 56.4842995520561, 52.18274208807176, 52.11088426651494, 55.332825030049975, 55.95203784204299, 56.49188149359919, 51.890458829941295, 52.07989361978347, 49.17556678095172, 57.20816120024651, 66.16921594066005, 71.2064806107552, 69.03664112091064, 68.35662764887657, 69.5053957354638, 66.2175238517023, 55.38245477984029, 51.6349164132149, 53.7606410057314, 53.05867795021304, 56.29867338365125, 60.061042231898156, 65.77727702356154, 64.352413300545, 62.10342038062311, 59.15020511996362, 56.6011038134175, 55.98358154296876, 56.305953302691066, 54.38854971239644, 57.479671585944395, 56.904055918416674, 57.72615332757273, 59.11464098961123, 65.98367214202881, 68.8690225539669, 75.84444799730855, 77.25780348623954, 77.7906810083697, 82.5432365171371, 82.05178706876694, 83.927135006074, 32.075605700092936, 0.4646081483412174, 0.4062709206294629, 1.074186178945726, 1.1643537470409948, 1.9779654760514538, 2.1499542988115743, 1.4535851560292707, 0.3334213216458598, 0.14304799748764885, 23.149989574186264, 29.28391952668467, 40.52796825285881, 78.55701015841576, 47.45291671445293, 38.131721711927845, 42.451408370848625, 42.52761217855638, 55.47964719034011, 58.43626706830917, 59.55924164864325, 3.1396572820601927, 0.1327086450351823, 0.1915974407306602, 0.038823520374153896, 0.04499563797106666, 0.046656715773767045, 0.0945286231956655, 0.02560822405822335, 0.07288592687297253, 0.039719686197537574, 0.03678105335922972, 0.048465698341568636, 0.010320020223697348, 0.01542233625396846, 0.0982943130657077, 0.01055816535822927, 0.08994287450707729, 0.04143893305632857, 0.05521470695854195, 0.09355626609777251, 0.1322343906447772, 0.0479898389969622, 0.05889967031356308, 0.03331490003714158, 0.030321683434228745, 52.31598892519551, 90.7143965075093, 72.58710784296836, 60.42549710119925, 54.036203199817294, 57.927296392379276, 76.01372180446502, 69.03560561518516, 26.467987222056237, 0.10543810594226084, 0.7640673520584261, 5.8425983594309905, 3.6303097538409697, 5.150934957688855, 1.4434682601882567, 2.080377090361811, 1.4692653210893756, 8.783289001834008, 85.86488000808224, 92.966276291878, 106.17349286233227, 97.45500533811509, 102.98571202062793, 96.81816931693785, 100.61096006824125, 97.98242292096539, 99.40709837021367, 96.32180906111195, 96.68683267408802, 95.75393615230438, 98.25381955792828, 91.89532018476918, 90.83858659190517, 74.00927297530636, 66.79573612828409, 64.98794709482502, 67.61285997206166, 64.00781739142634, 66.92597450748568, 63.599663396035474, 64.99736470560875, 65.09400798428443, 65.50079307248517, 60.320052023856874, 59.340302790364916, 55.925930546176055, 61.93555078198833, 78.34296641811248, 80.29153716179633, 77.29981207078504, 79.37570295026227, 81.20981108757758, 81.48149797993322, 81.37786895998063, 79.42296751083867, 78.01518963229272, 77.35768272030738, 74.3014346399615, 66.7365240281628, 59.56478395769673, 59.07187930999264, 58.93396092999367, 59.47975873947144, 58.580327879997995, 61.04553753329862, 60.794011623628684, 67.34849222244756, 73.74694485818186, 76.17731601961198, 63.99723483670143, 59.943626080789876, 58.20405490936772, 56.593847428598714, 57.4844607999248, 54.732694548945275, 56.08559062404018, 55.57500785396945, 57.51478464372697, 55.32516464110344, 60.47614666723437, 63.57829824570687, 67.76766023328229, 71.75587915605115, 68.58849463924285, 67.52997244558027, 64.48821752302109, 59.207467802109264, 62.72872855586391, 61.530954376343765, 55.440097931892645, 53.81822532223117, 57.037498874049035, 57.88452294565017, 60.15819149632608, 56.05261133563135, 54.053763651078754, 54.383297658735714, 58.76831923761676, 67.2332529867849, 72.84854950443392, 71.53972518059516, 71.347991881832, 71.07599904460292, 68.7481507947368, 59.76406389667142, 54.50715826403711, 55.59042669111683, 57.23898710743074, 58.59477789171281, 62.963819734511844, 68.66199985627206, 68.46293957002702, 66.89539570962229, 60.47622119226764, 59.274932569073094, 59.31815316600185, 59.38500212084863, 57.75321375939154, 60.61887779543477, 59.47124327382734, 61.50821247408467, 64.93408510761877, 70.74957939886278, 73.76913762861683, 78.49712341062485, 81.0931597986529, 80.75918566796088, 83.04828090052452, 87.15584970289662, 83.20380287785684, 43.213313087340325, 0.7320062659921185, 0.32689192362370034, 0.8782278746366502, 1.4687980687425983, 4.191190302371979, 2.6670626671083513, 2.95618032736163, 1.2325434170423017, 0.20500684457440532, 23.625780920828543, 43.61679946222613, 42.77369776079732, 84.79464561708512, 54.04421660207934, 35.78869781186504, 47.74405856286326, 55.263524593845496, 62.52322381542575, 64.52561732261412, 71.09484211091073, 4.533696078485058, 0.29436024506726577, 0.2778690380434836, 0.09046112532697378, 0.11165505500450251, 0.04611821725003181, 0.16990694818237137, 0.02922020987757752, 0.08292572362528694, 0.054321119021023476, 0.028679123891878034, 0.0335673987865448, 0.1061455958012131, 0.11348550718638206, 0.1568223349750042, 0.1675988325188237, 0.17649613170614167, 0.16883206553757193, 0.16944340370114774, 0.17678765880484737, 0.23817618407549399, 0.22193479832381974, 0.17584075880867822, 0.20792082853374944, 0.254656282824374, 60.37392185580347, 104.05703683053295, 81.96981737690588, 74.6041553251205, 55.71200055460776, 94.37231263806744, 98.28061719094553, 74.7580534412015, 36.99240261508573, 0.3657842157108169, 0.6189793083936938, 6.693748274157125, 13.069401152672308, 10.589396319081708, 4.33772171697309, 17.81404426020961, 2.2256273608053885, 7.6754611442166, 88.75301530284267, 99.19759673456993, 111.84015673975792, 101.21548360393894, 107.99425709632136, 101.58107203821983, 104.2160261830976, 102.07795004690848, 103.99465545531243, 101.94651926717451, 102.27393519493842, 101.07441948306177, 100.96852333314958, 94.36422471077212, 96.10254072373914, 77.16784784870764, 69.83525922221523, 66.77765400178971, 71.8431205134238, 68.98448928709954, 70.74750054267146, 71.77157648148076, 68.70695806318714, 68.76378536224365, 68.94755624955701, 63.84371719052715, 62.78206494546706, 58.911983889918176, 63.532308455436464, 83.30411357264366, 84.62466578329764, 83.36508289460214, 85.00155064367479, 81.77924509971373, 86.79610560017248, 86.63577479700889, 82.22046467565721, 83.22450514762633, 82.35631988894555, 79.57088793477705, 72.45078194525935, 63.271172738844356, 63.15546674113121, 62.23621222280688, 61.640686604284475, 64.25315380096436, 64.80291320431617, 63.141942408777055, 70.91391886434248, 77.75395977881648, 80.22921854449858, 67.42693962589388, 64.76230098355201, 62.23616907673498, 58.66833802192443, 56.9323322849889, 56.777900726564475, 55.104660757126354, 56.95396023411905, 58.36082420041485, 58.06564231072703, 65.57528280442762, 67.84282069052419, 71.2299991423084, 74.1530356868621, 70.02361143788984, 70.6663074801045, 67.50945060483872, 63.47708148341026, 66.45082642955165, 65.72120281957811, 58.03851912098547, 57.663673893097915, 59.23512443419426, 61.3932046582622, 63.12927315312048, 57.544371081936745, 57.91958893499067, 56.844188782476614, 62.756514626164595, 71.30400642271965, 78.2736816713887, 74.77899105318131, 73.56988122386318, 74.93856091653147, 73.49886278952323, 62.29708740788122, 57.80202765618601, 60.31171698724071, 60.07927340845908, 61.37202385933169, 67.28877021420386, 74.71252256824125, 72.58859834363385, 68.60148552925357, 63.62239745355422, 63.47909365930865, 62.454633328222464, 61.70007913343368, 62.929322488846324, 62.706080790488954, 64.32196786326747, 65.06931274167954, 67.7436710173084, 74.3891231475338, 75.88622908438407, 84.2823762278403, 83.58604569588938, 84.12989016502135, 87.43252585011145, 92.82944048604658, 88.87193372172695, 42.98405447313863, 0.7931753836812512, 2.2155265221672673, 4.844480176125804, 4.914330724746951, 5.647356500548701, 7.629504694092659, 3.2871518836867426, 1.0951665692752408, 0.3393765214470125, 33.87542839973204, 53.68310359216506, 57.55660103213403, 88.76302519152242, 69.33259179515224, 52.989169628389426, 56.69651939022926, 62.38726269814276, 73.14908150703677, 74.70669392616519, 84.64675657210812, 5.825561054291264, 0.4531105475560312, 0.3959492954515642, 0.3069888674203427, 0.20769415843871333, 0.2261670817050242, 0.32134250527428043, 0.08473021308741263, 0.20652952093270519, 0.1361342378321194, 0.14720046982890175, 0.14465475965651775], [0.07520776317124406, 0.09327706535376849, 0.07143446604811376, 0.021725604273078424, 0.09988072027842845, 0.03600219091881187, 0.03207332240567813, 0.00722619520890857, 0.022161374236607266, 0.05194652224740675, 0.028304485829486966, 0.022667260397405877, 0.0440591529402281, 39.58040598900088, 79.22170285255679, 61.47675114293253, 55.67308672012822, 30.821841647548062, 55.607206590714, 78.42361819359564, 50.45106272543631, 7.517413650789569, 0.09139642675196932, 0.253663448196265, 2.1463256161059103, 4.441098234345836, 1.3091339459342342, 3.409244235484831, 2.3734105017877396, 2.604326072239107, 68.97632291240078, 89.28342173176428, 79.10749912261963, 88.24428389149328, 92.4757682123492, 99.63478411397627, 96.8336783685992, 96.56705917850618, 93.57843275993102, 96.72358528260263, 97.08065432886924, 94.35931390331638, 89.42435249205559, 93.66064563874276, 90.50088620954945, 87.38872866476737, 80.91088725674538, 66.81848587528353, 64.08844171031829, 65.61689130721554, 60.725495661458666, 62.099509777561316, 61.65503463437481, 62.87969666142618, 60.80821452602264, 60.103776454925544, 56.81276275265602, 55.310573424062426, 54.77957863961497, 62.34069631945703, 75.7586108484576, 77.3570865200412, 71.48560431695753, 72.29206715860676, 75.74527478987171, 75.37703483335434, 72.19813423772013, 70.1442478549096, 68.26366747579267, 61.86559530996508, 57.62038269350606, 53.97728919982911, 55.521569482741825, 62.785540165439734, 67.89658854084631, 67.60426213664394, 66.28435319469821, 65.64912142292147, 62.41916333475421, 65.83262166669293, 69.038037484692, 68.84213862880584, 62.49903063620291, 56.63775051793745, 52.76968556065714, 59.33195206426806, 58.33552491280341, 57.71358997591081, 56.290679593240064, 55.48291844706382, 55.9058048648219, 54.8831174450536, 50.26613081655195, 57.410535889287154, 60.85105465304468, 65.8442005034416, 68.261808272331, 70.77152113760673, 63.22338650303503, 57.9833431397715, 56.63209446014897, 54.535301270023474, 50.10440757197719, 53.49087999713037, 58.15244044027021, 65.87153942354264, 66.69759842657274, 63.876731780267534, 50.682929715802594, 49.87744746669647, 51.570820962229085, 59.62415687499508, 62.580800287185184, 68.03601311099145, 63.737013032359464, 69.38988977862944, 66.39745866098713, 61.60101575236167, 53.08702884181854, 51.03286397072577, 51.83416105085804, 52.35772294382895, 57.8479782227547, 64.70029223349788, 63.888851904099994, 63.43402562602874, 59.69538319495417, 56.85132357382006, 54.26374773825369, 55.75263630959296, 55.84476886257049, 61.09472405525946, 61.70000853077058, 67.38045953935193, 70.40110034327354, 73.57886345155778, 75.81666977174821, 77.29031209022769, 76.30834671758836, 82.32106562583678, 78.32408412810295, 82.86777342519453, 78.04236381284653, 85.2218544867731, 24.775953215937463, 0.05654455132542118, 0.6622530411808722, 3.257993474122017, 0.910110860582321, 1.512150432794325, 4.980881579460637, 0.19584423381715052, 0.12901147406908775, 3.578952935434157, 54.80026914227394, 27.523632357197425, 48.69115406467069, 44.41802201732513, 43.645711252766276, 25.376664207827663, 22.486785419525642, 55.3793639521445, 54.43435515126875, 68.10590974746212, 6.6989454146354435, 0.2076419265640359, 0.07142904214560986, 0.06204291757556701, 0.14582071483375567, 0.07113131739559674, 0.05115355612830289, 0.04060285533928583, 0.034549814618883595, 0.06612870962389054, 0.028215908828461846, 0.02565438277088106, 0.05583904563419281, 0.05354100785728905, 0.10018985973851335, 0.007022598245736933, 0.07733417044003164, 0.04644796830571948, 0.06456673295507509, 0.05415844025030252, 0.09766311790313452, 0.03942330593183156, 0.03740204423065147, 0.06626691954630999, 0.06437842854328694, 46.42434181705598, 90.04964105544552, 69.98666271086663, 64.02729588170206, 35.248587439137125, 55.11791052356843, 83.7689144380631, 58.941401666210545, 7.412780504072867, 0.21448284657972477, 1.3506503955971811, 3.494032640610972, 4.49608741268035, 2.359665536111401, 1.8327053996824452, 1.1935448838818459, 6.822456928991503, 78.28393474701913, 93.31526525558965, 91.29117319660803, 92.15117639110935, 96.37494148746615, 100.43054672979541, 100.32254818947085, 100.49660728823756, 97.05363704312234, 97.79521603738108, 98.91697468296175, 96.62401983814856, 93.06620259438792, 95.42530428978705, 95.20423166213497, 92.04509196742889, 87.07883004219302, 68.854046944649, 67.50988206555768, 66.16025724718648, 63.588461106823345, 65.75319367070352, 64.82702793613558, 63.94966040888141, 62.92191705396099, 63.13592157056255, 58.38740218070246, 56.86474984691989, 57.227192540322584, 65.23720587453535, 79.60509884742, 78.47802931262602, 76.861675477797, 76.07234554906046, 78.73610558048372, 77.92139007199195, 74.99856533542757, 73.57942042812225, 69.2056482068954, 65.08138579706993, 59.180846675749756, 57.74416485140401, 57.416611640684074, 65.60782670974731, 73.55497621720838, 74.22988276327811, 70.56124287266886, 69.19647770543253, 67.16262678946218, 69.37591829607564, 72.4080124209004, 71.96965617518272, 65.96615483683925, 60.48586237815119, 54.059702119519635, 60.312332799357755, 59.818012176021455, 59.258317409023164, 58.20492959791615, 55.66444966100878, 56.34522407285629, 55.89529291276009, 53.24681835789835, 59.49254174386302, 63.88777325230261, 68.88442962400376, 71.24655938917591, 72.34669008562642, 67.55138858672112, 61.34615975041544, 58.19718683919599, 56.701171321253625, 52.908196218552135, 54.578333593183956, 64.14425311550018, 67.95099181513633, 72.40645131757184, 68.56022219504081, 53.7031469037456, 52.66853940102362, 54.37957925181235, 63.42558468541792, 67.39698056251773, 70.43648796696817, 69.51380529711324, 68.75255953881049, 68.39937363901447, 63.828894553645966, 55.63161157792615, 54.55814515390704, 54.160177553853686, 53.7277283976155, 61.89112993978686, 66.26216042426326, 68.18711065476941, 66.26741640029415, 63.28179059490081, 59.162505672824004, 59.84132282195553, 59.9700040201987, 60.99761793690344, 64.21259649338262, 66.96122877059445, 70.35786013449393, 76.4591932296753, 77.81140681236022, 79.36105682003883, 81.02498900505805, 79.97970088835686, 84.31704998016357, 80.62076522457986, 79.99555510859336, 81.15378395203622, 88.69831392841955, 38.848036719906716, 0.4792730936840658, 0.5295406269931024, 1.5966806969335003, 3.658753556589927, 2.7808038025133075, 3.9831769610604937, 0.6624403956436342, 0.26829532918430143, 2.2868477144548973, 61.160521814900065, 38.35145681135116, 54.437618563252116, 53.06171778709658, 35.953723692124896, 34.0031760738742, 31.43052289562841, 61.40234770313386, 61.01715918510192, 77.40016983401391, 10.276661822872779, 0.489012859761715, 0.09987538830647547, 0.09295197594310008, 0.10003584542221601, 0.0304925401935414, 0.029812853580581087, 0.08790479717595924, 0.07589001809397052, 0.09987377186095524, 0.04009598858594414, 0.00463457242961252, 0.15638675270301683, 0.18551602028310302, 0.19998337622852097, 0.10250592739471506, 0.23359848697098995, 0.26217658493307333, 0.15208876962142606, 0.10630534045518407, 0.295711133869425, 0.16020468976949492, 0.1603163087800626, 0.18388911000182553, 0.12685478334465336, 55.74997302024595, 105.29087328141736, 78.08293680990897, 74.93627025235084, 43.138380127568404, 74.49112830623504, 93.27647301458543, 72.90005022479643, 12.704041196453957, 0.38763488192231427, 0.9031924737557289, 7.6269821197755885, 11.249183108729701, 7.280588294229201, 15.313035134346256, 11.278778372272368, 5.731961534869287, 80.24082091546829, 95.47866421361124, 93.1548010918402, 93.45097141881143, 98.02164662268855, 105.40725784917032, 104.33653708427184, 104.13699826886578, 99.48409449669623, 102.18679581919025, 103.293578855453, 101.08625719624182, 96.59616316518476, 97.49592350375269, 97.71046930743803, 94.49190570462136, 91.45217864744126, 74.35935235792591, 71.1194981298139, 71.1062091396701, 66.77362964999291, 67.00087608829622, 69.98929854362243, 70.17889807301184, 66.1095880693005, 67.73453189480689, 64.20043322347826, 61.2214126894551, 60.01582122618153, 70.10662448021674, 83.17950771700951, 82.80358775969475, 80.84579160136562, 78.49944545376685, 85.01762451664095, 83.25854347598168, 78.43035682555168, 76.94547299415835, 74.83551240736439, 69.7320459735009, 63.86616491502332, 61.25920472606536, 61.50586297435146, 70.00639223283338, 76.17792790935886, 75.42110658461048, 72.55510914710261, 73.9871508075345, 69.43807217382616, 72.160095091789, 77.5239755261329, 76.55855471088041, 69.92544235721712, 62.23075620589718, 54.77740172416934, 61.137132721562544, 61.410490543611594, 61.37184735267394, 59.62946384183822, 56.937376453030495, 57.44968114360687, 56.95515655702161, 58.40729644221645, 65.06809288455595, 69.53042830190351, 72.9100287345148, 72.50401635323801, 76.0782055700979, 69.24521707719373, 64.52956714937764, 63.12549591064454, 60.48667823114703, 55.42723255772745, 58.36111837817777, 65.15453015604328, 72.23125473145517, 73.4893314300045, 71.63220682451802, 56.053191846416844, 55.72117890081098, 56.99122275075605, 67.14157935111754, 70.82877205264184, 74.97422310613817, 72.29419308324015, 74.73830038501372, 72.55976892286732, 67.38649214467695, 58.213637259698686, 58.07806053469258, 58.6085650228685, 58.081300412454915, 64.38201542823546, 70.02209740300333, 70.73782797782653, 72.58407977319533, 67.25784624776533, 63.4947282268155, 61.12716990132486, 61.73960878003029, 62.62373847346153, 68.8791814927132, 69.37383943988432, 72.66062090473791, 77.58895351040748, 80.66257769061674, 82.57291316986084, 85.76859366509223, 82.15864812174152, 89.64852379214379, 83.36614193454866, 85.12556029904275, 81.67639270905526, 94.60294800419962, 33.12066631932413, 0.4087347206809829, 3.6925832638817453, 11.401727026508702, 10.052918061133354, 5.652637481689454, 12.885238028341725, 0.43446914623341254, 0.25242492917083925, 5.668736359765453, 73.04855115952031, 46.96257337447136, 66.46374671689927, 60.54348591835269, 62.20921062654065, 34.114418414331254, 36.512253515182, 73.21535387346822, 71.50336480909779, 90.35967303860573, 13.36267480927129, 0.826611812076261, 0.31871338344870076, 0.28297430925792266, 0.21785455275206797, 0.17070953253536456, 0.15134764084171864, 0.2042132540936432, 0.13466711817008836, 0.14619596002082672, 0.23253163292763696, 0.17553887420123623], [0.00731437863226259, 0.07249676186831729, 0.07275854943380242, 0.05308292941340516, 0.10312281203486266, 0.026030022493233124, 0.0673274610251669, 0.11971839087744875, 0.051542384054271445, 0.01221560232806951, 0.10932387243355475, 0.10063099614795178, 0.011488893238316861, 34.132657435632524, 73.44827990378104, 52.73476862138318, 45.94996252367574, 33.60971527714884, 67.27803860941242, 75.4285983116396, 33.36707353591919, 0.819183333266166, 0.07949929579251236, 1.493214455343062, 5.439878807913873, 0.4207240886265232, 3.0845085122892937, 0.45066770767011954, 4.767488462309684, 87.45271036701818, 81.10014946229997, 83.77904984258836, 95.41818911029448, 99.13801593165245, 96.39463178573116, 96.19706984489196, 96.79050876248269, 95.53986103303971, 93.79064083099367, 93.09511830729824, 87.08020287175333, 90.86835738151305, 90.29860173502277, 88.74470772281771, 93.11692668545632, 88.9606342008037, 84.31570852956465, 75.75855593527518, 60.55016179238597, 62.55905074457969, 61.36576767890685, 60.605012216875636, 63.135482265103256, 59.94492046294674, 58.83363846809634, 60.89268669005364, 55.20113145151446, 54.72692082005163, 54.891362267155806, 62.254313961152114, 76.98585771745252, 74.65840954934397, 74.58609673284715, 75.3613139737037, 73.18387293046521, 70.43113785405313, 62.015292567591516, 62.05597931338895, 56.43964336764429, 56.097616610988496, 55.980518171864176, 57.05653413649529, 61.883755883862904, 72.90529051134664, 76.01369827024399, 77.60410954875331, 69.75708638468097, 68.7411532863494, 67.25865425602083, 69.65909773303618, 65.90929615882136, 61.27936963112124, 58.92528072480233, 54.58739819065217, 55.83060910624843, 58.34333042944632, 55.8677343399294, 64.36456088096865, 62.05897208183043, 64.67428691925542, 64.52299325696885, 54.554297308768, 50.30890034091089, 50.08205790673533, 58.07613857330815, 59.08529381598196, 69.65826619055964, 70.62456561673072, 66.39551316538166, 64.58509222153695, 59.58869864863735, 53.63791788777998, 53.73973869508313, 61.37848008063532, 65.1433631681627, 66.80565188007971, 70.11625782135995, 67.13707647015973, 60.539587082401404, 50.194237693663574, 52.830592124692856, 51.58177614212037, 56.04833595214352, 59.54332074811382, 65.87340647174467, 62.6388592104758, 62.3530125617981, 63.152905433408684, 52.448141421041186, 51.119324776434134, 52.90533288832634, 51.92209274538102, 56.028516215662805, 61.17668198001001, 64.51093981342932, 61.43547211923907, 60.350552374316806, 55.73555438749252, 57.23324475749847, 55.45480289766866, 65.06231131092196, 71.77212561330488, 73.04385216005387, 72.94482015794324, 74.46358542288505, 75.5501211843183, 77.26681709289551, 77.98129250926357, 78.25758426420151, 71.64879845034692, 78.39706374752906, 79.83228252780053, 86.08719994944911, 78.0414616677069, 93.80299629703646, 27.74680345289169, 0.6703014996263289, 1.215410626703693, 3.0131652566694447, 1.9898232913786367, 4.034262400481009, 3.042508753076677, 0.36008335710052525, 0.2566529071379093, 30.89343470911826, 56.91030817647135, 33.45711546559488, 71.4730998008482, 28.1846615575975, 30.97873449325562, 25.601051238275346, 55.1817157191615, 51.995362620199884, 71.98711856718987, 16.11406941567698, 0.38246464645189626, 0.06417456871619628, 0.06224670079386523, 0.12004553340375425, 0.01121534909602375, 0.014308355354343452, 0.04239353989701598, 0.009617668899497198, 0.030550739893148986, 0.04871990929748263, 0.05619871242332363, 0.09528086791115423, 0.06232223323275966, 0.032314833539027366, 0.052251769980836305, 0.047269758482974385, 0.012419845199122304, 0.07421090658153258, 0.04018675085277327, 0.06802994832997361, 0.026406977971595143, 0.04779269010008824, 0.14871163954657896, 0.04617454769510416, 40.55974337362474, 83.47829818725586, 61.10902109453755, 54.24818377340994, 30.199394841347974, 58.19166414199337, 87.04304233674081, 36.72296324083882, 0.835900474940577, 0.2524570129331081, 1.8360380660141669, 6.243259647200185, 2.850545260214037, 1.4274743055143666, 0.3532571153294656, 10.459820820439248, 96.20413795594247, 87.62560844421388, 90.73072925690683, 97.50960473091372, 101.71370306322652, 95.88073069049467, 97.34738334532707, 96.92985488522439, 94.78275729763894, 96.2099273743168, 96.40705000969672, 89.86682722645422, 94.5732399725145, 92.8810667222546, 91.980357170105, 95.60192861864644, 92.00225184040686, 89.44051265716554, 80.46134441129624, 64.89937997633412, 65.27516657306303, 63.06779784540977, 62.53416722820651, 64.63373745641401, 63.674200196419996, 63.19811074964462, 61.845799107705396, 55.712796795752745, 57.65771581280617, 57.448473053593794, 66.45666291636806, 82.33913206285047, 78.22678581360849, 78.9964803572624, 78.87552230588852, 78.07727290738013, 73.10192677282518, 66.86331072161275, 64.0235225615963, 61.343559218991196, 59.83257985884144, 58.57597012673655, 59.11960278787921, 64.12244081497192, 77.18090934138145, 79.09319031623103, 78.64051741938438, 74.81995628726098, 72.5642639590848, 72.0280602670485, 73.35353112989857, 68.77006115451937, 66.91914958338585, 60.882755248777336, 56.94994764943277, 55.12999926843951, 57.89971820769772, 57.555153677540446, 66.36127871851768, 65.32099554615637, 69.1909706977106, 68.60991862512404, 56.850303757575254, 52.47609223088911, 54.72523420087753, 63.21604774844263, 62.989009195758456, 70.95009096207158, 70.93299727286063, 69.80064038307437, 67.91886760342506, 62.731250639884706, 57.624916953425256, 57.52280196835918, 66.72488243349137, 67.8236795240833, 70.60660116134152, 72.0930225618424, 70.36589314860683, 65.05176013515842, 55.25307539970645, 55.70048839815202, 53.9133192646888, 57.37978450713619, 60.63809348690895, 68.02585417224516, 67.8327480439217, 66.15271060697495, 66.98928156206685, 56.47456030691824, 54.63467059596893, 55.82343116883309, 53.553610463296216, 59.36556285427463, 64.63743232911634, 66.90264424970074, 64.58389982100456, 62.05250409341628, 59.74442066684846, 60.13026029832902, 58.495483090800626, 68.96544225754278, 75.41465036330685, 76.64727087943785, 77.2278993360458, 78.21477551614085, 79.23033991167623, 80.35322819986652, 78.88917999882852, 77.8091004586989, 72.8592340407833, 80.71152887036725, 81.87338198384931, 86.99270263794931, 77.74469514046946, 96.31455267629316, 40.89243488927042, 0.5554663293784665, 0.6665870150731457, 2.0624695093401018, 2.32233805521842, 2.6360168620463345, 3.65332622201212, 1.0744205405635219, 0.36759307187411094, 28.26786679606284, 71.39793934360628, 38.62632082354638, 80.04465533841042, 26.1220008327115, 26.518321037292484, 28.169321167853575, 64.46521674433063, 57.35863900953724, 80.2060059578188, 20.89091027936628, 0.6046559769780405, 0.16836636068840183, 0.033030964869765506, 0.04037636910535155, 0.03583571235198648, 0.09292864090492649, 0.09305940445272193, 0.019016219415671883, 0.06402732278670996, 0.028994763608000455, 0.046266826816023364, 0.2574245721822785, 0.1844892173164314, 0.16710499692107403, 0.16057414333185843, 0.27859939562697567, 0.10468527899994966, 0.2439752245141614, 0.22999401264373334, 0.17601746464929274, 0.13771466189815154, 0.2227231487631798, 0.1406296417717972, 0.10972316512056898, 50.77626251405286, 93.40443641908708, 69.89973514310776, 63.51797611482682, 48.64453669517271, 88.68938661390736, 93.97459999207528, 51.68531102518882, 0.8915497759176839, 0.33409425327854775, 3.9409685807843364, 17.372144153041226, 8.438727413454364, 10.203764573220285, 4.8644121904527, 7.493535732069324, 100.23541665846302, 95.51644448311099, 95.20884436945762, 100.69119607248615, 105.0030497581728, 99.67730260664418, 101.7284119513727, 100.53144578010806, 96.47575424563502, 99.9688131578507, 99.37054972494803, 92.48985736600815, 99.85145584229501, 95.77345386628183, 96.4613748365833, 97.79386674204181, 96.32982638574417, 89.05001717229044, 83.81325291049096, 66.91269336208221, 70.51069921062839, 66.31548112438571, 66.6499573184598, 70.13765042827976, 66.49763599518808, 66.2750179536881, 66.48949315471035, 60.88025277660739, 61.06105050733013, 61.11239825525592, 68.04465801485124, 83.74876914485809, 82.10318580750497, 81.39218561110958, 82.62970124521564, 80.86698808977681, 76.00405708436044, 67.92535520369007, 68.2205920065603, 64.45183361730268, 63.05426959068545, 62.103200727893466, 63.892005489718535, 66.4495163579141, 78.36893250865322, 84.28375690214096, 81.6830764278289, 78.33392143249512, 74.67309490326913, 76.34752335086947, 77.02239067323747, 75.00053436525407, 69.74035355352586, 64.71895487077775, 58.88567263080228, 55.07835342038063, 61.770368006921586, 57.38759786851945, 68.0439833671816, 67.39392895852366, 71.53869751961001, 68.48112367814588, 55.97310881460867, 53.64354256660708, 57.79382205778553, 64.40101146697998, 68.70961743016397, 77.44927790857132, 73.68003706778251, 71.68587269321566, 73.1941181613553, 66.73338613202496, 59.91186272713446, 59.99038857798423, 68.6161865726594, 71.69669843489125, 73.38704386065083, 77.63844597724177, 72.9887899275749, 65.93866686667165, 57.57188650869555, 59.220780326474106, 56.95383864064371, 60.21596016422395, 64.22256323599046, 72.00672257331111, 71.6436444559405, 66.57306317360171, 70.07837557023572, 58.80684867981942, 57.905515470812404, 57.533510038929606, 56.144543847730084, 63.08627220892138, 68.2705080893732, 69.41972332616007, 67.66436069242417, 67.03533018788984, 63.3036538862413, 63.06276152210852, 61.4221360606532, 72.72121367915985, 78.5603363283219, 81.58275788830173, 79.12386325097854, 81.88904008557721, 82.75521709072976, 84.46498609358265, 82.31558999707623, 82.18461421228226, 75.44599010098365, 84.01216414666946, 84.19350316447597, 93.53437669815557, 81.37447218741141, 101.80305465575188, 34.756000503416985, 1.8708378244792263, 6.097395035528368, 10.771522752700314, 5.985784482571387, 12.090428548474467, 8.477762841409254, 0.7075581327080728, 0.5380962356444329, 39.961848643518266, 74.75589613760673, 50.513114621562345, 89.45191106488629, 41.017472205623505, 42.09043656626056, 38.021973794506444, 73.87157424803704, 66.52435518080189, 93.35454387049522, 26.337119302441998, 0.8676363107177519, 0.2966611748260837, 0.17196092183791822, 0.2704057481981093, 0.09300010158650338, 0.16881714214480695, 0.1814590484624909, 0.1536641834724334, 0.15987622191108045, 0.23349721014740007, 0.14058413614909496], [0.07489337600887784, 0.038648201152682304, 0.012840559619719224, 0.09260498407867648, 0.0663108240452505, 0.05684959987599043, 0.014524214991158056, 0.10731649990644186, 0.08799137277228218, 0.14425231834813473, 0.03598306936422183, 0.13642294572726374, 0.18504703657761698, 30.80127273836444, 80.36896474899785, 57.96610824523434, 55.02062789855465, 51.31855372459658, 78.84429239457654, 58.821969416833696, 18.853211518256895, 0.01058195430349799, 0.022942670921404517, 5.533809767615411, 1.6634977825226325, 1.8083059283033496, 1.2340872374273117, 6.5539550012157815, 104.78343625222485, 75.78108602954497, 83.74472910358061, 97.08703210276943, 94.58273995307185, 91.96347528888334, 96.61605742669876, 93.54605751652872, 94.28641273129372, 91.44508700216971, 93.75399804884388, 86.84728468618086, 91.68425744579685, 85.26004268277077, 85.62591352770406, 86.05602495131954, 88.20263616500363, 90.25523601039764, 84.45900055669969, 79.48221883466168, 63.36339158396568, 62.68961860287575, 60.68695445214549, 58.81108091723535, 61.60869575315907, 62.81447549020091, 60.14997805318525, 56.679935609140706, 55.78547439267559, 54.44863257869598, 55.266807617679724, 62.67714546572778, 76.92025215395036, 73.75009059906006, 78.3094144636585, 74.24836497153007, 74.50659028945431, 67.67262120400706, 66.00741032631167, 58.778913559452185, 60.111938907254135, 59.38617098715998, 55.56588442094865, 54.875515891659646, 61.2678849312567, 71.92699647718861, 72.40018337003647, 72.99633656778644, 75.80684031209638, 70.81260404279156, 73.63121924861785, 70.6089702729256, 63.86263870423841, 60.03839054415303, 52.20697841336651, 55.2400609754747, 55.16260985405215, 58.75601868475638, 64.05370912244244, 66.42290699866511, 67.3540541433519, 66.60508540368849, 72.63103054415795, 66.92834361906975, 57.20448201702487, 47.2314126260819, 56.47489763075306, 58.96957212878812, 62.825634633341146, 68.67859148210096, 69.02847474621188, 64.8533195834006, 64.01789788276919, 61.463352326423895, 63.65390585314844, 65.37000556145945, 66.72631802097445, 67.06821533941454, 63.042796657931426, 70.03547268529093, 67.56182993611982, 56.45941211331276, 48.109611695812596, 52.66855116813414, 51.45426381018854, 55.84127010837678, 58.39001840160739, 64.03297939608174, 64.4003721206419, 63.06678195153514, 53.79546380812123, 51.05028321666103, 51.570785660897535, 52.92157150083973, 53.61109672054168, 59.04996110546974, 63.22876799491144, 63.689030678041526, 57.6942370014806, 58.064277325907064, 60.68553847651328, 66.42772366923671, 72.75893119073683, 76.05619322869086, 73.1723411621586, 73.7603593641712, 71.36134362989857, 78.54844370195943, 73.1940475586922, 73.4012036169729, 71.0214545649867, 79.54612208950905, 76.3665468462052, 82.3088356756395, 73.82498433513027, 81.67825975725728, 75.15037675057688, 81.91299007784936, 15.681291760936862, 1.5119642427852078, 1.188687641293772, 3.2489820737992567, 1.7652128084051995, 2.268277498022203, 0.3883925122359107, 0.12812049083051183, 8.568265649580187, 79.67868251185264, 37.95750964072443, 54.34443873743857, 43.36664638211651, 45.35245610821632, 26.78348698923665, 43.88681934725854, 53.80404987642842, 64.56231894031649, 20.667474423685384, 0.3841048406977808, 0.1388568989932537, 0.07755142531447834, 0.06177446504514064, 0.057147156086660204, 0.07201364384062829, 0.04021421893529835, 0.03610234159315306, 0.12204143759464064, 0.01315623093696852, 0.05812141308260541, 0.07047605175044268, 0.018501057845330047, 0.01178726724784581, 0.0376295417006458, 0.053645766550494786, 0.05125110976458077, 0.05755597890745248, 0.0757859603712155, 0.0563533932361151, 0.1596872739854359, 0.04551608746330585, 0.12024225712183023, 0.15077002586856966, 39.70533347898914, 89.36578366064256, 62.74375907836422, 71.47550029139366, 52.03139351260278, 78.58858523830291, 71.7133528186429, 17.664327390732304, 0.02910373386956992, 0.4853298767439781, 10.024113155180409, 6.163642887146243, 1.2571307944674648, 0.7123333732447317, 11.046486785334926, 112.1543150563394, 82.47758388519287, 94.39946328440021, 100.63640840591924, 98.91127940147155, 94.51693042632073, 98.8813909407585, 94.62633317516696, 97.03122461995771, 94.54453606759348, 94.57954714375158, 89.13318710942423, 94.4786794724003, 89.34238280019453, 88.93179693529683, 88.68333831910165, 91.71505589638987, 91.25729960779991, 86.23062533717003, 80.60783709249189, 66.4375295946675, 65.3039450030173, 63.50365946369787, 62.763359162115286, 65.31844992791453, 65.10813636164512, 62.969722901621175, 60.144459278352805, 59.13180920385546, 57.57118048206453, 57.41615664574408, 63.497309146388886, 79.64231429561492, 75.62190840321203, 82.39842261037519, 77.95760923816313, 77.91521626134073, 70.00472914788031, 69.58662802173247, 64.51295983406806, 63.61075585888278, 63.836558864962676, 57.7848437524611, 57.905284050972234, 67.38398967250701, 73.70598746884254, 73.49138675197479, 73.52107909417921, 78.31550982690628, 74.87655608884751, 79.84711693179223, 74.4521713256836, 67.95484358264555, 63.824936882142104, 53.67068536819951, 56.248066963688025, 55.03525833929739, 59.51852352388444, 66.66233631872362, 69.32199355094664, 71.95559055574479, 70.53200552540441, 74.78002655890681, 70.97671601080125, 58.67584543843424, 49.11351488482568, 59.63510028777584, 63.05952948908653, 65.66533257884365, 70.66745281219482, 72.90959727379584, 68.93010954703055, 67.20861265736242, 63.63833796593451, 67.7544810695033, 68.27454028591033, 69.5663336784609, 69.33271731099775, 68.08259517915788, 72.41861850984635, 68.90735195529076, 59.78480146777246, 53.385760476512296, 54.45026820705783, 54.57308546189339, 59.37974614481772, 62.13260673707532, 65.1652382266137, 68.03418528649115, 65.13420835618051, 58.31215935368692, 54.38011661652596, 55.32898895202145, 55.30761987932267, 56.120095714446045, 61.94956933298419, 66.09236886424404, 66.62515224949007, 61.513091902579035, 60.20613854931247, 64.49027676736155, 71.64419358776462, 75.92304445082142, 78.46619159944596, 76.66059124854304, 76.41763964006978, 75.0561692637782, 80.56645608717396, 73.21409087027274, 76.38808850319155, 73.14798324338852, 83.42196510684106, 78.99870826352027, 84.03489035944786, 75.03035222330402, 86.90167227099019, 77.05263999200638, 88.4025279937252, 23.48912162165488, 0.5015074167280428, 0.6729764947968145, 2.806702967612974, 3.9326080487620447, 3.8034267483219026, 1.8332698532650549, 0.1683925608954122, 6.820664896119026, 86.43569469451906, 46.6709255403088, 61.012974016128055, 43.10841714182208, 36.732635805683756, 38.24171673867011, 51.50389748234903, 61.311450696760616, 73.32872606092884, 26.8382550439527, 0.49513840687371075, 0.22545512555347336, 0.10679166073039656, 0.0995202759100545, 0.0278224115965948, 0.026229496466957276, 0.018138575683077498, 0.016620536071939335, 0.07252560507866644, 0.007653902575839312, 0.0602405731596293, 0.21069734567596068, 0.2648537864367808, 0.13112235273565018, 0.1512221862832385, 0.15523789660824885, 0.2194551249305087, 0.11517769581968747, 0.12605845793000153, 0.212406947487785, 0.26761565597787984, 0.1633720343271571, 0.21942442012650354, 0.27004433855895077, 52.154724597930915, 97.52025004356139, 76.36169095193186, 71.7900037765503, 72.80171640457647, 96.86631248843287, 80.8021983792705, 29.80263533130769, 0.12967294502642848, 0.7719193855600973, 16.77980938265401, 9.996676175825058, 10.947125304129816, 7.5785609502946185, 8.23329229508677, 116.02018740869339, 91.09478012208017, 98.06472993666127, 103.76798168305429, 102.56454360100531, 98.28734797816124, 105.69267303712907, 97.07849702527447, 100.52446396120133, 98.16762155102145, 99.29851147436328, 92.79654748978155, 101.2869256542575, 93.97501576331355, 93.6504239420737, 90.42733392407818, 95.2598116474767, 95.49022736087923, 90.6805621424029, 85.31683075812556, 68.97770358670142, 67.65163652358517, 67.29662279928884, 67.32053356785929, 69.3975305557251, 66.99882861106627, 66.61087482206284, 64.92070198059082, 62.682989797284534, 61.91478575429609, 62.02420027025285, 68.26626408484675, 85.38581740471625, 81.22027597119732, 86.52896081247638, 81.29665236319266, 81.91314697265625, 73.12604150464459, 73.62124073889949, 65.9690652355071, 67.564724645307, 65.83189995058122, 60.12507100259105, 60.89569122560563, 68.17947772241408, 78.70396567929176, 79.08980138840215, 79.10542811116865, 80.9332133877662, 76.92157007032826, 82.09760819711994, 77.75652500890916, 71.63346982771351, 68.41024644913213, 58.24263142001245, 57.23209550303798, 56.68614864349366, 60.642612057347456, 67.41811429300617, 73.97774496386128, 74.18278294224893, 74.10432769406226, 78.08207388847106, 71.83354208546301, 59.7362268355585, 52.47373880878572, 64.04968084827547, 65.96018498943698, 70.83544008193478, 76.60636840328094, 75.03726343954764, 71.58091791214483, 73.51554070749592, 66.7286479088568, 72.97758763836276, 71.32091183816233, 71.56438119949834, 74.76586680258475, 68.22457713465538, 76.97283544848042, 73.90471043125277, 62.57006083765338, 55.128763721835234, 60.137740258247625, 57.44990864107686, 63.476536273956306, 65.63280828537481, 67.81443841995733, 70.18179278219901, 69.2714185099448, 61.00084212518508, 58.33461492292343, 58.967446204154726, 59.06898852317565, 58.61222851660944, 65.92560537399785, 70.05870096145138, 71.74947784792992, 65.63081572132727, 62.708736235095614, 68.20454166781518, 72.79108678140949, 80.36073561637633, 82.96875876765098, 79.70382490465718, 80.16344039670884, 79.26030681979272, 83.50589598378828, 77.0789041826802, 78.55923806467365, 75.12775251942297, 86.02959602109848, 83.54615519123693, 89.61200652583953, 79.89410692645659, 89.53162931626844, 81.56728806034212, 92.43901560383459, 22.154390042827977, 3.8304739421413796, 5.874846616098958, 8.280666682028002, 6.2699082301509, 8.948522767712994, 1.4622713673499323, 0.21326421519681332, 11.539333578078978, 96.91400066498788, 52.9560334451737, 72.93521819576141, 58.59782165096652, 60.09405289926837, 40.54435591543875, 58.84495842841364, 68.37634148136263, 84.66983579820203, 33.585310289936686, 0.8683615201903928, 0.2812751568853855, 0.29940413731721144, 0.2277801104731137, 0.12380902460145375, 0.242684182500647, 0.058770052067214446, 0.13894659256742847, 0.17515596813492237, 0.12765398924990048, 0.22218878711423568], [0.10525825148027752, 0.16815816863409935, 0.04602483113206202, 0.07419836572221211, 0.05804255199167998, 0.10783835900046172, 0.0809808025857614, 0.015426911714096225, 0.01129670284553281, 0.2024067268376389, 0.06609608193919544, 0.09160770614060665, 0.04931809756183817, 32.55277575985078, 66.1757976778092, 54.49827801796698, 30.612867570692497, 50.11876736917804, 69.80542567468459, 46.59381174272107, 6.518954221279391, 0.28157166355559904, 0.3254657437003428, 2.0652166393495377, 1.806776694232418, 2.052415493995913, 2.9712723820440234, 88.60259240673435, 79.766645585337, 83.18294371328047, 101.85937989142634, 91.52706453877111, 100.65544759073566, 90.40700035710489, 90.24246477311658, 88.28226027950164, 92.34330977163008, 88.66066701950567, 91.31087918435374, 88.5043997918406, 90.90054435114708, 77.5722599029541, 82.11436456249606, 83.77413119039228, 85.5327650808519, 88.00012419300695, 86.46489281808176, 80.90170891054215, 64.00613469462242, 61.186978201712336, 61.674862215595866, 58.1145424996653, 61.47416630098897, 60.28649222466254, 57.90527228386172, 54.643911700094904, 54.436175131028705, 52.99590041560512, 55.21817807228335, 59.59685717859576, 74.93321864835679, 71.74972887962096, 72.34064963556105, 73.5818915213308, 73.60991293384184, 69.40528900392594, 68.95334566793134, 66.63043960448235, 65.21055729158464, 60.718682504469356, 58.15223255465108, 53.98474170315651, 59.57152258965277, 64.59504719703429, 64.90403190735849, 66.58955281780612, 69.04899658695345, 70.98176017884286, 67.96548105055287, 60.386406760061945, 57.55057234917918, 55.10686120679302, 53.01741853837044, 56.98277004303471, 60.21428531216037, 65.38440458236202, 64.76021036025017, 70.42112012063303, 67.41979306743991, 67.31900384349208, 68.72325158888295, 66.32364749908447, 64.94211027699133, 50.591503189456084, 50.36341344156573, 60.722055742817545, 61.27951083644744, 63.36799644654798, 69.13102903673726, 68.31814919748615, 66.61693880634924, 63.33356588117538, 66.88109474797403, 67.69344114488172, 66.99583192025462, 65.51819662893972, 65.38699334667575, 66.183760089259, 66.46630410225161, 65.5159765674222, 52.84997647808444, 51.227448832604196, 51.35249007132746, 50.889979870088645, 57.13603665751796, 59.89217635123961, 63.33315010993712, 60.14856992229339, 54.91364132973456, 50.17294706836824, 51.77044999214911, 52.19611344798919, 51.05347210361112, 56.98421347525812, 62.907463119876006, 63.91155066028718, 61.50549034918509, 58.62862010155955, 67.76307890492102, 73.06548795392438, 72.15473713413363, 72.65595328423285, 73.03011601971042, 72.17893815809681, 75.62294390893753, 72.06061593947872, 72.36441135406494, 76.52912124510735, 78.70325965266075, 76.98246878962364, 78.65454381512058, 72.85769647167575, 73.0143637810984, 73.64124482677829, 85.07450672887987, 71.26463367092994, 54.733675141488355, 2.5491476395437798, 1.0690622151859346, 1.5590779146840497, 1.318145713979198, 1.2760839322882316, 1.6122708926277778, 0.0711932172998786, 0.5407052246793624, 60.641862884644546, 60.95630361187843, 45.27608363859115, 53.47162900432464, 37.21504419080673, 22.777346757150468, 34.36226906314973, 56.28143456674392, 68.02998050566643, 18.49133364615902, 0.24161290046909165, 0.10995259313213249, 0.07607217848060593, 0.11910100061927112, 0.06177558736394971, 0.0469162357189963, 0.012202594155115227, 0.10559022036050597, 0.03276121765074711, 0.08233018219470978, 0.034217853399534384, 0.029850671510963194, 0.03910594634831913, 0.07375676199913987, 0.021329228465835896, 0.044246993868822054, 0.09000310433968421, 0.043307107407599695, 0.029881297790956114, 0.0628477925314538, 0.0439884928205321, 0.009512119220509645, 0.07523437706573356, 0.048504696047354134, 44.47557103249335, 74.42515403993669, 61.56310604464624, 36.852107278762325, 38.51891456111785, 74.49705892993559, 53.267504938187145, 7.121023824138026, 0.5727007949063855, 3.080674395445855, 3.8802995652921743, 0.9677399166168706, 0.45481307071543514, 5.433181360844643, 102.3726220284739, 81.42749478740078, 93.40014534611856, 101.23028662896927, 94.79585016927412, 102.65137703188005, 94.57788405879852, 91.53461117898264, 90.97110779054704, 94.77579901295324, 92.04830046622985, 92.78738483305901, 92.55953434974917, 92.81062095395981, 82.54094585295647, 84.85329289590159, 87.71629364259782, 88.23745896739345, 91.01318697775565, 89.38726255970617, 81.7997512509746, 66.30391797711773, 63.40512560259912, 62.99544188284106, 63.15019115324944, 64.89628914863833, 62.242280129463445, 60.38848561625327, 57.14017868041993, 57.558491614557084, 56.23383660470286, 57.829782347525324, 64.10434692136704, 77.13842222767492, 76.76201589645879, 74.58229203378, 76.58817645042174, 75.26797725308326, 71.8215710116971, 72.21574567979383, 72.06293013788039, 68.50027268932712, 63.85809267720869, 60.83883646995791, 57.30465935122583, 61.873365525276434, 66.30184696566674, 68.00985874668245, 70.64272619062855, 71.88736484896752, 73.56119709630167, 70.05797140059933, 61.402198653067316, 60.399723206796956, 55.905051769748816, 55.315974527789706, 60.9403121086859, 59.99289497252434, 66.85507374425089, 67.36378946611958, 74.253189486842, 68.53795882194274, 68.53270284591183, 71.43611185012325, 69.70250268136301, 65.37659514334895, 51.39792680740357, 53.02172922318982, 63.476163648789935, 64.02486008982505, 67.58144963172175, 71.28336691087293, 70.99027172211679, 70.15866648766303, 70.11098615584835, 69.59047978924167, 69.97722548823204, 70.590040914474, 68.75908636277723, 68.5723501636136, 68.2054751919162, 69.75147739533456, 66.20714526022634, 55.94077671727827, 52.44437202330559, 55.36738111126808, 53.36009640847483, 58.74902117636896, 63.06057676192253, 65.27014201687228, 64.9676174502219, 59.92087241142028, 53.16281295591786, 53.85416992249028, 53.55302603014054, 53.62582522053873, 60.26781389790197, 65.61792681294104, 66.41045739573818, 63.58470739856843, 62.537242366421616, 71.54495762240502, 75.55023885542347, 75.42828452202582, 77.22167061221215, 75.08249621237479, 76.70935415452527, 78.81121896928357, 74.80940511149745, 75.07183521024643, 79.03141298601705, 81.14792393099877, 79.61451253583355, 80.77901717155211, 75.03852644274312, 75.24496078491211, 75.63403637178483, 86.38260933660692, 75.56498696727138, 66.23288385329708, 5.304875239249199, 0.9274064292830806, 0.484435668275241, 2.0305466868223685, 2.8115887699588655, 2.6677461401108773, 0.03937904903244588, 0.20024583795137946, 60.74212651098929, 71.1146265460599, 53.82603476124426, 56.56850107254521, 30.978861970286218, 27.17054255547062, 43.075214278313425, 62.15448179552632, 76.756148030681, 25.110968735910234, 0.3278811882820822, 0.1540702560375775, 0.03981543569675377, 0.06859062509911676, 0.05861204260239198, 0.08792999380778882, 0.03791338876791058, 0.08185287111348684, 0.07667084554991416, 0.053581334725623174, 0.017619131681238933, 0.13573449315322986, 0.2355588906474652, 0.15719865268516928, 0.15833552716480148, 0.0854850088756892, 0.18556472815332875, 0.14425355941057205, 0.15986630873334023, 0.22755196948926296, 0.3108938014315021, 0.21813373051343427, 0.23522199582188363, 0.18613388551579368, 53.17141863607591, 82.7386333096412, 72.61369366799632, 40.412721172455825, 72.08602505345499, 87.9072738462879, 68.11955959566178, 11.183045083476651, 0.6563946136063146, 2.1970423527302283, 6.758988566936986, 5.590082051292543, 6.84042432615834, 4.443251615570438, 103.13810394656275, 91.32178337343278, 93.19069862365724, 107.10252977186634, 96.07108331495716, 109.10823375948014, 97.65169651277604, 94.46491979783582, 95.7462404620263, 100.19471814555507, 94.3595257113057, 99.51349658350792, 95.3069506922076, 98.82021765555106, 85.62654895167198, 88.31413345952188, 89.9660945707752, 90.48889160156251, 96.27486613488968, 94.67650813441124, 85.19008328837734, 69.48255185158023, 68.22412213971539, 68.59749255641815, 67.27346512579149, 67.46635160138531, 65.8878251044981, 64.53821205323743, 62.10022757130285, 60.49148705697829, 58.457522392272956, 62.129641425225046, 67.76039600372314, 81.82297952713506, 77.82607647680467, 77.9715964101976, 81.37743749926167, 80.69276425146288, 77.0786060825471, 76.26518495621221, 73.52193417087679, 72.60287577106108, 67.31070410820746, 67.20598466934698, 60.8660694860643, 67.71102905273438, 70.37940963622063, 70.84183354531565, 72.68060145839569, 74.81328825796805, 77.31786281831803, 72.0740932033908, 65.22272448385915, 63.709536829302394, 59.090565481493556, 56.77292323881581, 59.6570106475584, 62.01781465161232, 67.23085249623945, 69.54728664890413, 75.18003771381994, 73.38075237889444, 71.82552476083079, 74.98947328136813, 70.7950710481213, 69.70364801345333, 50.99601330295686, 56.970728366605705, 68.51362443739369, 67.95664002818447, 69.87784831754624, 75.27176626266973, 73.78548606749504, 72.35872391731509, 72.32240276951944, 72.41835178867464, 72.54675449863558, 73.6307720984182, 71.78992532914685, 71.16324040197557, 72.00258055040914, 74.30149739788425, 71.53839941947692, 57.3752071011451, 57.04114667830929, 57.42954761751237, 57.57261999191777, 61.784221818370206, 67.95686752565446, 70.55698317866172, 67.75489684074157, 63.555607334260024, 56.943899354627064, 57.310821394766535, 57.13098856710619, 57.38586418090328, 62.36614073476484, 70.55313925589286, 70.52769091821486, 67.3940230954078, 66.11305544453283, 76.63848477025186, 80.0561478830153, 78.83824409977083, 78.99233048962009, 79.5233331188079, 79.43709588819935, 81.38525086064493, 75.84810364630916, 76.77531273134294, 82.52171054963144, 85.17724929317352, 85.51613423132127, 88.1259459833945, 78.51482898958268, 80.299177938892, 78.71512090006183, 91.76620360343688, 80.32157467257592, 68.5830896131454, 4.487993601829776, 3.548382227459262, 6.7925130647997705, 5.31121624092902, 5.634778439998628, 5.761546992486523, 0.16467996091852266, 0.8959576006858581, 73.74174379533338, 76.74736976623535, 63.217122477869836, 67.60593306633734, 51.477433250796416, 31.337370526406076, 49.116150717581476, 72.3501496161184, 89.77763252873575, 32.915526359312, 0.4939088051117236, 0.22834485516913477, 0.1831103203397605, 0.2180344761619645, 0.12227232883413955, 0.15822835146419464, 0.17847784794867042, 0.21506570159427582, 0.1593017325766625, 0.07907820790405236, 0.1747813817834662], [0.06520316815905033, 0.058866521689079465, 0.04910276939852103, 0.06379365447848555, 0.0977402706179888, 0.049357964777417725, 0.07914469667500065, 0.09490618962914714, 0.09961369267154126, 0.06953998423752285, 0.05751448758547345, 0.09065228724671949, 0.1744093694874356, 49.122426509857185, 65.87126485763058, 47.18198683954055, 48.272327300040956, 76.37928670452487, 70.82729724145705, 28.3673910556301, 0.8125568565822417, 0.04921788177002342, 1.4794165376693973, 5.144963149101504, 1.5272059604044885, 0.43862229273203884, 67.43202301763719, 84.50865776308122, 92.87985078750118, 103.54828188496252, 89.50304308245259, 100.94213362663024, 96.67456350018902, 94.36052199332946, 87.07123633353942, 83.23957489382836, 81.791930044851, 86.41802833926293, 83.37130377369543, 87.20795446826567, 82.85058559909945, 78.21143365675404, 75.30718526532574, 81.55916090934508, 86.20951514090262, 87.02630950558571, 85.77557548399895, 78.64346704175396, 66.00607672045308, 61.4415753272272, 58.90431173386113, 61.0509386370259, 60.86807381722235, 58.07099242364207, 55.99790211646788, 55.80640023754489, 53.18471939333024, 56.308185131319114, 54.02631098224271, 62.28796397486041, 73.4609099357359, 72.45812462222192, 75.10586569386145, 72.09227731150966, 70.9596929242534, 69.66068237058579, 69.87040365895918, 66.18999665783298, 65.51157959045904, 58.61328755655597, 56.32927963810583, 53.33517366839994, 55.91430071861514, 60.39142347151234, 64.14379027581984, 64.88171754344818, 68.76032583175167, 69.7079469311622, 67.99791120713758, 55.16892879239975, 56.35077814902029, 53.305034175995864, 63.72585388921923, 63.30011983071605, 65.68167709535169, 69.03056929188391, 65.17405179239088, 68.84467247993716, 66.5944165568198, 66.87041021162464, 66.91148527206914, 68.12262688913654, 66.85438340710056, 61.247006154829464, 51.100211066584436, 53.18712380624587, 60.50526242102347, 63.32495235627698, 62.300523404152166, 65.88665623818675, 70.04622782430341, 67.96930928384104, 66.74188983055853, 68.4677170168969, 64.02367553403302, 63.440921152791674, 66.13046292335757, 68.59699833777644, 62.96636535275368, 64.72146911005821, 58.10631728941395, 53.08962152850244, 50.949191970209924, 52.62309874257734, 53.19550591130411, 58.304114572463504, 61.72766516285559, 60.34198984023064, 57.27669285189722, 50.31865527552944, 49.00696369909471, 50.447199190816576, 52.18509551017515, 56.63314957772532, 60.08530993615428, 60.853325705374445, 62.893754436123764, 64.5501046795999, 70.28896762478736, 68.83475672814154, 76.24389433091687, 73.48432648566462, 70.15091588420253, 71.74632426231139, 73.90783263790992, 74.69336571231966, 75.41775688048332, 72.47109982275194, 69.3401776590655, 69.43472246969901, 68.41958953488258, 65.39749745399722, 67.61232652971822, 71.17341503020256, 76.97216864555114, 80.4469963812059, 78.88048802652668, 36.694306404359885, 0.04949203399460643, 0.572629027789639, 3.595418800269404, 2.308281506261518, 2.72549789278738, 0.31178938885850294, 0.10761814702662731, 24.74794945409221, 80.32606186405306, 44.3379742868485, 55.27878261381581, 43.606687591921904, 31.861587455195767, 40.977216920545025, 51.17864670292024, 63.73867219494235, 13.090439765684067, 0.26871919031104735, 0.16666866388292084, 0.1233690832891772, 0.0803947759672038, 0.07194808203606837, 0.04495262213411831, 0.07194376130017542, 0.044699767153830304, 0.041014164115392396, 0.06927317879613369, 0.0517210970452476, 0.04029549320318526, 0.09314868433941757, 0.06279697791943628, 0.05319580863860827, 0.027610934940316988, 0.1297443597427299, 0.06909867928874108, 0.056985078694959806, 0.07020088062892038, 0.07226492834067152, 0.016911457961184845, 0.06995284434167609, 0.22657871606849858, 61.7757220422068, 72.2494545290547, 62.71157995347054, 43.034692272063225, 65.83293545630671, 80.30602639721286, 35.053374998031124, 0.5618326426033051, 0.1403132474590694, 5.085042080571575, 6.3689671985564695, 1.188624760796947, 0.8621499567262588, 79.02266610053279, 89.02784009133616, 100.71498916995142, 101.85998393643288, 96.276717493611, 101.06856730676468, 100.51498751486503, 94.74748734504946, 89.38395992402108, 84.72396450657999, 85.87983208317911, 88.54926386187154, 88.40437935244653, 89.55954090241464, 87.18434964456867, 80.70914406930247, 79.68705284980037, 85.20078351420742, 89.82941565975067, 89.43042432108234, 88.47660587679955, 79.93961426519579, 67.03555768535983, 62.3970058656508, 61.65150057884955, 62.51981527574601, 62.71592593962147, 61.03822231292725, 57.49503550990936, 57.07474962357552, 55.39198221698884, 58.500131099454826, 57.58978036142165, 67.94515532831993, 77.95503616333008, 75.24925185788062, 77.83193649784212, 73.16936800556799, 75.75499442315872, 72.43967379293134, 74.4156305251583, 70.66250278103736, 65.60279823118641, 61.09080560745732, 58.26371415968865, 57.77792469147713, 58.815764227221095, 65.1026136644425, 68.93527138617732, 67.90192296428066, 71.13446589439147, 71.14327553779849, 70.9849137644614, 58.52567357401694, 58.65139338278002, 55.66060181586973, 67.02652838922316, 64.19655399937784, 67.46848537075904, 71.76850134326567, 69.85650277906849, 71.23005405549081, 69.54487831361833, 70.38803100585938, 70.30151136459844, 69.14149392035701, 68.29982388404109, 63.569013995508996, 53.22632789611817, 57.2121855520433, 63.57859634583997, 65.38330239634361, 67.18024607627623, 65.32438447398525, 70.93567232931815, 70.50123845377277, 68.56297569890177, 69.79682783926688, 66.77974854746174, 65.20511696415564, 68.74071398089009, 70.94682755008822, 67.86502915043985, 66.54999963698849, 60.61290794803251, 56.376002911598455, 55.68839965328094, 54.84915756410169, 57.40166348795737, 60.569106840318256, 62.52821307028494, 63.140102817166245, 57.64228520854827, 53.925113831796956, 53.35603283297632, 53.49837172415949, 54.77740956890968, 58.74373382137668, 62.23637303998394, 63.65725947964577, 64.24767424983364, 67.42327613215294, 72.25983312053066, 73.04066719547396, 78.94170838017618, 77.2515590729252, 71.81225930490803, 74.86580879457536, 75.29436695960261, 76.9094499464958, 75.71504900532385, 72.79459338034354, 71.70551592303862, 71.42249338088497, 70.63231622019123, 67.052565082427, 69.41451441857123, 76.8941919265255, 79.2499674520185, 83.3663066740959, 83.30084231591995, 47.510728528422696, 0.20070356016437854, 0.3982319616742673, 0.6681857486405681, 4.293293520327538, 4.915956056887104, 0.45963246856004963, 0.12764704083242726, 24.184395074844364, 87.83027771980532, 53.227288876810384, 58.42257799640779, 34.49444901558661, 30.214778377163796, 46.99354440935197, 53.76691679800711, 74.1710864343951, 17.56079839121911, 0.2806327155520839, 0.18777305320385965, 0.07235331956537501, 0.1062151795673755, 0.08187875722444828, 0.002233267915735562, 0.07583241594294388, 0.07215863364117761, 0.033912134522031394, 0.04468904958376962, 0.046582068166425156, 0.1763622655022529, 0.16613643195840622, 0.1535759148217978, 0.2869480992517164, 0.20245601693468712, 0.2172969479955012, 0.2279532157004841, 0.27074674925496506, 0.14481966774309837, 0.1733114582396323, 0.19336797717598178, 0.18607108162776118, 0.4240966834608586, 70.29006588843562, 84.48991667839789, 63.88467457986648, 62.98734218843522, 100.71334961921939, 88.7748158362604, 49.32847253737911, 1.5606042069773522, 0.1585604046140948, 6.024258521295363, 13.030632445889136, 10.964402364146325, 0.7353590957580075, 81.02129413235573, 96.15061329257105, 101.32217991736628, 107.34852513959332, 98.86617998923026, 105.50685467258577, 102.22230111399006, 99.84192448277628, 95.28074141471618, 88.36318662089687, 90.19923240907731, 93.2429132153911, 89.83856262699251, 93.35231596423735, 90.41001273739724, 82.94335749841507, 82.6556908699774, 87.48555629484116, 94.5641165394937, 92.8563871691304, 90.8677690259872, 86.3858570591096, 71.03707344301286, 65.04529214674427, 66.24505889031195, 66.50972474005916, 66.19682942667316, 64.12182108048471, 62.374565985894975, 62.28467310628584, 59.19488876096664, 61.6442677282518, 59.62429415795111, 72.29523643370598, 82.28520731772147, 82.11216803519957, 79.6228514948199, 75.0621626454015, 79.16588752500473, 76.53601677187028, 75.32138424534952, 71.72136229853477, 71.85178110676428, 65.34158406719085, 61.704315293219786, 59.31611745588241, 62.03231565413937, 68.90484948312083, 72.27535786167269, 71.46686323227422, 76.63366025493991, 76.25588109416347, 74.48908082900509, 61.448372794735825, 61.80920731636786, 59.37791047557708, 68.17614370776762, 65.42000009167579, 69.177367917953, 75.09422409919001, 72.34629000386884, 75.21588817719491, 71.06893093355241, 72.68177816944738, 73.72748990212718, 74.02512719554286, 70.25822408737676, 65.51585497394686, 54.64554732845676, 61.661275125318966, 67.66831444155785, 71.68418607404156, 70.41294590119394, 71.13758810104864, 76.54393211487802, 74.58505338238132, 72.67660064081993, 72.2436180422383, 72.17619249897619, 68.74080027303388, 70.26905767379269, 74.4485862793461, 69.32720245853548, 72.50584417773833, 64.45413997096401, 58.771837603661325, 59.702357169120546, 59.89245483952185, 62.05667357290945, 64.11086197822326, 66.1970490794028, 66.63508369076636, 62.741252683824115, 56.1315490353492, 56.209145284468136, 56.81237836037913, 58.932862666345414, 61.86667003939229, 64.6739495954206, 66.51281556775494, 68.43310602249639, 70.64398134908369, 75.03753016071936, 75.49408620403659, 81.51584225316202, 82.12130715770107, 73.44375348860218, 78.56819675814721, 77.94447714282622, 81.88492944163661, 81.89052274150234, 78.4635949903919, 76.15117734478366, 76.01520446039017, 74.70918070885443, 71.87476619597405, 73.68615596525132, 81.74485375804286, 81.76625420970302, 87.06751008187571, 82.98142802330756, 49.642120945838194, 0.3376658777556112, 4.051405854763524, 6.937641251471735, 8.10779998379369, 8.21502189482412, 0.7192677559871828, 0.17958208708272827, 31.996856274143344, 95.31978468741141, 60.53979496802054, 71.72060135872134, 59.15662996230587, 43.27331750623642, 53.56000392667709, 63.37155403629426, 81.63886347124654, 26.428518372197306, 0.4599162275272031, 0.3109863142092382, 0.1959201837739637, 0.25485355046487623, 0.12025137356812916, 0.19113573486045485, 0.1948909140041759, 0.1452880232564865, 0.13485398233657883, 0.20922152325510981, 0.12633578175859106], [0.1073174728381057, 0.08245400498591124, 0.10691238086550467, 0.07058067637826167, 0.05710415557147034, 0.07370382532357209, 0.032320077410869064, 0.16502326023915123, 0.011133641988459614, 0.02490277773880911, 0.1617818962662451, 0.12733516643845266, 1.3587899265750762, 58.772743671171135, 60.563101691584436, 40.284647941589355, 24.698606037324478, 56.27728077673144, 52.28047970802554, 14.735434747511341, 0.22350062075401508, 0.8997606450030882, 2.0980461422474157, 2.490847000191289, 2.020452467183913, 27.75819597705718, 94.4501873754686, 86.6921627906061, 102.07496120083718, 89.79308666721468, 103.74498090436383, 95.00445750451858, 98.35021572728311, 92.92166325353807, 89.93410371964978, 86.02203369140626, 77.06291660185784, 76.48012299691477, 82.48621309957197, 82.3381357808267, 83.20039041580694, 75.46153053160637, 75.7913940183578, 78.3510700348885, 82.35195821331394, 83.86872306946786, 81.93036617771273, 75.33121370500135, 62.35784492185039, 60.001724227782226, 57.78750311943793, 57.607521241711034, 58.90562965023903, 54.80961615039457, 53.865140791862245, 52.45806893994732, 55.87628510690505, 54.667316482913115, 57.34719353337442, 69.69194366085914, 73.25012176267563, 71.50047009991061, 73.32909476372504, 70.69064970939391, 72.34656456978091, 70.78787742122528, 67.10536018494638, 63.93512018265263, 62.633069792101466, 55.7254974303707, 54.27743681015507, 53.5753050927193, 60.12931892948767, 67.27470459476595, 67.38646861045592, 65.27559803378198, 64.68824271232852, 66.91794149337277, 69.92027267333, 59.148400829684356, 55.94073749357655, 57.8830873581671, 66.24909893158944, 63.51473623706449, 68.52987089464742, 67.00925427098429, 65.51521562760877, 65.11964459573069, 66.13024327062791, 65.60961138817572, 64.68852904535109, 63.564181635456706, 66.82291815357824, 65.69005527803975, 57.46094619074176, 53.66879478577645, 57.037534175380586, 61.483944769828554, 60.84246073999713, 61.521595601112615, 65.21391091808196, 66.78727949819258, 65.24936129969936, 63.42180352057181, 59.66970343743602, 59.60058343025946, 63.970754915668124, 67.89189738612022, 64.76018290365896, 65.96082825814524, 60.76016941378194, 56.78377251471243, 49.78589934687461, 51.585282741054414, 52.91239707700668, 57.5926358469071, 56.66853720141996, 56.548183195052616, 51.86867790837442, 49.4235154890245, 49.86292685231855, 50.96788206408101, 51.29318383432204, 51.61018586927845, 59.35757298623363, 62.83092198833343, 64.564539001834, 68.45431035564792, 68.67429256439209, 74.13524381576046, 73.1999703376524, 72.3939311119818, 71.3101645438902, 72.77767227542016, 70.08392964639972, 69.20505985136955, 67.369398455466, 66.80631083826866, 62.72252728862148, 60.80007560791508, 60.13720681590419, 62.54709536029447, 65.8512137013097, 76.49768737054642, 77.164168665486, 81.1345329592305, 72.2005033493042, 76.97438086232832, 11.026517998787666, 0.7204497377237966, 0.8221635991527189, 2.3817227396272846, 1.6851779482057019, 0.6987800521235312, 0.09535356199428921, 4.545017019394906, 76.66027745892926, 55.58241721122496, 53.01027197991648, 67.28481646507018, 32.41915237519049, 33.48871015733288, 50.50665055551837, 65.00882587125226, 17.612795291408418, 0.19907087358015202, 0.07940443878572795, 0.03217160191026426, 0.028695920369617885, 0.03667097418538986, 0.07422904754357953, 0.06092881888992364, 0.038676420001373175, 0.07259534972329294, 0.0038423393608912107, 0.014038758480080194, 0.056989610105031924, 0.10447249041810151, 0.1182105000160875, 0.06125622571656301, 0.024281242944961114, 0.06462521610721465, 0.017470499132609656, 0.14124782876141612, 0.041645991300503095, 0.05005034738250318, 0.05783499579035467, 0.05175863535353734, 2.3378373009543267, 72.62627663150911, 65.96384848317793, 62.87889649791103, 31.682998018880046, 54.88294093839584, 63.455539826423895, 17.01482995863884, 0.2701433784058017, 1.8929805846944934, 3.131983409966192, 1.0504510590145666, 0.8176831492493231, 33.604588739333614, 101.10808126388058, 94.19928904502623, 104.47591458597492, 93.08637926655432, 105.42695599217569, 95.30719387915828, 99.61432503115748, 95.19710079316171, 93.30067403854864, 88.94973001172467, 79.50313291242047, 80.85926102053735, 84.88114172412504, 85.02358651930287, 87.37736163600799, 77.98820372550719, 79.3782211119129, 79.22100467066612, 86.00140986904022, 87.74149879332512, 85.66308975219728, 78.31989503675892, 64.7008256758413, 61.729253722775375, 64.10736322402954, 60.93888828831335, 60.77278375625611, 58.38943396845172, 55.61643985009963, 56.12577530645556, 60.16789936250257, 58.37743151572443, 60.56265061901462, 73.90630291354272, 77.64694183103501, 74.89884299616661, 75.81942327560918, 73.26905112112723, 75.04536705632364, 72.84152846182548, 72.0619103216356, 67.87295233818793, 65.79611616749918, 59.56373276249055, 56.78916577369937, 56.84274142788303, 64.60989729050668, 69.83849125523722, 72.44019939053443, 69.46167699752316, 65.54207601854878, 69.45984917302286, 72.05601107689643, 63.596949115876235, 57.69584517325125, 60.59251162313647, 66.94279363078456, 66.09800923255183, 71.30535571805893, 70.20305202853295, 68.76642119499945, 68.21539878845215, 69.10605138347995, 69.22060028199228, 67.37141455373457, 67.06947834261003, 70.65427364841585, 66.88600555542978, 59.561120463955795, 56.48665297415949, 59.75109654088175, 63.236910835389175, 63.691352721183534, 65.33665364788425, 66.94022055595153, 68.97771143144178, 68.39163872503465, 65.2297180698764, 62.26429247087049, 59.7219454857611, 67.1659843383297, 70.51777516641926, 68.30009844995314, 68.01272992164859, 62.922815276730454, 59.70352995780207, 53.789635166045166, 53.66839862638905, 58.818082347992934, 61.29805188025198, 59.656520351286865, 59.48338693188083, 53.204986280010594, 52.148378202992106, 51.57028751988565, 54.57538789318454, 53.45269964587305, 52.957633772204005, 62.611088829655806, 64.93918811121296, 67.5074109723491, 71.48380787141862, 72.90765962293072, 77.68396900546166, 73.39875605798537, 73.74735278467979, 75.34160014121764, 75.58587751080914, 73.15334904578425, 71.642836447685, 68.90536723598358, 69.07286813182216, 65.05800454847275, 62.129053069699204, 62.97133891813217, 66.07418475612518, 69.54760043851792, 77.96315546958678, 79.13234341529109, 83.67454221171718, 74.2192139164094, 78.60110544389295, 21.597238932886434, 1.5150138855941835, 0.4588407626555812, 2.0630181508679546, 4.278685142917018, 1.0022322593196746, 0.16397375042640394, 3.6590004207626468, 80.11047270990188, 66.07192547090592, 60.673649772520996, 55.06158921026415, 24.395251889382642, 42.980136025336485, 56.98617073797411, 75.95838500607398, 24.40083734450802, 0.1331096001329922, 0.06463596432079231, 0.06913628654494401, 0.05310433007956994, 0.02390374737461248, 0.0910751294765261, 0.05382362918387498, 0.034032724422192386, 0.014930381402072888, 0.04942534987123744, 0.026590482842537667, 0.22237307722530059, 0.14289861034241416, 0.2289650186655983, 0.12123516835873166, 0.1439850149495948, 0.25380793237878435, 0.17182216799307257, 0.24024186355452384, 0.23043331810303275, 0.1779261114256036, 0.23422025925209447, 0.28922206271559964, 2.8725968253227974, 82.20884661520682, 79.72434674539875, 57.49665544879053, 37.15295307097897, 75.84040795603107, 73.01856856192313, 24.741210822136175, 0.47911923258535327, 2.43406456324362, 7.690415670794826, 11.227812074845838, 3.2553127792573746, 36.170587616582075, 106.59944657356509, 97.9618069433397, 108.93278614167245, 96.0955902837938, 109.3205673463883, 99.61079489800238, 101.69515025231146, 100.73413033639231, 96.02570149206348, 94.1332677102858, 82.91139802625104, 83.01830614766767, 89.04980536430114, 88.83910348338466, 90.69975037728587, 81.84290516761043, 81.0724889078448, 85.73653221130373, 89.75770688826039, 90.61603130832796, 87.2634324719829, 81.72331994579685, 68.39895002303585, 66.21837108365952, 66.21806513878607, 64.35655532344695, 63.81895134525915, 60.772187555989916, 59.61542175662134, 60.22176134970881, 63.56287548618933, 62.56524416708178, 64.0037420488173, 76.17834368059712, 79.03018136178294, 80.52767953565045, 81.04696212276336, 74.02115775692847, 78.69965891684257, 77.31810600526872, 72.55179082193683, 70.81105862894367, 71.48020713560044, 64.59494913777998, 60.349038339430294, 59.72804084900887, 67.38864160353138, 74.14854849538496, 74.05889095798616, 71.92932636507096, 69.25865511740409, 73.44515769712388, 78.24645257765248, 64.4901434067757, 61.33710299768756, 62.916574785786295, 72.47801103899556, 67.39762383122599, 73.90136857186594, 74.09880499685966, 72.5379526999689, 69.92545020195746, 70.67496807344499, 71.1610830983808, 69.77876924699353, 70.12065087595295, 72.77859011004048, 70.20845705463041, 62.20910864491617, 58.45976598801152, 65.94536627492597, 68.24706800522344, 68.65985824215797, 68.06461503428798, 71.5531945997669, 73.15997000663512, 70.82546941695675, 68.32972803423482, 65.28035979117116, 65.02717079654818, 72.38153642223728, 75.52453948605445, 71.10566000784598, 73.87903459610479, 66.61498546600342, 63.56777060416437, 56.53607483833068, 56.265627414949485, 61.691799009999926, 67.8186353560417, 63.07192417883105, 66.00608456519343, 57.153271552055116, 55.436728615914625, 54.6001458937122, 56.38450268776187, 56.745796126704064, 56.000737990102465, 66.19857880377, 69.65964686486029, 69.56733780522501, 74.75813188860494, 75.15757037747291, 81.80263811542143, 78.17881522640106, 77.71327695538922, 79.52323898192375, 78.42086468973469, 76.89591776940131, 76.54750931647517, 73.4641105897965, 75.04452766910677, 68.2710023080149, 66.23433513026085, 66.74690261963876, 71.8203236979823, 71.93440191207394, 82.76140659086167, 82.18410430415985, 88.409101886134, 77.7336654355449, 80.397080298393, 20.307353773424705, 1.9172410570806073, 5.990477108186291, 8.919042233497866, 7.4227148871268005, 0.8730936146551563, 0.2528357514811139, 6.335991342221537, 92.20627784729005, 72.26234343744093, 71.84661926761751, 88.68825697129773, 43.156689751532774, 45.55286961217081, 66.81708166676184, 84.72097566050869, 31.194007896607925, 0.4563292200046201, 0.18735271608156545, 0.18624985590577128, 0.25660874982995374, 0.14463278825484938, 0.2211825919127272, 0.14816791630320011, 0.11125199316490082, 0.2246011979877949, 0.23946281342256456, 0.12585267905266057], [0.08606204928289499, 0.0185612915083766, 0.07847561080369257, 0.018731575616965854, 0.008117826749390412, 0.038286960052867094, 0.0914935130746134, 0.06502355118432353, 0.09371547449019649, 0.03977011393515333, 0.10350191064419285, 0.24212170542488176, 4.578535633702432, 69.31175616479689, 53.059842894154215, 30.04125075955545, 35.42399191087292, 60.39310616831626, 42.42121396526214, 3.3102968094810366, 0.3209954368010644, 1.5687351577704953, 6.117098081496454, 2.6518799076157236, 0.5644741137662243, 69.56308595595821, 95.5621087166571, 92.76519990736439, 99.69769893154022, 99.21196045414095, 95.12117939610636, 96.48998460462018, 89.96284684827252, 95.45455732653218, 89.78448098705661, 87.64432599467617, 77.2710689421623, 74.87496360655754, 77.57013397832071, 79.04106986138129, 79.89334598664315, 73.43670106703236, 74.08174268661007, 78.18771900669222, 80.21288579510104, 81.6046525586036, 81.12997516509026, 72.65356848316809, 61.47420160232052, 60.571424961090095, 59.91999772287185, 58.2424823699459, 55.42947223109584, 55.42748358941848, 52.20412292788106, 53.38881600287653, 53.50400817009711, 54.818872944001235, 62.7039627105959, 72.38454095778927, 71.71015216458228, 73.68204532131072, 71.62202435155069, 75.7577008585776, 69.54194438072943, 66.74535720579087, 62.110476724563114, 55.4933205727608, 56.208525549980905, 53.345375753218136, 52.68204019915674, 59.9978175470906, 63.54812345197124, 67.0351811378233, 66.96139351014169, 64.26246550775343, 62.351835850746404, 66.28630653504403, 61.99452753989928, 59.23064900982765, 55.216440462297015, 66.33542245434177, 63.649081337836485, 68.95631882452196, 66.69799850833031, 65.07694175166469, 69.61702639056791, 68.50144940037882, 66.86832351069297, 66.49629454458913, 64.68398694069155, 70.08375706211214, 64.03146536119523, 64.47521094352969, 60.22056502680625, 59.28329506228047, 54.16223679819415, 61.34330426492999, 62.43427622702814, 57.43039484946959, 57.71761040533743, 59.59379772986136, 63.40936176238522, 63.410663989282426, 58.76016855239869, 54.63415284310618, 63.27468326014858, 68.89804809324204, 66.30209015261742, 62.72896782044442, 62.882775722011445, 59.41383546398532, 54.69391407505159, 50.227864173150834, 52.38694852398288, 53.553128011765025, 53.033210000684186, 52.18772349819061, 49.421656285562825, 48.632820575468, 49.037926889234974, 49.933478524608, 49.77190433009979, 51.904779403440415, 56.695389747619636, 60.65779555228449, 66.27675164130427, 67.87277975390035, 70.40808216218026, 72.33532305686705, 71.195482284792, 71.47181326343168, 67.73675980106478, 65.65842136260002, 62.05326503322971, 58.8904030092301, 57.69058527485017, 57.16484646643362, 57.33324558504167, 59.90860323752127, 62.144758239869155, 66.1683451744818, 68.24941358258648, 73.43416721590104, 76.22140346034881, 78.58747912991431, 72.92247833744173, 77.11153830251386, 68.57057725229572, 6.234744671852359, 0.5628212637478306, 3.235315065230093, 3.240514166893498, 0.8560237048133728, 0.053449004528022585, 0.3802387013791069, 45.24852506576046, 79.9376138564079, 44.015555458684126, 65.16169632634809, 37.37921891673919, 37.896583464837846, 57.811202080019065, 56.03110890234671, 23.160397583438506, 0.3305897381036513, 0.47035019183831833, 0.06732474141303571, 0.10422862164916531, 0.0064350533366744084, 0.1410847286423368, 0.03553366686608042, 0.11008377802828628, 0.02513432972914269, 0.196252053062762, 0.008726562129243488, 0.03043382529980473, 0.07638908607224304, 0.022126383170665755, 0.0337266837877612, 0.016642601319378423, 0.021683727991917444, 0.138150182883105, 0.06206861216454737, 0.04499781749121124, 0.036225608970609405, 0.14532879445581667, 0.46460103904528005, 7.610671924006555, 81.61841223316809, 62.08326332030758, 44.70446486626902, 29.10584588204661, 65.2151543094266, 53.03685388257427, 3.0285664431510435, 0.3031146995002224, 4.74960784758291, 6.274725881315047, 1.6586841763027254, 1.1362135602581886, 78.18802495156565, 99.77733873551892, 97.17029617678736, 99.3124908016574, 101.82378830448275, 96.92109231025943, 101.0122028473885, 91.3668514067127, 96.13723801028345, 91.99800783588041, 90.47990152912756, 80.45336631036575, 78.684918649735, 78.53391524284118, 82.39628099626111, 82.92906438150715, 77.29625055866858, 76.87013210788851, 80.26189188803397, 82.53371300235872, 85.45216037381081, 82.54340125668435, 74.94465627977925, 62.62295399942706, 63.63512554476338, 62.47101706843223, 60.93699770589029, 57.68292096353347, 58.00422191619874, 54.636796520602324, 57.11801728894634, 56.97390940881545, 55.68870167578421, 65.7396536488687, 78.10133272601713, 74.05638848581623, 75.8240673618932, 73.42731091283983, 78.15541436595302, 71.73809512968987, 71.653944600013, 63.79121234340053, 60.397103063521854, 57.782000034086174, 55.477270234015684, 55.61102697926184, 63.74090794594058, 68.88864224956882, 71.66548421305995, 69.5528015013664, 66.1674665635632, 65.23578989890315, 71.1168073838757, 63.73524796578192, 62.04958977237825, 56.7477612341604, 68.43349825951361, 64.61194084536645, 70.90521904730028, 69.53852407393917, 67.4413033454649, 73.5495319674092, 68.46469679186421, 67.29463807998165, 68.67458281978485, 66.26176034250568, 72.40680433088734, 65.35725785839942, 68.445798812374, 64.88201956595144, 61.35236494002804, 58.072690809926684, 63.10452691970333, 65.37731685946065, 60.78617080565422, 60.02388561925581, 63.727881754598315, 65.60052325648647, 64.60642207053401, 60.61192343311926, 58.808276422562145, 64.75596243335356, 69.54630605636105, 68.11211493707472, 64.81647283800187, 64.9913477897644, 62.1618676185608, 57.81666986403927, 53.388239414461204, 57.26053268678727, 55.32978519316643, 56.990053884444706, 53.99135089689686, 52.99827737192954, 51.66609141134447, 50.63200166148525, 53.97867379649993, 52.602376860956994, 54.54875892208469, 58.99789948617259, 64.09281123069026, 69.47703699911796, 71.70814391105407, 73.21334561994, 72.86019109910535, 73.93247296733242, 73.81760243446597, 70.64718984788465, 67.3042086632021, 65.05472936937886, 61.821307828349454, 59.46554799233714, 60.837867644525346, 61.855785462164114, 64.79235810618248, 64.88118410110474, 69.6635143218502, 71.93450389369842, 78.16212161894768, 78.59615541273548, 81.91713994549167, 76.79939608420096, 76.39021442782494, 78.0547506578507, 14.939274441811348, 1.7858725449731274, 1.9709613486643762, 3.1811971433701056, 1.329925817347342, 0.10980798637554531, 0.13188099428530664, 46.05324637505316, 87.48268511987503, 52.25000289178664, 63.72912514594294, 30.237471249795732, 45.68274713331654, 63.61967532865463, 63.81140078267744, 30.534900657592285, 0.32721496757961094, 0.38438029527183504, 0.0675451985350059, 0.09395222630231612, 0.06672314788785673, 0.0792458585854019, 0.06964863082694431, 0.0539746136224318, 0.007506159646812106, 0.07121566367606003, 0.081258854197879, 0.16239403116126216, 0.12447208902167699, 0.1524935398370989, 0.14903250781278457, 0.22913895126792694, 0.12913662219239821, 0.2938498772921101, 0.205176992702388, 0.1480891624645841, 0.20424480159436503, 0.25821091547127695, 0.5810128488848286, 9.157982237877386, 93.5257710179975, 71.25031701980099, 41.50477178635136, 47.74947535607123, 83.18161010742188, 62.900567593113074, 6.148016164379736, 0.5381853469917851, 6.539392711654787, 14.133204817771913, 8.984940994170405, 1.1209108007531012, 82.99201842277282, 102.59606376771005, 100.7223867600964, 103.38584084664623, 108.65164633720153, 99.50655398830291, 102.67271472561745, 91.09860835536834, 100.10482526594593, 94.76047039031984, 95.21330802671372, 82.01656418461954, 83.60238629002725, 82.86028954290575, 88.63481075532975, 86.84452333757955, 80.29451031838694, 81.50820147606635, 84.30987988748859, 85.80943338332638, 89.98411393934681, 85.68512562782534, 80.02700467263499, 68.19031915357037, 67.12756864486202, 66.33955663250339, 63.94902890728366, 60.65654039382935, 62.50123108586958, 59.218042512093824, 59.62468639496834, 60.48670176536807, 59.736768122642275, 69.2829659677321, 80.76413569911834, 77.10013989479312, 79.35237269247733, 74.88333394450527, 82.90234519589333, 76.00332752350839, 76.08749374266594, 67.48716369751962, 62.488216661637836, 62.570476608891646, 59.926136232191524, 56.68269695774202, 66.85817241668701, 71.07326123022264, 73.16471607454362, 71.4943512024418, 69.27882394483014, 68.02994912670505, 75.01598065899265, 69.98988689914827, 65.2039598649548, 59.02770949948219, 72.10491518820487, 64.7201943397522, 73.46263577861171, 71.56970777819234, 68.41514156710717, 74.05361929247456, 70.23284635236188, 71.21364285868984, 70.78873249792284, 67.21944624377836, 76.6646626687819, 69.71586227416992, 69.78668459000127, 66.26598865755143, 65.16948615351032, 60.50394450464557, 68.027831046812, 69.12699684020012, 63.35757078662996, 64.58822619530463, 66.44216583621117, 69.32507653390208, 69.6737438632596, 65.34392179981356, 60.79054424839636, 69.33976973256758, 73.178405146445, 73.33745725693242, 68.85472159231864, 68.39279974660566, 66.49248984552199, 59.81971056230607, 58.295732467405266, 62.11180640805153, 60.21645830523584, 60.5235485107668, 57.51511020045127, 56.61583623578472, 55.36234086559665, 54.16760260058988, 56.20517976822392, 53.559443027742454, 57.54521046915362, 63.47371608980241, 66.90210296261695, 72.42194467975249, 74.06341737316501, 75.70431740053239, 74.94913562651604, 77.15904605004096, 77.884857116207, 74.35557903782015, 72.4622509556432, 69.55392329923569, 65.77836744246945, 63.83748062195317, 64.8781717208124, 63.867953515821895, 67.75731302076771, 68.93179616620465, 74.26162258271249, 73.73845684912898, 81.70129975964947, 81.50433401907645, 87.66798573155558, 79.20177721208142, 78.94413240494268, 79.48648637340915, 14.68910861399866, 1.9617317665007807, 10.298938924266446, 11.159698155618484, 3.38945220074346, 0.18482946760712132, 0.8212695439015666, 56.26785924357753, 96.66881330551641, 56.96915157379643, 86.58224228889712, 55.08286022370862, 46.41570083556637, 73.33079707237982, 75.95935775387672, 39.261450613698656, 0.5376028137341623, 0.5728263720389336, 0.21440626843081367, 0.10949971259481485, 0.20080085333076217, 0.2311271486142951, 0.13075833839754905, 0.16874390413924573, 0.09578170555253183, 0.24592478038562884, 0.17113412910651776], [0.0981686593243672, 0.029415184999966336, 0.04304923455140764, 0.08672019541864434, 0.06072976243411822, 0.040809243256526614, 0.1440141722559929, 0.03042794365976607, 0.08585549665675049, 0.06267117479095055, 0.30704185006118595, 0.22873284805926586, 12.187363063135455, 68.03391856531944, 41.51078085745535, 47.48645297942623, 67.40250325972035, 55.80812608042071, 28.013083357964796, 0.12400711961691419, 0.11880067117031544, 3.302713151900999, 2.3176226308268886, 2.0113659289575394, 7.674055955102367, 101.64507727469169, 83.19754277506183, 99.46087406527613, 84.38280459373229, 93.01594134299987, 92.31265252636325, 96.68585208154495, 92.49253242246567, 93.31912486783921, 90.4124132279427, 89.13376762020974, 83.62193538296609, 76.95360014515539, 73.92929584749284, 77.66413750187044, 73.59667101214009, 74.68534838768744, 73.82144635723483, 78.4942679251394, 79.29246241046538, 78.50077905962544, 77.5207591825916, 64.79850053787231, 58.264859491778964, 61.090531041545255, 58.954145446900405, 60.059814530034224, 54.28865871121807, 52.727457323381984, 52.7027032452245, 54.53200647907873, 51.810199291475364, 56.59087819437827, 65.26651774683307, 74.23463667592695, 72.08298129420128, 73.6921650363553, 74.19724864344444, 70.51593165243827, 64.111265982351, 59.97344393883983, 56.642284777856645, 54.12518608954645, 51.756607947811005, 50.03649957718388, 56.307008420267415, 63.56538580309961, 67.40851233082434, 69.77685513034945, 64.887495194712, 63.42687514520461, 59.097413939814416, 66.29674003970239, 61.31617323044808, 57.57469100336875, 60.37707544142201, 66.97877745474538, 64.94735056354155, 70.63292026519775, 63.8169744706923, 65.59517314357143, 66.00563741499379, 65.70747452397501, 64.0235225615963, 66.40261265539354, 64.23218481002316, 62.78606184067265, 63.72318275513188, 62.381249704668605, 67.35966313269832, 59.40511995746244, 53.47260959686772, 54.78822354347476, 60.53007533473354, 59.52620352468183, 53.96263130249516, 53.20382525843959, 53.61079077566824, 55.09869483209426, 52.5909000058328, 52.78441013828401, 59.56610971881498, 64.65369839822093, 65.66388914662024, 63.781076938875266, 61.98154841699908, 60.21190051109561, 59.36998336545883, 53.72106036832256, 47.97416048665201, 48.98835597499725, 49.37471728171072, 48.369959016000074, 49.53032162881667, 46.71369114229756, 48.256641741721864, 50.40876780786822, 49.10656836725051, 52.81778950845042, 55.1349885232987, 63.566821390582675, 68.77077502589073, 70.9132363719325, 70.91114182626048, 69.3908860606532, 70.77526307875111, 65.27162467279743, 61.29499243151758, 53.29708745402675, 54.22686961389358, 55.58440193053215, 58.32299294010286, 59.090530180162006, 62.773059183551425, 62.87983002201204, 66.28624377712127, 66.22707874544206, 71.2953144504178, 74.1058260394681, 77.00567353156306, 73.64785794288882, 75.00902237430697, 74.44575432808169, 83.17169435562627, 62.07504203242641, 9.814673296866879, 1.1466225501029723, 4.171040106204249, 1.1168488187174643, 0.23552741975553576, 0.09540803084570555, 20.145012755547803, 82.42555756722727, 50.611417062820934, 55.48212612828901, 44.951711470080966, 46.25241648766303, 40.597245154842255, 58.06892141219109, 27.446973554549682, 0.05002317424382895, 0.11433853076830988, 0.0281745400805507, 0.026967545573209083, 0.014949860145157624, 0.06524564773445168, 0.03842533851462988, 0.09379142444700965, 0.024386051433881926, 0.04114784262773972, 0.026460004662494027, 0.10797284573556916, 0.06537659514334894, 0.046154525987203085, 0.05274125036873645, 0.09506665440576692, 0.05156779136028021, 0.21141265729261985, 0.04585092917325036, 0.07814418584589036, 0.13988218510583525, 0.21805764266079475, 0.36834871035910427, 19.722567604434108, 77.58131273331182, 50.47165516884097, 45.12470368416079, 45.38431752112604, 67.89664345402872, 29.57765013940873, 0.09826900918156871, 0.26313499156986514, 6.082325779622601, 2.542187883969276, 1.5252284729673018, 10.284237880860607, 109.09437994803153, 88.16527166674214, 102.871445532768, 87.09914791968562, 95.23990169648202, 92.32674168002222, 100.10752385662448, 91.04554653167726, 94.89397218150478, 91.93118633762484, 92.663555606719, 87.79339959544521, 81.6577143822947, 77.16121119837608, 80.03404140472412, 77.92453581287016, 79.05020898388278, 75.46269155317738, 81.99721905492967, 84.22967526220506, 83.98073811684885, 78.54962825775146, 68.07891599593624, 60.38810906871673, 65.55043066701582, 59.867179086131436, 61.78989748800955, 56.53809878133959, 55.61779699017925, 55.78179913182413, 56.90757820683142, 55.50492294373051, 59.033326333568944, 68.6289813441615, 75.58135894037063, 75.64574072437902, 74.9730307056058, 76.96466122904133, 72.82077127887358, 67.3018866200601, 63.67732632544733, 59.662941271258944, 58.49128223234608, 55.956203399165986, 54.68243329755722, 60.41940958269181, 70.24549207379742, 72.28195528830253, 72.7866937268165, 67.34059256892051, 65.88124336734896, 62.383924761126124, 68.4785113796111, 65.30557278663882, 58.880036184864665, 61.77107403355261, 69.39015649980115, 66.24388217926025, 74.41709749160275, 66.61182403564453, 66.7065884990077, 66.83175133120629, 68.38594344354445, 66.74716149607013, 70.11635195824408, 67.22811468185918, 66.40842560798892, 64.84788710071196, 62.020944703009825, 68.50932551968482, 62.23889512400474, 56.8515589160304, 58.76585598914855, 64.01901183589813, 61.8366599852039, 56.64983534043836, 55.78570973488593, 55.27380904843731, 58.32976295102028, 53.04156464915122, 55.272636259755785, 60.7114927999435, 66.62752136107414, 70.16115327035227, 66.34153350707024, 66.39849416671261, 62.50691067787909, 62.95289201121177, 58.725035882765255, 53.25635756215742, 52.070597602475075, 51.788571342345215, 51.029125951951556, 51.64166681228146, 51.838812981882405, 50.548949395456624, 52.757800779035016, 52.871259258639434, 54.36879665620866, 58.573232312356275, 68.29290482305711, 72.71882103335473, 73.1764518060992, 73.3081885307066, 70.99713586991834, 72.49271208240141, 69.34205255200787, 63.29158083085091, 56.377371818788596, 56.820438831083244, 57.812845553121264, 59.887183174010254, 62.43457824953141, 65.96789636919576, 65.90473051994078, 69.18134520130774, 70.42657221517256, 74.42911563381072, 76.94992096193376, 80.15383058978666, 78.82946583532518, 75.5822140170682, 78.83250174983856, 83.71324816057759, 76.44799878520351, 18.30754706936498, 0.8543838476461749, 0.6589832553459752, 2.757375240325928, 0.4253361524353105, 0.18029116274368379, 19.28682757962135, 90.0081031553207, 59.54074375091061, 62.87835521082725, 35.75794250734391, 48.1028534520057, 54.337339247426684, 64.80431349046769, 37.3475222433767, 0.08156430111416886, 0.10975433723820795, 0.03256936242142993, 0.03902355359206277, 0.0439817474163588, 0.08217173222933086, 0.06530549452309647, 0.015620946463557984, 0.06165478678960955, 0.06656334960773107, 0.04229448855884614, 0.1924631813721311, 0.15855666610502428, 0.20682224312857275, 0.2237332510131021, 0.19422087818384173, 0.21253163595834088, 0.39772275835275656, 0.17508686700415227, 0.2683148797481291, 0.19217370738906248, 0.4234304934019043, 0.3884627778203257, 23.20946643429418, 93.16419909077307, 55.79476256524363, 62.07468509674073, 86.94776796525525, 81.73034883314564, 41.00605810842207, 0.38405728195944144, 0.2835019293331331, 8.263472972377654, 9.899833836863118, 4.6236669152013725, 9.86255661133797, 113.49890355140933, 91.86785574882262, 106.39869182340561, 91.59952640533449, 101.02695880397674, 95.81493685322424, 105.17715592538158, 97.49493506646927, 96.00504629073605, 93.94042830313407, 97.75244651302215, 91.88785983670144, 84.92805327138593, 80.77207457634711, 84.10584603586506, 80.43939482781195, 83.51633733318698, 79.99148368835449, 85.03252952329575, 87.14278036548247, 85.63969673648958, 82.44446339145784, 71.9497932926301, 63.72562639174923, 67.27892506507136, 64.50297347960934, 66.79222952935004, 60.945603386048354, 59.349347775982274, 61.139929371495406, 63.513139832404356, 57.984186449358546, 63.58434261814241, 70.5393325128863, 80.60046303656794, 79.94825916905558, 79.4480549904608, 80.50711847120716, 79.9546604771768, 70.33095267511183, 67.36182043629309, 64.88685192600374, 63.16341346310031, 57.79659909586753, 57.91078321395382, 62.485455313036525, 72.71067034813666, 73.59966770295175, 74.6389389038086, 70.68330703243133, 70.59761108890658, 66.0396678986088, 73.10673559865644, 70.28076987112723, 61.860774717023304, 65.76485095485565, 69.99599795187675, 67.46086028314406, 78.53702176001765, 67.09138870239258, 67.47324712814824, 72.15667478499874, 72.39896743528305, 68.83878892467868, 73.19596167533629, 68.99990420187675, 68.27784292159542, 67.19486867227863, 65.0675751316932, 71.52948779444542, 66.10528915159165, 58.78442841191446, 61.172359528080115, 65.53280353546143, 65.629125179783, 59.80878676137617, 60.66993136559764, 60.008470704478604, 60.53138148400092, 57.27137804031373, 57.98177419170257, 65.38713062963178, 69.53550384890649, 71.34031972577496, 69.53927716901227, 71.95715950381371, 65.67462859615203, 65.64090405741047, 59.67746580800703, 54.33834729656097, 55.454555788347804, 54.4290481844256, 54.10584488222676, 55.49967089006978, 54.619330206225, 54.26977249883837, 56.31641426394063, 55.43828187450286, 59.408300999672186, 62.150214256778845, 71.46581203706803, 77.27088066839403, 76.26998593730312, 75.7023326812252, 73.59507068510979, 78.8764322957685, 74.02688441738006, 68.77889433214742, 59.18990342847763, 59.49409892482143, 63.92617325628958, 65.26578426361084, 65.7229482743048, 70.33190973343389, 69.49167528460103, 74.37180196085285, 75.43185387888263, 78.07078530711513, 83.00699403209072, 86.11267966608848, 82.90235304063367, 77.41953065318447, 78.26761768710229, 86.51200832859163, 78.9663016411566, 16.590158862452355, 4.949665396444259, 11.716339357437628, 6.122900737870125, 0.9277150707860148, 0.3489005878087013, 27.489262588562507, 98.05317463413363, 64.9114098856526, 70.87089046355217, 64.22488135676231, 58.721062521780695, 53.54395751030215, 76.141920551177, 43.132080801071666, 0.12128779093825048, 0.1832423326108725, 0.2052595156935915, 0.13149703101765725, 0.12293678753438497, 0.17053048246570174, 0.18947811977517223, 0.16741019102834886, 0.11249684007658113, 0.1967936619034698, 0.19701670074174482], [0.046055072452873, 0.03801744266022598, 0.049586232165775956, 0.08719742989107486, 0.040600618362546935, 0.07307182576867842, 0.11974082193187169, 0.009976609820319761, 0.08485308592958797, 0.0710494838835251, 0.08625486595255714, 0.06026565487827025, 29.692444186056818, 71.85422082101145, 38.13301217171454, 48.19630392136113, 66.84802132268106, 56.47126943834367, 19.792007284779704, 0.36875541111634624, 0.6519144088510544, 3.265314332900509, 1.317738155203481, 0.8470548989792025, 34.11706209182739, 102.42639772353634, 86.37990290118803, 94.06773274944675, 86.72216892242433, 90.99759947869086, 85.32589927796396, 91.38130141842751, 89.46203862467121, 93.16452856986754, 91.97852150086435, 89.52268631227555, 85.65555880146643, 76.66232493615921, 72.33541719375118, 75.6454034005442, 75.41729404080299, 77.50918034584292, 74.25055365408622, 77.2129080372472, 76.96473183170443, 77.80761780277376, 69.14202736270043, 61.16706825071766, 59.66866793171052, 60.635018348693855, 59.41576527011011, 56.262846454497314, 51.385367378111816, 52.18989649126607, 51.64743661880494, 52.2154938790106, 52.39336944395497, 59.455259615375155, 70.44467003114762, 71.05700692822857, 70.75243488434823, 73.59994226886381, 67.88125991821289, 63.31302442858296, 57.52353152921123, 55.82173670491865, 54.46191372409944, 52.30947779070947, 51.71858449136057, 55.03725874808527, 61.87843714990924, 65.91184569943336, 64.78488206863403, 64.06988497703307, 63.060678743547015, 60.61882288225236, 62.12234189433437, 65.14541456776281, 61.57177448272706, 58.7371010934153, 62.214270484062936, 70.1904063070974, 69.64599701666063, 64.71547180606474, 64.04165567890291, 66.00763782378166, 63.565413259690814, 64.60008352033555, 64.88622434677617, 62.79834278168217, 64.10617082349717, 68.67184500540458, 66.59286329823156, 65.07144651105328, 62.53646573712749, 62.42811026111726, 56.44226351091939, 53.63356405688871, 59.58911834224578, 59.88578288785873, 55.15678121197609, 53.87785711596089, 50.35681993730607, 49.419318552940126, 50.70815055601059, 48.70486274842293, 56.81763825878021, 62.40974572397048, 67.15963794339088, 65.46544859486242, 66.71979119700771, 61.660867198821045, 61.17752136722688, 58.98435946433776, 55.129481515576764, 46.767560974244155, 49.11256567124398, 48.79461834507604, 48.434886009462424, 47.29945398146107, 47.94087917573991, 49.828264867105794, 51.22643686109974, 50.80754733854725, 54.528186090530895, 64.84332538420155, 67.16632950690486, 66.73707315998693, 67.92730069929554, 67.74582832090317, 62.76415540326027, 55.23611899345152, 54.636494498099054, 51.80960309120917, 53.59926685210198, 56.54331553366877, 58.75307298475697, 59.774544469771854, 62.83994343972976, 64.42515757776076, 66.26098371321156, 66.83009609099358, 71.00210943529683, 75.4416205806117, 75.5434923787271, 76.31614438949093, 73.40318049153974, 82.05066527089765, 78.49336577999976, 80.9732686319659, 55.80127369972968, 1.7308388722519723, 0.8331247851733239, 1.2426837245302818, 0.5473759506017931, 0.220171892114224, 4.395992448253017, 69.19461850197085, 64.46335754086896, 53.35400496759723, 48.1018610923521, 26.37166753891976, 29.53494925652781, 56.89174752081595, 30.52106841917961, 0.036263867401547974, 0.06080112735470457, 0.08145172449369585, 0.058091098983441634, 0.02272570141470961, 0.08785641106266169, 0.04585166844809729, 0.042615939051874226, 0.09131445534407132, 0.08580647469047578, 0.061613165232683384, 0.07512020698237805, 0.02678660518159309, 0.040528433727881605, 0.07467845004172095, 0.10086633835829074, 0.038797504028245326, 0.11826225691625189, 0.10458188777368878, 0.08535148741136636, 0.025278300632752722, 0.13140675521666004, 0.014131723249691629, 41.195022213843565, 79.27311728077551, 46.35770074782833, 38.22880429606284, 55.24554837134577, 67.96787369635798, 19.716474202371415, 0.4714277098255773, 0.8406711802367242, 5.983224645737679, 1.09013992932535, 0.6716283026241487, 38.30463155623406, 108.037293341852, 90.96445545073479, 95.81320316560807, 89.23981282018846, 92.50915542725595, 87.80965389743929, 94.89025377458142, 93.49316043238487, 97.38049599432178, 94.56490101352816, 93.13224746334939, 87.43007044638358, 81.70452394793111, 75.03954625898793, 77.98253197823801, 77.80531929385278, 81.16679053152762, 77.04478740692139, 80.39823347522368, 79.04934606244488, 80.55708162246212, 71.63400327005695, 63.480552781012754, 62.60116915549002, 64.14462966303672, 62.737153806994044, 58.48427295684815, 54.11567434187859, 54.776589793543664, 53.26880324271418, 55.35966188676896, 56.24377589071951, 63.53891372680665, 71.46667495850595, 72.79303227701496, 71.38388941364904, 75.63828822105162, 70.68966127211048, 65.70516817031368, 60.1608390961924, 59.14793014526368, 56.19815088087513, 56.952152021469615, 53.45806544826877, 58.07663671432003, 68.7881903494558, 69.9940053878292, 67.95384730062177, 67.74720115046348, 65.77991285631734, 63.84356029572026, 65.49900447168659, 67.73531636884137, 64.90454966022124, 60.05087544841152, 65.07316058681857, 70.78398643001434, 72.58193031434091, 71.16193033033802, 66.677868904606, 70.29882061866023, 66.31481432145642, 67.49921321868896, 68.5504319590907, 63.21201555190548, 65.62258266633557, 70.68126739994173, 70.98769864728375, 66.7186301754367, 67.09517771197905, 65.83532025737148, 58.063618367718114, 55.92970386628182, 63.429522745070926, 61.76728110159598, 58.39579213050104, 56.71089095454062, 54.2810453907136, 52.88226150697278, 51.99925753378099, 50.8983031395943, 59.94370060582315, 64.75801775532385, 70.21746281654605, 66.75279401963758, 68.23282980149793, 65.93186547679286, 64.05292857077815, 64.0168898336349, 58.87787103652955, 51.14079190838722, 51.971455773999615, 51.6822672659351, 49.768005494148504, 49.46693220446187, 51.46764301484632, 52.1354422261638, 54.149034100194136, 53.607617578198834, 58.23569666954779, 68.20219609045213, 71.50673020270564, 70.03954410552979, 70.85615019644462, 69.65470467844318, 64.52976326788625, 56.75972838555613, 56.33331575701314, 55.30739630422285, 57.50574750284995, 58.058534975974794, 62.502819645789366, 62.86697641495736, 67.17576672953945, 66.54927007613644, 69.01695866738596, 68.04859607450425, 74.55162694377285, 77.61284858949723, 80.45565697454637, 77.65169574368385, 76.7596467848747, 82.56870054429578, 83.82388253365794, 82.6230332159227, 69.08363896031534, 3.9733421081496827, 1.207667990557609, 2.4047656837970983, 1.1298274513213866, 0.20505475571318982, 3.44476203283956, 73.55662361268075, 73.5371058987033, 63.46822869393134, 43.95914393086588, 28.902321938545477, 41.04559559975901, 61.22449959478071, 39.75415914289413, 0.07559563348730726, 0.05055430683217222, 0.010323321105041092, 0.06846515521887811, 0.03484768109516271, 0.025498882244010607, 0.05456455878072208, 0.09441056904653389, 0.01798687495231148, 0.08580763914412068, 0.04653100457583224, 0.16759726969945818, 0.06112744633649146, 0.17986944666312588, 0.16866113599990645, 0.17095993603429488, 0.18375345115219394, 0.2854810102332023, 0.17632792944148665, 0.2571639184269213, 0.1635784643792337, 0.15173204844036411, 0.12146134049661698, 48.935039197244954, 94.07407129964521, 51.44729768076251, 64.22550893598988, 84.42173804006269, 77.03698189027848, 26.552065187884917, 0.5631736641929996, 3.156462431915345, 11.194394461570248, 9.463398571937315, 1.6519179651814124, 39.885684059512236, 113.454008102417, 94.321086483617, 101.22820777277794, 92.74416815850043, 98.25363128416001, 91.64407668575164, 98.03893643040811, 97.70675090051468, 101.37362572454639, 98.26474728122835, 94.67913612242668, 89.42654117461174, 84.61293005174207, 78.96036317271572, 83.25741383337206, 82.35333104287425, 84.8448048868487, 81.11390913686445, 84.68572924214025, 84.1396176430487, 83.90081590221774, 77.43296869339483, 66.49620825244536, 66.28421983411236, 66.94613549017137, 65.1170950551187, 61.407744884490974, 59.797113787743356, 57.732707608130674, 57.17999466003911, 60.2563762664795, 59.0994143486023, 67.73580274274273, 75.55955840695289, 77.38184452056885, 75.89104575495567, 80.90323863490936, 74.30811835873511, 70.44139877442392, 63.07174767217329, 63.93084872153498, 62.03199401978524, 59.044501166189875, 57.480295242801795, 60.607263657354544, 69.93093367545836, 73.01278698828914, 71.57745838165283, 71.36186138276132, 69.57495504809965, 66.4728936841411, 70.15639935770344, 72.80846288127285, 68.99034930813697, 62.777514996067175, 68.15649263320431, 72.77476187675231, 77.52599946914181, 72.3906598552581, 66.83567370137861, 76.31950978309878, 69.52943986462009, 71.26143301686933, 72.4921315716159, 66.23335453771776, 68.89574958432105, 72.21217632293701, 73.10449200291788, 68.9440574953633, 68.33674907684326, 69.16130973446754, 63.238620988784305, 60.386744083896765, 66.13710741842947, 64.50309115071451, 60.63184907359462, 60.326429797757065, 56.704897572917325, 55.81795161770236, 55.32068921673683, 53.0731632632594, 62.60677814483643, 68.82946152840891, 70.01012632923742, 70.82523407474642, 71.21250537133986, 68.23031948458764, 67.17177375670403, 66.21018117473972, 61.825492997323316, 54.0335242209896, 55.23009031049667, 55.64466130348944, 53.742535345015995, 53.726030011330884, 54.72662271991853, 55.92640907533708, 57.968289083050145, 58.526144258437625, 62.167790397520996, 71.08553040412166, 74.22433653185445, 73.25651522605651, 74.2054856208063, 74.38691877549695, 68.82658250870244, 60.819734527218735, 58.782639811115885, 58.67997177185551, 62.62386006693687, 64.1756752229506, 65.76039121996972, 67.4226720871464, 71.36688986132222, 70.45414647748395, 73.75424046670237, 72.5424712704074, 79.6739835123862, 80.58457743737006, 85.53489100548529, 79.78515917255034, 79.47869654624694, 84.21172649629655, 88.3391111127792, 84.67374247889366, 74.26732570894303, 2.9429158520314003, 5.2806889241741555, 8.00850518288151, 0.836185766083579, 0.2541008537575122, 5.788208813436571, 83.22875699689313, 77.33063405559909, 69.70473843236124, 67.5788059542256, 39.29173523379911, 40.44562201346121, 75.22798476680633, 44.86059873334823, 0.17594364441690907, 0.21726109508064487, 0.21560148816675911, 0.1909968584415413, 0.07486807212473885, 0.17757387951977793, 0.14869650164919515, 0.21753855680506076, 0.19500426437345245, 0.17911575404146027, 0.16696461896982887], [0.062380195445110725, 0.07869063636227962, 0.009637388002668178, 0.061339955296247244, 0.009501513690807888, 0.041553578114197146, 0.031186299841670744, 0.035822298152432326, 0.03829744396611087, 0.05322500807984222, 0.03542860173770497, 0.34433488764109155, 43.518187153723936, 60.94340293638168, 42.31231720216813, 43.21572142262613, 48.24767520350795, 53.16337777722267, 8.026404919162873, 0.2309919034521426, 0.18065004429269224, 5.584999640141764, 0.8771853821892893, 0.031818416224972855, 66.30289816087293, 96.8468967560799, 90.79675059164725, 89.10292994591498, 83.26705501925561, 82.04107115345617, 85.13363253685736, 82.2923303419544, 87.64333755739274, 86.21746186287173, 89.48097582786315, 92.06318978340396, 89.71496874286284, 80.53962707519531, 77.43212930617794, 77.16955800210276, 76.00293528649115, 75.19820613245811, 74.36638124527471, 76.81166525809996, 76.71667329726681, 69.0028852032077, 60.909537192313906, 59.658465846892334, 62.67819666093396, 58.9307249746015, 58.5327220732166, 51.586953670747825, 51.932051643248535, 52.45133030799128, 52.10568712603662, 53.324143963475386, 54.467679608252745, 59.944912618206395, 69.02791776964742, 72.73378879793229, 71.52401216568487, 66.21273856009206, 64.88227844238281, 57.466323760248, 54.445643732624674, 54.26654831055672, 52.19206556197136, 50.22808774825066, 51.74089101053054, 58.211923183933386, 64.76889841018185, 65.70235583090013, 64.2385115931111, 61.184248232072406, 57.48205246463899, 57.78260800146288, 65.28944007812008, 61.38636012231151, 61.43269508115707, 58.140736087676025, 62.22390774757632, 64.58962255908598, 68.5072623529742, 62.801551280483125, 63.9504409605457, 63.57311679470924, 64.99676850534254, 59.89871101994669, 66.40312256351595, 59.760784795207364, 59.78299717749319, 63.937720714076875, 57.15599367695471, 55.68737983703614, 63.59061448804794, 65.4053774956734, 56.907833160892615, 52.55130760131344, 58.470862373229004, 62.065906832295084, 58.28462039270709, 58.61962610675443, 54.05540712418095, 51.746625515722464, 47.93751378213206, 46.826498508453376, 52.24593147154778, 60.6930458930231, 63.00392989189395, 68.30745681639641, 64.42902503475067, 63.60016545941753, 62.197906355704035, 62.04109391858501, 61.027667214793546, 55.805788347798014, 46.70912942578716, 48.6587631317877, 48.52195086017732, 48.89106550524312, 48.024923801422126, 50.85338415638093, 51.35287838597452, 49.19428040904384, 52.940022330130304, 64.07640395625945, 65.37165295693183, 67.25180579769996, 68.78622916436964, 59.997393931111986, 52.880174806041104, 53.70179368603615, 54.3944215005444, 52.62120816015428, 55.323964395830714, 55.52018880844117, 58.755308735755186, 60.304452757681574, 67.0449556842927, 65.70328151026081, 68.32227553090742, 67.67495109188941, 74.00951616225704, 75.67663331185618, 75.35933709913685, 70.37003517150879, 78.12744786662441, 77.22311404443558, 76.2259534097487, 78.33122284181657, 84.76518077235069, 26.062614187117546, 0.8830793562435335, 1.7205296576984468, 0.3147129642386591, 0.09016152366154617, 0.015330091607005847, 45.75651514914728, 71.83853134032219, 58.462805824895064, 43.45070669727941, 39.70481964849657, 32.30287763380235, 48.76657339834398, 39.90503703394244, 0.0793324648252418, 0.07157864379546336, 0.010434532173789077, 0.06017800675885332, 0.024126680875797907, 0.06764149578708796, 0.05968687928191597, 0.027334875156802517, 0.05972659327991067, 0.08927757311011515, 0.04768200188634857, 0.056198425140352025, 0.09589123314306622, 0.03764652970036672, 0.025332453472900297, 0.11809935598003289, 0.06786432778162342, 0.06341626807566612, 0.017386338628468015, 0.020289769726655176, 0.028940266028286952, 0.03341890796418152, 0.62768844106505, 55.910472485326956, 68.75521890578732, 56.26808281867736, 41.85188585712064, 52.99412358191706, 62.110602240408625, 7.265469518400009, 0.32380799071923383, 1.3749346473524648, 4.874235766549265, 1.2567571887085516, 0.19963662951223313, 72.917340032516, 100.39675158839073, 93.8515866187311, 92.62194710393106, 87.52237166127851, 83.67508349880096, 87.85436107266335, 84.50771639423986, 90.84874553065147, 90.38259536989274, 93.62856065073322, 91.52873546846452, 91.71878214805358, 84.06905420364873, 80.20548036021572, 79.17818023312476, 78.97296967044954, 78.63998397704094, 78.55860264070573, 79.75777318400722, 81.33302057943037, 70.40715648281959, 62.86898074611541, 61.65581910840927, 64.22844679124894, 61.301025036842596, 59.52175555690643, 54.20486903959706, 55.67916639389531, 54.739950933764064, 55.54033410164618, 56.42080030133648, 56.49359949173466, 63.396598369844504, 71.48543173266997, 74.95266575967112, 73.64272748270344, 69.6447967713879, 65.49312483879828, 58.97455353890697, 58.23377078579318, 57.31235111913374, 54.46675785126225, 54.40045802823959, 53.84838834885628, 60.952306716672844, 67.36557022217782, 69.62620473677113, 67.26816208131852, 64.7024142357611, 57.7898173178396, 60.77459981364589, 66.09807983521493, 66.96146411280479, 63.320814255745184, 59.612295627594, 66.31810911240117, 68.3810640150501, 71.78817595205, 63.640342297092566, 66.01635333030455, 66.01544334042457, 66.48857532009002, 62.600604334185206, 66.54201369131765, 62.09301433255596, 60.47402466497114, 63.62903410388578, 56.38963314794726, 53.37799810594129, 63.471496028284875, 68.50550513113699, 58.89205432707264, 56.31193491720385, 61.426054508455344, 67.0101877950853, 63.08388348548644, 61.49737496529857, 57.664513280314786, 54.456838177096465, 51.72325995660598, 50.284467897107525, 54.921815549173665, 62.48376869386243, 64.97015522372338, 68.60010485495292, 67.5721065459713, 65.18559532780802, 63.79635457069644, 64.26636042133455, 64.34306629242437, 59.41421201152187, 49.9234333345967, 50.21332394692206, 50.10680414015248, 50.802746357456336, 51.30026763485324, 51.52716890458138, 52.69552138543899, 51.45627206371677, 57.34165514669111, 67.81057096296742, 70.15323792734455, 69.50969465317266, 70.31005428683373, 63.116623509314756, 54.941086153830256, 56.96892015395626, 56.784266733354144, 56.46771577096755, 58.53518139931464, 59.03735853010609, 62.051484277171475, 65.50224827181908, 68.09087138022146, 69.3021777368361, 70.10031730897965, 70.42157511557303, 76.71002095745456, 76.67904207783361, 78.81274869365078, 71.67597263090073, 77.21050754670175, 79.48279150070684, 78.38954064153856, 80.52876995455834, 89.3622927511892, 37.22884701144311, 0.38173729193306744, 0.7936329526766654, 1.0500074634628913, 0.5523861043395535, 0.04030368268309582, 47.21120457495413, 80.81058440669891, 68.11886141377111, 44.9441962088308, 31.940852672823016, 36.993147865418464, 57.699689096020116, 48.67034981327672, 0.1810282619009095, 0.02876646940656487, 0.034210177198533094, 0.036128633730714364, 0.026435526238093456, 0.05032615052656301, 0.018455659474937186, 0.030966861616639845, 0.027020106865693966, 0.03432696730258965, 0.06689564790576696, 0.2321725981610437, 0.15563998551618669, 0.07814501322084859, 0.09985244397314326, 0.1966377936543957, 0.28076175540204973, 0.24740846286858284, 0.114922397018921, 0.2383156580429885, 0.10922721512014828, 0.11128865813295688, 0.7759504176435933, 66.03918152470743, 78.983701275241, 54.929197449837964, 58.64068923457977, 64.38763618469238, 74.69345200446345, 9.90800021156188, 0.39519423919339336, 2.4674012776344054, 11.164726634179393, 6.3132160998159845, 0.36282466484173653, 78.16413771721625, 103.00187218573787, 101.29810440924861, 96.54216781739267, 94.07137270896666, 88.12361609551215, 91.59689057257869, 86.89611035008585, 96.30685698601508, 93.01495290571644, 96.09057749471357, 96.089949915486, 95.86362915654337, 86.50155128971224, 85.03588707216325, 81.87950088131814, 84.66367767703149, 83.55468242399155, 81.2243160124748, 83.29085596146123, 86.86978340148927, 74.22512885062926, 67.82970428466797, 64.21202774970763, 68.70610298648958, 66.05123889061713, 63.94155286973523, 57.36297322857765, 59.64749105515019, 59.34737090141543, 59.063932588023526, 60.509255393858886, 61.51607682628017, 67.74067432649674, 75.14348122381395, 80.13625052667435, 76.95084664129442, 72.4034232477988, 69.85008578146659, 60.58436486028857, 63.23524775043611, 61.41636625412972, 57.6637327286505, 58.969317174726925, 57.835559998789144, 63.81907686110466, 72.22615565023115, 75.99114464175317, 70.90317941481068, 67.98197069475728, 65.00373463476858, 66.2813800381076, 70.12807200031897, 68.60940871700164, 69.1843968053018, 63.88609447786885, 66.31578706925916, 71.32188458596507, 73.35089529714277, 66.33453599868282, 68.75437951857045, 69.90779953618204, 67.02230007417741, 62.750109395673206, 73.0832641355453, 62.367289989225334, 60.896381562755955, 66.23435081974154, 60.188778138929806, 55.75404444048482, 66.85727811628773, 69.44077076450472, 61.29597694643083, 58.32426378803869, 65.07881664460706, 69.85951515936083, 66.19819441149312, 65.1838851744129, 60.729441565852014, 57.59480883998256, 53.654336929321296, 52.85558154506069, 57.97323911420761, 66.92784940042804, 68.90160176061815, 67.76442035551995, 71.2270808989002, 69.46472860151722, 66.03566708103304, 68.49514222914173, 68.49379293380245, 61.25831434803625, 53.41278168462938, 53.891365758834354, 54.32490533398044, 54.96582454250705, 55.1618371471282, 58.13447206251083, 58.393881936227125, 53.42162662936796, 60.602611726330174, 71.42273656783566, 73.36755752563477, 73.51923558019823, 72.38694929307508, 65.74573724500596, 59.086572508658136, 59.76248318149198, 60.49310307348929, 61.02332515101279, 62.823834265432055, 62.24369218272548, 65.83877978786346, 69.8881955300608, 72.60441334016862, 73.1081319624378, 75.27850489462577, 75.27306848956694, 82.32311310306673, 80.9740609507407, 81.07609748840332, 74.98869665207403, 81.43475117221956, 82.94492644648399, 80.89881420135498, 83.36731080086001, 93.12919585935532, 37.8134213724444, 1.7852708288738806, 8.561743728576168, 1.3826945664421206, 0.4515569212455904, 0.16876517074002376, 57.66760410801057, 88.08867562201716, 74.80068176023423, 59.502579089133974, 53.032853064998505, 45.0408394875065, 65.43543854067403, 58.5506159259427, 0.4253394619351433, 0.1371016383411423, 0.1047435399865912, 0.09728455555535133, 0.08290902290853762, 0.20551958722212624, 0.11319627069056996, 0.13022635162117022, 0.12262593969822892, 0.10867403835178384, 0.15809715124628237], [0.04590810231503941, 0.13459614778478302, 0.09474175651707957, 0.043640259893671166, 0.12198254841590121, 0.22179564611325342, 0.050162801428908305, 0.09586344713405257, 0.11442961096162758, 0.3400189627803141, 0.38967108233801784, 3.1422509493366366, 54.953084684187374, 62.926698423201046, 11.79039272569841, 40.9061239611718, 58.37568606099775, 51.774117408260224, 2.6190717326056574, 0.23418396200624206, 0.6542002313560056, 2.975097183258303, 0.28032480949355715, 4.870409494446171, 96.01928449446156, 82.90532619722428, 97.47757465608659, 80.58755843870102, 88.73342698620212, 79.23190885974516, 82.38512577549105, 77.49052555330339, 83.66646997390255, 83.1679916381836, 90.0192819103118, 86.5568410196612, 89.93474698835804, 81.91735175348099, 76.36523677456763, 76.78621692042198, 77.51191031548285, 73.96072972205378, 74.09459237129458, 72.21765195169758, 69.83291364485218, 61.43882182336623, 63.09873357895882, 60.698325403275035, 61.505015742394235, 60.22618578326318, 57.678563210272024, 52.04133279861943, 53.42573335093837, 49.29785451581402, 53.80536779280632, 50.96565415782314, 55.1618371471282, 62.33877043570242, 69.19583443672427, 65.94233820515295, 64.57594133192494, 61.903897254697746, 57.73583765952819, 54.02829177917973, 56.60273159703901, 50.74597397158223, 51.65903898977464, 51.44440297157534, 57.910394899306766, 62.66909676213419, 65.98258956786125, 63.82241872049148, 60.17485372481808, 58.35010044036373, 55.254683571477095, 57.68408198510447, 66.81313576236849, 63.61333677845617, 56.4575215308897, 56.565727956833385, 60.64844854416386, 68.7358816208378, 70.78760285531321, 56.685603434039706, 58.999872438369266, 63.12031838201708, 62.952056546365064, 66.26335282479563, 63.82423477788126, 70.65503458822928, 68.49070995084702, 66.98197026406565, 60.09703390059933, 48.43817295566682, 48.66064979184059, 64.60334693231891, 58.63308768118582, 50.98800382306499, 56.88498535463887, 62.273317844636985, 61.158807739134765, 59.667326481111594, 57.35720342205417, 56.37896822344873, 50.9788647005635, 48.665011467472205, 49.68154861081032, 60.652292466932735, 56.359674084571104, 60.689609896752145, 66.80752677302208, 65.33948952151884, 61.50195237128966, 64.95204171826764, 63.3469529305735, 61.89041214604532, 54.42272532370783, 49.627286541846495, 47.114835862190496, 46.160656559851866, 47.114714268715154, 47.721061706542976, 49.41087368995913, 51.13031525765696, 52.42527400293658, 63.93109583085584, 64.89692457260625, 67.82846481569352, 61.29777339196975, 54.719625211531124, 52.961273731723914, 53.702083941428896, 51.41351038409818, 53.9047488858623, 52.60665616681499, 57.81440665644985, 57.625556299763346, 64.71256925213721, 62.77221587396438, 66.25444904450448, 65.8704254704137, 72.19213301135649, 70.9041129389117, 76.70896191750803, 74.99061861345845, 71.41134600485526, 76.86409950256348, 81.37952420019334, 74.13118024026194, 77.15961087134578, 79.2575611606721, 75.70995776884018, 1.0222861122700477, 0.9317682887757979, 2.1390908043230734, 0.5040272024850692, 0.15118273275513805, 15.516636544658294, 79.98777312617149, 57.26245857054188, 50.392344843956735, 39.6658665903153, 38.32416495969219, 51.39395344641901, 36.530680810251546, 0.14608357492233479, 0.04299957290171616, 0.05533408260934296, 0.05129528239429478, 0.12257576093918855, 0.0523497564567914, 0.06800052289280199, 0.04125143303686092, 0.06615759113863592, 0.03744292268229108, 0.1603564364655364, 0.00987539524137373, 0.25840789199836794, 0.12556515859379885, 0.03179300508852447, 0.0646506732089385, 0.09872083251755084, 0.08878235855410177, 0.1282161139252205, 0.142963727815978, 0.3159357324963616, 0.43612509124702026, 5.8394187881100565, 67.30864094149682, 68.77893355584914, 22.59386024167461, 39.85089655845396, 65.30458827172556, 59.565937134527395, 2.693901239864288, 0.32153929794026964, 2.3675539128242002, 2.4725067327099466, 0.17461969126616755, 7.405747694353904, 102.14819969669466, 87.01450317136704, 102.3286130351405, 83.27815532684326, 91.34027342642509, 81.93402967145367, 85.12296368998867, 79.2951374669229, 86.68973092109927, 85.30900170726161, 91.96899798608597, 89.75175273033881, 91.70172768254434, 84.5755498639999, 81.5044673796623, 78.31505483196628, 80.16075749551096, 76.1219007738175, 77.12339170517461, 75.28883641765964, 73.76050841423773, 62.51316685830394, 65.53257211562126, 63.2601861799917, 64.01270858703121, 61.26226417479977, 59.136139500525694, 54.206849836534076, 57.60171613385601, 52.318142306420114, 57.67359748963387, 53.798821356988725, 56.0719996113931, 65.46462881949641, 70.48169720557429, 69.89045481528007, 68.41759697083505, 63.95537922459265, 60.53986164831347, 57.08494778602355, 59.23283377001363, 54.30794892772552, 56.31520225155739, 54.178381273823405, 61.25064611434937, 63.80749410198581, 69.696242578568, 67.33463841099893, 63.78526210784913, 60.64356519329933, 59.329033820859856, 62.793294691270404, 71.20884187759893, 67.82791568386939, 61.27156411447833, 57.54523008100448, 63.80499162981587, 72.98223956938713, 73.21906443565123, 56.724164255203746, 58.08756051524993, 65.78411371477189, 66.07045850446148, 69.69385777750324, 69.25830210408857, 71.0423372637841, 70.30503365301317, 68.68424753988944, 64.85156236156341, 50.771241880232296, 48.56666195777155, 64.95550124875962, 60.90412039910594, 52.876750576880674, 58.92789302333709, 64.72506200113605, 64.71675442111108, 61.90838836854505, 62.39726866445234, 57.90452311115881, 54.04747609169253, 50.68564399596184, 50.317286368339296, 62.236074939850845, 57.62430506367838, 61.6017766921751, 67.12370118787213, 67.77435964153659, 65.60085273558094, 67.3462329372283, 65.10950919120543, 66.253186041309, 58.402652355932425, 50.79810619354249, 51.181706151654645, 49.001746946765536, 50.05351481899139, 50.61682601128855, 51.633574962615974, 55.45584232576432, 54.12875544640326, 64.57684739943474, 67.73654799307546, 71.28750108903455, 65.70842373755671, 58.0177148695915, 55.0720384044032, 55.66267282732072, 53.73523581412531, 57.938479069740545, 55.85255476736254, 61.2913328601468, 61.10084687509845, 66.40976705858785, 64.02296166266164, 70.92507408511254, 69.859632830466, 76.7003954610517, 72.56344810608896, 78.83585929870605, 76.2529706954956, 73.7217789311563, 77.4886114366593, 82.29047898323306, 75.24433320568454, 81.44760085690407, 77.87698884164134, 85.34094548994496, 2.5792042718779657, 0.8352669508707139, 3.752468295635716, 1.4736360672020143, 0.2026760986735744, 14.643745422363283, 87.70329490784677, 65.08330383608418, 57.82187877162811, 32.49609162730555, 49.83033587855678, 58.1799715565097, 43.85932353235061, 0.191427844185983, 0.019047914388319178, 0.04929293540396518, 0.07118472138479834, 0.023937692730537346, 0.049779282492255016, 0.060588852051765694, 0.044146647842060176, 0.08656862492282545, 0.0562021444972244, 0.1258075181695242, 0.13580788437637592, 0.3000109095967585, 0.22204381263544484, 0.09427330141226131, 0.23001606065419414, 0.4161272240021537, 0.26719087554562476, 0.15587852997404916, 0.28322592317577333, 0.5445917419368221, 0.604779102629231, 6.629537113251225, 80.1764234419792, 77.53080829497307, 19.96123794586428, 53.97245291740664, 79.07972089705929, 65.53560410776447, 4.075366878701795, 0.4176970913765892, 4.08469966823055, 10.273960290416595, 1.8827158645276103, 7.217362138532824, 106.47788447718467, 90.60217749687934, 106.7971654092112, 86.15982655555972, 96.5116439327117, 83.33828526158487, 89.830105996901, 84.76267830018075, 91.58033032571116, 91.05644287601595, 97.96998900751915, 93.93127349115188, 94.17981839949086, 87.65890152223649, 83.76282691955566, 83.69726842449558, 86.94326508429744, 80.94502756672522, 79.81033294431626, 79.71134801064768, 75.79540268067392, 65.92228704883208, 68.21564982014318, 67.51742086102887, 67.88989697733234, 67.74537332596319, 63.169916752846014, 58.79174363228583, 61.68316587325066, 54.45090755339592, 60.0559784520057, 57.06160183875792, 59.30658609636369, 67.07280451251616, 76.74966043041599, 72.27239254982241, 69.95156534256475, 69.4197311709004, 64.96266741906443, 60.58778124470865, 62.502019482274214, 57.278642269872854, 60.84631250750635, 58.32867645448255, 63.943796465473795, 69.19892526442005, 73.05660770785424, 69.76762971570416, 68.04712910805979, 66.6359152332429, 62.029111077708585, 65.51228953946021, 75.54082516700991, 71.14404432235226, 65.77195828960788, 59.39927562590569, 66.10699146024643, 76.16588623292985, 76.61763345041584, 60.93661331361341, 60.543007389191665, 67.16177171276462, 66.68062240846696, 72.09913361457087, 69.91023925042921, 77.85704751168528, 74.62054298770043, 71.5848324375768, 67.34759792204827, 51.60709111921249, 49.8757137790803, 70.3266223784416, 63.979348828715665, 56.73904180526734, 61.33844052591632, 69.40495168009113, 68.38174650746008, 66.37241824980705, 64.54482909171813, 60.75981247809626, 56.33858350015456, 53.657925898028964, 55.44689539940127, 66.40653502556586, 63.18769293446695, 64.36681232144757, 67.41354080938524, 70.93484078684162, 68.05318524760585, 72.35389940200314, 68.11475861457087, 69.23070430755615, 60.285217454356534, 56.91062196608513, 53.670779505083644, 52.52873043860159, 53.30535188797982, 54.19265477888046, 54.060984734565984, 58.593397217412154, 57.798489678290586, 70.3851676756336, 71.2441510538901, 73.66054288802609, 69.99596657291536, 60.31345851959721, 57.521958658772135, 58.98041748231458, 58.97058410029258, 60.33030902185748, 59.91170583232757, 64.06642936891126, 63.54765276755057, 73.51250479298254, 70.40394798401864, 74.82514166062879, 73.08138924260294, 79.46110863839426, 76.93110142984699, 82.4678328729445, 80.45105995670443, 75.71181697230186, 81.79166332367929, 88.12106655490014, 80.19219137007191, 85.39896518953385, 81.52345165129631, 87.36562590445243, 1.6724889581241917, 4.295109087421048, 10.953745284388143, 1.0194447840894423, 0.31960124870942486, 20.45005940621899, 96.85893843250891, 68.52885892314296, 69.44969023427656, 54.38512156086584, 54.947824785786295, 67.93983659436627, 54.36404666592998, 0.2841097741357742, 0.14353548987738549, 0.19469176178737996, 0.14896778870494137, 0.24950417299424452, 0.22360462485061539, 0.17177768892818884, 0.11936782138241876, 0.2644934799642332, 0.15700444939636415, 0.2461328805093804], [0.028962156990723267, 0.1167865417477104, 0.06252828790175338, 0.06328422133059752, 0.039010840362959334, 0.12626378481546718, 0.14268242033018222, 0.062214973262481155, 0.04045030808136348, 0.10847208991406426, 0.34903192592244, 12.042909033836859, 65.28973033351284, 35.069040944499356, 33.64831139964442, 52.62147095895583, 52.73118749741585, 50.62440795283164, 0.09280499431394762, 0.11798665678549199, 1.968194361655943, 4.902538609120154, 1.0080305643139347, 25.307659910571193, 98.8917459980134, 86.44299030303956, 97.29345075545773, 84.11549506648895, 84.56197846320369, 80.00789488515547, 83.8715785549533, 76.18016366035708, 76.63920648636358, 70.28346846180578, 80.11959614292269, 85.21331156453779, 87.92396745374127, 83.84510255629017, 77.59422517591908, 71.6897636844266, 72.04249458928263, 70.35394560906195, 67.20861265736242, 65.0258764143913, 61.689645628775324, 61.860558986663825, 59.522740071819676, 58.46696353727772, 62.86125367687595, 58.61943783298616, 54.58153816961474, 51.99993218145063, 55.212361197317804, 52.210230058239354, 54.40580814115463, 51.76548819388113, 57.04517103010609, 63.598718104823945, 64.06131459820655, 66.13234566104028, 64.95128470082437, 58.19130328393752, 56.322894019465295, 54.024345874786384, 55.4394664302949, 52.865713027215776, 51.88145306802566, 52.05179768223917, 58.65487252512286, 61.033978308400805, 61.96356042738884, 60.056264785028276, 62.32090796193769, 56.94386013092534, 56.184187243061686, 60.45402057709233, 66.00127573936217, 59.347920033239554, 58.63314651673841, 57.756202605462846, 61.64012570534984, 69.78619037135955, 54.752914367183564, 50.98187708085584, 55.168058026221495, 63.985997246157744, 62.804971587273386, 60.680019701680834, 61.4324793507976, 58.4369299488683, 58.213907903240575, 58.62702761926959, 62.197996570218, 61.647782171926195, 55.96187906880533, 52.31971909922939, 60.38149987497638, 52.91839045862998, 54.688356076517415, 61.64515810628092, 62.68228769302369, 60.222314403903106, 60.149472067433024, 61.278722440042806, 57.43965556544643, 47.8019449018663, 48.68032047825475, 53.3068423886453, 60.47114172289449, 53.66673946380616, 57.20507037255072, 66.29843450361683, 66.88315791468467, 61.95334265308996, 64.13612596450314, 59.07475832969912, 62.16550757808071, 53.579211773410925, 47.10147626938359, 47.679468893235736, 45.47208839847196, 46.827537936549035, 49.74675801492507, 50.850493369563935, 50.83606689207016, 56.1449949202999, 63.41776740166449, 60.45966879014046, 56.617518932588645, 52.731128661863266, 51.59375506062662, 50.78661757130777, 53.40738058090211, 55.03901989229264, 55.516541004180915, 62.40454073875182, 63.41186815692533, 65.583190302695, 63.08100838815013, 66.19065561602193, 66.73623377277006, 74.31049531505954, 71.86710972939768, 74.67962172723587, 68.53174578758978, 76.52980373751733, 74.1501017539732, 77.47126671575731, 69.99191868689753, 80.41853566323557, 74.37426520932105, 91.88429047984462, 22.518846873314153, 0.511485742585313, 1.1960550782180603, 0.28251885466517945, 0.1043022656813264, 2.0553277312747897, 69.49824917700984, 65.35590856306015, 52.67873756347164, 43.40555629422588, 33.85675007297147, 42.40570099123063, 41.3290927487035, 0.336482118695013, 0.02365595623550396, 0.05746649983789652, 0.00803331001436398, 0.0638582203687439, 0.05723905599405689, 0.05083420854662696, 0.10932518244390527, 0.06593197824493532, 0.09991446645149302, 0.0866886709005602, 0.013785294459892378, 0.08412056797814947, 0.030077954476338722, 0.07231241813109768, 0.042579277914257786, 0.10676597380229544, 0.011319651966914536, 0.09910478046344173, 0.10817827987334422, 0.2557294494322231, 0.47535348142827716, 16.331931583343014, 75.08344542595648, 45.58312285330988, 34.36668957433393, 38.90516211909633, 64.19334942294707, 54.862285737068426, 0.06268663061482292, 0.30131080758667766, 2.914059219821807, 7.05691562544915, 0.8724733285846249, 31.753106463340025, 108.26897990319037, 89.1514810439079, 101.17883297704883, 86.64671820978965, 89.68839860731556, 82.03979246077999, 87.34369985518917, 77.88146818837812, 80.40326979852493, 72.26872121134113, 81.1582789882537, 87.67223758082237, 90.2435944157262, 85.92747319129207, 80.21243080016106, 72.66094253909203, 74.6829322076613, 73.17197245936241, 67.38333855905842, 66.94466852372693, 64.9008704769996, 64.40818940439533, 63.60586074090774, 60.451926031420314, 66.28975037605532, 61.98632978623914, 57.55552630270682, 53.444274394742905, 58.293720291506865, 54.835848962107015, 58.521460948451875, 55.47102974307153, 60.45026294646725, 65.66697997431602, 66.97487861879411, 69.73370905845397, 66.72529820472964, 60.56893817840084, 60.088353695407996, 57.8424241465907, 58.480825193466686, 55.9498687713377, 55.36260758676837, 54.6113677947752, 62.10495402736049, 63.45979167569069, 63.3572256180548, 63.94906420861522, 64.14289205305039, 58.714520008333274, 60.322009286572865, 63.56707634464387, 70.09474754333496, 63.47318264745898, 61.34130385614211, 59.154402056048, 62.59009630449357, 69.35140348249867, 55.76707455419726, 51.981810831254535, 58.36609194355627, 66.7856321027202, 65.59253338844546, 63.04704458482804, 59.757086000134876, 60.49002793527419, 60.553436971479854, 60.92622687739711, 65.61235312492617, 62.58016486321727, 59.03292625181137, 52.19449350910803, 59.752775315315496, 54.110026128830455, 55.962785136315134, 64.85502581442556, 65.26090091274631, 65.58836783132246, 65.4135242585213, 64.10626103801113, 61.22449567241054, 50.9360755643537, 50.90097427368165, 54.699107293159734, 64.89693633971676, 58.9326665478368, 58.70358836266303, 65.313907823255, 67.19649253352996, 65.20258311302432, 66.69842212430893, 63.07060234008297, 65.00042415434315, 58.23537111282349, 48.50640258481426, 49.34650367306125, 48.240560024015366, 48.185897873293975, 50.46758767097227, 51.72390714768441, 51.79544333488711, 60.06445861631825, 64.9275622060222, 60.96911015049104, 59.28346372419789, 54.62136983871461, 55.04430724728493, 52.70890059009675, 58.134354391405665, 57.69245624542237, 57.80090193594656, 65.16507740943663, 66.44913981037756, 69.14958184765231, 67.48235487168836, 69.11553567455661, 70.29758899442612, 76.57904517266059, 75.78749518240653, 76.65199341312533, 71.44110110498244, 76.90142477712324, 75.9313912545481, 79.41558561017438, 73.87742642433413, 83.55756928843837, 77.5438384086855, 95.2265577931558, 31.133411199815814, 0.5757483539562072, 1.1313972574087883, 1.7653931148590583, 0.09170795640637798, 1.725218360943179, 74.2836663030809, 73.27807257252356, 62.47794397415654, 38.77915989968085, 38.89466585651521, 55.43261797197404, 51.15410051038189, 0.9404985654738642, 0.04956767368581026, 0.11193122204032638, 0.0563226807712307, 0.040384872681311065, 0.0377967557118785, 0.11666327053981444, 0.032053496050197756, 0.018629929155952508, 0.12272234420262038, 0.08954296894972363, 0.1646343327217525, 0.20679031258388875, 0.20784498582924568, 0.23162950310976277, 0.13627823171836717, 0.20282455119154147, 0.2694402629088971, 0.3147314116358757, 0.3141686128031823, 0.49357233929537964, 0.8056294605616601, 19.322448584341235, 90.83659402785763, 50.339789006017874, 43.165958312249955, 67.17731214338734, 71.39741374600318, 61.43804127170194, 0.2694012230682758, 0.35725888285425406, 4.446743995912613, 12.284635882223807, 1.437071242159413, 32.72040413271996, 111.82354942444833, 90.65301141431256, 106.41460880156487, 88.9293493763093, 93.09522813366306, 86.75738396183138, 94.22596116219798, 84.59003909941643, 85.34547190512382, 76.18460378339215, 87.52557231533913, 90.87071080361643, 95.21997605600666, 91.28671738409227, 85.90804961419876, 74.74869466597035, 78.59651627079134, 76.86927703119095, 72.63359577425065, 71.16680191409203, 68.07581732350012, 69.48457579458915, 65.50955564745011, 65.35129977810767, 69.22911967000654, 65.94784521287488, 60.83887569365963, 58.510293960571296, 64.40390617616715, 59.688668097219164, 61.193450112496656, 57.861694751247285, 62.69684753110332, 69.99944963762837, 69.9763390325731, 72.54462857400218, 72.59036341021138, 63.98972742019161, 63.6646217684592, 60.50852191063666, 62.58246337213824, 59.09779833209131, 59.89389827174526, 57.17376985857564, 66.98621426859211, 65.53656508845668, 68.46392800731044, 69.44588553520941, 68.79540751057287, 62.05361412417505, 64.859952311362, 68.4814453125, 72.24717955435477, 67.46078183574062, 65.82135661955803, 62.23982864810575, 63.20292742021623, 74.58272349449896, 53.59977676022438, 54.79394628155617, 59.164588451385505, 69.9641953745196, 67.192578008098, 64.14911685451385, 62.624554326457364, 61.18078477921025, 60.44068844087663, 62.43780636018323, 66.06011129194691, 64.57751812473421, 58.86677465131206, 52.88062587861092, 63.89283703219507, 59.2355441278027, 61.109476089477546, 69.98077131086781, 68.28904521080756, 67.0562913340907, 68.34278952690863, 66.57929974217569, 64.44749939826228, 53.190453898522165, 53.37781375454318, 59.611452318006954, 67.78705243141421, 61.731932701603064, 63.24523410489483, 68.53250672740322, 69.96550544615715, 68.16657312454717, 71.6485474186559, 64.2389783551616, 69.42821133521296, 59.87025030197636, 53.055775396285526, 53.854315050186656, 51.12302357150663, 50.437644297076815, 54.02394971539898, 56.22735684917819, 56.33584568577429, 63.088829594273726, 70.7769653874059, 64.42803659746724, 62.672007160802046, 59.19257456256498, 58.71488086638912, 55.18986640437957, 59.70602458523166, 59.817651317965606, 60.88863488166564, 68.07565258395287, 69.07249158428561, 73.48364399325463, 69.85735001102572, 73.81782208719562, 72.40754173647973, 81.24387295015397, 78.7557174313453, 78.26690381573093, 72.02509495519823, 80.4461177702873, 79.00974581318518, 81.60834743130593, 75.98444523349886, 88.55929728477233, 81.47959955276983, 98.79664421081544, 29.798875739497525, 0.9625800386551888, 5.642858522553598, 1.975779367550727, 0.3051293881670121, 3.951776916942289, 85.26524374561926, 79.42808228154337, 68.66961709914669, 60.33905982971192, 42.83438074973322, 56.45448561637633, 62.26079763904695, 1.2772753522280724, 0.16999278067340776, 0.2014603171377413, 0.214509736265867, 0.1233079111684234, 0.14975558756099594, 0.2346838190550766, 0.23427659735804607, 0.18924015754413223, 0.3099238421888121, 0.17072254070831885], [0.01677121790576606, 0.010162634162923262, 0.01955869010529451, 0.065589475655748, 0.04405366392025063, 0.12262765573517931, 0.12880119825563124, 0.00896744698571462, 0.06520086223439825, 0.12258290853952208, 0.12209055149146628, 26.254900540074996, 74.198103720142, 25.910002608453077, 48.36338512359127, 50.914816318019746, 66.31712067511775, 35.106907506142896, 0.5123045373587839, 0.7168263257030518, 1.804704702188892, 13.569137588624033, 0.7191409531139559, 60.99460947898127, 107.22984206291937, 92.73514670710411, 94.73175079591813, 85.08033537095594, 85.50000544517272, 81.58812369069746, 78.14385121868503, 77.93675007358675, 74.24856109003868, 72.04393802150604, 66.48579043726768, 69.99943394814768, 75.4787968051049, 72.81673123759609, 67.74969577789307, 66.68743948782644, 65.54804978832122, 61.19355601649131, 60.651935531247055, 60.5611797302, 60.901908182328754, 59.864468728342366, 59.71330058190131, 58.85724329179334, 59.643345109878055, 55.55282685064501, 49.71519077977827, 54.07754105906333, 54.161248360910726, 54.50811924472932, 53.99282570808165, 53.42930270779518, 57.88826488679456, 64.51798439025879, 65.12824635351858, 63.71891913875457, 60.336008225717855, 55.70457943024174, 55.56644924225346, 56.631317830854854, 54.35968106792819, 53.45577870645831, 51.73765897750855, 54.77480903748543, 59.96688573591171, 59.506336719759055, 60.626961800359915, 57.40020436625327, 57.77342965525966, 53.71066608736592, 58.30241618617889, 60.86097824958063, 62.924615644639545, 62.319354703349454, 56.760073554131296, 58.50294343886837, 61.71225809281873, 58.4052058189146, 60.23870206648304, 58.27007624410815, 64.45955676417198, 67.32589937025502, 62.5664875584264, 60.812050604051166, 64.00766049661945, 65.13206674206641, 65.51687871256183, 63.086958623701534, 66.86053368353075, 63.260586261749275, 64.68789754375335, 57.230487331267334, 49.35307756547005, 46.93545802947014, 53.11042970226657, 60.857993325879505, 61.76486492156983, 64.97592895261704, 63.251655024866906, 64.57663559144544, 61.78064853914323, 55.28282657746346, 44.60180859411917, 49.60021434291717, 55.5116694204269, 59.01656996819281, 54.12786899074432, 55.98938665082378, 60.41799360705961, 67.76447526870236, 63.00942513250536, 62.67812605827086, 60.49691953966695, 59.312367669997684, 50.424523968850416, 45.1578987029291, 46.28191271135884, 45.1664416251644, 48.434685968583636, 48.87523481922765, 49.5661211013794, 51.839507241402906, 57.96411175881663, 53.947581168143984, 49.99532645748508, 51.58884033080071, 51.84389637362573, 55.040231904675885, 53.187582723556034, 56.56090736389161, 62.04179602284586, 66.34511855340773, 66.13059628394343, 67.43533349806263, 67.17520975297498, 70.21994175449495, 70.80723039565548, 74.22344223145517, 78.87828365448983, 73.47355565717145, 70.93619008218089, 76.73327276783606, 75.35795642483619, 76.34366373861991, 72.33755096312493, 76.16838086035945, 78.35946390705725, 84.64769009620913, 62.10283986983761, 0.17173943049725027, 1.2854391528714089, 3.1858829048372086, 0.011006433088632842, 0.15757359143707061, 40.20620838288338, 77.51183186807941, 51.65441059297132, 48.22724749965053, 37.59900892934492, 39.68151292493267, 50.64926793498378, 1.7903544657653379, 0.05382599639556101, 0.09916691785498012, 0.041636185375072306, 0.04220931490342464, 0.08318243968871333, 0.05509692477062345, 0.0604566635804311, 0.04158372367401758, 0.01918973258486198, 0.053746419012426376, 0.08011487808318869, 0.050641690651255275, 0.06988251747022714, 0.06090554896922362, 0.055217886223427715, 0.11627565303276624, 0.062051654808343425, 0.033640721061777686, 0.04053707519966749, 0.07719484202924275, 0.14887170595747812, 37.469064727906265, 78.77896924172678, 42.72395426227201, 44.582883158037745, 44.51117438654746, 81.02769544047695, 33.749814494963616, 0.5507776261337343, 0.6779580887767577, 3.6890482277639456, 19.30086966483824, 2.3672575287280546, 66.32131761120212, 109.56454661584671, 98.14187511321038, 97.78394314550586, 86.43135655310847, 88.90594067112093, 85.35069650219333, 82.90935054902108, 80.42284242568478, 78.99111455486667, 74.48254616029801, 72.43509246457008, 70.96104221959268, 75.66298346365653, 73.99995342377694, 71.17336796176049, 68.76107108208441, 69.23025715735652, 63.94741289077267, 61.11549300532187, 62.392659879499874, 62.68535106412826, 61.76294296018539, 62.389043454200994, 60.73365419141708, 62.174250541194795, 59.50928634212863, 53.11667019321073, 56.901447542252086, 59.32769237026092, 57.42326790286649, 54.28480302133868, 54.86678861802625, 60.9776883740579, 66.14546991163685, 68.78779811243858, 65.29306042578914, 62.248218597904334, 59.29087700382356, 60.470984828087595, 58.39638440839706, 58.641654137642156, 54.495508824625325, 55.01191239203177, 61.02093250520768, 61.20411895936536, 63.32089270314863, 61.352780711266306, 61.200122064159764, 60.39718543329547, 57.85391276882541, 60.85620472508093, 66.65333840154833, 65.91952570023076, 64.54927313712336, 61.12508320039319, 60.84537506103516, 59.46603436623851, 60.78814768022107, 62.2073475007088, 62.53400641102945, 69.67821536525604, 69.98890630660519, 65.88043535909345, 62.520254581205315, 66.59337320635396, 65.65697008563627, 67.53891544957315, 65.8507900853311, 67.4301245904738, 64.0480883659855, 67.80616221889373, 58.72203134721326, 50.2602433389233, 49.15857507336525, 54.479427106918834, 61.479626240268836, 67.81734881862518, 70.65703499701716, 66.12024122668852, 67.91157199490455, 64.99445822931105, 56.93428562533472, 49.03957036233718, 53.678302611074145, 57.32240415388539, 61.678553165928015, 58.416251213319846, 59.00027644249701, 61.40750561991046, 69.18911933898926, 65.38566758555751, 65.39643056931035, 63.25380056135116, 62.11336751138011, 52.73521577158282, 48.92642174997638, 49.92823039331744, 49.20637307628509, 51.87887999319261, 51.553954770488126, 51.40681489821404, 53.694847168460974, 59.051043679637296, 56.818779668500355, 53.33665632432508, 54.25482434611167, 56.67892363763625, 56.855061592594275, 56.54773604485297, 58.50429273420765, 65.8093620115711, 68.4632690491215, 70.6242282928959, 68.45714230691233, 70.91591927313036, 72.51115506695163, 75.28915020727342, 75.71183266178255, 83.16842309890255, 72.48601267414709, 73.92305927891886, 78.89253754769602, 78.93205934955229, 77.84491169837214, 74.96630776313044, 75.07705196257561, 81.92596527837938, 83.20182600329, 74.97431724302231, 0.5517493320568916, 2.166135056364921, 5.279822080366073, 0.14226226706898984, 0.1746151713474143, 39.89246583754017, 85.14159494830717, 60.72012593669277, 49.52348101523615, 32.42623617572169, 49.90983447720928, 57.5197817433265, 3.156815935527125, 0.158372238098133, 0.11004869886223348, 0.037478779427587025, 0.03337570443569172, 0.022920705265395587, 0.03542557569040406, 0.020778213980637734, 0.01509259190155013, 0.01004505403069479, 0.04798348046719067, 0.17440238276556616, 0.17107025269539128, 0.17394305176792607, 0.13908588267382116, 0.1757370764690061, 0.1927903622028328, 0.24778828926144109, 0.09699813060222134, 0.17255928247205674, 0.19026829350379207, 0.1920316134008669, 40.12906320633427, 94.11116907673498, 38.135608780768614, 61.86970203153549, 72.073528382086, 86.06592501363447, 43.423006919122514, 0.7241034255393091, 1.7074177870827338, 4.596255921548413, 30.918843823094523, 4.28857147693634, 65.85799940170781, 112.12993360334828, 99.75575785483085, 104.2520727649812, 92.6549420818206, 92.190274576987, 89.1162738492412, 85.1354838955787, 85.64212076125607, 81.59086934981808, 78.08986371563327, 76.45726342355051, 74.97355630320888, 80.65494475826141, 77.64989145340459, 74.68978851072251, 72.86251314224737, 72.07712911790418, 66.5511606585595, 64.64093500568022, 65.7079569755062, 67.06136688109368, 64.34021865167927, 64.99128503184166, 62.71835780912831, 65.26978115881643, 62.49881098347326, 56.56897960170623, 59.85936572474819, 64.17113704066124, 60.40994490346601, 59.25816051421627, 57.23921068253056, 63.419308893142215, 71.99481425746795, 71.86755687959733, 70.80768539059547, 67.96833653603831, 61.12807989120484, 62.25556519723708, 63.28292023751044, 63.56267936768071, 58.06494020646619, 58.31778011014385, 64.13073662788638, 64.44365155312323, 64.80263079366377, 69.03280504288213, 63.70437106778545, 65.9760235201928, 61.01926942025462, 63.825278128347094, 68.75164170419016, 72.06340866704141, 69.61865025181925, 64.12504526876634, 61.67029265434512, 63.17630237148654, 61.04430198669434, 63.107084305055686, 60.94727431574176, 71.47182110817202, 74.13339245703914, 67.99602846945486, 63.788749094932314, 68.10401916503906, 67.96121351180538, 69.16102732381513, 66.71496668169576, 71.93311537465742, 67.13214997322329, 70.76247615198936, 59.12004993807886, 51.666534639173946, 52.12176492137294, 56.39779952264602, 65.77724172222999, 69.94861572019516, 75.7958576756139, 68.68329048156738, 71.57457151720601, 66.997024320787, 60.39134894647906, 50.90947012747488, 55.27247152020855, 62.075677456394324, 64.93417532213273, 61.68542908084009, 64.19078811522454, 68.10505467076456, 68.90419052493188, 69.32378999648556, 69.78856732768398, 65.87743866828181, 66.9132032702046, 56.76351739514259, 51.8653085923964, 51.51374655385172, 53.4749081057887, 56.38785239188903, 54.87568455357706, 54.0703199755761, 57.80719734007313, 63.8385671184909, 61.77670263474988, 54.59120288971932, 57.10974501025293, 59.4882938169664, 60.27620384770056, 59.2659777979697, 60.99631178763605, 68.46512825258317, 72.73913891084733, 74.04389181444722, 71.53847786688036, 74.56226441168016, 76.8056954106977, 77.65877169947471, 79.9317067669284, 87.84846182792418, 75.30997799288842, 75.41623500085647, 81.93734799661945, 83.030559632086, 82.31696282663654, 79.40388910232052, 80.90811021866338, 85.23438253710347, 89.06106256669568, 71.76590473421159, 0.425915805202338, 5.843635826341568, 9.608309557360988, 0.17737028399302116, 0.282971796489531, 49.47063884427471, 91.62773609161378, 66.27086024130544, 70.13293573933264, 51.89986075124433, 54.113811216046734, 70.66502094268799, 3.2788166019224354, 0.20639640549498223, 0.25378404575730523, 0.1954196832112728, 0.16726501736669772, 0.20679414302351015, 0.11425883464154699, 0.11074305031328432, 0.14969978571659134, 0.11358807103768473, 0.08097868818309038], [0.07607086080937617, 0.03323080656569331, 0.021220811702791723, 0.05042261631798841, 0.07682713514734661, 0.0043627773618115295, 0.04305655452152414, 0.13954987148604087, 0.19213125079629884, 0.028943908776366906, 0.33976321198767234, 50.41956217058244, 57.64551724157026, 24.265448893270186, 51.538673216296786, 39.88780213940529, 74.68091610939273, 14.842393859740227, 0.29838312597524735, 0.8639903450685164, 2.5603411034230263, 0.40219570059449444, 6.118630257345015, 99.55696428975752, 87.48516405782392, 94.73357077567809, 84.19432686221215, 84.11701694611581, 79.05908922995292, 80.19142258551814, 77.78677432767807, 78.38292752542804, 71.1194981298139, 66.9806052792457, 65.5833903435738, 64.41684215299546, 62.130637707248816, 62.814651996858665, 61.15248880078716, 62.62532311101114, 62.73328635000414, 60.493695351385306, 59.55713925823089, 61.8046259880066, 60.234563965951246, 61.2777889159418, 57.323012121262096, 60.72028675386983, 59.9941187520181, 50.95335360496275, 49.96315125496157, 53.981144889708496, 52.41691543209938, 53.60136139777399, 51.08741629508234, 54.38817708723007, 58.04334755866759, 58.77567760406002, 63.04964119388212, 61.53661043413224, 59.48302607382498, 59.894388568016794, 58.26516935902258, 57.60283793172529, 51.71233223330591, 52.69622741207, 55.223504650977354, 57.58964307846562, 59.39828718862226, 59.779788678692235, 55.86515734272619, 57.14147698494696, 53.17123820704799, 57.33810932405534, 57.78918973861202, 65.63200812185964, 60.047364927107296, 59.52535629272462, 60.12287447529455, 56.28576878578433, 57.57695421095818, 64.3577124226478, 65.37591265093896, 65.07549831944128, 60.80201718115038, 63.74166496338383, 64.58532364137712, 57.87061422101913, 55.9599571074209, 56.92690372467042, 57.519569935337195, 56.435885737019206, 65.00865720933484, 58.56803517187796, 62.808552711240715, 60.22604850030715, 50.52431298840431, 52.254137069948264, 49.44212713549214, 46.754424956537065, 58.25330811162149, 60.729170922310125, 62.13154377475862, 60.59327256294989, 63.11658036324286, 56.100578000468595, 46.387895153414824, 45.33397782233454, 51.00074368138468, 55.283830704227576, 59.14456082928566, 58.254465210822325, 52.75912654015326, 53.01918360494798, 65.33958758077314, 61.28466875322404, 58.3106178622092, 58.932823442643695, 55.6310938250634, 47.17487558241814, 45.16897155392555, 44.87948494572794, 45.62912048832063, 47.692330345030754, 50.24651896569037, 50.61676717573597, 52.909070907100556, 51.30429198665004, 52.076943997413885, 52.58360439731229, 53.820394392936464, 49.95332964005009, 57.497694876886186, 64.54727272833547, 68.99662510041269, 69.32917933310233, 69.32778296932098, 69.98930638836276, 74.72637637968987, 68.78080060405117, 74.47163412647863, 72.82668621309342, 74.11033676516625, 71.2188909899804, 78.3388557741719, 76.5850228648032, 78.21606205355737, 69.305111669725, 73.85728113112911, 69.48232435411023, 84.76839711589199, 73.21379277013963, 92.80181915529313, 9.859834486438382, 5.812035251048304, 5.051490616413855, 0.06182863129182689, 0.15801308075747184, 13.877277028176094, 80.75770301203575, 58.73685398409444, 42.522736672432195, 41.89050551383726, 37.86569872210103, 48.99303928498299, 4.312033134122049, 0.24089248670685678, 0.1676795322207674, 0.06907516038946568, 0.13828043315199115, 0.08695961321674048, 0.0519798202590356, 0.06925152149051428, 0.08844081357481981, 0.07892608582492798, 0.057901810148670796, 0.10468642813183608, 0.00528698870649321, 0.006975419678530026, 0.04608084748108541, 0.04800208491243182, 0.05173630006010494, 0.10233089162577545, 0.09033764727533826, 0.14495790064815553, 0.0624861952007538, 0.849769424286581, 63.12349942422683, 65.65193768470519, 29.61470869279677, 43.1498569826926, 45.79134579627745, 86.10091255557153, 14.664717355082113, 0.18706771605197461, 0.933711210325841, 5.043969471608439, 0.27590368543901755, 8.389635028377656, 104.4638885990266, 89.57337902438256, 97.8968995617282, 83.62855634381695, 89.94092864374961, 81.87715530395508, 86.75823903852894, 80.48917755003899, 80.59345768344018, 73.5107240369243, 70.97338984089514, 66.56675600236463, 66.11112563840805, 65.59807569749894, 63.36801213602867, 62.20294267900529, 67.04088426405384, 63.296495560676824, 63.81232253966793, 62.46649065325337, 63.313091108875895, 63.543271480068086, 64.14520232908188, 59.21356708772721, 65.72911816258585, 59.45984486610659, 53.61739212466825, 53.66260136327436, 56.87591683480048, 54.877724186066665, 55.999973127918864, 53.787983848202614, 57.512117432009795, 58.643933034712276, 62.64609598344373, 65.8006739616394, 63.501200137599824, 62.465078599991344, 64.03333240939726, 62.21636110736478, 61.26999516640941, 54.56673906695459, 57.65819041959701, 59.89736956934775, 62.40344639747374, 64.07013600872409, 60.87038801562402, 58.687902804343935, 59.86861859598468, 56.298610625728486, 60.75799249833631, 60.18919783253824, 67.4238331087174, 63.608378902558364, 62.30091171879923, 61.54554951575495, 58.12941220498855, 57.38815484508392, 64.7089018360261, 69.04463491132184, 68.0501179541311, 64.51076722914173, 65.11285497296241, 64.58260543884771, 59.77113593009211, 57.971834905685924, 59.07417781891362, 60.53080489558559, 57.68183838936591, 67.04004487683697, 59.56676475463375, 66.50473548519996, 59.349339931241936, 52.74301344348539, 56.706803844821074, 52.796596942409394, 48.54444173074538, 57.361847508338194, 59.62834204396894, 65.44755866450649, 64.1051313954015, 64.73714682363695, 57.84659754845404, 50.480292227960405, 49.36675879263109, 54.51020594566099, 56.94112623891523, 59.50162203081193, 59.36981470354142, 55.45140220272926, 55.77841412636542, 67.26412204004103, 63.134348700123454, 60.84953277341781, 62.3968921169158, 56.653714564538774, 49.93573388745708, 48.05372968796761, 47.46681367197345, 49.14083419307586, 49.422370156934186, 53.11993752756427, 52.769297246010076, 54.16527271270753, 53.45476281258368, 55.12320572330106, 52.28789691002139, 56.433406799070305, 52.46166575339533, 60.48072407322546, 65.16055099425778, 71.1416595212875, 72.1144151687622, 72.73942916624009, 70.56347862366708, 76.67543349727508, 72.45418656256892, 78.36388049587127, 74.08723400485131, 74.52822608332481, 71.51300599498134, 81.71686372449322, 76.39681969919513, 80.19154025662331, 70.17707024851154, 78.0989714591734, 70.27727111693352, 87.92374780101161, 75.61174946446573, 97.58647534155078, 14.586149338752994, 4.371859085175299, 5.537074160191321, 0.11949933569638, 0.17370418555313544, 13.053326299113612, 86.47606372833253, 66.55686378479004, 50.03492278437461, 33.879339002793834, 47.775174725440245, 59.75589359960249, 5.859293928069453, 0.41425735659656987, 0.18495070868201796, 0.0681045959373155, 0.08110296296616716, 0.12521265089632044, 0.014583043840473459, 0.024349026404501452, 0.08687287674195344, 0.11722644475559074, 0.053821916977364215, 0.15895864776065274, 0.14114800750488235, 0.1799385324721375, 0.09551185874208327, 0.15324222224373973, 0.08777200349516447, 0.17877335870458236, 0.17718138203265207, 0.3158525047042678, 0.17489654012024405, 0.8571825200511564, 68.57224818198912, 75.85354005136799, 33.580521075956284, 68.6560849220522, 58.94910912359915, 92.59391000193935, 19.439197932520223, 0.49587504637818186, 2.2405323674601894, 8.449852235855596, 2.311677298238201, 9.340170448826207, 105.15104862951465, 96.95273014806934, 102.46146371287685, 89.29972310220042, 93.59921347710394, 86.58956143163866, 90.219848386703, 83.83253528225808, 87.0390336744247, 77.44340219805318, 73.95980404269311, 72.52418518066406, 70.01342896492251, 68.65808533084008, 68.77667427062988, 67.56772133611864, 67.61376996194163, 69.0680593059909, 67.61748052412464, 65.6801865946862, 68.35385061079457, 64.40411013941612, 68.52050427467593, 63.250815637650035, 68.20856601961198, 64.59538844323927, 56.026092190896314, 57.75528084847235, 61.19814518959292, 55.80704742862333, 58.474353282682365, 56.73462521645331, 61.20870028772662, 61.57835229750603, 65.58661453185543, 68.15486092721262, 65.91563470901983, 65.3668833548023, 66.32207070627521, 64.65314926639681, 64.8025562686305, 57.94409198145713, 62.28131163504816, 63.36444670154203, 65.28527844336726, 67.50845432281494, 65.18204950517224, 62.14127125278596, 64.94875084969306, 59.752030064982755, 65.16525391609439, 63.32114373483966, 72.70061339101484, 66.73078167823054, 66.21365639471239, 65.61069396234328, 61.53080532627722, 59.01883709815241, 66.07020747277045, 71.97193114988266, 69.85673812127882, 66.84441274212253, 69.39537325213033, 69.17605784631544, 64.38529845206969, 63.966012770129794, 63.111724468969534, 62.98065454729142, 63.351918651211655, 71.11346552448889, 60.542740668019945, 66.80473404545938, 62.05634801618515, 53.3089957698699, 55.20852119691911, 58.91327434970487, 52.46108916498, 63.34313646439583, 63.39823007583619, 71.41554294093963, 65.31804592378678, 68.88446100296514, 61.21133612048242, 52.12838588222381, 50.81096372296734, 56.52296235484462, 61.77705957043556, 62.81732313094601, 63.01286897351665, 60.04772970753332, 59.408583410324596, 68.61603752259286, 64.63156838570872, 65.4115120826229, 65.974776206478, 61.79963673314741, 51.64305533132246, 50.409834692555094, 51.16967231996598, 51.7396633086666, 53.47893637995566, 56.94373069270965, 54.592152103301025, 57.59301239444364, 56.015784202083466, 58.04683062338061, 57.39230079035605, 60.25123011681342, 54.94862887167162, 65.69637813875752, 70.17175151455787, 75.21279734949913, 76.24205866167623, 77.13314271742298, 74.22773330442368, 81.10626835976878, 75.16300678253174, 82.76123400657409, 77.00000178429389, 77.90943468770674, 74.27132652651879, 86.02017448794457, 81.43976396129978, 85.76994296043151, 75.05614572955717, 81.97048417983517, 74.1150357646327, 93.78028577373874, 80.26752441160141, 102.21970450493598, 12.2165366718846, 10.756099012590225, 14.204496837431385, 0.32249877710015545, 0.3222156310033414, 19.492212687769246, 96.30533510638823, 71.43872414865803, 61.11722277056787, 56.10006024760585, 50.320565469803356, 71.14151831596129, 6.843244510312235, 0.5798841255807108, 0.27178504354050087, 0.16755781617135773, 0.2812773938621244, 0.17796116760901867, 0.18001324136651334, 0.1540712519518791, 0.23054243966696725, 0.2611722436643416, 0.12160735685498485], [0.06665524951512776, 0.1110202362460475, 0.05878569175218863, 0.0525534630662972, 0.12241636868566276, 0.014452597261556696, 0.10111434400201806, 0.04575255965333312, 0.11628853863165264, 0.3398379208820482, 4.498877198465409, 61.49799862215596, 50.85940107222527, 48.005888538975874, 54.86308197821341, 42.98066162293957, 85.87753357425814, 5.956339249687811, 0.07558754359882686, 0.7264424451897222, 1.1296666341443216, 1.7603574044281438, 24.928309840540734, 107.37787231322258, 82.93199046965569, 95.46254327220302, 83.66395965699228, 88.79522785063713, 78.15860717527329, 84.15910397806476, 75.2562415215277, 78.8518782584898, 69.30089119941958, 64.97677226220408, 62.138356931747936, 64.82178372721519, 61.77949928468274, 65.83442595697218, 61.869419620883086, 59.868697043388124, 59.682227565396225, 61.69129694661787, 55.441094213916415, 62.517650127410896, 57.01337237511912, 60.19388898726433, 58.71674399222098, 58.48927005644768, 52.701267657741425, 51.290226367212114, 51.0877340070663, 53.40986736359135, 53.027130326917096, 54.064334438693145, 52.628009550033084, 55.512191095659816, 57.119346972434755, 61.58799348338958, 61.78908555738388, 61.18023564738613, 65.27293866680515, 61.911745917412546, 61.166742693993356, 60.108895148000414, 53.55555988127186, 51.85497706936252, 57.12494027230048, 56.65680539223456, 57.488767562373994, 56.40369876738518, 54.92326682613742, 54.25407125103859, 54.95974094636979, 56.047755441358014, 60.160666511904815, 60.425842269774414, 59.032730133302756, 61.532095786063906, 53.416335352005504, 56.28447440362746, 58.44610437270134, 60.12737735625237, 62.59485413951259, 66.5417391254056, 66.85188093493062, 57.56660699844361, 54.57520354178644, 63.96666780594857, 59.52140646596109, 56.76654154254545, 58.44116610865439, 55.02039647871449, 60.296000049960234, 63.39344478422596, 63.215533917950054, 58.20086210004745, 55.85113879173033, 50.17759115465226, 48.2836982511705, 50.8130229673078, 48.433724987891416, 48.87154779126568, 53.57254766648816, 62.172124616561405, 57.928653532458895, 56.58278242234261, 50.732449639228086, 45.721888465266076, 46.77587639900946, 49.76072165273851, 52.21902401216569, 56.14879961936705, 56.55493751648934, 51.775827561655355, 50.087125608997965, 63.084675804261245, 59.53877864345428, 58.093063600601695, 57.394383568917554, 49.340733866537775, 45.70487322345857, 44.431358075911, 46.06722962471747, 48.36777817818427, 49.33967482659125, 50.72529523603378, 50.36241715954196, 50.197661922824004, 53.51077818101453, 51.32348414390318, 52.451957887218846, 53.134273790544086, 64.82035206210229, 67.29624625175231, 69.60888355009018, 70.83378484172206, 71.99064085560461, 71.1241029923962, 73.12187594752159, 72.16377427501064, 74.24167340801608, 70.9312871194655, 73.55983995622205, 76.27998013650218, 76.62430932444911, 73.26326954749324, 72.92467486473822, 70.18935511189123, 75.79932505084624, 66.62472863351145, 81.51676793252268, 74.6146123639999, 93.97614540592318, 41.31499182793402, 0.1941499077985364, 3.15808188050024, 1.1820113995382864, 0.1383023126231086, 2.636680723197999, 67.46551221416843, 69.80207597055744, 52.82796805904758, 56.34586734156455, 44.15569782257081, 54.54003949319163, 5.524718694148525, 0.1899051831494416, 0.0685422543075777, 0.03623992332347459, 0.07878170889471808, 0.02307742387206564, 0.05419131691357302, 0.040701470007338834, 0.05589788884765679, 0.02422455626900398, 0.004071648628826464, 0.06538592609426667, 0.061254310496752305, 0.084436763108017, 0.05533912346788472, 0.13415210790211154, 0.09603583223877415, 0.23542022873317045, 0.13793789991928687, 0.16099029761408606, 0.523939666248137, 7.469078283156119, 70.11809349060059, 64.91449679097822, 48.64681559224283, 39.98521420263475, 55.23788406002907, 92.70485816463348, 6.29187056133824, 0.015355231739851016, 1.759800305289607, 1.9544219393883984, 0.999730951603382, 30.00753994910948, 111.43979257152928, 84.66399931138562, 99.66800658933579, 83.69207520638743, 91.72023342501734, 80.0370773192375, 86.2800472013412, 76.54345358571699, 82.94651892877395, 69.55658266621252, 68.82445658406904, 65.42178869247437, 70.3506665075979, 65.06323699028262, 69.81809493034118, 63.86002640570364, 64.32476059083017, 61.94030077226701, 65.27006749183901, 59.945053823532604, 63.71349057843609, 60.47165555338706, 63.05730550519882, 60.973452214271795, 61.61338298551498, 55.19057243101059, 54.69611844708843, 54.59601563792075, 55.761948016382036, 55.29245991860667, 56.224085592454486, 55.05805123236872, 57.10121385512814, 62.43183259041079, 64.06612734640798, 65.31036200061922, 65.94538980914702, 67.2446749287267, 65.08531993435275, 65.27718659370177, 64.05499173748878, 57.95117970435851, 56.63698957812402, 57.64563099030526, 60.987372706013346, 59.8398401660304, 59.31068497319376, 57.83918034645819, 57.562641482199396, 57.213993764692745, 59.42493184920281, 62.94581605542091, 64.05634103282806, 62.95590831387428, 66.05592220060288, 56.56721845749886, 58.16368979792441, 61.359076115392874, 65.34347072724374, 66.69461742524179, 71.02081129627844, 71.25826374177011, 59.953055458684126, 58.325809201886585, 68.78913171829717, 64.14207620005455, 63.56627225875855, 61.94158730968353, 58.37630971785515, 62.654591837236964, 65.42143960152903, 63.492959237867794, 60.96587027272871, 57.45721209433771, 53.32464210448727, 52.283766654229936, 55.92362027014456, 49.9772443309907, 53.865517339398785, 56.92192623692175, 65.65229462039086, 59.91255698665496, 57.19761002448298, 53.56679354944537, 48.68523128571049, 49.84877101836666, 52.867956622954345, 54.627990799565474, 58.118100089411584, 58.80271842402797, 56.09482388342581, 52.56449853220294, 64.14880306490006, 64.08972432536464, 60.893851633994814, 60.85109779911657, 51.664165527589866, 48.902091287797504, 48.83428527462868, 46.92036867141724, 50.9459364029669, 51.84597130744688, 52.48909881038051, 53.46392546930621, 51.353976649622766, 55.28702743591801, 54.796946894737985, 55.52910043347267, 55.97264597492834, 66.08333956810736, 70.27604733743976, 71.1367565585721, 72.14755135197794, 73.09836526070872, 74.36222353289205, 76.70829511457875, 74.0643979657081, 76.90693178484517, 70.60130596160889, 73.8206148147583, 77.52505810030046, 79.37875455425632, 75.83453224551293, 76.44479028640255, 73.57436057059996, 76.84217345330023, 69.35932667024674, 81.2400447168658, 78.11179760963687, 92.77030683332875, 48.62967875695998, 0.03067130872589206, 2.128371947234677, 1.5786805724905384, 0.1984252299993269, 1.5556882514107613, 68.36456652610534, 78.78806914052656, 59.29093191700598, 54.17613767808484, 55.22490493712887, 64.86742834891042, 8.700912364067571, 0.34018186371653314, 0.13256688812567344, 0.132674339617933, 0.05008095259507818, 0.052712184992889245, 0.07894236519331894, 0.04881966543654281, 0.04998421101200004, 0.08306590239367179, 0.04570626879050847, 0.13579867599952605, 0.2909578034474004, 0.1795187009678733, 0.20953629346143818, 0.3062914516175947, 0.23666858432754395, 0.2669485772569334, 0.26650844442267574, 0.19803510738476632, 0.7664340734481813, 7.941480211673245, 84.16056309976886, 66.03354900113999, 59.84575510025025, 75.41007687968593, 61.99008741686421, 101.35653988007577, 8.96007905083318, 0.2616064316563068, 2.092069430697349, 9.48216122965659, 3.282782118166647, 29.99562574971107, 117.66977156362226, 89.94489808236399, 103.93433724680256, 89.83985700914937, 95.78648397999426, 83.54020103331536, 91.56809253077354, 79.99484908196234, 87.0564333085091, 74.88654244330623, 74.26044587166079, 68.84179346023068, 74.04827702429988, 69.46898829552435, 76.66929891032558, 68.8821703387845, 67.90694359810122, 64.26372458857875, 66.96092282572101, 61.4491690358808, 68.70043908396076, 63.94662449436804, 68.03314193602532, 66.81470471043741, 64.781034223495, 59.12156397296537, 57.421247882227746, 58.88847712547549, 59.64904431373843, 57.53525157128611, 60.2104845354634, 58.2171634704836, 60.48669392062772, 65.24912595748901, 67.9205620673395, 68.07315795652329, 67.66616498270344, 67.01299621212867, 68.2431770140125, 67.86542923219743, 68.89580449750348, 61.893722626470755, 60.342762547154585, 61.73944796285322, 63.77593471157936, 63.689658257269095, 62.958202900425086, 62.431377595470806, 61.86030403260262, 61.04394897337883, 63.570598633058616, 66.15445213933145, 66.44207954406738, 66.71991671285322, 69.38576344520816, 60.42009991984214, 58.09168684867121, 62.10232996171521, 65.5486499109576, 69.17010368839388, 72.44077990131994, 72.55704679796773, 63.172015220888206, 61.34670888223956, 71.48258409192486, 66.9517837032195, 64.34918911226335, 63.38734942097818, 61.64114944396481, 65.84538505923364, 66.8827578329271, 66.04933261871338, 62.62682145641696, 57.25126412607009, 59.18786379598803, 55.98983380102343, 59.33352493470716, 56.496462821960456, 56.94299720948743, 59.4650576960656, 67.30607571140413, 63.44037594333772, 61.52636520324215, 57.833277179348855, 51.679396090968964, 51.44114348196214, 55.118420431690836, 57.73051500320435, 64.08584117889404, 61.062070323574936, 58.04458310527187, 58.785601200595984, 67.40255032816242, 65.62667762079548, 63.535799364889826, 62.64569197931598, 54.24936832920198, 51.48448959473641, 51.36429248317596, 52.13903511724165, 56.556102460430516, 54.99083357472574, 55.95924715841971, 56.26975767074093, 54.77365978302495, 58.73004867184547, 57.966504404621745, 58.40168353049987, 58.72711866132675, 69.03309529827487, 73.57469004969444, 76.22860493198519, 74.81434729791458, 78.21683083811115, 78.32592764208394, 79.1715435827932, 76.96873264928018, 80.33355359108218, 72.86723567593482, 79.10114488294049, 81.53261430801885, 83.37575174147084, 79.62106289402132, 79.71705898161858, 76.83665860083796, 82.9042906914988, 72.25050572426089, 87.04504274552869, 80.33256515379875, 100.23161980413623, 48.6957432377723, 0.19539097023587074, 12.189993012335993, 4.736673831939697, 0.3875830637351159, 3.8953903942338886, 81.9938144376201, 83.2782494637274, 69.80722212022351, 77.00795635100334, 57.50786950511318, 75.51325874943888, 11.21492708882978, 0.5070154050425176, 0.36076342867266753, 0.278970611191565, 0.18467188332109682, 0.20457601204754847, 0.22998776136627122, 0.1469245862456099, 0.218937341424246, 0.28016580028399346, 0.14327615379325806], [0.028521545351512974, 0.011194573749127168, 0.052691638514760046, 0.03987322553932186, 0.06512829072533116, 0.09064548438595188, 0.054921256979146314, 0.05515232058842817, 0.13484419173290654, 0.16907689191641348, 8.889459717658259, 70.48676490783691, 29.56104086291406, 32.496464252471924, 38.955235096716116, 52.006878699025805, 73.70710926671183, 1.0698856677739852, 0.1855660764680755, 0.7874173442682912, 3.20871967942484, 0.10471913242532362, 58.606427331124586, 96.28324431757774, 90.05017449778896, 96.37254099692069, 84.5454574400379, 83.90292613737046, 79.17613275589483, 77.02468918215844, 75.37796835745536, 74.10799118780321, 67.83419932088545, 65.53168958233249, 64.4031766153151, 62.47279782449046, 59.24462441475161, 65.23587619104694, 61.952660160679976, 59.97331842299431, 60.29647465675109, 58.781035561715406, 58.847339307108236, 60.258757145174094, 58.13942601603847, 57.664403453949966, 58.06944700979418, 59.542222484465576, 53.29078420515984, 50.27509735476587, 50.30331880815568, 54.03798003350535, 54.41222121638637, 53.72628104302191, 52.90139482867334, 55.74181449028754, 59.15106804140153, 61.68479757924234, 60.329854026917495, 65.4938308654293, 65.97571757531935, 62.51626945311024, 61.3224333332431, 59.33740415880757, 54.572171549643244, 53.480673989942, 56.552376208766816, 57.89143808426396, 55.991485118865974, 54.274561712818766, 54.79472291085028, 54.2505411178835, 55.902345334329915, 57.615695461150146, 60.01650371859151, 63.60040080162787, 57.3526377831736, 59.78417781091506, 54.428102893214074, 60.76889276504517, 59.06103787883636, 65.14621473127796, 65.88649934337985, 65.67999832091793, 61.13635216989825, 58.61035754603725, 66.66784332644555, 64.45949792861938, 60.61197834630167, 61.84069218174104, 63.89555523472448, 65.01304241918749, 58.38458199654856, 64.14980719166418, 61.726814008528194, 60.027862902610536, 56.96938691600677, 50.849383338805175, 50.27162605716337, 52.21425048766598, 49.24419256948656, 52.87037672535066, 59.84382529412547, 58.41756520732757, 56.101644885155466, 53.851184998789144, 48.60661522034676, 47.380297953082675, 47.90227520850397, 47.84963307842132, 50.023088993564734, 53.599521806163175, 52.2431936571675, 58.245671256895996, 52.417244911193855, 51.95252249317785, 61.34207264069588, 59.731096375373106, 60.04240705120949, 52.08793447863672, 45.95639521075834, 47.29434313312654, 44.773522115522816, 45.034563695230794, 48.404632768323346, 50.7335243686553, 49.291362993178836, 49.87278376856158, 50.28458949058287, 54.233878889391505, 50.278211716682684, 56.54899120330811, 66.85429711495676, 67.59559369856312, 68.40558667336741, 69.44967454479587, 71.04807176897603, 70.57679899277227, 71.55827014676987, 71.63134390308012, 72.5477586253997, 72.42180347442627, 73.62534353809973, 74.0054839657199, 75.86456975629254, 71.38102608342325, 71.54350634544127, 71.3361463239116, 70.99839102837348, 68.41109368108934, 73.85226049730855, 80.0607527455976, 80.249191253416, 75.82483614644697, 1.8991619949379277, 1.8325391892463931, 0.9475156244251036, 0.19311228767037394, 0.2699224999354732, 32.72129843311925, 83.06921851250434, 53.22970113446636, 42.55306051623437, 27.16824600773473, 56.184708918294604, 11.480970671100001, 0.3497308126140026, 0.11688051009250265, 0.0806405216515545, 0.08111618564374025, 0.019529473427082264, 0.028250549409177997, 0.048999937416444865, 0.03816339390112027, 0.12892427794154615, 0.05139608807381123, 0.05642279314117567, 0.010218889914422987, 0.05751219315214023, 0.056114565325720664, 0.1789606978455859, 0.1175387098544067, 0.05820426932205597, 0.08157039151316689, 0.22503255145444026, 0.41518006353609027, 12.867082357406618, 81.17969512939453, 36.35486448964765, 37.96666053033645, 37.45029618663173, 64.76361889992991, 75.29239008503576, 0.7876073953605468, 0.13094820562870274, 2.7177972995465804, 2.3880546708260817, 0.8216697482332107, 66.107619039474, 96.68356926210465, 93.32924458288377, 97.31838918501332, 87.36035423894083, 88.99181704367362, 82.37870877788913, 82.10559414279076, 80.6193845502792, 77.8152193561677, 70.51987755683162, 70.01600203975555, 67.46859519712388, 66.10742292096539, 61.7809505616465, 67.06474796418222, 62.553575115819136, 62.241209322406405, 63.19611034085674, 62.08993134960052, 60.889870428269916, 61.24799851448306, 61.96502739383329, 60.96921213211552, 59.75443840026856, 63.17236038946337, 54.49823094952492, 56.409480341019176, 53.235094393453295, 56.3994312286377, 55.86394925271311, 58.233821776605424, 55.35076595121815, 56.946429283388206, 59.99009047785113, 65.70557217444143, 61.74705736098751, 69.22394998611944, 69.57519823505034, 65.31116608650454, 64.82792615890503, 61.73656502077657, 57.593326184057425, 57.11503628761538, 60.75722371378253, 61.40834892949751, 59.94736802193427, 57.02698299961706, 57.97472569250292, 61.51978346609301, 59.443390523233724, 62.438457473631836, 63.10277754260648, 65.06528838988274, 60.96178708537933, 61.70598230054302, 56.18101012322211, 61.93999874976374, 60.43331830732284, 67.40417418941375, 68.44691276550293, 66.76954254027336, 63.645335474321925, 62.42411336591167, 70.88347342706496, 67.43228973880892, 60.86556350031207, 63.257840602628654, 65.54770854211623, 66.10965082722326, 61.428125519906324, 64.7868001076483, 63.223127626603656, 59.85657691955567, 60.532169880405554, 53.93957953299246, 54.06671923975791, 53.96759310076314, 55.86366684206071, 60.406375546609205, 62.00711442578224, 61.424414957723315, 59.3716739070031, 55.00580918404364, 49.74267482757569, 50.35632179629419, 48.84218885052589, 48.53444360917615, 50.92015466382427, 56.47801199266988, 57.467014097398334, 58.78749178301904, 56.276107988049915, 53.17428588867188, 63.6864419137278, 61.78007587309807, 61.76510026378017, 56.45314808814757, 48.10056671019524, 50.28044746768091, 47.809401327563876, 47.96011447906495, 49.37874947824786, 50.688115089170395, 53.39120472631147, 54.50782898933657, 52.4874278806871, 56.080271890086514, 51.616406748371745, 60.61721863285188, 70.18837451934814, 71.51091144930932, 72.38385846537929, 72.48549492128434, 72.63707099422332, 73.52653118871874, 73.6752203972109, 72.88476082586473, 73.74014346830307, 74.98830441505679, 77.10639999758813, 75.48043635583694, 76.89780835182437, 75.07730299426665, 71.43437816250709, 74.61502813523816, 71.82751732487833, 72.21122710935532, 73.80729444565313, 84.83523430362825, 80.20828093251875, 84.2980892427506, 3.5163200382263433, 0.8580545732571233, 0.8444708537670874, 0.17352956347167495, 0.36577453235945395, 28.79522946573073, 92.04448007768201, 59.30250290901431, 44.1844605630444, 31.33574470396965, 70.80305699379214, 18.473357423659294, 0.35970714664266956, 0.10094722958221551, 0.07050735410302877, 0.03997981518266663, 0.05336642791066439, 0.04240328836585245, 0.06552682498530035, 0.012221417893024703, 0.0780363972749441, 0.06556499148568799, 0.18248623447312465, 0.1477460163615404, 0.1198848617833949, 0.12160049270718329, 0.40530549662728466, 0.2734074339030251, 0.19147823744964218, 0.18834061710344208, 0.3551552054141799, 0.446201844080802, 13.918761976303594, 93.69041642835064, 40.2052003337491, 42.23610554972003, 57.16177132821853, 68.39756150399485, 87.98344627503427, 2.236923786901659, 0.4241373780513964, 2.582754507180183, 11.945250841879076, 0.7438689229949829, 66.21953994997087, 100.39341757374426, 98.43311109850484, 103.36555434811501, 91.83199744070731, 91.3206615755635, 85.98124104161417, 85.95258420513522, 86.15566884317707, 82.8301186715403, 74.38952322929137, 73.31867694854736, 71.55925073931294, 69.96552898037818, 66.01636901978524, 71.37955127223846, 66.70669048063218, 66.8244400332051, 67.4808879052439, 64.74230474041354, 66.15860200697377, 65.49043801523024, 65.17131005564045, 62.16359738380679, 63.18745366988644, 67.1903657913208, 60.3360866731213, 58.8352584069775, 55.80320742822463, 59.57109897367416, 60.99909274808822, 61.75054042570053, 59.04097495540496, 61.65248117139263, 66.4408322303526, 68.99011396592664, 66.98794795620826, 68.1904838931176, 67.73702652223649, 69.66197675274265, 67.99401237118629, 65.84889165816769, 60.346437808006044, 60.95594667619275, 64.06776297476985, 65.47957304985293, 62.644530957744976, 60.317357355548495, 60.60531031700873, 63.34203035600724, 62.85080056036673, 64.99121835154872, 64.61955024350074, 69.19939594884073, 64.77043990165957, 68.62887151779668, 56.71704515334099, 64.81482936489967, 60.953377523729884, 68.93549103890696, 72.99921558749291, 70.39016477523312, 66.0398797065981, 63.63540403304562, 73.71781733728224, 70.25827900055917, 64.15730676343365, 66.63746064709079, 71.25420016627159, 69.26193421886813, 62.92489805529195, 69.63655979402604, 66.10413597476098, 63.44256854826405, 60.90887038938461, 54.92014854185043, 57.166034944595836, 58.820310254250806, 60.25250096474925, 59.53598199352142, 64.33076573956397, 63.81408760624548, 63.110810556719386, 59.653186336640395, 53.17758852435697, 52.43604483142976, 52.919178855034616, 53.464811924965154, 54.35818272252237, 59.346225569325114, 59.943857500630045, 62.242531161154474, 58.39184230373752, 58.949426835583104, 66.97134848563903, 64.77333853321691, 66.2585283094837, 58.286962047699966, 52.32950933517949, 54.41057774328417, 49.16566279626662, 52.42909439148442, 53.00488656566989, 54.408777375375074, 55.126782924898215, 57.75419042956445, 54.16637489872595, 60.622451074661754, 55.39312362670899, 63.94759724217077, 74.08946975584954, 74.65968824202015, 74.86631870269775, 74.51650604124993, 74.62732868809854, 76.46161725444179, 78.41169418827181, 76.61380521712765, 77.50725838445848, 76.53604030609131, 81.36561547556232, 80.43478212048932, 82.03302244986259, 77.11574308333859, 76.77065295557823, 78.15422196542063, 78.26110655261625, 76.14851797780683, 78.71157507742606, 88.99560605326008, 88.14430267580094, 83.98549987423806, 2.9520311951637273, 4.953405866699835, 2.4595683044002903, 0.2585163700484461, 0.41358139125570176, 42.873490702721384, 98.23245832996984, 67.65199738164102, 61.173289129810954, 36.23156870565107, 81.23425529849145, 21.20660616505531, 0.8257070315941688, 0.28133956955805905, 0.30456818279720127, 0.13923240465021905, 0.12114716783886957, 0.18134972771569607, 0.11438389083430653, 0.0984580566986434, 0.23057878287809513, 0.18956952938629737], [0.0813688337802887, 0.04200924338111955, 0.0961362280612511, 0.042664604787264145, 0.03213861799468437, 0.1413629411329185, 0.1255960932241813, 0.029499397215042866, 0.15161538857125467, 0.34382880995831183, 18.85122483776462, 74.43434807562059, 33.66735058446085, 35.36981221168272, 30.626497807041293, 78.88757967179822, 40.07030610115298, 0.2939396321533188, 0.07227239003705402, 1.657838292660252, 1.4933616667985918, 6.583208037960914, 88.1451577524985, 86.39572574246316, 91.53421109722507, 92.44026291754939, 89.68772395964592, 82.81823388991818, 79.76505310304704, 79.15153165017405, 74.06140911963679, 70.05448833588632, 68.53879036441927, 64.6853558478817, 64.29768839190083, 59.61586890682098, 61.096194944074085, 59.80562925338746, 61.10855041011688, 59.17936401982462, 60.1826004059084, 62.36887854914512, 60.40308860040481, 58.12850613747874, 58.48118997389271, 57.90739820849512, 58.227134135461625, 53.726720348481216, 49.12880820612754, 49.76172185713246, 50.89714211802329, 55.1639630717616, 55.79257388268748, 54.06076508183634, 52.07683417104906, 54.33426410921159, 58.68592592977709, 59.79867096870177, 63.125895992402114, 61.74983832143969, 61.109142688012895, 64.87872869737687, 60.91831545675955, 61.30481012405888, 51.8666265087743, 54.34035947245937, 55.930782518079205, 57.864918939528934, 58.347401849685184, 56.76995792696553, 54.180467974755075, 57.06809728376327, 56.80012487596082, 59.04495223875969, 60.19415178606587, 63.17407446522867, 58.96848563225039, 55.58891657860049, 55.62041713345436, 58.72595763975575, 59.196343960300574, 65.45610550911196, 63.345466352278194, 64.33908900906964, 58.00441411233718, 63.46041533254809, 64.86863251655333, 64.19951538885793, 54.377649445687574, 55.43655603162704, 58.56758802167831, 61.58810330975441, 64.439093758983, 58.32405982478973, 65.42622881550943, 54.83924181230607, 61.47704139832528, 51.325664981718994, 51.23052789318947, 47.52531582309354, 50.3218755414409, 59.76995137430007, 58.52027247028967, 57.61577783092376, 53.74600664261849, 50.462123809322236, 48.92994403839112, 47.80543581131966, 48.30256092932917, 46.94230256542083, 46.575215785734116, 48.98996022439773, 52.136917037348596, 52.596293264819735, 55.252349761224565, 53.43661400579637, 54.554218861364554, 61.72484890107186, 58.286534509351185, 53.716294688563195, 48.79080187889838, 46.55240328081193, 43.77149774182228, 44.697043741903, 45.249674320220954, 48.340305897497366, 47.89215157108922, 50.963861634654386, 52.07563000340616, 53.13533675286078, 51.68263204636113, 59.35561572351764, 70.21952598325669, 66.15404421283354, 66.89050843638759, 71.28662247811594, 70.57903474377048, 71.89725706654211, 70.28597877871606, 74.26280713850453, 70.69859643136301, 73.11771039039859, 74.35645764873874, 71.83031005244102, 70.15629737607895, 72.8420619041689, 68.45795815990817, 72.44362754206504, 66.7042350769043, 69.90864676813926, 68.79705490604525, 84.6572999031313, 72.75060792123118, 97.72734334391933, 12.329781382314621, 0.37703721994353884, 0.6799853412855057, 0.060424208265518954, 0.23398879344665238, 7.372489917662836, 88.40715639052853, 54.603009223937995, 49.965128129528416, 38.88298503814205, 62.656015657609515, 17.81916883683974, 0.37175194871041084, 0.03114695739631932, 0.10846727122102054, 0.038274560919812614, 0.06672013716231431, 0.12952818505225644, 0.08370325690315616, 0.05315684540677936, 0.07803290391400938, 0.04311574247455405, 0.047497474288027135, 0.05828409185332637, 0.06193135985203328, 0.038658677405046846, 0.056178303841020794, 0.07906165274400866, 0.0645018223252508, 0.06436820893037705, 0.19346203745132495, 0.41547488481287037, 24.16390069069401, 83.01698038654943, 43.25170916895713, 31.104371932245073, 31.859245800202896, 93.41745084331882, 39.99662437746602, 0.4312584410992361, 0.053215531572218866, 2.045644870208156, 0.35526212064489243, 8.545697312201224, 94.68744370245165, 86.5303885552191, 96.88029181572699, 93.19824526386877, 93.07585946975216, 83.46539358938895, 84.33277083981423, 79.96308572830694, 78.6109584377658, 72.9787721941548, 69.91057657426404, 67.47553779232886, 65.26316019796556, 62.61017099503548, 66.27879127379387, 61.33316493803456, 64.11901266344132, 62.661381460005245, 64.53642737480902, 64.86035239311957, 62.444984297598566, 60.2282371828633, 61.93678240622244, 61.196360511164514, 63.61845939390121, 58.58861977054227, 52.22357788393575, 53.43023230952602, 52.41939044767811, 58.67647694003198, 59.756054416779556, 56.33238223291213, 54.640487470934474, 55.72054347684307, 61.998622494359175, 62.78066073694537, 66.05432971831291, 64.8725901880572, 63.71605188615861, 63.85122852940714, 64.30475650295135, 65.24945151421332, 55.077863124109086, 57.08524980852681, 59.57161280416674, 58.328523482045824, 59.72502454634636, 58.75021749927152, 57.65935144116802, 61.236341230330936, 58.67870876866003, 59.12215232849122, 64.0425774358934, 65.961118513538, 62.49989748001099, 59.33259141060614, 59.31586642419139, 60.20044326782227, 59.840561882142104, 67.47871491216844, 64.40502012929609, 64.85865792920514, 60.7686338886138, 66.67181276505994, 65.57718515396118, 68.34211487923899, 58.57835492780132, 56.96581755914996, 60.06512541924754, 62.662060030045055, 67.91213681620937, 59.41952682310536, 67.07374588135751, 57.18197153460596, 63.00110578536988, 54.825344854785556, 52.31747550349082, 51.292379748436716, 56.552125177075794, 60.17397511389948, 61.65805485940749, 59.29944738265007, 55.73278519415087, 53.31449493285149, 52.05557492471511, 51.649907712013494, 50.03225949502761, 49.92270769611482, 49.792033933824115, 52.97368803331929, 53.7679523037326, 56.9732935966984, 57.54675196063135, 58.54204554711619, 58.4482067631137, 63.89442166974468, 58.218504921082534, 56.6997867245828, 48.67100877146567, 48.49961296204598, 45.69328654196955, 47.17793895352272, 47.50264452349755, 49.51813482469129, 51.118108841680716, 55.04594287564678, 53.741448848478264, 55.39288043975831, 54.42931098322715, 61.44285401990337, 71.20830059051514, 71.13791758014311, 70.49604523566462, 73.56224829150786, 71.80608549425679, 74.27989298297514, 72.34808644940777, 76.41156781104304, 73.56457033464986, 75.32321206984982, 74.0567885675738, 75.27626914362754, 72.06615432616204, 74.60161362924885, 68.79985547834828, 75.56614014410204, 68.70200018728934, 73.41363753041914, 69.62010937352335, 87.5063919251965, 72.9381521286503, 99.16078136813258, 16.56653834927467, 0.5311174198023735, 0.3233017291753523, 0.08977876315193792, 0.22587154030559525, 6.804563566561669, 92.25380128429782, 64.7541424535936, 51.55266038833126, 38.645850304634344, 76.27173531439998, 26.616884316167525, 0.1540657820840997, 0.05151090550146276, 0.04270375188019487, 0.05815355813190822, 0.05098717715290766, 0.009564009228450878, 0.032158160897632765, 0.1040189893495652, 0.07856432378532426, 0.11616354372592703, 0.19779902973002006, 0.1621058748494233, 0.18802546385315158, 0.14497542873986308, 0.149339234095908, 0.23160771556919624, 0.2606651547455019, 0.14685730840409958, 0.23932067346909355, 0.7282000347491234, 27.370920758093558, 93.59452232237786, 44.99893680695565, 47.45269313935311, 45.79356193542481, 98.49610436347224, 50.040418024986025, 0.9223574195658008, 0.21052258569867383, 4.4752233451412575, 6.3403888094809755, 9.580102812859321, 94.94104846831291, 91.2657876168528, 101.39986638099917, 99.28025676358132, 95.4068220815351, 88.27909100440242, 86.37565105192124, 85.0723494252851, 83.40934291962655, 77.43056820284936, 75.42768832175963, 71.98605952724334, 69.93203978384696, 67.03103127018099, 68.8564395904541, 66.65305599089592, 68.87963648765319, 65.95173620408582, 68.28717031786519, 68.69863479368149, 66.29061329749324, 62.673168182373054, 65.58038188565162, 63.817966830345895, 65.30848710767685, 61.27435291967085, 56.47046535245834, 55.505060226686545, 54.97228860855103, 62.99195881812804, 60.660372549487704, 60.42144137044107, 55.84800874033282, 58.53351831436158, 64.98844131346672, 67.1766374957177, 69.4844267445226, 64.25259682439989, 63.68096236259707, 68.26587184782952, 66.13634647861605, 68.36395463635846, 57.746537885358265, 61.64691925048829, 64.1423939120385, 63.3120987492223, 62.29625194303451, 61.8137219644362, 61.190704453376036, 61.930377175731046, 64.24907845835533, 64.51998479904668, 66.53218423166584, 67.9728158827751, 64.08200510086553, 62.28646955182476, 59.173986450318374, 62.45606499333536, 61.12811519253639, 71.04616549707228, 64.64431608876875, 69.34884609714632, 62.437551406122026, 68.31195969735423, 67.67861458563036, 68.35590593276486, 61.31429441513554, 58.64332114496539, 62.88789833745649, 65.42744475026285, 70.25725133957403, 62.12704481617097, 69.41739343827771, 58.28269843132266, 64.89831701401742, 56.521887625417406, 55.61396875689107, 56.84376124412783, 58.05816235080842, 64.15645168673608, 65.09453358188753, 63.25576174643732, 59.3324698171308, 58.33951004089848, 55.603598010155466, 53.85264804286342, 53.59890207167595, 52.2695323728746, 51.954801390247965, 56.908209708429155, 56.742046340819336, 60.03775119781495, 62.36767045913204, 60.71083384175455, 61.514660850647964, 67.11347164646273, 61.250532365614376, 57.16086133833855, 54.23580869551628, 51.526035339601584, 50.0850663646575, 50.24336538007183, 50.87198795810823, 53.47239778887842, 53.55094325157904, 57.08268850080429, 58.18558839059646, 58.092263437086544, 58.06089624281853, 66.87152416475358, 75.05915026510917, 72.1970045951105, 74.26402307325795, 76.9079908247917, 76.98399066925049, 79.36974094760033, 74.88781329124205, 79.61782301625898, 75.35864676198652, 79.6889591217041, 78.3628999033282, 78.21114340136128, 74.17023920243787, 78.60420411632907, 74.91628969869306, 79.02538822543237, 73.19585969371181, 78.16915835103681, 74.08423731403967, 90.74945465210946, 78.39239612702401, 102.87390878123622, 15.750746150170604, 1.32147838031092, 3.911803552219945, 0.12808715068404714, 0.33325737883006373, 9.659031687244292, 104.63103648154967, 67.60856105435279, 70.03733973349296, 48.34875076047836, 84.21467611866613, 40.24751878553822, 0.46427575811263055, 0.28850570921936347, 0.17930372137456171, 0.2751745842397213, 0.15552790685286447, 0.20791782546908627, 0.19987191043553815, 0.3221123317076314, 0.22782891027389035, 0.24612940247020415], [0.0283218702797087, 0.07162567393313493, 0.027273277857250748, 0.050377600991557685, 0.042962195471890514, 0.037465541428255464, 0.023918540532430334, 0.008730861797718512, 0.06930769105712253, 0.2043595156001468, 24.065294265747074, 70.25221501627277, 28.585735674827333, 56.25882994744086, 42.11014647637644, 79.44574863679948, 24.953112948325373, 0.3933413176526947, 0.03367818659171462, 4.332741287446791, 1.2911720646004523, 30.481795687829297, 109.05876482686689, 85.16804741274926, 96.8993466900241, 86.49338491501348, 92.91217896246141, 82.27120445620629, 79.90236743803948, 73.42184312881963, 71.69327812810099, 65.97636084402761, 67.64858491959112, 67.69716739654541, 65.33330394375709, 62.752180407124186, 58.67745753257506, 56.61782879983225, 61.65132799456197, 58.71215089674919, 57.75355108322636, 56.296453322133715, 58.840224127615656, 56.65732314509731, 59.06709401838241, 57.14994930451917, 60.373694358333466, 49.70497300547939, 50.29628992080689, 50.011090463207616, 52.71951844615322, 53.932072116482644, 53.982058801958644, 50.66793449463383, 54.396951429305545, 54.02005480181787, 60.71329709022277, 59.39274095719861, 65.1253398772209, 57.05007399282148, 60.50676861116963, 66.29929742505475, 60.43091389440722, 59.986842755348455, 52.34743456686697, 54.3664393117351, 54.465824327161236, 55.046896011598655, 57.80573429599885, 56.40293390520158, 58.60394447080551, 59.48093937289331, 57.55119208366641, 58.984226103751894, 61.55396692214474, 62.683060399947635, 58.60411705509309, 55.04872383609895, 55.732192916254846, 60.45184366164669, 60.88428889551471, 62.08033723215904, 63.56246363732123, 61.823747542596635, 63.97314756147323, 63.91178208012735, 65.00539379735147, 62.33750743250694, 65.91360292127057, 64.59645925029632, 62.22075808432795, 60.99766892771567, 60.34109553983135, 60.75107735972251, 61.58267867180609, 62.779193770500925, 56.176130694727746, 52.876232824017926, 46.57490984086068, 48.812433750398704, 60.293415208016675, 61.19001803859588, 57.19733153620074, 52.47334657176849, 50.29021416940997, 51.694885530779445, 52.39224372371551, 53.876280323151626, 50.209927174352835, 49.92744984165315, 47.98351926188315, 45.37289950155443, 50.13177394866944, 52.666609594898844, 55.2360091670867, 56.662484984244074, 56.040263714328894, 56.302262352358916, 58.964343609348425, 55.397842238026286, 49.14869854527135, 46.861948890070764, 47.58650479778167, 45.10723736978347, 46.22638371682937, 44.4973401869497, 48.1797162179024, 50.85907159313079, 48.529481810908166, 51.54444694519044, 50.39989540653844, 55.06475456299321, 64.91115885396158, 67.3409769611974, 67.46845399179767, 71.29245896493235, 67.67833217497795, 68.49376155484107, 70.80317466489731, 70.40066103781425, 70.58803266094577, 74.03504294733848, 70.19473660376765, 70.73995390245992, 67.95884440022131, 69.1114564095774, 66.51779697787377, 68.09179705958213, 65.53622776462187, 68.40052681584513, 69.14371398187453, 81.42780857701456, 71.88634503272273, 94.13615457473263, 40.33141828352406, 0.596179367313462, 0.6163633939239287, 0.03906763812166549, 0.03947761007434419, 2.0711938411958757, 74.97403483236991, 61.90365799011723, 56.18895684519122, 32.12322327398485, 36.66315886282152, 30.749124826923495, 0.2786858716318684, 0.06087695856788947, 0.1682279592440013, 0.06232586448952075, 0.07514334283769131, 0.047300624165443644, 0.03942138688158124, 0.009226128064666786, 0.0206992992635576, 0.046575843702040376, 0.04023248630185281, 0.07835961743107728, 0.045183612965047366, 0.043586959326339346, 0.09531126627998968, 0.03170774333299168, 0.07573253339937619, 0.094903944991529, 0.0651492738735772, 0.12111781134961114, 31.251811865837347, 74.4910498588316, 38.306867307232274, 54.36159518457229, 43.665291724666474, 90.94329034128498, 26.379514240449478, 0.41901387394435946, 0.1116005938139654, 1.6320352256298067, 0.36537282649547825, 35.86989087443198, 111.75232702685942, 88.21553291813021, 98.24117383649273, 88.91833536086544, 94.94464920413111, 83.43903526183098, 82.81446056981241, 77.54652915462371, 75.40525236437398, 69.3612172526698, 72.0255107264365, 70.85633847021288, 70.26933223970475, 65.34260780580583, 63.649704994693884, 60.33359204569171, 62.88287378126576, 61.10769141104914, 62.7266614667831, 59.760121914648245, 61.782778386146795, 60.67667784229402, 61.88180646588726, 61.01125601799258, 60.156622548257154, 53.174105459643954, 53.73483965473791, 51.92579938519386, 55.57933422826952, 57.14384609653104, 58.65778292379072, 54.30378729297269, 57.23344087600709, 56.10206065639373, 63.70038201732021, 61.421775202597345, 69.210464877467, 61.4103336488047, 61.237788584924516, 67.60257551746984, 65.01947902864026, 61.399111747741706, 56.74364666784964, 56.8116174205657, 58.09349898369082, 58.385127206002515, 61.657929343561975, 59.55592332347747, 61.86087669864778, 63.79047101543796, 61.97699062285885, 61.35385151832335, 64.02038466545844, 69.10153281304144, 63.79868053620862, 56.75865365612892, 56.37221782438217, 61.76022083528581, 64.03212824175435, 63.45957986770138, 64.64993292285551, 63.601408850762155, 64.4617493690983, 66.15898639925065, 65.87025288612612, 65.15831524325957, 67.42477447755876, 65.91448937692951, 64.82272509605654, 61.43715873841317, 64.00219663496941, 61.410863168777965, 63.94945644563245, 65.13878968454176, 58.32025120335241, 53.47114263042327, 48.315669490445046, 53.05837985007994, 64.69538142604213, 63.16384492381927, 60.92085323026104, 53.60228707713466, 53.18616282555365, 54.61192869370984, 55.238107635128884, 57.014874642895116, 53.738259961528165, 52.66022005388814, 50.739886453074796, 49.58419146076326, 53.00534940535023, 54.66577499143539, 57.41545061911307, 59.6562457853748, 57.08521058482509, 57.826001182679214, 62.25964838458646, 59.55496626515543, 54.02376928637105, 49.47341588235671, 50.90933676688902, 49.374376035505726, 49.691232942765765, 47.625289194045536, 49.87259549479331, 52.360496059540786, 51.22337348999516, 54.18768513587214, 53.555485356238584, 57.920989221142186, 67.11593489493093, 69.7610793575164, 69.16196869265649, 74.05663167276691, 70.41590336830386, 71.80096287881175, 73.56137752532959, 72.0418042521323, 75.03141910799089, 76.85365030842443, 73.49559153279951, 72.89018938618322, 69.88223352739888, 72.06269479567005, 69.21833315203267, 71.50389040670088, 68.12658848301058, 72.81720976675712, 69.39421223055932, 82.48617387587025, 75.07637731490597, 94.32824873155164, 45.179079501859604, 0.20370274842266115, 0.4034834943952099, 0.08047777393292035, 0.16706532888835476, 1.8130423128604891, 77.3517599413472, 71.62146737498622, 57.273719695306596, 31.920603436808435, 47.55862066822667, 48.72050516067013, 0.2985150463158085, 0.04380160567140387, 0.1338748300387975, 0.03255559965187023, 0.12143137879789838, 0.1414257296991925, 0.06570320906898668, 0.04159047673907011, 0.024184922710241332, 0.059360973987608194, 0.11471317074592076, 0.26017191669633316, 0.13025282761983334, 0.14039601559840864, 0.15545039407668576, 0.24237039288686169, 0.2227288944226119, 0.1501685549174586, 0.11064617083437982, 0.380634738192443, 34.248445803119296, 89.47342134291127, 37.48362848835607, 73.07964771024643, 58.586407553765085, 95.37097161816013, 35.988260161492136, 0.8893036674107275, 0.2119641333457924, 13.830272324623602, 2.8172911607450057, 36.99545814144996, 115.64849576642438, 91.75667224391815, 104.19839120680287, 93.77681055376607, 100.19749518363707, 88.54006982618763, 87.14823246002199, 82.15151725276824, 79.18179665842365, 72.90502379017492, 75.19526435482886, 75.45971055184641, 72.37447615592711, 69.55484897859635, 66.5138275392594, 60.32442546659901, 67.82333435550814, 63.40723583775183, 64.32373685221519, 64.19626766635527, 65.92883740701984, 62.59623089144307, 65.24807476228284, 64.41137829134541, 65.83423768320392, 55.168077638072354, 59.53446011389456, 56.19223594665528, 58.66275256679904, 59.383892090089866, 61.41951199500792, 56.7739155984694, 60.37648708589616, 58.928453922271736, 68.65083679076164, 64.78045763507967, 70.42722332862117, 65.05658465047037, 63.95410445428664, 70.78984645105177, 65.24037514963459, 66.10179039739793, 58.40382906698412, 60.3121288361088, 60.90002152227587, 61.851647361632324, 66.42664109506916, 62.60407563178771, 66.37841163143035, 67.95350213204661, 64.26392855182772, 63.46485153321297, 68.43888759613037, 70.06654570179602, 67.24150565362746, 61.495158826151204, 60.97573895608226, 63.1954356931871, 64.43231982569542, 65.4729324771512, 66.60022166467482, 65.73510762183898, 67.8124144769484, 66.10085687329693, 69.00269692943942, 67.23156636761081, 71.14947288267075, 67.29360257425617, 66.91401127846011, 63.882325080133256, 66.96377046646612, 65.00336985434255, 66.9377023943009, 65.51017930430751, 60.380648720648985, 55.57045790456957, 52.35183938857048, 56.351272367662006, 64.61805189809492, 68.66841685387396, 64.2003155523731, 58.43483932556645, 55.34696517452117, 58.657700554017104, 56.33982296912902, 61.643024336907175, 53.380551568923465, 56.52946956696049, 53.95767734896753, 51.39333371193179, 56.58128407693679, 58.077487868647424, 60.73386992177656, 62.41703741012081, 60.48569763860395, 61.83029790078441, 65.9348778570852, 62.834303071421964, 58.56679962527368, 52.3317882322496, 53.054818337963475, 53.74522216858403, 52.78916797330303, 50.442778679632376, 53.11079840506277, 54.67294508411039, 53.16067134180377, 57.10783873834918, 55.78269735459359, 61.4543975553205, 72.24759532559302, 72.33886887950283, 72.18723789338144, 78.07506069060295, 74.6179699128674, 74.04371923015964, 78.4738951344644, 76.178249543713, 77.93541646772816, 80.2515289860387, 76.77103734785511, 76.73757953028526, 72.78430892575172, 75.8649149248677, 72.22839140122937, 74.23405616514145, 70.2087002415811, 76.24680472958472, 73.34537259994015, 88.20794705421694, 77.19310791261735, 98.01070320990779, 46.97086526501564, 0.7626552375093584, 3.652261788806608, 0.2595973201096058, 0.3738206312541039, 2.61530184457379, 88.81796190815588, 74.40486754140547, 76.07345165744906, 44.549295902252204, 52.084929943084724, 59.34230712152297, 0.4066527694944413, 0.1738415451179589, 0.2155390979662057, 0.18768265482879457, 0.2316239413114325, 0.2908920118164632, 0.14314833968397112, 0.08887042802187706, 0.12834718390818567, 0.1837945747519693], [0.07146991293637023, 0.01728608644747686, 0.05765083208379727, 0.0334824932618968, 0.049305928255160975, 0.025192868422656774, 0.036601693023957556, 0.06652037973605818, 0.05036564618949929, 0.12831253375137044, 39.24889510677707, 58.425578609589614, 29.22574293228888, 40.88041282469227, 42.65786624723866, 87.94841950939548, 17.690160120687178, 0.26840576841946573, 0.2726233275907655, 2.862336640396426, 0.6607523055807237, 69.90086478571739, 102.61781723268571, 84.54573200594994, 90.47005637999504, 87.09877137214907, 90.85164023983864, 82.98551513302712, 78.02367764134561, 69.97535059528967, 71.22419403445336, 67.79044920398344, 71.5584348863171, 68.94101373610958, 69.79757308959961, 61.56737358339372, 62.903630964217655, 59.99137309289748, 59.919201481726866, 57.78550663302022, 60.25750198671895, 58.03488308383573, 59.46623048474712, 57.39493270074168, 57.35430086812666, 58.215276810430716, 58.668522373322524, 47.678849158748505, 49.696386937172186, 49.78165141997799, 52.56656169891358, 53.1634013114437, 55.281100734587646, 50.85764385038807, 56.059679446681855, 53.81117682303152, 57.66747859216506, 57.722517290423, 69.08388999200636, 59.10542341970629, 54.48187858827653, 67.59408750841695, 62.59324989011211, 60.6202349355144, 52.21957706635999, 52.14145129726779, 54.61603933765043, 55.78132844740345, 57.56340242201283, 57.83098651516823, 61.431616429359686, 66.1416652125697, 58.7232159030053, 61.90385803099602, 64.98298529655703, 65.5696738150812, 64.2093683827308, 53.68504516540035, 48.90099694651943, 58.531208038330085, 62.284527978589466, 64.27009059536842, 61.47134611683508, 61.46896916051065, 60.82606523267685, 59.914051409690614, 62.76693244134227, 61.880543462691776, 59.10175992596535, 60.786257097798014, 60.70057684375394, 60.92206132027411, 55.90884470170545, 62.39364831678329, 58.57946103618991, 59.46472037223078, 58.84144790710942, 48.22131295357981, 44.77259251379198, 53.4987953401381, 60.45804492888912, 56.497819962040076, 53.88016346962222, 52.02505888477449, 50.047121355610514, 55.11838120798911, 56.3842712679217, 57.14481099959343, 54.510641328750125, 52.82493606690438, 46.71905694469329, 47.393155482507524, 49.245000577742054, 49.95684800609466, 54.08697043695758, 55.9789139224637, 57.526696881940296, 57.35417142991097, 59.24913906281995, 57.13677798548053, 51.59939150656424, 44.13990243788689, 46.78571370340163, 47.208129436739036, 46.394794602547925, 43.92006143446892, 47.37624614469467, 50.99597407925514, 52.0512407056747, 51.634449651164395, 53.42887124707622, 52.02139931340372, 57.738520560726045, 63.928197199298495, 63.11672941330941, 67.00297063396823, 69.64278067311933, 68.93261986394083, 70.35492620160504, 70.57301782792615, 69.81511392901021, 71.04881701930877, 69.58936583611273, 66.96011481746551, 66.15755865650793, 68.51307530556956, 64.96076506953086, 68.32745305953488, 66.60012752779069, 67.59417380056074, 66.41971418934484, 78.45017263966223, 79.45472301975374, 86.17724187912481, 65.20100239784487, 0.10712524605614525, 0.04837578260189584, 0.10497164266604571, 0.11039982760144819, 0.35393973031351644, 59.443335610051314, 68.9302585970971, 54.65294099623158, 42.234101218561975, 28.435130388506, 59.42235877436977, 1.5905445165211156, 0.08319197748337062, 0.03050540472500988, 0.05739082184229648, 0.060061197502598654, 0.024091128650451862, 0.016671536460278497, 0.0738204085838891, 0.017896064804987084, 0.024378852122613502, 0.13307518746343353, 0.021497319647741896, 0.05126005384109674, 0.014666431553421483, 0.03373083981475042, 0.020483714460785833, 0.06254457493102358, 0.003747299690017357, 0.030350423222708128, 0.20882605334683774, 49.20955019612467, 68.62509035295056, 36.667622520077614, 35.37772363232028, 51.630597883655184, 93.57764828589656, 19.688437100379698, 0.42293072828362066, 0.367640906404103, 1.270279559877611, 1.2828261188922392, 77.2365834636073, 104.92916799360707, 87.37702431217318, 91.24062953456756, 86.28811943915584, 94.62742359407487, 83.99925170406219, 78.23300669270178, 71.33813888795915, 73.46192975198069, 70.98411360094624, 74.50933594857493, 71.79496165244811, 72.67550237717168, 64.65791886852634, 65.54897546768188, 62.97509262638708, 61.57841897779896, 61.08825998921549, 62.06600096917922, 60.63408090222267, 61.188331419421786, 60.305570633180686, 60.611429214477546, 61.081435065115656, 60.831733057575846, 49.519013435609885, 54.57198327587497, 52.838523157181285, 56.09050535386609, 56.83293158008207, 58.65189544616207, 54.98532656700381, 59.529337498449514, 58.52827410544119, 61.43205181244881, 61.51386853187316, 70.72514303268926, 60.13359431297549, 58.433815586951475, 69.87053701954504, 63.11954175272296, 65.05817713276033, 57.765275047671416, 55.18558709852157, 56.73710807677239, 58.28480082173502, 60.89373396288965, 60.75003400925667, 65.23363259530836, 67.006516456604, 61.39058843735726, 63.43326468621532, 67.4748396104382, 68.12493324279785, 69.16463590437367, 58.45825195312501, 52.142051419904156, 60.10296452429987, 61.600345027062204, 66.44554691929972, 63.03799175447034, 67.11934735698085, 64.55629417973181, 62.13348534799392, 64.82738879419142, 66.34959005540418, 60.64479681753344, 63.60007916727374, 61.03334288443289, 63.52169452175018, 57.00356252731816, 65.0512384599255, 62.49845404778758, 63.748615403329175, 60.20802520936536, 48.56708949612033, 48.948516461157034, 55.949962908221835, 62.16131064199633, 61.29295279902797, 57.05271374794745, 52.874444223219356, 52.76523759288173, 56.84008990564654, 59.378369392887244, 60.62488686653876, 55.33938715534826, 55.712796795752745, 50.17107217542587, 49.04188848310902, 51.20073749173073, 54.37888499229185, 55.7874708790933, 58.87647859511837, 59.3783615481469, 62.00139953244118, 60.37755397058303, 60.27251289736841, 53.41623729275119, 47.888739109039314, 49.262643398777136, 49.74932324501776, 49.75433603409798, 46.45864686658306, 49.796207335687455, 52.76773222031132, 54.98984905981249, 54.29328318565123, 56.24013985356977, 54.073622611261186, 59.265746378129535, 65.62689335115495, 67.42092271004954, 69.1825532913208, 71.37935515372985, 71.24090333138743, 70.89899032346665, 72.34344236312374, 72.68008370553294, 72.21798143079205, 71.05561056444722, 69.81162301955685, 70.46354447641681, 70.49426447960639, 69.19049216854957, 68.7160187382852, 68.98451282132056, 68.9755698173277, 69.65072739508845, 77.2083894668087, 81.05390471796836, 87.57102474089592, 70.05167991884294, 0.35291170160616603, 0.05003557337688343, 0.08393921198383456, 0.15010095531902007, 0.7157488996463438, 62.92156011827531, 79.53244086234801, 60.302064034246634, 37.447852550014375, 40.189087237081225, 73.76093987495669, 4.090169168287709, 0.08769404638798968, 0.06522133210373503, 0.011316360661669845, 0.04536919393426469, 0.013059299747129122, 0.09543087558760759, 0.08696892884589973, 0.04103250042986005, 0.031169235233157396, 0.20886471014349692, 0.1643698944920494, 0.1989651687683598, 0.1189184648495528, 0.13218396673760108, 0.08617333121477597, 0.20882596141628681, 0.14379360022083407, 0.263819751600104, 0.31524891935048566, 53.87781789225917, 78.08023037449007, 36.27207894479075, 53.60948070403069, 60.42330449627292, 103.18103821046891, 23.612248743734053, 0.4796208363146552, 0.7256862857649404, 9.082630565089564, 1.4147427822313001, 77.4892468606272, 109.30137126676499, 92.22221835967034, 97.45081624677105, 91.87646142898068, 100.1957771855016, 89.94132088076684, 83.80758900796214, 74.27047929456158, 78.19433212280273, 73.87596730263003, 79.34304529620756, 75.59464008577409, 77.21710497333159, 68.16094060097971, 69.15887002022036, 67.0485564201109, 65.79562979359781, 64.01097489941505, 65.95390135242094, 65.00636262278404, 66.25643376381167, 63.596913814544685, 62.97572412798482, 64.56637467107466, 65.80496111223775, 53.93839497720042, 58.74579306571715, 59.623470460214925, 59.20455348107123, 59.630903351691465, 60.010141634172015, 56.577208734327755, 62.952338957017474, 61.338817073452866, 63.06484430067001, 64.71991977384015, 74.0877752919351, 65.7089061890879, 61.39069041898174, 70.38432044367637, 66.66155968942951, 68.13178954585906, 59.16374514179846, 58.888222171414284, 59.592605329328975, 62.80737992255919, 64.26869423158708, 63.43419036557598, 67.09967274819651, 69.38644593761813, 64.51219497188445, 68.67603409674861, 71.32689737504529, 70.56362767373362, 69.10066989160353, 62.87873175836379, 54.52538944059803, 61.8006016362098, 65.07008544860348, 68.17927375916513, 65.70570945739746, 69.64871914156022, 65.86844859584686, 63.811549832743985, 67.03690698069911, 68.05707623881679, 65.20206928253174, 66.28922477845224, 63.45332368727654, 64.8226035025812, 58.7702686555924, 67.31796049302625, 64.98584862678283, 65.3364614517458, 61.64281252891787, 49.945837913020966, 51.118144143012266, 58.10774503215667, 64.76552909420383, 63.70128808483001, 60.61351199303905, 57.19815131156676, 54.283069333722516, 59.736501401470555, 63.749631297203806, 63.01861132344892, 60.02210878556775, 58.61296592220184, 52.10948398036342, 52.634144136982584, 55.564605728272475, 57.576424690984915, 60.76169521577897, 60.51768064498902, 62.88231680470129, 64.50678210104665, 64.97102598990163, 63.331671376382154, 56.451324186017445, 50.895988941192634, 51.76831622277537, 52.72971660860124, 53.745386908131266, 49.590757508431714, 52.72438218516689, 56.150976534812685, 57.65239315648233, 57.135126667637984, 59.89892282793599, 57.52681063067529, 61.19639973486624, 69.14299226576283, 69.96370900061824, 73.02844509001702, 76.11717039538969, 75.46015770204606, 74.72337184413787, 76.42634730185233, 75.36160422909644, 76.93052876380183, 77.19382962872906, 72.19520030483123, 72.59286588238132, 74.59922882818407, 73.21046660023352, 74.01452895133727, 74.47441116456064, 74.09475711084183, 74.14386518539922, 82.44161575071274, 86.32510738988077, 91.71141593686997, 72.50461255350422, 0.44074083227784405, 0.24951181855172883, 0.18346010076422847, 0.3464440502707036, 1.5583902741632156, 72.57019458278533, 82.6779777772965, 73.5477041429089, 58.23753626115861, 40.1673416168459, 88.77471385463592, 4.314464513332614, 0.1637489189423861, 0.20101191055390144, 0.1256098215197844, 0.0805300594337525, 0.14607533181626953, 0.22272503333947352, 0.11961901395191109, 0.14860875393834808, 0.1262804319060618], [0.05013222302941065, 0.06107069837350038, 0.03196159805802088, 0.05928596631894189, 0.0626267799957385, 0.048076081345038074, 0.021114783218851494, 0.03947388305659256, 0.014637676443183615, 0.9112081436380264, 58.422938854463645, 49.98251991887247, 39.03299608538228, 58.58649776827905, 52.88153979086107, 86.57541736479729, 12.928477256528794, 0.5490900263670953, 0.491339192996102, 0.8175514434133807, 6.075947025129873, 92.54817516573014, 89.88840026240196, 86.77961595596807, 85.43124629605202, 82.56382111580142, 79.40716820378458, 73.48226331895398, 68.78850413906959, 68.39607884806972, 72.40329773195329, 71.15722348613124, 71.37490718595444, 70.34619500560146, 69.88468893112676, 64.24255163438859, 59.39164269355036, 59.230268539920935, 60.456417145267615, 58.71311579981158, 59.2526025156821, 55.571650305101954, 56.97879275967998, 59.78564085498933, 57.84605233900009, 60.805990542134936, 56.43701145725866, 49.53690728833599, 50.154786494470414, 50.214543804045654, 54.135097918971894, 53.2792563592234, 52.98331745209233, 52.76261744960662, 56.070854279302786, 54.559368933400805, 57.48966186277328, 60.947388064476755, 61.97102469782676, 66.23136981841057, 47.0264530950977, 65.18964321382585, 65.25147937959241, 58.28769945329236, 58.99878201946136, 50.93346718818911, 53.32687001074515, 55.133184233019435, 63.28011182046706, 57.07020751891598, 67.25194700302617, 67.2745555446994, 62.384030665120775, 62.173164044657064, 65.15500084046396, 63.76223779493763, 67.00530052185059, 49.057766237566554, 53.71201146033503, 60.31374093024962, 59.049227622247514, 64.83892448486822, 59.57078126169021, 63.931370396767896, 65.50067932375016, 60.64531457039618, 61.866034615424375, 55.59451380083638, 58.133005096066384, 59.2062440226155, 58.31991387951759, 59.53046714105914, 56.25522921162268, 61.23865150636243, 64.11830271444013, 60.37063883196924, 57.77767758215628, 48.653636593972486, 50.00308098331575, 53.8051716742977, 60.63424564176991, 58.98471247765326, 53.89069895590506, 53.829251104785556, 51.76669236152403, 54.97570107060095, 56.08400598649056, 56.51127761410129, 55.11543943035988, 53.72446498563213, 50.75961597504155, 47.82407099200834, 46.31209927220499, 48.97915017220282, 54.33201266873268, 55.66300622878536, 56.503079860441154, 56.1217587993991, 55.51058292388917, 58.306985747429636, 53.935849358958585, 46.335657027459916, 46.84094852016818, 46.7482001550736, 46.6157260248738, 46.09371739049112, 44.05429670887609, 47.607607149308734, 51.8449201122407, 50.07897492377989, 49.29279073592156, 49.10312844860939, 52.50755356204126, 57.932148364282426, 63.951621593967566, 66.99483563823085, 68.6069219343124, 69.13685767881333, 69.67159440440517, 67.36287947623961, 69.44206514666158, 67.33683493829542, 66.3171128303774, 65.69160069188764, 65.83833263766381, 65.99916550420946, 68.25926657645934, 68.45708739372992, 71.63230096140217, 69.70663685952464, 69.28116167745283, 70.96256409921955, 82.78861215037685, 78.76251097648375, 86.54934929263207, 4.030837190728034, 0.13427610689353559, 0.18366452366594346, 0.009295488707721233, 0.7059904716668591, 42.55783404073408, 79.70173820372551, 50.645110222601126, 49.10383839761057, 32.05269317473135, 58.11571528834682, 7.458190764150313, 0.22925014126925702, 0.0817138567987469, 0.14753627680963086, 0.04461573113897636, 0.010054850380026526, 0.07934491375401136, 0.12151156522093282, 0.053000310661211136, 0.06004365025869301, 0.031169101167770646, 0.04949472679366027, 0.06400999004742311, 0.0727223058141047, 0.0652412120853701, 0.08483973301706776, 0.04845775017935423, 0.09472026775080351, 0.15133709947188057, 2.298335110948932, 66.95256033251363, 57.220912825676706, 37.23958646097491, 51.4920715362795, 65.68699975167551, 89.7253002658967, 14.710897380305877, 0.795907743515507, 0.7332034469131501, 1.146902754422157, 7.178839560477965, 97.15191595015988, 91.45895650309902, 89.99447684134208, 89.71161119399532, 84.41061419825401, 81.12315808573078, 76.35696841824439, 73.33461746092766, 70.47292678586899, 75.23271514523414, 74.6709454444147, 73.37574743455457, 75.0343216619184, 73.52538585662842, 67.73324535739037, 63.064048059525035, 62.08576187010735, 62.90121870656168, 63.289054824459946, 59.20125869012649, 59.4659363069842, 58.5066657681619, 62.16674704705516, 61.138179994398556, 62.02383548982682, 59.020966945155976, 51.14962508601528, 50.68930356733261, 52.662349900891705, 56.73394272404333, 56.60847002460111, 55.96641332872453, 55.05849838256837, 58.3864765013418, 56.596534252166755, 59.41145066292056, 63.964157489038286, 65.48273055784165, 68.80311889033165, 51.575861207900516, 65.90523258332284, 68.45644412502166, 62.522380505838704, 60.99476245141799, 52.43490734407979, 57.17438567069269, 59.40032682111187, 65.84966044272146, 62.89330336355395, 71.01445705659928, 70.53197414644303, 65.7919623774867, 66.04807746025824, 65.17840954565233, 69.0918053350141, 68.00637568196943, 52.96460382400021, 55.34860080288303, 59.98599944576141, 61.45513888328307, 66.36386748283141, 63.828043399318574, 66.6004805411062, 68.97705247325283, 61.50538444519044, 61.798291360178304, 59.1505345990581, 60.55058148599441, 64.00924513416906, 60.93295766461281, 61.56941713825349, 56.81528875904699, 62.83671140670777, 65.57040729830342, 64.62077794536468, 58.34864524102981, 50.13826939367479, 52.17778813454413, 57.362910470654896, 62.08136489314418, 63.63004999776041, 57.8685079082366, 56.707874651878114, 54.30015125582295, 57.34796231792819, 58.19284477541524, 59.91141557693482, 57.335096943763, 56.799473762512214, 53.56786435650241, 49.82340112809212, 49.97576167506557, 51.720592744888805, 56.91861183412614, 58.37367388509936, 60.04165003376623, 57.87733716349448, 59.970278586110766, 59.6900095478181, 57.472536794600956, 50.220694080475845, 49.285377456295876, 49.029129012938476, 48.46921067084036, 48.05270987172281, 47.274790117817545, 49.29479506707961, 56.2000963764806, 53.42231696651828, 52.546679204510106, 52.645766119803156, 55.49144960218861, 61.02803199521957, 67.80616221889373, 67.63422904476043, 71.02574563795521, 72.74026070871662, 73.14154271156558, 69.5010732835339, 72.03332408781975, 70.29756546020508, 69.63641074395949, 67.11696255591609, 69.67855268909086, 68.62089341686618, 71.9252000316497, 70.92687053065147, 75.52410802533551, 72.69629093908495, 72.1041307141704, 71.19250128346106, 86.1906328508931, 78.6599096175163, 91.85960308198007, 5.634323445058638, 0.15843769265038354, 0.18845704714617423, 0.10413993165017137, 1.0097681743002709, 46.15412581351496, 87.74169491183373, 59.720843299742675, 48.805091073436124, 40.49996645219865, 74.75143248035063, 13.090394658427085, 0.21720808179628467, 0.1096826314084953, 0.09537186383480027, 0.06841379668443434, 0.004457432791710862, 0.011056558221518513, 0.04696928730775272, 0.06830495091215258, 0.05188786672548421, 0.11323860470926571, 0.16032223830059653, 0.14288405467185283, 0.23652391628392283, 0.17587815922114158, 0.1754723930911672, 0.21950640685616002, 0.1620695469600539, 0.2283602841799298, 2.31482524544962, 80.10341244359171, 64.49147309026411, 49.75335936392508, 79.86825066228067, 71.25498464030605, 101.21142787318077, 18.596296271970196, 0.8156979396458596, 0.83097820680949, 2.5498215517690106, 8.867878836970176, 99.17032841713198, 96.02097111363565, 93.78360409890452, 94.83212424862771, 89.66797090345814, 85.60753330107659, 79.52490206687682, 77.69978400199645, 74.4416436841411, 80.1071543847361, 78.68672294001426, 78.4775350939843, 78.05551159766414, 77.21948977439635, 70.58341995362314, 67.52405751136043, 65.69668408363097, 67.1815953716155, 65.65737801213419, 63.986754263601, 61.218710176406375, 63.123934807315955, 67.18060693433209, 65.3341394086038, 67.52404966662007, 61.64289489869149, 54.98751524955996, 54.408847978038175, 55.298312094903764, 60.97096935395272, 58.55785269891062, 59.315129018598995, 57.615573867674804, 62.602243884917236, 60.38265697417721, 63.63190527885192, 67.75772094726562, 69.3466103461481, 72.2537063783215, 56.41275944248323, 71.35186718356225, 69.08047752995645, 66.15968458114132, 63.478179747058505, 56.85904279831917, 59.16010518227855, 60.879374165688795, 69.99440546958678, 65.53894988952145, 73.6049158342423, 71.54727966554704, 68.54798440010318, 66.74381179194297, 70.14041962162142, 71.70943044847058, 74.03950660459458, 58.324173573524725, 57.329429118864006, 63.3211947256519, 61.02841638749646, 71.64634304661905, 65.19318511409145, 68.3865317990703, 71.97259795281195, 64.41091937403526, 66.84140820657053, 59.35607071845763, 62.90073625503048, 66.85465797301262, 64.20631677873673, 64.26461496660787, 57.83108457442253, 67.50304929671749, 70.52941676109069, 65.87721901555216, 62.44736909866334, 51.346006393432624, 55.52552715424569, 58.9631708206669, 65.71044768056562, 66.89163023425688, 60.72757844002017, 59.015067700416814, 58.951760645835634, 61.0080514415618, 61.91428369091403, 62.449671529954486, 59.44404163668233, 60.84972104718609, 57.570019460493526, 53.898994768819506, 51.521167678217736, 53.86901217122232, 60.89583635330201, 62.55390459491361, 62.82845873986522, 61.99121313710367, 60.87860145876485, 62.82206527648434, 59.1614152539161, 52.004329158413796, 53.46812240539059, 51.51317781017673, 52.70433495121618, 50.494126427558164, 52.37095702079035, 53.34856464016823, 60.636285274259514, 55.315174364274554, 53.598627505763886, 54.61465081860943, 59.720329469250096, 65.73262868389007, 70.5540963142149, 72.72253159553775, 74.64672088623047, 73.92940567385766, 76.61828456386444, 73.3187004827684, 76.6405479369625, 73.82913420277258, 72.94621652172458, 71.67450566445628, 71.43073820298719, 72.31846470986643, 73.94889200887373, 74.64100991525959, 77.78309514445644, 76.41026558414583, 74.61690302818053, 77.07946115924467, 89.30883084574054, 83.87386921913394, 93.15268301194715, 5.677764675309581, 0.263686636162381, 0.5809695802388654, 0.26191954711271875, 2.324787820539167, 53.26977599051691, 95.40621803652857, 67.85879258186587, 69.30151093390681, 42.62436136122673, 86.37517252276021, 15.60221677826297, 0.31001779521184586, 0.26621766809013586, 0.18267881365553026, 0.1401323281348713, 0.11293993001022648, 0.17768853223852574, 0.16658647797040402, 0.24950559791778368, 0.1269362031692459], [0.08473626518201444, 0.10145405037028175, 0.08490341024533396, 0.029716495041465087, 0.06412437846583706, 0.08369035598251127, 0.038174770306795835, 0.03878903875668203, 0.13582982513452732, 2.9321528682785654, 67.0877173639113, 38.60576368147327, 36.81935941019366, 46.787423856796764, 53.76691679800711, 85.0720670146327, 8.826090885746865, 0.32531623398104026, 0.4472193927053483, 0.8684408256123144, 13.786104475298236, 101.22256740447014, 86.65974832350209, 90.1039658823321, 79.70668039014264, 70.28462948337679, 67.72642043329054, 68.18685962307838, 68.32309138390326, 71.60664081573486, 69.47824508913102, 72.5664447969006, 73.71205145312895, 70.38902728788315, 67.48524958087553, 66.40220472889563, 60.36140557258361, 59.179975909571496, 58.72723633243192, 59.623858774861986, 59.33879267784857, 58.27119019723708, 57.659626007080085, 57.6761431078757, 59.46523028035318, 60.17158639046454, 51.90954116082961, 48.044127725785785, 49.36428377705236, 50.739741325378425, 53.45633568302278, 56.48443683501213, 52.88913742188485, 54.82109692788894, 57.75186838642244, 53.59087297993322, 57.491183742400146, 59.57604116009128, 62.289878091504505, 67.6366138458252, 57.47987162682318, 52.17021796011156, 67.25609687066847, 62.154513174487704, 56.80179580565422, 52.20707647262081, 53.49270782163067, 57.91203052766862, 61.816844171093365, 65.8920612642842, 61.14787609346452, 68.87722815236738, 62.05293163176506, 66.35545792118197, 68.5230145915862, 65.63687970561367, 58.62881622006817, 53.41296995839765, 54.90297248286586, 51.97608024843278, 61.64862155914307, 63.18321751010034, 60.98144600468298, 62.27866403518185, 65.8857854720085, 63.26291614963163, 60.0729230911501, 60.97157732132943, 62.39600566125686, 62.03084868769493, 59.15459425218644, 63.241492163750436, 59.28966891381049, 60.83639675571073, 59.87402362208213, 63.55003756861534, 58.403899669647224, 49.848974981615626, 45.908161824749364, 52.56707945177632, 57.576373700172674, 60.222259490720695, 54.27831542107367, 55.5316460517145, 55.321328563074914, 56.996792516400745, 57.79655987216581, 57.758646242080204, 59.28093379543674, 53.724068826244725, 48.88705292055684, 47.614059448242195, 49.34358935202322, 49.24495350929999, 51.2652918600267, 55.80317212689308, 56.24860432840163, 58.80536210152411, 56.77985014454011, 55.591940726003344, 55.770008487086145, 47.559365918559415, 46.100452100076986, 46.222186780744984, 47.44517395573278, 45.218973928882235, 46.00471881128127, 44.09248490487376, 50.384143167926425, 52.1321278233682, 52.062109593422186, 50.474867590012096, 51.175481350191184, 53.71341959122689, 64.118208577556, 67.36751571778329, 69.8933259902462, 68.82121670630671, 68.47436935670915, 66.28564757685508, 64.79183643094956, 64.07909470219766, 66.48910091769311, 66.95082664489746, 71.18667264138499, 70.84676004225209, 75.69156185273202, 73.00843315739786, 78.10183478939918, 71.53450058352563, 74.88333394450527, 65.50327593280424, 88.07697911416331, 75.74691434060374, 98.24533939361574, 15.631652205221116, 0.3436936720484688, 0.24829586847655236, 0.12153224959488838, 0.2300539053976536, 34.4969867890881, 83.79679464524793, 53.949648257224794, 48.0776326117977, 22.898367566447106, 57.04376289921423, 23.497862623583888, 0.24707493882986808, 0.0594581752234409, 0.1592216610668167, 0.030404493708403844, 0.021417638842737483, 0.09370615120015799, 0.06299834796077301, 0.02893919158997315, 0.04435061109102061, 0.058026563736700246, 0.08926264205647093, 0.08786227929616168, 0.06711112545622934, 0.09637155494983159, 0.05627773822315278, 0.007612168020944322, 0.06541961864117654, 0.19708777837935956, 4.861493456748224, 79.2091355785247, 44.69547479383407, 41.802801316784276, 49.37215989635837, 64.20435951602074, 90.58906893576346, 8.359945627950854, 0.39778330994229166, 0.4194024950265885, 1.3739702345863467, 15.904802141651032, 104.24590679907031, 89.20486450195314, 92.52263269116803, 83.69069453208678, 73.4964152305357, 69.7324695894795, 70.67520341565533, 69.97350708130868, 72.7095877739691, 72.40764371810421, 75.47655320936634, 75.36144733428955, 73.46313784199377, 72.29919018283968, 68.79055946103989, 62.98298835754395, 62.428922191742934, 60.73353259794174, 60.537731801309896, 63.71368277457453, 60.31388605794599, 58.41820455366566, 61.3553890874309, 62.64102828118109, 62.78624226970058, 54.75569925000591, 51.84864244153423, 50.691806039502545, 53.986836248828524, 57.196880463630926, 58.08239083136282, 55.84858925111833, 58.30717402119791, 60.5083179473877, 54.86830265291276, 58.04058621006628, 59.102316902529815, 65.94192243391468, 69.94701539316486, 61.81125479359781, 52.93817097140897, 69.3459592326995, 63.791173119698804, 61.64235753397788, 52.67695288504324, 56.289196937314934, 61.2318971849257, 63.145398016898866, 68.07580163401943, 64.5075273513794, 72.55801170103013, 63.49574804306031, 68.8023893294796, 70.6908928963446, 67.86768851741668, 63.5200196696866, 58.35104965394544, 55.481675055719194, 51.044297679778076, 62.89893588712139, 66.75152317170175, 64.19669912707421, 67.30133748823597, 68.94388491107573, 64.84001490377611, 64.92453413624918, 66.3272011664606, 65.05355265832716, 64.48724477521836, 61.4655057076485, 66.23947343518658, 63.62466850588399, 62.77014486251339, 60.26103211987404, 66.04081323069911, 59.843287929411865, 51.40518711459253, 49.605944925738925, 53.99579886467227, 60.9729423061494, 62.197918122814556, 58.56282626428912, 55.968378436180856, 58.767146448935236, 58.87628639897993, 61.73912632849909, 58.47858552009829, 61.089475923968905, 57.8498766499181, 53.29513019131076, 49.16399186657321, 51.831219273228804, 51.47796277076968, 53.3924755742473, 59.2822713236655, 58.76364377237136, 59.59380949697187, 59.87026991382722, 59.20462408373433, 56.27497050069994, 50.35520392079508, 48.50266064366987, 51.11654773835213, 49.244286706370694, 47.505664748530236, 47.405185391826016, 45.800367247673776, 52.16633873601114, 53.66615503065048, 53.68115809655959, 51.59086427380962, 54.81298154400241, 57.77995647922639, 66.79495949898997, 69.7965846523162, 73.09474099066951, 71.95261739915418, 71.63370516992384, 67.75441831158054, 67.92913636853619, 64.73163197117468, 68.1686206017771, 68.7547403766263, 73.09677277841877, 72.84078321149273, 78.7650683618361, 74.87235130802279, 80.90407017738589, 72.06669561324581, 76.67515893136301, 68.04811754534322, 87.80864192593484, 74.39048028761341, 100.64000129699708, 18.673806228945335, 0.22330824075446976, 0.18539090280330953, 0.443047063365098, 0.3442029979440474, 38.04826151940131, 90.96683240705921, 63.34920829342258, 47.89329298080937, 27.942870970695253, 74.20976884903448, 34.27538464146276, 0.19327584744220783, 0.1416068788497679, 0.13997834446209093, 0.07120912128518667, 0.025350718924234954, 0.012320235574377641, 0.054943236041693926, 0.04853643890049669, 0.10291422927571882, 0.1354367300988205, 0.1135743044376854, 0.1957847547507094, 0.15515566473045658, 0.23790865085057675, 0.29761167543549694, 0.19402088327032907, 0.17631046263681305, 0.29393534206094285, 5.300475320508403, 90.58506027344735, 51.96951812313449, 53.200793266296394, 62.892511044779134, 73.29752752857824, 101.97171657316147, 11.98116308258426, 0.6422318542195905, 0.8468537549338034, 1.4909740465302623, 17.633607387542725, 109.02944903219901, 94.05638141016807, 99.16074214443084, 87.86203322872039, 78.88450453358313, 73.327910207933, 75.1436302738805, 75.92155395015594, 76.21930106993645, 76.58732137372418, 79.17798411461615, 79.89110239090459, 75.83636791475358, 74.49055564018988, 74.43329688041442, 66.24266624450684, 66.50835191049885, 65.50459384918213, 65.15154130997198, 65.26592546893706, 63.57812566141929, 63.15358792581866, 63.76127681424541, 66.75826964839813, 65.7441879087879, 59.44142933814757, 54.704649602213216, 54.335719308545514, 57.0972522612541, 61.76054246963994, 61.68315018376997, 61.46360335811492, 61.611931708551225, 63.79116527495846, 59.46245324227118, 63.20861093459591, 63.12046350971345, 68.48932143180602, 73.69021169600948, 65.04550787710374, 60.76339360206359, 72.9019957204019, 68.10009679486676, 66.79570474932271, 57.46154239100795, 58.493310097725164, 63.243488650168146, 67.80456973660377, 70.9899030193206, 70.46530954299435, 73.3352215059342, 63.99767021979056, 75.15557781342538, 73.58650422865345, 70.25418404609927, 67.50278257554578, 61.93844156880533, 60.242906847307765, 54.23142740803381, 64.27827265954787, 71.44411348527478, 64.73733509740522, 69.32852037491338, 70.94196381107454, 68.00702679541804, 67.96715982498662, 68.0403434076617, 67.63075382478776, 66.67524876133089, 63.54704480017386, 70.0733627811555, 64.09696502070274, 64.55331317840084, 63.83400932435067, 68.1351157157652, 60.5024383144994, 51.71898065074798, 50.969882472868896, 57.05809916219404, 63.99010789009833, 64.74033178821688, 61.2151212076987, 58.78347527596259, 61.78163305405648, 61.40151223828716, 64.5644683991709, 62.91806528645178, 66.1229476621074, 60.10826364640267, 55.22568941116334, 52.09422988276328, 54.77590337876351, 54.93993297699959, 57.34778188890027, 63.73086275592927, 59.71591680280624, 64.34591785553964, 61.66990433969806, 62.11272816504202, 60.41562057310536, 52.99976787259502, 50.694728205280924, 53.10193777084351, 52.35647563011416, 51.182682821827555, 50.39768711213143, 49.00592819336922, 54.476842264975275, 55.95923931367936, 56.09460423069616, 54.99816840694797, 57.345350019393436, 61.15704267255722, 71.74843449746409, 72.32983958336615, 77.33220300366803, 76.4843277777395, 75.23375849569999, 71.14820987947526, 69.87323561022359, 69.53208354211623, 70.22256189777006, 73.0201296652517, 76.38094978947794, 77.05191043115433, 80.9773478969451, 77.00302985406692, 85.51401615142824, 77.23127257439398, 83.48925728951731, 72.30636027551466, 93.87671332205497, 79.82493200609761, 104.86746911079653, 20.030740384132635, 0.40102833581547587, 0.3880066797137261, 1.290145016485645, 1.4449498129467813, 43.26786933406707, 99.8653567221857, 69.01502101652085, 65.48117337688323, 33.28224443620251, 81.54456969230407, 37.79322901079732, 0.33281595896809335, 0.19942155798837063, 0.2461957916497223, 0.1132038473001411, 0.11108288691649515, 0.2491669870552517, 0.17866302672172749, 0.10458396387196357, 0.12799772524064587], [0.056609090402602195, 0.09021215441246187, 0.08297833854392653, 0.05413787461997521, 0.01633951012345572, 0.094138408650554, 0.020276790281998056, 0.15294556235594137, 0.25200938775895104, 8.579792514924081, 71.45526086130451, 40.27417521322928, 45.0474996720591, 47.95094397760207, 62.655038987436605, 78.97158899614888, 4.715400857310142, 0.4244184403890564, 0.41685467045153346, 0.33983825796073486, 17.502566883640906, 102.20610956991874, 85.2103070289858, 88.20907669682657, 80.17850229817053, 71.84006890942975, 67.63415844209733, 68.12261119965585, 65.72054778375934, 67.03276495779714, 69.73150468641713, 71.6717129368936, 71.83970805137389, 74.93688998683807, 70.77258802229359, 68.94197079443163, 61.78095448401667, 61.52520418167115, 57.63367560602004, 56.50568823660574, 56.8805334644933, 55.25822154937252, 57.452501327760764, 57.78982124020977, 58.61135775043119, 59.489756861040675, 50.03378137465447, 48.580625595585, 50.93476157034598, 50.32015362093526, 54.656494663607695, 56.994533231181485, 52.310434849031516, 56.66450892725299, 58.66468237292383, 55.1905998876018, 56.54555520703716, 57.120668811182824, 59.432725598735196, 62.12077294626544, 62.9103970527649, 55.910013568016794, 57.71695536951865, 65.80154472781767, 58.83543883600543, 53.59237524770922, 51.14476919174195, 57.08179027803483, 63.212505848177024, 66.8485704545052, 64.14229585278419, 57.35556387132215, 70.10016041417276, 62.58901373032601, 63.31800976107198, 65.21393837467318, 52.84988234120031, 51.79931471424719, 54.00750321726645, 57.37172795880226, 61.68726082771056, 62.17710210431007, 63.69464358975811, 64.11943235704976, 64.1227702940664, 62.45859884446668, 69.52291304065336, 60.84033089299356, 60.457185929821385, 65.04246411785003, 64.42223541198238, 61.34524976053546, 59.11478611730761, 61.68680583277057, 60.074393979964725, 64.53854937707224, 58.04677963256837, 50.33781997619137, 46.575678625414454, 51.15190006071522, 60.48300689266574, 58.915176699238444, 53.91009115403699, 57.087199226502456, 58.81171241883309, 56.6784490308454, 61.21021432261313, 54.27218083412417, 60.702302686629764, 58.80849999766196, 49.97169417719687, 48.923268164357836, 47.39047258130966, 51.637767976330174, 52.08994273216494, 56.05160720886723, 56.17666021470101, 55.43940759474232, 55.74244991425545, 54.53126515111616, 53.87454663553546, 48.03416098317793, 45.274491156301195, 45.32638803605111, 48.26076807514314, 45.97669739877024, 47.396309068126065, 42.91057279033046, 46.36975419136786, 52.57396321142874, 52.43599384061752, 50.612268217148326, 53.00196832226169, 51.854447549389256, 55.48014140898182, 67.11179287202897, 67.19439798785795, 68.12456454000166, 67.78403220638153, 64.94541683504659, 65.13731487335698, 64.69975094641408, 71.03919936764625, 71.82705448519799, 75.25525308424427, 73.21863297493228, 79.11147640597436, 76.63732374868086, 78.51724516960883, 72.18201329631191, 73.74041018947479, 63.498862404977125, 84.51945997053578, 72.22029562919371, 97.66311060997748, 31.210566182290357, 0.15499760546991903, 0.13160754686161397, 0.019798247714436824, 0.24548858524330203, 23.313493574819258, 83.07111693966775, 52.88884324412192, 58.58691353951731, 30.34046680696549, 41.0463761514233, 47.07076018856418, 0.39032743582802437, 0.08557586690350887, 0.04402397035230552, 0.012702772003268043, 0.08939825494082705, 0.054524844782727386, 0.08594676837204926, 0.15418374430268042, 0.0507646669153004, 0.03790320362895727, 0.0591128304480545, 0.08276390287304118, 0.028034918641130772, 0.0575489845247038, 0.05378931993618608, 0.14189681248559108, 0.17948962027026763, 0.40044102216920546, 11.68770311340209, 81.8968612917008, 47.908099928209865, 44.563828283740634, 55.740551487092056, 71.327164096217, 87.40641855424451, 5.587896800810292, 0.3746017038581833, 0.6325860105214581, 0.2998839228624298, 19.11693403797765, 103.99363563906763, 88.20176539882537, 90.52183951100996, 84.02945395438903, 74.05461557449834, 72.00524776212632, 70.26520590628348, 69.51592337700629, 70.96614914555704, 73.84834597187658, 75.51030912706929, 76.38229124007687, 75.72668275525494, 73.04895124127789, 72.13061455757388, 64.66210011513003, 62.89328767407326, 60.757894439081994, 59.78664105938327, 59.720917824775945, 58.43148962143929, 59.661976368196555, 61.12249051370929, 62.0620511424157, 62.817056409774295, 53.68997558470696, 51.7871985127849, 53.62686072626422, 54.15514515292261, 56.184097028547725, 57.98261357891945, 54.10559777290591, 60.71488172777238, 60.539249758566584, 56.64767803684358, 56.22016714465234, 60.48810205151958, 63.18113473153884, 63.71162745260424, 66.8402079612978, 60.00765092911259, 58.634613483182854, 67.06590898575323, 64.62680662831953, 57.82274953780636, 54.309098182186005, 60.53172273020591, 65.71139689414733, 68.60320352738904, 67.751264725962, 62.13218704346688, 70.64636615014845, 63.064157885889855, 66.60928233977288, 66.91657650855281, 57.362537845488525, 56.65279280754828, 54.47369652409708, 58.78355372336603, 62.503423690795906, 67.1976064866589, 66.4580592801494, 66.04043668316257, 65.32596518916469, 62.881402892451135, 69.45061591363722, 63.391962128300825, 62.26058190868747, 65.76875763554727, 66.84269474398705, 63.76042565991802, 60.35663989282424, 63.232117699038604, 61.95468410368889, 65.80102305258474, 59.430995833489206, 52.506388618100075, 49.00830907206382, 54.86133260111655, 64.5156466576361, 60.852917778876524, 56.84304737275647, 58.3368153725901, 59.6063022459707, 59.11398987616263, 63.09971809387208, 55.406259644416075, 65.03078329947688, 61.2149368563006, 53.20333103979788, 50.32788461254489, 48.89690983679987, 54.50977448494204, 54.250745081132465, 57.936125647637155, 58.267624762750444, 57.085418470444225, 60.36391196712371, 57.27937967546525, 56.89486580510294, 50.377098591096946, 49.71399053450554, 48.45113246671615, 50.567184494387725, 49.81182621371362, 51.96301875575897, 46.473916653663885, 48.75410418356619, 54.223684649313654, 55.18723449399395, 53.058434763262355, 54.35838668577133, 53.860131925152196, 58.30111395928168, 68.93604017073109, 68.75427753694596, 69.36517884654384, 68.34287581905242, 66.06279419314477, 67.25494369383782, 66.95358799349877, 74.85903878365794, 72.01920355519941, 77.50633270509782, 76.83989063385995, 79.9833643820978, 76.60497988423994, 81.04933907908779, 74.59878167798443, 78.18998613665181, 64.95144159563127, 85.41296020630868, 76.226165217738, 101.29015768727949, 35.34008064577657, 0.25630295817409793, 0.09055791287532738, 0.03275465993811527, 0.5427717008898335, 26.424843111345847, 89.17293640875047, 63.22404546122398, 58.99378491986183, 27.921333236079064, 53.2003814174283, 55.213428082004675, 0.829220433388987, 0.0712897367174587, 0.06908020890888668, 0.03258318647802357, 0.12951680098570165, 0.012274282747849584, 0.09554768867430188, 0.06738795898854733, 0.12453830200097254, 0.20730127790762534, 0.22664942598390966, 0.13952177138097827, 0.16927270398985955, 0.10804693409872633, 0.18481698037395555, 0.18659491722862567, 0.3567685252956806, 0.5779193245595502, 12.739687696579965, 91.72370864499001, 53.13580743728146, 59.76722924940048, 64.54653924511325, 81.8382610813264, 93.91895724881081, 6.998542912544743, 0.47561946715558734, 0.8408148983313192, 0.4230435577131087, 22.041145332397956, 109.56440541052051, 93.01356438667544, 94.39628616456064, 88.01877114080614, 77.99393823069911, 77.57277765581685, 74.28882029748733, 73.79109505684146, 74.28947141093593, 77.48938022121307, 79.2675082914291, 80.5558813771894, 80.73529058887114, 76.80016486875473, 75.8770428934405, 68.41955031118086, 67.56725065169796, 63.76458729467085, 62.63044180408601, 63.84132454472204, 61.54926007793796, 62.45689653581189, 63.68720285354122, 64.02461690287437, 65.33905806079989, 57.54744622015185, 54.338472812406486, 58.13723733348232, 57.58490485529746, 60.544768533399036, 62.39666854181598, 57.10689736950783, 63.547672379401426, 62.362944003074404, 60.958794316937855, 61.167707597055745, 62.28901124769642, 66.90150676235076, 68.49683669305617, 68.34625690214096, 61.137289616369436, 65.10457092715849, 71.52932305489817, 67.31286141180223, 61.08183514687323, 58.43034821171915, 64.85439431282782, 67.2655576275241, 73.15690271316036, 71.30017818943148, 67.64738467431837, 71.06510270026423, 63.91986216268232, 72.50327894764563, 71.25999742938627, 60.678964584104484, 60.73225782763574, 57.21118927001954, 60.161717707110995, 66.19668037660661, 69.08070502742645, 68.04343423535748, 67.62346606100759, 69.1732886529738, 64.28570947339459, 72.87373112094018, 66.52219003246677, 66.04899529487857, 68.88763027806436, 72.72791308741417, 67.04868978069675, 63.898069474004934, 66.41059860106438, 64.23076883439096, 71.5997374442316, 60.966305655817834, 52.070468164259395, 52.74636706998272, 60.11245273774671, 66.53638901249056, 64.47768203673824, 57.417090169845096, 63.05755261451968, 64.4667072449961, 61.8485055431243, 64.82083059126332, 60.027415752410896, 66.84798209897934, 63.51204156875611, 57.399447348810014, 53.2255865681556, 51.35855013324369, 58.50637159039898, 56.672679224321925, 62.67914587451566, 62.08725237077283, 58.57804113818754, 63.84515277801022, 60.82154666223834, 61.202753974545395, 51.69501496899513, 50.43511436831567, 50.393627459003085, 55.194051573353434, 52.35403591586698, 54.75671906625071, 50.007077878521336, 50.917028534796934, 58.6891265838377, 59.55524867580783, 56.150992224293375, 57.70843205913421, 55.779814412516934, 60.42441844940186, 72.5575880850515, 73.53240689923688, 73.12508444632255, 71.63588600773966, 70.65979634561847, 71.48233306023383, 71.05059777536701, 79.32791279208276, 75.51371374437886, 80.05682253068494, 79.93085169023084, 83.92790379062777, 80.3371935506021, 84.86899806607155, 79.01920657004081, 82.1933218740648, 68.20420434398036, 91.29729209407684, 80.47475107254522, 105.97642514013477, 37.09858902039067, 0.2938507046670683, 0.2608232446495564, 0.2470148775366045, 1.3853949957316922, 30.01245075656522, 98.80561074902936, 67.80864900158298, 80.13803912747292, 44.31676210895662, 56.85030767994543, 65.49764733160696, 0.6623307531399112, 0.264050834361584, 0.2766170971576245, 0.09321837535788936, 0.22828842513263228, 0.13228191873959957, 0.14120921793003238, 0.2884106836732357, 0.2626793531160201], [0.033526301999846776, 0.20651887231055768, 0.020418296297711712, 0.09741671338316896, 0.040969715694025646, 0.13467528466736117, 0.07370465269853031, 0.1037598907526943, 0.23802367129152824, 11.375160813331606, 65.1066380162393, 38.27053439232611, 44.94010125437091, 42.72063593710623, 66.22690616115447, 73.72548164859896, 3.019847259406121, 0.2951245556675619, 0.5622438786010588, 0.7025501240165003, 17.335299368827574, 105.62234493993945, 82.75648009392523, 88.41160435830393, 80.35994329760152, 75.20922799264231, 70.10723636996362, 67.63014977978122, 67.80955114672261, 70.46557626416607, 64.52289519771453, 69.87030952207505, 72.10065549419772, 71.59575231613653, 70.1767643036381, 66.21500569005167, 63.705579157798525, 62.72662616545155, 58.383805367254446, 56.94970838485226, 56.22894540909798, 59.117166996002204, 56.49578032955047, 55.611352535986136, 57.87555640743625, 57.433211111253314, 48.29775994823825, 48.115248141750214, 48.804196773036836, 53.168865173093735, 52.226876597250666, 54.335287847826564, 53.740825191620864, 57.984955233912316, 55.01152799975488, 54.38041471665906, 58.485892895729314, 60.44339095392535, 58.05507152311264, 61.62252995275683, 59.90916413645591, 65.51122265477335, 62.113971556386645, 60.46840783088439, 63.41607293775005, 56.51437628653742, 53.21065802727976, 55.1341099123801, 64.78556063867384, 63.98280051446731, 63.92096827107092, 55.16961912955008, 55.57162677088092, 70.03334676065754, 62.36699581146241, 61.33159598996563, 54.54579753260459, 55.18214717988045, 53.326999448960834, 50.32049486714025, 59.466010832017474, 62.85753919232277, 62.185103739461596, 63.044973573377064, 65.08030714527254, 65.43992180978098, 57.606999566478116, 56.168960602052756, 52.143690970636186, 55.85482581969231, 54.24360636741885, 58.03297288956181, 59.34822990048317, 61.364916524579456, 58.99261213118031, 62.299456519465295, 58.64218365761542, 52.086714621513124, 44.296581514420055, 49.80483262769638, 56.51826727774836, 59.587851416680124, 56.97440754982733, 56.44149080399544, 60.06437232417446, 64.07256787823093, 57.972670370532626, 54.25659725742956, 60.00028864029915, 59.71499112344558, 53.31062355349141, 48.01457658890755, 46.964742445176654, 49.88048730358001, 51.60026227274249, 52.909176811095215, 54.01371625161941, 54.93519475383144, 55.93495591994255, 53.481733029888524, 53.74443769454957, 50.38806161572857, 46.885443887402936, 47.404973583836714, 49.94888951701503, 47.81452394300892, 47.33871690688595, 46.06578227012388, 42.0482083289854, 51.402363008068455, 51.90970590037685, 52.58491446894985, 50.05987298104071, 50.41807559228713, 53.774110424903135, 57.961169981187396, 63.43328429806618, 62.256788976730846, 63.73220028415803, 61.709594803471724, 67.64248955634334, 68.99881378296884, 73.70182191171955, 71.6206907456921, 80.15213612587222, 77.25221018637382, 74.36007407403763, 74.09440409752631, 78.01294603655415, 71.98440428703063, 73.64290791173136, 65.60049187752509, 77.20484364417293, 76.87169321121709, 93.94442912070983, 47.349601484114125, 0.18665744532500544, 0.0651732907300034, 0.19734012774161755, 0.0745713432890273, 18.571495125370642, 79.57204895634806, 58.41589035526399, 58.248758162221606, 38.31454730802967, 37.55116778035318, 48.83993348767681, 1.5651236354343354, 0.142567660359125, 0.045105096613687855, 0.09893426461325538, 0.1009286136456555, 0.08449100213305605, 0.068298117407868, 0.03890044709307052, 0.10856676305974684, 0.028986813530566233, 0.04396264118352725, 0.05841062659577978, 0.11995693533531121, 0.05228448193520308, 0.15897331068352347, 0.1513695356345946, 0.1325564846516617, 0.392641450368589, 16.318981878219113, 71.22490790582472, 53.085126492284964, 48.38238900707614, 45.07235573184106, 76.45978158520114, 81.05111983514603, 3.3638459876660383, 0.38498550473201665, 0.4015451080856785, 0.6809086917388825, 18.614541176826723, 105.05445634165119, 86.26292997790922, 92.22932569442257, 84.58611672924411, 79.32336284268287, 72.64059328263806, 69.60077993331417, 67.19832820277061, 71.85264402820219, 67.27226488051876, 74.32329008656164, 75.55889944876395, 75.97705548809421, 70.24422907060193, 70.50054027188209, 68.18424732454362, 63.95806604816068, 61.442736348798206, 59.757407634489006, 59.02937650680543, 62.317193477384514, 58.23964257394114, 59.08966725872409, 58.191923018424745, 59.679536819458015, 51.958845353895626, 50.585247009031235, 53.661542323327836, 56.552603706236816, 57.49636519339777, 57.12184944460469, 55.6531689243932, 62.25716944663756, 55.51909054479292, 58.05571871419107, 61.433487399931884, 60.09011091724519, 62.94933834383565, 62.95366864050589, 63.17241530264578, 66.96256237645304, 64.10919889327019, 64.29395821786696, 64.646916620193, 58.61722561620898, 54.74905475493401, 57.31310029183665, 66.22944785702613, 65.64819574356079, 68.96495588364141, 56.49497624366515, 59.65398650015555, 71.05450445605864, 62.75889158248902, 64.34129338110647, 59.24492643725488, 57.891077226208104, 55.69470682451802, 54.142260166906546, 61.21754131009502, 65.51566670017858, 63.75516183914677, 65.42020405492475, 66.446896214639, 66.17814325517224, 58.54789380104312, 55.78703941837434, 55.037858870721635, 57.41104579740956, 54.73527546851866, 60.173967269159135, 63.37613536465553, 62.15785111150434, 58.34318137937977, 63.73316126485025, 59.912070612753595, 52.76351175000591, 48.7868598968752, 51.87610295511062, 58.48907393793906, 62.93658279603528, 63.02059212038594, 60.681412143092004, 63.3924328127215, 63.79784507136192, 59.91635384098176, 59.067529401471546, 61.732250413587025, 63.378735896079775, 54.383780110266905, 51.48088101417788, 49.26816217360958, 53.212077925282145, 53.314392951227006, 54.89030714957945, 57.471183576891505, 57.37650540567214, 57.502472323756066, 56.24055170243787, 56.787082995137865, 52.93857105316655, 49.77659156245571, 50.579469357767415, 53.1066720716415, 51.37737751007081, 50.80389561191682, 48.107152369714555, 46.45719166724913, 52.05564552737821, 53.72917575220908, 55.10112277923092, 52.08315703176683, 52.62551884497366, 56.21725282361431, 58.778219299931685, 65.04553925606513, 65.18782323406589, 66.71960292323944, 65.5757809454395, 69.8713920962426, 71.39538980299427, 75.7229486588509, 74.9218516195974, 80.76896805917063, 79.79280779438635, 76.57650347678893, 75.38094151404597, 80.23212109842609, 74.02618623548939, 76.37709802196872, 67.07437346058508, 80.42003400864141, 79.05622589972712, 95.68626742209159, 52.61550503392374, 0.14760379979927696, 0.13411493731602547, 0.6072116462934403, 0.25526071087487284, 20.924362213380878, 88.50309756494339, 65.08056602170392, 65.49562338859805, 39.85015130812123, 47.0581340789795, 61.05937565526655, 2.2730738212985377, 0.20306893323938693, 0.0607650331221521, 0.08260875474661589, 0.05887404084205628, 0.04147578571592608, 0.028581744540602933, 0.031020667802001682, 0.11021182962482977, 0.13193036099114727, 0.15182335079917986, 0.10952267224990553, 0.1717007430570741, 0.14074662339783486, 0.2445715779979383, 0.2761262493027795, 0.2748741551993355, 0.589176710815199, 17.571847707994525, 89.42627445344003, 53.843818787605535, 59.21342588240101, 57.06559088922317, 83.18316336601012, 90.34024946151241, 5.1933799059160295, 0.4832460256593843, 0.7713548706904535, 0.7961807772517205, 21.05147054118495, 111.0146390238116, 88.91410704581969, 96.51541725281747, 89.7285322989187, 83.01136355246268, 77.23198644576534, 75.50988551109069, 73.6950989692442, 76.72216461550805, 70.5069729589647, 78.24841376273864, 78.30761801811957, 78.48610939518099, 76.2894565828385, 73.73220459107431, 70.06547881710914, 67.59142814144012, 65.01586260334139, 63.40799677756525, 62.59262231088454, 66.56659126281738, 60.98980849789035, 60.123121584615404, 61.94472520582138, 62.06279639274844, 56.06737121458977, 55.21372618213777, 56.22931803426435, 61.293470551890714, 59.85793798200546, 60.59834810995287, 59.63217419962729, 66.17739016009916, 57.78121163768154, 58.94550446541079, 63.540008068084724, 66.06586933135986, 63.7195388732418, 67.43493341630506, 65.00646068203834, 70.75171316823652, 68.4556596509872, 66.49089736323204, 69.4235437147079, 61.22185591728457, 57.97620050368771, 60.59965425922025, 69.113951037007, 68.06926696531235, 70.84718365823069, 59.34574704016409, 66.69472725160661, 72.05557961617747, 65.81457876390027, 68.08399154293922, 62.32097856460079, 61.45482509366928, 58.28678946341238, 56.11523589780254, 63.691066388160955, 67.33251248636554, 67.85509770916354, 67.5472544085595, 71.16602528479793, 68.19741079884191, 60.111974208585686, 56.4291000366211, 58.72998199155254, 59.167887164700424, 58.794461834815245, 62.010405294356815, 64.72920402403801, 64.56120498718755, 62.89405253625686, 64.7437011041949, 60.00048475880777, 55.02097698949999, 50.57238163486604, 56.801380034415956, 60.896679662889056, 65.01014771000033, 64.87613601069297, 63.13148144752749, 66.26952663544687, 66.20919273745629, 66.82778973733225, 61.59208059310914, 63.650058008009395, 65.98244836253505, 58.15502528221377, 54.19776954958516, 50.74431873136952, 55.56093046742102, 55.78809061358052, 58.342016435438595, 58.579308063753196, 59.4120821645183, 60.68473831299813, 60.4997318790805, 60.34379020813973, 56.47920047083209, 53.237318377341, 52.94951446594731, 56.56531610796529, 53.75700104621149, 52.45068311691285, 52.74935591605402, 49.96948980516004, 56.37743457671135, 56.7287612730457, 59.806029335145034, 54.53847838986305, 56.64386549303609, 59.672354959672504, 63.73719738375757, 69.5864946611466, 69.35837745666504, 71.36745468262704, 68.32058106699299, 72.96588328576857, 73.20408098159298, 79.37306711750647, 77.65470027923584, 85.19163654696557, 81.5974981554093, 80.1480019477106, 75.58899187272596, 84.96006765673238, 76.1610617176179, 79.74735536882955, 70.19490918805523, 83.52196985675444, 84.42696263713222, 99.94239207236998, 52.60864088612219, 0.30744278983723733, 0.3022737188204643, 0.8937457516308754, 0.7381969918647121, 24.838061986431, 96.29767079507151, 70.46374059492543, 80.42579204805436, 54.3292042516893, 52.852463260773696, 71.5759757257277, 2.4671002357236804, 0.23300970243590496, 0.20831878056689618, 0.27631525851545796, 0.24985442839322552, 0.24029141412146632, 0.16141095649330847, 0.1741573572038643, 0.2957400307059288], [0.03394955791713249, 0.024201542987758597, 0.04017946535661336, 0.05444011545830196, 0.08579408704874017, 0.13611228175220952, 0.054350149922914086, 0.23237243985697148, 0.07976055475732974, 16.21099804678271, 62.27785602692635, 23.048390380797848, 49.736195072051025, 41.73342635554653, 73.12036975737541, 67.03609112770327, 1.2180116484242103, 0.1386168223595427, 0.18526649012440638, 0.5374958678599328, 14.732909721712913, 106.42467360342704, 85.34904910672097, 93.94738658781975, 81.58653120840751, 78.81095224811186, 69.34700258316533, 69.40752475492417, 64.94928036966633, 64.39078977031093, 66.5514430692119, 67.35349716678743, 70.12093328660535, 71.04902882729807, 67.78394591423773, 67.063900732225, 63.255134167209754, 63.99999618530274, 58.604787780392556, 58.20318022081929, 55.95458738265499, 55.17327477855068, 56.02726890194801, 55.91708167906731, 56.629733193305235, 56.13978601271107, 48.27841481854839, 47.55549846156951, 50.78391505825905, 49.45051708529073, 53.81692309533396, 54.92835806262109, 52.071507592355054, 58.6836156537456, 57.38927272058303, 54.085350498076416, 57.05766770147509, 58.05273379048994, 55.96768025429019, 58.32749974343085, 61.668088282308275, 61.2763572508289, 63.46441222775368, 61.94969484882971, 59.81368580172139, 57.98198599969187, 51.85791884699176, 49.52112367076259, 61.69128125713718, 64.25522481241535, 62.89537045263476, 64.21039996608611, 55.93800752393661, 56.85096663813437, 61.36628150939942, 60.015315240429295, 57.811508024892504, 60.11738707942348, 53.97386889303885, 59.689413347551906, 58.71455138729465, 56.57151345283755, 64.70861550300353, 60.549816623810806, 63.21547508239747, 66.31774825434532, 58.83929844825499, 52.57287279252083, 51.649994004157286, 51.60373357034499, 51.79087377363636, 55.21631102408133, 57.71207201865412, 62.536336298911806, 58.38762575580228, 58.231413441319624, 60.9468860010947, 55.81308787868869, 50.01489516227476, 44.35036113185268, 61.060238576704464, 61.24000472407187, 61.88519147134597, 62.66331518850019, 60.85715001629245, 57.85486982714746, 52.56303548812867, 57.87330888932752, 60.05968509181854, 60.16167848340927, 51.781334569377286, 49.762741673377256, 48.205529336006414, 49.883119213965635, 49.54446177328787, 54.78756458528581, 52.86192401762932, 52.77230178156207, 54.932959002833215, 52.79244707476709, 51.429443051738126, 51.22692323500111, 50.0444031530811, 47.788279364185954, 49.84866903674219, 47.647634936917214, 46.24426188007478, 44.99555572386711, 39.699489147432395, 45.93126850743448, 53.56196511176325, 51.68189464076873, 50.863931409774295, 50.38397058363884, 51.93370296109108, 50.40898746059787, 56.960604729190955, 59.508011571822635, 62.43481359174175, 66.42799039040843, 71.62955530228155, 70.59572835122385, 72.59736876333915, 74.18563058299404, 74.19302032839867, 73.3783205093876, 70.71298368515508, 72.52507948106336, 77.34633922576904, 73.92773474416425, 74.55771446228027, 66.80710315704346, 75.14291640250914, 75.71302506231493, 87.72310287721696, 62.0757519814276, 0.4189866318577721, 0.08582214884940656, 0.402640184808162, 0.4643217233880874, 13.921886144145844, 75.44508795584403, 59.53160462840911, 56.689721922720636, 35.71899337153281, 28.809169569323142, 54.174423602319536, 3.2825185839206945, 0.1510255008695587, 0.14060526485404662, 0.03792848070001891, 0.1367534667013153, 0.05531552795981688, 0.016698125456910462, 0.12393807977317803, 0.04307865232770001, 0.05216132181005613, 0.035435274363525456, 0.023201681418164123, 0.02920597404872458, 0.04103582525145143, 0.07772612400473126, 0.05162883324608688, 0.23995238957145523, 0.25887018009539575, 25.59433025698508, 70.38414785938879, 32.480886559332575, 57.28230184124362, 47.01951442226287, 83.8208152401832, 70.74786924546765, 1.6380593733441446, 0.09860314609062287, 0.24662461702621755, 0.6616100789077821, 16.518179447420184, 107.73623574164607, 88.19228110774871, 96.98050052888932, 84.54671259849303, 81.42959717781314, 71.45127573320943, 73.12539039119598, 67.5051595318702, 66.58839964097547, 71.2424801241967, 71.700926749937, 72.41038937722483, 73.93892918863605, 70.98882828989338, 71.27085455002324, 66.62401476214009, 66.1147185294859, 61.75221135539394, 58.13545657742409, 59.541818480337824, 58.20077580790366, 58.92893637380293, 59.61982657832485, 58.279882169538936, 56.58387284125052, 51.01325211986419, 51.60876597127607, 52.81448687276533, 52.7855593927445, 55.21187090104627, 55.909742924474905, 54.97952930388912, 63.31796269262991, 57.94371151155042, 55.10767705978886, 59.15897161729875, 61.496617947855306, 58.824126720428474, 59.66659299788937, 64.65842877664875, 62.811263069029785, 64.88194896328834, 65.25663729636901, 61.65666634036649, 60.71080246279317, 55.076776627571356, 50.518299994930146, 62.37772349388369, 66.08676771963796, 65.49749828154042, 67.44048749246906, 60.249398369942945, 60.906811145044145, 64.66151175960418, 63.56635855090234, 59.32335422885034, 63.354130867988836, 57.5669482446486, 62.344810885767785, 60.04836120913106, 59.024889315328295, 69.6673817788401, 63.32779999702208, 66.89438373811784, 67.70801667244204, 59.46305728727772, 54.09106539141748, 53.68067956739857, 53.06787983063729, 52.60976268399147, 54.8744176280114, 58.889908790588386, 64.74798041005289, 59.41415317596928, 61.68016918243901, 63.64809290055306, 55.41961923722298, 49.96961924337572, 51.76719834727626, 64.22472838432559, 63.93234314457063, 64.23429112280569, 64.05334434201642, 61.22595479411464, 58.08683879913823, 57.45759256424443, 61.97981080701275, 61.74242111944384, 63.287595702755844, 54.64409997386318, 48.51260385205669, 49.4916941273597, 51.33338812858828, 53.09284963915425, 58.070172648276056, 55.234357849244155, 56.132933632020034, 56.244073990852606, 56.125253631222634, 54.507487743131584, 52.804041600996456, 53.88479578879572, 49.96060563671974, 50.965893422403646, 51.41739353056877, 49.35634489982359, 49.0327101369058, 43.74005602252099, 49.19052670078893, 55.60599457833075, 54.50858208440966, 53.736224251408736, 53.65408589763027, 55.89479477174821, 54.292443798434356, 59.263749891711825, 61.02806337418095, 65.70659199068623, 67.8225185025123, 74.44642897575133, 73.81932043260144, 75.65848842743905, 74.77780649738928, 75.1173190147646, 73.3319502492105, 71.96280771686186, 73.84850286668348, 77.9030647585469, 75.61302815714191, 75.26497271753128, 70.04846357530164, 77.53837062466529, 78.93857832877868, 90.22276663011121, 66.10832506610502, 0.4942643311956237, 0.12577987005633692, 0.3954374874311109, 0.4676947778751774, 15.800049362644074, 82.91750123423915, 68.1848592142905, 63.388910524306766, 33.24681366643598, 35.888157352324455, 66.24406260828819, 5.922592647614018, 0.20377918867574585, 0.19128201168871697, 0.05192840426799752, 0.10922945209688718, 0.053350749921293995, 0.05412363304546284, 0.03163324702801484, 0.04321154559992495, 0.10619722246643036, 0.1513530187789471, 0.09892738514369535, 0.11204942940704285, 0.12347071251321225, 0.23492939620008393, 0.16504025206931178, 0.31617588573886507, 0.3150945985990186, 28.48072009701883, 84.72691412894957, 32.72054533804617, 65.35950537650817, 60.770869639612016, 90.64642183242306, 80.12868035224177, 2.6986894732521427, 0.1959481919484754, 0.6118098898760734, 0.9076749461312449, 19.07881840582817, 112.97078778666835, 94.10081401948007, 102.88846861931586, 89.1013531531057, 85.48170366594869, 77.59660997698384, 78.6170224220522, 72.16520201775336, 70.46840821543049, 75.50608865676388, 75.63321267404865, 75.63007477791079, 77.93418484349405, 74.9736661295737, 74.39899183088734, 70.69390527663693, 70.82422210324195, 65.41233578035909, 64.15198018473964, 62.6467941653344, 63.41926966944049, 62.57781144111388, 62.86010050004529, 60.56116404071931, 60.16795427568498, 54.06488357051727, 55.232345673345755, 58.551800481734745, 56.315547420132546, 58.88437824864542, 60.94368926940426, 57.73045224528159, 65.09861676923691, 61.28304881434287, 58.690589627911976, 62.78905460911413, 64.8020738170993, 62.16082819046513, 63.36309348383258, 69.89190609224381, 65.18536783033802, 66.42893175924978, 67.7519864420737, 65.77920682968633, 66.12593650817871, 57.70101093476819, 53.258769819813395, 68.87156424983856, 69.32590807637861, 66.75582993415095, 71.2500032301872, 62.04945641179239, 67.83844332541189, 69.29074010541363, 65.96421718597412, 60.9690591596788, 69.35367061245826, 62.29600483371366, 62.05338662670505, 58.42023634141492, 60.89538528073219, 69.51705301961591, 65.38696981245472, 68.95526762931578, 70.61308091686618, 59.275658207554976, 54.563377595716915, 54.66074651287448, 54.00947224709296, 53.989597597429835, 56.31129557086576, 62.208426152506185, 66.96788895514705, 60.581889844709835, 62.28135085874989, 61.965729498094134, 54.56091826961887, 50.69990965627855, 56.57484354511384, 66.31760704901912, 66.28953856806602, 65.22165759917229, 68.2986314835087, 67.09229084753221, 66.95293688005017, 62.16084387994582, 63.32847856706189, 65.84828761316115, 66.77351982362809, 57.823785043531856, 54.410165894416075, 56.43231245779223, 53.83022385258829, 57.00473531599968, 60.48338344020229, 57.059460224643836, 59.58700418472291, 60.11161335052983, 60.818455834542554, 56.977435619600364, 55.640966430787124, 56.41491282370783, 53.55785054545249, 54.32677630455264, 53.51075072442332, 52.537014484405525, 52.4634700436746, 44.86656073601016, 52.19418364186441, 58.078484150671194, 57.758736456594164, 55.752785359659505, 55.6603233275875, 58.76715821604575, 56.145406769168, 62.60355787892496, 65.84434955350815, 68.51762525496945, 72.74461453960788, 77.22900544443439, 76.77395559126332, 78.44275151529621, 77.58419959775864, 79.33269023895264, 75.1730166712115, 72.66132693136893, 77.93314933776855, 83.95106930886546, 78.28417008922946, 79.09032698600524, 72.22200578258884, 79.72881824739518, 80.59967071779313, 95.92839533282866, 69.64681286965647, 0.9981895214126957, 0.28419012143727274, 2.0506430729742973, 0.8516131221286712, 18.67458874179471, 92.15133328591624, 71.15269707095239, 73.55175987366708, 51.529475258242705, 42.69611327878891, 79.8171421789354, 7.415476643270062, 0.43015156662271875, 0.2723726942654579, 0.18892590827759237, 0.2536004604471307, 0.10028432604045638, 0.12032639655855396, 0.17486076381418014, 0.11110767752172486], [0.059079329423125715, 0.054871407637913386, 0.09563732862232194, 0.05611562635749579, 0.05987110427550732, 0.045885870443476785, 0.02767477113182747, 0.0839603943149409, 0.2872749430037314, 26.906429759917724, 56.775598295273326, 28.774201639236946, 49.66553357339675, 51.177242494398556, 78.43635805191533, 64.58960686960529, 0.4642759419737324, 0.1793222760240878, 0.26722020139136626, 0.31026073701439366, 20.519910935432684, 104.73548919923844, 81.21559266121157, 91.1704347979638, 78.18349853638681, 77.8993228174025, 71.00278408296647, 70.85224351575299, 59.34007921526509, 64.44604027655818, 64.73446392243909, 65.88333006828063, 65.3682836409538, 65.66269282371768, 66.4536819150371, 64.85340979791457, 62.64042815854473, 62.62140858557917, 57.99782845281786, 57.15953949959048, 57.272703801431966, 54.94994286567935, 55.492332135477376, 56.15460864959225, 55.427777767181404, 55.468856749996064, 48.82538933907786, 46.933524300975186, 47.2300672531128, 47.76364687950381, 51.83971512702204, 53.127609683621316, 56.45152422689623, 60.41295728375835, 51.5082513132403, 53.984784849228404, 57.20140687880978, 57.379404037229484, 55.38477290061213, 57.03390206060102, 56.19522087035641, 57.05420424861293, 61.14480095524942, 62.47653584326468, 57.76268628335769, 58.20469817807598, 52.19809032255604, 50.694673292098514, 53.044318153012185, 62.15059472668556, 61.058920660326564, 59.9692391580151, 64.28763927951937, 62.12913151710265, 64.56475473219349, 58.68334893257388, 56.2770022884492, 54.224061196850194, 45.93055463606312, 53.74547320027506, 60.65202182339084, 62.14248718753938, 65.00664111106627, 63.4903077156313, 64.574486132591, 59.965771782782774, 58.63722970408779, 52.079313108997965, 50.99519352759085, 51.23856090730237, 45.134686116249334, 48.741882078109256, 55.01839999229678, 61.06634962943293, 63.278899808083814, 60.55386058745846, 58.06054322950302, 51.955781982791045, 48.93422726661929, 42.99792397406794, 56.137550261712846, 59.822966129549094, 58.43676520932106, 52.949239900035245, 53.16607244553105, 51.10157212903423, 56.699425866526944, 60.097104503262436, 59.66074082159228, 58.34032981626449, 53.04681670281195, 47.60843869178526, 49.4326977575979, 50.528011783476806, 50.953310458890854, 50.36997556686402, 53.28926232553298, 53.53084894918627, 51.41927626825149, 53.8318516362098, 50.28626434264645, 52.44891412796513, 51.2604751894551, 47.390190170657256, 48.002836934981815, 50.328684776060044, 45.80809431691324, 46.25222821389475, 43.011605201228974, 40.994094879396506, 51.58427469192013, 50.67587729423277, 51.47823341431157, 51.537084656377, 53.466169065044774, 51.511451967300914, 54.301857486847915, 55.57117962068128, 61.60028619150962, 68.92187256966868, 72.87118158032818, 70.16180438380088, 73.36904802630025, 71.35798608103107, 73.84122294764366, 70.95442910348216, 77.18836184470885, 74.19996292360368, 75.19570366028817, 73.11244656962734, 72.71694614041236, 69.661757100013, 77.70688349200834, 75.65291081705402, 87.2594944123299, 66.02067578223445, 0.9250373789860357, 0.3340575729887332, 0.5415380541836062, 0.5484862265086944, 15.244155372342757, 73.75392667708859, 64.41012313289028, 54.24556755250501, 51.72742943609915, 30.0722865135439, 56.87477150271016, 8.723507177445198, 0.39309148105882835, 0.1375071593229809, 0.062341324143832734, 0.09527255585717578, 0.09416121508805983, 0.05448313895612956, 0.036817231861453865, 0.008711692362633205, 0.0570065904438736, 0.006116800303120287, 0.024395336419524207, 0.10586081793712032, 0.09130481029710463, 0.0425762020712418, 0.06650197064323772, 0.05130815267142269, 0.28075106081462675, 33.61389652375252, 68.94510869056948, 29.02193069458008, 42.609915271882095, 60.80311544479863, 85.97613411564981, 71.13750180890484, 0.3327190948109473, 0.2293325570081511, 0.31259365860492955, 0.17515052891066, 25.00280349485336, 104.81318350761168, 87.22023933164536, 93.85834878490817, 81.89627293617495, 79.69203425991921, 74.03138729833788, 76.19684157832977, 63.12441725884715, 66.76205081324424, 68.4119644472676, 68.69019385307067, 70.24244046980336, 67.6914878045359, 67.54376349910613, 68.21256683718774, 66.10589319659819, 66.01141898862778, 60.112566486481704, 60.97258929283389, 58.78193378448487, 58.70099567597913, 58.20172109911519, 57.91885545176845, 57.04841875260877, 58.6006457574906, 50.85944814066733, 51.30265243591801, 50.34401732106363, 53.37096921859249, 52.70591174402545, 54.80788638514858, 57.98662224123555, 61.99413922525222, 53.357111484773704, 59.12727886630643, 59.28305187532979, 59.050255283232666, 57.231734644982126, 58.59794716681204, 58.80095335745043, 60.252395060754594, 62.66117357438611, 67.11587213700818, 61.36738761778801, 61.114830124762754, 56.11762069886731, 53.46654561258132, 55.41826209714336, 64.08751210858746, 64.17940539698448, 65.08590044513826, 66.4020949025308, 65.31291938597157, 66.51918549691477, 61.014939123584384, 58.091463273571385, 57.805749985479544, 51.45394217583441, 54.89964631295974, 61.63937653264692, 65.30135623870358, 68.21551645955732, 69.48701550883632, 66.45084996377268, 61.39067865187123, 60.487203828750125, 52.16112198368196, 51.9289255142212, 52.730277507535874, 44.97612430203346, 48.87993381869409, 52.8345968646388, 61.46143036503946, 66.02816750926357, 61.92124197559973, 61.20966126841884, 54.30881969390377, 48.90789247328236, 47.78452173356087, 57.08831317963139, 61.48536074546076, 60.52465069678522, 58.68286648104268, 56.5250059097044, 57.840996403847974, 60.99818668057842, 61.43369136318084, 63.266026589178274, 61.09808160412697, 57.162347916633856, 51.00819618471208, 51.16875448534566, 52.866677930278165, 53.77726401052168, 55.8389009967927, 56.63123938345141, 56.49907512049521, 52.11239437903128, 56.132400189676595, 53.63285410788752, 54.998258621461936, 54.983090816005586, 50.13147584853634, 51.28181680556267, 52.27179165809385, 48.57300835271036, 48.442071791618105, 45.668403025596376, 44.218177257045625, 53.31723274723176, 53.15227354726484, 53.39214609515283, 55.26841971182055, 54.60182859051613, 54.08154187663909, 56.54548460437406, 57.72482756645449, 65.15901342515023, 70.77355292535597, 74.7698127069781, 74.52091478532361, 75.82356529851114, 74.62931340740573, 76.13308737354895, 73.14412363113897, 80.10480096263271, 76.83333243093183, 79.33716174094909, 75.4884615252095, 75.63708013103854, 73.04094176138602, 80.23972265182003, 78.64635390620079, 89.92503519981139, 70.4746526287448, 1.1692520519418101, 0.31935873591611463, 0.3115782550265712, 0.47454047827951373, 16.192401109203217, 82.36818113634664, 70.99065611439367, 64.19397700217463, 49.22288233234037, 34.71461165335871, 69.45831944865566, 13.240037002871114, 0.6028591024298823, 0.2404421955467232, 0.09567738735988256, 0.1079572098810346, 0.06473390100103232, 0.03900485721627071, 0.06743494316094345, 0.02216193156557218, 0.10440630042144369, 0.2014572221425272, 0.23798492256431814, 0.2586298736353075, 0.21065403106472186, 0.12985009519803908, 0.12353727789295298, 0.30753996042955306, 0.3338988702143392, 40.52935677189981, 79.64319290653353, 40.10211260088029, 61.45464074227118, 69.76853970558413, 91.99214781484297, 77.50480298073062, 0.921146632923234, 0.2767182207636295, 0.5485726412265532, 0.3280331188392255, 26.575595486548643, 111.74746328784575, 90.21933847858061, 101.53818484275573, 83.96648422364267, 86.42223312008767, 78.90082159349996, 81.42758107954457, 65.89309677000969, 72.5825814277895, 71.67829467404273, 73.03829023914953, 73.40455332110005, 72.32376775433941, 71.18684522567257, 71.92588252405967, 69.49937881961947, 70.5047607421875, 66.580672571736, 65.80454141862931, 63.627104297761, 61.55192728965514, 62.99545757232174, 60.99085969309653, 60.6118175291246, 60.98237560641382, 55.30045763138802, 55.46206712722779, 53.05514781705795, 57.508803029214185, 55.04680187471452, 59.23069215589955, 63.67447476233206, 65.38603236598354, 53.15122235205866, 59.42781086890929, 62.04474564521544, 62.848203951312655, 59.99296165281727, 61.84212776922411, 62.46250160278813, 64.41476329680413, 65.69447186685377, 68.65171540168025, 61.76058561571183, 63.23939761807842, 56.816889086077296, 57.508767727882635, 60.1545044683641, 67.3875198056621, 67.35782746345767, 67.09328712955599, 70.42398345085883, 66.64790984122985, 67.15875148773193, 68.06941601537889, 59.62228590442289, 65.41573255292832, 56.744454676105136, 61.57340618871874, 60.076088443879165, 63.5859586346534, 70.2814131398355, 68.51460502993676, 68.83503913879395, 61.2646960443066, 61.4624305694334, 53.256577214887066, 53.91753189025387, 52.66916698025119, 45.29165152580508, 50.69432812352335, 57.185627183606556, 64.04870417810255, 67.15804546110093, 62.145742754782404, 58.226008415222175, 55.85587309252832, 50.02288503031577, 45.748678253543, 63.60580582772533, 64.22806632134223, 68.77873743734052, 61.746798484556145, 62.033049137361594, 59.60798494277462, 63.23335716801306, 65.3495111773091, 65.98605694309359, 62.37225178749331, 60.295035146897845, 52.88790579765074, 56.40458522304412, 55.517184272889175, 56.41510894221645, 57.769040523036836, 59.491168914302705, 59.55582526422317, 56.32600053664177, 58.778948860783736, 56.0966673974068, 56.08564161485242, 56.62389278411866, 52.57405734831288, 54.35760221173687, 56.64411652472712, 51.35542792658652, 53.013045095628314, 49.57271852800923, 47.2007240018537, 58.387053089757124, 56.49882408880419, 56.65567574962493, 56.24169311215801, 57.78737760359242, 55.434049637086936, 59.72506769241826, 61.48392123560752, 67.90866944097704, 72.78195550364833, 79.11101356629403, 76.32750357350996, 78.54492925828504, 77.60475281746157, 77.88622994576731, 74.50542142314296, 84.59283182697912, 78.81309386222594, 82.7294392739573, 79.27863997797813, 79.31977779634538, 75.91005356081071, 83.08109544938611, 81.9905980940788, 95.43864819311327, 73.21577748944684, 1.7295547863168104, 0.33612426370382315, 1.4974708398503642, 0.7591974843413599, 20.36247091908609, 89.62978270746048, 77.85955782859557, 73.5108103290681, 75.60018631719774, 46.617306740053245, 81.11582325350854, 15.434404053995687, 0.767971765129797, 0.4312828946257792, 0.1398282525159659, 0.2362481093094234, 0.22737494189172025, 0.17912499306182708, 0.19081547946458866, 0.14430235921134874], [0.07365088098712506, 0.041854443824699814, 0.10829279469626565, 0.09957671360743624, 0.09799160108330751, 0.14196064293144212, 0.014554372999907262, 0.26702920035008465, 0.1181552880593846, 29.00877114265196, 46.82407056131671, 52.230014493388516, 62.05723054947392, 46.73004350354595, 81.49522627553633, 60.166797176484145, 0.21559762708362074, 0.08084021012989745, 0.13455278720826874, 4.452074496976791, 61.33540853377312, 91.54342082238968, 84.96409985326952, 84.65760584800475, 78.47902559464978, 74.70215966624599, 69.52588619724398, 66.02127198250064, 63.89728892234064, 59.289390425528254, 58.42195433955039, 57.71531581878663, 59.28711545082831, 65.01054386938772, 61.48150897795155, 64.3346018175925, 62.71781652204452, 58.910928772341826, 58.70134084455429, 56.01741198570498, 55.69238085900584, 54.64489621500815, 57.372167264261556, 54.1657433971282, 57.72940105007541, 53.140373076162035, 47.19074156976516, 49.45860501258604, 47.00783752625989, 50.838851774892504, 52.63425788571758, 51.84044076550392, 56.20999643879553, 55.16339040571644, 51.83449052995252, 53.864697564032774, 57.808495644600164, 58.11048676890712, 57.11250635885424, 52.99840288777506, 53.55322607101933, 54.02602072684996, 54.58173428812335, 57.1280546342173, 55.426942302334695, 55.74647426605225, 53.61214791574786, 51.354568927518784, 48.2992543712739, 54.343414998823604, 59.340910757741625, 59.87043465337446, 60.172578750118134, 62.19772592667611, 66.4535956228933, 63.195267031269694, 58.15030667089648, 50.72988833150556, 46.754781892222745, 49.75731311305877, 42.1941714902078, 59.16509051476756, 58.927065403230735, 63.38888306771556, 57.80013707376296, 48.740874028974964, 51.56375285117857, 49.13424461118637, 50.70386732778242, 46.93191220683437, 44.42242683902864, 39.803431956998764, 41.49668385905605, 49.650781539178666, 67.90040892939415, 58.167141483676055, 56.448060774034076, 51.001567379120864, 42.21335972509077, 48.603430255766845, 52.41814313396331, 54.19711451376639, 51.970275140577755, 57.328734859343506, 58.976471577921224, 59.97309877026466, 58.744753637621486, 58.3846761334327, 58.99066663557484, 60.71008859142181, 51.656089367405066, 47.988006453360285, 50.246597413093816, 50.06874930474066, 50.936585472476104, 51.54565895757368, 49.90902254658361, 52.05227621140019, 53.58998652427427, 53.57046881029683, 53.00987582052908, 54.03102567118984, 53.41771602630616, 47.4395885006074, 48.08529300074424, 49.60643914438064, 47.727784649018325, 46.05752960328133, 44.98192548751832, 41.094844879642615, 47.555945611769154, 53.769458493878766, 50.81976552163401, 51.13319819973361, 52.57153918666225, 52.93521350429904, 53.65528222053282, 53.704672705742624, 58.847174567561, 72.76105711537024, 72.14161288353705, 72.33848448722594, 70.87693875835788, 73.82615320144161, 75.79763843167213, 74.8059691152265, 76.66597274041946, 76.27956436526391, 74.57956206414008, 75.42099675824566, 71.75725198561146, 71.60483652545561, 76.45812634498843, 80.10611887901061, 84.22351714103453, 72.20650457566785, 1.5440879642002046, 0.22139487487654533, 0.6357295450664336, 0.5714190378785133, 12.962299854524675, 71.47757130284464, 66.26357247752529, 51.92956486055928, 42.88556768048195, 30.43135400741331, 52.92734915210355, 16.816579641834384, 0.5516906190783747, 0.24426160350201592, 0.05516228739232306, 0.08400694181722018, 0.12203743095479666, 0.10889020538137806, 0.04871985950176755, 0.06600560695533791, 0.011623790788073695, 0.017365248227912574, 0.05838897312059999, 0.03975184656859886, 0.03915133322739313, 0.15175135385605598, 0.09491034182569674, 0.23090885952115062, 0.016409542051053817, 37.00234974584272, 56.802968594335745, 51.94559166508337, 47.06962270121421, 56.41869791092412, 87.77723943033527, 67.34118092444636, 0.05552766536692939, 0.2331647739535378, 0.2604236531882517, 5.296853992246813, 67.86694326708394, 94.28146270013626, 90.3951391097038, 88.34260202223255, 84.2872948800364, 79.47195006955054, 72.7158635662448, 70.06996600858628, 67.50817975690289, 60.6766386185923, 61.685986057404556, 59.4610764903407, 61.59236300376154, 66.82151394505655, 64.8304953113679, 68.84223276568999, 65.54035802041331, 63.09194787856072, 61.1091701446041, 60.535947122881495, 57.73297825167256, 58.48290404965801, 60.54862814564859, 57.511156451317575, 59.34763762258715, 55.81829678627753, 50.087808101407944, 51.1456399579202, 51.17955669280022, 52.88907858633226, 55.39013085826751, 54.538454855642016, 57.25765366708079, 57.48160531443935, 52.42006901771792, 56.432139873504646, 59.07824139441214, 59.352838685435636, 58.677116286370065, 56.61521257892732, 54.999596149690696, 56.126296981688476, 56.30846754197152, 59.18137619572302, 57.894136674942516, 59.74533457909862, 55.23472655204035, 54.08511907823625, 52.92230106169178, 57.32220019063642, 60.634681024859034, 61.04463146578882, 64.4189759223692, 65.79759490105414, 69.43984508514404, 65.62473996993035, 59.539143423880304, 55.332774039237734, 50.92954874038697, 52.01897528863723, 46.27918666408908, 62.88619210643154, 63.11765509267008, 65.59536533970987, 57.104049728762725, 49.040582333841634, 51.865485099054155, 48.493129284151145, 51.17927035977764, 48.45672184421171, 44.804861853199625, 38.6822969682755, 40.895706145994126, 47.61823677247571, 68.10771403774139, 60.93364800176313, 61.97584921313871, 54.67741266373665, 47.4506966529354, 53.605636781261815, 51.11844224314536, 56.44496994633829, 59.13951273887389, 61.953946698096495, 60.89806425955988, 62.37137709894488, 60.46938842342746, 59.87165058812788, 61.97872038810485, 61.17394024325956, 54.47963107016779, 52.12266706651258, 52.33696968324723, 52.2991305781949, 54.706520572785415, 54.557980414359804, 54.70423383097495, 55.19431437215498, 56.862890643458215, 56.6196644690729, 53.663111271396765, 55.72893342664165, 55.258821672008885, 50.800236040546054, 50.584050686128684, 52.83770338181527, 49.809613996936434, 49.43347046452184, 48.18028496157739, 44.503282577760764, 49.18654157269386, 53.63151657965876, 54.73745630633447, 52.238608406436065, 55.348514510739236, 53.269842670809844, 56.511677695858864, 56.32454141493767, 62.040878188225534, 73.38147409500615, 73.44813085371449, 75.0138625790996, 75.23313876121276, 76.03602440126481, 78.43529901196881, 78.90013125634964, 78.43711899172875, 81.1480337573636, 76.45864409785118, 77.3153446566674, 74.49103416935091, 74.74807493148312, 79.0770850643035, 82.65831101325251, 87.54414866047522, 78.04820029966294, 2.17489444440411, 0.14423262988848073, 0.4318264493298146, 0.4140264576961918, 11.139706815442732, 75.35302208315942, 73.44052930032053, 62.10691521244665, 45.199707246595814, 36.250152895527506, 66.7849809892716, 24.069999148768765, 0.39905136931807766, 0.3259590430365455, 0.047158955356046084, 0.12677762296891984, 0.08320329260201224, 0.10477445929521516, 0.012488696393707107, 0.031198063121748068, 0.28638723096059215, 0.22122322521623106, 0.25105646631169704, 0.2297024549015107, 0.20036298811676043, 0.2838537475514797, 0.19544674143675836, 0.299068100510105, 0.3551368805910311, 50.28057298352642, 63.7467836564587, 68.96545794702345, 81.0511355246267, 65.54259377141153, 94.32732305219098, 73.65991530879852, 0.36244882210608453, 0.3604959720565427, 0.45868006805258416, 6.151080516076857, 71.07616378415015, 96.19664622891335, 94.78547942253851, 92.78130515929192, 87.09748483473255, 81.80193993353075, 78.06910653268137, 73.22843105562272, 70.99563752451252, 64.54027914231824, 65.12740304393154, 62.213842945714156, 65.1969192104955, 74.13955842295002, 69.70615048562327, 72.67531410340341, 70.23629019337316, 65.6005311012268, 64.99134386739424, 63.788764784413004, 61.73615317190848, 58.64301520009195, 64.23252213385798, 60.90663856075656, 64.23121990696077, 58.72534575000886, 52.42455228682488, 55.689133136503166, 54.29498157193584, 56.63263182486258, 58.83949848913378, 57.081319593614154, 62.66698260461131, 60.17017825957268, 54.186512347190614, 59.10461148908062, 62.96004641440607, 62.646194042698035, 63.56859037953039, 60.591162327797186, 59.12289365645378, 60.79621599566553, 61.20807270849905, 62.91126389657298, 62.61432086267779, 63.387612219779726, 58.942594066742934, 55.99913766307216, 54.66545335708126, 62.634360251888154, 63.0852210137152, 65.15132950198266, 67.46829709699078, 70.50274464391893, 73.67216879321684, 67.28367113297986, 64.19398876928514, 57.652585352620775, 52.94414866355158, 52.813867138278106, 49.704694517197154, 60.9622303132088, 62.48244685511436, 68.61555899343183, 59.91085467800018, 50.54097129452614, 52.96347025902041, 49.89814581409578, 53.094755911058, 48.76768735147292, 44.51130382476315, 40.30178477687221, 40.33794510749079, 50.11094616305444, 72.03037446545017, 65.9305004919729, 59.54805897128198, 53.02610658830213, 49.21378635591077, 48.48984626031692, 55.21106681516094, 59.01016081533125, 60.22014925556799, 65.24081445509388, 64.27288724530128, 66.4452958876087, 64.65971531406527, 63.178844067358206, 64.80212480791154, 63.73589907923053, 56.19460898060953, 53.09638369467951, 54.897457630403586, 56.65848024429814, 57.82542067189371, 57.48477851190875, 55.96024344044348, 58.09007475453039, 60.164231946391446, 57.975631760012725, 57.675919532775886, 60.282911100695216, 56.640515788908935, 50.55438972288563, 53.34327336280577, 52.97028341600972, 53.01191545301869, 51.64576568911153, 51.439229365318056, 47.61867607793501, 51.86306891902801, 58.056212932832786, 55.59111310589699, 55.122750728361076, 59.59752005915488, 57.76106242210635, 58.93990724317489, 59.90124094870783, 63.92709501328007, 78.43214542635026, 76.44846946962419, 77.63214665074503, 76.59257734975508, 80.12056104598507, 80.92372909668954, 80.71709079127159, 84.28252527790686, 83.46046709245252, 80.99033094221546, 80.69634929780038, 78.4532948463194, 77.35734539647257, 83.84812278132286, 84.48943814923688, 92.4416357471097, 81.44770283852854, 2.593309115017614, 0.23607221552200858, 1.8750933509680534, 1.0440524475228403, 17.060756990986487, 84.42799029811736, 80.40623511037519, 70.30973265247961, 64.8793484318641, 48.8302295438705, 77.10979677015736, 27.626563195259344, 0.6661877300470107, 0.5556076572787377, 0.16844434843909356, 0.20294085866020573, 0.16502699874822171, 0.22622415525538309, 0.09037045116025595, 0.21163578806144578], [0.01392696614211966, 0.0066579269872407525, 0.0076270167201366885, 0.03502937799860393, 0.09803270170044515, 0.047795543777606184, 0.03262082820818309, 0.07251455809079832, 0.1262767623449045, 28.550165660919685, 43.16269490026659, 27.725424574267482, 44.50651461078275, 53.79400076404695, 78.14686359897738, 60.32628074769051, 0.08148082051306002, 0.24241517838691515, 0.07380900153469655, 0.538764754610677, 56.33912870960852, 92.67937060325377, 83.42069425890523, 84.05329412029636, 76.57148284296836, 76.28711885021579, 72.80103391216647, 65.76226219054192, 63.666692779910186, 57.498498962771514, 56.96813960229197, 58.05019993935862, 57.91429765762822, 58.95132134037634, 58.15236983760711, 59.37527072045111, 58.814430621362504, 59.76560931051932, 54.395029467921105, 56.50504496789748, 53.8360171933328, 55.42455750126993, 54.609841992778165, 56.301854425860995, 55.1086772641828, 54.32917287272792, 46.16697549819947, 47.30726734284432, 48.82500886917115, 48.36240845341837, 51.70828434728807, 51.264268121411725, 55.61835396674372, 55.532485438931374, 49.92821470383675, 52.62778597493326, 53.901960080669774, 56.64340265335576, 58.73149994880923, 55.42938986132222, 51.15245703727969, 54.30411677206717, 51.992616961079264, 53.33198478144985, 50.89651453879572, 51.366814567196755, 50.89148998260499, 45.875994466966205, 48.29719120456327, 48.580147066423976, 52.231155903108665, 56.887915365157596, 57.7286087313006, 61.652206605480565, 60.13172334240329, 60.697740970119355, 56.004766264269435, 50.85297622988301, 46.698837126455004, 48.78725213389243, 48.24055217927503, 46.69705637039677, 54.7849718986019, 54.56866887307937, 45.54629571976201, 39.894831026754076, 43.94828288785873, 45.040639446627715, 47.86255336576893, 48.31302973531908, 44.64949677067418, 43.59239055264381, 43.9505696296692, 41.85568663381761, 54.062694887961115, 65.27300142472791, 49.45233314268051, 55.439062426167155, 43.406105426050004, 48.19485264439737, 51.43627189820813, 53.573383131334865, 60.66698174322806, 60.25516425409625, 60.47182813767464, 60.41735033835135, 63.250388099301254, 62.975994771526715, 61.63807038337954, 57.1606848316808, 53.182695450321326, 49.26562832247827, 50.27092003053235, 49.832383355786725, 50.55571548400387, 48.571235441392474, 50.57339752874067, 50.928383796445786, 54.55274405017976, 54.23536154531664, 55.61565929843534, 50.950043124537316, 52.81103910938386, 52.70470365401238, 48.9822566893793, 51.63732867087088, 46.704328444696245, 45.907926482539025, 44.495277020239065, 41.99680174550703, 47.00666473757836, 52.97509224184098, 50.78085953189481, 51.93573474884034, 51.76724541571833, 51.33725950794836, 51.26878276948006, 52.29515329484017, 52.79425136504635, 60.74524871764645, 65.37225700193837, 70.28670049482777, 69.02689010866227, 72.92094861307453, 76.65320934787874, 75.31480250820037, 74.44103179439422, 77.87489429596933, 76.62048109116094, 71.99978782284644, 70.7638725157707, 72.32222234049152, 75.3428788338938, 80.75990738407259, 81.14307588146579, 79.66019245886034, 3.2691428113368253, 0.3742413054550848, 0.25940092580933727, 0.5018174678327576, 2.6026210669548284, 58.08070028981855, 73.26636037518902, 52.26534720390074, 43.52237624506797, 21.68475289498606, 49.670860152090754, 24.958727821227043, 0.259154214854202, 0.09752248714287436, 0.18164617309887565, 0.04582411226546092, 0.014407947742109819, 0.08669892881786631, 0.011385102688725437, 0.025816427603844675, 0.025603506871829593, 0.01887546608134383, 0.027981597006381042, 0.08006390259270707, 0.1168302623855491, 0.1463107812789179, 0.0543930699988719, 0.014520563624588954, 0.11231045088460369, 41.535021105120265, 54.22508493546517, 33.6285779553075, 45.55305396356891, 61.92108115842266, 84.65140850313249, 67.38689222643453, 0.17685734216243992, 0.19733554653583035, 0.08499378563776132, 0.47378772028511573, 57.16105745684717, 94.26352962370842, 88.1422395090903, 88.94841209534677, 82.9385643620645, 80.55199823071881, 76.26854250507971, 68.13615122149068, 66.21321708925309, 61.98897346373528, 59.605694278593994, 62.84521902761152, 62.144405226553644, 62.10333016610915, 60.875467484997166, 62.94332535036149, 62.127131108314764, 63.86880467014929, 56.652639835111565, 58.64632960288756, 56.76261132763278, 57.333728036572865, 57.56376328006868, 58.155746998325476, 58.04248463722968, 55.63953476567423, 51.30274265043197, 50.104082015252885, 50.342232642635224, 52.31251370522284, 55.44523623681838, 52.7743374916815, 59.803056178554414, 57.576530594979566, 51.307445572268584, 54.26321037354008, 56.12711283468432, 58.79607000658589, 60.03134988969373, 57.3300527757214, 54.39275057085099, 56.001804874789336, 54.1049898055292, 55.56590011042934, 53.21340760877056, 53.76392402956563, 54.1512345498608, 49.29806632380332, 51.4127141429532, 52.250567713091456, 55.8346805264873, 58.64084220701649, 59.76538181304932, 62.721554540818744, 63.541808435993815, 64.31073419509396, 58.574997378933816, 53.06140791985297, 48.176539098062825, 50.839616637076105, 52.30548089550388, 50.50665055551837, 58.089215755462654, 57.373806814993586, 44.00258810289445, 41.70783681254233, 43.633253805098995, 47.09712636086249, 50.002476938309215, 48.96356659550821, 44.1763844028596, 42.87751505451818, 43.39187114469467, 40.629993023410925, 54.98473428910779, 66.22507049191383, 52.43040838549214, 58.35122223823302, 44.74203332777947, 49.28396148066367, 52.67878070954354, 53.58685647287677, 63.37383685573455, 61.84963518573392, 61.77418055072908, 62.54041164152084, 64.02015716798844, 64.6880622833006, 65.68175946512531, 60.23961205636302, 56.17482454546037, 50.75026896692092, 53.06508318070443, 50.70207480461367, 51.1621178350141, 52.169249134679, 53.312325862146196, 54.870714910568736, 54.90246649711363, 54.94956239577263, 55.85225274485927, 52.028808670659224, 52.79804429700298, 55.02976702105615, 51.472318480091715, 53.93940302633471, 48.94971278405959, 50.0290862975582, 49.26804450250442, 43.512731136814246, 49.96729327786354, 54.88576112254974, 53.43962638608871, 54.15559230312225, 53.89133830224314, 55.15370215139082, 53.996336229385875, 53.1393297256962, 54.23190593719483, 62.26961512719432, 66.78454168381231, 71.89640198984455, 70.5680364178073, 75.69207960559477, 76.9010482295867, 77.96946264082386, 77.83707480276786, 80.23042663451164, 78.178085665549, 75.69843384527391, 73.8747670573573, 75.73222114193824, 76.83187330922773, 82.86180357779227, 84.83273967619866, 87.87905631526824, 4.620880561490213, 0.28980220577889876, 0.15963856611521016, 0.573458363932948, 2.302426633334929, 62.60593091287921, 81.33024354134837, 62.179259407904844, 50.40622611199656, 30.94342531696443, 64.55030472047868, 31.480280122449322, 0.2632917638026899, 0.07900270227823528, 0.05947382256929433, 0.04626403059509974, 0.04619979795308844, 0.07177395025087942, 0.051759049041016456, 0.0692386741960241, 0.12462847054966035, 0.13643233796521542, 0.11859499188440463, 0.1944554389844979, 0.2310730628068409, 0.21569845957621453, 0.19981178785524062, 0.2076254403519054, 0.17420627957870885, 53.163393466703354, 61.86304576935307, 37.53019486704181, 64.24234767113963, 68.34504881212789, 91.04291069892146, 75.54204894650367, 0.7513237552296731, 0.7653918261489561, 0.27237756658465634, 1.6509296504720565, 67.0039826054727, 96.121885853429, 92.76432914118614, 94.58861566358998, 89.549146621458, 85.18827115335773, 83.4252049846034, 72.79877462694722, 70.01123243762602, 64.6903568698514, 63.61982830109135, 65.89450882327172, 64.43086462636148, 65.71432298229587, 64.26345394503686, 67.10001007203134, 67.81252430331323, 67.09075327842467, 60.8451710977862, 62.50999758320471, 60.40613235965852, 61.26792023258825, 60.57672016082272, 62.29925647858651, 61.10556548641574, 59.24019605882707, 54.80431702829177, 54.04745647984167, 55.238103712758715, 55.314193771731475, 57.61979041561004, 56.31598280322168, 63.48596565185055, 59.084438739284394, 53.13476016444545, 56.47875724300262, 58.63162071474137, 62.02581628676384, 64.3435565886959, 62.00376472165508, 57.96027568078811, 59.25693673472251, 57.78038401757517, 58.56279488532775, 56.131003825895256, 58.489972160708525, 57.14436384939379, 52.16343618208363, 54.9475698317251, 55.57515690403601, 59.95783290555401, 60.56338017986667, 64.73495421871063, 63.744336097471184, 67.70409430226972, 67.05403204887145, 61.91144781727945, 54.82021831697034, 52.57981146535566, 51.0336249105392, 53.76488501025785, 51.851913698257945, 57.50339015837639, 58.55305564018988, 46.41564592238396, 42.98950264530797, 43.875016935410045, 50.76673899927447, 50.04714881220172, 50.02297916719991, 45.92019565643803, 41.380420884778424, 44.00936203618204, 41.09997141745783, 57.62190065076275, 69.91750347998835, 53.51921127688501, 56.532517248584384, 46.96960226182015, 49.76650322637251, 53.06507925833426, 54.44105455952307, 63.32987493084323, 66.62372450674734, 64.9182975676752, 66.2666868394421, 66.60237112352925, 67.95840509476201, 68.56447404430759, 62.71637701219129, 57.7779011572561, 54.73649924801242, 54.8127854254938, 55.72723896272721, 54.48096467602638, 52.5911824164852, 55.66301015115554, 56.85622653653545, 58.95240783691407, 58.97638528577743, 59.48974509393016, 53.46836559234127, 55.23948830942954, 57.92736699504238, 54.39062856858777, 57.70654539908133, 51.88089216909101, 53.9000577311362, 51.25571735443608, 47.76514522490963, 53.637407979657574, 59.018507619057935, 57.975969083847545, 57.24556492220972, 55.83009135338568, 57.33200611606721, 58.35015927591632, 55.511712566498794, 57.50177021949523, 68.28451095088836, 70.85858206595145, 75.81490470517066, 73.71135327123827, 78.89507139882734, 80.22457445821455, 82.44849558799498, 79.87801736400974, 83.95456806305917, 83.23481313643917, 80.08070976503434, 77.78061620650753, 78.22252611960135, 80.11688970750379, 88.87453817552137, 87.86845807106265, 91.10833583339569, 4.60291757698982, 0.4248400645390634, 0.6418966141439254, 0.8588370248194664, 5.401500867259118, 71.72401382077125, 86.65178591205229, 70.0910448258923, 63.41753205945415, 37.144825919981926, 73.65375718762799, 38.067057517267045, 0.4634953290224076, 0.24610334015902013, 0.30074960221686675, 0.1568130806328789, 0.14079700133973552, 0.17515503350765477, 0.08305880841949294, 0.15117252846398663], [0.06491798426835768, 0.022628314402555267, 0.06978091888970907, 0.05046017760891588, 0.04836492713600878, 0.05157545990040226, 0.05658719177928664, 0.03262385808592362, 0.11967136840065641, 38.26816528074203, 42.83323934001308, 39.81655620759533, 44.302143435324396, 57.28410613152289, 81.81257740143808, 53.88536453247071, 0.391315873111448, 0.07720076388889745, 0.37939107105616604, 1.30802268943479, 26.3617439423838, 100.95304566044962, 75.93343088703772, 84.75306849325858, 74.46211845644059, 72.53223388425766, 71.39583695319392, 72.21984063425373, 66.9138857626146, 64.93228866207984, 55.16512801570278, 58.71438664774741, 54.6737648594764, 56.454481694006155, 54.59082634218278, 57.04063284781672, 55.403262953604425, 53.9289185308641, 55.58815563878706, 57.36221228876422, 56.69759804202665, 55.82359590838033, 56.91066511215703, 56.33518280521516, 54.59212464670981, 54.466785307853456, 47.17811546018047, 46.77571950420257, 47.1674701475328, 50.34642957871961, 50.556790213431086, 51.48127717356528, 53.74590073862384, 56.53862045657251, 51.19777217988045, 50.84131894573089, 51.27201088013188, 56.67762141073904, 56.63105895442348, 52.83838587422525, 49.428092895015595, 53.34808218863703, 53.97206460275958, 52.00957728970436, 50.15508067223334, 52.315573153957246, 54.03748581486364, 52.62876656747634, 48.54532426403415, 50.48963923608103, 49.46311573828421, 52.287759627065356, 56.04701411339545, 60.11716742669383, 57.60795270242999, 61.32921511127103, 59.36552755294308, 53.054155457404356, 49.12110074873894, 43.29678896934756, 46.874178840268044, 42.46432081345589, 48.83717606144567, 50.456271633025146, 37.66138245982509, 49.67022080575266, 48.379835544093964, 40.21560638181625, 45.316958658156864, 45.14779467736521, 42.134245518715154, 47.352649165738015, 41.720506068198915, 44.809976623904326, 44.02477302858907, 60.54257592847271, 49.53291431550057, 49.707801034373624, 47.56738324319163, 44.98807968631868, 54.04698579542099, 52.13725828355359, 59.365264754141535, 57.7604034639174, 59.294681702890706, 58.49041146616782, 62.023529544953384, 55.737170404003514, 58.85967123893, 57.92105590143512, 49.533577196059696, 49.21494737748177, 48.829445069836034, 47.71264430015318, 47.9019457294095, 49.82209105645457, 52.04892258490286, 53.02250977485411, 52.531311358174975, 52.63039435109785, 53.72340986805578, 49.94815995616298, 51.364676875452844, 51.721914583636874, 50.426202743284165, 50.31262659257459, 47.49697669859856, 45.08509951253092, 44.054100590367476, 43.23653744113061, 43.173677536749075, 51.79624349840226, 51.48632918634723, 50.61103267054404, 49.36591548304404, 49.87350156230312, 51.64240421787385, 54.006550081314586, 50.74622108090309, 53.101561223306966, 55.899152525009654, 64.92083534117668, 65.47385815651187, 70.84585789711245, 71.68390366338915, 75.23338979290378, 73.50971206541985, 75.95541969422372, 74.3844319928077, 75.88341282260033, 71.24585336254489, 74.06568450312461, 74.43681916882916, 80.72689671670237, 75.96526484335624, 83.89657974243164, 11.114897824102833, 0.2584522944544592, 0.3118088781352966, 0.6268018015450048, 0.9222644471353101, 50.36399395235124, 74.90757419217017, 55.10515105339789, 43.30438267800116, 26.871701094412035, 47.40085901752595, 27.81745514562053, 0.14756929519916737, 0.1285055112994967, 0.03547524500097479, 0.05078455838825434, 0.06037814722907159, 0.04634065853972589, 0.04544988214488953, 0.11265056327946725, 0.10777814448961329, 0.016563286321357857, 0.026369970179192966, 0.024307527421643178, 0.20718210527012426, 0.038040432958833637, 0.0194019082963707, 0.05204125668012327, 0.17505948702173849, 51.41169040433822, 52.474742935549834, 45.478426948670425, 52.41182027324554, 63.914716013016246, 90.56525230407716, 63.19052880810153, 0.6103929949383582, 0.11042733015792985, 0.3479572884257763, 1.6231248263389835, 28.790993305944628, 104.72014488712435, 82.28625851292765, 89.17853755335655, 76.72170962056806, 79.80460628386467, 76.6650156820974, 75.67396610013901, 71.65159117790961, 68.62264279396304, 59.723502666719504, 62.50388260810607, 57.520193592194595, 59.0812498523343, 58.86947716436079, 60.5323895331352, 59.32719422924904, 58.13791198115195, 58.9410682647459, 59.37985597118255, 58.956467490042414, 58.422707434623476, 58.694355103277395, 58.925457231460086, 58.14174805918048, 58.67657892165646, 50.653523706620746, 49.11314618202948, 50.88524949166083, 52.2830920065603, 55.352181926850356, 54.07634473616078, 57.042523430239775, 56.92399332600256, 53.37858253909696, 52.35803281107257, 52.08581247637349, 58.70261953723047, 60.04246980913224, 53.228708774812766, 50.17730089925951, 58.545473698646795, 57.61047086408062, 54.94351802333709, 56.24660391961375, 54.60794356561477, 56.459792583219475, 55.33405665428408, 49.38420941752773, 54.94450646062052, 51.58701642867058, 53.64570379257203, 58.2431060268033, 60.508259111835116, 59.693445544089045, 64.05017898928735, 60.673241846023075, 56.38351425047844, 50.930952948908654, 45.41835192711123, 47.836504905454575, 47.82863270851874, 50.28441690629529, 48.12187302497126, 38.85486164400655, 48.7576029377599, 49.745130231303555, 45.31552307067379, 46.8797956743548, 44.7806372950154, 45.03586984449818, 47.05248586593136, 41.56573718593967, 42.637673885591575, 44.51506145538823, 60.82057783680578, 53.118745127031886, 54.02583245308169, 48.57803683127127, 48.20637264559346, 56.502173792931345, 54.23983696968325, 60.55817127227784, 59.885186687592544, 62.50055643819994, 61.260750139913256, 63.976101106212994, 59.64099953251501, 62.15035153973488, 60.2126810627599, 50.599132199441236, 50.01178080035795, 50.10977729674309, 50.91537721695439, 50.691068633910156, 52.40024535886703, 53.51928187954811, 54.184370733076534, 56.32220368231497, 54.1500735282898, 54.78780777223649, 51.46769008328838, 53.84749797082717, 55.347051466664965, 53.89746112208213, 53.168347420230994, 48.75550054734754, 48.222109194724794, 45.90556129332512, 46.331075699098655, 45.19738912582398, 52.542113565629535, 54.0657857156569, 53.60870407473657, 53.86060653194305, 53.06953114847983, 55.17207845564812, 55.205230328344534, 53.255314211691584, 55.42707174055038, 58.516483460703206, 67.47837758833363, 68.24877031387823, 74.32791848336497, 75.42016521576913, 79.5961166197254, 76.00177426492014, 79.81190189238518, 77.16996592860069, 79.06697319399926, 73.27156928277785, 77.4223155360068, 76.29781907604587, 85.96940332843413, 77.47146283426594, 90.4946574857158, 15.399699903303578, 0.28236572901087426, 0.10048364679659567, 1.323222609296922, 1.2725801525577423, 55.145484785879816, 82.20035860615393, 62.754502450266195, 52.23947917261432, 29.950436122955818, 57.390547490889034, 35.59439536063902, 0.1894470319272049, 0.03170338812314215, 0.08129350435469421, 0.012173954915675906, 0.13619186296578378, 0.04514727358435912, 0.0334372136351322, 0.03473228144068872, 0.1843507086197215, 0.1778033534966169, 0.15022774287048848, 0.15115817197628562, 0.21618988965788197, 0.23425784352565968, 0.1512311188684356, 0.20294272791474097, 0.3015079373313535, 60.47788035485053, 62.360708252076186, 51.87509098360616, 63.90295674723964, 71.0486287455405, 96.97540144766532, 70.24782980642011, 1.3139004837120734, 0.16637155966412637, 1.1993338119599128, 1.5129554992721927, 31.57867866177713, 108.03128427074803, 86.32335801278391, 96.82555906234249, 83.2543779188587, 80.52103504057854, 80.33642476604831, 80.34503044620638, 73.83518249757829, 71.94926769502702, 62.01528864522135, 65.34161544615223, 63.93389640315887, 62.56288682260821, 62.85370703666442, 63.74712098029352, 64.48183974912091, 61.89855890889322, 61.15267315218526, 64.17123902228572, 63.31653494988719, 62.062498292615345, 63.32750581925916, 62.87388763120098, 60.57957956867834, 63.21859728905463, 53.35312243430845, 54.002721848026404, 54.52140431250296, 55.56210325610254, 57.40718618515999, 57.8442794276822, 59.22141575044202, 61.48862023507396, 54.64473539783109, 53.53529691696168, 53.08204350932952, 61.66953955927203, 61.31224693790559, 56.68315587505218, 52.16218886836883, 58.62590582140031, 58.451462330356726, 57.456549213778594, 57.128886176693825, 58.25740306608139, 60.17900359246039, 59.03092192065332, 52.95708856275005, 58.56117102407641, 55.580475637989665, 58.408159363654356, 61.7626448600523, 65.97443888264318, 62.85616244039228, 65.9882770046111, 64.26263024730068, 57.11786431650962, 51.956107539515344, 47.473360107791045, 51.28192270955732, 46.560757929278964, 50.85123469752651, 51.3939416793085, 38.612506235799486, 49.31270068691623, 50.02687800315119, 47.977180711684696, 49.05242396939186, 44.897873017095755, 48.630565212618926, 52.28866569457516, 42.98413684291225, 44.21551004532845, 43.432471598348315, 63.875837479868245, 56.77634746797624, 51.75082245180684, 46.158448265444854, 46.752318643754535, 57.466033504855254, 55.66153141760058, 63.706826471513324, 64.43026450372511, 64.15309806023875, 64.47679165870913, 68.05520919061476, 63.28288101380872, 65.44828822535854, 64.21625998712355, 53.285563530460486, 54.057646797549346, 53.38461122205181, 53.86955738067628, 53.58688785183815, 55.32447430395312, 56.03832606346377, 57.023303816395426, 59.64315683610978, 57.750679908260224, 56.52630813660161, 53.63345423052388, 55.16655968081567, 57.28462780675581, 56.5649317156884, 55.0419734370324, 53.15920437535932, 52.05129169648694, 48.221803249851355, 50.565897956971206, 50.06779224641862, 54.76159849474507, 57.04740678110431, 56.66004134762672, 54.77840192856328, 55.363509731908, 58.618837710349794, 59.21115875244141, 55.92723669544343, 59.07588797230875, 60.305907957015506, 70.28335079070061, 71.32597169568463, 74.34407080373457, 76.34298909095027, 80.0771874766196, 77.93871910341325, 82.6146158095329, 80.51021714364329, 82.55024971500521, 77.74384790851225, 80.19339161534464, 80.41028299639302, 88.82463778218916, 79.65241047643846, 95.75730939065257, 16.956659247798306, 0.5235795436366912, 0.5686397321762577, 2.984828583655819, 3.083748062772136, 62.50356097375194, 91.14593567386751, 70.68531528595956, 66.63465223004742, 42.40004493344215, 72.9757833480835, 43.115524476574315, 0.20478926028215116, 0.13291853780467666, 0.1735503550979399, 0.19416366673765645, 0.22333779642658852, 0.09110530567986351, 0.0793718034401536, 0.14664356987322533], [0.06504012932700497, 0.028794749542289687, 0.05056923788581645, 0.05193319997840351, 0.02049288261801966, 0.04839137632159456, 0.03673493869662766, 0.1729392161172244, 0.06752318882894132, 43.91685293566796, 47.62743865289996, 31.827351047146706, 36.290431714827015, 64.50764894485474, 77.5134635740711, 60.632719839772875, 0.7488791993068111, 0.3732314177097813, 0.6996787039022292, 0.5213879193029096, 18.517697857272243, 98.05494754545151, 76.1395828185543, 81.0169481462048, 72.15792209871354, 73.80690220863589, 72.38761609600436, 74.76078341084143, 69.95806863231044, 70.03214651538481, 58.32444813943679, 58.00080160940848, 55.541361762631325, 56.511371750985425, 54.41883041012672, 54.020137171591486, 55.86261564685453, 53.892848414759484, 53.32901162485923, 53.60772740456366, 55.69280447498445, 54.36529397964478, 51.7565098885567, 55.026680115730535, 53.1581021893409, 54.56979067094865, 48.124014639085345, 47.497357168505275, 46.26775687740695, 47.8018311531313, 51.199478410905414, 53.390345727243734, 53.02338838577271, 54.203790387799664, 53.14052604859876, 49.57049062175136, 49.38255417731501, 57.5428335128292, 58.675637552815104, 51.61043690096948, 53.19700817908011, 62.3070227715277, 64.80283083454256, 61.97912439223259, 58.45444725405786, 55.04132624595396, 55.27107907879738, 55.25695854617704, 54.823348368367846, 52.58422020942935, 49.74691098736179, 51.02168521573467, 53.10163182597007, 54.574897596913004, 55.220453046983295, 53.94394905336442, 58.6509854562821, 53.58451481788389, 49.91996595936437, 45.00855445861817, 48.172793234548266, 42.09987378889515, 44.89947334412606, 48.201873687005815, 41.66310610309724, 46.85587706104402, 46.229705964365316, 45.26012743673017, 43.32520654124599, 43.770403400544204, 39.47908724507978, 37.21587965565343, 38.43405408243979, 43.131657185093054, 46.25489542561193, 49.02521056513633, 48.2966773740707, 40.61105582021898, 53.36143393670359, 45.951213759760705, 51.79302323249079, 57.5173734080407, 53.60536221534976, 56.491363740736446, 58.203494010433076, 56.72514092537665, 56.046394378908225, 53.78197477709863, 55.316935508481926, 53.71446294169272, 49.44669277437272, 48.02459824469782, 49.09098871292607, 48.28732644357989, 48.97756161228303, 46.87221765518189, 48.57834669851488, 48.97460414517311, 47.289624521809245, 49.736732436764626, 53.21878910064698, 51.770246028900154, 55.24809006721743, 50.37969912252119, 50.72404399994881, 51.92041789331744, 47.80980533169162, 45.04560516726586, 44.36483075541835, 43.58119610817202, 45.16258985765519, 50.17743818221554, 47.897776249916326, 52.29475713545277, 52.37365168909873, 53.33556590541717, 50.45703257283857, 52.38427346752536, 52.09705791165752, 54.46007413248862, 53.60952777247275, 66.0396522091281, 69.60314904489826, 74.90861754263602, 70.85129430217128, 74.45788229665449, 71.40605080512263, 74.18712108365952, 73.90223149330386, 74.39659918508222, 72.92984454862534, 77.93743256599673, 73.03198306791245, 80.48306649731052, 78.62230193230414, 82.57199533524053, 36.78420712870937, 0.15362817733999223, 0.24667085809332712, 0.8493304252624513, 0.09836938202140794, 48.54270019838887, 73.94594238650414, 55.44320444906912, 42.92977671469412, 32.803997685832364, 38.10049572298604, 33.83238823183122, 0.1985408786323763, 0.1344243142633669, 0.09187847991744358, 0.030402641690846895, 0.12753470936009, 0.05698956413975647, 0.043416592863298235, 0.03601751267729748, 0.0368530503023536, 0.037665264380555, 0.03839872462014037, 0.022277174172021692, 0.015199841338119682, 0.023231260072920593, 0.04689353270336025, 0.07229618472798217, 0.2738092929845856, 52.86634452881352, 55.541357840261156, 38.39984316979685, 51.24318538173553, 71.0896175138412, 85.8905166195285, 69.24752343085505, 1.3999822904025356, 0.559445757779383, 0.32246678526843753, 0.8081813300809553, 21.29462415172208, 102.52438637518115, 80.98414144208355, 83.49742366421609, 73.86820885442918, 79.07597111117455, 75.57272188125118, 78.01184777290591, 73.89398667120165, 74.33407660453551, 63.21532603233092, 63.20615160849787, 59.828131891066036, 60.93704869670253, 57.066234157931426, 57.43783558568647, 58.93128195116597, 59.27809007706181, 55.24699572593936, 57.3677545978177, 59.05460519175376, 56.9615892441042, 55.54112249805082, 56.80893844173801, 55.90367501781833, 56.065723819117395, 50.826978760380904, 50.10102256651848, 49.68358039855958, 51.33483156081169, 53.56993929032357, 54.769458924570394, 58.2960815583506, 56.960196802693034, 53.97284907679404, 51.352533217399355, 51.41826037437686, 59.34983414988364, 61.956331499161266, 54.460011374565866, 56.495431238605136, 65.77489614486694, 67.00248426006686, 66.57784846521193, 60.741079238153276, 59.07861794194868, 55.48874316676971, 60.66239257012645, 59.357561219123106, 54.590889100105535, 51.32028348984257, 54.46989966977028, 55.80760048281763, 56.3011170202686, 56.44595053888137, 56.67526406626548, 60.92058258671915, 56.49178735671505, 50.76087505586686, 47.602704186593336, 47.962550270941954, 48.17977505345499, 45.83478604593585, 46.979059096305605, 41.46271613336379, 47.84957816523891, 45.5091900979319, 46.74006515933622, 45.758276293354655, 43.16606421624461, 44.3584333696673, 44.578823504909394, 36.97832522853729, 41.85946779866373, 42.7522070946232, 48.308766118941776, 48.8451345505253, 47.30267816974271, 55.67078036646689, 46.4453657211796, 55.24929031249016, 57.94506865163004, 54.433503996941354, 57.893054100774954, 58.527752430208274, 58.450234628492794, 57.45893401484336, 56.634863653490626, 57.144912981217914, 55.64817574716384, 50.62042674710674, 49.482111777028734, 52.4518794398154, 52.52981693513932, 51.50137539832823, 50.23088047581334, 51.354172768131384, 51.44446180712793, 49.28029014218239, 51.86183337242373, 56.64279468597905, 51.83793044859364, 56.81098199659779, 53.29545574803507, 53.21663964179255, 53.89132653513263, 50.73225352071947, 48.6137931577621, 47.73108336233324, 44.870859653719016, 47.97439190649217, 52.91991626062701, 51.882061035402366, 54.43166832770071, 53.36381873776836, 56.053187924046675, 53.19022640105217, 55.959498190110736, 53.76601073049731, 55.64302959749776, 54.877406474082704, 67.13426020837599, 71.94860089209773, 76.45745954205914, 74.67662503642421, 76.21830478791269, 75.53590651481383, 76.73330414679744, 76.32141605500253, 78.60575737491732, 76.10777239645682, 78.74340903374457, 75.32138424534952, 83.95930628622733, 81.82279909810713, 86.18487481148013, 46.76609008542953, 0.22084493099922137, 0.12793049336441104, 0.7983613086323585, 0.42108384351576533, 54.45933672689623, 81.57925128936768, 64.36425101372504, 52.50867928228071, 37.72428551027852, 50.08729427091537, 43.61480297580842, 0.12312274771712481, 0.08509065745578659, 0.16681150863728217, 0.02761744477245356, 0.13525018768925823, 0.029550968338885618, 0.06279798915549632, 0.056419292119361704, 0.1652089599519968, 0.10874700056569231, 0.10864392343548038, 0.12268917259549904, 0.09509025757471401, 0.16261049696514684, 0.17583639210750981, 0.20520011323594278, 0.45435654359959793, 62.127790066503714, 64.79471152828586, 39.73938749682519, 54.103609131228545, 78.65200996398926, 92.8474755440989, 75.12790941422986, 1.892055640778234, 0.7262098608959107, 1.024376919432994, 1.4560529397379969, 22.958246469497684, 107.00055599212648, 86.5207395245952, 92.19884103344333, 82.00689946451496, 83.10426881236415, 80.93132280534314, 83.366149779289, 77.01530687270626, 77.46431627581197, 65.19147496069631, 65.48380136489868, 62.869851512293664, 64.67050183203914, 61.90291273978449, 62.31495772638629, 61.157223101585146, 63.357198161463586, 60.83703610204882, 61.349893846819484, 61.27249371620917, 58.59979068079303, 58.67316253723637, 61.32846593856812, 57.43354451271796, 61.080685892412745, 54.695734054811545, 54.847223835606734, 52.92743152187717, 55.09181891718219, 57.32752676933043, 58.86020468127344, 58.85321893999654, 58.949097356488636, 56.009100483309844, 51.79471769640523, 53.133975690410985, 62.61935326360888, 64.05096738569199, 54.212945199781856, 57.389657112859915, 68.33792578789496, 68.9117685441048, 68.05236939461001, 61.43670374347318, 64.02712721978465, 61.52637697035267, 63.44235674027474, 61.752913459654785, 58.418553644610995, 55.14162517363026, 55.13345487656132, 59.686812816127656, 60.649942967199514, 57.978659829785755, 59.38914022138042, 65.35933279222058, 57.5278853601025, 54.053885244554095, 46.62608500449888, 49.49189024586832, 46.3105107122852, 46.566566959504165, 47.383765328315, 42.23927482481926, 49.06743880241148, 48.570564716093, 45.687469667004, 45.20972890238608, 43.78952495513424, 46.218793930545935, 44.87915546663346, 36.780653461333245, 41.447454191023304, 44.76925457677534, 50.86172703773745, 50.39830684661866, 49.17821045844786, 55.96196928331929, 48.96077386794552, 58.576833048174464, 62.32419098577192, 56.229043468352295, 62.5198309652267, 62.597501739378906, 62.896535396575935, 59.54810211735388, 57.92684924217963, 60.227966539321415, 58.54266135923324, 54.57663128452917, 53.366238840164684, 53.85407186323597, 54.27036085436421, 55.31575879743023, 50.659015024861986, 53.310898119403475, 52.68511141500166, 51.33472957918721, 52.83379670112364, 56.83470841377013, 53.90244253220097, 61.904132596908084, 54.24362597926971, 55.057843346749586, 55.61633394610498, 52.95085591654624, 53.251603649508574, 50.773246211390344, 48.070944970653905, 51.972969808886134, 55.20708953180621, 53.81357339120681, 58.92712816115349, 59.313779723259714, 58.98342594023674, 55.35226821899415, 58.77152773641772, 58.241184065418864, 59.57833182427191, 58.620532174264234, 70.1115039087111, 74.8092560614309, 80.2986131175872, 77.13213074591853, 78.7993263429211, 78.27503096672797, 77.62768299348893, 78.46720357095042, 81.66839891864409, 79.75993048760199, 81.75286323793473, 79.64018052624118, 87.0429168208953, 84.87547782159622, 88.93600171612155, 48.22979311789236, 0.3294334356342593, 0.5644323772961094, 2.423599679623881, 1.6348150829153678, 59.39394120247134, 88.3619785308838, 71.43691985837876, 64.66124503843247, 51.87397703047722, 61.72254254741054, 53.63798849044308, 0.24161293111260862, 0.17581602949048244, 0.2311669545428407, 0.13672317558478925, 0.22443291911434746, 0.12352476767714947, 0.16830257620782624, 0.14599978022517698], [0.04620484264206983, 0.01812290535458634, 0.10478844039983327, 0.025466582061903133, 0.09478475703226943, 0.10768534059846595, 0.07407398368682593, 0.12594637160580005, 0.5608916414841529, 44.97512802000969, 57.63143201028147, 41.6937868825851, 37.76734529003021, 61.126703139274355, 77.87137985229492, 60.979814298691295, 1.5619646565568064, 0.3435569100322262, 0.5103967332791898, 0.36012261144576535, 15.791814346467296, 93.70604315111714, 75.79582629665252, 76.43871845737581, 73.09281118454473, 74.58284116560414, 75.40580149619811, 78.57332721833261, 76.56047667226484, 72.51825455696353, 59.32886123657227, 58.55677012474307, 56.22116734904628, 55.22784671475811, 52.63571308505151, 51.80938736084969, 54.28189654504099, 52.65606234150549, 50.18549473054948, 52.478249534483886, 54.016465833110196, 54.9182971831291, 53.16626856403967, 54.37346427671371, 55.687713238500784, 52.37687587738038, 49.65747702506281, 46.64845035922143, 47.22997311622866, 47.056773016529704, 49.5069403802195, 49.68283122585666, 52.29555729896792, 55.31175797985446, 54.15134045385546, 50.46826624101209, 50.02224176160751, 64.1961617623606, 54.39990105167512, 53.2693523745383, 64.19633826901837, 67.24108203764885, 66.3254439446234, 64.35089142091813, 63.50365946369787, 59.60397628045852, 55.20198652821203, 59.706330530105106, 60.68949222564698, 55.609014803363436, 52.438947385357274, 50.55799045870381, 47.69185181586973, 49.52900371243877, 53.57645826954996, 54.41724969494728, 57.10735628681799, 52.77067792031073, 53.99242954869425, 45.299719841249534, 44.82439133428758, 42.59780299278998, 42.39402409522764, 46.40336105900426, 45.895786746855705, 47.06647696033601, 46.020176872130364, 46.45272800999303, 47.45456410992531, 41.1767400464704, 43.72762210907475, 45.582667858369895, 34.995167024673954, 43.338479841909106, 48.02041307572396, 47.39002543111002, 47.09466703476445, 32.54132636131779, 49.24937794285436, 45.3639643423019, 52.597003213820926, 55.497541043066214, 55.510194609242106, 53.17448592955067, 51.916577892918745, 53.07493617457729, 53.735212279904275, 50.431870568183164, 51.18538533487628, 49.91745564245409, 50.60436071888093, 52.09251580699798, 55.24282232407601, 54.5326340583063, 51.57072290297478, 50.00350852166453, 45.90425906642791, 43.875040469631074, 43.46725125466624, 46.689458739372995, 55.97004936587427, 50.477868203193914, 53.774734081760535, 50.25950201096074, 53.21062272594821, 49.737913070186494, 47.79794408429054, 45.09925142411263, 45.97076285269953, 43.37623657718782, 44.79511868569159, 50.019327440569484, 50.65106045815253, 49.526556153451246, 50.81909479633455, 50.71732497984364, 49.42215834894488, 50.57759054245488, 54.03848209688741, 52.946937468744096, 53.96254893272154, 59.977032907547496, 68.60258379290181, 70.62328692405455, 71.99068007930633, 70.69432104787519, 73.98684486266106, 74.52510387666764, 76.31366545154204, 75.45719239019579, 78.52064194217806, 74.37835231904062, 78.91378894928964, 77.92513985787669, 81.78036689758301, 75.39714090285763, 72.88184258245653, 2.9055922935085916, 0.44480379490602406, 0.19146057146210826, 0.09625548496842386, 49.046662007608724, 72.41063256417551, 58.760427428830056, 39.1890436603177, 34.42504267538748, 42.11982688596172, 33.58017198501095, 0.47290175492244385, 0.049881819530480334, 0.21609832682917196, 0.09003727186110713, 0.03720427480255885, 0.021270285660941756, 0.033701107942409096, 0.01997413384097238, 0.017999572859656428, 0.03705951482838681, 0.0915468481159018, 0.04752455549615045, 0.015006578422241635, 0.012761010007271844, 0.1406318787485361, 0.04084785025747072, 0.9374977071439067, 57.26048561834521, 60.24507984038323, 44.58555036975492, 47.18519141597133, 68.87980122720042, 87.17235503658172, 68.7967489611718, 2.779660676756213, 0.4179669075435208, 0.3569465641292834, 0.5946123191425877, 17.205743482035977, 97.75578052766862, 79.0272395841537, 82.98903742144185, 77.2118725315217, 79.13034300650321, 80.07633239992204, 83.74331705031857, 79.44866688020768, 79.42915701097058, 63.78148094300301, 61.5625019996397, 59.17162126110446, 59.77684297869283, 57.113177084153705, 57.32199230501729, 58.48132333447857, 55.16578697389173, 52.92605084757651, 54.560278923280784, 56.05404692311441, 56.6671565271193, 56.049445982902284, 56.27162471894295, 58.70053675866897, 56.30419608085387, 52.27247807287401, 53.17066554100283, 49.6630036446356, 49.87183063260971, 52.733352645750976, 52.845422606314386, 53.432040522175456, 58.328790203217544, 54.70902696732552, 51.57295080923265, 50.35629433970298, 65.02773561785298, 56.9361291393157, 54.15962842202956, 67.10743119639736, 70.24084798751339, 68.20849541694888, 67.12772553966892, 65.11454551450669, 62.3172091668652, 58.25361405649493, 60.480500498125636, 62.74480242883006, 59.118414309717, 55.76398764887164, 53.931801472940755, 50.19863074825656, 53.01002094822546, 55.62519458032424, 56.12167642962549, 59.93432614111132, 55.02269106526529, 55.64728536913472, 45.901403580942464, 45.81373076285086, 45.767387959264944, 43.47300144933885, 45.134631203066924, 47.32304311567738, 50.592538695181574, 45.778245079901914, 47.01051258271741, 47.56087210870559, 41.45258857357887, 44.477771482160016, 44.40222271027104, 36.47425751532278, 44.543322132479766, 45.50569526610836, 49.250080047115205, 46.06036155454574, 38.68097120715726, 56.87754461842199, 49.24076834032613, 54.34514084169942, 56.300210952758796, 57.09502435499623, 57.77187247430125, 53.03188423956595, 55.21639339385494, 57.166733126486506, 52.00812993511077, 54.780986770506836, 53.4631056939402, 52.02209749529439, 54.90203503639468, 56.62056269184236, 55.89263746815344, 54.733031872780096, 50.61553162913169, 47.41950596532514, 45.86582376110939, 45.10607634821246, 48.10987449461415, 57.106407073236284, 51.1104170737728, 56.93138699377737, 54.52631119758853, 54.24761895210513, 52.187244969029585, 51.182933853518584, 47.375394990367276, 48.12159845905919, 46.32014013105824, 47.3560380935669, 50.90223335450696, 53.1812677075786, 51.92305372607324, 51.40374368236911, 53.46936579673521, 51.667177907882206, 52.59238658412811, 57.03195656499555, 56.84794249073152, 56.74200711711761, 62.96198014290103, 73.55606663611628, 72.4064277833508, 75.31712455134239, 73.36689072270548, 75.66022211505522, 77.21413966148131, 79.32829718435966, 78.87193725955102, 82.56803374136649, 76.85560364877024, 82.59318397891137, 78.93041195407991, 86.00842306690832, 75.65517794701361, 80.66300915133569, 5.3167516858347, 0.5069282548802515, 1.013301739529256, 0.4640930614644482, 56.80304704173919, 79.81738536588608, 66.4834056362029, 46.58456279385475, 41.50096316491404, 55.73411095526911, 45.63813017260644, 0.5692732562461208, 0.08191818010903175, 0.11804125587185545, 0.02576241265952347, 0.04003405037726607, 0.03590380990757577, 0.05614863708615304, 0.002852605473655727, 0.13412209257723826, 0.12459578923881055, 0.1490280185375483, 0.11346354344559294, 0.22924467140147764, 0.1730363254225062, 0.1616835918638014, 0.23807052522897723, 1.442815430702702, 65.51699246129682, 75.80748358080464, 52.78424932110695, 52.2588360694147, 78.61683414828393, 92.78268583359258, 77.48948220283755, 3.2693683476217332, 0.5010933308832107, 0.7645270048129944, 0.693133126103109, 19.30624919552957, 105.09567260742189, 83.67854302929294, 88.71609795478084, 80.81219257846956, 85.38997511709891, 83.51124609670332, 87.76744134964483, 83.83207244257774, 83.98154612510436, 66.33742286312965, 66.23658657073975, 63.004216224916526, 63.132685615170395, 59.30997502419257, 60.196662102976155, 61.5434314358619, 58.13082425825058, 55.79973613062213, 58.63722970408779, 58.3641895940227, 60.44319875778691, 58.843165905244895, 59.04135542531168, 61.46492911923317, 58.167463118030184, 54.9455576558267, 55.93669352992889, 53.33394596653601, 54.08920226558563, 55.89386517001737, 54.31523276913551, 56.55707913060343, 58.465869195999645, 56.79757533534881, 55.366784911001886, 51.3218955839834, 69.49044366036692, 57.2016735999815, 55.7450504456797, 69.55620611867597, 71.39939062057003, 71.7035625826928, 69.82445701476067, 67.14816893300703, 65.09159572662847, 60.001979181843424, 65.0015930206545, 67.1724013359316, 60.75491736012121, 57.71538642144973, 58.470756469234345, 52.6222397435096, 57.26456880569459, 61.364924369319795, 58.292096430255526, 62.74489264334402, 58.20063460257746, 56.49955364965624, 47.520981604053134, 43.90897681636196, 44.46060719028596, 46.18111564267067, 48.11835073655652, 47.91070830437445, 50.150683695270175, 46.22080218407416, 47.556690862101895, 48.31696387260191, 40.74315732525241, 42.89922537342195, 44.75930352364817, 36.37282502266669, 44.042227575855875, 47.12612052117625, 48.50216642502816, 47.43523859208631, 37.23726834020307, 50.07544479062481, 51.88852510144634, 58.868323987530125, 59.36789274215699, 61.30041706946589, 59.03343615993377, 57.20673345750379, 59.43956621231572, 61.899888592381636, 55.030331842360965, 58.86405644878265, 57.40060837038102, 55.631693947699766, 55.97047298185287, 59.75928644980154, 57.27451593645158, 55.8141076949335, 53.4757161140442, 48.55491053673529, 46.64031928585422, 47.02602555674892, 49.63199730842344, 59.14957361836588, 53.223609693588756, 59.96634837119811, 53.36808235414567, 57.88753924831268, 55.78914573115688, 53.75067818549372, 50.760157262125325, 51.22357745324412, 50.855788569296564, 51.582870483398445, 54.64737515295706, 56.7604697135187, 54.76463048688827, 57.03991897644536, 56.91477183372744, 53.489448332017474, 55.6798763428965, 60.02561146213163, 59.09084789214596, 59.88776368479575, 64.35726527244815, 74.58973669236707, 76.18156002413842, 78.8263750076294, 75.22822795375701, 79.42845882907991, 78.74157336450394, 81.37219721271147, 80.22666115914622, 85.09198481036772, 79.08869528001355, 85.34885298821234, 81.3017043759746, 88.28462939108573, 78.43438117734848, 80.30876421159314, 4.830295904990166, 0.4610243277443994, 2.6222787605177973, 0.9280968277204422, 60.58134463525588, 88.76661808260026, 74.38101953075778, 56.682826395957704, 53.986157678788715, 67.95834233683925, 59.27340284470589, 0.8315782068717865, 0.16535059428743779, 0.25240153284563177, 0.18624027980671776, 0.10161744926365153, 0.09612603143097893, 0.1553901029570449, 0.06711170768305179], [0.04409427041067712, 0.03410951707572226, 0.02671130065385613, 0.01568538307647912, 0.06508127590941806, 0.041472771159944036, 0.021019753842284123, 0.0486922535234161, 0.8993961097251986, 52.87781353919737, 50.96797227859498, 41.379989424059474, 47.35522616294123, 58.00865419449345, 78.21815659922939, 69.93497371673584, 2.072406098727257, 0.39226956064662627, 0.6869180079910063, 0.9083929237338805, 14.24044437946812, 85.76456931329544, 77.23303764097153, 75.72533345991566, 72.36840432690036, 75.64714493290072, 77.78913559452181, 76.84969655929073, 74.16638743492865, 68.64241153963151, 58.99935076313635, 58.021790212200536, 56.705803640427135, 56.153973225624334, 51.69921582744968, 53.48725964946132, 50.26965702733686, 51.15325720079484, 52.87003940151584, 53.408133675975186, 52.73403906053113, 54.414927651805264, 55.756064461123565, 51.23231257161787, 53.61685868232481, 52.336683350224654, 51.24391102021741, 45.51164942402994, 47.003181672865345, 48.792253155862134, 49.26409859811106, 49.688863831181685, 48.491458354457734, 52.313753174197295, 49.93637715616534, 52.882186981939505, 60.47452280598303, 69.25194001966908, 51.828253961378536, 54.113520960653986, 66.71127965373378, 61.84066080277967, 59.404272725505216, 61.86335563659669, 63.802328340468875, 59.797717832749896, 61.50345856143583, 56.01309345614526, 58.32592295062158, 57.15189480012464, 55.20227286123461, 55.72677612304688, 49.20013650771111, 45.74816050068025, 49.80487577376827, 55.33869289582776, 54.11980459767004, 58.587850985988496, 50.60019908412811, 49.11544861332063, 50.54642731143583, 41.479645083027506, 46.93631702853788, 44.017963793969926, 53.390788955073205, 51.766649215452134, 51.014460209877264, 45.73432630108249, 45.193702097862, 42.206981951190585, 44.10782921698786, 46.05068114496047, 48.665085992505475, 48.078648505672334, 50.44762280679519, 50.72698969994822, 49.89886753020748, 37.066492265270604, 38.44848448230375, 53.382587279042895, 52.14444406570927, 55.41915247517248, 49.2527590259429, 51.597312650372906, 49.7310685342358, 49.76960974354898, 47.52963043028309, 50.489082259516564, 49.13106356897662, 48.45070885073755, 52.071613496349705, 55.83936383647304, 56.11401211830878, 60.13659492615731, 57.28621244430543, 56.875457917490316, 47.3014190889174, 47.00470747486238, 45.59344260923324, 49.34598199782833, 55.17851114273072, 53.670493172061065, 56.04889685107816, 52.75679272990073, 49.64878505276096, 48.327009062613214, 47.99846741460985, 44.22783413240987, 44.28866224904215, 43.07520643357308, 43.96845171528478, 47.18294389786259, 50.16700075518701, 48.24461575477354, 49.54302226343463, 50.67314340222267, 52.58973898426179, 48.48869700585642, 54.69811493350614, 55.16113504286736, 54.07365006785239, 57.84235746629777, 67.29198655774518, 67.27203738304877, 72.0641460726338, 69.34136221485754, 72.38750626963954, 70.46377981862715, 75.36377722217192, 75.91484669716128, 77.77983957721342, 77.66900124088411, 82.51603095762192, 78.35707910599248, 81.7659325753489, 72.96516941439721, 88.5227172605453, 24.141892271657145, 0.6313971646370427, 0.6844440955788859, 0.170890053493842, 51.532507250385905, 72.78509339978619, 59.01446757778045, 45.239248660302934, 37.31399382314375, 40.21471208141696, 31.352369669945013, 0.45552957742925615, 0.013123104337512726, 0.12542563100014964, 0.03142740111798048, 0.035903537946362654, 0.02882429372308956, 0.09917195871352188, 0.026501714319531477, 0.04681331946724846, 0.0895722411693104, 0.08191507745293841, 0.03980030546024923, 0.0738378064406495, 0.08266463319981292, 0.11912524730207459, 0.10993042254760382, 1.2554897728466219, 63.09170469161003, 54.89299789551766, 42.623663179336056, 52.03007167385471, 67.19829682380923, 83.34195660006615, 77.92652837691769, 2.5131606286571873, 0.7109016468448024, 0.9245112297996398, 1.4158671541560082, 15.869434129807258, 91.31486431244882, 81.6400323375579, 84.36746812635853, 74.99691009521484, 80.1594082001717, 83.19137680915095, 82.38148581597113, 78.1539160205472, 73.59266234982398, 62.02802850354103, 62.76750118501725, 59.65313926819832, 58.93972681414697, 56.447299834220644, 56.77741043029293, 54.280872806426025, 54.777264441213305, 55.184441766431256, 54.953316104027536, 54.555250444719874, 55.91342210769654, 58.01176071166993, 54.645598319269, 56.00486824589392, 54.266630680330344, 53.338225272394, 48.94833210975894, 50.30624489630423, 51.133496299866714, 52.82087249140586, 53.043066916927216, 52.39471481692407, 53.792757372702326, 52.44306979640838, 52.09823854507939, 64.45053139040547, 70.25005771267799, 54.24792489697857, 57.763298173104566, 69.6649734435543, 62.91654732919509, 62.53199423513105, 65.48189509299495, 66.02544538436398, 62.66418595467845, 65.82961713114094, 59.849085192526545, 61.015707908138154, 60.2233773662198, 58.819470867033935, 57.10736413155833, 51.85707945977488, 50.295195579528816, 52.65437179996122, 56.35362186739522, 59.33767872471964, 62.30059400681527, 50.473373166976444, 50.04707036479827, 52.64850393418343, 43.82045284394295, 47.202387086806766, 46.28798454038559, 54.22642246369393, 53.736475283099765, 53.255439727537095, 45.33452695415866, 45.604080077140566, 42.23073582495413, 45.40015605188186, 47.7447332105329, 49.31929811354607, 49.32212614244031, 51.7472727068009, 50.21018212841403, 49.70249798990066, 39.18063017629808, 46.168124752659956, 55.922290586656146, 55.464518608585486, 57.015176665398386, 50.67972906174199, 53.113920611719934, 51.63604213345436, 51.98720016787129, 49.73480263063985, 53.723084311331476, 50.316552885117076, 50.87681639579035, 55.38018764988069, 56.55869906948459, 61.60491458831295, 62.622824561211374, 58.64611779489825, 59.60482743478591, 49.15377409227433, 48.09860552510908, 46.421482409200365, 50.72757805547407, 58.81113975278793, 54.19445514678956, 56.86329464758597, 54.970398026127974, 52.946368725069114, 51.317071068671446, 49.996828725261075, 48.04346092285649, 48.90087143067391, 46.76670981991676, 47.592721754504794, 49.63297005622618, 51.36409244229717, 51.46653298408755, 51.33989926307432, 54.105013339750236, 53.97486517506262, 51.6225334905809, 55.79747292303271, 56.57678904071931, 56.75948519860545, 59.200889987330285, 69.07418604820006, 69.23337151927333, 73.35225243722239, 74.50268360876268, 75.9742235368298, 71.81655037787654, 76.87826710362589, 76.67436661258822, 80.88399548684397, 81.01678340665757, 84.37069231464018, 80.41171073913574, 86.08035149112825, 76.19199352879679, 91.85980704522903, 31.14390354002676, 0.6296013319684614, 0.7386886977380323, 0.44407889186855287, 57.55241978553034, 81.09312057495117, 65.60888574969384, 55.6050532094894, 40.7864720590653, 51.31205827959123, 42.60585954112392, 0.521339625120163, 0.05763184459459397, 0.17330514567513622, 0.016905769758347063, 0.013150832889932058, 0.023373407687270836, 0.0461760951927112, 0.02720623750299696, 0.15939081328049784, 0.17615418070025984, 0.15973873977218905, 0.07720387420587002, 0.18675466188259665, 0.236963466891358, 0.21213058892998005, 0.17380651957806081, 1.7278435297550696, 79.37124713774651, 64.38818923888668, 53.94387845070132, 61.73507452011109, 76.02476719887026, 88.48983210902061, 85.29562642497402, 2.882588818188637, 1.0484271160056515, 1.0314442337520662, 1.5917898690508259, 16.958949911978937, 96.41538896868306, 85.58511303317162, 88.21372078311059, 81.15259939624418, 85.8755410102106, 86.42621824818274, 86.58196772298506, 81.02105879014539, 76.33888629175003, 65.44578967555877, 67.26818561553955, 63.29857049449798, 62.81319679752473, 58.652264148958274, 60.39865632211009, 56.86211009179392, 58.67117781792918, 60.07645714667536, 59.761243712517526, 57.9719368873104, 58.19209168034216, 61.76287235752229, 54.80172826397804, 60.42825844980056, 56.935787893110714, 56.93450135569419, 52.50180336736864, 53.81854303421513, 56.3906608089324, 56.682928377582186, 55.379834636565185, 53.97295890315887, 58.19584931096723, 52.946047090714984, 54.58255406348936, 64.8347746172259, 73.6629355338312, 53.20521769985076, 59.05617806219286, 70.98096786006805, 67.75501451184674, 64.35700639601677, 70.94485067552137, 69.9093214158089, 66.09276894600161, 67.11987295458394, 63.15435671037244, 64.98832756473173, 63.20516709358462, 61.3024135558836, 60.39018008016772, 54.03744266879175, 53.23896577281337, 56.203120523883456, 62.11965114839616, 61.71915361958166, 64.62767347212761, 55.05055558296942, 47.25742186269453, 50.16731062243062, 46.823650867708274, 46.96291069830618, 47.72421136979134, 55.95390881261518, 54.596199989318855, 54.716989378775324, 46.08533920780305, 46.198189720030754, 43.335879310484856, 43.59175512867589, 46.9200195804719, 49.01800124875961, 49.02066061573644, 52.6576195224639, 51.041814819459, 50.75563869168682, 39.70816935262373, 42.02801596733832, 58.388174887626406, 58.93929143105784, 58.83871793746949, 53.42891047077795, 56.921082927334695, 55.72080235327444, 55.1813470163653, 52.76706541738203, 55.841442692664366, 55.27800990689186, 53.086283591485795, 56.66419906000937, 60.30863400428527, 62.80080603015039, 65.13645587428924, 61.015433342226096, 61.03769671532416, 48.44022827763712, 48.812759307123, 47.617930827602265, 52.35151775421635, 59.93021549717073, 55.61045431321668, 60.09701428874847, 58.00008773803712, 55.00681331080776, 54.2802099258669, 55.05118708456717, 52.082058768118586, 52.92494081681775, 50.32317384596794, 50.3248094743298, 51.46834904147733, 55.28212839557279, 53.32301432086576, 53.28190003671954, 56.26659624038204, 59.54727841961769, 54.36901238656814, 61.51446865450952, 60.20425973399993, 59.28707622712659, 62.35027474741783, 71.8044694777458, 72.79641336010349, 79.39114139926049, 76.17716696954544, 77.38433914799845, 72.62923409861904, 79.52645532546505, 79.23835723630845, 83.65268676511704, 82.33388393155991, 87.75496821249686, 85.07761324605634, 88.13071558552404, 76.89575302985408, 94.48210762393091, 29.136969889363936, 0.7812491107371546, 3.2014735908277574, 1.1588034706730996, 63.01514002584643, 88.16711518072313, 74.48162048093735, 67.60132820375505, 59.17293917748236, 63.04489904834379, 60.85055258966262, 0.751642325232106, 0.16343733566182275, 0.278140141238128, 0.17085109026201312, 0.17120914443606333, 0.18053171435190787, 0.32933859394923337, 0.2372065312679737], [0.004408300221492086, 0.0543231644757813, 0.05708486930797658, 0.04084610357700337, 0.10751927571911966, 0.056804124896805135, 0.1201191008271229, 0.066040915947768, 0.34733353963782715, 43.347968055355935, 48.94264859537925, 30.80057651765885, 39.05036041813512, 65.01085373663133, 72.67009735107422, 77.3312145663846, 6.247284489293253, 0.7278475117298865, 0.7304650809495681, 2.5291648795527797, 11.980374686179623, 79.11180588506883, 76.34071411625033, 76.94308819309359, 77.32759814108573, 75.00467638815604, 78.95149861612629, 75.05671055086198, 72.88984421760806, 68.69416329168504, 57.33424971180578, 57.077393301071666, 54.955190996969904, 52.52319205191828, 52.046420112732925, 52.30560248897922, 55.18779931529876, 51.615767402033654, 53.98927204070553, 53.48694978221771, 53.44888317969538, 52.081886183831, 55.352578086237756, 54.27680138618716, 52.87391862561626, 53.09766630972586, 49.819384621035674, 46.08867322244952, 45.151442481625466, 48.55725219172817, 46.56329962515062, 49.730225224648755, 48.46058537883144, 51.57478255610312, 52.24888109391736, 58.974345653287834, 66.46395068014822, 61.935099709418516, 53.035775230776885, 60.72875122870169, 65.80535727162516, 61.06012090559929, 60.17178643134333, 60.24509552986392, 60.7671316208378, 60.75259923934937, 60.262820720672615, 69.4795237818072, 63.698052129437855, 59.37381159874701, 58.23978377926735, 53.61233226714596, 52.18060831869803, 48.74958169075751, 51.20618566390007, 56.44129468548683, 60.95154577685941, 54.267038606828265, 52.52935409545899, 51.42633261219148, 41.081583346090014, 46.51833749586537, 45.584503527610536, 49.77763491292154, 54.04463629568777, 54.76873720845869, 51.729775013462195, 52.95648451774351, 47.789507066049886, 45.32556433831492, 50.793991627231726, 54.67910712765109, 53.03538691612982, 50.94879973319269, 50.58992247427664, 50.34773180561681, 58.328233226653076, 41.6961952178709, 32.377390899965846, 52.991185726657996, 55.002718356347856, 51.92548951795025, 48.71301735601118, 49.2519235610962, 47.15309858322144, 47.820207457388605, 47.406503308203916, 49.260474328071844, 48.85980029259959, 54.03672487505021, 52.04768311592841, 57.554749673412694, 58.70932286785495, 62.718204836691584, 59.94575592779345, 62.76356312536425, 56.84642845584501, 51.51085968940489, 46.117047648276056, 46.74745882711103, 55.74528578789004, 57.49470995318506, 53.28369255988829, 53.45243292470133, 50.75117503443072, 47.51714944839478, 46.609018771879136, 43.54420423507691, 42.241624324552475, 42.16654623708418, 42.790607098610174, 49.08733306392547, 49.46794417596633, 49.1465098627152, 49.829704376959036, 51.42521473669237, 50.55171466642811, 51.17279844899332, 51.39976639901438, 49.467669610054266, 51.97087918558429, 54.98973531107749, 61.33994671606249, 64.01650936372819, 68.8437468005765, 69.54591381934382, 73.6466420081354, 72.26011553118306, 69.29661581593176, 70.03352718968546, 74.3310171558011, 76.53315344164449, 78.7118104196364, 79.07430018148115, 80.65087333802255, 81.06522467828567, 86.92408469415481, 63.19012480397379, 0.185209401252289, 0.13757753215970533, 0.04226730392885305, 46.93451666062879, 73.08380542262908, 59.06034361931586, 36.4284481540803, 36.44738143490207, 39.77579101439446, 24.855589097545995, 0.5548123967263007, 0.05855870373066395, 0.10583787360378813, 0.06417076125921262, 0.03896866339228807, 0.06693065812390658, 0.04528129683627237, 0.03356613091103012, 0.06412868771041114, 0.04439651124900387, 0.1126796363161937, 0.06961992551242152, 0.10623037875179323, 0.012080859911117342, 0.061483589121170586, 0.08380321605551629, 0.442604141970796, 55.01222618164555, 56.44653497203704, 38.50136587696691, 46.3248626647457, 73.03969444767122, 79.13705025949787, 86.96529311518516, 6.83230354901283, 0.8314916082928259, 0.7673443084762943, 2.730081427481867, 13.50969308807004, 84.03856954266949, 83.5790168085406, 81.74645408507317, 81.65108557670348, 80.46412929411858, 82.30914946525328, 80.30935256711899, 76.66490585573258, 72.62448018597019, 61.19989848905995, 60.28238158072195, 57.77082912383541, 56.68722337292087, 56.74604715839509, 56.218774703241166, 56.85350048926569, 54.60781804976925, 56.42560912716774, 55.358230221656065, 56.344035594694084, 55.19445165511101, 57.14652115298856, 56.24480747407483, 53.96570251834009, 55.94926472633116, 53.04613421040197, 47.61846034757553, 47.981840487449404, 51.02074776926349, 50.95345166421706, 51.57221732601043, 51.43085510500016, 55.65066645222326, 53.313843819402884, 61.0627410488744, 66.78392194932508, 62.429283049798784, 52.33598909070415, 64.94173372945478, 68.84161303120275, 65.32136817132273, 64.17360028912945, 63.13629027335875, 63.99010396772816, 65.06651609174668, 63.58661759284235, 70.76828125984439, 67.56153968072707, 62.86008873293477, 61.77403542303271, 56.774123484088534, 55.13069352796001, 51.27330918465891, 56.83555172335718, 59.0364642297068, 64.00301641033542, 57.456600204590835, 51.11440612423805, 50.77449744747531, 41.471129617383404, 45.96253764244818, 48.17508782109907, 52.738279142687404, 55.16676756643481, 57.50312343720467, 53.94764000369657, 53.865854663233605, 49.25963886322514, 46.74826683536653, 53.00177220375308, 53.366897798353634, 53.23426677334694, 51.97045164723551, 50.491133659116684, 49.67678293105095, 57.02871668723322, 43.72453912611931, 36.84365849341116, 57.83588555551345, 55.54311898446853, 56.111666540945734, 51.60972695196829, 51.520347902851725, 49.58693711988388, 48.966896687784505, 51.16532241144488, 50.08121459714828, 52.4398926765688, 57.743294085225756, 55.944581416345414, 58.744349633493734, 61.3467598730518, 62.69517660140992, 61.793831625292384, 63.76692110492338, 59.95746420275781, 52.79315702376827, 48.41624690640358, 47.963656379330544, 58.22245082547588, 58.93349024557299, 57.02266054768717, 56.07433342164563, 52.65160652898973, 49.7766778545995, 49.805138572569824, 48.13224769407704, 46.28270110776348, 44.81544048555436, 46.49421491930562, 51.953342268543864, 51.93394614804176, 52.0733864076676, 52.71311321566182, 52.856209124288256, 51.85622438307732, 53.027381358608125, 53.21636115351031, 52.41105541106194, 55.21443220876879, 57.330445012738636, 63.20788137374386, 67.45209770817911, 70.1385368839387, 73.94302414309594, 76.89867127326228, 72.5462838142149, 70.04434508662071, 73.30945937864243, 77.06287737815612, 80.56827606693392, 80.01147993149297, 82.45952529291954, 83.18967450049617, 85.3726617751583, 85.22569840954196, 72.20273910030242, 0.3952931258226595, 0.3007716042620521, 0.10061857786269919, 52.061003485033595, 79.73379965751403, 64.53552915203956, 46.610175871079974, 43.03189954450054, 52.814902644003595, 42.10709487238238, 1.1748596929734754, 0.07193050031820614, 0.016937097008790702, 0.03569400906863232, 0.038074006762115226, 0.04276076797395945, 0.020478909174280784, 0.044973122646972064, 0.12126837060936999, 0.17185399128544718, 0.17345140718163984, 0.09661711677308045, 0.27251365444352554, 0.15553300899844016, 0.2775635221792806, 0.2313918166703755, 0.8344580233097078, 71.37183204773935, 63.68956412038496, 41.192551120635, 54.003537701022246, 84.39969431969428, 82.83605713998118, 94.89576862704371, 7.1263915877188415, 0.9684662292561225, 1.408065069587, 2.5745837198149775, 14.940537445006834, 93.38776634585474, 88.65392054280927, 86.84841432879048, 85.59359319748418, 85.4665711618239, 85.1633954817249, 85.06514010890838, 81.15852217520438, 76.30348297857469, 65.49050861789335, 63.39208372177617, 59.852062271487334, 59.03563660960044, 59.39224281618672, 59.5842702927128, 61.35391427624611, 57.606521037317094, 60.44064137243456, 58.39383486778506, 60.16288265105217, 57.80590295791627, 60.76841815825432, 59.861601475746404, 56.038655542558246, 58.791323938677394, 54.894413871149865, 50.66984468890775, 52.809752571967344, 53.68496279562674, 52.94532537460328, 54.953853468741144, 52.962701474466634, 57.153738314105624, 55.04680187471452, 63.785395468434984, 70.41447562556114, 63.73719738375757, 53.580925849176225, 65.18156705364105, 73.59828702865109, 68.60953423284715, 66.85412453066918, 65.53117575183992, 67.2124252011699, 66.50557487241684, 68.36522548429429, 71.17922013805759, 68.64368238756734, 67.09249481078118, 63.56736267766645, 59.443155181023386, 55.94216523631927, 52.65656048251737, 60.61654006281207, 61.96219544256888, 68.21349251654841, 57.382153618720274, 50.1617447791561, 52.789030690347, 45.09709412051786, 45.22440248920072, 48.497479192672245, 54.758703785557906, 58.671307256144864, 60.44773694007628, 52.96896549963182, 57.33910952844928, 49.481452818839784, 47.081911486964074, 52.081646919250495, 56.821776359312004, 55.334860740169404, 54.89145640403994, 52.23306609738258, 52.13443417702952, 56.25330332786807, 45.12624125326834, 35.15680397710493, 55.546048994987245, 59.84625324126213, 57.78567529493763, 55.98587612951956, 54.9100366715462, 54.23018401668918, 52.909161121614524, 53.057454170719275, 52.88114755384384, 54.52680541623024, 60.11652808035574, 58.62629413604737, 61.70002814262145, 63.39733969780707, 65.29243676893174, 64.66899564189296, 67.18646695536953, 61.897464567615145, 53.67698861706642, 47.09086625806747, 49.42919508103402, 60.34699478457051, 60.71032785600232, 58.55003149278703, 57.9546235453698, 56.04758285707044, 51.7422285387593, 52.46758068761518, 51.950078856560495, 48.99030931534306, 47.05670633623677, 49.2420901790742, 55.22663078000469, 55.59019527127666, 55.748753163122366, 55.113556692677165, 57.090894099204775, 56.049430293421594, 56.44897860865439, 57.644493502955285, 54.346321475121286, 57.32610294895788, 60.423865395207564, 68.01694254721365, 69.71717234580748, 72.85706889244818, 77.6650788707118, 80.21144236287763, 73.75719008907195, 73.76563887442313, 75.4066801071167, 79.82377882926696, 81.74516754765665, 82.6117681687878, 83.75667664312547, 85.52869366061303, 88.49467231381325, 90.42089339225524, 71.29416127358714, 0.6224822301057078, 0.923228185744055, 0.265960875417917, 59.163894191865005, 85.57645243983116, 75.6431362705846, 54.95810139563776, 59.55109880816553, 64.92474986660865, 56.290036324531805, 1.7696762205131593, 0.2865672616227981, 0.26603782128903175, 0.1823335837933325, 0.10231907854998305, 0.09406251231989554, 0.13981158244273356, 0.24379559221767613], [0.032617285051533294, 0.10037602676499276, 0.014307622782765858, 0.10543841237743055, 0.045693210821839116, 0.04071473865018737, 0.17056828124388573, 0.005616625806602139, 0.2053323400116736, 42.3611310989626, 48.72574544722035, 35.693882357689645, 37.51501921684512, 64.14860302402128, 78.15168811428931, 68.00590499754875, 3.144318283565583, 0.7622516623908474, 0.3126565391017545, 2.676190022499331, 10.70888348164097, 76.00675567503899, 79.58062325754474, 77.056091677758, 77.95486357904251, 78.23601907299411, 77.66496119960662, 74.23503675768453, 71.23554537373205, 65.64297506886145, 58.88382519445112, 56.27881442346881, 55.192051164565555, 56.31555526487289, 53.6625817514235, 53.670497094431234, 52.822998416039255, 51.48689400765204, 51.74374649601599, 54.576003705301595, 50.77634880619665, 52.98041489816482, 54.7667524891515, 51.53716310378044, 53.14956318947577, 53.34221040048907, 52.02024221420289, 48.95211719697522, 46.3000262168146, 46.54707277974775, 47.0652453361019, 50.084274045882694, 50.142823265444854, 52.01655126387074, 56.28754954184256, 60.15305711377052, 64.9460679484952, 62.07080979501048, 60.13195083987329, 62.9174377072242, 61.53766947407877, 62.476131839136926, 63.206814489056995, 60.149185734410445, 61.31396493604107, 60.215167845449145, 63.11720794247043, 85.49040348299089, 62.6212203118109, 58.697438086232836, 57.99533774775844, 57.141649569234545, 57.093890790016424, 53.881701038729766, 56.29412735662153, 55.98375804962651, 61.1354108010569, 57.39305388542914, 46.9441774583632, 42.32970114677183, 50.93720128459316, 49.143089555924945, 46.684163539640366, 50.78024371977776, 54.95476738099129, 54.02995094176262, 56.881553280738096, 55.945683602363836, 53.80687006058232, 54.369196737966234, 51.84388068414504, 53.04033302491712, 53.17098325298679, 49.569345289661044, 47.65680151600992, 49.32904520342427, 58.21576710670226, 58.25360621175459, 28.47444234355804, 51.327112336312574, 55.003287100022845, 53.57195931096231, 50.98558764303885, 48.012772298628285, 46.54640989918863, 49.256830446181766, 49.289319438319055, 53.01877175607989, 51.58630255729922, 55.08802990759573, 57.07951138096472, 62.212560330667806, 57.273845211152114, 62.308736847293, 56.80639674586635, 59.926155844042384, 59.374392109532515, 59.324672145228234, 47.489014287148755, 50.663384545233946, 52.42594472823605, 51.63186088685067, 53.746045866320216, 54.26713666608257, 50.50364994233655, 46.727913656542384, 43.67553303318639, 44.5497352077115, 41.8098537383541, 43.97748101142145, 45.63805172520299, 48.92579417074881, 48.06620674748575, 48.46222492956346, 46.57543936083394, 48.76037997584189, 48.00377438145299, 48.424476039025095, 48.56732483833067, 51.592052751971835, 51.99854366240963, 51.612464766348566, 52.519916872824396, 59.32896321819675, 64.06020064507761, 72.4152531162385, 70.71955757756388, 80.7794721664921, 70.111205808578, 69.22688391900832, 70.86881160736084, 75.85118662926459, 71.74916405831614, 82.74385790671073, 76.09912749259703, 83.35304906291347, 75.4563843819403, 89.28757944414693, 5.4676741938437186, 0.33739382461194073, 0.15984799923194995, 44.367748998826556, 74.6008134657337, 52.92963981628419, 41.49709178555397, 35.539439032154704, 32.53431512463477, 35.37154197692871, 2.337245758502714, 0.21784958850231864, 0.08839518537804966, 0.054369440016847466, 0.07381814096363322, 0.06757858464674604, 0.057342542981308316, 0.03538259432741231, 0.04596567765298871, 0.05812019883324543, 0.0730895377214878, 0.02628358802007091, 0.06599930971260033, 0.01880438652850928, 0.11306033604928564, 0.07090971880261937, 0.6998990920762862, 56.92281661495086, 54.943957328796394, 33.18192589667536, 43.63959235529746, 74.67438144068565, 84.48424493112873, 74.24386209057224, 3.1002958070847297, 0.6762149016703329, 0.6120188173747833, 2.3550506224555354, 11.275175675269097, 83.08511195644256, 84.2577672773792, 85.3785139514554, 83.48982995556247, 81.99406546931114, 82.65100755999165, 80.77974673240416, 75.51626328499087, 71.0617765303581, 63.60894372386318, 59.61502559723393, 57.7899585231658, 57.23377819984191, 56.761607200868674, 57.17966518094463, 55.61079555942167, 56.730177248677904, 57.193656275349284, 55.366930038698264, 55.642409863010535, 56.349793634107044, 55.52819828833304, 54.754051854533536, 54.266128616948286, 56.966401992305634, 55.26064165176884, 52.56157636642457, 48.978302940245605, 50.25302617780624, 49.46059757663358, 52.982395695101836, 52.61335949743948, 55.543562212298, 59.340965670924035, 62.76798755891862, 66.74614167982533, 63.587821760485255, 62.76548900911885, 66.8076365993869, 64.42372983501804, 66.47522357202345, 65.24892591661023, 65.52625709964384, 64.92526369710123, 61.59216688525293, 62.75975450392693, 78.79873798739526, 65.43802730498776, 63.08035727470153, 59.771249678827104, 61.07266072304019, 60.94563084263956, 57.384542342155214, 60.87975463559551, 61.667625442627944, 62.72280577690371, 57.01215251799553, 48.92383298566265, 41.61642989804668, 50.84119735225555, 50.578735874545195, 48.802784719774806, 54.90007777367869, 56.92593097686768, 58.15422119632844, 58.816446719631074, 58.451379960583104, 55.274617056692804, 55.67810735394878, 52.92841603679042, 54.81944168767622, 56.73487232577417, 52.18608002508841, 50.589236059496486, 51.96313250449396, 56.28248183957992, 58.12376399194041, 31.286452278014156, 55.640789924129365, 58.07291438502651, 56.29770455821868, 55.2890553012971, 48.42234619202153, 50.825445113643525, 50.32426426487584, 52.12954298142464, 55.69437734542355, 54.274420507492565, 57.70582368296962, 59.64574167805334, 63.93563793551538, 59.57734338698849, 63.89877550063595, 58.283933977926935, 62.119392271964784, 61.986816160140506, 61.656485911338564, 48.19127152043004, 52.31402774010935, 55.37131917092108, 51.74240504541705, 55.908264190919944, 56.163790918165645, 52.15883916424167, 49.41364680567096, 48.964205941846295, 47.23425634445683, 43.72242104622626, 46.92262011189615, 47.09398846472464, 51.87577739838631, 51.5738372648916, 50.34140894489904, 50.44343371545115, 52.362500390698834, 50.50912164872693, 52.53925808014409, 51.25157925390428, 55.576376761159594, 53.63113610975204, 54.896943799911014, 55.26084169264763, 62.24892462453535, 64.84461584398824, 74.31733592864006, 75.62177504262617, 82.4382346676242, 72.99810947910433, 71.42542731377387, 71.43978318860455, 78.29199914009341, 73.19600874377836, 84.21702954076952, 77.73827814286756, 87.95715070539906, 76.98470454062186, 95.983261446799, 6.872721612453462, 0.48203413585020655, 0.37640038637384293, 51.42209253003521, 83.1085128168906, 59.87154076176306, 49.26145492061492, 41.97529931222239, 47.576251722151234, 49.52216309885825, 3.2954462257123764, 0.35339960768338174, 0.10831684219620882, 0.05951460142950377, 0.13631676594095846, 0.07794811330255001, 0.06276695493368373, 0.05477127994620993, 0.16495867902713438, 0.1567807057571988, 0.17170768381366808, 0.1624063498550846, 0.22025970111210502, 0.1512515734160139, 0.33420754236079037, 0.25634682436864226, 0.9292738452073067, 68.36228370666504, 62.49332358760219, 45.50643267170076, 52.66382863444667, 81.98945276198849, 90.91742623236873, 83.44646423093735, 4.696115053469136, 0.8683108971003564, 0.8922433612808105, 2.5865310142117166, 13.161482714837598, 93.94158932470506, 89.17234805322464, 90.94480437617149, 88.43697424857848, 90.09499149937784, 84.82531855183264, 86.46431230729627, 78.48214780130695, 72.67876578915504, 66.02811259608116, 63.97366531433598, 58.93212133838285, 62.72384520499938, 62.82958446010467, 60.789928436279304, 57.65004757911929, 57.96792430262412, 59.770284775764715, 59.52548180857013, 58.87362310963293, 59.43977409793485, 60.329889328249045, 58.3100804974956, 58.780482507521114, 59.65809322172596, 58.450089500796416, 56.79431584573562, 53.78907034474035, 52.84268479193411, 53.06442814488565, 55.88811105297458, 53.84619966630013, 58.79390093588061, 60.463406808914684, 63.729183981495524, 68.92467314197172, 65.35133900180941, 64.6015622538905, 67.85321497148084, 67.3303081143287, 68.62674559316328, 67.94720280554988, 69.22579350010042, 67.88633546521588, 64.21339273452759, 64.52835513699439, 77.92837189089867, 70.18920606182468, 64.64315506719774, 62.244900272738555, 63.24303757759833, 63.729285963120006, 60.428984088282434, 60.07462147743472, 62.37393056192706, 65.63521269829043, 53.95170750156526, 49.759874420781294, 43.874683533945394, 50.21614020870578, 53.550919717358006, 49.64276421454645, 54.68415521806287, 59.54303049272107, 57.78062328215569, 61.233046439386186, 59.9542635486972, 56.811491904720185, 56.840172275420166, 54.99496775288736, 57.22393697307956, 58.42414302210654, 52.99389216207689, 50.76007881472188, 53.81564048028762, 58.004865184907, 56.6851366719892, 31.537042702397994, 49.707228368328465, 61.75397249960131, 59.73115913329586, 59.67120570521201, 51.90987063992409, 52.66116534509967, 54.96727581947081, 54.06956295813284, 57.8959801889235, 55.53948294731879, 60.09069927277104, 60.796455260246034, 69.43022743348153, 61.229783027402824, 66.72682792909684, 61.67649392158755, 63.993002599285504, 63.54462862014771, 63.45740687462592, 50.435224194680494, 52.5082556663021, 56.36586358470302, 52.75359992058047, 58.1518756189654, 60.17882708580264, 55.49264984746134, 51.75078715047529, 50.34352310242192, 50.68518115628151, 49.1734447786885, 48.70783198264338, 49.80491891984017, 55.40162732524257, 54.3504007401005, 53.80384199080929, 52.981379801227206, 55.33104427399174, 52.910286841853974, 55.65427111041162, 55.471971111912886, 57.06644204355056, 58.07570319021902, 57.072227539554724, 57.645187762475786, 66.6255444865073, 68.97507559868598, 77.65244099401659, 78.4982216742731, 84.91075561892602, 73.01856856192313, 73.42345914533063, 75.29835208769768, 81.39595893121536, 74.51445856401998, 88.49493903498497, 81.13009283619543, 91.43609692973476, 79.96115592218216, 99.03880350051388, 6.082319405771071, 0.5474513949405763, 0.7508652056417158, 56.22812563373197, 90.07061004638673, 67.44751637981784, 61.70845731612175, 55.55973414451846, 55.86911893660023, 65.79287628973684, 3.8442990712581144, 0.38975326825053463, 0.30484038915845657, 0.11901472379723865, 0.33036328251323394, 0.17545930830942047, 0.16131824453271207, 0.14895494907133042], [0.07431359300690313, 0.0924230075531429, 0.045164671441119526, 0.07794160155519363, 0.07227755346966368, 0.012136800608958208, 0.03077767620373878, 0.10855372424327558, 0.5024209306124718, 52.29629078219014, 41.812265996010076, 40.6811015067562, 41.229303729149606, 60.92922749057893, 82.01916079367362, 45.03552075355284, 0.04121686331927776, 0.43939643990128274, 0.8196115457723219, 0.41497610028712983, 6.365598372874722, 82.41063687109178, 76.41381925152194, 80.42403482621717, 76.87880054596933, 81.21538869796261, 75.59449888044789, 78.07731213108187, 75.64277541252875, 63.355860633234826, 57.08054296432003, 55.560200906568966, 55.448601630426225, 56.25841025383242, 52.47234636737455, 54.01450857039421, 50.54777268440493, 52.54916598719936, 51.55219754865093, 53.806167956321474, 51.76570784661078, 53.04137245301278, 53.98504372565977, 53.32885865242251, 50.28127116541709, 50.938311315351925, 53.56617773732832, 49.42635528502926, 45.373385875455796, 45.35246787532684, 48.91650207581059, 49.45623590100197, 49.97261985655754, 49.44557489887361, 56.535062866826216, 58.89022650257234, 71.4486163662326, 65.8414234653596, 56.658095852021255, 58.94255484304121, 61.066745788820334, 63.16791242168796, 64.49409715590939, 63.51776430683752, 65.65827231253347, 58.85946727568104, 60.335274742495635, 55.11196028801703, 51.38724619342435, 59.002143490699034, 59.42849336131927, 58.29022153731316, 54.256840444380245, 60.45502078148627, 55.61893447752922, 64.21827608539213, 59.96528933125158, 42.44915300799955, 44.89173450777608, 56.8859737919223, 49.052184704811346, 46.836504474762954, 49.56411284785117, 57.15528372795352, 56.625344061082416, 61.03508833915957, 56.89092774544993, 57.349758763467115, 58.162775885674264, 58.44562976591049, 56.66561111327141, 58.30797810708323, 55.162904031815074, 57.31255900475287, 50.040398413135165, 48.805177365579915, 41.34041663139097, 69.28513896080756, 40.67694771674372, 34.00920867919922, 61.86351253140358, 51.082187775642645, 52.99007177352906, 48.72888726572837, 50.26496979498094, 50.20428288367487, 51.353584412605535, 53.11621127590057, 54.392228895618075, 58.41951070293304, 59.09993994620539, 58.26715800069994, 57.786777480956054, 58.70752249994586, 58.777936889279275, 61.924921158821356, 56.28805944996496, 60.84791283453665, 53.430436272774976, 54.250392067816954, 48.148082302462676, 46.24572884651923, 50.45544793528896, 50.14506293881325, 48.37465801546651, 47.8408940376774, 45.73171008017756, 43.39019629263109, 41.883225594797445, 43.146330771907685, 47.057914426249845, 47.59952706675376, 47.88920979345999, 50.52010428520941, 48.009559877457164, 49.79426576245216, 50.25662691362443, 50.731382754541215, 48.21822997062437, 52.56973881875315, 50.01890774696104, 50.5622148513794, 49.26206288799163, 52.45061251424974, 60.18665613666658, 67.99838973629859, 70.05572780486077, 74.44351073234313, 75.1009548864057, 79.62662481492566, 70.73276027556389, 74.34201548176428, 76.09652303880262, 84.04457076903313, 75.66436413795718, 80.9369396394299, 71.57688571560767, 98.57638743615921, 21.175031085168165, 0.6400661543011665, 0.8345988609137074, 49.035498942098315, 75.72567862849083, 51.978872975995465, 43.53661837116365, 38.01357992233769, 30.76310415421763, 37.95432467614451, 2.951365863123248, 0.1305409686099137, 0.11083580057827697, 0.06814423332651777, 0.1007238153608576, 0.04306536070221374, 0.09910896330350831, 0.011808326047274375, 0.049973834351065664, 0.09657481339790168, 0.035595195217719006, 0.036327920012897065, 0.06177839890663182, 0.01685183908369753, 0.02919523349602617, 0.10402442091294836, 1.6184932426098855, 65.87859184511247, 45.78160655113959, 34.99599856715049, 44.505384968173125, 68.87394905090332, 88.20237728857225, 51.155763595334946, 0.13124771536357943, 0.5822885384963405, 1.1666006522793924, 0.5236633230120905, 7.227169534852428, 89.58942936312768, 79.75090119146532, 86.71022922761979, 82.3568376418083, 84.87772926207512, 79.4717304168209, 83.30629441045946, 78.27998099788543, 68.44419848534369, 59.151950574690304, 59.4324274986021, 59.03853524115778, 58.94484942959201, 55.27441309344385, 56.38187077737624, 53.98294133524741, 55.03347758323916, 53.24359024724653, 56.87392034838277, 55.222892761230476, 54.658902998893495, 56.98149527272871, 55.61550240362845, 53.92982852074408, 53.49685768927298, 56.24237168219782, 53.297063919805716, 47.53554928687311, 50.15746939566828, 51.63884662812757, 52.67027701100996, 54.38863208217006, 53.68954020161783, 60.00937284961824, 63.0678213796308, 72.52293002220893, 68.82236203839703, 58.191279749716486, 63.18479038053944, 62.16455836449901, 66.52131926628851, 65.29359779050274, 67.36417385839647, 67.33956490793537, 61.30468853058354, 59.12220331930346, 57.41510937290808, 52.52463940651187, 59.844719594524754, 62.41486441704535, 62.87703729444935, 59.17951699226134, 62.86862381042973, 59.37918132351291, 64.64959952139085, 58.740352738288145, 44.96030930549868, 44.591857540992, 54.79688021444506, 49.37776496333461, 49.09196930546915, 53.82472076723653, 60.17541070138255, 60.2549877474385, 64.16310010417816, 60.19650913053944, 60.33510215820805, 60.80897546583607, 63.2171420897207, 58.020684103811945, 60.46050817735734, 56.890292321482015, 58.257206947572776, 53.0970230410176, 52.91491131628714, 45.490350953994266, 67.47579666876024, 41.22137661903135, 39.311821691451534, 66.75849714586812, 52.992703683914684, 58.210267943720666, 52.39406370347547, 52.09136263016732, 53.75003099441529, 55.50847661110663, 54.121565741877404, 56.951120438114295, 62.40035556977796, 61.28631222632624, 60.50864742648218, 59.80534684273505, 59.77291276378017, 60.810681696861025, 62.99860331319994, 59.61630821228028, 61.12578530465404, 58.31572871054373, 56.243324818149695, 50.43499277484033, 45.44145468742617, 54.14245236304499, 50.870387631077925, 50.911698033732755, 50.51875106749996, 48.31270417859478, 47.0937531225143, 45.72398301093809, 46.1705409326861, 49.754273276175226, 50.316929432653616, 50.85142689366495, 53.0118566174661, 50.96359491348267, 52.700769516729544, 52.544059061235004, 52.33606361573743, 51.471271207255704, 55.449154684620524, 53.01485330827775, 56.7504951261705, 51.4243753494755, 55.3999367836983, 59.08334439800632, 72.27165514423002, 72.9023644231981, 77.44398270883869, 77.98901957850303, 82.00225537823093, 74.11557705171647, 77.87291742140248, 76.66027745892926, 86.39014813207811, 78.20707198112243, 86.28103563862463, 76.08739176104146, 101.82772636413576, 24.655967912366314, 1.027922374346564, 1.1696802031609321, 53.48983664666453, 83.63706788709088, 60.27361116101665, 52.940038019610995, 41.525274015242054, 41.77001814688406, 51.44938045932401, 3.496727554067489, 0.25719921975847215, 0.19157047443572553, 0.03543699040047584, 0.050423926328338926, 0.04373586383618174, 0.021786412502068187, 0.04022885887553135, 0.18530396714566216, 0.23388993746090322, 0.09130001458669863, 0.13725672518053364, 0.17439487510390822, 0.147276327855164, 0.2572876875919681, 0.32819831803921734, 1.9287941532750286, 79.12217663180444, 52.96852227180235, 51.6457421548905, 56.23379738100114, 76.90453913904007, 95.57781388682704, 56.035321527911776, 0.3530894340045991, 1.233952773674842, 2.1931788181104968, 1.3418910075579922, 9.111007932693727, 97.83731875881072, 82.6082145014117, 91.98115733362015, 81.59283053490424, 88.93425233902471, 80.81136103599303, 86.74794673919679, 80.57281817159345, 71.69765549321329, 61.42923162829492, 63.94622833498063, 61.30768129902502, 60.66161594083233, 58.711488016190074, 59.550177051175034, 59.18389043500347, 58.98385347858552, 55.03934152664677, 61.69562724328811, 57.614522672468624, 59.14598464965821, 60.32731625341601, 58.229114932398645, 55.84796559426093, 55.834664837006606, 59.70990773170226, 56.489783025557, 49.525701076753684, 52.1135671677128, 55.107743740081794, 55.12274288362073, 57.4365137469384, 55.85963856789374, 62.51086834938296, 68.50470496762183, 75.43231671856296, 71.60855493237896, 58.721082133631555, 64.1812999017777, 65.73118525166666, 68.29772149362873, 70.44151644552909, 69.38760695918914, 72.16644933146816, 63.984569503415024, 60.57881862886491, 62.01963463137227, 55.05601552224929, 61.01071865327897, 64.45798389373287, 62.69035208609797, 61.08410227683283, 66.82291815357824, 64.90715803638582, 65.5123483750128, 57.98613978970436, 45.42350199914748, 44.49243330186413, 54.320492667536584, 52.016237474256954, 51.82809314420147, 55.396826344151656, 61.84965479758478, 62.130496501922615, 65.97134021020705, 61.88445798812374, 61.59507728392079, 63.38783187250938, 62.786069685413, 59.99601325681133, 61.06802055912634, 60.34512773636849, 59.485975696194565, 54.01013120528191, 54.26445768725488, 49.82885322263164, 65.87705427600493, 40.39617269269882, 40.02833674030919, 62.310309717732096, 55.62949742040327, 59.1435057117093, 56.895642434397054, 54.47724626910303, 56.41603462157711, 56.28950288218837, 57.96542183045418, 59.51808421842514, 63.020121435965265, 64.60919518624583, 63.34672151073333, 64.65291392418646, 65.64364971653109, 62.077132655728256, 65.54049922573951, 62.342061304276996, 64.62601430954473, 60.35984054688485, 58.33205753757108, 51.38006433363884, 45.58418973799675, 57.23108353153352, 54.88965603613085, 53.944655079995435, 53.09985891465218, 51.649707671134706, 49.693515762206054, 48.060193754011586, 50.59141689731229, 52.89222824958063, 53.55476364012688, 55.623582486183416, 56.7754884689085, 53.38810997624552, 57.24366257267614, 56.76848311578074, 54.49527348241499, 54.52329881729619, 59.79450541157877, 55.64332377526068, 58.457953852991906, 55.06879068190052, 58.34339710973925, 63.98557755254931, 74.87354370855516, 76.0777505751579, 81.65738490320022, 79.4406024871334, 82.39376283461048, 72.75396547009869, 79.92330505001931, 79.89449916347381, 90.53971767425539, 80.49853632527014, 90.15866725675522, 78.55227977998796, 106.41046677866291, 25.39849808139186, 1.3643265972214362, 1.6626435638435426, 60.01676259502288, 92.38887986829205, 68.80127537635066, 68.73912934334048, 56.939012081392356, 51.991310811811886, 69.5120559200164, 4.462154007727101, 0.3831061071926548, 0.22671016143454661, 0.13834014204480957, 0.1704228777558573, 0.1175552267100542, 0.27515953827288847, 0.17195997188889212], [0.031774839228619976, 0.1196770374512961, 0.046963932353162, 0.07630608044564724, 0.05066974479104242, 0.02992750055366947, 0.09371342903543865, 0.06696379142663172, 2.3967378177950462, 60.275211488046956, 42.332709604694, 35.150445815055605, 43.7206010664663, 57.10853692023986, 80.42084986163725, 40.4045351859062, 0.1569089182322064, 0.21942653452917454, 0.20661907661105358, 0.46664186663204626, 12.155979198794212, 85.27795222497757, 69.67809769415086, 83.34466303548506, 73.45319855597712, 81.61745517484604, 78.13839127940517, 77.06279893075266, 70.33681269614928, 62.31957435607911, 54.66568477692143, 59.87693794312016, 55.5552508754115, 57.263862779063565, 52.43806092969833, 55.07920849707819, 50.54380716816072, 53.73724799002371, 52.441975455130304, 53.173069953918464, 52.995680762875466, 51.71556034395772, 49.78252610852642, 50.93819364424675, 51.27215208545808, 53.760201700272106, 53.34954131034113, 50.27478356515208, 44.89273078979985, 46.97451699164606, 48.86640948633994, 48.276394797909646, 49.06534817910964, 51.2290491596345, 52.61752113219231, 58.23789319684429, 69.77061856177546, 56.07322339088687, 56.39717194341845, 57.02912853610132, 56.711243967856134, 57.111184520106164, 63.54777043865573, 61.11934477283109, 66.43828268974059, 60.62028592632663, 57.113843887083, 48.739693395553104, 55.13344310945081, 58.81742731217415, 59.26089048385621, 58.323746035175944, 58.67016584642472, 54.74706611325664, 59.11635898774671, 56.69988086146694, 42.28637072347826, 60.85655773839643, 59.8007772814843, 41.74488359881986, 43.58991553706508, 50.88107216742731, 59.73315954208375, 56.849252562369074, 58.10769011897426, 57.36895092072026, 58.76804859407487, 60.277545298299486, 61.18141235843782, 58.80728798527872, 60.99142843677152, 55.83846169133341, 56.35112723996563, 55.9284604749372, 57.755398519577525, 49.64540004730225, 42.365355491638184, 45.22356310198384, 66.72371356718003, 32.52218911724706, 42.93291461083197, 58.401208923709014, 52.66585649982576, 55.22949411023048, 53.6113634417134, 53.89128338906073, 52.59919974111742, 56.8743125854, 57.20248945297734, 57.775583036484264, 60.814482473558, 60.62896613151797, 56.156377638539965, 60.228645109361224, 60.53082450743645, 60.95363247779108, 61.12512242409491, 56.88464410843388, 57.23992455390192, 54.3775043179912, 51.74688439215384, 54.12840243308775, 50.203541555712306, 50.07577426971928, 48.044214017929576, 46.01406974177207, 44.07902333044237, 43.38834493390976, 42.60448671156361, 43.99998364910003, 46.6018408344638, 52.67900428464336, 48.0899880778405, 49.54515995517854, 48.16476806517571, 47.69841394116802, 48.045806500219534, 49.415152995817124, 48.6230734855898, 51.78419789960308, 52.3632142620702, 52.93760222773398, 53.183279883477, 55.316935508481926, 52.7860693008669, 58.53005486149942, 65.5956438279921, 71.56835848285307, 70.5095931022398, 78.35758901411488, 74.88911551813926, 80.05011527769028, 76.86245210709112, 81.58931609122985, 74.50670011581914, 81.7031354288901, 72.43684968640729, 93.89194780780424, 38.43217134475708, 0.4667861056664298, 0.8221879301051941, 56.32268613384616, 69.62288641160535, 51.45274977530203, 38.68374040049892, 50.14354890392673, 33.57063670312205, 41.93693460956697, 3.381578778066943, 0.19505314078302155, 0.10603566218407885, 0.10627907130026049, 0.017346140079861207, 0.023345843843755223, 0.10903132643790976, 0.021782662501678835, 0.05097937454739886, 0.07435968085642784, 0.12338041372957731, 0.07137104162886258, 0.11548692721032328, 0.03937399285214563, 0.08357847650204936, 0.20349823359039523, 3.797367912146353, 70.81810320577314, 48.72751051379789, 37.56921852788618, 48.904617294188476, 66.93105789922899, 88.31422759640603, 45.08477395580661, 0.19150410057796588, 0.3148800633367031, 0.23249450830682633, 0.3882771393945141, 14.006514222391191, 94.42511558532716, 74.91421868724208, 88.18165148458174, 77.7335242302187, 85.51730309763263, 83.64524210652998, 82.24203771160495, 74.4309042346093, 64.93370463771205, 57.65685289136825, 63.04229459454937, 59.8746943473816, 62.10462062589584, 56.04282502205142, 56.941620457556944, 54.64617098531416, 59.8388478063768, 56.62029204830047, 58.045379346416844, 54.89450408566383, 53.96769508238762, 53.98781291900143, 54.543126398517245, 52.85240442522111, 55.44447529700495, 56.35845422744752, 53.16922995351976, 48.2145703992536, 48.49239580092892, 51.27389361781459, 50.593621269349136, 53.12995133861419, 54.00831514789213, 54.61013617054109, 63.68204493676463, 69.27541148278021, 55.307812075461115, 56.05947156106272, 58.06377526252501, 58.77113157703031, 60.061203049075225, 66.61861758078298, 64.37602596898233, 66.57318868944722, 63.73122361398513, 58.28544409044328, 52.682816828450854, 56.01800034123083, 61.164318669226866, 60.30444099057106, 60.34191139282719, 60.12233711058094, 58.20729870950022, 61.85938227561213, 59.635892606550655, 45.688818962343284, 57.767240155127745, 56.803164712844364, 46.8113777714391, 47.985723633919996, 52.451851983224195, 59.8042211224956, 60.5505540294032, 58.963719952491026, 59.81845148148076, 63.252670918741536, 63.10790015805153, 62.35597787364837, 60.314023340902025, 60.36851682970601, 61.45089487875662, 60.578069456162, 59.14791837815316, 60.45048652156707, 52.914385718684045, 48.41752559907975, 48.530340809975904, 64.64100953071349, 32.700813854894335, 50.08069684428554, 63.903164632858775, 56.13790327502836, 59.15904221996185, 55.741339883496686, 56.74564707663752, 56.258939773805686, 58.65660229036885, 59.10512139720302, 59.74026687683598, 61.8432064210215, 62.14810402162614, 57.960012881986565, 60.63610092286141, 61.54814612480902, 61.69039872384841, 60.77790244933098, 59.701623685898326, 58.105846604993275, 56.06588463629446, 53.50489462575605, 56.74189729075278, 53.6001846867223, 51.736819590291674, 48.803518202997026, 47.934666141386955, 45.47287287250642, 46.282391240519864, 45.563095231210035, 47.281866073608406, 49.90289580437445, 54.99237506620346, 50.85956188940233, 52.94769840855753, 50.72822132418233, 51.50023791097826, 49.14741985259518, 52.75914222963395, 51.13377086577877, 55.329063477054724, 54.920101473408366, 56.92285191628241, 55.55122260124453, 58.092620372772224, 53.92850668199601, 63.17818903153943, 65.97015565441501, 75.32405930180704, 73.5830682323825, 80.44329366376324, 77.87272130289386, 82.72503052988361, 78.68192980366369, 84.64414427357336, 74.91691727792063, 84.77140165144398, 76.32756633143272, 97.0490635595014, 44.384375925987, 0.3890804591919146, 1.0853293874571401, 63.288329185978064, 78.10924022428452, 60.7392474912828, 48.585191234465576, 64.85526507900607, 44.36925518897272, 53.39632341938635, 4.060173577839329, 0.16982039556868617, 0.14493890166763337, 0.04569935867743147, 0.020338119450776328, 0.01791016082279384, 0.0544258585620311, 0.025959959922118053, 0.26598833200912325, 0.18190026914160098, 0.2388913424745683, 0.174395625870074, 0.31092331113834537, 0.07947267423714362, 0.20082061839920862, 0.37014322535645583, 5.800141644093299, 84.9952591619184, 55.145751507051536, 46.439152686826645, 58.437145679227775, 74.99758474288448, 94.33581890598421, 50.64677722992436, 0.3933614197998278, 0.4098032601177693, 0.6099106046941973, 0.6078288067252405, 16.794459435247607, 98.85729189841979, 78.31615309561454, 91.32018304640248, 79.96550190833308, 87.94033942684051, 86.89876187232234, 85.5294075319844, 76.15221285050916, 69.7101983716411, 59.282361538179465, 67.2432158070226, 61.5833572418459, 64.22197095809445, 60.27381120189544, 63.03714452251312, 56.61602843192316, 63.37042439368464, 57.91291698332756, 60.296141255286436, 58.32524830295194, 57.9289359431113, 56.74696891538559, 56.80225080059421, 55.91624621422061, 57.57138836768366, 58.73061349315029, 56.9850960085469, 51.513271947060865, 51.796059147004165, 55.76039868016397, 53.54423207621421, 55.90186680516889, 56.18466184985254, 56.37209230853666, 63.35830034748201, 71.76865039333221, 59.813556363505704, 58.09065134294572, 62.905435254496915, 62.00945608077511, 64.29398567445817, 69.94048856919812, 65.44646824559858, 68.9795627901631, 65.14453595684421, 57.55257668033723, 57.93725136787661, 57.3469699582746, 66.70242294188469, 66.02266050154164, 63.78354803208382, 63.353954361331084, 60.6532181462934, 61.04370578642815, 59.39807538063296, 44.97116642613565, 59.17560638919954, 59.53128299405498, 52.8638106776822, 49.37075961020685, 55.18796797721617, 63.26268080742129, 65.44015715199133, 61.47841422788559, 63.31463260035362, 65.09409427642822, 66.68497623935824, 64.96227910441738, 63.72273168256206, 63.193356836995775, 61.02981667364798, 63.68660273090486, 63.31977090527935, 62.188437754108065, 52.62102773112636, 51.53529997794859, 55.91931350769536, 63.51437930137881, 32.444649742495635, 48.53068990092124, 63.1268334388733, 58.97593029083745, 61.745535481360655, 61.27655729170769, 58.32328319549561, 58.797650721765336, 60.946403549563506, 63.998831241361565, 63.83604895684027, 65.78491780065721, 65.31438635241601, 62.78702674373504, 65.17375761462797, 64.633964953884, 64.69575012883833, 64.13238010098858, 61.09447302356843, 62.560584391317065, 57.969940400892696, 53.991201846830315, 58.37844740959906, 58.05015679328673, 55.030959421588534, 52.55006028759865, 50.36964216539937, 49.516091269831506, 49.490564484750074, 49.72792671572778, 49.73820724794942, 52.36228466033936, 57.73923443209741, 52.939841901102376, 55.61889917619767, 54.3983321036062, 54.466000833818995, 52.028969487836285, 56.164806812040275, 56.97950663105134, 57.49620437622071, 58.28234541800715, 59.82870063474102, 58.110769179559526, 61.34743844309161, 57.365287426979314, 65.39310047703405, 69.4300470044536, 78.16798163998511, 76.63915157318115, 83.12856397321148, 80.73675755531558, 85.32572669367637, 81.72994875138806, 88.69979658434468, 78.8357259381202, 87.87652246413693, 79.49229932600453, 99.55006091825425, 44.873911257713075, 0.6268415155429995, 1.6149393300856314, 69.4796649871334, 85.61596639694707, 67.98148432085591, 56.80040728661322, 76.28002720494425, 62.393138408660896, 72.25545575541835, 4.940570400607202, 0.47150189778016466, 0.40835826507499146, 0.12259841415910952, 0.20305967889726165, 0.11698034667079488, 0.15527587924753466, 0.05405432124051356], [0.06737852844619943, 0.08049633624332567, 0.09047779540020613, 0.046101577820316444, 0.03865716438139639, 0.08284898459791176, 0.22547637683249291, 0.33829253767767264, 2.0671800307689177, 57.969905099561146, 38.58561446589809, 50.38030316752773, 71.03543389228084, 57.71893616645568, 81.2624728295111, 45.821387229427216, 0.14638821744630415, 0.3065487039425681, 0.20146289119316688, 0.33847998407098556, 27.93096853840736, 96.30362495299309, 71.38017100672569, 83.54639053344727, 75.08711676443778, 83.19826449117353, 74.08563367782101, 81.05719950891311, 68.28844901054137, 59.62498841747161, 55.8251020985265, 56.90306748113325, 53.01107606580181, 52.182820535475216, 53.92492948039886, 52.89598195783554, 53.27114882007722, 53.82803517003214, 51.29991462153774, 52.350352810275176, 53.06777392664264, 51.58752633679298, 51.697223263402144, 52.44457206418438, 52.449137703064956, 51.69731740028628, 51.364139510739236, 49.52561478460989, 46.08235428410192, 45.73689545354536, 45.93253935537031, 47.873265358709524, 47.882553531277566, 51.18550300598145, 51.2532070375258, 64.08757878888038, 58.882428830669774, 49.332583181319706, 49.94257057866743, 55.41051149368287, 51.69357545914189, 54.379159558203916, 59.487866278617616, 61.26861056973858, 61.595351849832845, 54.42833431305424, 51.220604296653505, 43.79261186045986, 55.12060126950664, 54.816845078622144, 56.584716150837565, 51.779279247407, 54.01768569023379, 59.78597817882415, 52.27106994198215, 43.931483376410704, 59.950454927259884, 52.33741683344687, 34.49206421452184, 44.65049305269795, 49.987968091041814, 54.087084185692575, 59.102815043541696, 53.11677609720538, 55.43549306931035, 55.30978110528762, 61.41305969607446, 61.21490547733923, 62.922336747569425, 60.49750397282263, 59.76387562290315, 57.44335828288909, 57.51576131389987, 53.507063696461344, 56.20423447701239, 57.40025535706551, 45.771882995482414, 35.758903488036125, 47.61165895769673, 56.5235742445915, 32.637220467290575, 46.51886701583863, 53.64127151427731, 55.90299644777852, 55.298312094903764, 54.00722472898422, 56.98169923597767, 53.80852922316521, 55.21100013486801, 57.30319630715155, 55.655871437441924, 55.24770959731072, 57.045253399879705, 62.773376895535385, 59.851081678944254, 62.121992803389034, 58.07560905333489, 56.1793117369375, 53.89164424711659, 55.52657050471152, 57.96035020582138, 62.54645209158621, 48.95858518538937, 48.12255943975141, 47.45323442643689, 46.59494530770087, 43.05237431680003, 42.93899428459906, 43.153300823703894, 47.95139505017189, 47.68099861760294, 50.0148049477608, 47.935587898377456, 50.21011937049128, 49.57502880404073, 49.46894438036027, 49.0604373716539, 50.01161998318088, 49.97745613898001, 49.904727551244925, 49.7726809593939, 53.913456547644834, 49.94277454191639, 53.16831996363979, 51.580164047979544, 54.46492610439178, 57.39528179168702, 66.38559741358604, 69.36307645613148, 72.40325850825157, 78.3059549331665, 76.99549105859573, 75.80586756429365, 77.51697801774549, 71.28118607305711, 78.5351311775946, 74.88600900096279, 89.50402367499568, 56.90728795143866, 0.0588218740848524, 0.8166920153364059, 62.764963411515765, 68.43009364220404, 47.88256529838809, 46.649128929261245, 22.17516487644565, 35.6799461764674, 32.9339026635693, 3.345606230920361, 0.10958326214383687, 0.14469076578895892, 0.0680393405679253, 0.03621679129860094, 0.04956484682136967, 0.20787182955011246, 0.05085273255263606, 0.10776985541827257, 0.06781819396682325, 0.09712059741779681, 0.05904312793826384, 0.029623534102293275, 0.03754730216197429, 0.06427231770489486, 0.12160541099165717, 3.1049180751846683, 69.52310131442162, 43.16914327682988, 54.94621661401565, 80.64801000779676, 63.227155900770626, 89.97376672683224, 48.341588512543716, 0.1626579178076598, 0.5564674530779162, 0.22720382849295295, 0.5148390932909904, 31.03035092353821, 99.5073776860391, 78.53988509024344, 88.73705910098168, 77.845500053898, 86.94797192850422, 80.26157809842019, 83.83721074750348, 72.644484273849, 63.47864650910901, 61.27230936481107, 61.11453594699983, 57.66740798950196, 56.384467386430316, 56.39036663116948, 57.532227423883256, 55.58153860030636, 56.630321548831084, 55.22776826735466, 56.711291036298206, 55.823223283213956, 55.99182636507096, 54.111649990081794, 55.40453380154025, 56.64128849583288, 54.30608972426384, 51.45091410606138, 52.648711819802564, 49.41618850154262, 48.77867783269575, 48.61280864284885, 51.58785581588746, 51.386367582505756, 53.91719064404888, 54.07708998649351, 64.83943831536078, 58.0565934027395, 52.98182302905668, 49.915584671881895, 56.48044386217671, 55.800171513711255, 58.76341627490137, 58.386037195882494, 61.925972354027536, 62.115595417637984, 55.737146869782485, 52.6719989315156, 48.22670229019658, 54.33682541693411, 56.34912683117775, 57.05264706765452, 55.67370253224527, 55.23622881981635, 59.0040183836414, 56.24093217234458, 46.23287131709438, 55.75420525766189, 51.13489658601823, 41.887952050855084, 48.943134969280614, 49.955569313418486, 56.65828020341935, 60.65141385601413, 57.613291048234515, 59.38818708542855, 58.94443758072392, 61.939092682253936, 62.32852520481233, 63.36366614987774, 60.96628996633715, 63.148716342064645, 60.71730575253887, 61.70077339295418, 57.902930628868845, 57.33246895574755, 57.07396122717089, 49.59218917354461, 41.054911228918264, 47.86842907628706, 53.69196030401415, 34.24124040911275, 54.993732206283084, 56.71064384521977, 59.369132211131436, 56.87940774425384, 57.50017773720526, 61.01964989016133, 57.02584943463726, 57.44182855852189, 58.05970384228615, 55.56470378752678, 56.90837444797639, 60.20695832467849, 62.98579677458733, 61.73682389720794, 61.54247829991003, 60.85183520470897, 57.920451856428585, 58.227706801506784, 59.91303943818616, 62.05306106998075, 63.68615950307539, 54.32410517046529, 50.97344790735553, 48.17112622722503, 50.67150777386081, 45.07602707032235, 46.871805806313795, 46.21092173361009, 48.55786015910488, 49.394823351214015, 52.065855456936745, 50.2636165772715, 52.567914916623025, 52.79228625759002, 52.383069299882465, 52.59586180410078, 53.18229929093392, 53.745551647678504, 54.457320628627656, 53.76484578655612, 57.787632557653616, 53.34539144269882, 55.77151075486214, 52.390129566192634, 56.79530428301904, 59.92513602779758, 68.38619447523548, 71.01048761798491, 78.14745195450323, 78.15334335450204, 79.7339173286192, 78.62644395520611, 80.69565896065005, 72.87814770975422, 80.8536284969699, 78.16355720643075, 94.0876897688835, 63.783610790006584, 0.020289681626543887, 0.8568194556620814, 68.06230083588632, 76.44315073567053, 57.09325144367834, 52.57522621462422, 33.29145023899694, 48.41386995007915, 45.633744962753795, 4.742151912181608, 0.18469452888013857, 0.14719858525260804, 0.0837226465885197, 0.04951309758208452, 0.01993059514901571, 0.21311286686649247, 0.04085075756114337, 0.24765195625443615, 0.19646974460732555, 0.28743303290778593, 0.14013431996347445, 0.11703968784140965, 0.20426812131078015, 0.3020314818188068, 0.6062050680479696, 6.548590179412596, 86.21909356886341, 51.79965596045218, 61.279008773065385, 86.66816572989188, 71.95197413044592, 97.75029705416773, 54.51031577202582, 0.5213719846740846, 0.8393784528297763, 0.5035097254139762, 0.8585844609525897, 34.24940678381151, 102.66588980151762, 81.07051203327795, 92.11826770536362, 81.62795928216751, 87.53752769962435, 83.22887466799828, 87.90466939249347, 74.8710020126835, 65.43002959220641, 62.71368626625308, 62.983804210539795, 59.5534679197496, 57.92978317506852, 58.67950893217518, 57.99842073071388, 59.78872776031495, 58.63148735415552, 58.725749754136615, 57.833559590001265, 58.40249153875536, 57.92843780209942, 57.31200595055857, 58.14911427036409, 59.12754950984832, 56.39011559947845, 53.919143984394694, 55.623708002028934, 52.73097961179672, 51.909141079072036, 52.29475321308259, 56.508645703715665, 55.813080033948346, 57.0037978695285, 56.11844831897367, 67.8197414644303, 62.08185126704555, 53.32604239063879, 54.033261422188055, 60.40990567976429, 58.03018016199912, 60.498974861637244, 62.249179578596554, 64.00798605334374, 67.06122567576747, 56.05563940540437, 56.105280922305205, 53.237945956568566, 59.43281189087899, 61.377526944683446, 60.96423856673702, 60.59504155189761, 56.2880672947053, 58.80118869966077, 55.07684330786429, 50.83746717822168, 59.6181046578192, 60.863057105771965, 47.318473554426625, 49.529105694063254, 52.016366912472634, 60.52294054339009, 62.91374675689205, 59.28651140582178, 61.95084802566036, 60.62089389370334, 65.05569427244126, 63.976614936705566, 68.17427665956559, 65.02702566885179, 63.77024335245933, 62.061431407928474, 65.09201149786672, 60.8208014119056, 62.48797739705732, 60.7448172569275, 51.65072748737951, 47.58156653373472, 57.88235779731505, 55.86150169372559, 34.20555860765519, 52.75969920619842, 58.610867454159646, 64.72153186798096, 60.2043499485139, 58.9774521704643, 63.28787419103808, 59.52002579166044, 59.64357652971822, 60.6917554332364, 60.29353287912185, 61.770881837414166, 63.63598062146095, 68.6783718293713, 63.401415040416104, 65.31459816040532, 62.528173846583215, 60.49222446257069, 60.87922511562225, 60.0363548340336, 63.82846309292702, 69.30486063803397, 55.778527875100416, 52.42357953902214, 51.8541729834772, 51.98317973844467, 48.249510872748594, 51.07901850054341, 49.89821641675888, 52.74686128862443, 52.90303045703519, 55.49575636463781, 52.551848888397224, 55.29825325935118, 55.294581920869895, 53.23875788719424, 54.907518509895574, 55.917858308361424, 56.16639929433023, 56.73139318343132, 56.94936713864727, 60.13928174972535, 56.23114193639448, 59.72871549667851, 55.92252985123665, 58.20722418446695, 64.26365398591565, 72.73383586637436, 73.79420941875827, 81.15662374804097, 82.04427180751678, 82.42775409452378, 82.31061643169772, 83.29894388875654, 78.16977024078369, 84.71202481177546, 80.9172728753859, 95.64228980771958, 64.10142867795884, 0.18652512661872372, 1.5153014443574415, 74.87903502679642, 82.25135726313438, 66.25655143491684, 66.48833213313934, 35.54019212722778, 63.037897617586204, 65.00083208084106, 5.7228390824410225, 0.2862519398331642, 0.2124145930452693, 0.09508833469402406, 0.30887635484818493, 0.12360342192433535, 0.30500491420107506, 0.10907933716812443], [0.03366866411881582, 0.10049890726804735, 0.06942013744264841, 0.055879751716049454, 0.10682644878303814, 0.06965844441325435, 0.11403337496543124, 0.14348037751211276, 0.6972293063036857, 47.13632652836461, 40.3912305062817, 40.040472553622344, 38.1088895951548, 59.24294956268803, 79.93633516373174, 44.06291415614467, 0.17577032468491988, 0.12198667762981308, 0.20790483261789047, 0.23471844622925406, 50.84527661723476, 92.17882910082417, 75.55364347273304, 84.2850983527399, 74.97624704914709, 77.94168441526352, 74.34024257044639, 82.77297758287, 61.97072659769366, 58.09122793136105, 55.01505028816962, 56.83528892455563, 55.92051767533826, 57.59431854371102, 55.36014433830015, 57.04840306312808, 53.6720464306493, 56.132325664643325, 52.910498649843284, 56.320893610677416, 53.82746250398698, 52.98028545994913, 50.19214707036173, 50.150165942407426, 50.01592674563008, 50.384158857407115, 51.12754606431531, 51.55963044012747, 47.90910405497397, 46.957823384192686, 46.31599026341593, 47.74874579521918, 48.58743483020414, 47.88919802634947, 50.7849701758354, 64.3460355266448, 59.53513868393437, 51.62727563611923, 43.64489147740026, 57.802482651126006, 50.79341111644622, 54.30351272706063, 52.65811374110561, 56.31417851294241, 49.96856804816954, 52.21690985464281, 45.60145208912511, 47.22862382088938, 54.48328279679822, 53.60953169484293, 54.737330790488954, 57.37855288290209, 58.95647533478276, 44.260248599513886, 40.57098096416843, 47.25196976815501, 38.545441550593225, 31.40829678504698, 44.54514995698006, 49.10697629374843, 53.17641573567545, 56.46782951970255, 51.31479217160133, 54.48121570771741, 51.10606716525171, 56.245038893914995, 59.42902288129253, 64.78780031204224, 53.5774584739439, 56.40094918589438, 60.09529236824282, 55.865404452047045, 53.845187694795676, 54.97269261267878, 52.9880399857798, 51.803817595205004, 53.15643518201767, 48.21036954079905, 32.709041026330766, 38.64155923166583, 42.07971280620944, 33.439731520991174, 46.50921014047439, 46.75050258636475, 57.00886164942096, 54.332734384844386, 58.10713706477996, 56.82895037435717, 54.667904838438965, 55.21660520184425, 51.47776272989089, 51.13146843448762, 59.23106478106592, 60.617763842305834, 61.865775738993, 60.48917285857662, 58.775226531490205, 52.94858486421647, 52.57040562168245, 58.762282709921564, 60.80855577222763, 57.60964716634443, 49.33332450928227, 47.46675483642086, 47.762983998944684, 46.31786123398812, 42.21524246277348, 41.937028746451105, 44.08331832578106, 49.46723030459497, 48.17768443015314, 47.82411413808023, 50.357863287771906, 50.314685836915054, 48.87508969153128, 49.31557578425254, 49.64954207020421, 52.64777437333138, 49.31551302632978, 52.10263944441273, 50.471608100398896, 52.704546759205485, 52.03846162365329, 55.10848899041453, 53.825936701989946, 55.47044923228603, 52.24071864158877, 55.35424901593117, 56.179041093395604, 65.82496520011657, 66.60901561860116, 72.08948458394697, 70.70229130406534, 69.38901901245117, 65.34618108503281, 75.15476980516988, 74.02621761445077, 87.44546182693975, 67.07835074393981, 0.2202062741402657, 0.4789159741372832, 63.732290498672, 67.8745997336603, 51.52781217328964, 43.398421502882435, 36.44461616393059, 33.366704833122995, 29.021320766018285, 2.814105215572542, 0.18914772137518854, 0.06684880162919722, 0.06340338247677972, 0.09010582140857175, 0.054244445111121864, 0.01615263063520674, 0.05639889885881736, 0.09023961100366809, 0.04881678494594751, 0.06436442445603109, 0.05233926488266838, 0.11309451123158779, 0.06096042001680021, 0.11499596444228966, 0.186148441186355, 2.5271558905801466, 62.380912380833784, 44.65059111195226, 41.575346992861846, 45.42951107025147, 66.26791846367621, 88.31044643155991, 49.14794937256844, 0.06967474676428304, 0.13267205667591866, 0.08744329814949343, 0.031309333562310186, 57.483786152255156, 97.20704094056161, 78.45440879944833, 86.16200739337553, 77.61977549522155, 83.9887946651828, 78.90974890801215, 84.55411018863802, 66.80849167608446, 58.953847346767304, 57.81044898494598, 59.474996982082246, 58.67250357904742, 59.70201200054538, 59.023179161933164, 60.278243480190156, 57.625811253824544, 58.91310176541729, 54.21451022548061, 59.02479517844416, 57.895489892651966, 55.10808106391661, 52.5878680136896, 53.81417351384317, 52.19176746183827, 53.849502301985225, 53.533037631742424, 53.934476529398275, 50.82872029273741, 48.71214266746275, 47.57381593027423, 49.67068756780317, 52.631523993707475, 49.679665873127604, 54.7889256477356, 66.33685019708449, 62.38366588469475, 52.83124716051164, 46.90684041669292, 58.1777750292132, 50.763102962124734, 54.71849556892149, 54.36729046606249, 57.30906025055916, 51.14192155099685, 53.91522553659255, 48.50467281956827, 51.435789446676935, 57.987857787839836, 58.60207350023332, 60.08365469594156, 57.59551486661358, 59.18885223327145, 46.40085074209398, 42.882331725089784, 47.590564450910016, 41.75082991200109, 39.607886114428126, 46.2695219439845, 48.79707374880391, 53.50963284892421, 57.37936481352776, 54.78411682190434, 57.108219208255896, 54.596894248839355, 60.48967099958851, 61.14889983207949, 64.94611501693726, 56.536725951779275, 56.443620650999016, 63.13257971117574, 59.20870334871354, 56.095922147074056, 56.40898220000729, 54.147378859981416, 54.76494427650206, 53.71765182864282, 50.324291721467056, 38.86472640498992, 42.26878281562559, 41.2656601782768, 36.33522518219487, 57.40630365187123, 49.8256721804219, 58.05476165586903, 56.116353773301654, 57.68557640814013, 59.22591470902967, 56.00901419116605, 57.75828930639452, 52.19138699193155, 52.069079645218395, 60.150629166633856, 62.605240575728885, 61.6913636269108, 62.29106264729654, 59.62531789656609, 53.502392153586115, 54.55130061795635, 62.122757665572635, 62.58785663112518, 61.75547868974748, 52.8808416089704, 48.67631181593865, 51.12600065046742, 50.235136247450306, 46.275240759695734, 44.583275395054976, 47.02223262479229, 50.77921213642244, 50.24229849538496, 51.54072069352674, 51.288312250568026, 51.573782351709184, 52.03271535135085, 52.909180733465384, 52.78974063934819, 55.32928312978437, 53.6822759720587, 55.163347259644546, 53.4700482891452, 56.84110579952117, 55.496701655849336, 57.40777846305602, 57.54867784438595, 57.88136151529128, 55.08596281851492, 57.915195880397675, 60.23588972706949, 66.36197690040835, 67.87885942766744, 74.00560948156541, 72.97244933343703, 70.84882320896273, 67.46426490045363, 78.62928375121086, 78.79455674079158, 88.14562059217884, 73.52253037114298, 0.5318663473571501, 0.39256517865484764, 70.78544555171844, 74.74310921084496, 57.33262585055444, 51.378365947354226, 39.70135227326424, 48.368743081246656, 46.61329023299679, 3.2286399266412182, 0.17244138154050997, 0.08222707442098087, 0.038429820128986915, 0.03233197858677276, 0.023023845597861275, 0.03196422190916154, 0.025559401274808956, 0.13606754221743153, 0.13565999876347282, 0.1830787881607971, 0.1524670331949188, 0.19631844224228015, 0.23467084152563927, 0.2616832243098367, 0.5399968078540218, 4.887303142778335, 78.80138166489141, 53.090590353935, 50.11172671471873, 53.799319498000614, 74.48664111475792, 95.6311502764302, 53.62915531281502, 0.29096463695168495, 0.3080118093038759, 0.25563306024959015, 0.45255433707948656, 57.52010337768063, 103.21937545653313, 78.51573897946265, 88.51313883258452, 79.85353392939415, 87.88559882871567, 81.05366937575802, 89.46544324198078, 67.88378592460387, 62.57665041954287, 60.11784599673364, 63.05681913129745, 62.84858442121937, 65.19810376628753, 61.65814899629163, 62.68377034894882, 60.02526629355646, 61.02068147351665, 58.375340892422585, 61.33743639915221, 58.96093114729851, 58.61256976281443, 55.56404482933783, 56.53222307082146, 55.04216563317084, 55.39442977597637, 56.17474609805692, 54.96028223345357, 54.85058530684441, 52.62233388039374, 51.082419195482814, 53.520376220826186, 55.23165533619543, 53.34666621300482, 56.344129731578214, 70.70240113043016, 64.24664266647832, 55.5387023956545, 49.32789202659361, 58.846284189531886, 55.42764048422537, 57.74812644527805, 57.9115088524357, 57.717445665790194, 55.4945678864756, 56.735488137891224, 52.97294278298655, 56.17048640404978, 59.610507026795425, 59.98320671819872, 62.18109507714549, 58.87646290563769, 59.82548821356989, 50.44005655473279, 48.84916674706244, 51.14773842596239, 47.565496583138746, 42.91575031895792, 48.18685493161602, 53.34572876653364, 56.32272535754789, 62.59699575362667, 56.96200501534247, 59.372411312595496, 57.74442372783538, 61.01516269868421, 63.479552576618815, 68.46451636283629, 60.150166326953524, 59.37856943376603, 66.43103414966215, 60.45896668587962, 58.710311305138376, 59.16121521303731, 58.6461256396386, 57.3711278361659, 56.00258542645363, 54.58993596415366, 43.40422268836729, 53.17733357029577, 49.651354205223825, 37.359763960684504, 53.89370741382722, 52.92316398312969, 61.44694897436327, 57.51023469432708, 61.835977492793916, 59.18955825990247, 60.56780069105087, 60.56215247800274, 52.75522770420198, 53.21080315497614, 64.39870903568884, 65.63281613011515, 66.4605382180983, 64.57820453951436, 62.94676919137279, 55.96269492180117, 56.71178917731009, 64.85857948180168, 64.28395617392756, 64.62944246107533, 56.451026085884344, 52.697576707409276, 54.44155662290512, 52.27885192440402, 48.710032432310044, 46.99143809656943, 50.14756933335335, 54.71849556892149, 52.60969600369854, 52.81469868075464, 55.969680663078066, 55.75055353103146, 54.83941047422348, 53.584189261159594, 56.55099945683634, 58.08820770632837, 56.401392413723855, 55.77306401345038, 56.53385477681314, 60.34853235367806, 57.54065659738357, 60.445932649797015, 60.44820370212678, 59.654578778051565, 57.38424424202212, 59.05103583489696, 63.49013120897355, 68.46217863021359, 72.95378669615715, 79.31768325067337, 79.10582034818589, 75.4464215617026, 73.5632053498299, 82.21043125275644, 82.04625652682397, 91.28683505519744, 74.53777313232422, 0.6570631938595927, 0.7612589963020817, 76.78895473480225, 82.47604631608533, 67.46799115211734, 62.34728590134652, 55.316241248961425, 61.610147030122825, 67.66309768922868, 4.437179786543693, 0.3337999835850731, 0.19568363114470438, 0.17552203558866056, 0.1071745438140727, 0.1636701497820116, 0.09141019335196865, 0.08617038943714674], [0.08236797331201454, 0.01563562853862682, 0.18550766992472834, 0.04288770108213348, 0.10209964798583139, 0.03642918151472846, 0.026328794868482698, 0.03775706852696115, 2.298657725895605, 45.95582646708335, 46.749019930439616, 41.057264651021654, 39.353104637515166, 58.75463801045572, 75.8675350681428, 51.52052833187965, 0.14380483106980402, 0.07015163649714763, 0.23544246060473306, 0.9256757447315801, 68.13080110857564, 84.04299397622385, 76.20663965902021, 78.28839840427523, 75.43227749486124, 77.72646396390854, 76.46900699984643, 66.69930857996788, 55.35305661539878, 55.276739058956025, 58.86079303679928, 61.11822689733198, 65.21029841515326, 67.42532360938289, 65.97810237638413, 65.70343448269752, 63.266967958019634, 61.746280731693396, 57.780556601862756, 57.05775791598905, 56.409735295080374, 59.02660731346377, 58.72586350287161, 56.48917898055046, 52.947098285921165, 50.2732930644866, 51.50344248740904, 52.06265088050596, 50.724569597551906, 46.84167023627989, 45.81827678988057, 44.96955040962466, 48.455886379365005, 46.45128065539945, 53.920191257230705, 64.72342245040402, 60.5621289437817, 49.3527598534861, 50.08116360633604, 52.88277141509518, 49.67244871201054, 49.81812946258053, 47.834006355654815, 52.16645640711631, 48.56992929212509, 51.352839162272794, 43.2923057002406, 54.532379104245095, 53.495316197795255, 58.281564866342855, 64.0728855902149, 56.39488912397816, 40.391862007879446, 38.92063979179629, 44.19390170804916, 37.66564607620239, 36.049468748031124, 48.359580424524125, 48.14323033055952, 48.678190631251184, 49.87671006110407, 53.299990007954264, 50.78734713215982, 52.698804409273215, 52.60311034417922, 58.08602686851256, 59.417675464384025, 63.4002265622539, 52.70164420527797, 48.605214934195246, 60.40918788602276, 57.09744445739254, 55.87598700677195, 52.70371129435878, 54.924145437056026, 51.985003640574796, 50.44968205113565, 49.248099250178186, 42.55709663514168, 26.94803826270565, 34.623389090261156, 33.7157565547574, 38.659025546043154, 47.83545763261857, 48.27695961921446, 55.41653233189737, 55.480282614308024, 51.20120033141106, 54.230529185264345, 52.08289423296529, 50.45767584154683, 47.637095528264204, 48.70884395414784, 57.675648889234, 55.982122421264656, 54.072194868518466, 53.3192684573512, 53.05644612158499, 50.14517276517807, 52.41156531918434, 61.36163350074523, 58.521013798252234, 50.5193982585784, 46.433053401208696, 47.30394901767854, 47.42212218623008, 43.52602012695805, 41.17337465286255, 45.46776986891224, 48.36753499123358, 47.530234475289625, 49.872611184274, 55.941690629528416, 58.3703516375634, 54.075854439889234, 52.91034959977674, 54.99934119562949, 55.02590740880659, 52.35860155474756, 56.0841275799659, 53.34015115614861, 54.52129448613813, 54.55648206895398, 53.52142349366219, 52.992025113874874, 57.90502517454086, 54.56579769811323, 55.52823358966459, 55.61227429297663, 55.17245108081449, 57.16891788667249, 58.04841133856005, 61.46346607515889, 61.62260055541993, 63.117513887343875, 70.92441512692359, 81.10648801249843, 81.40704354932232, 76.22166233678018, 1.4521103448444799, 0.1890402239176535, 60.43629930865381, 68.25942347126623, 46.276703803770005, 48.196421592466294, 37.87392000998221, 29.6227809306114, 30.439504692631385, 1.6617694881654557, 0.05725925390218055, 0.1343257034257535, 0.012376819786074902, 0.025507098536998517, 0.03008622439548133, 0.06280133695972544, 0.10153668827467388, 0.13071588180478544, 0.12571980876307334, 0.10281633089987502, 0.09455142197229209, 0.05863176170556296, 0.012829046275827193, 0.08588799410649846, 0.2020061701055496, 4.1319399591415165, 62.30472818497689, 50.3008084912454, 42.37678920069049, 44.35638589243735, 67.21510810236778, 81.38535284226941, 58.34621337152297, 0.2312953662007086, 0.05483055982979075, 0.42909654097691663, 1.3229674100875854, 73.53457204757198, 91.73371853366976, 80.9509817246468, 82.1360082011069, 82.09814163946336, 81.71145869839577, 79.33896603122835, 69.6885076645882, 61.0619055840277, 60.79118751710462, 60.866944174612726, 64.10593940365699, 70.20199298858643, 69.0529268018661, 66.8425770728819, 69.76243649759601, 66.14588568287512, 62.71519637876942, 60.051805050142356, 59.650083741834095, 57.96189954203945, 60.67383804628926, 62.534606533665816, 60.134547448927364, 55.87384539265787, 53.91653168585993, 53.669316461009366, 55.37652807850992, 53.36086911539878, 49.296720950834214, 47.320430817142615, 47.95078708279518, 51.23052397081929, 50.1624115820854, 55.84116420438213, 66.45663153740668, 63.422042785152314, 52.19994560364754, 54.308792237312566, 55.34430188517417, 53.14475044127434, 52.85199649872319, 50.89906407940773, 51.642490510017645, 51.88962728746476, 52.74329585413779, 48.04603007531936, 56.780348285552, 56.67250271766417, 61.74027166058941, 62.10051390432543, 57.31930155907908, 45.13967929347869, 42.36302560375583, 44.378343320661976, 40.680556297302246, 41.72212208470991, 48.60732516934795, 48.50087596524147, 51.65045684383762, 51.57973650963076, 54.875049129609145, 53.26009558093164, 54.56855512434437, 55.244556011692175, 60.84527307941068, 61.87667600570187, 64.86219590710056, 53.12601720133136, 49.26004678972306, 61.96558829276793, 61.22134600916217, 57.28621244430543, 55.788047467508626, 56.8489230832746, 54.8746294360007, 53.92952649824081, 51.55026774252615, 46.02201254137101, 33.3833945182062, 37.83726546072191, 34.73370182898737, 40.309711886990456, 56.59647933898434, 50.44541451238817, 56.06113856838596, 57.876882168554495, 53.74440239321802, 56.7745392553268, 54.70136265600882, 52.36710133091096, 47.73512340361073, 48.916941381269886, 58.52893306363014, 57.62916488032187, 55.434481097805886, 54.34636854356336, 52.30520632959182, 51.04846323690107, 54.933900371674575, 63.77504041118007, 62.81456570471487, 55.335586378651286, 46.5654137826735, 50.04943163164201, 49.669895249028365, 45.488966357323434, 45.27194946042953, 49.264518291719504, 49.65874787299864, 52.49475094579881, 53.397472673846835, 58.49836603287728, 60.08474511484946, 58.89826736142559, 56.559687506768014, 57.51221941363428, 54.777335043876406, 55.37359022325086, 56.2921622491652, 56.11391798142464, 58.313457658213956, 59.24587565083658, 56.38822501705539, 55.546452999115, 58.93014054144583, 59.39325086532101, 57.289158144304835, 59.26253003458823, 58.60696861820837, 61.03122480453984, 60.17068032295474, 64.45634042063068, 63.948060081851104, 67.10934531304144, 75.15456584192093, 84.4823072802636, 86.90092702065745, 81.27808386279692, 2.445969937309142, 0.024687374881919355, 67.46384128447502, 73.46064321456417, 57.67494678497315, 53.18062051650017, 37.24488950544788, 46.0904186771762, 47.481204848135675, 1.4690470166744725, 0.06199763028792316, 0.08647342317647512, 0.04118866745322462, 0.04953333762504401, 0.05963522963406098, 0.10255074353828546, 0.1258831693520469, 0.2035387136763142, 0.184327817912544, 0.31866484411781837, 0.3067946488097791, 0.23467916124049695, 0.19701018899438844, 0.20021775316807533, 0.39753022513562636, 5.942643803934898, 77.96633258942636, 58.764432168776, 56.389052637161754, 52.960630463015654, 75.58690517179429, 85.77090001875355, 64.55995375110258, 0.24059794122172942, 0.34783321282555985, 0.7436824878377299, 1.613025458589677, 73.55024583878057, 93.71526072102209, 83.88680519596224, 84.81711295343216, 86.22631072998048, 84.4394200847995, 82.56023606946393, 72.23772664223948, 60.75663535825668, 61.55247642147926, 66.07419260086553, 66.13147489486202, 72.04692686757734, 70.18922175130537, 70.10917402082875, 70.76417846064415, 69.89845645043158, 65.6585390337052, 62.990738961004446, 63.21740096615207, 59.681854940229854, 64.43828182835733, 63.07537978695285, 62.90032832853256, 59.12254848787862, 55.92968425443096, 58.18207002455189, 58.65191898038311, 54.73387910473732, 54.09589775146977, 50.74768804734754, 50.47863698774769, 53.881359792524776, 54.436622281228345, 59.795187903988754, 69.42620308168473, 65.42076495385939, 56.47315217602638, 53.84894532542075, 57.46173066477622, 55.91527738878804, 55.18730117428688, 52.60132958812099, 56.161174697260705, 53.572025991255245, 56.714060229639855, 52.50615327588974, 58.881640434265144, 60.542685754837535, 63.149269396258944, 62.80481469246649, 62.99574390534432, 52.135493216976045, 47.191196564705145, 47.51583153201688, 44.796271862522254, 43.562470712969386, 49.76288287870346, 48.955678709091686, 53.86376011756159, 54.044420565328295, 58.907504543181396, 55.55266603346794, 58.618837710349794, 58.56254385363672, 64.08710418208953, 63.73477335899108, 68.01829184255293, 53.42978515932637, 50.274697273008286, 63.54639368672525, 62.177188396453865, 60.36147617524671, 58.83502698713734, 58.5239516535113, 57.83678770065308, 56.33876392918249, 56.16443026450373, 46.88189022002682, 37.572332889803, 48.24976974917997, 43.23594124086442, 43.487239653064364, 50.89467886955508, 51.99931636933358, 61.022446540094194, 60.29865157219672, 57.66796496606643, 58.91011684171615, 58.08616022909842, 57.38556608077019, 51.730041734633915, 51.52363484905612, 61.074339497473936, 62.96894627232706, 58.74889566052345, 57.67511544689056, 56.97558426087903, 54.215588877277995, 56.47281485219156, 65.75632372210103, 66.21760229910574, 57.69158940161429, 51.41709935280585, 52.9718876654102, 53.665378401356364, 48.59795070463612, 48.65435831008419, 52.124204635620124, 51.57057385290823, 56.02567249728788, 55.14894039400163, 59.84787710251347, 63.66585339269331, 61.64299688031597, 59.02572870254517, 60.472710670963416, 57.09531853275915, 58.5504041179534, 59.149079399724165, 59.64603585581626, 60.96322267286239, 63.06327143023091, 59.844629380010794, 58.141755903920824, 61.73649834048364, 61.27601992699408, 59.05753912464265, 60.43392235232938, 59.84941074925085, 63.68271173969392, 62.79053334266909, 68.27691724223476, 65.94516231167701, 69.89578923871441, 76.0749186238935, 88.24576654741841, 86.98733683555358, 85.54122955568376, 2.3044096366051705, 0.41732832729335756, 74.38389855046427, 82.09144223120906, 63.203947236461026, 66.02407255480367, 58.86913984052597, 56.88024713147072, 66.26781648205173, 2.727298015548337, 0.2589578511974504, 0.2833542888683658, 0.16936449664494685, 0.22299662683038945, 0.10391472478307064, 0.22206619772459232, 0.19433764530526054], [0.08709920209742363, 0.0995294766260251, 0.020410796296933008, 0.10361024313756537, 0.04282134637657193, 0.013881426045460808, 0.05961236957040045, 0.0667290850692699, 1.302399849218707, 49.06988636139901, 45.774181504403394, 39.22614535977764, 45.26765838746102, 56.72259138476465, 73.88138017346783, 65.6187662001579, 0.6827312455542627, 0.0554464677078349, 0.15710727371756109, 4.361459410959675, 82.0389138498614, 76.86843764397406, 76.76349855238392, 71.50820501389043, 73.89111549623551, 70.52427845616495, 67.26089000701904, 57.622116381122225, 55.887491318487356, 56.8198073294855, 64.38161142410772, 65.91794890742149, 69.35928744654503, 69.11155839120188, 67.65528432784542, 68.8727331161499, 70.99642199854698, 66.00995986692368, 64.96110631573585, 67.34472674708213, 66.37409702424081, 67.42280544773226, 65.6427397266511, 65.59180382759341, 63.614493877657004, 51.22288319372362, 49.8965415646953, 50.21569698087631, 50.50782726657007, 47.68436401121078, 45.549578743596236, 47.9836683119497, 48.10173557650659, 47.23944956256498, 49.13112240452921, 54.9743753094827, 55.21290248440158, 49.99601679463541, 51.32461770888298, 50.86095040844333, 46.32488227659657, 48.497126179356734, 48.1628696380123, 44.31671896288472, 45.371350165336366, 48.90634313706429, 49.43829105746362, 53.21174844618767, 53.48092109926286, 59.040508193354455, 48.19899074492916, 43.17320292995822, 45.18204873608005, 50.10565488569198, 40.09594271259923, 38.4129713427636, 43.24384089439146, 41.38711637066257, 49.04249645048573, 53.45807721537929, 47.892657556841456, 50.54812177535027, 50.85847147049443, 52.27336452853296, 53.50262749579645, 58.32068658644154, 59.334474148288855, 61.52113668380245, 50.07356597531227, 50.72305164029522, 61.717474845147905, 55.28982800822104, 55.044366082837506, 48.538915111172585, 52.8624221586412, 51.2564508376583, 49.50891333241617, 47.84192954340289, 46.646151850300456, 37.983016813955004, 30.87942792523292, 33.66866850083874, 28.98008292721164, 37.4822360469449, 48.84790766623713, 41.458632946014404, 49.30307519051337, 53.08151006698609, 50.84695539166851, 50.00197487492716, 52.23139909005935, 45.20970929053522, 46.145072983157256, 47.29380969078311, 51.62697361361597, 51.86604992035897, 51.71421889335879, 49.88056182861329, 48.90475849951468, 49.343032375458755, 59.08182251837946, 57.08115093169674, 51.55799088939544, 44.04187848491054, 45.374954823524725, 45.67895420135991, 43.34719142606182, 42.131574384627804, 44.83721356238089, 47.74022248483474, 51.62307085529451, 58.054624372913, 60.125259276359316, 61.44438766664075, 63.945843942703746, 62.2476851555609, 61.93268352939237, 61.108715149664114, 61.08593794607348, 62.97295493464317, 64.3718643342295, 65.65836252704744, 61.45162836197884, 60.785292194735625, 57.356207140030406, 57.36807230980166, 54.08377370526714, 55.00814691666634, 56.98049506833477, 56.754601847740915, 59.01281625993791, 58.294771486713046, 59.58002628818635, 59.80315031543855, 63.44421202136625, 71.0733396776261, 78.74908862575408, 79.10819730451031, 84.24983624489077, 3.642867957392047, 0.17895469171625955, 57.622100691641535, 68.68910343416276, 46.36579259749382, 46.78857311125725, 38.382776937177105, 41.38525716720089, 42.96122627873575, 0.701669980922053, 0.0787070612873762, 0.03913432990591373, 0.02409202305810346, 0.05638861412843389, 0.061914222465167125, 0.07554713246082106, 0.03836083391140546, 0.07064810743735683, 0.0629543515312816, 0.05292109716984053, 0.11355075489489302, 0.02623759401631692, 0.09216317351186469, 0.10048336334406369, 0.049239558227840936, 2.1414025512433823, 62.46938928481072, 50.14580034440564, 38.78478457850795, 47.82130572103685, 66.67666865933326, 80.20904187233218, 73.86121134604178, 0.9435384023574092, 0.0468410671718659, 0.20452183430954335, 6.763688546995963, 91.03551310877647, 80.82370865729548, 82.40902869932114, 76.50936818891957, 78.05742571430822, 74.44015318347563, 69.56161898951378, 59.7413690628544, 59.407320407129106, 63.23516145829232, 67.071776851531, 68.45416915032172, 74.10791274039977, 73.25426378557759, 72.17034816741943, 73.14195848280384, 73.49652505690052, 70.44130463753977, 68.49940192314887, 69.8655399199455, 68.28869219749205, 69.49099279219105, 70.83508706861927, 67.17381338919363, 65.45463069792717, 55.92440082180885, 52.63685841714182, 51.604623948374105, 53.194466483208444, 49.67541402386081, 48.064896675848196, 49.21719097322034, 51.39183536652596, 48.70708280994047, 52.77253320140224, 60.11598287090179, 58.88926552188013, 54.46163915818738, 55.120295324633204, 53.72762249362085, 50.82040879034227, 50.53342857668477, 48.228949808305316, 46.64444954164567, 48.18107335798202, 51.23815690317462, 53.448353659722116, 56.35408862944573, 59.19848557441466, 59.83040686576598, 53.34479524243263, 46.44936261638519, 45.18066021703905, 50.44693639201503, 44.8300983828883, 43.05208798377745, 43.577630673685384, 43.66244800629155, 50.68677363857147, 55.814021402789706, 51.468596150798184, 53.39577036519205, 53.03100170627717, 55.49977679406443, 56.63980976227791, 59.287782253757605, 61.7484615695092, 63.09765884953161, 53.58822538006691, 51.83894634246827, 61.33182348743562, 58.705851570252456, 59.77769413302022, 51.64629520908479, 53.8162523700345, 54.458532641010905, 53.31609133751162, 51.943657936588416, 46.715236556145456, 42.18435379766649, 32.94053146916051, 39.04189202093309, 30.11282813164496, 39.67855545782274, 57.20538808453468, 45.44907193030081, 51.05695124595396, 55.84755374539284, 52.23949878446518, 54.34207354822467, 53.54379669312508, 46.80253282670052, 47.38264353044572, 48.929492965821304, 52.80794435931791, 52.96172480429373, 51.01871205914406, 49.94267256029191, 51.36520247305594, 51.16049789613294, 62.36522682251469, 59.88449242807204, 56.04169537944179, 48.69021661819951, 48.76329429687993, 47.1278424416819, 44.016288941906346, 43.626475949441236, 47.311985954161614, 50.38224081839285, 53.894134952176, 60.29417222545993, 65.00575073303716, 63.46928773387786, 67.85812577893658, 63.66281747817994, 66.55947608332481, 65.27390356986754, 64.55010075722971, 66.17633896489298, 68.63785374549128, 66.07681274414062, 65.38562443948561, 65.5545570004371, 61.98882441366873, 59.61044819124284, 57.4831703401381, 56.50190707175963, 60.07024411232241, 58.480221148460146, 61.30862266786637, 60.52151280064737, 61.11190795898438, 62.20262496702133, 68.14834194798624, 73.64719898469987, 83.01075950745614, 81.15765925376647, 91.7654505083638, 4.325795260167891, 0.06489173043519258, 67.84165182421285, 75.58565785807949, 54.035202995423354, 56.24343464451452, 42.38736391067505, 53.443415395675174, 61.80113507855324, 0.8518080761836422, 0.03594774505003326, 0.12978692358780292, 0.03998290251700148, 0.03454814837764829, 0.023258766459841883, 0.06861138608186476, 0.013965869044524529, 0.19295087294472804, 0.16858483364264812, 0.14159753257709165, 0.25335091496667556, 0.17648231147998766, 0.21338649815128696, 0.2208573569453532, 0.2581304762392275, 4.281725960393106, 83.95425427344539, 60.15061739952334, 48.812237631890085, 62.13702724825952, 73.42032124919277, 85.23316660235005, 78.97441310267295, 1.4010991853091026, 0.20320050117950286, 0.5384694123941084, 7.863336301619007, 92.92614260027486, 81.64864586245629, 85.62254028935587, 78.12442764159172, 81.39859476397115, 77.35932227103942, 74.98825734661472, 63.20898355976228, 59.98236340861167, 62.50830311929027, 67.54180231401998, 70.54424332034203, 76.62683533084008, 76.85968291374945, 73.93170418277865, 74.23109085329118, 76.7862561441237, 71.24577491514145, 71.99300996718868, 73.46808787315123, 70.66546809288764, 72.83697851242559, 72.81612719258955, 68.57514289117628, 69.0579003672446, 57.668419961006414, 54.260998156762895, 53.34192406746649, 55.71094543703141, 52.77745969833867, 50.332101160480136, 54.20458662894465, 53.329478386909734, 51.81459626843853, 53.986675431651456, 62.53024878040437, 62.33342424515755, 55.74140656378962, 56.70696858436831, 56.27675910149851, 52.64653490435693, 54.49384573967227, 50.56885150171096, 49.96264134683917, 50.998217674993704, 55.28649399357458, 57.305400679188395, 58.15017331031061, 61.53626918792725, 65.70092808815741, 59.62057182865759, 50.678560195430634, 47.63363992014239, 53.378625685168856, 47.715303667130016, 43.2185729857414, 45.10034184302054, 44.41264837018905, 52.30656346967144, 60.36883846406014, 53.467184958919404, 55.5113281742219, 56.672357589967795, 58.75369271924419, 59.32876317731796, 61.73188171079082, 63.64366846699869, 66.76911892429476, 53.29044295895485, 52.65224587532782, 65.56916782932898, 60.44897640905073, 61.59346911215014, 54.54506404938237, 57.089999798805486, 54.504294933811316, 55.02587210747504, 54.72919579475157, 50.9396174646193, 42.469270844613355, 35.68903823052683, 43.526992874760786, 38.69116152486494, 42.552456471227835, 50.76629184907483, 46.6544476632149, 55.014344261538604, 57.44899472882671, 54.51277509812386, 56.69395808250674, 57.416148801003736, 48.838391996199086, 50.89030934918312, 49.775183431563846, 55.784054494673214, 57.44425258328838, 56.32191734929239, 52.7290694175228, 53.133222595337905, 53.59047682054582, 66.19369937527564, 63.85682575164303, 59.06421107630576, 48.319858581789084, 51.14232947749477, 50.736854460931596, 47.64883125981977, 48.173777749461514, 50.4653597647144, 53.72008762051983, 57.659378897759225, 64.18246876808905, 67.4239037113805, 65.20472080476823, 68.0460386891519, 68.35118339907739, 69.74396997882475, 67.75946247962214, 69.02784716698432, 67.73014668495425, 71.23199955109628, 70.11220993534212, 67.85841603432932, 67.9560124489569, 62.65367008024647, 61.32306875721101, 58.801020037743356, 58.80974338900659, 64.2403551070921, 61.472942521495206, 66.25284087273383, 63.30411280355146, 65.61653044915968, 65.23227937759893, 71.73462775445753, 76.03656568834859, 88.18897847206362, 85.80238096175655, 93.29041311817785, 4.972479862551536, 0.31663210641953254, 74.6743735959453, 83.55496483464395, 63.7304626741717, 66.82731120817124, 59.14466673328031, 66.59053341034921, 75.75821861144036, 1.98147869398517, 0.26811689198497807, 0.20134117514375718, 0.15238766648596333, 0.18164831814506363, 0.11252015979299623, 0.09751307192228495, 0.10005898893840852], [0.07226993089481708, 0.06319899021858169, 0.011947226406435573, 0.047872428361686974, 0.015197975914024059, 0.014040965770912028, 0.15761716651820368, 0.14304864100150524, 0.8972116559743882, 38.760893421788374, 45.713188648223884, 55.55991065117621, 39.73888151107296, 50.09344846971574, 63.136074542999275, 74.00054962404313, 1.7617347692289662, 0.10606891039999262, 0.1315496919015723, 9.161736926724835, 89.02572985618346, 75.06970928561303, 80.46744761928436, 66.68590976345924, 66.2150292242727, 60.351391761533684, 61.247774939383234, 55.62911695049655, 60.16957421456615, 61.87992765057472, 67.9104188180739, 67.1322048864057, 69.50050061748874, 71.59756445115613, 71.51224505516791, 68.8197026714202, 70.56580066680908, 66.27690853611116, 70.65042972564697, 67.59705282026722, 69.07290735552388, 65.08446093528502, 68.76589559739637, 66.46496265165268, 67.49191761016846, 57.06799922450897, 50.5079214034542, 51.39700505041307, 51.54658463693435, 49.12391701052266, 45.48265918608635, 44.838237300995864, 47.85358682755501, 46.94339298432874, 52.38472454009518, 52.769638492215066, 48.70181114442887, 48.19769244040213, 49.82468766550864, 48.39175170467746, 48.10864287038004, 47.347314742303666, 45.848612400793264, 45.12306805579893, 42.49541736418202, 48.12928630459694, 49.87268570930728, 53.85978283420686, 53.96872666574294, 47.35880728690855, 48.24668676622453, 50.10244638689103, 52.21797673932968, 53.204664645656464, 51.30104034177719, 47.68133594143776, 48.79210018342542, 50.25855279737904, 46.6830966549535, 48.85165352975169, 50.268723503235854, 53.91639832527407, 47.27898705390192, 52.25018332081457, 53.26865419264763, 57.02672020081551, 56.51628648081134, 62.13223411190895, 54.064318749212454, 52.43034562756939, 60.75506248781758, 58.34406391266854, 56.22456019924533, 50.88918362894366, 51.09415100466821, 53.00230172372634, 50.46759159334245, 47.21815893726964, 45.3701695319145, 49.65175820935158, 35.567017216836255, 35.54180029899844, 37.4788353520055, 27.91020743308529, 31.167357352472123, 47.29013835230182, 44.51202161850468, 48.51389038947321, 57.692503313864435, 53.41886135839647, 52.15812529287031, 47.48280125279581, 43.359856759348226, 45.48341228115944, 46.458301698007894, 45.60762197740617, 46.34202695661976, 45.66493957273422, 49.02720312918387, 49.21981503886562, 55.90504392500847, 55.67469881426904, 49.08724677178168, 45.163868550331365, 45.20315500997728, 44.97092323918497, 42.264534888728974, 42.7763924291057, 47.57497695184524, 50.82053822855796, 53.490946677423295, 58.483715980283684, 64.3795717916181, 64.84291353533345, 61.63563066913236, 61.681243911866225, 63.718393541151485, 66.12331636490362, 62.57674063405683, 64.80843590151879, 66.46256216110723, 69.08436067642705, 68.72515001604634, 66.59620515761837, 65.84103122834237, 69.55131884544127, 65.24039083911528, 63.84478799758419, 60.53344072834138, 61.49534317754931, 64.59000695136287, 65.08574355033137, 67.96661853790283, 67.01247845926594, 65.85948205763295, 67.79962755018666, 79.54395694117393, 76.2453063841789, 89.08256499998032, 4.509003287361515, 0.032631208699557095, 65.43998849007392, 64.67062734788465, 47.84241983967443, 43.362527893435576, 57.517342029079316, 43.15941187643236, 53.711764351014175, 1.290607120721571, 0.09196851057030501, 0.1100503306295122, 0.04694736187135981, 0.12028335007808863, 0.0683226398823242, 0.05978689206043079, 0.12280256893005102, 0.07134512487438417, 0.07060003542010823, 0.0700883269910851, 0.04185925868730392, 0.05817564444676523, 0.07766472205760018, 0.06185333762738494, 0.05919817647325897, 1.477028794827, 56.71041634774978, 50.798788685952466, 57.084598695078206, 50.3217068795235, 60.02651752964143, 67.63562540854177, 83.37000154679822, 2.2363415600792056, 0.13771921246042176, 0.13815997348677728, 11.04336359808522, 98.03091126103556, 77.28283605267926, 85.19759070488715, 69.9293255036877, 72.32877269867929, 62.98740886872815, 64.11971869007235, 57.68050086113715, 62.894130983660304, 65.1292230236915, 73.34090894268405, 69.91768390901628, 74.84068993599185, 73.99589769301876, 74.81017389605123, 71.72700266684257, 73.2469524875764, 70.86925875756049, 73.28547016266855, 68.70487920699581, 72.83449172973633, 68.59826134097192, 71.13152411676222, 69.29499195468041, 69.98167345600744, 60.45564836071384, 53.75962903422695, 52.62154156161893, 55.31095781633931, 52.27116800123646, 48.0907254834329, 47.893873491594874, 50.62404709477579, 48.87792556516586, 54.59780031634916, 55.08131088749055, 52.033229181843424, 53.139270890143614, 52.86600328260853, 50.07274619994625, 50.974216691909305, 50.04900017092305, 49.18578063288043, 46.395029944758264, 45.992822262548636, 48.444123191218225, 53.787748505992276, 56.14158245824999, 58.45184672263361, 51.92790569797639, 52.45871220865558, 52.78011514294533, 52.90607813865908, 55.23762518359769, 55.82023051477248, 51.29486260875579, 52.88088867741247, 51.55716719165925, 50.11869284414476, 50.630864174135276, 52.08455731791835, 54.58449171435449, 50.060759436699655, 54.57578405257195, 57.30500059743082, 57.61836267286732, 60.17809360258041, 64.91020179563954, 55.85450810770835, 55.39971320859848, 62.836883990995354, 59.22576565896312, 57.483025212441724, 53.32839973511235, 53.55761128087198, 54.55499549065867, 53.35291062631915, 49.110679011191095, 51.04647067285354, 51.611896022673584, 39.07367890880954, 38.17176911138719, 40.81510928369338, 30.948898984539895, 34.476825806402395, 55.50943759179885, 47.29735943578905, 49.162238567106186, 62.47592787588797, 54.18137011989471, 52.82541067369523, 51.88754843127344, 46.98881795329433, 45.562400971689534, 47.60369654624693, 47.793802061388575, 48.665297800494784, 47.81162531145158, 49.47926805865381, 51.08446275034259, 56.011881443762014, 56.61524788025887, 53.88666675936792, 48.24600035144437, 50.1446863912767, 48.5243905744245, 46.988543387382265, 45.867243659111764, 50.573781921017556, 50.365551133309644, 58.13027904879663, 60.51053408653506, 66.41532897949219, 67.05456549121489, 64.8380184173584, 63.81289520571309, 67.1142247415358, 66.9172982246645, 67.79351649745819, 68.72838204906833, 70.00616473536338, 71.61952187938076, 71.29205103843444, 70.60973121273902, 72.2161614510321, 71.82230841728949, 68.14700049738731, 67.3232086243168, 64.09919292696061, 64.11359979260352, 69.95748812152495, 69.8225115191552, 73.6431432539417, 70.31964840427523, 71.14176150291198, 69.62092522651919, 85.19430375868275, 79.51362917500158, 96.35156416123914, 5.725252810985812, 0.09165662085457195, 74.49752961435627, 76.04353181777462, 55.4546695370828, 52.03500601553148, 62.86733335064304, 47.61060776249055, 70.11274337768555, 2.130948454141617, 0.07005464210505448, 0.06498898529718, 0.025180164769652392, 0.03223021912779058, 0.05995860300777901, 0.11878085247571431, 0.13719301730875047, 0.1648035462224676, 0.1460755616426468, 0.20348874942189266, 0.08644694717781198, 0.11144379859850292, 0.11619590327984865, 0.26643296944037564, 0.2620288218942381, 2.2675503886515096, 70.54025034750663, 62.6694497754497, 70.5755752132785, 52.21594102921025, 70.2140268202751, 73.5661941959012, 90.93877177084647, 2.373502677486789, 0.4169652322607656, 0.2432955053424643, 11.35767194532579, 99.424678433326, 79.09704992848059, 87.85276859037339, 72.61850249382758, 74.39812106470909, 64.4471856086485, 66.79204910032212, 63.07710955219885, 66.69866531125962, 65.77217009759718, 76.24778532212781, 72.05415187343475, 76.8160504679526, 75.90758246760215, 75.98992086225941, 71.28020548051404, 75.16379125656621, 71.32872519954559, 76.23130352266374, 70.12695020244968, 74.93109272372338, 68.69182555906235, 75.13376159052696, 71.10415381769981, 73.40443564999488, 62.775840144003595, 55.93921953631986, 55.31981845055857, 57.63408745488813, 56.00548798038114, 51.28898689823767, 50.71821143550258, 55.48273409566572, 52.337001062208614, 59.69631279668501, 56.84251785278321, 55.28849832473263, 54.63396456933791, 57.143897087343284, 53.17277969852571, 52.073782567055, 53.16857099533082, 52.03180536147087, 50.050365155743016, 48.60756443392847, 54.502957405582556, 57.43272473735195, 58.624772256420506, 61.24866923978252, 53.1314653735007, 55.33196210861207, 53.471585858252745, 56.540342377078154, 58.73506146092569, 56.02579801313339, 52.51668091743223, 51.96817667253556, 54.850840260905606, 52.22968109192387, 53.189171283475815, 54.44230187323786, 58.90691226528537, 50.517570434078095, 56.304313751959036, 61.720075376572154, 62.169559386468705, 61.31562802099413, 69.4334908454649, 58.84264815238215, 55.907550319548584, 65.18772909718176, 63.62530785222208, 60.69301843643189, 55.496893851987785, 55.01767827618507, 57.48680637728784, 53.482031130021625, 53.18903792288996, 52.69832588011219, 54.32949842945222, 37.04624891281128, 39.38235375189012, 43.43889644069057, 36.51192011371736, 38.072211511673466, 49.9085283279419, 47.63157675343175, 55.57765545383577, 65.44204773441439, 57.22302698319959, 55.59394897953157, 52.59824660516555, 49.038601536904615, 52.7058764426939, 50.90426514225622, 50.21782682787988, 51.04539986579649, 51.6528259554217, 52.5985643171495, 53.894735074812374, 59.46589708328248, 61.95244050795033, 53.99166076414047, 49.50804256623792, 53.36131234322825, 52.17982384466356, 49.9600447377851, 48.497318375495176, 53.44934209700554, 55.80041077829177, 60.97296584037043, 63.139800794662975, 69.77616479319911, 70.76005997196322, 67.15052235511043, 65.00421708629978, 69.20769568412535, 69.73715289946526, 70.76764583587646, 71.21181503418954, 73.2202725256643, 75.63183199974799, 74.2990969073388, 70.68594286518713, 72.9722845938898, 74.294845058072, 71.32620703789496, 68.69231977770406, 66.9868104688583, 66.03574552843648, 72.39492739400556, 69.04281493156188, 75.23999506427397, 72.41637491410779, 72.27958617671844, 72.7096034634498, 90.22749700853902, 82.49851365243235, 98.44198349983462, 7.0577427552592376, 0.24819742617828233, 81.55308123557799, 81.55130047951975, 67.61733931879844, 61.31902087119318, 85.29013510673278, 62.25973859910042, 80.60376567225303, 3.0882661429143723, 0.24026994833782797, 0.2342236300389613, 0.1943193817691457, 0.30413902034201934, 0.16669730024953044, 0.1586780450757473, 0.33433955463190235], [0.011024668854060433, 0.04983561676776698, 0.038776245088346546, 0.061333006878774014, 0.04552578996686686, 0.0776096020314482, 0.07750370569767491, 0.011391059022336718, 0.28414103052308487, 44.150739946673, 48.64346588811567, 41.1737786569903, 30.007394821413104, 56.00162444576141, 57.69273865607477, 82.98709192583638, 5.206992981895324, 0.104064196197977, 0.1561806597296269, 20.21371110793083, 97.90570136039489, 71.11642299159881, 79.27159540114864, 64.80574907795076, 63.50915862667946, 59.362550473982296, 60.0544330381578, 58.47578887016543, 62.78955667249618, 61.328195295026234, 65.74450562077185, 67.86299736269059, 71.00839307231288, 70.59768169156968, 68.52951003659156, 67.23688510156447, 74.1922672333256, 71.67280335580149, 67.99240419941565, 67.71071526312059, 71.10464803634152, 68.66448663896131, 68.47955473007696, 65.37020952470841, 64.7096392416185, 58.52255136735978, 50.42022505114156, 49.15087153834682, 50.61441767600275, 49.37606265467983, 47.80350600519488, 46.234573625749164, 45.81931621797624, 43.52557689912858, 49.39544308570124, 48.132416355994444, 46.427456178972804, 50.893831637597856, 47.001428373398326, 46.116588730965894, 45.18689678561303, 45.047538895760816, 42.83451411031908, 42.103439223381784, 41.032961645433986, 46.349475537576986, 47.9228009716157, 53.53442615078342, 57.14481099959343, 56.00106746919694, 50.45897806844404, 51.09326454900926, 55.534995755841656, 59.281741803692235, 55.07778859907582, 58.20416473573255, 55.98162428025277, 48.54389259892125, 52.307744103093306, 46.829730541475364, 51.84805408600838, 53.334753974791504, 53.08828792264385, 53.123330377763324, 54.22998397581039, 56.44460124354209, 56.1241396780937, 56.09571426145492, 56.14410846464096, 54.195584789399184, 60.47426785192182, 57.60923923984651, 57.21616675776821, 52.409796330236624, 50.40033863436792, 51.04237964076381, 52.046600541760846, 49.303651778928696, 44.440081427174235, 43.93179324365432, 48.763600241753366, 39.69557854437059, 42.70154968384774, 46.262489134265536, 33.64189440204252, 30.89387401457756, 46.5350232585784, 52.04648287065568, 49.511670758647305, 51.07126789708292, 52.75818909368208, 48.24481187328216, 43.022442710015085, 42.39556166433519, 43.59787010377453, 45.13000280626359, 45.84628251291091, 46.999969251694225, 47.84325138215096, 50.224314428144886, 51.805653264445645, 51.971773485983576, 47.52266430085706, 44.88006545651344, 43.99647705016598, 45.27872339371712, 40.589988770023474, 45.08068684608706, 46.302038392712994, 47.24826705071234, 51.540991337068625, 58.598833622470984, 62.049664297411525, 63.38118737743747, 63.7269913765692, 64.37307242424258, 65.33168008250576, 62.46529825272099, 64.80925959925499, 65.41305357410063, 64.63305496400403, 67.5736362703385, 68.89039162666568, 70.06762043122323, 67.5769781297253, 67.4757182213568, 69.17546949078961, 70.46960061596286, 71.30241394042969, 70.66313036026494, 72.35684117963238, 72.35072228216356, 73.71253782703032, 74.3031918617987, 76.95235283144059, 71.65157548842892, 79.07130349066951, 73.45202184492543, 89.87031029116723, 4.392384848287029, 0.28953183802866167, 66.26722812652588, 68.2066362134872, 51.06332901985415, 41.2505433636327, 38.03964407213273, 45.382191596492646, 64.55406627347394, 1.8066387984060475, 0.0627808402773113, 0.047620906374387206, 0.019901759599545793, 0.09815708373583133, 0.08846020326018335, 0.0682196393609047, 0.03560306294070136, 0.010186288085195326, 0.05507269724001808, 0.014454166784191565, 0.06292551598181167, 0.007587970176246018, 0.11523643178084206, 0.02512438973832515, 0.01255379663029265, 0.2080513239507714, 56.60353176055416, 54.136878675030125, 49.15886140638783, 47.47610184454149, 62.36066902837446, 64.56309164724043, 89.13933738585442, 5.904735076812006, 0.14492138889768433, 0.1099947432897264, 22.617922021496682, 103.91797311844365, 74.69104366917765, 83.06656699026786, 68.23490081294891, 68.50061001316195, 63.239032837652395, 64.33007148004347, 62.35626028430078, 66.65397382551625, 65.0739372161127, 70.18293811428931, 71.59845090681507, 72.7244378674415, 72.35193821691698, 72.1685124981788, 70.82874851842081, 75.72329382742606, 74.53899691181799, 70.81311395091396, 69.2730188369751, 74.06395866024879, 70.24035376887169, 70.18668790017405, 66.92584899164015, 66.60058252273068, 60.695293411131836, 53.10950794527608, 51.911835747380415, 51.92000996681952, 50.34743762785389, 49.47990348262172, 49.030435162205855, 49.18393711889944, 46.97685472426876, 52.106448065850046, 49.71652046326668, 49.163736912512014, 54.079561079702074, 49.650679557554184, 49.3660919897018, 49.16998132582634, 46.60649276548817, 46.68784664523217, 46.224124431610115, 43.30730876614971, 48.62796860356485, 52.488396706119666, 56.26747092893047, 59.2618122408467, 57.52619874092841, 52.92086547420871, 52.992099638908144, 60.07571189634262, 60.92450103452129, 58.87650997407975, 61.13254354846094, 59.84773589718727, 50.11446845146918, 53.9961204990264, 49.80998269973263, 53.83056509879328, 56.718123805138376, 55.28143413605229, 53.87784534885038, 56.647987904087195, 59.84036184126332, 59.98273211140787, 59.15171131010979, 57.6967590855014, 56.80456499899588, 63.46844834666099, 58.672480044826386, 60.263926829061205, 55.437669984755985, 53.100047188420454, 54.04432642844416, 54.73612662284605, 51.26794338226319, 47.905856332471295, 48.179123940006384, 50.68523999183409, 43.557461846259336, 44.90281912588304, 51.25452103153352, 38.028743805423865, 32.19008595712724, 53.398845503407145, 53.77223945433094, 51.33887944682952, 54.79281663894654, 55.43062148555633, 50.2096486860706, 44.08967648783038, 44.883375936938876, 44.865211440670876, 45.90882862767866, 48.810543167975645, 50.46626190985403, 51.45356955066804, 50.256368037193056, 52.82486154187111, 53.646849124662346, 50.599987276138805, 47.24926725510628, 46.86931510125437, 46.62258232793501, 45.6176200989754, 48.00443726201212, 50.75313621951688, 50.968317447170136, 54.758386073573945, 60.50684313620291, 64.46146303607573, 65.48746878100981, 66.12679942961663, 66.25995605222641, 68.04276743242818, 65.24032808119252, 68.08748245239258, 67.28799358490976, 69.06976161464569, 69.41655405106084, 71.79019205031857, 71.2575969388408, 70.70099692190848, 71.63818451666063, 75.55779334037535, 72.3629443876205, 74.64629727025186, 75.28298424136254, 76.2274125314528, 76.88954784024146, 80.09122171709615, 79.01166777456962, 82.04960623095113, 74.68296358662268, 83.52885753877702, 76.39855338681129, 96.07275424465057, 5.11337237973367, 0.41845119768573397, 73.10704154352989, 74.28933020560973, 59.20952312407955, 49.381063676649525, 46.001004326728086, 47.8987293858682, 78.99641759933965, 2.5016016489075077, 0.06790499172864423, 0.08489627030587966, 0.014638920378450666, 0.012532278178109518, 0.031042256159707907, 0.0636250002219552, 0.015643597768259146, 0.1619579892365202, 0.197381190054359, 0.15247454085657675, 0.1252947218956486, 0.093965127222961, 0.16110530273327905, 0.17384787300421348, 0.15597213059663773, 0.5712338284619394, 69.90796427572928, 65.18004125164401, 53.45988542802873, 40.45492195313977, 74.57656537332844, 65.89114342966388, 99.11490532659717, 6.40539768242067, 0.3148979591506143, 0.24510336559145685, 24.40873503684998, 106.14358871213852, 74.81573581695557, 85.9329095963509, 69.89428304856824, 70.02714157104492, 66.57909577892673, 67.0052142297068, 65.04515878615841, 70.90455224437099, 66.58129230622323, 71.02885999987203, 74.08220552629041, 75.4538897545107, 77.37349771684217, 75.3788548131143, 72.30712906006845, 77.49114528779062, 76.09057672562139, 73.31083220820274, 70.87485990216656, 75.16080241049491, 71.82161023539882, 74.48752757041686, 68.20560855250206, 69.19683071874803, 64.53591746668663, 56.89735651016236, 53.81051002010223, 53.36079066799533, 53.94208592753257, 53.77496157923053, 52.503925369631865, 52.97014613305369, 49.66994231747043, 55.271247740714784, 52.04201136865924, 53.26516720556444, 54.85115797288957, 54.59057923286192, 52.04097586293375, 52.46787486537811, 49.88932048120807, 51.136759711850075, 48.27883058978666, 47.65047865529215, 52.789713182756984, 56.423047819445216, 57.6765549567438, 62.11024922709312, 61.01869283183929, 55.73733122118058, 59.00259848563903, 63.57018286182035, 62.62619779955957, 60.48190078427715, 63.53005309258739, 64.23699363585442, 53.59364217327487, 58.342855822655466, 53.00123483903947, 55.00778605861049, 59.964771578388834, 58.50302188627182, 57.11356147643059, 60.24229103519071, 62.525106553108465, 64.18753254798152, 61.83468311063705, 60.80508447462513, 58.87778082201558, 64.13495709819179, 61.88983555762999, 62.59486198425294, 58.17481756210328, 55.12464915552447, 55.850766166563965, 56.585712432861335, 51.852878601320334, 50.826029546799205, 50.18635372961722, 54.535281658172615, 45.781418277371316, 48.413724822382775, 53.523361144527314, 42.26340524611935, 37.159122959260024, 50.917130516421416, 51.92607002873575, 53.03151945913992, 58.147635536809126, 58.48855226270614, 51.86355137055921, 47.47699222257061, 48.874866116431456, 50.17057403441399, 49.66660438045379, 50.870387631077925, 52.76474337424002, 54.28457944623886, 56.58331978705622, 57.20993803393457, 55.4899630238933, 52.66644485535161, 51.37987605987057, 50.68280419995708, 50.86357055171844, 48.0108581819842, 50.406500677908625, 52.788395266379084, 52.51340573833835, 58.01775017092305, 64.04447194068663, 67.64804363250732, 68.0120631187193, 68.09986929739675, 68.77983570098877, 70.80182536955803, 66.21114607780211, 70.65479924601894, 69.68641311891618, 71.90512534110778, 73.62669283343901, 74.96029869202646, 74.79021687661448, 73.631313385502, 72.86050488871913, 77.3558235168457, 75.22689434789842, 78.17716783092868, 76.70619272416639, 79.43737045411142, 78.14152917554303, 83.10925806722334, 80.63924743283181, 86.09070654838317, 75.02792035379719, 89.44840446595224, 79.15004899424892, 100.47279850129159, 6.371245605330314, 0.6603319378149125, 83.00405225446148, 81.54467167392855, 70.29900104768815, 58.74248650766189, 60.06680419368129, 62.97180960255285, 91.29327558702039, 3.709624981687915, 0.25813614528986717, 0.2901977216524463, 0.10777110414158915, 0.1934581304029111, 0.1095095108593664, 0.10441819776690776, 0.15372194650192417], [0.10209204073274329, 0.006018832500558347, 0.04404886820984464, 0.007310009537069428, 0.040526886230274554, 0.02587579558753679, 0.02055142131153374, 0.062419204642215086, 0.2810493754523416, 43.32259032034105, 55.06538606459095, 33.00293637860206, 25.048018617014733, 53.808894003591234, 46.78655701298868, 84.46449971968129, 8.621556931926358, 0.28377664846278006, 0.027055689734556986, 26.48057999149446, 95.01823286856376, 71.93034618131577, 81.13439175390428, 62.788846723495, 64.17347085091376, 61.366116769852184, 62.38535642623902, 58.19087966795891, 62.357840999480224, 65.70884735353532, 65.19137297907184, 68.9294505888416, 74.34309805593183, 71.88650192752962, 73.0272291552636, 70.18979441735053, 64.60571212153282, 65.76020686857163, 69.97587619289276, 67.1466705876012, 68.8818016359883, 68.5553192323254, 66.33666976805657, 64.04233032657255, 64.28512896260908, 52.67674499942411, 51.35745186959544, 49.62353675596176, 50.67251974536527, 49.412132770784446, 45.95907026721586, 43.214591780016505, 45.339151428591826, 44.25933468726374, 46.259319859166304, 44.106213200476866, 46.68240631780317, 48.456031507061375, 49.123156070709236, 47.084370813062115, 45.54598977488857, 43.094273074980705, 42.867960160778416, 36.941619688464755, 40.56498758254513, 48.57414584006033, 49.67104058111868, 50.40902276192942, 56.831315563571074, 56.50263663261168, 51.796365091877604, 54.34791787978142, 60.11946985798498, 56.70015934974917, 59.42833646651238, 53.66494301826724, 50.86510812082599, 52.3239395695348, 45.72417520707654, 46.26729011535645, 55.013500951951556, 50.673582707681966, 55.23754673619425, 52.37662092331917, 54.015685281445904, 53.902062062294256, 53.35406380314981, 57.189694681475245, 54.79362072483186, 56.13265906610797, 58.23172723093341, 55.93146893285937, 56.53283103819817, 51.64424380948467, 52.025596249488096, 50.152397771035474, 51.979422107819595, 50.00017058464789, 45.9395250966472, 46.01528567652549, 46.910437230140936, 50.642258659485854, 51.21039828946514, 51.61202938325944, 53.743072709729596, 42.67818412473125, 27.848963545214747, 42.446219075110655, 57.06528494434973, 51.771191320111676, 51.02386213118031, 48.601398468017585, 43.57125682215537, 38.40476182199294, 39.58647389565745, 42.52624327136625, 44.13607812696888, 43.92059879918253, 46.0726660297763, 46.03858063297887, 48.55947617561587, 49.33742730848251, 47.026762962341316, 43.940344010629964, 43.75553761759112, 44.284779102571555, 43.3804609698634, 44.74978785361014, 46.79059313189599, 48.0806371473497, 52.39077675727106, 59.176108452581595, 61.574990826268355, 63.54211830323743, 64.18306889072542, 65.64240632518646, 64.5898186775946, 65.45817259819277, 64.71640140779557, 66.37663087537213, 65.33861091060024, 69.80295458147603, 68.60798881899926, 69.23346565615746, 70.88812535808933, 71.89890446201449, 71.00973452291181, 71.35780565200314, 73.15157613446637, 71.48356468446794, 74.33377065966206, 73.61575726539859, 76.16506253519367, 75.54411211321431, 76.52705023365637, 76.52966253219113, 78.98209310347035, 75.81211982234832, 90.92975816419049, 3.120185410784137, 0.8090681534621024, 71.00659662677397, 61.906023179331136, 47.644332301232126, 42.028027734448834, 27.17835395566879, 45.60146385623563, 66.71125611951275, 1.5122913929723925, 0.11574563510235279, 0.013487095692976108, 0.059080654755234725, 0.10371154294379296, 0.05040918679667577, 0.06252647993425209, 0.07703962495490428, 0.060879095953198216, 0.02203320389643552, 0.036344613068767136, 0.07032943784349388, 0.06690028273770887, 0.02155823321382125, 0.04906870912940753, 0.02650578799206884, 0.25260810079353474, 52.1321709694401, 60.06844374441332, 28.393718004226688, 32.01443829844075, 65.28216800382062, 52.61229261275261, 93.32887588008758, 8.911513243952106, 0.2949494279680714, 0.0939893049578513, 29.48287194774997, 98.199934036501, 77.71013905925136, 83.4725558373236, 66.81903500710764, 67.25520257026919, 64.23751138871717, 67.178465320218, 62.449675452324655, 66.31087626180341, 67.59649584370275, 68.34563716765373, 71.58600130388814, 77.5610262347806, 76.75890153454196, 73.61046991040631, 71.29170586985927, 68.10260711177703, 66.37827042610415, 71.2078534403155, 68.82561760564005, 71.09069224326842, 71.02728320706275, 70.02277989541331, 67.44229962748867, 67.0741145841537, 55.43024886038996, 53.86023390677668, 50.93348680003997, 54.557368524612926, 52.22530764918174, 48.74081127105221, 46.42935852850638, 48.50007580172632, 47.23276192142118, 48.62202229038362, 48.183579752522135, 47.80060737363754, 52.4222812344951, 52.09168034215128, 48.29064869111585, 47.24265413899576, 44.41130299721995, 45.35850440302203, 40.734575179315385, 42.96858856754918, 52.082129370781686, 52.21442307195356, 54.61195615030105, 57.86079652847783, 56.3990625258415, 54.11508206398257, 57.91798076322002, 61.92985550049813, 61.33187055587769, 61.09947012316797, 57.958389020735225, 53.20828499332551, 55.40720885799777, 48.76446708556145, 50.84348017169584, 57.905048708761896, 55.017427244494044, 56.58413171768189, 55.524103333873136, 53.43026761085757, 56.172655474755075, 57.418521834957986, 57.92978317506852, 57.665850808543546, 58.998091682311035, 59.59654338898198, 57.264878672938195, 58.00070747252434, 54.87619446169946, 54.53189273034373, 53.40712954921108, 54.269140997240626, 52.65142609996181, 49.32980222086753, 47.724987999085464, 52.755321841086115, 52.85604830711119, 54.26002148658999, 52.62080023365637, 59.64891095315257, 47.00350722958965, 30.876229232357396, 46.28170090336954, 57.6859058872346, 52.95553530416181, 55.309824251359515, 49.31464226015153, 47.147089512117454, 41.703604575126406, 43.89954351609753, 44.84966708767799, 46.84266651830366, 44.4274906189211, 48.953313519877774, 47.76562767644083, 49.86574703647245, 49.54872931203535, 50.07540556692308, 46.78369368276289, 46.97120651122063, 47.10466515633368, 45.50212983162173, 46.747399991558446, 49.48246086797407, 49.91874217987061, 55.10836739693919, 62.06851520845967, 64.70784671844976, 64.12616314426546, 64.45437139080417, 66.94493524489864, 69.68438133116692, 68.17848928513067, 68.43562418414702, 67.03193341532062, 69.37329030806019, 71.35026685653195, 71.72503363701605, 71.73988373048844, 73.20497528199228, 74.46870803833008, 75.65160859015681, 74.76101090831142, 76.38278545871859, 73.93758773803711, 77.15336645803144, 74.97132839695101, 79.34775214041434, 77.48421053732596, 83.09316066003616, 79.13566174045687, 83.82376486255278, 78.99089490213703, 96.95581313102477, 3.2085809255799944, 1.5183081862426575, 79.89982574216782, 67.58112015262728, 57.15886092955067, 50.16689485119235, 32.62110933180779, 47.73050285154774, 77.78056913806547, 2.845559682576887, 0.17225863892705212, 0.04351170650953728, 0.10898895411481781, 0.08492080044121512, 0.010142589472384464, 0.03956193720260936, 0.033363810920667265, 0.1466911592550816, 0.12027683066985301, 0.16856949656240403, 0.12956823612893784, 0.17555249524452995, 0.11633153148596326, 0.20286426518953618, 0.18528677613264133, 0.5779505809468608, 67.55672301015547, 70.75563553840884, 43.72983432585194, 32.08957914383181, 74.43143767695274, 56.827373581547896, 101.92578561844365, 9.525594615167188, 0.3985736368884964, 0.25760058854376117, 30.027914700969575, 101.16959187292285, 79.41239280085411, 87.84482186840427, 68.58319943951022, 68.92671277446132, 66.24743584663638, 69.21319484710693, 62.96171342172931, 70.10776196756672, 70.82815231815462, 71.2291754445722, 74.79558267901021, 80.76050358433878, 76.09870387661842, 75.15313025443785, 71.20942238838443, 69.00468164874663, 67.4165218107162, 72.65476088370048, 69.6352340329078, 72.7391859792894, 73.38862065346011, 72.17146212054838, 69.17214332088348, 70.31869134595318, 58.221674196181766, 57.20784348826255, 53.503494339604536, 54.89465705810055, 56.01410935001989, 52.755196325240604, 50.1139703104573, 49.14323860599149, 49.58999656861829, 52.7541059063327, 49.58448171615601, 49.40294657984088, 53.75964080133746, 54.860897218027425, 52.71967534096011, 50.918075807632945, 48.88890820164835, 48.478706729027536, 45.25476555670462, 48.42023595686882, 53.39088309195734, 55.615757357689645, 57.84742124619023, 62.68054616066718, 59.610577629458525, 58.4652376944019, 59.68780125341108, 66.27199772865542, 64.63950334056732, 64.3648785929526, 59.998574564533854, 57.03042684062835, 57.023162611069225, 50.99345983997468, 51.851913698257945, 60.2061777730142, 57.45925172682732, 60.02988684561945, 58.22445123426376, 57.170282871492454, 59.806727517035704, 59.68430642158755, 61.71596081026139, 60.54478422287972, 60.52834949185772, 63.6759142721853, 62.48339606869606, 60.58300379783877, 54.897622369950824, 57.101786521173295, 54.679142428982644, 56.52731618573589, 55.356284726050596, 51.69048855381628, 50.69102548783826, 53.97199400009648, 57.52615559485651, 57.09057638722082, 57.97055621300974, 59.31134000901253, 49.67629263477941, 36.856402274101015, 47.70139494249898, 53.06364367085119, 51.077814332900516, 58.93880897952665, 52.280311046108125, 49.422581964923495, 43.248775236068234, 46.72157510634392, 49.75268471625544, 51.53048722974716, 48.93523531575357, 51.84039369706185, 51.946584024736964, 56.23240886196014, 54.634780422333755, 53.95493953458725, 50.34884575874575, 48.50954440332229, 50.892407817225305, 49.25221381648895, 50.85188973334528, 52.279863895908484, 52.14248288062311, 59.311030141768924, 65.24092820382887, 67.93710662472633, 66.81974103373867, 67.59480137978831, 69.80046779878678, 71.65807877817463, 70.3149337153281, 69.62601646300286, 71.0021565037389, 71.87486033285819, 74.9160857354441, 73.71162783715033, 73.33160508063533, 75.18408559983777, 77.55324425235872, 78.50354040822675, 75.96013438317084, 79.06034438840805, 75.2268708136774, 80.6263977481473, 77.131299203442, 85.62048496738558, 80.79538914465135, 84.28201536978446, 81.39479790964435, 86.8189573287964, 79.21039858172017, 100.58156582616992, 5.356966766618914, 1.5931861102581026, 88.57846198543426, 73.86456889490928, 68.33099103743031, 60.875000722946666, 40.77501089342179, 63.76791346457697, 93.62542275459536, 4.07354346686794, 0.32074563085071506, 0.22293365440301358, 0.3875788655732909, 0.18563418168454401, 0.11283332887556284, 0.21283106908442515, 0.1428014703936154], [0.02600610522823709, 0.055168312673847524, 0.039717234716179876, 0.12637603201813277, 0.07377767619947273, 0.09986638677336517, 0.09241576802225844, 0.16034175822090718, 0.06368799180152916, 31.902570339941214, 52.34721099176715, 63.466432248392415, 46.6107250029041, 53.45917155665737, 50.99797448804302, 84.71547649752709, 18.41484546661377, 0.15466644098201107, 0.07112823006126189, 33.89929602223058, 96.96455217176869, 69.98484273110667, 79.25619617585214, 61.364030068920506, 69.9162483215332, 62.05666180579894, 64.98406394835442, 63.6471946777836, 65.75427232250091, 65.44886873614404, 72.22262551707607, 68.4814453125, 71.27197634789252, 74.06947351271107, 63.00793855421005, 60.50828264605615, 64.56426051355177, 67.72171358908376, 70.39009417257002, 68.06470132643177, 69.3075200050108, 64.00442454122728, 63.23162348039689, 59.23995679424655, 57.10452433555358, 48.82044323029057, 49.71690485554357, 49.801184823436124, 50.949635198039395, 49.536668023755475, 47.24952220916749, 42.829846489814024, 43.1891591318192, 42.367755982183645, 44.73704407292028, 43.77304315567017, 44.8317143993993, 48.33726998298399, 47.03399189056889, 43.00680029776789, 44.52396915804955, 40.94807371016472, 38.77363328010806, 34.87470319194179, 41.25206916562973, 49.988646661081624, 50.171809581018266, 48.9608052469069, 52.526922225952156, 53.18999890358218, 53.62587621135097, 54.29189074424006, 50.155621959317116, 53.60330689337946, 50.60770257826775, 53.786320763249556, 50.76436596532022, 45.52958250045777, 46.342576088443884, 50.63207618651852, 53.79836243967856, 54.048484140826815, 52.428886505865286, 51.7008985242536, 51.213740148851954, 51.952447968144575, 52.04191330940493, 51.28668054457634, 55.24371270210513, 54.63569041221373, 53.387753040559836, 53.080596154735936, 52.774898390616144, 51.79236427430184, 54.62603353684949, 53.39589980340774, 51.14186663781443, 50.50711731756888, 48.101178599942116, 43.40421092125678, 47.03960872465565, 50.03959432724984, 53.85281670478083, 54.682813767463934, 53.60794313492314, 56.47495254393547, 46.58080908559984, 33.48520355839884, 37.02610361960627, 64.87195476408928, 56.53097575710666, 49.66268593265165, 50.3511913361088, 39.80908801478725, 37.224089176424094, 37.94096900570778, 40.78852345866542, 42.26003200777116, 43.56688730178341, 45.88707908507317, 44.708144049490656, 46.25111426076582, 45.8228777300927, 41.18506723834623, 42.21231637462493, 43.41720181126749, 42.21906285132132, 44.99073120855516, 47.195899486541755, 47.35352385428644, 50.82664535891626, 58.49556153820407, 63.72558716804751, 62.117964529222064, 61.174320713166274, 64.08628832909369, 62.4117265209075, 64.0880730075221, 66.28060340881348, 66.9421503620763, 64.90470263265794, 67.21963451754662, 69.52553318392846, 71.29649116146949, 69.00307347697597, 67.82878645004766, 67.61284428258097, 72.55035523445376, 71.91562160368889, 73.91339455881428, 73.60810079882222, 76.48568491781913, 74.13386314145981, 75.61269867804744, 74.42021185351958, 76.95144284156062, 76.30082361159786, 76.3878688504619, 84.59640902857628, 1.4486334088348574, 1.567081020724389, 71.52895435210198, 61.466792245065015, 46.43240228776009, 42.74003205760833, 34.02357632114042, 33.0776692974952, 70.95931637671687, 3.512405267646236, 0.11385614052414895, 0.09575287000306192, 0.07070937914954079, 0.05708144489495505, 0.05264347073652091, 0.02787608754700951, 0.06412026457368367, 0.012850938195873414, 0.047640073894252705, 0.09804478290701106, 0.09418265788906044, 0.04939488638492842, 0.1691824741541378, 0.03459193796340016, 0.10145158356716556, 0.23644648011653657, 36.94900551149922, 58.74560871431905, 61.397687927369155, 49.20059542502127, 64.30880831133935, 56.65812723098263, 93.12346919890373, 20.182443934102213, 0.1056947990230495, 0.15851410225995127, 39.99340411155455, 101.13951513844152, 73.99576433243291, 83.35072701977145, 65.15615401729461, 74.20528165755734, 65.9725090765184, 69.99925351911976, 66.44623725645005, 68.79019860298403, 67.82805688919561, 74.32851468363117, 70.7327445860832, 73.15788330570345, 73.53848657300396, 63.128959363506695, 60.04629412005025, 67.48783050044891, 70.55470035922143, 70.51788499278408, 69.16185886629167, 70.2986401896323, 66.37603467510593, 66.78087034533101, 61.51525705091415, 59.26017269011467, 52.2491164361277, 52.31898169363699, 51.68391858377765, 52.06395310740317, 51.060524525180945, 48.578527127542806, 46.69889596200759, 46.88940548127698, 43.60924497727425, 47.99609045828543, 46.59376075190883, 47.18778410265523, 49.52193560138826, 50.41547506086288, 46.39900330574282, 46.47497961598058, 44.04660494096818, 41.22956652795115, 38.3543279863173, 43.85273002809094, 52.387595715061316, 54.16062078168316, 51.279824241515136, 57.14697222555838, 52.69983207025836, 55.04136546965569, 58.03393387025403, 55.87777560757053, 55.849142305312625, 54.7726321220398, 56.36671866140058, 53.518740592464326, 49.5095173774227, 46.85152323015275, 51.5746021270752, 57.131043480288604, 54.557678391856534, 55.17221966097432, 54.65101119010679, 53.586609363555915, 53.09697597257553, 53.189363479614265, 54.32435227978615, 58.3130693435669, 57.419769148672785, 55.79884183022284, 54.66526116094282, 55.63712250801825, 51.15978794713175, 53.95122505003407, 57.10641099560646, 54.44378060679282, 53.2208405002471, 50.045175860005045, 44.781311942685036, 49.697693086439564, 52.414605156067886, 54.56338544045725, 58.327558578983435, 55.63008185355894, 60.23581912440639, 51.05172664888444, 34.383194908019036, 40.399208607212195, 59.863397921285326, 54.79873549553656, 53.25047792926912, 52.96679250655636, 42.27169321429345, 40.009470139780355, 42.32920692813012, 43.38147686373803, 43.84006077243436, 44.6713992857164, 46.089951915125695, 48.47679261238345, 48.8321279710339, 47.902824340328095, 42.76814368463332, 46.572011209303334, 45.582134416026456, 45.9191091599003, 48.37247325528053, 49.83396407096617, 49.012447172595614, 54.41338223795737, 60.47143197828724, 66.56118623671993, 65.42551886650824, 61.262691713148556, 66.1727382290748, 64.96068269975724, 65.9687828248547, 69.5661061809909, 68.66809521951984, 67.86727274617841, 70.2757021688646, 71.26079759290143, 74.10843833800286, 70.73498818182176, 69.60027002519178, 69.53261698445966, 75.17038868319604, 73.58266815062493, 76.19502159856981, 77.55852376261066, 78.2608868998866, 78.58212117225894, 80.96932272757255, 79.0732882099767, 81.31216925959434, 82.17055643758466, 81.50634227260467, 86.61880662364345, 1.522399463480519, 2.1483184253015826, 79.18709185815628, 67.10176729386853, 57.10316719547395, 49.248420884532315, 34.582121833678215, 42.11044849887971, 80.47657889704551, 5.132557182542739, 0.12130714231921781, 0.06419545993389142, 0.07855902245688824, 0.03824911530940764, 0.05990164820104838, 0.05441701790738491, 0.06328631658107042, 0.11580483071626195, 0.2572887294715451, 0.12796022523675235, 0.40315946984675627, 0.1976123341028729, 0.3765827459433387, 0.16225435801090735, 0.30597401542528985, 0.3350385026104989, 51.35702825361683, 67.18849089837843, 84.13532657008018, 59.50110427794918, 73.11042262661842, 61.59745816261538, 99.03210409225957, 22.643642963901645, 0.24921476029820983, 0.4565596898957607, 42.068298709008005, 103.84139276319935, 76.60760002751505, 84.62621119714554, 66.15123579579016, 78.82942661162346, 67.61721380295293, 71.89220505376016, 68.91367481600854, 71.63619979735344, 71.48504734039307, 77.38488827982258, 74.86997435169836, 73.06562131451022, 73.79100876469766, 62.80624635757939, 59.37427051605717, 67.4735216940603, 74.90162787898895, 76.67541780779439, 72.04571877756428, 72.6298773673273, 68.49716617215064, 68.68831111538795, 62.10164354693506, 62.88012027740479, 54.78254002909507, 54.197636188999304, 54.971072673797615, 53.82306160465364, 53.897214012761275, 52.31659297020205, 47.538094905114946, 51.59669291588568, 46.82949127689485, 50.77894541525072, 47.39205721885928, 51.47952387409826, 54.095427067049094, 52.097963979167325, 51.11423353995047, 49.94002103805543, 47.1420531888162, 43.74201328523698, 43.07330800640968, 46.32957343132266, 56.62764257000339, 55.27697832353654, 53.146115426094305, 59.852846745521795, 59.06066525366999, 59.21080966149608, 62.035779107001524, 56.2872318298586, 59.47911547076318, 57.117028851662916, 59.563697461159, 55.684732237169825, 51.829258088142645, 49.091906547546394, 57.65395425981092, 59.948780075196304, 59.388281222312685, 58.88528039378505, 58.1709893288151, 55.679240918928585, 54.6891091715905, 56.237370660228116, 56.66999632312406, 61.830015490132, 59.6179477630123, 60.961645880053126, 59.598386902962964, 58.857517857705396, 53.77457718695364, 58.81117113174931, 58.80827250019197, 55.30980463950865, 56.69019652951149, 54.17485506303849, 48.238371341459214, 52.248947774210286, 55.82868714486399, 59.221925658564416, 62.265920254491995, 58.890304949975786, 62.48807153394146, 51.87112154499177, 42.41023917352, 48.056196858806, 60.57936776068903, 54.18589653507356, 55.01422266806326, 54.98318103051955, 44.42953809615105, 42.545804131415586, 45.867667275090376, 47.01911041813512, 48.258669607100956, 49.63000082200574, 51.03697853703653, 49.636715919740745, 51.096790759794175, 51.52501552335678, 47.35959176094302, 49.59643710044123, 49.04100202745008, 49.848233653653054, 50.97636222839356, 51.778357490416504, 51.60743236541749, 56.9539680788594, 63.81839829106485, 70.47120094299316, 69.43266714772871, 64.58020494830224, 67.35246950580229, 67.20699664085143, 68.28129460734706, 70.24033023465064, 69.3462573328326, 69.57886172879127, 72.86493716701385, 73.99993773429625, 77.89497683125158, 74.14726980270879, 71.96874618530273, 73.9338928653348, 79.4235009531821, 78.67900371551514, 78.14873064717939, 81.2474109280494, 80.4130208107733, 82.33001647457, 82.6446533203125, 82.4064007113057, 83.62712860107422, 87.06196385045206, 81.91743020088443, 95.19069948504048, 2.643452940448638, 2.1346139090676464, 90.80428938711844, 75.36677391298356, 66.05279214920537, 56.95090078538465, 52.57992521409066, 51.892580832204516, 96.55689239501955, 7.482597712547549, 0.36533035458095614, 0.3398233958550038, 0.20198153271790475, 0.2407546828110372, 0.20202400463242687, 0.13103720972374563, 0.1776061777866656], [0.09477902669459583, 0.05131110210993117, 0.11016078518643496, 0.06573856402669223, 0.15070576641348102, 0.08320805766890127, 0.002144873099994936, 0.16331523656845093, 0.2796968625437829, 22.63389587402344, 56.80091327236545, 32.998319748909246, 34.05950523191883, 56.83959176463466, 50.46764258415469, 79.89711146200858, 33.57867363960513, 0.12513349869198379, 0.2821218679028173, 44.117054631633145, 92.9574352695096, 69.53415455356722, 78.38403363381663, 66.6940055354949, 71.74489651956867, 68.72290642030778, 71.10868807761901, 64.72780766025667, 70.56299224976571, 67.81636038134175, 70.54225075629451, 71.98270197837584, 123.26434227728076, 70.53367645509782, 61.03723387564383, 68.89122316914221, 69.05449574993503, 68.90474750149635, 65.41058640326223, 66.3365364074707, 62.89685310855989, 60.56248195709721, 60.55125221129387, 56.89897644904352, 56.28890668192218, 51.59680274225051, 50.633845175466234, 49.051792467794115, 50.652794145768695, 50.40649283316828, 46.58368810530632, 43.74240944462438, 44.377805955948375, 43.787434331832394, 44.76199034721621, 45.28697998292985, 43.9059095228872, 44.15411318502119, 48.70771823390838, 43.69496837739022, 42.324449093111106, 35.820088540354085, 38.512313212117846, 35.479069832832586, 43.50407446584394, 48.526434129284276, 53.167778676556004, 50.25679949791201, 52.81806407436248, 49.24983293779435, 49.10400313715781, 54.45124487723074, 54.449224856592, 53.399575064259196, 50.55963000943584, 47.50567259327058, 48.89761978580106, 49.48635970392535, 48.312602196970296, 48.50956401517315, 51.35567503590738, 51.524415400720414, 51.85783647721814, 48.4609305474066, 49.4256414136579, 47.631066845309356, 48.056051731109626, 48.8651543278848, 54.13665117756013, 55.9691511431048, 52.18618985145323, 47.0662808418274, 48.11405574121783, 51.16948012382754, 48.80749940872193, 53.175976430216146, 51.352623431913315, 51.13036232609903, 49.43345085267098, 40.8753215882086, 44.068597670524355, 49.360718342565725, 49.13484865619291, 51.348128395695845, 55.05856898523147, 51.21492470464399, 54.07753713669316, 53.31347903897686, 36.60084416789394, 30.773274860074444, 51.173500553254165, 52.04177210407873, 51.19914500944076, 44.7749420135252, 36.70974093098795, 37.47066505493657, 36.412213463937086, 40.79594458303144, 41.134119572178015, 43.180145525163226, 44.81094937170706, 44.95723024491341, 43.79408274927447, 41.5981791096349, 43.28167215470345, 41.49006682057535, 44.422520975912775, 47.233750358704604, 46.576431720487534, 46.49781173275363, 52.54980533353744, 61.86770162274761, 63.574077775401456, 62.21557663333032, 59.370026511530725, 62.84687819019441, 73.73782926990141, 75.6626618293024, 63.98253379329559, 65.66735259948238, 64.79023218154907, 66.0393697984757, 65.99940869116014, 71.16365617321384, 72.84639220083915, 74.25681375688123, 71.1168622970581, 71.44256807142689, 66.24729464131018, 72.45439052581787, 71.97618299914946, 71.46333309911913, 72.22689305582355, 73.47141404305735, 74.72439950512302, 80.49803426188808, 77.10763162182224, 82.79164806489023, 63.16924602754655, 1.2284912409320956, 3.614490344639748, 69.2295354412448, 58.8353015530494, 39.60435598127304, 46.40601650361092, 31.442323346291822, 42.4884630018665, 63.306191659742794, 3.194749667759865, 0.18982026996391435, 0.06017686145740652, 0.14677579664895612, 0.04357499303296209, 0.11618419745636564, 0.1172097210562037, 0.050813087502554546, 0.05773523965129449, 0.056660257415064884, 0.04654165702841936, 0.013490649383334864, 0.051672324057548284, 0.10028942052515284, 0.05336849251762033, 0.15271064915483998, 0.2656146649631762, 29.80580068403675, 66.74795381484493, 33.042909253028135, 31.06903333817759, 63.455928141070956, 59.313477700756444, 87.1272320901194, 36.38093648418304, 0.048052512650047584, 0.42897332339517535, 48.44866921824794, 99.3368487204275, 72.3435757237096, 82.24616404502623, 71.4248703372094, 76.75314349512901, 72.0748306089832, 75.35127270606257, 67.1751077713505, 74.03167755373063, 72.39684151064965, 72.64919111805578, 72.33242834767988, 103.68933816109936, 68.6300874525501, 64.57501173019409, 70.23052430921986, 73.13293703140752, 71.7547965818836, 69.52396423585954, 67.20065809065296, 66.87408939484628, 63.14970870171825, 62.43391929134246, 59.809198610244266, 58.601222345905924, 54.8113263037897, 52.00631387772099, 50.46372021398237, 53.87816306083433, 54.131281452794234, 50.39192907271847, 45.480262617911066, 47.11846797697006, 46.64575569091305, 47.19752727016326, 48.33798777672553, 46.24707421948833, 46.67189044337119, 49.238132507570334, 45.66499056354646, 44.71030135308543, 39.7879268277076, 42.22496601843065, 37.03359926900556, 46.543907427018695, 51.43941371671615, 55.34754568530668, 55.059765308134025, 53.202217086668945, 49.44810482763475, 51.41018029182188, 59.43225491431452, 57.1491648304847, 55.80184244340467, 52.83990383148194, 49.58923562880486, 50.95478919244582, 50.83288977223059, 49.55163578833304, 49.67346852825534, 55.03927484635384, 54.02549905161704, 52.34350435195431, 51.10720857497185, 50.09073026718632, 49.92494736948321, 51.7948353675104, 50.9425788540994, 57.045535810532115, 55.919584151237245, 53.299040794372566, 50.21919181269985, 50.13719466424758, 51.419515532831994, 53.25625165816277, 54.26557164038382, 53.864752477215184, 53.59804307260821, 51.78496276178668, 43.55841890458138, 46.411570579774924, 51.66230632412819, 52.60312603365991, 53.27618514337848, 57.200889125947036, 52.8026609266958, 59.07799428509128, 56.979271288841005, 40.553883352587306, 35.35692722566667, 47.81895229893346, 56.02800630754041, 51.697329167396795, 49.53852722721715, 38.832260947073664, 39.417964950684585, 40.12749818063552, 43.659816095905924, 45.58145192361648, 46.39507309083016, 45.113454326506584, 48.82323988022343, 45.82626273555141, 45.58400146422848, 46.201559036008774, 44.81107488755257, 47.685568178853686, 51.59313140376922, 48.118205608860144, 50.20747177062496, 56.706945050147276, 64.74450126771005, 65.78633377628942, 63.68683022837486, 62.76410049007785, 64.52209111182921, 74.57760087905392, 76.4783343961162, 66.05612616385183, 68.72277305972192, 69.64339256286621, 67.22918156654605, 69.916107116207, 71.83541697840538, 74.83463379644579, 76.3508181418142, 74.82516519484982, 72.90063073558193, 69.93850384989094, 76.04469283934563, 74.20204962453535, 73.6465714054723, 76.2461300819151, 76.85836499737155, 78.60221939702188, 84.54801482539024, 81.44848731256302, 87.92038240740376, 61.51602191309775, 1.4269445403929681, 4.502289660515324, 79.02558434394099, 65.49776108034196, 46.09862819794686, 52.934279980198035, 37.25954348041166, 50.57038122607816, 72.42422749919277, 4.124786046243483, 0.2174561104226497, 0.061244803345611984, 0.06293817175432079, 0.02322947508805702, 0.04440174362952671, 0.0424417038448155, 0.05130539858533491, 0.13952708803117275, 0.17376156553866404, 0.29673652723431587, 0.17881017689022327, 0.25166993419970235, 0.1940293715245301, 0.17678289373795833, 0.2993977634656814, 0.4763891710148704, 37.691047345438314, 76.72026618834465, 43.525929912444084, 43.96624734324794, 75.76030531237203, 62.64060466520248, 94.07609524265413, 39.16831001158684, 0.1978691574186087, 0.5171176839259364, 47.86395365192045, 101.96031032070037, 74.25526834303334, 83.72758050118723, 72.89967367725988, 79.69358751850744, 75.43405040617913, 80.00671817410378, 69.72345598282354, 78.55999900448707, 73.1458180950534, 75.60823502079134, 71.70273104021626, 100.96087471131356, 69.70248699188232, 64.46189841916485, 72.34003774581417, 74.07745161364156, 73.97536800753686, 72.86216012893185, 71.91411541354272, 69.16309833526611, 66.18729022241408, 66.34105497790922, 62.78093138048726, 61.59546167619767, 55.805211759382686, 55.46191415479107, 54.04429897185295, 55.8350335398028, 56.846863838934134, 52.13776819167599, 49.133628799069314, 51.10659668522497, 49.51089805172336, 49.80468357762983, 51.072719174046675, 47.19159272409255, 49.43248594960859, 55.029339482707364, 48.65951622686079, 46.61704786362187, 42.031373516205825, 46.265128889391505, 41.514040347068544, 48.33090005382415, 54.943404274602095, 57.761874352732015, 57.42581744347849, 56.237562856366566, 54.90618882640716, 53.65062244476811, 59.73075512916812, 63.30775276307137, 59.65068386447046, 55.74837269321565, 52.217270712698664, 53.99615580035795, 51.283872127532966, 52.14703675239317, 54.06263213003836, 60.062595490486395, 58.01060753483927, 57.42498197863179, 54.42352156485281, 53.59091612600512, 51.595708400972434, 53.62808842812815, 53.697577138100904, 58.29876053717829, 60.697635066124704, 56.65971186853225, 54.13711793961064, 53.88513311263054, 58.2393797751396, 54.41086799867692, 57.27068378079323, 57.24834196029171, 56.6344282704015, 56.49357595751363, 44.19068144213769, 49.94932882247433, 56.94670777167044, 54.67020726973011, 55.66084108045025, 60.61659497599448, 56.90460897261097, 62.95228796620523, 59.42943080779045, 42.933942271817116, 45.12912419534499, 56.172902584075935, 58.24825609883955, 56.29728094224007, 51.070812902142926, 42.19925095958095, 41.829045895607244, 43.41289112644811, 47.84382012582595, 47.155357868440696, 49.04524603197652, 47.16590119946388, 49.47747945785523, 48.54234718507337, 46.487554734753026, 48.477333899467226, 47.02021652652372, 52.261605262756355, 53.39831598343388, 52.23052047914075, 52.13643066344723, 60.87705996728713, 67.54303393825408, 69.0177902098625, 66.27250763677782, 65.57685959723689, 65.49061844425817, 72.98923707777455, 77.09120473554059, 69.3025464396323, 71.71874215525966, 71.83618576295915, 69.82699086589199, 73.30000646652715, 75.05265482010381, 76.72671456490794, 77.38946960818383, 77.77419136416528, 72.94550265035322, 70.66145158583119, 75.48777118805917, 78.09394298061248, 75.7554494180987, 78.25876097525321, 77.92345323870259, 82.13253298113423, 88.55084849942116, 85.98651270712577, 89.48007368272351, 77.89773033511254, 1.4290837030256949, 4.491955686000086, 89.90424663789811, 73.27258909902265, 58.75674432323825, 63.72544988509148, 47.63459697846444, 58.97221580628426, 85.45241925024217, 5.592986076108871, 0.3955568439297138, 0.15136121591973692, 0.33580872740957046, 0.1783673474264722, 0.2911086614814497, 0.2216405745956206, 0.15934084902607626], [0.03874516873169811, 0.10249508725058648, 0.03920814630785777, 0.2122902263316416, 0.1049572172304315, 0.09738267609669317, 0.05752405602364771, 0.24536711434202813, 0.5924789787780854, 30.18793171451938, 57.73049931372366, 48.574122305839296, 47.97023027173935, 49.28236115363337, 44.54300834286598, 71.91511954030683, 48.302015719875214, 0.10652939052951914, 0.13757728701156957, 50.1313817116522, 91.89604974562123, 69.32965786226335, 75.98236637730753, 67.54900378565635, 72.41420192103233, 67.28935856972971, 70.34337089907739, 68.12003812482281, 71.6942822548651, 73.92050189356651, 69.11747332542174, 73.50033760070801, 104.55441690260365, 62.451581724228404, 72.13427020657447, 65.95013587705552, 65.83209606908983, 62.58677405695762, 62.2969344354445, 59.82060094033519, 60.59630847746327, 61.937331538046564, 58.15333081829933, 60.087035779030096, 58.744769327102176, 55.946719108089326, 49.40924590633762, 49.7362970536755, 49.80875107549852, 49.21929728600287, 47.992642694903964, 42.19295555545438, 42.55831649226528, 42.757392467991004, 44.537673919431626, 43.655521100567235, 44.01148796081544, 41.59817126489455, 45.53357939566336, 42.44198291532455, 38.09416501752792, 36.82964778715564, 36.37292700429117, 37.966774279071444, 47.16285744021016, 48.89134399352535, 50.531243816498794, 50.74089450220908, 51.12230577776509, 47.86726020997571, 52.29488265129828, 50.84144838394658, 49.698689368463334, 49.33381088318364, 45.53233208194856, 46.746344873982096, 51.125224021173295, 50.46801128695088, 47.72783563983056, 44.20616695957799, 43.383783217399355, 46.11924809794272, 47.03106972479051, 49.24441222221621, 48.68388591274139, 47.03601191120763, 46.12628875240203, 46.44355750853016, 53.20577075404506, 52.38171215980284, 48.341376704554406, 45.60974397966939, 45.94508701755155, 46.415477260466545, 48.13716634627312, 44.85568400352232, 47.52731623188142, 45.52230650378812, 44.94182317487655, 45.644621695241625, 45.671991994304044, 45.98519717493365, 48.12281047144244, 47.48500954720282, 48.73438642870996, 51.689429513869754, 53.32255148118543, 53.4085572919538, 53.859025816763605, 38.2753667523784, 33.166052064587994, 50.21830927941107, 49.25744625829881, 47.53883231070734, 38.05663970208938, 36.79576635360718, 35.56123172083209, 39.42838276586225, 41.08253255967171, 44.17168540339316, 43.62342434544718, 42.38430838431082, 42.67987466627552, 42.49411905965498, 43.09980753929385, 42.387909120129, 44.027389249494, 45.923027607702444, 47.100519211061545, 44.78649731605284, 50.61097775736163, 59.77512890292753, 62.42731009760211, 62.770937181288204, 58.55099247347925, 63.87884201542024, 74.7424816316174, 69.17175108386625, 69.56767512905982, 64.4785253463253, 63.555266088055035, 64.96025516140845, 65.14181383194463, 64.84292922481414, 68.03320469394808, 70.58243936108005, 74.8045962856662, 74.8275343064339, 72.01848968382805, 77.05802932862314, 73.7566017335461, 76.02518297010853, 75.89518777785763, 79.58005059149959, 76.01482006811327, 80.83412647247314, 77.28500904575472, 79.04048150585544, 26.91078162962391, 0.916522464925243, 4.9086486812560794, 71.32404973430019, 50.48354387283326, 45.348710244701756, 41.17186846271638, 33.489847644682854, 45.786372230898955, 58.66637291446809, 2.8259034599027326, 0.2920798771083355, 0.05992986704973925, 0.04227158252991015, 0.03906455461777026, 0.11020393125833043, 0.051537894779035164, 0.09603377912313708, 0.07084587303500983, 0.04014239053151781, 0.047501285575450435, 0.08699615561072865, 0.059279829954668406, 0.07100764782198014, 0.04835255098559203, 0.38165755750190833, 0.5080378872732962, 35.327513371744466, 65.17575410104567, 50.462359151532574, 60.93127104543871, 59.708295637561434, 48.48658284833355, 79.65998065087103, 51.22505618679909, 0.12540542160070714, 0.34144416211112855, 54.5143283567121, 96.01086708807178, 73.55514095675561, 79.81103112620693, 69.50555263027069, 75.66358750866306, 72.89258203198834, 73.89473976627474, 70.46362292382025, 72.56471895402478, 74.70750977916103, 72.91768520109116, 71.64723734701835, 105.44088040628742, 65.62659132865168, 71.96050136320054, 68.9167421094833, 69.24170263351934, 64.92647570948448, 65.25831214843258, 61.92943188451952, 63.87130321994905, 62.095089266377116, 61.0692443386201, 64.72710555599582, 62.710513068783676, 58.997417034641394, 51.548855689264116, 51.63999588258805, 50.74615832298033, 49.52024898221416, 52.502179914905184, 46.372762649290024, 46.746650818855535, 44.520399801192745, 45.65494929590533, 45.86847528334587, 46.99115176354685, 44.11415207770563, 47.23169111436414, 43.74655931226669, 42.1974152903403, 39.65912795835926, 39.935984534602014, 40.65822232154108, 48.91949876662224, 51.88831721582721, 51.906450333133826, 51.557539816825624, 53.010421029983036, 49.836050771897845, 54.83428785877844, 53.54653450750536, 50.44464180546422, 50.38635146233344, 47.90015712861092, 50.254606892985684, 52.83931547595609, 53.8245403382086, 47.41909411645705, 47.47194413215884, 44.903344723486136, 46.75732358809441, 48.877898108574655, 50.998629523861794, 50.655971265608265, 49.38344063297395, 48.82999027928999, 48.70777314709079, 56.31423342612482, 56.393618276042325, 52.71424678064162, 48.12923139141452, 46.901615819623395, 47.88499324552475, 51.905116727275235, 47.28784376575101, 50.086411737626605, 50.52687037375666, 48.135922954928496, 46.49949050718739, 46.30443103851811, 47.3835535203257, 49.810449461783136, 50.43405140599897, 51.16919379080496, 53.73017203423285, 56.2830388161444, 53.37250286532987, 55.647242223062825, 42.17466554334087, 37.89317100278793, 53.36757244602327, 52.82341810964769, 50.91432602174821, 40.60470942528018, 38.590011442861254, 38.23540564506285, 41.74604069802069, 45.30500327387164, 45.24419084672005, 46.85198606983308, 45.27243191196073, 44.45584543289677, 43.91177346629482, 45.77661337391023, 45.445086802205736, 47.51235631204421, 49.16572947655955, 48.190781224158506, 48.77322181578606, 52.26988146381994, 63.55755675223566, 64.31011838297691, 64.07437609088036, 59.70982928429881, 64.79819851536905, 74.90737022892122, 73.57785148005333, 70.80024857674876, 67.6250820775186, 67.26777768904164, 69.11401379492976, 68.13423710484659, 68.4526002022528, 68.84231905783378, 72.56290681900518, 76.70969147836009, 76.23142119376891, 74.54769672886019, 78.39536928361463, 77.76491103633758, 79.68717836564588, 79.44317556196644, 81.25432998903337, 77.96925083283456, 82.96718981958206, 79.27541578969648, 79.77962078586702, 24.878901704665154, 0.5137042106399613, 6.278232970545369, 83.1764639577558, 60.12269796863679, 53.75058404860958, 50.237348464227495, 41.516087824298495, 54.479070171233154, 67.9970718199207, 3.493050822327214, 0.20820202876723584, 0.11294277219642555, 0.057218084337129715, 0.023798368150188078, 0.04414766673899947, 0.08214978381030022, 0.06468425850353896, 0.2346821030181262, 0.1530372937239947, 0.21662944026531714, 0.2585184844511171, 0.17472257687439843, 0.17037895027427905, 0.17644077419273316, 0.45954262176829, 0.7191977049073865, 46.34436861161263, 75.65451898882466, 65.72463097110872, 62.6521207440284, 66.61118076693627, 56.25531942613664, 83.58921497098862, 55.612317439048525, 0.18087410968878578, 0.5038722382197457, 56.77732413814914, 98.54469468516689, 76.33214765979399, 84.53768330235636, 71.28961132418725, 77.5286509913783, 73.54307574610557, 75.22956940435594, 70.75889110565186, 74.9497788952243, 77.45204710191297, 77.93398872498544, 74.87199044996693, 113.04493627240582, 66.56824650303011, 76.21721436900478, 71.286418514867, 70.75266238181823, 69.58446287339734, 66.32148235074936, 65.23327173725252, 66.07694610472649, 66.12950586503553, 61.72366042290965, 66.31281391266855, 66.542021536058, 59.50301054985293, 54.48531850691765, 53.38196754455567, 54.078847208330714, 54.550951527011016, 55.73624472464285, 47.49205804640248, 48.55275715551069, 47.07061506086781, 48.00979914203767, 49.266369650440836, 51.00330891147737, 47.60075869098787, 49.989764536580736, 48.04632425308228, 44.62512708479359, 42.463140180034024, 42.15872895333075, 43.95791230663177, 50.66147435096003, 54.83352299659483, 56.449080590278875, 54.113203248670025, 57.2283378724129, 53.94316850170013, 56.926433040249734, 58.850261472886615, 54.26561870882588, 52.89861779059134, 50.845657087141475, 50.818722171168176, 54.576054696113836, 57.0520547897585, 49.96315909970192, 50.59664933912216, 47.05268198443998, 50.216669728679044, 53.8358053853435, 54.60231104204732, 52.57478298679475, 52.63475210435929, 50.57724537387971, 52.501254235544515, 59.083081599204775, 58.615609599697976, 55.46325952776017, 50.756999754136615, 51.34181337971842, 51.513875992067405, 55.10748878602059, 50.62735757520122, 54.0476643654608, 52.782668605927505, 51.01578204862533, 49.98725814204062, 50.3329836937689, 51.979582924996656, 52.684738789835286, 53.594654144779334, 54.09068099914059, 56.64452052885487, 58.63408788557976, 58.55543259651431, 57.06581838669316, 42.95543686036141, 41.20675010065879, 56.35014664742255, 52.90143013000489, 53.07250038270028, 43.53513179286834, 43.33249822739632, 41.58603937395158, 45.953351451504616, 47.951563712089296, 47.08984644182267, 51.15129993807886, 46.769275050009455, 47.99599239903112, 47.851621720098684, 47.53539631443639, 47.833543515974476, 49.74804847471176, 50.721541527778875, 51.12963276524698, 50.21180991203555, 55.50271857169367, 65.69274602397796, 66.63627609129875, 66.69609223642658, 63.56889632440383, 67.34159669568463, 78.88635589230445, 76.1484944435858, 70.82246488140476, 68.07966909100934, 70.09906215052452, 72.44221548880301, 69.7332226845526, 72.71476530259656, 73.16874042634042, 75.88850405908401, 78.58653776107296, 77.48366140550183, 76.80507567621048, 80.01910501910795, 78.11778314651983, 80.51780300755655, 81.68415900199645, 84.63807244454661, 80.8594100706039, 86.66513766011884, 83.12096241981753, 82.60281732005458, 37.6827044640818, 0.7946532592177392, 6.347334346463604, 92.68946678407731, 63.60767679829752, 66.46267198747205, 57.43294831245177, 48.96468054863715, 65.86410260969593, 78.19991757792812, 4.127133094495343, 0.41765419045282953, 0.26070768794705795, 0.23207522838586764, 0.18345646950746738, 0.17202711183457606, 0.19501083740784278, 0.14606468319412202], [0.029450532296792637, 0.08606276940554382, 0.03552529352506803, 0.10760209748461362, 0.17933306254206166, 0.16222377578097005, 0.11561340066574274, 0.18135645396767125, 0.38051700580023956, 16.573245602269328, 58.73062133789063, 35.83236555899344, 22.50365749482186, 42.13398664228378, 51.82361771983486, 69.16050957095239, 56.385753923846835, 0.45645933237767994, 0.09603021681428918, 47.218919877083074, 87.458829264487, 72.93831686819755, 74.60193526360297, 69.62087031333678, 70.2881831507529, 70.6248088036814, 69.99072628636515, 72.30948248217183, 72.69681653668805, 72.24011144330426, 63.87806930849629, 65.14940754059823, 43.112417959397845, 61.57138616808, 69.12143491929578, 66.36746037390925, 64.46516183114821, 57.28835405841951, 61.83017238493889, 59.1569947427319, 61.348717135767785, 61.5752536250699, 65.86876238546064, 62.927733928926536, 64.37134265899658, 60.76195016984017, 51.50566254892657, 48.8736697935289, 49.70416499722389, 47.07228206819104, 46.8939789648979, 45.24643836482879, 46.11609451232418, 41.81411343236124, 41.09892414462182, 43.799640747808645, 44.1777023192375, 41.32104796748008, 42.08618471699376, 40.82083986651513, 41.66745601161834, 37.413245477984034, 36.322218602703465, 40.33203801801128, 49.30026677346999, 49.97148629157774, 48.80085099127985, 48.036302597292014, 49.15899868934385, 48.35241817658948, 46.244324637997536, 44.407976827313824, 44.90017937075707, 45.203198156049176, 47.334959276260875, 48.08449675959926, 51.701804591763405, 55.12056596817509, 50.02630533710603, 44.33161220242901, 44.90681994345881, 44.85601740498697, 44.37915525128765, 45.32247351061913, 45.14444889560823, 46.01905507426108, 45.52696235718266, 44.82040228382234, 54.32868257645638, 54.17815769872358, 45.63261532014417, 44.17799649700042, 44.56953140997118, 45.80855715659357, 44.375009306015514, 43.214631003718225, 44.16531155186315, 42.659815665214296, 41.889591601587114, 44.54107461437103, 45.04223585128785, 50.58803581422376, 49.6829959654039, 46.67846041340982, 49.40133840807023, 45.00016058644941, 47.790346453266764, 51.08235251518988, 45.74659155261132, 50.99418155608639, 50.60402731741629, 48.64503091381442, 51.581497653838134, 50.398977571918124, 42.9464977787387, 35.851557716246575, 36.23829557049659, 37.79926553849251, 42.65934105842344, 43.57319839539067, 43.90373652981174, 42.039967429253366, 43.228410290133574, 41.93569906296269, 44.6459391809279, 41.66841699231056, 45.96415758132935, 46.82361948874689, 44.51543800292477, 45.36226987838746, 50.121391434823316, 60.882563052638886, 63.036685605202955, 60.531879625012806, 60.648981986507295, 60.64355342618881, 55.99248140088974, 59.119249774563706, 63.4740573360074, 70.64198094029581, 70.03863411564981, 65.60238245994815, 65.64331239269626, 64.05108505679716, 66.14122590711041, 67.47918559658912, 68.56384646508002, 69.3697052617227, 70.30114266180223, 72.04271424201228, 74.32128967777376, 71.37311858515586, 72.29576987604942, 73.9891904400241, 76.46484144272344, 75.57997042132963, 77.45914659192486, 79.47240506449054, 11.21446522974199, 0.8946167629572653, 10.256912689055167, 74.6751110015377, 52.24160901961788, 46.768400361461026, 40.34598596634404, 32.64240780184346, 39.1454896619243, 61.8987746392527, 1.8584068528106137, 0.20907276430197302, 0.008838172521322005, 0.08246363471111945, 0.059201110590008967, 0.10901877025683081, 0.020207989840738235, 0.08016799861985831, 0.027530972598000403, 0.09320293102533588, 0.022934569541605252, 0.07096426426282815, 0.14348846740059315, 0.08820844378562705, 0.08669132922565745, 0.18269606595558507, 0.4409203420002615, 20.356832511963386, 69.22314197786393, 38.17181225745909, 33.66285554824337, 53.05484579455469, 54.86172483813379, 78.13740284212174, 63.2764797056875, 0.736352926300418, 0.1556060171776241, 50.975875854492195, 91.29665667010893, 76.81098276568999, 77.71457918228643, 73.70421455752465, 73.1586834692186, 72.96577345940375, 74.32576902451055, 74.30044620267807, 76.27524975807437, 75.1834031074278, 67.89488623219152, 66.98866967231997, 50.25003733173494, 64.24649361641177, 72.40895378974177, 68.2412628973684, 69.11420991343837, 59.58543523665398, 62.21732601042717, 60.849273896986446, 64.0762274496017, 62.355291458868216, 67.3452837236466, 67.23531615349555, 65.98299749435918, 64.41699904780235, 51.18837810331776, 51.796686726231734, 51.346379018598995, 50.408905090824256, 51.125722162185184, 47.643371320539906, 47.974835134321644, 44.56137288001276, 44.90674541842553, 46.517894268035896, 44.76048415707004, 43.67104191933909, 43.89538580371488, 42.79687504614554, 43.86036296044627, 40.1080196903598, 40.13890051072644, 44.27050951988467, 51.4823519029925, 50.249523501242365, 51.31587082339872, 51.010443702820815, 52.33123125568513, 50.61923042420418, 48.26831079298451, 45.01306518431633, 46.03337172539004, 46.527041235277736, 49.82606441743913, 51.220623908504365, 53.45839884973342, 57.22119131395894, 50.67471235029159, 47.3342885509614, 45.24382606629403, 46.856277142801595, 46.64823462886196, 48.26335683945687, 49.43587879980765, 49.833007012644124, 49.642246461683705, 47.83543802076771, 53.39801396093061, 57.21163249784901, 47.47963982243692, 47.86564419346471, 45.804972110256074, 48.203544616699226, 47.86331822795253, 44.918842008036954, 45.05086114329677, 44.695933711144235, 45.05436381986065, 47.49012824027769, 47.598958323078776, 54.40318407550935, 51.922288863889634, 48.6769707741276, 48.93668659271733, 47.074761006139944, 47.662567400163226, 52.58505567427605, 48.4603500366211, 53.12937082782869, 53.13101037856072, 49.65291138618223, 52.93025562840124, 52.23068914105816, 46.09889491911858, 40.50132359227827, 38.75507654682283, 40.72445546427081, 47.14686201464745, 45.412393846819484, 47.216350724620206, 45.33647244976413, 46.41131562571372, 44.68947356747043, 46.71878237878123, 44.94136817993657, 48.45323877949869, 49.18036383967246, 48.04524560128489, 49.05781330600862, 51.925387536325765, 64.16287260670816, 64.49366177282026, 64.70335168223228, 62.88203047167871, 63.94947213511314, 59.2208940752091, 60.19556776169808, 66.1153539534538, 74.08669271776753, 72.79341666929184, 69.79121884992047, 69.64005854821974, 67.23078189357635, 68.9124196575534, 71.37135351857832, 72.14181684678601, 73.74125742143201, 73.89487312686059, 73.1928002449774, 77.35655307769775, 73.50820587527367, 75.90887684975901, 77.13795938799458, 78.31565887697282, 79.84108432646721, 80.82377141521823, 82.32181087616952, 12.505275087971842, 1.0304496677652484, 12.677861336738834, 84.71220524080339, 60.04190498782743, 53.60548773119527, 49.27247678079913, 37.614349319088845, 44.67288978638188, 75.13986479851508, 2.123077237798322, 0.1705983425340345, 0.10353858327312816, 0.06443116603599441, 0.027459674710107428, 0.038797442741211385, 0.03507493724746089, 0.07126080923743787, 0.09223115615426533, 0.14250022930002984, 0.1087244469372015, 0.2956540756408246, 0.28465559646006555, 0.2617888218693195, 0.2819649118088907, 0.3783035019953405, 0.5570902519168393, 27.487240606738677, 82.9674094723117, 48.00705348291705, 29.295733705643688, 57.862726334602606, 69.32384490966797, 81.67967965525966, 68.83146193719679, 0.7563415085596423, 0.29666353437689047, 53.02853061306862, 94.69641808540591, 79.47228739338537, 83.39451636037519, 75.74241145964592, 78.36153491850823, 76.2189402118806, 74.81328825796805, 75.02893232530164, 78.17777972067557, 76.63023210340931, 70.24660602692636, 67.05567944434382, 58.12638021284535, 66.08309638115668, 74.94499360361408, 70.44889050145304, 71.74642624393587, 61.23441534657633, 65.10424144806402, 63.108351230621345, 64.79621379606186, 65.84915053459906, 71.57577960721909, 69.33778501326039, 69.4089368081862, 68.12687873840332, 56.677727314733694, 53.67214056753344, 53.27087033179499, 51.43093355240361, 51.941022103832616, 50.09038509861116, 51.38414359861805, 46.958427429199226, 47.337995190774244, 48.62825493658743, 49.3858136669282, 47.197954808512044, 48.5538750310098, 47.76534526578842, 47.158413394804924, 45.00825635848507, 42.05888894296462, 47.611902144647416, 56.11675385505923, 56.3058630881771, 53.18021259000225, 52.8336751076483, 55.9275387179467, 53.83357355671545, 50.815921598865145, 47.03319564942391, 48.0549926911631, 50.68432607958394, 51.543081960370465, 54.699550520989206, 56.45329713821412, 59.95507547932287, 53.12077299241097, 50.556131255242136, 49.77118653635825, 50.10061071765039, 49.6246938551626, 53.09718385819466, 53.50355317515712, 52.466027429026944, 50.94951360456405, 52.28621421321746, 58.01243143696939, 59.6791563495513, 50.54785505417855, 50.54986723007695, 51.187444579216745, 53.228999030205514, 49.62668641921013, 47.16333989174136, 47.48938298994496, 47.800505392013065, 46.62951315602949, 51.81974241810461, 49.87576476989254, 57.584430248506614, 55.5115556716919, 52.4578296753668, 53.57393226315899, 49.10227337191182, 53.97313540981662, 54.072175256667606, 51.46937278009231, 55.73202817670761, 56.239065124142556, 54.13380353681503, 56.22420718592983, 56.27207579151277, 48.30116456554782, 43.85507560545399, 41.522453831088164, 43.38785856000839, 48.94298591921407, 49.265926422611365, 49.19208780411751, 47.95609797200849, 50.180140695264264, 46.848483393269206, 49.70451016579905, 47.68108490974673, 52.698376870924434, 53.3448423108747, 49.61106754118397, 50.460456801999, 54.60141674164803, 66.78542813947125, 67.0533024880194, 67.76937823141775, 66.94247984117078, 66.32320819362518, 63.45490048008581, 64.6763147846345, 66.85348126196092, 75.16178300303798, 75.64737243037071, 71.41482906956827, 72.30839206326392, 68.5743348829208, 72.24631663291686, 74.12718726742652, 75.29567703124016, 77.01282009001702, 75.86172996028778, 79.24479776813139, 80.66989683335828, 78.09683768979966, 79.5574498945667, 81.85595097080355, 79.19345394257577, 84.63825287357454, 83.0951218451223, 86.10078703972601, 15.987249382080572, 1.0653045845608557, 13.835465542731749, 95.5602652026761, 64.90400837313744, 69.99232661339545, 55.69111001107001, 48.346295356750495, 55.15645565525178, 84.60356343177058, 3.0725519022633954, 0.4148580001727228, 0.21813569169852043, 0.30740647726962644, 0.1910217409773219, 0.12392763799477009, 0.09718466535090439, 0.1911846725570579], [0.0653840491788522, 0.09219763214669882, 0.04350718659078402, 0.04294692350911998, 0.02788255332909044, 0.11007020295026804, 0.0768584528216912, 0.20805837195967475, 0.5851166899646483, 16.626989918370402, 56.437525287751235, 40.06795660141976, 36.66339028266169, 36.374970559150945, 47.57438075157904, 54.03535596786007, 76.0922476553148, 2.3967598811272652, 0.23038860921177173, 36.893947201390425, 89.52431801826724, 72.54363229197841, 77.07888064845916, 67.47882473853328, 71.67175216059532, 68.24787601347893, 73.76526232688659, 71.68720629907423, 74.12219801256734, 66.77511230591806, 62.89529200523131, 63.768811687346435, 55.59355282014417, 70.49933218186902, 69.3334468718498, 64.62739498384538, 58.809343307249016, 60.72178117690548, 61.320778093030384, 64.17661659179196, 66.06356297769855, 65.15614617255427, 65.86937427520752, 65.36265503975653, 60.65722288623933, 61.02457638709777, 54.33479755155502, 48.19044782269386, 48.49878926430979, 47.714221092962454, 48.289907363153276, 47.00071057965679, 45.99482659370669, 41.579434102581395, 43.709928297227435, 44.264402389526374, 42.58720867095455, 42.73131655108544, 44.51261781877087, 42.6818044724003, 42.39641281866258, 40.41591790414626, 39.11083552145189, 42.705068049892304, 45.14407627044186, 46.49983567576255, 46.328726199365434, 46.10272707477693, 44.18023224799864, 41.56714531683153, 43.308979695843114, 40.47859737949987, 42.2922307445157, 46.19368683907294, 43.469855708460656, 49.65382922080256, 51.782264171108125, 49.84420930185626, 50.98866278125394, 48.46929304061398, 45.84447430026147, 45.47567736717963, 46.09737303949172, 43.0548297205279, 43.93776701342675, 43.5704174349385, 44.49522995179699, 43.702820962475194, 47.92352661009758, 52.41095735180763, 44.34196333731375, 44.39125968563942, 45.76031984821443, 44.380837948091575, 42.79223095986151, 43.844551886281664, 44.03917597186181, 45.09800411039784, 43.30135853059831, 43.75345091665945, 49.52831337528844, 49.81703512130245, 48.43293266911661, 42.858350353856245, 44.81008252789898, 43.89224398520685, 43.013687979790475, 41.64196452786846, 45.89963851436492, 45.99219076095089, 47.76461570493637, 48.800596037218654, 47.83139797949022, 47.89853718972976, 45.81599789281046, 38.60066460024926, 36.643801966021144, 39.94102478027344, 43.610931596448346, 44.30932921748008, 44.91517066955567, 41.61415492334674, 42.57521798533779, 41.43121950088009, 41.6970306827176, 42.08364302112211, 45.51719173308342, 46.62327658745551, 46.21220042628627, 44.57492074658794, 50.08997717211324, 57.67249530361545, 61.40349303522418, 61.08076826218636, 62.41083614287838, 64.2838228133417, 62.184942922284534, 59.57808471495106, 54.751965153601866, 57.8270798344766, 65.95015941127654, 69.63365724009853, 66.1477291968561, 65.39537152936383, 66.15428739978422, 65.99273281712686, 70.07689291431059, 66.5314389813331, 70.62236908943423, 71.18801409198393, 71.35744479394728, 70.63001771127024, 72.97129615660637, 71.38071229380947, 73.95067276493197, 72.94230199629261, 75.57253360748291, 81.38804358820762, 7.911078901060167, 0.9576462485617208, 12.723725611163726, 75.9332347685291, 56.25347591215565, 49.805585722769464, 32.9118707103114, 41.14460014527844, 49.62071657180787, 65.52397035783338, 2.2129522215935493, 0.31379022665562173, 0.04902752424259821, 0.14772231360116314, 0.11588808915187275, 0.061722547266512155, 0.012650182940095905, 0.04707876893301164, 0.033240191142765746, 0.09209168218677083, 0.028525260877945734, 0.13938035155015607, 0.023123618973899755, 0.06612828061465295, 0.07985853740284521, 0.20229331518132843, 0.399619561409758, 19.173006280775994, 67.75662268361738, 41.710362818933305, 41.68042336740802, 45.144703849669426, 49.806938940478915, 63.97097456839777, 78.095912010439, 3.737152665853501, 0.25756378567987875, 38.06761449383151, 95.82027127665859, 74.5332859408471, 79.85178455229729, 70.76502569260137, 74.90362828777683, 71.89016542127057, 76.44064041876024, 74.54892050835394, 76.32462455380347, 69.57280558924522, 66.20028111242479, 64.25644074716877, 58.944700379525464, 72.20801076581402, 70.83484388166859, 66.01863614974484, 62.68938326066541, 62.43152272316718, 65.56078572427073, 66.34369865540536, 68.32986139482068, 65.99132860860517, 65.70953376831548, 67.59684101227792, 63.46649892868535, 66.17947686103084, 57.842953666563965, 50.822291528024984, 51.85508297335718, 50.46350056125272, 51.12070545073479, 51.711253581508515, 48.71489224895355, 44.748615064928615, 47.31293516774332, 48.33936060628584, 45.84920860105946, 44.181232452392585, 44.96987204397879, 46.10937941458918, 44.689104864674235, 42.00234013219034, 43.34409275362569, 46.29659022054365, 47.69047506393925, 50.56266984631939, 49.60912989031885, 47.565425980475645, 48.14978461111746, 42.534931321297925, 44.74538303190663, 44.25430620870283, 46.2849368587617, 47.7378337613998, 46.36858532505651, 53.462419279160045, 54.09500737344065, 53.079505735828036, 52.8363109404041, 50.12268189461001, 48.447578799340036, 46.97956900442801, 48.999291543037664, 46.437336629436864, 46.407989455807595, 46.64924660036641, 47.60515174558086, 46.93685047088131, 52.155438469302275, 57.629941509615996, 47.60404563719227, 47.81036230825609, 50.11033035093739, 48.178449292336744, 45.47567736717963, 46.55962044192899, 45.950484198908654, 46.08131093363608, 45.719338924654075, 46.06067142178936, 51.03456235701039, 52.571319533932595, 50.06530938609954, 46.98546824916717, 45.29511497866723, 46.50920229573404, 44.68420974669918, 43.735051078181115, 47.831633321700565, 47.71243641453405, 49.831367461912095, 51.05186785421064, 48.839890341604914, 50.86250366703157, 48.978659875931285, 42.289987148777136, 40.20148192682574, 42.87240812855382, 45.335731121801565, 47.60335922241212, 46.9556817700786, 44.9619213996395, 44.72748525681035, 45.64065225662724, 45.586574539061516, 46.69531091567009, 49.125533027033654, 49.93399627747075, 49.158751580023, 48.60364598612632, 52.252230798044515, 59.29607806667205, 65.24124983818301, 64.11544330658452, 64.99916899588801, 67.99225514934909, 65.58726172293386, 63.905110128464244, 57.58800745010377, 61.66439340960596, 68.60762796094342, 72.10772360524824, 69.54334074451079, 70.27725542745283, 67.72638905432918, 68.96593647618448, 71.073975101594, 70.4202179754934, 73.50959439431468, 75.94873597545009, 74.14875245863392, 77.27026093390681, 75.55781687459638, 75.2533781913019, 76.53268275722381, 77.157226070281, 78.26792363197573, 84.22211293251284, 8.60746483648977, 1.0326161644151135, 15.197828258237532, 86.51573458025533, 62.12116910565285, 60.808720511774865, 39.205203825427645, 41.564313365567116, 60.92361457886235, 74.54282514510616, 2.792350279708063, 0.3212948852489072, 0.10310294737498607, 0.06022594471071517, 0.034157037509665374, 0.10178542936280852, 0.03417356968707135, 0.03181812702678144, 0.21016258566129595, 0.1845276289649548, 0.1662061919247912, 0.19313353894939347, 0.09844310266236145, 0.3262758663585109, 0.16558775978703655, 0.3277224242206543, 0.8790184773745076, 24.9054188882151, 78.53727279170867, 54.689226842695675, 49.39537248303814, 49.7060045888347, 63.93309231727355, 65.57301567446801, 86.59119313763034, 3.4475228911445988, 0.2378826191829097, 42.17717978262132, 99.26095870233353, 79.48295624025407, 84.11859373892509, 72.09991808860534, 77.95177275134672, 73.34579621591877, 79.62372226099815, 76.61389935401179, 79.06445503234863, 74.59398069689351, 69.4298351964643, 64.35017754954677, 63.489319278347885, 74.75275039672852, 75.8148027235462, 67.9393502204649, 66.51401581302767, 65.32339995907199, 68.00093143217026, 67.60162630388814, 71.20423701501662, 67.73996829986572, 70.15609341282999, 68.0797004699707, 65.14213938866892, 66.75051120019728, 59.930948980392955, 51.81522777003627, 54.63822818571522, 52.80843857795962, 53.284582937917406, 54.201770367160925, 53.747085294415875, 47.61802888685658, 50.81912225292575, 51.83242736324188, 47.226105659238755, 47.56289212934433, 49.133589575367594, 49.33678403977425, 48.68907128610919, 44.80747807410456, 46.60913644298431, 48.69667283950314, 51.894243917157574, 51.715870211201334, 52.998548015471435, 50.36076191932925, 51.04048121360041, 47.124018130763886, 49.6258548767336, 45.82614506444624, 48.163595276494185, 51.36681848956693, 48.857266441468276, 54.87822232707855, 58.07164353709067, 55.278107966146166, 56.1607510812821, 53.566216961030044, 50.284628714284594, 51.0805364578001, 54.350228155812914, 50.16589856916859, 50.39846374142555, 51.00428558165028, 52.532719489066835, 51.68640536646689, 54.15138359992735, 59.99644079516011, 50.71228473417221, 52.09513987264326, 55.896940308232466, 51.24717835457095, 49.5444853075089, 50.731382754541215, 50.65026813937772, 50.531600752184474, 49.74761701399281, 49.220913302513864, 52.93220504637688, 54.79729598568332, 53.6631779516897, 49.37542330834174, 49.00392386221117, 48.51773823461225, 49.3210788696043, 48.26889522614018, 52.403449935297814, 49.43437260966147, 53.7964875467362, 55.27780202127273, 52.511071928085826, 53.462901730691236, 50.734108801810976, 43.760452347417036, 43.32066835895662, 45.218032560040875, 48.15182424360707, 48.88298934505832, 50.825354899129565, 48.034627745228434, 49.51884869606265, 47.62615603785361, 47.88000006829539, 48.829119513111735, 53.005702418665734, 52.71049307238672, 51.41251410207441, 52.581376491054414, 55.071912888557684, 61.861202255372085, 66.19396609644737, 66.50886966336158, 67.28475370714742, 69.85014853938934, 66.99028568883097, 66.10677965225713, 58.80386767848846, 64.5617070505696, 71.15414834791615, 74.22452480562272, 69.4507178952617, 73.67531453409504, 69.64241981506348, 71.26137025894658, 74.37300220612558, 71.68207583888885, 77.47125887101697, 78.96781567604312, 78.38600266364314, 81.9126449092742, 78.98420333862305, 80.73143882136192, 80.65976142883301, 81.27698559914866, 81.90601610368299, 90.45235080103721, 10.901847424045688, 1.2738354335869513, 17.294671458582727, 97.19107689396029, 71.15417972687753, 72.14989692934098, 46.91355159205776, 58.555311003038966, 68.780227938006, 85.5432221197313, 3.903076278586542, 0.45866443985892885, 0.2384357499859987, 0.2724246656702411, 0.3062303178012371, 0.21638366393744948, 0.14147742531232296, 0.13094252125630457], [0.050702303527824344, 0.04734214996137927, 0.03890134724638155, 0.07945729119162406, 0.08029054970510545, 0.03657750762818802, 0.07503397612562103, 0.2108197665262607, 0.280878599132261, 11.629742249365776, 65.53670237141272, 38.087045915665165, 34.66716666375437, 33.24229509599748, 53.09014320373536, 56.54141710650537, 80.9146527321108, 7.938398209310348, 0.8380377989622855, 21.9934767676938, 88.10110169072306, 73.33452332404353, 74.24477208045222, 66.8654994041689, 68.54973377720003, 69.30248368170955, 72.87126002773162, 71.20131092686808, 67.86530371635192, 57.83063742422289, 64.86095643812611, 61.66540538111041, 59.57807294784054, 68.42305691011491, 64.32598044795375, 61.38403807916949, 61.78611632316344, 61.63346159842707, 63.762724168839, 64.27316181121334, 63.06061598562426, 62.95426091840191, 62.51557911595991, 62.467949774957475, 67.62392890068793, 61.429851362782145, 57.60197893265755, 48.222807376615464, 48.44590786964663, 47.13116861158802, 46.9481155180162, 46.864333691135535, 45.94469870290449, 42.13637144334855, 43.825920627963164, 42.726441044961255, 44.00829907386534, 41.43394947052002, 42.40258270694364, 42.09446484042753, 42.29597660803026, 42.891443391000074, 45.82325035525907, 47.881431733408284, 46.31257780136601, 45.41610048663232, 44.915256961699455, 40.76768782831008, 42.01538593538346, 42.870760733081454, 43.159557004128736, 42.19813308408184, 43.51357052403112, 44.01785004523493, 45.94040370756581, 46.00413830049577, 47.4443502579966, 50.33998904689666, 49.65895575861777, 46.46629548841908, 44.93121316356044, 43.50210151364727, 41.89721276683193, 41.42553598650041, 42.73706282338789, 40.85907513095487, 44.65708263458745, 44.506008625030525, 47.5558397077745, 49.73827785061252, 43.76662615806826, 44.27163524012412, 41.78145577830654, 43.567165790065644, 42.867764042269805, 42.30466465796194, 41.80924577097739, 42.765201907004084, 46.457427009459465, 48.71831647811398, 49.44355487823487, 49.46962687277025, 47.90791557681176, 43.44349738090269, 43.98729085922242, 40.616711878007465, 39.386676203820016, 39.168066824636156, 39.11279278416788, 43.96081878292946, 44.690783639107984, 45.541082889803, 48.02589654922486, 46.69447937319356, 44.96674591495145, 43.947168934729795, 41.729029378583355, 42.49053009094731, 44.15978100992019, 42.65644242686611, 42.137595222842315, 42.64770730849236, 41.52952194213867, 40.97412609284924, 41.748535325450284, 43.69467812199747, 45.225696871357584, 46.03083002951838, 46.05669413843463, 45.071857590829175, 47.97748273418796, 54.376292305607954, 59.676987278846006, 59.12239943781207, 58.871050034799886, 63.05715645513227, 62.700267837893584, 64.56282100369855, 65.45243417063068, 59.45484384413689, 58.64856535388578, 63.68810892105103, 67.81954534592168, 67.02277075859809, 67.433042833882, 66.9461747138731, 67.57061604530581, 67.57078078485304, 67.54373212014475, 71.50761665836458, 72.61859663071172, 68.19366101295718, 69.65533225767075, 71.14526025710568, 71.05769726537889, 75.04866969200873, 75.23682578917473, 78.76266787129065, 9.453905455527767, 1.3119793803461137, 15.332977444894853, 76.86915151534542, 60.98612931466872, 50.52920418400919, 34.88434830019551, 39.28087026842179, 47.35907793045045, 64.39436697190808, 1.5879955887794497, 0.2025682334938357, 0.06766642428814404, 0.042844696736504, 0.07261218833586863, 0.019618349202397852, 0.045155926547463865, 0.08179980420297192, 0.033679864324268796, 0.06113134955446567, 0.06346910132936413, 0.05571003259730436, 0.01566751982130471, 0.1407710462808609, 0.07787171901474077, 0.18595183238146767, 0.3464511289231239, 15.190145315662509, 78.42583825511318, 40.95848368060204, 32.59833997295749, 40.73237080727854, 58.24427097074447, 61.63030016806818, 87.78045577387657, 9.941359969877428, 0.922316786262297, 23.374143223608694, 91.92644811445668, 77.90578688344648, 79.15550108878844, 70.22472704610517, 74.06069524826543, 71.25294500781645, 76.94025624182918, 73.62470026939147, 69.96600750953921, 61.99402547651722, 67.09009432023572, 62.114057848530436, 65.0283984984121, 70.76521396636963, 67.77938027535716, 64.45386148268177, 62.476775107845185, 62.65547437052574, 66.90945348431988, 65.63011361706641, 66.93862022892122, 64.53630970370385, 64.99729018057546, 65.34563587557885, 69.89437718545237, 63.463576762906975, 60.8706743486466, 50.865931818562174, 50.48214750905191, 51.69621913663803, 50.314897644904356, 48.621653587587424, 50.403739329307314, 47.04215042052731, 46.81024812882947, 45.61473715689875, 46.72325388077767, 43.93264832035188, 45.389110657476614, 44.87105184985746, 44.50963289506974, 44.79615419141708, 49.003284515873084, 48.46254264154742, 48.311586303095666, 48.71515504775509, 47.15433412982572, 43.31934652020855, 43.06876982412031, 43.43424843203637, 45.24991750717164, 43.5893742499813, 45.846580613044004, 46.481349545140425, 47.51952248234903, 49.6044465803331, 52.03447649555822, 51.2185646641639, 52.29782835129769, 48.74680073030534, 47.04496668231103, 44.77465175813244, 44.73584382764755, 44.71392562312465, 45.11203442850421, 46.47639951398296, 46.07559604029502, 47.577652008302756, 49.947697116482644, 52.142635853059836, 46.61728320583221, 46.77960265067316, 47.40364782271847, 45.768027305603034, 44.28017031761908, 45.53024538101689, 44.189077192737216, 46.083782026844645, 47.590505615357436, 49.7945011046625, 50.79710598914854, 53.619255250500096, 52.716710029109834, 45.61621589045371, 45.678334466872684, 43.84743482835832, 41.20875443181684, 41.59078544186008, 41.11615903915898, 45.61615705490113, 47.17904898428148, 47.71545663956673, 49.90350769412134, 50.93458114131805, 48.618692198107325, 47.674338433050345, 45.18096223954232, 45.02640516527238, 45.83285623981107, 44.04551844443045, 44.766889387561434, 43.65530144783759, 43.29675366801601, 45.63642786395165, 44.731482152015936, 47.73610007378363, 48.210573504048014, 48.19057726090955, 47.13721690639373, 48.99300006128127, 50.23729747341525, 57.161312410908366, 61.61069223957678, 62.62993974070396, 63.32168502192344, 65.96460942299136, 65.35291971698885, 65.60377882372948, 67.10871773381388, 63.05787817124398, 58.88553927021643, 64.64040156333678, 70.58159212912284, 69.9719459779801, 70.04323897823211, 69.7183882805609, 70.00849462324574, 71.38370113988077, 71.3992964836859, 73.11095606896185, 73.7954802666941, 71.71092094913607, 72.54904516281621, 74.41302607136389, 75.30773439714986, 80.5042080725393, 78.84545341614755, 82.65089773362683, 10.817708661479335, 1.3793230441308792, 19.216058215787335, 83.8428746500323, 66.91702365875244, 63.8873770929152, 41.54934952335973, 43.29856972540579, 50.92714040510116, 73.96644853776502, 1.7675905001740304, 0.2467468999806912, 0.02565659676498223, 0.05641209089287347, 0.0371813764345021, 0.019036323478024815, 0.04674230311666766, 0.005834080821519057, 0.12449527850314496, 0.1792753148343294, 0.18474460038686955, 0.13392643372137703, 0.2240963307239356, 0.2039283000293278, 0.12134965253813614, 0.29807387160197385, 0.5666331946849823, 18.86341360307509, 88.83878969377088, 51.40955271259431, 47.20856481982816, 48.74700861592447, 71.666441271382, 66.02634752950361, 94.39943190543883, 10.816928109815045, 1.07505927403127, 29.819525057269683, 94.99487907655778, 77.55784911494102, 82.72265357355919, 70.05359403548702, 77.81612150130734, 73.38896582203527, 79.74204447961624, 73.20801119650565, 72.12906914372599, 66.36725641066029, 69.72297745366251, 62.9546021646069, 67.65373106925719, 72.55856083285424, 71.39844925172868, 65.74824363954606, 65.99745535081433, 64.56257781674786, 68.44505356204125, 70.08618893161898, 70.81093311309814, 68.92032715582079, 66.95565900494977, 65.81615555670955, 72.30225747631442, 65.48099687022548, 63.57475634544127, 53.229352043521025, 54.042118134037146, 53.74135471159413, 53.236161278140166, 51.41735038449688, 54.0844169739754, 49.241913672416445, 49.842150057515795, 48.54872495897355, 50.41700870760026, 45.38996181180401, 48.700540296493045, 47.341007571066584, 48.19114208221436, 47.4187607149924, 50.14566306144961, 52.05092691606092, 52.38051191453011, 52.06906787810787, 51.19703869665823, 45.1280455435476, 46.38161543876895, 48.10815649647867, 48.14612896211686, 46.12677904867357, 50.0758566394929, 49.597205884995006, 49.575122940924864, 52.391682824780865, 54.750525643748624, 54.31526022572672, 55.89552825497043, 52.13271617889405, 50.722318157073, 46.90607555450932, 48.26540823905699, 48.20865154266358, 49.917620382001324, 49.786279816781324, 53.89879080557055, 51.4598100416122, 53.14424837789228, 56.35956818057645, 50.774972054266165, 52.171971259578584, 53.51373564812445, 51.127491151132894, 47.3680954594766, 49.653405604823945, 45.754926589227495, 48.360580628918065, 51.587377286726436, 53.99703833364672, 53.48414136517433, 55.527025499651515, 56.357497169125466, 49.37776104096444, 50.306342955558534, 47.55912665397891, 43.76563379841466, 41.817172881095644, 45.81312279547415, 50.31683137339931, 50.65838352326424, 50.08068507717502, 52.61063345016972, 50.85255653627458, 49.31497958398635, 49.94286867880052, 48.38982189855268, 48.95085811614991, 48.405825168855735, 47.438592218583636, 48.01114059263661, 46.31737093771658, 46.605488638724054, 47.680006257949344, 46.78408591978012, 49.66976973318285, 51.43829976358722, 51.94625454564249, 50.46947825339533, 50.5049600139741, 53.164279922362304, 60.55949703339608, 65.05117962437292, 65.85396720517066, 64.88456518419328, 69.8293992011778, 68.13639440844136, 69.74832380971601, 69.54203851761358, 66.60094338078653, 62.488181360306285, 68.84967742427703, 73.82102274125623, 70.81856604545348, 71.07410061743953, 72.92949938005017, 74.62590094535582, 73.90814642752372, 73.30137929608746, 77.80473093832694, 77.83771022673577, 75.99885602151194, 75.90786487825456, 79.70721383248606, 77.42882667049285, 83.20153574789725, 81.88186214816186, 84.85337134330504, 12.608633464382542, 1.6213880743711226, 21.25197033728323, 96.4492468680105, 75.34622853802097, 73.27039257172616, 51.80250752356745, 57.98229194456532, 62.55932138812158, 87.8263004364506, 2.700680321262729, 0.2992902353646294, 0.1562909457472063, 0.13758025943271576, 0.17747240351332774, 0.09113545890056318, 0.2800955346995785, 0.1445424971320937], [0.016347473607428612, 0.07020041331528656, 0.048733614610448006, 0.061469539068639285, 0.019734198933527358, 0.042373361141090436, 0.16609319395595984, 0.22798991131205715, 0.46325395003922526, 11.634509890310227, 66.5188403283396, 49.594770093117994, 50.807084498866914, 34.52538082676549, 49.25959179478307, 47.849621311310806, 84.69013798621394, 20.837540549616662, 0.8515050730878307, 6.916837490374043, 80.85209092786236, 74.56477472859045, 74.73579006810343, 68.50729373193556, 68.64850690287929, 69.54483908991661, 70.42355199013987, 72.9754852479504, 62.602016387447236, 56.56668109278525, 63.82471722941246, 64.2469839126833, 67.64243464316091, 67.46964639233005, 61.30386875521753, 59.663972854614265, 62.25563579990018, 64.97682325301632, 65.29974022219258, 67.63870839149722, 65.55486686768072, 67.0496311495381, 63.11729423461422, 62.692368184366536, 63.58996729696951, 61.68975545514015, 53.665499994831706, 47.6525261325221, 48.499640418637185, 47.84300427283011, 50.30766871667678, 46.98589970988613, 45.110457635694935, 45.114380005867254, 42.22973954293036, 45.14645322676628, 44.52682072116483, 41.597351489528535, 42.10510230833485, 43.398754904347086, 43.77830697644142, 44.48028964381064, 45.076972361533876, 47.378301466664965, 46.10589242750599, 42.59209986655943, 40.403291794561575, 42.45627603223247, 42.034464343901604, 42.576826157108435, 41.10183846565985, 42.93856674625028, 41.92206490424372, 42.75089310061547, 42.50969086923907, 45.45009174654561, 46.51460339946132, 44.20610812402541, 45.94143529092112, 46.84952282136487, 43.26735158120432, 42.520296958185014, 43.67228531068371, 41.59311925211261, 44.62693137507285, 43.736302314266084, 43.70580588617633, 43.94075585949806, 45.735546158206084, 48.3302842417071, 44.56513051063784, 44.26582620989892, 42.79036783402966, 42.79296836545391, 43.47517444241432, 44.18597067556074, 41.17178609294277, 42.80386078742243, 43.67232453438544, 46.034132665203465, 45.6846220262589, 45.676000656620154, 47.046665068595644, 46.00030614483742, 43.36535592232981, 42.18829577968967, 40.803922683961936, 40.068031126453036, 40.834324975167554, 41.04727045182259, 40.6651060811935, 43.16487966045257, 44.11574455999559, 44.814667778630415, 45.47007230020339, 49.99886835775068, 44.92268593080583, 42.97542133638936, 43.83902918907904, 40.588062886268865, 39.17009076764507, 41.22742491383707, 42.5665024788149, 42.705068049892304, 43.65550933345672, 44.244417913498424, 46.405208495355424, 46.796680650403424, 45.449064085560465, 44.32454016900832, 46.84720470059303, 52.4793948665742, 56.12666568448467, 58.386747144883685, 59.50709765957248, 60.509651553246286, 62.234772712953635, 64.25046697739633, 64.66331212751328, 63.866604220482614, 63.10714314060827, 58.7084089556048, 62.58214566015429, 67.6906954857611, 68.68584786691974, 68.30478175993889, 71.66580584741408, 68.82837110950102, 68.5998930469636, 67.97692652671569, 67.07905677057082, 67.81098673420568, 68.13731224306169, 70.12631477848177, 69.94287337026289, 73.94751133457308, 74.8119624968498, 80.27760490294426, 10.365097541962902, 1.0247025374443302, 18.419840605028217, 76.13209109152518, 56.35993296100248, 44.24148398060953, 31.623554498918597, 43.38555612871724, 61.83237283460556, 60.51178532262003, 1.3492709470372046, 0.36580453236256877, 0.061017171810230905, 0.03123818889200207, 0.04684970481321216, 0.11069496297427725, 0.0550950363638901, 0.06347057604861837, 0.05741667347930132, 0.025639323397509517, 0.028264406024508422, 0.13478264422906985, 0.005717497561202055, 0.1049151206989923, 0.04542842402213043, 0.1800913976565484, 0.38586046907209587, 13.01638541683074, 75.6930523533975, 48.435282168849824, 34.31255302121563, 38.9534661077684, 56.84811115264893, 54.32803930774812, 91.9926812571864, 24.715633046242502, 0.7510729073997467, 6.56872566669218, 85.66057159054665, 80.4604422661566, 77.16248204631191, 70.25692186047955, 72.39192285845357, 72.77911570764357, 72.99402236938477, 75.10339460065289, 65.58258233531829, 60.60373744656963, 65.32250565867271, 63.252459110752234, 70.44892972515476, 70.1317511835406, 65.36136850234001, 63.48745615251603, 64.08959880951913, 68.05193793389105, 68.80799047408566, 68.90229209776848, 69.65674431093278, 68.40352350665678, 66.19155776116156, 64.14372359552692, 63.03665814861175, 62.31515384489491, 57.12588164114184, 49.024073077786355, 50.27743508738857, 48.795677385022564, 50.31709809457102, 48.4963377829521, 47.71848470933976, 46.55370158533896, 47.370229228850334, 48.41157536352835, 47.82428279999764, 44.58480511942218, 44.588233270952784, 46.04002014283211, 45.716808995892926, 46.583111516890995, 49.052722069524954, 51.584961106700284, 50.01445193444529, 44.47002087869952, 44.20963041244015, 44.60111825696884, 44.75398478969451, 42.921535814962084, 44.43076972038516, 44.132226359459665, 44.65414870169855, 44.353808895234145, 44.292517938921534, 49.24816593047112, 50.25036681082941, 46.00731149796517, 48.426115589757124, 47.23327575191375, 46.22707797634987, 45.953637784527196, 46.80365854693998, 45.05228888603949, 48.434568297478464, 45.32119089557279, 47.87146499080043, 47.720602789232814, 49.87267786456693, 50.89312561096684, 48.56670902621362, 47.65621316048407, 46.940208019748816, 45.29630345682944, 45.559098336004446, 45.46175295306791, 43.62450691961473, 45.42282342910767, 46.45751330160326, 47.40220046812489, 48.50888544513334, 49.229448380008826, 48.35774867765365, 48.73794401845625, 43.82821129214379, 45.0375093952302, 43.05599858683925, 43.81341611185382, 44.16990856970511, 43.38815666014149, 42.449376583099365, 46.517929569367446, 47.634793096973056, 46.921796414159964, 46.782858217916186, 51.82731651490735, 47.102923623977176, 45.68139391560709, 45.86403516031081, 43.35330640116046, 42.109695403806626, 43.50363123801447, 45.49916844214163, 46.56162085071687, 47.21678218533916, 48.01971097146311, 48.58104921156361, 48.38718998816706, 48.62550927746681, 48.25117395770166, 49.14359946404734, 53.157294181085405, 59.67850131373252, 60.451816205055486, 62.79779364985805, 62.029087543487556, 65.5233153220146, 66.32291793823242, 67.13804137322211, 67.31874496706071, 65.3545828019419, 60.485834921559984, 63.948875934846946, 69.56462352506577, 71.48693007807579, 73.15849519545033, 73.49321457647508, 70.55046419943534, 71.85243222021288, 73.56839856793805, 69.21402638958347, 72.2085520528978, 72.00039971259334, 73.70863114633869, 75.02945792290473, 77.3326893775694, 76.82586423812374, 84.97934218375914, 14.254742399338754, 1.3185819550868005, 21.020940772948727, 84.28978950746598, 65.59580856753935, 55.895426273345954, 41.23547753980083, 50.131216972104966, 69.85434547547372, 71.14467974632018, 1.3721408166231648, 0.23050560615956786, 0.04849084134724352, 0.0720034778538731, 0.05771236043543585, 0.07472813084361053, 0.0734948595204661, 0.042997439346847036, 0.124627512939755, 0.2135998229946821, 0.06940562007648331, 0.18792221052271707, 0.1385628591261564, 0.20476407131120083, 0.21359000174749285, 0.316909522178673, 0.7609170759397169, 17.55303994301827, 89.24972857198408, 61.17727425790603, 66.65516622604864, 48.07416131419521, 66.36208672677317, 60.28633925222582, 97.07970511528754, 27.067392064679055, 1.1325553372021646, 10.074733303439233, 92.15755416500954, 81.6600364254367, 83.41270046849405, 71.89948497279998, 75.5203817736718, 75.0033349375571, 76.80745263253489, 76.47787155643587, 71.12500513753584, 63.33775889488959, 65.99368203070857, 65.22229302314021, 72.93399441626765, 73.86866384936918, 68.14463138580322, 64.46465584539598, 67.29435566932925, 71.81596202235069, 72.36599599161457, 70.69047712510633, 70.20476218192809, 72.07857255012759, 67.41889876704063, 64.96298120867822, 68.62370183390956, 66.45445069959088, 59.57993607367239, 53.15914946217691, 53.54440073813162, 53.850682935407086, 55.71565620360836, 51.610342764085345, 51.39583226173155, 49.50903884826168, 48.4441977162515, 50.353034850089784, 50.272571348374896, 45.57917302654636, 46.66366523311984, 48.820776631755216, 49.72119592851209, 49.60356404704433, 51.21331261050317, 52.920120223875976, 52.41718215327109, 46.88985655384679, 46.448562452870036, 47.871978821293006, 48.26722429644678, 48.2578694435858, 46.63584778385778, 46.00204767719392, 46.79305245799404, 47.22647043966478, 49.39928700847011, 53.56062758353449, 54.81204017516106, 50.5583317049088, 50.76529556705106, 53.00563966074298, 48.60273207387617, 47.7227287138662, 50.534542529813706, 48.77546148915445, 52.84734064532865, 53.18834366336946, 51.72460925194525, 53.09340661571872, 54.102538324171505, 54.240903854370124, 54.42509835766208, 52.39992764688308, 50.419256225709, 49.29545794763873, 50.431176308662664, 50.7109119046119, 45.78625848216396, 48.31263357593168, 49.905225692256806, 50.43067816765078, 52.30443754503804, 52.41342452264602, 52.847399480881236, 53.038838601881466, 48.95768696261991, 48.68874965175506, 46.488484336483864, 44.91060895304526, 45.36624323937201, 44.81319296744562, 46.47267326231926, 48.97800876248268, 49.54975697302049, 49.843487585744555, 48.224125292993364, 55.661398057014715, 50.60333698026596, 48.18740798581032, 49.4817626860834, 46.95614460975894, 43.97233486175538, 47.147391534620716, 47.99341932419808, 48.63577019783759, 51.278686754165165, 50.85205055052235, 54.20029947834631, 52.318903246233546, 51.38927405880344, 49.73397893290366, 52.24955966395717, 57.54075465663787, 62.163424799519206, 62.908071087252715, 67.16515279585316, 64.3145388941611, 66.56454378558745, 69.41831127289804, 69.35572593442856, 68.9578014804471, 67.28804065335181, 61.83593434672203, 67.97112141886066, 73.08442515711631, 72.58533493165048, 74.6273914460213, 74.48822575230753, 72.85391530682965, 74.75773965158771, 75.55733050069502, 73.34433709421467, 76.08140622415851, 77.19380609450802, 78.6721081887522, 78.08020684026903, 81.23625570727934, 81.46205086861887, 91.4573718655494, 16.04977196262729, 1.4404957164679806, 24.02840437427644, 94.98985844273722, 71.22106398305586, 66.20102636275753, 44.55597962102583, 60.61558300449003, 78.86388855595743, 81.33760190779164, 2.1694193059398286, 0.42234650963256437, 0.21143879621259629, 0.17490780161273095, 0.21010410250915637, 0.2197644099472992, 0.15394074121309867, 0.18800485608798845], [0.018242552966600465, 0.05807065592718221, 0.06377901836869217, 0.11534124026976286, 0.0248262474703933, 0.10443309051615578, 0.11242746315415829, 0.13545511620900325, 0.19850874890483197, 4.935256079319985, 63.117513887343875, 46.425600897881296, 51.7193179745828, 30.8553445723749, 56.344035594694084, 46.119977658794774, 82.1657633012341, 26.95733428001404, 0.07807798052747404, 0.1963487333588062, 60.98201867072814, 84.05247042256018, 71.46730253773352, 72.05192396717688, 68.97174942877986, 71.21746324723767, 72.87732401201802, 66.63189872618645, 56.97641188098539, 57.002162241166644, 65.75719056590911, 63.939430867472005, 64.30489770827755, 61.954280099561146, 60.94006892173522, 60.36784218203638, 61.18376578054121, 62.94441184689922, 67.72782464181223, 63.44154873201924, 62.580764985853634, 60.25926313092632, 62.43752394953082, 59.71816432091498, 59.86579056709044, 58.993188719595636, 51.67358706074377, 48.45967931132163, 47.888990140730336, 45.63917352307228, 47.313284258688654, 48.35767415262038, 48.61841370982509, 44.69742421180972, 42.27824357248122, 44.266810724812174, 44.94846766994846, 45.334683848965554, 43.45168336745232, 42.788732205667806, 44.72612027199038, 43.159254981625466, 46.99590959856587, 44.58194963393673, 41.801714820246545, 41.9513963883923, 40.65809680569557, 40.67162898279006, 42.72609587638609, 43.323574835254306, 43.94397220303936, 42.020273208618164, 42.50319934660389, 41.21521849786082, 41.16126237377044, 41.04560736686953, 44.2399581786125, 44.93895199991042, 45.014112457152336, 43.56050952788323, 43.45410739221881, 46.020882898761386, 44.39001237192462, 43.54274511337281, 43.4016574582746, 41.553652363438765, 44.226594663435414, 42.139344599939164, 45.78958857444025, 48.93524708286409, 41.77713332637664, 43.4894871711731, 41.25873327255249, 41.601630795386534, 43.58733069512152, 44.16620192989227, 43.0295108210656, 43.661581162483465, 43.91413865550872, 43.89928071729599, 41.57562940351425, 43.39344401513377, 44.17076364640267, 40.34295397420084, 42.18257304160826, 38.89958450871129, 40.20009733015492, 41.97040027187717, 41.335097897437315, 42.11051125680247, 42.83393752190375, 41.115523615191066, 39.95982077813918, 44.1049619643919, 45.5810949879308, 43.89347560944096, 45.7784882668526, 43.662240120672415, 42.215187549591064, 41.30080853739093, 40.75126486439859, 41.65029564211446, 43.677823697367025, 44.08352621140019, 43.684793749163234, 44.16990464733493, 45.4423999786377, 45.80324626738026, 44.88675702002741, 46.47891767563359, 46.63423961208713, 49.588741410163145, 53.94470214843751, 56.821082099791504, 56.577585281864295, 62.018301025513686, 61.50175233041087, 62.60714292526246, 64.28561925888062, 63.72126079374745, 65.0897208336861, 65.59376893504974, 60.78285640285861, 61.62722110748292, 66.65883756452992, 70.16695053346696, 73.75750387868574, 80.03968961777227, 72.06842145612164, 69.48081031922372, 70.1740578682192, 67.15828864805161, 68.30440521240234, 68.08056339140862, 70.60071760608305, 74.16766612760483, 71.59609748471168, 79.08185466643303, 17.473311885710686, 1.3698401013689658, 20.468657324391028, 78.5672083208638, 54.2691017735389, 40.39974989429597, 30.602481134476204, 37.829138309724875, 56.66081797692084, 58.28146288471838, 0.851365399937476, 0.13954987148604087, 0.08998862527791532, 0.035928068081698114, 0.027695595316829223, 0.1597670237383535, 0.024541605586907076, 0.07948342245072126, 0.006836509264464821, 0.1383623585946137, 0.04304838419381169, 0.1254864583813375, 0.08145635932563774, 0.049029462445046634, 0.05740556520439925, 0.1282058560079144, 0.1581762268418266, 6.749468484232503, 73.90258450661936, 50.470541215712025, 50.33136375488774, 34.962309329740464, 67.41299167756112, 52.446521482160016, 91.99652517995527, 31.979056558301373, 0.016853848149278955, 0.09439052052555547, 61.13450081117692, 86.23872895394602, 75.9049544795867, 74.27113040801018, 72.8077882336032, 71.20684931355139, 75.77770494645642, 69.15588117414906, 63.351334218055975, 60.53777494738179, 67.0976644946683, 67.2503702102169, 68.64763613670104, 67.01876994102233, 62.55793679145075, 64.68531270180979, 65.86552250769832, 65.66265360001596, 67.91205052406558, 66.76423165106004, 65.66840379468857, 62.62950435761483, 64.24526983691801, 61.80082128893945, 61.35144710540772, 60.260965439581106, 54.14068729646745, 50.262447710960146, 49.75667768909086, 48.877611775552076, 49.89940881729127, 51.03372689216368, 50.469129162449995, 48.23681023813064, 46.3905192190601, 46.90183547235305, 48.456906195609804, 46.522252021297334, 44.87702169725972, 43.90329722435244, 46.92415375863352, 45.68728923797608, 48.620029726336085, 46.9495040370572, 44.05263362392303, 44.64229137666764, 42.6823143805227, 44.01760293591408, 43.94448603353193, 46.95015515050581, 43.76254689308905, 43.03873231334072, 43.437696195417836, 41.9656777381897, 43.65579958884947, 43.385869918331025, 48.3427809130761, 46.05768649808822, 48.73276648982879, 44.9044547542449, 46.57137578533542, 47.83764239280455, 47.10245686192667, 46.03009654629616, 45.966667898239635, 45.64104449364447, 46.712459518063454, 47.82211372929235, 49.45185069114932, 49.72032123996366, 45.497666174365634, 46.51304229613274, 46.08545295653805, 46.6758285030242, 45.155047139813824, 46.082766132970015, 44.58030223846436, 46.09008919808173, 46.07855350740495, 44.83198504294119, 44.02969168078515, 47.9544113528344, 48.80392220712478, 43.26911664778187, 43.00368593585107, 41.87740479746173, 42.592339131139944, 44.025004448429236, 43.90581538600307, 44.209775540136526, 44.77181588449786, 43.88213995964297, 43.40875694828649, 45.39446077039165, 49.53888808527301, 47.41569734388783, 48.835038369701756, 47.07307438696585, 45.112061885095414, 45.05983552625103, 44.67315258518342, 46.268890442386756, 47.572662753443566, 47.869448892531864, 44.62159302926833, 48.55266301862655, 47.11269424807641, 48.459757758725075, 47.90441682261806, 48.34783292585804, 51.617261825069306, 51.824939558582926, 56.133737717905355, 60.69313218516689, 60.09005992643295, 63.86509410796627, 62.49910123886601, 66.10102161284416, 67.16991455324235, 66.4522933959961, 68.39686332210418, 67.76064703541418, 62.82068852455386, 61.10678142116916, 68.54321479797363, 73.49309690536992, 77.21618713871126, 83.21037677026565, 71.7992135017149, 72.52079625283518, 73.04360897310319, 71.94460791926231, 73.55239529763499, 74.2198258061563, 74.71311876850744, 77.89208212206441, 76.33722320679696, 85.45283502148044, 21.5862915977355, 1.2610170052897547, 24.03387019711156, 86.79314813306256, 60.44159058601626, 45.77271061558878, 39.845683728494954, 39.35696032739455, 63.13700806710028, 66.83974512161748, 1.0067700738868406, 0.12262843714486207, 0.034287299269870404, 0.10924029224101575, 0.1231157992996516, 0.0971413737223033, 0.057344044513639905, 0.10568225816372903, 0.12859721968491233, 0.27166023249587706, 0.17839371617282593, 0.19378868202047964, 0.17304616199145395, 0.17767370077631167, 0.19133242027413463, 0.30165787605989364, 0.5188853858459381, 9.815881386879953, 84.9115950061429, 58.61710010036346, 65.70806680187103, 39.80065491891677, 79.86991374723374, 57.64928271693569, 98.20364459868401, 34.3729143757974, 0.22792525349124787, 0.9787603671992979, 70.40400289720105, 90.37987324499315, 79.47746492201283, 74.84350619777557, 76.3856880126461, 71.14857858227145, 77.07446405964514, 72.58409546267602, 67.525846112159, 61.29046209396855, 68.99317341466104, 69.43961758767405, 69.98215982990881, 67.27889368610998, 68.35249347071495, 64.66413190287929, 66.58653259277344, 65.74338382290256, 72.37070283582135, 69.08642384313768, 69.14001126443186, 62.6244366553522, 64.93590508737873, 65.80728315537976, 66.82288677461686, 62.98813058483986, 57.51510235571093, 52.7446412271069, 52.5487345264804, 52.097034377436486, 51.39045861459548, 53.08174148682625, 53.49288432828842, 50.34477826087706, 49.533922364634854, 51.57311554877989, 50.24060010910035, 51.09846953422793, 49.46137812829787, 47.625399020410356, 49.59665283080071, 48.36219272305889, 53.157592281218506, 49.487708999264626, 48.14986305852091, 49.51222773521177, 43.20151067549183, 46.53573320757958, 47.04488039016724, 50.62112100662724, 46.05228931673112, 45.300892629931056, 46.6398682132844, 44.75482417691139, 45.67842075901647, 46.19430657356016, 51.85414552688599, 49.679414841436575, 51.86120187082599, 49.02996840015535, 48.85779988381171, 52.26510793932023, 53.005788710809526, 50.40757932970601, 49.95465147879816, 49.89466274938276, 52.45538603874945, 53.3565309739882, 52.18486801270516, 54.366839393492675, 48.367068229183076, 51.225617085733724, 49.919507042054214, 50.5113220983936, 51.411451139757716, 51.25097913126792, 49.40038919448853, 49.30372630396197, 50.373019326117735, 47.56605748207339, 47.712185382843025, 51.72553493130592, 51.415801048278816, 46.47683489707209, 45.40828320287889, 43.76693994768205, 45.69117630681684, 48.07351804548695, 46.369032475256155, 45.407741915795114, 48.106564014188706, 45.77202027843845, 44.59277145324215, 52.080972271580855, 51.35594960181944, 49.01972316926526, 52.90661550337269, 50.041786932176166, 47.46488778821884, 47.03504700814524, 47.88794286789433, 46.7676394216476, 50.76797454587875, 51.954907294242616, 49.95853854763893, 52.33506733371366, 49.79833326032085, 53.04304338270619, 49.59388363745905, 50.54558792421895, 54.27248677899761, 54.648351823129964, 58.873007297515876, 62.95703011174356, 63.497846511102495, 67.40357798914756, 66.67848079435288, 68.89469838911488, 69.95729984775667, 69.00226546872047, 71.4321816352106, 70.81041536023541, 64.86704003426337, 64.27814714370236, 70.64794294295773, 75.17546423019903, 79.5049842711418, 80.9969283688453, 70.775647471028, 78.00784695533015, 74.46054166363132, 74.15010959871354, 75.61065120081749, 78.27376011879214, 76.97969175154164, 82.39005227242747, 77.8985304986277, 88.06165833627024, 23.8808604978746, 1.3950081121536995, 26.384613321673488, 97.10415717094176, 69.11941097628686, 59.63661824503253, 45.07502686592841, 51.90667783060382, 72.29823312451764, 81.14792393099877, 1.2038594916943581, 0.2608753999154414, 0.21723089589466973, 0.2420452192065216, 0.2153619324728366, 0.27709329741135724, 0.13812795101154235, 0.2591521617385649], [0.054242054916798114, 0.0581330269755375, 0.09289789013564588, 0.039248419550037196, 0.019170632097689856, 0.1034656593636159, 0.08922176360483132, 0.13782514709859126, 0.18965796657627632, 3.0097689743964904, 63.750964903062396, 52.46872209733533, 38.674926834721724, 32.60132293547354, 50.0421360231215, 44.46742034727528, 82.35056969427293, 40.5300235748291, 0.24768463756528594, 0.2871106631092487, 28.167534528240083, 87.56976958244078, 67.59031418831118, 74.47088887614589, 68.59359372046687, 71.12341265524589, 67.87867899863951, 62.77499683441655, 55.57558444238479, 64.46360857255998, 64.71514232697027, 66.81453212614983, 68.13488821829519, 61.92537615376135, 62.1884612883291, 59.83539612062516, 64.10233866783881, 64.3650354877595, 62.46011680172336, 62.87095762068226, 64.78839258993825, 65.11971519839379, 60.195520693256015, 59.9635870225968, 59.23799953153057, 53.493927678754254, 48.49237618907806, 45.54369126596759, 46.39227251852713, 47.276555184395086, 50.441123439419655, 51.52281115131994, 48.79172755825905, 47.184850169766335, 46.465087398406, 42.36156255968156, 47.17657004633258, 47.45445820593065, 44.911526787665586, 44.721856655613074, 47.74798485540575, 44.36774115408621, 46.383882568728545, 45.53698009060275, 44.7157456028846, 43.43364046465966, 41.79200695407006, 44.02408269143874, 42.348214733985166, 41.32926533299108, 42.555147217166045, 42.932981291124904, 41.4069910203257, 42.391411796692886, 40.59594685031522, 44.37022401440529, 40.68770285575621, 44.150641887418686, 45.75406366778959, 47.21714304339501, 46.69342033324703, 45.268682126075994, 44.27426715050974, 42.359613141705914, 44.55277896696522, 40.780145275977354, 43.45035760633407, 43.12367516179239, 48.70907145161783, 51.272054026203776, 43.27833421768681, 43.09793264635148, 44.84823150019492, 42.133049195812596, 40.15253466944541, 42.0534368484251, 41.597335800047844, 43.927270750845636, 43.95375851661929, 43.10864856166225, 43.400112044426706, 42.249720096588135, 40.197967483151345, 42.51581368907806, 40.53847236018027, 41.3886421726596, 40.21261361337478, 40.080994559872536, 42.33447467127154, 43.13095900320238, 42.52987930851598, 43.09631662984049, 43.90502306722826, 42.96481524744342, 43.63599161947928, 47.350648756950136, 45.717715063402736, 42.158936838949884, 44.254776893123505, 43.35161585961619, 42.116092789557676, 47.47959275399485, 47.038192749023445, 44.2592130937884, 46.250227805106874, 43.81512626524895, 45.79649194594353, 47.717072656077725, 46.41513993663173, 45.01144132306499, 44.51812874886298, 48.09152956931822, 52.67099088238132, 53.76798760506415, 57.34919001979213, 57.55775028659452, 58.97590283424624, 62.061074472242794, 61.07441010013704, 65.7693342239626, 66.8202901655628, 66.14652110684302, 64.06662940979004, 64.8614663462485, 60.09095422683224, 62.964164903087, 67.27220996733635, 76.39956535831575, 101.01741959971767, 70.08836192469444, 70.81181172401675, 69.76186383155085, 69.83308622913977, 69.92310462459442, 71.25852261820148, 71.75756577522525, 72.96553811719342, 83.18437145602319, 18.791595005219985, 1.1744354641245258, 26.232390057656076, 70.52071694404849, 58.210126738394464, 30.84494048549283, 30.318882003907238, 49.48411610818679, 53.49459055931338, 57.92819853751891, 0.7966916046796307, 0.11623950134361945, 0.004704120285403465, 0.036595518355287855, 0.03664573924916406, 0.051454942778594075, 0.04145677524408506, 0.11306536158606892, 0.060050246275721066, 0.08937093624544722, 0.0649502212482114, 0.052217682898645444, 0.026006331224174752, 0.06790515260710832, 0.09303543356157119, 0.07596368510876933, 0.13283826711197055, 3.7412032485008244, 71.79436545218192, 56.20331664239207, 40.40522552305653, 39.88848855418544, 58.68846370327858, 52.27592975862565, 88.37431046270555, 45.289019615419456, 0.4119724533971279, 0.12845298831140803, 25.855852327039166, 91.03639171969508, 72.33696260759908, 77.83771022673577, 71.58095713584655, 76.0497840758293, 69.1271145113053, 68.88483755050167, 60.22579746861612, 66.12988241257207, 70.24497432093467, 68.23181782999347, 68.49795064618512, 66.32897407777848, 66.03537682564028, 62.76824251297982, 66.68070085587041, 66.22061467939808, 63.40524719607446, 67.97133322684996, 68.76493069433397, 66.0678618954074, 63.8864004227423, 60.33705157618369, 63.265167590110536, 56.917870506163574, 51.801071936084384, 47.88826842461863, 49.38909276839226, 50.928062162091656, 52.66285196427376, 55.376163298083895, 53.378864949749364, 48.68560783324703, 48.636844927264804, 46.981718463282434, 49.59652731495519, 49.87222286962694, 47.632318081394324, 46.95525423172982, 49.17199742409491, 45.31315003671954, 47.973156359887895, 48.06897201845723, 48.169941671432994, 43.98758111461517, 43.9097495232859, 46.32549024397328, 45.20671259972357, 42.448356766854566, 44.63448978239491, 43.982615393977014, 44.03472015934606, 44.00137216814103, 43.58027042881135, 45.615117626805464, 42.63226101475377, 48.9126895320031, 47.39533239795316, 48.21835548646989, 46.89256691163587, 46.5101711211666, 47.54123672362297, 44.94374905863116, 45.24283370664043, 45.94519684391637, 47.70832577059346, 46.63396504617507, 52.52499241982737, 54.03514415987077, 46.78835738089777, 46.202555318032545, 49.03403197565387, 46.274315080335064, 42.65524218159337, 45.24201785364459, 44.56519719093077, 45.92041138679751, 45.8768024752217, 46.26976905330535, 47.08786956725582, 46.24983164571947, 41.903155157642985, 45.14206801691363, 42.906434689798665, 44.334306870737386, 42.501430357656176, 42.205036455585116, 44.48651052290394, 44.801708267581084, 44.4876636997346, 45.44139192950341, 46.30327393931728, 44.777479787026685, 45.7398372311746, 47.86580108827161, 48.570325451512495, 45.07343046126827, 45.95965077800136, 45.44807172590687, 46.49021802410003, 49.49545175798478, 50.68958205561484, 47.22038684352752, 49.389688968658454, 47.06420983037641, 47.62164923452562, 50.75519938622752, 46.82155632203626, 48.13774293468845, 45.38703964602563, 49.7665463724444, 53.43649241232103, 57.82324767881825, 59.79301883328346, 60.962371518535, 62.698914620184134, 64.2360483446429, 63.78145740878198, 69.48651344545426, 69.39301983002694, 69.66572653862738, 67.52075487567534, 65.30987170434767, 61.34640293736612, 64.39534756445116, 69.14970736349784, 79.81187835816415, 97.00769824366417, 72.18737909870764, 75.03074446032124, 73.22639142313312, 73.88228231860747, 74.14934865890011, 75.69148340532857, 75.54350022346743, 77.4047903860769, 85.07888409399217, 22.583454193607455, 1.2810507560929945, 31.817545121715916, 79.04071684806578, 68.29575246380222, 39.752798080444336, 40.82222446318596, 56.723650424711174, 61.364885145618075, 67.80120434299593, 0.8769655455985378, 0.04708093313139774, 0.08994256041102833, 0.04888334649524862, 0.003906039332392656, 0.05290885508481053, 0.06780360765274494, 0.06619920503468284, 0.19640013785852542, 0.21187512925074947, 0.19686037283991614, 0.11183430425702565, 0.1183263861363934, 0.17930761310121707, 0.20948282052432338, 0.4150010134664274, 0.414263638517549, 5.244806101245265, 84.62397544614731, 63.71869164128458, 50.55688827268539, 43.13952545965872, 69.74432299214025, 57.69686498949605, 97.8256771641393, 50.582034587860115, 0.4151336386078789, 0.23256413037738494, 33.34262932500532, 92.59711065599996, 74.39972923647973, 80.23004224223476, 73.95593658570321, 76.51438097799979, 72.62359373031124, 71.32953320780109, 61.80049180984498, 63.47706971629974, 70.2675671731272, 72.46832278466994, 70.64416962285196, 68.75790180698519, 66.90071444357595, 64.94699755022603, 67.73473585805586, 68.931349016005, 67.13233824699157, 68.78990050285094, 70.91580944676554, 68.67637926532377, 66.95551779962355, 63.868792903038766, 64.47309286363664, 60.98640388058078, 54.19514940631006, 50.80407211857458, 52.523184207177934, 53.2827276568259, 55.9408433975712, 58.713861050144324, 54.16284084320069, 51.45084742576846, 53.18280919905632, 50.06670967225106, 52.96199152546545, 54.57871798546084, 47.331538969470614, 49.85884758733934, 52.6545875303207, 48.5606764208886, 52.76553177064466, 51.71423850520965, 49.86294646416941, 46.213714461172785, 46.68135512259699, 47.43770576292469, 46.21134927195888, 45.89417073034471, 48.61320087986608, 44.72249992432133, 46.71308709729103, 47.01441534103886, 48.140974967710434, 49.01462801041142, 46.35401371986636, 52.410898516255045, 51.14251382889287, 52.16635442549183, 50.53811973141086, 51.32874404230426, 52.0589481630633, 48.030313138038885, 51.14263542236821, 48.812269010851466, 52.31223129457044, 50.990510217605106, 54.84814167022706, 56.813202058115316, 49.352571579717825, 51.719278750881074, 53.14537802050191, 49.494035782352576, 47.34778934909452, 49.42238976878505, 46.96906881947672, 49.809578695604884, 49.92277829877792, 50.25450883373138, 49.40560202444754, 50.91651862667453, 47.659453038246404, 48.26304697221326, 45.56568791789394, 46.00475803498299, 45.69371015794816, 46.05249720235025, 46.978098115613385, 46.8754889119056, 47.6148949130889, 48.46393900532877, 49.37570571899415, 46.910507832804036, 51.77767892037669, 51.9715577556241, 50.92326902574109, 47.7523269191865, 48.61333424045194, 48.53891903354276, 47.82538498601606, 51.21244968906526, 53.34532084003572, 50.45574211305188, 52.61443030449652, 49.246012549246515, 51.073750757401996, 54.02867617145662, 51.350842675855084, 51.77154433342719, 48.60228492367653, 54.14128741910381, 56.72839649261967, 59.26045902313725, 62.77593428088773, 61.966941510477376, 63.83114599412488, 65.75824568348547, 64.15520829539146, 71.86341485669537, 70.07980331297844, 72.75120412149738, 69.56842037939256, 68.86925789617723, 61.44342668594853, 67.07667196950605, 71.97190761566162, 86.1082552325341, 89.76501818626159, 73.75651544140231, 77.58457614529517, 78.30618243063651, 76.88838681867047, 78.71409323907669, 80.0557242670367, 82.42578506469727, 82.6728630065918, 88.91285973210489, 28.363857000104844, 1.2663855043149765, 35.71412571014897, 89.64212248402258, 73.72823515245992, 47.26656098519602, 44.4531350751077, 69.72519751518004, 70.24702179816462, 79.36432807676255, 1.0990694501707632, 0.14095222607495325, 0.12408170593722213, 0.07636952018665691, 0.18686693972877919, 0.20590359645505107, 0.20021260505722416, 0.1535719924516255], [0.03266724547551524, 0.05201917802614551, 0.07497179276880718, 0.05931926433057074, 0.05680908914655448, 0.08173477099907976, 0.029445876397432822, 0.005093916354986329, 0.054807803188, 0.8397220892290916, 50.6724726769232, 47.41730551565848, 54.95013506181779, 31.352379475870443, 41.86142506137971, 38.006174487452355, 66.9721015807121, 59.870332671749985, 1.6943448950206081, 0.16688542080021676, 5.57723677927448, 79.55937970069148, 72.38202279613864, 73.42605575438469, 72.94154890121953, 71.37136136331867, 64.27452287366314, 54.56772750423801, 66.29823838510822, 68.6913784088627, 61.64864901573428, 66.84042761402746, 61.27295263351933, 64.0706459168465, 61.48643155251781, 63.96148635495094, 61.774329600795625, 62.57506970436343, 64.13753801776518, 68.15994431895595, 64.1899291161568, 59.31912199143441, 59.42979166584631, 61.04967171146024, 57.94548050049813, 50.61206033152919, 46.298006196175855, 46.32580795595723, 47.280206911025516, 50.831846421764745, 52.26175823519307, 54.92973481455157, 52.545910419956336, 49.773728232229914, 47.99386647439773, 47.00363666780534, 48.52043682529081, 53.78173943488829, 49.258760252306544, 48.010505168668686, 48.56891339825046, 43.72497058683827, 45.70821116047521, 46.319418414946526, 45.7520632590017, 44.48889924633888, 42.74586069968439, 41.206553982150176, 42.760440149614894, 42.825955498603086, 41.27932179358698, 42.59740683340257, 42.41319271825975, 38.00753947227232, 39.4283474645307, 42.9501534277393, 42.81653004307901, 42.40724248270835, 47.542409512304495, 46.26464251549014, 44.73247451166953, 46.067970952680035, 44.874146599923414, 42.89010978514149, 42.24274220005159, 43.08312569895099, 45.37418211660078, 42.126612586359826, 50.91297280403876, 55.442180710454146, 44.70051111713533, 43.95992840490034, 43.902010686935924, 43.65944739310972, 45.79479355965891, 44.45180146924911, 42.10455317651072, 44.9236390667577, 46.15500442443356, 43.324237715813425, 45.25219640424175, 41.1080083539409, 40.26853484492148, 39.83244180679321, 38.99112870616298, 40.00936031341553, 38.1848031474698, 42.18023530898556, 36.99279485210296, 41.90268839559248, 43.52403540765086, 43.193642400926166, 40.79876868955551, 44.03255893338112, 43.52337644946191, 43.37010983497866, 47.916211389726215, 40.94948184105658, 44.12882958689044, 44.04204714682795, 49.11407186139015, 54.31228314676593, 46.800744225901944, 43.028039932250984, 45.95876039997224, 48.661802968671246, 48.34246712346231, 47.61041556635211, 48.131812310987904, 47.58623415423978, 45.95758368892055, 46.222967332409276, 49.56407754651962, 57.25004034657633, 57.76099966418359, 58.79238690099409, 62.07996460699267, 62.02325105667115, 66.09129413481682, 63.048127158995605, 66.03416089088687, 66.68804353283298, 67.13711569386145, 66.19086742401123, 70.20693517500355, 58.828190295926994, 62.30301803158176, 56.873975261565185, 92.93376768788984, 82.34828687483265, 67.74068217123708, 71.6880770652525, 69.13939937468498, 71.7156199486025, 68.61445288504325, 71.84801563139885, 73.27830791473389, 77.91824433111375, 11.388217403042702, 0.42903274117458257, 32.39644577426295, 72.48209814871512, 45.210136828884, 29.009351653437463, 26.0557774959072, 41.35368600968392, 57.16308139985608, 51.060453922517844, 0.5153838124486708, 0.1336699781278449, 0.024554292002933163, 0.0491577438679674, 0.020773330170120445, 0.08877958531581587, 0.014201903606825059, 0.09469235150684273, 0.0302730483423558, 0.00835636641920334, 0.015771692457248368, 0.10796696218031068, 0.03552410225834578, 0.04896493102874487, 0.07966978099918173, 0.0565604821238066, 0.061472247189451615, 0.7092383780306386, 60.707225261196015, 55.04478185407577, 55.84749883221042, 44.07346925427837, 51.53553139778876, 44.03090761553857, 77.35189330193305, 63.08929635632423, 3.107828473852527, 0.3928751684725285, 6.010067386011924, 78.66395750353414, 77.29571711632514, 73.80655704006072, 77.79374045710411, 72.9360418934976, 70.64562089981573, 60.740188860124164, 69.21408914750623, 75.91600771873229, 64.43388485139417, 68.62130918810445, 65.20000219345093, 66.96857144755703, 64.68490085294171, 66.07934659527194, 65.73599407749792, 66.07482802483344, 68.21475551974389, 71.62126341173726, 67.21213494577717, 61.94083813698062, 63.69421605140933, 64.26216740762034, 62.394052320911044, 52.89835106941962, 47.80500827297088, 48.80470668115924, 49.26536552367672, 54.07241844361829, 57.21599809585079, 59.05657422158026, 54.632799625396736, 54.67731460448235, 52.76511599940639, 47.942526571212284, 51.116449679097826, 56.12319438688217, 50.962343677397705, 48.809154648934644, 49.53307121030746, 46.4705708719069, 49.13317380412933, 47.61524400403423, 47.94042025842975, 47.291358209425404, 44.90369381443147, 43.47510383975121, 44.978524792578916, 43.41951993203933, 43.63343423412692, 45.21711472542056, 45.31516221261794, 40.768805703809186, 43.59685420989991, 44.13843547144244, 46.64375528212517, 44.73252942485195, 50.53501713660456, 48.054019943360366, 47.16217494780018, 47.071674100814334, 48.38676244981828, 46.79236996558405, 46.90042341909101, 47.339740645500925, 49.36830028410881, 44.86595669100362, 52.47451543807984, 57.05109773143646, 46.1610762534603, 47.47836112976075, 46.011363306353175, 46.692059270797245, 47.43694482311126, 45.83917517815867, 47.214836689733694, 44.98947212772985, 46.671894365741366, 45.055222818928385, 48.16397966877107, 44.71028958597491, 45.30247726748067, 42.10676539328791, 40.24564781496602, 42.03515075868176, 39.882534396263864, 42.951663540255645, 40.512612173634196, 43.13845465260167, 43.5366105264233, 44.20668863481091, 45.51679949606619, 46.56021271982501, 45.612497483530355, 45.6969068896386, 49.039903763801824, 45.45629693615822, 46.535105628352014, 47.01707078564552, 52.79627923042544, 57.05851101106214, 49.86523320597988, 47.35011139223653, 49.92661437680645, 50.70354177105812, 52.74199362724058, 50.48726620212678, 49.90487660131147, 49.40952831699003, 46.62217832380726, 49.00177048098657, 53.03587329003119, 58.983669127187426, 61.4083646189782, 61.16711139678956, 62.56212588279479, 63.30721932072794, 66.67353076319542, 65.36469467224615, 68.25008038551577, 69.1672246686874, 70.51946963033369, 68.7264600876839, 69.20729560236778, 63.913704041511785, 61.71505474275159, 61.188598140593506, 92.08143664944558, 81.38683549819454, 71.79982539146178, 76.39251293674593, 73.91290818491291, 77.36994404946604, 74.48273443406629, 76.70176829061201, 77.01698564714002, 81.14996356348838, 11.459457451297391, 0.4661882200068044, 39.933360468956735, 80.24582585980816, 55.072975850874386, 38.17824102217151, 25.92817298827633, 41.07409161906089, 65.71462500479915, 59.11982244060886, 0.5810062298851629, 0.0719855284138072, 0.0568613899691451, 0.03287141939865486, 0.04272421408865241, 0.08943678916341836, 0.035989538976742376, 0.05213256286937864, 0.11693590591030738, 0.13041091752388786, 0.24257054101795922, 0.23064815980051798, 0.110704799543225, 0.22227864922775378, 0.179834206618609, 0.15005989300627864, 0.18192044789752654, 1.7594546464181717, 75.79109591822471, 61.72444881931428, 72.7113449958063, 42.392804238104056, 59.34758270940473, 51.68326747032904, 81.84387791541316, 70.43861389160156, 3.1546701538947324, 0.3383972159316463, 8.7232090773121, 82.41498285724272, 77.97619342803955, 78.85496908618559, 81.52462051760766, 77.6873500885502, 73.69469888748662, 62.84232431842435, 66.28661247991747, 72.3049952906947, 69.26172241087883, 71.77612643088065, 66.24402338458647, 68.13643363214308, 67.3159130157963, 70.24607258458292, 66.92149516074889, 67.78288687429121, 68.60181500834804, 73.8528488528344, 69.95795880594562, 65.20028068173316, 65.61485167472594, 66.87349319458008, 65.40105504374351, 54.16266825891311, 49.76710334900887, 51.81920897576117, 51.974750564944365, 54.50722886670021, 58.75157071698097, 60.09561400259695, 57.00048346673289, 57.36943337225146, 56.04201701379592, 53.73236463915918, 56.06750065280546, 62.1047265298905, 52.23607847767492, 53.05582638709776, 52.63378327892673, 49.90692407854142, 51.328944083183046, 50.77118696704988, 50.594535181599284, 50.03062386666575, 46.30903590110041, 45.99277519410657, 48.05970345774005, 45.919603378542014, 45.58928489685059, 47.42064737504529, 47.14552840878887, 42.39840146033995, 44.446125799609774, 47.8029372615199, 52.58229824804491, 47.649305866610625, 57.88244801182901, 52.58136864631407, 48.86113782082835, 50.579041819418634, 50.1005950281697, 49.932466553103545, 49.81989452915807, 50.77623113509148, 54.72645798037129, 47.35142930861443, 55.2093017485834, 61.231552016350534, 49.204635466298754, 50.94090792440599, 51.66262403611214, 50.212331587268466, 51.92264579957532, 51.318643939110544, 48.76109776958343, 49.52214740937757, 51.61162537913169, 49.98099803924561, 51.6023999644864, 50.58102653872583, 49.652032775263635, 45.61479207008116, 43.61753294544835, 45.293675468813994, 43.55049963920347, 45.91779908826275, 43.38200638371129, 46.75156554868145, 46.49315980172927, 48.61761354630994, 47.558314723353234, 49.565740631472686, 47.96932812659971, 47.838748501193145, 51.18365556963029, 48.058997431109034, 50.428462028503425, 49.92076612287953, 54.95994490961875, 61.102329531023585, 53.33411070608324, 50.632774368409194, 52.89200467448081, 54.93178621415169, 54.13167761218164, 52.78057798262566, 53.204594042993364, 51.516229414170795, 50.674116150025405, 53.860359422622196, 55.07494488070088, 63.9872367151322, 63.73810345126737, 63.730337158326186, 64.93006075582197, 67.08495601530998, 68.90517111747496, 69.61536330561485, 70.67362662284606, 71.45800652042513, 72.82485838859313, 73.62100539668914, 72.32349318842735, 64.74684292270292, 60.92550516128541, 65.82981324964955, 94.05979387221798, 80.35044331704417, 76.53179630156487, 79.78419426948794, 77.87136416281425, 80.96211341119583, 76.42411939559445, 80.50942482486849, 80.57870172685193, 89.03940323860415, 15.105398585719449, 0.7830491109240441, 45.427687168121345, 90.32784692702755, 62.6957453450849, 45.61125409218573, 40.13981834534676, 55.649470129320704, 76.35364224833828, 73.43912509179884, 1.0674824805990344, 0.23101306280061124, 0.09325708578070326, 0.14621975471175488, 0.11400148272514345, 0.1944721856665227, 0.15435150223633937, 0.2748625413064034], [0.033501955725613146, 0.05642812128268904, 0.043579049468521154, 0.030987597701530305, 0.08933866862207653, 0.08146174492374544, 0.05759480424345501, 0.06785367915947592, 0.08679744006404955, 0.47872724071625744, 47.17039231331118, 58.787986001660755, 39.28173711222988, 20.570472248138923, 33.54425876371322, 38.87380276956866, 56.69479746972361, 73.15568677840695, 4.252894578441497, 0.12874453839275146, 0.9404302304310184, 48.540252639401345, 74.4547365557763, 64.24196720123291, 73.05610564447218, 62.3305413030809, 55.25716643179617, 68.30742543743503, 76.23790094929358, 51.31572569570234, 65.11381203128447, 66.91709426141554, 67.60786287246212, 62.91989703332225, 63.22893665682886, 62.43269158947853, 63.80295984206661, 66.53489851182508, 64.33586482078799, 62.56297703712218, 62.472405587473226, 62.84505821043446, 62.30748168883785, 62.45257800625217, 57.14583473820841, 47.13965662064091, 45.76857643742716, 47.54097000245125, 50.26010997833745, 54.203770775948804, 58.81226939539756, 56.191498541062884, 54.86409394971786, 50.4543222150495, 48.73144465108072, 45.86311340332032, 49.48739913202102, 55.898779899843284, 58.98023705328665, 50.82455865798458, 46.070908807939105, 46.724952267062285, 51.373996426982266, 50.678858295563735, 47.35678726626981, 46.756456744286325, 43.67273246088336, 40.32129464610931, 44.08331048104071, 42.62422015590053, 42.22022387289232, 41.71014708857383, 42.10551807957311, 39.805801068582845, 40.877557339206824, 40.94105658992645, 43.748493040761645, 41.4677877579966, 42.891882696459376, 47.32380797786098, 45.19325887003253, 46.01739983404837, 45.17578078854469, 45.5487472011197, 43.28271942753946, 43.79107036898213, 46.05813364828787, 46.31877906860844, 53.383944419122514, 54.394476413726814, 49.880514760171216, 44.0447888835784, 48.49000315512381, 45.49140214920045, 44.8396336647772, 42.277408107634514, 41.56191679739183, 44.93861859844577, 43.08150576006982, 44.03808163058373, 40.87454888128465, 41.17974850439256, 40.09984939329086, 39.66134801987679, 39.457259255070845, 40.86146777675998, 41.88999168334469, 39.49975421351772, 39.08480275061823, 41.694763552758005, 42.09250757771154, 43.395338519926995, 44.04922116187311, 42.74113816599692, 45.118176860194055, 46.642606027664684, 46.960533741981756, 44.481066273104766, 45.10452308962422, 49.40103638556696, 56.367785546087454, 53.194572387203095, 46.13507093921785, 43.81072536591561, 49.980209642840975, 49.161826718238096, 52.92480353386172, 54.73020776625603, 53.21214460557508, 48.78414953908613, 48.67600587106521, 44.507777613978234, 46.487091895072695, 51.65526959203905, 56.81671650178971, 63.28648567199708, 64.46038830664851, 63.26119030675581, 61.38776433083319, 62.07746997956307, 64.07774148448821, 63.81244805551345, 66.43265016617315, 64.97518762465447, 67.74257275366014, 65.92103189037692, 64.07110091178649, 59.20628324631722, 75.48544130017682, 73.50156922494212, 60.81861665171962, 69.36720278955275, 71.21020686241889, 74.17761325836182, 72.34916902357533, 71.31407122458182, 73.02627209694155, 68.72329865732502, 4.930405578305645, 0.03884763682201024, 43.25584334711875, 68.2188347847231, 45.361085322595414, 34.66683326228973, 52.83220029646351, 51.735497751543605, 58.91095230656286, 42.65235531714655, 0.10920225597557523, 0.06372048542083752, 0.05000908971734105, 0.05862050787395528, 0.13782099490204167, 0.11645513977254592, 0.0416375451811379, 0.04214401739919859, 0.01865399580809378, 0.05047438470947166, 0.019276011322114258, 0.049746428811622244, 0.05330374276626015, 0.050071974044605616, 0.033583444498118856, 0.12819100922394183, 0.06765984359287447, 0.6610197621968485, 55.236821097712365, 67.75037827030306, 39.27135067601358, 20.84121188809795, 40.6318953729445, 41.62549057314473, 62.287152044234745, 80.89358960428547, 6.087590580986393, 0.3265415456506514, 1.4214727114285193, 46.829926659983975, 75.58386925728091, 70.10527518487746, 77.90861098997055, 66.47957740291473, 60.09087970179897, 75.33220998702511, 86.58583517997496, 56.088383351602864, 69.60486704303374, 67.5998612373106, 68.84398214278683, 63.019054551278394, 66.27133877046647, 66.1621399848692, 65.57360402999386, 70.3650459166496, 68.06088878262427, 65.27304849316998, 62.24159371468329, 65.0645274500693, 65.80396090784382, 64.0580786428144, 58.558629328204745, 50.160254278490626, 47.977898505426225, 48.65018883059102, 53.473527431488044, 56.204352148117565, 58.61486827173541, 58.53917829452023, 57.74472575033865, 54.04054526359805, 51.33476880288894, 49.49216873415055, 50.97671916407924, 56.59501237253989, 62.206394364756925, 53.71532586313064, 49.34527597119732, 49.565830845986646, 54.575897801306944, 53.34376365907731, 50.940558833460656, 46.63118408572289, 45.52137297968711, 41.81430562849968, 43.0773284358363, 43.039026491103634, 42.42698769415579, 43.497257386484456, 42.478394277634166, 42.93780188406668, 42.1578150410806, 43.66982598458567, 47.42043948942616, 44.37690773317891, 46.623527619146536, 48.736445673050426, 48.67449183617869, 46.390711415198545, 49.67938738484537, 48.593789069883286, 46.84817352602559, 48.48920299160866, 49.341910577589466, 47.59412596302648, 55.78117547496673, 56.9652880391767, 52.34805037898403, 46.723936373187655, 49.22025826669509, 49.32258898212064, 48.95098755436559, 44.67818106374433, 45.14669249134679, 47.00775907885644, 45.608771231866655, 47.04831638643819, 45.5679040570413, 43.03906963717553, 43.66779419683641, 44.00895018731394, 41.354121392773045, 43.114081044350904, 42.80377449527864, 39.96246445563532, 41.80588037736955, 41.743542148220925, 43.92401910597279, 45.19580056590419, 47.77100524594707, 43.86034334859541, 47.39389288809992, 47.857383681881814, 50.66638908078594, 47.22682737535047, 48.14324209767003, 53.55471264931464, 59.024481388830374, 55.240527737525206, 49.60399158539311, 46.9805613640816, 52.98563949523434, 54.08837464547927, 55.838002774023245, 56.730518494882894, 56.61685212965935, 52.55672831689158, 49.11823349614298, 47.043950788436405, 48.398109866726784, 54.85790444958595, 60.76171875000001, 64.94973144223614, 66.37408917950046, 66.86023558339765, 64.5533053336605, 68.93911530894619, 67.9493365749236, 70.2205301100208, 66.87844322573754, 66.57301610515964, 69.22988845456031, 70.09363359020603, 66.0272575193836, 61.084733778430575, 75.87737237253498, 74.59770694855722, 65.28396052698936, 73.81165612128474, 75.41313632842034, 78.65819946412118, 76.98226482637467, 76.85672544663953, 76.27009576366794, 71.99457891525762, 4.028258722636008, 0.036961467065397775, 53.482101732684725, 76.39783167069959, 54.83952814532865, 40.263824078344534, 45.00559306913807, 53.99488887479229, 66.19031829218711, 52.520238507178526, 0.4886493357198854, 0.10437191839540198, 0.04018832516345767, 0.04597787760318287, 0.014338304604133292, 0.0877835714228211, 0.019287291966799288, 0.03705264301970601, 0.17618911430960701, 0.1376946670033278, 0.13888155170265706, 0.08826875788790566, 0.13836893162900402, 0.1555348782529754, 0.20427336135218221, 0.19372456046121736, 0.13323784325151675, 1.1481843888759613, 67.98163337092247, 73.97145348210489, 54.770576800069506, 27.981629871552993, 48.30161171574747, 53.27207842180806, 69.62428277538669, 89.3129179554601, 6.887632012367249, 0.4388117309539549, 2.1944462339724264, 55.843348964568115, 75.25717504562871, 70.69536439834103, 79.88668580209055, 70.87052176075598, 64.31010269349622, 70.06053663069203, 71.84128484418316, 59.226185352571555, 73.874555249368, 71.04021918389105, 72.23079973651518, 67.48096635264736, 68.4249004240959, 69.66170218683058, 68.03245159887499, 71.63674108443722, 70.51364883299797, 67.82506019838395, 67.03171376259097, 68.15396662681334, 67.5110980003111, 67.65808490014845, 62.28265700801727, 53.575897370615316, 49.90821453832811, 51.00068876820227, 54.655851394899436, 57.649129744498964, 62.43180121144941, 60.56886757573774, 59.932949389180834, 55.19147457615022, 54.15227790032664, 53.803226178692235, 54.7876077313577, 60.59097797639909, 64.4224040738998, 55.204590982006444, 52.17619957462434, 50.688115089170395, 57.09594611198672, 55.761516555663086, 52.81096458435059, 50.75656437104749, 47.63251812227311, 44.83910414480394, 47.109003297744266, 47.51176795651836, 45.00994690002934, 45.26353989878009, 45.42850302111718, 44.67900868385069, 45.86916954286637, 47.23738639585434, 52.64749980741932, 48.07578909781672, 50.51939433620822, 53.46344694014519, 50.71823496972361, 49.64665520575739, 51.94310880476429, 52.829070245066, 50.758352971846065, 52.40994538030317, 51.64089410535751, 49.411564027109456, 58.766436499934045, 58.97471043371386, 55.14819906603906, 50.33217960788358, 56.50398200558078, 53.9220622278029, 53.04864060494208, 49.32987282353063, 47.362400177986395, 49.997448459748306, 48.32193743798041, 50.35561576966317, 49.87542744605772, 48.017385005950935, 47.7868986898853, 45.95341813179755, 42.93855497913976, 45.69691081200877, 45.5674216055101, 43.9779987642842, 43.15078266205327, 45.8510442703001, 48.098664360661665, 47.99111689290693, 50.727460384368904, 47.15993919680196, 52.02170133590699, 51.04899667924451, 54.35555473450692, 48.94260544930735, 50.90877979032455, 57.1296275046564, 61.695489960332075, 59.325915536572865, 52.00278766693608, 49.042935755945024, 56.12435148608301, 55.762912919444425, 57.97664373151718, 59.764915050998816, 58.45900504819809, 53.32711319769583, 53.45821842070549, 49.19872837681925, 51.28475466082173, 60.64340437612226, 61.906215375469586, 69.45482069446196, 69.56467843824818, 71.77367887189313, 68.10122643747638, 71.09328885232249, 70.98963629814887, 71.88105767773044, 71.32270043896091, 71.97442577731225, 72.38862022276848, 71.90703945775186, 66.82076869472381, 61.8227747947939, 79.81197249504828, 75.8015686465848, 67.95875810807752, 77.31708618902391, 77.14873806122812, 82.1030681363998, 78.17730119151454, 82.36891854193904, 79.30369607863888, 79.45091047594624, 7.034411026585487, 0.17425193841899597, 59.659909279115745, 85.00641438268846, 62.99623812398603, 51.86934863367389, 68.95729941706504, 74.43223784046789, 78.52338760129868, 65.80826374792284, 0.9333613839360976, 0.1934335543023002, 0.11054634191696683, 0.12770439017443888, 0.14920245675790697, 0.20883221269374896, 0.09653992575382996, 0.2003681209058531], [0.09941711451017088, 0.09483891178763683, 0.045251189580848145, 0.07261506116558468, 0.0716003623881167, 0.015653775246333212, 0.040904050467595945, 0.06794131195713436, 0.12979628518223763, 0.3004625031063634, 42.87050185665008, 58.469952383349025, 55.29571156347952, 49.93043084298411, 36.69182746641098, 37.88591461796915, 52.197835368494836, 74.06493925279187, 17.06697198652452, 0.30913566028879536, 0.11054505488925404, 21.988960158440378, 66.82987643826392, 67.03975462144422, 68.15492368513539, 57.816461978420136, 66.49647497361707, 58.67917945308071, 47.27929299877536, 57.25753599597562, 67.42981080086001, 66.8567289844636, 64.072501197938, 63.050198170446585, 63.84672957081949, 66.62435208597492, 63.880399196378654, 60.435793322901574, 63.98753481526529, 63.80237540891094, 65.30760849675825, 60.93959039257419, 62.64771592232489, 60.262212753295906, 49.64722787180255, 46.19616185465167, 47.633082943577925, 49.82857865671958, 56.72569790194112, 58.27133924730363, 60.40412018376013, 57.38339308769473, 55.80931063621275, 51.15780322782455, 51.59328045383577, 46.93252409658125, 46.65170200409428, 54.8580534996525, 59.45483599939654, 51.48731762363065, 49.31482268917946, 51.63805430935275, 53.19319171290244, 50.98980811334426, 46.85401393521217, 48.84456972922049, 43.29698901022635, 41.13262514914236, 41.40465328770299, 41.874078627555605, 40.807260620978575, 42.08132490035027, 43.301597795178814, 40.387406195363695, 42.15674031165339, 42.129891687823886, 40.97581271202334, 42.33378041175104, 40.73117840674616, 47.33914052286456, 46.654573179060414, 49.157319914910104, 44.63388965975854, 42.495193789082194, 44.82883537969282, 43.30204886774863, 44.76345339129048, 50.483088877893266, 55.88752269744874, 52.069597398081136, 49.9372753789348, 50.42822276392291, 46.051959837636645, 43.32752466201783, 45.3377942885122, 42.89564032708445, 44.82537584920084, 41.995954513549805, 45.41237815733879, 43.14680537869854, 40.09037686932472, 42.35457289603449, 40.69468467466293, 38.704536807152536, 40.28322412121681, 39.43828282817718, 39.331770866147934, 41.308661122475904, 39.25329992848058, 39.56304165624803, 40.873705571697606, 43.852894767638176, 41.303969967749815, 43.85999425765007, 43.5365399237602, 45.01925468444825, 46.46595031984391, 49.17886941663681, 47.264270321015395, 52.89606824997933, 55.982157722596206, 52.12862122443415, 44.47394717124201, 45.05317926406861, 49.066787688962876, 54.04264765401041, 55.95967077439832, 57.74599659827448, 59.772065531822946, 54.46922894447081, 48.55050963740195, 49.40815548742972, 45.756013085765225, 50.096233352538086, 52.922799202703665, 57.78229028947892, 59.96319086320939, 61.62554625541934, 60.25193222107426, 61.90150460889263, 61.00462721240137, 62.85539757820868, 62.7594328695728, 64.64633218703732, 63.670458255275605, 68.22005071947652, 65.72725111438383, 61.596936487382465, 68.77457972495787, 67.77009210278912, 65.40959796597882, 66.40375014274352, 67.60199500668433, 73.3068706143287, 72.79333822188839, 74.54485693285542, 73.86085833272627, 59.27781158877958, 0.7027066511011894, 2.1630758527786504, 54.29432653611707, 66.72899307743197, 41.492722265182, 58.75109218781995, 98.08049786475398, 32.987003710962114, 63.39045201578448, 29.37418503146018, 0.08589083629269754, 0.038784476703092936, 0.05785365386175052, 0.11087572908089047, 0.033560821921714855, 0.048003023370139064, 0.08172548601343747, 0.08850454442924069, 0.06321889318285451, 0.06756105655503851, 0.0654910410183572, 0.060718006814920136, 0.02882057053577756, 0.03439426429629807, 0.07476049039753214, 0.02040339588758446, 0.05190369793243947, 0.33465481513450224, 51.170131237276145, 62.36448549455213, 58.33491302305653, 48.53696569319695, 37.94986101888841, 41.97315769810831, 57.53233332787791, 88.62728764933925, 21.1330028887718, 0.28962836510712103, 0.1662168405469387, 24.460027871593354, 70.93793945927774, 67.34838239608273, 71.8155227168914, 63.38139918542678, 73.58819084782755, 68.5405711204775, 52.32177049882951, 59.817243391467684, 68.85654941681894, 68.61177782858573, 66.00958331938713, 64.29855131333875, 66.7023366497409, 68.3822250366211, 68.97802522105556, 62.390165252070275, 66.33649718376898, 65.72704715113487, 67.86578224551293, 63.830981254577644, 65.2099257899869, 62.25557304197743, 51.526196156778646, 48.209322267963046, 50.67168035814839, 54.203233411235196, 58.643513341103834, 62.05292378702472, 62.25156045729115, 59.16363139306346, 58.015177096090014, 54.63638467173423, 53.86594880011774, 50.90126060670423, 49.22179975817281, 58.046285413926654, 63.77604846031436, 56.07410592417563, 53.07461846259333, 53.21916564818352, 56.601974579595755, 54.0431301055416, 48.66967908797726, 50.218344580742624, 44.729007136437204, 42.160042947338475, 43.83937828002438, 43.54673416383805, 41.94281816482544, 42.28933603532853, 45.0685667222546, 41.570961783009196, 45.44846788529427, 44.79996673522457, 43.32923481541295, 45.76635637590962, 41.482677075170706, 48.65784921953755, 48.941189473675145, 49.1620385262274, 50.40805001412669, 46.22672496303436, 48.22521963427144, 46.16179404720184, 47.96790430622716, 53.98724025295627, 57.143324421298125, 51.61306488898493, 50.71947836106824, 53.84379133101433, 51.35897767159247, 48.3260049358491, 49.8895989694903, 47.66699575608777, 48.0291638835784, 42.66866453232304, 48.03118390421714, 47.691632163140085, 42.9911853421119, 46.2290705403974, 44.71781269196541, 42.43125523290327, 43.25170916895713, 41.83834191291563, 41.71208081706878, 42.9432108325343, 40.715253583846554, 41.58083438873291, 40.87710626663701, 45.55620362681728, 44.14937103948286, 45.27881360823109, 45.92198033486643, 47.70501529016803, 51.249982849244155, 50.28566814238026, 49.072329998016365, 55.61152512027372, 57.12253978175502, 54.74372033149966, 48.87746272548553, 47.94338949265019, 52.024599967464326, 56.213891352376635, 58.938601093907515, 59.42845413761755, 62.98401994089927, 57.7469575789667, 51.30227588838147, 52.003172059212964, 47.71717071533204, 51.50489768674297, 56.24151268313008, 61.268469364412375, 63.690191699612534, 64.42147839453914, 63.48690309832173, 64.17177246462914, 64.3822939165177, 66.46438998560753, 66.09180404293922, 66.9035856185421, 66.38816264367873, 70.489134019421, 67.70368637577181, 61.86244564671671, 71.17769825843074, 71.33699355586883, 66.62193590594877, 71.7547102897398, 71.72809308575046, 76.75757577342372, 75.099778175354, 79.2788282517464, 77.2951130713186, 61.703550431036184, 0.361098270382612, 2.828523112881568, 64.11647881231, 77.23868585401966, 47.451967500871234, 71.23619648718065, 105.71262221182548, 38.21606051537299, 73.20780723325669, 37.209027274962395, 0.21406765756828172, 0.01337361987680197, 0.025025334569715688, 0.07534785766995723, 0.08045992408428462, 0.03690690245299089, 0.06829208063502466, 0.06983264514635648, 0.13834689894030172, 0.17749166296374413, 0.17273243366470262, 0.2653424279584039, 0.22915300132045824, 0.1139718198007153, 0.26192855630670825, 0.3507333765587499, 0.2160992614564396, 0.6685861981203479, 63.037270038358635, 75.35461456544938, 72.73676979926326, 66.25255846208142, 53.90150508572979, 51.79958535778908, 66.91518014477145, 91.88156835494503, 22.14200515900889, 0.6208394311608807, 0.4533040920092214, 31.134028973117953, 78.4057164961292, 70.06668690712222, 77.79963185710292, 66.2981834719258, 72.55194771674373, 54.88924810963293, 56.82454947502383, 65.58682633984473, 70.84257095090805, 71.12217318627143, 70.7860888204267, 69.15213138826432, 71.46734176143524, 69.44798792562177, 72.6207382448258, 65.47454457129201, 67.50070371935445, 67.52611283333071, 67.95971516639956, 65.24596452713013, 67.96969367611793, 66.68518804734754, 52.83220029646351, 50.65067998824581, 53.24223310716691, 56.37267674169233, 59.87018754405361, 63.09404634660291, 66.76267054773146, 62.712674294748616, 58.40282494022001, 55.0061974986907, 57.80827599187052, 51.85910732515397, 52.05753610980127, 60.9567193831167, 67.0049867322368, 59.971117973327644, 55.28610960129769, 56.98788873610958, 59.577704245044345, 57.264470746440274, 51.88811717494842, 51.98039093325215, 48.51027788654451, 45.0026983599509, 45.25868400450676, 46.72020227678361, 41.77364241692328, 44.331474919472974, 46.160374149199455, 44.93959526861868, 48.66359156946982, 49.53591100631222, 48.90134995983493, 50.73328118170462, 46.809600937751036, 54.63249368052329, 53.14160077802597, 52.381323845155784, 51.335008067469445, 49.20597691689768, 52.41042390946419, 49.903158603175996, 52.811568629357126, 55.84795382715041, 60.26606059843495, 55.82869498960434, 52.65949049303609, 58.78715838155439, 54.306317221733835, 51.126259526898785, 53.49527305172336, 49.14770226324759, 51.41937040513562, 44.87814741749918, 51.19290451849661, 51.8327215410048, 46.339920643837225, 49.47995839580413, 48.44997536751532, 44.76681094015799, 46.8117739308265, 45.166488693606475, 44.31030196528281, 44.24606138660062, 43.835142120238274, 43.63951390789401, 44.36393253264889, 49.66672597392913, 47.34490248464769, 49.82850805405648, 49.44035030180409, 50.85201917156097, 54.796127119371974, 55.95990219423848, 54.183943194727746, 58.948795333985366, 61.510612964630134, 58.0761032719766, 52.634430470005164, 51.63836809896654, 56.27802994943435, 57.19970457015499, 61.174767863365915, 63.17624353593396, 67.40622951138404, 60.97926908923734, 56.35889745527699, 55.41011925666563, 51.53561768993255, 57.232660324342795, 59.5938055746017, 63.95818764163602, 63.74154336990849, 66.76254503188595, 67.35772548183319, 67.47809517768123, 68.62258003604028, 68.33964378603044, 70.27989910494897, 71.6472844154604, 70.59403388730942, 72.18551989524596, 71.12409514765586, 63.07504246311804, 76.06143351524108, 78.81692994025447, 68.72763679873559, 76.42994019293016, 74.202269277265, 81.64382919188469, 79.4784455145559, 83.4738031510384, 81.86075979663481, 71.95692416160338, 0.7445445512571643, 2.632440641041725, 75.55084290043001, 85.30043525080528, 59.57178146608415, 83.29609624801144, 114.54579199514082, 48.270456329468765, 85.95374522670623, 54.22811692760837, 0.7977192043777436, 0.1603780707885181, 0.2771085578828089, 0.226808236010613, 0.3061701032903887, 0.21749824525848513, 0.2597102414696448, 0.16536966987675236], [0.08346715626577217, 0.056141726973076025, 0.0776633124558195, 0.04112864063391763, 0.02502951549456245, 0.05807283544732679, 0.0324753787548792, 0.07801342995897417, 0.057914680425798705, 0.15724037383352557, 26.281170614304084, 59.83834182062457, 43.49327225838938, 28.79416846459912, 63.433805973299094, 34.913048282746345, 46.01206933298419, 67.10791757029872, 37.10880287231938, 0.132452878920782, 0.10215796259862762, 7.020732250905807, 39.427060927114184, 66.06109972923034, 59.328339561339355, 60.83289800151702, 35.736047837042044, 24.800464107144265, 55.403886610461825, 65.6382054667319, 66.70786719168386, 67.8905402460406, 67.61410728577646, 64.01739189701696, 66.20203048952165, 61.46123816890102, 55.899634976540845, 64.0400984979445, 64.53489765044182, 63.700534989756925, 61.5534766258732, 60.17454385757447, 59.47678558288082, 49.43689469368228, 47.145912801065755, 47.457815754798155, 46.994842713879, 56.53116795324511, 62.254415942776596, 59.7191253016072, 58.230503451439645, 58.214974787927446, 56.69586827678066, 54.348600372191406, 53.32479899929416, 49.84611557376001, 47.58327668712985, 54.153686031218506, 58.67726141406644, 53.757761986024924, 53.13505434220838, 50.73201817850913, 48.681375595831106, 47.6965037468941, 52.59340247800274, 50.062398987431685, 46.372617521593654, 42.65990195735809, 43.92134797188544, 42.34173890083067, 43.56043500284995, 42.28336226555609, 39.946873034200365, 43.556802888070386, 42.116771359597486, 40.082618421123875, 43.502340778227776, 41.90556741529896, 42.38255116247362, 41.3251115429786, 45.67449838884416, 48.2318131385311, 46.86487497821931, 44.995751842375725, 47.37546559303038, 44.54425565658077, 50.23981563506588, 57.564175128936775, 54.365917636502175, 49.94854042606969, 57.10163747110675, 56.11393759327551, 43.980614985189135, 44.634623142980764, 45.278841064822295, 45.61692191708473, 46.0853039064715, 46.441737528770204, 42.32433926674628, 39.37903934909452, 38.96559015397103, 38.4990438338249, 41.228856578949966, 40.831987242544855, 40.68612606294694, 40.23337864106701, 41.27978855563749, 37.74057511360415, 37.180907803197066, 39.66848281122024, 40.149149663986705, 41.38124458251461, 42.443634233167096, 44.8577981610452, 46.518149222097094, 49.29740736561437, 52.157795813775834, 47.937713823010846, 48.425437019717315, 52.632822298234515, 58.88233077141547, 48.65322082273422, 45.48618931924143, 48.08783861898607, 51.10077588788925, 58.07873910473239, 59.1286007050545, 55.81015786816997, 59.44308850073046, 59.86091506096625, 56.59488293432421, 50.5960060704139, 47.359136766003026, 46.484989504660334, 47.15871933967837, 52.00847510368594, 58.29060985196022, 59.96907049609769, 58.96832481507332, 59.82994794845582, 59.95966073005431, 63.20662621528872, 62.56513041834678, 62.801104130283484, 65.71547615912654, 67.5051046186878, 67.46715176490046, 69.27889454749324, 63.23646368518953, 59.84815951316588, 69.0991872356784, 65.78449026230844, 68.64303127411874, 67.59427578218522, 74.67835087930003, 68.08688625212639, 75.690855826101, 32.28018279998533, 0.3453875537360868, 4.308001918177451, 64.87317462121287, 62.87424064451649, 40.17841446784235, 32.71307518405299, 23.54597245493243, 36.13586679581673, 51.094723670713364, 26.309537195390273, 0.8804001935547399, 0.042599556261613485, 0.013287864952167917, 0.024767480865721742, 0.027250873615905166, 0.009930654120961986, 0.11878768597999889, 0.03185703854767546, 0.02788416977461067, 0.033701330107907136, 0.027338182741415598, 0.025023605126226624, 0.09118558403344885, 0.03840592201618898, 0.009976590668121654, 0.0459064552260022, 0.07724967094198351, 0.18255735807601484, 33.43071791433519, 70.82614406462639, 53.439975477034054, 33.622894440927816, 70.19960034278132, 40.133393503004505, 51.51099697236092, 76.06967049260294, 44.8923267856721, 0.09873556438833477, 0.12857034532052855, 7.335190138509197, 41.9552638453822, 67.64977732012349, 62.96747538351244, 65.7576181042579, 40.06150038011613, 32.04158110003318, 57.137283971232755, 67.68680449455016, 69.62316097751741, 71.15341094232375, 67.43247016783684, 66.11230234945974, 66.90009470908873, 62.88274826542024, 58.3702104322372, 65.21025526908137, 66.44935161836686, 66.88854725130143, 64.78734923947242, 63.71494185539984, 60.97695489083568, 51.6451184980331, 48.97459237806259, 49.738925041690955, 50.0450974126016, 58.09847647143949, 62.87458189072148, 61.15484614526073, 60.519720277478626, 60.98668236886302, 59.207232459898925, 56.10646940046742, 55.5557882401251, 52.210277126681426, 48.604861920879735, 56.46569967269898, 59.80117736324188, 56.84185889459426, 55.53396417248634, 53.11604653635333, 51.01474654289984, 50.08478003163492, 53.63183821401289, 53.17393679772654, 47.556973272754306, 45.38985198543918, 44.01762254776494, 43.95725334844282, 43.42148111712548, 43.02385476327712, 42.47194982344105, 44.80540706265358, 43.990099276265795, 42.19293986597369, 46.43771317697341, 45.258605557103316, 47.96210312074231, 45.07428946033601, 48.10691310513405, 52.87287527515043, 49.07639357351488, 48.082778761463786, 49.74619711599043, 48.54491241516606, 51.03951631053802, 58.33229680215159, 56.01215600967408, 51.30588839131018, 56.42315372343987, 55.586300357695556, 46.689764684246434, 46.8753751631706, 48.30559292147237, 48.81439493548486, 46.76267370100945, 47.00096553371799, 45.655102268342056, 42.530138184947354, 41.76908070041288, 43.54267058833953, 44.85090655665244, 43.60084718273532, 42.17317504267539, 42.984164299503455, 43.218121913171586, 40.17583747063914, 40.582646093060895, 41.049219869798236, 42.730524232310636, 44.4747708689782, 43.122333711193455, 49.64248964863439, 48.88871208313973, 52.16273800019295, 54.44920132237097, 49.03610298710485, 51.517994480748335, 58.05667577251312, 62.94744383904242, 52.1106057782327, 48.15509550033077, 51.555417814562404, 54.77913148941533, 59.716387487226925, 60.86389257061867, 59.826158938869355, 62.877496211759514, 62.086248244008715, 58.75719539580807, 53.89067542168402, 50.4823906960026, 49.679822767934496, 49.00411605834962, 53.73194886792091, 57.535451612164906, 61.655838720260135, 62.62509169117097, 60.778177015243045, 63.263743769737985, 66.44916334459859, 65.53434894930932, 66.53187044205205, 68.88629667220577, 69.64478108190721, 70.87255354850524, 68.06858447290236, 66.10297495318999, 64.34615319774997, 72.83955943199896, 69.71171240652762, 72.98421644395398, 72.88800070362707, 78.39749520824802, 74.63896243802964, 78.78540977354973, 31.463984635568437, 0.30519655875621304, 7.074835463877648, 73.55777678951141, 70.13843490231422, 48.248083130005874, 38.30696144411641, 37.4467582087363, 44.58986105457429, 60.947399831587276, 40.65510011488392, 1.2603845230994688, 0.07000417989348212, 0.053211421510505105, 0.07058959364170028, 0.014036099197373036, 0.005020187095543671, 0.12033304620173671, 0.016507111009090178, 0.18956644971284176, 0.12271600865548658, 0.1722493692631683, 0.14092478480550552, 0.13223167869352526, 0.21092567052091324, 0.12685185688878262, 0.22357339910682172, 0.11690495595816644, 0.315961902059855, 43.10800529295399, 81.63137174421742, 58.460256284283055, 38.64532078466108, 76.68399995373142, 50.81991064933039, 59.74174953276112, 81.10825307907598, 46.50376589067521, 0.4548235814417563, 0.29724147110696764, 9.902239230371292, 48.04315497798305, 72.99238281865274, 66.59731126600697, 67.73170778828283, 36.95298279485395, 37.63635381575554, 63.726312806529386, 68.62624352978122, 74.46480135763846, 74.09482771350493, 72.16812810590191, 69.44357133680775, 68.44970549306562, 66.93283865528723, 59.59082849564091, 65.2960963403025, 69.77403102382537, 67.75078619680097, 68.54150464457851, 66.21849659950503, 65.47565852442096, 55.157267585877456, 52.65600742832307, 52.16980611124347, 53.005270957946784, 63.53404214305263, 66.26326653265184, 64.07927905359577, 63.94062719037456, 61.181537874283336, 61.63904313118228, 57.737802766984515, 59.998358834174375, 55.54256200790406, 51.721381141293435, 59.027227047950994, 65.16887034139326, 58.89949506328952, 60.1700056752851, 55.403604199809415, 56.22736469391854, 52.87112589805357, 57.49218002442391, 53.23219968426613, 49.849551570030954, 46.11185835253808, 48.25154658286802, 44.74263345041583, 45.382356336039884, 47.77850481771654, 45.38587862445463, 46.82052081631076, 48.37233989469467, 46.90036066116826, 50.576774689459036, 49.58377176715482, 51.053158313997336, 49.41558053416591, 51.6017488510378, 56.98867321014405, 52.588448524475105, 50.99061612159976, 54.12784545652328, 51.09870095406809, 54.87835961003458, 61.876268079203946, 57.70988725846814, 52.94424280043572, 60.184820467425936, 61.71708653050085, 50.3923213097357, 49.41399197424612, 52.26157780616514, 52.290650413882354, 50.07522906026533, 50.04076319356119, 48.417768786030436, 46.428919223047075, 46.616651704234464, 46.29717465369932, 47.246980513295824, 47.17493049560055, 43.78904250360305, 45.72582260254891, 45.197655846995694, 41.27554062874087, 42.465168045413115, 44.128515797276656, 45.40970702325144, 46.0762510761138, 46.434371317586596, 50.615629688386, 50.8306344093815, 55.496662432147616, 59.6117425733997, 52.54399238094207, 55.782611062449796, 61.341315623252626, 68.68245109435051, 55.089971480831025, 50.637320395438906, 54.94597734943513, 57.27773620236305, 62.22260944304928, 61.55237836222495, 60.72411106478784, 66.68590976345924, 65.52020096009778, 63.17245844871768, 55.96076119330622, 53.87126753407141, 53.381088933637066, 52.23984787541052, 56.667246741633264, 62.65930260381391, 64.37653587710473, 63.86478424072266, 63.726912929165756, 66.19125966102847, 69.74674701690674, 71.49592015051073, 69.85198420862999, 74.17127470816337, 71.76652446869882, 76.58989444855722, 68.77685469965782, 71.87315017946305, 71.27088592898461, 76.02367677996236, 73.36128957809942, 74.5911487456291, 76.7004660637148, 83.25377387385215, 75.84473040796097, 82.66992907370292, 41.89126253128052, 0.4205009425359388, 7.269494360493076, 83.50708053958031, 79.719435937943, 56.026449126581994, 48.38959440108269, 35.733102137042636, 52.15959618168493, 72.69487104108258, 52.166852566503714, 1.527848493668341, 0.11766075532162383, 0.1870708263689472, 0.22173063589199898, 0.15635178845015266, 0.12310069204578478, 0.26405699370849517, 0.17431189245995016], [0.05915285088121892, 0.04758387751456711, 0.050800381934330355, 0.06550777237862349, 0.061979320786532864, 0.0916071085920257, 0.14228780844038533, 0.09090563252327905, 0.05207086980883634, 0.16884939444641914, 39.60655643093971, 57.902965930200395, 53.48799313268354, 40.313885288853804, 46.01697621806976, 39.37162606946884, 42.50482320785523, 63.77745266883605, 47.56301372281967, 1.8163250915465818, 0.09575850841018463, 0.4998534941865552, 15.898107636359432, 52.19033579672537, 47.17626017908896, 69.56734564996535, 45.3233717333886, 52.740718856934585, 62.324128227849165, 64.02541314401935, 65.95440341580299, 66.3699471565985, 62.53907019092191, 67.43340369193785, 58.13662936610561, 56.227423529471125, 64.2458228911123, 63.72095092650383, 62.14459742269209, 61.99874408783452, 59.23110400476764, 54.10811593455654, 48.596785760694935, 46.193906491802586, 49.33328920795072, 45.97933323152604, 50.825229383284054, 56.9286766359883, 63.25766801834107, 60.4408767146449, 56.29997168817828, 63.738770254196666, 58.009968188501176, 56.081997732962336, 52.81436135691982, 53.40170491126276, 46.49014742143693, 56.03468610394386, 59.36746912617838, 55.866996934337, 54.763379250803304, 52.57579888066938, 47.78265468535885, 49.419444068785644, 53.19800446110388, 52.59783475629745, 44.64388778132778, 44.07001364615656, 41.67615582866054, 42.66768786215013, 40.94656359764838, 42.587365565761445, 42.84221372296734, 43.58359659871748, 41.80932029601067, 41.67264922972649, 41.04757247432586, 42.86145687103272, 41.82336630359773, 41.2998201001075, 40.873921302057084, 47.728286712400376, 46.472630116247366, 51.24012985537129, 51.01806486806562, 50.373682206676854, 53.02452195075251, 58.086277900203584, 51.66503237139795, 51.37969955321282, 54.56616640090943, 56.79137014573621, 52.148523330688484, 47.625897161422245, 48.93973427434122, 48.011340633515395, 46.98133014863538, 46.983161895505845, 40.664615784921956, 41.26509143460182, 39.84077292103922, 40.525740346600934, 38.93501527847783, 38.390586376190186, 40.736289255080685, 41.21591275738132, 40.270315600979714, 39.35675244177542, 39.50550440819033, 39.19687663355182, 41.97196529757592, 41.46248471352362, 44.361853676457564, 48.80361626225133, 47.48358964920045, 49.12255987044304, 46.59312925031109, 48.05191363057783, 52.93225603718912, 52.69498402072538, 54.36217569535779, 48.242850688196, 44.04843668783865, 48.9645746446425, 54.036289491961085, 59.1323269567182, 58.457455711980025, 57.33969788397513, 56.60574397733135, 61.66542499296127, 59.00481070241621, 56.372186445420795, 48.93272892121346, 46.00206728904478, 45.98411460076609, 48.87055543161208, 50.42397483702629, 56.069748170914195, 55.30694915402321, 58.93115643532046, 58.055306865322976, 57.04998377830752, 56.27810447446762, 60.53471157627722, 62.90412518285937, 66.39926295126638, 64.65424360767489, 69.91972354150587, 53.97009165056291, 63.12775519586379, 70.82933687394666, 68.92247661467522, 68.82825343839585, 70.46120674379411, 69.82652018147131, 69.93276934469901, 65.99522744455646, 11.703490653345662, 0.6708272198034871, 8.624332989415816, 69.60457678764098, 60.35405505088068, 40.205098352124615, 41.0356798479634, 36.891562400325654, 41.802001153269124, 54.90976995037448, 37.75592727045859, 3.098467492288159, 0.1348628689565005, 0.13409316509721741, 0.020509960633071683, 0.056330544663773435, 0.06180562950190037, 0.05751929478719831, 0.07014876366743157, 0.11198301724488698, 0.06192739917746475, 0.11734435334801675, 0.0808775186118099, 0.1068802587988396, 0.02254050157423462, 0.04665704519157449, 0.08384760318984909, 0.08989054304096969, 0.15549361675737366, 49.451697718712595, 64.55183444484588, 52.38401066872382, 44.41236988190682, 55.27166743432322, 42.73644701127083, 52.09757566452027, 65.69620555446994, 52.78653214054724, 2.4078817617508674, 0.4104702469081648, 0.5337055712457627, 12.130150391209511, 58.500476268029985, 53.54932723506805, 71.98465531872165, 48.686584503419944, 61.19814911196309, 65.11759319613057, 66.46326818773824, 65.47443082255703, 68.92576356087962, 66.4456332114435, 70.21027703439036, 60.880052735728604, 57.30602041367562, 65.45589762349283, 68.64992680088167, 65.01972613796111, 64.64621059356197, 61.74192297843195, 57.924146729130904, 51.16902905125772, 51.997017860412605, 51.90081388719621, 48.34681703198341, 53.97054272313272, 60.98650586220526, 63.56117317753454, 59.64378441533735, 58.183666429212025, 63.08655854194396, 60.33121901173746, 59.96699948464671, 55.881415567090436, 55.61897370123095, 48.347958441703554, 58.30144736074633, 60.415216568977606, 58.66404302658574, 58.18997752281928, 54.354738881511075, 52.46643927789504, 52.397738964326926, 53.96378055695565, 53.68363703450849, 47.4148226553394, 44.49552412955992, 43.01455090122838, 45.94901723246421, 42.96525847527289, 44.346485830122425, 45.66371187087029, 42.787002440421816, 44.07075105174896, 42.34537493798041, 43.45991642244401, 45.084660207071614, 44.49504167802873, 44.739966238698656, 44.21633766543481, 49.89114830570836, 50.6561085485643, 54.34162639802503, 51.55711227847684, 54.09178318515901, 55.07026549308531, 59.81620004100185, 54.34092429376418, 51.97665683684811, 56.629462549763346, 57.43461139740483, 54.19791075491137, 49.93224690037389, 50.264734452770604, 50.64521612659578, 49.076146464194025, 49.25949765789894, 45.47625003322479, 44.279044597379624, 43.7679950652584, 44.59726256708945, 42.99201688458843, 41.32653144098098, 45.50175720645536, 42.06478818770378, 43.46019883309641, 43.1894297753611, 43.550228995661584, 41.76451113916213, 44.32479512306952, 44.01611635761876, 47.77210350959532, 51.68018056500343, 49.80892758215628, 51.90095509252241, 50.77214402537192, 51.00471311999906, 56.17073743574081, 55.6415508639428, 58.541692533800685, 51.366755731644176, 49.555009026681226, 52.99615536966632, 55.27814326747772, 61.95664528877505, 63.49171976889334, 59.442280492474964, 59.51541700670796, 63.33215382791335, 62.48667517016011, 59.428552196871856, 52.584012323810214, 49.437522272909845, 49.86692374752414, 50.79472903282412, 50.83955387915335, 57.72294090640161, 59.03090230880245, 60.12199586437595, 60.695277721651145, 60.55784571555353, 59.740972903467, 63.67397662132018, 65.31607689396029, 70.9040266467679, 69.11320578667426, 72.22058588458647, 58.770464774101015, 67.73037418242424, 73.36577676957654, 72.04036081990888, 72.15788287501182, 74.3332136830976, 74.65664448276644, 75.34294943655692, 67.35996907757175, 11.832809236741836, 0.9064648949330854, 12.868521867259858, 76.90511180508521, 67.91624746014996, 46.69898617652155, 49.01676177978516, 35.160392945812596, 54.3050895198699, 67.5203626386581, 52.12029011018815, 4.562536285769555, 0.04449599925729056, 0.1899809798886699, 0.05383562229032959, 0.10321383094114643, 0.07726853202667928, 0.062491412259518146, 0.02135600515400931, 0.19275299243388638, 0.19501442269932842, 0.26064827016765074, 0.14670733903204242, 0.18816668450111346, 0.1893332372269323, 0.27729940570650563, 0.14515303856422826, 0.21605243816250758, 0.2886176499868593, 56.24037519578011, 75.28462379209458, 68.58919282113352, 51.021481252485714, 62.699322546682055, 52.095237931897564, 56.91402266102453, 74.4141714034542, 60.904489101902136, 2.4987442022369755, 0.5503652256823356, 1.2108822503397543, 19.271008660716397, 61.98762809076617, 57.686478553279755, 73.24878815681704, 49.98186488305369, 63.310667084109404, 68.3315166350334, 71.21819280808973, 68.1828195818009, 71.53686185036936, 68.45083513567525, 71.50247835343885, 63.147912256179325, 60.324652964069, 66.12774864319833, 70.62953918210923, 66.16398349885019, 68.72596586904218, 63.302892946427875, 60.47116525711552, 53.563361475544596, 55.6571775867093, 55.024754231975926, 50.50621517242924, 56.12290805385959, 63.11328949466829, 66.99529063317084, 61.46699620831398, 61.253995818476525, 65.24569388358825, 64.2151499563648, 60.46354016950054, 58.87856137367987, 59.2849346130125, 52.632751695571415, 61.24828484750564, 62.2384048277332, 64.38360791052541, 60.149683875422326, 58.455086600395944, 55.03548191439722, 55.39236660926573, 57.85319497508388, 55.87329233846357, 50.7089428747854, 47.340705548563314, 45.47767385359734, 48.08073520660401, 45.75074534262381, 46.5929292094323, 46.42334553503221, 47.23302472022272, 45.68106835888278, 45.087849094021706, 47.8473973274231, 48.44705712410712, 50.24206707554479, 48.90393480177849, 50.753453931500836, 55.82986777828586, 53.89651190850043, 58.13941032655778, 54.795789795537154, 57.74436881465297, 58.423703716647246, 62.89104800070486, 56.00199314855761, 54.879524553975756, 60.695387548015965, 62.53844653406451, 56.867895587798095, 52.74948143189954, 53.54926839951546, 52.86119837914744, 51.774415508393325, 54.63004612153577, 47.17401266098023, 49.693143137039684, 47.92943369957709, 47.44319315879576, 46.27244803213304, 43.39209471979449, 47.64903130069856, 44.39309535488006, 46.652235446437714, 45.051822123988984, 45.96893110582906, 43.89906106456634, 48.03933066706504, 46.987511804026944, 49.554279465829175, 53.45513936012022, 52.378503661001886, 53.461332782622314, 55.03064170960457, 53.974818106620546, 59.49198084492838, 60.557127921812004, 63.14715916110624, 54.34344245541481, 52.1128729081923, 54.95840341814103, 59.059582679502434, 64.97577205781015, 63.34011231699298, 62.95288024410125, 63.203554999443796, 65.70974165393461, 65.1507293793463, 61.41579358808456, 54.80206558781286, 49.24218431595833, 52.74370770300589, 54.940140862618726, 55.16774815897788, 63.217369587190696, 61.03564531572404, 64.69779760606828, 66.65466416266658, 64.45258671237578, 62.22499816648422, 66.99027784409063, 70.00257968902588, 74.62495173177412, 72.96628336752616, 73.39419826384514, 65.71448379947294, 70.11454766796481, 76.10609362202307, 76.44149549545781, 74.91845484702819, 78.04088115692139, 76.17854764384609, 78.77915751549506, 73.9400117628036, 17.818568714203373, 1.1199212603030668, 13.584406395112316, 88.2825348454137, 75.19939853299049, 56.35378660694246, 62.738812969576934, 48.303510142910866, 60.708739296082534, 77.28692316239881, 60.42834866431452, 5.61385553690695, 0.5416355618546086, 0.27326181591037785, 0.2569430093130758, 0.24477285993916376, 0.12321074823698691, 0.15288326408593886, 0.13554882408390123], [0.06068989521853867, 0.07531925194686459, 0.1049905420551377, 0.12043541087017906, 0.11353062976512218, 0.13483524382595094, 0.07947250569780027, 0.04291159153405217, 0.11803286720908458, 0.2762647579994894, 37.98221665043985, 57.40422871805007, 51.77701603981757, 25.069052327063776, 27.66638113606361, 40.45785588602866, 56.17247112335698, 64.66143331220074, 66.34366727644398, 7.869090908958067, 0.5366584418281433, 0.7620970352042107, 0.8220374704368654, 32.293097203777684, 47.42859017464423, 51.37265105401316, 61.68243631239861, 63.178777387065274, 59.88659089611423, 68.68564390367078, 63.14843785378241, 66.10994892735636, 64.8617369897904, 63.3345974645307, 53.775855879629816, 66.30361203224429, 62.205323557699884, 65.8798470035676, 60.50543500531105, 61.862218149246715, 53.5738734276064, 52.00399967931932, 48.59979029624693, 45.82382302130423, 45.53981596423734, 49.16493715778474, 57.13183579906341, 61.25134821861022, 59.60262698511924, 55.92016073965258, 55.778367057923354, 63.55294012254285, 56.61096857440088, 57.838642981744584, 54.170932692866174, 55.138910893471014, 47.31184082646524, 51.407316961596095, 56.872445537197976, 57.153483360044426, 56.25778659697502, 56.214993538395056, 50.44421818948562, 49.767966270446784, 53.20609631076936, 51.828665810246626, 49.52931750205256, 45.766748612926854, 43.28557883539508, 45.372993638438565, 42.851627411380896, 46.249910093122914, 45.060412114666356, 43.47058526931271, 43.52531017795686, 41.58252493027718, 43.44863176345826, 40.932360695254424, 41.19969767908896, 39.97188206641905, 41.17457882050545, 44.51878378468175, 48.11881749860702, 50.47857422982493, 49.66574538138605, 48.326671738778394, 49.48396705812024, 56.29921074836486, 52.82778763001966, 48.26616917887042, 56.05177587078464, 54.02421251420052, 51.122548964715776, 49.774477404932824, 49.46138205066804, 47.982656340445246, 46.131474125769834, 42.76365257078602, 40.60556450197774, 39.10965096565985, 38.34394547247118, 41.1965048697687, 37.83228797297324, 38.79040925733505, 39.555134157980646, 42.01707255455756, 40.95540462001678, 42.10780874375374, 40.70316876134565, 41.35418807306598, 42.0012261790614, 46.324709692308986, 46.21009019113357, 49.08857645527009, 48.13541696917627, 49.93602414284983, 47.94196959464781, 51.52329752522131, 51.75907119627922, 53.914613646845666, 52.71685515680621, 46.76402299634872, 44.72717146719656, 50.51711151676793, 54.237248205369525, 59.62552578218522, 60.58605540183283, 58.0800413316296, 53.97932490994854, 59.64080733637656, 59.341161789432654, 58.223764819483605, 52.476896316774436, 50.194433812172186, 48.400318161133804, 48.12991388382451, 46.820512971570416, 49.97321997919391, 48.692522971860825, 52.957492566877804, 52.59719148758919, 50.823378024562714, 52.886658483935946, 56.779489286484264, 61.2203065810665, 65.69285977271296, 68.5635091412452, 69.32506084442139, 50.96466964290988, 69.4322592212308, 66.16115154758577, 71.33379290180822, 66.93742782838883, 71.81632288040655, 67.02035457857194, 70.9698518629997, 54.6171768250004, 3.059574495400152, 0.5039673556964244, 20.689510299313454, 71.71940895818895, 62.70832830859769, 43.44926718742617, 37.697464343040224, 47.47350915785759, 27.06423651787543, 52.55508484378938, 57.95596499596873, 6.194595781064803, 0.30118210481539853, 0.04985547759720395, 0.1303350441758671, 0.10236361124102147, 0.014848854325170961, 0.054621720431192275, 0.0852957621757542, 0.0704069889240688, 0.06031908568054919, 0.06338194733665836, 0.07195475466188885, 0.1234373264014721, 0.03270698245614767, 0.0626802376110948, 0.11434928664276678, 0.035132987559923244, 0.22167570738782807, 44.668230010617165, 67.29112363630726, 52.653520645633826, 31.647490762895156, 38.414834468595444, 47.75974019881218, 63.57345019617389, 69.02497599201818, 71.0281696627217, 9.729893226777355, 0.49404587356313584, 1.6870138625944815, 0.4652577909010072, 28.430233309345862, 52.77583583708733, 59.98268112059563, 62.879975149708415, 64.12704175518405, 61.367509211263354, 70.44283436190698, 63.42214084440663, 68.02731329394926, 65.5824960431745, 66.33842698989376, 55.47303799659976, 68.043104756263, 66.23441357766428, 68.14322717728155, 63.07311657936343, 63.81045156909574, 55.73462086339151, 52.22542139791673, 52.29534549097861, 48.47066979254446, 48.277626422143754, 51.6125589032327, 60.565635542715754, 62.72588483748898, 62.83075724878619, 58.17524510045206, 60.04141076918572, 66.49629454458913, 59.69540280680503, 61.067106646876184, 55.91254741914811, 57.42352285692769, 50.903778768354854, 53.55189638753092, 62.067228671043154, 58.931168202430975, 58.753543669177645, 59.667738329979684, 54.00198052006384, 54.761716165850245, 55.55987142747449, 52.64021204363916, 51.24198905883297, 47.55213306796166, 46.47643873768468, 46.09645128250123, 46.67266707266531, 47.595914563825055, 45.638400816148334, 44.16195008062547, 45.32812956840762, 45.144225320508404, 46.61815789438064, 44.22181721656553, 43.981203340714984, 43.07481811892602, 44.08067072591474, 47.31987384057815, 50.00218276054629, 52.45220107416953, 50.347594522660785, 50.19504570191907, 50.998605989640765, 59.25921563179263, 53.86165380477906, 47.71862983703614, 57.041738956205315, 57.37442262711064, 53.373922763332246, 51.66997455781507, 50.23242981203141, 49.9890467428392, 48.572310170819684, 45.44925235932874, 45.32067314271004, 42.54470586776734, 42.47951607550345, 43.85805660678495, 42.57873242901218, 43.459912500073834, 42.31853808126142, 45.4758381843567, 42.858083632684526, 43.87736643514326, 42.928411729874156, 42.83684007583126, 44.50629103568293, 49.02217465062296, 49.29044908092868, 52.406819251275834, 51.56423922507994, 51.30737889197565, 51.232747954706994, 54.21617331043367, 56.46069865072928, 58.13684901883526, 56.89253199485041, 50.86688887688422, 47.824647580423665, 54.89600635343983, 56.74629426771595, 61.710696989490145, 60.88016648446361, 63.22956031368625, 56.246996156630985, 61.56360810802829, 63.334342510469504, 61.922155887849875, 56.9380275664791, 51.539049763833326, 49.82951610319076, 50.771673340951246, 48.31002912213726, 52.6675784203314, 52.53121722129084, 54.615596109820956, 54.84416438687233, 54.08557799554641, 54.53457170917142, 58.87168153639763, 63.869114537392896, 69.84844623073455, 71.7459555595152, 75.40286756330921, 55.31418592699113, 72.93295106580182, 70.65346564016035, 76.04977623108896, 70.67595651072841, 74.99123050320533, 69.71648200865715, 75.0271515692434, 54.72719146359352, 3.1728084193122004, 0.6137647011107015, 27.72385366501347, 77.57848862678775, 72.60635883577409, 46.27629979964226, 46.704312755215554, 42.10134467770977, 27.799880966063473, 66.90719419910063, 64.54147938759097, 9.996275113474939, 0.3688808656748264, 0.1686580103611754, 0.08424380088164922, 0.14450206301145016, 0.1419782323101836, 0.07572065137567059, 0.08270487579847537, 0.31504795916618844, 0.1813245847100212, 0.18066625471317, 0.23871610752276837, 0.3813950344920159, 0.1814471128126306, 0.25959186556358493, 0.3242772655381311, 0.1906779820039388, 0.39237371796081144, 58.17447239352811, 76.55012161500993, 70.57348851234683, 33.81722434874504, 43.66734704663677, 57.15287539266772, 71.47495115956953, 75.7118954197053, 80.48261150237053, 10.455090442011434, 1.0724314085898863, 1.8666690804304618, 1.2209307498508886, 38.225266318167414, 53.37973179355745, 65.84966828746181, 67.88646098106139, 66.85495607314571, 64.11700048754292, 72.71541641604516, 67.82107507028888, 73.47821543293615, 67.59371880562075, 67.45335286663425, 57.15955911144134, 68.12965577648532, 69.06309358535275, 73.09600399386498, 68.53848441954582, 67.36880225519981, 62.03959557317919, 54.50711511796521, 54.99424603677566, 50.70094516200405, 51.01338548045005, 55.487072237076305, 65.31732813004525, 66.361035531567, 64.32550584116291, 60.68722901805755, 60.94199480548982, 69.5007751834008, 61.94421529769898, 65.05166207590412, 58.740584158128314, 58.47338053487963, 54.55013567401517, 55.86827562701318, 62.96412175701511, 62.468914678019864, 62.36243017258183, 61.94100679889802, 56.24614500230359, 57.71136206965293, 57.589368512553555, 56.42996688042918, 53.17159514273367, 50.63209187599921, 49.6556648900432, 47.42662898955807, 48.84928441816761, 48.605909193715746, 47.88069432781589, 48.57287106975433, 48.18062620778238, 45.785677971378455, 49.69939147272418, 49.85597249000303, 48.995722186180856, 49.25149210037724, 49.83149297775761, 52.77044650047056, 54.19791467728154, 54.86470583946475, 55.30657652885684, 52.0701975207175, 52.74409601765295, 60.17780334718766, 55.87220976429602, 51.02172836180657, 58.636841389440725, 59.25707794004872, 57.00470001466813, 55.9716026244625, 53.76873677776706, 52.87258501975767, 52.64497772339852, 50.5694398572368, 49.791143555794996, 47.129383933159616, 46.79233858662267, 47.44897865479993, 45.37963813351047, 44.06577748637046, 44.70187610195529, 48.40351489282424, 45.35834750821514, 46.80607472696612, 44.44946373662641, 45.01144916780534, 47.68172425608481, 52.451761768710234, 50.612507481728834, 53.77893886258526, 53.78679144767023, 56.78987180033038, 54.10627634294572, 58.261937326000584, 59.83670226989254, 63.44094860938288, 60.14478875744728, 52.85184744865664, 50.92739928153254, 57.27001697786393, 60.296000049960234, 63.830157556841456, 67.06458322463497, 64.04334229807701, 58.73062133789063, 65.13953101250434, 66.10996461683705, 62.02619675667056, 59.2679899738681, 54.980294166072724, 54.45228430532641, 51.95788045083323, 52.33587141959898, 55.72684672570998, 55.06694324554936, 56.58521429184945, 59.29930617732387, 56.7122833959518, 58.680469912867395, 61.04291346765334, 67.0739027761644, 73.41124488461402, 75.88564857359856, 73.72494036151518, 59.621077814409816, 75.38703687729375, 75.6191784335721, 79.55380209030645, 75.65588397364463, 79.58912695607832, 77.13881446469215, 76.95133301519579, 59.81694529133459, 5.663020976128117, 1.1511199152277363, 31.242078504254742, 89.57861931093278, 81.30110033096807, 60.18319268380443, 56.854673277947214, 64.82710638353902, 37.99543503792056, 74.32500808469712, 74.79996004412251, 11.700935229178398, 0.4717825004650701, 0.2951871297292171, 0.22906850182241012, 0.2208392619485817, 0.1830903867319707, 0.22869900229477116, 0.21574244834482673], [0.0182075523245599, 0.03488810755492699, 0.09661766069550669, 0.04426902655752436, 0.07570988017945521, 0.1463645300076854, 0.05267949985159982, 0.025010631427228935, 0.21067610971869963, 0.5842188349173916, 38.26203853853288, 53.88622745390862, 46.44110210480229, 38.09321972631639, 25.835928647748887, 38.99021479391283, 46.14708515905565, 61.642808606547696, 60.161164652916696, 32.216626674898215, 0.6161252325100284, 0.42334763333201414, 0.47240585088729864, 4.563249666844645, 32.952879090462964, 52.32818749643142, 42.35742053677959, 58.222674400575706, 60.64434182259345, 60.20894696635585, 58.59128305988928, 57.964758949895064, 61.35041944442257, 54.182786095526914, 58.94654781587663, 65.82546726349862, 62.893879951969275, 65.55045812360703, 60.83338437541839, 53.92672984830795, 48.14811368142405, 51.18420077908424, 44.907765234670336, 45.80345807536956, 47.26322697054955, 50.197340288469874, 58.72864838569396, 61.79816192196262, 58.79335964879682, 55.048053110799486, 57.125709056854255, 62.21372527460899, 58.27728163811469, 57.82980980411653, 55.32143446706957, 54.08953566705027, 51.56723983826176, 51.366865558008996, 58.250703657827074, 54.855401977416015, 57.089823292147734, 54.853440792329856, 50.57917518000449, 51.41293771805302, 52.24655512840518, 54.722547377309496, 49.45797743335847, 48.40438958137266, 43.73402341719597, 43.21287378188103, 42.695595525926166, 45.670454425196496, 46.27071434451688, 43.045294438639, 42.625538072278424, 45.38852622432094, 42.04357993218207, 40.70760496201054, 41.19523402183287, 38.50517449840423, 39.079782116797666, 43.11184137098251, 44.83717826104934, 51.2833426075597, 49.72912696100051, 49.99446745841734, 49.66052862905687, 51.85272955125379, 53.5292996129682, 49.295112779063565, 56.696786111400975, 51.18826435458276, 47.95360726694907, 48.762800078238214, 48.58197489092427, 48.867378311772505, 44.98359641721172, 41.880319118499756, 38.37719148205173, 40.40792019136491, 42.19235935518819, 41.806543257928666, 38.77211532285137, 42.479704349271714, 39.613593163028845, 38.58210394459386, 39.66908685622677, 40.40338985381588, 40.14410157357493, 42.560642457777455, 41.26346757335048, 44.871593136941236, 47.12843864194809, 51.00073583664433, 49.55997866968955, 50.00807808291528, 51.661596375127, 54.31753520042666, 51.912620221414876, 53.72043278909499, 55.04797074102587, 50.86852450524607, 48.430536100941325, 50.86889713041244, 54.25542839111821, 59.101532428495354, 61.177423307972575, 58.68645152738018, 56.225121098179976, 55.804803832884765, 60.105251266110336, 61.61213174943001, 57.53323939538772, 54.388483032103515, 48.5071203785558, 48.490097292007945, 47.39063339848673, 49.89459214671966, 48.69251120475031, 49.20722030824231, 48.584563655238, 52.6326536363171, 52.833765322162265, 59.54488969618275, 59.777023407720755, 64.42462021304716, 65.62627361666772, 69.43280050831457, 54.25071370217108, 67.13857481556555, 67.4127955590525, 71.64726872597971, 63.49699927914528, 73.27365598370953, 62.07140599527667, 71.29527522671607, 36.61403117641326, 0.0998313842161048, 0.027192237246180737, 41.080669433839866, 67.31050798969885, 60.7993931155051, 40.14474484228319, 43.19447786577287, 34.3229982929845, 48.82922933947656, 59.45578521297824, 52.403465624778505, 8.786606346407245, 0.12220154230993603, 0.054261222436663606, 0.15310720690796453, 0.1003668720142976, 0.03635492461222795, 0.04722111189978258, 0.06439067828919619, 0.06993029837406452, 0.10026350377067443, 0.09054246088189465, 0.009710764861665666, 0.08848643411071071, 0.05398024436867526, 0.016888948382749673, 0.056432120261653784, 0.03170610198961391, 0.6299203922671657, 48.15394624587029, 60.74084389594294, 52.98599643092002, 37.817394733428955, 38.09296869462536, 53.26327662314139, 54.76823514507663, 67.03813076019287, 66.08712073295348, 36.49617964221586, 0.30615150267558716, 1.7042108817446617, 0.6242149984163623, 2.5806111770291484, 30.04257652067369, 54.249411475273874, 51.569342228674124, 63.10884544926306, 64.62236258291429, 63.19600443686209, 62.76674024520382, 60.11079749753399, 59.775615276828894, 56.29457450682118, 59.90275106122417, 68.7644443204326, 66.59692687373008, 65.14063712089293, 61.10824054287326, 55.700974772053385, 50.57395450530514, 52.38130031093475, 47.20564265404978, 49.2526884232798, 50.62490217147335, 55.68461848843483, 61.36770532977197, 62.270611409218084, 62.88676085010652, 56.969998805753654, 58.1420853830153, 64.65757762232136, 61.31929151473507, 59.706028507601836, 56.57727149225051, 56.774284301265595, 54.560224010098366, 54.076937014056796, 59.71212387084962, 58.758764343877, 59.29158695282475, 57.27280186068628, 54.79078877356745, 54.80240683401785, 55.382458702210464, 56.789346202727295, 53.307528803425456, 50.537790252316384, 45.80991821904337, 44.958865873275265, 44.423160322250865, 47.9664961753353, 48.77210394028695, 43.76603388017224, 44.889082985539595, 48.19884953960296, 44.851859692604314, 44.9093851735515, 44.68351156480851, 43.84114334660192, 44.47369221718081, 47.12760709947156, 50.510435642734656, 52.835298968899636, 51.351587926187825, 52.576575509963504, 50.344562530517585, 53.52227857035976, 55.47782328820998, 47.80657722103981, 58.330641561938876, 51.969318082255704, 49.4258963677191, 51.33028945615215, 50.49261631504182, 49.08818421825286, 47.52776338208107, 44.78805841938142, 41.72767616087391, 44.66724157333375, 46.28152439671178, 44.98637345529372, 41.997578374801144, 44.47073082770071, 41.62460411748579, 41.69268861893685, 42.6933793867788, 44.010781934184415, 41.294968128204346, 44.116642782765055, 44.913476205641224, 46.46637785819269, 49.86701396203811, 53.97244115029612, 53.65004193398261, 52.87203588793355, 54.4169633619247, 57.70946364248953, 56.80588291537378, 58.20671035397438, 58.04081762990644, 52.764111872642275, 52.04010117438532, 53.802402480956054, 55.41445347570605, 61.12303572316324, 61.02592960480721, 61.44936907675959, 59.28611916880454, 59.69213547245149, 61.49797508793493, 63.267862258418916, 61.952236544701364, 57.787310923299486, 53.05914078989337, 51.585988767685436, 49.89368607920986, 51.876914885736284, 50.3836646387654, 52.6711634666689, 51.62976634117865, 55.79219733515094, 57.2987836407077, 63.10470342636109, 61.39888425027171, 68.09233050192556, 68.54898068212694, 70.37736215899068, 59.595676545173895, 70.92832965235557, 70.55498276987385, 76.1478276406565, 68.2102761730071, 78.06661974999213, 65.48886906716132, 76.35179873435729, 32.53772366431452, 0.0389328909166638, 0.06664901355942411, 52.15579148261778, 74.29635909295853, 73.89528889809885, 45.17282724380494, 59.427771645207564, 35.605915361835116, 45.79854334554365, 68.53585643153038, 63.391738553201, 13.87783302414802, 0.2615569423763983, 0.12018040318282382, 0.06665377862631314, 0.04909852527142052, 0.016362456372007728, 0.018799809153161703, 0.09571039042766057, 0.17587969139699014, 0.20737664563761604, 0.26324601303185186, 0.12918372127798297, 0.13522317542904808, 0.23732239440564187, 0.1310225468008749, 0.13779654137549863, 0.26237279537224, 0.9623602633514713, 56.932791202299065, 71.49599859791418, 65.71000445273616, 47.83362980811827, 40.78683683949132, 56.39007637577673, 61.401453402734575, 72.1462961935228, 74.18221812094413, 39.65325224784113, 0.878442072820279, 1.975347171387365, 0.7430525797028696, 6.953428301119036, 37.175220366447206, 58.167549410173976, 55.358979394358975, 68.23000569497385, 68.12775734932193, 69.17924281089537, 66.61423237093034, 60.83319610165012, 61.54476896409066, 59.107521887748476, 59.67563798350673, 71.59516396061068, 69.39982121990573, 70.21431707566785, 64.87984657287598, 59.05387170853154, 52.87928835038216, 55.4267579509366, 50.71945090447703, 51.75705117564048, 52.644730614077666, 57.75398254394532, 64.83159749738633, 65.94742159689626, 62.18488800910212, 56.89506192361155, 62.70977958556145, 67.04835245686193, 64.17953875757033, 61.90995731661397, 59.77672922995783, 57.41501915839411, 56.667007477052756, 56.9079351425171, 64.1953851330665, 63.12403678894044, 65.1003465344829, 61.16053358201058, 57.150188569099676, 58.43302719054684, 59.90382186828121, 59.68760905727264, 54.752282865585826, 55.491833994465495, 49.470721214048325, 46.47668976937571, 48.244517695519235, 50.57315826416016, 49.293347712486025, 47.08890899535149, 47.87389293793709, 50.16427863028742, 48.531603813171394, 49.088803952740086, 47.47818462310299, 49.141112681358095, 47.94956330330142, 51.66436164609848, 54.006302971993726, 58.44688100199546, 54.71487522125245, 56.76432540339809, 54.48303960984754, 56.43844312237155, 56.77225643588651, 49.09692718136696, 59.82837900038689, 56.48770809173585, 52.641561338978434, 54.476453950328214, 54.79154971338088, 52.83817406623594, 51.59051518286429, 50.55663331862419, 45.37114620208741, 50.05991612711261, 50.33899276487289, 47.787369374305975, 44.560458967762614, 49.05690331612864, 45.719076125852524, 44.093359593422186, 46.15485145199684, 46.560593189731726, 44.11226934002292, 47.388480017262125, 46.003287146168375, 49.387104126714895, 54.32805107485864, 56.53937355164559, 57.11356147643059, 57.301392016872285, 59.76498565366192, 60.40265713968585, 59.920770429795795, 61.7957849656382, 60.14915435544906, 54.83868091337143, 53.973088341374556, 56.801305509382686, 58.2609292768663, 62.82890981243503, 65.85175498839348, 64.33931258416945, 60.79725934613136, 60.79869101124426, 63.43502975279286, 66.42733927695983, 62.30238260761384, 61.59617162519886, 54.49285338001867, 55.07883194954165, 52.89073382654498, 55.219786244054, 53.7329569170552, 54.762590854398674, 53.73740096246043, 58.38340528549687, 58.821149641467684, 66.07529870925411, 65.17396157787692, 72.95711286606328, 70.6017295775875, 76.21072676873978, 62.63527416413831, 74.26805526979508, 75.73749280744984, 79.84167268199306, 72.66899124268564, 82.926193206541, 70.49502541941982, 75.26749087918189, 43.221353946193574, 0.48540853865204325, 0.21965237724925243, 57.07970749947333, 82.53327369689941, 77.86352726720995, 54.759543172774784, 69.06146972410141, 46.57472941183275, 72.4606349391322, 80.31464776685162, 75.91963983351185, 18.93622652176888, 0.3851034822723558, 0.3265358766000117, 0.2537297607669907, 0.17627024302078834, 0.08652432971904356, 0.16962001761121137, 0.20788269267687876], [0.03358740900312701, 0.05856476731658463, 0.059949892588079944, 0.06920829880982637, 0.015535505634972887, 0.10166647122992624, 0.030528827863294753, 0.08874754751882247, 0.08206386704959216, 1.5234942950548664, 40.88630814706126, 57.62922371587446, 45.6369456168144, 40.21984646397252, 19.66238864006535, 34.74621418983706, 33.54901267636207, 63.373013157998365, 64.57148159703901, 57.88304421209521, 0.6172882152661201, 1.9411041443386388, 0.2787383333329232, 0.11684751468560389, 4.826613779990904, 32.23946075285635, 44.37407185954433, 39.46975200406967, 50.37985209495791, 57.906354858029275, 60.48719990637995, 65.40828789434126, 62.5752579781317, 59.7454640173143, 63.15569031623102, 65.31419807864775, 61.583886761819166, 62.316036378183675, 56.24769826089182, 52.288085183789654, 51.08253686658798, 48.457702436754786, 46.74299124748477, 47.453716877968084, 48.658327748698575, 58.0073441228559, 58.70394922071888, 61.53845002574306, 55.48062386051301, 56.17174156250493, 56.745843195146136, 61.30668501700125, 59.95592271128009, 57.24398812940044, 54.025487284506525, 56.69306378210745, 54.09738040739491, 49.77315948855493, 58.91566307313981, 55.8796779571041, 53.45401363988077, 56.86806817208567, 53.487812703655614, 53.189147749254786, 52.3521767124053, 47.9328893076989, 50.759466924975, 48.39894533157349, 49.97105483085879, 40.801498659195445, 41.49768014107981, 43.681600939842966, 42.105114075445364, 46.22501088726906, 46.21092173361009, 43.85088259173978, 40.78386368290071, 41.07185979043284, 41.22161196124169, 38.33406502200712, 43.105361615457845, 42.67045313312162, 46.51135959932881, 49.669644217337336, 52.29871088458646, 53.333200716203265, 50.5931152835969, 53.65707866607174, 53.231372064159764, 51.20181614352811, 55.42811901338639, 47.15354965579125, 48.85230856557047, 48.87668217382124, 48.09470276678763, 47.41532864109163, 41.97999046694848, 40.83497608861616, 39.874454313708895, 39.23756337934925, 38.6077013323384, 42.80393531245571, 41.957315244982325, 42.24715878886562, 41.522328315242646, 41.84288401757517, 40.91416874239522, 42.4936483752343, 40.921201552114184, 40.034569386513006, 44.53599906736805, 43.57901134798604, 51.38751683696624, 51.235297495319, 49.93148203819029, 53.06884473369968, 52.52071703633955, 54.94224717540126, 52.67353257825298, 50.737250620319, 56.43880005805724, 51.72632725008073, 52.13898020405924, 52.306943939578154, 54.06168291645666, 55.907730748576505, 60.665240210871545, 60.17026847408664, 60.04798858396469, 57.49355285398422, 59.05007485420474, 57.73282527923585, 60.95258520495508, 59.075370219446, 53.070951046482215, 50.532024368163086, 46.57900479532058, 48.05364339582382, 49.16622761757144, 51.56631808127127, 52.14587573082217, 61.76832445206181, 61.44637238594794, 59.98636814855761, 60.42938024766984, 61.306355537906775, 68.39290172823014, 67.21528068665536, 59.91786787586828, 66.06704604241156, 64.02412660660283, 70.37912722556823, 64.88717356035787, 67.61630381307295, 63.234243623672, 65.38479681937926, 8.642336668506745, 0.21799653948795414, 2.2752909410384397, 60.4067873954773, 64.81058536037322, 53.134611114378906, 21.873438512125325, 31.343175634261105, 51.20493050544493, 33.30793596083118, 44.6551763626837, 58.67280952392086, 17.342665580011186, 0.15911385717411197, 0.06946232590463854, 0.04361016796000543, 0.04517883640683947, 0.012036700687942006, 0.10377550362459115, 0.027813569026728793, 0.06948028300558368, 0.05076863908118779, 0.025482779075842232, 0.10594151763906402, 0.08598374743615428, 0.0734709116119531, 0.03968040120878047, 0.08989726163206563, 0.0027037402258194504, 2.0411628268418776, 52.809054390076675, 64.77826895252352, 54.174086278484715, 35.869490792674405, 22.862905417719197, 43.765092511330884, 38.41733694076538, 69.86670878625685, 67.71941508016279, 64.39957587949692, 0.8879403986277119, 1.6946089195628322, 0.3476215886973566, 0.2918322468476911, 2.858472125184152, 30.69612183878499, 46.69706813750729, 45.237695401714696, 56.00281292392362, 65.27199337559362, 63.906820281859375, 66.87478757673695, 63.67793821519422, 62.380539755667414, 66.36019614435011, 67.56576799577283, 63.83136564685453, 64.42829939626878, 61.44374832030266, 54.461560710783935, 53.000171876722774, 50.33662365328882, 48.94725345796155, 51.00495238457957, 48.292609876202, 59.59207580935571, 60.78768876291091, 64.42130188788137, 57.427825697006725, 55.6571069840462, 61.541811496980735, 63.458693412042436, 61.10557333115609, 58.30939408271544, 56.96025563824562, 58.725824279169885, 55.00717416886361, 51.733218854473485, 61.37334177570959, 59.5845958494371, 56.67684478144492, 59.16647511143839, 58.7127588641259, 57.44491154147733, 56.69413851153467, 54.324340512675626, 52.58094895270563, 50.05504846572877, 51.358538366133175, 45.16665343315371, 43.42858845187772, 45.724418394027225, 44.81278111857753, 46.27699798153293, 48.515220072961625, 46.86422386477071, 42.626514742451334, 44.07186108250772, 45.1846767240955, 42.91196523174163, 44.8663842293524, 45.34879653684555, 49.69968172811693, 51.344453134844386, 52.9573082154797, 56.640213766405665, 52.9098161574333, 53.36436002485214, 52.43819821265436, 49.07608370627127, 54.84843977036015, 48.521546856049575, 48.66295222313174, 51.83438070358769, 50.366888661538404, 47.97947922060567, 44.6496222865197, 44.21265848221318, 44.46374900879399, 42.65567364231233, 41.06096736846432, 44.20190334320069, 44.417155173517045, 44.6287238982416, 43.32917990223054, 44.83607607503092, 43.3500272996964, 43.93391132354737, 42.93858243573097, 43.39136515894244, 46.71104354243125, 48.4207066412895, 52.464242750598544, 53.22927359611758, 52.795914449999415, 55.21727200477354, 53.23104258506529, 57.16856879572715, 55.24796847374209, 55.44669143615231, 58.65756327106107, 54.13191295439198, 54.103985678765085, 55.25929235642957, 56.37247670081354, 57.02677119162775, 61.12533423208422, 62.23347833079677, 62.282088264342285, 58.942331267941384, 59.986819221127426, 62.360747475777906, 66.03401184082031, 61.63601113903908, 54.153619350925574, 53.517599182744185, 51.32289971074751, 50.828151549062426, 52.63538752832721, 52.613641908091886, 55.81139341477425, 64.48213000451365, 65.63879774462792, 65.33009936732631, 63.513641895786414, 65.68725470573672, 71.02221550480013, 73.34583543962049, 63.59132051467896, 71.62642525088403, 69.37583200393185, 74.30529425221106, 69.61857964915615, 71.34013145200669, 65.76151694020918, 67.0383268787015, 7.927396451273273, 0.23227453382024843, 3.7688380624017412, 72.91886191214286, 69.9652857934275, 61.023580105074, 26.371375322341922, 38.295135498046875, 55.66616373677408, 39.693754642240464, 58.98184130268713, 71.02898551571754, 27.704437932660504, 0.27239301091720985, 0.0845935276799625, 0.0030978407519268655, 0.08477919674929112, 0.03864204180577109, 0.07450300058530224, 0.0988052477459273, 0.11315822676425019, 0.22970815459566735, 0.1111332418757581, 0.17073124346713867, 0.1897744579060424, 0.17804788876204722, 0.2448743972326479, 0.2169278008683074, 0.1655316668292207, 2.7532945044579047, 66.55007023965159, 72.65746731911936, 65.42082378941198, 53.16197356870098, 32.12924803456953, 50.38228004209457, 46.70883917039441, 75.06188807948944, 74.3851693984001, 70.25063037872314, 0.7937489690319185, 4.5037125002953315, 0.5730620206844422, 0.44103439717042836, 6.29350422851501, 37.93756831076838, 49.73776009774978, 50.18038388221495, 61.9744332375065, 65.38394566505187, 65.86644034231863, 70.27534915554908, 69.6282914377028, 63.82373663686938, 69.65649327924176, 69.58803223025414, 68.13947739139681, 67.10309305498677, 64.51653311329504, 57.806550148994695, 57.51037982202346, 51.89605997454736, 52.505278587341316, 52.43335800786173, 53.11746643435571, 63.26610111421155, 64.11640036490657, 64.3198811623358, 58.657453444696245, 57.613008637582105, 62.360551357269294, 65.299567637905, 64.94614639589864, 61.269555860950106, 58.70274505307598, 61.98183475002166, 58.49796987348988, 55.27612716920915, 64.09398401937177, 63.608896655421105, 58.57978659291422, 62.898304385523645, 60.119497314576186, 60.166836400185865, 59.69983116272957, 56.508535877350845, 56.332327319729714, 52.65638005348944, 54.4898174655053, 46.79527644188174, 46.17524385452271, 49.24876213073731, 49.24507902514551, 50.69191978823755, 51.49913964733001, 49.18056780292142, 44.914025337465354, 45.376700278251406, 47.629038979930264, 46.019525758681766, 50.338722121331, 50.31785118964411, 53.11252032556842, 55.09473323822022, 57.037447883236794, 57.84770757921281, 55.024240401483354, 58.62039881367838, 56.73947326598629, 51.616100803498306, 58.95447492599488, 51.75538809068742, 52.86417153573806, 54.50712296270556, 53.98014468531455, 52.459159358855224, 46.98193811601209, 47.66818031187981, 49.6377984939083, 45.21606745258455, 45.93066446242794, 49.94766573752127, 49.502806202057876, 49.583928661961714, 46.771965795947665, 48.42672355713383, 45.85512745764948, 46.471080780029304, 47.422388907401796, 46.93060605756698, 49.153523060583304, 49.796458367378484, 56.44304798495386, 57.033411764329486, 55.57186603546143, 57.04644580041209, 57.41305405093778, 63.20933265070762, 61.17238698467132, 59.618010520935066, 62.41802192503407, 57.43945944693781, 57.30091741008144, 58.573569636191095, 59.16971106683055, 60.954154153024, 63.941729376392985, 68.61631208850493, 62.56453029571041, 62.49710867481848, 62.869898580735736, 63.91270775948802, 68.85174843572801, 65.74553328175699, 57.4221617944779, 57.01017172105851, 52.209241620955936, 53.06888003503123, 52.94102645689442, 58.19918724798388, 57.25375875349968, 66.87638790376725, 68.60298387465939, 68.21226873705464, 66.98774399295931, 68.84964604531565, 73.61570235221618, 74.40057646843695, 65.28600800421931, 75.32875830127348, 74.5319523349885, 80.67019493349137, 73.77932794632451, 77.486783612159, 69.79946367202267, 72.96674620720648, 13.591517652234725, 0.5073287656470653, 3.8146339404967526, 79.04929899400281, 81.38789453814107, 68.56050460569321, 35.01743432014219, 48.117923198207734, 68.02381453975555, 48.122716334558305, 65.53929113572644, 84.57345531832787, 33.818808986294655, 0.3324467658756241, 0.21848590113222602, 0.19675494381977668, 0.12605795997285074, 0.10256689267172929, 0.2006985959146292, 0.17754553426657954], [0.022194630113400282, 0.020436607714321826, 0.056837721682724454, 0.0858765640746682, 0.059361341709811846, 0.07616099105366776, 0.03874911408450815, 0.07785346313950517, 0.0977612078009594, 4.515697302356843, 54.10877489274549, 57.65831593544253, 44.98187449670608, 33.1056240297133, 55.72355193476523, 46.484640413715, 27.340371378006477, 59.30526817998579, 62.25569071308259, 72.11704315677767, 5.821548959901256, 1.3581693340693752, 0.4449598623379585, 0.23346753190121344, 0.32136285256954933, 5.910610297033864, 33.75140697725358, 35.2066808362161, 42.30968136941233, 52.95378984943513, 62.29074493531258, 63.51929403120472, 59.420636853864124, 62.98122329096641, 66.37739181518555, 62.63153614536409, 64.58136204750308, 58.93451398418796, 54.475610640741166, 49.93630655350224, 46.54269149226528, 45.965138173872425, 45.923486525012606, 47.67920217206402, 55.80799271983486, 56.17812325877529, 60.52032432248516, 61.363884941224136, 51.42782311285696, 59.555668369416274, 63.0567838299659, 59.17756365191553, 60.32827331173805, 55.84036796323715, 55.47335178621354, 56.11060750099921, 56.46056529014342, 53.52922508793493, 57.48137389459918, 57.193762179343935, 57.60297129231115, 57.748412778300626, 55.66686584103493, 53.43545298422537, 51.0607284884299, 51.04546262371925, 51.621133204429384, 48.77273544188469, 50.96044917260447, 46.212643654115745, 45.74113945807181, 43.938896656036384, 45.63470594344601, 42.54284274193549, 44.3673175381076, 42.36017404064056, 43.599305691257605, 40.13286006066107, 39.49876577623429, 40.62000666895221, 38.9570786106971, 43.12324762344361, 48.4555608226407, 47.22208522981214, 50.57890845883278, 56.09346674334619, 59.92170003152663, 56.52015393780124, 48.96339008885045, 46.068555385835715, 54.45092324287661, 54.983659559680575, 52.451047897338874, 51.31955392899052, 52.209637780343336, 46.64364545576034, 43.55114290791173, 39.93490196043446, 40.017208976130334, 39.79647367231308, 40.82297755825905, 41.17192729826897, 44.628574848175056, 40.918934422154585, 42.45191827897103, 43.02898914583268, 41.838224241810465, 39.795991220781886, 38.83961931351693, 41.50546604587186, 45.195514232881614, 48.34794275222286, 51.43088256159137, 50.361820959275775, 49.819961209451, 49.93452971981418, 52.67319133204799, 53.2368359258098, 51.46266552709764, 52.70799844495712, 54.738436898877545, 51.9012963387274, 54.02395363776915, 52.05960319888208, 55.44657768741731, 53.13044947962607, 59.807206046196725, 58.41668659640897, 61.812102025555035, 57.71120125247587, 55.04670381546021, 59.21243744511759, 62.39022016525269, 59.170401403980875, 56.551109283201164, 51.94077499451176, 49.86338969199888, 44.83779407316639, 48.29831692480272, 49.82641350838446, 59.28581714630128, 62.83379316329957, 67.52244149484943, 62.91927337646485, 64.72278310406593, 61.80011526230843, 70.30592795341246, 62.95029147978752, 65.51381926382741, 60.76164030259656, 67.84310310117661, 62.415762639814815, 69.30738664442494, 58.44337440306141, 67.16717673886207, 36.64687710423624, 1.4726650354362305, 0.2532287545862698, 8.628677994974199, 69.99436624588506, 60.80240549579744, 46.316229527996434, 39.19185992210142, 50.79332874667261, 42.16014492896296, 37.31606091222456, 36.09598021353445, 61.710073332632746, 33.26074200291788, 0.4865382425487042, 0.1428864142226596, 0.07376747956920056, 0.08485120135329424, 0.05015493370592595, 0.005953485200617222, 0.033320546105143525, 0.04452367418355519, 0.07367898109218768, 0.06923076050776629, 0.04491542090451525, 0.0069167727750966395, 0.10198570772885315, 0.13519394151385755, 0.11530513454589153, 0.04022712368638285, 6.435594049192245, 65.90760953964727, 65.27821033231675, 53.22251927468085, 24.37647354218268, 49.020982250090576, 47.64603068751674, 36.11808276945545, 63.61163054743121, 67.05917035379719, 79.06980514526367, 7.758509978171318, 1.5426726014383378, 2.408871669923106, 0.7820220015222027, 0.46276567623980586, 4.258422668903105, 33.817769558199, 39.06123715062296, 51.68400095355127, 55.189352573887, 64.2159265856589, 67.12955336416921, 61.44483481684039, 63.943121817804155, 69.5943707804526, 64.09195615399268, 68.05065139647454, 60.43404786817489, 58.661944558543546, 52.62433036681145, 51.089157827438854, 49.377619835638235, 48.59389889624811, 49.57668012188327, 58.46884627496043, 58.566795702903505, 66.48717895630868, 63.544165780467374, 51.610719311621885, 60.72837075879497, 64.86582409950995, 63.954959530984205, 60.861492080073205, 58.49058797282558, 56.882851585265136, 56.69021221899218, 57.54828560736872, 54.33289520202145, 59.964159688641956, 60.34558665367865, 60.21275558779317, 59.97582481753442, 59.20667156096428, 54.356107788701216, 52.080046592220185, 55.30892602859005, 55.17804830305038, 50.51821762515653, 52.85050992042788, 49.47081535093246, 47.54986986037224, 46.64051540436284, 47.51494899872811, 44.661083452163204, 47.24013597734513, 44.40661184249386, 46.95048855197045, 44.660032256957024, 40.944017979406546, 41.90745407535184, 42.17534411338068, 47.08609273356777, 50.0523381079397, 50.21938793120846, 51.40085681792229, 57.090054711987904, 59.66114482572002, 60.58722819051435, 50.68893878690658, 46.22944708793394, 54.15518437662433, 56.38137655873453, 55.46488338901151, 57.11604041437949, 52.834738069965, 47.74889092291556, 46.66698355828562, 42.04019100435319, 44.01349621434366, 44.163322910185784, 45.54968856996106, 42.39121567818427, 46.26189293399934, 43.570868507508315, 44.26774032654301, 44.98192940988849, 43.766096638095, 45.775287612791985, 42.363029526126006, 43.176725218372965, 49.23657140424175, 51.5054311290864, 51.773862454199026, 53.04198434275966, 51.60542018951909, 53.63148912306755, 56.17628366716447, 56.50152267948274, 55.94382439890216, 54.95524983252249, 56.03822408183929, 53.37033379462458, 55.58405283958682, 53.92651804031865, 57.98254297625635, 56.785761156389796, 62.24545724930302, 60.76318963881462, 62.112347695135306, 61.81170586616763, 57.07110574168544, 60.477135104517785, 67.32302819528888, 62.54242773978942, 60.67818795481036, 56.336759598024436, 54.21082319751863, 48.936266899108894, 52.10984876078945, 52.5500524428583, 61.95627266360868, 65.20650156082647, 70.81909164305657, 65.70042994714552, 67.47053284798899, 65.90869995855516, 73.25228691101074, 66.57478901647752, 69.06342306444722, 65.61320427925357, 71.96352943297356, 65.62452423957087, 72.27746025208505, 63.15496860011932, 71.48464725863549, 34.433969989899666, 1.3353017933907048, 0.3458738357069031, 12.463366523865732, 80.65448976332142, 65.7958298344766, 54.4629256956039, 45.1994405254241, 56.75077361445273, 50.594213547245154, 41.0293609096158, 51.32275066068096, 70.42690169426703, 48.66927508384951, 0.9965632086799991, 0.014513222587054536, 0.049496220665112625, 0.04608509160818593, 0.05696129549535052, 0.05609146011392436, 0.026248282858080445, 0.1276975413483958, 0.2578173607828156, 0.25166847863264624, 0.18635867103453607, 0.12187986199053065, 0.19611645550016435, 0.312131094716249, 0.2621786074051934, 0.36199244820783216, 7.765699192400902, 77.41103479939123, 73.8847141881143, 61.52274877794328, 46.750910512862674, 72.99724655766641, 60.5936255762654, 41.04867858271445, 73.07464276590656, 71.50673020270564, 88.61225712683894, 7.948809160340217, 6.676850213158516, 3.4948936008637954, 0.7377323135733606, 0.7553861662745477, 6.329099247532507, 40.25772087035641, 46.05618030794206, 57.2828862743993, 58.41037550280171, 70.84585789711245, 70.36335929747551, 67.26246679982832, 68.44842680038946, 72.49978803819226, 68.63393137531897, 70.38554422317013, 64.23464021375104, 60.859848606971006, 54.127108050930886, 53.062549329573116, 51.95903362766389, 50.64411786294753, 52.45164801997524, 60.49015737348988, 60.75424663482174, 66.91624702945833, 63.323269659473056, 53.87948882195258, 62.316609044228834, 66.46319758507514, 64.43559108241912, 63.48235707129202, 62.40687454900434, 59.98834502312445, 58.84304038939938, 60.58973066268429, 57.85361074632215, 64.36492958376485, 63.61133636966829, 63.921607617409, 62.747740284089126, 61.95338187679168, 56.94256967113864, 56.16372816024288, 58.38793170067572, 57.21960667640933, 53.03477110401277, 56.411465060326364, 53.45209560086651, 52.80421810765421, 49.682819458746145, 51.558908724015765, 49.76135707670643, 48.25212709365353, 46.72642707824708, 49.80065922583304, 46.635706578531575, 44.76845441326019, 47.39954110114805, 46.04287562831756, 50.43773058922061, 52.68869253896898, 54.285834604694, 53.87334639026273, 61.076673307726466, 65.15539307748118, 63.88066591755037, 53.29003503245693, 47.3913315803774, 54.44557312996157, 59.50771739405971, 59.188730639796105, 57.29643806334465, 55.42012130060504, 52.502501549259314, 48.98759111281365, 46.5803187893283, 48.89136752774639, 47.51486270658432, 48.10151200140677, 46.19782101723456, 48.65382094537058, 48.37187705501434, 47.779912948608406, 48.30321988751812, 46.406950027711936, 47.713220888568515, 46.28024178166544, 47.51745539326822, 52.86422644892047, 53.74112721412413, 56.708639514061716, 57.49096408967049, 56.51302306882797, 56.69959452844436, 59.87589067028415, 59.31883173604166, 60.26339730908794, 61.05690063968782, 58.72449851805165, 58.09116909580847, 59.915436006361446, 58.152130573026604, 60.780569661048155, 60.99007914143225, 64.85934434398528, 64.41390037536621, 63.91654383751654, 64.77655487675821, 59.967164224193944, 62.86790993905837, 65.09925219320482, 64.96868825727894, 61.429223783554576, 58.9183420519675, 54.38899294022591, 50.11404483549057, 53.833193086808734, 54.60997535336403, 65.37484968862226, 69.10824791077646, 73.62140547844672, 70.51593165243827, 71.64723734701835, 69.24769601514264, 75.45468207328551, 68.35203847577496, 71.23583562912481, 69.88047630556169, 75.60990595048474, 71.62946901013775, 78.0802539087111, 67.57415402320125, 75.50896767647036, 43.942622907700084, 2.752714974264945, 0.3988227380379554, 13.095529040982647, 87.97313044148108, 72.06245160871937, 64.8409798068385, 56.151545278487674, 69.65190410614014, 61.90570546734718, 49.867861193995324, 56.2487219995068, 85.89574121659803, 56.53851063020768, 1.2409717325241336, 0.26412689157070657, 0.19144555613879236, 0.19383253289326546, 0.21252710071782913, 0.07518104202444516, 0.17960962028272692], [0.06869448363901147, 0.039936205627576965, 0.023646678910740924, 0.09995065644503602, 0.05740720463255721, 0.05164415117413287, 0.01584505207926756, 0.18971905442735842, 0.08066576424865954, 14.282594169339827, 72.74348489699825, 54.24324550936299, 43.165315043541696, 60.44174748082315, 102.94661383475028, 69.16821310597082, 23.90205110273054, 63.45001712922127, 64.00351062897714, 72.16585313120197, 35.05559113717849, 0.8184720359502301, 0.3824428282678128, 0.2952126251353372, 0.30760109424591064, 0.3568736325588919, 13.753514482129006, 31.570584850926554, 31.601867714235862, 48.50723020492062, 60.29272487086635, 61.72374671505344, 61.267010242708274, 61.37342806785338, 66.6405906984883, 61.358750558668575, 60.03750016612392, 55.26848639211347, 50.17082114373484, 46.81229952842959, 49.12326981944423, 44.009781729790475, 49.12712943169379, 49.84563312222881, 55.22059032993933, 57.37519141166442, 63.66212321865944, 57.5938674711412, 57.423762121508204, 61.83103138400663, 59.272167298101614, 59.809755586808734, 57.70425865727087, 54.49994894766039, 52.462815007855816, 53.882669864162324, 57.5784957024359, 54.578333593183956, 56.556902623945675, 56.88331442494547, 54.63539623445081, 56.64557172406105, 55.864102225149836, 55.18857202222271, 52.18679389645977, 50.488333086813654, 52.391270975912775, 51.65101774277226, 53.85298536669824, 48.78097241924655, 47.21559370717695, 45.47168047197404, 45.55600358593849, 46.76036734734812, 44.14293443003009, 41.006932796970496, 45.34359939636723, 42.89183955038748, 41.288798239923295, 40.027262010881984, 40.19613573628087, 39.56161783587548, 49.44388043495917, 46.973638380727465, 51.0825486336985, 58.088372445875606, 59.44157446584394, 58.36344042131978, 46.07946349728493, 38.942883553043494, 52.72647280846873, 59.44958394573581, 59.02232016286543, 56.51487050517913, 51.72336586060063, 48.49889909067462, 43.641863407627234, 39.58330069818805, 38.94042030457528, 40.83595275878906, 42.669233275998025, 41.71711321799986, 40.88927345891153, 39.374042249494984, 43.15246535885719, 42.2136813594449, 44.935704277407744, 39.09882914635443, 43.30556331142303, 43.53421788061819, 48.89477606742613, 46.18658734906105, 52.7594324850267, 48.746537931503795, 49.55394606436453, 50.859616802584746, 54.209846527345725, 55.12009528375442, 56.21277347687752, 52.009981293832105, 52.153496896066976, 54.24858385516752, 55.91083334338281, 53.07821527604134, 56.68498762192265, 54.436692883891446, 58.356568428777884, 57.91323469531152, 60.11604955119472, 60.846194836401175, 58.19728097608013, 54.13984790925057, 61.68122037764519, 61.543290230535696, 57.86859420038039, 55.24706632860246, 54.52575422102406, 48.00572379942864, 48.00765752792359, 47.12619896857969, 59.07563301824755, 62.7992606163025, 65.6592882064081, 65.16242196482997, 68.70087838942005, 62.21806733838974, 67.30795844908684, 61.74457842303861, 64.70741133536062, 56.91061019897462, 65.53700047154581, 62.755247700598936, 65.32045818144276, 52.02995400274954, 51.81985224446943, 9.467624925797987, 0.4190743948903776, 0.4348395344230437, 24.026941330202167, 67.18568248133506, 60.000304329779844, 39.135177750741285, 24.353086410030244, 48.619017754831624, 45.58868477421422, 40.87522745132446, 39.659986957426995, 62.963003881516, 45.072194914663996, 2.6602399493417432, 0.15737992440981252, 0.12444616460631933, 0.07216699166043151, 0.08837814758261366, 0.06497496588816566, 0.0435351909348561, 0.07265453001544361, 0.07884837386588897, 0.055038947236513903, 0.04439227095234298, 0.022016987730298313, 0.040380578758495475, 0.07546990313717435, 0.21971286755175362, 0.11832492290845803, 19.06687282746838, 82.7643483684909, 61.372965228173044, 49.58197139924573, 58.04472431059807, 105.00606213846515, 63.86860855164067, 30.967893062099336, 68.47647174712151, 70.20363253931846, 75.68647061624836, 42.136006662922526, 0.8293760411681668, 1.7980242929150982, 0.49862236024871953, 0.25662532797263515, 0.34041086271885906, 12.046503886099785, 34.84031185027092, 38.80541624561433, 57.09238852224043, 65.52133060270741, 65.2627287372466, 64.10050299859816, 64.31959090694305, 66.98495911013696, 62.95254684263661, 63.12784541037775, 59.1366062625762, 52.67232448823991, 51.00886298764137, 52.33138030575168, 47.503240723763746, 51.48712542749221, 54.611191288117446, 57.9466179878481, 61.25778090569281, 68.2802277226602, 59.852164253111816, 57.16340695658038, 64.07929474307646, 61.93897501114876, 62.75060753668509, 57.691522721321356, 55.5630720815351, 56.02404471366636, 55.69307511852634, 58.93454144077917, 57.38003553882722, 57.52678709645426, 59.94393202566332, 58.22215272534279, 58.549572575476866, 58.40720230533231, 57.670698858076534, 56.98188750974594, 53.34886666267149, 55.66206485994401, 53.11051991678054, 56.06016582058322, 51.34075433977189, 50.22564018926313, 47.02153836527179, 48.76407092617404, 48.14840001444663, 45.09616451878702, 43.4407203428207, 46.40621262211954, 44.664378243107954, 42.812019317380845, 41.579736125084665, 43.52092889047439, 43.17026115232899, 49.84328362249559, 50.74016494135703, 54.427389021842714, 58.10867071151734, 59.665683008009395, 61.73390565379974, 46.07150108583512, 38.54539448215116, 53.49186451204362, 61.05954039481379, 60.828010728282315, 56.027923937766786, 55.27553096894295, 50.79571747010755, 45.94895055217128, 43.68501732426305, 42.469290456464215, 42.96307763745708, 46.45341834714336, 44.85973188954015, 41.57419381603118, 41.51395797729492, 45.37341333204701, 44.693815631251184, 45.25610308493338, 41.13359005220475, 45.51987071191111, 47.26206987134872, 52.05621427105319, 51.02717261160574, 55.82009323181645, 50.99596231214462, 53.451977929761334, 54.2297839349316, 57.66999675381569, 57.89239906495618, 59.28616623724661, 55.823737113706535, 56.42933930120161, 56.56371970330515, 56.153294655584524, 57.26012868265952, 60.274587831189564, 55.904996856566406, 60.07254262124339, 61.1120883880123, 63.349086699947236, 63.841924667358406, 60.14422001377229, 56.29864984943021, 67.53960578672348, 63.49475176103654, 59.39261936372327, 57.341270754414225, 57.374536375845636, 51.41110989355272, 52.10477713615664, 50.903900361830196, 61.893385302635934, 67.23322160782354, 69.84454739478328, 68.31452492744693, 71.82111601675712, 64.80468611563406, 69.24427570835238, 69.97404836839246, 65.93639189197172, 64.73138486185383, 69.3786874894173, 67.04167658282866, 68.3900619322254, 56.442659670306796, 54.17150143654116, 6.829966306686402, 0.45079542984885557, 0.4518509457909292, 31.782294780977313, 74.16142955903085, 65.41856450419273, 46.71874315507951, 26.230403377163796, 65.13492614992204, 58.607141202495946, 37.913343752584154, 58.66106594762495, 72.81837863306846, 59.221156874010646, 4.051116825111451, 0.15471712535908147, 0.14318010168931178, 0.04729929500289502, 0.15104745694946858, 0.043360729731859705, 0.020840280509043126, 0.17089825063463182, 0.15496546042061624, 0.1944062714615176, 0.2054928047882934, 0.1734572907368983, 0.22273244907058057, 0.23984784921330793, 0.3477423547977402, 0.3509052866889585, 23.389860160889167, 97.07591610570108, 70.99853223369968, 61.670084768725985, 75.51106222214239, 110.72366975968885, 80.11071589685257, 39.376144639907345, 77.69410440998693, 76.40851620704898, 82.52200080502419, 44.15065365452921, 2.496014968041451, 2.3851599616389123, 0.8032780609303906, 0.45929018047548115, 0.5524619164005403, 15.144640918700928, 40.31870980416575, 48.47869888428719, 65.66329686872422, 70.71896922203803, 69.42079805558728, 67.40280135985344, 67.03517329308295, 69.73683910985147, 66.30136843650573, 66.22892225942304, 60.91231030802573, 55.478819570233746, 53.66906542931834, 56.54155831183157, 49.41695728609639, 54.52038449625815, 56.48063998068533, 61.258918393042784, 62.70621415107482, 65.97466638011318, 63.81265986350275, 59.543156008566584, 66.53004261755174, 62.357001612263346, 65.66805078137305, 60.332619297888975, 59.02120228736632, 58.284451730789684, 59.095288015181026, 62.143048086474025, 58.86000856276482, 60.45856268175187, 61.903920788918775, 61.226201903435495, 62.0279186771762, 61.56756185716199, 60.41812696764546, 56.497392423691295, 56.94560950802219, 58.90055018086588, 57.261152421274495, 60.37147821918611, 54.898748090190274, 53.82406180904758, 52.28801850349673, 51.20671126150316, 52.371961147554465, 49.16365454273839, 45.51896856677148, 50.3450136030874, 48.161261466241655, 45.6599973863171, 45.96821331208753, 47.01508606633833, 46.8884248887339, 54.42363923595798, 53.77124709467734, 54.78095931391562, 59.99137701526765, 60.29172858884258, 65.22748624124836, 46.32293285862092, 40.499656584955034, 54.4876209382088, 63.763857733818796, 66.29523384955623, 60.833376530678045, 58.34420511799475, 54.60568035802534, 50.469505709986535, 49.41999320060977, 46.125535657328946, 46.66783863498319, 49.413148664659076, 46.80139141698038, 45.35114995894894, 42.6554657566932, 47.56522201722669, 47.951528410757746, 51.36173509782361, 46.12326852736935, 49.00382188058669, 51.510557666901626, 55.47042962043516, 53.45288007490097, 57.95245055229434, 54.37686497165311, 57.04470034568541, 59.62747520016086, 59.270649340844926, 60.73411703109742, 60.57568073272706, 60.630758654686716, 58.7069929799726, 60.6384111988929, 60.928082158488614, 59.90745790543095, 63.63942054010207, 60.90883116568289, 62.68873999195715, 63.944153401159475, 65.33638300434237, 67.76971555525257, 61.396052299007295, 59.623968601226814, 65.28458418384676, 67.5392919971097, 62.224150934527, 61.037986970716915, 59.550388859164336, 56.08905015453216, 54.86978923120807, 52.78760294760428, 66.10755628155124, 68.90578300722184, 71.555587245572, 74.28041858057823, 75.92287971127418, 67.39667461764428, 73.82752603100192, 68.1456982704901, 70.24234633291923, 65.49054784159507, 77.10604698427262, 72.13718844998267, 77.30200859808153, 60.87090969085694, 64.7964765948634, 11.932417827267802, 0.6708275262386568, 0.5122027089518886, 32.87322948055883, 84.15664857433688, 71.377378279163, 55.63691070002895, 36.241562904850134, 67.78767216590144, 65.25207950222877, 55.026644814398985, 58.811449620031546, 86.33194015872094, 72.16007155756797, 5.993346321967341, 0.3290805755363357, 0.365284695740669, 0.2767841349686346, 0.1719505183639065, 0.262075767762238, 0.1528168902281792], [0.022250795849568905, 0.15886094090679, 0.032304230882155324, 0.1007179624491161, 0.02383696174459352, 0.05207424825658241, 0.08633244001576978, 0.23469835940387943, 0.0674902164046803, 19.972271573159006, 65.18293988320136, 46.403317912932366, 37.11272132012152, 56.49620786789925, 94.18587453903692, 64.28455237419375, 25.36605811888172, 45.67051326074908, 71.87489955655991, 60.65342995428271, 70.62608749635758, 3.8633934144050848, 2.522399771598078, 0.79045957134616, 0.658441539252958, 0.15203184928865204, 2.935177015681421, 22.73525384164626, 22.90083081491532, 43.90344235204881, 59.284110915276315, 58.69828139581988, 64.8694169905878, 63.04054129508234, 62.14802949659286, 61.92034375283026, 58.1081372691739, 52.36916057525143, 48.06093508197416, 47.08305681905439, 46.6413273349885, 46.31206004850326, 48.85171628767445, 52.44086542437154, 58.221697730402795, 61.851396329941295, 62.89466834837391, 54.7851993960719, 58.9296345556936, 59.77859627815985, 57.12887048721314, 58.253445394577525, 57.451183411382864, 54.33371105501729, 50.657559825528054, 55.026695805211226, 56.09092112510435, 54.598698539118615, 57.33197865947601, 57.574177172876176, 54.72327693816155, 54.360818555278165, 55.04207934102705, 53.671940526654645, 51.66881745861423, 52.492762304121456, 53.24098579345211, 51.08052076831941, 42.7085118909036, 48.63007099397721, 47.25708061648954, 45.30280674657514, 45.66104465915311, 47.27302112886983, 48.40902974528652, 46.49843931198121, 43.785308407199004, 40.832752104728456, 42.474797464186146, 41.36919113897508, 40.46474356805125, 45.52066695305609, 50.756109376107496, 51.50290512269544, 55.68054314582579, 59.312081336975105, 62.76282179740168, 60.68841749621976, 42.00727839623728, 35.16119310932775, 47.864871486540764, 62.719914990086714, 62.38698420986053, 59.92878383205783, 53.75668333422754, 50.42809332570722, 42.443508717321585, 40.502092376832046, 39.885684059512236, 38.577012708110196, 42.214595271695046, 39.487481117248535, 41.47531870872744, 41.73557581440095, 44.184782197398526, 44.63575278559039, 43.25713380690544, 43.05408054782499, 45.607131681134625, 48.24916570417343, 50.71508138410507, 48.766310599542436, 51.043591653147054, 52.18192231270575, 51.736105718920314, 54.21989956209737, 55.1797035432631, 55.41624992124496, 57.270260164814616, 53.646551024529245, 54.04080414002942, 55.982514658281886, 54.15313297702421, 53.629312207621915, 54.37790832211895, 56.27330349337671, 57.15257337016445, 61.21010449624831, 60.11830099167363, 60.88538715916296, 56.99879684755879, 53.74417489574802, 61.77640061224661, 62.28486530242428, 58.28687967792634, 57.475015732549856, 56.26993025502851, 50.20520856303554, 48.19125975331953, 46.3692521279858, 56.23866112001481, 65.74141479307606, 63.90310579730619, 65.98231500194919, 66.26045811560847, 65.86389864644697, 66.67821407318115, 64.92043133704894, 61.95388786254391, 59.136543504653446, 62.824850159306685, 61.07744601465041, 50.431513632497484, 45.38278779675884, 19.421717889847297, 0.12367400926567855, 0.5322527008191232, 0.08793072925219614, 44.20203278141637, 71.0842203324841, 59.03604453609836, 31.023778992314494, 27.551359591945527, 39.097201362732925, 51.76344071665118, 40.00593216188493, 31.941180190732403, 51.30057357972669, 56.29075411827334, 3.94038365733239, 0.1071020259311603, 0.11228972054537266, 0.07239513264428224, 0.10062318205112412, 0.1411444375351552, 0.022820466490943107, 0.027136916121948632, 0.14306546429232245, 0.027730998155030034, 0.06914094435952364, 0.01953645631851208, 0.005556479286056974, 0.05902741164449723, 0.1278803222662499, 0.07470569212830837, 26.71542602200662, 76.60541918969925, 52.46017917510002, 39.800294060860914, 63.94777767119869, 99.68084842927995, 68.09496633468136, 35.76685021000524, 51.95960237133888, 77.72873109386813, 63.575646723470385, 80.17866703771776, 4.5692371649126855, 1.1969107677859645, 0.26114123242516674, 0.40611163562824654, 0.09747839878283202, 2.593813139584757, 24.94095556197628, 32.00102379245143, 52.95502147366924, 63.463294352254565, 63.14522935498146, 66.74512186358052, 67.00539465873473, 65.29388804589549, 63.25385939690375, 59.270876838314926, 55.412680564388154, 50.38310373983076, 50.17725775318761, 47.19948453287925, 47.8797294247535, 51.17633250451858, 55.21453811276344, 62.50976616336454, 68.08119881537654, 66.6627207110005, 55.77673535193167, 60.247915714017815, 63.46990746836509, 61.34270021992346, 61.79230582329535, 59.93797786774174, 56.3717039938896, 52.366665947821836, 57.32590683044926, 57.23775156082646, 54.80272846837198, 58.19879893333682, 60.128467775160274, 55.95175150902041, 58.263557264881754, 56.99518434463009, 56.42928831038937, 52.545482881607555, 55.11312523195821, 57.0095362970906, 54.26918414331252, 46.10331543030278, 51.93788813006494, 51.08233290333902, 49.933211803436286, 48.01492960222306, 48.73665748103973, 49.798525456459295, 48.97358825129848, 45.77442469135408, 42.11014255400627, 44.60753525457075, 41.34437430289484, 43.22456244499453, 47.72370146166894, 51.606706726935606, 52.26894009497858, 57.52441014012983, 60.982226556347264, 65.13194514859107, 63.450562338675226, 41.44312389435307, 36.56409940411968, 47.86502053660732, 63.85867318799419, 64.46280448667466, 59.72603651785082, 55.49599170684815, 54.399697088426166, 45.49825060752131, 44.258765943588756, 41.14881669321368, 41.98918450263239, 42.63663837986608, 43.33937021993822, 44.13690574707524, 43.45052626825149, 47.45520345626339, 47.256911954572125, 45.937485464157604, 44.52542043501332, 50.365531521458784, 50.88188017568281, 51.47722928754745, 49.85213248960434, 53.21274472821144, 52.94299156435075, 55.105429541680124, 55.60216634504257, 53.536497162234404, 58.896419925074426, 59.91725990849157, 56.70710194495417, 57.673173873655266, 58.02598322591474, 58.131396924295736, 57.00660628657187, 58.39565092517484, 55.90376130996212, 58.20427456209737, 61.30907374043619, 61.36026459355509, 62.82897257035779, 60.44384202649517, 56.25309151987876, 65.87418310103878, 66.92749638711253, 61.712587571913204, 59.970207983447665, 58.13224807862313, 54.335695774324485, 49.509976294732866, 49.52164926836568, 61.51952066729146, 68.3508696094636, 67.0321766022713, 70.00330924987793, 68.36648064274942, 68.69922314920734, 70.50984413393083, 73.23478529530188, 64.32440365514448, 63.217047952836566, 65.86066661342498, 65.47851793227657, 57.187411862034956, 53.55514018766342, 17.71556923466344, 0.20912778473669486, 0.1745187974865398, 0.24109824260156004, 49.81377955405943, 77.26075310860911, 64.32445856832689, 36.65570243712395, 28.621750877749538, 46.29130678792154, 65.40871935506021, 35.18666498122677, 46.460329563386985, 61.77377262423116, 69.14793445217994, 9.1365857085874, 0.20733483255870883, 0.11523890624483747, 0.09744260715500963, 0.0863772025331855, 0.10036494147272841, 0.03635502803409773, 0.21350058396497082, 0.36272669751797953, 0.13312338971562926, 0.14647519906922696, 0.08357625484706895, 0.10169650953743728, 0.30047613947141555, 0.296146578245586, 0.17346239288247403, 30.834883528371012, 91.61849498748781, 60.979280856347856, 54.602722890915416, 69.63269233703613, 102.65245960604761, 73.49175545477098, 42.64264745097007, 57.58802706195463, 85.13848058639034, 69.31239943350516, 86.86623757885349, 4.311718363915721, 7.227804958820344, 1.2434069115308024, 1.599631299895625, 0.7137705541906819, 3.3850468887436778, 31.788970655010594, 42.38040954835954, 61.506066937600416, 67.46147217289095, 68.38049134900494, 71.01011107044836, 71.77924079279747, 68.86337434091877, 67.20327038918772, 62.26286472812776, 58.04346130740259, 52.46427020718975, 52.410827913591945, 51.00074368138468, 50.73088069115916, 53.589696268881525, 55.578494841052645, 63.934684799563506, 66.90771195196336, 65.8857697825278, 58.546042442321784, 61.33036436573152, 64.5256212449843, 60.683353716327304, 63.99305359009774, 62.77369068514917, 58.71722644375217, 54.6288380315227, 59.322671736440356, 62.34656418523481, 56.8941911574333, 61.916633190647254, 64.19068221122988, 59.262749687317886, 59.17110350824172, 58.67263301726311, 58.99976261200444, 55.178895535007605, 57.11766427563083, 59.03842541479296, 57.87207726509341, 50.690664629782404, 55.724316796948834, 53.11164171464982, 53.90736510676723, 50.32506835076117, 54.22572035943308, 54.513602718230224, 51.72438567684543, 49.43972664494669, 45.943663197179, 47.248259205972, 46.5957768501774, 45.37875952259187, 52.18222433520902, 56.12609694080969, 55.27102416561496, 59.359149779042895, 62.06423590260168, 66.64693709342711, 65.31178189862159, 42.34863834996378, 37.15608704474665, 50.1134447128542, 67.08183380865282, 67.34745671672206, 64.24005308458882, 59.7063030735139, 58.2316017150879, 49.258917147113436, 48.83485401830366, 45.256432564027854, 46.40116845407794, 47.303886259755785, 46.321128568341656, 46.5822603625636, 47.232126497453265, 51.607636328666445, 49.847519782281694, 50.02384993337816, 48.3984903366335, 51.86039386257049, 54.46210592023788, 55.66241787325952, 52.429474861391135, 56.49925162715297, 55.86434148973035, 57.49708298713931, 59.58976161095404, 60.73084969674388, 61.22131855257096, 63.16166016363329, 60.13981911443896, 58.590753539916015, 61.6424124471603, 59.62593763105331, 60.21760363732616, 60.84426110790622, 59.646985069397964, 60.33093660108505, 64.61306264323574, 62.92181507233651, 67.07195728055893, 61.530687655172045, 58.68999735001595, 63.27501273924305, 67.5886824823195, 64.64211563910207, 62.98027799975488, 60.97892784303235, 55.67398886526785, 52.63628967346684, 53.766567707061775, 65.42853124680059, 74.24382286687052, 70.16254963413363, 73.30963196293001, 72.36940845366448, 70.87288302759971, 72.71110180885562, 70.48958901436099, 69.34883040766563, 67.00137815167828, 69.08847916510798, 71.49002090577157, 63.608775061945764, 64.35133857111778, 25.395579837983657, 0.400372288760639, 0.6432047245963928, 0.6243649065013855, 54.68324522818289, 84.94753176166166, 70.59601860661661, 45.292836081597116, 39.683285836250555, 51.661992534514404, 71.54230610016855, 54.10563699660763, 49.68029737472535, 71.26056225069108, 85.51781300575503, 13.161922020296897, 0.6450766144740967, 0.30559017473170835, 0.2116723917424679, 0.32455229110294775, 0.19915575612216227, 0.1931743867575161], [0.014523211415977249, 0.05536071565603057, 0.03327494089101111, 0.022219903354022293, 0.009136447897030702, 0.022425551996416142, 0.15680321342041417, 0.10066928522240731, 0.08088594557897699, 29.278432130813602, 62.06316901791481, 49.71413173983174, 40.36202846034881, 53.61345798738542, 91.3976812362671, 46.98467985276253, 19.6602136858048, 41.18616550199447, 78.50226956029093, 54.824991841470045, 76.36409928721767, 24.28436648461127, 0.3848572309699751, 0.3793213570550565, 0.5327473484700727, 0.12368723194325164, 1.5484213252221386, 8.287219981993399, 15.37193246426121, 40.22500045837895, 57.71968533915859, 57.97208201500678, 56.71433871792209, 55.54076948473531, 56.12901518421789, 57.127097575895256, 52.436519438220614, 49.79992182024064, 49.56701540177869, 47.25671191369334, 46.995956667007945, 49.94973674897225, 52.59708166122437, 58.51578135644236, 58.899342090852805, 65.71848853941887, 50.273198927602465, 50.198768031212595, 60.03604888916016, 58.99960179482738, 60.72247151405581, 57.444244738548036, 53.513998446925996, 55.65874653477823, 53.11305769028203, 55.17876609679192, 58.95908763331752, 55.24406963779081, 59.29722732113254, 58.40930469574467, 54.866584654777284, 56.32366280401907, 53.60096523838659, 56.74011261232438, 56.11855030059815, 53.859810290798066, 52.38523837058775, 53.70896377871114, 44.6566354843878, 45.86405477216167, 46.5580318820092, 48.0928788646575, 47.575624142923665, 50.00262991074593, 46.88120772761684, 46.825109989412375, 46.93032756928475, 47.51305841630506, 42.29969893732379, 43.73541978097732, 45.66266852040445, 49.53852330484698, 53.85215774659188, 54.609179112219046, 55.710906213329686, 56.706521434168664, 64.96194570295273, 54.53005313873292, 38.40535409988896, 37.49357561911307, 44.01265682712678, 65.13371413753879, 63.13137946590301, 59.23977636521863, 55.83047574566257, 53.026663564866595, 48.93262301721881, 42.6643067790616, 41.847696765776604, 40.269884140260764, 43.8813554856085, 41.2296724319458, 42.791066015920336, 44.81791157876292, 47.029889091368645, 44.904576347720244, 44.226520138402144, 46.462828113186745, 47.893642071754705, 48.73141327211934, 49.2481973094325, 50.509831597728116, 52.673771842833496, 54.03850170873827, 53.0787173394234, 55.094317466981956, 53.47619856557539, 55.53830231389692, 54.266787575137236, 53.726171216657086, 56.797171331221065, 56.95754528045655, 55.73537003609442, 51.223742192791356, 53.03011132824806, 53.87443288680046, 56.09211352563674, 61.034280330904075, 57.720101110396854, 61.63668186433854, 60.14238826690182, 52.43561337071081, 63.40826349873697, 58.95523978817848, 56.20029641735939, 56.193581319624386, 60.33337239296206, 54.81990452735655, 46.093019208600445, 45.82396422663043, 50.22023516316568, 63.07012381092195, 64.62126039689588, 67.7226157342234, 66.9867947793776, 67.94101330541795, 66.7402816587879, 64.15886394439205, 60.856655797650745, 57.65771189043599, 57.9692029953003, 53.813047793603715, 39.75789716166835, 20.440916361347323, 0.8470040307410303, 0.10294686462129317, 0.1613217225718883, 0.9100020148100392, 61.19121828386861, 61.47763759859147, 70.3812139264999, 37.2981317581669, 21.772937582385158, 41.48634449128182, 50.85385484080161, 39.17500157510081, 38.504935233823716, 53.0585132106658, 54.00270615854571, 15.26756113575351, 0.37430387951674005, 0.06442880648518763, 0.04728029219193324, 0.019156505436366125, 0.15562595078541389, 0.05156731255532754, 0.025251977851674445, 0.02130541462270964, 0.04168781204028957, 0.07400350359779212, 0.07288539827230477, 0.011260958140595786, 0.11566981538048676, 0.14472618969457765, 0.06745235633946235, 35.98891519731091, 74.97137546539307, 56.78636520139633, 58.198253723882864, 70.10265504160236, 97.11880330116519, 55.79406830572314, 28.97286968846475, 48.362875215468875, 84.969983408528, 61.23957326335292, 82.83147581161992, 29.107103001686838, 0.4235584607287761, 1.6103288290962097, 0.2800781291819388, 0.4895991621719253, 1.2343257665634155, 9.968116418007883, 27.25363208401588, 52.87020021869291, 61.187546945387325, 63.75422439267559, 60.869085788726814, 58.394234949542636, 58.508728934872536, 56.949747608553984, 53.91378210436914, 53.24571224950975, 50.72809973070699, 50.42563792197935, 48.8509867268224, 51.9557741380507, 55.315209665606105, 58.480970321163056, 61.11061357682752, 71.85600942181003, 51.1768816363427, 50.17861489326724, 61.79940531330725, 62.542341447645626, 63.83053802674817, 59.00569323570498, 57.34621686320151, 56.73482133496193, 54.91068386262464, 58.057464168917754, 59.92286889783798, 57.163348121027795, 61.59104116501347, 62.410506663783906, 58.679132384638635, 58.55143962367889, 56.30435689803093, 57.9748276741274, 57.85588572102209, 55.18544589319537, 55.71062772504745, 55.03252444728729, 49.175911949526885, 49.764561653137214, 50.57596668120354, 52.68036926946333, 52.200114265564956, 52.72990488236951, 48.07537724894863, 49.75674044701361, 46.743120685700454, 48.73725760367609, 44.47716743715348, 44.90011661283432, 48.665811630987356, 50.767464637756355, 55.650270292835856, 55.48602496424029, 56.46531528042209, 58.28922525528939, 64.75026715186335, 56.59889551901049, 37.440329444023874, 38.18182214613884, 44.41026356912429, 64.41981923195624, 60.8906941260061, 58.98752873943698, 57.95788695735317, 55.46400870046308, 50.05418946666103, 44.330062866210945, 43.37093353271485, 41.05823347645421, 44.73885228556972, 44.59079457867531, 46.5900815686872, 45.982573109288374, 47.81333154247653, 45.67863256700578, 47.21501711876162, 49.085575842088275, 52.9729780843181, 51.981528420602125, 50.255991489656516, 53.023976741298554, 54.23869948233328, 55.98244013324861, 54.770580722439675, 57.62494833238664, 57.84444416722944, 57.83639154126568, 56.24517617687103, 55.37489245014807, 57.73442560626615, 59.215418446448545, 58.411869925837365, 54.88139160217778, 53.450832597671024, 57.54445737408054, 59.11625308375205, 64.84356464878206, 62.06509097929924, 65.48091842282203, 64.10573544040804, 55.70703091159944, 65.02569990773355, 62.89151476275537, 59.776360527161636, 61.49917533320766, 63.65472562851445, 57.92663351182015, 48.86761365398284, 48.05586345734135, 51.70730767711517, 66.91674124810004, 66.36132578695974, 71.73570248388475, 68.21594792027628, 70.10927600245323, 68.9182718338505, 77.38815169180594, 65.59368264290595, 62.50537310877154, 64.60968940488755, 58.54490887734198, 52.7371455777076, 22.850608787228985, 0.3175560390997318, 0.16362934793916442, 0.6567384951537656, 1.7663157298680277, 68.61848508158039, 69.32466860740416, 77.43164293227657, 43.868505800924, 24.69395018392994, 50.38405687578263, 63.6992209957492, 37.69369102293445, 47.52922250378517, 63.844207486798695, 65.42567576131513, 22.289847135543827, 0.3124187454100578, 0.0509819945680999, 0.033751581645300316, 0.05346113169986395, 0.2475478755490434, 0.07049655992417567, 0.27391351158580474, 0.2222580721061076, 0.0786337543339018, 0.09790409085971695, 0.14518636338893445, 0.06269991074899031, 0.1348542428064731, 0.25241700782170223, 0.13828702150813996, 40.81044166318832, 85.85194403125395, 64.88092914704355, 57.55084691509124, 66.40895905033236, 98.30389253554806, 58.31746239815989, 33.84907399454425, 55.470778711380504, 90.44955022873418, 64.48718593966576, 92.25893958922356, 30.972443011499223, 2.893075029696188, 4.463049779015203, 0.5805235332058323, 0.6616472801373852, 1.2404255424776387, 13.458507137913859, 39.37656433351579, 66.54646165909307, 66.29385317525556, 66.8807731136199, 63.34697646479454, 62.751772480626265, 61.96657673005135, 61.66994748576995, 55.97419923351657, 58.26818566168509, 54.1562081152393, 54.36325434715518, 51.07032260587139, 54.45293149640484, 56.912661598574736, 63.90389027134065, 62.829215757308475, 67.84984957787299, 53.536250052913545, 51.529938097923036, 63.29425196493826, 64.71706036598452, 64.7813166341474, 60.600646618873846, 57.83982753753663, 60.14250986037716, 59.1447255688329, 60.63475947226248, 61.770603349131925, 60.18357707608131, 62.28106452572731, 64.36272128935784, 63.1143642240955, 62.45672787389448, 58.55305564018988, 62.51847382514708, 61.1187485725649, 59.655810402285674, 55.95168482872748, 59.62397644596716, 50.94614821095621, 53.38569379621937, 53.75291785886211, 56.170886485807365, 53.97683028251895, 56.915301353700706, 53.19129328573904, 53.532162943193995, 51.633720090312345, 53.674952906946984, 47.87585412302325, 49.18773005085607, 52.3661756515503, 55.33533142459009, 58.77119825732324, 59.11895951917095, 60.894883217350134, 60.64249830861246, 68.97676221786007, 60.24010627500473, 39.38885704163582, 37.63507120070919, 46.18689721630466, 68.20593803159653, 66.01002262484643, 63.61338384689824, 61.46314444080476, 58.30333402079921, 54.35604503077846, 48.17998293907412, 48.19093419659523, 46.92012940683673, 48.57793877201696, 47.71916327937957, 48.5924280074335, 49.00316292239774, 51.54625515783987, 52.50272512435914, 50.94479107087659, 53.558105499513694, 54.8578691482544, 57.66623127845026, 53.73336876592329, 54.33595857312603, 58.549094046315844, 59.3968516011392, 58.240964412689216, 62.35881374728296, 62.18293859112648, 62.09429302523213, 60.49828844685709, 60.78923809912897, 60.26159694117885, 61.45018492975543, 63.006177410002685, 58.36739809282365, 55.946275880259854, 59.16810681743007, 60.227072238922126, 66.6333656926309, 62.70221725586922, 68.2849031879056, 66.2417797888479, 54.866212029610914, 62.22144842147828, 65.3833298529348, 63.80279902488955, 62.76928586344566, 66.178206013095, 60.37250588017126, 51.09593960546678, 52.26091492560602, 54.88612982534594, 71.97282545028195, 68.83384673826157, 74.06135420645438, 71.38537206957417, 74.16110007993638, 72.86039506235431, 69.28230700954315, 65.89526191834481, 66.88267938552364, 70.68351884042063, 66.10927427968672, 58.19649257967549, 32.147651795418035, 1.4981464681125458, 0.222976325500396, 0.4516605269764701, 1.891956600931383, 74.18825072626915, 74.12067613294049, 84.18109278525077, 50.812144356389204, 38.52069139480591, 57.44872800765499, 69.56949510881978, 50.887595069023874, 57.796100954855646, 72.5714183622791, 82.29899052650698, 29.129931196089718, 0.5850091925071133, 0.12208927978551197, 0.2622337657357416, 0.23179490149261492, 0.46865548277574204, 0.18558528995321644], [0.016156562581478108, 0.10465384641241644, 0.08798638553989512, 0.09971033466318924, 0.0837252053221868, 0.093908429055685, 0.20032249270908295, 0.2708329494682051, 0.4031784688272784, 25.697561156365182, 59.51866472921064, 45.19933462142945, 22.66399222035562, 19.80477656087568, 38.62772895443825, 36.296527078074796, 34.029789355493364, 23.482126074452555, 69.93792333910542, 61.65536803583945, 66.38373821012436, 55.10149148202712, 1.0634881594488699, 0.9088881229681354, 0.0642616231174719, 0.32273335322257013, 0.3653703137270866, 5.823047305307081, 13.651104338707464, 38.706160668403875, 56.7144367771764, 56.96303659869779, 59.63979144250194, 51.184149788272, 55.44067844267815, 50.4415431330281, 51.77032055393342, 49.13165584687264, 52.798695410451586, 45.042027965668716, 49.6961868962934, 48.51502003208284, 54.35690010747602, 54.194392388866795, 66.2160490405175, 53.19588245884065, 45.711156860474624, 55.65008201906758, 63.982749523655066, 59.7446560090588, 59.61353117419828, 56.42010996418615, 55.38657326852122, 52.71023027358517, 51.87041944073093, 54.01994497545304, 58.24542022520497, 54.710658673317205, 57.81798778041717, 55.9157794521701, 54.39808107191517, 51.98365434523552, 53.45322916584631, 57.28465526334701, 57.25160537227508, 55.311267683582926, 57.46462145159322, 53.04612244329145, 56.14617555372177, 46.963224487919966, 46.20945868953582, 48.54573219053207, 50.11115404867357, 51.3851006569401, 44.02490638917492, 43.45481734122, 48.90168728366975, 48.25001293613065, 48.93199543799124, 47.61588727274249, 51.33129358291627, 50.46334366644583, 57.10270043342345, 57.70068145567372, 56.78143478208973, 55.34230147638629, 62.12551509180377, 55.17674607615317, 38.29416667261432, 36.93112734825381, 43.36100209143854, 60.31285447459067, 64.31693938470656, 53.215176597718276, 52.57107634698191, 55.24312434657928, 51.60584772786787, 46.40085074209398, 45.22423382728331, 42.91947657062162, 44.53375547162948, 44.69314882832189, 46.11827142776982, 45.81727658548663, 40.11979856798726, 44.150284951733006, 47.08033077178463, 47.943350268948464, 47.76230935127505, 50.93177664664484, 51.370132892362534, 53.929251932328754, 52.595257759094245, 56.0082140276509, 55.45900767849338, 51.5660866614311, 51.949361062818966, 50.96090416754446, 51.904045920218195, 56.31346856394122, 54.39230734302152, 56.46810408561461, 54.619910717010505, 51.90953331608927, 51.880743119024466, 56.084311931364006, 54.15597669539913, 59.05526022757254, 59.315540867467085, 60.29647073438091, 59.2312373653535, 55.72691340600291, 60.704263871715916, 58.91507079524379, 60.86034282561272, 57.641037894833474, 57.992886266400745, 55.98589181900025, 49.50601470085883, 44.023655153089955, 44.588982443655695, 56.13318466371106, 60.53485670397359, 64.22380270496492, 65.81880707894602, 64.71087478822278, 66.70035193043371, 53.152261780154326, 64.77573902376237, 55.87571244085989, 58.89802809684508, 42.796133718182965, 16.85958254721857, 2.9819414740608585, 0.08031662733804795, 0.10095656053313326, 0.2847593554085301, 5.041697928982397, 72.79357356409874, 59.48957250964258, 73.16362565563571, 41.718348764604144, 23.175565388894853, 31.46401405334473, 50.805829340411776, 36.09483095907396, 31.663819589922507, 46.671949278923776, 63.272443586780184, 25.378468498106926, 0.06678371479915035, 0.03608748714830126, 0.012340621174042745, 0.06578562480788078, 0.017902028799477606, 0.059406184666459604, 0.050087081298472426, 0.05598618048093012, 0.03028205945156515, 0.03154370284098531, 0.10225668834942965, 0.047603527669824904, 0.26943033440939845, 0.17227055925515392, 0.20127244173519074, 27.65653990930127, 71.20587656574865, 51.23725868040516, 32.067704085380804, 37.47502673056818, 47.28701614564466, 36.42896982931322, 50.8846454466543, 35.80467754794706, 75.15096510610273, 72.52205925603067, 70.48510182288386, 62.9381948901761, 1.4505298748131723, 0.11757303059341447, 0.28647882443281913, 1.1041777244498654, 0.13077005954279056, 6.982509243872858, 23.042624496644546, 50.244408730537664, 59.633864741171564, 61.16023155950732, 62.11358324173958, 55.23276144458402, 55.91189238332934, 51.81621228494952, 52.531986005844615, 51.250324095449145, 55.2179584195537, 47.600868517352694, 51.88797989199239, 50.26108272614018, 56.903498941852206, 57.6929896877658, 70.29377645061862, 57.36500893869708, 44.5212431107798, 55.1071475398156, 62.971287927319935, 63.20421003526258, 62.22659457114435, 58.75099020619547, 57.37470503776305, 56.09691450672766, 52.670492741369436, 56.19817833746634, 60.1564460415994, 56.263364207360056, 58.18771823760002, 58.0774917910176, 58.701360456405155, 56.175471736538796, 56.95692554596932, 58.91148967127646, 59.17999159905219, 58.48190384526407, 57.58301819524458, 55.2193469385947, 58.087611506062174, 48.63382470223212, 49.11712738775438, 51.087941892685436, 52.21785122348417, 53.82718009333457, 47.29883032460367, 46.0766472355012, 48.29357085689422, 49.649695042640936, 51.90664645164244, 46.7540091852988, 54.76654460353237, 50.91685202813918, 58.21838332760719, 57.195240912898896, 56.830385961840236, 57.78152542729532, 64.44054503594676, 56.392602382167695, 38.937604042791556, 37.28590180796962, 42.13373953296293, 60.87023896555747, 64.32768275660854, 53.65814555075861, 56.202394885401574, 57.84773895817419, 54.715753832171046, 47.71724131799514, 47.796280999337476, 43.91376995271252, 45.98753098518618, 45.90441988360497, 48.78946435066962, 48.368778382578206, 44.70354310927853, 46.15228622190414, 51.17332796896658, 51.99954778917375, 51.034409384573664, 54.10499372789937, 54.00648732339182, 54.50395368760633, 55.00042376979705, 56.186615190198346, 57.665348745161495, 52.08454947317801, 52.93950849963773, 52.59493220236994, 55.09452535260109, 58.93803235023253, 56.533368402911776, 58.37030064675116, 57.172616681744984, 54.828467061442716, 53.888514195719075, 57.62510130482336, 54.9133667638225, 60.50318748720231, 61.675399580309474, 62.811780821892526, 62.72184871858167, 56.58520252473893, 60.91404791801207, 61.791866517836056, 63.25035672033987, 61.261715042975645, 62.62582125202302, 59.928544567477324, 52.24963026662027, 46.953653904699514, 46.21533440005395, 60.3377732922954, 64.21727195862802, 68.02164939142042, 66.56369655363022, 67.96854834402761, 65.09512585978355, 62.40608615259971, 76.92644949882262, 56.14690119220365, 61.09789725272887, 50.07865328942576, 22.368139605368338, 2.223254817147409, 0.15941005740915576, 1.0197351007692277, 0.6688060347110995, 6.067068249948564, 84.11732289098924, 62.42179524513983, 85.65922229520737, 45.518741069301484, 33.7513049956291, 42.86468498168453, 62.79130604959304, 35.10345974276143, 29.63886068713281, 57.82839382848432, 70.72125988621866, 37.90481259745937, 0.18033934967412105, 0.0137055303428262, 0.04115823077999296, 0.11649221076720184, 0.022407995176411444, 0.026891940355961843, 0.15129183899731408, 0.22564378236570667, 0.11485822183350403, 0.27475835334870125, 0.19000465200553018, 0.20682224312857275, 0.4812891000220853, 0.41410671306713936, 0.5056877746697396, 37.19423209467242, 79.12937810344081, 62.73107021085678, 35.867706114246005, 30.56731120232613, 55.29140480103032, 50.39023460880403, 50.80250709287582, 36.613584026213616, 84.25552368164062, 74.02688441738006, 78.01832752843058, 65.61128624023931, 2.0385478316776218, 2.0860297160763897, 1.083833616106741, 2.2061527928998395, 0.45689070116608377, 8.118999331228196, 33.647126843852384, 61.13606583687567, 63.35047914135841, 66.36353800373693, 66.87732142786827, 56.94083598352248, 59.04179473077098, 56.54796354232296, 53.71594559761786, 54.64593172073365, 58.64537254456551, 49.47318446251654, 54.06539740100984, 54.46314142596338, 55.895802820882494, 59.83407035950692, 66.15224776729461, 57.01871464329382, 45.851997406251975, 54.34245009576121, 67.11270286190894, 64.98395804435977, 65.02660989761353, 61.17185354232789, 57.72958147910334, 58.17878700071766, 55.72248897244854, 60.236525151037405, 63.43420605505667, 57.9736941091476, 60.976001754883804, 61.51834003386959, 60.677077924051595, 58.79707805572018, 60.024046436432876, 61.711591289889434, 63.42438444014519, 61.03417834927959, 60.69591706798923, 56.39685815380466, 61.91512307813091, 54.15761624613116, 53.41240513709284, 54.1051035542642, 57.12344192689466, 58.01021137545186, 51.57749683626237, 50.64738127493089, 55.0170075508856, 54.51174351476855, 55.908978062291304, 51.745676302140765, 60.5583320894549, 55.58610031681677, 62.38244994994133, 59.84732797068935, 60.600022962016446, 60.61640277985604, 67.06767405233076, 59.89500438013385, 39.14947871238955, 38.00803369091403, 43.284782594250096, 62.532790476276034, 67.96224117279053, 60.03692750007876, 57.324686973325676, 58.858408235734515, 55.36452562578263, 51.05509596486246, 50.51003948334725, 49.47251373721708, 50.975005088313935, 49.48185290059736, 52.1510140357479, 54.46783258068947, 51.13437491078531, 51.55810071576027, 56.31499828830842, 55.17269426776517, 53.89991260343983, 58.55141608945785, 56.35318648430609, 57.58607764397898, 58.61395828185543, 61.6912224215846, 61.174391315829375, 54.775981826166955, 57.62283809723393, 58.17182087129163, 58.01943286772698, 62.018171587298, 60.27893381734049, 62.306905100422526, 59.53950428193616, 56.84176868008029, 56.16214352269327, 60.06482731911444, 57.30898180315572, 65.22522303365892, 64.15928756037067, 65.98004002724925, 65.09591425618818, 57.21944193686209, 58.73442995932795, 64.85586912401261, 64.71805664800829, 63.550523942516705, 63.204268870815156, 63.112559933816236, 55.18742276776222, 49.87433702714982, 51.21261050624233, 62.99577920667587, 66.8194664678266, 72.2263203897784, 69.7872886350078, 70.0148331734442, 71.24648878651281, 57.88483281289378, 68.92676768764373, 62.878049265953806, 62.25924045808854, 61.82038607135896, 32.94259463587115, 3.7477038416170307, 0.2492491729677685, 0.5357906787145523, 0.6455218647756885, 7.026554028834067, 86.72514207901494, 71.6510420460855, 85.96259409381499, 56.64316731114542, 39.50890510312973, 45.983318359621116, 73.0301473986718, 48.58062951795517, 51.0208026824459, 63.55356377940025, 83.943342239626, 47.266215816620864, 0.16435121726845542, 0.10357760013111177, 0.1616838216901787, 0.2216737615245004, 0.08311458728125981, 0.2055841684341431], [0.03166982006551999, 0.059462940290329926, 0.0681912558033101, 0.1033707487306768, 0.10910506240062176, 0.03138830956642426, 0.15955434240881475, 0.06933464203029871, 0.48356254254618003, 18.135980636842792, 71.21474112233808, 47.92971218785932, 46.78332105759652, 29.074368861413774, 38.54994050918087, 56.44657811810894, 25.583624147599746, 10.832466579252674, 39.850190531822946, 70.11204519579488, 59.39208199900966, 74.75213850698164, 21.837360551280362, 0.4651594558550466, 0.10569591751141895, 0.9097334550273035, 0.04308209589291965, 1.3969245577050795, 8.726603888696241, 42.116092789557676, 58.08887843162783, 58.74152944933984, 63.41717904613864, 59.654578778051565, 63.01368874888267, 58.53345555643882, 55.36977375707319, 47.57324718659925, 49.514734129751886, 47.72666285114904, 50.77514071618357, 51.69496790055306, 58.831383105247255, 57.56101369857789, 61.39759379048502, 43.61128068739369, 49.64749067060409, 55.27670767999465, 63.82466231623004, 59.232606272543634, 59.385017810329316, 54.80068099114203, 55.91451644897462, 53.059434967656294, 49.28570693539035, 51.34246841553719, 57.3228983725271, 55.62768528538366, 54.371259904676876, 55.761500866182395, 57.09723264940324, 52.580340985328924, 53.953386275999016, 50.52217921903057, 52.16383234147103, 52.22540178606587, 56.712628564526966, 55.64298252905569, 56.340203439035726, 51.343350948825965, 48.08648147890645, 47.71242072505336, 48.52221365897886, 50.828790895400516, 48.042915713402536, 47.201233909976104, 46.48283220106556, 47.91179480091218, 49.247389301177, 48.37813323543918, 47.906464299848004, 49.94749315323369, 53.18035771769863, 58.922217353697754, 55.76006135632915, 46.77140489701302, 63.45091535199074, 55.62243323172293, 38.51308984141196, 39.07029390335083, 46.291730403900154, 59.63370000162433, 59.134962789474, 48.837995836811686, 54.100898773439475, 55.207975987465154, 52.344241757546705, 50.482877069903964, 48.678896657882206, 47.10946221505442, 45.37883404762515, 47.13387896937709, 44.12235375373594, 35.17907911731351, 38.22379935172297, 48.872030242796875, 47.57955043546615, 50.256493553038574, 50.547909967360965, 53.0277814403657, 54.257468023607814, 51.95262447480233, 54.82221480338804, 58.602897197969504, 49.12953384460942, 49.949740671342425, 50.19386114612703, 51.47378544653616, 52.749920737358835, 56.865330357705396, 55.51643902255643, 54.79697435132919, 54.419756089487386, 50.335486165938846, 48.81186892909389, 54.778280335087935, 54.68510443164457, 57.05280396246142, 58.15324452615554, 59.57237766635034, 59.33233253417477, 59.14846750997729, 53.68399397019417, 56.90935504051947, 61.62377334410145, 60.22440894957512, 60.412718019177845, 60.383967045814764, 49.81084954354071, 47.902808650847405, 45.13183847550423, 47.10413563636042, 58.90006380696451, 59.69907022291615, 65.32255664948495, 64.05961228955177, 67.41773774546962, 42.67129252033849, 48.58680725097657, 65.80660850771012, 43.66509560615786, 14.677326794593567, 2.7790875204147834, 0.27315851661466783, 0.17688548823277797, 1.4927331069784782, 1.3263369712137407, 13.308733394069057, 76.33089250133884, 58.09388337596771, 72.84330137314336, 30.18886523862039, 15.242415801171335, 27.77389526367188, 51.386136162665586, 51.1397603250319, 56.95160681201566, 43.2482143371336, 57.09249442623508, 41.67474769776867, 0.13630709791135404, 0.05846218048264423, 0.023568867360271757, 0.036834403722276615, 0.035941957255765315, 0.05565010919986714, 0.11862742038623941, 0.10353575640868756, 0.07252975727521604, 0.22726772022583794, 0.13364092807375616, 0.024991548177035108, 0.093585561299997, 0.12141804120713666, 0.4146260593927676, 23.256825131754724, 79.99668475120299, 55.817928083481334, 45.009174193105395, 31.48416130773483, 51.29465080076649, 64.36631418043568, 30.68496857920001, 17.223976619781986, 43.9508520403216, 79.84492824923608, 65.90350674044701, 80.04151744227256, 25.607315263440533, 0.5299739876101094, 0.7047705532562348, 0.4737866171185048, 0.12247660617914893, 1.294910696245009, 12.006801655215602, 52.58031352873772, 62.49118981822845, 62.80438323174754, 67.3968707361529, 60.70834313669513, 65.29192686080933, 61.61447732679306, 57.4688889903407, 50.1482714376142, 52.7361963641259, 49.23967399904805, 53.46598863601685, 54.23141564092329, 62.711477971846065, 59.46010374253797, 67.76092944606658, 49.189585331947576, 48.436345131166526, 57.28517301620976, 65.85373970770067, 61.280287465741566, 59.90433569877379, 59.13089921397548, 58.10562695226362, 53.91483722194549, 51.08324681558917, 54.50919789652671, 57.30659307972078, 57.31378670661681, 55.38336476972027, 57.58565402800038, 59.95702489729851, 56.9169173702117, 57.823824267233576, 52.385528625980506, 53.62092618019351, 54.123930931091316, 59.88232727973693, 57.68508218949842, 56.199288368225105, 54.2234375399928, 51.50736485758136, 50.29493670309744, 52.08397680713285, 49.39540778436969, 47.67032192599389, 48.2696718554343, 47.17680931091309, 49.701501707876886, 50.96082572014102, 49.98355150222779, 51.24910031595538, 51.21471681902486, 53.57356356036279, 61.386972012058386, 56.34836196899415, 50.03567980181787, 66.39559945752545, 56.26897711907664, 39.4905052646514, 38.492403261123165, 46.71437363470755, 61.462085400858236, 60.151558768364694, 50.74227125413957, 56.953171837714414, 55.945256064015055, 54.1375062542577, 53.42211692563949, 49.44409616531865, 47.013591643302675, 47.867503396926395, 48.296304748904326, 48.39342655674104, 39.06435935728012, 41.301636157497285, 51.16106271743775, 49.757203286693944, 52.722495525114, 52.42616830333587, 54.323661942635816, 55.02957874728788, 54.239028961427756, 55.2051636480516, 57.84924122595019, 52.02975788424092, 51.00711753291469, 52.632433983587454, 55.527684457840465, 55.109865742345015, 60.021340001013975, 55.92482443778746, 55.51670574372815, 56.34523976233698, 53.03680289176203, 53.938736223405414, 58.16431345478181, 57.41867088502454, 59.842632893593084, 60.643325928718816, 60.83846384479154, 61.23633338559059, 57.384863976509344, 55.07322296019524, 59.443618020703724, 61.04940499028852, 62.98633021693077, 65.16434392621441, 64.32145795514508, 51.53404481949345, 50.185879122826364, 45.994536338313935, 50.53103985324983, 61.504658806708555, 64.55339554817446, 68.76464043894123, 66.1803162482477, 70.5615488175423, 47.359407409544914, 57.431638240814216, 71.36200258808752, 48.18921227608958, 22.402644695774203, 2.941157159305388, 0.4500779118989745, 0.24829738533064244, 4.113126310610002, 1.0997931274675554, 15.558790256900174, 82.10186004638672, 64.8039447876715, 82.11436456249606, 33.01462111934539, 31.752259231382805, 28.562876101463075, 58.23353936595302, 54.39735543343329, 55.60444524211269, 50.56687462714411, 65.83685782647902, 55.36921285813855, 0.21376299972255386, 0.06472630906970271, 0.05382238812143764, 0.03186339324700736, 0.1240129572068972, 0.04895822775940742, 0.10569846092332756, 0.3745805291879562, 0.22937689817720847, 0.36313983341378553, 0.3076535559469654, 0.12985456915151689, 0.27703875195114847, 0.39297184876857266, 0.7414368083400111, 29.851590433428367, 93.82558130448865, 65.98775140700802, 66.4441740897394, 38.178982350134085, 56.134753611779985, 79.61630113663213, 34.00431748359434, 19.991030308508105, 52.70115390900643, 82.4116409978559, 72.71614597689721, 89.3117412444084, 27.586302026625606, 1.5456147467897785, 2.9160574222764666, 3.032784461975098, 0.25421196715004984, 2.3101635084998224, 18.819100626053352, 61.55397868925526, 67.64916543037661, 65.35237450753489, 70.88452462227114, 65.74869471211588, 69.77141088055026, 65.36923677690568, 61.615618736513206, 52.315875176460516, 55.02219684662358, 52.246559050775346, 56.651447434579175, 57.16875314712525, 64.12917160218763, 62.34616802584741, 63.31042781952889, 46.54222473021477, 50.309265121336914, 58.714978925643436, 70.00267382591002, 63.57729804131293, 62.521878442456654, 59.754559993743904, 61.43481316105012, 58.316489650357155, 55.72923152677475, 56.48793558920584, 62.39807667270784, 59.9408176637465, 59.60191703611805, 58.95743631547498, 63.8037129371397, 57.590023548372336, 62.40247364967101, 54.99609347312681, 56.14672076317572, 55.13238014713411, 61.1729282717551, 61.77201148002379, 59.30280885388775, 57.901267543915786, 55.93046872846542, 55.34639643084619, 56.408252639155236, 53.72548872424711, 53.686233643562566, 54.2987274354504, 55.04367966805735, 52.32026823105351, 56.778936232289965, 56.41601893209643, 57.34946458570419, 56.517682844592684, 58.3681982563388, 64.67405942178542, 60.42142960333056, 50.455918619709635, 70.9627680624685, 57.59878612333729, 38.94311105051349, 40.46267647897044, 48.838337083016675, 62.67517643590128, 63.992806480776885, 53.68860275514665, 57.540264360366336, 59.55948875796411, 56.70827473363569, 57.499565847458385, 52.5336883144994, 51.86693245364774, 51.849011144330426, 50.635943643508426, 52.14133362616263, 46.090485357469134, 46.277041127604825, 55.7100119129304, 54.927428460890255, 56.461581184018044, 55.46442054933118, 57.22794563539567, 59.61559434090892, 56.72727861712056, 57.40603300832934, 62.27454554650092, 56.622778830989716, 54.9974702250573, 55.19857014379194, 59.7913126022585, 58.80222420538626, 62.85701751708985, 59.02562672092069, 60.33433729602445, 58.997401345160704, 53.832322320630475, 56.71437401925364, 60.419919490814216, 60.050522435096006, 62.09665429207587, 63.687269533834154, 61.291022992903194, 65.53647879631289, 58.481931301855276, 58.133389488343276, 64.77598613308322, 66.63425999303018, 65.91594065389326, 66.37586209081834, 66.97391371573171, 53.295671478394546, 54.902380204969845, 49.934604244847456, 54.934245540249734, 65.57927577726304, 66.22647470043552, 73.05474065965223, 69.75452899932861, 73.42386707182854, 48.92075000270721, 49.06886654515421, 72.57412479769799, 61.54811474584765, 31.1830448719763, 4.282617809311036, 1.029590913845647, 0.28005808832183965, 4.406073920188412, 2.802010096849934, 17.441903506555867, 90.1919368005568, 69.72395804620558, 85.08522264419064, 44.21757321203909, 30.15035540826859, 38.732566064403905, 71.06807585685485, 68.95286713877033, 79.06066602276218, 60.97251084543044, 78.86696369417253, 66.76880513468097, 0.30823299420937417, 0.23672449342425794, 0.18975354370570954, 0.1655960028931018, 0.20141262050357558, 0.20425650741784804], [0.06275308491181462, 0.03957749644835149, 0.10306035288639608, 0.09149890633360033, 0.05109066414015909, 0.04830060256344657, 0.13761082634089455, 0.09882979320302125, 0.5111351501076452, 18.88254496359056, 76.94202915314706, 48.95811450096869, 45.09069281239664, 46.591795644452496, 27.677928593850908, 45.490707889679946, 52.6763213834455, 7.1697136759758004, 17.062571087191184, 54.16084435678298, 68.48369675297891, 56.97216787645894, 58.16001453707295, 0.5122457937367502, 0.22604263838260408, 0.020513743192197818, 0.1829253560713222, 0.14646455044707946, 2.277616906550623, 25.19139693629357, 61.35270226386286, 63.825776269358975, 66.15250664372599, 64.05985939887263, 64.05259909168367, 63.62181694276872, 60.162537482477006, 50.95078053012971, 49.638837922003965, 51.70800585900584, 50.168726598062825, 56.79750473268571, 59.37933429594963, 61.35960171299597, 56.897776203770796, 44.4471848395563, 50.98421089110836, 56.6079758059594, 63.20701060756561, 58.19963832055369, 59.63819111547163, 54.326552729452814, 56.49249338334607, 51.82850107069939, 46.57157190384404, 53.07702287550896, 55.13162705206103, 56.013964222323516, 59.462978839874275, 57.422848209258056, 60.895326445179606, 54.12025567023985, 53.3750484835717, 49.25025263140279, 49.07339296033306, 49.257509016221576, 53.725939796816924, 54.2479209746084, 53.75220790986092, 53.15199505898261, 42.25497999498921, 48.981370233720355, 56.42588761544997, 52.693619035905414, 48.67580190781624, 48.57462044685118, 49.80884521238266, 43.051248596560576, 48.31612056301486, 48.707604485173384, 51.82372362382951, 50.67215104256907, 56.38741700879989, 60.32730056393532, 55.97983567945419, 45.30331665469755, 58.76031368009506, 58.401958096411924, 41.18545555299328, 46.46159256658247, 44.034453438174346, 60.215913095781886, 52.61803888505506, 42.913726375949004, 54.14817117875623, 58.50882307175667, 51.5182690466604, 51.57331166728851, 47.595447801774554, 45.59677662387971, 47.32170950981879, 45.75304385154478, 42.11153891778762, 42.306123779666045, 46.836590766906745, 44.918787094854544, 50.08594105320592, 50.96834490376135, 51.89843300850161, 50.79843959500713, 57.12657197829216, 54.59702760942521, 53.68762216260357, 49.23960731875513, 48.90779441402805, 46.08256609209123, 50.20408676516626, 52.259624465819336, 53.66090297698975, 49.932360649108894, 55.484467783281886, 53.55375166862242, 53.34562678490916, 47.94788060649749, 47.30652993725192, 56.662928212073545, 54.498842839271795, 55.85641045724192, 58.60917691261538, 58.808900079419544, 59.36122863523422, 59.0719852139873, 48.12468928675498, 57.784067123166984, 63.01861916818927, 59.472855367968165, 60.15041735864455, 59.66765203783589, 55.40764031871673, 46.88993500125024, 48.775692908994614, 46.2393000818068, 52.32553205182476, 58.53396154219105, 63.29599741966494, 63.067346772839954, 67.29673262565368, 61.1931324005127, 29.759422579119285, 46.346835782451016, 43.055496523457194, 8.78779286338437, 0.4595754409749662, 0.02964383926272633, 0.4146038734864804, 4.182566481251871, 1.089718274531826, 30.688524207761212, 71.60969241972893, 61.0207599209201, 57.09919775685957, 11.031434689798663, 16.32170596430379, 36.42773428270894, 52.423450100806456, 35.217475198930316, 56.36126656686106, 69.49697832907401, 48.881514533873535, 40.06198283164732, 0.3481765427897054, 0.14912561813910163, 0.20112277879830331, 0.0554316477369397, 0.07335045194673924, 0.060190624226966215, 0.12498766619471774, 0.024149209606431188, 0.08161363717649253, 0.0839183897140526, 0.07118295938257249, 0.058698748433662046, 0.13745120426099147, 0.2236405237307472, 0.4326259693311107, 21.146635086305682, 84.22103035834529, 57.05851885580248, 48.887688344524754, 42.655093131526826, 32.0809518906378, 66.13666026822983, 46.381517379514634, 4.40878035560731, 24.566781059388195, 57.537840335599846, 77.29541901619204, 61.7484615695092, 66.03058368928971, 1.0273737941057453, 0.3043841378342721, 0.13849659252070612, 0.11811746629856287, 0.05527488699543381, 2.072581134496197, 34.26990901270221, 65.9456329960977, 66.43637641783684, 71.41161272602697, 65.14754441476637, 67.58042981547695, 64.82423520857289, 62.61056323205272, 52.331388150492025, 53.24772834777833, 51.49980645025931, 52.905521162094615, 58.653578142966, 62.34674069189257, 63.76449315778671, 64.18966239498508, 47.592878649311686, 52.4151268313008, 58.295089198697, 64.38438453981954, 61.32723823670418, 64.21031759631249, 56.832653091799834, 58.143113044000444, 52.839899909111764, 49.82946511237852, 54.562330322880904, 56.03581966892366, 57.28993869596913, 60.59675562766291, 58.261615691646455, 61.58950751827609, 57.893748360295454, 57.80372212010046, 51.07795161585654, 50.66128999956193, 53.267202915683875, 55.82708289546352, 53.92163076708394, 58.01404745348039, 54.93101742959792, 47.184814868434785, 50.263855841852006, 58.69908548170521, 53.87373078253962, 52.39329099655152, 49.735285082171046, 52.84714452682003, 47.85987830931141, 52.574865356568374, 49.99090594630088, 54.5110845565796, 53.042886487899295, 57.78297670425908, 60.965603551556995, 55.3421445815794, 47.52389984746134, 59.512969447720444, 59.79173621823711, 41.450572475310295, 45.44194106132754, 43.411632045622795, 60.33792626473212, 54.0110961083443, 43.98846757027411, 54.73655023882466, 60.76474289740286, 51.82604174460135, 51.917217239256836, 48.400784923184304, 47.93676853179932, 50.168302982084214, 48.227349481275006, 44.85088302243141, 47.77193092530774, 50.71145711406585, 47.39567756652833, 52.51318216323853, 52.21706674944971, 55.50552306636688, 53.33467160501788, 58.52450078533542, 57.67170690721082, 54.262312150770626, 50.81738072056925, 50.85175245038925, 49.302777090380275, 52.77191346691501, 55.716770156737304, 56.87427336169828, 52.951824741978804, 56.379764464593705, 55.38362756852181, 55.48467566890102, 51.278455334324995, 52.120599977431766, 58.35390513943088, 57.755080807593565, 56.477804107050744, 62.711925122045706, 61.15386947508782, 62.28452405621929, 58.06663074801045, 48.61964533405919, 62.21322321122693, 67.75925851637318, 61.88016691515523, 64.42738940638881, 62.601122087047955, 58.98204526593609, 50.89016422148674, 51.9878512813199, 49.62649422307169, 54.180416983942834, 61.353353377311464, 67.14063798227619, 67.13669207788283, 68.82198549086048, 66.05043872710198, 33.32123671808551, 53.437229817913426, 49.20354504739085, 11.994649171829225, 1.4081877662289528, 0.08778081350629369, 1.5856216968067232, 6.537402108792336, 0.42234133087819625, 39.675456785386615, 75.439055350519, 70.08014063681327, 57.21985378573018, 17.496177342630205, 15.430196331393336, 24.466325236905007, 63.08892373115786, 40.42812039775234, 50.73219860753706, 70.24101272706064, 60.77246604427215, 48.223693832274414, 0.40320163532610864, 0.07577955587616853, 0.07443402968947926, 0.018531584533892812, 0.01286196603154343, 0.062424617053400126, 0.327772802162555, 0.14039825257514754, 0.1954229620675887, 0.2303571383198423, 0.24791846292153483, 0.1508166346578829, 0.166091431953734, 0.3659207019354067, 0.7115223619245714, 25.53237053655809, 98.18588410654377, 66.33772880800309, 60.46169665551955, 60.20660138899281, 40.17517459008002, 63.00782872784523, 61.91045937999603, 12.81792623381461, 32.408124631451024, 67.35403845387121, 81.36049286011728, 67.9589306923651, 69.18226303592806, 1.1024017487802813, 1.528683223070637, 0.28259328776790255, 0.38017756756274934, 0.22185972170724025, 3.1959082378495127, 39.40912785068635, 74.35503775073637, 71.13830197242, 74.65855075467017, 68.05360886358446, 71.47019724692069, 67.94835598238053, 66.45592551077566, 55.220919809033795, 55.95042967027234, 55.981894923794655, 56.64117082472771, 60.253477634922156, 64.91856821121709, 67.1139423308834, 55.62562604104319, 47.74226996206468, 53.42076763030022, 59.902582399306766, 66.09960955958213, 61.58272181787799, 65.28534120129001, 57.89905924950877, 61.566789150238044, 54.614011472271336, 51.53914390071746, 58.733574882630386, 60.418228949269945, 58.60598802566529, 61.407458551468395, 60.00183405414705, 62.83801363360498, 62.05753649434736, 61.59547736567836, 55.19908005191434, 54.303712767939416, 54.445730024768466, 57.50986206916071, 57.66052815221972, 59.57864169151553, 59.293171590374364, 52.450071227165964, 55.913147541784475, 61.00465859136274, 59.149059787873306, 55.66198249017039, 56.05131695347448, 57.01919317245484, 51.284162382925714, 56.87934106396091, 55.09068535220239, 62.73828737197384, 58.046034382235625, 62.39999863409228, 64.1461633097741, 58.85931038087415, 50.699866510206654, 63.71294929135231, 61.56749517686906, 43.01908123877741, 47.42389901991814, 43.93718258027108, 62.880740011892016, 56.81077018860848, 48.05807959648871, 56.96647259496874, 62.318903630779644, 56.13354552176691, 57.75828146165418, 51.28364855243314, 52.41543277617424, 54.21220779418946, 52.65807451740388, 47.95040269051829, 49.61934374224756, 56.92553873985045, 52.466756989878995, 57.7366142888223, 58.07132582510672, 56.04752402151785, 55.911096142184356, 64.19542827913838, 60.90819574171498, 58.74007032763574, 56.36722464715281, 53.1029026739059, 53.84889433460852, 57.09886827776509, 60.765915686084384, 59.29909436933456, 54.96990772985644, 60.6709001910302, 58.12731765931653, 60.142231372094926, 50.56274044898249, 54.47149607443041, 63.434539456521314, 59.071596899340236, 59.69666581000052, 63.98865661313457, 62.76646567929176, 62.791278593001834, 60.9005549646193, 56.946378292575965, 64.5656451102226, 65.70490929388231, 65.36770313016831, 67.72697740985502, 66.2575634064213, 63.83577046855804, 54.10685293136105, 55.578388937057994, 53.282766880527625, 58.04293963216967, 64.35471573183614, 69.85148998998827, 72.60956733457505, 71.51841886581914, 70.73416448408558, 34.387203570335146, 53.704931582174, 56.50211103500859, 19.8420508446232, 2.064192165290156, 0.21073059389187446, 1.1501846750897746, 10.143161012280373, 3.4965728655938184, 39.982135142049486, 85.33675639860093, 71.61965523996662, 71.2602484610773, 24.812725436302927, 25.14395586905941, 49.469560192477324, 72.57197533884357, 49.937871579200994, 67.83656058772918, 86.19449246314265, 70.57860328305152, 65.61637747672297, 0.7336577064087315, 0.22960868573957877, 0.29676628208929495, 0.20903003191755665, 0.15624042990947926, 0.2750243697195284], [0.03746233535029235, 0.0686474381795814, 0.057271499817650166, 0.07066678466095079, 0.04849159211340932, 0.02802906572938927, 0.07424914202983342, 0.03941317058859333, 0.27604878249187625, 5.773415594331681, 75.86429519038047, 49.88895177841187, 52.122674911252915, 33.592056766633064, 43.709892995895885, 26.76437524057204, 46.68157477532664, 10.552942791292745, 18.59079710898861, 49.29857230955555, 68.86266046954741, 52.83969986823298, 69.66120012344854, 10.508577842866222, 0.9203263059739144, 0.48828728256687043, 0.056945395340482076, 0.03491642599504802, 0.14424176165653815, 3.1894591258418177, 66.82478520178026, 61.983733177185066, 65.01616462584465, 63.96500079862533, 64.33042449335899, 64.07745515146564, 59.31980056147422, 48.7040312059464, 48.863314736273985, 51.81492966990317, 54.25398103652462, 61.999960022587935, 63.343544390893754, 58.027156014596265, 49.12245396644839, 46.43065291066324, 52.93593522041075, 55.89042917374642, 63.05922354421308, 61.610535344769886, 58.035232174781065, 57.84698978547127, 57.179978970558416, 50.87418056303456, 46.62157427880072, 51.70233411173667, 52.490287288542724, 55.42901723615585, 57.07987616139074, 52.99819892452609, 54.1951572510504, 53.34361853138093, 55.17287861916327, 51.98494088265204, 49.19137785511632, 47.7427916372976, 50.62879316268429, 52.232901357835345, 52.20171851496543, 53.56259269099082, 42.850791946534194, 48.01536106294202, 51.422190589289514, 50.17898751843361, 53.356880064933534, 55.54078125184583, 52.97092668471798, 48.247847787795536, 53.1438208395435, 51.86203733567269, 55.07509000839726, 52.79059571604575, 55.936791589183194, 55.38284701685752, 60.07957543096235, 48.878486464100504, 56.88452643732871, 56.075980817118, 43.71337998297907, 40.933855118290076, 45.098211996016964, 61.173395033805605, 51.07770058416551, 45.57966724518807, 58.52380260344475, 56.643798812743164, 55.72259487644319, 51.32634747412897, 49.59974758086666, 48.04215477358911, 47.79604957949731, 45.12980668775497, 47.074761006139944, 51.30903805455854, 43.75348229562083, 47.87186899492818, 53.16457017775505, 49.96868179690454, 51.673065385510846, 52.41224781159432, 53.81840182888893, 52.976033610682336, 47.43407364814512, 46.24288905051447, 45.4597564666502, 45.90241163007675, 51.64813480069561, 53.96432184403943, 58.8371725236216, 55.27657039703862, 53.74258241345806, 50.47310252343455, 52.76314304720972, 48.60467364711147, 49.99754651900261, 53.57905095623386, 57.00890871786303, 55.5937607057633, 57.94810848851358, 59.20097235710391, 59.78938279613372, 54.00438101060929, 40.72646764016921, 47.14728955299624, 49.097464546080566, 61.43182431497882, 59.593605533722915, 61.45776687129852, 59.19519078346991, 52.09328459155176, 46.64075859131352, 48.83741140365601, 45.682649074062226, 52.35188253464238, 61.69649800946636, 64.98944936260101, 63.173999940195394, 67.63349948390838, 66.95593357086182, 49.90433923659786, 54.796550735350586, 6.024941504001618, 1.089323218311033, 0.09015831375314344, 0.19248539792193523, 3.0842844468932, 1.767441817829686, 57.045586801344356, 63.972484680914114, 57.79272771650746, 39.35465397373323, 11.748928370014315, 29.929533812307543, 32.92264546117475, 38.64554043739073, 40.50026847470192, 28.10660246879824, 46.45155522131151, 50.814599760117076, 29.244050595068163, 0.38330961078886067, 0.07192459378030992, 0.021982931291624423, 0.0894906298227368, 0.04474959734286513, 0.03777186168477901, 0.01546500160569145, 0.047230795251145485, 0.04442393719669312, 0.0711350865481842, 0.06823559697236746, 0.05148473210752972, 0.02289129514998246, 0.07775948713383368, 0.3496225184250263, 6.950966033243365, 84.70854174706244, 56.489943842734064, 60.183808495921475, 34.99703015050581, 51.4221082195159, 26.314722568758075, 48.789613400736165, 9.94794366821166, 23.71330272766852, 55.32933804296679, 76.30371832078504, 59.12135216497607, 76.41358390931161, 12.481177026225675, 0.5588896392333893, 0.18737199085374034, 0.2857359030073689, 0.04298084971284674, 0.15698735031389421, 5.879693194743126, 69.58033653997606, 63.98408312951366, 68.68407495560186, 66.28694195901194, 68.43272163021949, 66.42164399546962, 62.48232133926884, 50.831042335879424, 51.904830394252656, 53.2989074337867, 55.00069833570912, 65.74631383342128, 64.59110913738128, 58.41984410439768, 52.85181999206544, 49.00999176886774, 53.89797103020453, 57.579386080465014, 63.87280156535488, 64.12183284759521, 62.69735351685555, 58.98240612399194, 60.125435783017075, 53.97137034323908, 48.986186904291955, 52.317157791506865, 53.50812273640787, 57.8891944885254, 59.51125929432531, 56.94476227606497, 55.08404477950066, 54.16982658447758, 57.454176179824344, 55.28087715948782, 50.37669850933937, 49.85216386856572, 52.188547195926795, 55.94162787160566, 55.35941869981828, 55.73626433649371, 47.48842985399308, 50.488956743671054, 54.475453745934274, 53.38307757531443, 56.520055878546934, 56.55397261342695, 56.0983383271002, 51.17714835751442, 54.166186624957675, 53.59039837314237, 57.09714635725945, 53.86483092461863, 58.43262710878926, 56.98309952212919, 59.15338223980319, 49.54794876037106, 58.98830144636093, 58.76419290419548, 42.599218968422186, 41.14288214714297, 45.4881348148469, 60.21046492361254, 54.93247262893185, 46.00513458251954, 57.018122365397794, 59.64644378231418, 57.90894754471318, 53.08576191625288, 51.000053344234345, 49.409085089160556, 49.97971542419926, 47.466605786354314, 51.47261265785464, 53.11179076471637, 48.5684544809403, 52.63566209423927, 56.880305967023304, 54.06229872857371, 53.953088175865915, 55.221398338194824, 55.75535843449255, 54.00579306387133, 49.388065107407115, 48.76060355094172, 49.87653747681649, 49.405429440159956, 56.17975496476697, 56.72963203922395, 61.582141307092485, 56.014336847489886, 57.268781431259654, 54.06287923935921, 55.8526449818765, 50.462104197471376, 52.95324463998118, 55.230243282933394, 59.64415704050372, 57.60386951508061, 61.422430238416126, 61.45674705505372, 61.167903715564364, 52.680530086640395, 42.5857142479189, 46.769863405535304, 44.46464330919328, 66.87774504384687, 62.83587986423124, 65.21851578066426, 60.74464075026974, 54.274189087652395, 50.31374446807369, 51.05329559695337, 49.79490118642008, 56.05501967091715, 65.31272326746296, 68.17367261455905, 66.20666673106533, 70.48740817654517, 71.31381234815045, 54.3187472128099, 58.62961246121315, 9.034355994193785, 1.2665150651047308, 0.10115742112600035, 2.68512616234441, 2.0094795140527912, 2.3605311541788043, 65.9820012123354, 72.03710525266587, 63.662895925583385, 45.41664569608627, 14.311423590106351, 17.79119057040061, 29.13716796905764, 46.413657280706595, 47.78955805686213, 28.08178367153291, 56.185705200318374, 59.59345648365637, 42.18154930299328, 0.4300078485281237, 0.06548682753477367, 0.007393700812357448, 0.04179520607595483, 0.06952759659578724, 0.028790926763547525, 0.12200048253420862, 0.1858654636288843, 0.18877888068316445, 0.22529777109382615, 0.22546033495135848, 0.22016424655673966, 0.13841267524948045, 0.23928993802157142, 0.48703092901456746, 8.426591600141219, 99.52926451160063, 62.5502371788025, 73.42688729686122, 43.94687475696687, 60.41412222769953, 41.18868758601528, 57.193813170156176, 16.20499191745635, 30.220285384885727, 63.014257492557654, 81.75992350424491, 63.56701358672112, 83.51919281867244, 14.352514340031533, 1.5594073937785242, 0.8200655601197674, 0.2941157404453524, 0.27476834313523385, 0.4587585767430644, 8.588925753870319, 72.93942297658613, 64.43070380918442, 69.35585145027407, 68.82614320324313, 72.35153029041906, 66.56630100742464, 65.70153605553412, 53.71989934675155, 55.06306402144894, 57.8821381445854, 59.11315048894575, 68.65392761845743, 66.41879635472452, 60.21597977607482, 47.68771763770811, 48.8969490605016, 55.82965204792639, 58.850724312566946, 66.829696009236, 67.53141587780368, 63.79326374300065, 62.725331783294685, 63.74193168455555, 56.49219528321297, 52.1327514802256, 56.97538029763007, 56.360454636235396, 60.939276602960405, 61.58625195103308, 60.063933018715154, 56.93421502267161, 56.01853770594443, 60.21927848938973, 58.30380078284972, 54.720001759067664, 52.52419225631222, 57.66427401573428, 59.36132669448853, 59.20676177547824, 60.713603035096206, 54.8690204466543, 53.774306543411754, 56.883840022548554, 57.259689377200225, 58.28891538804578, 62.712564468383796, 60.960582917736424, 55.37561808862994, 59.42665376970845, 55.50400510911019, 61.299612983580566, 57.12807424606816, 64.42707169440486, 58.698136268123505, 64.88067811535251, 53.44787905293127, 62.141710558245265, 60.07213469474547, 44.317028830128336, 41.99429927333709, 44.78665028848956, 65.25789637719431, 58.08703099527667, 48.78979775213426, 60.23399129990609, 61.74174254940402, 61.97163266520347, 58.254751543844904, 56.08837158449235, 55.514152280745975, 56.50610400784401, 53.90193262407857, 56.579687672276656, 59.944536070669855, 51.96927493618381, 58.14389751803491, 60.50131259425994, 58.29109622586159, 57.96661815335674, 58.438039979627064, 58.65797904229934, 60.296498190972116, 54.39948135806669, 52.17375593800699, 52.08760107717207, 52.026455248555834, 58.96631263917493, 60.62150186108005, 65.52369186955114, 59.195830129808, 59.175892722222116, 56.13022719660113, 57.01856951559744, 54.19701645451208, 57.18543106509794, 59.38417450074227, 61.74322520532916, 61.79822467988538, 62.66088724136353, 65.62515966353878, 62.63014370395292, 61.09193132769678, 53.8455250186305, 50.29144971601425, 55.554038863028254, 69.13607320477887, 66.48021282688265, 67.59287157366353, 66.44252669426703, 58.121112469703924, 51.832913737143244, 54.56470727920533, 52.897805859965665, 58.516357944857695, 66.31490061360022, 71.39261276491227, 68.35876926299065, 73.42283156610304, 74.71571537756151, 55.12470406870688, 61.317514681047015, 13.591130318180209, 1.7912952217363545, 0.12895397150949126, 2.373940266909138, 10.070033323380256, 2.5653823296869955, 67.90786143272155, 77.81383868186705, 68.17353140923285, 54.169249996062256, 21.686310075944473, 40.09119664469073, 44.9690483462426, 53.14380122769264, 59.68781694289177, 41.36967751287645, 68.24005480735534, 71.47997179339009, 60.74576254813903, 0.7849818588264528, 0.28116643368717165, 0.10263270728530423, 0.23706443727977816, 0.17506926230365233, 0.08360204902747947], [0.04209244819057565, 0.00568253618116761, 0.06081954793884389, 0.08411575694598498, 0.07043150373764577, 0.010729838958791187, 0.05783771923292549, 0.05312878743655259, 0.0943729158250555, 2.3144626713568166, 65.77787714619791, 53.24002873513007, 44.0130372970335, 30.119113729846095, 30.26292350984389, 71.47593175211261, 56.59235692793324, 3.6867492285466965, 37.01098680496216, 62.40203042184154, 65.85635200623544, 54.50342024526289, 62.02485138370145, 41.167514631825114, 0.12058171068107891, 0.11714491767868881, 0.20648815218479405, 0.14528312029377108, 0.3313739976334957, 0.6836154948799842, 31.190846466249038, 55.98698223790815, 64.03206940620177, 66.88624874238046, 64.12917944692796, 64.79923009872437, 56.515329422489295, 48.5599821613681, 49.01738935901273, 50.93170996635191, 60.87234135596984, 60.025921329375244, 60.68602092804448, 53.94500417094077, 50.81307788049021, 51.857797253516416, 51.88381433486939, 59.31840419769288, 59.86875195657054, 61.41269099327826, 57.56356323918989, 57.113196696004565, 56.809189473429036, 50.75417956998272, 48.09467531019642, 49.92170749172088, 51.19107669399631, 52.32790508577901, 57.727985074443204, 57.11730341757498, 53.54706010510845, 52.64574258558212, 53.10349495180192, 54.552951935798895, 53.787215063648844, 45.90065048586938, 48.122198581695564, 46.86898169978973, 47.05186220907396, 50.318200280589444, 50.41369430480465, 54.795915311382664, 56.66355971367129, 53.96973079250705, 53.87240894379155, 54.95972133451893, 54.39471175593715, 50.61908529650781, 52.62854299237652, 53.56602868726177, 57.482060309379335, 57.66852978737124, 59.34589609023064, 56.84238449219735, 61.38282998915642, 60.0244112168589, 57.261740776800345, 63.56060051148938, 45.90632223313855, 42.52800441557362, 51.06524313649824, 64.82185825224846, 58.74094893855434, 59.2576466837237, 60.648052384776456, 57.29013089210757, 55.528045315896314, 52.992401661411414, 51.64997046993625, 49.485269285017445, 48.507269428622344, 48.25354699165591, 48.42897891998292, 48.52266080917851, 51.2954705761325, 53.866780342594275, 52.50074824979229, 52.60170221328736, 53.331506252288825, 54.288384145306004, 49.90176223939466, 45.7482664046749, 44.9800152932444, 44.583173413430494, 48.34254557086576, 50.55460937561528, 54.67666741340391, 51.15841119520126, 52.19414834053286, 52.855750206978094, 50.63957968065816, 50.49932356803648, 51.408991813659675, 46.28724321242302, 48.94815168073101, 51.6135787194775, 56.948763093640736, 53.701997649285104, 60.18536567687989, 54.01646975548037, 63.54645252227784, 43.23871043420608, 39.88302077016523, 32.630809353243926, 16.330928437171444, 41.477436788620494, 58.498887708110196, 61.15739176350256, 60.136026182482325, 57.346365913268066, 55.343395817664366, 48.583802715424575, 47.675193509747906, 47.27896744205106, 54.648618544301684, 63.3578767315034, 68.25556385901668, 65.20019831195955, 70.75210540525376, 78.1799840927124, 40.633652594781694, 3.0201051552449507, 0.5276253458953674, 0.22443630522297275, 2.951631603702422, 1.7192531713554937, 8.93811966142347, 73.06669604393744, 57.40767648143154, 64.4043101802949, 39.53949174573345, 25.994739532470707, 25.903850370837798, 21.9121640728366, 38.96048322800667, 46.901243194457024, 21.897582661721017, 42.713481533911924, 53.37204787038988, 27.80743152864518, 0.21639788252932413, 0.019284173988947467, 0.0684329565434206, 0.037266622868276415, 0.023567174305959095, 0.02869361636018561, 0.01504136264444359, 0.08497916868016606, 0.07826966338700826, 0.01039997490513469, 0.05989420948730362, 0.07126477757288564, 0.12716301116010836, 0.10129098089471941, 0.15988959780623838, 2.5385008560072992, 74.28678066499772, 60.121431043071134, 50.28814315795899, 29.544392362717662, 36.24009593840569, 81.97574800060642, 55.35613959835422, 6.320744599065473, 39.735061122525124, 70.82007223559965, 71.92343496507215, 60.983842572858265, 67.36616642244401, 45.515336451991914, 0.2657327037905493, 0.7648674542865446, 0.08618630874421328, 0.10156401463093297, 0.3640180459666637, 0.5731978327516587, 35.06371436580535, 59.57670011828023, 63.67727925700527, 69.69751342650383, 65.37768556225684, 67.7615648700345, 57.5716943125571, 51.358969826852125, 50.565419427810184, 54.82210497702322, 61.908890431927105, 64.03800395227248, 62.638812142033736, 56.807032169834265, 53.57565810603481, 50.92632455210532, 52.2966790968372, 60.47220076284101, 62.03494364215482, 63.532877199111454, 60.763040588748076, 61.103667059252345, 59.73799974687638, 52.87556602108864, 49.14088910625827, 50.328747533982806, 53.964549341509425, 54.74091975919662, 59.35554119848437, 56.73943404228457, 58.61759824137534, 55.98267939782912, 56.79149173921155, 56.96127545449042, 55.53218341642811, 50.64527496214836, 50.16485521870275, 52.40346954714868, 51.914742223678104, 54.325195589373195, 53.02535741559921, 56.31356662319553, 60.35054060720629, 56.74598047810217, 56.37317880507439, 58.34551911200247, 56.57534953086608, 53.80617580106182, 54.17727124306464, 56.84741689312843, 58.391242181101155, 59.7779804660428, 61.64429518484301, 58.660461902618415, 62.1707086409292, 60.021445905008626, 60.39996639374764, 61.728669289619695, 44.06181589249642, 42.95717839271792, 49.31323412925967, 65.32387456586285, 57.44470757822837, 59.75084158682055, 61.34366512298585, 59.610240305623705, 57.75961114514259, 53.54440073813162, 54.977313164741766, 52.83914289166851, 51.65955282026722, 48.93363891109344, 54.471366636214725, 51.96659987972629, 54.73775048409739, 55.71652696978662, 56.015376275585545, 55.601134761687256, 55.15582023128387, 54.38524315434118, 52.199776941730136, 47.919619929405954, 48.764863244948856, 46.75782172910629, 49.770735463788434, 51.955138714082786, 58.94722638591644, 53.51261385025517, 51.666840584047385, 54.96763667752666, 54.81169500658589, 53.119623737950484, 54.41102489348381, 46.89249238660259, 53.350674875320934, 53.31859773205173, 57.863777529808786, 56.4498846761642, 61.82792486683015, 56.913979514952636, 67.49825616036692, 47.90295770091396, 40.95803260803223, 40.11532314362065, 26.315783569889685, 41.51994351417788, 60.832537143461174, 63.567123413085945, 64.33072259349208, 60.90559128792056, 58.33131620960852, 52.20125175291493, 51.01828452079527, 49.905708143788004, 56.370244872185495, 63.35751195107738, 68.94361034516366, 68.37834189015051, 72.01226095999442, 80.79359269911244, 45.598482854904674, 4.420571980937835, 0.8249826801400032, 0.09807466799693723, 3.322477484903028, 2.1129234471628746, 12.668716330682079, 79.57179007991668, 64.71441668848838, 71.51842671055948, 47.1918829794853, 31.120086908340458, 27.75016296294428, 25.39721546634551, 51.47218511950586, 52.326394973262666, 23.98211452268785, 52.877856685269265, 61.36955276612313, 42.1359674392208, 0.4526424678342958, 0.024934237139419686, 0.027313227427282163, 0.061509126662126476, 0.029099263746531743, 0.04471262593963935, 0.11380547146883704, 0.1717479187514513, 0.15896408698491513, 0.17095040590051683, 0.16339782084668839, 0.15565352995068799, 0.23544043813261295, 0.2707651353651478, 0.24445553099916828, 3.6282571285001697, 88.5061570136778, 71.38562310126521, 60.64030570368613, 37.034128788978826, 43.416727204476636, 84.88816276673349, 66.76285882149973, 9.977889003292209, 48.717500625118134, 74.82288237540953, 78.25706651133876, 64.04547214508057, 73.82980100570187, 49.94399439903998, 0.3356316691685108, 0.3464786468013641, 0.26157082388958625, 0.20860054770544653, 0.8274281553683743, 1.0693312652649418, 40.04670127745598, 59.42786970446187, 63.8096357160999, 71.84120639677971, 67.35843935320455, 69.70373430559712, 60.19490095876879, 54.20003667954476, 54.32949842945222, 57.11799767709548, 66.48667689292662, 65.6902906202501, 64.79661780018961, 58.594197380927305, 53.032052901483354, 50.895133864495065, 54.14799467209847, 64.59290950529038, 63.17593759106052, 65.93301865362352, 61.92910632779522, 64.87234307873634, 60.84589673626808, 55.338120229782604, 52.23898887634278, 52.74245646692092, 54.89857158353252, 57.308181639640566, 63.54739389111919, 60.46670159985943, 60.26889254969936, 59.205541918354655, 59.11257782290059, 60.343013578845614, 61.521791719621234, 54.48854661756947, 54.40138370760026, 57.93877324750347, 54.17419218247937, 59.88346084471672, 56.35791294036373, 61.11459086018225, 65.21296954924061, 61.308995293032744, 61.57162935503068, 62.46763598534369, 60.820522923623365, 59.788947413044596, 59.16774203700405, 61.46348960937993, 65.25915153564947, 63.2777113299216, 66.01461964268839, 62.02127025973413, 66.72322719327866, 65.84881321076425, 61.515406100980705, 66.83351639778384, 44.345324808551425, 43.20906908281388, 50.93145108992054, 68.35334854741251, 60.20293005051152, 62.76139797702913, 63.66632799948416, 61.6923834431556, 60.99369164436095, 59.642348827854285, 57.71921857710808, 57.45994598634782, 55.81615909453362, 54.06919817770682, 59.56072822693856, 58.18296432495118, 60.124796436678984, 60.486278149389456, 59.49025500205256, 61.22058899171891, 58.93853833598476, 59.38841850526872, 54.02851143190938, 51.82869326683783, 51.465262136151715, 51.470698541210545, 50.91416128220097, 56.674020674920854, 61.49474305491294, 55.71605628536594, 53.23794987893874, 58.66520012578657, 55.87197442208567, 56.97113237073345, 57.0391619590021, 49.90596702021938, 55.410287918583045, 58.294367482585294, 60.20151799724948, 59.551761688724646, 64.47445392608643, 59.69075872052101, 69.70721737031015, 52.95090298498831, 50.3745686623358, 38.436866421853345, 24.410792320005356, 45.94048215496925, 62.77862894919611, 66.69952038795718, 67.26055268318423, 64.4616356203633, 62.642110855348655, 55.497980348525516, 54.50489113407751, 52.64718601780554, 59.10965173475204, 68.08487799859816, 73.22764658158826, 70.65442269848239, 73.67091363476169, 79.90018660022368, 50.36022847698581, 6.727820923251491, 1.2301198825720818, 0.2590564926785808, 5.651080791027316, 10.608325677533305, 11.63684860352547, 88.58221961605935, 68.08789822363084, 77.44819533440375, 52.46493308774887, 36.67063882274013, 37.79821042091616, 32.3364786178835, 57.532815779409106, 64.34765546552597, 31.889954036281956, 64.17025842974263, 74.86361226727887, 58.24982504690848, 0.7511837756441486, 0.23405475361693293, 0.11620358714172918, 0.15990953141402814, 0.107045128581024, 0.13279107609583488], [0.05491268445527362, 0.06343558115223724, 0.03803793551220048, 0.07598508960537373, 0.054836508502522786, 0.09660575568916337, 0.028855743547601086, 0.09474154201246078, 0.02472809245509486, 0.27900664796752317, 54.7671486485389, 55.29159307479859, 48.46422141598117, 30.133734364663404, 41.667738422270745, 34.434397528248454, 65.0208636253111, 4.629617150752775, 21.236841755528605, 73.87251561687839, 60.22922169777655, 65.0527407277015, 49.474694575032885, 58.47275687802223, 2.4738856909736513, 0.3056797763753322, 0.1086986604176702, 0.09196133998733375, 0.4773006011401454, 0.7338744786477859, 11.4565303825563, 65.31823419755506, 64.24391661920856, 70.6239615717242, 61.867332919951416, 62.36749003010412, 49.57778230790169, 48.72851071819183, 49.6593911417069, 58.704231631371286, 60.838506990863436, 63.478893618429865, 59.260898328596554, 55.07161871079476, 46.174133823763945, 51.89018426402923, 50.84351939539756, 58.39401137444281, 59.73569339321506, 60.07892823988392, 60.943893232653224, 57.96578268851004, 56.42451086351949, 52.547675486533876, 46.55169333181074, 48.79862700739215, 50.241019802708784, 49.57637025463966, 53.73561236166186, 54.33420135128883, 56.26085781281995, 56.02396234389275, 55.02645261826054, 55.056717626510135, 57.686741352081306, 51.49238532589328, 46.77553515280447, 45.40131315108269, 46.8141822661123, 48.08607355240853, 49.98457524084276, 49.37730604602445, 52.61281036561536, 53.35130637691867, 51.209707952314815, 51.62862493145851, 52.40032380627048, 51.11336277377222, 53.276632293578125, 51.06849478137109, 54.37540584994901, 57.24398420703027, 58.183058461835316, 59.94765827732702, 58.33951004089848, 62.9611760570157, 62.279020970867535, 61.63452456074377, 49.029791893497595, 44.465737650471354, 49.44784987357355, 66.86706835223784, 60.75874559340939, 64.09703954573601, 61.46597639206917, 61.513127203910585, 60.795239325492616, 57.45894578195388, 53.20817908933086, 52.963501637981786, 51.79492165965419, 48.45909095579579, 49.13314242516795, 53.41897902950164, 53.342261391301314, 50.64221943578413, 51.306108044039824, 53.665429392168605, 49.88455872381888, 48.61984929730816, 47.233518938864435, 45.79302064834103, 47.50432722030148, 48.2523585134937, 52.19547017928093, 54.92907585636262, 53.82801555818128, 51.47922969633534, 49.902083873748786, 48.95309386714813, 53.37156149648851, 49.108203995612364, 49.25547330610214, 47.3958501508159, 51.26062423952165, 52.941963903365604, 56.58256669198313, 55.154223826623735, 59.63633583438013, 55.398838520050056, 63.369996855335856, 49.325083609550234, 47.559342384338386, 58.23264114318356, 52.574637859098374, 35.7570364398341, 50.99383638751123, 58.58603885096889, 62.85469939631801, 59.83854186150336, 61.254137023802734, 53.153599308383086, 49.57158496302944, 46.64065268731887, 51.93674672034479, 55.76329731172132, 60.12720869433496, 67.14959667574975, 71.74343739786457, 68.7340694858182, 38.53564346990278, 1.016846152563249, 0.13635831854997144, 0.12935592252160275, 3.9541327905270363, 0.5812692738348438, 31.652183878806333, 71.22988931594357, 62.10841355785247, 65.9522774911696, 58.18279958540394, 48.146105427895826, 24.823278573251542, 17.97485359253422, 30.371708485387988, 45.36540777452531, 35.03126067499961, 50.84751236823298, 57.83962749665784, 34.95261715304467, 0.40534324944019323, 0.07841142795739636, 0.05874959751963616, 0.052310165032864585, 0.06903943004867724, 0.04316771770977686, 0.027367753735292825, 0.0566658805004291, 0.014145636364006469, 0.03297359254511614, 0.0464875252556897, 0.018411023362028985, 0.04255593904564458, 0.05123756533007949, 0.06432280289910494, 0.5095524124560818, 63.03072360254104, 65.23757065496137, 49.57522100017917, 33.00847476528537, 43.81908785912299, 54.05982763536515, 67.43445488714403, 5.882010825218694, 27.140093195822935, 78.11057383014311, 69.32707694268996, 70.54829905110022, 54.89237423866026, 63.07472082876391, 2.9042743771306934, 0.7543484542158343, 0.060365736604698246, 0.04776875751333372, 0.7108510237547659, 0.9362152146716273, 12.167391334810565, 67.1123420038531, 65.02932417777278, 72.00589103083458, 62.57906267719885, 64.90640101894256, 51.81707520638743, 51.32834396054668, 53.43918708062942, 60.304609652488466, 62.0315037235137, 64.88412195636381, 61.602066947567856, 57.97680062632407, 44.36991806953184, 51.017503969130985, 50.103972188888065, 59.597025840513176, 63.81637827042611, 60.1410311268222, 63.05548944780904, 60.62217258637952, 59.595656933323035, 54.306991869403475, 48.14380691897485, 50.41474942238101, 51.50698831004482, 52.878715684337, 54.81549970565304, 56.33011118058236, 56.65831942712107, 58.64219934709611, 59.23212382101244, 60.24258129058346, 59.718187855136016, 53.923544883728034, 48.02928547705374, 50.903261015492106, 50.87026211523241, 49.1342406888162, 51.83871884499827, 52.432522543015025, 53.43437041005781, 56.216370290325536, 56.72803955693399, 56.488998551522535, 56.596306754696755, 54.80932981737199, 57.27960717293524, 52.56931128040437, 58.24922492427211, 60.48789024353028, 59.16525525431479, 59.19655969066005, 61.39669949008573, 64.38589465233588, 62.34931768909578, 62.062160968780525, 47.61092155210434, 42.80402552696967, 47.84776210784913, 67.7717944114439, 60.98829054063367, 66.30196463677191, 61.78493568974157, 60.27333659510459, 61.01823391452913, 60.871274471282966, 57.02110336672876, 54.064816890224336, 56.03951061925581, 52.36519898137739, 54.466910823698974, 55.484330500325854, 55.99217153364613, 54.780010100333925, 52.524356995859456, 54.26113151734876, 53.93487268878568, 50.047886217794115, 50.95172974371141, 48.888417905376805, 50.18834629366475, 51.73274424768264, 53.66325247672297, 55.37329604548793, 57.50675555198424, 52.29010912679857, 52.90619188739408, 50.76177327863632, 56.98750826620287, 50.851756372759425, 51.10244681758266, 49.0299330988238, 54.76260262150919, 55.344054775853316, 61.45902595212383, 58.85519973693356, 63.21067802367672, 56.359493655543176, 64.69869582883774, 53.469585449464866, 51.103082241550574, 59.806029335145034, 67.46505721922844, 45.387737827916304, 50.984685497899214, 62.95053074436804, 66.37762715739589, 64.9060401608867, 63.03244552304668, 57.90822582860147, 50.936514869813, 47.8697979834772, 53.90159137787358, 57.13493839386971, 63.347160816192634, 68.76849220645043, 73.95283006852674, 71.00144263236754, 43.16307929254348, 1.0457847868242571, 0.6841901221102284, 0.03131822209745165, 2.1705553224009853, 1.210039431048978, 36.61770643726472, 77.77696055750694, 66.71896749927153, 75.66405819308373, 67.26613029356926, 55.414331882230705, 31.375874473202614, 23.975083674153975, 42.14653430446502, 53.34902747984856, 39.29945445829822, 55.43685805413031, 67.79747809133222, 44.88160694799116, 0.5047635968414046, 0.10292717616163916, 0.05402302271836708, 0.07776198458046683, 0.0678759416745555, 0.006909720456948685, 0.09073550737793408, 0.17240502300762361, 0.10507242919336404, 0.29006102092323766, 0.1943815727868388, 0.12115459889173509, 0.20748736066443307, 0.23225363494167406, 0.1713651505809638, 0.7739262907735763, 75.96753197331583, 72.01565773256364, 65.29075014975764, 39.90007915804463, 60.30089516793529, 44.355609263143236, 73.42398474293371, 13.4271183706099, 32.05225386927205, 87.87348654962356, 73.58193858977288, 76.50945448106336, 62.359574687096384, 68.68449072684012, 3.683225959539414, 0.945928780542266, 0.22282297001971355, 0.2252621480053471, 1.4047756719012416, 1.094893964548265, 14.542044247350386, 69.05686486151912, 67.86821411501977, 77.08683521516862, 65.6022608664728, 68.67657538383239, 54.863803694325114, 53.912793667085715, 54.51543054273052, 64.54927313712336, 65.72689417869815, 69.18306319944321, 64.1052019980646, 58.15827300471645, 51.18986075924289, 55.464091070236705, 51.66136103291666, 62.905756888851045, 64.20625794318416, 65.15267487495177, 66.17518578806232, 64.93149242093487, 61.9887577333758, 57.37606217784267, 51.12860118189166, 54.04388712298486, 55.18547334978658, 54.868702734670336, 56.45660761863955, 59.41801278821884, 59.16170550930885, 63.040031386959946, 62.267504892041615, 64.80418405225201, 63.570884966081195, 57.98517488664197, 51.930200284527196, 52.93202853971913, 53.30926249104162, 51.527392479681204, 55.62212728684949, 54.92568692853374, 58.543849837395456, 61.50070505757486, 59.35155999275946, 62.05728154028616, 61.839307585070216, 63.05839200173656, 60.78772406424246, 54.379998945420795, 64.27757840002737, 63.99090413124331, 64.22408511561733, 64.56796715336462, 63.834491775881865, 67.77811727216168, 66.0096303878292, 64.15775783600347, 50.484030246734626, 44.041941242833296, 50.68372987931775, 68.84271913959135, 65.0353410936171, 69.13311573766893, 65.78310174326744, 64.81297408380817, 65.98204828077748, 64.74598784600535, 60.45858621597291, 56.82980545105473, 62.78590102349559, 57.6023123341222, 59.17195074019894, 61.42490525399486, 61.31161935867802, 59.88419825030912, 57.19407596895772, 58.30489120175762, 58.41706706631569, 54.47740316390992, 54.457677564313336, 50.317160852493785, 52.20626454199515, 55.42058806265555, 57.048909048880304, 59.03658582318214, 61.30983468024962, 54.037430901681226, 55.329138002087994, 54.82563903254848, 59.54715290377217, 52.26753980882707, 53.66096965728268, 51.16454970452094, 56.18223782508604, 58.22054455357214, 62.916233539581306, 61.953962387577185, 65.51101084678405, 58.535652083735314, 68.00288477251607, 55.420505692881925, 55.57766722094629, 61.740150067114065, 53.77627165086808, 40.77117873776344, 56.887934977008456, 63.28189649889546, 74.86813083771737, 66.54220980982628, 67.74986836218065, 60.00698020381313, 53.912366128736934, 52.560105477609945, 57.09980180186611, 61.23251691941292, 67.20091696708434, 71.35896667357414, 78.83786755223429, 72.37013016977619, 49.16843591197845, 2.180676998630647, 1.8578590693012362, 0.2582944803420575, 8.61408873911827, 3.4181830719594037, 37.52322089287543, 84.86385191640547, 73.71953533541772, 79.81051337334418, 68.37239557696928, 60.919394108556936, 38.25075387954712, 28.053275885120517, 41.86336663461501, 65.65954708283948, 49.37918093896682, 69.35800875386884, 76.31921168296569, 61.501873923886215, 0.7689496610433825, 0.3320289721652385, 0.26028195756577677, 0.19839785001691312, 0.24336774743372397, 0.16258330084383488], [0.0732943743106819, 0.1064875391462157, 0.023385065630258575, 0.016177258446752545, 0.07085204770367953, 0.0378787960676897, 0.09246941715959581, 0.1290852023709205, 0.05340185947716237, 0.027014072008070447, 44.444219527706025, 59.159811004515625, 36.21410239127375, 27.66195081895398, 48.696084483977295, 28.55093444547346, 17.896629764187722, 13.079793472443859, 27.33610187807391, 70.51692008972168, 62.1083390328192, 63.95441824390043, 56.355233961536044, 63.56823344384471, 6.975060172619359, 0.4933635650142547, 0.09060452932551985, 0.10676322354664726, 0.16740678959796507, 0.6602075251360094, 6.250934254738593, 69.21248097573557, 67.47056422695037, 64.97255963663902, 63.18117003287039, 55.85555930291453, 48.37125339815694, 53.41074597450995, 58.7672366634492, 61.34359059795257, 60.98684710841025, 59.39094843402986, 58.60612138625115, 55.22160622381396, 53.05507329202468, 55.899203515821895, 43.823657420373735, 56.70879640886861, 60.982795300022254, 60.600003350165586, 59.223141593317834, 60.198960611897135, 58.86074204598704, 51.90535206948557, 46.528398375357355, 46.90633050857052, 48.30943684424124, 48.966873153563476, 53.46871860565678, 53.2532863463125, 51.56453732521304, 56.02725321246732, 54.25934683892035, 56.10841097370271, 55.82226230252174, 57.3484290799787, 54.386863093222345, 48.22185031829342, 46.60075041555589, 45.59785135330693, 49.151918811182824, 49.17719064220306, 47.71212262492026, 46.12724188835391, 47.17856261038011, 49.96462214377619, 49.34141635894776, 46.330185321069536, 48.256677043053415, 51.52690218340967, 48.06657937265212, 51.68419314968971, 56.835465431213386, 56.43184961811189, 57.55742472987021, 62.30816418124784, 61.16919025298088, 64.5201652280746, 48.12554828582272, 39.731154441833496, 50.69439872618645, 64.77507614320325, 66.42571541570848, 64.47113952329083, 59.77247345832087, 58.58696453032955, 57.63945325728386, 54.20249208327263, 50.920715562758915, 52.24056174678188, 49.9399818143537, 48.4075157104, 48.357442732780214, 51.46325388262349, 49.10748620187083, 50.66866013311571, 49.550910149851155, 51.430509936425, 49.005739919600956, 46.894092713632894, 43.5401955727608, 43.51570429340486, 47.02366036753501, 53.02922095021894, 53.86213233394008, 51.49563304839596, 52.72641397291615, 50.314830964611424, 48.543174805179724, 52.0027562879747, 50.557217751779866, 49.51437327169603, 47.06349203663488, 45.70916821879726, 48.35906659403155, 54.36970664608864, 57.94437046973937, 55.47680347196518, 59.714410612660075, 52.595630384260616, 60.03466821485951, 56.279657733055856, 64.09659239553636, 48.05137626586422, 52.79165867836245, 57.696606113064675, 44.82348526677778, 55.25585636015862, 60.812925292599594, 63.403156572772616, 64.72166915093699, 61.573672909890455, 54.583526811292096, 46.372703813737445, 51.201937737003455, 52.01076576786657, 58.09759786052089, 68.32061244595435, 67.72372968735235, 71.81063544365668, 25.605991463507376, 0.38815125582679627, 0.1464099743433537, 0.09080213404470876, 1.3720838196815983, 1.4950506148799774, 47.84537338441419, 59.71149236925187, 66.49121115284582, 60.787018037611446, 61.1059263444716, 55.54949675836871, 19.60713617263302, 20.32467496010565, 33.35496910156743, 38.46902201252599, 26.442162336841708, 54.8826781395943, 55.49776854053621, 37.05496049696399, 0.06284971924258337, 0.1757775259114081, 0.08854354596546582, 0.07414483915894263, 0.1082483462748989, 0.081774975293346, 0.0684451450022959, 0.030463197110821644, 0.05655993820138036, 0.015572276897728445, 0.08308511587881273, 0.024311103137029756, 0.024377720227705377, 0.08737193705934672, 0.10345468132366097, 0.04601594068170075, 50.35021466593589, 68.45948003953504, 39.76518100307834, 30.080054767670173, 57.73192705646638, 28.210974777898482, 19.45602882292963, 14.457273983186292, 36.11836910247803, 76.63057727198448, 68.55022799584174, 69.30399771659606, 61.385814912857555, 70.61727000821021, 7.887718244906395, 2.0485849318004425, 0.5556324785274844, 0.16455207020044327, 0.46575105959369295, 0.8647212542353139, 7.354070957629912, 71.97069952564856, 69.85334919344994, 67.60237155422088, 62.278385546899614, 57.87898063659669, 49.74697766765472, 55.437050250268754, 60.457735061645515, 65.95152439609652, 62.8060188601094, 64.25393043025848, 57.90344053699125, 58.243055035991055, 49.91732620423841, 49.47835806877383, 47.36903682831795, 58.74613823429231, 62.77158829473681, 63.45720683374713, 63.64033052998205, 60.5786499669475, 62.10135721391248, 54.21647141056677, 49.132965918510195, 50.74233401206232, 49.84854352089667, 49.90509233167095, 54.32490533398044, 55.1069631884175, 53.87347975084859, 56.959628059018044, 56.98895954316663, 60.52067733580067, 58.81360692362632, 58.45753808175364, 56.30888723557996, 50.45705610705961, 50.06581537185177, 47.57507108872937, 50.79671767450149, 50.0320476870383, 50.76669585320258, 51.048643665929, 52.99703005821475, 55.24421084311701, 55.10434696751257, 51.76709636565178, 52.01736711686658, 54.38634926272977, 54.202452859570904, 54.6337253047574, 59.377333887161754, 59.01446365541028, 59.6710095867034, 63.99675238517023, 63.85460176775533, 65.8265027692241, 47.52145228847381, 39.23541392049482, 50.672837457349225, 65.74640797030541, 66.01792227837348, 65.02222076539071, 59.485708975022845, 59.74437752077657, 59.177210638600016, 57.08049589587797, 53.518293442264685, 54.10513885559575, 53.77594609414378, 51.20728000517815, 52.39008642012074, 55.6655087009553, 53.04776199402348, 53.46328220059795, 52.71587848663331, 53.04614989988266, 50.60787516255533, 49.02825432439005, 48.94895184424616, 46.03879244096818, 51.50529776850055, 55.29187940782117, 57.06272755899737, 52.59824660516555, 54.08090645267118, 52.21711381789177, 52.30634773931196, 53.93357830662882, 53.35809207731678, 51.47786863388554, 49.43587487743747, 49.19790860145323, 50.89158019711895, 55.96123580009707, 59.95841341633951, 57.90314635922832, 63.50984111908944, 59.31265792539043, 61.53372356968542, 59.74103958375993, 65.67586414275631, 49.92327251741963, 52.13638751737533, 66.0676500874181, 48.98340986620996, 57.931916944442264, 63.71657356139153, 66.94589230322069, 66.79206478980281, 64.25520912293466, 58.14017518874138, 49.6820467518222, 53.309615504357126, 55.736456532632154, 63.14731213354296, 69.70708400972428, 69.48886686755766, 76.73154692496024, 28.662278767554994, 1.1714842482920618, 0.38548315544762923, 0.2963278040049538, 2.212738697567294, 1.694524956326331, 56.063652807666415, 63.57048488432362, 74.21654670469223, 70.17076307727446, 70.51495105989518, 59.43084678342266, 22.591247943139848, 21.33581296090157, 35.35057690835769, 44.556869999054946, 26.63968309279411, 60.291344196565696, 65.64262990028628, 44.78939202524001, 0.11932268348192016, 0.1730323570870584, 0.08220035327418197, 0.13009053955395378, 0.0821117475448597, 0.024724985968561906, 0.18786853840274198, 0.09419489997409045, 0.09454271155259303, 0.13643429915030159, 0.23208935504719136, 0.1845395799365736, 0.11023016976973704, 0.23103074410990362, 0.2705053089847488, 0.12628291403093647, 62.989613240764996, 75.00597861505325, 52.23712575051093, 40.56858439599314, 70.19328532680389, 41.4449477964832, 23.873762969047796, 22.733437784256477, 39.49868732883085, 86.6947437101795, 72.43602598867109, 75.68277574354603, 67.67494324714907, 74.62235512272005, 8.998525142669678, 4.6815042245772585, 0.3880307961615824, 0.3482781873354989, 0.643169300690774, 1.5084913517198257, 9.63391871221604, 73.11276820398146, 71.6022869848436, 71.25824020754906, 65.86405554125386, 62.12941392775505, 51.31205827959123, 58.96755210814938, 63.525318791789395, 68.96908221706268, 64.8984621417138, 65.65352624462497, 61.490738314967004, 57.52624580937048, 56.95077134716896, 51.62337680016795, 47.43976108489498, 65.4020199468059, 63.21249015869633, 66.82139627395138, 64.55795334231469, 64.2261012138859, 64.57940086241692, 57.15857851889826, 50.7722185504052, 52.00145406107749, 51.702051701084265, 53.551814017757295, 58.91858916128836, 57.706890567656494, 57.85812147202031, 61.16074931237006, 61.791635097995886, 63.28695243404758, 62.43287594087663, 62.28373958218483, 61.73615317190848, 53.72120941838911, 52.35260817312425, 52.490393192537375, 54.69571052059051, 54.15274858474732, 54.20758724212647, 54.655533682915475, 55.50444833693966, 60.682675146287494, 59.413058834691206, 55.76190094793997, 57.14811363527852, 61.86823898746122, 58.37064189295615, 60.143816009644546, 65.63217286140689, 62.36890208336615, 64.63734603697254, 67.99686001193139, 66.4525914961292, 68.41749498921057, 50.130499178363436, 40.90113078394244, 53.560906071816724, 67.04031944274902, 69.38843850166568, 70.97553929974957, 64.35076198270245, 63.21497301901541, 62.07922720140027, 59.24729947120913, 58.87079508073869, 59.33508996040591, 58.70279604388822, 57.52959551349763, 59.659536653949374, 61.32823844109813, 57.75400607816635, 57.848480286136756, 58.529537108636674, 57.28454935935236, 55.43345343682074, 51.12090549161358, 50.72068252871114, 48.0040567921054, 54.87841060084682, 59.357706346819484, 59.68545959841821, 56.61530671581146, 58.07631900233608, 56.27991268711706, 54.991076761676425, 54.86709456289969, 55.444840077430975, 57.00883419282975, 52.63548950995169, 52.265727673807454, 52.8782489222865, 58.53658560783633, 64.6338668946297, 61.50497259632234, 66.31272762052475, 59.96091196613928, 63.88932258852067, 63.034312571248705, 69.0943705651068, 52.27359594837312, 52.49695139546549, 59.67598707445207, 48.916051003240774, 59.2409138525686, 66.87788624917307, 70.87404404917072, 70.73979700765302, 68.0388842859576, 60.90502254424557, 52.45453096205189, 57.31906229449857, 55.577424033995605, 64.33777109269174, 72.10272650564872, 73.80007728453606, 78.66815443961852, 35.05967432452787, 1.9192792186813972, 1.3433717022980414, 0.2820411835226321, 6.306517672154212, 2.9666126062793117, 59.567258973275464, 70.48423890144595, 78.65348477517405, 72.01974484228319, 76.4235310400686, 64.97410112811674, 33.475240738161155, 29.192396902268936, 47.67834317299628, 52.64203202339911, 38.73640998717278, 74.77848114505892, 72.08849614666354, 59.63677121746925, 0.3115259465431014, 0.2608995470068147, 0.1545027739578678, 0.19668844738794913, 0.1337092477948435, 0.14018768564827983], [0.007705658039588842, 0.06772558159765697, 0.016233027732420354, 0.08571404618241134, 0.047525719949795354, 0.10157139971852304, 0.05678730160598794, 0.24749899913947432, 0.026178633974444483, 0.2735642367793668, 40.498777974036436, 63.984698941630704, 48.27158597207839, 42.29761223639212, 30.02702432294046, 49.909540299446356, 24.841937288161247, 12.866178251081898, 46.45529324008573, 70.57881509104084, 55.30192459783247, 65.39398301032283, 54.864709761834916, 68.9857993587371, 18.210729245216616, 1.0670071383637767, 0.21202485347467087, 0.031425867026912115, 0.31252124797432657, 0.3644592819675323, 5.859324326438289, 70.35982916432043, 66.0799192613171, 66.56432413285779, 58.1261174140438, 48.98395507566391, 53.71880108310331, 60.10894221644248, 61.99970114615656, 61.36111967025265, 63.47639114625993, 64.11215636038011, 59.42619093002812, 57.33054307199294, 38.788314711663034, 69.83234097880703, 50.72881360207835, 46.57180332368421, 63.65767132851386, 59.2632713625508, 62.05859945666406, 61.76322144846763, 58.985571476721, 52.15075515931653, 48.867860763303696, 44.015218134849306, 49.8858727178266, 48.451948319711995, 54.62044023698377, 50.58870261715305, 50.873451002182506, 51.81951492063461, 55.825682609312004, 51.46192027676491, 49.28829569970408, 57.56604609950897, 58.23536719045332, 58.49147050611435, 52.78367665506179, 48.53286681636688, 47.06753992265271, 44.89508421190324, 48.89533696636077, 46.12399024348105, 43.90945926789315, 46.9078916118991, 46.16494371045021, 49.10336379081973, 47.429664904071444, 47.68833737219534, 48.59429897800569, 51.284997847772416, 51.8963384628296, 54.28210443066013, 56.49467814353205, 57.49447461097472, 59.333069939767164, 62.46228979479883, 52.91125566728654, 43.74910493050852, 55.767615841281035, 68.61221713404503, 60.76003997556625, 60.67129242804743, 57.92904184710596, 55.16913275564871, 51.87369461982481, 51.0170332847103, 52.076516459065104, 54.42878930799423, 52.76362549874091, 50.89576536609281, 47.60839946808354, 51.76290727430775, 46.514313144068566, 48.27293918978784, 46.363611759678015, 46.406561713064875, 46.13814999980312, 46.318955575266195, 46.80146201964348, 48.700685424189416, 50.01128265934606, 49.63531171121905, 47.55275672481906, 47.804612113583474, 48.75355505174207, 47.88891169332689, 49.87657277814804, 48.732723343756895, 51.61696372493621, 48.99744802905668, 48.22135609965171, 47.3743712517523, 47.345855620599565, 54.07898056891657, 58.60091247866231, 56.106406642544655, 60.148970004050966, 58.3030516101468, 58.76373006451515, 61.703891677241174, 62.964211971529075, 53.15294819493448, 52.029946158009196, 60.05730813549411, 51.189370462971354, 51.61678721827846, 58.48744615431755, 59.37344289595082, 64.05015937743649, 63.12619017016504, 62.687939828442, 48.9004046686234, 50.63981110049833, 55.24811752380864, 56.73018901578842, 67.69841471026021, 67.55367925090175, 62.0399054404228, 17.29050394027464, 0.33168628571494935, 0.3215669077490607, 0.19574125627836875, 1.0158765916862795, 4.045052105380643, 59.22430653725902, 53.497901039738814, 70.31400803596743, 42.08971485014885, 67.32084735747307, 41.85148577536307, 19.529369300411595, 48.95978935303227, 35.716557579655806, 43.558395370360344, 49.411046274246715, 53.143781615841775, 57.75487292197443, 28.425704932981922, 0.46175269349928827, 0.17162721393810165, 0.050136551426182834, 0.23537836968898776, 0.021541528666632313, 0.07869498774168954, 0.060158268503484234, 0.060555588514093435, 0.04916575714765538, 0.0724654978201274, 0.020596361944391843, 0.11267577523305533, 0.039902735246165145, 0.14078411574084915, 0.14465597007543812, 0.36916027326257, 44.870953790603146, 75.4678612370645, 50.861903544395204, 38.832668873571585, 48.4768985163781, 43.524749279022224, 29.131045149218654, 18.18305104009567, 48.06439069009597, 79.00903978655415, 65.27532346786992, 74.39647366923671, 59.106203971370576, 77.83879280090332, 20.71126768665929, 0.7139255490995223, 1.7138308623144705, 0.1005688434346549, 0.34349117968832293, 0.5355922925856806, 5.886615197504721, 75.26124646586757, 67.02920344568068, 69.47833922601515, 58.73643821285617, 51.05532346233245, 55.61887171960647, 63.28491280155798, 63.468766058644945, 63.78770574446648, 64.08238557077223, 66.85330867767334, 60.768355400331565, 56.191537764764604, 40.729068171593454, 61.02669054462064, 47.295508077067716, 47.870911936606134, 63.28449310794954, 60.04024974761471, 64.48153380424746, 63.39415865559732, 59.675477166329664, 54.7455560007403, 49.88629633380521, 46.85881883867326, 51.58276850177396, 50.38775174848495, 55.949178434187374, 50.99414233238467, 53.535516569691325, 55.01867848057901, 57.914109383859945, 54.97438315422305, 51.50835721723495, 59.74116509960544, 59.09471534913587, 60.53622168879355, 54.32894537525793, 50.974934485650834, 49.177908435944595, 47.98165221368113, 51.30756324337375, 48.97648296048565, 49.47542021351476, 51.99720613418087, 52.25347418938914, 52.72386443230414, 52.810588036814046, 53.24897566149312, 53.735781023579264, 55.58683772240916, 55.97350889636625, 56.99569817512267, 56.39316328110234, 59.44007612043812, 60.62442010448825, 64.66178632551625, 50.7893200843565, 41.72068257485667, 54.36030080241542, 67.01601643716135, 63.15797313567131, 61.513425304043686, 60.324845160207445, 57.91221487906672, 53.92167783552601, 54.88071303213797, 56.376214719587765, 57.96096209556826, 56.293189910150346, 54.07171241698727, 52.40314791279455, 53.80603459573562, 52.73183468849429, 51.452031981560495, 49.77400279814198, 49.337952906085604, 49.242337288395056, 48.96828128445534, 49.921095601974, 49.47008971245059, 53.666178564871515, 52.725904064793745, 51.7506302556684, 49.89779672315044, 50.13605717689761, 47.1152320215779, 50.29740387393583, 50.782620676102184, 53.15343456883585, 50.838887076224054, 48.80771121671123, 50.50873333407987, 51.03815524808822, 56.74366235733033, 60.96033973078574, 56.74531367517287, 61.69457212571175, 61.60880557952389, 61.8826929215462, 62.81547569459485, 62.59160641700991, 55.17398472755186, 52.33355722119732, 62.20989704132081, 57.091556979763894, 52.018394777851725, 61.83724834072975, 61.30907374043619, 67.56554834304318, 62.970307334776855, 65.6521063466226, 52.54406298360517, 53.398829813926454, 55.34936566506663, 59.79575272529357, 70.31021118164062, 72.27867618683847, 64.66742277145386, 19.588571594607448, 0.8437395155910523, 0.4056488265914302, 0.5747525009416765, 1.6797426463134828, 4.71744490246619, 68.49951174951369, 58.21363333732852, 81.94111347198486, 42.7968946579964, 71.86179099544403, 45.00271012706142, 24.742209065345026, 45.305050342313706, 32.37648875482621, 53.07113147551014, 42.091636811533284, 58.32155735261979, 67.34033369248914, 34.209567269971295, 0.40371163537906063, 0.21233205473230732, 0.06158780389195008, 0.08911474878268857, 0.08433527944068755, 0.020495653941085743, 0.13243009546591392, 0.20653609396709552, 0.18870049456675209, 0.16372012935819166, 0.08435367321174952, 0.12244627675822667, 0.26749390928495315, 0.3463495456643643, 0.3488048574616832, 0.5322511073562407, 52.348179817199714, 84.79355519817722, 63.67358438430294, 55.7722677723054, 45.168308673366425, 71.33759760087537, 33.8781113009299, 24.91260074800061, 57.613647983920195, 85.28452611738636, 68.13965782042473, 80.14267536901659, 65.02744928483041, 82.97447758336222, 23.299018067698327, 4.059049328488689, 1.0773868330063359, 0.2975716550023325, 0.7225131495825706, 0.9778884365673989, 7.7493183939687675, 79.51508045196533, 68.95334566793134, 72.5632990560224, 62.52106651183098, 54.30969046008203, 58.616111663080034, 63.573324680328376, 67.1588691588371, 65.2892518043518, 65.92553477133474, 69.00697231292725, 64.00370674748575, 55.214177254707586, 52.03514722085769, 68.67461419874623, 44.77018417850618, 50.06534468743109, 64.39525342756703, 63.39728086225448, 65.43184172722601, 65.25257764324066, 62.922281834387014, 59.83572167734946, 52.43444842676963, 50.4440926736401, 52.96456067792831, 52.11872116211922, 60.35822845274403, 54.51468137002761, 56.432516421041186, 59.272951772136075, 61.66128297005931, 57.90388768719089, 54.39388021346062, 63.47096650831161, 63.2257281580279, 65.4248442188386, 58.83837669126449, 55.74810204967376, 52.47644916657479, 52.303625614412375, 55.87906998972739, 54.50449889706027, 53.66568826859998, 57.20836516349547, 57.99985631819695, 59.09139702397009, 58.11583688182216, 58.88627275343865, 58.73174313575991, 62.819092119893725, 63.409146032025745, 60.75368965825727, 62.59500318957914, 64.27442089203866, 65.2598104938384, 67.43419601071265, 53.64662947193269, 42.564615818762014, 55.829106838472434, 73.21214537466727, 66.62930996187272, 65.3546416374945, 64.22231612666961, 62.14832759672596, 59.79670978361561, 61.23956934098275, 64.11778888394757, 65.19476975164106, 60.97110663690875, 59.24869583499048, 58.751935497407, 60.54414487654164, 57.70536476565946, 56.315939657149784, 54.60861429091423, 53.281123407425426, 53.71447078643307, 53.802849631155695, 54.50152574046966, 55.19765623154179, 55.49749397462415, 55.504919021360344, 55.89052723300073, 53.241531002906065, 51.94170851861277, 49.322388941241854, 50.055656433105476, 52.54598886735978, 56.01720410008585, 52.92506633266326, 52.00564315242153, 53.73894637630832, 53.12125544394217, 60.83748325224846, 63.52771928233486, 61.16742518640334, 63.08768033981324, 63.50396933094148, 65.27445662406184, 67.91274870595625, 65.38294546065792, 54.61570985855595, 53.68322126327023, 60.62267857213175, 55.27413068279144, 56.10819916571341, 62.74855221471479, 64.415375186551, 69.60342361081031, 68.84929303200015, 70.53282137840026, 54.78723510619133, 56.28780449590376, 61.056296594681285, 60.646875673724765, 73.11733384286204, 73.09194041836646, 68.58328573165402, 23.940962976025, 1.3708270677635748, 1.6701640957786192, 0.36278632980200554, 3.688219381916908, 6.489499672766655, 72.59476430954473, 65.2330756187439, 83.59469059974917, 52.79792662589781, 77.25082951207315, 54.37496654448971, 33.04669434024442, 58.65327219809256, 53.105785615982555, 62.43804170239357, 69.8131605886644, 69.45280459619337, 78.50469358505742, 48.71994818410566, 0.4461791372347263, 0.29795506668667643, 0.217285962294667, 0.3229994615239482, 0.21747074270200348, 0.10366831260222582], [0.08471507519002884, 0.1660875861923541, 0.024048218150593104, 0.05237997479496464, 0.05233476794655285, 0.07118561770766973, 0.06856400354374802, 0.17748432384142954, 0.2230973827141908, 0.7517010994976567, 22.069366785787768, 68.47218851889333, 44.499375897069136, 43.3677799470963, 25.321456847652314, 40.70356099836288, 22.25284153415311, 7.674938488391138, 20.826334338034354, 73.79748067548199, 44.5202782077174, 71.2073435321931, 55.03107317032353, 65.96671181340372, 31.203109756592784, 0.8824298362578116, 1.88366801988694, 0.4222684912383557, 0.04516830652832024, 0.7137996655318045, 3.623344114711208, 62.04336497091479, 65.16616390597436, 63.4132605983365, 54.285528659820564, 48.680716637642156, 54.6558278606784, 64.32173644342731, 62.332345593360166, 68.30638993170955, 57.612239853028335, 58.41276422623665, 50.00717593777565, 58.33888246167091, 36.74889010767783, 28.921771011044903, 64.35241722291516, 45.790106327303, 57.879235590657885, 59.93039200382849, 61.98621603750414, 61.29108575082595, 57.23611593246461, 50.358188844496205, 49.33607016840289, 45.47624218848444, 48.16929448035456, 47.77281345859651, 52.55730098293674, 54.44792655206496, 46.872429463171194, 51.986878533517164, 54.807984444402884, 57.31701481726862, 52.694387820459184, 55.86607517734651, 58.164125181013546, 56.226795950243556, 55.74661154900828, 55.28930241061796, 53.03538691612982, 52.31139582972373, 46.9221023590334, 47.10623802677278, 42.962214716019176, 46.05339542511971, 46.50317361277919, 47.93169690716652, 46.75519374109084, 47.819870133553785, 49.820169095070135, 54.838198461840236, 53.58513063000095, 56.64712106027911, 55.45942737210182, 56.808401077024406, 54.760633591682684, 59.43276090006675, 57.201140157638065, 57.442926822170136, 58.43090518828362, 62.56506766042402, 56.00050264789213, 57.393379442153446, 51.19597573434153, 53.99035853724326, 55.65095278524584, 58.584638564817375, 55.64352381613947, 49.69064066486974, 47.28367428625784, 47.30115236774568, 49.126835253930864, 47.651074855558335, 45.97123745949038, 46.96065141308693, 46.958874579398866, 47.42001195107737, 48.32964489536901, 48.40862966352894, 53.06647169974543, 51.53774361456595, 55.12452363967896, 60.15047227182696, 53.46214863561815, 49.57054553493377, 48.127011329896995, 49.817141025297104, 49.50281404679822, 46.43099807923841, 46.57844781875611, 49.592879510694935, 47.75286036152994, 48.52072708068356, 47.93845122860324, 52.00271706427298, 58.29452829976236, 55.461384634817804, 53.08381249827724, 59.8746512013097, 58.14753747755482, 63.109975091872684, 65.03114023516255, 49.24307469398745, 57.00181707259148, 60.690017823250066, 61.30112309609691, 46.721053431111, 56.243128699641076, 58.7227334514741, 63.955277242968165, 63.81249904632569, 65.32466296226748, 52.97497064836564, 46.80444302097444, 52.218341519755704, 63.1084139885441, 67.91710253684752, 71.2095400594896, 55.004036272725756, 9.609982448239482, 0.21653499694601183, 0.10000524020964101, 0.33772238440090613, 1.4988419533737245, 8.436587760525367, 67.01571049228792, 52.60279655456544, 49.95744812873102, 55.33022449862573, 78.76504482761507, 13.149108617536484, 29.2426993385438, 61.52673782840852, 50.86391179792343, 30.126075936901955, 32.85937959148038, 52.316122285781375, 60.73370125985915, 14.90196583732482, 0.4885951273383633, 0.1715501914581945, 0.08084383372577929, 0.1147318632912732, 0.03183167912216196, 0.15466570553760375, 0.10655289410703606, 0.120269384295229, 0.04944893005754679, 0.0747933402477253, 0.10546530972445205, 0.129176244259842, 0.053811130459390344, 0.1816060760569188, 0.3828191612997363, 0.7562327853614285, 25.467294493029197, 78.00946297184115, 53.227555597982104, 37.04331890229256, 35.14848855233962, 42.77813396146221, 21.347846792590236, 14.47712411803584, 23.40139977393612, 82.17646352706417, 49.80575830705705, 81.05801536190896, 60.9289490022967, 73.30019474029541, 34.88949837223176, 1.6017040273835583, 2.839760458277118, 0.13324663794088748, 0.052410365502920844, 1.2654867912492445, 3.891688902531901, 68.15640634106052, 66.9686185159991, 67.08426567815965, 56.526814122353834, 49.19483346323813, 56.65464808863979, 69.24163203085624, 64.89112730949157, 68.39790667257002, 60.66589132432015, 57.70542360121205, 50.35981662811772, 60.18973519725185, 41.745111096289854, 32.673161145179506, 57.72993449241885, 47.33070350462391, 58.126493961580344, 64.17386701030117, 63.17283891862439, 64.22746227633569, 57.835254053915705, 53.01324905887727, 48.45856535819269, 48.56372410251249, 49.552530088732325, 52.20864934305991, 55.56465279671454, 56.4119985026698, 51.67419502812048, 54.680923185040875, 57.13607588121968, 58.669597102749734, 53.20690039665469, 60.755768514448604, 61.0445059499433, 62.607558696500725, 58.80263213188418, 57.96790469077326, 53.35519736812961, 52.81548707715927, 50.86121712961505, 51.63288462546564, 47.8392505645752, 52.502948699458955, 52.1293076392143, 53.00185849589687, 52.468345549798784, 52.536802676416215, 56.10167626411685, 58.43894604713687, 56.821454724957874, 57.82544028374457, 56.49690604978993, 57.52252740244712, 57.2259295371271, 60.19980392148418, 57.84817041889314, 56.82859736104166, 58.964951576725134, 62.59574843991188, 59.899499416351325, 59.812556159111764, 52.891330026811175, 54.46240402037098, 58.878733957967455, 62.4212618027964, 57.962170185581336, 55.32410167878675, 50.43736973116475, 52.61431263339136, 52.303005879925145, 52.92594102121169, 50.783209031628026, 48.70800456693096, 51.1242748075916, 50.69494785801057, 51.12660861784413, 52.22043606542772, 53.70535912052278, 54.06566412218156, 55.8710644322057, 61.455115349062034, 55.14513961730465, 50.64389428784771, 49.03252970787787, 51.35463168544155, 50.98794106514224, 50.574044719819106, 48.777665861191295, 50.4860031989313, 50.815513672367224, 48.824644088745124, 49.46633600419568, 56.61107055602535, 57.83588555551345, 58.259156365548414, 55.560255819751376, 62.87353461788547, 62.772345312180065, 60.15667746143957, 60.71475228955669, 49.58409732387912, 55.19411040890602, 62.37605256419029, 64.31308369482717, 52.16108668235041, 57.63130257206579, 60.96116342852193, 64.42845629107568, 67.54381841228854, 67.69311166578724, 55.308380819136104, 50.94080202041134, 54.123558305924945, 65.104923940474, 72.6148154658656, 71.48432562428137, 62.14277352056196, 11.411485883497424, 0.6734513467358005, 0.049545369035894835, 1.053817310640889, 1.1282325175500687, 12.885819519719771, 75.25584928451046, 61.42400703122539, 54.80070452536307, 58.18638855411161, 80.45399388959332, 15.083181300470907, 39.316222590784875, 62.366383921715524, 57.30533792126564, 36.27824883307181, 34.650351462825654, 57.16886297349007, 70.67987103616038, 18.261410190213113, 0.500917375808762, 0.2347747383699302, 0.10388379781356744, 0.09897816145131666, 0.09240478232142427, 0.033600654663337816, 0.2078670031961895, 0.2667593535396361, 0.11058876786621348, 0.18446580566946538, 0.18076371641889696, 0.2420659648675111, 0.2371759643597949, 0.39751373892349584, 0.6448162058668753, 0.8709115510986698, 34.722715270134714, 93.1745933717297, 61.4112122597233, 62.849490488729174, 37.325780545511556, 60.1904647581039, 29.1015822656693, 19.24338144640769, 31.92317847282656, 88.11796003772368, 55.22206906349429, 84.00689248115786, 67.314085191296, 80.55938013138311, 39.863083362579346, 2.878079318231152, 6.978082358837129, 1.1051589298632838, 0.2904423794919445, 2.6015956123029036, 5.975041600965685, 72.03927040100098, 66.43233637655935, 71.67212870813185, 58.35900029828472, 53.349831565733886, 59.33105776386877, 73.0440325890818, 66.06789327436879, 72.72818765332623, 62.62031816667127, 60.071150179832216, 51.25274027547529, 58.65593940980973, 43.299185537522845, 46.050677222590295, 62.07900362630045, 46.66384566214777, 60.8035586726281, 64.6158161470967, 65.6269717985584, 67.17611189811461, 61.28992080688477, 54.74728968835647, 51.40868586878623, 50.2620868529043, 51.54278386023737, 51.73740402344735, 57.31951336706839, 59.678944541562, 53.476971272499334, 57.46076576171383, 62.524427983068655, 63.61794164103847, 58.78317325345932, 62.470852328884995, 62.956582961543916, 64.76690192376414, 60.90410470962525, 62.45963827256234, 57.478922413241484, 56.87952933772918, 54.17320374519595, 53.92416854058543, 51.63053120336225, 56.180410000585745, 59.62474130815076, 59.21012716908609, 56.19828816383116, 57.776010574833045, 58.79559147742487, 66.96192695248511, 65.30962067265665, 67.00747351492605, 58.9701134158719, 60.11823038901053, 61.16769582994523, 63.05411661824873, 60.97372678018386, 60.0846549003355, 62.95968947872039, 64.05172048076507, 59.73554042077834, 63.26966654869818, 55.706823025980306, 62.48909527255643, 65.83916418014034, 67.81959241436374, 64.81105996716407, 58.478154059379335, 57.50511992362238, 56.97807888830862, 61.0416857657894, 56.84403188766972, 57.99682824842392, 55.232934028871604, 54.931566561422045, 54.89384904984505, 52.747563392885276, 54.772200661320845, 60.59795195056547, 57.8017609350143, 61.32237449769051, 63.972912219262895, 59.1620389107735, 53.603565769810835, 52.74588069608135, 52.10040761578468, 53.20185622861309, 53.85276963633876, 50.630899475466826, 54.40533745673395, 53.360335673055346, 53.60572699577578, 51.29923212912775, 58.462911728889715, 61.660655390831735, 60.789445984748106, 58.445971012115486, 61.608221146368216, 65.32301164442494, 63.17290559891732, 58.5927814052951, 51.39356120940178, 57.971477970000244, 61.93349546001804, 64.89036636967813, 55.5849196833949, 59.78792367442962, 61.07486509507703, 68.14976184598862, 70.84659530270484, 69.6090796685988, 57.95723584390456, 52.15590915372295, 57.40442483655868, 67.69087591478902, 75.63889226605816, 74.69808040126678, 67.60914940987864, 14.838525422157781, 1.5013145174710982, 0.1950255003307135, 1.0048566926871578, 3.8873924363044003, 12.727656806668929, 82.04828046983289, 65.85637554045647, 64.82161898766795, 63.6434409695287, 90.45673601088986, 24.197170234495594, 41.6426391755381, 65.64259067658456, 72.1432916579708, 41.4473835883602, 50.31121846168272, 69.02172042477515, 79.80451999172088, 28.252775476824855, 0.9073764169889112, 0.38419548422098165, 0.24369442264639565, 0.280892419358415, 0.15679441873104344, 0.3478757460271159], [0.06839047696801924, 0.10269509748585763, 0.024999440797875007, 0.14614332978042865, 0.01857568630047383, 0.033034802970266154, 0.028404466049264998, 0.05732628659555509, 0.21443245331606559, 0.47040770971967333, 9.656843985280684, 67.8321361541748, 48.31872893917946, 45.74355563809795, 33.128820926912375, 43.07499462558378, 30.134332526114683, 18.379912837859123, 20.772672391706898, 64.68544606239566, 48.03042296440371, 55.68604230880738, 61.98112872339065, 66.08242173348704, 38.525543366709066, 1.0484207421541214, 3.9774944272733506, 0.01921951233769857, 0.10745346110554473, 0.5214178886625075, 2.54117468672414, 53.636694108286214, 70.05535910206457, 66.1057912149737, 54.90369812134774, 48.18522714799451, 56.18703880617696, 62.31337308883668, 63.87544916522119, 58.76667184214438, 56.45133595312796, 57.37013939888247, 55.53621953533542, 41.05743331293906, 35.13166942904073, 34.770760382375414, 37.555498077023415, 62.31818191466793, 59.09496245845672, 63.21237248759117, 61.52516495796942, 63.2178794953131, 56.92843344903762, 54.86953819951704, 49.581037875144716, 46.90368683107438, 48.580041162429325, 51.44808607716715, 50.593374160028276, 54.84919678780341, 53.519042614967596, 53.35470707185807, 54.09317170420001, 56.6206842853177, 56.0588518265755, 57.07998598775556, 57.38609167837328, 56.30564343544745, 58.14008889659759, 56.64064522712462, 54.54507581649288, 56.56420607720652, 51.4737658346853, 47.70236769030171, 46.42083129575176, 47.1484427298269, 48.39169679149505, 49.47356493242326, 50.08523110420474, 51.5736529134935, 51.04493702611616, 61.98037170594739, 65.34993087091755, 55.16651653474378, 59.552083323078776, 58.61770414537, 55.680366639168035, 55.85323725977252, 50.31925932053597, 45.126629567915394, 49.718583629977324, 58.463978613576586, 57.32795038530904, 60.336294558740434, 62.30620299616168, 65.18752905630296, 61.18435021369689, 56.603649431659335, 51.31990301993586, 45.12741796432003, 47.93099480290567, 49.176657199859626, 50.601611137390144, 48.08891727078346, 46.068253363332445, 46.643782738716375, 50.126153192212506, 50.483249695070334, 49.5494588728874, 55.73769207923643, 55.953940191576564, 52.6071229288655, 51.33797337931972, 52.74053842790666, 57.21331519465293, 55.60408438405683, 50.89330603999477, 49.542602569826194, 45.7998965632531, 47.95621172074349, 48.75904244761313, 46.444836201206336, 45.29778611275458, 46.49575248841317, 46.02657818025159, 55.95628184656943, 57.60898428578531, 58.79827830099291, 54.41113864221881, 58.959942710015085, 58.164411514036125, 64.5231266175547, 67.71200180053711, 49.59334235037527, 62.11916085212462, 58.22510627008254, 70.54129369797246, 55.88206275816887, 49.214186437668346, 55.24664663499402, 57.45539211457776, 64.29592724769347, 64.63337267598799, 55.478745045200476, 47.607340428137014, 52.250234311626805, 60.25248919763873, 70.8790333040299, 71.36758804321289, 46.48592302876134, 8.302066153095614, 0.18107054995432978, 0.15561360144807448, 2.740910356083224, 1.7381229588100988, 23.109130244101248, 69.54163059111565, 54.75484025093817, 60.66471853563863, 67.84914355124197, 46.45894496671615, 8.110109769528913, 32.0884612683327, 16.65815511057454, 38.178696017111506, 34.14773110420474, 45.696714693500155, 51.353815832445704, 66.48898324658795, 7.803084773402061, 0.3403195450382848, 0.23589851274605722, 0.05465065940253196, 0.11251296622738724, 0.023928045768350847, 0.13995183781991083, 0.042231646366417415, 0.06935346481059829, 0.1973018539889205, 0.11307599488645793, 0.0895981042976341, 0.015290174595711213, 0.1500979369325984, 0.18091898711939014, 0.19867845270181858, 0.781364820657238, 11.080387830734255, 77.63044434209024, 55.47243002922305, 43.94260721821939, 36.82038707117881, 51.59269209830992, 31.009438806964507, 27.634505994858284, 25.501997663128762, 68.98536789801814, 49.279101664020175, 62.90551370190036, 67.33259093376898, 69.99192653163787, 43.498936160918205, 0.6877515729396575, 3.7222959533814466, 0.09071079338149679, 0.07773965311747405, 1.1756259034718237, 2.9371867400984613, 57.44628437103764, 70.07594370072889, 67.80402844951999, 56.45297158148981, 53.30130400196199, 59.17393545950613, 66.80059202255742, 64.85264493573096, 61.136650270031346, 55.134235428225615, 59.48592078301215, 55.2365896778722, 40.992722049836196, 34.327995392584036, 38.4888142924155, 39.13535425739904, 63.690764365657685, 60.466862417036495, 67.95167430754631, 62.15439942575271, 65.62730127765288, 61.02371346565985, 56.12149992296773, 50.06048879315777, 49.66751829270394, 51.867889511969786, 53.844489512905, 54.1649785349446, 56.504507603183875, 55.277237199967914, 54.76286149794056, 57.475623699926565, 58.79523846410937, 57.50742235491353, 60.77681595279325, 62.23497275383242, 61.22639017720377, 60.27008887260192, 60.75447805466191, 59.17583388666953, 57.0352945020122, 52.625871858289166, 50.891372311499815, 50.50228103514641, 51.365688846957305, 53.230011001709975, 53.77559700319844, 55.678640796292214, 55.54011444891653, 53.821727998795055, 63.012594407604595, 65.99700820061469, 55.86354132621519, 58.986253969130985, 59.30083590169107, 56.99469012598838, 57.794426102792066, 51.31217987306657, 45.82765517696258, 52.46469774553853, 57.86243607920986, 60.028364965992594, 62.213364416553134, 63.30350875854493, 66.26460798325078, 62.69489026838734, 61.50345856143583, 54.744602864788426, 49.638841844374134, 55.5441427230835, 55.037195990162516, 56.067057424975985, 51.14360817017094, 51.52696101896225, 50.484944158984774, 51.85484763114683, 52.72554320673789, 54.0507395036759, 58.98374757459087, 57.52397867941088, 56.06994821179298, 55.48683689486597, 54.41596315753076, 57.752119418113466, 56.549308915292066, 52.43682538309405, 53.53549303547029, 46.91847416662401, 50.17740288088399, 51.6045964917829, 47.881823970425515, 47.91244591436079, 47.92575843872563, 48.25683393786031, 56.34551040587887, 59.321887262405895, 62.0620785990069, 57.84904510744157, 61.59204921414776, 62.03728137477752, 58.9990879643348, 62.941940753690666, 51.68056495728032, 64.13798909033498, 60.22189471029467, 69.74291878361856, 61.11813668281802, 53.08935872970089, 56.7764376824902, 59.8779381475141, 64.56199338359218, 66.24780454943257, 59.20230988533267, 51.56957757088446, 54.057988043754335, 61.77416878361856, 70.95489978790283, 76.0155810079267, 52.53216251250237, 10.129577844373642, 0.3629268303273186, 0.18040601464529193, 1.6563951055849753, 0.9543842461801345, 26.874942933359456, 77.81668632261216, 61.60180807113648, 66.32728745860439, 72.35336595965971, 49.47140370645831, 8.765734434127808, 35.860273222769464, 22.661805498984553, 48.35365764556393, 38.430021885902654, 37.94938641209757, 58.84339732508506, 73.38960909074353, 9.33192366553891, 0.49359584287289654, 0.2791656878206038, 0.1082791276876965, 0.17057675417632828, 0.1020735550311304, 0.01715732430438361, 0.25923615561858304, 0.17830011555023734, 0.3371206376581423, 0.2917101937195947, 0.1603422025519033, 0.15218537330867785, 0.23451397736226362, 0.27011028340747284, 0.41968076880420413, 0.7911223906182474, 14.328055420229513, 91.62585335393106, 62.80473624506305, 66.16985136462797, 43.76469242957331, 61.95578628970731, 36.57233638148154, 29.056802526597057, 33.07120523145122, 76.25440628297868, 59.372729024579456, 70.07593585598853, 73.90190985894972, 77.46477127075195, 47.298842091714185, 2.0174622727978617, 11.850423620593164, 0.4197807586000812, 0.2703311005907674, 2.2014893399130915, 5.0378010542162, 61.54167029165453, 72.85381332520517, 71.3200096930227, 60.9571861451672, 54.827964998060665, 60.70498558782763, 67.68751052118117, 65.96854748264437, 62.89139316928003, 55.476321020433986, 61.31898164749146, 56.47491724260392, 43.511413220436346, 36.61473328067411, 41.17830114979898, 45.46440055293422, 64.68311225214313, 62.79899389513078, 67.80451482342136, 64.44484787602579, 69.7362272201046, 63.32606630940592, 60.54202287427841, 54.571704787592736, 53.1655546926683, 52.644326609949914, 56.53981285710489, 56.70948674601894, 59.44120576304775, 58.579986633793006, 60.30903408604284, 60.59508077559933, 61.795985006516986, 60.352529248883656, 62.457677087476185, 65.98356231566399, 64.76515646903746, 65.98003218250891, 62.9141939070917, 62.779864495800396, 61.9715149940983, 56.158425115769916, 58.76794269008022, 55.183908324087824, 54.39297414595082, 57.82258479825912, 61.9343230801244, 61.49484503653742, 63.05884307430637, 57.33076272472259, 69.08062658002301, 68.32119295673986, 59.274607012348795, 65.06582575459635, 62.75645579061201, 59.85270946256576, 61.14449893274615, 51.08507856245964, 45.026464000824966, 51.2733680202115, 63.68843840014551, 63.90842845363002, 67.36087122271138, 69.37857766305247, 70.05350774334323, 66.24898910522461, 67.23792060728996, 62.27722060295844, 60.631935365738414, 62.31211400801136, 62.23998162054247, 60.17224927102367, 59.333850491431456, 57.36212599662043, 56.21391488659767, 58.79089640032861, 56.91074355956047, 56.65867636280676, 62.712482098610174, 63.42049737130443, 58.52732489185949, 59.2477152424474, 60.56763987387381, 60.88765821149273, 59.880279802506976, 56.89632492680704, 56.98933609070317, 49.80432271957398, 51.78364484540878, 53.993237556949744, 53.57447747261294, 51.84188419772733, 50.94110404291461, 49.71631257764755, 59.89939743472684, 61.622180861811486, 63.86720042074881, 58.89238772853729, 64.52114582061768, 64.42580084646902, 61.464042663574226, 65.64790156579787, 53.526746149986025, 66.37430098748976, 62.8230066453257, 71.19348187600413, 62.615619167204834, 57.00192297658613, 59.141630818766934, 61.55976026288925, 67.1618736943891, 67.99688354615243, 62.18865740683771, 54.292498711616766, 56.538953858037154, 63.98101191366873, 74.07092478967483, 78.47035715656897, 58.13318944746449, 11.33527619223441, 1.1514688835990046, 0.33853030072585233, 5.535261044579168, 4.9471124237583535, 28.82587298270195, 85.19099327825731, 66.48873221489691, 72.56021607306697, 80.09229644652336, 61.98685146147206, 14.257905790882727, 43.87636623074932, 19.561283665318644, 53.66278179230229, 46.02097703564552, 58.400259710127315, 64.61111714763027, 90.68679086623654, 15.318118526089577, 0.7661472501293306, 0.5411330694633146, 0.2653472083470514, 0.19742389179525838, 0.23821903903397823, 0.2188153342614251], [0.022804859364705703, 0.022725015766017383, 0.015025564953835021, 0.07616569483352285, 0.05906526021839631, 0.05337007831962359, 0.11525910798340075, 0.1714028421068384, 0.049578287834001165, 0.2620761967714756, 4.196608566468762, 70.99047568536574, 47.47900439846901, 49.114099317981356, 29.321829234400106, 33.81508665700113, 27.074501360616377, 9.737768365490822, 29.372488606360655, 71.73815788761263, 59.26360476401545, 50.584423311295055, 59.96299474470077, 61.833839801050004, 50.07351106212985, 2.27199639524183, 1.693423138030114, 0.06054997692004808, 0.03432568410531648, 0.9053467129988055, 0.9074754568357623, 48.01120727292953, 69.14745592301892, 62.43315050678869, 59.155731739536414, 51.18623648920367, 56.443408843009706, 62.84797645384266, 68.33139896392822, 63.34287366559429, 59.63956002266177, 34.96734173067155, 38.84116472736482, 42.08827141792544, 17.61409555712054, 55.380215106471894, 49.778093830231704, 60.13313147329516, 62.575218754429976, 60.64738950421734, 58.605929190112704, 57.98931690954394, 57.3466444015503, 55.09546279907227, 47.509304708050145, 48.06114688996346, 49.32410693937733, 53.20302509492444, 51.75126567963631, 54.34424261892996, 49.8704146569775, 49.80830392529888, 53.1454643126457, 58.15407606863207, 52.78726562376946, 55.379854248416045, 56.29903031933693, 61.791478203188994, 55.51405029912149, 55.5298888298773, 57.311123417269805, 56.51046568347562, 56.576675291984316, 53.92251722274288, 52.27019133106355, 55.7047833934907, 57.26597693658645, 53.81849596577307, 55.795499970836026, 57.91467028279459, 58.27841912546466, 57.79730904486872, 60.103529345604684, 58.79393623721216, 63.09871396710796, 61.103455251263036, 56.955968487647276, 53.631916661416334, 49.73397893290366, 46.68818396906699, 50.18385517981745, 52.75365483376288, 56.43596026205248, 59.68867986432968, 59.181886103845414, 55.35125232511952, 52.08450632710611, 51.84539471903155, 53.787301355792636, 49.9194089827999, 46.06531943044355, 42.87180800591746, 46.85470819473267, 49.67854015288815, 48.71841453736829, 48.227902535469305, 50.70240428370815, 48.68916150062315, 54.3891223784416, 55.139032486946356, 57.360239336567545, 53.43025192137688, 51.658195680187596, 57.07451035899501, 49.835838963908536, 55.22000981915382, 49.67961880468553, 54.80399931630781, 46.46374987017724, 51.44852146025627, 47.666850628391394, 46.56813982994326, 47.40809971286405, 45.709019168730705, 48.022758653087, 53.23632209531723, 58.620975402093705, 59.85357238400368, 60.6295701765245, 58.447418366709066, 51.12776179467478, 57.94991670116302, 51.32517468544745, 52.63636812087029, 58.63923403524584, 60.46379120119157, 63.10040450865223, 62.74637922163933, 61.73985981172132, 51.86506148307554, 61.21053595696727, 61.22494674498036, 61.499218479279556, 57.84757029625678, 51.020265317732296, 52.22196186742475, 64.53879648639311, 68.5518910807948, 69.43308291896697, 45.015293090574204, 6.3869522463890815, 0.17549405805766585, 0.24767035768637735, 1.6970496144025558, 0.5656799974460756, 27.89797748288801, 68.24307503238802, 55.43625400912378, 63.41916768781601, 63.06326358549057, 45.92893861955213, 9.444999714051525, 39.92742984525619, 15.255767549237898, 40.50499493075956, 34.822390540953606, 56.06879503496232, 51.481394844670454, 55.69665624249367, 1.2282961030160229, 0.14229723132185398, 0.1143852085055363, 0.03230812643925029, 0.0810539486607717, 0.03211538254794094, 0.09160044362708446, 0.0329624881006537, 0.0707777678185413, 0.020041649169739217, 0.032457854493611285, 0.07052577085672848, 0.07261984921511143, 0.14922119526853486, 0.2133102264375456, 0.1914917205971095, 0.3334048047902123, 4.764428032982734, 81.01628918801585, 58.24743240110336, 50.238933101777114, 33.142533533034786, 43.61030401722078, 20.251548251798077, 13.15814870019113, 33.50086558249689, 82.09407806396484, 59.53291470004667, 55.805305896266816, 66.70993820313485, 68.15378619778541, 55.19361619026431, 2.1194838564242087, 2.0014881751229687, 0.12207506119363731, 0.03536546843186502, 1.5718208373554292, 1.60638059579557, 50.800361556391564, 71.77723253926924, 65.65738977924471, 61.70303660054361, 54.716577529907234, 57.11684450026482, 64.02871185733427, 68.74631512549617, 62.51950933087257, 61.43742545958489, 37.71091807273127, 38.52655141584335, 48.08214333749587, 24.33552203639861, 57.57084315822971, 54.044506857472086, 62.987479471391254, 64.14218994878954, 64.48151811476677, 62.40172839933827, 62.147558812172186, 59.32353465787826, 57.07977417976626, 49.78650339188115, 51.8064102818889, 50.798039513249556, 53.523325843195764, 54.483239650726325, 56.29906954303865, 51.43451859874111, 54.09328937530518, 56.139138821632635, 61.132814192002826, 56.46251470811906, 59.88690860809819, 57.38165940007856, 62.76588516850626, 58.716708690889426, 56.54562188733009, 59.120410796134706, 57.59083940136818, 59.62224275835099, 55.27408753671954, 56.2779946481028, 56.69126733656853, 60.08805951764507, 55.562970099910615, 57.986916418998476, 60.32029521080756, 59.189887738996944, 62.456967138474994, 63.23922111142067, 60.41559703888432, 63.923113807555175, 61.44932985305787, 57.028242080442375, 52.270395294312515, 49.655829629590436, 48.06444560327838, 51.39787581659133, 54.47749337842388, 57.10417132223807, 59.12115996883762, 63.25039202167142, 57.45735722203409, 55.80154826564174, 55.847894991597826, 57.57147465982745, 54.36171285567745, 50.648432470137074, 49.435506174641276, 50.28886095170052, 52.281326939982755, 50.719086124051, 50.936385431597316, 53.589978679533935, 53.4784068599824, 57.58674052453811, 59.83299955244988, 58.88682188526277, 55.02441690814111, 54.62988138198853, 59.33501935774281, 53.39228730047903, 55.36117592165547, 52.45717071717786, 56.67151428038075, 49.031717777252204, 52.63324591421312, 51.528263245859456, 48.36445985301849, 48.89980062361687, 48.31086850935414, 50.45470268495622, 55.21932732674384, 60.89401637354205, 61.052197717851215, 62.68923813296903, 59.7667585649798, 55.40029764175416, 55.51229699965447, 50.53233815777687, 53.766571629431944, 58.64310933697609, 65.10990142822266, 62.72172712510633, 63.159808804911954, 64.94823701920049, 54.842211046526515, 64.83555124652001, 64.22514023319368, 63.834205442859286, 59.600022531324825, 52.49870077256234, 55.30168925562213, 65.74163052343553, 69.38441414986887, 74.28583145141602, 50.33505078284971, 5.707526149288301, 0.33231830825248077, 0.0929379488732065, 0.7555781785518892, 0.6910310421259173, 32.32806709504897, 74.26630589269823, 61.12041165751796, 67.6535035717872, 68.44564976230745, 52.37442831839285, 10.555445263462683, 48.730244405807994, 15.969498695865756, 45.90154870863884, 43.829184039946526, 49.16257196857084, 61.099226936217285, 60.7709716212365, 1.87848485285236, 0.08568296599532328, 0.04952026433461616, 0.015022898967858526, 0.06910519869697672, 0.023173694311070348, 0.03453889403552298, 0.1808409840469399, 0.15759665068359147, 0.12172496667312038, 0.19442194562044837, 0.12752720169843207, 0.13400184741664317, 0.22066287786489536, 0.48605790542018035, 0.3469711187626085, 0.515885017812252, 5.882692827332405, 96.81142284024148, 63.78142995219078, 70.18433447807067, 40.249095578347486, 50.067447077843454, 37.49780785652899, 19.226711373175345, 40.85470953295308, 85.5071206246653, 71.0188030427502, 64.45720334206858, 70.7642412185669, 76.45785177907636, 60.25366590869043, 3.3599849045276646, 7.6775561801848875, 0.2354714953370633, 0.2279128735103915, 3.067584465588293, 2.9879902591628413, 56.77070317729827, 74.72098704307311, 68.18031710963096, 62.75498882416756, 56.80538869673207, 58.81249689286756, 66.57736209131056, 73.41528492589151, 64.92664829377206, 66.1834776786066, 41.48325758595621, 42.66251817826302, 45.22378275471349, 22.376074560226936, 60.133264833881015, 55.48357740525277, 66.62002963404503, 65.69810790400352, 64.75811973694833, 64.52142038652974, 63.79344809439875, 61.23159516242243, 60.75643139500772, 52.2999660430416, 55.606131861286784, 53.6446447526255, 60.09191520752446, 57.112537737815614, 61.44047314120878, 53.94713401794434, 55.923259412088704, 58.036710908336026, 66.95718088457662, 60.820809256645944, 65.18941571635585, 60.672724093160326, 67.38339347224083, 62.22673577647056, 64.02025914961293, 61.77529842622819, 61.6800436665935, 65.64416354702365, 63.621354103088386, 59.35058724495673, 64.70505791325724, 65.19096505257392, 62.09304571151734, 64.46778197442332, 66.29965828311059, 64.36700843995618, 63.68236657111876, 64.35722604874643, 63.129677157248224, 67.39929476091939, 67.02659114714592, 61.46083416477327, 58.427057343144575, 50.91421227301321, 49.99800935868294, 53.89536657641011, 57.110627543541696, 59.186977340329086, 64.1288774244247, 67.56455990575975, 60.426948378163004, 56.895034467020345, 62.68937541592506, 62.87508395410354, 59.981743674124445, 53.845544630481356, 55.09746713023032, 55.70914506912232, 58.92803422866329, 56.478867069367446, 56.77375870366251, 59.238595731796764, 58.773532067575765, 59.75883145486156, 62.05837588156424, 64.21167081402194, 59.18756177348476, 57.22119131395894, 62.37617415766563, 54.96839369496992, 60.78626102016818, 55.23655829891082, 60.9059952920483, 50.92129999591459, 57.819403756049375, 52.85430677475468, 54.66450806586973, 52.76936000393283, 50.610632588786466, 52.31256077366491, 58.77626988195605, 63.69510250706827, 65.3121623685283, 62.7016681240451, 65.03492924474901, 55.25516602300829, 63.181358306638664, 60.87032918007144, 54.64884604177168, 64.16795992082166, 66.32749142185335, 65.40109034507506, 66.42759030865085, 65.36666762444281, 56.02590783949822, 66.70544316691738, 68.43866794340073, 68.46689331916072, 62.87145968406432, 57.96276638584753, 57.83973732302266, 68.78658217768516, 71.7379068559216, 77.83242287174349, 55.27520148984848, 9.16039449553336, 1.2252408217999244, 0.38937230804754847, 6.488739223249498, 2.701047798318248, 34.989742386725645, 82.3918487179664, 65.90516982540008, 77.30819809821345, 71.57403807486259, 58.151004852787146, 15.610189976230746, 49.7982705023981, 20.38312219804333, 56.94929653598417, 53.08816632916851, 82.66728539620676, 65.97887900567824, 81.50758958631947, 4.474935541229864, 0.5900675178535524, 0.2933989885833956, 0.1425662660791028, 0.19745786013382097, 0.22550006427111166, 0.2895610719438522], [0.05530972867423008, 0.11362305061230737, 0.17260760729832036, 0.03556409587843284, 0.08704713110121028, 0.07246469342780691, 0.061499814863406846, 0.19612007143516696, 0.04959986086994891, 0.07752018424892619, 1.2005042717341454, 55.50635853121358, 64.43851717056768, 42.165389137883345, 33.86110782623291, 38.118562159999726, 88.4654349665488, 57.158994290136526, 9.13188768971351, 65.27095002512779, 58.47060349679763, 52.90940823093538, 57.129152897865545, 62.751576362117646, 57.91838868971794, 2.498972680299513, 1.885443872982456, 0.15668062403077082, 0.2091136580753711, 1.0477916920377364, 0.30142942864087324, 39.129760957533314, 66.55362390702771, 65.64420277072539, 61.04255653196766, 50.05346382817915, 51.59300196555353, 62.35676627005301, 66.25247216993763, 59.59543335822321, 74.14037427594586, 49.980888212880785, 25.863642154201386, 61.45868470591884, 50.72263979142713, 54.00218056094263, 59.39589846518732, 64.09451746171521, 59.637288970331994, 61.16038060957386, 56.37352789601972, 58.205168862496656, 54.90364320816533, 56.12636758435158, 50.60669452913346, 46.69064721753521, 49.09483655806511, 51.5573868443889, 50.584282105968846, 53.89543717907321, 49.41250539595082, 49.11282454767535, 50.537429394260535, 54.693133523387296, 56.41025697031329, 55.97508961154569, 56.66740755881033, 58.74358084893996, 56.0284181564085, 57.17153410757742, 57.0013895342427, 58.737960092483036, 56.87620316782306, 60.32487261679865, 58.61848861940446, 59.07264417217624, 57.91364654417961, 59.284840476128366, 60.400578283494525, 57.26016398399108, 55.77449175619311, 59.57620982200869, 63.79712335525021, 59.19789721888881, 59.56238738952145, 59.34253854136313, 58.64708662033082, 62.67012834548951, 57.27082498611943, 49.802624333289366, 48.53663621410247, 56.22275590896607, 56.97127749842983, 56.93146936355099, 62.107801668105594, 55.91542251648442, 60.53782201582386, 57.091925682560095, 55.7076741803077, 54.82640389473208, 54.07369321392429, 48.98461011148269, 55.278766924335116, 52.77272931991085, 53.71162706805814, 56.301532791506865, 52.95008713199247, 57.11077659360824, 59.21011540197558, 57.5632219929849, 56.46842964233891, 53.75087822637251, 53.1255151379493, 54.25130205769693, 51.823868751525886, 50.344672356882405, 49.240470240193034, 50.058033389429895, 46.213075114834695, 49.1772416330153, 45.376559072925204, 47.28846350023824, 44.11069254721365, 45.26330847893992, 48.758148147213845, 53.110853318245184, 56.83824246929538, 57.417749128034046, 59.8522936913275, 60.164086818695075, 60.21214369804629, 40.19954427596062, 32.6474460863298, 65.99285833297238, 54.60216983672112, 66.18250493080386, 54.979827404022224, 59.937424813547445, 59.28564848438386, 60.548055479603434, 64.22928225609564, 63.340488864529526, 61.94407801474295, 53.446306182492165, 49.23783832980741, 54.91751270909464, 63.466024321894494, 69.51571941375732, 70.78941499033283, 43.296761512756355, 2.9739275815025454, 0.18371169936032067, 0.1401958981108281, 0.13332174520098394, 0.8872528806809457, 59.494624522424516, 57.29990151620681, 67.74924862769343, 56.32787935195431, 78.72837851124426, 32.63814222428107, 14.215226481037757, 36.489213512789824, 19.952069405586492, 44.73334527784779, 14.139903245433686, 33.27373681529876, 55.3347626809151, 44.32288100642543, 0.258192743865713, 0.06440027737088742, 0.15699764653559656, 0.16840285711711453, 0.13662480989531164, 0.09375876611879758, 0.06438588257879019, 0.06923050769875128, 0.14427764521491143, 0.12787190295996206, 0.025001151089165962, 0.19394913147534096, 0.05043601136534445, 0.13626369136956432, 0.0636288459833351, 0.015575328800496797, 0.0794050899604636, 1.0832833811160059, 65.58786184557023, 74.61447900341403, 48.098025014323575, 32.68610692793323, 47.270675551506784, 62.36313227684268, 58.8711480940542, 13.6754475485894, 72.01262181805026, 65.65720935021677, 57.859964986001295, 64.94448331094557, 67.56794883358863, 60.33514530427995, 3.829667404774697, 1.7248709860347933, 0.24858356513563665, 0.15898045062297778, 1.9944082969619383, 0.41694920570138966, 43.138772364585634, 69.10926772702125, 67.58575639417096, 64.9465621671369, 53.9233369981089, 53.429153657728634, 64.2884982785871, 69.07691601783999, 59.99840198024627, 74.98833579401817, 53.70757918204031, 26.605574161775653, 65.76743187442904, 55.14897961770335, 55.26617219371181, 63.109261220501324, 66.19451522827148, 62.64629602432252, 60.618869950694425, 56.47543891783684, 60.41014886671498, 58.08192799168249, 57.90977908718971, 52.28859116954189, 49.68339604716147, 50.95886061268469, 53.21205439106111, 51.35353734416347, 55.9206824148855, 52.994453061011534, 52.30064069071124, 52.961399247569425, 59.09079297896355, 59.471945378088186, 60.32380573211178, 58.54724268759451, 62.32941166047127, 59.0998105079897, 59.8022364031884, 58.75938015599405, 61.391361144281205, 60.42712880719093, 64.16785793919718, 62.44509412396339, 62.401587194012066, 56.910563130532545, 61.14433811556909, 64.50447574738534, 61.256968975067146, 55.62841876860588, 60.02188521046793, 65.77881851503926, 62.94724772053381, 62.52924465364026, 61.25621980236423, 58.60335611527967, 62.07543426944364, 56.20121817434988, 48.73909719528691, 48.92579024837863, 57.93525880382907, 58.099515899535156, 60.76529595159716, 60.290665626525886, 58.55541690703362, 60.61055060355895, 58.941240849033484, 56.70850615347586, 57.640516219600556, 52.500250108780406, 52.7859280955407, 59.47866439819337, 52.558069767490515, 55.633176603624904, 56.898066459163545, 56.67611522059287, 60.35618489788425, 60.539265448047274, 60.17237870923935, 58.80302044653124, 57.26225068492275, 55.11050116631293, 55.86605948786582, 53.28643429663874, 54.27068248871834, 53.994716290504705, 52.37848012678085, 49.21296265817458, 50.83774958887408, 46.46069826618318, 50.46488515792355, 47.16736032116798, 46.953402873008486, 52.02525108091293, 55.942082866545654, 60.18607954825125, 59.3718857149924, 62.26974064303983, 59.81745912182716, 63.0880255083884, 39.431567730442175, 35.38448579849736, 67.56564247992732, 59.87161528679633, 67.66545895607241, 58.14154409593152, 60.98704322691887, 56.44083969054684, 62.71035225160661, 67.14339148613715, 64.716001326038, 63.03379874075613, 58.281082414811664, 52.04187800807338, 56.44740966058547, 66.49390974352437, 72.85278566422002, 74.50415841994747, 47.3361320649424, 4.270347164523217, 0.11327822677670948, 0.3007130445011201, 0.34593644041207533, 2.0264696281763817, 65.78366264220207, 62.6269155933011, 74.44532286736273, 62.06621277716852, 85.78556968319802, 33.928733410373816, 19.599434598799675, 48.55942518480363, 16.33477137934777, 53.89069895590506, 20.012303283137662, 35.173779995210715, 66.99663208376977, 52.6305002550925, 0.31896683597756975, 0.04808488369528805, 0.12340313589741146, 0.050249269772921844, 0.01072952103230261, 0.030905486482586113, 0.028920717379679124, 0.17559222456428314, 0.20330211508177942, 0.15108638953778053, 0.08569301706888983, 0.40540784597396856, 0.22350299562658035, 0.1747752071147965, 0.341935561549279, 0.2787153813387117, 0.2587777898917275, 1.9977849673840309, 78.50125758878647, 83.05858104459702, 60.011447783439394, 44.093234077576675, 55.46139640192832, 106.34787359545308, 71.35073754095262, 18.0284978881959, 78.81692994025447, 71.02185464674427, 67.46236647329023, 71.80424982501616, 73.70153950106713, 68.53261655376804, 3.7437429831873987, 4.881545103365376, 0.27566377734464986, 0.550823652696225, 3.5964623958833757, 1.079269202966844, 47.46296190446424, 71.82459123672979, 71.49792055929862, 66.60848217625772, 54.456802875764915, 56.2811678455722, 69.0448231850901, 71.20002438945156, 64.41586548282255, 74.51559605136995, 46.342627079256125, 26.64274254152852, 63.59956925915134, 48.74163889115857, 56.29839097299884, 62.03036623616373, 68.57186378971224, 64.98450325381371, 63.60324844237297, 61.233689708094445, 60.62911125921435, 58.99278863783806, 61.01212678417083, 54.958560312947924, 53.10940204128143, 55.138659861779985, 55.54490366289693, 54.300308150629846, 60.746821588085545, 56.76745937716577, 53.73242347471176, 56.6651168946297, 62.73128986358643, 61.815863578550285, 65.34618108503281, 62.03977600220711, 65.73804547709804, 62.79503230125674, 64.72657603602256, 63.667587080309474, 66.60003339090656, 64.28988287525793, 70.5323899176813, 65.77818309107136, 66.80507921403455, 62.85285195996685, 67.00792850986605, 69.88433591781124, 66.03577690739786, 58.275430279393355, 61.419315876499304, 70.16884896063036, 66.45532146576913, 64.79113040431854, 65.46648802295809, 63.16676316722747, 65.82172532235423, 61.001461859672304, 46.675483334449034, 50.42957990400253, 64.59072082273423, 60.55984220197124, 61.62411851267661, 64.39110355992472, 61.87395388080228, 67.2817962400375, 63.14001260265228, 61.144585224889944, 66.54346496828141, 60.8619745316044, 58.920346383125555, 65.87917235589796, 62.48781657988026, 60.62732658078594, 63.64188378857028, 61.21519965510215, 63.648618498156154, 65.42590325878513, 65.31637107172321, 61.94028508278632, 59.754395254196666, 58.31000989483249, 60.035907683833955, 53.12588776311567, 57.201767736865634, 55.20235523100823, 56.7723152714391, 50.38513552758002, 54.11520365745791, 48.69759067412346, 53.544647847452474, 47.12368472929924, 52.011052100889145, 53.96872666574294, 58.913286116815385, 61.03658276219522, 61.55391985370267, 63.70608122118058, 64.82006180670955, 63.302230065868756, 50.54218330690938, 42.112276323380016, 67.7300682375508, 62.96540044969129, 70.95953602944651, 61.94492916907034, 65.04808095193678, 57.231754256832986, 60.51743745803834, 70.92802370748213, 68.78851198380994, 67.41716507942446, 61.20337370903262, 53.30252385908558, 59.37603950500489, 67.08901174606817, 76.86653921681066, 76.87675306873938, 50.37443530174994, 5.843121015256451, 0.7503191994563226, 0.7108020554146459, 2.7197991792232763, 1.8188624973258667, 71.6544545081354, 68.52921193645847, 79.7179062135758, 68.98093561972343, 89.72850876469766, 44.64108328665457, 23.159011025582593, 45.03151993597708, 29.62365169678965, 65.3900174940786, 24.10834227838824, 49.47623214414043, 71.87657833099365, 70.61362220394996, 0.6960776616488734, 0.35250236550646447, 0.20200604753148174, 0.3884374356317905, 0.18758922274554932, 0.15961579798210054, 0.14711244632640194], [0.032244579445931225, 0.051048215208274704, 0.07534912937591154, 0.0906493914343657, 0.10629109121979245, 0.03039035747098106, 0.07929172426942857, 0.02309423758678379, 0.13546999363649276, 0.06733003508059249, 0.1131563651705942, 42.219176600056315, 60.67848997731363, 47.319897374799176, 35.263480678681404, 38.45727843623008, 63.128359240870324, 49.332069350827126, 4.302938628581263, 29.899296260649162, 74.13630285570699, 52.1590470498608, 57.91718059970487, 55.07818083609305, 63.36984780526931, 7.558367608054993, 0.797582534292052, 0.07667214789938542, 0.07454636116181651, 0.5694876995778854, 0.27202139698689987, 32.34834771002493, 63.15537652661724, 62.779919408982806, 64.7671921791569, 56.9607537792575, 50.174006108314764, 56.21331084159113, 63.90602796308456, 61.699482933167495, 68.90487301734187, 72.82427787780762, 63.27164342326503, 52.94227769297939, 46.18677954519949, 53.13244204367361, 59.953879156420314, 62.69303498729583, 64.93289270708638, 60.85169399938276, 59.74089837843373, 58.09705265106694, 58.1302829711668, 53.762680638221006, 52.872290841994754, 48.64921216041812, 46.84383538461501, 50.06084965121362, 52.01166399063603, 54.055689534833355, 51.21514435737364, 50.28108681401899, 52.20895136556318, 55.99755694789272, 55.635581016540534, 59.38677503216652, 57.24190142846877, 62.57806639517508, 57.33969396160495, 59.862652670952585, 59.94862318038941, 57.78951529533633, 58.50901919026529, 58.90309579910771, 56.74097553376229, 59.51151817075668, 57.30476917759065, 57.493545009243874, 59.6011168726029, 59.22139613859115, 59.67806200827322, 61.36589711712253, 60.095162930027136, 62.874997661959746, 59.130381461112734, 59.20305121329523, 56.69618598876461, 57.713915532635106, 61.35934283656459, 54.152725050526286, 56.024397726981874, 63.842654228210456, 57.923860396108324, 58.30333794316938, 58.49681669665922, 62.559529273740715, 58.70975040620374, 58.26668731627926, 56.56841085803125, 54.933904294044744, 55.84903640131797, 54.75627191605107, 53.43621000166863, 56.553180294652144, 54.33098500774753, 56.54675152993972, 57.24234465629824, 54.89122890656995, 55.24372054684547, 53.779158515314904, 54.16657101723456, 57.268852033922755, 57.29603798158708, 55.74024554221861, 51.034032837037124, 50.81877708435059, 50.4178245605961, 48.20987532215734, 48.880302521490286, 47.854618410910334, 47.058283129046046, 47.716927528381355, 44.27279626169513, 44.85036919193883, 48.52196262728784, 52.85297316889609, 54.77545230619369, 56.205673986865634, 59.68422405181393, 55.370456249483176, 61.698133637828214, 37.96883744578208, 37.34973053778372, 58.971670596830315, 55.31396627426148, 64.77393865585327, 53.83522095218782, 59.613221306954664, 54.15947152722267, 59.049192320915964, 63.322524409140314, 59.60707495289465, 57.64132422785605, 53.098764573374105, 49.722043160469305, 55.78236395312894, 66.16383444878363, 67.48371985650832, 68.22835045476114, 39.920753971222915, 3.8475041379851684, 0.025048761538440184, 0.10010205074063233, 0.8203818012149104, 5.574285195719812, 67.71221360852643, 50.4942205644423, 62.700389431368926, 56.64282214257025, 73.68889377963158, 11.464535940077997, 14.748911030830877, 27.95236114532717, 25.708683036988784, 39.13256152983635, 34.46252092238396, 46.21487548274379, 60.03154208583217, 28.74196760116085, 0.2720090782930774, 0.09476578869526425, 0.13844832898147647, 0.058472243047529654, 0.04383763478648278, 0.028582347834843303, 0.012338458890876463, 0.035479301436533855, 0.030322782770400087, 0.07284818172094322, 0.0751529495802618, 0.03495240148397223, 0.05509358079683396, 0.12418939491673825, 0.03549475726040621, 0.08511564724387662, 0.02840043259634366, 0.1166949942407589, 44.81384408089423, 71.81658960157826, 47.37494391779746, 35.5569367254934, 43.13901947390649, 72.96465166153448, 56.02131866639661, 5.863014786474167, 35.4719703428207, 79.70458584447061, 59.73780755073794, 66.46548824925577, 59.560108492451334, 69.44133558580953, 8.507153161110418, 0.9052299611991452, 0.7010403792223623, 0.04989043801962849, 1.2628589258078606, 0.2430769557794256, 34.349925364217455, 66.8152146185598, 63.131030374957675, 68.30261661160377, 60.12494548674553, 52.53590445364676, 56.95104199071085, 67.66457250041347, 64.38972288562407, 68.51308315030991, 74.64968619808074, 64.1258297428008, 53.53685802029025, 47.98085205016598, 52.98423920908282, 63.222613796111084, 63.784948318235344, 65.73367987909626, 64.08052636731055, 61.87005112248083, 58.819615994730306, 60.38944267457532, 55.73936693130001, 55.18143330850909, 52.579984049643244, 48.921809042653734, 52.8177071386768, 55.19593431103615, 59.19870130477413, 54.568500211161954, 53.58788021149174, 54.055332599147675, 57.69216991239979, 58.577899932861335, 61.0181672342362, 59.79465838401549, 62.34603074289138, 59.96426951500678, 61.919359237917014, 60.64849561260593, 60.80359397395965, 62.22397442786925, 62.264778844771854, 61.082717680162006, 63.08354223928144, 61.15694853567309, 60.830685784739835, 63.893307716615745, 62.00068566106982, 58.7580700843565, 65.45403449766098, 61.70430352610927, 63.32284996586462, 61.89311858146422, 58.361702811333444, 57.614557973800174, 59.99900994762298, 61.98057174682618, 51.57206435357371, 56.92590352027648, 65.29528833204701, 62.668155393292835, 59.858498880940104, 61.745657074836, 64.82072468726867, 59.1390577439339, 59.020433502812544, 61.688288488695704, 57.015337482575454, 59.41143889581004, 58.09706834054763, 55.2724636754682, 59.44392788794733, 55.4331474919473, 59.345601912467714, 56.7969673679721, 57.374661891691154, 59.72581686512117, 57.19753157707953, 55.452021937216486, 60.20302026502548, 59.52880797847625, 58.37757664342081, 54.42630644767515, 52.14715834586851, 52.22288754678542, 49.39310143070836, 50.404947419320386, 50.40471992185039, 51.00979258937221, 49.47329036651119, 46.2862822317308, 47.343498276126006, 51.144424023166785, 54.81547617143201, 58.47225873701034, 59.79174014060729, 60.195183369421194, 58.810951479019664, 63.659616824119325, 42.11469250340616, 40.927045883670935, 60.83664778740176, 54.80110460712064, 65.91161820196336, 56.855100816295995, 58.03394171499438, 56.31406084183724, 58.34573091999177, 67.33004139315698, 62.03151941299439, 60.17910949645504, 56.28029707939395, 53.84219100398403, 55.95954918092298, 69.16848767188289, 68.45153331756592, 71.5105741254745, 41.661278278596946, 5.613531451071463, 0.2416657758576255, 0.068156766524959, 0.9674525417147145, 7.937598536091467, 75.65160859015681, 57.55529880523682, 68.4720943820092, 62.29627155488538, 76.6567708599952, 15.053361481235875, 17.289992070967152, 31.639006676212436, 24.34918953526405, 44.11211244521603, 35.6928978427764, 47.43172414841191, 71.70243294008317, 33.03254635103288, 0.33542856393802556, 0.05300687986516184, 0.1705961208790541, 0.06114291365168268, 0.027549352962523702, 0.0533640836816161, 0.04029092731915655, 0.18029601974112375, 0.11763473131483602, 0.21783808186169595, 0.2018757512973201, 0.21091528236866, 0.16494632968979497, 0.18809991227763315, 0.15342724779921194, 0.2510659045149242, 0.22655551892615136, 0.36403830133138165, 58.08681918728737, 79.34957996491464, 63.112916869501916, 49.849798679351814, 56.42380483688847, 82.37669267962056, 56.92491900536322, 11.386957341624845, 38.666650633658136, 86.63739081351989, 63.44034064200617, 73.8958066509616, 65.82062705870598, 78.07195417342648, 9.574508532401055, 2.472414557010897, 0.9680356878426768, 0.20442037362485163, 2.7955793709524217, 0.4529295056577652, 36.970453031601444, 71.925411839639, 67.08104933461836, 71.31072152045466, 64.50684093659925, 54.192925422422356, 59.762816582956624, 71.26314317026447, 66.40327161358249, 71.34124540513562, 78.35328225166568, 67.19655529145273, 53.09126500160464, 48.58051969159035, 53.00598090694797, 65.57066225236463, 66.8058087748866, 69.02073983223208, 66.25582971880513, 65.94048684643161, 62.14567607448947, 64.77111847169938, 58.13078895691903, 58.6114832662767, 57.106489443009906, 52.96167773585166, 56.99731811400383, 59.007328864066835, 60.59517883485364, 56.61231002499981, 57.41335999581122, 59.123693819968935, 59.46714439699727, 61.34939962817777, 66.11955088953819, 63.54135344105383, 64.91675607619747, 62.831235777947214, 65.19451479757986, 64.29901415301909, 66.4483553363431, 66.55582827906456, 65.94097322033298, 62.18778271828929, 67.8792908883864, 64.99093986326649, 63.884301954700106, 66.90658230935374, 66.95625520521595, 64.8760183395878, 70.62252598424112, 66.62869807212584, 67.09003940705331, 63.04900969228437, 62.48061903061406, 60.64099996320663, 61.58817783478768, 67.29199440248551, 59.48420278487667, 60.3564476966858, 66.54308842074487, 64.21798975236955, 63.7960054797511, 63.234004359091486, 69.42681497143161, 62.43549216178156, 64.1075671872785, 66.14426182162377, 62.01872856386247, 64.90136077327114, 63.617898494966575, 59.10530967097129, 65.32848335081532, 58.93571815183086, 66.24293296567856, 61.29342740581882, 60.66223175294938, 61.56310604464624, 59.075091731163766, 59.55334632627426, 63.87365271968227, 62.98973875661051, 61.39812723282845, 55.660291948626124, 53.20960290970341, 55.62969353891189, 52.15951773428148, 54.13686298554944, 52.56858171955232, 53.49026418501332, 52.76253507983301, 49.059550915994954, 49.16187378668016, 52.873467553046446, 58.55753890929684, 58.30407534876178, 62.36084553503222, 63.296064099957874, 62.68310354601953, 65.80421978427519, 46.72958066386562, 43.09803855034613, 60.510843953778675, 59.89230971182547, 67.71823836911109, 61.031373854606386, 59.12489014287149, 59.560751761159594, 61.08839727217152, 69.70581316178846, 64.51341482900804, 64.24277913185858, 59.814654627153956, 56.0505207123295, 59.05128294421781, 71.7644142335461, 71.09870172316029, 73.06681371504261, 50.27274393266248, 8.041532030028682, 0.44702636919194655, 0.2735760651769177, 2.4613451380883498, 7.863903574405178, 84.21702169602918, 62.62147134350192, 76.52509689331055, 68.06448167370212, 84.41192426989156, 20.529036329638576, 22.9806726209579, 35.86741193648308, 36.4007640654041, 57.285345600497344, 48.22648263746693, 63.11227360079366, 78.06474485704976, 49.592040123478064, 0.4715059427244048, 0.28043475843244986, 0.42899213851459567, 0.2772980573917589, 0.11731752494890844, 0.1928124102132936, 0.13453840007705076], [0.015168504511576988, 0.03121955763368357, 0.06085746546065616, 0.0726259625967472, 0.027855066094367255, 0.17607568733153806, 0.15371024067844116, 0.06712126079946756, 0.1632863397319471, 0.14922268147910797, 0.547641139597662, 19.775421542506066, 63.202417512093824, 44.10122786798785, 26.45480609709217, 42.976445075004335, 21.236098466380952, 21.48830882964596, 12.474559987744978, 17.5764839495382, 76.90896357259443, 49.628353426533366, 51.50906716623614, 57.407876522310325, 68.96160617951425, 22.567707838550692, 1.7081024858259386, 0.7541758086412185, 0.007557647458593091, 0.8151305442856205, 0.04000061446981084, 22.200756380634925, 61.32599092298939, 64.27802947259718, 66.19103216355848, 61.092182359387806, 53.731427192687995, 52.60222388852028, 62.28758742732387, 61.90799613152782, 64.47511288427538, 59.632844924926765, 62.564808783992646, 63.31167905561386, 55.38982883576424, 48.752009637894176, 62.44811827136625, 62.328529127182506, 60.854325909768384, 61.50902048234017, 59.83299170770953, 60.90305351441907, 55.877155873083304, 56.2965553037582, 56.43221832090809, 50.21169616330055, 48.429586887359626, 46.28895336581815, 49.35992994616109, 53.77884080333095, 55.784603626497336, 51.38852488610053, 49.99149037945656, 55.35066004722349, 57.98344904376615, 57.29944259889665, 57.38922565214096, 57.40404828902214, 56.27455472946168, 58.03241983536751, 56.00959077958138, 58.99500085461525, 57.810809843001834, 57.62863928271879, 57.831174788936494, 57.99421594988916, 55.121028807855424, 60.49682932515299, 62.63334435801353, 58.84246380098405, 61.90123004298057, 58.29681111920265, 62.30090387405888, 58.16321126876339, 57.25278208332678, 57.6989830693891, 55.64327670681862, 60.59992490276214, 56.19059639592325, 48.73942275201121, 58.61090667786137, 57.546081235331876, 55.32572161766791, 53.363583395558024, 57.35140615893949, 58.46238613128663, 60.58621229663972, 57.83872535151821, 57.1784374790807, 54.40900487284507, 54.309360980987556, 52.69512130368141, 58.26616171867617, 55.39264117517779, 55.889527028606786, 57.32746401140767, 56.85786608726748, 55.657867923859634, 55.68110012239026, 57.226211947779504, 52.01202484869188, 54.81333455731792, 55.70518739761845, 54.115164433756185, 50.9269795879241, 50.40197426272977, 52.830380316703554, 46.750769307536466, 50.5086156629747, 50.57940267747449, 47.94107529424852, 48.31537139031195, 46.977450924534956, 49.57353830337525, 50.560751807305124, 54.21661653826314, 55.68353591426727, 54.818676825492616, 55.765815473371944, 59.08267759507703, 60.01064761992424, 54.17909906756494, 50.034036328715665, 59.42173511751237, 60.266013529992875, 59.949262526727495, 57.63560148977465, 57.30136456028108, 56.48140484286893, 56.34545941506663, 63.26390850928522, 63.13901239825834, 61.380931561993016, 54.18100533946868, 53.82200256470711, 56.15277298035161, 64.16060939911874, 65.93161444510183, 70.92359142918741, 28.979676961898807, 2.0421432968108886, 0.39370346273626056, 0.28155772075537716, 0.4770845337019813, 18.43609686820738, 71.02429436099145, 49.76909591305641, 67.05155311092254, 59.221780530868045, 66.4237150069206, 24.051362006895005, 19.520130157470703, 40.2422078963249, 31.612228655046035, 63.14189534033499, 47.78083078322872, 39.34247109197801, 62.56478132740144, 12.96282054916505, 0.30730716163112276, 0.21386331127535915, 0.1090169086631748, 0.10212430835611398, 0.07013605426876776, 0.11166782569020026, 0.05222434403314706, 0.04967477277762467, 0.05547392812948074, 0.09897639944909081, 0.11256566541569848, 0.0336151298946671, 0.09619779088684628, 0.06189165351491782, 0.09004566818475725, 0.1627899607222888, 0.1979940297502664, 0.4899025942769743, 21.68102272095219, 75.8185132857292, 50.866037722556825, 31.152215042421897, 52.89256557341545, 26.25886017276395, 21.20268967843825, 14.200646050514715, 22.872927073509466, 86.49564420023273, 51.41615013922415, 60.86133910763649, 63.64566887578657, 72.93033876726705, 25.00366053273601, 1.1373139076655912, 0.7284690235410968, 0.011889263236474608, 1.1444028563076452, 0.057465090236115846, 22.833566088830274, 65.20070429771178, 65.53773003239786, 69.17516354591616, 63.4848399316111, 59.74959427310575, 55.43999987263834, 66.21048711961316, 64.27890416114562, 67.7246004535306, 62.83478552295316, 65.20772534032022, 65.82385124698763, 56.045664818056174, 49.43936578689083, 63.64990503557267, 63.99896460194742, 63.337586310602006, 61.9238385846538, 64.58120123032602, 61.86663473806074, 57.3337358813132, 59.03331064408826, 59.74524436458465, 54.00161573963781, 49.96808167426817, 49.35472103857225, 52.052590001013975, 56.614294744307, 56.07534931552026, 53.951734958156464, 54.17779684066773, 57.00504126087312, 60.577881182393725, 60.24487587713427, 58.66252114695888, 60.2526500148158, 60.49581343127836, 60.28668442080098, 58.85028892947782, 62.023725663461995, 59.73199852051274, 62.023961005672334, 61.86235935457292, 60.30520977512483, 59.89908756748323, 62.764731991675596, 62.67353688516925, 60.60816972486435, 63.06910791704732, 64.83128370777254, 64.40634196804416, 61.49398995983986, 59.322048079582956, 59.30342858837497, 58.5393665682885, 61.35265127305062, 58.35820013476957, 51.55802226835682, 59.904955433261016, 58.962362812411406, 57.497181046393614, 59.181862569624386, 58.8407850265503, 59.35934589755151, 63.08172618189166, 61.250183274669034, 58.155001747992735, 57.30359638890913, 56.95771002000379, 57.668082637171594, 57.678684803747366, 57.499530546126834, 59.54108107474543, 60.00625456533125, 60.628028685046786, 60.16485952561902, 56.86111380977016, 60.39712659774288, 56.57597318772347, 56.22084179232198, 56.53344685031522, 57.701524765260764, 54.80960830565422, 53.638706284184615, 54.07539944494925, 49.41807908396567, 51.81582004793229, 53.57664262094806, 50.73084146745744, 49.78406367763397, 48.16487396917036, 49.908449880538456, 51.83279606603807, 55.12086406830819, 60.01578984722015, 57.08639121824696, 57.92112650409822, 60.37955437937091, 61.09026824274371, 58.43153668988136, 53.43257004214872, 61.054853162457874, 62.15813744452692, 62.55941552500572, 60.65647371353642, 56.89135528379872, 56.45388549373996, 59.579414398439475, 64.35475103316769, 64.96658978923675, 63.677283179375436, 57.509481599253995, 54.921027152769035, 59.075734999872026, 65.91679573059082, 68.06099860898911, 73.24481087346231, 31.378602481657463, 2.622176778893317, 0.4024064667042225, 0.15422128261097018, 0.36409496119426144, 22.084832691377212, 77.20987212273383, 54.457908984153505, 75.45689429006269, 65.67782925021264, 74.49502714218633, 28.703802939384218, 21.533139559530444, 42.033283710479736, 31.011498051304972, 70.29615340694305, 44.47368045007029, 42.39619708830311, 74.84964078472507, 15.851547141228954, 0.43763836004560996, 0.26564337793857823, 0.12713953056522917, 0.03664464757387196, 0.03483577608881939, 0.05129108806290934, 0.05621771906472503, 0.11085080057983437, 0.225458710844959, 0.20796569064259532, 0.25133988820016384, 0.1359367403652399, 0.43997774741822676, 0.2659343994192539, 0.2581100983004416, 0.37958066249566697, 0.38873878397768546, 0.7682777100032376, 29.56537312076938, 85.41845152454992, 61.32439059595908, 41.93742490583851, 56.67860200328212, 35.262425561105054, 28.975789893058042, 23.238601799934145, 24.79639857046066, 90.78935300150226, 60.994130949820246, 68.21895245582827, 66.21412707913306, 82.94656599721601, 27.317068576812748, 3.5363626143624707, 1.875238723812565, 0.09857117724154266, 2.4324791902495972, 0.1896136560507359, 23.71264376947957, 68.58811024696597, 68.24766420548963, 70.39978242689564, 66.715131421243, 61.1365012199648, 56.5774283870574, 68.62167789090064, 65.89255548292591, 70.33193326765492, 62.866748917487364, 69.28128719329834, 67.79397933713852, 56.77211915293048, 48.97134857793009, 64.65038007305515, 65.47857284545898, 64.6520745369696, 64.92148253225511, 66.77054666703748, 64.84032084864955, 61.27142290915213, 59.31903962166079, 60.45867643048687, 55.13979342675979, 53.968346195836226, 50.2951681229376, 54.048452761865434, 58.528944830740656, 59.96341051593904, 54.86565897541662, 55.29901027679444, 60.46273608361522, 63.90658101727886, 65.00182051812449, 63.561094730131096, 65.30192890474873, 62.15136743360951, 64.9602355495576, 63.801563478285274, 65.61572636327436, 62.944302020534394, 66.08617936411213, 66.90454267686414, 63.86195621182842, 63.81566439905475, 68.48306917375135, 67.84489954671552, 65.40796625998713, 66.39727038721885, 68.16889516768917, 67.13360125018706, 63.277095517804554, 64.30778849509456, 63.38239546745055, 61.46489774027179, 65.4765175234887, 61.37342022311304, 50.90817574531802, 64.44368685445478, 62.77193738568214, 60.816690767965014, 59.88665757640716, 61.864944196516475, 61.302699888906176, 67.94435516480478, 64.2419828907136, 64.35431957244873, 61.98601207425518, 63.69823648083595, 62.40273644847255, 64.64394346360238, 61.40360678395918, 61.10770317815966, 65.76380368201964, 64.23883322746524, 62.47462957136093, 62.291556865938254, 64.88703627740183, 62.38741174820931, 60.13799521230883, 59.253712546440866, 59.62816553731119, 56.93064958818498, 56.36171763943088, 57.417309822574744, 53.34178286214029, 53.876311702113, 54.82938489606304, 51.02453677884994, 52.74393520047588, 50.21420255784066, 54.93812084197999, 55.84241151809693, 58.97427112825456, 61.6039026168085, 59.97973934296639, 62.587256508488814, 63.28161801061323, 64.43022135765322, 58.50504582928073, 53.98738538065265, 62.53472812714116, 64.99355608417143, 64.93231219630088, 62.96675366740074, 58.53824869278939, 59.20228635111163, 58.842954097255586, 68.12755338607296, 68.04326949581024, 67.04981942330637, 61.19726265630415, 58.10001796291721, 62.45582180638468, 69.00687817604312, 68.79834144346177, 77.19458272380214, 35.99483405390094, 5.175303662976911, 0.6555310792980656, 0.7542575655444976, 3.0504998468583633, 22.67524353919491, 84.1808888220018, 59.093009118110906, 80.57197093963623, 69.25130459570116, 80.82430485756167, 33.93967682315458, 30.943825398722005, 48.855505297260905, 45.31031416308495, 86.02029215904975, 64.17109389458933, 51.782597572572776, 83.8370224737352, 27.26453431190983, 0.49382827394912326, 0.36941740301347553, 0.1711281382989499, 0.1818462752646977, 0.22508081499366994, 0.20865469479993468, 0.2899969759727678], [0.04316505555423998, 0.01374229490231242, 0.042238192587730386, 0.12092212951111218, 0.06825179973196599, 0.10586493182927371, 0.11877777280225871, 0.05649753267906847, 0.2172735210267767, 0.19001663362066593, 0.602397304629126, 5.683663920048745, 55.0230440785808, 47.36709917745283, 33.738298416137695, 39.26427864259289, 49.07920591292843, 75.03244676897603, 18.91704809281134, 21.540146873843288, 61.16391466509912, 67.47883258327361, 47.10410033502887, 43.00702387286771, 67.00633602757608, 38.30969141375634, 0.28567709809830116, 0.29289998955303626, 0.11408143166092136, 0.3549475342996659, 0.1919736358667574, 12.524323098121151, 58.81323037608978, 61.01178946033601, 68.46650892688383, 59.071632200671786, 57.86003951103457, 53.86460342714864, 59.77405025113014, 60.14760894160117, 64.79045967901907, 65.55463937021071, 66.99282738470262, 62.79152177995252, 57.17690383234332, 50.10935368076448, 54.9299583896514, 59.64954637712049, 66.70871442364108, 61.30823827558949, 58.594499403430575, 56.86827998007498, 59.62390192093388, 58.712539211396255, 59.09371122237175, 53.44310945080173, 49.20952666190363, 48.13427163708595, 48.964166718144575, 51.34979540301908, 53.810000111979825, 53.31108247080157, 52.18191054559524, 52.45913974700436, 57.47686316890102, 60.308230000157515, 55.14410411157916, 56.58250785643055, 58.28200417180216, 58.66750255707772, 58.11107904680314, 57.47560016570553, 60.249339534390366, 59.45872699060748, 56.77899506784255, 58.49057228334489, 58.34207919336135, 55.79338973568332, 59.27568958651636, 58.22165066196073, 60.74024769567675, 60.98422696513515, 61.781711501459924, 60.08234070193384, 58.77336732802853, 55.310518510880016, 55.840050251253196, 56.41965496924616, 57.579743016150694, 44.323379147437315, 57.14154758761006, 60.89316129684449, 59.33012816213793, 55.987221502488666, 56.228313907500244, 60.154159299788944, 59.666365500419374, 59.02545021426294, 56.69622913483651, 53.45467652043989, 52.47476646977087, 55.793060256588845, 56.9880848546182, 56.59942111661358, 56.383023954206905, 56.34589872052593, 56.72666280500351, 56.726894224843676, 56.617165919273134, 57.07376510866227, 55.35290364296206, 55.629269922933275, 55.66660696460355, 54.807486303391, 52.603016207295084, 50.17080153188398, 49.88427631316647, 47.492081580623505, 51.665134353022424, 51.14796200106221, 46.87166460098759, 46.651235242043775, 46.40649895514212, 47.16924305885069, 53.34380680514921, 54.475057586546875, 53.8362996039852, 58.17160514093215, 57.917529690650206, 57.86252629372382, 58.82376586237262, 61.55248818858978, 56.588065854964725, 51.37480835760794, 57.342694574786776, 60.42845849067935, 59.037103576044885, 53.89132261276246, 52.51883822102701, 56.06929709834438, 63.951284270132746, 63.23514184644146, 59.990157158144065, 55.95692119290752, 53.5616042537074, 59.08754917883105, 65.74269740812241, 67.75208842369818, 63.396637593546224, 27.513208658464496, 0.9797978341098755, 0.176187536168483, 0.2331877719130247, 0.2988790300103926, 39.282670636330884, 65.1216842282203, 54.44181549933649, 68.03464028143114, 49.23575555124591, 79.47988894677933, 14.634853409182641, 19.525280229506954, 37.62341391655707, 31.73358286580732, 69.32113062950873, 38.52294675765499, 49.326452516740375, 54.870738444789765, 4.696453357896497, 0.30139287092512657, 0.16884450680546223, 0.11396488670500056, 0.10864346378272581, 0.01347554691751758, 0.20106683905807235, 0.01993005122658947, 0.046347461400493506, 0.05717016553746597, 0.014415094384833451, 0.08323830282015186, 0.0485411120368348, 0.10342707917574914, 0.01943004096017009, 0.06450825746381475, 0.16431147262694376, 0.21164424567212983, 0.5615812431900733, 6.407390736764477, 63.91435123259022, 55.086174626504224, 35.80924318682763, 56.460149518905155, 53.365768155744, 77.36994404946604, 25.810305764598233, 18.794805465206025, 71.84843924737746, 68.14337622734809, 53.795824666177076, 50.15687711777226, 73.57923999909433, 41.06012798124745, 0.4588353387530773, 0.36814425681387225, 0.32601839952891876, 0.43352241477658676, 0.1314005345827149, 13.044094020320525, 65.01462313436693, 62.38646253462761, 69.32826149848201, 61.18407172541465, 60.426611054328184, 56.10037011484946, 63.74943910106536, 61.88659960223783, 66.22445075742661, 67.55040014943769, 69.5204419474448, 62.8778806040364, 57.30167050515452, 48.43800037137924, 56.37447710960143, 61.987820286904615, 68.83762005836734, 63.35057720061272, 61.46419563601094, 58.501401947390654, 60.88129220470306, 60.91207104344522, 61.12393002356253, 52.74251530247351, 52.19130462215793, 50.20061154519358, 50.44996053941789, 52.33092531081169, 56.40691903329665, 56.24325029311642, 53.75363565260365, 57.0703604913527, 60.29969884503273, 62.09716420019827, 58.71397872124949, 60.46781555298836, 62.02724795187674, 60.323527243829545, 60.354596337964466, 60.6254909115453, 61.646213223857266, 63.64600619962139, 59.30908072379328, 61.26260934337493, 61.26085212153774, 57.2453962602923, 62.983184476052564, 61.70913588616156, 62.02201943243704, 62.990080002815496, 62.424984132089925, 62.333863550616854, 59.83507448627103, 57.90851608399422, 57.709067483102125, 60.63024874656432, 57.6257328064211, 48.686313859878055, 59.615927742373565, 61.59805436288158, 60.66223567531955, 57.725361008797925, 58.74915061458465, 62.34793701479512, 62.16753936582997, 61.26017355149793, 60.6136178970337, 58.51121963993196, 58.23737544398154, 59.86526496948735, 60.362731333701845, 61.90863155549573, 58.15616276956374, 58.49795810637936, 60.29316417632565, 59.345672515130815, 56.15002339886081, 60.12145457729217, 56.659739325123454, 56.72263060846637, 56.99148947192777, 57.1022258266326, 53.599074655963534, 51.37660480314686, 54.92207050323487, 49.9769893769295, 52.3533102773851, 53.374048279177764, 49.87368199133104, 48.49163878348566, 48.90715899006013, 49.160010660848315, 54.84532540844333, 56.803839360514, 58.20867153906054, 61.11608920558807, 60.909058663152884, 62.81703287555326, 60.63588127013176, 65.1808924059714, 58.630691113010535, 53.19340352089175, 58.38579008656164, 62.725794622975016, 62.85371880377493, 55.06790422624158, 53.22002072488108, 56.750538272242395, 65.04130309627902, 66.88547211308634, 62.281499908816436, 58.4453591223686, 55.08213458522674, 61.34070765587592, 67.91690641833891, 70.11159804559523, 68.23802301960608, 30.547248278894735, 1.4191852341736517, 0.345607788692559, 0.10994606606301763, 0.5755088442275601, 43.896695875352435, 69.7984124768165, 59.96259858531337, 73.52223227100988, 55.39271570021107, 83.86916237492716, 17.87543131459144, 25.54438867876607, 37.822352609326764, 33.16832311691777, 79.11439464938256, 39.464339133231874, 56.55219185736872, 62.004953199817294, 5.264107594566961, 0.44559648140303554, 0.14073350797257117, 0.11887413900225394, 0.12194198406031057, 0.059645487551367095, 0.024036102470070608, 0.049293617222217784, 0.1453118485909316, 0.2594764927221883, 0.14035875308177165, 0.39738117506907833, 0.14876569471051618, 0.24671337597312468, 0.2855507242343118, 0.29268759933690874, 0.41145454731679737, 0.4403048976054115, 0.8456677282529493, 10.668692915670334, 80.00172891924458, 60.874918353173044, 53.20402529931838, 50.73045315281038, 72.90185451507568, 84.56339051646572, 32.19553805166675, 28.982832508702433, 76.510129128733, 78.13015430204331, 60.677093613532286, 56.576977314487586, 80.7559379454582, 45.24015472781274, 1.4166782267632023, 1.7404127649722563, 0.4684288433242229, 1.4356441122870294, 0.2344330784774596, 15.432295780028067, 68.71496754307901, 64.09827509234029, 71.87583308066093, 61.984125414202296, 62.83441289778679, 57.38834311885219, 67.90002453711726, 63.81187931183846, 69.33347825081118, 70.52594154111802, 73.06975549267185, 65.20767434950798, 59.19185676882344, 50.53442878107871, 60.9750525413021, 64.69182775866601, 73.21981753072431, 64.440368529289, 63.509915644122714, 61.19323045976701, 66.22498419977003, 62.267151878726104, 63.811479230080884, 54.78041410446168, 54.99066099043816, 53.29465166214974, 53.07158647045013, 55.55675706555767, 61.20884149305282, 58.37429754195675, 58.8067663100458, 58.25347285116873, 60.83411393627044, 64.12169556463918, 63.001843190962276, 63.58984962586434, 64.38747536751532, 63.545283655966486, 65.31300175574519, 63.94132537226524, 66.70687875440045, 67.44846559339955, 62.393460043015025, 66.07140771804318, 65.90926477985998, 60.9053441785997, 65.32067391180223, 63.54067487101402, 67.54470486794749, 66.82687190271193, 67.14238735937303, 66.02566503709363, 65.52443319751372, 61.963144656150575, 61.15739568587273, 64.02644864974484, 62.820143315099905, 50.94545787380588, 61.92858073019213, 62.79362417036488, 66.04562205653038, 64.12650439047044, 61.5082516977864, 67.56163381761121, 66.10150798674553, 67.30138455667804, 64.33252688377135, 63.20347262967018, 59.13482550651797, 64.75889636624244, 65.93922384323614, 66.98782244036275, 61.59126081774312, 63.615188137177505, 64.66775225054833, 62.98951910388086, 61.17835290970341, 64.28554081147718, 60.443492935549834, 61.415570012984745, 60.11691247263263, 59.37941274335308, 55.98896695721535, 54.67052498171407, 55.16414350078952, 53.69238391999276, 53.92816543579102, 59.16543568334272, 51.975444824464866, 50.418962047946074, 53.18561369372953, 53.83979443580874, 58.26477319963517, 57.84449908041186, 58.99734250960812, 63.32439537971251, 64.18595967754241, 65.67898242704331, 64.1190165858115, 67.77454791530486, 60.95518573637932, 56.16014311390539, 60.98239521826468, 67.59346777392973, 62.396205702135646, 58.1174607430735, 55.460043184218875, 59.07040057643768, 68.34963798522949, 70.20444054757395, 65.96543312072754, 61.123702526092536, 57.08831317963139, 64.29294232399234, 70.80543395011657, 71.40005742349933, 68.32403275274461, 37.075788282579, 2.4033509339055708, 0.5868729924963367, 0.9173102484595392, 0.9614009374091703, 46.35893237206244, 79.23470943204819, 64.34141105221164, 79.79760093073692, 59.632813545965384, 90.7989392742034, 21.42544500289425, 30.92964210817891, 46.543656395327666, 48.969034379528416, 85.66567851651101, 53.61761569976807, 66.12518341310563, 78.40025655684933, 11.307685259849796, 0.8264038651700943, 0.3898723796010018, 0.25058777371962226, 0.31035095152835696, 0.15958811156451702, 0.44050309987318137, 0.12867119313488085], [0.08246388752013445, 0.06049469218499238, 0.05485071560307857, 0.024691611348140626, 0.07030358237604942, 0.025383419387282866, 0.04139907733206788, 0.09902323806478132, 0.08209637216021938, 0.14859280398776456, 0.04782986068617433, 0.30695797875523567, 43.62709568392846, 51.494946633615804, 34.13902344242219, 37.21752312875564, 35.692564441311745, 45.335413409817605, 30.31975277008549, 6.21095157438709, 61.8546401300738, 61.21439164684665, 59.34130691712903, 50.897699094587765, 62.90092845116893, 55.036858666327696, 1.049517780061691, 0.2955319305821773, 0.19375258395748754, 0.3395164397455031, 0.05768694929898747, 7.3460830507739905, 61.08991130705803, 60.139521014305856, 67.88130698665496, 58.690503335768184, 61.84773283620035, 57.20814158839565, 62.74516720925609, 59.50024920125162, 64.76089677503033, 59.83554517069171, 64.62584564762732, 62.218675305766446, 67.94651246839955, 52.57319442687496, 54.19710666902604, 64.90110581920993, 62.644123031247055, 63.0581723490069, 63.46344732469129, 60.43540500825452, 59.81938892795194, 61.96081084589805, 58.104277656924346, 54.80895719220562, 53.24799506895004, 52.169664905917266, 49.51243169846074, 50.13291143601941, 52.95848884890157, 53.26242154644382, 50.219305561434844, 53.61824720136581, 55.18185300211753, 57.856576058172415, 58.43244667976134, 56.05745938516433, 56.74255232657156, 58.56625441581973, 59.809061327288234, 60.46792930172336, 59.92956438372212, 57.790625326095096, 60.76780626850744, 59.12532160359045, 58.666667092231016, 57.5449162913907, 62.22271142467376, 58.68281549023044, 60.92879995223015, 60.52931047254994, 61.02056772478166, 58.28704049510341, 55.633372722133515, 54.99135917232883, 56.41706228256226, 56.17515794692501, 56.204116805907226, 46.22121403294225, 53.02652628191056, 56.63198071141397, 55.303320961613814, 56.008476826452444, 59.05957091239191, 59.59684541148525, 59.911674453366196, 57.731099436360026, 54.06956295813284, 53.03150376965923, 50.61338217027726, 55.92838594990393, 54.11704324906873, 56.66783509715911, 55.714773670319595, 55.50700179992184, 53.478963836546875, 58.190867900848396, 55.2501493115579, 55.76618417616814, 56.09254498635569, 53.002968526655636, 56.81714796250867, 53.177725807313, 52.106718709391934, 51.49823750219038, 48.66398772885723, 50.41716560240715, 49.735218401878114, 49.77519519867436, 46.58116209891535, 46.398520854211625, 46.56310350664201, 51.00081820641795, 51.56752617128434, 52.59894478705622, 54.14981072948825, 60.2042361997789, 57.068285557531546, 60.69474820167788, 59.17977194632254, 57.712436799080145, 47.10418662717266, 56.40242791944935, 67.72419252703267, 56.77806938848188, 66.23087559976886, 51.035495881111395, 52.84861933800482, 58.414160590018, 59.48290840271981, 68.13746913786858, 61.033621372715125, 58.490988054583156, 55.97224589317076, 61.0129818608684, 62.30855641826507, 64.1306346462619, 61.81260801130726, 17.15744341573408, 1.0268358165217986, 0.37452521763982316, 0.27106988514142655, 3.1464746065678137, 44.77973514987577, 60.574103939917784, 57.94943032726165, 56.14873686144429, 58.148847549192375, 70.10304727861958, 13.508089819262105, 31.23138612316501, 28.866569534424816, 40.29362232454362, 56.71551150660361, 27.493587001677486, 56.189858990330855, 38.26483518846574, 0.8178155905296727, 0.09554126119661717, 0.15556391298530564, 0.10943690104590309, 0.06785745597294263, 0.049314600370463826, 0.04363855534803964, 0.022905630570265557, 0.06287864289216458, 0.050407371168295224, 0.018700077911959063, 0.0838064412856775, 0.064883318789784, 0.026520897161155462, 0.11744428951773914, 0.14788403476197876, 0.05472687365967901, 0.10398191835490928, 0.18291895157627522, 0.8746496311599209, 50.64210568704913, 63.99130029063072, 36.246430566233975, 45.23032526816092, 48.99863650721889, 50.76964547557216, 39.02764989483742, 5.2004921436309814, 64.19963698233327, 69.554135107225, 62.22031093412831, 52.00920466453799, 71.84781951289024, 58.76960185266311, 1.7848528513023931, 0.4091607881409507, 0.42192457904738767, 0.7031546593193085, 0.187752430116938, 7.3556055849598305, 64.7938995976602, 64.4033178206413, 71.91999112406086, 61.689641706405155, 64.54397793739074, 59.71404975460422, 64.56406047267299, 61.37922925333823, 65.48189901536512, 61.805736018765366, 66.31462604768815, 62.62939060887983, 68.94204924183508, 51.55408813107399, 56.97562740695093, 67.56824693372174, 65.75774362010341, 64.76127332256686, 66.30328255314981, 61.62291434503371, 61.46654905811433, 62.24542979271182, 60.04600778702767, 57.53498877248457, 53.93557479304653, 52.19330110857564, 53.250929001838934, 52.43406403449274, 55.52309920710903, 53.389129792490316, 52.77939342683362, 56.11523197543237, 59.47017638914047, 60.763950578628055, 60.931773108820764, 59.34242087025797, 59.806150928620376, 64.3448313590019, 59.17699098587037, 65.18162196682346, 62.15077515571349, 62.194909664892386, 61.116234333284446, 61.354118239495065, 60.250339738784305, 58.66833017718408, 60.98476432984876, 61.25141489890314, 62.84459537075412, 62.00047385308051, 61.507777090995546, 60.48003373607513, 57.845985658707164, 58.89860076289023, 58.133091388210175, 61.56517705609722, 56.952442276862364, 50.11098146438599, 56.30103072812481, 58.268942679128344, 58.126211550927934, 59.07248727736935, 60.999477140365116, 60.37826391958422, 60.51142446456417, 61.968153522860625, 57.73090331785141, 59.29473269370295, 56.04377815800329, 57.673911279247655, 58.43560026537988, 61.37510684228713, 60.5262549461857, 59.71523431039626, 55.621409493107954, 60.006395770657456, 56.75754754774032, 59.43071734520697, 57.60940790176392, 56.3358299962936, 58.70127416426136, 55.838092988537205, 54.50536966323853, 54.157824131750296, 51.47999848088911, 51.476103567308, 51.02330907698601, 51.25679992860364, 49.905437500246116, 49.24210586855489, 49.98259444390574, 53.278436583857385, 53.92460392367456, 55.80046569147418, 58.75268859248008, 62.52593025084465, 59.52074358540197, 63.305799422725556, 61.47031061110958, 61.39412641525269, 48.799740960521085, 55.81011472209808, 66.3147044950916, 61.184962103443766, 66.80387896876182, 57.22140704431842, 53.40434074401856, 59.53923756076444, 59.46321810445478, 70.70524877117526, 64.04939451525289, 61.856781744187884, 56.22658806462442, 63.175690481739665, 63.24729727160547, 68.1152920569143, 64.97700760441442, 19.567598681296072, 1.3899269267435999, 0.8106348951978068, 0.43310891115857714, 6.302049602231672, 57.124159720636186, 67.88198947906494, 63.50805251829086, 64.45878797961821, 62.64708834309732, 77.38356251870432, 16.11684057020372, 36.22002124786377, 30.022329245844197, 46.0571373662641, 59.37452547011837, 28.411539293104603, 63.233808240582874, 47.1774604243617, 1.1123094106874158, 0.11339670227419947, 0.09727429763804521, 0.05838034314013297, 0.12976089192013587, 0.03244114228554311, 0.057300162997337124, 0.020847043150194713, 0.17947299616231074, 0.12192909080054491, 0.16355997101674158, 0.14709825837804427, 0.20604354539705863, 0.22325234697951427, 0.1832026186128778, 0.18213155108594126, 0.2843615719147267, 0.44803870841860777, 0.24220974424914007, 1.809111485077489, 70.58477709370275, 71.88670589077857, 52.264390145578695, 49.25505753486387, 52.225950917889996, 59.934302606890284, 41.40296274615873, 11.757924326004522, 72.87235829137987, 72.04777409953456, 73.20215902020855, 59.413415770376886, 74.92349901506978, 65.88209059930617, 1.9617993048121853, 1.3005030155181885, 0.7035517992992556, 1.3289254903793337, 0.41187660047604197, 8.784189185788556, 68.31770989202684, 67.74746002689486, 75.36656210499426, 64.64469655867546, 66.17265978167134, 61.32910920727638, 68.77112803920623, 64.16827371043544, 69.79420769599177, 64.5325206941174, 70.12237671882876, 65.10113885325771, 71.01600247044718, 52.13390073468609, 58.5144438282136, 71.78130395950811, 67.87965959118259, 68.35392121345767, 69.77429774499709, 63.89826559251355, 65.54979916541808, 65.63492636526784, 62.3653954844321, 60.396875566051854, 56.30039922652706, 56.760987466381444, 56.69318145321262, 52.57313166895221, 59.12692585299092, 56.384369327176, 56.052203409133426, 58.2779876647457, 60.943681424663914, 62.51769719585296, 65.53021084877753, 64.19230215011105, 62.463384136076904, 65.60513988617929, 66.16679191589355, 70.27958531533518, 67.89421158452188, 64.33765342158657, 66.3417374703192, 65.70236759801065, 66.1162482538531, 63.26667770262688, 66.32695797950991, 66.05456506052326, 68.03915885186964, 66.23156593691918, 65.9492023529545, 63.70918773835706, 60.53686103513164, 63.02469491958619, 60.78744557596023, 63.110775255387836, 59.136123811045, 50.20972713347405, 59.340177274519405, 62.68941856199696, 63.114823141405665, 60.98234422745244, 61.416370176499896, 65.71587624088411, 64.48886079172935, 65.73394660026797, 62.04367876052857, 63.82389745404644, 57.955733576128566, 61.70725314847885, 60.77498028355261, 65.50075384878343, 65.60920346167781, 64.30785517538747, 59.471878697795255, 64.11686712695708, 59.76904922916044, 61.64532676819832, 61.990401206478, 60.280204665276315, 62.48376869386243, 57.10575595978768, 57.3154458691997, 55.74225379574684, 52.82933696623772, 53.671869923991544, 54.54119659239247, 54.048841076512495, 52.01122076280656, 52.14314183881206, 51.72534273516748, 55.48242815079228, 56.09855013508951, 57.24415679131785, 60.001692848820845, 67.60859243331417, 60.82236643760436, 65.86768765603343, 64.11032069113948, 64.80712190751107, 52.0694601151251, 57.7916725989311, 67.8376196276757, 65.93126143178633, 68.44226083447857, 57.11860564447219, 56.34166256073983, 58.593569801699736, 62.28509672226445, 73.77497411543324, 66.61544046094342, 64.33297795634117, 59.95818984123969, 64.62507294070336, 66.45771411157423, 71.76184115871307, 67.43273688900855, 26.88114812297206, 3.2134221109651753, 1.4000802270827757, 1.03874413236495, 5.516252258131582, 57.663156140235166, 72.97667764848279, 70.49616290676978, 69.57140922546387, 68.04409319354643, 83.5271316959012, 20.31713616463446, 43.647013479663485, 34.528495188682314, 61.99613178929975, 67.28454974389845, 39.40148707359068, 69.00454044342041, 61.52386665344239, 2.8307995584703263, 0.37488598376512533, 0.32344529405236244, 0.21455813770092305, 0.24781346291063294, 0.16711703982324372, 0.2547836526026649, 0.10858664304138192], [0.006569675573583453, 0.07152178474972326, 0.08967997611410196, 0.12593220664008012, 0.06603194505817468, 0.09464800267690614, 0.042929560126316164, 0.07239093448245719, 0.1020123829103766, 0.14859121052488206, 0.03939194229221152, 0.12849639485319778, 25.175374054139663, 59.64730670375209, 50.611970117015225, 33.08891473277923, 37.029551382987734, 50.17360994892736, 37.46135334814749, 3.6908056947492787, 47.52311537342687, 73.062452039411, 64.69851932217999, 70.16371850044497, 56.67732723297612, 69.40978404014342, 4.96745579665707, 0.6574010079906834, 1.0142859480073376, 0.4308920978538452, 0.05895841393559691, 1.8517824598858434, 55.8364220588438, 59.41781274734005, 69.47322445531046, 61.83001156776183, 61.658819721591094, 57.420016257993645, 59.62957366820305, 59.195822285067656, 64.23008634198096, 63.07029247283936, 69.01025925913166, 59.55701766475555, 65.13802874472835, 53.78865065113191, 48.789884044278054, 63.2450536758669, 59.40695562670308, 60.10836562802715, 60.06553334574546, 65.68814116139566, 63.72366912903325, 59.830504925020286, 58.586317339251124, 55.201198131807395, 57.48653965611612, 54.15576488740983, 52.17481105558334, 51.60611052666941, 53.222311389061716, 53.29411037506596, 51.56923632467947, 53.734549399345156, 56.54873624924691, 57.10234742010794, 57.23183662660661, 58.068780206864886, 60.53549997268185, 62.00123871526411, 60.28205602399765, 59.51629169525639, 60.441582741275916, 59.07460143489223, 55.993677723792295, 56.40400471225862, 58.2823375732668, 55.575043155301, 59.22124316615444, 58.24944849937194, 58.94484550722184, 57.72893821039508, 60.43203961464667, 57.66903577312347, 53.88254434831681, 52.12377317490117, 58.38550375353906, 55.37779892644575, 56.946750917742335, 48.19457807848531, 51.7796754067944, 59.869799229406546, 58.42133852743334, 52.903046146515884, 53.133438325697384, 61.30527688610939, 59.75489339520855, 58.664458797824004, 57.501009279681796, 51.414200721248505, 50.83416846490676, 54.40796544474941, 56.062668292753166, 55.54040862667946, 54.05187699102587, 54.52878229079708, 57.2166492092994, 57.23638265363632, 55.54543318287019, 55.923651649105935, 56.00759821553385, 54.4748693127786, 55.88731873419977, 53.38121052711241, 55.21220038014074, 50.99615450828306, 48.935819748909246, 49.59498582347747, 50.39792637671194, 47.9959806319206, 47.970838239116055, 49.664866770467455, 48.53633811396938, 48.174483776092536, 53.04872689708587, 51.64740523984356, 55.473791091672844, 52.4954334382088, 61.002140429712114, 50.54795311343286, 51.50905147675545, 47.56122512202109, 52.30816379670174, 43.63078271189044, 37.75286389935402, 64.73188692523588, 56.98007145235616, 66.31603810095018, 46.91857614824849, 63.726242203866285, 60.628938674926765, 63.045063787891024, 57.17476614059941, 60.10104648528561, 58.31627784236785, 61.173406800916126, 61.6055735465019, 63.86981271928357, 52.61295941568191, 7.6254371962239675, 1.0153243342234244, 2.7708201446840843, 0.2691781382647253, 26.00317458952627, 50.61718686934441, 52.006219740836855, 64.07531353735155, 56.00243637638708, 51.63495563691663, 67.04628144541095, 18.53624282344695, 27.660523076211255, 20.122969035179388, 46.93426170656758, 41.681427494172134, 32.07043209383565, 64.1800682775436, 29.684828904367265, 0.19274683308697518, 0.01007121114525944, 0.03582696745833082, 0.02137269629465957, 0.143079238553201, 0.1677435158842033, 0.054569143816948905, 0.010517353939283039, 0.020848142486366055, 0.05707059708994724, 0.05162735852683264, 0.07855218129172441, 0.06298363524218721, 0.06227002051028033, 0.03444011082812663, 0.028198016844990275, 0.025629950311755943, 0.12014392973674883, 0.0460244519185395, 0.2558507517941537, 29.12662071566428, 72.12254231975925, 50.932231641584835, 37.614918062763834, 51.55741430098011, 54.57297955789874, 44.02204305894914, 5.2518202797059095, 51.045317496022875, 83.88632666680121, 72.0396077248358, 77.80131847627702, 60.896915005099395, 73.27030627958237, 6.087018895533777, 0.9702824092199727, 1.7422831226741116, 1.0922028508878525, 0.020317400602864164, 2.2552922464186147, 59.33039880567982, 63.538188088324766, 73.08549988654353, 65.93887082992062, 65.9522774911696, 60.047937593152454, 64.5416441271382, 61.124977296398534, 66.39192027430381, 63.95810527186241, 71.61417176646572, 62.084608693276685, 68.70917812470468, 53.376793938298384, 50.49476185152608, 65.09936986430999, 61.535053253173835, 63.350604657203924, 62.7816491742288, 67.55069824957079, 62.98008972598661, 60.76756700392693, 60.333293945558616, 56.66457560754592, 58.612667822068744, 56.72862791245984, 53.52078806969428, 52.02401945667883, 55.12937561158211, 54.330259369265654, 55.226854355104514, 53.912456343250895, 58.79491682975524, 58.51119610571093, 62.667214024451475, 62.00196827611616, 62.86885915264007, 64.32361918111002, 63.21538879025368, 64.61015224456787, 64.94111007259738, 61.07167620812694, 60.02520745800388, 59.610907108553, 58.737018723641675, 57.28647916547714, 58.62647456507529, 60.79022261404223, 60.18220032415083, 59.39816559514692, 63.84483506602626, 63.187559573881096, 56.56360987694033, 54.48370249040666, 59.78648416457638, 61.00813381133541, 59.03045908097298, 49.87956946895969, 54.301841797367224, 61.653536288968986, 59.72602867311048, 55.71604451825542, 58.4312189778974, 65.27392710408857, 59.32893968397572, 61.26258188678373, 56.575835904767445, 55.94091007786413, 52.44945149267874, 59.22160010184012, 60.281848138378514, 58.69905410274383, 58.23681846741707, 59.69655206126552, 58.36554673410232, 59.562779626538685, 58.78558551111529, 59.25574041181996, 59.60891454450546, 54.99028444290162, 56.7747510633161, 56.205528859169256, 56.94286384890157, 52.14043932576334, 51.35079952978319, 51.950165148704286, 52.905929088592536, 50.16400798674553, 50.49394992090041, 51.69439131213773, 51.51387206969723, 52.182149810175744, 55.53482709392425, 54.41161324900966, 58.23945822254304, 55.99042215654927, 63.028126993486964, 52.21967120324412, 55.77133817057456, 45.453841532430346, 56.06406857890468, 40.54354398481308, 35.43798300527757, 69.41705611444289, 57.285824129658366, 70.98047364142634, 50.80327195505942, 61.632237818933305, 61.35072538929602, 64.08459386517926, 59.65177036100819, 61.88924327973397, 61.51219760217975, 63.72211194807484, 65.53634151335686, 68.2271815884498, 56.444283531558135, 8.428147800507086, 1.0169392475678076, 4.590950425594084, 0.3670512638505428, 31.60142448640639, 56.97266209510065, 58.43459613861577, 68.4138079612486, 63.98438122964675, 58.41241513529132, 74.60062519196542, 17.819015864403017, 38.528791089211744, 20.52140731965342, 53.47466099646784, 47.38835057904644, 34.33938595556444, 72.74669339579921, 31.63785742175195, 0.2596466255284125, 0.11455205479456533, 0.08587598950872499, 0.0742221144478648, 0.12408748224017122, 0.1149038730129119, 0.04192890757093987, 0.04654251504689456, 0.11522704720376961, 0.09376419768218072, 0.27613918086694134, 0.21390788227079377, 0.2224004418859559, 0.116185944136833, 0.28596330854681234, 0.18061278177605522, 0.37908377786797864, 0.30058051129021957, 0.13310691882525721, 0.2873864241184727, 44.29291802067911, 79.34165677716656, 70.41491493102043, 47.20805491170576, 51.71787061998921, 67.57693106128325, 46.59241145656955, 9.166578112110015, 55.85297446097098, 89.95976386531707, 76.01095261112337, 82.48355373259514, 66.90955546594435, 82.16434340323173, 6.151813509002809, 1.6134677058266056, 3.3102114979297887, 2.459804136906901, 0.14698564345317502, 2.973361779605189, 65.51155213386782, 67.04028806378766, 74.95049276659566, 67.27913687306066, 68.55345218412339, 61.90128495616298, 66.3326140372984, 62.71412557171237, 69.99970066931941, 68.86574345250284, 75.41221064905967, 64.58076976960706, 71.91931647639122, 55.71430690826909, 49.29545794763873, 67.42110313907747, 62.68704160567253, 65.01038305221066, 65.08892851491129, 71.07405354899745, 66.1304158549155, 63.772522249529445, 62.19674533413303, 59.69167655514133, 60.82097399619318, 59.66485538790303, 57.66883573224468, 56.183830307376006, 56.777292759187766, 58.60181854617212, 58.861883455707186, 57.95984814243933, 62.55164923206453, 62.43893208042268, 64.92907231853854, 65.44364806144469, 67.39123036784511, 67.16245420517461, 69.19327705137192, 68.70144321072486, 68.32673134342318, 67.09827638441517, 63.30839603177963, 64.23163175582886, 64.24738791681105, 58.064022371845866, 66.65643707398446, 65.3252983862354, 63.907251742578325, 62.87026336116176, 70.4553702569777, 65.72521540426439, 60.82434723454138, 57.784800606389204, 64.60470407239853, 63.87051874591459, 64.18958394758164, 51.66178464889527, 57.29095458984376, 67.22527488585442, 61.98994228916784, 60.205291317355254, 58.830633932544345, 69.6585407564717, 66.34087454888129, 64.43200603608163, 63.18288410863569, 59.7125082631265, 55.75683716804751, 62.08270634374311, 63.95883091034428, 63.797464601455204, 62.63111645175565, 65.03004197151431, 64.25271449550506, 63.12618232542469, 64.28376397778912, 62.23604356088946, 63.3131891681302, 59.16656532595235, 57.68019491626371, 56.86092945837206, 57.855187539131414, 53.85465237402148, 54.70422598623461, 53.012903890302105, 55.25957868945215, 53.774820373904326, 52.63668975522442, 54.457940363114886, 53.59232425689698, 52.32465344090616, 57.36041192085513, 55.016517254614065, 60.92679954344227, 57.50084846250473, 64.25866080868629, 58.26911526341593, 61.66715083583709, 47.88194556390086, 56.41124540759672, 42.03033408811016, 40.66747519277757, 68.63295078277588, 60.12799316836942, 67.58960031693982, 55.818394845531834, 66.46385654326409, 63.548586291651574, 66.50090725191178, 63.92048189716955, 64.08206393641811, 66.22556471055555, 66.18758047780683, 67.87597256322061, 68.26812328830843, 62.990899778181515, 13.130315561448375, 1.9020880830864755, 6.897401165577674, 0.9656361166027285, 32.71392633838038, 61.86611306282782, 63.933759120202836, 75.38017272949219, 67.50467315796884, 62.32907041426628, 80.13750568512948, 26.916876992871686, 38.700131985449026, 26.916327861047563, 65.63027443424349, 51.086282730102546, 50.12127768608832, 81.2664265786448, 48.191404881015906, 0.450635286829164, 0.3405934061494566, 0.2092564721862155, 0.21888691751706987, 0.20846760080706692, 0.3448957865757327, 0.1930359853131156, 0.09742366180064217], [0.03734194080255205, 0.08637832868243418, 0.07035775245317528, 0.03411545808757505, 0.03154993688146914, 0.03326852490464526, 0.06091365034902289, 0.08105489094891856, 0.10563474539066516, 0.21627452705175648, 0.1991104803258373, 0.6141160596762935, 13.218875815791469, 59.92363376002158, 45.634709865816184, 28.31290933393663, 32.07799638471296, 43.7994916977421, 34.96141895171135, 4.9270019415886175, 44.60844132208055, 52.14962159433673, 52.95759454850228, 62.10172591670867, 60.5561355621584, 65.27375844217116, 16.306863715571744, 2.1362139909498157, 1.3670774044529086, 0.3584085969674972, 0.15293662977074424, 0.6508378408128216, 44.571033677747174, 69.74753933568155, 66.12883121736589, 64.08409572416737, 63.436175084883175, 60.308124096162864, 62.11676036157916, 60.10234086744247, 60.76824557396674, 56.6696786111401, 60.877409058232466, 62.05350037544005, 65.06149153555593, 61.06598092663673, 45.80421117044265, 62.68996769382108, 62.825513039865804, 66.0637826304282, 63.21841293765653, 60.48399532994917, 65.2060151869251, 60.550903120348536, 62.5853737708061, 58.78724859606836, 58.126725381420506, 55.36320770940473, 52.88353235490861, 49.01030555848153, 53.17505467322565, 53.15917691876812, 53.25617321075932, 51.03171079389511, 54.83229137236073, 53.730446600144916, 57.68833775674143, 53.26577517294115, 61.591605986318285, 58.23191550470168, 60.20766827367968, 61.04967955620059, 57.96209566054806, 58.91568660736085, 57.68689432451802, 59.261396469608435, 55.274169906493164, 58.436859346205196, 58.93335688498713, 59.04292437338061, 59.12671404500162, 57.423122775170114, 58.58840796255297, 53.8917266168902, 52.25373306582051, 52.06345104402112, 54.237605141055205, 57.44053025399485, 59.5650585236088, 47.226317467228064, 51.032424665266475, 56.56770090903006, 52.78768531737789, 53.09485789268248, 53.18643739146572, 60.39898187883439, 57.66631757059405, 58.427790826366795, 57.03290970094743, 53.51097037715297, 50.54526628986482, 51.83123104033932, 55.08871240000571, 55.4821418177697, 56.6614887022203, 56.005746856812515, 52.46005758162468, 54.26994508312595, 56.35092327671667, 53.932491810091086, 56.46135760891823, 54.965369547567065, 54.801547834950114, 51.66073345368909, 52.8317060778218, 49.62308176102177, 52.52424324712446, 48.36009033264653, 47.83311989999587, 46.20770931243897, 47.64455979870212, 48.309503524534165, 50.807759146536554, 51.297714171871064, 52.413287239689986, 51.645020438778786, 56.50694339506088, 52.99056991454094, 58.97407500974594, 52.38039032105477, 61.99835969555763, 47.3274322479002, 54.16560611417217, 24.769889231651064, 29.937772750854496, 67.18434887547647, 56.5138546113045, 65.07021096444899, 60.026419470387125, 53.256114375206735, 57.398819769582445, 65.3734141011392, 63.26669339210757, 62.03712447997063, 60.28058905755321, 65.26490957506242, 63.176671074282744, 67.82585251715876, 45.63126994717506, 0.8440349190946549, 0.3462478091880199, 0.627406275560779, 0.6026856601238251, 37.96852757853847, 58.23606144997382, 55.52659403893256, 64.18191963626494, 39.019240333187966, 54.994053840637214, 48.22098739685551, 4.469389309806209, 40.08897266080303, 26.31270843167459, 51.593445193383005, 28.49951413369948, 35.38637245855024, 62.34849399135959, 16.333839816431848, 0.3553907927726546, 0.23595267516230387, 0.06703938132212048, 0.06412183505392845, 0.04510506597017089, 0.10030024534752292, 0.09893876921025016, 0.02830531320444519, 0.056345789813466614, 0.034863654028383956, 0.06413484705732235, 0.019447174516596624, 0.016850852745495016, 0.02791970284775861, 0.07149850333770437, 0.06372215166207283, 0.16192831099033356, 0.08116750587378779, 0.2912400608822223, 0.535570596975665, 14.149212991037677, 72.24026833811115, 49.54247313161051, 25.020850320016187, 44.44258782171434, 54.75273001578547, 42.83482005519252, 8.930422990552842, 47.082997983501805, 60.07681015999087, 56.2523776485074, 69.56285845848822, 64.95836065661523, 70.88452462227114, 18.766489874932077, 3.1436907043380127, 1.6801057107025579, 0.8572830920738559, 0.08843369661800324, 1.0329838866187682, 46.12416675013881, 71.74181353661322, 67.64352506206882, 67.86656671954741, 65.68213993503203, 64.50457772900982, 64.69370265160838, 62.56957446375201, 63.88913039238223, 60.05913203762424, 61.55611638099917, 65.1794332842673, 64.96255367032944, 62.942607556619954, 48.73188003416985, 64.33003225634175, 65.4716851634364, 65.78387837256155, 64.18746194531842, 63.74079419720558, 65.4293784787578, 61.546910578204745, 61.36958022271434, 59.96295159862888, 57.727588915055804, 56.87172774345645, 53.519646659974136, 50.31433674596971, 53.709661960601814, 55.168485564570275, 54.14390756237892, 51.942822471741714, 56.897705601107695, 57.10451649081323, 62.67883992964222, 56.30949520295667, 62.550084206365774, 61.782688171632834, 63.74641887603268, 65.4313043625124, 64.44852313687726, 59.97476185521772, 62.24736352120677, 61.70122054315383, 59.28656239663402, 59.31359144949145, 60.28288364410401, 59.83074811197097, 62.162463818826986, 60.667181784106845, 59.82971652861565, 58.50538707548573, 55.89511248373217, 55.412033373309725, 59.77019063888058, 59.56353664398194, 59.914047487320445, 49.965328170407204, 56.280889357289965, 60.941504509218284, 55.73532296765236, 57.1382841756267, 55.354856983307876, 62.723249004733184, 60.322707468463534, 61.741875909989886, 59.15927363980202, 56.14849367449361, 54.732957347746826, 57.602488840779955, 58.07341252603839, 58.73793263589182, 61.431153589679354, 58.09094159833847, 57.06581446432299, 56.166520887805575, 59.708758477241766, 57.063045270981334, 56.453053951263435, 56.159393941202474, 56.08455119594451, 53.76012325286866, 54.125005660518525, 51.214881558572095, 54.9087893578314, 51.965301575199256, 51.44103365559732, 46.30410940416398, 50.28135353519071, 48.75302160939863, 52.56767565204252, 53.81615431078019, 56.87380659964777, 53.718844229175204, 59.899428813688225, 57.265251298104566, 61.40479133975122, 55.45131983295564, 67.16882413433444, 47.344859338575795, 53.64900642825712, 27.457367835506318, 34.64820200397123, 67.61548011533677, 59.791642081352975, 65.31947758889967, 64.96013356793311, 57.00113065781132, 57.32321608451105, 65.58890911840624, 66.49448240956953, 64.96029830748036, 63.42893438954508, 67.15958303020847, 66.38808419627529, 68.8661592237411, 47.12438683356009, 0.6343472773028959, 0.7224662650016047, 0.6914450360401985, 0.8703254019060443, 43.895860410505726, 58.89341931189261, 60.24246361947829, 71.43865354599492, 44.03743051713513, 60.8455829466543, 49.025285090169604, 9.469161514312992, 51.4180407216472, 26.957173462836977, 62.92995006807389, 31.839653561192176, 39.164662207326586, 70.47957912568124, 20.29654960478506, 0.45599330577158165, 0.1140674275736655, 0.13219559595229166, 0.1214302373268912, 0.011882952587198348, 0.08018133621062003, 0.11443285151354729, 0.02291358639335921, 0.2658284341375674, 0.2502331056541974, 0.21541736659503755, 0.1585876313789237, 0.13537962590494465, 0.17877945676445964, 0.257420833673208, 0.13997330360354918, 0.27400902742820404, 0.2942921858160727, 0.4217271428675421, 0.6069220650580622, 20.721842396643854, 85.43876940204252, 57.787256010117076, 47.7886127656506, 44.74545363456973, 66.58003714776808, 42.39675406486758, 11.504433308878253, 52.721091316592315, 67.88992835629371, 62.69589047278128, 75.6058894434283, 68.3089473170619, 80.0821610419981, 19.99571950204911, 4.095231232143218, 2.719332907469042, 1.5702082529183359, 0.3076677438953231, 1.507321749964068, 51.48190475279286, 76.67959905439808, 70.71610589181223, 70.11337880165347, 67.55934315343058, 67.41951850152785, 66.48763395124867, 67.17550000836773, 65.8424589710851, 61.84883502221877, 63.933970928192146, 68.90758729750111, 66.96197402092719, 64.62982685335221, 48.379423695225874, 67.79060609879033, 66.28156046713552, 69.97543688743346, 65.63450274928924, 66.47046181463426, 68.53759796388688, 64.06790418009605, 64.804639047192, 64.07763558049356, 59.99917468717022, 60.711214311661266, 57.55207853932535, 52.27354103519071, 57.04628106086486, 56.56075831382506, 57.4706462121779, 53.57800368339785, 59.07885720652919, 61.43040049460627, 66.67131070167788, 59.42222149141374, 65.38066264121764, 62.95972478005194, 68.37034025499898, 68.68373763176703, 68.09257368887624, 62.370408273512325, 67.32266733723303, 64.06762569181382, 64.33157767018965, 63.47059388314525, 64.51258328653151, 64.264822852227, 66.57291412353516, 64.28576830894717, 65.00816299069312, 59.1488048338121, 58.762247408590014, 59.48867820924329, 63.55331274770922, 64.06367194268012, 64.55891040063673, 52.79592621710993, 59.76209094447475, 63.48585582548573, 59.04436388323384, 60.05392313003541, 58.74943302523706, 66.8846405706098, 67.07159642250308, 62.93568065089565, 62.9555239215974, 61.080721193744296, 60.480092571627715, 61.03417834927959, 62.69814191326019, 63.11894947482694, 65.67676236552578, 63.88583167906731, 59.353889880641816, 59.02271632225283, 63.90167020982312, 58.29148454050864, 61.14182387628863, 60.04110482431228, 60.32049917405652, 55.99623903151482, 58.07326347597184, 52.66479745987923, 57.97180744909472, 55.43759545972271, 54.5048205314144, 49.728369943557254, 53.980450630187995, 51.805402232754616, 55.495936793665734, 55.402262749210486, 58.49647545045423, 55.84942471596503, 61.10838174819947, 58.114173796869096, 65.07224275219825, 56.08518661991243, 66.72155626358526, 48.867931365966804, 55.51741177035917, 29.097063695230794, 37.08755147072577, 72.03235134001702, 63.93304132646131, 65.8116683652324, 61.58359258405624, 59.47334174186953, 61.060666115053245, 67.46996018194383, 69.05877113342285, 66.78413375731438, 66.13891955344909, 70.30380202877906, 69.85476124671199, 73.10184048068139, 58.01862485947148, 2.162363942592375, 1.1627760962132485, 3.247959806073097, 0.7830535235904879, 50.56623135843585, 74.54703777067124, 66.69054600500291, 77.2213960463001, 49.903778337663226, 69.6505783450219, 56.73064401072841, 11.44139003369116, 52.193897308841834, 39.290888001841886, 66.88744114291283, 37.68565016408121, 51.42459892457532, 77.0203039723058, 32.153158803139966, 0.6117199817972799, 0.32322790894296866, 0.30007743667210307, 0.3528396280542497, 0.11906287242327968, 0.19827061813444863, 0.25248989342681827, 0.15685317767483575], [0.09533437149178597, 0.15557229398719727, 0.03635644529675765, 0.0913065416558135, 0.03505513387461824, 0.05349637940526009, 0.13150171947575387, 0.07504047255121893, 0.058127829068971265, 0.09122199619248991, 0.08078337406679507, 0.19525584764778617, 2.700088288514845, 53.890671499313854, 55.33837910621397, 44.19803196384061, 32.97437760137743, 33.698007829727665, 31.651293500777218, 1.8747908381685134, 40.266675641459805, 55.87420625071372, 50.60655724617743, 70.8134904984505, 60.47192227455878, 65.2600811373803, 30.94507859599206, 0.70090867338642, 0.3750075465969501, 0.8887612771603369, 0.10100347575761619, 0.0635893311682007, 32.81430567464521, 77.0412572737663, 66.43083018641319, 67.62518405914307, 61.45706868940785, 61.80212351583666, 62.10739766397784, 62.33759372465072, 61.667735268992764, 62.2240803318639, 62.51670483619937, 60.45271442782495, 61.364120283434474, 63.07850199361002, 57.07929172823506, 60.540673578939135, 64.23944903958228, 55.76473682157455, 57.03041507351784, 64.4698255292831, 60.612409807020626, 61.39203186958068, 63.037964297879135, 59.53462093107162, 57.781517582554976, 57.58799960536342, 55.42538904374646, 54.237354109364176, 52.30258226394654, 49.71775993224114, 50.17286469859462, 50.396388807604396, 51.89660126163114, 52.19741959725657, 56.652463328453806, 54.383011325713134, 57.812935767635224, 57.752280235290534, 60.781283532419515, 57.05409834461828, 60.399562389619895, 57.07129401545371, 58.63934778398084, 53.58660151881557, 54.46687944473759, 56.446746780026345, 58.04122555640436, 56.66769389183291, 57.97872651007868, 54.35418582731678, 58.57803329344719, 51.85358855032152, 52.17146135145619, 49.40228369928176, 55.053438525046076, 55.159660231682565, 58.330947506812315, 52.16024337276336, 52.94285035902455, 57.55832687500985, 55.35293894429361, 51.476240850264034, 51.045890162068034, 54.741410055468165, 55.67736602598622, 56.20880403826314, 56.57422381062662, 55.474650090740575, 50.97221628312142, 47.27189933100055, 52.998893184046594, 56.63819374576692, 55.07310921146024, 55.13807935099448, 55.551485400046076, 53.70029141826015, 55.185226240465724, 57.77398663182413, 57.37459521139822, 53.039450491628344, 50.80482521364766, 52.236219683001124, 48.37962765847483, 47.55484734812091, 51.5830038439843, 50.77072412736955, 48.30093706807783, 47.41223389102567, 48.4912504688386, 49.207075180545935, 50.649801377327215, 50.732022100879306, 52.901708618287124, 52.28830483651931, 54.92187830709643, 56.48566845924624, 58.2871267872472, 60.054519330301595, 59.36906945320868, 57.00000885994204, 49.35312071154195, 49.741866819320194, 57.77954855272847, 60.130911411777625, 63.88774971808157, 60.53362507973949, 65.36183526439052, 65.43732520072692, 57.18501921622985, 56.16956072468912, 61.277667322466456, 63.97440664229855, 65.07655343701764, 64.19447122081634, 72.91144078777683, 68.75889808900895, 15.379640902242354, 0.9079657531073018, 0.3420460927149942, 0.31931185133514867, 2.5686236783381435, 53.47309597076909, 55.31552345521989, 58.72976626119306, 59.452494344403675, 46.76843566279258, 73.8166218419229, 27.712765124536332, 9.726129712597016, 33.350054371741514, 26.570306170371275, 46.16955641777285, 21.730972143911547, 52.248465322679095, 55.035485836767386, 11.274508872339803, 0.50511228942102, 0.33520731774549334, 0.0947406150460724, 0.22870784294941734, 0.06589797160197651, 0.13923730761293443, 0.07759845545214993, 0.12330752812446126, 0.061194375607996225, 0.03698934500496234, 0.020857620909209215, 0.050348171723946455, 0.10290604745668751, 0.04041922023339618, 0.05136797647742976, 0.08987907470474321, 0.04750593189871119, 0.08608573672151373, 0.21583247899768815, 0.13339573397271096, 2.4060186359190174, 61.04589839135448, 63.37531951165969, 44.223990209641, 44.79016865453413, 43.25918520650556, 38.88694663201609, 7.000036845284124, 41.355404007819395, 62.68538636545982, 60.27488200895248, 83.8254750159479, 62.52916228386664, 71.97676350993495, 34.493048729435095, 0.6442002711757537, 0.25253461763983776, 1.0792625839671781, 0.04373695551147384, 0.05124730613803671, 35.22675944912818, 78.96751757591002, 69.26562124683012, 70.2377022466352, 62.48797739705732, 65.02365635287377, 65.16857224126016, 65.11566731237596, 64.01735659568541, 67.1142404310165, 64.10230336650726, 64.59184654297368, 61.89237333113148, 63.62932043690836, 59.39930700486707, 60.535876520218395, 63.86856540556877, 57.83680731250394, 60.56315660476685, 65.84584005417364, 62.393711074706054, 63.69259219015799, 62.76238641431255, 61.309065895695845, 59.26550319117885, 59.50286934452673, 58.20171717674502, 54.01814460754395, 54.01289255388322, 51.8320704275562, 52.930945965551565, 51.77145019654305, 53.520340919494636, 54.640648288111535, 58.331837884841434, 57.2139153172893, 62.52384354991298, 60.695579744154415, 64.45318291264196, 60.27657255049675, 64.30280316260554, 61.25719255016696, 61.32828943191036, 57.32610687132805, 54.26615607353949, 57.441910928295506, 59.402805759060776, 60.71811768316454, 58.59973576761062, 56.37235902970838, 59.74402842983123, 57.33056660621398, 54.848733948123076, 55.33915965787826, 59.38789290766562, 57.006582752350845, 61.671673328645774, 53.931711258426795, 54.536458369224306, 61.51701819512152, 59.18108986270044, 55.07172069241924, 53.81256926444269, 57.91883976228776, 58.792355522032715, 58.900338372876575, 60.62973099370157, 56.395599072979344, 54.189646320958296, 52.68404060794462, 58.411724798140995, 58.57033368079894, 59.028313544488725, 58.57877462140976, 56.58372379118397, 57.8954702808011, 57.72074830147528, 58.57604465176983, 57.55975854012274, 56.081762390752, 54.96090589031097, 53.26963870756088, 50.41469450919859, 49.22250186243365, 53.360672996890166, 51.71037497058992, 51.61120176315308, 50.06400715920233, 50.74126320500528, 52.322166658216915, 53.96003077107092, 52.53328038800148, 56.64207296986734, 55.43024886038996, 56.07197607717207, 58.94694005289386, 61.71151284248599, 59.844429339132006, 61.13427331370693, 58.961578338376945, 50.27026891708375, 49.52940771656652, 58.68880887185374, 61.88235167534121, 66.76285882149973, 60.195697199913766, 67.73596748228996, 69.84529264511602, 62.7840575095146, 57.37415198356875, 61.608970319071126, 64.54096947946857, 67.85172447081536, 65.43146910205965, 74.45905116296585, 70.99133860680365, 14.94383910009938, 0.7867310520622038, 0.9215043040533221, 0.3211985113880327, 4.123752501703078, 58.21161723905995, 60.97898275621476, 60.4576370023912, 69.36277051125803, 45.88807144472676, 81.7103761242282, 31.80872175001329, 15.003526787604056, 37.61574568287019, 27.287274252983835, 57.09441638761952, 21.42078914949971, 53.766944254598315, 62.09839974680255, 11.297290978893157, 0.6512970645581523, 0.26603475693733464, 0.11561744560998295, 0.12290079672370227, 0.06242318446898173, 0.0737193615866765, 0.054481691049952666, 0.030283712286261782, 0.1539881773773701, 0.20010892271755204, 0.13440179127839305, 0.1301369491604067, 0.1882029511034489, 0.13517124998954036, 0.17922850686215586, 0.14943960693574723, 0.1930497136087187, 0.15813144134177318, 0.34164974946648846, 0.3128754870305139, 4.980430016594549, 80.26865405421104, 68.18703220736596, 71.72385692596436, 45.12533126338836, 57.699594959135986, 41.34338586561142, 8.866273606977156, 47.59909952840498, 73.43136664359801, 62.151873419361735, 86.25592462478146, 68.15067968060895, 78.823088061425, 39.298713130335656, 0.826575591439201, 0.4387846420849524, 1.5370927847200826, 0.15672436765124723, 0.18832592353705438, 36.409958101088, 82.24683084795552, 74.85095870110297, 72.10998289046749, 64.71218093749016, 68.32391508163946, 67.13428374259703, 68.02246524441627, 66.46414679865684, 71.15554471169749, 67.75259048708024, 67.16277583952873, 63.03618746419107, 65.57588684943416, 56.70940829861549, 63.33231464509041, 67.9815000103366, 57.772335313981586, 63.50077652162122, 69.33822431871968, 64.52174986562422, 65.37802680846184, 65.78665933301373, 64.1446610419981, 60.827865600585945, 63.30862352924963, 61.534394294984885, 58.392077645947865, 56.39280634541666, 55.00734675315119, 54.76582288742066, 54.93848170003584, 56.114051342010505, 57.04887766991892, 60.99802194103118, 63.02243171199676, 66.55273745136877, 62.87868468992172, 68.53791959824102, 63.29254181154313, 67.97738936639601, 65.39745430792532, 65.67884514408728, 61.04834202797183, 59.47256511257541, 61.67821976446337, 64.55470169744184, 63.041070815055605, 65.34920523243566, 57.668204230646936, 65.3313623705218, 58.749178071175855, 58.93971896940663, 56.514937185472064, 61.945799935248594, 60.977606004284276, 67.5140005542386, 56.298379205888324, 58.86833183227047, 63.49598338527065, 61.403089031096435, 58.39558032251174, 56.35320609615695, 58.90126405223724, 59.41929540326519, 61.71892612211166, 63.9502997552195, 58.65153066573605, 59.5934368718055, 54.8061683870131, 61.02548637697774, 64.11602773974019, 64.21755044691025, 62.65348572884837, 60.25474063811764, 60.803852850391024, 62.566091399038996, 61.616277694702156, 63.158039815964244, 59.642454731848936, 57.25743009198097, 53.59590145849413, 51.53304853746968, 50.04534059955228, 55.64420238617928, 56.48717464939241, 53.826831002389234, 52.34357103224724, 53.93433532407207, 54.48985276683685, 56.5647905103622, 53.79670327709567, 59.46954488754273, 56.49973407868416, 59.51327147022371, 61.850615778277, 65.05421946125647, 63.531696565689586, 65.42012952989148, 60.10697318661598, 49.86646483021398, 49.83490543980753, 59.41563583189442, 63.49870158780006, 69.21390087373796, 63.745104882024954, 69.38441414986887, 66.58602268465104, 63.737130703464636, 61.85644834272323, 65.25419758212182, 67.65551182531541, 71.30063318437146, 68.36545298176428, 76.36785691784274, 73.56722185688635, 23.606633870832383, 1.122409146158926, 1.4346106903206919, 0.32921954388580016, 4.857528430800285, 58.69713998609974, 70.21906314357635, 65.97408586932768, 74.73101262123355, 54.66946986413772, 88.80592023172687, 35.97239025177495, 17.046930636129073, 42.07385278517201, 41.541900942402506, 60.2536266849887, 35.70400207273422, 67.82771956536078, 77.59709635088521, 21.129859109078687, 1.000703025248743, 0.41600676433693984, 0.2307238033221614, 0.35803655402794965, 0.2317759484773682, 0.23802642920805564, 0.27576358327942513, 0.12482260489055227], [0.056875930317947944, 0.05242671764966461, 0.06673186596843504, 0.028677126317615473, 0.10036300327027999, 0.08980263445165851, 0.06986460633455746, 0.012526404198950097, 0.042887436781799605, 0.04990944849146951, 0.037312840952748255, 0.034116304614731384, 0.1043736420932316, 30.434911597159605, 53.448836111253314, 39.514741589946134, 24.169278260200258, 29.367934734590595, 58.90484125383439, 5.466548473604265, 19.9877159057125, 68.76591128687706, 40.77568554109143, 43.49565705945415, 70.7959653485206, 54.83946146503572, 69.98336007518154, 2.6179538571065475, 0.3140378262727492, 0.29201105176921816, 3.575863088330915, 4.760511546365676, 10.730965445118567, 79.12052139159172, 63.39819085213446, 72.33387962464364, 62.842073286733324, 65.49405444052913, 59.501990733608125, 63.57006126834501, 57.88307951342676, 61.011565885236195, 59.89983281781597, 63.36537630327287, 61.62632680708363, 63.154082144460375, 58.45668300505608, 58.73426521978071, 59.89165075363652, 56.03144230381135, 46.37955619442848, 56.59973882859754, 61.77012874234108, 66.0639081462737, 62.90305045343215, 61.27537273591565, 59.28889620688654, 58.51058813833422, 55.988241318733465, 54.53019042168894, 52.77805982097503, 51.04368186766102, 52.72060102032077, 50.868983422556234, 51.601325235059186, 51.438017352934814, 57.59959020922261, 55.2734128890499, 55.40409841845113, 59.585976523737756, 58.054518468918346, 61.1669348901318, 57.377478153474875, 56.686156488234005, 55.00964133970199, 48.99027793638168, 56.657366291169204, 54.42622407790154, 56.85919184838572, 55.03263819602228, 55.715487541690955, 54.27733482853059, 53.65776900322207, 53.29502036494594, 51.82224489027455, 52.04550620048277, 53.50384343054987, 53.61502301308417, 55.418881831630586, 53.45689265958725, 54.421678050871826, 56.004805487971154, 53.979815206220074, 52.21141069166122, 48.77202941525368, 52.77839714480985, 52.55307266789099, 54.19187422721617, 54.80889835665303, 55.401427284363784, 54.08162032404254, 48.96162894464309, 49.831347850061235, 52.362174833974535, 53.405548834031634, 55.44476163002753, 55.64124884143953, 54.27598161082114, 58.944390512281856, 56.28909887806062, 55.76984374753891, 50.55109493194088, 50.8731254454582, 49.78382833542363, 46.71296942618586, 48.70115610861009, 47.24492519132553, 46.845380798462905, 49.760729497478856, 47.100856534896366, 49.36167540088777, 49.884366527680434, 52.82471249180456, 54.01692082805019, 52.997590957149384, 53.62958677353398, 54.274851968211514, 54.84707478554019, 57.90916719744283, 57.68085387445266, 59.264051914215095, 59.36983823776246, 57.47268976703767, 48.27045240709859, 54.284920692443855, 59.828171114767756, 59.45070966597527, 63.49861921802644, 62.98921708137759, 64.46666017655404, 69.56411361694336, 62.54552248985537, 61.720506837291104, 59.90037410489975, 64.38942086312079, 65.6390566210593, 64.86440420150757, 44.508777818372174, 0.6904178653513232, 0.5109635770561234, 2.5248009975879424, 0.17132008928925763, 1.85949482023716, 43.94842409318493, 60.42797211677798, 58.53384387108588, 58.713696310597086, 52.48121876870432, 79.93046729795395, 21.191085346283455, 21.78204336474019, 37.52360920752249, 34.483991976707216, 36.21281585385723, 29.262279810444003, 53.214521561899495, 41.92536361755864, 2.593554018005248, 0.2790359738132646, 0.17639870064393168, 0.08794498614846699, 0.06267485584342672, 0.010413928239065553, 0.22533630531641746, 0.025870375515472506, 0.09494813294300149, 0.047898651551335096, 0.011119306568176517, 0.04515247149092536, 0.06380012026056647, 0.03854780916064497, 0.05898485929074307, 0.06489215178355094, 0.04082060434044369, 0.03626215902547683, 0.1329092221755174, 0.09200722865399816, 0.01484598149545491, 0.0778210959247043, 31.58380323840726, 66.16580347861013, 38.077134086239724, 34.113971264131614, 41.35729066787228, 55.67418890614664, 9.380061934071204, 20.227608065451346, 77.6509661828318, 47.182747779353974, 51.050789202413256, 75.30727940220987, 63.1210244086481, 75.98355877783992, 2.8559419512748723, 0.44366210939422734, 0.32617351701182706, 4.913167741990859, 6.277210702819209, 11.002879834944203, 85.79897634444698, 64.32489002904585, 76.1071369724889, 64.57154435496177, 70.12909966130411, 62.27981328964234, 67.6521699659286, 59.982277116467884, 63.79676641956453, 61.200741798646995, 66.46557454139956, 63.56764901068903, 64.90163141681303, 58.19606504132671, 60.53444877747567, 59.2587096460404, 56.608442568009906, 48.40424445367629, 59.95513823724563, 62.229089198573945, 67.11580153434508, 64.45690131956532, 61.1887118893285, 59.21086849704866, 58.91282719950522, 56.377713064993586, 55.70755650920253, 52.766480984226355, 54.13208946104973, 54.77017671831193, 53.288352335653, 51.595029830932624, 54.43657913515645, 58.85642351642732, 59.91287077626875, 59.971922059212964, 60.19235926289713, 60.210868927740286, 62.08556182922856, 61.75267811744445, 59.458597552391794, 57.53141549325759, 50.37457258470597, 56.480812564972915, 58.68166623576995, 59.27280272206953, 56.79479437489664, 57.99095253790579, 58.158476967965406, 56.88242404691635, 55.40032509834536, 53.91903808040004, 57.106167808655776, 57.569882177537494, 57.60230056701168, 58.60147729996712, 56.35868172491751, 57.95938138038882, 61.24050286508376, 59.18556528706705, 56.91146135330201, 54.449656317310954, 56.524723499051994, 57.063935649010446, 58.491058657246256, 57.4738900123104, 56.04845754561886, 57.98180949303412, 51.51164024106918, 53.71369415713895, 53.66020479509908, 57.774010166045166, 59.89806382886825, 59.16585145458099, 57.79861911650627, 60.99535472931401, 60.64306705228744, 57.21660998559768, 52.94356030802573, 53.19231702435402, 50.40819906419324, 50.46041757829728, 50.78977900166666, 51.0714404813705, 49.57297740444061, 50.0527617239183, 49.75437918016988, 51.87989980943742, 51.32656320448845, 53.55978819631762, 55.125127684685495, 56.13289048594814, 53.96448266121649, 56.213907041857325, 55.53678827901041, 60.39466727164484, 58.7232865056684, 61.94710608451598, 60.888175964355476, 59.511023952114975, 49.020076182580766, 56.5568987015755, 62.931032642241455, 62.12864514320128, 63.46443576197471, 63.31336959715813, 63.60873191587387, 70.79700869898643, 69.48484251576086, 65.37756004641133, 62.43179728907924, 65.23991623232442, 64.36543949188726, 69.34578664841192, 45.73077655607655, 0.2384733189378054, 0.8317198412072274, 4.0305069761891525, 0.38474712881349754, 2.8267112230100944, 48.13216924667359, 66.0865088432066, 63.49942722628194, 63.28745057505947, 54.438261831960375, 85.2553201490833, 23.96269290677963, 24.3129252618359, 34.67041046388688, 36.91301776516822, 45.467628663586034, 28.227036883754117, 60.19874488153766, 50.49964128002044, 2.705409719097999, 0.43420267020983083, 0.2084813444244285, 0.06597527753441565, 0.05045469624981765, 0.06766513726043125, 0.08071185209818425, 0.0768959145211885, 0.0888144729598876, 0.15551505189749504, 0.12371407566411842, 0.21781307675184744, 0.18019750083406127, 0.2419650710878834, 0.22729718396740578, 0.15770974058297374, 0.14086997887540248, 0.1964478651362081, 0.11040901299566032, 0.256677100194558, 0.19440941242200716, 0.20362687507464042, 54.41233104275119, 72.85533520483202, 59.33077143084619, 34.964980463827814, 45.54871189978815, 78.73793340498402, 9.89582125217684, 28.610440723357666, 81.15849864098334, 49.93068971941548, 54.09863164347988, 81.5368426230646, 67.23188800196495, 84.95122663436398, 3.3015146226652208, 0.9183370514262108, 1.1171617503127744, 5.449300341067776, 6.375066974470693, 13.673251021292902, 87.3469554224322, 65.41693279820105, 78.9663879333004, 67.06887429760349, 72.84917708366149, 62.573845924869666, 70.1316805808775, 61.508706692726385, 67.40347600752308, 62.50746373207339, 69.39793063748267, 65.92212230928483, 68.81163827834591, 59.54069276009837, 63.33563297025619, 64.02579753629624, 59.06290100466821, 50.608687093181, 62.88219128885577, 64.16834039072837, 70.75883619246945, 66.08441429753458, 64.57625904390889, 63.35234226719026, 63.29442062685567, 58.93388640496039, 58.88741416315879, 56.7578064241717, 57.55027817141626, 57.113855654193515, 56.62824269263976, 55.179660397191206, 58.94573980762113, 62.59077095216321, 63.729862551535334, 61.348968167458814, 65.28838103817355, 62.87699022600728, 66.57743269397368, 65.17740541888823, 65.44475809220346, 58.714178762128284, 54.50039609786003, 61.95297395029376, 62.446266912644916, 63.072873392412745, 60.86228047647784, 63.02862121212868, 63.93676757812501, 58.38982228309878, 59.92279045043453, 57.909614347642474, 59.680878270056944, 62.00770278130809, 60.070848157328946, 62.67535294255903, 59.50122587142452, 61.65313620721141, 64.9905554709896, 61.88236344245173, 62.12704481617097, 57.231216892119384, 59.59054608498851, 59.73654846991263, 59.975718913539765, 61.27680440102855, 60.47666442009711, 61.50641995091593, 55.65764827112998, 57.06287268669375, 59.238670256830034, 61.47916732295867, 64.4180267087875, 62.563651684791814, 59.324256373989975, 63.73356134660783, 62.9335900275938, 60.71063772324593, 55.40130961325861, 56.232789331866854, 52.84623061456988, 52.409509997214045, 53.04972710147981, 52.583745602638494, 50.9918987366461, 52.96109722506616, 52.51210351144114, 56.590803669345, 54.46412594087663, 58.4332311537958, 58.0016056952938, 57.32974683084796, 54.5522419867977, 58.507940538467906, 57.462393545335345, 63.874178317285356, 62.47415496457008, 63.76850574247299, 62.49114667215655, 60.51424464871807, 48.96408434837095, 57.120672733553, 64.6067907733302, 63.71169805526734, 68.1338684020504, 66.64558779808783, 67.77158260345459, 70.7654885322817, 68.16363919165828, 66.64422281326787, 65.86262779851114, 67.2996194901005, 67.14317967814785, 66.6978729924848, 50.48764274966333, 2.056725198222745, 1.2662087525090864, 5.35161518281506, 0.5590416310775665, 4.699019078285464, 53.53709336250059, 73.35135029208276, 67.05491850453039, 71.6146424508864, 59.84091489545761, 95.32948078647738, 27.735095177927327, 32.175761461257935, 44.962521522275864, 49.87267786456693, 51.95278136960922, 46.94926085010652, 68.57005165469262, 63.250839171871064, 7.441304470262221, 0.7591908653416942, 0.35116137456028695, 0.2198469482602612, 0.29243077602117296, 0.18246103018041582, 0.43259336462905335, 0.17738506948995977, 0.30169952059945754], [0.038920162365801876, 0.016502930084243417, 0.07899688767088998, 0.11416549448885265, 0.045080072351641236, 0.24734873865400595, 0.09850160879713875, 0.10203136656914027, 0.07275428998494342, 0.12433432343025362, 0.1756119743109711, 0.04092373892724995, 0.329330473417236, 12.691852431143484, 54.23043112601004, 45.03958040668119, 33.25493689506285, 21.282005886877737, 65.16841926882344, 12.817556550425868, 6.276642449440495, 59.60010490109844, 52.31451019164055, 50.13072275346326, 60.380899752340014, 63.288968532316154, 67.34686051645588, 25.429918227657197, 0.565518812546807, 0.5438585038627348, 2.7485673129558568, 4.548178940050064, 1.5042095943804712, 57.69478221093455, 67.9612527355071, 70.35749143169772, 63.86264654897875, 68.85057172467633, 60.58801658691899, 67.06770543129214, 60.81714184053483, 65.51553333959272, 61.832466971489694, 65.50519004944833, 60.247060637320246, 61.423469666511785, 59.37073253816175, 59.11079706684236, 50.33305429643201, 58.351716456874726, 49.97906823312083, 55.36613771992346, 62.96594958151541, 64.19832298832556, 59.805884207448656, 62.97732053264495, 59.5419636080342, 55.80534511996854, 57.32382797425794, 56.27994014370827, 53.52412992908109, 55.29609987812658, 51.96447003272272, 49.540386430678836, 47.50544509580059, 50.59476660143945, 53.28985852579917, 54.97880758777742, 54.85535490897394, 59.12733770185902, 56.20028465024887, 55.09527060293383, 55.916430565618704, 53.82196726337556, 50.838212428554414, 54.16250744173604, 54.758774388221006, 54.03001369968538, 55.60163290269914, 54.34784727711832, 53.049703567258774, 50.88023670258061, 50.16415703681208, 50.24222004798151, 51.1027527624561, 53.188669220093765, 54.557407748314645, 53.66423306926605, 54.724598776909616, 51.5502049846034, 53.384619066792155, 54.01456348357662, 53.21298399279195, 51.009129708813084, 46.05719620181669, 48.86408744319793, 51.425610896079775, 52.10300030246858, 55.998059011274776, 51.67984716353878, 53.969973979457734, 53.319582246964984, 49.40413898037326, 51.074754884166104, 50.9739617378481, 55.09876935712753, 55.07554892570742, 56.338669792298354, 56.2669570984379, 53.99814444203531, 51.365955568129024, 49.996813035780384, 52.14757019473661, 49.37809052005891, 48.22229746849307, 48.16365411204677, 47.74431743929463, 48.72355284229402, 48.87880025371429, 49.40391148290327, 53.33336153338033, 52.304555216143214, 52.490412804388235, 51.604192487655155, 52.28389609244562, 53.43398209541075, 52.5927278303331, 55.58976773292788, 56.74018713735766, 56.02353088317379, 59.41465916172151, 59.34038908250871, 58.835682022956114, 54.77917463548722, 58.70760486971948, 58.802820405652454, 58.36154591652655, 57.266392707824714, 65.25247566161617, 57.96027960315828, 62.15719999805574, 62.97089176793253, 66.28197623837379, 62.88281494571317, 62.256632081923954, 58.12295990605509, 53.17719628733974, 7.368367996908004, 0.5151561924046086, 1.467281337226591, 1.7425323157541215, 0.32142931835785993, 11.35150597941491, 59.5857725604888, 55.1124741185096, 56.237476564222774, 53.35788419169765, 58.16743958380915, 67.45413734066871, 18.327135386005526, 29.931855855449555, 31.31173783732999, 36.6544904247407, 28.978500250847112, 33.99888107853551, 55.16131154952511, 35.829466927436094, 0.4415978395169782, 0.057997605613162445, 0.060677189650314475, 0.04965113896516062, 0.06536531066822429, 0.07027030351661867, 0.08332033551508382, 0.02044434520235706, 0.06085176959693913, 0.02548684700272016, 0.04848081325631469, 0.03671905769395732, 0.0224400406342841, 0.03738482640455327, 0.09067511666686305, 0.11596573216299857, 0.05923781386246124, 0.12194137118997113, 0.037652355799030875, 0.1331756981990991, 0.03910499256885341, 0.26413685071372217, 13.463516004623907, 66.6397983797135, 45.13185416498492, 23.350591351909024, 32.646683185331284, 67.10463846883466, 18.14442942219396, 7.252467351575052, 63.12872402129635, 52.051962421786406, 49.27941545363396, 69.52622352107879, 65.24501531354844, 73.98995922457787, 27.06546421973936, 0.5857358728685688, 0.6751104480316562, 3.335130805930784, 7.4992741596314225, 3.170901902260319, 62.408792588018606, 69.7957766440607, 73.90907210688438, 66.61221627266177, 71.6465626993487, 64.17785213839623, 68.94158640215474, 62.98991526326826, 69.52494482840262, 64.95695252572337, 68.84584919098886, 64.50364028253864, 62.167064759039114, 60.96738038524505, 57.42052616611604, 52.0798034052695, 58.43321546431511, 51.36361391313615, 58.23521814038677, 65.63478123757147, 65.63838197338966, 62.014504171186886, 64.60026394936347, 60.943908922133915, 58.47654588760869, 58.12124190791961, 58.20527084412114, 57.247278997975016, 56.23671954677951, 54.91155070643271, 52.86335568274222, 50.67773257532428, 51.91276927148142, 55.73560537830476, 55.775692001465835, 57.58452438539075, 60.492518640333614, 61.702530614791385, 58.68076016826015, 58.681783906875125, 57.93024993711903, 52.4013553896258, 54.90773424025505, 57.51565540990522, 55.06650394009006, 58.54905874498429, 56.733993714855565, 54.51593260611258, 53.766948176968484, 53.326073769600164, 53.241527080535896, 53.164993793733665, 55.78283071517945, 57.65407977565643, 57.90020850396926, 58.620351745236306, 55.766011591880556, 57.72000697351272, 58.156319664370635, 58.74905647770051, 54.06199278370027, 54.08439736212454, 52.246257028272076, 54.52675834778817, 55.047292170986054, 57.90660981209048, 53.86890626722767, 57.88851591848559, 52.34965070601433, 51.488133476626494, 53.44241519128123, 54.04022362924392, 57.26965219743791, 57.56309647713938, 57.575389185259425, 60.426014854062, 55.94464417426817, 55.37114266426333, 53.53853679472401, 53.46773016837336, 50.334387902290594, 50.13562963854883, 49.270880376139, 51.01034172119633, 50.11175809368011, 50.858247895394605, 50.80382500925372, 55.10781042037472, 54.85386440830847, 55.79418205445813, 54.67611435920962, 55.38525142977315, 54.157145561710486, 54.56238915843349, 58.37727069854737, 58.02949766958914, 56.89573657128119, 58.68313712458457, 61.92428573485344, 60.49139292009416, 55.168752285741995, 59.77813343847952, 61.55890126382152, 60.11557494440387, 57.49067383427774, 65.51665121509184, 61.47053810857958, 62.661008834838874, 63.57517996141988, 69.67182190187516, 63.02465961825464, 64.06057719261416, 56.99782017738589, 57.618319526795425, 8.45278028518923, 1.3291683096078135, 2.592004436639048, 1.9619793661179084, 0.21360009878633485, 14.69507355843821, 65.63118834649363, 61.98226228837044, 62.188186722417036, 60.59478659783641, 63.67242728510211, 74.61281591846098, 20.366895352640462, 33.77310552904683, 33.635320509633715, 43.58971157381612, 33.27582743860061, 35.09919612638412, 65.30799288903513, 35.129484668854744, 0.47281763846835784, 0.0458781597685189, 0.10680503662555449, 0.05484729502049666, 0.06261462984125941, 0.12449190771627812, 0.06792389877861546, 0.07897546019164786, 0.01119825384399343, 0.16283911292351064, 0.1648779486816737, 0.3347451828660504, 0.18939855388335644, 0.1059409047687246, 0.24500401930943613, 0.22165638665037773, 0.19524746664589454, 0.30719411769701593, 0.18955572448190183, 0.34926530694769276, 0.23298960028877183, 0.4294510558247567, 23.43422216753806, 82.95605028829267, 62.27557712985624, 50.38075031772737, 31.81921409022424, 90.7792725101594, 18.319120022558398, 12.703298887898846, 68.56128123498732, 62.77370637462985, 61.41757042177262, 75.62398725940336, 70.68766870806294, 80.61532881952103, 29.5977307135059, 0.6428051331350881, 1.8183796780724681, 5.016898743567928, 12.26342272373938, 3.5483834531999405, 64.95042177938646, 72.0120648414858, 76.1965670124177, 69.8893016384494, 75.39255957449637, 65.98798674921836, 71.93667688677388, 66.14321847115794, 72.16892042467671, 66.8427025887274, 72.8733310391826, 65.25504481407904, 65.90891176654448, 61.4952019722231, 58.22562402294528, 51.918186064689394, 61.9276354389806, 49.78356161425191, 61.06217230519941, 67.71666157630183, 69.39560074960032, 63.810549628350046, 67.18725927414434, 63.333703164131414, 60.309634208679206, 60.64204723604264, 62.12766062828803, 59.70487925314135, 60.17745425624233, 57.385220912195024, 55.37231937531502, 51.74082040786744, 54.908334362891416, 58.182670147188254, 58.15646479206701, 60.86142539978028, 63.98660129116428, 63.09871396710796, 62.400575222507605, 61.8011115443322, 61.375063696215236, 56.828605205782004, 58.83165767115932, 60.33030509948731, 57.483986193133944, 63.42246247876076, 60.910607999370946, 57.97777729649698, 55.484503084613436, 55.75935925206831, 56.20404620324412, 56.20113972694644, 59.307676515271595, 63.14339760811099, 61.38140616878387, 62.69032462950676, 58.17705723547167, 61.463670038407855, 59.670448687768754, 63.22692055856029, 57.228408475076, 57.86680559958182, 54.24623043306413, 55.79082450559063, 57.076808867915986, 64.1288068217616, 56.49696096297234, 63.56337362720121, 56.44065141677857, 54.32962786766791, 58.37795319095735, 58.048046558134025, 64.36399213729366, 61.64804497072774, 60.40814453555692, 64.05491329008534, 58.81566616796679, 56.75226019274805, 55.25966890396611, 56.11484758315548, 53.36405800234888, 52.379448952213416, 52.999960068733465, 52.23897318686209, 54.64543357972176, 52.54849133952972, 54.98661310442033, 58.40658257084509, 58.087093753199426, 58.21589654491794, 58.07913918648997, 58.3212867090779, 58.2946930393096, 58.8640917501142, 63.145543144595244, 63.26711700808618, 62.39983781691521, 64.26689778604816, 64.55349360742878, 63.184959042456846, 54.50912729386361, 59.80565278760849, 63.513700731339, 62.9254432647459, 60.07263675812752, 69.95198111380301, 63.16271528120964, 66.67519384814848, 66.30598114382836, 70.74753192163283, 64.23381651601484, 65.44540920565206, 58.20532575730355, 64.45805841876616, 12.207563269522883, 1.3123969901953976, 3.716735748514053, 4.184089341471273, 0.4609210897357234, 16.50810483963259, 74.07472164400163, 67.16854172368204, 67.44593174226823, 66.03370589594688, 68.3578122046686, 78.38186848548152, 24.678164605171453, 41.47926853549096, 42.03132644776375, 53.12177319680491, 43.45446040553432, 48.718492984771736, 73.56621773012223, 57.17688814286263, 1.1372252866145105, 0.20906642109395998, 0.2094027336927191, 0.17100565616161595, 0.1791108357569864, 0.2768750542834882, 0.211832013822371, 0.18673678139044395, 0.1554119364628869], [0.08169610654154132, 0.1346751467715348, 0.024694664208518884, 0.06734370975004089, 0.03689287921353694, 0.04949298394363254, 0.11167390842831905, 0.019037057007212314, 0.038539979742058826, 0.039415599087313305, 0.0245309607951992, 0.1045950108598317, 0.1830015052109957, 1.3221553568878484, 30.32877814385199, 48.40884931625859, 53.2863127031634, 24.415091237714215, 40.2206858511894, 31.536730873969297, 1.979279102336976, 42.837581403793834, 55.935199106893236, 67.70932674407959, 55.79472726391208, 65.23719410742483, 60.610060307287405, 47.388460405411266, 0.28782922293870683, 0.37596966109929547, 0.25470799375926295, 14.116126818041648, 19.98973788753633, 24.176446391690163, 69.59715566327496, 63.30903537811772, 69.95636632365566, 62.06290229674309, 63.89713202753375, 62.830961212035156, 66.37570519601145, 62.61323044376989, 65.54494327114475, 61.0582499350271, 64.00553457198605, 60.35172124062816, 60.87817392041607, 53.37346776839226, 58.58212432553692, 65.50669231722432, 55.67882907006049, 59.8692108738807, 60.42503033914874, 65.9437894821167, 61.77932670039516, 61.64224770761306, 57.08389266844719, 58.78829979127454, 57.04476310360817, 59.37664355001142, 56.1397664008602, 56.91927079231509, 52.90469354198825, 53.00582793451125, 49.5750758724828, 48.849154979951926, 48.47177590093305, 51.82881486031317, 53.55757597954043, 56.87383797860915, 56.42969623688729, 56.77225643588651, 51.457091839082786, 47.72385443410566, 51.157991501592825, 52.95085591654624, 49.58311673133604, 52.39916278469948, 51.553260510967625, 53.1863824782833, 50.28429139044977, 49.80058077842959, 47.75440185300766, 50.75674087770524, 50.352038568066014, 53.10971583089521, 52.8947267993804, 55.10538639560823, 52.73803987810689, 55.18591265524588, 54.24590095396965, 53.90626292074881, 53.99857198038409, 51.50509380525159, 50.01223971766811, 47.635848214549405, 47.50939492256411, 50.31373662333335, 52.26687692826795, 50.33364265195785, 52.39817826978622, 52.606495349637925, 51.17393985871346, 48.353092824259114, 47.4370664165866, 50.885700564230646, 53.90383497361214, 54.42733803103047, 54.423694149140395, 52.54613399505616, 51.4806378272272, 51.748759285096206, 48.6367743246017, 46.2949114461099, 45.74121398310508, 46.94947265809583, 47.87279467428885, 48.24872247634396, 49.80129857217112, 52.77918554121449, 54.10828459647394, 54.480513603456565, 54.53145342488443, 53.551060922684215, 53.62407976581205, 52.52046208227835, 50.70820154682283, 52.0403169047448, 53.49309613627773, 57.05715779335269, 59.257423108623875, 61.85950386908747, 57.04591628043883, 48.13921382350307, 54.46835033355221, 62.80622674572853, 61.923795438581905, 58.11578981338009, 60.55071484658026, 64.26278714210757, 61.93832389770016, 62.938681264077466, 63.640950264469275, 65.02669226738715, 67.33787828876127, 66.10985479047223, 24.7500910682063, 2.8756400942802434, 5.254818441406374, 1.853948711387573, 0.2758416323171508, 0.4318495851851279, 45.86252504779447, 50.92819160030734, 59.984434420062655, 57.312213836177705, 55.56901839471633, 61.78097017349736, 61.68043198124055, 16.709049824745424, 39.008634244242025, 23.849316796948834, 35.02784821294969, 29.721989439379787, 37.66258662746799, 48.05376498929916, 10.215504227146026, 0.2912038402451623, 0.19706094998025125, 0.06349517896230664, 0.11977428465240425, 0.040756750911954916, 0.13204579511957784, 0.06249536144276781, 0.06130680667176362, 0.06662192469042155, 0.04116743915684281, 0.05641421295642372, 0.021586695295428077, 0.07838789373636246, 0.08941044339970236, 0.03209837922646153, 0.06075271442832966, 0.09583762997100431, 0.01991836455530457, 0.03416611948200772, 0.03172975495427607, 0.1252335344531363, 0.06825423589156521, 0.980773768838375, 37.456928914593114, 55.40801686625327, 46.27378948273198, 39.214350792669485, 45.664574792308194, 35.06762104649698, 4.759447603456436, 41.30365617813603, 65.86691887147965, 72.62894384322628, 62.65454476879489, 70.59317881061186, 69.42357509366929, 55.20410853047525, 0.1518487389529905, 0.40935886783465264, 0.43372585708575867, 21.435552950828306, 25.6300179419979, 28.076327654623217, 75.62736834249189, 66.61086697732249, 72.82571346529069, 64.42200399214222, 68.89532596834245, 64.29343654263404, 69.39545954427412, 63.83322092794604, 68.40381376204952, 64.05448182936638, 66.35319079122236, 63.820904685604965, 61.659615962736076, 55.01684673370854, 59.10959682156963, 64.66865831805815, 55.59682799923805, 61.34920350966915, 62.26416695502497, 66.16172421363093, 62.466239621562345, 62.16588804798742, 56.840497832144464, 60.4809594154358, 59.11667669973066, 60.62148224922919, 56.62004493897962, 57.88094182168284, 52.66415811354115, 54.66774794363207, 51.341303471596014, 49.97793466814103, 51.15502618974256, 54.790827997269176, 57.101645315847094, 59.81669425964356, 61.06594170293501, 61.16305566603138, 55.40909551805066, 50.68593425135459, 53.71641235966837, 56.70524274149249, 52.94809456794493, 56.99664346633419, 54.377649445687574, 54.57262654458323, 54.33817078990322, 53.07536763529624, 50.43178427603937, 54.41135437257829, 54.3408929148028, 56.19427557914488, 57.71290748350082, 59.17757149665587, 57.41416015932637, 58.554295109164336, 59.210338977075395, 59.338875047622196, 58.23404927407542, 53.74753636698569, 53.52367101177093, 51.201655326351045, 51.44711725173458, 54.21090948966242, 54.40120327857233, 52.32309233757758, 55.890503698779696, 55.90551460942915, 52.25327022614018, 52.069777827109064, 50.164698323895855, 55.22224949252222, 57.10559122024044, 57.10029209813764, 56.79695167849141, 55.25082003685736, 55.19138436163626, 54.2762718662139, 50.69333184149958, 47.518483054253366, 48.273896248109885, 49.51390258727535, 49.3707243088753, 50.4323608644547, 50.80093422243672, 56.50909285391531, 57.38734683682842, 55.53796891243228, 57.52433561509656, 56.57880513898788, 55.65368275488577, 56.43903540026758, 53.17594897362494, 56.387499378573516, 55.843635297590694, 59.594315482724106, 62.043157085295654, 63.80953765684559, 57.46869287183208, 48.89053598526986, 55.060769434898134, 62.86795308513027, 59.89040343992172, 60.36193509255687, 62.9204696993674, 66.99510235940257, 62.45664942649103, 67.32608764402329, 64.69148259009084, 67.20775758066486, 66.56142157893028, 66.15008261895949, 27.289560994794293, 5.178183663275934, 7.8620409388696, 3.400453958780535, 0.33754894209484904, 1.0241485639445245, 53.03828554768717, 58.60137139597247, 65.45436397675546, 63.8089414565794, 61.34195104722054, 68.62268986240511, 63.05329292051254, 21.52997028443121, 47.712969856877486, 25.68574501622108, 45.487715121238466, 30.153089300278697, 41.019092144504675, 57.67834355754238, 8.972742422934502, 0.5515276568551217, 0.1182987150405684, 0.019462615018710494, 0.07665588385275296, 0.024516880099150925, 0.06733234100524457, 0.10242175731447437, 0.040396268239184734, 0.06974103635237103, 0.1836153101776877, 0.203748683054601, 0.10663697991760508, 0.19073507087605615, 0.15893649249788255, 0.12426212730426943, 0.14132491252835722, 0.14193571443038602, 0.13141027922111173, 0.17946322088039693, 0.07277895801610525, 0.19842720650617154, 0.4540409766618283, 4.310823573220161, 62.52432992381435, 64.9292919712682, 82.31876711691581, 33.68050621401879, 62.87068697714037, 39.72611811853225, 4.990676228077182, 53.51905438207812, 72.33760587630734, 77.43823251416607, 68.0168091866278, 74.71981033202141, 74.21616231241535, 57.19706481502902, 0.3245872859993289, 1.653446218659801, 1.1282125379770034, 23.443412280851796, 28.60660856769931, 35.00729499324676, 75.45723945863786, 69.92330074310303, 74.71183223109092, 67.36405618729131, 71.46104243493849, 67.41123445572393, 72.92465917525753, 66.78750699566257, 70.25871830601847, 68.64325092684838, 67.16586666722452, 65.14580680478004, 62.550048905034224, 57.16936111450196, 61.807218674690496, 64.23942550536125, 54.70205691552932, 62.06376129581083, 65.61879365674912, 68.55020446162071, 65.18897641089656, 64.67110587704566, 60.82635941043977, 62.56684449411208, 60.37508679974464, 63.34561932471491, 60.22793908273021, 62.435178372167776, 58.70929148889358, 60.018559040561804, 52.87057284385928, 55.04367574568718, 54.1354234756962, 55.898921105169485, 60.34366861466439, 61.791886129686915, 63.78758807336131, 65.68414818856024, 58.920628793777965, 53.09890577870031, 56.72249724788051, 58.89410572667276, 55.09632179814001, 58.68388237491731, 55.643033519867934, 57.30453775775049, 55.80498033954252, 56.916638881929465, 54.1095240654484, 60.21619158406412, 58.31384597286102, 61.80065262702204, 61.178760836201334, 63.71563611492034, 61.098265955525065, 61.77987190984911, 62.392036222642474, 64.07887504946801, 61.85420474698467, 59.76962973994594, 57.127438822100245, 55.21518530384187, 53.55103346609301, 58.124069936813854, 58.48066829865979, 55.92460478505781, 59.0550954880253, 59.89111731129309, 57.61719380655597, 57.60868226328204, 52.39140825886881, 58.703804093022505, 58.83987895904049, 61.38329675120693, 61.15522269279727, 57.44193446251654, 56.52472742142216, 57.79607742063461, 53.57213973999024, 50.1200617513349, 48.88046333866735, 49.520813803518976, 51.30461754337434, 53.48151729952905, 52.83471453574396, 59.11742587243358, 59.82357801929597, 59.40032682111187, 61.506278745589725, 59.28950025189308, 57.9673320247281, 57.02749290773946, 55.90903689784389, 56.83843466543383, 57.93802015243038, 60.87440844505065, 65.25239329184255, 66.73615532536661, 60.31784765182003, 48.110447160659305, 57.18867486523044, 65.74504298548545, 63.73744057070825, 61.791101655652454, 65.6597000552762, 69.75373668055381, 65.60939958018642, 69.06207376910795, 65.18515602234872, 69.73111244939989, 71.09385367362731, 67.01321586485832, 33.92888638281053, 5.802721583074139, 8.561742747983626, 5.796471776500826, 0.46593510455662207, 0.9763959747168326, 57.88138112714214, 64.34540010267689, 68.58564699849775, 69.48002584518926, 67.52734445756482, 72.96005464369252, 71.21806729224421, 25.232558288881858, 47.113765055133456, 33.97231486535842, 52.68098508158038, 45.06293027631698, 54.55343438733009, 67.3525244189847, 23.356633763159476, 1.0119029242665538, 0.37574844555028025, 0.15202397390479042, 0.3369606172125186, 0.17771077943184685, 0.27482586101658885, 0.2038210783634455, 0.25528922466741455, 0.23870060190318093], [0.0894614571945802, 0.038922020129018256, 0.05640519993199457, 0.0653293198575416, 0.0292646085032292, 0.04098365466380793, 0.060102577741828665, 0.04111921392200936, 0.09463435099009546, 0.014431321084679616, 0.1006735599930248, 0.142959468367119, 0.02884761343950466, 0.20946187568047356, 17.438253741110525, 42.01866111447735, 39.04536331853559, 24.018500389591342, 35.5668132535873, 60.58856179637294, 4.43591139008922, 18.102513013347505, 58.90283300030617, 62.351141591225904, 66.49996588307043, 63.41900294826877, 52.905525084464784, 59.30440525854788, 5.13330243287548, 0.501119684307806, 0.26651524728344334, 15.428093940980974, 19.635265450323782, 3.8274767610334584, 52.66125555961363, 68.42655566430861, 73.35939899567636, 63.39042848156345, 66.68484287877237, 62.78280235105946, 68.72436554201188, 63.11274428521434, 66.9447861948321, 65.42491874387188, 64.03774507584112, 57.82203174406483, 56.86225129712013, 57.4959925682314, 55.17059187735281, 54.7229866827688, 61.421633997271144, 57.74906389174923, 67.72492208788472, 63.93617137785881, 62.81047075025497, 58.935820133455344, 61.68176558709914, 61.94238355082851, 61.40362639581004, 60.044442761328916, 60.9864587937632, 59.520135618025265, 55.23700152674029, 52.03523351300148, 50.525250434875495, 49.529446940268244, 45.27256919491676, 51.91054528759372, 50.43595767790272, 53.28780320382888, 52.216270508304724, 52.357773934641195, 47.5266258947311, 49.56285376702586, 52.09640679820892, 49.61444470190233, 52.504929496395974, 52.35378096180578, 49.194649111840036, 50.603788052835775, 47.19318128401234, 46.7452387655935, 49.00976819376792, 52.31031717792634, 49.499440808450025, 53.00231741320703, 54.42545529334776, 55.005373800954516, 53.682334807611284, 53.566534673014, 55.929284172673384, 54.02764851047147, 52.45119694740542, 49.294077273338075, 47.09474155979772, 47.43468946026218, 46.62726956029093, 45.10979083276565, 47.70032413544194, 50.194131789668916, 49.17797119386735, 51.8864187886638, 48.144983630026545, 47.69591539136825, 45.5323124700977, 47.82891511917115, 49.27471253179735, 52.84685819379745, 54.067809658665816, 53.35449918623894, 50.80190697023946, 47.409409784501605, 45.61863207047986, 45.09294033050538, 47.88096497135778, 48.31166867286929, 48.442322823309134, 50.515883814904, 54.70196277864518, 54.66810487931775, 55.70297910321144, 58.13423279793032, 52.92272075530022, 55.9419338164791, 56.757543625370154, 54.852091496990575, 53.79899001890614, 54.537474263098936, 53.88552534964777, 57.55300814105619, 57.32762482858474, 61.438963028692434, 53.385976206871774, 52.029577455212994, 53.422450327104144, 57.89217156748618, 60.61702251434327, 58.40124814741073, 58.014875073586744, 65.3736415986092, 58.182689759039114, 67.19045992820494, 58.13893179739676, 69.06860843781503, 55.76848268508912, 34.24743775398501, 3.0459545552730565, 13.103411043843916, 6.307409030775871, 0.8811713683028376, 0.907011513988818, 12.712501748915642, 60.06007732883577, 54.14788092336347, 55.98209888704362, 57.74205069388113, 62.692689818720666, 70.65173979728453, 22.069072608024847, 15.890240342386308, 42.101764371318204, 31.150075389492898, 39.83605038735175, 28.916797445666408, 49.21150353647048, 47.0553570408975, 2.4444453610527903, 0.16631525220169177, 0.23238865027744926, 0.08830831100743625, 0.16027118620132247, 0.07084526016467041, 0.041657896306846416, 0.02887202674643167, 0.12369493112689066, 0.07121183323643862, 0.06978967527468359, 0.022063364778014443, 0.020217688513859626, 0.06241090407955551, 0.03509348806654734, 0.05964739894073817, 0.12482116464525463, 0.12371451233423526, 0.11141805804424709, 0.04110591463564385, 0.10001895318348562, 0.11705091102950035, 0.08252982470777728, 0.38536085717139706, 24.61622057422515, 55.96665651567521, 36.8548882392145, 30.195878436488492, 45.29719383485856, 58.93303917300317, 10.798126228394048, 17.694894421485163, 60.20633859019126, 69.06744741624402, 72.14464879805043, 68.90291967699605, 58.18507063773371, 68.97833901066934, 6.173634634863946, 0.5992515637509285, 0.0945626068559866, 18.44148620482414, 32.75780589349809, 7.34526425600052, 57.57436152427428, 67.93319994403471, 77.41199185771328, 65.57173698179184, 71.36329697024438, 65.17690727787634, 71.4670358165618, 65.56606523452267, 71.74143698907667, 66.6558094947569, 66.34039601972027, 58.85812974745228, 58.592522528863725, 58.15383288168139, 55.7351033149227, 56.52731226336572, 59.60503924277521, 57.830441305714274, 68.27350478018484, 65.03337598616078, 64.66654416053527, 59.4193071703757, 63.28685437479327, 65.90715454470727, 61.42052004414221, 62.44531769906322, 63.54633877354284, 59.50527767981253, 54.77202415466309, 53.38024170167985, 53.39460934362104, 49.22248225058279, 48.05516919782085, 52.91175380829842, 54.60424869291244, 55.34671806520032, 55.80593739786456, 55.85767346043741, 50.30085948205764, 52.58304349837765, 53.913860551772586, 53.186676656046224, 52.57135875763432, 52.84002542495728, 52.12121578954881, 52.76474729661019, 50.5683925844008, 51.45913931631273, 50.35469793504285, 53.7330275197183, 53.047663934769176, 57.8739482356656, 57.364020501413655, 56.84269435944096, 59.265142333122995, 57.3231533265883, 58.81864716929775, 57.0206444494186, 55.1551926520563, 56.330342600422526, 53.86660383593652, 52.36280633557228, 50.646769385184015, 50.40652813449983, 52.24939100203976, 55.186030326351045, 51.66489508844192, 53.94156032992948, 51.556610215094786, 50.46573631225094, 50.459574268710234, 50.99390699017433, 52.330635055418945, 55.60884614144602, 57.20304250717164, 54.86936953759963, 52.901069271949034, 49.09230662930397, 47.154067408654, 47.49035573774769, 49.74968018070344, 49.495071288078066, 50.159850274362874, 52.625797333255896, 56.29173863318659, 57.21209141515917, 56.84398481922766, 60.87345923146894, 55.53030852348574, 58.139669202989154, 58.29383404024186, 58.62221487106816, 57.393685387026885, 56.73025177371118, 56.238206125074825, 60.745429146674375, 60.231457448774776, 62.085263729095466, 53.092382877103745, 52.727688743222146, 54.75908425546462, 58.420530519177845, 60.64535379409791, 61.72687676645095, 59.682890445955344, 66.43810226071265, 58.269009359421275, 68.98766640693911, 59.95718963684575, 67.51542045224097, 57.114640128227975, 40.95276094252064, 5.932871218650572, 16.87290487750884, 6.790918621324725, 1.930225695813856, 0.8834981918334962, 17.997699437602876, 65.04588442464029, 60.68828413563391, 61.540117033066295, 65.35130370047786, 70.88432850376253, 73.39390016371205, 24.15198060774034, 28.817492838828798, 44.64066359304613, 32.47010788609905, 49.02522233224685, 32.441294154813214, 56.857556220023866, 53.77766801464943, 4.4056708966532065, 0.23853989197842537, 0.24192552562923203, 0.06619784905905686, 0.13104071840643883, 0.04287353228597392, 0.060666315032229315, 0.02588122523570013, 0.15100149167401178, 0.08551045065565456, 0.3398248054567845, 0.2171716313328474, 0.15700679362541245, 0.13333760322101657, 0.169180145246848, 0.1534167523946493, 0.269598996326808, 0.3377188297529375, 0.2195685059433022, 0.21055460817390875, 0.16905233113756105, 0.24356611824083715, 0.17669788862188018, 0.6386708323993991, 41.98515622846542, 64.82814973400485, 57.16167719133439, 34.74814791833201, 52.75367444561374, 76.7626513204267, 9.919466280168104, 24.757125839110344, 74.98190310693558, 72.72364554866668, 77.33735699807444, 72.91089950069305, 62.781939429621545, 74.58469252432548, 6.639457768009556, 0.732662650125642, 0.3258636804117311, 24.544529453400646, 41.17620268175679, 11.571585266820847, 60.92010013518795, 68.03977074161654, 82.83304475968885, 67.97491042844712, 74.22296370229414, 66.3767328569966, 75.68669811371835, 66.26414514357045, 74.63751900580623, 70.77719288487589, 67.52286511082804, 58.86353085117956, 62.12158095452094, 59.30715484003867, 54.814774067171165, 53.840308266301314, 59.355333312865234, 60.47919434885825, 71.34978048263058, 69.4497843711607, 66.73453146411528, 63.682452863262554, 67.14254425417992, 68.11458603028329, 64.27137321041477, 62.850945688063106, 67.47693415611022, 64.26104560975106, 58.95669498751241, 56.08279005173714, 57.1823049360706, 53.702009416395626, 49.69573974609376, 54.86430575770717, 55.55383097740912, 58.142716884613044, 58.22583583093459, 58.271684415878795, 53.308175994503884, 54.9687074845837, 57.364840276779674, 55.899489848844475, 56.11906805346089, 57.1290313043902, 55.27654686281758, 56.56770483140023, 51.73767858935941, 53.129998407056256, 54.77249876145394, 58.998272111338956, 57.02415889309299, 61.831251036736276, 58.735285036025516, 61.78255481104698, 61.610609869803156, 60.257741251299464, 64.55780036987798, 63.027538637961115, 57.91115583912019, 60.07488035386609, 55.84900502235659, 55.73801763596074, 52.70558618730115, 52.25030099191974, 53.036559704811346, 56.61560873831473, 54.43659482463714, 57.81884285711474, 53.2852928869186, 55.00573465901037, 52.396244541291274, 54.44727543861636, 53.93264086015763, 58.349131614931174, 59.34683353670182, 57.86132212608092, 56.58934847001107, 51.446450448805294, 47.884534328214585, 50.28823729484312, 51.35334122565485, 51.670480543567294, 51.99448400928129, 54.59474086761475, 58.02115086586245, 61.8020607579139, 58.15288759046986, 62.819041129081484, 57.40255778835666, 62.85314613772977, 60.9222888177441, 61.96586285867999, 58.967050044767326, 60.70560532231485, 57.37406569142496, 63.70983100706532, 63.57594090123331, 65.3291658432253, 54.959199659286014, 54.12104798901466, 54.34559583663941, 59.63581808151738, 59.29935716813611, 67.82834714458835, 61.907858848571784, 69.56150916314894, 59.486371855581964, 70.80063296902564, 59.736050328900745, 71.99048396079772, 58.85786302628056, 49.60006137048045, 8.07971679395245, 17.11303237945803, 9.475556938878952, 5.013278395898881, 1.2286154084628629, 17.638378950857348, 72.12364842814785, 65.69270287790607, 66.0968089872791, 70.30759888310587, 70.50181896455827, 83.94326379222255, 31.053620384585475, 25.483178131041992, 50.37948339216171, 47.144857683489406, 56.3234313841789, 46.759116111263154, 63.91540635016657, 67.45655352069487, 10.03276296200291, 0.7961235351620183, 0.4806136249774887, 0.37471603482000293, 0.4633503545436167, 0.21537680990032612, 0.1472765730032998, 0.18291106087065515, 0.1948639936745167, 0.24430453506929262], [0.05992073911212145, 0.0304677170295749, 0.06817328338060649, 0.0822502179371734, 0.1221939503786064, 0.057209021516985474, 0.09592472650711575, 0.007756101577768043, 0.02118966448301029, 0.039470872331050136, 0.07593447417621652, 0.03598465133578547, 0.17823047815792023, 0.1471349693113758, 7.554246667892703, 37.44706415360974, 38.54304106004777, 48.22836145277947, 29.923779695264756, 64.54850827493976, 24.584498405456547, 3.2860693095191835, 56.631713990242254, 56.73601373549431, 65.42578951005014, 64.65305512951267, 61.81279236270536, 55.285807578794426, 21.67853201589277, 0.18607848203710972, 0.251168315148642, 0.8353194738588026, 23.17929752411381, 8.386926631773672, 25.71290154610911, 52.55147626323085, 72.82957307754025, 67.69938745806294, 69.16455745697021, 66.67022028276998, 68.25827029443556, 65.24931423125729, 61.98963242192423, 60.27530562493109, 60.03216966505974, 57.2765673360517, 59.01279272571687, 58.210303245052216, 55.130191464577955, 50.058100069722826, 60.64929185375091, 59.180509351914935, 66.54890921808058, 61.64148284542946, 64.01315181486069, 60.42152374021469, 63.03904687204669, 60.13652040112404, 62.23357246768091, 65.11617722049837, 60.34860687871134, 59.315917415003625, 56.505131260041274, 52.912585350774954, 52.01191894469723, 49.48763055186118, 46.452543658594934, 47.699155269130586, 47.637864312817975, 49.36129493098105, 48.51647523141677, 45.52786057995212, 44.48102704940304, 49.193295894130586, 50.674935925391416, 52.72988527051864, 50.09884957344302, 51.03473494129797, 48.739120729507945, 45.50022748208816, 46.78379566438737, 46.91679539219026, 47.641943577797186, 52.36817998270835, 53.06542834927959, 52.92424655729725, 49.80782147376768, 53.87775905670659, 51.05040873250654, 52.47277390572333, 55.372672388630534, 54.39257798656341, 54.36071657365369, 51.87768367029006, 50.92610882174585, 48.551784407707956, 46.64461428119291, 46.82054042816163, 46.07849859422254, 49.740972518920906, 48.79677564867082, 50.397742025313846, 50.19358658021497, 47.713648426917295, 43.749846258471095, 43.38981974509455, 48.35929016913138, 47.51363108235021, 51.32353513471542, 52.91826102041429, 46.8782659499876, 45.20229601090954, 46.58042469332295, 45.332295125530614, 45.84337211424305, 45.40321550061626, 53.74008386365829, 54.49888990771387, 55.229654927407545, 58.89365073173278, 56.87457146183137, 56.005087898623565, 56.71497806426018, 57.70416059801656, 58.07134151458741, 55.938089893710234, 55.21587956336237, 55.862799998252626, 57.38535427278089, 58.74047040939332, 59.04494831638952, 56.81351192535893, 54.429044262055434, 49.9566440428457, 54.128994710983775, 54.0604865935541, 60.75301108821746, 60.018468826047844, 54.63849490688693, 60.3219190720589, 62.75674996837493, 57.23040888386389, 61.48223461643342, 48.72454520194761, 33.3177811099637, 6.376693777499661, 13.43891784068077, 11.667674510709702, 1.1511581583369164, 1.364408844420987, 1.6540943903307763, 47.6906947166689, 54.04095319009597, 56.29770848058886, 59.66447884036649, 61.012742596287886, 52.423097087490945, 42.070134378248646, 5.370380782311963, 44.90239158753426, 36.511657314915816, 33.047188558886134, 30.168617963790897, 26.7521394068195, 54.30322639403805, 27.26263784593152, 0.44413144550015854, 0.08701423528574168, 0.048999336037424304, 0.022730613953524062, 0.04613261204212905, 0.04889299154221531, 0.1067161780872172, 0.17335848071642462, 0.08785759083806507, 0.045850507824892, 0.041321790551826845, 0.002088708560838695, 0.040017901243822235, 0.020173715067005927, 0.06422627199020597, 0.05533323225174701, 0.07795961994317271, 0.020089177264561577, 0.03384262353422181, 0.04027382440624699, 0.05358601552284053, 0.03689873595571807, 0.054290720652188026, 0.2663251655476709, 8.190230554149997, 55.831158238072554, 42.47270291851413, 42.004685709553385, 43.01179739736742, 60.648907461474025, 30.879425964047833, 6.282328415301539, 55.90099603899064, 67.70630651904692, 70.71778466624599, 70.9838233455535, 65.50786902827602, 63.24956047919489, 26.190634465986683, 0.323190309347645, 0.2805126542525907, 0.7464770540114373, 23.82390964415766, 11.383319343290022, 30.476894686298987, 55.83519827935004, 73.51725870563139, 72.12185198260893, 72.51604234018635, 70.42751358401391, 72.47754035457488, 68.57562142033731, 63.7989668692312, 60.819793362771314, 61.11018603847873, 59.18527895404447, 57.66943977725122, 58.76721705159834, 53.932817366815385, 52.37876645980343, 62.02510633776265, 57.85363035817301, 67.43523936117849, 62.227284908294685, 65.88974706588253, 62.47959136962891, 63.53966682187973, 61.80426120758057, 66.28945227592223, 64.54346802926833, 63.304285387839045, 60.24475428365893, 58.14115970365463, 53.557069993788204, 53.863093314632295, 50.37874990893949, 49.028368073125044, 49.5247636302825, 50.428842498410134, 51.45693102190572, 52.773243150403424, 48.61465607920001, 49.529603835075136, 51.787327951000584, 51.31209358092278, 55.9461699762652, 52.731305168521025, 53.54729152494862, 51.49156555052727, 51.295709840713016, 47.396379670789166, 50.204486846923835, 51.06930671199676, 56.12268447875977, 56.0606796510758, 56.35466914023123, 53.970966339111335, 59.051043679637296, 53.20506080504387, 57.28222339384018, 58.63100098025415, 58.510584215964045, 57.61954330628919, 56.579668060425796, 53.69547474768854, 52.23375643453291, 48.40674300347605, 50.72777025161251, 50.655206403424664, 51.0637604805731, 51.63917610722204, 53.02915034755584, 51.77728276098929, 49.26201581954957, 47.358709227654245, 46.20852516543481, 50.00144143258372, 51.77121093196254, 52.90923956901797, 55.65887989536409, 50.197748214967795, 48.802094382624475, 47.53800076823081, 46.75864542684248, 48.35186512239518, 47.306329896373136, 54.164849096728915, 55.67916639389531, 58.37415633663055, 60.50152832461942, 59.23774849983954, 57.75919145153415, 59.87130934192289, 60.56722018026537, 59.591581590714, 57.326314756947184, 58.84848463919855, 57.435564533356704, 59.02741139934909, 61.48551371789748, 59.88821867973574, 59.25245346561555, 55.92768776801325, 49.569345289661044, 55.232020116621456, 56.21788824758222, 60.76951642190257, 62.19644723399993, 57.30696570488715, 58.031274503277196, 62.68943425147765, 58.56717617281022, 62.5326257367288, 50.066909713129846, 39.54064492256411, 8.408933089625451, 18.411072146508005, 10.265496796177281, 1.2397076261620368, 1.3336974214161597, 2.2017781244170282, 56.92654286661456, 57.83014712795135, 62.80838012695313, 63.79458558174872, 72.0395528116534, 56.341219332910356, 47.39397525787354, 8.869976324419822, 50.67664215641637, 35.413323064004224, 37.93631707468341, 40.977232610025716, 28.839942524510047, 60.159332906046224, 30.25680265118999, 0.2755599264656344, 0.05276236758236924, 0.07270839365739977, 0.04924166880007233, 0.061976922931329864, 0.09926615688469141, 0.08770598969872921, 0.08665277968130766, 0.06545260638719605, 0.09810908832737515, 0.1823593549911053, 0.12910864466140348, 0.1608925141514309, 0.1511122986313797, 0.1728474234621371, 0.15906757014172693, 0.18798931982488404, 0.11245863527179727, 0.14744117465471068, 0.18476505493444784, 0.13447228668918534, 0.1878835384042994, 0.3778859227895737, 0.39949012319407157, 21.021515400178973, 70.90326570695447, 56.38633443463234, 71.5531083076231, 44.133493285025324, 87.22479712578559, 32.62150156882502, 7.2442921515434024, 68.69377105466782, 75.99276065826416, 75.27310771326866, 78.50881207373835, 68.29760382252356, 73.12129543673608, 29.7620133046181, 0.6067136891426579, 0.33165374229992595, 1.717886838220781, 29.61518918314288, 18.980827792998284, 39.42153822991156, 58.078193895278446, 74.12829337581512, 72.984467475645, 76.02788940552743, 73.00582870360344, 72.55245762486612, 69.32205630886939, 64.25045128791564, 63.13387801570278, 65.13864063447522, 60.65364176227201, 58.63061658797726, 59.27089252779561, 55.661825595363496, 53.95029152593305, 60.44881559187367, 59.50702313453921, 69.95442082805019, 66.27610837259601, 69.02178318269792, 65.51554902907341, 67.38297770100256, 64.36671033982309, 68.21808953439036, 68.07668024493803, 65.53985987940143, 62.742056769709436, 62.470318886541556, 56.55379218439902, 57.03172906752556, 52.801994123766505, 51.51643337741975, 51.07017355580484, 53.20763387987691, 53.8402964991908, 54.89165644491873, 51.30472344736899, 51.85185486270536, 55.28250886547951, 54.412640909994806, 57.82722496217298, 54.84257974932271, 57.540519314427534, 56.06330763909125, 51.44399896744759, 51.8433472418016, 53.918539939388154, 53.089256748076416, 59.47113344746252, 59.52914922468124, 60.785296117105794, 57.56332789697955, 61.92492508119153, 56.86332210417717, 57.877843149246715, 62.18211097102012, 62.05001338835686, 62.389165047676336, 61.21681959398332, 57.76973086018717, 55.300269357619754, 51.81119165112896, 53.454276438682314, 52.00039894350114, 54.7160009414919, 53.629861339446045, 55.95432066148328, 54.848914377151004, 53.3124670674724, 51.88590888054141, 48.50940319799608, 54.11632937769736, 54.0996906834264, 56.66876077651978, 58.57156138266287, 53.623730674866714, 48.58550502407936, 50.69915656120547, 50.03736249862179, 49.83379148667859, 49.25513205989715, 58.17998724599039, 57.80226299839636, 58.032537506472686, 62.32020978004702, 60.67642681060299, 60.78140120352469, 62.53342197787378, 62.34861558483493, 63.841053901180146, 59.56109692973476, 61.0326329354317, 59.85475693979571, 61.57879944770568, 65.07249770625945, 62.37857072584091, 61.95703752579228, 56.25976347154187, 50.5376608141007, 56.18432844838789, 58.93708313665083, 63.41304486797702, 61.34847002644693, 59.93756209650348, 60.036331299812566, 63.38585499794253, 58.44758702862648, 65.13876222795056, 55.961518210749475, 47.52089923427951, 13.94709913961349, 18.644102119630386, 17.673066431476226, 3.5403742184562073, 1.6549042371972915, 1.974481553319962, 61.671869447154386, 62.118337154388435, 69.26501720182358, 68.37816146112257, 73.41144100312265, 61.2029657825347, 53.99138619822841, 9.454892912218648, 57.933685933389974, 43.535288687675234, 51.46721155412736, 44.42809074155746, 40.852811105789684, 70.11307285678002, 50.480076497600926, 0.935640526154349, 0.28731824229321173, 0.20176814658747566, 0.1519968543922709, 0.16337335199838685, 0.20704318288593523, 0.3606797718713361, 0.4102381222671078, 0.21786855683932382, 0.1857581347106926], [0.13500370656050023, 0.04707252148598914, 0.03751093979864832, 0.04645637995112808, 0.07693927509770279, 0.10609714074000236, 0.036272723377952655, 0.024440405372109626, 0.07100938684156827, 0.05925918771554867, 0.04960824570228016, 0.09624132766358315, 0.019060767428468794, 0.21651091114167245, 0.6686992726979718, 33.74149122545796, 44.07320253310665, 36.84770637942899, 30.18732570832776, 40.767770198083696, 69.38845419114637, 5.586689201093489, 26.661071777343754, 62.73638894481044, 58.38775519401797, 66.38370683116298, 61.87083167414512, 60.99960265621063, 54.9382738144167, 4.708473951585831, 0.5292733542380795, 0.44883694139219105, 5.858799709427742, 14.922218995709574, 13.499751840868305, 35.672881987787065, 49.50677564067226, 72.32656832664244, 67.64520383650257, 67.95882086600027, 59.82084804965604, 56.179680439733694, 57.76352174820439, 59.807743410910334, 57.47634541603827, 61.90496413938461, 63.86041864272087, 59.57508802413941, 61.755051151398696, 52.74800662071475, 57.344016413534845, 60.83474151549801, 61.434860229492195, 63.929856361881384, 60.21722316741944, 64.37271156618672, 58.65086778517693, 59.631864332383685, 55.684379223854314, 58.277411076330374, 62.6817895520118, 59.92990955229729, 57.92769647413685, 52.19032010724468, 53.010797577519575, 49.76613844594648, 49.623611280995036, 45.061926149552875, 46.768278767985684, 41.334580144574566, 44.93523359298707, 43.67584682280018, 48.249530484599454, 46.99548598258726, 52.749975650541245, 51.784327337818766, 49.56155938486899, 49.29043731381817, 46.97818048538701, 45.7456031153279, 45.141887587885705, 46.4558776732414, 47.3178538199394, 51.82763814926148, 54.19382364519181, 51.278831881861535, 31.57217537203143, 40.94103697807559, 49.80536607003982, 51.54904396303239, 52.43764908083024, 50.40674386485931, 55.28884741567797, 53.116662348470385, 50.426449852605025, 48.07377299954815, 47.05737313916607, 45.04725648510841, 48.50289598588021, 46.53805917309177, 49.10711357670446, 47.96484485749276, 50.72378512351744, 45.165100174565474, 41.284377728739095, 39.373932423130164, 41.593248690328295, 43.8095643443446, 47.10093890466998, 45.97951758292414, 44.74686568783176, 43.96299177600492, 45.47357497676727, 46.082519023649155, 46.31543328685146, 49.37823172538511, 53.02057996872933, 56.643245758548865, 56.69051424149544, 54.49281023394678, 47.515360847596206, 51.83737347202917, 57.389923834031634, 56.98799856247441, 57.86593091103339, 55.50347166676676, 55.16870521729993, 54.92798935982489, 58.86852402840891, 58.275697000565074, 58.30175330561977, 56.03508618570144, 47.93078691728654, 50.19630086037421, 53.59263020177042, 53.92714954191639, 50.79406222989483, 62.12700559246925, 56.55984047920474, 52.14809971470987, 60.49658221583213, 55.86405515670777, 42.63939580609722, 28.072970105755715, 11.526427019026972, 17.31300069439796, 18.247448513584754, 1.010005416408662, 0.4511646535848418, 2.0151132633609157, 38.04306437892299, 53.607452838651604, 56.955521337447635, 57.893422803571156, 58.26609503838324, 34.802335462262555, 57.51981312228788, 29.716254934187862, 11.957812232355918, 56.416203283494525, 33.94841194152832, 41.08078318257486, 27.125437259674076, 31.432413478051465, 50.06419151060043, 12.857568648553665, 0.2995562517354566, 0.29703039856206986, 0.03295142962146671, 0.08372437794722858, 0.052422515657399936, 0.029241583730664947, 0.061831101925382694, 0.07950446688600125, 0.03437144253703375, 0.03679446372834425, 0.02425353737517951, 0.015321965329349043, 0.018557939873707872, 0.020042903638715227, 0.037494204607942415, 0.047058781699067166, 0.05814538780419577, 0.027406125164200223, 0.06270572152589599, 0.03822083517368283, 0.03142819976464155, 0.017932362050839493, 0.3126020855720966, 0.28997141927961384, 2.1008077359968618, 45.09263438563193, 53.65580781813591, 31.905051239075203, 41.3403421063577, 46.73328730367845, 75.28624765334591, 10.483435450061675, 27.55058884620667, 72.17699266249134, 63.383513342949655, 72.15602367155014, 68.74071398089009, 64.86481605037567, 61.94489386773879, 6.397321031939599, 0.5536463496185119, 0.5068684387351237, 5.153467337931357, 12.447807461984697, 22.104413163277414, 42.606310613693736, 54.72332792897379, 73.95781932338592, 69.21208873871835, 71.49999941548994, 60.30615114396619, 58.64902427119594, 58.14040660858155, 59.513255780743016, 58.28300829856627, 62.5123784618993, 63.14716700584658, 59.1024188841543, 60.07068341778171, 57.1005117508673, 61.251905195174686, 63.88609447786885, 63.29535415095668, 65.5601816792642, 63.86777308679397, 64.45774855152254, 62.21164641841766, 62.213435019216234, 55.743944337291104, 60.36159776872205, 63.391930749339444, 60.94712526567521, 60.138716928420536, 54.26016661428637, 52.713497607938706, 52.968424212548044, 51.6672916566172, 45.86302711117653, 48.12595621232064, 46.670576449363466, 48.83301442669284, 44.762876802875155, 48.21928116583055, 49.12860816524875, 55.67868394236411, 52.295157217210345, 53.5201055772843, 50.28270675290016, 52.64239288145497, 47.47991438834898, 48.13256932843117, 48.34313392639161, 52.52372941663189, 57.41408955666327, 58.19511582774501, 54.036575824983665, 39.72795378777289, 47.63864878685244, 51.931718241783884, 54.733871259996974, 58.86088325131325, 55.822187777488466, 56.581240930864894, 56.682893076250636, 54.30400694570234, 51.16206292183169, 50.4354791487417, 48.309699643042784, 50.36127967219199, 47.34746379237021, 51.20618958627024, 50.26802532134518, 52.27669854317942, 48.042080248555834, 44.60382469238774, 41.96690151768346, 46.313640763682706, 46.50383257096814, 50.019272527387066, 49.48920342230028, 48.99341191014936, 44.289505558629195, 48.934007613889634, 47.217154810505534, 48.137978276898785, 50.789194568510986, 55.186473554180516, 58.54175529172344, 57.46814766237813, 57.69064803277293, 50.23118249831661, 53.98816593231694, 59.57298563372705, 59.09639412356962, 58.928171511619325, 58.134640724428245, 57.408464877836174, 57.082763025837565, 58.72838558689241, 61.854141989061915, 60.1719041024485, 56.898580289656124, 46.848879552656605, 50.46143347217191, 52.56303156575849, 54.669101161341516, 53.09020203928794, 62.30374759243381, 60.10631422842703, 54.07708606412334, 60.60376098079067, 53.808501766574004, 45.12094605353571, 32.33610599271713, 17.327750767430953, 23.52121445440477, 15.344042451150957, 2.107558870507825, 0.8728261580390315, 4.582957615775447, 46.00919031327771, 56.98174630441974, 63.328760977714296, 63.39333103549097, 64.2063089339964, 38.35205301161736, 59.54311286249469, 34.22257777183287, 12.000684718931875, 63.6731803801752, 35.97716377627465, 46.26001019631663, 35.965890884399414, 31.62258959585621, 61.05937565526655, 14.525266308938305, 0.25848168158723467, 0.04849332730255781, 0.05336183138311871, 0.06395129622110436, 0.06615142413084546, 0.01666425096411859, 0.03838313090044164, 0.0639679279899405, 0.06788858212530613, 0.051522109537355365, 0.18321578000341693, 0.11673499169128558, 0.07626615194303375, 0.09196219800580895, 0.4130645270549482, 0.16545222351147285, 0.13209569808696547, 0.10487871620083049, 0.1753440886856087, 0.19335110791988913, 0.25150258995352254, 0.28739092871546745, 0.564299690867624, 0.7377885750705196, 5.5212665181006155, 65.14234335191789, 67.28278467732092, 57.566599153703265, 42.06887921979351, 60.943661812813055, 81.96081161499023, 10.467475325830522, 31.592983545795565, 81.43510418553507, 71.51375909005442, 76.33724674101799, 72.77656616703158, 72.59081840515137, 72.11506628221082, 8.121516021990008, 0.7547899047213217, 1.1663631037358315, 6.273386391901202, 18.995089530944824, 36.22174316836942, 53.255490718349336, 58.792477115508056, 76.49292561315721, 69.56715737619709, 71.00931875167355, 63.55404230856127, 61.02054026819045, 59.757144835687455, 62.68888511965352, 56.758167282227554, 66.12356739659464, 66.41665474061044, 62.32383405008624, 60.81942465997512, 58.6643175924978, 61.1970430035745, 65.12231572981804, 67.46118976223853, 69.79183858440769, 67.18617669997677, 70.00727868849232, 62.38692145193777, 66.49776935577393, 59.97065905601748, 62.18338181895595, 66.07409061924105, 60.995182145026426, 63.6868380731152, 57.68802396712765, 54.72218651925364, 55.96737430941675, 53.392981559999534, 46.66007234204201, 49.8400515894736, 48.34887627632388, 50.03217320288382, 49.22825205710627, 53.556877797649754, 52.9239837584957, 59.465261659314564, 55.43535970872449, 55.46953924240605, 54.90196443373158, 56.10614384374311, 51.87309057481828, 51.3070180339198, 52.77614962670111, 55.28583503538563, 59.08806693169379, 61.84551669705299, 56.971814863143436, 36.21898181976811, 45.73498525927144, 52.67397972845262, 53.6144660365197, 60.237344926403416, 55.563605523878536, 64.34018335034771, 62.333828249285304, 57.77860718388712, 54.0392626485517, 53.9383832100899, 50.63788129437355, 53.63331302519768, 49.950011314884314, 55.02682132105674, 53.21496478972897, 56.43109652303881, 51.43602871125745, 48.750193580504394, 45.03538739296698, 49.31471286281463, 49.97252179730324, 52.19875320311516, 51.37855029875233, 50.68546356693391, 46.095000005537464, 48.492917476161836, 49.45849910859139, 49.34582510302144, 53.267453947374904, 56.785298316709465, 62.45745351237636, 58.98025666513751, 60.069032099939164, 54.58724914058563, 56.91891777899958, 61.77989544407014, 61.71279153516216, 62.76336700685563, 59.97243588970554, 61.676078150349284, 59.46729344706382, 61.69424656898745, 63.297523221661976, 64.32009689269528, 58.14670593507829, 48.17808451191072, 48.94718285529844, 54.64724571474137, 55.28526236934047, 53.108233174970074, 60.81355679419733, 59.90213132673695, 54.167202518832305, 60.897452369813, 54.02761713151009, 50.06377966173234, 39.01249777886176, 25.80460459955277, 23.384449251236457, 24.130350697425104, 4.758899452224855, 1.4725678342003978, 3.648447774110302, 48.69759067412346, 64.14733217608544, 67.1647919377973, 66.8687863503733, 68.32157734901675, 47.03493718178042, 68.62295658357682, 38.430323908405924, 17.08401664610832, 68.15770072321739, 46.84769499686457, 58.29957639017413, 39.913874133940666, 48.91160303546537, 69.4331221426687, 30.264612090203073, 0.6714166172089115, 0.4526811093091965, 0.14907088881779104, 0.17518900184621736, 0.12062415961296329, 0.15929125249385834, 0.15668278439871727, 0.28441639316658823, 0.19590363627479923, 0.13148117299762466], [0.10056482147305243, 0.0487166840673214, 0.039506537554365014, 0.048612618683687145, 0.04441800767615919, 0.08504231730776449, 0.026300723491717252, 0.031403024200229876, 0.02175110734007772, 0.047315800367223645, 0.0806436702729233, 0.01882362108106815, 0.1260537618110257, 0.07519832496801693, 0.14431545931485393, 24.095492593703735, 40.32637803785263, 37.22161416084536, 32.91874662522347, 29.668819750508955, 38.569587661374, 20.400929758625647, 13.699421075082595, 61.235933303833015, 58.945284812681145, 69.02114775873, 57.30896611367503, 67.80902554911953, 61.91041231155396, 47.17094928987565, 10.842038143065668, 0.42689615259728125, 0.6353651936496458, 2.1080957449251607, 5.293850437287362, 33.41402822925199, 40.23762264559346, 54.580851754834576, 62.52763255949944, 58.544865731270086, 60.836851750650716, 66.11399681337419, 59.144298030484116, 68.52776850423506, 66.42106348468413, 68.01090994188863, 63.712725716252486, 64.55167755003899, 58.626321592638575, 58.211585860098566, 52.62986875349476, 64.08554700113112, 60.90207292187599, 63.939693666273556, 60.95587607352965, 63.71264726884904, 60.08381551311862, 62.25031314357635, 53.838025446861025, 45.77698992144677, 64.07011639687323, 61.9517501708, 62.20416253612888, 54.35659416260258, 49.42577869661393, 52.652489062278505, 47.84080774553361, 44.840269088745124, 45.55779610910724, 43.156423030361054, 44.29156480296966, 41.24202397561843, 46.19915462309315, 48.58163364471928, 49.55472661602882, 49.19783015404978, 46.90609908873036, 45.54271067342451, 46.50286766790575, 44.850110315507465, 44.29518515063871, 45.911903765893754, 49.4116150179217, 56.22345016848657, 52.0118954104762, 57.922664073205766, 20.259120387415734, 21.50930919954854, 49.262808138324374, 46.32718470788772, 23.226689561720818, 41.90141362528647, 58.993435828916496, 51.662188653023016, 57.298752261746316, 47.31632017320203, 46.84879326051282, 44.77582846918414, 45.54258123520882, 45.87277420105473, 45.83508806843912, 45.97506569277856, 47.94016138199837, 46.284489708562056, 46.093336920584406, 43.31675775589482, 41.343260349765906, 41.18174891318045, 41.528710011513006, 45.208744387472834, 42.95856691175892, 45.049590295360936, 44.05757188796998, 48.114938274506606, 48.534918215967, 49.93468661462107, 57.29360611208024, 56.25095775050502, 55.5475708746141, 52.36446157578499, 52.944070216148134, 53.00627900708107, 56.81162526530605, 55.0789378535363, 56.69619383350496, 56.709992731771166, 59.00706998763546, 55.26739989557574, 59.168365693861446, 58.26517720376292, 56.3557360249181, 48.87496417568576, 50.182243085676625, 52.561419471617675, 47.569826879808986, 53.27817770742601, 51.755505761792584, 52.610523623804895, 62.36036308350102, 54.3715109363679, 52.51922653567407, 45.34265018278553, 38.69420920648883, 17.598335473768174, 13.2058790422255, 18.46249638065215, 3.686825469616921, 1.274006179263515, 3.2908894121646886, 38.162528007261216, 60.40450457603701, 52.96056378272272, 58.57714683778825, 56.62488122140208, 52.43511522969892, 55.12828911504438, 76.31892142757293, 15.50746996556559, 17.79678387026633, 38.36000365595664, 27.279749185808246, 39.13160839388448, 21.947696824227613, 39.61260864811559, 41.49675053934897, 4.994174982270887, 0.04444429981372049, 0.0926930229029348, 0.028032610801258878, 0.07346968587127424, 0.18453843080468718, 0.017114618733044595, 0.02916770412646715, 0.019336413524504152, 0.02093499195912192, 0.03221690451966659, 0.055986762707752574, 0.023625841319200494, 0.02417423769891743, 0.04596732091158629, 0.030023939532017516, 0.0709568485317211, 0.08895295867395979, 0.05100711459113706, 0.0708137050030693, 0.03448845097614873, 0.025085581639300913, 0.0403545968865435, 0.14368830909652097, 0.03452739505577953, 0.11030857120790791, 28.80852237824471, 54.494418405717425, 34.7506425457616, 36.50193375925864, 37.98049865230438, 38.70876119982812, 26.18738674348401, 17.660401098189816, 69.22489135496079, 64.98470329469251, 75.03845584008002, 63.608343601226814, 72.40469409573463, 67.69333916325724, 55.26525828146166, 12.535229248385276, 0.3557744802486512, 0.6229316479256076, 4.1816275638918725, 3.827466464811756, 44.869220102986986, 46.60761848572762, 60.32589243304346, 63.45167629180416, 61.00569409708823, 60.53208358826176, 65.6478270407646, 60.0044620421625, 67.99780138077276, 67.94310785108998, 68.52199477534141, 66.24456467167025, 66.77402973175049, 60.239541453699914, 58.3452602355711, 57.22994604418355, 65.82566338200724, 62.86300697634297, 67.99360444468837, 62.23465111947829, 63.51225729911559, 61.476472654650294, 64.89330814730737, 54.907891135061945, 46.91419486076602, 62.235898433193086, 63.94309436121295, 63.07250861198672, 55.132756694670654, 52.87486783919796, 53.55906255783574, 50.43602828056582, 48.0682542247157, 48.1400022199077, 45.96934687706732, 43.84630910811886, 43.36361438997331, 49.80330682569935, 49.257442335928644, 52.29605936234998, 53.19004989439442, 49.46374723988195, 48.80796224840226, 48.9528702920483, 48.403083432105284, 47.21449152115853, 49.43301546958185, 51.3547650460274, 58.29606979124008, 56.50277391556771, 60.243228481661895, 24.397391542311638, 29.354559452302997, 51.11947382650068, 50.24515005850023, 32.61643386656238, 46.367035988838445, 63.495508778479795, 56.43693300985522, 59.47587559300085, 51.08354883809244, 50.64194486987207, 47.515349080485684, 49.66157590189288, 48.33127660136069, 48.81575207556448, 47.53314095158731, 50.619387319011075, 47.32907179863223, 47.761697461528165, 44.79505200539866, 45.16732415845318, 46.29717465369932, 45.196334008247625, 47.34432981860253, 47.216954769626746, 45.90986021103398, 46.523922950990745, 47.74355257711103, 50.4512196202432, 52.59127263099917, 57.798383774295935, 59.48395175318564, 58.02697166319817, 53.553735979141734, 57.48149156570435, 55.81283684699766, 58.8488611867351, 57.38329895081059, 58.24861303452523, 60.08435680020241, 61.20487205443844, 57.42850034467636, 60.97180089642925, 59.541920461962306, 59.89324715829665, 49.92543374338458, 50.59216999238538, 50.803338635352354, 49.45936987476964, 53.89898300170899, 52.731999428041526, 53.97966223378336, 63.016501088296216, 57.55893092001639, 54.55522298812867, 49.76635417630596, 44.6920701765245, 23.85545530626851, 19.41528912513487, 16.792798311479633, 4.743827744837731, 2.6060207813016834, 4.83015077729379, 43.52980913654451, 65.29358210102205, 59.16292536643244, 61.744554888817575, 62.69073255600468, 55.07783566751788, 59.15620634632727, 77.02971766071936, 18.536274202408332, 22.71496145955978, 47.14037833675262, 28.777835715201597, 48.199037813371234, 22.66377256762597, 42.5401206170359, 50.0754173340336, 3.8005511606893236, 0.24967068986546612, 0.12387298528225192, 0.04719804116194287, 0.07525252568865977, 0.15138619038606846, 0.039511501804114356, 0.11670175879713028, 0.056493150656141584, 0.02106457190107434, 0.042076509731310996, 0.26140115073611664, 0.13956811970039723, 0.08520725603786208, 0.10452949502054723, 0.14579141963153117, 0.22483163723541846, 0.19026086245092655, 0.09603760190187924, 0.18616146468106778, 0.09239827823494712, 0.2513080342642723, 0.20758158947911956, 0.44889452056057993, 0.20948335678587038, 0.46209292846821975, 49.236190934335035, 60.24745679670765, 57.93084221501505, 48.68132852738904, 45.87227606004285, 50.783852300336285, 28.558133955924745, 21.060019346975512, 75.24118746480634, 72.46876993486958, 79.69109289107784, 66.04300191325527, 74.65946074455016, 74.36489858934956, 64.09106969833374, 12.821401453787281, 0.49915417848575505, 0.8456794340764323, 7.725926358853617, 12.265705543179667, 59.46163738927534, 50.49999429333595, 64.47292420171922, 66.91140682466569, 64.5899441934401, 63.97744647918209, 66.56095873924994, 61.3199543952942, 70.04702798781857, 70.64857836692565, 73.14097789026076, 69.91842915934902, 68.67015054149013, 62.02829130234257, 61.05545328509424, 59.307413716470045, 64.72471291019072, 64.72657995839273, 69.45605231869605, 66.71218964361375, 66.82069809206071, 62.10292223961123, 66.93551371174475, 58.15675896982993, 48.81470480272847, 66.1503650296119, 64.77969669526624, 66.30049767032747, 58.822542082878854, 55.436406981560495, 57.02846565554219, 52.25995786728398, 49.68817349403135, 49.061206156207675, 48.09238856838596, 48.08762681099677, 44.59131233153805, 53.18995575751028, 54.231458786995184, 54.13888692855836, 55.67554604622626, 50.35703566766555, 51.4118355320346, 51.17534798960532, 50.42526137444281, 49.37268941633163, 52.868619503513465, 53.29662853671659, 64.55446635523151, 58.72859347251154, 67.575377802695, 21.451275771664037, 26.881332474370158, 52.452459950600904, 48.74351770647111, 27.396843702562396, 47.494007464378114, 67.43255645998063, 56.66785863138015, 66.03202712151312, 54.04881754229146, 55.23356945283952, 52.76543763376052, 52.31715386913669, 53.24934828665949, 51.50685887182913, 49.3023770086227, 53.73164292304747, 48.9704111314589, 52.87151421270063, 48.968536238516535, 48.51653014459918, 47.87712889332926, 47.5103598256265, 50.12726322297127, 50.18385517981745, 46.757813884365945, 48.61785673326062, 50.409599350344756, 52.77483171032321, 54.602067855096635, 60.09214270499445, 59.32458977545462, 62.093696824965946, 53.11077487084174, 55.90116470090805, 57.83346545311713, 59.84943428347188, 58.99966063037996, 61.79307460784913, 60.98263840521536, 64.45778777522426, 58.446045537148755, 63.77698590678554, 62.42287389693722, 62.95694774196994, 50.197430502983835, 51.601340924539876, 51.81145837230068, 50.51179670518445, 55.37457081579394, 55.737201782964895, 54.18416676982757, 60.88694041775119, 55.60106023665398, 56.04410371472759, 51.944940551634765, 49.24785214085733, 32.64352567734257, 24.12391016560216, 25.954286167698523, 8.246455769385062, 3.048364116299537, 4.917638753691028, 44.7374519994182, 70.80366103879868, 64.13410986623457, 68.14463138580322, 65.30412543204524, 63.003612179909986, 64.57507841048702, 87.28072227970247, 21.138398108943818, 26.376927437320834, 45.97277502859793, 40.06026483351185, 56.59063892979776, 36.10626074575609, 56.226513539591146, 66.3431259893602, 13.313072516072182, 0.7465567884425963, 0.36714834251230766, 0.28083465632892424, 0.2660357375298777, 0.3447930695068452, 0.1353903358141261, 0.2382819195308032, 0.12254261997558417, 0.14491559727297676, 0.171332469270114], [0.02715266880489165, 0.0755743975300462, 0.13217213834005018, 0.06185735575854779, 0.01575745758600533, 0.10078815142473868, 0.034768119033786564, 0.08233408924312362, 0.08576420961969322, 0.30612432187603367, 0.015193626449833957, 0.09596156001451517, 0.0853641661665132, 0.03273378787261825, 0.45439343839403123, 7.6059842013543655, 38.878074230686316, 51.48769809353737, 53.69783601453228, 31.76559921233885, 44.00521216853973, 22.857133650010635, 3.866957623151041, 41.64957392600275, 67.41732197423136, 64.6962914159221, 67.381440131895, 58.80127499180456, 70.02198757663851, 54.116839285819765, 60.64234925854591, 11.49227592252916, 0.26113936317063147, 2.3777001038674386, 0.8931930651587825, 16.789954593104703, 36.5964432685606, 53.07748179281912, 54.28874500336186, 61.237663069079005, 70.11773263254474, 66.3711238676502, 63.40399203761932, 67.76150211211174, 63.91691646268291, 64.68927429568383, 60.45347929000855, 61.946490272398925, 59.27472076108379, 63.828043399318574, 56.380796047949026, 59.2057341144931, 62.99616359895276, 61.613943884449625, 65.53600026715186, 60.10797339100992, 61.23217959557811, 60.0967828689083, 61.07205667803365, 44.38138315754552, 59.43781291284869, 61.17734486056913, 62.13961993494342, 55.855155298786784, 53.282374643510394, 52.32649695488715, 49.53537756396879, 44.57960013420352, 41.884508209843794, 41.34856339423887, 39.54183340072632, 42.07514716732887, 45.835597976561516, 47.77478641079318, 47.916317293720866, 49.66446668870988, 45.835276342207386, 44.84445425771898, 41.75243416140157, 44.25612618846279, 41.76459743130592, 46.4298370576674, 50.68266691700105, 57.4467864344197, 48.48235061091762, 63.54842155210434, 22.67587700197774, 7.3953357627314915, 46.53226583234726, 32.17484951019287, 10.138242360084288, 41.49962171431511, 57.05801287005025, 56.3315781470268, 57.224674378671956, 46.9634323735391, 43.67681172586257, 42.470255359526604, 43.95311132554085, 42.39168636260494, 45.346784360947154, 43.41336573323896, 45.23067828147642, 44.42764751372799, 45.99306544949932, 40.62205806855233, 41.0794456543461, 42.84528886118243, 39.17737068668489, 40.0836774610704, 42.440335519852184, 43.24690818786622, 44.8170643468057, 49.50974095252253, 49.105595619447776, 51.70084361107119, 57.84657793660318, 57.21800242700885, 55.65487907778833, 53.84919243474161, 52.78143305932322, 53.71294890680621, 55.08235031558622, 57.25414314577657, 58.0489134019421, 56.06098559594924, 56.90597003506076, 57.846715219559215, 54.992480970198116, 59.782420589077866, 53.781311896539506, 50.12047752257317, 51.04095974276143, 45.65152898911507, 51.19483432462139, 46.70272811766594, 51.60990738099622, 49.897541769089244, 53.876535277212824, 53.59764299085064, 50.89791090257707, 46.806749374635764, 28.330438406236713, 5.423610287327921, 8.204283916181135, 2.462973657154268, 1.7651317869463277, 0.6538809871961994, 8.379351554378387, 46.96680168951712, 51.28073030902494, 55.310075283050544, 56.81508479579803, 54.31291857073384, 52.92138714944163, 71.66742970866542, 32.24958242908601, 5.275116707048109, 38.36463989750032, 20.538065625775246, 36.244967522159705, 31.518154528833207, 22.168887122984856, 47.51627083747618, 27.723816402496833, 0.734006307057796, 0.06710226181894541, 0.2318744367409137, 0.04580585255978569, 0.09953667785251334, 0.08778871953367226, 0.03986710066636724, 0.10290076145000997, 0.030096813645814697, 0.04741133536182104, 0.1177255740208972, 0.02573397739099399, 0.04210610753826557, 0.03804667657541652, 0.0340731202384397, 0.08097108093000228, 0.020369647799300093, 0.019469548114425233, 0.03501725848764181, 0.07367066137732999, 0.0700308244314886, 0.022131307200799068, 0.0390282841849952, 0.21065277468052604, 0.13180017200929503, 0.4348734874398478, 9.159288387144766, 54.63535308837891, 58.79557186557401, 54.761272938020774, 46.57863217015421, 37.95574457414689, 28.184889055067494, 4.7098041253705185, 42.89703276849563, 74.24075557339576, 68.95294558617377, 73.19538116455078, 63.45155077595865, 77.24709541566911, 60.93831562226819, 69.88724631647911, 14.3380388329106, 0.21969189206438683, 1.2718313475770335, 0.7707573221095148, 22.478009116265085, 43.43535454042497, 56.798920708317915, 59.11643351277998, 65.04282105353572, 68.43139586910125, 67.63796314116448, 64.96524049389747, 70.24684136913669, 66.61455400528448, 65.98001649302822, 63.70033887124831, 64.55268559917327, 61.58500463731828, 63.73733858908377, 58.046607048280784, 63.80147718614148, 63.29205936001193, 64.02897465613582, 67.16236006829047, 62.139663081015314, 63.72195113089777, 62.55852906934677, 63.52982167274722, 48.37986300068517, 59.22294547480922, 64.69969603323167, 63.95994486347322, 59.01128261320053, 52.29580833065895, 53.26196655150383, 51.7236678831039, 47.091054531835745, 44.14003972084292, 43.64623292799919, 44.70018556041103, 42.64237680742818, 46.47375975885699, 50.834768587543124, 48.85974537941718, 50.14680054879958, 48.21018911177113, 47.514737190738806, 45.59908689991121, 47.12460256391957, 44.87544882682062, 49.60790218845491, 52.443771900669226, 59.191189965894154, 51.89464399891516, 67.48105264479115, 26.634893878813713, 13.542522345819782, 48.06013099608883, 37.850781948335715, 13.870688426879145, 43.39421672205771, 60.27262272373323, 58.459150175894464, 59.36055006519441, 51.06199933636574, 46.9196940237476, 44.420826511998335, 46.79966165173439, 44.1877906553207, 46.9747523338564, 47.0769065426242, 47.8617218232924, 48.26982875024119, 47.66778807486258, 43.22329551942887, 44.41273858470302, 45.64844208378946, 43.80874064660842, 42.97859061148859, 46.08845749209004, 45.63882443212694, 46.31272292906239, 52.04160344216132, 50.53661354126469, 53.455645345872455, 60.34558665367865, 59.18473374459052, 56.19001588513775, 54.77044343948365, 55.42272575439946, 54.88605922268283, 56.748216229100386, 60.41323969441076, 61.364241876909816, 58.417074911056034, 60.31082660921159, 60.5580771353937, 58.12943573920958, 61.48059898807157, 56.51488619465982, 50.060296597019324, 50.99285579496815, 46.72623488210863, 51.45592297277143, 48.5112702461981, 52.71567844575452, 51.93035325696392, 53.353867684641195, 55.92847224204771, 56.65157295042469, 49.14592150718936, 33.732877700559555, 9.535269141197205, 7.347401947744432, 3.23096368582018, 2.611647911610142, 0.5923766907184356, 10.12674883488686, 53.19049704459406, 58.297109219335745, 60.92859206661102, 61.47529202122843, 61.05121320293796, 57.15114562742172, 71.41686870205787, 33.86914476271599, 8.741046055670708, 46.104496063724646, 21.09219062712885, 37.617412690193426, 38.705537011546475, 18.663831641597135, 58.54188080756896, 33.10605156806208, 0.5664817544241105, 0.08036121365524108, 0.0797987059359589, 0.014718643318290913, 0.028904369063374978, 0.014057317917655795, 0.05478509634192433, 0.03577144906645821, 0.07886668336727927, 0.06896075281885362, 0.0808853020651206, 0.14611731343452009, 0.1599940002685593, 0.17913827702643412, 0.22941034557598255, 0.23761511660150944, 0.18413120910765665, 0.12762216595752587, 0.16605924093915572, 0.3193111771777753, 0.41085969536535205, 0.2243589763078959, 0.17604820009681488, 0.2809792017984775, 0.26925263265448235, 0.703604628722514, 22.023339733000725, 71.11052374685966, 73.66009573782645, 74.11724013666954, 47.997486822066776, 62.158219814300544, 33.19188871691304, 5.9341915865098285, 50.740149251876346, 79.97995976478823, 76.14874547527683, 78.56696513391311, 69.87810719397761, 82.40345108893611, 67.20953049198275, 73.25948053790678, 15.049944116223244, 0.47722999847704367, 4.336475874147108, 2.7581562822864902, 29.83269637630832, 52.87999829938335, 62.21154835916335, 61.84272789186048, 66.94946950481784, 67.20890291275518, 66.05087803256127, 68.42377078148627, 75.82448313313147, 68.82135791163292, 69.83018367521225, 64.74633693695068, 66.03409028822377, 62.229818759425996, 66.59176503458332, 61.57589689377816, 61.518116458769775, 64.87673221095916, 66.92312686674057, 71.60981793557444, 66.62518362845144, 63.91213117107269, 64.48064734858852, 68.05732727050781, 49.23388458067372, 59.46987436663721, 66.57882905775502, 67.2910608783845, 61.49545300391413, 55.70841943064044, 57.41754124241491, 54.079541467851215, 47.49822793468353, 45.140299027965916, 45.66530827553042, 44.66083242047218, 45.93761882474346, 50.26862152161137, 53.92596106375418, 50.7761997561301, 53.550437265826815, 51.21973745284542, 49.34284802406065, 46.03727840608167, 49.88173853966498, 46.82257613828106, 54.14004010538901, 54.43510432397166, 61.8972723714767, 52.95311127939532, 73.49820383133428, 22.19962085447004, 13.163718465835819, 54.76738399074924, 35.093665584441155, 13.725479341322377, 43.32334733778431, 63.97925076946136, 62.23637303998394, 62.068315167580884, 52.017080783844, 49.405649092889604, 47.24679616189773, 49.2105935465905, 43.42301476386286, 49.421350340689386, 48.405170133036954, 52.328697404553814, 47.899062787332845, 51.277545344445016, 44.6462921942434, 45.55656056250296, 47.05920096366636, 45.362760174658995, 44.512127522499334, 49.95007407280707, 48.61343622207642, 48.126713229763894, 55.46451076384514, 54.67662426733202, 54.81710003268335, 62.39331491531865, 62.424305562050115, 59.18133304965112, 54.6091712674787, 58.43596112343573, 58.223086249443796, 58.294418473397535, 62.771827559317316, 63.206622292918546, 61.53994444877871, 62.87527615024198, 62.65907510634392, 60.216219040655325, 66.60313206334268, 59.569377053168516, 51.78870470293107, 53.20592372648178, 45.968429042447, 51.77519606005762, 47.86972345844392, 55.77888873315627, 54.984306750759, 56.94961032559795, 55.021973271523755, 58.38992426472326, 56.31698692998579, 39.327330743112874, 16.0955411195755, 11.793087394006792, 4.883620527482802, 3.807723704845675, 1.3233021598669792, 10.831875281949198, 56.682559674785985, 64.7355386518663, 66.72332133016279, 67.47114473773588, 65.62890552705335, 62.64566844509494, 77.82735516948085, 42.20383621031239, 7.831368984714632, 49.43568268129903, 25.361149272611065, 57.961742647232555, 46.79532743269398, 37.88320426018008, 65.13023107282578, 54.05499919768303, 2.2101457657352572, 0.242562772886407, 0.3558289337783091, 0.16678555357840755, 0.16997096248932425, 0.3112359056549688, 0.17693500815620347, 0.2932799998069963, 0.15324433664641074, 0.21464453709702339, 0.2470606589509595], [0.08637845891738131, 0.07702053404383122, 0.03218177938833833, 0.05455032869752857, 0.12547411670487735, 0.1946050253125929, 0.10922167630445574, 0.06071339496561597, 0.03648662661773063, 0.09390430750265237, 0.051447979039362365, 0.02343908248979959, 0.031023452531606443, 0.07363346780860618, 0.0801845001537473, 0.321149175325709, 26.511239197946367, 41.48788990512971, 48.08114313310193, 30.84845296798214, 30.75298247798797, 44.84549760818482, 15.984579228585767, 9.342240479684646, 54.64659460129277, 63.63231712772001, 66.74540427423292, 59.65681452904979, 68.09874749952748, 55.242775255633944, 48.11744466904671, 43.86703883447955, 0.1092092120539277, 0.4712732052130084, 0.23587082632847373, 7.650940447084366, 28.87314146564853, 45.32500736175045, 52.56038396589218, 67.8864452915807, 60.08028930233371, 62.807003375022646, 65.78668678960493, 62.70706922777238, 63.807839270560976, 61.934546655224224, 59.267546746038626, 62.69184258676345, 59.16167805271765, 62.76201378914618, 59.68991148856379, 57.627964635049146, 63.879544119681086, 59.660874182178134, 64.56881438532184, 63.84264638347011, 64.31979094782184, 59.91669508718676, 60.63975657186201, 50.22703655304448, 58.894564643982925, 62.07386924374489, 63.40903620566092, 56.382153188028646, 50.3349958696673, 50.86846566969349, 48.803416221372544, 47.79461399201424, 40.72127049969089, 40.52002545325987, 40.89446667701968, 42.02370136014877, 46.35750462931972, 48.09924487144717, 49.904119583868216, 51.51064395904542, 47.36372593910464, 42.443438114658484, 45.58173041189871, 45.10484864634853, 42.00337563791583, 43.2316658573766, 50.1621566280242, 53.87090275364538, 54.05817239515243, 55.48339305385467, 40.49442414314517, 15.765077510187703, 34.38370089377127, 21.597672354790475, 13.303069491540233, 57.73043263343073, 49.871834554979884, 59.145086426888746, 52.55177436336395, 48.75516322351272, 42.375475206682765, 43.41138101393177, 41.954000842186716, 43.075355483639626, 41.87529848467919, 41.85466681757281, 45.50667193628127, 44.61109284431704, 42.57424523753505, 44.65782788492019, 40.48100963715584, 41.95984125137329, 40.479397543015025, 39.81471269361435, 43.48343103162704, 43.996732004227184, 43.8182641613868, 47.48273065013271, 50.10656095320179, 48.55458498001099, 56.390762790556884, 56.181374903648134, 57.95039915269422, 54.848914377151004, 59.32858667066021, 53.66132659296836, 57.07444367870208, 54.16942650272001, 56.47295605751776, 56.26902418751871, 57.05798933582922, 58.13209902855658, 55.828055643266254, 55.69030200281451, 49.39121477065548, 52.37498529495732, 51.20838611356674, 50.92976839311662, 58.03388287944179, 56.58982699917209, 56.3676521855016, 55.00987668191233, 53.07446549015661, 49.770304003069484, 50.46213949880293, 33.40805838184972, 17.574420782827563, 5.319781716792814, 1.8997008305403495, 1.2947606655859178, 0.7087321471302741, 0.30731479186684857, 11.504311715402912, 52.70271108996484, 51.754038795348144, 59.04212028749528, 51.8340826034546, 57.85104551622945, 59.663725745293405, 63.40828311058783, 13.709304467324289, 20.26366445326036, 57.17123600744433, 30.41662746860135, 41.448591678373276, 22.683241251976263, 27.05194380975539, 43.850129496666696, 18.820314599621682, 0.19086188907104154, 0.12031867439227721, 0.06217283459620611, 0.08304075172711765, 0.018905736130451965, 0.2150167485759143, 0.15028847832112543, 0.04297125446159513, 0.07276332982244992, 0.05220493519558542, 0.04971208125953713, 0.06722266019712533, 0.01937860773215371, 0.024434472021136074, 0.03427103522323793, 0.05889040831055853, 0.14804039330732438, 0.08806098718196155, 0.053156768797986934, 0.061174905483400634, 0.0662728643886024, 0.03653237738856866, 0.03682382787848192, 0.11660337012501494, 0.06965453736484051, 0.2626760742597042, 0.882355985381911, 37.920847246723795, 48.296665606960175, 50.69812105547998, 41.63436297447451, 36.341759850901944, 47.52323304453204, 26.53352022171021, 10.233732461929321, 58.052255261328916, 69.74411902889129, 71.58369495022681, 65.44675457862117, 76.00311571551909, 62.34147294875115, 55.35914413390621, 50.29472881747831, 0.8062022491808861, 1.0467213752769655, 0.8177779602908319, 8.51738368311236, 34.88216354000953, 50.65505343098795, 54.64279774696597, 67.47256463573825, 61.22173432380923, 65.26245809370472, 68.70748366079023, 64.07819255705803, 65.57103487753099, 64.65066640607773, 60.703479397681456, 65.4705947445285, 63.09973378335277, 64.80132464439639, 60.258439433190134, 62.89100485463297, 63.759378387082016, 62.92193666581185, 66.3350066831035, 64.65183527238908, 62.29105088018603, 60.00737244083036, 64.1176123772898, 53.64961047326365, 59.241663025271514, 64.34931070573869, 64.0922385646451, 57.40910030180409, 51.956821410886704, 53.366952711536044, 51.13349237749654, 49.471415473568825, 43.85083552329771, 44.29069011442123, 41.92191977654734, 42.22609173867011, 47.611047067949855, 49.34912381633636, 51.32390383751162, 52.14859001098141, 49.70323147312288, 44.809058789284, 47.039726395760816, 44.948240172478464, 44.071715954811346, 45.541361378085234, 54.93687745063536, 58.78537370312599, 59.78369535938386, 55.99963972645422, 51.88934879918253, 19.740694838185465, 35.530413658388206, 24.904563811517534, 17.11907479070848, 63.48191384346255, 52.06461206559212, 64.07140685665992, 56.38872315806728, 53.14284416937059, 46.06594308730095, 45.42572206066501, 45.253616302244126, 45.069143310669936, 43.94238756548974, 44.96951903066328, 45.838861388544885, 47.444299267184356, 45.295420923540675, 45.62180526794926, 43.63058267101165, 43.56233735238352, 43.711909094164454, 44.306548257027906, 45.86541975698164, 47.15850753168906, 44.66417035748882, 50.265158068749216, 49.50516746890161, 51.960986968009706, 57.77831692849436, 59.89891890556582, 57.49169365052254, 56.46213816058252, 59.35235231153427, 57.738869651671386, 58.68697712498327, 57.036996810666984, 58.61797086654171, 58.89486274411602, 59.017048497353834, 61.27907153098815, 61.10242366790772, 59.19725002781038, 50.87805978713497, 50.74411476812055, 53.49734014080417, 54.13860844027612, 60.20538545423939, 58.146207794066406, 60.22872355676467, 56.40959801212434, 54.96070192706201, 52.73967158409857, 53.931389624072665, 37.39142141034527, 23.63077017568773, 6.6569530098669, 3.597524622755666, 2.419367687356088, 0.7370280642663279, 0.5179078576545562, 14.192439471521686, 59.96356348837576, 56.22658414225425, 64.33074220534294, 57.915784235923525, 60.63289242406046, 65.28964796373921, 62.37408745673395, 19.583752962850756, 22.937593229355354, 62.16118120378064, 26.433860640372, 44.323790996305405, 28.532662084025723, 29.31761072527978, 56.40355756205898, 22.19152900480455, 0.22710619824788264, 0.1134390362928952, 0.06624265754174802, 0.058529603880860155, 0.1177576807658038, 0.08212067246917756, 0.07380877936919851, 0.03685281281509707, 0.04228689662751652, 0.06185440632003931, 0.0866897434236542, 0.18435832353368883, 0.22135425689479998, 0.28225516720164207, 0.1855243399979607, 0.1903252291583246, 0.8247344676525363, 0.3446130388446393, 0.21770413904901476, 0.16796900620383604, 0.4329550807033816, 0.14725371293963926, 0.16148905149630963, 0.44187966794256245, 0.1760043032587536, 0.8032699097548762, 4.56938817616432, 63.37882611059374, 57.65106739536409, 63.79773524499709, 47.6529928945726, 46.73680174735285, 54.94119990256525, 22.359171105969338, 12.819122556717167, 69.98635676599318, 71.36031596891343, 77.46226879858202, 69.02674105859572, 84.02272316717333, 68.84245241841963, 61.70950066658759, 54.36574112984442, 2.2325863809354844, 1.343392417315514, 0.9915352204153616, 10.88760627854255, 43.50540022696219, 58.5348754544412, 58.7137080777076, 68.32619790107974, 59.57460557260821, 67.71534365992393, 73.13401960557508, 68.4250416294221, 68.49128261689218, 66.58146489051082, 61.00917323943108, 68.40131128987959, 62.516814662564194, 65.16612468227264, 65.44490714227, 63.94389844709828, 63.15068929426132, 63.673721667258974, 72.23921714290496, 70.40248101757419, 65.90983744590514, 61.43649978022422, 67.33022182218491, 52.89902571708926, 59.67389645115022, 68.24230624783424, 68.42079762489566, 60.23436000270229, 54.423909879499874, 55.975779948696015, 52.68149891207295, 49.695029797092566, 43.69669422026604, 45.97771329264487, 44.043973030582556, 43.44598024122177, 49.27729737374091, 53.308846719803356, 53.53853679472401, 54.859720506975734, 52.263068306830625, 45.620593255566014, 49.13268350785779, 50.3021538642145, 46.35692411853422, 47.70164597419001, 57.15624470864573, 61.02849875727008, 60.92754087140484, 58.45557689666749, 49.40160905161212, 17.81462477099511, 34.35228663106119, 21.49952288596861, 12.93080126085589, 66.09556951830464, 52.56735401768839, 68.0269681253741, 58.341482993095156, 54.28110422626619, 48.33706601973503, 47.58197838260282, 48.57904880277572, 46.818818507655976, 46.746705732037945, 48.064845685035955, 50.72977850514074, 48.72028550794048, 49.08885102118216, 48.53164695924329, 45.78185366046044, 46.287435408561464, 46.12377843549175, 46.200433315769324, 49.11451508921962, 49.84910834220148, 46.00048657386534, 52.58220803353095, 53.18350345857682, 51.63335138751615, 59.057676407598684, 62.59692515096357, 60.518331758437625, 60.59343338012696, 64.07622352723153, 59.10185406284948, 61.71987141332319, 60.25355215995543, 61.932232456822554, 63.78504637748965, 61.25254454151277, 63.65878920401297, 61.92148516255041, 62.0827220332238, 54.18843038620488, 52.666644896230395, 55.46771534027592, 55.48624069459977, 62.78994890951342, 58.23992890696372, 60.27654509390555, 58.274077061683904, 53.85193417149206, 56.762183789284, 58.40991658549155, 43.42811384508687, 27.248938968104703, 9.53942685357986, 4.598883909563865, 3.700184326979422, 2.98615385447779, 0.7040710230508159, 14.57383897996718, 65.31427652605119, 59.310794799558586, 68.98347731559508, 61.23931438692155, 65.58487299949893, 66.79944669046711, 69.3186830705212, 19.509104374916323, 26.582090931553996, 68.10978504919237, 40.566937000520774, 61.79141544526624, 33.93060045857584, 41.76068290587395, 60.50127729292839, 42.79431766079318, 0.3792454530635188, 0.41491242305886367, 0.19507692015219122, 0.19854866208568697, 0.29511425944585956, 0.3209787360843151, 0.23707180704560973, 0.11343242495410866, 0.1458959599896785, 0.21198613539097771, 0.1883121952414513], [0.019961897501601808, 0.06624209829756329, 0.017410070117142414, 0.06681776740738461, 0.1523352047849086, 0.2590554814425207, 0.050407677603464936, 0.11240193710452127, 0.08934878098267703, 0.02119318848746198, 0.06279697408899665, 0.02289244045142926, 0.020294109614746227, 0.14533959629554905, 0.08736439875417179, 0.2344799017713916, 11.758553866417179, 44.18350350472235, 33.62650694385652, 25.158388230108446, 33.51982631990987, 62.039485746814364, 57.51027391802881, 2.8423553512942408, 23.724716824869958, 69.61896404143303, 65.77010693088656, 62.64003199915733, 61.27809093844507, 67.75171187616164, 61.75677699427452, 51.39878972884148, 4.261205100244092, 1.2533670351389916, 0.20084790645107148, 0.3285820668022479, 17.717885394250196, 34.38294779869818, 55.25018853525962, 63.27749559956213, 62.92782806581067, 65.64669739815497, 66.25542179230722, 61.144228289204264, 59.46208061710481, 55.00763308617377, 54.78667420725669, 57.557095250775745, 63.22253927107781, 61.44346198728008, 62.816060127750525, 54.428561810524236, 62.539258464690185, 62.96038373824089, 62.28440246274395, 62.267701010550226, 64.68019400873493, 66.03064644721248, 58.16094021643362, 54.58249522793678, 60.81891082948255, 60.573260630330736, 59.906151756163574, 52.06809120793497, 51.53447235784223, 49.41911458969117, 47.995764901561124, 44.3638030944332, 41.166639943276685, 43.08914653716549, 42.06921262125815, 41.40923461606426, 48.71880677438552, 45.47741889953614, 48.625489665615945, 46.634851501834014, 45.069398264731134, 43.39493451579925, 44.499058185085175, 42.586455575881466, 40.49612645179995, 42.90010790671072, 53.74175087098153, 53.677588739702784, 57.39346573429724, 54.291286699233524, 57.79361809453657, 30.151228135631932, 37.90488320012247, 23.243771483821256, 24.56671634028035, 63.68781866565828, 52.02352131566694, 59.26953538771599, 50.28280481215447, 51.931784922076815, 40.79069252937071, 43.321809768676765, 40.31816067234163, 42.057065040834495, 43.60060399578464, 42.959916207098196, 46.70388913923695, 45.52507569712978, 42.44870978017008, 43.473938895810036, 41.03905700868176, 41.15000124900572, 41.12031675154164, 40.949885845184326, 41.32278557746641, 44.80581891152167, 45.2947501982412, 45.31215375469577, 48.82234165745397, 46.11782427757017, 52.77790292616814, 54.761700476369555, 54.59101069358088, 55.55021455211025, 56.19694279086206, 56.53787520623977, 56.20856477368263, 56.083386252003336, 56.712310852543006, 57.41849830073696, 57.316548055218114, 59.1260943105144, 55.696554260869185, 52.4590063864185, 52.481034417306226, 53.55916453946022, 53.43003226864723, 59.50556401283511, 58.169279175419966, 59.4437906049913, 58.98978802465624, 60.23533275050502, 60.77385064094298, 54.45930927030502, 42.55820666590045, 27.698877972941247, 13.2301212510755, 7.594198949875371, 5.815006446453833, 3.432566648529422, 1.0506422745604669, 0.8779371902346612, 30.556891425963375, 55.2643600586922, 53.0170851369058, 58.54808207481139, 47.06914809442336, 61.45645287729079, 59.34316612059071, 46.7569980313701, 10.990688127856101, 51.073825282435266, 41.115201980836936, 31.360310508358864, 38.71474673671108, 38.58188821423439, 43.22676681703137, 48.216080511769945, 7.667956669484416, 0.30633444447190533, 0.18347994244146734, 0.048529138082578305, 0.17090270926635112, 0.06312331222298165, 0.039334098823488726, 0.07378991062362349, 0.03449282150775675, 0.07344164705324559, 0.04512731699393161, 0.021249193345166503, 0.024042028160164916, 0.046629515822015466, 0.0858191304629849, 0.04396214322637647, 0.12477947414041528, 0.07980029173796216, 0.011359770076289293, 0.12009922850636706, 0.046101198606793924, 0.04913214120953795, 0.0772748522520546, 0.08559369376950687, 0.013765988086590604, 0.09799427473016324, 0.023298696877675194, 0.3154415138546498, 16.89089482830417, 58.613793542308194, 34.17982001458445, 33.501108769447576, 45.28698390530002, 55.90929185190509, 69.3809546193769, 7.9749007667264635, 26.04883686188729, 73.75958273487707, 71.71714182822936, 69.56477257513231, 67.3332969604, 72.26862707445699, 63.52240054838119, 60.94243411094912, 4.795190691947937, 1.953923920950582, 0.7769679049811056, 0.42114151461470517, 21.701724990721672, 43.279809028871604, 59.92032720196632, 62.46831063301333, 64.79455463347897, 69.3027582476216, 68.03102385613226, 64.29670387698759, 61.66518965075093, 58.708193225245324, 57.56887412840321, 60.874506504304954, 63.74692878415508, 64.33866147072085, 65.05254853156306, 57.40968081258959, 66.29099768977012, 64.26087694783365, 63.10475441717333, 62.29349059443321, 67.07210633062547, 65.93370114603351, 59.18784026176699, 58.634095730320105, 63.308490168663766, 62.88858082986648, 60.618046252958244, 52.63739185948526, 54.03077463949881, 51.618689567812034, 51.38419066706012, 49.846872591203265, 44.444168536893784, 44.64220508452385, 44.444843184563425, 42.65139041408416, 49.20289393394224, 49.489493677693034, 51.03453882278935, 50.645737801828695, 47.35903478437855, 47.17100420305806, 49.10904338282924, 44.94640842560799, 45.10517028070266, 46.773016991153845, 54.156721945731874, 56.63590700395646, 62.46599643461166, 53.82332048108501, 66.24632973824778, 54.28921961015271, 39.35071199171005, 28.266431208579775, 37.641017513890425, 70.68243626625308, 56.62413989343951, 61.293909857350016, 54.62874781700873, 59.421154606726866, 47.24525859279018, 46.68591683910739, 43.3658540633417, 45.543095065701394, 46.2215474344069, 44.796679789020175, 45.72307302105812, 48.16870220245854, 44.806254294610795, 46.73030630234749, 43.15323806578114, 44.11068470247331, 42.579803236069225, 43.279899243385564, 44.13750194734143, 46.64143323898316, 45.837700366973884, 47.17797817722444, 50.07489173643051, 48.96647307180589, 55.37575929395614, 56.78949525279384, 56.80163891084733, 59.25175528372488, 58.544457804772165, 57.32517726959721, 59.78668420545517, 57.58003327154345, 57.96023253471621, 60.11600248275265, 57.12836450146091, 58.227079222279215, 57.22204639065651, 56.43003356072211, 55.40291778502926, 54.59146568852087, 56.1158085638477, 61.971911153485706, 60.69097095920194, 60.79717305398757, 60.79512557675762, 61.3337532935604, 61.6809928801752, 56.58599092114357, 47.45598008555751, 33.0113616297322, 16.934203678561797, 7.171212511677896, 6.206023606561846, 4.745511422234197, 2.764706640474258, 1.7470826328762117, 33.349109080529985, 59.597021918143, 57.95484319809945, 62.661346158673695, 52.9136836144232, 66.75866188541536, 64.11464314306936, 49.74607944488526, 14.054007261030137, 52.52435307348929, 47.23311885710686, 26.619922191865985, 49.74485174302132, 42.67321448172293, 45.77482477311165, 59.352748470921675, 8.175303484162978, 0.4976730853799851, 0.19897056202734673, 0.029757068973154794, 0.06934639381905718, 0.095907696372559, 0.054655849648218964, 0.09827737486170185, 0.03440600076329804, 0.046823194340592435, 0.03600683724207263, 0.16146850501818044, 0.12621080217462394, 0.19513990790132554, 0.11180616584756684, 0.15016864684800948, 0.2565537600387489, 0.4480242753221143, 0.20297825907266911, 0.27206751547994157, 0.1274065964765126, 0.10556061872311177, 0.19837639955503328, 0.2979595712836712, 0.1789190686277805, 0.4596730099330026, 0.1862192889975925, 0.6522585355466413, 38.35155487060547, 71.05882690798852, 51.90136301902033, 38.339454358623875, 50.33362304010699, 76.63007520860242, 71.77840140558058, 5.410260010150171, 32.23202786137981, 78.68911558581938, 75.59702488683885, 72.04121589660645, 71.93556293364495, 78.30700612837269, 76.24211357485864, 65.7345663347552, 5.116886823408065, 2.5236993018657934, 0.8765753923404602, 2.113502977355834, 24.550436542880153, 49.382734606342936, 62.26366096927274, 62.943250825328214, 65.79150738254671, 72.13718060524234, 71.68340944474744, 69.21604248785204, 64.89009572613624, 60.95044359084099, 59.11624916138188, 61.6143871122791, 63.434943460649066, 64.10428808581445, 66.15090631669568, 60.74529186371834, 65.805945627151, 66.54020155629804, 67.86028308253135, 65.18564631862026, 71.47287230337821, 69.20431460103681, 61.30048374975882, 58.26469082986155, 63.43126819979761, 66.43207750012799, 65.95086543790757, 55.17673038667249, 57.9126424174155, 52.72975975467313, 52.617195575468, 48.39080641346593, 46.81902247090494, 47.68881197898619, 46.64230792753158, 43.18800595498855, 52.15259082855717, 52.13744263495169, 52.85563253587293, 51.23359518666422, 49.80990817469936, 47.46065947317308, 50.40235473263649, 46.98474261068529, 46.759449512727805, 47.857395448992335, 59.88481798479634, 59.33157943910169, 65.90873133751654, 55.673910417864406, 73.01858425140381, 37.894492841536, 34.71891841580791, 24.895828693143784, 26.354501285860618, 71.90225416614165, 55.66364949749362, 64.94108653837635, 55.286631276530606, 61.24986948505525, 47.79535924234698, 50.38096604808685, 44.60970824764621, 45.62755546262188, 47.94554679624496, 48.41278737591159, 51.96647436388078, 51.73436810893398, 45.35917905069167, 49.588725720682454, 46.99686665688792, 45.50531871857182, 46.13172907983103, 46.298347442380845, 46.61181149944183, 50.19996435411515, 47.45049661205661, 49.34622126240885, 51.55095807967648, 49.38510371792702, 58.41396054913921, 59.382181936694735, 59.35115598863172, 61.29944824403333, 62.067942542414514, 59.36337024934831, 59.26650731794296, 60.127914720965975, 59.812481634078495, 62.36075924288843, 62.51638320184524, 64.24125332986155, 60.45692313101984, 56.86941746742495, 57.91330137560445, 58.68480805427798, 59.35692187278502, 63.47815621283747, 63.82625872089017, 66.27769301014563, 63.32732539023123, 63.85923016455866, 63.765426681887725, 57.78402005472491, 54.25363979031963, 38.10215096319876, 22.882405481030865, 13.446416431857696, 10.301622806056853, 7.368711204298082, 2.9891049477361866, 2.365551787999369, 34.376315070736794, 66.90676273838167, 59.557080422678304, 67.72603604101366, 56.29326051281345, 72.02537736585064, 69.63698341000465, 55.27451115269815, 16.469883303488455, 63.282677050559755, 51.22049054791851, 42.282483654637495, 55.626183017607666, 49.54212404066517, 57.91218742247551, 69.56352526141752, 19.067592582395, 0.7416585448288149, 0.40895225900796156, 0.19561892735861963, 0.5207596046309317, 0.24245905990321792, 0.1463309906783604, 0.23978147535554825, 0.1347132519848885, 0.17254169309331527, 0.16283618646763987, 0.1570199550159516], [0.017691030948152466, 0.0622843693371021, 0.13030011056651994, 0.12485836587485769, 0.1869084770160337, 0.2233802836628691, 0.011095111596307928, 0.03070701608404277, 0.056053339578812166, 0.025739240415033796, 0.01012822628141411, 0.02534458639040109, 0.11855132487272063, 0.05665957176637265, 0.04203935446698339, 0.23409167905488323, 1.455082765990688, 30.95368623733521, 41.6751124781947, 27.407155613745413, 31.19600634421072, 47.32753815189485, 68.39920105472689, 14.235020722112349, 7.534030772024586, 57.260509152566236, 67.69237426019484, 66.87227725982666, 60.255529034522276, 64.1372359952619, 54.29477368631671, 61.04236825819939, 7.811732619039475, 1.9633416543083808, 1.6227648263016057, 0.14388666458187566, 6.451758626968631, 29.007384584796046, 58.394180036360225, 63.4491777420044, 62.61399138358332, 64.74041808036067, 64.89888183532223, 60.62410631487447, 54.48472622902163, 50.42644593023485, 52.98103855502222, 53.1776983507218, 60.74930052603445, 62.54474586056125, 62.50463178080898, 59.60643952892673, 52.96392133159023, 68.74372636118244, 60.26131845289662, 63.61485865808303, 62.33473823916528, 64.70794477770406, 56.42311449973815, 55.54348376489455, 60.470321947528475, 60.76818281604398, 58.03513019315658, 48.663391528591035, 49.37406224589194, 48.76708722883656, 48.789150561055834, 47.47306593002812, 42.16063914760467, 41.91801309585571, 42.8125645268348, 41.34882227067025, 45.89558670597692, 48.421177325710175, 51.5272944204269, 45.84925959187169, 45.5927405049724, 43.60965290377217, 42.058477094096524, 44.711446685175744, 42.894098835606734, 48.127744813119214, 54.9040158333317, 55.22836054525068, 57.39667815546836, 56.69231460940454, 57.720493347414084, 35.22990126763621, 46.86480829792638, 31.932752978417184, 38.06970903950353, 59.19943871036653, 51.81227030292634, 57.80912322382773, 53.08811533835627, 49.928312763091064, 44.29560876661732, 39.95763209558303, 41.75401487658101, 42.25632144558815, 41.97027083366148, 44.26598310470582, 46.215777627883426, 46.19480863694222, 44.57635241170084, 41.36309577572731, 40.30808410336895, 40.327554748904326, 40.18373320179601, 40.39534507259246, 40.86998324240408, 43.271713256835945, 43.370909998493815, 43.10070183969314, 45.96446744857296, 46.886816716963246, 49.985132217407234, 49.516805141202866, 52.99533559430031, 53.97140172220046, 56.0397381167258, 55.451151171038234, 55.85091913900068, 54.969091876860595, 54.2092973955216, 54.528739144725186, 54.07206150793261, 55.199829224617254, 57.159190408645145, 52.84165320857879, 53.86169302848078, 53.32765448477961, 54.55190858533306, 56.18411271802841, 56.77777913308913, 53.92193278958721, 56.06451572910432, 56.711153753342174, 58.21124461389358, 60.496903850186264, 45.3283727553583, 23.51682532218195, 5.5797289552227145, 0.22284275040991847, 0.5907340143476764, 1.1256050198308885, 1.564581980628352, 6.1782051767072375, 48.05884445867231, 52.28022867633451, 55.74239107870287, 48.211052033209036, 61.978547803817264, 56.270408784189534, 64.52843358439785, 21.463501799491144, 23.030820123610958, 52.65984742872177, 31.32701546915116, 35.08003142572219, 37.443392815128455, 48.224819552513864, 47.227133320223906, 40.94216269831504, 0.940695848436125, 0.13746825737818597, 0.048687672317628904, 0.01901572337374091, 0.1555033001087366, 0.045657687324790225, 0.045064202840289766, 0.024127243950422254, 0.06390440397925916, 0.02101280159437128, 0.08463683463032208, 0.09661579144097145, 0.06670481540382871, 0.04981229322091226, 0.030440337047161117, 0.10475374427774262, 0.0772947169119312, 0.07257003817827472, 0.05360247492189369, 0.035064085612013456, 0.05787225830699167, 0.07059736943413174, 0.03951445124262283, 0.010803119099188236, 0.041051633475768956, 0.09660051564776129, 0.07627536031988359, 0.022747282111536593, 4.57206666469574, 45.040376647826164, 45.68270006487447, 33.21382261091663, 43.29077989824357, 53.49721854732883, 70.13164920191612, 17.43018542566607, 10.896947403107921, 58.0766837827621, 75.88231455895209, 70.49802995497181, 68.55145177533551, 69.9244539199337, 59.957083732851096, 68.10736886916622, 9.256943637324918, 3.5186756666629546, 5.273694357564373, 0.15122713521122932, 7.4729736870335, 33.82303730134041, 63.946561736445275, 63.036305135296246, 65.86316908559492, 66.45101470331993, 67.37124196944698, 62.95727329869425, 58.084344171708636, 54.74217491765177, 55.06613131492369, 55.43534794161397, 62.96650263570971, 63.52773889418572, 65.5604915465078, 60.01675475028254, 57.782109860450994, 69.22771546148485, 59.704690979373076, 67.23603786960726, 63.361100919785045, 65.27555881008026, 58.14830626210859, 61.80116645751461, 60.88444186795143, 63.14692774126607, 58.9750869812504, 50.24082760657034, 52.61073150942403, 50.16511017276395, 49.41576880793418, 48.750695643886445, 44.18329561910322, 46.12932858928558, 44.7021310560165, 45.22583023194344, 50.191884271560184, 49.77580708842124, 52.263495845179406, 48.25597493879257, 45.93936820184031, 46.347632023596, 46.204587105781805, 47.07494535753804, 46.14114669061477, 50.21313175078362, 57.57584810256959, 58.8574041089704, 60.232316447842514, 60.17342205970519, 62.32465382545226, 61.61519904290477, 56.03565492937642, 38.88960207662275, 60.00183013177688, 61.93625288624918, 58.416325738353116, 57.87070051316292, 60.00528573989869, 54.29147497300179, 49.747377749412294, 45.37400168757285, 45.27849197387696, 44.07282990794028, 45.29222419185024, 45.727258190031975, 47.5044095900751, 47.05578850161645, 47.44779802137806, 43.64374614530995, 43.37152581061087, 43.01139339323967, 42.25700393799813, 41.987250774137436, 44.832302754925145, 44.16831216504497, 48.34757404942667, 45.57376407807874, 48.082496350811375, 47.53051296357186, 50.35009699483072, 50.96518347340246, 54.615596109820956, 56.95566254277384, 56.87225726342971, 58.87557252760857, 57.13911571810323, 57.23430771981516, 57.86973953247071, 58.5370994383289, 57.36321249315816, 57.887735366821296, 58.79768602309689, 56.29089924596972, 56.411586653801706, 56.837516830813506, 57.340203869727354, 57.92718264364428, 58.73892107317525, 57.03761654515421, 58.94435128858013, 60.1831966061746, 59.736407264586425, 63.64136603570754, 47.92628795869889, 28.426393308947166, 6.06255115039887, 0.36261089566734533, 0.5236268572268948, 2.371652299357999, 3.969325601093231, 6.858963408777791, 54.610069490248165, 60.582336994909475, 58.31248491041122, 54.024094843095355, 68.51125532580961, 62.85264799671789, 68.67749321845271, 24.80545924555871, 25.044343356163274, 55.152760782549464, 38.851104013381466, 36.01993722300376, 51.43064721938103, 43.74588074222688, 50.982449746901, 46.04682153271091, 1.7179947034005196, 0.08444799395698695, 0.021506838290201082, 0.03505021559014436, 0.13344520793086098, 0.013776580209753687, 0.08056185208261013, 0.0015026241265830675, 0.053218668702268795, 0.06832550505116101, 0.05510632849989399, 0.03363155098932405, 0.14244214451361087, 0.15076547530629944, 0.19210079114042944, 0.19308585763698627, 0.24068227218043423, 0.3003664356806586, 0.2549673911304243, 0.1566593574299928, 0.17517879755506593, 0.16399621212434384, 0.2241067495197058, 0.15904987351067607, 0.22217211704100334, 0.39955701799161975, 0.3754877611514061, 0.8309807195778817, 15.854920379577147, 64.40826000705843, 66.06988583841633, 45.50209060792, 49.41166993110411, 65.15950372142177, 80.13430503106888, 19.26425826164984, 12.169912438238821, 63.19369023846042, 83.64422229028519, 76.24153306407314, 71.95286058610486, 78.61131929582166, 65.37661083282964, 74.05718864933138, 10.726998948281812, 5.343142863242857, 7.139418269357375, 0.3607664317373307, 10.104303071575782, 42.764880272649954, 64.4531907573823, 61.57623421761298, 67.15096950531006, 69.99574692018571, 72.0147712769047, 64.9827068082748, 60.2071544431871, 56.50043226057484, 57.06036236978347, 57.270852442710634, 62.29689521174278, 66.07136849434146, 67.46073476729855, 65.66743104688584, 59.036605435033, 68.26766044862809, 63.98053730687788, 68.84974802694013, 64.32174428816765, 68.19676753013366, 62.11715259859639, 57.938812471205196, 64.3329858010815, 66.06426115958922, 61.44082615452429, 51.616089036387784, 54.46750702396516, 52.859598052117136, 54.778229344275694, 51.04932223596881, 45.74506182824412, 46.77521351845034, 46.15239212589879, 46.091128626177394, 53.429298785425004, 52.04017177704842, 56.2907031274611, 48.44915951451948, 47.17487558241814, 48.99439642506261, 47.335567243637584, 49.31323020688949, 48.309358396837794, 53.19443902661724, 61.23767091381935, 61.755031539547836, 64.59834591034921, 61.382112195414884, 61.98689460754395, 54.88462755756994, 54.59276791541807, 32.8387341960784, 48.8160893993993, 64.28167727685744, 57.60272418299029, 62.833032223486136, 61.39828805000552, 56.89859597913681, 52.46032822516657, 45.93375529012373, 46.067253158938506, 47.36618918757285, 48.40255391213202, 49.2033959973243, 50.416804744351296, 51.00827463211552, 49.936781160293094, 45.57128121775966, 44.690779716737815, 45.371962055083245, 44.794377357729026, 45.68403759310323, 46.00094156880533, 46.73092995920489, 48.58914106122909, 46.3623958249246, 48.03758128996819, 49.73249627697853, 54.30889421893705, 51.3673048634683, 55.65586359270158, 59.37261527584445, 60.55169543912334, 60.753932845207956, 61.855518740992395, 59.39419223416237, 61.20323250370642, 60.498386506111395, 58.752880788618526, 61.39363611898115, 61.63872934156849, 58.95543590668709, 60.35711057724492, 59.93092544617192, 59.36899885054558, 60.27239914863341, 61.432291077029326, 58.23672040816277, 61.71255619295182, 61.38266917197936, 64.31346416473389, 65.23217739597445, 52.10970755546324, 34.23133250205748, 8.791799564515392, 1.2813357408008268, 1.2240171648802296, 2.0965384812124315, 3.821754268100185, 8.301592526897307, 57.84925691543087, 63.23099590116932, 61.80284523194837, 57.562445363690784, 71.2020169534991, 66.41986323941138, 73.89846601793843, 29.205354452133182, 29.041719052099413, 63.7829989002597, 37.85049169294296, 48.907919929873565, 52.22977130643783, 57.6569313387717, 56.80461991217829, 66.71986964441115, 3.8590640983273907, 0.3247758049157358, 0.30313857079994294, 0.18381901295675387, 0.2688155948154388, 0.14206175121568865, 0.37187075362570826, 0.14947510745015838, 0.1301474598867278, 0.2052005422451804, 0.13273145913356735, 0.12480252572605688], [0.005297013445787373, 0.05056197537229427, 0.04580683698276839, 0.01985185088649873, 0.07092030613773292, 0.07025783926609062, 0.03533929503793198, 0.07710617501288652, 0.10789741671854451, 0.0275730844511981, 0.16166615570264478, 0.041631562034449274, 0.03230961264982339, 0.04962773114863423, 0.007528736736745604, 0.09791322262777437, 0.548603713752762, 18.809914435109786, 37.92039617415398, 34.009840180796964, 29.052256499567342, 28.65938601955291, 66.67098906732375, 58.36097325048139, 8.927979353935488, 50.43218043542678, 69.98091251619401, 64.73211834507605, 61.67894932531542, 61.89399327001264, 56.61624023991247, 69.82273117188485, 10.550478562231987, 3.9515986942475845, 0.5526295977254068, 0.9472351136707491, 2.2249218244706435, 19.243199056194676, 56.56093874285298, 63.058972512522054, 63.24394364510814, 68.26436565768334, 63.73992343102733, 63.672293924516254, 57.07453781558622, 49.07302033516669, 50.164035443336736, 48.732397787032596, 55.51917683693671, 63.67188599801833, 63.964071196894494, 65.26354851261263, 56.19915893000942, 56.72235604255431, 70.71663148941533, 59.40976012137629, 62.1827934634301, 57.15625647575625, 59.994271724454826, 62.01649281286425, 57.211020608102125, 56.3469656052128, 53.83466397562335, 47.4342187758415, 48.09403204148816, 50.546344941662205, 46.381815479647734, 45.21677347921556, 43.57268064252792, 41.729386314269036, 41.24293788786858, 43.170041499599336, 46.01120641154628, 48.167050884615996, 49.700791758875695, 44.4890796753668, 44.83188698368688, 40.56247334326468, 43.97105224670903, 41.83661607003982, 42.76170315281038, 50.66343161367601, 55.9749327167388, 56.23948089538082, 56.34154488963466, 55.51125364918863, 57.27324901088592, 50.076252798880304, 48.89929856023481, 41.98294008931806, 46.729055066262525, 59.2957603546881, 51.86674417987947, 54.047095621785815, 53.19882815884006, 50.111393313254084, 43.84820753528226, 41.84181321051813, 42.6997414711983, 44.19491367955362, 41.400726995160504, 43.06558093717022, 43.68916719190536, 46.19671883121614, 45.51635626823672, 44.11672907490885, 42.59521422847625, 41.67323758525234, 40.12284232724098, 39.63920231788389, 40.98296711521764, 42.62431037041449, 44.127876450938565, 43.316463578131895, 44.23627115065052, 45.70734431666713, 44.79603259794174, 47.298147832193685, 49.13304044354347, 52.36817998270835, 53.27565954577539, 54.835833272626324, 56.6134161333884, 55.87990937694427, 55.065613562060946, 56.56506115390409, 57.35082957052416, 57.39962385546777, 57.235119650440836, 55.34110907585391, 53.380947728310865, 53.007016412673465, 57.03126230547505, 57.256269070409964, 56.113341393009314, 53.50563987608879, 53.497042040671076, 55.258735379865094, 57.836038527950166, 59.25637975815804, 55.38361187904112, 27.687791393649196, 5.0987184047698975, 0.4006313796966307, 1.7474393234137566, 1.6920704106169364, 2.157450928803413, 6.603729878702472, 50.07692352417977, 55.02345200507872, 48.783478813786665, 42.75064599129462, 48.37799203011298, 58.24996232986451, 51.75064986751926, 18.52236351659221, 39.449881276776715, 55.631019300030125, 27.473455436768074, 38.097702995423354, 42.50787481184929, 33.69474049537413, 55.98669982725575, 23.1522233639994, 0.15534255954046405, 0.04494227994714053, 0.14494832454910203, 0.06979472379410459, 0.016393622743987268, 0.016589019214734435, 0.01603282118711861, 0.10693441355420698, 0.07516158339116844, 0.12360450976918783, 0.04029356266161607, 0.06131313455801818, 0.019131268584920515, 0.05227527738879285, 0.003135878214379773, 0.01157653944251398, 0.05236321662162101, 0.04769236322552447, 0.0494271157039029, 0.005022056828883867, 0.0895809745716472, 0.027565021375795046, 0.17909424229254647, 0.04428262461818034, 0.04183583554901904, 0.035741020054105795, 0.13174078487340482, 0.0433309480638033, 1.187964576867319, 30.485245412395848, 48.16153995452389, 32.51280680779488, 40.354572034651234, 34.73243490342171, 68.73308889327511, 55.33217783897154, 12.573538057265743, 53.86308154752178, 76.1251014278781, 72.11816495464694, 70.0041643265755, 70.79845997595018, 60.424359613849276, 76.00048772750363, 11.450084947770643, 3.332055667715688, 3.463736008251867, 0.4066002465063526, 3.0456329209189263, 24.257557084483487, 61.87445594418434, 66.54974860529747, 64.85891288326633, 71.0080792826991, 65.96759042432232, 65.80900899825558, 59.42491223735195, 53.32664643564532, 51.28873194417646, 51.97039281168292, 55.77598225685858, 66.8219610952562, 64.2753230371783, 65.83270795883672, 57.60202992346979, 60.516656906374045, 71.30632062112132, 61.04814590946321, 65.16100598919776, 58.80502477768929, 63.366431420849224, 64.72209276691561, 59.893992408629394, 58.73460254361553, 54.63552175029632, 50.63835982353457, 49.486214576228974, 50.962076956225985, 49.61765712307346, 46.265168113093225, 47.55703603067706, 45.658812830525065, 44.791796438155636, 47.2708010673523, 48.0594838050104, 50.21079794053109, 51.452314392212905, 47.54553564133183, 46.814613726831254, 45.61457241735151, 47.65790762439851, 47.169160689077074, 44.52805234539894, 53.24081320916453, 58.16862806197136, 59.75879223115983, 56.07668292137885, 57.45919289127473, 59.01791141879175, 62.756871561850275, 54.40403915220692, 56.51373694019934, 63.97905857332292, 60.000622041763805, 59.49636213241085, 56.712255939360595, 57.29715585708619, 52.849690145061864, 49.58689005144181, 44.03794434762771, 47.06854404941682, 45.582918890060924, 44.0583053711922, 44.28333174797797, 45.8501656593815, 48.06833659448932, 48.33548922692576, 47.057914426249845, 45.70078611373902, 43.393695046824796, 42.44926283436437, 43.44968295866444, 43.627652660492934, 44.155529160653394, 47.80593787470172, 44.961180071676935, 44.234611988067634, 46.11347829141925, 46.67536958571404, 48.32351815315985, 51.861111656312026, 56.21812751216274, 54.28582675995366, 57.14210848654471, 57.2756887251331, 58.227455769815755, 58.02265705600862, 58.10881191684354, 57.00346054569368, 58.96736383438111, 58.85044190191454, 56.974474230120265, 57.31976439875942, 57.578150533860736, 59.633503883115715, 59.24550694804038, 57.21047932101835, 56.390299950876546, 54.140765743870894, 58.63550778358214, 59.64975426273962, 61.92581938159082, 58.46402960438883, 35.11667028550179, 7.480393830806979, 0.5265522099310352, 0.8561130613088609, 0.6989872022982567, 1.4683199073037794, 8.220123917825761, 51.9523302970394, 60.92218291374945, 53.33575810155561, 48.15259302816084, 52.078261913791785, 65.3268438000833, 54.85719450058476, 23.182500139359508, 41.67510463345436, 63.14390751623339, 26.249470018571426, 42.81635745879143, 49.699167897624356, 29.431600686042543, 66.48727309319281, 23.873104010858846, 0.2262524392215475, 0.06320961585809147, 0.10140993136672244, 0.06348539984995319, 0.04092055583192457, 0.044089727509286136, 0.014735859229169307, 0.014601534330135873, 0.0587536845987122, 0.08876153628431982, 0.026940391586732962, 0.06240982006514265, 0.06892244076176036, 0.19980642523977066, 0.09211028280157237, 0.09464304608803603, 0.20155863686194345, 0.13782451890649336, 0.15980157430373854, 0.13566061163381224, 0.22414669334407777, 0.21084333139081157, 0.302651921106923, 0.12036746653217463, 0.13929264980458445, 0.21771316356476278, 0.1483464913983499, 0.19613235948547242, 1.9181760520704332, 52.50886363367881, 63.45512013281546, 55.72291651079732, 44.473064637953236, 42.14589495812693, 79.19260671061855, 73.1599307829334, 13.360029170590064, 58.04237481086486, 81.64517848722397, 79.84898397999426, 72.5139791734757, 73.90889167785645, 66.93337209763067, 82.13513743492865, 14.661474535542151, 6.559016819923155, 5.8525224462632215, 1.490085261964029, 4.74583060510697, 31.13967718616609, 66.18532903732793, 66.9631193530175, 66.72973048302435, 74.03900454121252, 69.119732610641, 69.44435581084221, 61.74252702343849, 53.88645102900844, 51.54754169525639, 53.89512338945943, 59.48711318354453, 68.57639804963144, 67.87402706761515, 69.46370094053208, 61.27718094856509, 62.37642911172683, 71.36416773642264, 65.08572786085068, 65.74075975725728, 62.26849725169521, 63.0798787455405, 66.53497695922852, 61.34786205907022, 61.3743459024737, 57.449485025098255, 50.423119760328724, 53.133936466709265, 54.12504880659042, 50.967462370472575, 49.23349234365648, 50.65404538185366, 47.959298626069106, 46.18104896237774, 50.24721714758104, 48.89773353453606, 52.12042347077401, 51.9587355275308, 50.072526547216604, 49.95965250076787, 44.298279900704664, 49.67953251254175, 46.979914173003166, 46.57410183260518, 56.59059186135569, 59.33607447531916, 62.76572042895902, 57.593667430262414, 60.69148478969451, 61.92025746068647, 66.49187011103477, 56.569544423011045, 48.509799357383486, 61.54451008765929, 68.09678631444132, 58.310959108414195, 58.91732615809287, 59.96937251860096, 58.392132559130275, 51.71679981293217, 47.01256398231753, 47.61793474997244, 50.6625686922381, 44.99891327273461, 48.070905746952185, 47.49885943628127, 50.86548074599236, 50.019092098359145, 49.165733398929724, 46.60603777054818, 46.46029033968526, 45.27011771355906, 45.28446182127922, 46.214412643063454, 46.43393201212729, 50.107749431364, 45.784465958995206, 46.18880348820841, 46.893818147720836, 49.4305012303014, 49.58805499538299, 53.430561788620494, 59.05997099414949, 57.265533708756976, 58.235610377404, 59.93553815349456, 62.20425667301301, 59.38927358196628, 61.88814893845589, 61.2221069489756, 62.029342497548754, 62.596128909818596, 60.68553063177294, 60.018221716726984, 60.646020597027196, 61.2526818244688, 63.41433925013389, 61.454809404188595, 60.957460711079264, 58.116405625497144, 61.111476498265425, 63.39558639834004, 63.927804962281265, 60.383967045814764, 37.997580574404815, 9.96452646870767, 1.1521894965440997, 4.841939951142957, 5.67861435874816, 6.060113397336775, 12.11523557862928, 57.33452427771784, 66.31118220667686, 56.496125498125636, 53.51379056130686, 59.60791041774135, 68.56600376867479, 60.56598071129092, 25.246292468040224, 50.54426608547088, 66.30597329908802, 33.04850255289386, 54.106425393012266, 55.746721375373106, 44.52285520492062, 73.46973526862361, 41.67202557286909, 0.3594114367038973, 0.17427533474420348, 0.3089089901937593, 0.15214414245659305, 0.12678647128444526, 0.12806961493146035, 0.13523937052776738, 0.1902973282361223, 0.15467102218779827, 0.20749612471028683, 0.17110160101325284, 0.1500659910661559], [0.040416611704014005, 0.03157281418210797, 0.055890136037863074, 0.05009971025790419, 0.08468674525858895, 0.05785121387171169, 0.11048563710984685, 0.008550620461333423, 0.09703163928802937, 0.022035737732245077, 0.03721403093227456, 0.02077209293812273, 0.03732908584718262, 0.01694662714256875, 0.04720913794552607, 0.07396043413468907, 0.22014299527772013, 5.3774479127699335, 35.18919883235809, 39.66785915436284, 33.549373534417924, 30.005745464755645, 43.41664483470302, 68.3340661756454, 15.876303180571526, 39.59713097541563, 68.58124609916442, 68.07785695598972, 61.811411688404704, 67.23901887093821, 58.92300967247256, 65.55606711295344, 17.216259356467955, 2.1971698297608286, 5.405300173067278, 0.4920017977635707, 0.9814929721816894, 14.3620898262147, 54.70610872391732, 67.92450797173285, 66.84645237461214, 65.13470649719238, 68.06103783269083, 64.44472628255045, 61.10629896963797, 54.086099670779326, 50.15807344067482, 47.65740948338663, 50.10861627517208, 51.93557785403345, 61.00886729455764, 64.16941904252576, 61.89623686575121, 53.429420378900346, 54.70061348330591, 65.12150772156255, 59.03763309601815, 64.28789031121039, 61.695760603873964, 59.691519660334436, 57.23246028346401, 55.08808874314832, 49.6944296744562, 48.71062078783589, 46.63716177786551, 47.82685195246051, 47.62867027713407, 43.75862844528691, 42.46551713635845, 44.00934242433117, 41.83842820505942, 45.8226933786946, 47.572396032271854, 49.41799671419206, 48.32302393451814, 44.83009446051813, 43.48035981578212, 42.68651523897725, 42.69994151207709, 43.40194379129718, 46.518521847263465, 53.23497672234812, 57.30565955561977, 55.612384119341456, 56.04119331605973, 56.66707807971586, 55.55231694252261, 53.078458462992025, 52.01137765761345, 46.48971988308815, 53.329246967069565, 54.56643704445132, 52.57023695976504, 54.767544807926306, 51.25116348266602, 49.7990353645817, 43.84561092622819, 43.01005978738108, 41.70967248178298, 41.79577242943549, 42.579642418892156, 43.20697061477169, 43.21538409879131, 45.68978778777584, 45.74511281905636, 42.64709541874547, 42.06680428597235, 41.60436076502646, 40.286875847847234, 39.65904166621547, 41.20365535059283, 41.13505309627902, 41.29750590170584, 41.62799304531467, 43.323594447105165, 44.731109526849565, 44.09597189195695, 45.161162114912464, 48.881483154912154, 51.35530633311118, 49.24201173167075, 53.91446459677912, 55.1136939756332, 54.61408599730461, 55.6604370763225, 55.87498680237801, 56.2630464953761, 58.928508835454146, 56.59695394577519, 56.17030989739203, 52.59004492913523, 57.74007381931428, 55.13541213927731, 57.20245022927561, 51.05784554635325, 51.031695104414425, 49.534902957177934, 55.39232738556401, 58.92995226767756, 59.84892829771965, 61.9796617569462, 50.52379523554156, 11.688835697789347, 0.32864390541949584, 0.2537152204181879, 3.797389730330437, 2.634192469619936, 10.474190423565528, 43.420363241626376, 58.20491390843546, 55.976737007018066, 48.26596129325129, 59.83024997095908, 64.32826718976422, 45.8014694336922, 24.937299912975682, 48.620421963353316, 40.97954288605721, 27.86087774461316, 38.22008094479961, 25.420977184849402, 37.69278103305448, 54.18059741297076, 5.217786854313267, 0.3310232519382431, 0.13443647973960446, 0.05990605703705262, 0.19655479568867915, 0.05763156114206199, 0.10715710765291607, 0.0433891860678071, 0.04208518567705347, 0.0616902873040207, 0.03775167909841384, 0.03534695591717478, 0.1356362653595786, 0.013081968288808582, 0.012072754700878456, 0.05348304181449837, 0.04792008286101684, 0.04346504026362973, 0.022454343495830413, 0.02967320149764419, 0.04503146407284564, 0.08246534308719058, 0.07084447109410841, 0.12429112373220345, 0.015102146933185718, 0.022079104054418784, 0.0649065159321312, 0.08151193134366505, 0.06979688416205107, 0.24413326845294048, 8.324149097165755, 52.6319593767966, 39.67758663239018, 44.30150016661614, 39.700846287512014, 41.647020463020574, 65.49584696369787, 17.065771741251794, 45.0672919519486, 72.85811224291402, 75.12863897508191, 68.56023788452148, 72.40867922382971, 62.07221400353217, 73.6736043806999, 19.825565122788955, 1.887044200012761, 1.7555417144490828, 0.6149032303402501, 1.117554109904074, 17.01575367681442, 58.756128511121204, 70.4742996154293, 69.57453143212103, 68.90778341600972, 69.9163189241963, 67.13561734845563, 63.997799658006244, 55.83752032249205, 52.745927764523415, 51.506474479552246, 50.78268343402494, 55.06328759654876, 63.97304557984876, 66.71638657969814, 63.615996145433, 54.95774838232226, 59.36371541792347, 66.03383141179239, 59.86388429518669, 65.0247153928203, 66.99042689415717, 60.11350785532306, 58.46088386351063, 54.6837394468246, 51.78684157709922, 51.145133972167976, 50.300314272603686, 50.04677618703535, 50.764467946944706, 45.11870638016732, 46.779688942816954, 46.00892751447616, 43.74189953650198, 49.24357675736951, 49.10820791798253, 51.93376179664366, 49.922574335528964, 48.439702680034024, 45.90461992448377, 46.49852560412499, 47.60019779205323, 47.31345292060606, 50.04536413377332, 55.3988895108623, 60.474244317700794, 59.596366882324226, 59.14538060465167, 58.586584060422844, 59.86249185377552, 61.97351148051601, 55.97192033644646, 59.396353460127315, 62.35272230640535, 55.77638233861616, 56.44742535006616, 57.387072270916356, 56.81306869752946, 52.845532432679214, 46.625586863487, 47.67791955701767, 47.4144539525432, 47.081927176444765, 45.08481317950834, 44.12913553176388, 44.84163407356509, 48.200893094462735, 47.12642254367952, 43.76783032571116, 45.80761186538204, 42.553044826753684, 43.636925143580285, 43.40211637558476, 45.35035764017413, 42.79832240073912, 44.22732814665764, 44.25896206209737, 44.83908061058291, 46.392013642095755, 46.019533603422104, 45.26374778439922, 51.699717890831735, 52.3770563064083, 54.44595359986829, 56.436725124236084, 56.53513346948932, 57.663724883910156, 58.38980659361809, 58.53630319718392, 58.979766368865974, 61.7270258165175, 59.499915799786976, 59.129914699062226, 57.13231432822443, 59.7282918806999, 57.54669704744893, 59.16816173061248, 55.23784483632734, 53.69673382851386, 53.371161414730935, 58.43084635273103, 60.691912328043294, 63.82396805670954, 65.19247124272009, 56.239367146645826, 16.04226846848765, 0.5002043624558757, 0.3276851617040173, 2.1613186309414525, 1.653989221780531, 14.144926821031879, 47.74732197484663, 62.13250867782101, 58.159798806713475, 53.78309265259774, 64.67962134268977, 69.13208807668379, 49.84360525684972, 29.25196005452064, 50.63260570649178, 49.45743222390452, 27.378896897838963, 49.65797516607469, 27.37802613166071, 39.96959924697876, 63.56413848938481, 4.300871049204181, 0.16408032857842986, 0.07608925458043814, 0.016213998108381228, 0.025759455560135747, 0.04337319015194813, 0.07647871835938386, 0.061691574331733494, 0.022675729499408798, 0.11621524699993672, 0.09399955521427816, 0.02267448460653184, 0.06896436875385624, 0.1074504120756061, 0.1679447825036703, 0.13236830281394144, 0.10668610913618919, 0.22313116719165157, 0.0957230691828074, 0.27697320546834703, 0.132625371277813, 0.24348874336048482, 0.14750120530445732, 0.20590554231837874, 0.22161730084448095, 0.12385712726221931, 0.19305838572402156, 0.27359261267608215, 0.2339898200044709, 0.5280979302140975, 20.765502299031905, 69.86033101235667, 63.73700126524895, 52.25527063492806, 45.92529866003221, 55.74470135473437, 79.9557508960847, 19.62859545984576, 48.93397623492826, 80.09644631416568, 80.22297413118424, 73.6804057705787, 77.71493219560193, 66.87721160150343, 79.56028184583111, 22.31306560577885, 3.3530094594724718, 14.153861980284415, 1.8659907555387867, 2.3896410244126476, 22.697934450641757, 64.370942577239, 72.99109628123622, 70.01288767783873, 70.73843202283307, 73.53921613385602, 71.08949984273603, 67.62224228151383, 58.9319448317251, 57.08053904194986, 54.606398151766875, 54.14058923721314, 56.98180121760215, 67.0049161295737, 70.16350669245567, 66.64965137358635, 60.65172764562792, 61.176372112766394, 66.20521545410156, 64.15033671163744, 67.87982433072983, 65.52019311535743, 61.82109994273033, 60.04587442644181, 57.22789464458343, 53.63547032879245, 52.645358193305235, 51.12575354114656, 52.406815328905665, 54.26313192613664, 50.16611037715789, 48.33150409883069, 48.2128994695602, 45.03828210215415, 54.623817397702126, 51.21505414285968, 53.24413937907065, 51.709861140097345, 49.752104205469934, 49.321761362014286, 48.78533801724834, 48.13649169860348, 49.026175468198716, 53.874872192259765, 57.47178369952787, 62.820017799254394, 62.366595729704834, 60.914495068211714, 62.33427932185512, 62.63115959782755, 62.56863309491066, 56.99666700055523, 56.69717834841821, 65.34330206532633, 59.43175677330264, 57.92991653565438, 60.487988302784586, 57.94302509677026, 55.99618804070258, 48.766808740554325, 50.78958288315804, 48.62447769411149, 49.739882100013, 48.528967980415594, 48.39348146992345, 46.94074146209225, 50.340553868201475, 50.39738116725799, 47.75881059708134, 46.85927775598342, 46.767258951740885, 45.89642217082363, 45.11297579734556, 47.661535816807906, 47.58015840284286, 47.72678052225421, 46.33531578125493, 46.501408546201645, 48.34999807419316, 47.77594743236419, 48.616197570677734, 53.68710048737065, 58.243070725471746, 55.79479394420501, 57.39499153629426, 59.69862699508668, 59.84035791889314, 60.100089426963564, 59.6683031512845, 62.49433948147682, 64.23062762906476, 63.14890461583292, 62.70286836931783, 60.68125524828511, 62.19911444571711, 60.13199006357501, 61.51086007395099, 59.56372884012038, 56.48579789746193, 57.16724695697908, 60.268865093108154, 65.13318069519536, 64.78067336543914, 67.4784246567757, 56.7703305521319, 18.180354410602202, 0.8987633210997429, 1.269975085892985, 9.892652957670151, 5.229146038332294, 16.650153475423014, 53.39809240833406, 68.22092148565477, 64.750486804593, 57.19651960557508, 71.49880701495756, 74.34472191718318, 56.20004538566836, 32.64609482980544, 60.339303016662605, 49.17830851770217, 39.23238977309197, 54.320151421331595, 38.2213008019232, 51.0445055653972, 75.79848566362935, 14.131371109716355, 0.7000086732929753, 0.376594084044618, 0.19447659833296654, 0.49452703806661796, 0.13567271582301588, 0.19387569428691942, 0.15653534311681025, 0.12162596513066562, 0.23101159191179663, 0.19261039282766082, 0.13107539154589176, 0.260123101573798], [0.03713784731864449, 0.04739042882236743, 0.008957924512815813, 0.048722333965762976, 0.02306040139838813, 0.1298280625093368, 0.010679184267627857, 0.04031458028381871, 0.05572449250687515, 0.035453767726017583, 0.0572067002705749, 0.07009414925930962, 0.04906759830191732, 0.1151303975512424, 0.0855616253289965, 0.07599089655183977, 0.17447477807441067, 2.3392000794410706, 17.044898848379813, 34.38090032146823, 29.32593595597052, 29.653181260631932, 36.1735019376201, 83.75845739918371, 34.67380331408593, 25.23863600146386, 69.36194681352185, 64.62728515748056, 61.47742579060217, 67.48292753773352, 64.88746773812079, 64.5235227769421, 22.08597606228244, 0.595870541949426, 3.598803805728113, 0.593502594818992, 1.177494299988593, 15.402030771778477, 55.16677933354532, 68.47338091942572, 68.7537205603815, 68.66111340061312, 67.54821931162189, 66.03037188130041, 63.26144918318718, 54.986354227988954, 50.294877867544855, 49.343055909679784, 47.471081210720925, 50.31681960628879, 49.03362797152612, 58.541319908634314, 59.306570406883, 63.917983347369784, 58.89501963892291, 58.647592606083045, 59.43233728408814, 61.39582087916713, 55.92419685855989, 55.37735177624611, 53.228677395851385, 51.90260641036495, 48.47973046764251, 48.97785579004596, 45.06024345274895, 44.86944367808681, 43.645985818678334, 44.90661205783967, 45.95267680383498, 42.2741799969827, 43.264209762696304, 45.76110824461907, 46.763995539757516, 49.05424002678164, 49.21648102421915, 44.28734433266425, 43.832745552062995, 42.928701985266905, 42.63099408918812, 42.80209572084489, 48.9224091652901, 53.88059493034117, 57.295932077592425, 56.95719618951121, 57.112455368042, 56.17021968287807, 57.86618978746476, 57.028944184703214, 51.747119734364176, 50.91922506209343, 56.46465239986297, 54.71178439355666, 54.78759988661736, 56.14614809713056, 54.22107235077889, 51.32332332672612, 44.76361420846755, 41.87237631890082, 41.911674545657256, 39.61805682028494, 42.40928603756813, 42.6829654939713, 41.753720698818086, 43.18663312542824, 48.54683437655049, 43.60600117714175, 41.89898960051998, 42.01732358624859, 40.16999706145256, 41.98221837320636, 41.30922986615089, 41.67744628844723, 42.197678089141846, 43.141620005330736, 42.064949004880845, 44.69151712233021, 44.36432476966612, 42.242353885404526, 44.37865318790559, 46.58228389678463, 49.643615368873846, 50.6314133059594, 52.627778130192915, 54.77509929287819, 55.59956581361833, 55.04221270161291, 56.18819590537779, 57.722329016654726, 56.6106116387152, 54.29901769084316, 54.63595321101528, 60.14065850165583, 54.5758193539035, 55.36392942551644, 52.13665816091722, 49.586693932933194, 49.63237385595999, 53.5187445148345, 56.84782874199652, 61.18955519891555, 63.13429770931121, 62.46346258348035, 36.024079245905725, 1.1532386079911263, 0.1350365104454179, 0.4541673811693346, 0.3860318276189989, 8.106176122542351, 39.15837072557019, 55.19290231889295, 52.1018785045993, 57.69478221093455, 61.620023558216715, 58.03171773110667, 33.662777100839925, 38.45021816991991, 58.6984775143285, 22.042161226272587, 32.45186886479778, 31.68682036861297, 26.377168663086433, 53.98662836320939, 34.188884612052675, 0.4361390034037252, 0.06675647271256294, 0.14715404490069037, 0.03194958005370873, 0.0437202854382415, 0.027101951869084474, 0.03500602763867186, 0.05326475272135389, 0.1031602047864468, 0.05659035189197429, 0.02873188436722323, 0.040231375474362605, 0.036026897254369916, 0.049569098609349424, 0.02421722480756862, 0.06841360516245328, 0.03986006797922235, 0.03565645543858409, 0.04809763139834808, 0.0317137073274822, 0.07110232862854196, 0.039299215009856614, 0.03978269692930964, 0.08888188869722428, 0.015635186122850548, 0.024203567375098507, 0.05079764317000105, 0.14164480020201978, 0.07750405809812008, 0.14070652635587802, 2.5237811813431406, 26.96886997069082, 43.86453243993944, 33.11323735021776, 43.71554905368436, 42.58529063194029, 83.54745741813414, 35.980721366020944, 29.333453178405765, 75.9511443107359, 71.00452561532298, 68.22025468272548, 72.74058234307074, 71.27059567359187, 69.97549964535621, 27.619408792065038, 0.9097761108029274, 0.7063309211404093, 0.6270566943191713, 1.1957783059727762, 19.360881928474672, 59.77068485752229, 70.64936284096011, 70.96553725581016, 71.72105635366133, 70.03863411564981, 68.86256633266326, 66.81963905211418, 56.3280362467612, 53.8257445058515, 50.66685976520662, 50.00832126986597, 51.20218092395414, 50.558786699848795, 60.95518181400915, 63.321241794093964, 64.40723234607329, 59.86205254831622, 60.48133204060217, 63.188308746584006, 62.59088470089821, 59.24800942021032, 57.55949966369137, 56.111878348935036, 52.994931590172556, 51.08361551838537, 49.907790922349506, 46.525335004252774, 46.9649346413151, 44.58746056402884, 47.61925658872051, 48.85307735012424, 45.78666640866188, 46.22142191856138, 49.10799218762306, 49.49662846903647, 51.70249492891374, 50.789661330561486, 46.02335006959977, 45.79355409068447, 46.97642326354981, 44.3712987438325, 48.48495114234186, 50.26763308432795, 57.95745157426404, 59.6583717100082, 59.89732250090569, 60.06372513309602, 59.91752270729312, 60.43674253648328, 60.56115619597897, 55.820301117435584, 61.82936829905357, 60.83649873733521, 59.65735581613357, 58.17333882854831, 57.01919317245484, 57.70618454102547, 54.494383104385875, 48.07862104908113, 45.25143546442832, 47.647901658088934, 43.941053959631155, 44.92724764731623, 43.9562217650875, 42.99569214543989, 46.679958758815644, 50.769959265185946, 47.12006830400037, 43.83192185432681, 43.04343523517732, 44.686429808216715, 42.87057638168336, 43.88822355578023, 44.62359343805621, 43.69322292266354, 45.57939660164618, 44.20854391590242, 45.59328571442635, 46.06527236200149, 44.52890349972633, 46.34271337139992, 49.45698507370488, 52.15310858141992, 53.25580058559295, 54.64068751181326, 56.042401406072806, 59.37318401951944, 57.442746393142215, 58.87217575503934, 59.57439768698908, 59.65097411986321, 58.14301498474614, 58.36908863436792, 60.09530413535334, 57.54719518846082, 56.71108315067907, 53.301809987714215, 50.60926368159633, 53.18202472502186, 56.98484105448569, 58.56016689731229, 62.39799430293422, 65.70596441145867, 64.53056735377159, 43.44989868902391, 1.9662263124219834, 0.1034930240242712, 0.19409360033610176, 0.7720890893570839, 10.650074405054893, 45.35253847798994, 60.05543324255175, 56.358760172320956, 59.17560246682937, 67.05098044487738, 62.41969677709765, 38.79627320074266, 41.66549090416201, 65.01583514675018, 26.246481172500122, 32.48482658017066, 41.80856327856741, 25.81609518297257, 63.27532260648666, 34.357366100434334, 0.5947577532741332, 0.09633873574315541, 0.11629534149242025, 0.033518051232902274, 0.06933456542150629, 0.02914358959383061, 0.03833797001730531, 0.0620718565469067, 0.0503379789241139, 0.02221961990149031, 0.008329287126299836, 0.01291088074550874, 0.08502848175985199, 0.15009090424545352, 0.14172939163061882, 0.14104434048696873, 0.11919683821859861, 0.10714134922431362, 0.1611150473716759, 0.1694124690707653, 0.1269093441266206, 0.1518562159711315, 0.1789283382916643, 0.1847382571788565, 0.24370001508824288, 0.2685014681229668, 0.23781713398714222, 0.2694287715900329, 0.15209731916266103, 0.5083335052815177, 3.806976248179713, 47.95431329358009, 61.454829016039454, 47.32099171607725, 46.42932322717483, 50.729080323250066, 96.86886987378521, 42.049722363871915, 32.58519611051006, 81.28580308729603, 76.34360882543749, 74.78853025744039, 76.94589661013696, 77.23534399463286, 75.51794205942463, 29.580348730087284, 2.455772430666032, 10.708007812500002, 1.8681376403377903, 2.636842520967607, 23.33668851083325, 64.76670580525553, 73.31175004282306, 74.6097094012845, 72.76805462375765, 72.50079216495638, 72.05108457996, 68.79300702002742, 59.56426620483399, 56.471665597731075, 53.57904311149351, 53.06618536672285, 54.828055212574625, 52.54283528174124, 62.624554326457364, 65.68285380640339, 67.53940966821486, 63.67863247471472, 63.63679255208662, 65.72680788655435, 62.687947673182336, 61.92261088278986, 59.790198649129565, 58.68360780900525, 55.73939046552105, 51.722573541825824, 51.81386670758648, 49.37535270567864, 48.76911509421564, 47.14875651944069, 51.177940676289225, 52.606460048306374, 49.54534038420647, 49.11298928722259, 52.36347313850157, 49.02330037086241, 54.12908100312757, 54.220295721484774, 48.3754385671308, 47.42096900939942, 48.33395558018839, 44.53725422582319, 52.05657512910905, 53.45735157689741, 59.61646902945734, 61.198105965891195, 61.29409813111829, 61.831074530078524, 63.038980191753765, 63.82486235710883, 62.471640725289625, 55.49476008261404, 59.85481185297812, 65.23441314697266, 62.96412960175545, 60.677666279577444, 61.251281538317286, 60.74648426425073, 56.2851490512971, 50.29154777526856, 47.46581738994968, 47.74006559002785, 45.785407327836566, 46.83468841737317, 45.50498923947735, 44.65079115283105, 48.713825364266675, 54.97630119323731, 49.453121539085146, 48.06813263124036, 47.76154841146162, 46.739163014196585, 47.436156426706624, 49.15089507256785, 46.91301814971432, 46.6894155933011, 47.77431572637251, 45.051320060606926, 47.10839140799738, 48.755826104071836, 45.093771872981904, 48.652228463080625, 50.76293430020733, 56.11454163828204, 55.429342792880156, 58.25584196275281, 60.9264700643478, 62.32845067977906, 60.15555566357028, 61.716721750074825, 61.77089360452468, 63.60386425449003, 60.6107977128798, 60.398138569247344, 63.98993530581075, 59.55081247514295, 59.67807377538374, 56.71364445840159, 55.319579185978064, 57.993643283844, 61.32804232258951, 63.60957522546092, 66.97972666832709, 70.26187189163701, 66.0200874267086, 46.37266459003572, 2.723809067280062, 0.542676460839087, 0.8831447495087501, 1.3259870222499295, 14.488138133479705, 48.75300199754777, 62.85785690430672, 63.00630684821837, 66.62689378184658, 75.5578717877788, 68.78436996090797, 42.186409119636785, 45.339779007819395, 71.39553100832048, 26.455931817331624, 47.05958143357308, 43.70037732585784, 41.56199132242511, 67.84293051688903, 55.598196906428186, 0.8297504436585211, 0.26988269400692755, 0.24590040346787823, 0.1201305921459871, 0.11941148073322351, 0.1824811629710659, 0.16058626284282054, 0.16013584910861908, 0.19869979591138903, 0.1472064759582281, 0.12211557958395251, 0.12082113614005428, 0.1709688532977335], [0.034750613924716754, 0.013796285906385992, 0.02528362302860666, 0.046840676467024514, 0.060255795326684757, 0.09313225175344175, 0.037373231663819284, 0.027989840112446297, 0.03646481609452636, 0.024669320104763876, 0.03184208834183312, 0.031280808278449604, 0.02639626040153446, 0.08098896908303423, 0.02278398346876906, 0.03786617476913718, 0.03437583222083988, 0.16068815253674984, 6.446649249522917, 43.98589841781124, 33.54174844680294, 34.5003443379556, 23.752620566275812, 53.822120235812285, 66.81432816290086, 12.664980273092947, 51.88188060637444, 72.17961280576645, 66.71546090033748, 66.10863101097846, 62.69950297570998, 67.49081934652021, 32.833833194548085, 0.5764259434034747, 1.165592970867311, 0.20045738547079026, 1.9535891711711886, 28.72082014237681, 62.45137776097944, 66.01052468822849, 66.86527190669891, 69.184538010628, 69.00735670520415, 68.85126206182665, 65.51335250177692, 56.823615950922814, 48.78161568795481, 51.32708880209154, 50.037280128848174, 47.49286997702814, 48.364910925588305, 51.3558280083441, 53.47255860605548, 53.92742803019863, 59.98262620741322, 61.1611690059785, 54.6921137071425, 55.205901053644, 55.14243318188576, 51.83971120465187, 51.08241527311264, 49.141308799866714, 47.44360108529368, 45.94030957068167, 45.95223749837568, 45.27100809158818, 43.04056798258136, 42.94550541908511, 43.97239369730796, 43.52321170991467, 45.82283850639097, 46.01909822033298, 47.74932238363451, 46.71287136693155, 45.9229060142271, 45.09871405939902, 44.36394429975941, 43.692371768336145, 44.021266429655014, 43.483921327898585, 48.89835326902328, 55.05915734075732, 57.808562324893096, 58.12243430845199, 58.39461541944935, 56.87191601722472, 56.32375301853303, 57.39601135253907, 55.957125156156486, 55.75954752583658, 58.5416611548393, 56.062727128305745, 53.79216509480631, 54.918407009493926, 54.75117675719723, 52.002297370664536, 44.960787834659705, 42.670013827662316, 43.45779834255096, 41.98791365469656, 43.702389501756244, 41.94830948306669, 42.04427419170257, 43.78590852983537, 47.64594831774312, 44.24853247980918, 44.94275277660739, 42.21399907142886, 39.56586184040193, 40.13719035733131, 41.42337083816528, 42.19770554573306, 42.041944303820216, 42.506066599199855, 42.730202597956506, 44.38212448550809, 43.958304543649, 43.585149857305716, 43.876817303319136, 43.9313853171564, 44.73876207105575, 49.66467849669918, 50.29365408805109, 50.01400086187547, 50.38197017485096, 52.8587390530494, 53.531896222022276, 53.18295824912287, 56.2260389328003, 56.5589108774739, 57.828389906114154, 56.90307924824377, 55.22037067720967, 52.32365715888239, 49.1382218945411, 47.2888792714765, 49.9835358127471, 51.30160124071183, 57.77917984993228, 58.429344084955034, 64.14837944892146, 60.363103958868216, 55.903200411027484, 8.007141178654086, 0.07823007196308145, 0.100100809678195, 0.08629527709056294, 4.428258845883032, 39.24474131676459, 52.3661756515503, 58.47122323128485, 59.90407289997224, 62.529009311429924, 53.63035163571758, 35.181734561920166, 54.415833719315074, 44.69318020728327, 28.168779880769794, 32.98886291442379, 29.542880289016235, 34.416515442632864, 52.99212709549935, 7.669422165040047, 0.45479508297097304, 0.04582348024292339, 0.06795199888367807, 0.031706617183742986, 0.03957156692781756, 0.0058266459382139155, 0.08205367808019923, 0.0948902013741674, 0.010518019478167258, 0.009411893852595842, 0.04874092691968526, 0.09511977494243654, 0.024946959944622173, 0.01665602509503163, 0.034620340673192855, 0.03228669512956854, 0.03483219462777338, 0.05264809407714394, 0.07463451489926347, 0.018490865045497497, 0.03708458888614851, 0.04254582668504408, 0.0592107632978549, 0.018186429365267678, 0.023707923809847525, 0.04903590141405021, 0.09845905261294496, 0.07747906831003006, 0.0809379935925526, 0.03771140968667404, 0.24006285945013647, 11.538740319590415, 59.06797655167119, 35.49006815879576, 43.61851746036161, 32.183833699072565, 64.08911243561776, 69.94907071513515, 14.765737998870113, 57.61080818791544, 74.85007224544403, 72.68501020246937, 73.00759377018099, 69.9087409050234, 72.68944248076409, 38.74623160208426, 0.3197967543477013, 0.6256511987697694, 0.1243945072975851, 3.4187932456693346, 33.32267622793875, 68.43502798388081, 70.25556472039992, 70.89827645209529, 71.50895026422316, 71.27130954496323, 70.42258708707749, 69.15993690490723, 58.03630690420828, 51.762256160859145, 52.293094050499704, 50.96563454597227, 50.076535209532715, 51.00464251733596, 52.03250746573172, 54.469193643139256, 57.522174389131614, 63.93037411474413, 63.02540879095755, 57.18959662222094, 57.23276622833745, 56.9971808310478, 53.41551165426932, 52.18709199659286, 49.562767474882065, 51.2577256079643, 47.941902914354884, 46.99033198818084, 49.729727083636874, 45.57742364944951, 46.37715570388302, 46.4138690886959, 46.006534868671054, 48.828491933884166, 49.65963040628741, 49.33783523498043, 50.98250466008341, 49.92095831901797, 47.873904705047615, 46.250278795919115, 46.34316052159956, 45.99979231434484, 46.54507629333004, 50.49725647895567, 58.93283520975421, 59.54633705077633, 59.727048489355276, 60.9901850454269, 59.28028660435831, 58.45617701930385, 61.837828851515255, 60.89872321774883, 61.68782957138554, 59.56558804358206, 58.24246668046521, 57.234264573743275, 59.06499162797005, 57.11444793208953, 55.911437388389345, 46.07593336412984, 47.97217968971499, 46.57728287481493, 44.66960676254765, 45.838892767506266, 43.821711924768266, 45.058580367795884, 45.9676641802634, 49.00774817312918, 46.629607292913626, 45.168147856189364, 46.44605605832992, 42.09011493190643, 43.84385370439099, 44.017893191306825, 43.994880645505845, 45.85633554766255, 44.41662565354378, 44.83801764826621, 46.90260033453665, 44.79444011565178, 46.38045441719794, 47.09459643210135, 45.11073612397717, 47.34694996187764, 51.06041469881612, 51.258274739788426, 52.99672411334131, 54.769972755062966, 55.49545826450471, 58.63624518917453, 56.71928090433921, 59.36741029062579, 59.42267648635372, 59.40033858822238, 57.63833538178475, 57.88537802234773, 53.24312348519602, 52.24633547567552, 48.41187738603162, 52.76645352763515, 54.78556025412775, 60.921857357025154, 59.202525615692146, 67.55492656461655, 62.94398823092061, 62.46219565791469, 9.865092423654373, 0.05571446824638594, 0.5714996303281477, 0.34339440746172784, 5.171636737162068, 44.182373862112726, 58.4502189390121, 64.14337842695176, 65.26759247626028, 68.54500339877221, 57.822420058711884, 42.50227366724322, 55.5090335876711, 54.84945958660495, 27.46041943950038, 40.28242395770165, 34.544843627560525, 35.133865956337225, 63.186476999713534, 5.958259740183431, 0.469840590151087, 0.06466082387393521, 0.04756177970839124, 0.09665285477474814, 0.015545449456230048, 0.03403456686365028, 0.08664213872003941, 0.08746542276874666, 0.04103000298322689, 0.05062833773873506, 0.05953740020613036, 0.01694662139690932, 0.027650516788144747, 0.11858066604022058, 0.11871547453225621, 0.12917864977592422, 0.09034711612208236, 0.22668685703989, 0.14679724711083597, 0.14659435638496954, 0.11018322390173713, 0.1073250800911938, 0.10458925753952035, 0.08620713867487446, 0.12034356458893708, 0.12506449715264384, 0.22737143320902703, 0.20644191111768448, 0.3283992475799976, 0.15680384161251207, 0.3499201589053677, 26.264471123295447, 74.43565814725815, 56.76014023442423, 51.82800292968751, 37.34741633938205, 63.96079209543044, 81.89830472392421, 16.49638283637262, 64.51969062128376, 81.3524990697061, 77.83974201448503, 77.24999012485628, 76.14517611842003, 78.2329047110773, 43.19016325858332, 0.799304087075495, 2.0013146102428436, 0.7726973018819286, 4.17431136292796, 36.441968564064275, 72.10438959060177, 70.73189735412598, 74.02408384507703, 74.69032979780629, 74.32798124128773, 72.35824538815406, 71.48957375557193, 61.81139992129419, 54.36501941373272, 55.78635692596436, 53.71628684382285, 52.541258488931966, 53.273584611954234, 57.163705056713475, 57.3311157380381, 61.29210556707075, 65.67384804448774, 63.9146375656128, 59.31156750648253, 60.63321798078476, 60.53242483446675, 56.96537040895032, 53.57275162973712, 53.529844822422156, 52.049165771853545, 49.66512172452865, 49.50400252496043, 50.49392246430921, 49.1886321959957, 48.005547292770885, 49.6144211676813, 49.760356872312485, 50.478899786549235, 49.93311766655215, 51.877942546721435, 52.43422485166981, 51.41875067064839, 49.93505531741727, 48.2048939120385, 49.30861749956685, 48.573553562164314, 48.358917543965006, 55.17101941570159, 60.548781118085316, 63.1890892982483, 61.46855731164256, 63.7244692925484, 60.19479897714431, 59.399491356265166, 61.73588252836659, 63.22192738133093, 63.185904333668375, 62.33627580827283, 59.935071391444055, 60.30337410588419, 61.00073229882025, 60.2709125703381, 56.03615307038831, 49.425366847745835, 48.32994691787228, 50.43380429667812, 48.45365455073696, 48.59387536202708, 46.64585767253753, 46.384204203082675, 47.71041247152513, 52.19818445944017, 49.67582587272891, 49.11996718375914, 47.47763941364904, 44.992025590712025, 46.67224737905687, 49.10726262677101, 48.92522542707382, 47.7879891087932, 47.69762946713356, 47.94688040210355, 48.630926070674775, 44.99727764437276, 48.384789497621604, 48.424244619184925, 48.66048897466352, 48.25774000537012, 54.85961852535125, 53.68228773916922, 57.09886435539492, 55.87620273713143, 60.090475697671216, 59.28344411234702, 59.83674149359427, 61.64340480681389, 62.04452599248579, 62.370212155003706, 61.751685757790845, 60.38499078442974, 57.815948147927564, 54.524212729546335, 51.56811844918036, 56.02369170035086, 58.266710850500296, 63.89457071981123, 64.01393236652498, 70.0037956237793, 65.40377324627292, 62.74568103974866, 12.51609298490709, 0.14594529605200215, 1.0961230147269465, 0.25647816248238087, 6.583960642737727, 49.43798903496035, 63.40734174174648, 67.47869922268775, 70.96423502891295, 72.3022888552758, 64.15676547634986, 44.25173705623996, 64.95603469110304, 53.84837658174577, 36.501851389485026, 50.24276133506529, 44.2555142987159, 53.762559044745664, 72.93234702079528, 19.874937957332982, 0.9131020355609156, 0.3574075651985984, 0.19234028554731802, 0.21885438942380492, 0.12123890686780216, 0.12671924706908966, 0.15552039919120653, 0.1984040553290998, 0.1752694410782668, 0.13378705168443342, 0.14028753754833054, 0.15010844765891954, 0.12365971406501149], [0.04053782213539366, 0.02500669373529813, 0.08306544274091722, 0.01647769514801762, 0.02320319252659477, 0.04106227060659759, 0.05022113902434226, 0.042366707667468056, 0.0338839463168575, 0.04549266432502097, 0.048082428383490736, 0.06647013968998386, 0.012907382596524493, 0.011791082365708727, 0.00715321192758218, 0.0760782229143285, 0.1893156784917078, 0.1588612779854767, 2.2621120224075932, 32.113411464998805, 38.463589529837336, 28.744301411413378, 34.15436383216612, 21.893034673506214, 70.8396448627595, 39.72279587099629, 52.538869765497026, 72.25448300761562, 66.6164053640058, 65.98740623843285, 58.455510216374556, 67.80354207561862, 29.993996004904474, 0.32240163715135667, 0.03523075570081992, 0.3089897665044954, 6.741105991025125, 37.10089537405199, 66.59877823245141, 68.25388508458292, 68.25124140708678, 66.6341580114057, 67.7579092210339, 64.58684552100398, 64.44238854992774, 55.291216527262044, 48.75650859648182, 46.600138525809015, 47.73692769388999, 47.33429247333158, 48.690436270929155, 47.42337734468522, 48.193974033478774, 51.37801685640889, 49.665278619335545, 50.722914357339185, 51.23187718852874, 50.055891775315814, 50.43769136551888, 48.60161419837706, 47.367534560541955, 46.35071500655144, 47.004087740375155, 44.62325219185122, 45.32259902646465, 43.19763537376158, 44.13784711591659, 43.78363747750559, 44.413734866726784, 43.57931729285948, 44.81812338675223, 45.671937081121634, 48.64091634750367, 47.6049477823319, 47.087022335298606, 42.955354490587794, 42.97062035529844, 44.86187742602441, 43.17555635206161, 45.376990533644154, 48.43745516192529, 57.08594014567714, 55.91873299690985, 57.17057704925538, 57.40904931099185, 57.80042732915571, 59.25245346561555, 58.40918310226933, 54.50782898933657, 58.397674868183756, 58.847802146788574, 56.62874083365164, 56.42204761505128, 53.97559473591467, 55.7268153467486, 53.510856628417976, 45.28073164724535, 43.04323911666871, 43.851094399729085, 42.66491866880848, 44.13164192630399, 40.93557703879572, 41.44803077943864, 42.69193987692557, 45.73112172465171, 46.25241256529286, 44.26446514744913, 43.19663516936764, 40.14386230899442, 40.67070722579956, 40.91480416636313, 40.29589729924356, 42.22202031843124, 43.8050732304973, 42.69677223697786, 44.20393905332012, 48.508779541138686, 45.004181015876036, 44.22263699193155, 44.01626148531514, 44.94702031535488, 46.52414260372039, 47.455462332694765, 49.127953129429976, 50.20658531496602, 52.26524914464643, 52.94229730483025, 57.3342889355075, 59.03689569042575, 58.52697972328433, 58.76384773562032, 55.81065993155203, 53.795448118640536, 49.03869567378875, 47.90633486163232, 46.981322303895034, 50.08684712071573, 52.95791618285641, 54.33798643850512, 56.7058507088692, 62.35267916033345, 64.40589481784453, 61.25203855576054, 23.721033719278154, 0.1308491964253687, 0.45348090510214534, 0.15091558257418294, 10.28738852470152, 46.510535901592625, 60.7029341882275, 50.892015580208074, 59.783103081487845, 58.6715425983552, 55.60774395542761, 49.82707638894358, 56.94493878272272, 37.200178407853656, 21.98516526529866, 42.69325387093329, 25.587226844603016, 48.09274942644181, 39.80424388762444, 0.3436413635649989, 0.0719504492477544, 0.1578884535739499, 0.06449783866804454, 0.057731447516069304, 0.05252697940675482, 0.08084974792455474, 0.00962846499357012, 0.05222655036636899, 0.031311599267346245, 0.02911173757315884, 0.09503267840632508, 0.03889421113736687, 0.05131793178377613, 0.07896642035414135, 0.04241269592556261, 0.03021252548111783, 0.020822436406066822, 0.046323735657478535, 0.05627809445403757, 0.09546546445738885, 0.029529491063928413, 0.028949608470523552, 0.0329993560820097, 0.024486646439219197, 0.09121117903099907, 0.03958855875797811, 0.024877665376651193, 0.04561682802534873, 0.044843339691719705, 0.04159295886394478, 0.041791961693595496, 2.6114495867683045, 49.338898197297134, 40.94006030790268, 34.535728039280066, 44.38505057365664, 28.268066836941628, 79.61565786792387, 43.36407722965364, 62.719503141218624, 78.80977553706016, 72.85880258006435, 71.16961033113542, 64.60049536920363, 76.27132738790205, 35.14264422078287, 0.3889136971725572, 0.19017452434186013, 1.4639535738575844, 9.870350360870361, 41.48890972137451, 70.54381970436343, 70.1058086272209, 71.65774929908015, 69.61199006726666, 70.86125712240897, 68.07897090911865, 66.46423309080063, 57.33721110128588, 52.26218969591203, 49.21706153500465, 50.95792708858367, 51.38294335334532, 50.62129751328499, 49.66335665795111, 50.640371999432965, 51.69896087338848, 53.704829600549516, 53.34890196400305, 51.95642917386947, 52.65323039024107, 52.24412325889834, 48.96685354171261, 49.19815571077409, 47.231738182806204, 50.186502779683764, 48.48358223515172, 48.15725280392555, 47.19467570704799, 45.92292562607796, 46.23754678233978, 46.98295400988671, 45.76646620227445, 46.7150325928965, 48.57049803580008, 51.34262531034408, 50.22430266103437, 50.24141596209619, 44.65137558598673, 45.61835358219762, 45.60284060816611, 45.018674173662745, 48.64945926973897, 50.37680833570419, 58.53029020370976, 60.172900384472264, 60.35310191492881, 60.39360430932815, 58.5094859523158, 60.31030493397867, 60.82594756157168, 57.87170463992704, 61.37484012111541, 62.01697526439544, 59.721380664456284, 60.45175344713273, 57.61653877073719, 58.1427796425358, 54.924859308427386, 50.090263505135816, 45.42220761699062, 46.529896720763176, 44.913562497785016, 45.720194001351636, 44.46030124541252, 44.10283211738833, 44.819068677963756, 47.55592992228847, 47.76810269201956, 46.194388943333784, 45.4285853908908, 42.550585500655636, 43.740503172720636, 42.65853697253812, 44.601604630870206, 44.407564978445734, 46.327012123600134, 45.62988142813406, 43.897680390265684, 49.594715179935584, 47.45564276172269, 46.585449249513694, 45.23140784232847, 46.65142351581205, 49.68742824369862, 49.91307435497161, 51.29042248572073, 53.401551938826046, 54.359994857541984, 56.60188828745196, 59.86922264099122, 60.085623725768066, 62.00967965587493, 60.835745642262125, 58.40095004727764, 55.88942504698231, 51.172821983214355, 48.72624358823223, 49.28267494324715, 53.672685776987386, 56.63398112020185, 58.03029391073412, 58.76624822616578, 63.849075148182536, 65.20793714830953, 66.7421643964706, 28.639703566028228, 0.0639508557205479, 0.20411801404289662, 1.396233975406616, 12.437609299536675, 49.183650785876864, 66.29579867086103, 55.57254460550124, 64.6701527410938, 62.470601297193966, 61.043337083631954, 53.31152962100122, 61.36567354202271, 42.60787171702231, 18.64386481623496, 53.53322590551069, 25.31111747987809, 55.47668972323018, 43.45822195852957, 1.0233838856220245, 0.08435495257858308, 0.04458398828583379, 0.08614787411305212, 0.015286823918652392, 0.0926563885783957, 0.04206541294772779, 0.02498540223666257, 0.04758670054856808, 0.02383283827634108, 0.05620082299555502, 0.07688551104717678, 0.03023106672410523, 0.03881808881077074, 0.17202236208944552, 0.16778149852348914, 0.21534155453405074, 0.16914131991084547, 0.1714853497762834, 0.24125533659131299, 0.2723508147943405, 0.16334437855309056, 0.14922448944660927, 0.1998110524108333, 0.30572393368328776, 0.22160092188465982, 0.1887377264398721, 0.11509731021379271, 0.15931040469196536, 0.2792245846602225, 0.38001129583966353, 0.4954913589021852, 8.693850136572316, 65.25732371114916, 58.004747513801824, 43.77987200214017, 52.43025541305543, 30.75394738105036, 84.93407018723028, 47.314868896238266, 65.89507364457654, 84.52250372978949, 76.71951309327157, 77.97792711565572, 70.56325897093743, 80.69729851138207, 38.908386307377974, 1.196771891367051, 0.9500915797487383, 2.540925616218198, 10.650398981186653, 44.75951925400765, 76.35629377057477, 75.832029773343, 75.85121800822597, 72.44918946296939, 73.50629960336994, 70.1369914700908, 68.47255722168954, 60.333580278581195, 55.702276998950595, 51.557253483803045, 53.63324242253458, 54.11404655825708, 54.376327606939505, 52.65703508930822, 53.43492738662228, 55.854778751250244, 55.222590738727206, 55.556227545584406, 54.22329633466659, 53.53333965424569, 55.77285612783125, 53.01178993717317, 51.34729685321931, 51.03765710707634, 53.45768497836206, 48.51757741743519, 50.70713466213596, 48.8564545108426, 50.49969227083268, 48.92449586622177, 51.54780841642811, 47.83124108468333, 48.15536614387266, 49.511549165171964, 53.804328364710656, 53.51602238993491, 52.14274567942466, 46.34848710029356, 47.611690336658114, 49.16337213208599, 48.33804661227811, 50.87139568021221, 52.72291914109261, 60.743075724570986, 61.88874121635192, 62.13021801364038, 62.41220112769835, 60.23292833758939, 64.27385214836367, 64.37195454874347, 60.32966575314922, 63.57319916448286, 65.46056132162771, 62.392071523974025, 62.60610741953697, 59.195786983736106, 62.298526917734456, 56.57926797866822, 52.20035745251564, 47.5074415822183, 47.02092255315473, 48.084814471583215, 49.48843071537633, 44.179204587013494, 45.97406156601445, 47.29630039584252, 50.06167727131998, 51.539653808839866, 50.065717312597464, 47.27868110902848, 45.51894111018027, 45.93143716935189, 46.31981849670411, 47.964079995309156, 45.93684611781951, 48.29558695516279, 49.249436778406945, 46.15545941937355, 51.87878977867865, 48.84316944306897, 48.449488993613954, 47.86755438773863, 48.56470469505557, 52.78016221138739, 51.94468167520339, 53.37098490807318, 54.21273339179255, 57.148709835544715, 57.23509219384963, 62.40322674474409, 64.10366050658688, 65.12109587269445, 64.12448829220187, 61.66554266406644, 59.06544270053987, 54.58599398213049, 52.71610990647347, 53.80196709786692, 55.78977331038445, 60.287908200294744, 59.423366823504054, 61.69760019548478, 67.97623618956536, 67.64485866792741, 67.74758554274037, 31.116437142895116, 0.2501567420099051, 0.6106718509427963, 1.3936654358140885, 14.264010960055938, 54.95677563451952, 72.91013071613928, 60.677305421521595, 70.45489172781669, 68.34803765819919, 67.64836526686146, 57.883762005836736, 67.33294394708449, 43.71933806327082, 33.330481744581654, 63.68324910440753, 41.19137440958331, 64.51209299025997, 59.2483388993048, 2.0765814617756875, 0.6179524441399883, 0.355583050198132, 0.25600612974695625, 0.21519359231235521, 0.16669774458052652, 0.21261530808143078, 0.07972123912505566, 0.1428131762170984, 0.11894691735506059, 0.1547324317958086, 0.22754812372788308, 0.17336441023695856, 0.11859301537755998], [0.05807047589652001, 0.11258089524363318, 0.01856098890364651, 0.06540993528981363, 0.0986986159677467, 0.03590044678158818, 0.04407349410617063, 0.03835095903806148, 0.05624784930278698, 0.02603293171212558, 0.022573523794210727, 0.025396452458094687, 0.04603166463634661, 0.049086735178265846, 0.04411464068858374, 0.048533566070780645, 0.05166809525220625, 0.02516432015615846, 0.08812117871017226, 23.092297392506755, 47.80153697536838, 26.704800321209817, 29.55351383455338, 25.682956211028564, 56.231612620815156, 58.27088817473381, 51.87919770517657, 69.1866639352614, 64.03061028449767, 71.6075272713938, 59.801965759646514, 66.10146876304381, 25.63161042428786, 0.14358268089352116, 0.21104746317911535, 1.320417992049648, 19.163659272655366, 48.30605183878253, 67.34179281419324, 66.56099796295166, 65.43329692655995, 64.7963353895372, 64.19622844265353, 62.4319306496651, 62.83023949592345, 53.60703314504316, 48.38567203091037, 48.35628563357938, 47.17831942342943, 50.21180991203555, 49.35104577772079, 51.37740104429184, 49.02349648937103, 47.26352114831248, 49.18877732369208, 46.62129579051849, 48.152310617508434, 46.25747242281514, 46.23420884532314, 46.76348563163511, 46.742904955340975, 47.565092579011, 45.01786224303707, 44.717969586772305, 46.343129142638176, 44.901222721222915, 43.75086999708607, 44.39095374076597, 43.596297233335434, 46.1875012613112, 46.56515098387196, 46.09896944415185, 44.894252669426706, 44.01899145495507, 44.76097837571175, 42.07258585960635, 43.67740400375859, 42.64672671594928, 44.35984542292934, 46.12659469727547, 50.74436972218176, 56.37725414768342, 55.00524044036866, 56.76965590446227, 56.534600027145885, 59.29276366387645, 59.835070563900864, 58.75814853175994, 54.57186168239963, 59.061386969781694, 56.59522810289937, 56.34165471599948, 55.43976845279817, 57.04630851745606, 55.0153366211922, 53.636368551561915, 48.28210969125071, 43.256545451379594, 42.4331771942877, 42.3567811904415, 41.474102773974025, 40.43300767098704, 42.54241520358671, 42.72647242392264, 42.95625271335725, 43.96702005017189, 44.93743012028356, 42.292579835461034, 41.82475482263873, 39.988826705563454, 41.03470317779049, 41.40166051926152, 39.666580461686664, 42.2968630636892, 43.284696302106305, 44.80790169008317, 49.00894841840191, 47.69584478870515, 43.65558385849, 41.27231251808905, 42.78451173536239, 42.87871922216108, 44.93737520710115, 45.611814991120376, 47.34256475202499, 49.59680580323743, 51.00826286500501, 54.45246081198416, 55.86247444152833, 54.03146497664913, 51.89474990290981, 49.60811399644422, 46.66839561154766, 44.60667625550301, 46.397097033839074, 51.613123724537516, 55.958446994904556, 55.5347211899296, 56.626685511681345, 57.172506855380156, 57.08155885819466, 65.26883194523474, 59.621705393637384, 44.54661692342451, 1.0155572249524056, 0.667407587170601, 1.9484850644103944, 18.26170632916112, 48.66967124323691, 58.02602637198664, 59.64651438497729, 64.58493924910023, 59.64721256686796, 59.31299132685508, 40.28966073066958, 48.86125941430369, 42.297459263955396, 33.12281970054873, 35.50325908968526, 28.615804564568307, 53.547209155175, 16.023086117159938, 0.32221419075804375, 0.027733838426009304, 0.10603228373633278, 0.02804056853957234, 0.051720905523266525, 0.028580551358660864, 0.059615744187706904, 0.014998532583816879, 0.04974265582859517, 0.0690421266781707, 0.039727078946006876, 0.018649205843347217, 0.06272664721754771, 0.05993270157505909, 0.0064018640137698144, 0.04358009900897742, 0.05999539054990296, 0.07215341658241327, 0.06532204202226093, 0.02498237618936166, 0.006402435228078356, 0.04775745771645058, 0.010021697925103289, 0.01859335803366717, 0.17344661147123383, 0.02042178008254738, 0.08605920709669591, 0.0423009964757629, 0.06144169943347093, 0.050470404882705024, 0.04168468257111888, 0.01998640465429954, 0.2706269024600906, 32.752887241302, 58.38120875820037, 26.33412653400052, 46.891041109638834, 26.81065332505011, 62.088978213648645, 64.06908089114775, 56.53388223340435, 75.39702323175247, 68.84861053959017, 76.76065875637916, 66.36755451079338, 72.95280610361408, 29.38699157007279, 0.5129533219000986, 0.07432457104685807, 2.0101582066666697, 23.437226703090055, 52.61525400223271, 71.1621892067694, 69.89519303844821, 67.62798463144611, 65.33607313709875, 66.8359718015117, 66.57711105961954, 66.71000880579795, 53.71765182864282, 50.31188134224185, 51.22378926123343, 51.63643437047159, 52.121972806992076, 50.75648984601421, 52.53476304392661, 50.96305362639889, 49.317329083719564, 51.095790555400235, 48.96786943558724, 49.3028006246013, 48.64650964736939, 47.73440953223936, 48.290746750370154, 48.51255286124445, 48.49236049959737, 46.730341603679044, 47.2012064533849, 49.135315418243415, 46.543283770161295, 47.61984494424636, 47.85816815591628, 45.65851473039197, 48.50015032675959, 46.22241820058515, 48.79896433122697, 47.63535007353752, 45.546225117098906, 48.731385815528135, 45.61668265250422, 45.57456424159389, 46.20273966943064, 47.781285778168716, 48.31789347433275, 52.719738098882864, 60.25436801295127, 58.238524698442035, 58.55195737654164, 60.636799104752086, 59.89833447241015, 62.84938066236435, 60.698952982502604, 56.301513179656006, 61.64087880042292, 59.582034541714584, 58.58013176148938, 58.34805688550396, 60.61231174776631, 56.342470568995324, 57.364369592359, 48.99691458671324, 46.12884221538421, 46.271259553970836, 44.979579910155266, 42.97153818991877, 43.99121715176491, 45.11288166046143, 44.42105008709816, 47.04897534462714, 46.38915031186996, 48.08195898609777, 45.559510184872536, 44.505400657653816, 43.13317906471991, 42.882974993798044, 44.136968504997995, 43.41142808237384, 45.5524028501203, 46.531018518632465, 46.62657137840025, 51.08442352664087, 50.42229214022237, 46.15986031870688, 43.085965494955744, 44.20440581537063, 47.796500652067124, 46.927021011229485, 48.77300216305641, 49.47964460619035, 51.63700311414657, 53.09262214168426, 57.211463835931596, 57.91153238665674, 57.01232902465328, 54.04282023829799, 52.306873336915054, 50.140630660518525, 46.327121949964955, 48.42558999215403, 54.424266815185554, 57.55548707900509, 58.91258009018437, 58.25659113545572, 59.857518288397024, 58.798219465440326, 67.48581440218034, 62.97186451573526, 50.977017264212336, 1.202304026772899, 0.5970096840493141, 4.051798336928891, 20.726815962022354, 52.57171569332, 62.14193805571526, 63.720001712922134, 73.18219415603146, 65.3076869441617, 66.3117862516834, 44.29125885809622, 56.26670606674687, 44.86926717142905, 35.97393958799301, 46.108955798610566, 28.604921948525217, 61.04634946392429, 10.970253559850878, 0.1919094223769442, 0.018485833763054783, 0.12091601612947642, 0.053540245599804394, 0.03223090477648281, 0.07510299298671946, 0.034816279151146455, 0.027544997752674168, 0.043792542851259636, 0.03818136632382389, 0.039633823062984214, 0.032341849629677115, 0.006240787324420507, 0.08699185785747345, 0.145209223452595, 0.14119699116676085, 0.14470824791539103, 0.18062608106242073, 0.21012363775122553, 0.1289449776372602, 0.1361397689869327, 0.09422403429785083, 0.17505933380415364, 0.07889526610773417, 0.2907407247731763, 0.25061259496836896, 0.20515679862470398, 0.1398937223899749, 0.08838181714377097, 0.17701627476321113, 0.09688493345052966, 0.15676498563299257, 0.5080008699047951, 52.26801441561792, 71.29777769888602, 42.814031493279245, 48.347632884979255, 39.12730163143527, 67.61084387379309, 70.25740823438092, 61.022803475779874, 81.65596500519784, 74.36951129667221, 82.65831101325251, 72.47410435830393, 79.75952256110408, 34.19201466345018, 1.5753141982901482, 0.2833109282918515, 2.737369436410166, 25.887756886020785, 57.696943436899495, 76.1624502366589, 72.80009254332512, 72.15226604092506, 69.58502769470215, 70.58535760448825, 68.38999917430263, 70.24138142985683, 57.882942230470725, 52.7029150532138, 52.93220504637688, 53.40829057078208, 55.2545698227421, 54.3092550769929, 57.036514359135786, 53.71203499455606, 52.346681471793886, 54.63956963631415, 50.22298474465647, 50.725573724316014, 51.74069096965175, 50.683565139770515, 50.654437618870894, 51.32160140622047, 51.031142050220126, 49.417235774378625, 49.65042068112282, 51.3176162781254, 50.11067944188272, 49.5923460683515, 50.16905999952748, 49.79017865273261, 52.92770608778923, 49.73408091452814, 50.31868273212064, 50.457609161253906, 49.58392081722137, 50.044520824186264, 48.48249966098417, 49.89907149345645, 47.29082476708197, 50.404092342622825, 52.58227863619405, 55.784913493740945, 61.94669031327771, 60.71031216652163, 63.82506632035779, 62.15348159113238, 64.30603519562753, 65.27111084230485, 60.88921931482131, 60.86697163120393, 64.22653659697502, 60.52322687641267, 59.37178373336793, 60.2313123210784, 63.6047467877788, 59.72024709947648, 60.069922477968284, 51.93850394218199, 47.96195407067576, 48.68935761913177, 47.27910080263692, 45.978564446972264, 45.607488616820305, 47.18168481703728, 47.015180203222464, 47.4824050934084, 48.12252806079004, 50.00799963551183, 47.475360516578924, 47.75116981998567, 45.5693631787454, 45.437477404071444, 47.616040245179214, 46.1740553763605, 49.47347079553912, 48.38531509522469, 48.08122158050538, 52.86383028953306, 53.28090375469577, 47.986653235650834, 45.230152683873335, 45.234180958040305, 49.4720430527964, 47.821705802794426, 52.47014984007805, 50.786472443611395, 53.10972367563556, 56.640872724594615, 59.2965252168717, 60.95726851494082, 60.65962337678479, 57.387268389424975, 54.93760701148741, 53.52320424972042, 49.451105440816576, 51.361307559474824, 57.577334680864894, 61.976194381713874, 61.24531953565536, 61.7423269825597, 64.1475518288151, 61.581890275401456, 70.73094029580393, 66.04598291458623, 54.25872318206295, 1.9615669043794757, 1.8112705047092132, 8.686474119463275, 21.87539969721148, 59.18744018000942, 67.14815324352634, 69.34897945773217, 73.24615232406124, 70.68392676691856, 68.70481644907306, 53.013402031313994, 63.10579384526899, 48.527983465502345, 51.114739525702696, 49.47555357410062, 44.387576580047615, 72.11929459725657, 28.936468132080574, 0.41483149353054266, 0.15919365289230503, 0.25132755418458297, 0.15182270728532346, 0.13435884438935788, 0.13560114788912958, 0.18105645393652303, 0.09018691947623607, 0.15249147139970334, 0.1284254934158056, 0.2486473189726953, 0.17101236709183262, 0.09578489247829684, 0.3077187959945971], [0.06996602871485295, 0.02234930709575213, 0.05478194389011591, 0.033248863258068605, 0.049260644797956755, 0.030747130362977906, 0.055986195802688606, 0.03203558108408845, 0.028723612532860814, 0.08350825688290982, 0.09823563839158705, 0.05720327968799299, 0.03822926214084991, 0.014529091140796101, 0.055777842869922045, 0.023425880879644426, 0.04754213721401269, 0.0632147754602615, 0.31036480239802794, 7.676616282232347, 56.99088542692123, 36.29111812960717, 28.953042107243693, 28.19412231445313, 36.74241427452334, 68.82604122161865, 50.24714654491794, 64.60652797452866, 69.23548959916639, 66.92917516154628, 61.49539024599137, 65.93880022725752, 26.086697539975567, 0.32894837940412186, 0.32983293516501305, 4.688040364173151, 32.29644298553467, 62.00635348596881, 70.51833214298372, 68.64129758650257, 63.58461718405447, 59.99966498344176, 60.52638830677156, 59.154715845661784, 58.06665428223149, 50.39793029908211, 48.42387591638873, 47.489010364778586, 52.06436887864144, 54.362881721988806, 53.86502704312725, 51.66598158497965, 50.16644770099271, 48.822788807653616, 47.05001085035263, 44.14710783189343, 46.1205699366908, 47.48968109007805, 44.763947609932195, 44.12112605187201, 47.65052572373421, 46.15193320858864, 48.99524757939, 47.665905337179865, 45.20795206869803, 46.644457386386016, 45.21921711583292, 46.45646995113742, 46.006962407019834, 45.549617967297955, 46.704434348690896, 45.57106156503001, 45.05642306420111, 42.47330696352067, 47.221716527015936, 43.856464124494984, 44.67213669130879, 43.44419164042319, 44.64051454297958, 43.848937096134314, 48.62564263805267, 53.295000753095074, 55.64827772878832, 58.96572428364908, 61.11939576364333, 57.22809076309205, 57.55892307527604, 40.607066769753736, 57.673087581511474, 59.752669411320845, 57.86129074711954, 55.609642382591005, 56.177734944128225, 56.509088931545136, 54.02199637505316, 54.27134536927747, 48.08595588130336, 44.416849228643606, 46.32962834450507, 43.09994874462005, 39.55744443401214, 40.699630783450225, 40.79573669741231, 42.42237106446297, 41.933981064827215, 42.52372510971562, 42.70659777425951, 43.69913785688339, 42.522697448730476, 40.40520983357584, 40.4822491061303, 41.14578862344065, 41.14853428256127, 41.93760533486643, 43.67201466714182, 46.386612538368475, 47.17951182396182, 45.799955398805686, 44.086283637631325, 42.235348532276774, 42.28978710789835, 42.55239763567525, 43.061842918396, 42.60301974511916, 42.530157796798214, 43.00535686554448, 45.51865477715769, 46.97865901454803, 47.71801010254891, 46.61623201062603, 44.13240286611742, 45.092877572582616, 43.10614216712214, 46.57433325244535, 49.77152778256325, 55.3636940833061, 56.29215832679503, 57.5225587814085, 55.198538764830566, 60.07655912829984, 56.069857997279016, 65.38230219194966, 59.14170926617038, 56.6756719927634, 9.009736257214701, 0.8521741436373803, 2.215084274930339, 20.188896233035674, 53.416868794348936, 56.24406614611226, 55.71767230187693, 49.681909468866166, 60.34654763437087, 58.06040202417682, 42.89837814146473, 34.41271074356572, 25.060917331326394, 28.31329176502843, 27.690199728935, 38.69552712286673, 45.59911043413224, 0.1815021638908694, 0.08797613528346823, 0.032624727595717676, 0.048288555830837264, 0.0350386783060047, 0.04713321863222988, 0.1150856733382229, 0.08675339000840342, 0.0664230406043991, 0.08301887991687945, 0.054389346811559894, 0.04634321344295337, 0.09258533392341868, 0.07812478849964757, 0.03944162692454073, 0.04564189442223118, 0.029254134166084474, 0.01602853492518226, 0.09705086809492881, 0.06296018146038537, 0.05556049989536405, 0.05417974898591638, 0.015404137835327177, 0.03608177213238613, 0.026669723146985617, 0.037477745208889246, 0.019636467181807084, 0.03387627777673545, 0.025869061674682364, 0.011988261906099657, 0.0682921419220586, 0.0949084036232483, 0.19579161889851096, 0.28693525961810545, 9.913381703438299, 72.12497418926608, 34.49783794341549, 35.57646228421119, 31.94457107974637, 42.36112717659243, 76.55284373990952, 55.002557539170795, 72.33043578363234, 74.32876571532219, 73.84946776974586, 66.65068687931185, 71.97711652325046, 29.708119938450476, 0.5534957060890814, 0.331110708535679, 6.661473051194222, 34.695760742310554, 65.8020624806804, 72.15008520310926, 69.36051122603878, 65.22908656827866, 63.97510482418922, 63.13795335831181, 61.382963349742276, 60.39966437124438, 52.70704923137542, 49.95871505429668, 49.43193289541429, 54.942035367411954, 56.65734667931834, 54.26524608365951, 54.36122255940592, 52.3415078655366, 49.44814797370665, 48.54000945245066, 47.17246332476216, 47.799936648338075, 47.96581760529549, 47.058502781775694, 47.243073832604196, 49.17379386963383, 48.13060422097483, 51.40283369248914, 48.798328907259055, 46.85948956397272, 49.77449701678369, 47.194012826488866, 47.947409922076815, 48.08554795480544, 46.49672131384573, 47.03148157365861, 48.049226807009795, 46.20945868953582, 43.53930127236151, 47.38944099795434, 46.47198684753911, 48.11555800899383, 45.50894298861104, 48.031956611141084, 48.327432678591826, 51.95575452619984, 55.49833336184102, 60.27033598192277, 62.867760888991825, 60.75674518462151, 60.261895041311945, 60.309889162740404, 49.37164214349563, 59.66997015860773, 62.4467650536568, 61.117662076027166, 60.552903529136415, 60.32808111559961, 58.599916196638546, 57.41363063935311, 57.02772040520945, 51.16511452582575, 48.117279929499475, 49.35000634962513, 44.46337638362762, 42.67998841501052, 44.60429145443825, 43.352031630854455, 46.39301776885987, 44.16345627077165, 45.28436376202492, 45.83729636284613, 46.57564724645307, 45.938375842186716, 42.69369317639259, 44.08834288197179, 44.76283757917343, 43.813192536753995, 43.9492085672194, 45.483526029894435, 48.44506063768941, 48.2840669539667, 47.70400724103374, 46.34859300428822, 45.53474041723436, 44.98542424171202, 45.215161385074744, 44.29457326089182, 45.181479992405066, 44.927969363427934, 47.14816424154466, 48.24593367115144, 48.299372042379076, 48.19298167382517, 50.33765523664413, 47.23258541476342, 47.39932929315875, 45.47679916504891, 49.241980352709376, 51.04107349149643, 59.049215855137, 60.21095521988408, 61.567534400570786, 57.439075054660925, 62.12662512256254, 59.0469918712493, 68.54171645256781, 61.06986015073715, 64.71689562643728, 10.243377570183048, 0.4691577300189003, 2.979016366504854, 22.569661178896506, 59.55971233306393, 61.71680804221862, 59.2516533021004, 55.84111321356989, 68.811002854378, 65.51636880443942, 48.507359643136304, 46.08981463216966, 25.097730736578665, 39.69883803398379, 29.806869529908706, 43.0129623413086, 53.19076376576578, 0.6010548121506168, 0.038193504986984116, 0.07017932291473113, 0.02676196587872842, 0.006226370986100407, 0.06846758371759808, 0.11254298155226054, 0.12174660099610207, 0.043802325794052695, 0.039162318928227316, 0.05628538761107672, 0.06456780547816908, 0.014314766552659773, 0.05474214945288916, 0.04335766154972296, 0.10511393583710156, 0.12742787073816986, 0.11543295631605772, 0.2636652163440182, 0.39596072548339445, 0.12255116951681914, 0.16496733582067877, 0.23171525899200673, 0.1314444927078101, 0.14972105231736937, 0.24284028057609838, 0.19623909085508318, 0.11259070116906397, 0.1104916585609317, 0.22784412478006658, 0.22519362910139948, 0.29643842710121987, 0.4710125821011682, 0.663881253811621, 20.52773606392645, 82.12833604504986, 51.82522196923533, 45.81509182530065, 42.391360805880645, 46.357928245298325, 81.65314089867377, 61.57521832373835, 77.32809235972744, 81.46660081801876, 79.19288912127095, 72.48670301129742, 76.71330005891862, 34.6346462926557, 1.3640854940299065, 0.9863589788156172, 8.900312915925058, 37.14250387683992, 73.33056957490983, 77.43538487342097, 74.28863202371906, 71.87864934244465, 68.92057034277147, 67.16835344991377, 66.06732060832363, 64.1836807804723, 57.11811142583048, 52.412165441820704, 52.64782536414362, 57.82166304126863, 60.02064966386365, 58.71315110114313, 56.825577136008974, 56.08776753948581, 51.561642616025864, 52.26349976754958, 48.0780876067377, 49.760031315588186, 52.23438009139031, 49.70782849096483, 47.97095198785105, 51.96211661061933, 51.48670573388377, 53.51318651630033, 51.19283783820368, 49.24853855563749, 54.94733841188493, 49.84945743314682, 50.8090143049917, 51.14004665805448, 49.575562246384166, 49.97078810968707, 50.29979259737077, 50.744608986762266, 45.556054576750725, 51.65193165502241, 47.861408033678615, 50.074468120451904, 47.173636113443685, 50.71490487744732, 51.16206292183169, 51.997323805286044, 58.21642214252103, 60.220890583530554, 64.97170455994146, 65.11602817043182, 62.30575976833221, 63.01246496938891, 49.02916431427003, 61.97361346214049, 65.6123060564841, 63.229156309558505, 59.4983390069777, 62.43378200838643, 62.2287989431812, 58.080068788220814, 59.7253304912198, 55.70851356752458, 50.26551892680507, 52.09235891219109, 46.86818938101492, 44.931997637594904, 47.160888410383656, 45.26479113486506, 48.35933331520327, 46.85737148407967, 47.32459637426561, 48.66898482845676, 48.58379487068423, 47.22187342182283, 44.442352479504, 46.17528700059461, 47.412033850146884, 46.56662971742692, 45.854088029553814, 48.10844282950125, 50.82954006810343, 51.238149058434274, 49.801624128895426, 49.658124216141246, 47.27595506175872, 48.459918575902144, 47.384843980112386, 48.10125704734556, 46.825541450131325, 46.79253078276112, 48.87735682149088, 50.519531619164255, 52.081078175575506, 51.17266901077763, 52.84119429126863, 49.64103837167063, 50.36007942691926, 47.65442848205567, 52.750061942685036, 55.32721211833339, 61.48181884519516, 61.621576816804954, 64.63563588357741, 61.97957546480241, 64.18560274185674, 63.307380137905, 69.60969155834567, 65.54781052374071, 68.82273074119323, 11.960441200963913, 1.6251939991789481, 4.938531258413869, 26.57197710006468, 64.59067375429215, 65.59518883305212, 65.74316417017292, 57.998326593829745, 73.39504549580236, 69.58088567180019, 56.28412139031195, 49.01571058457898, 31.985822646848618, 45.05901182851484, 41.62377649737943, 53.51028004000264, 67.71364919600948, 4.118210682945867, 0.3900933806453982, 0.2608119065482771, 0.12388111347512853, 0.21368856661983077, 0.23085524868820947, 0.280332409085766, 0.24108382482682508, 0.15616501621421308, 0.11957098023905871, 0.1474508426843151, 0.17247398624256735, 0.19073006066103138, 0.1726629035246949, 0.12310134322052041], [0.12044754570289967, 0.03140076424085325, 0.012778223045320522, 0.04834480200623793, 0.07932200772507537, 0.017106672486049995, 0.030234652015590863, 0.05049849349644877, 0.09046713911717938, 0.09753157294565633, 0.03751563974806378, 0.09794562814697143, 0.008347708668049065, 0.043632143192113414, 0.02877777494910744, 0.0808696432279483, 0.03226767699684828, 0.1371549733824307, 0.09311150609245224, 2.3377255134044157, 49.06887046752438, 42.350893712812855, 38.557314565104825, 34.50751443063059, 27.464955660604662, 66.06521821791127, 68.55544474817091, 59.05989254674604, 66.77185673867503, 68.86175832440777, 59.97147883138349, 65.4964941547763, 31.293251706707863, 0.8282919961117929, 0.0470537944666801, 8.218829535668897, 39.76740106459587, 69.77318379186815, 71.25070925681823, 68.14678868939801, 64.71941771045809, 55.09831828455771, 54.55485428533247, 55.89270807081654, 52.876091618691724, 51.887360157505164, 49.81819614287346, 50.660356475460915, 53.68605321453464, 55.13301557110202, 56.636456135780584, 59.486030609376975, 56.338046135440955, 56.678727519127634, 54.730643149345156, 52.36905074888661, 45.26398312660956, 45.87662204619377, 46.78577646132439, 45.142762276434134, 46.571081607572495, 48.2063530337426, 46.11210546185894, 46.79370749381281, 48.14144957450129, 46.43165703742735, 44.91220928007557, 44.94705169431625, 44.787603424441436, 46.31420166261735, 45.01677182412917, 46.411892214129054, 44.670422615543494, 44.685417836712254, 44.50188229160924, 46.51467792449459, 45.129959660191695, 45.433857056402395, 44.35566417632565, 45.16025212503249, 48.31182556767618, 54.50689546523556, 57.44956739487187, 59.66036819642591, 60.30606877419257, 56.769134229229344, 58.035565576245716, 49.36753542192521, 55.02378148417319, 60.59331178665162, 58.74112936758227, 56.14471643201767, 54.13527834799982, 54.02229447518626, 53.01364914063485, 52.72030684255785, 47.92873944005659, 45.581600973683024, 45.3364489155431, 44.207763364238126, 41.12405477031585, 41.3986167600078, 40.580218145924235, 42.54250934047084, 41.68430259150844, 41.898020775087424, 42.31880480243314, 41.81384671118952, 43.19457984739735, 42.17693659567064, 39.33661499331075, 42.08668285800565, 41.53984169806204, 40.615754819685414, 42.55430782994917, 46.907671959169456, 49.208483311437796, 49.72055265980382, 45.76704279068978, 45.22299435830886, 45.352562012210974, 45.55812951057188, 45.7959859601913, 45.45392782457414, 43.89528774446057, 43.10030568030573, 42.22863343454177, 43.222507123024236, 43.75023065074798, 43.88976112488778, 44.025937972530244, 45.2697725449839, 45.58467611189812, 46.375127838503936, 52.10883286691482, 56.27487244144563, 59.80722565804759, 63.21007790104036, 58.897027892451135, 58.27208449763637, 62.36793325793359, 61.44422292709351, 65.15870748027679, 57.5874504735393, 20.95188352369493, 0.1717645122158912, 3.268009246357026, 25.822947563663607, 54.403784198145715, 52.69226974056613, 47.65896274197487, 43.72479015781034, 57.71366842331425, 62.630861497694454, 61.47792785398422, 38.554478691470244, 27.0200490566992, 28.462955682508408, 25.917788513245124, 52.814082868637584, 26.458024401818555, 0.13365678609378878, 0.056233917993883935, 0.02819844585422787, 0.059524844025051406, 0.01983073941852537, 0.06994119214434778, 0.04119352828110418, 0.05615037227530153, 0.07012958848668684, 0.06261932979067487, 0.1205433909631064, 0.033891293100051345, 0.012188843834484297, 0.03847160256437717, 0.08204869850869141, 0.11654733845423307, 0.013146583974782019, 0.01931004860859004, 0.01864036327348121, 0.08803392129559671, 0.040884331364424965, 0.05094350248034443, 0.03730501153416211, 0.00717442729623027, 0.02621049748643512, 0.023181661625482866, 0.03799482774470122, 0.04408866264707139, 0.07737435175166016, 0.0425721035008469, 0.11674496615605971, 0.0074962914767374685, 0.06368075227064472, 0.05062731501135615, 2.7980703211599782, 56.752264115118216, 47.97103827999484, 40.21576327662314, 41.39732630022111, 30.479485411797803, 78.21039815102854, 71.43280136969783, 62.85732346196329, 72.86170513399186, 76.80748401149627, 68.31955340600783, 70.42171632089924, 36.177863613251716, 0.9251890031080093, 0.5878512561321259, 10.277422762686207, 43.721518901086625, 70.43833932568951, 73.30144989875056, 70.92692544383388, 68.16924033626434, 59.19856794418828, 56.19270663107596, 55.961408384384654, 56.82407094586281, 54.42150154421407, 51.461496660786295, 54.911687989388746, 56.553905933134025, 57.99485529622724, 60.39811111265614, 60.14938577528923, 57.68878882931125, 58.111031978361076, 55.727627277374275, 52.695525307809156, 46.37900706260435, 49.75255527803975, 50.24941367487754, 47.90591516802388, 48.46266815739293, 47.512026832949736, 48.317650287382065, 47.289569608626834, 50.50180642835556, 49.247083356303555, 46.83142108301963, 48.21038915264992, 47.14842311797604, 48.4361647021386, 47.87589334672498, 47.772499668982725, 46.482918493209354, 45.594309453041326, 47.321113309552594, 46.719515862003455, 45.21289033274497, 45.674431708551225, 47.93411700956283, 49.048729096689534, 50.60659254750898, 56.30960502932149, 58.67372343617102, 64.39610458189442, 62.93329977220105, 60.359075684701246, 59.091942233424035, 45.37330742805235, 58.84305607888007, 63.81366791263704, 61.27977755761916, 60.1009484260313, 58.31025700415335, 57.91218350010534, 55.772911041013664, 56.111611627763324, 50.302738297370176, 47.61802888685658, 48.38840984529065, 46.86999367129418, 43.74257026180145, 43.88005718108147, 43.75759293956142, 43.19841592542587, 43.697455160079464, 45.25173356456142, 44.735463357740834, 46.705752265068796, 45.94624803912255, 45.448997405267534, 42.30466858033211, 44.51899951504123, 43.814490841281035, 42.61686178945726, 44.308615346108716, 48.58907830330634, 49.80707230106477, 51.33414122366136, 48.32336125835296, 47.91807843792824, 46.80332514547533, 47.861800270695845, 48.757167554670765, 47.72303073636947, 45.193517746463904, 44.91028339632096, 48.05666754322667, 45.8504206134427, 46.969162956360854, 46.17451821604083, 45.99756048571679, 46.492226277628255, 47.91517588400072, 50.80724923841415, 56.9816521675356, 58.841883290198545, 63.36107346319384, 63.91588095695742, 64.50530336749169, 60.66391444975331, 65.41039028475362, 64.60999927213116, 66.46614720744472, 63.488715233341345, 26.830649568188576, 0.19733735450333167, 3.0116291584507113, 31.097315588305076, 60.37559670786704, 57.06968192131289, 53.30149227573026, 45.06476594555763, 63.433394124431, 65.08289983195644, 68.36823786458662, 42.18322807742704, 29.021330571943714, 35.53638742816064, 26.683244935927856, 63.55115544411444, 25.308497336602983, 0.11608544106204664, 0.08388174772863427, 0.03346826700914291, 0.06258673657993637, 0.014089989652406546, 0.04847972924190183, 0.06962952459411276, 0.014369283284571384, 0.0535169450355874, 0.03855693709826277, 0.023033940721483483, 0.06596823718639151, 0.03280635555124572, 0.040885871201152765, 0.025261517561551546, 0.24019277264033598, 0.16550289256678474, 0.15658018990389763, 0.1715156868580849, 0.20059655300311505, 0.10327674974236759, 0.09535333216791192, 0.1951663685782302, 0.20760046588557385, 0.3105319934266229, 0.09370798981117626, 0.13277000867791716, 0.14103876336687995, 0.30408585384007425, 0.08873324465727614, 0.18163468178001144, 0.16829859255061996, 0.23166725592267132, 0.4708008047553801, 6.592093186993753, 79.14835453033447, 56.295806131055286, 55.606520175933845, 51.93338132673695, 38.484570287889056, 80.84983164264311, 80.65343856811523, 68.62816549116566, 77.3642409232355, 82.28993769614928, 72.597502123925, 75.31449656332694, 39.275575068689164, 1.4496866878001922, 1.1742082118026673, 11.268350751169267, 47.23193037894465, 78.24540138244629, 78.74136155651462, 74.77435481163764, 72.50016458572881, 60.98629797658613, 60.431031565512384, 60.4196802262337, 60.68895486093337, 55.975599519668094, 55.05058303956063, 58.2359790802002, 58.02485750567529, 61.56323548286193, 62.772400225362475, 63.7908907090464, 60.33516099376064, 60.07968917969735, 58.59474259038126, 54.849718463036325, 50.675579194099676, 52.232297312828806, 52.069860196882686, 49.10772938882151, 51.777435733426, 51.153500387745524, 49.28618938692155, 51.61188817793324, 54.43024842969833, 49.82192239453716, 50.26871565849551, 52.09984671685004, 50.58821624325168, 50.135421752929695, 48.86680564572735, 49.27832503472605, 48.1137066502725, 49.10043770267118, 49.70903265860773, 49.70899735727618, 47.81501031691029, 49.83217547016759, 50.067462767324145, 52.54479254445722, 51.74060859987813, 58.54191610890051, 62.27823649683307, 64.93980000095983, 63.75207885619133, 62.04200390846499, 61.29061506640527, 57.257943922473544, 60.52331709092664, 65.3168535232544, 65.28819276440528, 60.625216345633234, 61.32269613204464, 59.05959444661295, 57.177872657775886, 57.61888827047041, 53.47799108874414, 50.846425871695246, 50.84943040724724, 51.78371937044206, 45.192627368434785, 44.690101146698005, 46.453485027436294, 45.60859080283873, 45.78189680653234, 47.43819605919623, 47.48195009846842, 49.422530974111254, 48.14755670485958, 48.22502351576283, 44.5482054833443, 47.67321271281089, 46.92717006129604, 43.77673802837249, 45.522534001258116, 50.99783720508699, 53.36410899316111, 55.235036419283965, 50.84591596357284, 50.70069805268319, 50.170279856651064, 49.87118344153128, 51.446234718445815, 50.05411494162775, 48.38503660694246, 47.972693520207564, 49.43774584800967, 47.45426993216238, 49.23462983100645, 48.485712082155295, 50.731045430706395, 49.04790932132352, 51.025937065001465, 51.865379195059504, 59.669001333175174, 59.709684156602435, 66.19535461548837, 66.53892286362188, 66.84584048486525, 68.22740124117944, 69.76504095139043, 69.03871213236164, 68.8520622253418, 67.67056588203677, 30.044133701632102, 0.3597766154956433, 5.285138853134648, 33.64287107221542, 65.19238887294647, 62.104506877160844, 57.566210839056204, 54.029480257341945, 70.89125540948683, 72.24218245475524, 70.77943648061445, 46.39020542944632, 40.439201093489125, 39.67234242346979, 41.412294064798665, 67.23066422247118, 45.137518067513746, 0.1957996474999574, 0.23249309870504567, 0.11317795352830042, 0.14834751795616843, 0.1736601354974893, 0.15236445402185764, 0.09161346712179723, 0.15365871360465405, 0.2396158624680773, 0.18372555022999165, 0.11917751748114826, 0.12999592769530513, 0.16631902135427923, 0.08724298913993182, 0.14693935642079], [0.060522531820160735, 0.04619214090428526, 0.050094290185839906, 0.01318753328955462, 0.03547503815723523, 0.02427541110063753, 0.00939257886080492, 0.05271183259244408, 0.00852376333392796, 0.03646731737159914, 0.008346475266490974, 0.048829804610220656, 0.08827534624405446, 0.011457046963304523, 0.019414629186353376, 0.014700886357815997, 0.06698541042785491, 0.06838006583312828, 0.1260842061451366, 0.2954838202605325, 18.341250035070605, 56.23880232534101, 63.04680532024753, 48.93018330297163, 21.28168817489378, 47.91863149212253, 73.37268798582016, 66.74363136291504, 70.46181078880065, 67.03835041292253, 69.4876980012463, 64.8022738579781, 41.623749040788226, 3.5319497027704796, 1.0458514671171866, 10.819832624927646, 47.3518725364439, 74.83927003798946, 71.82381460743566, 70.48451346735801, 70.1298370668965, 67.97585179728847, 59.08364642050959, 54.37186002731324, 51.49921024999311, 51.08549433369791, 50.79439563135947, 52.93627254424557, 53.363297062535445, 59.4498977353496, 59.32850822325676, 60.55774373392905, 60.37755004821285, 61.38443031618672, 62.81080022934945, 58.440695424233716, 55.28218723112538, 47.289020476802705, 46.63021133792016, 44.598149022748395, 46.06484090128253, 46.78338773788945, 47.23695101276521, 47.48162454174411, 48.29916807913011, 46.24713305504092, 46.76058700007778, 47.397321039630526, 46.62756766042402, 44.77010965347291, 46.37940714436193, 46.02823734283448, 45.607967145981334, 44.04159999662831, 43.360747137377345, 44.32340660402852, 44.87371906157463, 44.72111140528033, 46.01417172339655, 46.198527043865575, 46.03428171527001, 49.875686322489095, 56.10078196371756, 59.185592743658255, 58.441479898268184, 62.492515579346694, 59.67364934182937, 63.59873771667481, 60.30802211453838, 61.99802237172281, 58.43741240039949, 57.539628936398415, 57.13214174393685, 53.25187429305046, 54.85768871922647, 54.736722823112245, 51.59895612347511, 47.66010415169501, 45.02525983318206, 44.862426557848536, 42.77123451232911, 41.740812178580995, 41.87857758614325, 40.52315942702755, 42.092707618590325, 41.01563261401269, 41.03364806021414, 42.91036098234115, 44.05309646360336, 41.30913572926676, 42.15806607277163, 39.37898835828228, 42.59947784485356, 44.39326793916764, 42.818648122972064, 48.568399567757886, 50.70407521340155, 50.573927048713934, 50.79618030978788, 51.59097802254462, 51.27787482353949, 51.28679429331134, 48.972639037716775, 48.868770753183675, 48.984810152361476, 43.57196677115656, 43.12369085127308, 43.823367164980986, 42.242620606576246, 44.664095832455544, 43.68682945928266, 43.19732550651797, 45.267466191322576, 48.90175788633285, 53.78741510452763, 57.81885462422525, 60.65510480634628, 57.743631409060576, 66.25531981068274, 60.11117012270036, 57.63799021320959, 61.64570331573487, 66.97068168270972, 57.82622083540886, 41.32245217600177, 1.3917299912821863, 2.838289079166228, 30.101727824057306, 53.64870440575385, 59.33490560900781, 52.732305372914965, 57.314331916070756, 63.80765491916288, 62.708540116586995, 63.975265641366285, 39.85660360705468, 24.799224638169814, 36.3851647992288, 35.44300756146831, 56.12989771750666, 4.041119193838489, 0.3511207719003001, 0.03060307902013583, 0.07171161367648071, 0.0402398215937278, 0.011620077176860744, 0.032792014385303186, 0.010659473782946027, 0.09487356194445203, 0.06913693005880041, 0.023515461455850352, 0.04673840372913307, 0.02365595432028415, 0.07777369806482907, 0.030273808684620648, 0.04552457571750687, 0.023713183003447713, 0.03681583375099205, 0.10055313097132791, 0.07275522461221104, 0.05503383359961933, 0.04143060951103126, 0.031619015029601516, 0.03140853045718565, 0.02811389847568447, 0.019165600815247145, 0.05157649794953966, 0.07501976519462562, 0.08345565728602872, 0.01130016460534065, 0.03200131780167501, 0.02059810479441958, 0.03950163459164962, 0.05416126328430349, 0.061972115729605, 0.4937887131687134, 24.8195582051431, 68.45276494180003, 56.27244449430897, 54.972108179523104, 28.33921470949727, 54.87076590138098, 80.54682070209135, 75.58769749056908, 76.47707923766106, 74.28838883676838, 76.06060197276454, 71.08196104726484, 46.86347076969762, 4.323250622518601, 1.1525966875976132, 13.158085942268373, 50.05953173483572, 76.29308085287772, 74.82944057833764, 72.91925414916008, 73.95117482831402, 70.90879624889743, 62.43559022103587, 57.84966484192879, 54.17891079379667, 54.72045675400765, 52.78030341671359, 55.648595440772276, 56.105531953996234, 62.10779382336525, 61.06226644208355, 62.4583125114441, 62.229426522408765, 63.88244275123843, 63.92556921128304, 59.370685469719675, 57.00584142438827, 49.635786318009906, 47.05332133077806, 47.44925322071199, 49.09619369814473, 47.61255325809602, 48.64669399876749, 50.26019627048124, 51.97793160715411, 49.0418061133354, 48.03764404789094, 48.11014121578586, 46.7040656458947, 47.021075525591456, 47.73304062504923, 48.131773087286184, 45.66278619150962, 45.742406383637466, 47.19041993541103, 46.09354088383336, 48.503974637677594, 46.13205071418516, 48.32749543651458, 47.876383642996515, 48.249510872748594, 53.546463904842255, 59.09620977217152, 61.681675372585175, 61.622071035446666, 65.25748452832623, 61.23327001448601, 57.33962335894185, 61.44487011817194, 65.00197349056121, 61.21688235190607, 60.56672988399383, 58.81660753680814, 57.16117905032251, 58.26914272000713, 55.98097708917434, 53.15515648934149, 49.83415234473444, 47.51196799739715, 47.46458576571557, 45.36995380155502, 43.8772762206293, 43.75175253037484, 43.488843902464836, 43.24770442901119, 45.2923850090273, 43.74818317351803, 45.38264659143264, 47.97687084444108, 44.74138613670103, 45.21335709479548, 43.66727252160349, 44.94208989604827, 45.46660100260089, 45.44142723083497, 51.443904830563454, 52.03054628064556, 52.12861730206398, 52.29477674730363, 54.35874362145701, 53.47628093534901, 53.52953495517854, 51.95049462779876, 51.077210287893976, 50.50905889080417, 45.9290406011766, 45.25163550530711, 44.9849731691422, 45.94119602634061, 46.54762583394205, 46.55968319985175, 45.26179836642358, 46.569885284669944, 50.556880427945046, 56.723532753606, 61.39645238076488, 64.71407936465356, 62.18155007208548, 67.19109535217285, 63.27149045082831, 61.513433148784024, 63.647955617597034, 68.83478810710292, 62.57938823392315, 48.98098976381364, 2.8804342112233563, 2.674879950861777, 34.377346654092115, 59.99391478876914, 64.342238672318, 59.23217088945451, 62.66499004056377, 68.57218542406636, 68.10405054400044, 72.21463957140523, 37.35904616694297, 29.915134791404974, 38.28217990936772, 39.424350569325114, 64.77479373255085, 3.5462146276427857, 0.43152641865514946, 0.05507802155109183, 0.04647464731768255, 0.07171068671009234, 0.030460960134082747, 0.03838273253472101, 0.020749181163527315, 0.0770948062680902, 0.051521975471968615, 0.015795171136907753, 0.038754756322070476, 0.029628408336711508, 0.03559231089668409, 0.01983226967915412, 0.05033049041465406, 0.19836578157640275, 0.12742361895019008, 0.2853037374875238, 0.15613938291226664, 0.10615966117550289, 0.20482229399344615, 0.13225259289385813, 0.21400583427279227, 0.1339342171746877, 0.1265730851540162, 0.09541756864036284, 0.1380716895143832, 0.2882818276843717, 0.16943048745874437, 0.23404053502505828, 0.1130518631168431, 0.15938281532256834, 0.14946402981877327, 0.17337813853256165, 0.5063059769811169, 42.778251632567375, 79.16034129358108, 74.94571531972578, 65.13816995005455, 36.37986959949617, 59.25715638745216, 87.69861159786102, 79.73081865618306, 85.72634973833638, 79.1725084858556, 81.91743804562478, 76.92375875288441, 51.929078486657914, 4.916923411430852, 1.305890023227661, 16.77653616474521, 56.09456108462427, 81.87399387359619, 79.44254798273887, 75.80555377467986, 76.90297019097113, 76.31534422597578, 66.0346394200479, 61.58525566900931, 55.86344718933106, 55.98569570049163, 56.327134101621574, 58.554561830336056, 57.507179167962846, 64.99230092571628, 66.82695819485572, 64.37563765433528, 62.53151178359986, 64.99583498124154, 67.86048704578032, 63.2861561929026, 59.34528420048376, 52.86472851230253, 49.768664452337454, 49.05360460281373, 50.02275951447026, 50.9896316066865, 51.32695544150568, 53.04139598723381, 54.656051435778224, 50.709986225251235, 53.01830107165922, 51.990942109015684, 51.20859792155605, 49.182415239272586, 50.520884836873705, 50.8282692201676, 48.16572120112758, 48.15825693068966, 48.243360596318404, 47.98761029397288, 50.895294681672134, 48.089148690623624, 51.21809397974322, 51.24410321635585, 50.87401190111714, 55.628273640909505, 61.379162573045306, 64.11445879167127, 64.64844242219003, 67.83731368280226, 62.86565065383912, 62.612677389575595, 65.66570128163984, 67.6918721968128, 63.308023406613266, 63.20334319145449, 62.081502176100216, 58.210589578074796, 60.55839876974783, 59.88006014977733, 55.112968337151315, 52.16360092163087, 50.1192968891513, 49.53585609312981, 47.21039264432846, 45.735350039697465, 46.79646492004395, 46.18948990298856, 46.362952801489065, 46.48831175219628, 47.14945077896119, 48.21604128806822, 50.5764255985137, 45.4746183272331, 48.60614845829625, 45.449554381832, 49.15085192649595, 47.23015746762676, 47.576122283935554, 52.58396133299797, 55.61951106594455, 53.17039097509077, 55.65341995608423, 56.77804977663102, 55.98809226866692, 55.169128833278535, 54.044389186366914, 53.98322374589982, 53.85318540757703, 47.43999250473515, 48.125783628033055, 47.127603177101385, 48.14692128089167, 49.34183213018602, 47.92722540517008, 48.62370106481737, 48.392740141960886, 53.25662820569931, 60.30571968324723, 64.67456932990783, 66.23892430336245, 66.27543372492637, 68.68092136998331, 68.17358632241526, 66.00468820141208, 65.63988031879549, 72.88308989617133, 65.8379090216852, 54.042443690761445, 3.252448223290905, 3.442491961102332, 39.986183028067316, 65.64038630454772, 70.3259006623299, 61.83739346842613, 68.98299094169371, 74.42433818694084, 72.81558590550577, 77.46270025930097, 50.59722200516732, 38.71362493884179, 51.7847901774991, 49.31326550822104, 76.07640912455898, 13.012928828116387, 0.915396131815449, 0.24811674179809712, 0.21917369487064503, 0.1637118709303679, 0.10446120594297686, 0.10935676058814411, 0.11321785138739694, 0.18687411031175047, 0.18229422219578298, 0.08835570886731149, 0.21588967512211493, 0.26003561433284517, 0.21393061976038644, 0.12476902470112809, 0.16762910831359126], [0.051082386560137236, 0.009736076406683895, 0.052375094814886974, 0.03413186386047352, 0.05756833590567113, 0.03266241146071303, 0.009611552645031725, 0.01776306811089237, 0.06488742502105814, 0.03952200486955624, 0.060665234848256075, 0.05637270631268621, 0.083775031680782, 0.010131321276628203, 0.08978096182428061, 0.08149989610237461, 0.031327455372159044, 0.06607618663580188, 0.10203445390347513, 0.3514362162640018, 6.609205507463025, 57.658021757679606, 47.8812316925295, 49.51030185145717, 21.040976239788918, 40.784918800477065, 69.13572019146335, 66.00150323683216, 71.62258132811516, 68.57670399450487, 58.89712202933527, 66.65194203776699, 50.29592514038087, 9.771641954298943, 1.247149710693667, 7.747547443835967, 40.59644891369728, 73.18624988678964, 69.99365237451369, 71.89586070276076, 69.80780263100901, 72.63298388450377, 67.98122544442454, 65.96214617452314, 57.61482077260172, 51.22603285697199, 51.69519932039323, 50.68305915401828, 55.77730017323648, 58.007300976784, 61.42443849194435, 63.30549740022229, 65.38496548129667, 64.63420814083469, 63.694098380304155, 61.052248708663456, 58.008740486637244, 52.71246994695356, 50.16155258301766, 46.5197495491274, 45.79636643009801, 48.0262730967614, 47.47542327450168, 46.25709979764877, 48.20097546423636, 47.13635006258565, 47.75165227151687, 45.34984380968156, 44.703299922327844, 47.64903130069856, 48.684462501156716, 45.127214001071074, 45.88516889079925, 44.52356123155163, 45.2009427932001, 44.067209151483354, 44.31713081175282, 45.310753468544256, 45.23881719958398, 47.410460979707786, 47.39859580993653, 53.038132575250444, 57.50300184372933, 57.79247276244625, 59.3137679561492, 59.71124133756084, 60.56280751382152, 60.09440591258388, 60.254293487918, 59.38453143642795, 60.24504061668151, 56.84956635198286, 53.519379938802416, 57.28732639743436, 54.07019053736041, 53.963694264811856, 52.113884879696755, 47.36565574522942, 44.77256505720077, 47.081711446085286, 45.33103212233513, 40.32624467726677, 42.13579877730339, 40.15359763176211, 41.547588379152366, 40.79785085493519, 42.75996554282404, 43.8120589717742, 43.65070050762546, 42.27493701442596, 43.189206200261275, 41.95440092394429, 42.6990903577497, 41.39475322538807, 44.32746625715687, 49.460177883025146, 51.39809154695081, 54.58258936482092, 57.94713181834067, 53.54460470138058, 54.47908193834367, 54.25100003519366, 52.305606411349395, 50.45922910013507, 48.93889096475417, 45.96862123858544, 44.8214848579899, 44.518007155387636, 44.4809054559277, 43.85800169360253, 43.5684052590401, 44.361175106417754, 45.05000998896938, 45.61665519591301, 51.00710576580417, 54.89458645543745, 60.400009539819536, 60.046941311128684, 58.74469087969873, 64.41638323568529, 61.44084576637515, 57.430641958790446, 70.41933151983446, 58.87350543852776, 52.40529344927881, 8.263358243050115, 1.0528742257625827, 28.74307567073453, 53.958136266277684, 46.99314432759439, 50.61565322260703, 69.64385540254655, 62.27253729297269, 64.88683623652305, 51.6317157591543, 22.29530119126843, 38.48460558922061, 43.37642485095609, 43.239020301449685, 36.88964828368157, 0.1405514241947282, 0.08716540741583995, 0.02206341265850971, 0.04351004026830197, 0.0455882759284108, 0.009954775356867862, 0.024490746924833908, 0.03447151660258251, 0.02320574168416281, 0.04710333737274332, 0.03672920452851442, 0.06807600553598135, 0.05966315736934062, 0.031027499391066454, 0.015256098047229312, 0.03434947879624463, 0.07995157878124907, 0.044792015631232536, 0.06337259723354252, 0.03507179245653172, 0.046722518896023114, 0.02448730719005389, 0.0421986241464413, 0.029665724479503212, 0.012371100939720148, 0.029367076593541333, 0.0626565769855534, 0.03362206682082146, 0.05247137291477092, 0.04148793970084479, 0.04706936903418072, 0.023410656797369162, 0.02673372596261963, 0.05393871857273964, 0.11204162297109443, 0.38891247143187835, 8.140065400831162, 69.18651488519484, 52.0227054626711, 49.550035461302734, 29.982564257037257, 44.86620380032448, 81.29234560074346, 72.31301261532691, 77.06449339466711, 74.88191404650289, 66.58847024363857, 72.37685311225154, 54.41531204408216, 11.530483730377691, 1.5305620383831764, 9.007775072128542, 43.054515930914114, 76.35943166671261, 73.60851657006049, 74.7850707269484, 73.57280731201172, 73.82306237374583, 73.35073055759554, 68.75214376757222, 58.94073486328126, 54.50878212528845, 53.23055228879375, 53.57080221176148, 57.63097309297132, 60.631598041903594, 61.775341572300086, 66.35319079122236, 66.02018156359273, 68.20960937007781, 67.49304725277808, 62.93868910881781, 60.480449507313395, 54.66807350035637, 52.427890223841516, 49.050388259272424, 49.29004115443076, 49.2618550023725, 47.886064052581794, 49.72873864635345, 51.049773308538626, 50.318121833186, 49.480236884086366, 46.75862581499162, 47.246960901444965, 49.01940153491113, 49.69653990960891, 46.928993963426166, 49.61431918605682, 47.39958424721995, 47.648023251564275, 46.780132170646425, 48.265161129736136, 47.461181148406, 49.46555937490156, 48.62744300596176, 49.78595033768685, 54.54193007561469, 60.96095946527297, 61.80845814366495, 61.20908468000351, 63.394013527900945, 65.66163378377115, 61.66128297005931, 60.66569520581154, 62.627900108214355, 60.460535633948545, 58.62845536201232, 57.610294357422866, 59.94740724563599, 56.25524097873319, 56.896693629603234, 52.920449702970444, 48.847805684612645, 47.14727778588572, 49.08749780347271, 47.452485253733975, 44.8943389615705, 43.14997465379777, 42.62101950183992, 44.15535265399564, 43.51065620299309, 44.8533070471979, 46.29134601162326, 46.05828269835442, 45.507664295934866, 45.83870841610817, 43.76454730187693, 45.04229468684043, 44.90348592881234, 46.24486984745149, 51.20846848334036, 53.489111008182654, 57.54968981589041, 58.00832079302881, 54.1756473818133, 56.79903445705291, 56.92223610416536, 54.42736156525151, 54.4793604266259, 49.90900293473275, 48.43326999295143, 48.46792413342384, 46.4550853544666, 47.95019872726933, 46.332056291641734, 47.476176369574766, 46.057325640032374, 47.55509445744176, 47.60387697527486, 54.477822857518355, 56.398144691221184, 62.01578678623323, 63.53345378752678, 62.69008144255608, 65.00154987458261, 65.62255913211455, 60.561230721012244, 72.0103076196486, 61.90565839890511, 60.5182925347359, 10.874144704111162, 1.1088430160476317, 32.76042211440302, 60.79493730298935, 51.94545438212734, 55.89954083965671, 73.66637937484249, 67.05145112929806, 69.75932998041954, 60.02425432205201, 25.583800654257498, 46.81281728129233, 43.11599123862482, 50.801553956923954, 39.23700248041461, 0.2691732965890439, 0.0665064062923193, 0.015713139399585706, 0.09803448668530873, 0.045367550675667105, 0.024395610295957135, 0.021272871207686204, 0.059404817199514764, 0.02456188584948259, 0.04746014665391657, 0.032923360159921075, 0.04023715177731168, 0.009006957970409384, 0.04143195782577799, 0.07165555902306112, 0.02024593417562785, 0.15528674237430096, 0.1568119008574755, 0.22602026861521507, 0.13735994786745118, 0.18219889021448551, 0.17716308785302026, 0.13828792549189062, 0.10421794238350085, 0.24407944311538052, 0.11629480523087325, 0.38070969223495454, 0.22519468630273498, 0.18710876304295757, 0.11635803046726412, 0.22585922161177283, 0.1281433585550516, 0.10832169153276952, 0.22549891513922524, 0.3208850588529341, 0.9122896146389746, 16.292608841773003, 85.64203446911228, 65.20689772021386, 66.29626935528171, 35.522251206059615, 53.690159936105054, 82.35650816271382, 76.18023426302018, 84.39092389998898, 82.02481685146209, 74.29226413849862, 80.82592871881302, 58.258881799636356, 13.421726092215508, 2.2980909434057053, 10.297791630991044, 47.524864750523726, 78.95387557245071, 77.78864922062044, 77.66238028003325, 78.36252335579165, 79.3390993918142, 77.15506876668623, 72.51112368799025, 62.92733776953913, 58.10060239607289, 57.211326552975564, 55.65533015035815, 61.553951232664055, 64.79663741204047, 66.68208153017106, 70.18981795157157, 71.3386409513412, 69.60205078125, 71.25708703071841, 65.1373540970587, 61.78459444353658, 58.53582074565273, 54.592281541516705, 51.10251742024576, 51.499378911910526, 53.79073342969341, 51.14704808881206, 50.66196856960174, 53.18336617562079, 54.538439166161325, 54.0915164639873, 50.87110542481946, 51.61502607407109, 53.9421526078255, 53.20583351196782, 48.90447608886227, 50.35168555475051, 49.34017296760313, 50.831536554521136, 49.470003420306796, 50.18569084905809, 49.0742519594008, 52.14395376943773, 51.52925952788323, 52.70533907798029, 57.69768476486207, 64.64931318836828, 62.55094712780368, 63.95938788690875, 63.13120295924526, 66.91104596660983, 63.69568694022394, 63.61574903611214, 63.71881715713009, 64.37230756205898, 62.799088032014915, 60.783154502991714, 62.19317205490605, 60.56645924045194, 58.86268361922234, 56.0274689428268, 52.97812423398418, 49.55162009885235, 52.73106982631069, 50.34626483917237, 46.128175412454915, 47.01941244063839, 43.22797490704445, 46.809600937751036, 46.452273015053045, 49.12050847084292, 48.438733854601466, 48.004935403024, 49.56189670870381, 48.57688365444061, 46.36177609043737, 47.6513494214704, 46.01003362286476, 47.77211527670584, 52.30679488951161, 56.84274927262337, 58.460040553923584, 62.94686725062709, 58.570467041384795, 61.360123388228885, 59.5225674875321, 55.75026327563871, 56.476588172297326, 54.23233347554361, 50.051008424451275, 51.32429215215868, 49.82983773754489, 50.12889492896296, 47.79877562676707, 48.67720219396776, 50.728954807404556, 50.83744756637081, 50.856749549988784, 57.225925614756925, 58.19915194665232, 67.07167486990652, 66.30388659815635, 65.17838993380147, 67.18817710876465, 69.09882637762254, 63.776927071232954, 73.50676244305026, 66.07329830046623, 66.75997195705291, 13.885345343620548, 1.5364540512523346, 36.88523953960788, 65.08855588974492, 57.66124594596125, 60.929843302695986, 81.51651690083166, 70.94456042012861, 74.19288696781283, 62.47281743634132, 33.61967809738652, 55.21902530424057, 59.25315164750623, 54.98041968191824, 59.88887371555452, 0.722679972888962, 0.16075832619061395, 0.09067486385784804, 0.19457079650413608, 0.10032525045737144, 0.16197729465221206, 0.1172243609964367, 0.15198214550412473, 0.07365409855640705, 0.3237241194132836, 0.12280559497735194, 0.20970967448046132, 0.1808639666846683, 0.11836200922487244, 0.23497609691994809, 0.11800294381476219], [0.04012172147932072, 0.08326696216939919, 0.03255551538219856, 0.008258725640424078, 0.05243701004092732, 0.061970537588480985, 0.019081070673682036, 0.05926569563246543, 0.04205189915674348, 0.044889247510582216, 0.036337036459196004, 0.034175684089742364, 0.030865356881892493, 0.028234021062211647, 0.04388244709961357, 0.07593708653603831, 0.0827685070614661, 0.04509213440600903, 0.032172777855228034, 0.03399578366248358, 0.06090507399471057, 29.78109367432133, 42.555825787205855, 23.43668345482119, 39.713503776058076, 29.401537679856826, 65.1583230879999, 62.95066802732406, 66.69918306412237, 67.27695603524485, 61.95151090621949, 63.92371785256171, 55.892143249511726, 18.763199006357503, 0.9927157925501947, 3.5429139531427816, 29.756759289772283, 71.8699259911814, 73.87932485149753, 70.04272907010971, 76.5491331777265, 70.90700764809885, 71.69378803622338, 70.2730663361088, 67.04946640999087, 57.00149151586718, 51.765092034493726, 50.46810150146485, 52.25612571162563, 59.5988928887152, 64.66035858277353, 64.26666244383782, 64.11210929193805, 63.786179942469445, 65.79120928241362, 61.07240184660881, 55.00577388271209, 54.78183400246405, 52.28555525502851, 48.480864032622314, 47.94781000383439, 44.302504293380245, 46.18022134227138, 46.053599388368674, 46.18368479513353, 46.04030255348452, 46.639036670807876, 46.3218306726025, 46.59469427600984, 46.76119104508431, 46.72885894775391, 44.59967482474543, 46.23122784399217, 45.97353989078153, 43.69864363824168, 44.00174871567757, 45.12363679947392, 45.57251676436394, 43.97377829397879, 47.20448947721913, 48.26796562440934, 54.255240117349935, 58.23584571961434, 55.853511825684585, 57.27625746880808, 60.678748853745006, 58.18924011722688, 63.453841440139286, 61.976370888371626, 61.34818369342435, 58.11951214267362, 55.26144573765417, 54.34743150588005, 51.507882610444106, 55.576376761159594, 52.75649462976764, 51.9434186720079, 46.37993274196502, 46.31779063132502, 46.176502935348026, 44.71161142472298, 43.42479159755092, 41.30367971235707, 42.042516969865375, 40.93134872374996, 41.891246841799834, 41.93065097255092, 42.735572322722405, 44.233368596723004, 41.31586651648245, 42.142121638021166, 41.79086162197975, 42.85748743241833, 44.7700390508098, 43.24961070091494, 46.915198987530125, 54.32096335195727, 53.90120306322652, 57.72200345993043, 57.92500572819864, 56.459063022367424, 55.56399776089577, 54.884823676078554, 55.14148789067423, 55.25963752500473, 52.106338239485225, 52.44501136964368, 50.954910785921165, 49.37601950860793, 47.99050892553022, 47.023703513606904, 44.384328857544936, 44.84211652509628, 45.689407317869126, 45.412217340161725, 48.9559022841915, 52.34026055182181, 54.985357945965184, 60.06620014867475, 56.676833014334406, 66.0726942554597, 61.50854195317915, 64.71791936505225, 60.47400113075011, 53.352847868396395, 9.65417383178588, 0.5064247206093804, 35.53033913335493, 56.0070373165992, 53.72825791758876, 59.93453010436028, 63.63096783238073, 57.72345473689418, 62.5271854092998, 32.474906906004875, 25.769605290505197, 36.26881945517756, 25.248245808386034, 55.71886470240932, 7.581155107867334, 0.38997662884573786, 0.013236232541291224, 0.022800197719686457, 0.06539400832186784, 0.037038022231671124, 0.08487486580927527, 0.07405136877130117, 0.027389024166510473, 0.042294362154338634, 0.015595325610540329, 0.02394816323724245, 0.029936865978543798, 0.013524684754590835, 0.10010528363167279, 0.010377120587133594, 0.04605506862243337, 0.021749132748452887, 0.09872188971888635, 0.02518706722185016, 0.037275371592371695, 0.044482251809489344, 0.0291963845431324, 0.040394540710915486, 0.0859917147505668, 0.09382674876119822, 0.02480131130845797, 0.039435712725765286, 0.04139178417502873, 0.020360146393819202, 0.00896953553291819, 0.04888287152073557, 0.04549368705239989, 0.04381455638776383, 0.05366908626690988, 0.044979653546526555, 0.029329139919530962, 0.20050358057262438, 35.0453459062884, 55.83402156829835, 29.837926856933105, 44.02209404976138, 37.89155890864711, 72.83930055556759, 72.34349727630615, 76.76336519179806, 73.03774895206575, 69.34311943669474, 70.51505304151966, 61.1463346019868, 21.30581859619387, 1.4921643633034922, 4.539557570411313, 31.912615529952514, 74.08874019499748, 76.17717481428578, 75.13122773939564, 78.03223625306161, 72.87051477739888, 75.15991595483597, 72.17646706488826, 67.06266126325055, 58.4109442464767, 54.23759729631486, 51.310940404092115, 55.0154346804465, 61.45202844373642, 66.1435793292138, 66.44785327296104, 66.95821639030211, 65.72049287057692, 66.50171526016729, 62.22911665516516, 59.934286917409594, 56.434763939149924, 54.38378403263708, 49.66911861973424, 50.036028892763206, 46.70313996653403, 47.8617218232924, 48.48333512583087, 47.26447428426435, 48.3102644643476, 48.75752449035645, 48.085132183567175, 47.7278160279797, 49.583536424944484, 48.92559412987002, 47.441184905267534, 48.89995751842376, 47.751409084566184, 47.53296836729973, 46.531077354185044, 47.62007636408652, 47.39640712738038, 46.375810330913914, 49.67450795635101, 51.31021476561024, 57.95557668132167, 61.11734436404321, 59.959029228456565, 58.98877997552196, 61.782013523963194, 62.589056876397905, 62.678302564928615, 61.6326496678014, 66.09134120325889, 61.44728237582792, 58.32040417578913, 58.37390530493952, 57.561268652639086, 57.924182030462454, 55.762838394411155, 54.031563035903446, 49.70765198430708, 48.20181485145323, 48.02336269809354, 46.92184348260203, 43.644483550902336, 43.88936496550038, 44.23691441935878, 43.58861331016787, 43.795004506264966, 44.98373762253792, 44.55158656643283, 45.45282171618554, 44.673701717007546, 45.29638974897323, 44.06648351300148, 45.9832203003668, 45.83586862010341, 45.970700094776774, 48.9483085755379, 56.45624283821353, 56.70676462111935, 58.03220802737821, 60.12192133934268, 58.83623507715041, 58.11520538022442, 57.21893987348003, 59.57609215090352, 57.36873519036078, 53.161322455252375, 57.36569927584741, 53.90825156242617, 50.96126110323014, 50.02256339596164, 49.20667902115853, 46.974634662751235, 46.75796685680267, 47.88818213247484, 48.77029180526734, 51.87291014579035, 54.82645488554432, 57.71086000627088, 63.555728927735366, 60.65551665521438, 67.93192909609887, 63.99219066865983, 69.35012478982249, 62.80006470218782, 61.28511198105351, 12.776351071173146, 0.5026775087800719, 40.750154833639826, 60.14878957502304, 58.04990183922553, 60.655465664402136, 72.13964385371055, 61.49503723267586, 71.98482790300923, 41.136935833961736, 31.655994461428737, 43.291183902371316, 28.68253977068009, 64.47421466150593, 5.386536534755461, 0.2865466078923595, 0.009421575288738935, 0.01088114994232573, 0.04836656273372712, 0.025701497178224307, 0.03518321611467869, 0.025306906355845354, 0.012054232610089165, 0.05565657881238768, 0.014509868079556093, 0.041653728788538326, 0.025126496480116924, 0.0403956706906038, 0.08065683166346244, 0.02237080735334706, 0.043936276267613136, 0.14525889659360533, 0.21309147769164657, 0.08279665313180416, 0.05937694692082944, 0.25963020060331593, 0.14213264499220157, 0.15209836104223806, 0.16002678883171853, 0.27003232630029805, 0.11230289725767029, 0.13731442692299045, 0.10637262595757362, 0.08311894632154897, 0.16902645268747885, 0.15413434695332281, 0.15969161004308732, 0.16218735596104977, 0.21253339796056672, 0.1294000185425243, 0.12914607571738382, 0.27631593267283133, 58.34838636459843, 66.21412707913306, 42.34624178178849, 56.10202927743235, 45.29031399757632, 78.30113041785457, 85.52257476314422, 83.29158552231328, 76.2386069759246, 75.35019797663536, 77.92077818224507, 66.29754020321754, 25.351833643451815, 2.254733063520924, 6.6475118648621345, 34.69036748332363, 79.58486726207119, 77.96863894308768, 77.38475491923671, 81.51745826967301, 75.93149323617259, 78.0476668573195, 77.52778806994039, 70.92929455541795, 63.29994332405829, 57.31038993404758, 54.48310236777029, 57.45434484174175, 64.89583023132818, 68.73569334706953, 70.0189281279041, 68.66924055161016, 67.14138323260893, 67.21452759158227, 65.7485652739002, 62.02469841126473, 57.80906046590498, 56.532250527412664, 52.798483602462284, 52.56021922634494, 49.09161236978347, 51.680674783645145, 52.50261137562414, 50.66862483178416, 51.5016342747596, 52.51518649439658, 50.89960144412134, 50.730990517523985, 53.49141736184397, 51.20932356003792, 49.622564008159024, 50.79621168874925, 51.034425074054354, 49.919024590523016, 48.39640363570183, 50.404288461131436, 50.32664122120027, 49.362346126187234, 52.85108650884321, 54.41403727377615, 59.549161157300404, 62.60368339477047, 60.41526755978985, 63.53988647460938, 64.83466479086107, 62.42865939294139, 66.77678323561146, 64.85233114611718, 66.02040906106272, 64.53406218559512, 61.767869457121826, 61.05703792264385, 57.67973207658338, 61.02459207657845, 56.973156313742365, 57.73488844594648, 52.14954314693328, 51.45582491351713, 51.649872410681944, 50.15441779167422, 46.90484785264539, 47.00033403212025, 46.94631907247728, 46.47215550945651, 46.28862388672368, 48.83631314000776, 46.93560707953669, 49.246938228607185, 46.04043591407038, 47.35932896214147, 46.85475526317474, 48.73181727624709, 48.789417282227554, 46.60214677933724, 51.51893584958969, 58.24822471987817, 58.14677261537122, 60.6202623921056, 63.15242690424766, 62.2981386030874, 61.82247669466081, 60.44317914593605, 61.203577672281575, 61.8015939958634, 57.80919774886101, 58.47525542782199, 56.18062965331539, 55.111846539282034, 52.51903041716545, 50.331959955153934, 50.77952592603622, 49.75056271399222, 50.10984397703602, 51.901390475611535, 54.82460352682299, 59.54718820510372, 61.096944116776996, 67.25637143658054, 63.2623827072882, 70.22042812839632, 66.74329403908023, 73.15894234564998, 65.55453346621606, 65.86352209891042, 15.45918264696675, 0.7012863240895734, 45.04107875208701, 66.81901147288661, 64.20320241681992, 69.9859017710532, 76.0386759235013, 67.74422014913252, 76.2658517591415, 42.16108237543414, 37.54595495039417, 52.556041902111424, 37.20819965485604, 76.92535907991471, 16.191418555475053, 0.6616443383597559, 0.1469239427317535, 0.05933215759033638, 0.12939624938993685, 0.19832412171508038, 0.23485917658094438, 0.15096075111819854, 0.08188621892083077, 0.19428792619897475, 0.11021977395660455, 0.17612395087076774, 0.1287561063204081, 0.16202149792544304, 0.15913772847383253, 0.0706112892517159, 0.17447220401898508], [0.018155983115936962, 0.061542991578819296, 0.052908640580191735, 0.060548513692112706, 0.08896757563155505, 0.01294884614781627, 0.009925218727139216, 0.024109982074268406, 0.05375116109667767, 0.05021115306824927, 0.009911430102112073, 0.034791925216033574, 0.03092695035100464, 0.027076287923621076, 0.08077921420936623, 0.030345767323348313, 0.009386123612432951, 0.06921240504110052, 0.056537851886523355, 0.03440099054827325, 0.12285844738324805, 1.8282951847199471, 48.52292753035023, 35.342618419278054, 39.468402708730395, 24.741761915145386, 49.980284167874245, 60.9551465126776, 56.20575635663925, 67.27666577985211, 63.87750448719148, 69.67502255593577, 65.41242991724323, 34.196607758921964, 3.1486343616439454, 0.9762946059626918, 20.615242181285737, 71.78185309133222, 74.45316760770737, 72.02522047104375, 70.34352779388428, 70.99135429628434, 73.16493572727327, 70.24160108258648, 69.65508907072007, 64.0728699007342, 56.322164458613244, 52.56429064658381, 57.025123796155384, 58.876953201909224, 65.22548583246046, 63.74023722064111, 64.66082142245385, 67.73293156777659, 63.65434515860773, 57.46441748834426, 54.96152562479819, 52.774561066781324, 50.291936089915616, 48.824804905922186, 46.9455659774042, 46.42065871146418, 46.226599447188846, 47.49510180565619, 47.110752674841116, 46.621813543381236, 44.82031599167855, 43.92330131223125, 46.38614969868814, 45.64841462719826, 47.09462781106272, 46.00538561421056, 45.88873824765606, 43.882171338604344, 44.635925369877974, 44.321378738649436, 44.352530202557965, 45.3841253249876, 45.99593662446546, 46.22178669898741, 52.290081670207364, 59.970953233780406, 59.59848496221728, 62.43937530825215, 59.53667625304192, 61.42605058608517, 60.313646793365486, 56.419623590284786, 61.95183254057362, 63.52471866915303, 58.67895980035105, 56.62579513365223, 55.88083113393476, 54.48383585099251, 55.17758938574023, 52.96882037193545, 52.98119937219928, 48.69067945787984, 43.858295871365456, 46.924647977275235, 44.93921087634179, 43.769599314658876, 41.528996344535585, 42.97082431854741, 42.88800347235895, 42.491769559921764, 42.211225955717026, 44.27901321841825, 44.76392015334099, 43.30806970596314, 43.31531824604158, 42.11827362737348, 43.65996514597247, 42.441833865258005, 42.72566441566714, 43.692991502823375, 50.38147595620925, 55.77521347230481, 57.24168569810929, 57.22474498133506, 56.55279982474543, 53.043172820921875, 52.532382165232015, 55.799814578025575, 54.490013584013916, 55.04066728776502, 56.822651047860425, 55.82862830931141, 58.10026114986789, 52.68176955561484, 49.889661727413056, 45.92400427787535, 45.073567744224306, 43.438335541755926, 45.45361403496035, 43.508240022966945, 47.30964037679857, 46.77639807424238, 52.87336949379214, 56.38831130919918, 60.40502625126993, 63.97076276040847, 67.6683379757789, 55.46620915012976, 57.897545214622255, 8.983666223864402, 0.44301835038969595, 44.07322998969786, 50.205236019626746, 53.427604321510564, 62.227661455831225, 59.79755701557283, 61.700216416389715, 37.187991603728264, 10.34401087991653, 30.07265913871027, 23.13516497612, 39.5297368111149, 42.366147810413, 0.4662590371745248, 0.0518305403661103, 0.03583902185181937, 0.018177456560454542, 0.05924848929768609, 0.02546288760288829, 0.010058309267004652, 0.05809189571488289, 0.055270029997993866, 0.06485113543608496, 0.0808423321934477, 0.03887190648745145, 0.04087288601083621, 0.05203464151089711, 0.04596635181036207, 0.06038556296017863, 0.06678885524912227, 0.03127868429967954, 0.06977492042126195, 0.02493018070386062, 0.07251926953153265, 0.054484387679446133, 0.024709242861717943, 0.04878084776141951, 0.04832780634563777, 0.024373778705334952, 0.033720777249865, 0.022525089800417907, 0.023828739705946178, 0.033848472615523685, 0.015101400955069452, 0.029083691094250932, 0.06423613154179146, 0.02372205621683069, 0.13903509104444137, 0.018352015439661282, 0.02907830741136305, 0.03383477496343755, 3.768495345307935, 62.13981213108186, 39.28763635696904, 42.97757863998414, 34.698055328861365, 55.95389312313449, 76.10411674745622, 64.65894652951148, 72.28317122305594, 69.68145524301838, 75.80403973979335, 68.99635837924096, 38.51722009720341, 3.9410874776301847, 1.6954110442630708, 22.837066804209066, 73.35253484787481, 74.11102710231658, 74.2028497880505, 72.88169353238999, 71.26144086160969, 75.32925251991519, 72.60050665947699, 73.03504251664685, 67.29781519982123, 57.14615245019236, 57.117064152994466, 58.65147183018347, 60.87551847580941, 65.3297895000827, 66.1576763276131, 66.94194639882734, 69.83707920197519, 64.3147389350399, 58.60201466468073, 56.614220219273726, 55.466715135881984, 51.374227846822436, 51.10731840133668, 49.874419396923436, 49.137390352064564, 48.05189794109714, 48.78810328821982, 50.555899835401966, 48.737057562797304, 46.210486350520966, 47.63615808179302, 48.643152098501886, 48.55793468413815, 49.49670299406975, 47.05177591693017, 49.07332628004013, 45.842497425694624, 48.674142745233354, 46.80305057956327, 46.95053562041252, 46.58820667574483, 49.01376901134368, 48.623544170010476, 54.32005728444746, 61.056210302537494, 63.89761840143512, 63.398132016581876, 61.83020768627044, 61.23924770662862, 64.77939467276296, 58.919471694577126, 62.63179502179546, 64.79393882136192, 62.725029760791415, 59.53595453693021, 59.380130537094615, 57.77452399653774, 58.743361196210316, 57.13292621797132, 54.858594786736276, 50.84320560578377, 48.449147747408965, 48.538930800653276, 47.082209587097175, 46.40245106912429, 44.73285105920608, 45.39616700141661, 45.45300214521347, 44.836954685949514, 45.89388439732213, 46.90010178473688, 46.865494712706536, 46.59742424564977, 46.684857799160866, 45.16323312636345, 46.52468389080417, 45.270176549111646, 46.94569541561989, 45.38388998277726, 53.258809043515114, 57.87497981902092, 60.15204121989589, 58.81135156077724, 59.146404343266646, 55.00351459749284, 57.49897356956237, 57.448453441742934, 58.135440887943396, 57.142967485612445, 59.23652472034578, 59.37787517424553, 59.787488291340495, 56.96341706860451, 51.35421983657345, 47.969802733390566, 47.23927305590722, 46.95879220962525, 47.1000014581988, 47.134765425036036, 49.52026074932468, 51.007807870065015, 55.10306827483639, 58.69983465440812, 63.147520019162094, 66.91038700842088, 72.09957292003017, 59.90136254218317, 65.04223269800987, 11.487615166171906, 0.5813988346245982, 48.22606294385849, 55.62234301720896, 61.76176232676353, 64.62215861966534, 67.22593384404337, 63.78292045285625, 52.19085354958811, 16.63271265645181, 36.079953409010365, 27.017672100374778, 46.57700830890287, 46.740143606739665, 0.476562061737622, 0.06152351762378409, 0.033074118602540226, 0.0360383119644417, 0.03786967196051152, 0.05111255127215578, 0.033012241680896094, 0.09234999171307973, 0.05974479169855195, 0.06026771948522618, 0.057310382610247027, 0.04736162391641448, 0.05410693615915314, 0.03431413149941833, 0.028126590637369987, 0.062187834597763524, 0.0702268893139497, 0.15285465836284623, 0.16846415947281546, 0.11435020594827591, 0.19618056173766815, 0.2728131028913683, 0.172926330518338, 0.13321728145162906, 0.09986286276891347, 0.21545518069498001, 0.08209903814619587, 0.1251230492526966, 0.10549663505967587, 0.26211192711226405, 0.07819248768951624, 0.21993812804500903, 0.1965388917033711, 0.0832827665632771, 0.2630924890118261, 0.20407774846159643, 0.10117340938098009, 0.31515260677664514, 8.907542824745178, 81.68618294500536, 49.83594879027336, 59.83671795937323, 39.52842281710717, 64.25112985795545, 79.03333494740149, 69.94692910102107, 81.03939979307114, 75.09409073860415, 82.70166104839694, 77.61578252238613, 41.15024835832658, 5.3697551642694785, 3.1076355422696764, 27.06958466960538, 81.3955431599771, 77.80628419691517, 78.47991989504906, 75.95417238050892, 75.21731591993763, 78.11386077634751, 75.9431662098054, 76.64834560886507, 69.51608027181318, 61.504262647321156, 60.46505812675723, 60.30952045994421, 63.56306768232777, 68.58268953138783, 68.2983333833756, 69.48627810324393, 72.83611559098767, 67.81895699039583, 62.18546459751745, 59.50612883413992, 59.74718986019012, 54.79898260485742, 53.9000577311362, 50.56419957068659, 52.120231274635564, 51.1917866429975, 51.40249636865432, 52.849988245194965, 53.35353428317655, 49.98278664004419, 50.065854595553496, 52.295231742243615, 50.344174215870524, 52.684628963470466, 49.75344957843904, 51.665557969001036, 48.08497921113045, 52.87513848273985, 48.26563965889716, 47.4500023934149, 48.73461784855012, 50.818635879024384, 49.45252533881895, 58.29257888178672, 64.65549484375985, 66.16526219152635, 65.89367728079519, 64.44425559812977, 65.45257145358671, 65.70676065260365, 59.62809885701826, 66.637146857477, 68.13888119113061, 66.44481735844766, 62.76410049007785, 62.179898754242934, 60.850289790861076, 61.76184077416698, 59.69714826153171, 58.265749869808076, 54.58600182687083, 48.593306618352095, 51.46304207463419, 51.49910826836863, 49.09564064395044, 44.843516811247795, 48.537503057910556, 49.74174914821502, 48.30252562799762, 47.45487789953909, 49.399494894089244, 50.03281647159208, 49.860675411839644, 49.22724400797198, 46.88020752322289, 49.39327793736612, 46.356520114406464, 47.975384266145774, 46.60697129464919, 54.40324291106194, 59.58384667673419, 61.27341155082949, 60.92938438538582, 60.19697197021977, 55.89468102301321, 58.61497809810024, 59.23252390277002, 61.970310826455396, 60.21264576142835, 61.9318009961036, 61.73427043422576, 63.743888947271536, 59.78185969014322, 55.31736304683071, 49.61185985995878, 50.3068724755318, 48.989501307087565, 49.84477804553125, 50.30447982972669, 53.5827575960467, 54.43053084035074, 58.98332395861226, 62.704919768917954, 66.3507196980138, 69.70575824860605, 73.76806289918962, 65.46451507076141, 70.13470080591017, 13.744868597676678, 0.8226983285238667, 54.824987919099875, 59.520637681407315, 64.59376065961777, 71.14239692687988, 71.15458765337544, 69.20980591927805, 50.243820375011815, 14.602418349635217, 44.137023418180405, 37.72125351813532, 54.03599531419816, 62.137611681415194, 1.3668007547816923, 0.27223317433268795, 0.10848999338885469, 0.10739543760615973, 0.14359827844365952, 0.1069292807651143, 0.13546573418763377, 0.23783346698168786, 0.1834712396826475, 0.12677684155923705, 0.18476186800868283, 0.19561240028950477, 0.11310808630960603, 0.1568733411090028, 0.12359582999300574, 0.19900132811838583, 0.2208244304863676], [0.02318235876549396, 0.018121708342204654, 0.0679914141073823, 0.03390260821869297, 0.053806453492612615, 0.043087439356191505, 0.026675336656250784, 0.09511804358372766, 0.08086716110307364, 0.0746585394165689, 0.02047805498624521, 0.11499658497350831, 0.018482181438875776, 0.010685809970562978, 0.12381664717630034, 0.04264719926962449, 0.06567019834032943, 0.11233923280791891, 0.0577997251023208, 0.02704936950918167, 0.0866909615034538, 0.09301337022935191, 18.217785589156613, 61.44687444933, 35.99570482007919, 43.29559656881517, 32.88196263774749, 56.478121819034705, 72.16517848353233, 72.86693757580173, 67.08257121424522, 64.93207293172037, 65.64161400641164, 48.29891704743909, 8.75048622008293, 0.5282246105132565, 6.287824146209225, 42.71768239236648, 76.78137671562934, 68.73525404161023, 73.10750438321021, 70.13994109246039, 69.62313744329637, 72.24495949283724, 71.86513285483085, 65.4915637354697, 54.8169078365449, 51.63370832320183, 55.393794352008456, 60.53025576376147, 64.33449983596802, 66.38176918029785, 65.21748811967912, 66.95788691120764, 62.72832455173616, 52.53974837641562, 51.395891097284135, 49.94402970037153, 49.76278874181932, 47.91543868280227, 48.135464037618334, 48.372045716931744, 46.453273219446984, 46.881396001385106, 47.18070814686437, 43.71090104503017, 45.04653869136688, 45.67763236261184, 45.86804774499709, 46.57003433473649, 45.280610053770005, 46.13926003056188, 44.69575328211631, 45.467001084358465, 44.13215967916673, 44.671846435916045, 47.1219902653848, 45.84979303421513, 47.73002432238671, 46.85925814413255, 53.06103921705677, 60.3772323362289, 62.2876541076168, 60.09468047849594, 61.71052440520256, 60.47192227455878, 61.54634575689993, 58.53560893766342, 58.19922254931543, 63.04742113236458, 60.31797316766555, 56.39916450746598, 55.50185172788559, 54.8323933539852, 52.531472175352036, 55.59851069604197, 52.77727926931074, 51.55305262534849, 46.305799945708245, 45.59495664411976, 45.3754255079454, 45.03124929243519, 43.33310227240286, 41.07089488737045, 42.025937111146995, 41.48586988449097, 42.945940802174235, 44.26130371709024, 40.977464029865885, 42.63104900237053, 42.919951177412464, 43.146950506394916, 43.70075779576456, 43.08233730254635, 41.51116524973224, 44.59894526389338, 44.33036488871421, 50.09514685600035, 56.266341286320845, 59.77428951571065, 59.5769315381204, 58.14395243121732, 58.84859446556338, 59.09136564500871, 59.4460577349509, 55.90900159651234, 56.66366561766594, 56.874512626278786, 57.91348964937272, 56.17685241083945, 54.084012969847656, 48.83195930911649, 47.734276171653505, 45.46331405639649, 46.736719377579234, 48.10532454521426, 53.70145243983115, 47.371276501686346, 50.689593822725364, 49.15693160026304, 65.7540056013292, 58.63491942805629, 73.71859396657636, 60.10947565878592, 55.724936531436065, 10.916400397977522, 0.8835765779499085, 36.812189317518666, 55.943134061751834, 51.062772043289684, 65.2765590144742, 56.94661755715647, 69.61515149762555, 14.731668291553376, 17.006310570624567, 44.63812974191482, 23.79831029522804, 53.29197660569222, 18.438065898033884, 0.15985478677095907, 0.08357140551050825, 0.07306623332683118, 0.06561234338028778, 0.04709263512444112, 0.03283160197879038, 0.12173720109727114, 0.04077894447912132, 0.04425968411528776, 0.01373136665807256, 0.044827297810585275, 0.03097867277721244, 0.030606574296290358, 0.04672671322740855, 0.024365208096682064, 0.021467754399524103, 0.04923343718532593, 0.00763165250968849, 0.013547909667625303, 0.05199368645046508, 0.019137962278158917, 0.05301761275698101, 0.03152327702170418, 0.06284775422705759, 0.029495900023668527, 0.03177024270107429, 0.04047024551959288, 0.05690069794053993, 0.012841158125910067, 0.04384571318364432, 0.01520996902047867, 0.048381888322652354, 0.05470178811059845, 0.08151760805518397, 0.06701962391455328, 0.05756534433232681, 0.022899503782091123, 0.012704788729728711, 0.068672887620426, 27.01533436775208, 69.35081512697282, 38.62343395909956, 49.53086683827062, 38.564751378951534, 61.005913749817886, 77.29173198823007, 77.6764145205098, 72.29348705660912, 70.95540185128489, 69.96115946000623, 54.85970873986521, 8.774282259325828, 0.227948006302599, 6.928643824592714, 46.6931418449648, 78.7199846390755, 72.07380294799805, 76.12370506409677, 74.11944450870638, 72.44776172022667, 74.94482886406684, 73.92473020861226, 68.68219221791914, 58.538303605971805, 54.0592118232481, 58.838117814833126, 62.35061207125264, 65.83211960331087, 69.04029676991125, 68.04482275439848, 69.37446701911189, 65.52201309511739, 54.75208282470704, 53.692121121191214, 52.896323204040534, 51.561638693655695, 50.574009418487556, 49.799894363649436, 49.72527911586147, 49.612040288986705, 49.141787329027736, 49.48729322802637, 47.071783927179155, 48.079374144154215, 47.39339082471786, 48.44792789028537, 47.064292200150035, 48.77020551312355, 46.748219766924464, 49.55031002721479, 47.524456824025805, 46.74784321938792, 46.51004952769126, 49.69071911227319, 47.76892638975575, 49.694233555947584, 51.246954779471125, 55.75624489015149, 63.36947125773277, 64.44709147176435, 63.1681909099702, 64.12682602482458, 64.66102930807298, 62.501980258572495, 60.11112305425829, 61.69382687537902, 64.031186872913, 62.57434014351138, 61.18365595417639, 57.595306980994444, 59.38370381632159, 56.214836643588164, 57.30866801354193, 56.800187633883574, 55.072928782432314, 49.020970482980054, 47.93678029890984, 49.199316732345096, 45.88584746083906, 45.77784499814434, 44.83314214214202, 45.143523216247566, 44.01310397732643, 46.41763456406132, 47.38415756533223, 45.544518886073945, 45.494383150531405, 46.811958282224595, 46.28503099564583, 47.3858206502853, 44.768297518453295, 44.387098050886586, 47.425350296881895, 49.323828451095096, 50.65856395229217, 59.33037919382895, 63.56160463825349, 61.57742661814536, 60.6120450265946, 60.95356187512798, 61.216376366153845, 63.312698871858665, 58.52093142847861, 59.848822393725, 60.05877117956839, 59.609922593639745, 59.32319341167327, 56.754637149072465, 50.5742722172891, 51.17721503780734, 47.88286732089135, 48.491470121568256, 50.38315865301317, 57.230557933930434, 50.75873736412295, 53.81937065432149, 51.30027547959359, 68.53042002647155, 61.635873856083045, 74.55805963085544, 65.40980585159795, 64.97930219096523, 12.812714384448144, 0.8750239723632414, 41.89088206137381, 61.421257449734604, 57.82549127455681, 70.79293727874756, 63.44843641404183, 73.93502250794442, 25.166801714128066, 18.535962373979633, 53.05832493689753, 26.09025905209203, 61.826795224220525, 16.71333697534377, 0.1430394326246554, 0.045163970470668814, 0.060054233763366945, 0.02433075137706774, 0.052677419922885396, 0.05622408908581542, 0.0625216880542857, 0.09966318195144977, 0.05782768731155704, 0.005416752988352411, 0.014787632408702086, 0.03829099350578843, 0.03561638137926498, 0.026263692716677344, 0.024017203080978607, 0.00877726565851199, 0.02483881514279112, 0.2217384193453097, 0.12324120023197706, 0.13963355893088927, 0.12600885373690437, 0.12117917499234601, 0.19129077573457073, 0.14372269112256267, 0.22180540607340876, 0.14799412159669786, 0.21684904702969138, 0.1684915088117123, 0.11786422827431273, 0.06082557705080798, 0.121678005483362, 0.11640923578412303, 0.1472271603321837, 0.19773458641382957, 0.1340907442593767, 0.1549934992386449, 0.08566291747434486, 0.16301580344236669, 0.25153026104934756, 43.291450623543035, 84.95834181385656, 52.18427573480914, 60.93569155662291, 45.05829795714348, 67.25739909756568, 85.14470931022399, 84.73942648979926, 81.0399724591163, 77.45956236316313, 77.01527549374488, 61.05021299854402, 11.145074579023547, 0.8223853969285566, 8.812273356222338, 50.12745934147989, 81.94199992764382, 73.85713208106257, 77.81831802860384, 79.34831696171915, 76.01181553256127, 76.43789475963962, 77.85485882912913, 72.45777160890641, 60.72313439461493, 57.19007907375213, 62.48582009346255, 64.23746824264526, 70.63586988756734, 72.38971064167639, 69.25707047985446, 71.31405553510113, 67.16551365390902, 58.3577843635313, 58.08225354840679, 55.28890232886038, 54.63712207732662, 52.806791182487245, 53.21592577042119, 53.24297835749965, 51.71543482811221, 52.25377228952224, 53.25601239358225, 49.13023202650009, 49.868284809973936, 50.27654470935945, 49.425241331900324, 50.60900872753513, 51.808340088013686, 50.32205597046883, 50.952541674337084, 48.932313149975194, 48.846981986876465, 48.34558148537913, 51.66298881653817, 49.7485387709833, 51.99622946400797, 55.03425813490345, 56.14232378621256, 65.29229164123535, 68.43829139586418, 65.37530076119208, 66.7298952225716, 65.10872079480079, 63.62012640122445, 61.70298560973137, 62.95632800748272, 66.55254133286016, 65.66058651093515, 62.913119177664484, 60.185357832139545, 60.32621014502741, 58.22657323652699, 59.47925275371921, 57.38199280154321, 57.051941041023504, 52.30789707553003, 50.49691131038051, 50.760051358130674, 49.93363149704472, 48.17606841364215, 47.41025701645882, 48.55366322302049, 45.03923523810602, 49.09822548589399, 51.35466306440292, 46.34344293225197, 47.4464604931493, 49.70831878723637, 48.91902415983139, 50.09082832644063, 46.44575795819683, 45.07425023663429, 50.074754453474476, 49.93898553232993, 51.91436567614156, 61.186903676679066, 66.35255536725445, 64.29383270202145, 61.86096299079157, 62.115983732285045, 62.745783021373136, 65.35732846106252, 62.303535784444506, 62.739236585555545, 65.69431104967671, 63.002859084836906, 61.44636454120759, 59.70559312451271, 53.233560746715916, 54.347894345560384, 52.00566276427239, 50.351732623192575, 53.65031649989467, 60.1030312045928, 51.91225544098885, 57.44760620978571, 54.16890482748709, 72.80518377980879, 64.5101631841352, 77.17686930010396, 70.12520867009317, 68.25554816953598, 15.667317336605443, 1.2094415147458355, 46.3523349454326, 66.43581944127237, 62.71405889141945, 75.75169178747362, 67.75317099786574, 79.73188554086994, 20.10643820608816, 24.408117263547837, 67.1633328160932, 34.21855734240624, 72.38281511491346, 32.02421284491016, 0.2678187305648481, 0.16742180492128098, 0.23928639869536125, 0.15894498075208358, 0.16523641654320304, 0.22058141207502735, 0.22991034052064344, 0.2072152921990041, 0.16830113596252858, 0.08785864803940059, 0.11359856644224738, 0.1301077305669746, 0.07652792418676038, 0.14364370745756935, 0.12304636875107405, 0.14334703224801248, 0.12463077647431244], [0.03665223184432234, 0.04456337285979141, 0.0777871965340549, 0.044442415237426765, 0.03217707943892287, 0.10183254377015176, 0.08890464916945466, 0.09529891694265027, 0.05039747331231352, 0.04320367021606334, 0.09382387593148217, 0.07712205601555687, 0.08699077001262097, 0.011230247590931193, 0.04994178506275339, 0.10878948014109366, 0.05386405181319964, 0.024412096508087653, 0.01627555327309716, 0.11616231032436895, 0.04764747430360125, 0.028865760147211053, 4.510271683815987, 67.17141289864817, 34.68758260050128, 87.67944689719909, 36.365466656223425, 30.818784159998742, 80.55781118331417, 64.15216061376756, 70.30888542052239, 67.49235691562777, 64.50367558387019, 59.75915308921569, 15.975447950824616, 0.7646177709102632, 0.3949489684835557, 13.62595312057003, 76.97950347777336, 70.42635256244291, 73.51951799085064, 70.46445446629679, 77.31340700580229, 75.11464395830708, 73.93510095534786, 66.8000978039157, 58.03017231725878, 53.48785192735734, 54.79888454560311, 56.98338193278159, 62.8720009711481, 67.42532360938289, 69.29461540714388, 64.55523513978528, 66.07906418461954, 57.41533687037807, 52.044035311668154, 49.805260166045166, 49.12937694980253, 50.27001004065237, 48.10248867157967, 49.40086380127938, 48.484252960451194, 48.494482501860595, 46.71126711753107, 48.34495390615156, 46.603578444450136, 45.84651785512125, 46.30099111987699, 46.58470399918095, 47.89800374738632, 45.810494807458696, 46.59721243766047, 46.07274447717975, 46.3908879218563, 46.64494376028738, 46.98304814677085, 43.92267765537385, 47.5698386469195, 46.16929754134148, 54.51742702914823, 60.43849191358013, 63.163762554045654, 62.297385508014315, 62.437551406122026, 62.886376457829634, 63.758170297068936, 55.02853147445187, 60.53555096349409, 61.657140947157345, 58.460966233284246, 59.00072751506683, 54.86500393959784, 54.28491677007368, 55.47788604613274, 55.52417785890641, 56.12902302895823, 55.33605706307196, 49.34059266121157, 44.17551755905152, 45.998156685982984, 42.78446074455015, 42.76625702458043, 42.409337028380364, 43.05810882199196, 42.770085257868615, 44.51066840079523, 43.6914147100141, 41.95547565337151, 42.89427926463466, 40.93324322854319, 43.539085542002034, 42.28542150989656, 45.46440447530439, 44.166990326296904, 41.293610988124726, 44.939838455569365, 45.7238967187943, 46.84457279020741, 54.15114433534684, 58.58015529571041, 58.89379193705898, 62.004651177314024, 61.32381792991393, 59.623466537844756, 57.728247873244754, 58.87387414132395, 57.262046721673784, 56.430363039816584, 57.09989986112041, 55.956756453360285, 49.332516501026774, 46.59284683965868, 45.465753770643666, 53.100992479631984, 61.83008217042493, 63.11865137469385, 60.36384136446061, 55.07250908882388, 52.6138105700093, 57.27878739756923, 65.09526314273958, 70.04062667969735, 59.438216916976444, 54.96867218325215, 7.550747423402726, 1.0955480197744987, 39.342855484254905, 55.618820728794226, 62.203303537061146, 53.01938756819695, 65.41469704720282, 47.92750781582248, 12.000571950789421, 35.47344907637566, 27.354258529601562, 32.59544526377032, 48.8556621920678, 1.680595516677826, 0.14541646555787133, 0.029110220719068765, 0.05885746269937485, 0.03465831948203906, 0.04914822522550822, 0.03179490307135688, 0.03680321245243953, 0.013117313670415073, 0.035541722280604225, 0.0453545922984279, 0.02242778514271542, 0.022554697183471535, 0.08534961815683112, 0.04407373159342716, 0.05303925091040231, 0.17690007454685627, 0.05403872369037521, 0.0367124501856104, 0.09483891944851607, 0.028593408229250102, 0.02830933516604766, 0.03156588108639323, 0.040031104769197204, 0.13310134170516846, 0.10180308768946318, 0.031329412726805575, 0.004211944225619758, 0.033576331371741916, 0.047198899180418065, 0.04089354357171444, 0.07808890494127428, 0.017007385575843435, 0.03322684206068516, 0.040984543325800094, 0.06870733093350165, 0.053411152123683886, 0.08365115526342586, 0.03622485437400399, 0.14143689926112854, 6.2544300671546695, 81.2382874950286, 37.164367168180405, 88.96556069774013, 48.9047977232164, 41.93811132061867, 90.24670877764302, 69.24793920209332, 78.22713098218365, 75.4027577369444, 72.87224062027471, 65.50391527914232, 20.075578958757465, 0.5321192176591966, 0.30619274884943043, 15.540731664626831, 77.93854651912567, 71.38895711591168, 74.70297551924183, 70.61523037572061, 81.34247349154565, 75.75177807961741, 77.39992664706323, 67.57333032546505, 59.700819600013, 55.56248372600925, 57.20815335550616, 58.22495329764582, 66.79156272642075, 69.2853899924986, 69.85113697667276, 67.09942956124583, 69.91528341847082, 58.56101020689934, 54.32050051227693, 53.84082601916406, 51.78125612197384, 52.77114075999106, 48.94578256914693, 51.52766704559327, 50.1349667579897, 50.34373491041122, 48.647682436050914, 52.371019778713105, 48.98760680229434, 49.554083347320564, 48.62808627467002, 48.86992785238451, 48.26388635943013, 48.49957766071443, 47.425738611528956, 50.00694451793548, 48.12853713189402, 47.7237642195917, 48.10033529035507, 47.645026560752626, 48.800360695008315, 52.22892015211044, 57.76827958322341, 60.8334392886008, 64.89399456208753, 64.45576383221534, 65.4298452408083, 64.07949478395524, 66.25356258884554, 59.05477385367117, 61.31662038064773, 66.78586744493055, 60.20313009139031, 59.940186162148755, 56.73781018103323, 57.439714400999016, 57.94744168558429, 59.02967068456835, 56.85097448287472, 59.49438525784401, 52.510703225289625, 47.99589433977681, 48.28146250017228, 44.94559257261215, 45.991061118341264, 46.38653016859486, 44.98755408871559, 44.861646006184245, 47.69269512545678, 46.106837718717514, 46.32857322692872, 46.50767649373701, 44.34365780122819, 46.26208905250796, 44.19061083947459, 46.46941377270607, 46.64524578279065, 45.4658910535997, 45.55965923493909, 49.51008219872752, 49.28541275762743, 59.091475471373535, 59.70722090813422, 61.836550158839074, 63.31751946480044, 62.70524924801242, 61.97942641473586, 60.52593331183157, 62.885054619081565, 60.69352442218412, 61.495778560638435, 59.028525352478034, 57.64278727193033, 51.27725508905227, 50.53570747375489, 47.335657458151545, 56.863404473950794, 64.83138568939702, 67.02952508003482, 62.29834256633636, 58.652695609677224, 54.6404835485643, 61.77461985618838, 68.11093038128269, 73.73627601131317, 60.69739187917402, 64.9541009626081, 8.548940131741187, 1.1220861634900494, 43.74290758563627, 62.22196225197085, 65.76369385565481, 63.149234094927394, 66.73640635705763, 58.524151694390085, 15.148374034512429, 32.81326036299429, 34.826689458662464, 36.291357394187685, 59.73732117683657, 0.6124255794190592, 0.10846426049547811, 0.06969985146556171, 0.0532838512933062, 0.03189492925641037, 0.06314341437011477, 0.034951535804617795, 0.01333229709416628, 0.017011078119638468, 0.0472600789620511, 0.014926142063021902, 0.02434983654248138, 0.02819865844362686, 0.025688542631424727, 0.01704189783683227, 0.04052810431007416, 0.02020381466155091, 0.018841689264762308, 0.17406904258795325, 0.28246663811226047, 0.1483072064095928, 0.14933526576046022, 0.193750515520092, 0.20613074152460023, 0.16819906240749746, 0.17400884339886327, 0.08447220999627345, 0.11236894169762252, 0.21343623257933125, 0.15917785615930635, 0.16784028811079843, 0.1712592006210358, 0.11030390573244904, 0.21369987407759314, 0.17607934923181612, 0.12535964018635212, 0.10689027156800994, 0.1817425776032671, 0.21342221317031693, 0.39147267598778973, 15.398045643683403, 98.26434719947078, 49.699685650487105, 107.76185666361164, 46.449954894281205, 41.67253940336166, 95.80142821035078, 76.12958861935523, 83.61286686312768, 82.90988399136452, 79.81339239305066, 73.46253379698723, 21.364911064024895, 0.6330217000457549, 0.5901980592358498, 18.594162502596458, 85.75456726935603, 75.1925971431117, 77.14455681462442, 71.29744821979155, 83.14215106348838, 76.44217014312744, 82.8134407535676, 71.15996914525186, 62.98449062531995, 59.39949920100551, 59.254653915282226, 60.0928016631834, 68.62003834016862, 71.08946846377465, 73.32146183136972, 68.94951743464317, 72.67598875107305, 61.02707493689753, 56.65633863018405, 55.07805532024753, 53.88351317374937, 53.43193069581063, 52.71033225520965, 54.427710656196844, 52.3557617587428, 54.71818570167788, 50.822056185814645, 55.64492017992082, 53.291823633255504, 52.73975003150202, 53.54922917581374, 51.19652486616566, 52.998853960344874, 49.8213928745639, 50.515499422627116, 52.682173559742594, 51.5672633724828, 50.64913065202775, 50.287139031194876, 48.14158685745732, 51.60462787074428, 54.04387927824452, 58.5212452180924, 63.97901150488085, 68.16037577967491, 67.12280688747283, 69.10002662289527, 68.95765243038055, 68.48939987920946, 60.34874023929719, 65.81658701742849, 69.17338278985792, 62.89570777646957, 64.30989873024726, 59.62239180841754, 59.943826121668664, 63.29378912525793, 61.53950514331941, 61.489985219893924, 60.18223562548238, 55.07288171399025, 50.600328522343794, 51.935907333127915, 47.20202230638074, 47.41118269581949, 47.08496701332831, 48.992337180722146, 48.667506094901796, 49.74084308070522, 49.20459624259703, 49.392132605275805, 50.122940771041385, 46.87433965744511, 48.35213968830724, 46.48557393781601, 50.00065695854926, 49.66569046820364, 45.3876672252532, 48.97079160136562, 49.571537894587365, 50.020178594896876, 58.83861987821518, 61.67825506579492, 62.71313321205878, 66.86869221348917, 64.33061276712726, 65.63414581360357, 63.09942391610915, 64.96599751134073, 62.88502716249036, 66.07205883149179, 62.27711077659362, 61.09670485219648, 54.93516337487006, 53.13126925499209, 51.609295491249334, 61.408548970376295, 67.2506526208693, 69.87827193352484, 64.10042847356489, 61.51308013546852, 58.26096065582768, 62.782598387810495, 71.90583921247914, 76.00649679860761, 67.17604129545151, 67.76240425725138, 11.559165081670209, 1.6832425036737997, 49.03941346753029, 66.56219820822439, 76.11212622734809, 67.2911314810476, 73.92331031060988, 58.8166977513221, 16.568664273908063, 53.02098789522725, 41.01715841600972, 45.8787009023851, 72.15447825770225, 6.2459896168401166, 0.45107177308490204, 0.24251351343287578, 0.17690477832671136, 0.17046784711701257, 0.1727792109933592, 0.1940865370054399, 0.07965196945494221, 0.07245034460098514, 0.16160551218255875, 0.27096581975779227, 0.15071214026501104, 0.07015283925518875, 0.17439104466428682, 0.12573270202283898, 0.07725666532473219, 0.3600637758931806, 0.13486346650508144], [0.047455634396042556, 0.038556205484295086, 0.006798257536795592, 0.051119783142160986, 0.009569673491041026, 0.08794873231841673, 0.1014496377038379, 0.028940225808670925, 0.07423484682916634, 0.09520242050770791, 0.01976715220559028, 0.02719506794106095, 0.013427837834423108, 0.05126964526190873, 0.023891549339638125, 0.03297945311773689, 0.07796345804367336, 0.07814757961539492, 0.030125239338245124, 0.05412388202403823, 0.02284164499160984, 0.020932253194792617, 0.4593783112302904, 37.56153068234844, 60.114327630689075, 28.505935053671564, 38.57755791756415, 11.003472112840223, 45.28323804178546, 79.77307042767926, 66.45488216030982, 65.84345525310886, 64.01918834255588, 71.15046131995418, 33.10268225208406, 0.38739258363362283, 0.38345421754544784, 0.5806954433360408, 42.53634337455996, 78.68093352163993, 71.43319360671505, 77.76899814605713, 74.9180704547513, 76.68279970845869, 69.38223331205307, 61.65967872065883, 54.904717937592544, 53.63393668205508, 51.9984063794536, 57.19806501942297, 59.30551921167682, 64.6384286111401, 68.41544751198062, 67.14570568453881, 67.42641402829078, 64.75041227955973, 54.59618822220833, 51.54387427914528, 52.0525154759807, 51.14671468734742, 50.389316774183705, 48.61462470023863, 48.907100154507546, 48.24571401842179, 48.889931940263324, 46.90531461469589, 49.277336597442634, 46.36528268937142, 47.418913687429125, 45.77361276072841, 47.688976718533425, 47.7696559506078, 47.52690438301333, 46.44218860134002, 45.42165848516649, 46.116227872910045, 47.257869012894176, 45.241919794390284, 47.24424662128572, 47.76624741092805, 50.699560565333215, 54.8352135381391, 58.439201001198064, 60.50870233966459, 63.07450117603425, 62.579321553630216, 62.52005061795635, 58.18490982055665, 61.999552096090014, 62.19546664145685, 61.143616399457386, 58.27238652013964, 57.29098989117531, 57.28861293485088, 59.39573764801026, 56.61200408012637, 59.34011059422647, 58.875717655304946, 53.54181981855824, 47.25789646948538, 44.29225906249016, 44.78792113642539, 43.60076481296171, 42.94845111908452, 40.35093991987167, 42.678395932720555, 43.24457437761369, 44.132991221643266, 41.92279838746594, 42.7494300565412, 43.73179551093809, 43.25115219239266, 43.00330546594436, 43.12767597936815, 43.59626585437406, 45.81905734154486, 43.442348126442205, 48.677649344167406, 47.73233852078838, 47.125838110523844, 54.51321440358316, 60.27081451108379, 59.72818597670525, 61.36177078370125, 60.62240008384951, 59.07538983129687, 63.26452824377245, 60.13119382243003, 60.23714488552463, 62.175458631207874, 54.98496963131813, 49.38468794668875, 46.182425714308216, 51.069620501610544, 61.53786167021721, 66.45698455072218, 66.44369556057838, 64.47798405924152, 63.41475502137215, 57.11742893342049, 63.85631192115046, 63.64819095980737, 70.40359497070312, 55.1491718138418, 51.52696494133242, 3.5570587554285606, 1.437906952154252, 42.169456635752034, 48.75041715560421, 66.30907197152415, 52.603961498506614, 71.25711056493944, 22.597482550528742, 21.182203139028243, 45.756064076577466, 32.518525623506115, 44.588664731671734, 33.31665538972424, 0.27627036576309516, 0.09347591113539473, 0.10639078224137907, 0.07024065591394901, 0.007336004336755122, 0.01429558179581598, 0.07642809526934739, 0.06745106931174956, 0.038564471572998076, 0.062316928073884024, 0.031106433260344693, 0.05091348715547112, 0.01916159609062297, 0.012091734529202505, 0.060477301989111214, 0.11275271344329081, 0.06633145479305137, 0.01845826800431936, 0.03793100495972941, 0.052106891263036, 0.04040017911803819, 0.043033974079955975, 0.04201134246203207, 0.039726439262590105, 0.09284769605484702, 0.019800026953640967, 0.09501454510515737, 0.08975791789951826, 0.011491094783489263, 0.04912800050430721, 0.020675546707465284, 0.037150506921593225, 0.08865689633474236, 0.041280693765128815, 0.05812165823074118, 0.02665639896276257, 0.039351718845747174, 0.08237543500839703, 0.02393840710752674, 0.06037266970041299, 0.4256708715711871, 46.42675015234178, 66.05758528555593, 34.40786269403274, 47.71274235940749, 18.375404073346047, 60.0892166168459, 83.80432559597878, 78.06174032149777, 73.2839169040803, 71.00418044674781, 77.12083431982225, 34.853769502332135, 0.3548242554308907, 0.17655645346929952, 0.9206013621822481, 49.329162874529445, 77.33599985799482, 71.74252740798458, 79.98880863189697, 76.66885960486628, 77.26207102498701, 71.45568447728311, 64.54349548585954, 58.10811765732304, 55.70035895993633, 55.30607054310461, 59.47055293667702, 63.501478625882065, 67.25023684963104, 70.08119183201944, 70.0775989409416, 69.16244722181752, 67.06826240785661, 57.0439080269106, 51.8000638869501, 52.41988074394965, 52.93544884650938, 52.914683818817146, 49.88494703846593, 48.50484540385585, 50.39682811306369, 50.892031269688765, 50.718172211800855, 50.534362100785785, 47.686105543567294, 50.74678982457807, 47.73537835767193, 49.67684568897371, 49.69874820401592, 48.58710535110966, 48.027606702619984, 47.95253645989203, 48.18643916037775, 49.74150203889417, 48.65555855535692, 50.20227070777647, 50.48499122742684, 54.30980028644685, 57.58704254704138, 63.641307200154955, 62.840378822818884, 65.70302263382943, 64.85472771429247, 62.4662749228939, 60.70753120606946, 65.60297866021433, 65.05451363901939, 62.758491500731445, 59.89525933419505, 58.738642584893014, 60.25900033212478, 60.46199083328248, 59.844947091994754, 60.91185923545592, 61.81805226110644, 56.66607003058157, 49.29339085855792, 48.32078426114975, 46.383007880180116, 46.60401774990944, 44.722550915133574, 44.00121527333414, 45.594489882069254, 45.085338777111424, 46.14322946917626, 44.578086099317, 45.408059627779075, 45.076101595355624, 46.809581325900176, 45.14024019241334, 46.17501243468254, 46.78600003642421, 48.37399513490739, 44.59656438519878, 49.28981757933094, 49.44168783003285, 49.670699334913685, 57.91574108985163, 61.88176724218554, 62.59730562087029, 63.21214499012117, 63.94530265561996, 60.576437750170314, 65.90557775189801, 63.092575457788286, 62.11768996331, 64.5052170753479, 57.49886766556771, 51.62851510509368, 47.93211267840478, 53.01951308404246, 63.52909995663551, 67.81516013606903, 68.41127411011728, 64.60683391940209, 66.21633929591026, 58.10616431697723, 66.5763658092868, 65.89953730183264, 74.53194449024816, 60.72180078875635, 63.02305144648399, 4.527641409827817, 1.8458736543693852, 45.69304727738904, 57.55047428992487, 71.56455378378593, 62.517030392923665, 72.4892839308708, 36.9913867212111, 18.93999984187465, 46.60835196894985, 35.36985928012479, 51.09085621372346, 39.726945738638605, 0.2516181926212965, 0.033646934034843604, 0.06849501732616656, 0.07531968861698143, 0.020071903897088864, 0.05814189061282143, 0.04195305849275282, 0.02727298099818009, 0.030946029770758846, 0.03275790815091422, 0.07706944109691728, 0.046823167527515086, 0.013775990322051991, 0.021027223199545857, 0.03991598090637596, 0.06407008198420368, 0.048438846959822604, 0.025594388510310845, 0.06165780134559159, 0.12632767654835217, 0.10817670939309944, 0.09460956038486573, 0.09855944843542191, 0.17533377714214787, 0.15254451532758054, 0.15078471943495736, 0.2621978208903344, 0.1681159571894715, 0.15542348906878503, 0.1383425628826503, 0.20006317194671402, 0.159640833735466, 0.13153597892772767, 0.11060977399709726, 0.1858395698570436, 0.14737064860040142, 0.074209657858216, 0.28529120428908256, 0.10356623138631545, 0.17468179035330975, 0.9615219180141726, 61.72746904434697, 79.0081690203759, 43.0497855524863, 52.686021404881636, 18.130799185845163, 55.44532252896217, 96.23567381212789, 80.88004173771029, 80.23607484755978, 78.12275671189832, 84.91222258537047, 37.44064323363766, 1.1484511100476789, 0.3412732325734631, 1.3086266118672587, 54.59560771142283, 80.98674589587797, 74.13377684931602, 83.6292153020059, 79.95080086492723, 82.41588500238235, 73.19662063352524, 66.94273871760215, 61.21179896016275, 59.05624474248579, 61.24995185482887, 62.23597295822636, 65.43942759113928, 71.39970441018382, 73.30164601725917, 72.23115274983068, 70.90288915941792, 68.70130985013901, 60.062269933762096, 54.71396915374264, 56.25595877247473, 57.26586318785145, 57.34671892658357, 52.77835007636778, 52.163444026823974, 51.72630371585969, 54.99108460641677, 53.60118489111624, 55.03020240414528, 50.022194693165446, 54.01487727319041, 51.16119215565344, 53.480195460780976, 55.8387597914665, 52.92389746635191, 51.99218550036031, 49.78569538362565, 50.595743271612356, 53.35366372139224, 49.78382833542363, 53.37509555201377, 54.421485854733376, 56.17440485185193, 59.5258112876646, 64.2704043849822, 64.55514100290114, 67.08813313514956, 65.73700604900237, 65.43028062389743, 63.84078325763826, 66.9591106907014, 66.09800138781148, 65.65578552984422, 62.96855795768, 61.8627162902586, 60.759479076631614, 63.234612326468195, 61.858617413428526, 64.18956825810095, 63.29433825708205, 60.16883680897375, 52.99975610548451, 50.713802691428896, 48.22704353640157, 49.23302558160598, 46.377410657944225, 45.87634355791154, 47.380670578249045, 48.71152293297553, 50.16984055119176, 46.51961618854154, 48.121539623506614, 47.0954671982796, 49.87784362608387, 48.67826907865463, 47.87674450105237, 50.59053044165335, 52.485968758983, 47.181406328755045, 53.3788884839704, 53.77548717683362, 49.77956864141649, 58.06384978755828, 64.89407693186115, 65.40517745479461, 65.87655221262287, 67.75260617656093, 63.154368477482954, 69.20971178239392, 66.52896004338419, 63.765050134351185, 66.91518798951181, 60.647644458278535, 54.24867406968148, 50.73290855653825, 56.668933360807365, 64.98616241639661, 71.23190541421214, 70.90828634077504, 70.22971630096436, 69.6040355005572, 60.66093344842235, 70.52531396189045, 68.34170695274108, 77.56108899270335, 65.9895400078066, 66.13960989059942, 6.7906499389679205, 2.0524848709183354, 53.42102650673159, 60.990710643029985, 78.53807295522383, 64.56069900143531, 82.8606660904423, 29.414640357417447, 30.109960879048995, 68.67004071512531, 45.893056777215776, 59.08539187523627, 55.544287850779874, 0.6725545335681208, 0.20123173182289447, 0.21984794417456274, 0.31442807146137763, 0.14906348840844247, 0.13198576446983123, 0.12298262257489467, 0.09017443990394955, 0.11853255571857577, 0.1242919204636447, 0.2707528473148423, 0.10676643345505, 0.10354151738987816, 0.18333404865716735, 0.13209298613571352, 0.18099282267353228, 0.18004771532310596, 0.1292348959513249], [0.02084951569897033, 0.03828408339271142, 0.052364082300975445, 0.03707059245977191, 0.041588381488597205, 0.06936827329017463, 0.04382906226261009, 0.0036051638063884553, 0.0063132649877168726, 0.0898261150465377, 0.018399993611139157, 0.11430211094838959, 0.0735630107022101, 0.02038540431268273, 0.03481922475921531, 0.0320316874422133, 0.018550924423541275, 0.06090579794779901, 0.012038217542032081, 0.05586169502367416, 0.0680342231005911, 0.029854553661519484, 0.2244513052245302, 15.643719377056247, 68.80883770604288, 35.62222065464143, 43.42967494841545, 29.687615748374697, 11.093200252902124, 76.83505042906731, 54.62973233192198, 55.381030959467736, 72.98142371639129, 68.78432289246591, 51.3704780609377, 1.753641938970935, 0.45682739166002123, 0.08542693175014951, 18.24474011698077, 81.2300818966281, 69.95995136999315, 79.75723974166378, 70.79727542015814, 72.62735920567667, 65.6159067923023, 60.65545389729162, 53.49435521710304, 53.96508670622303, 51.35862465827696, 55.40474168715939, 57.064147456999756, 62.84516803679928, 64.29050260974516, 67.95528288810485, 63.192074221949426, 65.80930709838867, 61.22562139264999, 49.59546827500867, 49.56960024372224, 51.198599799986816, 51.16046259480139, 53.2099441559084, 51.52276800524805, 48.20108529060118, 48.68349759809433, 49.83588603235061, 50.214614406708755, 46.709156882378366, 48.307126568209746, 46.85977197462513, 46.59887552261353, 45.708144480182284, 47.61698945876091, 45.17559643714659, 45.39826154708863, 46.818030111251346, 47.318379417542495, 47.06189955434492, 50.54617235737462, 49.38744929529006, 51.552225005242136, 51.53473515664378, 55.582864361424605, 58.64372907146331, 62.348823470454064, 60.68536981459587, 62.84223410391039, 58.63020081673899, 64.36581211705362, 60.638709299026004, 59.010360856210035, 61.30698703950452, 59.339090777981674, 62.76819936690792, 60.06604717623804, 61.338158115263916, 61.54671053732596, 61.931353845903956, 57.774367101730846, 48.74080734868204, 45.6423153415803, 44.897857327615064, 44.279397610695135, 43.72290349775746, 43.08360422811201, 41.79202656592093, 43.56169800604544, 43.783382523444395, 42.881245228552054, 43.892024332477206, 42.52688654007451, 44.15284233708536, 44.20311143321376, 45.01406538871027, 45.061628049419774, 42.57513953793434, 44.20203670378655, 46.60570044671336, 45.129339925704464, 44.20820266969743, 46.11146611552085, 50.048227463999105, 51.28618632593463, 52.552009705574285, 51.54083051989156, 57.82456167282597, 58.89461171242499, 63.233490528598914, 63.71970361278903, 61.44583109886416, 55.41656763322892, 49.08127692437942, 47.34142334230485, 51.52540776037401, 64.71398522776943, 65.07639654221074, 67.34843730926514, 67.09016492289882, 63.49924679725402, 62.87518985809819, 64.15796179925242, 68.58313668158748, 65.91730563871323, 52.348662268730905, 43.72126002465525, 0.33020372172036483, 3.9574898490982675, 34.63677613965927, 54.081326146279615, 49.04579516380064, 51.15212363581504, 52.41997095846361, 4.324413114978421, 38.2413205792827, 37.617467603375836, 25.058267770274995, 55.68570498497256, 16.662324590067712, 0.3561298224714495, 0.11157921229999875, 0.07324203518369506, 0.022860722496144237, 0.01648950247815059, 0.007851807026928592, 0.026857523855963544, 0.055483711072273796, 0.021007111476313685, 0.0993094485132925, 0.016739053704265146, 0.02176129247903103, 0.03182916060811089, 0.02801021996645197, 0.040653256263824246, 0.03160170144251278, 0.007827122237593418, 0.013750695056402156, 0.03078892428968703, 0.05563126726736946, 0.014822220320873445, 0.10471134131113369, 0.0811697811549229, 0.052641153320549965, 0.027898526262311686, 0.03370524098676059, 0.029298119104257035, 0.06817846213497462, 0.07152206820225523, 0.08230647943433254, 0.016563675110979427, 0.03411259674917787, 0.027142091045877146, 0.019458979931509784, 0.03797349985688925, 0.033791985122426864, 0.04247916554431281, 0.12212133290426386, 0.06464190916308472, 0.14982517898803757, 0.27934191868670527, 16.27299601031888, 80.5927045883671, 35.652167950907064, 53.036167467794115, 29.42567986826743, 24.032301249042636, 87.96999254534322, 64.40627921012141, 66.45088918747442, 80.01818718448763, 74.75284453361266, 53.914813687724454, 2.2356102831902045, 0.6065420241605851, 0.1998702710073802, 22.75070013538484, 85.48203314504316, 68.87912657953078, 82.91386911945959, 73.97928253296884, 76.29356722677909, 68.22718943319013, 62.26522991734167, 56.56940714005501, 57.077734547276656, 52.72780249195715, 57.73744190892866, 60.25054370203326, 64.36155634541666, 66.84566790057768, 71.78978412382065, 65.48615086463191, 68.83125797394784, 62.98782463996642, 53.96324319224204, 50.54407781170261, 53.508256096993726, 53.55171595850299, 54.4823924187691, 53.4773870437376, 50.94205325649631, 51.635018394839385, 52.846744445062455, 52.30484154916579, 49.873317210905014, 50.49657398654569, 51.26363269744381, 49.03846033157841, 47.49083426690871, 49.21573185151624, 48.550035030611106, 48.36981781067387, 48.97408639231036, 50.32989286607312, 48.524614149524325, 52.16069836770335, 52.25553735609978, 53.898355422481416, 55.4224080424155, 58.20593372468026, 61.853836044188476, 64.53681961182626, 64.45120603807511, 65.0533643845589, 62.083855598203606, 65.7607050095835, 63.28083353657877, 63.38359963509345, 61.929216154160045, 62.311631556480165, 64.25726444490495, 62.06911925346621, 64.98106333517259, 62.805234386074936, 64.93474014343755, 59.43157634427471, 51.88832898293772, 47.3430589706667, 48.28522405316753, 48.172224490873276, 45.500513815110736, 45.19793433527793, 44.30213166821388, 45.31515044550742, 45.25615407574562, 46.19101178261542, 47.68138300987982, 46.614027638589185, 46.19798183441163, 46.24907070590604, 47.612313993515514, 48.38743317511774, 46.03246173551006, 48.152898973034276, 48.29810511681342, 48.429806540089274, 45.78226550932854, 47.77181325420257, 53.12597013288929, 53.930087397175456, 55.10517066524875, 54.48774253168414, 60.25939256914201, 61.53860692054995, 65.45162224000501, 66.49077969212686, 63.10269125046269, 57.83761532075944, 52.39425589961391, 50.828151549062426, 54.32576433304818, 66.44768068867346, 67.51746008473059, 69.34588078529605, 68.84890079498291, 66.66155184468916, 66.68459969182169, 66.24242305755615, 71.18833572633805, 69.008878584831, 59.97238097652313, 49.20952273953346, 0.391693860893288, 3.72662355342219, 39.75730096140216, 60.237745008161, 57.14509341024584, 56.89330862414453, 63.59718445808657, 11.79006422719648, 31.787805711069417, 45.178757867505475, 25.030646439521547, 67.50636762188327, 17.99232775165189, 0.48791009151647174, 0.09404895256363577, 0.034693398648091865, 0.03686004468510228, 0.10941813189175822, 0.0840208692956836, 0.01904922248344989, 0.060812507590819756, 0.04263263976862354, 0.06556886022970562, 0.0219260320262683, 0.022046987733413136, 0.024472542760533192, 0.09164316835062158, 0.01276998089686517, 0.02921944187443343, 0.017517408611433163, 0.02380156848249176, 0.1258049900793741, 0.14765967825247397, 0.17920892565481125, 0.21630008374491047, 0.17505493645946826, 0.2599308441483206, 0.07398152453524452, 0.24936728840393407, 0.07616694355683942, 0.21697393468310758, 0.13496059113212172, 0.2329224756648464, 0.11912825036673777, 0.143594034316559, 0.056118836265898524, 0.14515380465215252, 0.1514232843633621, 0.22761354763661662, 0.09696574806566201, 0.36757701467121806, 0.2812754020335213, 0.3061225139085324, 0.4640948387884325, 27.789571016065537, 91.81110689716955, 46.45349287217664, 66.55091747160881, 40.02626965122838, 18.590279356125865, 88.98968327429988, 71.6844214162519, 71.93025988917198, 87.7544112359324, 80.63707443975633, 61.47022431896579, 2.1629062102686976, 0.3333740080556562, 0.27042051837328945, 26.381742146707353, 88.75024610950102, 70.53963845775974, 85.04071943221554, 77.92956429143106, 79.70282862263342, 73.73630739027455, 66.63267535548057, 58.24151746688351, 59.94703854283979, 55.68463810028569, 61.29135247199767, 62.44531769906322, 69.0446113771008, 69.13271565591135, 75.09275713274556, 68.84046769911244, 70.60471057891846, 65.66416763490247, 55.56519016142815, 52.56874253672939, 56.19108276982462, 56.20854908420194, 57.75788530226677, 57.47242696823613, 52.80319044666906, 53.21825565830354, 55.99946321979646, 56.21688019844794, 53.619400378196474, 52.89624083426691, 56.055913971316436, 51.65268082772532, 50.7432871480142, 52.85240442522111, 51.079544098146506, 50.5777435148916, 51.12662038495464, 53.08929989414831, 49.868178905979285, 54.687014625918486, 55.634761241174516, 57.50648883081252, 57.69342507085493, 62.09717988967896, 63.926553726196296, 67.72201953395721, 65.08824994487148, 67.91723589743337, 64.21033328579318, 67.57263214357438, 63.92811875189505, 64.27129476301133, 65.45026117755522, 65.33231942884385, 69.25867865162512, 63.66474336193454, 69.42655609500024, 66.4319912079842, 67.39472127729847, 62.60509152566234, 55.58313500496649, 50.705244079712905, 51.81493751464352, 50.289049225468794, 47.772891905999955, 48.743549085432484, 47.60283362480902, 49.17539027429397, 46.76871022870464, 48.777112806996996, 48.88029075437977, 48.53223139239896, 48.40968085873512, 48.933999769149295, 50.24426752521146, 49.68862848897135, 47.64058251534739, 49.52995684839065, 51.34662612791985, 50.957707435854026, 48.609498162423414, 48.04620658197711, 55.66135491094282, 56.31470018817533, 57.79070377349854, 56.79602599913075, 64.06721776531589, 64.10503333614719, 68.56253639344247, 68.87179174730855, 64.43710511730563, 62.088852697803134, 56.15051761750252, 55.94198088492117, 56.51910274259506, 70.73352121537732, 70.43654288015058, 72.85786905596333, 71.58700543065225, 70.2057663086922, 67.1628385974515, 70.75386262709095, 74.25191863890618, 71.55969788951259, 65.98204828077748, 52.67834924882459, 0.735115786233256, 5.225831145240415, 45.50266719633534, 64.97442276247087, 61.646605460874504, 62.86503091935189, 63.07818428162606, 6.522175467783406, 54.90430608872445, 54.64280951407648, 39.22402727988459, 76.273147367662, 30.746787094300796, 0.62384482473135, 0.20912211568605518, 0.10630412237538446, 0.1679188580883126, 0.1349659231040747, 0.17700222471067983, 0.20832328516389095, 0.17300344492879607, 0.1152621953177356, 0.1948724972504762, 0.0843091941468658, 0.16764550259517086, 0.0909464496878847, 0.19773939744599406, 0.09310402907431127, 0.06457505266993277, 0.08089857836884838, 0.26992403211132177], [0.011322186760333999, 0.07328682068374849, 0.05740026387596323, 0.06385225637425339, 0.052160195660807436, 0.05713735399166903, 0.04443694920008702, 0.02692437077301645, 0.057593160984857436, 0.03344251496356822, 0.06988058692865795, 0.053068603569221114, 0.030203878263672514, 0.04524369341050906, 0.03665736463341502, 0.036001175852312196, 0.08080094046289883, 0.06198273753867515, 0.030236810468317523, 0.06993291073388631, 0.05378499153941389, 0.11534623516302918, 0.11335866600875893, 0.3922036464416212, 48.20921244159822, 56.6006645079582, 30.821155232767907, 54.72740327158282, 13.927051905662784, 29.457515785771033, 74.0159410045993, 66.06512408102712, 79.44017102641445, 65.32038757877966, 65.76851444859659, 6.281328701203869, 0.2992689381203344, 0.09111558657980735, 5.5787973923067895, 62.49408060504545, 74.29740244342436, 78.86881505289386, 70.04949123628678, 68.25060598311886, 58.78862142562867, 56.46442882476315, 51.605890873939764, 54.47066453195388, 53.09388906724992, 55.633635520935066, 57.477318163841005, 59.907932512221805, 61.02983236312867, 65.82163903021043, 68.06058283775084, 68.42548877962174, 61.64451483757266, 52.769101127501465, 50.99237334343695, 53.69219956859466, 54.4586463897459, 55.30555671261203, 56.03437231433008, 51.99246006627237, 46.944757969148704, 50.20005849099929, 48.488779375630045, 47.669913999495975, 49.25054680916571, 47.68003763691072, 45.644853115081794, 45.36190117559126, 44.17673349380494, 47.31763024483958, 46.924918620817124, 47.424012768653135, 46.38612616446711, 48.47440388894851, 53.241068163225734, 52.037010346689534, 50.46455567882907, 49.10716064514653, 55.07252085593439, 55.970304319935465, 58.185003957440784, 58.970427205485684, 59.03756641572522, 62.35945701599122, 62.68221709036059, 63.62289951693628, 58.104638514980195, 57.84939812075708, 63.82738444112963, 59.58744741255238, 65.13484378014842, 62.149570988070586, 62.47762626217258, 64.53005744564918, 60.15741486703197, 51.12030144660704, 47.006064614942, 46.08970872817501, 44.335554184452185, 43.84555993541595, 43.143891057660504, 42.61754428186725, 43.92472905497397, 44.108852955602835, 43.28584163419662, 43.643753990050286, 43.4289179309722, 45.61927533918812, 45.06790384169548, 45.439152256135024, 45.78951797177715, 42.39802099043324, 44.13170076185658, 44.082482860934356, 43.55308055877686, 46.10021283549648, 44.14485639141452, 44.9523861177506, 44.755443911398615, 48.11598946971279, 53.09925486964565, 62.301684425723174, 61.299848325790904, 62.61983571514007, 64.35341350493893, 61.90769410902455, 56.43497574713923, 51.03196574795631, 48.38634275620984, 53.945298348703695, 63.01173540853686, 68.8666691318635, 71.2161845545615, 64.08839071950605, 70.71097543162685, 64.65361210607713, 70.87324388565557, 66.84673478526454, 53.593371529732984, 45.63325074411208, 23.972502754580592, 0.06893612309208802, 6.367190855164682, 38.18892163615073, 57.680948011336795, 44.71264693044847, 61.93220892260152, 12.924483303100834, 15.662792882611676, 47.33041717160133, 28.01890023293034, 32.123307604943555, 55.13123481504379, 4.0194750649313775, 0.3354155404433128, 0.1022876766059668, 0.04172257711029342, 0.010962444320020658, 0.02794796191606551, 0.0898715210778098, 0.03280088951390597, 0.07187314331531525, 0.022898802811640407, 0.03503717677367311, 0.008397872105330951, 0.10610503144562246, 0.04228904550414413, 0.09995959669111237, 0.05160305055699522, 0.039170627151766134, 0.036729568420278455, 0.03449059985277634, 0.006164075588927635, 0.07610142005667572, 0.022825130051182165, 0.09803572008686681, 0.034432013278766986, 0.049696813127206224, 0.061230381740437406, 0.07113612842776122, 0.03404281763059478, 0.06285317429912186, 0.04908009702640195, 0.020357447849105925, 0.09792198667362814, 0.03156178443121814, 0.02853574096074989, 0.05014033207008916, 0.03355250220685717, 0.03615588730862064, 0.04553472255206397, 0.08106958451530627, 0.06954239741448434, 0.09529543890347404, 0.10944404098535739, 0.3043379580541965, 56.60183337426955, 61.25712194750386, 32.848728395277455, 51.398919167057166, 14.464585281187489, 47.10812468682566, 74.75164428833993, 72.41912841796875, 84.27826558389972, 71.99374737278109, 72.40199550505608, 7.5789291627945445, 0.9029107372606955, 0.22680362416130884, 8.240749701376885, 69.7778671018539, 76.68762422377064, 81.85558226800735, 71.40661562642744, 70.41402063062115, 61.382712318051254, 60.7303358662513, 54.81802963441419, 55.62254305808775, 55.40088207490983, 57.72822433902372, 58.22226255170761, 62.68259363789713, 65.10166052849063, 68.32509963743149, 71.1515909625638, 71.76661076084261, 63.83655102022233, 54.299523676595385, 52.26074626368862, 55.36145048756754, 57.67871618270875, 57.88847669478386, 58.980248820397165, 54.510343228617025, 50.31997319190733, 52.44860033835135, 50.67664215641637, 49.125529104663485, 50.94884287926459, 50.296089879928104, 48.94859490856048, 46.640735057092485, 48.852135981282885, 47.89181032488423, 49.876007956843225, 49.6519386383795, 50.0410730608048, 51.14190978388633, 54.79665271697506, 55.10222496524934, 53.051033250747196, 53.30785828251993, 57.223858525676114, 59.72853899002076, 61.29903247279506, 63.49441051483155, 63.229222989851436, 64.39681060852544, 64.01345775973412, 66.91150096154982, 60.311650306947776, 61.55057799431586, 66.446213722229, 62.22471575583182, 69.21754867799821, 63.384886172509965, 64.4889235496521, 64.147481226152, 62.86803545490388, 52.91649987620693, 49.393501512465946, 49.149561466709265, 46.53561553647442, 45.48836623468707, 44.54377712741975, 45.09258731718987, 46.32470184756864, 46.26237146316036, 46.86580850232033, 45.80949068069459, 46.83531599660074, 47.53854205531459, 47.44060047211186, 47.37552442858296, 47.50073432922364, 45.65932666101764, 47.00380925209292, 46.0453781004875, 47.30170542193998, 47.28641994537846, 46.63344729331232, 46.301481416148526, 46.6128077814656, 48.77179407304334, 55.83702610385034, 61.63183773717573, 61.5149667955214, 65.17251422328334, 68.2914770803144, 63.46879351523615, 57.51644380630986, 52.64363627279959, 51.76885358748898, 57.55969970457016, 65.1051788945352, 70.99783405180901, 70.96702775647564, 67.2610390570856, 73.88815018438524, 68.59633153484714, 72.92546718351304, 72.04655032004081, 59.99956300181728, 56.21056518247051, 23.69048433919107, 0.047684300150121414, 7.055504552779659, 45.789082588688025, 60.63581458983883, 54.8625446134998, 60.08944019194573, 25.31772863480353, 14.288674823699461, 44.82733311191682, 36.39524921294182, 36.26682689113002, 65.72451330000355, 3.3661523413273597, 0.09763182321142766, 0.07002504046766028, 0.06384527731326319, 0.03228984758137696, 0.03231884400931097, 0.008607649004026767, 0.04093075629263636, 0.0517443822877061, 0.03832549810589802, 0.02052334035866924, 0.015358953011943208, 0.02860486507415772, 0.04938060650601984, 0.06455224623242695, 0.02283022262065882, 0.049523435938622684, 0.04842461687662909, 0.018955497371573603, 0.13147193397725784, 0.18024407897985753, 0.17325600879567285, 0.20836483777290393, 0.13408216407462475, 0.12903601952618168, 0.16132500142820422, 0.18255979423561405, 0.28143484025232257, 0.16732000715790257, 0.15797381109047323, 0.16271154396235943, 0.12891948223114014, 0.14717037789523602, 0.2196128164688426, 0.11704496618720794, 0.2791057184578911, 0.21668724926008334, 0.15070547530006978, 0.2468155414587067, 0.1421383600081167, 0.3039737292114766, 0.5006243931430002, 1.6464228471440654, 75.0246883207752, 74.5226014044977, 46.67779361048053, 76.0601391330842, 20.305476919297252, 36.963298628407145, 91.40531416862243, 77.38550016956945, 92.41064117800806, 77.7071580579204, 75.06715190026068, 7.530087809408865, 1.087011839112928, 0.36143587000908395, 9.391113212031703, 77.60512152025777, 81.4143705368042, 87.85834620075842, 75.07181167602539, 75.49068158672702, 64.6961659000766, 63.193325458034394, 57.30173718544745, 58.970282077789314, 58.61326402233493, 61.214219062559074, 62.75955446304814, 65.42919020498952, 68.30693906353366, 69.13714008946573, 72.52427147280785, 77.30547597331386, 65.17727205830236, 58.98770916846491, 57.3988119248421, 59.08301491891185, 61.02976960520591, 61.49514313667052, 61.16452263247583, 57.24079924245035, 51.27568614098334, 55.99501917439123, 52.56504374165689, 53.025631981511275, 53.92107771288965, 53.53503411816013, 51.39418486625918, 50.14248594161003, 49.408606559999534, 52.93753162507088, 51.97422496734127, 54.8707619790108, 52.72957148090486, 54.447730433556345, 56.80830694014027, 58.828366802584746, 56.996796438770915, 54.43744990133471, 60.837867644525346, 61.40790962403821, 63.820304562968595, 63.58457011561241, 63.543428374874985, 64.03615259355115, 65.47118702242452, 68.69136271938201, 61.29436092991983, 63.5736188580913, 68.11595101510325, 65.07465893222441, 70.90416000735375, 66.45670998481013, 66.25129545888593, 68.57405247226839, 64.75948079939812, 54.27715832187284, 53.31909587306362, 51.21417945431125, 50.00150811287665, 47.87592472568635, 48.972352704694195, 49.23836000504033, 48.01359599636447, 50.08035952045072, 49.76357321585379, 46.74774123776344, 49.172750519168, 49.7933243936108, 50.95171013186055, 49.22856192434988, 51.92542676002749, 47.88655042648316, 48.91779253559728, 48.874438578082675, 47.72581954156199, 49.2201288284794, 48.52208422076318, 48.90679420963411, 50.23846241735643, 51.33991887492519, 59.78849634047478, 66.43661176004719, 64.2315140847237, 67.13110662275746, 70.89502088485226, 66.87178304118495, 61.456182233748905, 56.54364893513342, 53.5421649871334, 58.8837859707494, 67.61427987006404, 74.10377856223815, 72.47655191729146, 68.57908879556965, 77.57652744170159, 69.9805751923592, 79.39097665971326, 71.93656706040906, 71.30486149941721, 55.37391577997516, 25.893126610786688, 0.1535526104271412, 7.909181454489309, 49.13045952397008, 69.76047531250985, 58.62345826241278, 72.1919761165496, 18.32526049306316, 21.848313769986554, 67.80548757122409, 41.50785869167697, 49.32507184243972, 76.4003106086485, 9.636274095504515, 0.762553378458946, 0.3420893613609576, 0.14349185350921848, 0.26042604338257547, 0.14035941191738652, 0.1986371299191829, 0.124232518005996, 0.21328641642485896, 0.14877514823550178, 0.09580200688252527, 0.2277200645016086, 0.2867873433616854, 0.08128089454746054, 0.2250931030439754, 0.10502986534829102, 0.22032592175227983, 0.1327103457503742, 0.15996285113355807], [0.07934522018918107, 0.02889333548204553, 0.07253665972741381, 0.04475119463618725, 0.05630142183133191, 0.0482154518906628, 0.028729662712242816, 0.05098228568151113, 0.02760069809042879, 0.0518834425677215, 0.03332142327581683, 0.028126531265555855, 0.0657104409389919, 0.02810920618714825, 0.009742856284813776, 0.043303514455234816, 0.019327842915851264, 0.02750652673233661, 0.05480230650714329, 0.062186298591475335, 0.10065874385256922, 0.06256387268583621, 0.07404098061904793, 0.08318980179366567, 20.618085899660667, 68.0959939956665, 38.0021305238047, 48.744235500212646, 50.94363397167575, 13.221191975378222, 82.52393845588931, 75.01160329388034, 75.66818452650502, 69.94807443311139, 62.1781611442566, 18.699117283667288, 1.1197532112559965, 0.4419412614116746, 1.2764373133259437, 45.945471409828436, 74.68953747903147, 75.60996086366715, 75.0349178621846, 65.68894524728098, 66.14548560111754, 65.1855404146256, 64.8179280373358, 63.785717102789114, 58.505485134740034, 55.45188857663063, 55.3295341614754, 55.225928675743845, 59.62754580282397, 65.72354447457099, 67.98958009289157, 66.05203905413228, 62.19030872468026, 51.8394797848117, 51.763542698275664, 52.136862124166186, 55.562644543186316, 57.946249285051906, 62.1188941309529, 57.150419988939845, 54.33641749043619, 48.48489622915945, 50.995664212011526, 52.03624548450593, 47.69140466567009, 47.86553436709989, 47.35921521340647, 45.94673441302392, 44.88447420058712, 47.446974323641875, 45.90218805497693, 47.63066676355178, 47.82900925605528, 52.55342175883632, 58.53683663952736, 55.746580170046904, 55.012398765933135, 53.763147400271514, 53.15809042223039, 56.63423999663323, 58.42922249147969, 58.463143148729884, 63.04904107124575, 63.39679841072329, 65.28218761567148, 60.11419034773304, 68.12569418261128, 51.72969656605875, 55.21290640677176, 67.32168674468994, 59.86788119039228, 61.31853841966199, 60.49657437109179, 61.36223754575176, 60.208338998979144, 53.76549297763456, 47.85915267082953, 44.408651474983465, 45.016607084581935, 45.689477920532234, 44.110833752539854, 44.66826138957855, 43.1259266022713, 43.85794285804995, 44.75971537251627, 45.5567959047133, 43.70696298537716, 45.65724780482631, 46.70574049795828, 44.276632339723655, 43.93475855550459, 44.66517056188276, 46.172976724563114, 46.03950238996937, 45.47126862310594, 45.1961810358109, 46.43127656752064, 46.33504906008321, 48.483146852062596, 49.289978396508005, 57.07041540453511, 61.85283191742436, 62.79003912402738, 62.166370499518614, 63.46638125758018, 63.06213786525112, 55.38002683270363, 51.31516871913787, 48.503021501725726, 52.47937525472334, 61.21553697893697, 66.0897251867479, 72.73548326184674, 71.8639326095581, 64.34037554648616, 71.14261657960954, 66.29703029509514, 54.1325758349511, 36.25285540857623, 36.90408652828586, 6.666927597215099, 0.07434761497162043, 10.574250086661309, 42.12387869434972, 58.83022208367625, 69.9546169465588, 56.597534456560695, 7.811749289112707, 44.05627750581311, 43.52491794093963, 25.694325200973022, 45.71343183517457, 35.30785445244082, 0.10067848593837793, 0.027657855910459356, 0.04778840000771227, 0.061089356444896235, 0.007024205115158112, 0.026251454462086963, 0.055780217742487315, 0.07150785727125984, 0.05157658604965095, 0.04642690088780177, 0.04296949628980891, 0.027346042803518718, 0.06796965721033274, 0.05115588503559271, 0.07051262478794783, 0.03147412482048235, 0.07666792675492264, 0.02222186453910845, 0.03725313205992983, 0.014290694154859071, 0.022482344009462866, 0.04583436252188779, 0.04833901421197, 0.04545930119591855, 0.038176340787040616, 0.07524337093796461, 0.010245814074521825, 0.029762856767422734, 0.04206338281472845, 0.018085855427348328, 0.0634411046461713, 0.0355899858198339, 0.035926516753651445, 0.05802091000781906, 0.05044603179539404, 0.03122529754745624, 0.012767188506381167, 0.006671288997055062, 0.032560096587985754, 0.03428146167988739, 0.13217273588863113, 0.031026413461433786, 0.23070910975577372, 23.65452208826619, 83.05849475245323, 34.94523917475055, 57.356230674251435, 40.22734211337182, 25.019177429137695, 94.36305584446077, 77.77204190531086, 83.2735896879627, 73.35224459248205, 73.45095496023856, 19.14557126260573, 1.0817270581760714, 1.0737961482617164, 1.1894852307534989, 55.899297652706025, 79.9063447213942, 77.89129764802995, 79.71938886950093, 68.65278228636711, 68.62354493910267, 65.2060857895882, 65.83863858253726, 67.3319947335028, 61.501128673553474, 56.450594625165394, 57.99514555162, 58.50396717748335, 62.51891313060638, 67.25000935216104, 69.54030482999741, 65.43480311670612, 65.40155318475539, 54.35342880987353, 53.06372211825464, 56.60324542753158, 57.328417147359545, 60.3362004218563, 62.71921288582587, 60.29506260348905, 55.16860323567545, 50.28304799910515, 53.33497362752115, 54.22921911362679, 50.00213176973405, 50.84519424746114, 48.44214631665138, 49.10756857164445, 47.30994239930184, 48.40917487298289, 50.17964647662256, 50.54620765870618, 50.719831374383745, 54.1597225589137, 61.12920953381447, 58.841526354512865, 56.42423629760743, 55.788549530890684, 55.31102841900241, 59.28600542006954, 60.557222058696134, 60.66701312218944, 65.73930455792335, 66.60645038850846, 67.79711723327637, 62.61738815615254, 68.64152508397257, 53.078544755135816, 61.108067958585686, 69.48457579458915, 62.47997183953563, 62.38971417950046, 63.08582113635156, 63.56501710030341, 61.080383869909475, 57.20020663353705, 49.613040493380645, 47.51032844666512, 47.39713668823243, 46.646830420340265, 45.73522060148178, 45.33014566667619, 46.29982617593581, 45.812616809721916, 46.39761086433165, 47.99398022313272, 46.198487820163855, 49.21320192275509, 47.71376217565229, 46.73704493430353, 46.569634252978915, 47.41052766000071, 48.8302020872793, 49.429748135228316, 48.156519320703325, 47.92510340290685, 48.29792076541532, 47.78792635087044, 50.94436745489798, 50.24826834278722, 59.114170305190555, 65.67873139535227, 65.97401526666457, 64.24167694584017, 66.1221004301502, 64.47639549932173, 57.22982445070821, 53.51842680285054, 50.59099328133368, 57.09918991211922, 63.50647180311142, 67.39864364747079, 72.84676874837568, 71.89230703538465, 67.24337270182949, 73.45686204971807, 70.59857599196896, 59.59837513585245, 44.594489451377626, 40.58119089372697, 5.427424302024226, 0.3492857461735126, 12.649086829154724, 47.20548968161307, 63.93499858917729, 71.6676728956161, 62.23656523612238, 16.545808622913977, 25.20633920546501, 48.905390001112416, 29.049922689314815, 53.21218775164697, 37.617326398049634, 0.15733110928727737, 0.07852508476184261, 0.05610693125955521, 0.06126222801544975, 0.0451962189418414, 0.03278039666193147, 0.036725473680323174, 0.03572697000157449, 0.0261627261586968, 0.037631702068592274, 0.058269003751657666, 0.07626079698844303, 0.02729691358493461, 0.030563656135552356, 0.09038303032397263, 0.04116573078077167, 0.0349349461706175, 0.036186243542620254, 0.02622252315162651, 0.14242260927154174, 0.13184468171769573, 0.2014936113189305, 0.10075422905145154, 0.1941894839007047, 0.1297402228679388, 0.16577641659926984, 0.14194366642304007, 0.14722020425383123, 0.12579929804609669, 0.11802604136567925, 0.203729530856494, 0.15546246762237242, 0.21516690180907327, 0.14497267082333565, 0.2143498230725527, 0.10849542495223785, 0.2297894058809165, 0.16461893435447447, 0.1306558664767973, 0.18638720014883628, 0.2782482209224855, 0.17182215267131407, 0.2707760444571895, 37.989202391716745, 93.18630556906425, 53.5336495214893, 72.36230896365258, 71.74522599866314, 20.075553463351344, 100.0151441943261, 88.8700980524863, 87.55327209349602, 79.59592834595712, 78.83774988112911, 21.872061760194843, 2.1115435083066267, 0.6418934885051943, 1.6766116143234315, 63.26550099157519, 82.9121668108048, 82.56997139223161, 84.3074401732414, 72.49504197028376, 74.22097113824661, 69.53702572853335, 69.08803985964867, 71.25471791913434, 63.72737969121626, 61.55749313292965, 60.918397826533166, 61.58940553665162, 64.5337680078322, 72.7463560719644, 72.15573341615739, 68.69433587597263, 68.95429488151305, 55.59219960243472, 56.38465173782841, 59.563568022943315, 61.94596075242566, 62.655694023255386, 66.90731187020579, 62.23865193705406, 59.50446182681669, 50.78370325026974, 58.404378198808246, 58.05838200353808, 55.061212662727606, 53.86949854512369, 51.819095227026175, 50.97896668218797, 50.464139907590805, 50.5698517061049, 53.13721556817332, 52.67048881899927, 53.8732091073067, 57.061994075775154, 63.61290139536705, 63.03027252997122, 59.40014639208394, 58.2985604962995, 56.45112414513865, 61.88710951036023, 62.83760570710706, 64.49617208973055, 70.08869140378891, 69.5294241751394, 67.68650639441707, 65.45064164746192, 70.73760832509687, 54.501462982546904, 61.60130208538425, 71.488004807503, 65.00683722957488, 65.56288419231292, 65.59005445049655, 66.45576077122843, 64.43213547429731, 61.951805083982414, 51.76759450666366, 48.454976389485026, 50.88819519166024, 49.955769354297274, 48.56466939372402, 48.447563109859345, 49.429406889023326, 49.83802372409452, 49.985218509551025, 50.047160579312234, 48.71695541566419, 51.10979341691541, 51.59976020936043, 48.68483120395292, 50.059100274116766, 48.883389426815896, 51.79670633808259, 49.91946781835249, 50.02569736972932, 49.99361238171978, 50.858228283543745, 49.23710876895536, 52.914636750375074, 53.57774480696648, 61.00842014435799, 67.5208019441174, 68.67110759981217, 66.23238178991502, 68.76674282935359, 67.85159111022949, 59.13198963288338, 56.593894497040786, 54.473790660981216, 59.73561494581161, 65.98830838357249, 71.68899489987281, 77.04147692649596, 71.94616117785054, 68.05646434906991, 75.2061136307255, 72.66639463363155, 69.5818348853819, 49.69305684489589, 41.451156908465975, 8.19676963552352, 0.40335157405464883, 14.23302717747227, 50.21650106676164, 71.51801878406157, 79.38596387063303, 70.03530010100334, 10.788239894374724, 60.63929765455185, 62.69576495693576, 38.79388055493755, 61.85493430783672, 55.07307391012869, 0.40944237141839923, 0.21777377644133186, 0.1736101865648262, 0.1894065058760105, 0.13472717946335194, 0.15030735472757972, 0.24466232877344857, 0.3113300118955874, 0.14204204743427618, 0.13470148487437156, 0.24641719105983936, 0.12194620520477334, 0.20096902495190022, 0.12298105209464989, 0.21788056909797654, 0.06730929708048221, 0.20582141054253425, 0.17788625953178253, 0.0963043537171137], [0.075444714166224, 0.11043258552109042, 0.0845893218572582, 0.07130669790410227, 0.05726705267724972, 0.11386012418135522, 0.051679004344248006, 0.045593692170035456, 0.06854197851592495, 0.06328871826671305, 0.13414257776833352, 0.020117080101983684, 0.12336786520937759, 0.05257545745060329, 0.08767943709127365, 0.12690054943724988, 0.05554186863704555, 0.11640321433303819, 0.07923303427354944, 0.07408525284019209, 0.0210452530788438, 0.1368319600700371, 0.10559315447725597, 0.3918580182137028, 4.522313850541269, 59.96763098624445, 52.774270811388575, 24.08954235815233, 58.277230647302446, 20.368599622480332, 22.629071358711492, 89.34148849979525, 71.32070787491338, 76.41519208108225, 70.40815276484336, 40.42260554529006, 0.23945214947865856, 0.7912871301654847, 0.784666475749785, 43.834188984286406, 79.744656778151, 76.08261431417158, 76.47118783766224, 74.9025692478303, 72.62320149329402, 74.36888371744465, 75.92290324549522, 76.73623023494598, 73.84231336655156, 61.32226859369586, 55.92704057693482, 55.74097510307066, 60.636536305950536, 60.07474699328023, 65.55613379324636, 64.9304804494304, 63.589767256090724, 52.151696528157885, 52.658015681851296, 55.22258289398686, 57.689294815063484, 58.486904867233775, 63.34804727185158, 63.69567517311343, 59.559571127737726, 51.19326145418229, 52.003525072528475, 49.14844751358033, 47.67306758511452, 46.34416464836367, 48.648839535251746, 47.086206482302764, 48.09104319541685, 46.91832119418729, 47.23469564991613, 45.83804945791922, 49.13775121012042, 58.07530703083162, 61.69988301492507, 60.28468008964293, 57.88981814538279, 55.57054419671336, 56.832688393131384, 56.50742584659208, 58.292472977792066, 59.06780788975378, 61.85851935417422, 64.71513055985974, 63.93098208212084, 62.20372715303975, 63.670042484037346, 65.36315710313859, 55.35599839302802, 54.96593829124205, 60.200027496584006, 60.814121615502145, 63.76253197270056, 60.492004809841035, 61.332027450684585, 55.682633769127634, 51.16521650745023, 46.27203226089478, 47.342094067604314, 44.1319517935476, 45.200738829951135, 44.01708126068116, 42.61572430210729, 45.3720405024867, 45.204425857913115, 44.877923842399355, 44.81975901511408, 44.74113510501, 43.3322040496334, 44.68224463924285, 43.11195904208768, 48.04928956493255, 45.42305877131801, 44.43535104874642, 47.27156200716573, 44.80807035200058, 46.28047712387578, 46.83316653774631, 46.19424773800758, 54.291070968874045, 65.61407896780199, 64.68965868796072, 62.30393978857226, 64.73073767077538, 64.05266184960642, 59.63495516007947, 59.2644049275306, 54.445996745940185, 51.8935888813388, 53.83884914459721, 57.435639058389974, 67.46814020218389, 63.622644562875074, 71.52321200216971, 73.56951252106698, 67.79940005271666, 51.507102058779815, 28.106543633245654, 26.403934917142315, 15.93660177723054, 0.06557563244695626, 0.5990685606675764, 8.801140689080762, 46.212012152518, 57.35676803896504, 66.38445992623606, 15.459849449896044, 14.422545317680607, 50.15491201031593, 30.456315971189934, 33.32579451222574, 60.49415426869547, 10.961473334220148, 0.5557498431974842, 0.21069656426627792, 0.04034504760056734, 0.07349929516954769, 0.132795718588656, 0.06719131187926378, 0.039143070969129765, 0.022390214275688897, 0.05328816819875952, 0.03293443779130617, 0.04138028136484566, 0.059641427285368406, 0.008191808817848083, 0.03544449423169417, 0.03256134148086271, 0.02282520282953497, 0.0759503628397661, 0.0716833143885578, 0.027016519658988523, 0.046570381495140256, 0.04640948770928287, 0.03543828125862825, 0.06838462405627774, 0.030418725706817164, 0.1380692380330255, 0.016112851519738475, 0.02520632475704676, 0.0717804619982358, 0.07436843724140237, 0.022073676321475257, 0.03892406941421571, 0.03947233938942513, 0.00766446884353495, 0.013389581318704352, 0.029976625941813956, 0.045476185773769696, 0.024856255134387363, 0.09832485699124875, 0.004576761998431457, 0.1390769960538995, 0.10822475842771032, 0.11864969822307748, 0.45319374470460805, 4.130462696475368, 72.55360295695644, 53.76072337550502, 29.979083153509325, 61.12110199466829, 19.937064378492295, 49.060637412532685, 89.08884863699637, 81.91371963870141, 81.12653132407897, 77.42910123640492, 44.3623439727291, 0.14794521454361179, 1.6579695694869565, 1.1786479671155254, 51.78189546831193, 83.67862932143673, 78.97620170347153, 79.91065932858376, 80.43544107867827, 74.64224938423403, 75.01838899427845, 78.46779977121662, 78.32853994061871, 77.44278246356596, 64.94297712079941, 58.229738589256044, 58.932486118808875, 63.4466125119117, 62.081968938150716, 68.17866186941824, 69.10980901410504, 67.42217002376434, 54.252494458229314, 54.41987376059256, 57.14685847682338, 58.11653114134266, 61.77383930452409, 63.52105909778226, 64.68220226226315, 60.81626322961623, 53.41536652657294, 53.466290658520116, 52.93630392320695, 50.899479850645996, 49.39046559795257, 50.953537956360854, 49.05837812731343, 50.32953985275761, 49.020397816934896, 49.85631373620803, 49.441479944413715, 50.6198227021002, 60.46259095591884, 62.13795684999036, 62.21035595863097, 60.81236831603512, 59.403754972642474, 58.631389294901204, 57.60701133358864, 61.56642829218219, 61.89153786628478, 64.61287436946746, 66.37961187670308, 66.58243763831355, 65.61712272705572, 65.62115884596302, 69.8356593039728, 58.19760261043426, 60.8708587000447, 65.26867897279801, 62.48102303474181, 65.34164682511361, 62.21407044318415, 64.06789241298553, 57.3683782546751, 51.46262630339592, 49.21543375138314, 47.273864438456876, 45.78864328322872, 46.52101255232289, 47.13090973515665, 45.21194111916327, 47.65932360003072, 47.341309593569854, 48.12762321964387, 47.19240857708839, 48.225851135869185, 45.866439573226444, 47.09865216285952, 45.539972859044234, 50.21412018806704, 48.11305945919406, 48.57566379731702, 48.64772950449298, 48.322604240909705, 47.41127291033345, 49.19870484259821, 48.94029909564603, 55.59036393319407, 67.22414524324479, 68.00328485427364, 64.7436305015318, 66.1832501811366, 66.22203457740046, 62.051750998343195, 60.92728591734364, 55.71394212784306, 54.09886306332004, 55.67647172558693, 61.1798708669601, 69.45255356450235, 67.16659622807657, 70.89995522652903, 75.54186851747575, 67.03045860413583, 58.818505963971546, 33.911710323825965, 35.462866521650746, 13.551107433534439, 0.268636514102259, 0.9900528709253958, 11.502693737706831, 50.645612285983184, 65.24087329064646, 66.30099188896918, 29.60843682289124, 16.120730580822116, 41.79006145846459, 37.289879091324345, 32.66670688506096, 73.88313739530503, 9.065611400911886, 0.5539024681333573, 0.0863743220425902, 0.06131770427248651, 0.053925338847142075, 0.06909916958501262, 0.03517969977110624, 0.026155438747317083, 0.05149514707286031, 0.05961225848765143, 0.10871829525116952, 0.03356217789734083, 0.027255573565320625, 0.025909618369393775, 0.059242471677040866, 0.026636335120025664, 0.008610998723475684, 0.02767761906368598, 0.039794211230811574, 0.03712190885937983, 0.20271120082226493, 0.29496615932833764, 0.09987240822445001, 0.15267216089752414, 0.11478692203039124, 0.22816461000231006, 0.21953170307941977, 0.10225781449867834, 0.2288388593062278, 0.17522948193213633, 0.24725313088105572, 0.1448767872587327, 0.34124424380640833, 0.244265771020324, 0.16267733047566107, 0.1792893802086192, 0.18768783358316268, 0.2278791349982062, 0.2427155614620255, 0.22428969131602397, 0.5350942741478644, 0.46199211129738443, 0.5090287760380776, 1.0790493050890586, 9.456579531392745, 85.9254570930235, 68.54563097799978, 38.15882528981855, 84.84318887033771, 28.409383950694917, 32.86756753921509, 102.62650136024722, 83.55970305781211, 92.0488025296119, 81.7976959290043, 50.21983508140811, 0.9012072641522655, 2.861418805776104, 1.676637845173959, 55.17847191902899, 85.56685047764933, 85.51415735675444, 82.97585825766288, 83.59920132544734, 77.7206039428711, 79.6945838005312, 80.1827855263987, 81.55673688457858, 81.44594561669135, 66.90706083851477, 62.147452908177534, 64.63421206320486, 64.23695048978253, 65.50768467687791, 71.17156367148124, 72.01251199168544, 70.1187289145685, 58.028579834968816, 57.969230451891505, 60.92090422107328, 61.50000295331402, 62.766999121635195, 66.15602893214073, 66.97571800601098, 63.69720489748063, 56.724701619917354, 58.48976819745956, 54.537654692126864, 55.41431227037984, 52.11237084481024, 54.64169556094755, 51.00613694037161, 54.25118046422159, 51.30205231328165, 52.6495002162072, 51.2307357788086, 55.61829120882096, 63.83289144885156, 66.70250923402848, 65.44831960431992, 65.10948173461422, 60.21436768193399, 61.56230980350126, 60.438499758320475, 65.55911479457733, 64.40002695206674, 65.60718736340924, 66.56012719677341, 68.44784628960394, 64.47780363021359, 66.36880182450818, 64.4573563145053, 59.76355398854902, 61.60871536500993, 68.03063161911504, 63.22771679970526, 67.78615813101491, 63.98145121912803, 67.94356284602996, 60.14232943134924, 56.27806917313607, 52.211544052247085, 50.83920086583784, 48.064790771853545, 51.18249062568911, 51.19131595857682, 47.79410016152167, 50.945587312021566, 50.03352249822309, 49.97352984643752, 48.40775497498051, 50.78077716212119, 47.78106220306889, 50.88885414984919, 47.3406231787897, 53.36047687838155, 50.10999302710257, 49.84025163035239, 51.999355593035304, 49.6823017058834, 49.52933319153325, 52.12229051897603, 52.40333226419265, 57.358458580509314, 70.56376103431948, 71.22351154204338, 68.60125018704322, 68.5872551702684, 69.25801184869582, 64.70416753522812, 64.78072043388121, 58.771213946803925, 57.76139582357099, 59.1447530254241, 64.0574118398851, 73.9879431263093, 70.74973629366967, 75.18455628425845, 75.15273801742062, 69.04298751584946, 64.84120338193833, 43.462014890486195, 37.357802775598344, 21.567481871574156, 0.44371680807202096, 1.2259495450604347, 13.737385695980443, 59.36168755254438, 68.62122289596066, 76.08846649046868, 22.88653181445214, 18.95245336717175, 73.98083579155707, 43.12110993169969, 47.180680690273164, 78.65696783988707, 19.906116877832723, 0.8312532017307898, 0.26604698370060614, 0.24295427445923132, 0.1529243110769218, 0.23573354337244268, 0.15746249336629145, 0.12251353161709926, 0.13098269490705383, 0.1378368376003158, 0.3705313561424133, 0.1951156995229183, 0.14990253854663144, 0.13617048911269636, 0.12967617791746894, 0.15195320270234539, 0.23578410517544518, 0.19692178244792646, 0.2059663850213251, 0.13681558111021597], [0.02906394134756298, 0.050587417152259624, 0.03403120373766269, 0.030668041360895, 0.014950887660586066, 0.046178634774180195, 0.08591187306709828, 0.019049919623460983, 0.04772700189102081, 0.0319043310704611, 0.059854775111401276, 0.06395330337146599, 0.07040953233597741, 0.052756258031173106, 0.07834130026880773, 0.03400734392926097, 0.025207439414976586, 0.02192260569802696, 0.024092969176689946, 0.1690419429853078, 0.04029401848393102, 0.06280792914631386, 0.10244226548820735, 0.1668161817736203, 0.14340191478690795, 26.802600699086344, 65.51866731336041, 40.34356586394772, 41.09608434861706, 55.97066910036149, 5.194345789570963, 52.8990061052384, 82.54775508757561, 73.28745488197573, 70.82221384971373, 47.38255723830193, 3.098235582151721, 3.055644770783763, 0.19744299802808993, 38.30228990124118, 80.36387351251419, 72.7585546432003, 85.90381345441266, 70.00626671698787, 79.35890736118441, 76.90883021200858, 80.86117513718145, 78.2589884727232, 74.3764695813579, 66.4453508007911, 57.4158703127215, 53.756726480299434, 59.27131614377422, 64.11043836224464, 67.81595245484384, 63.27140023631435, 64.2128396803333, 53.57312817727366, 50.827814225227606, 53.30772884430424, 57.31614012872019, 61.98994228916784, 64.07117935918993, 65.89264961981004, 63.25904869264173, 60.660458841631495, 53.64523703052152, 50.28222822373914, 49.16469004846389, 48.70706319808961, 49.17230336896835, 49.055808974850564, 45.51663083414878, 47.55516898247504, 46.14488078701881, 48.344730331051736, 50.34284061001193, 61.29205065388834, 62.761880428560325, 62.31365157711891, 62.982254874321725, 58.108345154793035, 59.14172887802125, 62.45690830292241, 60.912196559290734, 61.1987139332679, 62.624997554286836, 62.76828958142189, 62.57532465842463, 62.85446405410767, 62.6592476906315, 61.855640334467736, 70.17393235237368, 55.37150352231918, 58.21223697354717, 63.495740198319965, 59.60772998871342, 57.72412938456382, 55.58384103159751, 53.63115572160291, 48.59085905936457, 47.68381880175683, 46.882074571424916, 48.031258429250414, 44.2368830403974, 44.36243810961324, 43.333969116210945, 44.78344571205878, 46.23207115357923, 44.75777379928097, 44.64630788372409, 46.884624112036924, 45.60453899445073, 45.311965480927505, 43.838954664045765, 45.69283939176991, 46.52456229732883, 45.726418802815104, 45.9917789120828, 49.4572517948766, 45.631391540650405, 48.2444235586351, 50.44848965060327, 56.82473382642193, 65.454513026822, 63.69071729721562, 65.95398764456472, 66.0916236139113, 62.84029253067509, 58.67514333417339, 55.52067125997236, 53.85916309971964, 51.88020575431086, 50.324276031986365, 53.8967433283406, 62.21106983000233, 71.18366026109265, 66.22853786714616, 70.924925035046, 67.46831278647146, 35.56788798301451, 18.825647061870946, 20.658800102049305, 1.1252738246994636, 0.2728194767428983, 0.4301745799039641, 18.253169290481075, 52.31875027379682, 64.06590377130817, 43.913565989463564, 5.848811393783939, 46.495258269771455, 40.49197658415764, 28.450386447291223, 46.5114184348814, 45.79926898402553, 0.634457961686196, 0.10288920118323258, 0.043387424065581257, 0.018537774524321, 0.006354985178463282, 0.02661275110327669, 0.059321141245985226, 0.025271865494188764, 0.021189492113227328, 0.016974928345711484, 0.07142625358556548, 0.046695552601088444, 0.06504424321915835, 0.06857456789622385, 0.025982009847798658, 0.041490303082091194, 0.03577695723863379, 0.04130136664776553, 0.02632914343848825, 0.07624704571020219, 0.011467603654901107, 0.03482370637357235, 0.13069622398864839, 0.06746910302148712, 0.05913312028672907, 0.02647145576174221, 0.08827275686687039, 0.015329033448060435, 0.04648541085301869, 0.012936209527505262, 0.024570948669626832, 0.0677350351226426, 0.11929886580835428, 0.052147034270268296, 0.042391961755891966, 0.08259016945357285, 0.0316150026440981, 0.03344822614904373, 0.017574447687835466, 0.009470798353093767, 0.015425253133740158, 0.0948757759385532, 0.02517529628089359, 0.09458719827835599, 0.036665688178712325, 29.823867121050437, 79.43750381469727, 36.86436076318064, 54.549151159101925, 43.474688068512954, 13.231945153205627, 77.02766233874907, 82.15558867300712, 82.86740472239833, 72.47024474605438, 56.57687925523328, 3.73016030557694, 2.508074049988101, 0.37008803638239063, 46.38013278284381, 81.48454958392729, 77.29002183483493, 88.2075705066804, 74.80981303799537, 82.00686808555358, 79.54806758511452, 80.34435579853674, 80.44139523659983, 77.44404546676144, 69.32728090593892, 61.29554548571187, 56.427436951668035, 61.16074538999989, 65.63804072718467, 71.12094940677767, 65.8075891002532, 68.62207012791788, 58.18523929965112, 55.11190537483462, 56.40430673476189, 60.76378191671064, 63.23151757640224, 67.61082033957204, 66.36550703356343, 65.18099046522572, 62.5516256978435, 57.0112778294471, 54.35646864675707, 53.263139340185354, 50.24255737181633, 50.67530070581744, 50.14773407290059, 49.55671918007636, 49.62344261907762, 49.68512581240747, 51.66779764236943, 52.344669295895486, 64.85598679511779, 66.75302936184791, 64.98730382611676, 65.06511188322499, 61.49776327994562, 62.05782282736994, 63.10911217043477, 61.87464029558244, 64.02293420607045, 65.81775588373985, 66.22328189111525, 64.90509486967518, 65.4428086742278, 65.02436630187496, 67.934094244434, 76.0080422124555, 58.88058531668879, 61.040128584830995, 66.32158433237385, 62.885733189121375, 61.2517326108871, 58.99029401040847, 55.775750837018414, 52.22504485038019, 50.04286950634372, 48.35223382519138, 49.23519857468144, 46.94237316808393, 47.46129881951117, 45.79882575619606, 46.164669144538145, 49.22008960477768, 46.93323404558244, 45.7605512680546, 48.846715265704745, 46.69267900528447, 45.66362165635633, 46.81430385958764, 48.91998121815343, 48.57293775004726, 49.66001087619413, 50.36793201200424, 51.20789189492503, 47.848020984280495, 50.320263447300086, 53.37966511326452, 57.22737689172068, 66.99356479029503, 65.00629202012094, 68.95531469775786, 69.1713902258104, 66.98799502465033, 59.522277232139345, 57.44721397276848, 56.87874878606489, 55.61110934903545, 54.175243377685554, 56.158797740936286, 64.29744912732032, 73.03297150519587, 70.86776041215467, 71.95861862551781, 71.83002764178862, 45.87329195391747, 31.28883315670875, 21.196492333565992, 0.816039247137885, 0.8510473202313147, 1.6014685625991516, 22.4883072991525, 57.6022417314591, 70.91289120335733, 49.21926590704149, 15.797602784249092, 26.49110567185187, 45.652678243575565, 29.506892542685236, 52.11202567623508, 49.309656927662516, 0.3159162432195679, 0.06150998468060167, 0.037805362709707795, 0.06435739942976544, 0.04887411130532142, 0.040783682732932994, 0.036044237654536, 0.04272745847101173, 0.028147730833640503, 0.03063626786423547, 0.024770629487090537, 0.09284732067176411, 0.05167191420050879, 0.03611711176833318, 0.03718876535253179, 0.03354947615955626, 0.06971400110952317, 0.07374556945456613, 0.01361723775194297, 0.026186689388968294, 0.10842576457728302, 0.13042792467580688, 0.1975034270435572, 0.20892497061962084, 0.10105348597731321, 0.1493219817958532, 0.16036500132852988, 0.2460301481187344, 0.1472119458260075, 0.11890533410253064, 0.2011489943270722, 0.31073105371286797, 0.19093877365512235, 0.15955786641326644, 0.23698983563771173, 0.16832287753781966, 0.18139903313450276, 0.18120772565805143, 0.08133327963972285, 0.25011806989148744, 0.21101848973381906, 0.31649160589421954, 0.28475310413106797, 0.22729686221047757, 0.31185772390134875, 46.934724546247914, 85.36370308168473, 57.97780867545836, 61.28315471833753, 79.77804399305775, 7.288898816031795, 69.74286387043615, 96.41392984697896, 89.15694882792812, 82.07019082961544, 57.65580561853225, 4.193846237274909, 5.534733976087263, 0.5775220620055352, 51.3481911536186, 83.07575318121141, 78.70514239034345, 94.15039277845814, 77.67970931145453, 86.57381703776699, 82.14796358539213, 83.41819963147564, 83.60322567724413, 82.02333419553696, 73.8190850903911, 63.942117691040046, 59.91861704857119, 64.63420421846452, 70.71992628036007, 73.50455807101342, 70.32993285886704, 71.61055534116684, 60.755662610453946, 58.42732014194612, 61.45007510339061, 64.45119819333478, 66.24363899230957, 69.15994474964758, 70.43007881410661, 67.15049882088938, 65.83858366935485, 62.18011840697258, 57.84223195045226, 55.24023748213246, 54.39082860946656, 54.73190223017047, 53.08823693183161, 52.83954689579626, 51.69255564289709, 50.53920622794859, 54.09068884388093, 55.05845915886664, 68.24830747419789, 69.90636394869897, 67.13436219000047, 69.59972089336765, 67.32650341526156, 65.8277500829389, 64.96176135155463, 63.84185014232513, 65.23293833578786, 68.46684625071865, 66.87528964011901, 65.42801349393784, 66.35580308975713, 66.2619407715336, 67.28357699609572, 71.26538676600303, 61.250551977465236, 64.90553417513448, 66.87580739298176, 66.06705388715191, 62.65069692365585, 60.417181676433934, 58.77555601058468, 54.47599111064788, 52.18089465172061, 52.272933067814, 52.11164912869854, 49.18283493288102, 49.86639422755088, 49.33323429476831, 49.28753083752048, 52.236929632002315, 48.445421495745265, 48.98315883451893, 52.93477027646957, 49.54386557302168, 49.42883814534834, 49.31202211687642, 50.30496228125788, 49.70751862372122, 52.309336585383264, 51.758910379102154, 53.717542002277995, 51.75356418855729, 54.131332443606475, 56.3084283182698, 62.79753085105651, 69.8656968147524, 70.13746999925183, 71.13745474046277, 73.40720484333654, 69.19568538665771, 63.491476581942656, 60.831964477416015, 61.12900949293568, 56.103229522705085, 56.8919946301368, 59.09686873036047, 69.12319214113298, 75.68342685699463, 73.26585046706661, 73.40423953148627, 76.34116911119031, 51.09788902344243, 34.25694165691253, 31.40815361853569, 1.825181190525332, 0.44715553161598026, 2.0404452782484794, 24.96004181523477, 64.62528474869268, 75.37818016544466, 54.55408157840852, 9.440015362155053, 66.20198342107958, 60.137030309246434, 42.60252552647745, 60.15878769659228, 65.60592436021375, 1.9357297617581584, 0.3727037669910539, 0.15617333592907076, 0.1095853612247494, 0.13946480508292877, 0.2290540227606412, 0.09699875113344002, 0.1472052195740323, 0.14533755850167046, 0.17065812803564534, 0.13718069861492804, 0.11244439369728489, 0.13945798690040268, 0.14151349273179809, 0.18571144931258696, 0.1244234117949682, 0.12145557185454715, 0.148149422940708, 0.1497772372057361, 0.17772228607246954], [0.07512196898460388, 0.020300943119030808, 0.03170576299570742, 0.03232588052689549, 0.03197096922855464, 0.07323878697089611, 0.04342774710347576, 0.06339056965624613, 0.0410588002283006, 0.05681280467298724, 0.036774886351439266, 0.04081778896732196, 0.06048147716829854, 0.05150762281470722, 0.06392278625900227, 0.07866198467391153, 0.015403480914932106, 0.03373219962081602, 0.0788626614056768, 0.03188875458774067, 0.03188964516495264, 0.15298302405543868, 0.08966381165889964, 0.09775666489956841, 0.2100522230349241, 2.8078411904073532, 60.89900562840124, 54.51091981703236, 38.515094172570016, 58.906884808694166, 35.07645030175486, 9.885629953876618, 79.65786257097798, 73.25304000608384, 68.64722036546277, 61.90668998226043, 13.05200642155063, 1.31308414041996, 0.3425321601811917, 8.55526299245896, 82.83994813119212, 76.24391002039756, 81.39519014666158, 82.8531429844518, 82.74328524066557, 84.00232684227728, 82.94178855034613, 79.19649770182949, 78.31634921412315, 68.99686828736337, 58.44204079720282, 55.28974563844743, 60.07755541032361, 63.38873794001918, 63.362473749345355, 67.78851939785865, 64.45804272928547, 54.92988386461812, 52.031177782243304, 53.46802826850645, 57.229326309696326, 62.253957025466434, 64.93863113464849, 67.57181629057854, 64.57446652074015, 63.18081309718471, 56.27321327886274, 53.37901399981592, 50.32790814676593, 49.47479263428719, 47.82758151331256, 49.963343451100016, 48.59891168532833, 47.81251961185087, 46.50872768894319, 48.765561426839525, 51.15075865099507, 61.72442136272308, 65.10257836311095, 65.09688308162075, 62.34909411399596, 62.67714938809795, 58.00393950554633, 57.07542427124516, 58.94684591600972, 65.57994258019232, 63.29231431407314, 62.73752250979024, 61.92450538758309, 62.48168591530093, 63.577909931059814, 64.52650770064324, 61.43959453029018, 67.82968859518728, 62.90539210842502, 58.21288024225543, 59.058331443417465, 55.671133379782404, 56.018349432176166, 53.199224318227465, 48.78497323682232, 47.405114789162916, 45.096070381902884, 48.069034776379986, 43.49871650818856, 44.47098578176191, 44.71300386613415, 44.692227071331395, 46.035415280249815, 46.63785211501583, 44.51687359040783, 46.99687057925809, 45.17561212662728, 45.09996921785417, 46.49989843368531, 45.09545456978583, 46.90480862894366, 48.25948153772662, 48.233625273550714, 47.4934857891452, 49.892944751247285, 50.95288292054207, 47.56936796249882, 57.27886976734285, 62.65303073390838, 69.30747293656873, 64.60210354097428, 64.39179781944522, 60.3360866731213, 56.91787835090392, 56.295813975795625, 51.19677197548651, 52.581050934330115, 54.99881952039657, 53.62673128804853, 58.38084790014452, 63.71251783063335, 72.52365958306098, 68.3370707111974, 62.526530373481016, 36.76737623829996, 27.5368978131202, 3.77066417086509, 0.10556036591409676, 0.1817059586004865, 1.9597230226762834, 27.053916761952063, 56.34561630987353, 64.58722991328086, 13.642694777058018, 14.717845859066134, 50.430960578303186, 42.15846223215903, 30.649461323215117, 63.95484185987904, 11.764986553499776, 0.42654500853630806, 0.14824815635238925, 0.028190105071952267, 0.08263552185869025, 0.02186973222471293, 0.05636967260450606, 0.010978576216486194, 0.06644740220039122, 0.012567210829846803, 0.009703134625939833, 0.12218016079596936, 0.020731451973739653, 0.04674850842885433, 0.10402465840020489, 0.06248940510915653, 0.01680688695952056, 0.03278347250494746, 0.04319279176753856, 0.05479927662940276, 0.011662690817648846, 0.03124589382130052, 0.021399691317891403, 0.020166550229694095, 0.013269881038145434, 0.04840785104240622, 0.01641758214381914, 0.046009697065117865, 0.058736049254695256, 0.08430462826283709, 0.06602645986863682, 0.02942073913741737, 0.0651798944079107, 0.05852101220478935, 0.09372946325569384, 0.06699264229786012, 0.0444055357647519, 0.01665202037040745, 0.08078066977642237, 0.055425783333879326, 0.10092583274649036, 0.008132110458738621, 0.0694380332565596, 0.09311853877959714, 0.07615619534326178, 0.19801776315416061, 3.2372492840213165, 74.29425670254615, 57.58772111708119, 40.07074932898245, 60.8692152269425, 21.479628624454623, 32.27056122595264, 84.6951586200345, 82.97070426325645, 72.0033650244436, 70.04805564880371, 13.178067476518693, 0.9379707817589084, 0.712597213925854, 9.707081702447708, 90.41497845803538, 74.56006788438367, 83.34241159500615, 82.81518228592412, 84.070403498988, 85.57651519775392, 85.66551377696376, 80.6129518631966, 80.21857323185091, 71.36889811485045, 62.75311785359537, 59.0461132603307, 63.10053786923809, 66.58279065162905, 68.55536630076747, 69.8808136293965, 69.09861456963324, 58.211923183933386, 54.16935590005691, 56.39756418043568, 59.30856689330071, 64.79246401017713, 67.76940176563879, 69.96121437318864, 66.21185210443312, 65.02788466791954, 59.89672630063949, 54.15945583774198, 51.906736666156405, 52.30473956754131, 51.4031357149924, 52.36248470121815, 50.63606915935394, 50.809524213114095, 50.83371739233694, 50.76673115453413, 53.407976781168294, 64.50353437854399, 69.01028279335269, 68.80259329272856, 64.70501476718535, 63.31729196733045, 60.74687650126796, 61.26353894510577, 63.056968181364006, 68.67368067464521, 65.27156191487467, 67.07111789334205, 64.58390766574492, 63.57360316861061, 67.10669379080495, 67.58079851827314, 64.6765854281764, 71.38783531804239, 65.5718703423777, 62.105216826162035, 59.67212746220251, 58.74672658981816, 57.64148896740329, 55.1512820489945, 52.186389892332016, 51.77798094287996, 48.28342760762861, 50.667416741771085, 46.790279342282204, 47.74043821519422, 48.44640993302869, 48.09006260287378, 49.34646444935953, 48.236457224815126, 46.21051380711217, 48.76047019035586, 48.22088149286086, 48.357529024924006, 47.82370621158231, 49.25489671768681, 49.27643837467317, 50.97829595688851, 49.836231200925766, 51.427944706332305, 51.66647972599153, 52.33865238005116, 49.866645259241906, 59.46227673561343, 65.54051883759038, 69.80985010823896, 66.92454676474294, 66.25280949377245, 60.55434303898966, 60.52064595683929, 59.1688677572435, 56.2583278840588, 55.73109857497677, 58.022390334836906, 54.82613717356036, 61.33351795135006, 64.16834431309854, 76.14424259431901, 71.0320528091923, 67.13698233327558, 51.50635680844707, 33.75587063450968, 2.000706397717999, 0.02797350520268083, 1.2062007789650273, 4.550033730845298, 30.901936446466756, 65.62703455648115, 65.83979960410826, 26.13277558357485, 18.306087947660878, 40.07931186306862, 51.19498729705811, 30.99694605796568, 74.3687189778974, 12.945419934488113, 0.5153810545321434, 0.055282777701053894, 0.08744445494225911, 0.01792768891450138, 0.012423913126000235, 0.04340229000175192, 0.031955760468037865, 0.055623939636373715, 0.009914651501833672, 0.013815643990622654, 0.06613738940007265, 0.06485465944053666, 0.04943902071024622, 0.09960565640921555, 0.032748492930324814, 0.04041409127474312, 0.13118860401934193, 0.08323177575103699, 0.03729193058285502, 0.027301081103242697, 0.16581135020861704, 0.12810531462873184, 0.11201388292735624, 0.10991981222985253, 0.08898246838080306, 0.10480653539660478, 0.14840416249728974, 0.24688271204790763, 0.1977158019379262, 0.15875263139605522, 0.051812069986255906, 0.11580470814219407, 0.15116952539932343, 0.28129838467124973, 0.13984363556148546, 0.2072607518564309, 0.12449460434577159, 0.16812323502475218, 0.1795639614424398, 0.1871636609036115, 0.13872185301396156, 0.27866380829964915, 0.5092952827051763, 0.3742181083127376, 0.8895253426124974, 8.002786367170273, 90.88256420627718, 72.63368991113478, 52.324112153822384, 86.93066643130395, 48.103692839222575, 18.395753329800023, 95.23558708929247, 87.07215416815974, 80.95240162264916, 75.74620046923238, 13.835448872658516, 1.682402135864381, 0.5532739696002776, 10.454395201898391, 93.58105290320613, 76.23552399296915, 85.14503094457811, 83.992873930162, 83.71305988680932, 86.99340081983998, 88.51321727998796, 81.93257054974957, 87.59344500880088, 75.55788747725948, 65.70755689374863, 62.40555663262645, 67.0505097604567, 68.8227778096353, 70.11900348048057, 76.76752290418072, 73.30355228916292, 60.563399791717536, 59.04470512943884, 61.217251054702274, 63.639953982445505, 64.91384959989979, 68.62129349862376, 73.17384735230478, 70.41852351157897, 69.00953754301995, 64.49904326469668, 58.796740731885365, 57.59565607193978, 56.21878647035169, 53.62595073638424, 58.00971715681015, 52.60018817840084, 53.57802329524871, 52.9296947294666, 51.68237709229993, 57.695570607339185, 65.27881829969346, 71.06756594873244, 71.5937283731276, 66.43377196404242, 64.62391191913237, 63.15118351290303, 63.63307414516326, 64.07827100446148, 70.40034724820045, 67.31293985920568, 68.53321275403424, 65.15168643766835, 64.57618844124579, 68.6799015537385, 69.76693937855383, 64.95388523224862, 68.54689398119527, 67.40364074707031, 64.24696430083245, 61.52363131123205, 60.57650050809307, 59.609259713080625, 56.91472476528537, 53.2430842614943, 53.42102650673159, 49.79167307576826, 53.45371553974768, 49.27383784324893, 49.76594232743787, 49.83050061810402, 51.14291391065044, 51.87520473234115, 51.19794868653821, 49.28437332953177, 51.93179668918733, 49.436808401538485, 50.42205287564186, 50.61612390702771, 52.030236413401944, 54.068166594351496, 53.755408563921534, 53.96390215043099, 52.848297703650694, 54.71190990940217, 55.816163016903786, 50.06575653629918, 62.44302311251241, 67.13540554046631, 73.66933684195243, 70.12178836330291, 67.604764200026, 64.20148049631428, 62.30901141320506, 60.98874945794383, 59.240427478667236, 60.37550649335308, 61.69559194195656, 58.219591417620265, 62.28779139057283, 68.31949849282542, 79.27287409382483, 74.9446092113372, 71.73443163594892, 57.400584836159986, 36.4283344053453, 5.9803490581051, 0.18497105597728686, 0.6639791904918609, 4.979412651831105, 34.55114295405727, 70.83564404518374, 76.77468515211537, 20.233662243812315, 20.40788608212625, 77.25410861353721, 58.57267925816198, 48.15083972869381, 81.35391896770847, 28.390636982456332, 0.7409910677421478, 0.21426736136838315, 0.24663066912081935, 0.24404768111003985, 0.17582159128881272, 0.15862866304814816, 0.09356721349421049, 0.1931226298573517, 0.12603526844853355, 0.12704827417168887, 0.2091649859662979, 0.12892435455033857, 0.132108966729814, 0.2859772207035173, 0.2375475629683464, 0.15983774897552308, 0.2099576724633094, 0.12507297774596562, 0.1291876436481553, 0.08560733779543832], [0.007940538203148472, 0.1016353757210797, 0.13265524870685994, 0.0625734104804935, 0.04983105854461751, 0.03668183731215616, 0.004915763086999857, 0.02644367932882761, 0.016582323606276227, 0.06740077563952054, 0.05313544091017497, 0.05671563025023188, 0.07768257956711516, 0.05410962129732775, 0.030098878252770633, 0.05450642419858806, 0.014374011962284005, 0.03758301335056463, 0.13773199080699874, 0.01713768372522487, 0.09710008924406383, 0.056160928966898116, 0.04819405122449802, 0.06322438220283197, 0.09062844659051589, 0.23149580544521733, 30.79753079722005, 68.08631358608123, 44.27894261575515, 49.304863791311945, 69.24676249104162, 12.095487425404212, 28.619218987803308, 84.60206508636475, 54.78950223615093, 74.42228286497055, 15.177121085505332, 0.5236746611133699, 0.07261245646664212, 0.08625501150926275, 15.253352349804295, 89.65594491650982, 82.59349776852517, 81.21261950462096, 80.34019024141374, 78.76299735038512, 78.52369354617211, 80.00010505799325, 72.36066941292056, 66.55953099650722, 59.817545413970954, 58.05982151339131, 60.88804260376961, 64.32072447192284, 70.52096797573951, 69.14392578986384, 66.94506860548451, 57.09585197510258, 53.978422764808904, 50.779086620576926, 57.06045258429743, 64.03473269554877, 66.452222793333, 63.76868617150092, 66.65800602205339, 61.02005781665925, 58.62741593391665, 54.14112660192675, 51.952538182658536, 48.78189809860722, 50.38119354555684, 48.44781806392055, 50.11029504960584, 48.168729659049745, 47.824682881755216, 47.96874369344404, 51.55743783520114, 61.390223656931234, 64.82228186822707, 65.63894287232431, 62.889153495911636, 64.28996524503155, 64.93529319763184, 63.500592170223115, 54.87702208180582, 54.355609647689334, 66.35527749215403, 63.02198456179712, 61.58289832453574, 59.706334452475275, 65.71168714954008, 62.86074376875355, 61.70892800054243, 61.466380396196925, 64.69061966865294, 57.85412457681472, 55.94882149850169, 53.260193640185946, 51.89241609265728, 51.91338508359848, 49.73132741066718, 46.34948338231733, 44.13403849447928, 46.537188406913515, 45.66338631414598, 44.76049592418056, 45.783430453269716, 45.10243246632238, 45.708018964336766, 45.21272559319773, 45.34636074496854, 45.84619622076712, 44.64752381847751, 45.355358662143836, 47.00422110096101, 46.7585002991461, 46.835951420568655, 49.91350973806074, 48.030976018598004, 50.86077390178558, 47.64310852173836, 49.01339246380714, 49.13971631757675, 58.0834145699778, 66.90764919404062, 63.66296260587631, 67.30337712072557, 64.02191438982564, 62.168237547720636, 56.79874420166016, 56.22349723692864, 53.86097915710942, 51.921571070148104, 51.12856980293028, 55.16289618707473, 54.95466539936682, 65.8652400970459, 70.07495526344546, 74.46944544392248, 69.52467026249056, 51.51344060897828, 15.971438307915966, 0.369409435699063, 0.3779552384249626, 0.1874786149710417, 3.6320150042733843, 28.223873492210146, 67.20840084937312, 43.273588149778305, 6.96184374632374, 39.13760962024812, 51.39911528556578, 30.186790304799235, 40.81253228649017, 46.97244205782491, 1.9173967261468212, 0.06592225658917619, 0.0650931119678482, 0.055311352780629555, 0.0746914352320375, 0.046915235974255114, 0.0527251165570511, 0.031304706391247536, 0.036458185603541714, 0.04298974016320802, 0.05291889849749785, 0.020393046039727428, 0.03232402276367911, 0.07780226548352549, 0.05220687722847347, 0.006716541331937357, 0.05353296776452372, 0.11985258649914496, 0.011860676665580081, 0.07256599323403451, 0.050476445485987974, 0.03822125269160156, 0.0422738271675283, 0.09954482902802768, 0.08959715434860799, 0.06197423396271564, 0.033091462833145936, 0.051388193537751516, 0.030441760055480466, 0.052030991101937915, 0.016746262591632626, 0.02529187188033135, 0.04259966734436251, 0.05104019809814711, 0.009332444789188524, 0.05484166810469282, 0.05435327173120553, 0.024233230299526648, 0.03320021284443717, 0.044717800863567865, 0.048817528051234065, 0.02694508579048899, 0.03534904350676844, 0.015099826644385054, 0.07878570021280358, 0.00957412158905138, 0.11829955007640586, 34.75278023750552, 83.2102983228622, 36.41242527192639, 60.222369317085516, 39.577119042796475, 17.903933217448575, 52.10011343802176, 86.35088520665323, 68.90279416115054, 78.0323382346861, 19.419303671006237, 0.6416471146287457, 0.2082954455287226, 0.12189138395291184, 18.286819304189375, 91.55558016992386, 83.24310502698346, 80.34735248934838, 84.51738111434445, 80.54418486933555, 77.47999791176089, 81.71487900518602, 74.87534799883443, 69.7788869180987, 62.18402508766421, 59.95092953405073, 62.84566617781117, 69.00784307910551, 71.43164819286716, 70.85531080922773, 69.54174826222082, 60.55611987267772, 55.37233898716589, 53.86829829985096, 60.11722233987624, 66.73563757250386, 68.14580025211458, 67.06361047683224, 68.95677381946196, 64.4262009282266, 60.83974645983789, 57.505006174887384, 53.12027092902891, 50.03851567545245, 53.03343357578401, 51.175281309312396, 51.296925775466434, 52.27337629564347, 51.3479793456293, 51.41165902537685, 54.3479492587428, 65.13606755964219, 67.36834726025982, 67.33872552071848, 67.40457427117133, 69.53559798579063, 67.77561479999174, 66.04366087144422, 57.38879811379218, 58.36477402717837, 69.5541900204074, 65.71460539294829, 62.068064135889855, 63.361014627641254, 67.01963286246023, 66.50727718107163, 65.16510094365766, 63.308380342298946, 70.23224230735534, 62.56499705776092, 60.2455230682127, 57.75703414793938, 54.95107643065914, 53.60667620935748, 52.64066311620897, 48.10864287038004, 48.0243315235261, 49.5113608914037, 48.6059013489754, 47.31490811993999, 47.371594213670306, 46.573748819289676, 48.331304057951904, 47.750251985365345, 48.464464602931855, 47.76285063835883, 47.43612897011542, 48.62806274044899, 49.52801919752552, 49.238218799714126, 51.798859719307195, 51.43298495200373, 51.37438081925916, 52.230995085931596, 50.78229119700771, 51.32291147785803, 51.906340506769, 60.92740751081898, 68.02015889075496, 67.39916924507388, 70.05528849940147, 65.30983640301612, 66.00835169515302, 58.53379680264381, 59.129165526359316, 56.44983760772213, 56.38834268816056, 53.08392232464206, 58.21949728073613, 60.73944360979142, 69.20200824737549, 71.1540699005127, 77.70951932476413, 72.65818903523108, 59.685777310402166, 14.224491119384767, 0.16789198372392886, 1.6830912472740298, 3.673951270118837, 4.325515300996842, 33.08609847099551, 74.98466445553687, 48.772927638023134, 16.38063075080995, 24.815508357940185, 51.9672784497661, 32.43675205015367, 45.780582812524614, 50.93426342933409, 2.0604149228142155, 0.08763347947669607, 0.11214978692512359, 0.027526529288039576, 0.10087150945177964, 0.01182007304798331, 0.022599574614075885, 0.03305739490315318, 0.07001374067077715, 0.057611432181851524, 0.02568147930076286, 0.017622816564154722, 0.07098024485692864, 0.05347149686947946, 0.0882713089606935, 0.036199267037333026, 0.05440921913231573, 0.0385977466019892, 0.005271795267734918, 0.04291061094150909, 0.03611816130878945, 0.08813583397216375, 0.2801574652473773, 0.24483321234583857, 0.18248438054034788, 0.19389575046877708, 0.12647839668657512, 0.1708773977213329, 0.16676077829493632, 0.13904390105557057, 0.14263620990658962, 0.17686595299070884, 0.18689603574814337, 0.15732098160491836, 0.17603644830805643, 0.1275548421507401, 0.1905632067111231, 0.11931221872087448, 0.15509957177264078, 0.15846177845472292, 0.11741230534690043, 0.15619421948588666, 0.13996011156949306, 0.20847008293194158, 0.16485062998629388, 0.16377064519591872, 0.2667099561902785, 50.740796442954775, 90.8055837692753, 62.14448759632727, 70.56149390435988, 100.32690202036213, 14.38331671299473, 42.874914523093935, 100.50715846400108, 70.41740171370968, 89.89153815853982, 19.481381062538393, 3.1330434305052606, 0.2166753595754985, 0.22496390997642474, 19.390360501504716, 93.95665907090711, 84.68639604506954, 79.68265979520737, 86.75251237807736, 81.80052003552838, 82.94687194208946, 83.96060066838419, 76.44331547521776, 74.47875715071156, 65.5382046391887, 63.420952366244414, 65.22878846814557, 70.66642515120968, 74.8580817253359, 73.28325794589135, 74.37018594434186, 64.16288829618885, 59.96064916733773, 55.04699407085296, 61.87278501449093, 70.57369247559579, 71.99478287850657, 68.8452059222806, 70.58202358984178, 66.11558929566415, 64.06990458888393, 61.96223858864077, 55.64803061946746, 52.896860568754136, 57.408841425372714, 52.82451637329594, 55.29927699796615, 53.98993099889448, 54.211470388597064, 52.44414060346542, 56.810079851458156, 67.42981864560035, 69.66806427125009, 69.68354194395005, 69.46344990884104, 69.96173997079173, 68.42428853434902, 68.73671316331433, 60.043728889957556, 59.952929942838615, 71.52032513772288, 66.23186403705229, 63.14334661729875, 63.69664792091616, 71.26515142379269, 66.78836207236013, 68.64492970128214, 67.51945264877813, 69.2307827549596, 63.01441046499438, 62.24963457353654, 58.69952086479434, 57.15241255298738, 57.07965650866109, 54.8230581129751, 50.81882807516283, 48.74113290540634, 53.23977770343904, 51.03101261200444, 49.17844972302837, 51.64925659856489, 49.09902172703897, 52.588232794115626, 49.53431852402226, 52.7115442675929, 50.28163986821329, 48.51931502742153, 49.999899941106, 52.20802568620252, 51.64410652652864, 53.67800843331122, 55.66603822092856, 55.73408742104807, 55.60391179976925, 53.22531200224354, 53.67569423490956, 55.63838551121374, 63.25997044963222, 71.49398249964561, 67.2271890024985, 72.55783911674254, 67.80729970624371, 67.86005558506136, 60.37897779095558, 62.54155305124099, 59.45132155572215, 59.727228918383204, 55.871574340328095, 61.64536991427022, 62.137019403519176, 72.14860254718413, 74.71904154746764, 78.84979940229847, 77.27879601140177, 60.03124790806925, 17.29159632036763, 0.4908382940676905, 1.4772936773876992, 4.9803491177097445, 6.225115253079323, 36.89535140991211, 80.03403355998378, 55.595772881661695, 9.957840788748957, 52.61098646348523, 75.62620732092088, 43.31301581475043, 54.420179705466, 67.1734368416571, 4.471448063850403, 0.25990219245995244, 0.21865813301936274, 0.19978993902764014, 0.20516985276293373, 0.1619600117086403, 0.2371283902996971, 0.13223049891812186, 0.2666102421860541, 0.12148639157174096, 0.08542855585654897, 0.09854026559379794, 0.14322907002943178, 0.17973875206324363, 0.16558849523144384, 0.12641542425919927, 0.1650560794458274, 0.1598922178269394, 0.11398986117133211, 0.22725848120547112, 0.13508578522070763], [0.039895955368035266, 0.06524506550762924, 0.04861285617094367, 0.034568610586105816, 0.05258636654264504, 0.01631887362999541, 0.02693304097309949, 0.04747716146671484, 0.026706162119104017, 0.034788094776412176, 0.042141194365197615, 0.05361803799807545, 0.048766970078671174, 0.010450759831245148, 0.0533787427740472, 0.005752617425675835, 0.050384537917712045, 0.03149641031819967, 0.030331834099225463, 0.06003475214745249, 0.04201483582296679, 0.09589340117189193, 0.1131480990818912, 0.027008956455956065, 0.13926675603274377, 0.13255418638788885, 3.3951381666045037, 61.66573093783472, 50.05251853696762, 37.481992859994214, 57.03147411346436, 51.88284158706666, 4.2865867576291485, 60.095108016844726, 55.63656945382395, 74.1449163806054, 29.41972374916077, 0.5171795838302182, 1.8748998065148632, 0.1168827394083623, 0.31903281146960877, 15.43558959038027, 89.47160920789166, 82.0197020807574, 83.77479014858123, 79.90032780554988, 82.8276397335914, 76.39674125179168, 72.67675753562682, 65.09054453142228, 60.56312914817565, 55.49947084919099, 63.877763363622854, 65.91785477053735, 71.66646480560303, 72.85945369351295, 68.73513637050506, 58.195221731739665, 53.82368133914087, 54.38716119335544, 58.21982283746043, 64.45020583368117, 66.23611588631907, 65.16399483526907, 63.935296689310384, 60.918895967545055, 58.14922017435874, 55.30838474150627, 49.66727902812343, 48.97034445116597, 48.535722301852324, 49.61898680656187, 49.827601986546675, 51.179364496661776, 49.91039145377375, 48.564943959636075, 51.583996203637895, 61.03213479441982, 63.12440549173663, 62.26111535103091, 63.868757601707216, 63.34664698570006, 66.20643138885498, 64.11547860791607, 65.75274652050388, 56.100342658258256, 53.00121522718861, 63.804011037272794, 59.72617380080685, 66.26514927033456, 62.682993719654704, 62.422269851930686, 62.72449631844798, 61.35920947597873, 55.64799139576574, 57.34751909009872, 57.16690178840392, 55.07413295007522, 52.35410259615991, 49.45522000712734, 46.39622234529065, 47.24359943020729, 45.50029024001091, 45.83160892609627, 46.437438611061346, 45.019725368868926, 44.149112163051484, 44.29543225995956, 44.73838944588938, 46.44714255486765, 45.783328471645234, 47.105300580301595, 46.400215318126065, 47.807695096538914, 46.04806492405553, 47.288290915950654, 46.855578960910925, 50.052644052813136, 47.207384186406294, 46.54568033833658, 49.33136332419611, 47.499032020568855, 47.978094623934844, 54.79221259394, 67.02055069708055, 70.66946106572306, 66.78354540178853, 67.31284572232154, 60.821966355846776, 59.650299472193566, 58.63996359609789, 55.75981816937847, 56.94626846621114, 60.15071545877765, 54.42276454740956, 61.727472966717144, 65.43208099180653, 73.33479788995558, 73.63272543876403, 73.50946103372883, 66.84948044438516, 4.670826062079399, 0.05249228328466416, 0.7868812665823968, 3.963174589218632, 5.143765355310133, 45.06086710960635, 62.37185955047608, 18.09688441215023, 14.33260242785177, 53.97893267293131, 43.333008135518725, 36.897653841203265, 55.64301390801707, 25.192907048809914, 0.4733906722357197, 0.026615876742007754, 0.07138090118044807, 0.03383637991763892, 0.045698849228961815, 0.03164402971554908, 0.01820620209459336, 0.01810121357501034, 0.03647091032396402, 0.044117329657197966, 0.018510149393771446, 0.05938956055850272, 0.03787480091916458, 0.035799736863062266, 0.07737075879929528, 0.06155162538972594, 0.007436344139052616, 0.07634361875393698, 0.04104159006308164, 0.06530344906833864, 0.03383791975436672, 0.0360482825987762, 0.03710039711046604, 0.022477758973236048, 0.0412556886552803, 0.026584744843984806, 0.019080166689931385, 0.03258109888842991, 0.02859692457282255, 0.039252380224605726, 0.0284667662344873, 0.04950621428208486, 0.0445956941093168, 0.02880017152957378, 0.03268139894991633, 0.025880286777992884, 0.04960189483338787, 0.031092235735887964, 0.03012694771431627, 0.0128325731531086, 0.08871976917068805, 0.016945087305840947, 0.09564385569143681, 0.12301262257800949, 0.09532785208355035, 0.10595630313600264, 0.0776717241012281, 3.2113756143277694, 74.99036758176743, 51.37511430248138, 42.58833439119401, 64.43287680225988, 28.864094518846084, 19.011587019889586, 68.97403224822014, 62.04220394934378, 79.37751508528187, 35.581918301120886, 0.7647620405881637, 3.1996384118833854, 0.5678981590655543, 0.7236717809592524, 16.934382146404637, 91.97803512696298, 82.42174502341979, 84.34842109680176, 81.79899031116118, 84.80806012307444, 78.95875500094506, 76.77116286370062, 67.23844620489305, 63.40238386584867, 60.37608308176841, 66.35244554088962, 68.56817676175025, 73.6536708954842, 73.62490423264043, 70.12209430817636, 60.54277989172167, 57.33735622898225, 56.26085781281995, 62.67576086905695, 67.43834587835497, 68.5728757612167, 67.48312365624213, 65.98758666746079, 63.174494158837106, 60.21244964291973, 58.146851062774665, 53.13716849973125, 51.62165095729213, 52.07547703096944, 51.75076753862443, 52.31647137672671, 52.9801050309212, 52.16474625372118, 51.508902426688906, 54.6842062088751, 64.91800338991227, 67.28373389090261, 66.63348336373606, 65.83853660091278, 64.96188686740014, 67.27234332792221, 67.82303625537504, 66.72670241325133, 58.011501835238555, 56.745137168515114, 64.32225419629005, 59.48117079273347, 66.04290777637114, 66.46615505218506, 64.37952472317603, 64.03158695467057, 64.23941373825073, 60.08930683135987, 60.03610772471274, 58.90313110043926, 56.420411986689416, 54.700244780509706, 53.06737776725523, 50.835090221897254, 50.42196658349807, 48.11657390286846, 50.1633176495952, 48.9836020623484, 48.59185926375851, 46.55187376083867, 47.93474066642023, 46.640946865081794, 49.01163916434012, 49.12885135219943, 49.508336744000836, 48.605089418349735, 50.03265173204484, 49.77490886565178, 50.38004821346652, 49.96563411528065, 52.16115336264334, 49.51177274027179, 51.23361087614491, 51.70190265101772, 51.41723663576188, 49.87150115351523, 58.8603929550417, 69.22645245828937, 71.86164979011782, 69.24491113232028, 68.33565865793537, 64.976019167131, 63.26201792686217, 60.745770392879365, 59.03658974555231, 60.43091781677739, 61.91375417094078, 58.07627977863435, 64.11762414440032, 70.06333720299506, 73.72230452875938, 75.19977508052703, 74.92425995488321, 69.23657217333394, 5.308575014914236, 0.07900605774334363, 4.5644842328563815, 6.389287527530424, 4.48394081284923, 53.24070338279971, 64.98440911692958, 28.358026396843698, 19.87789934681308, 34.355130349436116, 51.86394360757644, 39.235661029815674, 65.65233776646276, 31.216867469972183, 0.7793209593622916, 0.1322262088257459, 0.09033858956348512, 0.039956713801309954, 0.12400409356961328, 0.047123255658774614, 0.03641916108467887, 0.03823367480729376, 0.022825317742723613, 0.03712012387451626, 0.025275659544633764, 0.013759697547122357, 0.016009163434406923, 0.06301741588920837, 0.042413071308645516, 0.04381339193411893, 0.05103355228540398, 0.041934159103660815, 0.019183389376848936, 0.060179427851952856, 0.04998357898946251, 0.12473778363557593, 0.2325268218954725, 0.1125511710321711, 0.15338315177829037, 0.1373000857570479, 0.07752880273807435, 0.12380139436572792, 0.1444035441043877, 0.058359026743639866, 0.09612056922407881, 0.09783474458081108, 0.08537108394046945, 0.1805337981110619, 0.08799485081145841, 0.16058237111616522, 0.12177526800622865, 0.15022455594472348, 0.22859613200829876, 0.12250539576334339, 0.2562876364156123, 0.19430605183926322, 0.20477680369250237, 0.37654931386632307, 0.22283018656796028, 0.30026215579240556, 0.6346561026669318, 7.907688012046199, 93.34145884360038, 66.40509943808279, 54.73480870646816, 85.44973634904431, 72.0749875037901, 8.871913975284947, 73.839842273343, 68.8800444141511, 90.960658596408, 34.724868651359316, 4.838195068220939, 3.953581942665962, 0.5880515421590498, 0.3522440100148801, 18.718874262225246, 91.4743321941745, 84.86805669723019, 89.34887040045955, 84.47711406215545, 89.51957979509908, 81.87973622352847, 83.10616723952755, 69.39605574454032, 68.55705291994157, 63.365344924311486, 70.24819066447597, 70.65988263776227, 76.48783437667355, 76.66346242350917, 76.5891884219262, 63.56866490456366, 62.00310968583631, 61.80331983873921, 65.47476422402167, 71.18722961794946, 71.44769853161228, 68.37180722144343, 69.44335952881845, 66.68637260313957, 64.43801118481544, 60.9538285962997, 56.467103881220666, 53.149825988277314, 54.513120266699026, 55.14997197735695, 55.32590989143618, 55.8903899500447, 54.78283028448782, 54.42789500759494, 57.805530332749896, 66.64188508064517, 68.04912167210733, 67.91365085109588, 67.59704497552687, 66.66539576745802, 68.91529867725988, 67.95243524735974, 66.00041281792426, 59.118253492539935, 58.96781098458075, 65.18020206882109, 61.32080947199176, 68.51063559132238, 68.29422273943501, 66.30733828390798, 66.84267120976602, 66.3475190439532, 62.4843531270181, 60.177477790463364, 62.688147714061124, 59.650832914537006, 57.97856961527179, 54.91456700909523, 51.781797409057624, 52.740146190889426, 50.791591136686264, 53.53176678380659, 52.64797441421017, 51.18578933900403, 47.91854519997874, 49.58031615903301, 48.58655621928554, 50.25149645343904, 52.29144665502733, 51.07779079867948, 51.7206358909607, 52.73978533283357, 52.76325679594471, 51.48407774586832, 53.277346164949485, 55.83016980078913, 52.971181638779186, 53.07780342717325, 54.76725455253355, 53.75805224141767, 53.09242210080547, 60.412431686155266, 71.80314371662756, 74.92749983264555, 72.02418496531826, 73.17496915017405, 65.49539589112806, 65.59368656527612, 64.23449508605465, 61.44594092522899, 64.66046840913835, 67.75519494087466, 60.38308059015582, 67.6361745403659, 72.41027955086001, 77.68039180386451, 78.73580748035063, 77.16039534538024, 68.11630402841877, 6.866983675187634, 0.13699133700180438, 6.163212897316103, 17.716975404370217, 8.927634185360326, 53.83705269905829, 74.25724521760019, 24.52624728602748, 20.548975698409542, 81.46055252321305, 57.07337287164504, 51.54633360524332, 72.3798184241018, 45.41999540021343, 0.7769679662681396, 0.30339085887516704, 0.28257741442611145, 0.18171417106303478, 0.2171609980324584, 0.1647883010727744, 0.12795670123230066, 0.09988433621343105, 0.14119328330120734, 0.12299401430232872, 0.07406554139790035, 0.15206335082409844, 0.06808274710971503, 0.26111304038955324, 0.12143917757296756, 0.2216587462011845, 0.13127400750114074, 0.17325625394380864, 0.1203475788896603, 0.17532614690642204, 0.11103809375556246], [0.024074144481170564, 0.05605744581008631, 0.055635181976662534, 0.09075262178216251, 0.03034411640387149, 0.03588338217307483, 0.034144278315286485, 0.07347345502386171, 0.06789330122691971, 0.0476780335509008, 0.07358236974405666, 0.06473755524043115, 0.05531621743894874, 0.06517425600078798, 0.03960916652314125, 0.02663761065641959, 0.02126562593114232, 0.057611026155251654, 0.06598951910892803, 0.046135063523486744, 0.03960879114005835, 0.04370906225015079, 0.019995591963731477, 0.08529532550563736, 0.10877981211148924, 0.17186957351382703, 0.276474911238878, 24.88811339101484, 73.32052046252836, 40.87440767595845, 37.26460333793394, 73.96798610687256, 16.033531388928814, 20.918417861384732, 95.34030652815296, 57.46801430179227, 51.73996533116987, 0.9809679261619045, 1.0925998682937315, 0.4026853227086606, 0.8345913226085325, 0.24542582732054496, 53.84809024872319, 93.53727925208308, 76.7308722772906, 83.37080171031337, 73.11357621223696, 72.47091154898368, 66.34594225114392, 64.59341156867244, 58.523881050848196, 61.393640041351325, 67.15393481716033, 70.38195133209229, 73.67906431997977, 72.59337579050373, 66.52407277014949, 59.13203277895528, 51.93053368599185, 56.53886756589336, 60.49151843593967, 64.16647334252634, 64.44837016444053, 65.46655078088084, 58.57084751129151, 56.50580198534074, 53.037520685503566, 53.004682602420935, 49.81354813421927, 49.41242694854737, 52.02901263390818, 49.956875462685865, 47.83257861291209, 49.79634069627332, 50.078747426309896, 50.53354624778994, 49.65544915968373, 60.26227943358883, 61.28990903977425, 64.31266792358892, 63.489680136403734, 64.06615088062902, 67.44139748234903, 63.99295553084343, 60.31310158391153, 67.48897583253923, 55.24656034285023, 61.65940807711694, 61.22932411009266, 63.19297636708906, 65.88164344910653, 64.32255621879332, 60.57269973139609, 57.598425265281435, 58.01041141633065, 55.542307053842855, 55.22388904325424, 57.362216211134395, 55.98327559809531, 51.928435217949655, 48.886225300450484, 48.474145012517134, 46.38918953557169, 44.553080989468484, 45.325944808221635, 45.99188873844762, 46.55904777588383, 45.12802593169674, 47.023432870065015, 47.46892782949632, 47.69319718883884, 48.055698717794115, 48.195488068365286, 45.846882635547274, 49.05274560374599, 50.63533567613172, 48.50220172635971, 49.20174860185193, 46.60470416468959, 46.819979529226984, 47.86638944379745, 47.61803280922675, 48.12968246398434, 53.126503575232725, 62.41067924807149, 69.74611943767917, 66.518644209831, 68.38846160519508, 65.51922821229505, 61.49357811097176, 56.840890069161695, 59.8631037435224, 57.563496558896965, 60.39281199055334, 58.996150109075735, 64.9507708703318, 69.0252427131899, 73.86886781261813, 72.62251115614369, 87.61222531718593, 33.983521076940725, 1.4698537991892908, 0.27360342983757296, 2.7102033457448407, 4.2478719834358465, 7.282181757111704, 56.54933637188327, 42.98405055076846, 6.673721142353551, 36.9753756061677, 49.14684718655002, 77.31601145959671, 54.12104014427432, 59.21262964125603, 17.357958901313044, 0.5722738694279426, 0.15168226804704438, 0.15749033300145981, 0.02861162196964987, 0.03615100349810335, 0.0058680932101372995, 0.016338330348052325, 0.08489538164388749, 0.033592511148702715, 0.03864011126420191, 0.02701751365807028, 0.02040575160795162, 0.026039905027456345, 0.052992059894266634, 0.06704807642006105, 0.06637385009878105, 0.009617737847410384, 0.007162143555169385, 0.045624102030189774, 0.060274273367418404, 0.023964168729200482, 0.04027486628582401, 0.053808127394727165, 0.021037295340530334, 0.008380602568297858, 0.07231076338118123, 0.02443781599492556, 0.032413471189718095, 0.07849719150051956, 0.033838249172174165, 0.03357918121882024, 0.05114465418662276, 0.04786750241633385, 0.07774959693873122, 0.07580213248729706, 0.05249953047642785, 0.10636291962357299, 0.013283078817860975, 0.022926324520320184, 0.03276604400467008, 0.011926271986486691, 0.031202416416377794, 0.07027260944127076, 0.023226431803777817, 0.04249274062233106, 0.05249834687058484, 0.13557464124694948, 0.25792810645314956, 29.43932579409692, 87.68418512036725, 36.63159555004489, 52.438692431296076, 50.64943267453102, 17.533826212729178, 41.547643292334776, 88.24364062278502, 70.75328211630546, 55.01410499695809, 1.3272175433174258, 4.423094064958634, 2.9243672086346537, 0.9404521711891698, 0.13113844058206006, 55.77457412596672, 95.93754230007049, 82.61732224495181, 88.01769641137894, 77.40376272509175, 76.82618587247788, 69.23210851607784, 69.059571296938, 60.84304125078263, 64.50462871982207, 71.68290738136538, 72.52466370982509, 75.5103640402517, 74.92565631866455, 70.07586525332543, 62.016881127511304, 54.803046180355935, 57.583194701902336, 63.10462105658747, 68.6096126802506, 68.7861507169662, 65.72028890732797, 62.75721673042544, 60.51677457747921, 56.21604473360124, 55.44156097596692, 52.03083653603831, 52.258592882464015, 52.97507262999012, 52.19378356010684, 50.65806581128029, 53.56920188473117, 51.66485586474019, 51.199015571225075, 53.13306570053101, 63.021121640359205, 64.04985343256305, 67.26769924163818, 67.50817975690289, 67.26036440941596, 67.90237795922064, 68.60134432392736, 60.69778411619125, 68.96836050095098, 57.235139262291696, 65.22496415722755, 60.38558306232576, 65.41124143908101, 68.3281433966852, 68.30937877778085, 64.75353448621689, 60.744911393811634, 60.511275414497625, 58.93471402506675, 57.35892534255982, 60.700788651743245, 57.89869839145292, 54.818767040006584, 50.62725951594692, 50.398063659667976, 48.6380490949077, 48.797830766247166, 47.70237161267189, 49.6447410891133, 47.84794253687705, 48.179174930818625, 49.35967891447006, 50.021504356015114, 48.90128327954201, 48.42990459934358, 49.211138756044456, 49.27725815003919, 50.23773285650438, 53.33731528251402, 49.96979575003348, 51.70312643051148, 50.670801747229795, 50.159991479689076, 49.69306861200641, 50.7450012237795, 50.75628196039508, 53.64364062586139, 64.5790203925102, 71.81524030623898, 69.55706904011389, 68.66693419794883, 65.82638509811895, 64.25635053265479, 61.48727878447502, 62.721605531630985, 60.41529109401088, 63.832405074950195, 62.815989525087424, 67.57579357393327, 71.33596589488369, 74.14017815743723, 71.21348596388295, 87.72916686150336, 33.94210477029124, 1.310871801068706, 0.9632344616036262, 7.349815676289221, 3.204827952769495, 9.419576871779658, 64.8112835422639, 45.95610887773576, 15.518640875816347, 27.13068342977955, 51.54962447381789, 82.02611123361896, 52.87832344731977, 68.24142763691565, 18.846270884236983, 0.5753601005961818, 0.15781759044095395, 0.10404517423481711, 0.023125143488869074, 0.05005307082507399, 0.023463352155240796, 0.01676344977421386, 0.006976675583920892, 0.03075508810129137, 0.07486637140954695, 0.02435699754935359, 0.016539035808114756, 0.07058050017803907, 0.06816389880353405, 0.017951246118173003, 0.036756216788724545, 0.010781762483079108, 0.010988205941694399, 0.013525316777128368, 0.012181097727959916, 0.038888116907929225, 0.11265339780478709, 0.26084258070876526, 0.06525154661146865, 0.13459012633369816, 0.20007613415439285, 0.10554632352244471, 0.12106596251889584, 0.1900824712168786, 0.11260449841258027, 0.1264693338664309, 0.1716976633836185, 0.12373623858776786, 0.16287424571571812, 0.19219160320297365, 0.12705131554074828, 0.19542544419246335, 0.12064000231123741, 0.1343819189576372, 0.14925439751917316, 0.20794201852573505, 0.18206896170252757, 0.2683070043642675, 0.14422064827334496, 0.185842358417088, 0.24069734879078405, 0.3272677050723184, 0.7421326613233936, 47.25504098399993, 97.96634120325889, 57.25347634284728, 53.995590979053134, 104.60258360831969, 22.13677860075428, 30.037126387319258, 105.87321189142044, 74.85189222520398, 58.41177186658306, 1.0351779624339075, 9.401225082335934, 1.620770301068983, 2.053141500199995, 0.20813504203913674, 59.86922656336139, 97.65210443927397, 83.27940264055806, 91.18107226587112, 78.5606187389743, 79.92491322178995, 73.27709982472082, 71.93837135068833, 63.882929125139796, 67.72715783888295, 73.18099391075873, 76.50820716734856, 77.9828457678518, 79.602094311868, 71.27284711407077, 68.39359206538047, 56.731283357066495, 62.435409792007945, 65.72055955086985, 71.24448837772493, 69.72027101824361, 69.6996864195793, 65.18816448027088, 63.82143420557823, 58.168051473556034, 59.38033842271375, 54.807482381020826, 56.83342972109395, 55.63107813558271, 55.24306943339687, 52.123616280094275, 56.0645902541376, 55.982126343634825, 55.40263537437686, 53.38816096705776, 65.33180952072144, 65.35349238303401, 69.94140640381845, 72.69443173562327, 70.58337288518106, 71.0909354302191, 71.35080814361572, 62.89440162720219, 67.3563212733115, 58.51183545204901, 66.637374354947, 61.339499565862845, 66.29018183677428, 70.7877597501201, 69.14767557574858, 64.29003584769465, 63.127661058979655, 62.13068477569088, 62.02094862538, 60.28324057978969, 66.11857814173545, 61.38573646545411, 57.67603328151088, 54.989397987242675, 53.544216386733524, 50.47562852982552, 51.9514242295296, 49.159418382952296, 51.04962818084225, 49.28027053033152, 49.59252649737943, 52.550742780008626, 52.656250615273755, 51.567396733068655, 52.73155227784188, 52.80544188714797, 51.04245024342691, 52.94965174890334, 56.07732226771694, 51.608597309358665, 55.187720867895315, 52.12004692323747, 53.98158027279762, 53.50209405345302, 54.01073525028845, 53.227335945252456, 58.609012173068145, 65.60305710761779, 72.60260120514901, 71.32248078623127, 71.68126783063336, 69.2606084577499, 67.29006459636074, 63.01899179335564, 66.93466647978752, 62.43726507309945, 67.16958507414788, 64.61508658624464, 71.50664391056185, 74.8143865216163, 79.92643510141681, 76.22505126460906, 88.30171523555633, 35.798797915058756, 2.391384517954242, 0.9017929843356534, 10.271231301369207, 11.431266396276413, 9.978208676461252, 67.19717502593994, 55.32755728690855, 10.326558293834811, 50.286068224137836, 75.9490732992849, 87.10494518280031, 65.96402106746551, 75.91061838211553, 30.908910420633134, 0.940435991412209, 0.3489735193790928, 0.279245330321212, 0.26374406211318513, 0.230736505059946, 0.06186995407446258, 0.06677180979280703, 0.1376051419684964, 0.11761483601144246, 0.18900300736629194, 0.10077995428394887, 0.1513570790449458, 0.18112416078727092, 0.13909740463620232, 0.16253246324917964, 0.18145540188397133, 0.0834565842524171, 0.11010993993090046, 0.1610526571711225, 0.19564521949618094, 0.11715982574969531], [0.04825699683879653, 0.02034225057990801, 0.09735292890259335, 0.035526074934750795, 0.05008020182891239, 0.017058866684355082, 0.048740382997259024, 0.011672886490311113, 0.05573924352985717, 0.048853756349173286, 0.03670619124726903, 0.07376927221494337, 0.04015274804025408, 0.029663552620237874, 0.03869866336425466, 0.011070266407313607, 0.021145572292528326, 0.1029026996524584, 0.10004573561731847, 0.025223661326773228, 0.1366811786447802, 0.08603165857493879, 0.011701305479472204, 0.10346805721881891, 0.05439775079608925, 0.09025034389548725, 0.08161414279452256, 3.0378286300166963, 60.75729039407546, 59.26322429410873, 37.327686817415305, 45.31830010875579, 61.77921295166016, 4.373966868846647, 60.51923782594743, 66.21879469963812, 52.98260358072097, 3.4165383731165244, 3.4816624656800306, 3.5217446761746563, 1.4526984552221915, 0.21765316355853312, 42.57034640158377, 101.91739959101524, 75.32524385759908, 80.23179946407195, 68.79958875717656, 70.26017742772257, 62.69741627477831, 63.70846994461552, 61.034692179772165, 67.54260247753513, 69.07615507802656, 77.25344181060791, 74.00657438462781, 72.62411148317399, 68.89834619337513, 55.32139132099768, 53.05153923649942, 57.24143858878844, 63.602299228791274, 63.53209664744716, 67.5585194556944, 64.01242617637881, 60.68493050913657, 54.2577818132216, 52.07716757251371, 52.31595754623414, 51.28135396588234, 50.24625224451865, 51.13286872063914, 51.509898708712676, 51.065572615592714, 51.11722238602177, 50.173131419766335, 51.6092288109564, 49.40284067584623, 59.478507503386474, 64.0086724681239, 64.3625134037387, 63.77295763261857, 63.73736996804515, 64.19204719604986, 66.10153152096656, 62.19164233053885, 63.475755722292014, 58.20992669751568, 64.71009815892866, 63.40798108808456, 65.11366690358808, 66.51373340237525, 63.45227249207036, 62.28677157432803, 59.09826117177164, 58.98902316247264, 56.57279214551372, 55.5371569818066, 55.624206143040816, 54.820940033082046, 52.964835243840376, 49.23714799265708, 48.4115400621968, 47.54080918527419, 47.24543509944793, 47.196934992267245, 47.435101309130275, 48.01950308584398, 46.67241996334445, 47.6411904827241, 48.495129692939024, 45.689670116670676, 49.55709180524273, 48.81033135998634, 52.04310963230749, 52.726829744154415, 52.04582391246673, 52.194948504048014, 49.61950063705445, 49.06874102930869, 46.916532593388716, 47.00420541148032, 48.37995321519914, 49.964112235653786, 52.101953029632575, 63.13943993660712, 69.84378645496984, 70.1606668964509, 69.17921927667433, 66.18852969138854, 61.564525942648615, 59.02101009122787, 57.972941014074514, 59.13158170638546, 61.71722773582705, 61.10850334167481, 72.70586936704575, 70.16269868420017, 73.98479738543111, 76.75133920484974, 63.87324479318435, 2.153671234846115, 0.17983233736407372, 0.10884816247609355, 4.970142129928836, 3.727750009106052, 10.952657807257868, 66.92973998285109, 25.956215973823305, 10.36713227148979, 49.414254773047666, 37.32423905403384, 37.206230625029534, 46.65819744909964, 42.219321727752686, 1.8621684058058647, 0.18208383913001708, 0.07092805894752664, 0.010239854868080829, 0.06232029503031124, 0.059959215878118435, 0.0583621102475351, 0.06701652125845994, 0.04649832709542206, 0.051284231575987035, 0.06274056703513188, 0.09791562048297736, 0.02785111691111759, 0.039388808992601214, 0.022693556365406802, 0.050275496793009584, 0.041232127621169054, 0.09255016282681497, 0.04463289150848024, 0.0457552945872228, 0.05039469241314838, 0.00854423033043502, 0.014342721101016769, 0.031932672493219856, 0.045410543529977726, 0.04008224496858255, 0.02767515800622923, 0.03071379213173303, 0.04243106671398686, 0.01417123327677649, 0.06641400076689259, 0.08896481771502765, 0.08117201047078257, 0.053155240452577995, 0.057805589505381165, 0.013950559734967689, 0.059964850454801516, 0.0036623271326759774, 0.03537612471489176, 0.07054017330970495, 0.012481308433287328, 0.03137206850242952, 0.05861595348124543, 0.03908970145388477, 0.04638233372280675, 0.011012215137241349, 0.08935508588629384, 0.10638473014677725, 0.06042914187175132, 3.6068245624342277, 75.93831031553208, 64.77344835958174, 37.58979920418032, 58.49736190611317, 30.524959410390547, 14.333634991799633, 73.8492088933145, 75.21028703258884, 60.23434039085143, 4.680807513575401, 3.1444817973721415, 6.703484087221085, 2.2944728020698797, 0.3216175614826141, 45.53807443188083, 104.13114609256868, 78.70885295252647, 82.64769707956623, 73.47402634159212, 75.22888691194596, 67.47120749565863, 65.6832617329013, 63.27769564044092, 70.14085892708071, 71.5488015451739, 79.24548810528171, 76.3521360581921, 76.04560282922561, 69.45316545424923, 57.450595055857015, 56.184049960105654, 59.70999402384604, 65.78094836204284, 65.91162604670372, 68.58807886800459, 68.68152541498985, 61.525894518821474, 57.453693728293146, 57.03365495128017, 55.90685606002808, 53.24220172820553, 52.700498873187655, 53.41844558715821, 54.35747669589136, 53.590359149440644, 52.825316536811094, 53.099062673507206, 54.62164832699684, 53.11903930479481, 62.1085939868804, 64.73326367716636, 68.41461596950408, 67.24645568478492, 66.14372053454, 65.74954978881344, 71.28382975055327, 62.85809224651706, 67.40510771351477, 63.04453426791776, 66.99807551599318, 64.79882217222645, 65.97524689089867, 68.77619574146887, 66.2762652674029, 66.16275187461608, 62.66765332991078, 62.52785613459926, 58.923664708291334, 57.26130539371122, 58.37299139268937, 57.7258042366274, 55.071967801740094, 51.48879635718561, 49.852277617300714, 51.08807133090112, 50.62628676814418, 50.60044227107879, 49.426951485295454, 50.308288451164, 49.55045907728134, 49.79290077763219, 50.582787682933194, 48.26249391801896, 52.6502650783908, 51.69343033144551, 53.608303992978996, 55.20095886722688, 55.841995746858665, 54.34101843064832, 52.79864834200952, 50.26827243066604, 51.6952738454265, 50.423759106666814, 52.55915234165808, 52.00335641061106, 54.49732488201511, 66.6695221008793, 72.63281130021619, 73.6433001487486, 70.81595374691871, 68.14043444971885, 63.879795151372115, 62.280072166073715, 61.814761392531864, 62.63703923071585, 64.20832110989478, 63.75252600639098, 74.91101018844113, 72.48825626988565, 74.614455469193, 78.10121505491196, 64.0211691394929, 2.215407135025148, 0.5336012607139926, 1.2500719990461104, 7.268644677054498, 1.8918179696606052, 16.276303548966688, 67.700117018915, 35.4683146938201, 15.42464029404425, 37.18890159360824, 47.072407584036554, 37.74372085448235, 56.176275822424124, 45.805266288019, 0.959141897338052, 0.1254750896365412, 0.02443678943710702, 0.057041263583326535, 0.04715188819494459, 0.07373743360081027, 0.060720638326940045, 0.06813586764638463, 0.019022683282533003, 0.02338596195312998, 0.026341475538849354, 0.06488998375472523, 0.021282799707184878, 0.021357115981499517, 0.039858731155794476, 0.05220819489970323, 0.06380353701270877, 0.04503122658558911, 0.05446649569597456, 0.06015721513258834, 0.02603812770347201, 0.02127054038517658, 0.1520247553144732, 0.12667405554243635, 0.1833124756212196, 0.14553318671401472, 0.11020826731598186, 0.12264433346929089, 0.1964954391963059, 0.11340610217303039, 0.14419893734157085, 0.15749891318621176, 0.0970349181443453, 0.22837883882945587, 0.14794204293960525, 0.2115769984741365, 0.13042337411353666, 0.09224022663528882, 0.11315657201433375, 0.15117015359142136, 0.20798521056290598, 0.16875174887959035, 0.2900487635164492, 0.2381546723265802, 0.14201408522503992, 0.15823527689903014, 0.39297607757391473, 0.2365984872824723, 0.5055081423732543, 7.419942752007516, 94.16058309616582, 77.96761912684288, 54.282637873003566, 71.31535776199834, 83.71210282848728, 7.68071613965496, 74.59852280155306, 84.7752534189532, 65.59893861893686, 3.542667824414469, 9.115789301933782, 9.645130807353604, 2.8519700611791308, 0.4658307327378181, 48.010662063475586, 110.26585855791646, 81.19454522286692, 87.55539017338907, 73.55951832186791, 80.12482858473255, 68.93043902612501, 69.4434928894043, 65.72818071611466, 73.22821140289307, 74.54870870036464, 83.69394225458946, 77.21391216401132, 78.845076868611, 72.82780801096271, 60.97111840401927, 61.18920218560004, 65.80099167362337, 68.91675779896399, 68.6075024450979, 71.57258679789882, 71.11221821077409, 63.525279568087676, 60.870227198446955, 59.717866220781886, 57.639465024394376, 55.25788814790788, 55.915893200905096, 56.32040723677605, 58.43749477017311, 57.57050583439489, 56.649717669333185, 55.684379223854314, 58.05702094108828, 55.44667966904179, 66.49026978400447, 68.5561429300616, 70.63259863084363, 71.61428943757089, 67.50818760164323, 67.55687206022202, 74.81172715463947, 66.03019929701283, 67.72351003462269, 61.996998633107836, 68.9665012974893, 65.30988347145819, 67.07781730159637, 72.0865192720967, 69.0232736833634, 70.1430711438579, 64.99497990454397, 65.67475018962737, 62.18748854052637, 59.67237457152336, 61.980116751886186, 59.06833740972704, 56.79272336344565, 54.76338709554365, 52.837722993666134, 51.94771758971676, 54.18625739312942, 53.07496755353866, 51.30631592965896, 53.716937957271455, 52.04742423949703, 51.472997050131525, 52.14475785532306, 51.2650800520374, 56.46087515738703, 53.84912183207851, 56.814931823361306, 57.72194854674801, 59.07644887124339, 57.562072738524414, 55.51840805238294, 53.88060669745169, 54.48000761770434, 51.53511954892067, 56.5694659756076, 54.462953152195105, 57.015749331443544, 66.51247039917978, 75.23183653431555, 74.32808322291221, 73.66953296046104, 69.73967106111589, 67.20985212633687, 64.0730817087235, 66.48199358294087, 66.01165433083811, 69.28458982898344, 65.30747905854257, 81.39282887981784, 74.69947676504813, 80.14142021056145, 77.66915029095065, 69.22110234537433, 2.6825736799547752, 0.6966610529249715, 0.7795435538695705, 16.712387761762066, 12.604902309756126, 13.408112525939943, 78.02447780486077, 35.619467150780466, 15.151433483246835, 77.54281859244071, 54.16232309033794, 53.45965400818856, 60.61042116534326, 66.14128082029282, 5.627395558741785, 0.5215964790794158, 0.42488792971257244, 0.13667463625390686, 0.2160950939381315, 0.20968998602080732, 0.15109179811852594, 0.16430594147213046, 0.22650762310912534, 0.17501076382975425, 0.15423304972148713, 0.16935930256882023, 0.19238666451025396, 0.17856594805996265, 0.17289256136263573, 0.12871429324150085, 0.18049002384706853, 0.22684117779135707, 0.2532677178180987, 0.19382926935870803, 0.1405819757811485, 0.08664226129410729], [0.06260553254715859, 0.02836174707138731, 0.034760347071794734, 0.039066787764069535, 0.11423583668206008, 0.03571930529189206, 0.012768369239394464, 0.029534434246259834, 0.01870018707948827, 0.051698501281920946, 0.03187933936715126, 0.03779567935834489, 0.03961979982353026, 0.008664690953258787, 0.06633655693862708, 0.08146747526141905, 0.01042943385865299, 0.07616810801048433, 0.016247937718646664, 0.1416565673125367, 0.03603578387429157, 0.025720791102597312, 0.04294076033176915, 0.06185375131486405, 0.03230294768488215, 0.07071186127441545, 0.22082400147713002, 0.2581965130183005, 32.33476258093311, 64.31764541133758, 52.21378764798565, 58.980088003220104, 75.07823651836765, 26.1656960364311, 17.239995579565726, 85.77355154099004, 76.25581833624071, 16.70743576941952, 2.1802281323940527, 5.811097314280849, 0.2763342574959801, 0.8755041562741803, 46.856881187808135, 97.16505589023714, 75.93013609609297, 86.03667982162969, 69.40693639939832, 68.19819527287638, 63.36880837717364, 66.73779487609863, 69.93961780301987, 75.230298965208, 77.64304299508372, 76.99635398003363, 76.41867514579528, 72.64597477451449, 61.33371014748851, 54.49124520824802, 52.467733660051906, 54.34812576540055, 63.838912287066066, 63.79213802276119, 66.48997168387136, 65.12382191996421, 60.91302810176727, 51.56114839738416, 55.53129696076917, 49.75613640200708, 51.064592023049634, 50.934032009493926, 52.20668423560358, 51.203094836204286, 51.273662197974424, 50.39631036020095, 51.5544686009807, 51.49023194466868, 50.48176311677503, 53.93610431301979, 63.55495622081142, 63.252494412083784, 65.48561742228847, 66.09119999793269, 67.69621818296372, 65.16279851236652, 65.0386437293022, 65.88807613618913, 61.71703553968861, 61.9806109705279, 67.20708293299522, 53.58137692174604, 62.73567507343908, 65.44521700951361, 62.63228139569683, 59.73404599774269, 58.31377537019792, 57.85717225843861, 55.5547409672891, 56.16741126583469, 57.52481806662775, 52.87020414106308, 47.77507666618594, 47.89896865044871, 46.418650457935954, 46.26859626462383, 47.23238145151446, 47.69764515661424, 47.08215075154459, 46.13816176691363, 50.47894293262113, 48.64202637826243, 47.882231896923436, 47.52722993973763, 52.5438747098369, 52.087640300873794, 54.465275195337114, 54.675055319263095, 54.79479743588356, 54.48125100904896, 53.24746947134695, 50.33761601294241, 50.135778688615375, 46.94437749924199, 50.860138477817664, 46.564213537400775, 61.85225532900903, 71.84067295443627, 72.09751759805988, 68.61131498890539, 70.89997091600972, 60.45341260971562, 59.465191056651456, 58.550266834997366, 60.673685073852546, 58.56918834870862, 70.03819481019052, 65.55202707167595, 77.38414302948983, 65.52081677221483, 80.28304915274344, 17.120563330188876, 0.2992190198311883, 0.5174066522909749, 2.450901827504558, 5.856626716352278, 1.925763509446575, 27.21574983289165, 63.83542529998287, 19.660319589799453, 28.854492556664255, 55.22200630557153, 28.019545462823686, 28.456801483708045, 55.865188721687566, 17.792641847364365, 0.3914243205180092, 0.07293495650012648, 0.06833960872984703, 0.03551368346257556, 0.07873988049405237, 0.04142948719222219, 0.056903823579271, 0.05987576592052656, 0.0230477781846158, 0.04288819137840502, 0.04504490125503752, 0.07954548323346723, 0.019459424262505867, 0.10110607025243583, 0.07628804673590968, 0.11138012903111597, 0.05044448046734737, 0.062066624166383866, 0.04310054329013632, 0.017746505289969426, 0.026543548465856624, 0.04106359593870659, 0.07248532417560778, 0.04856519018029494, 0.033849974147855275, 0.024386625999825138, 0.04235179959646156, 0.05670961646002628, 0.057210802671409426, 0.05512401747006563, 0.031155851677120216, 0.05154227680196205, 0.015918780381100315, 0.03338513114759999, 0.03531361960114972, 0.05261145975260485, 0.020714747426550717, 0.11636991249096972, 0.03220561238366269, 0.012320934629608548, 0.028711550478493015, 0.0792348345801715, 0.05024791762773549, 0.004094041857658134, 0.06329031556003517, 0.04818231475749805, 0.07840759751777496, 0.023141298367972338, 0.06554334184094783, 0.19299622534984545, 38.52937552236742, 77.35754151498118, 47.63435771388393, 60.45186327349756, 45.681260555021225, 18.042263446315644, 41.101591356339, 84.28818918043568, 80.70818701098042, 19.556159088688513, 1.6837401543894124, 7.495864639359136, 2.6264918763791365, 0.6551761660845049, 51.6124608439784, 98.85085136659684, 81.09961601995653, 89.25798123882663, 71.188994684527, 71.35476189274942, 66.30358849802326, 68.15388033466955, 71.43592357635498, 78.07984598221319, 78.45181219039425, 82.1947809957689, 75.97435689741566, 76.04803469873245, 62.75718535146406, 58.62604310435634, 55.4915790404043, 58.57545629624398, 66.43045363887664, 68.88366083944999, 69.80207597055744, 67.81778027934413, 64.823509570091, 54.22689707048478, 57.54990162387971, 52.48600013794438, 53.03464558816726, 53.65183053478118, 54.109724106327185, 53.33196516959898, 55.98987302472515, 52.62268689370925, 55.556137331070445, 53.0187992126711, 51.70236941306822, 57.1443481599131, 65.53445485330397, 65.40719355306318, 68.3177020472865, 68.55018092739967, 69.61584967951622, 67.43495695052609, 67.23300195509388, 66.94262889123732, 67.49603609884939, 67.03089006485479, 69.03427985406691, 58.63937131820187, 65.78627494073683, 67.69091513849074, 67.65316624795237, 63.89657897333946, 62.296044057415386, 60.57879509464387, 59.12110897802538, 59.255010850967906, 59.60601591294812, 55.9967371725267, 51.88895263979512, 50.355670682845584, 49.85151667748728, 49.41356835826751, 49.97791505629017, 49.413489910864065, 50.361820959275775, 49.81795687829295, 53.55165320058023, 49.40511957291634, 50.51545627655522, 50.62954233538721, 55.41222556944817, 55.34012848331083, 58.58131239491125, 57.34410270567864, 58.20227023093932, 58.22022684158818, 58.294363560215125, 52.287014376732614, 51.295301914215095, 51.03589988523915, 52.620686484921364, 50.414918084298414, 62.68108744775096, 73.0854606628418, 74.1534593028407, 71.1296570685602, 74.33104069002214, 65.80439236856276, 64.20280233506234, 61.4907814610389, 63.494775295257575, 61.281056250295336, 71.69996969161495, 70.869384273406, 80.59461870501119, 68.57305619024461, 81.9977681867538, 18.572332551402432, 0.48481236902936814, 1.054461437367624, 6.145771097752356, 4.155059879825962, 1.8436354518898073, 33.061846456220074, 65.45954542775308, 25.467794595226167, 17.03186873466738, 54.9505586777964, 31.515975652202485, 34.35342411841116, 64.41396313328897, 18.755097350766583, 0.37942097912872996, 0.07160245380814999, 0.11094242469557833, 0.14091324752136586, 0.04694611697848286, 0.060307625005201954, 0.06972743063083581, 0.06942096481760664, 0.017954015526019277, 0.03585671848287025, 0.030896077007656137, 0.04574384157275481, 0.07270486199206884, 0.05298251060829048, 0.13214152546659594, 0.0331694352620792, 0.07528349096255918, 0.06216573679158765, 0.026545925253641703, 0.040743861482628894, 0.0012740564078182704, 0.04363488195644271, 0.23671165379064701, 0.10839341268424066, 0.14114129657466568, 0.1146850246755827, 0.2752171787283113, 0.16491674337415926, 0.13609063210746936, 0.12245067410291204, 0.1157530278508221, 0.1902754947302803, 0.09021275962192206, 0.14988412179293173, 0.17425161666206776, 0.13047661722427414, 0.1207438225467359, 0.3003100516094316, 0.19149218024986406, 0.14150492786880464, 0.10289808780315424, 0.37699119338104803, 0.12843682385620572, 0.18597293044290236, 0.2337963674818316, 0.19348417739233664, 0.20165510265336883, 0.16471135520165966, 0.2694961873273696, 0.4779692733239743, 57.046500713594504, 85.14682739011704, 74.70405024866905, 73.12558650970459, 105.05984567826795, 36.15767909634498, 27.270510042867354, 97.99802610951086, 91.6013934535365, 21.596001425097068, 5.458570862970045, 13.805969319035931, 3.7226014079586154, 0.9641755852968463, 54.516956344727554, 101.29735131417551, 83.03954970452094, 95.07657420250678, 73.56410749496953, 75.09906430398264, 70.17674076941707, 71.72822644633632, 73.78770612901258, 79.96338382844003, 83.06946954419537, 83.89713671899612, 79.94198337677987, 78.18478507380333, 67.04614808482509, 60.07472738142937, 59.30221265362155, 60.23441099351453, 68.32962605261034, 72.20256651601484, 72.05877242549774, 70.64893138024115, 65.88618555376607, 56.467017589076875, 63.6346274037515, 53.80662295126147, 56.95607046927176, 55.94171808611963, 55.93654447986234, 55.39769318795974, 57.55789149192072, 54.09946710832658, 59.66540451972716, 55.04234213982859, 55.30466241221274, 58.82276565797868, 69.62196857698503, 65.53363115556779, 71.16606450849964, 70.99308798390051, 71.74120949160668, 68.61111102565643, 68.147949710969, 69.96013964376142, 67.66768686233029, 67.13725689918765, 71.70725745539512, 57.835646290932935, 68.27875291147541, 70.36093527270903, 70.49731608360045, 65.73793565073322, 64.20246501122752, 65.033768223178, 60.49393461596582, 61.298495108081454, 63.80810206936252, 57.73043263343073, 53.802116147933475, 53.058026836764434, 52.88242232414984, 51.36046817225795, 52.84797999166673, 52.218055186733125, 51.94060241022418, 51.239306157635106, 56.57022691542103, 52.22296599418887, 55.29548014363935, 53.044639787366314, 58.371771535565784, 56.288683106822354, 62.2403464009685, 59.25819581554782, 60.54523137307937, 61.41933941072034, 59.425418223104174, 54.33125172891925, 55.824878523426676, 53.185088096126435, 57.836768088802216, 51.365441737636445, 66.86330287687241, 74.82137618526336, 76.63872795720255, 72.01725805959394, 76.39275612369661, 66.26248990335773, 67.294190929782, 65.71616257390669, 67.83600361116471, 63.57775303625292, 78.25341870707851, 74.4440520194269, 85.47399228618991, 69.85550649704473, 84.74787527515043, 19.958029447063325, 0.46113498148418247, 1.490035251744332, 8.744888997847035, 14.518530618759895, 5.518722370747597, 32.84614747570407, 74.85631665875836, 25.743121447101718, 41.63224489458146, 79.84873294830322, 41.73148478231123, 44.93398235690209, 73.82763585736676, 37.828769606928674, 0.9183629758415685, 0.21224735605139888, 0.3096657624888805, 0.1647710334509611, 0.19416109268223086, 0.21683346480131152, 0.15977552731431302, 0.2789677613444867, 0.19226401383357664, 0.16150287172246366, 0.1443623285740614, 0.1812109891926089, 0.09171660553904311, 0.3450804137654843, 0.23285925808933475, 0.32860897181014864, 0.20021882569116933, 0.1659744043624209, 0.12886614718985173, 0.19943960701986668, 0.08816712100299136, 0.08961110480970914], [0.021202465812225017, 0.018384641209136576, 0.027968734390132373, 0.06010484919252415, 0.11839099799192722, 0.02678681968621189, 0.04045760506884225, 0.05782144369497415, 0.0712540140375495, 0.03244208074325035, 0.05895617695885801, 0.034062689951350617, 0.04575675781515818, 0.03092781794557889, 0.0294435283379449, 0.006252349985222663, 0.09737664698472909, 0.01432733326744769, 0.008490221131773246, 0.04191629010282698, 0.07676634607055495, 0.06650464429009346, 0.022990786988708763, 0.02559640523677151, 0.02805151210557069, 0.010517426717635846, 0.047903033574261976, 0.1751841601705359, 1.577457773589319, 78.25024158723893, 54.27599337793166, 96.03740584465766, 94.56245345454063, 59.75071999334521, 9.279877735722451, 47.12537134847334, 101.42373008112754, 36.508287998937796, 0.6524675856194189, 4.677243059681309, 2.5840077044502383, 0.4252974803168928, 34.23510974453342, 101.01318343993157, 82.88341583744173, 84.89457191959505, 80.47233489251907, 78.6771837357552, 66.5107524010443, 75.64898060214135, 73.69152176764705, 77.48055488832536, 78.86595172266807, 78.0390376429404, 75.31834833083614, 65.54524921601819, 58.642905373727125, 56.44995135645713, 55.17112924206642, 58.750778398206165, 65.85466538706135, 63.020333243954575, 64.4313156989313, 65.62006450468495, 60.79321146011353, 54.22905437407955, 49.2494995363297, 50.68487128903789, 53.14288339307232, 51.47042005292831, 52.24395459698093, 51.04444672984462, 53.20927343060894, 51.83545151064473, 50.47750342276789, 49.14742769733552, 50.13606894400812, 50.877020359039314, 59.68705600307834, 61.25811430715746, 63.75380862143732, 65.36594983070128, 67.41114031883978, 63.126284307049175, 67.73880727829473, 60.602945127794825, 65.55232909417921, 63.4184459717043, 69.31900470487534, 45.78604667417465, 58.799223592204434, 67.23761466241652, 64.15077209472656, 65.37161765560028, 59.36557854375532, 60.507423646988414, 57.4307753193763, 59.47176102669009, 56.68908649875272, 56.82063887196203, 49.93946013912078, 47.58748931269492, 47.5794876775434, 46.75614295467254, 46.46455787843274, 46.90282783200664, 46.29452313146284, 47.60668931468841, 49.87287790544572, 50.97799393438524, 52.33330618950629, 52.72054218476819, 54.77402456345097, 55.56809271535566, 58.38914371305897, 56.60219030995523, 56.552960641922496, 56.36092532065607, 55.53781986236573, 55.18089986616566, 54.89080136822116, 50.311512639445645, 50.26633870217108, 49.26524393020138, 57.848770541529504, 72.56217725815313, 71.08319267149895, 72.48156470637169, 67.56204174410912, 68.03219272244361, 62.189147703109256, 58.67180539715675, 58.37914951385991, 64.52657438093617, 64.48797825844058, 74.17693076595184, 64.79192272309335, 79.75432149825558, 42.50017519920103, 0.21562424097811023, 0.3657845834330205, 0.13089385935135428, 3.9855683811249274, 3.2930244072791073, 0.43600279297078814, 42.903383085804606, 44.35334213318364, 34.30342174345447, 70.27563941094184, 32.38217030802081, 35.89701798654372, 54.59099108173002, 46.38953862651702, 2.0813623407194695, 0.06836117410491552, 0.06794410817805799, 0.017284266988656694, 0.03883146470592868, 0.14741152705204102, 0.05589875835745085, 0.02328148288201661, 0.040430956700396155, 0.025662148987213453, 0.10088316930998718, 0.15578039411094882, 0.04560206168060822, 0.10357364711742248, 0.033266517754283645, 0.028071145023850184, 0.018994726818956194, 0.11283904389147797, 0.050622032835118236, 0.07249861580109404, 0.08806014448524484, 0.018589897231469234, 0.06244591812813475, 0.042125029909995296, 0.03848338882709223, 0.03433751633330699, 0.039313717054263245, 0.12319119767315927, 0.016355668832998604, 0.04950904497696508, 0.040745657958811334, 0.03703736722649586, 0.12761222979714795, 0.012443508697493423, 0.02374095943636231, 0.031851700830063036, 0.06676918211122675, 0.044809670127447576, 0.03927145581392031, 0.015372399770234142, 0.06717067347058366, 0.05201589150895035, 0.01790046214967245, 0.05391221959143878, 0.08602007532552366, 0.019151702065080888, 0.053150138307002284, 0.02438953138827797, 0.013613279950204156, 0.05845661102343471, 0.2110628462246349, 4.686696462092861, 92.68279091004403, 61.66372660667666, 90.38725514565745, 111.09227057426207, 31.048203591377508, 17.772576962747884, 65.22591337080925, 100.06628405663275, 40.051455190104825, 0.8147573062489111, 6.588026179421333, 4.826534842291187, 0.25878774903474316, 37.14093492877099, 105.6919748552384, 84.13232987926853, 91.3349860714328, 81.2169498012912, 79.78017776243149, 70.98548643050655, 79.09383358493929, 74.8463067700786, 81.50216102600098, 81.56379715088876, 80.33861344860446, 79.10734222781274, 70.40061396937217, 61.55711266302294, 59.17695176216864, 57.13575032449538, 61.02638852211737, 68.54129283658921, 67.50500263706331, 69.0262782189154, 68.02131991232595, 63.36869070606848, 54.89350780364006, 52.83453802908621, 53.07858397883754, 56.20991799139208, 52.96322314969955, 54.39106787404707, 53.680687412138916, 54.402054432899725, 53.319295913942405, 54.62824575362667, 52.175870095529866, 52.80655584027691, 54.49641096976496, 62.05759925227012, 63.843513227278194, 68.97770358670142, 68.35452525846421, 69.09703777682397, 65.78687898574337, 67.88292300316596, 65.11229407402777, 68.09618226943478, 64.90971542173817, 71.18374655323645, 47.702595187771706, 63.320574991164676, 71.07666584753221, 65.7807404764237, 68.38210736551594, 61.279416699563306, 63.9172302522967, 59.82621385205177, 60.953432436912294, 61.99898335241503, 59.62734968431535, 53.985945870799405, 50.08419167610907, 49.61357001335391, 49.708816928248254, 47.981142305558734, 49.726483283504365, 47.769522590021936, 50.688256294496604, 52.74235056292627, 53.23188197228217, 54.061749596749586, 56.09837362843176, 56.121629361183416, 58.26271003292453, 61.82150786922824, 59.99709583097889, 59.833093689334014, 60.79371744586576, 59.00770541160338, 59.23970576255553, 59.28223209996378, 52.10243940353394, 50.57544500597062, 51.56012465876918, 60.419848888151115, 75.26218783470893, 72.58891997798797, 73.3590381376205, 68.9054064596853, 70.53037381941273, 65.38933107929846, 64.26446591654133, 61.87694272687359, 69.0683417166433, 68.45409854765862, 76.94209191106981, 67.96294719942155, 81.9635102056688, 44.121710485027684, 0.17986276637642615, 0.6693938386536414, 1.51584162827461, 5.849530658414287, 3.250131573407881, 1.1036908602522266, 46.786957094746256, 51.64389079616916, 34.17516023881974, 56.42154555166922, 41.09194624808527, 38.57038782488915, 61.57564193971696, 53.8689298014487, 1.1144197684141899, 0.12133593956429152, 0.010190589668890162, 0.05972273985765154, 0.08172982973196814, 0.060151703129973144, 0.0035330677506393727, 0.056225686379137545, 0.0030929382680164232, 0.07480598835935516, 0.06540399810840046, 0.08607394662835906, 0.07461189998373871, 0.03596640695186873, 0.05418133095748002, 0.006444177443852589, 0.05246708282239495, 0.05680556897254241, 0.05262306215421808, 0.04161685314630309, 0.08159426281288748, 0.04454420917036553, 0.06901160573526736, 0.24444315101831193, 0.10556780462784153, 0.25244817227846195, 0.22308048281458118, 0.2228602631798675, 0.10476944908019035, 0.14853084279644876, 0.20673216651043586, 0.11845315836610333, 0.20193395865780694, 0.1677162891193744, 0.09921318956560667, 0.12869710222848002, 0.10475234233684118, 0.20649316239981882, 0.19314069421060626, 0.13740499383739888, 0.0770670815461105, 0.22013528843320188, 0.08728415104410342, 0.11056020810839631, 0.20663563943197652, 0.20157973492337813, 0.1625195163632593, 0.12424262270571725, 0.14491624078683316, 0.11776450660920913, 0.45668021084800847, 9.577338522480382, 111.78580053390996, 72.37315823954921, 112.49939733935942, 107.63676443407613, 89.0165279757592, 12.831661393565517, 63.41539829008041, 115.50915748842301, 46.095333407002116, 3.389474754371951, 21.354152002642234, 9.57996258812566, 0.4986844133705863, 41.015334513879594, 108.26795224220523, 89.15583487479918, 91.19872293164654, 84.09904464598625, 83.84393368997883, 74.9288805069462, 83.23403650714506, 79.36169224400675, 83.66943528575283, 83.92962963350358, 82.67546746038622, 81.82083791302097, 71.7444964378111, 65.5196165269421, 62.87817478179932, 61.64383626753285, 65.52589231921782, 72.87484507406913, 68.41302348721412, 69.75544683394894, 70.3410331664547, 66.34709542797458, 60.29250129576653, 54.69431415680916, 56.53793796416252, 57.6171192815227, 56.66783901952929, 57.09041949241393, 54.71599309675155, 56.78197214680334, 55.61529844037948, 57.11118844247634, 55.23463241515621, 55.03248130121539, 56.63656596214541, 64.9329907663407, 65.68562299974504, 69.43616590192242, 71.65669810387396, 72.30953739535424, 65.96039679742628, 68.93862893504482, 65.64197094209733, 70.44172040877804, 66.42247553794616, 71.39431507356706, 50.73762324548537, 63.72840342983123, 72.99319867164859, 71.50030536036338, 73.25106313151699, 63.27561286187942, 66.42406017549577, 62.354809007337025, 63.69747554102252, 63.14555098933559, 61.19449738533267, 56.883373260498054, 52.745551216986875, 51.526054951452444, 53.189132059774096, 51.244617046848425, 51.69944724728985, 51.28950465110041, 53.05282185154577, 56.12186862576393, 55.360834675450484, 56.29424895009687, 59.1766458172952, 59.354227204476636, 60.576312234324796, 64.35258980720275, 62.83384807648198, 62.73491805599582, 62.60084752113589, 62.706127858931026, 60.45733890225811, 61.95109513498122, 56.59845621355119, 54.850981466231815, 53.66904581746748, 64.42068607576432, 77.0695375627087, 75.1174053069084, 75.85795664018201, 71.46793011696109, 73.80956942035307, 69.35471396292411, 66.90547620096515, 65.98579806666221, 73.20059791687997, 70.22445248019311, 79.78010715976839, 72.28352423637145, 85.35093184440368, 47.913238233135594, 0.4760753201140512, 1.1493161152447424, 0.7428698217676533, 12.205778591094479, 12.105280603131941, 2.638124645717683, 49.52329274146788, 56.771448427631015, 40.28360459112352, 98.41852772620418, 46.682469075725926, 55.86628306296564, 69.45756635358258, 73.57749846673781, 5.126750113502626, 0.6847920833576111, 0.31062763184309006, 0.13978381941635765, 0.12296076608641494, 0.23624536671465446, 0.12076790835107527, 0.18236497807646954, 0.16873000730429927, 0.21342376066792398, 0.1653984747827053, 0.4276927614644651, 0.15125736504072143, 0.2004267879190945, 0.15212601681630458, 0.10600911723750253, 0.15236227833215268, 0.1588405936115211, 0.1375594371629338, 0.1927009137767938, 0.25501453618128456, 0.08032555992324507, 0.15133144574299937], [0.06470861243865182, 0.06246913442268007, 0.03795414081504268, 0.04145661053518134, 0.02563471346342516, 0.06238692169708591, 0.04201953577238225, 0.10552626734058704, 0.07244155757249364, 0.04017227945188361, 0.09538988222277935, 0.07334965521529799, 0.015796677457288872, 0.052584727114487084, 0.02732329765304683, 0.044005534446407715, 0.05241638695400569, 0.03852334031234345, 0.04382150863567668, 0.021428323854061387, 0.07245509434611568, 0.02556719813465832, 0.03892573948589064, 0.03130533266812563, 0.0869702848215257, 0.03266509276844802, 0.07659635882103637, 0.1161117944866419, 0.029823919720647317, 41.23687390358218, 59.895184809161776, 40.8286649950089, 33.77581980920608, 61.676109529310665, 45.74188078603437, 8.687504722226052, 81.37924178954094, 46.64115475070092, 0.7709286193693838, 4.046766916590353, 1.396348949882292, 1.0200630476878536, 8.38410448643469, 92.85739914063485, 84.5328744765251, 90.60827286012712, 83.2802184935539, 85.2933906739758, 72.06639751311272, 71.42238355452015, 73.2704004164665, 79.54332151720601, 78.38700679040726, 78.89685999962592, 68.46949777295514, 60.84128402894544, 57.972172229520744, 61.32699112738333, 57.097315019176854, 57.97283118770969, 63.565750583525634, 68.76529939713018, 66.10130402349657, 66.40196154194494, 59.626392625993304, 54.4325626281, 52.378056510802246, 53.37240088370539, 53.55339081056657, 56.543052734867224, 54.83105974812662, 55.8674793858682, 56.0294379726533, 52.854267551052956, 52.0316170877026, 51.272893413420654, 51.1079381358239, 50.194010196193574, 53.322806435246626, 61.83341226270122, 63.904914009955625, 68.55285598385719, 68.29721158550632, 66.04908158702236, 66.50884612914055, 60.714336518318426, 68.40505323102398, 64.09871439779958, 66.53140760237171, 51.428250651205744, 61.10828368894516, 67.50497910284227, 65.25804542726087, 61.71038712224653, 60.49284419705791, 62.149947535607126, 58.26423975729174, 63.892558543912834, 61.31298434349799, 59.59054608498851, 51.42816828143213, 47.365071312073745, 46.258178449446156, 45.571151779543975, 47.80873452463458, 47.85212378348074, 47.853814325025006, 48.36063946447065, 51.45290274773875, 59.491804338270626, 61.28180542299825, 60.856785235866425, 58.52739941689276, 57.343377067196755, 57.122375042207786, 60.35186244595436, 59.44466529353973, 58.484194509444706, 58.0322668629308, 56.77703388275639, 61.38427342137983, 53.90099909997756, 49.47190969221054, 50.07342869235624, 53.199934267228656, 66.68420745480445, 73.67110190852996, 72.24703834902856, 72.68348047810217, 72.22139389284196, 64.28037112759006, 62.75971920259538, 60.08478433855119, 64.84174074665194, 74.66928235946163, 69.19071966601958, 76.91559237818565, 54.16141702282814, 1.3361827332165934, 0.282529947618323, 0.1382386353948424, 1.1450795877364375, 5.096081591421559, 1.9698079266855795, 0.7692888847762539, 49.71139784782164, 25.062978536851947, 25.252168178558353, 49.24420433659708, 37.21931565192438, 41.93085493579988, 61.468984849991344, 19.624924121364472, 0.6903609296967906, 0.04450219690859799, 0.062367401776775244, 0.0556815302960815, 0.07398810523051409, 0.04901910493631036, 0.0807285221714166, 0.08568398489226257, 0.03568120390897797, 0.02002275169586703, 0.044711331251047315, 0.05615915547335341, 0.03741817804233682, 0.025965671107593565, 0.049538949219089363, 0.01756544423950536, 0.0688453646556985, 0.10051979848574247, 0.01577197878261007, 0.02944554697962538, 0.04048541023005401, 0.03173833705424782, 0.05385507709316669, 0.014389733044100145, 0.017514742625456665, 0.03399945705408051, 0.05209934529698184, 0.10787344582739378, 0.02711396221251738, 0.0282467017325783, 0.07705389717293364, 0.06175926586072292, 0.03467319307908897, 0.1308902280945932, 0.057021529158397075, 0.012335908775698515, 0.05424535675575176, 0.06211562698046046, 0.023938619696925727, 0.049018499726850184, 0.024080037612528093, 0.08376295813509534, 0.035353161229361454, 0.015735663342169456, 0.02359682382384856, 0.017466099872704477, 0.03823714518559076, 0.059981443919241435, 0.022941215354348385, 0.09269277775479902, 0.11879631979090553, 0.06912589839269077, 49.22793826749248, 75.06613992875623, 44.91546092494842, 52.641651553492395, 60.857620700713134, 24.938054969233853, 23.47128856566645, 89.49180156953874, 53.39804533989199, 2.760443514393222, 7.797435089465111, 8.343985503719699, 0.1030413309232362, 8.896882803209367, 95.80138114190872, 86.56212837465348, 94.65418984813076, 85.9141920458886, 89.8716752759872, 74.52149529610911, 77.081312517966, 76.3385489679152, 81.44462770031345, 80.82774085383262, 81.98275335373418, 71.33693864268642, 65.55321947220834, 61.354938014861084, 63.746458099734404, 57.97351760248984, 63.45010734373524, 66.69847703749134, 71.10835859852453, 70.48059894192603, 68.15905786329701, 64.68101378410094, 55.299645700762355, 54.80459943894417, 56.82451417369228, 56.75008327730241, 57.868786396518836, 57.49930697102701, 57.077742392017, 55.78941637469877, 55.113309583356305, 53.583224358097205, 53.801563093739176, 54.052908574381185, 53.3336204098117, 57.72387443050262, 64.28254412066552, 66.1899652788716, 71.5921986487604, 70.49093830970027, 67.93661240608462, 69.22294585935532, 67.30456167651762, 69.21327329451039, 70.28368811453544, 70.08691849247103, 52.668480565471036, 62.17710210431007, 70.08079175026187, 66.97512180574479, 67.11726850078952, 62.362975382035785, 63.76855281091506, 60.7957806125764, 66.090501816042, 64.58894398904616, 62.78809362842191, 54.28329290882234, 50.49433823554747, 48.738175438296416, 48.48021291917371, 49.88289171649564, 49.024461392433416, 49.99027052233296, 51.939311950437485, 53.62880229949952, 60.3449982981528, 62.7413546654486, 63.99677591939127, 61.9049092262022, 60.8335961834077, 58.789719689276914, 61.64242029190064, 62.3594021028088, 63.20643794152045, 63.53086502321305, 62.20129920590309, 63.63885571879726, 58.36755891000071, 53.0572384403598, 54.565464296648585, 55.72349702158282, 69.62351399083292, 74.32823227297875, 75.31007212977256, 76.56476774523335, 73.80614911356281, 66.53407481408888, 65.84555764352122, 64.02983757757372, 68.91194897313272, 76.70866381737494, 72.9100287345148, 79.27020688210764, 55.60134656967656, 1.3416114161091468, 0.6098600428911948, 0.5782948302165155, 4.343602330453934, 7.025032149207208, 2.5812823926248862, 1.4919679996467408, 54.2630377892525, 31.40733188198459, 28.204551896741314, 63.10402877869145, 47.02616676207512, 43.15130825965635, 71.55540681654408, 17.31278104166831, 0.5842508267491096, 0.0823457720839689, 0.13428779739526012, 0.04550478383598309, 0.030354320695022904, 0.03531354299235729, 0.05821736942556116, 0.02633739995109218, 0.04251926641670927, 0.037257579200330286, 0.03153955447487533, 0.0460147149410219, 0.09856385344098653, 0.042931881372726736, 0.023330885977033648, 0.028435427492724794, 0.027144153737613273, 0.04158727832198624, 0.015614838827581657, 0.09228536453578742, 0.044049205288531325, 0.05959396047757999, 0.04377610260440458, 0.2525684634043325, 0.24065136819356875, 0.14693325836091273, 0.18355553999783533, 0.16014832102002638, 0.13910811454538377, 0.15850253433229464, 0.2990129728230738, 0.16918624330672527, 0.14005666929146937, 0.38644346198247326, 0.25782109929188607, 0.11614188642030764, 0.19179242542914807, 0.19256807413072358, 0.1472516291804852, 0.1594047101154443, 0.11201836454171328, 0.16668380178030462, 0.09460349296850544, 0.2206405693845403, 0.15133625677516385, 0.05981541734429137, 0.16116942429254133, 0.16707899589692393, 0.17979069282450985, 0.18066876748156163, 0.33349544831341316, 0.1694158858229076, 68.28644075701314, 83.45211244398548, 62.74210776052168, 49.33521116933515, 90.09648984478366, 62.95557491240963, 15.386351097014645, 97.00614498507593, 58.79471286650627, 3.433241786495332, 8.7533877934179, 3.267821953181298, 1.5304023243727223, 13.260996187886885, 95.68871498107912, 88.85731112572455, 97.87986078569966, 87.19978809356691, 94.73542213439943, 77.6696837332941, 78.5289102985013, 80.9869106354252, 84.11345543399935, 84.66238329487463, 86.43484746256183, 73.79733162541544, 67.51811119817918, 63.5428870877912, 69.56020693625175, 62.2540746965716, 66.92646872612738, 69.57471186114897, 75.83462638239708, 73.55638042573007, 72.98637374754875, 66.90037711974114, 59.0868470745702, 58.12093596304617, 61.41402459913685, 59.05374227031585, 62.90054405889204, 59.814321225689305, 60.34240168909873, 59.63984635568435, 57.648219754618985, 56.92256166088966, 56.948782705491595, 56.498569134742986, 55.926056062021566, 58.65253087012999, 69.95991999103178, 68.33634115034535, 74.75821818074873, 73.17766774085261, 70.74224456664055, 69.52354061988093, 69.65064110294466, 70.9193003562189, 72.07064936237951, 72.56168303951141, 57.236119854834776, 62.81733097568635, 74.12144491749426, 68.41224685792001, 68.5385864011703, 64.17557324132612, 64.86947974851056, 63.26350842752765, 69.00299502957252, 66.38879022290631, 65.10366485964867, 55.22556389531782, 52.97002061720818, 51.29141092300416, 50.86082097022764, 52.63508158345377, 51.88382217960974, 51.806206318639944, 56.75753185825964, 56.60320228145969, 65.50916341043288, 66.9260843338505, 68.72701706424837, 63.25952722180275, 63.96318474123555, 62.702385917786636, 67.31566982884561, 64.70752116172545, 65.93308141154628, 65.32214480061685, 64.16461413906467, 67.68769879494944, 61.57471626035629, 54.684021857477006, 56.54598666775612, 56.53038740158082, 70.94886718257781, 76.40594313221594, 76.0255830518661, 77.89121135588616, 77.07775100584954, 69.30463314056396, 70.31389820960261, 66.84376947341427, 73.8834668743995, 80.44081472581433, 80.01688495759042, 82.98603288588986, 59.312704993832504, 1.821719943996399, 1.0701022561519378, 0.39340110315430554, 5.538843149139035, 17.33761552841433, 7.775876272109247, 1.3618691097344122, 62.52080371302944, 32.81309366226196, 39.68177572373421, 64.89841115090155, 53.88213249944872, 56.18295169645741, 78.00554844640916, 34.744339296894694, 1.115012781754617, 0.2887597439750549, 0.15812718189291416, 0.1774658304789374, 0.1694807121830602, 0.15823945973909673, 0.29497630233245514, 0.25457740641169013, 0.15785071608279982, 0.153083810582757, 0.1563266148009608, 0.14790884068896695, 0.16026283584294782, 0.16067345897036214, 0.1213399462041355, 0.11265115316716895, 0.13245583602016972, 0.12462908341999977, 0.11610469285158381, 0.23273300679941333, 0.16501097218884578, 0.1591339286777281, 0.10873005470080722], [0.02052459291242544, 0.10265027368140799, 0.03617123971062322, 0.02136333086978524, 0.04298808158285195, 0.10124377455682525, 0.0337078916509786, 0.04123926756062335, 0.03906716314715244, 0.02373921275589495, 0.04571671439935604, 0.06893574770900511, 0.052206620589018836, 0.049483848345135494, 0.11680279047258439, 0.03270390661313169, 0.10645499573119226, 0.04194063254662099, 0.03168006649150724, 0.07314064344691654, 0.05320671006977078, 0.13395580553239392, 0.013089957628248921, 0.0846860021533024, 0.052082905050126777, 0.05882082454439613, 0.11856261700872453, 0.11853329882386232, 0.20200606285324021, 12.47144268405053, 86.0577037257533, 47.63471857193978, 80.89897894090223, 43.793847407064135, 75.08374352608958, 22.97696598114506, 43.085302614396625, 70.36648934887302, 0.8285177775448369, 6.5799063828683675, 8.719842703111711, 0.8893985397392704, 0.1177243942454938, 46.456352280032256, 99.81748027186241, 82.9188113058767, 87.90634032218688, 80.60399316972303, 85.01698124793269, 74.70169682656565, 75.61247118057744, 79.70068700851934, 79.19707821261498, 68.10315624360116, 63.357500183966856, 65.63110989909019, 69.41994297888972, 64.83570421895674, 57.77623414993287, 60.65594419356316, 66.96907351093908, 66.83590904358896, 66.52632421062839, 64.39807361172092, 63.88368614258305, 54.32172429177069, 53.58010999618038, 52.83630701803392, 54.84478412135955, 57.27110739677184, 60.54585110756659, 62.180644004575676, 63.535697383265344, 57.28386686694238, 53.42637661964663, 50.01380866573703, 50.211586336935724, 51.18185912409137, 53.10982565726004, 58.62693348238545, 62.316534519195564, 66.46706504206504, 68.26885284916048, 65.73118917403683, 64.12835967156195, 63.594576081921986, 68.24927237726027, 62.034241537893976, 70.04634549540859, 49.8659941457933, 61.79970733581051, 67.67477850760183, 67.09182016311154, 63.373668193817146, 57.72164260187457, 63.79392662355977, 64.14375105211812, 67.5536008034983, 65.3930220296306, 64.98366386659684, 53.387992305140344, 48.11940977650304, 48.42346406752064, 45.53598380857899, 46.77311897277833, 48.87807069286224, 49.55711141709359, 51.657034658616595, 63.26874086933752, 65.81644581210229, 68.72045886132025, 63.96830343431043, 62.77661285092754, 60.42533236165201, 59.78504857709331, 58.97615778830744, 59.028544964328894, 59.87895011901856, 62.4823134945285, 60.574794277068115, 63.62278969057145, 61.37871150047549, 53.068938870583814, 53.20420572834631, 55.80259946084792, 65.29703378677368, 77.35356423162645, 72.81135759046002, 75.84675435096987, 71.84931785829606, 71.39611936384632, 63.93321783311906, 67.3381293204523, 67.95339230568179, 75.01661608296057, 75.57249438378119, 59.8498422099698, 2.8634339234521313, 0.14291457561475618, 0.13619900290523806, 0.5005994186766687, 3.441811920173707, 4.460251167897256, 1.819040965168707, 3.694483161933961, 45.51591696277742, 19.262440243074973, 42.15165691991007, 41.360754120734434, 46.16904650965045, 50.09536650873, 49.529945081280125, 0.09406039025634529, 0.01598099246621132, 0.006200125771424463, 0.03086104189165898, 0.06475519058444808, 0.05568917968400544, 0.038362408222089854, 0.03825155146900685, 0.035128816211175536, 0.013227625543461933, 0.023010806781390024, 0.05641009906427034, 0.07608839656196295, 0.03163492667578882, 0.04831176446450334, 0.04400897035074811, 0.09837800051055609, 0.020915006640397256, 0.0358347317594434, 0.07105933577423135, 0.013001280078183741, 0.02054395961515125, 0.013748941672665459, 0.029154445059717666, 0.011996619925353558, 0.01428293559940592, 0.027468576651787566, 0.005373711295936618, 0.036525275753510576, 0.0392102453887703, 0.031642646926845756, 0.06049939213440784, 0.022924326946057623, 0.01649687415920198, 0.055579855106771, 0.052262843781781775, 0.08192070053830262, 0.0075336526271947216, 0.12799082278844812, 0.048168333652879924, 0.03200538189811332, 0.047072720668849447, 0.025370397807789907, 0.038860805873428626, 0.026981836943436536, 0.03407199791963062, 0.09022312479153757, 0.051168720838764024, 0.07335376144657213, 0.0969321704319408, 0.1689989348092387, 0.1403207091554519, 0.3235227608632657, 18.146780883112264, 97.25299542950046, 55.7573627656506, 68.42698712502757, 54.30235955022997, 57.37730556918729, 23.628367723957187, 66.20629018352878, 67.95646744389688, 1.6199591058877207, 6.958167995176008, 16.752231197972453, 1.1354376664084773, 0.07616072292289428, 52.20205583880025, 101.99178341896304, 82.77750399804886, 91.5067074375768, 85.12946697973436, 90.77280059937509, 80.20720620309153, 81.06404796723398, 83.9294413597353, 82.58536277278778, 71.006620160995, 65.74754545765539, 68.91960543970909, 67.49404353480186, 64.74804316797565, 61.984647089435214, 64.5185217549724, 67.79837239173152, 70.84999992001441, 70.20465235556327, 68.81602348819857, 65.35384539634951, 56.36061937578263, 57.39372853309878, 56.77920687583185, 60.439480350863555, 59.110193021835826, 61.82128037175825, 64.93552461747201, 64.69251417344617, 59.729366610127116, 54.61169727386967, 54.06149072031821, 51.64207081640921, 54.571492979603434, 56.02069500953921, 60.94372457073581, 65.69863350160661, 70.30159765674223, 71.77726391823062, 69.19270438532676, 69.03375425646382, 67.42012254653439, 72.57144189650013, 65.6521063466226, 74.17922927487281, 52.59621873978646, 64.59544727879187, 71.43197767196163, 70.04188183815249, 65.26957719556748, 63.05709761957969, 67.67342921226256, 67.5159146708827, 71.45250735744354, 67.87891434084985, 67.28280036680161, 56.67901777452039, 49.94647725935906, 50.77787460819368, 49.03666388603949, 49.30249860209804, 50.43852290799541, 50.63258217227075, 54.31968073691092, 64.18520658246933, 69.59968166966593, 71.64934758217105, 68.37951860120221, 67.30662484322825, 63.123844592801994, 62.787289542536584, 61.52133672468124, 62.379535628903305, 63.04546779201877, 65.04501365846204, 67.10387752902123, 69.22219276428223, 65.36678921791815, 56.87272402548022, 55.38245477984029, 57.866025047917525, 68.23078232426798, 77.79805506429365, 76.57243205655006, 76.89457631880238, 75.47307798939367, 72.5760938275245, 67.31815661153486, 69.99302479528612, 73.49963941881734, 77.43062311603178, 78.40240601570376, 62.0491583116593, 3.05339529148994, 0.18696692952465627, 0.5183849159267642, 2.4273641743967613, 5.677874501674406, 3.3551130756255123, 1.9760704809619536, 4.80919159227802, 56.772244668776, 23.13809890900889, 46.72587794642295, 49.516001055317545, 47.17349883048765, 57.33949784309634, 50.075946854006865, 0.6454029066428062, 0.04866672747377907, 0.13670414596075012, 0.048475737923816334, 0.061741347064173994, 0.06360540369285211, 0.04166401734936141, 0.03149402586953535, 0.05498033767986683, 0.10090443591076521, 0.06637887563556433, 0.05720656620518816, 0.023552804411719405, 0.048878481836929444, 0.009898777202432676, 0.05055537169438697, 0.05317633085313344, 0.019532690996364243, 0.003198408944186785, 0.052692082845756126, 0.027491674202704625, 0.05109108931895706, 0.03489396046666849, 0.0797982233005666, 0.11900202972033333, 0.1336163060078698, 0.06409602938219905, 0.14056869181654147, 0.13431108646815823, 0.20406351454796332, 0.1008424747194494, 0.155515082541012, 0.11576520864881816, 0.145258161149198, 0.18686122471286407, 0.1252484195415051, 0.20073930582692548, 0.08443954400718214, 0.21356338785300333, 0.12217865160275852, 0.1535495154319271, 0.133297736005437, 0.1447099792740999, 0.19186552553888292, 0.23206911500423189, 0.2539347658955282, 0.2023657258119314, 0.2095561811039525, 0.13076357843895114, 0.10682694674018892, 0.25510908675289923, 0.2731567699342005, 0.4186054265066501, 25.564655565446426, 114.40167627026959, 63.28018634550033, 95.10137142673616, 62.49924244419221, 108.76810150761759, 30.442766143429665, 59.143195844465694, 81.47426512933548, 2.461101951137666, 22.963376929683072, 23.14268612092541, 1.2776364554320614, 0.25694613495180685, 55.606579011486424, 101.08894009743968, 84.35081374260687, 96.01856277834986, 86.99101601877521, 97.48279140841578, 82.46842907321069, 85.82710758332284, 86.90292742944534, 84.55371010688044, 71.81092569904943, 70.47635493739959, 73.39175854959797, 75.7968931813394, 69.43727985505136, 63.472488387938476, 67.47086232708347, 75.2682988874374, 71.49533963972523, 74.41580310944589, 70.4759705451227, 71.20513916015625, 59.553581668484604, 60.40365734407979, 58.9207935333252, 63.6985267362287, 62.99929365035027, 66.26667899470176, 68.60947931966474, 68.08613315705331, 64.2517456700725, 58.933929551032286, 55.48686827382734, 53.8559663680292, 56.686819368793124, 59.13098942848944, 62.278040378324455, 69.39886416158369, 71.0898450113112, 74.96507613889634, 69.0016378894929, 72.35870038309406, 66.75187618501725, 72.72832101391208, 67.83376786016649, 76.98961534807759, 56.0596872914222, 65.06460589747276, 73.16485727986982, 71.46956966769311, 66.9272610449022, 63.764195057653616, 70.41360485938289, 70.5988976263231, 74.12314722614904, 69.99557433589813, 70.47259730677452, 59.70703263436595, 51.774184088553156, 52.52173293021418, 50.0003392465653, 52.39573463316887, 52.45523306631273, 54.57237159052203, 58.23054659751154, 68.35734152024793, 70.74044812110164, 75.09627157641997, 72.3275096954838, 69.56155623159101, 65.00768053916194, 66.3147907872354, 65.41335951897406, 65.01576062171691, 66.99810689495456, 68.81527823786583, 66.78161559566375, 70.33793449401855, 67.73089978002733, 58.281506030790275, 58.661854344029585, 61.342331517127256, 72.24109988058768, 80.6869669883482, 77.37633751284692, 79.25684728930074, 78.4890119491085, 75.7487892335461, 72.10609974399691, 76.37800016710835, 76.81490513586229, 82.38518068867346, 80.68330349460726, 65.86505182327764, 3.592238493504063, 0.3469199440892666, 0.8409512006948072, 3.315942571047814, 13.625323580157373, 11.8235553849128, 4.3914121004842945, 5.503664881952348, 58.89712595170545, 28.4809652451546, 62.25437671907487, 49.313975457222234, 60.40479090905959, 61.11838379213887, 78.48825885403541, 1.1788885800107833, 0.2964604597899222, 0.1754527812403056, 0.09040052011128395, 0.22632408376422622, 0.12228448664949787, 0.14169733851186692, 0.11991476985595881, 0.1246297652382524, 0.2436916953733852, 0.12050514019304708, 0.1898693302345853, 0.181554778809509, 0.13668059641795774, 0.11553506817548506, 0.07687531441690461, 0.1488887284311556, 0.15740319816095216, 0.12998930869563935, 0.12062468821363104, 0.06538401853533522, 0.14201569400968092, 0.14944346801888558, 0.1821108513902272], [0.05448154166280743, 0.024002852338937022, 0.1630029944522727, 0.07673029397283831, 0.02879937288291272, 0.12259163428097965, 0.09129266780350478, 0.02208709243624922, 0.0705724868983511, 0.10627428325073374, 0.012792261606532962, 0.07279906016323837, 0.07499332750035871, 0.06029789951900321, 0.002634891185856935, 0.05148514579500883, 0.05022227666490982, 0.044969085363611105, 0.14730965267987023, 0.04587746262850781, 0.041483963704517776, 0.05530549220800881, 0.04941166371047016, 0.028151942402004238, 0.10389924980700017, 0.03681137128883312, 0.026345531974408417, 0.09650721379946317, 0.09015226931942087, 0.39932841735501445, 60.8272340989882, 70.5470125136837, 97.84648141553326, 63.220260374007694, 46.38776571519914, 46.47466974873697, 17.06917243619119, 73.47336738340317, 2.146945105445001, 9.734085259899016, 25.956763144462343, 0.5638297418913534, 0.3320216483646824, 0.9032228108375304, 46.81651607636483, 96.21130020387712, 83.48602525649532, 84.31871306511664, 75.2392811929026, 77.22291792592695, 80.93132280534314, 79.58423968284362, 76.47645165843349, 69.11880693128033, 72.9881388141263, 78.52253252460112, 79.19882758971184, 76.77627763440533, 61.32519468184441, 58.118755125230365, 64.01083761645903, 67.98282577145484, 68.2894217583441, 64.05229314681023, 57.668310134641594, 54.76780368435768, 54.058647001943285, 55.4931087647715, 56.975560726657996, 60.77886735239337, 65.97367009808941, 72.6802876687819, 74.04322501151793, 71.84676831768405, 60.86193923027285, 52.01045197825278, 53.02103496366932, 51.48535251617432, 53.34998846054078, 54.83200896170832, 65.46640957555464, 64.4273619497976, 71.28998002698346, 66.4020949025308, 63.51824283599854, 70.45346398507395, 67.30451460807555, 64.58275841128442, 71.901807015942, 41.39397267372378, 57.1726284488555, 70.49279751316195, 64.33941456579393, 60.14901707249304, 65.34588298489972, 67.13817473380797, 68.07438173601705, 68.12381928966892, 65.94135761260986, 69.97700583550238, 57.16389333048175, 47.80758134780392, 47.91666246229603, 48.76355709568147, 49.05481661519697, 48.05839730847267, 51.36443368850216, 59.976679894231985, 67.89807904151179, 68.17084066329464, 67.21133478226201, 70.99038939322196, 63.764834403991706, 62.75667544334166, 59.6137272927069, 58.068446805400235, 60.51461727388444, 61.555998709894, 62.97680277978221, 64.44027439240487, 65.79752822076121, 65.41778395252844, 60.85815806542674, 52.94190114544284, 52.370054875650716, 61.244225194377286, 73.07144995658629, 74.8875936385124, 74.02551158781975, 72.87293095742503, 71.12140440171765, 70.0446431867538, 66.07095272310319, 70.86965099457773, 75.85412056215348, 62.65084989609257, 12.584464799973274, 0.14733920835198897, 0.43368761397657857, 0.23705568855568288, 2.932664247289781, 3.977775367036943, 4.670226429739307, 2.2318624584905566, 8.559612900980058, 22.289560802521247, 28.492094970518544, 48.831080698197894, 98.05447686103084, 53.5000426538529, 49.98341029690158, 7.024441342200003, 0.29369969341543417, 0.1045516273006797, 0.14892108798507722, 0.050729204705285455, 0.041058145223125335, 0.049954509783175685, 0.038275874760602756, 0.07006391176893827, 0.016296542167002638, 0.10008400170913628, 0.034374120014329115, 0.05026343090820217, 0.061206640675663955, 0.06871239477468115, 0.03361048740184596, 0.05040449833857918, 0.0407256247595914, 0.013033008567177722, 0.018768434022222797, 0.038167806567564126, 0.059073016858629646, 0.0060784255225782196, 0.08028750833604606, 0.02699851276232831, 0.0392259770042954, 0.03025906340729806, 0.06407417289371933, 0.05282294598498172, 0.03501264663833765, 0.04286119443995338, 0.1196637228431721, 0.07498027336212897, 0.08043377750342892, 0.036268552029204947, 0.051335850580325054, 0.02829603587968215, 0.04454915043747714, 0.02390677916757282, 0.03745624878173394, 0.015614360022628981, 0.051527483644144195, 0.03256103121525338, 0.05376707274286498, 0.01395538321606094, 0.10347105262260284, 0.06526414109694381, 0.03908559905305024, 0.009295121943127484, 0.15026135880860592, 0.05951098166406155, 0.043528683017939336, 0.018595796108486193, 0.0686844861915996, 0.4496081774273227, 69.53355050856068, 80.31063125979516, 89.04725582368913, 66.50601417787614, 67.75277876084851, 36.38496475835001, 31.564348282352572, 82.4884331610895, 2.277246242569339, 1.5450717436690486, 4.372068441683247, 3.6836787481461806, 0.7236753968942551, 0.6259463571252362, 54.67759309276458, 97.54307823796427, 88.55351571113833, 89.3736284009872, 79.72281702103155, 82.08542531536472, 84.1422377863238, 82.31306399068525, 78.0384571321549, 70.54110542420419, 74.44985712728193, 79.76374303140949, 79.6028160279797, 79.58795024502663, 62.88731782667099, 61.12098824593329, 68.19573202440816, 71.59477172359344, 71.49916002827307, 67.02600279162007, 62.00476100367885, 58.209589373680856, 56.23941813745807, 56.87173558819679, 60.88444186795143, 64.83758303426927, 67.84584091555688, 73.118926325152, 75.76417276936193, 72.94800512252316, 60.32929705035303, 53.97053487839238, 56.01967911566458, 54.26220624677597, 54.021082462803015, 57.73911676099224, 66.87958855782786, 68.3091591250512, 72.46076045497772, 68.88628098272508, 68.51123179158857, 73.0184587355583, 71.12685649625718, 68.74768011031613, 74.88424393438524, 45.63121111162248, 59.48958035438292, 73.07022617709252, 66.43793752116542, 65.37133916731804, 69.56751038951259, 68.98257517045545, 72.37323668695265, 70.33327471825385, 68.82404081283077, 72.41876755991291, 60.045588093419234, 50.49064336284515, 50.045191549485736, 50.740776831103915, 52.59136676788331, 50.94398306262109, 52.95682184157833, 62.477696864835686, 70.93403277858611, 71.42977329992479, 70.86930582600256, 72.10515837515555, 67.03781697057909, 65.02515862064978, 63.81360515471428, 62.65130096866239, 64.42263157136979, 65.23524861181936, 67.01070554794805, 66.77407680019256, 69.69927064834103, 69.41724438821116, 66.41591733501804, 55.61445905316261, 56.38786808136971, 63.49354367102347, 76.27570475301435, 76.1977437234694, 78.67662675919073, 74.88925672346546, 76.96882678616431, 73.59623955142114, 73.17607525856265, 74.57293325854887, 77.61832421825778, 64.76178715305944, 14.012710586670908, 0.18267994746565822, 0.977526352770867, 1.258518700638125, 5.465107002565938, 4.85583886984856, 1.9579349121739789, 0.822183701299852, 11.126712003061849, 30.221558194006647, 30.910640185879124, 61.89117700822892, 84.79787765010711, 56.07705162417505, 60.51777870424333, 10.060357816757696, 0.5097499405664783, 0.08399698267420454, 0.14819676717442853, 0.05377612790212997, 0.15216669608508387, 0.023034057549891934, 0.05016441787442854, 0.05900317262257299, 0.02145548550141675, 0.11712853105798846, 0.1057331723671767, 0.07910194130794657, 0.06637452425615442, 0.057038494175480264, 0.047205468384368766, 0.029346928481132756, 0.019780920720809413, 0.046586879198589635, 0.025275337787705566, 0.19924715041152893, 0.04971894923777831, 0.057521531763937206, 0.05273689132844729, 0.09221686095359827, 0.1870182267720661, 0.10361575897062018, 0.29212149100438245, 0.2068231624340819, 0.12106835271321958, 0.18974540785195368, 0.12315653985546482, 0.08010060586515935, 0.17558209688192414, 0.19790562320380442, 0.1034260526179306, 0.11451354355461175, 0.1287934454458375, 0.1541614358223254, 0.10129994412343349, 0.10366100412342819, 0.13329908432018372, 0.1015825079934251, 0.2684805386008755, 0.1801395539434687, 0.15190346827430112, 0.15005955592759196, 0.1035182053343423, 0.11147347684468954, 0.2698713559056482, 0.21813653439523714, 0.12226753312373355, 0.16650861279378015, 0.29080262467745815, 1.945053848528093, 95.33291678274833, 87.77971836828416, 114.42581453631001, 67.89997746867519, 77.68534183502197, 67.10704680412047, 26.472333208207164, 90.42003047081732, 4.113155238090023, 19.64312784133419, 48.169141507917836, 2.2122089324458956, 0.48348820137400783, 1.727181752362559, 57.49827538767169, 99.20897160806965, 90.58829230646934, 92.76927132760325, 84.79061342054798, 88.08461204651864, 86.52145339596657, 84.83922727646367, 82.22391636140885, 75.60716813610446, 80.63079864748063, 84.14221425210276, 83.64701501784786, 85.751766697053, 66.7515702401438, 64.2233084863232, 71.42423491324149, 73.77363266483431, 74.51437227187618, 71.04904451677876, 63.175419838197776, 61.357150231638265, 58.88849673732635, 61.80230394486458, 63.40186219061575, 66.99480425926947, 70.8947463189402, 77.1347979576357, 77.76131814525974, 76.0093601288334, 64.76891802203271, 56.80778526490735, 59.45742868608045, 56.79880303721274, 57.3763838121968, 60.77212872043733, 70.73884779407133, 70.56830313897902, 76.25533196233934, 70.09401798248291, 70.05892061418103, 72.46744417375135, 73.95367730048396, 70.43218904925932, 77.86225641927412, 47.80172524913665, 60.51621760091474, 73.88449453538465, 69.5867064691359, 67.82785292594664, 69.29287387478736, 72.51778387254285, 75.48719852201401, 72.62924978809973, 72.26572452052947, 75.81141379571731, 62.398457142614554, 51.422920150141564, 52.53673599612329, 52.59669334657731, 53.35143189276419, 52.29023072027391, 56.395610840089866, 65.45752932948452, 73.0878140849452, 73.67437316525367, 72.72301796943911, 74.07280752735754, 68.89662035049932, 68.53195759557909, 67.7439691174415, 65.60604595368909, 67.70707530360069, 66.75936791204637, 70.28450396753126, 70.25565885728406, 74.00616645812988, 70.28523352838332, 69.79931462195613, 58.4375536057257, 59.56017125037409, 64.70501476718535, 79.26398600301435, 78.25899631746354, 78.52733350569203, 77.47129024997835, 77.15768890996134, 75.80456533739644, 74.97255217644476, 76.06144135998142, 81.00749523408952, 68.9794921875, 15.20954437794224, 0.28196178617015966, 0.9693502947207421, 0.6673952071897445, 10.756450064720648, 13.58986633439218, 10.657170953289157, 4.473588207075673, 11.700705770523319, 33.3854341506958, 43.14007851385301, 66.18998881309264, 98.35242794406031, 65.0625309636516, 68.42833642036685, 24.100024892437844, 0.7738594879065791, 0.28562095917520985, 0.33572016764552365, 0.2141700069149656, 0.22463371075930136, 0.18477706719310055, 0.21603382222594755, 0.1526964765282408, 0.08818011385418716, 0.27461524812444565, 0.2265997834864163, 0.1361711939135867, 0.2046262061283473, 0.13460347158533914, 0.1662006301264609, 0.18185192899357888, 0.08935825749030037, 0.14969722698292426, 0.12278175432114832, 0.3754916835215784, 0.14660157293321627, 0.12019299000741974, 0.25353545022587626, 0.16495736135590464], [0.11908083718510405, 0.0454479094684845, 0.04295902769832362, 0.061776552634734305, 0.03530424651539615, 0.026302864707465616, 0.03366291462894409, 0.033369924302303025, 0.06976012726344409, 0.03899154260814671, 0.05384421779684002, 0.031990343592159694, 0.056085645506579074, 0.07627780414036206, 0.04769971000871832, 0.07474412675946951, 0.07794949992169296, 0.029415263523978573, 0.014434182423076805, 0.03421702985501578, 0.026226435945699775, 0.07107708603143692, 0.028583954704264482, 0.0822050647149163, 0.035352632628693696, 0.06739185837608191, 0.031109032213627815, 0.18364325706516543, 0.028906232572250792, 0.42736996265669025, 16.117576995203574, 91.10864962300947, 35.756177440766365, 38.37469293225197, 36.219264230420514, 64.46853899186658, 16.653597316434308, 44.39733935940651, 8.228509945254173, 1.978241145130127, 10.001642877055753, 3.012241538493864, 0.500076272554936, 0.24386126127454544, 0.1453731815901495, 21.84810588436742, 79.90936494642689, 72.77209466503513, 80.89116557951897, 84.33481047230383, 90.98596572875978, 85.93287037264916, 75.24845169436547, 75.14961581076346, 82.64980731471893, 86.79430130989321, 85.2047529528218, 83.95586244521603, 68.88278222853138, 61.861896514892585, 64.91805830309468, 65.20466981395599, 67.815136601848, 65.80524352289015, 61.439712201395345, 56.830495788205056, 57.38926879821285, 58.402934766584835, 60.364402263395256, 63.93079380835257, 68.2235808526316, 74.30685535553964, 75.97277225986605, 72.86867910815825, 69.08414886843774, 56.576334045779326, 51.88560685803814, 52.69494479702365, 51.77087360812772, 55.25062784071892, 61.94880054843042, 61.91572712313745, 68.66432189941406, 62.515606572551114, 67.7587329187701, 65.41728581151655, 64.66319053403794, 64.25162407659715, 72.47590080384286, 35.768568208140714, 54.68127227598622, 69.16593028653052, 54.35429957605178, 70.27657293504285, 65.3247021859692, 69.31792997544812, 67.07488336870748, 69.72011412343672, 67.62187357871764, 68.19286084944203, 55.92715040329964, 50.9856504009616, 49.17751619892736, 50.506995724093535, 48.67839067212997, 50.809418309119444, 54.64564538771107, 63.079294312384825, 66.16019448926373, 63.87773982940182, 62.09858409820065, 66.90826892852783, 66.17472294838198, 64.26882366980276, 63.837096229676284, 60.79116006051341, 60.68964127571353, 61.39634647677022, 63.38632568236321, 64.49982773873114, 67.53256905463435, 68.43446316257601, 67.36950828183082, 60.389972194548584, 54.54158490703952, 58.16097551776517, 71.57765450016146, 74.76206210351761, 73.8109814736151, 76.60017890314903, 77.19098198798396, 72.81849630417364, 69.51083214052262, 68.47891930610903, 53.82311259546588, 15.66834205581296, 0.18494163820099446, 0.3486083405873468, 0.19831661405342244, 0.725157501236085, 1.5642290898869116, 1.8508155956383676, 0.8773619501340775, 0.47879879332838526, 12.415719532197523, 31.20235273914953, 45.35003208344983, 35.487757882764264, 57.54370035663728, 55.52142435504545, 55.473791091672844, 0.32021571251173175, 0.26767718815995806, 0.17138834772331102, 0.026665948248738726, 0.012095594654730972, 0.059826736293372616, 0.04314909794277722, 0.05024863391994469, 0.04245613694130894, 0.04637220604044776, 0.006773685266624295, 0.038458544595707814, 0.042463437759227333, 0.06860898822666177, 0.12099987211366817, 0.03675214886184662, 0.05384369685705151, 0.0365095479684251, 0.11284913326944075, 0.039715514848789865, 0.01262890772082873, 0.03412940471823658, 0.009103563572880963, 0.049016875620450706, 0.06231444977944898, 0.042488075146872195, 0.046890288321000916, 0.05521615869515846, 0.016290825235867695, 0.09329309191314444, 0.03531659585273555, 0.03157088938619822, 0.056661915995420954, 0.05803685229752333, 0.04773265178946238, 0.10746669144399705, 0.044120382517576225, 0.003555117915722452, 0.05609267436328435, 0.07457743368802533, 0.05490006698716072, 0.04379048207474332, 0.025772593968037157, 0.037580918100091724, 0.028836156594597047, 0.043879271665167426, 0.09155896762686391, 0.05363006940892628, 0.009122206322518329, 0.07562045473605394, 0.07619601659356587, 0.053493747893240184, 0.19249626104870152, 0.11481627851964966, 0.49617397388623613, 20.56310603695531, 100.11066175276234, 45.82068512516637, 43.46374465573219, 51.42444987450877, 60.69724675147765, 15.278374129726043, 60.62653033964096, 7.2671698658697075, 0.7196735987259496, 3.264192535031227, 8.799003977929393, 2.1603051885481808, 0.3666881381744339, 0.08816643152385951, 27.63053067268864, 84.56545368317636, 79.36201387836088, 88.73552153187414, 87.603713773912, 92.60821096358761, 87.90175899382561, 76.6576337814331, 75.71038922955914, 87.2377880157963, 87.96187323908653, 85.9884189790295, 85.60929052291378, 72.40158757855816, 65.05864389481084, 69.632598200152, 68.14429406196841, 73.16772845483595, 69.35214873283141, 66.14035514093214, 60.6135041482987, 62.17518798766598, 60.659768504481164, 65.0406402157199, 65.17870372341525, 70.78635554159843, 77.12751803859588, 78.0025831345589, 75.87581911394673, 72.21980925529235, 59.32104395281885, 55.77250311451574, 55.00005114463068, 54.49423013194915, 57.43492910938879, 65.474066042131, 63.72698353182886, 71.87750401035433, 66.13793111616566, 69.62529474689116, 68.55242452313824, 68.1608307746149, 66.21113823306176, 74.48386407667591, 37.435442170789166, 55.679597854614265, 68.93073712625812, 58.430305065647254, 75.38394604959797, 68.92685397978752, 72.92271367965206, 69.24668404363817, 73.22416351687524, 70.64187111393099, 70.83314941775414, 60.40639908083024, 52.628845014879786, 52.20435434772123, 52.24111872334635, 50.34200122279506, 52.77955424401068, 57.331464828983435, 65.14780721356793, 71.26351187306066, 68.36943810985935, 66.68536847637546, 69.08191311743953, 69.09419013607886, 67.87507041808098, 66.94489602119693, 65.13476533274498, 65.3402308494814, 65.08648487829393, 68.17129565823463, 68.31904349788543, 72.46765598174065, 73.14793617494645, 73.14207615390902, 62.81064725691273, 58.094507032825106, 61.875087445782086, 73.78530563846712, 78.2035889164094, 76.01635763722082, 78.75116748194542, 79.88226921327653, 76.99685604341569, 73.62309209762081, 72.48547923180365, 56.94523296048565, 16.71959315576861, 0.34115065850557824, 0.37104696395897097, 1.1461196287024407, 3.459263525662884, 5.501784105454722, 4.5191254538874475, 1.2771487332159475, 0.2855563626414345, 15.50724050691051, 31.18511784461237, 54.12473893934681, 44.32521873904813, 56.85189623986521, 60.902692656363214, 64.08086761351555, 1.3392210992113238, 0.31954560008260513, 0.16554081391903663, 0.022450229603677027, 0.0024025544342059163, 0.08139395380332586, 0.08899950617623907, 0.09587526020984496, 0.03438533554154058, 0.04403585237601111, 0.0430104436893617, 0.02307637433160938, 0.021784252134121714, 0.06305104714908427, 0.12055752528530937, 0.041627252789875197, 0.03869848333359246, 0.02764623818708764, 0.12129578889617998, 0.03144451169176929, 0.06249573682585071, 0.03120664713693963, 0.01030568671863406, 0.1068846638044042, 0.012292147918243804, 0.19093759387971895, 0.08520660486312644, 0.06174772091570401, 0.10829945200032766, 0.23316609162476756, 0.1222990423200592, 0.12802053933903096, 0.14428118454112163, 0.14920366717682731, 0.18656105614237248, 0.2602913957690039, 0.08299677061938471, 0.1707401607305773, 0.17792359865721197, 0.09193961373380116, 0.18599534617556682, 0.23798677649709488, 0.06755334971052024, 0.10244878489644298, 0.09726636096714966, 0.1501477479694351, 0.30139896898500385, 0.1234192850308553, 0.1740119383940774, 0.14010382966408808, 0.12917861913240727, 0.14819800823686585, 0.2999855061211894, 0.21878490524907268, 0.4949618082854056, 29.57541831078068, 124.85552234034385, 52.002634694499356, 58.98449282492361, 47.676460435313565, 97.60248645659416, 25.85517571818444, 60.55123259944301, 10.368439401349715, 4.665046449630491, 22.02175117308094, 10.357807816997653, 0.8156041091968937, 0.25797456202487795, 0.166955946854526, 27.87999733801811, 86.6043487671883, 84.45264631702055, 94.52637549369567, 92.47670958119055, 94.3671194199593, 93.14536386920561, 79.70161268788, 79.38856047968711, 90.22960724369173, 92.26733346139231, 89.67723554180515, 89.56988027018886, 74.93915711679767, 70.69363071072486, 72.47226084432295, 72.1297045676939, 76.56904312872118, 73.02708010519706, 70.04731039847098, 64.5971848887782, 63.96424770355225, 61.99800668224212, 66.87436396075834, 68.24910763771304, 75.23849671886813, 80.20897126966908, 81.0267540716356, 76.21616317379859, 74.66694462683894, 62.47437461729973, 57.6265682712678, 57.45170116424561, 56.291781779258486, 61.112135456454375, 66.6403632010183, 66.23628062586631, 73.07650196936824, 68.48884290264499, 68.80158132122409, 71.00156030347271, 71.49914433879238, 67.87384663858722, 78.98297171438895, 40.66603176055416, 55.24086113898985, 70.54952283059397, 62.75450637263637, 74.30488632571313, 71.28325708450811, 74.79031885823896, 69.56407439324164, 75.20605087280273, 71.48924427647745, 69.98969862538, 64.00288697211974, 55.63315306940387, 55.53068507102228, 55.36222711686165, 53.94897753192533, 55.0775924805672, 61.09615964274253, 67.821624202113, 71.66255028017106, 71.660659697748, 67.67495893662976, 71.68212290733092, 71.6599379816363, 69.9110786376461, 70.82979186888664, 69.08700435392319, 68.33280317244991, 67.89538829557358, 71.93924996160692, 71.98558099808233, 75.45991451509538, 74.18475981681578, 74.75141679086994, 65.71893176724835, 61.53797149658204, 62.78312398541359, 77.01086674967121, 79.60180405647525, 78.51112627214002, 80.14203210030833, 81.56182027632191, 80.69685136118244, 78.31263865194013, 75.60107277285668, 59.71016268576346, 16.65276577395778, 0.5743749728125911, 0.7114824640654749, 1.223704846155259, 5.040609961555851, 15.528280100514813, 8.841441081416223, 4.532159980266325, 1.1663317247744531, 18.396333840585527, 44.31766033172608, 64.28959654223534, 48.05549083217498, 70.46390533447266, 68.76127504533338, 80.82544234491165, 2.959923739394834, 0.7606940524232003, 0.6635473620507025, 0.1192977243373471, 0.2021379831938013, 0.27840137722030767, 0.16312420488365237, 0.18810089287017623, 0.3024963439712602, 0.1552078199963416, 0.25235253386199474, 0.13445589240760575, 0.25963844370938116, 0.2061632389743482, 0.3972607460473815, 0.11233837478944372, 0.21303713141429811, 0.12380835810495962, 0.2724834705793089, 0.13198651523599703, 0.14170104637742043, 0.1227949386943252, 0.13198375731946962, 0.18403492717733308, 0.1480040807397135], [0.055823727706146825, 0.04561371770837615, 0.06587585464360253, 0.030640680530679323, 0.13835056084057978, 0.0793221379600225, 0.043974266567778204, 0.0423685232958486, 0.07824767666358141, 0.0684981199822599, 0.06212753964768303, 0.05394597342538257, 0.023104118205787196, 0.05484628378443661, 0.017555362522421826, 0.060546755520326484, 0.06511711350251591, 0.043424341842652335, 0.03043046600425676, 0.0692674867628563, 0.06014044929836547, 0.05164634218559631, 0.13220371648428902, 0.015027388243094809, 0.008456410798845033, 0.03403642079642704, 0.060829411320869005, 0.08665101001820258, 0.17477848597111242, 0.13128965101655454, 0.06750614337262607, 41.64887574411208, 77.5486707687378, 50.09266399568128, 46.25007875504033, 66.2273846903155, 36.233882904052734, 26.118553069330034, 22.248654403994163, 0.6926958431159297, 0.466749670524751, 8.104081086574062, 8.882507316527828, 0.30045018441254095, 1.2597248294661123, 0.3719171479104027, 21.52131949701617, 74.72191272243377, 80.72457467356037, 95.34656663094798, 91.43829345703126, 87.70837829959008, 78.22502859177129, 83.6919104668402, 84.1991513775241, 86.91791088350358, 89.56551859455725, 80.18561747766311, 75.10612457029282, 61.97192292059622, 63.91572406215053, 70.22772373691683, 69.79834971889373, 64.61746746493925, 59.36975979035901, 56.36642448363766, 61.30369224855977, 62.56482055110317, 63.71421229454779, 70.08229009566769, 75.59693074995472, 76.27747766433224, 80.87910821360927, 74.60915242472004, 73.2186565091533, 60.23310876661732, 57.10265336498138, 52.206268464365316, 54.90911491455571, 54.338155100422526, 60.29741994796261, 64.89615971042265, 66.09670700565462, 67.16898887388169, 70.4683768364691, 61.33322377358714, 68.18662428086805, 64.16805405770579, 74.22547401920443, 28.077376888644313, 52.47607654140842, 64.27401296554073, 69.43993137728783, 73.98278128716254, 66.15682125091553, 72.17801247873615, 66.78054871097689, 71.5456558042957, 66.47504314299553, 66.60808209450015, 53.22031882501418, 49.615872444645056, 50.74661724029049, 48.468132019042976, 49.92556710397044, 54.02629137039185, 55.5682574549029, 66.07645188608478, 67.91848321114817, 63.59819250722086, 63.48042334279707, 63.45058587289626, 65.0723918022648, 62.653183706345104, 61.879425587192664, 60.94183006594258, 60.529847837263546, 60.48809420677924, 63.84953014312252, 64.37240562131329, 66.70768676265594, 69.49410715410787, 71.85713906441966, 63.99297906506447, 55.90660110596688, 54.676890988503736, 63.36078713017126, 72.43007183074951, 79.0877539111722, 76.34201634314753, 72.13533709126135, 76.26480056393531, 60.045705764524406, 39.95352145164244, 16.716437608964984, 0.06393042415560735, 0.25083427017013876, 0.05491127102305332, 0.8803655050935284, 4.998872510848507, 3.106626267394712, 2.970732565849058, 1.1727859848929991, 0.039493996695044546, 10.565972905005179, 53.32541873378139, 33.62019585024926, 18.694063309700258, 26.39627648938087, 64.36494527324554, 23.815062738233998, 0.2555957517676777, 0.05447909018144973, 0.07459657822525309, 0.058359015252321005, 0.017902388860802018, 0.06422665503416812, 0.019009232693802447, 0.029522293667879798, 0.038452492501105995, 0.07503426723903225, 0.013287081627265341, 0.05915426431343921, 0.03892120807581852, 0.02819570517467876, 0.0026485955412124075, 0.017433317055204706, 0.03708250129655485, 0.0231926569024161, 0.035192206156470125, 0.02724225895719663, 0.07778444627840674, 0.0668771468823956, 0.049602017407455755, 0.024325271933189323, 0.017370873228496602, 0.006320614164935486, 0.06895709857945481, 0.047786067269982836, 0.03574018118782871, 0.06936086521994683, 0.05027631267664894, 0.02127237708097504, 0.011143790738236521, 0.03653199817504614, 0.12046687410122926, 0.06532221056160427, 0.05002433486703423, 0.08419962825193521, 0.10918714106082918, 0.013444863180930336, 0.09541100326685176, 0.0574790062232604, 0.043748910313532244, 0.025994160002277746, 0.06092051066638482, 0.04403577959765831, 0.009718058018704817, 0.09047141388779686, 0.03960927377545065, 0.04988541631328483, 0.036383116647841475, 0.07245525522457977, 0.07738064133351849, 0.1419319299560401, 0.02557495669011147, 0.07474490050827304, 46.976368350367395, 90.63857709207844, 48.1865450643724, 46.112164297411525, 83.08318999505813, 26.398590687782537, 35.29585984445388, 25.88778434261199, 0.5980887648559386, 2.0773365180338583, 5.846092210661981, 5.8365343751445895, 3.5233361778720735, 3.615025748168269, 0.2992122782574546, 22.842187458469024, 81.13491735150738, 83.43674459765035, 97.2508930390881, 90.55084151606407, 90.33751949187248, 81.90821263097948, 85.58288512691375, 85.64779250852524, 89.10255339837845, 94.70623185557704, 83.00100065046742, 78.6673621208437, 65.81648503580402, 70.46003003274241, 73.74747045578496, 73.76492500305176, 68.59395457852271, 64.27111433398339, 61.238286725936405, 64.02796268463135, 64.94908817352788, 67.21882650929113, 71.8542443552325, 77.34539785692769, 77.78016121156755, 82.24974909136373, 79.66674281704812, 75.73322526870236, 62.791337428554414, 59.93666387373402, 55.49098676250827, 56.838834747191406, 55.83373915764594, 62.381983187890825, 64.72469329833984, 68.67547712018414, 68.27980410668158, 71.7404563965336, 65.75611975885207, 71.20098929251395, 67.86160884364959, 77.13674345324117, 30.93757510185242, 54.43357852197463, 67.50153526183098, 71.69794574860605, 76.69987770818895, 69.74335808907786, 76.53887225735572, 70.67266956452401, 77.07338148547758, 70.69035160926082, 69.60509454050373, 56.91365395822833, 52.13838400379304, 53.78014303022816, 51.363641369727354, 54.64023251687327, 55.999451452685946, 60.167224714832926, 69.10144652089765, 72.19393730163574, 68.66622032657747, 66.02740656945014, 67.47792259339364, 69.95214585335025, 68.15706529924947, 67.08974130692022, 67.29736804962158, 66.29594772092759, 66.88494651548325, 69.1795487557688, 68.23956843345397, 70.32665375740298, 73.8318798618932, 75.87706642766153, 67.95376885321834, 57.30747561300955, 59.30080844509987, 65.84554195404053, 77.14562369931129, 81.20759102606004, 80.16866499377836, 75.38856660166095, 79.30503752923782, 64.30506637019496, 43.493676262517134, 18.180030815062985, 0.3319040079030299, 0.3345945699801368, 0.47421121368965796, 3.153344883072761, 6.656741692173866, 3.2743026892985068, 3.116217443058568, 0.5882390191958797, 0.12019757121320694, 13.833888749922476, 60.757890516711825, 46.52075367589151, 26.963543391996815, 32.21490475439256, 76.09164361030825, 22.772800730120753, 0.32395627469785754, 0.014535987847334435, 0.05600556633585403, 0.020263372252004284, 0.028867008870527632, 0.03770198297476576, 0.04744274879715616, 0.014952118189314441, 0.028458429282651316, 0.023331037279398694, 0.08376079010626963, 0.060479761131348155, 0.0072683530273817245, 0.008788306900720683, 0.04381888478453602, 0.02164793636409506, 0.00976704168058331, 0.06236829426920703, 0.021221776973576318, 0.041136504526460366, 0.14081118928809322, 0.04686967672539815, 0.026344001713779666, 0.05489155575032196, 0.016223712103261102, 0.09902252560301174, 0.21359127345344714, 0.12518931585814685, 0.17269789842107605, 0.16755766295377286, 0.15244233452024, 0.13906708287615932, 0.134793660573421, 0.13686179153380856, 0.15289205877530962, 0.26448079354820714, 0.11518886538162348, 0.11014367078220653, 0.2058001899070317, 0.14391913138810666, 0.1729067493109934, 0.20373642564781252, 0.1268768236942349, 0.062113382342842326, 0.18843781833927478, 0.1191334444428644, 0.11712867661469406, 0.1652065084706391, 0.14597120514560133, 0.15686537379459028, 0.19004367652439302, 0.13495211819967917, 0.16408140110152383, 0.23558332885224975, 0.2739935524521336, 0.2012411853478801, 74.56419421780494, 96.05549581589239, 74.41088445724981, 68.401821198002, 87.64386315499583, 58.365695784168864, 38.76879699768559, 28.509935871247325, 0.7627689249573216, 5.170944929122925, 20.691593077874955, 16.698755564228183, 1.6316648067966586, 1.8894529030207667, 0.3491568595411316, 24.873471183161584, 86.14372130363219, 88.69186555185627, 102.07604377500473, 95.1514522490963, 92.39338274924987, 86.47069008119645, 89.6616715769614, 91.66792469639933, 90.26467323303224, 94.17641378218129, 85.21210347452472, 85.05181189506285, 68.70466739900651, 73.84779684005245, 79.02484693834859, 77.9363892155309, 74.20041791854366, 67.05443213062902, 63.46642440365207, 67.26383178464829, 68.26859397272911, 71.33632675293954, 75.80684031209638, 81.07147693634033, 79.00824746777936, 83.92550330008231, 83.02635485126127, 78.47012965909897, 63.63153265368555, 61.51723000311083, 56.507947521824995, 58.46579467096637, 58.24186655782885, 65.18372435723582, 68.9072342841856, 71.86194004551058, 71.94762029955464, 71.09419884220247, 68.08566247263263, 74.94003572771626, 71.27542018890381, 79.6459307209138, 34.54500444473759, 56.000133945095925, 72.47644209092664, 71.89877110142862, 78.13002094145745, 72.3991870880127, 78.37176445991763, 74.03044592949652, 78.73125753095074, 71.25427861367503, 72.60325231859761, 58.51396529905258, 55.25360884204988, 55.81885768521217, 52.93464868299423, 57.04430418629801, 58.46670073847617, 62.83698205024966, 74.15022726981871, 75.22676883205291, 71.12677804885372, 70.36849760240125, 69.02769811691778, 71.30531649435721, 70.97813590880364, 69.67306137084961, 71.46966380457725, 68.2818986523536, 70.80987407315162, 72.87033434837096, 71.29782476732808, 75.44802973347326, 77.83982046188848, 79.50017544531053, 71.6432757531443, 60.97841401253978, 61.09584977549892, 68.06215178581976, 77.56319138311571, 85.68756534207253, 80.49238604883995, 76.94121330015122, 83.42647583253923, 67.95875810807752, 46.513210958050145, 19.673543860835416, 0.6444309555715131, 0.4382776757401805, 0.416949849215246, 3.2958963176896496, 17.28112555319263, 9.84735252395753, 8.072145638927337, 2.492812352795755, 0.33204720505783636, 18.247015091680712, 76.14274424891319, 44.956488916950846, 30.901191196134015, 41.81928703861852, 85.26281187611242, 40.080547409672896, 0.3026934124289021, 0.12562255390108595, 0.42253867512749094, 0.14476388122045225, 0.13100054475568956, 0.18103770010413664, 0.11199801724644438, 0.12636058768557926, 0.13617775162621854, 0.18247960015170037, 0.14013324744038044, 0.25618317266625745, 0.13567340530214772, 0.19431838585484415, 0.15312995971931567, 0.10710653052815508, 0.07848737025333029, 0.12211878949235525, 0.08885755774474914, 0.1281957819517101, 0.2517236982502284, 0.12014592156535196, 0.1591773965065518, 0.12886263850715854, 0.1019108149733755], [0.0978978012778586, 0.045963134241080096, 0.03804541253034146, 0.048473351559932196, 0.05734902025470811, 0.03729043288096305, 0.08970850522840217, 0.07495847049980395, 0.006367843006662424, 0.013085805431699321, 0.03503126640533728, 0.026269131940939737, 0.006799968306891501, 0.044494945886394674, 0.033287749881105076, 0.06954241273624283, 0.019862980228818713, 0.004741288956269743, 0.025318955003674475, 0.077476731741861, 0.077500426841359, 0.05595557143791549, 0.03723792138419325, 0.10677394111670795, 0.11252121699433174, 0.10549143332267001, 0.022644582279627363, 0.12291364401819245, 0.08259639774839725, 0.10020694349922481, 0.11308201633754278, 2.6758090622963446, 64.7321379569269, 79.31711058462821, 42.64332602100988, 40.54305761091171, 66.26051302879088, 25.582739653125888, 24.542026981230705, 0.5435509655264117, 1.039344622723518, 7.665989600842999, 4.751583251260943, 5.317375342692099, 1.116849431587804, 0.9377037541520212, 0.11118220255499887, 44.12864915786251, 99.14836314416702, 96.18465946566675, 95.1532643841159, 94.33473633181666, 88.75100704931444, 85.0306938540551, 86.98918819427492, 92.24526620680287, 81.43219378686722, 82.56741400687926, 77.99320082510673, 67.1696242978496, 68.93043902612501, 69.21721919890373, 68.82464485783731, 65.33033863190683, 60.23084555902789, 61.20611152341289, 61.910443690515336, 65.96520562325755, 68.16329402308311, 70.72147953894832, 73.62070729655605, 76.38077720519036, 74.34238418456047, 75.54344531028502, 73.8720763114191, 64.99958868949645, 61.159702039534054, 56.263791745708836, 54.76750166185441, 55.599695251834014, 54.189363910305886, 56.60009968665339, 66.02317040966403, 65.75063628535118, 67.91384696960449, 58.27470856328165, 66.71150715120378, 63.52320855663669, 75.75042093953779, 24.633429973356186, 47.601955013890425, 77.38601007769185, 67.51351418033724, 68.59761022752332, 65.51350939658381, 69.16652648679673, 66.15720564319243, 70.38687782902872, 64.98333830987254, 62.80853309938985, 54.93175091282014, 52.04044242059031, 51.820479823697, 50.384539327313824, 54.428812842215265, 54.48962134699668, 58.642905373727125, 64.24130824304396, 66.94986174183508, 64.40917391930857, 58.78288692043674, 61.13141782822148, 62.44212096737277, 65.61205502479308, 63.37936739767752, 63.940709560148186, 59.64212917512464, 61.515139379808986, 61.48712188966813, 67.03158824674546, 63.52835470630277, 71.28338260035362, 68.1768262001776, 73.24328899383545, 60.44984325285881, 60.356588902012, 63.166563126348684, 72.28596395061862, 73.27109859835717, 79.72811222076416, 71.58957850548529, 67.45334502189391, 37.6270224971156, 13.163170314604237, 0.3985475286120369, 0.04249473628137381, 0.06989616915703782, 0.4901317158533681, 1.3769753830086802, 3.21726922065981, 1.7847191229943307, 3.7133546654255163, 0.21561017560382045, 0.13974104106666582, 20.87456380167315, 38.05094442059917, 25.40939246454547, 31.013882852369743, 53.31598935588714, 54.5947487123551, 1.4456805995395108, 0.26050491979525936, 0.08794661025486647, 0.03113027583176811, 0.02337680720243483, 0.02226070136642985, 0.09647287007781769, 0.024352828115825693, 0.0483004110414655, 0.02437190945079971, 0.04605810999149277, 0.07674636649748973, 0.03497873192592975, 0.04785271308895561, 0.040762458266990806, 0.09781457348576478, 0.08702612497032651, 0.0401578157118732, 0.023204640432771657, 0.10495714828251831, 0.0748463152276893, 0.037226089156202735, 0.0029340894581119143, 0.059554713793219104, 0.012396639438285943, 0.05644092261190376, 0.026063466061567588, 0.044411392506933024, 0.046939088121777585, 0.024301272313741427, 0.0466137727151715, 0.05289609205999202, 0.056801282710606055, 0.03421113097799882, 0.09461450931285659, 0.07449501028825199, 0.06449804551178409, 0.0347847699548208, 0.07252100855112076, 0.04456158787492783, 0.10006341692661086, 0.031718571985801386, 0.02105096617953912, 0.08346485034112008, 0.06014583489647316, 0.022773802160255374, 0.12238705816167979, 0.07947416044771671, 0.04897295579975171, 0.14579862085801942, 0.04536064822346934, 0.05287285278280897, 0.03303589464555825, 0.08216214846939811, 0.1256369716758209, 0.11804563023390309, 0.2201831689284694, 3.833654739202992, 77.3043384859639, 88.67281067755916, 36.540184713179066, 54.03592863390523, 75.92528020181965, 28.329697078274144, 34.5910216915992, 0.2764711114427736, 0.372767536149871, 2.5765826577140443, 7.609156908527498, 4.755159472265552, 2.8301435420590066, 1.8576674860331321, 0.11640299216754015, 47.812076384021395, 100.7920245201357, 99.33276161070793, 98.35787219385948, 97.26934386837868, 88.27431355753254, 88.88737217072519, 91.34990676756829, 93.44021627979895, 86.1242663475775, 87.56742400507774, 82.06942204506167, 71.81542073526691, 71.34635233109998, 72.95504969935264, 72.09013569739558, 69.97386793936454, 66.51234488333425, 64.94196514929494, 67.3998046690418, 71.77250216084143, 69.37820896025627, 72.05216715412756, 76.77026856330134, 80.02297247609785, 77.26844879888719, 78.67792114134758, 76.71142516597625, 67.71008768389302, 63.4977327623675, 58.05889975640082, 57.086438286689024, 58.73954473003265, 57.22798485909739, 61.970291214604536, 67.34902566479099, 68.70636186292096, 71.18267966854957, 62.72868933216218, 69.52083418446203, 65.97243062911495, 78.09829681150376, 25.90646855292782, 49.10204195207166, 80.49795581448464, 70.79346287635066, 70.79498475597751, 69.0948804732292, 73.782912992662, 70.14784074598744, 73.2824577823762, 69.90240235482493, 67.24183513272193, 56.84200402229064, 54.43707335379816, 55.06779439987675, 54.79210668994535, 55.57351735330398, 59.924143668143984, 60.18868792441584, 68.93210995581843, 70.32677927324849, 70.02121879208472, 64.51538778120472, 66.732954671306, 65.25318953298753, 69.57253102333316, 68.46263362515357, 71.35629946185698, 63.57062216727965, 68.78584477209276, 66.74000709287583, 73.53937302866291, 69.78538236310406, 76.74379256463821, 71.88325420502694, 78.918668377784, 64.0872924558578, 63.648030142630304, 65.47605468380836, 75.41365408128308, 76.10537975065171, 83.42574627168717, 73.53623513252505, 69.89907618491881, 36.72930179103729, 13.976535547164179, 0.7076764166835816, 0.49730134887560723, 0.18207118335750797, 3.1686536487071746, 1.9789556293718278, 3.0038927735820895, 0.8973987652890144, 1.254387709402269, 0.3586570239595829, 0.29923694628861647, 31.600210512838057, 47.087273366989635, 38.23655882189351, 28.387169607224006, 62.6162898925043, 57.63571131613947, 1.735338566284026, 0.13656168425035092, 0.04481758764614502, 0.0780267522279774, 0.015389541945149823, 0.1455989017361595, 0.03628428747516967, 0.055059562662556294, 0.04948549926461232, 0.041297593664738445, 0.06791996108668466, 0.07263482623403111, 0.025291697595328577, 0.041717869499998714, 0.05981124599554366, 0.18294365025095402, 0.08264505965334755, 0.021794621134176854, 0.060760248903064966, 0.012618820258085767, 0.03136874942649757, 0.038206742986315684, 0.07430295970651411, 0.029598331724804257, 0.008068758817840247, 0.04120144963024124, 0.12533573824311459, 0.10458970187051643, 0.1619430658437552, 0.08718331089063037, 0.11897118702050179, 0.1532397094753481, 0.25634094081338377, 0.1901068634563877, 0.15596102232173567, 0.11368489689043454, 0.16888731579867103, 0.1157306197790369, 0.13962621980857465, 0.08534578005633048, 0.2803203661835963, 0.1783878785828429, 0.15115026594890704, 0.2623412938367936, 0.23820627600915972, 0.1446102039828416, 0.30435959237717813, 0.1968527426041903, 0.21323300477477813, 0.2055033155146145, 0.11788967005427807, 0.16465760647289215, 0.20919999618443752, 0.27465968122405393, 0.222809165115318, 0.17947057532447, 0.5952408176756675, 8.018875929617113, 105.10279563165481, 94.93423923369377, 70.80693229552239, 56.31280960575227, 93.14605420635593, 40.17399003428798, 37.759378956210234, 0.6710920410771525, 2.7358049010076835, 15.232833450840367, 19.948923664708293, 12.508747366166885, 2.2846068153458257, 1.7132621186394847, 0.5551792609114801, 49.84449171250867, 106.04191303253175, 100.45795625255954, 103.2300913718439, 102.2725623653781, 95.128796638981, 90.3676119158345, 93.99274487649241, 97.7546351955783, 86.72143151683193, 89.74316273966144, 87.98771381378175, 74.85850534131451, 77.265075560539, 76.90268778031873, 77.71399082676058, 72.7069519412133, 68.69267279101958, 69.78497443660613, 70.31606335793772, 76.4830961535054, 74.12493582694762, 75.90551930089151, 79.41003937875071, 83.97725505213585, 78.51374641541513, 83.85710500901746, 79.01884571198495, 71.62159289083174, 65.24757269890078, 60.09989723082512, 59.339557540032175, 61.23414470303444, 58.25695199351157, 61.85333398080642, 69.90966658438407, 68.84977940590151, 71.847427275873, 64.56617855256604, 71.40304626957064, 68.50853320091002, 79.27727499315816, 29.865587411388276, 52.26529229071833, 80.8185625076294, 72.39532747576314, 73.56583333784535, 71.61778819176459, 76.01885226465042, 69.90548533778038, 75.94190320660992, 70.99132291732296, 68.58905161580732, 60.04436823629565, 57.17995543633738, 57.55008597527781, 56.68406586493216, 59.23474004191738, 61.798181533813484, 62.96944833570912, 70.88806260016658, 72.34641551971436, 73.28442681220271, 69.42963907795568, 68.63266837212348, 67.75841128441596, 72.28080995621221, 72.1705364411877, 76.50695200889342, 68.92296298857659, 72.41490794766334, 70.90301467526344, 77.49242398046678, 70.76311157595727, 79.92510934029856, 76.33457168456047, 82.57113241380262, 67.98404955094861, 68.25332810801845, 68.93227469536566, 79.81105466042796, 76.76532637688422, 86.51568751181327, 76.27200203557169, 75.05461600518997, 41.69360645355717, 16.837352514266968, 0.7148881232546223, 0.4755235529474674, 0.14345567883743396, 3.055089019959973, 8.715778147020648, 11.161734846330459, 6.857490068481815, 9.138179171469904, 1.6115441509792883, 0.5016900214456743, 32.55325821138198, 54.30914525062808, 37.18013509627312, 48.954305879531375, 69.99282083203717, 79.03485682702835, 4.796157065899142, 0.5002164972885963, 0.2027612723289959, 0.14481490267620933, 0.14623342172032402, 0.2895810515169175, 0.16092556318448437, 0.19015820666907296, 0.22483736757309208, 0.14095778787328353, 0.13242491671154577, 0.1457957556891826, 0.11876453480292713, 0.11604828579771904, 0.16612224401004855, 0.2591977592918181, 0.28659030554756043, 0.1460501275235607, 0.15325653276616527, 0.20004593496841772, 0.11122013156813, 0.08874394690557834, 0.16338856650456307, 0.17285077892724546, 0.09513590875412188, 0.12948912988987663], [0.04933555670563252, 0.03837546236031959, 0.03905404772188875, 0.0323031890025783, 0.06173521453034013, 0.05005701617788404, 0.06788560204328069, 0.021255775955655885, 0.052699674777085745, 0.058921178232037255, 0.04228008610586967, 0.09552054617914463, 0.03619916361546324, 0.04913059754237052, 0.055050940342968514, 0.021783687144277558, 0.024315059981158665, 0.06811491514165556, 0.0741656844113623, 0.021810385308438734, 0.028014981202901374, 0.08259278181339465, 0.040730589009340734, 0.1386832728260948, 0.05992522455691811, 0.19855191029848593, 0.030083430089777517, 0.16234327017539935, 0.009584979927768151, 0.3210050588653934, 0.16317495054775671, 0.9712107239230987, 18.22522436418841, 78.8257082047001, 69.8328116632277, 38.48437809175061, 56.407538767783876, 52.21494474718648, 25.243550731289773, 1.3935942202806475, 0.3639762788530319, 2.5744157933419753, 0.811780411149225, 8.093042556316622, 9.506997677587695, 0.8151174288603568, 0.12483521469778593, 0.7972615740952954, 41.49413431844404, 100.89585750333725, 91.16600251966908, 90.39585298107517, 92.69487181017476, 93.15149845615511, 89.11142579970821, 88.76747315929782, 90.35718625591647, 85.36907672882081, 80.74497099845641, 67.83759609345468, 68.09308359699865, 70.7336231970018, 68.70790727676885, 65.28474107865365, 63.69091733809441, 63.469676048524924, 67.47385901789512, 67.37585467676963, 71.20007930263397, 70.28834789030014, 80.18274630269697, 77.96110014761649, 77.06388150492023, 72.79657025491038, 77.65094264861077, 67.09452659853044, 66.64449737917992, 58.76911940113191, 55.697264209870376, 51.822876391872285, 56.903502864222375, 55.358014491296586, 60.67142971100346, 61.40289683495799, 69.53154225503245, 62.190916692056966, 71.634277835969, 62.92022651241672, 75.1318004054408, 19.73956519557584, 49.177692705585116, 77.52335579164567, 67.31668180035007, 72.71455349460726, 64.41395528854864, 65.04280536405503, 62.47444521996283, 64.45747790798065, 59.989815911939075, 59.75956493808378, 51.5842511576991, 52.68824931113951, 51.16059203301707, 52.09196275280368, 57.70454106792327, 57.91409761674943, 58.73636761019307, 63.15408606683055, 66.59535792566115, 64.14896780444731, 58.90932844531152, 57.757128284823516, 58.89507455210532, 61.16020802528628, 61.86596793513145, 63.39792020859257, 62.4979833633669, 61.33962508170836, 60.60815795775383, 64.40523978202575, 65.4385450578505, 65.30008931313792, 67.5965036884431, 69.04221873129569, 64.29549578697451, 57.53763244998071, 64.0752625465393, 70.74357032775879, 77.95681691938832, 72.13047335224768, 66.05597711378529, 50.793634691546046, 7.501559430553068, 0.7905437797307969, 0.11573915399851338, 0.2505574979248547, 0.3735909580944046, 1.7302065126357542, 3.639057129621506, 4.865028002569753, 1.456782010293776, 0.9169439971446992, 0.5644480667767987, 5.615507835342038, 36.2576916909987, 45.90490233513617, 26.26391218554589, 48.033360819662775, 59.12661990811748, 12.677736801485862, 0.386350029899228, 0.1738552887353205, 0.05052862756495034, 0.09193322456051266, 0.04155484215927221, 0.034434177477153084, 0.025825526813165318, 0.04511941862743228, 0.026530764373620192, 0.02354298124931032, 0.030764750385236357, 0.04881935517093347, 0.03855763040783425, 0.0204539806732247, 0.03651420961344435, 0.07039817125206033, 0.022111002040366014, 0.08810699842269383, 0.07035874070659762, 0.01443140248152157, 0.03298717528401363, 0.03852759976120245, 0.015486011567014842, 0.1295856110030605, 0.018434735698505275, 0.06108730715969878, 0.06996841890917671, 0.02979958876817217, 0.05618541313695812, 0.07137136338579078, 0.02439070733324174, 0.08364452094200157, 0.07441867728747668, 0.08047588935662663, 0.04680247166224065, 0.022986807161942128, 0.09579774743366627, 0.057299228370069503, 0.021398132328965494, 0.03345078105227121, 0.08831080079319016, 0.04745630089253668, 0.03539335786274845, 0.03040762317757453, 0.0343489540260165, 0.13528092313678036, 0.04789059230637166, 0.07637121324096957, 0.05797008773492229, 0.05101124763548855, 0.06222060400872462, 0.06523810942927677, 0.08068947466991602, 0.08602273365062091, 0.14827582744821427, 0.3405524051237491, 0.1891390186163687, 1.015856060529909, 21.62597421676882, 94.0917141206803, 66.99620062305083, 43.12988427377517, 76.89349374463482, 54.666014256015906, 34.5810902503229, 1.5570398756573278, 0.10546865752868115, 1.0023724227663011, 1.597074895135818, 3.1214415498318213, 7.539411773604732, 2.021194775739024, 0.052478440075872414, 1.199912974430669, 48.34478916660432, 101.56404895167198, 94.0529061901954, 91.84864397971862, 95.40355866955173, 96.0405594302762, 91.64277445885443, 87.6551752705728, 92.10016204464821, 90.43663778612691, 81.7165813138408, 73.66422991598807, 74.93011213118031, 75.80982131342735, 73.1827275983749, 69.48026903213994, 67.85166955763295, 70.06667121764153, 71.45584137209, 70.89258901534542, 75.87231251501268, 75.74526694513138, 81.47699509897541, 79.17068850609564, 79.1500803732103, 77.09312669692501, 79.4408142951227, 69.68867240413543, 67.97374940687611, 60.275764542241255, 57.590243201101984, 54.760382559991655, 59.67346499043127, 58.884170363026286, 63.115874336611846, 64.50164379612093, 72.9835496410247, 66.1155108482607, 76.96142135127899, 66.56644221275084, 79.28348802751111, 21.720854390052057, 49.960974339515936, 80.66537041817942, 69.78419780731201, 77.99074542137885, 67.84302465377316, 68.6612153822376, 66.48297417548396, 69.27107334136963, 63.67047002238613, 63.252600316078436, 55.115270768442464, 54.80560748807846, 54.54611132221838, 58.63401336054648, 60.3444609334392, 59.22739344258463, 62.369698324511134, 66.87276363372803, 69.24440122419789, 68.32404059748497, 65.61720509682932, 64.69684054774623, 62.229975654232895, 67.15329939319243, 66.64940034189533, 68.14540017035701, 68.83149331615817, 68.24797799510341, 67.37623906904652, 68.86648085809523, 71.42388189992597, 71.65799248603084, 74.27653543410763, 72.9175518405053, 68.19711269870882, 60.62429851101291, 66.81668158500426, 75.45716885597476, 83.01486230665638, 77.34761007370489, 72.46931122195336, 53.84231259745937, 8.399473313362368, 1.6852733108305162, 0.43621916684412193, 0.7873979162785315, 2.292821974523606, 2.927154542938356, 3.707786370669642, 1.9211067980335605, 0.8754692226648332, 1.6797539231277283, 0.7609635927984792, 12.219701044021114, 41.39237626906365, 57.329429118864006, 30.142836224648264, 45.12028709534676, 69.21065315123528, 12.442828013050942, 0.49071397331933825, 0.09338201173851568, 0.062383466640547405, 0.10381476563071051, 0.05132484189685314, 0.061979244177740436, 0.03515389409937686, 0.06584419222969203, 0.01595603523685807, 0.07743939261643157, 0.04591400502249599, 0.005960137716629693, 0.03681423262723031, 0.03834581475764994, 0.023431808484958547, 0.05312841971434894, 0.026302782353013757, 0.0252984851343377, 0.014261921807642908, 0.06514061708003283, 0.07478536527243353, 0.03910064501988311, 0.05664013611573366, 0.04824689596951489, 0.004897572329237817, 0.02600301980912205, 0.11651511679613784, 0.09117121222398936, 0.14867246181013125, 0.21245594647142196, 0.11026490419622391, 0.16301696789601158, 0.25854523624143294, 0.1510782383622662, 0.19150912611474916, 0.11340187336768835, 0.17273261752580443, 0.19318285968995866, 0.12918460993997513, 0.13734510108347864, 0.16103929659772306, 0.15340106291396005, 0.143102680843684, 0.17316579428170958, 0.20484955140179206, 0.28489562712850114, 0.1401201013715998, 0.22709106035049886, 0.14476034189424208, 0.29612065383022834, 0.2039209762287717, 0.3425766852113509, 0.36328603363325523, 0.21962421585715589, 0.35981783102596965, 0.549754622963167, 0.401522217378501, 1.3929000833342153, 41.48777223402455, 106.05697493399344, 90.81089465848862, 61.4179705035302, 74.89713284277147, 69.8057943774808, 43.36640319516582, 3.2568393166988128, 0.7090010746352134, 6.837945388209436, 6.53519626586668, 22.95514583587647, 19.428350617808682, 1.3063708812959733, 0.36636442006114994, 1.8589727772820381, 46.97776079177857, 103.28716970259144, 95.97511076158094, 94.75724620203819, 99.03421432741227, 101.49798839322983, 94.71869714798467, 87.75352478027345, 96.39742451329386, 94.46995612113707, 87.76969279012373, 75.00589232290946, 77.1519151810677, 80.67793769221153, 78.64083120899816, 74.29571582425025, 73.37570821085285, 72.21256071521391, 74.61731095467844, 74.25505653504403, 80.74999947701731, 78.76562533840057, 86.429638554973, 79.21716074789725, 81.20691637839042, 79.24866522512129, 84.41688214578937, 71.32846632311421, 71.75853852302798, 61.97335066333894, 61.29242720142488, 55.118781289746686, 64.50804510424214, 59.15431968627438, 65.29464506333875, 68.24895074290615, 74.82111730883199, 68.90700678671561, 80.81107862534063, 71.0123860451483, 80.51157428372292, 24.208374484892815, 52.73965589461788, 79.30701440380466, 74.912077073128, 80.80452826715286, 71.88598417466687, 70.15352818273729, 69.17025273846042, 71.32084123549923, 67.09476194074078, 66.0766323151127, 58.04854469914591, 57.80938210025911, 56.9416832154797, 58.56663096335627, 63.35990067451232, 62.27003089843258, 66.51956988919166, 70.78133490777785, 74.90276536633893, 72.68547304214971, 69.54418013172766, 67.85877689238518, 68.12952241589947, 70.05935207489999, 70.83575387154856, 72.94155674595987, 73.72175539693525, 73.93320252818447, 71.77742865777785, 73.2354050297891, 76.5803317100771, 73.18362974351453, 78.91686408750473, 76.23754793597807, 71.93797126893075, 62.44530985432287, 70.28710057658535, 77.69754825099822, 84.9453587685862, 79.18433050955497, 76.0345809690414, 55.56804172454342, 9.414339527007073, 1.1835086417775, 0.45542024136070286, 0.42481922694752294, 2.52777636051178, 9.000921710844963, 13.38249944871472, 11.3406684706288, 5.172980148946086, 5.103780223477272, 0.8771457294783286, 10.265543864619348, 52.33200396260908, 59.57577051654939, 41.340946151364236, 68.28485611946353, 80.24550422545403, 31.50149230034121, 1.184606415129477, 0.42701553973940115, 0.29075396277250787, 0.28693228719695923, 0.18270426309637486, 0.1948778445441877, 0.15257252350209222, 0.1298481799782284, 0.16616571183887222, 0.2674350737323684, 0.20428335113871485, 0.21357123259334795, 0.19830970394034542, 0.14611153713157102, 0.09930882798207384, 0.30461289168846223, 0.15575030217728308, 0.136608982518796, 0.11655249422596348, 0.2285600186235482, 0.11452294345344267, 0.15983851506344735, 0.08173511573864568, 0.21769113087606048, 0.2562058948340916, 0.22357977295835174], [0.1396574761958853, 0.024452082467295473, 0.06725974651353975, 0.11619410297322659, 0.07313389421230362, 0.04190115603588281, 0.07427941782460099, 0.09291754029090367, 0.016680633754379327, 0.0679212557752767, 0.08219741915743198, 0.0502335304965175, 0.08135276891651654, 0.026297645733481454, 0.006709451667003094, 0.04552797331745106, 0.06862910569555337, 0.12970939548986574, 0.05808734898305228, 0.04069877337784537, 0.06404365961169524, 0.08662104831948396, 0.11478525961959556, 0.08504017226157651, 0.11178546615185277, 0.10374868288636209, 0.16294579832784592, 0.11810468795198588, 0.2684188838447294, 0.1518270433429749, 0.17003149875710089, 0.11171539208941883, 0.44238770681042827, 48.65851602246685, 85.02561830705213, 50.1045056312315, 48.73240955414311, 85.48325692453693, 36.87677506477603, 5.667069352442219, 0.2897741669608701, 0.5613541134422826, 2.356522737010833, 1.9749720947396372, 2.0501628277763246, 1.358273889749281, 0.2757856466116444, 0.037460305217293, 0.2693327348078451, 50.50739580585111, 104.77790571028187, 105.02215170091199, 100.17121530348255, 90.35974364126884, 97.73656875856462, 95.23331211459254, 92.10395889897501, 82.3124050324963, 81.7068930595152, 76.81815285836497, 72.18306449151808, 64.32734543277373, 67.82753913633286, 66.39663496325093, 68.8386163403911, 67.37243436997937, 72.41675146164434, 71.68661009880805, 75.00067557058027, 72.7472189934023, 78.20213763944565, 76.49051727787142, 78.17603818831905, 76.77371240431263, 76.26876215780936, 66.24148953345515, 63.60484484703311, 60.205648253040934, 58.10593289713706, 53.29461243844802, 53.07251999455114, 50.87684777475173, 55.632694152093705, 55.91100200530022, 63.90117599118141, 60.43378506937335, 69.98314826719223, 63.17242314738613, 74.95720786433067, 25.78532026660058, 43.37086293005174, 75.80350629744991, 66.37845869987243, 71.32840356519146, 61.01783383277155, 63.17858911329701, 61.14646011783231, 62.36528565806728, 58.27934480482533, 55.7399788210469, 51.98691775721889, 53.65601178138487, 52.15958049220424, 55.49023366743519, 57.67144410840927, 59.50357144878757, 58.408084838621086, 63.49802694013042, 63.271459071866936, 61.19299903992684, 59.84568449758715, 57.294578859882975, 57.834912807710715, 58.88904586915047, 56.2176646724824, 58.693680455607755, 59.64491405794698, 60.934569758753625, 63.72677172383955, 68.40491202569777, 66.56151571581441, 68.75110041710639, 68.88658692759853, 73.18967803832024, 67.07773885419293, 61.04975408123386, 73.0994164559149, 74.84050166222357, 74.75105593281408, 75.05710278787922, 64.8925393627536, 29.045474721539406, 1.6129338957609671, 0.627734222479405, 0.3594810894179729, 1.1419526006906264, 1.7404467179890604, 3.728964718118791, 0.8437403736095276, 0.8444356750096045, 0.6624540013651694, 1.1772965880170947, 4.370794651969787, 20.055010049573838, 75.16807448479437, 32.08649812206146, 37.687760399233916, 62.35095723982781, 39.41182251899473, 0.42416060583726056, 0.0456679912073718, 0.03152567487690718, 0.08047140774226959, 0.07543293173394858, 0.04552612321511392, 0.07172282154281294, 0.05514298197663119, 0.08376714863604115, 0.07213415713199685, 0.07026284182023618, 0.03891001170080516, 0.11258558370172979, 0.04911859677503667, 0.0515307778222186, 0.006549595451478156, 0.05285782979861383, 0.022663657868941946, 0.0499569459427749, 0.05572472999413168, 0.06850468535577098, 0.03300833080204264, 0.041129529295909795, 0.15758970992699747, 0.1547420078948621, 0.03529237598300942, 0.09825798517633831, 0.0192552580002455, 0.06414899287084419, 0.07667447680667525, 0.10683014898771241, 0.012177603409415292, 0.0573874970207051, 0.0454592016044884, 0.05513732058687076, 0.07902519461969215, 0.029524986466933644, 0.07312748971725665, 0.021836872798420733, 0.04120379768972916, 0.04803247562038803, 0.04831790082877682, 0.0601461106881259, 0.04080647001824072, 0.048229149542748935, 0.04232500950174947, 0.06167993362572405, 0.0970795734094516, 0.0558241528849448, 0.045515160496917464, 0.08722327003676085, 0.1621250576910473, 0.06231995029074531, 0.2321629914184732, 0.11389313491001246, 0.15097477052721286, 0.10253244935865365, 0.13997169481890817, 0.11770638351839398, 0.2966017264031595, 56.36527915154734, 102.18575246872442, 39.52410820991763, 63.54298122467534, 92.35641048800562, 47.723101339032574, 7.429228963390474, 0.5879411029238856, 0.6337163885754924, 0.46330965995307893, 2.3898621480311117, 3.949822350855797, 4.534466333927647, 0.4213926382362843, 0.1818664999858987, 0.2691817848432449, 59.55678624491538, 107.27269003468176, 103.55029013849075, 99.97493990005987, 93.52559843370992, 99.94470627077165, 94.26189791771674, 92.11935027953118, 86.33772957709529, 85.82903738944762, 79.72363287402739, 76.54831732473066, 68.45319640251898, 74.22735675688713, 70.24488018405053, 73.47161016156598, 72.48747964059153, 77.37194445825394, 74.29328395474342, 78.28590377684563, 74.9107748462308, 82.3804973786877, 79.28745746612549, 79.75480002741661, 78.38741471690517, 77.49265932267713, 68.31334037165489, 68.47951550637522, 63.851785505971606, 61.48662374865625, 55.27560549397623, 57.43273258209229, 51.75198347337785, 59.584105553165564, 59.461892343336544, 67.29489695641303, 63.58733146421371, 73.53478385556129, 66.02262912258026, 78.85575356022005, 27.310110292127057, 48.8644600683643, 78.97882184674664, 72.24622249603271, 76.28741695034888, 66.04415509008592, 66.698241695281, 63.79180069892638, 66.81852509898525, 63.75966079773442, 59.03197703822967, 55.26153595216813, 54.864850967161125, 56.72822783070227, 58.59633115030105, 61.51174260723976, 62.26238619896674, 61.472071755316954, 66.2525349278604, 67.78754665005592, 67.6317108831098, 67.16140300996842, 64.52748437081614, 64.45410859200263, 64.77928092402797, 64.39654780972388, 65.6478701868365, 66.38121220373338, 67.74470652303388, 70.3170596399615, 73.09866336084181, 72.3185274677892, 73.67701684274982, 74.16031560590191, 77.18616531741235, 73.84690253965317, 64.21892719884073, 75.80032133287, 79.05595133381506, 81.59561541772659, 78.55064022925593, 73.69680127789898, 31.90082096284436, 2.144758138925799, 1.0322543257667174, 1.616120698951906, 1.6917835872980858, 1.5567839410035842, 2.8325508967522652, 0.7698465967851301, 1.272269549869722, 1.1028009725193824, 2.002001025022999, 8.57104366825473, 29.78843046772865, 76.99818964927428, 44.066295239233206, 28.192812242815574, 70.51142877148044, 41.550965539870724, 0.6350444786010251, 0.02107320188154136, 0.08652885729867606, 0.05802633774076259, 0.027810269102994955, 0.04122329079696248, 0.07487907314733153, 0.044002041085472995, 0.009647195843318778, 0.1264235218085589, 0.042138401974713614, 0.046341868958646254, 0.05666409551556553, 0.04632945450383329, 0.035954233814751914, 0.0845752181785722, 0.038631481283734885, 0.018466197014335665, 0.08785234313578376, 0.0067471235618746335, 0.07989380809087908, 0.05796140029786095, 0.009620546517262777, 0.040328791214814114, 0.07389514046090265, 0.03227956285099349, 0.07550210181263185, 0.21525160048998174, 0.11324449592540342, 0.1538196533557869, 0.23265373202100878, 0.1781653606843564, 0.16209047648214525, 0.2287243904485818, 0.1913023283404689, 0.128956897965362, 0.14592622046268758, 0.18870060181906148, 0.1287563208250269, 0.1855622613502126, 0.13364299651115172, 0.16271963385083985, 0.1425621292043117, 0.19556107239857798, 0.22018782674304901, 0.12608013055737943, 0.2590628358865938, 0.2999085908935916, 0.16892315339176886, 0.1583332748663041, 0.10774608370998215, 0.1706533936122733, 0.0848953280177328, 0.28560575999079213, 0.18714273138152016, 0.3554004761240175, 0.1629866001706931, 0.2412522262743404, 0.2866681400806673, 0.7580467589920568, 84.09969575943487, 105.40505347713348, 71.70298991664764, 67.49038788580125, 106.44160255309075, 56.07145047956898, 10.914560806366707, 0.789615219879535, 3.0876216484654337, 5.7828307536340535, 7.469290091145424, 8.04121333745218, 3.4516960478598073, 0.3160263453760455, 0.16871830148081626, 0.39203421843628733, 58.482645173226636, 108.27414174233715, 111.96888108407299, 104.0566759724771, 95.59777875100413, 101.35908942068778, 96.93766824660763, 96.49559359396659, 90.78616803692233, 89.22464893710229, 86.9512196510069, 82.12501771988408, 71.21445871168568, 80.41134203633955, 77.88194671753915, 78.01425610819172, 79.13775628612888, 81.40603942255821, 82.08216190338135, 83.47403064850839, 78.71920800978138, 86.99404408854824, 83.05624331197431, 82.04827262509255, 82.20153531720563, 79.82247660236975, 72.01410447397541, 68.56761978518578, 67.51791507967057, 63.75026279880155, 59.518582359437026, 59.11303674021075, 56.20432861389653, 62.06531063202889, 62.166456791662405, 69.3008598204582, 67.10747042009908, 77.05023165672057, 70.55960332193683, 79.23361116839995, 33.76235431240451, 47.760963978305945, 80.07155495305216, 75.93652955947384, 79.75034421490085, 69.11885399972239, 68.32090270134711, 67.5334555102933, 68.62109738011515, 66.81416342335363, 61.391376833761896, 58.248334546242994, 59.20937015164284, 60.352207614529526, 61.96502739383329, 64.74179875466132, 68.07595068408598, 65.83486526243149, 70.60285137545678, 71.4694441518476, 74.62567344788583, 72.74368101550688, 71.5346888572939, 70.56584773525115, 70.36796416005781, 66.48459803673529, 71.81808010224374, 72.38355252050584, 73.11479214699038, 76.45390587468302, 80.18269923425491, 76.89071670655282, 75.91999284682736, 78.40306497389271, 82.71427539087112, 75.49721625543411, 68.47917818254041, 79.97309561698668, 82.81852414531093, 81.44801662814233, 85.80636608985164, 74.81688899378624, 34.81647560673375, 3.2963417518523435, 1.5802096839874022, 1.021869360439239, 5.71630931669666, 9.240614810297567, 12.783751603095764, 5.07946103811264, 2.5614538308112853, 2.6403807440111717, 2.999358758811028, 6.103059918649736, 33.95682542554794, 95.00908590132191, 45.46139601738223, 57.134197065907145, 77.07183607162969, 65.00474268390288, 0.9857162616906628, 0.20313907624973407, 0.15485886694683185, 0.1480286568403244, 0.3070985712110996, 0.17644443609301122, 0.221154062798427, 0.12885050367443793, 0.100772638144272, 0.17186762765049937, 0.22719298068794513, 0.12985498283899602, 0.14330361038446426, 0.1683069888742701, 0.12194740030193522, 0.1435762457549572, 0.12198221899809376, 0.14188109236138483, 0.08438405625882649, 0.1219972036778927, 0.1184176961560884, 0.07656489558998616, 0.10298371345045106, 0.16040244770626869, 0.3340040081210675, 0.13166835892104334, 0.1762763564024241], [0.1411913987249136, 0.05626855665938028, 0.16629127364966179, 0.07317766081541777, 0.018708930057924122, 0.04058400574590891, 0.054367900180119666, 0.05454693492802401, 0.03970894564483916, 0.023648381541152636, 0.013924192903833765, 0.06624667950335049, 0.06355969505684991, 0.0666522311287061, 0.03238501868421032, 0.11967917483660484, 0.0973646960131103, 0.08654868365415642, 0.10334137691965989, 0.13603915099895772, 0.19117115876607357, 0.15945010848583716, 0.2823845134867776, 0.08255711275964014, 0.14236107708946352, 0.1043376129781527, 0.17843997256169397, 0.21198395970127276, 0.1674519274984637, 0.09022208291196054, 0.21440680469236068, 0.32380710205724167, 0.5366499229304252, 4.293507289501929, 62.32224941253663, 77.91229801793253, 35.88215612596081, 66.17099669671828, 81.50389471361714, 14.994422966434112, 0.6753689567408254, 0.13457829793614728, 0.4854870473425235, 0.23156702097865844, 7.026191699889399, 5.536262719861923, 0.6823896316270675, 0.204406691294524, 0.07062903950892149, 0.8399145305156709, 22.4418919317184, 52.53353926443285, 58.780753151063, 53.33099634416642, 46.0785456626646, 67.13698233327558, 90.21630256406723, 87.73878451316588, 81.34703128568589, 78.69881952962568, 69.77475273993709, 72.95224912704961, 71.9880913149926, 70.37199635659495, 72.505153840588, 71.68648458296254, 76.35158692636799, 75.09320428294521, 73.37064050859021, 78.83710661242085, 82.41904643274124, 78.70724478075581, 77.70360439054429, 78.16345522480627, 74.54910878212222, 68.56202648532006, 65.12082130678239, 60.47479344952492, 56.96492325875067, 55.120397306257686, 53.512802124023445, 52.80819146863876, 54.54331074991534, 55.19599314658873, 65.25775124949794, 65.37253941259077, 71.85252635709702, 61.32951321140413, 72.3590612411499, 30.62932779712062, 33.908411610511045, 73.38050134720342, 65.03234048043528, 72.93352373184698, 64.59455690076275, 68.67847381099578, 59.804782021430235, 63.42348621737573, 58.69784601273076, 56.678884413934526, 51.42379876106016, 54.461631313447036, 50.97613473092356, 57.47905185145717, 57.58731319058327, 60.237913670078406, 54.9535200672765, 62.71816169061969, 60.937154600697184, 62.02127025973413, 55.31379761234407, 55.65525562532487, 53.35643683710406, 55.921384519146336, 52.81106656597507, 56.72672164055609, 57.99650661406979, 63.13412120265346, 66.46142467375725, 69.88304153565439, 66.86612698339647, 69.66199244222334, 70.69716084387996, 70.59819944443242, 65.69005527803975, 60.99954382065804, 72.62616680514428, 78.51834343325707, 81.75412624113022, 67.56640341974074, 49.641242334919596, 11.117188488283466, 0.271553838204953, 0.7691186293959619, 0.9388504958441182, 2.5189547048461054, 2.686859359664302, 2.111896276473999, 1.4723293050642938, 0.289464391647808, 1.235994980219872, 5.248120013744601, 19.994734987135857, 72.3249444653911, 47.88047075271607, 31.961633389995946, 61.60559708072294, 57.05412580120949, 7.933498678668854, 0.5446367266197358, 0.2341208823265568, 0.0488807647789438, 0.033015217932481924, 0.07846200508215735, 0.10303639731700383, 0.031171723103691495, 0.11301312205051223, 0.046733558223012, 0.012088130085518765, 0.014690706006912215, 0.057109510526061065, 0.07220397838541577, 0.11485179435581931, 0.04208387183626333, 0.03028397467137585, 0.026771997800096873, 0.0924572823268752, 0.06243810403130709, 0.12728377726049195, 0.0699155128771259, 0.10283282477288477, 0.05818747667475574, 0.08912418698591572, 0.11396627332414351, 0.11935580146288681, 0.08208401516200074, 0.10124062593545645, 0.03099444078191394, 0.09247817354457033, 0.017411464397164605, 0.05172909117273746, 0.07720546766875253, 0.012969583190316636, 0.10303524052423817, 0.03305115894744954, 0.020663724055573828, 0.09459223913689775, 0.07294591921832293, 0.050113151270535686, 0.03637808728061857, 0.04220104881472165, 0.05149562970825261, 0.09154669489831695, 0.021791131603681756, 0.09197393447280892, 0.18453081589071982, 0.12208066895724305, 0.06636830362220926, 0.20910607380492074, 0.005551342666524673, 0.084422375976799, 0.11362399290045423, 0.12433462986542333, 0.18042230167456214, 0.17538269951699242, 0.09860938204632652, 0.26129659505621083, 0.24796904004629583, 0.35622469479999236, 6.0379176851241825, 77.23770526147659, 81.77635039052656, 34.307944236263154, 100.12530788298577, 77.81843569970901, 28.773699575854888, 0.22921847119446725, 0.30473417872863434, 0.154930021193239, 0.5238902076117454, 4.248874149014873, 4.107524430559528, 2.1399892722406695, 0.42605370102870854, 0.05623661845381703, 1.7619812656794827, 30.753086420797533, 62.592657612216094, 70.93737463797294, 62.20377422148182, 55.524777981542776, 73.38407070406022, 93.9787341702369, 89.44427813253095, 84.90411112385412, 80.09994506835938, 76.4036524680353, 77.93656964455882, 75.20156368132561, 73.72860385525611, 75.03294883235809, 77.72256512795725, 77.98039036412393, 75.89329719543457, 76.78869585837089, 80.5335787803896, 83.49497610522856, 80.9851691030687, 80.30302186166087, 81.8094002815985, 78.58039532938312, 73.42247855278754, 68.6275928251205, 63.40326639913744, 60.305092104019664, 57.7339078534034, 56.288428152761156, 56.14373191710442, 58.0113253285808, 58.305491324393984, 69.57555124836584, 70.37576183196038, 78.38681067189863, 67.36199302058067, 78.26904542984502, 33.70400905609131, 37.689674515878, 78.13823438459828, 68.89833834863478, 78.86125272320163, 68.8301597102996, 73.36446669793898, 63.84616474951468, 69.51245600177397, 61.83996262088899, 61.28280954976236, 53.08131787084764, 58.36265594728532, 54.002917966535016, 60.093382173968905, 60.520418459369296, 64.64822276946038, 58.63071464723157, 67.77055494246945, 67.5992650370444, 68.18842072640696, 63.075568060721125, 64.36486290347192, 62.171751991395034, 65.6469758864372, 59.64916590721377, 66.0179458125945, 66.25081692972492, 72.25253751201015, 71.41675103095271, 74.71675872802734, 70.00262675746795, 73.3938923189717, 74.02643726718041, 76.6282787630635, 68.97772712092247, 66.77941906836726, 77.0280388862856, 82.5590358241912, 85.99233350446148, 74.51047343592491, 55.68117072505336, 12.982531439873481, 0.22646930339115284, 3.2556407874630344, 1.4312954295066096, 1.2298645607886778, 1.4381226825137294, 0.612110686638663, 0.7664869641584735, 1.2161643346471172, 2.142527290890294, 9.464057530126265, 27.450389938969767, 67.30089818277668, 73.20812886761081, 31.069490294302668, 63.2575503472359, 68.81781208899714, 8.25257956981659, 0.5224104321772053, 0.2694444610707222, 0.12892680603169626, 0.022218620156749122, 0.060313121686058666, 0.044996434702507915, 0.09533542103224224, 0.08299559084398132, 0.048201520581759756, 0.02632824903083665, 0.029229092667059555, 0.007766928794162889, 0.05654460112113626, 0.11882517066213394, 0.09772989012661482, 0.0794292523735954, 0.09747894270525825, 0.05106557093019928, 0.07506208389156288, 0.01778880483470857, 0.08997577032254589, 0.03767641095985328, 0.03818143527173708, 0.034126367179616805, 0.04996824573965804, 0.06321636126226475, 0.04864454539793153, 0.22686245971389357, 0.1394435844474262, 0.20741871918641752, 0.27639888467327245, 0.09061212891772871, 0.1673982400567301, 0.14899875397884077, 0.2775606416886853, 0.16459680973522126, 0.2542582235389179, 0.1436353570991947, 0.2041728659382751, 0.13080047323338448, 0.18860421263642851, 0.19354388628515506, 0.15696779975006658, 0.2616078106145705, 0.2469809245198004, 0.1265242853532395, 0.2309021332691754, 0.2011162976944639, 0.2677042770289606, 0.33055311910087065, 0.1425880995849448, 0.22175344999038407, 0.21916208097771292, 0.30029249287420706, 0.3215899210303061, 0.2010717879860632, 0.3283392782172849, 0.35555724835684227, 0.5080450272127506, 1.063542337186875, 17.190410937032393, 100.31384837242865, 99.79273796081544, 61.13152373221613, 86.35329354193904, 103.82300469183154, 28.80263097824589, 1.077810448984946, 0.4555369625168462, 2.0840261203627435, 1.6873491026701468, 14.339738199787757, 15.564890523110668, 1.585538836736833, 0.1702497265632114, 0.26218694244180957, 1.7376459005378908, 27.90931509387109, 56.74598440047234, 66.96351943477508, 62.11716828807708, 53.17818080225299, 70.08181941124701, 94.47631820555657, 94.42739840476744, 88.84180207406321, 87.67255137043615, 79.3223665606591, 84.05023467156195, 81.97220217797064, 79.86283779144287, 83.19937059956213, 82.82956169497582, 86.61996764521446, 82.5474883664039, 81.98737390579717, 86.05200059952276, 87.43247093692904, 83.95350117837229, 85.31865073788552, 85.66383500253, 82.15143096062445, 73.61082292372181, 69.48347753094089, 67.08874502489644, 61.68526826366302, 60.6214665597485, 58.31495208124961, 59.71912922397737, 60.65350447931598, 62.99355914515834, 72.27180419429656, 75.61292617551743, 80.98738916458623, 70.6676253964824, 77.85283488612022, 38.77971687624532, 41.7495394522144, 77.76152995324905, 70.91355800628662, 80.85089852732997, 71.32799563869354, 76.26722458870181, 66.43696477336269, 72.19477668885263, 64.37795577510711, 63.38533332270961, 54.936912751966915, 61.09048789547336, 57.88373062687536, 64.53903575097361, 64.45329273900678, 67.55084729963734, 62.45530405352193, 71.52631851934618, 71.10791929306524, 76.0788566835465, 70.60804459356493, 71.85833146495204, 69.53533910935926, 73.51698413971933, 66.80000366703158, 70.44176747722011, 71.10848411437004, 79.71236782689249, 79.72411924792875, 78.60849518929759, 74.37491632276966, 78.19760337952646, 79.66592696405228, 82.44288659864857, 74.84708339937272, 69.82594751542615, 80.43748071116786, 85.45987175356957, 88.19026500948014, 76.48628896282565, 57.354092982507524, 14.769160266845459, 0.37174103961836913, 3.3172345017233207, 4.246741850529948, 7.7801227281170515, 10.210203143858141, 5.293968598688803, 2.5432608973595405, 1.4685328184596955, 2.537504328835395, 8.03374122227392, 36.05493260968116, 91.98930017409786, 65.00719808763074, 48.919294803373276, 82.4205526228874, 80.478069397711, 18.14152882945153, 1.2937670801916432, 0.5126186946947728, 0.24666750262821877, 0.2556588314473629, 0.2969968439109864, 0.19342477493468793, 0.20250141530507998, 0.2846682522325747, 0.1659977087570775, 0.1449859394661842, 0.16319330601442247, 0.14290385038381623, 0.1324888697314647, 0.22608791417892904, 0.21516798965392575, 0.2365940133289945, 0.12025938684781713, 0.2015137594313391, 0.169618807192291, 0.13562736341789847, 0.17837589696770717, 0.13428510076576664, 0.14687376397271312, 0.2001737184341877, 0.21525371489265274, 0.19356772694135868, 0.20632439323009985], [0.04559446208839936, 0.03578098303067588, 0.13834892141242183, 0.1555703481238696, 0.0408871658897448, 0.0757852785529629, 0.020156696423768036, 0.061564484175534985, 0.017327535634620056, 0.02033792984401507, 0.06692014739758546, 0.01601912066220276, 0.04083776087950795, 0.03416885058545778, 0.08971340053023831, 0.06732537726601286, 0.09530149099807586, 0.05428007203004053, 0.024949694878511855, 0.10864241424226954, 0.09567308194574811, 0.1727862130369871, 0.16687115624306664, 0.28616589283750904, 0.20079415772230397, 0.17165031914989795, 0.14490945324782403, 0.2856470061646354, 0.04441905721661545, 0.14123031599146707, 0.1738250742275869, 0.12845021507312215, 0.018388015826443033, 0.7403756846343318, 26.621438187937585, 82.43222559652021, 63.2290151042323, 24.177068087362475, 84.57724432791434, 71.24826954257104, 12.988050214705929, 0.1404149226483799, 0.03612054384223396, 0.8594570044548282, 1.294617866796832, 2.198415182290539, 4.3999618868674, 1.4880287142530566, 0.20499987317429436, 0.08852958018260618, 0.35014624677358136, 0.37957208231091505, 2.4988871236001295, 3.095968697340258, 6.151821844039425, 11.112723850434827, 43.294513994647616, 84.11545584278723, 76.62842781313005, 79.21642334230485, 71.46079924798781, 69.85179593486171, 75.15691141928397, 78.80443326888546, 80.83254967966388, 77.83533327041134, 76.48934841156006, 75.76960132968041, 74.32401964741369, 75.02371557297246, 81.02586761597665, 74.24903177445935, 78.2091586820541, 74.97911822411322, 76.32394990613385, 69.07157374966529, 64.98782157897949, 60.54974209877753, 58.09009436638125, 53.807874187346435, 52.79701663601784, 47.562303773818485, 51.11590446964387, 52.896840956903276, 65.4497669589135, 63.65700060321439, 70.69825126278785, 60.19304567767728, 72.20035429923766, 28.842260645281886, 31.883223249066262, 68.9932518620645, 65.18687009811401, 74.02839845226657, 65.36019963602867, 68.14753393973074, 61.058081273109686, 64.28630959603095, 58.41266224461218, 55.065833214790594, 55.791506998000614, 55.965687690242646, 55.41361408848917, 58.16408203494165, 54.26253180350027, 60.67244168250792, 57.29788541793824, 60.579591335788855, 60.42002539480887, 57.80138830984793, 54.65618087399391, 52.22033016143307, 53.21237602541524, 54.55438360091179, 52.84555204453007, 54.86438420511062, 56.05074036505915, 60.716046671713556, 67.35439146718672, 74.4480763712237, 75.84387533126339, 74.88959404730028, 78.46189268173711, 80.92570597125639, 74.03775722749772, 78.51270306494929, 77.2647931498866, 82.9853190145185, 72.377637586286, 76.9629196966848, 28.02866497347432, 1.8511043801423044, 11.215333054142615, 0.898590736812161, 4.92223528123671, 1.151897647688466, 0.3442453779280186, 0.4075561710182698, 0.7218369084500498, 1.2443021925226336, 10.9447189300291, 23.51335402457945, 72.12691184013121, 54.665947575722974, 14.687378848752669, 53.689104818528705, 58.80853529899352, 39.72128575847995, 0.1384010307130314, 0.023601563992880048, 0.015675783037177978, 0.02436832990497351, 0.12608836600256543, 0.12491182349021397, 0.10915206955565561, 0.057789275663033615, 0.07775614699048382, 0.04081816051996524, 0.05282003485086945, 0.051538940489051804, 0.08277896416163252, 0.015213636666416161, 0.0718806509769732, 0.020158797419900377, 0.008221260110487141, 0.08962467222684815, 0.0768202786604243, 0.1407588195175894, 0.09291391669502182, 0.08015833059025389, 0.06195071506344023, 0.03581207853952243, 0.12008936895478158, 0.15136178282480087, 0.08160954626697688, 0.08105213303239116, 0.028974550378118313, 0.044410959667255806, 0.1820442323843318, 0.08586843588179158, 0.030514618847519163, 0.015588446140980289, 0.0204785184694394, 0.06265265461538108, 0.04032586858938298, 0.04719361317374053, 0.03192753587368756, 0.04116232168950862, 0.0345412957211656, 0.12305121808763474, 0.04184303294506766, 0.05176454189143354, 0.040666865815799084, 0.04392761181318953, 0.0712539067852401, 0.07982214822644189, 0.07930628760086914, 0.11967801804383917, 0.09908555931742154, 0.20232705369351373, 0.20367048079929045, 0.1856736964996784, 0.06048991562678449, 0.11944502006254851, 0.06687077303086558, 0.024250683697661566, 0.12255929770969576, 0.2215381333183858, 0.06104467436671258, 0.7212767449598159, 34.555018255787516, 101.1517450886388, 52.24469200257332, 30.671024553237427, 120.75961082212388, 66.44351513155046, 21.567834884889667, 0.22333318457728435, 0.10177402997449522, 0.5030784485561233, 0.2162592665803048, 1.08121543401672, 3.158157631274193, 1.3789109501146501, 0.22999542224551403, 0.24123878909214852, 0.18018763362159654, 1.0166086653067221, 3.9881669513640867, 5.749318513178057, 8.891734692358202, 16.62106321704003, 51.3097519259299, 86.08278336063509, 83.53292111427554, 83.54331539523217, 77.57862198737361, 77.22090967239873, 80.51932488718342, 81.8008416698825, 81.59494077005695, 78.45164745084702, 80.80677970763176, 80.6696536464076, 77.23140593497985, 79.7681203965218, 83.55619645887806, 77.5603594318513, 80.31526750133884, 80.22073053544568, 78.18150597233927, 72.04305941058745, 69.2103393616215, 63.801634080948375, 61.013954608671135, 56.41350469281597, 55.446836563848684, 50.37773793743503, 56.005621340967, 59.458326908849905, 72.12239326969271, 69.22600530808973, 74.1313998929916, 65.13594204379667, 78.24820195474933, 32.12498049582205, 35.31673077614077, 75.68104205592986, 68.2371836323892, 78.79337218499954, 70.01754745360344, 73.79306408666795, 65.19433044618177, 68.17359416715561, 63.63552170415079, 59.819647804383315, 57.639108088708696, 58.61799440076275, 58.562108470547585, 62.97080547578874, 58.56011198412988, 65.36230987118137, 62.35001979335662, 64.30274040468278, 65.474407288336, 66.12166112469089, 62.746724390214496, 63.82500356243503, 63.971288358011556, 65.06688479454287, 62.77791507782475, 65.49660005877095, 65.31081699555921, 66.881071213753, 70.54490227853098, 79.06709870984479, 75.85635631315171, 77.63196622171711, 80.935394225582, 83.70599962049916, 80.05772467582457, 82.87349224090576, 83.04747289226901, 87.25545437105241, 74.59742453790481, 84.45286596975019, 30.723802005091024, 3.23521381905002, 14.26106624064907, 2.460612145162398, 3.6264736758124445, 1.624719147239962, 0.6062519526289356, 0.3186277654622832, 1.200263168542616, 1.591622678022231, 16.542358898347427, 36.45464174209103, 69.38410036025509, 88.75997358752836, 21.197741608465872, 49.59082026635447, 69.2015689419162, 42.39955463717061, 0.13483862993457627, 0.06115841161039087, 0.0787699724277181, 0.05702095842289348, 0.09648155751487902, 0.14234062254188523, 0.1285819285699437, 0.02448583821645908, 0.08738875268928467, 0.018835378615486047, 0.05906363228155721, 0.04162962383200084, 0.08366440092363665, 0.09535408293407771, 0.07525810280874853, 0.08621443949279287, 0.005778891368648939, 0.04191090067427966, 0.019399757504523284, 0.046263099798271735, 0.08090567234302722, 0.019951915375948436, 0.03615959134373454, 0.0679191260508472, 0.06441300209130972, 0.0955454746802007, 0.07102554363589134, 0.09062728213687098, 0.10587464582415358, 0.12170384562904797, 0.19952568465903883, 0.17624755149647114, 0.08963517529229004, 0.15760153832454837, 0.15820405115523647, 0.12022588582288836, 0.13354699037248088, 0.1135890669519863, 0.15180240595533004, 0.17921223515464416, 0.07817790137543794, 0.23368326226069083, 0.21016223326085076, 0.1487604240255971, 0.20230160425266913, 0.24022899327739594, 0.1562658180632899, 0.1196656916891375, 0.18558349730747362, 0.21954293392838972, 0.18335088726974305, 0.2771899164203675, 0.21648271910605893, 0.3002227175860636, 0.21231284124716637, 0.48484414635646733, 0.2110301495920266, 0.22942588183908696, 0.24465604685246947, 0.39416382029171915, 0.3352077773982479, 1.0497075247187768, 59.754328573903734, 110.27643326790103, 85.77065683180287, 42.51903395498953, 102.07376880030479, 90.65960099620204, 24.37201576848184, 0.41458726470028207, 0.38800260412596893, 3.4455854854276105, 4.275609514405651, 10.17878201700026, 13.652450692269111, 2.8957905355961095, 0.31633002262923027, 0.3325772766144045, 0.34279020923760634, 0.8141429650206721, 4.126506986156587, 3.959108562238755, 8.804364877362406, 15.258348468811283, 48.934713640520656, 88.61227281631963, 87.20018033058413, 90.2840183627221, 87.45820952999978, 81.05734855897965, 86.41285081063548, 88.82187643358785, 87.54054007991668, 84.90540550601098, 88.93414251265988, 89.72537871330016, 84.71221308554374, 87.61466503143312, 88.18272621400895, 78.752046092864, 84.90706859096404, 84.08591255064934, 84.87928252066337, 76.69119358062744, 72.19257231681578, 68.42282156790456, 63.7364835123862, 60.46001003634546, 57.60876071068549, 53.408278803671564, 57.83615619905534, 61.53703797248102, 74.52198951475083, 73.11909890943959, 78.3376084604571, 69.25231656720563, 80.23170532718783, 37.25152223340927, 43.47659041804653, 80.58707206479966, 72.84578815583261, 80.99484951265397, 73.4091660284227, 75.2708641175301, 67.6981479890885, 70.96038326140373, 65.52948913266583, 62.31508716460198, 61.25815745322936, 62.84596820031444, 62.05690891511979, 66.07156461285007, 60.30142861027872, 68.89111334277739, 67.64120301892682, 70.2172274743357, 72.12811993014428, 69.59619076021256, 70.96659629575669, 72.57798440994756, 73.21354958318895, 75.3927949167067, 71.96574949449109, 74.08373525065761, 73.19883285030242, 73.05347765645674, 77.67360610346641, 84.89749016300325, 80.97923847936815, 80.9501580269106, 86.55009454296481, 90.77568746382191, 84.35520679719987, 89.47128757353752, 86.54929437944966, 89.82974513884514, 78.98662736338954, 85.03416907402777, 33.842123554598906, 3.8758751317378017, 16.74215659018486, 5.242335498332977, 12.456079740678112, 7.205285160772263, 4.632732493262138, 0.9947053535330681, 1.7589444931476348, 1.8194014555023563, 15.905719976271353, 39.945394300645404, 91.46942138671876, 70.69206960739629, 27.009741067886356, 74.3715117054601, 75.94056175601098, 66.3594901177191, 0.41726317917627676, 0.14194581146922805, 0.16703097750583004, 0.1591582289866863, 0.27416625931378336, 0.20728877535270107, 0.22491875675416764, 0.2299891556462934, 0.16605476698567792, 0.09560473924202305, 0.2816979148455205, 0.1740483275704807, 0.14969192565448824, 0.1321418931887996, 0.22559035539386735, 0.14122594929029866, 0.21610992540034557, 0.12726735233539535, 0.11204988139891818, 0.1947994584277753, 0.09235142429749812, 0.12335327123442005, 0.1098188111979154, 0.2110753181360422, 0.1394111942499876, 0.1847790436999452, 0.15293431618521292, 0.15544418876449909], [0.09352724668720076, 0.09730723175791003, 0.018282228660198952, 0.08938736883142302, 0.04612231198998709, 0.03843712860778455, 0.1839011835475122, 0.0717214196019115, 0.057415110659935785, 0.09893123090507523, 0.04619271930066809, 0.04820273100068012, 0.03550292375767904, 0.03571046846768549, 0.04295417836176292, 0.05462801767392986, 0.03112906541284775, 0.056382297733498205, 0.05778899221050163, 0.07633022753702057, 0.16360929175730676, 0.08091327193523608, 0.0790255623418958, 0.1323870872898448, 0.2643136638066461, 0.2612150220140334, 0.1664157169720819, 0.11947283671507913, 0.051670232637514996, 0.1160204461625507, 0.1211086949033122, 0.09179607950030796, 0.10569010290407366, 0.30439091005152275, 2.2561014804147907, 73.29956716106784, 82.0228321321549, 68.81530177208685, 30.399243523997647, 91.4352418530372, 74.37912110359439, 11.018489887637477, 0.036938120535905325, 0.3302815562534717, 1.250801682472229, 1.4747989273840383, 1.0859123497240006, 3.2184527958593065, 0.954326268646025, 0.5191445687124806, 0.166371958029847, 0.45608361221609584, 5.870804123340115, 0.5118459877708267, 0.08769878847224098, 0.23883377862793786, 2.4626162311723157, 33.4645365899609, 82.54700199250253, 67.73496335552585, 64.72366171498453, 82.8025051855272, 98.43104008705386, 89.74739889944755, 88.84748951081308, 81.81307946482013, 79.86430475788733, 80.07630886570101, 86.5456622646701, 75.00188366059335, 75.91889458317911, 76.94169182931223, 74.54331151900753, 70.51953238825645, 70.6262130122031, 66.08361413401943, 66.3087111134683, 62.11371267995527, 61.372800488625806, 57.934391960020996, 58.708475635897734, 55.23814293646044, 52.59406928093203, 51.921300426606216, 64.21099224398213, 70.58381219064036, 71.15991423206945, 65.90648774177798, 67.77492446284141, 44.726775307809156, 54.94316501002158, 65.66229666433027, 67.01978975726713, 73.57951456500639, 65.73342884740522, 70.61019405241936, 62.15785111150434, 62.47447659892421, 57.73719087723763, 55.571367894449544, 55.142295898929724, 58.27319452839514, 55.32170511061146, 56.971442237977065, 59.01727599482383, 60.25683910615983, 57.490544396062056, 63.26992150275939, 61.19417575097854, 58.39053223209997, 53.919461696378654, 50.69676391540035, 48.57199245883573, 47.968359301167155, 49.21523371050435, 55.005699357678814, 63.3789163251077, 66.50880690543883, 68.28374216633459, 73.92072154629615, 79.17261831222042, 82.30975351025982, 76.56973346587151, 72.23236083984375, 70.01761805626654, 73.51685077913346, 71.18340922940162, 84.6063796935543, 78.0682671454645, 42.229998419361735, 1.4806898370865853, 22.608853501658288, 64.15951113547048, 18.668705186536236, 1.9030346000386824, 1.1120497988116358, 0.20248597097252646, 0.16952295427120503, 0.6954955574004882, 13.877013248782005, 22.31739001889383, 67.07165918042584, 53.29355732087166, 11.743776336792978, 56.03228169102823, 54.425141503733975, 59.06597614288331, 1.8158454592189484, 0.46120996617021104, 0.04236006951560417, 0.024909017524952372, 0.11823172065159006, 0.016203834036845836, 0.03598029612593594, 0.06584652113698183, 0.042450900730346484, 0.02098969829779479, 0.03777614411627574, 0.08626157688277383, 0.04602785334892331, 0.03490642471719654, 0.06324010615747783, 0.09864591677943546, 0.07029147818684578, 0.11557266777080875, 0.02914787777098677, 0.052137488814731764, 0.03742140710293766, 0.11414166915440753, 0.11282004491095582, 0.051983198706781676, 0.11134103556433994, 0.11482079843840293, 0.04711752149066137, 0.0631051367869781, 0.04460692495828675, 0.05326924582702979, 0.028327560397766294, 0.031824384049903, 0.03075888598217599, 0.02775362647709347, 0.10281358064422685, 0.045130051927821296, 0.050892595937775995, 0.05222047911956907, 0.09900253070818801, 0.05651788380477698, 0.03686238508371096, 0.027387231520767656, 0.020536045926893433, 0.03494376767306559, 0.023512548406518275, 0.030309408790461963, 0.11522199102346936, 0.04315403154900959, 0.039902202815057776, 0.1600232954707838, 0.09589509422620458, 0.06300449964680499, 0.09208618933635374, 0.21003729964215911, 0.13546236340076695, 0.09442199907836415, 0.10306461233525507, 0.08092657122160159, 0.07710730116213523, 0.05506675622816529, 0.1511350820862478, 0.033213067799806595, 0.33851366129613697, 2.326016502995645, 85.76255321502687, 89.18395042419435, 49.090784749677105, 43.39416573124547, 131.1072155737108, 72.9000816037578, 21.088927215145482, 0.011396013695987002, 0.19105969297309078, 1.3736989781741173, 0.8905622579397694, 0.20272951032365524, 1.5045970510090552, 1.5300702712228222, 1.7778476207487046, 0.5758640638762905, 1.2098238232635683, 7.718858247803104, 1.2530672189689454, 1.293162422314767, 0.6373709956965139, 5.158368339461665, 42.54483530598302, 85.10211237015264, 74.30802422185099, 76.2199600281254, 85.83627024004537, 95.85914980980658, 86.71119413068219, 89.80446938545474, 83.73887692728351, 80.94467455340971, 77.51547182759931, 88.12673045742898, 73.3317933544036, 77.91895820248511, 78.29849458509877, 78.59616325747582, 77.05725269932901, 77.46313956476028, 70.37675811398414, 69.00959245620236, 62.85625657727642, 62.89458205623012, 62.091665037216686, 59.519919887665786, 58.65659444562851, 57.1635324724259, 57.13420883301766, 70.9045365548903, 77.6505974800356, 78.52720798984652, 71.94769090221774, 71.39586048741495, 47.009241734781575, 55.178593512504335, 72.45343346749583, 72.52111788718932, 80.84761158112558, 71.76848565378498, 74.01067718382805, 66.98257430907219, 67.34802153802687, 62.87131847873811, 60.1714216509173, 58.891246318817146, 60.6190582244627, 58.298407523862785, 60.35671441785751, 62.84010425690682, 62.1785141575721, 60.34448446766023, 66.3755718354256, 66.73648480446109, 66.36419696192588, 62.26029949803507, 59.83261516017299, 59.68684419508904, 59.05785683662661, 60.925316887517134, 64.73482085812476, 73.17316485989478, 72.52492258625647, 72.89962660881781, 74.95613313490345, 76.51063119211506, 81.9968189731721, 78.84240965689384, 74.25533894569644, 72.55057488718342, 77.41755377861762, 76.50607339797482, 86.9297956651257, 81.89941867705315, 46.1818334364122, 2.210042313221962, 28.41082738291833, 70.00465854521721, 19.60789122889119, 2.0960817702354926, 0.4800808874349441, 0.17446915498904644, 0.36735788288135685, 1.3027163354619857, 24.051728748506118, 36.03706229117609, 62.06662462603662, 94.44443718079599, 18.039282444984682, 43.27940110237368, 63.03149238709481, 68.81192068899833, 1.430766032107415, 0.29980820273199393, 0.10884945716468558, 0.026275448335875428, 0.06426399799003717, 0.04081559795585852, 0.05236006416981259, 0.09621335013258843, 0.05107139319842381, 0.03243240888320631, 0.09850802095306498, 0.0388157177686451, 0.07421932588782042, 0.016771719693356467, 0.007274713951178016, 0.03590251138854412, 0.041922652463038126, 0.11756544632296409, 0.0807194133859969, 0.06603041288232611, 0.0329833754879092, 0.09378591627483407, 0.07217755601290735, 0.025571252654997573, 0.06682396505869205, 0.13272284830529846, 0.06461832131589614, 0.06855188403278589, 0.05062068835081113, 0.15134310560120692, 0.16944360288400806, 0.16122145698435847, 0.1154907959543409, 0.2109009105592005, 0.1314449370388062, 0.31826218830481656, 0.12829220177786005, 0.16002271324396133, 0.20649262613827185, 0.1711188839568246, 0.15480634395874318, 0.13330159708857536, 0.15221033245325089, 0.11539316570927059, 0.14340870232591707, 0.19270079120272593, 0.1872682165835173, 0.06942397554314907, 0.07656788333289086, 0.22007107494338868, 0.20126390751571427, 0.12941069780818878, 0.21745638621430244, 0.3044352818640971, 0.3593865235245997, 0.145472175471725, 0.26491203976254313, 0.094396059341248, 0.23648645458442552, 0.26391937367377744, 0.35230241655822725, 0.24367876380922335, 0.6165202887308213, 6.3271233535582025, 114.03130254437848, 98.00131305571526, 99.37164798859628, 47.505845177558164, 110.70812148432579, 98.38754884658321, 24.035133200307047, 0.09723834513175873, 1.2008113197741972, 2.930136770009995, 1.8387296699708509, 3.0092772072361362, 13.083853125572206, 2.085034904941436, 1.8123074813235192, 0.24989254892833773, 1.0333670531549761, 12.331721974957375, 1.528488452876768, 0.6462736115340264, 0.5303925780519363, 3.561481227797847, 38.238578842532256, 92.85925834409653, 78.47445211102887, 83.33380591484809, 97.03583732728036, 104.51577371166599, 97.06679267268028, 99.47249997046687, 92.01698426277407, 91.23099619342436, 82.54976334110384, 94.9763733340848, 77.18247828945037, 79.46915734198787, 82.28601532597696, 82.88611442812028, 80.85410702613093, 83.01288543208953, 73.68275919268208, 75.79670490757113, 68.96592078670379, 68.96007645514705, 68.06163403295702, 65.65309086153584, 63.67682818443545, 59.26968051541237, 60.14299623427853, 73.09113241011097, 84.02280161457678, 83.73553506789669, 74.57782053178357, 73.03559949321132, 57.04838345127722, 68.1432899352043, 80.85030232706379, 77.51115722040977, 83.8668324870448, 75.96197789715183, 78.7654919778147, 70.92268928404778, 70.35299639548026, 64.77369939127277, 60.85742850457469, 60.94650160881781, 63.72605000772784, 62.182397304042695, 63.09912189360588, 66.81862708060973, 67.58618001014956, 64.37439034062048, 72.38899677030503, 74.96629207364975, 73.3905896832866, 71.98564375600508, 68.7362346341533, 68.43705977163008, 70.00999296865156, 70.54142705855831, 73.40431797888972, 81.38500767369425, 83.90812720021894, 77.7312021870767, 80.3278269306306, 80.57827811087333, 88.5896485851657, 83.82187428012972, 80.43575486829205, 77.11409568786621, 82.76325010484265, 78.94574057671332, 91.97081796584591, 88.06856955251386, 47.68255972093152, 2.8764382966103095, 29.710220367677753, 82.18450438591742, 27.110647962939357, 7.867580306145453, 2.408431629019399, 1.6540823780721234, 0.7456287188876061, 0.9051710643595265, 20.547704850473714, 37.89790922595609, 82.17804031987345, 70.30203696220153, 21.09547168977799, 83.44395391402706, 70.64489133896367, 90.98643641318046, 5.759677492803143, 0.5931054548390451, 0.2253396607815258, 0.16842438418778682, 0.25281589448211655, 0.12651095542335702, 0.13533670965942646, 0.18008978887190744, 0.15057730879033768, 0.16437046139711337, 0.22887955389676556, 0.1573912165458164, 0.2439853521965204, 0.12060589607684843, 0.15160046517848969, 0.12036579646049969, 0.14444704257672833, 0.32886509032499406, 0.15625362194353537, 0.16722557916035577, 0.1839926238021543, 0.23715796129357433, 0.2738867904390058, 0.1189716007079809, 0.21279947561842782, 0.19954551101451923, 0.1576507977780796, 0.1571695566658051, 0.14930970906730623], [0.08764258060123652, 0.08293706172656629, 0.05682922959808381, 0.031903764165397135, 0.07437594490306032, 0.06436754243388292, 0.06541243273644679, 0.06540206756683127, 0.12290180029888308, 0.08866713126941074, 0.06388275816495861, 0.043951544399944045, 0.09990047768599565, 0.03094223572031385, 0.03482960142014969, 0.079153384112062, 0.11199703665390132, 0.07119641188652286, 0.17488288843343336, 0.10777676553134957, 0.17168235694689138, 0.05683311366385991, 0.11180172253760601, 0.1418634570173679, 0.13576429397348436, 0.10587561875581743, 0.16524309682990276, 0.14348593931044304, 0.13844816044213312, 0.09972567174343333, 0.1647284542841296, 0.1966104289937404, 0.2847620826815405, 0.07077602879895319, 1.0742903669034283, 12.75869648302755, 80.45944598413284, 79.87679358451598, 69.85330996974822, 21.924093961715702, 88.4643445476409, 76.98779536831763, 20.71646482713761, 1.6906182756347043, 0.6601159623072994, 0.5027388571010483, 0.6088657220525127, 1.549580508182126, 1.4238470936975172, 1.894808041472589, 0.2388120064091298, 0.33342720520111824, 3.701126921561457, 2.6652821561982556, 2.923102244254082, 0.7452440201755494, 0.5844948104312343, 0.5685283123485504, 35.7009308568893, 83.15559694843908, 64.25603674304101, 91.70856829612487, 92.82492191560807, 84.80211380989321, 85.79884298386114, 88.8447516964328, 89.97980717689761, 84.45449767574188, 88.3951460930609, 74.189545108426, 65.54126016555294, 73.18086839491322, 68.48758774418985, 65.84096062567927, 64.73321660872429, 63.80818836150631, 63.92136443045832, 63.04336147923624, 62.80380272096204, 63.10609586777226, 63.33219697398525, 58.61447211234801, 57.46950088008758, 50.265405178070075, 54.78677618888117, 63.29480501913256, 70.30172317258774, 63.00032523370559, 80.50910319051435, 42.695866169468054, 17.171018738900464, 69.21323407080867, 72.31051798789733, 69.31958521566084, 66.89027309417725, 65.84664806242913, 62.247861662218654, 63.374401677039366, 59.66334135301652, 59.47223563348094, 60.3492776040108, 63.12955948614306, 67.10280279959402, 70.53653978532361, 64.27152226048132, 66.47109723860218, 63.251800152563284, 66.12275938833913, 64.2584176217356, 57.83310459506128, 52.57765808413106, 48.528320789337165, 49.39282294242613, 50.324366246500325, 51.07791631452499, 54.26520685995779, 57.77914062623055, 67.55628370469617, 75.09081163714009, 83.15216095216813, 79.6592354005383, 79.46504669804727, 79.78682225750339, 91.69084702768635, 87.12286256974744, 90.17576094596618, 92.12999559217884, 73.93106091407039, 16.143918652688306, 0.5434853884000932, 0.17388369527555284, 6.942203458278411, 24.810405354346, 10.715492675381324, 2.154118875342031, 0.4717869437750309, 0.14813223192768712, 0.1036013718394022, 21.584048001996933, 22.24732864287592, 70.15050011296427, 47.32130942806121, 6.7745280169671585, 56.97500375009353, 51.22744491023403, 76.80524041575771, 9.237857384066428, 0.49951276892135227, 0.03445750868488704, 0.11627209838479759, 0.1454022316442382, 0.0469962727548855, 0.05702612568594276, 0.08834523644538657, 0.019651359931055098, 0.04134920500819722, 0.05567270496319379, 0.03831585305893133, 0.0475834102009333, 0.04697148214965578, 0.2458990551531315, 0.1024798037964971, 0.0310688681389776, 0.08255136710020804, 0.10319588916195978, 0.05397713022126306, 0.09165928684054844, 0.07901624671273655, 0.07144454010431806, 0.07875082789049034, 0.036507379939599384, 0.09624689712279266, 0.10254849123978808, 0.07905260524562291, 0.07820798564822444, 0.07670924953755832, 0.08240620876031537, 0.18451874234503318, 0.06926797705912782, 0.026995783574098063, 0.061675114932680325, 0.04710901791470186, 0.04182897140121749, 0.05861267079448989, 0.0938807426381015, 0.020035907340746735, 0.0645066716618115, 0.05386121345744018, 0.09337405974586165, 0.07556694349454296, 0.051388182046432654, 0.0554373397702171, 0.09433917731287018, 0.07280914188032189, 0.02633437581901108, 0.054747098380880016, 0.09327614604825936, 0.062312044263366735, 0.1098926390911783, 0.13293491676449776, 0.09826586056019991, 0.15339453584484516, 0.1822487318948392, 0.15383336632963152, 0.11890957822963116, 0.04312769344617282, 0.12903712269279266, 0.10292630282140548, 0.2713275971191545, 0.20996360198384334, 1.0225987374301881, 14.6755793786818, 93.75380977507561, 83.02377393168788, 49.996522780387636, 37.264897515696866, 122.91489047388878, 71.51671655716436, 29.927727560843195, 0.9783651271174032, 0.9095084090386668, 0.9368326202515633, 1.0806833399880318, 0.22944874190274747, 0.8152152429665289, 2.0564636251618786, 1.1327330696005975, 0.9007746389796658, 9.631999692609234, 8.505338084313179, 5.639440667244696, 1.4850010122022321, 0.9393227124406446, 1.2220867458851108, 45.73684838510329, 83.82198410649454, 71.02616140919348, 90.44423149478051, 94.62440336904218, 91.84530996507215, 90.60876707876884, 86.33537615499189, 91.0964745859946, 90.5354501355079, 88.5479381007533, 76.91991483011554, 71.25860891034527, 75.67430342397383, 75.71260144633632, 72.44808335458079, 69.36789312670308, 70.52063849664503, 68.66112909009381, 70.07426492629513, 69.92457159103887, 67.78810362662038, 67.83864728866085, 63.91920712686355, 62.998054181375814, 55.16668911903135, 63.42748703495149, 73.10714352515437, 78.52112831607943, 68.90775203704834, 82.96334589681318, 46.135286669577326, 27.12699640181757, 78.67245335732737, 75.29778726639287, 75.22982828078732, 72.65603957637664, 70.9395476310484, 66.44350728681012, 67.2052707979756, 62.279079806420114, 61.105687079891084, 61.380166699809415, 66.77892484972554, 66.78189800631615, 70.72717482043852, 66.89192833438997, 68.85817327807027, 68.29050433251166, 70.25835744796261, 68.77428162482478, 65.56139761401762, 63.22969367427211, 61.11079008348527, 61.820895979481364, 61.340837094091604, 60.795831603388635, 66.50618676216372, 68.14800462415143, 73.83807720676546, 78.96727438895934, 82.94334965367472, 86.4646339416504, 85.96672042723625, 81.25409464682303, 92.19570313730549, 90.81400902040544, 95.19518667651762, 97.29392143987842, 76.44689267681491, 18.062451885592555, 0.5101727598136472, 0.5559240209479486, 9.369697070890858, 34.55280603901033, 10.587154684528228, 2.263315454606087, 1.087045792129732, 0.20658245760827296, 0.20792337194565805, 38.396273812940045, 36.511053269909276, 59.42904249314339, 81.07565033820369, 11.73769764361843, 35.521270613516535, 53.31072161274572, 87.06325038786858, 11.100764543779436, 0.25532991925795234, 0.1343374092492365, 0.09470187397974153, 0.14344622531244833, 0.016262887924488996, 0.01681032094864115, 0.13050969690084457, 0.01933943765658525, 0.054940681138466445, 0.02923028393378181, 0.035935644691269246, 0.04417585877461299, 0.048645169759589824, 0.09472351596360246, 0.13665065770187687, 0.04991062060599366, 0.021216663336681745, 0.12976835361651837, 0.013220546891041582, 0.03561555783474638, 0.04142145476033611, 0.07884019204685766, 0.05842660718988027, 0.056681340154741085, 0.04902284727582047, 0.09556551554029989, 0.06511817070385141, 0.09090910290157603, 0.034902291672845046, 0.209119648882939, 0.24290247159379147, 0.2023228555316887, 0.10187942069023849, 0.1276716782200721, 0.16984907790057122, 0.18512317039553197, 0.2020924162840651, 0.17802659151775224, 0.15902430149576358, 0.14620084766178362, 0.1574383922401936, 0.19836526063661422, 0.1654422643684572, 0.09213921794247243, 0.10832339224796142, 0.14669068428056856, 0.13344853275245236, 0.30671240161022834, 0.16721433298962732, 0.18034730166677507, 0.22171229574709173, 0.23494972817359433, 0.2761753402169674, 0.15952941390775865, 0.2581968500969872, 0.26787128419645373, 0.19671299284504307, 0.37677815965106415, 0.29233997928038724, 0.33688143436466494, 0.2340692480004603, 0.5076263754838898, 0.5110088681742069, 1.5859049654776052, 28.247672473230672, 116.52643988209387, 96.53295024748772, 99.03338278493574, 32.136396554208574, 110.51070859355312, 97.61428494607249, 36.84298384574152, 1.625209933807773, 1.0575908758947927, 0.9638476383782203, 3.7523060075698362, 3.305134234889861, 5.233684220621663, 8.120940904463492, 2.3385273929565185, 1.6989609118430846, 7.6666838603634995, 6.578746832186177, 4.655684732621716, 1.2549417441891086, 1.5691486001014712, 1.0392388413029334, 41.754662067659446, 90.04238467062675, 79.60354558883175, 99.79393036134782, 100.13214849656629, 101.98911620724587, 97.9057405840966, 98.83119244729319, 99.20611612258419, 96.55334657238376, 94.36147120691116, 80.52205485682335, 75.19389152526855, 79.10036040890601, 79.19077888611825, 78.04742367036881, 74.70594083109211, 78.2504455504879, 74.1810884783345, 75.75255470891153, 74.25069485941242, 73.00396165540143, 72.81786088020571, 67.85800026309106, 69.47960222921064, 58.89954997647194, 65.851425509299, 76.10577198766893, 82.98170258921962, 74.11923270071708, 86.59984588623048, 49.290048999171105, 23.370073764554917, 80.93921461412984, 81.46624780470326, 80.12217706249606, 76.69051108821746, 73.76298735218664, 68.88043665116834, 69.9724401966218, 66.61687604842648, 63.63540403304562, 66.68058318476524, 70.37136093262704, 74.00665283203125, 76.79543449032691, 72.92039163651006, 75.65987694648005, 74.23076921893706, 75.49505110709899, 77.06064947189824, 73.5469118241341, 71.36307731751474, 72.67815389940816, 71.31025083603399, 72.00956236931586, 71.11796056070636, 77.7173169966667, 76.96811291479295, 81.54856266513949, 86.30544847057712, 90.38164615631105, 89.18513497998639, 90.03058618114841, 86.88730070667883, 96.93682101465042, 96.97414628921017, 100.71532649378624, 102.99181522861605, 79.05129155805035, 18.117319960748, 1.0925541481664105, 0.4646968306793321, 11.371176665829076, 43.537693100590865, 17.05460867574138, 4.712007026518545, 2.7237286586915297, 0.34738220154277744, 0.1701153853848096, 29.14091775494237, 37.06827694369901, 83.18171208904636, 61.54747147713939, 12.440135305927647, 86.54881585028865, 64.25144364756923, 102.66272837115874, 22.204735625174738, 0.6190190223916885, 0.34381379463499595, 0.2468405925338307, 0.3546155424367997, 0.12003968049201275, 0.176433481035694, 0.2420311538322318, 0.06851452192471874, 0.07556291387206124, 0.2072072023105237, 0.19225307409801792, 0.13456607117287575, 0.14241022929068536, 0.20776636988645603, 0.3089621566957043, 0.11915132493501711, 0.20478118571542925, 0.16129325474462203, 0.15746152809550687, 0.10313252602974254, 0.13517606102170485, 0.08924438618123533, 0.1821316276947337, 0.10398670640443602, 0.1994581157041173, 0.16177181454916156, 0.14736494890624477, 0.20813047615510805, 0.22338294964884559], [0.06127429006981754, 0.06263817938405179, 0.19513030115875507, 0.03998348474382393, 0.13379691889689815, 0.13161735278704476, 0.05312838140995272, 0.04213705365996688, 0.0737031664879572, 0.060325191401305704, 0.1322944672597993, 0.06223605217171773, 0.10076771219891888, 0.05450518313615073, 0.043403921769030636, 0.046041118161332224, 0.02322770350973212, 0.046190715980746096, 0.11508160541134496, 0.08465994750299762, 0.06304112248002522, 0.122081519314839, 0.06577997107899959, 0.21780103384967775, 0.11515523412174757, 0.12173916994323655, 0.23438700594969336, 0.315599910193874, 0.16366115590978056, 0.27552560572662665, 0.09155145230432672, 0.1160530738472458, 0.0911342791251598, 0.29827118520775153, 0.06357353060476242, 0.5432273087001617, 41.5116241670424, 87.2293000067434, 75.51698500110258, 69.82211143739762, 34.9571749471849, 80.94877735260995, 85.50120569044545, 31.04114332506734, 12.666567852420192, 0.39211818167278845, 0.20258948477285527, 0.1746488026072902, 1.1880012265136166, 0.5675788536187142, 3.409861763638835, 3.481045182674162, 0.9445916813227438, 4.719119264233497, 9.045289601049117, 1.155039588770559, 0.7103821779451063, 0.23426319081937116, 1.2536556970688606, 28.28801012808277, 47.22523097069033, 75.60286921839561, 84.25192294582244, 80.38146142036685, 73.76470535032212, 72.62128737664992, 78.5978106529482, 81.84612151115172, 82.12075802587694, 77.82272677267753, 58.22419628020256, 62.55255529957434, 65.20892558559295, 56.523229076016335, 57.904691773076216, 58.863813261831964, 62.989562249952755, 61.47717475891114, 62.46128174566454, 58.44418241131691, 67.99798965454102, 66.94196208830803, 67.93095634829614, 59.304824952156316, 59.69477130520729, 58.73073508662563, 74.04127951591246, 63.565126926668235, 79.95629218316849, 32.50908643968644, 0.24760551600446626, 68.15006779086205, 75.41122221177625, 70.3882977270311, 64.12324882322743, 60.73873758316041, 58.548164444585005, 59.29272444017472, 60.87063120257471, 66.56893684018043, 74.45264201010428, 79.93234219089632, 73.54011827899565, 74.49873770436933, 76.93140737472042, 77.62932254422095, 74.34138005779636, 69.80585713540354, 63.83817488147367, 63.83079690317955, 52.27842830842542, 54.527950748320556, 48.098040703804266, 42.21491298367901, 43.221655968696844, 51.162106067903586, 60.557963386658706, 62.77506351470948, 48.448524090551565, 29.837830758863884, 17.66283296769665, 16.06694704101932, 16.67800230364646, 36.42413746926093, 41.99029845576133, 40.710542817269605, 32.19281788795225, 4.999293185049488, 0.43619134253071207, 0.06031152439273654, 0.4673541445405253, 1.101373720072931, 0.9249399326020672, 1.1448975652456284, 0.170553618321015, 0.6428710779836101, 1.4813494081458738, 31.719829074798096, 20.483332872390747, 73.050182865512, 51.71113983277352, 8.925575921612403, 66.14441087169033, 62.119121628422896, 74.02613132230698, 26.296642403448782, 0.10110301356161795, 0.09378350309787259, 0.09049132451294892, 0.21584269861059807, 0.21067440900350773, 0.30041463793285433, 0.030298880827162537, 0.06521168705676833, 0.04255810324403067, 0.027198568962874915, 0.05614773310240238, 0.01383270285347657, 0.15626044012606144, 0.07676836088179581, 0.08947588263019439, 0.09794686154852952, 0.08615325205028058, 0.2384425528467663, 0.26718762733282586, 0.046562728276776696, 0.0567113210056578, 0.09971961964883151, 0.10297766901672849, 0.18208642850720114, 0.1832497789854965, 0.14904487247188247, 0.07330583498602913, 0.07599736999479995, 0.0559287085648506, 0.06765274961869563, 0.019981283356525728, 0.046137989979357495, 0.1904975989412877, 0.04132721062389113, 0.0351151185590894, 0.0040448570976995175, 0.0236832749308838, 0.06305773892710287, 0.03112715402347667, 0.05229495052668837, 0.047131188499230536, 0.0934340444303328, 0.014129678752543706, 0.04423280592046438, 0.04817042124247359, 0.016485200894455758, 0.023601485468867808, 0.10508846341361923, 0.06116638658568264, 0.08766280532243752, 0.050899597981403914, 0.11498286433878446, 0.07464531673899583, 0.20938174288359382, 0.09378728757221853, 0.15618945441899762, 0.10977806298122292, 0.26174490970949976, 0.1737329598155714, 0.24542924407268726, 0.1273484887074559, 0.20450130315317264, 0.0932168585037993, 0.27901957953168505, 0.08876689123891054, 0.47661954897546005, 49.88796334112845, 97.4704751660747, 75.73414310332268, 43.62409114837647, 47.42828030740061, 129.17549533228723, 82.37653578481367, 47.21297356390184, 13.249287912922522, 0.9579585672866915, 0.5505217527670245, 0.5952036164460645, 0.30918542536035665, 0.7928465787441501, 1.7577164235614964, 1.6044033535065192, 1.1465646951429307, 2.701567022069808, 13.621835612481641, 4.477118340230757, 2.7682242710744185, 0.1648147157844036, 1.8231407000172524, 40.867555295267415, 59.987199691034135, 87.34144056996992, 94.39168914671868, 90.10472682214554, 82.58264064788818, 85.09937455577236, 80.48061893832299, 76.61862188769926, 76.80702901655629, 73.44796611416724, 62.800103925889545, 69.26393462765601, 72.42893434339955, 67.51301211695518, 70.0465416139172, 69.2766038833126, 70.7104576787641, 67.5636185369184, 68.70284741924655, 67.96108015121953, 75.61103559309437, 76.07398509979248, 77.79527802621165, 65.54556692800215, 64.00090617518272, 66.25656712439753, 83.19220835162749, 71.98166647265035, 87.64121947749969, 35.738758194831114, 0.3914020120376541, 74.22902768658054, 81.39641392615535, 76.13689991735643, 67.06697587044009, 65.95185387519099, 63.5234909672891, 63.27988432299707, 63.23878965070171, 70.04138761951079, 76.88103629696754, 84.52186830582158, 75.97182304628434, 79.4316202594388, 78.43609133074361, 80.39163604859384, 77.87139554177561, 72.23574976767264, 70.04594541365101, 70.85427530350225, 62.19468216742239, 63.62497052838726, 63.63980101000879, 55.37792444229127, 58.707118495818115, 64.1286656164354, 72.07585826996835, 72.34654103555988, 57.32089796373921, 38.46960644568167, 23.512491103141542, 23.659599596454253, 28.241333923032208, 47.2348133210213, 49.2897665885187, 47.07187806406329, 35.922564383476015, 5.853215234894907, 0.5967558944417585, 0.20508582823939864, 0.9185375213142365, 1.1361413641322045, 0.20485872913512493, 0.532353088980721, 0.5241756826158493, 0.508283066052583, 2.0683937591891137, 59.719168447679095, 32.74189676007917, 52.17661534586261, 91.34174039286953, 13.974816568436163, 31.857878854197843, 60.02291679382325, 79.79808730463829, 28.854788695612264, 0.32527514102478183, 0.10395986268356924, 0.07863046781670663, 0.20290293730795386, 0.12318238766203005, 0.16151140594194013, 0.06521223864007382, 0.06274511376696248, 0.08527788934448073, 0.032073418166668664, 0.00739540679440383, 0.029980228470277884, 0.06501464158176415, 0.027297233426642996, 0.05465919362200845, 0.08416833356022836, 0.11403816301495799, 0.06311144935147417, 0.22716250571031726, 0.012111216145116958, 0.0619062168463584, 0.050114120371759906, 0.10419887445506551, 0.14066485117279715, 0.0936015801984937, 0.12088656004878784, 0.03489957972159309, 0.0800875134225334, 0.047644796826305895, 0.0655177621651561, 0.14058781337113152, 0.2054847915086054, 0.39302829412683365, 0.18816846182509778, 0.20630430640472522, 0.3625256147596144, 0.16499065553709386, 0.3438820683908078, 0.28249081584715074, 0.07341979056476586, 0.17841314416258566, 0.16896297464207297, 0.18122358367808405, 0.12128704783296394, 0.10005988526127993, 0.10339072830374203, 0.18720080084618063, 0.16114471029610405, 0.1607968297696883, 0.13278628038542886, 0.1316004682091936, 0.2102955938467095, 0.19070813522463848, 0.3037328711680828, 0.2088488827669813, 0.19808353946333934, 0.2048581162647855, 0.3175552730118075, 0.332341474751311, 0.2589667071738551, 0.14248820171961862, 0.29465580178845313, 0.16792153939604762, 0.48787926413839866, 0.177746279946258, 0.5297773788052221, 72.53898036095404, 112.42900648424703, 95.38824573639901, 103.1991046474826, 50.624376573870265, 97.42908631601642, 103.51546733610093, 51.6368579864502, 15.052691736528951, 0.5473617932969524, 0.7914638819713747, 1.7032528428300735, 2.3045277980066117, 5.244381014377841, 9.300558432455986, 10.553416417491052, 4.518191439490165, 9.614687331261175, 19.01703126968876, 3.6847980945341052, 1.8250211087926742, 0.48472552530227175, 2.4020249276391925, 33.55680250352429, 56.76026575026974, 89.04288630331718, 100.79805712546073, 102.38944115177279, 101.6402998278218, 94.25943466924852, 88.71894559552594, 83.39770916969546, 82.02023552310082, 76.8677237726027, 71.58114540961482, 73.98526022511145, 79.00690601718041, 73.08120881357502, 76.6221284866333, 72.57425815828385, 76.9048450839135, 74.78703191203456, 77.03636215579125, 72.69887185865834, 82.57383100448116, 82.79699817780526, 83.14622248372724, 75.0038605351602, 70.6743718731788, 72.59600377851918, 89.39054950591057, 76.81674080510294, 89.55479483450614, 40.304863837457475, 0.7454843266356377, 76.5128355641519, 83.56665349775746, 80.65998108156266, 70.96887127045663, 69.29186974802326, 67.12601538627379, 67.76861729160433, 67.7103465603244, 71.58875480774911, 81.66095426005703, 89.94132872550719, 78.37059559360628, 82.67757769553893, 83.04944976683586, 85.88999886666575, 84.95542357044836, 77.21930150062808, 79.51373115662606, 79.99764180952504, 73.89913282086773, 74.44380098773588, 74.85904662839829, 67.27145687226327, 73.17720490117227, 78.00874910046979, 82.53076337998914, 78.32200527191162, 58.94788142173522, 37.72380305874733, 22.526905382833174, 22.128414146361813, 27.94595983720595, 45.74670137897615, 51.19988241503316, 47.421306333234234, 38.18281842816261, 5.713902942595944, 1.003220941751234, 0.3050739846883282, 1.3438388320707506, 5.278127126155361, 2.0279221308808175, 3.0969399742541777, 1.1943820647654997, 0.6426345100325923, 2.4751705123532206, 43.20713143194876, 35.071641475923606, 85.17043221381404, 69.80509619559012, 16.92554504640641, 91.42405525330575, 77.34343667184153, 93.27382149234896, 45.37655122818486, 0.4068531474519161, 0.34015704246778644, 0.2585177183631928, 0.41510192256781364, 0.27617025339315016, 0.34197714480180896, 0.18930144457807466, 0.17305647353491477, 0.2346071336538561, 0.17102352133201015, 0.18696165883973723, 0.11032746293612065, 0.196705102139423, 0.13036639249372867, 0.10323400203619273, 0.22106139680310605, 0.2134855839634134, 0.30078131825693194, 0.29035152146412485, 0.10698659180272972, 0.1584206854984645, 0.12337453783519807, 0.12337601638489193, 0.16347058387773652, 0.2866864955473331, 0.21211773397461062, 0.13094350184884765, 0.18091808313563948, 0.14475897825773687, 0.12010894250124694], [0.12853358842192159, 0.10808312409226933, 0.1137677569603247, 0.07338241313494022, 0.08487158695295935, 0.032782618316911885, 0.05410487921307645, 0.09582604672158919, 0.11681933797174886, 0.04246864715711244, 0.07618880004531915, 0.0551740353506419, 0.10404882847421593, 0.05814115516841412, 0.0346611003812042, 0.07533458136622945, 0.036444193007604736, 0.02884403197845865, 0.19933666012460188, 0.037502669879505714, 0.059157466560962706, 0.10882927840876003, 0.2418768943677987, 0.2739495790052799, 0.17832063138484958, 0.25605371912881253, 0.24500499990197921, 0.14490563812996113, 0.15740269254292213, 0.06535207266889273, 0.10806872163929286, 0.02672978827068883, 0.06619319890535648, 0.04947381642376704, 0.08231410967005838, 0.053109995299769994, 0.37357508475261353, 47.75202489668324, 93.48735532452984, 79.00504681371874, 72.3853725002658, 21.48831863557139, 56.260512644244784, 80.2036133120137, 33.87848392609627, 28.60426495152135, 1.3068891244549907, 0.6228895437332892, 0.1465592695580375, 0.10714140285046832, 1.6764574161460324, 0.18825133721674644, 4.290801834675574, 6.896902043973246, 8.614105409191502, 7.262829272977768, 1.3663781193956253, 0.2873390492412352, 5.285434992082658, 3.692568554993599, 3.130174952168619, 3.3611706860603827, 11.498625259245596, 26.14326596260071, 32.939472429213986, 44.78417135054066, 54.395672736629365, 69.59252726647162, 74.62910159941643, 77.87238397905904, 69.54436056075558, 50.51659768627536, 46.18123723614601, 44.557250468961655, 45.02673072199668, 46.34045016381049, 49.93744404085221, 52.95292300562705, 58.748876048672585, 62.26780299217471, 64.3733666020055, 61.76684571850685, 65.14705411849484, 61.82528511170418, 61.91927686814339, 54.13001844959875, 63.16924602754655, 57.42152244813981, 79.4469645715529, 26.825060190693026, 0.4414643563570515, 72.16788491895123, 69.27231281034409, 70.80755203000962, 60.13539468088458, 60.984525065268244, 62.96436102159562, 70.35491835686469, 75.50244869724398, 80.70427248554846, 82.32880053981658, 83.52509206341159, 82.82890273678689, 88.43262826242756, 79.42346957422073, 80.69061479260846, 75.30298832924136, 78.03622138115668, 75.44540959019815, 62.8142362256204, 60.6259576735958, 59.07280891172348, 48.34260048404817, 47.33617128864412, 41.07500945368121, 39.532035320035874, 29.13582063490345, 19.139897554151474, 4.572392221420042, 0.7772940132887133, 0.14169706272021418, 0.24846077656313298, 0.16757603374219712, 0.3487202813548427, 0.0924608446357231, 0.38284775170107044, 0.14045606156991375, 0.31768042113511796, 0.04872264806181193, 0.31478249437866673, 0.9289091260683153, 0.8793601525887367, 0.31500279062217285, 0.2835326954241722, 0.43003695986924634, 10.710038619656718, 40.59457794312508, 17.325758203383415, 85.85534080382317, 64.95832535528368, 13.349440732309896, 55.184653574420565, 62.09170818328858, 57.49791452961584, 14.889933966821241, 0.1965556996724298, 0.006897119268204176, 0.07153472397476435, 0.04374028033306522, 0.12790824617108992, 0.04792038929618655, 0.08102441597129069, 0.12289255361763701, 0.10050006406081301, 0.012058418322985452, 0.025735791104154724, 0.018836027875001875, 0.1033856568016833, 0.05383757198409689, 0.09141235371991512, 0.23193048373345407, 0.05862117054000978, 0.04789984281805735, 0.12111051053169275, 0.19638097033865992, 0.19804647612956264, 0.24402583228243938, 0.11366733049433078, 0.2833963930606842, 0.11602057639749781, 0.16624167711744386, 0.07314874099627619, 0.1226077144665103, 0.14157116383073792, 0.06133897470370416, 0.08688794569142404, 0.08007961505603406, 0.0207459214594095, 0.09779221137925502, 0.026090313612874, 0.07437347043906489, 0.059563274825772936, 0.13052143336784455, 0.14710104693808865, 0.08061128773636396, 0.04172024054212436, 0.03747064357383117, 0.05028936681487868, 0.11407983819803885, 0.047244918082029595, 0.04845819451035031, 0.019113571953869635, 0.03834932727078277, 0.04139449229584106, 0.1245081717629106, 0.03888685286285416, 0.07115978522286301, 0.10895189844192037, 0.2042181417346001, 0.2059689437549922, 0.13973768560155747, 0.17225629469800383, 0.21830579386122767, 0.1416349789548305, 0.10062521984500271, 0.09614205799035488, 0.07232455296381828, 0.11364198830579558, 0.07317730841497261, 0.08554700837140122, 0.0442862328923037, 0.03259935859410513, 0.29187159312348215, 60.74894359034877, 100.29980628721177, 75.76901297415458, 53.103024267381244, 35.4853730816995, 103.83132011659684, 72.58491131567186, 51.761671727703465, 43.46104606505364, 1.2030360391063075, 0.4580664622687525, 0.2940113686265484, 0.3064766916776857, 0.2491819870568091, 0.11729405201490849, 1.7910565700261825, 5.321647784402294, 0.9751576701960257, 6.000080541256936, 4.501557157885644, 1.1768505409840615, 5.476363714664213, 4.0964358900823905, 4.718717711587106, 11.049899247384841, 25.40074363831551, 46.373970739303104, 56.13357690072829, 60.61429254470333, 72.51663854045253, 79.23529778757404, 82.45056659944596, 84.49943234843593, 73.73024340598815, 63.13171678973783, 60.811764271028586, 60.26549185475996, 59.01783689375847, 62.56588351341986, 64.85588089112314, 68.13124041403493, 73.55448199856666, 72.85426832014515, 71.82796447507798, 69.60633400947818, 72.91388834676435, 69.92192006880238, 70.13091179632372, 61.89455024657711, 72.6295949566749, 64.20069209990963, 85.3680726020567, 31.560463174696896, 0.35015234483345864, 80.69785548794655, 77.09704906709733, 75.38414216810658, 64.0176115497466, 66.00620223629859, 65.48427989405971, 72.05783105665638, 77.23752483244866, 80.87189105249222, 83.90106693390878, 86.10303063546458, 84.95871051665276, 87.68083541624009, 80.84773709697109, 84.44016533513224, 80.34406554314398, 82.88136051547143, 77.081312517966, 71.15119872554656, 69.23625838372016, 74.18324578192927, 63.141440345395004, 61.17488945684126, 58.82356189912366, 56.566924279735936, 41.98290871035668, 24.702959868215746, 8.019112252419996, 1.923195337576251, 0.4806852082331335, 0.18358216921408332, 0.20563869857259337, 0.7144576431282106, 0.05630218025837695, 0.29857636399326787, 0.28299793540950746, 0.5539136836605688, 0.17040069184957013, 0.7318653671010849, 1.4295907919445348, 0.49419663966663424, 0.2732012643208427, 0.19885924945194877, 0.49782786578420674, 14.881901933300881, 75.51034050603067, 19.17738756825847, 58.77104528488652, 109.0394667656191, 13.720132170184968, 31.67687127667089, 60.957280282051336, 67.97218045880719, 19.141935225455992, 0.18923813507201212, 0.04282514617267636, 0.14152642429595994, 0.07337192539125681, 0.12429961198640448, 0.04502864486928429, 0.1153079767320906, 0.027564222729133985, 0.13103085119397412, 0.06738735377908715, 0.08251192123298684, 0.05169037691948395, 0.046690607503537214, 0.0358285570907737, 0.08933452408640616, 0.13544805287834139, 0.08995751444731029, 0.11395408486526822, 0.1633933009279351, 0.20128574102155625, 0.16236553269047893, 0.1237119765832059, 0.08749012144342547, 0.19184698621111532, 0.08046879538244779, 0.042629326438351024, 0.10867920178439348, 0.10361772015570633, 0.05600025351609915, 0.08371598162357846, 0.11253326755738068, 0.14101564283332518, 0.19600158827679773, 0.18688549437830526, 0.19579520418999657, 0.15321122632632334, 0.1233581665362562, 0.19123603109150164, 0.24602982636180618, 0.21975397582977052, 0.1136776956639463, 0.15819429119508113, 0.1092748964325555, 0.27533457404182804, 0.187265336092922, 0.18220917111442936, 0.1414364855736494, 0.14186149583228175, 0.14679853413854876, 0.21325846953738123, 0.15910936789887567, 0.13671189877054385, 0.19306097510120562, 0.2924661079962408, 0.26201147766363236, 0.14890716050661382, 0.2748380264928264, 0.3033644748070548, 0.23165902813836453, 0.16066837214654492, 0.13572609682957973, 0.1688216620635602, 0.26928606473149796, 0.13812234324793662, 0.13668675576486897, 0.27778887460308693, 0.1844082724663519, 0.5356699432576857, 89.16779810382475, 110.08130319656865, 105.50294799189415, 90.31829203328779, 33.614084797520796, 73.89745404643398, 95.6618232111777, 52.571295999711566, 40.98665414317962, 2.3525285384347363, 0.8383838255559245, 0.3744599775921914, 1.0125788589639049, 3.8161813155297315, 3.430016862769281, 12.933515541015133, 20.569454393079205, 22.622913237540956, 24.346455643253943, 6.770551714204974, 0.5240300646232021, 13.209804354175446, 8.063818937347781, 4.140707927365457, 7.736951651111727, 18.539563109797818, 39.458059418586, 48.74343141432732, 58.69445708490188, 65.97573326480004, 79.17135530902495, 83.81045233818793, 88.10358062867196, 78.79615706782188, 74.51120299677696, 68.22197268086096, 69.64384755780621, 67.96622630088561, 74.42603265085529, 75.52049944477697, 76.53121579077937, 81.71173326430782, 81.98402420167001, 76.84458178858604, 74.05910276597547, 79.10225099132907, 73.57060293997489, 76.83813341202276, 67.08199854820006, 79.99698285133609, 71.31025868077433, 91.93481060766405, 34.25692988980201, 0.7204582566215146, 85.64264635885917, 80.72504535798105, 82.79407993439706, 69.07059315712222, 71.26570840035716, 69.43285542149698, 76.22335680069463, 82.1353021744759, 85.29466152191164, 88.8633123520882, 90.09537589165473, 90.43792432354343, 96.21166106193297, 84.83203364956765, 88.27218763289913, 86.07828832441761, 89.30603027343751, 87.10315658200173, 81.25999389156219, 78.82948152480587, 86.7858446798017, 78.85334522493424, 76.64004587358045, 71.4086474141767, 68.52249683872347, 47.5535451212237, 27.239633144870883, 6.9704558003333315, 2.0430921426703854, 0.8937034635774551, 0.6224027408226844, 0.20649382123543372, 0.6871405412112513, 0.17505231643876723, 0.36732840381803056, 0.38893079625502713, 0.8194913006117268, 0.3047978866004175, 0.9373923547325597, 4.045376681512402, 3.2704509217892928, 1.4842667935356018, 0.8534087709361508, 1.0003658852750257, 15.878935090957151, 55.75693914967199, 29.734495916674216, 99.10626042273738, 82.67545177090554, 20.375881502705237, 75.92794741353681, 79.34195487729966, 82.62682222550916, 34.6762312612226, 0.27018667769528204, 0.23009112194901515, 0.20168403013338967, 0.18032609635303098, 0.17704872624768367, 0.12549098596097003, 0.20401235519637986, 0.22672598881106223, 0.34572006653874154, 0.33891640903968967, 0.1615317685589675, 0.13292938560968445, 0.15485324386146762, 0.292311450166087, 0.22621686209834393, 0.3012227381189024, 0.2241526075428532, 0.22444465558134744, 0.4201657943908246, 0.2403719452840667, 0.23180804756139559, 0.24410308458872382, 0.10989856861171224, 0.2268428325412735, 0.33566948326845325, 0.23183158178242946, 0.15301789637775193, 0.13919653641360422, 0.1694651759199558, 0.1947118486127546, 0.40389234019863995], [0.13467572899835725, 0.08798067052397998, 0.17274179525913733, 0.09424310222628618, 0.14220025991239857, 0.08448861193873229, 0.11268782579610426, 0.008288966961235048, 0.13428609668006822, 0.05041940257914605, 0.04898512127598928, 0.056498743097988836, 0.08740743757375787, 0.09622310243186452, 0.006372878119544757, 0.011588564150095468, 0.010531851195640141, 0.08273044781338784, 0.06561779792630865, 0.036715667754892385, 0.09494966511885006, 0.11881484379691463, 0.09937830449592683, 0.1267808941643565, 0.12274127423522935, 0.05270542426695747, 0.03746903478919018, 0.11464030812344245, 0.25839039455017737, 0.06363285262317908, 0.07507926724370449, 0.04635825940978624, 0.06269286274008694, 0.02506680290905699, 0.04706885192483183, 0.07148605440893481, 0.003407371874463054, 0.4756497429503549, 72.68228807756978, 90.82454450668828, 75.80175692035307, 81.25471438131025, 21.105693386447047, 62.886341156498084, 93.96478622190415, 29.837920973377845, 30.14087307837702, 9.132109303628246, 0.4518305065651094, 0.21704544132995993, 0.23925446815067725, 0.3005325541861596, 0.6200623115704906, 0.6906745354494741, 3.420669609500516, 5.396496413215514, 5.125005639368489, 4.418279845868388, 9.33639810931298, 28.505252561261578, 30.447323937569898, 8.66581597635823, 2.1977192067330886, 0.1848559129622675, 0.29677118505201033, 0.482705474020012, 0.5726168929569183, 2.110130229303914, 7.654250927509801, 12.543857482171829, 16.89983194874179, 21.52570862923899, 19.28021054114065, 19.27324245052953, 22.165657051147956, 32.036401610220636, 44.77190217664165, 48.20292880458217, 55.65443584995886, 59.903370795711396, 69.66523231998568, 71.7178870785621, 71.46048545837402, 62.8057207599763, 68.99324401732414, 62.95863828351421, 68.87692220749395, 56.42439319241432, 65.54141706035983, 14.244523644447328, 0.16027356107388774, 63.867008224610366, 62.45406458454748, 74.35421405300018, 68.20164695862802, 70.45373070624568, 71.93422148304602, 77.26949214935303, 76.49210976016137, 84.03700843934091, 82.71909206144272, 81.3795320449337, 81.29846449821227, 97.7927214099515, 77.22708348304995, 82.56241690727973, 84.01913812083583, 89.71709466749623, 83.42504024505615, 79.36321412363361, 55.993571819797644, 45.33387584071006, 38.792770524178785, 35.6760512628863, 25.62326950411643, 11.446848992378483, 3.5607224943176394, 1.021543681140869, 1.8751018085787374, 2.303440075728201, 0.7438451436258132, 0.7512048583838248, 0.44154804380189994, 0.9150689816282642, 0.12794459704309702, 0.19706626663044577, 0.14969734955699215, 0.08429359659672746, 0.18751200108278185, 0.8661483228206636, 0.8679650543678192, 0.016784371635425958, 0.13917382956752855, 0.041965511251962, 23.769204347364365, 38.76085419808665, 19.597428306456536, 100.98659761490362, 57.77603410905408, 14.072800317118245, 62.72600643096432, 56.942918762083984, 53.328564474659586, 15.689809187766045, 0.149429724401524, 0.1583767120516108, 0.04138316951632019, 0.03237494462800603, 0.02229263574155348, 0.06298188856171985, 0.07555617229832758, 0.04013029783363304, 0.057230154052376754, 0.15778463333845139, 0.01969594624824822, 0.07353431304856654, 0.05306290770550409, 0.10445807264336657, 0.19278316097634454, 0.1599720595104079, 0.15117715563504927, 0.05722526258098022, 0.05927361698160249, 0.11537016774978369, 0.12262747187407748, 0.16455957786210124, 0.26744325555139975, 0.12838568748726, 0.32072506905082737, 0.26086504240670516, 0.27862430880627326, 0.10606150232976484, 0.20073496976927405, 0.2286110094357883, 0.04273642553016544, 0.12429699962658268, 0.131010182141777, 0.056053010161004724, 0.14808825848083343, 0.07287582217325127, 0.18532771587131486, 0.1276661470652588, 0.07721977053029884, 0.003366860426819673, 0.09403368443130486, 0.04211727326976196, 0.03153061039835936, 0.020651533681478713, 0.08451069059271006, 0.03273484507395375, 0.020602078875526786, 0.03432323262395878, 0.014560149302856337, 0.10732637477978584, 0.08537386483963459, 0.08989445775026277, 0.052996487882468975, 0.09579598543144043, 0.08688252178892013, 0.11922679991731722, 0.17869299608132533, 0.04448320175851545, 0.10998324430998295, 0.046935510491171194, 0.1414556530935149, 0.04845285104707845, 0.035404546576882565, 0.025208611529500737, 0.03822935790184044, 0.021774578358857863, 0.028052578883005247, 0.044627616993121566, 0.017186956585294778, 0.1856254636039657, 92.3970619324715, 95.29379506264964, 78.78146386915638, 43.248198647652906, 24.17748581978583, 106.83270992771273, 77.21219416587584, 39.978357899573545, 61.19370506655786, 9.745009060828917, 0.5402006485289144, 0.40227969447451256, 0.2185020962309453, 0.2145316617022599, 0.4696038689824843, 0.34451467315516165, 2.4790195832329416, 7.36188578990198, 4.14734261651193, 6.297731562968224, 17.252692291813513, 28.68874299910761, 30.891793197201146, 7.366809835357051, 2.590376162721265, 0.5637327858036565, 1.5042243032686173, 2.729801468310818, 2.854461011386687, 6.681745331133566, 16.65533100405047, 21.259656221635883, 30.569841131087276, 39.55358874413275, 34.33485561801542, 37.13976606245964, 44.44412539082189, 53.481336870501124, 60.41736602783204, 61.296498621663744, 67.30320453643799, 69.95283619050058, 78.8534942750008, 79.15163363179853, 78.39212940585229, 71.43923405678042, 75.32986440966206, 71.5607883084205, 81.43010708593553, 68.58553717213293, 77.81879655776486, 17.448667633918024, 0.22408413460418103, 77.68366306058823, 71.9868440012778, 82.4973604756017, 72.68973273615684, 76.96836394648399, 77.81058311462402, 83.07679653167725, 82.98742140493086, 88.6491430959394, 88.14478120496197, 85.4651669533022, 87.53671969136884, 101.05645502767256, 80.29180388296805, 85.23089162765011, 81.80991803446125, 86.89177220867526, 80.52595369277462, 79.75311340824251, 63.92228226507864, 54.93550462107505, 47.81083299267677, 47.734684098151426, 34.81716202151391, 17.22513960253808, 5.845887266820477, 2.5246360128925693, 2.6609192548259615, 3.024407995323981, 1.1525316007675663, 1.2542245633179143, 1.6306191274235327, 1.083978498654981, 0.14393062270697088, 0.3707012744440187, 0.6802602136327375, 0.5943301536383168, 0.7440403428289198, 0.5287541304865192, 0.2636013858981671, 0.1465409294131302, 0.05206778247450149, 0.3148224535247972, 35.66560991348759, 74.35529662716773, 14.239831509128695, 75.01782417297363, 106.32447273500505, 20.141429670395393, 42.57743804685531, 55.16613998720723, 65.7170254953446, 26.726914644241337, 0.21168160011931775, 0.10238007447051425, 0.13877144954617948, 0.034272004324462146, 0.12426894548679553, 0.03726342828163216, 0.0063305733079511315, 0.09141239968519058, 0.044273937181119, 0.05623776375526383, 0.0879013727629377, 0.06998416201602067, 0.038011884692335324, 0.11765515521889734, 0.21076641616321382, 0.22774197461624301, 0.17802708181402377, 0.09734480070971674, 0.08123144357194824, 0.10435456650391703, 0.14608526031576818, 0.12895484484972494, 0.22401857279962112, 0.12427724987989473, 0.25876703401727064, 0.18305563698372534, 0.2729585676664307, 0.01828184944667643, 0.09825423900638858, 0.06897942238156834, 0.1401772668525096, 0.0701071038061092, 0.20602278441431063, 0.1491512054757726, 0.2779135017866089, 0.14834993879400915, 0.27642241889430635, 0.1924614806569392, 0.15675502648997694, 0.12704147131092128, 0.19602858521524938, 0.11549143946819729, 0.10756229155606802, 0.10197574092495827, 0.16055060911082453, 0.1688493484811437, 0.09316931508721844, 0.22510326136985134, 0.23269634183135726, 0.2201023313306993, 0.16504919997626738, 0.1299717959256903, 0.154247528783256, 0.2144923767135028, 0.1864680071030894, 0.22766824631441027, 0.21839855178709955, 0.13432801701128483, 0.22559738808101226, 0.1502326305114454, 0.25237162477306785, 0.20064552134323507, 0.18369755737723845, 0.08969895977286563, 0.17757915020469697, 0.24716857009597365, 0.11815056895777104, 0.133725228388944, 0.20477568520413292, 2.4692104708763862, 112.80889588017618, 106.25422308521887, 103.44504510202717, 104.92748921917331, 34.25630231057444, 80.34386157989502, 110.62613610298403, 45.469640839484434, 47.6472976130824, 14.718992171748994, 0.6595569019836764, 0.7992676212902993, 0.9284295550277157, 0.6520073199945112, 0.9074381330320913, 5.375487708276318, 18.25759960759071, 20.267084760050622, 20.80302761447045, 9.323918108017216, 18.162284051218343, 43.84823891424364, 38.45354826219621, 16.628968754122337, 2.272981155303217, 0.42399935965095803, 0.611769869442909, 0.8334423745832136, 0.8628928781517091, 2.2707189283063336, 9.821206004388872, 14.21881054678271, 25.181942062993205, 35.87127547110281, 39.227651549923806, 44.085479551746005, 55.364984543092795, 65.5448648237413, 76.07210236210977, 72.69141935533094, 77.28213787078857, 78.54157955415788, 86.04769383707355, 86.56553299196305, 87.02229299852925, 78.07076961763444, 83.67207896324896, 79.81088992088073, 89.43932025663315, 74.06652389034149, 83.83137426068707, 19.277460959649858, 0.4107146289560103, 80.3312001689788, 76.221999660615, 88.64096103175994, 78.01898648661953, 82.89675189602761, 82.72610525931083, 88.55623783603792, 86.18324310548844, 90.5730813549411, 90.33849223967522, 87.76733936802034, 89.09262195710214, 101.87774442857312, 81.5285115088186, 91.74816070064422, 88.23905929442375, 91.11395266748245, 89.29309429660921, 88.37715810345065, 71.60689969216624, 63.070484668977805, 56.36976634302447, 57.31442605295489, 40.708742449360514, 19.37559473899103, 6.500515159099333, 3.1320532771848866, 3.412736860975143, 3.91043096780777, 2.4122208837539922, 2.3641061494427347, 3.0800676538098246, 2.1053478794713176, 0.45814273398249383, 1.0322253982866965, 0.5208821174117827, 0.6477563900332297, 0.766782490236144, 3.8284909388711377, 2.482009655044925, 0.4233209734722492, 0.21460154424271277, 0.37205829194957213, 34.05435908225275, 59.672566767661806, 27.423706054687504, 117.01044467187698, 73.72342632662865, 23.055917409158525, 81.57940033943423, 74.68741155439808, 75.8642481219384, 44.724547401551284, 0.2334098761240321, 0.4257565508446386, 0.22363413455745867, 0.085147715684387, 0.17739368031822866, 0.23247223046998824, 0.163881053787566, 0.22291744398253582, 0.18656874766513226, 0.27360750542533013, 0.20388319277234618, 0.15121202795736252, 0.08096410186901208, 0.25384237569185997, 0.4042045669930597, 0.3416324971664337, 0.3629751551535822, 0.1851786198394914, 0.1670723309319827, 0.3256245996923216, 0.22822710745517286, 0.23278007524148112, 0.3151492359897783, 0.13459800171755976, 0.2911878136857864, 0.24635522986852357, 0.26173957773754675, 0.22233619775262572, 0.17778274573145375, 0.2910918688341495, 0.1787176028254532, 0.23600697547437685], [0.17494835830744238, 0.20138104235933674, 0.09011695266611154, 0.12450091691026766, 0.19407925917015922, 0.044764574361784805, 0.04513070310255693, 0.12103955546814589, 0.053436521125296434, 0.07528058748932616, 0.16438313249138095, 0.17669650966361647, 0.0831466404000117, 0.05228994797254282, 0.02295521561116461, 0.07114586540527883, 0.03984876435189959, 0.045677368123564994, 0.07385240041560705, 0.07005149348368568, 0.10634904577126426, 0.05980891325781423, 0.06383934013185001, 0.03702074311853897, 0.10523674739224297, 0.1670181378722191, 0.038226274397945216, 0.07096841645937774, 0.04570003283480483, 0.029447722669330337, 0.1513696275651455, 0.040799575226922194, 0.0532342394393298, 0.020866524766109163, 0.09079762944771398, 0.061359712703814434, 0.08296955917631427, 0.07751957137858675, 2.5710224528466505, 76.06484597729099, 94.45600032806398, 69.7671433418028, 71.3554443851594, 20.851545372316917, 54.15864782948648, 106.42619548305389, 42.66998244870094, 42.819095273171705, 27.641001439863636, 0.8410225388023161, 0.3450972064127845, 0.22678594285201645, 0.05338865212134777, 1.4698967001130505, 0.9176303506378205, 1.7967125052405943, 2.7475291106008717, 6.251495153673234, 5.697186781514076, 22.051867131263982, 28.54569219773816, 28.47480320161389, 9.208708290130861, 0.2311148912075066, 3.7456693572382775, 3.7927615786752398, 6.6249356827428265, 7.901246009334442, 1.0649629706336607, 0.8760775577637457, 0.7618287205696107, 1.7017049775008233, 1.2563112642495864, 3.5645355284214024, 8.279311503133467, 14.961477998764286, 24.61515957309354, 34.36027257673202, 55.600150246774, 58.55783700942994, 62.19939293399934, 56.43864316325034, 61.249983233790246, 59.76961405046525, 61.72411149547946, 51.85463190078736, 53.74834437524119, 51.11118585832658, 67.93634568491291, 5.415484116923425, 0.4446729470885569, 56.274064433190134, 62.26954452453121, 66.45707868760633, 69.88395152553436, 74.51526657227548, 77.08918863727202, 82.05984361710088, 81.93591240913638, 79.49607264611029, 79.17869014124717, 83.68625440905171, 82.97659566325527, 85.4880657503682, 86.96147272663733, 90.60293843669277, 94.71458650404408, 89.64116542570054, 80.65838075453236, 53.77880942436957, 34.66979465176983, 25.556600978297574, 17.359000290593794, 9.638697139678463, 2.836058476278859, 0.16916752011785585, 1.3227416286545417, 0.7654837566998698, 0.9109242008097711, 0.10624540173598837, 0.07136065347660935, 0.0923016822085746, 0.11102866321321457, 0.4049462320343141, 0.09395961138990619, 0.21769163649409048, 0.19138356430395959, 0.19715830443366883, 1.0783878954187518, 0.24855361109779728, 0.30727829543813584, 0.035635840012541706, 1.2039147725989743, 31.147745501610544, 32.512759739352816, 28.10025803504452, 109.70157069544639, 31.155664766988448, 10.615567353463943, 50.035726870259936, 33.34367659784133, 57.79455554100775, 38.57475342289094, 0.4263870412063214, 0.18870360488372465, 0.07433605470484303, 0.06269236478293616, 0.07656766116739282, 0.0029356410255610586, 0.06167748214436635, 0.05989908180650204, 0.0750781027900596, 0.014692118481522607, 0.06247460046001981, 0.025154368674022057, 0.03812682086361512, 0.05788836147516005, 0.06965158792633204, 0.11023054515281994, 0.13986451911830133, 0.050170416342875654, 0.009271187441153152, 0.02653104974137199, 0.1834029812485941, 0.1593562473933543, 0.1361129559095829, 0.0432467052052098, 0.09329471601954392, 0.26722924122887276, 0.31607801034565897, 0.38539165390595315, 0.1460263634761495, 0.18174456943187023, 0.1031940658727, 0.09110871477112656, 0.04086471185268414, 0.11443406193246765, 0.1665806557021795, 0.17818976824562396, 0.08341796576015412, 0.12077867188641142, 0.06047200066067519, 0.05840904845465576, 0.05523958566388296, 0.04186722983215605, 0.058664515794765566, 0.20401197215241773, 0.12525585825524985, 0.10363279676605618, 0.08727749374004141, 0.01613409130743915, 0.09651995384164395, 0.0419736011404424, 0.07734088137024835, 0.07377462716953409, 0.03431421576909, 0.11003746801326353, 0.03711157050284167, 0.07811266132780621, 0.03702521324157715, 0.08782535385821136, 0.09952128714611454, 0.061348861068367004, 0.113658060830447, 0.08054636178478118, 0.05175343361653147, 0.1110168194939052, 0.022115104441200534, 0.07545342458592308, 0.021245104350870656, 0.01046559320867903, 0.06058350858849384, 0.0074658035713758685, 0.13760754748457862, 4.078997277444409, 97.27513328675302, 97.97886140884893, 71.35956287384033, 43.51646915558846, 24.550520873838856, 105.11643763511412, 97.41109832640618, 30.17429363343024, 69.71004932157456, 32.360965974869266, 1.7682602448809532, 0.15329247761157253, 0.10424878508333238, 0.37437760781857277, 0.26759941491388506, 0.46921491082156863, 0.5305283288321188, 2.076328714047709, 6.585645300726737, 6.74469348884398, 29.677529373476585, 38.40129444676061, 35.19407826085245, 10.083472344183154, 0.6932665479760016, 2.2228248273172686, 0.7248437116222998, 2.6607584376488966, 3.064529919816602, 1.392484189521882, 1.866934943583704, 2.3282851038440584, 3.982427052913174, 4.646094537550404, 9.834947047695037, 17.112769580656483, 26.41823587879058, 41.76624874914847, 53.85056526430192, 69.27894946067565, 70.47823767508231, 69.85451021502095, 62.84659185717183, 72.06492270192793, 69.33296834268879, 74.05634141737416, 61.0404541415553, 65.36485941179338, 57.638786454354566, 76.35486602783203, 7.375984259190099, 0.6073879078030586, 72.27201600228587, 72.32578385260798, 77.47823284518334, 77.26958628623717, 81.30506976958245, 80.97085245193975, 87.07720618094169, 85.9665870666504, 84.90841004156297, 84.9481201171875, 88.7491164668914, 84.55513000488281, 93.47283471015193, 89.32443403428601, 89.45949692879954, 93.45272079590829, 96.26142809467932, 85.00820298348704, 60.75947515426144, 39.562555282346665, 30.076679568136896, 21.51407095693773, 13.27244656701242, 4.346883393103077, 1.5877584079580924, 2.516363734199155, 1.4174258060032323, 0.8140531795159464, 0.2498230647536055, 0.31248125818467914, 0.23993823226661454, 0.06020467810993714, 0.21940525260663804, 1.0718510203784513, 0.1822832518167073, 0.8010184079889329, 0.48065137779039724, 0.31420455764858957, 0.09131209579326453, 0.39620679292467337, 0.03236576306423353, 2.532595237416606, 48.64726274244247, 57.36201224788543, 15.575520146277645, 88.96726300639492, 74.38902901064965, 12.417379675372956, 28.271571474690592, 35.01989756861041, 67.33578374308925, 53.04433776486305, 0.8610210495610392, 0.07311137888820902, 0.0841625266137623, 0.10525358600481864, 0.1455042439122354, 0.006413616760138182, 0.0789052022681121, 0.062335973019681634, 0.07902821300611382, 0.06717904681159605, 0.14182051012833274, 0.038602722343057394, 0.13226598411077453, 0.06978271153545187, 0.11571827810257675, 0.1016962107631468, 0.08538185513668484, 0.0669449609854529, 0.09077588021154366, 0.20249969926812958, 0.13013305743375134, 0.12309239531356482, 0.07911285039998832, 0.13928347207125158, 0.29962228851452954, 0.22916417088239427, 0.1742650998095351, 0.33460318080840573, 0.1695994251678067, 0.0948764730785643, 0.12485966822432897, 0.06400511006734545, 0.049475421377968405, 0.2629983214841735, 0.20749537394412104, 0.1599467326436312, 0.1973853422509086, 0.2761191400068422, 0.12390173656205017, 0.21942645792038212, 0.11379727432804723, 0.13112255191851047, 0.12329514048272565, 0.1823584050420792, 0.2245531949184595, 0.19428460137738338, 0.1356479711830616, 0.06849894735721812, 0.15879910228954208, 0.15263341217031404, 0.218741468063766, 0.25884146711999373, 0.12099273983509311, 0.16242470532175035, 0.11628168214473034, 0.26517888350832847, 0.19492118979894346, 0.16509334196246442, 0.20740741172865515, 0.2536884073408381, 0.2658044709072959, 0.27177726008719016, 0.18337842046974168, 0.23439131136382782, 0.20069144065341643, 0.16039697783848933, 0.07872876455827106, 0.161743683800582, 0.12682246209512796, 0.12752078188162658, 0.20505107849115328, 6.828049738560954, 113.79055530794206, 114.06734912626206, 97.18066692352296, 92.50616658118464, 31.356554838918875, 72.72420252523115, 126.02147040828582, 54.98592668964017, 65.86414183339765, 41.31134402367377, 1.8914285518469351, 0.5195504727382814, 0.3604633673544853, 1.0864554754187985, 3.790074019662796, 2.3809944045159126, 7.827504959798629, 12.907603383064272, 21.003917686400875, 12.114837458056789, 27.19978382510524, 40.24206276862852, 36.64343718559512, 12.580328660626567, 1.3470440213718724, 7.967449243991607, 5.163053120336225, 10.607913828665211, 8.448244064084946, 2.31404003597075, 1.2544491190102793, 1.2627951872925605, 2.819610016961252, 2.6234326727928656, 6.708448336970422, 17.70485724172285, 31.99177484358511, 52.634430470005164, 63.06079641465218, 81.47229609950897, 79.7119991240963, 77.83977339344641, 64.92917037779286, 76.85065361761278, 76.42788487095987, 78.88858379856234, 65.32284298250752, 75.09922904352989, 65.22401494364586, 86.74518539059548, 7.966585341961154, 1.104396274012904, 78.94859606219877, 80.89187160614999, 82.67036837916221, 80.82614052680232, 87.88844646946077, 84.34319649973224, 89.30474373602098, 87.73687824126213, 87.49174579497307, 86.80240492666923, 88.78669277314218, 88.16505985875284, 93.97610618222146, 94.0369656778151, 95.90730867078229, 97.57513184701243, 104.1949002973495, 89.6631306986655, 62.32330060774281, 45.19265482502599, 34.175011188753196, 23.888834676434918, 11.758831374106869, 4.23274242108868, 2.119611333454809, 3.6760914133441065, 2.1805159363054463, 1.4726014194949981, 0.584913646021197, 0.705926733151559, 0.3688832252256332, 0.45346855576480594, 0.7561589344855278, 2.323419893941572, 0.5623784036405626, 0.9040160489178474, 1.6289794541174367, 3.287553926629405, 1.1252261433870563, 0.5821930532974582, 0.11260963120167294, 1.870903156457409, 43.9077098907963, 45.16399014380671, 34.8773507918081, 130.34221218478297, 48.109466568116225, 16.63152810065977, 66.12646995052215, 51.46692914347495, 74.3941516260947, 72.1101946984568, 1.4998095530656077, 0.3176991443239874, 0.3180029135077231, 0.20339291182256516, 0.27250626935593547, 0.12801326150375028, 0.17315634075672398, 0.2868371390767636, 0.24334496397885585, 0.14362452461594535, 0.3110942406760108, 0.13038381333312682, 0.2769851564399658, 0.18693954954224248, 0.27954980430583803, 0.19835619015559075, 0.23017758263214944, 0.20000853455595433, 0.24990613932811448, 0.30640149248703835, 0.2695068206277586, 0.30968074716867944, 0.26483947591435525, 0.2941685392250938, 0.3181279390569656, 0.3102995010633623, 0.29169474938704126, 0.3355934567028477, 0.20430720711667694, 0.15997786645687398, 0.15341450009615193, 0.1467183400546351, 0.15695172722541517], [0.13798797142601785, 0.0828969570237302, 0.29659636378768955, 0.12187506628012466, 0.04178481792370158, 0.06361294199802703, 0.01586328018381591, 0.19547666483108075, 0.05277834817646973, 0.07830956124610479, 0.18990326792963091, 0.14480627652618194, 0.039970629788454504, 0.05850888120250837, 0.009101641649800924, 0.047333159919587836, 0.04750263772063679, 0.24203527538526445, 0.09837593207316053, 0.09551554362499907, 0.08671353811458235, 0.07199105190774126, 0.17410354718806284, 0.10669029963713501, 0.13542148494912734, 0.04096402749118786, 0.012878621740627193, 0.07349177218613125, 0.03213135165072257, 0.08625962335856692, 0.054668455625013004, 0.02934106982373182, 0.09643239765277795, 0.025298082938177452, 0.06550426369593029, 0.061548185654945915, 0.043988385568222696, 0.049338674683484345, 0.2875749123913627, 3.012565379181216, 71.8342794910554, 97.50324264649423, 63.74589327842959, 73.1852771389869, 20.743772368277273, 26.603650239206132, 103.15172241580103, 50.77099869328161, 42.264801609900694, 46.92415375863352, 5.951248013204144, 0.20895391342140016, 0.2744799569970177, 0.0657398663761635, 0.22210617219248127, 1.1700182624401585, 1.1180797075071642, 4.264310146531751, 11.27517959763927, 15.45099469923204, 15.585220167713782, 18.025864016625192, 13.752820222608506, 5.636732760936984, 45.7363933901633, 63.24422213339037, 44.315106868743904, 36.43726956459784, 5.319405169256273, 0.6513535712034472, 0.6858885083948413, 0.8106690933627467, 0.30392273839923645, 0.4341568887954758, 1.264025585785989, 1.7672936257816132, 5.84507288471345, 13.468506240075635, 24.30070315637896, 46.142472451733006, 59.96154739010719, 67.55214952653455, 63.58963781787504, 57.97854608105075, 67.058119158591, 71.08129424433555, 70.04756927490234, 69.0809952828192, 30.218541891344135, 0.08558097670996383, 0.3861238194569465, 40.81279900766189, 61.106550001329, 66.16064163946336, 74.0189455401513, 75.1062265519173, 80.47599838626, 78.52007712087324, 76.25956812212544, 82.00869591005387, 87.37266263654156, 86.63495894401305, 84.17567206967263, 87.30526847224083, 86.06105342988046, 84.25100511120212, 67.0680505998673, 50.2242281360011, 37.20210429160826, 21.75796001188217, 9.265215916018333, 5.467465327632043, 1.5616163010558777, 1.609321270258196, 1.6734320430024978, 2.041074205790797, 1.1728546263710147, 0.2412772313841889, 0.0575471957094006, 0.11502236383216036, 0.023537478822794174, 0.013369465765032559, 0.02977910549229672, 0.030958961334920702, 0.5335765007522799, 0.2738670560140764, 1.1539479441219762, 1.219182966216918, 0.4320344881665322, 0.1326701874213834, 0.09398459351711697, 5.26244499991017, 46.38212926926152, 29.247465018303167, 39.636660622012236, 94.0047473292197, 21.409502529328872, 14.86624579275808, 81.89629647039598, 46.35354303544568, 62.9204696993674, 55.33675524496264, 2.917016932079869, 0.08599083374945388, 0.03852507933193157, 0.05065034744479964, 0.08788452648948278, 0.00791133110103528, 0.07067066872672689, 0.007379505203120531, 0.07280449938750075, 0.06635184805359572, 0.07121208604545363, 0.02899380408287529, 0.06414478704813989, 0.06533062220701287, 0.07439269924596434, 0.0845727130710598, 0.09041530560822257, 0.10797895911720493, 0.025489993708869143, 0.04780669418734409, 0.006667554797229147, 0.13250492693435761, 0.03731112491579787, 0.05564926267271081, 0.08208413007518939, 0.2663608958884593, 0.2156679233115527, 0.24738888166123824, 0.26435098761031706, 0.3022283357718299, 0.19681151175210554, 0.08799430688903218, 0.08898138053595059, 0.13302945201435398, 0.11930936121291692, 0.15506074643663822, 0.20241461754325898, 0.13871460582219786, 0.088491176194962, 0.045197306786693876, 0.052359753904203256, 0.0829270566182752, 0.09920360580567392, 0.037622708196361224, 0.20443356565890775, 0.09741066128856714, 0.058620228251862916, 0.033265334148440635, 0.045017582559657675, 0.025384288897076925, 0.03241151766551118, 0.09543737967408474, 0.09952307979185736, 0.04089642789274935, 0.05354565418054981, 0.03719654497540286, 0.055332439350745374, 0.039814198464756055, 0.13991722596749184, 0.027179020314267086, 0.08000908134084556, 0.01599445454626074, 0.07974816711559411, 0.06162448801220425, 0.09692057952164643, 0.044180788550405733, 0.07423354447969506, 0.02942540844331586, 0.06703371993236004, 0.049544763826434655, 0.010270215890129969, 0.13413985049532307, 0.2989915530047109, 4.871330270844122, 94.1554997044225, 102.48939883324408, 64.14715174705752, 42.07218970021894, 17.274775235883652, 64.6772796876969, 110.70191629471319, 41.50805481018559, 67.68476486206055, 66.9754591295796, 9.256286640321056, 0.15484941342184622, 0.19880185414466167, 0.1139452059062258, 0.5417837539026814, 0.8358055413250001, 1.0935791125220637, 4.024673676298511, 4.929787805003505, 12.948484286185234, 14.701170882871075, 18.83920865674173, 15.033875146219808, 11.007826924324037, 36.136396315789995, 40.99388699377737, 45.68474361973424, 42.96245790296986, 7.380405750966842, 1.3056480620176563, 2.0555993554092225, 0.3376029972587863, 0.6956322887732137, 0.8302558165404105, 3.121088536516313, 5.898003309003769, 10.722183258302751, 18.591034412384033, 32.10925375261615, 57.57263960376863, 73.82175230210828, 79.06111317296183, 72.68882274627686, 68.53737831115723, 76.35481111464962, 82.83956373891523, 80.25536506406723, 81.16876740609446, 43.519508992472005, 0.05610226961453596, 0.6075986739127868, 54.716149991558446, 73.49269682361235, 76.37023387416717, 80.3684626856158, 83.29429195773217, 91.11654927653652, 90.50054888571464, 85.4013107668969, 89.7306582235521, 92.43284179318337, 93.22949086466144, 89.83779384243874, 92.27776696605068, 94.85852964462774, 97.39853105237408, 82.0189489856843, 61.732983896809245, 46.78112060792985, 26.339766902308313, 15.88078841086357, 10.075021597646899, 4.050763321499671, 1.9354027341450415, 2.4580998670670295, 1.787774771932633, 1.250561192151039, 0.17363002824206508, 0.07534428770023008, 0.06999828867734441, 0.030976043180412347, 0.0916289957240224, 0.0369076723713548, 0.04897140447170504, 0.7738565461289498, 1.1789964451905222, 0.25752790212150545, 0.3063437294575476, 0.5373225481279436, 0.1448611590650774, 0.06012267222808254, 9.122847607058864, 68.2411216920422, 40.75565007425124, 16.32572933550804, 94.55678170727145, 59.807402164705344, 11.627843822202376, 45.92147042674404, 42.69383045934862, 69.45378518873646, 67.62593715421616, 3.6062102212059886, 0.06598066313252335, 0.16608000192190372, 0.0713927372388782, 0.11400402613705206, 0.11180513928974829, 0.08142053705429839, 0.06405375282009763, 0.08273336660837935, 0.09755266334621177, 0.11386301999370899, 0.09985940771237498, 0.05222475005974693, 0.06084511612331676, 0.1304391861682938, 0.0469603164181594, 0.0729593180961186, 0.033466723341975486, 0.014558226422166393, 0.03671803496657841, 0.09784900147708193, 0.043493282094958334, 0.06442463896687954, 0.045367956702266975, 0.05313781195230061, 0.11621856416064887, 0.17109458364786642, 0.3239465300594607, 0.4051972943688593, 0.2672089552206378, 0.2540051540540111, 0.033336649273311904, 0.1107316432640918, 0.030025751329958442, 0.18121244475966503, 0.1656858496848614, 0.40529786639155885, 0.17897971214786654, 0.30569531263843663, 0.272123470541931, 0.1224776557196052, 0.192991919935711, 0.13463569324343436, 0.1618185305907842, 0.40113129803249914, 0.25887511370162813, 0.14803945868005677, 0.274374236863467, 0.1711795581204276, 0.1786292269225082, 0.1333169954558534, 0.28897314542724245, 0.23655719514335358, 0.12074732356854986, 0.13005649460659874, 0.11695917966144702, 0.2798942987236285, 0.32797118829142663, 0.2270491859845577, 0.1604199911197347, 0.15753211543685006, 0.2102860024258975, 0.2096659615035019, 0.21402417441769955, 0.15122105247311055, 0.058563874824152845, 0.17270886880015174, 0.13762576505541801, 0.17230474209833532, 0.17592363420032686, 0.12919319012472708, 0.43354616350223946, 0.39867779420268157, 7.746165788942768, 107.60036483887704, 118.83302104088568, 86.08946707940872, 94.73841882521107, 30.274161100387577, 37.943938239928215, 120.8428748961418, 63.21621641036003, 63.044757843017585, 68.33423875993299, 10.638124904324933, 0.208777851094642, 0.27477526857006934, 0.34105183316334603, 0.9636346046482364, 2.995795285509479, 4.107583511260248, 10.053679000946785, 19.015974190927324, 20.612594581419422, 24.936611537010442, 24.390798038051976, 23.380171906563547, 15.260582258624417, 55.41341796998055, 76.98670494940974, 73.89856799956291, 64.57886742007348, 9.01379983271322, 1.2274923848529016, 4.7768408636893, 1.206523761633904, 0.6576555330426462, 0.7602495375660159, 2.1929831898981527, 3.494467043107556, 7.915609728905463, 15.713892540624066, 32.029666900634766, 62.415801863516535, 83.72238728307909, 89.70401748534172, 82.39996017948275, 82.55658042046332, 90.71903274905299, 98.56542833389776, 92.58826963363155, 89.39435420497772, 41.47050988289618, 0.2113622640289607, 0.9763239624519503, 63.32918851606308, 79.24795135374993, 81.86035971487723, 89.76404543845885, 89.28137425453433, 94.12299894517469, 92.78232497553672, 87.0468548805483, 87.86834824469783, 92.54131101792859, 94.05381618007537, 88.0664828515822, 91.57769449295537, 94.35976105351602, 95.30207910845357, 79.7530741845408, 57.81682675884616, 43.96613359451295, 22.927602952526463, 12.824360882082294, 7.553469548302313, 3.498156522550891, 2.9651265182802757, 4.229047058090087, 2.5759160999328863, 1.4135670517721486, 0.19832455072431796, 0.13018253139190136, 0.1646793633699417, 0.09439369212956199, 0.16927690215168462, 0.1548179272081583, 0.14597148093725407, 1.4351843369583932, 3.4393680384082184, 5.764489750708304, 3.2370901828812015, 1.1388443674772017, 0.2657171981709619, 0.29059728247023403, 8.234155216524679, 64.86779705170663, 40.296124796713556, 45.234255483073575, 115.97005951789119, 39.628804114557084, 22.700672265022035, 96.07124805450441, 61.63301444822743, 78.82211531362226, 83.36818156703826, 6.0412762145842285, 0.2255469794955946, 0.21088612506226187, 0.22819762839184654, 0.2753860551503397, 0.29187520905848474, 0.21874332199654273, 0.17465511517178628, 0.33827004533621574, 0.2223572038835095, 0.12056772191558154, 0.2571658489684905, 0.26907741302444094, 0.15215373387740505, 0.23358284345557614, 0.16800366402153047, 0.14435437658140737, 0.21238027230626155, 0.10477250577100825, 0.1554478046995017, 0.13289881870150566, 0.22205484430155448, 0.12148615408448443, 0.13190255199949588, 0.16979535981532068, 0.3571842965339461, 0.3014889689943483, 0.43776078089591, 0.27912548352633754, 0.30472011335434457, 0.2450185443364805, 0.10678081292538874, 0.14276937130958806, 0.22872235265470323], [0.04014337112406089, 0.0475684485037721, 0.08749882420224529, 0.017227346655882655, 0.05381753495443733, 0.049725744437666676, 0.020524227105441595, 0.08911220537077996, 0.13135447737670716, 0.1820965715113186, 0.07754454584491831, 0.13888633209130458, 0.0812988746310434, 0.13359920692539987, 0.04347712530063526, 0.1340369495653337, 0.04675251506869832, 0.0965852168719134, 0.08395603527465174, 0.06333464523777366, 0.040502195216474995, 0.10563987817975784, 0.14260446322300743, 0.10285463529608904, 0.06927496378099726, 0.04543750216403315, 0.02490366257036165, 0.03691523748960707, 0.05689890912523674, 0.015131888381626098, 0.03715728296928349, 0.08381670686386286, 0.014815301589307286, 0.02001735077600085, 0.06819779053330421, 0.011790392886576875, 0.015551177878683854, 0.05159906689978896, 0.12539108809564384, 0.05273925854013332, 2.1161155210387323, 45.63109736288748, 98.57254351339033, 67.49149399418985, 75.44924566822668, 47.47463880046722, 22.576899913049516, 72.84503506075951, 59.52618783520114, 39.380047398228804, 55.488927518167806, 25.04882662527023, 3.357195854187012, 0.25601417367016116, 0.16936245885106826, 0.17809071307701452, 0.15925045065101118, 3.241689652204514, 4.991545523366621, 6.656820629873584, 11.561645000211655, 11.01085009113435, 4.879307881478341, 3.22228838359156, 31.29389301423104, 46.2030573814146, 33.55675151271205, 27.96544028866676, 4.602506218417998, 3.1153341743253895, 1.4909576216051657, 0.2968474874092687, 0.18194612716474842, 0.261969281540763, 0.23691520335212832, 0.4720946353289389, 0.12981882348896998, 0.4779521742415044, 0.8291765518726841, 2.7004221802757633, 9.625800386551889, 17.583787402799054, 24.908935293074578, 37.35623774989959, 37.026284048634196, 29.497212133099957, 14.43039398039541, 8.09628047289387, 0.2355153615316076, 0.9172427714351685, 0.7175628119899381, 31.40993045222375, 69.80858710504347, 52.697023653214984, 69.19082164764404, 64.72262620925903, 73.82321142381238, 73.74098285551995, 87.69010005458709, 84.77018571669056, 85.02212739759877, 80.01155053415607, 82.4752853762719, 72.65705939262145, 54.738095652672556, 30.941013059308453, 19.614569064109556, 15.615510671369492, 6.289470070792783, 1.0031492972085554, 1.0935332698206748, 0.8825042387170177, 0.5083521058963192, 0.30058274826695847, 0.3847410920406542, 0.06543485612999048, 0.06901161339614661, 0.042602628274189855, 0.06980201695114374, 0.051688450208354386, 0.0628879891648408, 0.02259120701872293, 0.07315209646138453, 0.1589334434679439, 0.1292828224118679, 0.4968836164522556, 0.11866761701962641, 0.12465966564993705, 0.07033615643458982, 0.18116039674608939, 16.82187484156701, 54.98977061240904, 31.531672977632095, 52.01291914909117, 114.3562787578952, 17.895366760992236, 20.247639609921364, 72.50891931595342, 53.233168509698686, 69.76898685578378, 46.95341071774883, 1.8795626466312718, 0.24339734907111815, 0.0983026021370484, 0.024910009608814315, 0.09238722358619975, 0.07993092505081047, 0.022258211580675938, 0.020997443446709264, 0.05290345799538398, 0.07872965322026322, 0.08666010348186379, 0.12483835565827547, 0.05595850172422587, 0.05728164282176764, 0.16002495022070024, 0.020259631827713984, 0.02748474876786913, 0.027920256346283902, 0.08905752967562407, 0.021126697801293868, 0.025483876496793765, 0.06017794547181937, 0.09512468556603117, 0.00853091667992093, 0.10242598611981639, 0.06956923347447189, 0.023246882520916484, 0.20629512867139232, 0.08421192396311991, 0.044628344776649634, 0.1298601156280887, 0.06193049034223922, 0.1329770362785747, 0.06376544329067392, 0.03214200410330969, 0.04422529825880643, 0.0941583652409815, 0.022210107004690557, 0.06371498873998081, 0.024360349184022318, 0.08406621403992177, 0.035013646383078835, 0.07273692277169998, 0.14525367187396174, 0.18935454979298577, 0.1139371006959869, 0.11172055552202849, 0.020715691629917394, 0.09410440966847444, 0.1134847257766993, 0.11607031848642135, 0.11112669948488475, 0.09131806361819468, 0.043969210387477954, 0.06629110494207952, 0.09518595727821512, 0.12542772242018294, 0.13090242421434772, 0.07812644324956403, 0.13685667406647437, 0.044569739050442175, 0.060670559159329826, 0.08802083651385001, 0.06851551783902031, 0.015263121158275154, 0.03197927936731327, 0.11239963117986919, 0.052337407119452, 0.03673879977976603, 0.028985227728562973, 0.043202973076052247, 0.011251641553826632, 0.029181685231085268, 0.04681306282779382, 0.1272874238390115, 3.307607044135371, 67.93194478557956, 104.4858774062126, 65.42117288035732, 44.67042653791366, 8.020816031963594, 46.73774703856438, 109.24302993282195, 49.18156016257502, 46.44706018509404, 74.28165804955268, 34.62259677148635, 5.4828052270797, 0.17291522224343595, 0.18409048387360188, 0.20690358634437286, 0.48738605673274693, 0.7727777717574951, 4.298116564750671, 12.33566003461038, 10.32034427888932, 12.208006497352356, 12.551466880306123, 5.264744979719962, 37.53796115998299, 61.45942603388141, 36.5150736993359, 33.17779171851374, 10.160291964007962, 3.249445894072133, 2.9716236793225814, 0.15603234510748618, 0.5208664279310934, 0.34926224259599564, 0.3872017051664091, 0.5803120929387309, 0.35814886251764916, 0.84241314160247, 2.1097916797284157, 5.010058620283681, 16.447129634118852, 27.288894191865, 36.12311124801636, 56.0589224292386, 50.72850765720491, 39.972548869348344, 22.99023339825292, 13.824573120763226, 0.20993617603615408, 0.8472592299503665, 0.8476788622717705, 41.546988256516, 78.53283266867362, 61.569519119877974, 78.43753476296702, 73.8926609100834, 81.5228868299915, 79.36296309194258, 91.22694830740653, 95.00167262169623, 96.95596218109132, 91.9901866297568, 92.29774751970845, 87.34027954839891, 65.79066407295966, 42.43788796086466, 27.444545607413016, 23.641805764167543, 13.287505526696483, 2.47113831581608, 0.6602992718258213, 0.8543525912588643, 0.5936426356915505, 1.773658774552807, 0.6653063612118845, 0.1000100895462017, 0.070859540043579, 0.007613533093864399, 0.03210759334897082, 0.04999171484321837, 0.10170395591206129, 0.029601055167375073, 0.1289655394371479, 0.0366786235733138, 0.2723593949790924, 0.6317998817370785, 0.36836231608063946, 0.2655719785440353, 0.43608945283678274, 0.7004600522979614, 27.759031441903886, 68.0523850840907, 33.42582671873031, 34.47750045407203, 122.72048996340845, 44.53990967042985, 11.562848187262013, 45.292769401304184, 53.50443178607572, 75.21096952499883, 59.25522265895721, 3.0940283498456402, 0.19568425933680228, 0.07979096078704442, 0.027563866498249195, 0.18013173984664102, 0.17340512014925483, 0.0320790795564291, 0.05669318387405046, 0.025125925744613333, 0.023557854846360225, 0.08993165897986583, 0.03254878529978376, 0.062162109365266185, 0.02318389094134252, 0.03477278833968505, 0.04663663277883203, 0.03134382475588111, 0.06538413344852387, 0.04887275916013507, 0.021721532515760873, 0.03363862581130478, 0.04984651819892949, 0.036932704294280666, 0.026578154572616183, 0.029429413167940035, 0.0557112391857851, 0.039598908605835134, 0.11141124752260025, 0.16573726950633913, 0.07299350860017924, 0.10823638764240089, 0.09668856213289885, 0.13458352265579088, 0.041253876857339375, 0.04528562140260493, 0.14060215453707403, 0.1381316588770959, 0.22414097832816265, 0.2225193387318042, 0.15935063962974857, 0.12508272238436247, 0.1391288448846148, 0.21450547681700802, 0.22557123383927732, 0.26196128358283355, 0.14365297712145314, 0.1860678793802377, 0.14967358550958096, 0.2312209330979855, 0.26186190665729586, 0.22463326642830528, 0.1981663229244371, 0.3029496841613324, 0.1306573680091289, 0.1938298209420135, 0.2576254710795418, 0.2499669054222684, 0.20805582854776614, 0.20946366832621638, 0.16021756004662285, 0.09315026248054159, 0.18930763456850283, 0.11339275692138942, 0.3068970900870139, 0.10961995009453067, 0.16790171304056722, 0.18592751675075103, 0.18704940655058433, 0.12020239756712991, 0.1259171147079718, 0.11835633251335352, 0.11994032654911281, 0.12140692527135535, 0.16766361291370085, 0.24676511755153058, 4.058289614415938, 83.09899714685257, 124.34401389091246, 89.08089407028692, 98.50966791952811, 61.06413349028557, 32.634770947117964, 95.11648824138027, 74.90384794050648, 50.58240721302648, 83.24781187119024, 40.46439055473574, 4.541880103849596, 0.21213443469135992, 0.24244248176053648, 0.21497826031859846, 1.9004602994649642, 6.036688022075161, 10.233418672315537, 18.99711739632391, 14.126674071435007, 15.832447159674862, 10.385945920021305, 9.957044547603978, 37.32651402873378, 63.14266804725894, 47.90773907015401, 40.68231351913945, 7.10191305606596, 4.765446868634993, 4.038728754366598, 0.7204989512120524, 1.2312486671632337, 0.3853099889332249, 0.5363468585475799, 0.9195969902699994, 0.3861894885138158, 0.9156219132484928, 1.2092181847941492, 3.0087758792984873, 11.738437990988455, 23.879775962521954, 37.27446809891732, 58.02554392045545, 48.53061929825814, 35.634964435331284, 18.858716564793742, 10.320997353523008, 0.24385678732106764, 1.7256289840705934, 1.2317219256393372, 44.53262582901986, 93.32203526650706, 65.64763092225598, 81.85642165522422, 75.49630626555413, 82.82410960043632, 80.47317427973594, 87.99261677649714, 92.98128328015729, 97.3083165384108, 89.60352636152699, 89.31153728115945, 83.1080735114313, 63.91818731061874, 38.42266351945939, 25.407086110884144, 21.621414461443504, 12.432337634025082, 2.2601351478407463, 1.1353554192089266, 1.1633618776836705, 0.6501115894606037, 1.3008331074830026, 0.4473127022145256, 0.15271464813380473, 0.15043602685534185, 0.17784135145766122, 0.17069696869340636, 0.18757770078316813, 0.19196071962435401, 0.1320608717299277, 0.4292371027892636, 0.30054579218549116, 0.5430541728292743, 1.8767278761632982, 2.4966359282693555, 0.4023702767106795, 0.3586297818729955, 0.48843624070286756, 24.424365681986657, 72.02170602736935, 38.86149044959776, 61.20189105310748, 131.61002420609998, 33.641419795251664, 31.409581361278413, 88.94297569028794, 67.55916272440265, 85.34667215039654, 73.93159435641381, 4.381229627516962, 0.3116576217355267, 0.17324658591420422, 0.10214886147408717, 0.30037492393485965, 0.2804161884611653, 0.15118326901668502, 0.18775057618416127, 0.12065035981997368, 0.10905623961720737, 0.24850606768121644, 0.21064347437312528, 0.16198849485766503, 0.11438365334705, 0.24360475971573786, 0.13008249563074883, 0.17504300080960797, 0.10611681387789788, 0.17213425689166592, 0.09976886378060426, 0.16265394947221204, 0.18610149531835513, 0.21315823459336836, 0.13228415571633848, 0.1483254086586737, 0.1103330170735717, 0.1487623698889248, 0.32172931838900815, 0.2150996852545969, 0.14497821729990745, 0.17026802074284325, 0.09202800495850463, 0.23296773613941288, 0.16603451162095995, 0.12575406055416793], [0.024201979657875437, 0.03259940838982021, 0.13070596862704525, 0.0677119299108463, 0.02051959610393932, 0.03841516486699543, 0.06677275974183314, 0.19035896767050992, 0.09737389672908092, 0.13133774601644085, 0.10370024314690983, 0.17226230082733018, 0.113394258453721, 0.10018332500851924, 0.057629442908951355, 0.12717770472649606, 0.009366987693694331, 0.0423933828489915, 0.019225748293402217, 0.12890512574343913, 0.04938478934608641, 0.042952807064378457, 0.037309458674562555, 0.039252495137794365, 0.04473524468560373, 0.06180132408776592, 0.06991581931229561, 0.014585734724307494, 0.015279701216176394, 0.02666210440257865, 0.017801753635848724, 0.0851550011805469, 0.030728794048510255, 0.0364925101729891, 0.054919839716486396, 0.0262865929999539, 0.012232768443232823, 0.02429376465208348, 0.05149916137358354, 0.10038815393683412, 0.1658120243659904, 0.27936906884274176, 41.305433011824086, 103.76460059996575, 69.27317573178199, 97.76178175403227, 65.64847030947286, 23.546315662322506, 71.2697405968943, 86.7340301698254, 47.21143991716447, 48.02408049183507, 34.503262581363806, 12.607774465314805, 1.4280531002629189, 0.37634020250651146, 0.07805774814539379, 0.6312670522639829, 2.6953392788287136, 2.453676659253336, 1.7229696170937632, 0.4083735561899601, 1.3747933194521935, 2.765797059382162, 4.53976349484536, 28.224138252196777, 24.55100920892531, 3.2439408475352876, 4.974852896505787, 5.494935647133858, 6.561212366627109, 0.5153247930349842, 0.04768699677961488, 0.030399583084809206, 0.0573722671927704, 0.126964824214097, 0.5286279404836317, 1.5523478629127627, 0.2376047284492562, 0.8296131607024901, 0.41626548755072784, 0.0915039854965383, 0.0687873947824682, 0.6179064175774974, 0.13315663793154303, 0.16747697857358765, 0.09204383999589952, 0.1882655558086211, 1.061481989679798, 3.070399501631337, 0.23288758802077464, 3.518468761636365, 69.48569759245842, 78.48698800609958, 86.96312796685004, 85.28197657677435, 94.87643134209418, 98.65163418554492, 86.99241238255655, 77.92020551619991, 64.84698103320214, 49.44152309048561, 36.6216915653598, 22.576327247004357, 7.437263938688464, 2.2722800316349154, 0.9657781799474071, 1.2818644027556143, 0.7678185475449409, 0.3991816655522393, 0.06310392253761811, 0.07656726280167218, 0.037873046577817975, 0.07150359782240084, 0.05492063644792765, 0.028124863109100732, 0.07243057187165945, 0.020056189518542062, 0.051303004560571526, 0.040813782327477975, 0.15638279968932753, 0.014172781731993442, 0.07728130271237704, 0.0898438346602263, 0.1978355108369743, 0.14368181267092306, 0.07471046485607663, 0.09767887633173697, 6.055318790097391, 28.04675102233887, 51.14701278748051, 45.90292546056932, 63.09323833834741, 81.83482508505546, 31.076140672929828, 39.819278332494925, 73.6215780627343, 46.771628472112845, 68.2196584824593, 38.016553078928304, 1.0346287080357153, 0.2587137449412577, 0.2120586839174071, 0.07047602876780495, 0.13900876826336309, 0.06997028816371195, 0.08706066021395308, 0.04910764554815908, 0.05740381469349227, 0.010759561255033459, 0.06635632200707352, 0.03880392001461118, 0.1256849900669148, 0.10532235005690206, 0.018063922330076178, 0.07771664749710791, 0.08464769009620914, 0.02929255156026733, 0.06706066324465698, 0.004173874443832545, 0.06668629905869884, 0.07592950992646717, 0.09135345688029643, 0.06284947792488722, 0.03714341677785401, 0.037962441377702265, 0.01478672746734153, 0.022092106481713635, 0.04018449472383626, 0.028068547985786875, 0.02311232683789586, 0.03780949958449891, 0.047926540982218525, 0.039902363693521875, 0.0205781884236081, 0.04954428119104236, 0.07393291625644892, 0.10992984032078136, 0.07325302854540848, 0.03219987055467021, 0.020455344309729916, 0.019257879936166348, 0.02979647270554016, 0.04539236809397417, 0.08852867619885553, 0.2104923711909402, 0.0580377409595155, 0.1571048069144449, 0.07285932063936226, 0.1076714973896742, 0.1384922717848132, 0.11776422315667714, 0.07665783737695987, 0.19680403473396457, 0.014395314952238433, 0.050781624271504344, 0.04420723773599152, 0.025487496262235988, 0.08689349982887508, 0.02911412010660335, 0.017980395763691877, 0.09912061550083662, 0.05794146669007117, 0.00940156507215673, 0.01478111491568627, 0.07830615215484174, 0.033452259601965066, 0.046590594725022395, 0.0541293901962138, 0.019448882892667767, 0.02797564450320938, 0.1089483437939517, 0.01807635593708725, 0.03366012223846009, 0.013982866620344502, 0.08986460330385355, 0.19604542382782508, 1.3382101082994093, 60.65483024043422, 117.81234187464561, 67.30260049143146, 85.79095901981478, 33.61053113014468, 34.2453706649042, 107.67757277334891, 72.65032076066541, 48.793692665715376, 62.623142273195334, 57.66689415900939, 17.889716586759015, 2.053072000703504, 0.5889887434820975, 0.1733650843943319, 0.2534923654410147, 1.8232534681597066, 1.9501700901216077, 2.929537137669902, 2.582510339636957, 2.4028721595964124, 2.324539730625768, 12.024519981876498, 44.54533038600799, 33.23259899693151, 12.764465308958485, 8.200764079247753, 8.571950716357078, 7.7015414737886, 1.7590814083814623, 0.21821413910196674, 0.11737679717161002, 0.03369505584780728, 0.07393285496941499, 1.4881680809682416, 1.6439603341202584, 1.0450066866413241, 0.4753349421005096, 0.3892068636994208, 0.049828775602603154, 0.16235699847100243, 1.4192185743201164, 0.7211726795761817, 0.12435680044995201, 0.10660530218193609, 0.18163048361818637, 1.7512903554785637, 5.230969450166149, 0.17616620828067103, 5.587611938676527, 81.62013023130356, 86.8087983900501, 92.92441675739904, 88.99969316297963, 103.5383112199845, 109.7538088214013, 100.14166416660433, 89.99306478808003, 75.45806315637405, 62.452315207450624, 49.65005590069679, 29.811311614128854, 12.158308106084025, 3.5529235966743964, 0.8196646816307499, 1.2453102416569188, 0.704021870849594, 1.0632203351105414, 0.42041284242464655, 0.10652067244894083, 0.09934884841523825, 0.05208540632719955, 0.02671247276838028, 0.007697296189895321, 0.03611148868296896, 0.09586583732837632, 0.09140116883622063, 0.040607532306063565, 0.17015232614451842, 0.04338255174638283, 0.10517241898924114, 0.2955650868675401, 0.08285676805122245, 0.2672804159022147, 0.15470244711445225, 0.131978563243343, 11.941989391080796, 49.58586239045667, 65.23273437253891, 43.96323888532577, 50.07217745627127, 105.2254089232414, 50.920821466753566, 29.154802945352372, 52.647707693038456, 49.29752503671954, 76.68494916731312, 52.232795453840694, 1.8238540810923425, 0.21855314833021935, 0.05749245872721077, 0.06918221351600463, 0.051056454483900345, 0.03131032564617213, 0.10538653290319829, 0.026253948078280496, 0.0420134951690993, 0.06426488665202934, 0.09274397541077868, 0.05054566919082596, 0.09542226475933868, 0.026862413412140265, 0.028778740219892036, 0.02549041697244731, 0.0310422906336645, 0.05943708865332508, 0.027676261172840194, 0.07319384059237857, 0.037808794783608574, 0.06842591619539647, 0.08734095646368881, 0.07769081501230117, 0.01726034972366066, 0.025144524444195054, 0.04060116228497317, 0.03989793187487991, 0.08186797836735364, 0.053782551549375064, 0.025788513275103706, 0.00394045750820829, 0.012943813907763651, 0.027876307797287742, 0.021945565353117643, 0.07029499453041824, 0.18988881951137898, 0.15277694640380723, 0.187247792679456, 0.15711527167549058, 0.10155752586621432, 0.18407267999024163, 0.1618871567470412, 0.22154243873252025, 0.2565950521778676, 0.21986363365525202, 0.13171780223567642, 0.18656851783875497, 0.20191957152658896, 0.16447887816015752, 0.1577282186237074, 0.43952262990417024, 0.1522778094776215, 0.34357155763333846, 0.08494407419235477, 0.2361396925463792, 0.2784785069525242, 0.12424947153176032, 0.1567018293445149, 0.1668544095610419, 0.07052747923279963, 0.2682041340777951, 0.15158145087620906, 0.07743543194186303, 0.06012474449591772, 0.12740072058213334, 0.10950397970455308, 0.1732278474035763, 0.22757081525220027, 0.1304878480732441, 0.1861086352578094, 0.14303480545359273, 0.07838241620770386, 0.12628528890350174, 0.18470136238442314, 0.1822409790850455, 0.2850188140667254, 1.3538961569147727, 67.69322933689241, 136.5649740157589, 90.732007949583, 124.64526760962703, 81.33519357250583, 31.428496991434407, 89.98345498115786, 109.17285088569888, 60.77340741311351, 68.14992658553585, 59.29160264230544, 20.58159608994761, 1.9820371414384537, 0.4534082799669235, 0.2663051859746056, 2.2499573326879934, 5.724887540263515, 3.9364115220885125, 4.570901720754562, 6.357197146261893, 4.6206981712772, 7.798856458356304, 8.72262954711914, 41.87242730971306, 32.231969025827226, 8.953608120641402, 14.154841592234952, 16.728406721545806, 17.7286385720776, 3.560901207308616, 0.3613735104520475, 0.3697632151024957, 0.11031162789872578, 0.2708758197484478, 3.1992856437160127, 5.146825294340811, 3.243564545146881, 1.4127534051095287, 0.792395199739164, 0.48207706741748324, 0.3096997155056846, 1.31691936043001, 0.5989562828213938, 0.3045489386685433, 0.1374117966981665, 0.3022743929778376, 2.4344156153740424, 8.265210582363991, 0.5107907782639227, 4.422510122099231, 80.8003548652895, 95.43982490416496, 100.20356701266383, 94.17571560029062, 101.87053511219641, 105.76473482193487, 97.42761934957197, 87.26281273749568, 74.33748122184508, 60.66200425547939, 47.460294692747055, 28.769787011608003, 11.534494353878884, 4.043705751818996, 1.483722564674193, 2.7742191235865317, 2.7748910746266766, 3.54545172664427, 0.25106838663979886, 0.47431025353650896, 0.13976911052821145, 0.15294366245788915, 0.26371807641079353, 0.20949798906522415, 0.1829206829349841, 0.1699065804601677, 0.2195681995081325, 0.15197580229611168, 0.2376980073149166, 0.13584862493218916, 0.6089397567895152, 0.42157846052319775, 0.9586810188428049, 0.46502330670914344, 0.2754609172623004, 0.17133133545998605, 7.581947426642142, 39.6225675459831, 67.95257645268595, 55.99121055295391, 73.02711932889878, 101.13804032725673, 45.33711179610222, 52.89129080310945, 87.05568805817636, 61.84337900530908, 87.89764050514468, 61.47834754759266, 2.3996413523151032, 0.38052920191999406, 0.3862711534865441, 0.15359411707087872, 0.25397708459246543, 0.1671469785393246, 0.1662896648650208, 0.1551378761688548, 0.1434608422700436, 0.09764864650224486, 0.10842209501612572, 0.1707234446920695, 0.14656412655547743, 0.1643872387226551, 0.10034018917189491, 0.17072145286346638, 0.1624821465943129, 0.1324207185497207, 0.2717750843974852, 0.15571645641278836, 0.09704251773655416, 0.14843149651442805, 0.12166905757640639, 0.22208631519348393, 0.31690863351668086, 0.1933595348870562, 0.1125818298709008, 0.11770593918739788, 0.20319558289502898, 0.15568975058774795, 0.11078530772318763, 0.07966919111148005, 0.15796022069069648, 0.09107469280640926, 0.09446983360835622, 0.1554656851916544], [0.021002227665796395, 0.059144849092849804, 0.033365373740032796, 0.0483925101317225, 0.03714786774869408, 0.09074070911493995, 0.058224892408977595, 0.0816606290097679, 0.07703479860098132, 0.08718894163687384, 0.045050696710184704, 0.09704191252709397, 0.09673632771497774, 0.026379833561218074, 0.06861658781887063, 0.1175761868756625, 0.0681667333288539, 0.04884421472407637, 0.029429549148546594, 0.061684587609864054, 0.009171816261274921, 0.02904080549224971, 0.05226617243381278, 0.04142815036879432, 0.0947749970721141, 0.05950216399205308, 0.028035087180474115, 0.04120312736279542, 0.023085197749277277, 0.03215475946724896, 0.028706760513746453, 0.07411757408971749, 0.036485086781002825, 0.026654456929874518, 0.05817898459011509, 0.07197273474547171, 0.06597189908666957, 0.062244498291082924, 0.09292657246753093, 0.02963442212691711, 0.14468246139585972, 0.05845429743790339, 0.24370801304617237, 29.536949665315692, 75.92116955787905, 62.91410369257774, 58.15260517981745, 55.49191636423911, 21.817430988434825, 44.23744001696187, 77.62299183876284, 60.11894426038189, 35.493602214321015, 41.394309997558594, 35.31338891675396, 10.393064041291515, 1.095258009529883, 0.3289870821660565, 0.03307205016514467, 0.2086934282053863, 2.1398490475070093, 1.5572736244047842, 3.282313149782919, 2.3299158292431987, 1.8043056010238587, 3.578457000755495, 4.442234250806994, 2.627934818306277, 2.947898242742785, 5.779414369213966, 2.6979773179177315, 0.14551642471023146, 0.3259964587707674, 0.0081231041375788, 0.12377530141102693, 0.08037472744622538, 0.03821014441669949, 0.09060226936614321, 0.11788947087141777, 0.09612129700760688, 0.7269361122481285, 1.0323731000384977, 2.445266362159483, 1.0017590621306052, 1.79021816340185, 1.6670834417304687, 2.00078631601026, 1.1862158126408056, 1.1498650019207308, 0.4220242317645781, 0.4017857209809365, 0.12255070986406458, 4.467815458774567, 29.392982990511005, 59.313383563872314, 69.41738559353736, 46.65846809264153, 23.010257097982592, 14.09680522257282, 9.829818548694734, 4.7077066379208725, 2.9259682711093657, 0.9418727433489216, 0.2552091225140518, 0.3258259582423395, 0.7379143360641696, 0.6862915932170807, 1.179537609700234, 2.3204996893482828, 0.9481409360324183, 0.025445256089310975, 0.19224619462845788, 0.03894398386980738, 0.057560391573896336, 0.036378366902710936, 0.03711255492582437, 0.08895003987896828, 0.05115329565840864, 0.09447059203540126, 0.030717302729646047, 0.0206062866134509, 0.07852310825499796, 0.8120950587814855, 0.47004409374729283, 0.01649312798925225, 0.30322587417979396, 0.2080519368211108, 14.457280847334093, 29.047031902497817, 47.34534179010699, 56.18644652828094, 75.23542158065304, 73.76248528880458, 41.00993733252249, 59.822699408377375, 57.765953617711226, 52.5541748539094, 71.58414994516681, 26.292204241598807, 0.18033038644540697, 0.11428382442963701, 0.15835792757570744, 0.0929321878920159, 0.12295801583076678, 0.04724808968603612, 0.03126041693312507, 0.05571118939007002, 0.02698957443147177, 0.018304684612479423, 0.01152356542015989, 0.029136587550202687, 0.07175766322160922, 0.028842472989532738, 0.004119780975499101, 0.015819241619488646, 0.062019080749803016, 0.0137050113182575, 0.09304122518627875, 0.019073419370538285, 0.038826477473541614, 0.024964807878038096, 0.00932743648938354, 0.017405975377187133, 0.030500310240313414, 0.030502332712433515, 0.0020760367483636665, 0.05206386393476879, 0.06974256852821958, 0.04543979276692675, 0.034605578158891974, 0.047285022784865675, 0.02732262349567346, 0.037228341454700116, 0.08596313967099113, 0.03388694172064143, 0.029225109009853298, 0.026822287641886263, 0.09802550813483615, 0.016775647809188214, 0.038436485093928156, 0.05895934473242491, 0.06249525802089803, 0.06948684071821552, 0.03812821514363732, 0.14227259393420913, 0.04114973103447307, 0.04721457716978846, 0.09158152125535474, 0.10084621322851989, 0.0778521990944301, 0.07173399876562819, 0.0716035646356402, 0.01868933927448046, 0.014141349144460214, 0.04665558196363911, 0.01027971059234152, 0.022565451142708623, 0.033947251992480415, 0.028095182947694298, 0.012063252337787662, 0.02766325683032553, 0.03300356573515362, 0.03278817245436292, 0.04872336818446075, 0.030398589085727453, 0.01938928316737856, 0.03532763901016405, 0.05947473421392422, 0.004006096639768071, 0.02898309608891366, 0.04840223178748162, 0.023050386713997974, 0.07778071543021549, 0.007432760762786794, 0.08441112980607056, 0.031229265882904013, 0.10191714285963005, 0.15594517962346155, 1.1020482451685014, 48.725004119257775, 96.0480276230843, 72.81740588526573, 57.12437937336584, 27.247819131420506, 28.087722139973796, 86.37546277815296, 87.23583467545049, 57.537773655306914, 40.04284950994676, 57.31754825961206, 50.90870526529128, 17.45238996321155, 1.81900370265207, 0.33266497835997616, 0.01501505901556342, 0.3874755662775809, 0.2364546159702924, 0.5419926814013912, 2.5519700300308967, 5.289105349971402, 2.421716206496762, 10.09013056755066, 9.326415677224437, 4.005510446525389, 10.086622988024066, 11.688771959274046, 4.191952222777951, 0.4500557566362043, 0.0626080223329125, 0.12148855960056668, 0.10588400741858829, 0.14336145002274744, 0.19945263051457945, 0.09358143974696437, 0.10889353020296944, 0.017251704421435154, 0.32496073854065716, 1.4664370470469998, 3.838961951194271, 1.670825505448926, 1.2263135900420528, 1.9041112906509832, 2.612436798311049, 1.9750754246788642, 1.682438295214407, 0.24634199186919198, 0.5779916432596023, 0.16125444473037798, 5.99683968290206, 36.675447648571385, 70.69827479700889, 78.10168573933264, 53.474327595003196, 28.666916970283758, 16.82585604729191, 12.70051988863176, 5.714933055062448, 3.72112512588501, 1.3023260596298403, 0.47375385919886254, 0.5821141768847743, 1.1464378309826697, 1.2325333659687352, 1.416298492300895, 1.280046261606678, 1.6358161453277835, 0.0493747842377953, 0.16149044577633181, 0.03841687324306658, 0.05806384157509573, 0.06163359296718433, 0.015453363772511724, 0.011057196947325383, 0.05098482909341974, 0.08676508051012793, 0.0957663071852538, 0.05269461093590625, 0.08251678589130602, 1.7615183034250814, 0.44316314100738496, 0.05006393778227991, 0.5442809553877, 0.5962279066443443, 30.665246901973603, 53.347752709542554, 42.910733607507524, 47.803039243144376, 76.82207522853729, 104.31272045258554, 49.50281796916839, 44.9222505477167, 48.99712639470255, 56.691636039364724, 79.56812658617574, 37.40907992086103, 0.9162953964644863, 0.09257666946899507, 0.058430020111582937, 0.03625887633872129, 0.019647552474071423, 0.050063095085563204, 0.053585046421616316, 0.008906525758756025, 0.06174406284586557, 0.07629721680836332, 0.039274991309690865, 0.10163511525118545, 0.16098395440607302, 0.03412761207249376, 0.03502166732364605, 0.022919008380643303, 0.04044012294241017, 0.0742814249749626, 0.0338845017306026, 0.05895940218901923, 0.0204032426699996, 0.028478450990552386, 0.03503916860227624, 0.04257313771954468, 0.037566033011722955, 0.04733116426054509, 0.07630126941348277, 0.023398250003435442, 0.02429412279818808, 0.0537002851976262, 0.08540663808103531, 0.056795732403594645, 0.0187697229651554, 0.04314308415257162, 0.04027847455994737, 0.030099039131234732, 0.05239789742195318, 0.19884342207543312, 0.10955946745290872, 0.13186460000372704, 0.1329899371992196, 0.08607123467710712, 0.167999358607396, 0.2694171883406178, 0.14767648622153268, 0.2817170976871445, 0.1537520384355899, 0.11766367411661534, 0.18487259835725833, 0.18085224553942683, 0.2295689104545501, 0.11684923838343352, 0.19144489730317749, 0.13704101014281475, 0.21045737629455907, 0.06251591941221588, 0.22388302120229892, 0.15490475561349623, 0.08681204936076557, 0.11850666960761433, 0.1499696325270399, 0.16843244343275027, 0.09656333740079596, 0.19119953466278894, 0.20867283576198165, 0.05996954274333774, 0.11304097700743906, 0.07264608006563879, 0.20985645692675345, 0.13941827290240796, 0.12151724959333098, 0.28261069328554217, 0.2023367830101521, 0.20625313173138327, 0.12541313610610463, 0.2289970717843502, 0.22459719900883016, 0.22639871604980963, 0.16578951670277506, 0.9371521708465392, 50.70696992258872, 115.98054793573196, 91.4146258754115, 80.46998147041568, 76.76425949219735, 28.235921052194414, 62.64053406253938, 101.99127351084064, 78.95961792238298, 47.41939221659015, 59.453510238278305, 54.9547242349194, 17.118829642572713, 1.6826561093330386, 0.4064095825437577, 0.18268140303271432, 0.6919173139237589, 5.761012079254274, 7.511809074109601, 11.191739997556134, 7.78170834625921, 5.534382923956841, 6.0035042801210965, 6.203169591965215, 4.876620077317761, 11.90494848835853, 11.936064650935512, 9.35381833584078, 0.9647163207973204, 0.39234390181879847, 0.19092467763731558, 0.2728366064688852, 0.2751629703467892, 0.1984666753560305, 0.17757865990842545, 0.3593035102371247, 0.5631417336483155, 1.2650845031584463, 2.554886802550285, 4.993805789178418, 3.301564632884918, 3.0021375129299783, 2.757629704090857, 3.5709172246917604, 3.074183608255079, 2.3108928242037376, 1.0235901164912409, 1.1374958075823323, 0.33727413103465115, 5.856442855250451, 32.19578319980253, 67.5347577371905, 76.31354778043686, 52.739079306202555, 29.84277882883626, 18.261739669307588, 13.38369773280236, 5.98490342017143, 4.721130459539352, 1.9236954397732213, 1.0571673824902506, 0.8889898165099083, 2.088172801079289, 1.883392228234199, 3.480700259247134, 6.47404553428773, 3.2429580486589864, 0.13485880869050182, 0.34351226242799915, 0.12549873877076373, 0.15192548564124495, 0.23470646461411832, 0.12962771519537897, 0.19533123069953537, 0.17118728028670435, 0.1829128994816734, 0.2976428092487397, 0.0719166954138106, 0.2839208874971636, 1.8207087079363486, 0.8601168206622525, 0.12861359864473343, 0.4213799518202582, 0.5176560905191206, 23.543175804999567, 43.069758261403734, 57.8713280923905, 64.77024770552113, 90.85002422332765, 92.93195555287024, 54.25973515356741, 73.34348986225744, 68.48033135937106, 67.82483270091396, 93.19870810354911, 41.35771428385089, 0.9425674318786591, 0.22828430357959964, 0.23222971767667802, 0.17681984981942564, 0.17950396143621017, 0.18814529532626753, 0.11541060953130645, 0.19367956045654514, 0.11299242235479817, 0.0661087453725838, 0.08601619125974756, 0.14155495341026014, 0.2264333585457456, 0.09615357229185682, 0.15729654340013383, 0.1419824917590426, 0.275575278867637, 0.14707412660842942, 0.11895977231043002, 0.1795737826896291, 0.09826935392113463, 0.12184249222158425, 0.1119890693394888, 0.09868050564921672, 0.10339438254314084, 0.2254186750900361, 0.17834686223537694, 0.11897466505967802, 0.1751907638484432, 0.2547451337018321, 0.1989224670274604, 0.3155228723922084, 0.0871856244761617, 0.11890571714649278, 0.20392143588152625, 0.21470249930937446, 0.14866795721313647], [0.030458771037839116, 0.03826489672064781, 0.07213211167723903, 0.0844130143823643, 0.014647163484515923, 0.1069057465440804, 0.021094326756053397, 0.054490512552400755, 0.043731650352598204, 0.0421612543774949, 0.08869956743212477, 0.028572497859356866, 0.02355030313464663, 0.022173809758838148, 0.03467657918771429, 0.043308045865306934, 0.06881423850333498, 0.030575229808868423, 0.06854803061052676, 0.044813458432233146, 0.024446265944730372, 0.05022805679829852, 0.019890940522835143, 0.07071529334831624, 0.042915632647852746, 0.07048694552072594, 0.0169623855711712, 0.03922348338810187, 0.07396602657653632, 0.02211389019184055, 0.05191597832186569, 0.03129666055282278, 0.053792886075473605, 0.018825861888246673, 0.04455810600531198, 0.03079291752299234, 0.04327402773102926, 0.08549173512766439, 0.02773435362013838, 0.05484719159862688, 0.05169602681792552, 0.0712025405899171, 0.06572094400443378, 0.12824785294792346, 12.582998814121371, 62.523412089194025, 77.24506362791985, 71.85517003459316, 73.60552772398918, 36.40867156367148, 33.6355911531756, 55.69738188097554, 82.33576666924262, 66.55618129238006, 61.56189795463317, 32.21895067922531, 34.53909343288791, 7.65836206174666, 0.34860785029107527, 0.139224452657565, 0.16954293384427027, 0.13802684272729582, 2.261697476910007, 3.7288737681604203, 0.4564844600615963, 0.2799964948527275, 3.030900008255436, 7.61599212884903, 9.555752738829582, 14.435810773603379, 3.2845204635973904, 0.0874593630132656, 0.2856371389521707, 0.2042012111914735, 0.04128421776958051, 0.044495351912994544, 0.11648989718167052, 0.06727712138766243, 0.03217658531221171, 0.0653230379365625, 0.11875050007215432, 0.07939321559763725, 0.12474946647642121, 0.04959064100178019, 0.16326228457112468, 0.10818800918998257, 0.11808535189277704, 0.06068945088754259, 0.03522641198228925, 0.03395923743805578, 0.03804941150930621, 0.2963809705068988, 0.2478276661807491, 0.1444998873217452, 0.0858813444633157, 0.271349415303238, 0.5180493694159293, 0.7244101671441909, 0.5598316209450845, 0.7088954770757306, 0.20627210006838848, 1.006199001304565, 0.856524910176954, 1.0933932902351504, 0.3069360379970843, 0.19691373852472152, 0.09381105161962972, 0.2742185371537363, 0.19989510757788537, 0.28313368618969, 0.02690722572527105, 0.026264838018124143, 0.05155836464837194, 0.024854671247603915, 0.07073602368754726, 0.0360837179957138, 0.07290406783501949, 0.008224601211446908, 0.18022422198086016, 0.13137159178093558, 0.15479128267015183, 1.6079239258843085, 0.6631534702835545, 0.17180342948244465, 0.1311397888968068, 2.6282326732912376, 22.380183242982437, 40.38146772692281, 61.825963681744, 60.42346139107982, 67.58714491321196, 57.645862410145426, 23.052391198373613, 44.30434388499106, 46.38115259908861, 57.25217019357989, 55.39794421965077, 12.40579789684665, 0.07188782155994447, 0.04720412390006166, 0.14386005068738617, 0.014009689273793372, 0.07026354662112652, 0.018398626144194317, 0.05399688762883025, 0.04344851191666338, 0.007617385558513625, 0.043250363275048234, 0.05639462025776025, 0.0681499483424329, 0.006589332910915536, 0.026120233176756772, 0.06373932352289557, 0.031060824215772654, 0.03790695745978625, 0.04934105721692886, 0.04810033185828117, 0.03695479443957729, 0.010904133537664049, 0.01181721841285546, 0.03609119501385478, 0.08344353777506659, 0.017037211293955485, 0.05254541531265263, 0.0358890320715164, 0.03754387391851314, 0.06890177937044252, 0.017173046343809655, 0.07099118459248735, 0.06101552855163332, 0.04010065406140301, 0.022259421999596303, 0.024466463852854028, 0.03380878926104596, 0.08536962837341332, 0.052099092487966826, 0.021107187457082253, 0.00864494024896093, 0.04837181043600844, 0.04405251095792459, 0.02569103624761826, 0.07975966609533756, 0.007574804955267258, 0.05412977324017594, 0.02124402225167761, 0.015257533504477432, 0.04966530010044094, 0.02829573519017187, 0.007535710052076368, 0.017873779307269765, 0.04069917557400562, 0.0656293505322068, 0.06667681489019625, 0.04228910296073845, 0.015461320553215281, 0.050887639348905896, 0.07408597296284092, 0.03876153620020036, 0.026888688312723275, 0.030030087387609868, 0.0443762558842859, 0.053751957828118924, 0.04446632101110393, 0.038949786985833804, 0.05370357937570061, 0.06972654196884363, 0.14773355977189156, 0.04674850459841471, 0.042107103452567136, 0.026971184490849415, 0.004691675187073528, 0.04597019374130234, 0.031714906255083705, 0.06024006754159928, 0.058663569676179084, 0.0493579954209347, 0.03231781745149243, 0.039236426443582585, 0.11077979955101207, 0.23619445251120677, 23.054854446841826, 84.30789516818139, 84.13563251495361, 62.15723529938729, 32.261704514103556, 28.288943652183782, 58.93482777380175, 90.55911771712765, 78.19837216408023, 55.79522148255379, 65.46888459113337, 52.38532858510172, 52.20122037395355, 8.833454155152845, 0.38049733266234403, 0.245309213416711, 0.24157010679764135, 0.4273258359922517, 0.39221382008925565, 0.832601884199727, 2.1869701964239923, 2.3643405110605302, 1.7064907594073204, 2.959246395095702, 3.9809882785043413, 8.546972082507226, 4.116104370163334, 0.2745730826450933, 0.05055356372688567, 0.10116814635694028, 0.041371161088107095, 0.05092525426598807, 0.07363398874839468, 0.09556724689900876, 0.04399734879693678, 0.07821580740593134, 0.1006136748999838, 0.027128966044514414, 0.12438399657126396, 0.139299544595903, 0.050752773400275945, 0.05446148548094977, 0.060753266011635144, 0.035536306038979566, 0.093365425934955, 0.0529598573883695, 0.04428851966475768, 0.21223042550827229, 0.7367922317597174, 0.17688916545481453, 0.13403826723656348, 0.8795232373860575, 0.7477163391247873, 1.1880269670678725, 1.089826875155972, 0.9661495180860643, 0.6923093057928548, 1.0154356927640977, 1.4835057311481046, 1.4433453183981682, 0.6579341438989486, 0.39783843762932286, 0.3285483282900626, 0.17522646354571467, 0.4257787061074088, 0.24575565881546468, 0.043798656232895396, 0.07949997761076497, 0.06099145806905243, 0.21199827022369833, 0.13441000374094134, 0.04374104259054988, 0.04226160806513602, 0.018639313733024944, 0.1028766066977574, 0.3173797163030794, 0.3048685199070362, 2.428975042796904, 0.5084935257271413, 0.0900865926016723, 0.08201152026172608, 8.202707613668135, 41.334085925932854, 51.57863824598251, 39.957353607300796, 59.134511716904186, 79.02692579453992, 76.31998831225981, 28.431213901888942, 40.95365524291992, 53.03700685501099, 63.555681859293294, 70.34544191052838, 20.227845368846772, 0.15854250880018358, 0.03734848702386503, 0.10474557011959054, 0.048907524230138916, 0.007005441706672672, 0.04119586867971286, 0.034605149149654374, 0.014956558626445552, 0.023766703821057757, 0.04650694175413059, 0.04225003247660014, 0.06687919999803267, 0.06063171850156881, 0.058989130230920936, 0.020133363300814264, 0.04429497395551974, 0.05747031495575944, 0.0423292919332462, 0.011928668884079785, 0.06473348731355322, 0.02195186259585523, 0.051351114882216345, 0.013261670490816958, 0.06270304404860062, 0.022620553931882306, 0.020521877130733866, 0.013747366404371157, 0.07409393261637419, 0.07869744688392648, 0.046737132023178765, 0.11851481312224943, 0.0041576381678873255, 0.041623502789485844, 0.028897401493703647, 0.012326770304371754, 0.060952046675787824, 0.02886184543791798, 0.007143900128862551, 0.09359499950322414, 0.09803291620506395, 0.08299730688093171, 0.13507009574001835, 0.13310771555669848, 0.15294107308070506, 0.14325963693761057, 0.09125044869799769, 0.2969567315472711, 0.0671768558001326, 0.24268962172490938, 0.15543403043862314, 0.11537246601355654, 0.10520731429419211, 0.14073569898403462, 0.18436174028583113, 0.1385412248031747, 0.14598029094838327, 0.11475643939188412, 0.14939687455133085, 0.1342033898277629, 0.15399907114765338, 0.16951737715111626, 0.2508625694580617, 0.15636073635710826, 0.1514992036766583, 0.08255068528195543, 0.13863805831680376, 0.178740187097461, 0.11860878912792092, 0.2135048740573468, 0.2114775449398064, 0.15045380009518516, 0.13660881397945268, 0.1281789203564967, 0.14786764048039913, 0.19604246672843734, 0.3348092891035542, 0.1417875377040717, 0.17228886875654423, 0.11700090080980333, 0.12965042204145463, 0.239281878776608, 0.1570083411230195, 20.127828851822887, 91.48016083625056, 108.22749691624796, 92.96234607696535, 95.93315709021785, 51.23253614671769, 47.727768959537634, 77.6641845703125, 102.46524487772297, 83.76568240504112, 81.90516887172576, 54.338049196427875, 54.67578095774497, 13.57644888662523, 0.41487025757951124, 0.30478262612896584, 0.3490867471743015, 0.6708131237856804, 3.4030856240180234, 8.684511953784574, 2.3292838373491844, 4.284748146610876, 8.42294869884368, 12.135932945436048, 20.86688183969067, 25.536800853667724, 10.735128060463937, 1.4529331845621911, 1.564145616946682, 0.3528124778982132, 0.09080445529111932, 0.22658680595697897, 0.22030084003363887, 0.18095801163825298, 0.12361179526534774, 0.13356405881143388, 0.29320887620410613, 0.1336152334847758, 0.34644552115951815, 0.32563394596499784, 0.465151580471185, 0.17956943131021916, 0.16976188177302962, 0.23476317044227357, 0.18491395178341097, 0.20484371381180905, 0.2679266876751377, 0.6049992456551522, 1.7782714818754506, 0.2051160121036153, 0.2848714493936108, 1.1366755419200467, 1.2855855063084634, 1.3959128313487577, 1.3875020439586332, 1.2759967821259655, 1.5109668575948285, 1.8502956364424, 2.1235001183325246, 2.120519607297836, 1.4427489955579083, 0.710547530362683, 0.5737462904184096, 0.4713027455633687, 0.3232635779967231, 0.6048148329700194, 0.14597312036541202, 0.19445219077169898, 0.17065345489930722, 0.38473959050832257, 0.2011711342680839, 0.19646386105206706, 0.1518460882887725, 0.14902230352163315, 0.24404616425594977, 0.524431555982559, 0.35720148754696696, 3.5229699265572334, 0.9450038979130407, 0.4376673488126647, 0.13280641317607897, 5.408660173416139, 36.23220805198916, 59.97006285575129, 74.5031778274044, 70.13770534146217, 85.68713388135357, 77.18593781994235, 36.20033487196892, 58.41043041598413, 62.109943282219675, 79.12136862354895, 81.65303107230895, 19.602192025030813, 0.23826966212401468, 0.22341918560766408, 0.17341222944519213, 0.18042991658852947, 0.14746259447307358, 0.11720309439565867, 0.1818120924215163, 0.04743987979787973, 0.17769982437452964, 0.14328511702197214, 0.09748060511605394, 0.1510883507228667, 0.19117264497664668, 0.13121806776090977, 0.13821183763925107, 0.14574079654149472, 0.19779775802406574, 0.11945108747890881, 0.15984859678053087, 0.16312696280017977, 0.13823495817280587, 0.24885356516367008, 0.09252830633833524, 0.18651958014215195, 0.13283745505877081, 0.2135541794761535, 0.09017957269304222, 0.13931364061370974, 0.1756848905596041, 0.12049197114162868, 0.21823952725577742, 0.22609578956279064, 0.18031190840467332, 0.17798793472109303, 0.10350028653779339, 0.095783666737618, 0.20224955623909352, 0.2512573498872019], [0.05907559091405523, 0.032410701781871824, 0.046388087043118094, 0.027033886872231964, 0.012163441316525062, 0.022777931374167244, 0.010351021886773167, 0.01917121623973212, 0.02117578488504214, 0.02505809823501735, 0.07004990002080318, 0.07631436951698796, 0.01486555599953018, 0.0389633888769294, 0.026772468944170305, 0.0399699479702019, 0.011403195770277132, 0.057898010352566365, 0.054514108060468594, 0.08594483016960083, 0.03757756646542299, 0.02487954995294492, 0.05747182414897027, 0.04570134284515535, 0.008188573053977903, 0.04568791715428234, 0.0119578798166326, 0.004332866416417904, 0.03930087359021268, 0.043392553024234316, 0.03835526445219594, 0.01770183278788482, 0.06811935079073714, 0.16062173271371474, 0.016430165137975447, 0.061284609274157596, 0.04349735002183626, 0.05797342787827215, 0.09424810478043172, 0.08362411235969874, 0.08478796845602413, 0.003453632572575683, 0.08739409998299615, 0.0986347931827749, 0.29639019420550716, 1.971467334416605, 32.89469465132683, 67.77468127589073, 88.91882173476681, 70.10958194732666, 41.71031967286141, 24.209027559526508, 36.001972767614554, 74.04321716677758, 74.89734465076079, 59.36060497837683, 41.659909371406805, 51.30549223192277, 20.29919916583646, 1.453464297998336, 0.44465698181621494, 0.25995091565193673, 0.11600501715175568, 0.24685309508875494, 0.682374187294514, 1.0866308789099417, 0.7201505957111236, 0.4203189506886467, 0.5843779360575061, 3.5651898287957717, 2.1068462248771422, 0.421408909943796, 0.16651468021014046, 0.22107967566097939, 0.025300086258099447, 0.10180118013053172, 0.016770463309160644, 0.048320034383645946, 0.029623124245253783, 0.030761295328697855, 0.059605524574797, 0.02235439008912973, 0.0574990509137992, 0.06118339756804128, 0.02517565825743781, 0.12869809814278158, 0.03739954678401832, 0.005736315553452099, 0.025030358191279155, 0.07044437401477369, 0.08028079740582936, 0.1942624001493377, 0.05234075109324148, 0.8967873658384047, 0.42861313949669566, 0.25945982264895595, 0.2893058727345159, 0.1931676911490579, 0.33152494759809586, 0.1657642051577568, 0.11005545575772563, 0.08598896449491863, 0.1023308992866547, 0.03186927871748565, 0.09381386316231183, 0.07351065625346477, 0.06046604049662429, 0.09625273471277568, 0.5089556299630673, 0.24403435118015737, 0.038139377044694084, 0.1069079298946646, 0.07369718334126858, 0.12881000826676048, 0.13449730712079233, 0.017526410144543456, 0.01988435599712595, 0.028562517648923303, 0.10605309834523548, 1.1151919850418646, 2.411310403577743, 0.35530532800382186, 0.56982992637542, 0.5201228323482698, 5.97999212241942, 18.867847842554895, 45.35525668051935, 67.76405165272375, 72.48794248027187, 58.52799561715896, 49.12259124940442, 34.04448647652903, 44.50588703155518, 58.08118666371992, 64.92830745635494, 32.659960408364576, 2.138870171000881, 0.07735038852138866, 0.16735753014443383, 0.009479232981140095, 0.08291443915016229, 0.09159116630232142, 0.058020362254953196, 0.05178062590740381, 0.029247091902840524, 0.04950290095181235, 0.03088671349800162, 0.025545406763652162, 0.042421797050103065, 0.02641273703756592, 0.021363062739011743, 0.02812597968225037, 0.0547067370385893, 0.03621548128825042, 0.026414543089847413, 0.03972856132614036, 0.017977685727659735, 0.030336874957767226, 0.01903543098559303, 0.0649917049093112, 0.025026937608697244, 0.018730434145958676, 0.08570781788758694, 0.016675027905993404, 0.024285550274315382, 0.04933239276250524, 0.03864995166358929, 0.04456406233892326, 0.03781812956496593, 0.06961886831108602, 0.027507765879554134, 0.01968703281524922, 0.052073076142058264, 0.01363407732212856, 0.034605823307027744, 0.019040332033088612, 0.037466598629590966, 0.04658749589936868, 0.0485512588713919, 0.008009398495027376, 0.04859948410622535, 0.011368387607827542, 0.02723474554987925, 0.0500258325689262, 0.06125267106859435, 0.027515830870176998, 0.06480071152890883, 0.01874629408121109, 0.045554449316114194, 0.00923386746792183, 0.03727097424768633, 0.01247947269509877, 0.08027110639358721, 0.024198626107986898, 0.05869658040483633, 0.034558685917046764, 0.013171788267490846, 0.09857723699702371, 0.004248613024115442, 0.0400698688181658, 0.0049410588314546455, 0.01922682081649621, 0.10646537622256626, 0.08016870342074864, 0.05791778691233166, 0.04983068316153461, 0.11635397020126544, 0.034078007879396605, 0.022938258254960663, 0.0685492180468094, 0.057704688064874186, 0.01701537587289368, 0.02845002721334177, 0.05760969316226341, 0.032562471460551023, 0.04916853421638089, 0.09891628452967252, 0.11886506086035122, 0.04768737216269778, 0.0825054707726644, 0.16079356623513086, 6.2208084906301195, 56.00155384309831, 88.94012020480248, 83.51087739390712, 53.359355080512266, 30.891767701795025, 30.885929253793535, 68.05640159114715, 99.09890205629411, 87.90289648117559, 52.618956719675374, 56.82481619619555, 70.99698681985178, 25.430230056085897, 1.7388463909587555, 0.5561029790870605, 0.23638258838365156, 0.24195475954442258, 0.8151569589972497, 0.42301245454338293, 0.30395356577730953, 1.0014327086748616, 1.3413232444755494, 2.351772011287751, 2.330397545329986, 2.639129507926203, 0.42020244403712215, 1.3559167904238547, 0.5330543965101242, 0.07901522015491802, 0.09396921047159741, 0.028534858044417157, 0.03113494705288641, 0.028989303316320145, 0.01081349480251271, 0.0705197953709191, 0.024406297222500848, 0.04024741352505742, 0.052413881846493295, 0.09210528790830605, 0.048263792038684895, 0.018962794359052376, 0.11356157205638387, 0.022040230837920984, 0.06160451993045788, 0.11485157219032127, 0.15613388240097031, 0.5911394280772055, 0.1632579944787487, 0.9927248630312182, 0.5154712077590727, 0.2886900912609793, 0.08484153332368982, 0.1159115237814765, 0.05828630201698792, 0.03294216761846216, 0.03803269164035878, 0.032873058826812816, 0.01430627351040922, 0.03033352523831831, 0.036017279020480575, 0.09308638606941508, 0.16214689119688927, 0.6319404129059084, 0.6907295712059545, 0.10291559291222405, 0.18019409940367748, 0.05319512682035566, 0.04450888868661658, 0.14169634259756536, 0.0913497796582599, 0.017094106728871985, 0.23281320088332702, 0.1249833990849795, 1.8569295901444651, 2.7338348905886374, 0.12531172904756763, 0.32822960507004495, 0.5597102113308445, 17.876241284032023, 39.68871831893921, 45.071249623452466, 58.25901123785204, 90.38621963993197, 70.43047105112385, 57.13669953807708, 36.0212355275308, 36.626296427942094, 58.62711783378356, 72.29681322651525, 50.08110477078346, 6.306420593492447, 0.16201860211308927, 0.08231640027295198, 0.05835540314775802, 0.021827289038487983, 0.016792034429888573, 0.024549408192415873, 0.03159216556307529, 0.03505187417050043, 0.019148631967724334, 0.04065592608024036, 0.027735018201412696, 0.01998489737630852, 0.03653160747020476, 0.14516773213061596, 0.0471932684341746, 0.14129727207604917, 0.008571678303152083, 0.022340108295001333, 0.033773763721147855, 0.038775348765475136, 0.03561893245205283, 0.03019444006044538, 0.013779102554244381, 0.0160110384346016, 0.020589264139773387, 0.05186047142131194, 0.03315455400415006, 0.054809592003303195, 0.042486906862787666, 0.052285906858742244, 0.0594135046365761, 0.029155810611442696, 0.04540459868768531, 0.01952577705284761, 0.02886708739453987, 0.017049233128707257, 0.041159521638145374, 0.06237342705829971, 0.0698040317623846, 0.12841529678553343, 0.11792460366362527, 0.12099849315540445, 0.12750358320772648, 0.11245672771286581, 0.06764963930172306, 0.17050471126792893, 0.10283267155529992, 0.1548062979934677, 0.12468912939150488, 0.20274821819076616, 0.12611823577073314, 0.07311425171792507, 0.09594692007428217, 0.16107321897101018, 0.17511865965300993, 0.17483065655875593, 0.1499176764440152, 0.3274222403284042, 0.17769870588616019, 0.12886942604616766, 0.1577933667407882, 0.10215106014642986, 0.14625448913824174, 0.1239984398407321, 0.16229332124273624, 0.21027274910480748, 0.16303544593674524, 0.09976147103213495, 0.15767172730017096, 0.14636302847535382, 0.1305440789268863, 0.1303503965778697, 0.19376887098675777, 0.11132713106851425, 0.13965802777919079, 0.12425817429058014, 0.1501468133421675, 0.21971262240361786, 0.1288567089866246, 0.23245655631105747, 0.26557648314103005, 0.11872721099925619, 0.2383061738744859, 0.5571645318019776, 4.050078867904602, 54.10806102137412, 103.40790025649532, 112.62018280644571, 91.22698753110825, 60.711786977706424, 37.89846620252056, 54.2478778285365, 98.52632230327976, 96.0601399021764, 77.83844763232817, 60.38957211279101, 75.36715046052011, 32.28411889845325, 1.821275735574384, 0.7129684907774771, 0.2901082732264073, 0.7037513498817721, 1.9413041852174269, 3.2892925172082843, 5.6700390769589335, 3.39007634789713, 3.1469293563596668, 5.273479117501167, 8.618476890748548, 6.467055870640663, 0.8620450333241494, 1.1032868561244782, 0.7957137087660452, 0.17350848073199873, 0.20735802970105605, 0.1690701503426798, 0.20851269274229006, 0.15860633924603462, 0.11868466247594166, 0.18449392109628648, 0.18824416663377516, 0.16062373986407635, 0.25500762606820754, 0.3138491234952404, 0.14832524011933035, 0.11596247628932038, 0.18122359899984253, 0.13495397213245594, 0.1444946932456186, 0.15591283539129844, 0.899887447876315, 2.2042604944398327, 2.655996435111569, 1.9126300657949142, 1.2352554908683224, 1.3149584204919877, 0.8807461588613449, 0.5575166870990108, 0.2897762507200241, 0.3369459696114064, 0.23171280751064902, 0.19119590340602785, 0.12583088385121477, 0.3183925151824951, 0.15138683389992486, 0.22885689301596535, 0.2780147479666818, 0.8444908333401527, 0.3657653086608456, 0.31439696829165187, 0.2895186000293301, 0.1725481282318792, 0.16711860264260925, 0.22191120281575188, 0.1851214543585816, 0.1048543239613214, 0.49334128717741665, 0.2515213897511844, 2.7678462526490613, 4.37995828928486, 0.7206667551109869, 0.8544105075059399, 0.8152327710582364, 14.346980856310937, 41.21010372715612, 64.55744735656246, 81.27350253443565, 91.0362034459268, 74.81750872827347, 62.81825665504702, 49.4166866425545, 57.54784237953925, 76.27748550907259, 91.7592296292705, 59.32491140980875, 5.772218290836581, 0.30090490356087685, 0.18415722545356522, 0.07862194891898863, 0.12293412154840848, 0.22299478821937116, 0.15675626755241426, 0.23972556625883426, 0.10132944616939753, 0.15370020492663308, 0.11632801514239081, 0.0956498311772462, 0.155719505442727, 0.1372172716524332, 0.12186106985374806, 0.13061917086522426, 0.25386675260961056, 0.06704071431510872, 0.14042060702077805, 0.13318873701557038, 0.09158520613827052, 0.08165530469869414, 0.15403668606473556, 0.1350153510969493, 0.06747739209282784, 0.08176678581343544, 0.26722816870577876, 0.11440617633202385, 0.1350867811350092, 0.18166075941295395, 0.16451745834802428, 0.11612330878814382, 0.17368052875803364, 0.1071601720046132, 0.2189886693151728, 0.10630107334544582, 0.19514335529698482, 0.0961082888346526, 0.1505000718058117, 0.15857926569879055], [0.04061772510589611, 0.02354948725100727, 0.06361317565484394, 0.007653082382955379, 0.10247347591024253, 0.01754703897712452, 0.015704775634672374, 0.046060542320652355, 0.017651429948126598, 0.05241267142757293, 0.003838419145341182, 0.08779188347679955, 0.04429562513025538, 0.014215582106713087, 0.024257557421562173, 0.09089746602600621, 0.05872805512720539, 0.0369531320287816, 0.022408228833228353, 0.013260797150583278, 0.03612308725414257, 0.026127650823083617, 0.059896810355806546, 0.06423904650634335, 0.05296798941168574, 0.05183567315520299, 0.029559445101767782, 0.018725153884940574, 0.05458421659685912, 0.07308173128553937, 0.0243617243118464, 0.10999088986746727, 0.06319555814468092, 0.023895322322665204, 0.054238293425089894, 0.04043933004140854, 0.016479236899965232, 0.04363573231403867, 0.07071832705649637, 0.08362579775313217, 0.0713145579662054, 0.07232971639642793, 0.05062533850451151, 0.1172023129859759, 0.09264351064038855, 0.2723077912965129, 0.0414690058377962, 14.29146755126215, 45.48569117822955, 73.99669785653391, 72.15999311016452, 61.54772643120059, 40.0608100429658, 27.012618126407748, 42.99483706874233, 60.65765826932846, 69.19839182207662, 56.571454617284964, 55.452218055725105, 37.90577357815158, 10.718291286499271, 0.13886135762497304, 0.21467750952128442, 0.1560299702349209, 0.3498667778988039, 0.5746956878612118, 0.16791531876210244, 1.3845867423280593, 1.50895529456677, 1.2466372285158405, 1.3019307582609116, 0.7569243482524349, 0.15565003658975327, 0.07419963742816642, 0.03014279041259039, 0.05109293176041496, 0.03411861053938347, 0.06160754597775879, 0.010186941175150776, 0.06242794953587075, 0.05280383592171054, 0.0007582456976618438, 0.03420771039541691, 0.0379478435723051, 0.022325535387461706, 0.0813915099828474, 0.03388202343616755, 0.07262266075779354, 0.030770639686154264, 0.08019604509876621, 0.030948071395077055, 0.15661317764991717, 0.2507255010066494, 0.33130269016950364, 0.04180536440183078, 0.07048441743057582, 0.060110253942829955, 0.11249098716483963, 0.11581491243334548, 0.09095295377436186, 0.03315367683347675, 0.08363990909269742, 0.04916181945572457, 0.09740055658884587, 0.06922547450108875, 0.028019217669122645, 0.09010779025453715, 0.05478813771098372, 0.12962046800361526, 0.12919001852072057, 0.6059974888640066, 0.2123725501399848, 0.10002582499216642, 0.01887876217463805, 0.0246392568993953, 0.1484593667931134, 0.05251939896674407, 1.279280909126805, 2.924143878682967, 0.6517678715528981, 0.3491322527970037, 0.353670864095611, 5.077205675263559, 19.922312344274214, 22.738383893043768, 48.661069485449026, 85.80475791808098, 68.11794357915079, 51.40160206825503, 49.02766204649403, 39.496875193811235, 54.34632539749146, 71.15096338333623, 59.52549357568065, 15.589478881128374, 0.23969622509133434, 0.1597912014732438, 0.02317894584379129, 0.02130820509797383, 0.03936095020523475, 0.09381109758490518, 0.042304401736586325, 0.04251349394419982, 0.03131262007950535, 0.08268049121984551, 0.023548152342799212, 0.004505124159022085, 0.016779227355014414, 0.06794476701367287, 0.027253282962427027, 0.02412696049789027, 0.011745139115279721, 0.05031450982055357, 0.05169610725715757, 0.05505327691113757, 0.09013421262704557, 0.0558175492070375, 0.010271342996988567, 0.03354048228732521, 0.059965279464039116, 0.025748272591661063, 0.05134189501404763, 0.0457247966269572, 0.01437364040964073, 0.15134851418195233, 0.012183541548438372, 0.031875336557746894, 0.06406102299449906, 0.02156973793922413, 0.14504031638704962, 0.018178728266408848, 0.019536285863948927, 0.050150976861797036, 0.023368814990164775, 0.009479910968953084, 0.03669709778360782, 0.004797923442487035, 0.060464983295288786, 0.013985333423460684, 0.03224876994687704, 0.046108836503398996, 0.027045778472036607, 0.06975253533211447, 0.017164630867961436, 0.07681209684139298, 0.01603801334802542, 0.039039442255612344, 0.01814595502500813, 0.036197225413014816, 0.04307854890583023, 0.025640903453853343, 0.009030990148594063, 0.01577478936768227, 0.05492768445683103, 0.0026027461365541265, 0.07603727551477571, 0.030922809645773906, 0.04552364109023925, 0.07577885873615742, 0.06421212234624452, 0.02459872893298105, 0.017137270037745757, 0.053160288971999, 0.018486163180862224, 0.04127816184453907, 0.07686168571273166, 0.0633348329293151, 0.052370678318003495, 0.05239225901483048, 0.017378848203788363, 0.04595140543495936, 0.001795803820582918, 0.0631897550286545, 0.03665220886168461, 0.04576160332127925, 0.0242078612979141, 0.003992808365916473, 0.0172984242934974, 0.04621330791363313, 0.1090363979399685, 0.035340945957408804, 0.3077861810884168, 0.2804540944916587, 25.546995093745572, 73.53749029098019, 85.15977905642602, 67.7710020926691, 40.423613594424346, 28.323725269686793, 44.905662844257975, 73.84829105869417, 77.46237862494685, 62.088083913249356, 63.115125163908935, 61.78957585365542, 46.56270342488443, 11.43995640739318, 0.22875184703978801, 0.038674657999147335, 0.17761584581627002, 0.5064870801664169, 0.06827839830469701, 0.8567876476914653, 1.3207761534760076, 1.5141143145099765, 2.4027745906383764, 0.34803098608409205, 1.1311779724013422, 0.17140589113677704, 0.0911942178443555, 0.035453530238761057, 0.017282798015061888, 0.13848919211135757, 0.0422150720541756, 0.05177242110573477, 0.01637499340088858, 0.04016347327119401, 0.050175583605924924, 0.04098715568562189, 0.06512527999978873, 0.02159574087859402, 0.01354929054110882, 0.02874930329140156, 0.08614654878094312, 0.07680300337773177, 0.03936377706967535, 0.02185705346956609, 0.2501374519159717, 0.3389042435634521, 0.27946479918975986, 0.07876511543027817, 0.06506754761381496, 0.07497618245261331, 0.1104371437442399, 0.05158033988047993, 0.07128779851501027, 0.04973587978090491, 0.02327291035814391, 0.028896240870498364, 0.06844898310279654, 0.00997912067349159, 0.08517227646323942, 0.15417976064547417, 0.012230701921057078, 0.10691819547284996, 0.30667311662147123, 0.2989202455407189, 0.04486697733462338, 0.1042613872296868, 0.025132309172242403, 0.11094345125339686, 0.12965705636287891, 0.13522213354947107, 2.5206060226886504, 4.852309226989746, 0.7525502313529292, 0.49344663958876367, 0.22061738756395158, 7.639176768641319, 35.220758222764545, 34.973217441189675, 41.077982610271825, 90.1890891598117, 86.953839794282, 55.204587059636275, 46.99689411347913, 39.866025140208585, 53.205033348452666, 71.86410519384569, 73.40259998075425, 28.911555197931108, 0.5176065093086613, 0.1430417615319452, 0.12415685916259406, 0.027545754264499393, 0.07708610350927038, 0.09380422577622438, 0.05738333716327625, 0.05053663318375907, 0.01988678832628554, 0.057169100675251217, 0.041599945585814216, 0.12450122334543737, 0.03198999119171452, 0.025020006428202315, 0.06558371467455741, 0.026798535085793947, 0.036216458050353874, 0.017060563569107366, 0.06349323692941858, 0.039774269962142554, 0.04898662280832087, 0.03225553450324843, 0.018291632389469493, 0.0822150698232074, 0.04211764099196561, 0.0044434502506778845, 0.015989564032474115, 0.04508453481380017, 0.03621496034846191, 0.09569441749443931, 0.021515125446321986, 0.052466607847881895, 0.05627590344257413, 0.01519182327038218, 0.12275955309310269, 0.020919126278210073, 0.02378935704097873, 0.10203774042067029, 0.029224557426547813, 0.07590085823809908, 0.018662461079657078, 0.155425634114973, 0.2070861450967289, 0.1781864127805156, 0.14657436149014583, 0.2098290616225812, 0.16251894945819534, 0.18382892613449406, 0.08795165877428748, 0.11451300729306475, 0.2050644390645527, 0.10977902059112826, 0.20911977145700686, 0.1734738229143043, 0.1567632542742837, 0.15138367761767682, 0.1849765564885832, 0.09351678958703434, 0.1495603730361308, 0.07607353445623191, 0.26107856643296057, 0.17542725519066857, 0.12843467114913848, 0.1644020088978352, 0.13667570877700083, 0.11364691425114871, 0.10084864172723987, 0.12038123313217394, 0.1187676068155035, 0.09937397609915465, 0.1737865246832371, 0.17616800092641385, 0.13422055019726678, 0.17928732709298212, 0.14180528030039805, 0.1304754068053538, 0.2316736450959598, 0.11668604633380329, 0.17624520726742285, 0.14821815634927443, 0.14799641986047068, 0.11905321971543374, 0.1340179046195361, 0.1535879577239675, 0.23762896747118045, 0.20437396401839875, 0.5076572641489968, 0.23597692950598656, 20.659900326882642, 75.87730176987188, 107.94812217835458, 94.53321610727619, 82.77188716396209, 60.89573437167753, 45.192984304120465, 63.16242894818706, 84.40342057135798, 87.72900212195613, 72.45613205817439, 72.91401386260986, 59.8794404152901, 19.507823721055065, 0.33287801208996004, 0.48836808952112354, 0.659811794757843, 2.0635758628768306, 1.4309986776882604, 2.478604547439083, 5.538518573007276, 4.279754479085246, 4.453182076254199, 2.79060727646274, 2.875339052369518, 0.7373443053614709, 0.20409447982186274, 0.1729176890465521, 0.18575329303501115, 0.2479974006212527, 0.14103035172147138, 0.14322899342063936, 0.08837763430370439, 0.22838173464180964, 0.22000914439558986, 0.13655753205380133, 0.15204729362120553, 0.13639484562220114, 0.14894598584261634, 0.12223598562301168, 0.2066726108352023, 0.11847116909320317, 0.21917130467632126, 0.14285529573117534, 0.35581649251041875, 1.3394324169043572, 0.4932188663271166, 0.24015508111446138, 0.18690873748592793, 0.2368319755600345, 0.2365208672539842, 0.17282813336820374, 0.2624807524825296, 0.09678313568715127, 0.29747261515548157, 0.0828572966518902, 0.23268910996135206, 0.10991945216852812, 0.2105571209423004, 0.23080317003111686, 0.1448540191256231, 0.30654683468803284, 0.2969761595370308, 0.8947753738011084, 0.5710232462133131, 0.24615060778394823, 0.066976799599586, 0.23275459515711955, 0.3581265540372941, 0.24612986212295873, 2.987539431741161, 8.130479618426293, 1.0867984376607405, 0.5493582184276273, 0.8012489698106243, 10.797805574632461, 37.278963135134795, 46.36567492638865, 66.63249492645264, 102.40098860956009, 85.39708245185115, 68.3475826632592, 59.977252560277144, 53.56959412174841, 67.81755278187414, 91.17130556414205, 83.12997602647351, 27.620267791132775, 0.45891314264266725, 0.3401210056918283, 0.4154491749021315, 0.11294951377015923, 0.1554306596517563, 0.23734018296724368, 0.16708464962580513, 0.13142604531059343, 0.14844908589316955, 0.2821893755707049, 0.17047537010042899, 0.21726897046450647, 0.16282025183881485, 0.1403378388814388, 0.1497941677488627, 0.15797440863905415, 0.148313365756504, 0.12059266573839611, 0.1805767143565801, 0.17246471657868356, 0.18975109222435182, 0.2033317320409321, 0.11076754980510282, 0.21328465442263314, 0.17573626441580636, 0.08489669931511726, 0.11132491707441308, 0.20239978608104492, 0.09135599263132581, 0.2274651870492005, 0.08407101741120701, 0.0944776706878216, 0.15739970480001744, 0.06774710866832925, 0.2618797411841731, 0.10108061315071198, 0.11475245573467786, 0.14696593967176255, 0.14780572525435878, 0.12965618302264523, 0.23435904374045713], [0.03199295978242111, 0.022377771092578772, 0.018237115657557885, 0.019396513122163953, 0.03780592961477176, 0.055371276178066774, 0.024884217343623602, 0.03428507761489, 0.025960750907899875, 0.021949120001086307, 0.039141971632958426, 0.05766158029737492, 0.02659887916618778, 0.047305347097496835, 0.017014228656227072, 0.09313158525694763, 0.02697584039020923, 0.03908236616200978, 0.0692460286400972, 0.057105588155888745, 0.019023321050729965, 0.039231615411418105, 0.04707310754325121, 0.0634355390174014, 0.023880906463150057, 0.08317064959555866, 0.01562315279677991, 0.048582488445625197, 0.01736925678297637, 0.04674006230948914, 0.07406693567792255, 0.029525130108419447, 0.10495717892603529, 0.020174753116143328, 0.06258753331137762, 0.026568930874007846, 0.0575406801316046, 0.07755651979917481, 0.17979630058811558, 0.06983841378842631, 0.042315215067637545, 0.0037073106185773453, 0.06590871981555416, 0.047914390827739434, 0.11923477489260897, 0.10284642283354076, 0.06808761942891345, 0.29909237017554624, 3.050224545501894, 27.773865845895585, 62.220652180333296, 95.28243587863062, 78.13166049218948, 47.679814061810895, 34.90813355292044, 42.48936514700613, 59.57483699244838, 65.86529501022832, 84.56832485814249, 71.19385057880034, 43.19895329013948, 19.745121232924923, 2.3261084335465587, 0.5333440390325362, 0.13973036180100135, 0.2032031365219624, 0.20128764091960846, 0.3634032144421532, 0.25712245774845927, 0.7772103564873819, 0.09501464469658752, 0.5518771155226616, 0.052841155894941864, 0.10727411992247067, 0.04129932502344732, 0.050042475829081196, 0.020300245979019714, 0.03574583491670989, 0.05638622776454976, 0.018973262950537667, 0.02508816335560574, 0.06016879455156385, 0.019514318292720184, 0.04650917490042987, 0.017740631310810006, 0.07924679321266952, 0.020370768202889352, 0.05412279417918575, 0.0335435581303412, 0.030491025254671133, 0.23011111684383886, 0.05304790387350706, 0.10024802879460397, 0.23206709253211177, 0.022329093865869988, 0.04127346572556323, 0.05567056757788505, 0.0147156163133801, 0.05106200862135138, 0.06289836199533555, 0.042934443936833454, 0.021567548842980497, 0.04508617424195813, 0.03737088360433136, 0.0180801768006096, 0.07137301047482798, 0.09277884773309193, 0.047222471705848174, 0.11807505567107471, 2.027016431093216, 2.962894199355956, 0.1448679772476035, 0.11822134016021607, 0.1965675280699807, 0.27369940533272685, 2.2197800874710083, 3.195657696454756, 0.7547120701882147, 0.39964956141287283, 0.7587029592644784, 5.804668549568423, 20.703605336527673, 44.88050476197274, 50.083364056002715, 52.85031772428944, 72.44627121956118, 60.12921302549301, 45.95740718226279, 53.443234966647246, 56.70468576492802, 70.55922677440029, 61.60351037979127, 27.202551057261807, 3.222115799303978, 0.15779428604629733, 0.15837908692417607, 0.03506871661351573, 0.07901316703928095, 0.06092663936977906, 0.045950984086601004, 0.05974103786772298, 0.09248575015414147, 0.16638902646879997, 0.05731546177318501, 0.03144523372963792, 0.06810982831783834, 0.08453345106494042, 0.04527214974645646, 0.0661594680540504, 0.053688793878762, 0.059200486228350675, 0.007141165194972869, 0.036161625307173505, 0.0379046208916172, 0.019024359099867365, 0.011836998803060383, 0.028772119305006442, 0.022316568328308004, 0.04397258883522403, 0.014539913090336469, 0.009734417826327826, 0.047998545586221644, 0.01548779559426851, 0.1436109495379271, 0.015298777763100882, 0.01837509575360004, 0.07658531949404748, 0.04361555738855274, 0.050570467456934914, 0.05668940706058376, 0.048781717271213575, 0.039209877666566646, 0.039569555947016326, 0.0622938190316481, 0.044082373065213044, 0.05494691326373047, 0.042660138494665586, 0.09204853611487536, 0.02201501122345367, 0.0357777463091958, 0.05986286116944206, 0.0400392827577889, 0.04525733360600087, 0.04168680463466914, 0.047606343042946635, 0.028762259753420952, 0.06936385296285152, 0.028911872894593307, 0.02978262949674841, 0.06982639386889435, 0.021168696656522733, 0.1554981673196439, 0.03012807194834515, 0.051224495870091265, 0.04119247107976868, 0.05162313738236985, 0.019863665877510945, 0.062330215868930665, 0.05825913270875331, 0.02396159658899471, 0.035072033774227865, 0.010937512946134854, 0.04411223900294112, 0.036162697830267494, 0.05030830833880652, 0.039582418563265, 0.03663018000342193, 0.0836902180866849, 0.015475813979132762, 0.020787508542379065, 0.03747713999942907, 0.07218940739309596, 0.0374352120073332, 0.1273881337575374, 0.2172809520796422, 0.03464413536412101, 0.0556195691047657, 0.0717186616853841, 0.012428016484444662, 0.12309972677500018, 0.18281677076893468, 0.1262493440580945, 0.16296165634787854, 0.3154832196812476, 7.158834982302881, 49.060900211334236, 82.01463437849476, 93.72718472634593, 70.86647387473815, 45.249995954575084, 37.13608687923801, 55.19502039878599, 82.58184048437303, 83.97087727823566, 77.77324999532392, 66.73133081005466, 56.91743904544462, 21.00257819698703, 2.3312043278448047, 0.449938974193027, 0.04977123856905007, 0.08735884461672076, 0.16277062466307995, 0.19731408075219203, 0.37635080516338354, 0.511215190973974, 0.0719024691610567, 0.27751829234823105, 0.13207740390733366, 0.08609852272896998, 0.08959696282662692, 0.055793417437422665, 0.04705061137135472, 0.018240172348375765, 0.033645137558661165, 0.03560793909033941, 0.03714522474535531, 0.10246046773728826, 0.06364138684265556, 0.06138461822223279, 0.08212945949766906, 0.03844525297022155, 0.01833275024358544, 0.06821354130102743, 0.02002876548607263, 0.04998802612986296, 0.11361666909989812, 0.05270552385838763, 0.16927691747344312, 0.225731790546448, 0.019452879956412702, 0.0171294923300945, 0.06497286680725313, 0.046694039577437986, 0.05513494188386587, 0.051439050284604874, 0.02752954958968105, 0.049140974203304905, 0.01736035675651604, 0.08799370167957199, 0.014884330899334483, 0.05032975497024675, 0.08944162317822058, 0.04153312739705847, 0.09643519387370157, 1.8960308403738084, 3.49314495921135, 0.6040515029622663, 0.2167444760280271, 0.39011795674600913, 0.7319818124655755, 3.282043241685437, 4.950462127885511, 1.0611932051758612, 0.6856078750664188, 0.1649307781049321, 10.64393295395759, 36.75154947465466, 59.45302386437694, 55.83311550078854, 59.475836369299124, 85.89727878570558, 78.92584631519934, 48.35582279389905, 54.10026334947156, 59.123246669769294, 74.03472131298435, 72.50413402434319, 42.593766873882664, 7.450711294527977, 0.13697757806268432, 0.053631942493901144, 0.053798620243586844, 0.19208761442813183, 0.03863325860771922, 0.054932683180536956, 0.031636882115215544, 0.07522469371437066, 0.07114003547617505, 0.0331636359764924, 0.04365844682099358, 0.01384689175944415, 0.003622587997421262, 0.020608404846561533, 0.08327548106711719, 0.10399868035869253, 0.04268909278776377, 0.04414855923143126, 0.06955483102149541, 0.10176332772619302, 0.026091305696735942, 0.09144210857489417, 0.03282753788235207, 0.03961580084456552, 0.059988246780009045, 0.06785258365374419, 0.03913996448259681, 0.05504387701230665, 0.03194959154502759, 0.0634256411614197, 0.06389358681776831, 0.07421827634736415, 0.08170865506174103, 0.030168393071019844, 0.09885184121348205, 0.04809093578988987, 0.10619426536704264, 0.05284363035893729, 0.00877372537469191, 0.02481173968032724, 0.05744070182704637, 0.04112429308494733, 0.1547869466125004, 0.18574626034786626, 0.09479388113944762, 0.1229428243072283, 0.12322177990309655, 0.17150745907377812, 0.09384763997889335, 0.14195825273711837, 0.1684861615180008, 0.13777044842079764, 0.10544451809818707, 0.2101693272350296, 0.0963287995827775, 0.19639551068746275, 0.1016161009489048, 0.17926972239248215, 0.06544905940010663, 0.11184902846693032, 0.12732320780595466, 0.14460366159196825, 0.08741443961738579, 0.1745516013714575, 0.2496444896584557, 0.15309577687613427, 0.13690300706413486, 0.17188400661032047, 0.1140853233875767, 0.21279564517880642, 0.10409339180877132, 0.18584819600707103, 0.17326656548726946, 0.21622964962115213, 0.18073360916347275, 0.13783446272775052, 0.14803752813848758, 0.2338513266295195, 0.2281187826226796, 0.2792881086709038, 0.3257829041009949, 0.23426332871519753, 0.1361551060671768, 0.08995480249605833, 0.1669731072240299, 0.2952807456735642, 0.26439306115911854, 0.21548580889019275, 0.24730018400136503, 0.6007717273408367, 4.058180033199249, 44.258342327610144, 92.36119577961584, 120.73160509909354, 101.27379355892059, 75.0939416885376, 51.98952221101331, 59.23081767174506, 85.46164466488747, 91.29962198195919, 104.02390849205756, 89.9795404557259, 67.61475055448471, 33.738294493767526, 5.101551336626853, 0.8260849274454579, 0.48406046905344535, 0.5280948045753664, 1.7407328058635037, 1.2811849746973285, 4.275913988390277, 1.2017590624670829, 0.4657750534674814, 1.8516580472069404, 0.14521385062365763, 0.21390441955337602, 0.1284710603255418, 0.11567317850647435, 0.3447754801281037, 0.1253868209859056, 0.18831083160494605, 0.23058802189846195, 0.13618276184124334, 0.26814051813656287, 0.15480478113937765, 0.20789337194254323, 0.12485661153351107, 0.13539189863349163, 0.10154642525219149, 0.16635265261415513, 0.10666429095210568, 0.16416308139601063, 0.6800633596797144, 0.23299663297591672, 0.31127396490304704, 0.450843969179738, 0.09844312564499917, 0.10863333610036682, 0.19214739992974267, 0.2087154608940886, 0.2857040643932358, 0.10087962232289777, 0.15536796301603317, 0.14576267601261217, 0.2804669034817527, 0.1636253336384412, 0.12144591148582198, 0.16640240236395792, 0.3498184224290233, 0.1705340217919119, 0.25929468473599804, 3.0102428457429333, 6.274922490119935, 1.5073489614071385, 0.41844847041272354, 0.5034838316421355, 0.5105925453526359, 3.504071456770743, 7.845059527504829, 1.6830797253116485, 0.5287732520411091, 0.8967453229331201, 12.627804048599737, 38.94217752641247, 75.69769643968152, 72.14015376183295, 68.87243501601681, 91.34911444879349, 79.89475803990518, 60.283891693238296, 66.64193214908724, 74.19387540509625, 91.93922719647809, 88.29779286538401, 42.193488997797814, 5.518952809995221, 0.3031314921475226, 0.23772117381374683, 0.15404520496245355, 0.26644706545818236, 0.1927949280868615, 0.17721395609119248, 0.17008275003923526, 0.1512420739257528, 0.18615680686648817, 0.1699359675929431, 0.16691159036371017, 0.2032808638027599, 0.22161319461320678, 0.130072720348835, 0.20478068009739925, 0.1706591392717054, 0.21351359213792512, 0.13421918656076157, 0.19344841640803123, 0.21885232098640936, 0.08882771862009842, 0.2798918472422708, 0.1427843406676285, 0.12610887417629843, 0.13178078998481074, 0.19941121580139284, 0.13562077506174966, 0.13574632155078073, 0.13550177096359192, 0.2616122845680483, 0.19388870245987372, 0.18855493786113878, 0.21091831607684014, 0.1435112048901858, 0.14521902937802578, 0.12741496981752495, 0.1920136256564048, 0.21009328534766553, 0.12004687405762174, 0.14039570916323893, 0.2414659035181807, 0.0730043487443078], [0.03032540853676056, 0.029073438922604247, 0.036626223159293016, 0.06196292650495326, 0.01320304465480149, 0.03785381394047891, 0.010795892017232555, 0.015894590197281254, 0.052551352494065805, 0.015033120495988237, 0.045920007321382725, 0.07777315414240284, 0.06550315286844008, 0.032032551206347924, 0.08191876999673345, 0.05669777657115652, 0.06299684642844143, 0.01129482593011832, 0.00505192611824661, 0.025365052429298242, 0.06264998096852534, 0.03082670200045311, 0.06773793093499637, 0.10362608583583947, 0.0291806529276073, 0.044344865431588505, 0.029818151078577486, 0.07792937479192212, 0.013030498671615797, 0.02664973782826095, 0.008773233163200559, 0.08199439819661841, 0.07715293701978461, 0.07091921063200121, 0.05147799053379605, 0.08448707210200448, 0.02948594088065288, 0.043185383697310765, 0.03572734921509701, 0.021448079346408768, 0.02017224034775169, 0.08670874240417635, 0.0258130319191203, 0.036795505607921275, 0.10713247026527122, 0.07726474755233334, 0.11823161339928066, 0.1335933999789338, 0.21152861236083895, 0.39054874330759054, 10.50937016164103, 38.25105197968022, 73.41836006410661, 84.90374242105793, 74.86925263558665, 51.659050756885165, 38.629764664557676, 35.878939782419515, 56.85426142907912, 82.81631192853375, 76.83203804877498, 75.48447639711442, 51.15879166510798, 16.98152119113553, 1.178691848631828, 0.05919557560475604, 0.31476662103687564, 0.4171018410594233, 0.44283749235253184, 0.5053904099810509, 0.0704502652309114, 0.11162127052704174, 0.20436213562084785, 0.0993762743629275, 0.048826790054238615, 0.09042065290193405, 0.06684006056598117, 0.030052229243841384, 0.0593200802142101, 0.06387633451771352, 0.09571587561719841, 0.028185834131774404, 0.04534369469770501, 0.023702137930799397, 0.08732188853525347, 0.04068586479632124, 0.016758801535733284, 0.041548747929834554, 0.005166003792246263, 0.017340777464391246, 0.22679147400682975, 0.044750179569687576, 0.3204119229508985, 0.12819923700824862, 0.027019520808431893, 0.03362104409344254, 0.04230191195083242, 0.08347049640912203, 0.015499566535225079, 0.07750087117235507, 0.043809841116589886, 0.056048088046091224, 0.03712596146449928, 0.0494733797536502, 0.008258606896795815, 0.07139656001762038, 0.06560900323693791, 0.03173000393285146, 0.2588775345394688, 1.5163935793022958, 1.9735269464792746, 0.6788252390200092, 0.3056688979268074, 3.654932187449548, 4.719797343977036, 1.107919543020187, 0.21507106420974578, 0.5659571374135633, 5.8443447947502145, 19.416012802431663, 41.18509077256726, 50.060049487698464, 66.5329687057003, 62.08004697676628, 67.56103761734502, 45.135450978432935, 41.31654900889243, 58.709542520584606, 75.81776019065612, 67.9535178215273, 37.55311719832882, 7.194590818497443, 0.08935981264878666, 0.08751209284509383, 0.014330149598179326, 0.11914743320836176, 0.019866287813431794, 0.09523738476057207, 0.09010412835425909, 0.04925298774915357, 0.06661196554740591, 0.046023930978750995, 0.09158307641384103, 0.04466078476980329, 0.07126382762385954, 0.08930863797544472, 0.024075762841910608, 0.12255750506395295, 0.029440743608340144, 0.06633357685660163, 0.04177203574668496, 0.07119975202987272, 0.039713484715790524, 0.050439646452545166, 0.07454533460399798, 0.02370441512715432, 0.022989423352203543, 0.015776441244769002, 0.11489511662793737, 0.021184127582537553, 0.07813551373058751, 0.03863193327561021, 0.02202585711324167, 0.03281803839209099, 0.05437095687093754, 0.06553383468980752, 0.00793280263033305, 0.009423037559064406, 0.025870643646246003, 0.044656207394455714, 0.029067404064980727, 0.04405955130594873, 0.03711687566171731, 0.0366719662692518, 0.01412996028985588, 0.014838131009450844, 0.08397276663491804, 0.026278575889826305, 0.013752839144980235, 0.025242939929387746, 0.03230694283340727, 0.05336257831884488, 0.02622574646656792, 0.011758744836814944, 0.016151724736236276, 0.0073758255870592215, 0.031817627154410846, 0.061711538583040244, 0.047354552924873373, 0.0340137024590325, 0.0432683433586311, 0.048738686112506736, 0.05027063213469041, 0.02078627131038135, 0.020860001527433916, 0.01138755512769304, 0.03892684648294122, 0.05334830993125516, 0.053002873225317854, 0.03664379721627601, 0.02434623784445707, 0.015469661335490886, 0.09271838807410772, 0.031962553752706416, 0.01889353809547761, 0.05025275930341694, 0.030947042922038707, 0.04589389904492325, 0.09002333672176446, 0.09027495063961515, 0.015362691521013697, 0.04417631076648832, 0.07397494383997495, 0.0675251729966652, 0.013425264736607432, 0.04553880963114001, 0.07712592475957449, 0.0068767571299817535, 0.003343354455277985, 0.008142393273902277, 0.034407705308929566, 0.11260373998553523, 0.09974591178639282, 0.025825429136954972, 0.0985619688646928, 1.2764048311979541, 24.180296198014293, 73.85943058998355, 91.30615665066628, 85.61810801106115, 57.49201528487667, 53.61554861068726, 48.64450139384116, 51.74906130759947, 87.30718258888491, 91.51274004290181, 62.7490895794284, 67.15453886216687, 41.9164990609692, 7.845194849275774, 2.0847679386215825, 0.2954419305728328, 0.4373560719672711, 0.4321585637667487, 0.21841336792755514, 0.41395738720893865, 0.4670575152962439, 0.056247481580583326, 0.5116140469908714, 0.2228083224186013, 0.010997202686755168, 0.14057111265438219, 0.005300142436153106, 0.15464902014261292, 0.008287126434996964, 0.051036674093695424, 0.1347297841622945, 0.054614304700085235, 0.06482211602551323, 0.036583697618616205, 0.054823013863736586, 0.09302635541966847, 0.009822339822177686, 0.01481429131085714, 0.11599018568954161, 0.054815471728122046, 0.2658952370045647, 0.2657020296300611, 0.19054301263343906, 0.21485988441253864, 0.045368990920964754, 0.0490698506004147, 0.04375589703540168, 0.0546035603169472, 0.05081108801307217, 0.11036274128503377, 0.06474211346358061, 0.09539519887297385, 0.09085949104759963, 0.10538533014515716, 0.017367188345580813, 0.11947658288502887, 0.06537290259955392, 0.06686033125245763, 0.10319838660859293, 4.039391389777584, 3.547360695177509, 1.1700428998278034, 2.128435685749977, 4.1912280551848875, 4.86358457034634, 0.9576767082175902, 0.2051132388653294, 0.06776255300088276, 11.267203457893865, 36.4574933052063, 54.91970531402096, 62.70151907397855, 83.61732267564344, 82.25533454648911, 75.0479793548584, 54.26512841255435, 40.38526065887944, 60.194289069021906, 77.33367781485282, 80.18334250296317, 52.844889163970954, 16.457892617871686, 0.15914859160059885, 0.1883754128169629, 0.1694558909343135, 0.04341849276135045, 0.037456287086130156, 0.030412181400724, 0.037327457910343524, 0.02146340685055381, 0.05034641738259985, 0.04213260268912681, 0.03739356363732969, 0.030064894592449553, 0.039211946103962204, 0.03837150551619069, 0.010298535287860903, 0.04327562502435139, 0.05697614227932307, 0.07878517927301508, 0.045882254508474184, 0.07112206305347143, 0.10621984504283437, 0.1081946358505276, 0.03787920975516881, 0.0635060191064352, 0.06064311405944248, 0.029722828673379078, 0.09708134307255668, 0.04569512604164981, 0.032235443847434174, 0.014048895738538236, 0.03465127147313568, 0.024251147180855758, 0.03650084137916565, 0.05066975628236129, 0.030640960152771686, 0.049596110869559555, 0.05248389462189329, 0.013265333348704923, 0.057489068788145824, 0.028791847984276475, 0.011765911589346588, 0.04544062014188498, 0.02477179011029582, 0.017613989316047202, 0.14801191015829965, 0.08339590242793483, 0.09297776246263136, 0.1387983545540802, 0.15338807006276425, 0.14583603659224126, 0.20333822846653002, 0.08028139495441029, 0.146571496321309, 0.12959270497723935, 0.20939956208871258, 0.22360018154065456, 0.13831555062244016, 0.1315830167262785, 0.16967810239763031, 0.21567121748962712, 0.16434082911620218, 0.07568495167839913, 0.11185516483120381, 0.16245252963516021, 0.176915273731274, 0.14285178704848214, 0.10698620109788834, 0.31798887877695026, 0.09869215784654503, 0.15168324863958746, 0.18607092841017633, 0.17695293461363162, 0.09968429533464294, 0.18263891579643374, 0.15625774349656799, 0.17190631509067553, 0.20246517934626151, 0.15767879063083282, 0.2188561207825138, 0.19988683382830313, 0.17651631046206723, 0.1453273695322775, 0.1871068018578714, 0.17835217888557142, 0.15055302380313798, 0.19685841165483, 0.08672974853506012, 0.16255696274099812, 0.12616429297674087, 0.2605189851695492, 0.317423751036967, 0.20943615044797623, 0.3083942710391937, 0.5047910840761277, 18.19331980520679, 73.70164932743197, 106.48386216932728, 107.37180048419584, 95.90506507504372, 78.11652014332434, 59.4221979571927, 56.422659504798155, 80.22011080095845, 105.60964430532148, 99.88616097357966, 99.14963399210285, 75.89052800209292, 29.414265771065992, 3.705492029266973, 0.2991368952057054, 1.1359701281593693, 1.698960421546813, 1.343071763553927, 2.9496799793935593, 1.3086012390352066, 0.22282074836473312, 0.6333666234727829, 0.37778587170666267, 0.19862036791539964, 0.19121966745343902, 0.280454829936066, 0.31010353577233135, 0.21010637012941225, 0.18585444728453315, 0.26488004793082515, 0.15297631312522197, 0.2614688116215891, 0.2552676516314668, 0.26837071223605063, 0.25889993495037483, 0.08609602528233683, 0.11874425645557143, 0.2440616698755372, 0.0913106402262084, 0.6811070165807201, 0.4052416968249506, 0.8923252407581577, 1.6296150006594199, 0.14210805356983217, 0.16291785144036816, 0.1691204057105126, 0.22629826660117797, 0.1925081813768033, 0.20662123697900003, 0.20999632925996858, 0.32632566207358915, 0.2755945229962949, 0.19197003525351325, 0.2334421284256443, 0.16878230046601067, 0.22027938957175902, 0.17173115674766803, 0.38550528006688245, 6.985619683419505, 6.036096234475413, 2.482882627556401, 3.246830653759741, 5.5959508976628705, 7.654028333002522, 1.3128419340618196, 0.4023081010147449, 0.973795504579621, 13.687761829745385, 45.65876968445317, 64.88130569458008, 76.85453676408338, 85.26965248969294, 77.48227288646083, 85.02095853128742, 61.7229740081295, 53.22331551582583, 74.78922843933105, 93.51430985235399, 94.75482217727169, 56.08824606864683, 13.274938252664382, 0.12820237796873818, 0.24576359548636023, 0.1842086452750429, 0.127011647508029, 0.15831331061499734, 0.14813641476775372, 0.17693715320239145, 0.09719473940710868, 0.1768855801633289, 0.18513608663793535, 0.20205861648484585, 0.19890912177581943, 0.2249411571650736, 0.1545582234018272, 0.14846456086924, 0.16734311236969887, 0.20052374400679143, 0.1819339157232354, 0.1108396540005361, 0.1422263069018241, 0.22439033994751595, 0.16597656473036737, 0.13785600512018129, 0.1333452181349839, 0.10613452583070725, 0.11020448284163592, 0.22616000305260384, 0.1773655495696491, 0.12252849331426045, 0.24536680790685841, 0.1595156396468801, 0.1454297342007199, 0.16696870987934453, 0.10655713823413658, 0.14138341100225527, 0.10985568300971102, 0.08443697761263579, 0.11534346192474328, 0.10600982969927211, 0.15742490909272627, 0.1613393885594222, 0.22048419551743617, 0.09975125141922506, 0.11246133190129073], [0.012573326126702372, 0.06108443432998273, 0.053150222576673956, 0.02184271613406318, 0.047983093592788906, 0.026114265351826628, 0.03941704316305057, 0.017087060635188417, 0.011096160179154288, 0.017537102816746603, 0.017720006308668566, 0.019383311512008793, 0.06078327367562921, 0.012099348485559948, 0.027789885418549664, 0.027233810922611627, 0.013630003649591198, 0.057248827445531086, 0.060492654391113794, 0.02916961934627785, 0.053718977742978645, 0.016417794733218128, 0.025912376285921183, 0.03170372903226845, 0.10002124378637922, 0.03412774996832013, 0.016990537387168696, 0.06715587265188656, 0.023168444693569216, 0.007543050610805832, 0.03068759000950283, 0.10839584118296063, 0.035406484779331, 0.12292530387640001, 0.07378491573035717, 0.06473658996964655, 0.049001216783278415, 0.016937788403142365, 0.007540151446817384, 0.03784883053853147, 0.08134138484996173, 0.028215747949997746, 0.03232614865766899, 0.026665337293619112, 0.15837398477860037, 0.035191777147232525, 0.02874444629396162, 0.05003015330481914, 0.13507669941792566, 0.35537222280137004, 0.03715777326555502, 2.4236874426564863, 19.69731342407965, 44.02379635841616, 76.0525454244306, 76.70626332682949, 68.49067857188564, 58.52230425803893, 36.0433380834518, 36.095960601683586, 62.92646700336088, 65.20101808732556, 66.06755595053396, 77.45417302654636, 42.52413695858371, 17.20702217471215, 3.1442155664966953, 0.13177098405937995, 0.1734104674429663, 0.4615671776475445, 0.11653821434705489, 0.2405587634852817, 0.058273764988107074, 0.12714733700117758, 0.1643108904001213, 0.27080126407165683, 0.04733611701897556, 0.11377625287540498, 0.06006424653253729, 0.08060724279212375, 0.054192343471391555, 0.01614287450549103, 0.05211907589147168, 0.04851783062481592, 0.04809000882350149, 0.16419818354470117, 0.08775750911163707, 0.2137832857307888, 0.3262696457245658, 0.26125118136405945, 0.43784826813686284, 0.10444924731047885, 0.7774396312813606, 0.15571772811874268, 0.09571087306305286, 0.013533877809682201, 0.061573661908867865, 0.07602815140759753, 0.041435420543195746, 0.08764615057096367, 0.11093174542991385, 0.03634666235396459, 0.10336470429695423, 0.04123462889824183, 0.05961674010200847, 0.10342552401726285, 0.14103110248763717, 0.07238384050827834, 1.8790271205286828, 0.6877501020508429, 0.6494256649767199, 1.162525432244424, 0.7998413292150345, 0.23884815043739735, 0.22304761764262954, 0.23253848175368003, 6.806416886468088, 29.386862131857104, 33.922708649789136, 57.586673844245176, 67.13375814499395, 63.741731643676765, 35.713141195235714, 58.85877301616054, 51.59694394757671, 56.194671738532286, 71.14196546616094, 72.56264009783345, 41.5029243500002, 9.904073919019392, 0.546080403991284, 0.22016213215406866, 0.04020551617647852, 0.0347895311912702, 0.07947001591204636, 0.03059399321735386, 0.12653045236102997, 0.020003365840943112, 0.03554777820564566, 0.05942139534219619, 0.07006220339286713, 0.05120733167014776, 0.017141412658196305, 0.03214362054882992, 0.1127918528753423, 0.04717741807502124, 0.10193709945005756, 0.0533148855151188, 0.02486111021660749, 0.015324110375537027, 0.029526604827673688, 0.07592985466603311, 0.048034111218106364, 0.01953632033790552, 0.06162764429445229, 0.04717798498008521, 0.030468718689535896, 0.022795229639497497, 0.02198152360506356, 0.07819085592223753, 0.10339121860001357, 0.03702413688804354, 0.03406369352653142, 0.050899915907892494, 0.027268472570745696, 0.010228045622728044, 0.034206672346279506, 0.04982931186415015, 0.015463117987007625, 0.05540747383248903, 0.0616360406181024, 0.05213633968284534, 0.04273079095348235, 0.018686403242510655, 0.05783661989675415, 0.00797203159891069, 0.08668602789722143, 0.02828363100096824, 0.05219530930081683, 0.042564592008749326, 0.024047683804265918, 0.06672393695841874, 0.05079057217845994, 0.06972772174424703, 0.021559154434550195, 0.018842125934879148, 0.04045185940941015, 0.020848006505759496, 0.041458721107412735, 0.007838690165250052, 0.009475705146248783, 0.07785229102498101, 0.05254670617080504, 0.0348420235358419, 0.028442310792724454, 0.02687799372530032, 0.07478449193219985, 0.055704834690738114, 0.004485662174110692, 0.05970901539248805, 0.06730648553780011, 0.02993310448683558, 0.02662697927125039, 0.02825072177896096, 0.054582477577271006, 0.0840603304846633, 0.05031219240458262, 0.0603584089737025, 0.03956205977667724, 0.081784819523173, 0.07752252081709524, 0.11979951192775082, 0.050209843057898745, 0.06218464001111927, 0.03028173194897752, 0.054923199012034365, 0.07356415217321727, 0.05688092904165388, 0.0018190573422133083, 0.015749978652644544, 0.21340653901138615, 0.03734817675825569, 0.06982052563539437, 0.043015300686801636, 0.014540061519871798, 0.14290138358070006, 0.22227253584611803, 6.882315239598674, 42.296353155566806, 74.41683861517137, 93.7314679545741, 79.13665802248063, 70.21215192733273, 52.76560237330776, 45.38059126946234, 63.96785236174061, 91.82158747026998, 85.04379457043063, 80.25461196899414, 71.19918500223469, 33.304931425279186, 13.751157137655444, 3.220568914567271, 0.29672901957265796, 0.2109242149538571, 0.10819393871051651, 0.06616067847297077, 0.2869875987450923, 0.049668801122254906, 0.06901656232413746, 0.34437064862539696, 0.0628110509546053, 0.06631083936700899, 0.04009708026123624, 0.029824289358070785, 0.0279190746556607, 0.1015717521189682, 0.055114548623321526, 0.09922887904629593, 0.06477419722584948, 0.0381354431832029, 0.06423244282843606, 0.12875959968134282, 0.05797076189229566, 0.408925170138959, 0.16854904201482573, 0.24578323798073878, 0.15949064985879008, 0.40279312660136535, 0.6627829901633725, 0.023807350531100266, 0.02043576884804474, 0.005908682942390443, 0.016911699278880993, 0.048345560433282975, 0.05261574984498082, 0.005950155590976319, 0.07040844449112493, 0.03089193055676597, 0.11053314988291073, 0.03954181973371775, 0.01524354282376026, 0.1005753398602528, 0.2939507863934963, 1.8516705497618646, 0.17532390992968314, 0.3932407456299951, 0.3034310018823993, 0.23501245545283442, 0.1769684249114606, 0.39000004049270387, 0.28193304255124063, 8.214616419807557, 41.28380898506411, 54.839586980881236, 68.23408495995307, 77.97082762564384, 80.85791956993842, 55.35823806639641, 52.59392807560583, 55.64808945502005, 53.74551634634695, 73.82443520330614, 80.63259509301956, 61.551652723743075, 20.06704584244759, 2.1123015063424266, 0.20361999560508037, 0.10903861193406968, 0.04512830141691431, 0.05178685803266783, 0.022162816397124724, 0.06359083653097192, 0.028767076531244863, 0.05362393687509241, 0.038600665396980705, 0.028385273631541964, 0.032295742627954295, 0.03431356459435436, 0.031708239374922655, 0.10197024041366193, 0.13058650487613294, 0.08615431691249532, 0.03647874357298978, 0.04456080263480545, 0.04703156259511748, 0.029182416845052957, 0.07953030703168723, 0.12569658097720918, 0.05937639150708433, 0.057240756709248795, 0.01106293781870796, 0.040088798850774765, 0.03212313535773466, 0.06993084229649076, 0.03555939592901738, 0.04536474296342462, 0.05995021434500814, 0.037284618273617766, 0.006918788065142449, 0.018711864174674117, 0.037862076198742274, 0.009677465892426912, 0.021519467249632846, 0.03022352458849069, 0.05550596975691377, 0.04604697873395297, 0.09350535955520407, 0.03605704281419035, 0.02327435060344156, 0.03421226095768713, 0.039562645833939314, 0.21155891879912347, 0.16605199374739202, 0.1217650943585942, 0.07105937407862756, 0.1565181827473064, 0.1506205008275086, 0.18585273124758275, 0.18964825258139642, 0.05570433673358733, 0.1357399630210092, 0.09904287289828063, 0.10251243914207143, 0.08437693930200993, 0.15349421920555253, 0.13242378290141785, 0.24274525502997063, 0.17188039067531788, 0.17251293415263777, 0.22927149980058595, 0.08439084379783562, 0.15133415769425132, 0.17714392033315476, 0.16531389867586477, 0.13550483531528904, 0.27250446138843415, 0.12150437165532382, 0.14410835510540393, 0.22257871054593595, 0.15188626193952176, 0.14196287990818102, 0.12475842204425605, 0.30271728372862267, 0.1413863527798845, 0.13779553013943857, 0.20616120118046963, 0.2678913250565529, 0.1330889464025536, 0.18134278695910208, 0.14679922361768064, 0.22738949756228158, 0.10653683690414315, 0.1666083267980045, 0.1223574028981309, 0.10095544970564305, 0.269488250656474, 0.09897986982738781, 0.1580871154944743, 0.2728143899190811, 0.1829783846774409, 0.5501556240262524, 0.16137780020794562, 3.6830273895494403, 35.66850070030459, 78.31058332996984, 109.975077567562, 102.19140068177255, 93.62013539960309, 83.68311651291387, 58.90849690283499, 56.48627642662295, 89.41544086702409, 87.31663550100019, 90.99982738494874, 102.69742565770304, 63.07984736657912, 27.77956504975596, 6.29917940785808, 0.4232777048262858, 0.7658160549979057, 0.7170335984518452, 0.8037755277849014, 1.1754408166293175, 0.18445687308426828, 0.523487122789506, 0.5506474524736404, 0.7110738634101806, 0.2803073120453666, 0.21943309224180638, 0.2583389440851827, 0.22884573877578784, 0.1639544296889536, 0.41865752048550114, 0.18203787385456024, 0.492292145086873, 0.31113671259053294, 0.5599947057424054, 0.3574105376197446, 0.36394833196555415, 1.007715119950233, 0.5442645917496374, 1.357311315594181, 0.4879982222712809, 1.1364546634497181, 0.6240039258714646, 0.1232982814432152, 0.09903306697284985, 0.21270114057246717, 0.17386163194333354, 0.3060113392289608, 0.2990791321762147, 0.26386507336170445, 0.29475781405645035, 0.3394918636448922, 0.1852426954334782, 0.1206623720786264, 0.2701233988327365, 0.3294186041720452, 0.6373736923260074, 3.686834049801673, 1.6844026672263301, 1.6596608464756322, 2.1954187366270252, 1.9653461080405021, 0.3355211380027956, 0.8944632389372396, 0.6501541226621598, 10.835212238373297, 50.55763744538831, 62.09440285159696, 82.65887583455732, 85.84721365282613, 80.0839182638353, 53.00123483903947, 71.6610284005442, 66.52612809211978, 70.38543439680531, 94.49829132326188, 97.75521570636381, 64.81231904798939, 16.625742604655606, 1.0909317578038862, 0.26032712610979236, 0.18075291457916462, 0.1913718278369596, 0.15653865261664315, 0.09878637900035228, 0.23440824190695442, 0.11639868675340569, 0.17535933383530186, 0.17367256144362112, 0.13596021329923985, 0.10320472215572674, 0.13264412511019938, 0.13890231268540507, 0.15963905641148168, 0.1711245376857058, 0.17223265322466053, 0.12102150643664984, 0.14841062827937065, 0.16236329571374003, 0.0730594917530975, 0.206381190988806, 0.2928500712638901, 0.09434181265532972, 0.12969652521273783, 0.1666214422232682, 0.12047430515409478, 0.10288082018134095, 0.11602366373183266, 0.1084586910362686, 0.10434568754487461, 0.14881113904618448, 0.1662408957077611, 0.11627508612770228, 0.11662310454994441, 0.14843498987536277, 0.15970307071843456, 0.2150784033320604, 0.13937334950652816, 0.2318469801497075, 0.22476325622729718, 0.20439437260070156, 0.188844840853445, 0.09658718571787882, 0.11353583916300729, 0.1463048977236594], [0.07722377717014282, 0.021174932612226378, 0.04556690207532337, 0.01840912729441639, 0.0007285287879752897, 0.01966190513133282, 0.07544175706683628, 0.007484466909626199, 0.05588345958160297, 0.08296372924721049, 0.060453262150047295, 0.017390983036508965, 0.06224357898557379, 0.03301798350988858, 0.04226334325428452, 0.05984694569281513, 0.06819666438405553, 0.07937195665773847, 0.07748698965916712, 0.049572442583138907, 0.04395973387985461, 0.0011979795676926453, 0.01956660570877214, 0.033155013656904625, 0.06120548771333791, 0.015404148369036136, 0.045302754959031466, 0.009323534229019237, 0.07271381755990368, 0.024785125785837733, 0.009745045381057407, 0.05679854011583713, 0.05010643650987937, 0.04798027055878793, 0.0361703587095103, 0.04291236145241607, 0.04495635298230956, 0.031583367043264934, 0.044456587864025954, 0.0607470300559315, 0.02130427123648265, 0.14919871824883646, 0.039807866748061874, 0.11973415696693045, 0.05006952256324792, 0.10504704870043263, 0.07450716044273108, 0.06916853118567698, 0.08667262901942577, 0.06738047430952711, 0.1570184688053785, 0.26476050757112046, 0.02704799821179721, 4.058230043418946, 27.848035904668993, 61.04984037337765, 76.18691013705346, 79.13455563206827, 68.71270041311942, 59.76394230319608, 39.700967880987356, 49.148831905857215, 59.74159263795423, 53.07661887138121, 75.70783968894713, 69.20216514218238, 42.28224046768681, 24.31132297362051, 9.022095645627669, 1.7119921287221296, 0.15090389207245844, 0.06810895497760466, 0.1634229332088463, 0.19255581672393507, 0.11833354139760618, 0.669044992856441, 0.324351851858439, 0.00849449398717092, 0.02974059425234314, 0.17527117243697568, 0.3915497750764893, 0.6667065247893335, 0.1680657324651557, 0.23299862480451985, 0.06817529819184734, 0.23920995844227655, 0.09038592613632641, 0.5270462447116452, 0.22440871073594018, 0.20224624673926062, 0.2501365326104626, 0.2062270234549238, 0.018973494692134763, 0.16953299002301309, 0.55640175337753, 0.15195271240607386, 0.03941583657456983, 0.06300067303762322, 0.15713442387359758, 0.24080725176440132, 0.09210439924631389, 0.32240068720233056, 0.5874839016506749, 0.5062301342766131, 0.08860003728900226, 0.07229670566777069, 0.6086496239708317, 0.8274874199301967, 0.4981977943210833, 0.009550281890457677, 0.031938295578584075, 0.13804340554821876, 0.2505542803555727, 1.4161007803293968, 9.301707686916474, 34.60333008919993, 60.1925906827373, 54.22157049179078, 72.04313785799089, 64.8164257695598, 51.8725492877345, 36.590442042196955, 49.29661504683956, 58.10079066984115, 67.46392757661881, 78.17440648232737, 47.487888566909305, 17.78580319496893, 1.6399953081723184, 0.25529426552595635, 0.05589605789751776, 0.05414687232264588, 0.1043169592477141, 0.03553865026802786, 0.03841904127189229, 0.08859473596056623, 0.06457500670465731, 0.027464244424575762, 0.049619189268278505, 0.04843322770489801, 0.03336693655939833, 0.054100190754979856, 0.02672776962900835, 0.08195017960162894, 0.018892212763368603, 0.1698062076203285, 0.10074647624165782, 0.1036264842015601, 0.05998063952692094, 0.03272448756521748, 0.03516254323204199, 0.017901345066005186, 0.03790018907297523, 0.02692839273461892, 0.09728470877293618, 0.057501345347132415, 0.047119689519487085, 0.018465028730251135, 0.0754975282677239, 0.03906406432149872, 0.07108735160962229, 0.03664199307921433, 0.053167628094313614, 0.016438567207284992, 0.019984317064705878, 0.003180982598531691, 0.12528503088340645, 0.038904013232358044, 0.08061065954426605, 0.0319064780318689, 0.02829185878527501, 0.02525909480849101, 0.0401001331216145, 0.05271896104057951, 0.01867560714843773, 0.05365040138243668, 0.0538725822022365, 0.014445105879267138, 0.04972169566298685, 0.10245479102576933, 0.09846900409508137, 0.023967681242333307, 0.06446046889909814, 0.04759970872152237, 0.06981736169226709, 0.07697302893164658, 0.029560873855746565, 0.02587484180807106, 0.04970818953288179, 0.040190052691726916, 0.03094033390704182, 0.0383838931579263, 0.03974233941745855, 0.011490589165459237, 0.024252058825485652, 0.03904736743518903, 0.009215197905207114, 0.04224606414115237, 0.07531688473517857, 0.020325162988756935, 0.07651598087602085, 0.032629094296886076, 0.061966959957874594, 0.03750661906275538, 0.09263499174267055, 0.037863413022170146, 0.09150916425090644, 0.03474417112527355, 0.005131125245468631, 0.06566834440755268, 0.05548276112324769, 0.05930228782216868, 0.03216790170558999, 0.04482937007842045, 0.08742565514459726, 0.16812432286960466, 0.07126463201618002, 0.01637991551580208, 0.0739370990965155, 0.03591829279978429, 0.05952963590501778, 0.053506173839372013, 0.07018337551985057, 0.10662835376757769, 0.05721202458164865, 0.12932734744202706, 0.21010698299975167, 0.1684448540571236, 0.5167462845002452, 12.447740781691767, 52.84561480245283, 82.37465304713096, 88.344068988677, 85.65166781025549, 64.83782622121996, 51.158921103323664, 54.23661670377178, 66.8240007277458, 74.14587343892744, 85.20537268730902, 80.47275850849768, 56.107955978762725, 34.31143906808669, 12.469794307985614, 3.408807626655025, 0.9808229210395968, 0.2067583207521708, 0.09342620735086742, 0.12452425194844124, 0.04568716255767692, 0.18743755265830025, 0.3154116057820859, 0.0672396750099236, 0.1599115079208728, 0.08229586911658127, 0.10949169165424763, 0.627565989571233, 1.398281452636565, 0.32073478304570724, 0.009487127517199805, 0.04945417009894887, 0.11500023155202789, 0.10363670381447, 0.2319228841412452, 0.9647298039447878, 0.25908054783940315, 0.13551939098585036, 0.15366836631249997, 0.24407336037726174, 0.0648912861041965, 0.6987934126969307, 0.17235217826260676, 0.1890690747888819, 0.09499056655312739, 0.06792383749158153, 0.12495866210590448, 0.23810501450732832, 0.43563660294298207, 0.5140973669627021, 0.31864002286907167, 0.23155065734059582, 0.15975965397252193, 0.7544380558594581, 2.2665614610718143, 0.20816134949845655, 0.02559921103379419, 0.046563360299314224, 0.170780916608149, 0.07682497477940015, 1.6884206451715964, 14.935675667178247, 44.9603916752723, 78.26143603171073, 62.37844128762523, 75.41128496969901, 90.33806077895626, 68.74058846504458, 42.860758689142045, 38.420180659140314, 61.39691522044521, 70.71555675998812, 89.29492996584985, 64.32161092758179, 30.59054340085676, 4.469284876700371, 0.24124088817306105, 0.23168403324821304, 0.053928633025216485, 0.02269649814303604, 0.03514379323009522, 0.06995135047022374, 0.06999940716571386, 0.05576122259240478, 0.04321678564132702, 0.09953585047755512, 0.06169856488404255, 0.057490704385864164, 0.07414985703484667, 0.04696759042300044, 0.04485417217496903, 0.012187696617817687, 0.0888628284296682, 0.03855950732324873, 0.058506169251256415, 0.022718354631515763, 0.013191640478438668, 0.026177002207165765, 0.03388879565341819, 0.08925935553927576, 0.1251202989970484, 0.11062434498941708, 0.03405764526236923, 0.07179795178554713, 0.043948395778575254, 0.031068414231882464, 0.03470504701498055, 0.055471001673609986, 0.056687407571101384, 0.027090247960821278, 0.03758426973476045, 0.06628722853718266, 0.009056293075123142, 0.056593397091473305, 0.0204336678519124, 0.04251694133985908, 0.023078214857847463, 0.06538502977139528, 0.0318261192390515, 0.013145502833198878, 0.045085622658652645, 0.04116541668472271, 0.028455862888104977, 0.1914787277459137, 0.16741501738227185, 0.15827946485050265, 0.21913099312974563, 0.18273610171050797, 0.23134087182341084, 0.18880719529284587, 0.09682705550785027, 0.15987458248292247, 0.21963895538881903, 0.1906196061041086, 0.20033508719455814, 0.1338706471987309, 0.07891919103360946, 0.1493697703605698, 0.11585048189566982, 0.09071057887687799, 0.19612308982158863, 0.13126800137181438, 0.0937951552952009, 0.1270311674283397, 0.13170473277568817, 0.12879840969558687, 0.12357853172767548, 0.3187321679246041, 0.07519450985015401, 0.15133538343493017, 0.07063951959172565, 0.23497997332484494, 0.18414683730131198, 0.1566064360761835, 0.15120467351328942, 0.24640899391904955, 0.07676005648869662, 0.18351012630568397, 0.19055534664901996, 0.13546521324784527, 0.14078934046049274, 0.13137418115811964, 0.5176715348516742, 0.14119607186125172, 0.23151774620336874, 0.13614430422744445, 0.3086231168239348, 0.1645265901160817, 0.2953345863328826, 0.28648507571028126, 0.26214048687008124, 0.2504646787119489, 0.17723004393760236, 0.278816290440098, 0.40206803970279237, 0.1749425666827348, 6.73920609297291, 46.00987672805787, 89.55423785794167, 102.44309917573007, 105.77434462885704, 95.1045250123547, 84.06355504066714, 57.32037236613613, 70.02983231698313, 81.96534587490945, 75.42336586982974, 97.29741234933176, 88.1182110694147, 61.152159321692686, 35.1603497997407, 13.670838763636928, 3.2559231981154415, 0.3493962466957108, 0.1861140744820718, 0.4636487917553994, 0.2910997135744941, 0.2674483730187339, 0.7819189167311116, 0.3620910590454456, 0.7745822458978623, 0.4715650540686423, 0.6507422943269053, 1.372034299758173, 5.05010700033557, 1.207799144810246, 1.138289352097819, 0.2377142790224283, 0.6532620494404148, 0.46143023177020015, 1.3352566861337232, 1.559705739059756, 0.2849643298935506, 0.4302191049341233, 0.7413011801338966, 0.3172639144524452, 0.5193064277691226, 0.7433604857613965, 0.41890159609817695, 0.45913377596486005, 0.18700036160167188, 0.31598709103080536, 0.467598281440235, 0.7150349669879483, 1.172708395508028, 1.4173837630979478, 0.6869125534449855, 0.32152584543631924, 0.7709683333673786, 1.5863132596977296, 4.233783320073159, 1.268421582156612, 0.09389748932012627, 0.14663515822781673, 0.36991156036815337, 0.673541254814594, 2.0057665003884226, 18.223455375240697, 47.75306040240873, 90.34201452808996, 77.6944495785621, 88.90674867937642, 79.5427723853819, 73.15120743167016, 54.64498642952212, 60.91613069657357, 76.46294301556003, 87.65690111344861, 108.55455983069636, 70.58527131234446, 26.5164481055352, 3.406824378236648, 0.3973086112208905, 0.3422438966170434, 0.1431199178219803, 0.2082453127349577, 0.1569200724723839, 0.20685271810620062, 0.14968650175198434, 0.11467418453145413, 0.12851160169849474, 0.2051606290643254, 0.09184357695161335, 0.1384037733078003, 0.1470497803341958, 0.17632598357815898, 0.26199162066463505, 0.20422469944723193, 0.23987368169811465, 0.18525840023592596, 0.25411176284955395, 0.15965168154047382, 0.1099833975275678, 0.09159914127761319, 0.17650543201354243, 0.25721870903526584, 0.1901594477315103, 0.23053641821588242, 0.20120971445595065, 0.21884049258885846, 0.10881455419885536, 0.15294470433746615, 0.08380090246998495, 0.20887574180960658, 0.16056018520987805, 0.15530155851475655, 0.12047063559293748, 0.16364439390599728, 0.1368258620101598, 0.2889620218305819, 0.12730990851958915, 0.2738969027996063, 0.0894987197112172, 0.16968991547342271, 0.1593393321719862, 0.13748520324307104, 0.18409265956330687, 0.11298699845229426, 0.19843921876482426], [0.017055154988361944, 0.04288909153171605, 0.05534313776860795, 0.06609318612684166, 0.033404145449880636, 0.014153549094654381, 0.07491576875890456, 0.040864033864871155, 0.04540272943315007, 0.030772056948814182, 0.057256691338073824, 0.013450637568659602, 0.004798304571229364, 0.05437671402168851, 0.022813276755773736, 0.10626898958317696, 0.035652828012262626, 0.03968674824723313, 0.033096446235093384, 0.1636277851197989, 0.11290213123204247, 0.05876420681635219, 0.04039356777925165, 0.04921718846045194, 0.06308678132031234, 0.054182709915743726, 0.01106240442999068, 0.08706192425902813, 0.043075909732931086, 0.08953392911221712, 0.03018367652510924, 0.03331645902606749, 0.052977052231829976, 0.08911959811924927, 0.05698377634548853, 0.017027296200995485, 0.04828447641264047, 0.045959579593111435, 0.02080699973439257, 0.04241958688644152, 0.04634745373961426, 0.0685809494086331, 0.07315178236533558, 0.029273447242655584, 0.06926422322829885, 0.06479505780002763, 0.14779950462041364, 0.04748068547116653, 0.05460827941856077, 0.033713127861941056, 0.02799230691556248, 0.07201583485209173, 0.19624978544250612, 0.3402125072335044, 0.17154078389848434, 3.8256442787185794, 26.821049567191835, 76.9767656633931, 81.53182198924404, 74.05529022216797, 67.69882263675814, 62.39380521159019, 59.191978362298784, 39.87245390492101, 36.7374603209957, 76.2374302648729, 84.54585752179547, 73.18371603565832, 60.57826557467061, 31.802983322451194, 18.949699863310784, 8.593376663423355, 4.009541662469987, 2.7735719325080996, 1.4496896295778214, 1.3958797363504287, 1.0758305100664016, 0.8547313451286286, 0.6931152915762318, 0.5221353146818377, 2.163252849732676, 0.9134821377454266, 0.29394128690323523, 0.19337778310141257, 0.0457493344231719, 0.7048456298728144, 0.30225723260833376, 0.6970401132299054, 0.140865198486755, 0.11581999159628346, 0.14871706344908284, 0.18525522863191946, 0.29907661940782304, 0.12329563843987643, 0.3405394122725533, 0.26066487895384916, 0.7510316612259035, 1.8952151099520347, 2.2146236415832274, 0.8390634374753122, 0.27703060077563413, 0.03769292398506115, 0.2779448807479874, 0.44530012795040685, 0.30362886707148246, 0.10307077168216629, 0.3597960128418861, 0.4838897846639157, 1.3252601580273722, 1.6876769883017388, 4.721858059206317, 12.553046614893022, 27.199687727036018, 49.094742421180975, 64.00502858623382, 64.40007009813863, 63.319829740831935, 90.12404841761436, 49.17460187788933, 47.76056389654837, 50.13218187516736, 59.0898790667134, 68.61225635774674, 76.59215373377647, 66.50682218613164, 27.702055092780824, 3.261012963710293, 0.37524834335331, 0.2574657877126048, 0.061519886367023, 0.03775643650442362, 0.06511853842605507, 0.04725061777618624, 0.0400972526310192, 0.01563546766016272, 0.05010208896090908, 0.10137705087301233, 0.02014574328167064, 0.04506077459682861, 0.031121645851301092, 0.05776182673270664, 0.022213837852881804, 0.0710588071735636, 0.04827235690167835, 0.073178740999391, 0.08957237906513676, 0.09146155954729165, 0.139953799004997, 0.16700136054667736, 0.1307511678145778, 0.08790075223171905, 0.06342751807683418, 0.04925382661543066, 0.05331160282836326, 0.02105454572536532, 0.02299899562081743, 0.009088905438059762, 0.025043580868852236, 0.12657693091539607, 0.11119785373129192, 0.047082204837352044, 0.13720441669706376, 0.05720323372271754, 0.08411017982589622, 0.015836780244905143, 0.0410033546147808, 0.06445362773393432, 0.06187883303350499, 0.05419414377801361, 0.031480895122513175, 0.07753940539494639, 0.07119669533905483, 0.033751669745411605, 0.07968972226785076, 0.06976136066500219, 0.03889968483558586, 0.015232787906913268, 0.04235099520414107, 0.07240390435101525, 0.06240141991105291, 0.0494468386375135, 0.031529777277741707, 0.005021028355845521, 0.0331573540555133, 0.0900287836069061, 0.04271515126850817, 0.018486182333060333, 0.02387567216740741, 0.10976823407315439, 0.03357009924647789, 0.01723713917477477, 0.04057257571407864, 0.027978442639352816, 0.047986253705476566, 0.03294080781239656, 0.044583907846601746, 0.03773520437760219, 0.1387083851882527, 0.06829494580386147, 0.15040591959991764, 0.01678935695259321, 0.09895109556495182, 0.06490378865912076, 0.02790648400062515, 0.03647733397120911, 0.17305832746769154, 0.02328295951649066, 0.012669630082053764, 0.04538452335362954, 0.0892391921051087, 0.07121969329854173, 0.024359929750883774, 0.04381809954441363, 0.037528835612559514, 0.04957190632159191, 0.055978312757947755, 0.09526917740942971, 0.04484007615716227, 0.05308899299932584, 0.10005306707875383, 0.09088972087709174, 0.013244884546786068, 0.1526569923566234, 0.0812877586952621, 0.06474779783597877, 0.04624809979671433, 0.01222159983890672, 0.026956647972486196, 0.23798659263599306, 0.21351916925801387, 1.1930200217231628, 17.53363597777582, 51.62941332786314, 94.1582061398414, 89.21524309342908, 84.61138463789418, 63.56840210576212, 63.973818286772705, 68.72657775878906, 49.65150325529037, 67.4956673960532, 91.43642640882923, 84.8263854365195, 78.51035748758625, 52.41606427777199, 23.375482713022542, 8.967389368241834, 3.661405569122684, 0.4590351651272466, 0.372041438015238, 1.1344309655889389, 1.5620415104973702, 0.6980253635875641, 0.5812863729173138, 0.5402086771303608, 0.28019540192138764, 2.7005565214541654, 1.6717227476258434, 0.5839431045516845, 0.18923508604207348, 0.05299183006788935, 0.27874348144377437, 0.23802374790032066, 0.8982463036814045, 0.1463158681027351, 0.1317283436055145, 0.13187031501964216, 0.3550707212378902, 0.22038904739724052, 0.06899223903254156, 0.15411939291704088, 0.23798400325880897, 0.546263407074636, 2.484778112942173, 2.4391491807276204, 1.379480674382179, 0.9431341530815248, 0.4881116645711084, 0.8046767536190249, 0.729680361766969, 0.18453640833256707, 0.06520302260234472, 0.2238150998469322, 0.21809127392067065, 0.8599789861229159, 1.9941589813078604, 4.299744838668454, 12.46703492056939, 29.07044649124146, 60.13410814346806, 78.9116551799159, 83.12832863100114, 92.83950528790875, 105.65606947868102, 72.9943440037389, 44.58423637574719, 45.62810851681618, 54.60358973472349, 69.18578532434279, 82.17763239337553, 82.6999116713001, 41.34813977826027, 7.940597188088202, 0.2917590088421299, 0.32595089186103116, 0.1046676742994497, 0.07194684097363103, 0.03433079008133181, 0.019116155585394274, 0.048604919500048124, 0.018967846708913005, 0.048374989700894204, 0.026867354679251873, 0.04267686602449225, 0.06918867929808556, 0.06505032595727714, 0.08187852739807099, 0.01412716311132235, 0.04081214289932002, 0.015628494344831958, 0.05728434711214035, 0.06167588485104423, 0.10087739300703812, 0.13499491187112947, 0.03186015652552728, 0.06892367416331846, 0.10616620356637625, 0.0543461969092248, 0.018659220527737372, 0.025657458613897045, 0.043847015533115596, 0.03409580793231726, 0.03187833196153084, 0.016915194555035522, 0.07736708923813797, 0.05125518535233794, 0.0422317153143306, 0.13685678131878376, 0.06359884214978065, 0.037358197188305284, 0.062203964579009244, 0.03275139257311821, 0.0312011830148197, 0.03338055760269204, 0.011268303008569826, 0.07719560811716704, 0.05278947943400952, 0.016305861626601508, 0.047525608867046334, 0.049100992074536706, 0.04532532390928076, 0.015543642446338652, 0.14787208379035996, 0.10816012358953876, 0.1566443267849184, 0.18351683723590068, 0.10468861914329952, 0.07527742354619889, 0.22210146841262618, 0.16637110001137181, 0.09781111076834703, 0.15520293235538468, 0.22098616696894172, 0.12101361573102976, 0.15865179890346143, 0.09118703193962575, 0.13510505999288253, 0.1450131968745301, 0.2920477627025497, 0.15285409145778225, 0.17025251512325582, 0.2099381831865157, 0.2120350424440638, 0.2962845660025074, 0.1813791914572639, 0.4089395419484185, 0.2100444395816134, 0.18151327216577146, 0.18923972853489462, 0.18293995770715898, 0.13312447756048174, 0.298832788943283, 0.1805117501006011, 0.1637323254779462, 0.18372216412136633, 0.23863120965899962, 0.2253385269713979, 0.10964935254906455, 0.15574247275869693, 0.10824964862437018, 0.28000152038951076, 0.1702111004100692, 0.1471876608388078, 0.2084817427901491, 0.20122880536702373, 0.2212649003993119, 0.20682015936941872, 0.22994266943104807, 0.30683874483070067, 0.2608392099218984, 0.1457215370910783, 0.1723864990016145, 0.09123470559115372, 0.08845712358672773, 0.32586325140249345, 0.8117765500660866, 0.2539408639554055, 9.25270159398356, 45.28840772567257, 102.06413545916158, 108.66886554225799, 104.49708754016508, 92.91592090360581, 88.2856962757726, 83.10557103926136, 60.04306208702826, 52.88907858633226, 95.07404819611581, 104.64140722828527, 98.9915075609761, 88.57761475347704, 49.55098467488443, 28.923543922362793, 14.392913772213845, 6.120911605896489, 5.222975659754969, 2.463175168921871, 2.915230782762651, 1.7448561975071508, 2.204830954151769, 2.036529036779558, 1.0517906710024805, 6.263513295881211, 3.239411980875077, 1.2722753108509126, 1.077768896375933, 0.25640481722451025, 1.0742217254254127, 0.7297992586128174, 2.0213142854552117, 0.3400164500119225, 0.1793718725563057, 0.4151719430040929, 1.0561945121134482, 1.0707520212857955, 0.4137590623671009, 1.3159180528694585, 1.3778680899450857, 1.8739921455421757, 3.4612050988981804, 2.8276974539602957, 1.6697583756139203, 1.5189265724151366, 0.6143723007652068, 0.7467060836572802, 1.3723038401334517, 0.45809394950347565, 0.17430596293941622, 0.2955250664343757, 0.4691806207260778, 2.09325447678566, 3.4444080389315084, 6.245629249080536, 14.924165471907585, 34.858139022704094, 67.70037589534637, 85.08737994778542, 90.20630836486818, 86.51563259863084, 110.69953933838876, 69.01475429534912, 64.17173716329759, 64.78483892256214, 72.56210665549003, 87.24047091699417, 99.88015190247567, 93.48468026807232, 39.02562987419867, 5.6859545842293775, 0.42360773550406583, 0.525025672489597, 0.31503493567147567, 0.17972981947804653, 0.17038593699614848, 0.13819216450135555, 0.18260252662003043, 0.1477586721340495, 0.24609210931005018, 0.14300060728865285, 0.27665521769273665, 0.16830976211255597, 0.23384328270631455, 0.2103805683192707, 0.12362744644164078, 0.2089069215881248, 0.08640801458950005, 0.14940548537959977, 0.12357349853001295, 0.20765046078351238, 0.2834832061442637, 0.18846136788206716, 0.21017954684793952, 0.2699858400850527, 0.19388833473767006, 0.15474366264477854, 0.283717108109305, 0.1035122451702914, 0.15860238623234535, 0.13448770037822186, 0.060561652100014116, 0.2860484975239923, 0.28784102069274076, 0.2697219994039305, 0.2429430742537783, 0.16069593599006055, 0.1320474651912528, 0.21851819939911368, 0.10975115797332219, 0.10012711713751478, 0.10843549389392139, 0.10867936266285759, 0.2380592637364903, 0.11490122234869389, 0.15055334556006617, 0.12503864168519938, 0.20585625222133053, 0.18056516175068196, 0.10914470745070327], [0.02314119877654218, 0.12983417589097254, 0.021347363682223425, 0.03517735554205795, 0.04242657743875058, 0.040102550129015604, 0.03233484758604919, 0.04240878504670916, 0.11533371728634643, 0.028145961170535416, 0.07973759510223905, 0.06570703950860808, 0.07600220400960216, 0.0072526736015964665, 0.04201062616982287, 0.05001304656146996, 0.061156733877836704, 0.06661698342330995, 0.02937690933204947, 0.06681303298401256, 0.08307367818610323, 0.037804623434860865, 0.036305914137272105, 0.043668298711699825, 0.056442837831714464, 0.010084665564429617, 0.051622110824551315, 0.020522932416849562, 0.01863299159242982, 0.01802507018099629, 0.027815451687802712, 0.11558929187876564, 0.028507393792331703, 0.06131405386352732, 0.03730326485369475, 0.027467075119455977, 0.024261301676292094, 0.03530058078467846, 0.017992440581081376, 0.174758690259149, 0.0043873616021066425, 0.015790781453101626, 0.04261439155426718, 0.047008740835853165, 0.15774766193522563, 0.007704476348965639, 0.0420781031941935, 0.012448212477348506, 0.16466546653499528, 0.12253008677714294, 0.061040962670719436, 0.1276439534980924, 0.08491186785601801, 0.13630709791135404, 0.06761043858263763, 0.176489390132408, 0.6185418415454127, 6.803093168043322, 26.381671544044252, 59.897455861491544, 88.68572312016641, 85.9598013662523, 66.94542946354036, 72.38014790319627, 37.481616312457675, 32.739770835445775, 49.7359714969512, 42.648872252433534, 53.851220300120694, 49.90302524259014, 44.777746508198405, 30.025453413686446, 21.042768762957667, 14.80590306943463, 9.814521305022701, 5.65653435645565, 5.0939885166383565, 4.949952710059382, 4.342468765474135, 2.5298167284457915, 1.88123173771366, 2.036997269718878, 3.21033128326939, 2.1346533779175054, 1.5294176868854032, 1.817068012972032, 1.9205727428197863, 2.167215669347394, 2.5085383605572487, 3.0282938384240676, 2.295249676512134, 1.3708911740010785, 0.9258346620105928, 0.757545124619238, 1.187536548222265, 0.8918561498003622, 0.5945900719492667, 0.5311063881362639, 0.8062005944309697, 1.970023779619125, 2.4947975623992185, 4.489779260850722, 5.543347991281941, 5.5694342044092, 3.091782302625718, 3.4930429775868697, 7.2016947211757785, 12.390853666490125, 24.170176482969715, 42.473550150471354, 65.29730443031558, 69.43756226570376, 85.79869393379458, 71.70183673981698, 76.67217793003206, 57.18883568240751, 35.412448375455796, 60.272375614412375, 49.126619523571385, 68.66493378916095, 66.36609538908928, 75.88256559064313, 68.70061951298868, 33.53805357410062, 5.663129821900399, 0.19270045412403924, 0.05048289977675004, 0.04983394669609205, 0.032364165770911404, 0.05404575254708048, 0.06346541261600872, 0.05541246489531571, 0.011693674286136465, 0.03833002951597014, 0.03353184847641857, 0.07978137702711167, 0.023649394692432497, 0.05005101004855768, 0.06776448354245194, 0.04279472482120318, 0.0783094922981916, 0.025960268272507577, 0.04366069145861172, 0.09288320423013742, 0.08043706402062409, 0.04950906029872356, 0.06734898043495995, 0.07799744936487368, 0.06919817878834664, 0.05724086013111857, 0.10819886465586963, 0.042806568540512555, 0.04163268818369797, 0.07932505675501401, 0.06663363817478381, 0.12499900429599708, 0.018917338532065193, 0.03201069663308802, 0.02699009728648009, 0.09513698127721587, 0.22158973700096532, 0.2588540616054689, 0.13053194409416569, 0.12876030448223316, 0.10562434957753267, 0.04548190462012445, 0.062048245717080376, 0.07038780608244481, 0.04112119808973324, 0.053759350576588226, 0.020937715401692737, 0.0486142581118451, 0.09892995153824169, 0.13863157721296435, 0.11436986376441295, 0.06612491748866535, 0.09724479559208117, 0.1263907179236412, 0.08235524859159224, 0.1102300548565484, 0.039128319946147745, 0.04932960037202124, 0.04609313170095125, 0.06803771646152582, 0.04797910993558265, 0.019360462939667127, 0.030099309177228042, 0.0569935975926778, 0.07235371027021639, 0.04893249486603084, 0.028270214886194276, 0.09581513762954744, 0.03356812273963325, 0.04759065356225737, 0.07423211189527666, 0.03928999897212752, 0.06625961106751235, 0.05723038387875404, 0.014016115793868179, 0.0182117045211095, 0.04876263402101975, 0.054986416587545994, 0.01023022801570234, 0.021438214049163847, 0.025064454849569068, 0.024718594880053596, 0.03184792210137652, 0.08648841551715329, 0.06679837006114184, 0.02957342429116609, 0.03378517460078001, 0.03295886833521147, 0.04142033244152704, 0.021661170532987006, 0.03539185633041686, 0.024685291122765313, 0.04241511676340334, 0.009675791990312358, 0.05440157740527103, 0.029899955862351967, 0.12666631039352189, 0.07619556460169054, 0.054143604957648826, 0.03475451714269096, 0.11277672263883776, 0.04757715892347117, 0.04241712774420458, 0.03293112063059404, 0.10601287872921075, 0.10545492923307805, 0.09869154497620561, 0.1051513822148404, 2.148953113825091, 21.785245979985884, 49.334563978256725, 76.6396693260439, 94.14297949883246, 84.82831524264428, 67.88290731368527, 57.91528217254147, 34.219035871567264, 55.83904612448908, 78.35021495819092, 78.62795014535227, 90.48812281700873, 76.57388333351382, 59.17076226203673, 33.30073448919481, 20.49727689835333, 11.174152089703469, 6.731090709086388, 2.2284183723311273, 3.751430093280731, 3.849907570308255, 2.47712409784717, 0.7132086746634976, 2.661204116959726, 2.764854955096399, 0.7730979352228103, 0.8754829509604363, 0.6408402095398595, 0.7838725022250607, 0.5241249982387789, 0.21993674908674535, 0.3594742559136883, 2.107534355694248, 0.8739048711234524, 1.109320564616111, 0.6349397390600174, 0.2505810474676471, 0.2672129082343271, 0.5998500929244104, 0.531037133787909, 0.5038286018515787, 1.0234006782693248, 1.862906179120464, 2.3158340300283125, 1.8013693392276766, 3.712718015716922, 4.079122057845516, 3.444493595630892, 3.541958610857687, 7.539618678631322, 14.779803618308037, 32.07032422865591, 48.040150442431056, 75.61928041519658, 93.05481203140752, 111.99278400790308, 95.27789377397107, 84.72441165677964, 72.55330485682335, 47.24304637601299, 73.3345547030049, 45.50945289673344, 68.65120549355784, 73.64111931093278, 84.01472937676215, 81.41636310085174, 55.98028675202401, 13.808499247797075, 1.0359265222664804, 0.02410888082287725, 0.0758850921486174, 0.024548442921631282, 0.12501145322476664, 0.06679114585201587, 0.05008447276909025, 0.04769836169397158, 0.04302961887010644, 0.046183667971842715, 0.02358624798005387, 0.031978496042410695, 0.08610629086052218, 0.015750863484197086, 0.03227959349451046, 0.11890061500091707, 0.07156121529518597, 0.04425254800627309, 0.05690166704176415, 0.10747662760437497, 0.08558003442181696, 0.13217420677744574, 0.04281326414897077, 0.05694964712846184, 0.051786777593435786, 0.11475913602137759, 0.07140205286803745, 0.045298886215013844, 0.14554461674584498, 0.0998322958607347, 0.07213572761224163, 0.07214323527389957, 0.11626360246971731, 0.1525570025607463, 0.09633748701983884, 0.1568728201692143, 0.29865190026260197, 0.16282368391271562, 0.1950179160602631, 0.11977060743036771, 0.04623033038731064, 0.016704872776303562, 0.06132380999324303, 0.031558457694406954, 0.0394041077684491, 0.12474968098104001, 0.08089704619299981, 0.08319248310140065, 0.06890762462130479, 0.050294254455835595, 0.09198962395349819, 0.13388108131625961, 0.4214324748083469, 0.1765388028035241, 0.18376874226716258, 0.13368563696501717, 0.1397633035817454, 0.07350160875507901, 0.12340646837988209, 0.22646737284958365, 0.15781037389270722, 0.21812243837743037, 0.25099291165749876, 0.27129293930146003, 0.13036558044052896, 0.22099653979943645, 0.41844476254717, 0.24967674196006792, 0.22542534005497733, 0.2208338074025608, 0.3107932600523195, 0.21977248451402112, 0.15024873367961378, 0.22401403755910937, 0.18848631170488175, 0.1461002756390841, 0.1481176915788843, 0.14893768144951713, 0.1498623342523652, 0.12761517157477717, 0.08899074979126455, 0.17474267902153154, 0.18357116819149066, 0.1110945467747027, 0.15747036875015305, 0.18924700637017527, 0.2587579022492132, 0.11014269785054269, 0.1127148763607106, 0.1774163105555119, 0.29156065335677517, 0.1353331703332163, 0.09119468515798931, 0.1739509118300292, 0.16193892896896409, 0.2569386426119074, 0.13552889047611144, 0.1161674201308239, 0.11543433527432143, 0.36152890372660856, 0.3080161913268028, 0.13899995825223385, 0.1378234923486748, 0.24093065320724444, 0.27815895635754834, 0.16931497672152135, 0.46898290875457954, 0.6387081562030701, 10.511480396793736, 39.37211636574038, 86.7201606688961, 117.89146392576157, 111.02527649171891, 93.29760674507388, 93.16742327905472, 57.46786132935555, 51.468199991410785, 68.49061581396288, 64.3303499683257, 80.47052275749945, 84.31839927550286, 88.25225414768343, 67.28611084722704, 54.45212348814934, 39.17991630492672, 31.770482563203384, 21.383834538921235, 21.65514292255525, 19.20073743789427, 19.229796317315873, 12.087778006830524, 10.085947359761885, 9.049405147952418, 7.430447839921521, 3.7413594078633094, 4.33871848929313, 4.771204908047953, 5.092915258099956, 5.793497639317667, 5.54577446752979, 4.320073012382754, 2.8117113440267505, 2.1634864759060646, 1.3069342317119723, 1.2377349191134976, 2.395475059747696, 2.521445655053662, 1.549751744154961, 2.602386460188897, 3.8033323662896312, 5.789763542913622, 6.503246109331808, 9.16934436367404, 10.994677178321346, 12.956143694539225, 9.46215812237032, 11.16989141510379, 18.801563709012925, 33.659035159695534, 45.837912174963186, 63.73820543289185, 91.92596958529566, 99.67636908254316, 120.25055777642035, 93.47936153411867, 95.89834213256837, 72.12918681483116, 51.33392549330189, 81.86015575162827, 66.48269176483154, 87.74251076482958, 87.7404397533786, 99.97705797995292, 95.39449014971333, 57.31763847412602, 10.704140355510097, 0.5082758035390608, 0.29343386090570883, 0.1347087933531692, 0.13929879382973717, 0.2549189590518513, 0.21218744797572014, 0.1480629622575737, 0.1663837711056394, 0.19778761501994827, 0.12886415536124862, 0.2431022979679608, 0.0693275174126029, 0.22776717890895185, 0.19037468779471614, 0.13857600519493704, 0.3575302005535172, 0.20211785040315122, 0.1384387835259399, 0.18474014175515022, 0.2271674852818251, 0.15290040913368427, 0.2817469751161914, 0.141321403845664, 0.19336809975004968, 0.14138377872445893, 0.1919433753937483, 0.23637685804597794, 0.12777460979357844, 0.1717178881048195, 0.2312431036825142, 0.24821870810081884, 0.11209900295662303, 0.1492024107926315, 0.18854030558178503, 0.19154747647623863, 0.37860763890127985, 0.40395215634376774, 0.3955944741685545, 0.38256721030319896, 0.369681948495488, 0.13037664275015556, 0.10853792751027692, 0.2213916266637464, 0.13330277686397876, 0.24254749709319687, 0.15465743178802152, 0.38157889559384317, 0.2916913479566574, 0.2772252483954353, 0.19710219615409452, 0.20541791203281573], [0.11027940624063054, 0.2931452602628739, 0.06760603357707301, 0.2191926938511672, 0.06823164395867817, 0.04459354140224957, 0.012760457466356458, 0.03682607251610007, 0.034801011018815546, 0.10348592238921313, 0.1210238966309736, 0.028671641128077626, 0.10878877534020333, 0.05138680691860857, 0.11393608945992686, 0.17063771945334252, 0.14767852401541126, 0.04807345749389741, 0.07638254368136968, 0.004890441965882577, 0.05523362549983206, 0.06058403718916159, 0.06778329100099302, 0.04439917340454075, 0.027100044310153015, 0.029634512142248215, 0.025317614349806984, 0.08948994800448419, 0.08954934280125365, 0.054408744157802676, 0.01917200339507432, 0.0654772590965994, 0.041683081447357134, 0.01760257652119523, 0.019709364278241992, 0.02488718976476981, 0.021089245677895604, 0.009761109287219663, 0.1126743196659992, 0.02864740019093358, 0.06934393467682023, 0.02199693154844065, 0.022625906971253218, 0.11013605586823919, 0.1063228685468916, 0.07683596048023432, 0.08445819824813836, 0.021081672898764094, 0.018239413921330726, 0.03295702589375358, 0.016341626441346544, 0.06180711571247347, 0.003964195700152026, 0.11296331867455475, 0.032082174551643194, 0.01838399578006037, 0.049562491101002505, 0.056096332433122786, 0.29501463737218614, 8.45887957080718, 39.7646632502156, 77.78518184538811, 81.47781879671159, 72.6453628847676, 88.03557457462435, 72.88465884424025, 64.958082168333, 44.0922809416248, 45.656388805758574, 38.88870385385329, 34.602353419027025, 36.72736806254233, 19.8476892517459, 25.449206482979562, 20.560944810990367, 16.06871504937449, 13.020415652182795, 14.126066104058298, 17.157233568929858, 15.127853174363414, 11.902752941654576, 6.646454786100696, 8.400798093888069, 9.71800256159998, 6.994758805921001, 6.948059066649407, 5.42167999090687, 12.155149617502767, 24.38002917074388, 40.18698092429869, 43.65115550256545, 36.07780395015594, 43.24590798347227, 50.555935136733524, 48.88475048926569, 47.8813022951926, 39.09400070867231, 34.73271731407412, 34.61227309319281, 32.639432684067756, 33.52676107037452, 24.593166843537364, 17.198545932769775, 12.222906601044441, 12.29776797756072, 15.944645577861419, 19.921325868175877, 41.787523684963105, 57.21980279491794, 74.46796278799735, 77.31971417703937, 65.36423575493598, 52.415962296147505, 48.23668472228512, 53.870416379744015, 55.6290541925738, 66.79994090910881, 56.65930001966415, 65.74476057483305, 80.81808397846838, 76.46957966589159, 50.602556428601666, 10.571262221182547, 0.5268680833039746, 0.19708940248575904, 0.06560584695468988, 0.04837186406216314, 0.029982582275425235, 0.143446562391135, 0.06762927668469568, 0.05498668854875911, 0.0249653096656285, 0.1415743814000199, 0.03302162242752891, 0.038887894742431185, 0.0532438155383833, 0.08340926300133429, 0.038337851273677045, 0.03529077102880805, 0.042194644319674665, 0.09014331375158603, 0.06059109668938383, 0.025999287045710993, 0.08171801665617574, 0.1182095883714576, 0.06090415085876181, 0.033175801452729976, 0.08291641565700693, 0.05539615105296816, 0.049781350929650574, 0.012966589701752509, 0.011546584447064709, 0.06259434766346408, 0.10449845313785538, 0.06255611604560288, 0.030471587688812328, 0.02928902755581564, 0.0910036841167077, 0.105872608030275, 0.12967162735519872, 0.07480847048422984, 0.14435898843071154, 0.0767973343270921, 0.10172866990849858, 0.11303922266609247, 0.015389100486983456, 0.13063024849660937, 0.06341509213070236, 0.02095643092968291, 0.07184225465020827, 0.09536844708265797, 0.04509702970784518, 0.23587076504143978, 0.11571194255544294, 0.032459528395725835, 0.19995090942228996, 0.4052005732251752, 0.27057799540700456, 0.1495946631316216, 0.23274553999785455, 0.14793254344934417, 0.052318224277828014, 0.026652629810175108, 0.03196532890621213, 0.07470245157638866, 0.04711782409539146, 0.08363846884739977, 0.11546650330626196, 0.15047736495973604, 0.15224836105781217, 0.14764607253093875, 0.14965506150357186, 0.09198821435171751, 0.18925192465464916, 0.16294490966585376, 0.06386013175811499, 0.12427465284183142, 0.05138815140291568, 0.06701464434304545, 0.058779241291866194, 0.08340044532932582, 0.049263130753271045, 0.11970818658629734, 0.021637023441613685, 0.0688290776264283, 0.06253971410314403, 0.10916997303044605, 0.07921965071751226, 0.03989390608283781, 0.08373774618150727, 0.08129464582570138, 0.07008316355847544, 0.02059866978426374, 0.032659787609572374, 0.13705866080859017, 0.07132784193081242, 0.07396550563674781, 0.009147598306768605, 0.03384318277840653, 0.08683021330545027, 0.12957695420951615, 0.03670189732445344, 0.08657918161442203, 0.10526885413714956, 0.08039669884789376, 0.0855448020381793, 0.046860724988002936, 0.08018622385157693, 0.06187634324775108, 0.09857629470887685, 0.029895696413492965, 0.14695273231594794, 0.0741725562200431, 0.12684681603024084, 1.4562782308747693, 20.993560667960875, 66.44826904419931, 98.57226110273793, 90.89018144915181, 80.74717537049325, 62.02140362031999, 45.908102989196784, 51.109534540484034, 42.70828047106343, 59.1921470242162, 65.45437574386597, 73.16767354165354, 66.92973213811075, 56.306580881918634, 43.414287490229455, 31.184998212322114, 21.961323138206236, 23.31929083793394, 25.02536692926961, 25.420430014210364, 23.559053559457105, 27.465879378780244, 18.50074145101732, 18.072583367747647, 14.165854627086272, 8.865983351584404, 11.860611977115756, 9.062597059434461, 26.789243067464522, 44.8748996949965, 57.64146935555243, 53.2285479576357, 51.8121918555229, 57.52509263253982, 49.46945428848267, 55.23376557134814, 56.17819778380856, 53.7281245570029, 51.11313919867239, 56.03387417331819, 53.7994489362163, 48.99974653797765, 48.66615679956252, 37.64312774904313, 30.545691097936324, 29.935209481946885, 38.67598979703842, 47.68017491986675, 76.85543890922301, 92.9131595550045, 105.42706581854053, 101.26730595865558, 86.87408231919812, 74.50452712274368, 58.52794070397654, 66.88419342041016, 56.59394548785303, 55.76644697496968, 63.26994111461025, 75.5098541321293, 87.18216096201252, 90.79788807899722, 68.78043974599531, 22.892921355462846, 1.6498745328957036, 0.4692362387093806, 0.1574643779425852, 0.0581106189037523, 0.07812272006225202, 0.0803428198841791, 0.042804534577073595, 0.11666832672011469, 0.015021133135193059, 0.1199889884540631, 0.010998705176696663, 0.0474825777083395, 0.0883258390991438, 0.07275320980097018, 0.09588462946515891, 0.04179943871173648, 0.11116775413674694, 0.07147123060759998, 0.0531365210941482, 0.07901594793844609, 0.040941634741161144, 0.049712092750855995, 0.05719804347703054, 0.036499994852009325, 0.04362042204687192, 0.06877245606794473, 0.07106457581563343, 0.012794361645055395, 0.08613884193642486, 0.0405713499733998, 0.024325350457201564, 0.05380847979517234, 0.033906779567440676, 0.04956708762854819, 0.06251272482557163, 0.13849838516644894, 0.220569537712201, 0.122371667455281, 0.3246294821221983, 0.14408878921981783, 0.185814151059716, 0.3119717484279987, 0.1381723075023582, 0.14146355912089348, 0.06109456967322096, 0.10820713840545186, 0.19205395252473895, 0.432618216521317, 0.2504430443889672, 0.45864289746649806, 0.26512418483053485, 0.5924915426200437, 0.24602136875112213, 0.4351209644829074, 0.4520420694062787, 0.2616624480053302, 0.3677499666810036, 0.2467054699457461, 0.13826570894208648, 0.18225905876005852, 0.13847676616522575, 0.1524843008167321, 0.2505873906756601, 0.29286367698542537, 0.18629945243798918, 0.2331188852868734, 0.2204622394375263, 0.1477427987922584, 0.22807146903247605, 0.27895820056719167, 0.19049978995275116, 0.23624225639768187, 0.11798076556935427, 0.17968849669541084, 0.17928594813471843, 0.1294334812630569, 0.13161994216422881, 0.12043383272905504, 0.13239480945612156, 0.30207717130261086, 0.1717589963828364, 0.22900070304111128, 0.22127941010459778, 0.2781000288744127, 0.1176798462326969, 0.18355785358336665, 0.1851647842915789, 0.15512477606534958, 0.30398473023406924, 0.14103614334617892, 0.13905343118934863, 0.2744417445313546, 0.10644351207320729, 0.19668544432328594, 0.21650050766766074, 0.10896115278404568, 0.2448887537203489, 0.22794442101111337, 0.16497596197070616, 0.2507445306306885, 0.3378478389593863, 0.2450264350421006, 0.11777890140130637, 0.2171723667772547, 0.17653259749133743, 0.12856587136705078, 0.39168935629629326, 0.11919618704386296, 0.29868744674228853, 0.06715250186501973, 0.4966217982432535, 0.3419572878028116, 10.94530434377732, 58.21514344984486, 107.21816124454622, 114.53657442523588, 96.00106116264098, 110.77782984702819, 95.3678023430609, 86.15814778112596, 62.59845879770095, 65.26672563245221, 59.25364978851811, 62.96102308457898, 75.26702803950157, 58.54168076669016, 66.32802486419678, 66.88004355276784, 64.08512338515251, 54.64491190448884, 60.87555377714096, 60.60285491328086, 62.34977660640594, 55.34279177265783, 48.41319138003934, 45.821869680958415, 32.810226409666, 28.447691778982843, 33.690963252898186, 44.923313510033395, 65.6523456112031, 77.58613724862376, 82.4926693208756, 73.10144824366417, 62.782990624827725, 68.78649588554137, 84.08723046702724, 80.49258216734856, 84.02659062416323, 70.85091775463474, 66.649871026316, 66.73530024866905, 65.52221705836635, 72.78237911962694, 60.10502769101051, 54.03756818463726, 44.70124067798738, 53.75142735819663, 68.95264748604068, 70.49295440796884, 86.40098171849405, 92.30494114660448, 101.6780722525812, 93.81590089490338, 78.3207893371582, 67.34640552151588, 65.37030366159254, 75.17954349517822, 75.89053584683326, 83.86855048518028, 79.69095168575164, 86.10579982880624, 107.35150614092427, 105.02782344818117, 72.43958750078755, 20.30511017768614, 1.0328376557557815, 0.408997580769562, 0.17740875692857852, 0.11248494273111706, 0.246969111444008, 0.3903961692365908, 0.2515740966003749, 0.21672553833453886, 0.09182887572434642, 0.2940481408469139, 0.14144716483931388, 0.14662375883950343, 0.23497007546886323, 0.3284284202081542, 0.1850470059341, 0.2254126229954343, 0.17703119815597612, 0.19728797247573254, 0.2784869339196913, 0.16187425582639633, 0.15736391317219506, 0.14783635344957152, 0.20889472546837023, 0.20037826390997057, 0.15601737574944574, 0.12168676952921575, 0.16096402079828326, 0.11123488642155163, 0.1737988740205765, 0.13859667424713412, 0.20382827958993374, 0.12919014109478844, 0.2608737758090419, 0.14636937168336686, 0.2456076506284937, 0.23388520303753116, 0.2534291325437446, 0.2643491489992988, 0.42309047293759167, 0.13327674519631172, 0.1926455562633853, 0.48671618945175604, 0.2580451953314966, 0.44655271235012245, 0.29660963243053806, 0.3256383586314417, 0.37398913995392863, 0.6313396773992047, 0.2808708463224673, 0.760295073832235, 0.39932280959140876, 0.7005155170636793, 0.23072427829667447], [0.22361603956068718, 0.1278952839634111, 0.12407249756037228, 0.050337580558393276, 0.1529136777765328, 0.13853105115554026, 0.1164848103578533, 0.03268772683617088, 0.07861962767257806, 0.048209185291442185, 0.09168127356397529, 0.1750988639410465, 0.08165169642457078, 0.14371222636151698, 0.14643894778865, 0.13489925813290382, 0.1780302534180303, 0.16413079845088144, 0.09120150334051541, 0.1831790690700854, 0.08456411756454937, 0.045773979471696, 0.020743349319203727, 0.030417476983500585, 0.019539413417899804, 0.053049730993206465, 0.02155146482701023, 0.033627410284093315, 0.01697197507676338, 0.032894168379566366, 0.010118784247747353, 0.06209539842881984, 0.06020489644499556, 0.03446187538605544, 0.06680406975529848, 0.026922894138542396, 0.03127380815004149, 0.008297485858953048, 0.08174770256324161, 0.09390439943320329, 0.04449621759234898, 0.028779253498801304, 0.04242402636596272, 0.09036476678785779, 0.02967484475624177, 0.04048294342693783, 0.09156571686147683, 0.06671135779470205, 0.09885576358365436, 0.022624539504308375, 0.03961528373521663, 0.056860033993519125, 0.00866616663012293, 0.08538410743518222, 0.04034178789644953, 0.10654813670102628, 0.06296182471898294, 0.0506178921298875, 0.06770545646788613, 0.17120830173934662, 1.0750020319415678, 12.589267742249275, 38.48362499667753, 78.02379531245079, 90.21842064396029, 88.64861749833631, 73.11126985857564, 77.42990139992007, 74.70554074933453, 47.861172691468276, 51.400150791291274, 39.202301271500126, 28.59253510352104, 18.026626917623705, 11.018192768096926, 18.953624194668187, 14.726798668984445, 16.071532291750756, 14.290205528659207, 13.646622050193049, 13.549719895085982, 10.634806579159154, 3.7680584913299935, 2.7308151558522256, 3.0195079743862157, 7.429891353653324, 12.175051723757099, 17.54443818523038, 26.790482536438976, 30.06024483711489, 34.46934584648379, 22.680870179207098, 23.316123524019797, 52.979328401627086, 61.97981080701275, 46.94932753039945, 24.038882986191783, 27.126586514134562, 23.40330800702495, 31.86708857936244, 20.19666840953212, 15.739729192949111, 13.515066735206114, 17.43465300529234, 30.35545026102374, 36.242312077553045, 45.44410620966266, 44.45796743515999, 46.69329481740152, 58.216990886196015, 63.43004834267401, 66.52655170809838, 56.18532473041166, 72.45891694099673, 63.6204598026891, 71.04946813275738, 72.74328877848964, 83.11464740384011, 87.07314260544317, 50.90071931962044, 12.159438729286196, 1.3906140769681623, 0.03497025133260796, 0.1912739830872705, 0.041756189217971224, 0.09851401942151208, 0.07934816962768955, 0.0595834037859834, 0.11071899515246192, 0.08643323420396737, 0.056777943841992855, 0.009880427481426347, 0.14706280382890857, 0.04535109893749318, 0.07996280196933978, 0.04640633142703483, 0.02863445522023305, 0.06283923149889996, 0.07258917505462324, 0.10636627508868134, 0.0693147926921806, 0.018704440782687837, 0.06560339547333217, 0.03431425407348621, 0.054253201496096394, 0.05017499371822323, 0.063021395715975, 0.06732245847102135, 0.01366181257781723, 0.06356229975579247, 0.06443941680293891, 0.03405165445480136, 0.05322269832475051, 0.03724018134356987, 0.024682954554596258, 0.06563963143215065, 0.06595459316046008, 0.11634253250855593, 0.08747093094092223, 0.1792867142226427, 0.14351672072324062, 0.0518011877072915, 0.06422482408402909, 0.10982213601950677, 0.1328901772297198, 0.08342784063349809, 0.08977726161960634, 0.08021030965591631, 0.05287533873812326, 0.07260204533175116, 0.12119102637253462, 0.24235510177189307, 0.25498239113198173, 0.15390882599017314, 0.09114894970890977, 0.05269990460346303, 0.22561759748045476, 0.3104383774822758, 0.11855673345346605, 0.11596384758670485, 0.1331865919693824, 0.2822076697503367, 0.13536491701679845, 0.12863403787055325, 0.04437255184917201, 0.08974913087102676, 0.1644305839774109, 0.23744202669589753, 0.1932728596993031, 0.18648984060893137, 0.11499106147957426, 0.13661860458312497, 0.14430798229671296, 0.1105745952396143, 0.22727603994069562, 0.11962748688435364, 0.03819790616210911, 0.011797352795368962, 0.08708990179002286, 0.05247978456017952, 0.03413719583242651, 0.05627715982676995, 0.06685368160927488, 0.021670049492029414, 0.05593347363173962, 0.021992109024957306, 0.0013437050520517535, 0.004054905777241314, 0.07800989063276399, 0.035338360410664356, 0.0443828059360385, 0.04935147601269907, 0.09532926934621028, 0.024986223865961357, 0.055772491745770945, 0.10744255967438222, 0.05058723712159742, 0.06088340519777229, 0.052931190378242926, 0.08491084895907872, 0.059729086896104205, 0.07130154979325111, 0.04746192780834052, 0.05757442247422953, 0.050591033087262226, 0.07098866416321647, 0.05663416062992427, 0.03059696946893969, 0.03658986845684629, 0.015299513207508192, 0.027043185264412916, 0.03374356453517272, 0.10763303977587532, 0.026391165916837996, 0.17918893075998754, 0.24615529624204485, 3.958120370103467, 31.922656797593643, 66.94925769682854, 92.1195463980398, 100.42569083552208, 96.17776393890382, 73.67576952903502, 57.842416301850356, 54.817178480086795, 38.19819804160826, 49.44780280513149, 60.31486665048907, 46.32969110242782, 56.24162250949491, 45.64573564837056, 56.9064328747411, 51.80101702290197, 53.867509903446326, 53.070594110796534, 54.06190256918631, 48.713986181443744, 46.76723149514968, 37.159958424106726, 35.67667099737352, 33.5543078760947, 34.67146950383341, 49.86861821143858, 64.37515128043391, 73.39326473974413, 77.85880473352249, 75.77844235204881, 61.01353883743287, 72.3777081889491, 99.59719996298514, 99.54401262344854, 83.4650876445155, 38.5361651451357, 49.96121360409645, 44.13104180366763, 55.76166560572963, 53.72875998097082, 48.757061650676114, 52.73159934628395, 52.805222234418316, 68.91288249723374, 85.54293186433854, 80.55425751593806, 78.1381167134931, 71.58030602239793, 69.16909956162976, 65.1965622748098, 59.203902367622625, 51.70812745248118, 64.01834895533901, 62.89087541641728, 74.63179234535464, 81.39702581590223, 90.99807016311154, 97.329513026822, 73.92458900328606, 26.401167684985747, 5.620911390550676, 0.45841699345938625, 0.31846363878538536, 0.054892333329565106, 0.017044117576592875, 0.02652480037912967, 0.04688816625745066, 0.018669625916968913, 0.09533234901966588, 0.09331751479617051, 0.13150692887363896, 0.06516244292499558, 0.02677963761192176, 0.05877151912558944, 0.033781501209183086, 0.05669129546731711, 0.18569975881086243, 0.061603332494175246, 0.04350550502779023, 0.03159345067556828, 0.011455759935591732, 0.0419868812746098, 0.02709919395255706, 0.031532244080857884, 0.04500718291608557, 0.0760096044189507, 0.03720016091040546, 0.02447662983960923, 0.029001238966180436, 0.04153680844953464, 0.05860103774935969, 0.10362344283250072, 0.01061576750925592, 0.0268655696943883, 0.07813077164633621, 0.14347185861439476, 0.08182631084515203, 0.012015890867088833, 0.27526314400376817, 0.24188024983290704, 0.0040500262759686, 0.058713549252359144, 0.23683470283304495, 0.14615986195783462, 0.16027771327043736, 0.1853753971837221, 0.15310930598887706, 0.20182937233438417, 0.20483557795805318, 0.43160839006304746, 0.5178714531563944, 0.5005443829201883, 0.322487561572944, 0.3029891530111913, 0.15532182920123302, 0.34110515288287596, 0.30452966389636843, 0.2433430027937697, 0.19815723712165512, 0.20569194168333085, 0.2766054526211754, 0.34418810519479937, 0.2101365386718704, 0.24285560233458398, 0.1977060266560124, 0.24916364691190182, 0.33068228152490436, 0.39793524049943496, 0.2988777123391628, 0.40523575198265815, 0.19567526546457123, 0.2920547494244191, 0.24410391196368203, 0.24519480584609896, 0.24135151126932716, 0.3054666200712804, 0.18784791531582035, 0.1881552544692832, 0.2567587804890448, 0.14239377372207182, 0.1364640846487976, 0.20648027680093245, 0.07775316690845836, 0.21946934352238334, 0.15691130842653014, 0.08688705702943188, 0.10900137240007039, 0.18345043273462405, 0.19922133324848068, 0.20127224255233042, 0.13806027480431143, 0.17931280717734369, 0.13760909498218568, 0.18712987642615073, 0.21953715762544065, 0.15054648141226462, 0.123567063391449, 0.16612543093581356, 0.3065106753380068, 0.15207718637201095, 0.14197455508814705, 0.11330703934354168, 0.12272609037257011, 0.16531924596957623, 0.11427189644065597, 0.140339233161461, 0.21000956725930015, 0.1378295597650351, 0.07517436173774543, 0.12724572567329293, 0.24418301820274324, 0.24793007681446694, 0.18811109716132765, 0.23128775128674126, 0.2271413923271241, 1.0983842611312866, 20.634530436608102, 61.98636116520051, 108.38638428718814, 118.34740023459159, 115.88150024414064, 97.54395684888287, 101.19110215094783, 101.4693158672702, 73.89410434230682, 81.23277264256632, 75.3961681550549, 68.9287131832492, 62.3614142787072, 47.19211439932547, 67.5720359433082, 69.75606656843617, 70.68466417251095, 67.10892954180318, 64.78817685957878, 55.413119869847456, 58.89261130363711, 42.87344755664949, 37.08140119429558, 39.65862197260703, 39.853614760983376, 59.212284472680864, 60.42721902170489, 67.74305912756151, 61.970867803019864, 68.60578444696242, 52.27434904344621, 48.603449867617705, 82.42397292967766, 98.385540593055, 76.5859014757218, 60.95398156873642, 62.80252010591569, 48.976843818541504, 66.17317753453409, 52.37782509096208, 51.552813360767985, 54.030460849885024, 65.12011920252155, 79.80225286176129, 75.77757943061091, 83.31650041764783, 77.41529449339836, 67.31534034975114, 81.42714177408527, 85.26486719808271, 87.59069150493991, 75.19050259743968, 89.02401185804798, 82.46560496668663, 95.04829391356438, 101.54957540573614, 114.42694417891965, 116.59994509912308, 75.51054446927964, 23.955195296195246, 3.665633639020305, 0.362904000907175, 0.3290050086234847, 0.11352142138827233, 0.26365289765019573, 0.1581401594223515, 0.1452077065985049, 0.19753445360449054, 0.23981846208053254, 0.19960952532147208, 0.2694758400321007, 0.18107513116011698, 0.16957544661577673, 0.19277084228252211, 0.16346840818803157, 0.15420864216021954, 0.23774936584936035, 0.15983920454257922, 0.19115520881549006, 0.17101556933935613, 0.18508334914522787, 0.20049815667012047, 0.1698788174337918, 0.11988405739107441, 0.15162703310770376, 0.2500484324991703, 0.07971919367029782, 0.16813739232959288, 0.2536311039641019, 0.10986907422662744, 0.1217249513513619, 0.2087449859226904, 0.09858336570041795, 0.10002506656512138, 0.13965019836060463, 0.3301476134407905, 0.2660557477464599, 0.22249589644132123, 0.26108867879356107, 0.2429981559755341, 0.22521238293378587, 0.19450479036858007, 0.28798728219924435, 0.22316346545853924, 0.3263276232586753, 0.36591521674586885, 0.27373921126127243, 0.531410678259788, 0.22768376725575618, 0.4628243279312888, 0.589483329846013, 0.5049084487461275, 0.3105950271410327, 0.27264051860378635, 0.22186811803089035], [0.16972225970558583, 0.08823652090805192, 0.09075413097537334, 0.03112620024401094, 0.12000467793475236, 0.09412224419535169, 0.06844019607430504, 0.05555476189681119, 0.08186548092072049, 0.05902795939736309, 0.07766511276244156, 0.10361408123806601, 0.02459252936645381, 0.1059107132436287, 0.07462432592987053, 0.03328053716329798, 0.12841121353689702, 0.12287575330945755, 0.1628199760471621, 0.12495253340251024, 0.03286311117511603, 0.014145953332885139, 0.09642640684521007, 0.0687471981490812, 0.02825276723371879, 0.008157064815262153, 0.13404468705336894, 0.03961827913900057, 0.022349180691244624, 0.04754121407806393, 0.044971781993104566, 0.10537346344321005, 0.03162298336504929, 0.056661693829922914, 0.02642496763127706, 0.06894143974228252, 0.024725495417031552, 0.026118850388053446, 0.08809119402881592, 0.045494456970763784, 0.026738251627032316, 0.033922246882631894, 0.08246590233137531, 0.032357780428062526, 0.11365718749021331, 0.025337126609238408, 0.0580754324853901, 0.09692908309760595, 0.016561516658252767, 0.005968229999134858, 0.047255647143409144, 0.07410312567146556, 0.020080602825469068, 0.11057240422815086, 0.05065990439165504, 0.0820095743983984, 0.01321957491698765, 0.10690402284625078, 0.03060548262099826, 0.16118800958558438, 0.061816373885038405, 0.1960309141225392, 0.8720563316056806, 12.097947732094797, 35.039497652361476, 67.5978059153403, 90.09252825090962, 89.11976475869456, 83.95846689901045, 71.52506336089104, 74.17883703785559, 68.97046289136334, 57.459698877026966, 46.84509054307015, 39.63187925277218, 27.378277163351736, 29.463783733306396, 27.821738373848703, 19.38411608819039, 20.04799096815048, 32.07536643551242, 17.368106072948827, 19.635139934478268, 17.241605712521462, 18.469050661210094, 23.098612408484183, 13.721289269385801, 34.03769293139058, 46.1614881023284, 47.263681965489546, 60.375208393219985, 54.47633627922305, 56.78902064600299, 42.59868944844892, 62.30430064662811, 51.54943227767945, 106.03593534038913, 48.862369445062455, 40.27792107674384, 53.761649054865686, 35.8463409639174, 49.31187306680987, 40.33274796701247, 50.288782504297075, 40.595052549915934, 31.59132830558285, 36.7981158533404, 61.36295141712312, 63.721296095079, 71.5152495907199, 73.02769983968427, 82.81667278658959, 89.49197415382632, 92.333770567371, 88.3864462760187, 79.82704224125033, 60.22735464957453, 40.08102593883392, 13.358145452314808, 2.02062358058268, 0.3597953999715467, 0.17110567660101, 0.0741946425349001, 0.02160415826966205, 0.04939555288142255, 0.03205345774580154, 0.031035118135473425, 0.054667287340928475, 0.03031679962371146, 0.03774795591110184, 0.04920067543524408, 0.030362054352618517, 0.024450971639805266, 0.08885781821464339, 0.07152337821260576, 0.07994405579783263, 0.03380939447050614, 0.023217233003027016, 0.08084704363418203, 0.050806349759260495, 0.021864574537762714, 0.011801298148179007, 0.05176648775476122, 0.09065229490759874, 0.02603017379559817, 0.15452807018112752, 0.01570893932254084, 0.044102364129597144, 0.03729347425002245, 0.04880459265663259, 0.01968769548130372, 0.04007812724598954, 0.047024139203131206, 0.032971390042333834, 0.01234004948092925, 0.01761139227798389, 0.05955921455977425, 0.10237644321375317, 0.08514411507114288, 0.17634060053575426, 0.13537660751852298, 0.20561766179819263, 0.058157909511318134, 0.13879849244990658, 0.1236863126377425, 0.07921556746887584, 0.10731907396186745, 0.10135566169816641, 0.24154251231060875, 0.09244575270361478, 0.20489960758676454, 0.1956960570908362, 0.30179736534914664, 0.23180328249450655, 0.2503702660361605, 0.2192708194976853, 0.12430905785051086, 0.17818586119721014, 0.06447114816476261, 0.05121035771744867, 0.1082179555669427, 0.11080661262836188, 0.10706966637723869, 0.04402180615391943, 0.09933316659542824, 0.0402791065824849, 0.1366289161265858, 0.04321885024828296, 0.10021555432749372, 0.13522533579699456, 0.04702311647575229, 0.018569831473512516, 0.18134762863478354, 0.05661262972881237, 0.07422792905521008, 0.027860907514789895, 0.052753603536515474, 0.01895980278570806, 0.05588942357609349, 0.054674289384556395, 0.04060627209142812, 0.045230719711511366, 0.07135459372112829, 0.017248381515063586, 0.040471157164222775, 0.006981275463101244, 0.02448712332895206, 0.10039858039348357, 0.1260389992967248, 0.04823756884903677, 0.04293891405987163, 0.09430688670686177, 0.00495979973610731, 0.0427425044378446, 0.09552855179795335, 0.02720099171593545, 0.03736202762792668, 0.07535403233862693, 0.03851609695101938, 0.06578446035423587, 0.03614106733772544, 0.027595716603701154, 0.03145992921124543, 0.08413144642667425, 0.036850188963956414, 0.08125264888569232, 0.05684901764916797, 0.017502709299386028, 0.02206220607002897, 0.1312341096420442, 0.06149886491438074, 0.06909889379335989, 0.112079092331471, 0.16282798932685008, 0.07450365176003787, 0.04577760306757785, 0.044712940035688306, 1.0029453339595948, 4.380488789850666, 30.57275349094022, 63.67350985926967, 88.9701420261014, 97.26160895439887, 97.01393481223815, 92.21238105527817, 63.70619496991558, 64.64798350487986, 55.603154782325994, 42.90012751856158, 34.18602520419706, 29.492111090690862, 36.78055147970877, 42.11005626186248, 41.74712719455842, 39.3315629805288, 37.93429705404466, 50.671978458281494, 37.7142285531567, 22.4279498669409, 17.925070870307184, 24.279594921296646, 15.770163843708655, 24.88404981551632, 29.620009776084657, 43.01490783691407, 37.94382449119322, 60.680533532173406, 40.24938975611041, 34.778389392360566, 56.628344674264234, 78.1081105816749, 63.55117113359513, 109.82277193377095, 57.397572455867646, 43.48366637383738, 57.77898373142366, 34.05612022646012, 44.6286964416504, 42.735482108208444, 57.95602775389149, 57.664101431446696, 47.68097900575208, 47.350684058281686, 49.681089693500155, 46.56722591769311, 70.6351089477539, 72.530853209957, 84.41811377002348, 91.35145218141618, 103.6221322705669, 98.9427681892149, 95.92677931631766, 83.62435156299223, 62.49314315857426, 29.226739214312648, 6.312872402129635, 1.2432196183550743, 0.25951344880365557, 0.08499375499424436, 0.013081266360747959, 0.025198338290436134, 0.08332792744641343, 0.017630701524115378, 0.01799337903878862, 0.06092071751012437, 0.07715686705083617, 0.049675581000384786, 0.04603277163339719, 0.07350301835685968, 0.09854348316307991, 0.05593197976028728, 0.020495489232182022, 0.014041814213288168, 0.05716386829472839, 0.022301415109165737, 0.08176350695711952, 0.04313682521423025, 0.04826261609372112, 0.05610709596845893, 0.03392755587194716, 0.05443786315980458, 0.03595057191447385, 0.07511457623613459, 0.05437374160054231, 0.00584328057987976, 0.08235611427094668, 0.029579033969991633, 0.07208692015058572, 0.06465885502796981, 0.021820114625077096, 0.0286507862995589, 0.017871756835149664, 0.03362638372627478, 0.1062866785533486, 0.09823494125157596, 0.257033254470556, 0.08634181693196298, 0.1938715727338868, 0.21044825984826013, 0.11233566283819177, 0.23408312951364826, 0.061821073834453864, 0.2299583895552543, 0.12688057752506388, 0.21895954265229164, 0.15802477125919637, 0.21585040545511633, 0.1178178339896183, 0.3369382168016126, 0.2898746776965357, 0.23230894648980713, 0.09437876107591776, 0.19944037310779097, 0.17613515107622071, 0.12171413418987106, 0.15600340230570686, 0.1618520545983507, 0.1618050780868338, 0.21990630475263442, 0.16990561518938313, 0.1456059191015459, 0.2425610874929736, 0.19996019440793222, 0.10825798366098635, 0.20543566995090057, 0.21613931253312096, 0.16829799500203904, 0.10056176478223455, 0.19436934602356729, 0.19783649142951737, 0.26673787243423924, 0.19842369782347835, 0.18072165819185396, 0.11008820601648862, 0.13529788432342393, 0.08326831814502517, 0.15393710995633758, 0.15784984274256617, 0.2534658434770761, 0.19136185337218548, 0.11679290027748193, 0.263416268412144, 0.13849536678002727, 0.269402050443234, 0.21156212104664696, 0.20163063380506732, 0.09502317125518477, 0.20165905566705813, 0.11269265215002722, 0.1227407992607163, 0.20065693605330684, 0.15062335067458693, 0.1425562609708117, 0.1548361294572392, 0.2800157696249024, 0.11153491709621684, 0.1631156400206589, 0.1349078842829312, 0.15226461744356543, 0.2930369660738976, 0.07809898665835781, 0.11623410042375328, 0.19848055686921845, 0.10196934409079053, 0.2092547561492651, 0.25477338702447955, 0.1377645342220222, 0.15239161949965263, 0.16023013921033952, 0.29977418842815584, 0.13958140366500424, 0.2611716307940022, 0.25766782041999603, 0.5501998732647588, 1.4170716895211128, 17.92129558901633, 53.83815488507671, 97.82353555002521, 122.30949617201283, 120.44563293457033, 114.04738426208498, 93.01438808441164, 101.80157199982675, 97.54812240600587, 88.3281441657774, 81.82387382753434, 82.36819682582733, 72.7008330437445, 85.99536941897485, 78.04213631537654, 74.20704672413488, 67.89430572140601, 92.96797860053279, 70.5710409533593, 69.35236054082071, 60.78362518741239, 70.16032957261609, 77.67582616498395, 55.76247361398513, 77.3391063751713, 99.41014997420773, 94.58754877890311, 109.03972564205047, 88.3048923553959, 106.57814025878908, 78.10673775211458, 104.21124089148738, 89.36945499912386, 137.3595363863053, 77.83089314737629, 84.47073628825527, 103.01668305550854, 77.21369251128166, 109.73418128105902, 98.38802737574424, 107.37864109777637, 80.49399422061059, 65.33322549635365, 71.97257441859092, 90.30325366604714, 85.92123662271808, 96.54929084162559, 90.60322084734517, 100.60400962829591, 111.23433097716301, 118.54664879460489, 121.24308216956355, 113.43125051067723, 88.93286381998371, 58.24530647646997, 22.879487237622662, 3.9770136917791064, 0.8192786958909805, 0.3051659458827588, 0.10314327424332019, 0.10561711004664821, 0.25634305521605477, 0.10835654087244503, 0.10876747043502909, 0.16393918453926043, 0.18971694002468742, 0.12780250305490148, 0.1768485321513107, 0.087647391633401, 0.14487006100675753, 0.16242594638418767, 0.2678645119792031, 0.18819922791613689, 0.1032321710860537, 0.1709394968084751, 0.14942230867041698, 0.1970108784735203, 0.09187112547337048, 0.18472229190651449, 0.10871513896892149, 0.1575722124788069, 0.21989214744779373, 0.18047862445875523, 0.11893276005021988, 0.10939405374829808, 0.10622664790360198, 0.15303939280490722, 0.14155858466702123, 0.20218788616118893, 0.13782530031617612, 0.15980249360924767, 0.0974910315727034, 0.12231551321043123, 0.1573872941756441, 0.20367861665304632, 0.199750148420853, 0.255977064371109, 0.37157755645532764, 0.264447943698014, 0.37716668880274223, 0.23384009578054954, 0.31382433289001066, 0.22425137159805145, 0.36047933262682735, 0.3061014311688562, 0.47843370646719013, 0.19835755379209596, 0.33647749152395034, 0.25843602274694755, 0.42554082048516123, 0.2964271502869745, 0.34879964806379815, 0.22080428237395905], [0.3082373455887841, 0.4025415433270316, 0.16237729980099588, 0.19011248654175192, 0.22310053899643884, 0.14573088336375453, 0.10421986526419079, 0.1012364277736314, 0.09097433528832852, 0.13350264920342353, 0.04996865176625791, 0.0035358306946187855, 0.0674435233456954, 0.07567872338357472, 0.3045799499077182, 0.11430935047927404, 0.33178459011739303, 0.2149262735920568, 0.10974044806414074, 0.039068289296401125, 0.04164139094251779, 0.05752537369487747, 0.05939716781159082, 0.057090863945984074, 0.06951212928059601, 0.01654658368938873, 0.06614534139272667, 0.046075699370234244, 0.03806946386072425, 0.0940975301989144, 0.0383511773731199, 0.0710861565124604, 0.02995292318143672, 0.02538056570976492, 0.055715165386397036, 0.05674125206085944, 0.030515197243901993, 0.04230937747765453, 0.07102954261485608, 0.013236518866652924, 0.049488410398724585, 0.033904787738837545, 0.014715846139757384, 0.052608000865626725, 0.01905210105882537, 0.06935075285934633, 0.036270448096817544, 0.059292527862013354, 0.03389490520461433, 0.06486960581593937, 0.0384494856060032, 0.03933289223500798, 0.08169449775690034, 0.03666218715689836, 0.16268143670693522, 0.043741601834734606, 0.014149854635639537, 0.0667919196008194, 0.001970720486790543, 0.050990184048010465, 0.16369844906993453, 0.0628057879305655, 0.10926214106861623, 0.08303109901927172, 0.0849696921725427, 3.5524281522920056, 25.455678393763883, 44.75976244095833, 66.46511170171922, 91.14340966747653, 87.96695663082986, 77.57766492905156, 65.14186090038669, 66.17774317341467, 53.96229005629017, 54.287776177929295, 53.45245253655219, 50.47960189081008, 34.56392595844884, 46.80356441005584, 54.05363421286307, 40.169047847870864, 41.85567878907727, 36.343897542645855, 36.27403620750674, 35.892185626491425, 51.180419614238126, 54.752306399806855, 60.924638317477324, 68.43248628800916, 70.26099328071841, 65.66996489801716, 66.1595041521134, 66.69871237970167, 64.51625070264264, 67.13311487628569, 60.7426913322941, 53.3236889685354, 40.97528319205008, 38.693895416875044, 37.539079035482104, 37.907958338337565, 38.086775272123276, 44.31527945303148, 49.429249994216434, 62.724759117249526, 60.44767418215352, 66.95366644090223, 81.42858520630868, 88.64391849886987, 99.95128016318046, 110.02380124984249, 95.3415773760888, 57.068889602538086, 36.203747334018836, 10.45515908348945, 1.005223556872337, 0.6487261347713009, 0.32773204628498326, 0.2537541836500168, 0.03560574807887597, 0.07976636936467502, 0.025221680989488963, 0.054715780706535426, 0.053093474613682884, 0.05264319111442855, 0.03395166848936389, 0.032263869539864605, 0.030991502834724325, 0.0383788637907034, 0.018719940656615842, 0.0390452683542765, 0.007733666692905489, 0.02278736574695476, 0.0728641240106475, 0.039280426703513636, 0.03162453852353558, 0.03153418036808651, 0.027827065580734806, 0.01475001844922982, 0.0732845837070096, 0.07833034521149052, 0.053305757577501, 0.08823940139864722, 0.021098716439859524, 0.01482509027775978, 0.0200923488685681, 0.05550808032914516, 0.037240457135222615, 0.061633596797623945, 0.02023848588578403, 0.0650593045077497, 0.07150293132590671, 0.07564247976387702, 0.07308669553528871, 0.030891840541434866, 0.07041694806708444, 0.022127886618217154, 0.06258376798922978, 0.1368497333098804, 0.07814998513147717, 0.13872306343288193, 0.1504819768090402, 0.21376630922238674, 0.18771211857036238, 0.09606701201729237, 0.1132985587502199, 0.2627356759002132, 0.20155341214229985, 0.31923564090844125, 0.3186341393138132, 0.21896286747388302, 0.3518471151830689, 0.24429500493551456, 0.23145500360237015, 0.34780802385460946, 0.2790571484834917, 0.25644091528750235, 0.1349173990949508, 0.1377066179749466, 0.17487668312124668, 0.11022950327324291, 0.11809872012705573, 0.09968394293419777, 0.01709021691743645, 0.08541337965476899, 0.0413536751312354, 0.07795073332325106, 0.13096554985930844, 0.11383104348374952, 0.2197928471310485, 0.12826377225499, 0.17157821495446468, 0.18724295100377453, 0.1361278486588309, 0.115477642224681, 0.01436981763089857, 0.024669132413222425, 0.0222837261389941, 0.033172357887510336, 0.06861562254808604, 0.06161259066674018, 0.0027454297730488885, 0.06482759355417182, 0.05470805470981906, 0.0813739895520191, 0.025525927062957518, 0.04877281532953343, 0.05997060377511287, 0.024457755348374768, 0.06182488129143754, 0.042204005914109374, 0.03142786843161429, 0.04769343191817884, 0.0651918147360125, 0.07179063564587025, 0.027579573215916756, 0.02866769002960815, 0.01054761824273174, 0.04123793839807472, 0.031340879147812244, 0.05447656592173923, 0.0340085122133455, 0.026201988164816174, 0.03918596806244985, 0.04698650513385092, 0.07100012483856372, 0.054991204637072744, 0.07176338589840359, 0.02672446204439527, 0.09490572231551332, 0.05361413478010124, 0.02579568002763535, 0.0279519877081076, 0.020634417362030477, 0.03216743056151656, 0.15983050178375938, 0.20930985319277934, 0.08535843582883959, 0.37777459489241727, 1.6249886876152408, 15.24112141901447, 50.62464329504198, 69.31828298876363, 87.77425058426397, 100.46711106454173, 101.85264910421064, 92.87655599655645, 80.78604605890091, 77.23988609929239, 67.07221615699031, 57.53393757727839, 56.20119464012885, 54.01207277851721, 42.01802569050943, 47.61577744637766, 50.737513419120546, 42.01061241088375, 52.46250514061221, 39.57360067675191, 42.60029762021957, 54.54803720597298, 55.536525480208866, 68.67317861126315, 68.3228168179912, 70.22111846554664, 70.9106711418398, 64.9466484592807, 58.82435029552829, 54.56547214138893, 66.68859266465711, 65.92076516920521, 87.4049751220211, 63.94814245162472, 51.92295174444876, 57.464856793803555, 53.32693669103807, 55.53931820777155, 49.20191334139917, 55.109081268310554, 50.02750166000859, 45.667230236914854, 61.09112331944128, 77.66631833968624, 82.615368904606, 93.70744735963883, 103.1466547135384, 115.83494955493559, 106.92084558548467, 80.83574248898415, 58.34798628284086, 28.792103336703395, 5.805494208489695, 3.7738952232945353, 0.8569192922403737, 0.31602882750092015, 0.1317161934510354, 0.03698359551509062, 0.05803602492256511, 0.12181227771385063, 0.06608960849623527, 0.03680795836713045, 0.05756960761162543, 0.055779405689287576, 0.03866002571979358, 0.042240406581831556, 0.05007303124594112, 0.044885941841188944, 0.03220224159679586, 0.050122696726072224, 0.048124907958892085, 0.0549341042736365, 0.04384950914930913, 0.07467846536347944, 0.02460080120081623, 0.04291939030912134, 0.13067730161691868, 0.07823161946068849, 0.07527472691670542, 0.08053780458266697, 0.09164941196720447, 0.09077326785172186, 0.0180244630563163, 0.06306234311552779, 0.02757854857331803, 0.016275913334421573, 0.14899711455068282, 0.008379576968089228, 0.02938157863794796, 0.06827835233942156, 0.12073812285257925, 0.06782579355903211, 0.12752376962453127, 0.05237172019758052, 0.002426040535342069, 0.10756694937064763, 0.13814501945049534, 0.11683677413290548, 0.15192026092160135, 0.22862916571959374, 0.1550476616548915, 0.16051654884171102, 0.06866611540317535, 0.2662570143659269, 0.18928069891708513, 0.2485830901611236, 0.16620764749184733, 0.16914516567222534, 0.3305096359502885, 0.22889052427584128, 0.17534091708160218, 0.23316629080762788, 0.5021922686888326, 0.48792538263144036, 0.23929638848189386, 0.43676342634904775, 0.27930578998019623, 0.37815524866023376, 0.2340739364585569, 0.14049320151248287, 0.09327076811103091, 0.2180901401105427, 0.10138960705409128, 0.22816476321989493, 0.2028732743835257, 0.18366741947829726, 0.49301680297620837, 0.28371738390095774, 0.5242468368622565, 0.27489741362871667, 0.20837021571013237, 0.17212252042466597, 0.1523688666883015, 0.11189130119859211, 0.15389868298605566, 0.13818692445995348, 0.26131412314791835, 0.12114151410998837, 0.2674448490142822, 0.22151911901610516, 0.16822363850810837, 0.2535722071244832, 0.11107433737526018, 0.1744794205672318, 0.1925924357267157, 0.09244726189682562, 0.12996077958133914, 0.106661556018216, 0.11373814766205127, 0.14930682857671093, 0.19879610848522958, 0.11704789264307869, 0.16361108440304958, 0.08518359158188106, 0.1712636745745136, 0.19511384559014153, 0.09596347523432586, 0.1633425552638308, 0.14049013716078576, 0.1346730323688638, 0.2243718619067823, 0.14580612851967736, 0.12557344766513956, 0.09629192777098187, 0.2782627459495299, 0.14945330458783335, 0.2725826636437447, 0.1369742992063684, 0.15714594583597877, 0.15970023619311471, 0.06169705569083172, 0.18481589252910308, 0.28198470752085414, 0.26751015034894793, 0.20333574634165535, 0.22187014050301046, 0.4305341509321044, 6.305224270589891, 34.70706893551734, 61.30761461873209, 93.21532326359903, 122.80974741904967, 126.70954827339419, 119.1013974528159, 108.42754563977643, 105.92217091591128, 91.88104275734194, 85.74485548080938, 91.13365081048782, 84.76417664558657, 69.55711610855596, 89.95413918648997, 87.2479469545426, 76.34785282996394, 84.71664536383845, 71.85589175070487, 75.10448501956078, 81.69697730771958, 92.94045925140382, 102.56750891285559, 99.85220109262775, 103.93030505026542, 103.62731764393469, 97.09820301302018, 99.26958791671261, 94.32036476750528, 95.77655253871795, 91.51779205568376, 86.05510711669923, 80.48065031728437, 76.62346993723224, 73.51881196421962, 70.79005825904109, 70.02365850633191, 68.02845862603957, 73.18236674031904, 76.08480299672773, 86.47309841648226, 86.2476170447565, 98.20635887884326, 104.3364586368684, 117.57603476124426, 128.29618623179775, 140.04505772744457, 122.96326898759412, 85.56072373544016, 54.81613905199113, 22.544548203868253, 3.3301518472933003, 1.8977425872318208, 0.636670362324484, 0.3694897830005615, 0.12387953533400452, 0.15563097632219716, 0.2386391922951706, 0.18392450326392729, 0.14606713467547972, 0.22610980897180497, 0.14363388621038006, 0.19881608805829482, 0.19441282917414943, 0.1134927467172665, 0.14226692488356946, 0.19969017905814035, 0.11535878368322888, 0.15658509286661304, 0.13547843592541833, 0.131880059658039, 0.15326453072409477, 0.17633232678617203, 0.13476232757731793, 0.1331103662209165, 0.1776261880032478, 0.17329186171052918, 0.17899788375343048, 0.19776838621304882, 0.14429782397083699, 0.15233417822709008, 0.1274059529626562, 0.1771909428099471, 0.09091458809111388, 0.13861772634329336, 0.23053159186195946, 0.11648418216575539, 0.24193203737658842, 0.15225839680962025, 0.26378285680567065, 0.18881767537565003, 0.20254491377742062, 0.12938144857123976, 0.15705675787983403, 0.29731725252443747, 0.25289380562401587, 0.2576624271610091, 0.3027398067135965, 0.3565632443754904, 0.30550115531490696, 0.21727431775821796, 0.16991952734608806, 0.3499781057959603, 0.42911492708709936, 0.31145016512563156, 0.3882787022138796, 0.2753973319645851, 0.47009879242508645, 0.5328777059912682, 0.3898243918534248, 0.402097120400398], [0.2668394250494819, 0.21774278052391546, 0.0519738600949847, 0.06455966962441322, 0.09415824266691362, 0.06503266763062247, 0.17424724996089938, 0.057097222475755605, 0.08103824385832395, 0.14495756356946884, 0.13681800194805668, 0.1773040173875709, 0.14423972386265957, 0.177343807994358, 0.04605395013406392, 0.10729448253949804, 0.14790907051534424, 0.04131241363563365, 0.06570838782335482, 0.023196496918136557, 0.05770479148674396, 0.03511466656721408, 0.06642878626383121, 0.08133670405274437, 0.049170744380042444, 0.07283361838950266, 0.0693350863612948, 0.14342610784355672, 0.013024311554017327, 0.11015723819934553, 0.00840607977982971, 0.09106810445026045, 0.03771815126040771, 0.022009269394461187, 0.07249761988679249, 0.015422592893423093, 0.032234689250828764, 0.041785944072950276, 0.022642887310094895, 0.05325387044238949, 0.1186556047609737, 0.0707133015197131, 0.05439233455446459, 0.06890476711334721, 0.027654197840620915, 0.057384294773181604, 0.008544369183871295, 0.03626676321390175, 0.03687843462572463, 0.03493685372954896, 0.026343168593162013, 0.03906612892845466, 0.08461519264646115, 0.10453026110847151, 0.05688666320976712, 0.07643578679210718, 0.03223173215144104, 0.014848400418075823, 0.054049916234948946, 0.08181668111994382, 0.04226654933224763, 0.13962124023706685, 0.18959412080866678, 0.024908209302192254, 0.11367111496867673, 0.12339605724499111, 0.12988956404789803, 0.08818710823693583, 3.6384462204671677, 14.160910479484068, 25.87830005153533, 49.11805306711505, 58.024002428977724, 67.87682763991818, 68.11725324200046, 68.20634595809445, 86.0156245385447, 83.29138940380466, 82.37084834806382, 85.74981335670718, 71.6869866463446, 74.890088265942, 84.53927578464632, 70.44901601729855, 53.0984547061305, 39.13431875167355, 35.57430105824625, 37.87134301277899, 63.65532967352099, 99.97721487475981, 101.81543365601571, 95.72239245137861, 90.03849367941581, 85.40404858127718, 83.28894184481713, 89.04805598720428, 89.50473754636704, 90.85196971893312, 88.11612436848303, 90.37161273341026, 77.19347661541354, 77.31219891578921, 79.0747473316808, 77.25332413950275, 75.76227434219854, 73.53433670536165, 74.82737741162701, 88.48894565336167, 99.98188249526486, 78.08745538034748, 55.62905811494397, 31.546829015977924, 8.708862027814313, 2.13903711688134, 0.6106524842400706, 0.344860332026597, 0.021851506992994298, 0.05100249891139327, 0.05492680728615773, 0.056062800764677026, 0.040688170720973325, 0.06567082653242735, 0.055130962057099234, 0.01303953180585297, 0.08277695701127091, 0.10994242714537729, 0.025149687876804702, 0.05258565408087546, 0.05245954068678041, 0.03577858517547289, 0.0954225711945084, 0.018436239146056677, 0.05513239464151764, 0.06730954988949722, 0.03047342438461079, 0.04628050914635101, 0.05536611657589675, 0.13821983559718057, 0.05898692772813863, 0.00900570445904328, 0.048533458818471244, 0.10937723811836013, 0.04170791418742269, 0.03950372218124328, 0.016842571335033547, 0.028622238033060587, 0.05940969717959243, 0.03552038673191302, 0.06765669497150568, 0.03235849672027173, 0.04984395563482277, 0.03944409372765691, 0.011575353921451157, 0.07827452804532745, 0.04439302937938802, 0.020292841739231543, 0.11843569156142975, 0.13148955399951628, 0.11074401558406892, 0.1578143575499135, 0.08909506032303458, 0.04477239228905209, 0.040115550641090646, 0.05916754827804624, 0.039243451469848235, 0.011097634898408527, 0.1231156767255837, 0.28194364520811266, 0.18648855358121857, 0.2868072616477167, 0.22082024764630104, 0.2599407420043023, 0.22313682092053277, 0.18252294540645617, 0.3493870842841364, 0.23166426817976662, 0.223038072187093, 0.3262025057788818, 0.1174792537706033, 0.042129641759299466, 0.10010246442811144, 0.08029557524188873, 0.07519954304781652, 0.04840850221714185, 0.025211206652344238, 0.06536704968781241, 0.0978608605181498, 0.03618842689320445, 0.08163239866975816, 0.0962944022349773, 0.08940068343954702, 0.10099347064932508, 0.13826783866651599, 0.014604523030650473, 0.025536675276535175, 0.11074203907722428, 0.04718803222321215, 0.04069582776977651, 0.03598693427779982, 0.08803382170416656, 0.04398065957150633, 0.1341211885934876, 0.06437069105525171, 0.07454474471629628, 0.016816587547861764, 0.030876271719593677, 0.09697231343917309, 0.042026886386015726, 0.01692404095534115, 0.036176993030934565, 0.01640625170341903, 0.018705718234301578, 0.06325974865185638, 0.034221902174214204, 0.022390752452455705, 0.10963736327304956, 0.07876403524630493, 0.020004394313981457, 0.017018740914101084, 0.013169026520523815, 0.030861495798754118, 0.06864840345036599, 0.016803460631279216, 0.016651918863757484, 0.020361529182522528, 0.0022631779035192827, 0.03744401435758318, 0.05673154955729843, 0.09251827824740641, 0.044940337914252476, 0.016259626305151372, 0.028254358781381484, 0.0626087922512764, 0.006971606954691872, 0.04831812299427487, 0.040371734273409655, 0.01974819535990396, 0.07026685612095941, 0.045540805290182756, 0.04770311526954175, 0.11718319909226511, 0.1119114876153969, 0.627948175514898, 2.7574639839510766, 15.52586490108121, 35.70500227712816, 50.40720670453964, 69.72158108988117, 76.40829655431932, 86.96234349281558, 83.96916712484052, 83.63017236032795, 99.36156749725343, 90.92636139162126, 87.14211356255316, 94.17472716300719, 88.08305094319006, 87.07722971516272, 87.22381653324251, 78.8548827940418, 74.53315258026123, 70.13963514758696, 77.31856884494906, 79.30853628343152, 96.21228864116054, 113.01529099864345, 110.94569944566297, 104.44982297958867, 96.37425115031581, 97.6154302781628, 92.4442715798655, 97.5329585229197, 88.0532487746208, 97.5529783002792, 95.29148086424797, 96.61405701791087, 82.08288361949306, 84.3260871210406, 81.87308388371622, 85.54448512292679, 88.32833243954568, 90.13253642666726, 89.05958775551089, 95.88575132431524, 112.3078130906628, 99.70134673580047, 84.64624666398572, 58.309590201224054, 26.827711712929514, 8.590480973643642, 2.6104547756333507, 1.1121131696047322, 0.5601972593895851, 0.24015284413772248, 0.017074843448015953, 0.0376210572768844, 0.049756648424532146, 0.08194961269656498, 0.07173472654915626, 0.06607916671782732, 0.040394996533230434, 0.09468084486622004, 0.010423820349387826, 0.06042612348532966, 0.07881904802014751, 0.07630540628827388, 0.02036218801813741, 0.022926659683787057, 0.05047201749778563, 0.05580695804148432, 0.0935299739602112, 0.02788176617374824, 0.04926175179500734, 0.07397248469773801, 0.07578818968707517, 0.04298867913143289, 0.005890112492300931, 0.049058677208039074, 0.0653843173096257, 0.03456428985021288, 0.06668806872180393, 0.03089097294686062, 0.07739333541042383, 0.04011656570759031, 0.0334384853410865, 0.03581087578148131, 0.02511709083562657, 0.06006517732936529, 0.023709425342179114, 0.05328939393943837, 0.08451227639471331, 0.12868106034734558, 0.09517101090281241, 0.1567046945133517, 0.05893933068540308, 0.009409077521864205, 0.0907849430316879, 0.00970556791270933, 0.0775508277658974, 0.18129076958904344, 0.08541793021703921, 0.10046857018624583, 0.19580032165733077, 0.03671433476190414, 0.21665381718306773, 0.2781152893458643, 0.28540035649653406, 0.20253222736139453, 0.12837064918130636, 0.20080221696726738, 0.21198707001824535, 0.24767886126233687, 0.3004772732815435, 0.34680254877574984, 0.17374825093054003, 0.17767221456573856, 0.21439051766309047, 0.15458169633582716, 0.23650873242126358, 0.16598997126904227, 0.2204046143038619, 0.28653202157828117, 0.29075589331407703, 0.19982047529230196, 0.20192360114907065, 0.2685816622068805, 0.19859018405118298, 0.31750783684753603, 0.18431730718622286, 0.09441455270374015, 0.1399091820442869, 0.2002545253884408, 0.10521002624544407, 0.22772991639231482, 0.22211473705547474, 0.29906402492234785, 0.18041623425820183, 0.3784726848525386, 0.2832322357402694, 0.1916308728076758, 0.10613254932386261, 0.22630724515165054, 0.14768644536454834, 0.1175721419314223, 0.19884893790848795, 0.1696973618480467, 0.22531042686633526, 0.08383185242212589, 0.19834532702882446, 0.09794561282521295, 0.19187572983003434, 0.2501635908359482, 0.2544727588012334, 0.16706909804094225, 0.13438058596464897, 0.15206825378681385, 0.1711989401449119, 0.21493037982333094, 0.0689136077679934, 0.1503875334897349, 0.27352755648955224, 0.1061803149059415, 0.14645892736171523, 0.26751790315874163, 0.23496543297604208, 0.18839108697589368, 0.15791287645697594, 0.18088042225328185, 0.29065323753222344, 0.10544424230653433, 0.1474734269563229, 0.10586886952120451, 0.13286115781914803, 0.2632162275333559, 0.26677749450168303, 0.20179117519047954, 0.25175631827404427, 0.33290687828294696, 0.2422005511940487, 0.54954698249217, 6.792201726667344, 20.539760089689686, 39.367303617538944, 69.36777545559791, 86.12666683812296, 102.4531953565536, 113.11282465534826, 117.52959389840404, 139.44051065752583, 126.49219405266547, 130.2858006569647, 133.965823265814, 123.08532530261625, 124.80163681891658, 130.4067430188579, 125.85789972735991, 118.30562699225642, 111.91257153787922, 106.24601748681839, 112.45507455641224, 141.22004293626355, 158.43137187342492, 153.09912927689092, 148.17054563953033, 136.4911706985966, 130.51452975119315, 127.72276709156652, 129.34481620788574, 131.66274870595626, 135.13225770765737, 135.81021585772115, 136.12311117110715, 122.65249175410118, 124.96638421089419, 120.43277540514548, 120.89292433954056, 119.72353243058728, 120.75740645008703, 119.75353856240551, 125.57346513194423, 134.00128149217176, 106.25947121650943, 82.4804158364573, 46.250831850113414, 16.60210640199723, 4.176966807534618, 0.8920226666715838, 0.6288620264780137, 0.33090263905544437, 0.2745217241106495, 0.14801001026024743, 0.1319813058381119, 0.16272836725317663, 0.1755984298764698, 0.1603898838643105, 0.12479686433629644, 0.10822268999031476, 0.23944237419674474, 0.12966410437178227, 0.18537613262812938, 0.23738005018282324, 0.19790908592122217, 0.23245459512597133, 0.09552135823234435, 0.1762573114566265, 0.14996200229131407, 0.30176635410997177, 0.1785842422395945, 0.1466585851965412, 0.28850883485809453, 0.09941845516403837, 0.10121438742404985, 0.2307443651220491, 0.28023977373396197, 0.18211219970497394, 0.13727036154558583, 0.1303394415205525, 0.11157955703956467, 0.23850593896162128, 0.2546395054988323, 0.22212000774039378, 0.0676509186685566, 0.17764339433802714, 0.10543003137553893, 0.14992708400372537, 0.26275105894573275, 0.179240090111571, 0.2680693945336727, 0.2327706523600125, 0.32847852235840214, 0.19670326352840473, 0.2544116556283928, 0.15048213002662505, 0.2703208043690651, 0.1918990801899664, 0.29179293121541705, 0.14115421281706902, 0.15831548630470232, 0.2993211546732534, 0.3676725305136173, 0.26829817903137976, 0.34014386575548883, 0.3088550882474069, 0.2896665162857502, 0.20334922948912268, 0.24419443291281503, 0.32991898216066823, 0.3638005995702359], [0.2432371907296681, 0.10754191361728216, 0.018746518161928943, 0.0968159472329482, 0.10340546783540519, 0.04091318606609299, 0.04815341409055456, 0.02993285742348, 0.14270016292650856, 0.08671767498937347, 0.09142314023788899, 0.17273540608584884, 0.1500223240544719, 0.04403800125263872, 0.12858813388213036, 0.03772171739969523, 0.12881527895167952, 0.026879930012528936, 0.15798242191874212, 0.10624031491217115, 0.09305555869134204, 0.04653999461762367, 0.06918996632579835, 0.046203570936115525, 0.020985446509815032, 0.00773863333667959, 0.019329516817965818, 0.018123315211625832, 0.01094989005416151, 0.04625474560945746, 0.03241079754286236, 0.028088960398529327, 0.017966399337315274, 0.031961324181587945, 0.010455974017179782, 0.10686382621286378, 0.03499637110038631, 0.02573537358623599, 0.02976738817749485, 0.05740556903483887, 0.018752539613013788, 0.031292211497202516, 0.0677789013171869, 0.10591033786054581, 0.05897273594934133, 0.04157874410250976, 0.03369496774769599, 0.056539123592477654, 0.035393744737150214, 0.029870231650889884, 0.032341466585714976, 0.029868709051140377, 0.03292276261134013, 0.03656470629897329, 0.05088861611100936, 0.06372854466580095, 0.014453466771350754, 0.07012856958974754, 0.0530176472309376, 0.030023887821082628, 0.10346103219255325, 0.04308169752719902, 0.05530431243260542, 0.16591769853426566, 0.22028692787693394, 0.043802999951426065, 0.050521158207688606, 0.06697843902774396, 0.16514644717737553, 0.14200383496861305, 0.008766447539411245, 0.47118011020844985, 2.401078900983257, 5.447305325538882, 17.278829005456743, 25.15892363363697, 30.773082663936002, 42.959080742251494, 48.89923187994188, 44.96172920350106, 52.48347020918324, 41.08597247831283, 51.00027691933417, 45.260158815691554, 38.2797872635626, 19.34270174272599, 5.759181803272617, 3.600820394292955, 7.641857708654097, 18.662258771158037, 31.200460195541385, 33.69769011774371, 45.490982455592004, 43.543219720163655, 45.542483175954516, 54.64376265002836, 48.77260992603917, 32.92541073214623, 27.209474040615945, 26.216122027366396, 48.49505909027592, 55.19050967308783, 52.27979721561555, 48.16670179367066, 49.55977862881076, 39.07649517059326, 38.77774000167847, 25.94998528880458, 17.495718425320042, 7.190803770096072, 1.7596708670739205, 0.24858255389957662, 0.203925434860491, 0.01701449104134114, 0.03768161652729877, 0.03535023094305108, 0.059632287856431744, 0.031568725187812126, 0.09828024003053866, 0.07436095256238215, 0.06249977793965129, 0.004333877652477954, 0.09817150917144553, 0.04837205175370459, 0.0846087575078972, 0.09070391391193675, 0.10066755386369844, 0.03752343852313296, 0.050665485342183424, 0.024229394114245812, 0.041128445281496936, 0.1405846264453665, 0.09159951666069609, 0.06370160135350401, 0.03830878589782984, 0.07243011987978414, 0.011283630512714868, 0.041522210644137476, 0.06482901847771098, 0.033991895766267856, 0.08062133114905128, 0.05666986798807498, 0.040639692677124854, 0.032580650726994204, 0.0851704991392551, 0.029578145307999466, 0.030151449121354573, 0.009939664272561429, 0.030157874683819474, 0.010616768211607012, 0.05646265269587598, 0.03592983391436358, 0.010745120497660772, 0.024479866561089313, 0.015300226626887679, 0.058619182541846275, 0.06257038826363222, 0.04679084627798969, 0.06535713651007222, 0.051053945545948325, 0.1173630995195239, 0.02357718515990963, 0.0310664702837746, 0.03866756785540812, 0.14101449370143876, 0.17293054400192154, 0.20969357131229294, 0.1366174094859631, 0.12682776342356397, 0.08486713598211927, 0.15083558767312957, 0.07368743870287173, 0.09088599002890049, 0.15714128802139915, 0.24594391726197737, 0.30556477125613923, 0.34001415174814964, 0.17209828140274172, 0.2508200822217811, 0.11070385725507814, 0.10625471736514762, 0.10644416324794294, 0.04104442075796185, 0.015674398333254843, 0.11462189903062199, 0.09613109527215843, 0.11489841846689103, 0.12257694071459195, 0.1477758937905873, 0.08879008838125775, 0.06397257814364088, 0.1847139721916568, 0.13594524394119942, 0.14542841652949012, 0.08795928134913407, 0.12984064167305348, 0.08426214868743574, 0.052182090453683376, 0.04862027573249033, 0.060558748626781095, 0.07700348092663674, 0.04446838944849949, 0.10083828421850359, 0.024627112490575642, 0.0297436471127214, 0.034777875163502274, 0.05403241495631876, 0.062439241671874646, 0.016401800732578964, 0.03540055525879707, 0.04010331621693988, 0.07932714051416806, 0.034042752513121215, 0.023956232058304935, 0.0349486553140225, 0.06392254877174575, 0.1136509745171474, 0.06993386834379166, 0.022109395170944835, 0.05874949026732676, 0.08245591254484269, 0.1147647054805871, 0.044100406774950605, 0.04804456065739355, 0.023409369769656373, 0.007314288616931487, 0.017498377072174224, 0.020771497304761605, 0.015439665162815683, 0.0333240854313537, 0.05941237848732741, 0.05229229603203074, 0.09385263487215965, 0.04680232610553504, 0.03017941516103043, 0.01952724602644242, 0.05137862893001688, 0.09053222594722625, 0.041918312574947075, 0.08602415857416007, 0.09343484116177406, 0.07304254588821242, 0.019839633699326266, 0.1102040155280021, 0.22135277068422687, 0.31566864360244046, 0.43696239470474185, 4.283891599024496, 11.655963293967709, 20.98997366043829, 37.99293648812079, 49.03659328337639, 59.838902719559215, 70.0016696991459, 78.73645074905889, 74.45229684152912, 78.10002265437957, 75.46338189032771, 80.60338912471649, 73.88637727306735, 68.49360466003418, 46.65149019610497, 29.67883748392905, 25.80547732691611, 30.86821779128044, 48.832292710581136, 59.856894631539625, 63.44507886517433, 71.07560680758569, 66.29756373743858, 73.05434842263499, 78.52756884790237, 77.92279428051364, 57.660218284976104, 50.88786179019559, 48.700559908343905, 72.68307255160424, 78.9587236219837, 79.96975375759988, 75.73721824153778, 75.37384986877441, 65.48918677914527, 63.911919363083385, 51.66144732506045, 37.5014203594577, 17.767262151164395, 5.719638918676685, 0.9053332911383722, 0.39729938752228217, 0.08001324119827441, 0.13797102556113275, 0.023960225291610248, 0.020784666356179985, 0.03678530131676986, 0.053620784423283996, 0.08797796623360726, 0.08410467931459989, 0.038801847746776, 0.056367500745240724, 0.06403170480963684, 0.034299744368200345, 0.07505451494287099, 0.1101047918200493, 0.02342403460774691, 0.0732618538782962, 0.039339331204011556, 0.03601513014385297, 0.12562146605623345, 0.03617651039554227, 0.021581644860787258, 0.026728732984573133, 0.01133445374322154, 0.014924442305439904, 0.06834644989501085, 0.040153085118940765, 0.028342577636302, 0.09691179249315493, 0.02909501961943123, 0.05358176756530039, 0.07018838573487536, 0.06796850807844632, 0.03113608852389359, 0.05786395391389247, 0.03573679507920339, 0.09332191214085588, 0.06442905929420265, 0.006771553148170032, 0.0746074796564156, 0.05353774049229199, 0.05919243847470611, 0.025551646549795425, 0.08859882687008189, 0.17413641236001448, 0.0751731743014628, 0.021682389253269763, 0.0475070427262014, 0.07053284950914883, 0.10340916804007946, 0.07486942043948559, 0.1335734816929025, 0.05067303896911683, 0.24706988264956783, 0.14431720599532127, 0.10214506167798273, 0.2784255855987149, 0.22424308252671074, 0.34113061764547903, 0.16006446503583463, 0.2233788127740545, 0.15077569491920934, 0.32403073844409763, 0.3264970819075262, 0.44048679752215264, 0.34921440806600357, 0.3169050482251952, 0.41975204562467916, 0.23169733253457855, 0.2670979337586511, 0.2048996382302815, 0.09036557118017828, 0.2840090795390068, 0.29881872356899325, 0.13770238916960456, 0.2289303148826284, 0.30537919411736153, 0.20157034268542645, 0.1294380471470856, 0.2356368324328815, 0.2247041602048182, 0.258604807238425, 0.40609646708734576, 0.28281447267340076, 0.25513323384427256, 0.17709587129854387, 0.31059891886768803, 0.1813842016722887, 0.12269225226895464, 0.10027685668319465, 0.16714881715034285, 0.10093596042884935, 0.1397316641504726, 0.10506297566837842, 0.1728777605439386, 0.13360568802923928, 0.11018189090874889, 0.08816620935836146, 0.1886037070183985, 0.19891977039796693, 0.09839175178879693, 0.07398450461726996, 0.2000193210739282, 0.2166859009453366, 0.270783000535542, 0.20987052230104325, 0.10631540685050911, 0.40323892848626264, 0.27645900725357, 0.1595317121715315, 0.19281427946782884, 0.15996288177707504, 0.16658260156550717, 0.1185476476506841, 0.11362365582176756, 0.07443725491964048, 0.2069213289406992, 0.17350114160968413, 0.14916559260699058, 0.16532519081186864, 0.22465064130242796, 0.14042011672450652, 0.10432603738961682, 0.19533645541917896, 0.2300735938573076, 0.19546483643352988, 0.20681386212668113, 0.37474110121688536, 0.36740881240656303, 0.17768627994002836, 0.1831907136065345, 0.15124152234244734, 0.2693362894558138, 0.19587136865142854, 0.1061159558594227, 0.9586059422262254, 4.550596590965025, 10.5752218538715, 26.84207739368562, 38.67246750862368, 48.88196952881352, 64.23791931521508, 73.83039720596807, 68.84949699524911, 77.62631800866897, 73.72542673541655, 74.35604972224083, 72.76888616623418, 71.17823954551451, 54.139498818305235, 43.25441560437603, 33.62766404305735, 27.90215676830661, 36.5610360330151, 49.06819189748457, 53.63340716208182, 65.11542804779546, 64.20768960829704, 73.23447150568809, 77.92248049089986, 70.35423586445471, 56.52428027122252, 44.246485002579234, 43.64958655449652, 72.12295809099751, 78.582395738171, 78.56833796347343, 80.10731912428334, 81.05643856909968, 67.53838985197007, 60.689574595420595, 42.78945392177951, 25.124498951819636, 10.761850187855384, 2.907346328420024, 0.4353166233387686, 0.456957565320115, 0.17883363450246473, 0.263762264362266, 0.10927135710634532, 0.12106842932201202, 0.19744823806949202, 0.1808449217388707, 0.31741829649094616, 0.26249233573194475, 0.12400245414145532, 0.14690649124883837, 0.13675391103231138, 0.2277133382496334, 0.17198866954253567, 0.31714271934282395, 0.31741317902361194, 0.1502301790300877, 0.08574876528713973, 0.19961868773304647, 0.21741547711914588, 0.22506011529795586, 0.1955893716865009, 0.17914697978525393, 0.1578960072008833, 0.10909098170457349, 0.18871033113569985, 0.12647441302936885, 0.12791399183052202, 0.27249704565732713, 0.19229059708454918, 0.23441234813822856, 0.19546134307259516, 0.2028050159494723, 0.13296519255926534, 0.2233458863150689, 0.11159045847072718, 0.20257244697741925, 0.1471113278380325, 0.1783170001280885, 0.1752863562996349, 0.08038900732513397, 0.1696069787947401, 0.1466612665042762, 0.17992386954926676, 0.24366814583059282, 0.16990422090936094, 0.1961221705160795, 0.16547306110301327, 0.2203670453520552, 0.2095578818191444, 0.17956946195373613, 0.20549243706608974, 0.2532569006566079, 0.46601692274693524, 0.48884965239032624, 0.27995576961867275, 0.5400874513772227, 0.25827339760238127, 0.301776742262225, 0.2382001166622485, 0.3457271451911619, 0.3144763350006073, 0.35962670741062014, 0.4170307481000501], [0.05089254231162129, 0.08077966620124157, 0.06766091611596846, 0.0032375747105106716, 0.03718004727195348, 0.033927548211067915, 0.023276196875339075, 0.03971645330649711, 0.01663305969428151, 0.014849001797096384, 0.04375391286767779, 0.01226057839249411, 0.06253500649284932, 0.045246390040002527, 0.031039678273842703, 0.004688884711809336, 0.028657273149057746, 0.06826720576012327, 0.03538043012902622, 0.027951328872492718, 0.03301724040460202, 0.02273008918329593, 0.061207602116008925, 0.06862889119093457, 0.0809429501814227, 0.026064274284327706, 0.031143808774950526, 0.04914122701231991, 0.013481783830831129, 0.04787982877103552, 0.06927326306580536, 0.045257758784798846, 0.02776262417976414, 0.009981420852484242, 0.033317753714659525, 0.038160229957992994, 0.04337535051989459, 0.02075427756344359, 0.05567254408472969, 0.02703715423722902, 0.04877548514594955, 0.02056010491815546, 0.06968187138197884, 0.0779842266873006, 0.04183578575330396, 0.07558231887918326, 0.07499080707108782, 0.04169161949727324, 0.013829936318460011, 0.014491712753360551, 0.057456000602894255, 0.021822485667202744, 0.04726059607139999, 0.041702038293043454, 0.033358310409370935, 0.06833868942433788, 0.004949056310579181, 0.015265053615064151, 0.01635790006407807, 0.10929823913160833, 0.037620888737541054, 0.028287984295597965, 0.01903758943831969, 0.028222730841427564, 0.021350778519145904, 0.048039125263570785, 0.06885667211346089, 0.057460206425598556, 0.06597269581811083, 0.025303200405511646, 0.03816778741536602, 0.011443243974128799, 0.1121927951011927, 0.02957006882605774, 0.13768090806420774, 0.1045185016588338, 0.14947789601020275, 0.2025091527931152, 0.6251236399815929, 0.5341433445292135, 0.9656746048600444, 0.18843392661261946, 0.2571430501918639, 0.052073516642614726, 0.3791424295594616, 0.5349735386909977, 0.6698541042785491, 0.11784805615823116, 0.13200735282753745, 0.21700975695444694, 0.23026612707443778, 0.061708941544976935, 0.05921603398277395, 0.03806604327814233, 0.6121497264792842, 0.2216399310817642, 0.057655137497931726, 0.06853134521553594, 0.13879948836420813, 0.3587926215221805, 0.03971078042541781, 0.22063676958843587, 0.20762076721556727, 0.47040078428483784, 0.45805604347298223, 0.5945805724590056, 0.31631473151426165, 0.029532768005024523, 0.04591463704503352, 0.10100196656440535, 0.08746893145143987, 0.058555103117419835, 0.039228455298730446, 0.0393420048508673, 0.1379586302585179, 0.02895377598883164, 0.040388722273130576, 0.012726060118556265, 0.007622662467897059, 0.05577628005055651, 0.03061590141676847, 0.09929732134145114, 0.04832325195292792, 0.060451243508366816, 0.017536779144598592, 0.04496434710979943, 0.05911163918133225, 0.038010494242752754, 0.032473294995725155, 0.019218211903447108, 0.03972722067227287, 0.03674967822829082, 0.017932706790405418, 0.022154764813040535, 0.04517213313750202, 0.028955620345509345, 0.07567745167762041, 0.04241021380068795, 0.07546306963288978, 0.05235314256541672, 0.06232638542930927, 0.03535981853342345, 0.027259880894674893, 0.05028483923524619, 0.10048916262965049, 0.0316683376853865, 0.027815624057585676, 0.06545562477361772, 0.0708484624121939, 0.06219537290293844, 0.06149582737576097, 0.030317121380639654, 0.05070965414145782, 0.011694191395485354, 0.042903329275788805, 0.024768878976183555, 0.12419283465151826, 0.016325100009600003, 0.050119291465248794, 0.007689186191606907, 0.09807548005013697, 0.08265933953225613, 0.041311199386273666, 0.09195498911844147, 0.028062641447890672, 0.0655264419413382, 0.05714118060085082, 0.039975731934030215, 0.023604287435450864, 0.03217641294242875, 0.011852165428741325, 0.04955348956789221, 0.051442750489279154, 0.07808706633025601, 0.0608687844097374, 0.03426534318996053, 0.1761782818263577, 0.05759227998374451, 0.08108515142192764, 0.08204414794642119, 0.028784694638283505, 0.027090788052807895, 0.020069567328919808, 0.04705051561036418, 0.013507870082262785, 0.03340386582778827, 0.05483582668427018, 0.08732259333614381, 0.10552511054782138, 0.041372697094395276, 0.0491160610240073, 0.01296486600392288, 0.06008727513554116, 0.0628867557632827, 0.0982051327704422, 0.09837678243075648, 0.04679325562451155, 0.02000453220980783, 0.06242987241656069, 0.04608999457090132, 0.0052823069516659505, 0.09104785674642171, 0.03605299786995015, 0.03414622800905378, 0.04355348894492753, 0.03661701861288279, 0.04977664331935587, 0.0036868725897699238, 0.022554067076153816, 0.02957902056345296, 0.02022091948968028, 0.017830108465146155, 0.03730188972587067, 0.05638694022631934, 0.037853595605420495, 0.06177150794575292, 0.051628752806854826, 0.1122039799848872, 0.06976286219733377, 0.03074200714998428, 0.027646420132969658, 0.06997810992141885, 0.033214186288176045, 0.029356623323814526, 0.024704765077800523, 0.07213995641758365, 0.067010591737926, 0.044187721646120476, 0.07547828413906597, 0.04586547718293244, 0.0126542805528809, 0.05465891783035571, 0.05080327008580489, 0.04389473898035865, 0.04412372649136571, 0.020459224545066396, 0.06422570508514201, 0.059471604744753534, 0.03792835046507178, 0.044122228789473736, 0.04778986323564764, 0.05525880680990316, 0.028708512939873244, 0.060440456990392945, 0.04333884259986301, 0.024770516489121704, 0.0682649381398674, 0.11391874522932115, 0.10901607362733734, 0.202040383592248, 0.5329253873036754, 0.9540672696405842, 1.1233798102025063, 2.1761814721169013, 3.398088034122221, 3.9655687059125597, 5.473452825700083, 1.9393477805199164, 2.8184134489105594, 2.1893473978965514, 2.1788653539073084, 1.8355200680032855, 0.9615234501900213, 0.024359839735552672, 0.15886789698514248, 0.160282876703047, 0.3271356315141724, 0.17928450788942077, 0.2668988428288891, 0.1296922964073958, 1.3431173611071803, 0.8285096263693226, 0.08405684478460781, 0.06701946303608917, 0.016599585482430075, 0.06924251229652474, 0.42882981980519913, 1.066834308928059, 1.2307548162437256, 1.8747206032276156, 2.0070237426027178, 2.1073294118527444, 0.9828901939815091, 0.18481442164028847, 0.20794872945595175, 0.12591474749628576, 0.08171227099674364, 0.07135033427226929, 0.050387203903688546, 0.0707475916152039, 0.11278570118931033, 0.10184174448612238, 0.09536115392561882, 0.05214866220710739, 0.101176688237296, 0.0561797364254392, 0.03352966512583437, 0.014985374066107457, 0.020008699728115913, 0.04653152934606037, 0.12964452316443767, 0.04987371432024145, 0.05657183937728406, 0.031155520344092965, 0.03433806025573323, 0.0486882085791759, 0.1172087021592644, 0.08179282514198173, 0.020952408968080437, 0.0776050361474195, 0.042477951294952826, 0.03125180610485616, 0.011908847316648933, 0.026228324352433125, 0.03693262385504861, 0.060291606106705246, 0.056582484168991934, 0.004920631096953707, 0.0035002305887774717, 0.06336934135986433, 0.048422521626156186, 0.0960679313228015, 0.02434102270091253, 0.05930642086652018, 0.023194876642176704, 0.09006678922882966, 0.0224610525108273, 0.06536592353856371, 0.023208560887724165, 0.03454309985822728, 0.032089113393017364, 0.06457164357866972, 0.06900612820660876, 0.030231813659831405, 0.0175807717436504, 0.05163249514636494, 0.07926347860766035, 0.01820721716109303, 0.02193877589888871, 0.13651176596120482, 0.046746861339817126, 0.048088568578203844, 0.030880851010161064, 0.050757362266942385, 0.01915709532406782, 0.07383209908561361, 0.039761955098759745, 0.06489598988405158, 0.05400405821180152, 0.049932806512280825, 0.046384777543285204, 0.05108704054427724, 0.32602756194049315, 0.1915625224430715, 0.13592612238660937, 0.11980907270504583, 0.14602351362907118, 0.100148452686206, 0.10957962322619655, 0.13116804221945425, 0.18627201116854147, 0.10425400980297597, 0.14396184845076454, 0.13434651037377698, 0.2343962296483017, 0.15215823847439983, 0.1496645916373499, 0.11800986924959768, 0.23982236912894636, 0.15975442925287833, 0.24825598593921433, 0.276711264685277, 0.13460022337254018, 0.0797015583262809, 0.14583363107615901, 0.10978417636285867, 0.13769800714667768, 0.16046433228879206, 0.18579208772749672, 0.1437784623234503, 0.09796675685192309, 0.19259822735142326, 0.10727259540750135, 0.11594171530657238, 0.13085892574200708, 0.18294551950548926, 0.11980860539141203, 0.18908341595482445, 0.16561866377390203, 0.08433886473217318, 0.18900852319934677, 0.14094073475608904, 0.10372034529404295, 0.15111864183939275, 0.27695390005265513, 0.16795184583433215, 0.10329765628182119, 0.27408076390143365, 0.175623235803458, 0.15491345837231607, 0.198201026707407, 0.1773750337381517, 0.16892401141024407, 0.1952217260916387, 0.23987573481375174, 0.14967539347708225, 0.09793044428431219, 0.15489280464187746, 0.09144047680761545, 0.11588631182788842, 0.12238087583213084, 0.23453093854890716, 0.12948079485326044, 0.15845862217247486, 0.2429554695563932, 0.1414271239792147, 0.11300361489937191, 0.2607665234996427, 0.307815782725811, 0.17629681095000238, 0.15024452019603024, 0.17786378251208415, 0.21297690158169116, 0.27948125475837343, 0.23644341576483943, 0.1659035718729419, 0.2073002513498068, 0.21132958271811086, 0.4105991641840627, 0.674426117010655, 1.049450732046558, 1.3901259870298448, 2.0764157416359073, 0.5995266812462962, 1.107785324415853, 0.8011572231208125, 0.8231292989465498, 1.1122643034304343, 2.7086020381219926, 0.21023738648622267, 0.31235200383009454, 0.44316513283598813, 0.31938383295651407, 0.16587531855029447, 0.1808237317468851, 0.11745414140844539, 0.7187101665523745, 0.38945139896485115, 0.19183347242013102, 0.13571279754321422, 0.2032263643078266, 0.32863621389673603, 0.23196989129627907, 0.4594841845814259, 0.471422714932311, 0.9139137210384493, 0.807721677326387, 1.0061998593230401, 0.32200403751865514, 0.13857056597067466, 0.3171046907382627, 0.22577436971327952, 0.2546310019228728, 0.189843038097024, 0.14291120482788933, 0.23822308397821843, 0.22757081525220027, 0.18267838464629266, 0.2004706694353973, 0.11819960624580422, 0.19599921340423246, 0.15358254914322209, 0.15343599652330722, 0.20369985261030737, 0.16885213704118807, 0.23418820613334257, 0.20201815172068535, 0.18673262919389433, 0.1254512336585791, 0.15680373436020267, 0.13727789985076075, 0.12210902953219992, 0.17558698452288107, 0.1812854989041244, 0.14372823759913445, 0.1746497831998333, 0.21693206031716641, 0.11798110264804094, 0.15501568514493205, 0.13962848742883052, 0.11273513172542858, 0.15486992925645846, 0.21147596679868239, 0.1226984729028998, 0.11353537951025272, 0.15649280991525422, 0.220013786888411, 0.18062914541411787, 0.13917012170197504, 0.1722896348444685, 0.19840796237751362, 0.22880470710656337, 0.10573383120279159, 0.19473158303768406, 0.25238489341591636, 0.08388727122256834, 0.10126810550930039, 0.13168291459160467, 0.26457067098348375, 0.08310982987525002, 0.14407883007680217, 0.0878476240341702, 0.14535110293617173, 0.17658613171548615, 0.08243684461640735, 0.16501814277181703, 0.16352083924556934, 0.19256733868631626, 0.08939427894450004, 0.09433016811888065, 0.2274471686612214, 0.17996840990118443, 0.15803842294600703, 0.15196431097724747, 0.17645859339785191, 0.13994957019965495, 0.14774076099837982, 0.11225811941849609], [0.06496500674515002, 0.015188755088245437, 0.03801294955455008, 0.055000282778975465, 0.047237881564445076, 0.041159571433860453, 0.02721858300989674, 0.012960392050445082, 0.0672719273115358, 0.09879895816406897, 0.057286886693609346, 0.02440113570511101, 0.02431121996543821, 0.06637034141608784, 0.05420611773227012, 0.020740051310689702, 0.046990335573472326, 0.003382137656444684, 0.02264232998112998, 0.016498253117465687, 0.1075055014582411, 0.024362793004500772, 0.07725529402734772, 0.03188996692188084, 0.03192861988810042, 0.0680134621178431, 0.02169457005126582, 0.02304672098328029, 0.02859476612009589, 0.01393860110246967, 0.03948414863477792, 0.05206591321996624, 0.07416736980479571, 0.002144107490875608, 0.09307746880597646, 0.02666629298830465, 0.012794340577637477, 0.014776124810469488, 0.07535561814063019, 0.01905018775423448, 0.03967249135096227, 0.03443734142028036, 0.053040491972839644, 0.026132896610145128, 0.02319115537008451, 0.016720861031283295, 0.10265553670544779, 0.07262394778550633, 0.022387291650257768, 0.05581154690815076, 0.03115108086457176, 0.09225045390907796, 0.037901204139474905, 0.04601694042644194, 0.01618686327410321, 0.011747933420983535, 0.0030584767603525713, 0.0499160866433334, 0.09968345263792623, 0.034966175744850794, 0.02052273897964868, 0.013793298163481299, 0.044916301905628175, 0.048117576497456724, 0.06884125076354512, 0.06982184330662412, 0.07543919833316919, 0.06174554905643868, 0.07244771691940485, 0.13461482500837696, 0.03751326487549851, 0.034822296771791675, 0.10403539129202405, 0.023947764871521823, 0.043356657974542155, 0.03463833224809459, 0.0902729205066158, 0.049729865990699305, 0.02705337997946528, 0.06716456774982714, 0.0786126179680709, 0.06834784417503303, 0.11989301295890925, 0.036827489778759985, 0.059278761262014035, 0.03412087432919972, 0.06515139593712746, 0.0574055920174766, 0.03805811426812603, 0.054572970426130685, 0.07491362371271656, 0.12896495721032544, 0.03446187538605544, 0.005590330317406165, 0.15389169626418622, 0.055959378894899166, 0.034750621585596, 0.00946005492756564, 0.11856525235118405, 0.08846798671349403, 0.06322004614518055, 0.03635803875964015, 0.052016883592812285, 0.10471441332371005, 0.04467982205472166, 0.1194535389602665, 0.041869792396262775, 0.05795112322835673, 0.06673031080994876, 0.06623239196356266, 0.011822852031928639, 0.056011020881874915, 0.028283552476956, 0.023843552015962142, 0.12531764324634306, 0.06290999887090537, 0.06854226196845693, 0.06107501910939332, 0.007756405618912991, 0.04925044433724496, 0.006423927824794045, 0.09542590367697901, 0.08164228886486062, 0.04604188807969613, 0.05489737035766725, 0.10913598937012496, 0.046385440209339705, 0.046803892755340186, 0.049760214563819676, 0.014763844421043273, 0.017391281810799436, 0.0647583085622999, 0.029545278220828024, 0.028017641443218437, 0.02388572132575416, 0.06373277347114298, 0.05741431775893416, 0.04540197483654465, 0.03648991313492579, 0.07548075094218216, 0.07114721372002555, 0.05464487543870365, 0.06398608427374594, 0.04138018560385512, 0.0539184172427462, 0.04957702761936573, 0.033702609474740686, 0.06124821243687503, 0.0339440114405607, 0.045809437851271326, 0.07700205600309758, 0.03290340356949357, 0.11678477974548457, 0.06300357651085624, 0.0754667085505301, 0.03443033554621282, 0.05480784149239621, 0.06370434777871256, 0.0372996757317695, 0.044309617726192366, 0.04215879140481834, 0.03680162281999665, 0.08206397430190156, 0.041779439986473134, 0.09401536726903531, 0.038786518327411146, 0.04098713270298416, 0.09001340822226579, 0.05583675503129921, 0.02985727518887049, 0.035611608651496714, 0.026151646612091895, 0.04999866326069159, 0.003798189713814927, 0.02956110751256347, 0.029033081410753152, 0.11776123541377245, 0.04539186630638377, 0.010924713532139939, 0.009990006782895616, 0.009118309807813457, 0.07494687958950959, 0.005307335044152194, 0.034343564597469185, 0.01115729591073168, 0.0419907653403859, 0.05583046927988049, 0.006141922241377254, 0.03768885988862284, 0.017989738205928477, 0.05946281771626204, 0.05172302375637716, 0.04836948535915825, 0.009578476798900915, 0.05224228198189409, 0.041753358523091005, 0.06552054306432124, 0.01627450181742109, 0.08467117069108833, 0.02777974816009162, 0.031260683148678754, 0.02620356247550057, 0.013865614948313565, 0.038670758611612746, 0.04047510634747244, 0.011539413864093443, 0.0517351470977789, 0.05657529826426218, 0.037066773511469364, 0.0644442661394996, 0.07038248177137106, 0.04498724164741655, 0.025696870007161653, 0.032954275638105414, 0.011980673805209658, 0.07559185667384057, 0.06242947788127969, 0.029292017213940143, 0.03652303877677168, 0.018325165973135063, 0.034327388650948004, 0.017127963984685562, 0.044012425407286615, 0.0548247337311266, 0.07670295995569999, 0.00630610206562485, 0.035247981187797366, 0.08403932435377952, 0.04669548365317526, 0.007953399382982283, 0.0509637386928643, 0.10989279230876316, 0.042377804451051264, 0.07361616954327592, 0.05226320384310619, 0.01345149271430508, 0.014272082048738676, 0.03384029845737162, 0.050880641135717594, 0.03509547223427123, 0.045421195982564846, 0.03926996960334721, 0.08140724542881213, 0.00965062695960965, 0.10342559296517603, 0.15298391271743084, 0.048263462620877454, 0.044589707132188544, 0.11845026255374956, 0.032690492413577535, 0.07026582190226163, 0.033913387075787595, 0.0625340718655817, 0.013173842340737823, 0.0675893328603237, 0.07731935429957605, 0.10951367071679524, 0.026563610393373717, 0.02454333886083576, 0.008583888787055209, 0.0854328919142004, 0.061750720149927565, 0.1927908984643798, 0.047109305197673465, 0.09075605385606328, 0.05635024844518593, 0.06419727556227196, 0.1123212986896115, 0.023505337603930986, 0.012805108901023144, 0.023761542303667917, 0.07081363605515612, 0.1385779663800232, 0.03834809003878505, 0.03276063159348504, 0.055208735303172184, 0.0495514287913759, 0.03896700481193201, 0.0784160168240628, 0.04997027587265738, 0.06846904694553345, 0.035895765984370824, 0.13439973816275597, 0.043092062696814544, 0.034338730582666975, 0.0870210764509055, 0.06308742483416874, 0.08782359185598551, 0.04609186382543656, 0.05173190654585919, 0.04239788744598628, 0.041523045679974946, 0.06027512755545397, 0.04698966141609896, 0.03393456940689395, 0.03294979019330875, 0.05652813789164347, 0.03470114379700634, 0.06634132200551611, 0.05868663658357917, 0.0798411395460848, 0.0907215339341952, 0.04108783879107045, 0.05580395497682114, 0.039731912960809086, 0.042557521017208215, 0.09308511436346079, 0.04730082334830396, 0.03746644158156649, 0.01162941674626763, 0.0328085005974337, 0.06563215441400967, 0.057313600179529, 0.06124645426508881, 0.04260373910168006, 0.03819827005387314, 0.018574933619088223, 0.03168108538844653, 0.034367267357846426, 0.02121637413849033, 0.05291494548380856, 0.07213637112609803, 0.015567725377848313, 0.053933555140129985, 0.06611249154253353, 0.04202947193276017, 0.010360204408155575, 0.020821109158738006, 0.03244177813852026, 0.017383584542380228, 0.020428621247711203, 0.04872335669314189, 0.01928445552625964, 0.10324861899378801, 0.03159686742771057, 0.1109841918092101, 0.027344554677725803, 0.04438457942958321, 0.07964865229423009, 0.025116018312532577, 0.06603264985906501, 0.03667704543218978, 0.08013863446972064, 0.07364606995496058, 0.023491816152067437, 0.07324637890222573, 0.019781884076374195, 0.016957049768778588, 0.025151844414311553, 0.06216590150049137, 0.045453367844945004, 0.0788356721281044, 0.2559061859163546, 0.08750937323296264, 0.08595079033365173, 0.12985234749653649, 0.19783207876307352, 0.11677982315661446, 0.14667182319587277, 0.13158448761509312, 0.1529523498949505, 0.2474251022982982, 0.1791411881605464, 0.09154136292636396, 0.17252977276521345, 0.15170241615945293, 0.16363518552914744, 0.07263503307777067, 0.1347194266535582, 0.0828004912323048, 0.1528042191339116, 0.1705525611196795, 0.16570582925792665, 0.1298036702698277, 0.18279861448512924, 0.22332414473977782, 0.10131335066210839, 0.10390796788757849, 0.05668094561946008, 0.20534542479342033, 0.169742836827232, 0.09660575568916337, 0.13380097916289685, 0.12652869801968336, 0.15145222716514142, 0.1339632672287764, 0.246322809027568, 0.09924098323549956, 0.09003043835682255, 0.10245108316021581, 0.169620385333415, 0.17665210720752517, 0.09878700719245019, 0.1654023052223267, 0.1554978455627157, 0.1363436862706177, 0.09816844481974842, 0.22944206161604774, 0.2332768985821355, 0.12102008151311068, 0.10553752117219473, 0.1685028775565086, 0.15951539449874433, 0.18379049916421214, 0.09103543080028989, 0.10247998765759891, 0.09705950190583545, 0.15933020040392876, 0.08420310629111144, 0.16797344951379686, 0.13354213337504095, 0.10920609407607587, 0.12011011461577109, 0.19157646524329341, 0.1311206213769413, 0.05534619062898621, 0.2122288014018728, 0.1585642197319577, 0.1669331480778994, 0.1397428643559256, 0.31781001256838926, 0.28777158248328394, 0.20106037327599144, 0.2559534382195242, 0.2182128061089785, 0.09855128959902833, 0.11496570396928057, 0.07521887144614613, 0.14321866655542007, 0.1215418639983381, 0.17341081984341147, 0.17099180529194494, 0.18495221021434954, 0.24649556185449326, 0.14752328395843506, 0.16759900105816705, 0.18882300734760302, 0.34402970885557516, 0.3052172737736856, 0.15701301425935763, 0.1749671734268627, 0.12621869288024404, 0.2663913861878457, 0.289748702198267, 0.1260500233019552, 0.10699707188553388, 0.23206678609694206, 0.08427790711603819, 0.1573639591374705, 0.2029952815463466, 0.33909598004914104, 0.22122636617672062, 0.14224968790527315, 0.12027116161921333, 0.09690760199220912, 0.15022458658824045, 0.14209158267946015, 0.1589596589967128, 0.17591053409682167, 0.18890623513969684, 0.1617487553026407, 0.2250938538101412, 0.10809885187735481, 0.18122476345348745, 0.1397228541393434, 0.19226753783802833, 0.27857350185513496, 0.17680298056333296, 0.2973318694820327, 0.1919279463829533, 0.07556192561863892, 0.328328552986345, 0.12838106031619734, 0.19333915694827036, 0.17992460499367408, 0.12082560243265283, 0.20420862692258052, 0.1780164025483593, 0.2200304109963679, 0.11481498383105763, 0.09433243573913652, 0.10061823312313327, 0.17148698920444136, 0.23535028490568363, 0.1381310919720319, 0.07811862149185712, 0.17000915963322888, 0.12370626922817, 0.19127684825610733, 0.1765577404970123, 0.19015682771080927, 0.15395318248098896, 0.15209761027607227, 0.154623907780455, 0.16396299455194704, 0.10334032737920362, 0.21527822970622973, 0.12300355975786526, 0.09464640921402363, 0.24550291108748606, 0.14460675658718233, 0.15702510312680276, 0.14234393204171814, 0.13148077463190402, 0.21707433816646377, 0.15020149669820262, 0.15823029732752233, 0.1468582277096087, 0.10522432144611113, 0.21985889923187996, 0.11581133480273909, 0.2029405981903115, 0.07049412376457645, 0.15267928551521995, 0.2582579226263108, 0.10089822293769929, 0.1450146064763108, 0.12348057206479773, 0.12108747426780964, 0.1303980012814845, 0.10007735972683277, 0.20597743200919322, 0.12117915967058752, 0.10655679349457065, 0.14770182841006788, 0.09730369243169985, 0.1300903097275765, 0.13525141342993707], [0.014599288734907826, 0.027615399317695733, 0.007334817379277441, 0.04077042558140332, 0.04805531270141083, 0.026927122943884423, 0.10707372664323739, 0.011252808880301253, 0.03677523492144481, 0.05713630062077315, 0.09331498670602038, 0.06585003748055428, 0.0987387742967375, 0.06307742355631725, 0.04527091634489837, 0.06614272137202563, 0.027193798150326458, 0.008685196254162059, 0.0536919080261742, 0.0505861952420204, 0.03602205940912809, 0.033847955506174796, 0.028577734070319324, 0.05135926988817031, 0.05092503976136927, 0.016628106935851036, 0.014435704065216406, 0.012359569401239917, 0.07238860557516737, 0.02465682329549905, 0.01609033428042406, 0.05199577404005874, 0.025161324752374523, 0.03893057733113247, 0.014380115767820709, 0.02776884672892911, 0.09528392460197212, 0.009598170046604449, 0.13873101542553595, 0.014198800950731724, 0.03142236792031796, 0.032382015619547136, 0.04655276147288181, 0.02106402223298867, 0.03606564598158002, 0.039952385404537764, 0.03025616567972447, 0.03706572780145272, 0.024093078344219157, 0.07067713450880782, 0.06067948791408732, 0.04416387715947725, 0.03317193653915198, 0.04207797678968599, 0.04451266166964366, 0.0070461214542569175, 0.05725945308504086, 0.020671865654989116, 0.02096443080283221, 0.03560367581104079, 0.05067870035887726, 0.0573983256735148, 0.010078423863066541, 0.018295194698317398, 0.023309389549878337, 0.016432359979878512, 0.07222981087022251, 0.06794363320354493, 0.053661727992397164, 0.0789033253526976, 0.020979855983187596, 0.01884456592491798, 0.01299061326144804, 0.0182581830754756, 0.08180211778850326, 0.05419325894646106, 0.03544872686747582, 0.11002924022895676, 0.09761457857225211, 0.03173932913810976, 0.04412823874923972, 0.10018933879872484, 0.05223531824266238, 0.04179472344056253, 0.04649101095574518, 0.02503780456590316, 0.07328305153116103, 0.07694973219786921, 0.09262952953577043, 0.05387129900496333, 0.06473725646614067, 0.05400914503561874, 0.11489935309415865, 0.02297542118016751, 0.03758943699780972, 0.06297504356611641, 0.04547451953253439, 0.06974745616917649, 0.19940450487117614, 0.11869008637844555, 0.04412390652202791, 0.026878623832618038, 0.051608417002904805, 0.0354047495901825, 0.010353829599015657, 0.04640370374545456, 0.05211261010939076, 0.04983062570494029, 0.03792088876868929, 0.06545747870639448, 0.013222641183904583, 0.07593816672001155, 0.020972698806755005, 0.047841206448332924, 0.02079959357938459, 0.0250957629478146, 0.022768085229120428, 0.02511662543721257, 0.05154183630140559, 0.06924094947715921, 0.015903546722725998, 0.02118122410930453, 0.04564983109312673, 0.009678933908411813, 0.0345988710591149, 0.0168509753195629, 0.024777346162966667, 0.041327501737302354, 0.05354816694894145, 0.08048887454694317, 0.04780041992724423, 0.06271527081187214, 0.04511279196688726, 0.0328701208796232, 0.07110604415497473, 0.058703804613962296, 0.018437767491465615, 0.05474348627631703, 0.04605048741664618, 0.038381690655144, 0.026402492526798483, 0.0728937792741964, 0.07193603147301944, 0.03781772353836606, 0.01795525275801699, 0.05059210944079584, 0.010320797802940493, 0.029600078405271617, 0.0314639684098262, 0.04983384710466189, 0.09423539538176791, 0.0792952023086048, 0.02544931060965023, 0.05629961386383061, 0.031146082140865828, 0.024995799965014862, 0.05457429575823969, 0.04421209473343146, 0.07029448891238821, 0.057691549656972776, 0.044957153544190435, 0.04830239137874977, 0.024314556278348453, 0.03434444559858211, 0.033622108955657294, 0.04081126955908634, 0.05605703978348644, 0.040411432949645866, 0.013821771736406993, 0.07435556696427446, 0.035584741947992195, 0.060153802210885676, 0.10054041391178485, 0.030014757968245015, 0.021890253804984595, 0.0326697965483031, 0.011876992423147445, 0.04627184086148778, 0.05138573056507496, 0.00822214206920997, 0.010503553822937032, 0.01562304171403089, 0.03133433292649927, 0.05350340443152574, 0.03227769359645825, 0.07774730633583762, 0.07718413212006131, 0.024694126031752077, 0.017535647249690468, 0.06798973637482814, 0.019848991463321353, 0.023725756421504964, 0.014439756670335849, 0.04780483642412771, 0.0532424365801196, 0.05811045036440896, 0.03255785961124686, 0.042814378806900595, 0.06914721095874425, 0.033664205487096505, 0.06620420758882839, 0.06917576305568218, 0.06003546843966169, 0.00482426920620304, 0.023196638644402547, 0.011068240104753886, 0.0024026865843728546, 0.017902220321458676, 0.04162840958264086, 0.03686727655510749, 0.01650181542631359, 0.02337427145140546, 0.1292680062714123, 0.06000623452447115, 0.03270649215987614, 0.01839973122602509, 0.021993319443877668, 0.04077375806387394, 0.040379387491773215, 0.06806419246018895, 0.01004912578801234, 0.03425002526191454, 0.04787475726897678, 0.009436057223337553, 0.10639380828867998, 0.07516105479050068, 0.046166162862772905, 0.12032541596601087, 0.07641380006868033, 0.033247878835085905, 0.04955715912904951, 0.05492098118749358, 0.09338608732627285, 0.06869717260762569, 0.05698399468054695, 0.05740730805442699, 0.046969597573362054, 0.09295612047877043, 0.041385467780093034, 0.013383356854319574, 0.0707804338045178, 0.055044666082868655, 0.05338935692223811, 0.048828869982953035, 0.016657543864341515, 0.052669724569686, 0.04278162854813761, 0.058286175612480416, 0.07271361071616411, 0.01006373699994818, 0.06666418210032486, 0.04454933429857896, 0.06947171048171098, 0.04058388317184102, 0.02008940709093886, 0.04978500516904939, 0.020664534193553755, 0.00639659237124086, 0.05027889822339339, 0.06247994009285204, 0.06633947573361859, 0.022170659222249544, 0.05023931446034582, 0.06912807408239573, 0.2033920078388145, 0.0653205864552048, 0.049513875161327665, 0.04996803123503924, 0.06416300078853965, 0.058731422083632606, 0.02302551949997583, 0.04202957535462995, 0.053264936582455714, 0.06233640968979848, 0.06853822468509597, 0.0202493796560673, 0.07435578146889325, 0.03910859318209752, 0.032130261890650276, 0.05137065778516474, 0.056036830384043924, 0.029568517498011072, 0.057402684713803956, 0.06565028771517739, 0.032830177055251215, 0.04302247510021252, 0.03166699894673882, 0.05736350697735625, 0.015559952458246581, 0.00837936437869024, 0.01607610611245036, 0.04424305234645163, 0.04094807754060434, 0.010060042540933336, 0.02366240286538678, 0.05130885364187341, 0.0415123166185954, 0.059030181052343506, 0.07028948635824266, 0.04576815720347147, 0.05218525056637103, 0.009487057611676715, 0.004835193620003279, 0.052836026936288805, 0.07238595491094936, 0.11375975900239522, 0.08312834622037989, 0.045109080270894115, 0.04752301948986227, 0.015917114139865005, 0.07438314612954855, 0.036525781371540604, 0.08892800719026597, 0.042202098355177915, 0.03449778575750609, 0.046089178687261964, 0.03437583988171912, 0.041982169833875475, 0.035679721528844494, 0.010942363240305456, 0.043110134710948315, 0.028421971158334808, 0.039619006922528635, 0.03953898137795829, 0.10241185179761342, 0.043689814291053244, 0.02029466119805171, 0.0625513241656365, 0.038016557828673435, 0.025186749295361584, 0.11133705956801293, 0.03572835662071744, 0.013016879543541901, 0.03395992691718763, 0.08096364987713676, 0.03591196874396936, 0.03527109406047291, 0.014246573236079947, 0.031072842220084804, 0.024099758630918882, 0.01775023422294086, 0.1191739475114211, 0.080170986362763, 0.059874792988862724, 0.017717250307360967, 0.046011187106130585, 0.04487991655966447, 0.040201605297625065, 0.04404968792392362, 0.03917202143178832, 0.06120528470003798, 0.015407409030763854, 0.068881822780015, 0.16719438406007905, 0.11571578065594358, 0.15097550597162018, 0.14987817695063932, 0.17352358798586554, 0.20759907160555163, 0.1489157866566412, 0.12996228111367072, 0.09986137655834038, 0.18825437092492658, 0.14368147559223637, 0.16809996127361254, 0.16657267306600848, 0.08595228420510408, 0.1896889318501757, 0.09591000995809033, 0.13076665811240673, 0.20166052655587274, 0.19378627650439742, 0.1973768080314321, 0.11799789529534117, 0.17705015117122283, 0.16007531284084245, 0.09982917788288287, 0.2083465435932721, 0.3067772739356564, 0.1064799701975238, 0.21152223850930893, 0.10220763573963797, 0.12124639920770161, 0.18014822605877154, 0.13450473817365785, 0.1319045591498575, 0.12184764033243542, 0.11891746893525125, 0.24379539303481582, 0.21105621190321064, 0.14937568455934525, 0.17775649955916792, 0.15917345881462097, 0.1317185530018422, 0.0998324414174403, 0.16228415883116185, 0.06995784689582164, 0.20491684456506085, 0.17357756654101034, 0.06160610190202152, 0.10386837646365167, 0.17706371092748258, 0.12415839133844261, 0.18237795560590683, 0.24153373294299652, 0.19243904960251626, 0.1287199010051066, 0.18550681190625315, 0.3150976323071988, 0.1490055415178499, 0.08107669381124359, 0.12550694357243278, 0.15511193643173865, 0.18940266011463058, 0.13395287907652317, 0.18918196550540387, 0.20956188079810914, 0.2321345542347239, 0.2010193262850085, 0.16125936301485186, 0.1640936738300708, 0.12213758162913785, 0.18604079051123512, 0.08568599204262418, 0.22519686199243993, 0.07020839595145757, 0.1743377096229984, 0.14421389137785282, 0.1317844672068473, 0.20106933650470551, 0.23270335919674368, 0.22721285300870098, 0.11845478247250281, 0.26495215212625844, 0.14050671530346717, 0.17175337329747217, 0.20635508271234654, 0.10640278683915254, 0.2546752664831377, 0.20932920457374668, 0.23478796104750327, 0.217180042978256, 0.26386387826454255, 0.15847421972261322, 0.1702486693618759, 0.12588833278465655, 0.14749454033951606, 0.1863818528551248, 0.17782003889160772, 0.186932624107407, 0.29729108296094403, 0.1726374694056088, 0.17946018717221676, 0.13723115316562115, 0.15000917798569127, 0.11986911867655094, 0.17988194921805015, 0.13680007549062853, 0.23264122946608454, 0.22866820556021508, 0.21183589022726784, 0.19453325819584633, 0.2029529322058924, 0.1558674983079395, 0.13861372736432861, 0.07423166756428058, 0.09094199105616539, 0.15463939807828397, 0.13189921185614603, 0.11675517810809037, 0.13431133161629402, 0.26803372547991816, 0.09262864087377826, 0.14498203241777036, 0.13860560683233125, 0.11771012202746446, 0.1575544545607221, 0.10153052892776267, 0.11970446339898533, 0.08956541532590505, 0.1658013910656014, 0.21510964439761257, 0.18311844087175785, 0.14966952524358226, 0.20035863673735052, 0.10601805748357888, 0.15851791737781418, 0.13401030502732725, 0.14207198615035704, 0.1051121355304795, 0.17174251017070588, 0.16172276960024912, 0.10020341183389388, 0.19474373319216315, 0.15897418402375715, 0.15009801354139082, 0.1315654426692955, 0.2027293417843119, 0.09961628204872532, 0.13503624997552366, 0.13987645476816163, 0.13048872141347778, 0.17421233167331066, 0.13034742415672348, 0.09201226185166067, 0.09373566856788051, 0.18159953366604545, 0.17500754626047227, 0.14692535233353415, 0.10622469437939507, 0.27224074328137987, 0.2179151196633616, 0.14523231334263279, 0.11383099751847406, 0.08583882658351814, 0.09683108513033199, 0.22100116697049912, 0.15254161951522674, 0.10861224569981137, 0.10896089231415142, 0.15228729364612412, 0.13070927812687813, 0.14066206261275277, 0.12717600401130416, 0.2214969177880595, 0.14325157769264715, 0.10028614932971616, 0.09482426418652458], [0.02847024427366353, 0.08761412809572874, 0.03242509657396905, 0.07032232854755656, 0.090578535962249, 0.06761445288336085, 0.02532019798133162, 0.04181443105241464, 0.05738705652014864, 0.01189444869411208, 0.05187158352665363, 0.011180937384074975, 0.07330271700817732, 0.004584020202709062, 0.015373013598183471, 0.03998737647047928, 0.06366227039947145, 0.015958359356098357, 0.038827890905761914, 0.0360321564479701, 0.07660798803572694, 0.021760018857856913, 0.00795641441776928, 0.03695446502176985, 0.05185369537362168, 0.019536628688295043, 0.0522190886699865, 0.04608102751174762, 0.03361306911815078, 0.0523275284156684, 0.03842566410199769, 0.07036185868444943, 0.0038497031416608804, 0.018797434280596433, 0.055071789425827807, 0.04905806433769965, 0.02774264652191872, 0.019285039668301904, 0.03403272059175276, 0.027665526365801215, 0.05686902020487094, 0.0677819273644878, 0.04809196617814803, 0.02575440704071474, 0.04880079286052816, 0.03259337161697688, 0.09085198338594168, 0.06760958056416243, 0.018990934683731007, 0.0048553833884427385, 0.02207404595889872, 0.0339918498009924, 0.056603582230426615, 0.05950943799689413, 0.037926829780542085, 0.041965338882179036, 0.008617196374783113, 0.0411516156107668, 0.05297111888085643, 0.06760036452643334, 0.02834309474565089, 0.01870105658928233, 0.018955171784205783, 0.06102960541724198, 0.019661537409129164, 0.02020841118909659, 0.10424579734042769, 0.09379104906392675, 0.021832450555877823, 0.06514790257619274, 0.004624601795278009, 0.08922623755830912, 0.0285760831508425, 0.031587277922118386, 0.11258756786945368, 0.02145351665545135, 0.07498721411872296, 0.0397746185321481, 0.06723136295594516, 0.05133547136680253, 0.020869799791985465, 0.05171021859672281, 0.058749482606447516, 0.05644881714796347, 0.015613120875411458, 0.010178220221742747, 0.0667731274640368, 0.057208232446423465, 0.0418135998470168, 0.04043428535242716, 0.05492428685688684, 0.02717399669270362, 0.06074519910579247, 0.07015403435235062, 0.046089979249142835, 0.036576806657737305, 0.05993852767372324, 0.03992076895590271, 0.06899664403810617, 0.05610467896105782, 0.03551821487264768, 0.05797906245495524, 0.04571750730035767, 0.06136401428750927, 0.03718748215525862, 0.004415955355075459, 0.06270025165811663, 0.033057881368985104, 0.031604892198717406, 0.030397857471759764, 0.06719015508649812, 0.10678242937090898, 0.05695338563753232, 0.06374232658755875, 0.009016590568447306, 0.07425847298075115, 0.04427294509725706, 0.07346037790299424, 0.05744255959026276, 0.04186973877010807, 0.04558814952390329, 0.005849394919125424, 0.06061708239177543, 0.05257709304832163, 0.057347166321931355, 0.08847949335411673, 0.022139684372251073, 0.018313892989329273, 0.06953173347057835, 0.03027143189683557, 0.08194563670023795, 0.10461099145393218, 0.017857317992996787, 0.04477171047079948, 0.015369286580431848, 0.07476891736469923, 0.0700441926657673, 0.05078175067601185, 0.02812909574488238, 0.046761083762131395, 0.057400681393881964, 0.06831979003524588, 0.03023525147939161, 0.04184946808363161, 0.06525897766433417, 0.033728503246581366, 0.07353312561228391, 0.05343822567092796, 0.050701047143628525, 0.025954672000220707, 0.030513176687001705, 0.11432384486280142, 0.007866556613495754, 0.005380155052989722, 0.07836750047581811, 0.019333793503803112, 0.01896373664719924, 0.03066361911835209, 0.046911666004527966, 0.08792855356249117, 0.07847037842316974, 0.012770319890771663, 0.04343630430558997, 0.04265842628815482, 0.04782784587493347, 0.034664145580703215, 0.026269105127862385, 0.05048435534380617, 0.09228727209471888, 0.09016431222159056, 0.0200448858912193, 0.04020735478749679, 0.023730709179935437, 0.053903539815256675, 0.07358533450432363, 0.040774688860701944, 0.054959553714481094, 0.01967832431076996, 0.0498665820416664, 0.052569167868744944, 0.014060223306108628, 0.0655560052743362, 0.03110176203922639, 0.02495413435803306, 0.04510926796243556, 0.05890155872029643, 0.03524547608028497, 0.11930643475704616, 0.041191888852946223, 0.03888368508928726, 0.08010112680494785, 0.03989459939240929, 0.019171279441985874, 0.08111236286499808, 0.008108506332181634, 0.026961437937232758, 0.032086604455065344, 0.05127747085005526, 0.023447951872742945, 0.031420958318537286, 0.020456604524365356, 0.06774238190583645, 0.051830180304785894, 0.01376209635993526, 0.06722133486501633, 0.016743041191911025, 0.11766218024516299, 0.08732911274437943, 0.060120109663975824, 0.09658805905811249, 0.03752570231294921, 0.03708909348314328, 0.08226120363800757, 0.03969090810466198, 0.04870751016442815, 0.07206711677774306, 0.04155064399744715, 0.03728864789609948, 0.019204025870309244, 0.019136052804007646, 0.03713547244607922, 0.09967367735601242, 0.051756344750643744, 0.05276143295510162, 0.016484164760538166, 0.011168616775032735, 0.031887611201513684, 0.08938710836152877, 0.0388047473895694, 0.0571918802996797, 0.03716805416549887, 0.035906931715867216, 0.0649091819181077, 0.07560219886081834, 0.057444877006233706, 0.020955647604780334, 0.04274530831964747, 0.029113367425217748, 0.019130422057764187, 0.05098580202508358, 0.08275927570197852, 0.06752867401847917, 0.035415727630137436, 0.014498552003304565, 0.03461167621876925, 0.03601229561853313, 0.031885385716093645, 0.10667768216902211, 0.035216675004771644, 0.01863640834457211, 0.07905900207979065, 0.0206678360325074, 0.13536623468802822, 0.03948429802192315, 0.04760843446297992, 0.04742395666037356, 0.02960705363582219, 0.034477453783995686, 0.04904310647097807, 0.049885435465482936, 0.01886422948671445, 0.004489079405057935, 0.08504137501961763, 0.01419803965085697, 0.042591324646867094, 0.07711175979385454, 0.03891335184415502, 0.043074729957527695, 0.03856878464801177, 0.03345142839656722, 0.04521747405130056, 0.043337521098193624, 0.029934891386918967, 0.024578255233204654, 0.030192084340078217, 0.061798179296836744, 0.05485606289679005, 0.051734534227439476, 0.05377735364280882, 0.0838408922596324, 0.056462445852136424, 0.019465279089467182, 0.06619167439038716, 0.018557867095355066, 0.011056013341482368, 0.08150639252797251, 0.02143469962081121, 0.02979653016213448, 0.0728712639501018, 0.07242540843904981, 0.07382474464154051, 0.07189467038598753, 0.03169232772873535, 0.011542444699443878, 0.03808861222839163, 0.018258939587300824, 0.0495031422695085, 0.022592363811488596, 0.0012905229889457266, 0.002734246565171728, 0.1240784424026647, 0.09170948858222655, 0.06676975667716996, 0.0801055011669955, 0.016595571181706844, 0.011632021445210182, 0.05201356643210015, 0.04658522061823357, 0.011083096464825495, 0.016119137271157196, 0.15823771305862935, 0.024547274637546752, 0.03762512520376233, 0.05624960364413358, 0.046546406773549896, 0.017824054455324527, 0.014274787296721292, 0.05014806955812439, 0.05601143456935402, 0.06246597814043203, 0.026250067842944015, 0.05084596416582504, 0.0845598274721734, 0.014569938948918736, 0.08253869600594044, 0.025747954665172487, 0.04717621531698012, 0.04201669358618317, 0.030263288382200465, 0.03986086854110322, 0.038403520330546365, 0.009512343301227497, 0.017364238907072335, 0.052677075183319474, 0.016916669274289763, 0.011439465245442286, 0.02815451645742982, 0.03292343293827388, 0.02472780900256288, 0.05089573689826554, 0.002970735513372347, 0.015914394527733806, 0.03597213728954235, 0.02443664388040141, 0.03651972161605954, 0.03355946211564926, 0.06594671777659847, 0.04115117894064996, 0.007505518526980474, 0.12473033726095192, 0.1115982649066756, 0.02374710346151504, 0.1452093153831459, 0.13871687344245373, 0.08134352989614972, 0.14852543421570333, 0.13247877269262268, 0.2064906649531857, 0.09448504045365319, 0.18461563714569618, 0.19416693027221388, 0.16847588061805696, 0.11136211064313689, 0.07331526552837703, 0.2922296932628078, 0.16511606413029856, 0.13921599504688095, 0.0808164537433655, 0.1512665580958128, 0.12713137938971483, 0.11005748589072498, 0.07116731586715869, 0.15976699309483652, 0.11816915425081408, 0.11884749446424747, 0.17122016078041447, 0.07577741849085978, 0.140548421130065, 0.19071322204845567, 0.1444158934417271, 0.13053303193901816, 0.11913767324820643, 0.19741764051779626, 0.16622094677821284, 0.15324559303060656, 0.20602434723367616, 0.10058385109709156, 0.15216864194841156, 0.16424100785966844, 0.11579192979561707, 0.15336099651552018, 0.1435090598439978, 0.15359494444583693, 0.1200383858034207, 0.12239415213585862, 0.1519874927978362, 0.13986949868980916, 0.18556782314854284, 0.19741209404122448, 0.1654587505805877, 0.0576414781502418, 0.09345490500451097, 0.09556855690935928, 0.1826794418476282, 0.1441149894268282, 0.13251842540358344, 0.09733023737827617, 0.11401853584233793, 0.09162770103543036, 0.2034437494172204, 0.1766505750316766, 0.17664873642065834, 0.1802207899069594, 0.1253510446798417, 0.11604293084312832, 0.1854416025021384, 0.16254905671361955, 0.06958718291453778, 0.18251039688625645, 0.2044576821067641, 0.12308770685546822, 0.20713476103640374, 0.1531136420465285, 0.20153732429588997, 0.17771278658220846, 0.11809825281342191, 0.17354526827412267, 0.11732389113955921, 0.2593495979184105, 0.1536545920516214, 0.15235147649242034, 0.14200503006577492, 0.09715164696136791, 0.17645336867820832, 0.22480758207459606, 0.15482883630020006, 0.06761115870528644, 0.12228843966318716, 0.31393464955110706, 0.04714721122816686, 0.14277234373073425, 0.11645870208139382, 0.1812851924689547, 0.1550794236602322, 0.09518760436725232, 0.13051930364341507, 0.21458504270882378, 0.14061075004358448, 0.1976917467771038, 0.1662722899908981, 0.13106625977783434, 0.17454634600829694, 0.2621912018906686, 0.16345492504056425, 0.14719867718315896, 0.1719905541188294, 0.077211351224011, 0.10835422728691371, 0.1479740500930817, 0.15703247289263433, 0.09473141433010179, 0.21800960894794236, 0.16557346458636946, 0.1745769588817512, 0.19686743617057803, 0.29683838628472825, 0.13763337996938538, 0.1991948112845421, 0.113635154801511, 0.20180445915508657, 0.21006469494633137, 0.23267584131850352, 0.08583328010694635, 0.08399120637125547, 0.23437988133199755, 0.12048315346962023, 0.3272168981211801, 0.27897995746424126, 0.1806409125246348, 0.1732101814160424, 0.10748277929040695, 0.1837591202028336, 0.2210240729994351, 0.1772057436286442, 0.1202147086000731, 0.11331215681087588, 0.28868638339542574, 0.1714066725464598, 0.13857644952593312, 0.1324509637009713, 0.07559701244557097, 0.11267457247501421, 0.11877860017721692, 0.11033700073077796, 0.12088634554416904, 0.1802642270922661, 0.16336046639950047, 0.12119780625066451, 0.18000130571665304, 0.12157263775025645, 0.1375859591268724, 0.1446351171621392, 0.12431884845418316, 0.2309005551280514, 0.13815456490603187, 0.08138771784762222, 0.11342127071393114, 0.12693036557926288, 0.06712744312901651, 0.18556083642667343, 0.13407834895676182, 0.17758874162550897, 0.14646991306254942, 0.09111176380106518, 0.06651428167618091, 0.1369037118650252, 0.10978058341049379, 0.14460672594366536, 0.09633366424109667, 0.17346084538486697, 0.18254539178263757, 0.1942340089308639, 0.13108299113810062, 0.13293983504897164, 0.07422961444864351, 0.2300624242953716, 0.1581185250993698, 0.19238442753351506], [0.027421339670376434, 0.08077005179779184, 0.055329386490367116, 0.009564035083918322, 0.0658127596421588, 0.03044652129192987, 0.03352894117274592, 0.028689619296440677, 0.03611723817284069, 0.03647139678979593, 0.030247506970960288, 0.028167051571090857, 0.0950509342815607, 0.12919829227030277, 0.05442816448668319, 0.0602359191754893, 0.04745528199559739, 0.035781124756941875, 0.00930501309583985, 0.018990907870653658, 0.05337521110871627, 0.057645913799323385, 0.026551199769000375, 0.09772878696000385, 0.018735618645986243, 0.0753272345830356, 0.030940837609852036, 0.050055457188958125, 0.067120012076151, 0.048118622207473365, 0.023051859518032403, 0.033703953959047794, 0.01590396807108435, 0.06686575515496154, 0.07126036490644179, 0.036222272657699166, 0.026517851961656447, 0.030084902893811948, 0.06123066519296939, 0.041232840082938635, 0.047731686518677784, 0.05321213014183506, 0.03563895799039352, 0.008296110731128964, 0.03195227859842201, 0.1571199294900702, 0.024585111720126965, 0.03099618554716149, 0.03621670702892927, 0.034607363143755544, 0.029596922123023582, 0.022529186455592997, 0.017566556982215376, 0.03993204960058774, 0.009660234659790032, 0.015917563258910614, 0.047775771048280506, 0.05026909612840222, 0.022637804316717292, 0.07185438948292887, 0.04767680397978233, 0.012077731399556563, 0.05942873063407118, 0.05867067514167679, 0.048205814504575346, 0.033962274976675554, 0.09879171863318452, 0.029989103598880674, 0.05227320129051805, 0.026248665902042584, 0.10419766403614514, 0.08268343299747476, 0.03791128202611881, 0.039987839953673464, 0.04979727406715674, 0.08469761604623449, 0.04539555501973918, 0.05220479346931942, 0.024501657932095473, 0.037663180621400956, 0.06896641420861406, 0.027095832741789283, 0.03821339262949844, 0.04175283375286287, 0.055203736579466256, 0.020849745525347612, 0.03050543919896647, 0.044565173166413466, 0.01622534961619925, 0.028373265203328866, 0.08635911519729322, 0.04739970614713046, 0.04156177908542656, 0.04066596183204844, 0.05331588525985999, 0.0920293226297344, 0.04747126258969788, 0.09288689677393244, 0.022877402145475633, 0.05706096736473903, 0.0501968233936256, 0.009834321437313432, 0.01820801197731447, 0.17018684606638648, 0.030014489837471518, 0.01872012643293748, 0.08153474544205012, 0.09588299003700096, 0.01281069751243077, 0.004108105316728113, 0.04678850970982064, 0.02498360384526032, 0.05733328480874339, 0.05135249767091967, 0.06847187380997405, 0.0424732934803732, 0.04864164575513813, 0.05823221620953372, 0.0693561154748163, 0.02286426182235441, 0.04551874195796348, 0.06669958302330586, 0.04091210205168013, 0.01571950463262657, 0.010847602952121487, 0.028979888095730738, 0.09025591335469678, 0.0429595792816291, 0.08786319860167081, 0.012638497226420912, 0.021269496590379747, 0.05272835710897081, 0.04792375242217414, 0.010783922851025578, 0.02846993975371363, 0.044124737727425756, 0.022899021146698825, 0.016213988532282172, 0.041654563824375795, 0.005860637259414239, 0.026870275389463193, 0.06244142502245884, 0.05430618413693963, 0.017430007555371812, 0.07276312297871036, 0.0398107165951402, 0.03615383802342319, 0.016278431848472646, 0.017186655895784497, 0.0188214281543849, 0.04441527657270913, 0.041455277542193095, 0.07439062314768953, 0.05023959025199856, 0.010053031878816265, 0.02073865128500808, 0.01094338405246456, 0.02171127651367457, 0.02878779537915703, 0.04081878488162353, 0.03446867441638343, 0.030862727285092397, 0.029038790681008852, 0.061068384787969054, 0.028224732246129747, 0.04802735049217459, 0.042462158392393784, 0.00660389815757592, 0.05673793106970768, 0.015147445712148424, 0.036426714711612275, 0.044291484425024646, 0.045937623513201555, 0.03176805360483066, 0.02496601829695846, 0.06757269343060833, 0.04149109598309283, 0.06694239459090656, 0.05840973793378761, 0.013276259677724974, 0.025499508520888708, 0.020703644897308082, 0.0321173973591818, 0.03656657555350854, 0.02952442722274892, 0.01685544735782089, 0.09696598555291853, 0.01557644441603653, 0.055668751949504505, 0.052562606325673486, 0.016835850828717795, 0.04882051579413876, 0.039080087050435044, 0.029638409614562992, 0.03870039855340316, 0.022335011895085057, 0.03495529346588639, 0.050943831898151874, 0.04253035936985285, 0.027558727963497082, 0.03176377691899336, 0.020068249657690045, 0.030051675745316093, 0.054029645548472484, 0.01032075279527494, 0.03753063591918157, 0.07824325633625831, 0.01681660670005987, 0.043926792099110545, 0.06927930749952793, 0.017277351129920255, 0.048696099284795985, 0.02351645928537173, 0.08105980923339244, 0.041653066122483824, 0.05821227877130432, 0.0546589523043123, 0.033141603287790096, 0.04951143517128883, 0.026129508586299997, 0.055661274931363525, 0.09519803848478103, 0.06899810726604155, 0.025149927279281042, 0.1037238463158569, 0.01291003613357222, 0.039210804632955024, 0.08107414273845573, 0.021149961976334456, 0.011807528358223218, 0.015846591915995363, 0.03706456717824744, 0.015888755480127952, 0.05262213135739008, 0.021704538770380522, 0.01709969534027961, 0.03727743236888801, 0.040638669949745944, 0.019534972023158785, 0.028907787730737083, 0.029203189319119822, 0.049032327613883445, 0.009159537787068515, 0.025181808028249972, 0.01877625003427027, 0.04193484092191343, 0.019183414274706476, 0.04392929337618332, 0.05310876955909114, 0.05085488909014291, 0.06638206256132934, 0.013531933861574339, 0.0064334349759343655, 0.021958519899917227, 0.03199316854138048, 0.07458458894923811, 0.034509958894622904, 0.09462916457484807, 0.03098526113336125, 0.045574095640932365, 0.06599924842556638, 0.061620370289611245, 0.10039672646070681, 0.020212873651255524, 0.045950539755604924, 0.05001657822680089, 0.00842966475418859, 0.01241738701449527, 0.03489553094691327, 0.04217579089585812, 0.06168569460691464, 0.11007154360413553, 0.058442507344748706, 0.06137911388049684, 0.05974170053377748, 0.05477588030419523, 0.05214378988790897, 0.04544477233843458, 0.06727643956940982, 0.07558629487551029, 0.04692241421810562, 0.047502982460202715, 0.06720861780547327, 0.07588799562185042, 0.006243297698787384, 0.012961223255842926, 0.055730150066195965, 0.02415552408614707, 0.060592027486211834, 0.04384061486850824, 0.03509945589147749, 0.022450344516865672, 0.01950477666762327, 0.020807528335060325, 0.05556173329692214, 0.024477742582319245, 0.023008730683115222, 0.0960496754475659, 0.08587258041746194, 0.05955046583567897, 0.051469801053885496, 0.023850446807280667, 0.0074841331825741845, 0.047898850734195406, 0.089670354049773, 0.01929994582408859, 0.059230229592010866, 0.047198002857546655, 0.054960066993390365, 0.018605983162659313, 0.03022558153456738, 0.018954539761668252, 0.06424424058246998, 0.11873223653603947, 0.046308567116577784, 0.014931734504869149, 0.039974996489622903, 0.014227569467508265, 0.01936473387984499, 0.008517400973716812, 0.0016742685200428712, 0.03680274896924535, 0.047645068787519014, 0.03755502815869066, 0.06413599235876914, 0.03344012476924447, 0.031612794395656355, 0.05673868183587348, 0.03977037823548721, 0.04923548264008376, 0.03309381089263386, 0.07107234394718563, 0.024698843218145833, 0.0179026186871793, 0.020741650519231637, 0.04977378198095868, 0.028443950220882416, 0.07184970868571151, 0.015431665289666385, 0.10370882333166177, 0.08343580028703136, 0.08516119883185433, 0.0223316372777786, 0.05309471950655984, 0.055046512354766174, 0.03061420453201619, 0.05385908373301068, 0.026118574596400705, 0.020360416439812512, 0.03881498232423779, 0.037659059068368334, 0.01187796152437166, 0.14937142511048626, 0.2733325411475474, 0.23010719447366654, 0.1186199357072192, 0.11232656171365131, 0.08387342801377659, 0.12484836076656658, 0.18873015749118022, 0.11024262635938584, 0.14061621991136383, 0.2175695220789602, 0.10972580812390774, 0.15913196749264197, 0.16429434290095685, 0.17570813366722676, 0.23481195492129173, 0.16989642213429176, 0.08696146714951723, 0.15424901499382912, 0.09392133763720913, 0.3263469286743672, 0.16730761185528772, 0.14197464701869797, 0.15440722747195154, 0.1156590671669091, 0.13709308879990734, 0.10441804454932291, 0.13234876757187228, 0.2380284823236927, 0.14794886112213135, 0.1365010254085064, 0.1618881373395843, 0.1280407180949565, 0.23235754710772347, 0.07723242630280795, 0.17217363381097395, 0.08552486076951028, 0.12439318962635533, 0.12990496241517607, 0.18756098474466032, 0.2947078038367533, 0.12644510250538588, 0.22823772543380338, 0.13086415046165067, 0.1531359811704005, 0.32661518202193324, 0.18194119355851607, 0.12994717385980392, 0.10665649983791575, 0.09280652648979619, 0.1040092523720476, 0.20717691119399764, 0.11541433271861846, 0.1269128145049176, 0.09747813831293776, 0.10447111145983781, 0.17317307211699026, 0.20904740679167935, 0.16356599246782644, 0.10976628820982673, 0.10862585908222584, 0.11157574192170175, 0.19156330385275427, 0.12548317186414235, 0.16201863275660625, 0.10482731936199051, 0.17123261737006326, 0.15320741120846043, 0.07767816690067131, 0.10258412198914636, 0.15148519958940246, 0.160670425262182, 0.23730051493452442, 0.17254605979448365, 0.17354117736460703, 0.19884593484382476, 0.14237456023693085, 0.09241956015748364, 0.15783939330327898, 0.17296288823408468, 0.15020405543186974, 0.2137752111640669, 0.20199167572202223, 0.12947963039961555, 0.21049306067007206, 0.18778213900664162, 0.1541496074247745, 0.12407100368891993, 0.15599966379663638, 0.14299372781909284, 0.12407932340377763, 0.20263981674948048, 0.10611405596137048, 0.15350506701056035, 0.1450044481504348, 0.3635089958627378, 0.1617271669449345, 0.19556560763908973, 0.2676937050156055, 0.17791530958587126, 0.27241556454570065, 0.10428823095055358, 0.12261538300663234, 0.2804603151256039, 0.13307682689159148, 0.22431794463867144, 0.1439821344589995, 0.2779701922930056, 0.15680129820060346, 0.15682293252358515, 0.14083023423389082, 0.07976246997714043, 0.12598150439800757, 0.22940646917108568, 0.12060739760918003, 0.10532436486814292, 0.13420590259615453, 0.10238944372582821, 0.22730941073067729, 0.19777053125923683, 0.14995777348597206, 0.17130513525297567, 0.1713023466929313, 0.2433971039229824, 0.11534361514232813, 0.10642952330770994, 0.1941041110624229, 0.16192323948827483, 0.22627652502588688, 0.10090842722885071, 0.17162483906553638, 0.11677184052044347, 0.151143922740894, 0.05562696951411425, 0.1483870634148198, 0.17077028330776, 0.1950387230082866, 0.24931010760126576, 0.10996237607492555, 0.0831047430514328, 0.1045496584547143, 0.2335742785925827, 0.10407968649580594, 0.11993068916302536, 0.22696244950977065, 0.1505949594561131, 0.09138085984534795, 0.15805146176247828, 0.1864040847266874, 0.12447422640698573, 0.10689482979115941, 0.11819523188375658, 0.1540280905582251, 0.13401710788809484, 0.17985450794860242, 0.13977404413444383, 0.09473038011140401, 0.09755176702334035, 0.10263480636621676, 0.16317925596189115, 0.10180229095802193, 0.1154081120846733, 0.1418269146233797, 0.29236749715862737, 0.15371990870804558, 0.17083356217030557, 0.0979323441823644, 0.10282485745847227, 0.17557625929194112, 0.15735424514259064, 0.10834600716348618, 0.1854609538831057, 0.09769791361665535, 0.14648820724218123, 0.19247591375343262, 0.18272577484528865], [0.0697952447338931, 0.06526942710362135, 0.03792109178198922, 0.08515353795261153, 0.04593788781353543, 0.029454709391199776, 0.02688446525304068, 0.04120438374699124, 0.03230378655115924, 0.039147487466013244, 0.013386041992494177, 0.043075848445897146, 0.05509137063317242, 0.047151918838461565, 0.04841506376021332, 0.044043019128542756, 0.04589088065850158, 0.02244865146255301, 0.04815380096495633, 0.0700856456833501, 0.025390953862018166, 0.0918839957504984, 0.058699771161040956, 0.024384578629847498, 0.03588158186645277, 0.01612673877858587, 0.05097203542508426, 0.07557214523154883, 0.03062749807272227, 0.04031178406289509, 0.039418858791431116, 0.014965066032844686, 0.03741416374161359, 0.025029264600767244, 0.012174959448466619, 0.03630642358574175, 0.16889514521725718, 0.056203347255265525, 0.03052731675486411, 0.050803557368776495, 0.04673619356547152, 0.04560794140542707, 0.020040078689494444, 0.02407011485868885, 0.04218175872078827, 0.03749591681445318, 0.04101850017304382, 0.03499729423633507, 0.015995970442740908, 0.03780297251538404, 0.023142549006508726, 0.007071057137387295, 0.029925118020224958, 0.01822702244915549, 0.05534752745241408, 0.030530712439588485, 0.1011345917058568, 0.004945095636010651, 0.05350164625973952, 0.11241178899522751, 0.03978752711367223, 0.039418456595270865, 0.032138771212269227, 0.0385106232528004, 0.03445094714181558, 0.045670515467082305, 0.06129256126681163, 0.0626878103902263, 0.035743912036019954, 0.03223701815811857, 0.04402891161941713, 0.019530051823465094, 0.020968810910539284, 0.060801460602951635, 0.15122961733610402, 0.010876234530681565, 0.03372476090707126, 0.06441940658635671, 0.017102838215988972, 0.10423088926942119, 0.011389717410859323, 0.023982302030368198, 0.022120852015852448, 0.023598961209157304, 0.10678222252716942, 0.012425125460140409, 0.05360028007999063, 0.042796295301447955, 0.1013169819188695, 0.02938812868970056, 0.04240483969389912, 0.028625781189710386, 0.03307240256558984, 0.05644745351145825, 0.052094779412953124, 0.07148677453158364, 0.04522013620683744, 0.017266325209470048, 0.02907358639452967, 0.05192791014128635, 0.055358961314683965, 0.023114998569531787, 0.0668075094900785, 0.06524866612087335, 0.07146302580593095, 0.01314745252696617, 0.04637674894183875, 0.022658214814239935, 0.028335353427176035, 0.021157333657385844, 0.019674595377798525, 0.05794536607760576, 0.0533279319924693, 0.05172062973161379, 0.03271721356037644, 0.018630576500248526, 0.02593956666157371, 0.025430118191927194, 0.01756056234420788, 0.025162943113114566, 0.027056790985948136, 0.029243219328383287, 0.01718105962349763, 0.01863263727676484, 0.024648392497892344, 0.05176458402626938, 0.026076177375451214, 0.03599275271558473, 0.06373007684164951, 0.07486225751739356, 0.03664635978038273, 0.02837215246061885, 0.030400540694714557, 0.022847427040218346, 0.11090658710248048, 0.08500559105267448, 0.026315916930475546, 0.051512663673248985, 0.04988765329002373, 0.004121671776257215, 0.01382621313114801, 0.007941403882502909, 0.06723684048460377, 0.042169168065752716, 0.021063001420829567, 0.028109910988038587, 0.06340829310037437, 0.049987957181949774, 0.0262037463366024, 0.05860571854657704, 0.013300185561210159, 0.035194370354856216, 0.07155791345623232, 0.09752021952261848, 0.02483258876318653, 0.018793638314931624, 0.015507075154492933, 0.030444535208986174, 0.01151834453095592, 0.07372318436541865, 0.024074701810135476, 0.022678077558896715, 0.06126536131506005, 0.03915407199172243, 0.11114534606496174, 0.02857963205315173, 0.06450712365368683, 0.04711531132699982, 0.061971571807178764, 0.042286318231133685, 0.034186179494305004, 0.04823685638726719, 0.03227433430091028, 0.0057389604720106775, 0.023982351826083277, 0.034942484475792415, 0.09354540297100622, 0.012949071186144027, 0.014164061736195319, 0.08210710505203855, 0.04367628517831045, 0.00028384883285804296, 0.026945373073460597, 0.05177804036065937, 0.030716232121771866, 0.03119473446971707, 0.02746404524171545, 0.0860458388624172, 0.07753654022610958, 0.028530347701762954, 0.013537053244128345, 0.04211824237098617, 0.05702698370441795, 0.021853734393634146, 0.06108754081651569, 0.035543760074482816, 0.021214121839992946, 0.06966345462827914, 0.011275940905174902, 0.04167755029254383, 0.05828554358994288, 0.0233806318963968, 0.06100993227934646, 0.0493170288691838, 0.019474219335543535, 0.10923283820551251, 0.019429353396258047, 0.025143597477806673, 0.04663058068423022, 0.04864511613343512, 0.021088343609364766, 0.05138428648933769, 0.09560451707652501, 0.03184664081932316, 0.019987592090582176, 0.05146363021565541, 0.04135430332333331, 0.02606939366688171, 0.035615075199354085, 0.020976931442536657, 0.034309661376380154, 0.027402631803265503, 0.08317731456049988, 0.02113180760774882, 0.008866953487027316, 0.04390282120795981, 0.07293742330324265, 0.09655674138376791, 0.02072193524650028, 0.04595538143128638, 0.03966205723343357, 0.09033297413900014, 0.04741078760895518, 0.03853685027288814, 0.029977443740673126, 0.08104172955837943, 0.0032569596078246836, 0.025952802745685465, 0.038692469543386857, 0.09095479238538012, 0.03727597680183188, 0.04136613172088419, 0.004063177611603732, 0.024248025372564316, 0.05532748276187528, 0.017544491734776287, 0.010930506114457405, 0.042394742655057105, 0.01630882255642885, 0.02509098064394728, 0.07668285780856687, 0.03461196733218047, 0.09039553287889689, 0.024264220471283602, 0.03579599835399178, 0.06038698788371779, 0.034926695403673, 0.06696460347983145, 0.05825102749851443, 0.03610942790645265, 0.03903853444142207, 0.03923764069294257, 0.01119432189772206, 0.02556572150018427, 0.14110864590733282, 0.1229826455575324, 0.029972121344819188, 0.005712763616634954, 0.0791831466279203, 0.060013822625361146, 0.10630260552129439, 0.040021126473983454, 0.05521751850122406, 0.03551660608800669, 0.05252930065316539, 0.07935464307064972, 0.023283626012984785, 0.034573295213762796, 0.1196346038411702, 0.016994791090368264, 0.04185788355947983, 0.024229625855842908, 0.04654414298373365, 0.08907995306916776, 0.024208506726990306, 0.043460953184553695, 0.04591901906796041, 0.098138804877958, 0.04874581839108179, 0.028936560077953245, 0.05419662207244866, 0.029857937854924993, 0.03382721750606452, 0.022662702174256408, 0.02576699386531067, 0.025327592645020738, 0.02182604606083084, 0.039859516395916866, 0.004703866518778546, 0.04478937645833339, 0.0071829279993600665, 0.0642677977861416, 0.0315684704635773, 0.02056865637461024, 0.05303588778441472, 0.046969459677535685, 0.0578647812888507, 0.0335596842811473, 0.04962248344635291, 0.06128184752719057, 0.029329429117722378, 0.019318058057838393, 0.08052383879980735, 0.0293891916366955, 0.1012700590335073, 0.024768938347997687, 0.03358563934002192, 0.02798987267118308, 0.07070474431759889, 0.04424071194784296, 0.021803419653987213, 0.03892121190625814, 0.05519121104190427, 0.03086420583478626, 0.0722557965726141, 0.06254874244933167, 0.02776881225497252, 0.03186050892597245, 0.037346878239224036, 0.0879339621432366, 0.03220889890085786, 0.07864379008570987, 0.023069150122483412, 0.002881961484109202, 0.046750132535253806, 0.0504082789824855, 0.08604335673754254, 0.04044776849989449, 0.047740971504320065, 0.0321413988938495, 0.09693250751062747, 0.06912755314260721, 0.06838713682466938, 0.03241959989311234, 0.04992791121044467, 0.021372198337508787, 0.06697882973258534, 0.05006671485100543, 0.02297299651188716, 0.06007278841289301, 0.02214109780447137, 0.04090585460465762, 0.21785354151600794, 0.13624260862988813, 0.08344341520099871, 0.1950655514073949, 0.1051075696464508, 0.1276612057981472, 0.2508960475003527, 0.12540829443042317, 0.20524325930783827, 0.09660563311509549, 0.09107915909900781, 0.21608528801270072, 0.16588183029765086, 0.12927928308565773, 0.20765422993609983, 0.10578374949193771, 0.14479938173486342, 0.09423706545344285, 0.19904859574331393, 0.1652488884546103, 0.23556426858469365, 0.18917094916105273, 0.18460167902371577, 0.17052855192413255, 0.07515304917169195, 0.08066250071410211, 0.17732430339580585, 0.1736068923867518, 0.12008114883135404, 0.18245957461335968, 0.10795417617285445, 0.11598049467729947, 0.09099496603612939, 0.07583049306225392, 0.08387033301856249, 0.12821791423184256, 0.2697475254535675, 0.16621463421371677, 0.10163054936715674, 0.08844549437203715, 0.21882552323081803, 0.12387445617106654, 0.09986151445416674, 0.09904962979377278, 0.13797890094499435, 0.07992089695988164, 0.19347617943440715, 0.17081994112701188, 0.10828266701390667, 0.19188729775769098, 0.11409922022252314, 0.17100202490485486, 0.16931241798785426, 0.20026840690162875, 0.1128759693294283, 0.26526453213826306, 0.21341184033982216, 0.1181417206422456, 0.1742104624187754, 0.2532059558096432, 0.09352940705514724, 0.10500077698980609, 0.10160405804673511, 0.1473292492089733, 0.07138499208996374, 0.1620187553306741, 0.22810326168133369, 0.13402294547807786, 0.09906426973400578, 0.0937191287295953, 0.0835994596502954, 0.11429723862919117, 0.10544961258288353, 0.17278788310866203, 0.24180486678115784, 0.09897607003128338, 0.12386448936717165, 0.11779033909401587, 0.09350544382487574, 0.18446565245188054, 0.11302438354299915, 0.3543349091083773, 0.18496826741724245, 0.16567006827362124, 0.23598408476719934, 0.1240418233998841, 0.17935632097144283, 0.14631779864430428, 0.20482272300268375, 0.20425505185079193, 0.1528696123991282, 0.15736143104732037, 0.18463891089683582, 0.17450384345025788, 0.3247978682479551, 0.129885335242556, 0.08832658220443033, 0.09885586317508452, 0.2299186908790181, 0.25596203372603465, 0.15791615531329187, 0.21748630960862483, 0.20552130325907664, 0.1125653436587703, 0.2084254659712315, 0.14923408086742126, 0.17542946152389052, 0.18703610726421882, 0.10586581283038664, 0.20330617534777812, 0.1247373469654591, 0.1680947825192444, 0.13999052526008698, 0.19219782383691883, 0.15334172174334526, 0.1880225527190393, 0.1121029329876746, 0.1532637646361705, 0.11256568839833622, 0.14656398865965106, 0.0739103779497166, 0.1461984268239429, 0.08931204706670777, 0.13704229717052754, 0.09021321161379738, 0.15998716676427474, 0.15091071025498454, 0.10168069748268013, 0.26237990466817734, 0.20067110867990604, 0.24004785944857907, 0.21087475631746555, 0.13690757294816358, 0.10314099130130584, 0.14324112825335997, 0.23810499918556985, 0.19135978493478992, 0.09791627165771301, 0.1799899522936152, 0.09441020898520948, 0.09927954044072859, 0.049307180808917175, 0.22076233139922544, 0.11617765506549228, 0.07010276008757853, 0.14563719081061502, 0.2605974325729955, 0.13024685213402395, 0.12540548288774106, 0.18164880844133516, 0.19179971858618722, 0.19498710400394856, 0.1278070153127755, 0.22151631513430228, 0.11130103045293402, 0.10012798281686922, 0.08689717705091161, 0.1840397075659806, 0.16261388307377217, 0.10036222952147646, 0.13258887484910029, 0.23433056059143237, 0.1235112768688029, 0.13891662320783063, 0.28225859927554287, 0.15051858049006234, 0.18735015734789834, 0.13028995224064396, 0.21109289219302518, 0.08867600256757391, 0.13371929886841005, 0.12279091673272273, 0.14005590320354508, 0.14479242565651096, 0.12224905508299991, 0.11662146512178645], [0.0026023427433814975, 0.03286065586331872, 0.010603653743953235, 0.06968597761325299, 0.05549434820310243, 0.08767696262727823, 0.019259760682020458, 0.06315561815074856, 0.040040228876375386, 0.006101875952745398, 0.04976724725096457, 0.05343702674332646, 0.03568588087575571, 0.011357511074522571, 0.036057789749916525, 0.05633451682966083, 0.040859674824582, 0.03332785841438078, 0.05609556251475888, 0.011917967593387492, 0.010823206882172776, 0.049922954621574575, 0.05169531435615594, 0.033401464142145655, 0.09124572193550487, 0.04262976310846787, 0.09313737688165519, 0.05341269579085131, 0.046742927478325945, 0.09428041836907787, 0.02246135128511777, 0.03150113516547267, 0.05319641767850807, 0.024570787791162733, 0.03416444557989317, 0.013794431973609233, 0.04347792203207651, 0.045699454438422, 0.03633912404878967, 0.10573154826077724, 0.028478757425722097, 0.03304396538184055, 0.030725135978671814, 0.032745888231382254, 0.013569179141233045, 0.040336306537351305, 0.1253564992258626, 0.03354180761943421, 0.04217800488995929, 0.024481590258918946, 0.04529481445769629, 0.026248692715119933, 0.021456481415718313, 0.04381070679594432, 0.08135617800777958, 0.0688381327856933, 0.035070321567717104, 0.012919821949194998, 0.017028108254195224, 0.03740523115641648, 0.014252595644774697, 0.02130052889697254, 0.08097923210551662, 0.055779566567751675, 0.005595895946176062, 0.08923465686459696, 0.03154274140064034, 0.04865521700271676, 0.04235462263046254, 0.04247481033446328, 0.02346767672157336, 0.06965131979555854, 0.04903858655222482, 0.02098229980366605, 0.05840749329616947, 0.03125885411375954, 0.026026546369276704, 0.06592610235055608, 0.08228473785904147, 0.04830436788559441, 0.04813711940040512, 0.03600177340089314, 0.037544360384345055, 0.0033838347805994415, 0.0322783294494354, 0.07663469386076735, 0.020901952502167514, 0.019820102287696737, 0.08918786421418191, 0.06528258083328124, 0.11247787940045519, 0.06084199048458569, 0.10996509568705676, 0.025330114989511432, 0.0719590217716271, 0.08951479989674785, 0.03672920452851442, 0.05468814791510663, 0.06705183791176927, 0.012631698196092922, 0.017953021526937524, 0.013929944308925302, 0.01909017179822249, 0.09350431767562706, 0.022088534596766678, 0.07792669348418713, 0.08320703111108273, 0.0553042741282092, 0.05842627394163321, 0.028927066333351598, 0.01982297894785241, 0.10263374916488126, 0.010288977383395598, 0.07108087816666211, 0.045424248842943105, 0.020741514538625078, 0.0553505381779565, 0.015794204908513253, 0.030974710187424096, 0.049732340454694726, 0.06784278538919265, 0.015209363811018487, 0.013977954081530053, 0.03344397436106398, 0.040867871965371796, 0.10469778155487393, 0.026408226694911722, 0.03744963361250778, 0.024671773501341383, 0.032802977103499636, 0.018797464924113407, 0.03699483785537943, 0.05309605249954809, 0.02005558430908188, 0.015640884859397287, 0.0550448882483667, 0.03151909609685742, 0.020037634869015986, 0.06208230215575426, 0.04382110260907681, 0.031946473567175775, 0.023665536164997086, 0.0240679046950273, 0.014797221914294266, 0.03905931074592856, 0.004870729565980935, 0.03770626157582287, 0.012360195678118016, 0.06366321651805794, 0.007215278934792526, 0.017783260273356593, 0.023765535536973227, 0.026558083069000035, 0.020309751214940223, 0.05962730828492392, 0.034953481667945464, 0.04247210604409057, 0.03643113503893537, 0.034251002024018, 0.04623928595514548, 0.012250479438432283, 0.12294027323444044, 0.026194949732011846, 0.04327839826263728, 0.026405675622123866, 0.061025610268716855, 0.009006496402435005, 0.02904615853162062, 0.018106700679768, 0.04756309354918138, 0.03636449688084183, 0.04053856524068021, 0.017709108707945675, 0.03024341223100501, 0.00980814612816058, 0.06321115569481928, 0.029330628045323878, 0.013241216900848575, 0.01953492988832295, 0.0586105793744566, 0.03146414844048841, 0.12651464030627282, 0.02524213170662763, 0.0875173865126506, 0.041947014059030244, 0.01845700587446411, 0.024952805195484432, 0.04007820385478197, 0.0585312050046219, 0.043904698123374296, 0.1085851185264126, 0.10371243926666437, 0.012087295049681299, 0.03193918615579605, 0.010068096040237335, 0.04176958043488764, 0.03868152980782813, 0.04224543211861484, 0.03533209764188336, 0.059708866005342816, 0.035294950038435004, 0.03325082444315476, 0.1110718016242308, 0.011096629408007909, 0.08905621200439431, 0.10525429080570899, 0.06784620980221419, 0.020731783306766904, 0.026782793894169793, 0.04797991049746352, 0.0067629614720992265, 0.036180754522642786, 0.06952766554370042, 0.03413152678178684, 0.031048905802890662, 0.028502427627362555, 0.05907232354905817, 0.0929611077111575, 0.01730990029060312, 0.024608033070821437, 0.03357270011498082, 0.02296207018286711, 0.052090837890582706, 0.03904397366568446, 0.003290136721202984, 0.013349084953416981, 0.05156543180947343, 0.01051028103252212, 0.0714630181450517, 0.07490177233252795, 0.05493914513217826, 0.04633007503505196, 0.03219854522256121, 0.020415459857172063, 0.036875037025780454, 0.03816925447374102, 0.05439635268562744, 0.051151843921792124, 0.03686978166261989, 0.05424078704128343, 0.040315430641414664, 0.030920038322707823, 0.010650180178814599, 0.037835611691398006, 0.023659133585169915, 0.004771450316653617, 0.02911744875863435, 0.0288877641076162, 0.052710894134736834, 0.0736228421690964, 0.058061083658568324, 0.053999576597444476, 0.0020413475689448177, 0.04979140200321713, 0.03410478265235021, 0.053706869723335396, 0.02439654875366438, 0.04871647722358185, 0.043263907709549514, 0.04651709624956693, 0.018862446417070685, 0.07785369296588245, 0.025182378763753562, 0.03574206193368282, 0.05574300885200501, 0.02371620713552881, 0.004484536503666952, 0.041101896504481, 0.014608941442753761, 0.031598288520810106, 0.027493453441908764, 0.03489170816817111, 0.03059601568947396, 0.013574305227056388, 0.06406022243261819, 0.09868792138032376, 0.01898212275738197, 0.025385022426264423, 0.023140313944989638, 0.056029192487438845, 0.030281469563863454, 0.023989307904435743, 0.07359249742641565, 0.028412837475057573, 0.026687216764736562, 0.039694493396147605, 0.04519839846198598, 0.03457640170029575, 0.03286494595569468, 0.01915365175884818, 0.011287826759320115, 0.02498085358961215, 0.027141482005977345, 0.032471670889325684, 0.06441822681095331, 0.04019282593001281, 0.0645722641098884, 0.053339419480893886, 0.014985579952237107, 0.03310057161856563, 0.057183935967904914, 0.07528276317903111, 0.016069732260920348, 0.05629110262699186, 0.07027751240398615, 0.07180650898766133, 0.03844498483944805, 0.04058971693138442, 0.033919404696432814, 0.029125027283425295, 0.03711391856232959, 0.04012460963079526, 0.05336243276213927, 0.047232212513805404, 0.07222221127801365, 0.0162265389677017, 0.024262065848996563, 0.02622833009809256, 0.048845563038823106, 0.02522159480459748, 0.037610665294191534, 0.03475806029934076, 0.039510149658928, 0.022917801792162563, 0.03357095343451347, 0.009820855526824393, 0.0295989120364069, 0.03008239587107974, 0.010207347842233797, 0.03252325925014673, 0.0533189113071609, 0.02886118277186348, 0.03356284439383495, 0.03060420516938452, 0.05666748545463047, 0.03851067304851548, 0.06141176071739005, 0.0695054489938963, 0.03905238531109306, 0.015985545901311262, 0.028889890001606078, 0.007865873358828287, 0.046886239546321096, 0.05407428932225993, 0.057361572605347445, 0.07352053112680874, 0.061375934615611076, 0.05876364757216746, 0.02263662071087428, 0.07029633518428573, 0.024426654093868794, 0.03965592853003933, 0.17435280155510674, 0.17287497198389423, 0.06991949653433216, 0.21800286737420868, 0.13138440077102956, 0.28979463683020684, 0.08918448576643583, 0.16345647253817128, 0.17631770982857675, 0.12196956322558465, 0.13115601463904306, 0.10816142593901004, 0.21072912300305985, 0.1309735631389964, 0.20319518452930838, 0.15012718616954743, 0.1348563725309026, 0.1850514798875778, 0.09216567095849784, 0.17004390938147423, 0.19855520447656033, 0.08866215935878216, 0.1340507085044538, 0.24048091363041635, 0.3559444291937736, 0.1398873485384449, 0.20339907116947636, 0.11846216756009287, 0.19589819705053685, 0.21006541506898022, 0.10068744150621277, 0.19572008160814164, 0.10467017174608285, 0.15683762608997284, 0.14198278287245383, 0.1139337145873616, 0.21017583898238598, 0.1164325325179004, 0.15625492429300664, 0.23300076985070783, 0.12835305214168566, 0.21486538492383497, 0.17828537601857417, 0.16454873005709342, 0.08190690329478634, 0.17160263783749075, 0.22831776630013223, 0.08229054480550752, 0.13142279709779447, 0.18623399788573866, 0.14832723194793349, 0.16266577786976294, 0.1509096683754075, 0.19688036773473988, 0.1314047787098154, 0.24982300346657155, 0.19286994341640704, 0.07246532161990482, 0.10681108872015631, 0.1846010201881009, 0.18136958471469342, 0.13842853326951304, 0.19993215558990357, 0.0948766875831831, 0.0834631343041697, 0.18203145403775478, 0.13905519319157447, 0.1083653585444535, 0.16737603882868446, 0.1598863802369564, 0.18154255204623748, 0.1754529957449244, 0.1086173708280248, 0.256859750877465, 0.1579177334544159, 0.299047875788904, 0.15054531695861972, 0.17278477279168947, 0.11148243241252438, 0.12225890697370614, 0.1770357027529709, 0.09331180744113461, 0.10400215073698953, 0.12552313867115206, 0.11793138354175514, 0.16281303529056812, 0.078713933096057, 0.12430670596058331, 0.2373147182046406, 0.10511362174105261, 0.2650824177169031, 0.16235292288324527, 0.17849313906363903, 0.12750015879470494, 0.12001645270614855, 0.14997118002464696, 0.12246634060096358, 0.11103735065027592, 0.24797276323360784, 0.3112195726604231, 0.12873600417327496, 0.0814100339888565, 0.13875336987116646, 0.2186133475193093, 0.05913249209463116, 0.17699920632425817, 0.17797017680300822, 0.11092441396847849, 0.1009750922000216, 0.18218010573858218, 0.0874267353285705, 0.21458387825517886, 0.10467573354441313, 0.1719398544200005, 0.13961993788759555, 0.12574983940970513, 0.18393395678891292, 0.08971809664921415, 0.08230526901541219, 0.10367834835403389, 0.14955893279083315, 0.09593151404612488, 0.10236922666550645, 0.10556340728315616, 0.13938145471676705, 0.18041194416582587, 0.14434473919531993, 0.12677578435790154, 0.16535687620841688, 0.10577776634524907, 0.14385242045166033, 0.061941958678465706, 0.14805364662841444, 0.07346184113092961, 0.1441669455098529, 0.11748375836759807, 0.10579554724597162, 0.17557887931264218, 0.1773431031934677, 0.12201927467099122, 0.1981308530535429, 0.12116688694204054, 0.18355229178503638, 0.11153569084502037, 0.0965827807123142, 0.174738465537948, 0.12057602630868075, 0.1488487386415082, 0.2077824424111074, 0.09331674870824622, 0.22553102954501109, 0.07174429498733052, 0.12370554144464194, 0.12061485930556252, 0.20083518939152842, 0.09197005806791206, 0.2924596115706429, 0.11943835509760727, 0.12298459142086007, 0.14267056128911434, 0.1249551381014528, 0.1329013314698973, 0.15803243213843915, 0.13875914617411553, 0.1414178543153309, 0.12079420814951583, 0.171669440704488, 0.13661800703454402, 0.14326591885858966, 0.14298211392616073, 0.12497030664235355, 0.12688651470647705, 0.10993288168984075, 0.10699134920873951, 0.16723540040754503, 0.20562469448533752], [0.06946401129807196, 0.06562577290160042, 0.045086752638340964, 0.013990358960243964, 0.0534035295488373, 0.016100892887240457, 0.055411733281348026, 0.02650046368099509, 0.067373403317986, 0.02425411002590291, 0.07831328443341679, 0.06725898808649472, 0.030188284543973785, 0.03804018398025825, 0.07257504839329951, 0.07920928554789675, 0.04437760036859301, 0.06210652585592001, 0.0010035205371921973, 0.040529284085477554, 0.03720168542537478, 0.02953447063543624, 0.08162813156001991, 0.11326999899240271, 0.017899960362082048, 0.029098003531896302, 0.024637492981949644, 0.06570385258284307, 0.06803185588890506, 0.05521627743878672, 0.05089888551963433, 0.04801659844815732, 0.07835062355884621, 0.034458929777986584, 0.04084081757032583, 0.0182451365981251, 0.044235663428421945, 0.0317922581527983, 0.014785389686303755, 0.010847333863738083, 0.07094656763177726, 0.055503211840386354, 0.06220411396615448, 0.0315206493401239, 0.007482826523858333, 0.01663469912243947, 0.048700366394534234, 0.050039989873766906, 0.06779481296337421, 0.06244742349090596, 0.027071528602391485, 0.048991188692349585, 0.029352329400998932, 0.026723638499876665, 0.0080886876375805, 0.08495056295707341, 0.09753834516290696, 0.039200347532788594, 0.05574980022145375, 0.040221665309922355, 0.03120181120691761, 0.033143598946832845, 0.023636765733000734, 0.05643684702414659, 0.0182346488544417, 0.06299500015654391, 0.03523424523131501, 0.05766060736571109, 0.03715969231580535, 0.014876649910283667, 0.059367788339694666, 0.039042613859618866, 0.06862008117980535, 0.06781617915558238, 0.027179079686081218, 0.03804260864853859, 0.03331920162083642, 0.034744538847477205, 0.03560100599462467, 0.03248254933785046, 0.07016151903137084, 0.020834027316361185, 0.010890128492798296, 0.01482278339549779, 0.02447897789909715, 0.07418132026589687, 0.04836484669677673, 0.035182610905218514, 0.003036481179034097, 0.023915707922330307, 0.02562135480524552, 0.10656119083925601, 0.02959442850683005, 0.03323594318522561, 0.01228680158214223, 0.021241898272907542, 0.05856632630551054, 0.05153597572878484, 0.051549861072412426, 0.040399045307910254, 0.061088103891140035, 0.03208199835142061, 0.02210866930263658, 0.08527939087681233, 0.05288542428564641, 0.04620784953717263, 0.09655049776718502, 0.0576646906143475, 0.041630098806513895, 0.11464043069751033, 0.019452016192278074, 0.05879283935252217, 0.03173107837116526, 0.04120845933474841, 0.012693869103977998, 0.029147609640213273, 0.02987984413911979, 0.03423028317610583, 0.06879829621363072, 0.04793465768377628, 0.05324218760154421, 0.022482725138205196, 0.008358984524684568, 0.019132461766862584, 0.022430192574017474, 0.0829944953382496, 0.053262144191971714, 0.06426581361841771, 0.045674292280549006, 0.039350623340015455, 0.029044936621381395, 0.018043506086894104, 0.03241544386612312, 0.030449070449497913, 0.009736623201939848, 0.028348434378483126, 0.08360628549370074, 0.030010004392674858, 0.035246223016011144, 0.028035723033451268, 0.08679020819404433, 0.09080769584303902, 0.05416258095553326, 0.07772659131836507, 0.04830505353428664, 0.04383383499037835, 0.010054401260980917, 0.01193465107315851, 0.06331406811612748, 0.023678935042792754, 0.025240814035397866, 0.04810467557681184, 0.01857461760781946, 0.034127841898871046, 0.02572073747644261, 0.020036922407246405, 0.06619539757769916, 0.09889912416016865, 0.05709458713329608, 0.024661042524742025, 0.061460388148383754, 0.08054024840314543, 0.04167781842331733, 0.015143944690334461, 0.028669819754037647, 0.004812224867618493, 0.019343720088081977, 0.013862643484777261, 0.02195926492042359, 0.044278656282732566, 0.0809643546780271, 0.031177081888721838, 0.02868331630804366, 0.05799652159874959, 0.05152019431754466, 0.04706324033078648, 0.04711853655716104, 0.024315776273367867, 0.019367277291753603, 0.07367913430977253, 0.0453609278455617, 0.03038643318558893, 0.03474827352610808, 0.02276803351818554, 0.02427319519131655, 0.020938127173952038, 0.02023577393453208, 0.03772188976947819, 0.03601126523027497, 0.04434621374633524, 0.014855890842755477, 0.056409459380853566, 0.05139868128143492, 0.03274297326683037, 0.036535893732141105, 0.022324600760194085, 0.054790773053443244, 0.0958374844142987, 0.030244019355685003, 0.029133274219930175, 0.08755733033702259, 0.057365410705848094, 0.0470803547350149, 0.039736930836713126, 0.10469685458848554, 0.046370689186357686, 0.02018267446528039, 0.06869069150378627, 0.1040864970174528, 0.11359364049689424, 0.03382983752676556, 0.03661303878611615, 0.03319759665417575, 0.036397634014006586, 0.03953161161212672, 0.029672592457744385, 0.0234030572051603, 0.08926715431434494, 0.019220031362267274, 0.07861749794814857, 0.05374793203607683, 0.03285743063315749, 0.033282176591455936, 0.004928863190505053, 0.0348360097456363, 0.020161990091324817, 0.059571380036011826, 0.021695801537604104, 0.0037274508307042022, 0.036750448146654714, 0.009450266239113145, 0.08747966434325903, 0.05035035507453065, 0.06835306889467663, 0.056452172613071824, 0.07157424645077798, 0.03860114420193338, 0.034937401482414816, 0.0942662840468749, 0.0336143063501485, 0.03597329025186839, 0.1157835411328462, 0.02293929630409806, 0.040874579065148874, 0.04206645099686519, 0.040489436022096106, 0.023354592567850507, 0.04800997944849153, 0.05000929656108061, 0.052112575635434165, 0.018401106353849173, 0.030552262492898493, 0.0013383143067908203, 0.05027285378967082, 0.020496349165877028, 0.025408568138617183, 0.0714996371478323, 0.01875208570591865, 0.016432773667357622, 0.0466478138320869, 0.017793732695281506, 0.053514290540929765, 0.060871668730772314, 0.04574053207292192, 0.05703886572812354, 0.06631755029722568, 0.048691372522303177, 0.028227635719362768, 0.03111710869556954, 0.08047978874416122, 0.029406369243177678, 0.05373743663151419, 0.06570708547388354, 0.035289476340216015, 0.02336279353907993, 0.019909114043618885, 0.056767084545666174, 0.028520181715007753, 0.04353435972945825, 0.0633388931953138, 0.028286978805197344, 0.09171834455863123, 0.020402817491201625, 0.03932677119249298, 0.027936765541052146, 0.058792563560869426, 0.09609201712714088, 0.050841555329820806, 0.042174320007043506, 0.017798323477167758, 0.08350866290950969, 0.02943625816354348, 0.016935886589870337, 0.046412812530874245, 0.018511733280554898, 0.01859524644040052, 0.017459946271452694, 0.028650437729553353, 0.01606965373690811, 0.03881538452039804, 0.0752362080158726, 0.03383149993756125, 0.006936205074100966, 0.07715372609034662, 0.09876353425845023, 0.09351593922943839, 0.025491552697795055, 0.0210832491246683, 0.053674088821055434, 0.034391429770978234, 0.06327253848975224, 0.06547702927022211, 0.031425855535593246, 0.026512115878323396, 0.10757249584721942, 0.003404090145317417, 0.08616916369646789, 0.05337677009764218, 0.02197428024373949, 0.06288961327124028, 0.02582856435178509, 0.017555847073033932, 0.04130627344092054, 0.0069756375347834925, 0.05735907132827467, 0.02559110390833549, 0.09549094454175043, 0.04951455697958027, 0.06681235116575995, 0.04682123315550628, 0.03616959262158602, 0.01251143196807994, 0.06033023225984747, 0.11806385546562173, 0.028137020924459064, 0.0335281137977877, 0.08051235514182238, 0.08626852530024706, 0.04874517870766502, 0.017743000437715845, 0.0696498106023477, 0.021032583899796013, 0.005575169437384654, 0.016412263578404824, 0.029564371047120903, 0.03098367533135799, 0.023733740972895778, 0.011343939826943943, 0.030738661260974985, 0.026177743397232507, 0.017358175321151654, 0.022291906042805603, 0.14177371747791767, 0.13785781308768258, 0.0886143631331863, 0.14018091343102917, 0.09654626896184298, 0.1516309095126006, 0.17049182566904253, 0.16726981307710373, 0.170475339456912, 0.10542404822885029, 0.1277371787375981, 0.19497008153027107, 0.08013987553215797, 0.16537012952950694, 0.13276689836094457, 0.15159167048911895, 0.16959801556602602, 0.21427470049069774, 0.1627575858466087, 0.09843933350977399, 0.1344464542043786, 0.19919822803668438, 0.16389775450431532, 0.23039660716970123, 0.15601929096925646, 0.15375099655601288, 0.12104802073970919, 0.08761313218142718, 0.17084874603296482, 0.21267823454353119, 0.1410362965637638, 0.15942015444799779, 0.22734520235849967, 0.10872643876580462, 0.1303454936151543, 0.1353969088485164, 0.17388009466230872, 0.11892315330764941, 0.1036898013685019, 0.1289036854981415, 0.1813190229116909, 0.14063889611392252, 0.26532925124610623, 0.12295054647350505, 0.20242837648237907, 0.12177187423672407, 0.17985634655962068, 0.13693922770119485, 0.12513313863065936, 0.23376564735606795, 0.1003966881563106, 0.11791456791181719, 0.09407028045144775, 0.13870847711880363, 0.12402823300010736, 0.25113117520607287, 0.1491604598178979, 0.19136476450629775, 0.13400635201363795, 0.1570472124242975, 0.11020115802004454, 0.14653883033221768, 0.18683389069572573, 0.1864984361154418, 0.08175537110336366, 0.22236307211700948, 0.09521655482991088, 0.10491139751168028, 0.1406938552616104, 0.11969736176392726, 0.11623160297712011, 0.1494901227734743, 0.12630570514668382, 0.11304813226865185, 0.12842090454913918, 0.1347350088819381, 0.15362983208990869, 0.13651669956743717, 0.08390600207231699, 0.18170419659826065, 0.15627658925950527, 0.19799660380569198, 0.11270539985308725, 0.14009362537293665, 0.09946792912218841, 0.15668261585937393, 0.20666614505312136, 0.202491793240751, 0.11125383177591909, 0.1628183672625211, 0.16087797380262808, 0.1549695360083734, 0.12161969853144501, 0.17029370001006514, 0.07140976737343496, 0.1939945604892508, 0.14756537282899504, 0.12771691571200086, 0.11870749955696445, 0.1389661584530146, 0.145148518645475, 0.07790087632113889, 0.16250610982458438, 0.2568045925469168, 0.27349786292160716, 0.1828049270496253, 0.1647635104675447, 0.12675155299685656, 0.19772303380793144, 0.1256539711668607, 0.15271763587670942, 0.29816497477792925, 0.10348812872243505, 0.12233751525561656, 0.1804331954448454, 0.15833964871783412, 0.1678339449027854, 0.14503008145238125, 0.09907677228893004, 0.15286906081582272, 0.17221057457068276, 0.13235540189329656, 0.11971400885452187, 0.13729627063918498, 0.07718965561399538, 0.11554314274220698, 0.12974252113171164, 0.2049524676535399, 0.20148144584269295, 0.2337602694188395, 0.1731114939696366, 0.14415977492688165, 0.14528623061074367, 0.0942441441058632, 0.07593741595384575, 0.15411236022989597, 0.1552220692317332, 0.15382994957748922, 0.21559823995396016, 0.0985960444555648, 0.2239556616592792, 0.19490367702899442, 0.10689276901464309, 0.171960630724507, 0.12991153544956638, 0.1580678560440579, 0.12482678773061884, 0.129400891882758, 0.2193695222658496, 0.1511483966943718, 0.3206987462697491, 0.10243628234151872, 0.15849868857091473, 0.09400132487738326, 0.16633186098789016, 0.10190598095857328, 0.16981164684459088, 0.2452896168876079, 0.181957220117892, 0.14064534657424496, 0.16353245313850143, 0.16652350554302817, 0.10243728591669952, 0.1665938477362356, 0.18985639867042342, 0.05012156291594429, 0.1001363714796401, 0.22299357780045082, 0.15097673171229903, 0.05585113450163796, 0.14445812020811344, 0.1342986758437849, 0.22102638658496643, 0.1770509172591471, 0.12024413403724471, 0.11775120732284362], [0.011231397680427519, 0.09549760950669166, 0.01843889938637374, 0.06676189661506685, 0.04971473958463438, 0.03350268350914121, 0.007759141031607626, 0.020038155808804498, 0.035240749317792155, 0.062149637453858896, 0.038318871445352995, 0.005836291942790512, 0.023301460539862033, 0.057559162002777865, 0.022061346136333964, 0.06688059427805486, 0.0476145516750553, 0.06301037554118423, 0.0792029959660384, 0.03131954168390123, 0.06773049222125162, 0.00568206551589913, 0.043107943699484876, 0.048114757293895374, 0.018843922411061583, 0.04283705883989892, 0.036328054078283815, 0.03952439123344037, 0.058220349507586616, 0.021659234245758385, 0.057985535897915406, 0.012216562810804577, 0.015662565147654427, 0.02596738139888452, 0.0590401670084365, 0.010935803612453804, 0.011748170908240062, 0.028625909509437702, 0.013599931825733474, 0.021437241117500012, 0.028456874124165026, 0.09318439935844752, 0.027821172449377277, 0.02545212023711253, 0.04390273693828814, 0.06359030793030417, 0.0018873379209957597, 0.06633772139227198, 0.01885021199291993, 0.06963084226534252, 0.03726896326688509, 0.11891897046758283, 0.07968623656779528, 0.06279531167820096, 0.01906897223013784, 0.017739417061450023, 0.031089837880684968, 0.03622149507845602, 0.01481437175008919, 0.060992568896542636, 0.028158377540568193, 0.009577967350431269, 0.08747331347436675, 0.04224880290548167, 0.017572090052248492, 0.03690520939867824, 0.04309055733404333, 0.050679309398777066, 0.05405317210862714, 0.02089666074983055, 0.06307989035943343, 0.05327792177277227, 0.058931842175943244, 0.01926279630542042, 0.06022743858216752, 0.038386371452361345, 0.03273459992581799, 0.044156932572443644, 0.02881120511090323, 0.07020529329536424, 0.05204898650727926, 0.029538837336604635, 0.024491980326392, 0.049003947886728474, 0.04021149549272753, 0.009903489600776905, 0.04740101232704136, 0.03728693185914909, 0.045880592097678495, 0.05063621312259667, 0.03842461456154143, 0.014980115830117177, 0.05487415406312193, 0.026841849697032766, 0.0028936972329017497, 0.055277016719863306, 0.011925368960345946, 0.03295840485201728, 0.027261623744702628, 0.06783133237472466, 0.032415179565789244, 0.034504925696960384, 0.08377601993420432, 0.06308824837868733, 0.019254863464964495, 0.059379118780094775, 0.04837708495136711, 0.03520365151005887, 0.006667388173105616, 0.05462248268867693, 0.01803295131051733, 0.04399361794874553, 0.016129207496921864, 0.029639922638213443, 0.053246198071827816, 0.03507540839153432, 0.02320031203599947, 0.024706791380360246, 0.045767295354556654, 0.012057978780038897, 0.027172975880544514, 0.037291310051636356, 0.029550843849597924, 0.05771584230505171, 0.04375934826150056, 0.04098120318245023, 0.09666102893290021, 0.05589174099206444, 0.013898563432326962, 0.0594271410016283, 0.06561864828390461, 0.08651207997313431, 0.058828435627923864, 0.057445309845910925, 0.09833573543977353, 0.02093237193842088, 0.046032875055266965, 0.04214277633676126, 0.03569390947720216, 0.015403063397013373, 0.018300398350543073, 0.02240437349574941, 0.036735892476093386, 0.06264669445133017, 0.03595228412098462, 0.04089375041545399, 0.058390015000177015, 0.07399729828560546, 0.03859413832786583, 0.02551759011112154, 0.04834953259917037, 0.019730983279465188, 0.06826182016201558, 0.009006626637382133, 0.03825221413506135, 0.0380614199375193, 0.03551027437131252, 0.016819849167199388, 0.05037024654748459, 0.001025786703159552, 0.021275598480696642, 0.0763459476612268, 0.048970328118171425, 0.00861505707425456, 0.06612051248310075, 0.05045845391108625, 0.06712662341493754, 0.0560881735967292, 0.0388295533165576, 0.051521730323832844, 0.0124928830642133, 0.05191192571674624, 0.02417603800553949, 0.02921684292115031, 0.009524099878035486, 0.023757202415576866, 0.03328619472261879, 0.019228577073062622, 0.03431857480937916, 0.04855274125152538, 0.03395187533310345, 0.09902070231375196, 0.05318268938290496, 0.012827503566269674, 0.020137184164336613, 0.048817305885736025, 0.07961857568232283, 0.06289410637691617, 0.012520422009871373, 0.062286663770435326, 0.015707016441850893, 0.08814203928435042, 0.06097462328691637, 0.02607569857049854, 0.026070445122557784, 0.015486687639608018, 0.03387380714317964, 0.035817969755660144, 0.09757435895622739, 0.057679204150072994, 0.036290856679120374, 0.046231927680632764, 0.038705117655016726, 0.060439349993342356, 0.051320559465356415, 0.05939503042628208, 0.031335880424106316, 0.0558851296532779, 0.033051051695140145, 0.013776375281233943, 0.03568983771988461, 0.010127549251211027, 0.03734597425547339, 0.042931191893594886, 0.08093261565532416, 0.03995176104287948, 0.05124622212362386, 0.04240254909100552, 0.015696055638874253, 0.015193889792557928, 0.021905451074182507, 0.023140331181967934, 0.025395215226096973, 0.05571475169891792, 0.030044583686357065, 0.0743884168144676, 0.03900745042389439, 0.006058173988299866, 0.08074506967058105, 0.03375571852009143, 0.03297263493521079, 0.03930602553150347, 0.04826790593083828, 0.09053645475256829, 0.07227361577773286, 0.019468747552544362, 0.023417963360946988, 0.07095772953283402, 0.08935445769419594, 0.0907541079927356, 0.01981049171468664, 0.0775917215392955, 0.11386749394718679, 0.03540193421706077, 0.08660475362933452, 0.06720476438321414, 0.015448195551852546, 0.04845129205815254, 0.04033067579110784, 0.018545077257459203, 0.03914052755722115, 0.07759802644291232, 0.08270526650331675, 0.0592869354201661, 0.008483307188256614, 0.006918931706628252, 0.02172433448234393, 0.023342404108975204, 0.07754109844925904, 0.019491586548786972, 0.023284501268438274, 0.007077189192416207, 0.0496689964746756, 0.0672685795073067, 0.07058038526485044, 0.04893701095434447, 0.02719342659768318, 0.01939832683532469, 0.03593074555899348, 0.020841749482637933, 0.006464427541716085, 0.04931746170886102, 0.008721324960671125, 0.06431182485915, 0.06003633028857651, 0.09999399403891257, 0.031748516447541696, 0.007492038731147806, 0.034900905053702094, 0.03317955528355895, 0.037114106253871036, 0.02332581447497491, 0.053173067318576, 0.0036669792015961706, 0.015157784068686588, 0.041748942026207526, 0.021800221236903342, 0.0746327835405546, 0.022712356163068645, 0.017498030417388486, 0.05758748810377814, 0.07318436408475523, 0.030865808873767817, 0.01988197920934087, 0.050360708752827305, 0.01839238061239162, 0.014763011300425618, 0.03198824834168679, 0.01450899569693232, 0.03752501666425698, 0.032623838933725516, 0.020707283814948414, 0.0687683881410668, 0.04787605195756882, 0.058112001692455624, 0.05514570541920201, 0.049549919598165064, 0.04081336097911962, 0.02997139930695055, 0.07536234439260538, 0.018787714540057125, 0.013334641323214578, 0.06944939434047669, 0.011336114238797417, 0.03199658529352277, 0.012622102944841309, 0.03325962296296512, 0.027017144020646814, 0.0026878843604091316, 0.0319454948898525, 0.06515868909416661, 0.048302582900730834, 0.07536573816210994, 0.049237815377813195, 0.01233236083099919, 0.05034795721932765, 0.018579443961742426, 0.039428863899722215, 0.013911934539435372, 0.0173437939355931, 0.03674020172066746, 0.05095800452475106, 0.005879884260901881, 0.050222747808983254, 0.014202851640631356, 0.079516984762684, 0.03870287301739858, 0.011619063067970978, 0.08219337421319178, 0.057389056009631005, 0.04568278436518965, 0.06396933376128155, 0.06869688915509371, 0.0269053909446924, 0.014939166515344575, 0.04848685385959764, 0.029807010244938637, 0.06376431331098562, 0.052682981721215674, 0.0492744688545504, 0.028627673426883358, 0.0388197627128853, 0.07937588668879002, 0.26814168259020776, 0.11527867386898688, 0.25249105788046317, 0.1458070478251865, 0.2044214001826702, 0.11143343342888741, 0.1017387516255821, 0.12268493612927776, 0.2674197826173998, 0.20786757010125345, 0.10003344756701302, 0.14266533656947075, 0.110614309237609, 0.07914499544929113, 0.22342035006130898, 0.19511597531457103, 0.14772695609398429, 0.14383594956128828, 0.15643526139038225, 0.11424704454839231, 0.10645720972529343, 0.21512836758648196, 0.14947984187353044, 0.12327807204377268, 0.17720335343432042, 0.1224274386561686, 0.14993384089921752, 0.11040564220879348, 0.16405189139468057, 0.14756004085704205, 0.1869328232902673, 0.10795026146356138, 0.11379282335720717, 0.0845853841653274, 0.10498820548696865, 0.14414981578386601, 0.17421616211293206, 0.13823740965416356, 0.15658345343845506, 0.11842892700505835, 0.12321653220081523, 0.12745122875898116, 0.145778825146056, 0.10060805947549882, 0.15053160398477508, 0.1374081654414054, 0.24614749746697567, 0.21555383749786886, 0.31967558988159706, 0.10106470150452468, 0.1602086734267012, 0.15956218714915937, 0.1275365326493498, 0.14608590382962458, 0.07166960907559242, 0.10345169358075627, 0.21260766252394647, 0.2215068156440412, 0.10944354302820661, 0.13470266464977496, 0.17963271017276472, 0.1640980711747562, 0.2534085860656154, 0.10402091223025516, 0.12001101348188617, 0.24339482098096804, 0.13263412000190827, 0.17390208138573557, 0.15415110895710607, 0.16021662541935522, 0.07632942314470008, 0.12659537831261275, 0.11298421755312912, 0.13156685227107617, 0.12415744905029574, 0.1363661479685576, 0.18891381941014723, 0.0901666104853634, 0.1508221658126962, 0.11005337199857158, 0.08445196995331396, 0.13956448844363614, 0.060605162063673626, 0.12847371098975982, 0.08116343028603062, 0.18647338504031782, 0.1061323884453985, 0.17222059500073233, 0.3436727425263774, 0.14486845222211656, 0.13512280258920886, 0.10617341245374373, 0.1553460222578818, 0.10729378539948695, 0.14398355938253865, 0.12764082785936134, 0.12881852716447847, 0.22740040665432332, 0.20377181890991428, 0.11426552258912595, 0.10508411203420932, 0.2345100396703328, 0.21704348014487376, 0.0820979503013434, 0.19576224708749404, 0.10991539956340868, 0.20018203814904537, 0.10073172138823618, 0.13472399253758693, 0.09210164899066572, 0.11162016736043077, 0.11570952171760222, 0.17334990053167268, 0.2487491627013491, 0.1807244927171738, 0.05946978911637299, 0.10872224060397957, 0.09812231866582748, 0.10331280184008422, 0.18816795620706775, 0.13138450802333895, 0.18007855802293748, 0.18042046306354387, 0.13959862532154207, 0.18794983565326662, 0.1628310690003057, 0.13055560088926746, 0.1440998821729614, 0.22650183148441777, 0.15214886155820664, 0.3050073963259497, 0.12261391211781772, 0.16499597218728837, 0.15486596092101068, 0.1184826987164636, 0.22267019676585353, 0.1440767616394066, 0.11226535894938054, 0.1604812168666432, 0.10131276077440671, 0.10475028922120411, 0.16453068102559737, 0.14198311995114052, 0.13171381857847014, 0.14436026013666584, 0.124342980223798, 0.22247484434516202, 0.11133208765738434, 0.08260313932213091, 0.13304013128001846, 0.13807501433597458, 0.12988148948117612, 0.1450212867630105, 0.1456242286029362, 0.11238684517241294, 0.08950476414493977, 0.11147000646639256, 0.06691215710053522, 0.16242701890728167, 0.13936352825933887, 0.1664355126840453, 0.19333541843919985, 0.2183321626075814, 0.12709229358381804, 0.155837697487685, 0.15433999559571668, 0.1505031821227843, 0.14929467842223185, 0.18206770531833175, 0.17531591197175367, 0.13321561137995414, 0.19558964747815363, 0.13826112773629928, 0.18834293068897343, 0.09967605988945692], [0.004828047934889553, 0.02921132708809549, 0.03729295331023393, 0.034632188222941854, 0.0271414743450981, 0.10138097324318464, 0.06961407260068002, 0.00845529901374492, 0.03659034343135934, 0.06918055110520895, 0.03668204032545609, 0.05289233822916305, 0.030292407384202368, 0.024184750340458368, 0.03778849345361514, 0.01745987732353951, 0.012317367532711116, 0.017392314114277403, 0.012390526056650185, 0.01572362043999977, 0.032788241402276104, 0.03984611368768158, 0.023482218985596014, 0.02745222067460418, 0.005817477302175136, 0.016957949922089616, 0.08790408471418966, 0.010033245742951911, 0.044787813638967854, 0.04832834643762439, 0.03658539067292887, 0.08088430615081903, 0.029529820481735854, 0.04596006605894335, 0.06922241781027087, 0.0432149202172314, 0.038094599205519886, 0.040895466452404376, 0.061194030868430296, 0.029329059480298913, 0.028792728985389395, 0.03528356597188019, 0.04368296546501018, 0.040302759547147064, 0.00832285198773588, 0.0515304024391357, 0.024078570554153095, 0.02710008261454923, 0.02843227504091638, 0.04706667240468725, 0.01637016321652599, 0.009186276170845714, 0.046252347754254464, 0.026367955367952108, 0.04028867885109879, 0.04803535611098332, 0.033674497878359216, 0.07025683569090982, 0.044487871064413945, 0.09682215254513488, 0.01820620592503298, 0.04735916860461716, 0.03189242606411778, 0.04939966294313631, 0.03936584550707091, 0.06839209341353948, 0.005548427223167833, 0.030407278438008604, 0.026509516925040274, 0.02650940392707144, 0.05373096701899364, 0.05482853352723103, 0.07599488020904603, 0.011457658876034041, 0.007692421476672134, 0.022146261237081022, 0.04149504516634249, 0.04626000097261802, 0.01591105534199385, 0.04276628763745389, 0.04061268424735435, 0.01642169795119234, 0.08180424751293275, 0.018932987793138432, 0.0371897689277126, 0.023212667118998307, 0.034845375170510624, 0.03444429749863283, 0.04833301191308326, 0.006183418830210764, 0.036833553364680666, 0.013371656776496, 0.044820445154102585, 0.010539294697434433, 0.08026076420660942, 0.05944144386317461, 0.049973478120180874, 0.010445501595254867, 0.05973112852042241, 0.0525596377349669, 0.10766860923819965, 0.07138166726837236, 0.01488815655090636, 0.03608410870055518, 0.04798450319456959, 0.05004329171272055, 0.004396354995532743, 0.05203011393126461, 0.031515365248666175, 0.05045811683239956, 0.009482886262929008, 0.0168388768760187, 0.015852780948813646, 0.016194899536428914, 0.031960192286679824, 0.04072823328897357, 0.06608205486930187, 0.03943964658725647, 0.01995452390533061, 0.040551389552532666, 0.0413473587362997, 0.06424466193082833, 0.027647674601945667, 0.011164341046805344, 0.04852925682620657, 0.0553375989529154, 0.04050877974218419, 0.0412644220576171, 0.036269367912844304, 0.044254359804214015, 0.06869741775576146, 0.09692753559999889, 0.06648382202031151, 0.0648222002951849, 0.055956735891560395, 0.008687781800906505, 0.10260196417690286, 0.019027203201286255, 0.06415059782504555, 0.031504843031026186, 0.006558609433517221, 0.02287742704333317, 0.04347665415656182, 0.04351372132077814, 0.050876921778845216, 0.020420787998685436, 0.0333130959000799, 0.09218899067491294, 0.017768357948009527, 0.03219396018633439, 0.04259920386116832, 0.05397206254964394, 0.008419081249514656, 0.046153070420146956, 0.07102175916154539, 0.08018738830522185, 0.05454421914633244, 0.05256728712289084, 0.0326443815814151, 0.03374702342215084, 0.04825142354914739, 0.0717552806881647, 0.029193689828858744, 0.011279833589440152, 0.03646058728918433, 0.0439699879667211, 0.010161915955494248, 0.10107388689873681, 0.016764319284007918, 0.036186599773505045, 0.025052888837132244, 0.0377299988101567, 0.04431122651083335, 0.016377163344934102, 0.08594066265129274, 0.05969088592175996, 0.03321928077287251, 0.04218227583013716, 0.045392647716066534, 0.012241766145903499, 0.03632873972697604, 0.039063206303023526, 0.01293774649140335, 0.0672423409959001, 0.04066782725614406, 0.03785635735238752, 0.05000086959391352, 0.009764574877467128, 0.04127264218104463, 0.0689885771322635, 0.04377300377875086, 0.01797541044652462, 0.056198574527497255, 0.06695670511333213, 0.04323636301823201, 0.04749625620822753, 0.012794302273241263, 0.08255048609909513, 0.07150531385935123, 0.02840034449623237, 0.04669548365317526, 0.030395292992433234, 0.041132566834529566, 0.03081484487460506, 0.0872443987417125, 0.0524019806705896, 0.007614534753825396, 0.046803264563242276, 0.0688860439244778, 0.02015184134154791, 0.020570585000959617, 0.05512272278147359, 0.050058184461968566, 0.038290664087980986, 0.06077547873099966, 0.028521554927612026, 0.03528131367338281, 0.01767142867338994, 0.016792501743522384, 0.030699450965790503, 0.04234465582656764, 0.019044327181613734, 0.04393518842276066, 0.047939162280771046, 0.07541574838180697, 0.0578625443121118, 0.02869512555339644, 0.11037348183773218, 0.03932966317440714, 0.03122426332875846, 0.05496528788259434, 0.0922568507432457, 0.03165974217887608, 0.020346804972617857, 0.020345856938811562, 0.030737184626500935, 0.043634935582597414, 0.025033761536882772, 0.038893889380438675, 0.02191245120259062, 0.01288275191214897, 0.04271294110484662, 0.013496704350766397, 0.03101730467601409, 0.014852838939987125, 0.028165136351280158, 0.04308738956047643, 0.09488710637895331, 0.08048505176820102, 0.0607467427729599, 0.0368019177638475, 0.07980997508932507, 0.022620582660179467, 0.03501599061212713, 0.038669456262141466, 0.05700013615311154, 0.026913486578832232, 0.015443077126908449, 0.12093462440515719, 0.046384949913068164, 0.020548939186659072, 0.04500378914658101, 0.02156127075244102, 0.00737664865277287, 0.03460242953752318, 0.029756498237651204, 0.042144660913054986, 0.05527253510550626, 0.006700206422171886, 0.05470292958160562, 0.06256210302273113, 0.02195161936293927, 0.03809416636584267, 0.07047253540687023, 0.016419372874342145, 0.01080810058591587, 0.04701922857953657, 0.03242608099695175, 0.05939817138677163, 0.04663889656864828, 0.02390061024456255, 0.029470624867826704, 0.0744449541032795, 0.06556565032130288, 0.05006510606636444, 0.04590129179339256, 0.057935579304373076, 0.009032431351501615, 0.0898050859330162, 0.02686977934753222, 0.010299196038695594, 0.026419195158767606, 0.0910928490902147, 0.03248114739694903, 0.016525792063123757, 0.026416203585423292, 0.013499393319380621, 0.04367677930502161, 0.011350714917024298, 0.015147555837287538, 0.01922562763455414, 0.10809201071219099, 0.05436672806559552, 0.07661300591163098, 0.020599286485042785, 0.077922050991366, 0.020030795619071975, 0.09436107210574612, 0.052301860639765385, 0.0627397090166567, 0.053459178175657034, 0.01988736097700894, 0.07465062572831109, 0.048097646720106565, 0.06203702635942929, 0.08039551907249036, 0.0885102364625181, 0.0321563605910107, 0.01971807469794106, 0.013984825890210849, 0.02160276207442005, 0.01674414435852199, 0.04378142691547832, 0.015699863095857924, 0.05256059534487225, 0.030777907945335876, 0.02147285846031962, 0.0980538457271553, 0.022734208821108746, 0.04583552314509307, 0.043450519067025, 0.07482370031216452, 0.00721287246110038, 0.04180918718057294, 0.04337499811944943, 0.07142903448473062, 0.08896576766405376, 0.04062127975386478, 0.018539592067921357, 0.0291847514980022, 0.06412575359366114, 0.053239824220297806, 0.08336332836939443, 0.0128669896531069, 0.05799980045506551, 0.03722101382370438, 0.02284552714216613, 0.12287262000984724, 0.03289397685758529, 0.009706968896000857, 0.07049684337670765, 0.011865758701347777, 0.09346142441274659, 0.14262643462467578, 0.08304825938877561, 0.09678980831297175, 0.1405421545308444, 0.18817848225514736, 0.13308022832197527, 0.18045873681624092, 0.0789696685669403, 0.16334064004402007, 0.1924546471526546, 0.10466402006005088, 0.14725829414542646, 0.18667160262984617, 0.08234623173672347, 0.05517747508542192, 0.17788195411764807, 0.22566224508468183, 0.18571570876144594, 0.1458391928744893, 0.11878701182262552, 0.13308205161123507, 0.1463806944628877, 0.08984797919589667, 0.13675959540470956, 0.07303161381353294, 0.16146199327082406, 0.21730316862944635, 0.22130885852440713, 0.14260233349857793, 0.15099953048892562, 0.18733831362858896, 0.15911440875741745, 0.12575189252534222, 0.18928580106266085, 0.14517879444024256, 0.14515858504080004, 0.15812952612196246, 0.1249251457592172, 0.1021339763857184, 0.09040799712942493, 0.08180288387642753, 0.1172556480272643, 0.21632982327813105, 0.20029843754826054, 0.08967655936195966, 0.0997642366095416, 0.12579180570619722, 0.18560447279484044, 0.18242379830729577, 0.14253972879340573, 0.1898037377865084, 0.13577028478105224, 0.09284470831194232, 0.20004809533636417, 0.22358793945562458, 0.09088124028376995, 0.12774474002541075, 0.17118636098119522, 0.28406865053599883, 0.10573909422683139, 0.1696265753238432, 0.12723388195398355, 0.20306668094088956, 0.11585327045571421, 0.114494115564852, 0.10658953609245439, 0.12242865673596821, 0.09139585218602612, 0.11203635228617538, 0.11364037186027535, 0.12608485731987223, 0.20405327961329492, 0.12626075876816628, 0.11500038476961275, 0.18181462051166644, 0.16131210050755934, 0.135723139730192, 0.1385337784285507, 0.20823152315232063, 0.13621037165003438, 0.11898455525478048, 0.2338051008841684, 0.08787075988948347, 0.1544460221644371, 0.14861025547067966, 0.07586946395496208, 0.11534959828901677, 0.11320324975156015, 0.15387355530213925, 0.19611371290539542, 0.13977093381747124, 0.14507454519550647, 0.10222205351437293, 0.14981056203044232, 0.1658867639038832, 0.11711295649048784, 0.1819403968270748, 0.1665836281233257, 0.13336400261088727, 0.19331493324810461, 0.14248147546764345, 0.20386947979850156, 0.12242301832884551, 0.1252905850208575, 0.1137352901540937, 0.18805215435643352, 0.1517697552879972, 0.17692920120973743, 0.12751701272903912, 0.13370759304492705, 0.06624001453840925, 0.08731613521494212, 0.16646327571042124, 0.11998053850425829, 0.13062911468648142, 0.2466242186604969, 0.0991673621859762, 0.11747582935758176, 0.17357384335369835, 0.1561210121238424, 0.09541434341020162, 0.07161779088839408, 0.14544410601017937, 0.1353478485778455, 0.20495317245443023, 0.14290250206906951, 0.19204183301377684, 0.15303358585844118, 0.18655665879768712, 0.19680637896301287, 0.25923790229905036, 0.2065320796663723, 0.18764580599963668, 0.14212987175391567, 0.07145117442574232, 0.2685026938636457, 0.10457793475999948, 0.1597696744025715, 0.14534851355898767, 0.1601969522814597, 0.1179550173542192, 0.10729335639024935, 0.15303606798331584, 0.17991769488059706, 0.08256053717266168, 0.13391596896033134, 0.10718100959615362, 0.14469717028400592, 0.11352775693540612, 0.13226138758322886, 0.17304902716029077, 0.06280758823718756, 0.11208208773525492, 0.1371202695994608, 0.193147343853789, 0.0956250788764127, 0.11835562771246319, 0.11509699611774377, 0.11600151612994172, 0.15435789140962786, 0.23855792568816295, 0.0921866387849854, 0.08722036656352782, 0.12501771216310803, 0.13772701123549094, 0.11569199362589468, 0.18785431981086734, 0.16631843912745678, 0.14978423924936404, 0.15091247225721038, 0.19300682800671748, 0.12413280400177165, 0.09849019408706697, 0.1923415878967893, 0.17574315920712488], [0.04141026987664161, 0.04227746608516863, 0.01183068240812469, 0.031556548220255685, 0.059912614749684456, 0.008830433118066961, 0.011220410064373527, 0.08492354303598405, 0.027848037237661983, 0.018188827220470678, 0.06523786428114099, 0.030135298072690928, 0.030535872041758512, 0.049686762053639665, 0.047759732997585694, 0.0475689502913625, 0.09648277559467862, 0.014930538450097366, 0.04171202041869683, 0.032158766107092944, 0.027647710991122072, 0.02774243776295935, 0.0778693977683302, 0.037206147887533715, 0.10894497300708487, 0.05774551289035909, 0.059785049618972894, 0.05693827072278627, 0.05774917862107677, 0.04535019495374253, 0.08609368105328853, 0.009008381936338641, 0.036674888894682935, 0.04353672311070465, 0.036793291613820105, 0.014561254384687111, 0.015617923289086792, 0.026187503357387842, 0.026327835343357538, 0.051921249006784735, 0.006104251782920573, 0.02870276728044114, 0.036921167010141, 0.021117874383625966, 0.02885121596796859, 0.044094147836609233, 0.0372545033573143, 0.04289946053177119, 0.03182103241523428, 0.026098392010035536, 0.08057498282963231, 0.043941405226266196, 0.05581333955389358, 0.040668233282743924, 0.04559180759374173, 0.09062185057348783, 0.02074442184229772, 0.020712834121959827, 0.04614575811090969, 0.04147785415332164, 0.032915615011006594, 0.02989781081616398, 0.012367120155343607, 0.017724591344895384, 0.0810852510133578, 0.0349177283445193, 0.06216180293009647, 0.02227321158223335, 0.015522440963034189, 0.09980486991304545, 0.04700116805672165, 0.0767805110362749, 0.06300486736900865, 0.01595866196082845, 0.0701811998301456, 0.02620014763857809, 0.045174366283801295, 0.037569882603542465, 0.03791903483591253, 0.008333431661970193, 0.03221587413140843, 0.01182820890173917, 0.059397225268185146, 0.025699558975775878, 0.02339707405847167, 0.03815186044742023, 0.10082313866024056, 0.04609052317156907, 0.027003540214331403, 0.1008509399910127, 0.03149423462849471, 0.1035627686688977, 0.024824795733776786, 0.01780452687413462, 0.03783330959718555, 0.06320089777751316, 0.021905527682974938, 0.024784424815387018, 0.0476143716443931, 0.1102756600706808, 0.05533840717567552, 0.06669069640338421, 0.036990643523994, 0.0655912299970946, 0.002043172055216987, 0.08480175803866118, 0.01863626853352593, 0.020425191089030237, 0.036476625339879144, 0.022950282004932245, 0.013563579038506555, 0.014377353063243774, 0.05065578283862241, 0.025061624154688853, 0.07152199159346281, 0.0629454572504807, 0.039090835264012705, 0.02772481582548109, 0.04618941363127482, 0.03215141166301985, 0.027350645076723832, 0.02773298423797373, 0.02938550675377971, 0.022220234687049544, 0.006309655277178653, 0.017734152122190403, 0.056817592722513986, 0.06319496059609998, 0.04373629667585896, 0.030142543349234812, 0.01170447804108863, 0.06088309110172334, 0.03481216908943269, 0.03239150744892898, 0.018025966503867702, 0.01630458417498777, 0.03370886841308206, 0.0454871753050435, 0.022046907294181087, 0.07504170595277702, 0.08088036079800899, 0.07742986248265352, 0.05108058625351518, 0.04087164494839888, 0.05062570239627554, 0.07261431039941889, 0.024539299662254994, 0.15384525601421634, 0.03571770033769069, 0.06971308946489327, 0.03001733585411022, 0.07436184888525356, 0.06041538293263125, 0.016217263558158473, 0.06987032901135183, 0.046028899058939955, 0.07697879757371641, 0.02238654088409197, 0.025681684229282603, 0.08067701041938798, 0.018630574585028717, 0.08980036683140263, 0.02760476793252653, 0.03592659719288349, 0.08148123420053914, 0.07834323847125615, 0.0590894915794413, 0.07004147305363609, 0.060741050739682494, 0.022679657615240545, 0.024258792738340074, 0.015777748382289805, 0.006800410722667773, 0.03480384554413538, 0.06809637581388797, 0.031947739527470646, 0.022296623229199362, 0.05887951837071489, 0.021002311935468067, 0.009271690186353461, 0.024736896720564654, 0.029234997289735946, 0.0626201763178312, 0.03327755708127253, 0.022590697570253285, 0.024551106992387967, 0.05334339930766052, 0.013592580254490097, 0.015536482397076345, 0.04017083154570672, 0.018592444473817464, 0.021306858698446906, 0.06604836998327125, 0.01895299992494045, 0.057352900490044594, 0.014215714256880025, 0.010871219527607244, 0.008132232075196602, 0.02383838666813268, 0.017070921077843637, 0.05408609856761271, 0.04679287641098903, 0.039306328136233554, 0.025556403955805208, 0.05206618901161898, 0.055396691144954775, 0.029377357493485176, 0.0054724901940883895, 0.02679196205140362, 0.027643074243960362, 0.04068968374462378, 0.03909183117831427, 0.013352072696321675, 0.030101276107973633, 0.01052235266298897, 0.050650412562273206, 0.0029243402710680162, 0.034980677789257425, 0.04705679753134328, 0.01464746513163611, 0.024846864811655496, 0.038215319340628, 0.04167886030289435, 0.06873791316343893, 0.0226580654270947, 0.02997051830583763, 0.027407059791467847, 0.0450416760248763, 0.04867175684100197, 0.07190394004987133, 0.019611944707350868, 0.03480995892577114, 0.07586003341261419, 0.03331031883135438, 0.034848619552869955, 0.019150332682916237, 0.09493217533153873, 0.06261428127125387, 0.09784183855498992, 0.03726624748519352, 0.07754375677435629, 0.050144963071591435, 0.004422449865453547, 0.032019929907795404, 0.03683307455972799, 0.13369055524949106, 0.02923907670793274, 0.02604024402136284, 0.030238894227471565, 0.003381658372687056, 0.024710370926186446, 0.04726854040317478, 0.021629109753355868, 0.0203073667662759, 0.05476584072194753, 0.05924856590647852, 0.02907743215590956, 0.03804687575827684, 0.025957050703225598, 0.017785692602516185, 0.017245236724134416, 0.01711206766025674, 0.06430194998580603, 0.056842107536090966, 0.022855758246394898, 0.044665557497571555, 0.013442858903398438, 0.04535022176681988, 0.03035073157309765, 0.038221379096109065, 0.02364491882373489, 0.03010667894305962, 0.03297576440438148, 0.03144168291210888, 0.024155859249613942, 0.03764089895412326, 0.05173547651558634, 0.04575866154365001, 0.027263887534518878, 0.040720158722251654, 0.03647490930292876, 0.009453819929471901, 0.028661886913581725, 0.03910267898332208, 0.0396511979371069, 0.006912067558826699, 0.032848582317632054, 0.024993804305972114, 0.030669763143504822, 0.024823003088033972, 0.08170456415222538, 0.021857538020178195, 0.05284427770323331, 0.009288504858681513, 0.10553788123351913, 0.07057958853340919, 0.055007625731729695, 0.007928742364334364, 0.010310281330959932, 0.06282220519478283, 0.006276387909066774, 0.026470976956789533, 0.03198003204869888, 0.044106163925701575, 0.017972746375767935, 0.07236342426509627, 0.019460954523134618, 0.024034484109330564, 0.02804815664046234, 0.06611911054219931, 0.012387855282624163, 0.07219683078508224, 0.00974939676046732, 0.023613853958405318, 0.03846429408557954, 0.05076274786505008, 0.15406225807964802, 0.05655256843554878, 0.06813939165083632, 0.00994628806027674, 0.055705213904260635, 0.018950718898145903, 0.03870560029040902, 0.061229619482952746, 0.043664406985044486, 0.01901516412955619, 0.0696617309304495, 0.049956953603654146, 0.060057271301986716, 0.00044726774625990906, 0.04255591606300685, 0.06416550972649167, 0.0488569088009817, 0.024671896075409268, 0.03580850856979528, 0.0791976256896892, 0.01935295719322899, 0.05666487309480867, 0.01735352133701165, 0.05148508450797489, 0.005843630107495213, 0.019531074550844008, 0.07321653211669576, 0.039688674958362695, 0.03472428348275923, 0.0380497332662344, 0.027436690157159205, 0.029899867762240673, 0.05566997002930411, 0.033410151579206994, 0.03822889058820663, 0.041774517871559634, 0.10091943591232262, 0.186633451451217, 0.09102033120730231, 0.053712764769912734, 0.14135359486024227, 0.16351815793783436, 0.10359414763027623, 0.11268947288514146, 0.09481172332720411, 0.09957462218740296, 0.14374110787626238, 0.11674543346969352, 0.1602462423785079, 0.1056119159705216, 0.17751006439568537, 0.12015912892116655, 0.15591183947699686, 0.0685401628875444, 0.18880102062417617, 0.08758911532500098, 0.12483540621976699, 0.08002811862576394, 0.217771478177559, 0.12312359041384152, 0.16726486414911287, 0.19014136805649728, 0.11407721051645857, 0.1157811969037979, 0.1988161187018118, 0.17613487528456798, 0.1744949721520947, 0.19655609803815044, 0.1468997649968632, 0.1667242818662236, 0.16266619155724205, 0.12934429330691216, 0.13374926822800792, 0.1280916016548872, 0.102747137838554, 0.09313109496067609, 0.07328816899849523, 0.097008878815799, 0.0841318830967911, 0.12160877411764477, 0.08986276469283527, 0.16332611501697572, 0.25452017964374635, 0.18436279748716664, 0.14883554660745207, 0.14010548441400453, 0.15729577731220953, 0.16080642119050026, 0.2072427641119688, 0.10529962788906791, 0.07943145870681732, 0.15680315213338022, 0.12614900952265148, 0.1067870871854886, 0.14666813065207776, 0.13762165882414387, 0.22379343488043357, 0.1316080371578855, 0.21323833674673112, 0.15420865748197804, 0.1830461068499473, 0.18604773126782911, 0.16246219766476463, 0.1186214219177923, 0.07892918082014208, 0.2284060349507678, 0.10737046313982819, 0.1621480403287757, 0.12997751094160542, 0.15020820762841933, 0.2106259922466932, 0.18108285332639373, 0.19788234945266478, 0.12103061522206954, 0.15820302459741795, 0.18240630085910522, 0.15024568464967514, 0.12172462193355446, 0.19852993889681755, 0.18515269542413373, 0.04943208378409186, 0.17682305206694912, 0.20644914298768968, 0.2037134583318426, 0.17034587059770862, 0.2543731520493185, 0.11685299987514174, 0.17958220965679617, 0.19539363622184724, 0.10202099373864551, 0.08736587730386565, 0.2814125317719675, 0.11978315595056742, 0.15392828462344987, 0.15468104261784785, 0.22168330698003694, 0.10776198003441097, 0.1392883597122085, 0.12018380461320763, 0.15513556258332345, 0.1566988262798517, 0.2129529230296612, 0.16572896511323992, 0.1293866120038494, 0.07884652759399145, 0.12147967298064502, 0.12050189964112737, 0.10254499787885336, 0.21376473108126273, 0.17126638652576556, 0.1674615955280681, 0.16280200362445849, 0.09945123606631834, 0.09208831906078324, 0.23822199613336595, 0.16403477699045213, 0.1738504930249145, 0.1295631339833621, 0.17482978321852224, 0.17122656527546146, 0.07887393821992221, 0.09064077294521755, 0.10692396411491979, 0.13695436559857863, 0.18530963619630184, 0.23240961044305758, 0.2509503018471503, 0.17098256627157812, 0.1508342853236583, 0.246140755893242, 0.15926131377777747, 0.23221084127022376, 0.10843407663126146, 0.14885060789604343, 0.1298313566874112, 0.15177983700508071, 0.29709790622995746, 0.2635463194981698, 0.15345142553410224, 0.10996398485956654, 0.19146515266789546, 0.17028176436020484, 0.13095087161467922, 0.228808828659596, 0.13848720028275444, 0.19886960696068504, 0.1768957997762388, 0.11907768856373527, 0.11522767539586752, 0.10374113692030792, 0.1683335874470011, 0.20295279431006602, 0.16935705027032286, 0.16626277517887855, 0.08300246265266212, 0.15834767731928057, 0.17798341480233978, 0.174099670783166, 0.06756339312320755, 0.13815160780664415, 0.09783059238426148, 0.11856070944979308, 0.18989197579362702, 0.207219137960384, 0.1163700350650376, 0.13849591836333275, 0.09185370463397234, 0.12518666519392885, 0.1771054320758389, 0.13492037151609698, 0.1440882682800293, 0.19268514768731212], [0.06545994550951066, 0.09432735657619853, 0.05153129110112787, 0.08777117612020624, 0.019980865838606993, 0.048868089854236574, 0.043510281585998116, 0.01053185981412929, 0.03630969478117843, 0.10983997054638402, 0.08762058621693043, 0.08344550662103199, 0.04854679640923296, 0.04241861778521731, 0.06959878148571139, 0.08097982965409756, 0.04661141699480434, 0.028688623382139112, 0.020587574915900346, 0.029273588968921575, 0.057970072413163806, 0.03274596484017468, 0.03716615043700703, 0.006476343081768362, 0.04489541834881229, 0.02554341493504903, 0.08988346438854934, 0.03261466886127188, 0.0679855611956408, 0.05607577446367472, 0.026909290332226988, 0.04722628299327147, 0.04387977728319745, 0.02538941594051017, 0.06647913356221492, 0.04351662862445078, 0.061211535977500106, 0.04488318775510115, 0.0823784916992149, 0.04622320193917521, 0.05091719502102464, 0.02712158670258378, 0.044122562037720796, 0.04570994601254502, 0.035830970267735185, 0.05046788828387376, 0.06381642261159516, 0.04893903725690419, 0.02417729822017493, 0.06497106650063107, 0.05815851855121794, 0.03215964327776625, 0.03491403580072426, 0.07084797211592236, 0.0398155123055462, 0.012116936906691522, 0.022576896496297374, 0.01944284995026406, 0.018067582315134428, 0.014817444720275462, 0.018133534824535735, 0.077389681171025, 0.04919930796829924, 0.04004772504671447, 0.030098133232264273, 0.07714418063481009, 0.035431156640932444, 0.02648435093672766, 0.03436967287392866, 0.052315014369425275, 0.06285006015170967, 0.024784809774568966, 0.04491138745159392, 0.07062363858905531, 0.0483115422990053, 0.04131248258354683, 0.017175539960003188, 0.04013496713953153, 0.03917626938932846, 0.07199627662738485, 0.05214134606743052, 0.10248910410389786, 0.019554365538961945, 0.03422987714950596, 0.01468468455582737, 0.02572969304427745, 0.02776190980277475, 0.04598515160802392, 0.014556685627828685, 0.007751227822154761, 0.04969943697834688, 0.016288182232528925, 0.05559847870421025, 0.06625578062789095, 0.06165367979255896, 0.02213369739512282, 0.07683825874400717, 0.07406523496273064, 0.021688215351933916, 0.017359845392826586, 0.043605988950378476, 0.013699867037845957, 0.04976709786381933, 0.1201518893902821, 0.030950000021426432, 0.031066774803724502, 0.03900460823769531, 0.02137750349638443, 0.03932941419583175, 0.07460401693899786, 0.034445852657119115, 0.02137362709148757, 0.0166028471017677, 0.0760570482441014, 0.07195441758320217, 0.06484666148260718, 0.05268791532744804, 0.07377204545322927, 0.06096977011991605, 0.030810026181561333, 0.02651685413213507, 0.019390173744590535, 0.015985065181138777, 0.03310666584800328, 0.019977950874055107, 0.0011326249659759924, 0.024779556326628215, 0.0276791435786553, 0.05058257164613855, 0.05936347909512059, 0.03275255702676312, 0.05138751171949891, 0.02989742968742165, 0.07050381477681861, 0.033822946565886663, 0.019073174222402515, 0.07012353639208502, 0.018073364363742933, 0.06871702194574379, 0.03496988744084393, 0.08520343325911992, 0.006917693517020634, 0.034257061779499054, 0.024477246540388273, 0.02430054261499355, 0.06048130479851558, 0.040329836924830754, 0.017415700863385876, 0.06529417940445485, 0.016690363071017688, 0.05777937014617267, 0.009575576198497608, 0.027623065942597967, 0.05517946691402505, 0.016676475812170296, 0.08163082818951338, 0.03675283068009923, 0.07908480392108042, 0.009895263731689944, 0.0160267882447149, 0.07929529423915571, 0.020460932921137542, 0.04160565677128973, 0.006308280628159523, 0.0225512363812736, 0.057174122381594875, 0.012552598660301059, 0.011915847445057045, 0.05297337500979343, 0.020741570079999588, 0.026870035986986854, 0.04441056130153518, 0.023475693831700954, 0.0519703169383349, 0.06301845393834576, 0.014566948333184325, 0.08248894625613767, 0.05355640239412746, 0.018761133204304406, 0.09416373551733072, 0.0484648326622142, 0.006870326300662372, 0.04931770685699679, 0.04611398461425016, 0.05164000280802289, 0.08367851992408115, 0.048401695525934624, 0.04025146613017686, 0.04946089635092405, 0.04934265067981136, 0.012658841648860084, 0.0885017175648001, 0.06622050227897783, 0.028575966322434046, 0.055524026449289055, 0.0294867318664347, 0.03768550059307487, 0.04487522427112826, 0.025648979935795072, 0.011319058248773219, 0.010577335750924484, 0.0651829204552116, 0.050311464621054555, 0.02290894390053807, 0.023550923665865295, 0.06262221794214941, 0.03706786135632185, 0.12752078954250584, 0.05590488706084509, 0.040684049167940696, 0.028366538951353684, 0.07161350845689736, 0.01962973135373285, 0.08412434479161617, 0.04901689094220919, 0.055438305041001695, 0.005988461902410153, 0.013995941825992158, 0.04241160041983089, 0.044113656265601035, 0.08420971762989798, 0.02246372041202361, 0.0682692512148811, 0.02707943462977006, 0.12645320005474553, 0.05993412649859825, 0.028944314802966775, 0.09222376340579602, 0.022589358831605604, 0.0316355491222273, 0.06109090394250328, 0.03862363654339025, 0.031177809672249906, 0.02599851138168766, 0.08447702868931717, 0.11247218736717779, 0.028046611058075103, 0.04032830474898219, 0.06621129390212797, 0.021336184544188362, 0.06841147543802377, 0.046619342174381025, 0.023520473586094957, 0.07096396548853767, 0.07076759417090686, 0.019777471409930338, 0.025997214777875814, 0.05149312077030059, 0.024321855181047035, 0.08346049896171016, 0.09470882239721476, 0.036886601122997464, 0.08533240416117253, 0.017480902606621385, 0.012962227788633637, 0.0713683066949729, 0.029360206700080348, 0.029500372061926513, 0.03224888102962606, 0.027206499888111028, 0.01728499668740457, 0.02521077764310664, 0.03919197802221583, 0.0183591055834005, 0.06647078320384026, 0.02198591711930931, 0.040910152357912836, 0.07228562037550634, 0.03397403825675288, 0.02620457179634081, 0.051572705814314466, 0.057575226866550026, 0.02889795690744875, 0.10866634682902407, 0.05713761063112367, 0.036130123771727085, 0.04966097170366876, 0.031116442199075417, 0.02671160134336641, 0.04711782026495184, 0.025744585793525464, 0.0221523784491564, 0.06404366344213486, 0.027079976636976488, 0.030150361276502093, 0.01409632424193044, 0.0182287423165455, 0.04099878490031247, 0.060402581603416515, 0.12647478841245174, 0.021521014747239893, 0.08628947780497613, 0.08378040961801045, 0.04866386996582151, 0.03930864555220451, 0.08320427319455533, 0.0568369057990851, 0.03282532771869052, 0.036018125547636906, 0.009999261125020925, 0.026353675489043518, 0.03626060003655092, 0.011294163264063819, 0.008704693191834997, 0.019878083652245904, 0.04058240845258679, 0.013835432999316725, 0.12188193042792621, 0.023121240270894863, 0.025649261473107244, 0.03867408726364374, 0.06077644783222388, 0.02615530085149071, 0.06503659000079479, 0.07572132553304396, 0.01948024653228781, 0.019403335135129672, 0.00774894918938498, 0.02297802779432987, 0.020585456682789712, 0.0024971028511983255, 0.05893970606848598, 0.07740595287853673, 0.019461975335293723, 0.0395933008422294, 0.018313107749206886, 0.05486964563568754, 0.007923226531279545, 0.014438464854573532, 0.03175359178004006, 0.021765266560138236, 0.04493826947685692, 0.02011155277761, 0.046398701191309004, 0.040775416644230005, 0.028819360116857196, 0.02469071502526922, 0.027057470888980938, 0.02825793066632844, 0.04540203612357859, 0.04545677310576843, 0.010457415220087335, 0.09104680720596545, 0.06644164888007988, 0.027265540369215514, 0.018120124455421202, 0.03438049769629875, 0.04896138021121583, 0.04902224589679991, 0.05810786864810413, 0.03378599431485899, 0.032186333781048175, 0.16988067136656854, 0.22687493162530087, 0.15091417297240228, 0.3264895742458682, 0.1346101212285219, 0.17379441538885718, 0.11635869696375825, 0.15704888249597243, 0.1490356640950326, 0.22631167313985287, 0.1997433455600854, 0.1360946310864341, 0.17354433364685506, 0.11089190885785127, 0.1596911044250573, 0.16472355132141422, 0.11826348265693074, 0.18357657677223607, 0.10210376187798478, 0.13961224636483577, 0.12580284503318612, 0.08304128798866466, 0.13937253745332842, 0.16675527778364, 0.10970052722240649, 0.22733152002817203, 0.17351877695370108, 0.06579959825161966, 0.12256211691325712, 0.24388229804894618, 0.13893962116731753, 0.2203607634310761, 0.1218935443208583, 0.20960421481680488, 0.16210046626867788, 0.1991152913580018, 0.14521765041976206, 0.22126186669113176, 0.23327941135052713, 0.12750217360594582, 0.175026468632202, 0.09648773984442796, 0.08102300636951001, 0.17042686141306357, 0.23512042788488252, 0.12398063595737181, 0.09951528867766743, 0.13081349672809725, 0.25224477593456546, 0.21796427186458342, 0.11012266465132275, 0.22474882313080374, 0.23235656651518038, 0.1982673392781327, 0.12093856209708799, 0.1148275246903781, 0.09796537789365939, 0.15663213066516385, 0.2257300132224637, 0.26071669714104745, 0.1784457028993676, 0.12892663749235292, 0.17981526892512076, 0.22452543189208354, 0.12880660683637665, 0.2402150045118986, 0.18460791497941942, 0.13424590770756045, 0.13226823640927193, 0.10000071263000851, 0.13019541699078777, 0.1438870629475963, 0.12372920590062296, 0.17451896602588315, 0.18595377824479536, 0.13961759365854726, 0.1449979670465954, 0.08677126283967689, 0.1257794333862201, 0.13930096951944215, 0.11403477690633267, 0.1543978811992753, 0.09005909770606987, 0.08623712335623081, 0.1466920325953153, 0.1404662352175482, 0.0953949920292343, 0.08747463880647575, 0.1928742641523, 0.13266151530608056, 0.17816160685352742, 0.19165828343360655, 0.14178320164642028, 0.11400749651534904, 0.21038671234442344, 0.11019234800891531, 0.1296764383873632, 0.2472115476285258, 0.12179303358519271, 0.17978991141482709, 0.22306686177128748, 0.2106717889828067, 0.08488161504388818, 0.15663937785692755, 0.12297787282976413, 0.1290409990976895, 0.1817341659578585, 0.14042529547887464, 0.09179411831522181, 0.08199005447808774, 0.1058954987374525, 0.1585851645758075, 0.1538753326261236, 0.18038211270205437, 0.1651824686315752, 0.1643648536335076, 0.1433839883294798, 0.15082521484263484, 0.19835721671340928, 0.22592614705283798, 0.2189178674692108, 0.123680459726001, 0.11549715448411242, 0.1343184868775068, 0.11710754024886316, 0.10598106309771539, 0.13739532580779446, 0.10814531510996242, 0.1370868528442037, 0.15570639001746334, 0.134378440918461, 0.25576571603455855, 0.10548502116674378, 0.14374219572111485, 0.109288479171453, 0.09385094181784699, 0.1701521116398996, 0.1118923200955314, 0.15938909724354744, 0.1561083563513333, 0.15938350480170022, 0.08484871922841958, 0.10606901765230203, 0.14552281388351995, 0.1100879149030774, 0.12786162206001822, 0.18296180653475946, 0.08346967669504304, 0.12602258203250746, 0.12890478866475244, 0.17158759187065786, 0.11760019607120946, 0.12702013576223006, 0.19245187391436872, 0.10670491659473028, 0.18670354849628865, 0.14494853905372082, 0.21916235676936566, 0.0942460056995192, 0.09106526226406136, 0.18424811412490186, 0.13956844145732542, 0.11252125529872795, 0.09054360235290182, 0.17437858807463802, 0.09339431511057962, 0.18150933447384066, 0.2167691593809474, 0.16502718260932356, 0.08025553182608659, 0.12554030670153518, 0.13475324177453596, 0.11550512179852494, 0.1688872391898786, 0.11266932477273288, 0.17061625366970418], [0.04096364827766534, 0.06760479251463568, 0.009544397377589298, 0.017072336425283746, 0.017038979041840763, 0.05466832539006587, 0.049714708941117416, 0.0556372159401015, 0.047037315915428826, 0.053147158224976836, 0.01924758371446402, 0.0697237074435238, 0.02346942531726053, 0.062231922957805864, 0.0442577765563563, 0.02329836362942813, 0.0552752432263186, 0.051527177208974484, 0.03081612998709804, 0.044446057985506715, 0.044102030881350084, 0.03793208514370265, 0.01847946374196439, 0.03851069986159283, 0.05613195552160183, 0.013432312745510811, 0.06497305832923421, 0.04018336474414795, 0.02267962122606414, 0.06327592076793795, 0.08025708698457287, 0.05707717778521681, 0.015789504959097794, 0.019741440379631617, 0.023607981894465706, 0.05260195643190415, 0.033558803280034376, 0.041458839851041, 0.09291881199685798, 0.06054722666439991, 0.020057463139716177, 0.057177983464733254, 0.04073813880583452, 0.02882873703305039, 0.0065644963404103635, 0.04860883803978082, 0.008685315955400227, 0.03906078163474318, 0.05153915116323098, 0.03591376905059142, 0.04534739490237929, 0.050767122227097713, 0.026545354518138116, 0.044560021225122676, 0.060825963925209746, 0.034796954583256476, 0.012384044952810773, 0.03707603934491354, 0.03202004673620386, 0.03229401509968504, 0.0953623643445392, 0.02757655482949509, 0.12851504143327475, 0.01665232105991773, 0.013403719471346949, 0.034830574351813526, 0.026921522841157935, 0.029589634711643862, 0.021669695176364436, 0.08322524102104288, 0.026098815273613702, 0.019303701570137374, 0.054418450491803314, 0.09166198347004191, 0.015397755365308016, 0.026831250870600346, 0.0331578903170603, 0.02822253357378706, 0.016295004245494644, 0.028557363792412707, 0.11953368707890473, 0.09430718548115223, 0.04912938712345016, 0.023007979916949427, 0.00995424005293077, 0.03237893211565191, 0.0358129863537127, 0.015611446973296906, 0.01877639367575607, 0.04230041807938007, 0.06134960417365355, 0.04104489956291453, 0.0063252073408465, 0.008299216260052016, 0.07322301322053518, 0.05441027250321162, 0.030998269306315534, 0.019922422906083447, 0.05337764726831548, 0.009737698597863559, 0.03407989245569033, 0.05326470292563881, 0.05180253219159861, 0.021156512028087052, 0.033027211038936535, 0.02274088336214904, 0.05383600916473135, 0.007681653153286466, 0.028464682475333253, 0.0745185291875274, 0.03142026117852619, 0.09173189665401175, 0.01577025891522006, 0.00783712399424985, 0.027028501274124272, 0.01595733758632935, 0.015622820506142754, 0.06681347731500864, 0.02837073902839855, 0.04130148922183341, 0.026593725309677185, 0.03345590618048464, 0.06608971574854466, 0.017232092570573572, 0.045850415894341086, 0.012526160966034138, 0.02177551681656511, 0.03762714384544281, 0.03532543267694212, 0.05054472307223947, 0.07444356748413655, 0.04530205015814112, 0.02080440078110945, 0.11983044655813326, 0.0624739186417672, 0.0744088177358912, 0.0712016825714419, 0.07628985470341099, 0.02852776981589775, 0.048150790239413904, 0.044375248478665474, 0.04447757867315123, 0.06136717440019693, 0.04048054940217445, 0.04577223279122864, 0.02813009357440376, 0.032976112974387024, 0.03599686660773812, 0.12230601372017015, 0.02839212245758503, 0.11968504307010483, 0.024055572594666196, 0.04055022892932739, 0.01140336718245019, 0.06273014057848243, 0.06407806462037467, 0.01765539445313475, 0.04386440572899677, 0.04129119300013108, 0.027935601087407242, 0.041554589350257194, 0.011740819336996685, 0.018955501202013225, 0.030282013486289693, 0.07889435446310429, 0.02364633608639481, 0.03340028436674226, 0.0265124567874497, 0.012658731523720969, 0.08310799126423175, 0.022470421766141252, 0.008259872857090688, 0.0057912967261678034, 0.026866546456491756, 0.0547715787205004, 0.03312139771878719, 0.01633449033233187, 0.11201981244789017, 0.0731845019805816, 0.016451540906282685, 0.046060687877357974, 0.036236173323085236, 0.0901195420432956, 0.04656037255640953, 0.027699667074146773, 0.018572386376739993, 0.02175261078762912, 0.030376989236702363, 0.002980861280511524, 0.029352587955673377, 0.08563804259944348, 0.02265068800038388, 0.020864975353282307, 0.10407300620910623, 0.04743251003204815, 0.04146810185404555, 0.05257049703129357, 0.044855631572464784, 0.023915321047928546, 0.08507725091711169, 0.046757506131525, 0.05759835889142367, 0.043534589555835536, 0.017420486997692816, 0.021933920816668583, 0.04333531859541132, 0.0399427097140541, 0.06662218516031582, 0.0332365675468839, 0.03288659560043485, 0.052312869323237296, 0.015365225356823255, 0.06976354401558638, 0.053587375328906124, 0.1444289016146814, 0.023460871945585937, 0.020782241687899636, 0.014150933862002868, 0.05964027815348199, 0.0329844480110032, 0.020208506950087125, 0.07790840696543455, 0.0582549958339622, 0.09382638869987381, 0.00815847824748245, 0.03788453406624256, 0.030489395402612227, 0.10171265101000186, 0.037276808007229725, 0.014125499742916756, 0.03203559066018751, 0.06356132682412863, 0.02790869033384708, 0.04552266815857542, 0.03684673390741791, 0.0762907510262824, 0.025471036863182823, 0.06589527497248304, 0.0871963803506186, 0.017904028288959976, 0.030047582920580625, 0.015401771581251056, 0.02498481617940049, 0.08389993465595669, 0.05470241247225673, 0.1338840690591643, 0.06975776771263731, 0.04598843812521908, 0.012480873678390299, 0.04705195968610145, 0.036551648330303936, 0.02186309790328866, 0.04010543828049014, 0.04485835118459598, 0.016179575862723495, 0.057476554741902705, 0.05072573049654884, 0.020392272290923906, 0.031891278847451174, 0.03721007025770603, 0.0366698173926242, 0.028782748774955833, 0.042663769751426675, 0.08083933678966376, 0.03520257515652526, 0.03959538460138344, 0.03130055610991774, 0.01024021684462505, 0.07978001339060646, 0.019055084971290444, 0.014941012787242091, 0.12792293207659838, 0.022486162957765406, 0.01169243130847932, 0.05991438058234992, 0.035579084388671384, 0.0324745552103606, 0.03796531037697869, 0.0750194740812144, 0.08777390339321668, 0.014073111777824741, 0.019048423836788824, 0.06616338276334348, 0.02104017774634544, 0.06209444464935411, 0.021400461236255306, 0.013122555627036962, 0.0379258300358009, 0.05773703612747693, 0.02618455008843974, 0.007455088874144901, 0.08317782017852991, 0.008366078498863406, 0.02820707583469489, 0.050469102533233744, 0.034447982381548614, 0.042526211003742875, 0.029072042727362246, 0.01753622756129311, 0.053145656692645246, 0.04156715319221539, 0.03801518653128897, 0.04125642026924799, 0.021450911956508795, 0.04315914135546454, 0.027539118027855313, 0.037162059527491374, 0.035819122717986186, 0.029672429664060477, 0.040996536432254704, 0.10472101700161734, 0.050388655640305056, 0.014209299228124082, 0.016643229511476332, 0.04019311704342404, 0.0394391869345019, 0.023968713545811274, 0.04895113378522858, 0.024282903440536994, 0.03573494880730587, 0.12116680267236887, 0.051739590407739726, 0.037397194894090775, 0.04314289646103017, 0.02745142777360255, 0.018087136709401687, 0.008816215483802221, 0.0031882283538805264, 0.02053432605950342, 0.06906109501517589, 0.05605643457402626, 0.005260260856424969, 0.052195500822797905, 0.06249349984911181, 0.007532573400831391, 0.013135165434270618, 0.06665360242609056, 0.050379458754774065, 0.08503354560103148, 0.04668184345768345, 0.043194722309107744, 0.0462668689508592, 0.010141281377253755, 0.06037892863875436, 0.03766147224532981, 0.04958638538336081, 0.017337933362972353, 0.008367592480123765, 0.015184717804884479, 0.03530686270565756, 0.0313378454396321, 0.06845660567764314, 0.1254874772782768, 0.24617092443570016, 0.15619366790258116, 0.107605422306205, 0.19371202726277614, 0.11693404431665137, 0.23266356858995654, 0.14506973416334198, 0.12790829979724463, 0.10446848377825753, 0.08885938103400892, 0.1535382386176817, 0.09730870264672464, 0.24471358005558294, 0.15402562375510895, 0.18728635754556427, 0.22290437452254758, 0.26135494031252404, 0.12441978819908635, 0.12226944834354425, 0.20947476127935996, 0.13015744967326043, 0.1251163000180837, 0.14083944261074066, 0.15392650729946553, 0.1415395703647406, 0.12221949175000192, 0.15060240583073708, 0.11853028809831989, 0.0728904161482088, 0.15863329021921083, 0.11308753983147683, 0.1988213127779384, 0.12127850595260821, 0.14426845215982007, 0.12589277609461738, 0.19055753766048342, 0.11396522378368724, 0.3292848758639828, 0.18572393654575273, 0.1620480505328986, 0.1202336079891651, 0.13698150043285665, 0.14014168972930602, 0.14773872320450124, 0.2101058951548992, 0.06372183373558425, 0.18210282278878076, 0.15639798355198678, 0.14528174133550736, 0.10798593051731588, 0.1290047018518371, 0.17810672431463198, 0.11351929166384282, 0.13620519289566627, 0.17741415018756546, 0.05758042860355589, 0.12325105978356254, 0.12013528826496295, 0.12464857269679347, 0.18705214914535323, 0.11879341631767251, 0.21141114043852977, 0.14091386039170528, 0.1318781597599868, 0.09696414694190027, 0.18813236376210568, 0.18528282311895203, 0.1771846455672095, 0.18547109688722319, 0.14102868164979643, 0.1451626759503157, 0.1915848922104605, 0.20709138513813097, 0.09002653130840871, 0.14049450386195414, 0.08580165599743206, 0.10020709671680966, 0.08097520248303491, 0.10804986821547632, 0.2018327584430095, 0.21864342413121657, 0.11767336512885748, 0.17986437516106715, 0.10619860142469408, 0.12206536252051593, 0.1376574044866908, 0.1804614181239759, 0.16110882673773075, 0.13987398796504544, 0.12969755177055636, 0.1311064487503421, 0.12790590194204163, 0.18109819040663783, 0.12791586108505726, 0.26005332628565453, 0.12971103491802372, 0.11303610468824064, 0.13615285376867942, 0.09961894803470182, 0.1999593823547325, 0.18960668465062497, 0.17902909417546567, 0.13473142359045245, 0.12028661361264607, 0.20066393809693478, 0.1093704122749548, 0.11005997567647889, 0.17308480346635466, 0.16170272874014993, 0.09772741566261939, 0.16187797901370835, 0.11735717765986921, 0.10362846070840474, 0.0778225438308812, 0.15638319805504816, 0.11012300173000944, 0.16192840292088448, 0.1212882046257296, 0.1416876704822625, 0.11331437846585629, 0.14446516821701683, 0.09566834752237606, 0.11892408793491703, 0.24461837064835334, 0.10947007265302444, 0.08579266212520101, 0.10058100125001324, 0.12977241388251706, 0.16298163592094378, 0.12793822319156703, 0.16437309673957287, 0.12601060041737172, 0.17226703525070222, 0.20797381117459268, 0.17429336845394106, 0.19555900396118242, 0.145504136659926, 0.09167740481995768, 0.0837684433246332, 0.13784287437315912, 0.13932173050219013, 0.11747530841779326, 0.1545332949007711, 0.24855961722712366, 0.05845175402599478, 0.13070321071051783, 0.08955361757187114, 0.16790038004757898, 0.10090211466435464, 0.1436750404536724, 0.13655583133860943, 0.07511433108799881, 0.16866348022895475, 0.2277692473463474, 0.1444971294052178, 0.14567552585034602, 0.17001184094096386, 0.11794893461610041, 0.10413536576614266, 0.22928764893402978, 0.17324364413657498, 0.1776409888219449, 0.17001554880651737, 0.15291145612155238, 0.08891773395120137, 0.1422601679880773, 0.17480811825202358, 0.18565158720218367, 0.14118649576219822, 0.12115411625634279, 0.04100212504366233, 0.06633874795009052, 0.1493260267400934, 0.08484914057677792, 0.15372864211038237], [0.01096813060763863, 0.08652257537769695, 0.02513697464770127, 0.018331045697953914, 0.02284625875613382, 0.02380845752815085, 0.026635404323197664, 0.01767175043031814, 0.06501709306312185, 0.03162480090864964, 0.04167511413294462, 0.01602509997845177, 0.03526786499987206, 0.058583953988648234, 0.027007891593741316, 0.03333361556513175, 0.035097261049574426, 0.035599849201859005, 0.044020358247742544, 0.061635615439304424, 0.021088862633933465, 0.03934171373745607, 0.012239033127233628, 0.0656865160131166, 0.0285296754596094, 0.040259755201517575, 0.03697165986523032, 0.053767038268908385, 0.0283792311130392, 0.09288066847910804, 0.07439477534423913, 0.039509019679239685, 0.0214348949732319, 0.009639384619320833, 0.03612401422053095, 0.10256205865692708, 0.030613700829205975, 0.05004830958862459, 0.05886338838946916, 0.019564385969011534, 0.043853017832002336, 0.049915768716844826, 0.04531167988334933, 0.031074721050719102, 0.06503608438276476, 0.027283487894061594, 0.052879498595552105, 0.009922173527640202, 0.06956254552689291, 0.006619922801732056, 0.04025297149294808, 0.028805107051025958, 0.03449751762673259, 0.028731541542877114, 0.015408262261189522, 0.03932714657557588, 0.06210733024824051, 0.011075354188740736, 0.04498498551847954, 0.026265108064117453, 0.04990704297538727, 0.041375477993560415, 0.15214267156777844, 0.03507668009748863, 0.08500752159424367, 0.044444200222290335, 0.05228560808445177, 0.038412690403, 0.046795959914884264, 0.02006443837026675, 0.041816491828930956, 0.029117546434844696, 0.0046517342355312605, 0.030995524796326796, 0.016783107590350895, 0.024113182406572085, 0.04150394710802263, 0.0012024469376023439, 0.05283223480106362, 0.0468942758086468, 0.00640526735937343, 0.072212252134998, 0.05406366368275016, 0.0287055520100459, 0.01871774198427316, 0.046699735441155014, 0.043337003988844734, 0.05274645210574231, 0.0423071519922345, 0.011658055028097044, 0.06548254510327693, 0.018048862956704635, 0.06714554578666726, 0.06823550504181655, 0.05545882087561393, 0.05602047440686053, 0.06873176147740695, 0.03872977419485969, 0.012231034211694233, 0.04323667328384134, 0.018685673543762778, 0.04246752866874299, 0.023284108648377082, 0.03403128034645512, 0.019942463766182625, 0.0370522638061835, 0.05990162904885027, 0.025588616037801392, 0.04295595568574725, 0.0437993188989499, 0.029590159481871995, 0.032688745733110175, 0.01792929961436218, 0.034601517892893285, 0.040548999358208916, 0.04843436151502594, 0.07274098303769866, 0.07801948971445523, 0.032929695707054875, 0.04967329805837043, 0.029150499706907623, 0.034756336601511124, 0.04461530212973876, 0.08945795617276624, 0.04402300508152093, 0.029498656024976127, 0.008914043954122932, 0.013598397734665103, 0.03353957064269531, 0.03204362309207359, 0.02357627734571936, 0.005083538736442044, 0.040507128822707364, 0.027627961244434122, 0.03997671252657329, 0.06525363803150193, 0.09842412666447702, 0.06872008629744092, 0.03768631647671423, 0.04556153179897417, 0.0483429710560989, 0.04037335071892988, 0.03607270165136264, 0.0390728666717487, 0.09128784911046106, 0.027643292579018784, 0.058547170276963906, 0.12669209691305316, 0.08256087425134837, 0.002792895383824925, 0.03369502903472993, 0.04473966501292683, 0.01451756151753568, 0.048167261129785935, 0.040863432485850594, 0.016634685715900797, 0.12346728043931147, 0.02130432486263735, 0.03786774907982157, 0.06842010158805117, 0.03115220126816102, 0.034107931273719, 0.021594518968354792, 0.022513104354842536, 0.034226736189016414, 0.03477463078114294, 0.047909480204144796, 0.01847399004374541, 0.007913297074170964, 0.07518468860296473, 0.03898488530408471, 0.0466753738451629, 0.007264090705693009, 0.052171231157356696, 0.005432030696782374, 0.07500864159796508, 0.035462263641097856, 0.027168281676788485, 0.03241650489789825, 0.052221999804098765, 0.04812246796885326, 0.016121448941468712, 0.06823331403035311, 0.019488345996867266, 0.019072590080360254, 0.026974898102062366, 0.045098623170727686, 0.03150411524749812, 0.03511613745602869, 0.0441174790443432, 0.04050555068158335, 0.059646077439068794, 0.02947411822876142, 0.028795553934610182, 0.06896897294228116, 0.010880121469287383, 0.018346945852822354, 0.03842526190583745, 0.05458309044761043, 0.023919848627561045, 0.01581739726281094, 0.022683963029375, 0.007517516900289564, 0.026107925974253206, 0.013434375437246937, 0.018361321492721478, 0.01853364914084875, 0.011955349811262662, 0.040531632144965475, 0.036737382517106114, 0.027834412363928654, 0.07207590380623456, 0.04478449647825572, 0.10901536116556776, 0.06709460093970261, 0.08700027716376128, 0.044403111096471555, 0.046770372578213294, 0.06165400537992678, 0.04511558435737126, 0.03837608289153826, 0.017546556341732224, 0.027221095778288382, 0.03992235092746635, 0.0481876045946152, 0.030304616910495588, 0.026727811763844183, 0.02879637364868916, 0.04779053356258139, 0.008597670708813013, 0.033674551504513914, 0.06642577553828878, 0.03621398358635845, 0.005894679333939548, 0.10222814391337096, 0.054920529195618246, 0.013216391821662265, 0.009224483848459298, 0.03592051828520433, 0.03246226332961552, 0.04824981093406678, 0.021947091783306772, 0.05072782191658213, 0.019226179217859622, 0.030270956922322515, 0.03865077903854751, 0.03885000020325665, 0.036586501500419075, 0.07076914932939314, 0.053814083728338444, 0.026419430730804324, 0.06181537414029722, 0.04290440562932242, 0.05672394230421032, 0.020927493873563026, 0.07227120260077138, 0.011802502821439938, 0.12620336346087918, 0.04116553159791135, 0.04271319008342201, 0.024246039289620616, 0.02036445372317347, 0.06451789484990221, 0.0328262010589242, 0.11224577008115669, 0.01763162849050376, 0.03407853264962474, 0.04867350352146933, 0.06821387837971411, 0.03946227299410009, 0.0632957241407806, 0.018276969466598767, 0.019750995411267205, 0.028795456258399837, 0.027956319935319406, 0.062326795286348755, 0.016153844884566722, 0.048591003512903574, 0.011547415652462553, 0.07956286576846916, 0.013264022380744499, 0.04871268508835666, 0.0161385920739943, 0.033497627328840957, 0.014121095694962048, 0.02794067258946598, 0.07294437172071588, 0.022085414703695044, 0.02368132140667689, 0.055602864557576764, 0.044769075128339955, 0.013901923685484837, 0.048982934094965465, 0.013382968064698, 0.03695280261097416, 0.013286820199761181, 0.02751821531884132, 0.004849236011655341, 0.04752632898969516, 0.05033339005744746, 0.11128239919461551, 0.009010999084209964, 0.05519164388158149, 0.0536726332539993, 0.017933030462553425, 0.041319258631237095, 0.03306947994015871, 0.025543150634715156, 0.07850126708827673, 0.024398990658923023, 0.055790414372759486, 0.0340538646184629, 0.030286447220151464, 0.027793610521081476, 0.03978370816536969, 0.010765553977821144, 0.03420077346926255, 0.016381710076764706, 0.004894595598847035, 0.1044551078830996, 0.07082341133706993, 0.08959359203976008, 0.048737000719073324, 0.10749561126313864, 0.10950946489409094, 0.05433281335318762, 0.045452605587460344, 0.03720076228942602, 0.03700524515983078, 0.044660351930126074, 0.059825265404557994, 0.08933270079714638, 0.07397532688393708, 0.08485437295730076, 0.02354260586622742, 0.14083544363177594, 0.04455463945745461, 0.04157993919967164, 0.014141048454949933, 0.04582402416534963, 0.06270830324220081, 0.04243265251599012, 0.07519903742978651, 0.02413102650954839, 0.03924520581119484, 0.042371874930517334, 0.06664642418224005, 0.07265963982189856, 0.0269265636996997, 0.022670405188335047, 0.019375861306945165, 0.038002140053938475, 0.13318311393020615, 0.1479666956490086, 0.10206232418216045, 0.10547552933736194, 0.09835149386837598, 0.10301505410743338, 0.11265381915314544, 0.08965516252623451, 0.10634598908044639, 0.15988759065587677, 0.137019973368414, 0.15251715066692523, 0.09372079880127022, 0.16207495554079934, 0.1083588238144594, 0.16314551744970585, 0.13060573368303238, 0.14857912165743692, 0.18520420717616237, 0.08921326768975105, 0.12425022995880536, 0.12469361866674117, 0.1542252969116934, 0.10452844548009096, 0.07451589384506788, 0.12941858851380889, 0.1418699534429658, 0.10135189254557896, 0.09683273988024843, 0.1342225573476284, 0.18160196982564467, 0.13961033114502508, 0.1712702782524209, 0.15479840728784763, 0.1671237507534604, 0.23314358396155221, 0.08257243451812575, 0.22772444652453547, 0.11371963131692141, 0.14805553120470819, 0.15554356569003674, 0.09444523452510757, 0.1846262398025682, 0.1470617006622976, 0.155606139751692, 0.10271479360639088, 0.15784877021947216, 0.10747407653158712, 0.13498145936717912, 0.10474261302020281, 0.08036935716987618, 0.1986259450354884, 0.10053482146993761, 0.11106993236969556, 0.20295328460633758, 0.15320751846076983, 0.21359096701827743, 0.0662215901238303, 0.19640274255746798, 0.13116111678461875, 0.168352325957629, 0.1687527601156504, 0.16181975633146303, 0.21221386268734935, 0.27900070312523073, 0.1365548047807909, 0.17465177502843643, 0.12077200692147018, 0.1658946546095033, 0.1781206211495784, 0.10657498042189306, 0.09812856994328961, 0.12450329944371216, 0.15017856002574967, 0.14534929496867044, 0.11920768602360642, 0.11250160514347016, 0.209345338385432, 0.0859006881834038, 0.11495438885063895, 0.10417726311472156, 0.33259682717823214, 0.203011920976062, 0.15727170682962865, 0.13037817492600412, 0.1589883872938733, 0.1670376271490128, 0.10924151032081536, 0.1645993378253714, 0.11785741009178663, 0.13470854820503345, 0.14993897368831022, 0.1590818806641525, 0.23366761874527703, 0.21753222891880622, 0.18785300213963757, 0.1798835886462081, 0.14198477470105694, 0.1559688670620803, 0.1090393320567185, 0.08685239155085818, 0.17085945594214624, 0.1407628797835881, 0.15506923469083925, 0.09802131763389034, 0.14168413115605233, 0.1546209660028258, 0.08639698292339042, 0.09869829421081851, 0.12415197918251639, 0.15985489402326847, 0.1619208492939511, 0.0841973912751963, 0.09040769069425522, 0.18652417666969762, 0.18510743494956725, 0.2201391954816157, 0.12632154018407868, 0.12090339866136351, 0.18545088748778069, 0.12418785508001044, 0.1004003577174679, 0.1872545955402236, 0.1944916596215579, 0.18499123473321238, 0.14970989807719184, 0.16701173337717212, 0.1014456310639939, 0.15577826438651932, 0.0689556123688817, 0.18184852756319508, 0.0957314272020613, 0.1516425234055327, 0.12124605446813569, 0.11955626369003328, 0.0989659806533206, 0.17204470121331755, 0.2256558865549103, 0.10636754679463564, 0.21427227965285703, 0.11828988204680144, 0.06950486676707383, 0.10878893621866742, 0.1844274859514929, 0.23069319044870717, 0.19889363147799047, 0.15963603802506002, 0.20585413781865952, 0.13145213826529442, 0.0936738835767873, 0.09333400100830103, 0.08152429600276294, 0.16178949585845395, 0.11014488120112689, 0.12637921894389775, 0.19166450406755173, 0.24846212487787972, 0.1853425779770459, 0.08473228152480819, 0.3318521284287976, 0.15700487840560176, 0.1307180574944904, 0.1056788337507075, 0.12477336075877953, 0.10209066177447958, 0.11556650842389754, 0.20961524648291452, 0.22163542648476942, 0.13857670999582739, 0.12641441302313922, 0.12568387157854535, 0.17270388922864394, 0.1255964686072642, 0.1640261048751493, 0.07402942035227053, 0.17171923641956624], [0.02533052484655092, 0.05802881986563725, 0.05139549818610953, 0.032737162489924705, 0.041480117943137884, 0.06007259306047232, 0.08689124753037769, 0.04484269234742369, 0.07998920135921048, 0.0025990318071337478, 0.08056219682217607, 0.016486233197933724, 0.1062428123588043, 0.020448189048517137, 0.043228338247225176, 0.047553789411340995, 0.009082925164200848, 0.03502591528118618, 0.06725457542005085, 0.025276291567171295, 0.0065423846488908656, 0.046940539858394095, 0.02812737396227256, 0.06215797632091469, 0.017724512820883144, 0.032730214072451476, 0.07243212703014575, 0.022486567069145463, 0.05328729102808622, 0.02706103511304865, 0.03581539953067418, 0.02319511412943323, 0.03388813681780331, 0.049017036498914805, 0.012011729094440178, 0.0049527033679037085, 0.011692077950424245, 0.008484805847758488, 0.04095496467104362, 0.011340616920572377, 0.053450506060354175, 0.03845279127539646, 0.04035407977719461, 0.059528119050927704, 0.06100518253421592, 0.02972400653356266, 0.04531077589959868, 0.06172876790045731, 0.013233447811686465, 0.027683046796629508, 0.04688213714548657, 0.019797182852222074, 0.01592920683774977, 0.05140456866713301, 0.026234822693250837, 0.03867874890866299, 0.043739747901957844, 0.04402290932053039, 0.17715754137644846, 0.06628431740307039, 0.04284380041363259, 0.004536019048593458, 0.03315735022507368, 0.09595607482497731, 0.02479287859563145, 0.02827218373215968, 0.10843587693788352, 0.04047846564302041, 0.017169302089079734, 0.031216799717156157, 0.02590583964070726, 0.03047388595258517, 0.06419302760473182, 0.009699539758355148, 0.013125483998127524, 0.028564572679780187, 0.04532543882246941, 0.05602828850368819, 0.022537044602476304, 0.052900623470064134, 0.1471339887188327, 0.043241296624464375, 0.016940113479992556, 0.008177189945033001, 0.09707837831228973, 0.13108754170037087, 0.052754158950260574, 0.024193596740763997, 0.06643961108620129, 0.017209433604993166, 0.0454637291841209, 0.04208086111072091, 0.01844299221110921, 0.03622886867472722, 0.02764740264073255, 0.026263508855575518, 0.04169955616816879, 0.0466155615304747, 0.10419410172729723, 0.030463377141483852, 0.021970986065665082, 0.053728967529511264, 0.08681447785948554, 0.018123728899104942, 0.0604232315034155, 0.008150203540290316, 0.04611676168297568, 0.025222728614725416, 0.04342633367125546, 0.01177449560453815, 0.03845034362447839, 0.023281925297792883, 0.05831846621848884, 0.01976362437069897, 0.02903406008807642, 0.011242493506400816, 0.011802198301490036, 0.02133896352813369, 0.02014702839416362, 0.026374564791518836, 0.06153398238482976, 0.09411686625812324, 0.03100277198809049, 0.07206180012754856, 0.011797673594687256, 0.026535883756174196, 0.06206806824212113, 0.03889965802250851, 0.05147140600808686, 0.08166887977671239, 0.035182427044116685, 0.04830081706806537, 0.04503763874151534, 0.04045055705993887, 0.024282095217776876, 0.03666520171288041, 0.06828104130803578, 0.10903079017636277, 0.0765717214333915, 0.038060634697396914, 0.03950411671652429, 0.023804583038473805, 0.035898987384092425, 0.025720115030004133, 0.027294389325224107, 0.02045759086256787, 0.05470186088895125, 0.011029908895462511, 0.006293010101803849, 0.05008819212596263, 0.09562642719115942, 0.0266603596373311, 0.03516079655157463, 0.04187566446020238, 0.03183837664583999, 0.019663230463441823, 0.02710705401466018, 0.059702836893378734, 0.07613408604576703, 0.039612464531655275, 0.02562218026498393, 0.019078109743854692, 0.053318535924078, 0.03011970243777239, 0.0937597926766161, 0.013763891878507793, 0.04860624866259675, 0.0654927034291529, 0.07017924630593869, 0.08168597885918233, 0.040173409431571924, 0.04402786207896087, 0.04369515009344586, 0.029038792596228664, 0.009183532618466885, 0.028703269068031546, 0.037986538673360506, 0.03698675562777827, 0.04433895506325268, 0.08716782059280143, 0.06002162906130957, 0.01717677336156128, 0.04012187469690558, 0.01582843658979982, 0.05512976312949773, 0.029253787511298736, 0.02390580049024955, 0.06441614305179927, 0.0640204586389084, 0.0011593392898043198, 0.044287232637044885, 0.027957626115230304, 0.03541269775239691, 0.027490496342521042, 0.06089665851886235, 0.056463380479404045, 0.055347025664823676, 0.08297196469239651, 0.012938941588565227, 0.0026218095163424173, 0.009497421823682324, 0.025933742478129365, 0.0197287482179461, 0.021139165882261533, 0.07017921566242172, 0.04519108615274872, 0.043771103880698645, 0.011280881214676606, 0.05968531263211082, 0.042568518209361264, 0.047625905098093134, 0.06301550449983728, 0.012299451608991912, 0.07417453272688775, 0.03362601600407112, 0.021712601845783573, 0.05867809087278382, 0.05598807271810309, 0.059461998002183054, 0.061505277070306966, 0.06297538830568233, 0.04024515356568079, 0.015240203638020304, 0.05110194861528374, 0.016570106419103763, 0.06205225235692436, 0.1320242374053886, 0.06254271716780721, 0.11078265705896963, 0.07949278404515597, 0.02596106500394883, 0.049738737288862474, 0.05267273912566805, 0.024135894998307192, 0.04162796142120515, 0.03929664861531027, 0.050687525691764976, 0.07160706565745416, 0.018826036173249447, 0.06939051282261649, 0.033099728921848925, 0.04540965486798556, 0.0817949855099282, 0.029933376448048703, 0.06317202392364703, 0.021430193108596632, 0.03402360414545383, 0.012666527425960429, 0.02488660753794736, 0.040509971008906444, 0.05383609343440302, 0.03631685004239121, 0.05381659649673009, 0.026043049818385514, 0.08048146647671539, 0.019816153104447072, 0.08325727881803628, 0.030936848206986344, 0.042440727082712036, 0.07485267375746081, 0.06683049978868616, 0.04825504331458961, 0.013256561641971911, 0.1026309835874746, 0.05501846970629789, 0.04298613571952428, 0.018046486168919552, 0.02529786268789922, 0.00698897943478979, 0.04521389259025455, 0.06958696840991897, 0.020708701077608332, 0.05648596858185145, 0.009795631124307553, 0.03764032055774043, 0.027153944341285575, 0.0377282444688101, 0.05357913605328049, 0.051226192754843546, 0.03091875321021484, 0.0857560431224204, 0.015012645838601936, 0.037520592506494255, 0.04576609259651554, 0.01955025164680856, 0.053621389632744175, 0.022075576219527472, 0.07442109812531741, 0.04530933565430103, 0.05988448017066526, 0.020222286956625122, 0.04672214351294022, 0.054096858272509235, 0.08653388283545933, 0.050266430142425725, 0.022919768722908154, 0.045197038655920375, 0.07001072228435548, 0.02662807669220192, 0.08115213815002673, 0.05137145451660599, 0.011566578384278523, 0.009573883144184947, 0.04699987719856924, 0.10230083799650593, 0.04914000893252031, 0.02163942129681668, 0.0651708392486457, 0.036903945353603175, 0.09060711104182467, 0.06573605891917983, 0.049420653752261595, 0.022927975439797008, 0.07122557685380021, 0.06757653919198821, 0.052666104804243774, 0.0158609340395478, 0.0227654134974845, 0.0020577911674345456, 0.03369928848358893, 0.02725911480675061, 0.0343656164383696, 0.026927800931697412, 0.012372604387271549, 0.043735488453098846, 0.05943826459828885, 0.01877519091771495, 0.04467984503735939, 0.018136468941285726, 0.05371908499528805, 0.032113643528352824, 0.023083219327212825, 0.014225814168551757, 0.1387391666010503, 0.04583284566779772, 0.026385303428997437, 0.018876530943558584, 0.020990002817744692, 0.023048172719896804, 0.010805227756199819, 0.027411644827694665, 0.03503200568018421, 0.050209827736140265, 0.04304817735007213, 0.05056121694524923, 0.052868600994829214, 0.027972267970683116, 0.027609293596939217, 0.060882834462268706, 0.0012687408349349074, 0.04554279328834626, 0.06166511748526847, 0.3267951820406222, 0.17194984420653314, 0.2223221783436114, 0.2151323665654467, 0.17474692314863208, 0.10229633339951116, 0.15625852490625075, 0.15056718110797868, 0.19795292147224952, 0.09551728264458718, 0.20269149704085243, 0.1222857277119352, 0.24544821240969245, 0.16644678949829073, 0.08883427633273025, 0.14317064816432615, 0.09958487244382982, 0.11853523702631075, 0.16110957750389654, 0.12324903731144245, 0.15601533795556716, 0.16177668686835997, 0.20410358094640318, 0.10689479914764244, 0.1474506588232133, 0.14626682315382267, 0.1009335166083709, 0.10224743400730434, 0.1430667972853107, 0.08177461523202159, 0.14593915202684943, 0.1085650393619172, 0.21587711128015674, 0.1330170567117391, 0.08598934753888077, 0.13968603595370246, 0.15728007250976178, 0.16279690147888276, 0.13228984008873665, 0.14497676173285132, 0.23463126542347096, 0.09273685079308287, 0.16066665610959455, 0.1423845193799465, 0.1509382128114662, 0.19150926401057553, 0.1327346000940569, 0.13070520253912096, 0.08653358406116886, 0.3444177477109817, 0.20530696717962144, 0.1724763917586496, 0.19525882006893236, 0.2220914633043351, 0.08996956501035921, 0.19771707364388053, 0.09853129470420462, 0.19324921822595983, 0.2914722774538302, 0.1393760921012971, 0.13179061123200003, 0.11361990965181783, 0.1394950042689039, 0.12828665530128827, 0.11590647526205548, 0.2396157705375264, 0.2531516861410872, 0.13121840483959646, 0.11010330560947619, 0.16352443985881346, 0.16816066608073252, 0.15467724282174342, 0.170693643871815, 0.1345162754577975, 0.13941585206456725, 0.07126780362018655, 0.2457906690336043, 0.19568353921415346, 0.17746152506480295, 0.10807914809594232, 0.28546158224344254, 0.15288997501615556, 0.08732573429663336, 0.1310752689718239, 0.19765495923497986, 0.30430964344451505, 0.1854014594949061, 0.13620039718526025, 0.14847314105399195, 0.14035041804515547, 0.14225010159275225, 0.1440524766522069, 0.11388323705403075, 0.14792213997533246, 0.13822319106228892, 0.14097776744634877, 0.16847794905545252, 0.1352433848284906, 0.2539186167620844, 0.18272304757227822, 0.17799502869527187, 0.13653750651546065, 0.18228288409450363, 0.10899220232761676, 0.16810737700471956, 0.14363779325879392, 0.16488735624138387, 0.18435394151076195, 0.11138728429232875, 0.13382002410869445, 0.14178025986879103, 0.12777654799602686, 0.0944425378956141, 0.08437682438882128, 0.13849984073350508, 0.2044260579972498, 0.15987772344341203, 0.09477475192397834, 0.1500434374376651, 0.13507840013311756, 0.1323004274238502, 0.26795598287736216, 0.14663053105675405, 0.16142056323587894, 0.06994778050049659, 0.09751359286207346, 0.13929989699634815, 0.12084650897210646, 0.20050852950061523, 0.15491025612479256, 0.132526898336026, 0.10024773002031351, 0.10780368586100879, 0.19571441255750197, 0.1497738357753523, 0.13193247539381828, 0.12710088909032846, 0.26874018112017267, 0.180978741977484, 0.16467703446265192, 0.11431547918266828, 0.10131615454391127, 0.12666656320253689, 0.11255828032810843, 0.13565098956948327, 0.09421160069083977, 0.16648017561003087, 0.1412412404052673, 0.15986566521948384, 0.11679107698822215, 0.1476891419940418, 0.16328679938470164, 0.09436825034959663, 0.19265945309833174, 0.1870652952141339, 0.13473430408104775, 0.12314039838290024, 0.1344049322388826, 0.16103958771113427, 0.08318999331564673, 0.06749675879555364, 0.08990388063173141, 0.1653922388270017, 0.1013592929549275, 0.15859112473985842, 0.0936472160561431, 0.12645857033109473, 0.12660519189892278, 0.1831891048218935, 0.20212002609285618, 0.1444688147955364, 0.09343775229588633, 0.31950622316329713, 0.16866562527514276, 0.12542501812981022, 0.16029435270015271], [0.050336745522555806, 0.03016774764194364, 0.025880030138538252, 0.06289076240312669, 0.05669053704027207, 0.016406943097770695, 0.03528399881155741, 0.05499962011292096, 0.06203460169114894, 0.052094174203492945, 0.024761363653646364, 0.02429327435581194, 0.020775237729051904, 0.031305914894948085, 0.07369615678345004, 0.030517732994931362, 0.015932235757880393, 0.022425877583783962, 0.026080285521945166, 0.04200501840621714, 0.00939667551598001, 0.051378820451997945, 0.009885772859918015, 0.03637991440031798, 0.03320829507203833, 0.060916163117414525, 0.025680019903267105, 0.029946830867218877, 0.07241172610872215, 0.06600048182712448, 0.01198809240914641, 0.04781622815156176, 0.0528267725941635, 0.03596771313177963, 0.0288576434456533, 0.021385051377658403, 0.018665512024815527, 0.03136155203044896, 0.03235287363490751, 0.025920977538091042, 0.04420007098345988, 0.03538189335696159, 0.059891558823085604, 0.05130491594994261, 0.028931178310285174, 0.012622610478091144, 0.03171400035611324, 0.05488584073440683, 0.037528364468486085, 0.014410230684124175, 0.032655972491709456, 0.09030963910082657, 0.024032172439019048, 0.01748481348547484, 0.042026997468764746, 0.024589610571462302, 0.03561602131794057, 0.08047010539279831, 0.02656912814164835, 0.034515666249658794, 0.008580830181017518, 0.032479469664394855, 0.02602429981643875, 0.05463370204632802, 0.029962935950607065, 0.028752049716610103, 0.03256276640440187, 0.07307615416545062, 0.044128920567492326, 0.02087796054359886, 0.018149737584134264, 0.05351044094911026, 0.032467461236181765, 0.08073301910753213, 0.034058150880399256, 0.010788041531228492, 0.025367000207845724, 0.049049549270421273, 0.07666532971685933, 0.0486493181256998, 0.06086133037423415, 0.0873209615688651, 0.031822229427615964, 0.1098093270294128, 0.0545396494318641, 0.1004905952140689, 0.09157210603476533, 0.009068938313923296, 0.04017849242494952, 0.02426560709042655, 0.05418467110082988, 0.034369596265136235, 0.029737139195804636, 0.044645662194177996, 0.06890312002431001, 0.048017743749604117, 0.026859224571155447, 0.004264083690941334, 0.04734405752031073, 0.02283416605824905, 0.047609625729702176, 0.06428412311980802, 0.03574940105599742, 0.14272654699462076, 0.05255687981843949, 0.00203385355322802, 0.08835039987799623, 0.03383331939638142, 0.02292639346823337, 0.031688472391256405, 0.03340287374392633, 0.004843290211753019, 0.03869817689842275, 0.06306417789610644, 0.07584419071434007, 0.046815430039479855, 0.07012955784316986, 0.03505476998285421, 0.02939765882347861, 0.014022606473806647, 0.03794255373518794, 0.02996249353483079, 0.038251233542518276, 0.05989586040678044, 0.030261449771182194, 0.02137835193876057, 0.06463733561817678, 0.04077037578568824, 0.02595680172465021, 0.025030473104467797, 0.020833538935309457, 0.04471377507152577, 0.05610684315944391, 0.025529627267631794, 0.07117566622553334, 0.043623088032848416, 0.013739104146107793, 0.095239054832247, 0.02820677514518461, 0.0164968779896416, 0.02032135361655345, 0.048340197817813006, 0.032714417339452816, 0.029617047252794428, 0.0381831398173686, 0.05223670869224495, 0.04218999033553466, 0.022598337382078174, 0.01513150916810358, 0.02789629886167184, 0.057721764164706396, 0.03286199651718621, 0.040579118104952, 0.014944503275347094, 0.03223507612523052, 0.027214158852134022, 0.02886056415586462, 0.008830042413225579, 0.031655478899577455, 0.03021470691648222, 0.03725738767834921, 0.05331764343164621, 0.04577534693864085, 0.04938477785476754, 0.050352392868409236, 0.06314754358402665, 0.0689894198289802, 0.04614049508686989, 0.0861838955672518, 0.005355925607164541, 0.05601199764397837, 0.03722032817501215, 0.056276248182140054, 0.04452564302952059, 0.07429325337251348, 0.018415639041772774, 0.03816235968242249, 0.039427975237730055, 0.009799832158962326, 0.051999167809563304, 0.04456774339139943, 0.007904926605988294, 0.015381906921374462, 0.024594253064283443, 0.037059671876411286, 0.03766797250136733, 0.033445127323390014, 0.03783780270286145, 0.05642727858597233, 0.025898556059767163, 0.0410237402144459, 0.027790188023279754, 0.017604315540783348, 0.007715926011798964, 0.01850474464346565, 0.04044989439388437, 0.05754428074484872, 0.01648174009225782, 0.04484601333857544, 0.027608504526377208, 0.08919884225413685, 0.03769990687649097, 0.03557643372445338, 0.015538683942248745, 0.06524097459811358, 0.048359782855597236, 0.034468502046600465, 0.07529470648977064, 0.023606673799334996, 0.09870104446646669, 0.011530562675738288, 0.00903521703871628, 0.03672767618310548, 0.04147383602215879, 0.03349245240491244, 0.05008962087994141, 0.029861053917557005, 0.0742842901437994, 0.042833251382915244, 0.030005275714962237, 0.013820797847133252, 0.01569465752841244, 0.04916724335822848, 0.04012905294075608, 0.015496948429743852, 0.11421318346213911, 0.05346840953514461, 0.09286907756881368, 0.04158955743356098, 0.0339308385587027, 0.010631356440905121, 0.027464495318370964, 0.04686398469212075, 0.06549523151930302, 0.008294373626760658, 0.030521670686862165, 0.01858873469304414, 0.019905118895093762, 0.030800823550370914, 0.013979078315558934, 0.06671996096209173, 0.021415344409404263, 0.040336685750873826, 0.05814294398371732, 0.026674633770580256, 0.030786298523326556, 0.021348290648611806, 0.08039610896019206, 0.025080236260809248, 0.013830907334904037, 0.05039194981837946, 0.0657445548342601, 0.030274946325188203, 0.016975472268137722, 0.04502248552237307, 0.03826791510706948, 0.02425984227879634, 0.09818850100160607, 0.05229555956658818, 0.055774483574374076, 0.05932524747725937, 0.07082022441130492, 0.04583196083624517, 0.026996695218727957, 0.0478044955150014, 0.05817146160669866, 0.05003203022023363, 0.14070756823545502, 0.039453022482414404, 0.027403585582731232, 0.02955818297191253, 0.031488506206040906, 0.056160576566452944, 0.06051859029779031, 0.044710323845426884, 0.04210714558740297, 0.025289351451060465, 0.027957762095836863, 0.05948256746294999, 0.013037940258190278, 0.04778728918022206, 0.056024075020104654, 0.005881739630093498, 0.042475135921831095, 0.06867923848931828, 0.0536829601192186, 0.015038076127248426, 0.08787773895047366, 0.04975944847589539, 0.054896182921384616, 0.024531874355048906, 0.03391864626938778, 0.03682000126930014, 0.0434610604368631, 0.06024733005512146, 0.023984445161336375, 0.053201508332764914, 0.020464133253441225, 0.019545892606519406, 0.05149492490736227, 0.01448116563786302, 0.007344415982163722, 0.02579221347977798, 0.0012649498967221007, 0.025213623659745343, 0.01476863342817993, 0.04102085206297137, 0.052934017242683526, 0.02490303437826374, 0.10012617484936792, 0.02828896105770142, 0.045158741920585596, 0.006529464576047876, 0.07016033925596746, 0.047861971261520544, 0.023945420642473528, 0.0340443957717188, 0.05670383632663758, 0.023318015699905735, 0.06216166120383048, 0.07653999007156781, 0.030825947403847694, 0.026293380538963025, 0.005430979719911252, 0.013749636897456743, 0.007170922443976687, 0.019884378979763678, 0.04087305838061918, 0.009902765647688461, 0.040706637270388105, 0.04818770035560574, 0.02046442436685245, 0.03173648120625125, 0.03782255372272865, 0.04207885779079892, 0.056094907509583625, 0.0889380889073495, 0.09640304116351951, 0.057036881560399655, 0.043778864351371606, 0.03869126295490611, 0.018891753110614036, 0.02771129054317792, 0.03576304508192885, 0.05741505703378109, 0.03556448658327422, 0.05750071332459489, 0.020414653549631758, 0.012872066900825069, 0.01514063902094119, 0.0746052043752805, 0.03053290919671136, 0.13489289960313228, 0.10950853026682332, 0.06063442662238114, 0.24766710947357842, 0.16798464971924984, 0.09203706777864888, 0.1735271426338342, 0.11527783883314942, 0.0958007428374502, 0.14752064861597555, 0.10256063373338792, 0.09455083208459039, 0.12008595986351853, 0.16476496603460083, 0.1612975295152395, 0.11675168474715565, 0.13103514128635008, 0.09106389862755615, 0.19215794129958078, 0.1307986346223662, 0.1445773847761654, 0.07908769207255495, 0.08997207011787162, 0.14641504584541246, 0.17700988558992264, 0.13989355385063157, 0.1278750209378139, 0.10008587862455076, 0.1681597008099479, 0.16057910758160776, 0.1604187347355389, 0.11196453154327408, 0.12918733721298556, 0.18832845162720452, 0.08998863293879455, 0.1496789787685679, 0.10432900214988379, 0.23320137763455992, 0.14349274217121064, 0.2323143091052771, 0.07438752049159619, 0.18525976387243118, 0.1629391180411462, 0.09447833718431574, 0.075161506782376, 0.14902962732218927, 0.18297378814989523, 0.2778417040263453, 0.10839590246999457, 0.28154239899689154, 0.1507022730525463, 0.11384918444579649, 0.10294532478456536, 0.09548077089411598, 0.10298729108105745, 0.16998712694452656, 0.19021292066862508, 0.2017522579239261, 0.14819521967682148, 0.10218984717803617, 0.10494607831201247, 0.10889315481988654, 0.09684855959588483, 0.13810176612629046, 0.09595962181206673, 0.17662756175043123, 0.14751997445860218, 0.13636608668152364, 0.1253815426401073, 0.20522059842703805, 0.11695980019266568, 0.11644171791211252, 0.19562114901360006, 0.14336647555953072, 0.15033764584410578, 0.09882174927981631, 0.12556732662262457, 0.13174521286160717, 0.1482516343915655, 0.13119266428534063, 0.10677515153562832, 0.16068685018727857, 0.14089395742743246, 0.24931632823521094, 0.1805600136398308, 0.20731312162693472, 0.21278976162354793, 0.13756260876694035, 0.11871083203943507, 0.24305498437775722, 0.15956223311443485, 0.18746968238584458, 0.16685514500544918, 0.09806280129499013, 0.1530353631824255, 0.08751785382628442, 0.1668398232469636, 0.13211838961128267, 0.1363999018025014, 0.14904870291150388, 0.13851283358470087, 0.14159923329228355, 0.13571098957571293, 0.26201160023770026, 0.10620092267110463, 0.08987947307046383, 0.1854149732858904, 0.12043607736667318, 0.15507265144298155, 0.1224687078126496, 0.09120862795821122, 0.23649197041748032, 0.22216479324044722, 0.11201937577777332, 0.1953032072032652, 0.16658751984998105, 0.1454196831271533, 0.14694663425607069, 0.2154201857985989, 0.14219238452853697, 0.2260091450185545, 0.10502314675719508, 0.15376239594432617, 0.14552918773504997, 0.12463495931437901, 0.19335951956529773, 0.12709636151069595, 0.1760407230786739, 0.18533850238928873, 0.16181915878288208, 0.11591841857279502, 0.09244848763750446, 0.1704180054366589, 0.21708883254999117, 0.1104479915492477, 0.1643418709957792, 0.08741149017887731, 0.1745719639884849, 0.16085443958159418, 0.13526057584151147, 0.09569129185570825, 0.18555418678349067, 0.07797478082319421, 0.13803735345361695, 0.20874333117277394, 0.11230385486757564, 0.1147480583899925, 0.166399659769189, 0.1407460564927709, 0.09442942247035042, 0.12216811023292043, 0.10003003081487072, 0.08000141280072351, 0.15153943861444152, 0.19888482146686126, 0.07744368270880754, 0.15828573144972324, 0.13834006543601715, 0.16367509871000246, 0.16791429220428392, 0.1954589682000299, 0.1396444833446895, 0.14987298287451267, 0.1568977333485119, 0.14751042900306566, 0.18029655600267072, 0.10194366482356865, 0.08453900520239147, 0.12955873663867676, 0.10511928313081303, 0.1265554038447238, 0.16123950601585452, 0.14215490750728116, 0.0994539326958118, 0.12743493406883172, 0.20019365204197748], [0.02350687744065879, 0.044412917021902344, 0.03104811098666922, 0.03026382272852765, 0.0036767820147947682, 0.05059528487524198, 0.032296259737303185, 0.057569462054919814, 0.07721653763925837, 0.049194194331404664, 0.018180543894789392, 0.06873457302008906, 0.05206188359748452, 0.008401400897832168, 0.029748820121430104, 0.03949548290561765, 0.0036277052253529795, 0.015315150977262567, 0.029883460074122396, 0.006392514868263877, 0.06833764754476086, 0.03287050392358534, 0.03296766302458221, 0.009601351226710025, 0.044610912445932634, 0.05389669098921361, 0.007146613037724409, 0.013854704898661904, 0.028855320284022924, 0.11171374500038163, 0.016716479008356412, 0.024227779583945393, 0.039383051841850245, 0.056458370264379255, 0.06598263963936798, 0.037045732906629006, 0.03914015217413826, 0.0501331614871179, 0.015371345441728352, 0.038374041267220056, 0.051496955040361614, 0.14598808972345245, 0.089284383631762, 0.04009763184454172, 0.06466899803208728, 0.07793923434350761, 0.026761444938939907, 0.031221509242670673, 0.03644147339547354, 0.03674808093496869, 0.06657880926204306, 0.03429577603275257, 0.032559035556210626, 0.037078728313527765, 0.05046669701715151, 0.026262654667539943, 0.026862039944277178, 0.09230704482404456, 0.012383195552824727, 0.07891742137050436, 0.005958269898509306, 0.10472067992293066, 0.04201457918351216, 0.0711460416055014, 0.022648857050244848, 0.03593415848069614, 0.03520339487060424, 0.01672024241528444, 0.03599410103033147, 0.07107520145514319, 0.03446696987075191, 0.047190387943579305, 0.0943960746630065, 0.009133113499340272, 0.028421360203215194, 0.055541677115064476, 0.027564349133641492, 0.011999744606474716, 0.0639033391170444, 0.031948974844248544, 0.03460537897603166, 0.016744755313641602, 0.07947016146875198, 0.03961396989442649, 0.036324660308779254, 0.06936270383096511, 0.02190670937359814, 0.0396223125919219, 0.042421513597571084, 0.03596877799399438, 0.048193070631954944, 0.032198866979489406, 0.035955291016087416, 0.03615511739025674, 0.008092819724322088, 0.0752159679729131, 0.06478829324365624, 0.034663161157720515, 0.07713324089925136, 0.027035087715053273, 0.09378358736754426, 0.0285518498745777, 0.04829645802777621, 0.017811944520461465, 0.014990253088575219, 0.009507224876283398, 0.053242915385072274, 0.04419401505841844, 0.021989787778546734, 0.06466460068740192, 0.0761954496885019, 0.01566673266596251, 0.04965864662681857, 0.04940873725459941, 0.06454612518991194, 0.04952347807345852, 0.04426415806876556, 0.009427929988070842, 0.03155646778102363, 0.004852308981841611, 0.010313536247028219, 0.03044472290052762, 0.038947630448326956, 0.026196997101989486, 0.0157766021232331, 0.014974747468987781, 0.01911316592726977, 0.020808807701893875, 0.013331759875009378, 0.04651887357355126, 0.050263021051162676, 0.019108998408961683, 0.03607217305069489, 0.04150928674085487, 0.035619323156894214, 0.023966568499623288, 0.12477683879795576, 0.021828861433952566, 0.08552135208681708, 0.02057540752444296, 0.028200148484639587, 0.04661384166308469, 0.0552698040020562, 0.01638627596079342, 0.04623013886532957, 0.03148690316705935, 0.08178272810313972, 0.023933973373664964, 0.020126378494164637, 0.028565001689017783, 0.00872805695830574, 0.08393990912384565, 0.010164609712158, 0.046931929030125184, 0.049147731098797054, 0.025117295764146313, 0.04500034175092175, 0.06329888425346825, 0.021124447418016293, 0.03146050186196883, 0.04127892410202373, 0.030620088087274667, 0.025151968903599248, 0.06335202011189635, 0.016843477234004006, 0.04574769116457432, 0.025460045416689208, 0.03663669941165755, 0.07273929764426525, 0.041254022414044994, 0.02052639704948712, 0.025838734168979912, 0.033112461303150466, 0.08122082559331771, 0.03869083394566852, 0.08128068770372099, 0.03024063324705968, 0.04118964038488846, 0.05074931451329782, 0.03651913555879747, 0.06195986598369576, 0.012381804145632253, 0.032832414031990116, 0.11270228187523543, 0.05731480676800974, 0.021041121949712117, 0.04060462883283054, 0.039743898406384454, 0.07289236201153648, 0.025123367010946238, 0.08173428070280822, 0.04997967960192792, 0.009425978379083738, 0.030860743117368514, 0.08161734504204604, 0.03356204383195408, 0.017869962274187037, 0.10350477581302966, 0.007152921292975906, 0.055182615535393845, 0.019812698047908566, 0.02638150937855244, 0.02205328689137053, 0.035867627574912006, 0.03404344965313231, 0.06465787443542673, 0.03378606326277218, 0.07932181620309431, 0.07831962764142983, 0.05573726702301253, 0.09517919272184373, 0.04781350470899094, 0.013953122299074406, 0.03005131376877187, 0.058962501014672944, 0.03194104583423225, 0.07685297529303259, 0.03298818652007369, 0.02706297331549708, 0.013934432626551679, 0.06939312518243829, 0.07113153190021554, 0.005806445636065497, 0.039904359352564624, 0.06281803767647474, 0.03996353964471529, 0.011311310227029027, 0.04154775201553299, 0.0381806691838128, 0.021247004248922872, 0.06371284369379282, 0.036154048697602366, 0.04870379463799539, 0.0778222373957115, 0.04550543884115835, 0.04066369804223219, 0.09748095751649911, 0.01580656573717152, 0.03883623360325733, 0.06132539579524629, 0.02616535000983746, 0.037032594498727596, 0.006245140140245279, 0.03028140253117008, 0.011031177728587102, 0.020963676206226793, 0.07803955355719214, 0.061967829467668656, 0.07084404974575005, 0.006915792661358513, 0.015227842809362038, 0.01998653680446648, 0.042735253415641286, 0.04768297481801241, 0.011936260815409404, 0.04187192978157152, 0.0258830102205637, 0.06418519052526643, 0.0389396746252333, 0.058578047450752034, 0.02958156780580119, 0.0361551633555322, 0.009018712631997564, 0.07400562566134238, 0.02024302304151558, 0.04143282350513243, 0.035039333311179956, 0.05252758078577538, 0.07482638928077875, 0.015337347417258689, 0.06442645459526009, 0.03528549268300976, 0.053463349524404735, 0.03846696007155603, 0.060679147004961013, 0.11123353044592565, 0.06947005573179453, 0.05773978255268547, 0.017641269707030827, 0.037260938495878256, 0.017531138822256077, 0.04172669483288642, 0.033681070912749536, 0.07615277859111948, 0.04802722791810671, 0.00788841358078043, 0.0641752850084055, 0.07800059032536323, 0.011665284025272536, 0.05766635302514319, 0.036894005362785635, 0.03180615690296456, 0.04391496370155965, 0.06908433812279856, 0.06456449597833619, 0.013982811078969992, 0.04674833222863175, 0.03120046863783031, 0.03513820844912722, 0.0041436666393682604, 0.03795998989634457, 0.050192632892679785, 0.09167984864043613, 0.037550841488184473, 0.00623143291206009, 0.06893737947628384, 0.06039220877292176, 0.05920897831299132, 0.08644287159005482, 0.03578441510457666, 0.1100336682171591, 0.00836212931561374, 0.039019746135079095, 0.03173137331501611, 0.05716574137970325, 0.0541982768223651, 0.0261021439256447, 0.005664765335349066, 0.0555345218538517, 0.05953720102327005, 0.03967305442558662, 0.028681025705150062, 0.04943767239549949, 0.01860008237042254, 0.07243417248490357, 0.009097133222366533, 0.03912298414375513, 0.060112398989017934, 0.010274601743496474, 0.03498887876048684, 0.05682017060837919, 0.022479250929468585, 0.047067813875694434, 0.06566999915746913, 0.013504695605426548, 0.05899310622724795, 0.017241032816649928, 0.02598300001644079, 0.05512528151514069, 0.04412199896309645, 0.0299147088005538, 0.02299421906260954, 0.046080062240963025, 0.05634867030406191, 0.044505548543266715, 0.020311070801389795, 0.08348761081335046, 0.08602340780799428, 0.05294531703956666, 0.028207951090148384, 0.03972859963053658, 0.057241151244529796, 0.09564287509889373, 0.15655984260862874, 0.11060209779609596, 0.15305557258186803, 0.13191461022342407, 0.12869716351551394, 0.12327039584277139, 0.3032353430265381, 0.22943846100280363, 0.13280376251186096, 0.18625839012524775, 0.1489266497834075, 0.16275242241399904, 0.0667567178606987, 0.12114729807381669, 0.22900471734183453, 0.12078198138624431, 0.17593845034078245, 0.21329493532257698, 0.060177596901813825, 0.1612500627074511, 0.23682426871551623, 0.08834618639441268, 0.16086819852071424, 0.11435510125011207, 0.21637751991229676, 0.07625109831532163, 0.10132183125543018, 0.1048568826949885, 0.14395693016629066, 0.12704114189311383, 0.16254095150338066, 0.15586143089157922, 0.22904406361762555, 0.25347689046494426, 0.10427247252195113, 0.13405522842320705, 0.12190817660021207, 0.14293748164369216, 0.13364938568444024, 0.12527809778769172, 0.2587969727333515, 0.19860930560577303, 0.08564070858541997, 0.17894689294119037, 0.2232609271642662, 0.15578974038362503, 0.1929526196251954, 0.2018171149275957, 0.11735560717962443, 0.12840526103372538, 0.09043856403760372, 0.14091998909509953, 0.15845137498071118, 0.18635485591667314, 0.2135167790636901, 0.12685750295678455, 0.20932728935393596, 0.09445848018531838, 0.21890675919430874, 0.1797450799494982, 0.181552097501774, 0.1553188721018453, 0.15727418895450332, 0.10328462512622918, 0.21070675323567084, 0.06982934330740283, 0.13422540719470671, 0.10122256924308116, 0.18934629136516204, 0.18774866096435056, 0.1516593466963499, 0.1769452124473549, 0.1048209838148567, 0.0904055762915842, 0.17001432306583852, 0.1724396501818011, 0.15253893820749176, 0.2721865655433747, 0.1371937527531578, 0.0975571449605688, 0.2215095888823271, 0.15847832595388736, 0.13298520277584755, 0.1304048041422521, 0.19791807979345324, 0.17912441083500463, 0.12053569177946738, 0.1496787489421906, 0.14281450921008665, 0.1478072114649319, 0.08744753461571471, 0.12180398098163067, 0.2100977746229018, 0.10840143362480788, 0.14150456014660098, 0.13152358362511282, 0.09832146322174419, 0.17538417040580706, 0.19480407027707947, 0.1806963772903527, 0.2050209099486951, 0.13393076977902843, 0.17359034488758734, 0.23387084654983015, 0.16387120189685978, 0.23348533578457373, 0.13994252219075157, 0.14152175115962184, 0.1837679761792383, 0.16302467474052984, 0.2501189585534796, 0.24344440219142746, 0.2689933885009058, 0.1685028622347501, 0.11346908992216473, 0.148203186991234, 0.12075356718513275, 0.21590521138521934, 0.09417541069729675, 0.1584147559779306, 0.10863816245428978, 0.14865030654736106, 0.12010738734276065, 0.14655822767846047, 0.09346327834552334, 0.20976089511907872, 0.17470157074351467, 0.09113170506973421, 0.15420775349822738, 0.11888890917743407, 0.15542571072376546, 0.15589729912819403, 0.1506345508800399, 0.33036294543454725, 0.08535517229428215, 0.1591850267422776, 0.12159300036728383, 0.09641344463753124, 0.17616631553298043, 0.06699415149107095, 0.11175623989754147, 0.2744569130722554, 0.15741525638488033, 0.17851720954621994, 0.05622120093434088, 0.10306216085389738, 0.0891026369326057, 0.1820330321788788, 0.07345327626793616, 0.06568968761712313, 0.12782350918578525, 0.12644471946142374, 0.14008429442201892, 0.19840451498185435, 0.08475130348796807, 0.0911843199883738, 0.2192736080577297, 0.13076472757083754, 0.11488309670840541, 0.20668883657743856, 0.12900179071772483, 0.1829620976481707, 0.12723320779661018, 0.12780147649708296, 0.11183773633092643, 0.10251286049042979, 0.17826775599631572, 0.16142980225624579, 0.15317203326811715, 0.2091793424539989, 0.18268108127578614, 0.1306616121362294, 0.19222005570848144, 0.08605683222413064, 0.18265339485820264], [0.009755552276938913, 0.036384905463144664, 0.03669088864098153, 0.03484928221892446, 0.02563010544456061, 0.007756906927698442, 0.011923443206826286, 0.036347700403101986, 0.05038434639573098, 0.0795241247021383, 0.018697762411207925, 0.02697630195818361, 0.011253668813996259, 0.04085906195424257, 0.06199753069649301, 0.020530759920215896, 0.011199766867643884, 0.08455719212971388, 0.03214899465561875, 0.04490859889154954, 0.05338384875006253, 0.0291645631659776, 0.05537029941596332, 0.04103802392379411, 0.03210979968219275, 0.05119035516174571, 0.05105758063314904, 0.02168169977413791, 0.09206908259300456, 0.02902597019959602, 0.07077618967741728, 0.03869599354783854, 0.016445368152832793, 0.019329047589112195, 0.04913282302779056, 0.022151924542061264, 0.021715110783735593, 0.03936335955175661, 0.03752207105618812, 0.07619535009707175, 0.04160706254263078, 0.09075334956569057, 0.04955758813828711, 0.018013084735420924, 0.013218668060407284, 0.11240350758476604, 0.025125247756800344, 0.01914802292782453, 0.06184149773851518, 0.033379125018273635, 0.02142724175486834, 0.042093057230475454, 0.04893857377371, 0.007923030221248947, 0.011746807271734843, 0.03463486186979759, 0.017995355545633265, 0.01896472681584137, 0.033237199569421436, 0.013724527408128545, 0.028210278082218383, 0.04384123923016652, 0.04787937294872058, 0.03493170178825817, 0.010017851206113496, 0.0528208124301126, 0.05592431888104447, 0.055519211586684956, 0.03971854472653039, 0.047768562160913026, 0.022093935516632857, 0.02636664918804121, 0.016253499516976938, 0.07616214784643344, 0.02537963682815673, 0.08841770070214426, 0.06808826294276984, 0.05015379223491877, 0.017222206205910733, 0.046383187910842325, 0.06895139888529817, 0.028048859526132865, 0.02558132096554243, 0.019815775806144364, 0.10967385970176229, 0.05500296791715007, 0.03882773768817706, 0.027718953337640535, 0.05673683939441558, 0.03086253384789152, 0.04191279674189226, 0.045145358364548416, 0.056594071248846675, 0.0066384736208185075, 0.06603333933819687, 0.06697748907871785, 0.10926543524669063, 0.05334639471144446, 0.017873696952817902, 0.04150491237880723, 0.023281138142450683, 0.04142303290146013, 0.014953582374859723, 0.013476505485032837, 0.04395548975275409, 0.023779834568079923, 0.09873994641126164, 0.08932594390165421, 0.06323703797534108, 0.019513383665452563, 0.0565361243582541, 0.03112873982547993, 0.04530398069971031, 0.03575909972911881, 0.020805385204092152, 0.05364490470157997, 0.0572864308712944, 0.04772290715106553, 0.030797868366203004, 0.05559002492396582, 0.08322986819210552, 0.061162341641442436, 0.07763103717156956, 0.07378604187960587, 0.018562913699556264, 0.009806907938552961, 0.03679780004125449, 0.03099531412214762, 0.06459430445946994, 0.09801839883889883, 0.054811105026953647, 0.025297619454983263, 0.029591877434042194, 0.026959350347639095, 0.03502876512826451, 0.023927681876586813, 0.0746263254193529, 0.038826140394854936, 0.025131602456132253, 0.06229224472096371, 0.066829863935709, 0.04054335329020697, 0.08559964627267853, 0.04543724552457852, 0.04161860365721007, 0.028948246749238144, 0.07923503376303181, 0.049553497228771455, 0.08039922693804388, 0.03204038062493407, 0.06517525191508955, 0.08527291743385215, 0.04572831680096927, 0.04137613299873568, 0.06202116833939668, 0.012344070484921818, 0.03631087838702145, 0.03687534729138978, 0.009867806182873827, 0.010635851461800837, 0.024517025655856537, 0.03718577377918748, 0.010509752431854365, 0.021251711859217575, 0.055295176834108374, 0.04916159345978691, 0.030687273998234062, 0.03488515811641851, 0.006547401567184997, 0.012859564345900812, 0.038354548159986734, 0.0039617183633268846, 0.05920987846630235, 0.02775715048154516, 0.02384163105049201, 0.05079382422169851, 0.052060048816905874, 0.04537933693838216, 0.0368782316124247, 0.04779878049908627, 0.03068086950318708, 0.060629646233733625, 0.019692960420563337, 0.03338789289456702, 0.020887831586503217, 0.019641691901450677, 0.05063797129438289, 0.025361890401390773, 0.027969582832508513, 0.06162087973808089, 0.046677296725852836, 0.05231169720871314, 0.020686446223407984, 0.07597925967626995, 0.037585836384565606, 0.060617653127279014, 0.06313547769921922, 0.06778859232942905, 0.05054600243907302, 0.04427026378952208, 0.049284523758556575, 0.024226731958708937, 0.04317673839508526, 0.048909420297751506, 0.061996642034500844, 0.07654386647646466, 0.05124233805784776, 0.05183615579059528, 0.03501935373811472, 0.07897984987545399, 0.02568114796773561, 0.009939807914047232, 0.03886832885684506, 0.046987359321886496, 0.022256748352740562, 0.01727377158409405, 0.03411651528891056, 0.1407941514926572, 0.013500095247441243, 0.028605571790267865, 0.03546672227281717, 0.08759844627591871, 0.05974686779682675, 0.06484596434259607, 0.035987593113414706, 0.08117609371941897, 0.01610827031395128, 0.04828232753601286, 0.05529533771257247, 0.015382018961733388, 0.05361056864081372, 0.028820777379517114, 0.028699314139122446, 0.05118106251522418, 0.05438826662758666, 0.03716333123344568, 0.07013539543315288, 0.04379956021664604, 0.07934533510236971, 0.040802007556081786, 0.01570831113044293, 0.03143209723695632, 0.0691748514110523, 0.04964792139587864, 0.009227444778286643, 0.03960075487773265, 0.014212180676329282, 0.05281369164285641, 0.04291977335308348, 0.0731700229188127, 0.11602898038202718, 0.06497013187336345, 0.04857751270455699, 0.06153848698182453, 0.05659245097288682, 0.03160810019190033, 0.04073047026571247, 0.010181722201166615, 0.02538174165472869, 0.021070453541113005, 0.02965473877866903, 0.028488592079450047, 0.05884025253415589, 0.054089932837673736, 0.03865573179697798, 0.01863118554014833, 0.08873413331926831, 0.022242359306302764, 0.007385044497618031, 0.02125366538342449, 0.038868777018280766, 0.09512116156157949, 0.08976467479501041, 0.01610243272396826, 0.041114422042042985, 0.036579782909323136, 0.041398307413703976, 0.07615585060369584, 0.056457140693260785, 0.05951265939661573, 0.029396344982688467, 0.02361140822270705, 0.08071854770664247, 0.08874992239138774, 0.02822009932940766, 0.009804429644117913, 0.026830486697895874, 0.08174572605639696, 0.02427270489504501, 0.014440004691301335, 0.018372424021964113, 0.049457433633506305, 0.10579140271030127, 0.08246880580460833, 0.09898039842805556, 0.037009814874299114, 0.06596709571538434, 0.025420233742484165, 0.043787846732283794, 0.02081778433714663, 0.022573677011795586, 0.05903550536341726, 0.03826317685325781, 0.05078581477245016, 0.054340098849347526, 0.07072867690435342, 0.06285169191898839, 0.02392101116598614, 0.027504105894495885, 0.027953851216983412, 0.017496875539842634, 0.06320548664417959, 0.02919395221397281, 0.055112817264612646, 0.03848892381234515, 0.053695845718105, 0.05045387653573867, 0.098414565887182, 0.058029723849387906, 0.03450395659573617, 0.013075643275383741, 0.012358960361340115, 0.053517500449332504, 0.050330214623001315, 0.08579566518986419, 0.025069558910364588, 0.0892053846450102, 0.041170936348217155, 0.030253744841883742, 0.10539008755116694, 0.04253146253646382, 0.023260551444705457, 0.024995482038526286, 0.01778784147914379, 0.034798145849978736, 0.032942098670548974, 0.034849826141350695, 0.07496737244148409, 0.055453029250906366, 0.014088517805982022, 0.039080604159783934, 0.05217283611155806, 0.08311208217374741, 0.01838309754196915, 0.1114225319977249, 0.03361866922087727, 0.031894031018319155, 0.016388756170448278, 0.049574262041959076, 0.038200441913138476, 0.010521870027596672, 0.04540143857499765, 0.12177449425742512, 0.1623359770183602, 0.1006022755116705, 0.09120000946906306, 0.11462711608938633, 0.07179961419634281, 0.16475980260199116, 0.07856658374470088, 0.1366991817110008, 0.11306071909324777, 0.15344143574756963, 0.12428495672441299, 0.10391170639664897, 0.11645677153982463, 0.12149718575059407, 0.10697567504980873, 0.1624969627347685, 0.18713381411808153, 0.10668381087241635, 0.14784144027338875, 0.1518350259791459, 0.11550614069546424, 0.11816567621163784, 0.20115048053764528, 0.1432051834079527, 0.1556035656962664, 0.11451497613903015, 0.17266955316787766, 0.17943654569887346, 0.1664122236111472, 0.14264972369757392, 0.10113289865154414, 0.10776823131187309, 0.18387634697700703, 0.09796970629043157, 0.05234774547599016, 0.18171771038924495, 0.20140319762210693, 0.12976029437155495, 0.25902085426834326, 0.16888464981269452, 0.2556632287920483, 0.1501933148791713, 0.11489959824229441, 0.1622037349208709, 0.32614085102273577, 0.15088342220312165, 0.27467978337118704, 0.14657275270550482, 0.1977977120587903, 0.09235980529938975, 0.13034777655716867, 0.1946325278690746, 0.11082735828935139, 0.12253420833017557, 0.16787494592849286, 0.08804392640388782, 0.11878009404866927, 0.12073032407751008, 0.15296048574870633, 0.14729797749990417, 0.15309151742727528, 0.15431571060851698, 0.12812486519255947, 0.12814999287647585, 0.16789736166115732, 0.2657100275879906, 0.2271674852818251, 0.11246117102282663, 0.11421902871300137, 0.13750234829081645, 0.141916056614249, 0.1429025939996204, 0.2076228662964798, 0.11462206756996532, 0.1941270937001513, 0.1765811827874953, 0.22598751069557285, 0.08931690406414772, 0.16664201934491435, 0.21102307093960626, 0.11427979480715529, 0.060270462079995105, 0.13536140833410526, 0.19329377389963598, 0.13483472288616244, 0.1539825389702474, 0.13001112687972285, 0.12785604493992944, 0.131575585673413, 0.19011979502054954, 0.12015241033007061, 0.12244216286607328, 0.2054592807807269, 0.1349861478252757, 0.1606297459934027, 0.2194471269725792, 0.1855828844371342, 0.10255475017812946, 0.13827275695098987, 0.09830545964500598, 0.14324025491312628, 0.17961970199981045, 0.11782410058883891, 0.1352599016841381, 0.10516907884589127, 0.3130431377118634, 0.2813713468851582, 0.15495997523107838, 0.09071460083848046, 0.2702311107948903, 0.12314024516531538, 0.1908510872313092, 0.1859469140969938, 0.057771387510001666, 0.16151163576831742, 0.23399859937208317, 0.22138791879819286, 0.08935336218846422, 0.13460492715239525, 0.18632257297154398, 0.16612449630854592, 0.1447522520057617, 0.21428234604818208, 0.15528334094391716, 0.23943341096803067, 0.10649863976023852, 0.13886313494895736, 0.2001411290538888, 0.21391698339533424, 0.140248175950781, 0.20361728365382842, 0.07203577612076076, 0.09133724645981867, 0.11564233580664282, 0.21800921058222172, 0.13324809350794362, 0.10320083042907138, 0.17711677017711824, 0.141136669403603, 0.13314418134189424, 0.1579278304932579, 0.1902493098450284, 0.1539165481564499, 0.08797645704039643, 0.11229273127091509, 0.10627999060576963, 0.13366024881120653, 0.24766283470296094, 0.13124328737537708, 0.18640311945590282, 0.14086369695442338, 0.1208728623967017, 0.2030794133221911, 0.10905153583735229, 0.15374869829224003, 0.12022328878482504, 0.08603202629714243, 0.17090408822461484, 0.0777260397350596, 0.19043065817846408, 0.19328718554348717, 0.08638161519962935, 0.11426414363086225, 0.08520436788638754, 0.09892979832065683, 0.2287222607241523, 0.11168592068697177, 0.20101469911394582, 0.182699850429931, 0.12210189725362486, 0.07263483389491036, 0.1408468583418477, 0.13691491207047818, 0.10760445703542042, 0.2007669769227505], [0.03801147100485621, 0.01207077244837438, 0.01755146888054667, 0.027461963397781217, 0.05389959829288626, 0.07366690754650101, 0.03764890074249237, 0.045064018979187936, 0.04777041609368978, 0.05195074339186953, 0.02944000050305359, 0.02655309775183278, 0.020834724456372283, 0.04239445920252512, 0.015949863441018088, 0.05529320415770335, 0.027291738661006096, 0.025699334895058025, 0.03596012120045001, 0.017755807512590004, 0.025948895697271632, 0.023356766342335654, 0.051830241591819835, 0.04288975419777055, 0.13252328240102337, 0.04211647270788108, 0.04767241812641582, 0.013794606258612008, 0.02438411897709293, 0.038425836471780654, 0.017695560443004774, 0.07409893517051974, 0.03605072258881504, 0.03435528191227106, 0.08536199047680824, 0.009739230773712118, 0.044355027587904085, 0.01067720871839312, 0.030621576213067582, 0.05361674713992304, 0.0752349746143145, 0.028787534909262776, 0.030632243987413186, 0.0404621058353974, 0.012071911046551842, 0.020816999097024242, 0.036164862028653585, 0.036770680528734966, 0.055370870151466904, 0.0533969794970847, 0.08623372958672625, 0.02927092872860451, 0.049140652446376706, 0.042419900982490474, 0.03101315247946449, 0.1119359871072154, 0.0159491854532051, 0.016876713958598914, 0.026014126168804306, 0.043210810155517636, 0.07181848294191784, 0.06770894216794161, 0.027715626600829345, 0.05409708426844689, 0.02903482426078089, 0.03411121779091416, 0.12935569269522545, 0.07332093457901671, 0.04270015126695076, 0.023684355114857038, 0.029959243406812032, 0.02988683277620904, 0.049154200711317604, 0.03341350704431534, 0.028296872830739426, 0.14009770096069382, 0.027811960242087805, 0.022240028483793143, 0.04889065880448588, 0.03330001877921243, 0.0920795779975672, 0.01954110455699265, 0.052288565183839494, 0.06591679438227607, 0.0547027112465472, 0.034466161647991794, 0.06222164971874126, 0.023488303638934612, 0.03888450480336624, 0.028729371598831592, 0.0652141155554883, 0.031184752344063697, 0.05425801635870049, 0.06086401168196913, 0.07885439531697382, 0.04285590460283622, 0.05971175032637774, 0.05687455519012386, 0.04507931775503582, 0.006915055301731393, 0.04660275254038073, 0.05966858127184453, 0.004475985526017124, 0.027113849214548548, 0.06783215974968287, 0.029924014853613994, 0.01763023804092119, 0.023471625904823025, 0.036265181242338115, 0.050904811209728645, 0.03189464005821895, 0.09977138420987515, 0.02037568457214342, 0.03657525149925101, 0.035347541974436854, 0.03257608867340511, 0.06293022359210639, 0.034897947954314376, 0.0178448460815895, 0.029507538814458157, 0.04321886173960182, 0.05042415232427659, 0.0905715185968626, 0.061285091909549894, 0.03048964438118762, 0.07704236754967321, 0.0564681685289308, 0.02846482803203887, 0.06996618959331705, 0.04425948876286707, 0.03609652315536815, 0.015996703014318502, 0.030549278580433423, 0.03386663272976875, 0.013960236383061257, 0.04594802315677366, 0.09765299022077553, 0.015134420302215845, 0.01941133117783935, 0.01758658635099569, 0.02380044999412231, 0.023490908337877165, 0.04318149963153466, 0.013079567560775867, 0.019536914056046836, 0.020468425261037006, 0.03462408684314259, 0.03225743440130065, 0.01939203916868616, 0.018338036250262972, 0.05167688228069775, 0.053465881444994486, 0.02788110159247393, 0.011464503871637487, 0.031206107044953014, 0.051741988262942726, 0.028374935275003798, 0.06552966717149943, 0.0703526349858411, 0.06414789736511246, 0.04964952251964039, 0.047550518215904315, 0.05594104641087114, 0.08487165590087253, 0.02407989397104229, 0.05478820282845728, 0.0044995369840293165, 0.051698528094998294, 0.03927401837802703, 0.012474154129684454, 0.05896320581556328, 0.029344827485000415, 0.04541759153888111, 0.05108156684605826, 0.0700930001274232, 0.0767574058244786, 0.028112425671650038, 0.028974659545647524, 0.023194725339811657, 0.010977543913008226, 0.0003258199473249636, 0.07949793981688638, 0.0736597829288052, 0.024963084180208466, 0.0355801071160503, 0.057336958200340314, 0.08980929941659974, 0.023492465411583265, 0.08086427295159909, 0.019740810272313898, 0.07468583512931101, 0.03848292151345842, 0.04066332648958891, 0.0472855820290504, 0.059581752866506583, 0.02788184086732086, 0.05528303051006891, 0.013959078632685688, 0.022934523576329795, 0.048399715188650355, 0.06304032574858397, 0.03668877423831052, 0.08267051675507138, 0.046694361334366184, 0.044450152725461996, 0.028945519476227706, 0.03714849594079199, 0.011029962521617212, 0.03686492849561957, 0.013317748126874288, 0.046570875621851415, 0.02577866521483708, 0.02859173241191574, 0.01787590711647945, 0.039567774792592374, 0.08847275178038305, 0.01497395073754653, 0.08022492661351159, 0.030477511463686827, 0.11843187644356683, 0.04419817108540766, 0.04528753662241563, 0.05669795660181873, 0.05208266373243063, 0.05674640783258984, 0.03736416884367505, 0.02028748869986063, 0.036721892219277165, 0.017348754354902816, 0.048164307860837835, 0.027728437506143126, 0.09617659323398145, 0.041600397577689546, 0.026089275563736598, 0.03718462847774068, 0.06269219624359282, 0.07045451701889116, 0.05320804689319865, 0.04537081421022454, 0.045419204153961716, 0.09558983883189578, 0.038159306822044235, 0.05860184597211981, 0.01877635345614005, 0.08230579761607994, 0.02552308679197825, 0.0168562728175593, 0.013354415010150163, 0.021494632594347484, 0.0487087014311504, 0.028706218506540024, 0.08068170653836382, 0.07258858516692154, 0.03482335014268756, 0.0455891186251275, 0.06421759221402389, 0.05338686330604458, 0.028171835790177988, 0.0306989855673765, 0.01758077748930983, 0.009415060668552836, 0.04306981550349344, 0.03391488477767956, 0.033317286401025714, 0.02347606346912442, 0.03350169908615851, 0.014991656944696462, 0.03732468467205763, 0.028850470947462226, 0.06398747472332851, 0.10253361381229856, 0.020091628745919275, 0.004150808972847318, 0.03265504552532108, 0.015391560586830302, 0.02503607703763391, 0.006092181588868581, 0.01862025729590847, 0.04125650070848004, 0.03302100189631024, 0.05283779276895428, 0.008251167225441145, 0.014803032691199935, 0.02714862769109107, 0.03149617474616295, 0.05451094028690169, 0.07642663204141202, 0.0399888128853373, 0.052544450041868036, 0.007063667261747704, 0.016973549387447776, 0.011344352556813148, 0.05593088042411593, 0.0073299536785681645, 0.03272086013889602, 0.025975233800108397, 0.0611806434819535, 0.06786633493198503, 0.03415242949080083, 0.013993135071359577, 0.031734194433797276, 0.06728946306412259, 0.052137527119127974, 0.018643649790676373, 0.019768096408956957, 0.023610192058127255, 0.11216549172757134, 0.006338588981663869, 0.0629209577586622, 0.03320631856519369, 0.0768763869399986, 0.025438840102945125, 0.06039109794543155, 0.0019050825522431444, 0.04750834507567268, 0.05754804606699655, 0.024136126739904288, 0.045821836984325806, 0.033251027456454696, 0.034739088131895954, 0.046962706612483154, 0.009742578577941224, 0.03550117707721168, 0.018523448680136955, 0.05088164088045878, 0.042298767159903244, 0.015233719661351175, 0.05983826974707265, 0.04271333564012762, 0.0248419618489401, 0.024415319823029063, 0.01796450901536211, 0.041723860307566585, 0.007590613658389738, 0.009638214420016495, 0.06929439943163626, 0.005563859106792558, 0.03305015920270835, 0.05355059927810104, 0.03079797370329259, 0.05808555633730947, 0.00970945006326562, 0.02209790768252025, 0.05597801015321767, 0.049767718395038005, 0.056838234961633725, 0.038378534372895956, 0.061433927471479105, 0.04504549880361846, 0.03308061885857775, 0.04003520333959211, 0.024976153640196692, 0.15660369348141456, 0.11961048739331386, 0.12208147334956354, 0.06048977007007888, 0.1301798347624079, 0.19489020920328556, 0.09334572981442175, 0.14183486661603376, 0.17782799088426177, 0.13630994775843236, 0.11721532115893019, 0.09834813074238839, 0.23138766447382592, 0.111398461515144, 0.11157224089988779, 0.15845989387842918, 0.15328657873455556, 0.19468292113273375, 0.11423228969497067, 0.16317882695265357, 0.11078431180888608, 0.09049273411472959, 0.0713893894346491, 0.1039149163050517, 0.1123727874590024, 0.09793447390679391, 0.18911192974736615, 0.12201480837839267, 0.12977506454673507, 0.14190943761458322, 0.09561415446261246, 0.1390981707241266, 0.12549528371422522, 0.1074066914377674, 0.18301802206664317, 0.11139175058492731, 0.11647577052034679, 0.15903498076142805, 0.08334913276015751, 0.14416576573444953, 0.1765726638897773, 0.13734733806021754, 0.13848954451180276, 0.19035464693461696, 0.1914053978098016, 0.11856782640660964, 0.1286322758683274, 0.23722508591749977, 0.14727076605683373, 0.07993335354953043, 0.16479806103292974, 0.05748647558052213, 0.14449283931284182, 0.140806638725823, 0.14233173592196358, 0.2239038281503224, 0.18542911526897263, 0.11884427689496549, 0.1258383915128727, 0.10455040156000084, 0.21577082424154206, 0.15567698756292944, 0.10324272777765028, 0.13295900256883714, 0.25203209460502674, 0.12192002031952144, 0.2503583916733342, 0.17705724514540166, 0.2387500298960555, 0.09111194766216701, 0.1308794568983778, 0.12373551080423979, 0.1336235225561165, 0.17931798593171183, 0.19756230856141738, 0.18188317005913104, 0.20396608348575332, 0.12902284281388407, 0.2317434816711372, 0.13724405408626603, 0.27835605545870723, 0.08260752900593704, 0.1388865159524064, 0.19369747159221481, 0.08113032762682246, 0.12174221897317518, 0.08626383684215047, 0.1578885455045008, 0.16024703910994917, 0.08999148278587288, 0.23797297159269934, 0.16529037977658934, 0.09878065632355791, 0.194144437930757, 0.21580569656385531, 0.14751373850289853, 0.15851776416022934, 0.16471829595825366, 0.17891369069055205, 0.06249345005339673, 0.22795016667054546, 0.08432406391347609, 0.13033547318510472, 0.13409717939794064, 0.24320015803940837, 0.08789855355937636, 0.09883978298955387, 0.1887474251129935, 0.14895140974512025, 0.1203637586666211, 0.17883288373629894, 0.18649624510397836, 0.1206667234580363, 0.10582675000712757, 0.12564356003196972, 0.06500031573758011, 0.20873142616643062, 0.12533377705802842, 0.187921766191721, 0.10901502408688107, 0.3050643626239992, 0.12716293455131594, 0.11460797921303781, 0.12572678782406355, 0.10191017912039835, 0.2533708332527069, 0.13784455976659252, 0.16193373489283747, 0.14185028030507027, 0.1462372981252209, 0.17039315354439521, 0.10635732718172575, 0.16874201956295198, 0.11042702372276014, 0.14245090855946466, 0.11414560684633833, 0.18391161766504088, 0.05825234133930457, 0.1400152392565243, 0.219716728634892, 0.10591591498063457, 0.09618564839324645, 0.16475854621779534, 0.10829801175503001, 0.10683428586250353, 0.11754692997783424, 0.1721669841677912, 0.18257100976282553, 0.0988648417255571, 0.23154400769741307, 0.11213836455417257, 0.20055651724819215, 0.2228675410151482, 0.12500912431747685, 0.06597042819785495, 0.2698663303688649, 0.11150025927852239, 0.19559626647781944, 0.2385605303871055, 0.13688564751177065, 0.15304164510340462, 0.16649627877819925, 0.11375088004335282, 0.11854976971423435, 0.22602491110803621, 0.12433090667811134, 0.1440601834967252, 0.2336725370297509, 0.08442654349510709, 0.16340344393205258, 0.13783568846842936, 0.10460396642766653, 0.14320726716710677, 0.2041929067983743, 0.1910138962369773, 0.1784168520281392], [0.0716065906829411, 0.05241158358272045, 0.02484135472426011, 0.012657089222733293, 0.044189617713733066, 0.018934903012949134, 0.05289568986383177, 0.021385495708654487, 0.047796329017728574, 0.02568557978637757, 0.06038491178544299, 0.0200448858912193, 0.024116120353761702, 0.030970027474986932, 0.018270381110449953, 0.04766132517327224, 0.05849659315220291, 0.01388264891330994, 0.028037594203206322, 0.03519088465480074, 0.08836883195345441, 0.07891103985809511, 0.03270970206827887, 0.012824339623142396, 0.045387296591915434, 0.04100074608539862, 0.03409107733938483, 0.006195685334293353, 0.054507895087402676, 0.033003558074274374, 0.06604835466151276, 0.021554215082658396, 0.014169102594737085, 0.04023823579172454, 0.011876504042095715, 0.02097322740742276, 0.054168284480129524, 0.10447694138894159, 0.03753548142530265, 0.09233037986221815, 0.04689932432806781, 0.02851307433429024, 0.02245529344485652, 0.026992083369423787, 0.07428635858119496, 0.06343753850688377, 0.09285738706708917, 0.01213968397238322, 0.021383308527630665, 0.02180059661998624, 0.031122352567411242, 0.063332021386633, 0.03653669429402198, 0.14139491764287795, 0.08824332376881953, 0.028949336509310433, 0.027289752578062397, 0.02714993770144159, 0.04673918896925546, 0.002603669033100408, 0.05415849770689684, 0.005736647365284303, 0.049020062546215715, 0.028450529000932173, 0.027329286545394894, 0.0640379062913839, 0.00797022219499453, 0.035139652524864486, 0.07233134816370665, 0.03421496524805984, 0.017953423723097772, 0.03729544309598785, 0.055768642153951435, 0.009172094925757377, 0.053574754030353604, 0.018830184539359425, 0.009783203262955913, 0.06478229477520912, 0.09315720323713557, 0.016162990059162823, 0.047510585882851196, 0.029061901638464584, 0.13483630102728644, 0.035308099937655275, 0.030425089982248125, 0.03347162630469088, 0.046459432811506336, 0.07900467878507991, 0.11278980742058448, 0.044240964756857966, 0.03312698633019482, 0.012862782872792695, 0.04178810827133637, 0.046323597761652166, 0.025726450577137933, 0.03946987258630895, 0.07317602138725982, 0.026142091580456304, 0.04906960545227893, 0.06889607967628587, 0.06144143513313705, 0.02270320907325274, 0.03990461982245888, 0.025144637442163886, 0.022452158230026404, 0.02753194361444443, 0.034490630496293306, 0.07592705844510948, 0.03587573278515089, 0.031386112809301384, 0.04222957026814261, 0.03448966139506909, 0.026506105918557416, 0.031037058253141663, 0.05061965413211335, 0.04294148428485759, 0.0025245848190670293, 0.01095038035043305, 0.053283276727362994, 0.028285747318859064, 0.024716220007488326, 0.033664316569845525, 0.050642502704455014, 0.029851688492682674, 0.05274251058337189, 0.012088480570744123, 0.019450418898955952, 0.04481749188515448, 0.042802163534947944, 0.007102459560208504, 0.02618280340797238, 0.006251591558177626, 0.05669044894016078, 0.03774591428678363, 0.07561395064957681, 0.07500683363046377, 0.054635253374374686, 0.02838887232956627, 0.023829023158478162, 0.033450034116545034, 0.03760312698901661, 0.07654305442326492, 0.021457607564967007, 0.06224868879202874, 0.04051626059076479, 0.07531202007685939, 0.0555003734846269, 0.019881216951856212, 0.007384627937309205, 0.026453552286951777, 0.031079844263712728, 0.028048034066394455, 0.08410621149044845, 0.025876080955288587, 0.1094748453807927, 0.03950068081218389, 0.05776614363815996, 0.04249478990752851, 0.04510972761519013, 0.04539415307883774, 0.018615363909292127, 0.03207908913252815, 0.03659468331945039, 0.04325512834193726, 0.009107307827610885, 0.054894413258279526, 0.05405922037278933, 0.014871733541029596, 0.03825574196995266, 0.016263562081862363, 0.035361553722571944, 0.04741565609771398, 0.021987709765052123, 0.05269803151848817, 0.06400907840279323, 0.026843462312113375, 0.03469619869945511, 0.01397580233207273, 0.04683884934732511, 0.05182841447212043, 0.01836151109948274, 0.059884445696708664, 0.04537168755045822, 0.021186106004602006, 0.06854196319416647, 0.03828669958297284, 0.049233383559171236, 0.023324023744451906, 0.018834388446843913, 0.05095567561746125, 0.017723285164984486, 0.03717136749577138, 0.052829208753762714, 0.01460917414196076, 0.0145510510511456, 0.04800095110230389, 0.027280410135825797, 0.011703009067493822, 0.022651136161819584, 0.03647400914961773, 0.013869694366510359, 0.029442314088584918, 0.05125313606714049, 0.0948397315017158, 0.07861375943907807, 0.04082582906008728, 0.051244866147997885, 0.017576851288697893, 0.060251260086173014, 0.07257347791305474, 0.03376995243372456, 0.04343428949434911, 0.025583437283433257, 0.04936177606484102, 0.05596856811955091, 0.03966429421017247, 0.03209768974732968, 0.046149285945801005, 0.026115104218103716, 0.02864887874062744, 0.03188506587438526, 0.011726884197654023, 0.0330182746232998, 0.030891105097027558, 0.04221159784543899, 0.07932928556035604, 0.03522296458662998, 0.04556296055295295, 0.09247052798708601, 0.04724098039009879, 0.01996252760891953, 0.06085922363244238, 0.06021415844800011, 0.03629510846710013, 0.029783431973849094, 0.04851123460778787, 0.06703057131099124, 0.09389270127059952, 0.06179006642571861, 0.0690146164608098, 0.022880024081396482, 0.05211388564578468, 0.03930283860573846, 0.03624529359982379, 0.07593318714850372, 0.0443917193690375, 0.03613174021724732, 0.03820169063645505, 0.013910667621530594, 0.017356616332225742, 0.028989031355107026, 0.013705280406640903, 0.02466886236722912, 0.038846732838259596, 0.12141987215727569, 0.02275527432380665, 0.021572543736246806, 0.06296567048036283, 0.08845877067576494, 0.028004382376468955, 0.0789464024766799, 0.045831750162066, 0.023162032537642988, 0.048797265025636846, 0.027689746235527342, 0.03716222040595547, 0.022345982274160753, 0.022077499100217418, 0.06786932267488972, 0.09912624624708008, 0.05012615178261073, 0.02077356191171754, 0.03457122677636724, 0.015350315370596947, 0.01951728305298715, 0.031649989879599986, 0.07932327177015044, 0.028291621298018484, 0.01560013664270481, 0.012491186179461019, 0.029277312156233578, 0.02121484579308139, 0.05983052459815818, 0.058781861312567234, 0.011467641959297321, 0.05188381412036477, 0.05552604892140916, 0.01784530190390445, 0.009840454928757203, 0.03088846017846898, 0.0408361406035481, 0.04005201130865082, 0.04858371035586442, 0.024385693287777326, 0.06852107197647134, 0.04355524328627414, 0.011193013802591351, 0.036967105472520474, 0.04573303973302246, 0.0531579792169073, 0.025997513552166285, 0.04712672986751122, 0.048970017852562095, 0.024499991690860163, 0.09460353893378089, 0.04035489949127359, 0.05693688793408294, 0.020737714742520647, 0.0024667181283040277, 0.015239914439828887, 0.03659834138928883, 0.02250827034004033, 0.06343285004878718, 0.0055228465897662025, 0.03637253697360716, 0.01383065548349893, 0.08487144905713298, 0.012689847142375525, 0.014769117021182132, 0.027906803842333537, 0.07015957316804318, 0.04032369289967803, 0.06470338005812899, 0.029784766882057154, 0.031013428271117232, 0.04198436467577854, 0.03751893775657781, 0.03560902693519189, 0.025651944696062037, 0.018792973733657313, 0.034301958362301516, 0.07000583464339857, 0.07764449733639918, 0.03446927196496437, 0.036422531871545705, 0.0161383411801991, 0.016789310987317757, 0.05885313047216304, 0.06433606388107424, 0.04999119773386948, 0.025338484500084194, 0.07295243862655855, 0.014306579945578933, 0.02536796930906994, 0.047680151784011436, 0.028960048333711685, 0.04775538161817578, 0.06478371203786905, 0.03261897044496671, 0.051469900645315654, 0.0759510063536225, 0.046611999221626794, 0.13830494796556814, 0.1742001508753146, 0.07688117498952536, 0.12065826584735226, 0.053654492291952335, 0.15872332087207228, 0.14915128208456502, 0.09166739971166657, 0.21100543559558932, 0.07622721169384257, 0.13454639803498022, 0.11076807840577058, 0.11808851583590431, 0.1641294807796517, 0.2360886864123806, 0.1761325923425536, 0.2126930047187113, 0.09991567687041338, 0.10403796534744963, 0.15969606867480665, 0.30507392340129424, 0.12006994862590106, 0.07774920623388984, 0.16482492007555502, 0.12390584279332431, 0.11405624268997101, 0.20622731456833504, 0.2477173954849282, 0.1806903251957509, 0.10068223210832766, 0.1291754781719177, 0.10917453891447476, 0.162292524511295, 0.14097477970344408, 0.11967386584728958, 0.13059162234346713, 0.0790489893106203, 0.2785183435245868, 0.16194662049172387, 0.16512036954443302, 0.14191084721636388, 0.09663832974770377, 0.131724068834897, 0.10341365731531575, 0.18726870687978883, 0.14821634838177314, 0.13582458509312523, 0.07806032986169861, 0.12037634549121703, 0.20440589456308275, 0.11582751457969989, 0.13594104577937435, 0.3378464293576056, 0.23954916685338945, 0.19258845206950942, 0.12672529916369146, 0.10282399177911783, 0.14570698142051697, 0.25485859132341804, 0.1293678734932215, 0.1599283158899315, 0.12827868798687575, 0.2028197248376185, 0.1616162067699817, 0.17165831710782745, 0.17640505917370322, 0.15463590471734925, 0.11018173769116403, 0.16158441412112406, 0.15212287585581505, 0.12745292947417305, 0.11774952959028945, 0.1107262576659841, 0.06006580935190282, 0.19825468350562359, 0.1118644881212423, 0.14171402390685775, 0.1506740656951743, 0.33952106691656575, 0.13633384970166992, 0.16191429158131923, 0.1082274397354453, 0.22451297530243475, 0.10018416004435671, 0.1747080212038371, 0.1266769130503939, 0.10077036286313688, 0.1583601951959633, 0.22360405794555144, 0.12020864884459204, 0.12983797568707697, 0.13894565794016087, 0.17171536001466936, 0.17986308813335436, 0.1831897330139914, 0.21459389868522846, 0.15949757529362557, 0.07659520968914994, 0.12098242829163229, 0.11360967471714943, 0.11760274714399731, 0.11570542314720732, 0.10820830285909677, 0.08656384453417794, 0.184613139699063, 0.15097391250873768, 0.12792382073859054, 0.23720700624248675, 0.0980838074258739, 0.13890816559714658, 0.1748634757654321, 0.12731485744758, 0.14131624041305435, 0.13945596442828256, 0.20644574155730588, 0.1226858018086322, 0.06876705514807856, 0.07417440249194061, 0.1002190400275492, 0.1499117162799643, 0.10407641530036928, 0.14404054100234664, 0.17260590658312844, 0.12045496909488594, 0.20102173180109073, 0.1827809944628708, 0.21165969000468332, 0.1206831330613744, 0.11231809644208801, 0.15382788114009366, 0.2116755939899914, 0.125406869506884, 0.15344817732130328, 0.05352455994955475, 0.15878203385058912, 0.22612341469334019, 0.20635480692069377, 0.13731903877229462, 0.08976711095460961, 0.14390704252066153, 0.20701825438487917, 0.16746277530347148, 0.10480750832826861, 0.12518406815586552, 0.10707973277256375, 0.20577425016991555, 0.24703620542441648, 0.0934269734387917, 0.09401185092546287, 0.09888638411798785, 0.18381859926927477, 0.09853558479658059, 0.14727490293162485, 0.08684522096788691, 0.18826667429699054, 0.20652291725479788, 0.13385975342844764, 0.10639188540799004, 0.151076844082244, 0.11565260138482818, 0.11129015966528848, 0.1961549744009972, 0.15915093582964715, 0.140018732617459, 0.17602829713254206, 0.12195065617561342, 0.1677172390684005, 0.0702344429408831, 0.16127062450733878, 0.09207557901860246, 0.1315103149822643, 0.14599567399390284, 0.1403732934305745, 0.15524830008226057, 0.1695290216875653, 0.12178692786443619], [0.026206008211198836, 0.03011790404637014, 0.014310395063441849, 0.04989183229965068, 0.08193580779216944, 0.045071438540734594, 0.012179889224259364, 0.06844225685082136, 0.00556805822622752, 0.024187749574681925, 0.0201494588081034, 0.04225508482646077, 0.04045820644786281, 0.031067211473841342, 0.055190452614859234, 0.05272682876356187, 0.07201456314613743, 0.019486246915954738, 0.04552405477771836, 0.02427571753580724, 0.07809018430810782, 0.08186217908176684, 0.015232840575458062, 0.02467466548325554, 0.05889393614544984, 0.06908677428239776, 0.04584199275761362, 0.004387411397821721, 0.029309227379159104, 0.04887200839396927, 0.07302637377213086, 0.020726566248002554, 0.045047302940680135, 0.03135233407750005, 0.06661679190132888, 0.05548840336081001, 0.0167630456628338, 0.02740330596063887, 0.01572211507722856, 0.01830784280994727, 0.06844863836323062, 0.09723042378262167, 0.026721255966432156, 0.0665293506256515, 0.03120088232530942, 0.052532100704528635, 0.026950772078106963, 0.018133021545626463, 0.02044177114693148, 0.008460305398330092, 0.027716452060567758, 0.05522498785848579, 0.0691355664222952, 0.06036869753452559, 0.05993216148307247, 0.04732704270751246, 0.0222160384404443, 0.004739148698131284, 0.03456104929829317, 0.02813875994404718, 0.030020153142451763, 0.030633634436995755, 0.05201489176420916, 0.022127859805139805, 0.011478802902744183, 0.03846914342214023, 0.06360451120042032, 0.08895498880695912, 0.014586885771413725, 0.046638854433812445, 0.03472156387062804, 0.05884790575251945, 0.053566315571867654, 0.04732033177729576, 0.035797040233568805, 0.010378541680233134, 0.05419692850761837, 0.014915853502198815, 0.041058302271149816, 0.01345250586558494, 0.017541751055227175, 0.028494420093334014, 0.040643136242344495, 0.03413904593476365, 0.037479848120241396, 0.02403469669872955, 0.043082946250515605, 0.03467660983123126, 0.09210131957285828, 0.05478956263452288, 0.06435720024690514, 0.017184154618711724, 0.07143435879580437, 0.03735601383772108, 0.02403772466125027, 0.07775885128085652, 0.08806338503716454, 0.04980466681562605, 0.01140128055046643, 0.05319089801501363, 0.05872725839576414, 0.01333699512836193, 0.06047204662595065, 0.03852671492964991, 0.03776512011104534, 0.028404134716237747, 0.033349488906922846, 0.021561481426620198, 0.0660738807111498, 0.031856341407664364, 0.04343428949434911, 0.005480741918642795, 0.06514069368882526, 0.043878608999112924, 0.045073085629771796, 0.04538520900232177, 0.06625789503056197, 0.037631070046054746, 0.033000555009611195, 0.032045785375239874, 0.017073012497876922, 0.05945685755221113, 0.028315961826592687, 0.08484005477399596, 0.04336175628967824, 0.026487692995297334, 0.031315031341247024, 0.043596236651102384, 0.028676136148973342, 0.05955653708247889, 0.02318375113029634, 0.05666223392190953, 0.028114547735200297, 0.04653845861133549, 0.005758049467863936, 0.029627475624663696, 0.039282782423880794, 0.09300607707231276, 0.02820275318358214, 0.02220219714687236, 0.027445375679000735, 0.06742087778665366, 0.07193219337251879, 0.05789352873820932, 0.052308824378997094, 0.03859270191300781, 0.013351639856644457, 0.014675063449108313, 0.09379145509052662, 0.010408858652226629, 0.007733679141834259, 0.013282799195768613, 0.021648767569492904, 0.017749586878644846, 0.012060938752256336, 0.03556834766641259, 0.06149741317776423, 0.03874405024332866, 0.05378249792322036, 0.025294185465862675, 0.07219333742414752, 0.059975012611117096, 0.03336290693691662, 0.04629037635881574, 0.02037483038410785, 0.019631769147611434, 0.00888605588941925, 0.02393873269489456, 0.03437747164899784, 0.040843590808611725, 0.05334229231060994, 0.051403174387110825, 0.04261873910323747, 0.09897472937741587, 0.022604056228432926, 0.02158088451852241, 0.03708793669037762, 0.03811279762416117, 0.04512348272387059, 0.05069403743912136, 0.032777761319471944, 0.0459174064528798, 0.019856430177066117, 0.07539075093283769, 0.006965567309018826, 0.062283151257302494, 0.04069657470550268, 0.03650751783542576, 0.015272886864089919, 0.04482083202850434, 0.03003296404776554, 0.10481778156733322, 0.05054590667808249, 0.07456529119442548, 0.038738542071153084, 0.010678739936631775, 0.1058917219239858, 0.03507599827923602, 0.022624455234636704, 0.03513716273911057, 0.02963703640195872, 0.0498285151327089, 0.012387522991987006, 0.027763913122696743, 0.04834212069850295, 0.049525810811187954, 0.026366551511830864, 0.08554928365253633, 0.024426577485076362, 0.050647903624321186, 0.04171195913166289, 0.03554962447754318, 0.057376955650867, 0.07231002793677392, 0.048160408473303246, 0.005876483309323029, 0.028534875281395453, 0.06994798734423614, 0.004296084619953388, 0.011082697141494964, 0.012397713876599747, 0.051346909059512044, 0.062212720963983774, 0.004543770421972318, 0.03116719743927881, 0.012471455584971175, 0.01051173947240797, 0.017414333396441033, 0.02032211587403811, 0.1256330186621316, 0.030004639861985084, 0.04686683070875945, 0.041043083934533986, 0.040916932236042716, 0.021214575747088082, 0.04683579648694685, 0.05790381346859279, 0.05400848236956424, 0.05288039874886313, 0.014087996866193511, 0.0090625319036565, 0.06119379721161339, 0.02325809613290814, 0.030685046597594218, 0.1398256937822988, 0.03027851629491535, 0.06757971845687398, 0.045251162767770796, 0.11844080902876393, 0.0529947565237601, 0.05513862293634204, 0.04903979697114518, 0.05561242150443216, 0.02354350601953845, 0.018000959478799376, 0.022389199209189223, 0.04493507105977305, 0.026600585627039115, 0.057464220726321784, 0.014442658228349062, 0.03303084612613724, 0.01010812413428099, 0.08209255704235646, 0.05624725558464566, 0.013504711884794938, 0.05616132350217912, 0.006182466965964846, 0.05826117433307152, 0.021693325158388867, 0.03395391695742165, 0.11763201936358407, 0.13974525455024936, 0.019985726666486552, 0.11393978966460114, 0.03112122450294274, 0.009029677265413828, 0.022281967967207876, 0.029262354289512002, 0.07291015057313828, 0.03960630518474406, 0.08896942190345257, 0.013793889966402805, 0.08737923021638587, 0.030098163875781243, 0.022077273104279753, 0.02106765923540919, 0.008455510645534002, 0.02313299780531276, 0.019868304539892464, 0.1290224750916804, 0.05211797272486072, 0.04946086187696746, 0.05045776060151477, 0.06885366904879771, 0.03229498803134888, 0.018544590791627284, 0.04349278796824717, 0.08113444151897585, 0.0628769651596104, 0.04274863314123885, 0.026676537499072093, 0.014856207811634147, 0.04625416338263501, 0.02654741529465443, 0.016355201519364794, 0.027238909237747713, 0.03565240283346465, 0.15710220221550236, 0.03777406418756132, 0.013462249546371883, 0.03378022950322878, 0.05294322561953337, 0.002633098061309166, 0.05836340110568751, 0.002195587881179827, 0.02151915698402351, 0.04260316836617647, 0.027095687185083667, 0.03995163846881159, 0.02575719943119874, 0.0702035159713799, 0.05706254167542343, 0.04143663862299535, 0.020378475047407613, 0.07165621019779675, 0.04541341635969378, 0.05751987318358114, 0.036489426669093876, 0.019949067444089922, 0.04126180586735568, 0.04165137689861079, 0.041059608451060714, 0.029395391203222737, 0.06472058639290833, 0.055063251375911705, 0.025701945339660012, 0.043699214189884164, 0.030196175249593876, 0.03229884145360801, 0.0232470644667985, 0.03650701604783535, 0.031439953468619816, 0.02820466648817303, 0.06751130680523573, 0.02064483424258088, 0.031349648939325445, 0.075660590082407, 0.023128161875290737, 0.030732097802683715, 0.04213107051327825, 0.03299001747021272, 0.04310059691629103, 0.14018722599552524, 0.13464808854604923, 0.23879460089149016, 0.19196533147365819, 0.15210528647707355, 0.12384427230684988, 0.11070891343537839, 0.17937824640783573, 0.09191640126969546, 0.17220253064747781, 0.13880907978502013, 0.11281940139709942, 0.09927028609860329, 0.13837078556178078, 0.10084344765111324, 0.19546036248005208, 0.13180017200929503, 0.13246771038299607, 0.13994023924873722, 0.13554007535980594, 0.17668693356456297, 0.1349134460812615, 0.09090767031715763, 0.17815488060155224, 0.11543822700097678, 0.13721414601370213, 0.13512747572554698, 0.0936059468996621, 0.11813120991592446, 0.128384867773181, 0.11666185327715452, 0.1705534038163962, 0.148873437316187, 0.1376404739435642, 0.14152003512267144, 0.19566055657642503, 0.12063820200461535, 0.1173604335335474, 0.11954907012442428, 0.11425963903386747, 0.14475880971839353, 0.16390837248294585, 0.07622420096830015, 0.156241241962679, 0.1327927461675098, 0.16289443979340215, 0.2549100877536882, 0.11561825000230344, 0.1513623037645894, 0.11026712585120432, 0.15056359581649303, 0.13788491727844362, 0.10028401194440742, 0.349169208878471, 0.18273804757383563, 0.12002962175756694, 0.23868060700835722, 0.12201736711205975, 0.1224735418274518, 0.13781966190905343, 0.08698202128852568, 0.10934306293605797, 0.165752284829655, 0.14005843129369522, 0.12917236785494512, 0.2627192509751166, 0.15692076195151577, 0.2144615033701543, 0.22959794518688034, 0.18420193434482623, 0.2585429379776601, 0.12391197149671855, 0.16128724861529567, 0.1418932578376224, 0.16556333690401048, 0.1450484215972885, 0.1511671352049997, 0.14428830915881743, 0.13241183192979905, 0.14449130713699326, 0.0949207146561915, 0.10906307312149195, 0.15815336677816608, 0.07264827873798148, 0.11560267543480282, 0.11812444535955308, 0.15755515936161243, 0.2551932185287437, 0.18134307807251332, 0.1074351822476714, 0.21914462949479782, 0.16371513446492536, 0.14626735941536967, 0.13254344583519045, 0.17697875177667988, 0.18573573429978665, 0.12818528654714748, 0.1794549318090562, 0.1491435139530128, 0.17514138182084407, 0.10311087638500238, 0.10545221728182609, 0.1264492547019355, 0.16913463962414574, 0.24605406538373042, 0.08128780466053756, 0.1262126561074007, 0.11598047169466173, 0.2917806125215946, 0.13091935475747432, 0.0897726574311814, 0.09044193482447056, 0.18435438584175803, 0.28138234790775085, 0.12552876175651628, 0.1356082878285839, 0.11649468523119727, 0.1391893198653575, 0.11374236880651406, 0.1567865893124573, 0.11625194261150977, 0.12352419311120627, 0.07237201211072745, 0.13446609669875714, 0.12080045942697795, 0.13685976906168845, 0.1107333822836799, 0.1332518473387726, 0.20057145596271564, 0.09584178216755392, 0.09935745158262792, 0.26959191767438767, 0.15117168576726991, 0.10529777395629114, 0.10766799636786023, 0.207743494501037, 0.13288053984363235, 0.21477612035889782, 0.1124009948163744, 0.13210979410477225, 0.1946606279741372, 0.1895202852545246, 0.17384012019441974, 0.18322629072973806, 0.14751712461152386, 0.1541888924135316, 0.14459013247922545, 0.11428381676875776, 0.17003975718492464, 0.0795130470707532, 0.17511651460682193, 0.136635611735044, 0.06571768813075558, 0.13413159206749933, 0.12363680803607549, 0.10560583323240282, 0.16735417467932548, 0.1472913738219969, 0.11917964720557775, 0.11769483857337507, 0.20716606338898982, 0.18788408998760486, 0.15324801386844727, 0.12038129441920789, 0.17318563595894845, 0.1066564385508818, 0.15291694131109024, 0.1378262809087192, 0.12636371332431032, 0.1062948756941384, 0.20208680852045938, 0.22416707128286364, 0.10976497053859696, 0.16830283667772047, 0.09326191979550547, 0.08535918659500538], [0.007840563250224917, 0.06848209342288394, 0.014066626843545708, 0.05818370369172866, 0.056108612822549, 0.08600121424082788, 0.03129572401033535, 0.02711950677386936, 0.022909608481812383, 0.11852409044701247, 0.05316353718479795, 0.05000318700988447, 0.05543716740043414, 0.0049029464360266445, 0.01811107887225526, 0.044385927744329944, 0.05246335963508295, 0.010305125559229526, 0.023495527848060575, 0.0545672094449401, 0.045216646676342336, 0.03195855094330206, 0.02234952734603036, 0.014195059568831518, 0.05346324227209534, 0.008573751528597167, 0.08261103768863025, 0.020675763127303893, 0.02265905176529721, 0.04074765361785408, 0.036925411137241515, 0.095148564526631, 0.04858292511574203, 0.06509465946545524, 0.03697408070307105, 0.016158726779864203, 0.011002543277197309, 0.04480901512227232, 0.08360125229603822, 0.040896822428030354, 0.039421432846856695, 0.04414480540060228, 0.0787513947955543, 0.02157463515628009, 0.048399588784142855, 0.011329655159985828, 0.041117118671536446, 0.06644447574452048, 0.018929720428141377, 0.07380597548739565, 0.035253849421297355, 0.06744772150752044, 0.03594032931892622, 0.059370703304246555, 0.058427499682312055, 0.03782441914682427, 0.06377303905244316, 0.049898807530201254, 0.067129572853446, 0.05423106921596393, 0.02216204647876082, 0.06120236973548609, 0.018379964242358843, 0.04650015804556109, 0.05074990440099951, 0.07544996186850533, 0.02372115223308004, 0.0394049504651658, 0.03408537381478856, 0.03578755606506621, 0.020540523710810853, 0.05916730312991047, 0.06270305937035911, 0.09715108005630393, 0.02406050045523913, 0.06020789950965874, 0.05187518030945813, 0.02978991499290832, 0.06444309402497546, 0.03324801290047265, 0.00678217830887485, 0.004461742036284939, 0.01486180312631111, 0.022665429447266846, 0.0684773973039081, 0.024063823361610694, 0.08772969245910646, 0.007868494337139232, 0.03579820851765333, 0.014265347178274346, 0.027314242493781834, 0.034392747442207994, 0.049557607290485216, 0.04984434250922454, 0.047510367547792774, 0.028969796802548152, 0.0527070215602796, 0.04285383233500104, 0.06890557916654695, 0.005652580706913385, 0.021159218233679573, 0.034543034740753716, 0.044790812873191414, 0.010220381870655524, 0.015656333980000308, 0.04842761994129227, 0.008766173662978315, 0.06276937960196408, 0.03769008562930169, 0.03860462990198885, 0.015401526433115285, 0.02151800019125785, 0.08108810852131537, 0.0101027031046068, 0.04220368032674155, 0.06667101560460945, 0.045976839554045475, 0.008439395028436858, 0.03125896519650856, 0.027283074206582485, 0.04987997708902244, 0.04665838584544198, 0.029663860970627398, 0.05840449023150629, 0.05279650446027518, 0.0982685265461764, 0.06432176101952791, 0.015849798951568385, 0.013979470935620129, 0.06578726423603874, 0.0072855823447987925, 0.019609587071763895, 0.03587086812683171, 0.014008679952953133, 0.020378095833885095, 0.023011628410688812, 0.03162408653166025, 0.0516995316701791, 0.035518900521339915, 0.03792490306941252, 0.05707545025694755, 0.025925920720422463, 0.03089990361683792, 0.07889281462637648, 0.06672618159603688, 0.04034483692638817, 0.01613827223228591, 0.031143105889279998, 0.0648945419778747, 0.03865698435073418, 0.03260411216967529, 0.030160195930230043, 0.01773512313863443, 0.0832084943390181, 0.023769848611986926, 0.011620777189701555, 0.039221813316426934, 0.07568323564144873, 0.02397012697803157, 0.03215912999885698, 0.04221396505712502, 0.03242913768776963, 0.04335355531844882, 0.1016788665325411, 0.05646873543399477, 0.054429914997590166, 0.03244345204063481, 0.028592889204681404, 0.05007706852930208, 0.023101940600862427, 0.07041018351071304, 0.059441413219657645, 0.059463227573301525, 0.03130028606392443, 0.002373815842738916, 0.054976871132009456, 0.04806406908638535, 0.036192701663821936, 0.03476837184280157, 0.04670143998678654, 0.04288840971346344, 0.05889329646203307, 0.015429152521274745, 0.04218758864989204, 0.04420336516153428, 0.054527307755403945, 0.012184000243583034, 0.02060017131659533, 0.02550759840936911, 0.04456823368767097, 0.04520267706304308, 0.009889233662115951, 0.02992138717203371, 0.0389272908139373, 0.026290369813420603, 0.07532140465393182, 0.055008081554044644, 0.016046716106845247, 0.029598109559306217, 0.026625757361011162, 0.020657352119263624, 0.0398734285526218, 0.09400357717588063, 0.008668739727938609, 0.03296575929609037, 0.029440257142508225, 0.04997918930565638, 0.07806989829987288, 0.03045380870330959, 0.0160229941942699, 0.052974367093655376, 0.018908572570991614, 0.019600191003372593, 0.02589619842418019, 0.018134419656088276, 0.039739294217959534, 0.07101582198013222, 0.02333570083963775, 0.07501960431616153, 0.08294431657920923, 0.048244344896727034, 0.06756575267401434, 0.008896701638737034, 0.01719258158587881, 0.029449990289586208, 0.0670669298438776, 0.05861305383845203, 0.017825799220572078, 0.023033347003342166, 0.0458629452623427, 0.020483819797875422, 0.007578305977081219, 0.03241197731826575, 0.03996150951171595, 0.019989719899791866, 0.07828294735161528, 0.023935042066319336, 0.02400426385593751, 0.044751593001907876, 0.06247220643525643, 0.04840477902982985, 0.035455219462634094, 0.022817813911505287, 0.018213374592784434, 0.06736712905788614, 0.00917506255885406, 0.05711319157853723, 0.03755177994589171, 0.025801299282559947, 0.08140565196592962, 0.032974860420630824, 0.03522196101144918, 0.030105355526170427, 0.026043078546682676, 0.023704813492874947, 0.045552702635646834, 0.033884884774564736, 0.04704474313785473, 0.014324267000530758, 0.04128207272339252, 0.02222355950864092, 0.03826971541369154, 0.04432064173142276, 0.022757990105498224, 0.06043885203619158, 0.04281506828603245, 0.015881413484983627, 0.036115556609846895, 0.03451876507531251, 0.11535182760487642, 0.02999658061702165, 0.04500794900400985, 0.024920604604807113, 0.017141205814456748, 0.01122369658156869, 0.10197489056736232, 0.049144333498852874, 0.06569359466553697, 0.023107282148914474, 0.05157738661153182, 0.0453527307047719, 0.05458358074388197, 0.10065709676353202, 0.08559045321758717, 0.06771701673466353, 0.04960733405765026, 0.006872986540979436, 0.046694296216892625, 0.009080562740564346, 0.0308987908741279, 0.0063804628688000865, 0.013260361438076343, 0.029849449600723964, 0.09615464481495081, 0.042493024074863044, 0.0369212206362957, 0.033878756071170496, 0.027357156824080214, 0.033524743010920864, 0.02026970013825884, 0.018418862356714184, 0.0721694431417892, 0.012202619052972766, 0.0059591178620804946, 0.039153945587214925, 0.0469939629997938, 0.03028998271592202, 0.013661898762708711, 0.005355725945499276, 0.01828432391067186, 0.06527558645053257, 0.07648893797229375, 0.07005382239097549, 0.06276311300274345, 0.046251891931939515, 0.030808195231422305, 0.06496991736874466, 0.026620153427845048, 0.058927107752571185, 0.1385755148986655, 0.02721552057341943, 0.00625391184697829, 0.05091444093493685, 0.02849616294336175, 0.020728512111330227, 0.03429286106820068, 0.02729450806885237, 0.028189718197550506, 0.008319162316770564, 0.052079756428757985, 0.03188619968451319, 0.021474283383858782, 0.07242641967510985, 0.055595448826469725, 0.04377084724124401, 0.019469933073607185, 0.02170805319873316, 0.08434419670412618, 0.011079594485401627, 0.0962848108141653, 0.04445679087732588, 0.10011562581865058, 0.07104857223889521, 0.07067882756312048, 0.0143181718134832, 0.031242854367460937, 0.042512371625390746, 0.04958954549604847, 0.03592117712081921, 0.024007933417094812, 0.04401959215981826, 0.024978350397319566, 0.17561690791720347, 0.15526847883818612, 0.17715804699447849, 0.14167901368871813, 0.14541271172704237, 0.18701102554557786, 0.11417527743164571, 0.13286872676783992, 0.1674333575271791, 0.17355804662069968, 0.16866346490719628, 0.10314234727693182, 0.17967386441605707, 0.11248635999377697, 0.17587727055914942, 0.08553289703183597, 0.17003016576411265, 0.10820677834412745, 0.1575336629344571, 0.22615156076367826, 0.08805393151217893, 0.09968860840965664, 0.08646460550446665, 0.12096299264099329, 0.16636244321782745, 0.08066728110274962, 0.19805853435349083, 0.1441814398933803, 0.1417655203371279, 0.14796847297299295, 0.11972532397316349, 0.19670415219039689, 0.14614325317163623, 0.21872637613165766, 0.14019171527076152, 0.18538616837993746, 0.11805833197168766, 0.14413305378008273, 0.13634405399282135, 0.20788618603781348, 0.15188105254163667, 0.10256061841162945, 0.1762298089001448, 0.12984491644367097, 0.12530912434862507, 0.16617231551677952, 0.15171144067520095, 0.20173932635976424, 0.11920449143696217, 0.16387088013993156, 0.1153817663209573, 0.12593255904052528, 0.14813653734182158, 0.14143041815728913, 0.133226397897928, 0.07727922661410225, 0.18157682681996978, 0.09897930292232383, 0.27430007955239666, 0.2707002630397197, 0.2544381622705729, 0.11295730488434916, 0.13698307857398065, 0.22905049875618952, 0.1456393511785615, 0.27705413499666803, 0.10681369341909887, 0.1201327908183298, 0.18459227146400561, 0.10748183700226008, 0.11343777990869938, 0.281778262147019, 0.11261402088547907, 0.22244087600659943, 0.13163624451525752, 0.1980329776603368, 0.17377180047333243, 0.17517024801383096, 0.2387422617645033, 0.1836789720841954, 0.08927877586815627, 0.11451384998978147, 0.11352110729222337, 0.13869723094807518, 0.21460842371227282, 0.09058537712741284, 0.16725415423993142, 0.09325602857936775, 0.1806778532843436, 0.06642645735654139, 0.06285586709817571, 0.1161301422924284, 0.14615151159945997, 0.19016076540274007, 0.195810709809584, 0.12644258973699424, 0.1527941067733111, 0.13027029442450694, 0.14676744629058147, 0.14065049468509613, 0.1350652693860954, 0.12981329233415667, 0.11337180441666035, 0.1237358708655642, 0.17336517632488282, 0.15171979103357564, 0.20714303478598597, 0.1549026718543422, 0.16166001167749205, 0.15121115461712883, 0.12359601385410755, 0.10494134388864042, 0.12712220931726118, 0.12333014303998602, 0.15923793277432843, 0.2384517305800992, 0.07761553921286138, 0.17937225560026784, 0.12145282159889899, 0.10873574673408463, 0.1949924053323846, 0.150078141220635, 0.16760197347931324, 0.20884050176508967, 0.18382846648173948, 0.2820935532931359, 0.14719386615099447, 0.14742752296790002, 0.14677856988724203, 0.09937510990928258, 0.11043861463305452, 0.09699947891696807, 0.0846007212455715, 0.1235477349931194, 0.15670425018235562, 0.12370871304864846, 0.1794134251653187, 0.21712280088855376, 0.1292050798093119, 0.09321832173173467, 0.2104131270560526, 0.19984561829797684, 0.13771450868056667, 0.27255995679766903, 0.19495357999638205, 0.14863536783283757, 0.11044572392899184, 0.12452220649368341, 0.10828622166187533, 0.11532978725529487, 0.11064686797439091, 0.08742211581838709, 0.16557600799827807, 0.18435777195038336, 0.1326523069292307, 0.11670924347615051, 0.10198782979240341, 0.15171235998071012, 0.12255599587074212, 0.1049506671786789, 0.11722927162003134, 0.1281217395538284, 0.14548509171412838, 0.28217861969624797, 0.18307204658706344, 0.1545455676293181, 0.10781984265533187, 0.15856520032450078, 0.09794484673728866, 0.11109204932806954, 0.16948684088645444, 0.1621543988585472, 0.10832364505697643, 0.1335182467535619, 0.08962386783452765, 0.0773935116106464], [0.0755288842464647, 0.05992337062414135, 0.08499043017265298, 0.05681964200771144, 0.06669069640338421, 0.033627364318817854, 0.056108084221881245, 0.05175092467857946, 0.0515889622000677, 0.029607107261976892, 0.09418628148494229, 0.0761074491686398, 0.08227909945191876, 0.019140373539900588, 0.025198893704181238, 0.03803178382616851, 0.026910041098392783, 0.016448890242064675, 0.19846370293488427, 0.024477491688524044, 0.04938991447429984, 0.05135101529078619, 0.031154260129457524, 0.021655880695869847, 0.0480775177598961, 0.018552778356318033, 0.0396094078408374, 0.05252826260402799, 0.02519198933676366, 0.05017101389145659, 0.10653452331861181, 0.024266497667638526, 0.014274018335967295, 0.030762178245030587, 0.1779014127509248, 0.03348330531509654, 0.037498881574720144, 0.03530147327711025, 0.0651949480356228, 0.03699972166589672, 0.041336330900629686, 0.03827058875392522, 0.026728493582096793, 0.02066023069463911, 0.0528818964507551, 0.03916188608855009, 0.026493162863076698, 0.05923721248344068, 0.09995976523045572, 0.022254350497537566, 0.03704463357045766, 0.07849099384921213, 0.049684632329210165, 0.0539583993715144, 0.03821597051536364, 0.0463135811620422, 0.04034195643579287, 0.043171077005324826, 0.05264540893896934, 0.03219229011465946, 0.02663940330216241, 0.02746640479252223, 0.027994168509218483, 0.03139254220220591, 0.08197814181086518, 0.024621041243775718, 0.0711513888992129, 0.02234641702905778, 0.03691309244341908, 0.054753905072087244, 0.04743875364863104, 0.05715952457619771, 0.07387418795617358, 0.05208157205713853, 0.008922550402912162, 0.0208134655164735, 0.054802777651216716, 0.0353595772157273, 0.03356300527229905, 0.011953440337111394, 0.03697734423762849, 0.03543126772368147, 0.024957623888528156, 0.042803305005955125, 0.011141878391255536, 0.05642476964802031, 0.02566826236884921, 0.08074886180580625, 0.030689112609252337, 0.04274528533700974, 0.0735461337852382, 0.024682044825186173, 0.06340154386576145, 0.09981935663569359, 0.033587995060389085, 0.057356183176800135, 0.06063680532538603, 0.06136569968094269, 0.005033776058905548, 0.04932064863462602, 0.03758716171667461, 0.022635594153055744, 0.03303554990599233, 0.015139670877326882, 0.05414993284390338, 0.06372348465506109, 0.06538912834179017, 0.031825017987660346, 0.05149126300708421, 0.011917078931395327, 0.028168685253589388, 0.0383672307455732, 0.04850323664985838, 0.06917266039958886, 0.023121435623315555, 0.0075071354513056585, 0.06342415495084659, 0.03616722157946037, 0.09696601619643551, 0.021639074642030943, 0.11503949355814727, 0.039197945847145976, 0.08981880656774006, 0.02517694336993079, 0.016452531074924816, 0.04465628400324814, 0.06918661086069, 0.029515682329093258, 0.01961500714382818, 0.0510222984537963, 0.06395692696734782, 0.01474295990661748, 0.09526635820586836, 0.03180175572783957, 0.01980061875656247, 0.084010343247604, 0.03578985049839943, 0.0068040022386177896, 0.06180741065632432, 0.05450739329981227, 0.029451646954722466, 0.03615037530600544, 0.03335420417809679, 0.0612146845988689, 0.06121261233103372, 0.04922979443724598, 0.013478709903034954, 0.015090368331349907, 0.05740742296761563, 0.030241246117399107, 0.061930459698722254, 0.0578203596805613, 0.03648329796569963, 0.06675415912703161, 0.013415019268230086, 0.014770783262417443, 0.05766036221757532, 0.05627701810050396, 0.041495765288991314, 0.012340881643937, 0.06258634587509498, 0.04075062220856067, 0.11074324949614464, 0.054790474279152776, 0.03958699210817295, 0.003552067209966481, 0.02797214348139542, 0.026521460235779806, 0.0708729465822539, 0.05191345023171556, 0.0366042594185039, 0.08768378080980432, 0.023404072271659974, 0.03816317556606185, 0.02465471463848747, 0.061357609792462284, 0.040511606606624784, 0.028339932717743422, 0.023866745327869733, 0.024137538256904772, 0.03486872553044269, 0.04988896330037425, 0.04430612053481802, 0.05892226990732936, 0.040857464660920446, 0.054450262292859056, 0.043483070142927675, 0.026576578346711975, 0.009065417182301323, 0.06533925601791951, 0.00635398974296667, 0.0193976124583353, 0.10628276384405552, 0.043535466726508834, 0.09920732899298591, 0.04162200508759387, 0.08618374234966694, 0.06792880174133085, 0.04347485001950015, 0.030503591011849143, 0.023842079211927714, 0.014638077681733957, 0.028710941438593214, 0.06013882136152637, 0.024304216006590475, 0.043691239214592406, 0.03319829379418685, 0.05257029784843326, 0.03352465874124919, 0.0490860648513321, 0.02879279601808277, 0.02647691605342252, 0.012396759139524113, 0.017811944520461465, 0.03773179528633914, 0.045087836652753815, 0.015198616555050738, 0.05339766514577693, 0.09197807900847928, 0.025906691913523024, 0.028038536491353187, 0.04210287081678549, 0.031086032338921103, 0.03109757919915982, 0.07751713521898755, 0.03715131131391372, 0.052321434186230746, 0.02982657421530495, 0.0058672371068819165, 0.031409126090546774, 0.04082841460683173, 0.05369539755666929, 0.04020384993524321, 0.03075509001651118, 0.021793807165757306, 0.06208802866298826, 0.023845015243897517, 0.04815360178209601, 0.01756608200770232, 0.09212293857408148, 0.05038298275922576, 0.05293954839749683, 0.03727434503455316, 0.10982385971733641, 0.04910917389356802, 0.05364932885934269, 0.03355616410713523, 0.03953840298157546, 0.05005771331789513, 0.03955138051101277, 0.05951959632277008, 0.0143311292331125, 0.07756143808364868, 0.038826477473541614, 0.06142856102556952, 0.028780465832941478, 0.049583255914190126, 0.06585785923826118, 0.07988892811080141, 0.037258456371003584, 0.06072059619210421, 0.044984196447917534, 0.03953108301145896, 0.03872363783058621, 0.04010829961888733, 0.02932984088998168, 0.08767002953156348, 0.02078058693798319, 0.06489118651276635, 0.0153554079400736, 0.022645955492231636, 0.05537309563688694, 0.03185901313930029, 0.040596155900387995, 0.017614364699130098, 0.018336055912978707, 0.03927665755092617, 0.07044419015367186, 0.07196987723751415, 0.017691699359866402, 0.09486832190304996, 0.06395311951036416, 0.02664343100942431, 0.046065828327329895, 0.10143305190027722, 0.08327946472432345, 0.015328330562389908, 0.04062404533127143, 0.06897550767227527, 0.02770241349935532, 0.04682107993792142, 0.04226846455205833, 0.03296359509770428, 0.024066964322100245, 0.04548457060610095, 0.029583431314677004, 0.0418375286033317, 0.020329286457009373, 0.055199446487090284, 0.015064769503360075, 0.0707747264494819, 0.04584344449423013, 0.009551400378827126, 0.05048892505827451, 0.019414644508111863, 0.04396870476944793, 0.06143827885088902, 0.03780264692801622, 0.02891996661351333, 0.04676790577509711, 0.034636482145757444, 0.07531447921909633, 0.048770252765426715, 0.05186601023700449, 0.07853834574381191, 0.07608622853313723, 0.048087040232794906, 0.022097698923560883, 0.04858561408435626, 0.06514762678454, 0.027455277365422057, 0.028258457351776383, 0.006803657020246911, 0.040428382644970576, 0.017426056456902338, 0.013402088661678137, 0.035868278749647646, 0.002500568920250742, 0.03796161017230442, 0.047356154048635114, 0.059023171347836335, 0.05065521976399807, 0.07706923425317773, 0.05478804961087243, 0.05106300453565294, 0.016675305612865957, 0.03954675333995012, 0.019034327818982063, 0.04666857098439529, 0.01997217265588622, 0.06009504709753299, 0.009225735444605592, 0.07987172943690131, 0.029695287812501196, 0.015196414052268431, 0.024686557083060185, 0.030432143736810937, 0.02751507052791215, 0.03163121114935606, 0.03024261933000338, 0.08040203848072598, 0.050202645661850134, 0.17018496149009274, 0.21637542083138422, 0.20345134900942927, 0.09968590411928394, 0.1538778607162737, 0.17827966100265905, 0.14492062280976004, 0.13958610744485933, 0.16713986924338728, 0.14666633800633494, 0.23131254189197095, 0.23769028514863985, 0.14814165480915578, 0.1689116161076292, 0.10206112142411933, 0.1148334312282743, 0.221634277352883, 0.09720492071562237, 0.3121594093259304, 0.1306872760816928, 0.23621844638499523, 0.16745526764181354, 0.09544313299439608, 0.13236681660336833, 0.11736273945819949, 0.10959506755875004, 0.09976507164537908, 0.13201567254239513, 0.10405160937338107, 0.18685235341470088, 0.2221500230652671, 0.12726420371402658, 0.13461217434415895, 0.14330623040516532, 0.26706784182498533, 0.1878651982593921, 0.1376828539275354, 0.08627399516802642, 0.14235445808979774, 0.15519197729806747, 0.23930568878929462, 0.13059943644029479, 0.15869405631336475, 0.1450811182298968, 0.12269747698859823, 0.16997509936411537, 0.21205065531596062, 0.14167184310574688, 0.1683856507823352, 0.11896978507960036, 0.13993006560110277, 0.17914014628096936, 0.2191404772982482, 0.1803986755229773, 0.17004443032126274, 0.19002290021988655, 0.16793031876365985, 0.13454740927104028, 0.09882098319189203, 0.25372848906103646, 0.09388202200493506, 0.18398612737655642, 0.07025212425017549, 0.2010001434433845, 0.21035326494564935, 0.1313611423416484, 0.10789363224419857, 0.16025938844728857, 0.15622261070436047, 0.21019555808555698, 0.18474745023394787, 0.19679879469256248, 0.12985302165390986, 0.12514836079771482, 0.1958302144081362, 0.12159197380946529, 0.19279517323499729, 0.16280278503414125, 0.17678937484179774, 0.0750001073784886, 0.12357080956139874, 0.12523196397289155, 0.1311392373135013, 0.15687012353972082, 0.09730374605785455, 0.15356753381990618, 0.09304316338872717, 0.20082178285285351, 0.10856630340699228, 0.09185791811755589, 0.14409684846478124, 0.14369503534849615, 0.21175408735871318, 0.14089167448541812, 0.10811083349249057, 0.13151624450279822, 0.11825781360629106, 0.14279255313017677, 0.10002577902689096, 0.1771986956197408, 0.10393279679720441, 0.15845543524670988, 0.21439148293387508, 0.10883896176012293, 0.20541521540332228, 0.3007658739243784, 0.12824455876984905, 0.12466147361743836, 0.17940959472569729, 0.11873217524900553, 0.1623632037831891, 0.09778597542355139, 0.10339223749695287, 0.14626886094770125, 0.13985143433655464, 0.19135144989817374, 0.23917381441400898, 0.14193154691207793, 0.16765599799973352, 0.09248010408613952, 0.22901306770020918, 0.1649933674883458, 0.14609650648649664, 0.10873701077915969, 0.14639506627234722, 0.10131797017229181, 0.181454130178017, 0.12846757462548633, 0.07143975971567054, 0.1786751462326896, 0.15004414223855542, 0.15807632897650042, 0.2600097818480384, 0.14920884593119546, 0.1192921395563791, 0.15784290198597217, 0.16807121765469352, 0.14392916713991474, 0.16160275426603135, 0.18184399232268336, 0.12320067418078262, 0.15790895408680364, 0.10264642025914886, 0.17862273049691033, 0.1694850788842286, 0.13006266927526844, 0.20758367323827362, 0.09439265024998496, 0.15200204846839752, 0.07232739515001736, 0.14877337091151746, 0.09452123810807544, 0.12870203583471237, 0.11660661067693465, 0.14027364071338408, 0.1972237130206439, 0.24083915166556838, 0.16065557847820944, 0.14761965781930955, 0.19030134253684552, 0.17768477840769678, 0.183660218251809, 0.19145995859176884, 0.17239981360973852, 0.14070453452727488, 0.07808403262207586, 0.17105247945554797, 0.12592819233935687, 0.11889538262039424, 0.12237044937548139, 0.1772840837797811, 0.142804044449041, 0.15352529173176135, 0.08797238145263926, 0.12981712277377808, 0.18696391113823463]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.04760152434990291, 0.02369894717459477, 0.06254197789296027, 0.04951442674463315, 0.07451417780811749, 0.021080496953800324, 0.05232275568790013, 0.04300220441373606, 0.034422012000915506, 0.008548965711416978, 0.02720944932661951, 0.033200235827074896, 0.0900264930040125, 0.09576169533594962, 0.04023756929523042, 0.033050806547004374, 0.014802361406656283, 0.011037713416191119, 0.01542890641552907, 0.054332273261201, 0.08935724625424032, 0.021024336963291132, 0.042228486253729755, 0.022376474488766927, 0.060364346155115677, 0.0319409309210436, 0.06853159802455096, 0.011688276239100003, 0.06131415345495748, 0.044568570766357646, 0.049917454110278245, 0.0218471402918259, 0.04422571960716479, 0.05242754119418321, 0.03516107617366699, 0.0691374280159512, 0.08402777940876062, 0.07842778393457975, 0.030260693259356968, 0.042029789859248746, 0.05082755507300458, 0.05967952100740326, 0.03711162795943599, 0.06646791037412421, 0.04848347158141194, 0.01012894927689265, 0.02357171337691046, 0.008307556084717714, 0.03274684967172723, 0.043181583901206334, 0.06920657511199675, 0.04631441236744004, 0.03776408206190794, 0.02994044552437, 0.16984209117870178, 0.08506193681950532, 0.0995293310693195, 0.07773206884702367, 0.028608494415698994, 0.046333380704445225, 0.08595495785195982, 0.030818738516480215, 0.020023554172967712, 0.09403140915016975, 0.0350349206447361, 0.07091481328731583, 0.02394635526974115, 0.0630645647705082, 0.08572906916660648, 0.044376543167257504, 0.022914118824466582, 0.03276831928580519, 0.05080295982019556, 0.03699459270724366, 0.06967722122827846, 0.03459962948615994, 0.021313117636788278, 0.04255272530680222, 0.02834898979222823, 0.015047818850425464, 0.057023402243371935, 0.02317102832509385, 0.09263015006698909, 0.026524306252418507, 0.007084823737386615, 0.08704437318468287, 0.03726195739281755, 0.07724357288210623, 0.011356004754141455, 0.0829202920619038, 0.04106123638789981, 0.02804506547568787, 0.018987877992913127, 0.03411976350170951, 0.04708180647163142, 0.025828830567338777, 0.03695072268225974, 0.03940858555236652, 0.023184655114046993, 0.0010590222307420788, 0.05915581181104626, 0.06058622053974579, 0.07206093444819413, 0.05939575820981015, 0.03922494278559762, 0.04566758135033231, 0.045141497281410044, 0.013526373978463874, 0.02446204735597055, 0.025824517492325078, 0.035636678878818794, 0.014956300071771107, 0.021652651635269006, 0.02170519186033597, 0.010064394877953155, 0.03585260076027724, 0.03739640199308915, 0.06818179461744524, 0.007246472598654369, 0.03404463708941494, 0.05973294414880295, 0.016630916563313336, 0.04670592160114358, 0.024902532590673338, 0.04885124741122127, 0.08312005714903917, 0.035910375281086857, 0.028292479316493677, 0.05985339232269795, 0.0371258044164748, 0.0285437791382954, 0.023172380470280207, 0.04381667462087447, 0.03364306529082599, 0.05136441799902147, 0.042515730920938716, 0.02735047079172106, 0.03975428272819808, 0.038936031877153346, 0.02243299645582034, 0.07835004133202376, 0.11334437846897111, 0.03889218483480715, 0.007972563551213112, 0.05259664361214927, 0.044506743640428593, 0.05817459107586934, 0.03232297322322284, 0.0740662461987907, 0.05645712154106267, 0.04846482117089534, 0.05697007486296277, 0.06247653483202862, 0.07151691243052483, 0.051851354975013, 0.03740012901084077, 0.013221809978506738, 0.03643129591739947, 0.05825051421960516, 0.011338639456117827, 0.013324428413574015, 0.0050851647580613295, 0.004671122005674988, 0.05068271082916087, 0.042449261302188526, 0.012312890706403602, 0.054833704620719924, 0.052182967624356674, 0.06143219994320985, 0.05039307979806777, 0.025663627536907315, 0.00883729822347842, 0.03216584858995292, 0.01835949245780226, 0.023756344397101673, 0.00560332652023663, 0.030172811483123133, 0.053696795667131106, 0.023390121810558825, 0.027324749389663342, 0.05315249402736945, 0.04746484277289241, 0.07098382248753501, 0.01645748766379491, 0.01631998254226581, 0.034554158337414265, 0.04176730515375253, 0.052407128781440764, 0.072714805813326, 0.07254545441678456, 0.008724207366486231, 0.0527683737116956, 0.07041340107999502, 0.08865104342300086, 0.04265615483745933, 0.027969557934650974, 0.08849587997481709, 0.04471227353919418, 0.028572300591716365, 0.04749298884323047, 0.040040546802863966, 0.019342379434214487, 0.02246716972290268, 0.026461582803618044, 0.01742423508286236, 0.02589329495094717, 0.038038467943307855, 0.11502076270839862, 0.042618892320822326, 0.08313546317719644, 0.02085269496385609, 0.03407552575452193, 0.02547206533622117, 0.010879273984521147, 0.029390356090340405, 0.05022122712445356, 0.07139012487905641, 0.024398220740559123, 0.02146993200444887, 0.025915515331190922, 0.03543586808166677, 0.0478229467426577, 0.01084719692552162, 0.02029084608018879, 0.02615541193423973, 0.016686477090021776, 0.014407200806383646, 0.03309921947337928, 0.019065517173599333, 0.07176229805355111, 0.018834668068936276, 0.024366416600382617, 0.04244898551053578, 0.08460586935642266, 0.029761437589543003, 0.061188829131424434, 0.0371735546767952, 0.07761118783345146, 0.05161544585961008, 0.025876906415026997, 0.06793820930104102, 0.009288822785170089, 0.05236342346536056, 0.054162389433552185, 0.08923519312614396, 0.015527524914021696, 0.06329204308830443, 0.015951367846179395, 0.03417717796119471, 0.05752795924162192, 0.032554619059327154, 0.02350777567875001, 0.017706523161201228, 0.056809499003593965, 0.06893318131445877, 0.016465476045625347, 0.03029148999391304, 0.059546915018149925, 0.038580230001600525, 0.02760900248352799, 0.034864282220481865, 0.09198851312600798, 0.011362988603181176, 0.008228188418152352, 0.026812395531563993, 0.02720342021465542, 0.0275771293954383, 0.03753998985273704, 0.03545110557048071, 0.015981594802841784, 0.009562988416291773, 0.014650718132484586, 0.0275302563057912, 0.05588864982728997, 0.02381740926554607, 0.021014513800882047, 0.04648623439753729, 0.03294023707689297, 0.03551421206324332, 0.029826509097831386, 0.09836755873214814, 0.05435963409141668, 0.023627884858738513, 0.059388135634963556, 0.10316613430698073, 0.020579241794503985, 0.020136280180585962, 0.03349884923908018, 0.074107714538132, 0.015636805441200493, 0.011706364532602171, 0.09016243530617607, 0.011704374619218852, 0.03456653448783102, 0.06583731276013198, 0.06376270835678424, 0.02281589103081534, 0.02290585465098341, 0.07322724968675645, 0.0032689955673225585, 0.055663622990851445, 0.03289722507038424, 0.03431254186697545, 0.021493925878237334, 0.04835832345810148, 0.016774868314725258, 0.06318246187161534, 0.0832434279483653, 0.02339371859336332, 0.052565747286163034, 0.03262648959794352, 0.03919267899266655, 0.05555949632018324, 0.03771501029991815, 0.018536830320954323, 0.022973283794858766, 0.06088711306332581, 0.08768901319032715, 0.04551667352056792, 0.03547783437815886, 0.045921865084599105, 0.03084505938233868, 0.07211032413667248, 0.04853650401797026, 0.029214558063916145, 0.05397349130362273, 0.04213794232195905, 0.05574292458233334, 0.02065002257304807, 0.04694075819345252, 0.026277271625135216, 0.026484301141012582, 0.03194606562535609, 0.032285890737248045, 0.05124518790492608, 0.06362451758656291, 0.03748376282953447, 0.006232846344280387, 0.0316249005000798, 0.04526985531312324, 0.027463240849394954, 0.050530362754098834, 0.05889035085396421, 0.06787841613855093, 0.03257315455665512, 0.09199412088961371, 0.05892260698601604, 0.041247970319443175, 0.029178318274658055, 0.034374503058291254, 0.0323515483027985, 0.0586415944440711, 0.10483820547139454, 0.11856223396476238, 0.13899097970176127, 0.10293578698990807, 0.1406643915200426, 0.11754001220387798, 0.23045824660408884, 0.09351211645069624, 0.1629048432674139, 0.12636889207867846, 0.13196445190377776, 0.14973199205292811, 0.16358390360349612, 0.2163236945747368, 0.0881561736065534, 0.16071173272305922, 0.14879367224151088, 0.16626320418811616, 0.12520908092659327, 0.18569776698225932, 0.20175622625937387, 0.10518518201405964, 0.11899371000547564, 0.13604932464659214, 0.15951804516296234, 0.12214143505139698, 0.1768676996711762, 0.09723294421189255, 0.16270385243959967, 0.1572486475831078, 0.19076644983743468, 0.2264133330074049, 0.1342032825754535, 0.1712503752881481, 0.1430135541745732, 0.12476729334241922, 0.1526466501696456, 0.14658116435091342, 0.08759635485588543, 0.17257097297378127, 0.11161094366182243, 0.12282198925893154, 0.07983173198637464, 0.1768124340883186, 0.11657333181750391, 0.10326334320369268, 0.1015063205493554, 0.08961479735350417, 0.17624952800331578, 0.10084852681405122, 0.16664764243027858, 0.26444671795733515, 0.11293328802792296, 0.11510330868223984, 0.27607691324045586, 0.17954747523030928, 0.1814299830866437, 0.13103633638351195, 0.16917967027233494, 0.16158603822752354, 0.12188160101011877, 0.24217304863756706, 0.12332834273336396, 0.21628704492843923, 0.12891876210849132, 0.2181144250977424, 0.10719695954673714, 0.13902294088996228, 0.2651015699150101, 0.12415880502592172, 0.14769951482453655, 0.11111926077113998, 0.1037102942204764, 0.24163059710014254, 0.10356119052777368, 0.1446652244175634, 0.09388870995251403, 0.16388456247025923, 0.13687109184120932, 0.07831133090920987, 0.18534774140965554, 0.1334455296877892, 0.20006465815728713, 0.1458837179046485, 0.12531010494116815, 0.2071597048592183, 0.14545562797256056, 0.1465526658801302, 0.11031029490573753, 0.142022542835724, 0.17318969622494715, 0.14787905519047093, 0.09153959326325886, 0.11642550749163474, 0.1317504069377338, 0.08507614008962147, 0.16758587031114489, 0.18748400823002864, 0.13328918646420204, 0.12226803874176358, 0.2188707070965921, 0.15378931627398537, 0.161942238468797, 0.11424431727538187, 0.19771655270409202, 0.11842302812804138, 0.1577519673493601, 0.15232078701017365, 0.25712533823905454, 0.11864396788540388, 0.12840640250473254, 0.12784649948439292, 0.1310310503768344, 0.1420122925792971, 0.1607441075987393, 0.11590057638503852, 0.14482490778450044, 0.1902116183191538, 0.19188072472330064, 0.18428647980814983, 0.09936453789592752, 0.07177252532734026, 0.10471044498826228, 0.10000956860641319, 0.17494137158557294, 0.27626408384211604, 0.14679281912263364, 0.15072714026656844, 0.20410545020093843, 0.16169912812690582, 0.1263637822722235, 0.17891100938281707, 0.1453980947694471, 0.2022731211036444, 0.1823591711300035, 0.11979848536993228, 0.18091603002000242, 0.12504549051124242, 0.1598848787046248, 0.08216056266739484, 0.1608581321253892, 0.1824257135271065, 0.12441209667632658, 0.0598149576915368, 0.1533317779220881, 0.13338552968155953, 0.17644578440775796, 0.1064125697819456, 0.20629030231746937, 0.18344828768843607, 0.11820162871792433, 0.15340277895091042, 0.1476608120626019, 0.19345551038221007, 0.18009516680913587, 0.10550117796106685, 0.106374089185509, 0.08504070086224426, 0.14671841666342753, 0.17395475759140908, 0.13067667342482076, 0.05046159104113618, 0.09937060531228782, 0.1560604298907903, 0.1922546828826589, 0.07666933635670332, 0.11277752703115826, 0.1644647514988338, 0.12253838350936291, 0.31764818415526425, 0.16607004277888807, 0.1483137181569492, 0.15937945985746, 0.1868536097988967, 0.11390764461529833, 0.11607317599437891], [0.010698213891666985, 0.04761613747705856, 0.020529852106025624, 0.031095706114184954, 0.020846861204312696, 0.00895618453561779, 0.03391145270377879, 0.023315108396233093, 0.037684857079218474, 0.04568726980998632, 0.045168092023701444, 0.015146192200782319, 0.010359861583809459, 0.027761563147989013, 0.007866396692641562, 0.060134933465310646, 0.052968418420923334, 0.013444694641586995, 0.014544118913040768, 0.024011275475664486, 0.06553886022659079, 0.02913171140056464, 0.02005488142341135, 0.031993478806989814, 0.042100488283340974, 0.04607805509060141, 0.025025738681095745, 0.10901839487374791, 0.010130333980815786, 0.022311634722075636, 0.0202505785836688, 0.015329053557868448, 0.07662004625965511, 0.0019573436340227005, 0.06175957612633225, 0.10014597056133133, 0.05030756140308035, 0.00955720157963374, 0.044754040652825955, 0.026988614906346606, 0.021007795209786104, 0.06430138308074206, 0.04411938277283504, 0.13628717962532275, 0.04457879804014679, 0.008838190715910207, 0.012930332675516125, 0.03717786009092966, 0.015154261021844804, 0.024359667365769708, 0.013458520613400447, 0.03362403183634724, 0.023355929391278375, 0.05117118381144059, 0.04944781923005658, 0.057534080284136924, 0.009310155461031583, 0.02081537882106439, 0.039961053689401, 0.033655483576078574, 0.04244242779790394, 0.08679564741830673, 0.07765035024814068, 0.021262502207631068, 0.026020484698575833, 0.05277567836005361, 0.04259265380941572, 0.1750125411537386, 0.06819979768366584, 0.04413231433699689, 0.04577587936974822, 0.026998529999306606, 0.04033935173685032, 0.08390070074388097, 0.02471259449638667, 0.05464980138405677, 0.0331307593132219, 0.04186300868769327, 0.028258602908481995, 0.005668637431001352, 0.09972894293887001, 0.043491868662738034, 0.02917696421425189, 0.03775525289858061, 0.011731595638388348, 0.040765794579901045, 0.02255047603900875, 0.04704788026790466, 0.051575827622605916, 0.038814664397749214, 0.06856691467786027, 0.014040243733043392, 0.05229370946425104, 0.058404693244806224, 0.08394231463992789, 0.025839230210910884, 0.0754232713652234, 0.021897958734283046, 0.02247763065350873, 0.0992638816035563, 0.0826716122608031, 0.09740327620097707, 0.03701138152410427, 0.016361335968418468, 0.07583442309330549, 0.03316974552768854, 0.01940054274464567, 0.03434246526129785, 0.0692549612252943, 0.07010344190583115, 0.020523731063510624, 0.04767245643081204, 0.06801857192429804, 0.04436812003053004, 0.0412684670018573, 0.10213590692728759, 0.04125977190391671, 0.055815978726792725, 0.035256312393973914, 0.027092402583108317, 0.021015461834688342, 0.031077580473896478, 0.04698218822839761, 0.01468065014529613, 0.031308498526472724, 0.03548573657509781, 0.029338861575290084, 0.010360048317741002, 0.06131661259719442, 0.08246150498668994, 0.015542689624482827, 0.049706921657367106, 0.01528597164583663, 0.04174522266933515, 0.021878952092881647, 0.05322927135914084, 0.029015434575417352, 0.004895526395675036, 0.006631173281705068, 0.03663785237398359, 0.02704677055589855, 0.00953901273709151, 0.08464116302709426, 0.038098180666565895, 0.08104012077373844, 0.06908906488529137, 0.037501352208275954, 0.026931010840100147, 0.0446558473331313, 0.03384054360550738, 0.00798106616956272, 0.08171712033330433, 0.02208622292645516, 0.012922596145090798, 0.03285697864128217, 0.011666690754223497, 0.062300958971102396, 0.07671144820990101, 0.008101147100059016, 0.0805394210281872, 0.0634489455560763, 0.02896041988635496, 0.04354755176351436, 0.016983177197436174, 0.0864325064204393, 0.029187264266393842, 0.04738598934284622, 0.04473303452194218, 0.031939867974048665, 0.08030506707127057, 0.08227512345559175, 0.044503912945548375, 0.06551211609715415, 0.027516501197110743, 0.04848786509565769, 0.027684374043958324, 0.045514248852287574, 0.014461182234358164, 0.021834310234314012, 0.04478582181036473, 0.02976123266102326, 0.007804264089152698, 0.05125156175645609, 0.028416811556164778, 0.060305173523844256, 0.08142196197783755, 0.036548944039931225, 0.03346057165594351, 0.02069833973843244, 0.04134423309756864, 0.022786339189136223, 0.043750044123660174, 0.03649490036731286, 0.05746053201296637, 0.0858576110594215, 0.03832199708408406, 0.050658728446691274, 0.055596950358801314, 0.017651146495594613, 0.058970579411834485, 0.04427957558824171, 0.01674755728022466, 0.06880694534629583, 0.05811478259162076, 0.06515000165710527, 0.07468834789770265, 0.032665177038119685, 0.05898758656375351, 0.0375681703970317, 0.01748484987465124, 0.014587111767351389, 0.030679170703214985, 0.036473216248616096, 0.059902789672055555, 0.028893967504583062, 0.03037710989555044, 0.01945902015112581, 0.07785733188352278, 0.016057027650306064, 0.10956739646292503, 0.08226455144223668, 0.016892836278965397, 0.03463984144130542, 0.05094305431890873, 0.037587732452178196, 0.010901191760034812, 0.017743523292724165, 0.027383109967735027, 0.025975226139229153, 0.03988161803253236, 0.023249213343426105, 0.001829691121407274, 0.04418006076687767, 0.013313807562113771, 0.053256678154631976, 0.03273837290884506, 0.03845617738402179, 0.05676433429001801, 0.040117052173422235, 0.036382971091135856, 0.03360145905565831, 0.02147657398675238, 0.05877061131139917, 0.13702522873157455, 0.06404466701731568, 0.05232047274588578, 0.0363030489684353, 0.008253046056075443, 0.0064249309211699, 0.011703410306044165, 0.024887308508398074, 0.11339545355088289, 0.0256688331043528, 0.04757548119091699, 0.0527448394906617, 0.048885617945944114, 0.05042081218092673, 0.04426295148028482, 0.05274750930707782, 0.03647620016108117, 0.038151052224660115, 0.05855471624301807, 0.06266080962133504, 0.015173794348694146, 0.05686971351444241, 0.03206281550979662, 0.05549603359653585, 0.0727254544354735, 0.09415740763107616, 0.05703059197854131, 0.03190967644895277, 0.0700552013492392, 0.023153674518389088, 0.020973462979459477, 0.08354646934857292, 0.018111528948910775, 0.0349415153745682, 0.05619492411853806, 0.05513691072983127, 0.047971234551721045, 0.05018280015417165, 0.0466446805324766, 0.07111051810845252, 0.02878209185456076, 0.02166683766840687, 0.012976824636420897, 0.011506726807584206, 0.08788643404841424, 0.1082321664979381, 0.06483925341237938, 0.013990093702300182, 0.06583340571171815, 0.03134628006767842, 0.030976311311185844, 0.03497752533744901, 0.013842749138993603, 0.05298622613472324, 0.028210528976013585, 0.013700604397473077, 0.025356179215915264, 0.04382563401914893, 0.07014194548490547, 0.049009873576822786, 0.01915337788241525, 0.023891309937161785, 0.08371299388067377, 0.043169736351457336, 0.05258062471365256, 0.06148135980531093, 0.02438529683727651, 0.06079330176655805, 0.022938589587987914, 0.03575774758393246, 0.03554892350709246, 0.052696116298677466, 0.02883584058332828, 0.0524928272070904, 0.0436008753134839, 0.08373108887744528, 0.02709705848246813, 0.0790300899215283, 0.06224140329586883, 0.016026324761520713, 0.042954653336275975, 0.13491200583596386, 0.025540611053246166, 0.07116522444712539, 0.07716592987098041, 0.02246492700050435, 0.06356590802991582, 0.017117742456555847, 0.04534370235858425, 0.034039577078675075, 0.059309538844372, 0.009572368205314683, 0.06715478480703409, 0.018546038697804176, 0.07435100874112499, 0.046020165656603156, 0.038518280301603584, 0.05207791781773971, 0.018943056103683287, 0.038423622477679484, 0.03232440963808087, 0.06766073225486664, 0.0455075609047086, 0.03544285480353621, 0.06754761171196738, 0.042962907933660095, 0.03464891575276852, 0.02119146287441254, 0.0340058807013256, 0.10414376208979277, 0.07729824091638289, 0.11037059368625765, 0.15244133860593842, 0.10908152817958787, 0.10400985758150778, 0.15901110946170746, 0.17342309257195843, 0.14924820752874499, 0.15995905133745364, 0.09479832444940844, 0.12724834569399396, 0.07247252284639305, 0.07267969600375622, 0.15929422491500456, 0.14785375896721117, 0.1461828905608385, 0.14351635300103696, 0.1301474752084863, 0.1531273396986146, 0.1809910913148234, 0.12037279084324838, 0.09408858995283804, 0.1846785176425211, 0.09682352384251934, 0.12038928471625814, 0.1838568883437303, 0.21152092083807916, 0.17601936454734496, 0.1296455497222562, 0.10972753182173738, 0.2329098811793712, 0.14214130178574594, 0.13599638797102437, 0.15330988312921218, 0.23280926319139622, 0.20152689017836126, 0.16354671769565152, 0.09398209607048381, 0.17157657552630673, 0.1930938862384327, 0.2206059422103628, 0.13632942171346757, 0.2398957756738509, 0.2563281624668068, 0.07935740098717713, 0.1069912955825848, 0.12987505434261215, 0.2628812938928604, 0.1398045037903132, 0.1206653981259273, 0.1498946784845283, 0.19562265054593164, 0.188176199313133, 0.203914265298555, 0.135180167252979, 0.14772275793215922, 0.09597664428574425, 0.18191767465924064, 0.15310098627401938, 0.12098370765846585, 0.14259551531605183, 0.2240677556443599, 0.1550520436778184, 0.1487005006281599, 0.08854086465773084, 0.0909835666478161, 0.31599606958127796, 0.1678878774926547, 0.14887941280199637, 0.12222748204705217, 0.12991847620616037, 0.1353669088454016, 0.1806632669702653, 0.08704996562653011, 0.23379272090331202, 0.11532176631472765, 0.18204702094437616, 0.10546632862139134, 0.11294071141990925, 0.17947642823621152, 0.15505189046023354, 0.19581326854325112, 0.1711971321774106, 0.10629292216993148, 0.14330914153927757, 0.15611125216368707, 0.0916606198335367, 0.1390399480418813, 0.23706884994622202, 0.09212686094425379, 0.12210752033898908, 0.2957998162075397, 0.12661726544460944, 0.13519158196305076, 0.14563803350733173, 0.19357266054759104, 0.10010499251826156, 0.17621390491483674, 0.16716392440420969, 0.1711667031650582, 0.14597587828193942, 0.1773398856241857, 0.1832594929803764, 0.17470757687284102, 0.17729117775395994, 0.18844072947338705, 0.1382336251798176, 0.12589054677875774, 0.2555743625928318, 0.11656092119313056, 0.12117110808650333, 0.24716529123965772, 0.17309076363040557, 0.09636486700225262, 0.3217697065443762, 0.22561519196437252, 0.09892781415293295, 0.14188032627346056, 0.10606206157394957, 0.15372182392785627, 0.15985765193979587, 0.13286200051586475, 0.13617462598748747, 0.10721353768941858, 0.16239891880221907, 0.07627674693902654, 0.07236558463304274, 0.155652426784077, 0.2175964730521364, 0.10739147693159119, 0.11519628877360975, 0.1453443153971626, 0.12873113185407656, 0.10445074118193119, 0.19857788067911902, 0.18947140884495553, 0.17824501850672309, 0.13046610649795304, 0.11364853835754818, 0.12477834033028734, 0.14230470833999498, 0.2434724869747316, 0.10570763865666044, 0.19973991348618464, 0.14289432025003818, 0.08741836964843736, 0.2058036679462079, 0.2631710589893403, 0.08495994753414586, 0.09962467837237543, 0.157020567886291, 0.09119374286984244, 0.17495107025869433, 0.10645740890815374, 0.09388284937989327, 0.1791580114513636, 0.15418832550846762, 0.07323169299671728, 0.12727803160105983, 0.10567213048137004, 0.2623927136582713, 0.1688329541995641, 0.12592864433123221, 0.17745429319479775, 0.11453065795884018, 0.19698515324102295, 0.1334852283640254, 0.12214904230448509, 0.1846760814829219, 0.13940388577118998, 0.18636680688829194, 0.14872313086544314, 0.051215184071371635, 0.17028729551501814, 0.1529768034214935], [0.028149592427296505, 0.02973889928281067, 0.029428535997266733, 0.04248102330752919, 0.013493552856567888, 0.0023989399356181707, 0.13964318099521822, 0.07018485406954443, 0.012968062505786939, 0.02858329395342979, 0.03940999898458681, 0.1283190378378476, 0.017055183716659105, 0.0323966478989009, 0.04435626098946218, 0.007698912635415553, 0.0584892885038449, 0.07543041130467769, 0.06472168189864005, 0.03654828903475597, 0.07649199466311163, 0.03570692914147531, 0.024168101334643942, 0.007505475434534733, 0.0275962432891491, 0.02954203575368851, 0.05456255929123971, 0.03937709167779934, 0.01297349981482952, 0.02191220030879542, 0.04225362925940464, 0.019808714390702305, 0.032003765452593085, 0.02618572220296389, 0.007107776689207963, 0.053198961090416684, 0.011790211898304764, 0.00970058355315198, 0.031719742185105725, 0.038840971857069, 0.011924368257994854, 0.09283844171272171, 0.022072412276400194, 0.06614431483490814, 0.08280861176430218, 0.01799023424785945, 0.014186240939213144, 0.07782969143121474, 0.042197792941043456, 0.039817201529419234, 0.06404336849828401, 0.032134458137255524, 0.05640960110711956, 0.04444244971138336, 0.04760017220471655, 0.024957395977370685, 0.04740840507551067, 0.02483234936071019, 0.062499287643379746, 0.050080255455067085, 0.06910178194483442, 0.03293771664762209, 0.05288301876956417, 0.02443517107636698, 0.06784143707444591, 0.026450717761631937, 0.08469742452425343, 0.07647008454847722, 0.061915390749251654, 0.0931104948563922, 0.07026405990003579, 0.0389819473568951, 0.04067674451958268, 0.023745950499188997, 0.04038244035215147, 0.05739860529560716, 0.004030223860735855, 0.025301721855817784, 0.045845520592504935, 0.016379302645462657, 0.04479203095299102, 0.039724336351237954, 0.02916513198626138, 0.02070014579071393, 0.07336641721908124, 0.028670518809268554, 0.04815555530630293, 0.05446456515440538, 0.06444919974573197, 0.05593358471448864, 0.027353573447814392, 0.017604771363098296, 0.05271898402321724, 0.02082572866892142, 0.04864001015741979, 0.023389422755327918, 0.028918884514320283, 0.027784007608950622, 0.07107139399815952, 0.07478801593665155, 0.05001332618356232, 0.03030978417354486, 0.04105249532468377, 0.0932683319514317, 0.009232497128147272, 0.03459786748393409, 0.03273282643227327, 0.0345979057883303, 0.019623244504234003, 0.039039660590670766, 0.011426211924352234, 0.03250305368114383, 0.10412605013698341, 0.049770660172667236, 0.08739308108605685, 0.0254371355573136, 0.051677602403346574, 0.047982626279155095, 0.020080215951067307, 0.014537836992061667, 0.028135835403396238, 0.01898744515323591, 0.1231292977688774, 0.00915310456372437, 0.06639198339994877, 0.01867546733739155, 0.02488989405514252, 0.06480053532868624, 0.11067048646509649, 0.01690021753611584, 0.03262219184468831, 0.01662743086325786, 0.06560619935513505, 0.012855254143716828, 0.03220297321076355, 0.056845160396469224, 0.09693591660189052, 0.011304878918904693, 0.01727717301447786, 0.021290581245275757, 0.0348213698054033, 0.03773789334621641, 0.06599767794532162, 0.04877274638162025, 0.01997754867789486, 0.044718896369299585, 0.036996243626720486, 0.03221881590903767, 0.04078130019948848, 0.023914192983460043, 0.04327989213408963, 0.034880002344688105, 0.050053871386954864, 0.074855140560577, 0.043721354130895874, 0.01757268568560962, 0.026555901633635647, 0.06539644448146706, 0.052480631087335854, 0.006382263654227099, 0.03228297960313578, 0.028906514109562964, 0.05746165816221507, 0.0700613760179089, 0.06763464696104489, 0.010158281825903443, 0.06741453457864062, 0.04245127228298976, 0.0627377401706913, 0.08156264636425242, 0.03279182669376174, 0.04009772377509264, 0.028662681729803165, 0.06342600122274411, 0.02110346426977025, 0.03939376941191093, 0.017939168742046725, 0.03758968597638511, 0.0743661696211465, 0.06541367379888412, 0.05545362296904768, 0.033139810642047275, 0.040037719938423366, 0.06434925591513034, 0.02191744801107674, 0.04133829208571584, 0.05511753253578659, 0.06315778617957427, 0.018366753056104627, 0.024173684200392138, 0.013634711259885902, 0.01891260410869314, 0.1158586560538219, 0.06209629092125162, 0.04178737665736868, 0.028110202101449815, 0.05901970863041859, 0.057928519804150834, 0.02192793958519976, 0.054764752877095056, 0.072546320096139, 0.006935695146826367, 0.09206741252132962, 0.08590246550738813, 0.018041690458513556, 0.024769828925209663, 0.06220227918557583, 0.012344497578939604, 0.018678039477597323, 0.024202199908153667, 0.06074940492849677, 0.07777952033305362, 0.012388444212715954, 0.026138847198096976, 0.012269459266756332, 0.028904882342284246, 0.04811956449562023, 0.058612034941512736, 0.04025101413830154, 0.04294309306949858, 0.07147221120014306, 0.055404662289806915, 0.026384853352341923, 0.07829626195973928, 0.015957479312595342, 0.011108246173769718, 0.05785158925479459, 0.02798055512680402, 0.07918018186765333, 0.02920491301694945, 0.03528096510337726, 0.05645059064150818, 0.02751539994571959, 0.03542360684443866, 0.07255347535735177, 0.037675273319285725, 0.04514367680155462, 0.0394876343348334, 0.020934628067357887, 0.021546856808145682, 0.14282034680006966, 0.013247799511337954, 0.08808805306832637, 0.01380178737529223, 0.020857569198274327, 0.07316071495053268, 0.04201203194116393, 0.04217413231550206, 0.025037557502547582, 0.021634324896900405, 0.09609240017110303, 0.0622879124937519, 0.026444790156317816, 0.024281413399524266, 0.03324035585166947, 0.009633536495628857, 0.050654852041794415, 0.028033553089405742, 0.03009432960572022, 0.05903645148200374, 0.05584740365344671, 0.008769506145448936, 0.03897990573257689, 0.04255832540952871, 0.06553383468980752, 0.01847102336825863, 0.03896711589468103, 0.028020533425132596, 0.04641237203031779, 0.03962456105997966, 0.05079016232142045, 0.036049998635726596, 0.048571996871502175, 0.03871533726792663, 0.013567233277905374, 0.057133994696121064, 0.05432485369965435, 0.0375377988412736, 0.0028633089189703067, 0.03232283532739647, 0.032229422396349336, 0.011428062984299277, 0.02274052138560482, 0.04142263070529988, 0.015223454083165815, 0.018802134230011897, 0.03550750879390586, 0.025598506232903852, 0.048456325255815065, 0.04419364350577516, 0.05312340949932414, 0.06614262178059548, 0.015956966033686074, 0.07481912676725658, 0.05027291507670476, 0.013038237117260936, 0.007342290088173844, 0.07805324354839903, 0.049926696961084684, 0.0033407203098308417, 0.04369296674286166, 0.033593985867956956, 0.029033410828560594, 0.039079374588665464, 0.13090369592030204, 0.057612389791756875, 0.03656034725868414, 0.0705599230563929, 0.026194775447009072, 0.05862665955998725, 0.05989926183716424, 0.07068004564292009, 0.05010580065690222, 0.06659216217456326, 0.04610479538959842, 0.015473193000821818, 0.02555264820975642, 0.0515335165865479, 0.055373513154805674, 0.016432097594764446, 0.032397306734515775, 0.056824433887677814, 0.11459523917085702, 0.025623145535768523, 0.046031852327888055, 0.027011463478688272, 0.08541331836773504, 0.01542535559800003, 0.03805153357285646, 0.04223199493642296, 0.07952270743947837, 0.009623458608984947, 0.05756218421963915, 0.04491897938292354, 0.04709361954742382, 0.0655528566529674, 0.017361613140711864, 0.030755068949093262, 0.013441666679066277, 0.021551824888334643, 0.06964041836439602, 0.0679932757010383, 0.054209212727484204, 0.03343038396128724, 0.04741138898797574, 0.011877793942638224, 0.010642116145801642, 0.023640452531136336, 0.02709634793591836, 0.010799384420557369, 0.02183118268036314, 0.047828623454176614, 0.12470422132361321, 0.11676846973357663, 0.12010076834309487, 0.15048487262139398, 0.1449346268970159, 0.06920770892212469, 0.1526164969489459, 0.17200679518282416, 0.09388052047260347, 0.14103157746215023, 0.15183455100463283, 0.15596180373141844, 0.07807267153815878, 0.07123378165546926, 0.09932603431685318, 0.19346458086323357, 0.21532387322475835, 0.1927108116327755, 0.1706143997369274, 0.11210591306970005, 0.15604310098194307, 0.11858929985112722, 0.06324051601451731, 0.1414621801626298, 0.14440581172464356, 0.08172530215233564, 0.23477489158751505, 0.2140511560343927, 0.10882056032818173, 0.09748124862991034, 0.1781724699802937, 0.13722389065209897, 0.1528048779695265, 0.1526090658960804, 0.07056901652005411, 0.13720536664608987, 0.07856718129328183, 0.2203909013300173, 0.19339800782261357, 0.1567500469184691, 0.1358527158417048, 0.18990460092261915, 0.20713663029093898, 0.21018661017860138, 0.12522536029498424, 0.17330067172165842, 0.25885513412856287, 0.17172029362090174, 0.08061259008583524, 0.14960471420518814, 0.14775828909008734, 0.1330270005329963, 0.16156769808261626, 0.11758410056392032, 0.17312626414481672, 0.1652849865176024, 0.19830933621814176, 0.14348886576631378, 0.17697006433961854, 0.08066701297197612, 0.1189122365547284, 0.16103071641297112, 0.078260094948834, 0.12425035253287324, 0.224433378767102, 0.05682526126263603, 0.219878557048017, 0.17228637130991106, 0.08893919207396046, 0.15066295742027222, 0.18369158189142906, 0.14578725211322308, 0.06703188132134176, 0.07968723248209685, 0.15017849873871575, 0.1546447147284785, 0.11737129666031369, 0.114805277497057, 0.18011479398175595, 0.12059998953895223, 0.21948350082722404, 0.14950120040485937, 0.10596922703928525, 0.13521150024908205, 0.13605825723178927, 0.11877294644833573, 0.18395649509564524, 0.09967108797882834, 0.18567294573351262, 0.15138237526820553, 0.10171944620989024, 0.12609686957852495, 0.1741891038874465, 0.12213537529591592, 0.15184095549967982, 0.10699330273294642, 0.13001403801383513, 0.13323464100399326, 0.14529211416600213, 0.15511371375572297, 0.1613877287074443, 0.12418737244461814, 0.12346520434103667, 0.1727090220177366, 0.17561033488281313, 0.1175094299739407, 0.149265750942211, 0.07322397849131977, 0.10645583076702972, 0.11668583949006374, 0.16693817361468272, 0.12362198423474066, 0.2733120712782106, 0.1598228255827581, 0.11296799947177211, 0.1507885345528203, 0.21293157982009076, 0.12648506165151635, 0.15714413786847747, 0.07958172685316495, 0.07890131054145676, 0.18323416611359966, 0.19007398296267758, 0.14621220108482147, 0.19369903441158035, 0.15585447481322676, 0.11705753769004539, 0.14934642000063775, 0.22704782234805249, 0.1553590151090776, 0.11513502472230505, 0.14317225694896715, 0.133013992360042, 0.1813195898167549, 0.12197155505418779, 0.22242636630131354, 0.22390649413629887, 0.18216204138532763, 0.09106873264235836, 0.07194124087090455, 0.13705047898955885, 0.1293805599092476, 0.15108585327623353, 0.09977170596680335, 0.16810546178490887, 0.09641256363641831, 0.19474134299783938, 0.07560962991368386, 0.09167670767994658, 0.0892873024267535, 0.18126651524536072, 0.1540350313148191, 0.17879431887019068, 0.16408863297152906, 0.2918289373478582, 0.09917198935703886, 0.1206092362201983, 0.17205818436078488, 0.09733703257816453, 0.12475840672249756, 0.09386140657889266, 0.13825861496790764, 0.16436941951753634, 0.1327420617904394, 0.14223594428791156, 0.22393506921587453, 0.12959756197467928, 0.13332891578395523, 0.2534342500110788, 0.16669345448815054, 0.16724264759930874, 0.17382032448245635, 0.18355587707652202, 0.15666320319137267, 0.07193490532377074, 0.15616846360987233], [0.07560348588853114, 0.038496626826423797, 0.021543970571890957, 0.035412962052730784, 0.014094414767779171, 0.029251855054509737, 0.016646581146145062, 0.03274727102008558, 0.05325082141245085, 0.03607414572709992, 0.010280992832004784, 0.03366640415943919, 0.03804658847530523, 0.0481735009159292, 0.07458180038919372, 0.031400392688209974, 0.0418271481119577, 0.06588316312240017, 0.014482795489921927, 0.02886856211379411, 0.0386384641751647, 0.10598726074902282, 0.05387705232527468, 0.011943997345834732, 0.01786834008300737, 0.07318419554541189, 0.0283205640997978, 0.07036044142178952, 0.02843967545026493, 0.014499216584578879, 0.018509931058713028, 0.031181494555165692, 0.0826439411649781, 0.030566597913181594, 0.030601184867743044, 0.02184284828423012, 0.012630914871190346, 0.02646809455097443, 0.018661480487114, 0.04999472939920041, 0.03368951320167511, 0.07071033675944613, 0.05166119663044811, 0.05594361280541747, 0.07265904227331763, 0.05859671701346675, 0.025599348929620562, 0.03548428866892092, 0.0740932354763631, 0.036235928174949465, 0.03581925295293331, 0.0872012143654208, 0.06512694241058442, 0.09521512224549249, 0.0718589783495953, 0.026997685387370088, 0.049553152489205526, 0.0044337022606463685, 0.11317087487588007, 0.024043227087766416, 0.04235448473463616, 0.05238187852345648, 0.04077239442736872, 0.03055536706421164, 0.023064850454008388, 0.03667443690280761, 0.05518351951914449, 0.02054155984472844, 0.011415250163765685, 0.06218081340193749, 0.05423920506971979, 0.04307627745513474, 0.044965741389821616, 0.029029339071243044, 0.050854498385301525, 0.04132762814180986, 0.04372898819706133, 0.03242422706417499, 0.021487048323897105, 0.011470130787441328, 0.06299796108637126, 0.012861122377216818, 0.04988383817216081, 0.04716481975910645, 0.041295958067020105, 0.04890791110454067, 0.04408341111435045, 0.027748918866798766, 0.0484816023268767, 0.0431696405904668, 0.07333023488641748, 0.02659441670402885, 0.027708090210874236, 0.035599623205921346, 0.045939431480702855, 0.03656155001672526, 0.06138299411583332, 0.06499163596139801, 0.008682897990389217, 0.028665313241823066, 0.022138567799101436, 0.033039292245502436, 0.011793429467586741, 0.05443399058534734, 0.01544768801860271, 0.01992691409653954, 0.05630501861413641, 0.06422163715826408, 0.03860813475424244, 0.03579914314492095, 0.038749550754624995, 0.005280152329378912, 0.01795740738030403, 0.020087715951846014, 0.018494027073404962, 0.09599944306237083, 0.018601589648413564, 0.027412899296670675, 0.048961663663747816, 0.03135597491036019, 0.030971622853089246, 0.018157381226398775, 0.015505870481232002, 0.07504944344081226, 0.06593649816368857, 0.058357195793500835, 0.02586153486082631, 0.026977657933809587, 0.07139507380704727, 0.043049759321635774, 0.026843736188546307, 0.0535781171563412, 0.033642961868956205, 0.03219275742829327, 0.033634925606630506, 0.04167666546099129, 0.031622914417136105, 0.10952549145346689, 0.033280751667916775, 0.0959381560284284, 0.027859863719993064, 0.06502309153156896, 0.07837993408282919, 0.043735760414311965, 0.01972598838619888, 0.024479251775530078, 0.025009551243255698, 0.005646125458541417, 0.04600258776918054, 0.006053363434940336, 0.019652422878050038, 0.021558396007505157, 0.062190772544953137, 0.038268309642350486, 0.018037639768613924, 0.03500030879231711, 0.0164798574311839, 0.022404270073879632, 0.023526087095360124, 0.043620100289943724, 0.02489956208474694, 0.0032207909211020677, 0.00800774901196541, 0.053925924904404156, 0.09085133221120605, 0.04095771492669179, 0.029557483916681622, 0.05754189821140421, 0.02907729809052281, 0.034937363178018606, 0.02236103015621343, 0.04737635578719839, 0.028723172032304352, 0.027389761526137594, 0.006652930657559585, 0.029675218224104856, 0.12055949413127477, 0.012057007763594871, 0.023118108886504368, 0.040216674247095664, 0.008189617806384641, 0.05558806373887966, 0.0442964525052136, 0.02840908172900879, 0.05266885122945232, 0.04890908321906482, 0.069224945900421, 0.0664377877969415, 0.028294003831462997, 0.05724446457480231, 0.06226621305329665, 0.09909494389449397, 0.04289911962264488, 0.0436864243519883, 0.05100046494795431, 0.04452290043475167, 0.011270052561866901, 0.014706204923230314, 0.03133777266127929, 0.033825601060544296, 0.09398755827738393, 0.09553230562878233, 0.06447842600004328, 0.09472825804785376, 0.009369778168958523, 0.0372079711767935, 0.03165497902720686, 0.022681517293676737, 0.03411978648434724, 0.020059728844752236, 0.012125351424929837, 0.05921476227681964, 0.038397613792650165, 0.08251322358245812, 0.0036180087068538756, 0.04956823292999499, 0.02053631980332636, 0.02264495574749045, 0.0203966562290706, 0.029525200971552444, 0.05823970471899356, 0.026485540288230105, 0.10450448991069872, 0.0751223290459283, 0.014804554333339536, 0.01505671696166598, 0.050718123243460735, 0.07850597086813181, 0.05074838754690943, 0.039543635362098296, 0.04476454371826784, 0.0667105074371061, 0.04096022769508343, 0.005441901739686728, 0.043391549449053504, 0.035712173013317014, 0.03066400024709442, 0.022799152009669813, 0.06700692217676871, 0.009598501379631702, 0.01853594740462159, 0.017993754421871518, 0.07726896103591689, 0.028395535379287698, 0.02724102747085835, 0.06944417728171234, 0.010182224946366924, 0.05108927752101614, 0.040252680379536845, 0.07613685928405294, 0.09552302064314004, 0.054653719923789465, 0.05307771235464081, 0.05618350174758704, 0.046935656047876806, 0.07621477042595226, 0.023316270934658188, 0.00813117391625119, 0.018320937167793032, 0.005680648253239211, 0.10615011571996635, 0.040143528172085365, 0.09186808410431109, 0.05689006847059054, 0.012733128237267657, 0.03260443392660349, 0.09353938918080061, 0.05117699458834626, 0.04164809038141563, 0.12008046701310143, 0.06258387524153917, 0.06227717960193273, 0.01948617030716231, 0.029993144712681254, 0.024194745872650417, 0.0489180272955808, 0.01792501335242583, 0.031646057933328614, 0.03088236977947095, 0.055248502927321586, 0.053875255849092245, 0.03815869778214443, 0.012078054114094666, 0.06368778112734999, 0.02138258840498184, 0.006626677782004399, 0.044070219080294334, 0.03449935623775086, 0.004753484597219335, 0.021097513681818402, 0.052201974265758073, 0.08055644350186472, 0.03884280280720803, 0.045325408178952434, 0.048446147777741, 0.001602340883935892, 0.01409606281442628, 0.051198732333197716, 0.021188455979309736, 0.03177617413682803, 0.0030925224259150245, 0.08277891819635708, 0.03212311620553655, 0.02418442283787074, 0.010246232550050463, 0.014746055859441479, 0.0749371272902335, 0.033191785877270084, 0.08097196959199444, 0.01048859691382536, 0.06625059421264357, 0.02246192393584117, 0.06455224623242695, 0.14251988711616687, 0.017675431482794306, 0.031112173174117363, 0.05972275900984964, 0.07588605741940199, 0.03535065612184905, 0.04073943732486617, 0.060185545064028234, 0.022356389578612103, 0.02121867431748298, 0.036004841583029884, 0.04678783172200765, 0.04473129167191444, 0.02426849907234071, 0.014973763046005081, 0.029439732372280092, 0.08243760304345239, 0.028625108947556828, 0.013137067247542643, 0.01684327039026445, 0.03658922111255027, 0.0072780133961069015, 0.030084159788525397, 0.09288462149279733, 0.01708461681470996, 0.08129729648991939, 0.0899643709342326, 0.04851318813199478, 0.049048304377544316, 0.040268534569129835, 0.05221202533932463, 0.039972483721231265, 0.007062981613055473, 0.046957600636467825, 0.021972610172064557, 0.054111253064606464, 0.04399149588519528, 0.06525605886934266, 0.026621296814072038, 0.19668778855233424, 0.09522944042879729, 0.09207865869205806, 0.091206191798612, 0.07437453530127965, 0.11746246878418232, 0.09549600838292992, 0.10607979650939665, 0.14071179704079706, 0.20088872361567714, 0.09944519163259577, 0.16359436836454178, 0.1023212159352918, 0.15837390816980795, 0.17727204087761142, 0.1975311747481746, 0.21315232039459292, 0.19497043393071622, 0.12622422403505734, 0.08541300427168609, 0.12760053163454418, 0.18607632166916327, 0.12847248524908098, 0.08687232515864796, 0.17270673907572226, 0.16956564069034594, 0.18005353759133047, 0.13907056091533554, 0.20318953080042718, 0.10972207727571649, 0.08932448833459809, 0.08509181424855225, 0.16265865325206713, 0.11324458019507509, 0.10284122875741414, 0.15965090013079106, 0.1246168106914528, 0.19769234432568475, 0.1188805741408179, 0.17911541696277358, 0.13138430884047864, 0.16047234556848006, 0.09706085022058218, 0.11353675080763717, 0.17077003815962424, 0.15717260569574373, 0.15235541418435114, 0.12633660147267003, 0.23257756755957681, 0.17625262299852987, 0.12554170098155737, 0.28803140886368295, 0.1261917342461886, 0.17588787321602145, 0.17145697387956804, 0.16994770405994308, 0.14634211427502095, 0.07185148600969585, 0.17582882315881793, 0.16706345963381952, 0.16266943977004097, 0.09511782141822962, 0.1561952460437052, 0.08667265966294274, 0.19689018898192914, 0.08816327524161147, 0.1849849681339918, 0.0835886654714423, 0.09173540533670495, 0.17483827147272327, 0.1620137757591663, 0.15300665020702348, 0.10526620347293154, 0.18588640847273413, 0.24768903490997132, 0.14654805403082602, 0.21008689617437704, 0.19275441735742554, 0.13390011094029874, 0.1638513602196209, 0.19669256894098175, 0.08075415547336302, 0.10202687729390399, 0.12476130253485135, 0.1271416526287794, 0.258105501772896, 0.12886827691428124, 0.19098104638678415, 0.10546589961215373, 0.08569284852954649, 0.21461761676736418, 0.22641094281308113, 0.1640937810823802, 0.28038652553673715, 0.18086007495801296, 0.12863532489826604, 0.13768107660355108, 0.12055949413127477, 0.07777948968953664, 0.13198201063900225, 0.145775101958744, 0.11803309703546187, 0.17811150470327947, 0.136035657638023, 0.21539777006593444, 0.13050929853512397, 0.12075672346738078, 0.19771460684076433, 0.20240997505043784, 0.11261520066088247, 0.2110312221151206, 0.16212639068403553, 0.09287792588433913, 0.09427035197375283, 0.17262824570700047, 0.2523601794194791, 0.09684771689916812, 0.12378409610039766, 0.14452346750805456, 0.18970121990048117, 0.15188748768020063, 0.1292373627544411, 0.15866008797480216, 0.3428228445831807, 0.08948191940303772, 0.294929570969074, 0.10617793237249698, 0.08449841020328384, 0.14000975406698643, 0.14383905987826087, 0.1621611251105224, 0.11664391149796786, 0.1894804946477375, 0.15073210451631777, 0.17104386862727905, 0.11845343415775608, 0.20281381063884307, 0.2613199147726259, 0.08707130117522133, 0.2627012938741715, 0.1323830423456046, 0.3028534022310088, 0.23418138795081647, 0.1473153217305099, 0.08703665101840612, 0.08402994743758634, 0.18264775645107995, 0.09115496349911537, 0.18792000418949514, 0.16012015962792983, 0.1247094460432568, 0.09960743373319988, 0.1423102088512913, 0.2019428452777286, 0.1235446553196638, 0.0968408221078496, 0.07449382285196936, 0.1715622343603642, 0.36211778019224444, 0.11217854586580109, 0.1487751329137433, 0.0639599645059676, 0.15079130779110617, 0.16832727488250504, 0.15243010775696847, 0.12461517126329484, 0.08194470207297033, 0.14715600608577653, 0.15735220734871205, 0.09765853669734732, 0.12458591436546658, 0.10384063641991347, 0.09457059715303684, 0.13373891071927163, 0.20943544564708588, 0.1280247911270107], [0.03142240239427455, 0.009066211998522764, 0.06593017027743402, 0.04645447239219662, 0.10593385675982123, 0.0574950251217571, 0.03679940882589548, 0.04255703072093668, 0.024204515408904805, 0.07627467084075175, 0.021958288158320134, 0.052809110437069214, 0.011974559465963996, 0.0313633140326748, 0.015772831055425828, 0.026818771298313816, 0.019270978124451735, 0.03665725738110562, 0.01957543487209947, 0.029385294164380724, 0.04035459305610388, 0.04519506214907573, 0.03347603131025549, 0.03789304530308132, 0.07293064342511278, 0.008884952722808287, 0.09476789543705602, 0.04728407283583957, 0.01154609415079317, 0.058906932827085264, 0.0017358329017541463, 0.01779751142396802, 0.04296234868947537, 0.02733884923790972, 0.065766480270653, 0.04815534846256337, 0.07030630198818061, 0.004202924497921261, 0.02356535867757855, 0.0373020927391706, 0.08733842837353868, 0.09296167461622147, 0.1016848803227467, 0.06625064783879826, 0.038096614016760746, 0.016624603998817263, 0.025438698376679135, 0.02569750777535862, 0.03633492588696461, 0.02775393865792261, 0.03686447650374424, 0.06327950605942358, 0.07362298772580202, 0.04184859091295831, 0.038609253242611885, 0.09280310973765389, 0.03415021166626004, 0.013706810667269654, 0.06326859696738182, 0.026340500691965706, 0.06426415120762202, 0.017802255423439127, 0.04858972797650964, 0.07151285216452614, 0.03086953206107982, 0.039349186925157424, 0.048058970771249265, 0.03674358782929279, 0.032790022556700056, 0.07333401936076342, 0.03607686533923111, 0.08996174325265231, 0.1039198728939218, 0.03874825989647258, 0.04917128830246868, 0.039244481858106396, 0.11057089503494003, 0.03572318935766816, 0.052517426290339043, 0.05785721617059843, 0.07384687692167298, 0.07439692039042711, 0.06973522174502574, 0.08295485794904732, 0.008761344436225633, 0.029229086921400124, 0.011834864290581356, 0.02347322511336496, 0.08964752462962944, 0.04365620984425468, 0.033893667972616615, 0.08372708989848053, 0.06466505267927725, 0.012571137988068646, 0.048133974609475945, 0.06100810132920743, 0.06047858901682401, 0.06206804908992303, 0.02959940233267844, 0.03626636101774151, 0.021390406332249125, 0.03702646579533335, 0.03229149083997453, 0.019191444791372747, 0.07070007118126077, 0.020923740042734052, 0.05220656696286413, 0.056615602149958574, 0.10498180099192167, 0.046040746608688954, 0.04150566697541264, 0.02540716428249594, 0.06452025440070899, 0.03723860703288548, 0.04074875295402543, 0.03729789840778516, 0.013950543455599297, 0.038856404698303634, 0.032211538073757005, 0.05289680835220122, 0.04572373942562169, 0.05642194278357972, 0.05403481281152176, 0.04841882142148191, 0.06537702415258655, 0.08882057868064412, 0.013285439326277664, 0.05468961880392125, 0.03377430764357409, 0.04210638716035793, 0.019942793183990067, 0.025303146779356946, 0.035637724588835434, 0.02099434270583574, 0.042229175732861605, 0.0421733700580174, 0.015955527703608238, 0.030376962423625014, 0.03476556413055908, 0.02120580787079469, 0.06993970593377467, 0.07612088635083168, 0.050577856374964605, 0.038611884754631794, 0.04499511320083853, 0.03031317219738999, 0.04841676447540522, 0.03712048010540105, 0.029574569592612888, 0.0772453578669698, 0.03147953531644758, 0.06335062200143453, 0.01864489851399295, 0.050939032357306256, 0.04315727976180854, 0.02476616510971179, 0.035699180162121216, 0.017249193568263325, 0.1359341816315728, 0.08203086398181417, 0.06941808432701134, 0.08239191355964831, 0.04274097992287528, 0.04350642433329936, 0.024181921560797962, 0.04017106903296325, 0.01907586702145636, 0.015416691143576418, 0.044485722187786333, 0.054095716801502054, 0.02965876457071112, 0.03355456681381311, 0.029154251622516784, 0.042868257770615245, 0.009348091177432048, 0.03882096930136604, 0.007960371261898188, 0.0375960559974755, 0.036342498666096124, 0.03229035319940698, 0.07334374867740177, 0.08536638782149361, 0.033272382157344016, 0.052528120877762, 0.03188087920387907, 0.07346289833226512, 0.060186146443048795, 0.04616147823511593, 0.07680328683026376, 0.013667106245374008, 0.03365709236071956, 0.026524030460765766, 0.013307215375525337, 0.04506928966410699, 0.052724116812309915, 0.06781234871596098, 0.09212914388626815, 0.06147669049941244, 0.01861474720851308, 0.051683259962667386, 0.025322636056150642, 0.03838458263705816, 0.07896454343872686, 0.0119962876347164, 0.028214958879435738, 0.0670757168723691, 0.05388590064080012, 0.04467805239161657, 0.019358854155026136, 0.027199371439975598, 0.021278199349199573, 0.06008888008974253, 0.03907947418009562, 0.036952216553712086, 0.018122282908147862, 0.05610393202533165, 0.033122795829249006, 0.05639756203538949, 0.031230663993365826, 0.023092707326155038, 0.05490075646629257, 0.02138075170918338, 0.04022935300224251, 0.03613608010533837, 0.061732682609750386, 0.028246667258621707, 0.032100344241987315, 0.059657974784532865, 0.006961615252939444, 0.023345903215569355, 0.037613679850173574, 0.04295859868908602, 0.030386479150864388, 0.07155904726636025, 0.021407919102198174, 0.016583365485853246, 0.05451074110404138, 0.02858753616531049, 0.051321651140648517, 0.025213026111164404, 0.011944232917871448, 0.05947610168086906, 0.016899443787312316, 0.013135229594134277, 0.04649628930154347, 0.034830647130166335, 0.03957934272024901, 0.03130942740808091, 0.09446286986912451, 0.048446251199610775, 0.025455642326344407, 0.055395266221415614, 0.04104898664199057, 0.09380177429486668, 0.006457107092794632, 0.09330666699116269, 0.007758107770519752, 0.047107129507968505, 0.015220837892904399, 0.04829680276734214, 0.021733498809138135, 0.003364875540888358, 0.021586545908282843, 0.027575719793657624, 0.07121193282786878, 0.03402192258246003, 0.07031778564616557, 0.04821077875432469, 0.012432004929700447, 0.05011419315011271, 0.08609177349435707, 0.05609793738732415, 0.0807450237053056, 0.018675543946183978, 0.035795676597063585, 0.012919742467572853, 0.014259188788973037, 0.04472150106824214, 0.07305070472460601, 0.024964612525617404, 0.07723929045060951, 0.04823288805181942, 0.03974936061328457, 0.015006504686278923, 0.04393223515381256, 0.04753256494539881, 0.021007278100437215, 0.021828857603512948, 0.05634781994646596, 0.019729340020867608, 0.044931087402566794, 0.03835265592281376, 0.07542914725960263, 0.04654295937789064, 0.04100477953831996, 0.0749126967463282, 0.06402021732121226, 0.016952617950136625, 0.08389495508444887, 0.01711198339058507, 0.020686741167258833, 0.035483779220451275, 0.036536361045774915, 0.04248307642316626, 0.06642493284157207, 0.037246386655756546, 0.03148932208968026, 0.05898390551127734, 0.038369969509902506, 0.047092179302126176, 0.018429673772545594, 0.06454942702886558, 0.052035346311787446, 0.04166027884029093, 0.03753866452062803, 0.028730647135225516, 0.09701812549704507, 0.029865131420533986, 0.05487554834314412, 0.039302631761998906, 0.08335022826588924, 0.016763175897780928, 0.017460968998831608, 0.01956166827210015, 0.05146960187102518, 0.005141296499078313, 0.043847387085758874, 0.045622037423233834, 0.06685085474483429, 0.05969087060000147, 0.05113863656597753, 0.049830874683515686, 0.03735281542063721, 0.015210443037381817, 0.02159571598073648, 0.040492933213470444, 0.02274497810210432, 0.03678724334965791, 0.0012409730205094564, 0.010677518984002453, 0.05100528747143765, 0.10455343526818099, 0.09375426918268205, 0.034436885597965414, 0.03049128189412577, 0.06134003573547929, 0.035066533262931535, 0.01896141923122829, 0.009536571789442772, 0.053860209882259376, 0.033203227400419213, 0.009322604389801141, 0.08231637729031425, 0.15641877517825173, 0.22163410881353965, 0.22068396060457154, 0.24399580163580759, 0.2012246838139911, 0.1738152529803976, 0.08661848192493762, 0.18788047405260225, 0.21845404719633443, 0.14202350810650857, 0.16784954245292372, 0.1388900552786166, 0.1532495766878128, 0.07800794476943632, 0.06390652987324903, 0.09845404239792017, 0.1010179931237813, 0.08132118311139845, 0.22240871563553813, 0.21997678484166824, 0.10443910430636137, 0.12523713506638043, 0.1714259319968762, 0.14972609317591115, 0.1289705343304142, 0.13217655100649403, 0.15365583311405875, 0.11561553039017225, 0.0988360827848796, 0.14023931997437633, 0.13230111690298205, 0.1293197478498182, 0.06650367135842962, 0.20205763589230277, 0.10983263142406942, 0.12277932582242836, 0.10128729601180363, 0.12108169796486055, 0.1457524257561853, 0.1689695323547048, 0.17514118263798376, 0.2783634405462973, 0.10372677277172766, 0.1106014772648773, 0.11271327523694885, 0.13483622441849402, 0.11167626797912583, 0.12178036249092511, 0.113552899941081, 0.09488719830950422, 0.19179283911662717, 0.21163508326055544, 0.19048595440483865, 0.22837761308877702, 0.13746038199432437, 0.1493555211251782, 0.11629439920427338, 0.14756852911124307, 0.1466346526097867, 0.1395781401304468, 0.10565965090908351, 0.3044274677672694, 0.16763414917213304, 0.11884587801872723, 0.11961486175536148, 0.14527584245849043, 0.13798935038428153, 0.1616117481382624, 0.09720337321801532, 0.09565694047318352, 0.21344229999569156, 0.18944946808680413, 0.1886362963986974, 0.3005735245683501, 0.10501066718490855, 0.16646595701815622, 0.19389535210305647, 0.12317923137978201, 0.14122233335529605, 0.1864303155772148, 0.19789024015828488, 0.18962243541834817, 0.24466438188908562, 0.11829802556143654, 0.11884896535306208, 0.07721982415645354, 0.10886565992428411, 0.1996230391124564, 0.1441451426475279, 0.16180270321426854, 0.21920243848956403, 0.167000686389304, 0.13807951893296935, 0.16878389392889317, 0.18873276219012278, 0.13804853833731145, 0.15345329478863748, 0.08297241668427184, 0.05881231330755738, 0.1334143039439955, 0.14818970384376665, 0.1784672912570738, 0.07465799549414266, 0.15538144616350053, 0.12373276054859163, 0.2545402511473625, 0.12115668265088914, 0.12080713971367768, 0.15822750876747793, 0.10226568988253994, 0.1839161682273111, 0.16047992983893042, 0.1387203055163545, 0.13879573453337918, 0.16922733626298367, 0.19218305366173868, 0.1664199917426994, 0.10574293998821128, 0.14356598017677186, 0.17611178539453015, 0.1306939563683925, 0.15739091011064668, 0.15858950063345895, 0.1002544409505302, 0.22519909896917883, 0.11075007533954997, 0.26657267323424744, 0.1637639495874605, 0.12118161115194521, 0.11114850234720977, 0.093680058245457, 0.21883853140377232, 0.08367939326431482, 0.07357263276653905, 0.2117953641760734, 0.15994204418553462, 0.11537805079452454, 0.09390275234416609, 0.09519118199785871, 0.17993159171554352, 0.1769925873245924, 0.10287654541072347, 0.15266511288862075, 0.2535963235723396, 0.21818648332790022, 0.15647572615454275, 0.14722201222133252, 0.10604260294067283, 0.18389290979792997, 0.1370014493624049, 0.1194414577537006, 0.15870208491481122, 0.1435980792607992, 0.112510024449758, 0.1397969808068968, 0.15334063389849278, 0.1098059102772705, 0.210801886034108, 0.20077024045730793, 0.1774820255776567, 0.17810802666410325, 0.17297123859245933, 0.16778635552092908, 0.11190171999436234, 0.2341296157288936, 0.13171268476834222, 0.12289943308719706, 0.11491308905064099, 0.18464415093823788, 0.09575242567206584, 0.11397198834005864, 0.1158419936414688, 0.1154796646968011, 0.14624665971965561, 0.10588501865464835], [0.030216034163811037, 0.029145112193580118, 0.010185346754658367, 0.06961461652310626, 0.00967496557296404, 0.07519498482466706, 0.04948403986711656, 0.027035319456650365, 0.02595249439529594, 0.04340210997108971, 0.05858007375331176, 0.04462109375444632, 0.03375611688581205, 0.03388606838040775, 0.044161532930428946, 0.05797919652034199, 0.023021941869369438, 0.042929127286638946, 0.06861698618459125, 0.12825167572666563, 0.014057778528020268, 0.06531650320656839, 0.028934068376979524, 0.035762340281038515, 0.06061276931676173, 0.008915635501785625, 0.0207252677289709, 0.04313063522380206, 0.03934581613829059, 0.023225832339977066, 0.0912077852614945, 0.043836117932392706, 0.028436630250765916, 0.03218073367832169, 0.07387524515750908, 0.03845171109142323, 0.040112367545765255, 0.06190474595754378, 0.003991935504487746, 0.01982901955113536, 0.028316976893092358, 0.039068561257614244, 0.07063365135822566, 0.06339833778779834, 0.008061082616838957, 0.05275057365877494, 0.01653846890305079, 0.03024887060746551, 0.0813039001678267, 0.025272223640293367, 0.057312293999618104, 0.034425455566135146, 0.023131739505897128, 0.056579902452687104, 0.025586266063093662, 0.07710435172362674, 0.02391481734511833, 0.01264717891782282, 0.023597132174238086, 0.054216356497378125, 0.073211491258154, 0.04429862053403932, 0.050514048911751284, 0.0533025361777794, 0.05930688818015399, 0.10570040678665524, 0.06679906720115293, 0.025783301961998788, 0.03365605048114254, 0.1038820741157378, 0.025278124432530136, 0.021154684908387643, 0.07704996714188207, 0.08617826482100834, 0.007183647164398985, 0.16819184585925073, 0.04702844461726566, 0.04358027137876038, 0.0111074197564214, 0.04887706457426952, 0.02155422657397726, 0.03489607869977913, 0.08914252713082299, 0.013109579055209555, 0.04736995129215141, 0.07691907335913951, 0.030834722941020326, 0.011608963156299246, 0.053839521677864176, 0.052219824114393805, 0.01084008284153477, 0.022320804794529275, 0.03914191800680372, 0.057285228113253275, 0.023216099192899083, 0.06492107926357178, 0.04460357715405765, 0.0095651765549255, 0.08570785619198315, 0.03569015947681281, 0.08941494799669712, 0.02677878725432581, 0.04709685243846429, 0.021664269358640718, 0.03218312770308506, 0.09144888845302405, 0.04746331442748347, 0.026668407390975667, 0.021490294621476246, 0.04599537505137344, 0.032905832068213535, 0.07631567186645924, 0.006033571074611598, 0.03241450923885549, 0.025604215503159552, 0.026657806649323434, 0.0746155848666545, 0.030908351651422923, 0.03444892083925586, 0.05734270769021204, 0.028886863954305172, 0.048979931030302286, 0.06951708586946612, 0.01749068746463426, 0.01875183481212345, 0.03382982986588632, 0.06423222449337763, 0.025147067856103666, 0.02749976983684446, 0.027941584234095873, 0.05998874856759945, 0.019094634260381424, 0.06593704974699406, 0.03214441344983155, 0.05131202907631955, 0.04206675360159528, 0.025876301205566814, 0.018672914349383885, 0.04178787078407984, 0.04964662670728661, 0.06100971394428804, 0.009938429913393432, 0.041892736729594975, 0.07984796538949013, 0.03805798020273928, 0.04083897895930756, 0.0676547644299365, 0.013090529321362416, 0.015660186444649535, 0.019346031758393493, 0.10260102188875599, 0.05808041588733754, 0.012500893471071558, 0.030181451039689205, 0.02637894489922591, 0.023883296657473813, 0.03267913516010008, 0.016879768734196984, 0.07370121296375029, 0.0395512426151864, 0.038978607213545235, 0.10747146417176533, 0.07946589435901373, 0.04646993587694822, 0.006038817340478061, 0.06409427887129207, 0.033266724598023205, 0.04860230714022633, 0.09123921784902773, 0.11901474677987638, 0.0640922985340078, 0.03710355722315369, 0.0402432230241116, 0.026219089162505926, 0.04627658677617869, 0.047291664767169186, 0.07488682595712524, 0.03749711191161506, 0.026300125943136313, 0.03150257541077032, 0.037919080801187985, 0.08349516444028386, 0.024250783289091724, 0.04297328459459447, 0.05475143826897106, 0.024470983771607283, 0.012484847759497503, 0.05047227796767989, 0.039460058999998916, 0.03245361419695039, 0.01817840076382122, 0.03737253069336857, 0.02288867512928142, 0.043590123269466624, 0.07297140696356375, 0.04419159422057771, 0.04494403428848713, 0.027870881979564027, 0.026889779988015373, 0.0586958411299894, 0.026246488297117815, 0.05172852809811312, 0.00285991084022117, 0.029554333380093018, 0.03316570824432758, 0.04192212386237037, 0.021439962644851016, 0.017069365919357347, 0.053879281641134334, 0.015829204592943912, 0.03817611862154257, 0.08419978146952006, 0.03679278216535046, 0.03880582757354264, 0.007071770556766781, 0.025961511250164722, 0.0171343071926986, 0.02697324335214592, 0.019586977901898568, 0.012464006337517453, 0.05078982524273377, 0.040912209303989526, 0.015312402636834211, 0.03261897044496671, 0.055421271076005314, 0.003382453907115926, 0.0503971285727476, 0.0683797134326831, 0.03841040363054603, 0.032825687780014934, 0.10124875412833306, 0.0442814908080524, 0.027250655280846744, 0.02415588606269129, 0.042535967133458585, 0.029628795211113272, 0.03854528873137409, 0.0390732956809863, 0.10345058275326606, 0.023233087192620003, 0.039714296768990257, 0.05520261426065719, 0.016652468531843156, 0.05533277642943206, 0.033070981472490296, 0.049572002082582445, 0.04733166221769587, 0.03326316611961492, 0.0322879400224455, 0.0582103788732521, 0.01984939557470141, 0.09406654194237725, 0.04765849447839203, 0.02519545779984084, 0.07074297976589973, 0.017967002631555644, 0.022676570280905695, 0.0282764470114583, 0.03847219245207887, 0.020241253378410495, 0.04762805780516036, 0.09204767809640016, 0.03496701461112788, 0.01764283252639636, 0.04307078843515727, 0.053587643459679625, 0.0676759391001636, 0.08165906619040236, 0.07107129440672937, 0.023009288012080138, 0.02864855123803981, 0.03051395235102504, 0.01866563651410322, 0.020950194973979267, 0.029598952256022926, 0.05031943193546707, 0.02042355740653171, 0.02257367126613615, 0.0319022185830099, 0.008954825687162098, 0.02119244346695562, 0.013950904474533616, 0.087111834887295, 0.06290746311987601, 0.02282910413228937, 0.08839608170092107, 0.03500495894601749, 0.049221501535465645, 0.0069912810501973, 0.03785510862907095, 0.0097758631830314, 0.07785564649008936, 0.016217849615420547, 0.008314544721806963, 0.04407675764072807, 0.030750405388854207, 0.010414944263175132, 0.0387648725131106, 0.07358690498456841, 0.04688564582817978, 0.02662020896921956, 0.03184082429675806, 0.06332089012909321, 0.01368193962280789, 0.045539246301256844, 0.008227113979838548, 0.03129524520538267, 0.05564933162062399, 0.03173358347867766, 0.03858545472124412, 0.04196307126192316, 0.023913702687188506, 0.03215900359434947, 0.039595748493147474, 0.0305674042207219, 0.06430739687094766, 0.03226622909067139, 0.02463529622482677, 0.033426856126395926, 0.059591260017646905, 0.038307613783305695, 0.02763389268018786, 0.0652552238335052, 0.043570561214320125, 0.029284917494101875, 0.02640025746527939, 0.07464563849592402, 0.06262641610397447, 0.045889191434628544, 0.060375025420780146, 0.02345650715963735, 0.011633791108315271, 0.020948473191369447, 0.03017390315841523, 0.043545245838862275, 0.06722567092266775, 0.046496921324081, 0.05019998733675288, 0.06616832403045508, 0.018198849565740076, 0.04840107116427633, 0.042477890007918885, 0.021742902538408677, 0.019745676845852888, 0.024671279374630223, 0.09804774766727802, 0.011683484359133628, 0.03912863021175708, 0.014929527214037315, 0.04016787061587938, 0.05440525462730758, 0.06356113530214756, 0.18901269071765486, 0.17705422675898, 0.07438727534346043, 0.22950854272611682, 0.11999962941533136, 0.17964412488283651, 0.10277554437878633, 0.13397385456388997, 0.15764722780835244, 0.06179723700868988, 0.155484730137452, 0.14790974467271759, 0.09479347511284775, 0.13302883914401456, 0.14685562301066615, 0.10094167544476448, 0.10445622637146905, 0.07679503606331926, 0.1878180532085319, 0.19248628658392739, 0.09475918501735696, 0.23978504532527542, 0.17948920658278852, 0.25375095075897636, 0.24055998922596056, 0.09552627651681823, 0.07879690041825657, 0.1305520768848158, 0.14642613879855604, 0.13544051457316647, 0.17718993157388704, 0.2203477705798803, 0.08947930704321592, 0.09890640965632855, 0.2053777077385495, 0.15796667115101892, 0.12174319190483902, 0.1113187653883811, 0.1514533150099939, 0.13507265447368547, 0.16532157487686605, 0.14784977531000493, 0.1490377018889112, 0.1423461843402155, 0.16417995065210328, 0.18972087771661822, 0.14040310957258748, 0.11500440673121523, 0.23671980496616135, 0.07724097584404292, 0.1563416148025182, 0.2426124000621419, 0.0801924444855221, 0.1758363154987174, 0.18195406383564397, 0.1954843869973575, 0.17127853668024465, 0.16502097729713688, 0.09011833928525449, 0.13732870680189904, 0.1961395147466852, 0.16251386263437811, 0.2872405916212067, 0.08850915627854486, 0.1923566032201052, 0.2275110450723479, 0.13147957953474215, 0.11066070352230342, 0.13555447781278243, 0.17122794423372517, 0.11871529067115438, 0.1135094780775328, 0.2120902620616459, 0.1344498862782794, 0.1021689482994618, 0.2728559118845771, 0.1276663998742738, 0.10629842268122781, 0.1451387280418027, 0.1314668624751991, 0.09106274949566973, 0.10530625454961293, 0.1198497826173421, 0.154639367434767, 0.16817272430466068, 0.1718224284629668, 0.1184407860461262, 0.15425924992849752, 0.15417756963401072, 0.12502022493149967, 0.14645238497084187, 0.2595831015177312, 0.25015591463494685, 0.13705849226924682, 0.16671343406121578, 0.1352857648124618, 0.1134728437529937, 0.12070259935553036, 0.16252838766142247, 0.07325292129309909, 0.125247438948962, 0.176045932476559, 0.1178129310269029, 0.10303436718400448, 0.10070121576709133, 0.18876973359334856, 0.21765371514183862, 0.1292453300688536, 0.11811575026161249, 0.2804446869319485, 0.16274719769435544, 0.1468064861312028, 0.060241048134142355, 0.14646870264362905, 0.1569224167014322, 0.19988874904811385, 0.17959198493870998, 0.1669489141673811, 0.13430851241273267, 0.14987823823767324, 0.1263721556132359, 0.09802841160806919, 0.14446469324250377, 0.18543142885450395, 0.04304983976086782, 0.11424511400682312, 0.1523927073445051, 0.10527933421995371, 0.15224966340728346, 0.16538768826473146, 0.1649068148746606, 0.19709868747140133, 0.13333501384383248, 0.129308792792501, 0.07527182344347239, 0.15033369283041648, 0.15268762055183613, 0.21557197845991583, 0.1572270592254016, 0.1370024146331895, 0.12600069490051077, 0.07985719674897772, 0.14285125078693514, 0.15689171189742704, 0.14883376928346773, 0.14161342124064125, 0.1560988721828307, 0.07230194570917277, 0.14645636862804814, 0.1735973009659398, 0.23191487086155724, 0.10510439804244427, 0.18565973837769803, 0.2147887914531654, 0.21602436870096192, 0.08625060650369815, 0.1198200737276385, 0.14682301830860878, 0.1767500438877652, 0.1183573131058966, 0.16121073175341855, 0.27509543203538467, 0.24252777799002587, 0.17991516679044695, 0.10224001061531807, 0.32768638744469614, 0.06720274957197328, 0.0998145609252876, 0.11361847706739941, 0.24355050536894032, 0.13594657693418766, 0.16801160069242602, 0.1198290216345941, 0.10279311843576933, 0.19525854427727962, 0.16450904670261568], [0.053301260641385476, 0.019009219287263773, 0.06143344866652643, 0.021246948707548362, 0.02959396885407548, 0.0498925868962561, 0.0431087174482884, 0.04735531901279765, 0.060526473342531154, 0.037901215630793766, 0.0376354290863439, 0.040488880608351006, 0.02341346834005127, 0.014330259723318441, 0.0561829578251608, 0.08385298878795679, 0.017919447723655932, 0.057062507201466835, 0.04757862981228579, 0.04843295574368489, 0.046183445806344675, 0.04578113473290878, 0.028282581460511977, 0.03393727369726666, 0.032300503864403696, 0.04138790777013187, 0.04999384073720825, 0.01781755994494644, 0.04404718281641122, 0.029137924373630556, 0.06164567417375023, 0.06231203277204787, 0.018758630012011817, 0.028569138563808896, 0.00468971926884185, 0.04934115680835901, 0.06008816762797295, 0.05857843049471417, 0.049968567496586236, 0.02572622458120027, 0.0629144613330643, 0.019415219074055072, 0.07649614685966123, 0.06412135624897576, 0.01736573277852468, 0.03234260422628253, 0.1182434494577108, 0.04582438039623442, 0.04402352985174906, 0.004689785343925319, 0.015816770985932843, 0.030085381698764624, 0.025115003246032906, 0.053412588538541916, 0.009898369260612997, 0.03250930495860596, 0.050149551938257875, 0.055251211048133915, 0.038975619470640537, 0.03292611424600886, 0.020072482293471694, 0.07865508988259301, 0.05800818911783638, 0.01323649301118548, 0.019290702973282146, 0.06899125843999848, 0.02136147310656886, 0.04272529044218602, 0.029552136622970144, 0.04242270103385372, 0.04170207659743967, 0.0711881151543029, 0.04749542883326931, 0.03780440509980244, 0.039311246420707435, 0.03783558104788104, 0.032970317519239845, 0.05907427707326509, 0.017336326493551175, 0.12229973179919106, 0.02212595990708759, 0.03168288569506859, 0.06423859834490765, 0.020664922983175325, 0.06388198824659472, 0.03035492973492271, 0.046953850636078466, 0.014877682213761635, 0.02804485480150869, 0.04747115533738848, 0.017874348127553542, 0.043637287472524953, 0.03582620520084616, 0.03929638048453678, 0.029077340225358645, 0.08257951317054611, 0.05571483979902922, 0.006941673026660518, 0.04964003069025855, 0.011954408480725702, 0.025083486388828007, 0.05541726443616133, 0.046574713722352064, 0.000787669818119837, 0.04518931648964363, 0.036216749163765105, 0.06826061740397446, 0.04754459252581001, 0.03265803326822577, 0.0058332644590747456, 0.05821089598260099, 0.045596679912940155, 0.04581428718783202, 0.022818384647008874, 0.01624274364252004, 0.04306162219314326, 0.0196542595738485, 0.034186853651678374, 0.026970872310020273, 0.03639397594416815, 0.041753312557815545, 0.050265690867578795, 0.04726974699165552, 0.02461085610482241, 0.015101142400395007, 0.049028635070088415, 0.016961108119557464, 0.061288619744441206, 0.025253213168452346, 0.07632446655582997, 0.0463756496056674, 0.08732911274437943, 0.10449790921542915, 0.03666684114103837, 0.02638580138614822, 0.07428245919366037, 0.11454216459946287, 0.07426340658698352, 0.02010830073437143, 0.09795171854596946, 0.01945177678980174, 0.05127170986886467, 0.025791370783061273, 0.07042258647420714, 0.046523228783400795, 0.04689912131476787, 0.02606459029559647, 0.06249865179040259, 0.02796493267880813, 0.05138304542690035, 0.10977790976363806, 0.039970786836478985, 0.03256272810000566, 0.05935052071788138, 0.058797952989416744, 0.052314347872931155, 0.03541827870292529, 0.04296874169320349, 0.047369905326875954, 0.02938315869429179, 0.022065207219472336, 0.03774318701377319, 0.007563892990395788, 0.0139060691787651, 0.04384826425643217, 0.02560901887444479, 0.023719779020475767, 0.02467917008025031, 0.050464869897452094, 0.021936987083585515, 0.03581053104191538, 0.044460648130024635, 0.007562272714435935, 0.01585426715938675, 0.011333424312573288, 0.06125847801506039, 0.05021089642879464, 0.050923967238275275, 0.027031019788175344, 0.04246365226384613, 0.04679779852590254, 0.03688796092906306, 0.03647696241856583, 0.043396234076710484, 0.07415991576929247, 0.036721620258064046, 0.035987175595495975, 0.048405518304676785, 0.06708032106079402, 0.020731109149393537, 0.004197129521579032, 0.016992084884775743, 0.04893332607142868, 0.05801859642228773, 0.05332669476047159, 0.036156580618192116, 0.054446558257745165, 0.04980451742848081, 0.039757278131982016, 0.04154738812376896, 0.02927993792259405, 0.03605939470411789, 0.055029585642079194, 0.009998066027859047, 0.04150439143901871, 0.017316965536484798, 0.07692360859965125, 0.09537850581710378, 0.03443509295222259, 0.04921752936957825, 0.011312731320128567, 0.05798257496808806, 0.04184130924723802, 0.06372067311237897, 0.009729023609730986, 0.057603192906225884, 0.02650556774179061, 0.027722733981546857, 0.07028664417204357, 0.03724557077211719, 0.023503937578249364, 0.03155541441012775, 0.12101501001105194, 0.07275471899418101, 0.07849122367558942, 0.030711719863897854, 0.024285102112879677, 0.018870553542529384, 0.060763018310911236, 0.12435493119541677, 0.03424798363759633, 0.03253730547223841, 0.034283767604539474, 0.019750639180382414, 0.040740253208505536, 0.01810101630736984, 0.07529781680674323, 0.031730455924726786, 0.016004322716335378, 0.07077031378303805, 0.07344491824868225, 0.0573435427260495, 0.020754599320371787, 0.02641289600081021, 0.02631525234920123, 0.0457658359570609, 0.06807734618984884, 0.007069706428615798, 0.04753696995096342, 0.04850938450545073, 0.021263233821598754, 0.029956052650607405, 0.021586850428232746, 0.03039394276246669, 0.020489866146817803, 0.0353994520921861, 0.04435574771055291, 0.032879041973501444, 0.05409829085692764, 0.04492569031314023, 0.043990243331439076, 0.03595966537813506, 0.04154828827707999, 0.023575607018785614, 0.06341793048646181, 0.020086980507438703, 0.022509898276879423, 0.013357856660149993, 0.041875798525589134, 0.019775132926541473, 0.047963891598966815, 0.03254467140763037, 0.04968822528157504, 0.031094095414324157, 0.06464020078701359, 0.016210227040573955, 0.03769820999173868, 0.028481342972466545, 0.043708832423773505, 0.0430980151999862, 0.007522779445524418, 0.03828765719287819, 0.04613369222610228, 0.07179183840391136, 0.07343547238457589, 0.009753014610689736, 0.0641300781599937, 0.03374246519900138, 0.032960044280175245, 0.04133973233101349, 0.03468181539867674, 0.04689571988438407, 0.038271864290319146, 0.019214898573174592, 0.002364574907152283, 0.052365020758682684, 0.022425795229332104, 0.04985605216314716, 0.05644805872091844, 0.05133832121388086, 0.05282384996873237, 0.02698897879811064, 0.016962071475122246, 0.06244930806719969, 0.05971068163372337, 0.03418350201700965, 0.06211255879832372, 0.14498719585038003, 0.05478258740397231, 0.029411400525620388, 0.03947250026788923, 0.08490408440270732, 0.03138455382037548, 0.06724539002583874, 0.026695134283434, 0.06663715451835625, 0.010906196229400174, 0.07534729076489326, 0.021966876003951318, 0.006927964840865424, 0.0844736502415711, 0.03733687313093293, 0.02720579317200088, 0.013862667425024896, 0.043811538001342167, 0.023565157579498428, 0.055002680634178465, 0.06693569132156911, 0.018474032178581245, 0.0387698291019807, 0.02267320332447848, 0.027688694779851267, 0.03273302944557321, 0.01330118626356125, 0.0734902783146789, 0.05005227792407236, 0.020559997665846062, 0.07676994668379908, 0.023636047525571722, 0.04052949859009635, 0.011803430745438223, 0.014393521348885713, 0.03957478832753916, 0.02749622093453523, 0.048639841618076454, 0.015528949837560858, 0.025088071425054825, 0.030435328747356133, 0.03743790097594742, 0.056893898910211946, 0.024665110451619954, 0.034474699697907896, 0.11570373009289465, 0.12150149116472853, 0.19811350882293718, 0.07654467086878515, 0.12224974456213175, 0.10934255731802796, 0.10343875435571517, 0.12703833035043172, 0.16994952734920288, 0.1507359043124222, 0.20068166537150262, 0.16025621684328203, 0.1697054670582856, 0.09348885802131507, 0.1642413755818721, 0.1720219637237249, 0.11225649531209662, 0.14662821747122273, 0.1892821238406243, 0.1428279770357955, 0.16583583437867705, 0.16929027804684255, 0.2419727013236092, 0.07785327927840334, 0.12954981937523813, 0.10453120339661838, 0.1680575046808489, 0.08224512345247692, 0.13641234307039168, 0.13843660783623496, 0.18113482473117692, 0.2811219086570125, 0.15593413263559341, 0.12940928820640812, 0.07059515544003056, 0.08301945448282265, 0.11051654109671233, 0.19917794202844943, 0.19145044377974926, 0.1159896647497531, 0.24616277326018582, 0.15363455119152225, 0.1469796066803317, 0.10850494742513665, 0.08423357360786007, 0.12907536580197274, 0.25131160423399945, 0.15338554197261411, 0.18851677136075115, 0.10364962005687338, 0.1734818055504753, 0.07516247971403985, 0.21074714139103892, 0.15610734511527324, 0.10228789877146484, 0.1367919089933557, 0.15991904622604772, 0.09190147021605123, 0.10918956955954914, 0.13487911002049524, 0.20073213524395422, 0.17934616264556685, 0.12086581438779832, 0.16374335714405583, 0.07791078949887907, 0.1766002430550514, 0.11009885463863613, 0.16267737644093652, 0.1181125326923305, 0.1859899069513044, 0.232798844395626, 0.13085509530238568, 0.20663824413091908, 0.1321688135184588, 0.07523977798559973, 0.12439821516313862, 0.10656332056368552, 0.12046551046472405, 0.16562926643077405, 0.2343346668227065, 0.23737461095856083, 0.1711354774212645, 0.14625629710574306, 0.0935930613007757, 0.23109097394251057, 0.19640680282346665, 0.18811612269811093, 0.14304090351347, 0.14943413706796785, 0.09845149898601156, 0.0997173979938511, 0.12423250268423751, 0.12023186130869774, 0.10040489295797964, 0.15211090956243778, 0.245695689452752, 0.1603631320739946, 0.18434513149963272, 0.16667525223906965, 0.11090058863403336, 0.086735203081081, 0.17008258149989192, 0.21174998112743904, 0.19531935633670902, 0.1650133930266865, 0.12194495648145677, 0.15597617554087795, 0.21549296415140554, 0.2580775548854182, 0.13697806835895585, 0.0902288551292112, 0.1318852996994411, 0.18099767967097222, 0.18172886462942248, 0.23027605557393646, 0.1734085369013971, 0.12831841730662893, 0.09990816920875542, 0.1051538183744396, 0.09929627180099489, 0.1984459909820749, 0.18639380382674356, 0.15839450061321259, 0.09968269421088119, 0.12198508416693057, 0.08255396413827136, 0.22509029916217252, 0.196503835519956, 0.1063849369905168, 0.13117441607098426, 0.14361839591255113, 0.2286125875769123, 0.20606851986339017, 0.1991469001457576, 0.10353551892143104, 0.12438372077961123, 0.24783043941903501, 0.10205966585706319, 0.10081044458333524, 0.2499994641590503, 0.07074044401487035, 0.1580891379665944, 0.08422111701821128, 0.10898702357324863, 0.29134299245572864, 0.1667727292665551, 0.20235184429874345, 0.13914145469184847, 0.17632930839975036, 0.15257647651578152, 0.18945250179498427, 0.18066538137293633, 0.23127275128518385, 0.17199986974798864, 0.10788113735015355, 0.10459843527285323, 0.23642377327046088, 0.1350333081978944, 0.10886300159918685, 0.3007038514460287, 0.08659702380217853, 0.08740798915706335, 0.12736800096688733, 0.11832233353127396, 0.12716819757535575, 0.12203212962636065, 0.17030827100238494, 0.19967387670711165, 0.1612200167390608, 0.1315145591093648, 0.06509426109973462, 0.09863378194671485, 0.11449652874181349, 0.13639749628641915, 0.1664802522188233, 0.11041716417117466], [0.04829338218476023, 0.03422528828283952, 0.03335164161399007, 0.048793698886349324, 0.07563521725035484, 0.04888915727215429, 0.062125624427872325, 0.02499873982742429, 0.011437896680417321, 0.04323381194544416, 0.02344443361395069, 0.04022927639345008, 0.0635187246746594, 0.06237702767154383, 0.046843403740034956, 0.041475061762837634, 0.035153813660144806, 0.037270089416133786, 0.03949700359014734, 0.01798901425284003, 0.06079850733400353, 0.05457929831238524, 0.03758990431144353, 0.1217186694303828, 0.007449665450445948, 0.017589422791535338, 0.0361107608994409, 0.025351977223650585, 0.033048385709163644, 0.025775380612861727, 0.05931448777236285, 0.0314884161907098, 0.036570474941043124, 0.03790298529389886, 0.05371231660847703, 0.10013051090701934, 0.02909576080949797, 0.05428842621885481, 0.06588995832228853, 0.04654223925524181, 0.05946997297747482, 0.03953974363544295, 0.029923664368388635, 0.04705071096278487, 0.07095517079916693, 0.07750349885393536, 0.034868315673403205, 0.06453757564867697, 0.01354067492479038, 0.13478229182862467, 0.0389312629798247, 0.015368146067034575, 0.032214096807424104, 0.030140505555356224, 0.10861787644605483, 0.06283573813796525, 0.10605188026543587, 0.022105873081712954, 0.04672486312507142, 0.0443676297342585, 0.04623809851886285, 0.03909034113730154, 0.013095890021612568, 0.049218636366628835, 0.006469369766437599, 0.04235623141510352, 0.018224986570496714, 0.026132281824585893, 0.015383622000714945, 0.03234391806707267, 0.03625232245652907, 0.006248504223842775, 0.017120542507919095, 0.05737528557919207, 0.04798045441988976, 0.03283271663672021, 0.0291179409701257, 0.012993549293417846, 0.013830981070866749, 0.027182040615908565, 0.024490729687855612, 0.027890082058166305, 0.026981676064972437, 0.039645421634157824, 0.008284513117565263, 0.004022535210805795, 0.034226525514837236, 0.0690336614066074, 0.02777861818040331, 0.01982355734423524, 0.04194845430432789, 0.09730799784583431, 0.05382587382149312, 0.048295837496557546, 0.06415995941948026, 0.06510505527858773, 0.01880733596701776, 0.06148556179757561, 0.017270693825858257, 0.07902029165697676, 0.032708380566609484, 0.036647934091067126, 0.07066745881832416, 0.02169185810001387, 0.011893356061210076, 0.046235263993543003, 0.07640652223339967, 0.05178255261853338, 0.07040479791260536, 0.013919282280239127, 0.12712066181965415, 0.029829261268699364, 0.03625374738006823, 0.08695694723076398, 0.024135420023794138, 0.04259574880462982, 0.03253098141642348, 0.018091262092873938, 0.037691820818450184, 0.040954378613781546, 0.02136974685615109, 0.043350939128187396, 0.04686309603012858, 0.030113659919269627, 0.030181971979477716, 0.03724247960734271, 0.05361775454554347, 0.04185602579626345, 0.02813289171054719, 0.033259665097800956, 0.07563099610589205, 0.05514490485732114, 0.032267673166408654, 0.04788669291883708, 0.036249913110007206, 0.05843496137869455, 0.03423753802874877, 0.04064485227929489, 0.09390203222151726, 0.015086670999505348, 0.017271659096642848, 0.028069365784646045, 0.07056761457915268, 0.035614312941869425, 0.05736982337229195, 0.017921031610439384, 0.05584453465417028, 0.033049170949286034, 0.02015042024844837, 0.06934817880392075, 0.06944887340068817, 0.040964012169429374, 0.05537699119398191, 0.06278303128877474, 0.04987109812998003, 0.06793322206865396, 0.002643132855507335, 0.022842290420686046, 0.04375831404280278, 0.06355507937710612, 0.02447898364475658, 0.06922516806591904, 0.021519499808369626, 0.07634650690541153, 0.00699880499122364, 0.014976299754644354, 0.02937553994988482, 0.029999093385413293, 0.02291266134219064, 0.026810884423133348, 0.01707027756398724, 0.010251937989866542, 0.055009177059776364, 0.009783287532627583, 0.03644078008590206, 0.04450569026953271, 0.12126211167102861, 0.027619915406009363, 0.013212983688009123, 0.00824957376255864, 0.03376495754045825, 0.023427945486600363, 0.05301726801741508, 0.028643950880054506, 0.05757313161607712, 0.019053455119231538, 0.1091065179676779, 0.04676100332289935, 0.05220251052730507, 0.046196829362381855, 0.09435000979611952, 0.04484679857869783, 0.05272354990724595, 0.07712217858962475, 0.032027849341712655, 0.13491306303729936, 0.06006489770727293, 0.06814847745361828, 0.00772172577619072, 0.10051340165157473, 0.03974182230810966, 0.03095106105320156, 0.04347692611777494, 0.054663487544824044, 0.04909104442283992, 0.09325274206217259, 0.024008774198591713, 0.010527789014421645, 0.031176922925477548, 0.033464808122164784, 0.01598124814805605, 0.0689929821378281, 0.01934998285686297, 0.013640322853931257, 0.031971781281754375, 0.03855623995825168, 0.028716955228798816, 0.07537107779494218, 0.04655741545702181, 0.09742045955311868, 0.07364219355006373, 0.04167214171179841, 0.014937962799693548, 0.05685707306369178, 0.011466700628760361, 0.04309348378991408, 0.04517635428196481, 0.02774186319701614, 0.04233505291443679, 0.0814964946719908, 0.024627311673435955, 0.025948987627822547, 0.028846676897017226, 0.03890551859512925, 0.03780347047253482, 0.04004936447487243, 0.0682126219955183, 0.0341992795978102, 0.05178013178069265, 0.03506202483549714, 0.048210686823773774, 0.0361941265873611, 0.027949708596532865, 0.028412705324890635, 0.015805320844294566, 0.03146172185698825, 0.044189227008891684, 0.013156990321623463, 0.03303638494182979, 0.012970994707317123, 0.0674832756480863, 0.022961457312527685, 0.018483217572793365, 0.023350020938162363, 0.003149948376719089, 0.02730977045552385, 0.06741319392477313, 0.06626105897368924, 0.06969540049472163, 0.027980436383175756, 0.056792396090684406, 0.06672575258679929, 0.04885950583904501, 0.04285437625742728, 0.039955384638761325, 0.002981014976901333, 0.04849869757890702, 0.032060302741404985, 0.07326370781107296, 0.04324477083320099, 0.025213853486122626, 0.01729359027869519, 0.043381609458235965, 0.039610001558978716, 0.04571355428666838, 0.06154423264125663, 0.01164630994260792, 0.07452553889203457, 0.05107402471044371, 0.032720507738450845, 0.03487968824863915, 0.038641283378726056, 0.013461718072874412, 0.046345113341005585, 0.04168248006833657, 0.028546240195752155, 0.02205465244309556, 0.03317115895990883, 0.026521565572869395, 0.03708835803873597, 0.06419997602220505, 0.02777384162219542, 0.03951430568591722, 0.01433880543411379, 0.06186783584135194, 0.038419795868497704, 0.042844872936726584, 0.027788977604359392, 0.025014548051741817, 0.06050910995972734, 0.05805443401538557, 0.04913922369239792, 0.06338350632558427, 0.01800607694613357, 0.010583694280696013, 0.052788184745417494, 0.019914474743869037, 0.0894224786409928, 0.03755964000799483, 0.03501339740450344, 0.06441834172414196, 0.05540133746821554, 0.020754654861746297, 0.022736392171692946, 0.005626131042522649, 0.01984961007932021, 0.03719259962259281, 0.05272437345176455, 0.035413394892408, 0.0707554669990655, 0.06832234876891298, 0.03352418376673614, 0.06044754713413216, 0.03803318576706994, 0.10324012307870774, 0.048039837725340366, 0.11230710308037459, 0.029716726783062183, 0.06008888775062177, 0.06871091622498728, 0.024840747599580118, 0.02021152150606917, 0.036992305934789686, 0.012748656839492821, 0.033331692684441805, 0.07548957627506987, 0.023895577046900027, 0.08330466135615304, 0.018215573265127117, 0.027104692548633586, 0.044046684859260436, 0.024576089119598753, 0.015314286255518035, 0.0015622916027730814, 0.01804208499379456, 0.08013029943310446, 0.03076636300031697, 0.02056616658885633, 0.03342011838310188, 0.012617482477047992, 0.0801784480591455, 0.019782902973313487, 0.21991143754172712, 0.12919389492561742, 0.12706066181342449, 0.16473207021913222, 0.16848142709462874, 0.1521816807648828, 0.13805311954309865, 0.12045652425337224, 0.09402654449185056, 0.11018991951019534, 0.17835387960076335, 0.16644544118354399, 0.26192279532551765, 0.13081247017027872, 0.19365044911542248, 0.16515645228566664, 0.13856618394774778, 0.13576178120509272, 0.21518795390523252, 0.2465091369325115, 0.14495046959529, 0.21271523659027394, 0.09200168217742637, 0.19056302285002125, 0.10663630576023173, 0.07747793449990212, 0.1242871400749972, 0.141345351754177, 0.136862910022178, 0.20219458176964716, 0.14012063763314678, 0.10478909923544816, 0.07174081694815429, 0.15558206926911108, 0.17073884305934753, 0.257548617138978, 0.12693440286262384, 0.11234441156228704, 0.12609046508347796, 0.12026770656267483, 0.18597743503989714, 0.24939820771255802, 0.0752060164907767, 0.19614533701490974, 0.10669626746206515, 0.16859638624854628, 0.1265302761608074, 0.15342946945419236, 0.14010910034900712, 0.23079140292059994, 0.2977094895416691, 0.09171670513047327, 0.11047805283939648, 0.16512415401877897, 0.2671920093557527, 0.26378840328224246, 0.27066744383304353, 0.10247874659516158, 0.187315376956136, 0.1218031612675517, 0.17066548247971844, 0.09036407730872593, 0.11047663557673655, 0.2326039056624136, 0.15408485767341432, 0.14815873856986725, 0.07725209944070348, 0.07142782406581026, 0.13079710244651765, 0.11004676832066429, 0.10389672937772929, 0.11293902602647582, 0.15645347896122164, 0.06640430975465045, 0.23743107163858032, 0.10415801898606362, 0.14236106176770505, 0.17770025338376724, 0.07272589110559033, 0.18790544851893382, 0.15083020973590114, 0.1238265373714028, 0.24977251827236147, 0.21855261206867235, 0.11641345692858582, 0.13746882428324994, 0.07533313346005256, 0.10906294288654482, 0.08481740155407498, 0.10259981146983563, 0.21047412297658383, 0.2282704067446532, 0.2102143885267358, 0.183274278477315, 0.19830777339877623, 0.11995882757248418, 0.09364802044846358, 0.14164587272511375, 0.21674600820387566, 0.2315340485543974, 0.09489743324417262, 0.19618707348502454, 0.15009415245825244, 0.1124290029908861, 0.14113896766737585, 0.16571880678736395, 0.19803483159311358, 0.3082137807242332, 0.16120170723767052, 0.14896441791807452, 0.2939635953835903, 0.14824889179679657, 0.12954370599360238, 0.2925961897257836, 0.1650726882320258, 0.3313607289906471, 0.10741505711790054, 0.18625828287293836, 0.13008905334338067, 0.17640884364804915, 0.14103756826971808, 0.12559053142585103, 0.13411780248486227, 0.1419751373149695, 0.13931204715082723, 0.10395145869903988, 0.20403472496376884, 0.12188699426910571, 0.11239932474469948, 0.18877626066246342, 0.1342113571421754, 0.19689481615299181, 0.15033937720281465, 0.18367357882520846, 0.1120294115295814, 0.1533761803781794, 0.1517809401716917, 0.07243782672430239, 0.18313264414187402, 0.09590967287940365, 0.09061186078695521, 0.11043235569471314, 0.1322954172088254, 0.18343753181397918, 0.18168780231668105, 0.11885429732501508, 0.21407818361636133, 0.0773895739187156, 0.1195152473425673, 0.17741592751154978, 0.23306590264603017, 0.19594721135593232, 0.16834681012457417, 0.17903655587184816, 0.21037998609244826, 0.206602651685957, 0.14024440679819355, 0.10895269517336162, 0.1303994721702991, 0.16563680473594897, 0.1829191047938601, 0.1874401726790013, 0.11604842369354541, 0.15238755923365394, 0.14658464239008967, 0.1166682041460468, 0.06903895507416419, 0.1418222568088001, 0.1371105556045809, 0.18042219442225274, 0.08986792812544493, 0.11635828327627913, 0.19823291128681553, 0.11302561694455725, 0.18019025364229757, 0.17391677495212327], [0.008182945180564158, 0.0294254161041951, 0.05614744581943078, 0.014534091779721842, 0.022559146239091794, 0.0897263550770379, 0.04016415508944662, 0.011576410165176758, 0.019385812789081566, 0.044761670888551784, 0.05739649089293615, 0.03165523758188131, 0.019412631612090815, 0.020002339283124577, 0.031026622220393152, 0.006256133501958703, 0.038450450876787785, 0.02160768418933355, 0.02514866323420598, 0.038943313542873635, 0.05893363482168606, 0.07634682100146048, 0.040135507231518146, 0.01470764133808834, 0.05046303894731307, 0.0284719028540196, 0.045637179151057236, 0.042725118072403055, 0.03887042027687834, 0.014276832751479122, 0.05459598753781569, 0.0023094860033222265, 0.024011560843416282, 0.04437721349419125, 0.0378113228737587, 0.04280673324941628, 0.04219687746597394, 0.025195419495444626, 0.04255849777931168, 0.03437395147498577, 0.03645202242619088, 0.07755802899238563, 0.043275605872153275, 0.017468064888230255, 0.06433837746660556, 0.052818901040741516, 0.08118214581402079, 0.02918083487348932, 0.12198339877349716, 0.006077446366449999, 0.07004959358563347, 0.02883824035375109, 0.05415499285464326, 0.004404014438360689, 0.04811478410697272, 0.05076272488241235, 0.040224622409310073, 0.031743893106918664, 0.029097549624801166, 0.016537001844675794, 0.06339438094366943, 0.05425094153671976, 0.043593049725337375, 0.05602055101565296, 0.043827419004012505, 0.029715776834036076, 0.10321635903129656, 0.029981481024034085, 0.07878088151975986, 0.023640077148053436, 0.0180208835104901, 0.007473754606419995, 0.0479534536509985, 0.0334186551551665, 0.020655804621656577, 0.016556510273667596, 0.05614256583935311, 0.030511765170001218, 0.01592277936006506, 0.05612289270145759, 0.05013659356101867, 0.10654826693597341, 0.12137023732066156, 0.017467517135364395, 0.04044814771341701, 0.06201845638814473, 0.10695835380184074, 0.04488449010457243, 0.09286052802757871, 0.025784393637290886, 0.02564324385246202, 0.063733957076986, 0.061160483878226056, 0.02883040135906589, 0.04056294981931006, 0.04413310723799852, 0.026850506490577134, 0.079351938780277, 0.05683611672852309, 0.1021568670928959, 0.04307643450315922, 0.04267871612682939, 0.03602912273978995, 0.07164450437431374, 0.01873129216443387, 0.04698779982244296, 0.012670130912034262, 0.0697733729236549, 0.02438974206245715, 0.10957498839425464, 0.03739221915302258, 0.06292172384658648, 0.04501538388731499, 0.01679041415392872, 0.01249575397870954, 0.03299062651011252, 0.03496698396761091, 0.04821737094091312, 0.03467082203696332, 0.006700601915062796, 0.01784363949310876, 0.02267663731359907, 0.02927097852431959, 0.04319872128807249, 0.017659414499517412, 0.011074962526289447, 0.009005802135253626, 0.03810439747007143, 0.0664125681824742, 0.08071179847202956, 0.022443882565224366, 0.04271881316878623, 0.038690014231589534, 0.04762320463816005, 0.012570457127425941, 0.02960353154659031, 0.051023413111726125, 0.015644669333743234, 0.018505798014361533, 0.054117366446242224, 0.055685851031974445, 0.027729255305002296, 0.004932134385941731, 0.06924629677087069, 0.06009205552418867, 0.029496738889945612, 0.057796216419627594, 0.05374084572277723, 0.008994157598804562, 0.036154726685415355, 0.011893127192442697, 0.02224501571618021, 0.0026756812979827726, 0.01816053942386662, 0.057053934677594134, 0.04150950890635291, 0.057318395889934995, 0.00946703686138555, 0.013872300980672722, 0.028776422803921085, 0.0889546976935479, 0.11230827519489874, 0.019590331451787103, 0.051276176161463224, 0.03907299307625621, 0.0793111292765506, 0.10116211724497619, 0.04539621768579368, 0.0507620545554786, 0.03991369030348236, 0.10883455675455833, 0.03868002827549654, 0.032704193896103295, 0.05280373633028038, 0.0803879731064362, 0.012683120890400343, 0.005002631233148878, 0.039715602948901155, 0.0558778096831614, 0.010820764019304227, 0.026825614378697453, 0.04171653267657084, 0.06517686069973054, 0.03857435410722129, 0.04882774766414397, 0.028623946409131733, 0.061202963453627406, 0.03417548490688205, 0.02883255981179255, 0.04721598294112952, 0.09330949385560329, 0.034973629780354044, 0.008841183246864427, 0.02290126578431697, 0.020839299916500048, 0.061765861877750974, 0.09548010439762185, 0.04275230653283577, 0.022065166999856313, 0.04870850224829009, 0.016517506822222666, 0.052456679348383224, 0.010512334148159191, 0.027378651336015716, 0.05192106897612253, 0.02790603775440926, 0.005210918569636922, 0.06698852074482749, 0.021618016800212286, 0.04271525852081757, 0.042498053442085945, 0.010754097132913528, 0.006757143991924222, 0.04047702922816238, 0.05454998778840227, 0.03419019379502824, 0.15089368778130702, 0.05876544021791028, 0.07521903232461022, 0.0015042062178479449, 0.019649628572346225, 0.09141912593716577, 0.0950064781993147, 0.05974054757145144, 0.04309696565952994, 0.060214637252952785, 0.025093041420463594, 0.017961515526797985, 0.041484369731117646, 0.017098630478064862, 0.0542265722798484, 0.048196146474970926, 0.08190054476501481, 0.08095092515671447, 0.05024596027308895, 0.024111646400283904, 0.0018591937658775058, 0.03466005467118756, 0.06999487958608136, 0.019991660017460104, 0.023134089480604858, 0.029795777480748874, 0.09611783429018914, 0.006597282509544805, 0.0536912645123178, 0.013470672683099346, 0.08429280752616544, 0.07389366957208804, 0.0233706095511274, 0.042483490110645374, 0.053507977976433696, 0.028088401154344602, 0.014198066463934319, 0.024239472000889724, 0.006121607504845147, 0.07704346305540494, 0.07300549787619422, 0.0911569553277185, 0.1079345873046306, 0.029383198913907813, 0.017584424067829407, 0.04764592297555459, 0.12752018433304566, 0.05158300969689604, 0.05457834070247989, 0.030780319207077547, 0.05465635526624899, 0.07483712983347716, 0.035313228896308335, 0.03377921443672911, 0.01080407192104406, 0.0127303798968393, 0.03379328364145852, 0.07883081513066446, 0.04176026863616802, 0.12469652980085343, 0.02494845190085471, 0.06741097993067197, 0.008492685062059713, 0.03789579555872948, 0.03460212310235347, 0.021547460102386052, 0.031633473023952495, 0.04160117898737231, 0.06228449574160961, 0.03783064361120905, 0.04833091666261035, 0.03098894601627704, 0.04538206038095298, 0.020459310729957877, 0.013910266382980251, 0.05256130780664183, 0.020308094549803965, 0.08552817793022241, 0.041350369461842125, 0.07256208618562068, 0.010124209107861165, 0.03558395670786981, 0.06851177932994981, 0.03619766591357128, 0.09560925149989706, 0.01718417185569002, 0.024680815254067703, 0.032821861170833154, 0.0338561526469646, 0.021876983246916247, 0.062404675784731106, 0.046625516843050725, 0.06834572211148278, 0.0506642825841423, 0.03734759453143324, 0.046462351606497844, 0.0042958059554709304, 0.0646644551306963, 0.048807342912280754, 0.047160039370458935, 0.023118043769030802, 0.03616573153844765, 0.035681947014264526, 0.036575615391015046, 0.08581307070750384, 0.04470667726690731, 0.0438074087874303, 0.047019688232291135, 0.02404589307374291, 0.03849769168863854, 0.0241335162953023, 0.02863464674221412, 0.01308499433610949, 0.036282935329983314, 0.06874819406338277, 0.04058892786082241, 0.03353345343061993, 0.019567751010218938, 0.08839008323247395, 0.08179657131193147, 0.014526970992465655, 0.014945746253004238, 0.03463499210474472, 0.04178487921073552, 0.02353926955331718, 0.02196538021727916, 0.01615369932786111, 0.0270976081505538, 0.0987235444688028, 0.038802487430192774, 0.05884466903103937, 0.02013373676867735, 0.039717571794866555, 0.036516936886454784, 0.053973043142187024, 0.026759112201210473, 0.10643186753675823, 0.10746833853303425, 0.10792518740579968, 0.119565878093483, 0.13650056575575184, 0.18543486092840472, 0.140357849098021, 0.08947983564388368, 0.15337250315614287, 0.12763794736876605, 0.13550288945196137, 0.21235502204827725, 0.15972459778910683, 0.1283300771648365, 0.1653633726340148, 0.0735966572838445, 0.1563302460577219, 0.096766909944915, 0.08359385188668968, 0.2438302193918536, 0.10626064688568154, 0.15698638504310963, 0.1738464634024328, 0.10389711242169143, 0.17903796547362882, 0.22313193327957587, 0.2217025051434194, 0.1543323040729569, 0.1464885902861434, 0.1104829787847496, 0.21796417993403253, 0.22154427734353851, 0.11496832398998161, 0.20228168596663784, 0.14242734369491378, 0.16763626357480405, 0.09950565129157998, 0.08710087216909855, 0.12570883838399766, 0.1699766621834809, 0.33007281261586374, 0.19459986187998327, 0.16943580410893888, 0.11653912599168478, 0.11798733094286536, 0.17797200009226802, 0.15182696673418247, 0.14199309441591465, 0.17761733202684313, 0.14313812007106122, 0.18823184793995273, 0.061918696418644927, 0.11895998681504881, 0.09603158811167364, 0.2846437680625147, 0.2589908849087454, 0.12126696100758931, 0.18071254174555504, 0.13854525442565643, 0.15535265657930605, 0.12754195655185369, 0.14462569428067054, 0.22924926792902334, 0.14822066911766607, 0.1278452431001971, 0.2219496297860338, 0.20307544498674332, 0.09210358719311415, 0.1546440558928636, 0.12949577953305938, 0.13744207249293405, 0.13854099497679742, 0.08535959262160525, 0.1500465171111207, 0.11312126302190366, 0.11082872192585662, 0.08518214367570416, 0.1350011784703501, 0.09742085025796006, 0.13588208765272172, 0.1447928853092655, 0.2163253952899287, 0.19841850374735173, 0.11265938095147572, 0.12528810289598283, 0.19003630675856145, 0.19198109756313986, 0.2525127228469618, 0.1929539985834591, 0.2384040033024165, 0.1956232480945126, 0.16226848467223107, 0.16083916378838403, 0.10046518407762052, 0.12737951526838925, 0.11677624552600807, 0.08251088701428906, 0.2312670515910272, 0.20495828992176443, 0.1734136696904898, 0.15674679870567015, 0.177578077681603, 0.24257921313326208, 0.2133975451391551, 0.14024730261054733, 0.11920881983373435, 0.12330703782818972, 0.12649316686175524, 0.10816650510194803, 0.15956329031577035, 0.15648115005704666, 0.12987039652803253, 0.10891600722266782, 0.10413078456035546, 0.09643266578355143, 0.17900451807485473, 0.09782261740896972, 0.16776361803133644, 0.15675095090221974, 0.15826032797415412, 0.07490951748144242, 0.17698439018380258, 0.16510897015611972, 0.09012552518998423, 0.15729841265466907, 0.17500376178612634, 0.060848207288091226, 0.11903081164364854, 0.1823875623484773, 0.12086334758468213, 0.18011865506489433, 0.13658003971701668, 0.10610107843193317, 0.13518180668113694, 0.20646581306092202, 0.14590366683419675, 0.1196572800437289, 0.0804514205083251, 0.12127789308226879, 0.12389697149516114, 0.0791582870747774, 0.14240324256881592, 0.1546258536437827, 0.22573928288634748, 0.19610540851229624, 0.154060143676977, 0.1110414645424293, 0.1398453056331604, 0.08596071117227116, 0.13447014164299737, 0.08645357383835701, 0.10202179813096601, 0.057485303465997985, 0.07533805940540568, 0.12007461410135993, 0.1602815896753342, 0.19216361035022045, 0.12426920595668978, 0.11183508566670841, 0.12529495172202587, 0.25419800902806944, 0.1717335316202333, 0.17876920650803274, 0.09027028516415628, 0.16917602369381537, 0.16274094641689332, 0.15685565979971042, 0.12493590163367412, 0.2634684849650629, 0.15290106796929914, 0.2686913966411545, 0.10044792411668647, 0.13311606591507313, 0.20395825406716717, 0.18344251138548698, 0.15340359100411016], [0.018171917744761994, 0.06426867878725452, 0.02268425797322585, 0.0688182681258167, 0.05338218633926684, 0.04563075550381215, 0.02228424899400242, 0.06910285446792841, 0.027275409496900056, 0.039896499290461504, 0.048576857699381734, 0.06967146024708787, 0.013605940827889549, 0.021393250433668014, 0.03576723175243505, 0.03670085927531604, 0.049159697392174316, 0.06185907945637742, 0.04591536482856159, 0.028200860946409168, 0.010652717845063778, 0.05607134264503276, 0.024005721338213454, 0.0695812993592793, 0.030185164650902156, 0.027470723613195365, 0.0871056065924706, 0.014418459426040852, 0.03653185261834053, 0.037071925452760154, 0.008340500738291491, 0.047952790984943996, 0.02336902183390433, 0.024049579871878512, 0.03783037548043555, 0.08542561407891974, 0.0478509395954109, 0.0676240902694483, 0.04850094604696478, 0.06670013460661135, 0.05120429796196761, 0.04670135188667525, 0.06534549197362316, 0.04879747953025564, 0.07194657284285753, 0.08308857093535124, 0.01294251443112209, 0.0441055778684395, 0.020045627081286044, 0.060346163058232885, 0.046754503066861824, 0.026232880660362785, 0.0635433888753816, 0.034767667041911234, 0.019276438416132045, 0.047312873911352894, 0.05121448310092092, 0.02109977364119503, 0.05083792024262009, 0.03920003343673964, 0.024805949970839486, 0.0576096203839106, 0.05660393463087179, 0.01515829447476614, 0.02600247780191562, 0.05527791304273471, 0.09049351552441236, 0.030597111195205685, 0.110580769908284, 0.016006951355525566, 0.013269326582010235, 0.02187538595359412, 0.061739857023161274, 0.04148877090624264, 0.04220300233892856, 0.03485489381296981, 0.020603413783734845, 0.02693166584527541, 0.04741406263483148, 0.02366278782456873, 0.02040058817534197, 0.0929058421282999, 0.02555962918596643, 0.04606089472109753, 0.0116612687669394, 0.05489511039829063, 0.06911721861650867, 0.10503176524634324, 0.0536112811025833, 0.10328234218421484, 0.08218198248575773, 0.06967713695860679, 0.04106525834950228, 0.05010006648878898, 0.07134114121717793, 0.030615686912149675, 0.02907175544439064, 0.04142359214564485, 0.042356583815548694, 0.05689211009490875, 0.07414140708504185, 0.037227161679296725, 0.037292604740228386, 0.08196472761131103, 0.029627268780924143, 0.061280204268592986, 0.03609234797618082, 0.04307571821095001, 0.033733092113247806, 0.03992208279669285, 0.015318590712042586, 0.05771214976125668, 0.047888443429744056, 0.02660505575007729, 0.0072313600779330784, 0.04024927894915304, 0.00834413391027239, 0.08786921239187641, 0.12092420560938698, 0.02310936782328833, 0.0015056283882586288, 0.013650304021974726, 0.056607159861033006, 0.03360044015871902, 0.023127658172480525, 0.04033469009183107, 0.030364718423375202, 0.04733212953132968, 0.053734425905971765, 0.02533858600673416, 0.017558524550329295, 0.051127535951954704, 0.005284188176325012, 0.02617578795780578, 0.014132673198717737, 0.06228738389308415, 0.042114683892577894, 0.036299590081457174, 0.042649780985929316, 0.04680190475717668, 0.060357865051276265, 0.05185543822364942, 0.0786614254297268, 0.06025951468355714, 0.0275847174963283, 0.023146245380743377, 0.05602101449884715, 0.021785422333426053, 0.04736845742069906, 0.04975032053827759, 0.04476572732411085, 0.03482454907028906, 0.013975944058338722, 0.034135778569766594, 0.04403903164089688, 0.01595623154688867, 0.02356245711956534, 0.01642716398853208, 0.06632264478192215, 0.050073218937482566, 0.03223096989395638, 0.08396597143502967, 0.02138941616360699, 0.03815414338943459, 0.039746047283012065, 0.0660978822458175, 0.07787286814662718, 0.02348879393520615, 0.026961541359102534, 0.06578736382746889, 0.04643618970388367, 0.03905247724164398, 0.023232907161957795, 0.030288416066116867, 0.03497575567434392, 0.05104632297110173, 0.0570521037274551, 0.018001807921175516, 0.03735312185580692, 0.10865975847287525, 0.05195935038969882, 0.04071535535096642, 0.03692989275159855, 0.011652639744082286, 0.043831134530445265, 0.021624902015431754, 0.027891167987798973, 0.04073122103187827, 0.00973595957827544, 0.07298509695477064, 0.019742886370588696, 0.009056678034305092, 0.06784359744239239, 0.02570759332288177, 0.016412598741871696, 0.01701381496874796, 0.0493276966435294, 0.0452175161861364, 0.05917626252818493, 0.021275175217118476, 0.014867708706597408, 0.04178485622809779, 0.018904531457191034, 0.04964985959832707, 0.042317168591844465, 0.006334996029298994, 0.037851542489783424, 0.08626560650525555, 0.029432523484912612, 0.03213320941393895, 0.045787393671250155, 0.12982392563454567, 0.04309081014305834, 0.0645036456145106, 0.05133878469707505, 0.07563432858836266, 0.14261561746318496, 0.060810615353646784, 0.05099841949319647, 0.04405464068235409, 0.05599126347430772, 0.017122287273166642, 0.017922810849643523, 0.035888396218539245, 0.13167871642977963, 0.05880672852658938, 0.06205754219404152, 0.015114898466685367, 0.04250748398443384, 0.03636344350994595, 0.041385575032402436, 0.0455271574338117, 0.058755128674449465, 0.033829944779074965, 0.0271977435031365, 0.019648561794911663, 0.015554858931160022, 0.08276145905256271, 0.09572454007162202, 0.007767765266415213, 0.02354366498278274, 0.010951044931707364, 0.027877947225445704, 0.06860380947229362, 0.03133305164444591, 0.005705853024752992, 0.031101857800216928, 0.02635695051491982, 0.03739032308540998, 0.06441289483900033, 0.04745677203661011, 0.042529114476975896, 0.07206794415270129, 0.06540342354245725, 0.030087197327145168, 0.008253641689436571, 0.04080083544155763, 0.020286644087924112, 0.0283793383653486, 0.06539302006844552, 0.07094796191179945, 0.03734442292742672, 0.0362588073908081, 0.03987211088139204, 0.026916847789600015, 0.05782518986492388, 0.02716475001145755, 0.0562090507798618, 0.02388181619256014, 0.03529517603437266, 0.03769662418973543, 0.05414051379287436, 0.02855513447655305, 0.043833570690044475, 0.038384207253975254, 0.027744465980738885, 0.07062546953919434, 0.02106874133460224, 0.046398172590641246, 0.03246397170568666, 0.05700322348744639, 0.01733986773498116, 0.023888161315792994, 0.04782123453614693, 0.06256024142907513, 0.04434132227493871, 0.03383619222609747, 0.02861282089725137, 0.06005262880916557, 0.041362607716432506, 0.04272219544697193, 0.02489912924506972, 0.03363189189845035, 0.02994043786349076, 0.037094720398947116, 0.04154135901180487, 0.016598524450654947, 0.01947680679750779, 0.00801705937427018, 0.02505601447586331, 0.040932005015952934, 0.08150476076069378, 0.053934968572350285, 0.02838611632825867, 0.05393553930785387, 0.01925457426677308, 0.0344165344722569, 0.034303743347165086, 0.05397641009861424, 0.055913938389670466, 0.012939988256191776, 0.05125706226775243, 0.05459703707827195, 0.02038726590633873, 0.04921633810285599, 0.11276627319955057, 0.07281076598672137, 0.04420272930855713, 0.03649206967243264, 0.024233686121841593, 0.01779062620874855, 0.05358455229490515, 0.08789453925865312, 0.010630169004622486, 0.02560175253048299, 0.039571084292425264, 0.06858543102299014, 0.03657397213241747, 0.020351085488894777, 0.014716657235347217, 0.047095760763172186, 0.005679570463290739, 0.05423416421117802, 0.04185719408034798, 0.011642798387084999, 0.028605895462415876, 0.02748223408425768, 0.07337055409387236, 0.05859929106889233, 0.03676115422539654, 0.02924648094772091, 0.09400546175217438, 0.07085256098258881, 0.01572575399486889, 0.042049152731534936, 0.024981439646874225, 0.03520652817021455, 0.01112879648233854, 0.07978450266584274, 0.008768733354255317, 0.02883228976579924, 0.02872874149151387, 0.11887873552979962, 0.11857379423153978, 0.1982225384563208, 0.25881336701493113, 0.0870370417232475, 0.24981224759211465, 0.13210317510510647, 0.24365766574778866, 0.16509401611983776, 0.0866242582278867, 0.07835447698110536, 0.12603457130852247, 0.0752868770711845, 0.23786375809821392, 0.11051123210739706, 0.20928769793000915, 0.11952058697539954, 0.17979610140525526, 0.09999229332372066, 0.06897244332057816, 0.2612504459196522, 0.1704075406756132, 0.19661609804438007, 0.14269214964682056, 0.11709407242315432, 0.10624261317594398, 0.11923278306400585, 0.14126963162374112, 0.11237150809216885, 0.15779834631229603, 0.13981049459788109, 0.17523755649885825, 0.13892370186025096, 0.14167049479100013, 0.1715754263944203, 0.27263380767356965, 0.08544252930028785, 0.12806222218299104, 0.14847076618142668, 0.1412594426543482, 0.29263314580725086, 0.17330384332566492, 0.14000791545596816, 0.10739450297889211, 0.2808031241499609, 0.18012237825220634, 0.16143835179748076, 0.14029306870314384, 0.12869497250405051, 0.17497863410220993, 0.1724342416010557, 0.07019018604149742, 0.19633721139642502, 0.21810373051031945, 0.20516878023983973, 0.15462799868997068, 0.17350345519521546, 0.11626299726025713, 0.1221022419931908, 0.07888682381880861, 0.09605402682697582, 0.16618719294426904, 0.1780339612835838, 0.13170079508375737, 0.1409026601862523, 0.18299459509791868, 0.18232051433334429, 0.12373785503328809, 0.32122014571101437, 0.12267254848754215, 0.14258046934921897, 0.07913689023905224, 0.18848825756820942, 0.10082320760815375, 0.08779770574502407, 0.1377774044991501, 0.18899346191075542, 0.1916303671896458, 0.13613770054953714, 0.10012240569678046, 0.08699771076921495, 0.154924183603256, 0.22637705108331097, 0.10091837105010787, 0.29180004051135433, 0.15155160409067908, 0.17732516141428104, 0.32973686773930827, 0.10795354798075654, 0.30933864294521274, 0.18698179163038733, 0.1473947344047408, 0.11601173574285162, 0.09502176165340409, 0.19335395776696745, 0.1775248039273485, 0.12247079157180364, 0.1130484616864593, 0.15229063378947397, 0.14576367192691372, 0.2738031642811914, 0.19940864174596726, 0.12356303376896728, 0.25381064433003625, 0.1721950842728538, 0.1180809239045747, 0.12802731921716085, 0.2152478006938773, 0.2112132752494466, 0.2603617839274868, 0.09535219835778398, 0.1147545931199866, 0.13138908922912615, 0.13282466139043533, 0.14415847257741038, 0.15962166621560053, 0.12899472738706297, 0.14307585244457569, 0.2746693032883829, 0.11998380203881573, 0.18673851274915282, 0.08662235832983449, 0.0910801779959471, 0.14952421368610475, 0.1211130616044806, 0.21026134971649418, 0.09715025268134572, 0.12394635352276026, 0.2366587630803547, 0.12840267931742053, 0.15020149669820262, 0.1187532886321987, 0.15809197249191423, 0.18315890563591836, 0.09506618709213312, 0.16424180459110968, 0.16357066560416453, 0.10531849663464293, 0.07836932376507791, 0.16570794366059766, 0.23405547373958174, 0.13068523828781423, 0.13455533062017735, 0.13218880841328254, 0.1790564128708455, 0.16688672314968803, 0.2402164907224717, 0.1450183143418643, 0.11817630185114762, 0.12990966619503114, 0.12026052065794507, 0.08595180156971179, 0.14404752772421608, 0.10552630564498325, 0.11732654946465647, 0.09368838562119393, 0.18580068323400714, 0.21725069160663316, 0.1637674429483952, 0.08751829049640125, 0.19917815653306825, 0.11835075539326477, 0.16183506276819015, 0.1849303307432321, 0.10070261004711352, 0.20193979624778996, 0.20322846338873912, 0.1126966741116297, 0.08375005721445046, 0.13397287397134688, 0.10318357812901659, 0.09664546968715806, 0.24127674108791738, 0.13744142897907766, 0.14593984150598127, 0.1393109133406993], [0.06219638796943811, 0.0420289395016528, 0.02507118110154425, 0.07149962948695307, 0.07124021679403321, 0.025625533814872467, 0.0623672868635866, 0.01911306059018018, 0.02878493404075984, 0.026883086294776974, 0.06075457602198567, 0.02197747866082336, 0.00845606318644939, 0.07376561797554455, 0.03303427820003802, 0.017524408739841273, 0.026772593433458, 0.021287047664725015, 0.05505383232488267, 0.025682379454073888, 0.033906561232382254, 0.05578166181822458, 0.033458840297234636, 0.058798607994592, 0.05973883153450105, 0.024713734052174037, 0.024063074510664712, 0.06249427359791533, 0.021934713717670213, 0.01059257994300776, 0.014291048470524051, 0.04966893135720203, 0.0248516624372813, 0.034507262265129436, 0.07193475976706513, 0.02459572012265844, 0.03339166970803373, 0.05962636216633743, 0.03608333495175166, 0.01356376960287772, 0.015531636890955271, 0.023247112347293767, 0.021310917049225782, 0.03788048529156274, 0.039368794945579384, 0.034852262300949906, 0.03468666090479782, 0.09178514742562849, 0.03496272451875191, 0.07650798291809137, 0.019969954831345428, 0.0855033873249927, 0.03564669547842876, 0.006021962448533986, 0.02871087823633946, 0.04872067155496729, 0.04168120836238227, 0.04733950312760088, 0.03038238441090911, 0.0058773212179902105, 0.043064004726587765, 0.020654377782897606, 0.03213735011916968, 0.014617756241932513, 0.039969618552394455, 0.08175638233942371, 0.04008126054559985, 0.04089160919970563, 0.03816821642460362, 0.055644382692633144, 0.06806843658728946, 0.04488350568158973, 0.0750184705060336, 0.06637033375520861, 0.046946002065294215, 0.08176887723346872, 0.04392752754351786, 0.03251646788069799, 0.02129613155228717, 0.0159363889120399, 0.012221460985470445, 0.06242121562301632, 0.06903310982330192, 0.046841005884831956, 0.06423244282843606, 0.038241358669174295, 0.04696625743001219, 0.0983803294178459, 0.051462867958170753, 0.01577680226370332, 0.02870407537557185, 0.04946841167346124, 0.0192811019763711, 0.01496777989931645, 0.07636603448660144, 0.037636842518564195, 0.013841272504519553, 0.04336850935473077, 0.04584605685405193, 0.026284202805630145, 0.012555585445595846, 0.07484649142791187, 0.04577432804170155, 0.05925678986034567, 0.0919162480521106, 0.06397810929845418, 0.021035299681487585, 0.05921643234849457, 0.036251870464653745, 0.009488044907489132, 0.019682269663580006, 0.03873823180554375, 0.05101427368278946, 0.0399688218209532, 0.04391892437612818, 0.0237569936566175, 0.006051731188856667, 0.03305171053075502, 0.04576759412884713, 0.04398253648692081, 0.02363828833275024, 0.05090126422263923, 0.07252070211595105, 0.035010574370502465, 0.050989054068322145, 0.03280210759370558, 0.0335925264704612, 0.0234134376965343, 0.03815065002849987, 0.050086790185061195, 0.027187238522474805, 0.04124477956323855, 0.05471406083914542, 0.025625171838328246, 0.041591307944467956, 0.03178011374397865, 0.02888139408652581, 0.07056985155589159, 0.06739559688515241, 0.06964110784352788, 0.06317147617078116, 0.06118903980560361, 0.019759763287560596, 0.014563957717449916, 0.0237268002163018, 0.1746807791172497, 0.0499709959953062, 0.019303866279041095, 0.03319979915695806, 0.034353799532137574, 0.04523172328669218, 0.04078129253860924, 0.02426142999601941, 0.07196888132321258, 0.03130766732107488, 0.1375008007932094, 0.07413295713523704, 0.04395725941585918, 0.01023868466877649, 0.009401939497629722, 0.06088465392108887, 0.01777486203448667, 0.015253335342652377, 0.034205044409440416, 0.031147078055167393, 0.060935342128598885, 0.09253368427556369, 0.03259463183161232, 0.06815158777059087, 0.025418268726958383, 0.021580108854499076, 0.011653106100106192, 0.0495347855312209, 0.031469390397110296, 0.043734481047478416, 0.06142066648950981, 0.042353668850996805, 0.004848254940307309, 0.021252039361805208, 0.03779893140158346, 0.07568309008474312, 0.01473170415978999, 0.0649283877423694, 0.04170819380951505, 0.014074544362243147, 0.06389462869734534, 0.07252270926631267, 0.03240382231231178, 0.0401041780658547, 0.08857635751126275, 0.05082209286610446, 0.03892747467503913, 0.04799718961059567, 0.020996273247404926, 0.04419635162658749, 0.01850646834129528, 0.040157968929458054, 0.09846324311389078, 0.010278278965533022, 0.0315130957131905, 0.0439903007880334, 0.020887327883693, 0.0037314744681240094, 0.03787628329929806, 0.08877803015732959, 0.02765399291210117, 0.0632792609112878, 0.04643799001050573, 0.04102828311583689, 0.0990199055823107, 0.04822285613045097, 0.04821402696712364, 0.08865082891838205, 0.03344809208365698, 0.048191680182372375, 0.03157622327337102, 0.027393704963727828, 0.020722850721569794, 0.05108716311834512, 0.04826140184436114, 0.01572332358092911, 0.054742264366077806, 0.04023981776328818, 0.05267777232333057, 0.014693468711489152, 0.07415303629973242, 0.036000118650976694, 0.010717604534640428, 0.07462620284528503, 0.058864280881900946, 0.008648835806055896, 0.044848150723884185, 0.01975843795545159, 0.019661682965834777, 0.03092899389054266, 0.03688863891687605, 0.00931106040239214, 0.054186364155142545, 0.017387708010632667, 0.02395930598610111, 0.026906300674102483, 0.003309883595061218, 0.08567004209204067, 0.0591116851466077, 0.0295194840404175, 0.09926351388135266, 0.024516328515845443, 0.028301051840366378, 0.02932656586410538, 0.00929887768917627, 0.06988381215881917, 0.03586170571525732, 0.005302555613114589, 0.03859392765368666, 0.06344266363509721, 0.04066278256716267, 0.105828151948029, 0.03291154325368904, 0.06904634782263348, 0.08142461264205557, 0.11178056318913737, 0.06410064506194284, 0.10825875740978988, 0.09469690206911295, 0.023111564580411203, 0.0036923855499950272, 0.061015291064376795, 0.034087296695478504, 0.036611521932026075, 0.03352303846528934, 0.025929996308179635, 0.028399662677979762, 0.06265776442183603, 0.008737641675848394, 0.002411296455031862, 0.037913691372640675, 0.03607041870934829, 0.05918723290726062, 0.06975331674179724, 0.052692737850931384, 0.02112506028835572, 0.06525546132076172, 0.05918119230397767, 0.08578392872286421, 0.020789515692740682, 0.05438942725079195, 0.04442815068027666, 0.030521145916634032, 0.050203963333079894, 0.04179729366554849, 0.04168085213149748, 0.004706897832933934, 0.029137838188739076, 0.02134736942788286, 0.03368983495860331, 0.05902137104121428, 0.054193883308119355, 0.021771107980560873, 0.06210234684629306, 0.03453217927486666, 0.019187836517249385, 0.060331143904477365, 0.03490701077445861, 0.03429613609407698, 0.025082752859640508, 0.02509437441345184, 0.04180390500433503, 0.06357804669307605, 0.07441352917662553, 0.06673488435485671, 0.037582369836708235, 0.023077783933390054, 0.03396159315842294, 0.012644018805135163, 0.0620638394367791, 0.08581530768424274, 0.03851254230305072, 0.032867056527926077, 0.04056774552971606, 0.0249761191662401, 0.022580859086085713, 0.03968105621395573, 0.07718667553196992, 0.029174568274268703, 0.05668666063537521, 0.043908842659044656, 0.05252839283897512, 0.03571067914186466, 0.007939239684116818, 0.024512861967988075, 0.022111237612402728, 0.015195117448456587, 0.03786959535171909, 0.02996459070052351, 0.016521521122945894, 0.007126519030275485, 0.08334613735637358, 0.0368078051495456, 0.012878248272764107, 0.013621988454683414, 0.021393464938286814, 0.05666075537221567, 0.039133326330732916, 0.06233453660482361, 0.053130465169106765, 0.0324354847262223, 0.02730852556264689, 0.0179608739281614, 0.0397599058135623, 0.03854970522825757, 0.02158164869122688, 0.0818647301545547, 0.21668424619542015, 0.119916164135981, 0.11049804773422019, 0.11990523206130152, 0.2799641965858398, 0.0798636395484209, 0.1360380018670713, 0.13281117824296798, 0.08942159763987988, 0.14723232376479334, 0.19805464262683548, 0.155264341963395, 0.08624244000642531, 0.16331177385103318, 0.1238119510573245, 0.13052759271475578, 0.11360530801598104, 0.13144772559885057, 0.11867054347549716, 0.05488205242962126, 0.1942506023953038, 0.217451008277074, 0.09071515242178595, 0.2237470865610146, 0.16220992491129907, 0.22005020670833128, 0.0764986826106906, 0.17345589645687612, 0.12508980103678283, 0.14239363582624545, 0.12656532468334322, 0.13657073940961592, 0.13873794086037144, 0.21957912392193274, 0.15712444940882345, 0.10121824850718822, 0.16515864329713006, 0.15700800404433282, 0.16074403098994688, 0.1934612560416422, 0.0888099453802551, 0.16369098737355203, 0.18641393661739367, 0.12914284282634336, 0.1399348153462333, 0.13483856864754232, 0.15615729404793632, 0.19525624601350677, 0.16584179454272793, 0.22261333772011344, 0.20428793234450204, 0.1866566485935642, 0.16680309699187357, 0.11483312479310459, 0.13290257253233465, 0.09637051307025457, 0.07912206643771741, 0.15422411713629, 0.16444564526600225, 0.20644036362007742, 0.08551887762282165, 0.28401431958040885, 0.12821317980847052, 0.21169250921135951, 0.10491067738903147, 0.145405633074622, 0.11524848234389098, 0.16131536404211677, 0.12885847098885045, 0.17392699456503316, 0.17414707630392046, 0.1111508006109826, 0.1644413398518678, 0.08744139825144122, 0.29258163405522225, 0.20282574628870334, 0.284134472810453, 0.24039745601194523, 0.13807596428500069, 0.18706996835047202, 0.19042583182454112, 0.12188424401345754, 0.1310099829589167, 0.1938731661967693, 0.20856421981607715, 0.16173933242117206, 0.17832734231506625, 0.1420306174024459, 0.18484564738408213, 0.10622596608534937, 0.11283453929448321, 0.18169578495285205, 0.14136366125556732, 0.20443808557766102, 0.22557290391095225, 0.10864996020832371, 0.13913909514104167, 0.19132563273512548, 0.0866291611906021, 0.13314799645975714, 0.1391437376338628, 0.13394399245660152, 0.179071320941852, 0.16301197300274528, 0.22418827659660773, 0.18526564742768967, 0.16186282579456607, 0.270656258949349, 0.1403835130434844, 0.11908089081125876, 0.08132086135447025, 0.06865662357379353, 0.12799719663997813, 0.17403418558739847, 0.15065270716384535, 0.12947653540440146, 0.08351198773110106, 0.10620676026108766, 0.10610046556159373, 0.19501036243332973, 0.16946395017927693, 0.15686906633838532, 0.23282080047553588, 0.11142268521530975, 0.1219112103083922, 0.17754737287759784, 0.12198040336971322, 0.16483648800321166, 0.14364988212623905, 0.1150129562724502, 0.16302600773351808, 0.08483250114706256, 0.17143901677862292, 0.15548391808425227, 0.1879065210420278, 0.10024018405425934, 0.09633902685656663, 0.13996653138629853, 0.1614422282023776, 0.23221719979999528, 0.180454385436831, 0.1664162532336289, 0.17380330200877883, 0.1613306551570854, 0.10116914993212109, 0.2772417346075658, 0.19002483076145574, 0.13445417637065535, 0.14098696050144013, 0.11445411045344607, 0.1591588571787842, 0.09690642987768497, 0.08100160953378485, 0.17914950787540407, 0.1732419127778661, 0.31823240280632054, 0.1728393488954152, 0.18807277744335515, 0.22457029400092943, 0.07439322018575284, 0.17413440520965284, 0.15405839699650967, 0.14277862565171334, 0.16521876587742762, 0.1449679210782051, 0.3204808708640837, 0.2587510074578947, 0.1755603246631161, 0.1836806881211458, 0.12896279684237896, 0.08240895901596354, 0.09965455580142238, 0.09312919506262388, 0.13782359960098423, 0.1322473988177315, 0.24670651182532313], [0.05234552382100975, 0.05498555090819156, 0.045390360943612554, 0.04472980546134134, 0.034925435189037554, 0.014629774246244662, 0.06904550512591678, 0.04882160363899124, 0.0038439658613154486, 0.0731573518245451, 0.06885184575953791, 0.018370767356827855, 0.03995402483269572, 0.04888720757838699, 0.03827826495492651, 0.038212940637623115, 0.03395739499659788, 0.026557870479601047, 0.022717370208533063, 0.06532691434145936, 0.015808264537143613, 0.050402893384377805, 0.032085016737842274, 0.03484901791859058, 0.025447276646211266, 0.011599793083845608, 0.02984457728152554, 0.046353099807616205, 0.03358709107663843, 0.020211128886007977, 0.01388999378128398, 0.005755945120096928, 0.017696236515597954, 0.03436244483436308, 0.07540998740061637, 0.051063858723688516, 0.008406052966752361, 0.005088528362853874, 0.008830391940841032, 0.036432682536542416, 0.038728395236595985, 0.09250444269949391, 0.06214428249926818, 0.016061828148761587, 0.024084419635454976, 0.036037419472009904, 0.05205958916415131, 0.02523028032643901, 0.04949808608920825, 0.03243794386845923, 0.042851886471673366, 0.05186889072759979, 0.06040042889634929, 0.05140796626707719, 0.0448341045017925, 0.0377254176043695, 0.08735508312501254, 0.05211978835324126, 0.0566266491378267, 0.04549863214995112, 0.06402960572872432, 0.0699225991904255, 0.06298569984914315, 0.02166839282689316, 0.016825905092240825, 0.03739234172709046, 0.026102548037024758, 0.05665108734261125, 0.015949583818925726, 0.08934563236130823, 0.10314768690976406, 0.030236435085234624, 0.0747175818128932, 0.012613756416906274, 0.050021553967869094, 0.021693918876530185, 0.041020082144607464, 0.021499918601025018, 0.05991033563810972, 0.08365498570304725, 0.009687918204543813, 0.0866991586442436, 0.0029196645013026654, 0.03981572681016499, 0.022945945947280815, 0.011281989169337097, 0.037881607610371806, 0.07151064583130422, 0.08310488094725917, 0.02956449362118879, 0.021182549441413536, 0.03488534580795996, 0.035563299146991585, 0.062174677037664, 0.04896747061021386, 0.036355131455967506, 0.03843959158046111, 0.009045331314536593, 0.07620840423530148, 0.04071304942631433, 0.020041744930729754, 0.009260928566237132, 0.04692856207369797, 0.09124965196655643, 0.10786485032088335, 0.01810703775845468, 0.06513595160457396, 0.05695405213402645, 0.03272928327562348, 0.033383909237360766, 0.015382546604791237, 0.029956983447435404, 0.016373953436531367, 0.07445954807823704, 0.03897259725377925, 0.04302558158674548, 0.017478437718725013, 0.030725352398510423, 0.050661214402005564, 0.07686539357828517, 0.020073765490744865, 0.053485956779050256, 0.08504308339568876, 0.06081658317857693, 0.03411053214222193, 0.025486008136443077, 0.05014864795450723, 0.06843334724826199, 0.05273327539344469, 0.029072088692637704, 0.052821509570123694, 0.006709114588316411, 0.028281685137640566, 0.07247682826052751, 0.01646248255706122, 0.050576147998893456, 0.023649383201113632, 0.024177868955678517, 0.02429772149621239, 0.03251795792171071, 0.047780742958909085, 0.0561130331498721, 0.08342715881524548, 0.012492203161180502, 0.09129213920283703, 0.021831096495471655, 0.05376642156812934, 0.07289542636323361, 0.009386057537349482, 0.026950362221067472, 0.0713043766576917, 0.05913196732440303, 0.05120801731883999, 0.026409283896247228, 0.08210096102688583, 0.015089343688751181, 0.004813278238514378, 0.04367661842655751, 0.03727826740472548, 0.06835267818983524, 0.035115976577564594, 0.015259287845824036, 0.021772050268707738, 0.0534101523789427, 0.014413652224315992, 0.0457829810048063, 0.049112437428125454, 0.04186113943315802, 0.11144753710757341, 0.019090618044438384, 0.025472427312765392, 0.042104732410441485, 0.07203903965531819, 0.03440457583975888, 0.07632458912989787, 0.046809255370810154, 0.07263678741911728, 0.04204300870638221, 0.025171159406102477, 0.05485303301904952, 0.018388875760138035, 0.04089750424628297, 0.13425215898502257, 0.0328498616844656, 0.08203743701620449, 0.024732487884560422, 0.057915124756794785, 0.0438089486241581, 0.04426596603626686, 0.013021496180895598, 0.034930426251864245, 0.041793424921530875, 0.01948324385129156, 0.03661316519062366, 0.02103760560613967, 0.01869699249284402, 0.06880366648997992, 0.03183683489389237, 0.03510940737361389, 0.016159065773770694, 0.02602998035839729, 0.025435586144486745, 0.01653027176226099, 0.05567592253247577, 0.05379356789372621, 0.035622345373755505, 0.017327951237318978, 0.007653309336502947, 0.05231816682123369, 0.058477207297278996, 0.04639102115986809, 0.01827212013003807, 0.05175593106316463, 0.0907242535463264, 0.053135414097097614, 0.10984044552089707, 0.0349501415245956, 0.10198429812707248, 0.03345649606818634, 0.06681642675351712, 0.04736967550049867, 0.03125894412909064, 0.09621230059213216, 0.08050424227070424, 0.1013830953067349, 0.07563697925258069, 0.021194544463087956, 0.03466879190396398, 0.00453908340029058, 0.11139971789933982, 0.037808844579323646, 0.04263003506968099, 0.06763392683839606, 0.03980436189580829, 0.032187007938421545, 0.03960705595090985, 0.05927375487742886, 0.06707632208182927, 0.024821344507677902, 0.0145576547290529, 0.06114012892207792, 0.021097743508195686, 0.04034750291236466, 0.037933364510536194, 0.026142947683711688, 0.05799048482590626, 0.043456854614158796, 0.04117889217131081, 0.026787744737380458, 0.04073951010321898, 0.0017664229122719038, 0.032193048541704496, 0.0694211563395877, 0.03916550968443194, 0.0853466610574434, 0.08094712536061004, 0.06554059924617892, 0.02829589989907559, 0.05305495188241044, 0.017167802471967957, 0.09225004788247809, 0.01956179659182747, 0.08379318796458744, 0.09402739484944651, 0.03134366579263682, 0.0773191474558365, 0.043973194044684215, 0.0700041032846897, 0.03598960409421594, 0.05990446357417011, 0.05447809426714817, 0.029527319204663078, 0.029063184835737752, 0.05765288136899472, 0.0940975838250691, 0.06570637301211396, 0.04593488474887225, 0.008976213904398104, 0.0338237241451298, 0.06025187678695206, 0.09416462417932288, 0.015857403331826773, 0.036245684304665175, 0.013037413572742334, 0.03638773615802488, 0.03153227472437486, 0.04129862022255698, 0.022376524284482006, 0.02894684480833671, 0.06707767805745525, 0.04082825372836763, 0.04412837664506609, 0.013389675164475076, 0.054329745171050874, 0.04231634887776548, 0.10650921943447283, 0.06358776451839555, 0.0883561225547906, 0.075263733554992, 0.03815189492137682, 0.056720395317120906, 0.020997322787861192, 0.02714237066796951, 0.011583174721548154, 0.05368909265305247, 0.026818932176777915, 0.09405383254371344, 0.05397460979199218, 0.012625024612662534, 0.03372111432855168, 0.03260444924836198, 0.030800467319486123, 0.034829038345525344, 0.012874716607433175, 0.021099379105914026, 0.01379222659799721, 0.08003226316143429, 0.03854579434940412, 0.08472992963488064, 0.05531666560038444, 0.05201334426660211, 0.0058388918536835385, 0.05995150903360017, 0.011629960668693868, 0.035519544035196304, 0.04957242726138042, 0.06275400804776339, 0.05800404841260565, 0.02405722925980245, 0.05465169362122974, 0.06287893017513618, 0.03388525632720801, 0.08961799960102766, 0.008197046944030352, 0.023387225998205044, 0.07720732926240853, 0.026948816638680238, 0.006701157328807899, 0.01838135086150179, 0.039461621819364454, 0.058961945600927844, 0.07216817909671415, 0.0528344679473629, 0.0163208041715646, 0.03544110429262923, 0.020052022000233975, 0.013158042734909444, 0.07456341427901099, 0.058066840809319294, 0.05935823905371851, 0.07296000757525045, 0.027175463751078616, 0.17118826087924743, 0.09678610810829748, 0.17974210752835199, 0.2355550448860853, 0.19550969854237574, 0.10813873441469286, 0.1945151785208333, 0.12067791600261005, 0.2104059105078059, 0.1458689170859514, 0.17562548810195538, 0.14021374795946384, 0.10334804954548037, 0.1325233743315743, 0.2528866963280786, 0.15230074615007447, 0.13316408430616702, 0.1480965781956911, 0.11235472310574786, 0.14226381456659687, 0.13844854348609525, 0.16427378110106916, 0.09979519422256178, 0.06819045907186885, 0.10185447686742391, 0.10000904000574544, 0.19000471329256413, 0.1553109813962252, 0.1078283309095329, 0.18694632175949313, 0.13331601486331032, 0.08832705717894339, 0.11524381686843212, 0.14252696576858723, 0.14147976954137126, 0.1088539694225596, 0.12609976539087872, 0.14375825292400776, 0.16792506340049929, 0.18194886975951735, 0.08745562450419511, 0.22806699507899825, 0.1319926132958743, 0.1588007876829755, 0.1039055010844623, 0.19514012240594436, 0.12270670834808581, 0.1398347336198053, 0.1652910539339627, 0.21626285187179045, 0.19798197152633823, 0.12903341482723915, 0.0891258493967114, 0.13532056052598262, 0.165227392027455, 0.12803600665422218, 0.13791402861956628, 0.1759008201019418, 0.14768048520049742, 0.16381818861249955, 0.19743060272547508, 0.23628348724976664, 0.14174446824096865, 0.10939156396254417, 0.1521355775935996, 0.13968309417607325, 0.13790189378684567, 0.17389429793242486, 0.1046980113812512, 0.1854198609268473, 0.14400750729105166, 0.13764609702892844, 0.19415219074055073, 0.12074916217956813, 0.12598151971976604, 0.1524261547432792, 0.10282519453715894, 0.1309214998036623, 0.15576452076915773, 0.2052039436755642, 0.18509485578585058, 0.1352358312015572, 0.11427791789174081, 0.085960611580841, 0.17329291891186469, 0.16322612522109864, 0.22686080496397712, 0.2168660695033689, 0.17258217317923424, 0.12092855698879688, 0.19764135351344464, 0.2153957782373313, 0.23230048887912305, 0.18066686758350942, 0.09643441246401879, 0.1214890652185967, 0.12306663943755052, 0.11749182527344074, 0.23209195974613392, 0.1316204018169834, 0.09122575768419812, 0.0751735879889419, 0.13182540694552083, 0.24628026050425347, 0.2982767623278403, 0.1499263025940426, 0.13598054527275025, 0.145500949734161, 0.11557813763858811, 0.098789083290725, 0.17474015093138143, 0.14998225765603204, 0.11079944970626986, 0.19176519866431915, 0.1567477946199717, 0.12310941012636309, 0.040645043801275954, 0.1844255554099237, 0.09131581898057654, 0.2090843015861127, 0.11460001955950454, 0.1804492526477383, 0.3279937725634344, 0.17881095829990604, 0.13058777658208726, 0.1563471766008485, 0.12144688441748581, 0.10611220968947296, 0.14987768665436776, 0.1460456535700829, 0.25767937302589417, 0.10179669085529544, 0.14393013241069932, 0.1590019164066161, 0.13959801245120265, 0.09500600322480164, 0.10238247232571726, 0.10716100704045066, 0.14064940684024366, 0.13078463053511036, 0.15327306494357126, 0.11810533912672151, 0.20182459194573665, 0.10561215345777812, 0.1698533526711887, 0.08342616290094391, 0.15609262090536857, 0.14961199204046882, 0.1119628155063237, 0.1874839316212362, 0.15213798310968185, 0.1001105466557126, 0.19012342627731063, 0.1517567624368014, 0.21010655399051406, 0.19564580172300342, 0.19808421362071268, 0.1414699329724235, 0.08769262912532977, 0.17335687193178362, 0.18237380340935724, 0.09117011671825763, 0.16560433792971796, 0.16410286688516218, 0.14050878374086273, 0.1459047853225662, 0.1012025666873782, 0.0921963221363483, 0.21367658500469502, 0.11474772131130581, 0.08018735000082562, 0.22257831218021534, 0.18768659252072536, 0.17190668281287919, 0.301457375528351, 0.13501072392588662], [0.04874922365190522, 0.03778966939857891, 0.043963882245964585, 0.039402142752923315, 0.0163175463826666, 0.030270269358410474, 0.01441656718886788, 0.019994364307832815, 0.03673964630692236, 0.11743658267322088, 0.04051109332771551, 0.04906853675962456, 0.04946597551386203, 0.03780262777581811, 0.010670015152784125, 0.07780623381897327, 0.08831407198862684, 0.0205343222290638, 0.06484991735628536, 0.02882613999498708, 0.03621482628307516, 0.026236021620852333, 0.05269171895399209, 0.008253072869152793, 0.04612853645437187, 0.009879720765316199, 0.05139888046429523, 0.025746167765089104, 0.03287598145224395, 0.034197260956129724, 0.02245894576903553, 0.06130812434299339, 0.028273945734385523, 0.028622205474323807, 0.024544242844586412, 0.06919309962540865, 0.035386635441212885, 0.03401641057984483, 0.02892641324339615, 0.03589872308375855, 0.008142714073220569, 0.10954595366192442, 0.026225351931286917, 0.0626481117139901, 0.04945824185626642, 0.020921238765661276, 0.06402668310329318, 0.032329182365849134, 0.013349950632771418, 0.032498955110748934, 0.022428306082503933, 0.03597589112037132, 0.07131310239914926, 0.08215385939805739, 0.07525665490257163, 0.06713274445745253, 0.01740249159235147, 0.011760962661355736, 0.02267707972937534, 0.000496962523269054, 0.021280376954124342, 0.029634023761196487, 0.013586830764618373, 0.0770772475328657, 0.09172384506992756, 0.04950370917457247, 0.023026364111912348, 0.006955016363081673, 0.006986538965946004, 0.06204951742303468, 0.043514847470026825, 0.008043700081837035, 0.0440140686658842, 0.043808400871292244, 0.020152865984146635, 0.039405073039233685, 0.026416946690709844, 0.06028470365450748, 0.06749851313690025, 0.08261559591177972, 0.03413777422880934, 0.026536339578489145, 0.03398199024940691, 0.042685419396166845, 0.026381354245747772, 0.023831717872751818, 0.053696994849991415, 0.09639806925289093, 0.0335304771790341, 0.008217620235236903, 0.025379161853643677, 0.07323419044335043, 0.05263618907080062, 0.051809599352700096, 0.025179523171015808, 0.0007029400148894639, 0.039645421634157824, 0.03394627523037695, 0.018362141206800457, 0.017340149272293333, 0.05302211735397578, 0.03561222918271538, 0.06345956353470683, 0.0493321705970072, 0.042404314923670985, 0.047274849137231234, 0.026359047680612535, 0.033191318563636274, 0.017652887430402543, 0.016046265072579828, 0.0315078882305252, 0.02387094923535422, 0.03817006652694076, 0.03705831207034569, 0.07682561063237729, 0.04384787355159079, 0.06289775678587538, 0.06529793323528382, 0.04411271014701455, 0.0350618907701104, 0.0379902963346291, 0.03248248038993728, 0.087118775643889, 0.09196024448160203, 0.044372310531475855, 0.04308869574038733, 0.06975830397418431, 0.09404814051043603, 0.017709156588440942, 0.06746757084563856, 0.10500185717377933, 0.06105127804461987, 0.049889024587408196, 0.07828487789318447, 0.0021866864183046407, 0.0337880167869791, 0.05042573046540061, 0.07535866717056883, 0.011158193191212994, 0.07528603437446779, 0.086064699947113, 0.04070973992648144, 0.016218353318230763, 0.02503266794637086, 0.04867930663749576, 0.036717720870529456, 0.025288420654232466, 0.037527334080227924, 0.03648469990660106, 0.03335983492434025, 0.026429707800308545, 0.030425959492042184, 0.024988535536272873, 0.03849809005435917, 0.03040697583327851, 0.08792445499209628, 0.02556744136757428, 0.03541663161388809, 0.04703870253457178, 0.024853506793959007, 0.026070257431016337, 0.03697937437062783, 0.028010344455739664, 0.07808142026225406, 0.05939387746395604, 0.04876475991500963, 0.03603317917534902, 0.05428672933410253, 0.01732352899477607, 0.0076312421738440476, 0.04566338701894687, 0.07317558471714297, 0.04085767150466, 0.024217736171258074, 0.09075295886084919, 0.03681096526223325, 0.08793030790383778, 0.019781543167247888, 0.029936368021393017, 0.04613159697562937, 0.013088427367620172, 0.005604659034419926, 0.009975153295653722, 0.04071466204139494, 0.05970646048926058, 0.11645532363364774, 0.0589150112242468, 0.061185519631591544, 0.03780047506875089, 0.04124525070731198, 0.06717740738343808, 0.028253537152082692, 0.029409169294540922, 0.014395624260237862, 0.04232519719329092, 0.05335992382418725, 0.03559478153023989, 0.03654869506135583, 0.08080562892099542, 0.07789897642308667, 0.05915085522217616, 0.024276020140537334, 0.029843525825849468, 0.006030805497204946, 0.027301690143142498, 0.09482954253232288, 0.015817089870031324, 0.04381053825660099, 0.03237263870335395, 0.07881923188124934, 0.09096252987341535, 0.0902432652430669, 0.01455007907709167, 0.06537643426488485, 0.03412098158150911, 0.06658172805703456, 0.04964524008814366, 0.06739319136907017, 0.06810333955311967, 0.016115523251374404, 0.030852205067452405, 0.03883847824087547, 0.04736314460094418, 0.01718733962925692, 0.009009933264385308, 0.008166683049151495, 0.03125466361281372, 0.026490782244851994, 0.04107457397866153, 0.043253148004653, 0.04351042714270373, 0.04595097642572177, 0.014427717598605783, 0.03456507509033527, 0.026985280508656177, 0.03987329448723505, 0.0434184123221184, 0.04604833470957895, 0.06545226930850936, 0.034646590675918326, 0.06796609490148484, 0.03966586085997763, 0.01885634261153398, 0.008279808380100276, 0.049125564344708, 0.028147290333084045, 0.023574519173933134, 0.022944429093190742, 0.04250529680341002, 0.14278789531559716, 0.019514396816732425, 0.013449949047137654, 0.05770692121117346, 0.03204487373060998, 0.010359743797791102, 0.017273756262335568, 0.04469503656089787, 0.03628728670939323, 0.01768948345054542, 0.03605721518397331, 0.026057086464378144, 0.08301598410452567, 0.011585839749914745, 0.023153341270142028, 0.00509378947167387, 0.023544480866422097, 0.07154449159579893, 0.02732920419094303, 0.03701446119755988, 0.02113732535602345, 0.038649771632927085, 0.04122562353469191, 0.03023567665818959, 0.02107712999737311, 0.044901171669123635, 0.03582659973612717, 0.07521982139517223, 0.03359115517307674, 0.04368105790607872, 0.029442997822057337, 0.029284298878103018, 0.01302191178359452, 0.031475568896219615, 0.05231750032473957, 0.08578320860021538, 0.06302885741235749, 0.05555027262157491, 0.018251148473110893, 0.011140895883492645, 0.02418734354808206, 0.047167788349813035, 0.0886009412727529, 0.011058077948438305, 0.01379251483857872, 0.08215814949043336, 0.023453622838602434, 0.05034435660608354, 0.039832948466702815, 0.025271107067143726, 0.060423151064183445, 0.02088731830759395, 0.021664989481289542, 0.049179194329847256, 0.06903811237744747, 0.04859336306371036, 0.04196479495975279, 0.05139973848277042, 0.07498394292328628, 0.09129236902921431, 0.04422135673643601, 0.03401379055914379, 0.048303291532060796, 0.029033799618182164, 0.009870469296020607, 0.02083785775598259, 0.06372798925205585, 0.07347108015129644, 0.02584028549702658, 0.029905709182663314, 0.03158988070584113, 0.022280422384820642, 0.02156345410302522, 0.04081817967216334, 0.06541568094924574, 0.06457669975896997, 0.04330321185050472, 0.04154667183155975, 0.015873020991773134, 0.09528066106741467, 0.06926086010231126, 0.0073537608184250855, 0.0469170592635149, 0.07699349114010412, 0.03352321849595155, 0.06809218531294216, 0.04502234379610708, 0.08436884941352953, 0.022909420790270935, 0.06873170019037302, 0.05991061142976246, 0.031786725082765185, 0.03180131905772273, 0.04054441815242171, 0.04840209389165525, 0.024276307423508937, 0.05288569241641991, 0.011183254800045924, 0.015367052476522664, 0.05593901627787179, 0.023675635119058916, 0.0284652091607812, 0.05074799301162843, 0.1288575823268583, 0.07880294485197914, 0.12863327178262896, 0.16325967987218212, 0.10494423204011495, 0.12854812877072444, 0.13063901254246313, 0.12873555984227888, 0.12878690305496418, 0.26294601300070364, 0.28552522882819176, 0.14428826319354196, 0.1873097232272548, 0.10216625933084758, 0.11628859225780734, 0.1212184599811031, 0.14900391741145044, 0.1463793308263825, 0.22478924192968877, 0.25172455626870355, 0.22644567723956802, 0.16214485340301069, 0.20616166083322418, 0.11164210045770293, 0.1704515141224669, 0.09217173837485815, 0.20978159481479278, 0.11586774185660387, 0.10110544206033792, 0.18298354811005055, 0.1379337017574618, 0.21245095157815566, 0.18039775621746817, 0.14338008128106594, 0.2373639010493794, 0.20226222733336113, 0.1000059909758068, 0.1272844667396238, 0.08397883405127833, 0.10436890000898032, 0.12464615951983199, 0.22011483388562358, 0.20199179829609012, 0.1205105487737925, 0.16091077768754575, 0.13620341557168192, 0.1253569129133417, 0.10365758737128589, 0.08497772077398916, 0.12117188183530686, 0.08131759781991282, 0.1299454884663705, 0.19912630770235293, 0.2632563092535542, 0.12939824121854, 0.18895212380636126, 0.11026546344040863, 0.06549255021156804, 0.15144773788990515, 0.08314770526222645, 0.16683654439064766, 0.096774639772071, 0.21462647274376886, 0.1584854352498247, 0.23272488626741597, 0.16324601286361295, 0.07445184123371879, 0.1269307103188288, 0.11744009901679332, 0.12988643840916697, 0.19240489740285183, 0.1483750205126501, 0.16939186130560216, 0.18102850704904527, 0.13428807318691285, 0.09644734402818066, 0.17019668263533425, 0.14416297717440513, 0.14401008134647725, 0.16407087505344423, 0.1579982186517408, 0.19660998466274432, 0.11455050729695829, 0.17238682075854272, 0.09463330911051843, 0.2506541475773819, 0.13666731245335073, 0.3515454604020042, 0.11246830330140169, 0.10638880573453442, 0.1710725509591641, 0.1782229704962623, 0.15246678804678304, 0.17323419061158934, 0.1268743875346357, 0.1503413537096593, 0.14113993293816043, 0.09394160832368559, 0.11870684072134957, 0.20601858625248556, 0.21635568640645475, 0.10359143567902428, 0.17005463461241416, 0.1672719581232917, 0.07770433646416472, 0.1640143684081493, 0.15292106286412285, 0.23763393172092978, 0.20784610431761513, 0.11927143986066503, 0.15832398988066182, 0.14038735880486428, 0.15657259031168877, 0.13446036636108352, 0.17305875647692912, 0.1228508324692807, 0.1670152727033823, 0.1484787181740807, 0.13610043803290015, 0.16334215689811016, 0.13533949821947083, 0.11831408276432946, 0.2318913672840403, 0.22821103493052147, 0.09286953722156825, 0.1563098068319021, 0.15893681425481074, 0.23090266953072242, 0.1196594097681584, 0.22586026349134986, 0.13549832356793268, 0.1889554792714696, 0.16717322471161045, 0.17784335860802283, 0.09067427397014634, 0.11380606135653873, 0.14815636369730198, 0.2832796412610239, 0.14101234865525078, 0.33810809434902284, 0.17683264348776112, 0.09511298740342741, 0.11404351796954872, 0.0915374711997086, 0.1425361435019201, 0.14340798220326825, 0.12368287290296248, 0.18933755796282523, 0.19599890696906275, 0.23340023873794466, 0.19039382467106467, 0.08303906633368424, 0.12981828722742297, 0.18068153050638017, 0.09735036250804702, 0.22644546273494923, 0.16237219765542016, 0.19353199660057024, 0.13829405419528484, 0.1672453442288022, 0.17248684119793678, 0.1323070004582405, 0.12726427266193976, 0.12877657618974486, 0.2537900672083901, 0.1446987790686469, 0.12208233136803874, 0.21495034407463767, 0.1324445898494413, 0.16402008342406443, 0.22464460452958462, 0.12266905512660743, 0.2193507684334632, 0.06795199888367807, 0.18337993732383176, 0.1902118175020141], [0.04648120503031439, 0.01975584091738828, 0.022961947608799226, 0.029383666227541627, 0.00885794429303778, 0.02684331292496814, 0.02979104497259663, 0.05686916576157655, 0.10302328189174015, 0.09573934855119837, 0.040071711259623694, 0.020283652514579798, 0.05740704375409311, 0.041203560202472636, 0.049361814369237235, 0.006060188799540723, 0.04143320271865495, 0.041077665143436005, 0.004509720686567767, 0.08680058868541833, 0.04062851162386998, 0.04234719157759701, 0.0299682755834393, 0.13793826764149053, 0.038074052727390686, 0.04658918895368134, 0.04087149556125364, 0.05898921450059261, 0.07071925402288476, 0.1366586096945309, 0.013677945431892671, 0.03234110652439056, 0.11031500634647186, 0.03818668680445802, 0.035310497792858275, 0.02565533655034679, 0.05034702259206003, 0.05959107232610545, 0.046075829605181376, 0.05392111004180005, 0.033158395935090325, 0.04161855386149499, 0.032594233465891694, 0.08369751890460331, 0.02290842487596937, 0.036238613313124064, 0.008047961445915843, 0.037074767638959234, 0.012675553856928264, 0.06057756374620142, 0.07784159643755806, 0.016673118431842136, 0.026412957287844152, 0.015387457228385875, 0.03938573698002485, 0.021161323060251532, 0.06948959863474292, 0.06864352347028833, 0.05571032754115521, 0.03639312941701182, 0.020315483467833653, 0.03064716738017817, 0.03063479697542085, 0.07576833268807781, 0.07556489037890589, 0.01929101515411129, 0.01866611914949552, 0.025676001772104252, 0.05181912565603853, 0.03645150148640237, 0.02084695505008342, 0.026654261577453826, 0.0334714692566664, 0.010895046777272177, 0.04968036904991154, 0.0343911195053689, 0.015464677933543442, 0.04553562653581462, 0.06593170245328257, 0.040300522570408163, 0.08582037918630146, 0.020397223134134567, 0.03225129420658754, 0.03151132988052503, 0.07110625099871429, 0.03141726002908282, 0.022844364603741035, 0.027990506608940424, 0.055977684565849846, 0.05579860385267004, 0.061791299827276706, 0.013169387539458132, 0.027230558879373055, 0.02285781136203197, 0.055320974844958515, 0.0533273229525695, 0.03494429244329372, 0.05224429679313495, 0.04995324573810062, 0.015515702262130237, 0.03462044792550226, 0.03382752777167386, 0.03542352257476699, 0.015549179346811388, 0.04448712412868777, 0.022795449889775728, 0.01307996879932621, 0.04418495989915344, 0.07021339084472387, 0.06602639092072364, 0.013890081881395271, 0.04274390637874604, 0.07314870269187997, 0.029297450692543102, 0.044782914506692084, 0.0067772581091811585, 0.0981262410359998, 0.046572557184845216, 0.05750555500027634, 0.036273167708948735, 0.043213579563363906, 0.019161460110016407, 0.021788341128417564, 0.018493331848613678, 0.026900357747029875, 0.013633951875230959, 0.01824043281827002, 0.02207122867055718, 0.04108710717710276, 0.01372396624872401, 0.03720127556833529, 0.01532847420387571, 0.025973153871393977, 0.009970822026051823, 0.0563643099890361, 0.030702770041722446, 0.02096844893399506, 0.025675312292972402, 0.09502902416692627, 0.06478740458166407, 0.04821933978687852, 0.05206025566064543, 0.11335847448677787, 0.043368359967585535, 0.03836931067428762, 0.05703626102918098, 0.038012681423776576, 0.021892827860410177, 0.0377116356826117, 0.024864170737864993, 0.012577755072514617, 0.033879533650413636, 0.0073237138924249, 0.02056152218081538, 0.060893490745295445, 0.020982613899715005, 0.010586288445929607, 0.022869865755520524, 0.05056119779305113, 0.040319919916650945, 0.013141208910383286, 0.06376491085956655, 0.08429601743456819, 0.06746953969160396, 0.044241305665984276, 0.026492371877294876, 0.0743673877009461, 0.033995710884130774, 0.0838488212696487, 0.019462664814425573, 0.0014068915052414543, 0.06676655442964646, 0.0449059788708485, 0.019205862566107706, 0.05626396779271384, 0.0689180970432297, 0.07002687141779931, 0.029051463690496264, 0.0034147964634617133, 0.02637077265629365, 0.011773925826644466, 0.012703700884876233, 0.05491730396545703, 0.03273189563544528, 0.0472552985734036, 0.03175428508961153, 0.025258458955513857, 0.030078423705192345, 0.06486903124999616, 0.009795792002771652, 0.010067822163804405, 0.028512595529337565, 0.06752276748058296, 0.03849306451757589, 0.02055980231342537, 0.06260291252645754, 0.046674933344606435, 0.09603433836732181, 0.021767423097645084, 0.07265718067966162, 0.06648708555486894, 0.05901985035668458, 0.02314114706560729, 0.02067820886300216, 0.0587203253000494, 0.039534212480629646, 0.03688922497413812, 0.05808721491766553, 0.08581733015636284, 0.04911165601844269, 0.03413448771161418, 0.056815551098195784, 0.05013770055806926, 0.06320150681741296, 0.06737533385955519, 0.0517595048633314, 0.033563353842304605, 0.019426369483792977, 0.05629321702966287, 0.03957815145352676, 0.03362271416511747, 0.08064042972100359, 0.022179425183323123, 0.030598984280180548, 0.06290417277224122, 0.020367196317942395, 0.08114653804730024, 0.016826866532585794, 0.023093783679688652, 0.0066768196730634145, 0.01667793329444624, 0.022075627930462364, 0.060109407415673624, 0.07755167046261412, 0.03246428580173562, 0.040084355540813944, 0.052868930412636655, 0.05159500280335065, 0.0345341366295132, 0.044686123127898866, 0.07326075071168524, 0.020371817743345615, 0.04147490854525278, 0.014381743704659805, 0.004769433111387996, 0.0204273323047786, 0.048626025222362056, 0.06360021727760473, 0.0349751619562026, 0.02666569160928409, 0.023413970127641674, 0.05239627331555371, 0.01100646852019934, 0.030405211915832855, 0.038268826751699375, 0.023573814373042797, 0.08361441368657736, 0.07380503319924878, 0.016544312238693237, 0.03369791718620447, 0.07365930795429215, 0.09259743811262232, 0.06275167531003395, 0.016945656126124725, 0.051510066635185675, 0.03449858631938696, 0.04483964331748505, 0.01387154734167721, 0.11256685285198112, 0.02768145907940644, 0.041307326811816425, 0.04868400658691122, 0.06829772670302661, 0.026070311057171034, 0.07737308770658509, 0.02279911753571322, 0.03264949904874929, 0.055712733057237444, 0.06612702423045713, 0.049528043957487236, 0.040545843075960875, 0.029174376752287633, 0.05565584336798038, 0.027784700918522094, 0.10070951249931129, 0.028031486567229997, 0.05472414638666857, 0.06598248642178313, 0.011919918244764691, 0.0527854115071316, 0.05706364484203439, 0.07987579736377924, 0.08254611173704748, 0.05406628753389082, 0.05478370206190213, 0.04135406583607678, 0.02156834748964156, 0.016968251889451377, 0.06078333496266316, 0.026528368433637005, 0.06695315046536346, 0.009716423378596383, 0.022657368287083604, 0.026789564196200624, 0.11308199335490504, 0.013449784338233933, 0.02699667989696947, 0.009411890979766125, 0.048590107190032164, 0.07105572750010798, 0.09975037807899137, 0.024022146263310028, 0.025548308321665374, 0.017671334827619217, 0.051835715290038824, 0.03893020577848919, 0.058151279020333485, 0.045658200603699496, 0.1037515480551989, 0.022324087481284817, 0.021007253202579675, 0.07044384541410594, 0.03881281046497245, 0.043884668754593986, 0.01147742969013991, 0.013414418846819431, 0.02809393805481734, 0.04228670893597507, 0.05343117766202458, 0.04428714070649398, 0.02564282633454329, 0.05382181355549444, 0.03994540251310795, 0.013688666832392976, 0.023372195353130662, 0.037122866469285185, 0.014912653169895132, 0.018455760981587153, 0.08222339719894432, 0.010220388573924861, 0.09015045369104033, 0.0013456537882091419, 0.03168873477637047, 0.07232903457817531, 0.043137039718849045, 0.04568541204676994, 0.09223941458208908, 0.03673781535678333, 0.05315467354751403, 0.03465931539634063, 0.06446259096264839, 0.06756657238809333, 0.12744211231268224, 0.13369717424915684, 0.15509640016863424, 0.09046386026086346, 0.08769539470273642, 0.1829456880448326, 0.14048995329968392, 0.0854616355331194, 0.22762634130495213, 0.12472204818961122, 0.10702753154140328, 0.12600731390017655, 0.14093433026104205, 0.2474485292670227, 0.11779683551961377, 0.16950518103136172, 0.23949583181210105, 0.13848761397023357, 0.08608672497493607, 0.2518190761968013, 0.15036819743052607, 0.21458698857215144, 0.0910465467360712, 0.27300554417794753, 0.14382177693468912, 0.1225244560308995, 0.11641239206637106, 0.09947093218685159, 0.15149557241989722, 0.25414524089184504, 0.09781970627485745, 0.08758415107525165, 0.21123158475083692, 0.15595230424115736, 0.12560727044699654, 0.11695246107035107, 0.1578340460095675, 0.1927177523893695, 0.16353436835831212, 0.23783326779882755, 0.16663299482916633, 0.20581692126729798, 0.17062464999335428, 0.175975130630597, 0.10068125917666382, 0.20704883661481643, 0.09107461619761684, 0.11606865607562566, 0.12343151179412681, 0.07533878718893375, 0.32297929808978115, 0.11177913826559821, 0.13316161750305083, 0.18573242479995375, 0.1315075264222199, 0.14185028030507027, 0.16200329567636215, 0.23295049916111657, 0.18845925347939615, 0.1451395707385194, 0.13100815966965693, 0.09311615624615262, 0.15183482679628557, 0.229476933938361, 0.1685824128048074, 0.12224255099652276, 0.13050922192633152, 0.14005190422458036, 0.13916552517442934, 0.13809816551304635, 0.17671602958392713, 0.152126093425097, 0.16173260616919688, 0.11349745815800083, 0.06726432771932694, 0.12560808250019628, 0.221713598096563, 0.16755792342366713, 0.12656766125151228, 0.15275523547203312, 0.28600115329027176, 0.32399301627470606, 0.11542246091149508, 0.1223942210837718, 0.19139379923862798, 0.17123851624708022, 0.1851382623276403, 0.19327195571555247, 0.15663997540550847, 0.28148512626367234, 0.2604610382789566, 0.1169757348214907, 0.14311783406282627, 0.11985573512051376, 0.16213012919310602, 0.17092895543863698, 0.18605346160550273, 0.1222728038086526, 0.24847576124293191, 0.1243073647961982, 0.20286449501591347, 0.2484595048571787, 0.20009453558633405, 0.11725862044841052, 0.29047725181425776, 0.11176075215541548, 0.13690683750375626, 0.12639059534957334, 0.1402091207884012, 0.3258677866430052, 0.11361315275632566, 0.14227247136014123, 0.14197902904162485, 0.1449964961577808, 0.10592298597217568, 0.24813509726476288, 0.3109894092044523, 0.11924120237029369, 0.17671443612104462, 0.17664119811548343, 0.131715580580696, 0.08340697239844069, 0.11196941918423099, 0.1102296794734655, 0.2014022783165978, 0.08091122648047824, 0.12953616768842743, 0.19672707354109134, 0.19611561280344764, 0.09104371221075136, 0.25020351933856166, 0.11985293889959013, 0.07747631805438189, 0.1442484112997209, 0.1804367041275386, 0.12287215269621342, 0.09327996116612228, 0.1364055402096241, 0.19391939194212038, 0.15563140533143477, 0.18000194923050944, 0.16774241271759235, 0.2301907133791716, 0.10802205922382493, 0.08039812377143292, 0.16738575282356433, 0.14713838606351806, 0.14641077107479497, 0.10135400694824996, 0.1405951678152046, 0.10893011856223307, 0.14981502066216162, 0.08389463332752067, 0.1102414389231032, 0.15452644607472807, 0.13228472262140245, 0.07117961923922263, 0.15764306029004438, 0.17661308268866233, 0.12687969652395095, 0.11029630614024018, 0.06641871220762692, 0.14635023480701834, 0.08049553951188441, 0.19410997929592289, 0.13352742448689478, 0.15605738086085166, 0.20535068015658087, 0.14463792104394207, 0.12579264840291393, 0.1863879202714851, 0.1050451258197427, 0.14591449931744607, 0.14684244629836854, 0.18357725092960944, 0.14208274202481394], [0.02388031082978893, 0.037380708681960265, 0.05851864499310332, 0.046386152671109286, 0.01136309298266086, 0.03911506279461807, 0.027183982648796616, 0.07306706070178941, 0.048905915445497924, 0.021534785177678834, 0.07347275788385062, 0.019607074303372253, 0.02230240719302768, 0.047282291681415616, 0.01865632471538359, 0.014856264310618563, 0.04988314869302896, 0.011659766276997906, 0.027422234078028032, 0.024597311670321132, 0.015018613663532082, 0.08578508551562987, 0.03977545356798557, 0.10878725848611324, 0.031596725701444575, 0.07024982598640266, 0.07548350885870957, 0.032642121622038466, 0.013533769599762897, 0.019954399416042913, 0.02768480305319592, 0.028138934229049953, 0.0489588521210657, 0.015951250060161036, 0.028143496282639045, 0.03446899617331163, 0.03959732280383187, 0.023653638819533012, 0.05524741508246911, 0.08504414825790352, 0.0235211075238523, 0.016912856071646658, 0.022043959770892418, 0.0798408560935528, 0.027925617046534058, 0.019087835230053436, 0.027172085303332538, 0.05554394856575997, 0.0085962007776083, 0.0404783737124695, 0.014406658799177217, 0.040931560684956854, 0.03225874441165117, 0.023131088331161488, 0.019493317907495845, 0.08849778753374854, 0.03594412911503065, 0.036392466750957315, 0.03030454221692297, 0.09255211635102188, 0.02314958743931305, 0.01933791122639612, 0.04312773941144828, 0.020211284018812642, 0.05727903812282509, 0.03334871898855894, 0.0872953512495564, 0.03646111972029171, 0.04032915510657815, 0.03462822754837332, 0.023329296344590765, 0.018497759836816022, 0.049172973695902095, 0.0555657169541284, 0.03867022235006575, 0.058127262163907296, 0.04761170182797698, 0.03339900883034833, 0.07572564626893691, 0.027873065330148227, 0.025453838189282728, 0.09596383529565028, 0.06823704487854435, 0.0378481027550034, 0.05426703321356928, 0.1148327494100217, 0.017155868737327478, 0.03174030590021322, 0.036764433081712455, 0.03147147607148415, 0.009012937286658394, 0.07483438723870824, 0.06825549993664026, 0.07452433613399345, 0.0965778777495988, 0.05110711970877263, 0.015954012764737974, 0.01647982870288674, 0.02789210644550622, 0.04817523993551732, 0.04185118795102162, 0.049262602152603294, 0.06797776242057163, 0.027161969112292416, 0.04010721177403485, 0.05271675087691796, 0.0026285441474042715, 0.03524213210649548, 0.06292648125259627, 0.09228069906032856, 0.008070676910480665, 0.12228683087854617, 0.054629385140874696, 0.08507495265333884, 0.06879391419070383, 0.05307033109749037, 0.059009232378054055, 0.06908755569208054, 0.02660499446304335, 0.018060202973203796, 0.06186675182693909, 0.019249445308120023, 0.006328005476989934, 0.03414636207444053, 0.061066032898041515, 0.013132572226646929, 0.09922670335659098, 0.05828929359033223, 0.03067535558535207, 0.06464813745790912, 0.01163358522218562, 0.0637238830207817, 0.043292839020009966, 0.06937235653881105, 0.035356999329862096, 0.030427054997773904, 0.02383742714300752, 0.04766188824789659, 0.05870607606465778, 0.06327540748902867, 0.0976997292450359, 0.09892566144586572, 0.05674789787360257, 0.02006290236397857, 0.02859295623737478, 0.09918675953221899, 0.044605055703751506, 0.0507386620607107, 0.029708537303151625, 0.07811993916308688, 0.048866412121682405, 0.03750919311818096, 0.0673770882009018, 0.05564853105874312, 0.022386849234481494, 0.022587937738506064, 0.039315253060551426, 0.05065150423756531, 0.01390172929067405, 0.03706956207151375, 0.02874420497626547, 0.07561349099682224, 0.02152339153502497, 0.02751138372977655, 0.016496171273531455, 0.11976421059619997, 0.027560752350836996, 0.012432550767346496, 0.07234097788891486, 0.07450760477372716, 0.043844433816810774, 0.0908550477376388, 0.10032341184635317, 0.04586799761220332, 0.033673873516700925, 0.0668144885510687, 0.04874192666442645, 0.008004784251698444, 0.018593965158347162, 0.08068778927648261, 0.06868234880629086, 0.030919421621928775, 0.024653532947864265, 0.0483900394981667, 0.06498481011799266, 0.04209953450387524, 0.09838098059258155, 0.013685489482727024, 0.04178036695286151, 0.05818040951365425, 0.009564191174332895, 0.04901873721410671, 0.08941399804767101, 0.06530586224530013, 0.0573515062100224, 0.02530211256065917, 0.01122235784292101, 0.07310387888743032, 0.005935225494941998, 0.06834290290792143, 0.06277135993924833, 0.06555970547901047, 0.04266623272410324, 0.034043537753243605, 0.02432326861326733, 0.0283133149928143, 0.01669568738209144, 0.03877684263692748, 0.038506003742616986, 0.035759448299124356, 0.05387342106851359, 0.06936928452623468, 0.03060624679370273, 0.036580365136145584, 0.005661460144760749, 0.0343551286946862, 0.07702836346241736, 0.03707868617869193, 0.03656688198867825, 0.013278965883317494, 0.08999317584018554, 0.008608827821820254, 0.02108715425786232, 0.01689665905770756, 0.04013274548455112, 0.0374630248294242, 0.013501116059600346, 0.04045422662109618, 0.007540695848048575, 0.01774681938601838, 0.027379517015370152, 0.07330676195241752, 0.04272304197412826, 0.016570261551908428, 0.02494550629278585, 0.05925920686774677, 0.026981068940292445, 0.035180841242113424, 0.002398446287711962, 0.011660468205058528, 0.01587179046304476, 0.05038471411793463, 0.019881080971249653, 0.07445583255180428, 0.04660963967082001, 0.06705933791254798, 0.001511658218430145, 0.05488243930402303, 0.009295475301182559, 0.00656510777433493, 0.05775365257455457, 0.0318244376760577, 0.01861075780564739, 0.09133153144390353, 0.013321691564464522, 0.0153982360854805, 0.061555222172530434, 0.03316147943898555, 0.04387198616900752, 0.0342065995679267, 0.03795371563624471, 0.13085704116571334, 0.06827559442289415, 0.03092948610203401, 0.04686687284359529, 0.017557691429711638, 0.01330618690248699, 0.08389926815946257, 0.018066651518306425, 0.0408714342742197, 0.018298197762980577, 0.06286160126628895, 0.019712493747412678, 0.057404749320759896, 0.07262753307699196, 0.11872929475841024, 0.07107599818658444, 0.0267077517515469, 0.02151655420030077, 0.046416485922471176, 0.03719541116527492, 0.045554131389625614, 0.06959324267001883, 0.04377612941748193, 0.05653609754517675, 0.05114836205217627, 0.045987848237517386, 0.03328745876769385, 0.07824013069752725, 0.03049087969796552, 0.008510537783525163, 0.02864832524210215, 0.03694328396851498, 0.05400889605704335, 0.03465118720346401, 0.03607136099749515, 0.03415467029797935, 0.040254748816932404, 0.025183962650537014, 0.03257534173767894, 0.054160910883858326, 0.037194978325597705, 0.10082961976407998, 0.0505667059652267, 0.08525681426568378, 0.04302960354834796, 0.04211018695646236, 0.048416235874737465, 0.05549467762090987, 0.038057141336462194, 0.03513039435229955, 0.014009009370760573, 0.0036905352082554133, 0.07763277619115769, 0.029283984782054063, 0.06278346029801235, 0.06144682456168437, 0.0183625242507626, 0.06393099872155056, 0.012103051563063938, 0.03933299948731738, 0.09224062500100944, 0.035039727846460964, 0.02647738719749595, 0.05788401775662938, 0.08754959284898736, 0.03230698113780349, 0.06112099970660864, 0.0169335710891192, 0.02119092086720611, 0.03743980087399964, 0.04396501605609252, 0.0431010757212437, 0.007541766934727709, 0.04002971815005426, 0.014842485261690474, 0.018671663710847497, 0.12317095763019978, 0.008297622797169514, 0.01668949739166325, 0.030547836419915965, 0.01748927211719415, 0.021466791043959318, 0.03029541810974479, 0.06784025729904253, 0.053965144775687694, 0.02826867121902685, 0.02006554919775696, 0.0761403066797122, 0.04460382996307266, 0.046864011505198096, 0.029866738289955164, 0.11920449143696217, 0.09940339387544703, 0.1610266714687309, 0.10650454629813472, 0.16199048668626817, 0.1442345757518084, 0.08000795519159687, 0.10816936260990559, 0.15176451524659512, 0.11963707064428639, 0.3261328837083232, 0.14161840081214905, 0.16116559385291993, 0.14575002024010306, 0.16391220292256725, 0.11125157181654247, 0.13360334380019095, 0.1859861990857509, 0.15952778980135918, 0.18764533102512362, 0.17669620322844676, 0.17933183680138282, 0.11771995093553297, 0.11454260893045895, 0.13790342596269425, 0.18400449816498066, 0.1372963778914944, 0.2673533168290892, 0.13073920152120053, 0.0959599205863572, 0.11112304524548593, 0.18696875281391606, 0.20018471945678035, 0.11957044397751171, 0.1546884583489549, 0.1295545384768517, 0.17600885382102383, 0.1189189091805489, 0.0860479839086052, 0.11674485124287107, 0.21136672266068, 0.15290022527258243, 0.18068199015913472, 0.14940212991449142, 0.09894492855716137, 0.1678080358091862, 0.10855787643982519, 0.15025536800103803, 0.24196923860619146, 0.22033883799468318, 0.08366009550950221, 0.1774714842078186, 0.16286226410058238, 0.12232247694966294, 0.10608080008457746, 0.1547618036068255, 0.09905562060134065, 0.25090772268031875, 0.17719065169653586, 0.20238892295427863, 0.1180167793626747, 0.13100080522558383, 0.12997538121717592, 0.08646881132717095, 0.16235664607055728, 0.1045315481361843, 0.18176543766692763, 0.30333171688741256, 0.142834902470631, 0.17060117705935435, 0.150112216811507, 0.1931667412000318, 0.14259903932050352, 0.16688102345553138, 0.11804053574920663, 0.17794854248002653, 0.12625118266911278, 0.2239537464394685, 0.14366883514148576, 0.11088771069602621, 0.14606615408293663, 0.18791243524080325, 0.1623907829484632, 0.14037087259273376, 0.13499915599822998, 0.2592869625697213, 0.15569175773810956, 0.10679066481609499, 0.11428184792279236, 0.13370215382066467, 0.1269577915269521, 0.23500891612662425, 0.2533643215053505, 0.1865473278467694, 0.16719006332418612, 0.20108931607777075, 0.3005376103664598, 0.19935280925804572, 0.10578653805198208, 0.1879861482208775, 0.1549552561294648, 0.184376786252664, 0.17513566680492895, 0.11878402407972083, 0.14623348300735797, 0.1835336452049594, 0.11434504251566627, 0.1641849302236111, 0.29129313545361646, 0.27672848634181485, 0.15746946476640242, 0.268451274042168, 0.14952496445227056, 0.19323322231010084, 0.16162645702640857, 0.14620729812210606, 0.15511811110040835, 0.18920208297429547, 0.11177196768262695, 0.12833719412165304, 0.17681119302588125, 0.09635007384443477, 0.11686510406434537, 0.16147423535585403, 0.16013246299999376, 0.1864040847266874, 0.2576310175561136, 0.0961633399128914, 0.17144626397038662, 0.18561121436857408, 0.11979337556347733, 0.1441802601179769, 0.24248843171423484, 0.145659591221521, 0.1894618480676605, 0.09580998951869626, 0.10105192315794768, 0.22320605994712925, 0.09749814852951996, 0.11493084696872581, 0.13937889598309994, 0.2043879374621376, 0.13826465174075098, 0.10124320765176129, 0.0990561492020084, 0.23197459507613416, 0.18647632681794707, 0.1513661188824523, 0.0890690056727298, 0.22072293915815894, 0.15466208960260117, 0.10116787822616678, 0.14533800283266654, 0.05772470211189601, 0.11076163560632737, 0.22093771956861022, 0.17122160102571213, 0.12107455036452702, 0.10904094084135948, 0.12906100931427172, 0.061277105442939274, 0.23375245532201183, 0.12916757214453914, 0.10061800329675598, 0.09836324565713445, 0.2950606639346769, 0.11372051231803433, 0.13613909482955933, 0.2249590529789848, 0.21928984912172442, 0.14335005063443415, 0.10720151010900737, 0.22276050321036772, 0.12603660910240105, 0.30413301421269295, 0.20981994517628225], [0.05821568403212775, 0.05773129046804482, 0.05694254932384338, 0.04069745570661561, 0.012891966034658255, 0.022684801895652088, 0.06396444995076427, 0.04826631246795578, 0.050586628081697615, 0.008830491532271188, 0.04123122363741841, 0.041126503248608885, 0.04072856653722064, 0.05992358129832053, 0.031397194271126104, 0.05076932856031964, 0.07907990095836502, 0.06016196870815851, 0.05992854554806987, 0.04132256430063037, 0.04441672830932564, 0.03582219090012293, 0.05329382575808033, 0.02965009437062808, 0.08813586461568072, 0.008269213384107478, 0.10371996991096005, 0.01754309936997391, 0.0531066321737824, 0.02629708265885711, 0.02063226848540287, 0.0618515411512025, 0.01665419797533222, 0.0070770000644599, 0.01860450269774564, 0.0634760574077166, 0.00709948426623258, 0.016136152083955465, 0.05573214955567833, 0.04770072507521799, 0.06458347963709986, 0.025400740635250846, 0.06838987175855907, 0.04888598183770815, 0.05409624157173019, 0.003426834338179399, 0.06822433547988054, 0.019287613723727486, 0.012071673559295315, 0.044470132298527226, 0.01411772586570512, 0.030878826622821154, 0.06769389620110874, 0.053262094396256635, 0.06648108708642184, 0.04568312910475558, 0.04180513840589312, 0.01554386939988622, 0.02018245229978235, 0.0057046540971514926, 0.029377016584358873, 0.07738946666640621, 0.013489487802519674, 0.09895695613757258, 0.04619717027150816, 0.051903621323647044, 0.004392976068981713, 0.02944101173911364, 0.018444147088655063, 0.0467068026022565, 0.030597794928678104, 0.03833564111001549, 0.11513350020733573, 0.011932136389547059, 0.052280322077774236, 0.040896167422855095, 0.048316261400618864, 0.04186069893260156, 0.009916508307440147, 0.023446881264868765, 0.004044650732764914, 0.031138237400521195, 0.0675484927130803, 0.05215202533309499, 0.08753912808794169, 0.07197316375470932, 0.027134188848938194, 0.06484332900013655, 0.019730546609348348, 0.04994337086475665, 0.01768808534008361, 0.01459834261632134, 0.09288722619173989, 0.02532093725617855, 0.048857360792857026, 0.07734676492550681, 0.11592206515131459, 0.019358789037552573, 0.04678112079179095, 0.037276896107341015, 0.04278832798703544, 0.032660879284864476, 0.027479238680473743, 0.008183894171980361, 0.029520889811758554, 0.046409797974892204, 0.04446534424900048, 0.013291601546018595, 0.03492438947902091, 0.050572443963779565, 0.029929731784748937, 0.17260668799281123, 0.08472914822519788, 0.019673262384810278, 0.05200628476637987, 0.03073474080602248, 0.0323149293000179, 0.026357837261692173, 0.022116927730460322, 0.03810409103490172, 0.04300363699815447, 0.02064881981500695, 0.024017078591690912, 0.057220524327168544, 0.051530747178701625, 0.033227891601141424, 0.06381992746384875, 0.051616338352041866, 0.018394261358245727, 0.01624623891867457, 0.0406053374641605, 0.02142778567729458, 0.048333134487151146, 0.011511512941891148, 0.06699559939724785, 0.016554639103912538, 0.022564983829074813, 0.02486517239782599, 0.03911633450057238, 0.015337289003054462, 0.048137012148095716, 0.014113226056759878, 0.046187540546299956, 0.06680326536297798, 0.034384366440316366, 0.03480982102994477, 0.03239759784792701, 0.061292162901091005, 0.014440626180129907, 0.018345955684180223, 0.08161631848422751, 0.00915598601192957, 0.03382471239855213, 0.022294037682454915, 0.033536858691443364, 0.037084336077133497, 0.04415590984506473, 0.07660984196850369, 0.03228104906156659, 0.03710751023684298, 0.07527720904158008, 0.024731264059101383, 0.008093266928147885, 0.049430149412083055, 0.05964314715275842, 0.07367757915128624, 0.06531465693467087, 0.07006009665107535, 0.03557224322350756, 0.003591596389249448, 0.04240958560859004, 0.016556391530039332, 0.019980293187883594, 0.0224388417066826, 0.11084895430793686, 0.049316278103018, 0.041703853921424, 0.012330578718965333, 0.03992311318495101, 0.018934686593110525, 0.019809997587975477, 0.010600425640962297, 0.026782857096423546, 0.02357328002671561, 0.059658465080804406, 0.04802933082945886, 0.05109931710326383, 0.038604909524081216, 0.030346006725824652, 0.04122589549590503, 0.04788619879212591, 0.047251364711912415, 0.05205610729453545, 0.02212883656724326, 0.04734900644830158, 0.0602195248939097, 0.05274855118665484, 0.03342327466534992, 0.046433316874167616, 0.012168664120948844, 0.12246297747497598, 0.05399965703667653, 0.004288720599781241, 0.06102560260783761, 0.0553078709110137, 0.013075407703347025, 0.004643101382234525, 0.0676724304174704, 0.06247451619034814, 0.027114393136974786, 0.011890556967456736, 0.0684832502156496, 0.052852398235230684, 0.06413464787446203, 0.04632703366599256, 0.05837154845076223, 0.020513660837745955, 0.026372731926159996, 0.030276447857519796, 0.020936796096183603, 0.04199770226654026, 0.05523947841157356, 0.03462335139873528, 0.07315775785114496, 0.029194626371346177, 0.02136849047195527, 0.015883766332521074, 0.05398091086516938, 0.07892217877651415, 0.09802902447840861, 0.03904361360436005, 0.024927294467605894, 0.06266256779312127, 0.059823737059149056, 0.022233507160337704, 0.04130104872127695, 0.03990713642129014, 0.05037129608794086, 0.04216773548133431, 0.06435293313716689, 0.02203038852331379, 0.0687694606641608, 0.048232152607412114, 0.07326501782142347, 0.07271682062456686, 0.02381954665085481, 0.026970830175184438, 0.035171253651741057, 0.07893037591730395, 0.027976422082452525, 0.00961078942993716, 0.04043466073551005, 0.018225704777925726, 0.0403356247190987, 0.050060831295746955, 0.03771270437526607, 0.050616482528106826, 0.04401232964629608, 0.04918870148098758, 0.04870779361696013, 0.01899481300384768, 0.08703753201951904, 0.07021764263270364, 0.03290516940215903, 0.021806932167120038, 0.03367242944096366, 0.04891207862284876, 0.008292244859941064, 0.1371278232263942, 0.03951847703466493, 0.032607467634783636, 0.04503908281725261, 0.13309731208268674, 0.02102236045644649, 0.0742881359051793, 0.040561762383027423, 0.11229699071977409, 0.10476634642409702, 0.021869873950978922, 0.0700009546633209, 0.02280463528398785, 0.06740016276918112, 0.01735163484549811, 0.07892483710161141, 0.02117135881205961, 0.0314870199954678, 0.024765467969700698, 0.03244676537090733, 0.0842394111978431, 0.018304609918906804, 0.02928808526766877, 0.03134457169160728, 0.04461229906507558, 0.006019193519492664, 0.0629382981588283, 0.058773350075728474, 0.028970179846510295, 0.0068943953468284065, 0.03766991453425538, 0.023612574591571768, 0.03420397954722566, 0.04176009626638505, 0.044380526824463765, 0.07440432846065491, 0.05172519178520288, 0.038379691165661624, 0.041332630695955414, 0.04956509963038468, 0.029488568562233163, 0.038427518034774455, 0.04918410112300227, 0.04352230916640932, 0.030945039602116715, 0.019273109764101046, 0.03499245639109323, 0.011600335091052037, 0.016943710262797052, 0.04847997055959798, 0.015597939885581936, 0.029666040490771976, 0.04464683813914176, 0.0419296468457868, 0.02577501289065807, 0.033198393385617, 0.014475911232312361, 0.04312391663270612, 0.030267126482701114, 0.05143114042678668, 0.017352092583032868, 0.03395246139036552, 0.05717933177947999, 0.0737512385052058, 0.05613370220206919, 0.05427521120216097, 0.07716956878862075, 0.028363003455583128, 0.06071972285187053, 0.0293441801407044, 0.026346568108326005, 0.04226567982245357, 0.02585904890551202, 0.07761346311458657, 0.11654266531789496, 0.09975947154265258, 0.03316381600715461, 0.04442183045490135, 0.036412974924690304, 0.04827588090613004, 0.04495378658776322, 0.05069897870623297, 0.05085753209348168, 0.035498036116722136, 0.17347538573366983, 0.20933179395093074, 0.09899516860323568, 0.10524995474805755, 0.10655337674242836, 0.09534626117637081, 0.27214289853169077, 0.11176396206381822, 0.3036583154912918, 0.25390056773058833, 0.13530903856360144, 0.1288508560748831, 0.12130773986779875, 0.07819807247048424, 0.15011333529987644, 0.1746004777810266, 0.13427454407417005, 0.20182696681830192, 0.19446103142634516, 0.27717269476382966, 0.14145569905879038, 0.11256141362771874, 0.1677322237481994, 0.18492475362314334, 0.23787555585224784, 0.07406154241893562, 0.20344626218561204, 0.11696379917163043, 0.15200036307496412, 0.11407082134317006, 0.11282499383894667, 0.14407083211887267, 0.16466686081501747, 0.11222494781137475, 0.1392214802364188, 0.20038852948815594, 0.10071371066113634, 0.23928866631561713, 0.1093407416896474, 0.12947068249265994, 0.11831032127262124, 0.14631933082015286, 0.13446959005969186, 0.08758477160647031, 0.1388025067506298, 0.14061278783746306, 0.15755747294714376, 0.13579467702056133, 0.0855817427978881, 0.16418246342049492, 0.08338523848402886, 0.2701852374499844, 0.16901699916249321, 0.21080559389966153, 0.105136098760751, 0.08316285082048948, 0.13326493212051932, 0.2102251444011927, 0.18560660251926991, 0.08589183220699911, 0.1934641978192714, 0.2396753874997939, 0.11713459081346951, 0.19770408079268473, 0.12021455538248825, 0.2742808967107727, 0.10801872674135432, 0.178158312675453, 0.15373227336714346, 0.14694641975145187, 0.13368554503446625, 0.187904192134738, 0.33789696051709117, 0.13356228148744953, 0.12941532497925143, 0.0863648915002423, 0.1584303841715859, 0.17178096778450475, 0.11815099030612938, 0.17726022780181902, 0.10124681592588464, 0.11235120676217542, 0.1564629018426903, 0.16708982838017328, 0.1606980044274561, 0.17260144795140914, 0.13974050480511882, 0.15982137001570196, 0.16761504293930146, 0.1118434053815661, 0.0875898507694083, 0.14412058186867546, 0.3170430359821166, 0.10648637469257079, 0.17145142740299626, 0.21744265791869935, 0.24794428008458308, 0.08157112695757421, 0.17115249989494202, 0.09727838088668163, 0.13152566738426685, 0.20358786587753605, 0.12005876374220657, 0.1904220320284367, 0.11252584416539439, 0.18053965102280342, 0.26374207028458196, 0.1973600919929243, 0.12337432333057928, 0.20160311592682717, 0.23884753756705793, 0.16462647265964941, 0.23222243984139737, 0.08737042020525664, 0.18128767459382936, 0.15885505735153155, 0.18813795620395293, 0.0971762383837373, 0.15544477099132153, 0.11922908285933158, 0.07310520421953932, 0.07869629009116082, 0.16343269316900164, 0.19722939739304204, 0.18809715436110575, 0.12118622300124939, 0.17882225043590994, 0.2027646737593797, 0.07530169321164008, 0.2027796737609371, 0.08976066049428717, 0.10206011018805927, 0.18896906967124633, 0.08465015689932531, 0.12018167488877812, 0.11301513686175309, 0.12433434641289136, 0.20671909705044764, 0.1088354837209467, 0.1352234971859763, 0.19556318680124898, 0.1318504886641618, 0.14931468863881406, 0.17789989589683472, 0.14384794649818253, 0.16225809651997783, 0.13155179098248482, 0.10874086420141882, 0.08468444699481611, 0.0890574454059524, 0.16570097226048672, 0.12836506440033837, 0.13468009569952566, 0.13650125523488368, 0.12972298588964248, 0.15200448462799673, 0.22321669324751825, 0.14877154762225767, 0.1595510941960158, 0.12066113101618907, 0.15959230972634209, 0.08210415561353007, 0.10218967863869283, 0.1246245405186088, 0.1859602287051178, 0.1409669809283749, 0.23198234788592786, 0.1913587124116959, 0.1600792045674978, 0.15081111882482806, 0.14112611271200642, 0.19383881481424456, 0.16146678898123004, 0.20996404631483942, 0.20348430611193183, 0.11956774734801824], [0.026020515342092803, 0.05866157784757595, 0.035004667832606265, 0.015455232069437063, 0.030800191527833382, 0.04016796637686991, 0.016303176488426906, 0.024947988417660518, 0.07904610882002501, 0.10330484218655095, 0.05805040822334348, 0.032814430117967634, 0.07173305647748132, 0.02319976428313361, 0.0034789656638167803, 0.03811035380368272, 0.038424580087584835, 0.04773511093169932, 0.08766220011297735, 0.09907380752866307, 0.011274434584793786, 0.01588651850338905, 0.0794783279660248, 0.02176217348014395, 0.05188915758363662, 0.016225033604930487, 0.05132546242807181, 0.033901183295153806, 0.018102425909150514, 0.010725465554353452, 0.04690373699451166, 0.01616180836853962, 0.07305060513317585, 0.09665065610240545, 0.06958514512065919, 0.028488934903796163, 0.04467386572111038, 0.02986929319318264, 0.013789426546633966, 0.02523432527067921, 0.017224439352210012, 0.008959836859796799, 0.04436610521928919, 0.03193620032811117, 0.016891022565804662, 0.0494699783232664, 0.08178064434398567, 0.039119954266014605, 0.07076752522299368, 0.016128994907522877, 0.052949890584474614, 0.019831771722003337, 0.06023747433397559, 0.03284562138780471, 0.0594962612845965, 0.0062082577947407, 0.04074561199353587, 0.013202861751309566, 0.053502010151503555, 0.07303240288409495, 0.032689324129493005, 0.05326261916648477, 0.020895802731355353, 0.048510935833497394, 0.040074342771643595, 0.04595696723328964, 0.06820885284293084, 0.04095665006447704, 0.04868507911000521, 0.05244711091020896, 0.007329799503373403, 0.05120877957632465, 0.007880291133563245, 0.10036929285213833, 0.021957343954953457, 0.06502200368671648, 0.07842362407715091, 0.06881744841173773, 0.05184512284974899, 0.04584199275761362, 0.04396637586215812, 0.08327499077084564, 0.036148663099494674, 0.051120487943051324, 0.028503691672437617, 0.06908797704043888, 0.03450741548271429, 0.030254767569262656, 0.025226608850061897, 0.034185696858912706, 0.017559861373757164, 0.067763633184856, 0.040897519568041454, 0.03928090167802669, 0.10282068994016418, 0.05413946425241809, 0.053148054547848246, 0.0503771911345182, 0.07295918020029223, 0.05153904008048196, 0.01758270994609883, 0.0289755501228595, 0.020188787846916148, 0.042886831572339426, 0.050826130149465416, 0.0546503070020868, 0.046825714769863316, 0.08046871877365536, 0.009607311390760926, 0.1107903639034879, 0.04014389972472864, 0.02910878430421074, 0.04624415061346466, 0.014591058077771338, 0.009807637637300838, 0.0067475817782143436, 0.050835258087083224, 0.03413179874299996, 0.018579706346856493, 0.06495104096229039, 0.048845773713002284, 0.04192766650850254, 0.0683957323311798, 0.008359416406751882, 0.032573415026549375, 0.030329080013137673, 0.05162982532994882, 0.046845150420502316, 0.07893387693911791, 0.03725444207028036, 0.030408132626044176, 0.01921878838461013, 0.042668703357659044, 0.033703448341017773, 0.023894180851658026, 0.06655722090433683, 0.05861975327734986, 0.03167348388101786, 0.07829901221538745, 0.02916240471325094, 0.09286398308411722, 0.032566834331279805, 0.013881081305894882, 0.009075753623619676, 0.033303385735639644, 0.04161308782415525, 0.013261996078184776, 0.03495857615264193, 0.02498729638905535, 0.07058190977981976, 0.07159664686168395, 0.035669440628900644, 0.08031553183231624, 0.05827597515176862, 0.011376681467217785, 0.005883311546753131, 0.008161521531761655, 0.01544476347795177, 0.029043029062449936, 0.10308714298110816, 0.06237424677237869, 0.03703902197641231, 0.03317777795957462, 0.06756972100946211, 0.05346141132195631, 0.06522171514769716, 0.0647603846605747, 0.024053073232813228, 0.03426954135178559, 0.01836374999144145, 0.02153444809899215, 0.04533686119342043, 0.12623750799966435, 0.020150188506851276, 0.024140416832280256, 0.03928454825654626, 0.05454203579574824, 0.02028836204009431, 0.00864114236807631, 0.014421334170976715, 0.05079489291435288, 0.0340151158912528, 0.059129420082054795, 0.01678869811697833, 0.03866272234928705, 0.08367485802380309, 0.06183247322276716, 0.03583989136161343, 0.08771594118086562, 0.06939225184220461, 0.014332284110658353, 0.05758245107567599, 0.01442029707944922, 0.0379140897383613, 0.06715123015906542, 0.028354603301493392, 0.03440487078360973, 0.04330074121694892, 0.048794020643277515, 0.053177606389527364, 0.02524812059897569, 0.06374570503530484, 0.029773852044355967, 0.05890744993643415, 0.03432489886519409, 0.017700689401657834, 0.04212572321956677, 0.0625620264139387, 0.06160180414876631, 0.048553400087140264, 0.038201522097111716, 0.035914056333563024, 0.05149067694982214, 0.01693900265250235, 0.030291681515894113, 0.043248145450507446, 0.07957533001899719, 0.014750339248548112, 0.031101664363016045, 0.03446916471265497, 0.026510698615663478, 0.04260299216595389, 0.030353472252646764, 0.08081843025021015, 0.018727423420416254, 0.052953307336616906, 0.02321366494851968, 0.04874092308924564, 0.04374152139550255, 0.07093331431068721, 0.03598948535058768, 0.024931479222892274, 0.03431926428851101, 0.03315383771194085, 0.03119066079717971, 0.019261499701608575, 0.016800875084534768, 0.05457816833269693, 0.02177634227630352, 0.03298943907382988, 0.028808567853223895, 0.03189184383729533, 0.034354316641486464, 0.06917209349452488, 0.034095267840330644, 0.06588841082468148, 0.014241999691171993, 0.02682126682972716, 0.009939092579447936, 0.052193018697923234, 0.016290773524932804, 0.05656025995830855, 0.04709676433835299, 0.04199676763927264, 0.02020759530545723, 0.02134925783461621, 0.023440459532843485, 0.06783912348891459, 0.08788204436460811, 0.025156310706910108, 0.01339578758850093, 0.02113517264895622, 0.028374628839834083, 0.030399360919311166, 0.052291273304651824, 0.025824180413638393, 0.033703839045859156, 0.052099942845562776, 0.07026212169758736, 0.00384865791044919, 0.0815612827277472, 0.04723161496522446, 0.05329705098824156, 0.01789401360456982, 0.06458451385579764, 0.03169517374537405, 0.09741462962401491, 0.0889130148495878, 0.06006762881072299, 0.04905539835172315, 0.016972720097269745, 0.012865775403746916, 0.02484985063934038, 0.11264197543383607, 0.08127085879565248, 0.017211040474414345, 0.06755953970094843, 0.01635251446597038, 0.04922289964592746, 0.0352962217443893, 0.08759528233279144, 0.04659549385729817, 0.01515572616499999, 0.044517591445436405, 0.02763298869643721, 0.05628801529265701, 0.04422583068991381, 0.011461210651172987, 0.04040702028320201, 0.03335097894793557, 0.06795982064138498, 0.027396564386905204, 0.0390415643191626, 0.08649539457814348, 0.051360602881158554, 0.07099580410267077, 0.03833403615581413, 0.045326304501823844, 0.032013567547584255, 0.012596836407488633, 0.020207857690571297, 0.009800603992546038, 0.01778786637700133, 0.047014831234851194, 0.019516164564617702, 0.04793227131989214, 0.045464399511054646, 0.04074333288196114, 0.0580940637437086, 0.01750434681232418, 0.03296446077705872, 0.019879445373531313, 0.0209264864679426, 0.04093540261589712, 0.02448925688382118, 0.08084157376640266, 0.033079285865589496, 0.06901888357054803, 0.06403065143874095, 0.06744042835048131, 0.03613155635614549, 0.03370324532771784, 0.003599432511104932, 0.0029153028275862697, 0.014073873077699495, 0.07166208609217598, 0.023507298789017146, 0.027561160292656674, 0.028876119571167137, 0.0221454338621228, 0.02926985620551052, 0.06714330114904912, 0.06305045726138257, 0.037341764602329464, 0.047656142588464484, 0.05051321770635344, 0.017980252122206074, 0.04288106293026959, 0.051356481328125925, 0.01883623663396124, 0.0638292622452061, 0.015163367892044689, 0.11001622439512324, 0.1174997466225778, 0.08756294576150757, 0.09158575772157601, 0.11748975683604518, 0.08857403626485218, 0.12539828932213207, 0.12354627942606328, 0.120908209693528, 0.14603397839011686, 0.14741341162833477, 0.09759806171660462, 0.23872675614491587, 0.16645688653713273, 0.07649730365242689, 0.1481819969992484, 0.107419898793582, 0.13148613724737399, 0.26090089532156147, 0.20259435709205367, 0.1274863309076717, 0.20750879580455445, 0.1882457447748992, 0.18757282846396972, 0.10202113929535113, 0.11315797395523518, 0.1663270346339672, 0.23443309379921806, 0.11542385519151727, 0.11359727175365533, 0.11633576795218453, 0.11900099550163555, 0.12121001003129829, 0.29347866172752074, 0.1493773546310202, 0.08216192630390007, 0.12274960161096628, 0.08269635690075737, 0.15294709453178992, 0.1122232930614583, 0.1684718050302998, 0.09044975658217747, 0.0935263580252086, 0.13251479414682235, 0.20354438272695388, 0.15121667045018367, 0.18359629587540705, 0.2740794462302039, 0.25114239073328437, 0.14027310445183708, 0.17558344519667088, 0.20716774878242325, 0.17558669340946984, 0.20564747794020563, 0.1714376531421177, 0.1689261104911566, 0.100858079930467, 0.10319441827314516, 0.10475161455331311, 0.1816112854548039, 0.1875790184543979, 0.16715280080754913, 0.11738540799987894, 0.21175136008570272, 0.08635573674954715, 0.11358695254931528, 0.12555706870531844, 0.12934597870034556, 0.1878308009115919, 0.1816531598207451, 0.11216481757019797, 0.14081368673472636, 0.14323611803833516, 0.16295491477414487, 0.13337904857772012, 0.18920836489527457, 0.17380693326553992, 0.11348991219194667, 0.0960217208992089, 0.11785165677147529, 0.11789080386440601, 0.14104843139648438, 0.15129737015212738, 0.18011295537073768, 0.1278747374852819, 0.1474921807887093, 0.17233111084468905, 0.10862192905117428, 0.13948237913991177, 0.1117089799334926, 0.11128582360763704, 0.17227544689611082, 0.11396447301752145, 0.15380584845139136, 0.20873626784211208, 0.28946619961530934, 0.13287120889271462, 0.173469869900615, 0.18978660806052147, 0.22924842523230662, 0.15037385115940727, 0.21111258065267918, 0.17939879288596494, 0.13346774623759333, 0.13149407391826953, 0.1935810262277242, 0.1328273733416873, 0.22011667249664185, 0.19120662863696777, 0.20378027652059832, 0.10946750625847809, 0.2008420382175715, 0.12315779623966064, 0.08524637248727583, 0.11761917972997313, 0.11985725963548308, 0.1557730856321512, 0.13246884419312402, 0.1280830827571692, 0.15016170609141552, 0.15969156407781188, 0.21573478746558392, 0.19401801810149225, 0.09622638128818044, 0.12560836595272826, 0.18923813507201212, 0.12687384361220946, 0.16308090559417204, 0.27205642252679796, 0.2011624008657471, 0.11570777503713486, 0.1859027261455213, 0.17925299103221587, 0.14313857972381577, 0.14290765017992066, 0.16428911818131325, 0.08494860177198726, 0.10890319057169462, 0.11845108992870777, 0.16093189107073894, 0.1697558143566693, 0.10966164059937002, 0.11598457792593588, 0.11773224664671768, 0.08886222322020801, 0.11265405664040197, 0.12335366193926144, 0.16762900106128187, 0.08585042515469175, 0.2271949418730313, 0.16472280055524843, 0.1627519321177275, 0.2581528766501335, 0.2065474014248579, 0.05347400580743148, 0.10139690787200967, 0.08802979974256409, 0.11806368692627839, 0.16867786736017273, 0.24384957077282093, 0.11374655164658062, 0.19309803843498233, 0.05785071591456091, 0.10658683946296092, 0.15163997999362408, 0.16381722334171497, 0.1488563841989925, 0.24138482077227486, 0.21258575240931205, 0.18179442643398241, 0.11413207773359553, 0.14752630234485672, 0.21328981785524279, 0.07654631029694312, 0.12177290079454262, 0.12436824580354076], [0.019668972292434306, 0.07099594199849714, 0.05367094403012626, 0.021625924742810672, 0.0715450585008629, 0.05493635274169426, 0.007447894350926002, 0.022691922682908275, 0.08096240115382018, 0.027443613676774888, 0.012825328834174622, 0.01813436602993358, 0.0660291411763718, 0.004926367659091709, 0.022491106140096823, 0.04036185940006568, 0.016435883984330203, 0.012964022349596266, 0.04954837593099764, 0.03756622453370402, 0.06051515822388953, 0.03543407926636358, 0.0771151535633591, 0.05428675614717988, 0.04048917172176223, 0.03233133890335599, 0.030278533531893647, 0.060244231229467746, 0.04477148447486182, 0.07276683850514312, 0.04643033296170254, 0.03396887482414323, 0.004989739409798096, 0.02496724595285712, 0.023573664985897563, 0.019968217726977124, 0.0737817517872299, 0.0177724871619214, 0.04133263452639503, 0.033564621717819286, 0.04133770602845377, 0.02432315944573812, 0.07233688697939919, 0.048124241462397965, 0.04474836011086741, 0.01223672145692211, 0.02681556713557051, 0.048904069173600406, 0.09086445529734896, 0.06850833193429055, 0.013687379804680185, 0.007562602132243375, 0.0182237129493226, 0.023956885148260384, 0.06724231035238312, 0.08018441588407563, 0.058146272635748314, 0.05390299206239082, 0.049832514111673644, 0.059605616505347916, 0.08596073415490889, 0.08922493520883784, 0.06994008131685757, 0.002988086207844918, 0.03239723395616297, 0.026662993064570813, 0.05264481522082802, 0.009020307052489972, 0.05446546147727678, 0.031432694785537264, 0.03245724162327186, 0.0713983909677594, 0.03557134690063615, 0.052406182662854274, 0.09136625054863193, 0.14049396760040714, 0.01971440513678376, 0.038166871940296505, 0.013441493351673408, 0.06048550296034064, 0.009850503129494047, 0.030849142630975095, 0.03320127770665192, 0.06229088874533773, 0.05334427647833383, 0.03255587927396259, 0.011071550562196683, 0.06266845900925898, 0.023031077467866486, 0.08439237597368418, 0.018157459750411012, 0.08755438855939335, 0.028608729987735712, 0.032223902732854894, 0.05495017296784828, 0.09234839825019722, 0.04129579335811638, 0.041341547959394036, 0.042603099418263284, 0.009981303066465884, 0.05555002747343914, 0.020515532007501013, 0.01902309122435268, 0.048929032148613084, 0.059027304392187833, 0.09831686669419851, 0.03601363627240062, 0.03949554419265159, 0.04480937135315711, 0.02312016391736125, 0.038347630386030486, 0.072451823150679, 0.016523170127202908, 0.06879150101374235, 0.0226349602152984, 0.031150002595818335, 0.022592442335500833, 0.024773550197301854, 0.05540789135040776, 0.06085023359065095, 0.03861658087360763, 0.036029459818476633, 0.08598760085841341, 0.03805251416539954, 0.011066747190911445, 0.09718478026409304, 0.05056512399366306, 0.04544142070376585, 0.05997013646147906, 0.017008641960039254, 0.005861208952527734, 0.07721009483981518, 0.023043645140264305, 0.008148046045173562, 0.01412252923699036, 0.04534491277750462, 0.03962582893549435, 0.02065198567335404, 0.02526254028893046, 0.0038774228361885877, 0.032939762102379914, 0.035765343345701694, 0.018300702870492975, 0.03730802609014415, 0.04872551706108836, 0.037067164216310754, 0.019858420090449434, 0.012921436479495419, 0.03478291219160442, 0.014853864540195754, 0.07338592947851266, 0.0740822114711327, 0.054544012302592884, 0.039155002788550435, 0.0228471320963675, 0.03805855093824287, 0.023381572269323855, 0.034557896846484755, 0.059322753861065836, 0.07054245625171932, 0.05184007433032797, 0.011826100244727588, 0.050058249579442125, 0.07450274011540799, 0.03526842424405679, 0.042353446685498765, 0.028870502231462352, 0.08387273853464473, 0.061155316615176786, 0.043951506095547835, 0.04209400717950156, 0.04912362231181995, 0.10040047263065655, 0.011182839197347002, 0.07888941319599267, 0.015307929640966318, 0.024786474100584467, 0.06626793844324928, 0.007290508290151916, 0.018442053753401966, 0.05245292934799387, 0.04215521377421195, 0.05051045212894679, 0.01261042680726537, 0.06457130649998304, 0.012720468634318922, 0.05763353381846702, 0.05702254422489674, 0.025066268562729803, 0.01500021318920077, 0.06590336486096345, 0.05324035282096556, 0.03671698925656177, 0.02843448903501755, 0.10320766393335597, 0.046521999212282325, 0.0327057528850292, 0.013217961344297134, 0.04216227327443419, 0.01809137892128239, 0.10458879788676578, 0.039376114915695884, 0.015405421032600347, 0.03711482637651986, 0.059389464797512184, 0.02657590610455842, 0.04631614755658854, 0.036995580960665984, 0.029087337672770507, 0.025626763385990937, 0.0615318066951248, 0.04318017429942566, 0.056103372781146923, 0.019419055259335908, 0.07818691056942748, 0.015622266050007556, 0.04355205636050913, 0.04683780363730846, 0.010476852785946142, 0.027036192796884045, 0.012464409491287605, 0.036303489468991756, 0.034183628421517155, 0.021031097689222907, 0.02559691660046097, 0.030079237673611894, 0.027227666897458896, 0.03282212930160665, 0.02923061718202887, 0.06004356598902134, 0.07052402417626112, 0.12123409583563767, 0.03373111943684278, 0.013823736751932773, 0.016887337682888876, 0.025669472787769574, 0.023991121617596478, 0.024949018805918675, 0.041879326360480446, 0.07639690016907069, 0.033728147015696576, 0.015686627011746168, 0.05131929925072098, 0.05480384634387109, 0.0868874553951525, 0.035368758779499805, 0.040183372405027194, 0.067245903304748, 0.15562696202147394, 0.028352416120469574, 0.05941108379873538, 0.05744157516728005, 0.04330407369941954, 0.043399899807428165, 0.045907876319101745, 0.119582632436387, 0.02964865029489081, 0.07349405512814561, 0.030336574268256946, 0.017931666826048208, 0.043984352115301356, 0.03966922781640484, 0.03553763520152819, 0.03540117579001573, 0.06651833428130036, 0.033698380669398655, 0.08231411733093762, 0.06324512020294225, 0.02349248839422099, 0.06500089796440256, 0.07651236494101825, 0.11994889141210627, 0.08064192359245594, 0.015463852473805028, 0.0913673920196391, 0.01438334961647108, 0.05318032217121894, 0.03829045724424143, 0.042760886717587716, 0.05711881849434107, 0.034267982362859675, 0.014206858280475342, 0.056928430323398886, 0.0725827245943008, 0.03308818780726964, 0.02083296819980587, 0.004660258400103739, 0.020112602318066265, 0.06219058868385131, 0.07105812535531099, 0.017152944196676536, 0.027489339549755378, 0.026208193477002845, 0.02135565275356414, 0.0188593169479, 0.03646708371478223, 0.04668136848317039, 0.051853637917027365, 0.005329435723157781, 0.03423236693525988, 0.026415755423987587, 0.04522318523677607, 0.04432449898412151, 0.03465057050268497, 0.036841945857891155, 0.02888598678363187, 0.019946897500044396, 0.039661869541892124, 0.0569837342106527, 0.07297246416489925, 0.01772436534895772, 0.007406318280470348, 0.048816225701762785, 0.047581494981122595, 0.06747851824207653, 0.03176802104609388, 0.026368934045275374, 0.036090176116915486, 0.03142197530025677, 0.01753221134535007, 0.06540648789415437, 0.05600001602884262, 0.042798877017752784, 0.013280075753197796, 0.01881897284258758, 0.005973275645726151, 0.07911727072731142, 0.03554624219935748, 0.05865646038024176, 0.036351883243168556, 0.02142795230141811, 0.021006289847014893, 0.013670062387151825, 0.023216047481964194, 0.032989435243390264, 0.10825586925831535, 0.07067430764436722, 0.04006688490570073, 0.02938624794384645, 0.03915814374903998, 0.01733347090081342, 0.04393462151769669, 0.04863763528485452, 0.021860560237039483, 0.02576763163350763, 0.012297662793688718, 0.023112424514106205, 0.010131110602449025, 0.04801598557781789, 0.06480295616652697, 0.022466305958768053, 0.039610985981961416, 0.11736771136882806, 0.29670067431945957, 0.16240402094779477, 0.08554706965843517, 0.16902973154379478, 0.14210282885018857, 0.0947906559092864, 0.10494749557467238, 0.21159140092711295, 0.14629837065454454, 0.15778993466688743, 0.15165291155778593, 0.1969979775528754, 0.07618491597954305, 0.13881810430076816, 0.1342162601048908, 0.1887680635216736, 0.1212174564059223, 0.14321338054874252, 0.10968767226703706, 0.08902685551513588, 0.0835944647570291, 0.1868553105140886, 0.1432157400995493, 0.10527358089964237, 0.17682219404847394, 0.1926261895606595, 0.19229657257035856, 0.17174647850615365, 0.34552119011359833, 0.1948661080771877, 0.11914745619099949, 0.1221880438407102, 0.0752643081209352, 0.0740781665268925, 0.12366246432065965, 0.19400277295179907, 0.08415813692995618, 0.16967283171271125, 0.07384612615550719, 0.1649971059974163, 0.08462601746883124, 0.1550549088466552, 0.09979444345639599, 0.11043223312064526, 0.08153085371539479, 0.10949278715997936, 0.17343107520812945, 0.20902353549195876, 0.21822596749951764, 0.13657092327071776, 0.048446274182248505, 0.36172811723043846, 0.15785790198752958, 0.22233932339135679, 0.2643706913917296, 0.0864893654661794, 0.13285587181247052, 0.2095674732399564, 0.1737549925042737, 0.14475088836925645, 0.14427850323338665, 0.21378533884642587, 0.21257603841443218, 0.16697601835814216, 0.1126574810534235, 0.14182213423473222, 0.14247928445618, 0.16714895504616922, 0.1410638604072794, 0.17623111124961607, 0.13418057572937783, 0.2114391179695245, 0.11474344654068833, 0.19125774202327575, 0.19634988249069263, 0.14100479502831736, 0.1230722931664317, 0.10369513334045488, 0.25529339218572267, 0.10293757197477164, 0.1418362149307805, 0.24978604738510427, 0.20516355552019613, 0.11195242735407046, 0.11444072689740889, 0.1726323825817916, 0.12033095478170341, 0.2604034897540846, 0.17234436416577908, 0.19786076109495856, 0.3513207821355712, 0.11591478731603393, 0.2002332434659043, 0.2132245011988186, 0.1787692677950667, 0.2075351339073912, 0.10453222229355767, 0.18675274666278593, 0.09977247205472763, 0.226243399384041, 0.08116107839610308, 0.10410434686608853, 0.1621505837406843, 0.1218532940613166, 0.15585179350549178, 0.18155131609209124, 0.135453783216015, 0.20901204417309455, 0.10589928321179845, 0.063936912920326, 0.1791117857060125, 0.13482035107670293, 0.1846148404142549, 0.16195300966501236, 0.17633369042267724, 0.12693863166796585, 0.17705287844423326, 0.15110738034690582, 0.14957662942188402, 0.17653135642890008, 0.10372252864462715, 0.18592629101007216, 0.12875094288779845, 0.14096388593316078, 0.16743095201109687, 0.13757462102559306, 0.07967769468743956, 0.09436026005254639, 0.09264152647266466, 0.08669442422087155, 0.2019374979840171, 0.16308271356167334, 0.12684964289468142, 0.13286515679811278, 0.14850709407079607, 0.21161050715994453, 0.155949485037596, 0.10358073343072208, 0.07333218074974514, 0.12433128972207347, 0.12543472446381085, 0.17025046200761873, 0.1892390084122458, 0.15446857579292791, 0.09657312800446827, 0.12231048767364795, 0.09747349582011662, 0.14742865677802794, 0.07914984478585183, 0.18200477885623134, 0.23881353858497836, 0.15979199820468504, 0.1252350359854679, 0.19964237517166525, 0.1327773018349563, 0.27368573832415766, 0.17709371093059742, 0.10500198740872646, 0.13495096906779275, 0.15685080280227048, 0.17117874606722788, 0.17017866424735517, 0.16301203428977923, 0.22969252640201201, 0.11807497140140304, 0.2819758821879664, 0.17616001829024286, 0.14067536189911828, 0.19163902398319016, 0.09900855982015211, 0.12038647317357602, 0.14927978567298383, 0.16611571694093366, 0.14397724681804258, 0.11421948836575593], [0.05600517180057303, 0.02345165399263703, 0.08191411984303305, 0.03327124451677645, 0.03310011579625068, 0.05710513999445304, 0.019183523442235687, 0.013955590059800495, 0.004016016760180074, 0.019979157462535847, 0.06298915873612128, 0.021473415789284536, 0.019501229680533853, 0.006754473696703152, 0.07260498710938039, 0.01464682257538962, 0.02712161160044132, 0.04879897340170799, 0.018536033589513074, 0.04676314836908733, 0.0362111107566424, 0.09114311211892674, 0.030290415555599238, 0.0527511022594427, 0.018816946540027857, 0.03264274598369676, 0.09237476699655095, 0.09322044379528492, 0.020264170898665345, 0.020999814488834912, 0.03953574465647821, 0.06120608526191885, 0.04801501264615406, 0.044702620831348246, 0.029218490010187514, 0.030468651656842524, 0.054979330274246396, 0.02299156648317172, 0.033348370418553396, 0.07059236687998618, 0.06454882181940541, 0.03691636363885576, 0.018652337227737712, 0.02807661680684936, 0.016142384209219488, 0.03379400376410734, 0.027862713567071387, 0.06738785939711718, 0.027472562224213636, 0.00944646740061862, 0.026151016504774173, 0.024044835872407404, 0.033805709587590355, 0.09264882729058305, 0.06622541290257247, 0.04969403988892033, 0.010291949804541806, 0.057262693636960564, 0.08926277229141805, 0.052696227381426486, 0.03191839069909146, 0.044622560812821316, 0.02497410052455962, 0.09082241239206446, 0.03539856343019394, 0.04125362021788474, 0.07047183060597989, 0.05419718897751263, 0.06425485090022126, 0.03169034739145108, 0.11425209306781331, 0.04897938327743642, 0.018044982721368154, 0.12754001834940526, 0.034694896349983836, 0.09153082155652585, 0.14287761953328887, 0.026811202349621924, 0.04235354627692892, 0.024781887149137836, 0.10332296782683942, 0.06050610306462454, 0.05280369802588417, 0.035292896922797926, 0.04619264269187566, 0.03381104538998297, 0.07559138936020675, 0.06680469028651714, 0.05922688178778176, 0.10659033282389564, 0.043065012132208196, 0.05078324071702458, 0.0526179829912801, 0.015384696439028749, 0.041920231625197396, 0.06536877338564204, 0.04152321421931829, 0.09134176637857191, 0.0900021543906581, 0.1355329813856271, 0.0335601669165396, 0.02126702021116451, 0.07260813573074919, 0.05669059449686639, 0.02060052946269993, 0.028333712083798264, 0.06229295718273329, 0.02938927207592755, 0.0352248108585275, 0.021467654808093945, 0.021584192103135492, 0.03383148844624239, 0.0242470026451854, 0.012428808427836387, 0.014045192661034244, 0.03615000758380179, 0.07409081463852236, 0.024399078759034316, 0.031699482989948125, 0.07739220926117513, 0.04024850520034952, 0.07401217571309499, 0.02385920127703538, 0.013550281667360857, 0.033507923550543287, 0.08164242676068699, 0.05519591099131973, 0.018678347827986847, 0.04462852480731184, 0.006933776575380997, 0.02744279587791572, 0.042012208141386516, 0.045469015190798434, 0.022835493305577867, 0.07594561309463556, 0.08594855335691283, 0.02907852000076204, 0.04193430082992681, 0.019353464726478826, 0.031020313486336704, 0.058410484869513786, 0.016823317630276564, 0.04152627474057578, 0.10391958944138982, 0.07422841169060239, 0.08241753153983625, 0.018928220811029597, 0.004440444791989942, 0.04744153454779618, 0.005087135040441589, 0.09684573273144423, 0.027877673349012772, 0.030809681441995408, 0.026247352061252442, 0.04234092114793678, 0.05318041027133023, 0.03461844077514064, 0.044917221211137316, 0.04262481801091664, 0.07571778620683378, 0.01511605334423122, 0.04538327463031296, 0.04476632487269179, 0.0792890812660898, 0.06256712472907479, 0.06605888070959239, 0.04240528019445558, 0.06354742615874256, 0.056132193008858355, 0.005616633467481382, 0.030236810468317523, 0.042404299601912505, 0.10326826148816656, 0.046591958361527616, 0.015056962109801751, 0.05087587223838895, 0.0317748622112577, 0.07209039818976196, 0.013868898592679011, 0.14929892254933236, 0.04949315248297588, 0.05278326646094361, 0.019145749561909228, 0.02379088730160748, 0.029455630611928723, 0.03688938968304185, 0.027321928270882177, 0.020901046603197054, 0.07207797224363012, 0.06444465684434099, 0.03538178993509181, 0.07630588892366617, 0.12596631287446908, 0.03208231436268937, 0.11037983270662446, 0.08922636779325624, 0.03863395191729069, 0.013794827466500143, 0.0430657820505721, 0.035312604534650044, 0.033962803577343305, 0.03251198626634094, 0.07189243340924864, 0.050745786678406506, 0.026013392639616807, 0.04991812826765161, 0.009171657298030633, 0.02830078370959288, 0.02018904065593116, 0.05129997085239138, 0.03243276894453072, 0.048889145780835426, 0.014095389614662817, 0.034451904751720934, 0.01199515286697856, 0.05326217100504906, 0.04046358438509126, 0.05556853615768975, 0.04206633225323693, 0.03980856771851259, 0.022650789507033846, 0.029233620246692054, 0.036989800827277285, 0.0710715701983821, 0.03937027732571287, 0.028010691110525402, 0.032871204894036055, 0.09621307434093568, 0.0748016829452207, 0.04142892028715822, 0.07596845017565836, 0.026430175113942356, 0.08372782534288783, 0.06765278026221261, 0.04655162000187463, 0.029254771934281436, 0.04787100726858743, 0.03951812846465938, 0.09138771633227026, 0.0889365337488632, 0.030607145031793948, 0.02793882248712884, 0.024429743343423453, 0.07151102121438711, 0.007613586241214146, 0.023707550341984438, 0.027934444294641578, 0.034409858015996796, 0.023642030672260353, 0.12059505593271987, 0.07759202797446521, 0.0972722904876836, 0.06650818361630363, 0.030222831278919216, 0.032573047304345716, 0.012464146148563634, 0.07714421127832706, 0.07052419271560446, 0.09066812994499361, 0.014751900152693835, 0.030126784920632362, 0.055128342036398194, 0.09892685654302759, 0.02129143351809152, 0.03607738244858, 0.02543065828391381, 0.04653759293198105, 0.11270375276405005, 0.04765942144478041, 0.03874325734232703, 0.04456618823291314, 0.033489338257500244, 0.042519630308473305, 0.026599300514546134, 0.03748165991818232, 0.07555181325803842, 0.023598666265306455, 0.03453253167531183, 0.06675658762575158, 0.023898919105469704, 0.026841273215869745, 0.09974715284883015, 0.03997001308767546, 0.08934901846993355, 0.0127792572640183, 0.00815991370473057, 0.025570151403606422, 0.04859420959086669, 0.021433372373482393, 0.043464718506701534, 0.02157883331810515, 0.08641230468187602, 0.012262003316033271, 0.025837316906319994, 0.011938214339616319, 0.038639268567485195, 0.04499638873723246, 0.032610604764833566, 0.02624821965582669, 0.03094131258436509, 0.05113562200999549, 0.017682772520328724, 0.034401136104978865, 0.01929021650745023, 0.02948432251991284, 0.07530495674619753, 0.0036292986882354825, 0.05287176110751687, 0.036669487974816756, 0.019530668524244142, 0.027506557375853582, 0.02789782146142135, 0.02014077328626187, 0.05239665635951585, 0.031762738869855964, 0.01810001847784846, 0.032505734988878814, 0.022374664606045813, 0.08007088931457651, 0.06827751730358408, 0.04960471786738885, 0.1161429895869186, 0.0967857557078523, 0.027543825638150016, 0.07172795433190561, 0.024846117875929323, 0.05715323116389975, 0.0865314619976186, 0.029588416631844257, 0.018967597730337613, 0.04797895288755817, 0.030044736903941924, 0.07507738266741076, 0.0411726638764864, 0.05745496255375686, 0.08323664807023541, 0.05268775827942356, 0.02011691347786015, 0.01813893574440191, 0.04509074395642646, 0.043311056590849356, 0.06463935042941762, 0.025324206536395416, 0.04131877216540518, 0.08387141320253573, 0.028790447958594853, 0.058094810679434776, 0.05912028448355775, 0.04834287146466875, 0.006903857969108128, 0.03469652428682293, 0.04083423687505626, 0.11155537164379513, 0.07493312831126875, 0.17065353150809967, 0.19682985189701283, 0.13786682228167213, 0.21200516501501684, 0.17812920133433036, 0.15222309547806942, 0.10825232227122593, 0.07655787822459975, 0.1673864116591792, 0.19201341115178602, 0.12895752615745992, 0.17617909387955744, 0.16492713152641253, 0.2002284324337398, 0.2212766215445534, 0.21980596255631218, 0.26607266296782806, 0.17548190790318674, 0.14372963187915666, 0.12016327345683692, 0.11779987688867316, 0.1537782233208418, 0.16326680448987793, 0.07065081938860879, 0.15569325927044117, 0.16974331180174507, 0.19625245142848263, 0.12707583035432524, 0.17884258240942033, 0.1830344776352567, 0.07095690981875505, 0.20411542466571256, 0.19684759449333916, 0.11500847465809315, 0.11344926356668435, 0.12150346001069393, 0.10520457169942318, 0.11440187091788939, 0.1473117211172658, 0.11467888065042997, 0.2327651824922331, 0.12466066156423862, 0.09192214692912756, 0.12155936910740792, 0.12695064392661856, 0.21745246384413014, 0.1063099293218505, 0.1482571655463788, 0.19474057690991511, 0.24774408598821013, 0.13442364010599353, 0.21248628355322347, 0.13102038643292843, 0.10544354516652324, 0.17627096314343715, 0.1547313745944731, 0.19850914727055258, 0.10944249348775034, 0.13078463053511036, 0.09621136596486454, 0.18625207756075168, 0.32996605060273604, 0.16285513948288657, 0.12502626936522224, 0.131298721497578, 0.2086501902029399, 0.16624530837420495, 0.11740722618396245, 0.28077664815129777, 0.12768609599480707, 0.11824624567863443, 0.3286189003096473, 0.10467174988720687, 0.2151239549200381, 0.2724902734400765, 0.22957609635927986, 0.12768392796598135, 0.13555104573888166, 0.2294784354706926, 0.19943496452704554, 0.2653770857760983, 0.1810289973453168, 0.17787446177774863, 0.21048467966818044, 0.239214263856411, 0.17913610133672916, 0.16127037935920302, 0.25286922952340496, 0.218687137108176, 0.17181628443781408, 0.11579745328955113, 0.1079186603366848, 0.16659145754191185, 0.17829020237249715, 0.11994601858239021, 0.168572177870139, 0.17505648395707532, 0.2688793946177729, 0.1765864994376898, 0.1633206145056794, 0.25691740665464635, 0.1371955300771421, 0.1346048811871198, 0.12264787279550107, 0.07947379272551307, 0.18385351755686347, 0.09290721342568437, 0.15938800939869496, 0.11279381406042846, 0.23640520329917633, 0.14978941800373216, 0.13447427851778848, 0.10646552944015111, 0.20073031195469443, 0.13450841539569441, 0.11547663098862095, 0.08427272836167006, 0.1210811693641928, 0.1598049450906054, 0.16944826069858768, 0.05698993569239975, 0.07166742572500821, 0.1483822830261723, 0.1907806071422754, 0.15993335674847328, 0.12976179590388653, 0.07197128683929482, 0.19524988748373526, 0.10593160446132384, 0.22230621307126938, 0.2213546859040376, 0.1443345349041685, 0.11717821185987805, 0.16380469014327373, 0.2564180858673588, 0.15237827424801167, 0.05923268873424781, 0.10297405308172589, 0.1379381757109396, 0.08683013669665783, 0.10780717156106427, 0.14868940767501632, 0.21817370498132324, 0.2529719772358095, 0.23001026902948657, 0.10127670101581082, 0.16241865322714852, 0.07003103127522815, 0.16151765721940226, 0.12772806229129915, 0.12829610116539464, 0.08390790963124845, 0.16380292814104788, 0.16710625330526985, 0.23155294028261017, 0.18690245556494883, 0.11600909273951285, 0.1530894796333967, 0.10812008017373663, 0.12787220939513178, 0.10930285864179173, 0.21294676368274998, 0.09753514291538347, 0.12509840420417248, 0.19032521383656612, 0.15237148670900255, 0.15397955122734272, 0.13271973798832587, 0.1380453973768219, 0.1032744438177155, 0.11832800258191363, 0.08979277490007301, 0.15670759032570547, 0.21483302536991336], [0.008705911271634602, 0.008421973231428815, 0.013267057046534554, 0.018301708360893593, 0.05601975045377209, 0.0642304816433499, 0.0813340763711641, 0.0332643075906221, 0.021361875302729108, 0.07659282715570542, 0.018910129644697713, 0.026623058816297885, 0.012271204989613786, 0.056766096292243856, 0.07240499985674698, 0.02404346074458332, 0.051213877891460736, 0.013834419848036864, 0.054599848620954065, 0.07613596296118152, 0.0036803038646241715, 0.026469349019950437, 0.10260866744624031, 0.0345568128320719, 0.01200090139924038, 0.017470087360350356, 0.09864631514515608, 0.05635284165280962, 0.006086950644760603, 0.047922197263687856, 0.0298820830310785, 0.0183653702674013, 0.0772597986243425, 0.026987816259685545, 0.03581327746712393, 0.040917031827472874, 0.026110053783462896, 0.016353631039120017, 0.00936179553278752, 0.016147467202597087, 0.03974620433103654, 0.016706060212586197, 0.07463909610505066, 0.09367031360706014, 0.03331971106930606, 0.04199334705669073, 0.02556897354342284, 0.06630617389155012, 0.029231306661160725, 0.03286590739603966, 0.02431034279476491, 0.039173442524887865, 0.0441479578524107, 0.08718355603876614, 0.05595929845566711, 0.0057243578785639865, 0.0492432929064718, 0.046453637356359156, 0.040465277439403924, 0.023403310014175314, 0.08505892609396289, 0.02936253560737016, 0.04861970116654712, 0.022436374903566415, 0.08168601716357855, 0.053948486193774216, 0.022776188524139505, 0.01217400375378108, 0.04486073754848011, 0.026330566446807598, 0.047039667805356365, 0.013626162676260838, 0.06754858464363121, 0.023192609021920833, 0.046519352378503936, 0.10768294274326294, 0.04763242450632876, 0.06433856132770739, 0.013993878176646128, 0.03541196996886884, 0.026830239634540294, 0.06909389123921433, 0.00995949445848143, 0.08104061873088922, 0.06905275997855971, 0.04662575049986763, 0.06675279549052639, 0.04032406062188168, 0.05624337151886956, 0.07559815391657815, 0.058795260190362894, 0.11933183823261531, 0.05604599279561832, 0.03540188442134569, 0.1545859251411692, 0.004374567933771159, 0.016616142557693586, 0.0707809164399101, 0.09421608996607604, 0.0861741432679757, 0.04279004785442545, 0.09051140367744431, 0.024977333415600083, 0.06277215667068958, 0.021938904218616027, 0.034883399944632285, 0.03475904472232346, 0.07610416265144464, 0.05461301767237244, 0.03918590677541591, 0.0544986637279151, 0.04646996652046519, 0.031961036898616346, 0.04061489824145552, 0.04102793837627096, 0.11940752771953422, 0.04917325714843408, 0.040873567829088825, 0.002750226919869742, 0.07010977745296494, 0.030533866806616707, 0.05269121716640169, 0.030431548103449807, 0.014330260680928348, 0.008380053857822091, 0.01323949799106847, 0.01628122423895665, 0.05934410090107591, 0.04473040300992228, 0.027476294987624692, 0.030801459403348067, 0.02910553034575236, 0.061171251244001815, 0.004442203921386071, 0.01747994882715566, 0.040265202086659214, 0.024884941296712048, 0.018892919479478753, 0.04160942592387719, 0.021166402223189513, 0.03666832735161147, 0.07718859075178063, 0.011228250016668632, 0.03364862325871664, 0.02420264806958937, 0.020734951080333804, 0.02345393693465139, 0.08774277724085316, 0.041104302020563234, 0.030220105921128587, 0.03933574591252593, 0.0799882743928221, 0.05756586527211532, 0.09077409522668009, 0.05948506874002277, 0.01791403148203127, 0.0306076736324617, 0.0910135283465347, 0.02754457640431581, 0.02541391734754847, 0.09503313805907966, 0.020501887981569576, 0.0319111856421636, 0.055114142596721656, 0.0321503812747617, 0.008998698584975736, 0.04287128764835577, 0.07523867481898877, 0.03399005332480996, 0.07316551832181793, 0.041485197106075865, 0.030009651992229686, 0.11266434520122506, 0.04184387947222398, 0.03261564179293571, 0.02922044928005386, 0.043485284137028846, 0.017621460588528745, 0.03266477484195944, 0.05475185961732942, 0.030849322661637302, 0.007760093374658497, 0.036980105984595515, 0.01747182254949885, 0.014742946500078806, 0.021053710689527855, 0.08243579507595108, 0.012464851907063878, 0.04864097925864401, 0.014808309121778416, 0.10102592979467685, 0.020172759372320388, 0.0856409996988312, 0.06089657041875105, 0.06333137021189736, 0.03137567294611326, 0.042346348880880305, 0.007852113940903257, 0.01804312304293196, 0.07193757897062648, 0.014616905884336562, 0.01577037191318889, 0.01544742467587874, 0.06480923042662683, 0.012330720445231326, 0.0444862890928503, 0.044133965256473714, 0.04835929638976532, 0.026345250437096245, 0.03227191346306955, 0.02316485365642415, 0.017739792444532918, 0.04440951559151854, 0.056285311002284295, 0.022460977817254684, 0.0409168403054918, 0.0060458356634743755, 0.013903139850064633, 0.03849256656042511, 0.12026401401887979, 0.057068865731238365, 0.03543906649875064, 0.03837485332041979, 0.08285388756062716, 0.019691615936256224, 0.02516284543690422, 0.037282921388865485, 0.05494763338637929, 0.037647050640155236, 0.022517898150028724, 0.07670564892431421, 0.04996281417627489, 0.028597232923212073, 0.10749067765690627, 0.05913278320804239, 0.013479458753980938, 0.05610203212727943, 0.03917194865343552, 0.07929342498462047, 0.03216761825305801, 0.026909259688710014, 0.0302005285442236, 0.04944480850451416, 0.043748676656715335, 0.012545994024783855, 0.05644046678958882, 0.04368971853006271, 0.009169375313626183, 0.023586020068896395, 0.059101718342712814, 0.07714157593586753, 0.04318703844722721, 0.10275928799303309, 0.14574418265012004, 0.018464069205125975, 0.045222097391923594, 0.052600841773974324, 0.010372254971204507, 0.04074513701902282, 0.04982589894244748, 0.028655635636119593, 0.01105266841008298, 0.030745452630423734, 0.0070480673175845904, 0.03633419810343654, 0.010925480577674125, 0.02793431405969445, 0.04505139001975617, 0.058974210668595574, 0.06871643971892134, 0.12872526362057657, 0.08220559331558405, 0.036548380965306874, 0.12233154743068642, 0.037195629500333345, 0.017670492130902507, 0.05732473909794804, 0.043365958281942917, 0.015355602334884387, 0.01784877802786087, 0.022667859861206625, 0.06379237128121239, 0.09888916501715299, 0.04205456131228036, 0.041432398326334455, 0.09755621799418042, 0.03761619261856522, 0.05301225397195067, 0.05600657374147446, 0.07465511500354736, 0.01410376582850492, 0.06045521184381458, 0.061479283707036134, 0.003452625885162683, 0.01616986952872286, 0.059132128202867125, 0.03567424400018589, 0.04692663536256841, 0.06776946311395976, 0.07084409571102551, 0.026377301640628327, 0.04043140486183186, 0.037850929619443995, 0.04337645751694518, 0.019509874982759356, 0.08798145959454198, 0.04762925290232224, 0.021175457382454507, 0.046626857496918216, 0.05395982429505356, 0.02230907407318873, 0.030081723628926183, 0.05608089193100891, 0.0704364143612404, 0.045956247110640815, 0.045864094394229116, 0.06431250667740261, 0.0779274212677152, 0.026630277279764417, 0.024301860286223314, 0.03872456479697459, 0.029204732986287247, 0.03332658287798686, 0.08968463392868158, 0.03017116247886612, 0.04945489022159769, 0.05636963430010984, 0.01109616400959391, 0.0610952208479566, 0.04368424483184372, 0.05015295336864168, 0.008821847187655588, 0.07067386331337114, 0.0677536127548064, 0.05328061457182612, 0.02559134331081183, 0.06482164871187941, 0.07630513049662113, 0.0835982415704958, 0.02878148856032039, 0.03963397628056907, 0.03481337184747381, 0.012193217238922034, 0.006031148800356013, 0.03030961563420152, 0.046184629412187685, 0.04139086869995921, 0.03778256393308121, 0.06079384185854466, 0.03614285615302863, 0.05930301177525713, 0.013018495989062134, 0.15041442317587717, 0.0964736438266212, 0.08145878782435771, 0.10620574136414837, 0.17131173893088297, 0.1631626012104173, 0.15020194102919873, 0.14468554106931533, 0.1323101107752131, 0.11991740519841833, 0.14816511242139727, 0.23164431925021836, 0.077487112233235, 0.16949067132607584, 0.2325941916675337, 0.057178807009251854, 0.10316624155929012, 0.1145584209852161, 0.28483574969633935, 0.11701089059633595, 0.11058997828513385, 0.1609489441879334, 0.29814864178338363, 0.1305621739236578, 0.12215875629936496, 0.19300356447216005, 0.18679926352154824, 0.23074174510134807, 0.17918942105625907, 0.1354592224402774, 0.10730588958869058, 0.12719105763901628, 0.14909967840198549, 0.08190142576612773, 0.1018543313107183, 0.09997489546696026, 0.198640730532427, 0.18815621974006777, 0.15232709957466972, 0.13845873245548818, 0.14834272224576245, 0.1555220079758475, 0.10671122915922635, 0.22555899175424732, 0.12316060778234275, 0.24850638943814465, 0.13503975865821685, 0.18680833400257174, 0.14067983585259608, 0.1705012485505112, 0.08775999889739099, 0.16436474638119822, 0.10868411240798813, 0.11769037228077651, 0.15586202844016014, 0.17879306248599486, 0.10299174971277676, 0.23137438050921888, 0.1515348880521713, 0.1922906890151001, 0.20163400459193415, 0.15395027134687672, 0.16856002771565992, 0.13790914097860937, 0.15530411724842366, 0.184120208085064, 0.15341466863549527, 0.11715152135659611, 0.13436780761807196, 0.14396953997352432, 0.11777533909245846, 0.07291255608922051, 0.28930991767875613, 0.2614521721918737, 0.19146922825565263, 0.21623268332933226, 0.19262240508631354, 0.1943503623648036, 0.17078848555684092, 0.14687115927377056, 0.11182186298913534, 0.19165235391307264, 0.10177294979052198, 0.20958930674579837, 0.1263164763428992, 0.16110818322387435, 0.14293150615788278, 0.13714640851943724, 0.18425788940681567, 0.1291020103399792, 0.17265364918256962, 0.1976011492191784, 0.10929764924390663, 0.15140886658862715, 0.24322959113745923, 0.29443722158189745, 0.227771821401773, 0.221325482632364, 0.16149501166036054, 0.15899865287205867, 0.14177120470952603, 0.2294104987935674, 0.13662667914984689, 0.15790492446432192, 0.13669775678746163, 0.18936764989649096, 0.22437495690199638, 0.19450722652817928, 0.21877053343961317, 0.21010227921989658, 0.13558447781589725, 0.18871596954282255, 0.1915736000744566, 0.17774790405265747, 0.13505944711787088, 0.18747221047599472, 0.10980178106335864, 0.16861229023385435, 0.070242800960137, 0.09487003794000035, 0.21533274452292153, 0.08213998554574867, 0.1610384998662818, 0.11780206023925736, 0.07207752791263404, 0.10673211271604223, 0.1919563682449441, 0.20342409160108338, 0.1263823752261458, 0.15613078740575623, 0.18939994816337863, 0.16096497074730937, 0.1079704555412454, 0.1177466031344187, 0.07807782730988919, 0.12841703580512157, 0.07233011476214855, 0.119959547695133, 0.16666832680423416, 0.0921028440878276, 0.13863073451624763, 0.19669132787854443, 0.08180277662411814, 0.12919660687686937, 0.09062904413909682, 0.14457018354967718, 0.09224009640034168, 0.16435740725888362, 0.09651137365689201, 0.08932508588317903, 0.11105956720008005, 0.1662880714021383, 0.20182584832993247, 0.1334220873973062, 0.15158106783224692, 0.11583639353874231, 0.12276344481975802, 0.20090311074689512, 0.1495110522955656, 0.07809945397199163, 0.16678066593745064, 0.1496251074657325, 0.24893461726605895, 0.19588670573167263, 0.19212846223625446, 0.1729981895656355, 0.11966519373198671, 0.14398018859567183, 0.10174211475156969, 0.12733196419092918, 0.10434217886218142, 0.1619256143608401, 0.20257319774358504, 0.14092562750222223, 0.18552361987531188, 0.15384586888455576], [0.04353813654292495, 0.02621852608788158, 0.030195171674413067, 0.05889234651300696, 0.02619582881790496, 0.031347812243526986, 0.02097036032336614, 0.06297925704969995, 0.038254002950364546, 0.06423569104123501, 0.1019406311153885, 0.07084833217724677, 0.017976950283252427, 0.0451260797619339, 0.006717963861451755, 0.04363782373407195, 0.03323181780175336, 0.04684139658967334, 0.010974141525014514, 0.08493589237332345, 0.04547145518083726, 0.03631398870399402, 0.02310579976878099, 0.030502319305894837, 0.06583136025696032, 0.06596492002567937, 0.030104208309503815, 0.031344146512809305, 0.019887983423447417, 0.04727304500016955, 0.017166959775251248, 0.03170173720366532, 0.03592622947067984, 0.06521922536194324, 0.008489050932468907, 0.06717779808827946, 0.07085307426149808, 0.014012952808350807, 0.06831153926830139, 0.019218939686975172, 0.10621403043548908, 0.01564456878470317, 0.011496869171218527, 0.053609714452778144, 0.03707441523851406, 0.030703557197064645, 0.080643440446546, 0.11814992544391464, 0.017811971333538814, 0.020483448245232145, 0.04030174448064739, 0.02977787400595844, 0.018815925727868756, 0.07463118241679284, 0.04052468755793187, 0.009629741487573952, 0.01589232736507491, 0.04292416303688961, 0.0873789697464916, 0.01962694470890828, 0.02323165652342141, 0.01756930149220411, 0.05791585637076248, 0.05483296917631261, 0.05567236022362786, 0.045268116293535124, 0.04900109037877091, 0.035010459457313826, 0.030085284022554278, 0.021513148939477342, 0.09647329908705528, 0.0308266464590786, 0.052353491135422266, 0.039727707138104786, 0.053123796373725905, 0.046811645565133904, 0.05048610585471315, 0.02553909419915609, 0.044207256888189626, 0.03454573137024718, 0.04579924505143877, 0.07125006102386021, 0.00954225903467065, 0.015943864972570974, 0.058980825837821736, 0.029932819119083787, 0.028717447440290166, 0.0648929868193884, 0.07245357749202559, 0.09277853363704297, 0.030815881008522648, 0.05690250590804124, 0.05831610283724243, 0.05653352732019079, 0.06087395933366591, 0.07963611143490962, 0.06581615341166336, 0.01912669695523237, 0.04873010975819442, 0.0376309551328661, 0.03430978012000842, 0.03661618357704532, 0.10536076170542549, 0.04864507399859929, 0.04985733919085995, 0.0950731814748818, 0.061294353912554445, 0.03382022312331585, 0.0153336089081882, 0.0640240898956695, 0.013622597494583218, 0.018936956128586206, 0.0569945092373077, 0.013933405111123238, 0.06866036974374326, 0.07958936474977002, 0.03339325167959736, 0.030017412462902647, 0.06042812680525165, 0.02969964876801016, 0.06474757567048073, 0.01791206455128568, 0.016841403050949017, 0.056939293450165185, 0.012998312445087059, 0.06306432345281206, 0.07002183055925755, 0.12204788039408385, 0.004470262370417796, 0.013787147435059231, 0.10611167342792596, 0.032333189005693125, 0.03163495157364636, 0.027384977307050463, 0.015745241356442775, 0.057275012330783, 0.05568957421928645, 0.049667755412238265, 0.029841941939066016, 0.01829817478034285, 0.015273290017860071, 0.07342503060616794, 0.004522438224915776, 0.03151408205139301, 0.04758969595235202, 0.03726119130489327, 0.05554040540911018, 0.01307885222617657, 0.07910882077750661, 0.04346586763858796, 0.050030754683839704, 0.028963283139971957, 0.01864408263035359, 0.026795212179422382, 0.01628893682913434, 0.050576638295165, 0.04439886313893142, 0.07038160077025814, 0.009036223486726804, 0.07626169331131444, 0.03228481055327481, 0.10032473717846217, 0.0288210608320491, 0.04922584908443594, 0.020088192841578877, 0.07056733878749995, 0.03499447886321334, 0.03846537809999239, 0.025674550035487742, 0.04880690241172429, 0.04392862304924958, 0.03923388303167397, 0.030882362118591706, 0.021964717551224658, 0.04966762900773076, 0.011833989992737772, 0.08059215852089467, 0.0166225164092236, 0.05368475659540104, 0.059769007737838456, 0.035253983486684105, 0.03391459749470796, 0.016349850395213694, 0.05746530857117427, 0.01140829408541322, 0.02077519559421607, 0.054368015093308304, 0.04424104902652964, 0.05834543634386313, 0.05516462396049211, 0.02311270605141838, 0.04477973524180632, 0.016429877855003844, 0.021898878039792184, 0.055011708980366114, 0.05012454682840936, 0.024804327779659824, 0.033125086432142604, 0.01604565507507012, 0.04024680831559724, 0.06629556357379883, 0.055119719716810414, 0.037042856246473334, 0.014437359772742757, 0.0566901310136722, 0.042979578006892435, 0.04068956500099551, 0.044322426716286334, 0.05598278288098593, 0.012317831973515212, 0.03227831029723729, 0.02269892281131639, 0.06011156395318047, 0.039278323792161486, 0.03090504023637022, 0.06517766509205103, 0.026485862045158303, 0.043074239661256154, 0.04522446843404924, 0.006414018477493477, 0.02791338836804273, 0.07051358239785319, 0.07542109567551844, 0.03756064741361526, 0.009219295517992108, 0.03617228925107949, 0.03155265840882015, 0.060122090001260085, 0.007897318395290284, 0.021278469395192883, 0.007292887471961759, 0.054579823082613374, 0.009796651936466656, 0.02681182288084059, 0.0693414219084286, 0.029619812830201084, 0.06942205266245911, 0.029624281038019448, 0.05757698120789663, 0.051402917747656186, 0.023154618721755765, 0.03577761607424867, 0.03178283527132965, 0.02424110568338825, 0.029188557039766066, 0.016188922135399717, 0.021930293390347112, 0.06239388543631762, 0.021388939273874127, 0.07973444648087025, 0.020100613042051275, 0.09995443325850273, 0.1598332290567698, 0.02367105582849153, 0.020015117629701575, 0.01898930674689191, 0.040141938539642485, 0.022030346388477954, 0.06525063496683875, 0.08859907201821766, 0.038528503744953105, 0.0628449311930566, 0.05916595098472411, 0.08200331546005704, 0.03396408677461647, 0.009593351353560726, 0.06405616599705911, 0.13621541250857616, 0.08419361446172961, 0.03928957379332954, 0.04480883892204973, 0.021878381357378057, 0.06195282563567162, 0.02385351690463722, 0.018974810448144714, 0.04379001476110951, 0.026317533375995777, 0.03325871514877485, 0.0245863527825643, 0.027943156629560456, 0.06669148547394622, 0.06284209666773677, 0.05655000970188168, 0.014557366488471389, 0.012104934224137857, 0.042747997288261695, 0.03784197022116954, 0.05642210366204382, 0.07058757116958018, 0.07750747485026237, 0.07467737751862696, 0.01652864191020208, 0.04920660112533839, 0.01706861132275193, 0.0232446302224191, 0.039506583519640474, 0.041994840928143075, 0.038033473050041545, 0.03493844336199184, 0.021959217039928324, 0.024480550294561733, 0.038247667403230746, 0.01616929879321927, 0.04535655731395368, 0.04423295147717, 0.014557627915975549, 0.05535744063015427, 0.024269441360487573, 0.03641075710014951, 0.08001727848163537, 0.0208480792841123, 0.03517990278440618, 0.09306170271649476, 0.02950904609244918, 0.041873795205667134, 0.08836260365863001, 0.037000970389213295, 0.055535035132760965, 0.018287208231706775, 0.06355370424928204, 0.05394378241391913, 0.07808283752491398, 0.04598329384480754, 0.049513641504510764, 0.09789233907095848, 0.06118840395262646, 0.09119106156210746, 0.03510650390038087, 0.02392270230507899, 0.013233135630857321, 0.05127443331143549, 0.023822716339641524, 0.0552390915371718, 0.06353971165334506, 0.04344406477626293, 0.02027027470420205, 0.03946271349465655, 0.05772034690204648, 0.08077038121559928, 0.01794590840056058, 0.009790341287190396, 0.0593231407354676, 0.05293341969410258, 0.0818539206539431, 0.05702463564493003, 0.04562759922156411, 0.025761087327414466, 0.0299384058152716, 0.021130214144866315, 0.06328535514072546, 0.01957762013790348, 0.03801157059628637, 0.13404071871792117, 0.12683453564081462, 0.1770794463734473, 0.12092754575273684, 0.10695672203456202, 0.12361983152767345, 0.057192144600013574, 0.15038045483731455, 0.1524862926453352, 0.15062734965355168, 0.17067970107159308, 0.13241878800815152, 0.12774434165969012, 0.16681311742192315, 0.10978162529007082, 0.0846956855046653, 0.14089251718213483, 0.1373694013924368, 0.10629763361066581, 0.13491150021793383, 0.14559395280816864, 0.11271094632965904, 0.11744416694367125, 0.10464442353094779, 0.17814539643304964, 0.15941998590865444, 0.18974870203002808, 0.11432944496552791, 0.1430584928922115, 0.2379546008042751, 0.15441743176310294, 0.06771581397662241, 0.16650501218053604, 0.17889896648064738, 0.23802206250688723, 0.25895824956317104, 0.13841566299238514, 0.0634705990312561, 0.16938099817883584, 0.1288922861098282, 0.21639757609415441, 0.14048960089923876, 0.15280697705043902, 0.16439460848848667, 0.13822827788610614, 0.16421555841882385, 0.33618034133988045, 0.27310942570047997, 0.10412188261867532, 0.1217007353120754, 0.15107348861713565, 0.08568823668024234, 0.19903301351493408, 0.1174357476373834, 0.21681777532062224, 0.08537061662683565, 0.1231871220854021, 0.08555428620668189, 0.24477528077700447, 0.2189334037323152, 0.17559561067290846, 0.10844150768412698, 0.23048726601466057, 0.1784145997296418, 0.20099369298306205, 0.15286328451287362, 0.12762173694828827, 0.08469764668975147, 0.07926986778094884, 0.11515361767622734, 0.11305585443492859, 0.14312754805770614, 0.10075860341349918, 0.17520683637309462, 0.11052653088324493, 0.15194751832994724, 0.2411388146180299, 0.17780546789928792, 0.14320495358157542, 0.1727940884208487, 0.18273409456014636, 0.1156226626687473, 0.12676663726808565, 0.2725839200279405, 0.2375377570429156, 0.12241587072851197, 0.13777646987188247, 0.19377898334735827, 0.2440835033813792, 0.1575762727448056, 0.1680092717851362, 0.16878346491965557, 0.18327738879428757, 0.14867684383305813, 0.2129381222109641, 0.20938839252677657, 0.21142594125722686, 0.2029861497782892, 0.14273820685282831, 0.26761210132991115, 0.10922923759226838, 0.16282218238038404, 0.18845804306047578, 0.10198536298928723, 0.11487984849560647, 0.23597426352001008, 0.13385007007708474, 0.1758590683100685, 0.16472077808312832, 0.15487630310798847, 0.09660693546456676, 0.19933764071714496, 0.2556393421705692, 0.1664733267839878, 0.2310347277671099, 0.22401088127686133, 0.16333477181052009, 0.16310839282889522, 0.12923549349990585, 0.11532856151461603, 0.1789785936594971, 0.16658925120868992, 0.16956654467409657, 0.28722474892293254, 0.11208633186235545, 0.18385308854762586, 0.18817426877156382, 0.16754344436189822, 0.10934071104613044, 0.09683438696928563, 0.24681765586137774, 0.14208148564061812, 0.1072161730318781, 0.12796614709640705, 0.1148079434830335, 0.13821684785427588, 0.14219650608156958, 0.11073362743181568, 0.15155050092406813, 0.11017051450307332, 0.07336888402219742, 0.2264027916375668, 0.09194784917898717, 0.22702955881193762, 0.22503380783863608, 0.1478097548768405, 0.17903592767975024, 0.1278773192015867, 0.3067921973284214, 0.16876636583718563, 0.16196050200491183, 0.2065624167481738, 0.08309062405098831, 0.16390581374927876, 0.13301871146165556, 0.1403476294851111, 0.10297991365434662, 0.12890915536592085, 0.1427580025647917, 0.25147001589498214, 0.1575844545638369, 0.19031779810545907, 0.15836068549223487, 0.13795305313842912, 0.09782926705215247, 0.19829148636950603, 0.1271953783749092, 0.1578628662372789, 0.10425902001800076, 0.18000302175360341, 0.14225765521968567, 0.12712603209600334, 0.14212991771919115, 0.1911590086115945, 0.08817443714266823, 0.10293554950265155], [0.01948357709953862, 0.03467629190474268, 0.031101066814435106, 0.018614084542458578, 0.014191076869235165, 0.03352238729055371, 0.0198967857736974, 0.014612649308307277, 0.09671359788626434, 0.011096241575996242, 0.012302209525519322, 0.0878003257657251, 0.048960951201978235, 0.07744077157469527, 0.020999328023002996, 0.037989468959670876, 0.04682880593463779, 0.013596354195127084, 0.07178356465432914, 0.053873436390272075, 0.02363793018664564, 0.06427476918625255, 0.024395436010954362, 0.03900962611359935, 0.04405022418547062, 0.02177413211264197, 0.07088888121107895, 0.030873500396527594, 0.06064891717546891, 0.04230477711966923, 0.027968037250121276, 0.05543272792091293, 0.055876702686110814, 0.03919953931002848, 0.040342875741302006, 0.0377047447217328, 0.06555505532531009, 0.08195031749745531, 0.020643945580588716, 0.05656953345263197, 0.053757458339415254, 0.04884493101628558, 0.019201773571811857, 0.0549485297092507, 0.09206142171376175, 0.07712601669012539, 0.018642598335000298, 0.031736619102077625, 0.022186252941948273, 0.028986687126058727, 0.09626611826881286, 0.06813864854554977, 0.01929426528213005, 0.036644333477823005, 0.05087939241240102, 0.008779207691400042, 0.03165573553903209, 0.0736757635229057, 0.047766608636706114, 0.01513495464854303, 0.03647410874104789, 0.09279842894043654, 0.024906458791285276, 0.0371810891515305, 0.058905308720685785, 0.04760592169458828, 0.011688117275855715, 0.04178754902715164, 0.010862053285593228, 0.056591267367043806, 0.06518560176294658, 0.022854475049121727, 0.08121687257962842, 0.044523080465413874, 0.061760510753599875, 0.21829493073446138, 0.09444564821258669, 0.02920231406366633, 0.04676635061661082, 0.0397246849212435, 0.08077461002094131, 0.013310338141426686, 0.010249560244471557, 0.10909711040796773, 0.06719395488260255, 0.0585242604175883, 0.04568818911549546, 0.03557154608349647, 0.13864990203611313, 0.05452234350565461, 0.03677579033518991, 0.1288223269605829, 0.09852153474404927, 0.0562930791338365, 0.14231877371428475, 0.0033635430267050623, 0.054551255663916956, 0.03091468528333691, 0.14552247680483327, 0.07002480298040376, 0.07962209968677453, 0.009001674836561566, 0.03303987447232489, 0.05942666219667562, 0.08078839194269911, 0.04740514537139286, 0.04297493168363168, 0.021926474442044576, 0.03294286858891288, 0.058892292886852264, 0.05145263302350237, 0.01754854625511554, 0.04106987019880645, 0.010652831800642514, 0.03523231468974583, 0.04648467157817176, 0.054987822358887044, 0.08346417618374671, 0.012400210365622997, 0.03171782696529502, 0.015926250695971953, 0.00945280294775242, 0.057841917394750544, 0.02449580310513416, 0.06216638796632329, 0.06624878624514227, 0.02555614157069114, 0.02361750436736451, 0.048224487897729686, 0.056158703481478084, 0.04002015737275924, 0.03831205709326652, 0.03355008519945606, 0.02081754301945048, 0.02188016634224163, 0.012840132525701438, 0.06226691402374737, 0.05515410940373137, 0.05512646512098371, 0.0330069633350978, 0.027311350511867675, 0.04639267974022416, 0.02432457670839804, 0.014808106108478483, 0.03974476025529927, 0.0372528754204752, 0.09008194244797192, 0.016534487161064343, 0.025637540327865752, 0.02787867117853415, 0.03150784226524974, 0.03782234687898909, 0.0674780662502012, 0.041179413111099315, 0.052521153308090665, 0.027217897361204512, 0.030387333338899963, 0.056144212928390315, 0.07271446873463931, 0.04742049394295581, 0.0468426606347484, 0.04268578328793088, 0.013237646931121427, 0.03798189618053936, 0.04967768008129732, 0.030217397800316254, 0.028816307256478938, 0.018647014831883774, 0.03411828878245527, 0.05870937024273219, 0.033739871991377686, 0.08297854538766608, 0.03293664029408847, 0.0623590360966421, 0.009545837622886945, 0.04668971501110543, 0.023416787415983218, 0.03870682986152749, 0.02729491984111167, 0.023551172644440687, 0.023033973280220263, 0.027579433404870575, 0.014948844121048048, 0.07609241852356542, 0.05157063354647929, 0.014458834174870244, 0.04511401004668686, 0.00418751846976398, 0.033903113836722995, 0.10573389248982554, 0.016459454594540502, 0.06087639932370475, 0.006684819067407761, 0.011990772759271486, 0.027975567894416953, 0.02271738744551136, 0.02683842336879142, 0.031270485243669925, 0.08154916321678508, 0.11987318660342887, 0.0742817467318908, 0.03803705834152718, 0.08112996756549805, 0.052398307278992674, 0.02388353031429072, 0.02517471788451076, 0.026683914925782915, 0.07226992323393784, 0.03354979408604484, 0.07352998465179436, 0.02191201453247378, 0.022821855025305864, 0.0336242042061302, 0.04118334314215087, 0.03667331841443816, 0.05890310238746386, 0.10390522529280956, 0.09616314839091032, 0.012986923590482724, 0.07835818484665887, 0.030029066575450764, 0.024347695326733015, 0.03869143532468908, 0.05011561424321225, 0.020538916841389674, 0.05438619052931186, 0.0767412260475178, 0.03494727635575879, 0.08865855874553805, 0.04894586310030953, 0.04649081177288487, 0.043553006309535236, 0.05753489616777628, 0.09237672818163711, 0.09421831162105646, 0.03042100290317209, 0.043064345635714076, 0.02935109408422103, 0.05242710069362676, 0.05999312676008671, 0.042744971240960786, 0.04862599457884508, 0.014735760595349055, 0.04699236187603205, 0.046653164956238, 0.11433244036931185, 0.02686710570067648, 0.02677676861264533, 0.07157909578733868, 0.04945445355148085, 0.034478020689059655, 0.10194441558973444, 0.06879140908319144, 0.12754011794083542, 0.0912697617745688, 0.040916219774273135, 0.01961520441146868, 0.037332720934383334, 0.07892283761212904, 0.053208127332430695, 0.026729813168546366, 0.0840382824742025, 0.05471282360714771, 0.02213522765575157, 0.03362283290874574, 0.004966688302961449, 0.04179482303199269, 0.1108722280590765, 0.10267521750422255, 0.07304819195621437, 0.11247146724452896, 0.11685950396161889, 0.035491654604312875, 0.020739469083867246, 0.024896792676900665, 0.009076746665091525, 0.09749012758895274, 0.03871578542936233, 0.05591934697041589, 0.0709867182998888, 0.011356050719416911, 0.031337100419125734, 0.0490317109131044, 0.05651315321184455, 0.044021710392928896, 0.01874689162979203, 0.02596917595984715, 0.0767553833523585, 0.06570151601467403, 0.03852920854584344, 0.04247541937436308, 0.020635173873855703, 0.02886550350775642, 0.05886835646965812, 0.045190687787028096, 0.008430822504564159, 0.042796211031776284, 0.050651695759546374, 0.06674494308930251, 0.054826717898850484, 0.05409823340033332, 0.02660068330324946, 0.013229591516597618, 0.08980129379779102, 0.0659080992843355, 0.031688315343231924, 0.08352910979620873, 0.044734290906138, 0.04339135409663281, 0.037029978308466174, 0.08017474019359197, 0.017142128950405507, 0.09032407219732001, 0.05990379324723637, 0.08979160278554886, 0.03141056825106423, 0.0661787428262253, 0.046539787773884116, 0.031038301230798808, 0.05381266263523891, 0.055926410301077756, 0.014473968241814406, 0.04749712188758197, 0.023723917810486692, 0.056628870792807116, 0.05180927376533228, 0.06335487761985391, 0.06243402078267067, 0.027416321794472398, 0.020575417100542018, 0.017424715803034844, 0.025205064542411316, 0.07312493098358955, 0.03972159375646903, 0.04612847516733793, 0.017274491706742875, 0.02007683750332123, 0.04322074248545593, 0.04787846130409068, 0.07358872827382819, 0.06137888022367993, 0.04503527919070856, 0.034315035483168985, 0.06159094868287925, 0.024550833115955035, 0.04578080148466172, 0.017997770637814558, 0.07440085808235793, 0.06548577033343815, 0.019269528303055034, 0.02976478922421173, 0.08320818790384839, 0.11380356390990558, 0.11935985406800625, 0.18168165829152833, 0.22272111096930122, 0.12916709717002609, 0.13459213348405977, 0.07513365182544916, 0.16052597172317967, 0.2659314882851416, 0.06814917459362937, 0.12461268913842018, 0.1058881979195341, 0.18369542765280894, 0.19075549478011747, 0.1220374539374344, 0.12716571545048108, 0.14131244061694992, 0.0615926034327957, 0.15561807540155229, 0.17434936948120597, 0.1154857321131614, 0.09416484634482092, 0.16210509343974053, 0.1680580409423959, 0.1822904836867125, 0.11767844429179547, 0.171869604157344, 0.1581739898650877, 0.11886184329106925, 0.08821006789202653, 0.0904439649574699, 0.21302645214863364, 0.22461114180905206, 0.13268940090652437, 0.07362045197477264, 0.06652504521151704, 0.13353179118806316, 0.25050091467076735, 0.08271848152001059, 0.12837171404352113, 0.20045153255904877, 0.28764744559603356, 0.07891415783594694, 0.19306860533693146, 0.16944692770559944, 0.15093648145275732, 0.15249180847839003, 0.14665426446064828, 0.12502289091747615, 0.16400877596630206, 0.15419641539694803, 0.11583931999461305, 0.12418851391562533, 0.21078662556265632, 0.15581813160209887, 0.12957637198269367, 0.15633046056234068, 0.16468011413610753, 0.21800680506613948, 0.160365920634039, 0.20584019501843762, 0.27232890467970605, 0.1643839445445807, 0.1999777991084322, 0.24306445322450132, 0.12902843525573132, 0.06668504267450302, 0.1721630464758604, 0.11923773199199669, 0.19846635359910228, 0.12283377935208621, 0.16613287731043755, 0.17921235772871202, 0.20287601697829463, 0.4548562780743646, 0.29211006097255215, 0.18094200040063552, 0.2512459045336131, 0.18170652550555047, 0.11022198028982648, 0.16220387281669726, 0.0769908404758861, 0.13204556529320058, 0.23892463665575753, 0.15617698250759035, 0.11994542103380927, 0.15404604765917027, 0.15554831543516728, 0.19718930035108523, 0.10783279720213144, 0.11582828066762417, 0.2366897436760126, 0.25723614519642246, 0.13081437006833094, 0.28308931437711565, 0.22765742915291942, 0.20718273346222219, 0.27971972260744343, 0.20477259020891883, 0.13762905923349245, 0.17535384864576403, 0.1788241962992376, 0.08596284855757991, 0.2593108951564758, 0.17943688277756015, 0.1605211300474982, 0.27378202025448123, 0.22125877169591768, 0.10573560086589669, 0.13727993764463933, 0.0847187370903069, 0.12751431609954567, 0.18929264988870392, 0.21577214191277183, 0.18362228157779864, 0.08164045025384234, 0.19327541843297022, 0.2503140198607599, 0.11010360438376667, 0.10198298045584273, 0.1443503009936502, 0.11625562749442556, 0.18328181678248992, 0.11897896281293324, 0.12276481611714249, 0.20867571625257694, 0.13398260328798525, 0.22734374679144354, 0.13526223059142792, 0.09925203022336769, 0.13140805756613133, 0.13051922703462263, 0.11792562256056456, 0.15724124717375926, 0.12675221183247146, 0.14382212933513427, 0.2756722655988509, 0.2455010877982263, 0.1579365485738362, 0.23203795054747214, 0.20857877548663847, 0.159872958376523, 0.11527048438907632, 0.08985435304742667, 0.10479312885792987, 0.11191418424489037, 0.1347805757916743, 0.05979718062125387, 0.11100974084148485, 0.13841065277736034, 0.19474428477546862, 0.11373604858113874, 0.14238945298617886, 0.15944177344922097, 0.21336172286781574, 0.12178878179721295, 0.2535308843418475, 0.18554598964270086, 0.217536733515801, 0.0697126834382934, 0.08839517771717041, 0.12860625952241883, 0.1286916783259761, 0.14562171583454456, 0.13609893650056856, 0.14168273687603014, 0.14143104634938702, 0.12732160668219292, 0.15660475068275007, 0.1608510075076934, 0.16246325486610014, 0.2714914480043996, 0.16245671247522678, 0.16696794379142024, 0.123095398378228, 0.1264719155827357], [0.05447331004806104, 0.07323979820695616, 0.07419557716216772, 0.03283275494111642, 0.040713329048406695, 0.028036142466589812, 0.08934324216698447, 0.02589466816355144, 0.0730836158618331, 0.06986869724407312, 0.05532608465141347, 0.037714960504203074, 0.09285729513653825, 0.048803956803655436, 0.10521856812579979, 0.0821033358994511, 0.01120170602770222, 0.05257447302762059, 0.05390378879383207, 0.018883138451905503, 0.01732973239174293, 0.026829552070628253, 0.05464982819713412, 0.04235094157798637, 0.05117550837777315, 0.02738227301667775, 0.02952423953120747, 0.023039188423764803, 0.03784971537008401, 0.07572835822018885, 0.007760052676237519, 0.040536086946245165, 0.004628950780663159, 0.008673146648723032, 0.022039336430269386, 0.062041236012573206, 0.08582330564217222, 0.030684713349347154, 0.03663102653057825, 0.02899182949125046, 0.0306915583449506, 0.01571796862633839, 0.060280585931914474, 0.05189443975987454, 0.01043608445944565, 0.03294607849731561, 0.04423493564489388, 0.04278299984552207, 0.04048255272209644, 0.031941298643247254, 0.028595457514447552, 0.015048896161568983, 0.0032140910033992827, 0.03493414560873662, 0.037927902303636074, 0.035534635967304634, 0.034741325108634855, 0.06741278023729402, 0.013819873753574588, 0.011252236229577854, 0.09007058136405484, 0.05031855859523339, 0.06359422263959724, 0.1194725609234264, 0.008505989136474748, 0.023474176977610877, 0.02659570947740107, 0.03355525246250533, 0.045739612767412785, 0.05546934692369354, 0.09969112117804828, 0.11040533577362377, 0.02180998694271811, 0.028783338662657528, 0.04727245511246785, 0.1305420717765247, 0.11360988922176823, 0.04350461636579806, 0.04188488815881072, 0.02678163327096451, 0.08495509819758516, 0.015958462777968137, 0.03254667089711274, 0.07473045975090035, 0.04479490378270707, 0.04178069637066895, 0.04396315446243652, 0.10760688553414038, 0.052095982170994246, 0.059121694085338426, 0.05072648509315426, 0.03833802747389963, 0.1585514413853807, 0.04066765871680072, 0.05004759712685501, 0.06714245845233241, 0.06043850729662565, 0.09774855968932952, 0.03199468156503093, 0.10769046572667938, 0.0724592158991483, 0.11769168995200627, 0.06341706097666776, 0.049869244197203275, 0.03155215087557032, 0.008338985799421227, 0.030621064849378123, 0.07416386878298176, 0.08741889058822587, 0.010295987087902764, 0.02291636729252435, 0.05016599601555256, 0.04666141955362213, 0.027535837256319584, 0.10940253434161987, 0.0820269875769173, 0.037945074164458824, 0.04621909953834069, 0.03031313963865321, 0.010054968166044884, 0.0411134414494999, 0.1146070828901664, 0.008708947852644469, 0.05000067424149283, 0.061635477543478055, 0.019507597786404436, 0.027665223761071122, 0.06892946578802601, 0.026189401340220245, 0.05607649841676316, 0.06685335985234668, 0.005756721262925215, 0.03656579414382577, 0.05027709025589209, 0.014968619723203442, 0.014922731056539042, 0.037482023809946356, 0.022905128782675154, 0.04504300518742493, 0.045547340020176866, 0.06884534933394001, 0.07416526306300394, 0.08793778492197876, 0.021238083155044628, 0.04496694414786274, 0.034670676480257706, 0.04377343661842808, 0.06616723618560261, 0.06142808988149609, 0.039422172121703625, 0.04463556132489636, 0.03492967931613807, 0.0046357311375979935, 0.04984796227466676, 0.009569986629480077, 0.04946874875214793, 0.02657871381680091, 0.07547855993071872, 0.03623304768435417, 0.06380929416345973, 0.08048357321850716, 0.0693480792124906, 0.014263556447751341, 0.018865855508333734, 0.035052705375898274, 0.04412240882013594, 0.01985324516652092, 0.017999048089428295, 0.03246467267613738, 0.017484114430243933, 0.02322936592052781, 0.015090284061678236, 0.04559170800231157, 0.06049250883440818, 0.05939116551270408, 0.021680707690275965, 0.039153918774137576, 0.079822278461389, 0.038979790819388245, 0.021306337758658395, 0.045148828742845405, 0.04742134430055176, 0.04335144857665704, 0.04502568010901732, 0.020915263279851888, 0.05496549472633389, 0.02819240333572511, 0.04598040186289338, 0.03389040060761956, 0.06922263231488966, 0.026264228978224342, 0.0335827894929436, 0.00488613655174812, 0.029695075223102208, 0.01107168271236362, 0.04715538155587931, 0.017882382474659432, 0.029436652698824485, 0.007416508686278136, 0.05375918203724488, 0.02857095419218944, 0.025848658838038965, 0.04813644907347137, 0.03996239434326849, 0.04760757644450472, 0.05615548974263573, 0.039845248008327144, 0.06877311490355961, 0.04449803705116914, 0.07908999799720703, 0.03691657814347456, 0.04820689085810896, 0.03973559784372488, 0.03533960913398093, 0.05322634107283047, 0.006779947077795383, 0.05544650601223112, 0.018674766366940834, 0.012990198616359024, 0.04853548129059134, 0.034458742086445136, 0.06713808409028477, 0.0923003951808618, 0.08781622975103318, 0.011457672282572717, 0.019956902608335502, 0.022253609307470824, 0.09261685844150283, 0.04999147352552222, 0.023095919149777582, 0.09840001021662066, 0.07886937999677274, 0.023410855980229475, 0.009406212353027396, 0.02791226987967328, 0.09251070929871452, 0.05670313152574724, 0.018029036601224256, 0.02915628750117556, 0.022671443237472447, 0.03483335908141828, 0.05107444222836245, 0.05511563263773438, 0.05725464205287638, 0.08240780222319788, 0.0531160282421737, 0.08754590030519233, 0.016460699487417456, 0.062214724283905766, 0.009850909156093915, 0.06033211300570158, 0.09450796180434766, 0.09161077049230376, 0.07525351394208209, 0.09925367731240489, 0.057564968949243914, 0.057484568021590673, 0.020008004503324628, 0.050923143693756674, 0.06608542565616869, 0.05852672722070448, 0.12449292661321741, 0.03854895446209177, 0.07261844727421, 0.019301085379875956, 0.055991255813428474, 0.04444007483881809, 0.07061703491114801, 0.06425537950088901, 0.06730391914325376, 0.06468306340637707, 0.09100687104247271, 0.04785215767521051, 0.0285481094502874, 0.0566279553177376, 0.09036763961757384, 0.1643743531237687, 0.06139335928544883, 0.05124151451332916, 0.08833241979441336, 0.014802962785676844, 0.05355043456919732, 0.0504875461000108, 0.10576887206444818, 0.10290442335028803, 0.023786177776092966, 0.005789927822808105, 0.0027953552442692943, 0.11178780272002183, 0.05120243636831161, 0.009605196030480007, 0.060001902297259345, 0.01604147989588279, 0.029865435940483888, 0.0639654956607809, 0.029159246515783093, 0.022773662349209193, 0.0657231503376557, 0.09800883806160382, 0.03741759964595399, 0.029797386265389865, 0.040990779281503735, 0.0528906298530919, 0.03427930514238054, 0.06515776978865748, 0.05867716773683506, 0.0580626541388131, 0.030543082844345804, 0.018816140232487552, 0.0381195315370156, 0.027256069607251597, 0.018733674697878382, 0.04060379762743269, 0.0460290867504814, 0.03827022486216119, 0.0102989824916867, 0.039223215257328366, 0.04775763008623354, 0.08862876558616277, 0.02878003299326426, 0.06802398816592271, 0.03047615357284104, 0.060733481790990605, 0.028292741701607744, 0.05992450826470891, 0.020002505907248107, 0.07867546782137887, 0.025509689829402396, 0.04572520648399669, 0.000930114471092595, 0.06113641722608478, 0.01859485956599876, 0.09364777530032782, 0.024258599301139196, 0.008836712166216345, 0.03400296573677371, 0.03717108021279977, 0.03906530538393606, 0.013623511054432921, 0.0070847758568913476, 0.04862266209637446, 0.04007267269996866, 0.024078662484704007, 0.023758583289060383, 0.006300828029071131, 0.045624469752393426, 0.011290626810683359, 0.03558880987487013, 0.011464331501854524, 0.07546267126716914, 0.05555400730020577, 0.023018030990515987, 0.1738779496161207, 0.21878271423760923, 0.14344374318757366, 0.1441756635904312, 0.23137096375707658, 0.16031339764595032, 0.17601413982770137, 0.1607450575477654, 0.13562460550137106, 0.18891889091220596, 0.11992863604738829, 0.18516449317816766, 0.1929781763183494, 0.10793759036929378, 0.15387010790648, 0.23968261936979912, 0.13675205709953464, 0.1504465222599045, 0.10352112412933381, 0.10699012346806065, 0.11303223594422303, 0.2257100949364324, 0.13313923241390338, 0.1436048974433253, 0.12663749782668968, 0.10021776832159489, 0.11837796683633521, 0.08135779445329983, 0.08786802495559377, 0.24573160365464228, 0.11166335173672247, 0.2017416246235371, 0.13811610729223298, 0.14429348791318555, 0.1332830424390493, 0.08681971790088762, 0.26942959896499113, 0.09997035256556927, 0.11227588499746016, 0.13890117887527714, 0.07773145597668425, 0.1190801630277307, 0.154941221398692, 0.13284965117852535, 0.055594426099090814, 0.1436478136888435, 0.19198391676670123, 0.22405796504068762, 0.13084599417784523, 0.18938788993945047, 0.076143171848549, 0.16347082902587232, 0.06164968847447346, 0.09458014260857336, 0.13078631592854378, 0.11011790724531298, 0.14150285943140908, 0.1703172495528575, 0.17786831775259587, 0.24324194047479863, 0.11864695562830857, 0.12995961512769424, 0.22970672967212818, 0.1492031768805558, 0.10208650191705074, 0.1855087577695808, 0.11604204218113616, 0.08959605118199702, 0.1926552396147482, 0.1945207096756466, 0.25507292740287324, 0.2602004151671164, 0.08148235268890858, 0.09553331686484237, 0.22323206097127932, 0.18235578502137817, 0.2333822816369995, 0.17960692365323344, 0.235583619965661, 0.17751436980981983, 0.1856793502285596, 0.10549389246490695, 0.16568751975653634, 0.28365189870519025, 0.21741463442242917, 0.24114846732587586, 0.13884068857277596, 0.1556859814351605, 0.2889721341911824, 0.11069284857160623, 0.08063347364265112, 0.17948556000426893, 0.26028869913951047, 0.12421559512374863, 0.2988650872101707, 0.2740783430635929, 0.2113118707653015, 0.17178021701833895, 0.2596430095934099, 0.22424564126037785, 0.25832346910911225, 0.26538983347915834, 0.27409335838690885, 0.10661349932272589, 0.15888305020428475, 0.13611022863657246, 0.14413866154368848, 0.25038250812119056, 0.3751060655040126, 0.17357796490673097, 0.19115294119523418, 0.16921017589347978, 0.16944931789992318, 0.180328210755702, 0.17949024846236553, 0.1913925888197076, 0.13387824679093976, 0.10911934227953035, 0.19478608253261737, 0.10268265621796732, 0.1798047888423166, 0.2207542874760205, 0.17316873605933883, 0.11211898252968827, 0.2948626148844919, 0.14094888593160337, 0.173831892410113, 0.07710671127443353, 0.1548896790031464, 0.12985452318624144, 0.250492763495253, 0.22933009020503492, 0.10470165795977078, 0.12549624132413056, 0.1052916988790516, 0.10448567479127839, 0.2507597451368647, 0.13993896754278293, 0.09461103127368035, 0.09907353939788957, 0.1441671753362302, 0.10637087927710627, 0.1783868060597489, 0.16024098701534734, 0.2374640900281168, 0.14589887112379074, 0.2300590075432293, 0.1753463409841061, 0.1754142623394728, 0.08684214129443131, 0.12678888446140674, 0.10765557808260764, 0.11836329625258524, 0.15065099112689495, 0.20317710485429535, 0.09283962914900434, 0.17729802658000302, 0.10593683684184667, 0.147531864143187, 0.16818533411189435, 0.1873037937067209, 0.15289319258543754, 0.11804147037647425, 0.08533203643896888, 0.126202221989872, 0.1071920106187463, 0.0995911313821712, 0.056968140490953965, 0.09345920275776617, 0.16812813798746756, 0.15850169163557792, 0.10569279953356712, 0.06480088772913141, 0.13031926276462694, 0.14873238520756846, 0.08750880632789866], [0.015436810527687833, 0.03718176330890387, 0.005511243709348022, 0.01505993644616777, 0.03748165225730308, 0.03801623990218486, 0.07139829903720848, 0.02928696103363989, 0.03433768870308995, 0.018954196937322136, 0.050864901859313257, 0.02457081268902027, 0.019764627945879777, 0.05240621330637125, 0.02189750099674829, 0.022598417821310224, 0.060427969757227175, 0.008657434185396039, 0.128244336604351, 0.04394549613578185, 0.05304251444495974, 0.03576754967892363, 0.06286085433056278, 0.05997077614489583, 0.06514817070696624, 0.04170775330895859, 0.0680822951178397, 0.06025842300826504, 0.012985007413062117, 0.004908551805607614, 0.026152000927756873, 0.06414692443344863, 0.05065900040790439, 0.11079843080933056, 0.016456214042620796, 0.04071337118324253, 0.02798306597997585, 0.026717697488023873, 0.036462981313947714, 0.03141799355827032, 0.0927267077889654, 0.038757866639043057, 0.0588745464600863, 0.013848910401124629, 0.06458305062786227, 0.05445675105757771, 0.023007014646164836, 0.07232217043037377, 0.02417554770926795, 0.04051223479872269, 0.039085660340084184, 0.04462479778956022, 0.06807842637382208, 0.018644262661015796, 0.04789853280770683, 0.03943657840511972, 0.03480475718876527, 0.09810802346516041, 0.046046875312083194, 0.04180358324740683, 0.03233473267286055, 0.04600962045632544, 0.008437647390359593, 0.1148066564553207, 0.07438008177785144, 0.01653776027172083, 0.01810230141986282, 0.06846405205226715, 0.05321733187884093, 0.02374196875720255, 0.046334365127427925, 0.04253515508025885, 0.09453085251152517, 0.10496441079604049, 0.14932061815934797, 0.18875461101772326, 0.07079689703401058, 0.05683021019062689, 0.0052791904102289875, 0.036357728494030815, 0.02360838217540614, 0.02738745560148551, 0.05214491220671804, 0.03663494890075057, 0.07081088579950795, 0.01298411492063033, 0.024369191753888325, 0.004283558603586449, 0.08393771811238221, 0.03817005120518227, 0.09084665907486793, 0.08813623233788437, 0.08131866268212758, 0.09898485705977488, 0.15934287149819637, 0.06828731556813564, 0.13397976876266543, 0.0325761039951636, 0.05460035806942371, 0.030762415732287114, 0.09567124333472983, 0.03186586005012355, 0.01189022659203939, 0.04992887648122926, 0.08918535144579026, 0.060307525413771795, 0.0425340902180441, 0.02725642966857601, 0.02053055690691596, 0.1370654483475993, 0.07676590940043812, 0.10713754176732995, 0.08592758553042527, 0.03931580081341728, 0.03553574679479484, 0.027335773394893736, 0.03688900663907971, 0.028086495510632956, 0.04721943799766803, 0.08559189346288482, 0.05744553584184858, 0.06680108201239379, 0.02188559982084459, 0.05260820770936628, 0.04111892280859813, 0.029489834522528034, 0.050586199072460016, 0.00868745525592878, 0.014844569978454422, 0.04724170434318724, 0.03849834286337418, 0.02845554687683621, 0.00900289100114136, 0.030012511415407065, 0.02479511365715054, 0.043757459854767214, 0.0520131450837418, 0.03579208747513833, 0.05481794236167785, 0.03889262916580324, 0.07084680000139822, 0.06372800074337472, 0.040388228146419416, 0.013661201622697615, 0.019632801451089404, 0.04407990243165724, 0.07654123879488438, 0.052087122364149946, 0.025260378005764177, 0.01859078972390102, 0.04543574399224693, 0.10877206696257477, 0.07537716053306096, 0.024897587493122108, 0.04130998130647406, 0.06920467521394454, 0.020116045883285905, 0.01791778148242062, 0.0658845114371469, 0.05204154013265526, 0.02450675816245137, 0.026649259023308277, 0.008474362154130735, 0.06499941175382945, 0.011803744841487178, 0.015583413900927672, 0.0332613198477174, 0.050079814954510624, 0.05454970050543066, 0.027734886051245758, 0.049472606004846674, 0.039517507933440714, 0.03975012287076923, 0.03759572274922844, 0.0707681917194878, 0.04585913014447978, 0.043915082445187915, 0.0566149624665418, 0.06921101076107833, 0.010787014973409956, 0.050073563677048495, 0.05985971637851289, 0.0832308104802524, 0.0421566540195096, 0.03968115197494626, 0.005120253979018139, 0.005975367065759437, 0.024211377641486547, 0.09111190169689157, 0.025960228052891554, 0.06218965022614407, 0.039663650696316076, 0.01739109986491742, 0.02290618215357104, 0.030072775721970587, 0.04931396451748667, 0.07183234147246807, 0.041160973374761885, 0.03513013005196568, 0.009185652766797331, 0.047991520559955994, 0.1121380657798821, 0.046800705829575184, 0.04919754213563377, 0.021606604005360318, 0.02960606729761968, 0.05248245437659564, 0.0453197812631486, 0.06616717489856867, 0.09180303557866043, 0.06312380251925319, 0.06467357923787448, 0.03186916571951682, 0.014560282410633181, 0.0368683873825977, 0.05745209355448043, 0.0247859071955205, 0.06313682218352634, 0.07485632033598039, 0.0781988692019255, 0.0136520353806836, 0.11658514489329631, 0.03198522037916607, 0.029387623071670536, 0.005030164433147518, 0.04666611950303759, 0.017869533264949437, 0.014529116038653641, 0.07173440479222806, 0.07266729304026212, 0.028827034402638677, 0.007996051806971551, 0.04381408907413002, 0.03235723650563629, 0.011525442335574378, 0.0962429134655864, 0.03308652539647395, 0.016439745067468575, 0.07239896308390364, 0.11979700682023842, 0.05990795693510483, 0.03974660652719679, 0.057676557316294605, 0.03845884336999828, 0.04021435300068509, 0.041411411347648794, 0.06949747401860452, 0.052132310060363625, 0.025755054385010755, 0.05224621967382489, 0.1493337029410947, 0.28100843571366807, 0.11004011867748154, 0.0721219610122423, 0.035717018519438086, 0.11722060716560773, 0.10621440581857197, 0.0546124009715934, 0.09651105189996381, 0.13608681698960645, 0.10000983673718669, 0.07246403459219203, 0.06779355657917839, 0.058212945267798445, 0.08640740938003987, 0.01933504988799893, 0.057890089003429304, 0.18656517769540512, 0.10263708930823112, 0.14143259384699408, 0.024048907629724954, 0.08897609452927306, 0.18085992174042811, 0.0946097672286053, 0.030481880080075036, 0.05437641141695842, 0.06155662794387149, 0.08543490672544127, 0.05546958058051044, 0.11170098197556312, 0.05082450221262632, 0.06266250650608732, 0.055797466212102485, 0.05204976791696203, 0.15295705367480555, 0.09018797667757159, 0.05104953670994409, 0.07041839597326133, 0.02406626335164953, 0.051924880263545824, 0.04565179993909213, 0.0384464442369438, 0.03335323507687257, 0.07936293214199044, 0.007198824802593839, 0.09432220846534738, 0.06568684543092405, 0.019668380489512798, 0.022517229738314787, 0.06387274539578827, 0.052121370324804905, 0.04507651387323295, 0.04509279707206353, 0.030058708432460987, 0.03780040229039808, 0.036808632524503816, 0.040597986850527026, 0.05984436014607068, 0.026426670261688774, 0.006999902412175171, 0.07085772441519846, 0.05372291926534907, 0.05436591601239578, 0.020691444947113915, 0.04797334895439206, 0.07263486453842732, 0.017529192958928404, 0.04418464197266487, 0.011600671212128814, 0.013428803105207701, 0.03138465341180563, 0.05308573329520803, 0.05671982841205694, 0.029541200717851043, 0.02144483113360982, 0.10196046513174811, 0.06331753466398486, 0.034728336087878675, 0.022404632050423853, 0.02814337753901078, 0.03605069960617731, 0.032624823356708216, 0.026100824339195125, 0.04702658302360966, 0.0998882432618449, 0.03663563071900318, 0.01826231995026671, 0.036465957565533544, 0.06047205428682989, 0.010393725542892373, 0.007690489498688089, 0.017098691765098803, 0.026283775711612358, 0.019190921936364427, 0.04156266774741873, 0.0866386836635009, 0.038468829326091275, 0.02413471713812361, 0.006010186719527889, 0.05124829439145904, 0.09574625866427537, 0.057465178336227135, 0.10823284831619072, 0.0997458351776004, 0.16202419455493652, 0.2429947392233918, 0.08843808630180937, 0.1276030750464528, 0.231311974986907, 0.10995383419456983, 0.15693825939970632, 0.10025519937757524, 0.1267996863011391, 0.06656387820839882, 0.1255831693208987, 0.09925569978452499, 0.10017400937936, 0.07059995115043656, 0.12777165269419072, 0.11203118885356574, 0.182716888225367, 0.14802212977120954, 0.16819403687071416, 0.15078914742315971, 0.2436582479746111, 0.13746526963528127, 0.16289037952740348, 0.14824521457476003, 0.1269454038852165, 0.2115257778355191, 0.11207019038979085, 0.10899096126517943, 0.1927798208329947, 0.149039494534654, 0.14935447924560116, 0.24616049031817147, 0.15923744247805688, 0.1191759699835412, 0.15206897390946267, 0.07669126945397547, 0.11448679176429588, 0.13736901834847468, 0.11742874559375549, 0.14700743099374158, 0.20629077729198242, 0.184816520721201, 0.21283679942209877, 0.22746503383161562, 0.15785684478619408, 0.13534725102926456, 0.11869780088384306, 0.12127534967036017, 0.12835306746344413, 0.14800447910543413, 0.16957477245840336, 0.11964489240199329, 0.10602161213154755, 0.14376499449774144, 0.21457025721188516, 0.22182023753562283, 0.11068221527121722, 0.14478015292796398, 0.17450696908898894, 0.11097548138951102, 0.20606248309054684, 0.4250381748762823, 0.14938778874854888, 0.19687995404726077, 0.16324153891013515, 0.1322419749152276, 0.19148537738909646, 0.1732810751925553, 0.16678354642804594, 0.08315407911375647, 0.14949081225260613, 0.16037397987900243, 0.34390820731078425, 0.36168316319104166, 0.2935191724569567, 0.181749610290412, 0.11413181726370128, 0.2300038645344396, 0.1472487640116484, 0.09406291834649541, 0.17575946155815356, 0.23306771061353146, 0.16019964891095317, 0.17009626383021956, 0.11801529315210159, 0.15510767698287964, 0.19185434065518842, 0.12834064917819155, 0.16364350524400512, 0.19876877446809124, 0.239518768484554, 0.29569213488890284, 0.35116854514325824, 0.23176269515627818, 0.26157857669937995, 0.22493254633680468, 0.13133223018338605, 0.22596195400241884, 0.24108239990328592, 0.2629508853199021, 0.09696331956694204, 0.24627486724526654, 0.1786665047609037, 0.19549975472111858, 0.10851794793721169, 0.143060591973124, 0.29726405537897543, 0.22286127441592757, 0.2754213258383736, 0.20260571051509152, 0.15158114444103934, 0.16323651337335188, 0.14669583239141973, 0.08100536336461384, 0.11568031078504941, 0.19986083280415307, 0.101149017141471, 0.18132323639527445, 0.28338036650130827, 0.1592658643400477, 0.07403603935193631, 0.10255863424390556, 0.12811735753090153, 0.09819288302453295, 0.1622684540287141, 0.16111268782086913, 0.14933244655689887, 0.31636795930324063, 0.11549765244126321, 0.159101584445565, 0.1663173512826043, 0.1355123276551885, 0.17724099899491957, 0.09926599600622732, 0.178224349454526, 0.08852266240864994, 0.16262114558729435, 0.17797682644619098, 0.20098900452496546, 0.1599151391776339, 0.12505806201407987, 0.16704858220633, 0.11373627074663678, 0.2334686503895829, 0.13915484590876487, 0.16029488896169972, 0.11158645183088318, 0.18824703180261199, 0.19979747733281505, 0.16147536916598199, 0.25445867810518513, 0.15191169605860788, 0.13341873193219786, 0.10080561056853303, 0.0659985895899515, 0.23472940128657127, 0.3043913697042773, 0.1441820680854782, 0.11323858938750722, 0.16108038955398146, 0.08848901582701553, 0.15127909129425404, 0.14955796752004855, 0.07853227066657237, 0.14957278366050414, 0.09808514807974139, 0.18798758846617517, 0.18967201662880762, 0.15757091012933563, 0.1258393184792611, 0.16196077779656456, 0.1040253785228537, 0.17344966050117247, 0.2814031242122573], [0.04502630447067561, 0.04485204628097915, 0.03319462040258992, 0.022537810690400582, 0.059463920882873, 0.06369993128182908, 0.05904188687582651, 0.02173602306884864, 0.010874736828789597, 0.047428361665938175, 0.04414165677923349, 0.03493456695709498, 0.07120912128518667, 0.039332980335119276, 0.007265486422130057, 0.030248585239713712, 0.03718914839649393, 0.05008682465901779, 0.04664209115529253, 0.017465498493683916, 0.02782546828741268, 0.019207521146463773, 0.04966400158140929, 0.06983595464618937, 0.0371273251010045, 0.020544172204550237, 0.022835297953157176, 0.04389961129955707, 0.01851835036500087, 0.03350126624648129, 0.07826544990342471, 0.031021198317889246, 0.0410581375622461, 0.020747430652620334, 0.021624540038887533, 0.060147114263306704, 0.05871174894573708, 0.023183904347881194, 0.034807817710022775, 0.09205648044665014, 0.012742958102946081, 0.03407143101456665, 0.041125323473205494, 0.016919867691373634, 0.07750061070246082, 0.04997192296169458, 0.11472588780546382, 0.004827056329832563, 0.06206832105113615, 0.014712320220085883, 0.020981918674923723, 0.009539083600224508, 0.019739025287450324, 0.11613342114874434, 0.041792417515910445, 0.019983706109586264, 0.07291301574197508, 0.05686266167509941, 0.004242570026807728, 0.05868730308007329, 0.07164359272968385, 0.04564492046953209, 0.09140791807083354, 0.050743243266497894, 0.04435333836403105, 0.08159092266953762, 0.06452623754739761, 0.06320311943249357, 0.0346540485418612, 0.16577310709943696, 0.030206902395753615, 0.060839033385197964, 0.0696059444078034, 0.08938950621673176, 0.29444359543342746, 0.17148443047077427, 0.06536856654190248, 0.021394453191709135, 0.03000436215511253, 0.05178318081063129, 0.053958318932282354, 0.04180138840550377, 0.021776032010694186, 0.017884851192995425, 0.08473555272024486, 0.05046125779288912, 0.11005594605399717, 0.05860063938363906, 0.018607226140316457, 0.04466605162428272, 0.002601937434989058, 0.14348520386603572, 0.11459236634114098, 0.15250104749875684, 0.1674284698862222, 0.2664086997749344, 0.26011283599561263, 0.03758571764093734, 0.0427106466715134, 0.04228914126513466, 0.11242320370529929, 0.018734934912513823, 0.09996866717213586, 0.06481337496229718, 0.014480087369109594, 0.029161445188125776, 0.1436031814063749, 0.11999677190737379, 0.028890949118161396, 0.043708748154101834, 0.024676686040155833, 0.0867689569150248, 0.0380096783591134, 0.04554803332974834, 0.08122791190661731, 0.06734351056718058, 0.04771257262496699, 0.06954494082639295, 0.05853773973461601, 0.0656780507415533, 0.02687469380156648, 0.02590428448222097, 0.024841582635417584, 0.05684196964026459, 0.1039874724923603, 0.022907806259970513, 0.02562305360521761, 0.049618733445963556, 0.06568990212174193, 0.09889615939990168, 0.045908060180203575, 0.03386787379220609, 0.026197977694532564, 0.05040176723512912, 0.07816252599079763, 0.020555755453965357, 0.03316316866285859, 0.02120268989294287, 0.016684397161307356, 0.02690193205771427, 0.03424275891795274, 0.028940710359283035, 0.009938790932327751, 0.039907952304929495, 0.04973506772770517, 0.07323512507061805, 0.02252818096519238, 0.054012741818423235, 0.019884865445595597, 0.02299338019633245, 0.04394943765815228, 0.03552430910208533, 0.01783282616205754, 0.0286929881680877, 0.06758403153188768, 0.043163561682787635, 0.030709511615456115, 0.07481860582746806, 0.023519789852622538, 0.025528887992784865, 0.0295076001014921, 0.013668707369135754, 0.07674157844796296, 0.07269811275745593, 0.033184442924515854, 0.02248606911199468, 0.022949678710691875, 0.051030913112504836, 0.031504105671399066, 0.06704737161917072, 0.01575424671999269, 0.03464364506784947, 0.010292341466993093, 0.03486983252749328, 0.0630254406602152, 0.012778878050495782, 0.02596354904404331, 0.02800836028801578, 0.020455888232156154, 0.0190388802964721, 0.004623957323811708, 0.09371206539893344, 0.03024406532096046, 0.05467269209123427, 0.04341740108605835, 0.020854974075430827, 0.03181003330786142, 0.10184875419062954, 0.07013812270616332, 0.07291694577302664, 0.015577487253223457, 0.03944730363605965, 0.03074432648117504, 0.0685927624844255, 0.04634323642559109, 0.04110961484031812, 0.03722905008603008, 0.009685041544388139, 0.05997592808618661, 0.04018523782912282, 0.07828867002840965, 0.023638186826100274, 0.04562621260242117, 0.08755186813012247, 0.040313906126445344, 0.020600441362588637, 0.05635547699526914, 0.06568548945529808, 0.022825465214649038, 0.02580125906294392, 0.014999396347951506, 0.026016116082187624, 0.042241084569644545, 0.022494206880970348, 0.061436991823176225, 0.07457328149147573, 0.12027781126239609, 0.00668949555538054, 0.08275621901116065, 0.03751191273031216, 0.044309288308384924, 0.05433524568234721, 0.044522253090455655, 0.0629580593968351, 0.049341294704185384, 0.028146721512800264, 0.03434565984794209, 0.11686704992767304, 0.023325259061229807, 0.08102997776962097, 0.024548789576417016, 0.04965960806716354, 0.01310895182072155, 0.013984099064292687, 0.05994165714289393, 0.051118614858076464, 0.16541551257814133, 0.031065688874091835, 0.07785482677601038, 0.06861557658281058, 0.012735431289090025, 0.05093096162102396, 0.07457267628201554, 0.0501625677720914, 0.05972148347345572, 0.06663125564133929, 0.14157733849940762, 0.075953925148614, 0.07853256944086283, 0.15269014864198624, 0.26271155945235686, 0.18875623512412273, 0.15769336162315262, 0.07016633006353533, 0.03555265818572333, 0.04282274831747336, 0.09060330358484099, 0.05216993263832504, 0.05185612004190203, 0.028203341156064023, 0.025641119873691953, 0.030931529641572027, 0.025112862030284542, 0.060526925334406484, 0.033627008087933064, 0.03120593084473043, 0.02713087168822606, 0.13669092328317706, 0.2364129101436946, 0.16862083977508932, 0.09322224410190698, 0.17461651966216105, 0.27132977280885945, 0.0027272883321969744, 0.04957669054067904, 0.12707110359183243, 0.13588293034943844, 0.10159606008880562, 0.11729274966543722, 0.0368065717479875, 0.04920825587525483, 0.07758714799438754, 0.13443425808462406, 0.029748709038681084, 0.029774987769703713, 0.08607046858918282, 0.02361831259012463, 0.04420942108657572, 0.01611762424750674, 0.07458045973532623, 0.07077654207786245, 0.05885118460883537, 0.044824578198454076, 0.05284942581408447, 0.07761563880429154, 0.032011602532058474, 0.02329171973190481, 0.07794222974729154, 0.07861699233011854, 0.02908911882719446, 0.10646764384282213, 0.05885384676437225, 0.022020791356842366, 0.11935413139121187, 0.04835397973957081, 0.10049870808518703, 0.05575194526764174, 0.03480665325637787, 0.04168383604396255, 0.036930605213368134, 0.017762104755327586, 0.02982165210039145, 0.0391403207134816, 0.032660622645409844, 0.028659232418924093, 0.0433801653824987, 0.018354710153934937, 0.027137768394764394, 0.01574934279966739, 0.03085331014928318, 0.022727291047152494, 0.07282729816412734, 0.019926517646038727, 0.01121461556683625, 0.01893025285924875, 0.012012420488791841, 0.06589000428756399, 0.07782439776365796, 0.01651702418683037, 0.0445420028371436, 0.05395713915687896, 0.009235342187176069, 0.029971280563322288, 0.0036409097083378588, 0.05912781895829305, 0.02195101415347909, 0.021601800634075078, 0.013845872862504856, 0.02803534573514856, 0.062108870084968314, 0.029012358732401367, 0.026508078594962438, 0.040022279436309496, 0.070988365388926, 0.024307895143846833, 0.04588041589745591, 0.01596756390250859, 0.03570612857959444, 0.016470329212625662, 0.06123583628645828, 0.10491249301741201, 0.01950949959967646, 0.22978404326544655, 0.09843774770777072, 0.12215744628901444, 0.22661856796231963, 0.10787696217096622, 0.2124574020384781, 0.24189492807753626, 0.1505000718058117, 0.13983340062681707, 0.1517154549759242, 0.0979843155871476, 0.1357398864122168, 0.2047633665103105, 0.1858677159273817, 0.15438825913494633, 0.0863261963991869, 0.16504080365261725, 0.2192190932410379, 0.09151572962441752, 0.1398276090021095, 0.1333244571522359, 0.07411974977942244, 0.13542413561334535, 0.13388485046884707, 0.10540517948327527, 0.07539088882866406, 0.10031513809677094, 0.16918166210093807, 0.16976675409222805, 0.14787718593593568, 0.12934996235755183, 0.12730311331970076, 0.18286192399119178, 0.07431055163784374, 0.10663169391092756, 0.07777866997545765, 0.11877906749085074, 0.1790725007172554, 0.18636847695996686, 0.30138177797198296, 0.2690541852385767, 0.11264291772198294, 0.22658905825547634, 0.21843848028971305, 0.1398998051280937, 0.12309803372068752, 0.16978388381821496, 0.07437251282915955, 0.14241300252897127, 0.1258291141881097, 0.14458945832185208, 0.2613983621760722, 0.12327270942830271, 0.29049787490117934, 0.16019735064718033, 0.10575365755827197, 0.23130975333192658, 0.16812504299225348, 0.15206613938414282, 0.23991351827017723, 0.2068260276029187, 0.15487679340426, 0.232491122198201, 0.21864871013789408, 0.11250352036328086, 0.16532954219127857, 0.21670888358306503, 0.12479660386640219, 0.2028116349491381, 0.30625520033701775, 0.20455283022695975, 0.12637964795313536, 0.2998785908904768, 0.23100621397456816, 0.39488507675067075, 0.21673376611884565, 0.2804497124687318, 0.16911479794690687, 0.12229265314677071, 0.13566390581188664, 0.1716347369215181, 0.07560952266137447, 0.17989832817787127, 0.08921116094795928, 0.1401525528560723, 0.17951330770888638, 0.36551994602045706, 0.13346897197827218, 0.10481873151635933, 0.16742327581009558, 0.11051052730650672, 0.21455354117337735, 0.2590293118790273, 0.2134787964244043, 0.42464088167875047, 0.38474593371633564, 0.3861958010783119, 0.18636058625434676, 0.06994041839554425, 0.27791245990703184, 0.3800846564192926, 0.18510271584795368, 0.24491492328384232, 0.1268511597487715, 0.11127899776423171, 0.16532125311993784, 0.2788196612269648, 0.30485258527821113, 0.11681443500903346, 0.24744445367926554, 0.14166128641415027, 0.17311049805533502, 0.12075058710310729, 0.1661950223628552, 0.17167794428044753, 0.18022883383016433, 0.18454894153100831, 0.17985607076796795, 0.1482061747341387, 0.19294310481317584, 0.14247516290314738, 0.14001033629380888, 0.16817488467260716, 0.1639347412292996, 0.30077589435442803, 0.1534187595450109, 0.19495348806583113, 0.13977009112075453, 0.2653770857760983, 0.260589434615066, 0.2479817571058389, 0.13023450279668455, 0.14152918221248736, 0.13678954944254892, 0.1439265471192137, 0.10206178792061345, 0.10125308252510526, 0.10953509053515811, 0.1318675111378393, 0.1209376504524581, 0.08063564933235608, 0.09949245159664463, 0.10536876732423421, 0.11727768071596661, 0.15368630809168662, 0.1533986573978778, 0.1667886792171386, 0.15937310132768848, 0.1199448005025906, 0.13354293010648222, 0.21791931782518664, 0.1741067800791033, 0.15515355032778558, 0.08764627314503155, 0.17288729067771666, 0.12738646368586248, 0.1125161991184277, 0.13426538166259566, 0.0949342820733305, 0.19035254785370445, 0.10230426240952746, 0.1274476204848578, 0.12387775034914095, 0.27948208213333164, 0.15404059311314938, 0.15494427042863063, 0.2135069884600178, 0.22695972223676023, 0.09157523933437564, 0.11949821720801054, 0.12290810520249991, 0.09299297696880757, 0.11901646281682676, 0.1403939318392546, 0.22562125938073282, 0.09635687670520238], [0.0302613252818945, 0.06134208119023712, 0.05546444013053852, 0.07185092676551112, 0.1210358705852301, 0.07352053878768798, 0.037574954105601195, 0.025832923392074245, 0.04652831943765764, 0.044915918861666036, 0.02129584235409575, 0.023814471318356456, 0.0686716695406264, 0.04410322980895158, 0.02636236484132467, 0.016065724663466455, 0.04444732969146102, 0.0844831727144699, 0.016948347009958762, 0.06626656714586482, 0.007890075991576118, 0.10019796494875224, 0.048603146006503416, 0.03747327125541145, 0.009232683862078815, 0.044588902739868055, 0.042521905589608416, 0.08956680960592725, 0.04544970977510657, 0.05448264865985802, 0.014983679096574986, 0.05814934081788506, 0.04089581885284955, 0.034540682850826177, 0.07286420061943993, 0.0554788617357131, 0.0058082306209290705, 0.07245037524450211, 0.016799909813750177, 0.06627346959806259, 0.06392333401186813, 0.042967584900437825, 0.01529009702930888, 0.10063421371723376, 0.027134466555810748, 0.045209070066771204, 0.005826942797284574, 0.03569819190869889, 0.049074178997186885, 0.010551938978624682, 0.10957840514639694, 0.04920904877625647, 0.07931842243358975, 0.03498157028168921, 0.0847032391315987, 0.06161973060619447, 0.03833782063016007, 0.03710790477212399, 0.056197505834842884, 0.02811911936488844, 0.09369108991156663, 0.0808479706005704, 0.17478584041518552, 0.15559653300912152, 0.16797384787951747, 0.0861059537818355, 0.012628708537968417, 0.004105705546305305, 0.11147207490378812, 0.14010638839775516, 0.08877714915621666, 0.17131196875726024, 0.35445579778282876, 0.38937837546390874, 0.6780136761165435, 0.5405621807421408, 0.06345427369758969, 0.32760420153217934, 1.3555931948846387, 0.366763613156734, 0.5885328292365998, 1.2919929431330774, 0.9962035763648249, 2.279032146738422, 2.364028927779967, 1.0583031538032717, 1.2780823798910266, 0.9413247146914083, 0.8237904634687209, 0.8505160842211017, 0.7927843111176646, 0.0710508092156341, 0.32359998252603317, 0.18005194412844797, 0.30181854001937375, 0.6360874000576235, 0.8675835425815276, 0.19160536207979728, 0.030026661059368524, 0.10181451772129345, 0.11697859232944828, 0.0735193590122846, 0.07122461924389487, 0.0463487139542497, 0.05670915680727171, 0.05662148570521705, 0.06523132955114688, 0.1075933410996391, 0.06659976942765136, 0.10226823329444855, 0.030315788387651407, 0.04003140354348768, 0.020433495482129437, 0.019378577088636738, 0.07470289590738474, 0.030757934117930073, 0.10080103702362507, 0.025199127360998143, 0.057174218142585415, 0.028830430087363048, 0.02791634355221064, 0.06003385582458108, 0.04576932165711638, 0.022692529807588267, 0.05476389485861986, 0.05421395481173551, 0.009659965571406628, 0.013927013065005022, 0.010948556103563357, 0.021444319769920363, 0.03195166189764296, 0.0488460265220173, 0.026604063666215347, 0.0414176051685166, 0.01816920004785061, 0.0262631124050747, 0.06983460633144264, 0.003584760730342579, 0.05325713397694692, 0.030972191673373024, 0.01939619711089519, 0.0599363366622598, 0.06985624831530356, 0.02803581113356256, 0.04674287385217125, 0.06272640206941194, 0.051909907075065764, 0.07599245171032606, 0.08049020753993143, 0.0800931518296561, 0.0509617353729423, 0.03865447924322179, 0.07374984422518362, 0.012766883986431264, 0.01762412082884581, 0.005982491204650292, 0.035937257306349855, 0.022970937650590655, 0.033240375003867575, 0.06648471834318292, 0.06045338089367556, 0.025428783283719135, 0.005282117344904692, 0.05506670260201058, 0.01586848096321187, 0.019813107904948054, 0.049746317728873224, 0.0474356509925377, 0.015434711446775305, 0.01933100111331911, 0.015725143997359182, 0.009218244062316035, 0.07479587599875466, 0.052693952100291375, 0.026850146429252722, 0.02350933275245611, 0.0296475567043789, 0.04804187551921895, 0.0105425639776513, 0.048413933780525005, 0.02750617050145182, 0.02432599588627777, 0.010175397187741774, 0.023875551508559335, 0.04420264886932508, 0.040024581530521956, 0.027368140609694586, 0.0439334417422933, 0.05392766392399227, 0.030202409290077708, 0.02803882185910498, 0.04744046202470218, 0.04912327757225402, 0.06164611084386707, 0.02928073273881549, 0.049409568459997256, 0.026907294673184236, 0.09703303356805155, 0.01578008495045886, 0.013986214424573607, 0.009890425886448112, 0.015590910071266756, 0.02113621644375305, 0.011399360542606202, 0.032086625522483266, 0.0815634660783314, 0.0195781429929118, 0.0538590147850975, 0.041824807713349024, 0.041181232569919485, 0.06795753769937062, 0.054190029885860226, 0.07640317442917055, 0.0597607646317732, 0.015108240205013465, 0.0500805082640821, 0.01792591925139629, 0.047148341207855174, 0.015970271065711014, 0.004644658455940625, 0.06552655685452685, 0.06667692214250565, 0.055054567769289985, 0.04982488387594781, 0.05854580664045869, 0.04103269578228074, 0.14166442737463983, 0.02800065918915695, 0.024336516188697952, 0.08213489872193144, 0.06699653402451547, 0.03625274380488742, 0.05112787303064139, 0.0471136067813683, 0.09597207840171554, 0.02944545504907447, 0.04018084814531669, 0.051114336257019354, 0.2217801251719075, 0.1018332485710421, 0.11878973909563596, 0.03575907291604146, 0.0068246928370377475, 0.03183543869865037, 0.051347353390508124, 0.1645548281169707, 0.15483666571878618, 0.05279954582933457, 0.11727368939788112, 0.465559323108004, 0.4211950488388539, 0.49466904012426255, 0.1876265005839448, 0.1357850089909569, 0.6959298373230043, 0.32666957426455717, 0.22553475273232307, 0.7306153567567949, 0.7939164664956831, 1.8251467472122562, 1.974576303074437, 0.9830522368992529, 1.705725652075583, 1.427111976569699, 1.504517623013066, 1.3590475772657704, 1.3231189116354913, 0.008041020689321863, 0.3072063751038044, 0.13942403388359856, 0.32971829776802375, 0.5166310648764334, 0.7027464876732519, 0.022739772534658833, 0.012997147991442153, 0.04907295708694766, 0.125748383842649, 0.07830947697643312, 0.059230727549161644, 0.013383482301217175, 0.058599597504062045, 0.03963896734339576, 0.11203190897621455, 0.06096004846415693, 0.10768654335650707, 0.06261169955494904, 0.04143946165699632, 0.025771667001648776, 0.06551290516771617, 0.023277801829540444, 0.030965206866723397, 0.02020950094916888, 0.026147793189832763, 0.05452795126926034, 0.07676666016660391, 0.05792990642329378, 0.021216667167121367, 0.038071570602516015, 0.03994830598634097, 0.07443261242681935, 0.057638505729095596, 0.027400751057411396, 0.015724004441571814, 0.013192734068950579, 0.04908156408477695, 0.02201230501786115, 0.039556271982409304, 0.054650682385169694, 0.03375789037935677, 0.038114345121768214, 0.08930766504378089, 0.026319419867509318, 0.06080824431152113, 0.027822110907084523, 0.024537662149316842, 0.03351413269316958, 0.017380550834200075, 0.04481275363134281, 0.039602214275228406, 0.07071477240852772, 0.03513301820344022, 0.03386824534484937, 0.005743986008793957, 0.02965657547446749, 0.03699205695621429, 0.13623640331770145, 0.012697897768849808, 0.02842078180683236, 0.01977300128689216, 0.0855405425893203, 0.023227207467801148, 0.00660739534895026, 0.04685988229128623, 0.014484997992704233, 0.03343311889517692, 0.02636566668027832, 0.04360496239255994, 0.03696984040641016, 0.05857353519287802, 0.06203640582821062, 0.031804278072330265, 0.016769293109856306, 0.07368340908039002, 0.030717375507998853, 0.06303532702487803, 0.032111709156344016, 0.0014715046774888892, 0.04922147089194867, 0.024908069491146073, 0.0458301758513816, 0.01206339502166356, 0.021172032969432975, 0.1281848805205476, 0.1543265430917663, 0.21242134994076145, 0.178445810151677, 0.1381674045396428, 0.17302665739290177, 0.07441512263950802, 0.1549600518398708, 0.14087077560684375, 0.23661339535347878, 0.17731792954427583, 0.17334911912198991, 0.13356222020041558, 0.08788698563171972, 0.07237138391862954, 0.14995526071758042, 0.12624822556972504, 0.10763966643642034, 0.13402325191324757, 0.15818175799663992, 0.12845996737239823, 0.37938049904281096, 0.17050906264733884, 0.1598417632762463, 0.08026092508507353, 0.11692561734948428, 0.09800573540551048, 0.2910282835364342, 0.14176429459644904, 0.1611560483973834, 0.0976577782703023, 0.16123244268519266, 0.19321183313525495, 0.11938712679811063, 0.1365608568753927, 0.11002400784843391, 0.19217019870636926, 0.18754906441655853, 0.11165089514707366, 0.15900461303610958, 0.17373450731317844, 0.16566239207261996, 0.12027811003668655, 0.12444982650659739, 0.09997203795900268, 0.1231257354600295, 0.15715340753236126, 0.1744541090222136, 0.1847768833319987, 0.08870439378604775, 0.2464364198667388, 0.19559562296396305, 0.17408468610336705, 0.11266632936894895, 0.2069764872712474, 0.16824430756030545, 0.15931469478434132, 0.20269103738809788, 0.14676796723036997, 0.15381865744148532, 0.21765391432469894, 0.108432705333877, 0.4298437524947428, 0.3552251645634252, 0.25821397982297406, 0.1531564357179788, 0.061516519410595785, 0.11327539225138965, 0.21975927715820653, 0.26267346956076165, 0.2976002454036667, 0.2522070690869324, 0.48039936550682594, 0.5804771389211378, 0.680272409752492, 0.7293628336441133, 0.13033637716885538, 0.48585795647194313, 2.406580270298066, 1.7855273763979636, 1.9827800628639038, 2.594417920035701, 2.7844677865505223, 4.381413978915061, 4.332713830855585, 3.4986806492651668, 4.239490368673879, 2.8882505143842394, 2.7202629994961525, 3.1699860288250834, 3.1216129083787245, 0.18635367614126977, 0.3452985343192855, 0.1752735932748164, 0.4376141516672027, 0.7580476170105319, 0.8779398868641547, 0.33640529539796615, 0.11298898262001815, 0.12455977544549013, 0.1824336042327266, 0.18546357390380677, 0.2940438201110209, 0.11913719827369337, 0.19325068911477444, 0.1848371438081226, 0.2159123972899491, 0.4734878121845184, 0.3375879512919534, 0.1697271013812673, 0.17482166268652485, 0.13703062199056149, 0.1998758021621935, 0.08717645440370807, 0.22824471215567282, 0.08145399977483096, 0.17297931315918125, 0.18326629584114398, 0.1991960829904964, 0.17766429321660152, 0.16488632968356534, 0.10594824389103921, 0.17611137170705105, 0.1871026496613218, 0.12380917015815936, 0.1199816493317485, 0.10224548814397666, 0.1343355246729428, 0.13142046819050468, 0.11526031074144187, 0.1668635413290993, 0.16485830618729516, 0.13561165861545071, 0.08617037411538825, 0.17331879736194689, 0.14271386057859467, 0.2594481474689899, 0.07540590415197997, 0.15943443432690638, 0.09918452255548009, 0.13221048870153967, 0.14558312032491932, 0.18998542319863074, 0.15003574591490532, 0.11318307865651385, 0.1742093286086475, 0.10684802947986512, 0.23322143381641758, 0.14623712958587756, 0.19900969379851896, 0.1359903971634565, 0.14328925389676325, 0.16669379156683722, 0.11211684514437953, 0.13290100971296911, 0.1259902607829821, 0.1934521855606187, 0.15100457134746736, 0.15006908606137, 0.11362475132749927, 0.1825998912775709, 0.19667893257592955, 0.06949316860447008, 0.15055126180091213, 0.08178613719440277, 0.13791333914043444, 0.2612669934188166, 0.13537602529170054, 0.11878622275206352, 0.096433661697853, 0.08259891817766814, 0.14143345186546927, 0.12269355461842592, 0.16906805126176727, 0.1187146318355395, 0.1015481795935381], [0.035344316744275635, 0.060450435285606695, 0.10388385910060137, 0.02540715853683651, 0.014521832457713544, 0.044172970623138456, 0.06978703993222407, 0.01543563937077359, 0.023066675658487988, 0.060074213336432175, 0.040572116061324076, 0.08078537355627745, 0.07225702231329295, 0.03824200218303069, 0.07212647327011631, 0.024806957376459916, 0.027103168033664266, 0.04213544104488627, 0.03708155900840798, 0.07243873836893229, 0.021712059838577144, 0.0569648884477154, 0.03273734635102653, 0.020547006729870074, 0.024183511193240845, 0.01746143631246542, 0.012299434372013616, 0.06885893973371676, 0.04463036724876973, 0.0754965246925431, 0.016013728360825732, 0.06894861032525379, 0.03848427365864477, 0.023939514104577325, 0.02141926677957658, 0.022767933926755385, 0.02377575323466332, 0.02772980880352759, 0.020059592864145676, 0.01894245089422311, 0.030805337723464738, 0.03873727802607802, 0.07640885880156871, 0.011725363513124327, 0.03920533093473604, 0.02936919674187178, 0.10666013109467684, 0.05196146096193022, 0.06412482662727276, 0.0448756609412451, 0.04941030007396494, 0.021421061340539206, 0.024836177885111783, 0.05328077161985059, 0.07165084758232679, 0.07269356985606494, 0.05213234453432022, 0.021424851560544585, 0.014879995799292962, 0.031954297240102486, 0.1019670841314139, 0.024120172958881147, 0.14550533175708788, 0.08647268007118857, 0.11382253990779001, 0.045225514144065886, 0.05284541917424049, 0.23586983041417217, 0.3557679838230533, 0.23291495268142995, 0.06464085196174922, 1.413654692230686, 7.197083975038222, 23.897503114515736, 33.73377984569919, 38.83382205040225, 57.492258471827355, 68.03167496958088, 104.90774400772588, 108.55226916651573, 89.43248748779298, 106.95912791836648, 106.55561800925963, 117.19027749953733, 119.4186701313142, 110.64617156982423, 106.22002001731627, 110.21095322024439, 114.71741922440069, 111.74943231767224, 114.02814111401959, 76.56917648930704, 56.06926179701283, 58.69124858610092, 47.98011464457358, 39.7985250719132, 21.143279498623265, 4.697751172127263, 1.9560000805124163, 0.3448652656328294, 0.2046715891769817, 0.39058235924570794, 0.1697047162921198, 0.029877804430021398, 0.07691906569826026, 0.07539910129121236, 0.10660343292740085, 0.10541977345823281, 0.0654280073039474, 0.1378673738649776, 0.10091008197876716, 0.08893969769199049, 0.05693740504343183, 0.012896859421274595, 0.019018619186094692, 0.028214700324761293, 0.02206734652000089, 0.08563608141435732, 0.07271633032829532, 0.002791097950032582, 0.023772447565270048, 0.056340634041736205, 0.04227802915979297, 0.017268395562085415, 0.05167021731575651, 0.010976577684613726, 0.04296665410360983, 0.030642264417462775, 0.053460469033809445, 0.0575864615459596, 0.01925277396015102, 0.002971662958565679, 0.07438607258541931, 0.030995846553254994, 0.05866278443605669, 0.018006691731692805, 0.07528980352705525, 0.03263726462459853, 0.028113599701393998, 0.014587709315932326, 0.11398415381629622, 0.05186262412837917, 0.0403425348321757, 0.015307401040298565, 0.057421063163107446, 0.07199420818998929, 0.04316119447110161, 0.037386527119745175, 0.002231629684589984, 0.05071635741079527, 0.01996353884497958, 0.024531931811643225, 0.04251713669227977, 0.02373483456340769, 0.028162313317279183, 0.021795180378361576, 0.007532827167456309, 0.05923701330058037, 0.06469323705401152, 0.008707757543532119, 0.0874629942700267, 0.1022271326773109, 0.03828389570116997, 0.04745248194423415, 0.09940631267043853, 0.03723178501991976, 0.04322630428378621, 0.010829165131003867, 0.018430874615366903, 0.01970454558519827, 0.03127973192491599, 0.031165385641337886, 0.048752904704381386, 0.04603092536149968, 0.05157412690741401, 0.043700294373857404, 0.08538416872221617, 0.01977695238536164, 0.06427865325202865, 0.046706710671705585, 0.07543169833239048, 0.04717742190546086, 0.07522493886250643, 0.05585991769968983, 0.007575892321314784, 0.0241149922892932, 0.041709147588980776, 0.04676183452829719, 0.041072179953898155, 0.03289434841022857, 0.03337150627386666, 0.029567477533653862, 0.017960374055790807, 0.07389565373981193, 0.021827484390908675, 0.01464593678622717, 0.022725634382016236, 0.04617047593778661, 0.06068452494218946, 0.03720290733561401, 0.013021107391274024, 0.02617559260538509, 0.0332604963031988, 0.011804486989163825, 0.05743027537039692, 0.036265169751019254, 0.022925432027888396, 0.10757799635851577, 0.035215161981121186, 0.027315202018906994, 0.0814674829222983, 0.0346431317889402, 0.007877271789531674, 0.013793131539357767, 0.03635603927015778, 0.022492986885950934, 0.04430471476347697, 0.026825443924134298, 0.022866653931897976, 0.020612790699928038, 0.019189809193654407, 0.02717077529298202, 0.06400328294764604, 0.012650327539191613, 0.037083144810411243, 0.03325211530130717, 0.038106213098451976, 0.064453964812621, 0.019896739808421944, 0.04085944499820471, 0.07157105186413373, 0.03484760448637028, 0.007138801813726464, 0.051238913644826224, 0.02413057068723344, 0.07647016881814889, 0.13003444659613794, 0.05555912476753997, 0.21079381146738607, 0.13042720455315807, 0.0770826714353696, 0.09727605197939182, 0.030628066893006047, 0.022142790858784032, 0.29431890696287155, 0.19674873850759, 0.0631571809701141, 1.1116562134796575, 7.475617854825913, 24.46710382738421, 34.24594725331953, 43.028487082450624, 67.20642397480627, 81.17767118638562, 120.01480763958348, 122.670424830529, 107.7180673230079, 120.27180917801397, 125.57208445764358, 137.30055962839435, 141.88466502774148, 133.04875743004584, 128.1499602717738, 129.23525656423263, 132.19692845498363, 129.11493393682665, 131.24129787568125, 89.07230407960954, 66.19484470736596, 69.36859130859375, 55.21293778573313, 47.78272921039213, 24.70744509850779, 5.582809486696798, 1.7798720540538913, 0.0730218002272229, 0.27311475767243293, 0.3125791335778852, 0.22741981932232458, 0.06768083440199976, 0.09152974137255261, 0.03919000917625043, 0.10302318996118923, 0.03647724204065819, 0.09905588873211416, 0.07991123659115645, 0.06901374312057611, 0.06542518043950682, 0.10704974043032817, 0.05758894750127389, 0.07175188691866013, 0.03218608097203317, 0.02999078133143485, 0.057763799409111666, 0.01003594237244538, 0.017318455577497522, 0.03753555420365545, 0.011524027945744175, 0.04591125476684782, 0.01164233681911062, 0.05063453922048212, 0.0631176316810231, 0.028390632416572303, 0.05613447212043309, 0.02576063725075895, 0.024756506656206424, 0.02189516251335942, 0.09051066823303701, 0.030319818010133122, 0.029314268237700867, 0.09924741837406352, 0.028203599710738467, 0.06842642181342648, 0.013164425204928606, 0.043110180676223776, 0.0409480354057685, 0.06979059458019272, 0.04267307388926706, 0.02688178969096513, 0.021207550720822428, 0.03326901137047718, 0.08580728674367552, 0.04745146687773447, 0.1031057435959097, 0.05113507042669001, 0.031476133886063774, 0.0735083350070542, 0.012383931954841942, 0.026469963805509672, 0.028700118531442942, 0.06371590804548995, 0.01399183080666849, 0.017145953644367478, 0.010026570244301713, 0.03233231949589906, 0.03233113205961643, 0.05426504904584539, 0.03164176975617246, 0.051675905518594294, 0.07305569961787232, 0.11930485661592215, 0.03659351886580548, 0.05720794516345186, 0.02670391939670569, 0.03421190472680234, 0.0068697641836479315, 0.0336679095222104, 0.08479675548451562, 0.009839578715693808, 0.07460214768446262, 0.036177716984023015, 0.02407850543667953, 0.1415936561721948, 0.13539600486476577, 0.3508143367305879, 0.1690467540174723, 0.21770469063232023, 0.11077164071461848, 0.21702475695600434, 0.14524118464079597, 0.1543165379834752, 0.07993450268141686, 0.09789672109388536, 0.16147602800159686, 0.1518483252655114, 0.07744372101320375, 0.11820215731859209, 0.1426036511698077, 0.06457027994216451, 0.2354751878808583, 0.15719405615762358, 0.18249519770183872, 0.10970058850944044, 0.19495843699382198, 0.24164412621288534, 0.14029915144126262, 0.08879930441898685, 0.17179415981856086, 0.08462207977690044, 0.19936669077123367, 0.2790215100732542, 0.1384209030337872, 0.1425773590322464, 0.2864453617122866, 0.119664098226255, 0.10878325950714851, 0.168690906176644, 0.08251756730098879, 0.1434531813908008, 0.23340661258947468, 0.09817828138869616, 0.11232954179567677, 0.19143757350262136, 0.12713456631547984, 0.1875735792301355, 0.1611825550395635, 0.12317703270743932, 0.12333548267281826, 0.17129727519087254, 0.08675601002910445, 0.16794884276966895, 0.27859185732180075, 0.1582070235763827, 0.1534815940765604, 0.12791265117665454, 0.1086545950402656, 0.20513908667189462, 0.14769568438491515, 0.14028189914120784, 0.19057503510867396, 0.14400952976317177, 0.29275719076395035, 0.19697248214675536, 0.11226896722350391, 0.40023025605947743, 0.27278362382804194, 0.18799621461620256, 0.2921423898829568, 0.21613572724163535, 0.34018866657730074, 0.6493858284046573, 0.20555574657215228, 0.1798843547341324, 2.594574324546322, 11.682428506112869, 33.547322134817804, 50.135441364780554, 59.2647030276637, 83.84165871527888, 105.79407415082379, 146.1763341965214, 149.5758524248677, 132.29636838359218, 146.6509880558137, 153.4541194669662, 165.373072778025, 168.8191887640184, 158.37184598368984, 151.8488188712828, 153.20540981908, 161.6008823148666, 156.5441469992361, 155.08864956517374, 109.5701006920107, 83.9156581509498, 89.67012820705291, 73.25234182419317, 61.98487066453504, 32.58426454759414, 8.426970108862847, 4.141093300234887, 0.38804847747087484, 0.21216313234500347, 0.7673932155293803, 0.6518301391793836, 0.2199852424523523, 0.1571077793355911, 0.135946209211984, 0.238634534480591, 0.29617581216077654, 0.1816625060934213, 0.31503015528282813, 0.2970014404385321, 0.18124826703100436, 0.23796831377811972, 0.1348403000062512, 0.17378038065808435, 0.22195897605871, 0.08510334387181268, 0.1597178102500977, 0.255057712896697, 0.15124169088179065, 0.1333241507170662, 0.16707878139230514, 0.11092737872874546, 0.0583038377695747, 0.14838718598888767, 0.20876522596564986, 0.10031468610489562, 0.10997924533101822, 0.10842944179931957, 0.10778186767692528, 0.09725885330549172, 0.14592166990041733, 0.23924784915101147, 0.12353017625789489, 0.13264576453835736, 0.08156260039897696, 0.14230313019887095, 0.12092531643687718, 0.21861382249382236, 0.1861723124860756, 0.20711134938943773, 0.11819809705259339, 0.1292745333405272, 0.106432648946441, 0.20830543531525522, 0.2977687541034914, 0.15916455687294084, 0.1584537958185519, 0.08118408401646922, 0.1186143892306474, 0.1585419572168781, 0.07843143051309932, 0.13644557596454698, 0.10060353189586632, 0.14491464732395065, 0.17152354692018804, 0.10823292492498314, 0.16908439957807142, 0.15850474066551656, 0.07805820013726912, 0.13929939137831812, 0.12476504104392183, 0.17723166804400184, 0.13117219441600386, 0.2851765056050593, 0.13446001396063836, 0.16726042083915205, 0.16427437864965008, 0.12195627926097763, 0.17369690771785476, 0.09957833771383572, 0.13531847676682857, 0.16741308684070266, 0.15536796301603317, 0.14395490769417058, 0.10473026368286341], [0.01640507192801564, 0.02480041307036675, 0.010365291231972797, 0.08042740365189892, 0.004997818764569539, 0.016789519746277123, 0.09062322953175153, 0.08940708027371476, 0.06686194003709862, 0.008031957869177625, 0.03282059712575809, 0.019277715867745782, 0.03543903202479405, 0.011884769173188797, 0.07014638113398707, 0.006792861404978941, 0.06493256292155673, 0.06364954567904915, 0.032763994719472625, 0.034842249531779564, 0.05966309225186706, 0.046396793632377545, 0.02555179402172085, 0.07342403469186637, 0.07964859866807539, 0.04456163384020329, 0.08613627554187853, 0.03347801164753976, 0.017016149621697205, 0.06777721592375348, 0.05333699098217392, 0.06775385024206293, 0.008296514842509022, 0.04018689640947888, 0.057622525134995106, 0.06645734602164838, 0.04908353293074235, 0.011196649847401968, 0.02803761144018462, 0.04215624799290973, 0.07370652195306555, 0.024949830859118415, 0.05962630470974311, 0.07809967613748967, 0.0506045583695654, 0.12414593474879382, 0.02771730433338352, 0.07201507642504669, 0.01809640445806567, 0.019115889369840586, 0.01234428403193071, 0.06583588783659282, 0.043468901346768105, 0.042726619604734645, 0.09883448166111786, 0.039260500756603096, 0.07130350331745802, 0.09997797514041586, 0.05405578063800932, 0.0925829743726119, 0.05256663977859482, 0.04921222038026299, 0.544573784835877, 0.30805235067682885, 0.10922556037023183, 0.5880554032421882, 1.198842780243966, 4.974791609471844, 9.375830677247817, 37.82597295699581, 58.41135609534479, 76.69052677769815, 105.70385179212018, 122.19698690599012, 123.69259449743457, 117.12025534722113, 117.58727627415811, 124.30869686988093, 107.63694486310406, 112.15984559828236, 121.7399052650698, 115.90960794879545, 110.48385604735344, 107.0849104850523, 109.55575266192037, 106.16398503703456, 114.35587083139728, 94.84208706886538, 104.84073423570203, 104.92127618482037, 103.12379514017414, 123.99590353811942, 123.86491206384476, 120.39822716866772, 131.5348559041177, 133.41618937830773, 123.83310948648761, 120.55492585705174, 99.20118178090742, 72.79871186902447, 62.26553586221511, 17.80344601600401, 3.036916678951633, 0.27527696422992215, 0.06394097701676431, 0.12090686137878126, 0.394054331005581, 0.6056628003716469, 0.1995811034594813, 0.07900391269715563, 0.05401274947930248, 0.10802363736494895, 0.12121852892901629, 0.016330297916166244, 0.02619689559533952, 0.0559534072395294, 0.06834121751448802, 0.023719288724204226, 0.03553986068694823, 0.07596232147226412, 0.032224182354947256, 0.030214392820433266, 0.058824720101491104, 0.06253597942451317, 0.06763497637885232, 0.03438084243586467, 0.06453572937677945, 0.012489326501024828, 0.02004354140691219, 0.08982596948983208, 0.0331879937420449, 0.029121612446502815, 0.012436668489939504, 0.06603540011471318, 0.0326965713212567, 0.035168181639164686, 0.024796406430522763, 0.03522679502625139, 0.0141407381893406, 0.04625838452709779, 0.03220336008516531, 0.012985340661309179, 0.08615682968088696, 0.04128117640052111, 0.03640981864244227, 0.040500521314360445, 0.07422337849293986, 0.07348881508674353, 0.03425102500665573, 0.06454493775362931, 0.014505035979973694, 0.036837272721553044, 0.02324739579982575, 0.012576632753705547, 0.06560698842569705, 0.01802785299538124, 0.026795382633985534, 0.09758258674053416, 0.022057774251387007, 0.022050998203696746, 0.024408369490336028, 0.033625039241967664, 0.12180461683460783, 0.03143970640526424, 0.05354292307709975, 0.020526571334489895, 0.040132270510038065, 0.031253497243949005, 0.04908420708811572, 0.03798925445505208, 0.0480007749020813, 0.029391233261013706, 0.03235237567775673, 0.11903743064331433, 0.07761861122543774, 0.04734324929755061, 0.0724095504190172, 0.04212475794878218, 0.0473029607336127, 0.024658945359049306, 0.032569136425492265, 0.04358984364737426, 0.011753210809171922, 0.060429482780877626, 0.039770477826917366, 0.006567709121642815, 0.050214723037976416, 0.06578037710559946, 0.06172292648003467, 0.013041724732536222, 0.10694303204335513, 0.06194965786210472, 0.012289177412317406, 0.10318366239868826, 0.05516643192799342, 0.021280664237095945, 0.024263136456870747, 0.04466420918282482, 0.031120971693927725, 0.01375334093257064, 0.10343608070885944, 0.020588090110029426, 0.06483016760959741, 0.03196873608225536, 0.04872450965546793, 0.07675094770327692, 0.02383432065647456, 0.02986128757437391, 0.027219854715851047, 0.05736646407674398, 0.022613228216106375, 0.03978683763454038, 0.06092437557996281, 0.010730774543668714, 0.044698280943257195, 0.04835902825899182, 0.06105264551156472, 0.02570627948209163, 0.06820943506975329, 0.13621040229355136, 0.0500792020841712, 0.07753677005248685, 0.03039090905428654, 0.0577784814841805, 0.011035224588047112, 0.041599600846248294, 0.024118284552147793, 0.11011092052344354, 0.04938455185882988, 0.021211339025607994, 0.057563861952193325, 0.038377890859039566, 0.07686449725541376, 0.060309923268974795, 0.03272978506321388, 0.16878594704453023, 0.06288243885782939, 0.09852423137354274, 0.541505326907481, 0.43401004506214974, 0.10852799901077825, 0.5562602416161568, 0.9344986874249674, 5.544826234540632, 10.854057265866189, 41.732096672058105, 73.11822029852098, 95.87991483749883, 122.98517934737669, 141.40685758283064, 142.44157883428758, 137.6389503479004, 135.38837279042892, 141.6626118075463, 127.23016446636571, 129.54889712795136, 139.0303719428278, 135.91765742148124, 132.8075630434098, 126.35418938052271, 123.89111349659582, 129.69660574390042, 132.63673597766507, 124.44459130687099, 131.11184397051412, 132.12378409601027, 131.27942331375615, 153.50898558093658, 153.28178621107534, 145.03705824575118, 161.32604968163275, 160.1760264365904, 149.91104249031315, 144.82976882688462, 127.82565870592673, 94.72647913040655, 80.4916564879879, 24.344796480671054, 4.9020713567733765, 0.409095548093319, 0.09133369947272925, 0.0522939354601887, 0.36368473643256777, 0.28218425810337067, 0.3064012166953856, 0.15727615013958948, 0.18781193982689612, 0.1280208534350799, 0.06988509152565273, 0.09674915968770943, 0.01073485779230513, 0.07274712706285139, 0.027045192414774533, 0.04699131233557578, 0.07356042898590527, 0.07096490777668453, 0.02148290761866637, 0.047507977353469025, 0.04686413024882636, 0.02910384303709913, 0.035209404830370224, 0.06856660058181133, 0.04283821180222496, 0.028010357862278342, 0.02272118724161579, 0.003045782683447244, 0.053522100807317806, 0.02153009863480205, 0.01950648887413404, 0.05086284108279694, 0.03864900171456318, 0.05620219429293948, 0.044907296542078264, 0.03422990013214369, 0.07642134603473448, 0.026658408028343995, 0.05480407617024837, 0.04478162747897929, 0.025768552854236577, 0.025671163926862424, 0.034890359853424376, 0.0597240039027266, 0.015077071917814114, 0.07774984974774622, 0.0569615789478825, 0.03639648871255979, 0.018911717361920787, 0.07146944562273641, 0.04406356943711158, 0.04232936854203863, 0.02482229828714363, 0.009550390100376982, 0.03168110071020502, 0.033631750172184366, 0.025908668420367667, 0.05614239346957015, 0.034807568731447386, 0.03275783537256141, 0.050003803710663514, 0.02606576815578005, 0.03682986848176487, 0.032202992362961654, 0.03558682570714624, 0.05797455785796047, 0.012563340170609375, 0.05096910513877388, 0.08780027980044966, 0.011296791903254007, 0.030027367775478674, 0.050549702643747293, 0.04823369627457954, 0.03797263800797444, 0.23240610176036436, 0.10439524577269632, 0.12484736485226501, 0.1262976305799619, 0.11102236597047699, 0.09882659095549777, 0.14578663924288365, 0.1478410725511851, 0.12453611865038834, 0.14841854962850773, 0.07466397097995205, 0.09130352326939184, 0.14254075535122426, 0.12086100335563384, 0.15001881537177872, 0.13824782844993377, 0.13057152019633403, 0.15177850401209247, 0.1549218393742077, 0.21213451130015237, 0.2373206783686915, 0.10594465859955358, 0.1761036495407743, 0.16011980722748465, 0.17712691318123572, 0.2380833495408297, 0.26344853603551466, 0.15838328508600114, 0.15231085851067497, 0.2673067999703269, 0.15283832536830058, 0.13203502392336247, 0.2499399544490922, 0.101093108044757, 0.09311568893251881, 0.12690455607709386, 0.15491951046691788, 0.16450929185075147, 0.11504016005464139, 0.1638133469368181, 0.15624487321944008, 0.12218271952963645, 0.2530827535496604, 0.2188135109721653, 0.19982091962329804, 0.24441361066795167, 0.09928999754089503, 0.17053267347716516, 0.10210877209300957, 0.14637206831286032, 0.15348203840755648, 0.24904648142476238, 0.15888052211413461, 0.14321834479849185, 0.15920316770432458, 0.18405207222507847, 0.21293101291502678, 0.2299097429720625, 0.18329560636512696, 0.21290108952070438, 0.21022589516735848, 0.19234875847976055, 0.9965242914134457, 0.5360908013197684, 0.16909950683193822, 1.5981289095455602, 3.0000034984081023, 9.643462819437827, 16.779181803426436, 56.81502988261562, 92.8770580599385, 116.37603267546623, 146.74419926058863, 161.46262661103282, 161.60902515534434, 152.72353879867063, 151.25828250761955, 154.92530638171783, 135.9525037580921, 141.48252794819496, 154.87761036042247, 146.54712369365078, 138.92854721315447, 134.67486227712325, 133.81462374041158, 137.04265594482422, 143.10207459234422, 126.1083979760447, 134.4732367607855, 136.55759995983493, 138.40246323616276, 160.6413450548726, 164.38110536144626, 162.0878053480579, 176.54895659415953, 179.11385720775974, 170.88682697665308, 167.8364153831236, 152.10548308587843, 120.51109729274627, 94.99656569573187, 31.139669341425744, 6.725296387749334, 0.9861939941202441, 0.2733522449289599, 0.14731522979995898, 0.5332736202305364, 0.7220911270668431, 0.5755209177732468, 0.30317203352047556, 0.3007772733126917, 0.309506569418215, 0.2731329599215139, 0.2446935851607592, 0.11619481543499617, 0.13993680717483645, 0.264286115284889, 0.12722514855164674, 0.170761228148495, 0.2112589494114922, 0.09550852625961266, 0.11840257358046309, 0.13866329325302956, 0.1306488337896524, 0.14183007090562774, 0.11578140374753745, 0.13049149465176368, 0.16488424592441128, 0.09409941477520813, 0.15258300358489638, 0.10572661465454487, 0.15266246222440275, 0.10386613948691277, 0.174569727011746, 0.2113354049863354, 0.2177064219910291, 0.1381172717458779, 0.10646405855133649, 0.17241541115987688, 0.10076291648851288, 0.08021466103532622, 0.2099393629619191, 0.17954035061261348, 0.16115589517979853, 0.13807643925951374, 0.14060350285182077, 0.16524182512394844, 0.18567032571281158, 0.07906833303070838, 0.26510503263242785, 0.24225652157779665, 0.06740930985899703, 0.13481535618343662, 0.12519300074106263, 0.24438327358615017, 0.19905562843045882, 0.13521628063772956, 0.16864875601905008, 0.06747712396205434, 0.16040342829881177, 0.12191299529325579, 0.2063092246891991, 0.24255669014828823, 0.1453882735222578, 0.17248569206605036, 0.09533705279952097, 0.09230674604975408, 0.13302375232019734, 0.17125141716772513, 0.14701541362991258, 0.2686875355580161, 0.1927665062248707, 0.11774040548311127, 0.17389633572630345, 0.190503130096101, 0.12971109620505764], [0.015567827842108186, 0.036607266313606696, 0.053369733580057664, 0.017613809285384995, 0.059381761783433545, 0.05681129931021602, 0.08402512108366336, 0.049095640950385606, 0.02993009376129316, 0.03766331085634809, 0.01582069239849525, 0.018884111383569338, 0.037055561814697525, 0.05084500655591969, 0.0201204834475873, 0.0194016401655972, 0.050815109974674644, 0.09070621983658883, 0.07865501327380058, 0.04784226748010805, 0.06444903120638863, 0.02213500357503372, 0.05029946768416032, 0.04651703879297261, 0.03204195302039866, 0.07258262500287065, 0.08197221995121048, 0.03513359276938342, 0.033351791001135306, 0.06671894972603168, 0.016163279257354238, 0.02644842524351853, 0.041980239292306286, 0.004707401535744149, 0.012919699375127113, 0.022495853970007553, 0.0574393458514204, 0.03130277201923872, 0.047065657338187586, 0.021492820796406558, 0.03866310156280956, 0.0076916055930327755, 0.05729357081074869, 0.012502965738906736, 0.03953837999893774, 0.016201734955933307, 0.08130831283427055, 0.026585336646906314, 0.05412795378135578, 0.04372549483612661, 0.10382988054545657, 0.07168294666635414, 0.020838508930718227, 0.04247552279623286, 0.006248400801972997, 0.06513433515905373, 0.03982949724060394, 0.08716828024555599, 0.037078460182754264, 0.33062108642151283, 0.16003697780111145, 0.9461864312329601, 12.413370032464305, 24.686531020749, 40.9314428606341, 67.98604995973649, 85.42251510004844, 94.77996457007625, 105.53367583982407, 111.16841162404707, 105.81489409169843, 105.58330951198455, 83.71758630198818, 82.83548447393602, 90.17127375448905, 86.87583954103532, 77.16910300716278, 64.3111107426305, 87.13091911808138, 93.03641611529936, 73.68589708881994, 86.90937580600863, 81.43333127421718, 75.3169676565355, 91.53529367139264, 79.09202144991967, 82.73536205291748, 111.13474199848791, 116.68892014411189, 104.238979893346, 81.52918615648824, 85.03576940105808, 91.63342352836364, 91.62089547803326, 88.48961245629096, 84.97731824075022, 104.47922506640035, 103.65560577761744, 117.54816239879979, 127.30072006102532, 125.20045557329733, 118.39242904416977, 103.49405119496008, 80.69612964507073, 57.34932338037799, 46.5734899428583, 30.141957613729662, 20.68974171915362, 5.110498753286177, 0.2794026847808592, 0.2001538154699149, 0.04995503455340382, 0.18420533577521003, 0.09855136620782076, 0.07133430771289334, 0.0986767441575085, 0.017654061460146503, 0.042014598335710265, 0.0424352074192176, 0.05366952293702672, 0.014988031433594805, 0.02577372777816509, 0.013377021307185774, 0.025763224712723208, 0.029039416957886952, 0.04237862033469062, 0.040153146405974706, 0.012843139420804239, 0.04728265557317965, 0.06337728569163911, 0.03182008055098836, 0.030881293425937335, 0.041066556868533936, 0.039332513021485466, 0.02740627072090584, 0.04730361573878796, 0.033015489893695044, 0.0441064014129581, 0.007230370866900851, 0.028648279276826692, 0.04866168661523731, 0.04632878417689954, 0.034220017597920475, 0.028277107762292992, 0.030992496833806078, 0.019374407655108842, 0.017666276732099154, 0.05227648014683397, 0.04952210294563444, 0.011802159997093822, 0.06749187881547598, 0.07476544698640224, 0.052040479100880124, 0.016254549057433204, 0.006609372813404808, 0.015459851579620473, 0.031082648145515594, 0.05062251547051053, 0.01062091657771699, 0.02396955241208836, 0.011312542670977213, 0.017545027996323282, 0.013534056882734501, 0.02040727803814075, 0.01881557715786321, 0.044192065364651145, 0.02513266923356681, 0.009548233562870132, 0.03717501790473058, 0.010791489884497659, 0.008793581416079355, 0.04063113547501065, 0.027289365703660636, 0.015088787317396173, 0.024171146534142957, 0.01652569055647379, 0.00800317642466736, 0.026747573001851, 0.03453389914225667, 0.02068435863381432, 0.032467549336293054, 0.02741789035949736, 0.03286613722241694, 0.05317185689965564, 0.006389098594926539, 0.02315108705642483, 0.04050764976249587, 0.05377506687035484, 0.039707310047120824, 0.06213371814679235, 0.04885818816781525, 0.04600801933256369, 0.023055241796218102, 0.10658258767498117, 0.037575444401872736, 0.06827123538260499, 0.01821109739642951, 0.06361794455217258, 0.026115870306027994, 0.022360819482034253, 0.037894156130571524, 0.06758007085731915, 0.044537594001139366, 0.11870326309074318, 0.06053585025872435, 0.01572006100398158, 0.01469574686545398, 0.05261851542238748, 0.06925305366636285, 0.0640415950047393, 0.06014400777677375, 0.08851792032439863, 0.045670132423120166, 0.03182829684397626, 0.05295837883867564, 0.038015933467015144, 0.06340412558206628, 0.06089385463705948, 0.04101381937582647, 0.07693749777371846, 0.0035548483485340955, 0.038881241268808805, 0.07518311812271995, 0.03266466758965004, 0.04354842510374804, 0.04967388794607213, 0.0513795635572845, 0.02519810654883904, 0.07114253292280821, 0.02263443544507027, 0.08617693182802008, 0.03882097313180566, 0.052154698979950724, 0.13341487084905948, 0.050248392602248546, 0.31461705003053914, 0.0722308297671618, 1.0930661400479655, 13.079114902404047, 29.01352897767098, 47.472987482624674, 82.12056975210868, 102.14104529350035, 114.1189439835087, 119.97685478579615, 131.65812030915293, 119.083872302886, 125.55873270957701, 102.1668387997535, 108.80827442292245, 121.42163630454772, 124.54136402376237, 134.87360092901415, 104.45141546187863, 138.94848854311053, 139.35340266073905, 118.01963129351218, 129.16562664893368, 129.0173767459008, 124.3775736901068, 125.04889518983903, 122.01123129936957, 138.95440347733037, 137.01422660581528, 147.04989310233825, 138.91613683392927, 113.0005350420552, 116.19522710000317, 131.54075514885687, 127.6653592817245, 116.47205229728453, 117.34386182600453, 135.86017116423577, 130.933085872281, 139.2168414208197, 144.4525937111147, 142.87145491569274, 141.1311306491975, 130.19606467216246, 101.52021254262617, 75.85906274857061, 57.1569585800171, 41.3458530364498, 26.064724422270253, 6.831369534615548, 0.1389791513042104, 0.17632834312896575, 0.04846407806560878, 0.13745207760122516, 0.062363858620125445, 0.125396772468042, 0.051490064079482714, 0.03784691531872077, 0.04387523055136685, 0.06668721070332874, 0.048299579836067655, 0.05001526055557113, 0.026624326691812566, 0.0638891971339622, 0.05096011509698245, 0.05214175975490963, 0.020368479515215563, 0.01151610755421702, 0.031781868085325245, 0.04416838175647202, 0.04307695927338735, 0.02993572259231681, 0.035452116806540764, 0.048609948867271026, 0.029917110486196417, 0.0039572199907965, 0.034896649435282714, 0.07807246469441922, 0.0557344516498908, 0.048880450682894844, 0.03476809222070921, 0.04321569779647454, 0.09306221599540404, 0.05466025465378358, 0.07027917481478184, 0.02378836878755641, 0.02083952782765752, 0.01837251978295465, 0.050552403103680386, 0.005359989224797896, 0.06043157037047129, 0.07287283443034658, 0.03528751515512986, 0.08846073952173034, 0.015437736536466308, 0.027210362886469212, 0.038608337767542376, 0.0599116035136244, 0.008961893805873491, 0.013062670533995957, 0.0434623321428174, 0.03449600460308214, 0.01690095872618258, 0.033286842066914804, 0.043751480538518205, 0.05258575750274524, 0.06827182527030669, 0.01623362145056167, 0.053373583171877174, 0.03007168404667849, 0.027123316146072843, 0.03992361497254141, 0.055270485820308815, 0.017214424667819854, 0.07287030634019645, 0.009834567543059107, 0.023795060565574996, 0.10573992160178962, 0.12430141229302653, 0.16305205472294362, 0.09017734337718257, 0.15719059344020583, 0.1554619620043424, 0.12107016834160014, 0.14059110754920592, 0.08762817814826004, 0.21082077776232075, 0.11337273138304872, 0.08718409230031314, 0.17080800547715158, 0.15455089960127108, 0.18173611182118618, 0.10919685505570904, 0.1464522470750155, 0.19216166448689279, 0.16237498621546453, 0.16280725898761905, 0.21884723416259214, 0.1237204418547692, 0.1079444315344576, 0.1997507919347094, 0.20211509248662382, 0.19623645551262364, 0.20935019538287195, 0.1469876199600197, 0.17890010029077533, 0.143216582796266, 0.15525801407714046, 0.23091293510890779, 0.15019705338824182, 0.20677361186713944, 0.13522282302860292, 0.15089282976283183, 0.1672059519877357, 0.1083462063463465, 0.1334887370467186, 0.12809652760024035, 0.11943300780389579, 0.24395955035523062, 0.16603653409308003, 0.1663931480218326, 0.16173986868271906, 0.1548295104575734, 0.20971105343872504, 0.1320819238260869, 0.13777902860554958, 0.159713244366069, 0.33977013742250783, 0.14859671103617839, 0.16226880642915928, 0.1098094879078769, 0.3042574575351131, 0.11685863828226445, 0.09878346786624002, 0.2380668326851822, 0.19031887062855307, 0.48391868150041956, 0.1867554739357964, 2.5611282740869834, 21.47342343484202, 37.834225623838364, 60.42760341398178, 97.69408164485809, 120.35046838944959, 133.73631754229146, 142.63997231760334, 145.26532450029927, 137.3196537263932, 133.87937422721618, 105.71450494950818, 104.1447174933649, 112.39342274204378, 110.23250272197109, 102.67596244812013, 89.92889481206095, 117.22697519486951, 123.27534060324393, 100.5866256836922, 117.37808058338781, 111.82601267291655, 106.72016928272863, 125.7468495830413, 110.75239719883089, 112.48195063683295, 137.83681038887272, 151.31303879522508, 139.13535025811964, 106.63974500471546, 112.39146155695762, 121.95107783040693, 121.06055075122465, 116.81071758270265, 114.47793499115976, 130.23742998799972, 128.30080678386074, 143.48637273234706, 159.40335089160553, 159.07609970338885, 163.343873793079, 145.34535654129522, 118.58707274160078, 88.97923408016082, 72.89163281840663, 49.85720411423714, 36.52842152503229, 10.545350063231684, 0.2651424483666497, 0.3466672882918389, 0.12820618542572185, 0.318198940085788, 0.3093678462168863, 0.29115600571517025, 0.18214580032133287, 0.19275129171869448, 0.11430184281761609, 0.24285980049640904, 0.1251597065598734, 0.14306601587562792, 0.12802061594782338, 0.19600549532521158, 0.14387273710341225, 0.16051055803414316, 0.14861983156973316, 0.07396434884398215, 0.19853913195190892, 0.18068657136492192, 0.19385353902414923, 0.08791763680957018, 0.18187468180493002, 0.21440343390549385, 0.13368301694431614, 0.10020829947485078, 0.11069265704962516, 0.12067901150834177, 0.12459401957570546, 0.2166227753003759, 0.19299476978278932, 0.0768165937775085, 0.19315316612201353, 0.12579247220269135, 0.08734074961994925, 0.10947902055998003, 0.16486979750615938, 0.12231319962489991, 0.17261673906637778, 0.10370977328068788, 0.16489141650738257, 0.1706024028000332, 0.22021065616319258, 0.09860989532523579, 0.12924612680029485, 0.10856844079230102, 0.11327981257871275, 0.21939722400519157, 0.1370078232139349, 0.12627740585876088, 0.15298434172666844, 0.11542439145306427, 0.12169042376861458, 0.0916318608928592, 0.08917723857467214, 0.10160039614645705, 0.19028718523200483, 0.08298498818710928, 0.22600402755122032, 0.16146484311790238, 0.15857361196990938, 0.13337080547165486, 0.13669829304900863, 0.0838107543606912, 0.09807831457545681, 0.09979210688822693, 0.1649121315248551], [0.018079180886308034, 0.029187112964028795, 0.02362096900000207, 0.06208449699765733, 0.025076846321744305, 0.009271535053548795, 0.04485612952961557, 0.02993176383296809, 0.055491977160976785, 0.033166244505874576, 0.05219240582758381, 0.020132976426412503, 0.05538650217556185, 0.0998980338655172, 0.037145266880191145, 0.060696858957770376, 0.052086693354912346, 0.011771860262078625, 0.08356702348758137, 0.0646263345955841, 0.019211627377737916, 0.024496645801850868, 0.06485992246457646, 0.04049457264162841, 0.0486495517825167, 0.024761401958042578, 0.12705753617469343, 0.025148845180087996, 0.06784361276415087, 0.031000577146187428, 0.06109366951990993, 0.018814732545926686, 0.018396977139937303, 0.07736681344648523, 0.04178826914980047, 0.07343387126081413, 0.004039838742990528, 0.01249574152978077, 0.06970899855537761, 0.02616635550023808, 0.03040472928044056, 0.031315399063450676, 0.03687598697480656, 0.05438055212218916, 0.06745711374547213, 0.02820169406702682, 0.015230586361740867, 0.009606617123579547, 0.06700529040948999, 0.0342755206680346, 0.03780037547732073, 0.05877330411045302, 0.036005197813914674, 0.08274362452568547, 0.01886707550335315, 0.04162984216705926, 0.15423433674919992, 0.25269325912719776, 1.0802352091958447, 20.390058909693074, 57.53020348087434, 77.96525785999914, 100.07699212720318, 97.32591229100382, 102.08500246847831, 99.56385981652045, 94.74579288113503, 81.43277429765271, 84.32553798921647, 68.81079889112904, 78.52779634537237, 46.632855015416304, 60.72117713189895, 63.275275538044596, 37.39501430142311, 44.26945047993814, 27.168720614525583, 32.105088195493146, 25.517896990622244, 33.712928525863155, 32.18033298369377, 29.97318194758508, 41.84443727616341, 25.331870740459813, 29.206295820974535, 38.65733500449888, 22.768552803224136, 51.77838886937788, 37.405883189170595, 40.67191531581264, 34.396319158615604, 52.401488750211655, 69.27095567026447, 53.92512559890748, 49.85049686124248, 37.863670856721946, 53.188865338602376, 61.67394438097554, 76.33392057111188, 95.69387682022588, 97.78183291035315, 79.70013787669521, 98.9094280427502, 110.0070527292067, 109.76901977292954, 112.81915680054696, 117.28574014479115, 112.8144185773788, 95.4758793307889, 49.33615253817651, 5.347051014823299, 0.2459344943805087, 0.5319804025273169, 0.315261329974859, 0.043065552224194815, 0.03125849788287475, 0.016518567853997794, 0.03115231618134966, 0.04788303484899863, 0.035377534316672433, 0.0908810334400304, 0.05587897030636669, 0.023530599353234136, 0.025636268621911446, 0.0217832830328975, 0.03424486565974451, 0.04729003683033009, 0.04005716708038123, 0.052676424008583835, 0.13218925274427862, 0.046567282669486544, 0.04300553689620668, 0.02419309303795378, 0.014678950387714131, 0.05239298296791892, 0.03321234384671815, 0.016822421307405157, 0.03457747039295012, 0.04033539489272141, 0.027213542151354977, 0.022495308132361502, 0.01866969869532172, 0.10379265633321579, 0.02763560871713825, 0.04482249443930003, 0.029518486210896127, 0.07137324030120527, 0.03447075434509785, 0.04947242597418447, 0.030344401771623283, 0.04477657129867904, 0.04700657280702745, 0.006067774506405958, 0.0668310437111124, 0.032613546542462804, 0.06911417724744928, 0.02063131279071733, 0.04543904583120058, 0.09828679008229126, 0.05786554354633536, 0.014552711546721478, 0.071066360800497, 0.04358728874414679, 0.09338936618258876, 0.037835021803696314, 0.028105751130609747, 0.0376170314848423, 0.01763739330213397, 0.03394812916315371, 0.017358832241546725, 0.02822649041791597, 0.06790149070683026, 0.10860134426864887, 0.038677450389631336, 0.0327216453790184, 0.03354720853930039, 0.04566830530342075, 0.05594282756529509, 0.015329009507812802, 0.03278160325041221, 0.06126669047760868, 0.025263287224656632, 0.04855349967857042, 0.028226706837754578, 0.028258857632716818, 0.05484722224214385, 0.04121693609763057, 0.013372429567689617, 0.022369307736235283, 0.024682008436009772, 0.10385715327556096, 0.03992811190865694, 0.07064050784514797, 0.060329508306759025, 0.04389162483294645, 0.006812558483122098, 0.016051027266639137, 0.05180201508224972, 0.035673313203357884, 0.030673945983571392, 0.02208845990319406, 0.047690926810666445, 0.04080127977255372, 0.06129112102151398, 0.06326216182881786, 0.13113657132752482, 0.037327431097266175, 0.038206482516421426, 0.055655506289293694, 0.05188618516249042, 0.06653907994228987, 0.028558861494304675, 0.07763508977668901, 0.06979434075014246, 0.023203761346878547, 0.0421503376245739, 0.035066284284356146, 0.027399052257439303, 0.05977281136438251, 0.04342407754231845, 0.0631606896528073, 0.06298183493556515, 0.04430887845134543, 0.04190192978468634, 0.06679429447338467, 0.02963491050796884, 0.03247414535332111, 0.0479783132041414, 0.06372297520659144, 0.05365939525466773, 0.018140433446293878, 0.02907558013835261, 0.12304293667717327, 0.2479822933673859, 1.119815724030618, 25.468020131511075, 66.83363406888901, 93.42204001642044, 115.90927846970098, 118.06763325968097, 117.86318363681917, 113.71562234817014, 108.70105251189202, 104.67471599578859, 109.84694942351311, 95.49673849536528, 113.95459667328866, 95.39680434811501, 98.04516515424176, 91.99973367875623, 69.52486638099917, 58.146192104585715, 40.49792681970904, 39.36948837772493, 38.382278796165224, 53.09524620732954, 38.54396673940843, 42.986164708291334, 55.95140241807508, 39.910218484940074, 52.67410916666831, 50.99749203651182, 45.228995584672504, 69.43791527901926, 65.00504470640614, 64.57109720476213, 52.85826444625855, 62.171806904577444, 87.89451829848751, 79.01081269787204, 75.93050479888916, 74.54329582952684, 86.56799624043127, 96.56054804402014, 120.14335155487062, 132.10304260253906, 139.97963259297035, 107.98622408220845, 131.02817981473862, 138.92371485310218, 137.37710860467726, 139.70257205347863, 134.11341421065794, 138.12905834567164, 115.99506855010988, 61.876781909696525, 7.790874435055641, 0.1806034201816205, 0.38589276733898353, 0.1422341822856857, 0.0551434301380669, 0.02561991455994787, 0.004048966201803377, 0.03716347295971167, 0.03248370996105575, 0.05878419021985704, 0.050783899552639455, 0.06289439365988778, 0.07874427783873775, 0.06216819210338497, 0.03060677347915067, 0.05392064272816624, 0.059380015102966185, 0.04772849576247316, 0.026394555855902935, 0.03797088749706745, 0.034438153473480095, 0.07196718826889992, 0.01992254164971171, 0.1061657822180179, 0.04444133888389315, 0.037481016404325926, 0.06777520111251263, 0.024580216418290814, 0.061956859088592955, 0.04865759953616127, 0.07300737479160871, 0.01600395690935153, 0.05986330166999852, 0.06264985456401784, 0.01968409295283979, 0.042304486006257996, 0.023367234933820945, 0.02787170743930244, 0.004813673252600336, 0.03156341619849686, 0.01565569142375382, 0.01870002237058455, 0.02223560432603042, 0.05857929617406861, 0.053516420265359264, 0.009801801004927727, 0.06383436439078181, 0.045341541990637786, 0.039824716851956425, 0.04820124862054664, 0.0800537978929858, 0.06212387391696535, 0.024196984764609127, 0.02675688863101025, 0.07430719617273539, 0.06203239535792701, 0.09323968792394285, 0.040777324203161464, 0.04346320165261146, 0.036437072220348546, 0.030222858091996565, 0.10650949522612557, 0.019151500967000763, 0.07953671152673422, 0.05339832015095219, 0.02444355782391804, 0.19600218582537868, 0.15429182398703792, 0.17225614148041896, 0.19646816646620152, 0.1514086980492838, 0.08598138022446826, 0.12222033444671862, 0.15740079264486992, 0.10671917349100114, 0.17094420058833015, 0.1147615185548221, 0.14516731844313685, 0.12555632560003188, 0.25499961278851957, 0.25770195729790196, 0.11717976701836433, 0.10557523568070705, 0.24303655230229904, 0.12725082015798939, 0.18223622933991496, 0.1443662662659922, 0.09896253325766134, 0.15150747742624054, 0.1880913474146397, 0.17819830246510046, 0.19900546499317695, 0.1937473132725685, 0.144112017005682, 0.17005569181374966, 0.367314093295605, 0.15327300365653732, 0.08801698309159087, 0.16443021625520723, 0.1626633723536807, 0.19905081739829433, 0.1627501547937432, 0.20735750876126752, 0.19992909123820646, 0.20184084833148988, 0.13243407912312016, 0.18220246018421266, 0.19234590863268222, 0.12307487488273652, 0.1675764627514347, 0.2532560732816496, 0.15862651800196018, 0.10821657660867899, 0.07996502362432019, 0.15399465848120952, 0.21311893428285278, 0.15228157863020897, 0.2607741843788855, 0.2459435648615322, 0.16937606457260349, 0.1358676392344698, 0.12013310491437874, 0.2944848722507877, 0.3906166493411987, 3.683176684764124, 37.745583980314194, 89.84544246427475, 115.77083449209891, 131.87058725664693, 133.28198156049174, 136.05122197058895, 128.6753225326538, 119.65620886894965, 104.89253305619764, 106.8005935607418, 88.19408539802798, 105.36206430004489, 71.18992820862802, 88.32334318468648, 87.49634281281503, 54.19032096862794, 59.22984492394232, 35.65290143412929, 47.651086622668856, 32.86960717170469, 44.26089971296249, 50.083509183699086, 44.30470082067674, 52.827524831218106, 36.827663067848455, 43.60529122814056, 52.17439920671525, 34.97190736955212, 72.80497981655982, 53.66465276287448, 62.103110513379505, 50.46482240000079, 72.41044429040724, 95.08587021981516, 78.71848629366967, 71.10818601423695, 59.6074632675417, 77.64785182091498, 92.19626795861029, 110.10966193291449, 130.7653182552707, 127.2612217933901, 105.64951912049325, 128.10059332078504, 144.1354465484619, 145.69695780354164, 150.63239774396345, 155.63356091899257, 152.58989580215948, 133.51704136017833, 79.50466263678767, 11.117255168576396, 0.5569646747842912, 0.504554485481593, 0.44660584820855054, 0.22900704624912432, 0.1547312673421637, 0.11426097202685573, 0.12569725513458252, 0.2920208883381659, 0.16214077781525352, 0.223228138601107, 0.185854600502118, 0.12388669825609654, 0.13175417609032125, 0.10214933644860022, 0.09907654246255275, 0.09991743121175997, 0.16024038946676641, 0.09050953442290907, 0.23722097968622563, 0.10739019756475765, 0.19715170075576152, 0.0842763519575519, 0.16485697319430692, 0.18680813481971142, 0.24235481065848183, 0.21521124297813063, 0.13376635198871936, 0.14988907072092258, 0.13584882411504948, 0.19347564317286017, 0.15020446911934884, 0.24747256910608662, 0.15097081751352356, 0.14129284408784684, 0.11265166644607821, 0.13773802757984208, 0.12617620564396345, 0.15833712062768399, 0.08380588204149278, 0.15047586342740446, 0.22154689736423955, 0.14878797254735424, 0.12138159840457863, 0.14720918790948007, 0.15724903062706994, 0.2251413052961711, 0.1669423104894738, 0.13181348661741904, 0.10320568742651133, 0.15597890281388838, 0.13139842018004388, 0.11475339802282472, 0.1869034668010089, 0.10340602707958992, 0.16448618663895517, 0.21692616144014945, 0.19785175190096904, 0.19004545384837737, 0.12231268634599064, 0.13180288396054698, 0.19764454043920965, 0.18157103519526221, 0.1245214174231214, 0.0680596035935225, 0.10279371598435026], [0.05876942004467692, 0.023991313139577548, 0.04064480248357981, 0.046454920553632324, 0.022766183415848403, 0.05056873992866567, 0.09129031591357724, 0.06929121250587125, 0.019959760116293065, 0.008960016890459003, 0.05001009712296148, 0.030816340661277215, 0.03263484761719743, 0.01640020535447665, 0.02386365416309526, 0.04564420800776251, 0.06551718759921289, 0.022140892875951626, 0.06656317340750849, 0.03749776691679032, 0.01785828134856157, 0.04687890425444611, 0.06401421502232552, 0.012438298341998411, 0.055774376322064674, 0.10096157074815805, 0.07176636598042904, 0.06997051032920999, 0.043607647530734546, 0.010996035360280546, 0.052138174463423996, 0.08465430143499568, 0.13428416613849903, 0.038981254047323624, 0.021395491240846536, 0.05448376714822747, 0.03947458019660365, 0.030587207593564546, 0.018685905285359874, 0.012210132460290147, 0.028649786554817713, 0.017432112381943775, 0.018283327996370294, 0.003912688017965505, 0.077911670499992, 0.05078555047211628, 0.05567912861043888, 0.051494001771413514, 0.054567642284617315, 0.07437103427946568, 0.06105212840221583, 0.010117235792530401, 0.04657886591890166, 0.16366615080304686, 0.09715626647155132, 0.39432810018620185, 6.492861634300602, 26.71054659351226, 65.63598932758455, 88.95494676405384, 87.75498390197755, 85.49966027659755, 84.56055072046097, 74.30838507990684, 88.90197907724689, 72.19363135676231, 61.6378781872411, 42.749637942160334, 24.602351073295843, 51.663883116937455, 35.33154949065178, 57.76615758096018, 33.80942667684248, 66.37570519601145, 85.12302644791143, 87.1605408576227, 136.52722512522053, 103.92988927902715, 126.04485557925318, 126.27531051635744, 100.79418966847082, 90.9762853191745, 119.68369683911725, 121.32254938925468, 80.82770947487124, 114.17217054674703, 151.2418399318572, 74.19357730496314, 75.41246952549105, 83.60949362477949, 69.68740940093994, 91.91854846092963, 95.60225025300058, 70.14875073586741, 53.88715313326929, 66.66350518503498, 58.05064708955827, 45.18623782742409, 49.898326243123705, 57.35414789568994, 41.60199949818273, 47.05143467072518, 41.792214839689194, 47.97900069144465, 54.85601386716289, 71.92061085854807, 92.85993299176617, 94.87573316020351, 104.8511520508797, 103.16121455161803, 99.88472538609659, 65.0765299027966, 19.964597455916866, 7.447581243130469, 2.0823723510388406, 0.054266757421916535, 0.2210976327619245, 0.04018460963702491, 0.11280782580856355, 0.03702336313924001, 0.0962236923195662, 0.06338288962480522, 0.034013177688804366, 0.01402077648127752, 0.022295299812310168, 0.0591840613032541, 0.08521075705967604, 0.08515011353959, 0.04794861580575666, 0.013753894431095932, 0.030268742928221345, 0.06919329880826897, 0.06165551074269799, 0.00440600818218363, 0.05547188650516253, 0.10084572293224836, 0.04273740995314814, 0.03217568515890068, 0.037522806500595425, 0.059413156066570556, 0.06336229335096094, 0.005468291074653427, 0.0409352379069934, 0.09378133506904687, 0.011982990263570702, 0.09108465961030415, 0.05924685369996775, 0.04808146311270614, 0.0570020973381977, 0.04923431435599924, 0.04221022654805453, 0.03801515205733238, 0.035485748066416675, 0.0205552440902759, 0.012399992030564577, 0.053067730228987434, 0.0411117943604627, 0.03245202456450751, 0.04881994122819555, 0.010672287561089523, 0.03368905737936016, 0.01797024701391497, 0.07570601909631684, 0.06076788679967004, 0.007376010884575907, 0.03748709148156547, 0.04845322259972173, 0.005649597273253266, 0.052456652535305875, 0.024084339196222927, 0.058791395276784904, 0.02251941691933861, 0.004918982092696693, 0.023001558184924147, 0.03928109703044738, 0.022361937970403704, 0.128284280428723, 0.026906526670040145, 0.04527683054367381, 0.018013992549611196, 0.03560796973385638, 0.06418517137306833, 0.025323804340235172, 0.07530889443812833, 0.013178047205832218, 0.04551057546069065, 0.12380807465242764, 0.03973833277761456, 0.0346384778048002, 0.043713176142304175, 0.015226329785711585, 0.02196680514081832, 0.012355345383947416, 0.0397408110720496, 0.06225549165279635, 0.005278815505951042, 0.08158083329157484, 0.04349895114559801, 0.040529073411298376, 0.05035889695488638, 0.05305825755180371, 0.0755113101894817, 0.08342957199220696, 0.053406344921959024, 0.016198785517424825, 0.03290562139403436, 0.03473525386183493, 0.13166858874742063, 0.04313004150566074, 0.036547553590348655, 0.029521634832264918, 0.03654577626636432, 0.029321082589787342, 0.030041103731961023, 0.03394183958129537, 0.08693789462408713, 0.048663046421302904, 0.02750332831525274, 0.021877904467645194, 0.043590330113206184, 0.08059129284154024, 0.04246467116078542, 0.07434892498197095, 0.0409755954188445, 0.021821533802956827, 0.052125518690914883, 0.05276953050446126, 0.09877953783518846, 0.0652537759273283, 0.17186880742590274, 0.12985299101039288, 0.3282656418460031, 6.357010833678707, 30.06567143624829, 80.61083378330355, 101.63129406590616, 104.07372259324598, 99.59867477416994, 101.44647982812698, 100.10586077167143, 113.70583995696038, 117.71456503099012, 103.09501278784968, 75.12445772847822, 55.93012355989026, 64.97851771693077, 43.496598428295506, 38.6380643998423, 29.29425301090364, 45.72859964063091, 39.184172076563684, 46.014591417004986, 50.701262873988, 67.10752533328149, 50.151413256122225, 60.500649713700824, 59.39916187717069, 50.41106239441903, 51.43198474760979, 53.707739999217374, 40.14431730393441, 57.82077266323952, 54.554360066690755, 43.3335925686744, 31.12083019748811, 43.872075157780806, 28.84618497663929, 60.29865157219672, 61.07846583089521, 36.60044016376619, 32.62211934212716, 34.30239016009916, 32.320238044185025, 41.781404787494296, 51.089659890820904, 69.522426666752, 55.998772882646136, 72.97146874089395, 82.28518378350043, 87.48847453824936, 93.22508212058776, 106.91768415512578, 124.5572574677006, 108.3845486179475, 121.70906759077504, 123.40481804263209, 121.59614255351406, 84.75764982161984, 27.699211374405895, 9.147801726095139, 2.7250720704755476, 0.07298957856912767, 0.15774540963672823, 0.0856771896923742, 0.11234029767013366, 0.006954670187100889, 0.1515886367809388, 0.11837526254596249, 0.13027564171821843, 0.010191516635278541, 0.05473623525411372, 0.1146597361132022, 0.0443370245216835, 0.026811261721436056, 0.052878897216531544, 0.05263005270652714, 0.03876757680348331, 0.01866806501282319, 0.026193384997426506, 0.028839186472337575, 0.02502061929854174, 0.05997683973081651, 0.04714782792894591, 0.030184863961391875, 0.04210236519875546, 0.10234478079984266, 0.09642694310675706, 0.017755271251043005, 0.022458003480888666, 0.0324373654720764, 0.055569884472436486, 0.021018685149629752, 0.03839364162676277, 0.018175529849324978, 0.056986396366189566, 0.0510389072399947, 0.06911108225223518, 0.026656923732990702, 0.024066744071822015, 0.05581382218928588, 0.01736661186441779, 0.04383128774803012, 0.051034605656299865, 0.03092069524310289, 0.0273620578715758, 0.10003069731136484, 0.02489983787639968, 0.03196012333876664, 0.06725521127302801, 0.01864708761023658, 0.019979739689358303, 0.029292430901419253, 0.03268535962448486, 0.029038417213145765, 0.048311913851648576, 0.008630390324059033, 0.08941984329853328, 0.04696453756262218, 0.025943927617082675, 0.024656241068676598, 0.0390887591657379, 0.018828870698569283, 0.30708698796168454, 0.12425921617015717, 0.09571779083700911, 0.14170529050452096, 0.11885252766190998, 0.1951046065697747, 0.17874597872216857, 0.18668906943451974, 0.0623434653595811, 0.0741281001377971, 0.19718594488597688, 0.12618264844340663, 0.16087256522188265, 0.1987437846800012, 0.14855400929527898, 0.13885250164856835, 0.09870624620347254, 0.14137141406536102, 0.2210391955750604, 0.11481630916316664, 0.1351414798128028, 0.12170888648758973, 0.16631485383597114, 0.17930908399003168, 0.15330053685653597, 0.20886507786570058, 0.11923456804886942, 0.18620655661629093, 0.1442428648231491, 0.10317439273480447, 0.1434520016153974, 0.2297785887194257, 0.2725971580272721, 0.2171239040551647, 0.11648982823375734, 0.17311443574726584, 0.13124362445406376, 0.17678162203200404, 0.09461388878163793, 0.20606488860662908, 0.15712935237153886, 0.13079160193522132, 0.07557836586549398, 0.09922746944451526, 0.19008797172817493, 0.16708970580610538, 0.1687649102701295, 0.14800018901305814, 0.16519187619128536, 0.2626403132753988, 0.10293944122930689, 0.22709731162796098, 0.15073363669216633, 0.5541997102479781, 0.16118166637757134, 1.124052006390787, 12.86276480843944, 45.00371033145536, 103.10241037799467, 120.3928299873106, 112.84385204315187, 106.40068438745315, 106.18278887964065, 97.0353352638983, 109.81977524295931, 90.51230815149124, 83.8473226178077, 63.244861479728456, 41.65593993279242, 73.37087585080054, 46.675624539775235, 76.72711464666551, 44.85452298195132, 93.78540054444345, 123.22529115984518, 126.04931923650928, 205.46871739049112, 156.0725368991975, 185.0592290201495, 191.72128062094413, 150.17798331476027, 136.2835047321935, 173.14035415649417, 180.14074940835278, 123.46424195074268, 165.79530808233446, 210.4056949000205, 105.01265956509499, 111.26732595505254, 123.99106333332678, 103.87055166306035, 128.11412549787954, 141.74276936438778, 103.26336876038583, 82.5268723887782, 90.95699510266705, 79.9401790865006, 63.44664781324325, 67.56569739310973, 73.97801952977335, 56.32932278417773, 68.41814610265916, 58.18483921789355, 68.38773988908338, 72.40820069466868, 93.71526856576243, 119.19358884134601, 121.42789640734274, 132.52661151270715, 134.8618651974586, 139.25302136328915, 104.87314870280605, 39.10721909615302, 13.434805235555096, 4.665455847017227, 0.17670579464925876, 0.3878990596821232, 0.24572925942559398, 0.21636219815381114, 0.19327676674771696, 0.31974999234080315, 0.33323543807191236, 0.2392162863285311, 0.05340841335935458, 0.1482601532892835, 0.3851567407048518, 0.1091163621975049, 0.2048476821472568, 0.10838273341857618, 0.10768823641081972, 0.13830372222488926, 0.16584059944556606, 0.09722945851183708, 0.10446707417647685, 0.13668218988084024, 0.15326762571930885, 0.12525088634462128, 0.2338725012997466, 0.15565855548747126, 0.2596017940630836, 0.27703418606711977, 0.07897113945575492, 0.11803926404325232, 0.18192862971655785, 0.149268401606429, 0.14727281917247081, 0.1813240484484742, 0.16159130891244258, 0.14777992341306903, 0.2283052177799325, 0.1820909790694714, 0.12281538558102424, 0.11666726185789994, 0.08600761107499562, 0.13293252657017401, 0.18457292008303827, 0.13468650019457265, 0.14450567894645278, 0.1251872320989928, 0.1441586717602707, 0.1471775331564488, 0.126906547905697, 0.16181978697498, 0.09596064836988527, 0.09992371313273908, 0.10246505660395469, 0.17342673915047802, 0.11887059201516452, 0.17762559045466686, 0.09705055399887985, 0.15898216665992815, 0.0636521848519483, 0.04133137048131997, 0.08194296305338222, 0.1396454486154741, 0.12952951804524468], [0.05021687191460402, 0.02182930959538827, 0.02044023131020367, 0.07002121768891811, 0.03758557974511097, 0.02657487188586064, 0.012019023209089234, 0.01863195162807261, 0.09231033134123973, 0.02065971741572984, 0.039462912677516865, 0.023084722774764223, 0.06579307118250478, 0.05544825269269848, 0.008198484316498281, 0.02976568554708314, 0.07021071719786814, 0.042375245717384165, 0.05005489411433378, 0.04548239108595637, 0.02338246476175564, 0.02723035586607312, 0.04066727567283858, 0.057206646644420205, 0.0361412588597065, 0.013997675099920844, 0.06403135240919168, 0.0764791397077422, 0.019028834968564973, 0.03985626818311792, 0.057786161515621416, 0.017987242674515132, 0.041309785954053366, 0.003374278791353948, 0.04077614442775807, 0.05171897881213696, 0.06536632956516358, 0.013756499130038485, 0.031861324809611805, 0.029308940096187498, 0.03857040875441125, 0.02503295905978209, 0.027885403176168763, 0.039932528405540416, 0.033847017048467556, 0.062259218670547976, 0.13465976372601526, 0.05775641049108198, 0.12165834000634572, 0.02393947196974149, 0.06477546127092454, 0.24622551586118438, 0.7483018141600394, 6.012881196314289, 20.568091369444325, 56.841529415499785, 81.35244415652367, 84.6288234956803, 87.01405602116739, 69.36579073629072, 87.8653907775879, 83.3550573164417, 60.10674568914599, 59.65029162745322, 40.750064619125865, 27.244900888012303, 18.76291855689018, 45.615509863822695, 72.8082275390625, 71.530821400304, 96.38522594205796, 136.4505192541307, 103.55079220187281, 89.04081529186618, 88.17525017646052, 60.27021046607726, 49.60073994052026, 37.06409177472515, 47.587818791789395, 37.31869674498035, 35.78237887351744, 48.44250325233706, 49.62748658272528, 47.6044378742095, 53.36886290580996, 54.693953298753314, 75.65054170546993, 71.05113906245079, 73.51275582467356, 63.852122829806426, 77.84917923711961, 67.78451858028289, 75.58778378271288, 85.3058167426817, 93.66962002169703, 114.68061954744401, 106.88836836045789, 102.60210421777542, 125.96126202614077, 90.58302064095774, 85.84449152792655, 53.95264887040662, 57.324263357347064, 44.7187501384366, 50.80593132203626, 33.849383861787864, 47.534925630015714, 74.531599321673, 57.61175347912697, 98.88263040973295, 87.90765039382443, 97.28322905878868, 99.29247886903825, 94.36196542555287, 94.56444601858817, 42.15685798275856, 8.8169046948033, 0.3057887447216819, 0.2155078109353781, 0.32445101427935785, 0.34112525503000907, 0.017951439555373885, 0.03146639690854617, 0.05249643931165338, 0.033086701596696536, 0.06719808409651441, 0.02428737547879498, 0.01770870842700524, 0.04924880107864738, 0.04445235139780468, 0.08272510051967637, 0.03376182807128757, 0.03691829418042495, 0.09187414385979215, 0.044630348096571626, 0.011328327912657012, 0.05854540444429844, 0.0480782340521053, 0.04228222732161803, 0.026742128031929175, 0.024072945553569064, 0.021726581035181883, 0.04930455312733689, 0.055649170742159894, 0.018412036513308846, 0.060509247855553706, 0.041839240809842464, 0.055628551485677885, 0.0054360622344839, 0.0466877231825023, 0.03753802866765088, 0.02400650466311603, 0.04947765452426769, 0.05358454080358629, 0.023554723461969726, 0.03979488921862456, 0.03730316143182497, 0.011884263555158772, 0.05303871081841569, 0.06206160246004021, 0.040102278167802485, 0.0059161206985253005, 0.025330976838426247, 0.03650121676224855, 0.053307979232481414, 0.061472963481660814, 0.03653562943180723, 0.04863541746031373, 0.03173905143123721, 0.013733853570996754, 0.012372843789747887, 0.06642895480317455, 0.06866392439171191, 0.04986796866080934, 0.030462643612296354, 0.021232105754015428, 0.008021646804521762, 0.021877776147917877, 0.010753647056258014, 0.01589056632045897, 0.08235545543533179, 0.05296153129048405, 0.007752964926523067, 0.028260949052750107, 0.03614341539721336, 0.015252052145379206, 0.03566988495989673, 0.006821275127285551, 0.04910776429178734, 0.0899481222093586, 0.10424801133452885, 0.05741970335704185, 0.04664599437326674, 0.06756904685208875, 0.05864153315703716, 0.007137980184427673, 0.01533997509883897, 0.05486563516540393, 0.12960483980995993, 0.06763614083249724, 0.09065662330437092, 0.04291909536527049, 0.022999204379776796, 0.06559594143782893, 0.017494086979798252, 0.041993649661420815, 0.02887748703811198, 0.04930007917385909, 0.06974210887546502, 0.042986070602050716, 0.06935603886602387, 0.1041010450271349, 0.03328726341527316, 0.06800316589614076, 0.05720185476445383, 0.057979660003536174, 0.013753160901908434, 0.04310805095179428, 0.023060723155316327, 0.04867556812842527, 0.016504420125256145, 0.012313645303009019, 0.1070925570844162, 0.08117961006299143, 0.1334965051782708, 0.05680666830871375, 0.060244120146718726, 0.23648556592243336, 0.3811746463179589, 4.46411568310953, 22.184125531104304, 66.7749632558515, 99.5493313574022, 105.08080682446881, 104.58305020486156, 97.94461127250426, 119.19606777929492, 108.17827901532574, 90.88781233756774, 83.4651739366593, 70.3500153941493, 43.18898654753163, 22.497534674982873, 28.305617647786296, 37.75518202012585, 50.94068827167634, 71.69520793422576, 109.17911883323424, 84.12504996022871, 85.17027531900715, 88.8365068743306, 70.97691212930988, 60.24826088259297, 44.55554816030687, 54.624421442708666, 47.895964114896714, 43.522909687411406, 47.761466041688, 52.95143250496157, 55.578263421212476, 55.22783887001776, 61.517602628277196, 72.16943033279912, 72.33483668296569, 71.21273286880987, 63.0807573564591, 67.59815892865582, 74.57842457679011, 82.97353621452086, 84.922773761134, 86.76074151069888, 90.3728678918654, 97.66966096816525, 78.47093766735446, 90.37655491982737, 69.9360719803841, 59.45391816477622, 39.0906157032136, 28.022548037190592, 33.85403187044206, 48.867091978749926, 56.84807977368755, 77.49788391974666, 122.85111273488691, 95.25126088050105, 123.87111725345736, 111.03749859717585, 110.18244543383199, 122.71598708245062, 114.3915722447057, 114.61594750804286, 51.532573930678836, 11.392790886663622, 0.7687578939141766, 0.06783356169058431, 0.5795184258491762, 0.3474302505773883, 0.07161530876351942, 0.09437941991153265, 0.013385670439850901, 0.04907238252100445, 0.039785745959248275, 0.05863677192058775, 0.04310309053248456, 0.04061211734229038, 0.030129565819797498, 0.08275156119658102, 0.02368108583464017, 0.043765603369402314, 0.05427618796426443, 0.03821187960584799, 0.02398990162257706, 0.08058348640559182, 0.11335027734598807, 0.05065012144886198, 0.048199172522271835, 0.07603735978444738, 0.04335290031327356, 0.05968683714708013, 0.015789319182776155, 0.07890635906087776, 0.017480690017222397, 0.0361417414950988, 0.028093863361244722, 0.020743280371290543, 0.05869571855592151, 0.03280819799270361, 0.007404817705748664, 0.06228076489341836, 0.04705561775593989, 0.058127449855448744, 0.05502148426227993, 0.06635321169010093, 0.004229929097252148, 0.027519747494689883, 0.05877127397745367, 0.023167831823229793, 0.024450305143311143, 0.08202591505382331, 0.057090346836635185, 0.05481745589584593, 0.08577832095925847, 0.03942262028313933, 0.019760138670643492, 0.04863899509092012, 0.03911608552199699, 0.020868462968557593, 0.014408244601180478, 0.019917657839194424, 0.10918914055031155, 0.0637759999822705, 0.06747780578030695, 0.12699462503435152, 0.12282169048464107, 0.13169034564447019, 0.17741692342585136, 0.1780183024464115, 0.12208996926464381, 0.13941755277975915, 0.1603945570006486, 0.1842242275034228, 0.11333457254354032, 0.1182452574252121, 0.08457614514496058, 0.0839385761308574, 0.29429515823721886, 0.1722172242138655, 0.1572422430880608, 0.13243570322951964, 0.13029381332378234, 0.1789731544352347, 0.07034545674199058, 0.1327274754763611, 0.1988901994040897, 0.25251278413399575, 0.22158098827687003, 0.19341775756930152, 0.06997401135102396, 0.17292066146769833, 0.14782625641072952, 0.22350889450359732, 0.13876913596064816, 0.13566183737449108, 0.15203987789009848, 0.14339636831033614, 0.14875621054201357, 0.16483513968846492, 0.18365030507406882, 0.28851658766788824, 0.1016432511049413, 0.1821172558852742, 0.2082278306085256, 0.13723331353356763, 0.2308148605328414, 0.15942283575573277, 0.14449132245875176, 0.14469084239775135, 0.18030974803672684, 0.34756146611705907, 0.15750773851909947, 0.2488972015318371, 0.18302677079073845, 0.31217065549665884, 0.31615734641109744, 1.1784824921238808, 12.003793197293437, 37.98120075656522, 91.40922084931405, 116.26921869093373, 116.92548613394462, 109.43817569363503, 92.15818174423711, 110.93388526670395, 110.03122237420853, 79.97038918156778, 74.36809139866983, 57.08988212770032, 36.381301264609064, 26.302594600185273, 64.38065044341549, 101.4045104672832, 103.0593349087623, 136.32338739210562, 199.73007017566314, 158.0884155150383, 138.9208593676167, 142.78371933967838, 94.06191195211103, 77.38523344839774, 56.007460932577814, 74.77160130777668, 64.08916342643, 58.28215714423888, 71.36732916678153, 76.91999327751898, 77.05476591663977, 86.34543311211371, 90.00508293028801, 119.31360552387854, 107.56435748069518, 119.51304235766013, 102.75363322227233, 124.42802321526312, 102.8247065697947, 119.80837329741448, 128.63353360083798, 145.62343689703172, 178.40889746142975, 160.64478105114353, 156.88446752486692, 184.71547249824772, 133.5022932483304, 135.43790448096493, 82.243449764867, 83.44076110470681, 61.07364131558327, 66.6856195080665, 49.236653774015366, 67.03464769547986, 97.63338688881167, 78.12170551669213, 127.09794921259727, 112.35381464804374, 119.39091543997489, 133.08821647397934, 132.25424212794152, 133.2719873612927, 66.1324005742227, 15.20214972957488, 1.5087025468387913, 0.1691058193964343, 0.7845617362087773, 0.44956294759627313, 0.12728517920139337, 0.22921698498389415, 0.18384967179548356, 0.200323503945143, 0.23380418157865926, 0.20644981714506305, 0.13430436021618306, 0.19958847322531287, 0.1964083503210737, 0.17020288794752092, 0.1439678699018494, 0.14260962665561708, 0.21739166710645924, 0.23507861480597528, 0.08495964875985539, 0.10558656612110716, 0.24028242024923527, 0.15408899454820543, 0.12038491801508974, 0.16190109954726312, 0.11816070430100926, 0.136718119404489, 0.10489895624378998, 0.15921930151600994, 0.17215458886517634, 0.1657761408076171, 0.20601656378036548, 0.1257956284849394, 0.1493020788315804, 0.12288254084846667, 0.1357035585228474, 0.0907881299574529, 0.14940741592116896, 0.14061588283267715, 0.16332812216733733, 0.2633304052775906, 0.1317563364582677, 0.1409797439531934, 0.2858269448962904, 0.09224346718720852, 0.06994471614879948, 0.12346701996941721, 0.13966123002671427, 0.09336339580195566, 0.20971437826031641, 0.07455412929336871, 0.17507946659480372, 0.150342196406376, 0.1098723607438226, 0.10529278672390407, 0.12849903019565728, 0.15327986780433886, 0.21385526735215418, 0.20549753921166544, 0.160948300674077], [0.027027227652950153, 0.0090512206154545, 0.02455262193125823, 0.050849564779069156, 0.0412076166380317, 0.022359289221405503, 0.023102997802197937, 0.04251349777463944, 0.03206965284452083, 0.04973079295708768, 0.06972861806711844, 0.12168855451407934, 0.043840139893995184, 0.019100322463219205, 0.11270441159966493, 0.03871977291700821, 0.05343643685562476, 0.037993038929398024, 0.015705432555067445, 0.009770831900588688, 0.017292919951761444, 0.015745877209419928, 0.040125394870917645, 0.07641242877129586, 0.03651764168734512, 0.03635136996425929, 0.06487838518355163, 0.04257771126445263, 0.03822483032220795, 0.036233147275784326, 0.03364506861074798, 0.04528145388429684, 0.018860797412813674, 0.047249901483977036, 0.0698369275778532, 0.026249399431230083, 0.021688274723748048, 0.03199868820487492, 0.09341240244647188, 0.05815663780536383, 0.02420507082264991, 0.03673268639813027, 0.025405591887031353, 0.04114452163658796, 0.07626489555883793, 0.024575721397395098, 0.18611559133616187, 0.06528689390829494, 0.09598924643209866, 0.06949792601047985, 1.4053401254838513, 12.369982734803232, 42.491165514915224, 71.96513760474421, 93.25595117384388, 81.31162797251056, 81.88265446693667, 74.30388219894903, 71.90258364523612, 46.88720110924014, 32.295938960967526, 30.574173388942597, 38.283348775679066, 55.70951769428869, 49.30665239211052, 89.02296850758215, 103.08805450316399, 124.1314841854957, 101.15993499755861, 61.960595115538574, 36.92543991150395, 16.676562793793217, 11.392486902975268, 4.492733786183019, 0.9370987898399754, 0.5186087361747219, 0.7127041598000835, 0.45553334658184363, 1.171042001055133, 1.3092940276668918, 0.5345881658215677, 1.4038400640410762, 1.2584127966434726, 1.1590737464927858, 1.197781288816083, 0.5826259849052275, 1.1134602586107871, 1.3610088849259963, 2.2789919424441556, 1.350548291398633, 1.0896930242738416, 0.8738758823563977, 0.660381457738338, 0.891794617618284, 2.403233507948537, 2.4067530997337836, 2.816508157599357, 10.392582570352863, 17.78375179536881, 33.78710446819183, 66.17757058912709, 84.58017826080322, 129.9241973507789, 130.59388714451944, 115.42037071720247, 80.41696671516665, 52.604353735523844, 29.391737637981294, 33.993617257764264, 49.11654295459871, 67.26608322512719, 92.85639501387074, 89.81285541288315, 83.36427488634664, 84.36791527655818, 103.97256466650195, 98.15904724982478, 62.36007282810827, 36.75780173270933, 15.592095102033309, 4.114379998176329, 0.059251883067190654, 0.22233373094950953, 0.13293474822515441, 0.023922907233598734, 0.03359176804341617, 0.018594798278964816, 0.015079954323629218, 0.06300603565309318, 0.028937916053579222, 0.032622835358544704, 0.06210957871629827, 0.07062081172461472, 0.09282344937204354, 0.030595872047988158, 0.040403017473797646, 0.04526962165630633, 0.04950851637629732, 0.02596533211368707, 0.021959550288175384, 0.026142848092281533, 0.02312753176797302, 0.03071392428189997, 0.026007641234525272, 0.044985460492992596, 0.0375463713651463, 0.03450083861788435, 0.07346410109030624, 0.011077506895807963, 0.02164449854453485, 0.022885357968569286, 0.046431286741168275, 0.0660266513906179, 0.017143789445981383, 0.01966182660732058, 0.007494708068758971, 0.03484837057429456, 0.027767004287471215, 0.020727981595442663, 0.07194413668325833, 0.03501446226671819, 0.018485981234980207, 0.03874112761789753, 0.02331583809498097, 0.03343359386968998, 0.031190760388609864, 0.1038154244663254, 0.054297083012399175, 0.01241607700414475, 0.04770887242029271, 0.03530328124461155, 0.07346698924178079, 0.03949649797211732, 0.012831229626411393, 0.08006213292960199, 0.017846805351455847, 0.015841613302097445, 0.029644138037016796, 0.011362215811987559, 0.05233107540275782, 0.05008341173731512, 0.05197002965536329, 0.03763111218089058, 0.01921991836429844, 0.04185552783911267, 0.038837532122288985, 0.014731342183245767, 0.10456052158148059, 0.031296848244364225, 0.011793988711771466, 0.01713711107450147, 0.02309356534463023, 0.032202007939978954, 0.024984469524614757, 0.0283301210466532, 0.007184999788390293, 0.02636413833486938, 0.04759470999781643, 0.05132204950636914, 0.09361619715608897, 0.05986766071028768, 0.03372058955832355, 0.027273544072804433, 0.04821712962321697, 0.08544446750273628, 0.012146943613075683, 0.011135864601049934, 0.09427271152455961, 0.025888979960713657, 0.040595933734889955, 0.04971410373165723, 0.05300139850606361, 0.02220441305619334, 0.023698119799636548, 0.041835326100549394, 0.03941480235587205, 0.018357512120517994, 0.035262081036043745, 0.03983621583169988, 0.04136406711392826, 0.10441426007497696, 0.026764170296730536, 0.13756214911418577, 0.07219097021246149, 0.11024018253890738, 0.018114348152472128, 0.5619325404686313, 10.115861315881054, 44.88909475265011, 84.8720496700656, 106.39012536694928, 93.68174799026983, 92.32262319134128, 93.31515542922482, 110.88289445446385, 73.15351378533148, 62.67352119568856, 57.01019917764972, 42.38857984542847, 54.236216622014204, 26.660167671019032, 33.23834526923395, 49.803357816511586, 105.23417149820636, 101.00639773953347, 62.127484121630275, 47.41132782351586, 20.748918517943352, 14.351359202015786, 5.33819773504811, 0.6689221736404204, 0.15860424016512212, 0.4309610457670304, 0.6101573462928496, 1.1595082715634377, 1.6156519757163141, 0.8275859081937421, 1.3858975494100203, 1.1807153013444718, 1.2629730422650616, 0.8347026811492059, 0.7292975016659307, 0.9681162190052771, 0.9051700224799495, 1.4918807269104066, 1.2469136330389208, 0.5708009581412039, 0.7899472730294351, 0.19678128192261343, 0.17271686675808123, 2.187024619310133, 2.1779646796564904, 2.1503551160135577, 10.672486828219506, 20.075365189583074, 38.45284615793536, 70.17204961469098, 77.08356395844491, 103.07621678998395, 95.50024509429933, 71.74778338401549, 29.816043953741755, 36.058450975725734, 31.91731256823386, 44.61121051542221, 92.66290449327039, 102.35558325244536, 128.11565522224674, 110.1388914354386, 102.7171394901891, 93.06958367747646, 124.56134457742016, 116.84273981278943, 77.56291681720366, 45.58397793000745, 22.497197351148053, 6.232109819689105, 0.02398943239372344, 0.3123404205806794, 0.08809822671596082, 0.006734002869756472, 0.058141610990729065, 0.02741458469010409, 0.0767057178722274, 0.024648727661359216, 0.10286886920972217, 0.0058859540712869465, 0.012595836662747448, 0.044686398919551604, 0.044586186958176476, 0.056917965562353214, 0.054700684943987485, 0.034407038812435446, 0.02208715372328316, 0.07419591424085441, 0.02363876905292273, 0.03642871420109465, 0.09377584987950903, 0.09660969338109417, 0.03899968612278181, 0.05470069260486672, 0.03308158412936234, 0.03656238505256273, 0.009795532490487301, 0.02019595842988741, 0.01299101258477857, 0.015767975973205704, 0.01075164182111621, 0.033279813210209536, 0.05714810603568631, 0.05126733550681703, 0.03727117343054664, 0.05811693912912762, 0.051086891157132004, 0.015509708581732647, 0.03638922619903761, 0.0312702305194351, 0.055514247336935614, 0.03964199339069667, 0.09108965450357046, 0.018170952473977403, 0.02268477891301436, 0.10877411241733259, 0.05476571048700041, 0.04117480892267439, 0.015682431722750828, 0.06896855925480205, 0.04317886428907514, 0.016706062127806006, 0.004719734593715158, 0.10380933406732737, 0.01097325669346197, 0.08998369933256219, 0.13535984551473973, 0.12707862657524888, 0.19742585298034454, 0.17644409901432453, 0.1162994477236944, 0.1722701302459163, 0.15504962283997767, 0.1176302343787205, 0.30514449542087896, 0.14959084801375866, 0.20941379600234572, 0.1425836103097085, 0.08834931969402299, 0.1977339275782147, 0.1301285375149981, 0.17377072795023843, 0.1293977815657854, 0.11768392182045406, 0.1272023880794164, 0.14995616470133105, 0.12442198687142904, 0.1277907282835053, 0.2836435330250571, 0.17396215800075762, 0.14938578159818727, 0.15110972457595412, 0.17138808725341675, 0.16134665107294438, 0.13307953884284343, 0.10769575939423616, 0.27092157051928584, 0.14844007669918, 0.1646043173968792, 0.20862245782008096, 0.1252372040142936, 0.11708079611942654, 0.19282108232859643, 0.1588660583741242, 0.17571729607880118, 0.207910654886115, 0.14885312066443507, 0.1720504009074742, 0.10703133133750771, 0.21713761702900936, 0.14505602118949737, 0.22378468615633829, 0.1587659766476962, 0.22471827154438342, 0.13541869638908294, 2.609861762292924, 20.123592692036784, 66.77711271470594, 105.81866741180421, 123.93103538020965, 102.95033224167364, 100.0760115346601, 96.00843521856494, 94.80572669736802, 65.43622693707867, 41.26005118893039, 42.597540193988436, 57.62428152945734, 79.60996258643367, 68.59260528318345, 132.17632816683863, 147.0786205414803, 174.03336801836568, 156.60801887512207, 94.00869323361306, 59.55836696009482, 24.741471659752634, 19.54403112011571, 7.174835801124574, 0.8911385399199302, 0.7303196468180226, 0.8188274394600623, 0.8159712798172428, 1.4188054997113444, 2.273700665081701, 1.2238304845748411, 1.7893895627029481, 1.3344476972856831, 1.856140948591694, 1.3966150581836703, 0.9008516154942975, 1.5968201862227533, 1.5186393813740824, 2.69312632660712, 1.8429197419074275, 1.3349644695558858, 1.153667984950927, 0.826687440276146, 1.1191304124170736, 3.73252181756881, 3.8326055051818972, 5.115546843697948, 18.95370460325672, 28.200949199738044, 53.193179945791925, 100.21156864781534, 132.3806836528163, 202.5700701436689, 186.71509681209443, 163.42100328014743, 115.27891435930806, 77.57362488777407, 44.514602538078066, 49.514734129751886, 62.23272915809386, 86.95729148003363, 121.4997777631206, 110.56007554454189, 104.95208248015373, 102.34362002341979, 131.8412793067194, 134.19907877522132, 91.89426114482265, 57.825840365502145, 30.312419899048347, 9.127973164281538, 0.1462203675820943, 0.6042852517097228, 0.21608937892221639, 0.1336796461574493, 0.10349248776272421, 0.1787443392940106, 0.17681336871558623, 0.1396889930530902, 0.15648311124213282, 0.0931926271427543, 0.20215437747538093, 0.1433952651437252, 0.1549835707391462, 0.1185299510196332, 0.19247922325326552, 0.13994169481579335, 0.10183864183002904, 0.21775597255797158, 0.08177133637570566, 0.17502438487304797, 0.11296597699965201, 0.182216479593227, 0.1905909850592575, 0.10641872912885682, 0.1415814294089233, 0.10825879571418609, 0.19016540789556122, 0.17271525797344026, 0.09925072021301716, 0.1474585342070749, 0.17291191274360304, 0.1590070491957088, 0.14306164917445954, 0.13207706682864698, 0.15333983716705155, 0.12802769460024374, 0.12381881520512605, 0.13622518779048998, 0.19218662363146582, 0.12658521232585754, 0.20819043019606223, 0.09827957353404454, 0.2541472020769312, 0.06241516352841451, 0.1081687037742907, 0.24363338076058896, 0.17885323103156783, 0.10188300598172412, 0.2157135055430474, 0.129513215694216, 0.2831475677028779, 0.07847296013947457, 0.10242207907140256, 0.21102670219636735, 0.11790270887074933], [0.0823624728007182, 0.027910176544420184, 0.04481525107797596, 0.024731509207237153, 0.05583773179340267, 0.02968011352594101, 0.04330062247332066, 0.05585046034426459, 0.019643972928245223, 0.05822547463580005, 0.020024303023913698, 0.0655642407195222, 0.06313017254034359, 0.046938559521109834, 0.013183988217685013, 0.040297653571131735, 0.0577624281117272, 0.07954134635867612, 0.027650484229407968, 0.031824305525890766, 0.03817729839694597, 0.03163656418872697, 0.08110471730751377, 0.07138028064922941, 0.0677910361499075, 0.026475041053227844, 0.07275753053686312, 0.053423329091240326, 0.021408911186060118, 0.06481247097854653, 0.07609876173157847, 0.04675874719396234, 0.03782245030085887, 0.03411178086553851, 0.024533015826056083, 0.0737529392203977, 0.019357205150769125, 0.05970897708809184, 0.07264337577526608, 0.004063985834363848, 0.02680143472858735, 0.009568874844379965, 0.026994040724070325, 0.045910986636074326, 0.053823502779367476, 0.06120691646731669, 0.1088467222307959, 0.0862062117084861, 0.2682778010925939, 8.635408782189893, 54.15620419286913, 61.257329833122995, 75.84169449344759, 59.394074563057195, 66.68681190859887, 76.80484033400013, 66.34091377258301, 52.29017188472133, 29.95811612375321, 52.12349468661893, 63.15010878347582, 46.05967513976559, 54.570257432999156, 64.26701153478315, 86.79244210643154, 74.2070153451735, 44.488271667111306, 11.663687421429543, 3.342329090641391, 1.1128825670288456, 0.47308169365409886, 0.1566323911350581, 0.4080213702494099, 0.2512357155642202, 0.1858964442245422, 0.18148955408363573, 0.34877194632445613, 0.19137480025810583, 0.5245973374093733, 0.5450936827448107, 0.34884751323730717, 0.629673099085208, 0.5025565894621035, 0.3845333596391063, 0.34189351864399453, 0.3412492693431916, 0.6723710401884971, 0.6393205975332569, 0.9142690019742136, 0.452058831410062, 0.5548018553564625, 0.4046298070780693, 0.37186557487134014, 0.23143298623542632, 0.060887312246186126, 0.049668410417413524, 0.09584575816388093, 0.5420240603627697, 0.611757121739849, 0.8057405739541977, 0.49982187007704093, 1.5967602475035576, 4.829192738379202, 19.456609333715132, 49.72209022891138, 92.77108346262287, 92.11944441641532, 107.65019462954615, 65.0040994151946, 35.31017649558283, 36.12791615147745, 33.9948881057001, 70.02609822057909, 72.43641038094798, 95.11387594284551, 74.8619491823258, 83.42791926476264, 84.4548506890574, 93.24464690300726, 89.27047791019564, 79.52769479443951, 37.41012719369704, 4.10410633010249, 0.3164127601250526, 0.02474941268202759, 0.0244859492992081, 0.09200921282172204, 0.07881860368915143, 0.09659075568760596, 0.03292928585001538, 0.02368804765865207, 0.05247373629601733, 0.01914791759073494, 0.06812691207854979, 0.03219558812317348, 0.03625399635864362, 0.07600967336686389, 0.022336457886042136, 0.019751945360293312, 0.022702148041477608, 0.043091204678339344, 0.018220127657836965, 0.09649415966123344, 0.034630610081817836, 0.03248308176895784, 0.06862100814619372, 0.014876434448054962, 0.03368480559138041, 0.031030751434305025, 0.020557846873998642, 0.0529816564202549, 0.05651351327316896, 0.04797698787203239, 0.0511797946397095, 0.05502400086111119, 0.06500196282661731, 0.016281536419785792, 0.044919266665895144, 0.0180913808365022, 0.03917377960357455, 0.027353606006551175, 0.02900821802717063, 0.016759370356017066, 0.04172665652849021, 0.034885759495439074, 0.03668500891616268, 0.03697560138760075, 0.0163118735015873, 0.012910546539651771, 0.03360763372432801, 0.07695979093231502, 0.03919609574480884, 0.05390008858915779, 0.021200083278780504, 0.036881744125557524, 0.03629119375780706, 0.05261882185755719, 0.016356521105814367, 0.015912356733855222, 0.07690945129481054, 0.01789256952883255, 0.04067595927946029, 0.03368020140295548, 0.016138310536682125, 0.03944025945759589, 0.021027240436524156, 0.052431988334583665, 0.04100958674004482, 0.02412116121230347, 0.0696670092762478, 0.033037901795919866, 0.024508265440442392, 0.03583846643807427, 0.08123716624874262, 0.08389123189713686, 0.06324485973304798, 0.0451998885029987, 0.07852735238209849, 0.02227902810479845, 0.012453260996769513, 0.014146038560166716, 0.04466334733391001, 0.029675760231311285, 0.049885469939439535, 0.024610789072129036, 0.049081249988727996, 0.04853662659203814, 0.06531862527011864, 0.013012350048689593, 0.009006610358013742, 0.02335050931921409, 0.05429690298173697, 0.042452819780596805, 0.05142899155015907, 0.04310921540543918, 0.06992967018196661, 0.006615960690748668, 0.024407086293062857, 0.07122382251245361, 0.08034972233637687, 0.04148012943445675, 0.11595439406171923, 0.09569821729054374, 0.10374875183427527, 0.18018515149672187, 8.230170088429606, 58.58256755336639, 73.49865882627427, 96.92540691744898, 69.52081849498134, 89.45149529364802, 109.2675055226972, 111.97000288194226, 91.58491949881278, 55.16350807682161, 47.482832631757184, 25.930371476757912, 27.373587969810735, 36.37240140668808, 46.71178879276399, 81.95741484242102, 76.44686129785354, 54.248395581399244, 17.203146872981904, 3.102131476325374, 0.9774001627679795, 0.6478906086375636, 0.42716324149120244, 0.6623777602949451, 0.2331625522985574, 0.3088123098977151, 0.024889715939700126, 0.3670341647680729, 0.19313732342373943, 0.5784122561735492, 0.590333993877134, 0.5742887419558341, 0.5826172208593738, 0.46084763722554334, 0.3788105296271463, 0.18083643348466966, 0.324431708863666, 0.7594931942801323, 0.35555734028739316, 0.6541117328789927, 0.37408909910628874, 0.3137593379905147, 0.3831300397794093, 0.16617899580347925, 0.0957046677508662, 0.018686947164936893, 0.03199891037037296, 0.03970833660493936, 0.4859687327857941, 1.0022657833272413, 0.9652767294356901, 0.38050579027302806, 1.366516750666403, 4.872910005431022, 25.588852667039443, 55.957435023400095, 92.77014209378152, 82.2071050828503, 65.65262409948534, 39.80445569561374, 14.751399774705211, 42.05466847265921, 60.39371805806314, 110.26599976324268, 109.80758451646375, 128.1766402336859, 95.94940354747158, 94.27093505859376, 102.79785402359502, 110.83610842304846, 110.86116452370922, 96.5066703673332, 50.69473997239144, 7.090534260196071, 0.18027752637863162, 0.04037967477474482, 0.015118554621303995, 0.08432038669143954, 0.025258598766560038, 0.013711446456821456, 0.02029182475751206, 0.10628880827777809, 0.05365209060630972, 0.05913598545556588, 0.0016386630276458399, 0.03756307591233523, 0.07682520460577742, 0.0622705337891896, 0.03982584683164474, 0.025311774844604156, 0.02016227737429642, 0.014162235574105815, 0.03656530001711461, 0.038187648244802995, 0.040001652518948244, 0.01326448586393869, 0.04727490276338593, 0.04145510517241013, 0.0358015678132013, 0.03969493389670407, 0.055473108415401755, 0.0765943976359502, 0.05178824082137116, 0.030177296927919796, 0.07269438957014392, 0.011829235459557705, 0.10511608088328954, 0.018179584369664232, 0.10946750625847809, 0.016795081544607397, 0.046005096707132556, 0.04097933009747536, 0.013151157519689972, 0.013115390789725128, 0.1255620559377055, 0.01857912603525385, 0.024800945501474124, 0.05611334341548144, 0.01404837192592001, 0.04646512101434412, 0.028782536185556845, 0.01566446887614626, 0.02602262974476382, 0.011327308058107813, 0.056282694812022874, 0.041495320957995234, 0.01909590596633573, 0.18149664805781457, 0.10317918078433122, 0.2194508348381327, 0.11489700886511034, 0.2915281405852687, 0.14435299762314366, 0.20501482721057632, 0.15999658964574337, 0.1396278745584911, 0.15038336597142682, 0.1910651015538362, 0.1139053846559217, 0.10727195189364495, 0.15048375413302453, 0.19415240524516952, 0.19477105188754298, 0.16735397549646516, 0.22123609549335896, 0.1777351257060805, 0.1757222603285505, 0.12419220645942035, 0.19233182793663395, 0.10090680312245123, 0.18183423236252802, 0.13706570881749355, 0.1251749210660496, 0.13368022838427177, 0.13558648496625886, 0.10893634685705747, 0.14556539305035146, 0.24054992283063553, 0.1400542944189041, 0.10923505219961367, 0.12592528120524463, 0.12675396617381804, 0.16589863826670956, 0.08210477614474875, 0.22659986009520872, 0.1318557746708393, 0.1474725995813647, 0.11208912042239982, 0.11956764009570885, 0.16292384224793605, 0.24424337060941806, 0.131059181125414, 0.284304820121296, 0.19184841113465448, 0.1380443401754864, 0.4041699398188822, 17.919322636819658, 81.10028282288583, 94.48099367080196, 108.10591128564651, 80.88615279043876, 87.75339141968759, 99.24809332816832, 86.92108015860282, 69.79706318147721, 37.603833444656864, 75.42691953720586, 88.907603756074, 74.16167274598153, 84.86254968950826, 98.39125940876623, 133.18538142788796, 110.57574149101012, 69.11911287615376, 19.04411131335843, 4.180136082633849, 1.656142112708861, 0.9857772422894355, 0.5671344613355975, 0.5973658230035537, 0.28388040741124465, 0.4484177993670587, 0.32332465052604675, 0.5855586307664072, 0.6234567552324265, 1.1291021805617119, 1.285150368367472, 1.0683479760923693, 1.2326841320722335, 0.9302866134432055, 1.0061431075296094, 0.6241334253741849, 0.8605296501228887, 1.3062704931343756, 0.8201440688102477, 1.2450226828936608, 0.9194166225291068, 1.1080328014589127, 0.9034340672435299, 0.7448122530214248, 0.4440362667364459, 0.09333623032416068, 0.14797604192168484, 0.1824043090305021, 0.8103334855648779, 0.9742099887901737, 1.0977064265358834, 0.7818420627905477, 3.393795490264893, 5.932263741570135, 35.29375745404151, 80.24493155940887, 150.80893578067904, 139.04756761366323, 162.06693833874118, 100.03176719911637, 53.33918625308622, 49.40883013509935, 42.5413247846788, 86.702972842801, 92.76862805889499, 122.22860905431934, 93.09930739864227, 101.07130512114495, 109.73544428425451, 124.95022404578425, 124.86004091078236, 118.35438205349831, 63.77374995139338, 11.406271092353329, 0.3690753600770428, 0.11622168979937993, 0.11706761940712891, 0.16631198866713434, 0.22877695940194592, 0.2500121352533179, 0.15743727375182415, 0.17389633572630345, 0.0983223595446156, 0.14269495352862344, 0.12123760451833088, 0.16868934335727848, 0.15718155360269934, 0.23211866557117433, 0.09132641397656933, 0.09175269594115597, 0.13447961048974147, 0.11858535449831717, 0.12266294174497167, 0.21739344443044356, 0.17621600399574927, 0.13471792512122663, 0.186546148071366, 0.09320095451849122, 0.21901920557983462, 0.12741257196232197, 0.1333024091417751, 0.15318596074658056, 0.1594465538378685, 0.12886721971294574, 0.20299612424306332, 0.13598397734665102, 0.3062845568262762, 0.07893705620400368, 0.19500797223900596, 0.08956228202629475, 0.12296604443221323, 0.19655075074443895, 0.11559595684370688, 0.17174126910826853, 0.19066201673159677, 0.11889146025022192, 0.15031628731277683, 0.15707929618656635, 0.12266117208186658, 0.0873359615704225, 0.15185541923969023, 0.12630870055046775, 0.10760784314404573, 0.12366801845811068, 0.10984511865723519, 0.1617382292545611, 0.09529879436858239], [0.031376513727610154, 0.011668542771780444, 0.08310950811832182, 0.04593190083640718, 0.045718541519055446, 0.03219105288266175, 0.016588670644728888, 0.055033079003013914, 0.02510624494583857, 0.0318842499907459, 0.018006446583557035, 0.02749862645061747, 0.019006451794637308, 0.03420972903709739, 0.010491400795628228, 0.04130445398210038, 0.034883940036618905, 0.02046715930074213, 0.051471057438081315, 0.03895053392155998, 0.006440166494764027, 0.06719236141972004, 0.019308284691144383, 0.02970516651628479, 0.044399702005208506, 0.04169544610645502, 0.023784996085469762, 0.03000233968299243, 0.07860599130752587, 0.02056674307001935, 0.034805599885481986, 0.020780198148361618, 0.08267096108606747, 0.002312228837493627, 0.01758707856248704, 0.06833097491894038, 0.05489655064358827, 0.0195852120692331, 0.05884986693760561, 0.025284057783503688, 0.055235743732942696, 0.02768496393166002, 0.07784129000238835, 0.036269164899544376, 0.014977862574009886, 0.054045844477631395, 0.09241002236282633, 9.109671385057512, 35.569068616436375, 64.04162037757136, 65.61720509682932, 63.35424069435366, 39.16718821371756, 92.70689779712309, 80.66938692523588, 34.54356493488435, 20.35533416655756, 28.636391124417706, 66.8982433503674, 53.776534449669626, 79.84393981195267, 80.35683678042504, 61.34505364202685, 66.89246962147375, 18.61564140166006, 2.2574039524601353, 0.2213193232854528, 0.11141298654218836, 0.14602922864498633, 0.014791223445847152, 0.0727171883467705, 0.07453164461279109, 0.10786425277230241, 0.11988402674755744, 0.25119826918648136, 0.19313557674327206, 0.3753764026107327, 0.1411224201682114, 0.25977943453096575, 0.43046612232442827, 0.06752653663317043, 0.11887334993169194, 0.2292177817153354, 0.06286852670112444, 0.6740623171771727, 0.13396740410356753, 0.29318316629336727, 0.45947529796150427, 0.6623155539554935, 0.31571402665107484, 0.36464798474504106, 0.3078576724135107, 0.18792784892983977, 0.09018138066054353, 0.3792542783964065, 0.32002697909070604, 0.2293110605809958, 0.5755188953011268, 0.28513458527384267, 0.23509960561510057, 0.06084836050567608, 0.050106248818337924, 0.2754926333023656, 0.3195206562597906, 0.11699847231108336, 1.4463063401560632, 15.974677205085756, 55.18420642422092, 91.75507191688784, 120.89566999866118, 75.0675049135762, 76.64396039901241, 40.61193050876741, 33.135367362729966, 20.546443808463312, 47.63871546714537, 80.03565742123513, 67.33906284455331, 84.55266675641461, 71.09976076310681, 79.2564001391011, 79.9444309357674, 68.16688691416095, 17.126878346166304, 0.18467402836728483, 0.11985620243414757, 0.03720414456761172, 0.05700447221076297, 0.046756877939427094, 0.049907406867151304, 0.040644155139283794, 0.05918671579791173, 0.05195095406604871, 0.06895681512692282, 0.022205569848959005, 0.008518972411571492, 0.025742814215200565, 0.05721801538921653, 0.022567667052029602, 0.05257752205755922, 0.05226379373080788, 0.028528878728168148, 0.10269991617890135, 0.03565721386562913, 0.056523855460146745, 0.008158725310838031, 0.05766758259626166, 0.06057932191798764, 0.024649081977024197, 0.01994102926654441, 0.054317269429203965, 0.06411809271441833, 0.028433956603910175, 0.08416788156835303, 0.01279103012019468, 0.03615263909582169, 0.043307846682446624, 0.08348482225330607, 0.025399200798523043, 0.022379422012055596, 0.07851599895906064, 0.02937046270216665, 0.033224042009321914, 0.021497099397463665, 0.04407546295213603, 0.011978298932644389, 0.02721545928638549, 0.024171301666947625, 0.025462521795904445, 0.019532727385540644, 0.02072758706016166, 0.04430442365006574, 0.08166881848967845, 0.03781002818516666, 0.04689332202918107, 0.04980257922603239, 0.02264541731546483, 0.067680052992317, 0.05348797159029111, 0.0323262942143746, 0.026212774682790044, 0.04955748088597771, 0.047254869564166, 0.0210913026239723, 0.028213018761767496, 0.024457288034740957, 0.05170899285604397, 0.038897110780160275, 0.06892221093538307, 0.008757888422077222, 0.050681757049695145, 0.11151456980094795, 0.015035482919624737, 0.01086430845692033, 0.10436410429857432, 0.02089470339518401, 0.061189813554407134, 0.0496539619991616, 0.03024668917210112, 0.023703469008567835, 0.02656164346262813, 0.016126964774523533, 0.03577963088548953, 0.006100815878580175, 0.027870054604605805, 0.040681884969554605, 0.06970886832043048, 0.032402186714593446, 0.04086508723576704, 0.05044424681053047, 0.03263442626883907, 0.04040526211141579, 0.029029038381732764, 0.012776119176358467, 0.019243310859066345, 0.037675334606319666, 0.030959248617892305, 0.02227719715465942, 0.08395549901310476, 0.02979912720019779, 0.05221223601350381, 0.02609828858816576, 0.11718397284106863, 7.99709108568007, 41.375749341903195, 77.83626679451235, 85.19851638424782, 77.08653711503553, 50.49021190212619, 113.2262517559913, 107.99828144811816, 66.91750218791347, 35.43062463883431, 32.12402539868509, 25.281778150989165, 42.15851714534145, 64.15866782588344, 67.88342506654801, 61.743790026633974, 68.42251562303113, 23.03540929671257, 2.3816621880377493, 0.3151170602969585, 0.2910333703602514, 0.07388052350330739, 0.08504526674627297, 0.1540371457174901, 0.10973177594883789, 0.10499114726459789, 0.20817435767141082, 0.4497815584463458, 0.6346210464835167, 0.7552534798460623, 0.34454366192221647, 0.8351043563696646, 0.9695114183329767, 1.1290477576755709, 0.8167324647788079, 0.9732116842942854, 0.8045617178563149, 2.448619253212406, 1.1659670669224955, 1.204148031050159, 2.167753524357273, 2.014940556499266, 1.2962368250854555, 1.1699057394458403, 0.9832329723623492, 0.7810625530058338, 0.27218687197854446, 0.45432464369843084, 0.41402394492780015, 0.3365594322883314, 0.2611061455982347, 0.18647975889184784, 0.18898659776295387, 0.04947859681241455, 0.019612615034284613, 0.29767283989537147, 0.853872652496061, 0.2783589665928195, 1.1900632900576438, 16.716861224943592, 61.806700921827755, 80.4794422272713, 88.89058066952614, 39.50218216065438, 36.07135165122248, 29.94833569372854, 37.07256017192718, 47.18397155884774, 82.95340661079653, 129.23192254958616, 93.75235849811186, 102.57542425586333, 91.56695504342356, 91.30328547570014, 97.21738030833583, 89.61566217484014, 25.68448985776594, 0.06331941540983897, 0.15372173199730535, 0.02919266901669964, 0.11827004803044182, 0.02199002526580326, 0.1140033902840749, 0.005720141522150728, 0.07954864717659452, 0.03336770647776223, 0.05862835644473953, 0.03536864003587154, 0.034608788067294706, 0.0557791413889537, 0.05716231313624209, 0.019926274413122766, 0.08319218432711017, 0.015801991234653662, 0.025633265557248267, 0.08477166610499544, 0.05423943872653669, 0.023449713874968792, 0.03746238897644705, 0.035063863446515416, 0.047503181643063025, 0.06888650357723236, 0.05996614514339355, 0.050124454897858446, 0.05218702022947612, 0.011515264857500311, 0.05397608834168604, 0.021556402263682217, 0.057212158647035403, 0.015021741217482957, 0.029848503482137478, 0.06539118911830649, 0.03735455444022533, 0.02878550286104362, 0.028941235129511165, 0.03805309639222199, 0.009923545782634569, 0.14948463758393643, 0.020980468853527022, 0.042356388463128, 0.03238796429227918, 0.05323625425057066, 0.01831279365315793, 0.035074370342396924, 0.014755133043734298, 0.01523527960788699, 0.02546971344629363, 0.008599106166061134, 0.10129826639087931, 0.12191784462981647, 0.23135078500115105, 0.1578888519396705, 0.09627701203909614, 0.09757510206151394, 0.11941094447167651, 0.08506975857721222, 0.19916882558215052, 0.1058787826989447, 0.09731212705974618, 0.18186504441884258, 0.12994554975340444, 0.1107065155801754, 0.19084914136798153, 0.12520950993583088, 0.19724695612826657, 0.11718377365820831, 0.17546148399912542, 0.16659058420167816, 0.11669639618166032, 0.09261967764506418, 0.2412468943023874, 0.14026492263280577, 0.06039771694509734, 0.14075745588108418, 0.12600297784252515, 0.15756855057852884, 0.10483016154818958, 0.1640295063055331, 0.08361599182770138, 0.20040288597585695, 0.17464641241296647, 0.17303326107080907, 0.19387074535892856, 0.08848467210848486, 0.14167640898977557, 0.12766300610476924, 0.08758716180079407, 0.13713477930474666, 0.1933819046544452, 0.14300898829054448, 0.07036125347498925, 0.21803623816419035, 0.15978550177908715, 0.09769992076701696, 0.15073915252522116, 0.125071254048136, 16.112916238846317, 62.485792636871345, 101.35717530404368, 97.01620194219775, 89.5992039095971, 63.98242396693077, 120.48418983336418, 100.97904312995173, 43.11000177937169, 27.320475155307403, 41.76670374408845, 98.78901912320046, 77.69372786245039, 117.43088353064753, 128.05041051680044, 91.67940939626386, 107.09611277426444, 30.208910511386012, 4.242384097268505, 0.489959376713922, 0.4934450154823642, 0.32556174983901365, 0.1341893244534731, 0.17334705068459436, 0.21239174830336727, 0.7226273886138393, 0.5632109879966706, 0.7097887355954416, 0.764612561512378, 0.6192395331398134, 0.3188418717153611, 0.6695496302939231, 0.7794761381322338, 0.5360330689337947, 0.42929409973083005, 0.40993677392121286, 0.3116300425702526, 1.0938857928399117, 0.393264310494546, 0.32829686758979676, 1.0487922641538805, 0.9713788342572028, 0.7054767024613197, 0.7180651205201304, 0.6446581466063377, 0.6031548123686545, 0.3517470334566409, 0.5867974868705196, 0.8572974332397985, 0.6878155566030933, 1.2349231925702866, 0.6020121769078317, 0.5220593187597491, 0.13208724047628143, 0.1337657697618969, 0.4032350367596073, 0.8452192297385586, 0.5408928855772942, 2.0480101819961303, 27.554056221438994, 89.24426078796388, 135.5750148527084, 179.15634432146626, 109.1251705538842, 108.27297287602579, 57.22347021102906, 48.46314668655396, 31.885559020503877, 62.85808440177672, 104.16975005980461, 87.13221350023824, 105.92821921071699, 92.61457304800712, 102.74003828725508, 113.65899901236259, 109.37735542174309, 35.251337020627915, 0.3895443101083079, 0.42382977842803926, 0.1385463269487504, 0.2206130974715756, 0.09950826365140178, 0.316436753998841, 0.11132612749333344, 0.306982156490126, 0.194995163248912, 0.18330096898059692, 0.14968861615465534, 0.16751796427753665, 0.11236081350474589, 0.18473657178542308, 0.14739759957357762, 0.1400199123928624, 0.12255290853640727, 0.20457103247604064, 0.21418856156449165, 0.2148027495751458, 0.20370731430668987, 0.14010108706931915, 0.15905240160082618, 0.1616822282272962, 0.14061310959439124, 0.13348879833375255, 0.13051659169216312, 0.21386544099978863, 0.11532758858295218, 0.1607800830876635, 0.06828052802912651, 0.15492272803619986, 0.15956747315583691, 0.14592286499757923, 0.18865613807593623, 0.10571486286578641, 0.13196281247561978, 0.1279770025622941, 0.19917072548020273, 0.06717694773068351, 0.3611118148171133, 0.17233135599282481, 0.10302725788806716, 0.12717013577780417, 0.08031916308907733, 0.19439928473964815, 0.0959421320247554, 0.13388345618882488, 0.14992978063321885, 0.11079188075757797, 0.08094368562583001, 0.16192854081671085], [0.06229738517093563, 0.03616036509253806, 0.03908711973757994, 0.04338270496396769, 0.013222930382096, 0.0290322846793119, 0.0852509307104253, 0.02336025970327037, 0.04306960482931426, 0.024615429649730364, 0.030522141830935597, 0.0458249319795399, 0.03282992041579658, 0.019820946899633256, 0.03934001302226417, 0.04684375614048012, 0.02447392363401671, 0.030180091233623606, 0.033969005059090354, 0.06928889125946068, 0.04736058203683746, 0.06594212124905278, 0.058847430778006395, 0.07148397831066002, 0.05986072378413332, 0.0200077670160681, 0.01525133872599972, 0.02181813237257302, 0.08459060122409175, 0.09626915197699301, 0.041295429466352354, 0.07078116158804587, 0.04743611064529227, 0.032896175529927976, 0.008503471580033582, 0.0489981179576247, 0.049917446449399, 0.008575905193274301, 0.07092057426850643, 0.03114893198794415, 0.07096433321074133, 0.09524085513886907, 0.03398539551023034, 0.05663741650360246, 0.05691949773820178, 1.1735308675035354, 17.68900694385652, 45.46079981711603, 64.91875648498535, 74.13514967887633, 81.77503247414866, 70.29690650201613, 66.96315073197889, 37.99541934843987, 33.65441853000272, 51.416193285296046, 68.05661339913645, 73.30130869342436, 79.66408345007127, 60.1578345606404, 47.54418634599256, 34.909035698060066, 15.41424209071744, 1.3023041188716888, 0.10680929607441349, 0.07592535006903833, 0.05964115149371567, 0.056632662928032304, 0.1850423327977619, 0.11878776258879131, 0.38620404418437715, 0.1370164800074793, 0.12121091401504895, 0.14463461154410917, 0.056405521688922766, 0.1063280396403805, 0.15226086361273644, 0.02941112090352803, 0.18094017711137572, 0.2859438499135356, 0.2407747083493779, 0.34515135350727266, 0.3107155480932805, 0.1815637267164646, 0.522900544587643, 0.504353157575092, 0.42959259822964674, 0.4388567462803856, 0.5481921713198386, 0.3516514256836907, 0.32721836900999474, 0.33072037141649957, 0.24038179717477293, 0.18581943706639353, 0.0879190540722301, 0.11295279262647515, 0.13217532526581519, 0.233033619700901, 0.2256021378261428, 0.1887838296111553, 0.43245942181637215, 0.32564650980695603, 0.31969219866779547, 0.43394725649587573, 0.04645055768290355, 0.03681207992016308, 0.1551111243785389, 0.4343572054659167, 10.84084770371837, 33.90113169147123, 80.0329117621145, 107.25376852097051, 111.37966263678767, 78.6873426745015, 60.24029062640283, 26.41676106760579, 18.569539823839744, 37.72375206793509, 49.353320752420736, 65.54536688712336, 80.6545368317635, 77.36403695998654, 72.90787927566036, 73.80071270850398, 31.858067127966116, 2.3032834260694446, 0.261332601188652, 0.32239740834601466, 0.047020461981094656, 0.033142809876270836, 0.052493470720946796, 0.05450547808000157, 0.05547686224623073, 0.07044313295233635, 0.06841060975866933, 0.0780004600904161, 0.02171395207575012, 0.013248204580327917, 0.037412164252131216, 0.020769587830610333, 0.052363986539984905, 0.09123543337468179, 0.02550742987002577, 0.01155582346743153, 0.09068247111093614, 0.028653182239542087, 0.032617258238455946, 0.05230030165083947, 0.050882272902996316, 0.04740606850734161, 0.10338643821136606, 0.05321783366643133, 0.03790794954364819, 0.03795707493179268, 0.023179424648743965, 0.005103608324838382, 0.0736482226620278, 0.06830453722467346, 0.01556304649585077, 0.10741263628005983, 0.059400868016265096, 0.037708942883557854, 0.02704696399309943, 0.08109817491664041, 0.021061869525921442, 0.04652600585212631, 0.014932261190317092, 0.03741673013615993, 0.05380682121481627, 0.045386511351793044, 0.03747064740427079, 0.027910452336072925, 0.11867587544745016, 0.040204114235577085, 0.02191979798578447, 0.00013298240475940535, 0.019485072886210777, 0.009933119966468264, 0.06099181429993722, 0.04635846242308617, 0.014855028036230756, 0.060750891139069875, 0.01913549164460311, 0.03212316791647144, 0.03802993372383137, 0.02915844403868241, 0.019337440082322688, 0.05300761914000877, 0.01581806663213478, 0.03555509817576216, 0.04245167064871039, 0.031898058725581054, 0.015144996146010536, 0.007373983145601327, 0.09182632465155856, 0.03220713689863201, 0.049462037821931225, 0.010550339770082746, 0.06849104132983955, 0.06096670193777931, 0.012694188945686385, 0.0748364020499491, 0.04128550862773292, 0.005014942744897018, 0.07372177476363798, 0.054641910678436684, 0.06427438614229042, 0.02458618807366058, 0.06533087501602788, 0.05170215935175938, 0.095833960409847, 0.02326558081192836, 0.02529170717142763, 0.03731077634579232, 0.01789242971778637, 0.05264173554737241, 0.07496279889657613, 0.038812327829580155, 0.021062606885548563, 0.04948044691475169, 0.0775534401257192, 0.8117242109390997, 20.378087835927165, 65.91307732366747, 81.09499546789354, 92.77688072573756, 96.37074455138176, 108.22545728375836, 94.55557361725839, 73.43696778820407, 47.557922486336004, 26.35815497367613, 44.13028478622437, 38.148548679967085, 59.21977619970999, 53.427600399140395, 52.32568894663165, 43.92846315137802, 19.682178958769768, 1.969387987929006, 0.013632051977178743, 0.07340823795886771, 0.10347076150919161, 0.14944170601665974, 0.20036962243818468, 0.594528049470917, 1.2081991039937543, 1.0385360015976814, 0.690618273952315, 0.7477545822339674, 0.5789745034229371, 0.8401882996962917, 0.8518117534056787, 0.710509225966469, 0.9135415248813168, 1.7202715167114813, 1.5848505833456594, 1.3761668844569115, 2.3979669905477956, 2.4262411507868, 2.707167676379604, 2.8741628316140946, 4.3162310507989705, 2.5032206071961314, 1.915562527794992, 2.372693443490613, 2.6509765367354117, 1.3381668396534458, 1.447973715201501, 1.57395166495154, 0.2733701407428711, 0.3001202456653118, 0.4672998442284523, 0.7200376437075677, 1.358815667129332, 0.9589919892530289, 1.2977398283058599, 1.1214599325772256, 0.3228669283130477, 0.4405881049892595, 0.20054298813544935, 0.042212884873151786, 0.3575812526527913, 0.22509972204364118, 11.659402232016287, 36.88902462682417, 80.61238704189178, 94.32844485006025, 70.71992628036007, 54.26042941308791, 33.30836349917997, 24.69485232906957, 31.535118779828473, 64.9789531000199, 88.40707009838474, 93.43254412374189, 103.74507504124796, 92.08096596502489, 92.76482335982784, 91.66579092702558, 47.84127450758412, 3.707029353226385, 0.10168340943393209, 0.24689559764679403, 0.03192623160899647, 0.10156680319097736, 0.026854189458273114, 0.01513675495516509, 0.04869976501551367, 0.013539223188173868, 0.0943247365554975, 0.1152999404697649, 0.03599214367568493, 0.023968862932956508, 0.022929685731087963, 0.05039305681543005, 0.04813611199478469, 0.02794974498570927, 0.08405378809378994, 0.023665313999499046, 0.03251170664424858, 0.05813421824225976, 0.060246426071370804, 0.028586017396000606, 0.012687211799916002, 0.04384483601297102, 0.03161317935483831, 0.03770561040108723, 0.08412599954153262, 0.004983994707975898, 0.054298163196372415, 0.06666333940360816, 0.01678598808094619, 0.024778033726878708, 0.03721080570211334, 0.12557648137331973, 0.05289824093661962, 0.035785736606246045, 0.0293057014594876, 0.06292118758503949, 0.029128744725077867, 0.024809495042709094, 0.011753284545134635, 0.037310071544901985, 0.05722543878120281, 0.03540276925289824, 0.08234268474963405, 0.03723932332509468, 0.09523160079674375, 0.003211580868434882, 0.02750318850420656, 0.0779055877618732, 0.1257698419654081, 0.1026369973776802, 0.2079382034078721, 0.09014533622370613, 0.05178089403817731, 0.14630710405688133, 0.12394109049872046, 0.1692528623126207, 0.16144766742664, 0.08497025907760666, 0.08800716950528084, 0.168769690658777, 0.15852976109712355, 0.12316868234906467, 0.1771537875456195, 0.14599452486201642, 0.07528489290346062, 0.10843071350527388, 0.2471313535446121, 0.15347333564873666, 0.1775619745134346, 0.13758844125174707, 0.11690690948237335, 0.16015765197094411, 0.12872360887066012, 0.14666145036537803, 0.22871846092804787, 0.1564058282923314, 0.26017360208976653, 0.15042867241126878, 0.13526966164429344, 0.17098196872299717, 0.20371586384792484, 0.11931697612688427, 0.16084661016300802, 0.17574577922782592, 0.32245728577817645, 0.14095381953783576, 0.15403218146774078, 0.08233264899782597, 0.14613053611209317, 0.18976190938584267, 0.11825283403478323, 0.19521827869597944, 0.12899650471104732, 2.6898141301447347, 40.21702627981863, 88.61719146851571, 98.4634937778596, 100.85651613050892, 108.66841839205836, 100.42736960995583, 93.69820625551286, 51.99487232392835, 48.14524642882809, 78.58369012032786, 104.39239163552563, 112.36347152340798, 115.63919974911599, 93.65806471916937, 71.2288224312567, 56.9846135570157, 24.332040932870683, 2.6800177654912396, 0.34472084273734405, 0.25381033789486657, 0.2979021759763841, 0.3364206477999688, 0.26958833238290203, 0.47971460547658706, 0.9422329272474013, 0.7442359097542302, 0.22791472744316826, 0.2807278636722796, 0.2730303041396603, 0.3642995679570783, 0.2939177220386844, 0.46014605390448726, 0.40949333158712237, 0.7850534420820975, 0.7589197927905668, 0.7674124596580383, 1.6350026212392317, 1.1865977534363348, 0.7428440812133974, 0.67551531017788, 2.1991695031043026, 0.7750024910896056, 1.1233798102025063, 0.9886159351275814, 0.9755174250852678, 0.7904074773673089, 0.7331431404717508, 0.5899360571657458, 0.12648423427655814, 0.16580581905380373, 0.2356582369294859, 0.34846060819202856, 0.5239604425526435, 0.4887298362389688, 0.8355344687738727, 0.804338081469459, 0.48130393148429934, 1.046739883961216, 0.36643520658535345, 0.17097963981570738, 0.5784663113374865, 1.1510109468813867, 17.863156257137177, 50.00933324137042, 122.1524444703133, 157.26134454050373, 154.3001433341734, 115.91696631523871, 87.82875584017846, 37.33139345722814, 23.58874982403171, 49.900252126878314, 69.0976575113112, 85.56157881213774, 106.661404332807, 99.85645294189455, 97.45770392879363, 110.04168725782826, 65.01280707697715, 6.57898364528533, 0.39148576076953645, 0.7402938664440186, 0.15113204837806765, 0.26694263241464095, 0.09771557960418925, 0.4055455885827542, 0.16819906240749746, 0.27838954882275674, 0.20360373921932715, 0.30504698774987654, 0.17725883352179683, 0.11368102048553767, 0.12618028889259986, 0.21173439889905915, 0.1336338800648528, 0.11087533071516983, 0.12986192359558998, 0.14262680234687944, 0.1864446567431573, 0.1108256958785557, 0.14737118486194842, 0.15799326972374994, 0.12358900414960039, 0.14522811518080775, 0.18378430917378397, 0.14066826792493944, 0.18383903849509456, 0.19970547017310897, 0.1430300557084622, 0.13201706682241734, 0.19877416772707818, 0.14779126151434838, 0.11571739710146382, 0.20550553716959494, 0.12201093963437504, 0.1631405838434735, 0.10608186494679221, 0.1970711236278857, 0.08277463576486034, 0.13406589236711303, 0.0844387702583786, 0.1342339260924247, 0.19934968361931465, 0.19055078076499124, 0.22227405270020809, 0.131479732752327, 0.30626990922516395, 0.1407622209479732, 0.12743747748074033, 0.09999057728677027], [0.021983170694100763, 0.02109600257338776, 0.013478214818713887, 0.04392385032148131, 0.04629121139465321, 0.029541997449292295, 0.011580730901069699, 0.031022121453838005, 0.028738579975681442, 0.010673969124083318, 0.06940844694092389, 0.010843455543621414, 0.06550601037639765, 0.01845820863250523, 0.008931211984506058, 0.03873137914906106, 0.039845604239211935, 0.015264029930075331, 0.018665213250525056, 0.04974927099782133, 0.06193850745236682, 0.07788585333694374, 0.06039256117336693, 0.0748075358569622, 0.06658526738324473, 0.033893790546684496, 0.025603294282430605, 0.03550858514743947, 0.030402394627491315, 0.03966715171813004, 0.024733041383085713, 0.024057482068817464, 0.04862694835831081, 0.04848203899699354, 0.031645452723868435, 0.021456544617972067, 0.04625401399548977, 0.04734171712170205, 0.029276287513634855, 0.11835581157356502, 0.03509452228524512, 0.10093478065344597, 0.039579974742786544, 0.18629611229463933, 7.580624607301528, 32.29199305657418, 69.6014702704645, 54.73242390540339, 61.27460787373205, 60.29860058138448, 56.78110530299526, 34.28706938220609, 22.183858809932588, 32.42824835162009, 59.54831000297301, 76.49234510237171, 67.86404855789678, 75.07203132875505, 50.257634962758715, 30.217828019972774, 9.473863455557055, 0.9471350319443211, 0.431499176568562, 0.11414058130955505, 0.044573060041593934, 0.10991422744888453, 0.07759980376689665, 0.08659097936845596, 0.07168799518577515, 0.22726295515894893, 0.6085251500048946, 0.23291657678782943, 0.5333489419952516, 0.37917129575244846, 0.7141968055117516, 0.7869302962095507, 1.6204570017514692, 0.7294265721594134, 2.321102263466005, 1.2007158345753148, 3.3954450920704877, 2.855103789798675, 5.834315294219602, 2.7327518261248067, 10.813737261679865, 6.158312876378337, 6.277599998058812, 8.750987302872444, 4.430996660263308, 3.7292025118104877, 3.6186085881725436, 2.3844720759699425, 1.9036510250260754, 1.7864157932419933, 1.323941261056931, 0.4667076582629835, 0.27736740367066476, 0.49183086822590527, 0.5857454336458637, 0.2976080901440113, 0.14567080674873245, 0.16202840803852006, 0.1512645662672097, 0.34558281422622744, 0.09267894220688651, 0.12428998992207552, 0.08850645198817216, 0.05351376960114126, 0.20353997006051003, 0.19944893797078442, 5.191340763722697, 25.27716152129635, 51.57367644771453, 70.42790582103115, 82.58481364096366, 109.74488935162945, 94.898529975645, 42.85280020006242, 26.285496988604148, 27.356468785193663, 45.9777525163466, 57.72535316405758, 61.73851443875221, 72.0808239906065, 75.12486565497615, 63.95562241154333, 28.20242597210792, 8.094182985444224, 0.497711512350267, 0.17552298553768667, 0.04932310777686296, 0.04694808582444826, 0.06173432586834796, 0.09235973635147657, 0.05663046425568962, 0.03194419062516141, 0.04907494508511117, 0.11005907169272823, 0.0139807187013268, 0.017571255016411026, 0.015179965186924224, 0.010281900646195058, 0.022298153489828113, 0.010463083313117105, 0.03969790631785028, 0.045934915392389225, 0.04495566733361733, 0.06680341858056284, 0.012387396587479501, 0.02421048706427457, 0.033021197248730934, 0.04663311643525959, 0.04303411963666159, 0.03661048005244905, 0.03785413569740711, 0.05086860972486677, 0.049868052930481015, 0.03178742988365552, 0.05752905474735364, 0.05358525326535587, 0.0537479090534391, 0.08956435046369031, 0.020436889251633998, 0.07188758407268794, 0.04390599281196633, 0.026603418237139142, 0.03349450935098914, 0.02014456925192668, 0.04693940987870578, 0.04410389247500608, 0.06313700987506779, 0.14960866721887744, 0.012408125011490719, 0.015565333268304747, 0.053136911798989585, 0.1200876912222274, 0.027828597756583365, 0.06278158338259786, 0.05170329316188732, 0.028364715662093896, 0.03285162368669145, 0.06060798892811422, 0.018457837079861955, 0.05620254286294503, 0.051902916522756706, 0.029811913207654032, 0.05366717104709918, 0.02823594394290159, 0.07542871825036503, 0.0023669141087485778, 0.027588863947218465, 0.02773139652075066, 0.03749181058317904, 0.0959291544953181, 0.03972096939481074, 0.06510448071264452, 0.037053190772571874, 0.016992960140229236, 0.04943543541876059, 0.03432306408461544, 0.06762222101491305, 0.1306480983452451, 0.02695056906480703, 0.020879324180104082, 0.007311706900626662, 0.032659944657596855, 0.0461029491177009, 0.02456264427652763, 0.039432380243294665, 0.04555700421934167, 0.061613050319494746, 0.04826093453072733, 0.09315618434019628, 0.014946932731676969, 0.05696576178794908, 0.06175472295933193, 0.0318318285093072, 0.023690870692653042, 0.0750789454867763, 0.10402833562224142, 7.007872760295869, 41.11815552557669, 84.80099985676428, 67.04865055699503, 78.06363090392082, 94.10519922933271, 105.15144086653187, 65.484719199519, 49.855646933278734, 21.075883373137444, 25.420210361480716, 52.20597428660239, 49.00228038910897, 66.8780117650186, 56.92404823918497, 39.71973249989171, 13.735925593683797, 1.4977229747080034, 0.5817821237348741, 0.2575317938481608, 0.10468092762053975, 0.4361761739898113, 0.5458896787416551, 0.8853272420744743, 0.716693026404227, 1.6053171431826008, 1.7071319443564263, 2.5017256938642074, 3.027573593201176, 4.13680762052536, 4.609014901422686, 4.897598874184394, 7.989177213561151, 5.6416837726869895, 6.905134118372395, 4.967219473854189, 5.969827300117863, 7.570075392723084, 8.744714452374367, 11.256649340352705, 15.901256319015259, 13.85245725031822, 15.783018431355877, 11.01916551589966, 9.556416599981247, 8.288330993344708, 9.250133422113235, 9.634037363913752, 8.476279204891574, 5.158027093256674, 5.982238169639341, 3.7425491117662, 4.644831044058646, 2.7358514791534794, 3.2441171090449057, 1.5706791824871495, 1.5537416526386816, 0.749450026740951, 0.6791489571332933, 0.9295487788415725, 0.7800442689368803, 0.7630992620702713, 0.16743947090881486, 0.052727472277418266, 0.3187617695619983, 0.10107955594937648, 5.411202849880342, 26.974514261368785, 59.172378278547725, 71.69272115153652, 64.92941356474354, 60.963218750492224, 38.80314911565473, 32.710211853827204, 33.92587400251819, 50.23157865770402, 79.56089373557799, 95.47200402905865, 84.05881681749898, 84.5192010941044, 91.34118341630506, 81.81194982221051, 35.89562162276238, 10.217821367325323, 0.1535749648727717, 0.17933525355352511, 0.04757054375424501, 0.024888055444124247, 0.061842382570067723, 0.08414592548844316, 0.043208864292189966, 0.031016333659570065, 0.0781204064767207, 0.020662375740827094, 0.007316298640122818, 0.018880518431204463, 0.027739394478680148, 0.017039264409592556, 0.027398621332981897, 0.025820526174239578, 0.002668896631803364, 0.027434776852568312, 0.1184525991219186, 0.08290067255016297, 0.032921885440666834, 0.02014048217285064, 0.10852940095167969, 0.07652453807813507, 0.03028766338473126, 0.08000459972648852, 0.08163750847621311, 0.0716943230720297, 0.028837198474174066, 0.04810901929534251, 0.03080909346951352, 0.02849305262638917, 0.023835578955890193, 0.07573679284823519, 0.039303861333117376, 0.04144586998248293, 0.04375808038598588, 0.07662100386956046, 0.02992855967022479, 0.04717736827930616, 0.031183392537998098, 0.02235881041645283, 0.05477713668839105, 0.06773525728814064, 0.04143055588487656, 0.051026082928142244, 0.02937898734554408, 0.038685264486458995, 0.08832036923136442, 0.11651264999302165, 0.15349185965474577, 0.14445750733777402, 0.19290846231723988, 0.1449693306799858, 0.10241877723244891, 0.1457301479193472, 0.1412859646182868, 0.07107216774696304, 0.15658889266271747, 0.14807315122696663, 0.15935692155072767, 0.09900801589772587, 0.07628447676618254, 0.10387112671929984, 0.13714725121615395, 0.26970349071967986, 0.10285130281361843, 0.13932727697876193, 0.34839558264901566, 0.17321854709617554, 0.1516142087958513, 0.10960927848974544, 0.19992982668261375, 0.28477369657447266, 0.11757394223804436, 0.09688907798620001, 0.089865721792223, 0.13103126488145322, 0.1879446262553815, 0.14445258905330013, 0.11004548895383075, 0.15453593024323065, 0.22577391006052497, 0.15960154874670893, 0.19076690949018926, 0.11084440374566663, 0.10997757525934328, 0.36084800477950807, 0.11636366121350758, 0.29261390167859297, 0.14985340166716807, 0.2723358914015755, 14.85993960211354, 69.73307363448605, 107.48319579708962, 84.88743320588144, 87.69367725618424, 81.38718066676971, 81.38631774533181, 55.97949051087903, 36.15300363109958, 50.144745226829286, 87.1260710685484, 113.61706103048017, 100.5242443084717, 109.33332289418867, 74.4776902660247, 51.0489260765814, 19.025564385998635, 3.0716264680508645, 1.1235088806959892, 0.35088254919936585, 0.2707588228006517, 0.4151735364669754, 0.2829870569609827, 0.4149752116251377, 0.3425688404710062, 0.866096780425118, 1.3599822045333925, 1.5551784658624281, 2.268525587935602, 2.7951665414917857, 3.7015542147621034, 4.890194419891604, 6.518607091519141, 4.878064980429988, 6.659388801743908, 6.808452106291249, 7.255771458148957, 10.410615667220085, 11.388727311165104, 13.984528356982818, 28.368048052633966, 15.839212267629563, 16.54434165646953, 20.495509870590706, 13.781658468707917, 11.791229171137656, 10.121698783290002, 7.288658570858741, 6.519680350057541, 4.673120158333933, 4.038497089378295, 2.090050880947421, 2.722573030379511, 1.2698309387891524, 1.3130433232553544, 0.648206543297537, 0.757775012283556, 0.20138710977569704, 0.21726434329344382, 0.29238735415762473, 0.4407624359573088, 0.46985064122465353, 0.2962848724376771, 0.2301341914121182, 0.4428065424003909, 0.43599372248976465, 8.392731739628701, 35.99782682234241, 75.90594291687012, 103.43873793079008, 122.57613889632688, 148.31973691140453, 131.3086763505013, 59.121316863644516, 37.64056644132061, 38.8635536163084, 58.07066686691777, 80.05273542096539, 84.36764071064611, 92.32344688907747, 103.74658907613447, 102.53443548756262, 52.31856200002855, 19.19453028709658, 1.0071226581931114, 0.27170104966048275, 0.1555867424054492, 0.19021713415220862, 0.25626771812958105, 0.21105605868562577, 0.13234306787771563, 0.12021553597503132, 0.22351776580176047, 0.21334296903542935, 0.23556360974907878, 0.12754877473437978, 0.08676535630178067, 0.13148498811548756, 0.1775527201713093, 0.12091714227872512, 0.12305939224578681, 0.15259251839691593, 0.23853926378632748, 0.1979659296452038, 0.18019282769772316, 0.10233819244369384, 0.18484819079599074, 0.17167440495423733, 0.15308108330974657, 0.18794799704224835, 0.12079213971212027, 0.18396064729219486, 0.12643567196303798, 0.09230471591675475, 0.1918469096023229, 0.13773808886687602, 0.14112998911690328, 0.18495115301301404, 0.1650467178513927, 0.21197130392876365, 0.13955528006678627, 0.23946140382078387, 0.19785207365789723, 0.10427268702656993, 0.12894589694276934, 0.12917222995911876, 0.1942140906448326, 0.2658029080879304, 0.14746060264447045, 0.11219425066824883, 0.08974728459912924, 0.17490142776120096], [0.0313129686495109, 0.04492358740178808, 0.06027099068066286, 0.043815575284703125, 0.06225180676988056, 0.005304329585464251, 0.04439595200481915, 0.028866005295346824, 0.05327566947427489, 0.011944955913349988, 0.0585528967841979, 0.03341745622756501, 0.09667192270318348, 0.026026550199716322, 0.05511096716227551, 0.06609305589189453, 0.050532772100620696, 0.06774861020066085, 0.004542500631237824, 0.0721993665361116, 0.019633628826047626, 0.012327572781472437, 0.009892931951570415, 0.04620733242782374, 0.03256707564897595, 0.05123995552440325, 0.02524991707515813, 0.0016320574345187315, 0.04988820870376883, 0.01874025347792814, 0.024716290870621323, 0.036836667512092865, 0.049540531190653006, 0.05446442725857901, 0.06131840524293723, 0.06353812202090217, 0.06885732328819652, 0.007554408821893195, 0.11388352816744197, 0.01651273792489402, 0.0198629955505772, 0.023008906883337808, 0.7080447517575756, 15.228871856966327, 52.38796049548734, 69.37236462869953, 71.69506672889956, 89.4403322281376, 77.19740683032622, 36.710980399962395, 24.98205807901198, 36.485969712657315, 37.92980201782719, 61.642075123325476, 73.66273941532259, 54.6242606255316, 65.05012842916673, 26.541402224571478, 6.906954588428621, 0.285311000001046, 0.516303546967045, 0.12906972739485004, 0.0622451379744997, 0.04503062903700818, 0.07747211989255683, 0.280092838070085, 0.13775197038006398, 1.0904685504013494, 0.914868082731001, 2.0264815178609665, 0.5555896388907586, 2.1032153358382564, 4.278328207231337, 4.613782542367136, 4.189600761859648, 5.276923939105004, 4.371953712355706, 2.2164772066377827, 4.298953010189918, 6.477955156756986, 7.666123942021401, 3.653263954385635, 4.614935228901525, 7.120009891448483, 11.78433560555981, 19.9208551837552, 15.216312427674572, 9.32447116221151, 2.935307924785922, 6.9295655815832085, 10.560012863528344, 5.71952271846033, 6.986571348482563, 6.4447846528022525, 2.765655363759687, 2.2282305888591276, 4.063499502597317, 4.638503770674429, 6.8397805671538086, 5.593047853439085, 2.635974451418846, 3.040679212539427, 0.9281538859490426, 1.167115585938577, 0.3569323761809257, 0.08613516471438831, 0.16885080404819983, 0.13187052952426095, 0.208943433338596, 0.0773866551237241, 0.1069025596183154, 0.31238114581473414, 4.718165637985353, 32.7802045883671, 52.777624437885905, 81.03514009906401, 87.58370184129285, 79.87385180688675, 64.37732819587954, 47.01600390095865, 19.630154601989254, 24.590307435681744, 54.517223065899266, 65.29064816813316, 63.76543452662807, 65.46827662375667, 82.86343528378396, 73.48862540337348, 43.027612393902196, 9.301083049466534, 0.49093203258610546, 0.1740860190963553, 0.1434915164305318, 0.03895231507598393, 0.08851501685116561, 0.056142822478807745, 0.060854726696326855, 0.05096850375975332, 0.051664575078194185, 0.011646525404836622, 0.05106787302441174, 0.04138241108927516, 0.10296452294794783, 0.0550124942204885, 0.011187473071678992, 0.005190222704362485, 0.026943260586009394, 0.036670005084165645, 0.049580440541068395, 0.04247780956868683, 0.029163000346612067, 0.03071933286264539, 0.05339334440988399, 0.08398277174320914, 0.03887050837698964, 0.07723878483257948, 0.10582504929193567, 0.06199776818374954, 0.03589966537190541, 0.04354470957731528, 0.04251860375065477, 0.03911282581787917, 0.034618800836465055, 0.02713032585058001, 0.04105600783781659, 0.0051786787169534835, 0.059772244459318544, 0.06696741502251356, 0.03593438447663381, 0.014851020438776863, 0.01048466113711437, 0.06676846964945717, 0.05182158479827547, 0.040718285637276794, 0.040036034544989954, 0.019472984018765634, 0.043725399075136076, 0.08309152037385972, 0.06483538466836176, 0.032738897679073196, 0.015429962659254672, 0.0677503722028867, 0.039352002298279155, 0.0492731090484848, 0.03927807098314647, 0.04307807393131718, 0.022320781811891545, 0.03086029878637243, 0.017435720656067133, 0.03160347110561786, 0.04483450286751313, 0.06906385293170329, 0.0358436451924424, 0.013019439234818905, 0.012921594485129802, 0.06194694974129239, 0.055853042060569416, 0.019455078628755385, 0.02737240771943283, 0.044854888467178236, 0.031024412056731603, 0.031623385561209534, 0.018837644320522106, 0.024670220258074905, 0.007153119039421361, 0.06951783663563191, 0.022086828135915344, 0.06259581472183909, 0.012028727627870058, 0.052590668126339876, 0.02045201757291873, 0.05842294912004183, 0.03677925305260766, 0.021579718149657694, 0.04293408770594866, 0.09643861062584386, 0.054435806213727886, 0.07729243396991685, 0.5559164826427737, 22.529647119583625, 73.29315016346594, 98.3724477214198, 105.9032964706421, 131.9570362952448, 111.11745219076835, 61.29335288078555, 38.990446213752996, 21.297240372627012, 21.476573098090388, 44.169500643207186, 69.12418842315674, 56.716394039892386, 60.88933698592648, 33.79900493929463, 9.974099013113207, 0.171373454974063, 0.8429219465582602, 0.2618646339303063, 0.07356455819981714, 0.09486687399687306, 0.5045286223532692, 1.083354351501311, 0.9059587253197547, 2.5765936893801538, 1.8205268080196075, 3.280588532647779, 3.7555088679636683, 4.854789635827465, 3.9957493832034454, 5.040337847125146, 6.503013218602827, 5.47799002739691, 7.471373850299467, 4.572826623916626, 5.56731318273852, 10.230827946816722, 8.667630072562925, 9.876459452413744, 15.171613097190859, 7.020239012856638, 15.414804950837167, 17.84396606106912, 17.050396050176314, 12.519951616564105, 8.69952384502657, 14.080306753035515, 13.287875210085224, 10.489311160579806, 15.59956721721157, 15.111846962282735, 9.51867163181305, 7.574780766041049, 5.133549051900064, 5.033475660508679, 8.877724966695233, 3.3832114646511697, 5.9623017426460025, 3.171383373198971, 1.7770765072876409, 1.2880542706097327, 1.5159899428967507, 1.0990263040988677, 0.6087927904821212, 0.4453502913876888, 0.08787861995158658, 0.054172578402945114, 0.11418362779002036, 0.11481491488314445, 4.9019379961875185, 34.08888378450948, 51.809093183086766, 77.21435931421097, 74.05307800539079, 45.75410681386148, 41.244742178147845, 16.258899011919578, 23.15350794023083, 42.688911807152536, 84.75783025064777, 98.44522337759696, 86.31649386498236, 81.64633166405463, 99.07594050130537, 91.80582738691761, 51.75011250280565, 10.051256937365379, 0.3548502411332823, 0.12169243091897619, 0.1506026203353559, 0.10508064931679158, 0.05439033506498222, 0.06193787542982929, 0.03978813998401165, 0.024748859183502295, 0.07518377695833484, 0.03131377112661158, 0.09422113848549706, 0.03630810514873555, 0.010889900581640823, 0.02755281376472164, 0.029888179175735965, 0.03714708250857169, 0.03460222652422325, 0.042094643032478715, 0.08814362508635368, 0.057152369314984935, 0.0474049385276533, 0.032640780968170975, 0.06269439108549588, 0.031493455134031755, 0.030804182845918886, 0.01070587477090979, 0.04827909081453278, 0.08773562964051963, 0.01415097025117927, 0.08729186554950091, 0.03707305926288809, 0.014235224601091638, 0.03266431135876525, 0.04912949820619918, 0.05559935204444393, 0.023897549723305052, 0.06753363060734927, 0.03337557803118422, 0.047334573351808136, 0.041424683820936954, 0.04141443356451008, 0.015180172988273686, 0.021076938475392038, 0.035650617848601074, 0.06488527997487015, 0.06822573742078197, 0.17638287326741606, 0.17975683173825666, 0.16840026773993047, 0.2225610139148851, 0.15698978647349343, 0.10375021506221065, 0.12115196354927556, 0.09805684113093922, 0.10833966395547313, 0.15337631827400577, 0.13874920235285837, 0.14786350360560804, 0.19208335497927284, 0.11364636266784323, 0.11131660502043464, 0.14724873336813143, 0.09435358742672591, 0.21784136071801188, 0.06573185309647553, 0.23362879340927448, 0.1685286640760399, 0.14806850873414548, 0.11912877130652628, 0.13337572375612874, 0.16508679957159106, 0.16295845410035503, 0.07911039125775138, 0.23041041207409677, 0.13516797113322443, 0.13985736385708855, 0.10184941302624442, 0.1179214243987395, 0.17933448746560082, 0.13669826240549166, 0.20983284609692715, 0.10328291675015804, 0.2395627572531662, 0.11093141601210642, 0.23541572413617567, 0.302917079459275, 0.1552409456381875, 0.180032761286824, 2.5184278815023364, 40.14263460713048, 101.42611488219231, 107.92534889713411, 102.95680415245795, 125.65537991062288, 103.65583327508743, 56.06752418702649, 42.55841847388975, 55.738213754469356, 54.30627407566194, 88.44338340144004, 100.20544190560618, 75.99148981032833, 101.98505263174735, 44.213344896993334, 14.544340795086278, 0.8255256219736992, 1.4043753449955296, 0.4285615358141161, 0.2504361342758902, 0.24740991843563898, 0.49544695644609393, 0.8983117582336549, 0.749419138075844, 3.126122653484345, 4.618999784992588, 9.743064545815992, 10.078796878937753, 10.259012137689899, 14.530305574017188, 13.059012755270928, 13.119025018907363, 13.914747430432229, 14.985421126888646, 7.864426720526911, 16.00959904732243, 22.590477197400986, 21.021888025345344, 17.985822500721103, 25.28267833494371, 25.76785199103817, 32.85712030626113, 47.51216411590577, 39.66956930775797, 30.286728374419678, 21.18959680680306, 29.06087394683592, 29.076137850361487, 20.270946333485266, 20.7094673187502, 27.087902138310096, 13.860733451381808, 13.699525017892162, 14.950025658453665, 12.232646826774845, 18.053665776406568, 11.365652007441367, 9.715073531673802, 9.960082423302437, 4.865823753418462, 2.9687998179466497, 1.2159342631216974, 0.5152523517608643, 0.5103061816865399, 0.2461651328109926, 0.3319098301712544, 0.2644878109135936, 0.1894707959746161, 0.5508446741488673, 9.846376834377166, 55.21170616149903, 77.9115919913015, 113.8635741510699, 119.1119250943584, 119.77097742019163, 93.44858661774667, 67.66538050866896, 32.580004853587, 33.3161376368615, 71.37118093429073, 88.94605867324337, 88.46305016548403, 89.12112974351453, 112.54082541311942, 107.78998005774714, 74.65266719941171, 22.26022735718758, 1.3756204492622808, 0.38848968282822643, 0.3612551345459877, 0.2572628050561874, 0.12991858345846977, 0.16829171308105992, 0.215876299226957, 0.21109964908851733, 0.16727220327142747, 0.09266047948791135, 0.12613074598653665, 0.1132914724369203, 0.15214794225269748, 0.1413937072239576, 0.07315438706427813, 0.15608057800319888, 0.13400207724302046, 0.20070426496526889, 0.19423924897226597, 0.10762825938722781, 0.18091659692506637, 0.11094434757626827, 0.12858487034757293, 0.20462254422806925, 0.09607119485735895, 0.13905231270097917, 0.14200136816549686, 0.28369715917975674, 0.07896464303015702, 0.2696793436283066, 0.06625250943245427, 0.13407084129510388, 0.10860527429970042, 0.13192720470889924, 0.16880123815949888, 0.14732410109812213, 0.09675186397808214, 0.2701594968957286, 0.301447814751056, 0.33286241453982174, 0.08260876240749514, 0.1321651822616977, 0.16955347521410835, 0.21953205547986493, 0.12058138126327146, 0.20321481170192843], [0.021402228984140584, 0.029274734270368374, 0.010882038604317894, 0.025759444068816882, 0.04361285309818003, 0.022891865885486046, 0.03301854658451292, 0.015345411450271646, 0.04445456156146623, 0.09186652128494556, 0.023255133287860982, 0.03468678730930533, 0.018687849233467734, 0.08870303014954252, 0.047897559876042994, 0.08603794049591788, 0.017095039440919797, 0.02141123243247069, 0.03664818690008214, 0.01924378008791997, 0.04089488422558193, 0.041147677918835994, 0.03666921601360364, 0.015738984333321212, 0.01961954621477954, 0.030218265394890503, 0.052957072658764745, 0.06984153176627814, 0.02090524093458249, 0.008471005731412481, 0.046834609050664215, 0.04074731270872778, 0.03681085417948423, 0.055101486824212544, 0.05146690524153171, 0.06390239299845792, 0.019327603513374925, 0.03144066209994978, 0.1091251339042379, 0.11630579093170744, 0.16158344885033948, 3.056738376617432, 35.112575331041896, 63.93029174497051, 61.27981678132088, 54.2377188897902, 43.806485283759336, 30.14513473356924, 24.233116795939786, 39.38482092272851, 66.88344817007741, 68.61959118996897, 78.93519724569013, 47.06650049455705, 36.821956019247736, 39.55332986770138, 5.551905622405391, 0.29811524034988496, 0.43372478456266467, 0.019491785731647285, 0.1996175079576431, 0.019670688329384695, 0.05508339565788066, 0.15308203325877268, 0.2876225630602529, 1.6607739415860947, 1.5677001423412755, 2.2243937753861953, 3.1552011447568096, 5.536141616682853, 6.317027663030933, 9.295102415546294, 5.3984674042271035, 7.962654636752221, 5.833568572998048, 4.89290330679186, 11.016578712771016, 7.671402471680795, 6.278864472143113, 3.9652492778916515, 5.672191967887263, 8.797099667210734, 16.720044228338427, 9.716225727911919, 10.887652366392075, 12.846791936505227, 18.046393702107093, 9.662153893901456, 10.297491569672863, 8.47382183997862, 6.9258559999927405, 15.336573277750324, 14.782723822901326, 4.979884316844325, 11.42865703951928, 11.515659132311422, 8.780370758425805, 6.835276705603446, 10.484427809715271, 5.778822581614218, 6.41567821464231, 5.711358304946653, 7.219551801681519, 2.8040340398588492, 0.685750367420335, 1.1524609981044647, 0.493511266766056, 0.15020805441083449, 0.11938959360122682, 0.1469349897196216, 0.09014195777596005, 0.20118647134832798, 0.16159815773848565, 0.10899368853818987, 8.085842555569064, 30.507865721179595, 49.593157998977176, 53.35740174016645, 52.493025102923, 114.87012493994929, 108.05504598925191, 67.78752311583489, 19.23877658382539, 19.858734646151145, 52.13526964187623, 54.02215719223023, 64.67929578596546, 68.97150624182918, 68.47655019452496, 66.6893300702495, 28.706732949902936, 2.238165707357468, 0.35227655342990355, 0.02234190285596396, 0.05262145336957709, 0.09135241500071942, 0.02646285642479216, 0.03458027044431337, 0.07446255114290022, 0.12573278629251067, 0.018535468599668915, 0.11147512393372674, 0.07610525815717636, 0.0465535122390476, 0.029051865886656508, 0.05817918760341503, 0.031130095801105907, 0.006749457257213973, 0.055756599251781745, 0.029034012207581155, 0.023301136867714026, 0.07209624344062421, 0.03774633563514199, 0.05573301523503277, 0.011436306090364534, 0.05129666135255849, 0.037036447920986725, 0.034093115133263414, 0.06297504356611641, 0.025076053420742674, 0.10187437217081748, 0.08354461541579616, 0.048511717243180166, 0.03639562303320535, 0.02327287396896751, 0.0352196206128405, 0.07213696101379972, 0.018399499484427997, 0.010007517637624856, 0.05147469252528203, 0.031902101754601446, 0.020633900252681588, 0.057890150290463245, 0.03421939706670181, 0.05385989961665004, 0.057442973277741866, 0.00860044586231872, 0.03162640203241139, 0.034300839873932065, 0.02973681935409625, 0.07220013262403589, 0.025309940064025503, 0.04734714102420596, 0.02618457307107747, 0.022159734808449304, 0.06394015730268533, 0.04653821729363934, 0.009411077011346577, 0.017522767396463503, 0.05679385931861978, 0.07216887623672524, 0.04325365362268302, 0.08515350730909456, 0.0473822623250946, 0.012654723926267077, 0.028507999001791882, 0.09359310726605116, 0.06189008686511267, 0.06028203000765174, 0.036815420063512946, 0.06438473344690378, 0.06095675428608253, 0.04359317996028451, 0.02085239427434581, 0.11401498119436926, 0.08376680389647523, 0.045018589965278105, 0.0904431222607532, 0.0192632578733948, 0.030351422967449315, 0.1082245056186953, 0.035619212074145194, 0.091198745423988, 0.050186013893014005, 0.07432127686878366, 0.08568918662926844, 0.034927744944129265, 4.4924935410099645, 47.170160893471014, 88.1716102169406, 84.53520436440745, 75.48757506955054, 50.510710208646714, 62.13590937276041, 58.60827476747575, 19.706648665089762, 33.07612780601748, 46.49423453115648, 51.36600263657109, 43.410525937234205, 47.46760991311843, 45.61837711641866, 8.809370802294824, 0.2123421977364248, 0.397287896203418, 0.05151286668654892, 0.26140516503683986, 0.32144335308863276, 0.7236842222271428, 0.7882589378183888, 1.9811325448174633, 2.1325951141695825, 1.662735984690728, 3.242706526671687, 1.73696328555384, 0.5242191964099484, 0.9212736809445966, 2.9522376098940453, 1.7493326024663065, 2.8491827268754286, 3.1596944649373335, 1.8732191934700937, 1.5964166723912763, 5.899988518607232, 3.258372227991781, 7.199644302168201, 13.235357615255541, 12.485870142136852, 25.495433576645393, 16.62357157276523, 16.77247258924669, 12.358683366929332, 12.019534649387484, 7.958937210421409, 7.709717164116522, 5.242842464677749, 9.285496530994292, 15.627887710448235, 17.601920520105672, 8.00658469238589, 4.498222652942904, 4.926352299028828, 2.8053857866794836, 4.778380393981934, 6.48056794558802, 3.9838778395806593, 4.483630945605617, 4.538570113720433, 3.0483018486730518, 2.8571551893987968, 4.734044373035431, 3.0531624007609586, 0.6677196607474358, 0.2944511337386024, 0.19751600620727386, 0.23188122427992283, 0.03760840916525453, 0.12100401664933852, 0.28730672033083055, 0.19006443750714103, 9.476210994105186, 34.983356768085116, 53.58948446089222, 52.58389857507522, 38.06286450355284, 75.31637930100965, 47.154808736616566, 36.0819185164667, 31.420191372594527, 43.696058796298125, 80.71598468288299, 81.06847240078835, 81.46024657833962, 84.92931627458142, 87.08971854179137, 83.26171275108092, 36.19201552483344, 1.8603207243065683, 0.2917565267172552, 0.00955217029719103, 0.050846462122975826, 0.02751419144201904, 0.007235730609541098, 0.032243434144484426, 0.027346774417486404, 0.004840518409881982, 0.0723697827948678, 0.10920524371847992, 0.06488334177242172, 0.08532696493691014, 0.021503243422616395, 0.014981021729087638, 0.06350742870821588, 0.08792114549226339, 0.028434450730621338, 0.05606904438125992, 0.03649948540353968, 0.09061180716080051, 0.05879371269275585, 0.013814615517584308, 0.02126469704953413, 0.029107571970070564, 0.05320689010043299, 0.03855311048908099, 0.01706333489217345, 0.04263353609149495, 0.055527320627363465, 0.058332075770463676, 0.05322288218585234, 0.011586007331648182, 0.05654837793460297, 0.009999432537193981, 0.013895162001943157, 0.08016272027406, 0.04779650904839078, 0.03115066909231246, 0.06871011949354602, 0.04488391553862922, 0.044341640201427286, 0.12508882044423975, 0.1118724707574133, 0.020461764126535387, 0.05515179964863966, 0.11214319856897478, 0.09579081433795153, 0.08795077777317456, 0.19162111284752048, 0.13409969216633227, 0.09323129160029274, 0.09284066336770212, 0.12135759686991093, 0.13800680186719666, 0.15658711533873312, 0.18045827716348634, 0.11434805324120868, 0.211498734931792, 0.1735343745038394, 0.15226641008930822, 0.1994903680057295, 0.24928755397277497, 0.1238992544371755, 0.07958966352406048, 0.1643072897868772, 0.14878288572353704, 0.1773355189230173, 0.14528198648364316, 0.11107573931616162, 0.17532809276974973, 0.07932534020754599, 0.08207645387418809, 0.17250473701184796, 0.1494448469771493, 0.11836115120639724, 0.173023761580548, 0.11105937567809898, 0.14017250178562057, 0.1108334257057117, 0.2042233358107267, 0.1531715429718456, 0.1593600931547342, 0.21156690143529447, 0.25313886182923473, 0.34017294645309454, 10.005543674192122, 77.55458570295765, 111.78460028863724, 95.45004660083403, 90.17116392812422, 67.96722258290937, 45.05467368710426, 40.15284061431885, 62.89777094318021, 109.42275293411748, 103.56618358242898, 115.22218904187604, 72.76603068074873, 55.29619401501071, 63.466467549723966, 9.600983550471645, 0.8509387808942026, 1.116498011735178, 0.14465921828823705, 0.628236776157733, 0.4293654378383391, 0.5628297213585146, 0.45215122161373017, 1.6084389821175606, 3.767183312485295, 7.4635938290626775, 8.3776423815758, 9.094130954434796, 10.589259036125677, 13.031871914863588, 19.511259717326013, 15.428230243344462, 21.032427433998357, 20.1650756789792, 17.886537505734353, 30.850447493214762, 24.62517926769872, 20.879666805267334, 16.33853783530574, 17.608310061116374, 21.736843932059504, 33.59186064812445, 24.711332167348555, 28.930745393999164, 33.75231304476338, 42.89707199219735, 25.63512290677717, 31.430671945694957, 23.55339946285371, 25.99380796955478, 41.2966194460469, 36.83245228182885, 20.76638287113559, 32.686658020942446, 30.897476711580833, 28.828402911463094, 27.05255569950227, 33.664134240919545, 23.80034012179221, 22.09495436760687, 33.28562551929105, 22.469548563803396, 21.153952267862138, 15.770810054194545, 8.51796321330532, 1.5024549465986992, 0.5625392821046614, 0.2490277429141345, 0.20101137429235444, 0.2203211566853908, 0.332372332772901, 0.7011502055871872, 0.5819556273279652, 14.599692302365458, 49.45477285692769, 71.50886397207938, 79.13604613273375, 77.68212549148068, 144.84081422128986, 126.08907638057586, 95.89629465533842, 29.017537639987086, 28.54997346478124, 70.71828672962805, 76.33938051039173, 87.58829885913481, 92.88854275980304, 96.34099729599492, 102.89501113276329, 57.88409932967156, 6.071634379125411, 0.5406078395824279, 0.19341144500480545, 0.09596501507105366, 0.23413206721025132, 0.18819444752748937, 0.1262577557035031, 0.13636470772325993, 0.16736968029891292, 0.14423632243227574, 0.18609634720750395, 0.18340193936901708, 0.11299321908623942, 0.11994911357760431, 0.10204694879752013, 0.119236069581201, 0.20904019024343262, 0.0619933057215906, 0.14304785959182248, 0.07936964307220713, 0.1429977880850915, 0.1015499186131262, 0.11922794138832439, 0.0819628430350173, 0.1010217852590065, 0.13441040210666197, 0.16177345397731951, 0.04585748305544258, 0.13893131677421833, 0.16153140083676384, 0.20007334559434847, 0.12984005944623103, 0.14256310979685477, 0.09419837801326668, 0.1405312760823196, 0.15089747225565298, 0.20270925495893727, 0.13370321102200017, 0.16769419514363812, 0.1028918365256921, 0.10385355266231684, 0.2832421335962511, 0.14909958647143456, 0.18775609201721608, 0.13508126530195438], [0.047387578975289106, 0.016102798530952107, 0.10750273588083445, 0.04595563040986177, 0.026881864384537744, 0.01476562653307713, 0.02715681717100163, 0.0400703706057562, 0.04538734255719089, 0.020883681305173426, 0.014537899236705516, 0.04685825818488675, 0.1119391740329804, 0.060885864340009234, 0.07817158881094187, 0.030513349056784666, 0.045936485872634, 0.02057057350964075, 0.05723074010963883, 0.03267579884718984, 0.036323530329090935, 0.03931960443996134, 0.05198568849253559, 0.013538292391345868, 0.034068914415735396, 0.07165145279178697, 0.05603580382622539, 0.018270651156443263, 0.077097954889459, 0.08174751870213978, 0.05926224440636654, 0.03338595852255821, 0.03619918659810097, 0.03091806947674242, 0.02622581924492073, 0.08340779977339892, 0.11896944034003443, 0.14033549465239048, 0.13176781245537345, 1.6097643755136, 12.35856177345399, 45.881379881212794, 65.02235804834675, 50.26899414677774, 83.1496584799982, 74.41451657202937, 135.082490674911, 113.98328488872899, 35.04201189164193, 56.56470814058858, 50.4966288997281, 36.17705560499622, 41.29362275523525, 37.071638414936686, 13.800369155022407, 0.807446988840257, 0.0739767594683555, 0.051696536266395164, 0.07289976242088503, 0.11828612055509322, 0.06286185790574358, 0.21490041046373307, 0.5797224503851707, 0.6628355131514612, 0.6854696115178447, 1.3150553765796846, 3.252788979199625, 2.5342928882568114, 3.4946357050249657, 7.962370264914728, 16.984370793065718, 20.081544883789558, 28.286215643728937, 23.974230558641498, 17.009350407508112, 5.697375545578619, 4.877796298073185, 4.506544451559744, 4.825209571469215, 8.105974120478477, 6.67110933411506, 8.84003883407962, 15.835859621724776, 3.0126658899168817, 10.074838226841344, 8.744891939624663, 10.645861779489826, 5.45607231317028, 4.011434696374401, 8.327585093436703, 8.881009951714548, 7.625506327998254, 17.76249254903486, 13.941325410719841, 6.991011471517625, 3.6396391112958235, 3.971066643153468, 7.123776837702721, 13.862827016461281, 7.836151824843499, 16.540389868520922, 14.296316581387675, 18.412452820808657, 23.82394494548921, 24.343051025944373, 18.86848326652281, 3.418819476519862, 1.3928941997789568, 0.6209182462865307, 0.440854826160977, 1.2471108547141476, 0.4181336695628782, 0.12411552871907912, 0.24077164399768078, 0.3415323847964887, 0.6636717747296057, 14.553924126009788, 44.57992176855765, 65.04847318895402, 48.10746223695817, 109.55888271331789, 130.87963181157266, 84.51623578225413, 42.69924725255659, 28.274011188937774, 27.78144190388341, 51.877032556841456, 59.66200774715793, 60.00596823230867, 63.57519565090057, 75.05767545392438, 54.83612745038925, 12.361719281442705, 0.0967319533529301, 0.07334122058725165, 0.042962206963209376, 0.049806543731040535, 0.07586262278979825, 0.0153328035582578, 0.10584353499354855, 0.08862331870102114, 0.030320923091963898, 0.04995812954861791, 0.1116827950482407, 0.036191138844456405, 0.03191548339541882, 0.027157970133327672, 0.02622705264647882, 0.027739224024116996, 0.04699457970057284, 0.024113015782448555, 0.004607128287335077, 0.04230064024487811, 0.04616391439471514, 0.021859476222626625, 0.057998233805260355, 0.09177916427893985, 0.05110557221116559, 0.04025776720335407, 0.05352565162484685, 0.06744291813623521, 0.03278346101362859, 0.047585639516792955, 0.04040752590123204, 0.06895394995808601, 0.029923716079323526, 0.03390294146694003, 0.03141062762287836, 0.015354204224422576, 0.043208190134816596, 0.016888205277463122, 0.039811800609553055, 0.05411444382081109, 0.027780219304165053, 0.0626729023192198, 0.09444902666033277, 0.02949069828666266, 0.036331574252295884, 0.050411848952212644, 0.05486729757619962, 0.10231185434085709, 0.028113645666669455, 0.04541615129358346, 0.031098027360595526, 0.052014152489362225, 0.029477877805249828, 0.019814226393317504, 0.007967600259073681, 0.018611449199999054, 0.11503152624373475, 0.06920630698122325, 0.017717853601601337, 0.042964248587527586, 0.04550298735980065, 0.03876824329997744, 0.03499436395002469, 0.05666321834489223, 0.05043501928148251, 0.028903737040837447, 0.05632749946427442, 0.026329405823602315, 0.053591630947325504, 0.10123953809060397, 0.035839830074579485, 0.050735946279019124, 0.05007871178789966, 0.0557048500124966, 0.049026827102587114, 0.05103218864889876, 0.05937047347786927, 0.03678936158276854, 0.0852825548199396, 0.11876207566069019, 0.038282126038064884, 0.23163626000525492, 2.8351073015120725, 18.840085306475242, 68.14452940417875, 90.74479487634476, 77.62684360627206, 115.39423204237416, 91.54906119069746, 116.71833792040425, 86.68770697809036, 23.136027897557906, 36.724743996897054, 45.26414002141645, 41.51296561764133, 50.36298982558712, 47.28316830050561, 17.15050474289925, 0.7583175251080144, 0.5085697667973658, 0.0572800072240493, 0.14264224667943295, 0.4405635595321656, 0.9959475191370134, 1.355215911903689, 1.9077001367845845, 2.7364028173108257, 1.3035184601622245, 0.7816844325392478, 0.7739764235673413, 0.8043788986340646, 4.354351585911167, 11.898189263959086, 23.39750486035501, 33.51915167224023, 40.05829580368535, 33.80679868882702, 24.767869211012318, 10.803010559851124, 3.9794364908049187, 1.7341987500267646, 1.0926203381630684, 1.0180187573836696, 2.841237475795131, 7.613418563719719, 10.273234651934716, 10.427392625039625, 8.24227354218883, 1.5529825514362705, 2.274861196356435, 3.7242465970977663, 3.4678147829348043, 2.722880446141766, 2.345779855405131, 1.1636415917065837, 1.7719292544549512, 2.7643612267509585, 2.681459236529566, 2.6864926180531903, 8.157454738693854, 13.882013290159165, 21.782680749893192, 18.755505277264504, 26.084318622466057, 24.264446727691162, 29.842853353869533, 36.53377163794733, 38.928853234937115, 29.27753390804414, 9.667197081350512, 0.9478044702160744, 0.8521397003243047, 0.5013700111979439, 3.5200651662964977, 1.1580881284129236, 0.21830476730340914, 0.2658820602922671, 0.6742176185211828, 0.5528466763996309, 16.66606260884193, 53.253957071611964, 63.7927891362098, 55.197150245789565, 107.82049609768777, 91.52731557046214, 41.714606823459754, 33.096088747824396, 43.16533073302239, 53.96173700209587, 80.04790306091309, 94.02421797475508, 77.39345473627891, 81.66978743768509, 88.13999591335174, 67.4564907627721, 12.439936245641402, 0.11426074986135769, 0.0214004248470789, 0.027396401593221292, 0.013368306099437179, 0.10869463845606774, 0.051064084719626174, 0.11160317553027023, 0.02823361695083159, 0.020735286243800676, 0.08644324697313771, 0.07417188972354898, 0.08431705420896893, 0.05075390337996426, 0.04169296015114073, 0.03275734124585025, 0.08935489436431278, 0.0007752527298796321, 0.0678468379943121, 0.029405834896850492, 0.031186882068493196, 0.019392600328090693, 0.05679891166848041, 0.07160734910998615, 0.022526597078408928, 0.025677018753823735, 0.0318082751360752, 0.0618545480463053, 0.01073712349734119, 0.02679840868128644, 0.041343700666461265, 0.02724272244039082, 0.04062294216466047, 0.03562510712072253, 0.01142632587993097, 0.0427820039312205, 0.009842830758932377, 0.010503510730491291, 0.03710720380167327, 0.04832350859238256, 0.04359851576267712, 0.05629168868425393, 0.04789852514682759, 0.06901675384611854, 0.15476082301428243, 0.1442698157963253, 0.2649128058504674, 0.19125188911153426, 0.1970674157623322, 0.08570057069582325, 0.21653113586287345, 0.2502885397763983, 0.09415532387192212, 0.11764936359418977, 0.12390587343684129, 0.11452668962339241, 0.19463710907486179, 0.22361170350303575, 0.19417400892463424, 0.09711483643660623, 0.1268049110207827, 0.11565093131315325, 0.17219502298581987, 0.11230413065922838, 0.1094351850089527, 0.20823095624725665, 0.1112566433186012, 0.1661191796583514, 0.114002478639445, 0.1629926982305704, 0.13745900303606065, 0.11534356917705267, 0.14356919774605384, 0.1360291305689081, 0.11991951960108935, 0.1702222852937637, 0.1698655181474263, 0.1217308042631034, 0.1911022414964053, 0.2508370893737001, 0.2332768985821355, 0.262654960876511, 0.2764599572025961, 5.8090488564583564, 35.93881868547009, 101.0691007491081, 106.81731070241621, 77.75541890052058, 122.48095866172545, 106.41769178452031, 161.61031169276086, 145.79591135824882, 60.81087389299947, 84.15970017833095, 80.24853229522705, 58.68555330461072, 69.04926330812516, 59.39542385839648, 24.69982981681824, 0.995683923604027, 0.500940818099245, 0.11691510662316315, 0.30193801909204454, 0.43046649004663196, 0.5110260591872278, 0.8496999247900902, 1.2934280403198735, 4.483552007905899, 8.22158500071495, 7.240330557669363, 8.86083229895561, 11.451231260453502, 8.955382993144374, 14.931313010954089, 21.321547300584857, 27.523020467450543, 36.394241163807536, 29.385838393242132, 23.805925576917588, 17.054163486726825, 19.300559797594627, 19.67476764032918, 19.242679342146843, 23.67026452095278, 18.559059250739313, 21.093743885717085, 36.27637394012944, 20.704497675741873, 26.798564580179033, 31.260299874890237, 28.546782616646063, 24.22161836777964, 17.27392996511152, 25.580919673365933, 29.646697582737094, 22.76187692919085, 41.469756787823094, 32.98496407847251, 29.212163686752323, 18.45400444922909, 17.03262967448081, 15.578811995444761, 25.287781338537894, 15.794950281420062, 26.60132819606412, 21.953392105717814, 24.205195403868153, 27.5254072297004, 32.234251845267515, 27.30549562361933, 9.139591224731939, 5.691566025057147, 1.2836369463512975, 0.7515524784403463, 3.5354016336702534, 0.8479385354345845, 0.15441619070066562, 0.5307742736993298, 0.8709457492636097, 1.213927725630422, 25.508467612727998, 71.80997648546773, 98.50006595734628, 61.59572055262905, 127.09702353323661, 151.09782618861047, 113.84615098276447, 63.66194671200168, 39.768875875780665, 38.09872673403832, 73.99421107384467, 83.9704458175167, 84.23074999163228, 87.81924801488077, 102.58947418582056, 91.45194330523091, 24.652788831341653, 0.29577622069947185, 0.07333458626582738, 0.12266882530023014, 0.22186571251480813, 0.22663048829042146, 0.13441980966637213, 0.2366429816691145, 0.16145656936832015, 0.14775159348162914, 0.15356255424839838, 0.2180608602300767, 0.19013959073251296, 0.10974882906603237, 0.20601999585426625, 0.13115124957215402, 0.13251341518855866, 0.1356277617836191, 0.1396525885549284, 0.11521085210505033, 0.13061478884229738, 0.1593415691487251, 0.18860081120604472, 0.16845435354738467, 0.19488222656711457, 0.11070491445641364, 0.12843372886099164, 0.1663934851005193, 0.1280485934788181, 0.10767568022974076, 0.12323465018022446, 0.1658815545059981, 0.1095431421192423, 0.2063475597289301, 0.08047421162407245, 0.1090526849692387, 0.10044516620015907, 0.1024714840816394, 0.16366870953671395, 0.12651904531183744, 0.145958763877711, 0.08722409741171906, 0.19475812032338113, 0.2996571301933258], [0.07890313383071654, 0.015857741368123363, 0.018555218346356865, 0.04654830667160211, 0.02467441075902072, 0.02236348355279094, 0.024097525484619603, 0.016131251036459883, 0.0236209383564851, 0.09440539029216576, 0.0434538132450994, 0.05107484059408308, 0.022009617964466734, 0.03415218051222544, 0.05508061858915514, 0.09428991785933895, 0.02226198456370302, 0.06843597492984227, 0.01963164465832374, 0.0024256821498349914, 0.08496297358144676, 0.12029216008921785, 0.03816874502527137, 0.03926425075699245, 0.07184125107502745, 0.024983929432628137, 0.020013489692862478, 0.08822820119319424, 0.04118880151861137, 0.12860834328157286, 0.07000746641067729, 0.05533663368213081, 0.06358412560075521, 0.023082755844018633, 0.05301076010049832, 0.030077140507919174, 0.10241321543411863, 0.6695387824889153, 15.359397549783031, 49.033125908144065, 78.40332385032409, 67.73785806471302, 73.8615486698766, 68.0344912313646, 34.57182168960571, 22.636643494329146, 45.2230453491211, 94.17979486526983, 74.43056691077449, 39.135318956067486, 37.37164481993645, 33.63763470803538, 20.143973327452137, 1.8728927787273162, 0.5324907396589557, 0.12236879462556494, 0.06580233318550933, 0.10587481436349692, 0.0814118572781163, 0.07021720596258679, 0.3022512264790074, 0.50780919470614, 1.1074429750442505, 3.3760016579781813, 4.069090841277953, 2.397400208057896, 4.553702617845228, 31.16688470686636, 76.78016078087592, 107.87293818689163, 133.564266697053, 137.3611524028163, 135.5827340772075, 137.1261396715718, 130.86850796976398, 109.6916078752087, 73.03960031078708, 34.98447072121405, 5.890848415513193, 2.4512040951559624, 8.80558277330091, 8.18572816348845, 12.75346992477294, 17.535669726710168, 14.852543973153638, 8.374621175950574, 4.996304829274455, 6.345104479020642, 10.6800324878385, 3.3512024725637133, 1.9992503403655946, 6.853207820846189, 6.7808768633873235, 2.9095690865670485, 6.501627641339456, 45.96322013485817, 90.86516457219278, 114.0223438509049, 129.8671817779541, 137.07962036132812, 131.6996817434988, 127.2571268389302, 140.2495857977098, 152.55530049723964, 148.62070821946668, 140.52570496836017, 124.72735497259326, 67.94673996586954, 10.056466825546758, 4.013850876400548, 6.942813877136477, 9.587095418284017, 0.7345889628894868, 0.07202247683439525, 0.044467968100141135, 0.036849327115041595, 0.5549684335147181, 3.143471051608363, 19.210792433831003, 42.30224847793579, 34.0143548288653, 59.83050100265011, 97.91372652976744, 102.545120023912, 51.37835418024371, 39.98787356961159, 29.796553696355513, 23.89484570872399, 36.382356382185414, 63.84212078586702, 65.06615915606099, 62.18954778486683, 70.54654182926302, 19.450778730453987, 0.9381898216182186, 0.1465544738476315, 0.06003780883827037, 0.05117381532346049, 0.06751765001324878, 0.049908965856077216, 0.07010740258039967, 0.03078734614856301, 0.03610088602609692, 0.08163718671928491, 0.04701835523930289, 0.06980056904496686, 0.05303253614974599, 0.025974331731577555, 0.026830511595753413, 0.023420774903629097, 0.005362871151808049, 0.04045489694802992, 0.0923261127524799, 0.04863999866610093, 0.02447232251025496, 0.05792997537120696, 0.01712973173257084, 0.026729071978479627, 0.025435090102555773, 0.0233495804376059, 0.07511213241565613, 0.05006159738367123, 0.029963954847546357, 0.050502611219041774, 0.06648454214296033, 0.015323716797865929, 0.018721354088836142, 0.010455660878740733, 0.02300252154048893, 0.04989642882719637, 0.07153418005233811, 0.04673045939735828, 0.053509751469978405, 0.031235331384044503, 0.06033406652990849, 0.01610377337783575, 0.03174551146765871, 0.01395837574701516, 0.05144710186868907, 0.032101487628214305, 0.05818350450886835, 0.046029967751594326, 0.03341646797414268, 0.07732880016368243, 0.029587843981120857, 0.05434792826793367, 0.03597206068074992, 0.03852431707444691, 0.028584806977080244, 0.02143748626563578, 0.04503510299048597, 0.08992540770240369, 0.0405360754549263, 0.03274284303188324, 0.07423474723773618, 0.062447660978162484, 0.027343953298705242, 0.08727811427126009, 0.022082844478709084, 0.06177253833401108, 0.12179691765096881, 0.01871905199462368, 0.03402135567739606, 0.04892141723464574, 0.057148803175697406, 0.09036934033276574, 0.01748940809780071, 0.052360899205650055, 0.07647278117797068, 0.048656216747457945, 0.16256266243515477, 0.026331531717592192, 0.04513506980372533, 0.6513880145165228, 23.742404753162017, 68.00029600820234, 107.50406280640634, 95.18488653244512, 111.2135345705094, 106.54864403509326, 74.65015688250142, 50.464712573635964, 85.2276203709264, 94.26559279041906, 49.035926480447095, 46.39318250840711, 42.13653618289579, 44.02990348877446, 24.997894648582708, 1.9911435366638246, 0.696022809753495, 0.14647538293032877, 0.060744984601173675, 0.18682837486267093, 0.6266178791561435, 0.4925944433817941, 1.5092146612944142, 1.918167962181953, 0.5121976527715884, 0.7343606686880513, 1.7593250856284173, 1.4101310555011997, 7.586704281068618, 39.38902178118306, 89.66836314047538, 124.62285518646242, 146.43911730858588, 147.01959671512728, 143.94381523132324, 147.62972924017137, 139.8810242068383, 125.44489768243606, 90.44167410942816, 49.01591847019811, 13.356650048686614, 3.595085889101029, 0.9908842908278589, 1.3457416719005955, 5.7158832492366916, 5.964433550834657, 1.6778878555182488, 1.2759810926452761, 3.700659178918408, 6.475397771404636, 13.728310311994246, 4.004767647674007, 1.1197660815331245, 2.24549759780207, 3.7469144646198522, 4.806678333590108, 11.567697217387538, 61.541313355968846, 107.81261213364141, 131.109451324709, 145.05696819674586, 148.5465754232099, 144.1144540232997, 136.8636389701597, 148.28992689809493, 156.55185053425453, 154.73621676045082, 148.59047459017847, 144.51670092921105, 84.51245461740803, 18.699788008966756, 1.7537789767788303, 6.389828814614204, 7.026612864386651, 1.4878507367064877, 0.2106819932739581, 0.17412345015233563, 0.028468158599289677, 0.7993984078207325, 2.8419067302057823, 21.603526492272657, 50.57855544551727, 37.713118522397934, 63.56446012373894, 79.3297641508041, 65.84842097374701, 31.779488325119022, 28.89203944513875, 51.77772598881876, 48.06852486825759, 69.11858727855068, 87.17690498598161, 82.5089785360521, 76.71270385865243, 88.21121046620031, 24.83673622531276, 0.614269890131489, 0.16150656426625867, 0.06122551708211822, 0.013912443030295114, 0.027955258903544278, 0.020113515877915968, 0.05600683804180834, 0.06737421537118574, 0.0923487889550386, 0.019090434183336554, 0.02778400569373081, 0.047261699238010955, 0.05002569084266021, 0.0339517412677167, 0.1032276971325759, 0.02179549255919072, 0.036767681294511405, 0.05147160136050755, 0.07061846749556643, 0.05006837726180112, 0.04150397009066036, 0.00996219874885414, 0.10078677246647497, 0.02769512034231617, 0.03731446505914773, 0.009028367255063308, 0.05608033651726381, 0.08821559904683983, 0.037989223811535106, 0.03932119407240422, 0.07633614939667525, 0.026619948499325304, 0.04997425952986364, 0.050380221012258725, 0.0037274565763636344, 0.018833859846176162, 0.06407742493695791, 0.04085964801150464, 0.027436420111165895, 0.10158076897383699, 0.02620135231183902, 0.012351681568449544, 0.13691204690164135, 0.17476558505046755, 0.15552248295036056, 0.15209367258414147, 0.15144383084149132, 0.18032539155214064, 0.06311971160973753, 0.17841023302847342, 0.13097403811350947, 0.1601112270427327, 0.14114633743320742, 0.16741978244916086, 0.09714877413165185, 0.11753688656514692, 0.11054292516482454, 0.14354114360626669, 0.26055257046414965, 0.14366587804209802, 0.12464792918293707, 0.18664891110552898, 0.12540662435874825, 0.21915250487865942, 0.15216387688152253, 0.2469263790595916, 0.3530606290986461, 0.14095637827150284, 0.06759578332064614, 0.15373366764716564, 0.231609538858456, 0.21299470546505145, 0.19871925454466574, 0.24935973477700066, 0.12796551890430913, 0.16243932227934563, 0.26446856678493563, 0.16206652857363224, 0.43214799175339363, 3.539441429799603, 42.41826042052239, 100.18520247551703, 128.69221225861583, 100.8909623853622, 108.811428008541, 99.06601690476941, 46.670913773198286, 35.2358671926683, 57.0653163233111, 131.95885627500473, 135.22609649165986, 59.49000397036153, 65.56140545875796, 57.62664279630108, 34.82985481139153, 2.5100595047397, 0.7366310468604489, 0.2184257785519285, 0.21018682468322017, 0.32737655084460016, 0.31746367953958055, 0.2314360199436065, 0.8262141205130086, 4.463771985423181, 5.920573607567818, 9.97517276194788, 14.07080481129308, 8.17763533323042, 7.982372881904726, 38.68885517120361, 88.81698916035315, 121.51158409733927, 151.20689945836222, 154.33483277597736, 152.62229457978282, 153.672909275178, 146.43790921857283, 124.16524010319864, 83.44775861309421, 44.70545722592262, 11.164029432881264, 12.813041902357533, 26.673066385330696, 24.674248118554395, 31.491249030636205, 38.90375791057464, 34.31039571762085, 18.500007967795096, 11.765524898805927, 11.209026863498073, 17.49601652545314, 5.819044036249961, 9.692351241265575, 24.391272644842825, 24.662755573949507, 11.837542556947279, 8.695057245992846, 53.42958904081776, 98.80548523318384, 128.48484439234582, 143.78455131284653, 150.03304389215285, 143.74011870353453, 135.4477260958764, 155.12508053933422, 165.56705751726705, 161.25893008324408, 151.51960649797994, 141.07216958076725, 75.04926589227493, 14.433023929595949, 6.668971152074876, 10.238560899611443, 13.216576326277949, 1.1144490636164144, 0.2679679951360149, 0.2144841642509545, 0.16834495619179743, 1.0609834809457104, 4.611852245946085, 31.829424019782778, 73.25663289716168, 49.981978631788685, 80.13064938206827, 127.14122864507861, 142.35280775254773, 75.05116431943833, 61.64827639056791, 43.167189936484064, 35.45520221033404, 56.03143053670084, 89.9028738083378, 91.0721480461859, 85.80690737693541, 105.60068561184792, 38.869284199130156, 1.61141888028191, 0.38203128583488927, 0.17570430322760539, 0.14667150143894458, 0.11201966689118456, 0.13212349175685836, 0.1532973958960464, 0.16893629946054953, 0.1943521703323049, 0.10225478079049818, 0.14030629138071693, 0.17501258711901405, 0.16457637050940147, 0.09696740281557846, 0.24290883012356299, 0.1148730379739596, 0.1773708662198436, 0.09782174406873603, 0.17407811306897672, 0.1145394679699694, 0.15744976098498992, 0.18337348686350932, 0.15921904104611567, 0.14138514236096414, 0.10108214532656055, 0.1321702231202395, 0.25156784532291276, 0.1346090487054279, 0.09822260723599503, 0.160786472260952, 0.18192800152445995, 0.09787713988654076, 0.13028979902305912, 0.11051109421157068, 0.10603521019220354, 0.21625615626333222, 0.11783104134543289, 0.13266534574570196, 0.13936461610419137, 0.1846592275485877, 0.15077623118075634, 0.10285498769653421], [0.020356132093095974, 0.042327587387614676, 0.028235890316746892, 0.05358456378622402, 0.06215637519715294, 0.07022262220421145, 0.06494376312700972, 0.08558259315548405, 0.031113299323366057, 0.01929160887225261, 0.06760958056416243, 0.005096727418863485, 0.04709067010891534, 0.02941475982116836, 0.0367163150991884, 0.026534024077738007, 0.04365170907769953, 0.06660868669108999, 0.0452162827845783, 0.08886897245482092, 0.061238172854627335, 0.05061396592927556, 0.014355670859766825, 0.0506797269166958, 0.050217235806368055, 0.11179704940126789, 0.04558534564210042, 0.06323435283716648, 0.08603771833041984, 0.05131800456212894, 0.046900461968635364, 0.0776206260366786, 0.04373607451036092, 0.04485690327841909, 0.08340946984507384, 1.469681092327641, 9.130937495539266, 44.27223928513066, 74.11821288447227, 83.55407837898501, 61.558783592716345, 45.406439688897905, 27.404798269271854, 46.21792708673785, 34.80239037544497, 41.86294694100657, 29.666872293718402, 39.92204835337978, 33.40336330475346, 39.812645604533536, 29.203254022905906, 6.3342748149748775, 0.17363103947812514, 0.29391202234452773, 0.16659040034057634, 0.25043523029213954, 0.15023555696731614, 0.11935146540523538, 0.6780560254569977, 0.619555161364617, 3.261937172182145, 4.9290999193345355, 7.6407050221197075, 2.6590514711795317, 10.089776573642608, 49.11266373049829, 101.23106325826338, 124.87197276084655, 121.57088248960434, 117.45956390134751, 104.9732554343439, 104.86302114302113, 102.67079276423301, 103.26275687063895, 103.09561683285622, 117.24533188727595, 130.95702017507247, 137.37819117884484, 118.25348300318565, 55.247482099840724, 9.809793868372518, 3.0553420128360873, 4.332473585682531, 4.604335023510841, 1.8967760907065485, 6.545204193361345, 39.429249609670336, 75.01260742064446, 81.36047717063659, 48.2145429426624, 7.722660495388893, 0.5774517657776033, 8.111676756412752, 37.95610935457292, 104.60567443601548, 139.19194221496582, 130.87256370052216, 120.57918179419734, 112.84045527058264, 117.27565180870795, 117.09888627452236, 118.91378264273368, 115.29845560750654, 106.26430357656172, 107.47245634755781, 111.84553823163434, 119.80481963003837, 141.03139262045585, 140.99568336240708, 57.48738296570317, 1.4861420542001726, 2.9397610406721792, 0.6622184752937287, 0.38570909009825805, 0.027747493943259604, 0.033371268786610134, 0.22484489055650853, 0.09046308651205995, 0.12990107068852072, 8.50901726753481, 35.773200527314216, 40.65516287280668, 47.03760047112742, 47.088736411063906, 66.7353630065918, 75.5664853126772, 30.066010721268196, 38.216280168102635, 21.509658290493874, 32.23007844340417, 56.069022532432314, 67.4491245515885, 68.28738997059484, 63.0155832536759, 25.346883612294352, 3.1467717261083665, 0.2579334384251026, 0.04105252979864036, 0.02228569690017931, 0.07474439489024301, 0.05495490739122034, 0.05390951147062644, 0.06487015739924486, 0.0331900698403197, 0.05886225840978085, 0.05350258471744676, 0.025392336650721492, 0.07732475521944224, 0.035906173288822174, 0.061042881720969756, 0.049471372603288585, 0.04921768258716311, 0.015741581371384525, 0.07185916221069713, 0.012389927550459342, 0.05242745692451155, 0.055495290491249294, 0.028431327007110083, 0.014955832758137296, 0.061206629184345086, 0.0493985521156461, 0.06783498661412347, 0.04208010268367587, 0.03209806513041258, 0.023665767906594182, 0.013621011692579958, 0.06462952152134911, 0.0521008238466757, 0.015050708917119812, 0.023040728260492607, 0.05962772963328227, 0.045430745268541003, 0.018787235735104452, 0.0486596449909191, 0.029233285083225178, 0.06675045126147809, 0.04832828132015082, 0.027722151754724405, 0.015618880898992141, 0.05091771979125277, 0.03442397318600166, 0.05557543094900828, 0.05813937784442979, 0.0340035364722773, 0.0286708673792741, 0.04114482807175767, 0.05701607461237619, 0.0411942292515549, 0.04804783568326985, 0.037043764060663606, 0.08028327186982478, 0.025330526761770732, 0.026662625342367158, 0.0181390947076462, 0.05011651439652328, 0.022352478699758652, 0.023476927233259046, 0.034625814371411844, 0.04006524547754277, 0.039707321538439685, 0.04864871674667924, 0.09911737494891691, 0.1096463188408844, 0.02056059329920719, 0.05086434261512853, 0.11401623757856508, 0.04920053370897809, 0.05952304754886897, 0.058788702477731054, 0.053706919519050475, 0.096352226551502, 0.762282980065192, 15.550697426642142, 63.02189042491298, 98.70771623426869, 106.39300438665576, 88.92203807830812, 84.07218425504624, 63.99154739995157, 78.97374629974365, 35.662825030665246, 23.42998600775196, 21.01899135497309, 37.55183850565265, 41.28059264152281, 48.87070055930845, 39.114122467656294, 7.451160896208979, 0.20489948501269664, 0.27407831242007596, 0.22218192296643413, 0.31691083984990276, 1.0921528406681553, 0.2524377075174163, 1.0237745904634077, 1.139376584079958, 1.2336904651695684, 1.5938496036875633, 1.4836395820302348, 3.821651796179433, 15.944732850597752, 59.38983840327109, 115.14201579555389, 134.10079986818377, 126.40404270541285, 120.86285544979958, 110.17435750653668, 111.41781160908361, 107.44758067592498, 108.1764276566044, 108.54729560113724, 117.70885406001922, 132.30193814923686, 144.08236903529016, 129.256343226279, 70.03041282776864, 14.90727770713068, 1.415377715902944, 1.5702721140077038, 2.895878298628715, 1.30641917547872, 11.700356679577983, 56.85900749698762, 94.52781108117874, 107.0433412059661, 71.51199402347689, 15.373196448049239, 2.347275504181462, 17.61811794773225, 51.70051413197672, 118.84627080732777, 140.43224273189423, 134.2561257270075, 121.02799507879443, 117.26118610751246, 120.00609213306059, 116.79574197338475, 121.56218267256214, 118.52160838342483, 111.4123595145441, 112.70095225303405, 114.2417141699022, 121.92225625438076, 142.42830553362447, 153.82421862694525, 75.4104220482611, 3.7892081564472573, 3.1539974674101803, 0.4363399942315394, 0.075084836702914, 0.18617269553003774, 0.19910992874253183, 0.028453403745868036, 0.19324005581438544, 0.16145682983821438, 8.29902631621207, 46.12361761831468, 45.33518983471779, 45.731604176182906, 42.35327066913728, 48.79409666984312, 54.13786318994338, 22.303814695727443, 34.51015418575656, 27.356003984328243, 62.3341263494184, 85.01076821357974, 87.14891495243197, 85.37197928274833, 79.90026504762712, 33.97808074951172, 2.508056889618597, 0.21610301528726855, 0.08293032781371186, 0.021889792237010215, 0.04443087029240785, 0.09307947595633807, 0.047587252131873564, 0.10320596321816407, 0.0205836468000686, 0.0053656855673198745, 0.05179888178263942, 0.04042848989727997, 0.004952756515253456, 0.031139704458896193, 0.09473991024518207, 0.04151736896845602, 0.010306126261580615, 0.04962138411018157, 0.033163712585284826, 0.0622624630529073, 0.043059871682236274, 0.09534074534331599, 0.030138349017849377, 0.05211729473704773, 0.04783898479335251, 0.07350401427116125, 0.06239861602925005, 0.03202260163943133, 0.020428764889197006, 0.04645553725441137, 0.10099115706379376, 0.03620652572041558, 0.05047417403529248, 0.04039106267173925, 0.00977221756212173, 0.017153189344812306, 0.036800872053830855, 0.018834844269158862, 0.020753139922876033, 0.07360849334227462, 0.05140417796229163, 0.09964953026463909, 0.1260340580296132, 0.15333160938274476, 0.20198091984756533, 0.13088880317105403, 0.07850004900847712, 0.12897545261488808, 0.16033618110081843, 0.11285441161523904, 0.13705248613992047, 0.20939211571408858, 0.18432654620658967, 0.11560245326930478, 0.11889253277331592, 0.22579316951094136, 0.14362806394215555, 0.07973557263011895, 0.23282371160964813, 0.18053559075680473, 0.19298439695229455, 0.188312501676621, 0.1565817220797462, 0.13783187335056646, 0.14882109818920014, 0.2772678428840253, 0.18217492698421403, 0.18933987154835658, 0.25925346920567177, 0.14629237984697666, 0.2628571774450041, 0.18430881893202183, 0.11949526010862282, 0.16470012435268971, 0.1522107614624885, 0.25768599202556, 2.7463698050668164, 34.55956036044706, 97.39036467767532, 123.05546037612424, 121.18452118289088, 86.00475957316738, 77.51285952906456, 44.96785202334004, 67.21459819424537, 58.922519376201016, 62.32894882079094, 53.1957334087741, 65.22279508652227, 55.31298960408857, 64.94562079829555, 50.355474564336966, 9.450806783091638, 0.974785841761097, 0.5022633922917228, 0.6222910145598074, 0.611170482250952, 0.6382351428751023, 0.20908805541694167, 1.5406897207421641, 6.269148270930014, 11.41913450533344, 15.75687877593502, 16.553498429636804, 6.142139963565334, 15.880940402707747, 59.148259624358154, 116.88469348415252, 134.68567232931815, 134.45580574773973, 130.9658690421812, 120.37743076201409, 118.92656172475508, 112.94600625191967, 114.8839944408786, 115.92473260817991, 130.46206412776826, 145.43841085126326, 152.545588708693, 133.9165896754111, 66.12637581363802, 14.191893281475192, 7.728563662498229, 16.196215614195793, 17.21502577104876, 6.486311276112834, 13.653668588207616, 62.511911699848795, 104.38828883632537, 120.22986335139122, 84.54271962565761, 15.946789153160589, 1.7696352807744857, 16.56741499900818, 48.972725329860566, 122.97066657773911, 146.59747123718262, 147.28109328977524, 127.61025782554381, 126.31598549504434, 126.98117240782707, 124.77154439495457, 123.55240114273565, 121.44770437671293, 114.02257919311525, 121.56845846483786, 122.02291996248307, 135.80709365106398, 153.00141519115817, 156.35814820566486, 62.90274450855871, 4.169016163195334, 7.276055505198817, 1.9084952747629536, 0.7265844472473668, 0.165526059065615, 0.3116015134559524, 0.26279788223966477, 0.32949024871472393, 0.601102554750058, 11.873431263431428, 65.06706130120062, 62.79518527369346, 69.02826293822258, 67.91558850196101, 108.00075254132672, 117.87230706983998, 46.603256810096006, 58.10765481764271, 32.95480497421757, 49.16934197948825, 78.43910371103595, 92.62090375346523, 92.71817068899833, 98.11863899230958, 54.223967059966064, 6.3151012889800535, 0.4281481241266574, 0.31040598728483726, 0.18043716378029317, 0.1276046148831806, 0.19258790048620394, 0.09562420553617901, 0.21972616683811913, 0.18591787936466356, 0.13197159184323204, 0.1490513229322049, 0.12131638900046388, 0.23105637741185006, 0.13289413024340907, 0.12129427204208991, 0.17254365427840143, 0.11197555554850448, 0.1584283463777073, 0.20047610865965967, 0.14273030082544974, 0.1961062818525299, 0.13291631614969623, 0.14031756819496233, 0.12225444834198683, 0.1836801518595988, 0.13226164805312313, 0.1335423172361428, 0.0939200965747718, 0.10900576974475577, 0.10993154103597326, 0.1976067876263011, 0.2454974412197067, 0.15367034281934464, 0.08020529944089153, 0.1492157254007555, 0.14480377907954878, 0.16629833698032365, 0.10951566254539837, 0.10916057313161512, 0.16325333666416908, 0.16768521659316557], [0.03870090800187281, 0.03445191241260018, 0.03537659968940481, 0.051290655223232125, 0.1300862494615778, 0.06584842869591329, 0.02923023030762711, 0.08515235817720813, 0.08824543051061132, 0.03836484821212869, 0.023025211149586305, 0.07932095052373987, 0.0125179034958203, 0.08685113516666236, 0.08610769280142362, 0.06477200621438604, 0.10263237020661754, 0.05856070705058594, 0.057908406165698846, 0.10850123189870389, 0.07457420845786411, 0.0742995199717341, 0.11365265991058081, 0.11369358432749588, 0.056111045151708595, 0.13808121964816125, 0.13401252668230765, 0.031751676560229355, 0.07770299581029723, 0.0979959677844759, 0.0983079877351561, 0.07121189452347255, 0.11807527783657275, 0.09255078335803363, 5.970458311419334, 24.327441953843643, 57.909057371078006, 73.35235441884687, 76.82868049990746, 54.43868152556881, 65.61402797698975, 38.86029412669521, 40.475679136091664, 53.31036859943021, 74.85218248059674, 75.91803950648155, 62.031746910464385, 35.61881995970203, 34.83589133908672, 17.516491297752626, 1.0530887303813812, 0.4040449449131566, 0.03639914320721742, 0.29852381036166226, 0.17823815435892154, 0.14019713917326543, 0.24573187944629502, 0.9520801601390686, 2.143636831352788, 4.754709870584549, 5.973816350583108, 7.120611484973662, 38.71209521447459, 84.23890067685036, 112.30276107788087, 124.56093665092223, 112.79800738057783, 108.38304242780133, 104.74917827113983, 105.00221037095594, 106.62436146889965, 106.7283905706098, 107.96970305904266, 111.63617780131679, 108.2486306467364, 103.31068823414465, 102.35333181196644, 99.4808703084146, 110.967005760439, 117.89025583574849, 93.3959327205535, 21.363457825876054, 3.0213274638498984, 4.970228422072626, 23.8741728567308, 82.17323149404218, 106.14045866074102, 102.47886334696125, 102.6350207482615, 122.60042621243386, 90.57579563510035, 64.22992944717407, 75.48356640723445, 99.11718814603745, 103.73005236348799, 110.70464626435312, 107.215697996078, 115.53807320133333, 116.9171707091793, 127.07339517531858, 129.78019929701284, 123.03156529703449, 128.04801787099532, 124.06435674236668, 114.68156091628538, 107.6826169413905, 108.8091451891007, 103.81448530381726, 113.0524201546946, 141.98339892971902, 107.85615828729446, 18.869557995950025, 1.647458230295489, 1.3002643638080167, 0.9141709427199057, 0.21370656968605137, 0.09026136023983841, 0.07653575360534653, 0.08135911978540883, 0.38928711907036845, 0.8305661127932611, 22.52919408582872, 35.489872040287146, 44.36652129696262, 44.02879738038586, 38.132965103272475, 71.70070709720736, 117.70351179184453, 134.66285982439595, 47.87571291769705, 29.875026595207956, 35.26663426429995, 55.138624560448434, 67.45390984319872, 71.27673810528171, 46.2036535816808, 6.832144693020852, 0.35971836216988107, 0.0075149696579413314, 0.03850863142419727, 0.046528951460195166, 0.07028438421266694, 0.25606806029475504, 0.07664175719142922, 0.057946576496526125, 0.10526843278879121, 0.03077008427240916, 0.06626254518426235, 0.14058286444314066, 0.09683852384407675, 0.20573407651916628, 0.2899164448101675, 0.2311301057136828, 0.2917481303936051, 0.059514068998396404, 0.11349125284581416, 0.09169707029697396, 0.06717753761838521, 0.06454348218657317, 0.0326252140615496, 0.05181865834240472, 0.04058441943338802, 0.05336544348768169, 0.08444289947229047, 0.03432972904955668, 0.06566371723649002, 0.07943982438695046, 0.08426440864681237, 0.0203767724169959, 0.014377871130202568, 0.2147660386418143, 0.15814668649146635, 0.05621718280317803, 0.025363041448497006, 0.03531239769091049, 0.03406644761261921, 0.1436890138974113, 0.03256054474942146, 0.028680251956346537, 0.016195587100340955, 0.06491841327759527, 0.047582490895424163, 0.04813971260802881, 0.08686088746593845, 0.08698521587516993, 0.0774842853687944, 0.055771055330912915, 0.1094049551794606, 0.14792993875040164, 0.11822696324558028, 0.021575318889752514, 0.13087014126921856, 0.09002099249271617, 0.08907064510088775, 0.1152543735600287, 0.040554327499722286, 0.051192718542992115, 0.038737572969928864, 0.12872449753265228, 0.11891371510442227, 0.041115766526350093, 0.11441143935606365, 0.10762367052056136, 0.06075444961747816, 0.02689359510587829, 0.05061712987240284, 0.17109249988871236, 0.14629047994892444, 0.07564745933538483, 0.08136710242157982, 3.59999890288999, 31.74185906687091, 83.31566103043096, 96.74845310949512, 98.94330163155833, 86.12862017846878, 104.27754463688021, 67.38572336012318, 34.10493804562476, 27.061669326597645, 37.19190220679007, 49.87021853846889, 58.32977471813079, 45.11563908669257, 44.581796661500015, 22.257075732754124, 1.1234236917188092, 0.7980651696843486, 0.09369040043243478, 0.30234576172886357, 1.065967710268113, 0.26192877081132704, 0.8907837492804375, 1.6843104915272806, 0.44777805466325055, 1.9102403617674306, 1.6536501819087615, 11.118235761119474, 45.75507171692387, 94.83030426886775, 122.5958291945919, 132.628357794977, 116.24002841211136, 114.71532467872866, 112.38702143392256, 111.56571634354131, 115.62333768413914, 111.15769570873631, 113.11130277572141, 115.66213776988369, 115.41986865382042, 109.4114015948388, 109.26055508275186, 102.78829912985526, 112.45565506719775, 119.6346515224826, 106.6241967293524, 30.959348178678948, 5.368353407229147, 10.119894493010737, 34.88672917889011, 105.34129142761232, 119.69074141594672, 110.13345503037976, 108.84625865567116, 137.79407224347517, 110.24581524633594, 77.91425920301869, 84.95776130307107, 109.99112790630711, 107.18964561339348, 115.31107779472106, 112.65298166582662, 120.42511109382876, 125.018324236716, 136.91081723859233, 137.05037516932336, 130.1192646641885, 130.87949060624646, 130.4483672111265, 121.20529405532346, 113.76447154629616, 114.72415001161637, 108.72304131907802, 111.8449184971471, 142.29535287426364, 126.18584909746725, 30.239301035481116, 4.055069593652602, 0.6955608893786708, 0.4754738491629401, 0.08804189627088847, 0.029873464541930347, 0.09681410096105068, 0.024560798004630114, 0.47057140738733355, 0.3691162998157163, 26.667349530804543, 46.74701167691139, 47.702026444096724, 42.80428832577121, 44.89600596889373, 43.40494832684917, 83.1303604187504, 77.49061969018753, 25.382485005163378, 52.1754543242916, 60.54667088293261, 76.46595539585238, 82.95005690666937, 86.52841952539261, 61.968506536176136, 9.830653032948895, 0.32274420102757795, 0.041953541128145116, 0.021491773171170105, 0.053846290064675194, 0.047626000859083674, 0.16980207074553738, 0.1305211882197088, 0.06576146239474898, 0.06510490972188211, 0.021182763946032333, 0.06614085977836963, 0.13047830261770757, 0.18083410457737986, 0.24347092415536606, 0.3759820410801519, 0.529835049904162, 0.5143768664809966, 0.1118082189632039, 0.14113080117010302, 0.007356614017138078, 0.07367701990710152, 0.032781783281074416, 0.1170597057188711, 0.0959982019999335, 0.10527457681394393, 0.02506926396651374, 0.04904755744181814, 0.07278306424737939, 0.04665016572201445, 0.032471081001623985, 0.028005475966980862, 0.021413484730968074, 0.07418433099143928, 0.20600878032705477, 0.18334842046662686, 0.06443520331935537, 0.016831397942657915, 0.09612019384099592, 0.030504791854670456, 0.2492299135173521, 0.1844912397885515, 0.11295427883704824, 0.18255509045575896, 0.32343922663600216, 0.2683834292955937, 0.14002144456871096, 0.27124014052171863, 0.2132687197938081, 0.19216695049357033, 0.17528154526747045, 0.14092429450923397, 0.2871021442115307, 0.1851901264801141, 0.14326236421062102, 0.27111232641243166, 0.2020812620438876, 0.20739133920400374, 0.20068218631129112, 0.2835436658032479, 0.20127081762879126, 0.10093923162428603, 0.23783168965770354, 0.20967251921613372, 0.15907258035675173, 0.2957343922988061, 0.20050468373923533, 0.1328033947896573, 0.12778572572935976, 0.14978010237457293, 0.38012535100983036, 0.2826823071847039, 0.34075649094677746, 0.20385150737579794, 12.9048224226121, 62.00314498716786, 119.77856328410488, 106.54195247157928, 103.74020345749395, 78.28466430787118, 91.13639646960844, 54.100867394478094, 69.27967117678735, 82.47768586681735, 118.17321561997937, 121.50154282969814, 98.15921983411236, 63.92816974270729, 59.608781183919604, 29.39433816940554, 1.7527290073133286, 0.9213939873922257, 0.10028385106594333, 0.650964092102743, 0.8148006974689422, 0.24486201725179152, 0.8416157360038451, 5.2340190929751245, 12.96716457413089, 12.998886742899495, 13.861682664963508, 12.708431309269322, 45.55565449499315, 98.32265715445243, 129.82468681950724, 139.91412901109265, 122.10991813290505, 120.60659916170182, 118.56483290272375, 118.84321920333372, 121.16034369314872, 115.96887496209915, 121.42425644782283, 119.82724774268367, 117.02283151688115, 110.64077438846712, 109.56605280599287, 104.40590027839907, 115.02351314790788, 123.40969747112645, 106.1231610082811, 31.30461677428215, 5.9235369582330035, 9.132968302695982, 38.582645231677645, 116.55842288847893, 121.79141383017264, 110.59852261697094, 108.52951941951629, 138.3290050875756, 134.17033564659857, 89.31136469687186, 95.45261967566707, 119.03101444244386, 111.67245972541072, 119.72466207319691, 114.43219231021021, 123.80771606199204, 126.16126368122717, 140.69282931666223, 140.37329735294466, 134.4283648460142, 134.4731269344207, 136.5951919555664, 125.60862525816887, 117.61713335590979, 118.44310606679609, 112.88477805352981, 123.7482999986218, 160.02834135486236, 123.89927202655424, 22.90819702609893, 4.750279553474919, 5.0083808264424725, 0.9277341310535708, 0.1968307252372465, 0.18966460089770057, 0.402890327837198, 0.16819141685001313, 0.7862489069661787, 1.0866951077215135, 38.74289366506761, 61.235670505031464, 69.49593497860816, 67.5764839110836, 63.799986685476, 109.61019515991212, 153.36785870213663, 165.97129698722594, 61.34895247797812, 44.70255074962493, 52.647103648031916, 81.06449511743362, 92.96500544394218, 100.59314466291859, 83.5191535949707, 18.504379449352143, 1.237638821044276, 0.2136930099297916, 0.16021890836136957, 0.11556237920998566, 0.18944356920978717, 0.47759361444942416, 0.2641169017841739, 0.10907458742299389, 0.32611762323687155, 0.10425754912918615, 0.16825233616175192, 0.23794283369375815, 0.28026468691325956, 0.4400122520183364, 0.5379918638256289, 0.6476305677525459, 0.5905493565144078, 0.25544176809489727, 0.2090960074095957, 0.1544481518888666, 0.1782614893970951, 0.11633022913649199, 0.24938356011144577, 0.1801278327982272, 0.32089544700518735, 0.17636010513430642, 0.14479919787376158, 0.23372522855718292, 0.17579960456538588, 0.18345386480852482, 0.16566128890600898, 0.08535531785098777, 0.10486175501418692, 0.25825749361707323, 0.2812124602496624, 0.1121305121529487, 0.15767546580924144, 0.1785302330409327, 0.18470188332421167], [0.07788911687150117, 0.04617583855325657, 0.015419886687830573, 0.07216627919866193, 0.10810583093834501, 0.024259035971256036, 0.1330955500804609, 0.03022593776545217, 0.01826384446523603, 0.035890288455712224, 0.03772893394794195, 0.05341394068372827, 0.11474291027914132, 0.03663024129045587, 0.130604523264112, 0.023190816376178015, 0.028160580043350498, 0.04667172726664332, 0.022764093911034927, 0.013107440712290907, 0.028364526055332635, 0.05831649737252344, 0.17543604988003933, 0.19017239461743063, 0.3527984125239234, 0.03383082961062751, 0.01518455309598076, 0.01813612228649999, 0.078864308494714, 0.05496027766756954, 0.012350605214915931, 0.12960805737924191, 0.11997643227298414, 9.523045074555183, 53.52394950005316, 72.59709419742708, 77.14694161568919, 64.77307181204519, 66.67787674934634, 59.936722709286606, 28.248429490673928, 55.23253394711403, 62.121847675692656, 73.94136105814289, 54.63088943112282, 32.0877101344447, 37.72467774729575, 31.27902330890779, 4.021409774018872, 0.36481974165766473, 0.14313876358491762, 0.11649696817321163, 0.2146934901153849, 0.18267182693366082, 0.1656239804240965, 1.0327301582982464, 2.0713421558180163, 6.065917034302989, 2.446073144674301, 8.276133402701348, 55.32982049449798, 101.49967501240393, 120.01131673013012, 106.09624570415866, 102.63498152455976, 99.52486361226728, 109.48911159269272, 109.18539462550994, 110.937619363108, 98.13422649137436, 88.37814654073408, 85.43938913652974, 89.08100389665174, 90.63808287343672, 94.45692600742464, 99.96245107343121, 113.25487721350886, 108.36165766562186, 117.9399444210914, 100.46471057399627, 108.47852860727619, 94.16905541573801, 31.01181184091876, 68.34759050799956, 70.7885128451932, 107.1752348253804, 91.65076824926561, 84.38660144805908, 89.9517700749059, 95.03414984672301, 104.3043658041185, 58.21868535011046, 80.36745855885168, 114.92414382196243, 110.04684125223469, 110.99538018626552, 104.17551594395792, 109.49545014289119, 118.24535585218861, 119.1944831417453, 124.65851737606911, 115.30841058300389, 112.7805842122724, 117.45807340068203, 104.57423271671419, 101.22019044814571, 86.33497607323432, 102.54924635733329, 110.55172874081521, 103.91912629527431, 114.36901861621489, 143.49722985298405, 86.06892954918646, 30.207349408057432, 6.3117099096698155, 1.2254002906622425, 0.34868556225011427, 0.03220365119857654, 0.151250914580399, 0.22394599362967477, 0.13134113212506618, 0.19833169066377226, 6.223321749318031, 28.87658726784491, 39.072925813736454, 44.3962214839074, 51.51345629845896, 64.79165600192162, 149.36646061558878, 155.5772513727988, 46.694769628586315, 32.528241334422944, 47.855657839006, 63.96464386293965, 65.68754888349964, 74.65748386998331, 60.45628770705193, 13.235706706200878, 0.033109412273211826, 0.041469243325052724, 0.015842980769042288, 0.12975160693449359, 0.20115942844460089, 0.07975542196823705, 0.056007611790611866, 0.032027642497973095, 0.06167930543362614, 0.06187129089789045, 0.05705732078621945, 0.17243825590177891, 0.3085963037465849, 0.2699307736850554, 0.13863891633527894, 0.20258908640713463, 0.026237938755882845, 0.05167128600841088, 0.07040095215122547, 0.12069594205146837, 0.09944337600421521, 0.020264477333835056, 0.05136604210542095, 0.09555574025838606, 0.04507487444507499, 0.03197422127179321, 0.07254568424316184, 0.06582165392295969, 0.027342520714286837, 0.0692545858422114, 0.05495714436795923, 0.045768524925675125, 0.14027540271560993, 0.06844896012015882, 0.08170713820765096, 0.06795497130482428, 0.030519904854196696, 0.04058197561290957, 0.1145062503975726, 0.02335962768073284, 0.03382284314401689, 0.04492931390902208, 0.08004811352058765, 0.06218416120616659, 0.06419917546032418, 0.04387709214502285, 0.0064677801339947175, 0.05138870681666079, 0.04134832017664467, 0.06653600026883426, 0.1645004205525883, 0.07511521208911173, 0.06194572017017392, 0.09076176121109918, 0.07894241881947364, 0.03522232873365283, 0.060234724078327424, 0.016140193197756045, 0.13029445683763874, 0.028226128441371748, 0.12491458906762062, 0.19524800290744151, 0.42686501878403854, 0.09022919986877712, 0.049117305916884256, 0.06758763214513179, 0.014020721897512916, 0.08879872985304364, 0.05827843429400556, 0.11175358923332346, 0.15295743671876771, 7.898714609684483, 73.62267632638255, 95.68882480744394, 96.53614305680799, 95.0128278424663, 100.38555714391894, 89.44806714211741, 42.672582980125185, 31.43189572518872, 47.501169712312766, 45.417190905540224, 44.66259356467955, 35.422521022058305, 45.33682938544981, 35.89980679173624, 5.539453077700831, 0.40188739617024705, 0.1905087685032237, 0.1778859990618883, 0.30607281012400506, 0.6018639848597589, 0.4418703523134032, 0.946535767326432, 0.7480078202582175, 2.693224385861428, 2.122856359327993, 12.241798696979401, 64.07909862456783, 116.68218935689619, 130.1709693478, 112.75589681440785, 107.9792187290807, 106.57694785825669, 117.0197642234064, 115.55314294753538, 115.23391692869126, 102.25274655126758, 91.24398708343507, 89.57032742038851, 93.8442910102106, 94.87923191439722, 100.99913350997433, 102.1137926655431, 114.91293368800994, 111.04397835270052, 124.81881680027132, 105.37360391309186, 109.1534508428266, 99.81063965828189, 41.509333502861764, 80.46110122434555, 88.47561743951614, 117.95794025544198, 97.96390933375206, 88.88847043437343, 98.2518348386211, 101.11467084577008, 114.48192796399518, 67.81806268999654, 84.49235639264508, 121.41372880628033, 114.73639565129434, 115.08268602432744, 108.38965554391186, 113.16112472165017, 121.55636187522643, 120.22953387229674, 126.14898666258782, 119.65028608998945, 114.12197205328174, 120.77337834142871, 110.40507916481265, 106.53015398210096, 87.97293432297246, 104.8508696402273, 119.61044265377907, 109.7576056757281, 116.68782972520398, 151.80840276902723, 103.01574168666717, 40.013549404759566, 11.393668516989678, 3.3211664326729315, 0.12908276621132128, 0.07354088608295688, 0.24495350347170908, 0.2245901203564098, 0.1640480149897837, 0.35058267174228547, 6.2180633218057695, 35.70555140895229, 47.27223273246519, 45.94500464777793, 52.54527499598842, 61.6891670996143, 151.45217310997748, 128.21981768454276, 42.25097525504328, 43.79243143143193, 67.70287052277597, 84.3296564778974, 78.71465021564116, 90.49496343058925, 76.96596345593854, 20.256649294207175, 0.03708202249160217, 0.02312778266176822, 0.01925601834251035, 0.18146108625636947, 0.25771231480663825, 0.023176440736278895, 0.027239453160173954, 0.14521075562844354, 0.018876195780091712, 0.10998027188883674, 0.022783835996843638, 0.253247692279758, 0.36586155994765224, 0.30932712098283155, 0.1886412912919637, 0.1981966600062386, 0.04882439602947524, 0.07703302893787622, 0.007011855299013757, 0.09230358976750605, 0.05166599617129372, 0.047347677285752954, 0.05224370307499363, 0.036248216225254926, 0.14673160869748364, 0.009600039301139694, 0.0724156714615322, 0.05171209168169768, 0.010431270554451453, 0.04939431947986445, 0.10997264165311091, 0.07104462688608516, 0.1365970621906942, 0.05503201414079917, 0.05919514659551844, 0.11293850508668732, 0.10776312150541814, 0.04577823125967576, 0.1973948264194112, 0.12642873886732325, 0.07002244342959697, 0.1407492434185359, 0.25854747321817184, 0.2314618830719302, 0.21870494099153628, 0.1814778789036697, 0.1040999188778862, 0.19005368163268413, 0.10568601965543725, 0.17111704534580632, 0.2889199482817804, 0.14769159347539948, 0.2823279149109318, 0.17831624936192267, 0.21829919018332036, 0.1293904577652293, 0.16800495104924326, 0.09339610009544319, 0.2846896414074206, 0.10390602968513005, 0.2927187331501515, 0.27468765875504864, 0.6979386424345355, 0.17829639236292533, 0.1170692281917699, 0.17939343027049498, 0.2962064250342308, 0.14935132296335313, 0.1238009806782488, 0.2677828163629578, 0.24071267054926967, 19.377869713690973, 111.34387493133546, 119.5040758194462, 109.9782076189595, 95.96713266065045, 92.1010406555668, 74.97075573090585, 40.3520970190725, 88.37844464086717, 101.84230973643642, 116.89698619227256, 86.76600533147013, 51.3733257016828, 55.76034768935173, 48.41516040986585, 7.36364056025782, 0.8513492201605152, 0.3147934341142255, 0.4540276467319458, 0.6731813160642501, 0.3915152091893458, 0.5853177114359794, 3.5600154870940797, 11.727880931669667, 16.00416656463377, 6.490312093688596, 12.041656817159346, 66.0904469028596, 119.38305501014956, 134.66918268511373, 116.08048208298223, 110.13309417232391, 109.75449131381129, 121.72520422166394, 119.64974480290567, 123.31080667434202, 109.01903121702134, 97.87361637238534, 96.5872201611919, 99.83659005934193, 101.4364307157455, 107.13067670022289, 107.39327938325944, 122.01640098325669, 115.718596366144, 128.14093882037747, 105.89229029993858, 111.15394592285158, 105.41894651228382, 52.071790003007465, 89.2786285954137, 111.83023314322196, 122.15927723915347, 105.63102906750095, 98.6662567815473, 107.32616762961112, 111.25122070312501, 118.71900558471681, 83.66330069880333, 87.75969074618432, 123.40575156673309, 122.48884262577181, 122.65083651388846, 116.1503787194529, 121.28240785291119, 126.73880131013932, 129.46367186884729, 133.74198144482028, 123.54803162236368, 117.18728080872567, 122.79679575274069, 116.34304554231706, 114.19489675952543, 96.9771194458008, 112.28482800145304, 123.78145187131821, 108.97512420531243, 124.35405515855359, 163.9087421663346, 102.10654412546467, 35.529083974899784, 9.175766264238666, 3.9767771238280885, 0.3333928538185935, 0.14910865695245806, 0.6852191926971559, 0.33029749088229676, 0.3917092745823245, 0.7200174802734006, 10.683775409575432, 49.41598453829366, 64.81380954865487, 70.51573553392964, 81.77975500783613, 92.74341506342735, 157.35629727763515, 169.06800823826944, 66.60163371793686, 54.050943466924856, 67.78710734459662, 90.14653144344207, 92.45027280622914, 101.9074603049986, 98.55988994721444, 35.63045763200329, 0.3295781956084313, 0.18422810390831965, 0.13724328799834176, 0.2221039198939839, 0.3303170414461244, 0.2504190964804542, 0.21639305617540114, 0.1805088696100058, 0.13264222521214716, 0.15023495941873521, 0.17933104006994158, 0.44126299780703365, 0.5646998339122342, 0.42562159679589734, 0.3181504620419395, 0.37769093809108584, 0.24964530171165544, 0.24364700180388268, 0.12041755336066408, 0.15371240104638761, 0.23153988614438042, 0.08400553987631876, 0.14578496917120873, 0.15409493939049784, 0.2621962887144858, 0.14426345726655376, 0.16398894961082167, 0.11426379889129631, 0.10569295275115198, 0.12125057438688895, 0.24877576127408013, 0.23956755296357218, 0.2703716419637203, 0.12691069244136735, 0.29953752854658716, 0.2068829785792097, 0.1589561349922611, 0.1812116020629483], [0.027630730652280396, 0.02368862030937547, 0.007915394718668634, 0.01576847871840601, 0.07827225276419232, 0.10607322347500633, 0.036557382498417175, 0.027406069622825713, 0.006948691828461785, 0.028553881922796853, 0.024402045434521093, 0.07115946346593481, 0.03453021042890126, 0.0630101916800824, 0.11061562690883876, 0.02204841074173249, 0.048023677100577665, 0.0247440098469416, 0.06242092067916548, 0.05574951676892177, 0.09005794857418345, 0.1211631024676946, 0.061168631223300775, 0.19999802382963322, 0.08629058863246634, 0.022918700030253782, 0.026998903467169693, 0.08063548845389197, 0.035149726581068776, 0.09920150672476138, 0.05604368687096623, 0.2760124086372314, 5.005322848596881, 67.17569612687635, 84.39566996789749, 82.93821919348933, 78.6284992771764, 79.64950007777061, 41.118912543019945, 38.75020104069864, 74.79601413972917, 71.19255619664347, 62.185048826279186, 42.87782099939162, 30.071890354156498, 38.04201318371681, 14.317115929818923, 0.6294927926313493, 0.30251617032674055, 0.13079230673611164, 0.1931290496741572, 0.0994488305502361, 0.09946839643582221, 0.5730256774733143, 1.5534882920403636, 2.53000573765847, 3.2780176641479617, 14.481829981650076, 57.953772391042406, 115.34721066874843, 112.98751277308311, 101.86742859501993, 91.14541792100476, 100.9378896221038, 104.59954769380631, 108.08812725928523, 100.19096835967034, 93.45455646514894, 86.25165708603399, 90.90871072584584, 95.7470484702818, 100.4852088805168, 100.91943094807287, 101.52964976526077, 102.71960273865731, 109.60686114526565, 109.490005893092, 111.63766045724194, 112.24765177695983, 111.76694962286182, 110.51716481485676, 107.89589974188037, 58.401597238356075, 49.34183213018602, 78.90978813171387, 99.11933760489188, 96.55388785946755, 95.68623604313021, 92.84196853637697, 99.96449855066116, 112.67688458965672, 56.01578812445364, 123.71536777865504, 119.68946272327055, 107.86190848196708, 99.29983723548152, 99.67128569079985, 110.54491166145571, 118.712431692308, 114.74938654130506, 116.4053249359131, 118.36858887826244, 112.73466894703527, 116.72643369243993, 117.77975482325401, 110.29895551743047, 99.52485576752694, 79.76879504419144, 89.3555776534542, 114.38350785163142, 112.21937148801743, 104.97244742608841, 114.33876145270564, 113.85740034041868, 104.67673209405716, 71.23358418864589, 27.475491146887503, 0.5843916643531092, 0.3252506568547218, 0.43238673539411643, 0.2811139413425999, 0.08311376756718082, 0.27011475736095064, 0.9492906807891784, 13.79558288281964, 31.460885963132306, 51.04627063197475, 52.26089923612533, 20.914873999934045, 37.736484081514426, 49.89469805071431, 32.0453603036942, 26.227657718043176, 45.25731117494645, 61.52199568287019, 77.30916300127583, 70.74717890831732, 82.31265606418734, 27.680613456233857, 1.1928987959700248, 0.03665038557242482, 0.08944733819413571, 0.2025567421749715, 0.04191909015419022, 0.051248876618281494, 0.046300040557980544, 0.07784421645825909, 0.03310682289602776, 0.07685761012497448, 0.2061228814624971, 0.18622443710844364, 0.17400216311216357, 0.17825698480010035, 0.026241550860445828, 0.018483311418564092, 0.05307537195603213, 0.03251924877986312, 0.007406356584866562, 0.09699458361513193, 0.06437404652036006, 0.06164045711498588, 0.043015917387580684, 0.05805181399468453, 0.06328556198446501, 0.03602027059382489, 0.06672113307661588, 0.020193838281556964, 0.010562521525688711, 0.02505151562452797, 0.1400669808349302, 0.03488605826972954, 0.09357931002253488, 0.016887391309043574, 0.016511200003386024, 0.03057451926231865, 0.03338672078004287, 0.008403907920564375, 0.055089949540072874, 0.05392725023651316, 0.06657425103889358, 0.027901031369824084, 0.08093061616584178, 0.031367868425384644, 0.014401372792499681, 0.02199061706872477, 0.0484123403176425, 0.02256456822637589, 0.04913898620514139, 0.07024319166497839, 0.05376106661353862, 0.025523973538750605, 0.05081950731936002, 0.050335282294620434, 0.054464308514950745, 0.07469811551873723, 0.05772963571812838, 0.02320707276193125, 0.16196267769461678, 0.14975180308665, 0.1690778418654396, 0.09940478049458996, 0.08986264977964664, 0.09850651175985414, 0.045443845372046196, 0.03469089737101909, 0.13355463592996522, 0.1751511724245164, 0.2607488115468333, 6.975757373917488, 84.21168727259483, 102.78811085608699, 99.10691153618598, 102.3891979648221, 101.95780784853044, 73.7341030182377, 52.197749076351045, 35.677592754364014, 47.78220753515921, 53.19638452222271, 44.98727560043336, 41.86328034247122, 49.15068326457855, 20.144194941366873, 1.1019914933750707, 0.4283449167926466, 0.17677406840507062, 0.039769481912615805, 0.3881658421408746, 0.20828485819360903, 1.3028411158630926, 1.1457523967950576, 1.3716149738719388, 3.6841386460488845, 18.746909403031875, 67.25753245815154, 128.40041145201653, 125.49604538948306, 108.10736256261026, 98.46677287932366, 106.77904405901509, 110.63438092508625, 114.56033614373978, 103.85485433763074, 98.22560202690863, 93.41193599085655, 95.21774814974879, 101.60877181637673, 105.72071798386114, 107.82891350407755, 107.92734146118165, 107.54638518056562, 115.77580021273707, 113.08021406973563, 114.52744314747473, 113.16587078955867, 113.87788295745851, 111.15650330820392, 108.21538463715585, 65.38222374454622, 56.08265276878111, 89.96127790020358, 107.62570335019021, 102.46756692086498, 104.95022327669206, 101.66898804326212, 110.70972965609644, 114.80357800760578, 63.72568914967199, 124.48314820566486, 124.27178736655944, 110.19655027697164, 102.17264390760853, 103.38780987647273, 117.09486192272557, 122.24332578720586, 119.08903414203276, 118.78271272105556, 121.38701746540686, 120.11802088829779, 118.89422570505451, 122.47916221618654, 116.32166078013759, 107.54628319894115, 84.64408936039095, 91.64813241650982, 118.68249616315289, 119.4205685584776, 109.18962294055571, 116.82305735926475, 123.20349062642744, 119.9270877530498, 86.23323763570478, 38.40074923730666, 3.841223442746747, 0.3879118686722171, 0.4460614354860398, 0.13148215359016774, 0.071681238290283, 0.3953195405342887, 0.6986007262622157, 17.50988014282719, 41.18847577802597, 51.90892927108273, 45.03170820974535, 32.7023906477036, 57.387680238293065, 41.190209465642134, 35.58394616649997, 52.272230963553156, 70.50301136509066, 89.60122785260602, 96.9548325384817, 85.98226870259931, 100.90752263222971, 36.57679219399729, 0.42580741908281083, 0.012622576961744458, 0.10426126465561891, 0.16182029259301003, 0.05428842621885481, 0.04222612670292297, 0.0672835412044679, 0.03244326817953298, 0.0701212228065537, 0.10465087399127022, 0.21720460375710843, 0.16750124823902884, 0.1335129147816089, 0.17556168829962132, 0.06877050254373782, 0.03422094839474848, 0.08994714161681552, 0.06955829373891316, 0.1322650801270239, 0.031503307024738005, 0.059500930590494994, 0.02604391358252014, 0.0423612033257321, 0.05899823901634063, 0.04684740654943932, 0.0367573889032487, 0.054787524840644294, 0.0184663464014809, 0.08312820832455352, 0.1364998609548615, 0.10791771804853793, 0.033717188127939744, 0.11766711385139536, 0.06018351876146852, 0.03135596724948095, 0.0461445783355063, 0.1243809245586876, 0.20405881076810822, 0.1656057015662232, 0.16989867443278914, 0.11389010120183231, 0.2692226632948845, 0.22504460967836842, 0.15616106320052378, 0.12801303933825225, 0.11890560223330414, 0.14331185349052952, 0.1441512100638882, 0.1256462260179462, 0.15817107873097544, 0.10414206137460086, 0.2999225643373305, 0.11913335251231348, 0.2577424986708549, 0.2839166280483046, 0.2726412234046767, 0.19959899927339247, 0.1434259086606964, 0.2804017247211549, 0.24894272247629784, 0.2932139017408894, 0.26241811713384045, 0.18997765506707853, 0.1432220373422869, 0.14841212981170224, 0.14635129200835384, 0.2680756151676178, 0.20172496987206323, 0.3311463469459165, 21.912079741877896, 122.76754271599555, 119.25129475132113, 115.34474742028021, 112.35113959158622, 99.62127547110282, 55.30907115628643, 53.77696983275875, 108.97920347029164, 110.69156123745827, 90.83322863424979, 65.37125287517425, 53.798550713446836, 63.668085221321356, 28.572060331221554, 1.776399162988509, 0.4254698500998559, 0.4105895421197338, 0.514536151482213, 0.2533484328418009, 0.3849280481376956, 2.5805270912185794, 6.192174698075941, 7.695935916516089, 8.741662848380304, 18.353540782005556, 70.66925710247409, 136.71965660587435, 131.5324789477933, 111.54186048815328, 98.57143740500175, 111.49651788896131, 114.97698599292387, 120.41648187944968, 111.3575561584965, 103.49102312518706, 99.9387913365518, 99.92579260180074, 105.7491316333894, 111.23453494041198, 112.43558822139617, 110.08848113398399, 110.44289081327378, 118.21335715632286, 114.08397997579267, 116.73947949563305, 117.36061034664031, 114.59934803747363, 111.27200142029794, 105.91842113002654, 71.7459555595152, 73.3832077826223, 96.60145836491739, 118.60608839219617, 108.4864596397646, 110.20013532330914, 107.74572003272273, 120.11740115381058, 126.48372173309328, 69.18100003273257, 129.3794193575459, 135.0446633369692, 115.48942796645628, 106.88284566325527, 106.5962851432062, 119.80690633097004, 126.9313112381966, 122.56686641323952, 122.46215481911938, 126.65663549976965, 124.63972922294371, 125.51158582010578, 124.29993429491599, 124.21893735085766, 109.78652138863842, 89.16032991101666, 97.1847854122039, 127.17876572762768, 123.04654875109274, 107.78856800448511, 119.69672695282968, 129.24083417461765, 121.86012591085127, 80.11765849205756, 33.38630491687406, 3.4026134687085308, 0.7267494932297738, 0.6773932061849103, 0.43795472371482086, 0.19997053659491001, 0.7501892709443647, 2.2982493091014127, 25.368346821877267, 54.49321031570435, 73.79336218680106, 75.03825187683105, 32.521237942480276, 54.06361664495161, 74.38446337176909, 49.32448348691387, 39.73182908950314, 63.01526554169194, 84.66504266185146, 101.02599390091436, 94.096373896445, 118.71399279563659, 52.1728616376077, 2.238390998494241, 0.1540985859690174, 0.22070089114769814, 0.28074392087517247, 0.15535169130852147, 0.12018681533875004, 0.14133150088450602, 0.15069778377731002, 0.27481256173022334, 0.21397689147101295, 0.30753563969366016, 0.3385527930673092, 0.32716357840165017, 0.2544909304067973, 0.2401055305475189, 0.12817361136718144, 0.23250845110704824, 0.09419142959579345, 0.19841448944662848, 0.2583817530783915, 0.2193553496392504, 0.2036594644549393, 0.1324739923039752, 0.1576119111550431, 0.22944632106490676, 0.13190213831201678, 0.22546379766877622, 0.0941179694247342, 0.24685174677400823, 0.27707868045376194, 0.23262057573564593, 0.2330215767987313, 0.1866156475678567, 0.13968603595370246, 0.09601678729297654, 0.12861528403816685, 0.2424135083152402], [0.09963481371561367, 0.02018234696269276, 0.06340369657282868, 0.04372929463223104, 0.043406564772369406, 0.021135900432484287, 0.03159836896004216, 0.07718283743146928, 0.09354967008074445, 0.03215230032501202, 0.02056349102678078, 0.07381814862451247, 0.05521983208675539, 0.030567969210566055, 0.04051985354312966, 0.04648266825824977, 0.02313041417378812, 0.06349374637788822, 0.020208570152340878, 0.10556482454581607, 0.04731757769120797, 0.07656011520133865, 0.08690918930956433, 0.16598284665134647, 0.2187012024824658, 0.05322347207355404, 0.03991592728022126, 0.04334086124154349, 0.06730133742694894, 0.14942767128588694, 0.08590971269915182, 18.22317296458829, 92.00861392482635, 98.66431128594184, 85.17536655549081, 86.02859189433437, 73.90259235135971, 53.786575717310754, 37.881541175227014, 69.15638323753112, 67.75075481783959, 54.37093434795257, 57.91946734151533, 40.99227489963655, 26.418843846167288, 3.7108509675149, 0.5060933416168536, 0.21539222358936266, 0.1613065846745045, 0.12590079703518461, 0.21188689636126642, 0.24413518367275117, 0.4516405474034048, 3.9023494143639845, 3.184783905744553, 33.615175216428696, 83.89179445082142, 122.85799257216917, 121.94130328393753, 101.80120329703055, 93.90882184428554, 97.82532415082379, 98.60458927769815, 93.25510394188666, 86.41009730677452, 86.43586727880663, 87.10132875750142, 83.70342654566612, 86.05935896596601, 92.91619546951787, 94.4469710319273, 99.22957189621465, 106.18040407857588, 99.05543435004451, 102.9983263631021, 113.36977912533669, 112.17720600866504, 114.59825761856573, 102.8586821402273, 103.9728549218947, 101.73011426002749, 108.75340046421175, 98.75897376768052, 46.39558692132273, 96.39155664751607, 91.13761240436186, 82.64539857064524, 93.48760635622087, 82.06255789726012, 100.43314333884948, 69.00192030014531, 78.84965035223192, 112.9909566140944, 103.71354702980288, 111.7052193610899, 93.75279780357116, 102.65001204706009, 109.54773533728816, 113.20788721884452, 107.44714921520604, 106.06892247353832, 109.0228751397902, 116.71379581574472, 99.6445272814843, 108.16255031093475, 111.82245900554042, 106.1790704727173, 96.01465609765823, 83.39800726982855, 89.9283064565351, 105.49071804169687, 119.22526590285764, 108.04100390403502, 97.51864971653109, 101.28542730885168, 114.89370622942525, 123.71521088384814, 89.6563449982674, 10.718203033170393, 0.19819980096672812, 0.4590510384690377, 0.09733517098450854, 0.32149645830354384, 0.19486338080417728, 0.16889519118253263, 5.7258240061421555, 21.72958166368546, 54.64037372219948, 52.32710884463403, 37.699907979657574, 47.67153001600697, 58.298838984581735, 35.1114966792445, 26.024524050374186, 33.07569242292835, 51.99376229316958, 69.46325379033243, 62.01062494708646, 80.41120083101335, 49.33579168012066, 1.9624276194841632, 0.4550577285549333, 0.04578858493797241, 0.03886744402529251, 0.05580388219846834, 0.05419067723015624, 0.06491767017230873, 0.08850389325450506, 0.10787572876940812, 0.07421177992176625, 0.016917795423538457, 0.051365643739700324, 0.09674989513211674, 0.04882158831723275, 0.09307591364749017, 0.03476048879806073, 0.05769033923805241, 0.04591781247947966, 0.08998211353055893, 0.030081396126338554, 0.08981374272656056, 0.0973140652621946, 0.0181020658478261, 0.038441974113905625, 0.010163658805521987, 0.05756582313727948, 0.016030529626615105, 0.030559233893009446, 0.12965815952948986, 0.10190673172473909, 0.15870364773417675, 0.0655012070051124, 0.041358574263511166, 0.012155242260515451, 0.012046610035242574, 0.005775019272996654, 0.08109868819554968, 0.04515352869226087, 0.047753431924408486, 0.05931015937559067, 0.05469274444265231, 0.02667322416879958, 0.010786088007021575, 0.029966381431046515, 0.022462126949141105, 0.03766917525940845, 0.02991051255394855, 0.04547687908334117, 0.0505762092859274, 0.020427506589781375, 0.05335275324121599, 0.05234300339173886, 0.017279189740938526, 0.038042367330842444, 0.09136674084490345, 0.04069791918980979, 0.04733104934735645, 0.05465270102685017, 0.09493691741579002, 0.08218687012671463, 0.25708350983838885, 0.0011270454518624673, 0.07875792952554841, 0.02018727099282607, 0.11508978723037629, 0.07450267882837404, 0.027331017904103767, 17.29027448161956, 111.23279340805547, 114.15790880880049, 114.3574397794662, 115.93351087262555, 106.24379742530085, 78.85483572559973, 37.65924869045135, 27.395910178461385, 56.90634658259731, 55.856296708506925, 67.02234714261948, 54.26353200789421, 32.804697828908125, 4.172866459815733, 0.9030893889646378, 0.3435018742757459, 0.257899945061053, 0.34664721678822275, 0.6589261358303409, 0.3064996436718972, 0.8722861579829647, 2.414878534693872, 6.345155469832882, 41.40239400248374, 95.71359849745228, 135.0183363883726, 129.9146738360005, 106.30534725804483, 98.23449796245944, 102.2554059182444, 105.61552001583962, 99.14009478784378, 89.6134421133226, 89.63930622223886, 92.12935232347058, 88.81134094730501, 87.6760030561878, 97.90597592630695, 100.59489404001545, 104.71222954411661, 109.18108786306074, 105.71228488799065, 110.12714001440234, 114.84612787923506, 113.47438089309202, 113.480162466726, 104.45744806720366, 104.35937312341507, 100.80282672759026, 110.19475383143272, 101.31669644386538, 54.90129763080228, 102.78839326673939, 100.16718310694542, 90.39342111156833, 100.27463251544584, 91.77993974378033, 110.76915356420703, 77.58317978151383, 85.71251161636846, 117.42441946460356, 108.4561554078133, 117.94179577981274, 96.5212929633356, 107.32751692495039, 113.55610739800238, 114.89515750638901, 111.50900671558996, 108.21063856924735, 110.53071268143194, 117.69815383418914, 103.52796400746992, 112.2014541010703, 115.4097960072179, 110.4798944534794, 101.86537327304964, 89.8066423785302, 93.38731135091474, 111.00046357800885, 125.85829980911748, 115.6673074537708, 103.72489052434122, 105.93961761843775, 119.36039940003427, 131.4763890543292, 106.65676024652298, 21.128721621728715, 0.08840427884171087, 0.5007063645508982, 0.1853416433497783, 0.38475123504477166, 0.10242160409688951, 0.25112458684992406, 6.286505739535055, 28.948450972956998, 61.40099448542441, 44.29554208632439, 34.365187306557935, 35.755675377384314, 37.335300137919766, 20.39457748013158, 42.97597439058366, 61.39734668116416, 81.90213295721239, 91.76119081435665, 72.67067786185973, 96.47884507333079, 64.15003861150434, 3.041698048191686, 0.6847104490283997, 0.0322463108046401, 0.03134407181923669, 0.08279024097587794, 0.013903385955810308, 0.05236520078934489, 0.08130602223137695, 0.08214557032671668, 0.14529727759861177, 0.06752908004507904, 0.09560954261330828, 0.09175464946536288, 0.025248886686899973, 0.04151269966255754, 0.045457623463364384, 0.035093139496541796, 0.0467975763604045, 0.1431701885115716, 0.033110469474547335, 0.05343630279023802, 0.03912555819918071, 0.025290479515528968, 0.06246791251244084, 0.007662349652814409, 0.05901982737404685, 0.035343493199757034, 0.029827288592294342, 0.0939824331491705, 0.16744016038794673, 0.200444882915866, 0.03665016340692678, 0.06996059715146981, 0.007956563804914515, 0.05409116240879221, 0.028613192449894645, 0.3057862932403242, 0.18113862452728136, 0.12613539614023703, 0.1310984507924126, 0.12628144314212184, 0.15593983232975006, 0.08903122987718352, 0.17350379227390214, 0.1898893098076505, 0.16137197793972108, 0.19176101582425256, 0.20439356054750182, 0.19077682266792945, 0.1331411169901971, 0.19018197071648416, 0.1615574478261894, 0.15335272276593795, 0.13307100462336696, 0.20341924992540192, 0.24234033159671292, 0.13477401807904243, 0.2312845030739423, 0.18653321650720414, 0.20818414827508314, 0.4869209800756747, 0.2214366573119356, 0.15601642580041963, 0.07166482102606567, 0.14912092968100502, 0.1975668591236876, 0.1644110793788587, 41.137834056731194, 149.7396506032636, 132.95526381461852, 119.17299639794135, 119.32215629085418, 97.06378813712828, 76.65768869461553, 54.74121001458938, 106.82688913037701, 104.29507763155046, 78.43787208680185, 86.92505744195755, 65.70102614741172, 45.52800178527833, 6.245897931437339, 1.5580507439951745, 0.4043885506689549, 0.80050396462602, 0.6347401271904669, 0.5161997880185805, 1.067494370283619, 3.7246361374855046, 9.028861734174914, 7.246093500045038, 38.58386116643106, 97.38747781322849, 141.89989951349074, 137.29776690083168, 109.60794371943321, 99.35281276702882, 105.4246888622161, 110.52231096452283, 104.62974209939281, 94.2144686175931, 95.7443263453822, 97.8656461161952, 93.81508504190754, 93.87203785680956, 104.33844335617559, 106.8968955932125, 111.36929189005207, 116.09150394316643, 110.20293589561217, 116.44680007811516, 118.84756518948464, 116.93928503221082, 116.50583959394886, 103.96912082549065, 106.21170459255096, 103.64976929080103, 115.62358087108983, 104.81439159762476, 65.05609043182866, 116.1717870158534, 108.72281382160803, 99.64352315472019, 110.78722000122072, 103.90440956238778, 121.60352445417836, 86.224820229315, 88.85156093105194, 123.10630998303814, 112.7398229414417, 124.19745845179405, 102.97301923075031, 113.74972343444826, 117.79587576466223, 119.70348911900675, 116.710979553961, 114.44064109556138, 115.69605058239354, 121.88223238914244, 105.72746446055751, 114.90168433035575, 121.62149675430791, 116.97726142021918, 108.51510078676286, 92.42157674604847, 95.26147473242976, 117.76714832552018, 135.11688201658188, 119.3345666700794, 106.3780366220782, 109.44540854423278, 128.91361436536235, 139.2454904125583, 101.47107308910739, 16.3369208382022, 0.2581961452960968, 0.8799621751231532, 0.36710415456083517, 0.4829435741468784, 0.4039504709503343, 0.8872315527931337, 11.70392603643479, 41.253998971754505, 84.94433110760104, 79.41947660138531, 62.94396469669958, 75.7818312798777, 82.52279312379899, 52.01919494136688, 36.28988258300289, 45.08473473210489, 68.69494776571952, 92.41846238413166, 83.72546242129418, 109.8113186128678, 81.20440606148013, 5.6119615224099935, 1.2424458082645171, 0.10446941074464591, 0.12861304706142795, 0.18126677571525499, 0.15867298889544704, 0.27927860918064273, 0.21334169732947506, 0.17923564680161017, 0.22142821502301002, 0.25660832082071616, 0.2971561289122028, 0.38891106183009766, 0.22183290862989044, 0.12877331265518743, 0.18885737405188624, 0.15697472518490208, 0.12950837401853454, 0.2537015074443433, 0.11844707562798455, 0.18370198536544077, 0.1824168575507018, 0.07124639912358216, 0.1429817308821986, 0.0666005814808511, 0.1292274495767009, 0.10112300079556243, 0.16373899044288745, 0.30580915330398467, 0.40116111417451217, 0.32147157576776325, 0.21902824541734112, 0.14267203217792895, 0.12036723670579734, 0.17786188261403194, 0.11263082885453779], [0.08253379304322504, 0.10162332515803077, 0.03667088991571819, 0.06823915928121536, 0.036064676880355806, 0.0773707434775368, 0.026152996842058438, 0.04407646269687722, 0.059908508518410314, 0.03981550847510657, 0.07234065613198666, 0.029468627293564142, 0.03803448811654122, 0.017172563708417358, 0.059733936232664896, 0.024972637296624245, 0.0799447835813607, 0.05026505884504126, 0.011605666105395124, 0.05119443841038212, 0.08708225623253854, 0.022214498603716496, 0.05686354267621233, 0.02134980367226226, 0.06361861487910633, 0.1228519969229256, 0.10926476875019651, 0.04227243671794573, 0.06789224402558419, 0.17196208629156315, 21.923391857454856, 108.0207174055038, 91.98197318661599, 95.94565376158684, 59.86373132274997, 85.43550599005916, 37.42902125081709, 27.37409591674805, 80.76691273720034, 79.40389694706087, 57.78937409001013, 37.73655076180735, 36.131920891423384, 19.093231155026345, 0.1363027771754611, 0.45702283601126364, 0.2677461360731433, 0.059225962482272625, 0.24842385112518267, 0.06465346176898287, 0.29135616916802626, 1.5021753551498538, 0.40384128809936587, 35.134207202542214, 110.320614845522, 133.33738111680555, 119.96133788939446, 98.4061408812, 97.18627591286936, 97.98042251217751, 93.65624473940943, 86.15397437926262, 91.05855311116865, 90.14881426288237, 91.23754655161213, 92.1929653229252, 85.71124076843263, 82.67786795093168, 81.42037960790819, 85.17515474750151, 96.2264483974826, 102.46148724709789, 112.01889914851036, 111.14323000754081, 109.19975050034063, 106.33965230757191, 106.25238741597822, 103.77938793551539, 105.20257288409819, 104.74902137633293, 110.22300274141374, 98.61446580579205, 111.4762863036125, 66.8115197458575, 57.66785906207178, 105.403335478998, 79.45280890310966, 87.7468724404612, 83.54286040029218, 103.18994199076008, 74.55965995788574, 108.53850949195125, 109.28798813973705, 109.26563847449519, 97.8111251708, 92.95029655579599, 99.90403913682508, 107.12696613803988, 108.6299164064469, 107.39282438831945, 100.85504916406448, 101.20126108969413, 107.2840178397394, 115.93172227182697, 100.97671324206938, 106.01000062880978, 109.45558317245977, 99.68770473234116, 82.65369046118953, 88.91172224475493, 103.1525068898355, 102.73304077886768, 108.17623153809579, 109.99509734492149, 105.98245774545978, 95.24903297424318, 96.59071107064524, 112.43268566746866, 129.24735315384405, 27.897081221303633, 0.28500229721107795, 0.2504174876958132, 0.11220548917809803, 0.15795994489904375, 0.06514994037007132, 0.20340860130325442, 0.9233677363203419, 12.912547530666476, 29.438874721527103, 49.17071480904856, 51.84479459639519, 54.366003928645966, 88.96491742903187, 45.959309531796364, 28.43636005155502, 28.72795101135008, 53.88946733167095, 72.8068390200215, 65.7427405541943, 78.54627855362432, 57.682269850084865, 4.918248682252822, 0.30561842805435585, 0.03994530292167779, 0.11112250132305969, 0.07247411630927555, 0.053479376083780686, 0.051627940753655094, 0.031502000844827106, 0.026953064596220374, 0.03349856961698782, 0.09198242272700995, 0.059631724781807394, 0.024128582689069936, 0.021125380130064104, 0.09828922624189047, 0.073693536762749, 0.009052055651291965, 0.03722613512147819, 0.04394464960862552, 0.02536403544757876, 0.04867128186648892, 0.05783429098946433, 0.07120188941518146, 0.03300309842151981, 0.006847319722686324, 0.038024406399457686, 0.04792947892940814, 0.051756000011077816, 0.05590512454810162, 0.08515214367258934, 0.03459940349022227, 0.003014184189997914, 0.04212978348556546, 0.03922526837296544, 0.09387307409797946, 0.05729997147535605, 0.08950609713792802, 0.012723491808790113, 0.06849667973696225, 0.02586347114805493, 0.03867474226881901, 0.034007497146845825, 0.09968803384371343, 0.05166110853033681, 0.011604177021992304, 0.030261147166452104, 0.03512295563855479, 0.005535373563743047, 0.048586786198880405, 0.03904450609679184, 0.07947712520798368, 0.014515247932004352, 0.02675953354956883, 0.0008596462923319891, 0.03807764567975556, 0.02005096671411828, 0.088267853904155, 0.0806099547433757, 0.09172274956419584, 0.12368560783685216, 0.17464252068631111, 0.06991794903672512, 0.03192269994366554, 0.06713318878844862, 0.025470659564880115, 22.614495831151164, 121.86752350099626, 107.38732522533788, 117.15935353309878, 85.7798900911885, 98.26004043702157, 69.61853258071407, 35.45056989116054, 23.774048474527177, 64.31393877152475, 61.85862918053905, 45.06410698736868, 44.98740896101921, 24.96258351110643, 0.2458660520853535, 0.3171532607126621, 0.4108680916890022, 0.0904383801765019, 0.47069900699200173, 0.33557792043974327, 0.32944863481867703, 1.1659225725358533, 1.1394585861313729, 43.66970046874016, 120.51748291138681, 140.27177072340444, 124.51573525705646, 100.93153538242464, 102.03019126769036, 102.79156254183863, 99.34793333853446, 91.03825092315675, 95.17821065841183, 96.5123656488234, 97.47536243930941, 100.67366307781589, 91.13580026934224, 86.96250038762247, 88.4754370104882, 90.05612865571054, 102.57558115067022, 108.63347791856336, 117.61914945417836, 114.9322239045174, 111.23616664640366, 111.23894368448566, 109.65884039478918, 104.7109273172194, 106.75964401614283, 107.10144719769879, 114.63123690697455, 103.70247810117661, 116.42269319103612, 72.55778420356013, 61.70806507910452, 113.99006274438675, 87.06823179798742, 96.4281915849255, 90.67052871950212, 111.21300897290631, 82.18991725675522, 113.61104411463585, 113.90239777103548, 113.35265405716436, 102.56381404015326, 98.92778473515665, 103.50758337205457, 111.90576230326008, 110.88191386192076, 112.10866651227398, 106.11646160002678, 105.20480079035606, 111.33044473586544, 117.98223541628931, 102.06230763466128, 108.82525044102823, 115.2818012237549, 105.18806795920096, 87.8924943554786, 93.68022611064296, 106.26092249347319, 105.59663772583009, 113.37204625529628, 118.03095909856982, 115.24893176171088, 102.26952645086475, 100.76314803092711, 116.0856282326483, 138.77742613515548, 42.79141510686567, 0.08869723086395571, 0.2469823034780641, 0.05350736893653389, 0.15095307491719723, 0.03681617082967874, 0.3023988363002577, 0.48091022357825314, 14.519521017228405, 38.99680045343215, 49.68917762079547, 47.91803529185634, 52.58468304910968, 51.733038425445564, 22.509044870253533, 32.504189360526304, 52.050075761733524, 77.67634391784668, 96.61218996970885, 79.4137264067127, 90.19568658644154, 77.09910438906762, 11.168328350590123, 0.2565762370584473, 0.06290347946266975, 0.11803196322533394, 0.06708399828283057, 0.04844131376293879, 0.03565055656156713, 0.04755203506999439, 0.02702486235648394, 0.025887522478437713, 0.08758955199511782, 0.0010027689929683543, 0.036131732556368076, 0.021136658859529325, 0.03652914449752819, 0.024807311692124894, 0.07666348344496182, 0.024823014579352834, 0.02281591018301345, 0.020210496863470446, 0.029143955400814454, 0.06094999356015075, 0.033069422483564384, 0.018192372292340286, 0.013087566476315262, 0.03389102879971747, 0.026337007331030986, 0.037990671717712, 0.06587417691104835, 0.11414876312858636, 0.05780770390805218, 0.04070765999776702, 0.02940732685308303, 0.05403843257696398, 0.07521906296812719, 0.21169396477841565, 0.1675621062637337, 0.1685667692893936, 0.2873498357592091, 0.10379372119543054, 0.2064017221451767, 0.14617696104030456, 0.13096829245407737, 0.14001920759197206, 0.17479998239826772, 0.15039177761683542, 0.13142258259317569, 0.08150076944260828, 0.13206114752158044, 0.17345090156360982, 0.12311733913637939, 0.17442369533161964, 0.18221569818354424, 0.10708583849332026, 0.213994940502509, 0.1533939842615397, 0.22599898669267857, 0.19626116950906095, 0.2189209318209079, 0.1683594505753248, 0.3937098672313075, 0.12605703300646237, 0.21596663631498816, 0.19381082196149135, 0.22313331223783955, 46.226870090730735, 157.250173630253, 118.81214618682863, 130.10339475447134, 82.20235117020147, 107.80016253071447, 52.576987358831595, 41.977107524871826, 121.07847598291214, 123.16896592417072, 81.73780133647304, 59.163250923156745, 57.12086885206161, 34.355616723337484, 0.9189293293222305, 0.7113425457669843, 0.8001315233207519, 0.4755845029027232, 0.5039540870535759, 0.31881784719805567, 0.8466037651223521, 3.663091943148644, 2.703296297019528, 40.77060214934811, 122.02227669377481, 149.46969739852415, 131.79319104840678, 103.95503167183169, 102.69185589205836, 109.06588785109982, 105.512094959136, 93.62006479693999, 97.95739819926601, 100.39290766562186, 102.60490479007845, 104.07198106088947, 96.56137174175632, 93.75257030610116, 93.0021659789547, 95.30406382776077, 106.19053948310115, 111.98455487528156, 122.85199919054587, 118.93362983580559, 115.39829561787268, 111.16695250234297, 107.8341616353681, 105.21324957570722, 109.5289707183838, 109.52474240333804, 115.62806806256695, 107.03739489278486, 122.09019645567864, 78.0326049558578, 70.42967873234903, 124.59153113826629, 97.51481363850256, 105.3021461732926, 101.50715889469271, 120.99780067320793, 91.33689234333654, 117.68183677427231, 119.32855759897541, 118.69251389657299, 107.6126261680357, 100.89134677763909, 108.48605955800703, 117.09470502791868, 115.0630114155431, 118.60959499113022, 112.57420478328582, 111.13000377531975, 115.9571078515822, 121.68994211381482, 105.86950917397778, 113.87391351884412, 118.96685231116511, 109.85550803522911, 90.66124839167442, 100.4382424200735, 111.50580606152936, 109.86009720833071, 116.0438471455728, 123.60347824711954, 120.387558321799, 104.25193940439533, 105.23449313256049, 126.43038534349012, 143.56759717387538, 36.962306268753544, 0.5155959268731456, 0.4193848137172961, 0.12026583730813958, 0.42360038105999276, 0.1802888185146355, 0.6953427688248697, 1.7814096231614391, 22.893027259457497, 51.10332935087143, 73.6423195562055, 75.65660568975633, 87.62441604368149, 137.61467872127412, 68.16654174558579, 40.87519999473326, 38.82969571698097, 67.24705188505112, 96.28980252050586, 84.99911877416795, 100.15774588431083, 96.12603572107132, 18.49576396326865, 0.6869677730625676, 0.16209139578765439, 0.32945059600376314, 0.14828275288304976, 0.16379500679191084, 0.13800917673976193, 0.0812785579792915, 0.0998838076127633, 0.14864488264485715, 0.3272275007780521, 0.3636230203893877, 0.17264626409497955, 0.13351771049201488, 0.11185763929519923, 0.14963442309489175, 0.23717188877203774, 0.17309494647047213, 0.15721570580236374, 0.10038476782820879, 0.10680970976189261, 0.1805678890236924, 0.18021902790473354, 0.08196740891904601, 0.1497921605985011, 0.1536190608936933, 0.16867308697152525, 0.1758284401148558, 0.19232946838582718, 0.22589072314721925, 0.14394249706979723, 0.11127240940808289, 0.18533032057025742, 0.13255032530475047, 0.24547971394513887], [0.023257776291199753, 0.07329466542409313, 0.033965867929040425, 0.017444653241264246, 0.03635245397867214, 0.017549739437057607, 0.023861511032127088, 0.026156296765792276, 0.05271116609594995, 0.033902412866272276, 0.05838379819667148, 0.051713930292715954, 0.05449083047888933, 0.004725214037593575, 0.04067869038291035, 0.016891577979549766, 0.0704345680893429, 0.022760265386633338, 0.004718228752138995, 0.1176065929053772, 0.017663700761453762, 0.11989616158027804, 0.03732471914601423, 0.05270661936411935, 0.1496740758058525, 0.13873849244367692, 0.2485977837275113, 0.12213563576581017, 0.3780833283259023, 14.96120245225968, 101.9523008408085, 94.70120337701614, 113.08525039303689, 82.81935568778746, 80.8524674753989, 41.14459622290827, 49.22159971729402, 69.07808488415134, 68.32662151705834, 64.55558423073062, 36.43823054529006, 33.449517834571104, 13.397243638192455, 0.2546129069261013, 0.0875482215516029, 0.10710264646237898, 0.21559874557199019, 0.1702992771301539, 0.041112024186839985, 0.22280553385855692, 2.010785908468308, 4.593287177624242, 83.901686668396, 131.50046456244687, 113.10512896507018, 98.3975273563016, 98.51976410035165, 98.31696971770256, 93.49953036154471, 86.62270545959474, 89.6073232158538, 91.92401624494984, 102.55158408995598, 103.07453017080985, 97.2529483610584, 95.2687938751713, 92.86655395261704, 85.7881349132907, 82.30800413316297, 88.95419366898076, 95.96649723668253, 101.56531195486747, 102.6665016912645, 98.53756381619363, 98.68178936742969, 98.33202377442392, 103.39384248179775, 103.34065514226114, 100.96173763275148, 104.8234679622035, 103.6994343419229, 106.1327237467612, 105.88812474281558, 96.9141104913527, 49.14513311078472, 88.06762818367251, 84.64624666398572, 73.76950633141303, 90.32896872489684, 68.11551955438429, 77.34777481325212, 108.82783920534196, 96.9062343720467, 97.73710220090805, 97.05830466362738, 96.67850155984202, 92.09606709018831, 101.74093215696274, 100.67194507968043, 103.58300270572786, 97.25405446944698, 95.08444247707244, 96.18199225394957, 103.06145298865535, 103.43145016700991, 95.71508115337741, 100.76983174970074, 109.00022737441525, 92.21475016686225, 82.60494324468797, 83.13858955137192, 97.15492048571187, 95.57041629668205, 94.41091660530337, 91.48882142959103, 91.66042512462985, 95.1860083303144, 101.98017320325299, 91.17810695402085, 134.8112980011971, 30.294082818492768, 0.3831741664438479, 0.5070761711366716, 0.11662423836007235, 0.10944451595987044, 0.0422591872272953, 0.07094979286193848, 0.33032473296888415, 6.917987235130803, 29.105006494829734, 42.34535532612955, 42.41225527178857, 39.87352471197806, 80.00867151444959, 63.7473798567249, 35.66972840216852, 28.291499076351045, 31.934029709908273, 73.73592299799766, 63.13606669825893, 70.93873177805256, 66.8340027716852, 13.643938168402642, 0.5019748529359218, 0.08405428605094072, 0.044018105949245157, 0.12510830972103343, 0.047546752893756476, 0.058502392437789714, 0.009248105211994581, 0.018219549261454134, 0.07367267618857085, 0.029130744214560238, 0.04780241558628698, 0.040748745293146184, 0.03876248614922647, 0.03669030641415908, 0.012017691173710892, 0.07135224949207998, 0.05607459468827133, 0.02146103580842816, 0.019173412996854995, 0.10802732990874399, 0.04380089320963429, 0.0660677443468763, 0.045742098722727075, 0.038793087531361854, 0.043792014250591885, 0.023893502863845038, 0.03208614097187116, 0.06203245664496095, 0.04750218572876146, 0.031682923999464804, 0.04387847493372617, 0.010381987160672585, 0.057329193899227734, 0.040570691137784914, 0.12913487551193084, 0.027340532716123328, 0.05456250566508501, 0.036990892502569386, 0.005805371676556646, 0.015319911256102065, 0.007491758151445539, 0.05672462412246293, 0.010171420233804854, 0.10247457141597426, 0.017198853930758855, 0.03478197373389717, 0.06339319733782642, 0.06903559960905584, 0.044386655527858004, 0.029614059509889736, 0.07629954571565313, 0.027791511440168948, 0.035397410467867894, 0.0706882274619514, 0.08678697530300387, 0.063093917429327, 0.018234549263011546, 0.16944999205729655, 0.10203731141143269, 0.3601727442395303, 0.1207824640216366, 0.3973598471812664, 14.219794081103418, 120.22245791650589, 112.06279831547891, 129.76927157371276, 97.31702420019336, 100.40401581794985, 80.77401222721224, 27.909521018305135, 28.80021675940483, 66.78698139805948, 74.01349344561177, 49.55849601376442, 44.557175943928385, 16.71779278785952, 0.14980084803556243, 0.09656935885188081, 0.12248233651682255, 0.3490062160117011, 0.6133714222138928, 0.30441622159654097, 0.12404530143906033, 1.3097158050344837, 7.530189300737074, 94.83173201161047, 138.37077048517042, 117.29704441562777, 101.04176182900706, 104.34951228480186, 102.62686221830307, 98.610731709388, 90.34892574433358, 93.46800235009964, 98.41940633712277, 109.50604054235644, 110.4117315046249, 102.07875021042364, 100.63211733295073, 98.67405445344987, 93.67999861317297, 88.0030502811555, 94.62669403322282, 101.03172056136593, 107.45187959363385, 109.6557495670934, 103.5385230279738, 102.89115152051373, 97.9421558687764, 103.03121151462679, 107.18689210953252, 106.88084525446739, 107.00033633939682, 105.9781039145685, 107.50402358270462, 108.03885444518059, 102.03277218726375, 56.70301091286444, 92.76230519817722, 92.6749304802187, 80.31466345633231, 99.76403405589443, 78.36797545033117, 81.51577949523926, 113.99645620776762, 101.08002847240817, 102.02835559844972, 100.17203900121875, 101.19990394961451, 95.76564834963892, 105.1431489759876, 102.10153133638444, 105.51300494901596, 100.1430997540874, 97.68769602621757, 98.19674907192108, 107.05465332154306, 107.19934171245946, 99.18757115640949, 105.408183528531, 112.8872020782963, 98.06710689298569, 86.98200241211923, 87.19308084057224, 102.82593034928846, 100.77652331321471, 99.12759811647477, 95.25649332231092, 95.58896910759711, 102.43357566095169, 109.9432671454645, 94.65871626330961, 142.56278007261216, 43.94556860769949, 0.11173625266359699, 0.39130358506114254, 0.10801728649605667, 0.14269686874843415, 0.07363941265089859, 0.1316081444101949, 0.15998650792865984, 7.162312653756912, 36.18941891577936, 43.746049404144294, 38.27379780430948, 49.34062404017295, 56.9525364137465, 40.45583978776009, 29.940396816499774, 48.43725119867633, 59.695583235832956, 95.57096542850618, 81.95811302431169, 79.813400237791, 87.4328867081673, 24.149323201948597, 0.2859962503275564, 0.11629829093092874, 0.07116324794028075, 0.0982971246083898, 0.06429545356020813, 0.08540981734592108, 0.039692497737104857, 0.06661787974618136, 0.09604203755096083, 0.02244157855579209, 0.04447997652835423, 0.06640416419794483, 0.08968885507314436, 0.05745546434134726, 0.040577310137450695, 0.026826472397172646, 0.005875183353876515, 0.010439090396938546, 0.031851628051710226, 0.0351664656022143, 0.015215432184988694, 0.037075564370400486, 0.03913698823101098, 0.021485933665967277, 0.015089662572849664, 0.06261662933074179, 0.02562169379915201, 0.10138943851474794, 0.052339467895968314, 0.055882321941035415, 0.04387620348303069, 0.019547943806936665, 0.04966088743399709, 0.12756056482753447, 0.21399569126867482, 0.1444928852781173, 0.10164506673332184, 0.09324853623946829, 0.11084769792374104, 0.17342807214346626, 0.12334990810843245, 0.1229635316638216, 0.1900767255574465, 0.16793244848808936, 0.16766673855243192, 0.1903631198670595, 0.14558020919080705, 0.2076608949010411, 0.12339528349618759, 0.20156461234775283, 0.14656869243950615, 0.1098628229491653, 0.1653687965365187, 0.1467450765231925, 0.29332734404071686, 0.24683820233950693, 0.08127920149314789, 0.2591045723567086, 0.19179467772764547, 0.6568565339811387, 0.3878332986947029, 0.7616240831632769, 34.68551943379064, 148.92605689264113, 116.93892417415496, 145.53058655031268, 107.47162480508129, 104.20315296419206, 60.827508664900265, 73.79821023633404, 102.90418163422616, 104.28368706857006, 84.28951494155392, 63.22181363259593, 58.91469817007742, 26.1962709119243, 0.552085368863998, 0.2041394645047765, 0.37686129551260705, 0.5967930956713615, 0.38984875344941694, 0.45144375473741566, 1.9481700490559302, 5.112720285692523, 6.9355011082464655, 99.00290596869685, 148.8436714295418, 127.92283934931602, 105.55592352344145, 105.12319195655085, 107.18732357025148, 105.76587230928483, 92.58687326985022, 95.65662999306956, 101.81377057106265, 113.87185819687383, 116.2569259828137, 107.98034837169033, 105.20252581565612, 103.60787837736069, 98.47581002020068, 94.09758983119842, 100.0202746545115, 107.46541961546868, 112.21117373435729, 113.52443033649077, 108.9667538673647, 109.10139314589962, 99.7915377155427, 107.89779816904377, 110.56404498315628, 109.77352265388735, 111.88190644787205, 112.47859308796545, 112.49619668529881, 114.29039078374063, 104.38292303392964, 63.701260628238806, 102.61220039859896, 103.64157153714089, 97.5065766611407, 110.31033039093019, 88.77950699098649, 86.99270263794931, 121.64317177188013, 107.16743715347783, 107.04189777374269, 106.02936144798034, 104.85637664794923, 100.9983882596416, 109.01239456668978, 111.85100601565455, 111.1704904802384, 105.735215064018, 103.96004446091192, 102.53981697943904, 112.34106694498371, 113.12301497305594, 102.60801130725493, 111.1583625116656, 120.45540748103973, 100.31926908800679, 89.08468307987337, 92.48587223791307, 110.05864758645336, 108.43757121793686, 107.07727755269697, 102.65065531576835, 101.27609206784157, 110.55162675919073, 112.05067819164647, 102.78850309310421, 150.8459629551057, 37.35160935309626, 0.4746768725735526, 0.8318965317260835, 0.2328164031308505, 0.3552214260543547, 0.27286807736081464, 0.3304097074414453, 0.5489974829458422, 13.20392668247223, 48.07744433802944, 64.28030836966731, 64.09876538861182, 60.28484482919017, 122.5973589189591, 89.91033415640555, 48.398784514396425, 39.13738996751847, 42.212206548260106, 94.4803660915744, 84.01912243135514, 93.28889908329134, 105.92987445092972, 34.43831205368042, 1.0058682351823778, 0.2260195944578417, 0.18131091770145202, 0.2478833607728443, 0.1330722150422873, 0.2158046700060368, 0.21755000215864953, 0.15549882615525878, 0.2821052591166189, 0.31952791877331277, 0.13803746070592635, 0.22018106984755687, 0.24404893749423567, 0.11929313547068066, 0.17145625375691922, 0.19951713511780386, 0.13140909944570836, 0.12647044469392107, 0.13644772101073496, 0.19708725743957106, 0.11711199888058248, 0.15129854992753075, 0.1232972242418797, 0.09319014501787963, 0.0906380073678109, 0.16188957758488196, 0.15534485780423687, 0.24908421891591243, 0.12052528830545566, 0.10435948478839091, 0.185576188828676, 0.08978977949628908, 0.21228847965117426], [0.017935696448529923, 0.031937653979947495, 0.06228378711027965, 0.033327582622728044, 0.047969150792567, 0.03387715111696913, 0.00861102840938275, 0.09714714236437313, 0.073321417214409, 0.032188275813936226, 0.04924795838193067, 0.09843996936275114, 0.08392682434209893, 0.10181532977449317, 0.031780450822665327, 0.04222202430208845, 0.02564580450134893, 0.02162049509464733, 0.060138537908994386, 0.028368488645120978, 0.060581225646479483, 0.022459478200142904, 0.10006340926573162, 0.02554991710630636, 0.04076733824706847, 0.11806630694697942, 0.2116036276903845, 0.17336123863295202, 7.365867976219424, 103.44607276301231, 114.36577873845255, 109.9900531768799, 75.39870985092656, 71.38128495985463, 59.340247877182506, 27.204349463985814, 72.01449671099263, 93.03403131423458, 58.43123466737809, 43.15233199827133, 37.09217202278876, 7.38739590491018, 0.7835082733823407, 0.0588309483963155, 0.018705750793038357, 0.145431189767776, 0.07235260710360543, 0.10847881616603945, 0.48243360473744334, 1.5077106774814668, 14.4303459313608, 119.29190697208529, 114.45356922764933, 94.55314174775155, 94.10707412227508, 98.47925386121197, 90.5502139368365, 85.00017781411448, 85.78794663952243, 90.59172045799994, 90.38684721915953, 103.37803533000331, 105.29733734746134, 105.04729409371654, 99.59925528495543, 98.61724284387405, 95.19637123230966, 88.45005143073298, 83.81590443272745, 85.18751805828464, 95.0533773053077, 103.11846856148013, 104.03118841109738, 103.8474096790437, 93.54210376739503, 96.1129742283975, 97.37152945610785, 102.18900803596743, 100.51336365361368, 100.36381936842396, 103.52382198456796, 109.44183134263562, 92.48704110422443, 116.54568303015925, 67.97436129662299, 55.38963271725563, 87.06530570983888, 70.10992711590183, 82.6293090081984, 64.19968405077535, 103.92809283348822, 100.45397896920481, 101.4533910443706, 93.26272902950164, 97.60189025632798, 92.74652942534416, 92.7836899603567, 93.003766305985, 96.21234355434295, 93.61487942357218, 97.13276693897863, 92.85985454436272, 93.92245600300451, 97.29819682336624, 105.63639486989668, 101.97509765625001, 100.71425176435902, 102.3670522628292, 95.77386179277974, 86.470839131263, 87.20389089276715, 80.29327869415283, 78.58456088650611, 79.82222557067871, 81.45322553573116, 78.2925796508789, 78.63030356745567, 89.04500438321023, 103.69232700717066, 91.82987151607391, 131.07101994176065, 26.598721781084617, 0.8166896864291161, 0.32150059517833496, 0.09698554377762542, 0.0450921995234826, 0.014911346989984234, 0.1344671079348172, 0.2349244166285761, 2.884233517031516, 19.08673571002099, 46.983424694307395, 32.93311034479449, 34.77857766612884, 64.37096611146005, 82.69967632908975, 47.79484541185441, 29.05335476321559, 25.155932826380578, 59.14199167682279, 76.35099857084214, 65.04044017484112, 82.71826051896619, 25.099019235180272, 0.750150537538913, 0.08912348218502537, 0.01353481722499935, 0.042048869279002955, 0.03530555652574666, 0.016623849402211847, 0.03061231229484322, 0.07351940497756004, 0.037705422709545786, 0.06128184752719057, 0.03013410297552905, 0.030498837436278983, 0.029205116030249386, 0.07219338338942298, 0.09216141150963884, 0.060527185804300734, 0.025247588167868318, 0.03847764316766012, 0.05829952086412138, 0.11717174607779711, 0.07797494170165832, 0.03646035746280705, 0.09253084975024385, 0.05269329709511611, 0.02351397907571687, 0.08333655359644083, 0.09439203737964554, 0.09134417189465416, 0.027739553441924435, 0.043346070639428594, 0.014626295249458524, 0.028543432483509667, 0.007274682828856092, 0.07161009936563431, 0.03346387349489716, 0.03449642595144049, 0.07993346846271908, 0.027198957752496488, 0.021214114179113702, 0.04914265959673832, 0.04300390512892797, 0.024734650167726704, 0.03082249617774881, 0.07167158558243705, 0.052177693108998, 0.0399374466900143, 0.031933287278779095, 0.02595701814448882, 0.03959990068969708, 0.030432358241429737, 0.04423277910738703, 0.04769742323626434, 0.039052331684938366, 0.07061521928276747, 0.08049786841917424, 0.047950963865244584, 0.05894709115607604, 0.16134723329976683, 0.1958551429091923, 0.08229894879003687, 8.833139384946517, 118.30020627667828, 121.09487149023242, 120.51364683335828, 95.22301981526037, 109.4075341378489, 80.43522142594861, 28.977962886133504, 42.35065837060252, 76.92351556593373, 67.6096514732607, 55.198546609570904, 46.87747755358296, 9.71082168240701, 1.1376064919656323, 0.14397096489706349, 0.04928435904965286, 0.03970976152847852, 0.7875217773741292, 0.7055922898073351, 0.6635029902381282, 0.7852641469047916, 19.89773673395957, 132.14019529281126, 117.12308729848554, 99.11597221128403, 98.83988441959505, 102.87930596259334, 93.2105536614695, 88.29522763529133, 88.1999611085461, 98.0033056197628, 98.60270654001545, 108.22454729387837, 109.10333079676475, 107.93156193148707, 106.00772565410983, 105.31440750245126, 97.07342932301184, 92.98064785618936, 87.70538160877844, 91.85385288730745, 99.39384860377159, 111.41172409057619, 107.05892086029054, 108.45002866560414, 98.0860205619566, 104.86408018296765, 102.21494274754679, 103.67274653527045, 102.4246483464395, 104.91653796165221, 106.17309278057468, 112.50485727863928, 96.26069068908693, 117.88232480326008, 74.5725880899737, 61.74738291771182, 98.57608149128576, 79.63850959654778, 88.88400677711734, 69.26642925508561, 107.70590797547372, 107.06768343525549, 105.00252416056972, 95.38218175211261, 99.70556720610588, 96.39638116282802, 97.45790004730226, 96.27903169201267, 98.96792627150013, 96.81665528205134, 99.9607095410747, 97.40697199298491, 98.12162783838089, 100.74963154331331, 108.70311567860266, 104.73915269297939, 103.60185361677601, 105.5062427828389, 99.77853113605131, 89.69858892502324, 91.38625144958498, 81.29500496772029, 81.09251652994465, 83.08070321236887, 86.94483403236636, 81.6341801612608, 83.75558622421758, 92.37701077615061, 108.81152214542513, 94.62064573841711, 138.4246010934153, 40.229715147326075, 0.38563208294010937, 0.061619853180262356, 0.19779202768639212, 0.04348716105244333, 0.04486279449455681, 0.11743544120221369, 0.29112545412874996, 2.5157074726396993, 26.545332439484138, 55.5980674682125, 34.24999906170753, 40.82550356465001, 46.34040701773859, 37.99414850050403, 34.81147066239388, 35.988954421012636, 49.77383805859474, 80.82382632840066, 98.23415279388429, 77.34103618129608, 102.12035086847122, 44.20618264905868, 0.8058207986816284, 0.013276935750318151, 0.04931296477274549, 0.033301933999023134, 0.03785701235756278, 0.023519016103819016, 0.01679825506383373, 0.02495585422542307, 0.018020251487952568, 0.04618118967740767, 0.06784163625730623, 0.06038860815967764, 0.051661303882757505, 0.03112303630088366, 0.020691190222879092, 0.05845389524174314, 0.02394141400262954, 0.07691422402257882, 0.06675153910633057, 0.0203100691414288, 0.07707920871795186, 0.02325683974871232, 0.08016517941629694, 0.021963516708403345, 0.012457270509443216, 0.07278487221488068, 0.003510974732513029, 0.11321081870025206, 0.07498788827609632, 0.02223054814573017, 0.02323882136073324, 0.04490748423361971, 0.08245819548685705, 0.20956615556872663, 0.15357594546531478, 0.2000768236335247, 0.2049382950269407, 0.15909236074695665, 0.14664439724818354, 0.18794589796133582, 0.12895069265317533, 0.13972354361847525, 0.2306956266083064, 0.1512041832170179, 0.145945449269587, 0.24711345773070093, 0.14124919239792133, 0.11761515776837066, 0.09243857445976428, 0.10412012827732872, 0.15724794278221746, 0.19819088370328952, 0.23018850704594968, 0.23389255748160426, 0.156788473888751, 0.0914175937613172, 0.19482812543790187, 0.3604407217954436, 0.433098369788739, 0.4385636716840729, 28.675053927206225, 149.1731034555743, 135.3290508639428, 138.84773069812405, 100.62500215345814, 91.8974147304412, 78.69605818102437, 39.00788899390928, 114.25036691850232, 137.79344466424757, 77.80019667840774, 73.06689216244605, 61.50150914346019, 14.932444614748801, 1.6506467495233783, 0.20893758042685448, 0.3016758638043558, 0.37519352210144846, 0.47876278719594406, 0.519210268412867, 2.6546895503997803, 4.446431186891371, 18.915471300002068, 140.34569955641226, 124.36132723285307, 103.54464192544262, 101.849652413399, 109.07292458318896, 98.99010335245441, 91.75883739225327, 91.255503162261, 102.77344903638287, 104.88032664022138, 115.06802420462333, 112.11218880068873, 114.03273813186155, 110.4978745983493, 110.7002139860584, 103.91520392510199, 97.61244927683185, 95.53787631373253, 94.88975955593972, 106.06193280989125, 114.32752778453212, 109.66727349065967, 110.39917207533314, 98.26375099920459, 106.89694266165458, 108.67583167168402, 110.19874680426814, 104.80507204609533, 107.35535006369315, 107.66039279199417, 115.20020807943037, 101.63407110398816, 122.15925370493244, 77.66718126112416, 69.2108335802632, 104.45210579902896, 84.27780274421939, 96.1636277168028, 74.14863478752875, 111.66126528093892, 112.24562783395092, 112.1797477045367, 100.25614246245354, 105.8758947926183, 100.78941222160094, 100.12526081454371, 100.86789884874898, 103.63715494832685, 100.6849830381332, 105.20776610220634, 102.77927767845893, 104.0692981596916, 105.57488426085442, 114.11327223623954, 106.33672621942337, 103.72569068785637, 107.97560230378183, 105.61137014819731, 97.71611752048616, 93.40346367128434, 86.88621813251127, 84.98359403302594, 89.58271426539268, 92.30506666245, 85.65101669680688, 87.46965500616258, 99.99436347715317, 113.83060270740141, 99.94922484121015, 145.19861282840853, 36.07401101819931, 1.2205762656465655, 0.7069585616550138, 0.20450150233603295, 0.19172485647422655, 0.16904857730673206, 0.35975256033482095, 0.45264041471865873, 4.867699626953372, 37.05525467472692, 77.23752483244866, 53.57801545050837, 53.39338556412728, 94.90610799481793, 120.84726795073479, 62.73573783136184, 38.83717567689958, 33.63821129645071, 77.1408619419221, 102.41722722207348, 85.97603997876568, 117.65886737454323, 59.100622438615375, 1.5359310277046696, 0.15593261578150336, 0.20603986817502207, 0.2776495078879018, 0.1563463032606148, 0.16804768343365964, 0.08163081286775489, 0.15627282010691781, 0.11323464403469717, 0.1218140090725595, 0.17307311296463015, 0.11539119686330519, 0.14976833526405597, 0.17592004890884125, 0.14815454040804218, 0.1871034004274876, 0.11371662059137899, 0.12418072280143538, 0.2701001097598384, 0.18072712805963334, 0.20337861662189807, 0.10732232983554564, 0.2210253600271479, 0.11762496369380145, 0.07487282186986939, 0.21114775941016214, 0.15625962807286173, 0.3149483983795489, 0.17424151962322576, 0.12446203028723118, 0.35850800453655185, 0.16247589531685078], [0.07802376448507271, 0.03568526800541628, 0.0577195808141222, 0.014712633358524933, 0.04911315755077428, 0.03883543687181608, 0.053336355129196766, 0.013175152351088343, 0.006987336654997161, 0.07683053657773041, 0.041862721404721664, 0.03550849704732818, 0.041367441731234716, 0.037162637923874205, 0.10599796299732502, 0.05023554913819798, 0.03607592688152387, 0.030552318034273003, 0.10639413004560817, 0.007969313901999306, 0.036701119745210294, 0.04271400596706137, 0.11059702629403723, 0.033299693191844615, 0.07669286291685797, 0.33391311944973084, 0.5241563772001575, 8.494146581619017, 99.79999434563422, 117.54771524860014, 111.35128821096113, 84.8169639033656, 94.7033057674285, 51.18183951224051, 45.58933588766283, 95.82638232938706, 60.11601817223334, 53.70793611772599, 43.47463707770071, 32.18839737676805, 4.157286315195022, 0.7876960776986615, 0.21315072693171042, 0.06119108526036144, 0.23045292995389433, 0.061076195054357095, 0.04456945942834981, 2.0165204136602344, 1.3956907271377503, 16.201211733202783, 110.05623925116755, 94.5288073632025, 95.27765058702039, 98.30788550838348, 90.02889956197431, 84.02440194160708, 87.38223321976201, 87.7351837773477, 91.00346734446865, 92.83553584929436, 95.65894419147124, 98.99242539559641, 102.65882169046711, 100.22074699401857, 101.42260043851792, 95.0859094435169, 84.99788714993386, 81.29687986066266, 82.70453222336309, 92.92019628709363, 101.46311852239795, 101.14484956187587, 101.73715883685698, 100.91267662663614, 101.18871734988306, 92.92975118083339, 93.78025439477737, 92.78267014411189, 95.83396819330032, 97.17162978264594, 96.88426909908172, 96.69858409512429, 99.96993495571999, 95.88429220261114, 104.682647028277, 47.4654173081921, 77.92958782565209, 105.44641094823038, 65.59855030428979, 80.71628278301608, 101.44830765262728, 93.63693883342128, 89.88842379662299, 87.52964373557799, 92.90266329242338, 89.5969524691182, 91.41099376063194, 87.66193743674987, 92.0636369336036, 92.18928613970357, 89.95109542723625, 87.86063686493905, 89.27830696105958, 89.43806509817801, 99.48101935848113, 105.85467476998608, 100.49820761526786, 99.52976657498269, 97.04156398773195, 79.13651681715443, 83.57136818670458, 81.34945531045237, 74.93294408244472, 80.83291838246008, 75.35539903948384, 83.97756099700928, 84.38023936363959, 84.89338736380301, 88.04254854879072, 101.08255447879915, 87.72503268334174, 114.58834971151045, 28.54016753935045, 0.5005313900689925, 0.07872319509906155, 0.14675056171273032, 0.04319647282001473, 0.008497034526249815, 0.04757715892347117, 0.5065705837501634, 0.9312798924023106, 12.67571678084712, 33.924336433410645, 38.92618602321994, 66.69503319648005, 107.51600250121086, 116.4459450014176, 72.94485153690462, 27.6234664840083, 24.962673725620395, 40.75448513031006, 72.16015784971177, 69.73929451357934, 85.09418918240456, 31.291086558372747, 0.7411287797074164, 0.07176601357998387, 0.015195692972009702, 0.03825471158169451, 0.0539651639278858, 0.08363925791796177, 0.05096525171651475, 0.061014245354360154, 0.028203829537115754, 0.04674025383147021, 0.10064915243175723, 0.02762372669343266, 0.024458488877562266, 0.049573120570951895, 0.025877086445689205, 0.07575509468874625, 0.03418379313042087, 0.017313740306323575, 0.05737589844953149, 0.06420626177362378, 0.03337249069684937, 0.13333751129046564, 0.0452209176165202, 0.00931246330090348, 0.041217242532800284, 0.040427781265950015, 0.02291405945265245, 0.043054899771607695, 0.055604844894861026, 0.041055107684505564, 0.06978655729683177, 0.053783440211367224, 0.07728467349924388, 0.032116186940261436, 0.006964310924823006, 0.0499525600894084, 0.0245430592387434, 0.023193445972978108, 0.04849035871185122, 0.009592306601153988, 0.05494819263056402, 0.04543399348133995, 0.0605835200798127, 0.04598663781859702, 0.02707279647790617, 0.05970092167356803, 0.03275964334006271, 0.03275301667951769, 0.042164751568869244, 0.03972107664712014, 0.03928271347596761, 0.07075450938916014, 0.032787996254140334, 0.03204329367426615, 0.01817203457317045, 0.09300929464159474, 0.30373633388550053, 0.5597463093938366, 10.259724047876174, 115.10866780434887, 128.16277857749694, 126.27497319252261, 104.05538943506058, 111.76250165508641, 72.58815903817454, 62.61756858518047, 39.22983631010979, 57.124481354990316, 65.8318607268795, 52.05548471020114, 41.70605213411393, 5.848359340621579, 0.9676101719660144, 0.1061473501425597, 0.049640053672896284, 0.11481214164485855, 0.9282580126197109, 0.6830601117783978, 1.6074450290010822, 0.5442218133999456, 19.14076243677447, 125.81284738356068, 98.4682555352488, 102.88563666805145, 104.81795310974123, 95.25184139128655, 88.89884902584939, 93.64983558654787, 94.2501151177191, 97.28769271604477, 96.83702807272635, 100.75813524184689, 104.06965117300712, 106.96515267895116, 105.47149058311217, 107.17841194521998, 99.65594922342609, 90.5383134657337, 86.42794409105855, 87.13978367467081, 95.15528048238447, 106.42458731128325, 105.38007582387617, 105.40946222120716, 103.92038145372945, 102.15827234329717, 99.27109410685878, 103.60150060346051, 99.2140079313709, 98.68592354559131, 97.00419164473011, 99.12137723738148, 100.1680774073447, 105.62971115112306, 99.23200376572149, 109.91721476277998, 50.096982525240996, 78.06901239579724, 113.28188665451543, 69.91731520622008, 86.92715983236991, 106.80960716739779, 100.0693670395882, 92.47328142965995, 91.07366208107241, 97.75488622726934, 92.77529608818793, 94.24518862078267, 91.98424816131593, 96.15581435541954, 95.46248835902061, 95.47800525542229, 92.47328142965995, 93.59176097377654, 94.3185761667067, 104.46620279742827, 108.27723257003292, 100.53812165414134, 101.19201998556815, 102.86231425500686, 83.41237883413993, 86.42377068919521, 86.43419634911322, 81.22682632938509, 83.74535668280818, 80.3889923710977, 89.37164368168001, 91.606367018915, 89.55585387445267, 92.06770835384246, 109.40896188059162, 95.43223119551136, 119.28664315131404, 41.99100840476252, 0.8012147103586506, 0.13358866555556176, 0.10298738301160837, 0.14273462156134267, 0.07428608278954223, 0.138605346362437, 0.5283971948008384, 0.365317760095481, 15.352927600183795, 41.98886679064843, 41.200795942737216, 65.85105680650281, 94.05831121629285, 75.19600176042127, 41.18012897429928, 23.42791695748606, 51.87077245404644, 66.58264944630285, 88.35218045019334, 84.61598950047647, 98.4841803581484, 55.686285495758064, 0.5537477183726527, 0.03798111094041698, 0.06059145675070825, 0.10155089154479005, 0.027250113273640315, 0.06102179898129356, 0.033941655720193545, 0.04550380707387963, 0.060800797936897126, 0.034881925225378044, 0.049496331747861645, 0.004759873291702881, 0.05784769369769962, 0.014741266852304822, 0.05456057895395545, 0.05567175118372806, 0.02972641779530433, 0.024011928565619935, 0.04629509929086893, 0.04451836902467955, 0.03141472427805345, 0.032492903016147115, 0.1087429709432106, 0.0689652037896937, 0.08320438810774396, 0.04366467511581798, 0.03426540447699447, 0.05614988197902999, 0.08822000405240445, 0.06051741052238692, 0.050141247545158675, 0.2880070779112078, 0.12723970422220807, 0.2128447514147528, 0.14506645530702608, 0.09314694531982945, 0.09020635512687507, 0.09495292099252825, 0.1738009118144551, 0.10940397458691752, 0.14790349339525546, 0.135911597359565, 0.1818186807776651, 0.16513376076134945, 0.13290542237941297, 0.24696670592792574, 0.17100187168727, 0.12790708171744503, 0.09082756050291563, 0.18552738902789934, 0.18657225634782545, 0.12924667838360035, 0.14266671552773447, 0.14578008153025182, 0.2190497571662549, 0.17282342958834865, 0.48100423788832086, 0.5432637744853573, 31.259368311974313, 145.91763034943614, 140.54614836169827, 141.29894533464986, 107.05419048186272, 119.22288110179286, 64.0098060331037, 64.61093671860235, 143.5290167408605, 84.6928914900749, 74.06642975345736, 71.57683864716562, 55.45264167170371, 8.891501311332949, 1.5889259259546957, 0.7152078577107, 0.24268951447259998, 0.33072233260158573, 0.3567693526706388, 0.16957987460397905, 5.638127653829513, 4.651869737332867, 19.489559204347675, 133.85383175265406, 102.99221531037362, 107.1429301846412, 108.94319611210977, 101.86132538703181, 89.36843518287905, 97.31725169766335, 98.40712931848343, 103.65417019013437, 100.82003024316604, 104.92126049533968, 108.08929612559658, 115.76382913897115, 110.76336414583268, 112.48745764455488, 105.096221739246, 96.8676539390318, 93.20712550993889, 93.04913243939801, 101.8527275516141, 113.57929645046111, 109.1707092715848, 112.45852624216388, 106.93691161371048, 109.5400082680487, 103.40623717154227, 111.66341473979335, 104.1641410704582, 104.38482146109305, 101.93237520033314, 101.5245585287771, 106.88144929947393, 110.57062672030543, 103.58081402317171, 113.05755845962034, 58.05376537384526, 87.02813733008601, 114.15861483543151, 80.70432739873087, 91.08225207174979, 112.56313585465955, 105.65971728294127, 100.17329415967389, 95.89353330673711, 104.5253364501461, 98.39118880610313, 101.92184755879065, 96.74355799152006, 104.65522966077252, 103.20062652710946, 100.61216031351398, 97.66204372529062, 98.67515271709811, 97.93938667543473, 110.0198475007088, 113.4051275253296, 107.3694549068328, 104.7567484455724, 106.41492259117865, 87.16499667013846, 92.52623342698621, 92.33262523528069, 84.80225501521942, 87.56922045061665, 83.69917469639933, 94.74420039884507, 96.56359180327385, 91.26909809727823, 99.53540694329047, 112.25336274793072, 99.5080994021508, 124.113645245952, 37.204908786281464, 1.1688241458708242, 0.837241925539509, 0.3025130140444925, 0.3143334442809705, 0.16311997607831033, 0.28127485045021583, 0.6815235845504269, 1.805606479606321, 22.312606688468687, 54.473790660981216, 58.889253754769605, 95.08184586801838, 144.7961933382096, 161.02328977277205, 106.08740468179028, 39.45607077690863, 35.54975094333772, 57.30943679809571, 95.98887043614542, 90.45105641888034, 116.3711375574912, 67.959087587172, 1.3045062845753086, 0.2799410300870096, 0.15472288634027206, 0.1849817352429513, 0.08322722518876677, 0.1580431573693791, 0.14854455577029338, 0.14221435593020532, 0.1510398880007767, 0.12355819975416507, 0.18939011159443087, 0.1638106962726001, 0.26570457304196976, 0.07818805204043466, 0.30037985754109203, 0.16269971556480856, 0.1350024501763044, 0.11440331116318704, 0.11041392361925495, 0.21202471557884447, 0.130752531451083, 0.21664643209547768, 0.20169648672303847, 0.1806710351018175, 0.1417809340261644, 0.09609560241862651, 0.11245915621158578, 0.2116835613044039, 0.1768929192856435, 0.15484765141962037, 0.1784497172000908], [0.02103810356329045, 0.060757667186760136, 0.051313055634138086, 0.026420235123124816, 0.024161277406458414, 0.011149976898225085, 0.06086727138608695, 0.04124183395516969, 0.04022018292978887, 0.04036696537608101, 0.041788652193762606, 0.09277857960231843, 0.05094640595357745, 0.06794766282602664, 0.06138805795701281, 0.07871616241191665, 0.011917450484038602, 0.011371965238433934, 0.030973988149555463, 0.04093575118590267, 0.04044478458742942, 0.040877838769266685, 0.03334151393163108, 0.11557660546273955, 0.1255927837243484, 0.258531354728245, 28.119228578382923, 109.44104686860116, 119.83569652803483, 105.5106907506143, 95.43101526075795, 99.47053094064036, 47.33171939849854, 61.18044745537543, 50.82249549127395, 63.55885897913287, 40.250719439598825, 41.76975534808251, 25.75898547326365, 1.3390426313684833, 0.35776443959724524, 0.26019024151948195, 0.24888776332860996, 0.31590349551650787, 0.2827228179141399, 3.5589586534807762, 33.30062858520016, 1.6238123442857497, 4.005818107435781, 88.86146883810721, 93.3825574382659, 98.75068187713624, 97.3412173794162, 89.10918220396965, 98.47738681300994, 105.7175330192812, 98.33734250837757, 97.12973102446526, 94.07207089085733, 91.95941171338482, 93.29898741937454, 98.23282703276604, 94.97274121930523, 101.13975832539221, 99.67825182022588, 87.18271793857699, 78.3301559571297, 77.18305095549553, 81.62417027258104, 90.07384207940872, 100.9191014689784, 103.94567289660054, 101.4909516611407, 100.20845428589853, 97.24935546998056, 103.13485622406007, 99.45531998911213, 94.36050630384877, 97.11656755016696, 94.90593541053035, 89.42377982601043, 93.57141956206291, 95.02218661769744, 92.83998381706976, 101.29818285665205, 78.54801224124047, 26.92277035405559, 61.58125877380372, 48.04251563164496, 93.91444652311264, 100.90397680959394, 92.74739234678208, 88.2102769420993, 94.16924368950629, 90.61280712004631, 91.64884628788118, 91.3726878935291, 89.68600596151045, 86.54465813790598, 86.29450505779636, 88.67272438541536, 87.01198500971641, 88.03536276663505, 90.22792062451764, 95.46182940083166, 104.92334719627135, 100.94100398402061, 103.40349935716199, 91.03894126030707, 75.89367374297112, 77.7723321607036, 70.21266183545514, 77.49944502307524, 82.82283090776014, 85.20205436214324, 84.31029565872686, 88.15201405555972, 91.43898379418158, 96.31862409653203, 92.15232956794001, 106.27928703061997, 88.9617246197116, 105.35807917194983, 30.817623138427738, 0.6597549816773784, 0.25092408631838137, 0.029516795071803277, 0.22476745438912224, 0.15079162954803438, 0.02585424744944659, 0.1207481892479043, 0.2683919481933117, 11.196832214632343, 36.902384219631074, 73.2419083195348, 84.55020350794639, 104.35166958839663, 135.51572430518368, 88.14611481082055, 27.488986061465358, 26.978862208704797, 45.69623224196896, 63.49135106609714, 69.62081540015437, 79.94642349981493, 46.024609150425086, 0.9447472278148898, 0.16322145208476052, 0.025046739066320083, 0.10732488090833349, 0.025934073811156616, 0.02492029050875816, 0.06556981017873173, 0.05005237751550252, 0.06089006250183429, 0.06435205979693322, 0.06818309696691652, 0.04102409644533069, 0.01239083632225952, 0.03529774625935862, 0.04509909431480112, 0.04833820215877026, 0.10090531691187814, 0.03571344854971094, 0.0714978981282442, 0.08695854069364649, 0.030634322000907797, 0.03281404707400549, 0.018554168805900603, 0.08659661777557866, 0.04933317417218801, 0.03540644647493478, 0.050645272112301284, 0.030170517049789913, 0.05650465729676428, 0.01204653438406005, 0.023955538748733463, 0.04591293632984162, 0.04784885200581724, 0.014918223586714557, 0.032494845049035166, 0.03587307062961402, 0.10502811866782366, 0.03506142345647659, 0.03342034437903955, 0.012128180204590243, 0.04929749745755427, 0.06147869764977406, 0.040654133434497544, 0.023891547424418312, 0.03720271198319332, 0.09576929492815849, 0.06508706753412563, 0.10387771507544864, 0.017074364643063278, 0.0577819173885209, 0.044397158593299894, 0.04805708236451592, 0.03258578351608688, 0.1196851273397765, 0.07893571555013619, 0.2780612954689611, 30.365430731927198, 124.43518546319778, 129.57189006190148, 123.18429454680413, 122.88415478121851, 116.49929708050145, 74.83227252960205, 70.17090428260066, 31.747581804952315, 58.153075864238126, 51.51557830072219, 48.6423990034288, 34.08804047492243, 1.8587319192386444, 0.6250444571337392, 0.13116557541633808, 0.21066290236288504, 0.3724167291675845, 0.7674239203333856, 8.294588154362094, 28.68789576715039, 0.8083469889337017, 5.399081745455343, 102.12445366767146, 100.37796343526533, 106.45052986760294, 101.79288787226524, 94.42133442048105, 105.0260191579019, 110.98280506749308, 102.45414457013531, 100.55893375027566, 96.31740816177862, 97.01440549665882, 95.35403482375607, 102.80180777272871, 100.47077455828267, 105.39516910429924, 102.73414688725626, 91.74593279438635, 83.1468814419162, 83.68576803515035, 87.28739815373575, 94.79650128272273, 105.0990693799911, 108.93599464047341, 106.26227963355281, 104.69421802028533, 102.69570765956756, 105.23016283589025, 102.34229426230155, 98.62489146571006, 102.61205919327276, 99.33876283707158, 91.77513876268941, 96.57542167171356, 97.22300498716294, 97.96388579953103, 102.80425533171623, 85.8489473404423, 29.649039237729966, 61.436982231755415, 53.4094633594636, 96.65217461124544, 105.10398803218719, 97.54498450986802, 94.86358165740968, 97.65346157935359, 95.96045678661716, 93.51390977059641, 94.43002639278289, 92.808895111084, 89.70957940624606, 90.08604065064462, 93.5698349245133, 90.64865758342128, 92.59913459900888, 94.00397854466593, 100.11834959830009, 108.3707183407199, 107.20627646292411, 105.73676832260625, 92.35026805631577, 80.844434461286, 81.81915913858722, 75.63374611639208, 81.3231832750382, 85.9448100674537, 90.36339144552909, 88.20995530774518, 92.39899173859628, 94.99607147709017, 103.84952775893673, 97.41181219777754, 109.25271034240724, 96.01550332961544, 111.8699275293658, 43.73478827937957, 1.9451652683558005, 0.18441581077152686, 0.2652586792265215, 0.3353651318578951, 0.13318493721946595, 0.013581540927501216, 0.10795523337418995, 0.2616140618920326, 12.455712018474458, 45.114380005867254, 77.2358460580149, 87.38045246370378, 82.39307249746015, 106.00997709458875, 52.909996586461226, 20.145826647358557, 44.949001112291896, 73.76748238840412, 84.54703423284715, 81.4910371841923, 90.0363834442631, 70.29949526632987, 0.8187356314832165, 0.20020376440257798, 0.03427951964699934, 0.03696000000702278, 0.043092507027810624, 0.01956912805326283, 0.0838059586502852, 0.06017607621728413, 0.037533665796922105, 0.030339826311495517, 0.05354864575389413, 0.033757786957486983, 0.016262422526074995, 0.0661060257604526, 0.029213424253788207, 0.06189740683522917, 0.044031493335721955, 0.08265096619124375, 0.03997551742941141, 0.07321170576277279, 0.036009445771454804, 0.04199412080549425, 0.0815035273591357, 0.04505279196065761, 0.029782397755151315, 0.037188692574178984, 0.04178959065146985, 0.050373797365013635, 0.061881977824434165, 0.0487408809544098, 0.11685974910975465, 0.14470047978383882, 0.20084717100666416, 0.07868715832310338, 0.1961958375308783, 0.08064881072289522, 0.2780443802475929, 0.16071476643123936, 0.20779126774399512, 0.1410034926788461, 0.11668551773313554, 0.3892571803542876, 0.11740217766454143, 0.13775416139152744, 0.18281490151439944, 0.22751888981269253, 0.08819645450961205, 0.23940212393720306, 0.07197885578798671, 0.15133922919631004, 0.17355985458820097, 0.13097462034033192, 0.1371143860442023, 0.22817060080987794, 0.16539470563011785, 0.34336302850034933, 60.81202314745996, 156.30075608530353, 143.79181554240566, 132.08980068083733, 119.08421747146116, 125.15455599754088, 59.53412279005974, 82.59753780980265, 73.98558970420592, 88.97875555099981, 69.6232629591419, 67.21095823472547, 46.08232290514054, 2.825099619165544, 0.7744665359777789, 0.48933902935635665, 0.45863823965191847, 0.6683283635685522, 0.7545262479013013, 4.991201335384, 57.16248912196006, 8.960248693343132, 5.368767707578598, 113.6950534389865, 105.37905600763138, 113.04916458745157, 107.124965729252, 99.16719836573448, 107.28317845252253, 118.14192295074464, 109.68624207281299, 106.38537145430043, 100.54391891725602, 104.2049886334327, 105.03671938373198, 107.75623982952489, 104.30209082941856, 112.40349538864629, 107.54149790733092, 97.29261921298121, 86.93586749415245, 90.79309494264665, 91.66200191743913, 99.99323383454355, 110.4955525552073, 114.12150136886106, 111.69099684684508, 109.26252411257838, 106.70717054797758, 110.74976921081544, 106.52078736212947, 103.03241960463986, 106.55910107397266, 100.74596020483203, 94.5283837472239, 96.84551608177924, 100.99557984259822, 101.44030601747575, 106.57322945133333, 88.16114533332087, 39.97701252660444, 76.44597484219459, 60.39900149068525, 99.75880161408456, 112.31201002674719, 103.7000854553715, 100.70104122161867, 103.45616109909551, 100.99106911690005, 101.2192020108623, 98.51934832911338, 99.80599557199787, 94.23824602557768, 95.07132607121622, 99.71636941356044, 96.35799684832173, 98.38951787640973, 99.95517899913173, 105.86903064481675, 112.75022506713869, 110.80854985021777, 110.28160295178814, 98.93843789254466, 84.62466578329764, 87.00836073967719, 78.78900266462757, 84.83754850202992, 93.32780899540072, 95.44238228951731, 92.25846890480288, 97.44755283478769, 100.58842212923112, 105.63130363341301, 100.98088664393272, 114.10541180641421, 97.46918862865817, 115.5929942284861, 39.002001516280636, 2.2419355953893354, 1.0388490557670593, 0.27851990634395235, 0.4395129771963243, 0.30637817277062324, 0.12384621050929832, 0.24268389138723576, 0.5124483780274468, 19.910798226633382, 60.08930683135987, 81.54383228671166, 96.37667517508231, 119.8242667413527, 174.02043988627773, 135.52509092515515, 40.14032040872882, 38.213926745999245, 61.41288711178688, 87.23386564562398, 88.201961517334, 107.74444134004655, 85.16701190702378, 2.0240701182234675, 0.32827602999825634, 0.09496711660176517, 0.18898149561737815, 0.09646109530642148, 0.13284678600968855, 0.16223350509760842, 0.2313884152399917, 0.14122777257955846, 0.13699797132322866, 0.11485261406989829, 0.09873160371376623, 0.11740216234278296, 0.13917341588004944, 0.06904277785290634, 0.15663439828541972, 0.1817023120219669, 0.20162113431480624, 0.1316813824157561, 0.16909457322570587, 0.09928071255525274, 0.1280885219814316, 0.16657668736673173, 0.14603269136240407, 0.13539882406832712, 0.17597398149871057, 0.10597849670316904, 0.12774314656252825, 0.14405316613133878, 0.12547139709274616], [0.013606541249300204, 0.01762813896000866, 0.01806291300923594, 0.08837908987076053, 0.025254090339125648, 0.09387988461962632, 0.038767783647222866, 0.01653095549573341, 0.018838218886465318, 0.05145291647603435, 0.04738412008831098, 0.020142159905404817, 0.030610285992283496, 0.026150612393394116, 0.0586939259101787, 0.1031431669910108, 0.023340540600099394, 0.035111923972445155, 0.07476413697605172, 0.06118288045869239, 0.018999127994081186, 0.0848536987999274, 0.08649159478203905, 0.10160999522814829, 1.3801312975345121, 56.94634691361458, 110.43260635868197, 109.1509013022146, 98.69340742788008, 114.796094125317, 67.87696100050404, 35.57876079313217, 53.44452934880411, 45.75308307524651, 115.73182259836506, 41.49090620779222, 27.96294370005208, 28.293795624086936, 0.683511245635248, 0.4364134773852364, 0.02827142722033445, 0.3712026330251848, 0.11164971537167027, 0.18471104573578606, 0.10328123135672462, 22.17015208736543, 12.11258895935551, 0.8795234825341933, 55.2092311459203, 97.4492080750004, 106.40854481727847, 97.72871617347964, 97.75854187626993, 109.56455446058705, 107.03158978492984, 102.67749217248733, 106.34089177654636, 104.4940673151324, 98.73864020070722, 95.87847925001576, 93.68862782755207, 92.66840365625198, 99.63260327616047, 94.3795847123669, 87.3330702320222, 76.34605638442501, 73.3463139687815, 74.94767650481194, 81.88671804243519, 94.29051553049396, 98.28273527083859, 99.30117084134011, 100.17865211732926, 95.07874719558224, 96.49749202112999, 96.99109877309492, 95.4483207579582, 99.36522314625402, 98.06544380803263, 98.26784595366448, 98.82341830961167, 95.74263188146776, 93.41130841162898, 94.61129480792631, 92.75522139764603, 97.2929879157774, 50.90039768526631, 16.722776159163445, 52.36024110547958, 99.25838562750049, 91.18960734336608, 86.0457875651698, 83.2222693966281, 87.25815296173097, 88.67966698062035, 90.29942543275895, 89.07308070890366, 89.37533070964199, 86.77069648619621, 85.99405150259696, 81.29883320100846, 80.78303367860856, 81.44265867048695, 82.32364654541016, 85.07624826123639, 93.23073033363589, 100.22520280653431, 96.76768841282015, 79.1499391678841, 73.64385712531306, 73.97030815001457, 77.45027419059508, 76.73816788581111, 82.4734732412523, 82.13849498379616, 86.8467120201357, 91.58961065353887, 93.74434117347964, 93.21038107718192, 98.01773209725657, 95.40337039578347, 101.4543402579523, 86.91531427444951, 95.1192888136833, 31.99786432327763, 0.02335290334397747, 0.575020325280005, 0.15605727360854227, 0.07574397875296493, 0.17992940070408006, 0.0371259116687842, 0.020598001372549805, 0.2733666167384194, 8.570213106370742, 45.50728382602815, 84.17358536874094, 93.75976393299719, 111.11121562219436, 120.50817904933807, 99.40535683785716, 30.859100241814893, 22.32648011176817, 44.016559585448235, 70.61235920075448, 71.40429358328544, 72.06593467343238, 50.029984520327666, 1.8492108559416187, 0.017938519482530894, 0.04376942231770485, 0.024224236427295594, 0.1236649081411381, 0.08618964888756314, 0.039350845505513495, 0.035474693417669304, 0.017234747065231204, 0.058999108526134686, 0.051326600068639365, 0.04314722868824198, 0.06390139325371673, 0.0216992374419445, 0.0069928433907578795, 0.05182164991574903, 0.040223082572582274, 0.06761841355792939, 0.025751884696224046, 0.08736413062339829, 0.06970853890262305, 0.0427392102597702, 0.023830049716296698, 0.025837889557043393, 0.010974553297273816, 0.02801674703556684, 0.024439145157474185, 0.008150491780871827, 0.04252776999266879, 0.02223816305969752, 0.08858725894242526, 0.018092428461738655, 0.06601293075589404, 0.036591825811492826, 0.05836903185193097, 0.07167799007748404, 0.041999379999094436, 0.03264066222454271, 0.018415152575940858, 0.012195920571684839, 0.04783330042095435, 0.06444571404567649, 0.02060459930479767, 0.015586959930407185, 0.015138049643757123, 0.03049639744624015, 0.05451103987833185, 0.03047306240806657, 0.03262724036410932, 0.03858579946081004, 0.09802458882932702, 0.07664093747735023, 0.20952411266344212, 1.6176151219875583, 69.664761635565, 132.9205116148918, 122.01369454783779, 117.34806660682925, 122.04279068977603, 84.33408875619212, 69.60245086300758, 55.893912238459436, 23.1800643474825, 58.4799308930674, 45.43841485054263, 36.32484659071892, 37.44154145640712, 1.1137844670203425, 0.4966961700589427, 0.11996992818650701, 0.5933534221783762, 0.1055164690760355, 0.49585705863371976, 0.6055337911651981, 12.674552817498485, 5.834006897864803, 0.7040841997631135, 65.2931074942312, 105.35428231762302, 111.68146548732635, 106.0533114402525, 102.85176307924333, 115.41076875502064, 113.0865526199341, 108.74998015742149, 111.1098349478937, 112.3220826733497, 106.25010459653794, 102.6260228310862, 96.58168961924892, 97.32653987023139, 102.88974731199204, 98.93703368402298, 93.1694079983619, 78.78934783320274, 77.60049312345444, 82.35951269826582, 87.59636325220909, 100.72979219498174, 103.86124780101161, 105.26032586251537, 103.24050134228122, 98.86006109176144, 99.6989070215533, 100.38725945257373, 100.70738761655747, 101.8190187023532, 100.15244283983785, 100.57232472204394, 99.54190238829582, 98.70425670377671, 96.20963711892405, 97.95600968022501, 98.00505499685966, 99.87127165640555, 59.156818236074145, 22.90192907856357, 57.17410326004029, 104.46851699582993, 97.72131858333465, 90.29839777177381, 87.46311249271517, 92.65270633082237, 94.7243610505135, 94.78902524517429, 93.2316795472176, 91.78631751768052, 90.0667896578389, 89.71135231756395, 84.80190984664425, 83.73587239173152, 86.0016530559909, 86.85534907925515, 88.94798063462781, 95.52030409536054, 100.5755175313642, 99.92969143775203, 83.81289205243512, 78.90201399403234, 79.4794810202814, 83.40917033533897, 82.07523499765705, 87.11588075084072, 87.41758946449526, 91.23012542724611, 96.65418286477366, 98.38338328946023, 95.49558531853461, 102.69722953919442, 98.74888543159732, 106.3167299762849, 91.92728750167355, 97.12729131021808, 46.652572770272535, 1.3532092518383458, 0.5069549760270504, 0.28035260316345, 0.1927258422778499, 0.13482465649083739, 0.06621664119583946, 0.05246112265834405, 0.5000700519209909, 9.795859648335366, 47.59770708699381, 84.68215988528344, 93.51184660388579, 106.61204522655856, 109.6645905894618, 39.4912975834262, 12.612146927464394, 34.880221966774236, 60.609758284784135, 89.20570388917001, 87.88586554988738, 81.55564646567069, 78.33601597816714, 3.751489909425859, 0.10082803396207672, 0.003932002530951474, 0.0508275397512461, 0.11589421785526699, 0.04921239275004595, 0.0647067278623581, 0.051305908033804554, 0.05243830855995898, 0.02754145651124418, 0.06244414846502966, 0.11388706749365216, 0.030623384180568883, 0.03825237501352545, 0.08164804218517197, 0.05288339798308669, 0.02611929854948915, 0.03594846134224246, 0.05091141105719632, 0.04809273992695155, 0.05039568066657071, 0.0716526555498281, 0.04471727609333973, 0.009916138670016682, 0.06917092904087997, 0.009878527583374132, 0.01739832024360376, 0.02050490636799124, 0.023512383697614558, 0.12512799818068743, 0.12617399931074152, 0.1205884752374503, 0.1097031778866245, 0.14061568364981683, 0.24146329881923817, 0.13605419696579057, 0.12856225543204816, 0.1288396711911886, 0.11937232597941354, 0.18863790518333837, 0.11639192985791354, 0.10707034819549131, 0.07421553375259524, 0.11913279326812876, 0.19493995895308835, 0.11218879612222796, 0.09265783648457258, 0.16401219271844433, 0.11293013940655416, 0.16504880161054675, 0.18545261884648956, 0.18368212836644343, 0.3686746654491271, 3.454213228917891, 104.52416758383475, 154.29711526440036, 130.75298632344894, 127.9273343855335, 138.7854434597877, 85.28281596399124, 48.43401916565434, 68.75118670925018, 64.87377474384924, 170.06454129372875, 69.55358597540086, 49.49558119620047, 48.44589610253611, 1.784929705242957, 0.7675593033913644, 0.3038716862999624, 0.8299450912783224, 0.34893601171432004, 0.48915673107389485, 0.39495917277470716, 33.188672373371745, 24.14773856439898, 0.9225558669817064, 73.90460060488793, 106.54349004068683, 117.09839205588065, 109.97642686290126, 105.50331669469034, 120.17371070000434, 117.79040013590168, 111.70696873818676, 113.88479417370213, 118.01722295822637, 111.75799877412858, 106.51397028276998, 100.15468643557642, 102.33681863354099, 111.07876193138861, 103.95445900578653, 97.87257302191951, 83.53791821387507, 81.87980682619157, 83.9228988462879, 91.19503590368456, 104.39910673326062, 107.20656671831685, 110.0320617614254, 110.15651072225263, 104.98486565005396, 105.27392864227296, 106.61522234639814, 105.33543925131522, 107.75279598851358, 105.99440528500466, 107.27864419260334, 104.39332515962663, 102.16687802345523, 98.92660802410495, 100.98316161863266, 102.00910460564398, 106.4049127024989, 60.984901612804784, 30.645672313628662, 66.49397250144713, 111.65873927454795, 104.29286541477327, 96.66367500059067, 94.94713598682036, 98.12908818644863, 99.60701373315628, 99.63307396058114, 100.06633112507483, 97.78290763978036, 95.18643194629301, 95.25719150420159, 90.79793514743929, 89.39357757568361, 91.98468746677523, 92.31502948268768, 93.94577841604911, 102.75154652134066, 109.05903154803862, 108.17705523583197, 88.9819875840218, 82.23077266447007, 84.24623550907259, 90.52038823404621, 86.22627150627875, 92.28687470959079, 90.81917870429255, 97.12985654031077, 101.93912952176987, 102.0516074088312, 103.56920380746166, 107.42307370708836, 102.725627499242, 110.83822650294151, 93.62803505313013, 100.8704170103996, 41.540837980085804, 1.5500791394902815, 1.3615273732331492, 0.3278949778647192, 0.33235014686661385, 0.40445596640629156, 0.35232113974709667, 0.21527637577345296, 0.6153348749203067, 16.40805596305478, 64.9913203331732, 95.96405752243535, 97.79796169650172, 114.58881255119078, 150.6144646675356, 140.8436836734895, 47.29050313272784, 34.302947136663626, 60.27863963957756, 91.93812893282984, 94.51586354163386, 93.08680288253292, 89.08293370277651, 4.948030258378675, 0.2613221823928818, 0.09426643726445975, 0.13834791017636178, 0.2926903878969531, 0.2705589657829654, 0.1660973767960264, 0.11206164084855588, 0.10175211219898156, 0.13397837448264324, 0.160088014578627, 0.3623436535558393, 0.12025580921721075, 0.06045539570491641, 0.14196697081769669, 0.18669060161036832, 0.08988611505276735, 0.11190009588796286, 0.2096706193180815, 0.12510120042509612, 0.17109640693712622, 0.13636171998035523, 0.14979473465392668, 0.1975837896668142, 0.2529548168663056, 0.15048249774882871, 0.10594947729259731, 0.10108604471409514, 0.12744343764479124], [0.04054086733489268, 0.09298949126875208, 0.07262384819407618, 0.0637208569734808, 0.00396784108165922, 0.04605539420980119, 0.03841250271145855, 0.03796172125505344, 0.015523728948356885, 0.06887125076665994, 0.03778556699774439, 0.08175511829434864, 0.026239570523161563, 0.06679125310432527, 0.03332966638188208, 0.09795538044624752, 0.01757496479718435, 0.03414256610877572, 0.058217377086440404, 0.07254159333364618, 0.05866609776632921, 0.04134945015633299, 0.08207911986016458, 4.968080434107012, 89.43382893839191, 110.78199540415119, 105.58395278069281, 117.66935579238401, 88.6930501076483, 73.0893987224948, 89.25142303589853, 55.07701981452204, 64.88276481628418, 124.82589275606217, 45.83242870146229, 33.930733819161695, 35.604511153313425, 0.9911572019900046, 0.40388740659240757, 0.35425045557560464, 0.08067209979579335, 0.1172377675351116, 0.2923535237148885, 0.1529906542911645, 1.9975168978975666, 4.900652929659813, 1.3924688677633963, 25.893993454594767, 103.50778733530353, 100.37549234205677, 104.10232451654251, 104.45771478837537, 111.1234926408337, 101.02717061196604, 105.64205092768516, 102.4897518465596, 101.47227333438013, 103.09090998864944, 103.8606986691875, 98.01681426263626, 97.97348776171285, 94.31875659573464, 93.40143188353508, 90.65735740046348, 87.35705160325574, 74.46520928413638, 71.78550874033283, 72.92365504849342, 85.53282783877465, 93.37022550644414, 101.44214953145674, 99.70392765537386, 99.48295700934626, 89.79714239797285, 97.4311573274674, 99.55951383036953, 99.8488356990199, 95.84542935894382, 95.49995483890658, 92.86478888603949, 100.02360082441761, 97.27848299088018, 102.87461480786725, 93.71735526669411, 99.85738646599555, 89.18682944390082, 103.98270791576755, 34.33435355463336, 47.701045851553644, 106.12927206100957, 87.63810511558287, 88.09950136369275, 80.32378688935312, 90.3031438396823, 84.00766911045199, 89.33125895838585, 87.17280218678137, 89.04935036936115, 86.53736252938548, 84.55250986160772, 80.5304487289921, 79.21886305655204, 80.68531959287583, 83.54505692758869, 83.68088860665598, 86.95268661745133, 86.40081697894682, 77.41706740471625, 75.18905916521626, 76.85674113612022, 75.78618511076897, 74.22842364157401, 78.46799588972523, 82.40198412249165, 85.58750567897674, 86.06597992681688, 90.32766649799963, 92.86543215474775, 97.9172174392208, 92.5089906877087, 104.0675566273351, 88.47116162700038, 96.01438153174617, 90.13347779550861, 103.24386673588907, 24.286276678885184, 0.790003840961764, 0.5117799203482367, 0.08346770784907764, 0.0890566027092357, 0.08236704634562617, 0.05902188815056317, 0.009183487610801334, 0.2525723704527463, 11.494446954419537, 44.20384883880616, 79.501187416815, 88.05121698687154, 109.48297700574322, 101.0986989544284, 91.7091017384683, 44.59512095297537, 24.526955273843583, 38.28044622175155, 55.523032526816095, 83.35206062563005, 98.05370023173671, 35.07564621586954, 1.2559394971016915, 0.259713183247274, 0.14203342128424876, 0.10560925764542435, 0.10969870393314671, 0.0833546256105746, 0.12087538282597259, 0.041503820703515125, 0.019153910313522624, 0.04152038735487769, 0.021896941752563563, 0.020109566694666303, 0.043889062268839735, 0.04088420879035708, 0.04423990372508284, 0.048523407744904684, 0.044900915029669, 0.011695728359383442, 0.061715549053323854, 0.04323314161851041, 0.042857900261878974, 0.027384418062865738, 0.03531641965251296, 0.1039188539969825, 0.043478948589895046, 0.006587356404070893, 0.03231892827898264, 0.019646853418840517, 0.022188108789944844, 0.03370207321319369, 0.06411387540039516, 0.019757681443626364, 0.024207962804564068, 0.036918336315260786, 0.04154125942037471, 0.030498048365716974, 0.07807801883187025, 0.008077562125700136, 0.09399386318100077, 0.01122522684219744, 0.017136226242948926, 0.0011334595230085055, 0.036080573204784624, 0.007905076471938482, 0.056501673384299206, 0.06593239959329367, 0.0158631355847202, 0.040279953109641234, 0.09427107209640165, 0.0932578442077483, 0.06083879972838106, 8.375745915597486, 110.33655535790228, 133.83495730738488, 117.16404468782487, 137.16782662176317, 105.57671993009507, 112.78005861466931, 98.04696944452103, 34.153085139489946, 45.92098405284267, 65.89497166295206, 53.20560209212765, 40.54241041983328, 48.5056887134429, 0.8027810843721513, 0.29855482160083713, 0.271784859679399, 0.3907861079900496, 0.09426456800992451, 0.7278959897737349, 1.5672285999021225, 1.795879124153045, 1.501416008799307, 0.5270334357215513, 34.82610110313662, 112.37085342407228, 105.07976347400297, 111.08405713112124, 109.40637311627789, 115.71950635602398, 104.35414068160519, 105.8854732205791, 105.944198946799, 106.28827710305492, 105.5623640552644, 107.45364466021138, 104.11700987046765, 107.20408778036796, 100.05959249311879, 97.69615265630908, 95.61036955925726, 91.15753020009687, 77.82089894817722, 77.73745444513138, 77.43850708007812, 88.64023147090789, 99.61687457176947, 107.42488584210797, 100.67559288394068, 103.14302259875883, 95.6316601845526, 101.25107519088253, 101.73911217720278, 104.24611076231926, 99.83763340980776, 100.47807801154353, 97.40445383133428, 103.38879831375615, 99.08889216761436, 104.78473847912204, 97.60006243182768, 104.00538706010389, 92.01283439513176, 107.91276593362133, 42.9015984073762, 50.602858451104936, 111.44242840428507, 93.57551451652282, 92.61765603096255, 83.71708423860612, 95.24370639554917, 89.27534164920931, 91.77328740396808, 89.29001915839412, 92.79920685675837, 88.80541816834481, 89.97222131298435, 84.86156125222483, 82.20844653344925, 85.57862543290662, 88.75353305570542, 88.43464436069613, 87.60777734941053, 88.20418942359187, 79.77318025404408, 77.85542365043395, 79.17033549278014, 79.61761120826968, 79.02938119826779, 80.17318356421687, 87.35225062216483, 89.56560488670104, 91.72147289399179, 95.60121474727508, 94.53909181779431, 102.75464519377678, 95.45187442533432, 107.15563081925916, 92.34563181477209, 100.81173835262176, 93.79795212899485, 107.59643462396438, 35.31738188958938, 0.6258022100214036, 0.9312794021060391, 0.29178717023422646, 0.17243413434874627, 0.09516062275055917, 0.14144995339935826, 0.011743355088026054, 0.478982164133941, 12.97689107156569, 47.6037867607609, 84.67036139580512, 96.77181474624142, 110.45023349023636, 103.97170958980438, 51.20821745164933, 26.22805779980075, 45.62316240802888, 60.68632295054775, 72.88315265409409, 96.30327193967759, 107.5701076753678, 59.537766671949825, 0.7144143744822472, 0.1839115870215239, 0.08687104579181441, 0.12364880497296973, 0.016772374698531725, 0.03869059645841199, 0.07896112668658457, 0.038505586224698254, 0.05688334221861536, 0.011351366091759936, 0.033799473631886706, 0.047836383924849575, 0.03885748871271649, 0.057095242138471336, 0.01589932557826321, 0.03980783227410528, 0.05633647035386774, 0.002346992710485093, 0.02667762534392457, 0.042175959435201464, 0.041422619213981014, 0.11405441173983198, 0.05923036365739762, 0.0357211017680745, 0.10083060801750231, 0.0020160089714467647, 0.06778232573020844, 0.05446813895457214, 0.13256174001482227, 0.265566953007252, 0.13489567284141818, 0.2244129701847992, 0.09276982321734391, 0.11884717270731927, 0.17989883379590127, 0.1496258275883813, 0.1569598171138956, 0.1013850641527003, 0.21575096724254472, 0.13320491679253119, 0.08383751381188632, 0.15175956631860427, 0.11450984334993748, 0.23676220027189102, 0.13150820057959328, 0.20123645092450804, 0.11855324009253133, 0.17274187186792975, 0.32093424169767293, 0.23417204167814026, 0.1564532184913274, 12.791662043140782, 143.23723946848224, 147.0863397659794, 132.2808357977098, 147.36426322690903, 119.11651426746, 96.5637408533404, 102.86266726832237, 68.65239004934989, 91.46054898538898, 181.04215714239308, 68.11458603028329, 55.568457495781686, 61.5777757090907, 1.9253604859113695, 0.7632936032549028, 0.7256102285558178, 0.4124113604907067, 0.21971009431346772, 0.7056368454810112, 0.9214587677871028, 5.004228507318805, 15.354447518625568, 2.0500891607615257, 38.34709513571955, 112.8831934159802, 107.05797164670884, 115.06910677879088, 114.34266028865692, 119.89955271444013, 107.54571837763633, 110.09745551693825, 109.24964304893248, 107.40174385809131, 109.61728680518367, 111.09751086081229, 108.57166136464765, 114.12111697658416, 104.29197111437398, 101.79520991540726, 101.96766868714364, 97.01183242182579, 81.78970213859313, 79.35790323442029, 81.13257961888468, 94.09135326262444, 101.71596234844577, 110.76859658764256, 105.37168195170742, 108.40895360515965, 99.82906695335143, 104.9283286063902, 107.54091739654542, 108.64545683706962, 102.82422804063367, 104.80874338457662, 103.63178130119078, 109.81505270927184, 106.03698653559532, 111.39228482400219, 103.93567869740149, 105.64494563687234, 93.80443188451952, 109.4900921852358, 48.7579990971473, 57.22718469558224, 113.39998922040387, 97.90797633509483, 95.80341292965798, 89.44600397540678, 99.71398461249568, 94.90333880147627, 96.55215417185138, 95.96648939194219, 97.06916178426435, 94.1201356149489, 95.72947625190982, 89.96426674627489, 87.40695984132829, 90.17467052705827, 92.77491169591104, 95.06285375164401, 95.00947813833915, 91.8798032883675, 82.91592444142988, 83.79352338852422, 85.27499475786763, 85.95465521658622, 83.58264107857981, 86.94349258176743, 93.07178020477296, 95.97188657329929, 96.845578839702, 100.85322918430452, 101.896179568383, 107.21390939527943, 97.65068454127159, 111.52734771851571, 93.52279786140689, 106.82434743450534, 94.11415792280629, 111.2345035614506, 30.604401134675552, 2.25904080656267, 2.3390605901518176, 0.26717230557434024, 0.2674073413495095, 0.2446939988482383, 0.4043137804875451, 0.13337678095746425, 0.709644588491609, 21.545467568982033, 61.153979301452644, 90.97660695352863, 97.98765536277526, 117.20974030033236, 122.89551396523754, 125.81884860992433, 71.68228764687815, 35.94967580610706, 54.30045327832622, 76.40317393887427, 106.04725530070644, 118.83601773169734, 77.35266993122717, 1.610128420495218, 0.4000070180383421, 0.19074265514650654, 0.25811236592069753, 0.40882867370401665, 0.17242446631914185, 0.29422651675920336, 0.1437260619094295, 0.12423726775112653, 0.2883260156358442, 0.16190661538031795, 0.20920258556162158, 0.15840732492506504, 0.20142219660262908, 0.19230838564615096, 0.21189820381902882, 0.12115484403987085, 0.127325490747969, 0.09113109986027403, 0.1880550654905458, 0.16060406672618083, 0.204275720902989, 0.180644988112392, 0.1945415932324625, 0.15339326413889087, 0.10372900974846656, 0.18278393624050004, 0.1249548699706793], [0.013004945808901422, 0.05136097060336221, 0.04210312745624012, 0.033515343112089944, 0.03357878285309961, 0.018492418288763975, 0.013982956635675604, 0.03935053523990416, 0.03774471918962175, 0.048324983311636795, 0.006334348685002976, 0.018341924146478696, 0.026197885763981653, 0.02003335052229945, 0.016784563157407027, 0.07274885842156026, 0.037560229895696524, 0.05049016612071184, 0.03264934583116443, 0.0722840192517446, 0.07207692270317385, 0.27064326609815326, 4.679426839274745, 111.3704921353248, 109.0922304891771, 107.1015727135443, 99.6795383576424, 74.79155048247307, 75.51338426528439, 40.733076833909564, 23.53533302584002, 81.93057014096169, 110.6411744702247, 61.94276009836505, 39.751033013866795, 36.42114077844928, 1.4572606620288666, 0.12788026097921595, 0.2797979861497879, 0.17728840451567404, 0.22595354235701023, 0.7229393396166064, 0.10322090193268754, 1.1854596532160238, 2.142796218395233, 2.479731248271081, 21.251799714180734, 100.47876834869386, 102.76723600202992, 103.4243114532963, 103.92609242470034, 103.67762596376481, 105.22132181352185, 108.31201614872103, 105.05630770037251, 103.53240413050499, 100.68137445757466, 102.45828659303727, 100.94749942902597, 101.32785166463545, 103.08854087706536, 99.34870212308823, 94.48093091287922, 87.17549293271958, 81.16249161381876, 73.28032401300246, 73.46963328699913, 74.10097798993512, 79.31860893003403, 99.1765179172639, 100.1080180752662, 92.26660390054026, 90.84501143424743, 89.74510039052656, 97.18986095920687, 96.33109723368, 97.97019297076811, 94.42280923166584, 91.66622238774454, 89.62086323768862, 91.09206584192093, 88.18515808351579, 97.38245717940792, 94.26381203436083, 98.02590631669568, 87.94361068356423, 100.27245952237038, 73.66134305154124, 43.76996017271473, 101.4677704534223, 83.92437365747269, 81.1665081208752, 77.58716490960892, 87.61499451052758, 84.3636477378107, 83.4632049068328, 84.27871273409936, 89.2007460132722, 87.21690531699889, 86.16895783332087, 77.12200318613361, 81.14557050889539, 75.77672435391334, 79.88373617972098, 76.40315040465325, 75.03587492050664, 74.40078043168592, 75.5544436362482, 73.54575864730343, 73.14993658373433, 70.33456125567037, 75.47070103306925, 73.84274482727051, 75.0774912680349, 79.08714986616566, 86.4479717131584, 88.19698795195549, 88.6868449180357, 90.11300302320912, 97.06307426575692, 90.40146197042158, 97.5457219154604, 91.33986549992716, 96.39599677055114, 94.26206265726398, 95.69865426709576, 10.915600234462369, 1.0170073374625177, 0.49947709986759775, 0.08979180196840918, 0.032903506991363345, 0.055400310910397, 0.013650801979125509, 0.039796375429197665, 0.20758791736537413, 13.975610848396057, 38.879705936678, 78.17316701335292, 98.87992397431405, 92.22413247631442, 69.78609623447542, 43.500881656523674, 32.78745705081571, 31.528433099869762, 48.36568363251225, 65.22883161421746, 75.11051762488582, 83.95070060606926, 28.93423826463761, 0.6886477119499638, 0.09906384072476819, 0.07669450234501593, 0.0648708468783767, 0.04869664703766185, 0.019057741381167885, 0.07004863597572812, 0.08050159160648623, 0.029804951383642135, 0.013525402004409944, 0.06989334229259722, 0.009505640031890044, 0.05842378032543968, 0.04952704421274605, 0.048637482067269665, 0.04237086369445728, 0.029337984404616782, 0.07994652260094881, 0.03642569581467298, 0.026261126322131005, 0.0682320959505535, 0.02920009240868592, 0.01331879000645131, 0.04342983852350905, 0.053275366869544795, 0.03326144625222491, 0.020044700114897663, 0.04283498657206374, 0.021259158233841582, 0.03408068152625234, 0.10703132367662846, 0.019874783728512067, 0.047478096093982465, 0.024472548506192626, 0.049022238235920675, 0.07481002564271612, 0.11593035422265531, 0.03850250655124265, 0.005729055912759636, 0.030928878977354017, 0.03300746512268821, 0.022621291291509426, 0.06105954413332286, 0.03749234301428642, 0.03172068830369221, 0.045797371966463905, 0.02012684963823807, 0.10157116223126651, 0.42899952360218574, 9.51939727029493, 138.39999998769454, 126.50272953894832, 116.24637480705016, 122.24321596084104, 84.0422644153718, 91.71921360877253, 60.89367512733706, 48.84417749220326, 62.659792900085456, 70.10341598141578, 66.92668053411668, 43.33158823751634, 52.8246497338818, 1.705491413031855, 0.19828635358041335, 0.16915923104651515, 0.3989192344728978, 0.14325612825491738, 1.5699968126512345, 0.7862664350578863, 2.0279682187303423, 1.6581781905504966, 0.3055283667579774, 28.51183625959581, 108.95787362129458, 107.22605305333292, 109.16721836213144, 106.84031148110668, 109.24717980046427, 108.29747984486242, 113.87392920832481, 110.27440148015177, 107.26018551857241, 103.49300784449424, 105.29488194373347, 104.78888050202401, 105.7938466533538, 105.82749274469192, 104.9891959467242, 99.34113979339601, 91.42430628499677, 85.08743486096783, 76.587658697559, 75.79992909585276, 77.67814036338561, 83.04461740678357, 101.70859613726216, 105.09206402686335, 99.02550666562973, 94.37243030917261, 92.21403629549089, 99.7377698652206, 100.50227119076638, 102.80038002998599, 99.22914828023603, 95.8855002926242, 92.6303017523981, 94.49862864709671, 92.12995636847712, 98.00698480298443, 96.89099988629742, 101.82777343257781, 93.48458613118818, 100.67498883893414, 80.23354884116881, 48.79702275799167, 105.15968568863408, 89.33239644573581, 85.64369755406534, 80.54573028318345, 91.89168022524927, 87.21944701287055, 87.88479866520052, 87.72459337788244, 92.8589210202617, 88.76447646848618, 90.09846671935051, 81.41955591017201, 87.03151841317454, 79.20630362726028, 84.79845031615227, 81.34711757782968, 77.33036733442738, 77.83285433246245, 79.2056760480327, 77.02620321704497, 76.81324205090924, 74.61281591846098, 80.12357342627742, 77.09866508360832, 80.65250504401423, 82.84570617060508, 91.12433125895839, 91.78910240050286, 94.63464859993228, 92.60923077983242, 101.39771692214474, 94.77194724544403, 101.43120611867597, 94.58776843163275, 100.4125665849255, 95.50167283704205, 101.95578390552153, 17.641638440470544, 0.09629074033469924, 0.49299406548661573, 0.48930139911751597, 0.7873130337365213, 0.3251268264026411, 0.13275862461136234, 0.02528952765128305, 0.09753577110748138, 17.28735427702627, 43.420453456140336, 83.66632876857635, 110.15158422531621, 97.55701834155668, 77.59341716766357, 29.085914358015987, 26.77568539496391, 49.66655338964155, 59.37605519448558, 79.52307424237652, 81.05916853873961, 101.1028645115514, 53.665233273659986, 0.5507159100905542, 0.10847335395913933, 0.02177478903303704, 0.07531346032215704, 0.05709197094303466, 0.018681712869194247, 0.07502894292795852, 0.012960170842556944, 0.09310916952428319, 0.05047638802939365, 0.04675762487515327, 0.10137600133255606, 0.017126642483016177, 0.03947975129009255, 0.0517090158386817, 0.04690795813897445, 0.049701536059259414, 0.1287576844615321, 0.03557687039457021, 0.09906877433100054, 0.03329300524426564, 0.0965373210548874, 0.021205581874857028, 0.034905428802894975, 0.08616357125462064, 0.06099286000995387, 0.03212801725303214, 0.12285241827128396, 0.183068783052506, 0.12940129024847863, 0.20988487878874426, 0.07998803690556558, 0.22032599836107225, 0.08817524153498874, 0.11984039804026966, 0.12953848127395878, 0.17916407886772387, 0.08327308321191419, 0.19534639924043612, 0.16726297957281913, 0.11210232011733517, 0.09862121810475666, 0.21926997680096857, 0.1302669083158816, 0.19081688906636932, 0.19492161880818107, 0.18504640838551908, 0.24217580655409446, 0.6354664398297187, 16.45711991094774, 173.6267594368227, 138.92868841848068, 135.01140163790797, 133.09725361485636, 96.62932288262152, 102.25279361970964, 62.19252486382762, 30.87319135665894, 102.89046902810375, 161.02798092749813, 81.71997808641004, 64.70017064002253, 70.06560433295466, 3.3251218978435766, 0.36895747446725446, 0.6892180490878321, 0.48750939688855605, 1.1103457741199003, 2.7293798135172938, 0.8639866065594458, 3.7718411270649206, 9.494364703855208, 4.847124343918217, 31.643407575545776, 110.58506888727989, 106.48645877838136, 111.00345242408015, 108.87866527803483, 113.65302132021998, 112.89535276351438, 118.1543411747102, 115.9613283218876, 111.39741528418757, 105.20388295573574, 107.41709601494574, 110.19804077763712, 111.16219074495378, 110.6660972102996, 108.8145737494192, 105.4988451926939, 97.64550701264413, 89.9918096296249, 81.1898305339198, 79.05528453088577, 80.4618464746783, 88.93291873316612, 109.74698389730146, 108.17634920920096, 104.09593105316164, 100.94524014380671, 99.91266050646382, 105.23977264281243, 103.67572753660141, 107.5719198103874, 104.62904391750213, 100.02677794425719, 98.42759624604257, 100.27909617270194, 99.0762072224771, 105.25128872163835, 103.29008794599964, 107.02547088746103, 98.9425563812256, 103.9806761280183, 82.91393972212269, 54.32104964410105, 110.23680163967995, 91.99100248275265, 88.97258174034857, 84.38870383847146, 97.13009188252111, 93.82063127333119, 92.41558336442517, 92.84463574809413, 96.82712801041143, 95.91493375839727, 94.8260602643413, 84.75923445916946, 93.17653886733517, 84.58870549355784, 89.26013854242142, 84.94259741998489, 81.85893981687485, 82.5370313275245, 83.25138907278739, 81.28163753017303, 80.87466024583387, 79.6945838005312, 87.22731528743621, 81.64583744541292, 83.6880273203696, 86.56208130621141, 96.71213980643981, 98.18463679282897, 99.10517000382947, 97.99522553720783, 106.25968302449873, 99.30848998408165, 105.52395620653706, 98.88006517964025, 103.11340870395784, 101.71487192953788, 105.48977667285551, 14.817150465903746, 2.202377756757121, 2.0443194768121167, 0.46723950714353596, 0.8062081327361446, 0.7664455341235284, 0.3628267486008906, 0.11219055046357455, 0.35639262127299465, 29.417384055352983, 55.63143507126839, 92.27913979561099, 112.2334449521957, 105.20143539674821, 85.2515782079389, 63.104075847133515, 48.51489059386715, 46.198044592334384, 62.64734329715852, 88.55390010341522, 93.90260096519225, 112.50903852524297, 60.99937123637046, 1.2416162269730722, 0.3016831876049119, 0.2678108245374695, 0.3455230287246166, 0.25454201314958835, 0.14474741033008023, 0.15980563456973723, 0.20347413246429738, 0.14405319677485576, 0.10745490135084237, 0.3027053021134869, 0.2202593793551768, 0.15233204850266058, 0.2295758358893856, 0.14382182289996456, 0.13059772040334441, 0.0974680336132165, 0.27027995656094245, 0.11443491995094285, 0.2518101436116042, 0.2175744250416756, 0.16203377065399002, 0.09049487150003833, 0.1539996993397513, 0.3027631877170455, 0.1309275672200226, 0.10423393063848058], [0.061827321281476375, 0.016644537606607043, 0.05361238043875464, 0.03560279480992787, 0.09508321722668987, 0.014527796452204067, 0.0669502393312512, 0.03700442927619142, 0.07631509730051603, 0.017666858958921606, 0.048652980025977864, 0.039804407861083746, 0.02197033106048982, 0.04513226592192247, 0.03602431936850471, 0.03262563540990795, 0.041002148026300055, 0.024113368182893724, 0.03919418052499814, 0.04477867421003119, 0.07909788870282712, 2.101169329497122, 95.40617881282684, 116.99634767347767, 103.67443315444454, 106.55840289208197, 83.93343433257073, 145.8229757124378, 151.5417286657518, 97.84880345867526, 56.07227417730517, 59.14966383287984, 84.10763463666363, 47.754441076709384, 37.1192559888286, 1.333046553115691, 0.04090150322524771, 0.08702992476643094, 0.14017668462568714, 0.34472096531141194, 0.30366698760659466, 0.21571632474660876, 1.216427378596798, 3.485717215845662, 1.2201108519108066, 24.943505102588286, 104.86695135793379, 103.49959742638373, 104.59251880645753, 105.64252161210584, 103.09609536201724, 107.09269246747418, 105.75580750742267, 98.9258784632529, 106.82506915061705, 103.2789013462682, 104.24170201824558, 100.12053043611589, 100.0167445213564, 100.18732840015043, 98.38638782501222, 97.79389027626284, 101.39912897540678, 93.90074960647091, 82.01227311165103, 72.51947833645728, 71.41947315585229, 73.90445155482139, 74.88138060415946, 82.46815450729864, 89.9817212935417, 88.82936816061698, 82.33545287962883, 90.33786466044765, 97.6566622334142, 97.59694806991085, 97.99928911270635, 93.56239811066659, 89.4225952702184, 86.81057914610832, 88.90942373583394, 89.62310683342719, 89.98445910792198, 91.11777305603029, 90.22067208443919, 91.05034751276817, 92.28163442304059, 94.27164108522477, 58.6669808818448, 88.6742776440036, 93.95315247197306, 78.66775435786094, 80.77642840723838, 85.3378075938071, 82.76316381269886, 79.49001650656425, 83.05530194313296, 84.1658426100208, 86.69945055438627, 82.67545177090554, 81.1776319626839, 78.01351085785898, 77.32358163402927, 79.72258952356155, 79.79216452567809, 73.55980073252033, 75.06122912130049, 70.42020228601271, 70.59590878025179, 71.30316703550278, 73.23393021860431, 67.85812577893658, 72.79796661869173, 77.87524730928483, 79.58150186846333, 84.2991247484761, 86.47952325882451, 89.70606496257167, 90.77212595170545, 89.08857407108431, 97.31167408727832, 88.7802443965789, 94.00894426530408, 93.0528586910617, 92.40394961449408, 99.40011655130695, 78.11492766103437, 3.9413826359856516, 1.4027780823169218, 0.13609159737825394, 0.06903255823999643, 0.07820556481038371, 0.10787718433646426, 0.08084135926178387, 0.10778619607369747, 0.6288987986983792, 13.605739185887, 30.939522558642974, 54.66560240714781, 90.1966122658022, 68.37462348322715, 48.89537226769232, 60.4583038053205, 29.277469188936298, 41.92734441449566, 66.13921765358218, 80.24810083450811, 80.02195265985306, 87.50243033132246, 5.2882478217924795, 0.4595242663016243, 0.1330653968597612, 0.0752878959681238, 0.07240575062291277, 0.014183200527763656, 0.052723009815259333, 0.05183529394168047, 0.03681745019651229, 0.055836153652278654, 0.011918481829906664, 0.033637304309635394, 0.042039840932815306, 0.07194594465075962, 0.09657774751465167, 0.045744806843539404, 0.022182928120356896, 0.030484364120169517, 0.005380540012171673, 0.025298117412134044, 0.03256363208375631, 0.026418448223041433, 0.03870029513153338, 0.07024135305396012, 0.06316492228858894, 0.04622580280767814, 0.05210300336682028, 0.026864407155963204, 0.05141475763652594, 0.05744114615804246, 0.03556498070998538, 0.041106401101475766, 0.01790622313086304, 0.021873080028942036, 0.020273739336839607, 0.04998794952107053, 0.03840272742954474, 0.006585201302978902, 0.058999859292300484, 0.06535219524296061, 0.04317913241984864, 0.05312578054144979, 0.03950316293705856, 0.05135047136835995, 0.0071077288087126956, 0.05838128925871946, 0.06551242253232388, 0.06971141173233909, 3.3124413653727505, 121.0537728955669, 134.2141877451251, 117.48335699881278, 122.02528122932681, 96.07213451016335, 139.8675783218876, 142.93019633139335, 107.32568910045009, 22.31586225571171, 49.985257733252745, 85.97462792550364, 52.4351897547322, 50.73204955747051, 0.3382801270532993, 0.1521275949574286, 0.05485451156874338, 0.20833244757546535, 0.1373609897470282, 0.48896563810206234, 0.5792468630017773, 2.3653002660120688, 0.6256000853834615, 0.5835202240174817, 35.0703392490264, 114.98818043739566, 105.78892800115771, 108.47080153803672, 111.03713773912, 108.60642925385507, 109.04219673525904, 112.5586094394807, 104.7778586418398, 107.63055139972319, 107.92038317649596, 109.31095753946613, 104.14623937299176, 104.46663425814722, 103.03216857294883, 100.51134755534511, 102.49795744496008, 103.8426322321738, 98.60893526384908, 86.94441826112809, 77.16336850197085, 76.23517882439398, 77.8845041028915, 78.42399474113219, 85.6547115695092, 93.65468363608085, 93.14333992619669, 87.72689973154377, 93.91476031272643, 102.60386143961261, 99.90573360073952, 100.30937687043222, 97.50723561932965, 93.48009893971106, 91.23695819608628, 95.02270437056019, 91.82464691900438, 92.69803324053365, 94.92655923289638, 94.68268194506246, 96.70499324798585, 97.72812781795379, 98.53317076160063, 67.25903864829772, 90.08076898513302, 97.7443350515058, 83.36872285412204, 85.85971816893547, 89.92756905094271, 86.50209257679602, 83.67338903488653, 84.60835656812115, 85.17129513525194, 91.01719564007175, 85.91439600913756, 86.60001062577771, 80.70319775612124, 83.28181097584387, 81.94889545440674, 83.31540215399959, 76.02914456398257, 79.94250897438296, 73.69830746804514, 75.80765616509223, 74.61848766573014, 77.25585799063407, 71.54814258698495, 77.36124423242386, 79.1058046587052, 86.05848035504742, 86.04637592069565, 89.14900210595901, 93.37047653813516, 97.37011740284582, 94.14292458565005, 101.2357230340281, 93.34986840524982, 96.29035165232997, 94.4623153440414, 95.42588480057256, 102.28592195818501, 90.16306815608856, 7.65442890505637, 0.9323583603385956, 0.793679224387292, 1.1039548847944507, 0.48069268525127445, 0.2490070585401789, 0.09246688140856643, 0.09269830890961232, 0.01967796807988517, 17.504357445624567, 33.43358124456098, 59.713359417453894, 100.47537942086497, 77.6751515173143, 41.20902507535873, 36.16122491898076, 38.21564082176455, 51.678482178718816, 72.17152487847113, 95.7217021142283, 87.11077382487636, 105.74990041794317, 14.981785089738908, 0.6208758969460765, 0.24303195577475334, 0.10055025048073261, 0.1307354017250961, 0.03864517893582102, 0.004138056002932811, 0.025123654293917844, 0.022012728281439315, 0.032327542937691175, 0.1042364587286307, 0.06342101015991743, 0.0039662006958913545, 0.034743623372407696, 0.0570846050076427, 0.0708019991795863, 0.04044820900045095, 0.04969059249326106, 0.04679942263230201, 0.024766096161798607, 0.0284706503002634, 0.03182918742118824, 0.02276174776676682, 0.1270740147259447, 0.023858959959339232, 0.013283253102863749, 0.051924052888587605, 0.1144708494745916, 0.13306257765619986, 0.13567772603804065, 0.2255370816396129, 0.16316998629800736, 0.08038598127783307, 0.1634158851999429, 0.19824167533266931, 0.18725888563259957, 0.09244713932275773, 0.09317094685449716, 0.19614248716783142, 0.14868553127011946, 0.19236526001364956, 0.19138779310930162, 0.09108983836467228, 0.2174154311538704, 0.13088982972887256, 0.17603376700032144, 0.21718097760552363, 0.3049845975493231, 5.518431625058574, 146.77865336018226, 147.5982875208701, 134.68943780468356, 135.83812744386736, 104.01166285237959, 160.26561337132608, 161.11005260098366, 115.65546189585041, 77.53790778498497, 83.37102136304303, 112.27510052342569, 71.60929233797135, 65.4136380072563, 4.254151698081724, 0.3187495734422438, 0.3113020037210757, 0.3998222989180396, 1.1067395224686594, 1.5041250182736305, 0.4196118208910189, 5.652152578676901, 12.871695064729261, 4.0786293100926185, 35.80313997883951, 117.83981415533252, 107.31396121363487, 113.61681784352949, 114.1996349826936, 113.05376160529353, 114.92434778521138, 116.93460172222508, 107.95035008461245, 114.84343713329686, 113.15421350540655, 115.87919389047931, 107.82895272777928, 108.62005556783369, 106.95767664140271, 108.75923695102816, 106.75431743744882, 106.58492595918717, 104.27916849813154, 93.29874423242386, 80.01166820526123, 79.69546241144981, 79.27764369595435, 80.62971607331308, 91.98384807955836, 98.53244120074858, 99.07073943845688, 89.4911269218691, 99.7951384513609, 104.94144501224642, 105.69079029944636, 105.13211927106305, 101.00080443966775, 96.31519594500142, 95.22462798703103, 102.27362140532463, 97.50704734556138, 99.54212988576582, 102.87090424568423, 99.47100162506105, 99.12373850422522, 101.36671450830276, 100.9334965675108, 69.67925871572187, 94.08356343546222, 104.50919981925719, 87.13456692234163, 90.46224301861179, 94.64613329979682, 90.90175244116014, 88.72499389033165, 90.35712349799373, 89.89473096786007, 94.78507934078094, 89.45757496741511, 91.94632668648997, 85.98257464747276, 87.28662152444163, 87.835141458819, 88.22215387898108, 78.80682591469058, 84.18392473651518, 77.77381481662874, 80.74659485970774, 80.63432093589537, 83.11418456415977, 75.13023145737188, 82.48861359011742, 88.30165247763358, 89.65712162756151, 94.1823914743239, 93.01811433607533, 96.90821909135389, 100.77043579470728, 99.63849467615928, 105.09710035016461, 96.258894243548, 101.47050826780259, 99.45313130655597, 99.18935191246771, 108.29646002861762, 88.04042262415733, 5.610194004351094, 4.239481543340991, 1.4218780638710147, 0.21732976720217737, 1.0444579225394035, 0.3243115249901049, 0.19996220155829386, 0.24666310528353338, 1.3688874557133646, 29.807814821120235, 47.14032734594038, 74.5717094790551, 107.86884323243173, 88.12827587127687, 62.949071622663936, 90.02985662029636, 42.00259116388137, 57.69893207857686, 83.83157037919568, 105.72988064058366, 97.08817743485974, 126.48890710646107, 19.429660689446237, 1.0995887964963913, 0.2716885164620415, 0.3360155405056092, 0.25164638465690997, 0.14482922852039337, 0.1491360982219058, 0.0898342049350181, 0.08335811131063008, 0.1803789870633233, 0.1788884097890508, 0.13841595410579635, 0.09476693782715068, 0.1466555208448441, 0.21151114555616535, 0.29057420790195465, 0.18085037628489156, 0.18375751141819263, 0.19701530646172263, 0.09944714515680268, 0.11092479701244062, 0.13180676036544386, 0.13721148002772562, 0.19488158305325817, 0.11240108674692531, 0.1646484134178008, 0.15733587435416638], [0.04781133284972561, 0.07249805655690932, 0.01939076937795166, 0.0071744770919453475, 0.0496613011214762, 0.04179607558574888, 0.014458913656492389, 0.015217477639746523, 0.07753546004213634, 0.04636600455870071, 0.01066407414093133, 0.1526450567067631, 0.01233993839818023, 0.015918679832060252, 0.010681344635574328, 0.06388717849228172, 0.012144897200707949, 0.05883745631323226, 0.023349534472330444, 0.014809096277120614, 0.11918767580702422, 47.05672987045781, 118.7937738049415, 99.35776279818629, 99.05854086722098, 74.93493664649226, 70.19014743066603, 51.27319151355375, 115.87500479913528, 87.19779552951937, 131.2087735822124, 90.19252515608265, 70.19342653213009, 32.14291749462005, 0.3398086563233407, 0.6335172670022134, 0.10843072882703236, 0.09700343959153661, 0.08289763118110358, 0.5594346648262394, 0.30572341274349923, 1.7783162214102286, 0.7739774041598844, 2.6077539786215755, 31.325162149244743, 128.0094139037594, 100.89025635873118, 108.18701805606966, 106.44824704816266, 104.9672620527206, 107.62749979572912, 101.84354136067053, 97.23668621432398, 97.91850397663733, 90.30436761917608, 91.80771012460032, 90.16919489829772, 94.14630566873859, 94.64215601644209, 96.9184329432826, 99.53473229562083, 97.39284361562422, 96.90197467803956, 95.73610505750104, 82.94840166645666, 71.89059688198951, 70.33486720054381, 71.34457157504174, 77.74134543634231, 78.60216448383947, 79.69593309587049, 80.1128496662263, 80.59433629435878, 92.79102479257892, 94.87772572425105, 93.3101583296253, 92.77796329990511, 93.35391629126765, 87.42765426635744, 85.18526661780574, 84.33344548748386, 82.71473823055145, 84.07638903587096, 88.92621148017146, 85.8260093196746, 86.24859763729958, 87.79701602074408, 96.31825539373584, 71.38638404107863, 80.07276304306524, 92.29596676365023, 74.83991330669772, 79.2275942525556, 83.36443178115353, 81.93461802697952, 78.37392960825275, 76.0776799724948, 80.4891461710776, 82.78654113892587, 82.22923509536251, 81.96572242244598, 76.00769704388034, 77.24891539542907, 74.25666470681468, 75.77677926709576, 72.27280047632033, 69.2002353360576, 71.69598456351989, 68.66370216492685, 67.63539791107178, 67.24071333485266, 70.93663723238053, 68.9339142460977, 73.18559092860069, 78.33832233182846, 77.89518863924089, 86.26447539175712, 86.42785779891476, 87.11368422354423, 90.48598120289465, 88.02070879167127, 93.1469249725342, 92.28331319747433, 87.80648462234005, 88.83265510682138, 89.90249726080125, 98.9855298688335, 63.00005066779352, 0.6935463232859489, 1.542892009019852, 2.193774037784146, 0.18279853787633682, 0.3234554983435139, 0.04109748766847676, 0.018288462700682784, 0.042786466393379435, 0.5586869017251077, 12.919224385292301, 23.67052535856924, 59.345903934970984, 86.50082172886019, 58.18192489685551, 52.02136793444234, 55.18100969253048, 29.348995570213567, 38.66710562859812, 65.10715184673187, 75.10195901316982, 79.70048304527037, 52.741487641488355, 2.365383126081959, 0.1295038387780228, 0.025486297334634492, 0.0421128069771634, 0.015479965218072458, 0.04650683067138157, 0.07365690243820991, 0.02808252142952575, 0.06797031604594762, 0.03617336943505272, 0.006354000276675629, 0.039516155788254355, 0.029888596693654696, 0.018225404088415446, 0.048330246335676605, 0.054789849917494485, 0.019910387664793, 0.03646365547132108, 0.01164808726659225, 0.018977987797810666, 0.048058970771249265, 0.01620311391419701, 0.049259821253438155, 0.019660202500921105, 0.05155281051092091, 0.07003048735280192, 0.0471651874813101, 0.033853000195156184, 0.04772697507794346, 0.02308186909724628, 0.049269071765123844, 0.04334331655334081, 0.05607172185855527, 0.03781981112795972, 0.035895727679974614, 0.07433388667601733, 0.026436610252506314, 0.09636825311087793, 0.022644865732159347, 0.02227717225680188, 0.021403389607345866, 0.025238134642882694, 0.04436729265557182, 0.06248683105373095, 0.031570473783499295, 0.008081335108727217, 0.15546147170807087, 65.43414415851717, 140.58146538272982, 110.63140776849563, 114.2281113901446, 88.22107130481352, 97.00359544446393, 92.1998530049478, 152.83592254884783, 58.134978048263065, 100.12444496154787, 90.71686760071786, 72.69844039793938, 42.976056760357274, 0.32893508011775635, 0.5786021234047029, 0.021323434925908526, 0.13255199537642542, 0.14833100110052094, 1.0354908940292176, 0.5574601804537158, 2.4781338630184053, 0.3343157752627327, 1.5824749753359826, 42.18398117250012, 136.66414722319573, 102.89129272583993, 113.40479020149478, 110.52298561219247, 108.88971067244007, 110.7615206318517, 106.79068565368654, 102.9360548142464, 102.57407496052404, 94.55006660953646, 96.30685698601508, 93.23622949661748, 98.82261030135616, 99.83718625960812, 103.24236839048325, 103.47093274516445, 101.29142069047498, 98.94814183635097, 102.31042108228131, 85.57897060148179, 71.40610571830504, 72.33536228056877, 75.44536252175608, 82.02496590152865, 82.64492004148423, 82.06445632442352, 83.7723425895937, 86.2610472402265, 96.59935597450503, 97.89351847863968, 95.33956912256058, 96.57300549168741, 96.29789044780117, 93.50813604170277, 88.54417262538787, 86.56733728224232, 86.48231598638719, 89.33167472962411, 92.3810665069088, 90.42058744738179, 90.27574216165851, 89.55855246513121, 100.09227368139453, 75.21745712526383, 83.8642123437697, 97.3328156625071, 77.88679476707213, 83.1598723319269, 87.57915973663331, 86.65031894560784, 82.87732047419395, 78.41598526124032, 84.64735277237432, 86.09447986848893, 86.87716530215356, 86.45673428812336, 78.62234115600586, 80.36064147949219, 79.48128531056066, 78.44450089239305, 77.0083878117223, 72.50299653699322, 74.47831000051191, 73.22696408917828, 70.3964719464702, 71.61127705727854, 74.41111979946014, 73.25941777998402, 76.87261889057775, 83.05452531383884, 84.62096306585497, 88.91045924155944, 88.61370055906235, 89.59426956792032, 95.05322041050081, 92.44450692207583, 96.5416814434913, 93.9142111809023, 92.33737914792954, 91.71701708147603, 93.39508548859628, 101.58905013915032, 75.97281148356777, 3.0297794361268324, 0.16269939380788034, 1.4818295307697789, 0.14202119452097725, 0.608599184741897, 0.028982054209336642, 0.21366821932456187, 0.08923307872347294, 0.11488918710740344, 16.40520832230968, 27.507793826441613, 64.27178898165303, 94.15380524050806, 70.25380749856272, 35.61580365703952, 16.0067621930953, 39.76945638656616, 58.833465883808756, 69.5508481610206, 85.10152401462679, 88.91288326632592, 77.09668036430114, 5.36359312072877, 0.11814946579116008, 0.021763489236153906, 0.06486534636708037, 0.04385901247000983, 0.028333662288083185, 0.04068827797328273, 0.01575927034155616, 0.015099249205612128, 0.03985625286135943, 0.04059741994546306, 0.05351588400381227, 0.023926607438273007, 0.048261627840298804, 0.02029062199947094, 0.03470453373607128, 0.023640952403506926, 0.005686986673202727, 0.0032735664788032734, 0.06217142116398581, 0.06422665886460774, 0.026446318501726757, 0.07461556954489601, 0.10068449206770429, 0.05319727952742288, 0.011491657858113609, 0.13550719486609583, 0.1238372932458597, 0.19346828872878707, 0.16666346980679422, 0.16060063465228006, 0.146205245006469, 0.10507824380070933, 0.15600917860865593, 0.1965500612653071, 0.19871885617894514, 0.14326636318958577, 0.39567506661818874, 0.15189245192994996, 0.12568135881015371, 0.15871100217824982, 0.1490977478604163, 0.21069627315286668, 0.22384433376212276, 0.12019339603401961, 0.19377326833144312, 0.1907345959015431, 82.69282002602854, 163.4022072822817, 125.5166692118491, 132.54314822535363, 99.81034155814879, 104.4166083489695, 62.6792400113998, 128.74784715713994, 100.8134328165362, 189.68373483227145, 123.92763076290008, 92.0110301048525, 53.59907073359336, 1.1508171572800607, 1.0706380274026626, 0.29347492321845026, 0.42568561110285025, 0.3173562433690794, 2.7714344859123234, 0.5240852842407843, 4.850401484197186, 5.752573590124808, 5.96329459259587, 40.15656294361238, 139.39477582131664, 104.12983602093112, 115.59338646550333, 114.0250659758045, 113.60010854659544, 114.69654437034362, 110.73830804517193, 104.55520137663811, 106.54811059274982, 101.52052633223995, 100.38942460090884, 99.26714820246544, 104.39197586428736, 107.35736616196172, 108.51251202244913, 107.71629441169001, 104.68081920377671, 105.06103807880034, 107.41657041734265, 92.28945562916418, 78.54373685775265, 76.95959352677869, 78.69655239966609, 84.6965628285562, 88.05779872402069, 86.79517207607147, 87.31018712443691, 89.97805779980075, 100.51665844455843, 101.43798397433375, 99.43121310203307, 100.06355408699282, 100.20686964834891, 96.52650187092443, 94.35030814140075, 91.78004172540481, 91.92870739967593, 93.63394998734998, 99.9700761610462, 95.95745225106516, 96.95126318162488, 94.35718013394265, 103.97633798660772, 81.83721773086056, 89.35096494613155, 101.56954026991322, 81.60880242624592, 85.91952646932295, 93.21013789023124, 91.77227543246363, 89.56288276180145, 84.1008097125638, 90.53589728570755, 91.56712762771114, 90.91898733569731, 90.57279109954835, 82.44140394272344, 86.3583141757596, 82.1874696977677, 82.7428145562449, 81.30049628596153, 76.94583385221421, 81.16635907080867, 76.63449179741644, 74.47426995923443, 77.27929023004349, 80.48513750876151, 78.04570567223334, 81.488981862222, 88.00773359114125, 89.41881410537228, 95.93929952190769, 94.41777290836458, 95.38732005703835, 100.03338321562737, 97.27751024307744, 100.97234372169741, 96.15117811387586, 94.88084008616786, 97.85067835161763, 98.98090931677051, 105.74195369597405, 75.27226832605179, 2.4352795174044948, 4.572810934435937, 8.405229391590241, 0.23019685740432433, 1.0414000672678794, 0.3006610730963369, 0.42914290461809407, 0.14468460644204773, 1.8975784605549229, 28.07191106580919, 41.34013422073857, 77.29978069182366, 102.24793772543632, 81.40415668487549, 73.59014418817335, 75.27571216706308, 43.15636419480847, 57.31801109929239, 82.9438909407585, 98.17698817099296, 101.23849222736975, 90.36456815658077, 5.826682361864275, 0.254400838466902, 0.164898939490799, 0.11495657220122316, 0.10451036580507794, 0.10409805728423019, 0.12138422608615891, 0.12801044996106817, 0.23630565783429533, 0.17021169795865015, 0.1030883304173908, 0.13757583144451344, 0.12297623340160617, 0.12020011462511555, 0.18631949329808836, 0.11454732037119328, 0.12214459133364501, 0.08747776444520682, 0.12621444875314353, 0.16406577290786853, 0.15439080254685494, 0.2000347500847232, 0.14200961127156211, 0.16395908750353322, 0.1902181300665102, 0.15237386158156782], [0.038730482826189655, 0.08238197739927039, 0.09795642998670379, 0.10312910161672101, 0.0678189906982645, 0.051786888676184806, 0.07108289297790298, 0.056076502247202786, 0.04532213698351576, 0.006587250588176352, 0.038411598727707906, 0.03467115911565, 0.0073102192536387, 0.013247674064440353, 0.041664281649695295, 0.04077042558140332, 0.041548376377191276, 0.08437225084391334, 0.12388755627457174, 0.1710154774088052, 3.288358993107273, 80.32609324301444, 109.39664563825055, 97.0426622513802, 75.71366048628285, 57.71096591026553, 23.907830715179447, 8.480884067473873, 31.77811157318854, 130.44602163376348, 72.10963772189233, 60.62713830701767, 33.8069438165234, 0.1423125530803396, 0.16567026745648156, 0.10386400976248326, 0.16133217201117547, 0.0689818125758921, 0.2964403269992721, 0.08686742219593256, 0.5373316186089669, 0.7679476793254576, 2.7617977126952145, 24.63294359945482, 132.24609928746378, 97.32020916477327, 109.45174709443124, 104.86559421785417, 112.64792180830433, 106.91847647390058, 106.11884640109156, 107.03664179771178, 103.43232877792852, 93.03520802528628, 90.0179796834146, 88.15111191042008, 87.85626734456709, 87.6273342870897, 85.8257818222046, 90.12178128765476, 96.03942978766658, 97.82362968690934, 94.4542980194092, 97.90659566079417, 83.34223901071857, 69.79663172075826, 71.5268676511703, 72.4157787138416, 76.8747526599515, 80.21283872665899, 74.91344205794796, 76.38011040226107, 84.42892382221838, 94.45848711075323, 95.5491570503481, 95.264189012589, 93.1133573285995, 88.43821371755293, 82.242767272457, 80.97965425060642, 79.1218157737486, 80.32579514288133, 82.36429798987605, 85.19397427958828, 82.03980815026068, 87.17270020515689, 85.6364647034676, 95.76149063725626, 71.35732712284212, 74.72247754373859, 97.84382204855643, 76.9818647446171, 79.4495141121649, 84.57779345973846, 81.68271556977304, 78.14420423200055, 74.41209254726287, 75.75041309479745, 79.21787461926861, 77.57835526620188, 77.77099071010467, 73.78218343180995, 70.81582038633286, 73.76138702515634, 75.10764644991967, 72.09745484013712, 69.35633782417544, 67.6519032447569, 67.70058770333567, 66.18670971162858, 67.21273114604335, 67.22346275083481, 68.386092493611, 68.5918600328507, 75.35404974414458, 79.20995927626088, 79.63435972890547, 85.01511419973066, 84.28990717857116, 87.54742776193928, 90.3118436567245, 90.21527490308209, 92.75715904851114, 90.95004466272171, 82.64466900979319, 90.08979043652936, 86.81345032107446, 99.9702879690355, 42.83071333362211, 0.5038919113576412, 10.492502989307528, 0.9018239955748282, 0.12096647068016952, 0.1394683597308974, 0.09382977480849913, 0.06807156988689977, 0.1595932749971267, 0.18555994776468124, 6.473699875416295, 34.93350344319498, 49.318486182920395, 47.68650562532487, 79.21985149383545, 107.95611596876576, 31.966810918623406, 21.742413697704194, 46.92041573985931, 58.81089656583725, 74.01734521312099, 83.09201532794584, 34.28997585850377, 0.8481724067561088, 0.3019739332939348, 0.06469702152835746, 0.11514907477483635, 0.06745902896528283, 0.036309346211172884, 0.030228224537906148, 0.060471728699462074, 0.03445971118766935, 0.05131072289640865, 0.04959241832576452, 0.04003982284977552, 0.022869679979198886, 0.02048608741813129, 0.050232599699689504, 0.06578025453153157, 0.047074930832511, 0.06177925309466739, 0.045611986349667274, 0.003920196158428407, 0.03412812918184265, 0.0071915847929044366, 0.025085171782261422, 0.06263457877080768, 0.05176881283161141, 0.04187633861757575, 0.03355519117547139, 0.04072018936576863, 0.017421400557542523, 0.06320491207823639, 0.04988066656815429, 0.03251822605248421, 0.04535338954038678, 0.017802377997507012, 0.03157135669983203, 0.04529752640894825, 0.08097680360679665, 0.05163996067318705, 0.023225280756671584, 0.043112854323079514, 0.059634180093604716, 0.030656542381151553, 0.061953951784920316, 0.07026039799975772, 0.11596245330668266, 5.5777211919907606, 107.24514715133175, 122.84992817909487, 113.14358388223957, 85.09414211396249, 81.0538419600456, 40.905692500452844, 15.532838875247588, 25.966329805312622, 82.18266087193643, 81.54560519802956, 65.22361093951811, 45.48232578462171, 0.11016659979378024, 0.16596004787471988, 0.08203911474875866, 0.401646783274989, 0.03575374860496771, 0.3713053500940723, 0.10330255158365735, 1.0421350213789171, 1.5687648206949236, 1.826868790291971, 33.69572501028738, 140.5588254620952, 100.18509264915221, 114.7946899167953, 107.90227751578055, 117.03106064950268, 111.6058421904041, 111.04914803658764, 111.56092320719074, 106.7226246864565, 96.74702536675238, 94.95778914420836, 94.02330014013475, 90.57356772884246, 90.2116035646008, 89.24722609981414, 93.86275752898186, 101.08347231341948, 101.34366666117023, 98.65944754692816, 101.87074692018571, 87.1277419982418, 71.73181149267381, 75.52322156967656, 73.90993502832228, 80.61584657238376, 81.42427844385948, 76.96484165806925, 81.13557630969633, 87.91241215121362, 97.44756852426838, 100.28590540732108, 98.83050995488321, 98.68523320844098, 91.82954203697943, 84.43542711196407, 84.21527231893232, 84.28368629947786, 84.2502441713887, 85.21608075787945, 87.67086475126206, 85.19369186893587, 92.4634833489695, 89.52811487259405, 101.15477315841183, 75.31514767677554, 76.70721254041119, 102.1301724833827, 80.96868730360463, 83.39716788261168, 87.5820073773784, 88.01490368381624, 81.85264833511846, 77.4966444507722, 76.57719381393926, 82.29683322291221, 80.0860991016511, 80.36692511650824, 78.5278904822565, 77.11647264419064, 77.23353970435359, 77.789731794788, 74.21506404876709, 72.55507776814123, 71.34016283096807, 71.15972595830118, 69.92613269436744, 72.157545551177, 71.00450992584229, 73.65957014022335, 72.82411313826039, 78.33207791851413, 81.713011956984, 84.70251698647776, 86.86768885581725, 88.51426063045379, 90.74099802201795, 91.88519262498426, 93.88239291406448, 95.9930673722298, 93.79191952366983, 86.47033706788095, 92.0574474334717, 91.76695669850996, 103.37187720883279, 56.3745084885628, 1.09069568014914, 0.9892877023066244, 0.726063630032924, 0.6098756097978162, 0.5128401860354409, 0.12517947162831985, 0.09287283139964266, 0.2999813692463983, 0.3038569161247823, 6.398000582571953, 40.81436403336064, 50.79792968688473, 51.397424744021514, 83.47940429564446, 81.85711199237456, 42.74702564362557, 36.38597672985446, 58.30439698311591, 66.90804927579819, 82.03084161204677, 95.96896048515075, 55.708015426512695, 0.7787431452062823, 0.1486130133872071, 0.11398445259058669, 0.144622017058634, 0.0896412733521673, 0.05910754444137697, 0.038603679952962745, 0.019897073056669008, 0.019674997573958772, 0.0704620246805491, 0.0548981479369104, 0.05676591626158165, 0.0473990511419552, 0.038501066305945, 0.02590759398205386, 0.035602112991675254, 0.05323093760037615, 0.02328197317828815, 0.08548532297173816, 0.05445613818723829, 0.027720845574813507, 0.02894372683048489, 0.052543894628122936, 0.08242365258235125, 0.008274908290214596, 0.28553193975840846, 0.5035784588225427, 0.15719086923185857, 0.17943610136787738, 0.1351475931944386, 0.16567920004167866, 0.1347216636302971, 0.15398954101387533, 0.21425617648468864, 0.15929647721350193, 0.17149989012508624, 0.21036083389434124, 0.2038604859262705, 0.1418077624252727, 0.19473283942187988, 0.19651613889201996, 0.12556186441572445, 0.23354633170510494, 0.26899590126929745, 0.2724945328889355, 10.817085004621937, 136.94367101115566, 140.3321752240581, 131.97766796235118, 103.9404090758293, 87.32709253987959, 36.32656066648422, 19.926917206856515, 44.43340947551113, 174.34731452695786, 92.23703707418134, 77.76757040331441, 60.180188148252434, 0.8316803723573686, 0.4440797498870281, 0.5075020547355376, 0.5069710638734602, 0.2235062285176208, 0.8107425765164438, 0.4025531572199637, 2.499241117508181, 5.872137238902431, 8.904595163560684, 32.69531469191275, 146.22641501888154, 104.32562505045246, 119.92096885558098, 113.98505780004687, 121.07582446067565, 114.80999500520768, 118.28162993154218, 115.21175553721767, 112.89441923941337, 101.86178822671215, 99.87811226998606, 99.54569924262263, 97.05104827880861, 97.8770523686563, 93.30909144493842, 99.72581448093538, 107.65511328174223, 108.6287240059145, 103.28683237875663, 107.28411982136389, 91.98395790592318, 76.3810125474007, 79.49780633372646, 79.85330643192415, 84.10488897754301, 86.77990621136081, 81.64555503476052, 84.08354343906527, 93.63490704567202, 103.01544358653408, 103.32615806210427, 103.24122305839293, 104.29066888747677, 96.56563143576346, 89.75786378306728, 88.5730020461544, 87.87086640634845, 88.45267941874843, 91.57239929322274, 94.68415675624725, 88.594480945218, 98.21620402797576, 94.0407782216226, 103.87240302178168, 81.76772117614746, 83.28603144614928, 106.99151100650911, 84.84563642932524, 87.71596416350334, 92.78654544584214, 92.12282549950385, 86.17849703757994, 82.78055560204291, 82.10243271243188, 86.79293632507326, 84.22911044090026, 86.96461846751552, 82.94079226832237, 78.69787816078433, 82.57571374216388, 83.8663382684031, 77.91117622006324, 76.06363004253757, 75.4673905526438, 74.68792146252048, 74.61650294642295, 75.98722227158086, 75.0346040725708, 77.78642915910291, 76.41740429785945, 84.11977829471712, 87.66957036910519, 88.23368564728769, 92.47678018385365, 93.14225735202913, 94.66079511950093, 95.82013007133239, 99.67130138028054, 100.21870736152896, 97.24274235387003, 89.80006064138105, 96.7823737667453, 95.09950437853414, 106.61293168221752, 51.786166929429584, 1.8433664018108, 26.365487844713275, 4.3275603267454334, 0.5588033470895983, 0.7751994676166966, 0.4123511766233752, 0.23697045361322744, 0.42222445650446805, 0.5675774440169334, 13.097804015682591, 55.435300873171904, 67.62978107698503, 62.28321790695191, 106.52814572857272, 154.44873840578143, 44.85304032602618, 33.77147774542532, 64.11435288767662, 80.69955779660134, 95.83374069583033, 108.91206818242227, 64.1277164028537, 0.7817679667665113, 0.34883329464543256, 0.21554917968328924, 0.18686464146500636, 0.2196849666295513, 0.11767104388244691, 0.18819958031658204, 0.12920278154553907, 0.17957690832836015, 0.16787824010656727, 0.17552117757018537, 0.1602580707760588, 0.1153005839836213, 0.14727853418838593, 0.1325933181590611, 0.1360091356740844, 0.10652330779140035, 0.1728243335720993, 0.10694142325871414, 0.14509024999795422, 0.11741769094500812, 0.20854430153004586, 0.16277286163981886, 0.1939524716186908, 0.1087546231405389], [0.04860215392264147, 0.0536365351910072, 0.07142210904989513, 0.04065005018586113, 0.06698687365579029, 0.010296621983270011, 0.057028197953777934, 0.02215226162074795, 0.06884147292904316, 0.04147516518470742, 0.05423534398658141, 0.013111538325075903, 0.07592578673915518, 0.05883394380009944, 0.018413474843386683, 0.10778295552177776, 0.02656184073026863, 0.09013010639577143, 0.0671223409834408, 0.39652251308002784, 25.546400854664466, 101.24023375972625, 89.65422691837435, 82.79074591975059, 71.74586142263105, 36.93262961602981, 46.0812952441554, 118.15153275766681, 126.5636988609068, 102.17273804449268, 109.25865665558847, 50.966430787117254, 1.223533610182424, 0.10182396358539982, 0.06994078611774791, 0.18750061701622703, 0.03591696363723567, 0.09316667974475892, 0.19927885112983568, 0.6344564295103473, 1.452563746321586, 2.6965250603614317, 7.170481970233302, 122.6625330217423, 98.76961908032818, 113.68844032287599, 104.9666815419351, 107.5391052615258, 103.334528400052, 105.75919643525155, 103.548383866587, 102.51541199222689, 102.10785419710221, 104.00462612029045, 93.1253597813268, 85.07215330677649, 81.24384941593294, 84.13384391415505, 78.538190626329, 85.84240482699487, 89.5986233988116, 93.9537408274989, 93.10396717440699, 91.97351655652447, 72.57412479769799, 69.68519718416276, 68.9553931451613, 71.80850951902329, 76.71308040618896, 78.80613557754025, 72.47792474685177, 74.34194487910118, 79.77663978453606, 87.90995674748575, 85.65958315326323, 84.85699561334427, 75.31219805440595, 74.5784402662708, 68.43283145658432, 65.83087228959607, 66.81179431176955, 74.09190162535637, 73.37658682177144, 78.69908625079741, 80.97289208442935, 87.90732091472995, 84.19089871068155, 98.63865114027455, 69.48030041110131, 63.67429825567431, 94.72474544279038, 74.07083849753104, 75.57056457765641, 78.36158983169064, 83.03497622090002, 77.2425062425675, 73.95377143736809, 67.31298692764776, 75.11154528587096, 75.21953598145517, 76.11573480790662, 70.8776604744696, 69.08820459919592, 67.97375725161645, 71.92482348411315, 67.61397392519059, 66.11170614919355, 66.52973667267831, 65.18928235576999, 63.28392828664472, 67.94755581886538, 66.44726491743519, 67.51225902188209, 64.97006893157959, 73.39646539380475, 75.69877901384908, 79.62994314009144, 77.00089608469318, 80.0127507794288, 84.3310606864191, 85.27353563616353, 89.56620893170758, 92.13016033172609, 87.21421457106068, 86.8039660299978, 80.27137617911063, 92.5529839915614, 85.20367037865424, 102.4901754625382, 29.962854346921368, 1.5726998159962318, 1.0512924074165284, 0.2956012155740492, 0.1713582098243698, 0.18902153137230104, 0.09862998215061042, 0.08840539733008032, 0.04107913603225062, 0.3917180692716953, 1.8919835672263179, 24.85887996612057, 58.648859531648704, 83.38298459206858, 49.40897134042556, 43.64744886275261, 29.037626058824603, 21.67424290410934, 59.55528005476921, 68.76140840591924, 79.13557544831308, 77.06968661277526, 13.361055850982668, 0.8627627044916154, 0.16481955746008506, 0.05188227428363697, 0.10819642849627042, 0.08386461800264736, 0.029937835079768015, 0.07161842674137124, 0.0412211112768179, 0.004790354972600096, 0.026613130316799207, 0.03757729450420987, 0.06621988174775917, 0.09373874824133613, 0.020075858825997963, 0.027961728516064828, 0.06347451757098879, 0.039706589924472, 0.027155162421085184, 0.0423510181867788, 0.005223139108444054, 0.03804205323479349, 0.0510481960560766, 0.020307075652864673, 0.04248479629055627, 0.01982049490775793, 0.07336360567639913, 0.09007683264151697, 0.06378232020764582, 0.05946036623490434, 0.022699121994176702, 0.018027125211853175, 0.03560376391115208, 0.08252012603465589, 0.019177457941095197, 0.04676915066797407, 0.01119119147094147, 0.05437710855696952, 0.04268708563740215, 0.02379096774083953, 0.06928518339390717, 0.006588775581950623, 0.02626898638423412, 0.14736330947808682, 0.2954068131023838, 41.62716542520831, 128.57257212361984, 101.36779708247032, 99.59205381331905, 84.66360707436839, 51.329873684913885, 44.975743832126746, 67.6389515784479, 118.00676591934698, 111.77081707985171, 99.46532987779187, 61.706382382300596, 1.165483267076554, 0.1773639407850081, 0.06074652060746186, 0.1195346293670516, 0.1955969253134343, 0.17523608561004364, 0.24558842182159427, 1.0073621066347247, 1.9556224298092628, 2.0898925152517136, 11.148418399595446, 132.41880909089122, 98.83859788217853, 120.16406166938044, 108.00452586143248, 110.81724182251962, 106.04305051988172, 110.68479122654085, 105.4251281676754, 106.96408579426428, 105.19719139222177, 107.69514499172088, 99.1296926621468, 89.88491719768894, 86.39936570198306, 86.92029568456834, 82.93131582198605, 91.84234465322187, 93.47859274956488, 100.07144589577952, 96.77522720829134, 94.21191907698109, 76.3455072526009, 71.50021122347924, 70.8937971053585, 74.9877788174537, 80.84729779151179, 81.63431352184665, 76.6091375966226, 78.72594664173742, 82.44806412727603, 89.38107305957426, 89.16533485535653, 86.3024047113234, 76.33337928402808, 75.75322151184082, 69.0988185328822, 68.49124339319044, 69.36132707903462, 76.67113457956623, 76.42455870105375, 84.50955990822085, 85.75905446083316, 89.72603767148911, 88.11591256049373, 101.00039651316982, 73.52208322094333, 68.00687774535149, 98.34859186603178, 78.95780578736337, 81.36990654853084, 81.73542438014861, 85.94323327464443, 82.18339827752884, 77.38437052695983, 69.93243202086418, 77.76259683793592, 77.89878153031873, 78.7914502236151, 73.44375348860218, 74.20929031987345, 70.40077086417907, 72.97503809775077, 72.22948182013728, 70.2406048005627, 69.69755265020555, 68.92181765648627, 66.37176713635846, 70.13889774199455, 71.69574922130954, 71.78774449133104, 68.5053482363301, 76.19122474424302, 79.29192112338158, 81.70376300811768, 81.99879584773895, 84.92432701972224, 86.41368235311201, 89.75217634631743, 93.1466111829204, 95.18283905521517, 89.31961736371441, 90.72937211682721, 80.3067716475456, 95.31236356304538, 88.29026191465317, 106.754913637715, 39.99007009690808, 1.7110235484377032, 0.4623723360559633, 0.7597828980895781, 0.2886422567309872, 0.29468512763419463, 0.08468346640227303, 0.0877393834713486, 0.06421212617668413, 0.5879673337744129, 0.8730975370253287, 27.457330572989683, 59.843056509571696, 89.04053288121378, 59.59755536048644, 40.27244544798329, 41.21485763980497, 37.820348278168716, 62.866207630403586, 79.99295065479895, 86.18702427033456, 98.15303817872079, 24.235444722637055, 0.972003655568246, 0.40047984750520804, 0.23145846631978792, 0.048101473329288345, 0.09456276007357145, 0.08744673022339422, 0.0784740020190516, 0.03841185153672292, 0.047670556532759825, 0.056861252073318734, 0.04074888318897255, 0.07588188224021467, 0.06231195233281582, 0.042450149964180686, 0.012452425960932049, 0.04553655733264262, 0.08343955411786035, 0.07077857987174103, 0.014979195566998135, 0.10344060062761269, 0.006093122919405541, 0.026361797936260704, 0.01946380245499313, 0.1057255804358471, 0.20472389766045157, 0.23543722056333097, 0.2626207933550881, 0.18815340053650642, 0.21161344893757375, 0.1252648291448432, 0.11613896762531613, 0.19229634274398127, 0.18057899729859445, 0.10584637717974764, 0.18138245499182135, 0.10210846565783986, 0.2683579032459567, 0.1289128172661989, 0.19458746657736842, 0.21716796943256933, 0.16510592112618108, 0.19126267562950813, 0.2989096122403299, 0.4870006532197999, 61.23513706268803, 152.06046996578095, 119.72123392166631, 114.52602324947235, 103.10328114417293, 58.999946963402536, 74.15120786236179, 160.77351324019895, 158.37504663775044, 119.48178106738676, 136.8074078713694, 83.21516206187587, 2.487781667901624, 0.47450885416999944, 0.4332676139329711, 0.3620091182810645, 0.7629279648104023, 0.4628485056661791, 0.5543322128153617, 2.6103442138241184, 4.50591245966573, 6.100814852022356, 10.814995361912636, 143.2061586072368, 101.94279301551082, 126.68349589070968, 112.1931072973436, 116.01005200416812, 110.61266668381231, 115.27616870018744, 109.51268503742834, 112.83738013236754, 110.23543665485998, 110.87651668056365, 104.00094693706882, 92.94781761784708, 90.82075549710183, 91.60792812224358, 88.03810842575567, 94.98344928987565, 98.22172672517839, 102.09829145862211, 101.85068791912448, 101.62115081664055, 81.55791359563028, 76.49259613406274, 73.49381077674128, 78.8167259770055, 84.49789477932839, 87.33393315346011, 80.60618969701952, 81.05975689426546, 87.86830902099611, 95.1191476083571, 95.05544047201835, 92.07039125504033, 82.38721247642272, 82.59134046493038, 75.58115497712167, 72.62393889888641, 75.24473328744212, 81.03925074300459, 81.55162995861423, 88.80854037500198, 92.31147581531157, 95.29587391884097, 91.57083034515382, 107.15845492578323, 77.68839343901604, 73.5144659780687, 99.33495029326409, 83.21210261314147, 83.49528205010199, 87.64893870199882, 87.82340572726342, 86.19220964370236, 82.085386091663, 74.63714245826968, 82.57097551899572, 83.0754158573766, 84.16237523478847, 78.67155121218774, 78.39790313474595, 74.46382860983573, 78.43016855178341, 77.32311879434894, 73.03428157683342, 73.66838762837072, 71.9477536601405, 70.11857201976161, 76.06897231071227, 75.74058363514563, 77.12253662847704, 72.62761023736769, 80.75978186822708, 83.30096783176546, 88.35981338254868, 87.10580025949787, 89.14841375043316, 91.66024469560193, 92.8083538240002, 97.81115654976138, 97.64268290612006, 94.28648333395682, 96.19132749495968, 87.87952699968892, 100.87099752118512, 94.75545760123961, 113.48433586858935, 37.9105314131706, 2.9511229213207, 5.603499989355765, 1.0748898766694532, 0.9603282917411098, 0.8520907932712186, 0.40306830538376687, 0.24254185868607414, 0.2712700792377995, 0.6150329749911063, 2.7688908288555765, 40.39042642039638, 77.37784370299309, 98.04813046609202, 64.04271864121961, 60.06145015839608, 41.99640166374945, 34.205001631090724, 77.7604160001201, 97.1748382814469, 100.11210518498575, 111.92881799513295, 26.164668375445952, 1.5108968678020662, 0.4865371393820932, 0.3237678783555185, 0.16526108457436486, 0.18598452901407597, 0.19384454515191818, 0.15462798336821218, 0.17516013565323046, 0.1286384505369971, 0.16564373017078446, 0.16081282568554725, 0.24071578086624223, 0.2062825954729511, 0.12850587902170035, 0.09788652446361319, 0.11366441169933927, 0.28646794598429437, 0.1569899243693198, 0.2539017475059917, 0.24118827325442146, 0.14814459658678503, 0.1021720969208306, 0.10701995493183214, 0.18700270583072018], [0.04053316432081404, 0.14478525507353968, 0.016581172559169993, 0.013861354541844659, 0.04810562935627757, 0.026182274807304628, 0.08117939555837263, 0.018749232028400706, 0.022012994496993, 0.018520903353008534, 0.014555028962692427, 0.043697934823050615, 0.041463800270350716, 0.035358267205376784, 0.06280625907463894, 0.018575969753005815, 0.08024579484856899, 0.035126625199712096, 0.07862802399622817, 2.239460579810604, 77.40432754639657, 96.79750627087009, 88.09265290537189, 67.99776215707102, 52.33588710907967, 31.213400094739853, 81.31389510247016, 76.42816728161228, 43.0709820408975, 101.7827210887786, 68.27508941773446, 5.682738240688078, 0.3062737090212684, 0.13652066790288495, 0.02622661406114217, 0.05012958002607188, 0.22308051345809815, 0.05521623147351127, 0.1706580667486114, 0.17995275106401215, 1.6483563304908815, 0.24874266627575123, 84.16279885076708, 106.56182319887223, 101.68186126216766, 102.10837194996496, 96.79155211294852, 104.7842207262593, 103.80937053311257, 106.40825456188571, 99.15358774123654, 108.80828226766279, 111.37980384211387, 102.85002154688682, 98.16665664795907, 88.60735416412355, 81.16437435150146, 76.74376118567683, 74.99180316925049, 79.91457385401573, 85.78682484165316, 91.51661534463206, 90.40416840584048, 78.28884555447486, 66.64921206812706, 69.15577919252458, 70.17973746022871, 74.59499266839798, 73.35615911791402, 76.25417094076835, 70.11666574785787, 71.2663124453637, 69.57554340362549, 72.80922382108628, 66.48670042714765, 68.01756228170088, 64.67104704149308, 67.11304803048411, 62.23267816728162, 67.01290991998488, 69.04417991638184, 73.54462115995346, 75.60996870840751, 81.51064119031354, 81.37326409739833, 85.76058418520036, 81.30131998369771, 91.48060798645021, 69.23909817972492, 60.180317586468114, 95.93383958262783, 78.3388557741719, 76.59833538916804, 79.20851584403746, 83.65998237363755, 78.04114003335276, 78.99832387124339, 69.0576885592553, 64.53352482088151, 68.395584629428, 69.6003092488935, 66.34910368150281, 69.12145845351681, 69.06804361651021, 69.93382838464552, 70.87773892187303, 67.2109111662834, 66.58295539117628, 67.29938414789015, 64.50546026229858, 66.17986125330772, 65.10950919120543, 66.88559762893185, 67.31711326106903, 65.84713443633049, 71.81374196083316, 74.38130978615054, 80.00152495599563, 78.46113174192368, 80.93675921040197, 83.81020915123725, 85.79724265683083, 88.53530806879844, 93.52630446034094, 82.73067089819139, 79.77317240930374, 80.20481355728643, 91.92582053522911, 86.94816804701283, 84.00360553495346, 15.14740030611715, 0.8236113214685071, 0.7848410825094869, 0.2442140447636766, 0.08349648977239287, 0.1468717568223515, 0.12697251573685678, 0.039365385854316336, 0.12797674975327908, 0.23139865017466008, 0.0685655050760796, 23.94085511084526, 45.535403297793486, 46.65491442526541, 77.25612471180578, 39.31167264138499, 29.752193650891705, 42.003650203827895, 61.24366037307247, 70.2582319321171, 81.64568839534637, 49.97587150143039, 2.68938438546273, 0.13571546352919073, 0.0342389399696502, 0.025470845341201753, 0.038107737613421296, 0.030806592192440748, 0.10491562631702232, 0.06195559887395752, 0.04955908584017908, 0.05638939936855628, 0.01702414566440688, 0.03812061938186807, 0.019805780273952314, 0.06306580583294553, 0.016763041832394177, 0.04778436272435131, 0.020303884896660046, 0.03230884273145949, 0.025405559328294573, 0.0373080873771781, 0.050913755286244616, 0.04667200305829606, 0.015316867971822861, 0.06803144986230521, 0.016296754756401625, 0.015020248303640515, 0.06730348247313692, 0.006247334024538437, 0.04293773811490786, 0.09552079132728039, 0.04758454018062161, 0.011132892179903726, 0.025107238944920323, 0.020394725687501412, 0.031836275649707646, 0.03898714526346134, 0.022487419341961225, 0.00814385075617822, 0.06269757418082127, 0.026858238232952934, 0.0541781785056716, 0.08830824972040231, 0.1562615739361894, 3.7039297001977123, 104.63930483787291, 112.54656776305168, 103.77480660715412, 82.9850209143854, 73.16969748466246, 40.191923110715805, 72.77356947621992, 89.53107233970397, 50.09200111512215, 102.21374250227406, 78.27557225381175, 6.743364295651836, 0.1981354036158131, 0.11228071135138312, 0.10122930315593559, 0.04289144342164359, 0.22558473230850315, 0.024146319539736838, 0.2835451673355795, 0.1521378145703385, 2.268782748330024, 1.3312084323936895, 91.73118468253844, 111.85287306385656, 105.43650304117511, 105.84624951885593, 102.79472397219752, 107.56292973795246, 107.47821438697078, 109.27791549313454, 102.68255987474996, 110.89372804087978, 113.6903779737411, 105.5150132025442, 99.02824448001002, 93.28915795972271, 84.961424796812, 79.90390500714703, 79.21887090129238, 82.86858143345003, 90.72861117701378, 96.32908113541143, 92.19771923557406, 81.87217389383625, 71.11765461583292, 72.78670941629719, 73.76782755697928, 77.8883715598814, 76.60281473590483, 81.34423071338286, 75.09710311889648, 74.83366104864305, 72.12273843826787, 76.09045905451622, 69.59583774689706, 70.02726708689045, 68.97755453663488, 69.11530033234628, 65.72254427017705, 70.39928820825392, 73.30805517012074, 78.36072691025274, 79.11956433326968, 85.60202629335465, 84.00007540179838, 92.77019700696393, 86.73317509312784, 94.98304136337774, 71.56463223118936, 63.12863380678239, 100.46132949090774, 82.51109661594515, 80.02899723668253, 82.00630326424876, 85.88624908078103, 81.58539372105753, 83.96144790034141, 71.29528307145642, 70.21003384743968, 71.56058434517153, 72.11620376956078, 69.38236667263892, 72.26947430641421, 73.15060338666363, 73.61811853224232, 73.84374110929429, 70.20615854570943, 71.59916477818643, 69.44957256317139, 67.67677891638972, 69.51968100763136, 68.9243201286562, 68.98099053290584, 71.60788028470932, 68.69882306744977, 73.7051716158467, 76.30906058895972, 83.6338201645882, 83.21712324696203, 84.13926462973319, 85.79654447494015, 90.10494647487518, 89.90115581020233, 94.21819486925679, 86.0161187571864, 81.64469995806294, 84.27709671758836, 94.85246566034134, 90.78552476821407, 92.72376398886405, 22.71312971268931, 0.48321574986461674, 0.3999980701313865, 0.3073592556099738, 0.048051160504861225, 0.2836090590684645, 0.05233749138912367, 0.2977786213159561, 0.05142316545149492, 0.2736977199392934, 0.06680743288128607, 24.10817950002609, 44.203342853053925, 43.87123577056393, 44.066581572255785, 35.12532303410192, 40.45962879734655, 59.003175074054354, 67.85620381755214, 80.96685947910433, 89.85132601953323, 77.34357787716773, 4.954485989386036, 0.17991207179523286, 0.09371358991390275, 0.04923132661309454, 0.0379662603260048, 0.05441652761111337, 0.07235995388679928, 0.03937551736711495, 0.05439936341116986, 0.07924901486764993, 0.03425970861327744, 0.038703336500592773, 0.026746584748428677, 0.06839482068654991, 0.06856184317580155, 0.0643795470316564, 0.037176722450362104, 0.07944324113909276, 0.004853841636495124, 0.04953963869822122, 0.005390723714710124, 0.05462681874632836, 0.015156365848416764, 0.08354858375124394, 0.11768497136091033, 0.25371589457556126, 0.1977769510760423, 0.09290778033074834, 0.1534834939746126, 0.20262451031275336, 0.14628355451408895, 0.18319405374988434, 0.09670291095972063, 0.13264289936952053, 0.09193687879991147, 0.21606711640713677, 0.09395679984722408, 0.13272787384208173, 0.14341020385824865, 0.13093847631206437, 0.22808501346697732, 0.21874315345719939, 0.25329240117101903, 6.759677433198498, 131.94682244331608, 132.79259527883224, 121.62985924751528, 103.30861722269367, 76.25388853011593, 47.22948281995712, 109.75860195775186, 101.35822649924987, 60.150327144130586, 122.293179112096, 96.01254586250552, 7.985413699380814, 0.46887823050060584, 0.3694065552084677, 0.41376614101952125, 0.3297773478252273, 0.7377342747584467, 0.4188564581976783, 0.5576171978346763, 1.177516363320812, 3.7627983477807816, 1.569229744134411, 95.24353381126159, 115.7346780838505, 111.15256524855091, 112.1189509668658, 107.95722207715436, 115.06306632872551, 111.21893959660684, 113.21108002816479, 105.71964325443392, 113.38791616501348, 114.85026990213703, 110.35403343939014, 105.1691464454897, 98.71827525477256, 89.62247925419962, 84.83477146394792, 83.56705357951503, 88.66096511963876, 95.52799978563863, 100.35388008240731, 99.106229043776, 86.21111546793293, 74.06318203095468, 76.55393415881743, 77.99501296012633, 82.3307695696431, 80.07691291070755, 84.83649730682373, 77.66882081185618, 75.765380859375, 75.83279855789678, 80.53197060861896, 74.79628086090088, 75.58854472252631, 71.454680350519, 73.39309215545654, 70.08447877822384, 75.11239251782818, 77.85223084111368, 80.38248123661165, 86.07628791562973, 89.7150001218242, 87.16970351434524, 95.83698057359265, 91.30275987809705, 100.97987467242827, 75.77315499705654, 69.3877560092557, 104.3429462371334, 87.33717303122245, 83.99377607530164, 88.69915331563642, 90.48365915975263, 84.3492369497976, 86.67863845825197, 75.79836799252418, 73.91855639796104, 75.8779215043591, 76.68970307996197, 74.86144711894374, 76.09064732828449, 77.22887992858887, 78.49223613739014, 78.14014850124236, 74.54182101834205, 76.84905329058248, 74.77142087874874, 72.5561289633474, 72.92745190282022, 72.99907438216671, 72.6708112224456, 77.60235232691612, 74.96480941772461, 79.18629953938147, 80.96867945886429, 89.7846378818635, 89.29030156904652, 88.782409544914, 89.36824690911078, 95.21182537078859, 95.72768765111124, 99.03794057907598, 90.18546488977249, 86.81323066834481, 88.59801107837309, 99.00455336416923, 94.5549774169922, 97.17408518637382, 22.519743134898526, 2.3367954213773054, 3.660039603710175, 0.8073648029277403, 0.1740531079591282, 0.497853146685708, 0.28453176600798485, 0.8232534664773172, 0.3007049546126397, 0.4579760638936874, 0.24114483606911477, 37.97413264551471, 66.9657002725909, 66.77964656583725, 99.97036641643894, 54.10524083722023, 44.5528378025178, 62.229367686856186, 82.45386139039071, 93.01783977016326, 106.7059781474452, 91.15916975082891, 5.549509054230106, 0.2805998963454078, 0.27120039588020695, 0.19209155212006263, 0.16592696819814945, 0.15176589420485884, 0.19982016885713225, 0.15789508789537415, 0.17933799614829404, 0.13033971731220523, 0.17311791378644206, 0.07875094280367897, 0.17968947728795392, 0.2309539208128568, 0.21701125848677852, 0.10983900527559942, 0.16019788690872733, 0.15600660455323037, 0.11466034898354162, 0.16267680953587257, 0.1590002310131827, 0.07321981863389093, 0.13388318039717215, 0.17349547255904446], [0.043590196047819434, 0.011818222945646174, 0.017609000168440324, 0.01652681479050267, 0.0494152681541539, 0.11918157774714694, 0.024836949718695496, 0.036974226259776664, 0.006448017938377997, 0.014752490998005435, 0.023555165877746, 0.0208982273996357, 0.06371406943447168, 0.13548053500633087, 0.09464503791663917, 0.06436700617233593, 0.12880441582491323, 0.07727960199718514, 0.39754171645449055, 14.229999107699241, 86.68249022576117, 85.66133253036007, 72.83164408899123, 56.99463521280597, 31.934476860107917, 41.39032094709335, 71.10140815857919, 50.61928925975677, 161.5241450648154, 98.82380270188855, 14.441730610785948, 0.10605282255358274, 0.05051762271191805, 0.23491482520776413, 0.015421857449015784, 0.1516929932779843, 0.1459929313991339, 0.10638875210837972, 0.12563344767136922, 0.5015926669922568, 1.137055276382354, 50.04181831113754, 125.640655332996, 98.00942451723161, 102.80914260495095, 94.5453832995507, 99.56354602690666, 93.65276951943675, 100.86085427191951, 100.26227704940304, 104.61584906424247, 96.31347794686594, 96.23908627417781, 97.94074381551435, 96.55025574468799, 84.66437585892217, 80.60185155560895, 75.1025709029167, 75.2533781913019, 72.50003906988329, 81.24307278663882, 82.73797435145225, 80.39933173887192, 68.07587223668253, 67.31081393457228, 68.891309461286, 70.8468149554345, 68.44808947655463, 70.63026089822093, 68.25049615675404, 72.58744516680318, 71.96400011739424, 66.81054699805476, 66.24887927885979, 65.35485736785397, 64.1811155503796, 64.84130536356281, 68.09597830618581, 68.34087541026454, 70.86685826701503, 72.2138786315918, 77.11149907881214, 76.91044622851958, 83.89097859782558, 79.9712521030057, 85.15719813685264, 80.13639957674089, 95.38182089405676, 68.16985222601122, 47.524954965037686, 95.64244670252647, 77.57293455062374, 72.79463260404526, 70.68211463189894, 82.35636695738762, 77.28593472511538, 77.80110666828772, 71.23696527173443, 70.61097068171348, 64.11159546144548, 64.94140817273048, 62.873205138791, 68.21273942147532, 66.8464288403911, 70.71686683162567, 66.13683285251741, 65.50057734212568, 64.57320743991484, 64.49138287575015, 61.96933415628249, 66.4591496990573, 62.924635256490404, 67.53041175103957, 64.00186715587493, 66.60188474962789, 64.35346841812134, 71.11843124512704, 70.57595960555538, 73.41257064573227, 78.19661494224303, 83.0502656198317, 87.60263119974445, 87.86417484283449, 84.27021688030612, 86.21613610175349, 74.75913601536905, 78.37248617602934, 84.67757071218183, 89.55084108537244, 80.79127065597042, 77.34619802044284, 6.609028020212728, 0.6099965904028185, 0.28530579060316086, 0.16269898012040124, 0.02235787770440502, 0.10571929085398875, 0.12576606515194141, 0.29761428013443947, 0.2877614394791665, 0.22750415028102938, 0.8519255634277099, 17.199146055406143, 26.42184053697894, 78.81727510882963, 58.14891030711513, 27.638112614231726, 15.752182718246216, 68.07299321697604, 65.7734448679032, 71.01732038682508, 77.1554845379245, 21.862132280103623, 0.6496643166868918, 0.11673160558266026, 0.11015549917975742, 0.015024330594667025, 0.046796779628963246, 0.06395416138994117, 0.023109930897912672, 0.036868195860616626, 0.029941590825816797, 0.08215857083879172, 0.09675644518386933, 0.05217909888033906, 0.07251507903058683, 0.023325485057167472, 0.02115268733412508, 0.04560851214093067, 0.02850459948662789, 0.026967256375017668, 0.0780278247510714, 0.0606979736157002, 0.04969204422987757, 0.08100753905431879, 0.10779535082439262, 0.06008668907827908, 0.028315770304611618, 0.019111765901588144, 0.02579712793381224, 0.02223013062781144, 0.0745902426781193, 0.03075959844394557, 0.13266405871798917, 0.027470654665282177, 0.07204877663283579, 0.06050064085772442, 0.008254515029670251, 0.04545684205368162, 0.06124093843203399, 0.030535397067245458, 0.13284943667390656, 0.03380657909738441, 0.11876501743831944, 0.42066347574995416, 20.61038040345715, 113.32699391149707, 101.70163000783613, 90.83077323052191, 71.63866304582166, 46.20644238687331, 48.387574380443944, 64.0329715513414, 50.577186538327126, 130.25718304418749, 113.62899288054436, 18.43308841028521, 0.12290740040160957, 0.13095819541523535, 0.14179452442594115, 0.03776995412584755, 0.36581084492706484, 0.12775718129330105, 0.24658808995398784, 0.08441964870378857, 1.4755067926260734, 1.1764073131545898, 58.949473904025176, 129.53196817828763, 104.59959476224839, 107.91176180685721, 97.91729588662425, 101.70609366509223, 99.41735929058444, 103.72296071821644, 103.71435503805839, 109.16819895467451, 98.69143055331324, 100.120373541309, 103.10384596547773, 103.33264566236927, 88.60014484774682, 85.71985429333103, 77.94759934948337, 79.434538502847, 76.92255066287133, 82.76430130004883, 85.49740883611864, 83.6433123004052, 71.06009775592436, 69.98912595933484, 70.90520335781959, 73.83784970929547, 69.74336593381821, 74.3299973395563, 72.46923277454992, 76.01313344893917, 74.98216198336694, 70.02088146824991, 67.37563502403998, 69.30591967798048, 67.31956866479689, 69.57070319883286, 72.03313581405148, 73.0459467057259, 75.56107244183941, 76.16923593705701, 80.94534920107934, 80.07832496396958, 87.96707430193501, 84.20910635302144, 87.84111130622126, 85.57074146886026, 98.04248225304389, 72.25482033145043, 50.60094825683102, 98.36509719971689, 80.875209377658, 77.10821213260775, 73.13042671449723, 83.93579559941446, 80.11418327208489, 81.75968816203456, 74.73211872962214, 74.20217514038086, 68.01582074934437, 67.90584533445298, 67.25179795295962, 70.06226247356784, 70.64480504681988, 72.2796489346412, 72.48278848586544, 70.74263680365779, 67.96733240927419, 68.96232789562595, 67.64008122105753, 68.8855984903151, 66.52488077840498, 71.24207219769879, 67.39303465812438, 70.74957155412244, 67.58592897845854, 74.75362900764712, 74.54793207107052, 78.01970035799089, 80.63073588955788, 86.54519158024942, 90.30553648548742, 89.39245577781432, 86.35575679040726, 89.97517878009428, 78.24454630574873, 82.91513996739542, 88.22450730108446, 94.64819646650746, 86.65070333788472, 90.46666745216616, 11.482233674295488, 0.7123346602724445, 0.45556662544127435, 0.2765084965334785, 0.09729556423882324, 0.32819890026603976, 0.06529185049716504, 0.5837640238385047, 0.1662447261473825, 0.08225704378057873, 0.5705509683297527, 20.005919625682218, 23.92358099260638, 58.718387465323175, 50.36586492292343, 37.2779276294093, 32.40429443697776, 76.42262889492896, 72.3025163527458, 80.05813260232249, 92.09121119591498, 46.256770318554295, 0.878409039108984, 0.021334393813665357, 0.10904614257836535, 0.07213430268870247, 0.050456638282705704, 0.09177779298155539, 0.036003022124209715, 0.03844411916009361, 0.0685293150825366, 0.05662174234467168, 0.032541404042633316, 0.0271297512846368, 0.04181536951012189, 0.09126510395998917, 0.028486268917819666, 0.03251628018915653, 0.04401814808408099, 0.061765739303683086, 0.06279500907347088, 0.052836383167173595, 0.0348218715929937, 0.052970777971730124, 0.024267826830187154, 0.1758444819959902, 0.13391042248375956, 0.08975385763351956, 0.13849403378703903, 0.18181342541450457, 0.1292311574422544, 0.1890240441406927, 0.2502732946267051, 0.07972781982032523, 0.16115356627250874, 0.13262636719211457, 0.09451918499243837, 0.1958190448462002, 0.2046391223707507, 0.3825429712812747, 0.35075455122897703, 0.18388996802030072, 0.35562592047837477, 0.7002229327636381, 31.117511872322332, 139.47394494087467, 120.47843179395123, 108.04722478312831, 81.32236742204236, 48.69142470821258, 62.23491391827984, 92.09176817247945, 74.01301491645076, 185.51524377638296, 126.09455985407676, 26.687155538989654, 0.20061495443505628, 0.16836980808406107, 0.7980081114557482, 0.16216636515192448, 0.7570140111830927, 0.34801321284424874, 0.46667303108880603, 0.4517576975687858, 2.804607931644686, 2.73375766892587, 58.72315706745271, 138.54627301616054, 108.31611110318093, 113.59759822968515, 102.49174441060713, 108.59804322642665, 100.40989937320833, 110.9921952216856, 109.06697042526739, 115.6362658162271, 101.19334574668639, 104.82679413210963, 108.4979364948888, 108.72938771401684, 92.20467752025974, 89.58782903609738, 82.448974117156, 87.14574567733273, 79.47057723999023, 87.74323248094129, 90.91813225899973, 87.35028943707867, 74.88294170748803, 74.89202591680711, 72.90194080721948, 77.25975682658535, 73.81056570237683, 78.18178053825133, 75.22196000622165, 81.2525963014172, 79.85156489956765, 73.70293586484848, 73.21294553818242, 73.83359001528832, 71.39458179473877, 73.74328920918127, 76.53735822246921, 78.86468871947258, 78.86176263132404, 81.87461360808342, 84.92791206605973, 86.30560536538401, 91.67089785298994, 88.42013159105855, 93.19298928783786, 89.38713704386066, 101.24366191125686, 81.01217069933492, 57.621120099098455, 103.86324036505916, 87.88135482418923, 81.35725298235494, 76.70875795425908, 89.24683386279692, 85.85890231593963, 87.58217996166599, 78.9900476701798, 79.49870847886609, 71.03227246192195, 70.74562564972909, 69.08043830625473, 75.55635775289228, 72.76305752415811, 76.39074002542804, 75.25973243098106, 74.8593839522331, 71.60955905914307, 71.92726319836032, 70.64627201326432, 72.72810920592278, 71.7696152963946, 76.4694933737478, 72.24955651067918, 75.7155667581866, 72.10906505584717, 79.5638119789862, 79.74412333580756, 81.9662166410877, 86.62974219168387, 91.83136986147974, 95.6733000663019, 92.54899101872599, 88.67629374227216, 95.9959307024556, 82.923188670989, 86.72500871842908, 92.82449045488912, 99.52333388790008, 88.74703761070006, 91.70794856163764, 9.295698615812487, 2.2035848661776516, 1.1782466596172703, 0.573347618262614, 0.458597207982694, 0.6130456203414548, 0.6371096064967494, 0.6629205182675393, 0.610794731445851, 0.29326421839575617, 1.997771239088428, 31.816678277907837, 42.065925675053755, 105.05977507560485, 81.99396348768666, 39.96529248452956, 27.73227107140326, 88.34439846777147, 89.15648598824778, 92.99107351610738, 108.24011125872212, 54.71660106412826, 1.2202090337391824, 0.12495308498581573, 0.2688304262776529, 0.21720575288899485, 0.14812729832145477, 0.15431362684936295, 0.13913106653959523, 0.15619616534921432, 0.20880812688940958, 0.16550735119850407, 0.19004802790380296, 0.1079326184586652, 0.15600429096769902, 0.12515023005225007, 0.09263500706442902, 0.08429518239873071, 0.12744148412058431, 0.1758938027365554, 0.12233293404982937, 0.21671557919152323, 0.16279460321510994, 0.15057167038321495, 0.12061295940751031], [0.036081197566442916, 0.04819964749678489, 0.01655199227013415, 0.02106386326974438, 0.01360927522557998, 0.06044861199634691, 0.043388753228129885, 0.01700944826757956, 0.06330529640939447, 0.08532645165800087, 0.015826633410348047, 0.070087882660089, 0.031456993179275625, 0.05590381070731148, 0.06324645319593049, 0.035210439049068, 0.07608497214894142, 0.06559231784194708, 0.20510792221513488, 29.109528987638413, 80.69824772496378, 82.95368902144894, 70.22239715822282, 38.92245584918607, 39.35727803937851, 67.04081366139074, 76.11549946569627, 83.10958754631781, 96.00896081616803, 37.99933387387184, 0.5815527876538615, 0.102232625527728, 0.12550615450187078, 0.4445668285892856, 0.2157801551924598, 0.2079769981003577, 0.10083671373825881, 0.2732373930273518, 0.8533477903373781, 3.2763920868596728, 18.329845743794596, 128.84148197789347, 98.04369034305697, 105.52943968003797, 93.09038792887043, 94.3052871765629, 85.58001395194762, 93.56353559801656, 90.28373595206969, 97.2559372071297, 97.76564921102216, 100.08530755196848, 100.27343227017312, 99.45370397260113, 95.74547952221286, 89.91704925414055, 81.15993422846641, 77.1123698449904, 74.92873145687965, 74.13584001602666, 71.78256696270358, 75.34313771032518, 71.58241625755065, 67.43926371297529, 66.02801845919701, 68.17791661908551, 66.39152019254624, 67.39907510818975, 71.6282844543457, 71.79252978294127, 71.50917776169317, 68.67027605733564, 66.07445932203724, 69.21978442899643, 68.84941854784566, 72.85456642027825, 68.08070459673482, 73.23165524390437, 73.39975234000914, 76.23232333890854, 74.62332787052279, 81.22676357146233, 79.83976641008931, 81.6765574486025, 79.1467228243428, 84.31470440280053, 79.87813503511491, 91.12931266907724, 67.05741313195998, 46.98806093585107, 92.16928205182477, 77.16458443672427, 76.08401067795293, 65.84172156549269, 76.39712564406857, 76.93998952065745, 79.20650759050923, 77.459013231339, 79.2362234669347, 71.90382311421057, 69.77258759160196, 63.63917735315139, 66.91929863345239, 64.9498373462308, 68.335399781504, 66.47563934326172, 68.1062235370759, 63.11888279453401, 64.67477721552696, 62.58068653845019, 63.73189826165477, 63.93097031501032, 65.89456373645415, 63.90102301874469, 65.19287132447766, 63.449511143469046, 65.85585778759372, 67.62611758324408, 76.2376420728622, 79.20646836680751, 84.5023427471038, 82.58432726706229, 87.00005315965223, 86.76726833466562, 82.03125738328504, 75.65040050014373, 76.97155675580426, 83.14185296335529, 90.2632454902895, 86.64557287769934, 87.47881766288512, 63.61956550228981, 1.9930646400297842, 0.28681905940175056, 0.05013004350926607, 0.06226665738429274, 0.0717958910090308, 0.1755020866591123, 0.1708472445006332, 0.46938427753986856, 0.32064107517080925, 0.3616822745290495, 5.038417846925798, 26.899953926763228, 49.34391490874752, 57.1506239521888, 41.147012402934415, 24.342711740924468, 33.08864801160751, 53.70490804795296, 63.894092190650206, 73.71163568189068, 68.59984597852154, 5.155620228859687, 0.24248564315419047, 0.11165800444301098, 0.08186154322878969, 0.14410601087635563, 0.07098605180339468, 0.06592690674287659, 0.03271191606238004, 0.07051359771961166, 0.02910873833893528, 0.026359585857379342, 0.11160099984056528, 0.03003121162163875, 0.04456556770169447, 0.012628247927603944, 0.025089255030897838, 0.023820789628511956, 0.04343218275255734, 0.052629849693227204, 0.08568838223694794, 0.039203902180757255, 0.04889326350342843, 0.022996710763583263, 0.04640401784150351, 0.07195844720568388, 0.05282021105109204, 0.01776945728418087, 0.03063716993276631, 0.046116968526715235, 0.008349394061482482, 0.02501529498746799, 0.12832450770562695, 0.05144335186829971, 0.01597052770516565, 0.03912619788259749, 0.029510651046650547, 0.06128577372780251, 0.009612451840732849, 0.08621064735756767, 0.076130140692957, 0.09623593440459621, 0.33583069881123884, 41.58951067155407, 106.84570081772344, 97.90893339341687, 84.37562665631695, 48.49864413661342, 45.432178281968646, 52.61972942659932, 60.07085600206929, 78.42023711050712, 116.37032954923569, 43.76738709788169, 0.5503202409994218, 0.17843306244861695, 0.19171166444017043, 0.5293629558817033, 0.16388761150019784, 0.2579266968513689, 0.11828481820562195, 0.36452059964499167, 1.360913277153046, 2.8676492456466924, 23.56802402004119, 136.44794617929767, 100.90038391851611, 109.23900558102517, 98.32078226151006, 96.12844405635711, 88.05044820231777, 98.25140337790214, 93.91373265174128, 103.26080353029313, 101.8961246552006, 102.22024579201977, 101.04362887720909, 102.70228939671671, 100.08203629524478, 95.58220694142004, 87.05027518733856, 83.33352350419568, 77.25041374083489, 78.551848319269, 76.00606533788866, 77.80234613726216, 75.31615180353965, 70.59879564469861, 70.40667010891822, 71.24515518065422, 69.55955582280313, 73.07869065192439, 77.79321485950102, 73.5561921519618, 72.39276224567045, 72.32387758070423, 69.89818972925987, 72.50898207387617, 72.84172458033409, 76.18215622440462, 72.11414060285016, 78.4964644524359, 76.8129910192182, 81.4567478241459, 78.13564562028455, 86.12596865623229, 82.77185578500071, 84.406676138601, 81.69668705232682, 88.32603393062469, 82.95369686618929, 93.60741123076409, 71.29373765760853, 50.16643201151202, 96.28447594181185, 82.47554425270327, 78.41844066496819, 69.27730990994361, 81.03241797416442, 80.06620484013712, 84.32626755006852, 80.3824027892082, 83.37193919766335, 75.93392510567942, 73.6248650089387, 68.23188843265658, 70.12798570817517, 68.76181633241715, 72.3076311234505, 69.8085557260821, 71.18427999557989, 66.33184525274461, 68.89717732706379, 68.13415865744314, 67.77686211370653, 67.31126108477193, 68.78560158514208, 67.53624823785597, 67.61648424210088, 67.23517494816934, 67.96159005934193, 72.61047732445502, 80.21771815515335, 84.26008147578086, 88.82585371694258, 89.32403395252844, 88.38599912581905, 88.24215796685989, 84.84428713398596, 78.54867904416977, 81.58502501826133, 85.34200452989148, 92.3848633612356, 89.62473853941887, 88.46796881768012, 75.46486454625284, 4.6889964419026535, 0.38094362484351285, 0.18928816061346762, 0.3868829513028745, 0.15714406125968503, 0.2006276102075654, 0.22859668359160426, 0.45583454171015375, 0.09912894287657353, 0.42512618305702365, 4.021031020149108, 30.346148360160093, 40.91449037674935, 33.172272943681286, 37.514634824568226, 31.066999589243245, 55.673843737571474, 63.71426328536003, 75.44626466689571, 81.15314068332796, 91.7513221310031, 12.465208076661634, 0.511984036814782, 0.2797102844042163, 0.1682997416825064, 0.11323845915256009, 0.07046888882835066, 0.05809212171082055, 0.061998649184862455, 0.026181311451739846, 0.07785078183177017, 0.01595788150875559, 0.02847592290040226, 0.02776701194835046, 0.06320519170032875, 0.06619623261353662, 0.020004103200570233, 0.04856090391835859, 0.041558021424157966, 0.008604682328539991, 0.047892181938814546, 0.03526739002535901, 0.01656092677055107, 0.07036080148311392, 0.1637065696019319, 0.14290513741152902, 0.127988264054781, 0.1389707243370433, 0.12544999259614176, 0.19113829359412196, 0.13382193932850517, 0.09365698367717767, 0.21700920537114146, 0.1549216248695889, 0.09823572266125873, 0.24950576645712702, 0.15330099650929052, 0.18884381429562647, 0.15821215636547536, 0.13351659200364543, 0.2676017438211749, 0.23659180699577256, 0.6024264159702486, 61.72276220014019, 134.55755203000962, 115.47758240853588, 105.96757627302601, 62.871271410296046, 58.81450514639578, 90.47997213179066, 101.49951811759703, 106.01071450018115, 114.5214968342935, 59.44951334307271, 1.4629898965358736, 0.3037872021236728, 0.6395286057264574, 0.7012766407382104, 0.488508161037199, 0.5528507213438711, 0.5402058579267994, 0.6064987555146217, 2.6567115322236092, 4.451961728834338, 27.14171901825936, 145.7526711494692, 106.51954004841467, 114.81266221692486, 103.07192571701543, 101.70776459478564, 93.57903680493756, 103.46707313291489, 99.4412386801935, 109.06252245749198, 106.39796226255356, 107.18602918809461, 105.20263564202094, 105.20055678582962, 104.5156168168591, 100.80026149749757, 91.43846604131883, 87.68689155578615, 82.93615602677869, 83.95829431472286, 81.5720811966927, 83.96703335546678, 79.51933230123213, 74.45632903806626, 74.88483228991109, 73.64944258043843, 74.21173787886097, 75.64104172491258, 80.61849809462025, 78.92212006353563, 75.36041182856407, 77.36595892137098, 74.2977633014802, 75.54875619949834, 77.27255944282778, 80.44756120251071, 76.5334358522969, 84.13326340336954, 84.20724714955976, 84.48057359264743, 82.38108573421356, 90.5684764923588, 86.7273150720904, 89.77920147680467, 88.99679060905211, 92.6581427358812, 89.50945223531416, 95.72331028599893, 73.66120184621504, 55.265148455096835, 100.02345961909141, 86.71543813520863, 83.50589598378828, 72.59207356360652, 85.3923834523847, 85.0097405525946, 86.22150190414922, 83.208768598495, 87.01237724673364, 79.13873687867196, 76.19961077167143, 69.97334234176144, 74.50407997254403, 71.8815597411125, 73.7703457186299, 72.00907599541449, 76.32522859881001, 70.27775749083489, 73.10698663034748, 71.35597782750284, 70.78670855491393, 70.97648851333126, 72.70135079660724, 73.46378895544237, 73.10865756004088, 69.93545224589687, 72.65368615427326, 75.90140865695092, 86.01395360885128, 89.27087014721286, 93.53798527871409, 90.00312174520185, 93.27510018502512, 93.52328423530825, 91.0873354634931, 83.25670780674105, 85.93049341632475, 88.99179350945258, 99.54099239841585, 94.53848777278778, 96.68952342002623, 75.52081323439076, 3.563197264748235, 0.6846736155210004, 0.7965507057885971, 1.0153484200277636, 0.5066585612873877, 0.49663145095109945, 0.5156254672235059, 0.630505683441316, 0.5285018730548121, 0.6797936354433337, 8.098186254501343, 45.83919086763936, 68.40464530452606, 74.17787997953354, 54.79202432017173, 35.770368576049805, 52.436750858060776, 73.62002480414607, 89.72923048080938, 95.42022874278408, 103.75788550223075, 14.349395075151998, 0.9014581119821918, 0.5407943360267148, 0.3308153969626273, 0.2771540022184772, 0.28118763900091576, 0.1746105135328347, 0.15787100209103477, 0.12278820478147077, 0.0895432294196179, 0.13966954974157197, 0.23248150013387206, 0.12519261003622126, 0.19305116917577483, 0.12328590912323807, 0.10903700314942869, 0.13947013705488176, 0.07554148639281912, 0.15551152789304334, 0.1306697939552607, 0.19353708342438747, 0.08641942929957183, 0.16045308611806364], [0.09206714439055613, 0.035814426599010345, 0.05805872410776154, 0.030100442987355976, 0.030804546737682917, 0.04880011487271517, 0.03596963601246957, 0.0971752348085565, 0.09258950910260601, 0.04521848528736061, 0.022536757319504698, 0.02665170475900654, 0.027955320190578222, 0.023803899305001385, 0.06630477195064868, 0.04430676787911404, 0.05025101262294958, 0.34820810561218574, 1.7533074343396773, 33.7792871844384, 86.6223132225775, 67.20309780490014, 55.30888680488833, 37.785482329706994, 43.70852801107591, 84.45616860543528, 106.31330966949464, 63.48325137169131, 60.70218501552459, 6.6919057407686795, 0.7286943146778692, 0.3623414472226174, 0.1701658705790197, 0.2190984497147222, 0.22542552391607917, 0.18312247049423958, 0.23806916159247202, 0.19409692515769314, 1.2768886310438956, 3.4805850396233224, 76.01809916957733, 97.74552745203819, 110.24615257017075, 95.94723839913645, 90.02322781470515, 87.36421385119039, 86.32585264021351, 84.21186770162275, 85.3626440417382, 88.71806698460733, 97.48829841613771, 100.18023675487888, 97.58478087763633, 96.62563585465955, 95.99599346037834, 86.52081797199865, 79.33491814521052, 72.48684421662362, 71.79049799519201, 69.84905812048143, 70.22613125462686, 68.89681646900793, 66.9778831543461, 68.15133079405754, 64.92319660802042, 62.82206135411417, 65.4646445089771, 73.08853580105689, 69.73771772077008, 70.44119481117495, 68.27198290055799, 65.40918611711072, 69.98840424322313, 72.77604056942847, 71.58027464343657, 70.75971480338805, 70.22850036621094, 69.84768529092112, 72.9362693909676, 71.75010542715751, 72.58153023258333, 73.24834885135775, 80.17789040842365, 82.06208721283944, 76.49110563339727, 82.24260253290977, 78.16373763545867, 88.11015452108076, 69.002869513727, 43.720930545560776, 88.46567815349948, 76.39931432662472, 73.82126592820691, 63.07739196285125, 73.7077211564587, 72.49123727121662, 77.3117909892913, 75.26533357558712, 80.31598921745055, 75.86671921514696, 76.11477774958458, 71.1580785628288, 66.29738330841064, 62.596328950697384, 65.22885907080867, 64.81307606543264, 68.4568363620389, 62.11950994306996, 60.786257097798014, 61.67898462664697, 62.249983664481874, 62.49004448613813, 60.90564620110297, 64.38379226192352, 62.97760294329736, 63.363097406202755, 63.604793856220866, 65.11165080531951, 71.45113452788323, 80.48651818306216, 82.75054162548435, 85.07250632009199, 83.7166763121082, 80.89122833744173, 80.59877641739385, 76.97704022930515, 72.48715800623741, 78.48954539145194, 84.3650911700341, 86.35414077389626, 80.77459273799774, 87.10745549971058, 42.71521522152809, 0.4532177692219135, 0.11848029320038135, 0.07716609841032375, 0.10864065990092293, 0.04475270382939808, 0.16107841304713683, 0.04341413755150091, 0.08359064197828693, 0.027706998535582138, 0.20174275843366501, 8.401666898881237, 39.6605949248037, 78.30382116379278, 53.08388310094034, 34.75805190301711, 15.640997252156659, 34.155367958930235, 51.90066483712966, 59.30222834310224, 78.73785495758057, 28.60977588161346, 0.6212079500959766, 0.07670400183527701, 0.1144024454838326, 0.027815941984074253, 0.06807569910081164, 0.08263673993848986, 0.02986984286126831, 0.021092777343226538, 0.08882652352293653, 0.06289780658159046, 0.027823962924641468, 0.06985683054212602, 0.0413605660921143, 0.012000972262373375, 0.011661425814963879, 0.027031100227407394, 0.04783490154471609, 0.025912542910044713, 0.0287901166255676, 0.0401189788845518, 0.09369532637778791, 0.009175512635509574, 0.05644375330678398, 0.04100663730153634, 0.07405781157074437, 0.04085150449686954, 0.05603665035338171, 0.043509113301913586, 0.03224709221432286, 0.02371623777904578, 0.043805485906740355, 0.06252897738088524, 0.03999885629802462, 0.009868437247801452, 0.06856932785482177, 0.017752373523469415, 0.027902722508916934, 0.03472798751787313, 0.056909216838257934, 0.3866179155245904, 1.7020094514854494, 56.29582182053597, 107.52468662877237, 86.5176643863801, 72.55051212926065, 44.268826823080744, 53.733906130636896, 61.79782852049797, 96.6132019412133, 69.69053160759711, 69.68442839960899, 7.444020221310278, 0.656001334709506, 0.37165143797474526, 0.39059176680541813, 0.20812834643067854, 0.36073217228535687, 0.1521675541035591, 0.35593728925431933, 0.20781446488634234, 1.014325968440502, 5.548032772156501, 94.74178421881892, 105.50341083157448, 116.00765151362266, 99.50220015741165, 95.21123701526274, 92.28680410692769, 90.084001018155, 87.28571153456166, 87.0162368589832, 91.49327724210679, 100.4607254459012, 107.08333369224303, 101.72558784484865, 100.49001770634806, 101.17745230274816, 90.51728171686973, 82.39437472435736, 77.38705342815769, 75.98535522337883, 74.30135619255805, 72.89327236913866, 71.4902719374626, 71.55579120882096, 70.90198701427829, 68.30688415035125, 66.63443257731777, 68.37699259481123, 78.17527724850562, 73.58499019376694, 72.57056328558153, 70.98300749255766, 68.30008276047246, 73.22322214803388, 76.32591109122001, 74.86811514823668, 75.68389754141532, 74.5050605650871, 73.50650356661889, 77.56853365129041, 77.35156382283857, 76.51704034497662, 77.5290746073569, 83.61558114328693, 86.10287374065769, 80.37848041903588, 85.45415293785834, 81.35387974400675, 94.52415543217813, 71.35778996252245, 47.71017712931479, 90.61464278928696, 79.43229490710844, 76.60178707491967, 65.59783251054826, 77.29713701432752, 76.16792586541946, 79.49655117527132, 78.36213896351477, 82.38906383514404, 78.119061839196, 81.43370782175373, 75.02381755459693, 69.02390126259097, 66.3762935515373, 66.84923725743448, 67.29777597611951, 69.96159092072519, 67.14969865737423, 64.49590536855882, 65.10470428774434, 65.13880537402245, 67.2949440248551, 65.68981993582942, 67.39220311564785, 67.14764333540394, 67.64171292704921, 67.74622840266075, 69.508086481402, 75.60220241546631, 84.33500659081244, 88.59677945413898, 88.91654676006686, 83.66579532623291, 82.92776215460994, 84.34035670372748, 80.16024758738857, 75.28916589675411, 80.5050866834579, 88.2579964976157, 90.82635664170789, 88.41480501236455, 92.23948463316887, 54.80794914307133, 0.9045456301781439, 0.1287335373701588, 0.1305157489954464, 0.06706087008839653, 0.07070338068109366, 0.5207307384379449, 0.08428916094764587, 0.08934914104400143, 0.022321624508608254, 0.39457907059019615, 7.734198637547032, 43.66223619830224, 49.98927424030919, 27.17102304581673, 35.374166042574, 28.120177791964625, 46.02547599423317, 62.777122759049945, 70.43838639413157, 89.34588155438824, 48.850190485677416, 0.41227331144675133, 0.02537135733291507, 0.046764098318113435, 0.03568816764820968, 0.04549997280381861, 0.013559474722452223, 0.03904229210269067, 0.031262807127448826, 0.054066793151920846, 0.005526214982608274, 0.029663037426108797, 0.040429861194664435, 0.038071804259332924, 0.02416148616541778, 0.036283977209560336, 0.036612322493906946, 0.08493022332268377, 0.04276765893483835, 0.02277166285972682, 0.028374703533406702, 0.06742486910473916, 0.032832954123976736, 0.1864206015823349, 0.14684117459241422, 0.22439865966237363, 0.12029069686128248, 0.12176494880188858, 0.26962988499191504, 0.1393184822893912, 0.1832527514066427, 0.2677749716226132, 0.11247843098376067, 0.1317187828282195, 0.24449038799972306, 0.17578886401268745, 0.09619748445167657, 0.18302398223069408, 0.19471612338337208, 0.2180756916922908, 0.6246152027480064, 2.4636279575286375, 81.66955994021508, 132.06934159801853, 101.07205037147769, 89.52471810002481, 55.225250105704035, 62.797377878619784, 109.85979126345728, 133.04025373151225, 81.973371044282, 93.7783245886526, 11.009545903052054, 0.8193815968209698, 1.2835371710600392, 0.614692525517556, 0.9635053502936518, 0.5790071694120285, 0.6356340598675513, 0.5286802796106185, 0.7551176064918119, 1.8856517586015888, 5.536547581995688, 98.46313291980375, 109.94361231403967, 122.09816671186879, 107.48106202771588, 98.17046134702622, 97.35183915784283, 94.89981651306154, 93.35261406437044, 91.81595494670253, 96.92488131984588, 103.59333422876175, 111.76883236054452, 103.83763513257428, 104.04842330563454, 104.6045369486655, 95.41331752654045, 88.04203079592797, 83.50625684184413, 80.75184299099831, 80.76892099072857, 77.58020662492322, 75.71078146657636, 73.51459933865455, 76.49847184458088, 70.99409995540496, 72.176529822811, 74.3096088594006, 82.01096304001348, 77.1269218383297, 79.0597560328822, 74.42743685937698, 72.67106225413661, 76.54618355535692, 81.30040214907739, 79.69325803941297, 81.67674572237077, 80.41779041290283, 79.9422344084709, 81.53925880309075, 81.11909451023226, 81.74055484033401, 83.34698507862707, 88.8287405813894, 89.52294518870693, 83.90195338956772, 88.37388684672695, 85.52073124916323, 96.9425319856213, 77.6001165759179, 51.91732314325149, 93.31844237542923, 85.1455016289988, 80.99023680533134, 68.83026953666442, 80.64017311219247, 79.45109874971452, 84.16896481667796, 81.6933765719014, 86.67848940818541, 82.61432555414017, 83.04551170718285, 78.48645456375615, 71.93102082898541, 69.67230827577653, 71.41793558674475, 70.8067754007155, 76.51884463525589, 70.5126682404549, 69.08257992036881, 69.37162722310713, 70.03860273668843, 70.21180675875756, 68.94344560561642, 72.4153394083823, 71.47453538833126, 71.29024674815517, 71.68318194727745, 72.31168685420867, 79.03533535618936, 89.24894409794962, 92.16693647446172, 90.68020128434705, 85.9956596743676, 90.32846666151478, 86.9037981956236, 86.35738849639894, 78.50062216481855, 87.34877540219216, 92.52381724696006, 94.90098537937288, 92.57346660860124, 97.11694409770351, 51.438056576636534, 1.0013728925297338, 0.4425823850737464, 0.29194951958713994, 0.3856003975435611, 0.2287215406015035, 0.9520930917032304, 0.2445772317268195, 0.303501604545501, 0.27557616752962916, 0.3605534592943807, 13.51335265944081, 63.43930513628068, 104.32231457002702, 72.91896389376733, 47.78133284661078, 25.85131806711997, 51.12187823941631, 75.54373556567778, 82.99673311171993, 107.81989989742156, 56.108022659055656, 1.0682255245985524, 0.25562184472237864, 0.16812093676097933, 0.09739906271739353, 0.09706677208023687, 0.17518515608483748, 0.12768570528996567, 0.10330544739601114, 0.2372634975660232, 0.10109127709461797, 0.16670460872832807, 0.15013066420872367, 0.08854864811104152, 0.1352460354927086, 0.20128926502600794, 0.11590472858158812, 0.11738882475202123, 0.13391776160607416, 0.08716228943798812, 0.11741903159887561, 0.12869933920521892, 0.16051510859641338], [0.1488725486541948, 0.062398512607380274, 0.017704100408140692, 0.04544660711901323, 0.04291676262754106, 0.03846093479003157, 0.022921906108216896, 0.03320591253859382, 0.019655831969313083, 0.07073723410646762, 0.0577171293327645, 0.08142008506242307, 0.020219050235145038, 0.06657828066137529, 0.05199955085352544, 0.11158849728564102, 0.10207778383647242, 0.24651656798537702, 6.714610870807403, 50.60656116854761, 77.62168961186563, 70.38301037203881, 90.59346199035646, 71.0200660459457, 48.03256457851779, 79.50601193212694, 69.64392600520965, 94.33605424819454, 20.57255110433025, 0.11125852789489493, 0.04457179982695849, 0.1700240523824769, 0.05879058705402478, 0.08816048668156709, 0.1625068299472332, 0.059902678589306535, 0.22710769978021422, 0.20844602777111917, 0.21453149316291656, 68.79189306689848, 123.56223844712781, 106.04543532094648, 99.06220436096193, 91.79253055203347, 87.56356439282818, 81.5472133698002, 77.77706253913142, 81.53610521747221, 80.62769997504451, 79.47278945676743, 80.57541478064753, 89.10729946628695, 93.10721489690965, 96.91612658962127, 93.07446310597082, 83.11028572820848, 71.85038474298292, 69.58758508005451, 66.439726121964, 64.27168307765838, 67.57726054037771, 67.01596152397894, 64.61982873178297, 70.33487504528415, 62.5734301536314, 60.98044580028903, 68.56772176681027, 73.178405146445, 70.54455710995582, 67.71630856298631, 65.6422729646006, 67.2155160288657, 71.70593169427687, 72.34485441638579, 71.75059964579921, 72.42728694792717, 69.80292320251465, 71.84949828732398, 69.70463645073676, 69.54691794610792, 66.94915571520406, 71.89548415522422, 74.50241688759097, 81.32767831125568, 76.54040982646328, 81.10625267028809, 78.84263715436383, 90.11911407593759, 64.88594585849394, 42.94724695144161, 92.39152354578819, 78.82328417993362, 76.14654894798034, 60.32321737658594, 68.34018507311421, 63.14548430904266, 65.58163704410677, 66.59458914110738, 71.04662833675262, 74.31473147484564, 74.28003418830134, 72.71526736597862, 68.83241899551885, 65.9225929937055, 63.95086849889448, 64.19059591908609, 68.86479423892114, 66.5023506841352, 61.64189077192738, 60.81854604905652, 63.73411440080213, 62.32212389669111, 65.27437033191805, 63.16560999039681, 62.90855746115408, 62.38058290173931, 64.43273559693368, 65.78261929173624, 77.50707795543056, 82.44869955124395, 84.6299845172513, 80.88415238165086, 78.29652555527227, 80.59020211619716, 82.03186927303192, 75.22749054816462, 71.58272220242408, 74.78479616103634, 84.60651305414017, 84.51937367839199, 88.13083325662922, 79.43827259925105, 76.8833661848499, 17.146250932447373, 0.3833659948600877, 0.3325509844768432, 0.09135787720761954, 0.2269173575745475, 0.1805801311087224, 0.22623802144681254, 0.07756889211915194, 0.04860206582253018, 0.04966391731173762, 0.398770950494274, 15.113321773467527, 30.241224958050637, 77.83589809171616, 47.837038347798014, 30.898508294936153, 27.274059787873302, 56.23263635943013, 66.27886972119732, 66.81490867368638, 66.631592781313, 5.398658619773004, 0.28481466695666313, 0.13379693421865665, 0.10262244936799812, 0.04720990020301073, 0.02875939075414452, 0.019053119955764666, 0.019853760360649998, 0.03931791138564868, 0.06531044345108733, 0.05189333276282396, 0.02563536655338061, 0.024749385868950237, 0.0429735757080057, 0.03778950852011481, 0.05643066852503727, 0.035131302166489825, 0.04352539267030455, 0.03406060619219657, 0.07288161379795882, 0.04109231274454825, 0.04309222740571826, 0.10795281253634922, 0.041107408507096196, 0.050925269587746555, 0.043845157769899216, 0.09435325034803922, 0.031630431654893106, 0.06078672107128848, 0.004828260045483588, 0.021629398951547283, 0.01923201106218321, 0.025967111352891214, 0.050560083135121295, 0.0030899876324955618, 0.07652155799610962, 0.0408294832994861, 0.045555939357126915, 0.15955752933457976, 0.3642552267880209, 11.201449824917702, 77.64331756099578, 95.81041828278573, 83.14148426055908, 96.05218533546694, 76.82056119365078, 43.93712374471849, 74.5020874084965, 78.69814488195604, 99.66764573127993, 26.127805940566528, 0.10937734537066952, 0.04785773479529927, 0.17841084589881284, 0.15839355066418648, 0.18001022298009167, 0.1619437246793701, 0.05022407314109226, 0.09739651930548492, 0.19965797272180358, 0.19068207291345443, 80.20755921640705, 122.91667907468735, 111.06435114337553, 101.90888804774131, 93.14060211181642, 92.65450277636128, 83.89702689263129, 82.05064958141696, 85.68479614873087, 83.64749354700889, 82.47211610117267, 83.9455936801049, 91.91236680553806, 96.2814635615195, 100.78141843118976, 95.7206666085028, 85.88383290075487, 73.75597415431854, 72.28278683077905, 71.12861371809437, 69.50537220124276, 70.26339377126386, 69.41795825958252, 67.21063660037133, 72.28806634103098, 65.8925711724066, 65.68645454222157, 71.76633619493055, 76.60784321446573, 72.34450140307027, 69.81275266216647, 68.25618359350389, 71.76254718534409, 74.68413245293402, 76.80647203999182, 76.35926692716538, 77.70374559587049, 73.46107467528313, 74.49415637600806, 72.3160328403596, 73.43632451949581, 73.0079467834965, 76.93759687485235, 79.74993628840294, 85.42544903293734, 82.09169326290008, 86.30191833742204, 81.48509087101107, 91.1922667103429, 68.98308507857784, 48.05439256852674, 94.38891210863667, 82.03030816970333, 80.15371291868149, 64.66877598916331, 70.81755407394903, 65.06976773661953, 69.30105593896681, 69.75656078707787, 74.89989419137278, 76.031294022837, 78.29133233716412, 75.80920942368047, 73.84964819877379, 69.01258914701401, 67.09578960172593, 66.81191982761507, 70.95576270934075, 68.26805268564533, 65.089877728493, 64.59436470462431, 67.84420136482485, 64.9504727701987, 66.64399531579787, 65.86806420356997, 66.56958795362904, 65.01690595380722, 67.70272147270941, 69.51512321349114, 81.23725983404344, 85.9416800160562, 86.74359290830552, 83.0377140352803, 81.71575761610463, 86.05293412362376, 85.45982468512751, 78.87754624889743, 75.49815762427546, 76.37565458974531, 87.89045472298899, 84.617048540423, 91.07383466536, 83.84934656081661, 84.70869864186933, 26.267801215571744, 0.3054118601064528, 0.42375813388536054, 0.7992268041256936, 0.26558965985332766, 0.15324560835236503, 0.2635426422761333, 0.09170807131956663, 0.4771760658871743, 0.09030465952931874, 0.3037199702474379, 17.203054697282855, 30.60081804952314, 47.91518765111124, 35.92904413900068, 35.053943741706114, 38.494988103066724, 59.93436144244287, 78.06632949459937, 76.25914450614684, 87.89488700128372, 12.748236502370528, 0.48424322698866173, 0.20605606327374137, 0.07816189779869973, 0.04014280421899692, 0.0627395519686322, 0.0021986014795519655, 0.05577876983631042, 0.0476797151138946, 0.08337211539788593, 0.023913639484934752, 0.06952121508337798, 0.012705487784959618, 0.02453233017736385, 0.018582368502393365, 0.06670275462731239, 0.045459519530976975, 0.02619684963006406, 0.04158715574791835, 0.03991489306152348, 0.03615679512281091, 0.027275796371301817, 0.18698816548191732, 0.16936556916804085, 0.11759340853220034, 0.1430959699134673, 0.15857845364559084, 0.12535803906259038, 0.09095256306952046, 0.11674223888304927, 0.1195010210898134, 0.2973267213711816, 0.18653799689585165, 0.1662061919247912, 0.133179543960479, 0.1460323236402004, 0.11948945316215677, 0.17962868055028303, 0.23713761399830544, 0.3505250925738966, 17.133948418401904, 107.05744604910575, 115.52443119787402, 100.25711521025627, 110.67066284918018, 93.27648085932579, 65.50477820058023, 110.08528832466372, 86.26616201093121, 118.29390695018154, 34.31007016089655, 0.2004266806667851, 0.31001791778591375, 0.3561083107225357, 0.22974216889950538, 0.5831888450249549, 0.5782320722937584, 0.2740734094573606, 0.4075617174948416, 0.7391476763352272, 0.3511316197053079, 82.97396767523982, 124.95984954218711, 114.96019040384601, 107.1785923742479, 97.58189401318951, 96.88683432917442, 89.87572316200503, 87.49834322160291, 91.24489707331504, 88.16813499696794, 88.59699126212828, 92.3215876856158, 98.61364995279621, 101.52261303317164, 103.72576913525982, 103.54834464288528, 91.95052362257435, 80.41802575511318, 77.32464851871615, 74.73386026197865, 74.08381369806106, 77.3616050904797, 74.03370149673955, 69.64877405474263, 76.48468079105501, 68.52916486801641, 68.89710672440069, 75.21545671647596, 80.42856124139603, 78.10749084718766, 73.44895455145067, 71.54786802107289, 73.4306449274863, 80.53069191594278, 80.5033451511014, 79.64792328496134, 81.13594501249253, 79.40942748900383, 81.1801815032959, 77.990612060793, 78.45273002501457, 75.31334338649627, 78.19149232679798, 84.38495405258672, 88.87478136247205, 84.77930914971137, 89.64142430213191, 88.93012600560343, 96.02955325957268, 73.34817317224318, 51.6379484053581, 97.17592085561445, 87.67800346497567, 84.54075059583111, 67.85923973206552, 75.72839290865006, 71.12883337082403, 71.69731032463812, 74.84352188725626, 79.14384380463632, 80.72300572549143, 81.0708022886707, 80.63781969008907, 75.11500481636294, 73.41934850139003, 70.89397753438642, 71.80061771023658, 74.15356912920552, 73.0926307555168, 66.97202313330867, 69.04003789347988, 71.64380919548773, 68.25552463531494, 72.13032430218112, 71.08327896364274, 70.54683992939611, 68.09663726437476, 71.15209302594586, 74.55042669850012, 84.5144707156766, 89.7877130200786, 89.69795350105532, 86.79081040043985, 86.05542875105336, 88.6518495313583, 91.33379367090042, 82.87895218018564, 80.33079224248087, 79.87968829370315, 92.67499323814147, 90.62907711152108, 96.0952372704783, 88.90033168177452, 87.85353737492716, 23.90665008175758, 0.6183536903512094, 0.9855794690309033, 0.6487195157716352, 0.6212850491846762, 0.2951927681363398, 0.6840486103488553, 0.5201113103858886, 0.6300452952423404, 0.12242929258894537, 1.140444204211235, 26.193686069980746, 46.37242532545521, 104.32323240464734, 66.60026088837655, 41.64583982959871, 42.216179909244666, 75.79189608173986, 92.05067742255427, 88.33730682249993, 99.85320521939187, 12.333610596195346, 0.5629508858246188, 0.22868493692048136, 0.19302003536253207, 0.23287139292205536, 0.12350078146424025, 0.26467829101508666, 0.1932923796196138, 0.149568141167683, 0.1736647933120689, 0.0854233158151469, 0.10669008513251621, 0.08478177846559594, 0.11096446504515987, 0.11040573413934439, 0.13595327254264586, 0.1973874719753381, 0.06499060940357947, 0.17048661627115744, 0.19457527045761386, 0.13988264475858983, 0.09646737722740059], [0.009237835803369602, 0.03868026193231344, 0.04078533365240982, 0.0323614806327368, 0.021552906987527688, 0.0600459217093885, 0.06656625308096409, 0.08243547331902289, 0.050484006773800626, 0.060390144165965824, 0.06383444099957425, 0.026126857922081987, 0.02503034478474048, 0.09197676899812876, 0.01866634323021337, 0.05266609714336453, 0.10383472222113803, 0.28519231765981645, 23.40721861008675, 62.664840990497225, 67.09022768082158, 77.73431654899352, 71.41902600565265, 40.23006816064158, 47.530481584610484, 78.12617701868858, 91.97386956983998, 57.02479823943108, 2.686666673229587, 0.08747639314782235, 0.07618974999434526, 0.14304257358514494, 0.045441792256409125, 0.2538318343220219, 0.21546204484278159, 0.11194782316564553, 0.07398555415772623, 0.4825938703312028, 45.90319610411122, 122.0046809411818, 96.56490971965175, 104.55123978276407, 91.79552724284511, 92.8615568530175, 82.19724424423711, 77.14581981781991, 77.27935298796623, 74.91643874875962, 74.03236789088096, 75.68385831771359, 70.01196199847807, 73.95218679981848, 76.98941138482864, 80.54851516600579, 73.90847590661818, 68.3678299380887, 64.49671337681433, 64.46111394513038, 65.63767986912882, 65.50125198979532, 64.19606762547647, 66.95387040415119, 64.98378938244235, 64.45995292355938, 59.822409152984626, 66.37485796405424, 68.36953224674349, 70.22508005942069, 68.14624740231422, 68.1772655056369, 64.21132172307661, 68.47782888720113, 69.07791229986375, 70.30230368337324, 67.11966899133498, 64.62071126507175, 66.3546734471475, 66.38240460426577, 62.97317458737282, 65.8013682211599, 66.86591517540717, 70.32488869082543, 75.32673435826456, 77.92638717159149, 77.66762056658345, 78.46209664498606, 76.06830550778297, 88.38657963660457, 67.61978687778597, 45.82923589214202, 85.95817750500095, 77.99332634095224, 75.0057589623236, 61.19156737481395, 62.7227508637213, 58.374948655405355, 58.39910261092648, 60.99287971373528, 63.442380274495775, 64.13729875318467, 71.47204860564202, 67.18660031595539, 70.47945360983573, 65.11538097935339, 60.508918070024066, 61.618242802158484, 63.628343766735455, 67.44735948501095, 63.36637258529664, 58.227149824942316, 59.55182052427723, 61.23041845137074, 62.756087087815814, 61.12438894087269, 61.57383764943769, 61.525196336930804, 62.811620004715465, 64.72222612750146, 76.76963313933342, 81.0597647390058, 80.08915070564517, 79.77484333899714, 79.34538302883026, 83.46850010656541, 79.47818663812454, 75.13635035484069, 71.64937111639208, 68.71391634787284, 77.01010580985778, 81.98447919661, 84.7264434445289, 82.91484971200266, 77.25685427265783, 64.94006279976138, 4.576499923583, 0.8553597823746744, 0.3403070424833606, 0.19556347791466022, 0.1928970322854096, 0.0693902829962392, 0.11202628589085034, 0.3346055403592125, 0.045579351004092925, 0.2409893355422443, 3.6229084864739454, 25.541264510923817, 44.02452199689804, 67.50076647727721, 37.29404464844735, 35.389200487444484, 47.68878452239498, 55.86005041676184, 68.19753631468743, 77.614072368991, 35.60106731230213, 0.5847957297678917, 0.0635481845857876, 0.03567157418376977, 0.015483720006511338, 0.1371581756299542, 0.0039024394373559667, 0.0076058616809126355, 0.007807642058093822, 0.04408675891857955, 0.06399013687886539, 0.03127272796606825, 0.09502744602580225, 0.08141961774878925, 0.04836336431664325, 0.033570984078030434, 0.059882687524922436, 0.012372652267766817, 0.027895823887158788, 0.08686887010210946, 0.042354971200468085, 0.1630919066167647, 0.01811139871396365, 0.06140192797888191, 0.0584343446779155, 0.03679106995883969, 0.04044002718141964, 0.05839009926984868, 0.028266608527290727, 0.0335655908190435, 0.033293426592624, 0.020279329863467047, 0.03721447143283102, 0.059695827188871564, 0.04708189074130309, 0.0734024922994356, 0.011948334361096064, 0.06273215922016291, 0.10863914304683286, 0.25891522606534345, 40.09597801393078, 87.23425003790086, 84.38928434925695, 90.4734060841222, 82.61174463456678, 64.92276514730146, 57.92398983432401, 77.9465481542772, 104.2008936789728, 66.29631642372378, 2.9642118705857188, 0.12446483416903405, 0.31542459863328165, 0.2778237469254002, 0.039856026865421765, 0.12142204018610141, 0.23429354322293114, 0.2355099376291037, 0.12859176513889145, 0.41453265795303934, 57.644422900292184, 129.7908446096605, 104.56497592310753, 108.44964427332725, 95.89633387904014, 98.04534558326968, 86.88160542518862, 82.37190738801034, 79.35245898462112, 79.73333681783369, 75.7349354220975, 77.37432141457835, 72.49970174604847, 76.37196756178334, 79.65714869960662, 84.48462147866526, 77.16871861488589, 71.3263011747791, 68.29704684595909, 67.80869607002505, 68.9080972056235, 71.8970609480335, 67.32801745014807, 70.22326792440107, 66.82768775570777, 66.08082925119709, 62.795346090870524, 69.17095092035109, 71.59730557472476, 73.1666458806684, 70.37779361970964, 70.78164869739165, 68.95351825221893, 74.45047686176916, 73.16384530836537, 74.61836999462497, 70.20319323385917, 66.21975960270052, 67.79849790757703, 68.95382419709237, 66.4955492942564, 69.67233965473791, 68.46834459612447, 74.65009412457867, 76.08896855385073, 82.31674317390689, 81.04864089719712, 82.74399126729658, 78.25270483570715, 91.66849736244448, 70.01671591112691, 50.01661316041024, 89.59532860786685, 80.50797354790473, 78.78117361376363, 65.21720570902671, 66.34421640826811, 60.00175168437343, 63.27894295415571, 64.16165667195474, 66.13951575371527, 67.31165332178917, 74.7400026936685, 72.79875893746653, 75.12722692181988, 68.4842929532451, 63.77632302622642, 65.79477079453008, 67.56637204077937, 69.58132497725948, 64.7104747064652, 61.99943050261467, 62.26772454477126, 64.66859163776522, 66.10367313508065, 64.99301087471747, 65.38363972017842, 65.61846025528448, 65.95794139369842, 69.65901144089239, 79.44740387701219, 84.27298607364779, 85.76766798573156, 84.33539882782968, 83.05062647788756, 86.31590550945651, 82.27722921679097, 79.56334913930586, 74.07605524986022, 73.71508736764231, 79.56288629962553, 86.7102841408022, 87.37253712069604, 87.89067437571865, 81.33790000792473, 74.27168738457465, 8.008264937708455, 0.6919924518273723, 0.5673161773912369, 0.6883107558373482, 0.637295428783663, 0.26892275519428716, 0.11111863257904207, 0.36413700409954597, 0.2946864759489414, 0.4434583912934027, 3.3774502383124445, 29.197735248073457, 42.45174961705362, 36.69254133778234, 32.17717939807523, 45.89820292688186, 57.035965227311664, 67.97167055068478, 76.18505877833213, 85.7667423063709, 54.83970857435658, 0.6503163494410054, 0.025499751753804666, 0.02593692174301513, 0.04441862054649861, 0.03756482642324221, 0.04714860167774943, 0.05405897522465356, 0.037465786576391234, 0.015990309052980475, 0.04551120748322818, 0.01775126652641883, 0.0598462064179682, 0.058555386569951816, 0.04784879837966254, 0.031157058265600956, 0.06562037198173423, 0.03547883795333966, 0.039666925722192374, 0.04057952413155187, 0.014446765417233111, 0.0653494373264332, 0.08378063944438774, 0.092104023863231, 0.16393464929874868, 0.11417813493960327, 0.13322124978707683, 0.2328904991548869, 0.13900869165457067, 0.23127077477833918, 0.1024367266725148, 0.15822283563113984, 0.13183122921374538, 0.25317474538760804, 0.17171698412106884, 0.2716239812153001, 0.1794324701111163, 0.14400186888392896, 0.2607280658858438, 0.4144272748981753, 54.234271126408736, 113.45225872532015, 102.77302542040425, 113.64140325976958, 102.29744588175129, 60.429156672570016, 72.69668317610218, 103.04824244591498, 114.21436740506081, 81.61663147710985, 5.796757128930861, 0.14400413650418484, 0.3247675311661536, 0.3396727216820563, 0.48318342095421213, 0.8734583337941478, 0.7374180949503376, 0.48738526000130566, 0.5935743006487048, 1.0243403923607644, 58.97161960601807, 129.53488642169583, 108.4033916842553, 114.17838358109998, 101.93346561924105, 102.84228663290702, 90.19786742425735, 85.97018780246859, 86.1417522738057, 84.88774699549522, 79.11837977747764, 84.72395666183965, 77.07519362049719, 82.23771525967507, 85.64327393808674, 89.88199895428073, 82.81132267367455, 75.02433530745968, 70.37936256777856, 73.4004819008612, 73.6619000281057, 74.05580013029038, 70.85645614131805, 73.88570262539771, 70.64346359622094, 71.83012177867275, 68.06084171418222, 73.56243656527612, 76.25951320894303, 78.72774308727634, 75.04108382809547, 73.27023567691927, 71.39652729034424, 76.02705001831055, 78.16988791188886, 78.77111665664181, 76.63355827331543, 70.42402267456055, 75.94802210407873, 74.81527297727524, 69.9157541028915, 75.5767854567497, 73.8813409497661, 78.90157468857305, 81.87166398571384, 86.71495176130726, 85.64150102676885, 86.04875287702008, 84.69209132655975, 96.47391857639437, 74.97711781532534, 53.732231278573316, 91.79478199251237, 87.03995150904503, 83.63337301438855, 69.43381247981903, 68.1020579799529, 64.63033283910444, 66.27897954756214, 68.29663891946116, 70.43826087828606, 71.75488287402739, 80.24415493011475, 76.5409746477681, 79.68953963248961, 72.32550928669592, 66.26767527672553, 70.39331836085167, 69.19479108625843, 74.07577283920781, 69.23687811820739, 65.17574625630533, 64.83007954012963, 68.76585637369465, 70.20544467433807, 67.70243906205701, 69.12604762661842, 69.08159932782574, 69.98364248583394, 72.92805594782676, 82.76720385397635, 87.50418755315965, 91.78023784391343, 89.0177046868109, 87.67709347509569, 92.37807766083749, 85.47579657646918, 83.8554968372468, 78.52101064497425, 77.7893630919918, 85.31694842923073, 88.6492843012656, 92.6359264312252, 90.88316825128372, 86.06739198007892, 77.30574269448557, 6.0063828095313045, 2.1520098659300038, 0.9288990749947487, 0.6588052777994065, 1.8435065039703924, 0.5083167432777344, 0.9857953832514825, 0.7778360358169003, 0.6907174363732339, 0.32717510036403136, 6.317105129841836, 42.98645104131391, 64.44153739560035, 90.54623665348177, 48.710154025785386, 49.60731383292906, 67.87421534138342, 80.64959464534637, 91.2468739478819, 102.66698022042553, 61.7917606138414, 0.7195988898315738, 0.11127375006195038, 0.17310507415283113, 0.14083775721730726, 0.2972893975675106, 0.14007637307288187, 0.13452660232301683, 0.12489236485693725, 0.12108778070297935, 0.14394383006278547, 0.11116415352350283, 0.21452536445952233, 0.13984996344774, 0.16009054266877715, 0.10681152539027315, 0.16550064026828737, 0.1434516032496768, 0.15677093047528498, 0.2015222630072986, 0.15163933647976768, 0.33755902381193253], [0.003715278651197291, 0.0644271210917542, 0.08804071649548509, 0.06409686441803653, 0.03543348171778264, 0.04251109991943644, 0.024557992207607435, 0.01386781170543644, 0.04688568030213637, 0.04435396272568934, 0.08619411518016169, 0.023474962217733267, 0.03250175133167255, 0.04137642794258652, 0.10932691380261414, 0.12189414953031849, 0.1561042960853346, 6.4221633634259625, 47.50994013201806, 70.95988119802168, 74.66639549501481, 53.064216336896344, 44.67822420981623, 19.58848922483383, 49.61971636741392, 56.95752959097586, 73.10259357575448, 33.97624115790091, 0.32849035075595306, 0.24678846791146264, 0.2140749200818039, 0.4157403189568751, 0.28945069399572193, 0.18668738404108634, 0.5741270667602939, 0.27675116254437354, 0.7714954631463175, 29.58301398061937, 119.35001296381797, 98.8246185548844, 106.60197257995607, 95.691421416498, 94.67864190378498, 86.34437407216718, 80.95651226658975, 70.57385721514302, 73.98953560859927, 71.12877061290126, 67.59593102239793, 67.3044910738545, 66.48420579971807, 66.1084976503926, 63.310255235241314, 62.834620783405924, 64.90622451228481, 70.19086914677774, 66.98386869122906, 67.02415927763909, 64.75076137050506, 66.63808822631836, 66.06358651191958, 66.57121965962072, 64.67195703137305, 58.328182235840835, 63.374064353204545, 67.4250804224322, 67.75976842449558, 68.55334235775855, 65.67970022078484, 64.4813023844073, 63.07705856138661, 70.42147313394855, 68.49624833753033, 69.64001147977768, 62.36690559694844, 61.382072971713164, 61.03448429415303, 61.931997114612216, 63.73063525845928, 66.5389463978429, 66.00187193962836, 70.62815066306823, 71.15798442594468, 76.20780852533157, 74.72839247795844, 80.37950023528069, 73.52209891042402, 88.19144956527218, 62.726618320711204, 50.382786027846805, 88.44890609864267, 78.59131520794284, 73.02338523249473, 60.11715565958331, 65.85038215883317, 62.84525825131325, 65.10441010998142, 63.79866484672793, 66.22910268845098, 63.70063304901124, 65.38029786079161, 66.36121596059492, 68.25561877219909, 63.6944043251776, 59.6590659695287, 62.41852006604595, 66.31530069535779, 64.26797251547536, 61.08661651611329, 58.55647594698014, 57.26323127746583, 60.154249514302904, 63.08866093235632, 61.42696449833532, 60.590020918077045, 60.67633267371886, 59.82872809133222, 63.523942039858916, 77.48607758552798, 79.99219755972587, 83.64706208628994, 82.9840010981406, 82.43926232860935, 80.16311091761436, 78.98088501345727, 73.24790954589844, 68.70493412017822, 65.48674314252793, 69.52575283665811, 83.42960588393673, 82.58245237411992, 86.38261718134727, 80.92849869881907, 82.0211612024615, 43.62880191495342, 0.6395901379085357, 0.9806253316421664, 0.18596459540628618, 0.15104963263917356, 0.2825364134004039, 0.04401560467217238, 0.3890685695073297, 0.14483259930726022, 0.03531518242051525, 0.10714457445447484, 9.917964992984649, 27.738225229324836, 69.06455270705685, 54.88616512667749, 19.89451450686301, 26.584022698863862, 51.41982147770544, 64.07254042163973, 64.29082816646945, 75.40027879899549, 11.416744801305956, 0.1983674210045607, 0.16195687074815074, 0.0211571651180425, 0.020311972869920637, 0.08437644900573839, 0.038476245057198315, 0.022274081092027408, 0.07588562074928515, 0.008939939641183423, 0.02564993754570042, 0.015403225233087377, 0.029533451738496943, 0.015688601603371002, 0.06272182852450399, 0.016716245351539507, 0.01677607107276638, 0.026923706191742135, 0.06633534651970671, 0.07252768117694125, 0.08524287146546188, 0.03673152194448537, 0.037178840683472734, 0.04763847660093058, 0.04394382606410692, 0.023601786158378088, 0.033088398481448816, 0.027681171796434832, 0.021341085591683948, 0.09593103907161182, 0.001890236606179256, 0.06340162813543312, 0.025966712987170588, 0.018054415178935856, 0.037622880566144185, 0.03840515975870433, 0.12861149956382092, 0.16281832129724566, 8.576143730071283, 71.48161918886247, 91.27625250047254, 91.16980721873622, 70.07772445678711, 61.34462610367806, 27.77676251626784, 48.2411366124307, 65.7517659279608, 81.96478889834496, 37.06945757712088, 0.334317613873751, 0.24208715485949672, 1.0078877655248488, 0.17076557952790491, 0.8829154747147715, 0.261773408180283, 0.8955911042228822, 0.16971044662979343, 0.6570451754716136, 40.175198124301055, 124.36756380142705, 103.1497141622728, 111.86441267690351, 101.00947287774856, 101.34705558899911, 89.9126091311055, 84.92551942025462, 74.16433211295836, 76.22972672985446, 73.13167402821203, 73.2287605347172, 71.06411426298081, 70.54545141035511, 69.54130111202117, 67.29221405521517, 66.7302639253678, 68.17290383000528, 72.92130947113037, 70.2717327302502, 69.80730056762695, 68.00257882764264, 70.25078727353004, 70.21261476701306, 69.0991166330153, 67.78469900931081, 61.826367685871745, 67.64462332571706, 69.31735730940296, 71.88068897493424, 72.58807274603075, 68.74037665705528, 66.80693057275587, 66.28490232652234, 74.39920363887664, 72.77685642242432, 73.41359830671742, 64.36394899122178, 64.8828471860578, 65.15709538613596, 64.24827045009982, 65.83582232075354, 70.68042801272485, 68.95336135741204, 73.83726135376962, 74.57303524017334, 79.93461716559626, 77.29053174295734, 83.37992514333418, 77.3828878710347, 91.62976003462269, 68.95507151080717, 53.37519361126808, 92.09465503692628, 80.9811447512719, 76.19149931015508, 63.44182329793131, 69.21764281488234, 65.03548622131348, 68.42737151730445, 65.09059159986435, 70.28764186366912, 67.50519091083159, 68.87855391348563, 69.37387866358604, 72.67323524721208, 68.94677962026289, 63.60454282452984, 63.40200731831213, 69.25358741514145, 66.03151721339073, 63.96919773470972, 62.06037629035212, 59.909964299971065, 63.15662776270221, 65.01718836445963, 64.6510233417634, 63.734298752200225, 64.77004374227216, 61.94119115029613, 66.0393854879564, 80.64556244880923, 83.41343787408645, 87.26245187943982, 85.61116541585615, 85.1564528865199, 83.64404186125725, 83.1681485329905, 77.24406734589608, 72.44850697055941, 66.93176392586001, 71.0332844334264, 84.68768258248606, 84.8515356740644, 89.15308137093821, 84.76456103786346, 87.33740837343278, 52.498135951257524, 1.0844824006480556, 0.31498906232656976, 0.41603710141874134, 0.21712162111315036, 0.4323472359007405, 0.24354073008702648, 0.6269561835835058, 0.8346777986134253, 0.17676783244936697, 0.2871157805765829, 10.683527319662034, 32.02530522500315, 52.90399143772741, 26.331690742123513, 24.61141174839389, 48.437011934095814, 60.599434606490604, 75.17558190130418, 72.5925442480272, 96.24110237244638, 23.62798921523556, 0.6906726968384559, 0.16342942963444418, 0.049318733414815324, 0.11473647514057737, 0.04393508500089088, 0.023858168973557414, 0.021537550755085486, 0.10917473043645583, 0.025117194257496346, 0.04536100062391451, 0.03205040680064309, 0.025807475866449457, 0.007627219733436622, 0.035676484807364406, 0.031580044136893366, 0.07810189013159083, 0.0010264164513735582, 0.10178931342858462, 0.04928530516823934, 0.049697303423477765, 0.1207385442009376, 0.16308893419561848, 0.22447267907761762, 0.22582148412062278, 0.08488245007972564, 0.13963849253712163, 0.12885677027365855, 0.07478930296436434, 0.22352789348411947, 0.19054794623967142, 0.2544090815729672, 0.12019237713708032, 0.1451968741152556, 0.1094110762219756, 0.1936692795566013, 0.31845012499440106, 0.26360880162927414, 11.428767846476648, 95.70310223487117, 114.72856660043041, 110.8695976195797, 85.11122795843309, 74.63056072112053, 31.60588029892214, 68.14371355118291, 79.4487061039094, 98.2393224777714, 49.19716727349066, 0.64735158917404, 0.3673913456018894, 0.6788332676214557, 0.9090178063319576, 0.8755559438178617, 0.5837493149503585, 1.3564876178579948, 0.47908074432803743, 1.0252300962325067, 39.15811184913882, 127.07872959875293, 107.34931745836812, 115.35702443891957, 103.76235700422718, 105.0758332590903, 93.93205796518635, 92.63378481711112, 76.14606257407897, 83.10572008932792, 78.6793488840903, 76.39988699266988, 74.84358464517902, 77.04869408761301, 72.59725109223398, 72.06012172083702, 70.48372899332355, 71.00622007923742, 77.90180175535141, 74.23952394916166, 74.77844976609754, 71.58953143704322, 74.77510006197038, 73.60576306619953, 72.20406486142066, 73.13170540717341, 66.44942222102996, 71.3907535614506, 72.44217626510128, 77.13373107294883, 76.00181348862188, 71.22132285948723, 70.54827551687919, 69.41495372403052, 76.91550608604186, 78.4788530103622, 78.68788396158527, 69.94358724163425, 69.28626860341718, 70.13568139845326, 68.1538018872661, 70.8039826731528, 74.02693933056247, 74.37311987723075, 76.24506319722822, 80.40694113700621, 82.97745858469318, 80.51349624510735, 87.19279842991983, 83.92900989901635, 95.64266635525613, 72.03129230007049, 57.661465598690896, 96.68265142748433, 87.91729942444833, 80.47035017321187, 65.79416282715337, 72.31418148163827, 69.2283744196738, 71.24989340382238, 69.23940412459835, 75.04804211278116, 71.29969966027045, 73.45566964918568, 73.93066083231281, 75.92152257119456, 72.72723059500419, 68.03329883083221, 67.40852017556468, 72.85444090443274, 70.45547223860218, 68.61856352898383, 65.28458418384676, 63.342791295820675, 67.00265684435445, 68.9832341286444, 68.81067337528353, 66.66647049688524, 66.75109171098279, 64.42671475871917, 70.85809569205009, 85.66734160146406, 84.62992175932854, 93.16752526067918, 89.58483234528573, 90.51759550648352, 87.73654876216766, 87.23844697398525, 80.83537378618794, 75.7574890505883, 70.9686202387656, 76.79533250870244, 90.66397051657401, 90.16009499949794, 94.60221059860723, 87.95347152217742, 92.96274615872292, 51.59116629631289, 2.149512787019053, 4.132718059324449, 1.537706758226118, 0.25168525595818797, 1.2928340463869035, 0.3793671384694115, 2.0019113008053075, 0.573256116720938, 0.2721348392867273, 0.4010823909794131, 17.62827688647855, 44.710430791301114, 91.36382333693966, 76.39601953567998, 29.357412976603356, 45.378108409143266, 69.82104455271076, 88.75420770337506, 83.59334130440989, 111.896223099001, 24.754562570202737, 0.7165828936042324, 0.20159954595710003, 0.18092813420920603, 0.1952314247647601, 0.15461970961862995, 0.08141955646175532, 0.10453910942399695, 0.3247371940843521, 0.15226342234640353, 0.11804039785338026, 0.13903715948183692, 0.1254711519446104, 0.09981010229356828, 0.16500424593687057, 0.1632908749724588, 0.18845203693114942, 0.18584709284046005, 0.19355058189361327, 0.22027932828472507, 0.20179776354662834], [0.06175341677942103, 0.036316616385574305, 0.08689540738780653, 0.03438722011783431, 0.05552430990182104, 0.03758459149168865, 0.04503646279655157, 0.01279507506443488, 0.08023967380605398, 0.01800405830445309, 0.05216977175986094, 0.05492353226028143, 0.06076788296923042, 0.010347875180624185, 0.06890273698034786, 0.021422040017862475, 0.08807412558986295, 14.281944036483766, 68.41322745046308, 66.864408985261, 62.70763404907719, 46.99686273451775, 46.010367024329405, 49.378937752016135, 97.81590261766988, 66.8151597053774, 51.414110506734545, 4.425284708699873, 0.14182824761636798, 0.09893588871965486, 1.5378933159574386, 0.5265539872550196, 0.17546145335560845, 0.23546694477479305, 0.15902739649097766, 0.45047836137875436, 10.059114425413071, 108.17060685926869, 97.78962273751536, 108.14088313810288, 96.17947409229895, 97.88743880487259, 86.9972525873492, 85.31835263775241, 70.49447628759569, 76.80231432760917, 71.42410155265563, 72.3114279777773, 66.06624587889641, 67.85200688146776, 65.61157257326188, 67.64535288656911, 67.07807617802774, 70.49823391822078, 64.24046101108675, 64.25712716194892, 66.0663321710402, 65.88478134524438, 63.60285620535574, 68.40745372156944, 65.56846180269795, 66.83746230217719, 56.77033839687225, 63.17110130863806, 65.36276878849154, 65.91360292127057, 67.00253917324927, 68.96082170547979, 62.07492043895107, 65.92213799876552, 69.28677066679924, 71.90641972326463, 69.56983243265461, 68.87099942853375, 62.69844393576346, 61.53950122094924, 57.769734782557336, 63.4647770081797, 61.81774631623299, 66.24329382373442, 63.69431803303381, 69.17632456748717, 66.14747816516508, 70.2794127310476, 69.68300065686627, 74.59495344469624, 70.09442590898084, 86.3444289853496, 62.11352048381683, 55.13444331384475, 85.22457661167269, 71.54761698938185, 68.25824676021453, 67.08606212369858, 74.25706478857225, 72.0472720361525, 75.13704069199102, 71.56563635795348, 74.71883758421868, 72.46003873886602, 70.6743718731788, 67.94044848411315, 69.33347040607084, 61.234999779732, 57.07257663050006, 60.86674021136377, 62.00721640740672, 61.4165388384173, 60.891494289521255, 60.53256996216313, 56.7218186778407, 55.61159572293682, 59.19322175364341, 57.090592076701505, 60.543666347380615, 59.10792196950605, 60.7881437578509, 60.97978684210009, 68.77429731430547, 72.33946507976901, 78.09954412521856, 79.66781754647532, 81.34245780206497, 78.28434267351705, 75.56910545595231, 69.9796102892968, 68.14781635038315, 62.618506031651656, 63.81819432781589, 69.86112333113148, 82.71362427742251, 78.47510322447746, 86.97352224780668, 78.20438907992455, 87.38191943014823, 13.823912201389192, 1.9003972963940714, 0.2504163538856853, 0.6270837219011399, 0.12437829687710732, 0.3281311168064994, 0.2799246970924639, 0.5216555597801362, 0.09591106715942584, 0.03214331794409983, 1.0287501783140245, 23.099418455554595, 28.38428274277718, 67.57093767965993, 37.40762079915693, 17.863130761731057, 37.774409478710545, 53.39367189714986, 63.45039367675782, 78.41157651716664, 53.375224990229455, 2.8248402524378995, 0.1991466856411388, 0.0901434516474124, 0.01607694689394726, 0.04946759195938226, 0.07750924451336746, 0.054358048289413416, 0.07699054170159564, 0.03079370467833454, 0.024994434413289832, 0.026904266710663517, 0.019031087267062357, 0.06598894454298482, 0.05618998285142645, 0.018379008547673305, 0.0544490518739387, 0.048624619451021, 0.021909354292156718, 0.037304758725147096, 0.05817581298610857, 0.032351900703243675, 0.017552596945015174, 0.042040787051401796, 0.02640303453400491, 0.03386319299498874, 0.02412239461386156, 0.07478785505818744, 0.06489414361215408, 0.04991301846119666, 0.011272351783249649, 0.028459082372606765, 0.02614510996687797, 0.038545553031707966, 0.023365195224722548, 0.03533643369953479, 0.03097146388984496, 0.061500056181103, 22.591695093339492, 97.86948219422372, 81.11366594991377, 78.37419632942446, 56.93351291841077, 63.636831775788345, 51.54997356476323, 76.95549072757845, 70.50429790250718, 59.875165031802275, 4.192330241203308, 0.20277762064530006, 0.4806472102720892, 1.7950713610456837, 1.1197214645724143, 0.9253631195714398, 0.9678024293914919, 0.4875725225335168, 0.5314614239238924, 16.100965757523817, 118.64631622068345, 102.57126654348066, 113.04954113498812, 99.61493692090436, 103.58389700612715, 92.16375150988179, 89.06042714272776, 75.38880194387129, 80.68360159474035, 74.58837955228745, 76.45767919478878, 71.44893015584638, 70.71410548302435, 67.22835002406951, 70.01217380646737, 68.39043063502159, 74.4861468961162, 69.68694656125962, 70.18762926901542, 69.66419681426018, 73.34628258982013, 66.82535786782542, 71.1355092448573, 68.48801920490881, 68.99102395580661, 60.9295726591541, 67.47798535131639, 68.2151242225401, 69.08720831717216, 69.02825509348224, 71.38060246744465, 64.31998706633046, 71.5721082687378, 71.55745429377403, 74.7825054968557, 74.55308606547695, 72.17253684997559, 65.39775633042859, 64.13744388088104, 62.49723026829382, 65.19705649345153, 64.86541225064185, 70.07002092176869, 69.39799339540544, 72.27844084462812, 70.73983623135474, 75.40285971856888, 73.31102048197101, 78.0811482091104, 72.78925111216884, 90.10282839498213, 64.45932142196163, 58.06781138143232, 87.04936519745858, 74.00989270979359, 69.87634997214042, 69.16221187960717, 78.88506935488793, 76.81640348126813, 78.99422107204315, 75.5633552612797, 80.25031305128529, 76.07438518155006, 75.31000152710946, 71.95321359942037, 72.99763879468365, 64.39623794248028, 61.041426889358036, 64.36678094248619, 64.56801814417686, 65.07249770625945, 64.49686634925105, 63.13622359306582, 61.22927704165059, 58.83091242082658, 61.55109574717861, 60.49760987681728, 63.56196157393917, 61.889047161225356, 63.26457531221452, 63.28507754110522, 71.09698372502481, 75.78256084072974, 82.13249375743251, 83.94446403749528, 86.2522219073388, 80.7404524280179, 79.00782385180074, 72.67606719847649, 72.55400303871401, 65.2584102076869, 68.18574566994944, 72.20360202174034, 86.1169550495763, 81.69369820625552, 90.7996060771327, 81.27009007238573, 95.54136722318589, 19.099932524465746, 1.3150052437859199, 0.24845120046407948, 0.9259753770405247, 0.41495299507533356, 0.40295443407470183, 0.26817977248180297, 1.0836935139471486, 0.45200413273226836, 0.12207961941678679, 1.0335240705359368, 25.060060293443744, 35.67128166075676, 44.75662454482048, 31.52986280379757, 29.236035231621038, 44.375793780049975, 64.21986856768208, 72.0699982489309, 84.05953853361069, 68.46809356443345, 4.068973170172784, 0.18058529454133204, 0.07017689441601116, 0.023048720472762664, 0.09070847213508622, 0.09632747425066848, 0.04329886047109481, 0.10555101964142054, 0.07706970922769078, 0.024682157823155006, 0.05246187342450984, 0.025496926804583882, 0.061022791065155506, 0.05052363650212365, 0.03176679147497541, 0.08175568519941262, 0.04879150021400663, 0.06451861497255103, 0.04664402552730134, 0.03711332484418827, 0.176028358419576, 0.16457900585186097, 0.1799367245046362, 0.2157997363998044, 0.14252465218305588, 0.10769991159078576, 0.1504527888591251, 0.1414015672860607, 0.1288343698627526, 0.1325574346006878, 0.18348663804992554, 0.14152594932144688, 0.20151486259795007, 0.12880876720432313, 0.19461126126829656, 0.10875646941243641, 0.25083669100797945, 32.16223712890379, 122.05246325462096, 100.46795045175861, 97.92010430366763, 73.44109412162535, 68.5866746594829, 69.15905829398864, 128.74600364315896, 87.33529813828008, 80.90406233264555, 6.5735693035587195, 0.14626299271420126, 0.512472647692888, 4.34076988889325, 1.9304676570238608, 0.5014277742274347, 1.0434200879066222, 1.400912259855578, 1.3733795501532093, 14.646974513607642, 120.18958060972153, 104.30395003288024, 117.92667112042828, 104.91532987163913, 109.31123995011853, 95.59187950626497, 94.48340985082811, 78.87813460442328, 86.17811264530306, 79.7492616407333, 82.55137935761483, 74.26886327805059, 76.75660302562099, 73.43819941243818, 75.25121304296678, 74.20579156567975, 79.5396972471668, 73.70339870452881, 71.8591865416496, 73.12998740903794, 74.83941124331567, 71.27952298810406, 74.41962349799373, 72.489425136197, 72.52050599744244, 66.06987014893564, 70.97765737964262, 73.42241579486479, 71.91333878424861, 73.05386204873362, 77.81838078652659, 67.83834134378742, 74.15880941575574, 76.78440478540237, 80.05119785185784, 76.86730800136444, 77.6453571934854, 69.94808227785173, 67.21531206561674, 66.55484768652147, 68.74252611590971, 68.8544705606276, 75.54583795609014, 72.24964280282298, 78.05530763441517, 73.84442360170426, 78.32260931691816, 78.93914315008348, 81.92899334815242, 77.38293493947675, 94.17886918590915, 70.54778129823747, 61.81779730704523, 90.09692130550262, 79.97566869181972, 75.36958233002694, 73.75803732102918, 82.13006188792568, 80.56873890661424, 82.80402706515405, 78.98585073409542, 82.97865882996591, 78.89641284942627, 78.43295343460576, 73.71711915539157, 76.74435738594302, 68.06069266411566, 64.45585796909948, 67.45896970072101, 69.05480953954881, 67.19537073566069, 68.81608624612132, 66.16520727834394, 66.23147180003505, 63.24601073418895, 64.78177947382774, 63.68045245447467, 65.47629787075904, 64.13313711843183, 67.36891208156463, 67.70077597710394, 76.3474605929467, 79.23215989143618, 87.2212669926305, 88.30715948535551, 90.32400300425869, 85.23240566253664, 83.13718534285023, 76.14899650696786, 77.21736384976295, 70.3101013552758, 72.30204566832512, 78.3682970846853, 89.7036252483245, 83.83679497626521, 95.3705244679605, 85.10418338160362, 101.71876292074882, 15.444537497335865, 4.412049651145935, 2.5971214136769696, 2.2413146351614306, 0.400362758626861, 1.2979245474261623, 1.1418360327520678, 2.694054947745416, 0.4311890641768133, 0.14790306438601789, 1.9408156049828378, 39.80331820826377, 44.451099364988266, 98.79946047259916, 52.13451654680314, 24.17645815880068, 54.23751100417107, 77.63093071599161, 86.14285053745394, 101.36108982947566, 82.54493882579189, 4.715608742929274, 0.24122876866209894, 0.15536810091185957, 0.14219940189392338, 0.1321506112693779, 0.1624559770308195, 0.10895955166028393, 0.22875264377122928, 0.1286579244920323, 0.13389378305404417, 0.15733156894003192, 0.1630381425662387, 0.12983023819904174, 0.1432126451043352, 0.17594975779854483, 0.2206211107512636, 0.10875456185350496, 0.1049911855689941, 0.15834387752317614, 0.11833839839504612], [0.04431733989246911, 0.010195640103530981, 0.07539336329265948, 0.05302498252281258, 0.027135452894013257, 0.012284427667186867, 0.018422240804460262, 0.057323685727052154, 0.033961646784577644, 0.03492440863121902, 0.07908116500344008, 0.03420179236620184, 0.10544817233758588, 0.04425747012118659, 0.0383447345736767, 0.14585693547081563, 3.2960478192375553, 60.20231816076464, 75.00017350719821, 78.9367897279801, 61.47173835385231, 47.775872907330914, 22.79587603384449, 51.9237675974446, 99.4113031510384, 83.61923679228752, 26.041880538386685, 0.04695854292461469, 0.10133580469916906, 1.6931555588399212, 1.1228619347656927, 0.3097340975317263, 0.9356890041981974, 0.45905238678378446, 0.5511169111536396, 0.45081197734802003, 76.75151178913733, 101.63458885685091, 100.41034652340798, 100.75200065489739, 100.5679944253737, 94.62946322656448, 84.93975762398013, 72.16446461216097, 74.02226386531707, 72.40442737456291, 73.8099616573703, 73.11245441436768, 66.73255458954843, 66.84540117940595, 63.345662470786806, 66.01445490314116, 67.2542376672068, 64.08753956517866, 66.50367644525343, 67.14998106802663, 66.76890711630544, 68.23256308032622, 64.99917291825818, 63.97192378197948, 63.114470128090154, 59.439966294073294, 61.374314523512325, 63.65060713983352, 64.07130879740562, 67.77884683301373, 67.26202749436902, 63.01881136432771, 64.35265648749568, 70.45634300478044, 73.43023700098838, 73.91791312925278, 70.20546036381876, 68.49671902195101, 61.60054114557082, 61.35938206026631, 60.61224898984356, 61.841998331008426, 61.57852488179361, 62.19361136036535, 66.12199060378536, 65.36448286425683, 67.28899771167387, 69.93276149995866, 67.89189738612022, 72.10710387076102, 73.19875440289898, 86.55430716852989, 58.51360444099673, 59.608157527062204, 87.37423942935082, 68.1982344965781, 68.26000398205173, 73.04721755366172, 78.52920055389404, 74.64321428729643, 79.88259084763067, 77.94202173909834, 80.7848144346668, 74.78707898047664, 73.73350681797152, 69.20603259917229, 67.14568999505812, 61.25467831088651, 59.92567731488136, 62.94167011014877, 65.09394130399151, 60.32592381200483, 61.0457532636581, 57.24586694471298, 57.128168382952296, 53.13904339267362, 57.35418319702149, 56.8066870012591, 58.61035362366707, 58.923751000435125, 58.979887962341316, 59.69775230653825, 64.03870605653333, 62.06748362510436, 66.7450826398788, 71.2687913833126, 75.8065971251457, 74.76087754772556, 72.84936535742976, 69.12207818800404, 64.82115614798762, 59.601968026930294, 62.8957744567625, 61.99562188117736, 72.37650794367637, 76.45468250397714, 81.88454504935973, 80.26400996792702, 89.6442876323577, 72.05026088222381, 0.31487534423508956, 0.39719035788889856, 0.2452796117793168, 0.14914864674210548, 0.19900738021298764, 0.49455535267629935, 1.175383084243344, 0.5361126195038519, 0.16713032378785073, 0.3700266574178973, 7.8586172000054395, 27.338080713825843, 34.096175470659816, 58.347488141828975, 27.33520365530445, 30.711681881258567, 42.35248619510282, 62.28109982705886, 61.08996229787027, 62.40478784807267, 14.882608940524442, 0.8421916502618021, 0.08696117603610601, 0.056614223191694873, 0.02035169644401439, 0.02688291584021382, 0.010145070639649227, 0.07948470181755482, 0.02797905934013186, 0.1060035631000515, 0.02237331437607927, 0.031879341282371076, 0.01334136565996995, 0.00862854979782095, 0.09679553865064537, 0.021554644091895992, 0.016591878637911815, 0.047793276157350316, 0.046958780411871216, 0.02843880977091049, 0.03591221772254475, 0.01590295875024411, 0.01628253424930717, 0.026023966568191687, 0.025446997024118904, 0.006085762729673016, 0.007858717618810554, 0.1172099355608225, 0.013141387983435586, 0.015847508348674787, 0.08878346172071273, 0.04862715137161074, 0.0559264907403098, 0.03989162697126308, 0.05237116095339579, 0.2476680900661215, 4.429913595799477, 79.29596900939941, 92.7477139811362, 95.32792752788913, 77.38238580765264, 61.62914699123752, 38.04827328651182, 58.50839553340789, 78.58414511526786, 95.46237853265579, 28.20218670752741, 0.06991841635035892, 0.09583543129866162, 3.18825128097688, 1.8838410944707933, 1.3338687799630629, 0.7911370382193597, 0.9119912080707089, 0.3602541640641228, 1.0779897748462617, 91.97387741458033, 106.14900158297633, 109.36399582893618, 104.0363580949845, 106.12239222372733, 98.27235667936264, 89.06810714352517, 75.04635549360707, 78.32222492464128, 75.92016543111494, 79.99840274933847, 74.60384938024706, 71.9881776071364, 70.83356518899241, 67.4206324546568, 69.96530148290819, 70.61879188783708, 68.31960831919025, 71.3963782402777, 69.80040504086402, 69.55399390189879, 71.65472122930711, 67.63637850361486, 67.80311845964002, 66.05740485652801, 61.40645442470428, 65.21086323645808, 66.72209755066903, 68.91361990282613, 71.0419136478055, 70.67810596958284, 67.12873751117338, 67.92896378424861, 75.14445397161668, 77.58532139562791, 77.59936348084481, 73.35478628835371, 71.43893595664733, 66.22343878592214, 64.53747857001521, 64.71558555479973, 65.63869968537362, 65.52253869272047, 66.89584285982194, 70.38690136324975, 69.63510851706229, 72.90872650761759, 71.85193800157117, 70.29678883091097, 77.09930835231658, 77.31416794561571, 89.37736249739125, 60.52292877627958, 62.65536454416091, 89.7795388006395, 70.54425900982272, 71.96269004575669, 75.92890447185886, 81.56704487339144, 78.16849154810753, 82.36017165645477, 83.70334025352233, 84.44117730663669, 77.82181678279754, 78.48869815949472, 72.90405104237219, 71.37648397876372, 61.895950532728634, 63.45415522975307, 65.35421017677554, 68.17123290031188, 62.91954402000674, 62.93662986447735, 60.52447419012747, 60.24787256794592, 56.94018879244405, 57.30716182339577, 60.97629593264673, 60.21224567967077, 62.57994913285779, 62.08297306491483, 63.458571818567094, 65.41264172523253, 65.58689302013767, 68.33696872957292, 72.1248016049785, 76.78788785011538, 76.5892433351086, 75.35676402430381, 70.74907733548072, 65.74495669334166, 63.19650650024415, 64.5716973273985, 65.99008913963073, 72.44540045338293, 79.18131028452228, 83.90063547318982, 83.89172384815832, 88.97587653129332, 81.68601036071777, 0.6378206586645496, 0.8291110973204336, 0.07991817734775045, 0.6576986178275078, 0.753593826966901, 0.35507620642742804, 1.4974393383149178, 2.1652718897788756, 0.5526851237781587, 0.7519050014595833, 7.950218271824622, 34.081313610076904, 36.29567984611758, 42.66975887360112, 30.39070256294743, 46.00058855548982, 52.95650412959438, 72.8394260714131, 72.68641441099106, 80.95946188895934, 31.020399870411044, 1.4678479971424228, 0.10389864459753999, 0.05697061112450977, 0.04778210276497468, 0.034783781701398474, 0.03126331849113828, 0.03309951824766975, 0.07134949923643182, 0.04894385978038754, 0.07092351604613566, 0.04017712878844431, 0.03903938479901802, 0.03186866010148679, 0.07901558787712167, 0.031035937849552404, 0.0564377969731727, 0.006216046036100917, 0.08693017245781037, 0.07773809795898777, 0.12942828718693028, 0.18320025906207102, 0.11462387553746663, 0.14025972855667915, 0.1853585738929049, 0.09760053618060005, 0.10255013066794604, 0.17521713259479693, 0.06172070865549388, 0.15383577184571376, 0.3043454963593714, 0.1638267687972515, 0.23393004982461854, 0.2138878720542116, 0.1681803851839035, 0.2998348319482419, 5.74172382393191, 98.2532939603252, 112.3209765649611, 115.98774940736833, 95.16898524376654, 75.34790731245472, 36.12191100274363, 73.30580372964182, 117.90789865678357, 110.3718880684145, 40.96213540723247, 0.220878301789203, 0.23725640359184436, 4.706400488653491, 5.528185579084582, 3.2794461423350922, 2.6062301378096304, 1.199604087779599, 1.09658989935152, 0.6023058643744839, 96.25856476445352, 105.80257000461702, 111.67904146255987, 109.26559925079347, 110.8897586022654, 101.03175978506766, 94.7581091234761, 79.55926202958631, 86.62446268143194, 78.41715412755167, 84.50417057160409, 81.15496850782826, 74.66956477011405, 75.6718558649863, 72.63529808290544, 73.27475424735778, 76.42651204139956, 71.81618951982068, 76.25147235008978, 75.22642366347775, 74.90925296660393, 74.70254405852288, 70.48907910623859, 70.65416382205102, 69.69336355886152, 67.74687167136901, 69.79631008640413, 69.44169644386538, 72.79769989752, 74.18478335103681, 74.79854799086048, 70.35255709002095, 71.34447743815761, 77.96631689994567, 82.3688244050549, 81.05314377815493, 78.91816631440194, 75.43940836383452, 70.95896336340135, 68.52063763526179, 70.33163516752182, 69.53931639271399, 70.44066921357187, 69.60002683824109, 75.30637725707024, 75.47929102374663, 78.47232618639546, 76.20037171148485, 75.53181156035393, 80.35365181584513, 81.2423667600078, 93.26482357517366, 67.02455935939666, 68.43250982223019, 94.38014168893137, 74.21257726607784, 75.51671043519052, 79.51361348552089, 86.41277236323204, 80.76007996836017, 87.01090243554886, 86.49928415975263, 88.46141845949235, 81.62801419534992, 80.13414029152163, 76.67519815506475, 75.70007339600595, 67.28785237958355, 65.3959559625195, 69.34603768010294, 70.99204463343467, 65.96662552125993, 69.2023063475086, 64.01833326585832, 64.06489964454406, 59.67591254941879, 63.62600211174258, 64.69263968929168, 63.58097330216439, 66.26012079177364, 65.21032587174447, 65.66917650161251, 68.8914506666122, 68.92399849430208, 74.55382347106934, 77.08052804393154, 81.72769731090915, 82.15198793718892, 81.62739446086269, 77.45447112667945, 70.04876952017509, 66.37931377656999, 68.22703253838324, 67.50497910284227, 78.53085579410677, 84.35107261903825, 89.14662514963459, 88.03318192881923, 94.70007373440652, 82.00695437769737, 0.4133901144227674, 1.6618154534409124, 1.3812404702748022, 0.9146663258152624, 0.7168239355087281, 2.0383359011142486, 4.988222295238126, 2.8118871152400975, 0.5323318836669768, 0.8386109553037152, 13.785533770438164, 45.63090908911921, 49.337313559747514, 80.75698914066439, 34.82896051099224, 47.9257623610958, 62.39666854181598, 89.1615693799911, 86.89913841985887, 102.72131289205244, 36.29266746582524, 1.4902351700490521, 0.14912954050927393, 0.14214116388991957, 0.19016199114341892, 0.10981813704054202, 0.15599949525729304, 0.18082417607788118, 0.12424440769058083, 0.1311552179076018, 0.22535050858653363, 0.13193708724312245, 0.09681665969471778, 0.15969786132054944, 0.3456898826745249, 0.10876750107854606, 0.12636942067934623, 0.21270875548643453, 0.16033598191795811, 0.13111674497204442], [0.01727548570582463, 0.044306752557355555, 0.02641062263489491, 0.0477042529101093, 0.01864222486713721, 0.07885896886188178, 0.05325116232157715, 0.10465291944602806, 0.019120210105733528, 0.0629431321736305, 0.07257582980298227, 0.042497007732069304, 0.029144742556156653, 0.06069569833456509, 0.0917796009490567, 0.28000198004226534, 15.916968353333013, 69.41685215119394, 65.86619715536794, 72.42870684592955, 49.86884963127875, 36.37303683065599, 25.472026832642097, 71.25136037026682, 95.73457533313383, 64.7530520346857, 3.940589336618301, 0.019233447477041234, 0.6353077064118078, 1.6844808694816407, 0.9593284550693728, 0.17501644820215242, 1.7551673732457624, 2.8159627029972696, 0.8554313043432852, 32.58821633554275, 116.59911355664654, 94.21399793317242, 106.04853399338262, 94.47266255655597, 100.17762445634412, 85.79863117587182, 77.14734954218711, 68.09798655971404, 75.29715968716529, 73.18333948812177, 78.25749797205772, 68.1250979823451, 67.76060781171246, 66.39512877310476, 65.03358387177991, 65.3848046641196, 63.10761774739912, 64.86171737793954, 64.39366094527706, 65.07708687936106, 63.0631184577942, 62.881650001771995, 65.94629195428664, 64.20227673745924, 59.80527231770178, 58.902479986990656, 61.39930394388015, 62.632289240437174, 66.51504347401281, 64.5518462119564, 65.01958101026474, 61.7055743740451, 66.19770803759175, 77.25756029928885, 77.71880749733218, 77.17363726708197, 71.51611251215782, 69.84099372740715, 63.96783274988975, 62.0855422173777, 57.776312597336315, 59.47012147595806, 60.08866748502178, 60.41342404580886, 58.78064724706835, 66.21761014384609, 66.37714862823486, 70.56012107479957, 64.60318611514184, 67.59580550655242, 71.83857840876426, 84.99651432037354, 56.710275142423576, 63.66434720254714, 82.79301304971018, 63.510394173283736, 65.70810994794293, 73.06247557363203, 77.7354383468628, 72.69820505572905, 77.94186484429144, 77.52871374930106, 77.76085530557941, 77.37492545958489, 77.38935193707867, 72.66628480726673, 64.07474479367657, 57.07926034927369, 59.43782467995921, 59.900731040585434, 60.360236706272254, 59.57933202866585, 58.28019988152289, 57.52157818886542, 55.496203514837454, 53.12515820226362, 53.51856800817675, 55.75469555393342, 56.55783222567651, 57.49432948327834, 59.48696413347798, 58.975467451157115, 58.47127814446726, 59.65948958550731, 60.05568819661295, 59.70010180627147, 61.23471344670942, 64.22286525849374, 62.31912328350929, 64.18362194491972, 59.86849308013917, 58.94393943971204, 57.29105657146823, 62.531166615024695, 59.857981128077355, 69.29900061699652, 75.60254758404147, 85.63115381425428, 76.04450456557736, 101.11012089637019, 26.74503795562252, 1.322517685832516, 0.2030910272151232, 0.4071313292989808, 0.3052832799092416, 0.8125476635271504, 0.14412497921336082, 1.1664149525665468, 0.09466333975715023, 0.05765158668040268, 0.08362763636415044, 21.90284844367735, 24.875552000537997, 57.76463177896316, 45.18633588667839, 18.485208865134947, 48.67426041633853, 47.10969363489459, 64.80917722948136, 50.38730852065548, 45.283842086792, 11.26615422387277, 0.46345821972335544, 0.026926090640406457, 0.10943181422208587, 0.06308965031958877, 0.03549473810820811, 0.014928426920256067, 0.021722047709889954, 0.04735070333305386, 0.007459161110267404, 0.02076892133411621, 0.04816880862739298, 0.035948637542465044, 0.013363716275160833, 0.050408462843587326, 0.08064523309228883, 0.025242263856794567, 0.029075894234401566, 0.05422178039988203, 0.03572454533329414, 0.049107955813768416, 0.014625199743726803, 0.006900727542327538, 0.05834112326884943, 0.039025147054945274, 0.016460959957311713, 0.039998270240762544, 0.03813190385699272, 0.023072731583529425, 0.053963030373016675, 0.03508299649242432, 0.032395142536129684, 0.0871724707465018, 0.13633103049810857, 0.27055409346376696, 24.04544903386024, 92.24847470560383, 81.63805546299105, 87.49299310868787, 64.34966371905419, 53.97140564457063, 33.60241574625815, 58.77235535652407, 91.84777321354036, 72.82608216808688, 3.386637409848552, 0.01989883122845523, 1.3972626169843059, 2.6068368794456607, 1.426491996934337, 0.7709756878114516, 4.838492678057763, 3.8794363987061287, 0.9559590778043194, 42.74148725694226, 122.60754139192643, 99.62004384686871, 111.09921316946708, 99.176816017397, 105.76158908105667, 87.85864430089151, 80.20530777592813, 72.90030125648745, 79.14953124138617, 78.35904029107864, 82.96499329228556, 72.80847072601318, 72.72754438461797, 69.53814752640264, 69.99851611352736, 68.91103898325275, 67.85439168253254, 67.99709535414173, 67.44688880059027, 69.25049658744567, 66.16048474465647, 67.75466149853122, 69.59079357885545, 66.72463140180035, 62.10168277063678, 61.876142563358435, 64.76329726557579, 66.38382450226815, 67.06332806617984, 68.38790462863061, 67.83477983167096, 65.27198945322345, 70.1751482871271, 79.35380043522005, 80.58286728397493, 81.05293197016563, 75.6259641339702, 73.36581599327826, 67.17868497294765, 64.19596172148182, 58.31744278630903, 63.123060118767526, 61.116077438477554, 62.73899732097503, 63.01999984248992, 70.95089897032707, 67.33022182218491, 73.22878406893823, 68.19130759085378, 73.1051980295489, 75.18334819424537, 89.42198338047152, 59.697152183901885, 68.30522106539819, 85.42460180098011, 66.5782642364502, 67.46966208181074, 76.95381979788505, 80.25000710641184, 75.43849052921419, 81.8409675167453, 78.95810388749646, 79.27227789355864, 79.67374032543552, 80.11207303693219, 74.8756931674096, 64.19897410177416, 60.20587182814076, 62.43691598215411, 64.28785108750867, 62.07062152124221, 60.54431746082922, 63.81171457229122, 59.733414496144945, 59.37591398915937, 56.45067307256884, 57.0918119338251, 58.30163955688477, 59.74496195393225, 60.74396218022993, 63.33851983470302, 62.8431676280114, 61.191296731272054, 63.420348321237874, 62.61497982086674, 63.949130888908144, 63.25700906015212, 66.47640028307515, 64.68368099581811, 65.64117077858218, 62.60512682699389, 63.17393325990247, 62.04922106958205, 66.01272121552499, 62.394071932761904, 71.59030806633734, 76.68273695053594, 89.82035498465262, 81.2387268004879, 104.5623714693131, 35.81533462770524, 0.808364762173545, 0.27500218381324126, 0.8917761089340334, 0.8100663966709568, 1.2680346158242997, 1.3718488451934632, 2.7185533363972945, 0.6993364158176607, 0.3642245526275327, 0.05340018557504781, 22.99137088560289, 33.66843708099858, 41.39982877239105, 31.379736046637262, 31.0647814889108, 58.866201985266905, 58.46268815378989, 75.2797600530809, 64.91079015116539, 63.67633396579374, 18.865892541023996, 0.731000729626225, 0.046395000986634724, 0.03910768153746763, 0.028661517276158257, 0.026417521256653052, 0.03370092791174689, 0.0430208778068904, 0.06128223440159233, 0.02557970643524201, 0.007004066578848589, 0.04054379762120305, 0.03366410972610597, 0.009699614451927765, 0.02536693125993254, 0.04261630677407788, 0.06904799491167068, 0.020792591535756667, 0.05103817945646663, 0.15168165517670495, 0.15631262603546345, 0.11490187352342952, 0.1731091497405883, 0.1210571678295251, 0.15515397933702316, 0.09932981113031988, 0.19200420277493616, 0.105193585998589, 0.16968570198983918, 0.22639724516099502, 0.21553482319558823, 0.10889971253251839, 0.1636641896179607, 0.24437728277858228, 0.5198435473345941, 29.25554902322831, 120.4730659915555, 99.85617053124213, 106.85788369947865, 76.84639392360565, 58.772139626164595, 36.625998327809, 98.37123178666639, 116.05066422493228, 88.36539099293371, 6.417172637677963, 0.18828441689331687, 1.5972265192577917, 6.203199009741507, 2.8636467120339795, 2.349908395159629, 9.790295766245935, 11.161689739073477, 1.281587875658466, 41.769143458335634, 126.34454034989881, 101.30390951710363, 117.36247739484234, 101.56440196498748, 112.76559291347381, 92.88763276992306, 87.82212703458725, 76.57023552925357, 85.65030282543552, 85.32786830779045, 87.68844481437438, 77.22175690435594, 77.46634021882089, 72.75512649166969, 75.90086736986714, 73.6804920627225, 71.76221770624961, 72.95417108843404, 73.68252385047175, 74.501279400241, 71.47293506130096, 68.64960516652754, 73.54028301854288, 69.35608679248442, 67.56302233665221, 64.7598808811557, 71.2321093774611, 69.83507879318731, 72.23183524224066, 70.20412675796017, 72.61621182964694, 67.63276992305633, 73.6305759799096, 83.54384883757561, 85.0804687315418, 84.86659757552609, 78.9298314432944, 76.84761770309942, 71.19691787227508, 69.11162114912464, 61.52329398739723, 65.33086815188008, 66.92835930855044, 67.6047485105453, 67.1824896720148, 75.53960138751616, 72.45905814632293, 81.03402614593506, 72.23764035009569, 75.28280381233462, 77.8046211119621, 93.37231220737581, 66.80944088966616, 73.51590941029211, 88.99482157922561, 71.70526489134758, 70.24252676194715, 82.47184153526061, 82.79522526648738, 77.05982577416205, 85.06237876030707, 83.23869628290977, 84.70176389140468, 84.66880813721689, 84.92753551852319, 79.53931285488991, 69.4025041211036, 63.75100804913429, 65.86783670609998, 66.37145334674467, 65.0438447921507, 65.2600654478996, 67.15804546110093, 61.87040805816651, 62.349411825979914, 61.2091278260754, 61.63584247712166, 61.97700238996937, 62.81038445811119, 64.10261323375087, 67.19471962221208, 67.30901748903337, 63.46875429153443, 68.42148796204599, 66.844969718687, 67.27556751620385, 67.71818345592868, 72.22724606913906, 69.73714505472492, 71.49857167274722, 67.27144902752292, 67.24006222140405, 63.976638470926595, 70.91750391067998, 66.54976429477816, 75.01288198655652, 83.57925999549128, 93.91269714601579, 83.36898173055341, 110.5577927251016, 32.366855413683005, 1.6082157747399424, 0.6474291172719772, 2.9159272486163728, 0.9027309211031084, 1.3415454712606247, 5.149692546936774, 5.447601954783163, 0.3388546317094757, 0.3129372950042448, 0.3295830066405958, 35.84019853222755, 39.628568772346746, 83.30540011006018, 60.0799794350901, 31.049827452628847, 67.68096800773375, 73.24629352938744, 89.05001717229044, 84.50500211408063, 85.09146705750497, 21.116205338508856, 0.6935262211388158, 0.18347660229811746, 0.2579832341401808, 0.12430991586898604, 0.1394855354221598, 0.14249937128155463, 0.12161756114613627, 0.11793161336813243, 0.05829202469378229, 0.07502528102768045, 0.15471577704433473, 0.14045656718794378, 0.16543365354018827, 0.11195595901940139, 0.1557235657087257, 0.18947231282870616, 0.21827346495082303, 0.13745092846933873], [0.05186989813322022, 0.032551615994663975, 0.07712818471895111, 0.045668140594517036, 0.02505192739678727, 0.034707050334902546, 0.011635505230045848, 0.048196598466846256, 0.03914164987603023, 0.03218366013419244, 0.04205176892179636, 0.04785992197632309, 0.018331256372133092, 0.029406556934719125, 0.08794533088803293, 0.8448883410423034, 45.91850511489376, 70.36777588628954, 72.06615432616204, 64.83905784545406, 50.757270397678504, 24.757616135381884, 45.2498233702875, 100.59494110845752, 72.79076514705535, 31.04491076161785, 0.10094525307537087, 0.11917725701125399, 0.404073259522838, 0.8436215380507132, 2.3548304794296144, 1.0000113397836685, 3.050529754930927, 2.730176054662274, 6.142532200582567, 100.28215562143635, 100.8746688596664, 103.28159993694675, 99.22344515400549, 96.24552680600075, 89.6120692837623, 76.63984191033148, 67.00519069548577, 73.23645622499528, 70.84992931735131, 70.64459323883057, 68.55976720010081, 67.1577787399292, 69.3018090340399, 66.95570607339182, 66.31786592545049, 65.86121574524911, 64.50913552315005, 65.73520175872311, 61.77654181757281, 64.05611353535807, 64.37398633649273, 65.61309837525891, 62.91296228285759, 61.79443959266909, 56.446229027163604, 60.91944509936918, 59.48889393960277, 63.22356300969278, 65.64013527285668, 63.20025236375871, 63.763806743006555, 59.95056867599488, 63.152815218894716, 78.69108461564588, 80.7115210256269, 80.10370269898446, 72.38685515619093, 69.50236766569077, 62.19878496662263, 62.22403326342183, 59.33042233990085, 57.9685793384429, 58.70325496119838, 61.13395952409314, 61.086804789881555, 64.53951428013464, 65.16895663353705, 70.32086433902865, 61.03878713423207, 70.79205082308862, 71.92356048091766, 80.2921647410239, 55.63965635914957, 65.98264448104366, 81.5213571056243, 62.40812186271914, 67.70247044101839, 77.86911272233533, 74.1617904170867, 73.8720606219384, 75.63723702584544, 71.66245614328693, 71.07574016817155, 71.1234675684283, 69.4406452486592, 63.13483115165465, 57.791021485482496, 59.5374018915238, 61.05501790200511, 60.15815619499453, 59.10761210226244, 57.293296244836625, 59.049278613059755, 55.07710218429566, 54.28554827167142, 54.68654786386798, 52.59281412247689, 52.67724314043599, 56.80141925811768, 58.328625463670306, 58.815266086209206, 57.59559331401702, 57.353496782241336, 58.86060868540118, 59.45643632642685, 59.00515979336154, 58.412901509192686, 57.577817132396085, 56.62934487865817, 57.140543460845954, 58.270684211484856, 59.019092052213615, 59.644129583912516, 62.24394321441651, 62.83027871962517, 64.33451160307854, 67.92307238424978, 77.3484416161814, 82.88795794210127, 84.71019698727517, 87.18004288211947, 4.988384093007734, 0.4118758956751516, 0.26866862850804485, 1.363330315197668, 0.35035030195309275, 1.668344606314936, 1.4480804772146287, 1.6854682035984534, 0.6901836263075952, 0.3950553934179968, 6.134127051599565, 28.2549229744942, 37.76562336952456, 74.52489991341868, 20.391304262222786, 24.599540695067375, 46.088951710731756, 62.8336323461225, 53.84015921623477, 45.72576376699632, 32.929701805114746, 16.665415417763494, 0.9252173177176907, 0.02977472729980946, 0.09032135258518881, 0.02803127589305082, 0.03968895458045506, 0.04588964342650387, 0.031212312357139685, 0.0558238847541713, 0.08438673756656148, 0.07878045251052226, 0.014856450086940202, 0.07443242856571752, 0.03228702071693636, 0.03298384280154302, 0.0670659798948515, 0.06585788988177815, 0.04657875100571302, 0.05298156832014361, 0.029688732015089165, 0.015936408064238006, 0.029037001865705656, 0.04425846603548816, 0.028305853296431805, 0.06109022212425067, 0.022950421815978426, 0.057796890577000964, 0.02051011959631597, 0.03840047513104735, 0.12528962741095212, 0.05744581929438057, 0.04460071964610008, 0.057857269796753125, 1.3980001451507693, 67.72610664367676, 90.42054822368007, 90.40907136855587, 78.94575626619401, 64.66503404801892, 36.56634692222842, 47.25397409931306, 75.53457290895524, 80.31995081132459, 33.03417021228422, 0.13074244973399948, 0.17944855795752618, 1.4064019846339382, 3.0190086076336526, 3.665075191567021, 2.47951919513364, 2.4436773119434236, 2.016169238955744, 10.129560193707867, 116.07193916074692, 101.28898882096814, 109.75472665602162, 99.55440690440517, 101.63312189040646, 90.9467577165173, 81.47671268832299, 71.18449180356919, 77.34967324041551, 73.95348118197533, 73.79137746749386, 72.07858039486793, 72.6566122424218, 72.96746007857784, 73.1058491429975, 71.22442153192335, 67.71870905353178, 67.65110308124174, 70.0873185742286, 64.77350719513433, 69.64328273650139, 68.91710296753915, 68.21546939111525, 65.8867346855902, 65.78901275511711, 59.09774734127907, 64.05205388222971, 64.0083900574715, 65.52832418872465, 67.01287069628316, 66.91661573225453, 65.82016421902564, 62.965588723459554, 67.71984654088175, 83.28753763629545, 82.81091474717664, 85.25346879036196, 75.44611561682918, 72.74139819606658, 67.75106076271304, 65.31566504509219, 62.0604076693135, 61.68970446432791, 61.01175023663429, 65.63316522106048, 67.6890245560677, 69.11086805405156, 71.65075963543308, 73.17573793472783, 64.56271509970388, 73.37256246997465, 75.91377981247442, 83.1109368416571, 59.48206117076259, 71.97593196745842, 83.69107892436367, 66.72221522177419, 70.50323886256065, 82.35474309613629, 76.26056440414922, 77.98805467544064, 78.37068973049041, 76.43711028560516, 74.66382242018177, 72.33696260759908, 70.51197005856422, 64.68177864628454, 58.73606951005998, 61.898802095843905, 64.77963785971365, 62.68503727451448, 60.906418908026914, 59.957852517404866, 61.98709464842274, 58.883582007500436, 56.5391029081037, 58.37164994209044, 57.21156189518591, 55.3627448697244, 58.70019551246398, 61.147295582679014, 61.18379715950259, 61.97085211353918, 61.09738734460647, 60.92762716354863, 63.301998646028586, 62.339974603345325, 61.81769140305058, 61.10869946018342, 59.885578924609774, 60.20779771189536, 61.390004004201586, 61.66713122398623, 64.60868527812343, 65.11315699546569, 66.228192698571, 67.14047324272894, 69.99727664455291, 78.89340046913394, 87.82939126414638, 86.07130650551089, 96.60742036757931, 9.209076012334517, 0.3836481297208417, 0.4694468209580068, 1.3232552139989793, 0.37751875216922454, 2.4807692054779302, 2.087005650804889, 3.257757396467271, 1.7561654938805489, 0.8199352638856058, 4.759783946698712, 35.192783878695586, 42.58050534033006, 46.32231704650387, 26.87143437324032, 41.58153257062359, 60.47078478720881, 74.6941266521331, 69.63534385927262, 62.110955253724136, 49.2217723015816, 23.874543520712084, 1.0212528128777782, 0.043036302987245784, 0.08047637965289817, 0.07429218851029873, 0.05841353389945242, 0.038401172271058444, 0.01468286605461711, 0.017764006568599614, 0.07475977793576256, 0.02091796948544441, 0.010239116550843802, 0.10485662988597348, 0.010280368470346496, 0.06542898023561125, 0.04306117020126793, 0.016984548494820634, 0.01298209053329042, 0.13859975392058974, 0.10418185198138799, 0.18792337497636197, 0.1206662561444025, 0.15751008274814776, 0.09024320395603296, 0.11984374584449876, 0.10752859900915816, 0.12194470367244176, 0.10971369627382487, 0.13898662832235137, 0.15981211567357664, 0.13695893148260732, 0.14280407509255794, 0.2286548756303326, 1.5707974664626585, 81.42091305025163, 112.2758222395374, 105.6240786275556, 95.76847245616298, 74.69364812297206, 36.96343983373335, 65.76219551024899, 126.3073641254056, 93.93971443176271, 50.34649625901253, 0.29846310555454225, 0.27530555463125633, 1.586457774523766, 5.0817659208851484, 9.250137344483408, 5.407525137547524, 8.2783220852575, 6.878638998154671, 8.846941224990353, 117.95494356463034, 106.65454018500544, 116.0720568318521, 103.55281614488172, 106.4535108689339, 95.07758617401124, 87.37882075771209, 75.33846224507978, 81.86590594630088, 79.24900254895611, 78.99455055113762, 77.70617746537732, 78.39607531024565, 76.18338784863873, 77.10189711663031, 77.406704502721, 72.19177215330063, 72.87284466528124, 74.01985553003126, 67.38688438169419, 73.27870015175112, 74.0517287100515, 71.88912207080473, 68.1887423607611, 67.89967152380174, 64.66331997225362, 69.54209343079599, 65.68303031306114, 69.11828917841758, 72.84114406954858, 70.56480438478532, 69.16930352487873, 65.44884912429318, 70.78087206809752, 86.99526002330165, 86.91030148536929, 88.79709489883916, 78.32837520107147, 77.25320646839758, 71.83026298399895, 67.96162143830331, 65.46854726729855, 62.94061891494259, 65.29430773950392, 69.46748210537818, 70.00991452124812, 72.9336884713942, 75.761670297192, 76.37190480386057, 67.87388586228894, 77.4856069011073, 80.90232080028903, 85.58483846725957, 64.12131901710265, 77.62674946938792, 88.41071005790465, 69.24316959996378, 76.23708509629773, 86.4735455666819, 79.86490095815351, 82.05004553641044, 82.22824665807909, 80.81671114890807, 79.03975978974374, 77.04409706977107, 75.20798067892753, 69.05290326764508, 63.58260500815607, 67.5878038714009, 67.5918988258608, 66.9239740986978, 63.769101942739184, 63.03307702464443, 65.07795372316914, 61.61337906314481, 60.24441695982411, 62.271733207087365, 60.27063800442604, 59.864060801844445, 62.06746009088332, 65.55763606102236, 63.247112920207364, 64.9372269261268, 62.50792264938355, 65.05818497750067, 65.70211264394945, 65.24938483392039, 63.890295336323405, 63.91297840302991, 63.29510704163582, 64.63302750741282, 64.77530364067324, 65.58852864849952, 67.73220200692454, 68.87537679364605, 69.97612722458379, 71.35673092257592, 73.70230044088056, 86.25102950680642, 92.21154951280164, 89.62081616924655, 96.57453521605461, 6.824698563544982, 1.112118930585923, 3.5712069897882404, 3.3554736885332295, 0.4799056371613857, 4.03395057205231, 6.626612495991492, 3.7307231656966673, 1.6594358004869956, 0.7011166202925867, 8.788984283324211, 45.943816169615715, 56.78543167729532, 100.6483716349448, 29.80170180720668, 41.335686252963164, 68.71932137397029, 86.7218315985895, 86.3913405326105, 80.44603147814351, 64.20921541029408, 25.37031585170377, 1.1615681287742432, 0.10125309784686375, 0.20263889744397134, 0.29122424882746517, 0.14153661326535288, 0.11954608238151959, 0.16790316860762336, 0.17473203039938406, 0.17508256159001784, 0.1503088562599113, 0.08830056585852178, 0.20491025620891204, 0.10424172175267052, 0.16739873035300165, 0.15554036344251326, 0.15232881561162012, 0.1452315778982255], [0.06150885087047374, 0.04000697299958237, 0.017559623886500637, 0.034803853205014626, 0.05355490086179587, 0.04782963469023666, 0.10576926276928957, 0.03204972689761029, 0.021897271170371005, 0.02796719646862438, 0.08502072895005827, 0.06429875539916177, 0.07835895093458314, 0.12985184187850646, 0.37795434976297043, 9.33353772086482, 83.1368637084961, 65.85608528506371, 72.77595427728468, 47.24676086056618, 34.894366033615604, 24.524172352206325, 59.69912121372839, 87.20076868610998, 61.90382665203464, 5.610090061541527, 0.02825916215266672, 0.7238690026344792, 1.6850002158072688, 1.8754417064689823, 0.9366600359639815, 0.6328816591731964, 1.9575982012094992, 0.19493897836054527, 61.016688500681234, 107.76129184230682, 94.65309942922285, 99.78814094297348, 90.58305201991912, 92.86939374862179, 75.16146136868385, 70.83244339112314, 68.2144417301301, 71.55421441601169, 69.30245230274816, 71.15723917561193, 67.68405883542954, 68.65189583070817, 67.88529211475004, 68.33741587977256, 67.15553514419064, 67.09980610878237, 66.67269137597853, 65.93028868398359, 63.546444677537494, 65.52173068446498, 62.60994349756549, 63.679440482970215, 62.6180314248608, 58.07801346625052, 58.258211074336884, 60.403257262322214, 62.25457675995366, 62.29228250442013, 59.2640087681432, 60.752509024835405, 61.71409768442955, 58.62105777186733, 68.4822690102362, 78.05385635745141, 80.76663032654794, 80.96862454568186, 74.56827348278415, 68.28091805981052, 64.67594215946814, 60.6855502436238, 57.773531636884144, 57.997597032977694, 58.96118217898954, 65.74889083062449, 68.50091595803538, 69.65857998017343, 67.7927084892027, 69.69344200626497, 62.05468100886192, 70.08399240432247, 74.5600208159416, 75.32183139554917, 56.92320492959792, 69.18880554937547, 76.58381477479013, 63.61681592079901, 67.39583523042741, 77.00365743329449, 75.60465781919419, 73.99018672204787, 69.29685115814209, 65.6346635664663, 61.415605314316295, 59.37703970939883, 56.69585258729997, 53.724727784433675, 58.37238734768283, 58.779949065177675, 57.0807037814971, 55.86376882368519, 56.729337861461026, 56.827710905382716, 57.142057495732466, 56.03130109848515, 54.913704087657315, 53.39590764814808, 52.758400901671386, 53.112045718777566, 56.5046605756206, 58.12564280725295, 56.20921196476106, 56.47348165512086, 58.421589559124364, 59.65547700082103, 57.41478773855395, 57.0461320107983, 58.49367095578102, 57.584787184192294, 58.80600537023237, 56.560271939923695, 57.786542138745716, 59.17614767628332, 64.93477152239892, 66.2340291853874, 67.2953833303144, 66.60131992832308, 71.20618251062209, 71.84746649957472, 79.22721770501907, 78.56701220235517, 93.30700474400675, 53.98374542113274, 0.5090863245629496, 0.2128127902265518, 1.4608569851806088, 0.894965302319296, 0.5681236953504625, 2.1154923544776056, 3.19795350874624, 0.563864185204429, 0.027770610646374767, 0.15270919358778387, 19.3231624557126, 28.7959707936933, 57.79788955565422, 46.19298865718227, 13.615728482123345, 30.97037200004824, 58.48395524486419, 54.72267681552518, 49.64741614557082, 49.20014435245145, 37.750302591631495, 14.702311311998676, 0.7060592357189425, 0.04800173251198665, 0.06834497900619622, 0.0386167723955887, 0.10485849914050872, 0.015520592775916862, 0.0481430757340164, 0.08480836171656848, 0.023245030503359534, 0.03596706961792323, 0.057165373657499595, 0.023505125014532, 0.037571839958188996, 0.03661733653937136, 0.06550565797595248, 0.07164959119813097, 0.08500117072535139, 0.03821065769560876, 0.009562961603214425, 0.08130924746153817, 0.019462412005410563, 0.04458454753001852, 0.08182932157069445, 0.06329360973810957, 0.04748410605374844, 0.02018527341856351, 0.06768783644562767, 0.05153023389979236, 0.041964752824916955, 0.11006408190775303, 0.43170847178947547, 14.396034998278465, 105.87584772417623, 81.32519152856644, 85.76194132527998, 58.96885825741676, 46.1507055067247, 32.08387601760126, 53.862414744592485, 77.77885898467034, 69.59732824756254, 6.117497672957759, 0.07803300350543954, 1.7307823656066772, 5.240640544122265, 4.498849741874203, 2.1292061863407015, 2.957509275405638, 3.6314960256699598, 0.8232668883377506, 79.30906972577496, 109.3667571775375, 99.80718797253024, 106.22115750466625, 97.16913515521635, 94.75073506755214, 78.59033461539977, 73.9330142544162, 72.63685918623402, 76.73310802828881, 75.01679651198849, 75.26289386133995, 72.27652672798403, 72.32004934741606, 70.23018698538505, 73.1727098649548, 71.51129584158622, 70.68537019914197, 70.83269442281416, 69.4410296409361, 67.57585633185603, 66.38487569747433, 64.90706389950168, 66.91516445529076, 66.45798083274596, 60.982861980315185, 60.919256825600904, 64.39375900453138, 65.60092726061421, 66.1467093806113, 61.8150398808141, 63.77805279147241, 64.20667371442242, 61.1308490845465, 72.72300227995842, 82.10484889245804, 86.05713105970814, 83.4842445004371, 77.48219443905738, 70.88889414264311, 67.87275621967932, 63.7064616910873, 61.2861906328509, 60.861044929873565, 62.43816721823908, 69.2738974478937, 72.1275786430605, 73.35173468435966, 69.88817984058012, 71.55828583625056, 65.46713129166635, 70.1757994005757, 77.80195390024494, 75.41020239553144, 61.62959021906699, 73.63881295727145, 79.06294884220247, 64.3376769558076, 69.0541898050616, 78.87925640229257, 77.14520008333268, 77.12075587241881, 72.81222051189792, 68.78677045145344, 63.26441057266728, 62.28636757020028, 59.435345742010306, 56.21913163892685, 62.58282030782392, 62.39021232051235, 60.21056298286685, 60.08446270419706, 59.18915817814489, 61.52042281243109, 58.76535784813666, 58.24654594544442, 57.630600467804946, 56.50428795045423, 56.27255432067379, 55.43335145519626, 58.30768392932031, 60.348791230109434, 58.73673631298927, 59.987038873857074, 61.926172394906324, 62.18003603719897, 60.744091618445616, 60.092672224967714, 60.87289048779396, 61.027557388428725, 64.47669359945482, 60.47585641184161, 60.59584563778293, 61.64578960787866, 68.00310442524572, 69.49402870670443, 70.6308884774485, 69.32704556372859, 74.85081749577677, 75.91239129343342, 82.62262528942478, 84.90702152252197, 92.79913625409527, 65.46819425398304, 1.9014744773026437, 0.03513216401540464, 0.5468314153052146, 1.0956875090637515, 1.6261803527032177, 2.331738505632647, 4.539530113820107, 2.1358879439292418, 0.15380702822679473, 0.1621790362461921, 19.04556651269236, 40.70826392019949, 52.97062073984454, 23.91218846844089, 22.616107925291985, 45.47938792936264, 62.67679245241227, 67.86528018213087, 64.74877665119787, 67.06961170319589, 49.249079842721265, 20.126869832315755, 0.9475242046098556, 0.060287423266638676, 0.0467923861147175, 0.021708608612478263, 0.03237220586367673, 0.03751107386403507, 0.02230000933782468, 0.08981325243028904, 0.017704899054801753, 0.022868176531647483, 0.03862945881161479, 0.010972792252657876, 0.058788074285633145, 0.0548686727040237, 0.07526540362666692, 0.006768493584522437, 0.14302368185693218, 0.15142440285173156, 0.07669808763650156, 0.12132277817375238, 0.16625991001004176, 0.0782935806520043, 0.2027348729391252, 0.22393749005371527, 0.19272087802810056, 0.16201480231698484, 0.17125475731107498, 0.15963707990463705, 0.22460757183932492, 0.21174225896116228, 0.5321863882483975, 18.52845887983999, 129.32278033225768, 97.52822029975154, 103.50363746766122, 71.37425607250583, 52.27738888032975, 36.175223858125754, 82.89086834076913, 105.83214467571628, 91.84772614509829, 9.604616645843754, 0.16717671807254517, 2.216213917539966, 8.576455558499983, 11.71559508769743, 3.9232355452352956, 6.266189823227545, 13.267251387719186, 0.5387524359168545, 76.98268059761294, 114.05288342506655, 104.3042952014554, 109.77488763870733, 101.87405740061115, 100.54048292098507, 85.16716880183067, 77.00044893449353, 76.59866486826252, 84.20672155195668, 76.73437887622465, 81.3609556997976, 76.08071588700818, 75.51960514437768, 76.40581761637043, 78.44857231263192, 76.02752854747158, 75.34613440113684, 74.45435216349941, 75.74554935578378, 73.0401651320919, 71.4177865366782, 67.87699237946542, 71.21037944670647, 71.3499766011392, 63.750215730359486, 64.30274824942312, 67.26551055908203, 70.17767429351807, 69.6124215279856, 65.62720321839856, 66.4877280881328, 70.34182548522949, 63.55639573066466, 75.89045739942982, 84.17928065023115, 89.2946397104571, 88.63455187889838, 83.3129624397524, 75.07008583314958, 72.25879761480516, 68.66426698623165, 63.07810975659279, 63.855472533933586, 65.63573829589352, 73.62953262944376, 77.18793822873023, 77.78947291835662, 76.07480879752868, 77.00693653475854, 71.54685604956843, 75.51087394837411, 80.3318512824274, 81.0427494971983, 66.73729281271657, 76.84656650789323, 82.65256866332024, 69.41428692110124, 72.24915642892161, 81.60021243556854, 79.86847031501033, 80.56363198064989, 78.21912934703212, 73.70645030852288, 67.84590367347964, 64.33001264449089, 61.45210689113986, 59.555648757565415, 64.97204972851661, 66.0350630360265, 62.89335043199601, 63.37346815293836, 63.454288590338926, 64.22628164291382, 63.24867010116578, 60.81467074732627, 61.85384781129899, 61.34801110913677, 59.9026765361909, 58.37985161812075, 63.866851329803474, 64.79749248873803, 61.94728259117373, 61.15286927069388, 66.19894750656621, 66.48153858800089, 63.7425906427445, 63.22545751448601, 65.30320759742492, 65.89779576947613, 66.03916583522674, 63.426408383154104, 63.5545482943135, 67.69672809108611, 71.65414071852162, 72.9097463238624, 74.77020494399532, 72.71669510872134, 79.61135110547467, 78.64264334401777, 88.56977001313241, 86.67826191071542, 98.99467683607533, 63.706293029169885, 1.2270769813368398, 1.9834711354586387, 5.6799018767572225, 2.15352953922364, 3.19503624593058, 6.461690558541206, 9.733532205704721, 2.1967013516733727, 0.18713729215725777, 0.2381213321801155, 31.138877022650938, 47.07161134289157, 82.67002321058705, 61.38033143935665, 19.727372507895193, 47.596644124677105, 77.25721513071369, 83.70621142848846, 81.25050175574519, 85.28058021299302, 62.48719684539303, 21.197674928172944, 1.3511402015724492, 0.14561762492502892, 0.21371404670419233, 0.10467349656767423, 0.2610458698003523, 0.09663849828704711, 0.13683465669953054, 0.2110155632779483, 0.16247258581701787, 0.10812560366767068, 0.15027735472446488, 0.12971969171156808, 0.18008975822839046, 0.15621213062155634, 0.14162509642060728, 0.19329794141794407], [0.006230302932371776, 0.03355297718137022, 0.03583631373100704, 0.09546724944225243, 0.01573115012668554, 0.049092063319779215, 0.03949700359014734, 0.041626050031834075, 0.09979589136257287, 0.09690940995971042, 0.008566381762765588, 0.010790197111125435, 0.006106920162921832, 0.061950167310574365, 0.24079510160992224, 36.45421420374225, 77.31325795573574, 70.95025570161881, 67.4908350360009, 63.492708206176765, 37.46208290899954, 45.683182516405665, 92.40526753087198, 59.40921883429251, 34.19848265186433, 0.45735436822137526, 0.01634634937339973, 0.7884660267060803, 2.7890040076548055, 4.504865186829721, 1.0634283433037421, 2.012401434683031, 2.41606897404117, 21.59275370259439, 107.38374802374072, 92.67038837555917, 100.95485779546924, 92.60489263842183, 86.21885822665307, 76.13333840523997, 73.12384497734809, 71.22930880515807, 68.9800177851031, 67.07966866031771, 65.22359132766724, 64.91769352266866, 65.37270022976783, 65.2374961299281, 65.19987667760542, 66.15704090364518, 65.72845528202673, 65.8810237146193, 64.65284332152336, 63.929840672400694, 63.44463563734486, 63.70573605260542, 64.04870417810255, 63.129065267501346, 59.90434354351413, 54.73903309914374, 57.75712436245334, 60.35368634808449, 61.17001395071707, 59.60946367632959, 60.31695727379092, 60.38973292996807, 59.319996679982836, 69.09657493714364, 75.11211795191612, 78.62118013443487, 79.03414295565698, 77.98470497131348, 75.83563050916119, 69.31758480687296, 65.54409211681735, 62.92141891294911, 59.779694541808105, 54.8595126213566, 63.5671155683456, 73.76994563687232, 74.32645151692053, 69.60019942252868, 69.89056464164489, 68.20604785796135, 61.6466486069464, 68.43582814739597, 75.6208493632655, 68.55624491168608, 61.56412193852087, 69.10229375285488, 74.76328588301136, 64.66164119781988, 67.31098651885986, 77.45686377248457, 75.64022587191674, 75.98901871711978, 69.76885349519792, 60.4828852991904, 57.588584038519095, 56.07190939687914, 55.855582837135564, 55.042812824249275, 56.331860557679214, 56.355998823719645, 55.76681175539571, 54.87960692374937, 57.08294737723566, 55.56342509485061, 53.664127165271395, 55.10247991931055, 53.99115870075842, 53.67729456193986, 51.998535817669286, 54.2296427296054, 52.54144284033006, 53.81382442289784, 56.1254144483997, 57.54867784438595, 57.46647281031455, 58.90020501229071, 57.44267186810894, 57.92030280636203, 59.44853275052963, 59.54137525250835, 58.82108688354493, 59.59007147819766, 57.42564485919092, 65.16246511090186, 69.66866831625663, 72.48678145870086, 74.02275808395879, 76.23027586167859, 75.80759340716948, 78.84867760442918, 79.5404895659416, 82.14496689458048, 83.2876709968813, 86.94248845500331, 40.55364801037697, 0.07138553601238998, 0.7068676116966432, 0.4630162176345626, 1.6969275306309424, 0.3825465872162773, 2.029711712271937, 1.9646821243147699, 0.27155506394563184, 0.13312861443527285, 2.0018128738287957, 41.61431181815363, 38.18861569127729, 93.09456133073377, 30.00456875370395, 20.60285141391139, 44.15517614733788, 41.22940571077409, 53.226555393588164, 54.61018323898316, 39.74052106180499, 38.647254513156035, 14.59568658182698, 1.5443122747444338, 0.05799760178272283, 0.07234177462035611, 0.016644349915065592, 0.019099292074961048, 0.03754310783058886, 0.06603776732639921, 0.06676086239636907, 0.012449172002473667, 0.06373128726056988, 0.05952742191091661, 0.06894322472714609, 0.030608644648905725, 0.06251763161872664, 0.011314853383678825, 0.028783082023202896, 0.013359345743552813, 0.05391103215515614, 0.044469664984893416, 0.01319172474811034, 0.015803013004422668, 0.023034040312913638, 0.09693654479398843, 0.017876772795833887, 0.010102498176087056, 0.03768800187014765, 0.048495606414132544, 0.03216519741521728, 0.027779976071249095, 0.22167736213774453, 52.69906328570459, 96.85594174169727, 87.05648822169151, 81.9988036924793, 78.11896770231186, 45.385188287304295, 38.6369308348625, 52.031519028448294, 57.42568408289264, 40.67360977972708, 0.15654678847039902, 0.24943234459046396, 3.942944229610505, 4.844709634780884, 7.841719629303102, 2.469356824313441, 1.9687557508868558, 1.5140885739557206, 33.31581992487754, 117.5273189237041, 94.16336013424782, 105.57855559933571, 92.52454680781211, 89.98425514467301, 78.04887494733258, 77.26353014669111, 74.56319793578118, 72.45595947388681, 72.64988929994645, 70.18991993319604, 68.40770475326046, 69.83642024378624, 67.89128549637334, 69.56102278924757, 70.66982192377891, 69.05932810998732, 69.42585791310957, 70.7120580057944, 68.15723788353705, 65.31173483017953, 66.34101575420749, 65.93111238171979, 67.18471757827267, 63.33905719941663, 56.53008537907755, 62.4103380018665, 62.56781331954464, 65.6264893470272, 62.00429816399852, 62.43166392849338, 62.60342059596893, 63.20677526535527, 73.58917144037062, 79.4191235880698, 82.50691536934146, 80.0950264161633, 81.70112717536189, 77.50950198019706, 71.94593368038055, 68.71840353934996, 65.53381158459571, 64.6354397650688, 60.38149987497638, 68.64297636093633, 75.25173079582953, 78.26677829988542, 75.31654404055688, 75.06393555671939, 72.02600494507821, 65.57320002586611, 72.47904654472106, 81.78156714285575, 74.10668111616566, 65.88931560516357, 76.43703183820172, 78.01529945865755, 68.0751112968691, 72.42735755059027, 81.4564654134935, 77.39894605452015, 78.6666560942127, 72.68851680140342, 63.19394127015145, 61.66946503423876, 60.497331388535045, 57.48470398687548, 58.036710908336026, 58.572859687189904, 59.388653847479056, 59.94695617306618, 57.850210051382746, 61.44866697249874, 58.27850149523828, 57.120417779491795, 57.99647523510841, 56.63085106880435, 55.76576840492987, 55.778708304128344, 56.62259447959162, 55.665422408811516, 57.72745947684012, 61.40943542603524, 61.86983539212135, 60.24580940123528, 60.81072092056275, 60.696725076244725, 60.33611020734234, 61.808093363238925, 62.831639782074966, 59.611664125996256, 62.59051207573184, 61.84464985324491, 71.68690819894114, 74.54035405189761, 76.19051087287166, 76.12783924225839, 78.2402709222609, 77.1519151810677, 81.06872343247937, 82.50214576721191, 85.08225733234038, 86.97288682383876, 90.45436689930578, 52.31190181547596, 0.5621358908472524, 0.6725697940395725, 0.7734722764261308, 1.6445854618664713, 3.1124985458389407, 4.081859136781385, 2.5222114978298067, 1.2296148774123963, 0.1295675313280475, 1.180831011264555, 43.320276121939386, 47.15016857270272, 66.25721823784613, 27.34488602607481, 32.23147284600043, 58.19241723706646, 54.97701898697884, 66.35524611319265, 69.96764706027123, 58.033945637364546, 54.80660377010223, 21.33946860990217, 1.7778765482287255, 0.035642152577037775, 0.01000015553267252, 0.044418478820232615, 0.07989225293239278, 0.06187353170506897, 0.030270541319623593, 0.044056563563044035, 0.046284282129378095, 0.03794870542121991, 0.026690740769188252, 0.0490124169887314, 0.08782150043595223, 0.03547448274349013, 0.06654083428363647, 0.1392076446885063, 0.15945360184677188, 0.10796851733879698, 0.3788862191140652, 0.1166219937224542, 0.2530610732614033, 0.11965443785752981, 0.1328833437254352, 0.17281279628795965, 0.2192564476882258, 0.11783755309278927, 0.10494538117200138, 0.18873487659279378, 0.20344761050035878, 0.3773123680824234, 64.10816730991488, 116.87709193075858, 102.07350992387342, 96.3014284256966, 90.878280978049, 52.34318271760018, 63.33229895560973, 118.12313479761924, 83.15225508905228, 53.35111418078023, 1.067186954521364, 0.3058469674039272, 4.209935799721749, 9.408776625510185, 12.449081251698157, 3.801141722548393, 12.993433667767434, 3.451742380857468, 32.808498605605095, 125.66027502859794, 100.30079472449519, 111.99437649019303, 98.33811129293134, 95.70642056003695, 83.80345482980051, 80.29930345473751, 78.23454426180932, 78.25250087245819, 77.6833963394165, 76.06304168701172, 72.81359334145823, 77.0607828324841, 73.03767834940265, 74.53244655363022, 76.3685158760317, 75.3485192022016, 74.54625329663678, 74.36709511664607, 72.38381924167757, 69.83190167334773, 70.94873382199195, 69.45569146064021, 69.20626794138263, 67.0544791990711, 60.79303495345577, 66.43294826630624, 67.29093536253899, 68.7227338360202, 67.03878187364148, 66.47796923114409, 65.91569746694258, 67.33666235400786, 78.05317386504143, 82.14699868232974, 84.73049917528706, 84.45043410024336, 85.17486449210875, 83.06900670451503, 75.05569857935753, 73.35217398981895, 69.01498179281913, 68.2842912981587, 61.22054584564702, 71.82965109425207, 80.61968265041229, 82.53556436108005, 77.34448002230737, 79.69536827456567, 76.14024962148359, 69.14243528919836, 75.09513408906999, 85.62772566272368, 78.22535022612541, 67.86454277653849, 77.79738826136436, 81.73563618813792, 71.69469018136301, 77.28391078210647, 86.84725330721948, 81.21616532725673, 83.31710446265437, 76.12662330750497, 66.2683028559531, 65.12736774259999, 64.5372393054347, 61.48423894759148, 60.996739325984834, 62.09632481298139, 62.63181071127615, 61.046478902139974, 61.084110121573175, 64.30113223291212, 62.8972061218754, 60.6264675817182, 60.84476317128828, 60.04015561073058, 59.36530397784326, 59.416302634823715, 60.6658128769167, 59.0171387118678, 60.15557919779132, 61.616030585381296, 64.20267681921682, 62.93104833172214, 64.67000369102725, 62.882112841452326, 64.26076712146883, 65.2232422367219, 66.02025216625583, 65.64237886859526, 66.427229450595, 63.66000121639621, 73.63281957564816, 77.29429721832275, 79.09219403420725, 79.90526999196699, 84.45908684884348, 80.7873639752788, 84.08526143720074, 85.27537130540418, 87.8576950873098, 89.5215331354449, 92.5748472829019, 48.16345014879781, 0.305869521032418, 3.02656211199299, 5.56860315222894, 4.86215143434463, 4.783024480265956, 7.4890034333352125, 5.24554007476376, 1.1172041609402628, 0.16553558919939304, 3.5972186778822257, 60.88494785370366, 53.370020005010794, 127.15199947357179, 42.17479105918638, 29.77035422478953, 64.45260632422664, 64.61309794456729, 80.67345834547474, 85.43733381455945, 74.87324560842207, 67.37094386931389, 23.827157366660334, 2.0443131029605865, 0.13623830321575367, 0.13892642913326142, 0.0989048621587215, 0.1931321446693713, 0.11551699616135129, 0.11546085723826002, 0.1616796694936291, 0.17206495657803553, 0.1493215527866156, 0.14492969329078353, 0.27498885388335875, 0.13591270052617596, 0.10686197994096626, 0.07612215805678599], [0.010774644568652637, 0.04373332808515237, 0.027446300730169303, 0.07197624342816492, 0.02792579133153683, 0.025130116245559147, 0.04316389110059508, 0.12975454871212283, 0.022351775814088124, 0.06831634263958662, 0.028441673024527492, 0.03027962903762537, 0.042453386685660774, 0.2943605208589185, 7.974590409186579, 82.763485447053, 72.97925856805617, 70.47803371183335, 52.46089696884156, 37.36644375708796, 21.33760548407032, 66.2274709824593, 84.5037155766641, 46.51873365525277, 17.33200065551266, 0.46834990562450507, 1.6323727946127615, 2.7221579945856527, 4.937436917135793, 2.9043177683507246, 1.6456750227558998, 0.23076151016979451, 0.992864536181573, 69.44475589259979, 97.60753846937611, 95.92642630300215, 92.5051389201995, 83.37506924906086, 78.1143000818068, 73.63307060733919, 72.51176695669852, 68.15883036582701, 70.62693472831481, 66.82743672401675, 65.7021204886898, 63.484667347323516, 64.77955548994004, 64.10905376557382, 65.97845538969963, 65.22876101155435, 61.95213456307689, 63.637329916800226, 63.46353753920525, 63.46618906144173, 63.75167092969341, 64.77899851337557, 64.26768226008262, 60.311026650090376, 55.82611799240113, 55.534532916161325, 61.227198185459265, 59.87401969971196, 59.061065335427564, 57.0598759958821, 58.844613259838475, 58.8871435196169, 68.57121267626363, 76.20852239670293, 76.47829517241448, 78.67910569713962, 76.11378931230115, 76.15112243160125, 77.21630480981644, 69.7675512683007, 65.54213877647155, 61.83813087401852, 58.14466238021851, 56.385753923846835, 65.95361894176853, 74.19167103305941, 75.09573028933617, 72.70810511804396, 70.50010881116314, 64.48899022994503, 60.85085461216589, 68.31475242491692, 73.49172407580961, 66.36309085353729, 74.14830530843427, 71.14703316842356, 72.44300780757781, 64.9006861256015, 66.75299798288654, 73.05831001650903, 71.62655861146989, 71.5917593433011, 67.16680803606587, 63.89586902433827, 58.74457320859356, 58.885382375409534, 58.07829195453275, 55.19277288067726, 54.03116687651604, 54.41246832570722, 53.37842956666024, 54.523090931677054, 54.60508808012932, 58.280474447434955, 54.601322604763894, 57.00431170002107, 54.50546380012266, 57.63944933491369, 51.71437578816568, 54.89590044944517, 53.40522327730733, 51.66196900029337, 55.485860224693056, 57.01692604249524, 57.339207587703584, 57.64557215475268, 56.74700813908731, 58.92975222679877, 56.36114497338572, 59.05606431345786, 57.455835342407234, 60.00149280794206, 64.70052757570821, 73.00066686445668, 73.5076645881899, 77.75263401769823, 76.17395062600413, 79.88346161380892, 80.93180133450417, 82.1267435627599, 77.75483838973507, 83.41215133666992, 86.14991864850445, 81.47517511921545, 86.40435495684224, 50.98698792919036, 0.8911968238892094, 0.8608066675163085, 1.170422389141975, 0.8856539019653875, 2.8525167415218973, 2.208468952486592, 0.513872841913854, 0.11895568140091435, 0.2329692836370199, 15.807163561544112, 32.615949453846106, 45.52978646370673, 62.81093751230548, 20.117713059148482, 17.9215976115196, 29.161749462927546, 45.86781632515692, 50.074523033634314, 53.66251507113057, 52.014362581314586, 50.119998993412146, 16.647739256581954, 0.23747034130557892, 0.02904124024714674, 0.036656621528128465, 0.07925683662535683, 0.061476184881382415, 0.02245705927752199, 0.06358969505996474, 0.013320765555686048, 0.016574363952742952, 0.01323994902533389, 0.09521199660676141, 0.02459782877967002, 0.05057598328998974, 0.17785498782271342, 0.037884878805808486, 0.06718565048950334, 0.05435547423398784, 0.016906246648079926, 0.01805223565879128, 0.05463028146374611, 0.06833000964815579, 0.024484436275557648, 0.01640346505859446, 0.03284037368552339, 0.11682343654214375, 0.02181452409844966, 0.02611850564848752, 0.2760606721764611, 10.289224193942163, 100.64136628181704, 83.84081148332166, 81.30016680686705, 65.36252167917067, 53.91046377920336, 29.449449431511667, 57.93269357373638, 76.440930674153, 54.67590647359049, 19.38490056222485, 0.6655790272258943, 1.0455664824093542, 7.481153299731593, 8.379334884305155, 3.442322808888651, 2.8051992289481626, 1.234472365148606, 3.594105786854221, 88.29089733862108, 101.49492109975508, 100.33800232794978, 94.18694926846413, 85.94749296865156, 82.5508459152714, 77.61929696606052, 76.62186176546159, 73.93052747172695, 73.49764685476981, 73.40434151311075, 70.06636527276808, 66.89080653652069, 68.557813859755, 67.82755482581355, 69.68092180067494, 67.94539067053026, 66.45197176164197, 67.29512445388302, 67.2320213625508, 66.57442031368133, 67.9356239688012, 66.82691112641366, 65.87611290716356, 63.438171571300884, 61.468023869299124, 59.76129470332977, 62.98613017605197, 63.463219827221295, 62.993288501616455, 62.11262226104737, 60.364798422782656, 61.880794494382805, 70.96652569309359, 79.86035885349398, 80.82019421362108, 82.20005266128048, 78.76999485877253, 81.216581098495, 78.53311507932602, 72.12410342308783, 68.5619088142149, 64.16945042148714, 60.30010677153065, 61.22534682673793, 72.14733954398864, 79.65084152836954, 78.76775910777431, 76.86664119843515, 75.25034227678853, 67.27500269489904, 64.44244738548034, 73.12476281196841, 77.96750930047806, 71.50082311322613, 78.01477386105445, 76.64673743709442, 76.49819727866881, 67.87100684258246, 69.77873002329181, 77.74028639639579, 75.22150501128166, 75.8627183975712, 71.20908506454961, 67.94736754509711, 61.80389250478437, 62.86393265570364, 60.519135844322946, 58.62506643418343, 58.57819803299443, 58.49218829985588, 57.45029303335375, 59.343530901016734, 58.661870033510276, 62.340692397086855, 57.809240894932906, 61.11934869520126, 57.9751257742605, 59.82156584339758, 55.50524457808464, 59.065054385892815, 55.441804162917606, 55.873500224082704, 57.22678853619484, 59.820593095594845, 57.580080339985514, 58.909916800837365, 57.89766288572743, 59.92938787706437, 60.220251237192464, 61.9908405119373, 59.12368205285842, 62.55610504458028, 67.86699818026635, 79.49082451481974, 77.82195798812374, 82.19987223225256, 79.83253355949157, 82.92558131679412, 83.77043631768997, 84.84387136274769, 81.24537914030014, 88.79591034304711, 89.7126937681629, 84.23281315834292, 89.46297214877221, 64.66144115694108, 3.7238077819347386, 0.40388691629613604, 0.6560178209216364, 1.8232716091217536, 5.639197970590284, 4.074997930757461, 1.7199963379290797, 0.8418515685104555, 0.3967377531432337, 14.853408855776634, 38.18217123708418, 51.26714714111821, 43.17661146963797, 24.853068974710283, 34.64793920516968, 37.30421143193399, 59.57036156808177, 61.32818352791571, 70.96245427285471, 66.78349048860612, 68.76602111324188, 23.036640920946677, 0.30909897999898084, 0.04058250421357732, 0.03127788182257885, 0.05838806530640972, 0.07222441761123558, 0.08020588932859321, 0.026255453441051707, 0.037793270011823026, 0.04268633870167598, 0.038449738415018204, 0.07933998014777899, 0.06784711378596484, 0.04809814467725735, 0.03995220920431518, 0.0970910647283158, 0.14182766538954553, 0.15937733013303051, 0.1629934030314607, 0.17543738287302757, 0.14287164404747948, 0.19067684819381084, 0.18702267008202692, 0.13063064686232997, 0.291434187562235, 0.21320113551712808, 0.1446252959149499, 0.15801721763226295, 0.3457181972842063, 12.563645839691164, 118.41981503271289, 98.76950140922301, 99.01367679719003, 79.48895746661772, 58.129561255055094, 33.03571170376193, 91.14323708318895, 112.0995117002918, 72.05551685825472, 28.83119171665561, 1.1796234115477533, 4.2201864238708255, 8.623854460254792, 15.572239083628501, 6.953221886388718, 8.342655820231284, 6.296632318727433, 2.768885925892861, 94.98734028108659, 106.61148040525376, 108.16048714422412, 98.56474584148776, 92.83179390814998, 86.69658722416048, 83.56740659283054, 80.9630234010758, 77.58610586966239, 77.9201662924982, 79.80955631502214, 72.56518963844546, 71.7903724793465, 72.95316696166992, 72.40525891703945, 73.86837359397643, 73.29065553603634, 69.33646709688249, 73.74602702356154, 71.56552653158866, 73.60515902119299, 72.7873997534475, 72.42829107469129, 69.09324876723751, 67.75508511450984, 65.56850102639967, 62.373907027706025, 68.26605227685744, 66.7464162457374, 67.33042578543386, 66.09203938514956, 64.0954549081864, 66.38204374620992, 76.32784089734479, 84.29910905899541, 83.29445669727941, 84.48775937480312, 82.45258269771453, 85.64826319294592, 83.29822217264484, 76.35374422996276, 71.61793724183114, 68.20858955383301, 64.17207056476225, 63.29394209769465, 75.56865046101233, 82.94816632424632, 81.26161775281354, 79.52386656115132, 78.28061642185335, 70.72547251178374, 66.71097370886034, 76.265271248356, 81.10974357974145, 73.70474799986809, 74.26399169429656, 77.87944424536921, 80.1344148574337, 70.50529418453094, 74.39677961411016, 79.92603501965924, 77.76966494898643, 78.64726389608076, 74.54041680982037, 70.67061424255371, 63.98134923750355, 66.86914720842915, 63.60151867712698, 60.448325295602125, 60.324256804681596, 60.72828446665118, 61.69524285101122, 63.18857154538555, 63.00478104622134, 66.37906274487896, 60.9199942311933, 64.40171357124083, 59.82247583327755, 65.17790748227027, 57.77796391517886, 63.88398816508632, 60.38645382850402, 59.30926507519138, 63.29072967652352, 63.85298967361451, 60.56485106868129, 62.912566123470185, 61.95382902699133, 63.848627997982895, 62.57499910170033, 66.70356042923467, 62.54579705576744, 65.70331681159236, 70.36193155473279, 82.5285433184716, 80.28627334102508, 84.94104416139665, 82.62890892644083, 85.67858311437791, 88.35963295352074, 86.83951839323967, 85.91911069808468, 89.79405157027706, 93.0901918103618, 86.87801253411078, 91.49353611853816, 58.13376995824999, 1.8387568814139215, 2.499367613946238, 6.271383531631963, 5.735700043939776, 11.628703801862656, 10.800653215377562, 1.4745084268431512, 0.7765847384448975, 0.4494319159177042, 25.719098890981368, 49.46635561604654, 65.05576879747453, 81.1599499179471, 26.94851483068159, 28.403600415875836, 43.622714396445986, 74.08750072602304, 75.98496298636161, 83.44376564025879, 83.74500366949266, 80.74628891483431, 24.871406055265858, 0.5436895355101555, 0.07655178782560172, 0.13767962103649495, 0.1663993226905023, 0.14409292609460894, 0.17208113635499633, 0.1614346745754442, 0.13153961018448876, 0.15309943877641233, 0.07143011466870386, 0.14370957569729897, 0.10463323098637405, 0.10497192611857768, 0.1999533149383722], [0.05244620309601869, 0.06679167445268362, 0.016647870089077664, 0.022731337906612505, 0.029895391893543066, 0.05640602730695279, 0.0752908147631153, 0.01479016911734136, 0.10088981895316994, 0.030622455298960693, 0.053378037973156864, 0.08811249893399016, 0.025043881558362516, 0.33807775726722133, 25.571598160651426, 79.63052365087694, 67.1038539948002, 59.08630578748642, 33.48040649967809, 27.211233223638228, 40.50684628948089, 76.68231333455732, 47.92345600743448, 36.37961464543497, 2.2719892859458923, 0.14091321687784888, 1.550338506217926, 3.766384129562686, 4.481640342743167, 4.0109787208418695, 1.1274649587369736, 1.073336495507148, 18.08053008971676, 101.96903367196362, 90.02589502642232, 95.43768329005088, 82.86280770455637, 78.85451409124559, 73.90150193245181, 70.180859258098, 69.92688578944053, 70.5394737182125, 69.01164777817266, 65.11913860997846, 65.65812326246693, 63.33719015121461, 66.015976782768, 63.37175407717305, 63.986620903015144, 64.24542280935472, 63.11229713501469, 62.468981358312796, 61.117214925827525, 58.951862627460116, 62.92761625782136, 64.02334997730871, 63.69800506099578, 59.32915933670537, 54.59254041794808, 54.8357665923334, 56.43973358215825, 58.22177225543607, 57.96370775468888, 56.98833196393905, 57.754708182427194, 65.8607764397898, 73.65723240760066, 76.78313393746653, 77.6049332464895, 73.51255970616495, 75.19586055509507, 74.5866144857099, 71.48382356089931, 69.69500310959356, 65.84704029944636, 60.82292341416883, 58.50507720824211, 56.606677501432365, 65.25362883844684, 73.55871815835276, 74.0457510179089, 73.67987232823526, 74.60667348677113, 65.43486979699904, 65.03437619055471, 69.61371591014247, 75.32628720806491, 58.489725051387666, 78.3459944878855, 68.70981354867259, 71.6621345089328, 65.05887923702117, 64.42271394114341, 74.34869920053791, 70.21587817899643, 73.72719180199408, 66.840576664094, 64.60121316294517, 64.9208039622153, 63.5688296441109, 59.03553462797596, 54.77227518635412, 56.053493868920114, 55.49271652775427, 54.72992143323345, 51.55842627248457, 54.92169395569832, 56.6433124388418, 55.10301336165398, 59.42947787623252, 56.66122198104859, 56.77038546531432, 55.97582701713809, 51.43951962071081, 51.01856300907751, 49.81155164780156, 55.05845523649647, 56.67697029729044, 57.50002084239837, 60.37747160080941, 58.74855833668863, 56.97998908258254, 58.914231408026914, 55.5902894081608, 56.67466394362911, 57.25001681235529, 71.69803204074984, 75.6687964162519, 75.4293514067127, 76.89860067059918, 79.6736304990707, 82.00846056784354, 79.49290337101107, 82.41494363354099, 77.2503980513542, 87.13553967014437, 82.10930470497378, 82.27036506898942, 80.66542533136185, 90.14952813425373, 76.69003255905645, 4.009791468420337, 0.8678381289205245, 2.761381696308813, 2.766988479322003, 1.9062901672817048, 1.9325373201600968, 0.3369071749189208, 0.09118411314463423, 0.8256794524288947, 29.386391447436427, 34.90112819979268, 66.43957707189745, 36.58011051916307, 16.63834910238943, 27.681297909828928, 36.261872937602384, 42.73002216892858, 54.79573095998457, 59.180548575616655, 58.95793053411669, 51.69870984169745, 5.101853849426393, 0.13880307365569378, 0.06249223580403675, 0.0419167420947023, 0.02111015413256903, 0.03288990510026774, 0.0012233176863857456, 0.07346983908885911, 0.05684891805773782, 0.057568684475676674, 0.03074550625657843, 0.06903348520638482, 0.06428740197612394, 0.03721473956360452, 0.02979537719980844, 0.0351347878665453, 0.03603582600912741, 0.03151083958425349, 0.02083163903725724, 0.0760756105545067, 0.04018077153652426, 0.040637030521587986, 0.030128077694004586, 0.045363505731426904, 0.09659391963073323, 0.13561150539786587, 0.16465051249871332, 0.28910963165183223, 33.83315309401482, 97.32660262815415, 76.84525643625568, 73.53335611281857, 43.4135304727862, 37.66686201095581, 41.32322096055554, 63.02263567524572, 57.57453018619169, 45.42242726972027, 2.2823497364597936, 0.36422593158579647, 4.270222629270246, 6.4221368874273, 5.428772126474689, 3.5838152035590145, 2.8350925926239263, 0.9620493542282813, 27.84557265620078, 108.97048011902841, 94.67362911470475, 99.73566747480824, 86.40843422182145, 82.1420721853933, 74.89616793970909, 76.53385946827551, 74.05033234627017, 75.91144992459205, 73.43489677675309, 68.18841288166662, 71.32018227731028, 68.47942921423143, 70.29455307991275, 68.13837128300821, 67.50935646795458, 67.10661534340151, 65.86996263073337, 64.82596889618905, 65.03184626179358, 64.41895631051833, 63.85726113473216, 66.04792056545135, 67.16395255058043, 62.99426124941919, 58.053094648545795, 58.90059724930794, 61.63178674636349, 62.51164105630691, 61.922226490512976, 63.0151439482166, 59.69423786286385, 67.69922271851571, 79.58078015235164, 80.29150578283495, 81.4077966443954, 76.86462510016658, 77.90483766986479, 78.4580252247472, 72.34467398735785, 72.70688918329054, 70.36131966498591, 63.83229917095554, 64.60447657492854, 59.68878576832434, 69.24270676028344, 78.97143210134199, 79.62234943143784, 77.11255027401832, 77.1850670537641, 72.03199048196116, 67.1748959633612, 71.79524406310051, 75.21642161953834, 68.43905233567762, 86.30173006365376, 74.82904834132042, 76.55456958278533, 68.85802422800373, 67.1751077713505, 76.78081189432453, 74.1205898407967, 76.63231880434098, 72.76462647222704, 73.00791540453511, 69.43762502362652, 65.2992146245895, 59.94996070861817, 59.32551153244511, 57.68076365993869, 59.19213917947585, 57.96590820435555, 55.493955996728715, 59.72279664008849, 60.47216546150946, 58.66807914549305, 64.26905116727276, 63.37537050247193, 58.79778015998102, 60.82973264878797, 56.9597065064215, 56.803698155187796, 56.428005695343025, 57.0040096775178, 58.75949782709922, 59.566203855699115, 58.138347364241085, 60.59364126574609, 58.55062769305322, 60.634339778654045, 59.307052858414195, 62.21494513173258, 59.56745116941391, 72.13317978766658, 78.01615453535511, 79.23120283311414, 81.02846422503072, 82.21955468577724, 85.28594601538875, 81.0322924583189, 83.38598128288024, 79.01433498628678, 87.65009972356981, 85.8581413761262, 85.25608108889672, 83.7285924726917, 88.76601403759372, 90.08179664611818, 9.726310141624944, 1.1042072648002257, 2.2354938378257136, 0.47273462518088283, 2.965723208842739, 3.065525711544099, 1.2818164762950714, 0.11357196020863711, 0.5203521684292824, 31.243135583016183, 46.22178669898741, 50.52025333527596, 32.05517603505042, 28.632884525483657, 41.863896154588275, 51.75614903050085, 57.629443368604115, 67.98711684442335, 70.15457153320312, 70.45016919412922, 68.50901957481139, 7.472814831041521, 0.19395018867667646, 0.06311084414201398, 0.0659387581230652, 0.03988878095462438, 0.06723795897297322, 0.020877908832663973, 0.04351774711282023, 0.010433648299846438, 0.06816618174554841, 0.023425666375025626, 0.06324670983538513, 0.0762249976997414, 0.05175800716143943, 0.1680906303226948, 0.1233616369145532, 0.1497324210621657, 0.13079334861568867, 0.15662053209399024, 0.13333901282279723, 0.09958330196358504, 0.1356305197001465, 0.21277068603423335, 0.09445212165554685, 0.1594399348382027, 0.21689200924048502, 0.2744501714985217, 0.6894218284756907, 39.581115938002064, 116.70155017606675, 91.50696631400817, 90.03231986876457, 56.47936128800916, 44.1269507715779, 59.05246357763968, 100.64687328953897, 66.51702034857966, 60.74722166984313, 3.401947891519916, 0.22414998752215218, 7.415201096765458, 11.4311477445787, 11.006407026321659, 10.87423982158784, 9.079828031601446, 1.5572161371669464, 28.32140518772987, 115.5436743459394, 100.3910327726795, 105.09281712193643, 92.29644529281124, 85.3812203868743, 81.08121225910803, 80.35420094766926, 78.1895782101539, 80.40545848108108, 77.97485197744062, 72.45125262968003, 75.664246466852, 72.78916482002505, 76.13517407448062, 72.53867441608061, 72.99428124581614, 72.28809771999236, 71.55132755156487, 70.1057929377402, 67.6200222199963, 68.71653649114793, 67.62296399762555, 69.54234446248701, 71.62673904049781, 66.82308289312547, 63.03701508429743, 61.68216174648654, 65.48215004705614, 65.87948614551176, 63.29699762405888, 63.693384508932795, 62.64900638211159, 72.29675046859249, 82.34372123595207, 85.60265387258222, 83.89104135574834, 80.43123629785354, 82.45694437334615, 81.93112711752616, 78.35365879920222, 76.72736567835655, 75.15265172527683, 68.53886096708237, 67.1680082813386, 62.71760471405522, 72.3257524736466, 81.83180486002277, 80.89515070761405, 81.40931067928192, 80.50949542753159, 73.88586736494496, 72.55518759450605, 76.56469714257025, 80.59474422085671, 63.652521256477606, 74.25407594250095, 71.9333742510888, 78.00507776198849, 71.51675578086608, 69.90226114949873, 82.34803584314163, 76.81342247993716, 80.50289015616141, 75.44940256303357, 75.50375876888153, 72.23635381267917, 67.96648517731698, 64.46119239253383, 61.45434264213809, 61.57333950842581, 61.53577889165571, 62.21426656169277, 57.91522725935906, 62.415837164848085, 62.88101850017425, 63.48924083094444, 66.62646232112762, 65.29451170275289, 63.52621701455886, 64.350797284034, 59.99970028477331, 59.882707749643636, 57.471540512577185, 62.093912555325424, 61.79797757056452, 62.942176095901004, 63.64841453490719, 65.42397345266035, 64.0113239903604, 65.0578986444781, 61.17399515644197, 64.69439691112888, 63.03745438975673, 77.08110855471703, 81.27290633416946, 84.38190244859265, 84.0030328689083, 85.73777952501851, 88.7341251680928, 84.33834060545891, 88.69666653294718, 81.09607019732076, 89.69439198893886, 89.9653571651828, 88.10247452028337, 86.30569950226815, 94.88684131253152, 85.56027658524053, 6.190518967566952, 5.343860656984392, 10.0825378394896, 5.78205265345112, 6.777520295112365, 6.87227201077246, 1.516285836696625, 0.13677804280192624, 1.5753401839925398, 48.07965655480662, 53.5272599804786, 89.27231357943627, 49.63105986195226, 25.209002494812015, 41.68773074303904, 56.535953244855335, 67.62590577525478, 80.46620815030991, 81.52050202892673, 84.90944554728847, 76.84630763146185, 8.672009398860316, 0.32270365965462505, 0.15601086400208936, 0.2049187904283885, 0.1617843171040858, 0.2101932904653011, 0.16142589520783196, 0.14233337535012153, 0.15415541437124053, 0.2877958215052082, 0.20965705956182173, 0.19761976515573842, 0.10550383628616411, 0.1465515780352777], [0.12048250229488458, 0.020852101245714773, 0.12919190309701428, 0.07016041586475988, 0.07041847258205376, 0.06874694534006619, 0.06989057671519057, 0.1034916986921622, 0.09751103412840637, 0.05202395841479302, 0.049414318205127795, 0.0478848006816641, 0.05078766870522692, 0.24998086354424878, 52.80563016091624, 83.50641373665103, 70.03291529993858, 57.84934712994484, 49.97886426987187, 55.269588578131895, 55.41730503882132, 88.56439636599633, 60.19009213293753, 19.67101393207427, 0.04811252797803572, 0.06841675378382206, 0.17209995147441665, 6.703425741964772, 3.0930717818198668, 1.7456703344660423, 2.2523639519368452, 0.49596228847099894, 57.32439279556275, 100.38599644937824, 90.76943520576724, 88.62850358409267, 79.34184505093482, 78.20610707806003, 73.77963389119795, 72.01441041884884, 67.3479195564024, 66.8796983841927, 65.60768158205094, 66.20745120509979, 64.24629357553297, 66.60525014323574, 65.50455462548041, 66.03427071725169, 66.04854029993858, 65.99332117265271, 62.98310210627895, 62.88479966502037, 62.40653330279935, 62.90224636754682, 61.03279375260877, 63.94147049996161, 63.076917356060406, 55.88433381049864, 55.79893988947715, 54.76625042576944, 55.06883382797242, 56.78534538515153, 55.559879272214836, 52.32617532053302, 62.71531012750442, 73.9953250269736, 73.53734124091365, 73.65653422570998, 77.60502738337364, 75.6403043193202, 71.10865669865763, 71.84623487534063, 68.4998098496468, 66.14169659153109, 64.59032074097665, 60.39996247137747, 58.763667306592396, 55.27353840489542, 60.19782704691733, 70.29234086313556, 74.57330196134507, 71.33996671245944, 74.00629981871575, 62.096054169439505, 66.63251061593333, 69.65170798763153, 76.95864431319698, 47.59616951788626, 72.17529035383656, 63.99495593963131, 69.16493400450676, 68.22820924943494, 63.43137018142208, 73.58490390162315, 68.70556954414614, 73.54150679803664, 69.73859633168867, 67.43785165971326, 66.92925360894972, 70.9373354142712, 70.87997467287126, 58.90900681095739, 54.37818288803101, 58.18802810484364, 54.564432713293264, 52.18670760431598, 50.62798123205862, 55.003165506547504, 53.71432958110687, 56.244983980732584, 55.870252501580026, 61.343010087167066, 56.4323163801624, 51.025042764602176, 50.333156278056485, 48.37426970081945, 49.80213011464765, 55.38040338024017, 56.038000506739465, 60.7969141775562, 56.56226450397123, 58.62264240941694, 54.29225944703626, 58.10621530778947, 56.50606478414228, 59.77333637975878, 70.1312961886006, 77.95407910500803, 72.16112275277415, 77.32359732350996, 78.33335661119031, 80.2712663527458, 80.22958724729477, 74.42986088414347, 80.4676123588316, 76.33593666938044, 75.2880911673269, 84.28781263289913, 82.7995712526383, 80.58260840754356, 80.98152129880845, 85.70766356683548, 3.99076184438121, 0.9087183578841148, 3.4343655455497006, 1.0696987423204607, 2.1106705357951503, 1.0175814743964904, 0.13779620429681194, 0.08207124447630298, 11.135567734318396, 31.733967258084206, 36.5290020358178, 58.25734815289898, 29.314876833269675, 17.689548230940296, 16.663854314434914, 25.442601211609382, 32.82428026199341, 53.371926276914536, 59.86087191489435, 68.26695442199707, 27.034163705764282, 0.7562777087573083, 0.023258004202357224, 0.06238199575173278, 0.08148951561100061, 0.02978106284694326, 0.03654405256853469, 0.08517976880313889, 0.09445842655916369, 0.02372001459251248, 0.013499176899542012, 0.052053123382070375, 0.03404597008240319, 0.09660046968248584, 0.010585108670526215, 0.06030375243074471, 0.04997669568946285, 0.024419119619133494, 0.021035134972583865, 0.06468387545957681, 0.04261733333189641, 0.10436775087709389, 0.014874473262968806, 0.018735145586693, 0.029958239831631223, 0.034210066115784074, 0.011459380658643862, 0.2264722298470236, 69.0325383217104, 97.3106699605142, 80.82073550070487, 70.17331261788645, 60.704675720584014, 56.4130614649865, 56.18795664079728, 79.102886415297, 73.67192560626616, 22.903039109322336, 0.02647194797323356, 1.8231687694787981, 4.013900886620245, 6.083480917638348, 4.918694851859923, 2.3544330943015317, 2.40728065852196, 1.2252973284452193, 68.30915128031086, 106.4170563605524, 96.33049318867346, 97.44434433598673, 80.75627526929303, 82.7034810281569, 76.76664429326212, 77.84126389411189, 72.35757074048443, 71.42225019393429, 67.3650210903537, 70.41516596271147, 67.36287947623961, 70.39018046471381, 68.14196417408606, 68.67795605813303, 66.7738728369436, 68.62023445867723, 65.18589735031128, 65.64364971653109, 65.15607164752099, 66.42056142130207, 66.08863476783999, 68.0439833671816, 64.43853678241854, 58.40894383768882, 58.26197262733214, 59.17527298773489, 60.316251247159904, 63.10511919759936, 59.890019047644834, 57.48684952335974, 66.63504446706465, 77.8045661987797, 79.30275470979753, 77.89038765814998, 80.31583232264366, 80.88583115608462, 76.9205737883045, 77.463178788462, 70.75647492562571, 70.58491045428862, 65.52735536329209, 62.84238315397694, 60.94749004610124, 57.474144966371604, 64.7750408418717, 74.92436978124803, 78.58183876160653, 76.15882596661969, 78.1181832282774, 67.69831272863573, 65.73628433289068, 75.14734868080386, 74.9172624464958, 65.08830878042406, 87.66075288095783, 73.76796876230549, 72.9257417494251, 70.84587358659314, 66.01232113376741, 74.09618485358455, 70.31668309242495, 73.97794108236991, 72.42070521077802, 74.26075181653424, 72.31088669069352, 76.14634498473137, 74.92242428564256, 64.03090838463076, 57.142575248595215, 59.49994325637818, 56.07798907064623, 56.46322857949042, 54.69749519901892, 58.412740692015625, 57.424562285023356, 60.66943322458575, 61.88103768133349, 62.47016591410484, 59.481292386208814, 56.738033756133056, 53.744657347279215, 53.80649743541595, 55.06471926166166, 57.60984720722322, 60.17276702388641, 60.512130491195194, 59.08515653302593, 60.357969576312655, 56.96021641454389, 60.0552410464133, 60.10975022469798, 60.43260835832166, 71.46000692921301, 80.04383948541458, 75.17511121688351, 81.23101542072912, 80.49061313752206, 83.25907691832512, 81.32422662550404, 76.79958435796922, 79.39454601657006, 80.15532109045213, 77.1342174468502, 87.98864733788275, 85.7698723577684, 85.99423193162488, 80.3282819255706, 97.38404181695755, 9.136847526796403, 0.7033201343109531, 1.502755253065017, 3.364412525007802, 3.359171993309452, 3.3149806097630536, 1.1407915791196208, 0.14582010196341624, 8.762522993549224, 41.444347673846835, 41.88507303114861, 39.501868371040594, 24.81707730600911, 27.842103319783366, 35.414068314336966, 45.005075316275324, 40.873634969034505, 64.65650681526431, 68.38779480226579, 82.29477790094192, 38.97628645743094, 0.7544854307366956, 0.1690768612728965, 0.07835171906457794, 0.02726687144698395, 0.003776513255997411, 0.07697157336459046, 0.03232452455126951, 0.037394831512844375, 0.030434930381635507, 0.02816527999276596, 0.01654404410791974, 0.03804198811731992, 0.059629568244300546, 0.20823224327496945, 0.10802595861135952, 0.19119624048471454, 0.14526248188509097, 0.20947604830707275, 0.33069227131143697, 0.3270316580610891, 0.19089075526402843, 0.2597765846838874, 0.15047122093458332, 0.15589670157961308, 0.18418154108428186, 0.05844841771308453, 0.24634976000074418, 81.55273606700283, 113.83298750846618, 96.99831593421199, 81.54242807818999, 71.65760809375395, 71.7121761075912, 76.08768201643421, 106.1625494495515, 88.54261936679964, 33.04177568804833, 0.1285927763749515, 0.99367689581648, 4.578029157653932, 16.051929266222064, 8.545487465397004, 10.175077338372509, 7.573729570834868, 1.3441064112609433, 70.3052846847042, 113.0249478740077, 100.58642172044324, 100.2649050374185, 86.56986328863329, 88.49345637905984, 82.38427069879349, 79.41531888900265, 77.82827300410118, 73.77559384992047, 74.12833259951684, 75.3205919265747, 71.57051578644784, 74.90103167872276, 72.91031898990755, 73.09009690438548, 72.18492369497977, 74.8832005839194, 70.30067197738155, 72.16041672614314, 71.0413880502024, 71.29138423550513, 67.24177237479918, 70.98464704328968, 69.28684126946234, 63.129371212374785, 63.64293498377647, 62.33617382664835, 61.805080982946585, 63.98338102525281, 63.12278555285547, 57.952117150829686, 71.3643560101909, 82.33183645432996, 82.7025318145752, 82.03669378834387, 83.93938064575195, 83.89010783164733, 78.18887218352288, 81.5580940246582, 74.10522199446156, 74.68846274960426, 71.2499326275241, 68.00121384282266, 65.65038834848713, 61.01142075753982, 68.731857269041, 76.05078035785307, 81.77251431249803, 75.96103652831047, 83.02299730239376, 70.21732161121984, 71.70259767963041, 80.0649889053837, 81.3488277312248, 54.72538717331425, 70.81007019166024, 68.76476595478674, 73.72161419160905, 75.24607473804106, 68.92093904556768, 81.03706990518879, 73.02277334274785, 79.47199713799262, 75.18698030902495, 74.62348476532968, 72.93614387512207, 78.60041510674262, 78.9181427801809, 66.15588772681453, 60.7402829970083, 65.76113254793229, 60.560352110093646, 57.34778188890027, 58.81037096823416, 61.582474708557136, 61.148327166034335, 64.45443414872693, 64.12946185758038, 66.47330161063903, 64.38034449854206, 59.714712635163345, 57.51852658487136, 56.18133175757624, 57.82745245964297, 61.21272856189359, 62.531197993986076, 65.79863040677964, 62.91031468299128, 64.83072280883789, 60.56800073192966, 62.85737445277553, 63.197832261362386, 63.835864605442175, 78.04967511084773, 83.01301094793504, 78.68933523854902, 83.40992343041205, 83.51292487113707, 87.75758835577196, 86.09136550657212, 78.02169292203843, 82.22660710734706, 83.69609955818423, 78.80312319724791, 89.85435408930626, 89.14269493472192, 87.69972555098995, 87.35414904932823, 94.1608419725972, 5.7707694653541814, 3.998690425388275, 11.669456247360477, 7.206726141514317, 7.36727120414857, 4.141687539315993, 1.144466962545149, 0.23865431487079591, 18.764667933987035, 52.1457149136451, 53.69061493104505, 77.65872463103264, 38.69422097359934, 26.91627883142041, 28.039331859157933, 41.22724448480914, 52.750207070381414, 76.55602870448944, 79.7096457019929, 94.60085345852761, 45.95306904085221, 1.0714620928610525, 0.2583890155919137, 0.19868145576648175, 0.2275637365997799, 0.1174630050457293, 0.13637242988953668, 0.19237538769600854, 0.23181733254703785, 0.1620152772914979, 0.09476065590617158, 0.13626894673272488, 0.10232357548609858, 0.11876199139101852], [0.04533989107116096, 0.03483699033817938, 0.10177019953487382, 0.024475944190916997, 0.04408011310583642, 0.15003560801907895, 0.12415741074589953, 0.06695658253926424, 0.08824739935657672, 0.00620086073702682, 0.03408999332497197, 0.004057210744283493, 0.22229711194672894, 1.4050437413877057, 66.94113839057185, 66.09283954866471, 64.05155574121784, 36.05022184310421, 37.267090120623195, 67.07955098921254, 68.94816029456355, 77.10909074352634, 47.41370477984029, 6.006261706352235, 0.27494491108002206, 0.4601439088582993, 3.314790374809696, 5.246553517157032, 3.3371456784586755, 1.1978268863693362, 1.5348049397430115, 2.2934635271949153, 79.52429017712994, 97.22887285294073, 95.12772975429412, 91.3979793364002, 86.55027497199275, 83.23475822325676, 84.7374653047131, 78.79352123506608, 80.07322588274556, 75.66507800932854, 74.89434011520879, 68.27010800761562, 63.33335015081591, 63.256542298101614, 62.091951370239265, 64.65984475228095, 64.82336052002447, 65.47955343800207, 62.6301750829143, 59.82721797881588, 62.51833654219105, 63.18840288346814, 61.51639453826412, 63.73030970173498, 59.822428764835486, 56.66742717066119, 54.99535214516425, 52.46135980852189, 53.7888506920107, 56.890182495117195, 55.46399301098239, 61.32012697958178, 72.21782453598516, 76.71260972176829, 72.95129206872755, 73.58096584197014, 80.42284242568478, 71.17547035217285, 71.3375505324333, 68.22123527526855, 65.06418620386432, 60.468556880950935, 60.66670325494582, 60.18996661709201, 56.97678450615176, 53.89884571875296, 59.584121242646255, 68.59826918571227, 76.50195490929389, 72.60475850874379, 71.40241084560272, 60.2645230293274, 70.33519667963829, 70.14580111349784, 77.68438477669993, 38.46542127670781, 53.95384911567935, 56.03458804468955, 63.81814725937382, 66.72865575359714, 63.531021918019945, 68.83395656462639, 68.84912044771256, 70.36813674434539, 69.50395230324038, 68.31708231279927, 71.22744960169639, 71.0807921809535, 69.15739520903557, 65.42333410632226, 52.837868121362504, 55.678617262071185, 56.3920493279734, 54.68168804722448, 50.30655084117767, 54.291322000565074, 52.29946397965955, 55.57194840523505, 56.948068834120235, 59.90756773179578, 54.003165075855875, 52.08055650034259, 48.841208257982814, 47.20618394113357, 48.110859009527395, 53.82730168680991, 57.80718165059244, 59.274897267741544, 59.81382308467742, 58.041307926177986, 55.52462893147623, 56.742689609527595, 56.27358198165894, 58.0189621833063, 66.08806210179483, 76.88720226287842, 71.46824390657487, 80.02628295652329, 78.00204969221546, 78.74956715491511, 76.83698807993244, 80.64902197930121, 74.0968438117735, 77.8025265662901, 78.51493097120716, 80.59435198383947, 78.53584504896595, 85.63549195566486, 80.12006682734336, 88.37282780678042, 72.23036043105587, 0.585509846287389, 0.5557051649497402, 2.5711764058759137, 0.9808187535212887, 1.8757431161019111, 0.6206247426809803, 0.06134986081310819, 0.9309393203546925, 23.36463147594083, 30.461056155543176, 62.12071803308303, 69.478927581541, 29.749771587310303, 18.24239061724755, 12.929282323006662, 21.06231197234123, 41.69697576953519, 59.721153166986284, 66.00496276732414, 56.732209036427165, 2.9170806705951695, 0.1271742726525953, 0.05025491584092379, 0.029858679044991735, 0.15635846873685239, 0.02317307569507149, 0.021065205838831685, 0.07526779382099068, 0.07218822761769257, 0.03016360310627328, 0.05589371749890908, 0.008301447491131483, 0.061909078184755585, 0.02033059263692027, 0.06391856128409987, 0.013887050088434933, 0.013387306995179146, 0.0585093868205384, 0.06168097167486145, 0.06425807613038248, 0.08678119133917556, 0.07382594739958163, 0.008227755578475134, 0.05505236143606806, 0.02778175914089286, 0.3340749172193389, 2.287711126189078, 89.75608302700905, 78.4357540069088, 73.79193444405833, 47.73616283170639, 54.35431918790264, 66.55221969850602, 59.99826077492007, 83.17436941208379, 56.8332806710274, 6.521945518832053, 0.6321171034247645, 1.5827709917099246, 6.572525462796611, 7.155917719487221, 1.8677697955600678, 3.377336979873719, 2.4049473385657034, 4.699657444031009, 89.7276536880001, 97.30181324866511, 101.86255701126592, 92.88633054302585, 91.75188695230793, 85.87317189862652, 89.89955548317202, 82.1848887781943, 86.20790696913197, 81.52797022173482, 80.20201298498338, 72.74141388554727, 68.02289670513522, 67.19823406588647, 67.26566745388892, 65.53670237141272, 67.28731109249976, 66.1786453185543, 67.25057417346586, 64.41177837310299, 66.81697184039702, 64.22662681148898, 64.74743912296911, 65.59225097779306, 62.88580771415465, 58.055965823511926, 59.98277133510959, 56.21142418153825, 58.02397105001635, 57.8352265973245, 59.74668779680806, 66.456388350456, 75.42211855611494, 78.82177798978745, 77.2801374620007, 76.22900501374276, 82.94498920440674, 73.70907045179798, 73.20699138026085, 70.38328493795088, 67.37138317477319, 64.23447155183362, 63.499254641994355, 61.970844268798835, 57.89912200743153, 57.88943767547608, 62.11829793068671, 72.4282596957299, 76.99305134434854, 77.94860347624748, 76.97325121971869, 66.05754606185421, 72.1752275959138, 75.93121867026053, 77.43160370857485, 55.71914711306172, 70.6075111512215, 63.938430663078066, 67.4553140517204, 72.11540360604563, 67.34056903469947, 69.27655681487053, 69.36210370832875, 74.18656410709505, 72.84034390603343, 71.72976401544386, 72.48889169385357, 76.90390371507215, 72.635925662133, 69.05961052063974, 55.96342840502339, 57.53433765903596, 57.788864181887725, 57.66125771307177, 53.31110208265243, 56.2997991038907, 55.79882221837198, 58.39855740147253, 60.45865681863601, 63.491139258107836, 59.33291696733045, 56.67491889769032, 53.2942045119501, 50.441358781629994, 52.66998283324703, 56.76484315626083, 59.69632456379553, 61.67903953982938, 62.974661165668124, 58.156715823758034, 59.04091219748221, 57.744686526636926, 57.45060290059736, 61.75655341917469, 70.92552123531219, 77.61146007045623, 75.86335382153912, 81.81075742167812, 81.69152521318006, 81.21339613391508, 80.04441999620008, 82.577651393029, 77.23032336081229, 80.81846837074526, 82.88835802385884, 82.37679466124504, 81.56104364702779, 84.4746978821293, 85.4434056435862, 87.31559999527471, 88.2985459604571, 1.603942352437204, 0.7045811150343188, 1.5637850040389647, 2.21020239495462, 2.631973143546812, 2.3965044367697934, 0.15026056207716465, 0.41684063572076063, 25.894981891878192, 39.083096519593276, 48.91659621269473, 33.37482806174986, 21.39663519397859, 22.366656949443204, 20.3546908978493, 31.549376595404844, 49.92508073006907, 69.66143546565887, 72.59514870182161, 73.32818477384507, 4.96488223152776, 0.14921708903726072, 0.015653949531335986, 0.024127165426410014, 0.018031382745492364, 0.006966320469209384, 0.09774727266161673, 0.05829069936167329, 0.03968187592803471, 0.045045211520646854, 0.08532708751097803, 0.04955149773928908, 0.0678947338113381, 0.14461395781367056, 0.3242807282555488, 0.22473915510119932, 0.2293733435292398, 0.23315003442187465, 0.3214993694376561, 0.1733844970623332, 0.22004865921072422, 0.2542768547972364, 0.12737373130456095, 0.16824887344433417, 0.1727704469475054, 0.5877259241477136, 3.4161218664338513, 103.98058199113416, 93.61606397936421, 88.66421284214144, 55.49290872389271, 56.95463880415886, 75.444609426683, 88.66247915452527, 95.39819286715601, 67.53689150656423, 10.381122385301898, 0.8702502640024309, 1.226558247881551, 7.463637465430845, 11.781802735021039, 9.773334457028298, 5.177540884863946, 3.6360636257356216, 5.499403717056398, 98.36913724099436, 102.95638838121968, 108.37042024058681, 98.74502581934776, 96.82962263784101, 90.06717405011578, 94.38818254778462, 85.95228610500213, 89.79098427680232, 83.38273356037756, 85.01494946018343, 76.54503037852626, 72.02434970486549, 68.83746316356044, 71.63663910281274, 72.33557408855808, 71.82725844844695, 72.59080271567069, 72.78862353294127, 69.11588868787213, 69.472212483806, 69.19667382394114, 67.23803043365479, 69.3986915772961, 67.71712441598216, 63.627045462208415, 62.92611791241554, 58.95110561001686, 60.73340315972606, 63.14779458507415, 62.69902444654896, 67.9842064457555, 77.29019441912251, 82.62704187823881, 80.77380826396328, 77.81685890689974, 88.99118946444604, 79.463469905238, 77.85019120862408, 74.62196288570281, 72.76894107941659, 69.0317616924163, 71.25926002379387, 68.11252286357265, 61.38781924401561, 60.78765346157936, 65.5574320977734, 74.31264477391397, 82.51631336827433, 79.76633179572322, 79.31907176971436, 67.83216753313619, 76.99690311185776, 80.56657375827913, 81.74111966163882, 48.212781798455026, 60.0354487665238, 58.9928827747222, 71.27138014762633, 77.36204439593901, 70.95679821506624, 75.50073854384884, 72.71193335133215, 75.73955597416048, 74.84912303186233, 72.11184993866952, 74.53857329583938, 81.95004078649706, 75.59507939123338, 73.4699627660936, 57.8873941206163, 61.626923007349816, 62.08871149247693, 61.85533831196447, 55.107190685887495, 60.88768174571376, 59.83591779585808, 62.187417937863266, 63.960913688905784, 66.26754191613966, 61.6960390921562, 59.734701033561464, 54.805270164243645, 52.6397099802571, 54.74333986159294, 60.41155699760684, 62.9307423868487, 66.89718431042087, 69.022763775241, 62.08730336158507, 62.88893776555216, 61.4072310539984, 61.79027011317592, 65.35487305733466, 75.57194525195708, 82.75975135064895, 78.39157242928782, 86.27441467777376, 85.80249078812139, 86.92763051679059, 82.02514633055657, 85.38570757835143, 81.62107944488525, 83.95600365054223, 84.68009671857281, 85.87829451407157, 86.05098078327795, 90.69003074399888, 87.49289897180374, 94.99360038388161, 88.10747946462324, 0.8924397862245961, 2.6430781089490463, 11.391034645418967, 4.817438375565314, 7.065533563014, 2.3861638432548893, 0.1615861761233499, 1.6396371467459587, 38.3717550769929, 50.14789096770748, 83.67018053608557, 90.85604898391232, 39.3157087602923, 25.3570641240766, 21.9538902467297, 37.95605051902033, 61.990781676384714, 81.7818417087678, 83.04083624193746, 85.40983015491118, 6.550453795540718, 0.5291539670959596, 0.24544775275693786, 0.13461762889017984, 0.30060766144625606, 0.112323964675588, 0.12024626376167422, 0.16526497630102022, 0.14412959106266499, 0.1892502852264912, 0.2418365368559476, 0.1625795776565229, 0.16311154911114326], [0.08469354045847732, 0.050226007513101065, 0.008700290101490194, 0.01989050576793811, 0.11954993580377872, 0.1268779345217251, 0.09619928475829864, 0.10331870071710118, 0.03159258499621384, 0.08045352725011688, 0.06470709558456175, 0.10899904349278058, 0.4483427227504792, 9.257547682331456, 84.94841037258026, 67.67007166339506, 71.26940327305948, 34.87953555199408, 37.67960971401584, 74.6528946968817, 94.05747967381632, 69.01396982131466, 34.742452636841804, 0.43074001407911705, 0.08207721230123313, 3.2047990252894745, 2.0979664691032904, 1.8685399284285886, 2.1631780795512663, 8.094788501339576, 1.844084930996741, 25.284666976621075, 113.64719267814391, 96.56040683869394, 96.0206808582429, 91.13910290502733, 98.21581179095854, 91.5528815792453, 90.05151594838789, 85.76795039638397, 90.60265602604036, 90.67633382735714, 90.59649006012948, 82.67507522336899, 74.61804836027085, 64.96282039150115, 65.36113708249985, 64.55942423112931, 65.49201873040968, 63.08709198428739, 63.654874678580995, 59.65710086207236, 63.64119345141996, 62.29755416993172, 62.68894787757628, 60.49523684286303, 58.06595610034082, 57.13267126391011, 58.263321922671416, 54.40432156285932, 52.77461990233391, 53.96887179343931, 64.16320993054298, 66.88083587154266, 74.9904146502095, 73.40580847955519, 73.76584283767208, 73.36856949713923, 77.90431207226169, 69.41565190592121, 67.08388128588277, 62.3275093109377, 58.67054239396126, 56.23153417341171, 58.625019365741366, 56.088348050271314, 58.50234331623201, 53.246022116753366, 59.2713906688075, 65.99790250101398, 74.04662178408715, 67.39794546558012, 71.92170912219633, 63.81767265258297, 71.93244857172813, 71.05900733701645, 66.72012067610218, 26.35083975330476, 27.16156032777602, 45.6682578979, 61.71835737843668, 64.40536922024143, 70.41267918002221, 71.3525967444143, 70.13109222535165, 68.96269659842216, 67.1351231298139, 66.1219435353433, 69.48884333333662, 72.1674063897902, 70.83504784491755, 60.341852557274606, 53.82810185032507, 57.80008608295072, 57.16451306496897, 54.78422664826917, 53.15547027895528, 52.18595058687272, 50.64927185735395, 52.079940688225534, 53.029413146357385, 57.08888584567655, 55.3045408187374, 52.566271443520826, 51.334847250292384, 48.25499434624949, 47.57040346822431, 51.09229180120653, 53.54010966516311, 57.06524179827783, 57.603469433323035, 56.48150290212324, 52.259020420812796, 55.835559137405895, 55.05143419388802, 54.56848452168127, 60.6520139786505, 68.94825443144768, 71.02776173622378, 73.51771370057138, 76.31059031332694, 70.99766146752143, 75.96031481219877, 74.41890962662237, 80.78810922561154, 77.29273611499418, 75.34007826159078, 71.97513964868361, 77.09813948600524, 73.3460315581291, 81.66934028748544, 75.70838882077125, 91.91303360846736, 31.151277595950713, 0.746600915107035, 1.9087512094166972, 3.2902118227174206, 2.818243806400607, 2.692627695298964, 0.442982099109119, 0.499176578896661, 11.404320693785145, 30.821482750677294, 36.82913787903325, 66.33014294408983, 70.96038326140373, 86.16846361467915, 35.27776987321916, 20.036227780003703, 27.217267790148338, 49.545399219759055, 52.683169841766365, 68.58844757080078, 17.295775605786233, 0.5057054559790319, 0.08276757243419848, 0.0320979425563447, 0.1075919085152207, 0.11040565753055197, 0.018740489049964858, 0.0974840525117132, 0.06909950666369931, 0.020641591775441365, 0.032416179310530424, 0.0777294947915981, 0.021267824603485006, 0.06877390397412163, 0.10700693909799862, 0.09254365874033782, 0.09454104914179734, 0.059853139513682936, 0.09325964451437035, 0.078085488189132, 0.08284880839768918, 0.04831449939839302, 0.021218626436987714, 0.009658515750009929, 0.17366330710149583, 0.4819679764970657, 14.23137389844464, 101.3463338728874, 78.47949627907046, 83.82123101142146, 44.63325423579062, 44.393460135306086, 70.59586171180972, 83.20731732153124, 77.11933597441643, 37.48335392244401, 0.2351487884598394, 0.10090765348004718, 4.745880615326667, 5.018395618084939, 5.971978229861106, 3.988921517325986, 10.432546619446049, 1.29489267785703, 29.678859056965, 115.56704382742606, 99.1301868807885, 99.86872996053388, 94.13494648471956, 102.08094673772013, 93.07168606788882, 95.38885762614589, 89.27311374295144, 95.66859322209513, 91.70568143167804, 96.73594074864542, 86.79254408805602, 78.86186461294852, 67.19992068506056, 66.65152626652872, 67.04843874900573, 69.63259035541166, 66.14154754146453, 65.65398123956496, 62.479320726087025, 67.24992306001725, 64.51807460477276, 66.34242780746953, 63.72333964993877, 61.06703604421308, 60.87576166276009, 60.818114588337565, 55.988951267734656, 55.51426995185114, 57.06471620067474, 67.76398105006065, 71.21263088718538, 77.89198014043993, 76.92304488151305, 77.33468978635727, 74.38651869373938, 82.58853204788701, 71.40895335905014, 67.97897400394564, 65.83464560970184, 62.9887620864376, 56.770471757458104, 60.06887520513227, 57.46893998115294, 59.83435277015933, 55.03156346659507, 62.70225647957095, 68.68871904188588, 76.20977755515807, 71.04612627337056, 77.97486766692131, 67.2872640240577, 76.86732369084513, 73.94234165068596, 70.66378147371354, 38.867883912978634, 39.39614872778616, 55.48112592389507, 64.56949295536165, 69.77094804086994, 73.69656593568864, 71.60352645381805, 72.39437826218145, 72.8134992045741, 68.6426390371015, 69.01919441838419, 72.88021087646484, 74.6219942646642, 74.57641632326188, 64.09493715532365, 56.61900158851378, 58.594071865081794, 58.32157696447065, 56.860195975149836, 56.27598639457457, 55.843172457910356, 53.69216426726311, 55.41600673429428, 57.259638386387984, 62.2631000703381, 59.487030813770915, 55.137534141540534, 54.452754989747085, 50.23434000630533, 52.31342369510282, 53.60031804730816, 58.53710728306925, 59.56528209870862, 59.94039012539772, 59.57708451055712, 56.087759694745465, 57.16468957162673, 57.51625945491176, 58.730601726039765, 64.65019179928687, 72.45058582675073, 73.69534215619488, 75.77324913394067, 78.25163795102027, 75.67093018562564, 79.41781351643225, 78.41050963247977, 81.93300201046853, 78.77206587022351, 79.07117013008364, 75.53161544184532, 78.27208134435838, 74.72412493921097, 83.4047459017846, 78.40697949932468, 93.70604315111714, 40.417914390563965, 0.7888859654626539, 1.3243406073700998, 4.459489247491283, 5.277818729800563, 3.7876129775278033, 1.762171378058772, 0.5943796735617423, 9.06199791739064, 45.91912484938099, 39.434619334436235, 54.0209569469575, 53.42885555759553, 57.864436487997736, 32.1069219035487, 32.52852178389026, 35.90354873288062, 57.593679197372936, 60.98994970321656, 81.59893374289237, 24.836961761597667, 0.6013006344437599, 0.03796403867102439, 0.0570947518421998, 0.10581632355047811, 0.03561248582217001, 0.019938026201881228, 0.08242327719926834, 0.0426200682657861, 0.03290000596954938, 0.03083691395248377, 0.1315952588113085, 0.012707950757636179, 0.20973385221535162, 0.2442403522229964, 0.2109696592895254, 0.15161647641610715, 0.18104097896045257, 0.3235450080565868, 0.18704502452765742, 0.31170686586729945, 0.20166397395153202, 0.19364507117819404, 0.3165045068148644, 0.3124594400005956, 0.6899196017653711, 16.16975824679098, 120.6532596772717, 89.2792247956799, 97.75902040543096, 54.39059326725622, 51.293038706625666, 80.54012129383703, 114.40569277732604, 88.9847646221038, 52.90405811802034, 0.7700217551281376, 0.23849607174915655, 7.386147120306569, 6.086704615623721, 6.876577302332848, 10.135670265843792, 14.934828435221027, 2.25449453438482, 30.689749948440063, 119.04045950981879, 103.80710340315296, 103.4154704309279, 100.36648658014114, 108.00512206169867, 98.06544380803263, 99.70948173153786, 92.8879387147965, 98.05320601309501, 96.29101061051892, 102.83929778683571, 90.88032845527896, 82.69809953628048, 70.67773726678664, 69.8403347692182, 70.11367690178656, 74.99625898176625, 71.79500872089018, 71.52302372840144, 68.6605485793083, 70.95529202492007, 70.11286889353107, 71.2497914221979, 67.12613305737896, 65.4573606675671, 65.8708804653537, 66.28381975235479, 60.74133811458465, 56.90871177181121, 59.502182929746574, 70.34568509747906, 70.9990970550045, 82.9113588025493, 81.67074449600713, 80.41139694952196, 78.4387428529801, 87.42059400004726, 76.93362743623796, 71.5888410998929, 69.66951554821384, 68.1730293458508, 60.973020753552845, 65.03248953050183, 61.07994456445018, 64.22834873199463, 57.75287643555672, 66.52605748945668, 71.29409067092404, 77.94976449781849, 71.8274231879942, 79.43522883999732, 69.1838006050356, 82.65975444547593, 76.3844406989313, 78.94481489735266, 35.207390785217285, 39.888735663506296, 53.298095503161036, 68.84977940590151, 72.19929525929113, 78.86785014983147, 75.77473963460615, 75.81660701382545, 77.20838162206834, 70.97681799242574, 71.23213291168213, 74.34506708575834, 81.63584324621385, 77.99463641258978, 68.30417771493235, 59.25291630529589, 62.891495150904504, 62.1390276570474, 61.44736474560153, 58.509493797056145, 59.73192007310929, 57.43945552456764, 59.280957329657774, 58.55312624285298, 65.33151142058834, 61.51112287275253, 57.335563705813506, 57.54679510670324, 52.73763195160897, 54.35993994435957, 57.1691846078442, 60.86046049671789, 64.15132907129103, 65.19096505257392, 64.77305612256451, 58.77954506104993, 62.9382654928392, 59.55687645942935, 62.368984453139774, 69.5270864425167, 77.97564429621544, 78.58572975281747, 79.64841750360306, 83.97832193682271, 79.45874737155053, 83.07601205764279, 81.16191110303326, 88.23271289948495, 81.88753389543103, 81.84354059157833, 79.74737105831024, 84.78346686209403, 79.48914574038598, 88.97399379361062, 81.37530372988793, 97.93315010686075, 37.304654659763465, 2.025816921264895, 9.017999710575227, 8.44036304181622, 9.010922774191826, 6.297405025651378, 2.0565128999371685, 0.7780408570843359, 17.35821581655933, 56.45523478907924, 52.917292194981734, 90.36034768627536, 90.59431706705402, 103.81544236213931, 49.41258384335426, 33.21002575658983, 45.00325925888554, 68.78495047169348, 69.91644444004183, 96.40593605656778, 29.132208131974746, 0.8470292197119805, 0.33356644934223545, 0.15105249780801036, 0.25230304458208624, 0.12200635842858784, 0.12728501832292927, 0.15125065411050476, 0.21520419496922724, 0.15455813147127628, 0.39120151150611143, 0.26323381691209735, 0.13915193477465262], [0.10077686694961402, 0.06825028287787592, 0.06419198955559442, 0.07334524254885412, 0.0765639533018393, 0.0408599084813989, 0.18026341503906637, 0.025710525524411953, 0.035408534064528444, 0.06896950920382816, 0.09714959384573084, 0.11046355845586908, 0.3568765130494872, 35.70933649616857, 74.23959455182477, 62.86494070483793, 54.924882842648415, 42.58924830344416, 36.693698436983176, 46.35875978777486, 82.10989306049963, 49.90698291409401, 11.406670193518362, 0.0919476576570061, 0.8991844855969953, 2.078944444656372, 6.052961445623829, 3.9393278043116298, 3.096114315332905, 0.9116610548188611, 1.5331419773640171, 47.99963235855103, 87.5923232109316, 104.37329753752678, 100.37882635670324, 96.67632856676656, 96.39969164325346, 96.4428141809279, 96.97919045725178, 89.19872207026329, 91.27244780140539, 90.06358900377828, 91.50427556806996, 88.41459320437524, 88.4954018746653, 76.23244885475405, 65.02857108269968, 61.18912766056677, 64.65711478264102, 63.52554236688922, 66.07420044560587, 59.48297900538291, 61.89769206508514, 62.81639352921517, 64.11922054906046, 55.67273370681271, 57.277018408621515, 57.837913420892534, 56.65159256227555, 54.684931847356985, 52.88295576649328, 59.52349708926294, 67.66086193823045, 70.38821927962765, 72.2203113186744, 72.5497825684086, 73.76008479825913, 69.64762087791198, 69.72404433834937, 64.50855893473472, 59.56946334531231, 54.919689624540275, 54.10553109261298, 52.89685664638397, 52.58098425403718, 56.51262690944057, 56.84912704652356, 52.84249259579567, 57.8893356938516, 69.05092639307823, 74.82450623666087, 68.48858402621362, 69.59782246620425, 69.51406417354461, 71.59932167299333, 71.59467758670931, 52.27401171961139, 20.503984151347993, 11.025709009939625, 39.47503151432161, 56.28243084876769, 59.6258827178709, 71.04100365792551, 72.84954578645768, 71.8130280894618, 65.1274069663017, 63.99594045454457, 59.34881433363884, 65.73483697829708, 65.6094309591478, 60.9648661459646, 52.652167427924375, 54.94144701188611, 55.12754778708182, 57.00637878910188, 54.46523204926522, 53.829376620631066, 51.384088685435636, 50.80124801205051, 49.19502958174675, 49.22269798094227, 55.66483405328567, 54.27201217220676, 52.753678367983916, 49.41120316905361, 50.23232783040693, 49.00825023651124, 49.785275690017215, 51.305092150165194, 51.87644420131561, 57.18213235178302, 53.67584720734627, 53.44578450725925, 55.070285104936175, 55.976136884381695, 53.0106093037513, 55.803791861380304, 61.40331652856643, 66.07978590073125, 66.42820219839773, 65.66058651093515, 65.55908733798613, 68.58738068611392, 70.07430414999686, 70.8465325447821, 70.75168963401549, 67.2161671423143, 64.56129912407168, 67.5891923904419, 68.64201145787393, 73.35096589980587, 78.70846071550923, 86.02419883974137, 66.28618101919851, 1.620693692276555, 0.4934917468457453, 1.133540710133891, 1.127422793257621, 1.6663779053957233, 1.7006605238683763, 0.07770775321630702, 0.36237239717475833, 31.977783749180457, 37.472539947878936, 30.576042398329708, 82.70187285638626, 133.51810824486518, 70.78522589898878, 20.961136394931426, 21.73686550509545, 40.06043741779943, 60.34362154622232, 69.99073413110548, 41.175465276164395, 0.3658196702599526, 0.09118832662821778, 0.04137200378482381, 0.11627726181740723, 0.041819184627984805, 0.051924298036723375, 0.02268690480700424, 0.08469242197010787, 0.0473071129301623, 0.04385381073300396, 0.048880056147613836, 0.03769113133931833, 0.11805081664915047, 0.09379851076030925, 0.05603510668621429, 0.027354938999539422, 0.03326350702874122, 0.0641566192761304, 0.09367076559893547, 0.07220520412609463, 0.07690185936348093, 0.04482514127307842, 0.11990985923236418, 0.28056410471758536, 0.4558733976896732, 47.700371203884, 86.19071914303689, 70.34683827430972, 67.33947077105123, 60.67131203989829, 36.863176207388605, 44.04886422618743, 84.12617960283833, 59.150185508112756, 11.04830284272471, 0.3770244722404788, 1.3967539346025837, 4.675174990007955, 4.82027473949617, 4.381167850186748, 3.902527637058689, 0.6203383483713674, 3.3447643922221277, 62.503125590662805, 87.57145620161488, 106.51462924095893, 101.87399464268839, 100.26155533329134, 99.44003059018044, 98.49913243324526, 99.2406722038023, 95.43431789644303, 93.28307044121527, 92.65414976304578, 94.76476930802869, 93.08115466948479, 90.87818684116488, 79.96249737278109, 68.07116539247575, 65.45097897129675, 67.05180414261358, 67.65265633982997, 68.01087856292725, 65.17570311023344, 64.50871190717145, 65.6374406045483, 65.81031122515279, 58.72656560713246, 60.11134662935811, 60.36182918856221, 60.78558245012837, 58.20423533839565, 56.65808408491073, 61.580195811487016, 71.21174443152644, 73.55558810695526, 77.03620526098436, 74.38462811131632, 75.8801180316556, 71.00010118176861, 71.84375593739172, 67.74925647243377, 61.529385428274836, 59.27889024057696, 58.569894375339636, 54.891311276343565, 56.10149583508892, 60.236164292981556, 60.32759866406841, 56.226368411894775, 61.80797961450393, 73.03778817576747, 78.94973354954874, 72.67054450127387, 73.64866595114432, 72.7101682847546, 76.47521218945904, 72.27439295861029, 61.34511247757943, 26.976124394324522, 16.555630237825458, 44.9785561715403, 59.866645643788004, 63.55613293186311, 73.83233485683319, 74.47001026522729, 72.00895047956898, 68.72417726824361, 63.864619501175426, 60.90250046022477, 68.78229110471665, 67.75033904660133, 64.30626661546769, 56.201696703510905, 57.43860829261042, 58.08315961591659, 59.793909211312574, 56.75860658768685, 56.69754312884424, 55.45146103828184, 53.3083446564213, 51.228358822484175, 52.153767539608864, 58.267318817877005, 56.8676249442562, 56.81468863641062, 53.01526123477567, 53.47825780991585, 51.9024299037072, 52.76539056531845, 53.97979951673939, 57.02620637032294, 60.803213504052934, 56.82624393893827, 55.71082384355607, 59.06822366099204, 57.6729699104063, 57.71627679947884, 60.05733951445549, 64.30867102838332, 68.27536398364653, 69.17818377094885, 68.4560989564465, 69.87136856202157, 70.59037039356848, 73.05234801384711, 74.43197111929618, 70.60116475628269, 69.24130255176176, 68.4204367668398, 69.25178312486219, 71.74575159626623, 76.83657230869417, 81.2329452268539, 88.01557833148588, 76.13387969232376, 2.311210536187695, 1.0130254575802435, 1.4942704309378902, 4.385039229546824, 3.4611876933805408, 2.8762309012874483, 0.03995590557854983, 0.4320423329068769, 34.193430639082386, 49.743820159666, 35.5167559654482, 79.09524563820132, 110.43696018957324, 58.883209382334066, 28.83532197244706, 36.15237605187201, 47.37715221220448, 68.17761067421206, 76.92401762931578, 51.03455843464021, 0.4624757579257412, 0.07440193826633115, 0.05283495058275519, 0.09014681477339999, 0.06149506511827631, 0.11019381889772993, 0.12597611879989987, 0.09027142663516345, 0.021573623920220043, 0.047683522570878274, 0.018050144238757993, 0.05288303409132266, 0.21611141161091868, 0.17168068687521643, 0.11636639614739727, 0.10376369054879873, 0.10915406138425875, 0.1892014088169221, 0.3731013972672724, 0.18491444207968252, 0.25823083375730826, 0.2966014812550237, 0.2914781303655717, 0.4131617282907809, 0.6634938584700708, 57.23033435883061, 102.16378719575944, 83.29481755533527, 77.53009442360171, 60.99318173623855, 48.40859436219739, 56.53421955723917, 100.3495890094388, 72.08800192802184, 16.609433389479115, 0.7435599750568791, 1.7437598950439885, 4.354730094632795, 15.949342616142767, 15.033683930673908, 7.0019465492617705, 1.6139700143567979, 3.3320970977506335, 74.233044193637, 98.69620800018312, 109.57050077376827, 107.4924369012156, 102.67934353120866, 105.15679097944691, 103.57018440000473, 103.66407025244929, 95.45014073771816, 98.97737133887507, 95.82919859117078, 99.45196244024463, 96.01005123507593, 94.481472199963, 83.15627944084906, 72.72308857210221, 69.52158727953511, 72.09553287875268, 72.1422012390629, 77.04281053235455, 68.05458945612754, 67.97477706786125, 70.23723940695487, 71.09743087522446, 61.93069096534484, 65.92929240195983, 65.84344740836852, 62.6717169054093, 61.44041038328602, 58.64013618038547, 63.124954623560754, 73.38603973388672, 77.2631928228563, 80.02236843109131, 79.10811101236652, 80.08860941856139, 74.22672133291923, 76.92049534090104, 73.59041875408542, 65.72001826378607, 62.82612100724251, 62.19789851096369, 58.59349527666646, 59.83346239213021, 65.06288397696711, 63.49626187355288, 57.380463077176, 65.16170417108845, 76.31024514475178, 80.68138937796317, 72.13641182068856, 77.37441555146249, 75.45126961123559, 82.60631607424828, 76.91159940535023, 67.79925884739046, 25.634726747389763, 16.849519706541493, 49.66148960974909, 67.26915051860195, 66.94043236394083, 79.14045487680744, 81.04808392063265, 76.68455693029588, 73.03039058562248, 68.50676028959214, 63.168559612766394, 74.00651162670505, 72.93624585674655, 67.44965014919158, 59.592644553030695, 61.834192814365515, 61.58422016328382, 65.05792217869913, 61.40455991991105, 60.19207292987455, 58.49105473487609, 55.94289087480115, 52.96840852306735, 54.12199720259636, 61.839291895589525, 60.877977801907456, 60.43845268987841, 55.38594568929365, 56.58827766295403, 53.707398753012384, 57.35253580154912, 57.77642634607131, 59.945246019671046, 63.63644738351146, 58.91442360416536, 58.270150769141416, 61.590303759421076, 61.16560912901356, 59.940829430857015, 63.97248860328429, 67.05046269201463, 74.29750442504883, 73.29622530168103, 73.28234011127104, 74.11694203653644, 74.52211503059634, 76.79157487807736, 78.58947169396185, 76.81145345011066, 73.78353272714924, 72.64324480487456, 71.58920195794875, 75.21158925948605, 79.3500820282967, 86.43581236562422, 93.20379934003277, 76.78528339632096, 2.1011722712747516, 3.1902982679105576, 10.451297510054804, 6.665015441756095, 7.347123949758469, 3.96604968655494, 0.23419982002627468, 0.6306012912142662, 46.19459682895292, 57.12495988415134, 45.10930838123445, 92.74582339871316, 138.21376585191297, 85.29113923349689, 34.238216261709894, 36.85202490898871, 59.584101630795395, 77.45213339405676, 87.21936072072675, 58.70728323536535, 0.49162068434299966, 0.2424128801231423, 0.17939197470343884, 0.2158976884018029, 0.11600215198291887, 0.1514016806838974, 0.28228130612161856, 0.27623607566760433, 0.15633787629344773, 0.14426281375269737, 0.0860597433582429, 0.15475015907037645], [0.03535095489613953, 0.04848545191869621, 0.022538879383054954, 0.019410522955079234, 0.0650307217672948, 0.023311919555248275, 0.014907069346537034, 0.016781952712805043, 0.06290030402822361, 0.09235404431819917, 0.0789314024751225, 0.05160568206901512, 0.04711868594430628, 55.124037265777595, 75.24542362459245, 65.08049934141098, 43.43233039302211, 24.491636291626964, 27.742329989710164, 53.82575235059185, 71.37005129168111, 35.69698103012578, 2.437121315348533, 0.11471540772265966, 0.8829418894264006, 4.132902410722548, 5.700805658294309, 7.084367803988918, 1.9879664168242488, 0.5744132159217712, 26.584771871566776, 89.3020922137845, 81.28552067664363, 100.7269210200156, 92.82037981094854, 96.14158399643438, 95.59322880160425, 100.11554902599704, 91.22565392524966, 91.00673860119235, 87.41733843280424, 90.85219721640311, 87.08737296442833, 89.44467821428853, 84.44873963632892, 84.68882791457638, 74.45880013127481, 61.93657059823314, 61.97520202206027, 61.937845368539136, 59.57153827913346, 61.53835588885892, 63.03601880227367, 60.356545755940104, 60.649158493165054, 55.664783062473425, 56.76122280859179, 57.1184487496653, 54.75438525599819, 54.65866765668316, 56.277484739980395, 61.31811480368338, 63.99401457078996, 69.34412356345885, 69.81065027175411, 67.54785845356604, 66.85681527660739, 64.34902437271612, 60.13375120778238, 60.564399996111476, 54.37605304102744, 50.472553391610425, 50.53595066070557, 52.3457440253227, 54.16684166077645, 55.35753988450574, 53.13545834633612, 55.00491488364435, 52.959755774467226, 63.581455753695586, 70.57470444710025, 75.88513082073581, 66.76206650272493, 69.08637677469562, 67.88524504630797, 62.172018712566754, 52.46445063621768, 25.119962730715354, 15.49259045431691, 40.97469091415405, 51.896930740725615, 56.84851515677668, 71.98589478769611, 67.27134704589844, 67.30508727412071, 60.74133419221448, 56.369782032505164, 50.83498824027277, 53.3226966088818, 51.37516921566379, 50.87986799978441, 50.90965840124315, 52.54107413753387, 54.13751409899805, 52.944030992446415, 53.156254752989746, 52.46818473262172, 50.025936634309836, 48.85765475611533, 49.39346228876422, 50.125066695674775, 51.306892518074285, 51.29255625509447, 52.43492303356048, 50.25370082547588, 48.98858347246724, 46.907887689528934, 48.93871838046659, 50.44548511505128, 54.144327255987356, 54.8416462252217, 53.85444841077251, 52.93427605782786, 55.318951606750495, 54.56198515430574, 54.6056568238043, 53.228602870818115, 56.11400819593861, 57.375003137896144, 59.13610419919414, 60.688986239894746, 59.21667360490369, 59.182254806641616, 58.6751982473558, 59.82322108361029, 60.15750115917575, 60.25744315116637, 65.91395593458607, 63.73216498282648, 70.72184824174451, 70.64399703856438, 80.35374595272927, 78.28450741306429, 92.30087757110597, 21.221817116583548, 0.266199373910504, 1.6509117546581453, 6.451421303133811, 1.9564539722857939, 1.3760436975186872, 0.09384760933537638, 0.12740642793716925, 8.171477702356155, 57.592220075668834, 40.15345250406573, 84.76886780031266, 109.40984833625056, 94.98519082223216, 28.565407991409305, 20.46648825368574, 35.12387567950834, 58.51944877255348, 58.130341806719386, 55.00905298417615, 0.7226987880083823, 0.06759117147134197, 0.02186511271452952, 0.0021846026591505977, 0.05350495575957241, 0.013808441806524513, 0.0035818268529950615, 0.02071544456656181, 0.02317591405083095, 0.10863395663158548, 0.04032465817046262, 0.04675620761249335, 0.04915185265182968, 0.017750274442556887, 0.03573378052322134, 0.041557921832727815, 0.04513924881335228, 0.012278100738542215, 0.030769086442887787, 0.018351910102571693, 0.02590213177515374, 0.020581564956134366, 0.09350749694051282, 0.0325282656347319, 0.055904994313154495, 68.70233751112416, 86.40079344472578, 74.82903265183973, 55.88276094005954, 31.68999552726746, 28.945071851053548, 50.674135761876265, 74.17106290017405, 42.659780363882746, 2.011145050487211, 0.12444483927421032, 3.299968718521057, 5.3245974067718755, 3.827264462747882, 2.336358812547499, 1.109875457421426, 0.3408901273242889, 34.103682887169626, 102.58978797543435, 89.94179940992787, 96.6829965960595, 91.41612422081732, 95.16408228105115, 98.20908884848319, 100.953077039411, 92.62297476491621, 94.46487272939375, 92.46973560702418, 93.3552263629052, 91.26384996598767, 93.29487677543395, 87.76928486362581, 86.79744705077141, 77.04371267749418, 65.445248388475, 64.2124278314652, 65.3350886221855, 63.38156392497402, 63.947542328988355, 65.52515099125525, 63.046063992284964, 61.88008062301144, 57.56852895982804, 60.70334211472542, 60.84828938207319, 58.88840652281239, 59.0980689756332, 60.266672488181825, 64.37678690879576, 67.08105717935871, 74.06681414573424, 72.25965269150274, 69.96682336253505, 67.78551486230666, 67.72965246631254, 62.69660042178247, 65.241591084388, 57.361137559337, 54.748117308462824, 55.90105095217305, 53.51522222641976, 55.84006201836371, 58.694233509802054, 55.66852108124764, 55.95503845522481, 56.11826396757557, 65.11102714846211, 74.19134939870527, 78.44420279225996, 68.92691673771029, 70.69693334640996, 70.23607054064351, 63.44228613761164, 58.56390099371634, 30.029899420276767, 19.197211227109356, 45.57641560031522, 55.49136723241499, 60.3078495302508, 76.25872089016822, 71.88999283698298, 68.58578820382395, 64.28798444809453, 58.832650030812914, 54.960748995504076, 55.14880703341577, 53.972268566008545, 53.779801784023164, 55.069273133431714, 54.34148127032865, 56.02003605135026, 55.98171057239656, 55.35076987358832, 53.51782275784401, 53.442183771441066, 51.57233891948577, 53.41264832404352, 52.375738390030406, 55.62922285449121, 53.81484423914264, 56.50405653061406, 52.94907516048801, 53.529134873420965, 50.60507851262247, 51.767716100139005, 52.88702326436197, 56.57814225842876, 55.519733813501176, 58.474086561510646, 57.02552780028313, 57.24158763885499, 56.409770596411924, 57.02192706446494, 56.2737153422448, 58.898208525873, 60.21576404571534, 61.8028256200975, 61.39186320766326, 62.311878665801025, 61.5181831390627, 60.04754927850539, 60.48909441117318, 62.902544467679924, 62.35266347085277, 69.10322727695589, 67.5600334905809, 76.70200363282235, 72.25747185368692, 84.22734537432271, 80.24050712585449, 93.19844922711773, 34.19690585905506, 0.5753278023292941, 0.43642873785668806, 2.6336840323863493, 3.650754863216031, 2.8746867131802345, 0.9169049573040778, 0.14103772148730295, 5.133406865981318, 66.51763223832654, 47.476125378762525, 80.87057313611432, 113.26196101404007, 81.49293561135569, 33.24331883461245, 32.95800562827818, 44.73631058969806, 67.37237161205661, 65.29762998703988, 68.45416915032172, 1.220044539340081, 0.12040585519806032, 0.05252694493279823, 0.025759965008605393, 0.07537554408754073, 0.033649592359940854, 0.028332526562735442, 0.04876436537972862, 0.04189729112230482, 0.04842464368970645, 0.015353825968509961, 0.0228125719548834, 0.15832366812373364, 0.1399353516077803, 0.16033371429770224, 0.1861056628366632, 0.22065667255270868, 0.08668500900028214, 0.11781790293753149, 0.11609232819248592, 0.17356946133077147, 0.2029861651000477, 0.2480648929673818, 0.20916311671176266, 0.2671958704388911, 78.83757729684153, 99.95997998022266, 83.41547750657605, 64.17714218939504, 39.05533790588379, 41.42666562911003, 70.10911910764634, 89.38075926996048, 59.38708489941013, 3.5116808549050367, 0.09568909318336556, 3.0575706545383703, 8.34343146893286, 14.785682270603797, 14.976905661244547, 4.835256722665602, 0.5867711334459244, 34.94359962401852, 104.04720737088113, 92.18839968404463, 101.1242022052888, 95.72380450464065, 101.77201301820817, 102.59645600472729, 103.52537524315619, 98.95932059134208, 98.32916044419812, 96.15675572426089, 96.94714469294395, 93.44391115250127, 98.72527276315998, 90.75217677700905, 90.3553113629741, 80.81706416222357, 69.42928606464018, 67.97816599569013, 69.16573416802191, 66.33977628523304, 68.2482917847172, 69.23943550355973, 67.88991266681303, 65.284180179719, 61.048451854336655, 63.845297905706595, 64.69049023043725, 61.73678467350622, 60.42013129880352, 62.7340433674474, 67.39894959234422, 71.61831378936768, 77.09721380664458, 74.54256626867479, 73.23305160768571, 71.01004046778526, 71.61363047938194, 67.60477204476634, 68.10368968594459, 60.82117403707197, 57.956714168671645, 58.23541425889539, 58.454812034483886, 60.34872062744633, 62.47626519972279, 58.90970891521823, 61.109032861648075, 58.295089198697, 67.6519581579393, 76.4200165963942, 83.00669593195762, 71.86052799224854, 74.66297518822455, 74.938686432377, 68.91479661387783, 65.110023021698, 29.031046282860544, 17.025016353976344, 50.82279359140704, 63.104930923831084, 64.07410544733848, 76.98381024022257, 74.84397688219624, 73.2821596822431, 67.75237867909094, 61.638458698026604, 58.47456116830149, 58.64626292259463, 58.01857386865924, 58.090231649337284, 57.50749687994681, 58.82273820138747, 60.09320958968132, 58.676151383307676, 60.022959939895145, 59.1980972597676, 57.2084318437884, 57.25943050076885, 56.87524218713084, 55.92426746122299, 58.57726843126359, 57.66348561932964, 59.86223297734415, 55.2637364018348, 57.23284075337072, 53.977422560414965, 55.92073732806791, 57.230703061626805, 60.69839208356796, 59.862044703575876, 61.99576700887373, 59.19313546149962, 61.67877281865766, 61.784468927691066, 60.141411596728915, 60.58327836375083, 63.803418759376775, 64.0198943691869, 64.73473456598097, 67.3864293867542, 65.8587524967809, 65.45460716370614, 64.6426804604069, 64.23154938605525, 66.09157654546922, 63.60296603172057, 72.76636800458355, 69.77276017588954, 80.21433707206481, 76.22465118285149, 89.91036553536692, 83.9365408497472, 100.89221754381734, 30.022370430731005, 1.8344757369449063, 7.509636081034138, 14.68984111662834, 4.963322599087992, 4.774564418100542, 0.752535461177749, 0.2696012333035469, 10.96888759443837, 76.43079526962774, 59.92784246321648, 92.78282703891878, 109.11059502632388, 108.75383976967105, 42.357024377392186, 32.9904200953822, 54.12347593615132, 77.59112650348295, 75.57420453717633, 79.29986000061035, 1.3382195465026365, 0.21734407772460293, 0.09312148055722637, 0.1285462595161892, 0.1344312243764439, 0.06994763494379098, 0.12299950715274581, 0.09629163665757065, 0.12554352427081716, 0.19670488763480418, 0.13549665349625772, 0.15101059279855222], [0.04082435817127267, 0.1172918686643243, 0.025653386856579495, 0.08308250351899094, 0.030228310722797632, 0.09692859280133441, 0.08629719231037364, 0.03247481568025486, 0.026849748063532096, 0.060933936357257835, 0.028507027985347856, 0.04880338989859147, 1.4437769016911908, 75.69493509108021, 67.03984875832835, 68.50312033007222, 39.50539065945534, 45.99286540862053, 27.00674633825979, 53.353153813269834, 55.56848103000272, 18.20126848836099, 0.16644672821125678, 0.15247573595373862, 2.281565017277195, 6.013001809197088, 1.6535370460441037, 1.576891481395691, 0.451601997859055, 12.27075755596161, 98.06943678086805, 106.23770990679341, 107.710967832996, 97.13464967666134, 93.98407643841159, 86.47582054138185, 84.79075462587419, 87.67674830652054, 89.82891359636861, 91.82748671500914, 90.57421099755072, 88.33249015192833, 87.91372222285118, 85.72825601024013, 85.72632620411535, 82.21027435794954, 77.78910421556043, 66.0202992346979, 60.06680419368129, 63.51681901562599, 58.312441764339326, 60.42020190146662, 60.51048701809299, 62.03070355999855, 57.22428998639507, 52.573386623013405, 56.14775626890121, 55.88010549545289, 56.35961132664835, 55.62000528458626, 58.529246853243926, 58.8904030092301, 65.33420216652655, 64.31282089602563, 60.23075534451393, 61.96803977412563, 56.38644426099716, 57.39405016745291, 56.89160239311957, 56.22714896355906, 50.83538832203035, 52.30722242786039, 51.65619919376989, 52.331976506017874, 53.546820840527936, 60.66385169183055, 59.43668719260924, 57.20782387641169, 52.810125197133715, 55.36050127398584, 64.66168826626193, 68.26504030535298, 72.10927686383648, 63.871664078004905, 57.11880568535098, 57.96576699902935, 51.85832285111951, 35.778727146887014, 30.62074172881342, 46.15392577263617, 53.20106390983828, 60.46471688055224, 69.05860639387562, 67.41518820485761, 63.31708015934114, 58.0035041224572, 58.47700088254867, 56.75280932457217, 54.631395416875044, 51.69860001533262, 49.02596366020941, 51.56691035916729, 51.40108039302211, 52.93776304491105, 51.918625370148696, 50.888359931207475, 51.684812884176935, 49.9519960341915, 48.37595631999355, 46.65996251567718, 47.980840283055464, 49.81357559081047, 50.069922093422186, 51.03885735234907, 50.490117765242054, 48.36939027232509, 47.50958319633238, 48.16606244733257, 50.69473212765109, 54.09468573908652, 53.5759287495767, 55.640825225460915, 54.05374011685772, 51.89999018946002, 54.02627960328133, 54.21124681349724, 54.343830770061864, 54.35264433583906, 55.7735150860202, 55.908742720080966, 54.610198928463845, 56.99592959496283, 54.75803306025844, 60.768069067308986, 59.75959239467498, 65.28929887279388, 67.42839874759798, 68.70889571405226, 71.34873713216474, 71.28452008770358, 74.87093925476074, 75.52356673825172, 81.57560348510742, 79.98014019381615, 78.70463248222106, 6.443041159260658, 0.7284408315054832, 2.0118717921357003, 2.1668329931074575, 1.3492311104651422, 0.4015663746864565, 0.04977528734372989, 0.4993961396957598, 45.90701649265905, 45.742677027179354, 45.65595342266945, 89.57701113916214, 59.34717478290681, 34.043996180257494, 22.55968463036322, 28.302260098918794, 57.52148797435146, 55.87030741476244, 68.59482534470098, 5.2391573979008585, 0.30584617067248593, 0.142163610266101, 0.20088228847711317, 0.07206941504151591, 0.05110408217015286, 0.03846247462675937, 0.1438806584525493, 0.07224775264940916, 0.10587970200445383, 0.019540970491605903, 0.055832281077821413, 0.0382941382967176, 0.04809238369606676, 0.02286524241489749, 0.018416851375912948, 0.017479104215219136, 0.13079572348825394, 0.021121746958083203, 0.01938573618028914, 0.037265810815076676, 0.1138720062050608, 0.061150164673885996, 0.16461769329203715, 1.9829231068011255, 88.09362565317463, 75.9235151352421, 76.60209301979312, 51.7122616306428, 44.719146297824004, 32.160962358597786, 50.987160513477946, 59.111530550064586, 23.384704205297655, 0.22346639194555823, 0.5285976034018302, 4.696807842100821, 2.820933081450001, 2.2546904077453, 0.7209972760850384, 0.8220423121125469, 20.182702810533588, 103.78883300289031, 104.25049597217192, 107.81081568810248, 99.5037220370385, 97.07806556455552, 89.71083456470122, 87.60182319148895, 89.04464352515437, 94.13367563678374, 94.0656146695537, 92.6884469678325, 90.32796459813272, 91.554058290297, 87.90319458130868, 89.61708991758286, 84.76531413293655, 81.10998676669213, 69.41926048647973, 63.816182151917495, 65.11995054060414, 61.55818739245015, 64.88655774824082, 64.7897614971284, 64.85273122787476, 58.53182777281731, 55.96642509583504, 59.06528972810315, 58.39749051678566, 58.011254725917695, 57.25727711954425, 61.636960352620775, 62.96305094995807, 67.47887965171569, 67.56008055902296, 63.79978272222704, 64.2788767045544, 60.410792135423236, 59.766899770306004, 58.802035931617986, 57.27809313804873, 53.606244748638524, 55.398873821381606, 55.086170704134055, 55.7803007864183, 57.35885866226689, 64.54562141049293, 63.68006806219778, 62.5875271520307, 57.21895164059055, 57.60506191561299, 67.17947729172246, 71.31046264402329, 74.93988667764972, 66.18911804691439, 57.87164972674463, 59.894066933662664, 56.33647326500186, 43.20397392396004, 35.81337344261908, 50.7353521931556, 58.74800528249433, 65.02055768043765, 71.87414646148682, 69.47824508913102, 66.65567613417103, 59.06760000413465, 60.284464359283454, 60.641741291169204, 59.52305386143347, 52.962360228261645, 52.33434169523178, 54.389628364193825, 53.61653312560051, 55.92066280303463, 54.43159772503761, 54.95938401068411, 54.2813434908467, 52.13977644520422, 51.95664882659913, 50.239592059966064, 51.4887414440032, 51.89503623593239, 52.16915107542469, 52.99970511467227, 53.72291957178424, 50.985344456088164, 51.96282263725035, 51.04820043809953, 52.98969522599251, 54.41613181944817, 56.39034701931862, 56.22802365210749, 57.347601459872344, 55.43077838036322, 57.73720264434815, 56.19669175917103, 56.09589469048285, 57.44591174587127, 57.50686537834906, 56.12013886051794, 58.569023609161384, 59.05118096259333, 58.96927402865503, 63.02789949601697, 63.30857253843739, 66.87928261295443, 71.57508142532842, 69.91849976201212, 75.17835109464585, 74.33100146632042, 79.68609579147832, 74.65775059115502, 85.16776500209686, 77.38945391870315, 93.46713942866172, 10.852907030813157, 3.1434097645744203, 0.36718229552911175, 2.8163014977209033, 3.607320251964754, 2.11633125139821, 0.3731658405834629, 0.10952038930789118, 45.658848131856615, 56.38453798909342, 48.99779712000201, 87.85046223671206, 65.2423128004997, 28.542615098337976, 27.083734620002012, 41.29594087600708, 65.54061297447451, 63.448675678622344, 79.42762728660338, 7.378659805943889, 0.4640873004832576, 0.13389041226717735, 0.21747412881062878, 0.10096096553869786, 0.09216302029427983, 0.06088566515714892, 0.02528558804413244, 0.07481694341667237, 0.027935365515370524, 0.03533377920487716, 0.022993678970622922, 0.16950469073509017, 0.27480882322115285, 0.18181886463876695, 0.16777104908420196, 0.09909226258675899, 0.20420540935329853, 0.17346084538486697, 0.13560813461099902, 0.1621366409404624, 0.22367061566441293, 0.14101930473360325, 0.19550531651944886, 2.1602647391057785, 100.14328802785566, 90.12811199311288, 87.67653649853122, 56.746792408727835, 59.370661935498646, 39.32838586068923, 69.4919341610324, 76.30679345900013, 29.58099984353589, 0.3302571640139626, 0.68744863113088, 5.745082353391956, 12.444849014282228, 9.42779129551303, 9.57998808353178, 2.0570198662819403, 18.71189832687378, 104.30245953221475, 108.13627827552058, 113.89757325572353, 104.95846809879427, 102.41339114404495, 92.6240808733048, 91.2529928453507, 94.63405239966609, 96.43074897027786, 98.62713506144863, 96.78067930283086, 95.34462898008286, 96.82460200402045, 91.30461908155873, 94.8242167503603, 91.47477934437414, 87.45610713958742, 74.62302192564934, 67.27225703577842, 72.01109993842341, 65.24583901128462, 67.97021142898068, 68.65525337957567, 68.59940667306223, 63.508950741060325, 59.52150060284523, 63.626206074991536, 62.38883556858186, 63.19920116855253, 61.20730784631545, 67.30645225894067, 66.1510318325412, 72.30738009175947, 71.50519263359809, 68.55918668931531, 69.62742851626489, 62.9654828194649, 63.822548158707164, 63.548562757430545, 60.953126492038855, 56.88809187181535, 60.37821685114215, 59.964591149360906, 62.04382388822494, 58.74356515945927, 68.24438510402557, 65.28128939290201, 64.28319523411413, 60.940202282321074, 60.595527925798976, 70.68427978023406, 74.90782522386121, 78.63074287291496, 69.02823940400155, 64.12071104972594, 65.41264956997287, 59.66649493863506, 44.14400523708713, 35.72519856114542, 56.86318482122114, 62.560972705964126, 69.25847468837615, 76.17796713306059, 73.0048010426183, 70.10068601177585, 65.09019936284712, 64.69720532817226, 61.90503081967754, 63.06656622117566, 55.53220695064914, 54.30206929483722, 59.0829364715084, 57.736575065120576, 59.719458703071844, 56.792115396068944, 56.75927731298632, 57.325636186907374, 56.70355219994822, 56.541056248449514, 52.93746102240778, 54.023796742962254, 56.697778471054576, 55.532340311235004, 58.07419700007285, 59.61119344157558, 54.41610828522713, 54.93455148512318, 54.68215873164516, 56.616452047901774, 60.78603744506837, 59.02518349309122, 61.2327326497724, 61.20613505763393, 57.89869054671257, 60.60835799863262, 59.71968620054184, 60.12585547662551, 60.87571067194785, 62.69305459914669, 60.288975084981615, 62.3969352629877, 64.37667708243093, 62.86522311549034, 67.18155614791378, 64.86849915596747, 70.77715366117417, 74.89408123877742, 73.16561821968325, 78.10273693453881, 78.40287670012444, 83.39344947568833, 79.03731223075621, 91.32843571324503, 85.47837749604257, 93.16270859010758, 9.3037159404447, 5.579136187030423, 7.248626370583811, 9.230904982935998, 5.452721628450579, 2.7120627943546545, 0.3411973898689593, 1.2795924924073683, 57.34276125507971, 62.42523908615113, 62.90902814557476, 93.23035378609934, 76.28132943184146, 48.40385221665906, 31.22516916644189, 45.164598111183416, 77.82489192101264, 72.66922658489597, 91.6814176497921, 8.909589321382585, 0.7893709910492744, 0.2925337075946793, 0.35135023055538056, 0.2509800567021293, 0.14670049020599935, 0.14903434642380284, 0.2848899887213784, 0.15222568485525348, 0.1992533557237156, 0.08802930178541331, 0.12381494646110844], [0.02567642695090223, 0.09687593957829861, 0.03771980601032415, 0.038925563285668055, 0.04166141265041886, 0.041352365120884874, 0.014895827006248218, 0.03172425444297974, 0.010339014416169977, 0.017054823655334693, 0.12191012246353973, 0.24471368730789234, 2.8291190679996245, 67.78280058214742, 65.04260140080606, 64.2561230351848, 50.057621540561804, 30.273437423090783, 37.89167265738211, 49.87753375884026, 37.11991102464738, 5.546232894543679, 0.10365561852532049, 0.19889972953786775, 4.182478227922994, 3.282656112024861, 1.4488302627878806, 1.0207421693109697, 8.142786545138206, 108.847302006137, 95.82220892752372, 94.16419167672434, 90.15908302799349, 93.48322114636822, 93.02315065937658, 98.46830260369086, 81.42982467528313, 84.97239958855414, 89.5247494789862, 90.66364888221987, 82.23716612785094, 80.58304771300286, 78.070691170231, 82.38474138321416, 78.85656156847554, 80.67296412683304, 75.59728376327023, 70.6048047158026, 59.99649178597235, 59.93902121820758, 59.32014965241956, 60.202345617355846, 60.27446623771422, 61.15504226376934, 54.96136480762113, 54.19336865025183, 57.84347926416705, 56.36201966193415, 54.306599632386245, 54.99528938724149, 57.948355597834436, 60.9605868401066, 60.96715288777506, 58.66059918557444, 56.342074409607925, 54.376025584436235, 50.97309881641019, 54.149445949062226, 52.018053531646736, 54.42962477284094, 52.94980472134006, 51.336953563074914, 53.12681736484651, 55.15587122209611, 58.49846801450176, 64.84683590550577, 67.423778195535, 64.21713859804215, 61.75192894474153, 55.65094101813532, 60.121744832684925, 69.02910232543945, 68.57613132845971, 64.73247528076172, 51.94325785483084, 56.404083159662065, 56.70242255733859, 48.53627927841679, 44.248018649316606, 53.19618055897375, 54.92449845037153, 60.86948979285456, 64.72036300166961, 65.15750723500406, 62.66154619955248, 55.960215983852265, 55.52564482535086, 59.430784025499904, 60.178995747720045, 58.803318546664336, 55.44073335586056, 53.181503049788944, 55.02485229123024, 55.89650492514334, 55.99211269809354, 52.63982765136227, 52.09746583815544, 51.08143075819939, 50.38309981746059, 47.97469392899544, 45.91955238772977, 48.12124544574369, 49.03096075980894, 47.98853597333355, 49.333606919934674, 47.25057340437367, 48.79790529128044, 46.90101569698703, 49.487905117773245, 51.336286760145626, 54.23062724451865, 53.24517488479615, 54.99229661880001, 51.75269734474921, 53.40814152071553, 53.41806903962166, 54.07698408249886, 52.1924852555798, 54.46674608415174, 54.833048389803984, 56.40691511092648, 58.975490985378144, 64.06094981778052, 63.43717921164728, 70.90544654477027, 66.17249504212411, 69.3650141069966, 71.24851272952172, 68.67008778356737, 71.53442213612219, 71.86251271155574, 72.59362682219475, 74.90700152612503, 78.07325640032369, 88.47226773538898, 55.459709782754224, 1.0834323086084858, 0.27738198998474306, 3.8771008724166505, 1.6719336975966732, 1.26331735282175, 0.3264962545325679, 0.12929003896011462, 17.47801284636221, 77.58145393863802, 35.295961826078354, 46.20762694266535, 42.150856756394916, 49.67637108218286, 35.27197261010447, 19.41763078012774, 55.94670734097881, 59.032055485633116, 68.59281709117275, 14.736737955001093, 0.5569027135929754, 0.02978539124371544, 0.10209932622890319, 0.05441740095134705, 0.04967100745547683, 0.049274549293782444, 0.09622266576174768, 0.009437402665254571, 0.097218633689467, 0.02166277548718837, 0.09164100798267512, 0.015129635125518808, 0.0465732696466148, 0.044532836595129584, 0.07005150114456493, 0.07413733915816392, 0.042722915569620754, 0.05189312974952402, 0.07307446111113795, 0.0900103668532064, 0.08750941153735885, 0.06097925045797902, 0.31081805065754925, 3.9749946517329064, 81.51679146674373, 75.81730519571613, 75.45221098007696, 55.409056294348936, 39.536612726026966, 40.570463211305686, 51.06749849934732, 49.80538175952051, 5.337036223180833, 0.08852643922211663, 1.1138854680522796, 4.950513608994023, 3.491764775206966, 0.12983845066159003, 0.5910050256117698, 14.52588898520316, 118.00015280323645, 97.82115859370079, 100.75004731455158, 92.5116265204645, 98.45434681061776, 95.75043739811068, 101.84885224988385, 85.25970535893595, 88.39618944352674, 91.357798576355, 94.8354111948321, 85.49283535249772, 84.94875554115542, 81.73438102968278, 84.91257559868598, 81.52615024197488, 83.50584891534622, 79.43568383493732, 72.98437333876088, 64.17884057567966, 64.11682398088517, 63.43409230632167, 64.96614656140729, 62.00214870514409, 63.70371603196668, 57.95863613005608, 58.83151254346294, 60.53891243473176, 59.68685596219955, 55.28237942726382, 59.009360651816095, 60.81019532295966, 64.04307165453511, 64.54594696721723, 62.30030375142252, 57.83386945724488, 56.701830279442575, 54.295083553560325, 56.71444462191675, 55.932045521274695, 57.05084277737526, 57.369672636831964, 55.67214142891669, 55.47247709766511, 59.86606121063233, 61.843696717293035, 67.62465061679964, 71.92487055255522, 71.0536886030628, 64.23223187846523, 59.47297696144351, 62.35910400267571, 72.25552635808145, 70.13441055051743, 69.00942771665513, 56.31253896221038, 58.56335970663256, 60.53226401728969, 50.9635909911125, 46.7974925810291, 58.25345323931787, 58.338274494294204, 62.67732981712588, 67.65463321439682, 69.60069364117038, 65.6650972366333, 59.01088253144295, 58.85907503866381, 61.24386041395126, 64.13223105092203, 63.52409893466581, 59.4726514047192, 55.532395224417414, 57.75087602676884, 59.340090982375614, 57.44015762882849, 56.19767235171411, 54.64129547918997, 54.63392926800636, 54.419559970978774, 54.026271758540986, 50.63546119197723, 50.952663267812426, 51.54485879405853, 51.37487896027104, 52.43371102117723, 50.857996863703576, 52.34121761014385, 54.16506874945856, 50.323260138111735, 54.23437310803322, 55.66840733251264, 55.150532876291585, 55.90062341382427, 55.17999772102603, 56.53880088560043, 57.01539631812804, 57.679700697621996, 56.21627223107123, 55.77648432024064, 57.857627253378595, 59.58481157979658, 62.981521391099506, 66.95883612478933, 67.58191247140208, 72.97180606472877, 71.40624692363124, 71.90761212379702, 73.22635219943139, 70.37383987057594, 73.72602293568274, 72.15851829897973, 75.56238251347696, 75.29695572391634, 83.32710650659378, 84.8270679289295, 73.24186909583308, 1.2844981517522567, 3.5379151375063005, 0.6698650133705909, 2.5806984497654826, 2.5247848178109815, 1.345650844516293, 0.19706902454697317, 15.837446220459478, 86.7063617706299, 44.856350806451616, 48.48074636151714, 50.382966456874726, 37.095925731043664, 33.891494427957845, 25.28302154233379, 63.95210012312859, 65.20747038625902, 78.65535182337608, 21.07056660036887, 0.6783262399896499, 0.10677054734720338, 0.1363299273314976, 0.0518366958825819, 0.13170899222454718, 0.009753566193995217, 0.023138094205229033, 0.049472284247918476, 0.01400061879276989, 0.052283191077050664, 0.02768867371243335, 0.09691068932654397, 0.18063956420988808, 0.20992606367555358, 0.19713962721007486, 0.18270524368891794, 0.1306061473705115, 0.15692376501617894, 0.19908644048677338, 0.1547504195402707, 0.20261110377407845, 0.2324684766391593, 0.5838501934082277, 5.076473662930151, 95.11485653538858, 85.67150715858706, 83.50489970176451, 68.07508776264807, 42.255454601780066, 53.43766520100256, 69.71538374500891, 58.21909719897855, 9.044657118858831, 0.17316628457798114, 0.8023455174219224, 10.011738077286752, 10.629064229226882, 5.325555445686464, 2.7779588583976995, 12.96749895618808, 118.60756320338096, 104.05698976209088, 104.16335659642374, 98.50034836799868, 104.78666044050648, 99.48040746873426, 107.20513113083379, 89.19631373497748, 92.6251163790303, 97.58664008109801, 99.7492467203448, 89.37845291629915, 88.48978504057854, 85.51257271920481, 90.46922483751851, 84.75761059791812, 89.42316793626355, 82.91606564675608, 77.08715684952276, 68.68542425094113, 69.03340908788866, 66.6134714311169, 67.40324066531274, 65.83803453753072, 68.30194980867448, 63.235663521674375, 63.400414836022165, 65.09622804580196, 62.003737265063876, 59.410960366649014, 61.18477775204567, 65.25292673418599, 68.65015429835167, 67.52463802214592, 65.92628786640783, 63.20527691994945, 60.32692401639877, 56.78295273934641, 61.00376821333363, 59.15671625444966, 61.973605617400146, 59.575119403100786, 57.42184408249394, 59.75766651092037, 64.57222684737175, 66.74254094400715, 70.5173437057003, 77.76671532661685, 72.93275494729319, 68.55089479877104, 61.21638421089419, 67.17378201023226, 77.27235547957882, 77.11614316509616, 71.21225433964884, 60.69708201193041, 61.825085070825395, 62.476826098657426, 55.76413277656802, 49.979127068673414, 61.40800768329252, 62.95192710814938, 68.91333749217372, 71.1081781694966, 72.16310747208135, 69.1211054402013, 62.9525625321173, 63.912864654294914, 64.88397290629726, 66.23048336275163, 65.41075898754981, 61.57533599484352, 59.046905579105506, 60.347112455675685, 61.580944984189934, 62.53675207015007, 59.74542871598275, 59.3248761084772, 57.5465597644929, 55.977399887577185, 57.05149389082386, 51.298408431391564, 54.2216097154925, 54.91934837833528, 54.13994989087505, 54.550221966158965, 53.833349981615626, 55.5197024345398, 55.353166441763605, 55.740767217451534, 59.44218635559083, 58.952772617340095, 58.22286267434397, 60.04272476319344, 57.967932147364465, 61.011605108937914, 59.76928849374095, 61.78269993874335, 59.10188544181086, 59.51135735357962, 61.49832417888027, 63.79319706270772, 65.03523126725229, 70.25850649802916, 70.31258813796505, 78.48872169371575, 72.94536928976737, 76.81565038619503, 78.02414048102595, 75.71928516510995, 77.16793414085143, 77.95467530527424, 78.35569843169182, 80.34187686058783, 85.78391444298529, 92.72102617448377, 70.2821191664665, 2.895369371098857, 7.348746340120993, 11.383134011299381, 6.506886559147989, 5.296349477383399, 1.7435690472202918, 0.2505283252966981, 22.771192558350105, 94.00770479632963, 51.143729763646284, 60.082881989017615, 59.32346013284499, 69.24824514696675, 46.24197121589415, 32.458297629510206, 73.88984464829969, 75.40143197582614, 90.25964475447132, 26.130624163535337, 1.018845703332655, 0.2630749915636355, 0.32773195435443236, 0.15975940882438616, 0.2142044961933167, 0.1495057662888881, 0.14584063311978696, 0.14480017846630466, 0.31325494570116846, 0.13233807298444933, 0.2313783028793912], [0.0663886432565989, 0.012990350876333974, 0.06313558495152863, 0.021201563743694175, 0.033471005773472215, 0.0491073812478252, 0.03564518628521793, 0.012693510957873397, 0.00712157489033416, 0.10388242651618297, 0.07041703999763535, 0.3151820245529375, 3.654431594956306, 66.68614510566958, 63.714722202670195, 56.529324439264116, 37.62267651096467, 31.77543651673102, 55.05291684981316, 54.39733582158243, 26.68213490516909, 0.8702692016959191, 0.03114068505143927, 1.5683796929736293, 3.6556499811910816, 1.055974369087527, 0.9680996102190788, 3.8195788235433645, 103.66472921063824, 100.53590159262382, 92.60577909408077, 95.60458798562327, 89.31655791498001, 89.71951084752237, 90.75418503053727, 93.67588796923238, 92.31701420199488, 88.24094203210647, 83.54861843970515, 86.39137191157188, 80.13971790190666, 73.04035340586017, 70.38169245566093, 72.92186644769484, 71.43543720245361, 74.20283409856981, 70.6906653988746, 67.06857619747039, 59.55273051415721, 60.34922661319856, 59.11977144979662, 61.10187453608359, 60.616492994370006, 57.080786151270715, 50.94723470749394, 53.4332093884868, 56.08471985786192, 56.159037005516794, 55.38580056159727, 55.238068411427165, 58.38870440759967, 59.0070935218565, 60.35513762504824, 60.08645134587442, 55.56375457394508, 56.05269370540496, 54.13538817436465, 52.7864380036631, 53.913130990920536, 50.860275760773696, 53.0053533277204, 51.33114453284971, 52.8305293667701, 53.53710512961111, 58.88742985263948, 67.58878446394398, 71.58556199842884, 66.84473437647667, 64.9355403069527, 63.77365973687942, 60.30186791573802, 64.28810604156988, 66.6014297546879, 63.632175922393806, 51.38275507957705, 55.06318561492428, 56.34320797458772, 53.866246900250836, 55.09743182889877, 55.34111299822408, 54.11713346358269, 56.624006532853656, 61.73486271212178, 63.21224697174565, 64.39087214008455, 58.8598124442562, 54.83507625518307, 57.7160846033404, 61.03430778749528, 60.92093560003466, 60.840221066628736, 59.75893343648603, 59.59655515609249, 56.862922022419596, 56.545421846451305, 52.73455681339387, 51.915887555768414, 52.912601040255645, 51.503140464905776, 50.558178732472086, 47.838054241672644, 47.93270887867097, 47.27868503139865, 49.44366470459969, 46.20004500112226, 48.59355372767295, 47.94601355829547, 49.148118034485854, 45.622017075938565, 49.57598978473295, 52.20094580804148, 53.43315839767457, 52.830305791670284, 54.730925559997566, 52.112366922440074, 51.387465846154, 53.1892301190284, 55.193388692794315, 54.30229286993704, 55.55657271415957, 59.8746237447185, 66.69404475919663, 65.24032808119252, 65.54113072733726, 64.75597812283424, 72.10859437142649, 64.47376358893611, 68.48848204458913, 65.85096266961867, 71.09381444992559, 66.81565392401912, 75.43800415531283, 70.29001881999355, 83.79458242847075, 74.92696639030211, 96.1166298773981, 22.805521142098215, 5.143621208206301, 0.9451720695341788, 2.280884486052298, 1.3512443895301511, 0.5708589969623474, 0.06283257419483797, 2.920718178633721, 61.167703674685576, 60.8143412682318, 29.59566950798035, 46.07124220940375, 40.74151385215021, 32.42860332612069, 26.459765934175064, 48.648733631257095, 56.70572519302369, 69.22272620662567, 31.404803914408532, 0.26237769833495544, 0.17979432408127094, 0.0974487741628001, 0.046671279105207616, 0.029768870557628335, 0.013228689448066778, 0.022468257567755157, 0.08290145395984573, 0.05195960702915346, 0.0184860157089368, 0.05604456404163953, 0.044572320766747005, 0.13836238923813068, 0.0663607576561551, 0.017456129238369967, 0.07127958605246199, 0.05396123006639462, 0.03646505358178289, 0.03444898595672942, 0.07267866944593769, 0.11748113068601779, 0.07439676717284226, 0.342659606568275, 5.95817982189117, 81.3766844041886, 70.1316805808775, 66.32154510867211, 44.46941683369298, 36.89892076676892, 41.84203286324778, 66.09604804746567, 31.681101552901733, 0.4741582923358487, 0.16469986388279548, 4.005286871425567, 4.342272156669248, 0.9227090845665625, 0.833165112041658, 8.458602063117489, 112.18745123955512, 99.84154793523975, 97.82024075908046, 96.14936597885625, 91.97551696531235, 91.66481033448251, 92.88351428124213, 94.00934434706166, 95.78814706494732, 91.92955463163315, 88.57239015640752, 89.42995363666166, 84.3328022187756, 77.52494827393564, 74.5400167280628, 75.67496238216278, 74.99585105526832, 77.65232332291143, 75.44918291030392, 71.80467344099476, 64.01853330673711, 64.46803300611435, 64.32031262305476, 63.95015070515295, 63.95821509822723, 60.41462036871142, 54.78078672962805, 56.69078880740751, 59.90714803818734, 57.930112654163, 58.184219483406316, 57.65519372878536, 62.32142963717061, 63.556693830797755, 64.48116902382144, 60.614017978791274, 57.95708287146784, 58.91505118339293, 57.525755513098936, 56.916689872741706, 57.874830768954375, 54.24046062654065, 55.9703984568196, 54.67351775015555, 54.045899298883256, 57.9899876348434, 61.30477090035716, 71.06766793035692, 74.85485753705426, 71.0393484177128, 68.07437389127671, 66.0929258408085, 63.858304485198, 69.01588393795875, 70.7735372358753, 68.63149166107178, 54.80832569060787, 55.85072302049207, 59.536825303108465, 54.1478495444021, 58.225831908564416, 60.100548344273726, 57.540605606571326, 58.95124289297289, 64.99736862797891, 67.9768402345719, 67.2207014022335, 62.23642010842601, 57.76867182024064, 59.6723981057444, 64.14371575078657, 63.959787968666326, 64.72182212337371, 63.81856695298226, 64.34618065434118, 62.01744594881612, 58.390920546747026, 55.68611683384065, 54.45469656298238, 56.813092231750495, 57.1086153676433, 53.336836753353, 50.489384282019834, 50.55993987667946, 50.461962992145175, 52.38294770640712, 48.9966086418398, 51.41069804468463, 50.67908579303373, 50.984862004556966, 50.826139373164025, 53.18473508281093, 55.19716201290008, 56.41031972823605, 56.15015675944667, 55.685073483374815, 55.0257505139997, 55.2855840036946, 55.982110654154134, 56.45761566777384, 57.3893472456163, 59.36994414175711, 62.58287914337651, 70.3328981707173, 67.80704082981234, 67.91462359889861, 67.34587992391279, 75.24954211327338, 69.02462297870268, 69.54896542333788, 68.2355676158782, 72.06001189447218, 69.27643129902502, 75.69535870705882, 71.85025138239708, 86.35374853687902, 76.08271629579606, 96.6695507111088, 31.038887962218258, 4.281149862274047, 0.620035283988522, 0.6278471744829609, 2.4452116941252062, 2.5522534212758465, 0.07467487241111456, 2.110923283523129, 63.12656671770158, 73.63198803317162, 36.680809528596946, 53.93292719318021, 40.88669253933815, 33.5580341277584, 37.35873237732918, 56.53746727974185, 64.06622932803246, 77.670774152202, 39.82596205126855, 0.40535158447680936, 0.08404710014621097, 0.12852343775692487, 0.07110245886348909, 0.057387983486537016, 0.04056019190278265, 0.07095486436399721, 0.05966020793083215, 0.047975984296851584, 0.020609632502460194, 0.04214472603052855, 0.12580624646356992, 0.22227333257755927, 0.223796162153444, 0.1434000302106142, 0.2998597451275395, 0.14243886565729497, 0.1090918780274449, 0.14216275224762578, 0.36891429775184204, 0.25170606290621145, 0.32315687727062936, 0.5512967885982606, 7.251787800942698, 96.12216826408141, 80.43849268267232, 75.67933974727508, 52.9247917667512, 44.4790070287643, 73.28208907958, 78.49637816029211, 42.1975996417384, 1.7257397910279615, 0.14168048457753274, 6.665429742105546, 11.178508862372368, 7.690494118198273, 5.383550140165514, 7.174448467070057, 114.77808260148572, 106.10866392812422, 101.15020751953126, 99.40751414145194, 98.05680674891319, 96.89098419681673, 97.22392282178326, 97.9108867337627, 99.7273128263412, 97.05441367241644, 92.21362052425262, 94.57595425267374, 86.62892633868803, 83.46152613239904, 79.19555633298813, 80.03882669633435, 78.96276366326117, 82.67863673548545, 80.1744544121527, 75.7709506250197, 67.37581545306791, 66.861404449709, 68.82272289645287, 69.12565538960119, 68.88799113612022, 63.72632065126973, 59.18446310104863, 60.60414929543773, 64.0128654818381, 62.16321691390007, 64.18559489711639, 60.085611958657545, 65.5047546663592, 66.84038054558539, 67.34383244668284, 66.39170062157416, 62.05083708609305, 62.81210637861683, 59.841699369492076, 59.224439897844874, 63.74099031571419, 57.009971680179724, 59.27390490808795, 57.3852248345652, 58.032255095820275, 61.016825783637266, 67.61340910388579, 73.99982006319108, 77.75048455884381, 74.40665614220404, 72.11041435118645, 69.43174931310838, 67.57145543252268, 73.32760426305956, 74.4306218239569, 72.49472033592963, 59.935071391444055, 58.518087710103686, 61.902853904231904, 56.74137953789004, 61.76735954899942, 60.390164390687026, 59.298176534714244, 63.418936267975845, 70.0687422290925, 72.07711342842349, 70.22266387939453, 65.34746762244933, 62.092665241610625, 64.0761137008667, 67.9439550830472, 66.35130805353965, 66.40933559786889, 66.44640199599728, 67.169679211032, 65.51997346262779, 62.56156890623031, 60.384406351274066, 56.93385416461576, 60.989353502950365, 59.021516076980106, 56.49765522249284, 54.061961404738895, 53.58304000669911, 54.010241031646736, 57.54854840617026, 52.32005250069403, 54.53320280198128, 55.71100819495417, 54.87435094771847, 53.17907118028211, 56.74690615746283, 59.197681488529334, 57.79531255845101, 59.524591430541015, 60.71478366851807, 59.3810679835658, 57.207313968289284, 61.34927411233226, 61.68084775247882, 62.049413265720496, 60.67213181526431, 64.79674723840529, 74.11130166822865, 71.58428330575266, 69.23775672912598, 71.587523183515, 78.32755934807562, 70.85262006328952, 74.37858766125095, 70.81913086675829, 77.93057626293552, 72.11465051097255, 82.07929857315557, 76.06997643747638, 91.03883143394225, 80.13145739032377, 105.39174879750898, 30.999903525075606, 8.131113571505393, 7.982239521318867, 7.371114636621169, 5.961497166464406, 2.4611004802488514, 0.1810209074568364, 4.168661188694739, 74.0037424333634, 77.63062477111816, 46.55713365923974, 61.18813530091317, 61.17636034565588, 45.1915055705655, 41.199191693336736, 65.97535671726351, 74.0596518977996, 86.79464647846838, 46.61995041754938, 0.4255994721766441, 0.3959385395771073, 0.21949309224803604, 0.16448240216460921, 0.17890702572561082, 0.09882374876929868, 0.12012086282934874, 0.2999729116357142, 0.20306933160510757, 0.21016191150392258, 0.22668019207494877], [0.026252467613366824, 0.05633113072103551, 0.044117689718522375, 0.0717275406444265, 0.08035702315429527, 0.015136292429580806, 0.056023347236576586, 0.021751771921352036, 0.05597987557731329, 0.02476367723917769, 0.030161921543279485, 0.3884898973328452, 9.32755708694458, 74.27863782451999, 59.328559214069, 63.754836282422474, 32.870950583488714, 47.6238339947116, 65.27333482619255, 42.95279710523544, 16.251378847706704, 0.2321181599531443, 0.4627383422226676, 4.081748329824017, 2.26620011271969, 0.4305230886224778, 0.26171549193320737, 83.21270665814801, 101.27600577569778, 89.19799250941124, 95.78801370436146, 81.18679461940643, 79.50938517047514, 76.6692675313642, 83.94746857304727, 88.51266814816384, 88.96236788841986, 89.740079756706, 84.73970890045166, 88.10308641003024, 82.49126511235391, 73.55870246887207, 65.0674613829582, 65.13260410678002, 70.35299639548026, 73.06472701411094, 70.9239601319836, 65.98371136573054, 57.880220105571134, 56.96450748751241, 59.090086952332534, 58.22863640323762, 61.5732845952434, 53.94696143365676, 51.65994897965462, 56.17234168514129, 54.54291851289811, 57.662657999223285, 53.22171518879553, 55.04685286552676, 59.64658106527021, 61.7863202864124, 61.01150312731343, 56.69361683630175, 56.53571005790465, 54.82687850152293, 53.494261080218905, 53.55962345677038, 52.3917495050738, 52.47528030026344, 53.21968340104627, 52.762256591550766, 53.092881018115634, 53.23900499651509, 57.43317973229193, 64.46985298587431, 70.55686550755655, 68.00621878716254, 68.83474103866085, 65.61357298204976, 62.238785297639915, 63.54076508552798, 66.24982064770114, 58.071157163189305, 49.13955550039969, 53.94792241434897, 54.63834977919056, 58.911073900038204, 60.60925229903191, 62.69567082005163, 56.737665053336855, 52.56582037095101, 58.73663433136479, 63.21012496948243, 64.96479334369783, 60.60108592433315, 53.24475911355788, 55.17498100957563, 57.897474611959154, 63.187834139793154, 63.69490246618948, 62.760166352795025, 61.05786162038004, 58.837764801517615, 54.273118280595355, 49.92764988253194, 50.01302811407274, 51.87638536576302, 52.91042020243984, 53.03972505754041, 50.571424576544, 47.604449641320016, 45.433825677441014, 47.1896158495257, 49.515965753985995, 47.16480293581563, 47.841176448329804, 46.09214059768185, 47.50959888581307, 47.433524516321, 49.94821879171556, 54.00608724163425, 53.85411500930787, 53.833318602654245, 51.961183086518325, 51.77010874594412, 53.69199952771587, 51.424700906199796, 55.25109460276943, 59.312226464671475, 63.28189649889546, 66.89563889657298, 66.31071936699652, 68.69803074867495, 69.61424935248591, 65.2797322119436, 67.33077095400903, 63.699158237826445, 68.24485578844624, 66.78821302229359, 69.63054287818171, 67.58328530096239, 73.04539757390177, 77.8359059364565, 83.5595932314473, 75.45374070444416, 59.28160059836603, 2.4172861345352668, 1.8749553325676152, 1.9875447620307247, 1.7694472521543505, 0.7656467802101566, 0.07084954259616714, 0.023248489390337662, 32.8742963652457, 85.78997058253135, 43.83922530758766, 45.11078711478941, 40.12469368596231, 31.60766301616546, 18.68353174578759, 32.900489953256425, 62.71724385599937, 62.128751047195934, 48.99298437180058, 0.1815402691042231, 0.06704937110865308, 0.04356938909979598, 0.026558268845321673, 0.021400647012576945, 0.03481123446216507, 0.10683596359505769, 0.06372274921065377, 0.04588783928944219, 0.09882014049517532, 0.05788821591845444, 0.0664592305979421, 0.10423112675667771, 0.07403544946423463, 0.05603360132344308, 0.04429903805195805, 0.017075473555333672, 0.03894484188828257, 0.04163674844969665, 0.06978606700056023, 0.10069991341762005, 0.15912769272202448, 0.4035565178961523, 12.710060073483376, 85.92428822671214, 66.35565403969058, 71.92520787639003, 39.60299491882324, 36.6671008448447, 54.5600357363301, 57.89680388665969, 16.98837749419674, 0.47993303246555796, 2.4189663798578325, 5.6315199309779755, 2.587375549539443, 0.36778686147543693, 1.0097969179191897, 94.4857789624122, 102.3373834548458, 98.60222801085442, 96.74940232307681, 86.97516964327905, 83.30615320513326, 78.80073839618315, 85.4409816188197, 92.52017728744015, 93.3954228124311, 92.93935314301523, 89.44649034930815, 89.5518530568769, 85.3788120515885, 76.0958876148347, 67.70716159574448, 69.61232739110147, 73.4540222537133, 75.34603241951235, 74.2149777566233, 70.05313904054704, 64.01758017078524, 61.36348878183673, 62.489824833408484, 63.467663872626524, 65.48920639099615, 58.58632126162129, 55.55258366369433, 57.69983422371649, 57.81246508321455, 60.767727821103996, 56.809958257982814, 59.48143751390519, 63.74370459587344, 64.41251970106556, 63.753620347669056, 63.02043130320888, 59.400919099007886, 57.98920708317911, 55.42977425359911, 57.75856779467676, 55.51977695957307, 57.08569303635628, 57.169710205447295, 56.76546289074806, 57.81500677908621, 56.1011153651822, 60.06736117024576, 67.92130731767224, 72.47164110983573, 69.98820027997418, 71.94998941113873, 65.62779157392441, 64.8230428080405, 65.63968420028687, 68.81270516303279, 60.86763451176306, 52.45862983888196, 54.99962752865207, 55.001596558478575, 61.43358938155636, 64.492677257907, 65.1008995886772, 58.48504174140192, 55.71479720454062, 61.04571403995637, 64.81677093813497, 68.97276924502465, 64.10718279500162, 58.58554463232718, 58.21774005889893, 59.83968327122351, 64.99612915900447, 65.16670519305815, 64.87204105623307, 65.7763474218307, 60.01748431113459, 56.5676812971792, 55.280049539381466, 52.26212693798927, 56.559718885729396, 56.521534612101895, 57.90076155816355, 52.959791075798776, 49.379616322055945, 49.13294238428916, 49.231750811299975, 51.76387217737014, 50.96683086887483, 51.38475156599476, 49.30330661035354, 50.674225976390225, 50.55886514725224, 52.4378530440792, 55.74792946538618, 56.04185227424868, 55.50009058367822, 54.2356361112287, 53.93734378199424, 55.61897762360112, 54.694651480643984, 57.39583092351114, 64.54446823366227, 67.28560093910464, 70.05581409700456, 70.88459522493424, 70.64826457731186, 73.68784258442541, 66.88865707766625, 69.99296988210371, 67.98994095094743, 70.52156417600571, 68.9805276932255, 72.19829113252702, 71.24706145255797, 75.40672717555877, 79.41622887888263, 87.63843459467735, 78.25205372225854, 74.6197977373677, 12.579005841285953, 3.0849608105997888, 0.32381859337610586, 1.8917685723112476, 3.359926804419487, 0.5276643244489547, 0.021906209501227545, 32.1043154885692, 93.68114394526329, 53.06335341545844, 53.03672444435858, 42.19523837489467, 25.416719452027355, 26.122859831779238, 41.20670695458689, 69.07499405645555, 70.97244847205378, 57.51656147741503, 0.28212652571739694, 0.023480185022157048, 0.04327484361466862, 0.044332244133035985, 0.04576059591565882, 0.012246330114712399, 0.008727836708027509, 0.04309164134845619, 0.0271264762587605, 0.10053518919214126, 0.1127822231501341, 0.27544185699474427, 0.25462663522170437, 0.15146122103737247, 0.147179999959565, 0.18348171976545166, 0.08682348705347508, 0.1662819886640195, 0.10443885915822561, 0.24933598605134796, 0.1817956981399367, 0.3671017950100284, 0.565788230348018, 14.490355253219606, 99.83003185641383, 74.82136049578267, 85.07178460398029, 46.60729685137349, 63.993504662667554, 89.77698141528715, 66.02482564987676, 28.332085801709084, 0.5547454712852355, 2.628992142215852, 12.20336829462359, 10.272089319844401, 4.771937900973905, 0.9804357095591485, 93.53168595221736, 110.51619206705402, 98.24104832064722, 101.86857392711025, 90.62116176851335, 87.03017696257561, 84.37120222276258, 91.64518279414024, 96.3387615449967, 96.66947226370536, 98.66797477968278, 95.16840473298105, 95.60769450279975, 90.04220424159881, 80.26315489122945, 71.59767427752095, 74.36352575978925, 79.27763585121401, 81.66013840706118, 78.77942423666678, 73.33728467264484, 67.57862552519768, 64.29451911680161, 64.7072858195151, 66.48442545244771, 67.71123301598334, 61.336004734039314, 61.123655457650464, 60.55509221169257, 60.904673453300234, 65.04710820413405, 61.00434087937879, 62.044867238690784, 67.24031325309508, 68.44121748401274, 67.09941387176514, 65.54979132067773, 63.56713518019646, 62.42065775778986, 61.457307953988355, 60.34324107631561, 58.11414634027789, 60.76047928102555, 60.761561855193115, 61.170327740330855, 60.683122296487134, 61.11796017616027, 64.60826166214483, 71.0182382214454, 78.1427215760754, 73.58020490215671, 75.56343370868315, 70.08092511084773, 68.39724771438107, 68.80265605065131, 74.5566632670741, 66.21789255449849, 55.57669839551372, 57.33441837372319, 57.30485154736427, 63.18988553939327, 64.81822221509873, 66.66225787132018, 61.51769676516133, 56.75842223628875, 65.08144855499268, 71.11557575964159, 71.92206998025218, 66.96841455275013, 60.54226606122909, 62.05669710713049, 62.537905246980735, 70.57226473285307, 69.48125746942335, 69.08761624367007, 67.29830941846295, 64.94208674277029, 61.11744242329752, 57.394360034696525, 57.10628155739077, 60.818059675155155, 58.65150713151502, 59.21582637294647, 56.6057086759998, 52.53404525018508, 52.52370196004068, 53.786356064581106, 55.79493514953121, 54.931919574737556, 56.635330415541134, 54.146272751592825, 54.105197691148334, 54.21486323879611, 55.69925677391791, 59.08845132397067, 60.346437808006044, 58.78309872842605, 57.66213240162019, 57.34452239928707, 59.692464951545965, 57.798721098130756, 59.18078391782699, 67.72808351824361, 68.31722351812547, 72.08107502229753, 72.1214597455917, 76.0423158830212, 76.84229896914574, 72.84644711402156, 74.36305507536858, 70.71416824094712, 73.42446327209473, 73.41435924653085, 78.32122079787716, 74.9171055516889, 81.02515374460529, 83.6829125496649, 89.99592027356549, 82.70807020125851, 80.1506220909857, 13.096433147307366, 4.697194685859065, 6.25328375447181, 6.238566531289009, 5.498712399313527, 0.4734959327165158, 0.1476030030678357, 41.2837815284729, 100.7603160796627, 59.77995734060965, 62.27077614876532, 58.20829106915382, 43.075928149684785, 28.855971290219216, 49.62531751201999, 78.5475258673391, 80.95925792571038, 70.46417205564438, 0.38834550508087684, 0.17660721445516234, 0.11662161067849207, 0.1913015622525446, 0.14940171622701232, 0.12788284269552078, 0.2008030749857426, 0.16679981813555764, 0.17890327189478183, 0.19535275777020764, 0.198059423015483], [0.0351203969048877, 0.03182960110866735, 0.09282529564394106, 0.01094735717596186, 0.02068506151948485, 0.023772784643956733, 0.04488243315849574, 0.028280660495041843, 0.03086294562015082, 0.0985106026693698, 0.03057006637625877, 0.23413289458520953, 9.458336753229942, 64.33974012251824, 58.977589453420336, 58.34299702798167, 36.76803519648891, 60.72111437397619, 57.05672633263373, 31.111757755279545, 4.044926834683265, 0.5762197125342585, 2.2250872994622877, 3.8865341726810705, 0.4903475994304304, 1.3007135977668147, 44.476681063252116, 106.16877817338514, 87.0257995974633, 98.58785644654306, 83.13705982700472, 90.6254057730398, 83.67002364127868, 79.81791880822952, 69.14431802688107, 85.09468340104627, 85.31159047157534, 91.67916620931318, 83.68216729933216, 83.28296415267452, 84.61380081792032, 80.56535782352572, 67.9507250939646, 63.70523006685319, 66.05978965759277, 68.41337650052964, 69.04190494168189, 62.26717149057696, 58.81025329712899, 58.325522868864006, 58.34154182864774, 60.38554383862404, 59.59788876195108, 49.952576544977006, 53.46735754320699, 54.4498759700406, 54.35075375341601, 56.86134522961032, 54.16301734985844, 55.36426674935126, 60.929702097369784, 61.6631264840403, 60.43179250532582, 59.5014141451928, 56.73643735147292, 56.52635520504367, 54.01675608850295, 54.76723101831252, 54.00895449423022, 54.360795021057136, 51.9496395511012, 53.278060036320845, 54.63677298638129, 52.30224886248189, 51.64099608698199, 60.59259791528026, 69.2567959139424, 69.78315445684618, 71.32496756892051, 68.34184815806728, 66.46231897415655, 63.3830112795676, 62.29575772439281, 51.578806907899924, 52.43299714980587, 56.496043128352014, 60.88373584132041, 64.38857363116357, 66.00218572924214, 65.43071208461639, 65.26851815562095, 54.92483577420635, 55.51689401749642, 57.50524151709772, 61.4152640681113, 65.98052640115061, 57.75963467936362, 52.841896395529474, 50.900962506571126, 58.070407990486395, 58.88328390736734, 59.894149303436286, 59.398118526704856, 55.6892978760504, 52.866560259173, 50.77379534321447, 47.74355649948121, 51.82220174420265, 55.6297053060224, 53.73216459828039, 51.10331758376091, 47.7303381120005, 46.47613671518142, 45.597019810830396, 44.96482787593719, 48.10111191964919, 45.72599910920667, 46.91564613772977, 47.23285213593514, 47.14886634580551, 51.45685649687245, 54.00192560688142, 53.633626814811464, 51.50321106756888, 52.37485193437146, 51.079889266721665, 53.237553719551336, 55.47950206264373, 60.00652913124331, 62.76757178768035, 66.66016332564816, 66.0171534938197, 68.6089458773213, 64.67646775707122, 64.26140254543674, 63.04252601438954, 63.000635100949204, 68.89101920589324, 67.20599251408731, 68.61944998464277, 70.64180051126789, 71.41500949859619, 75.62773704528809, 76.80642497154975, 82.6350905818324, 76.24762058258057, 71.64699416006766, 52.922136322144546, 5.315766190328906, 0.902942177509108, 1.4888552311928043, 2.854530143160974, 0.46784912927016137, 0.10857012618573443, 8.627765063316591, 75.33156671831685, 63.25544795682354, 44.10147889967888, 45.082981432637865, 44.44870671918316, 32.02238894278003, 31.734896859815045, 53.318833074262066, 62.66058521886026, 42.43378516166441, 0.3033874574447832, 0.011747678696748712, 0.07536161660907731, 0.024244062782775973, 0.006783557267138555, 0.012730226679254445, 0.00850158125808042, 0.03488307435726447, 0.019806720646879366, 0.036370188914119236, 0.0272651266817364, 0.05179073060712507, 0.0669741336136095, 0.022788438270048752, 0.062130998534661155, 0.0863175166230048, 0.06284974605566071, 0.1523108431889165, 0.05308550729927036, 0.0691413120817273, 0.03712689992220652, 0.0623638318070481, 0.201736920843682, 12.729482669984142, 77.68211764674034, 65.36115669435071, 69.53766899724161, 44.059132991298554, 43.460265513389345, 59.97578167146253, 42.54586296696817, 2.8650685712214443, 0.5747472302567574, 3.435598150376351, 3.1450010211237016, 0.4978693264626688, 0.7821780383106202, 55.17622832329043, 108.58171047702913, 92.03504285504742, 99.41564129244898, 87.70508350864534, 93.50439410055839, 87.01431489759877, 80.19703941960489, 73.24473242605887, 85.06602656456732, 87.55503716007357, 92.46910018305626, 87.55673946872835, 88.03348787369268, 87.1265809766708, 83.62866617018177, 70.17976099444975, 68.043104756263, 71.20008714737432, 70.981399320787, 72.16598649178782, 67.02768941079417, 61.27474907905825, 60.392772766851614, 60.10341167449952, 63.03191600307342, 62.026985153075195, 53.605542644377685, 56.4742975081167, 58.217987168219786, 57.851567191462365, 59.91410632287303, 56.416913232495716, 59.04573671279415, 63.04784867071337, 64.09181494866648, 63.87604144311721, 63.90435703339116, 58.91653776168824, 60.18727979352398, 55.59223882613644, 56.04544124295635, 57.09779354833788, 57.823063327420144, 56.01849848224271, 57.09747583635392, 56.3620549632657, 56.77813999114498, 55.348385072523556, 62.762876710584095, 72.40475685365739, 73.97833331938713, 74.78253687581709, 72.85957136461812, 69.18012926655432, 67.43294869699787, 65.60990556593865, 55.964491367340095, 53.587950814154844, 59.239395895311915, 64.55856523206158, 68.63455895454653, 72.1856689453125, 66.60488144043954, 67.02748544754522, 57.25646911128875, 57.427453071840354, 59.642042882980846, 66.80625592508625, 69.5679340054912, 58.51620497242097, 55.25107499091856, 53.66044405967959, 59.56755315103839, 63.02467530773532, 62.42741207922659, 60.41403593555574, 59.49664454306326, 56.056525861063314, 52.18102016756612, 52.3776368171938, 55.33201702179448, 56.969128039575395, 57.69871634821738, 53.683185961938676, 51.98661573471562, 49.146137237548835, 50.302279380060014, 48.02542194243401, 51.776270789484826, 47.96833576694612, 49.58464645570325, 50.55218142847861, 50.29964746967439, 53.84618005444927, 57.027889067126864, 56.882765293121345, 56.3581443602039, 55.16848948694045, 55.95958055988435, 54.547193896385934, 57.11632674740207, 62.590818020605276, 66.6289883275186, 69.05571168468845, 70.56210579410677, 70.02231705573298, 66.46207578720586, 65.61656967286142, 66.2163314511699, 65.74807497762865, 71.8599396367227, 69.11085236457087, 71.34462648822416, 72.20075438099524, 75.00397036152502, 79.68896696644445, 81.42194071123677, 82.11584721842121, 78.84459049470964, 75.77156251476657, 67.25077029197448, 14.099425365847928, 0.5877114604077032, 0.19020529043289924, 3.825862950855686, 1.7526174649115533, 0.19223572986741222, 7.245368351859431, 79.40708191164079, 70.68969265107187, 55.11312130958804, 47.971230476133286, 37.806533690421816, 34.50200350053849, 39.026904644504675, 62.5956739148786, 69.19493229158464, 53.666876746762185, 0.5483155421191647, 0.07385082227448303, 0.058652151135667685, 0.017167940367794326, 0.0428553108846949, 0.027333670483541586, 0.022376744534760233, 0.05558196950944201, 0.03633787915591271, 0.0559140877768157, 0.042200895597136794, 0.188749554837423, 0.1801005600681228, 0.11611418468096565, 0.12313242340760848, 0.1630630404237778, 0.16142926599469878, 0.24083579620046003, 0.2015516654618325, 0.3050689591515449, 0.18192155106413752, 0.2330967606676202, 0.39979799860908144, 16.16735089209772, 93.58220608003678, 74.54713975229572, 78.78335445157944, 49.2785878335276, 83.4531871734127, 76.14619593466483, 53.21025010078184, 6.7064709721073035, 0.7547847566104705, 6.6681807944851545, 7.558197965545039, 4.789095328700158, 1.6788284889151974, 56.07061893709245, 114.74265575408937, 95.53437755953883, 104.65698688260971, 88.9817600865518, 96.97378543115433, 92.65076867995724, 84.3475660201042, 75.78048198453843, 89.36217508008404, 93.0083554790866, 96.49852752685548, 91.40683604824929, 89.99520640219413, 92.20392442518666, 87.57028733530353, 75.47219937847507, 71.90456836454331, 74.83690877114573, 77.34217366864605, 77.0840189533849, 70.75222307635893, 64.17622043240455, 63.13590980345204, 64.32273664782124, 65.93454837799072, 65.34182725414153, 56.37286893783077, 61.16234963940036, 62.54481646322436, 62.43178552196872, 64.0634915136522, 60.311689530649495, 62.087142544408, 68.08349732429751, 68.27809395328646, 69.7901362757529, 66.16887077208489, 61.6617654215905, 66.14000212761664, 60.55700632833666, 60.29830640362155, 61.38508927437567, 59.9921065761197, 58.9070926943133, 59.97076496001213, 60.83611434505832, 62.27678914223949, 59.18018379519063, 66.17239306049963, 74.16920369671237, 77.63642203423285, 79.35392595106556, 76.58890601127379, 71.57716812626009, 72.84524686874883, 70.29991103756812, 60.245562291914425, 56.21957094438615, 58.87858883027108, 64.18650096462619, 71.72274297283542, 74.91941975009057, 70.97188365074896, 67.14620774792087, 58.60190483831591, 59.36958720607143, 64.1547336886006, 69.78164826670002, 73.76625076417001, 61.5535472285363, 58.180740341063476, 55.97114762952251, 62.76385730312717, 66.37266143675774, 65.06699462090769, 64.19071751256143, 61.847760292791556, 59.46078231257778, 56.43452467456941, 54.31256555741834, 60.54528236389161, 62.588645027529815, 59.904618109426195, 57.1843877146321, 54.77079645279915, 53.415872512325166, 52.38068842118787, 50.86058955038748, 53.41595095972861, 52.84505390351819, 53.92621209544521, 54.48877803740963, 53.106927025702696, 57.199500606906035, 59.627855670067575, 59.21515957001717, 58.78019225212836, 59.88531612580823, 59.48918027262534, 59.64306662159582, 61.73247398868684, 65.71314627124418, 68.68539287197974, 73.66829349148658, 74.00404837823683, 73.23464408997567, 70.88981197726342, 69.52648239751016, 69.85964851994669, 67.99391038956182, 78.09162093747047, 73.10828885724469, 76.12873354265767, 75.68040663196196, 79.52015599896832, 82.35644540479107, 85.37890618847263, 84.83193166794317, 82.22541470681468, 76.42812805791056, 67.02468487524217, 14.140043470167345, 1.8634504079818728, 6.914273240873891, 9.835401062042484, 2.3704763237507116, 0.357633683710329, 11.834838082713466, 91.1799975364439, 78.09601399206346, 63.54193002946916, 61.12306710212462, 62.149394481412834, 43.9476788428522, 46.19219241603729, 72.34539570346956, 78.53350731634325, 67.75948601384317, 1.22208968766274, 0.14201353364173444, 0.20312101189647952, 0.15766978143684326, 0.1565311449549852, 0.117767310491012, 0.15566456161679762, 0.10206905043413562, 0.1902561280275545, 0.19456931029356297, 0.1181580076715158], [0.002398076889690973, 0.0417548064292679, 0.012750155498994695, 0.054509752850619056, 0.02919540203536951, 0.059081865174155083, 0.009707900650438764, 0.11340468491037047, 0.0322823207675209, 0.07788330992503513, 0.04075239570210538, 0.13427871159247814, 5.367652283560846, 62.211383619616115, 56.669898263869754, 46.57210926855765, 33.90918823980516, 69.50315213972523, 45.85380561890141, 30.061825552294334, 0.1485661441279996, 0.17206947649678878, 2.8558848317592376, 2.3970153254847375, 2.5992561636432527, 9.506000414971384, 93.65310684327157, 84.18942389949676, 94.10140237500592, 85.94888148769256, 91.75862558426397, 87.54849464662614, 94.22646322558003, 80.44658845470798, 76.8800792386455, 69.84617910077496, 82.25167105274816, 84.33138232077323, 85.52533611174553, 83.79790075363653, 86.41108574405794, 78.14574180110809, 70.37936256777856, 65.60366115262433, 64.45739161583685, 64.66741884908369, 66.84194949365431, 59.40644179621051, 56.81499458128407, 56.706109585300574, 60.105988671702725, 60.167334541197754, 57.31446919902679, 51.62757373625233, 51.994636981718, 53.56888025037704, 54.67506316400344, 53.72457873436713, 53.847046898257354, 55.595792493512555, 61.27109735242782, 61.52109353773056, 60.13084865385487, 58.38302873796033, 57.26480022553475, 54.48396136683803, 53.99841900794737, 53.143793382952296, 54.23895051402431, 57.37558364868165, 54.72008412884128, 55.40894254561394, 54.452382364580714, 51.39665203709757, 54.83435453907136, 57.258085127799745, 66.59801729263799, 67.73477508175758, 69.10134453927317, 70.52115624950778, 67.49606747781077, 64.47963929945423, 55.724312874578665, 50.877498888200336, 55.91465373193064, 64.34678862171789, 63.6281947166689, 68.95493030548096, 68.06825499380788, 66.68008112138318, 65.58447291774135, 58.73777574108493, 57.838356648722005, 55.562589630003906, 59.291834062145604, 63.83968499399001, 58.61845724044308, 54.6848024091413, 52.079548451208304, 51.95830406681184, 53.61045345183342, 54.933315938518895, 57.45202279859974, 54.34109295568159, 50.301008532124186, 47.6511376134811, 46.933649816820704, 51.16263166550667, 53.312274871333955, 55.807518113044004, 55.16690484939083, 50.517284101055516, 46.8448434337493, 45.532681172893895, 45.44947985679873, 46.42433789468581, 47.21667628134451, 47.10775598402947, 45.442984411793375, 46.901274573418405, 47.353198297562145, 50.48684258614817, 52.50188573714226, 51.5423406324079, 51.94046120489798, 50.503736234480336, 52.03040899768953, 58.097166399801935, 61.22466825669812, 64.53985160396945, 64.46519713247976, 63.70968980173912, 62.34346551279869, 62.06190601471932, 62.250909343842544, 64.68285729808193, 65.0168941866967, 66.9373336915047, 70.64158870327857, 72.35664506112376, 74.52670420369795, 77.13148747721027, 74.99056370027604, 78.76368768753545, 77.967007237096, 77.92583803976737, 80.88833362825456, 84.16171627659952, 55.22134342501241, 2.2449310604603063, 1.269146730342219, 3.08958062721837, 1.133008370957067, 0.03903633193863977, 0.86680366507461, 48.631243782658736, 80.61079455960183, 48.23128361855784, 45.37708467052829, 32.46217293124045, 29.495543164591638, 39.112247574713926, 55.02003954302881, 60.46480317269603, 50.3037698807255, 1.7221028958597493, 0.1271538717311717, 0.03963733557611704, 0.012845994055932088, 0.10215674451882802, 0.026373136037540053, 0.029917868913241455, 0.03676073287703818, 0.07041110281622218, 0.030212571446393287, 0.039074080921108686, 0.013583205253516716, 0.04301643449692957, 0.034825790132726395, 0.023404461061281544, 0.10537963045100052, 0.049048442273370685, 0.05898614631845586, 0.06003605832736339, 0.04115540774599199, 0.10698803204802737, 0.037638340220456167, 0.12493141235843783, 9.739554024511769, 76.38228339533653, 65.45877272082915, 61.51019719339187, 27.541941981161795, 50.952290642646055, 54.231184221083126, 32.82433125280565, 0.26157554299119984, 1.0368897092919196, 5.096242898894895, 2.3329941543840595, 1.1120938029020064, 12.850730976750775, 100.13458036607312, 89.59610523716097, 98.2154195539413, 90.57638399062618, 96.87331784156062, 90.16935179310461, 96.9928167712304, 84.38923728081488, 81.84597246108517, 74.2512361464962, 85.84808441900438, 87.78398590703165, 89.70233086616763, 87.59548464129048, 87.10672593885853, 82.13251729165354, 74.35678712783321, 68.70821322164228, 68.22291404970231, 68.64904818996307, 71.09916456284063, 62.95370394183744, 59.47245136384041, 61.72063235313662, 62.96609078684161, 63.77004331158054, 59.511439723353234, 54.023129940032966, 58.17778287395355, 57.38207517131683, 58.50406915910783, 57.43323464547434, 58.760301912984545, 59.26214171994118, 65.98902225494385, 65.0332034018732, 63.982074875985425, 61.31236853138093, 59.12598840651974, 56.9222870949776, 56.70524666386267, 56.69926112697971, 57.86522488440237, 59.15883825671289, 58.807919486876465, 57.953650797567065, 57.594271475268954, 55.183268977749734, 56.85910163387176, 58.5350166597674, 69.98219905361053, 71.05160190213111, 70.73159925399288, 71.07823479560115, 69.89961747200259, 68.38308011331867, 58.41634927257415, 53.41744930513444, 56.82834632935063, 64.05947500659575, 66.55094100582984, 72.33702536552184, 69.76250710025911, 68.9702824623354, 67.38384846718081, 58.13336203175207, 60.038880840424575, 58.29016270176057, 61.8661875878611, 66.77185673867503, 61.93843764643516, 55.678550581778254, 56.04891254055885, 54.174031365302305, 55.504381656646736, 58.31737218364593, 59.54418366955173, 57.73310768988825, 53.36727042352, 50.25370082547588, 50.51467180252076, 54.452131332889685, 57.702842681638664, 58.75874473202614, 56.941259599501095, 53.491213398595015, 48.79148044893819, 47.62679930656187, 49.56144955850417, 48.86006701377131, 49.835784050726126, 49.60253246368901, 48.1537462049915, 50.471251164713216, 49.93938953645768, 53.23570628320017, 55.96387947759321, 55.11134055352981, 55.09226214501166, 54.781900682756984, 54.601656006228545, 60.75914567516696, 64.42377298108994, 68.722592630694, 68.19792855170466, 65.43979629393547, 65.29517066094184, 64.27871980974751, 65.28020289636427, 67.74389067003804, 69.03154988442698, 69.40570477516421, 73.3084003386959, 75.25192691433814, 77.39467067103233, 77.90795987652194, 78.22308309616582, 81.07603473048057, 80.41797084193077, 77.87187407093664, 82.90873081453385, 81.65784774288055, 72.20484933545514, 7.352946217983001, 1.0597756360807726, 1.7802286220173684, 2.558840796832116, 0.10351796018620653, 0.4195463356952514, 50.149048066908314, 86.62597671631845, 57.87097507907499, 51.636410836250555, 31.462749088964156, 31.025546020077122, 46.397128412800456, 62.830266952514656, 67.42461758275186, 61.89909235123665, 2.809109586861826, 0.26667336783101486, 0.06626906459249797, 0.11250281556239052, 0.12036653956578625, 0.024901059786638906, 0.017021288156449314, 0.05029068065566882, 0.043882523708406, 0.08659625771425425, 0.09794289321308175, 0.057182128000403606, 0.16209484318331366, 0.1607128205679117, 0.13409682699749548, 0.29898208415796684, 0.2162197977304459, 0.14453540315791485, 0.1846455145747431, 0.15830813186062923, 0.18288913543426222, 0.18501084658407396, 0.3180321780664306, 14.041111488496105, 92.36230973274478, 74.36152535100138, 66.43963982982021, 47.24551746922155, 91.46688753558745, 65.94134192312917, 44.91715146649269, 0.41729437427655347, 0.9058622595283293, 8.87677183074336, 11.404913952273708, 4.153867969589849, 12.942465409155815, 102.07099176222279, 94.665007745066, 103.54909773795836, 92.61857386558287, 100.00868797302248, 93.35441050990936, 98.55212365427326, 86.39824390411378, 84.28280768855926, 79.08172915058752, 90.72179409765428, 91.95809379700692, 93.06773231875513, 92.16186092745875, 94.41938892487558, 86.23808568523776, 78.49226751635152, 73.9620868621334, 72.13026154425837, 74.21280476354784, 75.25372335987707, 67.46117407275786, 61.606471769271366, 63.07036699787263, 66.34609914595082, 67.6575122341033, 62.20543338406471, 57.962119194769095, 59.210746903573316, 60.5878165460402, 59.59402522733135, 59.819863534742794, 61.85462836296328, 61.495833473820845, 69.19957637786865, 70.24087936647477, 67.25900726933634, 65.04005186019405, 63.22523786175636, 61.44454456144764, 60.51609208506923, 60.192861326279186, 61.34193143536968, 63.329208127913944, 60.07277796345373, 62.955068926657404, 61.69111259521977, 56.89318310829901, 59.62008937712639, 62.4008301765688, 72.52810755083638, 73.82583156708749, 75.39115536597468, 74.44431089585828, 73.65170186565769, 69.74154595405825, 63.30028457026329, 55.50157323960335, 59.077605970444225, 66.85662700283912, 66.82915472215223, 74.98986551838537, 71.49027978220295, 71.21423905895603, 69.86619887813445, 61.322256826585345, 63.52327131455945, 62.59778415003131, 64.48657404991889, 69.19592072886806, 63.50987249805082, 59.26535021874213, 58.09289493868428, 58.35214791759368, 59.77582316244803, 62.335216768326305, 64.02812350180842, 62.77552635438981, 57.44159321631155, 55.925659902634166, 54.640181526061035, 57.79849360066076, 59.49892736250355, 62.7882230666376, 62.3732598366276, 56.999859809875495, 52.0805408108619, 50.15365292949062, 51.92259873113325, 51.938931480530776, 53.189614511305294, 53.50356494226764, 51.22856278573313, 53.63684708072294, 53.801672920104004, 57.267392912218654, 57.45582357529671, 58.37971825753489, 58.01760504322668, 56.441628086951475, 58.53997061329504, 66.22445075742661, 68.33215205900132, 72.6783343284361, 72.08033761670514, 67.85754526815107, 70.64114155307894, 68.19191163586032, 69.14556534059587, 73.08888881437241, 73.55288167153635, 72.31400889735069, 76.87664324237456, 79.19292834497269, 80.87229113424979, 81.37253453654628, 80.91637073024627, 82.92447520840554, 83.80974631155692, 80.04580851524108, 89.48830281534504, 85.41807497701338, 74.14492422534575, 6.49501403493266, 3.9181808358238595, 11.338880850422768, 3.3629722797101547, 0.08924028761084042, 1.3387806905854134, 61.538799116688395, 94.17637455847957, 65.0650961937443, 61.62421264956075, 44.183750614043205, 40.190424765309984, 54.94542429524084, 70.73032056131672, 76.74171370844688, 75.78077223993118, 4.241192187032392, 0.36777818936013407, 0.17569368524897486, 0.2552306342629656, 0.2242212183773518, 0.25762372439907444, 0.09840656792925251, 0.10230358059127485, 0.16652372004764696, 0.13547377811083872, 0.2469220430019402], [0.030658880864540418, 0.06149839377030731, 0.05551722741896107, 0.04564746771188033, 0.09004497870562539, 0.05055924043840459, 0.07781377978502743, 0.035962683764556726, 0.03332069932272838, 0.040847107152184176, 0.010958141778715918, 0.1456719252371019, 7.3097001256481295, 60.109695311515566, 52.23829461682228, 28.733140307088053, 52.32878761906778, 67.6341349078763, 55.39615561885219, 17.933517694473267, 0.7357382786370094, 0.7661967700527561, 5.03732301535145, 0.6572051959172373, 1.3802582842688407, 54.23034091149607, 90.71795017488542, 89.16069861381285, 95.42447274731052, 91.6593425504623, 91.12859095296552, 102.28420396004955, 90.19021095768099, 86.23881524608981, 79.46072424611738, 69.91348697293189, 70.34785024581417, 82.81650804704236, 87.19403789889428, 81.2627552401635, 83.82209393285936, 82.01411662563201, 70.22368369563934, 68.61348013724051, 66.74905992323353, 66.21167952014555, 61.780746598397535, 59.756077951000584, 57.06903080786429, 58.939530695638354, 58.94691651867282, 60.2063189783404, 52.20273440884006, 51.47820595772036, 54.94851512293662, 54.133525048532796, 55.58508442294214, 55.76411316471716, 54.67285094722625, 55.794766487613806, 58.90963831255513, 60.492338211305686, 58.593985572938, 57.63867270561957, 51.05965768137286, 54.64423725681921, 52.280577767279844, 54.42665946099066, 56.795088552659564, 58.12345804706697, 57.559519275542236, 52.59375156894807, 56.30924809363581, 51.84799917282597, 50.037084010339555, 56.4560898657768, 67.41944005412441, 70.69188917836836, 67.73366112862864, 69.8081007311421, 64.76716472256568, 61.59496353518579, 51.16425944912819, 52.06290191219699, 57.29348844097507, 60.07909690180133, 66.3731478106591, 65.1056181999945, 61.64397355048888, 64.37142895114037, 59.67924264169509, 58.10454045572589, 50.0615752896955, 50.937385635991255, 58.9986918049474, 61.37511468702748, 62.0007013505505, 59.76258516311646, 56.840070293795684, 51.47256558941257, 53.32510102179743, 52.68018099569505, 49.131181240081794, 51.247025382134225, 47.231471461634484, 47.35368859383368, 46.54609218720467, 48.9336585229443, 51.20166317109139, 53.10210251039075, 54.237679666088475, 52.605816779598115, 48.280383848374896, 44.5380033985261, 46.0586670906313, 47.359756500490256, 46.10611600260581, 45.480564640414336, 47.303262602898386, 46.764925141488355, 47.705148650753884, 51.79410580665835, 51.42723867970129, 53.57216719658145, 51.4313454012717, 52.47797889094199, 54.61127758026124, 58.1668512282833, 59.94338681620937, 63.17309387268559, 61.83892319279333, 61.864218558034594, 60.568820507295676, 59.79557229626564, 60.633806336310606, 67.41781619287306, 69.82797145843506, 73.86233314391106, 72.30115921266618, 73.62098186246811, 74.3242157659223, 75.02459418389105, 78.65605000526675, 76.44562182887908, 74.16427719977595, 79.0954182224889, 77.86188771647792, 77.28849995520808, 85.81559150449692, 44.681722964009936, 0.04359583828538176, 2.5706571821243536, 1.2177717709733595, 0.17872304204971562, 0.22291228054992615, 20.130329362807736, 79.76962658666795, 60.62015648811095, 47.123908304399066, 62.237518372074256, 39.052917803487475, 26.42806729962749, 50.34769258191509, 59.150879767633256, 52.05941100274363, 1.593660471900817, 0.08038575911233503, 0.08759545087213479, 0.024366661748518387, 0.026553386950024196, 0.001914700187626295, 0.02143803018806202, 0.11211482267225943, 0.07751935687396797, 0.07173351613023589, 0.013233411422510062, 0.0207670942144168, 0.05613628391837401, 0.04473209223379532, 0.007663285237691937, 0.023422598192888885, 0.019676430158377178, 0.0732063737908198, 0.02823520275283485, 0.014219252625480296, 0.03739081338168152, 0.04806007010742061, 0.41554303599461434, 15.008725889267462, 73.03192030998969, 62.059415309659904, 37.23053755298738, 47.19679770931121, 65.03622362690588, 64.58824972952566, 16.829856864867672, 0.7842186513927676, 2.8844428735394634, 6.2882242279668015, 1.3309875539233609, 1.0193393703910614, 63.957952299425685, 94.90043624754875, 96.45714652153754, 97.1811846763857, 94.62972210299586, 94.62114780179917, 102.24862806258663, 94.50238627772178, 88.9909698117164, 82.6987349602484, 74.1493643483808, 73.55745515515729, 84.82905264823668, 89.23549036825858, 83.73868865351524, 85.39142639406266, 84.31300209414574, 75.15382059158819, 71.78336712621874, 68.85279178619385, 70.92901214476555, 64.50378148786484, 63.51017452055409, 60.172268882874526, 62.56620122540382, 60.83336476356753, 63.18923442594467, 52.7673242938134, 55.62253521334741, 56.897564395781494, 57.474501902057284, 57.71481767777474, 59.55320512094806, 58.573550024340236, 59.027882083769775, 61.49959894918627, 63.04022750546856, 62.93265258112262, 61.073198087753795, 56.27706504637196, 57.347546546689934, 56.44042784167875, 58.05342412764027, 58.507677739666356, 60.98200298124745, 61.51267613134077, 57.22436843379852, 57.27725375083185, 56.14340636038012, 52.29035623611943, 59.1492441392714, 69.57053845928561, 73.18359051981281, 71.34036679421702, 73.77830028533936, 68.2081816273351, 61.31930328184559, 56.44767638175719, 56.66881961207236, 58.82719793627339, 61.49196209446077, 66.36809579787716, 68.42383353940903, 64.23272609710693, 65.62477134889173, 62.23767526688115, 60.181258955309474, 53.41624121512137, 54.23829547820553, 62.73457288742066, 65.28863206986459, 63.74623844700476, 61.973519325256355, 59.88601038532873, 55.72223401838734, 55.71004329189178, 54.493104411709695, 52.55591246389574, 53.70832835474322, 51.33095625908145, 50.665722277856645, 49.89119145178026, 51.34258608664236, 55.68497150175033, 57.082410012522054, 57.12122186537712, 57.13454615685248, 51.916166044050655, 46.280681087124734, 48.819701902328006, 49.467493103396514, 50.581214812494096, 49.232123436466345, 50.35569421706661, 50.71138651140275, 49.72700103636711, 53.264900484392726, 53.32658367772257, 55.88351011276246, 53.14283632463025, 55.345784541099306, 57.523562908172615, 62.495347530611106, 63.22716766788114, 65.97669032312209, 64.35692402624315, 64.11380375585249, 61.66460129522509, 64.08652367130404, 63.60223254849834, 69.19919198559177, 73.65588311226138, 74.25346405275407, 74.50960266974666, 76.5417512770622, 75.90669601194321, 76.46881872607817, 79.24925358064714, 81.4156884531821, 74.77332715065249, 80.89671965568297, 81.2564088452247, 82.24936469908684, 85.5966212672572, 62.40471724540957, 0.6229162035930542, 0.7937783255211769, 1.9283592604821729, 0.9400374418304813, 0.2695722138929752, 17.821161400887277, 86.85905179669781, 66.21204822294175, 59.12858109320364, 49.99995877665859, 27.715551968543764, 37.402462882380334, 60.28947714836367, 64.69860953669395, 61.8363775745515, 2.9493872725194503, 0.21849662636316594, 0.06676080110933512, 0.03543998197382016, 0.01800301450965626, 0.021459595563130516, 0.0019364102814917363, 0.03372980559605264, 0.019281329887528575, 0.02619932409405949, 0.03498547349966342, 0.109373384696101, 0.27498425735581306, 0.14993457634362484, 0.10703965105236539, 0.12767961489096766, 0.1908927164491146, 0.2053347914930313, 0.2112807063085418, 0.19552990794181827, 0.17130326599844042, 0.21817402673825143, 0.5915796528420141, 22.384050699972338, 89.07712075018114, 71.10713481903076, 41.74319305727559, 65.09678109999626, 87.15174690369638, 74.11838546875985, 24.125082954283684, 0.798716405707021, 2.4955406063987366, 9.862295773721511, 4.877217748472768, 2.0286065844758867, 66.12636012415733, 98.13773309030842, 103.22514918542679, 99.58287546711584, 100.31784134526407, 96.19389272505238, 101.04912019545033, 96.51868066480084, 93.61547562383836, 85.42581773573353, 79.57250395128804, 77.35110098315825, 90.85877895355226, 93.27469225852721, 90.07792918912827, 89.14566809131254, 88.81167042639949, 77.91808743630686, 76.45844013460221, 76.81864707700669, 76.64853388263334, 70.13691302268737, 68.12739649126607, 63.16528443367251, 64.87018969751173, 65.63949984888878, 67.29826235002088, 57.20270518333682, 60.08689849607406, 61.6303119351787, 62.38670964394847, 63.36604702857233, 63.59854552053637, 61.27174062113608, 63.94240010169245, 65.30802034562635, 67.22212914497622, 65.3387442711861, 65.56125248632124, 59.091279352864916, 61.90082603885282, 59.955604999296135, 62.25433749537315, 63.834762419423754, 63.98923320154991, 63.627614205883404, 59.40204874161751, 62.64662550341699, 61.1620044708252, 56.498074916101274, 63.09159878761538, 73.95878422644832, 77.21425733258648, 73.73038461131435, 76.8711519241333, 70.35545179920813, 68.81876914731919, 59.670248646889966, 58.21978361375871, 59.72281625193935, 63.25403198119133, 69.2149285347231, 68.58849463924285, 64.29479760508384, 68.23589709497267, 63.48948009552495, 61.01929687684583, 55.896210747380415, 56.505182250853515, 66.91696874557003, 69.13157816856139, 67.34530725786763, 66.61163576187627, 64.66089202511695, 57.52419833214053, 57.52122125317974, 58.78731919873146, 56.46808839613392, 56.944115084986535, 53.487757790473204, 53.88023407228532, 52.992119250759, 55.49763910232052, 58.839082717895515, 61.52620438606509, 61.5192892474513, 59.66270200667843, 54.60911635429629, 50.75233605600173, 53.75596946285617, 53.685413868196555, 52.406372101076194, 52.44640381105485, 54.70297082777947, 52.95578241348267, 53.78777596258349, 57.172706896258944, 56.248474890185946, 59.469180107116706, 57.43137936438284, 59.30772358371366, 60.346382894823634, 66.14437949272894, 66.16221843227264, 69.91170621687367, 66.76409044573384, 69.46195156343522, 66.26780863731139, 66.0400915145874, 65.7746764921373, 73.83454707361037, 75.69170305805822, 78.83531801162228, 77.39386266277683, 80.90205407911732, 78.31678067484211, 81.45335889631703, 85.35259492935674, 85.45582386755174, 78.74777855411654, 85.42547256715837, 82.94036080760341, 85.58689378922986, 93.13035688092633, 62.23159559311406, 0.4591386789275754, 10.537650450583428, 5.265519157532723, 1.0513076066009461, 0.4481255521457042, 26.209004886688728, 96.2219141375634, 73.98621728343349, 65.7304007776322, 83.65425571318596, 52.770940719112275, 36.32750988006592, 68.39042279028124, 76.46684185151132, 77.36636684786889, 6.075295421384997, 0.3706205287767995, 0.2554637088530487, 0.16916991031217962, 0.12401415230405909, 0.11455327287436494, 0.1905251781065618, 0.18584051980606972, 0.18947592876370878, 0.12668450498172354, 0.16205517515059442], [0.03175501670357922, 0.06401987258164633, 0.03332305121265593, 0.014517700370971956, 0.06531724631185494, 0.08820279005674586, 0.0503392851040248, 0.1253669180216328, 0.08106122649605237, 0.11158000137056075, 0.19100988193625407, 0.31674453748329995, 15.84555179842057, 56.54704178533247, 53.870416379744015, 32.49589550879694, 45.41596320367629, 52.31129777046942, 60.840754508972175, 4.778199474657736, 0.3547485659439718, 1.9512477613264516, 2.487041565679735, 2.7138790968925726, 6.355502192051181, 94.77488117833292, 76.70383145732265, 100.13378020255797, 88.31660455273044, 96.65224521390854, 94.72012489072739, 93.12122560316517, 83.06458227096066, 91.36145422535559, 80.94829097870858, 77.75892549945463, 60.696921194753344, 73.36929905799128, 78.64153723562919, 84.08876019139444, 77.3588986550608, 80.7818961912586, 68.5035753250122, 69.97193028849941, 62.609323763078265, 64.78465064879387, 58.999892050220126, 60.601289887582105, 58.54320264631703, 60.73750988129647, 60.51114205391177, 57.54675980537169, 50.52397566456949, 54.02225917385471, 53.29656185642366, 55.889703535264545, 53.600820110690215, 56.29617483385148, 53.86060260957288, 57.33903892578618, 56.914677696843306, 58.141806894733065, 55.351703397689334, 53.99719522845361, 50.476918989612216, 52.72164044841644, 52.02633757745066, 53.9318093176811, 55.201358948984456, 60.332191759540194, 58.830669233875895, 57.96153868398359, 57.716818086562625, 55.288537548434356, 51.81035226391208, 52.715297975847804, 60.934710964079834, 69.02249705406928, 67.94876390887846, 69.11272725751324, 61.930447778394154, 55.44413405079996, 53.91608845803046, 57.19892009612053, 57.03078377631403, 67.13957109758931, 64.74592901045277, 65.23512309597385, 65.62954487339144, 65.91458351381364, 65.67291452038673, 67.64070095554476, 54.41459425034062, 50.39133679482245, 58.21248408286803, 59.527019377677675, 63.00877401905676, 62.404250483359064, 60.17700710604268, 61.447517718038256, 61.32684207731678, 56.53793011942218, 49.68029345235517, 49.35829039542906, 48.96850878192533, 46.88493005691036, 45.8509030649739, 48.146783997935636, 51.87214136123658, 54.42322346471972, 52.258573270613155, 53.02475337059268, 51.25822374897619, 47.576247799781065, 44.982717806293124, 48.39738422824491, 46.86546333374516, 46.19967237595589, 46.796743408326186, 46.37092698004938, 45.454041573309134, 47.66771747219948, 51.63387698511924, 53.60495036648166, 49.17148359360234, 51.29610207773025, 54.2253359671562, 57.82963329745878, 58.23819914171773, 59.50299878274242, 57.97918934975901, 56.17478924412882, 56.46240095938406, 63.0355324283723, 65.57404333545317, 69.51047128246677, 68.68400435293876, 75.61840180427798, 72.87384094730501, 73.6668892829649, 71.05851311837473, 74.03834558302357, 73.49213200230753, 78.87076054849933, 71.48245857607934, 79.3470068900816, 74.54157783139136, 82.38809893208166, 72.2750597615396, 93.0625940138294, 21.13605841513603, 1.11117854233711, 3.7291527467389263, 0.079742168647147, 0.12536503344533906, 2.9369607135172817, 63.75368310559181, 73.5742978126772, 46.66024100395941, 64.62596331873249, 51.734536770851385, 22.473992609208633, 54.815291820033906, 50.80601761418005, 46.215659956778254, 5.6707132343323, 0.19783950981593904, 0.1144747871665224, 0.07844470681682711, 0.0521922602708782, 0.13030178063819486, 0.062120051138223185, 0.05946474059695198, 0.010332516075352268, 0.0323252025390825, 0.05945777302728065, 0.021551993427677982, 0.10675687267775498, 0.07430630751074323, 0.06457910527505221, 0.1085014847077189, 0.08778053771464095, 0.10454143067040753, 0.09247681756894435, 0.11199937322207036, 0.11729203720366764, 0.19188951941267138, 0.26174362268178697, 26.266467609713157, 67.62516052492204, 63.412942886352546, 38.22621945411929, 48.32564407779325, 59.76184383515389, 68.9662031973562, 4.165363455972364, 0.2794852997026136, 2.8790221579613227, 4.009989793262174, 1.1909973044549267, 8.790081566379918, 101.83108391300325, 83.17518526507963, 101.78553735056232, 92.5488184344384, 101.30468614639776, 94.02646157049364, 98.19066939815399, 85.50888569124284, 94.79907435755577, 84.20612535169049, 80.5997883888983, 66.7157825346916, 72.8974614604827, 81.97985079980667, 88.7182552583756, 81.8776495225968, 81.33437771950999, 71.99053102923979, 74.33478263116653, 67.21641032926499, 68.56109296121906, 62.2088497684848, 62.93760261228008, 60.807237855849735, 63.19472574418592, 62.515571271219564, 59.07655869760821, 52.51346849626111, 58.551447468419234, 58.2142726836666, 58.43266241012081, 56.09222727437174, 60.27111653358706, 57.31180983204996, 61.94015564457063, 60.31992650801136, 59.63398241227674, 58.975134049692464, 60.10334499420659, 53.109103941148334, 55.648917075126406, 54.63065408891248, 59.21288459531723, 58.902283868482044, 65.16434000384423, 60.609295445103804, 62.20994803213305, 61.99841068636987, 58.96341400761759, 54.55254400930097, 54.863211416429095, 63.214839658429554, 71.66107546898627, 70.11857201976161, 72.01244138902234, 66.14682705171647, 57.02902263210666, 56.116067440279075, 58.236865535859145, 57.571662933595725, 71.7296620338194, 67.70942088096373, 70.6319788963564, 69.84124475909819, 70.29361171107139, 68.47266704805436, 69.12840104872181, 56.077133993948664, 51.431706259327555, 62.67272887691375, 63.78700756257581, 65.62728951054235, 65.18063352954003, 63.46818554785944, 61.985251134441754, 65.1406410432631, 59.820542104782604, 51.243032409298806, 51.851827406114154, 51.952126333790446, 49.32465214883128, 48.43888290466801, 49.55966880244594, 55.132791996002204, 58.19770459205874, 57.92371134604178, 56.09332946039016, 53.58857839338241, 50.21774445810626, 48.15700177223452, 50.92972916941489, 50.31408963664886, 49.65344482852567, 49.12475639773954, 48.964806064482666, 49.19722610904325, 50.16658106157857, 53.41553911086052, 54.96194139603646, 53.288897545106956, 53.968636451228974, 58.520335228212424, 61.44794917875721, 62.97291571094144, 62.949714891372196, 61.22640978905463, 58.030737138563595, 58.57111423246322, 67.56533653505387, 68.60711020808067, 72.03540294401108, 70.39888812649635, 77.15658280157274, 73.40699303534724, 77.68364737110754, 75.67097725406771, 78.48567008972168, 76.84923371961041, 78.60338041859289, 71.03244504620953, 80.44792990530692, 76.99483210040678, 83.9268212164602, 74.51765137334024, 96.03846488460418, 32.0983083786503, 0.8118168769344207, 0.803851462419956, 0.5780412857570957, 0.19880147110069954, 2.523828494933344, 67.10266943900817, 82.20344943384971, 55.60269978738601, 64.64849341300227, 33.8357340135882, 27.707501303765085, 64.74800002190375, 57.19564099465647, 57.76560844913606, 7.440242488538066, 0.16009245788858784, 0.10060710186559348, 0.05710630827853757, 0.060981142695151994, 0.009396752124772438, 0.05429270481991191, 0.05758338953338324, 0.03763193189496956, 0.07334447646092984, 0.06951749955694522, 0.1209234931476174, 0.3300839668560413, 0.19092398815818373, 0.18436797624153478, 0.2206430361876565, 0.21039098711504092, 0.2507276613745959, 0.2642045115991946, 0.3484233763189085, 0.27610780190556283, 0.38463632185612956, 0.5709321123938407, 32.82873607450916, 82.6393267416185, 70.34551251319148, 44.72840309143067, 56.18839986862675, 70.76128375145697, 77.36924586757537, 6.545589075934503, 0.45688221291188275, 5.258523610330397, 8.543949896289456, 5.567680414645903, 8.51810049626135, 108.2873679745582, 89.83271045069542, 107.45937916540332, 98.58536966385381, 104.73399085383262, 99.02788362195416, 103.63969664419852, 89.69459595218783, 95.97711117036881, 85.711272147394, 85.21670049236667, 68.06958075492614, 80.2207697591474, 85.03917401836765, 91.42720099418395, 85.09125524951567, 86.33686665565737, 75.1093016901324, 79.4924169971097, 71.28637929116526, 74.3757321757655, 64.73780970419607, 67.72524372223886, 64.71600917077834, 67.381667629365, 65.73069495539512, 61.667162602947606, 56.85603041802683, 62.339637279510505, 62.28917206487348, 62.0577718365577, 59.20744426788823, 61.95571568704421, 62.10847631577523, 66.19562133666008, 63.347607966392275, 63.63473330774615, 63.37721009408275, 64.42990756803944, 57.98986996373823, 58.56309298546084, 57.865487683203916, 61.88492082780408, 62.33945292811241, 67.2311427516322, 65.47583895344889, 66.53641254671159, 64.64612822378835, 62.34179850547545, 56.58723431248819, 58.84030649738928, 67.616805876455, 76.51693051861179, 73.7741425729567, 77.33365428063178, 68.78423660032212, 61.247504295841345, 59.00000579895512, 59.919005363218254, 57.488673425489864, 71.78695217255624, 69.83266261316115, 71.82233195151053, 71.0239491924163, 70.91784907925513, 70.31917771985455, 69.80567670637562, 56.925715246508204, 54.415013943949056, 66.70098735440162, 68.19197439378308, 68.9615120426301, 68.9820574175927, 66.59281622978949, 65.5744787185423, 70.78503762522053, 62.319668492963245, 53.534873300983065, 53.57747416342459, 55.296280307154504, 50.97285562945951, 52.04885198223976, 54.10690392217329, 60.05091467211324, 62.80466956477012, 60.20775848819364, 59.65131144369803, 58.45423936843873, 55.654227964339725, 51.64608732346566, 55.52129883919993, 53.61056327819825, 52.44166166551652, 54.440599564583074, 52.49732402063186, 51.44955696598176, 52.81367494213966, 57.19137737827917, 59.87400401023127, 57.81461846443915, 57.029065778178555, 62.7480697631836, 64.41546932343515, 65.68424232544439, 66.09061948714718, 65.86390649118732, 62.25916985542544, 63.68333147418115, 69.96661155454575, 73.10778679386263, 75.47110111482682, 74.06568450312461, 81.58569966593097, 79.62693075979911, 80.88972999203591, 77.66283527497323, 79.98151302337646, 78.66142365240282, 82.3609325962682, 73.6401544078704, 84.6585472168461, 80.31321217936855, 90.2347533933578, 75.7867342425931, 102.88642898682626, 27.677612843052035, 3.625267056688186, 11.197738282142147, 1.1304120070511297, 0.2999814918204662, 4.91784320723626, 80.22906949443203, 87.48236348552089, 61.49509214585828, 85.53629521400698, 72.97061366419639, 27.609610711374593, 72.33717441558838, 64.14884621097197, 76.0065124880883, 12.123431371104333, 0.5868706635890469, 0.2904494887878818, 0.1728391190690379, 0.15633740131893467, 0.21702346992829155, 0.12029857224514408, 0.13158442632805917, 0.22412982408798512, 0.22761172434735685, 0.15069841196940792], [0.04830794168576118, 0.047178417819762425, 0.05247215049401407, 0.02280223168312542, 0.057269814424216754, 0.03060559944940671, 0.03200239415520863, 0.08043231427549355, 0.07826553417309638, 0.07132165960126347, 0.043872047456041466, 0.0721131739837508, 29.941112649056222, 65.7618817206352, 43.84170424553656, 29.69108900716228, 68.29266163610643, 60.21187697687457, 59.831163883209236, 0.6017523198839158, 0.0459697379189874, 3.3768091759374066, 1.5265863484913305, 1.6299590660679726, 35.40345438065068, 93.50402539776218, 78.09274273533975, 96.0204533607729, 89.65592138228878, 95.9011427048714, 89.98818535958567, 91.47437141787623, 87.55651197125836, 92.78616889830559, 83.4607102794032, 80.04164295811808, 67.44127981124386, 62.294020114406464, 64.30854159016764, 76.33235162304294, 81.48680102440619, 76.83796082773517, 73.5122694507722, 69.41306314160748, 59.37637682883971, 59.709507649944676, 57.59114142387145, 58.5418455062374, 59.27413240555794, 59.719384178038574, 60.14543202615554, 54.365501865263916, 47.89974527974283, 55.556851202441806, 51.904242038726814, 53.67183462265999, 55.82321936084379, 55.648987677789506, 52.16638972682338, 55.21333002275037, 55.856916442994155, 54.18504538074617, 53.3282232284546, 51.896911128874756, 48.97172120309646, 52.74188380087576, 52.295208208022586, 57.01452555194978, 58.4630137105142, 58.632758202091345, 57.62745864929692, 59.32608419849027, 59.42305303389027, 59.14243490465226, 52.46209721411429, 50.75627411565473, 54.70397887691375, 65.18120619558519, 63.68415909428751, 70.76697118820684, 57.783478767641135, 49.79962764247772, 57.063131563125125, 53.94378823618735, 56.36269823197396, 69.94470119476318, 64.20530480723228, 62.91640220149871, 60.286194124529445, 65.5903172492981, 66.74032872722995, 66.82461261749268, 55.387538171583614, 47.69914742439024, 53.8534011379365, 65.5263041680859, 65.556922189651, 65.65815071905813, 62.43455471531038, 62.78611675385506, 61.70413094182169, 60.943657890442886, 54.15166601057976, 47.91453261529246, 46.98382477606497, 47.33541034883069, 47.797920550069506, 46.761206734565, 49.78185146085678, 52.345865618798044, 52.84918808167981, 52.763115590618504, 50.84071097835418, 49.54758790231521, 46.02549168371385, 44.293820165818744, 46.48484045459379, 47.129383933159616, 46.0528580604061, 47.090501477641446, 45.14085992690056, 47.51059516783684, 49.2990469163464, 51.00931406021119, 52.70913200993692, 52.32176657645933, 55.18771302315497, 57.23573938492806, 58.325813124256754, 57.2913585939715, 53.838523587872906, 53.14613896031534, 59.67372386686264, 64.3087573205271, 65.95030061660275, 71.04946813275738, 72.15284655171057, 70.55593198345554, 68.2007997266708, 71.08134915751796, 73.40516521084693, 72.86224642107564, 75.6158914873677, 74.0524112024615, 69.56536877539851, 75.97895391525762, 79.20188703844624, 73.90315717266452, 82.13665146981516, 79.59690893850019, 78.62935435387396, 2.6662021971517995, 2.3326992411767287, 1.3299163791441149, 0.13715170984787328, 0.07957263338950374, 35.33204763166366, 77.78597416416292, 54.747148483030266, 48.76269417424356, 43.42189688836375, 33.64208659818096, 35.666139433460856, 52.22012619818411, 34.22246402309787, 2.5415240228176117, 0.12996523821305844, 0.06707850543241348, 0.07900578195169088, 0.09425413389239581, 0.022680283892118645, 0.035850382935736454, 0.02552369200143843, 0.038474471563653606, 0.08183059327664875, 0.0768223011325444, 0.10211058772139012, 0.046681196113387426, 0.0293779167376699, 0.017535672147548007, 0.056084584474803946, 0.04203908633620989, 0.04279150342148158, 0.02188117374786206, 0.04634552702848469, 0.11403483053248738, 0.04094040900048229, 0.07694143546564926, 42.93731943253548, 71.95070328251009, 49.78364398402553, 35.66565698192966, 68.83081866848853, 67.50644606928672, 65.41909794653616, 0.4417292695612677, 0.09239673839821931, 2.7643271511600864, 1.1868479271088879, 1.3048841804265976, 41.16767937137235, 98.78474373971262, 84.09433780177947, 97.04648263992803, 91.99472873441636, 97.35340026117142, 95.2868446227043, 92.82784800375663, 89.26948947291221, 95.85603544788977, 85.33499133202338, 84.94311517284763, 71.22168371754309, 67.12606245471586, 66.80065478048017, 79.04170528534921, 83.15715805176767, 79.92401892139067, 76.6055525502851, 70.6079504566808, 62.62956711553759, 62.417865030227176, 61.309387530049975, 64.5935017831864, 62.9207677995005, 62.50535741929085, 62.69199948157034, 56.52480586882561, 51.63395935489286, 56.93201457300494, 54.72068032910747, 57.75389625180153, 59.325684116732695, 59.228111236326164, 57.243788088521654, 57.79679129200598, 58.5288114701548, 56.66554051060831, 55.03380313996346, 56.35854444196148, 53.33328700834706, 56.32365103690856, 55.22817619385258, 59.74278896085678, 61.845744194522986, 62.76800717076948, 60.69058264455488, 62.90460763439056, 61.81407105538153, 63.853695700245524, 56.35229610627698, 55.43673646065497, 56.01479576480005, 69.03719809747511, 67.75109998641476, 74.26782777232509, 62.63964368451027, 54.221131186331476, 60.013205005276596, 54.13766707143476, 56.8845421268094, 74.17580896808256, 67.77292405405353, 67.05158448988392, 63.791118206516394, 68.09596261670514, 68.92126852466215, 68.87087391268823, 58.47596929919336, 48.55817787108883, 55.11824000266291, 65.1425394704265, 67.34988074148855, 67.35675273403045, 65.73213446524836, 64.2708005443696, 65.72353270746046, 65.62506944902482, 58.42457056045533, 52.31982892559421, 50.476585588147564, 53.09859198908652, 50.61099736921249, 49.37759237904703, 51.34729293084914, 53.99631269516484, 55.22270056509203, 56.52284468373945, 56.074741348143554, 53.50998193986955, 48.86714296956217, 48.66879655468849, 49.08483843649588, 50.26451872241113, 47.042009215201105, 50.718850781840665, 49.73241390720491, 49.29059813099523, 51.28397803152762, 51.36146053191155, 54.78778816038563, 55.3964223400239, 57.85092784512428, 59.79166561557401, 60.145298665569676, 59.25195532460367, 56.04448418463431, 54.35650002571845, 62.98640474196404, 65.8037216432633, 69.03783352144303, 73.01957268868723, 74.95050845607635, 74.58089566999867, 73.0990634425994, 73.34937341751592, 79.0536920485958, 73.83452353938934, 79.49889675263437, 74.68267333122992, 72.76704265225318, 77.7957800895937, 84.31901116524973, 73.50484048166584, 85.42835158686485, 79.67241456431728, 87.49364422213647, 5.036791534193101, 1.8849291844714073, 2.2361393128671954, 0.3918043920590032, 0.05742921433862179, 32.47294179854855, 87.13639474684193, 62.249873838117054, 58.82688414665961, 37.62033093360163, 30.34935489777596, 45.929162194651944, 57.13857443101945, 47.61011354384884, 4.33782026652367, 0.06643993284312949, 0.05520346078781351, 0.03419580155863397, 0.03508326462319782, 0.040415133154320146, 0.05618540547607888, 0.03927207251469936, 0.02200512294357102, 0.06635756306951085, 0.10203662193230084, 0.19681581716624, 0.17864122385940245, 0.29927187989796367, 0.09798603162409798, 0.15280022015494688, 0.14331185349052952, 0.17111349069783766, 0.22037202492356303, 0.14528728781207917, 0.1654486535417457, 0.22170892496022487, 0.22701644338667396, 48.64499561248287, 85.21215838770713, 58.05420860167473, 40.078197909939675, 85.9573067388227, 79.84435558319092, 72.6554512208508, 0.8684574956855468, 0.28786547421928377, 8.661361144435022, 8.709203274019304, 3.9096756664014634, 40.79240268276584, 108.11458756846767, 89.08450265084544, 105.53920638176703, 95.88524141619283, 103.54199040320613, 95.15224456787111, 96.63267258674868, 95.45772660163142, 99.33374220325102, 91.5481198218561, 87.84290775176018, 74.60180190301712, 70.62932737411992, 73.25034141540527, 84.22579211573448, 88.92012396166402, 85.57609942651565, 79.71620390492102, 77.10479182581749, 67.07898616790771, 68.62059531673309, 63.064157885889855, 67.09305178734564, 65.68829021146222, 65.08492377496535, 66.77680676983249, 60.80576696703511, 55.12739481464509, 60.707044832168094, 59.27907851434524, 59.2339281112917, 62.126629044932706, 61.490483360905806, 59.13869296350787, 62.187402248382575, 62.80767410032211, 61.01390754022906, 59.58937329630698, 59.20634992661015, 55.04644886139901, 60.334635396157545, 58.87154033107143, 64.43258262449696, 65.04141684501403, 67.30910378117716, 65.10552014074018, 67.42484508022186, 66.09087051883822, 67.89526277972807, 60.48583884393016, 58.51110981356714, 61.22215793978784, 73.2988219107351, 71.57560702293151, 76.55970788771107, 64.31059298976776, 57.788236602660156, 61.69562724328811, 56.44635846537929, 56.55850687334615, 77.233367120066, 69.79329770611179, 67.87790236934539, 65.47601546010664, 72.27298090534826, 70.44068490305256, 70.992279975645, 60.874184869950824, 51.19585021849602, 58.43462751757715, 67.90370372033888, 70.89717818844703, 70.81089388939643, 69.0753706039921, 68.25947838444864, 69.21113952513664, 68.04876081405148, 61.44467399966333, 54.09868263429212, 51.69138677658574, 54.575183929935584, 54.09996524933846, 52.80520262256746, 53.77561661504931, 58.89166993479575, 60.247617613884714, 59.94281415016421, 58.67040903337541, 56.53001085404427, 51.69537582705098, 51.027274593230224, 51.01800211014287, 53.418151409395286, 51.44916472896453, 52.02741230687788, 53.1771452965275, 53.622428447969504, 55.79173057310043, 53.73596537497736, 56.84695797581827, 59.15739482448947, 63.047236780966486, 63.10145962622858, 66.3588390042705, 62.99998790987077, 60.878730896980535, 58.00175474536035, 67.11117313754174, 70.75518838820919, 69.67057458816036, 77.43057604758971, 80.57608942831718, 78.70140044919907, 75.88715476374473, 78.70408335039693, 80.55520672951975, 77.30746069262105, 84.21793168590915, 79.98199939727783, 77.47106275250836, 81.6589460065288, 88.08345102494764, 79.38085694466868, 91.51049644716325, 84.12552848938974, 90.76909788193242, 3.72537525911485, 8.040917198504172, 4.731810583222297, 0.3134562429641524, 0.2868104485734817, 43.4756725834262, 93.43949456368723, 71.10608362382459, 65.52570404544954, 63.534552051175034, 44.65061856854347, 51.45166720113447, 67.43522367169781, 63.732337567114065, 8.440301264486006, 0.21139902092756765, 0.16019914329292315, 0.19335005071855363, 0.14254153676090703, 0.07604828419824762, 0.11422989183976767, 0.12690239570914738, 0.20548114493008585, 0.2856631246545623, 0.17413746956134998], [0.07237477002725487, 0.07266443553230456, 0.0939922773789975, 0.052799204920208266, 0.021621833833295013, 0.017025631874979987, 0.030465267463437015, 0.03435607098283307, 0.029331767601111246, 0.043533926889781034, 0.018953834960777915, 0.13212382883554505, 47.07517677737821, 62.38154388243153, 42.09026790434315, 47.600531193517874, 54.70270018423758, 62.27261574037614, 46.052226558808364, 0.053236629633653554, 0.17499675974249843, 4.033204586275162, 1.071252981501241, 0.7438445307554737, 75.76993080877489, 79.5547434591478, 89.82245737506499, 88.73559213453724, 85.51456528325235, 91.8608739299159, 94.64625097090199, 81.620436176177, 90.46353740076866, 85.84793536893784, 85.47642415569675, 80.14438552241172, 72.28024513490739, 62.358237158867624, 60.55766920889578, 65.4374271823514, 67.83452879997992, 66.67651176452637, 63.30819599090084, 58.15249535345263, 57.189341668159734, 59.080029995210715, 59.59820647393504, 58.53214548480127, 60.40101366658365, 58.685439555875725, 57.84729180797454, 49.644882294439505, 53.93252318905246, 53.67717296846452, 52.71505478889712, 53.865387901183105, 57.64166547406105, 54.2889097429091, 53.38999271392823, 53.22184462701121, 52.519187311972345, 53.39168717784267, 51.507815930151175, 52.61816440090057, 52.02040303137995, 53.890012541124904, 58.39737676805066, 58.85401910351169, 56.43872553302396, 57.69160509109498, 59.813462226621574, 59.923621992911066, 59.41623987690095, 62.29318857192994, 61.112900318637976, 54.232235416289306, 53.819857028222856, 57.38912759288665, 64.13410202149423, 65.78716139639577, 62.772808151860396, 53.84658798094719, 58.60085364310973, 50.397122290826616, 61.59239438272292, 67.94237044549757, 61.60670318911153, 61.254513571339274, 64.40887581917548, 63.366235302340606, 63.92136050808815, 55.42910352829964, 51.36986617119082, 47.07975026099913, 45.59988314105619, 52.85802518167804, 65.12978000025596, 63.573308990847686, 62.51393172048754, 63.16160917282105, 64.37539838975476, 59.13133459706461, 60.344382486035755, 53.74004463995657, 46.508766912644916, 45.68168417099984, 46.547370879880845, 45.307223335389175, 46.51490934433476, 48.873403072357185, 49.07955892624394, 50.7777294804973, 49.38963797784621, 48.2208187349381, 47.40633464628651, 45.93284137787358, 46.595663101442405, 47.55470222042453, 47.28184253938737, 46.70118270381805, 46.92868409618255, 45.81173819880332, 47.465589892479684, 49.958852337252715, 51.9441129315284, 49.138829861917806, 54.26182185449908, 53.68557076300345, 55.31516259716403, 50.49673872609293, 53.55795252707697, 56.05358800580425, 60.4275014323573, 62.3198724562122, 68.20971919644263, 69.48648991123324, 73.6738867913523, 69.78903016736432, 74.508221995446, 69.15788158293694, 72.77577384825676, 69.06489787563201, 72.72670499740109, 68.14026186543127, 70.89289496021887, 72.31973555780226, 81.43668882308468, 68.01448714348578, 75.75202911130845, 72.96883290813815, 95.67319023993709, 32.654694626408244, 0.8379630900679097, 0.822206132354275, 0.08037722489285855, 0.24006958570211168, 9.913121846414382, 72.92365504849342, 61.16707217308783, 44.380932084975704, 38.27118550577472, 37.315621606765255, 20.950130224227905, 50.34309556407314, 40.564764007445305, 1.0039956098602665, 0.10430313902156008, 0.13797841064872282, 0.03729016091974993, 0.0642715362952121, 0.08452471000172439, 0.08028021517900691, 0.013068068581032417, 0.12673430069680178, 0.0243799074087292, 0.030013465194872795, 0.02414632720061608, 0.07101896294062177, 0.04977520690449784, 0.06457527483543081, 0.04510177945297572, 0.03041920642698965, 0.03716947525859841, 0.015548698626638902, 0.0424541795866624, 0.059418039877087846, 0.026240445778615056, 0.4337093095865942, 62.19130108433386, 68.22503212959536, 55.75223230546521, 48.91274444518551, 51.48109674453736, 72.60993603737124, 47.824592667241255, 0.07326183089565846, 0.5837363833861967, 4.939230911193356, 1.940497034980405, 1.5662168735458006, 83.28184235480525, 85.48180564757317, 93.85447348317793, 91.12676312846523, 91.84380377492597, 91.87381775148454, 95.59933985433271, 85.27782670913204, 92.33089154766452, 88.02873396104383, 88.25714926565848, 81.38466250511908, 78.18289449138027, 65.89956868079402, 63.03922337870445, 67.26624011993408, 70.89076119084513, 66.31303356539819, 67.6635056157266, 63.728846657660704, 60.49050254206504, 62.6014123424407, 63.37250717224614, 61.1153478776255, 62.421916838615175, 61.24815933166012, 59.96626992379466, 53.94512184204594, 57.390641627773164, 54.85295049605831, 56.12441032163559, 57.44657462643039, 59.42307264574113, 56.28645912293465, 56.75453516744799, 55.219452842589355, 57.05000731252856, 56.38474979708272, 54.72129614122453, 54.622287673334924, 54.543518635534475, 57.433724941745886, 60.62174112566056, 61.648656860474624, 61.29632995974634, 59.884186483198604, 64.07743553961477, 61.588185679528024, 64.05325020513227, 62.92621597166985, 63.932280386647875, 59.27691728838029, 55.42272575439946, 58.35333247338572, 67.55981383785125, 68.22843674690493, 64.07329743908298, 56.48192259573168, 59.455616551060835, 50.433188484561065, 63.05000597430814, 69.59848926913354, 64.16481417994346, 62.12594655252273, 66.42947304633357, 64.25935899057697, 62.83596223400485, 55.11891857270272, 49.34462878011888, 47.7112675482227, 46.16965839939733, 55.56607661708709, 67.3718773934149, 66.96370770854335, 65.96320521446967, 66.02069147171514, 65.44736254599788, 63.032312162460826, 63.24480264417587, 58.40577848495976, 48.86313038487589, 47.357065754552046, 49.356709680249615, 48.59487948879119, 50.313489514012495, 51.703283325318374, 52.92488982600551, 54.38256417551349, 52.55015050211261, 50.637375308621316, 50.67835623218168, 48.88872385025025, 48.40746079721759, 50.952286720275886, 49.839353407582934, 49.532526000853515, 48.01561209463304, 48.11548740633073, 49.35565064030309, 52.677482405016505, 54.42489439441312, 52.519971786006806, 58.65544126879785, 55.29306396361321, 57.439055442810066, 53.63550955249418, 56.5975619131519, 57.65954755967664, 61.44954558341735, 64.11086590059342, 70.73618058235415, 72.0789255634431, 74.32222320187476, 71.85195369105186, 76.0899491463938, 74.51681983086371, 76.39797287602579, 72.67503953749134, 78.53658245455834, 72.22049959244268, 74.7831173866026, 74.22618789057579, 81.66881468988235, 71.33660916359194, 78.42594023673766, 77.0272465675108, 95.69109978214388, 42.65119429557554, 0.24619891728845336, 0.47764865020590447, 0.798813300507684, 0.23491237372640641, 8.899973630905151, 78.82766154504593, 69.55360950962191, 53.92443133938698, 41.106486474314046, 29.608479968963135, 29.471732416460593, 55.86771472807854, 56.37750910174463, 3.4431413585139863, 0.24602518386898503, 0.12501927498247356, 0.03125655393476688, 0.07031269116146911, 0.047661735030311736, 0.028976170654078166, 0.031502493056318456, 0.07142658300337291, 0.05450827813136482, 0.06939360015695134, 0.10276667308062316, 0.23460400801512504, 0.15639697231592672, 0.13950163859032816, 0.17674431355009157, 0.16169290749296067, 0.13490817539634245, 0.239116832794201, 0.11345085702956685, 0.13550396197505538, 0.12075031897233379, 0.46539142727851873, 71.70599445219963, 78.95095732904251, 59.194453377877515, 63.28548938997331, 70.28063651054137, 78.50656847799979, 54.96674629949755, 0.12545065143175665, 0.4459407613162072, 10.381026287232677, 9.070567315624608, 1.3237379106783098, 89.01106019173899, 91.60123655872961, 98.15049648284914, 94.70128966915993, 97.90389707011562, 95.47543218058925, 100.34757291117023, 90.55193193497198, 96.2897240731024, 91.24375174122473, 91.80289345402872, 86.78910024704473, 81.47039767234557, 69.22929225429412, 68.89037593718498, 71.76914461197393, 75.33995274574526, 72.9353750905683, 70.89710758578393, 68.64250567651564, 63.3958335076609, 65.04855555872764, 65.95071638784101, 65.13158036816505, 66.6427166231217, 64.08528420232958, 62.325893294426706, 56.22827468379852, 60.89170217514039, 57.24177983499343, 60.166193131477606, 62.23491784065001, 62.29949574316702, 59.52685071576027, 59.9031432982414, 60.087051468510786, 60.691877026711744, 62.00210163670202, 58.62224625002954, 58.44728892849338, 58.08485015746086, 61.59865448551794, 64.14062100072061, 65.71339338056504, 64.44203553661224, 63.49712479499079, 69.4283603852795, 66.56108425509545, 66.09502038648053, 68.55268339956962, 65.0426523916183, 62.73534167197443, 60.41228655845889, 63.1508618785489, 69.9020964099515, 71.25051313830961, 68.90623015742149, 59.488756656646736, 62.777711114575794, 50.73440690194407, 64.11093650325653, 71.57476763571464, 66.08533997689524, 62.86035545410649, 67.0343025269047, 66.1475173888668, 64.30370530774518, 56.462597077892674, 49.7893157312947, 48.87741173467329, 51.10199182264267, 60.07456264188213, 70.99078163023918, 70.57027216880553, 67.32546790953606, 68.87715754970428, 70.36657564101681, 65.98375058943226, 68.11162071843302, 62.50063880797356, 52.50420778028427, 49.69377071626725, 54.54976697121897, 51.22834705537366, 52.82952916237616, 56.018102322855306, 55.73888447976882, 58.34819416845999, 56.25118132560485, 55.62047596900694, 52.30988963957756, 53.346164149622766, 52.74135820327267, 53.03735594595633, 52.162910584480535, 51.859687835939475, 52.90164193799419, 51.848120766301314, 52.50038346936626, 54.83855147515574, 58.87745526529128, 55.310483209548465, 62.73540050752702, 58.63362504589943, 61.81947215910881, 57.638700162210775, 59.15426477309197, 62.23686333625548, 65.51122265477335, 66.96504915914228, 74.15991552414434, 76.26197645741125, 80.2083593799222, 74.9261034688642, 81.9366184357674, 76.72500441151281, 81.06451865165465, 78.52959279091128, 83.51817300242763, 74.89092765315887, 77.22708348304995, 78.1700683409168, 87.02075542942171, 75.35194735373221, 82.15536117553711, 80.11672496795654, 99.43321351082095, 41.00042166248445, 1.7659877216623676, 3.941391951614811, 1.1249382169015947, 0.38967981574035465, 13.675081787570832, 87.02874921983289, 76.40992041557067, 59.52595641536098, 56.83752859792402, 52.183110790867964, 33.99140896335725, 67.75245712649438, 71.35144356758364, 7.647163204608425, 0.36925287797085704, 0.26668050777046914, 0.1677378774770806, 0.16610938905467912, 0.13158762857558268, 0.16440836742760676, 0.09482649350238424, 0.243468334778182, 0.17071284203519746, 0.1985541779187418], [0.0506618119505865, 0.0698195297210928, 0.019997857668767535, 0.05233248883497812, 0.06015093321160925, 0.1024419360703999, 0.015974390703523834, 0.036353794632539634, 0.06730231035861277, 0.047493230160926624, 0.0880567200722233, 1.7750627379263602, 56.79489635652112, 57.689773344224506, 25.47938519908536, 47.80325889587403, 51.345469028719016, 78.94377154688682, 28.935971952253773, 0.5203512491237733, 0.17908667334385459, 1.6838954557334225, 3.7224320105967985, 10.096719168847608, 98.72027566356044, 73.16077017015027, 103.05625192580685, 87.5353233275875, 99.2028997790429, 85.74815811649447, 83.99966747530046, 84.26993446965372, 91.26124551219326, 83.7266783560476, 84.05160750112226, 78.90460275834607, 76.74642055265366, 61.38951370793005, 65.29670823004939, 59.817631706114746, 60.90861935769359, 58.92092297154089, 60.60466704830047, 58.4825510363425, 59.33362691633163, 59.04297536419284, 60.24741365063576, 57.348684034039906, 58.57061609145134, 60.81953448633994, 56.9902382358428, 50.26835872280983, 54.230599787927446, 52.49016569506738, 54.13325048262074, 53.506581244930146, 58.56633678559334, 54.05439515267649, 53.980701661879024, 52.709359507406916, 50.827441600061235, 51.727833440226895, 53.49884633095034, 51.1211722127853, 55.33742204789193, 56.01146175015358, 60.54583934045608, 59.083010996541674, 60.54139137268067, 58.70239203976047, 58.67925790048415, 59.99544451313635, 64.08668056611093, 61.04527473449708, 73.06812378668016, 58.588651149503654, 56.13664027183287, 55.72054739921324, 66.74283119939989, 65.4167406020626, 59.52963559858261, 52.87704867701377, 55.15438856617097, 54.365203765130815, 59.51415400351248, 54.40720842730615, 59.02235154182681, 63.68142912464758, 66.0368202578637, 65.57491410163142, 59.75269686791205, 55.96332250102874, 49.600904680067494, 44.913813529476045, 45.52767622855402, 50.54116741303475, 55.46218087596279, 65.51485084718274, 60.59936008145733, 63.7304626741717, 60.48568587149344, 61.70538217790666, 58.57201245523269, 55.94748004790276, 50.17663801870039, 43.80860336365239, 45.28965111701719, 45.5349051567816, 45.28487367014731, 45.94423978559433, 47.98960285802042, 49.76897431958107, 48.02350782578992, 49.46611635146603, 45.21696959772418, 46.098471303139966, 46.709745237904215, 45.76794493582941, 46.60470808705976, 48.79161380952405, 47.305576801300056, 44.91057757408389, 45.442556873444595, 47.88467553354079, 49.89204652847783, 50.307782465411776, 53.79840166338029, 51.80302919880037, 50.21143728686918, 51.57806165756718, 52.67699210874496, 53.11173977390413, 54.387204339427335, 57.92751996747909, 60.60479256414599, 60.28952421680574, 66.17456605357509, 71.38181055745771, 71.79313382794781, 72.40688277829078, 74.68461098209505, 73.18759133738857, 75.06545743634625, 71.96014050514468, 72.35932011758128, 75.56589695715135, 75.67894751025786, 70.9388808281191, 68.47304359559091, 80.04456904626663, 80.55308080488636, 81.02020371344783, 2.9139310073467994, 0.8006003691304115, 1.3602855753514076, 0.16916755076137283, 1.161685309583141, 54.55749011808827, 70.21350906741235, 47.630533402965916, 38.99327816501741, 38.21674300778297, 32.64996620916551, 41.149699226502456, 45.65187023532006, 4.147099919857518, 0.16141685537032543, 0.028998940702407595, 0.09775680279539478, 0.03449836415388892, 0.1003819409637682, 0.05722971355182029, 0.05395643818642824, 0.053636148316605445, 0.053721597763679685, 0.04349111789657224, 0.051404652936804685, 0.09100746093017441, 0.028445154894143346, 0.05114480357376799, 0.012323540286161007, 0.10277143814751219, 0.05515694775949082, 0.10703048097991175, 0.06976645514969865, 0.19393583218897545, 0.30204940827623494, 3.488741118100382, 67.12141836843183, 62.2886033211985, 36.06865306054392, 42.45932763622653, 47.99558055016303, 91.9189642321679, 27.40719875981731, 0.3313125267384514, 1.1032813402914232, 3.8857004238713175, 3.1385629407821165, 12.433176040649416, 104.86409587244835, 79.51154247406991, 105.32470764652376, 90.65334873814737, 98.71722405956638, 88.7762200447821, 90.89846549495574, 86.08636056223224, 95.94751296504852, 84.67306783122402, 86.60863984015681, 80.39078881663661, 78.2250129022906, 65.57157616461477, 68.43611840278872, 62.926004163680545, 64.83872836635959, 61.33516142445227, 64.13544347209316, 61.470338067700794, 64.06895929767241, 60.45476582742507, 63.00102341559626, 59.62477660948231, 61.93047915735553, 61.0720213767021, 58.11517792363321, 52.91167928326515, 57.783231658320275, 56.357034329445135, 57.76992697869578, 56.56605743592786, 60.687252552278586, 57.97483944123792, 58.36220095234533, 56.73930852643905, 56.52675136443108, 52.46940458974531, 56.4613183852165, 53.98902493138468, 58.771143344140825, 62.21968335490074, 63.141848271892925, 62.41985367190454, 64.40457297909644, 59.5408300430544, 61.69738838749548, 64.52070259278821, 66.72958143295781, 64.91520281760924, 75.05401196018343, 62.962854831449455, 59.65978376327023, 60.27385434796734, 67.17834764911284, 68.82464485783731, 61.71185408869098, 55.7277645603303, 55.104111625302224, 54.004875229251006, 57.55968793745964, 55.4918614510567, 60.66033332578598, 65.66073556100169, 68.68496925600114, 65.31881470834055, 62.495065119958696, 57.09991162823093, 51.31192491900537, 46.0453349544156, 47.712581542230424, 55.448515338282434, 56.80791862549321, 66.90631558818203, 62.403336571108916, 66.64055147478658, 64.29302469376596, 64.43997629227178, 60.66298092565229, 59.002571029047814, 52.419280621313284, 45.920121131404755, 49.99036073684693, 49.39934584402269, 48.61426776455295, 48.882408834272816, 51.64048225648942, 52.776734059856786, 51.385175181973366, 51.636728548234515, 48.55937811636156, 48.8076170798271, 49.18104240971227, 48.68151287878714, 49.87669044925321, 50.078708202608176, 50.02876466320407, 47.451736081031065, 47.232197100116366, 51.04562736326649, 52.99850879176971, 56.04926947624453, 54.94109792094077, 53.563879228407345, 53.48130549153974, 54.485651908382295, 56.35280993676955, 56.63234941421017, 56.72190104761432, 60.60314909104378, 62.81489518380935, 64.93976077725812, 69.6300329700593, 72.9573089845719, 72.99012353343349, 74.54247213179066, 76.85215196301861, 74.98427221851965, 77.5866000883041, 74.7852825349377, 73.0546308332874, 76.73736772229596, 80.30877205633348, 75.42531921017554, 70.72712775199645, 83.98183638049711, 79.0306128225019, 89.7772716706799, 5.658245000147051, 1.393710788219206, 1.2764215012711864, 0.21155481256784933, 0.8102468869859173, 55.31794747998638, 78.86695584943219, 56.13898977156609, 46.84074063454905, 32.72377540988307, 37.952367413428526, 47.37615593018071, 60.11864223787862, 6.77167498296307, 0.22918473268228196, 0.17527737774916236, 0.03248626486428323, 0.030388277542266636, 0.06090095627211756, 0.021787113472518903, 0.04933062309940015, 0.056997749789227406, 0.04421787869725977, 0.02464155516316814, 0.15826749855712538, 0.22771016664562688, 0.12824222220168, 0.14096456009053415, 0.12593198447458206, 0.3389787685967261, 0.1016793338461749, 0.16907706045575682, 0.27827224543979096, 0.3330074503056465, 0.5044983772020186, 3.783730321353482, 78.24310287352532, 73.41533199433358, 39.88007899253599, 63.39498627570368, 71.14486802008845, 95.13685318731493, 35.19363895539315, 0.5357246112919624, 0.9337216904086452, 8.289766580827775, 7.069770703392645, 12.187294421657441, 111.24117159074353, 84.37932152901926, 109.49639151173254, 95.69314725937383, 100.88935421359156, 90.95333945366644, 97.15404971953362, 87.65577147083899, 100.88117214941211, 88.10442001588883, 95.05401272927561, 86.46183336934736, 86.13997151774745, 67.496687212298, 76.27206479349445, 67.8511361152895, 67.81134759226154, 66.77119778048608, 68.86628473958662, 65.80191343061387, 68.57792777399864, 64.85417466009817, 66.40760191025274, 64.72460308382588, 63.83542529998287, 66.31625775367984, 62.046938250141764, 56.935858495773815, 61.96381538145004, 60.068745766916585, 59.84793986043623, 58.44462563914638, 65.13666768227854, 60.356596746752345, 60.190150968490116, 60.82477085051998, 60.16516547049246, 58.16264644745858, 61.60361628378592, 57.47438423095211, 61.17203397135581, 64.95778014582973, 67.89308194191226, 63.75484020479264, 69.29280327212426, 63.92355311301447, 64.26712920588832, 66.76371389819731, 69.61866594129994, 66.574890998102, 78.20398115342664, 67.32338120860439, 62.2426135309281, 61.106718663246404, 73.12753985005041, 73.02876672437115, 65.60285314436882, 59.707009100144916, 56.64235145814958, 56.048798791823856, 59.08348168096235, 57.99261170048868, 61.971613053352606, 68.11090684706166, 71.52859349404612, 69.82379021183138, 62.6036520158091, 59.0654387781697, 53.623318825998616, 48.52872479346491, 50.27545429045155, 58.601881304094874, 63.04730738362959, 69.44783103081488, 65.53918130936162, 69.37588691711426, 68.17495130723523, 66.97284683104485, 64.6914904348312, 62.55446157147808, 58.26025070682649, 48.804494873169936, 53.601910529598115, 51.9926404953003, 53.22299780384187, 52.834439969831905, 54.54026699066163, 57.66981240241759, 56.773138969175285, 56.38915069641606, 51.20743297761487, 51.632551224001, 53.17157945325298, 52.695505695958296, 52.45912797989384, 53.05135096273115, 54.78796858941355, 51.153637670701556, 50.78352282124182, 53.305493093306026, 54.94876615462765, 59.98192410315237, 59.3273119003542, 57.783106142474765, 57.46186402536208, 58.494341681080485, 58.92639467793127, 59.737693802002944, 59.70746017271473, 64.48360089332827, 67.51844852201401, 65.77825761610463, 72.95901129322668, 77.09340126283708, 76.37046921637751, 78.45066685830393, 81.816923387589, 78.79104229711717, 80.6567882722424, 76.94238216646256, 75.38643283228721, 82.0294060245637, 82.12073449165591, 79.3124194299021, 73.65717749441825, 87.91990387824275, 83.62423389188706, 91.48659352333316, 4.5846672788743055, 3.342823064134967, 4.402246177196503, 0.34245518366655997, 1.663436372914622, 66.37654458322834, 86.23644613450574, 63.0719869367538, 57.63334612692557, 51.18901744965584, 47.07239973929621, 56.4199177680477, 73.79535475084859, 11.658678554719495, 0.561291968389865, 0.3117704205214977, 0.16287600771794397, 0.18722730748836072, 0.20630407657834793, 0.09741414698862261, 0.1954275585951344, 0.23462810914122292, 0.11522784393521086, 0.13580740940186287], [0.05032683234481562, 0.07121987715964356, 0.0319854770186207, 0.014949139064898895, 0.021152608810112845, 0.036960842703739484, 0.09614512234205201, 0.07560952266137447, 0.11410688876264519, 0.32781787877601964, 0.2586519676110437, 5.102039181417035, 62.55741511621783, 48.10973328928794, 28.28284436656583, 51.778855631428385, 43.6432283924472, 81.21703609343498, 11.897795065756767, 0.22203232131658063, 1.2940052416055434, 17.897645658062352, 3.8031320802627073, 27.543285392945815, 98.7264180952503, 80.1880415024296, 104.92866593022501, 83.19216912792575, 98.43362885136759, 79.12329842967372, 89.91082837504726, 84.44138126988565, 89.3679880326794, 81.95462995959868, 79.90623489502939, 71.1303238714895, 66.56252768731886, 61.50031282055763, 63.89884218092888, 57.82397331730012, 59.976664204751295, 58.81389717901907, 61.7135367854949, 56.667956690634455, 61.048808790022335, 58.623168007020034, 62.45330364473405, 57.9822370313829, 58.79634065012778, 56.48842980784755, 51.369309194626354, 52.230014493388516, 54.665661242700395, 52.78706558289067, 55.19362403500465, 53.98518885335615, 57.44721005039831, 54.88181914052656, 55.12650835898615, 49.75820741345806, 52.74593168689359, 50.028133161606334, 52.1820007601092, 49.62101859431113, 57.07177646698491, 58.47439642875426, 62.22936376448601, 63.89992475509644, 59.319322032313195, 62.37806866245886, 62.26298239923293, 65.02807294168781, 65.16516370158043, 69.82155446083316, 69.16399263566541, 58.915906260090495, 58.490776246593846, 56.293993996035674, 61.68424844741822, 62.906678645841545, 53.971346809018044, 49.519138951455396, 51.64932327885782, 48.64260688904793, 48.79074304334579, 53.66927331493747, 63.01683448976087, 59.631778040239894, 59.46807399872811, 56.25619019231489, 62.406046928897986, 61.19381489292268, 53.085695235959946, 49.67489627099807, 46.131740846941554, 46.97271662373697, 50.72158467385077, 57.068575812924294, 63.61632562452748, 58.96709319083922, 59.328414086372625, 57.20672561276344, 56.03720818796466, 54.52799389439245, 52.28144068871775, 46.14743425000099, 46.9610240382533, 45.19927970824703, 43.61083353719404, 44.86495256423951, 46.7102433789161, 46.603080303438254, 47.628391788851836, 46.97584275276431, 46.14694003135928, 46.016285880919426, 46.487303703062, 47.361094028719016, 47.57304322335028, 47.01980075528545, 46.84722823481406, 45.88499630651167, 45.605009678871404, 46.46126308748799, 51.74062428935882, 50.63006008824995, 49.961527393710234, 51.48453666317848, 52.05871674322313, 51.02784333690521, 52.42534852796986, 52.582812078537486, 52.8731772976537, 52.30071521574452, 54.03128454762121, 56.676436854947, 56.86043523973035, 60.55859881062662, 64.65650681526431, 69.00715274195518, 70.79658508300781, 73.799802718624, 73.78817681343325, 73.31457414934712, 69.94620738490936, 77.31769023403045, 73.583876240638, 69.84893260463592, 62.776122554656006, 79.12146276043308, 74.97156373916134, 93.53982879269509, 30.910712749727313, 0.8129990425321364, 1.298481769138767, 0.05914506359746861, 0.07895293720667401, 27.223298434288274, 80.94873028416788, 53.237447815556685, 45.89668889199534, 32.67002913259691, 27.408691221667876, 35.54500487542922, 59.9103133909164, 5.974182111601676, 0.17566857288681692, 0.02129670803345019, 0.04012479732233671, 0.033492130647984245, 0.08432623960318104, 0.012462650361891477, 0.1860746822410053, 0.1636140261806788, 0.06848260670179321, 0.011401162764448072, 0.03174942809217159, 0.06780093400588921, 0.05789354022952819, 0.06931152915762318, 0.09439397558209398, 0.13500899256717774, 0.09895871047891917, 0.0973787077612454, 0.1236513407239991, 0.22367504365261526, 0.7310268379026844, 9.504450098160776, 72.63797313936296, 58.299266522930516, 34.88616827995547, 40.28203172068442, 49.45992292896394, 91.22246896066974, 10.16149809283595, 0.42826910473165974, 2.127805655041049, 29.720969623134984, 6.60390442417514, 31.05521090569035, 107.53734803968861, 84.36953913780951, 108.46315291620071, 85.54480675728091, 101.7988028064851, 82.59265838130828, 93.53736554422687, 86.4324861957181, 92.3637217860068, 82.4014820591096, 84.22387799909039, 72.54428340542701, 70.46294043141027, 64.74204586398217, 67.55171022107525, 60.53726111688922, 65.76571387629356, 60.52662757135207, 64.09554904507053, 59.51540523959745, 61.6875236265121, 60.39187454408216, 63.798390280815866, 59.905241766283595, 62.253372592310754, 59.33025760035361, 53.8970963416561, 54.81647245345577, 58.516985524085264, 55.74943957790252, 57.650247619998076, 57.75154282969814, 60.23828629524478, 58.626199999163234, 59.10358382809547, 53.30422616774037, 56.46577419773225, 52.55726175923502, 54.92428664238223, 52.844853862639404, 59.32548799822408, 63.52271041562481, 66.1539343864687, 67.01076046113046, 62.54081956801876, 65.31229572911417, 67.13244807335639, 67.42868900299072, 68.64190163150911, 73.40958964440131, 72.81736666156401, 63.10562126098141, 62.791941473560954, 58.70161541046635, 66.43832191344231, 65.50598629059331, 57.185254558440185, 49.78814686498335, 51.3620763440286, 48.309801624667266, 50.78030647770051, 56.46396990745299, 62.51368853353686, 61.136614968699796, 59.76576620532621, 56.792790043738584, 62.68492352577948, 63.876068899708415, 58.809296238806944, 50.84972066263999, 47.22538002075688, 48.67177755601945, 56.575337763755556, 59.37553744162283, 64.24724671148485, 61.466274492202274, 61.98204655801097, 58.47119185232348, 59.27471291634345, 57.061405720249304, 55.126461290544086, 49.30718975682413, 49.71381010547761, 48.29106053998394, 47.28268584897442, 46.91889778260262, 50.1701896421371, 49.69113880588163, 51.727762837563795, 50.3985696454202, 50.35123448218069, 47.16261817562965, 48.675546953755045, 49.87534115391393, 49.87996170597692, 47.77945795366841, 48.966186738783314, 47.47499181378273, 48.28280787314139, 48.95351748312674, 53.438210410456506, 53.70059344076342, 52.159525579021825, 54.454610270838586, 53.14586831677345, 54.70041736479729, 55.00980215687906, 54.59619214457851, 55.987492146030554, 54.89040913120393, 55.86593004965014, 58.28842116940407, 59.985913153617616, 62.83008652348673, 67.21568861315328, 70.0219326634561, 72.69269804800712, 75.28399621286701, 73.84617297880112, 75.57897413930586, 72.91150354569959, 80.42794935164913, 76.68875386638027, 71.68991273449313, 65.12517513767366, 78.90564610881191, 78.00235563708891, 94.2165631632651, 39.82153761771418, 0.47453928318235183, 0.38976497407401767, 0.06004425163771357, 0.044976432146804954, 26.102700810278616, 88.04292509632727, 61.934260322201645, 56.152274839339725, 26.86179710972694, 32.33820249957423, 45.8491458431367, 69.71090439827212, 9.731282726410898, 0.24983680837096708, 0.07600863914816611, 0.08567245526900215, 0.054950559842250044, 0.07073416209389126, 0.02925751452905036, 0.23998657241463664, 0.1033791603760854, 0.04689990655489026, 0.057071363177871516, 0.12090374340092945, 0.1860246566995498, 0.21917021683146878, 0.17670101426061124, 0.18209451839568155, 0.31291703963952683, 0.2227152580575597, 0.38281720011465015, 0.27657388979869507, 0.5242259992707161, 1.0986538015065657, 11.040846417027137, 85.05222766630112, 65.44672319965979, 38.49806324128182, 67.6877066396898, 62.39698233142976, 99.37289530231108, 13.938438546273018, 0.5147736387387399, 3.183195345824765, 35.300645136064105, 8.209543324285939, 33.15003702717443, 116.64446400057886, 84.86131806527415, 113.20066221298711, 88.63127277743432, 108.32510902035622, 86.81291687873103, 98.79127056367936, 89.36113957435855, 96.3628762768161, 87.35138770072692, 87.47792336248583, 77.29537979249032, 73.79250711010349, 68.64508659608903, 73.38158392137098, 64.51946312381376, 68.8673516242735, 64.53559583233249, 68.26744079589844, 62.490322974420366, 66.69125987637427, 64.56671983964982, 68.67400230899935, 63.595862619338504, 65.09944046697309, 62.411075407458895, 58.21572396063036, 58.18731423347228, 61.47380544293312, 59.49180041590045, 61.318157949755275, 60.29993810961324, 63.21267843246461, 61.24913207946285, 62.7695918083191, 55.73391091439032, 59.1498677961288, 55.06981834288567, 58.239238569813395, 54.15945976011215, 64.12750459486439, 66.23480581468152, 70.40663872995685, 70.43487195045718, 66.44186773607808, 69.63460645368023, 73.25784098717475, 69.22141613498812, 72.58101247972058, 72.87929304184453, 75.43817673960041, 67.1943195404545, 65.83765014525383, 62.75776586224956, 67.98757183936335, 68.34056162065076, 61.42784310925392, 53.50812665877804, 51.29264254723826, 49.07116113170501, 49.73312777857627, 55.39790499594904, 63.394225335890255, 62.72122113935409, 60.52568620251071, 56.68543869449247, 64.19861324371831, 66.01045408556539, 58.448434260583696, 51.4938287581167, 50.53165958773706, 52.42196352251115, 59.157567408777055, 63.32871390927223, 68.17626137887278, 63.67497290334394, 63.94724422885526, 62.24889716794414, 61.648758842099106, 60.65443015867665, 58.54452056269492, 52.63504235975204, 52.476919850995465, 52.05115441353091, 48.88711960084977, 49.93670271288965, 52.9049994868617, 54.83927711363762, 53.59765083559098, 55.62663409017748, 54.35868478590443, 52.135112747069336, 52.68155382525537, 52.19704304972003, 54.39522950879989, 53.05664616246378, 51.66837815315493, 53.10043158069734, 51.218109669223914, 52.05159764136038, 55.58686910137054, 57.551325444252264, 56.58825020636282, 57.893034488924094, 58.452286028092914, 57.39394034108808, 57.81368494033814, 57.19669611223283, 57.75972489387759, 57.04913262398013, 58.61020457360053, 60.33278403743621, 63.55519156302176, 68.94229242878576, 71.98602814828196, 75.2317423974314, 76.94965424076204, 78.09258584053286, 77.49159243799026, 77.22130190941596, 76.972302006137, 83.23327556733163, 81.93616344082741, 75.88272248545002, 69.5956337836481, 85.25954061938872, 82.34899290146367, 98.57983912191084, 37.495827059591974, 1.5656578132221777, 5.821990226545642, 0.1882722667388378, 0.17828070288223608, 34.53998381091703, 94.14272062240109, 67.86844945723011, 64.69019605267432, 46.605202305701475, 39.746683105345696, 48.368044899355986, 84.10681878366779, 11.247359206599574, 0.4527554811248857, 0.19398470859854453, 0.2251024493166516, 0.16526201920163247, 0.27440910918578026, 0.2107588625362804, 0.5075729638338089, 0.4405185135622179, 0.18735539738930043, 0.16715385800888463], [0.029312724570533442, 0.011867681582037722, 0.10908398732182481, 0.03755982769953628, 0.021859857351368955, 0.06443107410544349, 0.0646309158013713, 0.05789535968834835, 0.0254653946256205, 0.24701118499280947, 0.329935192581146, 15.810046503620764, 65.18710544032436, 44.52715804499965, 38.14337115133963, 48.402565679242535, 51.97668429343931, 84.24530982971191, 3.380582250895039, 0.08806537686576767, 1.9503864333514247, 2.8056306896671175, 4.34707215716762, 42.27074007834158, 87.21889003630608, 91.39239388127481, 94.63680590352705, 87.45132184797718, 86.08835312627977, 86.12847112840223, 88.40768983287197, 86.07574662854596, 86.09019664026077, 79.83760910649454, 69.47800974692069, 62.73771078355851, 62.454095963508856, 59.26167495789067, 61.56867188792075, 60.945603386048354, 58.767809329494355, 57.179782852049804, 58.289625337046964, 57.907672774407175, 58.34797843810051, 58.48754421357186, 56.999950024389456, 56.219327757435465, 58.6081963200723, 53.15188523261778, 50.493820482684725, 53.42650605786232, 52.791619454660726, 52.22064787341703, 55.7425283616589, 54.05783507131762, 58.748660318313114, 56.7517698964765, 57.20022624538791, 53.29380050782235, 51.374710298353634, 50.26913927447412, 52.79941320419312, 50.81839661444388, 57.97064642752371, 62.07074703708772, 62.68330750926849, 64.24054730323054, 63.29199660208918, 58.617857117806714, 61.98152488277805, 68.92826603304955, 65.41485394200971, 71.28845030261625, 60.41165505686114, 63.07251253435689, 56.75641006039035, 55.72994932051628, 62.21903224145213, 62.12510716530585, 48.549627104113185, 48.28962495250087, 51.65114325861777, 52.378789994024466, 64.8988583011012, 68.9744637089391, 66.33614417045348, 62.51259811462895, 61.75821258175758, 62.69669063629643, 64.1079084334835, 66.18331293905935, 69.6157241636707, 51.99654325362175, 47.72071653796781, 43.60663267873949, 55.522644212169034, 55.5415068903277, 59.44530856224799, 58.89375663572743, 54.935971383125555, 55.082213032630186, 55.45542263215589, 53.602581254897586, 52.619611755494155, 47.6870822137402, 46.33850859057519, 46.37552792026151, 48.380741611603774, 45.22777572754891, 44.524051527823175, 46.33931659883069, 46.946585793649, 44.506777409584295, 45.939407425542036, 44.94314501362462, 45.836347149264434, 48.01043064363542, 47.83002514992991, 46.998635645835634, 48.44493119947372, 46.67564807399627, 43.12408701066048, 42.986341214949086, 48.328075947300086, 52.45048699840423, 51.51691190658077, 52.568499349778705, 50.6209288104888, 51.62976241880848, 52.00971849503056, 52.9633721997661, 51.221353469356416, 53.43345649780766, 53.642773782053304, 53.59058272454047, 56.644991213275546, 56.48610384233537, 58.674460841763405, 68.25543834317115, 71.0351828605898, 72.61491744749009, 72.84902803359493, 72.16880275357154, 75.5525452090848, 74.58921109476398, 70.24127944823235, 64.99639588017618, 63.71955848509266, 71.63140666100287, 78.2622754189276, 80.59523059475808, 77.31505440127465, 1.5402991997618831, 0.20369082809455935, 0.8779131657173558, 0.4805908874878961, 8.850017343797992, 72.28859978337442, 66.42733143221948, 48.17624099792973, 44.27505554691438, 30.925133343665834, 36.34370926887759, 64.37429620373634, 9.683875979915742, 0.1956556076484342, 0.0871484155856794, 0.0464280346979297, 0.0955223847901629, 0.006930864962463778, 0.06929298216897635, 0.047189449485872066, 0.04149504516634249, 0.04324043860598918, 0.0480793257273974, 0.04500158281335908, 0.036668170303586996, 0.049277560019324866, 0.11212711072256488, 0.040099367033690214, 0.0658447974391522, 0.06602531073675041, 0.061608821514152715, 0.08643144921910378, 0.22999316994701663, 0.4202906667224823, 24.120250594231393, 75.91923190701392, 57.82972351197274, 45.45895238076487, 44.684860860147786, 63.938736607951505, 86.27792912144815, 3.331908578834226, 0.08338510058820249, 1.925316481820999, 1.616192037059415, 4.056617458981853, 50.70587558131064, 94.49442386627199, 95.13188746667679, 99.74497133685698, 91.84905975095688, 91.53923957578598, 88.80097804530975, 93.92435443016791, 88.25063813117244, 89.92179532204905, 82.12115026289418, 73.33056173016949, 65.60839153105213, 65.8677896376579, 64.15333732481926, 65.90995511701031, 63.9442357709331, 62.31281218990203, 61.562047004699714, 61.17395985511042, 60.666146278381355, 61.79443567029892, 61.06332548203007, 60.71817259634695, 58.907508465551565, 63.31601327465427, 55.81627676563879, 53.5890490778031, 56.507523905846384, 56.30781250615274, 54.56663708533011, 55.44556179354268, 57.33188452259187, 61.11470068654707, 58.681215163200136, 60.10237616877402, 56.048108454673525, 54.669014869197724, 54.39380568842734, 55.75892386897918, 53.62657439324164, 61.42747048408755, 67.27540277665662, 65.87896054790866, 66.74450997383364, 65.91131225708993, 62.670312696887606, 65.85978800250639, 72.42083857136389, 68.72756619607249, 72.3451917402206, 65.75926157736009, 66.70090106225783, 60.87340431828653, 59.60532165342762, 66.05480040273359, 64.40342764700613, 50.77616053242838, 49.924802241786836, 52.91379344078803, 53.5756737955155, 69.49952002494567, 70.24511552626088, 67.32337336386404, 63.49251993240849, 65.64082561000701, 66.88670373732045, 66.30525158297631, 68.81865147621401, 69.05744537230461, 53.980128995833866, 48.55898195697416, 44.45688486099244, 56.869221348916334, 60.313313391900834, 61.051217125308135, 62.16546443200881, 57.32243553284676, 56.80318824706539, 58.755257744942945, 57.0342315396955, 56.28557266727571, 48.92327993146835, 48.490779784417924, 48.99147818165441, 51.950933933258064, 47.490885257720954, 46.84937377129832, 47.7028658313136, 51.20757810531124, 47.65484425329393, 49.280560785724276, 48.978393154759566, 48.93920083199778, 50.39510227018788, 50.483390900396536, 49.57664482055172, 49.94119774910712, 49.676971204819225, 47.721689285770545, 47.03567458737282, 52.22131859871649, 53.6430012795233, 53.83833531410464, 54.616647305027136, 54.38476854755033, 53.927608459226555, 54.51864296390165, 53.72010723237069, 54.6336115560224, 56.122931588080625, 56.64715243924049, 56.20651729645268, 60.77510187702795, 59.64742437485726, 62.471891756980654, 71.75838162822109, 75.09081948188044, 74.68644665133569, 75.80984484764838, 74.46149872195336, 79.59565378004505, 75.97245062551191, 74.94363646353446, 65.79903833327755, 68.6577009385632, 72.27043136473625, 82.6421743823636, 80.57742303417575, 87.4154870740829, 3.1515942802352295, 0.6110206967399967, 2.112860934388253, 0.6932067318308739, 7.77060313570884, 77.01924493235927, 73.76909840491511, 57.285220084651826, 42.00181061221708, 33.175536355664654, 44.92076789179156, 72.63434886932373, 15.807507749526733, 0.3837889673248414, 0.11373751180907411, 0.0650772003216609, 0.07370177220793502, 0.0367703817544445, 0.05749529708297022, 0.052595333601798744, 0.03991448703492361, 0.025996674685889197, 0.06273449195789234, 0.2048281928704631, 0.12442800832251388, 0.2126690721319568, 0.21269839797769824, 0.1334576491987513, 0.19154013735392403, 0.21844963452989058, 0.25096445915199095, 0.26303448083419956, 0.3759138592548909, 0.6729359840673785, 26.85438971365652, 88.29488246671616, 59.27892946427869, 48.50073868228544, 69.4135416707685, 72.53486971701346, 97.02641579412646, 4.5025573622795845, 0.19757582235240168, 4.1968850935659106, 5.682311192635567, 6.323814344021582, 50.28496996048958, 97.72645688826039, 97.91611917557256, 104.47378081660118, 96.81856155395509, 94.70289784093058, 89.35075313814225, 97.46274025209489, 94.53072932458694, 96.91547547617267, 84.88427177552255, 80.24329985341718, 69.43669934426585, 70.0064157670544, 67.0243553961477, 70.36437911372032, 66.84795072001796, 67.31592870527699, 62.284637804954286, 66.31520655847365, 64.45908215738112, 66.81290042015814, 63.858504526076786, 64.76029273002379, 62.96623199216781, 65.69046712690785, 59.99187907864971, 57.83727799692462, 61.84210423500308, 58.67664167957922, 59.99027090687906, 61.15866261143839, 59.01870765993672, 63.56192627260762, 61.469129977687714, 61.83531068986463, 59.5826268196106, 57.11094133315548, 57.92175016095562, 60.09296640273064, 57.489406908712084, 64.91743464623728, 70.75150920498756, 71.79056075311476, 70.14255339099516, 71.48041894358974, 66.11402819233557, 67.00109574102586, 76.35774504753851, 72.09065345025832, 75.72949117229831, 70.60911932299214, 70.74741425052767, 62.161071377415816, 61.86889794565017, 70.11981148873606, 66.66846306093278, 54.851036379414225, 53.70665742504982, 53.96548286561043, 55.67186686300463, 71.11207700544789, 72.45695575591057, 73.00182004128733, 67.17730429864699, 67.64001846313477, 67.74807976138207, 69.33183870007916, 70.08032106584119, 73.02567589667537, 54.46682453155518, 49.62534889098137, 48.035412219262895, 62.58831162606517, 63.80472883101433, 64.91360641294911, 64.88871505183559, 60.689178436033195, 59.812018794398156, 62.78579119713076, 59.62770662000103, 58.571094620612364, 51.396102905273445, 51.58552200563493, 52.4381511442123, 55.774248569242424, 50.72038050620787, 50.64070147852744, 52.18648402921615, 54.05970996425998, 51.38956431419619, 52.13493231804141, 52.9242818586288, 52.29228604224421, 54.1077668436112, 54.26923905649493, 51.88345739918371, 54.7243320557379, 50.880515190862845, 49.490329142539736, 49.153005307720555, 54.09787854840679, 57.1855212796119, 57.51798922015775, 58.02426522777927, 58.80997480884675, 57.7672323103874, 58.7071341852988, 58.03780132724393, 56.351543011203894, 58.00389635947443, 60.623663087044996, 59.939366386782744, 62.478610777085834, 63.18209571223106, 65.21615451382053, 75.58158643784063, 78.76713152854674, 78.56608652299451, 77.73111589493291, 76.40420944459977, 83.78420383699479, 80.0442474119125, 80.91597849322905, 70.69181857570526, 71.22282120489305, 76.06853300525297, 87.25345396226453, 88.03599034586261, 87.91608348969491, 2.9811594515077533, 3.2499616857497924, 2.8374050749886424, 0.9402279219319745, 11.534896396821546, 87.27459553749331, 77.87607885176136, 65.1670385945228, 63.93392778212025, 42.911070931342344, 50.255654165821696, 86.58370141060122, 18.483837996759725, 0.47214691316889185, 0.3183129033254039, 0.19507462188841837, 0.20792453639930297, 0.08175855802912867, 0.14916406043114203, 0.1499603781849146, 0.1476261848884244, 0.12683682624370823, 0.19846834542770542], [0.041134719541596795, 0.111272034025, 0.05415629137367491, 0.05129341313975954, 0.05886559089225146, 0.08106126480044858, 0.0326015189620516, 0.052861575968563564, 0.12211528847054129, 0.032297983435132814, 0.07730968626997164, 29.562539208319883, 69.29288171952771, 24.915038501062703, 37.95605051902033, 43.40398734615695, 61.01789266832414, 67.80930011503159, 0.46818455320692837, 0.04526536603788695, 1.2537411311941764, 2.3091483500696, 3.353176405352931, 88.1340103764688, 85.83445026028542, 93.13904885322818, 86.00846229061004, 90.95448478575676, 89.81120801741078, 87.33367427702873, 85.04706582715436, 82.59753780980265, 78.97107124328613, 71.90534499383742, 61.45947310232348, 60.74828070978965, 60.42109620186591, 59.556543057964696, 58.53003917201873, 59.325954760274584, 56.49708647881785, 59.201458731005275, 57.93859674084572, 57.4961063169664, 57.06638713036814, 56.996792516400745, 57.12481083408479, 57.92471155043572, 56.928441293777965, 50.7907792060606, 49.573871704839895, 53.01564170468239, 50.779627907660704, 53.10453045752741, 52.89570739192348, 57.706408116125296, 58.643438816070564, 55.38540832458004, 58.55369890889814, 51.664420481651064, 51.47109077822778, 48.7253688996838, 50.085184035762666, 50.17613595531833, 56.543444971884455, 64.71938633149671, 62.17334447368499, 68.48092755963727, 62.672026772652906, 62.207692669283965, 64.1217661673023, 63.27449890875048, 69.50644693066998, 63.204821925009455, 60.07354282563733, 66.04021703043293, 58.13280113281743, 64.25512675316104, 61.5883739532963, 64.52343256242814, 45.36192470981229, 51.298977175066554, 55.34829093563942, 59.422507824436316, 65.4437735772902, 63.72562639174923, 63.81493876057287, 67.2030193574967, 64.81010683121221, 61.922744243375725, 62.181789336665986, 62.07484983628797, 64.12477462522446, 56.56507684338478, 46.879685847989975, 40.658857745508996, 49.14436040386077, 63.26673261580929, 57.30519279356926, 58.92089551494968, 57.08733650945849, 57.639425800692656, 55.290247701829486, 52.19306184399513, 51.98841218025454, 48.63950037187146, 44.964835720677534, 47.82653031810638, 46.966668328931256, 45.23285911929223, 44.00973466134841, 47.917368488927046, 47.106367464988466, 45.328925809552594, 44.065546066530295, 44.05271991606682, 45.97942736841018, 46.41505364448794, 50.39080727484919, 47.85619128134943, 47.79582600439749, 46.38733033211001, 45.444412154536096, 43.82554015805645, 43.67120665888633, 48.80595007250386, 52.851914128949566, 49.20412555817635, 52.84774857182657, 51.64974297246626, 53.67602371400403, 53.213078129676084, 51.31236814683484, 53.145452545535186, 57.42362483855217, 59.845143210503366, 65.978714266131, 65.16522645950317, 71.20118541102256, 69.28729626440233, 72.64005199555429, 70.20742939364526, 75.79625775737148, 71.65337977870819, 75.24692196999827, 69.01345991319226, 66.16254006662678, 63.623440804020056, 68.02845078129923, 66.67994776079732, 79.73687479572912, 72.58988488105037, 94.14338742533039, 18.898271706796464, 0.6034429840022518, 2.093798705647069, 0.07782587631335182, 0.6686037874990894, 50.325295848231164, 77.50170430829449, 54.608433861886304, 37.360815155890684, 30.235268838943977, 30.50051716066176, 61.65693698390838, 20.304229605582453, 0.3780671179054245, 0.2237053194473828, 0.0608806319594864, 0.09329945810379521, 0.0761159144402031, 0.040729677364710844, 0.05986237087317052, 0.03308781242418674, 0.026843100335569154, 0.04439825792947123, 0.07513118502233299, 0.02488369257339547, 0.024568150533483397, 0.04818165975232278, 0.04105319246469487, 0.043133864284402905, 0.011339459170196808, 0.01920786780124951, 0.0330429541457805, 0.05101863272307862, 0.03523214615040249, 41.71104923371346, 78.26411893290859, 35.864301496936434, 33.608362059439386, 41.52850212589387, 73.81288774551885, 69.56898520069738, 0.5808536864576802, 0.08998143937318556, 2.324820915537496, 1.7898509314944668, 5.736933629358969, 94.68809481590026, 89.2975030406829, 95.05683683579969, 90.35480929959206, 92.92174954568186, 91.50506004210442, 92.28535282996394, 87.77926337334418, 86.63852045612951, 79.63542661359234, 76.31061384754797, 64.41107626884215, 64.91992535129671, 61.896664404099994, 62.930389373533195, 61.985839489967596, 62.86889445397162, 59.92855241221767, 60.594425739780554, 61.139576358179895, 59.84225242368637, 59.47307894306799, 59.4300191633163, 60.75984777942781, 61.32406896160495, 60.65450860608009, 53.96475722712856, 53.31584422819076, 55.298076752693426, 54.654804122063425, 54.06746056772048, 56.91829019977201, 59.57926534837293, 59.27683884097684, 55.197201236601806, 58.46718711237754, 55.28967503578433, 54.89646527074999, 52.43034954993956, 52.02419988570675, 52.19341093494047, 59.22378878439627, 67.67908527005103, 66.91853769363897, 68.82186781975531, 66.80748754932036, 64.78249726756927, 67.56943933425411, 66.53199595789756, 69.40943102682792, 70.2327992839198, 62.97573589509534, 66.56338276401644, 60.65769357066001, 67.0677681892149, 62.4944414631013, 67.20917747866723, 47.13258066485005, 51.228609854175204, 55.53306202734671, 62.242225216281035, 66.34900169987833, 65.68687031345983, 64.33297795634117, 67.5194840277395, 66.27959143730902, 64.9360070690032, 65.06793206737888, 63.91408843378868, 64.79444872948432, 57.1889925772144, 48.671479455886356, 43.98825183991463, 52.185197491799634, 64.2190448699459, 60.1821336438579, 60.26000838125906, 59.154500115302305, 60.71335200340518, 57.04400216379474, 54.57800411408948, 53.3168169759935, 50.508760790671076, 47.42240067451231, 49.896937724082704, 49.36244026307137, 48.565622529675885, 47.53172889832528, 50.205506663168634, 49.60299922573952, 47.00832782253143, 47.10135467590825, 45.25895464804865, 49.54195145637759, 50.266173962623846, 52.87697022961032, 49.64398799404022, 50.84527269486458, 49.532510311372825, 49.599865251971835, 46.38803243637086, 45.596596194851784, 52.153622411912494, 53.939485396108324, 51.40873685959847, 55.76293645366546, 53.35341661207138, 54.5291627607038, 54.13608243388515, 55.79917915405766, 54.825646877288825, 60.13384142229634, 63.25581273724956, 70.1031727944651, 70.0931001478626, 73.79618629332512, 73.20346124710576, 75.94814761992424, 72.34712154634538, 75.57377307645737, 74.10220176942887, 77.2590272657333, 71.91206009157243, 68.3971300432759, 64.26826669323829, 73.47997265477335, 67.88197378958425, 84.24414880814092, 74.1725455560992, 98.67790622095909, 25.8796650363553, 0.18555029505683532, 1.531245879107906, 0.16741851074320657, 0.3785907543234287, 51.38417497757943, 83.68141420425908, 63.830498803046446, 41.02844307499547, 26.0741400718689, 40.224247363305864, 67.18216803766066, 29.22542522030492, 0.29980136922770934, 0.10691261069188196, 0.12835303681992716, 0.040366544027722655, 0.03695843335721762, 0.04847745396076672, 0.06848962406717962, 0.1364348966988825, 0.06009103662724938, 0.02303194123200111, 0.14955562329100025, 0.22644659654507715, 0.08941445003954634, 0.1694527040085485, 0.16644939419723329, 0.16257803015891584, 0.09181270360826485, 0.10876211548043836, 0.16143151829319616, 0.11338175589879675, 0.18086404329346073, 46.061393137901064, 92.35075443021714, 34.053947233384655, 49.787950746474735, 60.531099073348514, 78.27175971000426, 79.3087951598629, 1.0675603151321411, 0.15654665057457265, 5.766467605867694, 8.1564030531914, 5.431080441321097, 94.57447159674861, 93.88725665307815, 100.83335845701157, 94.56261819408786, 97.269328178898, 97.14582843165245, 95.54645061492921, 91.681347047129, 88.41449122275077, 82.80350146755096, 81.55739584276753, 68.21484181188768, 69.36408842763593, 65.71053789507958, 66.34900169987833, 66.49565127588087, 67.2769638799852, 63.24829747599941, 65.72039873369279, 65.1439279894675, 64.86272150470366, 63.74530884527392, 62.46975014286657, 63.381512934161776, 62.721087778768236, 63.27328297399706, 56.86368296223303, 58.53769171622492, 59.099304522237475, 59.030204126911784, 59.66166257858277, 59.54583498739428, 61.26767704563757, 62.49535537535145, 58.5491568042386, 61.8661875878611, 58.32109451293946, 58.61659411461123, 56.177342707110995, 54.152744662377145, 54.75720544015208, 61.83392217082363, 72.14161288353705, 71.09220627815493, 74.88209447553082, 68.35201494155392, 69.32369585960143, 68.4881760997157, 69.86462993006553, 71.71680450439453, 70.83009781376009, 67.25684996574157, 69.32755547185099, 66.17817463413363, 70.12422023280975, 67.90831642766153, 71.36281844108336, 49.90458242354855, 53.711529008803836, 57.16875314712525, 63.14683752675211, 68.4803705830728, 68.29716451706426, 70.18093770550144, 72.27400072159307, 69.44375961057602, 67.27347297053184, 66.22944785702613, 66.28901297046293, 67.72113307829827, 58.18187782841345, 50.77285397437311, 45.92617334858064, 56.200394476613695, 66.86788420523366, 63.36394856053015, 63.75186704820203, 63.6597344952245, 63.91521415402813, 62.95697127619098, 58.67752813523816, 58.51814654565627, 54.85764557315458, 50.02134746120822, 53.0512450587365, 52.30686549217471, 50.82657475625315, 50.796843190347, 53.97721075242566, 53.88762381768996, 51.04238748550416, 49.90398230091218, 48.396772338498025, 53.01603001932944, 52.6664173987604, 57.57786027846798, 52.12867221524639, 53.071002037294456, 53.23867159505045, 54.09698032563733, 49.15682569626839, 47.35958391620267, 53.63900046194754, 56.756272777434326, 53.72095838669808, 59.229272257897165, 56.356375371256185, 59.614323492973085, 58.04259838596467, 58.785601200595984, 57.76648313768449, 62.613924703290394, 66.04751263895344, 72.70128019394414, 71.52357286022556, 76.99289444954165, 77.21566938584851, 79.31343140140658, 74.31508448816116, 79.5399953472999, 78.62056039994764, 82.72508544306602, 77.71983515831732, 73.9421219979563, 71.38808634973341, 74.88991568165441, 72.80102606742614, 87.2131633758545, 78.18135692227271, 102.00559800670993, 22.980802059173588, 0.9425728251376461, 5.818313985101639, 0.18635879360860397, 1.0910782338150087, 61.96492148983864, 90.49899562712639, 70.73567067423176, 54.82143425172376, 44.08180036852437, 44.33985702453121, 79.29788312604352, 34.84452447583599, 0.48220543311007563, 0.23981329864792286, 0.19711566397980337, 0.23760615337279536, 0.18442466674793154, 0.14524938178158578, 0.1759339304220292, 0.24262672590632595, 0.1397432933651632, 0.15467506713203846], [0.1008062310997517, 0.07888693107111801, 0.04938915604725481, 0.06827190187909911, 0.06583617895000404, 0.07816681608317361, 0.06914670534071422, 0.07781097590322457, 0.12509842718681022, 0.24036233854149622, 1.7289735400869002, 51.420186258131466, 59.96597574603174, 43.80899952303979, 58.5912516809279, 41.97724480782786, 76.22670650482178, 50.23271614505399, 0.15709153827159636, 0.19311947357510367, 0.9492599146981394, 2.4504598254157655, 20.128360332981234, 103.21555506798529, 81.14802591262325, 97.58580069388114, 85.49682832533314, 92.96430726205149, 83.14903874551096, 87.6440514287641, 80.06240798581032, 80.62380113909322, 72.22886993039039, 64.43436730292537, 61.287120234581735, 60.77676103961084, 54.24382994251867, 58.99647958817021, 55.61293717353575, 59.21952124564879, 58.02989775134672, 57.580896192981356, 57.00644546939481, 57.73732031545332, 56.066861306467366, 56.027923937766786, 57.497216347725164, 61.53462571482505, 55.59797725369854, 47.80670273688532, 49.089666874178, 54.21108599632017, 52.203134490597634, 54.21702054239089, 54.36944384728709, 61.20170277933921, 55.32470572379328, 56.2536955648853, 56.722544316322576, 52.45063997084095, 51.43756235799482, 50.74456584069037, 49.88521768200783, 51.334188292103434, 55.62888553065639, 62.99286880800801, 62.0270126096664, 63.75111787549911, 64.44105102169898, 62.679514577311856, 62.50804032048872, 63.09328540678948, 68.07109478981265, 61.21793354711225, 63.07638783608714, 65.99441159156062, 59.34289939941899, 63.95887405641618, 62.024616041491115, 61.59970960309429, 44.88247771416941, 51.243534472680864, 59.82223656869704, 64.62460617865285, 66.36083156831803, 68.35761608616, 62.92417633918024, 65.37062137357651, 61.53010714438654, 61.98727899982084, 63.213286399841316, 65.17951173167076, 67.25852089543497, 55.04811979109242, 46.378269657011955, 41.71152776287448, 53.80257506524363, 60.569852090651, 59.63778711134388, 57.495553262772106, 54.52222801023915, 53.86418765591037, 52.20970053826609, 52.21463880231304, 47.65216919683641, 47.9243032393917, 46.567390657240345, 48.948069310957386, 46.765992026175226, 47.261830606768214, 50.49404013541437, 49.76954306325605, 46.80073245879143, 44.936578965956166, 45.64445303332421, 44.09179456772343, 44.12185169035389, 46.48981401997228, 49.50714826583863, 48.7490443260439, 47.34698918557937, 45.95161384151828, 47.086261395485174, 46.20412818847164, 45.24129221516271, 47.50988129646548, 51.897577931804044, 51.35425121553483, 50.9189034277393, 51.43039226531983, 51.891439422484375, 50.884245364896714, 53.77291410200058, 57.02463349988384, 64.44957040971326, 68.21011927820021, 69.93048652525871, 72.02941740712812, 71.44558045171922, 72.29373808830016, 72.64242110713836, 72.25252182252946, 74.65390666838616, 71.22292318651753, 70.24953995981525, 61.76155051877422, 61.726919912522845, 63.80412870837797, 70.35723255526635, 68.6806546488116, 77.14560016509026, 74.83952891442084, 87.88956042258971, 59.46890946357482, 0.06871604901407996, 1.1323371553613295, 0.10120511009928682, 0.2116614366851507, 23.360862078205233, 80.10140419006348, 59.3529720460215, 45.47839949207921, 35.31049812993696, 28.277676643863803, 55.29581746747417, 30.532347194610107, 0.050065197996915355, 0.03831689876894798, 0.018059593933303992, 0.02822930004537827, 0.009549651783139957, 0.06391813993574151, 0.022624125816829266, 0.017843547562557845, 0.08690866070889658, 0.057097394845538565, 0.0332001822009202, 0.07713982159452093, 0.053750471617545814, 0.03625844732948369, 0.058216967229400916, 0.06256252054064985, 0.04504288261335704, 0.09140685320861879, 0.12663680834755783, 0.2810301006801667, 3.033915085177268, 63.5748230257342, 67.12950629572715, 52.892953888062515, 40.80839810832855, 46.00920208038823, 88.57141740860479, 49.896580788397024, 0.05926280365055127, 0.46315867934496174, 1.767686843391388, 1.3639911119976353, 24.016396037993896, 107.65718429319321, 82.59977356080087, 101.55607869548183, 87.42262578779652, 98.32909768627536, 84.40814310504545, 91.19587529090144, 81.69907969813194, 83.44294194252261, 72.89153083678215, 66.3967683238368, 63.43164082496398, 63.99650919821955, 59.76842164993287, 61.58700112373599, 57.70261910653884, 63.12731196803432, 60.47018858694262, 61.9848902763859, 60.17276310151624, 61.396475914985906, 60.021445905008626, 59.879263908632346, 58.26582439484135, 60.86294335703696, 58.14800031723515, 52.69488596147107, 51.906113009299006, 55.46827623921057, 54.932566765815984, 58.59775104830342, 59.04603873529742, 63.81551927135837, 57.31275120089131, 57.87317945111183, 57.03376477764499, 56.28640028738207, 52.27177596861317, 53.17547044446392, 53.58653091615247, 52.62634254270985, 57.47711420059205, 67.11875115671467, 65.53392533333071, 65.63109813197967, 68.05875501325055, 65.19702119211998, 65.19009820876583, 67.59553878538071, 73.78371315617716, 66.50350386096586, 66.18681169325306, 68.10421528354769, 63.88297619358186, 68.26656218497985, 66.17203220244377, 64.8618938845973, 47.40002747504942, 51.951628192778564, 61.59708945981918, 66.00110315507459, 68.74663675985029, 69.90588541953795, 65.76008919746646, 66.07982512443297, 65.73138529254545, 65.38370247810118, 65.33327256479572, 67.58325392200102, 68.80565274146296, 58.12095557489703, 47.428131257334066, 44.15229712763141, 55.315299880120065, 61.68920240094585, 60.90219059298116, 61.72125600999402, 55.674000632378366, 57.87974549878029, 55.38915811046478, 54.553842313828014, 51.44130037676904, 50.02803510235202, 48.71110716173726, 51.843837538073146, 49.47208227649812, 51.227539047118164, 51.61963485902356, 52.120729415647446, 49.19756343287807, 49.81288525366014, 47.85804656244094, 46.59074837161649, 46.91845063240298, 49.6493890977675, 52.51684565697947, 53.139965149664114, 51.5829332413212, 48.477302520505845, 51.30996765628938, 48.22723181016984, 46.544672289202296, 50.21017036130352, 54.71164318823046, 54.182464461172785, 53.27472994404455, 54.00076458531042, 54.74366934068742, 54.23053310763452, 55.66867405368436, 59.284432549630445, 68.56860037772887, 71.97963468490109, 73.38384320659023, 76.07021177968672, 73.40107810112738, 72.50174922327842, 74.63483610460835, 73.2063167325912, 75.67275801012593, 72.82271677447905, 71.3096389462871, 64.86341968659433, 65.07615727763023, 69.11324501037598, 74.09779302535519, 71.74422187189903, 78.47754293872465, 78.47289100770028, 88.30866567550167, 67.68347832464403, 0.3670865345385767, 1.2468061355813858, 0.34986870844037304, 0.3777443190976497, 22.575517277563772, 88.11654798446163, 67.12518384379726, 50.56159903926235, 28.753313056884277, 36.618184966425744, 63.47578710125339, 40.29922739151986, 0.06950501232377945, 0.025452493704975616, 0.048826050779391686, 0.051967490073894305, 0.048986649621398225, 0.045005440066057834, 0.06258479071660869, 0.017986250590653192, 0.09703966022859659, 0.004152678706187515, 0.20789001647743488, 0.1446755666045412, 0.2378852851688862, 0.20865365292035765, 0.24679421357089476, 0.19394101094334357, 0.24246051547027406, 0.15186836612561058, 0.2542627894229466, 0.5138528929843057, 2.8401274450363654, 75.94540196080362, 78.50886698692076, 53.657761158481726, 76.05552642576157, 62.51382581649288, 92.42955484697896, 59.22899376961493, 0.3843947283683285, 0.5292807086821526, 5.663142569603459, 5.743933098931467, 24.26144023095408, 107.20848083496095, 87.93295752617621, 106.09239393664946, 94.26309031824913, 102.78328634077504, 90.18120519576534, 94.91584331758561, 83.69216934327157, 88.23065757751466, 78.4570603216848, 72.04222002337056, 67.76438113181823, 66.6980848004741, 61.741734704663685, 66.19245206156086, 60.55211513273178, 69.75407400438863, 62.2627039109507, 66.49165830304547, 63.564060041981364, 66.39486205193305, 62.94454128511491, 62.616407563609464, 63.76233193182177, 65.28371341766851, 62.33045108856694, 55.67126674036826, 54.8141739445348, 61.03726525460521, 57.42224416425152, 62.6108495650753, 62.06099210246917, 66.11235726264216, 58.957852086713245, 59.986042591833304, 59.26158474337671, 58.307946728121856, 56.87959994039228, 56.94591153052546, 56.75743379900533, 56.464840673631244, 61.94284246813867, 69.37458469021705, 70.28418233317714, 67.8836682534987, 71.66276208816036, 69.04581946711387, 66.90115374903526, 70.08400024906283, 73.25132200794836, 71.96720077145484, 68.11528421217396, 73.1595463906565, 68.86531199178388, 70.0150606709142, 69.3656103072628, 68.70689530526438, 51.02063402052849, 52.59607361209009, 64.0137166361655, 67.70357654940698, 72.02675019541095, 73.77416610717773, 67.80101606922766, 70.07360596810618, 66.45506258933776, 67.76580887456095, 66.58252393045734, 71.07386527522918, 71.31542051992109, 59.998052889300936, 48.512046875492224, 45.00053321161578, 57.93934199117846, 66.75561812616164, 65.07870681824224, 63.14676300171883, 57.409339566384595, 60.673638005410474, 58.237508804567405, 58.595817319808475, 55.03560743024273, 52.67535648038311, 51.91453433805897, 54.94776595023371, 50.98934527366392, 52.21518008939682, 55.94828021141791, 55.02179284249583, 53.82603476124426, 52.11602649381084, 52.172712587541156, 50.51467180252076, 48.82626010525612, 51.70292246726252, 54.731694344551336, 56.41115127071258, 52.264637254899554, 52.160470870233354, 55.26925909903742, 53.45741825719034, 51.24542505510392, 53.00602797539004, 54.94585575595979, 57.68154813397316, 56.225603549711174, 57.421338096741714, 57.49231730737994, 55.59486681415189, 57.282509726862756, 62.01739888037405, 71.20837119317824, 74.55369795522383, 76.39596462249756, 79.18278509570708, 75.42533489965624, 77.53169475063201, 76.85855327113983, 76.55207495535575, 78.10498837501773, 77.01674246018933, 76.04236295146328, 68.774673861842, 66.41175962263539, 73.23429107666016, 77.50519521774785, 74.15826812867196, 84.33616761238345, 81.65110126618417, 92.88845646765925, 67.05793088482272, 0.6753766176200683, 4.971394346606347, 0.5201559886336327, 0.33106523355649364, 30.603728448191, 96.01764494372954, 71.07120590825235, 65.16009599931779, 53.71626723197199, 39.752315628913145, 74.41226513155046, 49.31208095242901, 0.19147881967646463, 0.07731406063201927, 0.11618848754874161, 0.17021540582420366, 0.22697945666168967, 0.14253813533052323, 0.1679364474670541, 0.11679116891877306, 0.226868910174216, 0.11157853814262537], [0.16643719807747873, 0.047493042469385176, 0.12099323779224389, 0.027372350262838508, 0.004364249208236053, 0.0349529339150796, 0.03821218987145732, 0.12807755926323514, 0.3369626396846387, 0.5194286341148039, 8.240003470451601, 63.48742869592483, 46.109477473843484, 36.385843369268606, 52.77825986185382, 41.87205860691686, 86.48104513845136, 26.1219302300484, 0.474777659100871, 0.07245903203804648, 1.8504302227689375, 0.2977944946577472, 56.021012721523164, 101.24247735546481, 85.92734767544655, 91.45943503226005, 81.84797286987305, 85.72461605072023, 85.50890138072353, 85.74137241609635, 76.37967894154211, 75.7726215547131, 63.021153019320586, 61.33668722644929, 60.511950062167266, 59.415322042280636, 57.349543033107636, 59.30401694390082, 56.6630341160682, 56.991414946894494, 56.465550622632435, 57.7027093210528, 56.02157362045781, 55.78026156271658, 55.59069733465872, 56.844259385139715, 55.98853941886656, 56.54091504312331, 51.86899169798821, 49.63812012826243, 49.46131144800494, 50.09514293363018, 52.611539517679525, 53.84147321024249, 57.33062151939639, 59.544277806435865, 51.829042357783166, 57.50206831962832, 54.23882499817879, 53.502074441602154, 48.71295459808842, 49.01102727459323, 48.163665879157286, 51.59940719604493, 52.10755025186847, 64.55387799970566, 61.64098470441757, 65.63663259629281, 59.5741819566296, 65.66068849255963, 62.61095154669977, 67.74601659467145, 65.74446247469994, 62.07568530113467, 66.8833226542319, 62.832373265297186, 64.54002026588687, 62.114061770900605, 67.30811534389373, 56.70437589768441, 47.4481745689146, 53.144315058185214, 63.276099235780784, 60.27629406221452, 64.66478301632789, 64.40596542050763, 61.53697521455827, 61.560478056630785, 63.29190246520504, 62.917751496837994, 57.902659985326956, 59.830493157909764, 62.87866507807086, 53.825740583481334, 47.80825991784373, 49.3737288444273, 44.89176588673746, 59.778411926761756, 59.21950947853827, 60.08365469594156, 54.05316352844239, 53.778601538750436, 51.57018946063135, 49.758823225575114, 46.556725732741825, 47.11088603542697, 45.282320207165135, 50.926991355034616, 52.447129449536725, 57.7013914046749, 54.29189074424006, 52.142655464910696, 46.584147022616484, 48.798317140148534, 45.1569494893474, 44.7511528384301, 44.7933889204456, 46.7673413215145, 51.639870366742535, 51.64898987739317, 49.014443659013324, 47.38028618597215, 46.36078765315395, 47.66696437712639, 44.61049664405085, 44.495830074433364, 49.459185523371545, 54.22404942973968, 51.27141860223586, 52.03971285973826, 50.08556842803956, 52.255886447045114, 58.34758620108328, 66.41500734513806, 68.94116278617614, 69.3392284454838, 69.55757110349595, 72.41541785578575, 70.54346669104793, 71.65715309881395, 72.17524328539449, 73.94543247838175, 71.79506363407259, 66.92130688698062, 59.63485317845499, 58.38802583755986, 62.730893704199026, 66.6635444087367, 68.21917210855793, 70.14934693613361, 74.3567322146508, 79.25803184509277, 75.33726984454741, 85.08814088759884, 7.730856778160219, 1.2962488373441081, 0.7004682647605097, 0.2560071869482917, 3.647341910869845, 65.93065738677979, 70.79591828007852, 48.81568539527155, 43.12457338456185, 21.223550804199714, 48.96505709617369, 37.444910772385136, 0.56964244933859, 0.04325458441951102, 0.024912627714295543, 0.015891382204098328, 0.03799191278014933, 0.08035547565668821, 0.053891899109247236, 0.04532222125318743, 0.009420694287626014, 0.037263719395043395, 0.04468072603847231, 0.052204517677666686, 0.15689664550365942, 0.04684533811204376, 0.07164127148327327, 0.09337537741709141, 0.08283553975484065, 0.30277507740163034, 0.3095498993512123, 0.6622369839779793, 12.395659550543755, 76.74421618061682, 55.4028275705153, 36.454610363129646, 41.576457023620605, 51.22226738160657, 92.76615696568643, 26.990939186465358, 0.4465684018308117, 0.7655214482257444, 1.7987811877842874, 1.0730527365399947, 65.0394635046682, 101.42569911095404, 88.65892548714915, 95.22192155161213, 82.67686382416757, 89.76314329331922, 84.38177693274714, 89.26024052404588, 79.70242854087584, 80.09874482308665, 63.853515271217596, 66.18266967035109, 62.02998576625701, 65.7221677226405, 60.9329733540935, 62.424960597868896, 60.63810917638964, 62.772039367306625, 59.133448754587484, 58.63383293151856, 59.39816559514692, 60.05136966705323, 58.242592196310724, 58.45543176897111, 57.38185551858718, 61.45782178448093, 54.603389693844704, 52.56496529425345, 52.685260465068204, 54.68437094842234, 56.49688643793906, 57.34949596466557, 61.40270856118972, 61.372388639757716, 52.49025198721117, 58.04354759954638, 54.67169777039559, 56.80889137329594, 52.62563259370866, 52.54554563953031, 52.14340463761361, 54.872664328544374, 52.87187114838631, 67.86899074431389, 65.6069363317182, 68.97533447511735, 63.29414998331378, 69.59082495781684, 65.99162670873827, 70.27828308843797, 68.38090712024321, 64.52087909944596, 67.60436411826842, 65.5898073411757, 67.4250804224322, 67.33463841099893, 70.24049497419789, 59.33831414868755, 50.02916082259148, 53.83458945059008, 62.1800870280112, 61.22226776615266, 65.06321737843176, 65.33652813203874, 62.36556414634951, 65.28761617598995, 66.53128993126654, 63.730517587354115, 63.10738240518878, 61.98178375920942, 63.76584245312599, 52.88328524558775, 49.76753480972783, 50.85969524998819, 49.50144906197825, 64.37274686751827, 62.670191103412265, 62.74750494187879, 57.653424739837654, 56.79311560046289, 55.931135531394716, 52.21930642281809, 50.08777672244657, 49.28852711954425, 48.789272154531176, 53.121781041545255, 55.02750773583689, 59.98515613617436, 56.06362927344538, 55.67766412611931, 48.421549950876546, 50.41155269069057, 48.25344108766126, 48.21564120631064, 47.14051561970865, 51.580858307500044, 51.97098508957894, 53.97113500102874, 52.79678521617767, 50.691374578783595, 48.986790949298495, 51.42923516611899, 47.51003819127237, 46.901913919756495, 51.85918185018724, 54.68338251113892, 54.510609949788744, 53.94344306761219, 53.17921630797848, 54.38082656552715, 60.82839904292938, 71.69630619787401, 70.03347227650305, 72.62856729568975, 71.68630415393461, 75.30756181286228, 73.6433001487486, 74.91504238497826, 72.44011309839064, 74.98427221851965, 70.77880890138688, 68.77837657928467, 61.58863282972767, 61.22680202607186, 65.78977761730071, 70.11043702402424, 69.60314904489826, 74.19612684557515, 76.57047087146391, 83.32416472896453, 75.30935041366085, 92.9115435384935, 11.931212679032358, 1.52307337570575, 1.6348389848586053, 0.2209749054764548, 2.40408637831288, 67.98808174748575, 78.17455553239392, 55.68949791692919, 38.54996012103173, 29.62175915318151, 58.75902714267854, 46.678907563609464, 0.7584622237951525, 0.06650430721140678, 0.10041557222364411, 0.03566835278404817, 0.05928062668610966, 0.04186486645090965, 0.041227695802527095, 0.05572607064799917, 0.03386001756054259, 0.06246774014265788, 0.37326031454628517, 0.15832585913519706, 0.33127986074936006, 0.126792868118613, 0.19010488694954306, 0.16858461913802933, 0.2229934705481414, 0.41935141228379746, 0.5349262863878281, 0.8813884469770616, 14.07594213562627, 90.84194414077267, 61.372588680636504, 46.98436606314875, 72.85473900456583, 59.440213403394154, 101.16212368011476, 31.202319399003063, 0.580500366707002, 0.6940468544921568, 6.446521772492317, 1.3129974805539655, 65.14712079878777, 104.87914208442935, 93.99269780805035, 98.64815896557224, 86.41746351795813, 91.83729264043993, 91.46802502293741, 93.21083607212191, 83.06061283234628, 83.85887007559501, 67.95338446094145, 69.24323235788654, 65.90106702619984, 68.38012264620873, 63.33768436985632, 66.92136964490338, 62.127213478088386, 64.86376485516949, 62.89962622427172, 63.494492884605165, 62.27776189004222, 63.68721854302191, 61.34624212018905, 63.51790943453389, 60.20330659804806, 62.59220261727611, 58.181171801782426, 56.705752649614894, 57.418521834957986, 56.42621709454445, 59.388477340821304, 60.94573674663421, 66.12276723307949, 63.927389191043, 54.352738472723196, 60.73866698049731, 57.105140147670625, 58.47004652023316, 55.323466254818825, 54.56632329571632, 56.629693969603515, 57.867684210500414, 57.87605847081831, 70.89535036394673, 71.02838931545135, 72.41013050079346, 65.42948438275245, 71.14861780597319, 70.05278602723153, 72.46396895377868, 70.61141783191313, 69.89615794151061, 69.4788569788779, 70.25788676354193, 67.55844100829094, 69.47611916449763, 71.93274667186122, 65.32987971459666, 53.017606812138716, 53.95119759344286, 64.37307242424258, 63.220707524207334, 68.03560518449353, 69.28742178024785, 66.3678918346282, 67.61122826606997, 67.23821870742306, 67.75808965006183, 64.21869970137074, 65.38683645186886, 65.12231180744787, 53.62401700788929, 49.58413262521067, 51.34937178704047, 53.72642617071829, 67.304365558009, 64.34763585367511, 64.89203337700137, 61.208845415423, 59.79617634127217, 58.22275284797915, 54.30320678218719, 53.35054151473507, 53.9570850710715, 51.86286887814922, 56.36576160307854, 59.14017169706283, 63.428169527361476, 57.75284113422517, 59.298317740040446, 51.252410796380815, 53.32555601673742, 50.25115520723405, 51.62405537020776, 52.970224580457135, 54.283532173402854, 57.65006719097015, 56.13592640046151, 55.75038486911405, 54.233843588059955, 51.1679974679024, 54.21278830497496, 51.3656613903661, 51.23333631023284, 54.66945025228686, 58.79838420498756, 55.82642393727457, 57.10761124087919, 56.5880540878542, 56.69214594748713, 64.36104251492408, 73.5285472869873, 73.27291073337679, 75.9677359365648, 74.92663691120764, 78.70337732376592, 76.39151665472215, 77.43880518021123, 75.80543610357469, 79.74809277442195, 75.56690108391547, 74.0052721577306, 64.88989960762763, 64.78720803414622, 68.66201554575275, 74.44202023167765, 72.51676405629804, 77.64200748935824, 80.63326189594885, 88.91816277657786, 80.69099918488534, 94.52417896639918, 11.067291036728891, 2.912109801846166, 2.460042911191141, 0.4422962359122692, 5.319835159086413, 80.40882387468892, 81.59184209762081, 68.77061813108384, 61.59317101201704, 29.872939894276282, 66.24412536621094, 56.332676410675056, 1.108536948600123, 0.12970939548986574, 0.20717335654602897, 0.12903995721811248, 0.17180793407943942, 0.2940379059122455, 0.15267680339034528, 0.14954201756946503, 0.14626334511464642, 0.1270203043015734], [0.07505681320664383, 0.0707317718995675, 0.06350681583787646, 0.025688398989938924, 0.057581206182799036, 0.06535373507968842, 0.11312099489113016, 0.06437742496810614, 0.18372505993372013, 0.3421120988505502, 12.160766451589524, 73.83175434604769, 38.32571821828043, 33.302503478142526, 45.68003677552747, 51.12266663582095, 84.15295370163457, 12.899466426141801, 0.44484841186673413, 0.1386600450402306, 3.600980721173748, 11.284325584288567, 95.61473907962923, 85.87571359449818, 90.80452472932878, 85.8408986368487, 87.23002172285511, 80.26368048883255, 81.92805197931106, 78.61966609954834, 75.39807442695864, 67.71762647936421, 61.20788051236061, 58.23149581109324, 59.13273488321612, 61.52081504944832, 59.43619297396753, 56.004715273457194, 56.380301829307314, 56.246286207629794, 55.07686684208532, 57.93660417679818, 57.153859907580966, 55.6660186090777, 57.78270998308736, 56.49747479346491, 56.528700782406716, 54.28302226528045, 50.65082903831236, 48.360007962872906, 49.92368436628773, 50.49737807243101, 52.78799126225134, 53.87005552168816, 58.302561313875266, 54.91757546701739, 54.5547797602992, 56.212624426810976, 53.56309867674305, 52.64205163524997, 48.52226857216128, 50.39465119761806, 47.32575739583662, 48.161171251727694, 50.265358109628, 62.12073764493389, 63.442039028290786, 61.547251824409734, 63.797480290935894, 61.74403321358466, 63.26866634430424, 68.88446884770548, 59.25946274111348, 63.926773378925944, 65.94281673431396, 65.02655498443112, 65.47434453041323, 67.36396989514752, 62.085906997803725, 50.0751623799724, 47.246321555106874, 52.615905115681315, 60.076853306062766, 64.9399451286562, 65.87215131328952, 61.52569840031286, 64.11308596211096, 62.72737141578429, 63.5691983469071, 64.02540922164917, 60.22820188153175, 63.804003192532456, 60.275391917074884, 56.59229024764031, 51.22855886336296, 47.29488834258049, 41.94865857401202, 54.922407827069684, 62.905686286187944, 59.56544683825586, 57.821082530483125, 53.833589246196134, 50.540622203580796, 49.717673640097345, 46.66550874710084, 50.788519920841345, 53.70539049948416, 57.374681503542014, 58.91494920176845, 59.90011915083855, 57.53446709725165, 52.345540062073745, 48.71114638543899, 46.126320131363414, 46.54322493460871, 45.40561206879155, 44.24205664665469, 49.76447536099342, 49.265373368417066, 51.748088559796734, 50.821310935481904, 50.127059259722316, 46.625512338453724, 46.42880547431208, 44.51894852422899, 43.34261009770055, 46.134274698072865, 53.99108417572514, 50.703855560671904, 50.542991315164876, 50.92425746302451, 56.70943183283652, 63.01235514302408, 69.1326685874693, 68.81039880937146, 69.95792742698424, 69.73689402303388, 73.2821047690607, 68.96920773290819, 73.00909211558681, 69.8019661441926, 71.42922416810067, 63.05672499441332, 57.160869183078894, 54.1385966731656, 61.00709830560992, 62.9582852701987, 67.8985026574904, 64.48130630677747, 72.72020170765539, 67.77995294140231, 81.03265331637475, 70.8659561218754, 96.8335214737923, 27.074356232920003, 0.9415672274847185, 0.33181495784271153, 0.06591685566931002, 0.05949582844491928, 31.657394747580256, 82.84619254450645, 53.7610528545995, 46.833154770635794, 25.053021600169522, 46.6491210845209, 43.40143780554495, 0.8077981022577133, 0.14182509133411994, 0.09248110766132032, 0.09587144509198205, 0.05139751299735039, 0.08418925542144046, 0.10999551703852993, 0.07354074052625126, 0.08270474556352823, 0.07433046226299579, 0.01623369231369467, 0.01613012297199138, 0.010661254937369979, 0.059550630544582685, 0.09814132530722888, 0.09484899350472036, 0.013256843179284085, 0.12505412432214907, 0.22162825590179813, 0.6408360420215515, 16.19161271279858, 80.75443175531204, 50.36490001986104, 35.35043570303148, 44.57910983793197, 64.69675425560244, 91.58346037710868, 14.572910358828885, 0.717474558661061, 1.4571944720322088, 2.6556500407957264, 16.80576566726931, 99.99659138341104, 87.31641584827055, 91.66360224446943, 89.20648836320447, 88.23095567764776, 84.0420526073825, 84.9514227528726, 80.11070805211222, 78.53357007426601, 69.50490151682209, 64.8335273035111, 61.424658144674, 59.92780323951476, 63.691780259532315, 63.28691713271603, 60.86711283653014, 59.09661769866944, 60.41571863235966, 58.76576185226441, 60.07752403136223, 59.79041437948904, 58.659143986240515, 61.04862051625406, 60.381397893351895, 58.78349096544328, 57.809260506783765, 53.60906101042225, 51.72713133596605, 52.809874165442686, 54.82238346530546, 54.76645046664823, 58.06108843895697, 59.5367076320033, 55.31959095308858, 54.82262665225614, 56.88288688659669, 55.723245989891794, 56.52310748254099, 50.86319008181172, 53.094591171510764, 50.807755224166385, 52.68913184442828, 53.364987604079715, 64.6196992935673, 67.13626061716388, 64.24534043958111, 63.99298690980481, 64.19151767607659, 66.64471703190958, 71.40814535079464, 64.09421151684177, 67.83516422394784, 67.02018983902471, 70.09590072016563, 67.44262910658314, 70.42679186790221, 64.81267990604525, 55.775727302797385, 50.10825149474606, 53.4884951960656, 61.2655040525621, 67.65802998696604, 66.777387280618, 62.73163895453177, 66.3430553866971, 64.31965758723598, 67.03004283289756, 66.27110342825613, 63.22306879105107, 65.39358685093542, 64.47444215897592, 58.88755144611482, 50.23830160017937, 50.07911220673592, 45.085032832237985, 60.87103128433228, 65.84921329252182, 62.23563563439154, 61.1426789529862, 58.60620375602477, 53.67501174249957, 51.83040342023296, 50.66345907026722, 52.76428053455969, 55.951743664280066, 61.72375063742361, 62.57390868279242, 63.45581831470613, 60.20620130723523, 55.329134079717825, 52.62393028505387, 50.86821463800246, 49.17024804699806, 48.67706098864156, 47.79827356338502, 48.5290660396699, 51.716886105075965, 53.174179984677224, 54.16036974999213, 53.01220178604127, 48.303298334921564, 49.98332792712797, 47.28147383659117, 45.96286712154266, 47.56801866715955, 55.44910369380828, 54.2599351944462, 53.95396678678451, 51.73515650533861, 58.40616679960682, 65.49591756636097, 72.19400790429884, 71.18610782008018, 72.49123727121662, 70.84941156448858, 75.02668872956308, 70.55862272939375, 74.83093107900312, 69.71623882170647, 71.30147257158833, 64.74325395399525, 60.04334842005084, 58.17729650005218, 65.05031278056484, 64.5162703144935, 72.71764432230304, 66.27171531800302, 76.64236791672246, 69.19433609131845, 84.19864931414205, 72.43648882835143, 98.05774811775454, 32.66353368759155, 1.0921349448542441, 0.633346276177514, 0.20486884149572543, 0.18326922229701476, 29.883973521571008, 88.1909082781884, 62.27398856993645, 45.31284801421627, 33.1332375157264, 57.68466641826015, 52.30643010908558, 2.1696916655186684, 0.24995552135571358, 0.06266389695566989, 0.03215125461499537, 0.094993109965036, 0.11097612490336742, 0.04885857121177739, 0.06066401293801685, 0.08150611673631976, 0.08239826442854059, 0.21691189688299933, 0.19670599080141515, 0.12807174465588986, 0.11406781061762765, 0.13493065241604082, 0.23347369124812467, 0.12314796733159213, 0.23964957033674564, 0.27218917024231726, 0.9447490051388742, 18.16607894436006, 94.88359359002884, 49.59989270856304, 47.1574681035934, 65.18809387760778, 70.47870051476264, 102.70560772188249, 17.837092107342137, 0.7495898224653736, 1.5939108907215058, 9.69935953617096, 15.489115234344238, 102.78710672932287, 92.31560999347319, 96.23460692744102, 93.64782733301963, 92.90660919681673, 89.22416256320092, 87.65950556724303, 84.86216529723137, 81.23605958877071, 75.6821560090588, 68.36383696525328, 66.3159361193257, 65.28772600235479, 68.87445895902573, 65.95066931939894, 67.60201854090538, 62.77328275865125, 65.70521131638559, 61.16085129399454, 65.72306594540997, 63.39513140340006, 62.68202489422214, 64.3694010857613, 63.26635606827275, 60.77026167223531, 61.38118651605422, 57.64454057139736, 56.26340735343195, 56.472042145267615, 58.00765791246968, 56.00554289356355, 59.68141563477055, 62.31779752239105, 56.91177514291579, 57.17975931782877, 59.14099147242885, 56.375234127044685, 58.584301240982555, 52.90881203066919, 57.376713291291274, 52.98864403078633, 52.86586992202267, 56.035733376779866, 67.53732296728319, 72.87339379710536, 68.90644981015113, 65.6328945775186, 68.04374802497126, 69.58087782705985, 72.46763244751962, 69.54637665902415, 70.42942770065801, 71.43244835638231, 71.96074455015122, 72.93834040241858, 72.97552447165214, 68.31395226140177, 59.21437509598271, 50.69002920581449, 55.47074733241912, 61.479606628417976, 69.15609298213836, 71.10185530877882, 66.32731099282542, 70.90646636101508, 67.53335352866881, 68.85635329831031, 68.14890676929106, 65.70958083675754, 68.12560789046749, 67.26867983418127, 59.55965349751135, 52.97941861614105, 51.74656668016988, 49.60577234145134, 62.484439419161895, 68.06134377756428, 64.55577642686906, 64.52619391102945, 63.58622143345495, 56.102609788217855, 54.342489319462935, 53.253101994914395, 56.437544899602095, 58.35054759056338, 63.00558513210666, 64.32229734236195, 66.69631188915622, 62.88784734664425, 58.64431742698916, 55.96744883445002, 52.186691914835286, 51.70016504103138, 49.25045659465175, 51.17361822435933, 52.427745096145145, 55.23609938160066, 55.26102212167556, 55.98381296280892, 57.27835985922045, 51.21876078267252, 52.50005399027179, 50.7258169112667, 50.54267752555109, 52.019089037372225, 59.62838126767067, 56.671345618463334, 55.73243218083536, 55.53527032175372, 62.23959722826558, 69.0542604077247, 74.0517443995322, 73.07836117282991, 74.82583199777912, 74.64298678982642, 79.28998347251647, 73.2951113485521, 78.39396507509294, 75.11514602168914, 76.3365093354256, 68.67856010313957, 62.38509362743747, 62.91167966781124, 68.4289247758927, 67.26616951727098, 77.64608675433745, 71.93964219862416, 81.75066671063824, 73.94942545121717, 88.22701761799475, 76.26658916473389, 105.09953221967145, 32.141164195153024, 1.8615881401684977, 1.48483075682194, 0.5291444063186646, 0.3844799786325424, 41.41312952964537, 94.90277398017146, 69.54231308352563, 63.642374084841826, 34.563047347530244, 62.7015543753101, 63.00001536646197, 2.1183196479274384, 0.3287388696785896, 0.2275033995148636, 0.21149092083496435, 0.17456551352816244, 0.16571315305848278, 0.20310216613354223, 0.26183763699185464, 0.18559940129278168, 0.17671152498693238], [0.022619954468081557, 0.04792321233018752, 0.07058301294643073, 0.02146148588508368, 0.05514431113917982, 0.02251832715926632, 0.09051708804984247, 0.06792616639887133, 0.14913686430983006, 0.27081845508467767, 21.846536936298495, 63.258628999033284, 34.38569738018897, 35.87144805539039, 40.12756878329862, 56.98937139203472, 80.0912295618365, 3.911254175247685, 0.09500151394956535, 1.150498342129492, 1.5395803028537383, 44.458496955133256, 93.9251938173848, 83.71784517841955, 87.64792673049435, 81.62988908829229, 79.75076783087947, 79.60047045061665, 79.0531115378103, 73.68646191012475, 67.36577418542677, 60.00717632232174, 60.5789049210087, 59.60632185782156, 59.899393512356674, 57.265808274669034, 61.77370594393823, 57.59760941228559, 56.76390963215982, 55.84864808667091, 55.841748637537805, 56.69027105454476, 56.351582234905614, 55.180978313569106, 57.244870662689216, 56.642657403023016, 56.77912842842841, 53.933064476136245, 48.97077591188493, 48.77693237796907, 49.90157396562638, 50.49126309733237, 52.51908533034786, 53.613975740248165, 60.66269067025954, 53.55520686795635, 53.867443223153394, 51.841558641003026, 51.298063262816406, 54.60276995935748, 51.30187188425372, 46.5988794449837, 49.54509327488561, 50.1234624462743, 50.2676958422507, 56.66980804935579, 67.43916957609116, 55.42351022843392, 61.23294838013188, 58.46197428241853, 68.24596189683484, 64.68086473403439, 61.824708523288855, 69.75100671091388, 62.918194724667465, 65.89769378785165, 60.39640488163118, 67.4005106956728, 56.49341121796639, 53.28062526641354, 49.08790572997063, 50.64154086574432, 59.561979463023526, 68.21282571361911, 59.91318456588253, 66.2253999710083, 64.57114819557437, 59.80961438148253, 57.297697144169966, 56.8836360592996, 59.87265471489199, 63.58346400722381, 63.45149586277624, 58.20168579778364, 48.83341843082059, 49.44508460260207, 45.51800366370909, 45.1254960029356, 58.394203570581254, 62.587915466677764, 60.57841854710733, 57.02825776992306, 53.51678725211851, 49.68198399389944, 54.38658068256994, 58.31419114143618, 60.1111073647776, 61.637568319997484, 60.731951882762296, 66.32101166632869, 58.6808660722548, 55.17328654566119, 52.46797292463241, 46.73723320807181, 46.27413465130714, 47.846577552057084, 44.15867097916142, 46.716150468395604, 50.33317588990735, 48.798364208590606, 51.538947782208844, 50.55669607654695, 48.80766022589899, 48.030509256547504, 48.834249973297126, 44.89618639792166, 42.0975282115321, 53.26847768598988, 52.617991816612985, 53.24163298453055, 51.88560293566797, 55.24415200756442, 61.45154206983505, 67.24290201740881, 65.57584762573242, 67.99980178956064, 66.02423729435091, 69.47765673360517, 68.54072017054405, 66.12828993028211, 59.81698059266614, 60.43813105552428, 52.03975992818033, 56.409095948742284, 56.00603711220526, 62.64963788370933, 59.74361658096314, 68.4250416294221, 62.62967694190241, 70.00979685014295, 66.65791188516926, 80.59828219875213, 72.07163779966294, 89.04944450624528, 55.93984319317726, 0.1281691987007376, 0.558320343975098, 0.3353991768052501, 0.253427064106349, 8.284174261554595, 80.71620433561264, 58.54470099172285, 51.56056396422848, 46.638679735122196, 41.20576166337536, 57.78734622463104, 3.942105087541765, 0.318015753141334, 0.19215740503803377, 0.038789571187789404, 0.1641178362432026, 0.07628003345622171, 0.061876136404011524, 0.04333287860537249, 0.013781604788927062, 0.03513044414801463, 0.10413234737972099, 0.01918047249707724, 0.08215813416867487, 0.020742165713360714, 0.09787978288987953, 0.09519315084382411, 0.036156166930713, 0.05571376727593522, 0.14316234377122697, 0.27708719935147996, 31.436159341566025, 71.68009111958166, 42.23209688740392, 35.20096202050486, 44.34622695369106, 67.946818413273, 84.79705395237093, 4.063542403521077, 0.3844316844497958, 0.9021358240035273, 0.7648198342611714, 52.233242604040335, 98.95863809893208, 86.28365578189974, 92.54746129435878, 83.55873031000938, 84.02450392323156, 81.98891147490471, 80.71094835958174, 78.8734277602165, 69.2905596763857, 62.83924133546891, 62.33642485833938, 62.05468100886192, 63.146590417431256, 60.930141402829086, 65.35950929887834, 61.73254851372012, 60.49846103114467, 59.98593668783865, 57.943146690245605, 59.032949786032404, 58.61640191847279, 58.92525326821112, 59.56705108765633, 58.33168099003454, 60.378491417054214, 58.03607940673829, 52.51531593261227, 53.565714897647986, 52.83162763041835, 54.463380690543886, 54.99119051041142, 56.11462793042583, 60.97315803650887, 54.57180676921722, 55.74275978149907, 51.980881229523696, 53.956704601164795, 54.695612461336204, 53.72093877484722, 52.82177463654549, 52.521093583876095, 52.02880474828905, 50.70769948344077, 58.602685389980195, 70.59412017945321, 62.60773520315848, 62.280770347964385, 62.29708740788122, 69.84123691435784, 66.93704343611195, 65.49382302068895, 72.33607615194013, 66.44946928947203, 67.10041015378891, 64.22438713812059, 70.40950990492298, 58.84398175824074, 57.558793637060354, 50.048270610071, 51.65281418831118, 58.80024340844924, 70.36295921571794, 62.638459128718225, 68.82579018992763, 64.29078894276773, 60.28101659590199, 60.91589535436323, 56.92557796355217, 60.39247858908869, 65.60382589217156, 64.8857105162836, 57.05039170480544, 49.67746150109076, 49.08865490267354, 46.30615688139393, 53.529452585404925, 62.21084233253234, 64.18138227155133, 62.41571949374292, 59.000409803082874, 56.120201618440696, 53.954174672403646, 57.790468431288204, 62.29412601840112, 62.73935817903089, 62.79367908354729, 63.798590321694654, 68.26157293012066, 61.17363822075629, 60.41706792769894, 53.933401799971065, 50.56826314618511, 49.34706849436606, 48.51859723367999, 47.9736662680103, 48.61670747880013, 51.59088780803066, 51.58271751096172, 52.02323498264436, 52.948722147172504, 52.39248691066619, 51.23388936442714, 51.03679026326826, 48.99904443371681, 45.21505940345026, 52.89710375570482, 53.437084690217056, 56.90921775756344, 54.1565336719636, 56.18166123667071, 63.81365222315635, 67.69087591478902, 69.55201702733194, 70.46198337308823, 68.69837591725012, 71.31328675054735, 70.25230130841656, 68.28422854023596, 61.91835118878273, 61.88242620037448, 55.14110742076751, 59.53004352508053, 60.05233849248579, 65.50111470683929, 63.654129428248254, 69.11104848307949, 64.58472351874074, 72.90306260508876, 68.93315330628427, 83.17301227200417, 76.09842146596601, 87.6033607605965, 61.51812822588029, 0.221133838077226, 0.9816426351185769, 0.38072961052098586, 0.3953109297060198, 8.413728187161109, 86.2494997824392, 69.03641362344065, 50.22946450018114, 34.98038753386467, 50.916149923878336, 67.75386917975642, 6.721268113582366, 0.3358384209775156, 0.265833153239181, 0.05235012417899505, 0.12533954570009825, 0.08443188312793933, 0.10284633856386909, 0.04451886315139071, 0.043540319893509156, 0.08939809406236296, 0.18242752149460778, 0.21730643216400378, 0.26409014999385805, 0.11806786210546572, 0.3069144343176196, 0.12834156082282144, 0.1602177285859662, 0.3083033823678571, 0.4350020063500251, 0.6726551668778543, 36.261586604579804, 84.98836363515547, 48.1975120113742, 48.29066438059653, 57.01949911732828, 72.99649346259334, 95.0508277646957, 5.4571141927473015, 0.3403106277748462, 4.9547100547821294, 3.095246736080416, 52.589499719681285, 100.07668618232974, 91.14420983099168, 96.02985920444613, 89.63543876524895, 89.34458717223137, 87.51591543997489, 84.48116194817328, 83.46101622427665, 73.47112378766461, 65.833602259236, 66.42681367935674, 68.20469071788173, 67.02182154501638, 66.34562846153014, 67.86516251102572, 65.66014720547584, 64.81746912002563, 63.02378885207638, 61.581137180328376, 63.875017704502234, 64.70699556412237, 62.83511500204764, 62.32704647125737, 61.94458792286535, 63.33372669835245, 60.86022123213738, 55.14153888148647, 57.261619183325, 56.24340718792331, 59.934796825532, 57.70201898390248, 59.95306722579464, 63.20834813579437, 54.516740614368075, 55.663963287107414, 53.64808467126662, 55.0027968037513, 58.184058666229255, 55.248227350173465, 53.25727147440757, 57.428947494876006, 55.40340023656046, 54.93277465143512, 62.915845224934245, 74.61691871766122, 66.52503767321187, 66.65981031233265, 63.509256685933764, 72.6073629625382, 71.18948105842837, 69.11140149639499, 74.791958408971, 70.03839877343947, 68.03118859567951, 67.42551188315115, 71.75463184233635, 64.17577720457508, 59.39365486944876, 53.570064806169086, 52.864214681809955, 60.83485918660318, 74.31076203623127, 65.28642377545758, 72.5256835260699, 69.28490361859723, 63.698373763791984, 61.098069837016446, 59.75506597949613, 63.65733792704921, 68.4670659034483, 69.08669056430941, 59.76049061744445, 50.5447446146319, 50.34649625901253, 48.59880185896351, 54.63268587666174, 62.55911350250245, 66.49283501409715, 66.60348507665819, 62.770066415109945, 58.14134013268256, 54.838076868364894, 60.02008484255884, 64.31380933330905, 65.46265194492956, 67.10944729466593, 66.92529201507568, 70.2388789576869, 65.68756065061017, 65.03043813090171, 57.76978185099941, 52.21317968060894, 51.832337148727916, 53.87835525697278, 51.10281944274903, 52.837577865969756, 54.29887256314678, 51.272752208094445, 53.1422911151763, 54.66443746320663, 55.46278099859915, 54.54127503979591, 56.12194707316738, 49.82925722675939, 49.04352411147087, 57.68497628550376, 57.30355716520741, 58.129612245867335, 58.20672604345507, 59.48762309166693, 68.41968367176672, 71.22433523977958, 72.89518648578276, 72.43625348614108, 70.51593165243827, 76.57577391593688, 73.89393175801924, 73.19717761008971, 64.84699280031266, 67.54421064930578, 59.39055619701263, 62.168543492594075, 64.3259451466222, 69.1390855850712, 67.04593627683579, 74.51341521355414, 68.88192715183382, 76.59000427492204, 72.78205748527282, 85.73892485710883, 81.23142334722704, 92.97516438268846, 64.02052979315481, 0.3871440340674693, 4.650207142676077, 0.638425990698799, 0.5741341147691973, 12.044315203543633, 93.98260162722681, 72.13670992082166, 71.54557735689225, 61.24562155815863, 56.46404443248626, 79.35638135479343, 7.030708799439092, 0.5457015275474518, 0.37699407387164335, 0.20585441361031226, 0.3348356425281494, 0.32339641764279337, 0.24214583719449662, 0.09869833251521473, 0.125403146319572, 0.23403396199066795], [0.032208990831408775, 0.012027093945371528, 0.05472625695889997, 0.04893046090259187, 0.05993021945018442, 0.07330525275920668, 0.08307687277274747, 0.023589978828245116, 0.13445066768796216, 0.1152475553775026, 36.94793078207201, 65.29630814829181, 34.56156076923494, 47.11496922277635, 47.152204282822154, 68.56354836494693, 71.16836301742062, 0.4564423252257609, 0.030023657994705345, 0.7267923328664996, 1.180607436164733, 73.43464574506207, 92.20659163690384, 84.49194062140681, 83.3218740647839, 78.04266975771996, 76.59931598171111, 73.74735278467979, 69.93542871167584, 66.17736662587812, 61.04975015886369, 60.54387815536992, 60.11135839646863, 59.43073303468766, 57.301588135380904, 60.37875421585576, 58.86164419112667, 59.8864967592301, 57.009716726118526, 56.67209871353642, 56.31923052572436, 55.45128060925392, 56.83524970085391, 55.42212170939292, 56.661967231381325, 54.51639152342274, 56.179288202716464, 52.21804341962261, 49.21166435364754, 48.038067663869555, 48.24129742960776, 50.9837088277263, 50.55449562688028, 55.51884735784223, 58.02131560540969, 54.89356271682247, 53.24690465004214, 49.691589878451445, 52.082682424975985, 53.15107330199211, 52.3265597128099, 49.86791610717774, 47.877348546058904, 47.51287406490695, 52.612198475868475, 55.42957421272032, 65.02649222650837, 62.70665345653411, 58.20205450057984, 58.10607018009309, 66.74392946304815, 64.41268836298298, 63.3040225890375, 67.51287091162898, 67.21424518092986, 65.86734248745826, 61.711716805734945, 63.378735896079775, 58.93405114450763, 51.750441981900124, 47.90222421769173, 51.13384931318222, 64.03534066292548, 60.159670229881044, 65.61562438164988, 63.789513957115915, 58.65442929729339, 54.72170014535227, 56.10961121897544, 53.906717915688795, 56.98316620242212, 63.33807268450337, 68.4566088645689, 55.48899027609057, 51.599544479000954, 46.4283073333002, 44.25256859871649, 42.47947292943155, 48.65538989343951, 61.23294838013188, 61.24497044471003, 58.249421042780725, 53.671830700289824, 56.83491237701909, 57.87102606988723, 61.16906865950554, 61.922705019674, 61.94876524709887, 65.53520010363671, 59.211303880137784, 55.71668778696368, 59.27818421394595, 52.17861575465049, 48.570737300380586, 45.917661805306714, 47.554353129479196, 46.913967363296024, 49.6842707357099, 50.80667657236899, 52.275482608426, 51.38299434415756, 54.342061781114154, 49.78186715033747, 46.83300179819907, 45.569837785536244, 49.89703578333701, 44.695168848960634, 47.03212876473704, 54.37296221333166, 52.061078010066865, 53.59023363359513, 53.08056477577456, 57.13336160106044, 62.43670417416481, 62.851985116158765, 64.28768634796143, 61.45811988461403, 61.698914189492505, 58.8696458262782, 58.08455597969794, 56.186834842928, 53.255812352703465, 53.90952633273218, 56.31633581653718, 56.132431568637976, 57.43566651498118, 63.26459492406538, 62.16910831389889, 65.15127066643008, 65.90350674044701, 69.62680878177767, 76.36948077909409, 79.94130872911023, 80.93388803543584, 82.29383653210056, 2.647261561885957, 0.5503565229235158, 0.34162008654206033, 0.12180218833588785, 2.5801149972023505, 67.95052113071566, 67.96007602445542, 51.31809480728642, 55.13412167949062, 31.153434899545488, 59.93387899091167, 9.507873346728664, 0.2888174763610286, 0.02561672188852343, 0.08031197718434757, 0.042591841756215984, 0.06252097942295574, 0.04919288049061452, 0.03047732951780481, 0.05763115894590175, 0.053640580135247404, 0.04341773050386579, 0.02506988832817203, 0.03798701364787356, 0.018320728408833666, 0.04701007765928104, 0.06649579597456802, 0.035260418625248056, 0.06585873257849487, 0.02095539288054551, 0.018649552498132955, 46.648136569607644, 73.27430709715813, 43.73885577724826, 42.385085013604936, 53.00390597312681, 77.99872352230933, 74.30026577365014, 0.49178061285807245, 0.024868769180630485, 0.8797737174937803, 2.2109697086195794, 82.115478515625, 92.70596427302208, 86.92612432664441, 86.17167211348011, 81.40001466197353, 79.32576333322834, 78.20376150069698, 71.68877524714317, 67.32513843044158, 65.0969889856154, 63.58147144317628, 64.34559229881533, 61.8384172070411, 63.314785572790335, 63.402321107925914, 62.45896754726287, 63.622801457681966, 60.00196741473291, 59.887787219016786, 58.545505077608176, 57.77758736764231, 60.045050728705625, 60.00909828370618, 58.99453409256474, 59.442868848000806, 61.508777295389486, 56.837050068763, 52.73596886665591, 50.63970519650368, 50.18041526117633, 54.02122759049939, 52.94172856115526, 59.18855805550853, 61.89221251395441, 54.99413621041083, 53.58501295889578, 50.690127265068796, 53.31512251207906, 55.46502851670789, 54.93004468179519, 53.97902288744527, 51.464905200466035, 50.80215407956032, 53.469126532154704, 56.59301980849236, 66.62376373044907, 68.22170595968923, 64.99276768776679, 62.672242503012384, 66.82324763267272, 67.72063101491621, 65.49374457328551, 68.65736361472838, 70.05516298355596, 69.43877035571684, 64.61739686227614, 67.47604770045128, 61.16229864858813, 58.40996757630379, 48.88493484066379, 51.727045043822265, 68.52365001555413, 63.86006955177554, 66.929214385248, 66.58231996720838, 60.85223136409637, 55.38263128649805, 58.45421191184752, 54.758562580231704, 58.63832012299569, 64.809032101785, 69.25055150062808, 58.89527067061394, 51.40957624681535, 47.98209151914043, 45.66218999124343, 47.22921217641523, 53.35829211819557, 64.15877765224826, 62.74154686158704, 61.139768554318344, 56.921777186855195, 59.843754691462365, 62.17673340151387, 63.55614469897363, 64.38342355912732, 64.84612595650458, 66.90247166541316, 60.614445517140055, 61.23456831901305, 59.65945036180558, 55.48986104226882, 47.93161061502273, 49.12452497789937, 47.417521246017955, 48.505021910513605, 49.9938791028915, 53.29889958904636, 52.39953148749567, 52.10091360153691, 56.15655806756789, 52.40823522690804, 49.84167545072494, 49.56493654558736, 52.812764952259684, 46.53297185897828, 48.3155910430416, 56.24946332746937, 54.17004231483706, 54.745226521645826, 54.40646709934358, 59.44460253561697, 63.001082251148844, 64.45712881703531, 67.52792496835032, 64.46047067642212, 61.460159517103634, 60.908376170742905, 57.91508213166268, 59.447183455190356, 57.11186701251615, 57.842632032209835, 58.41907924221408, 60.24418553998394, 61.79745981770178, 66.68107740340695, 64.76888272070116, 69.17103721249488, 69.05274637283819, 71.42027331936744, 77.37917730885168, 82.96132195380427, 82.35199743701567, 87.98462298608597, 4.432864689057873, 1.0320248671116368, 0.2897396930042775, 0.14557328375597156, 2.2313329385172938, 73.68775629228162, 76.01543195786016, 56.862745515761844, 38.699708369470414, 36.15663966824932, 68.80079684718963, 14.313931945831547, 0.3748248805922847, 0.0778092445445157, 0.09341826301909263, 0.04553874451366644, 0.057104825898404085, 0.07465089385908458, 0.055416789461648276, 0.0506157432532599, 0.04974168672737095, 0.16119663573561177, 0.07698623628746118, 0.20969855088380077, 0.14075557130479044, 0.12149291864085583, 0.24119115374501676, 0.21800674377910553, 0.14062850796166929, 0.22920152532958218, 0.15712307045055976, 54.300931807487245, 84.27637500147667, 45.101647992287916, 62.1989457837997, 65.86840937214514, 83.06499019745858, 85.91047363896524, 1.004494486316558, 0.1340266380218729, 2.6197351034610503, 2.3699566097028795, 82.17581241361557, 98.7665282526324, 94.24780091931744, 90.21700859069826, 86.37361926417198, 82.60795562498032, 81.55847057219475, 76.85901611082016, 72.65030507118472, 69.24237728118896, 66.26181525568809, 68.0973276015251, 66.30076439149919, 67.05586771811208, 68.78422091084143, 68.3814170283656, 69.30963808490385, 63.98158457971389, 64.96579354809177, 63.05846652676983, 61.28344105136011, 63.42087784121114, 61.84939592115341, 63.447495045200476, 62.13639182429161, 64.22887040722755, 59.71375949921147, 57.20967131276285, 54.139855753990915, 56.87419099192466, 58.141740214440134, 56.26787493305822, 62.40325812370547, 63.197138001841886, 54.43538673462407, 54.53660741929085, 51.0013634158719, 57.135585584948146, 56.786710369971495, 56.20672125970164, 55.06074197830693, 54.58802184750957, 54.39013434994606, 58.32152597365841, 61.54163106795281, 70.30174670680877, 69.80575515377906, 68.85042267460977, 66.03951884854224, 71.15942001342773, 71.84832942101264, 69.18735427241172, 72.13170497648179, 75.53189000775738, 70.08216457982218, 67.3040674578759, 69.31186599116172, 66.39715271611368, 59.084489730096635, 52.23020668952696, 54.19568284865349, 69.80872046562934, 66.555906726468, 69.80639057774698, 70.89510717699605, 61.71234438496252, 56.62348093525056, 60.00725869209536, 55.16879543181389, 60.2163367117605, 70.99445296872047, 74.98973215779951, 59.729009674441436, 51.728543389228086, 49.664439232118674, 49.049407666729344, 46.25526020603795, 56.75999118435768, 66.61451478158274, 66.41099868282195, 64.95827436447144, 59.362146469854544, 62.288273842104026, 64.79737481763287, 67.33158680700487, 65.8142335953251, 68.560818395307, 69.74288740465718, 66.34391046339466, 63.36517626239408, 63.62824962985132, 58.262682576333326, 51.826222173629276, 50.71172383523757, 51.0159428658024, 54.808176640541326, 52.803155145337506, 54.9546104861844, 54.55435222195041, 54.82350134080457, 59.140359970831106, 56.16730928421021, 51.64736601614183, 52.33606361573743, 57.16848250358336, 50.26053359431606, 52.90234404225504, 59.60811438099031, 57.310480148561545, 59.0122082925612, 59.51629169525639, 62.45453134659798, 68.74212603415214, 69.29059105534708, 72.2189227996334, 69.65228849841704, 66.059020873039, 64.92732686381187, 63.41149160938879, 63.373566212192664, 61.20903368919127, 60.915169715881355, 63.28735251580516, 63.980737347756666, 65.8858403851909, 70.37409090226697, 68.48976858200567, 73.72049239373976, 71.9100518380442, 77.5494081743302, 83.6836499552573, 87.18474972632625, 88.61482235693163, 90.32374412782731, 4.364264886225424, 1.790469440241014, 0.5768162805226542, 0.3233354064005037, 4.247743035516431, 81.66818711065477, 80.95648088762837, 69.80980303979689, 75.13573846509381, 44.19974603960591, 78.58784783271052, 15.218516799711413, 0.5764496001985766, 0.20672375486502725, 0.1782853606968157, 0.21941397068721635, 0.12874913492029713, 0.14458069427599832, 0.07943048577515349, 0.3028813184749696, 0.1261779523244308], [0.025259583189542738, 0.04239046788443962, 0.02196152871023984, 0.07472505117015493, 0.038766159540823394, 0.021692779320742817, 0.0747258862059924, 0.05803541588266531, 0.05698776383313441, 0.5595178926183332, 52.20095365278183, 52.175175836009366, 33.01355815702869, 46.13612213442403, 48.78764044853949, 71.1493787457866, 58.11348345971877, 0.27332129497681895, 0.20486661984074503, 2.138454890058887, 5.832353128540901, 91.29176155213388, 89.49875200948408, 86.61071869634813, 83.48805704424458, 75.79215495817124, 67.64001846313477, 68.27611707871961, 64.80384280604702, 65.27312301820325, 62.41753947350287, 58.67377050461308, 58.94004060376076, 58.75810930805822, 58.43881660892118, 58.16778867475448, 58.17311917581866, 59.34721400660854, 59.8184593262211, 55.560291121082926, 55.56238566675494, 55.312962147497366, 57.54848957061768, 52.87475801283314, 56.681594771723596, 53.65128140295706, 55.616632046238074, 52.77078774667556, 50.90646559192289, 47.75804573489774, 50.942786739718535, 49.53120023973527, 50.651637046567856, 54.55478760503954, 56.64643072312879, 55.763214941947695, 53.645801851826334, 50.59679054444837, 52.126020693009906, 51.686562261273785, 52.559728930073405, 51.80166029161023, 50.438711181763686, 47.75220140334099, 52.23414867155014, 52.14009415718817, 59.25594829743909, 63.02506362238238, 66.3450244165236, 61.770313093739176, 54.857884837735085, 64.69185129288705, 66.77310405238983, 67.57765277739495, 66.74972672616282, 64.98665663503832, 63.61374862732426, 66.86189082361037, 59.196755809168664, 46.90094509432393, 49.699293413469874, 56.25632747527092, 66.71210335146996, 65.65814287431779, 63.70321396858462, 58.07594245479953, 58.976769678054325, 57.33498711739817, 55.80987545751757, 58.34300095035184, 60.53926937041744, 52.20194209006525, 57.9850572155368, 56.05717697451192, 52.91650772094727, 50.5728836982481, 45.615513786192864, 39.53266289926345, 36.32101443506057, 62.271588079390995, 56.51081477442096, 62.52079979065926, 58.93363537326936, 60.45923732942151, 60.28773169363699, 62.247163480327984, 58.4721802896069, 59.976730885044226, 59.10700021251556, 55.661951111209014, 63.896802548439275, 57.4902972867412, 50.5077370520561, 48.1996379360076, 49.02290813384518, 47.14754058468727, 48.052721638833326, 50.03929230474657, 50.95914694570726, 50.18517701856552, 49.83620766670474, 51.648315229723536, 51.572491891922496, 49.88560207428471, 47.6596373896445, 47.54258209659208, 46.58131507135207, 43.82583825818954, 51.86226875551286, 49.87112852834886, 53.13538382130285, 50.11321721538421, 53.912781899975194, 57.96221333165323, 60.62353364882931, 59.52038272734612, 58.54765845883278, 55.5023028004554, 55.37841866093298, 55.28143413605229, 54.16521779952511, 50.106788450671786, 53.61126538245909, 54.0577095554721, 56.55517285869968, 55.82996583754017, 57.456957140276515, 57.16230477056196, 62.277773657152736, 65.15109023740216, 72.04146692829748, 72.11858072588521, 82.47917636748284, 75.0415466677758, 94.10874505196848, 16.528230520986742, 1.2327596376980505, 0.47602074401032546, 0.140083160611891, 1.3215033854207685, 58.14214029619771, 71.126966322622, 50.21796411083591, 46.43809364688012, 20.060162082795177, 60.604678815410985, 21.81763887405396, 0.3462659195065499, 0.057757586436045755, 0.05574233469463164, 0.03489421710612313, 0.018460378576550755, 0.07382155005489627, 0.07845785288560776, 0.03614012504957857, 0.021076348587690343, 0.013900309155184417, 0.15873128818648477, 0.03496535603077181, 0.05670942110760559, 0.01796584583878998, 0.029288525768225233, 0.10654648961198908, 0.05357131046513396, 0.08421135705805595, 1.1485452469318145, 65.42595424959737, 59.22866036815029, 42.68211433964391, 45.443255055335264, 56.87480680404171, 79.86774859889861, 60.11791659939674, 0.3069339235944133, 0.2771413158024511, 1.9221834886458613, 7.276555607395788, 97.8782839928904, 91.19589098038213, 92.25831985473634, 85.7243650190292, 80.88831793877387, 70.98834976073235, 70.33598115367275, 66.15538566343247, 67.55298106901108, 65.32610639449089, 63.59235994277462, 61.39957066505187, 61.96492148983864, 62.89786115769417, 62.312718053017896, 63.396723885690015, 62.959544351024014, 62.804649952919256, 58.86869269032633, 59.63786555874733, 56.837269721492646, 60.692481071718284, 57.11584429587088, 59.09491146764448, 57.36994328037385, 59.78977895552113, 56.034842998750754, 52.673171720197125, 52.40772924115581, 53.953429422070904, 55.703061472985056, 54.26765441894532, 58.07436173962009, 59.145000134744954, 56.20716056516094, 52.18058870684717, 51.53367611669725, 53.76700701252107, 54.416688796012636, 54.797464647600734, 53.87456624738632, 52.72974798756262, 51.031447995093565, 52.24222875410511, 54.67833834309732, 60.275050670869895, 64.79592354066911, 65.17616594991377, 66.6921777109946, 58.87615303839407, 64.56362508958387, 68.09356997090002, 68.50027268932712, 69.10052084153699, 66.13292617182579, 65.85113525390625, 70.81429066196566, 61.754607923569225, 51.912851641255045, 55.33937538823774, 55.69164737578362, 67.56240260216498, 66.33016647831087, 65.20998854790965, 60.953891354222456, 58.85724721416351, 59.80922606683547, 57.27137019557338, 58.88224055690151, 63.499552742127456, 50.28046707953177, 61.1349714955976, 58.87712186382663, 52.469181014645486, 52.57317873739427, 45.344368180921, 44.38376403624012, 42.714215017134144, 64.51296767880841, 59.89942489131805, 64.97253610241798, 61.790179898661954, 64.20625794318416, 62.462850693733465, 61.13594816577051, 59.90294717973279, 60.481077086540964, 59.14013247336111, 61.0046076005505, 67.240493682123, 59.81589409612841, 53.93830084031629, 50.9786803491654, 51.58787935010849, 50.07110272684405, 50.93106669764365, 51.64309847739435, 52.1720693188329, 51.9783866020941, 49.84134597163047, 55.664822286175145, 56.30833025901549, 53.5728967574335, 50.01731526467108, 48.13730755159932, 49.13797086285007, 45.93238246056342, 54.394652920384566, 52.24533527128158, 55.29691573112242, 51.67582281174199, 56.53069334645426, 59.47994701323971, 62.85335010097873, 60.8611822128296, 61.13489697056433, 58.37654113769532, 58.94459839790099, 56.670616057611284, 55.82967165977725, 55.03932975953626, 54.238554354636904, 55.04925727844239, 59.29056713657995, 58.35625071679392, 62.05655197943411, 59.41179975386589, 65.41506182762885, 67.51498899152203, 76.59001211966239, 72.47895240783691, 84.88526021280597, 75.59416940135341, 96.07638635943013, 21.5218254827684, 1.448500661119338, 0.26965093708807425, 0.07719052129334981, 1.2590943084609125, 64.06251876584946, 78.25119864556098, 58.52595598466935, 45.817056932756984, 26.798323354413434, 71.37139274228004, 27.727326923801055, 0.2966050359029924, 0.05391740600668615, 0.04351524200530783, 0.08857666394643246, 0.010256852443900802, 0.0965715958286197, 0.06581439907031675, 0.012833961687471359, 0.052961661525431185, 0.10400522274956589, 0.19029334457891603, 0.10071476786247185, 0.11832296938425112, 0.11312485597426854, 0.11492242000155872, 0.2630843684798287, 0.20228531722339893, 0.23322520296900506, 1.1909612676789685, 73.21801324044505, 68.6912372035365, 42.14382786904612, 58.17035782721735, 67.97471430993849, 83.67316153741653, 69.62553008910149, 0.38161664840675175, 0.6133720350842322, 4.159806928327007, 7.9147482783563685, 99.96503199300459, 95.22018001925562, 95.89450605453985, 88.22453868004584, 84.05737338527557, 75.21717471461143, 73.84976586987896, 70.57287662259995, 72.59749427918466, 72.29923725128174, 67.79200246257167, 66.26903241680515, 67.9842064457555, 67.85624304125386, 68.1347313234883, 66.2750885563512, 68.38994426112022, 69.90153943338703, 61.61136688724641, 63.92528287826046, 61.371608088093424, 65.05809084061654, 60.03475842937347, 61.89492287174348, 59.859138227278194, 63.69174888057094, 59.80094202103154, 56.61374561248287, 54.42010518043272, 57.607909556358095, 58.57442863525883, 56.87292014398883, 60.394514299208126, 61.663863889632694, 57.934537087717366, 53.77588333622102, 53.127790112649244, 57.5073988206925, 57.14497966151084, 57.21468410184307, 55.9291547344577, 57.13463244899627, 55.01024538470853, 57.40537012777021, 58.45517681490991, 63.83600581076838, 69.17067635443904, 69.58785964596656, 70.90610550295922, 66.34549510094428, 68.99953549908054, 71.46040701097058, 70.79019161962694, 73.30292470993535, 72.69818936624836, 68.40850491677561, 70.12032139685847, 64.71820177570467, 56.380035108135594, 55.126998655257694, 59.513161643858886, 69.91579332659322, 70.20031421415268, 67.02193137138121, 63.18399021702429, 63.119796706784165, 62.692866325378425, 59.82000081769882, 59.9180914509681, 63.5594787136201, 50.74833916079614, 63.08144769360943, 58.987952355415594, 53.177635592799035, 53.302468945903165, 50.04261455228252, 43.56581649472637, 44.110700391954, 66.77699504360076, 60.61814431221255, 69.29980078051167, 65.47695682894799, 66.1214885404033, 64.66193145321262, 62.820449259973344, 59.5155111435921, 64.20316711548837, 64.17671857341644, 62.085534372637355, 68.32577428510113, 62.00046993071034, 54.64670050528742, 53.94112102447018, 55.83209568454374, 53.4965007535873, 53.1774708532518, 54.70236286040276, 53.756408768315474, 54.20588101110151, 53.508840530149406, 57.79115092369818, 59.3369609309781, 56.02636675680838, 54.703166946288086, 52.07613206678822, 52.485007778290786, 49.79042576205347, 58.178998808706964, 54.02539314762239, 58.41790253116239, 54.986122808148785, 61.237361046575735, 64.15252147182342, 66.34205910467333, 65.40831927330264, 66.21952426049018, 61.70373870480446, 63.05229663848878, 60.342813537966826, 60.68965696519422, 57.65352279909196, 58.68709479608844, 59.41275288981777, 63.486040176883826, 63.19725567294706, 64.33120896739345, 62.77269048075523, 69.25280294110699, 71.6597967763101, 80.61343039235761, 77.26575020820864, 89.0383049749559, 80.7684503063079, 100.3478317876016, 21.07863295462824, 1.926938872183523, 1.4017069075376758, 0.3201993795171861, 2.886304528482499, 72.88223481947377, 84.05510625531598, 66.31095470920687, 66.34139230174404, 30.489591398546775, 81.37557045105966, 31.601171493530277, 0.6020040870193513, 0.20091141513999433, 0.09429746382539311, 0.3219305850084751, 0.13689363014794168, 0.2217522242497052, 0.12921502363056908, 0.09679541607657749, 0.2165379080801241], [0.029306613104117495, 0.01193763115518396, 0.09655926947391803, 0.030526213588253148, 0.01912134008542184, 0.15661826447373436, 0.043587487927007104, 0.047443407632771044, 0.10759597644209863, 2.2937738847348, 61.166672091330256, 54.12341317822857, 35.68906176474787, 45.317747054561494, 52.472746449132124, 83.6073677001461, 44.11914525493499, 0.47148528899396625, 0.3644391185333652, 1.476753983766802, 13.820222231649584, 91.30345021524738, 89.24175831579393, 86.3686849224952, 83.97639213069793, 81.59991433543544, 77.02282997869676, 65.74052049267677, 64.8225328999181, 60.273803357155096, 60.52711786762361, 58.10027683934858, 60.7258878984759, 58.53191014259093, 58.314097004552046, 58.36091049255864, 56.62680318278652, 56.84629901762932, 56.1477013557188, 55.914132056697724, 55.685783432376006, 56.439863020373934, 55.018317622523156, 54.27876649364349, 56.22723525570285, 56.15409874146985, 54.87976774092644, 50.096276498609974, 48.46607669707268, 49.54210835118448, 50.15210359327255, 52.46856128015826, 51.879123180143296, 55.48322831430743, 56.912700822276456, 51.198015366831136, 53.80303006018362, 51.041536331176765, 48.920597030270486, 52.19491712508663, 51.86557531356812, 48.770268271046305, 51.096767225573146, 48.74875407065115, 47.70641557631954, 50.365653114934126, 56.73436241765177, 63.178789154175796, 63.241311734722515, 65.3685111384238, 57.392041913924686, 55.6604370763225, 60.75770224294355, 64.64873267758277, 63.19922078040339, 60.38816005952897, 62.4612739009242, 64.26377165702083, 62.74005636092156, 54.793271633886526, 49.06693673902943, 54.191823236403934, 57.35261424895256, 60.97863366526943, 62.31500871719853, 55.498588315902225, 61.47599412548927, 57.536898966758486, 60.79945979579803, 58.226314360095614, 62.122032027090754, 50.970294321736986, 52.386332711865826, 53.119054994275494, 54.49004104060512, 52.01116977199432, 43.12620509055353, 40.40941853677073, 36.406114178319136, 55.81382920665126, 62.22311935117168, 62.444148832751864, 55.61823237326838, 62.684821544155, 58.84417787674935, 57.733437168982725, 54.42929921611663, 52.703170007275, 54.404011695615715, 63.19885992234754, 63.291753415138494, 57.86626823486821, 48.34815848258234, 50.09082440407046, 44.43310353063768, 48.01497274829496, 47.88487557441958, 48.977424329327, 46.64492807080669, 48.65340909650249, 48.9899916033591, 49.84003589999292, 52.68998692112585, 48.459773448205766, 48.53284328214584, 47.32904826441119, 48.566618811699655, 42.04004195428664, 45.589532006171446, 52.36910958443919, 53.30011944616995, 50.09220115600094, 54.01808184962119, 50.876785016828975, 54.98587569882793, 57.52806186676026, 57.172420563236365, 54.76096307077716, 55.193408304645175, 52.47701006550943, 52.14795850938367, 50.284840522273896, 55.40411410793182, 54.21541237062024, 57.89594488759195, 59.15857545791134, 62.8559898561047, 60.221514240387954, 68.4993548547068, 66.62363821460356, 72.82510157554381, 68.28593869363108, 83.6078776082685, 73.41199797968711, 92.98145586444487, 36.21174112443001, 0.33244753196354837, 0.12011814321721755, 0.037861497802359444, 0.10263502087083556, 45.604739035329516, 77.73068443421396, 55.1930788255507, 41.52113199234009, 19.983732738802512, 53.41111859967632, 31.392322932520223, 0.13437940618924557, 0.05263216710919815, 0.07017507112675136, 0.06111782044172288, 0.0422042970275206, 0.0383558122050618, 0.05716874061392681, 0.016729301404989055, 0.07735937473274047, 0.03178041826392854, 0.023673806084139694, 0.0409748446526787, 0.025015526729065086, 0.034323745902868054, 0.09900299036094258, 0.13062897679065505, 0.17168033447477127, 0.33190501913908993, 4.297943490166818, 71.31466742484801, 61.98773399476082, 34.84877240273261, 44.0395603641387, 61.90605063592235, 90.40208954964915, 45.446334115920536, 0.39434909099532717, 0.25466170672687793, 2.5418302128391885, 15.800912284081983, 95.65542190305649, 89.20718654509514, 87.41596560324393, 86.20112126873386, 84.40871577109061, 81.67524737696495, 69.29483505987352, 67.96440632112565, 64.27180859350389, 65.04348001172467, 61.87474227720692, 65.7300477643167, 60.64966447891728, 61.67394830334572, 62.210493241586995, 61.71059500786566, 60.358612845020915, 57.97853823631041, 59.66751475487987, 58.75057051258703, 58.31594444090321, 58.35202632411834, 56.65825274682815, 60.027753076245716, 59.6566850908341, 58.85155977741365, 52.99805379682972, 52.58362400916315, 52.12731507516677, 53.039328898153, 55.4718416736972, 55.023773639432854, 58.553565548312285, 59.97515801460513, 51.358291256812315, 54.16860280498382, 52.10071356065812, 51.06805547591179, 52.64461294297249, 56.20701543746456, 53.27215686921151, 52.98337236527474, 51.709257095090805, 51.789697062584665, 54.04063155574184, 58.19025993347169, 64.22948621934461, 66.4085275896134, 65.7588928745639, 62.44258772942328, 59.89355310317009, 64.21183163119902, 67.48524173613518, 64.01460701419462, 64.09095202722858, 65.68153196765532, 67.82381288466915, 66.95146991360572, 55.41354348582607, 55.626383058486454, 56.8711668445218, 59.71797604714671, 63.37045969501619, 62.24904229564052, 56.184442197122884, 63.43214288834603, 60.9590139696675, 63.748795832357104, 62.28835228950747, 61.86013929305538, 52.90792557501024, 54.85992447022469, 56.122288319372366, 54.22613613067135, 50.91519678792646, 44.9833728421119, 44.14887289847098, 43.506278837880785, 57.065151583763864, 63.921607617409, 62.36379907977197, 59.96865472485943, 62.78497926650509, 59.67683822877946, 57.40367566385577, 56.77945790752288, 53.48365106890279, 57.56935265756423, 65.83613611036732, 63.60050670562252, 59.547396090722856, 50.46045287962883, 51.34500618903868, 48.16862767742526, 49.115691800271314, 52.474225182687086, 51.68935891120665, 48.9836452084203, 48.421730379904474, 50.168938406052135, 50.363535035041075, 55.11625920572589, 52.60199246868011, 51.43462842510593, 49.0413668078761, 51.043270018792924, 45.49328880925333, 50.09274636545489, 55.57522358432893, 54.443647246206964, 53.50771873228012, 55.058094378440614, 54.435453414917, 58.01088210075133, 59.52952577221779, 59.086521517845895, 56.62191198718164, 56.19357347488404, 54.40354885593538, 54.5760311618928, 52.58667953552739, 59.46859175159086, 56.52631598134195, 60.33748303690265, 62.35307924209103, 67.5437399648851, 63.34541143909578, 72.65988349914551, 68.6004186445667, 75.18512110556327, 70.42789013155046, 86.25604229588663, 74.80301949285692, 95.14906744803153, 41.13135430120653, 0.3365232422947884, 0.014781574568440838, 0.039707700751962206, 0.2679193638745816, 48.227651503778276, 82.64513184947353, 66.22292887779975, 41.07144401919457, 25.559256422904234, 64.89640289737333, 41.58371733080956, 0.181671867687856, 0.06076671085470627, 0.06925905213480996, 0.0537517394930605, 0.024246219320282824, 0.00863460093481286, 0.041985260998649944, 0.03981935806692608, 0.014428049889242938, 0.10812017976516679, 0.1849840947937581, 0.14603845234359467, 0.19219345713575042, 0.14307332435442557, 0.2658337354660034, 0.22837376732739711, 0.2168013197520087, 0.46557685119971154, 4.776288790087547, 87.28087132976901, 67.28109805814682, 45.03809382838588, 61.98889893870201, 70.3833241616526, 97.8699371891637, 52.555932075746604, 0.5592865953522345, 0.9830743615185061, 3.2319854632500684, 21.62235583028486, 98.0861774567635, 95.61006361438383, 92.38343561849287, 92.09384702867078, 88.55012678330945, 84.71590795824605, 72.86625508339175, 71.77009382555562, 66.95039518417852, 70.14296916223341, 64.01345775973412, 69.57051492506459, 65.37697561325567, 65.87572851488667, 67.3845152701101, 67.21991692819904, 62.14549564546155, 61.62531483557917, 62.20364086089596, 61.89546023645709, 64.29935539922407, 62.45295063141854, 57.897741333130874, 63.91894040569183, 62.93517466514342, 63.13059499186855, 56.31274292545935, 54.54801367175195, 55.9439459923775, 56.940996800699544, 60.37657337803995, 56.47779233994023, 63.28773298571187, 60.94110050509053, 51.90349678839407, 56.71518987224948, 52.76800678622339, 51.64436540296001, 55.61251355755714, 56.760912941348174, 55.77968889667142, 55.90956641781715, 55.91395555003997, 54.50946069532826, 55.69242400507773, 63.186100452176994, 67.1538406802762, 69.49467982015302, 68.07966124626898, 65.18553649225544, 63.99034323230867, 64.36209371013027, 70.2735762442312, 64.91130790402813, 67.0337220161192, 66.65260884069627, 71.36752528529014, 69.48404235224571, 61.85139240757112, 56.5043193294156, 57.97164663191765, 63.585452648901175, 67.532561209894, 66.30768345248315, 58.129827976226814, 65.23077318745275, 62.24110734078192, 68.36749261425388, 61.99545714163012, 64.49059055697533, 53.13742737616263, 55.2482077383226, 56.79702228115451, 56.5266768393978, 52.56163127960698, 48.709671574254195, 44.72343344842234, 46.43661099095499, 60.47144766776793, 64.42689126537692, 68.32252656259845, 63.04974709787677, 65.67856665580504, 61.82364948334233, 61.03323698043824, 57.56386133932299, 57.50294693054692, 62.27196854929771, 66.90656661987305, 68.4985468464513, 63.553614770212484, 52.73905577198152, 54.553379474147675, 50.12077954507644, 52.64336955162787, 55.241202385194846, 51.563941124946844, 49.87870262515161, 49.25919563539567, 51.79400382503387, 52.09019376385597, 59.017401510669345, 54.817253005120065, 54.642695765341486, 52.07721856332595, 54.55009252794328, 48.90423682428176, 52.06793823549825, 57.40489159860919, 57.31992129356631, 56.29590419030959, 58.33508560734411, 57.68454874715498, 60.686134676779474, 65.63416542545443, 64.44315341211134, 61.39886856079102, 60.24295391574983, 58.45763221863778, 58.64237193138369, 57.58874485569616, 62.56338888599027, 62.4434781074524, 63.42694182549754, 66.33841914515342, 71.38528577743038, 66.49990312514767, 77.91295697612148, 71.0888095055857, 79.37616578994259, 75.56679910229099, 92.91122190413937, 80.21302700042725, 100.0374860148276, 41.94763483539705, 1.015788828653674, 0.5639198951182828, 0.16011974594045073, 0.6729350034748355, 57.27577501727689, 90.74423005503994, 72.69497302270705, 56.679311952283314, 30.31170210530681, 71.5459539044288, 48.19501738394461, 0.2601479841095786, 0.14834449956974677, 0.2033429322463851, 0.2949015015075284, 0.13708542792066453, 0.22834696957180578, 0.11270490955681571, 0.17691982429354422, 0.208991865417169], [0.04854771954518172, 0.034037696332820964, 0.05122605485901718, 0.025996396979016644, 0.08346603011652347, 0.03140095384761451, 0.11762425123203187, 0.09237942481113058, 0.28754727193905466, 4.559323374302157, 61.10924074726721, 40.00964272406794, 40.9585895845967, 44.05011938464257, 50.7583608165864, 88.03704938580914, 30.297630602313628, 1.4687321238940763, 1.3556512949928161, 1.6049810450884605, 10.323779294567725, 93.444883900304, 86.1826390604819, 88.55983072711577, 87.53904173451086, 84.63004727517405, 84.79121746555452, 68.55353063152683, 59.94561864483742, 62.40603908415764, 58.02692851712627, 59.59851634117865, 59.59148353145969, 60.14932301736648, 58.63560192046627, 55.849252131677446, 55.036737072852354, 55.03809421293197, 56.66852935667961, 55.26308921075637, 55.92922141475063, 58.36859049335603, 55.32766711327338, 56.13413387729276, 53.73926016592211, 55.92556184337985, 54.147037613776426, 48.26878932214553, 51.38075859315934, 49.13270704207882, 48.417431462195616, 51.261185138456284, 52.59439091528616, 55.69872725394465, 56.336335982045824, 54.0182230549474, 53.128394157655784, 50.180846721895286, 51.81150936311292, 52.315482939443285, 53.216533737797896, 48.88380127568399, 48.438004293749415, 48.65804926041634, 49.55505217275312, 51.603427625471554, 50.421389995082734, 55.48005511683803, 59.24011761142362, 64.008629322052, 62.04337281565513, 58.220944635329715, 62.92490590003229, 62.440387279756614, 66.26338420375701, 58.87868688952539, 62.931173847567656, 59.76859815659062, 62.80476370165425, 51.6521316959012, 49.8645350240892, 67.14238735937303, 51.72242449175928, 57.414936788620494, 59.953683037911695, 55.413461116052446, 62.257824482456336, 59.39798908848917, 59.19469264245803, 59.31325020328645, 54.79269112310102, 51.862402116098714, 50.2107822510504, 53.54894284279116, 57.75967390306535, 50.33541556327574, 48.794747783291726, 40.03389866121354, 35.83412278083063, 59.0476155281067, 63.53272814904491, 53.92110516948085, 55.409377928703066, 60.662902478248846, 60.7248249361592, 61.937292314344845, 62.431632549532004, 56.93238327580114, 61.859582316490915, 63.315248412470666, 62.32224549016645, 52.78318243642008, 45.24723852834394, 48.292511816947695, 45.195706429020056, 46.3892013026822, 46.7121418060795, 47.207650907578014, 47.76006183316631, 44.52576952595865, 46.04131060261881, 46.49807060918501, 51.83620460571782, 52.04436086839246, 49.607674690984915, 47.36652651140767, 49.047689668593875, 42.90965495571014, 45.93102139811362, 53.184032978550086, 49.364750539102864, 53.33864888837261, 53.51781491310366, 50.57127944884762, 50.87567106370003, 53.35833134189729, 52.15734081883585, 50.51331074007096, 54.0066755971601, 48.536522465367476, 53.976975410215324, 52.213026708172215, 53.624546527862556, 58.070443291817945, 62.075532328697946, 62.67146195134809, 64.32237971213557, 61.814243639669115, 64.60482958824404, 68.86235452467396, 72.44281953380954, 69.81430592075472, 78.57404108970397, 70.70379749421151, 89.53099389230051, 58.495694898789935, 0.10935094598079882, 0.06025639670570532, 0.04970991706115104, 0.36856836308875396, 31.32158494764759, 78.09894008021202, 55.20649725391019, 56.38674628350043, 24.7560981781252, 42.22682522189233, 51.832109651257916, 0.6705291196703912, 0.11663219801360562, 0.11143072147763546, 0.08311071087636294, 0.02607387528123875, 0.010481571887559708, 0.019037122124685876, 0.019044129913973234, 0.0360774897008894, 0.015635902415059747, 0.053262657470880985, 0.041648473425377766, 0.0989727988358467, 0.06978254299610853, 0.05586296672962847, 0.10304821805367548, 0.12355670588271273, 0.21536099784556897, 6.624453231211632, 74.47787069505262, 45.97865466148623, 45.00393390655518, 45.65554549617153, 60.104831572501894, 93.387954619623, 31.533953835887296, 1.6122059283717987, 2.0768874066491283, 2.6667954556403624, 13.784348234053581, 99.51302589908724, 87.82869308225571, 93.85622286027478, 88.57244506958993, 88.02805931337419, 88.71626269432807, 72.26329265102264, 62.939395135448834, 66.57898595256191, 59.1976579543083, 63.253082767609634, 62.334930435303725, 63.72982725020378, 60.96249703438052, 60.02833750940139, 58.31551690255442, 59.150110983079486, 60.20689164438556, 59.25599928825133, 58.37511339495259, 60.13037796943419, 57.79146471331197, 58.793355726426654, 56.395932474443995, 60.43103941025273, 58.528305484402566, 51.763899633961344, 54.65420399942706, 51.279988981062374, 51.49481327302995, 54.08981807770268, 52.78198219114735, 57.14659960039201, 55.92303975935906, 53.68206808643957, 54.07015915839903, 49.72052128084245, 51.70348336619716, 54.370389138498616, 54.86019119139641, 51.836279130751095, 50.62216435709308, 51.19009610145323, 52.95178159590691, 52.81780127556094, 52.414569854736335, 56.61903296747516, 60.858777799913966, 67.02985455912929, 64.56597851168725, 64.23909994863695, 65.13986049159881, 65.85301014684862, 68.88908155502813, 59.539747468886844, 67.01117623236873, 61.812407970428474, 66.13782913454118, 57.52417872028967, 53.50634198034964, 65.28343885175644, 54.25705225236955, 58.59227541954287, 60.08791438994869, 54.66470810674853, 63.86725141156105, 61.75150140639275, 61.625479575126406, 59.31907884536251, 52.65228509902955, 51.18868012582102, 48.933305509628795, 53.24968168812414, 56.25096167287519, 50.421405684563425, 48.78762083668863, 44.329709852895434, 43.37776237918485, 59.154927653651086, 63.71615386778309, 57.670251707876886, 58.76958224081225, 62.998065948486335, 60.345900443292436, 64.65853860301357, 62.37162813063591, 59.82387611942907, 64.93205724223968, 64.75288729513845, 61.926792129393554, 55.420752802202784, 48.14618779766945, 50.26214176608671, 47.44453068702452, 49.33080634763164, 51.47056910299486, 46.698939108079486, 47.85896047469109, 45.615545165154245, 46.70108856693391, 48.580382408634314, 54.22763839844735, 54.68304910967427, 53.06869960600331, 49.856058782146825, 51.12070152836462, 45.50494609340545, 48.68892223604264, 55.73609175220613, 52.25095602773851, 54.88275658699774, 54.50873897921655, 52.42103784315048, 54.380728506272845, 56.386789429572325, 54.95812885222897, 53.140659409184615, 56.024056480776885, 52.864897174219934, 56.66375190980973, 55.366698618858095, 59.49091003787134, 61.660725993494836, 64.04599774268367, 66.57362799490652, 66.22802795902376, 63.32503864842077, 65.03234832517563, 69.87468688718735, 74.6704355362923, 73.18076641328874, 82.05080647622385, 73.27097308251166, 91.99536415838426, 63.12903781091014, 0.2228528474487605, 0.5247602996326263, 0.08803347696460063, 0.4935834322485232, 33.23380708694458, 82.08754339525777, 65.26368187319848, 55.35564145734234, 30.573439905720374, 55.55014394944715, 61.57720304304554, 1.7164671853665383, 0.05954036113595771, 0.06392401199968112, 0.08215084867251497, 0.02723799950833763, 0.10698357341630806, 0.04462054217114084, 0.13377549907853528, 0.029169784055181572, 0.13016314936741707, 0.27663468653636597, 0.228102924602647, 0.23585141366047246, 0.22708906852189573, 0.18231289941937695, 0.3353100961014148, 0.2413313171916431, 0.43303426355123525, 7.553096923135943, 84.77067209059193, 51.87684820544336, 53.509593625222486, 62.75720104094475, 66.33878784794962, 101.89346528822377, 37.137600914124526, 1.7930613914805076, 2.0896755591515572, 3.0129375140513144, 25.19950447543975, 100.00620119033321, 89.6546583790933, 96.32308775378813, 94.15065165488951, 92.14788944490495, 94.14737255342546, 73.52693911521666, 66.82205523214033, 69.9413122669343, 66.06692052656605, 67.83186943300309, 67.19113457587459, 67.337690014993, 67.2194697779994, 63.510017625747196, 62.94126218365085, 62.42432909627115, 64.10256224293863, 63.01518317191832, 63.36598034827941, 65.58991324517035, 60.969722040237926, 62.686378725113414, 58.784102855190156, 63.17552181982226, 60.82454335304999, 54.54058470264558, 58.07280063629151, 54.89338621016472, 54.35784932105772, 57.036734011865434, 56.030846103545166, 62.26117026421332, 60.2857038282579, 54.397935944218794, 53.94803616308398, 50.785829174903135, 54.24854855383597, 56.83900733147898, 56.26689826288531, 54.282928128396314, 53.238820645116995, 54.19696938607001, 56.91169669551235, 59.01667587218746, 57.21244835084485, 61.15608953660535, 65.35770893096924, 71.73674583435059, 66.12782709060177, 67.10746257535874, 67.47313730178341, 68.0974688068513, 73.65914652424475, 64.34053244129305, 69.30595105694186, 64.32001844529184, 69.4106940300234, 62.238267544777166, 54.23792285303916, 61.934958504092315, 55.420038930831424, 60.93067484517252, 62.02608693030573, 58.182772128812736, 66.44489580585112, 63.18375487481395, 64.31610391985986, 60.59370794603902, 56.090093504997995, 52.6982121313772, 52.210567382074174, 54.718001350279785, 59.010345166729344, 52.62613073472054, 50.17626539353402, 50.54059082461942, 48.926998338391705, 61.63902351933142, 66.24527069830125, 61.45046734040784, 59.91790317719983, 66.42251476164788, 63.314197217264486, 68.46948208347445, 68.11573136237361, 63.44244695478871, 67.52035479391775, 68.70897416145571, 65.3915629079265, 58.77798395772135, 49.52692485624745, 53.43496268795383, 50.283075455696356, 51.26673136987994, 51.83270192915394, 48.54443388600504, 51.4920989928707, 49.2453771252786, 45.82869068268807, 48.366248453817065, 56.51551769625757, 57.31611267212899, 55.499568908445305, 53.017908834641986, 53.74214703036893, 49.03258462106028, 51.99980666560512, 57.92919874191285, 54.881164104707786, 59.5439757839326, 57.14005708694459, 56.675428805812714, 56.483883780817834, 59.93029786694435, 59.994848312870154, 57.701575756073005, 59.36987746146418, 56.644955911943995, 62.37642911172683, 58.90491970123784, 60.13663022748886, 63.564162023605846, 66.87435611601799, 71.68408409241708, 70.46731779652258, 67.56427749510735, 69.88581072899603, 76.85543106448266, 79.42552489619102, 76.05307102203369, 83.88752691207394, 80.91957138430688, 96.61386874414261, 65.84645194392051, 0.28133506496106425, 0.5811984873106403, 0.2080626160867753, 0.7581456762648399, 41.22813486283825, 90.42552178905856, 72.26418695142193, 76.24991909150155, 36.54505629693308, 58.02262175467707, 73.87786572979343, 1.7266223243167325, 0.15527837669416783, 0.2066768396405443, 0.25072255922902015, 0.1212023491520555, 0.23326441134896972, 0.10092019433936766, 0.20143342745159903, 0.1642143173563865], [0.010547609624242591, 0.1330288085004976, 0.05625634904830687, 0.10989712836641459, 0.04284667324334864, 0.06386044585416395, 0.0994317927548001, 0.1725573059652121, 0.3739478324930514, 10.575769024510539, 66.652875561868, 39.665242933457904, 34.2148232460022, 38.909131557710715, 61.031942598281375, 89.00498836271225, 18.868057689359112, 1.052091222616934, 0.8265174913310236, 3.188251526125016, 11.152522179388232, 92.71014551962577, 87.18370637586041, 78.5929939823766, 84.28978166272564, 85.55535793304445, 85.40491934745543, 73.2914400100708, 63.35383276785574, 64.76812962562808, 63.74489307403565, 61.70840632530951, 59.50188875198365, 57.44526455479284, 56.43305770812496, 55.10025201305267, 55.263136279198434, 55.28528982593168, 55.94360474617251, 53.6705873089452, 54.646355336712254, 54.30323816114857, 53.750058451006495, 54.52508741809476, 54.20058973373906, 55.81810066776892, 53.014292409343106, 50.7659702147207, 49.309519644706484, 48.79537928488947, 50.91807188526277, 49.44275079234954, 50.552424615429295, 52.01547653444352, 54.06864120114235, 50.29812166767736, 54.63909895189347, 54.389130223181944, 52.78727739087997, 52.14274175705449, 49.85951831263881, 53.84513278161326, 54.71004678357033, 48.928300565288914, 48.392987251281745, 47.78213693249611, 48.520872208379934, 50.89875813453428, 54.67704788331063, 58.76911940113191, 61.71058324075515, 63.26838785602201, 61.03487260880009, 66.0285597462808, 64.38430217004591, 60.92220252560031, 59.18867964898387, 62.40340717377202, 57.71561391891972, 58.67171910501296, 59.23728958252938, 64.45902724419871, 56.82636553241361, 56.13447904586793, 59.182913764830566, 47.29192303073022, 50.34551958883963, 48.67363675948113, 50.851470039736846, 49.80921783754903, 47.535062912971746, 47.7400577452875, 45.72222971147107, 50.24937052880564, 65.26188935002973, 52.13588545399328, 57.769075824368386, 38.38462829589844, 48.49248209307271, 50.31801592919135, 47.42434224774761, 56.055882592355054, 56.191192596189445, 61.572174564484634, 61.071884093746064, 63.304924734177135, 56.16366540232013, 60.98285413557484, 59.26584443738384, 62.24674378671954, 55.33561383524249, 49.915196357234834, 46.08403698090584, 48.6372842327241, 45.39880675654258, 51.01266768670852, 48.96870490043394, 45.137859313718735, 44.37442879523001, 46.85266071750272, 44.93874411429129, 47.448347153202185, 51.6583800315857, 52.6499826677384, 46.70079046680082, 46.57338403886365, 45.92052513553251, 43.887894076685754, 42.5480830284857, 51.505764530551055, 51.33102293937437, 52.163142004320704, 51.4228024790364, 49.88995590517598, 51.758941758063536, 50.920413540255645, 50.59368794964206, 51.42366932284448, 52.65485032912224, 51.5538174875321, 54.91652819418139, 60.484105156313994, 65.6432927808454, 63.66976791812528, 66.49660048946258, 61.46701974253501, 61.02594921665808, 59.758552966579316, 61.94577247865739, 62.349462816792155, 68.32633910640594, 67.78167093953779, 78.31251313609462, 75.95912241166639, 86.44281771875198, 67.06647380705803, 0.1915829769906498, 0.13941022897920302, 0.12484358037791907, 0.32099316918080856, 20.93428973228701, 78.08897725997433, 57.73363720986151, 54.086695871045514, 32.906116593268614, 25.789436794096424, 58.766185468243016, 1.9941158352359651, 0.2705756971432317, 0.1454221499302695, 0.04244343520352437, 0.08595964631005641, 0.04497952714201905, 0.039550219887807485, 0.09130219793728284, 0.0500375728663658, 0.019876225889029524, 0.04422105413170592, 0.03590886991831564, 0.1114322689752425, 0.07757040897324201, 0.1624908646748912, 0.05885665830705435, 0.2042280089470648, 0.5511786884838535, 16.858409758537046, 76.52625791488155, 51.73415630094467, 36.482176780700684, 43.27316845616987, 70.7336388864825, 91.89954849981493, 20.800617317999563, 1.4562685475234063, 1.2106374699261881, 5.864395460774822, 15.114587718440642, 98.90233639747866, 89.20779843484202, 83.30150911884924, 84.25821442757884, 87.81828311181839, 84.2565199636644, 76.38531146510955, 66.00405277744417, 69.14671067268618, 65.99953420700567, 63.110892926493, 62.987977612403135, 62.16595472828035, 59.28919822938981, 59.89182726029427, 58.959656376992505, 57.474698020565896, 58.70330202964045, 57.746322154998786, 58.42120516684748, 58.7112997424218, 56.712240249879905, 57.72009326565651, 58.24220780403384, 58.42317811904415, 54.795679969172326, 55.65549488990538, 54.094109150671194, 52.045168876647956, 51.9079839798712, 53.267151924871634, 52.917166679136216, 54.521376855911754, 56.57358446428853, 51.714336564463956, 55.42218838968585, 53.95116621448148, 56.98755925701511, 53.01036219443045, 51.81450213155439, 56.44543278601862, 57.831135565234774, 52.05668495547388, 54.068421548412694, 51.385406601813536, 50.519194295329434, 53.102843838353316, 56.025699953879084, 59.1708799331419, 65.23864146201842, 64.88056436661752, 64.91970177619689, 70.77774201670002, 67.40232283069243, 62.94893826207807, 60.94859615448983, 64.76067712230068, 61.78162128694596, 64.58887338638306, 60.168028800718254, 65.44266354653143, 56.158162316968365, 60.42944692796277, 60.27953786234702, 49.34598592019851, 49.0260930984251, 49.02372398684102, 53.589355022676536, 49.71206465075093, 49.005653627457164, 49.36702159143264, 48.88114583107733, 50.28280481215447, 65.91961199237456, 53.61610558725173, 59.136441523028964, 41.418393350416615, 55.58877929564446, 52.68979864735758, 48.788895606994636, 58.59804914843652, 59.701627608268495, 63.120902815172755, 65.57307843239077, 65.14974486443305, 59.269080392776004, 63.32274013949979, 60.6755756562756, 61.450530098330596, 57.2088711492477, 49.82087119933098, 49.366099834442146, 50.6279694649481, 49.41427046252836, 52.567436387462, 49.9066299007785, 45.27777025776525, 46.461490584957986, 46.32109718938028, 46.431307946482015, 48.81208465945337, 53.75084684741113, 54.781704564248365, 49.768127087623846, 48.27602609511345, 50.37541589429302, 46.60726547241212, 43.30966611062327, 53.38919255041307, 52.83585594546411, 52.884862038397024, 53.4443175408148, 52.66037694869503, 55.975117068136896, 52.91685681189261, 52.70295427691553, 52.097854152802505, 55.52607236369964, 55.18264924326251, 58.19002851363152, 63.13421926190777, 68.2626162805865, 66.98237819056358, 69.16735802927326, 65.16193166855844, 63.51287703360281, 63.542110458497085, 63.466145915369836, 65.26907905455559, 69.59808918737596, 69.50242257887318, 82.23889981546711, 77.26582081087174, 89.0748457754812, 68.24338097726145, 0.6651174745732739, 0.30940569096034576, 0.11027458754758682, 0.36208572707349257, 23.837714425979122, 85.8067975505706, 66.5014720732166, 58.537668182003884, 34.458606396951986, 34.24009507702243, 70.93173426966514, 5.3497677464638995, 0.4898244226651807, 0.30670048128212657, 0.09205914643262664, 0.13031092772801078, 0.0647798203112137, 0.08272345343063917, 0.10752792485178479, 0.050564311940463326, 0.14371262472723761, 0.26532257095940653, 0.11690530069773236, 0.17864079485016485, 0.18121849685426683, 0.22015307699480366, 0.26927285737568335, 0.33899130179516734, 0.7736531957503289, 17.526375670586866, 89.91144026479414, 52.84166889805948, 42.57132307175667, 56.63875072233139, 75.88207921674176, 102.33910929772162, 22.993700773485248, 1.3930664163443351, 1.3527992415812709, 9.459220267111256, 26.327225123682332, 100.90125468469436, 94.23830878350043, 86.02805845199093, 88.3357535639117, 90.72606948114212, 90.68065627928704, 80.60020416013657, 68.57748062379899, 73.98300878463253, 70.01093433749291, 67.12075156550254, 66.42772366923671, 65.93047695775186, 63.21504754404869, 63.69023484568443, 64.23846844703921, 63.51028042454874, 63.32900416466498, 61.39639746758246, 62.930448209085775, 60.14250593800699, 60.746515643212106, 60.44168864527057, 60.5288476328696, 62.13463852482458, 57.62406972146804, 58.231554646645826, 57.8205059420678, 55.71567581545923, 56.26114022347235, 57.34403994775588, 56.31025614277009, 58.06987847051313, 59.031019979907626, 51.689860974588704, 57.45294063322006, 56.10327659114715, 56.748482950272106, 55.52634300724153, 54.46311789174234, 57.524347382207075, 61.45847682029971, 56.1033824951418, 56.025766634172015, 55.27852373738443, 52.81546354293824, 55.95214374603764, 59.601520876730646, 63.3848391040679, 69.19956068838798, 69.99751198676326, 67.35570938356462, 71.3760603627851, 69.46907458766815, 64.73358923389067, 64.38933849334717, 67.50730114598429, 67.1425756331413, 65.9645466650686, 66.32046253450456, 64.88244710430023, 54.95077833052605, 62.16152244998563, 61.204201329138975, 49.089125587094216, 50.614927584125155, 51.9723500743989, 58.449379551795225, 53.33909603857225, 51.130570211718165, 50.48197492476433, 48.4746313864185, 53.261464488121774, 68.89135652972807, 52.92502318659137, 58.56388138186548, 51.84411602635538, 53.369196307274606, 57.93976952952724, 51.688860770194765, 58.48347671570317, 61.81980163820329, 65.77661022063225, 66.42711962423017, 68.35480766911661, 61.980811011406686, 66.2460002591533, 63.00356903383809, 66.47873801569786, 60.96985540082378, 54.06441680846676, 50.01204752152967, 53.451048328030495, 51.39274927877611, 55.80811039094002, 50.614182333792414, 47.45149681645055, 47.76528643023583, 47.19683693301293, 48.21020872362199, 49.29132376947711, 54.51594829559327, 59.38740261139409, 51.69266546926191, 50.28501310656148, 54.63461176041634, 48.74986410140992, 47.585179036663426, 56.57559271781676, 54.59706291075676, 55.75424448136361, 56.57187038852323, 55.61111327140562, 57.283133383720156, 55.815358931018466, 57.25073068372665, 57.58684642853276, 59.42937981697821, 59.82964984832272, 60.746499953731416, 65.7980263617731, 72.47119395963608, 69.06964394354051, 73.27582113204464, 67.22643590742543, 66.05568685839253, 65.56924627673241, 68.20451028885381, 68.3851432800293, 73.2581312425675, 74.64861931339388, 86.78364030776486, 85.2930219711796, 92.75510372654085, 73.85134266268823, 1.0616327557832965, 0.5411700255447819, 0.3665450023066613, 0.7900654957179101, 28.160413465192242, 93.1453795586863, 72.61582743737006, 73.62358631626253, 45.9857855304595, 37.20129236098259, 86.97873900013586, 6.078810845651935, 0.5142810748469445, 0.4925496119164652, 0.18347038166417232, 0.2828360763528655, 0.1805666019959796, 0.17483107024623504, 0.2633663194794809, 0.14825134327815426], [0.03992516247014846, 0.03508394644145043, 0.0482510673182626, 0.03352752774052563, 0.01029892695031219, 0.06007347023114563, 0.023566923412163893, 0.15726317261015216, 0.4110639344059652, 22.074722782258068, 72.10853161350374, 24.661108178477136, 49.81386584620322, 53.758777879899554, 63.50951948473531, 88.37545579479587, 11.585773460326656, 0.7108338633852621, 1.2940639545840602, 6.251487308932889, 7.06601111158248, 86.02990196597192, 84.22306214609455, 85.10976883672899, 85.36555444040607, 85.4423152246783, 83.7568727616341, 73.02684476298671, 64.45755243301392, 59.65368055528211, 64.1575538727545, 61.22214225030715, 56.006833353350245, 55.427475744678134, 54.96265526740782, 54.196137843593476, 52.00161095588438, 54.047805570787006, 54.63802030009609, 54.38371735234415, 54.45583012796218, 53.94279195416359, 54.890326761430316, 54.08658212231052, 54.297119263679754, 56.695005355342744, 54.115395853596354, 51.309242017807506, 48.88204013147662, 47.88368317388719, 49.9949695217994, 47.03586678351126, 50.47652283022481, 52.39422059828236, 55.92780936148859, 51.25552515829764, 55.17694611703196, 54.83377402828586, 53.46731439713509, 55.459388148400095, 51.64742092932425, 52.72620216492684, 54.19491798646989, 51.71208512398505, 51.436216985025716, 48.662732570402085, 48.49068172516362, 49.151828596668864, 52.157470257051536, 52.18131826769922, 54.23192947141586, 60.090530610853634, 62.61108098491546, 62.8598730025753, 59.92076258505545, 60.26209508219073, 57.203956419421786, 63.32335595161685, 59.926889327264604, 66.70968717144382, 57.54416319631762, 52.75388625360305, 63.720233132762296, 54.83502134200066, 52.949490931726274, 49.251417575343964, 52.11234731058921, 45.786819381098596, 46.67437722606044, 43.32871706255021, 46.45147677390806, 50.621717206893436, 45.176008286014685, 51.01162433624268, 55.83501785032211, 61.75194071185205, 54.37799069189257, 42.716293873325476, 54.917395037989465, 39.52815217356528, 51.998661333514804, 57.23468818972188, 57.57420462946738, 59.988839241766165, 63.31472281486758, 59.774332661782545, 57.61369505236226, 56.36789537245228, 57.86316956243208, 54.08731952790291, 52.90961219418434, 46.49279109893307, 48.30930348365538, 45.18511210718463, 48.581786617156006, 49.71447690840691, 47.713899458608324, 45.092148011730565, 47.26514108719365, 45.33296192845991, 46.018415727923, 50.90268834944695, 53.437108224438084, 50.30176162719727, 50.06128503430275, 47.42190253350043, 44.57009230890582, 46.21636598340927, 41.4577974811677, 47.777245736891224, 52.48723568454866, 50.319196562613214, 50.88428851096861, 49.2790271389869, 52.29650651254962, 51.559516691392474, 51.2019455817438, 51.517304143598004, 52.74174651791973, 54.112438386486424, 60.351481976047644, 64.66190399662142, 65.630399950089, 67.69169176778486, 67.89969505802279, 65.02250317604312, 66.09003113162133, 61.823033671225275, 60.59503370715726, 58.18756134279313, 62.276114494569846, 67.57245171454646, 77.52776453571936, 72.63044218863212, 86.96094712903424, 64.43479876364431, 0.5318745598196983, 0.03121289649918195, 0.16872493580224054, 0.13956012174246774, 16.715935545582926, 76.5844972672001, 60.48996125498126, 54.038372270522586, 42.756164766127064, 32.149809099012806, 61.394714770778535, 7.227951557405534, 0.3046179478687625, 0.18916846703617804, 0.008678900926644284, 0.13095821073699382, 0.09437707568248434, 0.05481277126818896, 0.012683236761198891, 0.11004403338677461, 0.08741286147626177, 0.044731762815987876, 0.06448296124055501, 0.13025123415695083, 0.00938954706784458, 0.048382505023431395, 0.10494442356209602, 0.15109458667857034, 0.3996645154491548, 29.63582281143435, 79.56967984476398, 34.691014674402055, 47.81526527097149, 59.95802117932228, 73.73552291624009, 92.9325831320978, 11.701624585736184, 1.040457104963641, 0.3495762773579167, 9.014712764370827, 12.747494193815417, 91.9626751253682, 85.51918583531534, 89.6094334510065, 88.06072481216924, 86.8305596997661, 83.3351787444084, 76.2500524520874, 67.75475563541536, 65.19611512461017, 67.01696565074306, 63.7915143659038, 61.70165200387279, 60.33833419123004, 56.5412562893283, 58.128204114975475, 56.56079361515661, 57.02723403130808, 59.30838254190261, 56.83482216250513, 57.556436292586795, 56.42440888189501, 57.80593041450747, 58.09358527583461, 57.19338170943722, 58.128188425494784, 57.365640440294825, 55.03802753263905, 52.92443090869535, 52.266974987522254, 52.40597594168879, 51.374977019525346, 54.30529348311886, 53.7130783450219, 59.083387544078214, 50.63881089610439, 55.77645294127926, 56.04071478689871, 53.59436388938658, 56.420000137821326, 53.94993459024737, 53.524392727882635, 55.95967469676849, 54.569480803705034, 54.392640744486165, 49.5521653083063, 51.293450555493756, 50.745287556802076, 55.122362413714015, 54.707716895687966, 57.56495175823089, 61.66071422638432, 63.19614956455847, 65.08896381624284, 65.80637708786996, 61.45339342855639, 60.255332916013664, 63.74665421824302, 62.876284199376265, 70.58313754297072, 61.666731142228656, 56.371633391226496, 64.31200112065962, 55.63690677765877, 56.33828147765129, 50.35081871094243, 52.15998057396182, 45.98147484564012, 51.452373227765484, 48.132820360122196, 43.71614133158038, 51.39495757318313, 44.40356416086997, 51.68911964662614, 56.92982589044879, 57.56858779538063, 55.15043481703728, 45.41717913842971, 57.04426496259628, 46.65779344497189, 52.5005482089135, 60.3534157045426, 61.1906103164919, 61.34239035267984, 63.52336545144359, 62.078670224835804, 60.60184686414657, 59.42837176784393, 60.115076803391986, 56.19651917488345, 53.74754421172604, 51.65718763105331, 49.549517708439986, 49.50756403707689, 49.254496635929236, 50.356725800421934, 48.54557137335501, 45.38939306812902, 46.88628719698998, 45.18384518161897, 47.427327171448745, 51.69672904476043, 54.476897178157685, 52.43750395313386, 51.89441650144516, 47.945448736990656, 46.82496093934583, 47.35372781753541, 45.45280210433468, 48.91992238260085, 55.344501926052956, 54.07901194787795, 54.402340765922304, 51.684079400954715, 54.64261339556787, 54.13156386344664, 53.66861435674853, 53.606582072473344, 54.94912309031333, 57.625524920801965, 66.25848908578196, 66.26663192625969, 68.10371322016563, 71.4754924466533, 71.94578463031401, 69.13836386895949, 69.30212282365369, 65.419913799532, 64.24807040922104, 60.955530904954486, 64.87973674651116, 71.77189811583489, 81.22772062978437, 74.22570151667442, 89.4174098968506, 66.08407697369977, 0.5581770548897406, 0.5238191759394062, 0.13795686825629205, 0.10924937804379772, 18.423684527797086, 83.87426145615117, 67.89387426068707, 61.4288943044601, 39.7825571029417, 43.42568982032038, 73.31638628436674, 13.25877808755444, 0.4311263675410902, 0.1553865789525932, 0.09806154491079432, 0.14200375835982063, 0.10929898223689488, 0.0698553596533114, 0.03438656128221943, 0.09167462392079254, 0.17045528327505435, 0.15495278932634862, 0.10867763896502795, 0.26748122286892706, 0.13301557050116602, 0.2615905276709988, 0.17603042685697157, 0.2190311718732119, 0.7508546029848437, 31.2610706206291, 93.15509134723295, 36.4028468439656, 64.10224845332485, 75.75715172675349, 78.83233701029133, 102.9943569244877, 14.20105201582755, 1.1819226559131377, 3.5112413042976014, 8.721439107771843, 21.00140933067568, 100.28639178122245, 88.59455939262145, 91.85967368464317, 95.80924941647439, 92.15952319483604, 88.56904045228036, 80.59551300541048, 72.22818743798041, 67.08262612742763, 72.10038877302601, 68.5939859574841, 65.38156478635727, 61.54258420390468, 61.95564900675128, 61.73617670612951, 60.09674756757675, 61.55830506355532, 62.7368910081925, 61.11330040039555, 61.40384997090986, 60.84757158833166, 61.51056589618806, 62.24032678911763, 60.5227130459201, 61.451761722564704, 61.145295173891135, 57.059409233831595, 56.34997798550514, 54.5273349362035, 57.559935046780495, 53.786359986951275, 56.35893667897871, 56.97165404596637, 61.65060235608009, 52.057740073050226, 57.121665093206595, 57.153883441802, 55.918548645511756, 57.0902822094579, 54.9077420849954, 56.80583584693171, 59.51194963147564, 56.274703779528224, 58.50140586976082, 54.717020757736705, 55.07764347137944, 54.75484025093817, 58.19937944412232, 57.52382178460398, 61.25163062926262, 65.60815226647162, 65.89919213325747, 67.45189374493015, 65.92158886694139, 64.4471267730959, 63.21791087427447, 69.05109897736581, 66.29847372731855, 73.1917804287326, 62.15665871097196, 61.56695388978528, 61.0331153869629, 57.38572689794726, 56.110693793143, 51.18289070744669, 53.66352704263503, 45.492778901130926, 52.58310625630041, 50.4229118747096, 46.82152494307488, 53.38705093629899, 44.78372420034101, 51.66827617153045, 60.9235361314589, 61.62025105568671, 57.01365478577153, 47.37084111859722, 60.09603369620539, 52.90739605503698, 55.058769026110255, 62.493515783740634, 61.96603936533775, 66.42325216724028, 68.35325441052838, 65.11784030545142, 62.066385361456106, 62.494582668427505, 62.97527697778518, 59.82111869319793, 57.08612057470507, 53.91642970423545, 50.69576763337659, 52.350674444629306, 51.68412646939678, 52.87333419246059, 50.51898248734013, 46.47379506018854, 49.920452333265736, 46.496450670303844, 47.9246719421879, 51.67674849110266, 54.33873168883785, 55.92895861594908, 54.269819567280436, 52.262982014686834, 49.237634366558446, 50.97293015449278, 46.83954823401667, 53.13654484287385, 57.855646456441576, 57.83513246044036, 57.21497043486565, 55.344372487837276, 59.027583983636674, 55.48793123614404, 56.707160780506754, 56.56954834538122, 58.89404296875001, 60.30459788537795, 69.06948704873362, 71.44672578380954, 70.90560343957716, 74.1742870884557, 76.1187001197569, 72.15196794079196, 73.84636909730973, 69.38395915492889, 68.85407832361037, 65.12029178680913, 69.04574101971042, 73.99308143123504, 84.74784389618905, 77.93860927704843, 93.98600624453638, 72.19276059058406, 1.2671219293148288, 0.7515178512661689, 0.2604436021178, 0.17870733724726787, 22.319564973154378, 92.11640065716159, 74.18276725276824, 74.55182306228146, 59.30558981433992, 43.26019325563985, 85.95357264241865, 14.851464340763709, 0.7549890262946006, 0.5217457130070656, 0.18510276181322916, 0.25457748302048255, 0.1804781188407252, 0.16516676382912746, 0.08427363234542071, 0.16155879614093613], [0.03852879102792471, 0.03208976839819262, 0.032987255723245686, 0.01727054252349321, 0.14635518373500916, 0.15445265648586137, 0.02680783156275509, 0.18844895725769384, 0.19037525469978012, 27.87353523315922, 65.61205110242291, 34.32523012161255, 40.51580498295446, 53.64352295475622, 70.16848025783416, 82.40874628866874, 4.760430647480873, 0.11609915403589127, 0.7345739475661709, 5.013666220249669, 24.278884972295455, 83.00795109041276, 81.71912300971248, 87.81024225296514, 81.55075919243598, 80.2220876755253, 79.44350504106092, 71.91639823298301, 60.71205369887814, 61.75860481877481, 61.39183967344223, 56.24868669817525, 55.38499647571195, 54.71720903150497, 54.049484345220755, 55.15205083354827, 54.904290399243756, 53.23558468972483, 52.77883252789898, 53.68244855634628, 51.73271286872126, 51.61657933265933, 53.017826464868364, 53.232866487195416, 50.64154086574432, 55.20463412807834, 54.455822283221835, 48.49850293128721, 46.25817060470582, 46.97960038338938, 48.81141785652407, 52.58910748266405, 52.28698299777124, 51.412772978505785, 54.60129514817269, 53.42771807024556, 54.66562986373902, 57.22024602274741, 53.66338583730883, 51.77780051385203, 52.08633415160641, 49.22454541729343, 50.17538286024525, 49.74241202877414, 49.87481555631084, 47.79875601491621, 51.873525957907404, 45.83359364540347, 48.47494125366212, 50.89946023879513, 53.04860138124036, 53.876586268025065, 55.71568758256974, 59.035063943555286, 58.645243106349824, 56.494485947393606, 57.53107816942277, 57.062884453804266, 58.8066957073827, 58.48137432529081, 62.56482839584351, 53.7370793281063, 58.7648989308265, 56.78218395479264, 49.94493576788133, 46.226571990597634, 46.022898997029955, 48.591004187060946, 44.426639464593705, 45.10147933037051, 47.23973197321738, 50.54347768906624, 45.64757523998138, 49.548435134272424, 48.62672128985005, 44.304747889118815, 37.83012674700829, 49.56031599352437, 43.91831597974224, 43.31647534524241, 47.09054462371334, 56.78486293362033, 59.95178853311847, 59.27514045469223, 60.28708842492873, 57.32445555348551, 55.82176808388003, 55.348463519927, 55.01878830694384, 51.78324868602138, 46.905334226546756, 45.328564951496745, 44.087954567324736, 45.72927428830055, 47.284027299573346, 47.08945420480544, 45.88546699093234, 47.19606814845916, 45.46307086944581, 46.24556410697199, 49.53302021949522, 48.16821582855717, 52.61915676055416, 49.718583629977324, 47.145289144208355, 46.04655088916902, 46.942188816685835, 44.29544402707008, 41.80691588309504, 45.21793450078657, 55.782077620106364, 51.724142489894746, 50.96198281934185, 49.55027080351307, 52.104682999272505, 50.66312566880257, 53.11547779267835, 50.76126337051392, 53.86716473487116, 56.84041546237085, 63.34680780287712, 64.43160595432406, 67.63163243570636, 63.39146790965911, 65.92800586454331, 60.908446773406006, 65.30717703603929, 60.18643648393693, 61.95716696400797, 57.25850089903801, 69.8529883353941, 73.85224480782786, 78.74071828780636, 75.46403300377631, 89.27734205799719, 56.34088593144571, 0.09308525992016639, 0.458410864755992, 0.18218862463630017, 0.15351522533643633, 9.868400942894722, 69.72485234660488, 65.14143336203792, 51.43890380859376, 52.09366898382864, 23.507276311997447, 61.735694254598315, 21.151067364600397, 0.6698219285857293, 0.3011703070613646, 0.14407723661391966, 0.11545232301878354, 0.046403056401158535, 0.0793408228444957, 0.010222357419890263, 0.13574995280754182, 0.06076555023150099, 0.030218763352041284, 0.011122932079278175, 0.10455834589177564, 0.0307472720892439, 0.20680574159468376, 0.08318878289672636, 0.1260915222848135, 0.14426262989159555, 34.91651958034885, 71.94026193311139, 40.83550168621925, 37.87916029653242, 60.68922942684543, 75.8888178486978, 90.10577801735171, 4.444414108030258, 0.2470267978647063, 0.8138209016573045, 9.958240870506534, 37.559777382881414, 84.32225104301207, 85.27617146891933, 86.78032982733943, 84.11072546435942, 83.99101472670033, 82.54896317758869, 75.23396245894894, 65.80436883434173, 64.79598237622169, 63.86547457787299, 59.33483892871488, 60.08818111112041, 56.60113911474905, 57.05650667990408, 57.59322812480312, 57.942044504227184, 56.09372561977756, 57.172777498922045, 56.4361406910804, 54.56984166176089, 53.73254899055728, 54.56235777947211, 56.088434342415106, 53.76666576631608, 56.377944484833755, 56.0644490488114, 52.24530389232021, 50.4849402366146, 50.80790427423293, 52.10768361245432, 55.101715057126945, 55.11619252543296, 55.34745547079272, 57.251166066815784, 53.63656467007053, 55.83253499000303, 57.96571208584694, 55.77285220546108, 53.49679100898005, 52.810835146134906, 52.516516177884995, 51.59070345663255, 50.39043857205299, 53.217851654175796, 51.29212871674569, 53.27049378425845, 48.677296330851895, 51.810360108652425, 52.65587014536704, 53.75982515273556, 55.323074017801595, 57.780823323034475, 63.00465553037582, 61.10493006244783, 59.9114744124874, 59.0317456183895, 60.75747474547356, 60.86908186635664, 62.320401976185465, 66.06965834094633, 56.33256266194006, 61.55198220283755, 59.766452620106364, 51.601925357695556, 45.1602364355518, 45.00056066820699, 48.21970478180916, 46.37713216966199, 47.843278838742165, 48.26445510310512, 49.23506129172541, 45.54261653654037, 49.461558557325795, 52.18044357915079, 49.94454745323428, 41.125600184163744, 52.43327956045828, 47.06373130121539, 50.57579801928613, 50.183737508712284, 57.37326160553963, 62.366752624511726, 60.438515447801166, 61.69306201319541, 58.70116041552637, 56.61534201714301, 56.97882021627119, 54.662593949225645, 54.24689331362325, 48.38190655554495, 49.24585957680979, 47.11797768069852, 47.61736600629745, 48.0598093617347, 48.98946208338584, 47.00052622825869, 49.062614287099535, 45.19971116896599, 47.73719049269154, 48.28517698472547, 47.65319685782156, 54.2753932552953, 54.94004280336442, 50.264444197377856, 48.36461674782538, 48.99851883611372, 47.35885435535062, 43.68743742665937, 46.735275945355816, 56.93793735196514, 53.45612387503348, 52.823586771565104, 51.840723176156324, 54.81157733548073, 52.84179441390499, 55.39474748796033, 52.237698416556086, 54.014822360008, 57.179841687602384, 65.26718454976236, 67.44149161923316, 71.41060075452252, 66.33693648922828, 67.316862229378, 64.51473666775611, 67.53958225250244, 63.91007192673222, 64.22453226581698, 60.87785228606194, 73.65654207045033, 77.21825815016224, 83.32972664986887, 78.76406423507198, 91.51760378191548, 58.03418490194506, 0.0896719475126555, 0.5423824669372651, 0.1479698059659812, 0.07823355766313692, 9.109373284924416, 76.83530930549868, 73.01311646738361, 61.20310306549073, 49.67249970282278, 27.75060030721849, 71.53316697766705, 27.533069579832016, 0.3690338074680298, 0.15822119620298186, 0.0337335211224854, 0.09587297726783062, 0.03544103917515567, 0.058326797424665386, 0.07386767620881719, 0.04534606957027028, 0.20456104268950803, 0.12824678808570872, 0.1275439943457323, 0.20013924447759507, 0.3074628613408535, 0.2426310313204604, 0.17411459417593095, 0.26851740275179187, 0.2595391280708775, 38.70852193524761, 85.13060446708434, 45.42115249941426, 50.23127271283058, 74.6207312614687, 81.36993792749222, 100.21312190640359, 6.124868296807812, 0.44401034232108827, 2.8178934897145917, 13.673087262338209, 42.53189148441438, 89.27386683802452, 88.28557860466742, 93.69821410025321, 91.9464522023355, 90.05820751190187, 87.06176773194345, 81.01481437683105, 68.75186135691982, 67.94565739170199, 68.00783480367353, 63.72377111065773, 64.3176140323762, 60.83552991190265, 62.287010838908536, 61.946835440974084, 64.24815670136483, 62.45943823168355, 60.697058477709376, 61.10585181943832, 58.08211626545076, 57.378086120851584, 58.96249225062709, 58.88843790177376, 57.56999592627249, 60.79323891670474, 60.853345317225305, 53.557603436131636, 53.88383873047368, 54.53082976802703, 55.98083588384814, 60.28974386953539, 58.58172816614951, 58.2940693824522, 59.96876062885408, 56.31933250734883, 56.476443044600956, 59.88384523699361, 56.31823424370059, 53.573096798312285, 53.61553684357674, 52.99842249962592, 53.22838321808846, 52.629503973068736, 54.65830287625713, 53.51253148048155, 56.64671705615137, 51.48850217942269, 54.700586026714696, 55.23414211888468, 56.666156322725364, 59.290441620734434, 60.17339068074381, 64.69718179395123, 64.4154183326229, 62.513876807305124, 60.80982662016346, 64.96627599962297, 62.9734883769866, 66.22391731508317, 67.05423601212041, 63.952817916870124, 60.29701202146469, 58.77270836983958, 52.04339596533006, 46.84635746863581, 48.15573876903903, 49.07898233782861, 47.38911544123004, 46.81490790459418, 48.2588618032394, 50.07031040806925, 45.20464551064276, 50.97825281081661, 52.568997490790586, 52.549248356972974, 48.25707712481099, 53.64699032998855, 51.64932720122799, 50.80983408035771, 52.93103225769536, 61.67867083703319, 64.02842160194152, 63.49191980977213, 65.44806072788855, 61.5813176093563, 59.08461916831232, 59.74147888921923, 60.39033305260443, 57.44247574960032, 50.605784539253484, 51.42010388835784, 50.254355861294655, 51.488949329622336, 50.04832944562359, 51.340605289705344, 48.443032772310325, 50.1207991569273, 46.11818513562603, 47.70378366593392, 50.15925407409669, 48.272629322544226, 54.87581006942257, 57.41197147677022, 50.555754707705596, 51.51993213161346, 54.318849194434385, 51.184326294929754, 48.12993741804554, 50.6927199517527, 61.803492423026796, 57.401459524708415, 53.74663029947589, 55.44702483761696, 58.25630872480331, 56.07637305413523, 58.72704805866365, 55.02580150481194, 58.21849315397201, 62.986887193495235, 68.29795683583906, 74.1237904948573, 73.50946103372883, 69.72761369520619, 70.99329194714947, 68.63378232525241, 70.89321659457299, 66.67153819914788, 66.87519550323486, 63.652791900019494, 76.55848410821731, 79.20432675269343, 86.97703669148108, 80.55282192845499, 95.61903799733808, 63.65696530188284, 0.5451663078800325, 1.137449474584672, 0.47850672996813254, 0.22380728575010456, 14.96393144130707, 85.9499954408215, 79.39145518887427, 69.90356337639594, 68.6204227324455, 31.366713777665172, 81.75463614925262, 30.972805830740164, 0.7325843865832975, 0.4125222900221425, 0.23348807837934266, 0.16651129410151513, 0.10373561342637386, 0.15216764603410998, 0.12156277819867096, 0.2256616475361009], [0.12752169352625647, 0.027337426229590372, 0.07124213201384391, 0.057774072648176265, 0.08299010565444347, 0.09239472358697846, 0.04425318768968986, 0.4447209348361339, 0.2980604803850574, 37.42801712405297, 55.225893374412294, 36.708356334317116, 48.77421417543965, 49.454368852799945, 72.11734125691076, 76.04125684307468, 2.5335069433335335, 0.1850226443381079, 0.5167240373069241, 8.348873757546949, 57.83998835471369, 79.49036951987975, 86.2988353544666, 83.5419111867105, 82.17276080962151, 79.6218865917575, 76.94169967405259, 69.94589359529557, 59.14656908281388, 59.88186051768642, 59.958993927125015, 57.293190340841974, 55.56721802680723, 56.84294931350216, 52.6405885911757, 51.97855918638168, 54.87549235743862, 52.68277760474913, 52.85507555930845, 53.962556777461884, 54.48270228601272, 52.53439041876024, 52.95462923665201, 53.2995036340529, 51.921014093583636, 54.22566544625067, 55.80757694859659, 49.85339549279983, 47.109634799342004, 47.72508605833977, 49.38884173670123, 49.81006506950625, 50.02702313084757, 49.387119816195586, 54.12429571151734, 53.073983038625414, 49.19641025604741, 52.92049284904234, 58.3859234471475, 55.37466887504824, 49.14288559267598, 45.83190702622937, 46.348440031851496, 49.216971320490686, 51.28941051421627, 50.072561848548155, 48.952297626003144, 47.75069521319482, 44.674580327926144, 48.1585628755631, 50.508729411709695, 50.617567339251124, 50.159991479689076, 54.08748034507998, 56.54497861862183, 55.82358806363998, 55.29568018451814, 58.39111274288547, 60.38076639175416, 59.2114725420552, 64.38033273143154, 58.06488529328377, 53.44970687743157, 53.159698594001036, 44.98729521228422, 45.93982711915047, 44.065640203414425, 50.501720136211766, 46.01329703484812, 45.542090938937285, 48.590309927540446, 48.08703453310075, 54.88430592321581, 47.49208550299368, 52.53691250278104, 49.90753989065848, 36.069519904352006, 43.35560491008144, 47.00605677020165, 54.56464452128257, 58.05056864215482, 56.71351502018591, 55.65596949669623, 55.56296225517027, 54.650862140040246, 52.05140544522194, 51.898676195452296, 52.03296638304188, 51.28709239344443, 48.98768132732761, 43.931930526610344, 43.382108365335775, 45.41868140620571, 47.93845907334359, 43.52258020831693, 45.31420907666607, 44.22985023067844, 44.45767325739707, 49.8667590079769, 51.316659219803356, 47.95265805336737, 48.72192505867251, 51.47203999180948, 51.94254790582965, 47.98371930276194, 48.724964895556056, 46.22870183760121, 46.21189448141283, 41.879373827288234, 44.41202863570183, 51.49912395784932, 51.376208643759455, 52.30515533877958, 50.6773756396386, 49.25155878067017, 49.459769956527225, 53.10064731105682, 51.285837234989295, 50.81027730818718, 56.30573757233159, 60.793082021897845, 64.0151051552065, 61.9163860813264, 64.85448844971197, 64.40981718801683, 63.890969983993045, 63.882203486657914, 61.67461902864518, 59.497225053848766, 64.05688231991184, 73.25597393897273, 74.91148871760215, 78.61676354562083, 76.42306035564792, 82.88444349842688, 46.51963187802223, 0.16166086969596727, 0.387721419214241, 0.044679580737025514, 0.08254690080760949, 1.5869168144079948, 48.691860091301706, 74.79358227022233, 53.66829272239439, 47.67082791174612, 35.96452197720928, 57.939243931924146, 32.42182547046293, 0.21671421555501802, 0.08707731496542694, 0.041844871556085926, 0.09839218845891376, 0.015517019933359999, 0.059417009488829685, 0.04367625070435386, 0.14775856488174008, 0.10102787565800453, 0.022927483228305658, 0.0398698317698173, 0.10858334120242827, 0.031023301229241396, 0.02873857039958239, 0.06630936081731512, 0.2647933574213136, 0.1559460682854537, 46.20136683987033, 64.1577107675614, 41.894616157777854, 44.28044096116097, 58.389171169650176, 76.86023989031392, 84.19014561560847, 2.4532140647211382, 0.14156359488204603, 0.500754536159577, 11.167456603819325, 66.72263883775281, 79.27720439049506, 88.03873600498324, 85.56808210188343, 87.32797115079819, 82.53851398344963, 80.36648581104895, 71.46885579632175, 62.67044605747346, 62.237055532393924, 63.03219841372583, 60.267064725199056, 58.700470078376036, 57.574032045179806, 56.69862570301179, 57.52886203027541, 57.21623736043131, 56.19087096183531, 56.87046866263113, 56.17420873334331, 57.328413224989376, 56.04043629861648, 56.769098927897794, 57.214695868953584, 55.41586160659791, 57.92851624950286, 56.30647105555381, 53.04918581439603, 50.0494473211227, 51.47808828661519, 52.392035838096376, 52.338750439305464, 52.86716822654971, 54.15120317089943, 57.01133274262952, 54.5129672942623, 51.34299009077011, 52.6637541094134, 58.79739969007431, 58.49480844313099, 51.69197120974141, 48.74817355986565, 46.942867386725645, 50.140289414313536, 53.08551088456185, 51.97835522313272, 48.91592156502509, 49.996864026592625, 46.860003394465295, 50.28654675329886, 54.625417724732436, 53.60009839457851, 55.28011621967439, 56.46527997909054, 57.919812510090495, 56.7837764370826, 57.05241564781436, 59.41014451365317, 61.688033534634506, 61.01410758110785, 66.98160156126946, 61.66752346100346, 58.2645849258669, 54.687908926317775, 44.874538836940644, 47.36774244616109, 44.14068691192135, 51.55086002042217, 46.65800133059102, 45.47852500792473, 50.3799109305105, 47.010594952491026, 52.78840311111943, 48.53235690824447, 51.67208871533794, 48.77790904814198, 41.26596220078007, 47.99456857865857, 52.05926979741743, 60.39400439108572, 62.29516152412661, 62.055151693282596, 58.607623654027144, 56.90395785916237, 58.027226617259366, 53.71920900960123, 52.62887639384116, 54.17532574745917, 53.05115876659271, 51.84746573048254, 44.63142248892015, 47.61059599538004, 50.141897586084184, 47.76625917803857, 45.69768351893271, 48.691161909411036, 43.38188479023595, 44.94617700576783, 52.02032850634668, 50.69541462006108, 48.816014874366026, 47.337991268404075, 52.329336750891905, 55.44501658408873, 51.232049772816325, 51.537927965964045, 49.568184268090036, 49.02487324130151, 44.717291016732496, 47.91420313619798, 51.95229499570785, 53.79757012090376, 53.07584616445726, 52.17565044280022, 51.49131059646607, 53.082753458330714, 54.292659528793834, 53.524643759573664, 53.22668875417402, 58.744059378100985, 63.41284482709823, 65.64402626406762, 67.17634724032494, 69.45840574079945, 65.70684302237727, 67.7176421688449, 65.7653687077184, 66.39764693475539, 61.40669368928479, 66.4150857925415, 75.13308694285732, 78.56425085375386, 81.49044882866644, 77.34520173841908, 83.4819616809968, 49.199253974422334, 0.19269259406193612, 0.306467866344798, 0.1371335995293433, 0.3743916731928626, 1.9153003418637862, 51.485121096334154, 79.71366220904936, 63.951676507149976, 46.81616698541949, 32.00800953372833, 67.96194307265743, 40.74132557838194, 0.11167328789710038, 0.0916205840786138, 0.012540973276050102, 0.02196442835303324, 0.030459016185974887, 0.07547291386271678, 0.019926837487747113, 0.05194867495447398, 0.3056881114119484, 0.13332332334210797, 0.10540888734882879, 0.24164293111572344, 0.18153660720394504, 0.24561912662559943, 0.17864562120408783, 0.43619835989609845, 0.38167425821865764, 53.16139698028565, 72.10777067369031, 49.53187880977508, 65.92683699823195, 68.48649732528195, 84.38686816923081, 92.21067090188303, 3.0246396603122836, 0.31780373064741013, 1.261456433323122, 18.898040286956295, 79.12819354764878, 80.53610478678058, 93.3353634803526, 86.98680339321014, 94.54230816133561, 85.05397704339798, 85.93885590953212, 73.77522514712426, 69.94101416680121, 66.50054639385593, 69.31731808570125, 64.42807974353914, 63.90842060888968, 62.854315004041126, 61.02363894062658, 59.686597085768184, 61.17251642288701, 60.63932903351323, 60.00300684282857, 60.94112403931157, 62.15539570777648, 59.63712030841459, 60.88068031495618, 59.31124194975823, 60.535951045251664, 61.340821404610914, 60.53922230197538, 54.72879571299399, 52.858974395259736, 55.09983231944423, 56.593451269211315, 55.6315762765946, 57.23712790396906, 56.150937311110965, 58.61695105029691, 56.253577893780125, 50.528553070560584, 54.613831043243415, 58.118864951595185, 59.05718218895697, 52.02356838410901, 48.617660614752005, 48.35108457073089, 52.65743124869562, 54.43722240386471, 53.96176445868708, 54.26193560323408, 53.361959534306685, 48.831472935215125, 55.1323252339517, 57.20026154671946, 56.60754434524044, 55.982177334447066, 60.512275618891564, 61.05127596086072, 60.484105156313994, 61.77313720026324, 63.452468610578975, 63.92124283698298, 66.49718100024809, 69.1794232399233, 63.62771618750788, 60.59158202140563, 54.464984939944365, 45.59445850310787, 46.20427723853819, 43.369341050424886, 51.120517176966516, 48.75594377517701, 44.868098305117705, 50.048270610071, 48.12624254534322, 53.129943493873846, 48.41308939841486, 53.707394830642215, 48.49545524966333, 44.36999651693529, 54.50857031729914, 57.57260038006691, 63.17505898014192, 62.87305216635428, 63.78574455938032, 60.25058684810516, 60.17623832148891, 60.04886327251312, 55.370797495688166, 55.50927677462178, 56.21989650111045, 56.63256122219948, 54.85988916889314, 46.87372776769823, 50.465438212117846, 53.07554021958382, 51.60340409125052, 45.68832474370157, 48.760093642819314, 45.466695139485026, 45.738664442493075, 53.022513697224284, 53.3993475667892, 50.65900325775147, 47.18943542049777, 53.32702298318186, 59.29097898544804, 53.994767281316946, 54.5290921580407, 52.355471503350046, 52.07438268969136, 47.08182519482028, 51.226272121552505, 54.76337140606296, 56.91632509231568, 57.801129433416556, 56.560687711161954, 53.983145298496375, 54.75463236531904, 58.58766271222023, 55.664496729450846, 57.41063002617129, 63.72814455339986, 65.72370921411823, 68.62907548104563, 70.11071943467664, 72.12752372987809, 70.11293949619417, 70.88513651201802, 70.47977524418985, 70.1355480378674, 64.04713130766346, 69.24549948784613, 78.98460342038062, 81.54553459536645, 83.91561892724808, 82.55250115548411, 87.50163801254766, 53.282072621007124, 0.6321636202835268, 2.446169487891659, 0.3757936753813298, 1.0872230342318936, 4.263471739907419, 60.795223636011926, 88.20473071067565, 70.54068180822557, 65.830119194523, 47.86678560318486, 77.45654213813044, 47.03743573158018, 0.30915285130181624, 0.3468846121141988, 0.1595881575297925, 0.2723796197002934, 0.14665598049759865, 0.2574261043581271, 0.19129918737997934, 0.2863058111359996], [0.06536197052487443, 0.07893209961513359, 0.05167615832760931, 0.038366119918082996, 0.035145942106722824, 0.042200485740097306, 0.06438248880928563, 0.12503484188909494, 0.06606586743146181, 42.6863387323195, 52.566487173880304, 34.9154644627725, 47.97842018065914, 54.560761374811975, 75.57313765248945, 71.17240305869811, 1.8615864241315474, 0.2137794399694089, 0.3414855002155227, 1.0049978980133611, 27.771955651621667, 89.88148904615834, 77.74692304672735, 88.17901565182595, 79.1402195345971, 83.46153397713938, 73.84347438812256, 66.35814082237982, 59.939025140577755, 62.000960226981874, 59.58236794317923, 57.925656841647246, 53.134293402394945, 55.759610283759336, 56.085065026437086, 55.83747717642016, 54.556697799313454, 54.8546096586412, 52.66592710248886, 56.67661336160476, 51.77621195393225, 53.44028926664784, 53.009750304683564, 54.00203935561642, 54.62000877626481, 52.49776332609115, 52.541121205975934, 48.89125377901139, 47.06191132145543, 45.055901388968195, 47.531928939204064, 49.9635866380507, 50.616018003033055, 52.666629206749704, 52.96654147486533, 52.6404042397776, 51.531173644527314, 50.52703119093373, 56.11933085226244, 54.86872626889137, 51.11361380546324, 52.468784855258086, 51.16826418907412, 49.74084308070522, 55.24649758492747, 54.9492407614185, 51.829324768435576, 52.09173133296352, 52.86102579485986, 49.507089430286044, 50.87854616103634, 50.56540373832949, 49.35410914882537, 48.29239414584253, 50.925673438656716, 50.91182747194844, 54.6684657373736, 55.923255489718535, 56.27633156314973, 55.947181947769664, 59.88838341928298, 63.749184147004165, 49.437804683562256, 51.79042270106655, 49.62130884970389, 51.4067207613299, 48.11853116558444, 44.44750647391043, 41.522171420435754, 48.2916332060291, 45.315354408756384, 46.87020940165366, 50.60586690902711, 54.69373364602366, 48.27932480842837, 53.842716601587114, 45.96559316881242, 50.47450673195624, 45.28370088146579, 54.59088125536519, 55.12185642796179, 57.89044180224019, 55.20215126775927, 55.883015894120746, 50.32629997499528, 53.621895005626065, 47.18341458228327, 49.42174650007679, 47.685211243168006, 46.62269607667, 45.95872117627052, 46.11359988489459, 46.82182304320797, 47.38954297957882, 46.7783082685163, 45.71245124263149, 44.90848302841187, 46.85655170871366, 50.65718720036168, 50.37524331000544, 51.32992075335596, 49.49419659952964, 49.65951273518224, 53.43857126851236, 46.26729796009679, 47.764101874443796, 45.22113907721735, 46.94018448552778, 42.084537321521395, 46.02510729143697, 49.78628766152167, 53.47868927063481, 52.39756638003934, 51.739008272847826, 48.10304564814414, 53.15735301663799, 51.418264296747026, 50.59669640756423, 49.622881720142985, 54.17752227475567, 57.037408659535075, 61.04634946392429, 60.36263719681771, 62.22391166994649, 58.83383066423478, 62.17148919259349, 59.91328654750701, 62.323022119460575, 59.110589181223226, 64.40392186564785, 71.21772212366905, 76.0084972073955, 78.92718776579827, 78.7218830662389, 74.94374628989928, 51.63782288951259, 0.5106274176749491, 0.37531594295174847, 0.17892732705560424, 0.09419277791054019, 1.1810835138443978, 34.86851369180987, 81.26422220660795, 49.6128914433141, 50.59150711182625, 34.59188461303711, 47.477247176631806, 44.97825022666685, 0.06833318125216231, 0.07544171110156082, 0.03958293567261389, 0.03996517141199401, 0.05250860861833057, 0.012520422967481277, 0.020124321548087944, 0.09607152427516638, 0.0203875819176075, 0.016420612021559672, 0.08863205210335794, 0.04619115648130256, 0.09549856711659702, 0.04927113254164015, 0.04638404592931752, 0.08241506473672006, 0.07322147338380737, 52.526639815299745, 62.01163691859092, 35.49046039581299, 43.368666402755245, 64.44262781450826, 82.59708281486266, 76.8556820961737, 1.6190366134528191, 0.20244746739345215, 0.3057574576908543, 1.6561414998385215, 30.805418683636574, 91.50467564982753, 76.93366665993968, 87.48367355715844, 81.44907566808885, 86.06288909912111, 76.88855940295805, 68.36149923263058, 64.17720886968797, 63.76437940905171, 62.14731170285133, 61.28186425855083, 57.9985737031506, 57.81646982316048, 59.22394567920316, 58.94434736620996, 57.55157255357312, 57.801007839941214, 57.348436924719046, 57.74334115366782, 55.41131165719802, 55.64044083318403, 53.61077116381738, 56.96497817193308, 55.96467571873819, 55.02848832837997, 55.426314723107126, 54.10729223682035, 51.67366158577704, 49.28843298266011, 50.875420032009, 54.99090417738884, 53.37981808570124, 56.10828153548702, 56.589779930730025, 54.94229424384333, 51.54622770124867, 50.13036974014775, 56.016388247090006, 57.989179626587905, 51.761832544880534, 54.13590984959757, 52.47332695991763, 52.067691126177394, 57.316665726323286, 56.35898766979095, 55.53834153759865, 56.87894882694368, 54.11249329966884, 53.508883676221295, 51.602019494579686, 53.773984909057624, 51.96935730595743, 51.99378190502044, 52.992436962742964, 53.78897228548604, 58.62172457479662, 58.57741748133014, 58.425402102931855, 60.28037332719373, 63.48792291456654, 63.38167375133884, 56.86402420843802, 52.4766609745641, 50.07076540300923, 51.33248598344865, 49.72493786965647, 47.52768101230745, 44.286528479668405, 49.564069701779275, 49.71379441599692, 46.79951652403801, 50.682643382780014, 55.47180244999548, 48.86312254013554, 54.95657167127056, 47.00705305222542, 53.75285117856918, 51.64563625089584, 57.806765879354174, 58.46033865405668, 60.160058544528106, 56.78538460885325, 56.5811271821299, 54.91021710057413, 55.626881199498335, 50.947854441981164, 50.72980988410212, 48.92151486489081, 47.899239293990604, 47.93579186162641, 48.881871469559215, 49.81056713288831, 47.45421894135014, 46.5842999950532, 47.193247964305264, 45.26936854085615, 46.40801299002863, 51.37398465987175, 50.933090640652566, 53.909338058963904, 49.49216481178038, 52.403516615590746, 56.07945603709067, 47.525759050923014, 48.72146221899217, 48.217437651849565, 49.37578024402742, 45.18302540625296, 50.085074209397845, 53.03336297312091, 54.05206526479414, 54.44719699121291, 52.70144808676935, 50.1094360505381, 55.50412278021536, 53.55718766489337, 53.707685086034964, 53.00219974210186, 55.38813044947963, 60.16117642002722, 63.10488777775919, 62.949452092570645, 62.95999542359383, 62.36833726206134, 64.37185648948916, 63.29502859423238, 64.37011103476247, 61.02605512065273, 67.58462675156133, 73.97562688396823, 79.56332560508483, 80.22397825794836, 82.08434274119716, 75.52500232573479, 56.4121828540679, 0.7560177291593244, 0.4328111174606508, 0.06241861092407377, 0.02938397840837077, 1.3640667401975202, 37.75214610561248, 88.05728881589829, 58.47163508015295, 54.6758907841098, 35.199330314513176, 57.476957305785156, 52.987836022530836, 0.11776956278950938, 0.09418542346646709, 0.04112394834538141, 0.028774994049942302, 0.0629283313549334, 0.06061356221776336, 0.0826264207341498, 0.04206982944461127, 0.08374559092185191, 0.16853005835606208, 0.18917617388069632, 0.13306505978107452, 0.35195458199708696, 0.22271098328694222, 0.13179951317368016, 0.3018302151993398, 0.18263015175057998, 60.60198806947278, 71.26468073937201, 46.85100547729, 65.74629814394059, 72.68646932417347, 90.89115419695455, 86.05900595265051, 2.701391496004597, 0.48046901822090154, 1.018135631757398, 3.1493418591637767, 36.87615925265897, 92.05110888327323, 80.58480493484005, 93.5718039543398, 85.71400211703393, 92.47300686374788, 80.17946720123291, 72.73784452869047, 67.42923029007451, 68.25361051867085, 66.35925477550876, 65.82148213540354, 60.44225346657538, 62.8624225431873, 64.83187598566856, 61.64543659456315, 59.425630031093476, 63.14820251157207, 59.94083727559736, 61.9900756497537, 60.6083187749309, 59.81557638414445, 58.74288658941946, 60.879087832666215, 60.338373414931766, 57.72046981319305, 59.34806516093593, 57.25981097067557, 53.84696452848373, 52.44357185979044, 53.61228912107406, 57.382867490091634, 56.822239198992335, 57.952242666675204, 58.06913714255057, 55.34344288610644, 53.53303370937225, 49.987450338179066, 57.120790404658166, 58.585674070542865, 51.98444274164016, 54.77126321484966, 54.92451021748205, 52.73789867278069, 60.279808505888916, 58.79777231524068, 58.45912271930326, 60.24755485596196, 56.380709755805235, 55.306525538044596, 54.287046617077245, 56.359372062067834, 54.63257997266708, 53.35432660195136, 57.199159360701046, 56.053184001676506, 61.683330612797896, 62.11190838967601, 61.72678655193698, 62.999548604411466, 66.00594335986723, 67.43141112789031, 54.202645055709354, 52.45931625366212, 49.33263024976177, 52.56692647933961, 50.31870626634168, 49.44896382670249, 44.92672597208331, 48.9124777240138, 50.65190769010975, 49.99396931740546, 52.48076377376434, 51.61828948605446, 51.052985729709754, 54.763002703266764, 50.37838120614329, 55.05041830001339, 53.15179501810382, 59.573993682861335, 61.20825313752698, 62.97622226899671, 61.55360606408889, 60.55031868719286, 56.69964159688642, 57.92711988572152, 50.8635195609062, 55.709086233569735, 53.73605558949133, 51.91668771928357, 51.92379505403581, 49.70110554848948, 51.09450009561355, 47.583092335731756, 47.90607206283077, 48.04105258757069, 45.66190365822085, 46.66817595881801, 51.03162450175132, 51.896522814227694, 54.33984171959662, 49.67976001001174, 55.098404576701505, 62.027393079573116, 48.8374270931367, 54.04462452857725, 50.807421822701734, 53.36458359995196, 47.315437639913256, 51.705472007874526, 55.81388804220385, 58.521547240595666, 57.38584456905242, 55.53784339658676, 53.206072776548325, 59.560249697777536, 56.26105785369874, 56.435493500001975, 56.22386201735466, 58.90279377660444, 63.21137228319722, 67.83066918773036, 66.4812404878678, 67.8929328918457, 66.13843317954772, 67.88399773259317, 66.28014841387349, 68.92897990442091, 64.03073580034318, 71.84676831768405, 77.13344866229643, 83.94902183163552, 81.49270026914536, 84.7423682674285, 77.07724894246748, 61.253940905294115, 1.133620505852084, 2.934857097364241, 0.6349168789963568, 0.6643052375124348, 3.737886884520131, 44.962501910425004, 95.29588960832166, 64.82336444239463, 71.29138423550513, 48.14618387529927, 65.03088135873118, 62.685472657603604, 0.3061469980785924, 0.23392752173446843, 0.19204135803926378, 0.06918334732613257, 0.16528463411715724, 0.1411898205837896, 0.16405489445934374, 0.24283166974782947], [0.038184514945192684, 0.0653345445771852, 0.016672381072215015, 0.023845777501382177, 0.1406520268609447, 0.04002958791510713, 0.045312844336994236, 0.0645691537929158, 0.16828985914828318, 54.61507835695821, 38.8274246646512, 45.173709777093705, 53.56747211948518, 49.67122493251678, 81.43006786223381, 52.73110512764224, 0.2616674428985965, 0.1238321221523708, 0.41554824539249946, 2.2135535699705926, 20.263456567641228, 94.30401632862707, 75.82707974218553, 88.43974344192013, 78.3289086434149, 85.27187255121048, 69.37955825559555, 64.42568317536386, 58.40190710559968, 61.680494739163315, 57.267875363749845, 59.81106173607611, 54.73784462098153, 59.27595630768807, 57.600406062218454, 59.26750359996673, 58.64271317758868, 56.770809081292924, 52.21048893467073, 53.291321569873446, 50.526768392132176, 52.92994183878745, 51.47839030911846, 53.30331617786039, 51.34663005029002, 52.67224996320663, 50.65407283844487, 50.98564255622126, 46.99964369496992, 45.268803719551336, 46.67139622472948, 50.95082367620161, 49.75785440014255, 49.845946911842596, 51.36011123657227, 53.20881059092861, 49.10400313715781, 49.65337814823274, 53.23516891848657, 61.38489707823723, 54.20865020444317, 52.98687504183862, 55.44520093548683, 60.135649634945786, 61.1209725564526, 62.824905072489095, 62.57163370809248, 64.62073479929279, 58.758968307125954, 60.911451308958, 52.386422926379794, 54.38250141759073, 51.16969977655719, 52.32745793557937, 48.449575285757746, 48.77002508409562, 49.964755504362046, 51.921002326473115, 53.74992509042063, 58.19206814612112, 60.49402483047978, 61.91938669450822, 45.8170961564587, 47.76213676698747, 49.35885521673387, 51.613429669410955, 49.149204531023585, 41.984273695176654, 37.9785257001077, 45.71273365328389, 42.82163304667319, 39.213817350326046, 40.08779987212151, 61.18160455457626, 52.80294725971838, 51.29095985043434, 51.03088709615892, 52.378146725316206, 59.33077535321636, 55.833209637672674, 54.281551376465835, 52.467364957255704, 49.949477872540875, 49.95602430835847, 48.85280670658235, 48.91752581442557, 48.92849276142736, 45.410809209269864, 45.37451551806542, 45.70657945448353, 45.287780146445, 48.99869534277147, 49.60023395476803, 47.01682367632466, 44.30267687766783, 43.559101396991366, 45.20124089333319, 47.583374746384166, 49.18057172529159, 50.29302258645335, 47.656315142108554, 55.59824005250008, 53.2270456898597, 51.11042884088332, 46.22586596396662, 48.04723816533243, 43.43744908609698, 44.26026821136475, 42.30600610856087, 46.20794465464931, 50.87674579312725, 52.38638370267807, 49.14681188521847, 48.60058653739191, 48.058338472920084, 50.28017290176884, 50.33607059909452, 51.65688560855005, 50.38111902052357, 52.76424131085796, 51.63712862999209, 56.14123336730465, 56.817500975824174, 59.75014732730005, 57.74961302357336, 62.709465795947665, 59.70238070334158, 60.30900270708146, 56.41317913609167, 63.21378846322337, 67.57040423731651, 78.6063692646642, 75.47978524238833, 81.48966435463198, 72.4475577569777, 77.06057102449479, 3.896746308572831, 0.6154339760541916, 0.042967902826926405, 0.137570422863768, 0.6622502219773109, 25.095979398296727, 79.68828447403448, 54.685394687037316, 44.44215636099539, 19.28044980572116, 44.260248599513886, 43.80998011558287, 0.3419897699308011, 0.059832953096878146, 0.10623068518696294, 0.0272399089824889, 0.03997779271054653, 0.05087831988930703, 0.021937511853813645, 0.08321229413512253, 0.12674697179106936, 0.07619497471398885, 0.11762147799374596, 0.13527045837573468, 0.080859852624276, 0.049701907611902685, 0.029714411282311046, 0.07660527608447498, 0.43821010678525896, 62.961909540237926, 47.662445806687884, 42.137987459859545, 48.885848752913944, 58.99083921986242, 86.01976656144666, 58.41463519680885, 0.2924657709175541, 0.043963709876181624, 0.23097255207117529, 2.5275576883746735, 26.95575160364951, 96.36975611409834, 78.77007330617597, 90.80010814051475, 82.48604051528439, 86.52880391766949, 73.4478876667638, 67.5220492578322, 62.18387603759766, 61.82349258853544, 60.38521435952956, 61.70439374062323, 57.510870118294996, 61.90856879757297, 60.03814343483218, 64.16095849006408, 60.60190177732899, 58.77855270139633, 57.51979743280719, 58.007097013535045, 53.9032466180863, 53.276491088251916, 56.292781983652425, 54.966224624264626, 53.42962434214931, 55.75753927230836, 55.39594773323306, 53.39639009967927, 51.30468422366727, 48.73413539701893, 49.35090065002442, 52.95478220908873, 52.69820820900702, 52.11362600326539, 54.15628264027258, 55.57262305290469, 49.51416146370673, 49.97353769117787, 55.75966911931192, 63.87355858279813, 53.914111583463615, 55.50151440405077, 58.75970571271835, 63.781327970566295, 64.41199018109229, 64.7694593091165, 63.53829791468959, 66.56030762580134, 61.85097271396268, 63.6782951508799, 54.146233527891106, 56.13241980152746, 54.81370326011412, 54.938556225069114, 53.085856053137014, 52.27759284357871, 52.55906212714411, 55.16418272449125, 57.292029319270966, 58.68808715574203, 64.75481710126324, 66.49454516749229, 54.46452994500437, 49.002762840640166, 48.91756111575712, 51.31132087399883, 50.78346398568923, 44.20876749100224, 39.75796384196128, 43.677160816807906, 45.44209795613443, 43.047294847426876, 42.74926531699396, 57.662014730515025, 51.52390549259802, 53.33919017545639, 51.24347563712828, 54.50216900917792, 61.51433529392366, 58.248707171409364, 56.74578435959355, 54.25924485729587, 53.11782337004139, 52.32685389057283, 51.05228754781908, 49.74118432691021, 49.11018479254938, 47.50238172469601, 47.56079366130214, 48.618394097974225, 47.72185794768795, 51.474389491542695, 50.81914186477662, 47.87236713594007, 44.81609159900297, 43.57793661855882, 44.91406456116707, 48.41098308563233, 48.1596689839517, 50.598759574274865, 48.96717517606674, 57.54916814065749, 54.222092167023696, 53.549189952112016, 47.73674726486207, 50.41244699108986, 46.953693128401234, 48.36782916899651, 44.61698424431586, 48.766812662924494, 52.84075498580933, 54.72812106532436, 51.98252078025572, 50.377730092694684, 51.41433800420454, 53.371639943891964, 51.53638255211615, 53.67854187565466, 53.43321331085698, 55.47367734293784, 53.5011762188327, 61.2508971460404, 59.44967416024978, 63.34763542298348, 61.273070304624504, 64.75671552842664, 62.09986279087683, 65.00252654475551, 60.291277516272764, 65.53241914318454, 67.64419970973846, 82.31441328602453, 77.056091677758, 83.95318738875851, 74.38775031797348, 82.9020784747216, 6.1609624374297365, 1.0084308912196467, 0.13336734275423712, 0.25516778440965765, 1.5715590191464273, 28.040826282193585, 87.12859707493936, 63.5840327508988, 51.69332442745086, 25.01513150430495, 53.872255971354825, 51.808861763246604, 0.4163359982832786, 0.08440618853895895, 0.014932126167320437, 0.017791957286516988, 0.03658856610737501, 0.09393428452312948, 0.031172268941337546, 0.04286190690172296, 0.40830895965618474, 0.1959435954209297, 0.2512798115851418, 0.215082019267063, 0.26448011939083377, 0.10579809831875948, 0.1930422672340947, 0.2285336192336775, 0.573789436490305, 75.51665552200811, 56.79053860325968, 60.486795902252204, 70.2375453518283, 64.37843038189796, 94.97414542782693, 64.8146685477226, 1.4078325465802224, 0.2714788841624414, 0.815078879316007, 2.9079675337960644, 28.524791848274972, 98.00927546716507, 81.08917467055782, 94.42269156056066, 85.64030862623646, 92.54994023230769, 76.77632470284739, 71.30872895640712, 65.66910589894941, 65.94287949223673, 64.71617783269575, 68.17026799724948, 61.08736176644603, 65.71842578149611, 62.7683444946043, 67.9633237469581, 66.2932961986911, 62.903650576068515, 59.51472274718746, 60.55307219105383, 57.09312592783282, 58.76212973748484, 59.14137194233557, 61.07108785260109, 56.51558045418032, 58.526108957106075, 57.937474942976436, 56.90601318113266, 55.166328260975504, 52.58248259944301, 52.777785255062966, 55.4582545834203, 55.68286911133797, 53.01720673038114, 57.51305880085115, 58.13156166384297, 52.01052258091589, 50.47833888761459, 56.01966342618389, 66.00758291059925, 55.45970193801388, 56.59722458931708, 60.16784444932015, 66.68550968170166, 65.97879271353445, 67.5601903853878, 65.92307152286654, 68.70259638755553, 62.46617686363959, 66.11369086850074, 57.21409182394705, 58.69490031273135, 55.98518186999906, 58.0641871113931, 55.22165329225602, 54.39783004022414, 55.20133149239325, 56.32565144569644, 59.484324378352014, 62.356558384433875, 65.24765114630422, 66.03428640673238, 51.06517253383514, 49.38590780381234, 49.07845281785535, 54.753000659327355, 52.98598858617967, 43.60027451669016, 42.32918731627926, 45.325301539513376, 45.8939746118361, 45.54505625078755, 44.53079800451956, 56.917321374339444, 51.263181624873994, 54.361508892428496, 54.34772568364298, 58.20392939352221, 65.70493282810335, 61.69234814182405, 59.380240363459436, 57.35164150114983, 55.32730233284735, 55.7393120181176, 53.62603702852803, 54.32131636527277, 53.06272975860104, 50.28655852040937, 49.77282608709028, 49.98928208504954, 49.98807791740664, 53.83686050291985, 51.09289976858324, 49.35871793377785, 45.42210563536614, 44.46851076618318, 45.34812973391625, 49.77094334940757, 49.41182290354083, 51.93714680210237, 49.5470505376016, 59.982135911141675, 55.98568785575129, 56.435211089349565, 50.95890768112675, 53.78961163182413, 51.4007979823697, 51.290222444841945, 47.901165177745206, 51.386657837898504, 57.12202595126245, 56.55996599505025, 55.11993054420718, 52.31114087566253, 53.68527658524052, 54.913241247976984, 56.680829909539995, 57.32431042578913, 55.97029647519512, 59.02690933596704, 58.13439753747756, 63.88414898226338, 65.26645106654014, 66.47800061010545, 64.18699126089773, 70.51772809797718, 66.24655723571777, 68.80907304825323, 63.74300641398277, 68.7501512035247, 72.45504163926648, 87.13164083419308, 81.47699509897541, 87.91004303962954, 79.587981623988, 89.38522292721657, 5.44362614231725, 2.3326681073634856, 0.248054045162374, 0.7874980592919935, 3.4266634814200865, 34.45200897032215, 97.28169148968112, 69.26698623165008, 64.37451193409582, 30.358211609625048, 64.65555367931243, 65.15454976789414, 0.5959274776039586, 0.2088458797023181, 0.1603391994872401, 0.2089551238403205, 0.2113085765872271, 0.15415794246139067, 0.13623563722977716, 0.14049514737581054], [0.055216606856594165, 0.06249780909368589, 0.05536902004912977, 0.1227695428796353, 0.037440915531929464, 0.05178209679621843, 0.02566460429901077, 0.2271994005047506, 0.4156589297757995, 44.07110798743464, 50.989588460614605, 27.50308894341992, 37.99281097227527, 58.6143034504306, 71.0347592446112, 65.92486796840545, 0.6107392053930991, 0.07598662944210154, 0.46847545211353614, 0.34295179250259555, 23.397426412951564, 89.58808006778841, 76.18352905396493, 88.24677851892288, 77.2430161506899, 80.73850693241243, 62.37267932584209, 62.28672450588596, 54.89628091935189, 58.98102152732111, 56.24734916994649, 60.85670286609281, 59.87536507268106, 61.96942437079645, 60.34996794116113, 62.45330364473405, 59.890783909828436, 61.05980319361533, 55.38477290061213, 56.413120300539084, 51.83794221570415, 51.42988235719743, 49.724200464064076, 51.98223444723314, 49.24686370357391, 51.38293550860498, 52.46114800053259, 51.130621202530406, 46.58548847321541, 43.816153926234094, 46.325478476862756, 49.28375751741471, 50.66071733351677, 49.58425421868601, 51.975323230989524, 51.98629802273166, 49.08101804794804, 50.22633837115381, 60.46883929160334, 56.29810463997626, 53.41944579155215, 57.32035275428527, 62.89701000336678, 62.97192335128785, 63.0551403568637, 66.50404514804964, 64.70197100793162, 62.78992145292221, 62.28947800974693, 63.24681874244445, 59.34327202458536, 54.50382424939064, 56.63704056893626, 51.18758578454295, 50.92939184558008, 51.599226767017, 50.59493134098668, 52.69365825960713, 57.22307797401183, 58.18967942268618, 59.10449381797545, 56.14635990511987, 40.819027731495524, 49.14001441770985, 51.92450108066682, 51.669711759013516, 47.30030905815863, 44.15234419607347, 38.32001509204988, 42.32824202506773, 42.13175873602591, 40.06501090142035, 39.25593576123638, 49.607392280332505, 57.54229222574542, 46.64146854031471, 52.66612322099748, 51.975142801961596, 53.62856695728918, 53.48941695305609, 50.010647235378144, 47.72415645660893, 50.34415852638983, 50.167287088209584, 45.73851147005635, 47.202426310508486, 45.510751201260476, 45.58490753173829, 45.14615120426301, 48.62732533485659, 52.13805452469857, 54.87083650404408, 54.09788247077696, 49.21752829705515, 44.2403974840718, 39.751060470458, 43.29857364777596, 44.40172064688898, 45.61877719817623, 52.06395702977335, 55.89389654897875, 54.99412052093014, 53.5137434928648, 48.550380199186264, 47.50772007050053, 47.37702669635896, 42.38961927352413, 43.151963295475134, 42.74809645068261, 46.39987014955091, 49.11668023755474, 51.37089775454614, 47.18745854593093, 49.39128537331858, 47.76766338656026, 52.68631950501473, 50.48083351504419, 53.08615415327011, 48.73523758303735, 53.800923747401086, 50.18475732495708, 53.30191589170887, 52.6172387215399, 57.01964424502466, 56.63025486853815, 59.23935667161019, 56.01147743963427, 61.68643712997437, 57.2362728272715, 62.628919924459154, 56.92650756528301, 72.6658768807688, 67.5206450493105, 81.74947431010585, 68.25472447179979, 93.20525846173688, 26.939158016635528, 0.7190736599506871, 0.11340421759673666, 0.22049432319979514, 0.5761682927127808, 17.772600496968916, 82.16807749963577, 52.709665452280355, 53.17996155831122, 29.94133818534113, 37.38439252299648, 46.60098968013641, 0.891980930201469, 0.09234713420512215, 0.1488428704080082, 0.07575795985758305, 0.06059846645521541, 0.044185618734768325, 0.09074050993207963, 0.04781600215562409, 0.03288336653983401, 0.04838668786349797, 0.08411065480040927, 0.04877516721946098, 0.010011089522571815, 0.06014419929875482, 0.11043037152698926, 0.16540674853228754, 0.9970490922850948, 55.732694979636904, 60.3348550488872, 44.59624667321482, 45.791385019979174, 66.88279705662882, 76.33756053063178, 73.98234982644358, 0.8344480335231751, 0.04653512995930449, 0.3085424630872665, 1.184011318029896, 28.5744059085846, 94.02883068207773, 78.30910851878505, 90.16140507113549, 79.8658815506966, 84.2925508560673, 64.61273708651143, 64.86244693879159, 57.31177060834823, 60.20589928473196, 60.94247333465084, 63.11998890292261, 64.23738587287166, 65.294241059211, 63.97503029915595, 66.19779432973554, 63.185598388794936, 66.24408614250922, 58.126533185282064, 58.93633396394792, 55.28163809930125, 56.20216346556141, 53.67263870854532, 53.427623933361424, 52.84204152322585, 54.98780942732289, 53.59031600336875, 53.743641453404585, 50.93263956808275, 46.76252857331307, 48.87365410404821, 52.020822724988385, 50.52561521530152, 52.145224617373565, 55.33825359036846, 53.70178976366597, 49.770358916251894, 50.86452761004048, 62.44450969080772, 57.83240249080043, 54.173317493930945, 60.157006940534046, 65.51354862028553, 67.78808009239935, 65.1679446620326, 68.30933955407912, 65.25450744936543, 67.07973926298081, 65.81268033673688, 65.92562106347853, 62.824497145991174, 57.83921564778974, 59.46966648101807, 55.30954576307728, 52.66622520262196, 52.934283902568204, 53.3709535291118, 56.286306150497936, 58.87516460111065, 60.983042409343106, 60.42098637550109, 60.020018162265906, 48.89354052082185, 51.01755103757305, 52.128911479826904, 51.542454381142896, 47.83592831703925, 44.55522260358257, 40.7125981392399, 42.24218522348712, 43.465882347476104, 43.62047472307759, 42.95938276475476, 47.69121639190182, 56.68706255574381, 48.40697834568639, 54.535332648984856, 53.298083736050515, 56.84820528953307, 55.196742319291644, 53.11507771092077, 49.927744019416075, 52.16345971630466, 51.57834014584942, 46.95578767407326, 48.87029655518071, 48.02566512938469, 48.060319269857104, 48.95412152813327, 51.820020906386844, 55.713102740626184, 59.89667138745708, 56.602864957624874, 52.148684147865545, 44.766677579572125, 40.131467619249904, 42.26604500124532, 46.2585981430546, 45.466267601136245, 54.111136159589215, 56.158962480483524, 55.697554465263124, 54.83873974892401, 51.354670909143266, 48.97927176567816, 50.08144601698845, 47.11485155167119, 46.85760290391984, 44.57230060331283, 48.538844508509484, 50.47559322849397, 53.18351914805751, 49.3209651208693, 54.02262787665091, 50.58698854138775, 55.5515246237478, 52.32910925342191, 55.25335388798868, 51.62756196914181, 54.4555437949396, 54.03214746905912, 57.00455488697175, 56.74585103988648, 60.71643890873079, 60.03531148356777, 61.799283719831905, 58.030133093557055, 65.18189261036535, 59.85955792088663, 65.80383146962812, 61.71421535553471, 74.0133051718435, 70.00853384694746, 83.35233519154211, 72.67943259208434, 94.94869709014894, 34.46044206619263, 0.7057879180196793, 0.01953938085916302, 0.13387124474731185, 1.0323708937052758, 19.584682564581595, 90.42724763193439, 57.7354807238425, 61.84416740171371, 36.486040315320416, 46.15620859207646, 58.02179805694088, 1.2818103475916771, 0.13407931422754643, 0.11198451111633932, 0.042819262617417884, 0.1237829929337867, 0.029781951508935423, 0.05163966955977583, 0.007459117539016711, 0.13082454371596539, 0.21875354160945262, 0.1978672268770395, 0.1534940506662092, 0.17919604005592485, 0.13152833337024336, 0.208628801028094, 0.39992838677379394, 1.4827946789803044, 68.5635797439083, 66.73424120872252, 40.687973499298096, 54.68182533018051, 74.40333781703826, 82.81523719910653, 79.9178372659991, 1.7202211387695807, 0.21504938392148865, 0.9828205719109505, 2.2693914511511406, 31.12589397738057, 94.64000655758767, 83.69139271397745, 92.59564368955552, 85.5452460627402, 88.74859871402865, 68.89639285302931, 67.83822367268225, 59.689754593756895, 64.49969437814528, 63.12071061903431, 69.16809543486565, 66.10038618887624, 70.13257488127678, 69.0580415725708, 70.62012549369567, 69.82724974232336, 70.39660530705606, 60.74331891152167, 63.73792694460962, 57.82870761809811, 57.99880512299077, 55.9311943669473, 56.935897719475534, 55.917105213288345, 55.931974918611594, 57.10872519400812, 56.00882591739778, 53.60189484011743, 48.41277560880108, 52.20329923014487, 56.21175758300289, 54.397967323180175, 55.47770169473464, 58.42523736338462, 56.37624217617897, 50.81936936224661, 51.20319289545859, 63.75343991864113, 58.89683569631269, 54.50897432142689, 62.560066638454316, 67.4019855068576, 68.38599051198652, 67.25145278438445, 71.76299433554374, 68.74371851644209, 67.54698768738778, 66.29284904849145, 69.185926529669, 64.73438547503564, 58.90043643213088, 61.649813959675456, 57.01869895381313, 55.72384219015799, 56.36500850800545, 55.18422211370161, 60.35131723650041, 62.50161547814647, 63.27838205522107, 62.98398071719755, 59.916118498771425, 45.80677247816517, 50.108125978900546, 51.364743555745775, 54.02091772325578, 48.87487788354197, 44.800817889551965, 39.747542104413434, 43.29039158359651, 43.09131168550061, 41.09961840414232, 43.20300117615731, 54.10519376877816, 55.838038075354795, 47.74130505900229, 55.453375154925936, 57.143042010645715, 58.150510634145434, 57.39901981046123, 55.1661595990581, 50.926175502038774, 52.97824974982969, 55.5505322640942, 50.40434729668402, 51.132625533688454, 50.176394831749704, 51.117575399337284, 51.608346277667636, 54.08042792351016, 56.677068356544744, 60.29542346154491, 58.81248120338687, 53.29004679956744, 45.53918054026943, 39.76550263743247, 42.59903461702409, 45.3706519834457, 46.528414064838046, 53.61288532134026, 56.63358103844428, 56.86165901922411, 57.1493923279547, 54.363524990697066, 52.92815716035905, 52.11707768901702, 49.5770017562374, 49.30433819370885, 48.22941264798565, 51.5467611435921, 55.46072959899903, 56.24968298019902, 51.91686030357115, 55.95152008918024, 52.771329033759336, 58.81133194892638, 54.45462596031928, 58.105795614181034, 54.17576897528864, 58.41511764834004, 57.89851404005482, 60.19581487101894, 59.51744879445722, 62.16422104066419, 63.686018297749186, 67.70839321997859, 63.22322176348779, 68.32655091439524, 63.97313579436272, 69.55626887659874, 62.877606038124334, 77.96712490820116, 74.4703083653604, 86.81225792054208, 74.86547147074054, 100.14947752798759, 34.005572642049486, 1.1375373601913452, 0.17018966526994783, 0.40508372949496396, 2.7189146847494188, 22.774689351358724, 101.38846797327842, 62.99538304728847, 73.024507030364, 43.441242018053615, 53.39363267344814, 69.36168793709048, 1.6170409850535856, 0.1840866534339805, 0.2748733278243773, 0.12456172896969704, 0.28046956946772916, 0.09024826779721246, 0.3221959272219289, 0.06729415918309843], [0.05323134745741564, 0.009861895814538002, 0.04703690605838934, 0.04403148950528234, 0.060254186542043765, 0.039660168826700225, 0.11689528026768278, 0.02900330357313637, 0.7283643452871231, 50.39526308736494, 46.306902131726666, 20.858605638627086, 34.22039693401706, 58.64982443471109, 71.17691378439628, 64.45085302475961, 0.7207761524665741, 0.23093233245515057, 0.11200450601116305, 0.5505189335634632, 30.633869901780162, 88.70048692149501, 80.62526026079732, 85.24009350807437, 76.89992643171742, 71.41137738381663, 57.97902853258195, 59.63849706034507, 57.46449201337753, 63.33297752564954, 61.177513522486535, 65.21480914085143, 61.40199861218853, 63.5004391977864, 60.08196023202712, 62.17816506662677, 58.898330119348344, 57.849531481342936, 53.237145793053415, 53.96407473471857, 52.19105751283708, 52.507581018632465, 53.625833065279075, 52.715670601014175, 52.56741677561114, 53.30188059037732, 52.790870281957815, 51.00647426420643, 48.233691953843646, 43.01077365875245, 46.01152020116007, 47.681488913874475, 49.56619954878285, 49.68352548537716, 50.311508717075476, 53.4257568851594, 48.737571393289876, 60.20824878446518, 56.956968692041215, 55.78859267696258, 58.99011750375072, 62.12396575558571, 64.03702728209957, 58.973808288574226, 59.54073590617026, 61.446784234816036, 59.39182312257829, 63.1826840677569, 62.59792535535751, 63.81645671782955, 63.0909437517966, 59.61265256327968, 53.57446570550242, 55.79656293315273, 54.48187466590635, 54.43105251558366, 55.65318461387388, 56.05905971219463, 58.38205206778742, 56.81835997489191, 56.98473515049104, 49.23530840104627, 35.35816669464111, 54.249482077936975, 57.95510207453082, 43.048918708678215, 46.15204303495346, 42.16833483788275, 41.84226820545812, 41.389567852020264, 43.707347377654045, 43.40211637558476, 43.594834189261164, 32.85982085812476, 50.32480162958945, 62.96391779376615, 46.62947785469794, 55.79463704939812, 57.57622465010613, 52.815071305921, 48.56335932208646, 46.55709051316785, 49.104956273109686, 48.053737532707956, 45.954940011424405, 49.60869842959989, 46.94665247394193, 49.74004291719007, 53.6146072418459, 56.892912464757124, 61.33331791047127, 62.7418488840903, 61.56016818938717, 59.598830130792436, 51.92833323632517, 42.201172920965384, 43.804743751402825, 45.13602756684826, 47.70989471866239, 55.35592386799475, 56.942655963282434, 55.20028029718707, 50.53138109945482, 47.40136108090801, 46.24540328979493, 46.826110193806315, 45.399073477714296, 41.61672015343943, 44.1686063428079, 48.030654384243874, 49.23051134232552, 50.08008887690883, 47.97602753485403, 46.994603449298495, 47.76309382530951, 48.842333978222264, 50.543583593060895, 52.670120116203066, 48.84040809446766, 51.58818529498193, 49.330998543770086, 51.29777300742365, 52.751932913257235, 54.524620656044256, 54.24219823652699, 56.11214114773659, 55.91743861475299, 61.738992967913234, 62.01306073896347, 63.979686152550485, 62.436786543938425, 62.17869458660003, 67.61013000242173, 77.97806047624158, 74.16124128526258, 78.21389690522226, 61.86612482993834, 0.3239742011552857, 0.16540665660173665, 0.38837715983390814, 0.39488262526931306, 17.74649516228707, 77.7335399196994, 58.173719298455026, 46.13199187863258, 33.775447184039706, 40.903637178482555, 48.882283318427305, 2.4284722439704405, 0.16975121782912364, 0.15555398448580698, 0.042976670703219796, 0.02049894620394034, 0.02695436886091146, 0.027437400703708974, 0.06271998225260647, 0.03674747572550851, 0.04699408557386168, 0.03620249609793386, 0.049240408585436886, 0.03909168179116903, 0.003998657686620831, 0.036718598041202755, 0.08939745054850656, 1.3416625294954547, 63.20831283446282, 52.903634502041726, 22.69012697281376, 41.55607246583508, 66.2175944543654, 79.24993607305711, 70.21767462453535, 0.8285270318869622, 0.2420519454584968, 0.09487188421189786, 0.8162714637094929, 38.7964379402899, 94.48502586733912, 82.57026164762436, 89.34735636557303, 79.37134127463065, 75.60510496939384, 62.5347085152903, 64.16275493560299, 61.8173344673649, 66.2622937848491, 65.33714394415578, 67.71182137150919, 63.93471617852489, 65.44815878714284, 63.204731710495494, 66.15851571482997, 63.2829398493613, 61.11727768375028, 58.45470220811906, 57.216955154172844, 55.677569989235174, 55.70271630440989, 55.110791421705684, 55.358296901949, 53.46461972882671, 55.802509246333955, 54.164900087541156, 53.949055979328776, 52.57043700064383, 49.07986094874721, 48.33935276154549, 52.69095182418824, 51.127577443276685, 51.788273242212114, 54.66071905628328, 55.040263283637266, 47.821560675098056, 60.96659983358076, 56.8539672513162, 57.13566795472176, 62.169629989131806, 65.18929020051034, 65.22644681315269, 64.26157905209449, 62.73540442989719, 65.0205929817692, 64.20509299924298, 62.12731938208304, 65.95878078091529, 63.89653190489739, 64.49818034325877, 65.05667486498433, 57.894191588124926, 57.68107744955248, 58.0910788812945, 57.59017259843888, 58.47636153621059, 59.48692490977626, 59.83535297455327, 61.288900990639966, 57.82910769985568, 52.674007185043834, 40.32800974384431, 51.86281396496681, 56.968680889375754, 46.41187260227819, 48.06916813696585, 42.543097695996686, 41.37768307039815, 41.986736943644864, 43.404179542295395, 43.22114998294462, 43.09881517964025, 37.06429966034428, 50.529925900120894, 60.312666200822406, 49.92763811542142, 57.76976616151872, 58.15887312735281, 54.6382164186047, 50.8303794553203, 50.401542802010816, 50.00278680555282, 50.950933502566436, 50.14393721857379, 51.07803790800033, 49.98647366800616, 51.819114838877034, 54.97703075408936, 60.928419482323434, 62.3396098229193, 63.92368255123016, 64.03517200100806, 62.82971389832036, 54.65153286533972, 44.874217202586514, 41.01899800762054, 46.43321029601559, 48.11113749780963, 56.88462449658302, 58.462876427558164, 56.45128496231572, 53.099635339552364, 52.12596577982749, 49.139743774167954, 48.734915948683216, 45.731729692028416, 45.72677966087095, 45.62159345995995, 50.008183986909934, 50.59677485496768, 51.47032983841435, 50.71509315121559, 50.43607142663772, 50.690986264136534, 51.25274027547529, 52.18452676650017, 56.55642017241448, 53.210508977213216, 54.1841628474574, 51.747708089890025, 53.657906286178104, 54.97263769949637, 57.40501319208453, 57.65206759975803, 59.20599299092447, 60.00151241979292, 63.80512499040174, 64.66338273017638, 67.42827323175246, 65.73712372010755, 67.3827031350905, 71.37195756358486, 77.82450752873575, 78.82664957354146, 81.91595538969963, 68.75514045838388, 0.8385754701110625, 0.25421921434181355, 0.27736976322147155, 1.0461260330292488, 20.88500907344203, 84.02889697782456, 64.95483052346015, 50.488744935681744, 32.42408475568218, 46.6909453176683, 64.13734582162672, 4.00843579922953, 0.20928109425210187, 0.10738014649119108, 0.05001686167933288, 0.10478467124724582, 0.09428054094314577, 0.04040402487941808, 0.01626737336928566, 0.1657707322268717, 0.11815335751781542, 0.14343744594483607, 0.22476615203965097, 0.2099666050485065, 0.1309125672184652, 0.322873026372925, 0.18625722567160286, 1.8927241597444782, 75.53152130496117, 60.21782721242597, 28.796974920457412, 49.340357319001235, 75.64565443223523, 85.24024255814092, 78.3411778173139, 1.1298989120029634, 0.3885067819106964, 0.21497367911281126, 0.7940187545553331, 38.81349240579913, 94.40488399997835, 87.98013579460883, 92.95862767004198, 81.2747420034101, 79.35535369380828, 64.7382725438764, 66.47388996616488, 66.57644425669025, 73.29698624149447, 69.0175077992101, 72.05696029047813, 67.0827437985328, 70.22845329776888, 68.82560976089971, 69.29677271073865, 67.16892611595893, 65.43876078820998, 59.97597778997114, 62.84501114199239, 58.82880218567387, 60.264942722935835, 59.05419334288567, 58.38556651146182, 57.788240525030325, 59.324707446559785, 57.527042050515455, 57.22876933313186, 55.76731774114794, 49.627874897372344, 52.23008509605162, 54.906859551706624, 54.55104566389515, 54.41384900000788, 55.61571028924758, 56.1515413561175, 49.063881212665194, 61.87045904897875, 58.835627109773704, 57.34329469742314, 64.5778593709392, 66.54475935043828, 68.84544126449093, 67.01807175913166, 65.99302307251962, 68.6763321968817, 67.41060687649635, 66.95298394849225, 68.0960802878103, 67.97671471872638, 65.87346922966742, 65.62701494463029, 59.54377182068364, 60.893934003768436, 60.69148478969451, 60.03335422085178, 61.83303963753485, 62.2582402536946, 63.65569053157684, 63.36401524082307, 59.52931396422848, 50.374286251683394, 36.621197346718084, 52.52917758880123, 57.90281688013385, 50.54061828121063, 45.588127797649754, 45.24792102075393, 43.31627530436362, 41.48410089554326, 42.801836844413515, 44.21970698141283, 43.19529371876871, 42.15376715506277, 55.089755750471554, 57.35599140967093, 53.08573838203184, 61.38102569887715, 61.009945946355025, 57.529968138664, 52.61680726082095, 51.18862129026844, 52.61337910929034, 52.9351350568956, 50.8605581714261, 55.3794070982164, 51.74386416712115, 53.75504770586568, 57.647380367402114, 61.89894722354028, 64.94868416940012, 66.94878701240786, 66.45678843221357, 65.73138921491562, 56.02050673577094, 44.16339743521906, 41.221568815169796, 46.125480744146536, 50.19629693800404, 57.65938674249957, 62.31942922838273, 58.007187228049006, 54.82196769406719, 53.44298393495622, 49.36909260288362, 53.09286925100511, 50.36304081639936, 48.299623074070105, 47.253542638594105, 54.37753177458241, 53.219510816758685, 53.34333612072853, 52.85217300538094, 53.207065136201926, 54.36576074169528, 53.45824195492653, 55.25342449065178, 59.021500387499415, 54.60610789637412, 58.30471077272969, 54.29768408498457, 57.79478696084792, 59.405167025904504, 61.08747159281085, 60.84397477488364, 62.88703149364841, 62.45852824180358, 69.05323274673955, 68.27113566860076, 71.11530119372954, 68.83822410337388, 67.52747781815069, 74.02722958595523, 82.9064715293146, 80.27704008163946, 85.83130451940721, 71.42406232895391, 0.8939532695278045, 0.331989074306142, 1.0914377435561151, 1.4504069330230838, 23.27356580765017, 93.32802080339002, 70.4050305581862, 64.58764176214895, 47.284701947242986, 55.37765379874937, 75.86873531341553, 4.671455112195784, 0.3321914747357369, 0.3105593887307952, 0.13758510110839722, 0.2329962346101961, 0.1965939274598514, 0.15147870316380455, 0.1728296655440523], [0.03736224979342472, 0.015151985740709691, 0.05599628135021176, 0.0205734099501804, 0.019421571858167168, 0.033187798389624205, 0.09123928679694092, 0.15034944359813968, 0.9920472735839506, 48.39095154116231, 48.301333227465236, 44.506110606655, 37.052685522264056, 60.13110753028624, 70.46339542635026, 66.55283943299325, 0.9249957650899888, 0.21622333705665606, 0.05584135538928452, 0.2731802428682005, 35.236039776955884, 88.62654239900651, 78.00106909967239, 81.99919592949652, 73.05464652276808, 64.685453907136, 59.917150082126746, 59.02809781412925, 56.89580717394429, 59.589345839715776, 60.28190305156093, 64.82047757794781, 62.947663491772076, 60.568985246842914, 57.068928826239805, 58.24416506674982, 55.5205810454584, 54.38629042717719, 54.53222613180838, 53.791329629959606, 53.00346666766752, 52.44277954101563, 50.74580923203499, 51.19132772568734, 51.79354490772371, 52.9747353061553, 51.515303734810125, 48.67683741354173, 46.941067018816554, 46.10703383722613, 42.8416802806239, 48.67682564643122, 47.139511492944536, 50.37253687458654, 49.76243180613364, 51.57844604984407, 50.69250422139322, 58.6129423879808, 57.57767984944006, 56.524845092527336, 58.1515500622411, 60.82363336317001, 61.987353524854115, 61.19969452581098, 60.92571304690454, 61.26217396028581, 56.36836605687296, 56.57951901035925, 59.92473594604, 66.45356424393194, 64.23058448299285, 65.061879850203, 58.47772259866038, 56.70259906399635, 58.16201494586084, 59.46192372229792, 59.19800704525363, 58.25897985889066, 54.268466349570986, 54.75024715546639, 50.05043968077629, 35.28297093606765, 41.142556590418664, 64.39748525619507, 43.96663173552483, 41.92464190144693, 44.4155470017464, 43.99263704976728, 41.72842141120665, 43.54588693188083, 41.43850726466025, 44.682334853756814, 41.34278574297505, 37.579189192864206, 32.81724549108936, 55.849895400385705, 57.75124472956504, 50.483033964710856, 57.323247463472434, 51.00431696061165, 52.144989275163226, 48.12420683522379, 50.55210690344534, 48.50171535245834, 52.19622327435402, 52.780997676234094, 55.31819066693706, 56.993125100289625, 54.909193361959154, 60.21496780457036, 59.29903553378198, 56.62694046574255, 60.933781362348995, 61.527032006171446, 60.06880852483935, 52.40012768776187, 44.388772902950166, 45.75748005220967, 50.68922904229934, 55.36545914988364, 50.71868211992326, 51.099567797876176, 49.10065343303066, 47.61114120483399, 46.7425048735834, 48.0667951030116, 45.2744480102293, 40.99733475715884, 42.79702801858225, 46.10697500167355, 48.928633966753566, 49.316128838446836, 51.318679240442094, 48.092623910596295, 48.4485476247726, 47.950924365751206, 51.87789547827936, 48.688526076655236, 50.77551334134994, 51.52918108047978, 51.86344154419438, 51.82268027336367, 54.06178882045131, 51.88597163846416, 55.26475229570943, 54.526299430478005, 60.980543859543346, 63.50607172135384, 67.51782878752678, 68.69409268902194, 69.03405235659692, 71.00891866991597, 71.92278385162354, 72.1608324973814, 77.81134405443746, 73.17609879278368, 84.20616457539221, 9.803738709419004, 0.485502491675077, 0.48250889585864165, 1.2997958857205607, 21.338823380008822, 77.78772354125977, 54.19962483067667, 50.67091157359462, 43.30198218745571, 38.728518178386075, 62.63629005801294, 3.1223547266375635, 0.1164665927870139, 0.15244593513348412, 0.011348392713003823, 0.06352095399051905, 0.0720125176913796, 0.10378721710895339, 0.07830035286925494, 0.05238689639936051, 0.005186810261464768, 0.056501493353637, 0.038808229259185256, 0.06877641674251327, 0.06388704825733459, 0.08965745312912811, 0.14418326318264008, 1.7536121534724392, 60.48657232715238, 54.51878416922785, 41.80520965207008, 40.27903895224295, 70.32984656672325, 77.66157227177774, 75.29856389568698, 1.042136124545528, 0.3356524148295003, 0.13415291995531128, 0.28946292075899344, 39.36845679436961, 93.7221170240833, 80.24838324516051, 89.23352133843207, 75.4948785228114, 70.29332930041899, 62.61659191500757, 61.33733049515755, 58.73424953030002, 62.722746941351126, 62.52281196655766, 67.97035263430688, 66.35869779894429, 64.09507443827968, 62.348140978044086, 62.67257198210686, 58.33215167445522, 56.801274130421305, 58.28499694024363, 56.97064991920226, 56.41669750213624, 53.90494108200074, 52.53727728320707, 56.454179671502885, 54.980937434780984, 56.080950460126324, 52.979708871533795, 51.368383515265684, 50.39643195367629, 49.58012004052439, 47.70227355341758, 51.0669493675232, 49.11016125832835, 51.81828329640051, 51.67454804143598, 54.243414171280406, 53.15767072862195, 60.82525722442135, 59.04564257591002, 57.658253177519775, 60.60532208411925, 62.91741809537334, 63.92280786268173, 64.19343571509084, 62.254510079660726, 63.5834796967045, 60.14836203667426, 58.24974659950503, 63.83209520770658, 66.78669114266673, 64.4290211123805, 66.76955038501372, 61.31562017625379, 58.69649279502131, 59.590789271939194, 63.98125117824924, 62.49516710158318, 58.75013120712773, 57.136621090673636, 55.4727908872789, 49.23172727707894, 39.652565833060976, 42.20088266557263, 61.445646747466064, 47.91873347374701, 43.21250507908483, 44.32639937247, 44.0082480830531, 42.665169700499504, 43.44059090460501, 42.45668003636022, 46.27714310922931, 41.226597293730705, 39.581343435472064, 37.86793055072908, 53.54465176982265, 58.7402311448128, 53.18666488893571, 59.60609828272174, 55.25657023152998, 56.587889348306966, 52.6930542146006, 52.64556607892437, 50.92974093652541, 55.810330452457556, 55.76079876192155, 58.338705955013154, 60.721557601805664, 58.361114455807595, 62.487628306111986, 60.81452169725972, 59.85338803260558, 62.793686928287634, 63.17278792781215, 62.929804940377515, 54.2821083530303, 45.29942958585678, 45.405690516194994, 51.195505049920854, 56.00601357798423, 51.36692439356158, 52.905097546116004, 51.3719371826418, 50.70699737917993, 49.940562325139204, 49.47969167463241, 47.788153848340436, 45.52612296996578, 45.19631047402659, 48.007602614741174, 52.643251880522705, 52.08107033083516, 52.68305217066119, 51.45056109274588, 52.528353891065045, 51.84976423940351, 54.55368934139129, 53.12135742556665, 53.18776707495413, 53.29976643285444, 54.9862914700662, 52.70044003763507, 54.22814830656975, 54.901423146647794, 58.43426665952129, 58.80894714786161, 64.4208312034607, 66.66232847398328, 71.56333784903251, 73.2248067855835, 72.50008613832536, 75.11478516363329, 76.51412210156842, 76.17311123878726, 82.352460276696, 76.54630907120244, 90.01976828421317, 12.719452188860986, 0.8840016648173333, 0.3114774991427699, 1.8219205977455264, 24.30649845830856, 83.5049153912452, 62.67814959249189, 58.936228059953265, 35.09051592119279, 41.81096376911287, 77.98817234654581, 4.067052189380893, 0.18704021349549296, 0.10336175485844575, 0.02810969265298017, 0.09722346004338996, 0.023594295733698437, 0.02268691438310329, 0.06730051005199071, 0.1717345888215688, 0.10294547034127098, 0.11725333444173298, 0.13819129116112186, 0.17703674463254793, 0.20401408655508874, 0.20995234049135642, 0.31137453692574657, 2.292784466858833, 73.10147962262555, 63.89713202753375, 62.20711215849846, 50.896059543855735, 79.2305987881076, 83.02124008055657, 82.54886119596421, 1.5507373622348233, 0.45479235569796256, 0.2502073957434585, 0.5570974837868445, 41.858157727026175, 96.25822744061871, 82.97378724621188, 90.3326871318202, 80.96008162344657, 73.12320955338018, 66.18186950683594, 64.94036874463482, 60.95848444969424, 67.46421783201157, 66.64053578530589, 74.18788986821329, 69.8692818610899, 67.64765924023044, 66.27804602346113, 65.42268691524383, 62.879367182331706, 60.830877980878284, 62.30386526353898, 60.643863293432425, 61.50651408780006, 58.71138995693576, 56.18971386263448, 57.16856879572715, 58.391563815455285, 57.47965981883388, 56.63973523724464, 55.03250483543643, 53.02555353410783, 51.66335751933437, 49.55442067115538, 54.93494372214041, 53.61896107273718, 55.54549201842278, 55.24398334564702, 56.120833120038434, 52.759601146944114, 60.73210877756919, 58.98419864716069, 59.04791362823979, 61.50233284119637, 64.78645493907314, 67.10908643661007, 66.72790265852406, 64.70840369501423, 64.79805731004285, 63.16207201250138, 60.42611683568647, 66.5819904881139, 72.0397646196427, 68.60183069782873, 70.93458191041024, 63.43370006930444, 59.76995529667024, 63.63669841520248, 67.52874082134616, 65.25952416081583, 60.33648675487888, 60.72154975706532, 56.61332199650427, 50.81480372336603, 39.5254300486657, 40.57698219053207, 62.702742853472316, 54.12331904134443, 46.81557862989364, 45.163441011982584, 44.875480205782004, 42.253791516827, 42.996821788049516, 42.99750820282967, 44.68618662126603, 41.92890944019441, 42.237737255711714, 45.50229064879879, 59.91334930542977, 60.33337239296206, 55.567406300575506, 60.36056226299655, 56.49966347602106, 59.664937757676654, 55.28640770143079, 55.883749377342966, 51.45998654826995, 56.865632380208666, 59.86215060757053, 60.38120569721345, 63.176616161100334, 59.09811212170509, 66.04050728582567, 64.4216666683074, 62.7718157922068, 67.14503103686918, 66.77818744413315, 66.94775935142272, 57.09540874727311, 45.490390177695986, 46.00041204883207, 52.950110666213504, 57.737504666851414, 54.10613121524934, 54.61615700875559, 53.93585328132876, 51.81691438921037, 54.55898846349409, 52.576273487460234, 51.318247779723144, 47.149815559387214, 47.96078128199424, 50.24154932268205, 55.29001235961915, 55.03278332371866, 57.134930549129365, 54.16480595065702, 56.42842146658129, 54.786874248135476, 57.97393337372811, 54.45112720612557, 58.01652246905912, 56.97706299443399, 59.32676669090026, 59.72390667084725, 59.800573318235344, 58.142112839606504, 62.50890324192663, 62.33672295847247, 67.68612984688052, 68.7659191316174, 74.55199564656904, 76.87032822639712, 74.89201807206678, 80.32984302889916, 79.4205121071108, 80.35060805659141, 86.22432601067328, 79.18078468691918, 94.14999269670056, 12.4419484215398, 0.9230398506887498, 0.9911676820728087, 2.8883118014181814, 30.18652750599769, 91.48615421787386, 70.2146073310606, 71.08887226350846, 61.23707079118299, 52.7575772039352, 89.12588365616338, 5.500157302425754, 0.43697814547246505, 0.2600071465055789, 0.1866826342959558, 0.16115289211513537, 0.20077192585074133, 0.25414050646847297, 0.13996722086543037], [0.024777890085392905, 0.10986738117231477, 0.01602019988856609, 0.0781979728790541, 0.10340465578220545, 0.011938096553597961, 0.08113778166232571, 0.09341442491859199, 1.645338434365488, 50.55697456482918, 51.66991572226248, 37.69635823465163, 30.626715498585856, 60.65467334562733, 72.37642949627292, 63.90795776920935, 0.9690911731412335, 0.39841067466524344, 0.0635342226333676, 0.3542560020521764, 41.07152246659802, 89.32663840632286, 79.50181499604257, 83.11718125497141, 70.89343624730265, 63.09274019733552, 59.073165847409165, 60.965148556617, 59.59584520709131, 61.62992754290181, 62.966867416135734, 59.66894249762259, 58.28024694996496, 58.78245938208796, 55.263724634724284, 53.50028191843341, 54.38819277671076, 54.40531392251292, 52.379739207606164, 53.011566362073346, 50.5091961737602, 51.112288044345, 50.824409607918035, 51.95172625203287, 52.89605256049864, 52.67077122965167, 53.33743687598936, 50.82866145718483, 50.69037045201948, 47.8285817177065, 43.685205598031324, 46.72505424868676, 49.83394053674514, 48.93163850230556, 47.4264838618617, 53.12746063355477, 57.523900232007435, 60.718047080501435, 59.511737823486335, 61.59454384157735, 57.766581196938795, 57.6723893996208, 60.80165240072436, 64.83162887634771, 64.16903857261904, 64.05057514867475, 59.649036468998084, 57.551764749711566, 56.59716967613467, 53.092061242749615, 59.823142636206846, 59.14834199413177, 62.129586512042636, 59.78805311264531, 58.94076231987246, 57.78318458987821, 58.637590562143636, 56.29695930788594, 56.404079237291896, 43.81507527443671, 42.799467732829434, 41.410313267861646, 51.06717686499319, 45.160146221037834, 36.31154975583477, 49.00954854103827, 42.350073937446844, 44.44237209135487, 39.9828411686805, 42.27671777048419, 41.64547112680251, 45.56733531336631, 42.32268402653356, 39.149011950339045, 34.67737267094274, 33.68323226128855, 54.57558793406333, 54.521835773221916, 56.65149058065107, 57.59252602054227, 55.03160661266696, 57.09703653089462, 54.76447359208138, 56.4858292764233, 53.86196367202267, 59.640728888973115, 59.034087273382376, 60.78168753654727, 58.847464822953754, 59.96554428531278, 58.286252098698775, 59.75641919720558, 58.15206781510384, 60.09528060113231, 58.90627684131746, 58.694370792758086, 49.493396436014486, 46.30998511468211, 48.38243999788838, 53.64047527313233, 44.399735927581794, 48.05287461127005, 51.07356248363372, 45.581922608037154, 46.12602595360049, 46.081875754940896, 42.17696405226185, 42.83279218981343, 44.75118029502131, 47.15311035033196, 50.160826944535785, 47.70869447338966, 48.65764133391842, 48.97986796594436, 49.97547534204299, 49.43666327384211, 51.59391195543351, 52.56773056522493, 51.521116687405495, 54.09969852816675, 50.6963756007533, 50.76536616971416, 51.58487481455649, 50.07145966252973, 55.390962400744044, 54.98889200149044, 60.40665403489144, 67.71513185193463, 70.85934300576487, 76.33952171571794, 75.67314240240282, 73.17867186761671, 78.19219050868865, 75.62571310227918, 78.18103528791859, 76.86229521228422, 82.48532664391303, 37.71374610162551, 0.2980294385023656, 0.6925159043842747, 0.9527114165886756, 22.928030490875248, 76.99567933236399, 55.21961758213659, 41.87877762702204, 34.35089418965001, 38.99567865556286, 61.35285523629958, 5.063079259087963, 0.19372125096138448, 0.2591217020826955, 0.05424744817578504, 0.12972883880138397, 0.047950086694571285, 0.04887015829163213, 0.046222259651028344, 0.04256088797363543, 0.12768211233760082, 0.08583816008702402, 0.0145009383671887, 0.047008606770466414, 0.06319117229131442, 0.21192133967434207, 0.2454320939197656, 2.3493354839663354, 59.8338467844071, 58.77959997423234, 39.48304883895382, 34.57608138361285, 69.13624578906645, 78.64587537703976, 69.52772186648461, 0.5148691852246562, 0.1949100815240414, 0.07773254382153673, 0.4850406938743207, 44.83868837356568, 93.09280410889657, 80.38856875511908, 84.64135939075102, 73.42456525371921, 66.89967893785047, 61.126632536611254, 65.18424995483892, 64.9629419849765, 63.99583062817974, 65.25201674430602, 64.46980591743224, 61.59528909191009, 59.954181178923584, 58.28196102573026, 55.27372667866369, 57.23390371568742, 58.19934414279077, 56.816606675424886, 55.72693694022394, 52.93480165543095, 54.75420482697026, 53.09930978282806, 54.656761384779415, 55.242135909295854, 55.211411983736106, 54.05814101619106, 55.61718510043237, 51.9797751211351, 49.05671896473054, 47.78449427696967, 49.04180219096523, 51.905132416755926, 50.27883537354008, 50.02304584749284, 54.43271560053672, 59.22464778346401, 60.731771453734375, 59.26795467253655, 63.22020938319545, 60.51747275936989, 61.593833892576164, 61.951291253489835, 66.2649296176049, 69.64055276686146, 67.55112971028974, 62.095979644406235, 57.24425485057216, 57.64298731280912, 58.48540259945778, 61.68242846765826, 61.615285335048554, 63.89802632793304, 63.321841916730335, 60.484528772292606, 61.72926941225606, 62.42643540905368, 58.46703806231099, 56.09113685546383, 44.662256240844734, 45.24821519851685, 42.980689079530784, 48.59830371795162, 50.46247290026758, 40.91646332894602, 50.425751670714355, 41.67515954663677, 42.86317879153837, 40.025642072000814, 42.26601754465411, 41.02138673105548, 45.72890558550435, 43.473385841615745, 39.481703465984715, 38.31198992267732, 35.0013526024357, 49.27475960023942, 53.41326021379041, 59.97302816760156, 62.572171072806086, 56.019686960404925, 59.89872670942738, 56.820780077288234, 58.574177603567804, 57.490156081414995, 61.24057346774686, 60.63830529489825, 60.24016903292749, 61.55379433785716, 63.035489282300404, 59.579096686455514, 62.60447179117511, 58.48337473407869, 61.808819001720806, 60.244334590050485, 60.823817714568115, 52.206888198852546, 46.087257246817316, 48.295202562885905, 54.4222624840275, 45.00378485648863, 49.59545650789815, 52.633147854958814, 48.44830443782192, 47.17373417269799, 49.27238656628517, 46.483487236884336, 46.656299021936235, 45.000992128925944, 51.5593715636961, 52.09009178223149, 49.05456166113577, 51.58730668406333, 52.582392384929044, 52.52254486083985, 53.0273146783152, 55.33762601114089, 55.36640444109517, 54.057627185698486, 56.01802387545186, 52.87326358979749, 55.81474311890141, 54.78419526930779, 52.83169038834111, 56.569438519016394, 58.30677393944033, 63.197318430869814, 71.09018233514601, 74.16379867061492, 77.27112385534471, 79.73158744073685, 77.50107672906692, 80.45681015137704, 79.50592563998315, 81.86451742725988, 81.01872105752268, 86.12462720563336, 45.634831459291526, 0.4055744241322241, 0.2956933606295817, 0.8494813752270515, 27.264567652056297, 85.05865250864338, 61.395350194746456, 49.47628313495267, 40.82340117423765, 45.36379960275466, 72.24557922732446, 8.41699650210719, 0.49836158391929447, 0.25360545534039697, 0.09033891898129257, 0.0923346852763526, 0.005154745651394009, 0.10174761526286603, 0.035028140766606215, 0.12614126437373702, 0.2662613351018198, 0.17171560516280515, 0.170376330253578, 0.15179358062244233, 0.0981834754648228, 0.4038856905554572, 0.38543863041747006, 4.124611991067087, 72.05510893175679, 67.89214841781124, 48.283313858893614, 44.497846172701934, 78.94068071919104, 83.80611419677734, 78.03145962376749, 1.1730462096391188, 0.35255881086472546, 0.3897029209521509, 0.33911360007139946, 46.00664861740605, 95.44437485356485, 83.76291321169946, 92.34516113035141, 78.59771651606407, 70.87753495862408, 64.81704550404703, 69.31449397917717, 67.90439405748921, 69.61650079296481, 69.12017191610029, 68.46164518787016, 65.50749640310964, 64.98081622585174, 60.905328489119015, 60.8857637066995, 60.84857571509577, 61.89460123738935, 59.50570521816131, 60.22404809151927, 54.938089463018606, 58.458863842871885, 57.520264194857695, 57.351531674785, 58.471576244600364, 59.132213207983206, 56.21137319072601, 57.99147029076853, 54.75898619621031, 52.085447695947465, 48.675244931251775, 54.73913900313839, 55.45960387875957, 55.07853777177873, 51.82202523754489, 57.375481667057166, 62.660973533507324, 63.184213792124105, 60.95133396887011, 65.32631428011003, 62.51175872741207, 65.11267454393449, 65.27689633830902, 67.77710530065721, 71.39510739234187, 71.1981338070285, 64.62435514696183, 61.61295936953638, 61.526231842656294, 59.89687142833587, 64.63531424922328, 66.84871950457173, 66.06419840166646, 64.77333853321691, 64.81287210218369, 62.838307811367905, 63.404462722039995, 63.154509682809156, 57.60882739097842, 44.58062779518866, 46.1340158216415, 42.425340298683416, 55.142115469901796, 58.05725628329862, 44.538281886808335, 49.83087716564056, 42.83693813508557, 43.39067874416229, 39.95378817281416, 43.288453932731386, 41.73556404729044, 46.655887173068145, 43.5700761887335, 40.90084445091986, 42.94051224185575, 45.18359807229812, 56.170286363170995, 59.245067642581084, 61.579717282325994, 60.82990915544572, 61.06268613569198, 64.36971487537508, 58.871277532269886, 59.986466207811915, 59.2456324638859, 63.65154850867487, 65.13828762115972, 64.81987353294127, 64.0234519589332, 63.34205389022828, 65.29817127412366, 64.68805836093041, 62.28560663038685, 65.6899493740451, 63.471119480748335, 62.48713800984045, 52.395389464593705, 46.737221440961285, 48.10470481072703, 55.993446303952126, 45.693651322395574, 50.70559317065824, 55.10720245299801, 50.54194796469904, 48.976737914546845, 51.51490365305255, 48.63379332327074, 48.53836597934846, 48.028995221660985, 53.48864424613215, 55.86456506483017, 51.11284502090947, 54.15835365172356, 56.37675992904171, 56.512313119826786, 55.276413502231726, 57.982648880251, 58.17604918633738, 58.200054091791955, 60.85192149685275, 56.16502254239975, 59.07318938163019, 58.2530100114884, 56.02620593963131, 61.17833722022272, 60.662133693695075, 66.81913698873213, 74.91406963717553, 75.74227809906006, 82.53223819117393, 82.39882269213277, 80.50774605043473, 84.37069231464018, 82.55182650781448, 84.46093820756482, 85.0334708921371, 88.24545275780463, 46.65035663112518, 0.9442182594249326, 1.3563049824968463, 1.520664795271812, 30.152906910065685, 92.13237254850327, 67.80203588547246, 58.91208194917249, 50.145710129891675, 53.76072729787519, 84.48015782140916, 8.581499726541582, 0.619706233903285, 0.4586542355677774, 0.1412994937310296, 0.16329401593294837, 0.15653598663066665, 0.16600391406926418, 0.17542773016518162], [0.022944145640658758, 0.03294597507544583, 0.06249264183063662, 0.07997253894685738, 0.17425045220842286, 0.05404927272109255, 0.04674075178862099, 0.13225168891010747, 0.5393773798019655, 45.36217966387349, 51.18912727602067, 33.59094281350413, 47.12074687404018, 55.03590553037582, 81.45976020443825, 41.70348690402123, 0.18851911558979945, 0.2150279487813673, 0.025430060735332872, 0.7784473126934421, 46.58608859585178, 95.16438038118424, 74.23085551108085, 79.79063480131089, 65.18106499025899, 65.49190105930452, 62.86805898912492, 62.08804076717746, 59.76075341624599, 60.52108918466876, 57.634581673529844, 57.93660025442801, 56.94918670961934, 56.01780030035204, 52.79180380605882, 55.12629655099685, 55.96413050928424, 58.15748068594164, 56.10361391498197, 55.05144988336871, 55.490225822694846, 56.45481117310063, 56.2070389716856, 54.330992852487874, 51.071134536497055, 51.91355374551589, 50.43895829108454, 49.47052509553971, 49.6348371044282, 46.076992404076364, 43.78103694608135, 45.90301567508329, 45.45406902990034, 47.53436473108108, 48.097934799809615, 48.08358676971928, 54.40177202224732, 63.37851624335013, 65.18934511369275, 63.5685040873866, 61.05109945420296, 57.380992597149266, 58.570698461224964, 58.87994204798053, 64.27897476380872, 63.97038229050175, 65.76383113861084, 49.596872483530355, 41.983116595975815, 53.73065056339387, 55.07625102996827, 55.5663590277395, 52.951895344641905, 56.08517093043174, 56.442608679494555, 58.75623049274568, 55.02007092199018, 55.454340057988325, 45.7605081219827, 41.643329512688425, 48.725623853745006, 42.9609634799342, 32.52824917916329, 36.92528693906723, 45.98561294617192, 47.25286799092447, 44.249662122418805, 43.12589130093975, 41.03078080761818, 39.45782407637566, 38.77040516945624, 45.02724063011908, 46.79683362284015, 41.530353484615205, 37.141688023844075, 27.321696973616078, 33.13776393090525, 50.388689194956136, 48.012446741903986, 60.00533673071093, 55.44575398968112, 59.727495639554924, 55.680919693362334, 60.31305059309929, 56.28171305502615, 59.58100688072943, 58.499099516099506, 62.02892672631049, 59.50824691403297, 62.86496816142913, 57.6152483109505, 58.570196397842906, 58.84109489379391, 61.209159205036784, 57.25606118479083, 54.93614396741314, 54.47388479786535, 50.01355371167583, 53.9748534079521, 51.20020404938729, 44.37214989815989, 46.64288843831709, 48.932560259296054, 48.300497762618534, 44.268289458367136, 44.63976929264684, 42.30420574065178, 43.95272301089379, 45.73205524875272, 46.34337232958886, 48.02766553817257, 47.807569580693404, 47.768330189489554, 48.335869696832475, 49.062629976580226, 52.97088746101626, 53.14347959333851, 54.60349559783936, 52.63363422886018, 55.109916733157256, 51.389026949482584, 53.504369028152965, 52.191543886738444, 52.8177071386768, 49.992780839243245, 53.949965969208755, 58.91440006994433, 67.18065400277415, 70.83200408566383, 75.73575127509334, 73.99017103256719, 75.91404653364613, 73.17432588146579, 78.53735908385246, 76.60894932285433, 82.37048749000796, 73.96883333882978, 65.6483644054782, 0.49784165536684377, 0.2035805880422554, 0.5319842023234214, 27.28046109599452, 81.21010918771067, 54.599675209291526, 45.38096781699888, 33.275678388534054, 28.643963260035363, 71.94839692884877, 10.759517358195398, 0.44359628711977317, 0.25735764674121336, 0.14128409536375156, 0.1373027670647829, 0.07892114455781638, 0.08255090744745347, 0.012057790130887543, 0.03268412239248714, 0.010609539214431519, 0.08767180685554782, 0.04570822231471539, 0.16415232552155373, 0.11475480762460541, 0.11927740002471594, 0.13365018241588147, 1.4587626846567279, 55.06879460427069, 56.82433766703452, 32.9226101598432, 54.486969824760195, 62.50760101502942, 87.29620779714277, 42.42266131985573, 0.45153277415421705, 0.22119011489614365, 0.09284018073230983, 1.2787985801696777, 49.58766668073593, 96.91985284128498, 75.53251758698495, 82.98367161904612, 68.04362250912574, 70.66688799089002, 67.2047765793339, 64.34338792677849, 63.77415003315095, 63.50304365158082, 60.04955360966345, 60.908215353565836, 60.01087903976441, 58.78293398887881, 57.036498669655096, 57.39294013669414, 56.83480255065426, 61.8237671544475, 60.08361939461001, 61.53601031149588, 57.661108663005216, 60.48874532022784, 59.34815145307972, 58.3537757012152, 53.97629684017551, 55.56551964052262, 52.842320011508086, 53.66488810508482, 52.19746666569864, 50.80104404880155, 46.358567591636415, 47.67532294796359, 47.499071244270574, 50.49652299573345, 50.61618274258029, 50.52912965897591, 56.07392941751788, 65.40795449287661, 68.0879060683712, 65.78335277495846, 62.43052251877324, 61.56297268406038, 60.25583890176589, 61.0579792914852, 66.91020657939296, 66.80857796822825, 68.11418594852572, 50.03650742192423, 42.47384825060445, 55.39381004148915, 56.6065441408465, 56.20070826622748, 55.3252980016893, 57.550109509498846, 57.54586942734257, 59.09915154980075, 57.08580678509128, 56.383420113594305, 44.62750011874784, 44.41127946299892, 46.91656397235009, 41.74643293503792, 36.52815480386057, 42.523870237412, 46.111238618050855, 46.96475421228717, 45.538364687273585, 43.352745502225815, 41.36568061767086, 40.6412031573634, 39.805091119581654, 44.35728411520682, 48.07227073177215, 42.25430534731957, 38.090929062135764, 31.669620775407363, 32.26529544399631, 49.77572079627745, 52.64145543498378, 62.52598124165689, 61.55646154957434, 61.87442456522296, 58.13859055119177, 62.852020417490316, 57.79386128148725, 62.049985931765654, 60.00794510687552, 64.15608690631005, 60.73572912523824, 64.65021533350792, 60.57483742314001, 61.88004139930972, 62.8389314682253, 63.99736035254694, 60.18158843440395, 58.65906946120724, 54.55379132301577, 51.14060363461895, 56.539416697717485, 52.53913256429857, 44.66704153245495, 47.098130487626605, 48.10594427970148, 50.72276530727264, 46.342379969935266, 46.68626593005273, 45.210489842199514, 46.87406116916288, 47.669184438643924, 48.53981333394205, 49.95224706588253, 51.19469704166536, 50.209374120158536, 51.26773941901423, 50.31529380429176, 57.07584004248343, 57.94784961208221, 58.35297161532987, 56.26178741455079, 60.08585514560823, 54.01454387172576, 58.0823084615892, 55.91972143419328, 56.18560714106406, 53.872554071487926, 56.513227032076934, 60.845124029344134, 73.06096938348585, 73.30428969475531, 81.11000245617282, 75.51725956701463, 79.51457054384294, 73.85146817853375, 81.47523003239786, 78.61426891819124, 88.38502637801632, 74.9989575724448, 75.55374545435753, 1.0350469307553385, 0.2265552737780156, 1.2914436887348852, 31.578661011111354, 87.9435008571994, 61.67631349255962, 51.755913688290505, 38.666278008491766, 38.64874501382151, 79.25505084376182, 13.974726353922199, 0.8287376754226223, 0.39786381046137503, 0.08267086149463732, 0.13195247028864202, 0.023741702541648865, 0.026430360890263994, 0.05695187261388187, 0.13541026942191586, 0.1662961612906187, 0.2782275671920469, 0.15710849945823993, 0.44269579673005693, 0.24297826833301978, 0.2691709063947201, 0.27151841429933427, 2.0370742462335096, 69.37584769341254, 69.16553020477295, 44.2786798169536, 62.307101218931145, 71.13954144139444, 95.85666302711734, 50.959044964082786, 1.0353266447782516, 0.4940886212693107, 0.2037691376021793, 1.7773765686058232, 53.486969394068566, 102.33080956243701, 80.8503415507655, 86.12738855423467, 71.49715177474484, 74.73696677915513, 68.92315126234486, 69.20336538745512, 65.97466638011318, 68.22544005609328, 62.55610504458028, 64.99778047684701, 63.55420312573833, 64.22929794557633, 61.87902158306491, 61.228284681996996, 62.340331539031006, 66.1075484368109, 62.25793430882116, 63.03378697364562, 60.745072210988695, 61.89258906149096, 65.84988794019146, 61.53626134318691, 57.16886689586025, 60.02566245294387, 55.95864311341317, 56.22251664438556, 54.475132111580145, 54.1623427021888, 49.704055170859064, 51.65413210468908, 49.98595983751359, 53.003933429718025, 52.362190523455226, 52.8624653047131, 59.127525975627286, 68.64784794469034, 71.1851272275371, 68.06912575998615, 67.67977560720136, 64.80139524705949, 64.06158916411862, 63.997619228978316, 67.97707557678223, 68.50623469198904, 72.35701376391997, 54.54901779851606, 44.885392035207445, 54.75106300846223, 57.97371372099846, 57.64154780295588, 57.103853610254106, 59.801322490938254, 59.9343143740008, 62.36691736405896, 60.95733911760392, 59.47872715611612, 46.268592342253655, 45.5567959047133, 50.44931334833945, 49.12441515153455, 43.33362394763578, 46.41019382784444, 46.619071806630785, 47.82517710039693, 46.352915456218106, 43.14022364154939, 42.46132804501442, 40.66903237373599, 38.66851768186016, 45.53226540165563, 47.96721789144701, 43.50743985945179, 39.82690734248008, 37.27501330837127, 40.45151341346003, 52.56800905350716, 56.611494172003965, 60.73932593868625, 62.57157879491007, 65.22463860050325, 59.98008843391173, 65.36751485640004, 59.860385540992986, 64.34501963277017, 62.382391114388746, 66.9349096667382, 62.91316232373638, 67.99984101326235, 61.867960499178984, 64.21922529897383, 64.61600442086497, 65.96895540914228, 61.62280059629872, 60.42542649853615, 57.72753792424356, 50.48395179933118, 58.0470581208506, 52.56797375217561, 45.342450141906745, 47.568763917492284, 53.252062566818736, 53.01731655674597, 49.129361260321836, 48.78220796585084, 48.485162950331166, 49.258615124610166, 51.17643840851323, 50.12678469381025, 50.995664212011526, 52.31219991560906, 53.15291289360293, 54.06239678782802, 53.93457066628241, 60.2587846017653, 60.30564123584379, 61.59724635462607, 58.526183482139345, 63.016681517324145, 56.10651646890948, 62.60233802180137, 58.823126516034534, 59.24351046162268, 55.81989319093766, 61.19274800823581, 63.91351184537334, 76.97449068869315, 76.4407737793461, 84.19418565688595, 77.49357715729745, 82.35371543515114, 77.34171082896572, 86.46343369637766, 80.48287822354226, 91.56383283676641, 75.62117884235998, 74.64205326572542, 0.7199835272565965, 1.0833819306665853, 1.8242140811297203, 35.46893442830732, 95.73135114485218, 69.0913660295548, 63.71455746312296, 47.39300251007081, 42.45837450027466, 92.03050075038787, 14.744190458328495, 1.003923658882418, 0.5819546467354221, 0.2968157100821695, 0.3110762529315487, 0.15828651285940604, 0.15757592034436044, 0.19616654232865383], [0.11831825028263754, 0.03010312046465134, 0.15852882646985594, 0.04644271294255892, 0.03838131910250072, 0.022673165020082268, 0.03327430120759434, 0.1371043809359112, 1.4621241558944027, 48.360933642233576, 46.960729860490375, 52.732968253474084, 59.488384031480365, 50.47136491344821, 86.48142953072825, 20.19329320999884, 0.4078071107787471, 0.1374497793374523, 0.2705512129731717, 1.7226944383113616, 43.53626143547797, 93.79886211887484, 72.95944275394564, 78.425948081478, 68.2241770528978, 72.21082702759774, 65.3719549794351, 61.93754726840604, 55.32401146427278, 55.71573072864164, 55.22520303726197, 55.80732199453539, 54.316138836645315, 53.671167819730705, 52.847368101919855, 57.122986931954664, 56.416862241683475, 63.57506229031471, 63.53260263319939, 63.94798163444766, 63.42254877090455, 62.522003958302165, 59.42213912164012, 61.184393359768784, 56.13560476610738, 53.62202052147158, 48.89206570963706, 52.322919753289995, 51.119360077765684, 46.45523832690331, 44.03499472525812, 45.02180422506025, 44.52955069080476, 46.802364164783114, 47.14697576338246, 49.392897467459406, 52.4206809074648, 57.89844343739172, 57.773657152729655, 54.53454817495039, 51.11280187483757, 59.59316230589344, 54.21171357554775, 58.75803478302495, 60.54043431435863, 63.70877588948896, 58.00152724789035, 44.74215492125481, 48.89145774226035, 55.81667292502619, 54.634886326328406, 56.590168245377086, 55.71995512131722, 51.34210755748134, 52.12920957996, 50.55635090797178, 51.19627383447463, 46.28097134251749, 42.69476398344963, 44.921226809101725, 31.633503590860677, 29.780289588436005, 36.60553140024985, 48.53902493753741, 50.54572520717498, 51.897679913428526, 47.58963092680901, 45.562165629479196, 41.52276762070195, 42.49174602570073, 42.846512640676195, 48.001628844968735, 46.10661022124752, 47.802360673104566, 42.54922051583567, 35.13002203356835, 26.85282272677268, 37.760571356742616, 42.57168000744235, 50.798290544940585, 56.83293550245224, 55.57727890629923, 59.97091008770851, 57.09752290479599, 60.24718223079559, 60.22164760097381, 58.34988471000426, 58.087646807393725, 59.35456452831146, 60.580893562686065, 53.19540000730946, 58.37711772611065, 62.04931912883636, 60.48539561610068, 60.23592110603087, 55.58875183905325, 56.35008781186996, 56.8115899639745, 59.59081280616022, 59.12536082729217, 44.59332842980662, 48.282313654499674, 45.289109829933416, 47.6247126056302, 45.50695826930385, 46.94469521122594, 43.522752792604514, 43.59690520071214, 45.59629809471869, 50.42718725819742, 46.60982678013463, 50.7563643301687, 49.14838867802774, 51.09490409974129, 51.406622702075595, 56.61899374377344, 57.273150951631614, 58.74601664081697, 58.43243099028065, 58.93023075595979, 54.701139080908995, 55.94419310169836, 54.06991989381852, 55.866993011966834, 51.73170481958697, 54.67854230634628, 53.398147321516475, 63.38827510033885, 69.06858490359399, 76.52397509544127, 73.44252186436808, 77.82500174737747, 71.42501938727595, 82.63416490247174, 75.26336454576062, 85.20024222712364, 66.12985103361069, 87.38683808234431, 9.427793256698116, 0.44276048519438316, 0.6197344872259325, 25.388588213151504, 79.62831143409976, 52.667056745098485, 47.750106857668975, 35.33395390356741, 35.26292762448711, 72.11570955091908, 16.538391420918128, 0.7605640626242085, 0.21192448063483163, 0.025473199146349105, 0.14770329929888248, 0.07062462684247764, 0.06113830946325775, 0.08591843844060937, 0.05501009253484588, 0.09802795961619386, 0.10556523057241594, 0.027057650919643142, 0.01600209148525591, 0.056815294458741145, 0.022117645937889334, 0.11542379390448333, 2.0666242799451275, 60.3707996491463, 55.420894007528986, 53.83184771383963, 69.70980613462388, 58.467830381085804, 91.54093403970042, 21.076087336386404, 0.6423009247068436, 0.12593754627291234, 0.6516905273160627, 2.5785107478018734, 46.1821315365453, 97.53686520361133, 76.92863033663842, 82.52808832353162, 72.48398088639783, 74.12062121975806, 67.26928387918781, 64.5839939578887, 57.629714012146, 60.40188835513208, 57.688882966195386, 60.67630521712765, 57.39985919767811, 57.008689065133375, 55.724206970584014, 60.93331067792831, 59.81105781370594, 65.35432000314036, 65.84956630583733, 66.41735292250111, 66.60690538344845, 66.61702509849303, 63.431491774897424, 64.183355223748, 57.60803899457378, 56.45490138761459, 51.90660722794072, 54.82853374173565, 53.332522146163456, 48.112000419247536, 47.502064012712054, 47.675052304421705, 46.968131373005534, 50.34462921081051, 49.93880902567218, 50.59014212700629, 55.53441524505616, 61.58330625103366, 58.789417666773645, 55.81458230172434, 52.330584064606704, 62.66460564828689, 56.33318239642728, 60.567345696110884, 63.019211446085286, 64.96509928857127, 57.98365300701511, 47.84991548907372, 50.533079485739435, 56.09967193295879, 55.319685089972715, 58.12156354227374, 56.243364041851414, 55.095745209724676, 53.801245381755216, 51.15952122596003, 51.68590330308484, 46.66005273019114, 44.02005441727177, 42.471655645678126, 33.75335639522922, 37.1747536043967, 43.186229121300485, 50.152036912979625, 49.37951434043146, 52.78410811578074, 50.043144072255785, 45.173674475762155, 41.10590204115837, 44.360159212543124, 42.3091479270689, 47.9729720084898, 47.09022691172939, 48.22701215744019, 43.39378526133876, 38.06872452459028, 29.150141208402573, 37.50294616145473, 42.7703990474824, 54.06396573589694, 58.50508113061228, 59.25721130063457, 60.88735226661929, 59.898201111824285, 60.65335150687926, 61.40580723362585, 58.327809610674464, 59.291437902758204, 60.95530732985466, 62.190328336531124, 54.912150829069084, 59.91721676241968, 63.60067144516976, 61.356467739228286, 60.675689405010594, 56.70469753203854, 57.473858633349025, 58.31459514556393, 61.582172686053866, 61.40733695799305, 46.06318566106981, 48.75350406092983, 45.6260218158845, 50.11847711378529, 48.757665695682654, 49.523312353318744, 46.208348658777055, 46.922506363161155, 48.30442797753119, 53.038881747953354, 49.39324655840474, 53.95568086254982, 51.811983969903764, 54.837919973558, 54.484757607983006, 59.89009749504828, 59.72565212557393, 62.23770272347235, 60.307320010277536, 62.44290544140724, 58.13156950858332, 60.35836573570006, 56.406075723709606, 60.651225582245864, 55.78010466790969, 57.87575644831504, 56.320913222528276, 66.78539676050987, 70.5305777826617, 78.30990083755987, 75.28261553856635, 81.54009034556728, 74.64040587025305, 85.30155704867455, 76.26074483317714, 89.79373778066328, 68.6474713971538, 93.88364022777927, 11.602746536654811, 0.7810642690427843, 0.7149273469563454, 29.13849373017588, 87.74273826229958, 60.09526491165162, 55.800081299197295, 38.86408705865183, 46.87988588886876, 78.7571922425301, 20.672950052445938, 1.0243752646830775, 0.2900698156126084, 0.10194617759196029, 0.19753073041717853, 0.043842748423377355, 0.009263381005204734, 0.10391397401690484, 0.19838672642025257, 0.12734392282342719, 0.3326499323931433, 0.09029109211217973, 0.1840415308552404, 0.15295236521670896, 0.2209409371378922, 0.30285867291592783, 2.8023126096494737, 68.4838693372665, 66.26043458138743, 66.72518053362447, 76.62709420727145, 66.54039767480666, 101.54762206539031, 24.882359273972053, 1.0911989692718753, 0.4389842233109859, 1.692027141970973, 5.402225525148454, 47.41529726213025, 104.3181803918654, 78.5332876636136, 87.33319574786772, 73.52340113732123, 79.30138188023722, 69.95177715055405, 69.66332604808193, 60.50748640491117, 63.388204497675744, 59.38857540007561, 62.748779712184785, 61.75783211185087, 60.01785301393079, 57.82717004899056, 64.21227485902848, 61.853855656039336, 70.64393428064162, 68.76780186930011, 69.29128139249741, 70.0822038035239, 68.92627346900203, 65.57789510296237, 68.42766961743756, 60.47552301037697, 58.86310723520095, 53.427266997675744, 58.553534169350904, 55.03321086206744, 51.62434562560051, 49.075130570319395, 50.23853694238971, 49.59666459791122, 53.22672797787575, 52.60552260183519, 54.83081263880576, 55.53894166023501, 64.04201261458859, 60.94685462213332, 57.57283179990707, 54.48100782209828, 66.56939967986077, 59.01097666832709, 64.26652516088178, 65.79728895618071, 68.34860247950401, 61.19783924471948, 48.50570832529376, 49.51385159646311, 59.15215061556909, 57.55391813093617, 59.94890951341199, 59.54794130017681, 54.589512348175056, 54.755032447076616, 51.48466610139417, 52.25297997074743, 47.9424951922509, 45.86956962462395, 47.54673588660456, 36.77334216333205, 40.091961506874334, 43.52154470259144, 51.70202424449306, 51.89716216056578, 52.38844686938871, 50.12059911604851, 47.56653601123441, 42.19322619899627, 42.782275984364176, 41.87786371477189, 47.1548754169095, 47.465017226434526, 47.588497361829205, 44.16625684307468, 39.54607740525277, 32.6832494812627, 41.278403958966656, 44.162624728295114, 55.99712548717376, 60.18926843520134, 61.546483039855964, 62.31069803237916, 63.17153276935701, 65.15799360890543, 63.80113201756632, 60.87255708632931, 62.58802529304259, 62.29450648830783, 64.62887763977051, 57.44215411524619, 62.889777152769035, 66.92588821534189, 64.88720493931925, 63.308666675321525, 59.48857230524863, 59.799341694001235, 61.25671009863577, 63.459936803387066, 62.30655600947719, 47.273523192251886, 51.592495979801306, 47.75207980986565, 53.185441109441946, 52.11163343921785, 53.08666406139251, 50.21315920737482, 49.716340034238755, 50.997609707616995, 56.7254743268413, 52.526659427150605, 55.51948670418032, 54.798555066508634, 56.135181150128766, 57.12591302010321, 62.20575501841884, 63.61406241693805, 63.59139896208241, 64.72451286931192, 64.98717831027123, 60.00007683230985, 62.637494225655836, 59.93757778598417, 62.985267254614065, 57.27740672326858, 61.69243443396784, 59.570875398574344, 70.86878022839947, 74.47452099092546, 81.95754820300688, 77.05765278108659, 83.73782573207733, 77.83636877613684, 85.82752335456111, 78.68598553442186, 91.81515478318738, 70.99056982224988, 96.44308090209962, 10.554659808835677, 1.1015042614552284, 1.8613990083817515, 32.469088069854244, 97.46783148857855, 66.2158372325282, 67.75824654486873, 50.59131099331764, 50.3352939698004, 92.23672328456756, 23.40078200063398, 1.1541618358704353, 0.43963506096793764, 0.19337461149740606, 0.42898637753340507, 0.17567886910851926, 0.19835960690773305, 0.18197519254059563], [0.12043823773461966, 0.06579123257148652, 0.11404660530388357, 0.10960868094116451, 0.02871477953909386, 0.04908167133708635, 0.01370296203306005, 0.07924045000465647, 1.0602898342955498, 52.08964070966167, 51.490541811912294, 41.270880852976155, 41.45793868649391, 57.02510810667469, 86.45283545217207, 12.964769967140692, 0.6673448292478439, 0.1696519175123784, 1.4543225616216662, 2.827705788996912, 43.017575048631244, 92.43239464298372, 71.91860260501986, 78.52290122739731, 74.1701921339958, 76.2737278784475, 69.00685464182209, 67.89559225882253, 58.31816058005057, 56.968841706552816, 54.803701216174716, 57.21094216069868, 55.21764070756974, 54.31347162492814, 54.999576537839836, 59.733716518648215, 62.54604024271812, 64.16421013493692, 64.27084369044151, 65.6252420333124, 63.63569428843837, 64.11951080445321, 63.331330130177165, 64.40005440865794, 61.25890270356209, 57.87211256642496, 49.21082496643067, 50.88201353626867, 51.717968679243526, 50.86005610804404, 43.99712816361458, 44.548742848057906, 44.22856369326192, 48.97712622919391, 47.15665617296773, 49.460236718577725, 54.767427136821134, 63.41948539979997, 60.76280916890791, 47.935662423410726, 48.17323254000757, 52.27916179164764, 49.617107991249334, 51.22625250970164, 53.4111931247096, 53.958136266277684, 47.172118156187, 53.633999439977835, 52.95424092200495, 55.00153772292599, 56.13247471470987, 57.2393754220778, 56.684516937501975, 58.0240063513479, 56.396505140489154, 59.11058133648288, 54.64236236387684, 47.79588483995008, 42.46641535912791, 33.31578462354599, 33.02036739164783, 42.94001017847369, 46.83877552709272, 53.95513173072569, 54.773487198737364, 56.061373910596295, 55.056811763394265, 49.226435999716486, 45.536740826022246, 44.05253164229855, 48.24464713373492, 51.85440832568754, 50.98766649923017, 53.567911424944484, 48.23380962494881, 40.520280407321074, 34.52051708775182, 36.16954426611624, 41.371666154553814, 42.726460656812115, 48.81040588501961, 54.06128283469908, 54.50688762049521, 54.5579098116967, 53.43007149234895, 54.78331273601901, 53.290003653495546, 56.19682904212706, 51.69912169056555, 49.63189924916914, 44.306509033326186, 54.3065917876459, 61.329085673055346, 60.613076609949914, 58.688259740029615, 52.783347175967315, 51.014864214005016, 57.346138415798066, 63.3186451850399, 57.94108744590514, 49.37587830328172, 49.0441438459581, 44.98762469137869, 47.09561624834615, 45.90934245817123, 42.88105695478378, 43.576289223086455, 46.59655347947152, 47.19216931250788, 49.50701882762294, 49.300870818476525, 49.45183500166863, 48.8121356502656, 52.6893985656, 52.42581529002036, 55.62567310948526, 56.614435949633204, 59.938848633919996, 59.344334986902055, 62.044404399010446, 59.37600812604351, 61.64347148710682, 59.2992591088818, 60.29658056074574, 57.361953412332845, 57.25081305350027, 52.28115435569517, 56.38425950081118, 62.40495258761991, 74.09817741763207, 74.08830088953819, 81.35254613814816, 75.38436182083623, 79.1989060371153, 71.98878165214293, 82.30559579787716, 68.32051830907022, 90.49879166387743, 27.90169392862628, 0.25178202818478307, 0.21822343940936753, 30.34098848219841, 76.04249631204914, 54.421415252070275, 48.24014425277711, 43.52203892123315, 28.600495553785755, 69.01957881066107, 22.03911746701887, 0.6928444641732401, 0.300543831000405, 0.14807580189118463, 0.08570499868402559, 0.04846416616572007, 0.05512568754174056, 0.04432515015885715, 0.10240727825270546, 0.04235466859573799, 0.16947364885239832, 0.12802181870586452, 0.05403277501764317, 0.15836492961933538, 0.13146145389445368, 0.1470201786968016, 1.8457021732484142, 61.676913615195986, 56.42748402011011, 42.04051656107749, 46.67558139370334, 60.95313825914937, 93.67569185072377, 15.31059051713636, 0.7750610202070206, 0.37938166349645586, 1.9116055917355324, 3.833605709575838, 45.28995706189064, 95.17743402911772, 75.527465574203, 81.9255102834394, 76.29487729841664, 79.87283983538228, 74.20566604983422, 69.5930528640747, 62.66233067358694, 60.36117415274344, 55.9848641580151, 60.70041994894705, 58.231731153303585, 56.499071198125044, 58.87460762454618, 61.57052324664209, 63.870985507965095, 69.10991884046986, 66.89265005050167, 69.91303982273226, 67.19648468878962, 66.36913130360266, 65.32843236000308, 66.71207981724893, 65.33623787664598, 61.05930505260345, 51.99631183378158, 53.21046190877115, 52.356016712804, 51.404677206470126, 47.21391885511337, 45.90650658453665, 46.49579955685524, 48.77748150979319, 49.776203247808645, 51.93117303232993, 57.65476226806641, 64.6549770908971, 60.87274928246776, 50.17459838621078, 52.11993709687264, 54.23881323106828, 49.850955778552645, 55.74603888296313, 54.72568527344735, 56.62483807533019, 47.67823726900163, 56.2400653285365, 55.355323745358376, 57.53520058047388, 62.48199186017437, 59.50792920204901, 61.79248232995311, 58.81201444133636, 59.89128597321049, 61.64071013850551, 56.707447113529334, 49.71800704156199, 42.790371756399836, 35.127127324381185, 37.58394310551305, 44.39963786832748, 48.55076066909298, 57.60303797260408, 57.85747820331205, 56.75179343069754, 56.568563830467966, 52.15334392363026, 45.175082606654016, 44.19776524266889, 47.66621520442348, 53.60501312440442, 53.56203571442635, 54.82904757222822, 50.93551074304889, 41.06667049469487, 37.671702215748454, 37.51758444693781, 42.96697255103819, 42.338448032256096, 51.219262846054576, 53.725724066457445, 55.35012660488006, 56.651376831916075, 57.180551636603575, 58.09246347796533, 56.346867545958496, 57.73876374767673, 54.448118748203406, 48.46790844394315, 44.156792163848884, 55.487750807116115, 62.20449201522335, 61.09322963222381, 59.859871710500414, 51.946313381195075, 54.251227532663655, 59.38575521592171, 66.72067765266665, 59.62670249323691, 50.924622243450536, 51.270645895311915, 47.596820631334865, 47.37855642072616, 47.19784890451739, 47.11678920253631, 45.48727973814934, 49.37008888490739, 50.25799974318474, 50.31733735915154, 49.51943312921832, 53.43380166638283, 51.34113088730843, 53.724676793621434, 56.28330553731611, 59.38356261099539, 60.52905944085891, 63.63845171466951, 63.61067741147934, 65.60539091787031, 63.01758366246378, 65.29681805641421, 60.77380357250091, 64.49614071076917, 60.89770340150403, 59.81470169559602, 55.25629174324774, 59.76239296697802, 65.25079688718243, 76.74799734546293, 76.43790260437997, 84.6459956322947, 76.08736038208008, 81.96225504721366, 72.89307625063005, 85.45481189604729, 72.56842167146745, 96.48742721926783, 33.97395441609044, 0.7329899228868947, 0.1540796482755292, 34.23450177715671, 87.53647650441816, 60.238839349439075, 58.21883440017701, 48.87463077422112, 32.76718035820992, 76.51037231568368, 27.957964251118323, 0.6841067717440668, 0.37037305173373997, 0.22881481946716387, 0.20497592526578134, 0.012344138475225098, 0.15787242701457394, 0.01665964103003423, 0.29816546507420083, 0.14262473390948388, 0.26405782108345344, 0.25193284025355694, 0.14495491290525084, 0.26666368447965194, 0.2379702443196889, 0.3644314882976394, 2.612038677738559, 72.36553315193423, 66.90600179856824, 51.39035271060083, 56.79437860365837, 69.5291260750063, 100.67846405890681, 17.997087547855994, 0.878650693883819, 0.8462724474168594, 2.9453869452399593, 4.043042380963603, 48.383557873387495, 100.07104581402194, 78.49262837440737, 84.48129530875914, 80.67496453562092, 82.11794960883357, 76.14370130723523, 73.58627673118346, 64.96609164822486, 64.37770474341609, 58.18871059725362, 63.55537983679003, 60.85246278393654, 61.49104818221062, 61.72509208802254, 64.89416714637511, 67.22921294550743, 72.59084193937241, 70.45068694699195, 72.09116335838073, 70.36546168788787, 71.13423839692148, 68.97013341226886, 70.00670602244716, 68.36329567816951, 64.24303408591979, 54.334519063272786, 56.61355733871461, 56.69706067731304, 56.263932951035045, 51.395428257603804, 49.88289171649564, 50.50698787935319, 52.95391536528065, 52.93218151215584, 56.61752677732899, 59.989882592232, 66.63910019782283, 63.79677818667505, 56.26430165383124, 54.44278040239888, 54.99960399443104, 52.66674687785488, 58.42417440106792, 59.36645715467392, 59.1840002613683, 51.15417111304499, 58.628890745101444, 58.01095270341443, 62.44528239773166, 64.4473385810852, 62.62301283497965, 64.99526623756655, 62.618753140972515, 62.93132682000438, 66.1337028011199, 61.01202480254635, 53.285477238316695, 45.83377015206122, 37.46543653549687, 38.290907183001124, 45.79244798229587, 50.10351719394807, 59.624451052758005, 59.04788224927841, 58.28343975928522, 59.55962996329031, 53.23041500583772, 44.52926435778218, 45.31225573632025, 49.01509085009175, 54.94114498938284, 53.694827556610115, 57.85673687534948, 50.435043765652566, 40.96029189325149, 39.34210238918182, 41.33889082939395, 43.29990725363455, 45.315048463882945, 51.32404896520799, 56.24988302107781, 58.84605669206189, 55.29915932686099, 58.42225243968349, 58.41901256192116, 58.56287725510136, 59.16482771596601, 57.836269947790335, 50.518727533278934, 45.458850399140395, 59.66225485647879, 64.9941405173271, 64.56278962473716, 63.80694104779152, 56.673785332710516, 57.11713475565757, 60.886234391120176, 68.99700164794922, 61.9840116654673, 53.6085864036314, 53.613265791246974, 51.03893972212269, 51.83259994752946, 51.57426872561055, 49.0255400442308, 49.43302723669237, 52.26266430270288, 53.6879712535489, 53.45909703162409, 53.15200682609312, 55.92970386628182, 55.6372009554217, 57.44865348262172, 59.10016352130521, 63.43315093748031, 63.93266085655459, 66.51629863246795, 66.29645762904998, 67.6996777134557, 65.12689705817931, 66.25799486714025, 62.03807369355233, 66.11900175771406, 61.95038126360986, 62.71081509128694, 56.95178724104359, 61.606742412813254, 67.9942241791756, 81.47310410776447, 80.25119950694423, 87.08803192261728, 77.98189655427011, 83.31861849754088, 75.05385506537654, 87.5955395544729, 72.13546260710686, 100.10325631787701, 32.550273287680845, 1.126417808475033, 0.6515378000274782, 37.03383853358608, 96.74740975902927, 69.02057509268485, 68.5843526163409, 58.684553100216775, 42.43563259801557, 88.42938838466522, 34.56598128041914, 0.7396806283823906, 0.6546134898258794, 0.2986449441842495, 0.37493397151270225, 0.16976405746273457, 0.2001465529563927, 0.1650896034533939], [0.047047148653936964, 0.019936350384546865, 0.07580164985190477, 0.030766464506966934, 0.038597390371104406, 0.020515005322053068, 0.04016254247436601, 0.15241798824600636, 1.8031101361397774, 58.52705817068777, 42.29613350283715, 32.11100116852791, 52.913420815621656, 56.97402707992062, 87.24676239875056, 19.7864394803201, 0.5027914413761708, 0.19121055100714007, 0.6306236609816551, 3.3237836341704092, 38.84902123481997, 92.11312940043788, 73.15731063965829, 83.89730145854335, 77.34389951152187, 81.19719674510341, 76.08182984013712, 72.45994460198187, 59.319584831114746, 59.26309485589305, 54.928589482461255, 58.40921448123071, 54.87677105011479, 56.66366954003611, 56.80239200592042, 61.9490162787899, 63.14784557588639, 63.95444177812146, 62.35192606526037, 64.38694584754207, 63.22923083459178, 63.296028798626324, 61.2701952072882, 62.10340469114242, 59.13627286111156, 58.44934817283385, 52.144918672500125, 52.39782525647072, 51.40746601166264, 49.31332042140346, 43.43679012790803, 43.43619000527167, 44.97005247300671, 47.564998442126864, 45.718409322923236, 50.50472859413394, 55.90593822540776, 57.197806142991595, 52.04376074575609, 53.21470591329759, 55.76801592303861, 49.5590647574394, 49.6161352434466, 48.371006288836085, 50.02649753324447, 49.795046314116455, 53.08167088416315, 55.49407366783389, 56.56063672034972, 57.264466824070105, 55.92513822740125, 58.129627935348026, 54.431805610656745, 57.517863704312234, 61.16286739226311, 56.83608908807078, 58.87509007607737, 52.857048511505134, 39.830578680961366, 44.37507206393827, 43.44972218236616, 46.850036651857444, 53.447282852665076, 55.909119267617505, 53.55219056529384, 54.8376218734249, 55.76310511558287, 55.51987109645721, 49.889536211567545, 47.6118629209457, 52.37926460081532, 54.49469689399966, 54.31677033824306, 54.26620706435173, 56.312656633315555, 49.498711247597974, 41.280702467887636, 38.52138173195624, 44.74173522764637, 46.19573431630289, 40.215206300058675, 51.252803033398045, 49.223388318092596, 53.06707574475197, 51.714230660469305, 56.24958099857454, 56.04187973083989, 52.66809617319415, 48.61973947094333, 47.62019011282152, 41.63151925609958, 48.65542127240089, 54.68525740408129, 56.10693224014775, 53.40357980420513, 49.9005659164921, 48.35995697206067, 52.96299565222956, 61.69667843849429, 63.110794867238695, 58.43869109307566, 52.93109109324794, 44.12971604254938, 46.77280126079437, 44.91463722721223, 43.31497699983659, 41.19989771996775, 47.738375048483576, 48.580809946983095, 48.97731450296218, 47.40900970274403, 50.872760665032175, 49.322820401960804, 51.361605659607925, 51.75956149255076, 55.35590425614388, 55.77697461651218, 60.68738591286444, 57.522084174617646, 61.08995053075976, 60.91478924597464, 62.687163199147875, 59.22766016375635, 61.71370544741231, 60.51002025604249, 60.47423255059027, 54.75209459181755, 54.13665117756013, 54.31666835661858, 66.67320912884128, 71.86645077120873, 75.76386682448849, 71.77784442901611, 80.9960497579267, 76.5160362182125, 83.73880632462041, 73.44457718633836, 89.70644935484856, 47.43566613043509, 0.22033589621705396, 0.1079821766864869, 36.18168792416973, 77.09840620717695, 54.78745475892098, 55.099667579896995, 33.27126179972003, 39.84122007123886, 67.96110368544056, 22.57091437616656, 0.3880285591848435, 0.06824954743346862, 0.04860256377968097, 0.15130993399408557, 0.057972692433864846, 0.010854233443106135, 0.03591720878537144, 0.0704273208975792, 0.045803240199963895, 0.048364360230944814, 0.03785452640224849, 0.00819683914268089, 0.035741992985769626, 0.11872699649463739, 0.37600091748660613, 3.1509176713805047, 70.27594535581528, 46.06304445574361, 42.191559191673036, 64.68374767611104, 61.7015225656571, 96.83436870574953, 21.730352409424324, 0.3373533751695387, 0.31352411835424365, 0.5290682265354741, 2.8529658529066273, 41.621022993518466, 95.55930814435406, 77.91792269675963, 85.57335376739503, 81.57461504782401, 87.21053538783904, 79.34597922909644, 77.21516732246646, 63.09285002370035, 60.99626471919399, 57.79269241517591, 61.73037159827448, 59.033389091491706, 58.24145863133093, 59.42907779447494, 65.36487902364424, 64.9213295598184, 68.68366702910393, 65.44699776557185, 67.31827428264003, 67.52637955450243, 67.28320829329952, 63.76904702955677, 66.83653662281652, 62.577913422738355, 60.569981528866684, 54.51010004166634, 53.36280284389373, 52.859813782476614, 50.7461347887593, 46.67422033125355, 48.083080783967056, 46.55825153473885, 50.82553532815749, 47.70093602518882, 52.74900290273851, 60.248715877532966, 59.37092081193001, 54.18787733201058, 57.704945072051025, 56.966739316140455, 52.489145878822576, 50.25573653559531, 50.873772636536636, 52.31898953837734, 52.731842533234634, 53.89362504405361, 57.34962540288126, 60.65483024043422, 60.008819795423946, 59.569930107362815, 61.132590616903, 60.15773257901592, 59.528321604574884, 61.00622753943167, 58.84131454652356, 59.9297801140816, 54.62397037013885, 42.514821329424464, 48.33639529443557, 43.277867455636304, 50.147667392607666, 55.6823552808454, 58.91811063212734, 56.18432452601772, 57.6027516395815, 58.66193279143303, 56.32867951546946, 50.97543654903289, 48.911163730006066, 53.30472430875225, 55.91103730663177, 59.02509720094743, 54.93926225170013, 55.955720947634795, 49.75043327577653, 42.25844737022154, 38.50356632663358, 44.89099317981351, 45.5541169258856, 42.30738286049136, 51.84091929466494, 51.77959695939095, 56.27173846767795, 52.28837936155258, 56.8932419438516, 55.77688047962805, 55.17601259293095, 49.95079971128895, 51.011498820397165, 42.33995422240227, 47.14728955299624, 55.25185554258285, 54.580961581199404, 54.568229567620065, 51.06273281958796, 48.81397131950625, 54.908142166752974, 61.370658874511726, 64.65686767332016, 61.905627019943736, 55.21383208613242, 46.66791708238664, 47.9895910909099, 46.92300058180287, 46.03114774150234, 44.00590642806023, 50.44401814860683, 50.924406513091064, 51.18147865418465, 48.987485208818995, 52.409776718385764, 52.2723800136197, 54.41106019481536, 53.87606459279215, 57.994584652685354, 57.60813705382809, 63.31456199769051, 61.0669772086605, 64.8295029517143, 63.365399837493904, 65.32382357505061, 62.50188219931818, 64.92019207246842, 62.67196793710033, 63.438944278224824, 57.5322078120324, 57.13162399107411, 57.55245116449172, 67.81345782741424, 75.0716547812185, 79.9508479333693, 75.3821417593187, 83.24378751939344, 79.89877454696163, 87.1659694179412, 76.56509722432783, 92.19418125767862, 56.02862211965746, 0.8840078548077615, 0.14030192467954852, 41.83319184087938, 84.81572443439116, 61.98965203377509, 59.26509526468093, 35.56554240565146, 51.9723500743989, 75.70454489800238, 28.283781813037013, 0.43298495813242854, 0.2370556579121659, 0.12682944115611816, 0.03919863532627783, 0.034916885647802584, 0.03321231320320118, 0.08585040217205402, 0.34213422346980343, 0.17549225009016453, 0.39827222725556743, 0.17641068225906742, 0.2917616441845894, 0.07146432049452298, 0.412796457568484, 0.6485868906301837, 4.223042399652543, 79.61502244395595, 58.12328154040922, 42.6795098858495, 73.36090518582252, 69.37673414907148, 103.49856976539859, 24.103637395366547, 0.5610596292441892, 0.8747584156451688, 1.17587705773692, 3.818595779518928, 42.96891020190331, 99.97833667262908, 77.51729180735927, 90.752608237728, 81.99219057636877, 89.14176925536125, 81.59447008563627, 80.60074544722035, 65.55588276155534, 66.11951166583647, 59.0064698649991, 64.78673342735537, 60.979100427319935, 60.68644062165291, 62.57900384164626, 70.12831518726965, 69.27592139090262, 70.4520127081102, 66.58157471687564, 70.83360441269414, 69.23822741354667, 70.72423304280927, 65.3488169177886, 67.27217858837497, 63.76626999147477, 62.819280393662, 57.35838405547604, 57.58845460030341, 56.449413991743526, 54.64591603125296, 48.781486249739125, 50.8024404125829, 49.438553856265166, 56.552984176143525, 50.02879604216545, 55.00773899016842, 63.009158411333644, 62.463137026756044, 59.061739983097205, 59.6673539377028, 58.70907183616393, 56.15860162242767, 52.8606100236216, 52.332509948361306, 54.273847841447406, 55.406553822179, 56.76083449394473, 60.78383307303152, 64.02385596306094, 63.59751393718105, 64.17312960470876, 66.13719371057326, 62.90945176155337, 63.149269396258944, 64.60226435815134, 63.33660179568876, 63.21489849398213, 57.590223589251124, 43.406509430177756, 47.40352230687296, 44.2507407742162, 49.31114742832799, 57.108042701598144, 61.75600428735057, 59.70557743503202, 60.110711205390196, 59.549231759963504, 58.98375149696105, 52.65765090142527, 50.348630028386275, 54.7586763289667, 58.490933141400745, 60.56925196801463, 58.75899184134699, 59.35733764402328, 50.92419862747193, 44.151485197005734, 40.095134704343735, 46.19628344812701, 46.28689412147769, 44.45955207270961, 51.78883806351693, 53.20135024286086, 58.946712555423865, 54.34603906446888, 61.86540311382663, 58.48122919759443, 56.137781681553015, 51.712767616395034, 51.98088907426404, 41.24060407761605, 48.719618705011186, 58.41873799600909, 59.25610911461615, 56.76988732430243, 53.55984310950003, 51.375565375051195, 58.41016369481241, 64.33522155207973, 68.6379792613368, 64.03653698582804, 57.50084846250473, 48.88928082681472, 50.95485195036858, 51.487776540940814, 49.71672050414547, 49.0826811329011, 53.385580047484375, 52.406509384032226, 54.34357973837084, 52.962364150631814, 55.767153001600704, 56.65816253231418, 56.49590192302581, 55.84381964898879, 59.68846021160003, 60.17068816769508, 65.96543312072754, 63.267685751761164, 69.11649273287865, 65.9130459447061, 69.1103110774871, 66.78273739353304, 68.31294813463765, 66.49583954964915, 66.52513965483635, 61.67460333916449, 59.69436730107954, 59.48470484825873, 72.15274457008609, 79.64677795287102, 84.76057590976839, 79.65599552277597, 87.59514731745567, 83.8855500375071, 90.41428027614471, 80.48440010316911, 97.00845133873725, 58.54812129851311, 1.4190089726640334, 0.2789403660403144, 43.78225288083477, 93.36213757914882, 69.40917999513688, 73.81248766376127, 43.94297592101559, 55.75726078402612, 90.31877840718916, 33.10366284462714, 0.6255381854791796, 0.6116853546231025, 0.22541440031941862, 0.18327824681276278, 0.14201646009760518, 0.1258698317612852, 0.1744919997309485], [0.04583638116356827, 0.0517337681395152, 0.0674935105827547, 0.10268303926192945, 0.027026926963439873, 0.0355744150827729, 0.03868432219831213, 0.09468437653155097, 1.9136344377071628, 62.89205212746898, 45.50277310032999, 21.40674118072756, 38.26888699685374, 59.29069265242546, 86.93949960893201, 18.830426469925914, 0.29998881562102225, 0.5393509038033024, 0.08561806302637824, 1.0685179863245258, 46.76741584654778, 88.45078099158503, 74.12514763493692, 86.22209025967507, 78.95230662438178, 79.81097621302452, 75.68875343568864, 70.06418443495228, 57.18308548773489, 56.49090874579645, 55.02588779695573, 56.6704434733237, 56.252848332928075, 55.28405820169757, 57.470171605387044, 59.772618586017245, 59.04743509907877, 62.212164171280406, 61.84912135524135, 58.80653489020563, 58.316807362341116, 59.328088529648326, 58.04075094961352, 60.87344746435843, 58.881338411761874, 61.431741945205204, 53.15783154579901, 50.64962879303963, 50.583266212094216, 48.90601758033999, 44.86998888754076, 45.46407107383975, 43.04338424436508, 44.639596708359264, 41.56799254878875, 48.966198505893836, 51.009161087774466, 55.00604452625398, 58.24005050043906, 57.46330745758549, 49.669663829188195, 49.709185631044456, 49.81485036111648, 50.67827778477823, 48.126548490216656, 50.610616899305775, 51.6416040543587, 54.603389693844704, 53.85713131197038, 54.422372310392326, 56.64983926280853, 54.922086192715554, 57.06477111385715, 57.08088028815485, 56.778920542809274, 59.453196448664514, 57.757791165382635, 48.67404860834922, 43.36897234762869, 45.29226341555196, 45.826003859120036, 55.25411875017228, 54.88768308393417, 53.10090618748819, 53.21239171489593, 54.573920926740094, 54.88674563746299, 58.386711843552135, 55.074246698810214, 54.24435554012176, 55.52040453880064, 54.557674469486365, 52.62912742553219, 52.303288290577555, 51.52134026250532, 54.72371232125067, 50.993208808283654, 43.46672565706315, 43.80423384328043, 45.141762072040194, 41.323264106627434, 46.507131284283055, 51.37279225933937, 54.33455436460434, 57.163222605182284, 57.33391238797096, 54.035399113931966, 54.727893567854366, 55.929621496508204, 54.48922518760928, 50.65082119357202, 48.99354134836505, 51.72123993596723, 50.0882827081988, 48.35684653251402, 47.52909698793965, 48.5189227904043, 48.15873545985068, 52.90355605463828, 57.86879424125918, 58.85154016556279, 54.94286298751832, 43.6279115369243, 46.775660668649984, 43.29064653765771, 41.83021083954842, 42.54415673594321, 47.38200026173746, 47.0522544460912, 50.482712330356726, 48.98158204170966, 53.964215940044774, 52.99864999709591, 54.468777871901, 49.30621308665122, 53.98947992632466, 56.4427302729699, 56.34425524742373, 59.441001799798784, 59.335172330179525, 59.629922759148386, 64.08824559180968, 61.561776361157825, 61.515747347185695, 60.0979870365512, 61.41114557943037, 57.435976382224794, 56.403690922644834, 53.18801810664516, 56.53900092647922, 59.861189626878314, 69.71143784061556, 71.62695084848713, 77.3661236609182, 71.77960949559366, 80.94187398110667, 74.16566571881695, 83.82258815150108, 64.13637307382399, 1.452875697324353, 0.20953738130629065, 40.12026140766759, 76.2705272243869, 58.5212452180924, 51.691877072857274, 45.11520370360344, 26.883993802532075, 69.4009037940733, 26.230322968575265, 0.4537588418010743, 0.1019373216155556, 0.09098270862934091, 0.05253053405472348, 0.10917877538069602, 0.011903165817080487, 0.029259521679411975, 0.09085290269145081, 0.024524041106023138, 0.07717080985105808, 0.06121385339347105, 0.0725621244900169, 0.12111231083831481, 0.1328866532252681, 0.22450629501573502, 3.204448953751595, 72.91224095129198, 53.08770348948818, 26.682366325009255, 46.52633913101689, 65.4440716774233, 94.96028377163796, 21.638264963703772, 0.2304874651975209, 1.5807110119250514, 0.2558818702856379, 1.1671470874740233, 50.158528435614805, 90.45827357999741, 78.52590576294931, 89.29096837197581, 81.47351203426238, 83.95166550913166, 77.95050974815123, 73.83074237454322, 59.46558721603886, 62.10855868554885, 57.76024264674033, 59.45780131124682, 58.505481212369865, 58.54979615057669, 60.420923617578325, 64.45187676337459, 60.60903264630226, 66.48994030491, 63.401320903531975, 61.10791890851913, 59.57669619591006, 63.71908387830181, 60.44809387576196, 64.72830187889838, 61.69387786619125, 62.51136649039484, 57.2511346878544, 52.91466420696628, 52.697074644027225, 50.67227263604441, 48.070693938962876, 45.547456741333015, 44.64642947719943, 48.59240447321246, 46.012489026592625, 51.32093852566135, 53.66377807432606, 56.4368780966728, 61.27481183698101, 57.7359906319649, 51.08947946179298, 53.05998017711025, 53.19688266323459, 52.51175834286598, 50.62329792207288, 54.31059260522166, 55.83644559306484, 58.20063460257746, 55.36242715774044, 57.02582590041622, 57.91587837280766, 58.6528838834455, 59.868606828874164, 58.69191931140039, 58.93330197180472, 62.939752071134514, 60.66725630914012, 53.867403999451675, 44.120478860793575, 45.884513854980476, 48.228651708172215, 57.24294477893461, 57.322533592101074, 57.264839449236476, 55.32327405868038, 56.683469664665964, 57.83031578986876, 58.89476468486171, 57.5269792925927, 56.030477400748964, 56.81947392802085, 55.36578078423777, 55.52553107661586, 55.162209772294574, 51.98571358957599, 55.85815198959843, 54.087939262390144, 44.435343204006074, 45.690423211743756, 44.98300806168587, 41.236418908642186, 48.2602503222804, 53.26433566308791, 57.49483546903057, 58.07615818515901, 59.36508040274344, 58.056181553871404, 56.471755812245036, 56.43201435765913, 56.09718122789937, 52.84014309606245, 51.27268552780152, 54.548888360300374, 51.403520107269294, 50.92712863799065, 49.92954830969534, 49.443852978367964, 48.525630043398955, 53.90175611742082, 60.03196570181078, 60.065980495945105, 56.95854548485049, 45.99709764603646, 50.882601891794515, 45.64790864144602, 43.81589504980272, 45.25471456589238, 51.2866295537641, 49.877165056044056, 53.96463563365322, 53.14106341331236, 56.10698715333016, 55.84390594113258, 55.23631118958997, 53.11292432969617, 57.81247292795489, 60.549534213158395, 56.76990301378312, 62.353577383102916, 61.81200396630072, 62.92254071081839, 65.76166206790556, 64.89890929191344, 63.727968046742106, 64.98926893357309, 64.17338848114014, 60.86197060923423, 59.6294677642084, 56.25495464571061, 60.10099549447337, 62.106322934550626, 72.90578472998835, 74.41562268041795, 78.9294784299789, 74.62724239595475, 83.77640616509223, 78.53638633604973, 86.21186071826567, 71.74208025778495, 2.1413393030243535, 0.2676427142033654, 44.46039538229666, 84.05053277169505, 67.25352379583543, 61.001191216130415, 41.235595210906, 32.79015760267935, 80.60832346639326, 30.793429959204893, 0.41275104387633266, 0.138811883666823, 0.0895110690485566, 0.10545275354337309, 0.027399193983705297, 0.024983540643006567, 0.02095886134362269, 0.19437352886363385, 0.17771464051498523, 0.2884684773462434, 0.1561040662589573, 0.13066375718241738, 0.2403727726590249, 0.33826373277171967, 0.412629297183406, 6.102591685710415, 85.88267972392421, 59.84207983939879, 27.166273055538056, 53.01305294036866, 72.08658203001946, 100.97912942209553, 23.05228921674913, 0.3700182610942472, 2.969769378823619, 0.4364840800483381, 1.9963499927713027, 51.995699944034705, 94.76685600896036, 80.39531523181547, 93.92138911831765, 80.05238240764987, 87.99114196531235, 80.31801316045946, 76.56446180035992, 60.291399109748106, 64.49923546083512, 58.629585004621944, 61.708057234364176, 61.95954784270256, 61.83664821809339, 62.91050295675955, 67.13014171969506, 62.862465689259196, 70.01321715693321, 67.02025259694746, 63.13565877176101, 63.2633593774611, 65.27561764563283, 62.75909554573798, 67.36801778116535, 63.83702562701318, 66.98323326726114, 58.18094430431243, 56.39952928789201, 53.66758277339321, 53.63762371001705, 50.71967447957685, 49.10402667137885, 48.52552806177447, 49.58776473999024, 48.40567219641901, 54.236216622014204, 55.94744866894138, 60.66084715627856, 65.4433774179028, 60.29047735275761, 54.887545800978145, 53.04733837804487, 57.43232465559437, 53.025631981511275, 54.29361658711588, 56.59897004404376, 59.589008515880955, 62.275526139044, 61.51163278087493, 61.22927704165059, 63.111775459781775, 61.605098939711056, 63.66858728470341, 64.85475909325385, 63.16836741662795, 63.540082593117994, 61.42073185213151, 52.87602886076897, 44.895272485671505, 46.804219445874615, 47.08730082358084, 59.608526229858406, 59.815937242200306, 60.421919899602095, 59.126702277891106, 59.301938087709495, 60.82236643760436, 61.849917596386334, 58.422719201734, 58.074255835625436, 59.742808572707645, 59.47538137435914, 58.40971654461276, 58.60538790302893, 55.26823928279262, 60.65616776866298, 54.96367116128245, 45.650207150367, 46.251969337463386, 45.79957885126914, 43.59972930723622, 51.82008758667977, 54.23339251549014, 60.10872256371283, 61.509706897120324, 63.96981354682677, 61.0331428435541, 59.11912033634802, 60.866465645451704, 60.6056829421751, 55.63209402945734, 53.289344695306596, 57.22396442967077, 53.16683730771465, 52.00495673764137, 52.55477889891594, 52.066494803274836, 50.87285872428648, 54.99032366660334, 63.55964737553751, 63.7412021237035, 58.09557391751198, 48.57520095763668, 53.51134692468951, 48.914395763028054, 46.348640072730284, 49.409104701011415, 55.04053784954933, 52.02025005894323, 56.251416667815185, 54.00506350301928, 58.99052150787846, 57.34391835428054, 58.82540149073447, 53.787948546871064, 60.41407123688729, 64.03706650580129, 60.45728791144587, 67.298811481845, 64.30523895448255, 66.68622355307302, 70.2128501092234, 66.9117441485005, 68.15026390937068, 65.50035768939604, 66.4469668173021, 63.677961749415246, 61.8623201308712, 59.26732709330898, 60.997178631444136, 65.87983131408691, 78.4018490391393, 78.85474158871558, 84.19142430828464, 78.29952224608391, 88.12296498206355, 82.88230972905313, 89.78634019051829, 73.82290547893894, 3.5668565909708705, 0.35324050654326716, 49.70059171799691, 94.37166936935918, 73.20066851954307, 72.8484239885884, 58.99516167179231, 37.45003731020036, 94.38249511103477, 37.23852349865822, 0.5265292885803408, 0.24941843243375902, 0.27036287791786656, 0.2593802414353817, 0.2855283851104398, 0.15600047584983612, 0.13176068783767764], [0.054716998786335035, 0.041001224890351295, 0.017133929894395897, 0.0503077682468199, 0.03526226106670595, 0.13425851751479412, 0.16712562000799566, 0.2267233687903612, 3.8361574565210654, 66.56638729956843, 47.92442091049687, 44.31273775715982, 43.51488844040902, 53.42439974507978, 82.30003387697282, 26.4368220298521, 0.3426615064663272, 0.7096536589726326, 0.22622990091481518, 1.8904105742131512, 64.8844475130881, 81.9019760624055, 77.03525604740267, 77.9588722413586, 75.61270652278778, 77.83953805123606, 74.3805645358178, 63.36114798822711, 53.52441626210367, 56.30862051440824, 61.0449177988114, 64.07792583588632, 59.7706691680416, 62.45456272555936, 61.14102371277348, 61.34312775827224, 60.47895508427774, 60.74318555093581, 59.28582891341179, 57.16856095098681, 59.505234533740634, 63.98322805281609, 59.78314622755974, 61.36084902671076, 59.65051912492322, 59.40934042776785, 55.155631957515595, 50.63917959890058, 48.93492544850996, 49.8645350240892, 45.40669464295911, 46.6106112541691, 43.452616891553326, 44.30167667327389, 44.426227615725615, 46.650164434986735, 47.525794352254565, 49.537719218961655, 51.25402681289181, 48.05618901406565, 48.091533491688395, 50.344923388573434, 47.20483072342412, 50.13439409194454, 50.68141960328626, 51.451643666913434, 51.29348977919548, 52.54566723300565, 54.11510167583343, 54.00994685388381, 54.94363177207209, 56.80794608208441, 55.74402670706473, 54.04968438609954, 56.85911732335245, 57.02270369375906, 53.780084194675574, 52.64693106374433, 42.117755874510735, 48.675174328588675, 51.7865473993363, 53.02485927458733, 51.72704112145209, 52.0845651626587, 51.395051710067264, 54.18275471656553, 55.7028143636642, 56.437246799469, 56.358693492028024, 56.05413713762837, 57.113945868707475, 52.72471166426136, 52.800691896869296, 51.343727496362504, 53.48016800418977, 48.85467767715455, 53.13072012316797, 46.23926870284542, 44.86214022482596, 44.05921536107218, 45.911617432871175, 47.79332745459772, 50.88193116649505, 54.244406530934, 54.28755652519965, 57.0714234536694, 54.50464010238648, 51.90018238559846, 50.46248858974826, 49.54387734013219, 48.09673063216671, 48.67094601354292, 47.74423114715084, 46.71213003896898, 46.34330172692576, 46.96644867620161, 46.85780294479863, 52.32926222585863, 54.67674193843719, 55.07786704647926, 55.449315501797585, 51.30396250755557, 45.30274398865239, 45.907161620355424, 42.49759427962765, 41.0731973186616, 43.657890212151315, 46.41819546299596, 48.26696149764523, 53.36418351819439, 58.05973129887735, 60.476974287340724, 62.24448057913012, 60.19656012135168, 56.41295163862167, 56.30564735781763, 55.34703969955445, 59.2931951245954, 56.69255387398505, 59.124086056986165, 58.16909090165169, 59.57391915782806, 57.68443892079016, 60.113743197533395, 60.842166562234205, 61.10008201291485, 56.18357143094463, 57.58065692840084, 54.727932791556086, 58.81754106090915, 55.267803899703495, 58.95736963518205, 58.467171422896854, 67.83954158906015, 67.49317276862361, 75.31905435746717, 75.11913114978422, 79.7966674066359, 68.94108433877268, 2.875637152502614, 0.46434222390094115, 32.57989306603709, 74.83307269311722, 55.52914357954457, 43.61496771535566, 40.30287127340994, 43.4982144448065, 68.11053029952511, 25.403391238181825, 0.22797576932897493, 0.14507604672783805, 0.05927915962773466, 0.06569616872096254, 0.01875953782620209, 0.00959213710420074, 0.055333718717578924, 0.07768313115042064, 0.08679450594729955, 0.06553312988891717, 0.08092507735014924, 0.07802657602775483, 0.10918527180629392, 0.10134291399510638, 0.2898975071166792, 5.146255079777011, 78.15158613266485, 51.97302864443872, 50.11168749101701, 54.22240987900765, 60.24776666395126, 87.23312039529124, 31.817450984831783, 0.3292944979283118, 0.7099720451139635, 0.44640332520488774, 3.0300304678178605, 71.6985184146512, 84.1510082060291, 78.36983465379285, 82.03367356331118, 79.3527021715718, 80.90497232252552, 78.25170070894303, 67.0417393407514, 55.659754583912516, 59.46223358954153, 63.62994801613593, 66.45172857469129, 63.14267981436945, 65.17838208906113, 63.87062072753907, 64.9462366104126, 63.85632761063115, 63.42649859766807, 63.026236411063906, 60.423237815979995, 64.5617070505696, 65.9255269265944, 62.592688991177475, 64.93033532173403, 62.91263672613329, 62.48466691663189, 58.55841752021544, 53.768779923838956, 51.66799376087805, 51.872259032341745, 46.80946757716518, 49.34260875948014, 46.30201093612179, 46.57162681702645, 47.09789514541627, 48.91601962427939, 48.392387128645375, 51.166299081617794, 51.96801977772867, 48.197755198324884, 50.643133348034276, 53.194870487336196, 50.20478102468675, 51.90186508240239, 52.488988984015684, 52.365312730112386, 52.01080891393846, 56.4840171414037, 56.1778094691615, 57.860855364030414, 58.40071862743747, 60.543882077740086, 58.87813383533109, 57.366373923517045, 59.99181239835678, 60.657379781046224, 57.12070803488455, 53.62932005236226, 43.56804832335442, 50.719137114863244, 52.67681167971704, 54.43166048296037, 55.116671054593986, 53.22422550570581, 55.33266029050274, 58.05100010287378, 56.921451630130896, 57.79122937110163, 58.50683443007931, 57.809844939939445, 56.58424154404671, 56.79695560086159, 56.46456610771918, 52.537798958439986, 57.413061895678126, 53.08979803516019, 56.21093780763688, 47.2079215511199, 43.9612659331291, 45.65008163452149, 46.13768323775261, 50.00302607013334, 51.85568701836371, 56.9482571078885, 55.37866577025383, 58.986002937439956, 56.77505308581937, 56.338544276452836, 54.98083545315651, 53.18781022102603, 51.63885839523808, 52.235686240657685, 49.947457851902136, 48.93035980962938, 48.60493644591301, 47.79429235766011, 48.31244922453358, 53.34493644775883, 55.29438972473145, 56.275735362883545, 57.11808396923927, 52.43196556645056, 48.15371090365995, 46.441470807598485, 45.30610545989006, 44.72199001619893, 46.40836600334414, 48.839192159714244, 51.41971949608096, 54.37344074249268, 60.780871683551425, 63.96546363830567, 65.20465020210513, 60.56166610410137, 60.741636214717744, 58.70978962990546, 58.098931466379476, 63.12282477655719, 59.71545004075574, 62.44347418508222, 62.754714258255504, 62.875644853038175, 60.92404211721113, 62.046024337891616, 61.37051374681535, 63.530076626808416, 60.842127338532485, 59.023198773784024, 58.8233853924659, 60.73126939035232, 59.69159026299754, 60.78920279779742, 61.60018813225531, 70.0794267654419, 72.7044730032644, 77.74363610052293, 80.68779853082474, 82.39799899439659, 76.77080200564477, 3.7063279844099477, 0.5682194869845145, 36.1488498410871, 83.61063111212947, 61.22574298612533, 50.46043719014814, 38.83901919088056, 41.49916671937512, 77.93383967491889, 31.297758510035855, 0.2563548836136057, 0.11129013668265074, 0.027809424491058436, 0.006959262884206951, 0.06454162059291717, 0.034277355448613246, 0.051896941036947315, 0.19342952467981847, 0.16202897494358404, 0.19294727233148393, 0.16656536458721086, 0.18929793589538146, 0.3247039458684383, 0.4553914364547499, 0.4706709681739731, 6.233872434785289, 88.56619281153526, 60.9614929076164, 57.22762792341171, 61.116183342472205, 68.55102815935689, 94.73732056156283, 33.72677057020126, 0.3604193939076316, 2.385506601102891, 0.6242548962754588, 3.9296383242453303, 71.80219450304585, 85.42062451762538, 79.9366803323069, 83.11982493246757, 81.79344407973751, 85.5643323159987, 80.43310334605556, 70.0090672892909, 58.99502438883628, 61.42647027969361, 65.67378136419481, 70.36356326072448, 66.31510457684918, 68.90135072892713, 65.6709219563392, 68.62616508237778, 66.51367848919284, 66.85518357061571, 65.50168737288445, 63.0236162677888, 67.27958402326031, 71.59400293903967, 64.81464893587174, 68.88391187114101, 65.54815961468604, 64.36959720426991, 60.60529462752804, 55.781559867243615, 53.909369437925285, 54.636494498099054, 49.658806708551225, 52.83300830471901, 50.055981989829775, 50.853415535342315, 50.59577465057374, 51.78148361944383, 51.25393659837785, 53.99888184762771, 55.05114786086544, 51.89612665484029, 54.428028368180804, 56.88023144199003, 53.48027390818442, 56.742418965985706, 55.69014510800762, 57.251362185324396, 56.05035597278226, 59.42474357543453, 59.174786613833525, 62.537622836328325, 61.68687643543367, 62.589319675199455, 61.421473180094075, 59.40102500300254, 62.96087011214226, 61.82348866616527, 58.47527111730268, 56.361505831441576, 43.583726036933164, 51.733591479639855, 53.56724854438536, 57.38795480420513, 59.427304883157056, 55.932790771607436, 59.41149773136262, 62.09457935825471, 59.88286072208036, 61.31094078863821, 60.225577815886474, 59.360146061066665, 59.34090291300128, 58.36360123849685, 59.00976073357367, 56.521479698919485, 59.91920932646721, 56.706129197151434, 58.7670523120511, 49.38412312538394, 43.54942883214643, 45.845600020500925, 48.403436445420795, 52.05732037944179, 55.17592630078716, 59.2989335521575, 59.00406937445364, 63.59207360975204, 61.75136020106655, 59.676147891629135, 58.18924011722688, 56.64979611673663, 54.6166237708061, 54.9275775109568, 54.005930346827355, 52.49633166097826, 51.27204225909326, 49.54369691110427, 49.57991215490526, 55.20055094072896, 58.39247772770544, 61.006984556874926, 60.072664214718735, 54.96302397020402, 49.72328655181393, 50.44979972224082, 47.420290439359604, 46.872213732811716, 50.57690412767472, 50.777376467181796, 54.512606436206454, 56.52457052661527, 62.15479558514011, 66.52352363832536, 68.71151585732737, 63.74018622982887, 62.90339562200732, 61.54283915796588, 62.779864495800396, 65.45549361936509, 63.07098673235986, 65.42078848808043, 66.69387217490905, 64.98531518443939, 65.48633913840017, 66.37099050706433, 64.84935798952657, 65.88341636042442, 63.28288101380872, 62.44429396044824, 60.456040597731075, 64.96327538644114, 61.189245331671934, 64.81100113161149, 64.57786721567955, 76.13362866063272, 77.54062990988456, 81.90467465308406, 87.25447377850934, 86.15591987486809, 79.84044105775895, 5.468692539199706, 0.6416548367950224, 42.127204864255845, 89.31593818049278, 69.97757850154754, 60.86755606435961, 56.56419038772584, 59.156908450588105, 91.6746162599133, 39.4700304923519, 0.3628054513565956, 0.2684814885499016, 0.14623435634759166, 0.12652096053164813, 0.1770570919278168, 0.236990096107606, 0.13693918173591937], [0.0566573960766677, 0.04713115785571356, 0.026563922574202863, 0.013921647576705344, 0.06907473904110732, 0.09968483159618993, 0.054410391246839884, 0.12962039139482284, 3.068870757856677, 67.07038048774966, 44.40110091240176, 28.05609214690424, 51.754078019049864, 55.32494891074396, 72.43243309759325, 41.86149958641299, 0.4033754453543694, 1.1328268387625295, 0.9010508596416443, 10.812075157319347, 89.80816425815706, 75.00819867657077, 79.10445536336591, 74.31862246605658, 76.24480432079685, 75.49216424265217, 63.94565566893547, 52.76032286305582, 59.44302182043753, 68.04641523668843, 69.60559660388579, 69.97331096280006, 70.90011212133592, 65.4746308634358, 65.42553455598893, 64.71513448222991, 64.757429399798, 62.35753505460678, 62.99677156632947, 61.67536820134809, 62.318833028116536, 63.14114616763208, 63.99238286479827, 62.555147986258234, 64.3017166660678, 61.3437004243174, 59.82696694712485, 50.76240870260423, 49.47260395173104, 48.05156846200266, 46.74490928649903, 43.0347667970965, 44.38578405687886, 41.70852322732249, 43.384089162272794, 42.91999040111419, 42.74463299782046, 47.80007393129411, 47.749106653275035, 49.21500229066419, 45.68546925821612, 46.08202088263727, 43.79568699867495, 47.322894065610825, 50.01047857346074, 52.80764233681464, 50.42424940293836, 51.362727457477206, 53.0626356217169, 53.27583997480331, 55.13066607136881, 57.96810080928188, 56.09243515999087, 54.04525210780483, 53.74747753143311, 53.0261811133354, 52.252909368084325, 49.20355289213119, 49.58617618007045, 53.89383685204291, 52.87218101562993, 52.477186572167184, 51.1203642045298, 53.731340900544204, 49.802538041145574, 52.42294019268405, 53.543573118025265, 54.27819382759833, 56.965331185248594, 55.20569709039504, 55.12336654047812, 55.40997805133943, 53.62376205382809, 51.05476256339781, 51.36093885667863, 51.2196707725525, 47.99308200036326, 49.52956461137342, 44.77082744721444, 43.91268345617479, 43.02672986061343, 51.00219495834843, 50.404237470319195, 54.11889853016023, 58.39444283516177, 55.12581409946565, 53.858374703315, 54.912221431732185, 53.19103440930767, 51.046886444091804, 51.01052215022426, 50.05571919102823, 47.23307178866479, 45.94687169597995, 45.063408805478005, 43.656411478596354, 45.12612750453334, 46.623919856163766, 49.93156440796391, 48.907621829740464, 48.424476039025095, 45.44934649621287, 43.666711622668856, 42.53903804286834, 42.63111960503363, 41.671339158088934, 43.552366687405495, 48.319917417341664, 48.75708910726732, 58.96797180175782, 62.10425976783999, 63.783379370166415, 62.35580136699062, 65.48516242734848, 60.60074467812816, 60.353890311333444, 59.18018379519063, 57.371418091558645, 60.033138490492306, 59.91657349371142, 58.727907057731386, 63.86536082913799, 63.35866512790803, 62.999407399085264, 59.21310424804688, 59.75456391611407, 61.409082412719734, 60.90752893878568, 56.7692832792959, 60.175489148786, 58.04611282963907, 64.22228867007841, 59.11686105112876, 61.130178359247026, 60.01775103230631, 73.31156961379513, 73.59859297352453, 77.85660036148565, 70.59855245774793, 4.568398758288353, 0.6921688359110587, 28.890911763714207, 73.47050405317738, 54.75618170153711, 41.828755640214496, 39.2272985366083, 38.85703463708201, 67.8558272700156, 22.245169378096058, 0.40112547576427465, 0.2209144151739536, 0.11259134468292037, 0.05782355809764517, 0.13221710770120546, 0.028669942328105533, 0.0588745273078882, 0.01919636882150606, 0.030853620414892514, 0.10067828675551761, 0.05950670306300444, 0.05804491537292639, 0.04992897990309904, 0.04798367965005098, 0.1339186809115833, 3.8524833417707876, 74.74971448221515, 48.88453475890621, 27.846082564323183, 55.40596154428298, 61.76208396111766, 79.29392937690982, 48.40131444315757, 0.39037104155267444, 1.3873125444496832, 0.881050632845971, 12.852562723621247, 97.08241155070644, 77.47554209924515, 81.48743644837411, 78.9145734233241, 80.20048326061618, 78.66980967983123, 67.88236602660149, 56.1374718143094, 63.29633866586993, 73.4728810095018, 74.21529939097744, 71.9037603562878, 72.09037103960591, 67.11997493620842, 68.34149514475178, 68.53013761581914, 68.10385442549183, 65.57071324317687, 66.4767768306117, 66.40809612889444, 66.17603302001953, 64.93661895875009, 67.00442975567233, 66.52633205536874, 67.73627342716341, 63.536085697912405, 60.95735480708461, 53.506773441068596, 52.27529041228756, 50.81474096544328, 47.2725857457807, 47.342325487444484, 47.18293997549242, 45.222060834207845, 44.04749531899729, 44.97597525196691, 45.47262184081539, 48.33479104503509, 50.68889171846452, 51.92978059091876, 48.70420379023398, 48.71823803071053, 46.92645618992467, 49.07536591252973, 53.98604000768354, 54.49414383980536, 52.46603527376729, 53.60462480975736, 55.95594452273462, 55.50540931763188, 59.108498557921386, 59.02744277831047, 58.95380420069541, 56.85150008047781, 57.50290378447502, 56.47558012316304, 54.802222482619754, 50.66806393284952, 49.37598420727638, 55.21063927681216, 55.61354121854229, 54.480976443136896, 54.502282757912916, 55.16386501250729, 52.66214986001292, 55.7995557015942, 57.14728993754233, 58.664564701818655, 56.13749142616026, 56.66234377891787, 57.19970849252517, 57.09935465166646, 55.29697848904518, 53.52418091989333, 56.236480282199004, 54.585774329400834, 52.14885280978296, 52.483191720901004, 45.92514176522532, 42.82062499753891, 44.2731688868615, 53.2829551542959, 52.386422926379794, 56.95235990708875, 57.548062032268895, 57.036412377511304, 57.7256198852293, 59.3441310236531, 55.883341450845045, 54.659546267601755, 53.45702602017311, 53.42470176758305, 51.41349077224732, 48.29972113332441, 46.497286135150546, 45.25400461689119, 46.97920814637215, 49.513628021363296, 51.94251652686827, 49.94177825989262, 49.24405528653053, 48.32667566114857, 45.91277060970184, 45.350047772930516, 45.21520845351681, 44.08598553749823, 45.739182195355816, 49.27264544271654, 52.08796977996827, 60.51247958214053, 65.14103328028034, 64.69278481698805, 65.67961392864105, 66.17527992494645, 64.216679680732, 63.504549841726984, 61.99319393404069, 61.19921599664996, 61.221047909029075, 64.94522463890814, 62.64509577904979, 65.39639919034897, 64.39675569534302, 66.91399558897942, 63.692278400544204, 63.140620570028986, 63.86730632474346, 63.90663593046127, 58.97511836021178, 64.80692578900245, 61.80179011437201, 67.27057041660433, 62.00667119795277, 64.41448873089206, 64.19303955570345, 76.55430286161362, 77.96762697158321, 83.23494649702504, 77.7865154512467, 4.5158066384253965, 0.9058606660654469, 31.489242738293065, 82.31047522637152, 61.958692766005, 51.21470505191434, 39.45785153296686, 40.646933740185155, 77.93947219848633, 27.46993903190859, 0.41922096283205096, 0.1872889622445068, 0.14025111772841023, 0.07083365393261756, 0.021025037933741848, 0.04235574111883198, 0.012017941109896188, 0.1437433142094843, 0.1512170534941458, 0.24603696630126048, 0.2979281310352587, 0.16280747349223784, 0.19383746649949782, 0.200670603061876, 0.3924639631182917, 6.327485192206598, 90.67369799460135, 57.07380040999382, 38.09922487505021, 63.78172805232387, 73.08630005005868, 83.8997882412326, 52.18132611243956, 0.629651709910362, 2.460894555814805, 1.0908455882341632, 13.930520261487654, 96.90942718136696, 81.74116673008089, 83.81485323752128, 81.45053478979295, 81.89334684802641, 82.26358721333166, 71.2724470323132, 59.40606524867397, 66.09767975345736, 73.15589858639625, 75.82722094751175, 76.42418215351721, 76.64483116519067, 73.79832006269886, 71.46607875823975, 70.57038199517035, 70.5648357637467, 68.69982719421387, 69.36588487317486, 68.01391447744062, 67.22344706135412, 68.546478209957, 70.30738707511657, 68.38812428136026, 69.8567851897209, 66.74217224121094, 64.56099710156842, 58.01443969049762, 54.73646394668087, 52.704636973719445, 50.860495413503344, 51.89362418267035, 50.08991833656065, 48.557028616628344, 47.10513584075436, 48.70091292165941, 48.303455229728456, 51.791944580693404, 52.64424031780612, 57.601418033722915, 51.4933463065855, 51.90250835111065, 49.13996342689761, 53.327034750292384, 57.480703169299716, 57.37814887877434, 55.554501702708585, 57.749409060324396, 62.36261452397993, 59.76769601145099, 64.66990955414312, 61.977441695428666, 62.41792778814993, 62.69605128995834, 60.99152257365566, 58.55894311781853, 57.22413701395835, 54.801598825762355, 52.27685543798631, 58.81390894612959, 59.629726640639774, 58.693590241093794, 57.76944452716459, 59.67434752372004, 54.869326391527736, 59.306397822595414, 60.79365861031317, 59.881264317420225, 58.861526520021506, 58.95760889976256, 60.29431343078614, 60.07155418395997, 57.62379907792615, 56.93552901667934, 59.397055564388154, 55.0576001597989, 55.78474483182354, 51.994633059347834, 44.70002866560414, 45.17901674393685, 46.39085654289492, 53.14403656990298, 54.38698076432752, 61.14476957628804, 60.97158908843995, 61.84446550184681, 59.965375623395374, 62.71536111831666, 61.275137393705315, 59.565242875006895, 57.60146510216498, 55.84935411330193, 54.126998224566066, 50.59794372127902, 48.17173811697191, 47.87926658507317, 48.61823720316733, 51.18552654020248, 55.07423100932952, 53.456449431757775, 52.87233398806665, 51.19527363008069, 49.82449154700003, 47.41031977438158, 47.627348438386, 47.947982588121974, 48.68357996786795, 52.71787889542119, 55.2893102553583, 62.52310222195041, 68.56092037693148, 67.37343065200314, 69.78051077935004, 71.90081857865857, 65.18086102701002, 64.43758756883683, 63.23673040636125, 63.7334946663149, 65.16674441675987, 65.91233991807508, 67.40975179979878, 70.14236511722689, 67.10487381104501, 69.26529961247599, 65.91781554683563, 64.98763330521123, 66.7497581051242, 66.50072682288386, 61.46141467555877, 67.41885954333891, 64.25754293318718, 70.91399731174593, 67.19785751834993, 66.22968319923648, 68.78384436330488, 80.66952028582173, 84.76753419445407, 86.61060102524297, 82.62129952830654, 5.7678973097955035, 1.0384627023050863, 37.91186109665902, 90.90922847870858, 70.07522198461717, 60.137151902721776, 55.827145653386275, 55.30956929729831, 87.49077304717034, 33.4654152008795, 0.4208397679030896, 0.5213761521923927, 0.23602205208472668, 0.21949767345382323, 0.23842310953524806, 0.12213913678762414, 0.08773791258253398], [0.03453953371893975, 0.07809827419658823, 0.03576474579712076, 0.03169130883179605, 0.03662691646886449, 0.013219625670312634, 0.1618960127234459, 0.21291313242287407, 2.137766759241781, 60.12565543574672, 46.19940957715435, 55.87144490211241, 47.22120269652336, 51.6643028105459, 67.34571518436556, 56.28372130855438, 0.10617446965507923, 1.3794674363828476, 0.5586904563730763, 27.555330991745, 95.05784880730414, 71.51361788472822, 78.3072022468813, 76.66638851165771, 75.68359944128221, 62.42258756391464, 56.87492055277671, 63.00230603064261, 72.07819600259104, 71.8117101730839, 69.68014517138081, 71.17070859478366, 66.54792862553751, 67.19977163499402, 68.24708369470412, 65.00561345008113, 66.39059451318556, 64.52111444165631, 67.65389580880442, 64.95809001307335, 69.21269278372489, 65.43525418927594, 65.72152053156208, 62.238157718412346, 64.23452646501603, 64.24142591414913, 58.746805037221606, 50.850332552386874, 46.78991456185618, 48.23285648899694, 46.95350485463297, 43.715403925987985, 43.775702522647, 37.58375875411495, 43.55234315318447, 43.501160144805915, 42.36611250908145, 44.424556686032204, 44.113544110328924, 46.53534489293253, 45.289007848308934, 43.96154049904116, 43.546820455981845, 45.42812647358064, 50.72174156865766, 51.587365519615915, 50.64283524790118, 53.72690077750914, 53.480799505787516, 53.008373552753085, 53.580816022811405, 54.090453501670595, 55.09083047989876, 53.19618055897375, 52.09336696132537, 49.05080403051069, 49.54252412242275, 48.13531106518161, 46.47035121917725, 47.05296439509238, 48.81978427210162, 51.17773279067009, 53.032103892295595, 50.9733380809907, 52.64038855029691, 54.90028565929782, 53.629971165810865, 57.135640498130556, 53.16866905458512, 51.59109961601996, 53.90487832407798, 54.0213256497537, 53.83749200451759, 51.31329774856568, 51.21613671702724, 51.64880944836525, 51.35843638450869, 50.93789162174348, 49.89323500664004, 41.808594657528786, 47.11431418695758, 46.53840434166693, 52.19052407049364, 48.849821782881214, 52.47677080092892, 55.32221109636369, 54.79262836517827, 52.56069775550596, 54.577392224342596, 50.47249455605784, 51.22257724885018, 48.50393933634604, 49.1329933751014, 45.81579785193167, 43.87430306403868, 43.118125007998565, 46.12052286824873, 45.682472567404474, 46.80825164241176, 44.03217061873406, 45.07745873543524, 44.77604419954362, 42.18619731164748, 42.51802590585525, 41.20228644340269, 41.19141755565521, 43.74943048723283, 45.6315484354573, 49.020468419598, 59.88142513459729, 60.116594760648674, 60.399958549007295, 65.76001467243319, 63.72803080466486, 62.548299527937374, 63.76281046098279, 61.087816761386016, 66.60612875415434, 61.1451578909351, 63.20941502048124, 62.96908747765326, 66.69541758875694, 64.05427394374725, 67.40717088022541, 67.78047069426506, 66.15204380404565, 63.35856314628356, 68.26525995808264, 64.46520105484994, 66.88426402307326, 66.35491663409819, 69.16969576189595, 66.79488889632687, 68.15258595251268, 64.89194316248741, 72.37282876045474, 71.13131230877292, 79.8401508023662, 60.37188614568403, 3.2801558461881455, 0.29979432121880595, 31.004973188523326, 74.03822006717806, 53.55602272095219, 45.51119835146012, 32.98282246435843, 31.19679670180044, 72.39379775139594, 22.478809279780236, 0.4899494482144233, 0.11347282077035598, 0.030810685017176216, 0.03048331266449344, 0.04426600434066308, 0.04007628863497127, 0.0648539699614048, 0.13772400817082775, 0.011662995337598748, 0.07586963249430542, 0.016211584931419745, 0.05657176276849163, 0.05474450134281671, 0.07435115429783061, 0.17082651416140218, 3.716280753574064, 74.57208602659165, 49.072890896951, 55.916426643248535, 53.92469806055869, 58.264216223070704, 72.17612189631309, 64.12555909925892, 0.06411511646283251, 1.5844578560321563, 0.7603930105124751, 32.43612839329627, 98.72116996395974, 75.08871709146808, 82.91368084569132, 76.7340180181688, 80.34949410346248, 66.64796475441226, 61.20432684498449, 66.14396372149068, 77.12638839598625, 74.67949621139034, 72.34166945180586, 73.1127917382025, 70.15947449591853, 72.20147609710693, 70.54105051102178, 67.64709441892563, 69.67356343423167, 67.51609509991061, 70.16993937953826, 68.59488025788339, 71.50287059045607, 67.4444490863431, 67.4372789936681, 65.75680225126206, 65.97219528690462, 66.81159819326093, 62.511146837665194, 54.0876333175167, 49.36582526853008, 51.3521017566804, 50.25650532014909, 44.61764712487498, 45.439834748545, 41.21855251250729, 45.059592339300345, 45.426349639892585, 45.40555323323896, 46.03733724163425, 47.46444456038937, 49.46202924174648, 47.88705641223539, 45.697338350357555, 47.36573027026269, 47.38959004802089, 54.368855491761245, 54.97311622865739, 55.06219717764086, 57.55383183879238, 57.94508041874055, 57.00106789988857, 57.48567281230804, 56.746757107396284, 58.255798816680915, 54.78570145945395, 55.75922981385262, 52.65862757159818, 54.395653124778505, 53.0044041141387, 50.20697362961308, 52.46112446631155, 51.18050198401175, 54.45180577616538, 54.157004356384284, 54.73596188329882, 53.63385823465163, 56.451806637548636, 56.74552156079201, 58.51787590211438, 54.462686431023386, 54.982612286844564, 56.38353778469948, 55.072818956067486, 56.966468672598566, 52.74883816319128, 53.798856658320275, 55.743869812257834, 53.79487545259538, 52.11630498209308, 54.14104030978296, 44.147437310987904, 49.47915823228898, 49.621795223605254, 55.34174842219199, 52.07761472271335, 56.03305439795218, 57.99557308996878, 56.96173044943041, 55.46704069260628, 56.3498563920298, 55.14687330492082, 54.67091329636113, 51.00139871720345, 52.6517673461668, 48.72238397598267, 47.44240084002095, 46.18101366104619, 48.068246379975356, 46.837590971300685, 48.51405512902045, 47.72725512904506, 47.077557656072806, 46.589355930205315, 45.04139646407097, 44.17490959167481, 44.106589748013405, 43.71726312944966, 46.421537322382775, 48.99080745635494, 53.71274886592742, 61.46032425665087, 64.28445431493944, 63.06133377936579, 66.0086811742475, 65.00075363343763, 64.39897967923072, 65.22747447413784, 63.81296580837619, 69.34719870167395, 63.747509294940585, 65.70201066232497, 68.16352936529344, 70.29244284476005, 66.89348943771856, 69.16809543486565, 71.54504391454881, 70.60984103910386, 67.24574181341356, 70.91243620841735, 67.16665898599933, 70.62440087718349, 70.20217341761436, 73.11385077814903, 70.71329747476886, 71.85310686788252, 69.88244533538818, 76.29331619508805, 75.05275680172828, 84.60208862058579, 64.26294011454429, 3.0908737836345552, 0.24119815578864467, 34.87563279367263, 83.61954273716097, 59.438966089679354, 55.58584536275556, 30.46126207997722, 35.72979557898737, 82.7673372145622, 26.08931572206559, 0.33592244550105066, 0.15500868310130414, 0.11625839307183221, 0.05366954591966445, 0.044667526343536955, 0.11718608724373965, 0.048395754514081825, 0.20892581331633756, 0.15617929609312167, 0.09686769647223335, 0.11475832396817785, 0.13487760848816366, 0.103864285554136, 0.31922298513593217, 0.41161211628106337, 4.585303683434764, 84.86167892333, 58.70205079355548, 70.61495580980855, 62.145048495261904, 67.28232183764058, 78.93756635727422, 70.43161638321416, 0.1895776958835702, 3.5743338542599834, 0.6554417840896115, 32.68018807134321, 102.75459812533472, 77.51981781375024, 84.55869151699929, 81.56306759003671, 82.08162846103792, 70.38674446844286, 64.17360028912945, 67.8305358271445, 78.68192980366369, 76.69768118089246, 75.65187531132852, 79.07215072262672, 72.98184733236991, 72.98897035660283, 74.14541844398745, 71.46663573480421, 70.99629648270147, 70.1170579848751, 73.19398480076944, 69.97687247491652, 77.06732534593152, 69.97270691779353, 72.00988400367, 69.37822464973696, 69.54177179644185, 70.9463176419658, 65.96291495907691, 56.98630802093014, 51.86683047202326, 54.99669359576318, 53.548017163430494, 46.87166852335776, 48.92869672467632, 42.82899533548663, 47.81131936657814, 49.267263950840125, 47.69046721919891, 49.7259263069399, 49.09337743636101, 53.367823477714296, 49.73129210933563, 48.941114948641875, 51.01612329483033, 49.759180161260794, 58.2323234311996, 59.7517829556619, 57.6301807741965, 59.86312335537326, 63.01059007644654, 60.73616450832736, 63.477842423223684, 59.930344935386415, 61.263013347502685, 59.06088098402947, 59.519672778344926, 56.50191883887015, 56.163010366501354, 54.7584919775686, 52.94286212613506, 53.47847746264551, 55.915806908761304, 57.49149753201393, 59.63080529243716, 56.5250333662956, 58.36562125913559, 60.576775074005134, 59.74879018722042, 61.81841311916229, 57.73722617856918, 56.88768394531743, 60.349752210801654, 59.61668083744665, 59.80812388081705, 55.80123447602796, 57.2979756324522, 58.97528309975902, 55.44271023042741, 56.82155278421218, 55.78850246244862, 46.54585684499433, 49.30532270862211, 49.062990834636075, 58.255500716547814, 56.50990086217081, 58.69870108942832, 60.01840999049526, 59.47903702335974, 59.85067375244633, 59.978425348958666, 59.38406859674762, 57.01112485701039, 53.98142337799073, 55.346412120326875, 51.53409581030569, 49.63536662440146, 47.741748286831765, 53.24145255550262, 48.97629860908755, 50.874380603913345, 50.04390501206922, 50.31352089297388, 49.08259484075731, 46.86757749126804, 48.07844454242338, 46.808851765048125, 47.5721763795422, 50.061794942425145, 52.08852283416256, 56.06006383895875, 64.15653797887987, 65.54533550816198, 64.36480406791934, 69.15726969319006, 66.72060705000355, 68.6278203225905, 68.33601951599121, 66.48923427827897, 73.72076695965183, 68.60797312951857, 68.48857618147328, 69.57257809177523, 72.87119726980887, 70.13916446316627, 72.74505384506719, 76.77248862481888, 71.76119004526447, 67.92959920821652, 74.89397925715294, 69.7747919636388, 71.32699151192942, 74.1620179145567, 75.57820535475209, 73.6260966331728, 73.18698729238203, 72.97322596273115, 79.09745001023816, 82.53694503538071, 89.72399019425916, 72.13296013493692, 4.877593805713039, 0.40231781500962477, 43.19484656856906, 92.35810495192005, 68.03337727823566, 66.43527030944824, 44.879994853850334, 46.60250371502292, 93.39441868566698, 30.09546772126229, 0.6443887900921607, 0.3658924792562762, 0.16981477248332194, 0.13160342530858132, 0.304635537247504, 0.2528666401462209, 0.12009744352150349], [0.0702143254719915, 0.09712858771484706, 0.026084790118939938, 0.07397573291053695, 0.020241835605232947, 0.02246686520295278, 0.24475482622942618, 0.10978570087782799, 2.5055576043744243, 63.36656870380525, 45.41342935254497, 31.9544848703569, 33.587934355581964, 57.83290847655266, 61.24587651221984, 73.3817643503989, 0.813989747435816, 0.4515331725199377, 0.39219506625686923, 44.38251280015515, 92.5451078722554, 71.53246095103603, 74.22161440695487, 66.01019520913401, 64.70106494042182, 57.086222556329545, 60.44100615286059, 72.15269750164401, 71.85025138239708, 70.65574061486029, 75.04920313435217, 74.26442315501552, 74.46708417707875, 67.6230110660676, 70.00204624668245, 68.91504764556885, 67.29234741580102, 67.11411491517099, 66.56594014936879, 67.43204655185824, 63.679067857803844, 60.966301733447665, 60.010090643359774, 63.41127587902931, 62.98673422105851, 63.51117080257785, 58.875650975012014, 49.684568835842995, 47.73609615141346, 46.745529020986254, 48.4043425129306, 44.13538778981855, 42.2558036927254, 40.717979631116314, 44.11472474375079, 42.92651330271075, 44.038022795031154, 44.173501460782944, 42.73712558131064, 44.38035549656038, 42.29552553546044, 40.33159479018181, 41.129663759662265, 42.73625481513239, 49.20347052235758, 49.177731929286836, 53.18087547056137, 51.759479122777144, 51.536143287535644, 51.71745877112112, 50.64894237825948, 54.44633014740483, 52.874840382606756, 51.51193834120228, 54.876386657837905, 55.256766350038596, 57.409657278368556, 57.21827699292091, 56.54062478773056, 51.02369739163307, 52.00143444922663, 54.267701487387384, 52.30823439936484, 52.61615222500217, 50.72441662511518, 56.02965370301278, 56.907491914687625, 56.70432882924234, 51.412490567853375, 49.642564173667665, 55.48604849846133, 54.33122034995787, 56.49592153487667, 50.65510442180019, 52.85704066676479, 52.78281765599405, 49.9964992461666, 48.1561113942054, 47.234487764297, 45.08001612078759, 44.37022793677546, 42.92024143280522, 46.42725221572384, 49.32759000409035, 46.41220600374284, 51.99672760501985, 54.12712374041158, 56.907264417217625, 52.46408585579165, 54.30686635355796, 50.790571320441465, 51.854373024355986, 48.9199576839324, 44.592457663628366, 41.99424436015468, 42.2506183193576, 41.76237344741821, 44.192858357583326, 43.233262262036725, 44.36810201214206, 43.175709324498335, 40.17032654054704, 40.816458579032656, 42.850615439876435, 41.44617942071731, 43.58857800883632, 44.057077669328265, 46.103484092220185, 47.875061804248446, 58.3821540494119, 61.78162913168631, 58.248793463553156, 58.25991338299167, 68.67040157318115, 71.62338149163031, 62.7726238004623, 64.4615493282195, 64.37904227164485, 65.56750082200574, 66.77652435918009, 62.99317083051128, 67.34267142511183, 66.9440487892397, 69.85405522008097, 66.5334080111596, 70.58243151633971, 69.33467849608391, 70.19913750310099, 68.30946506992464, 72.41808506750291, 69.61046034289946, 76.16485072720435, 74.56882261460828, 74.44003551237046, 69.60648305954473, 76.1287727663594, 68.80551153613676, 77.53746847952567, 44.9573871397203, 1.5402576471528702, 0.02685950419324781, 36.692776679992676, 73.6657282613939, 54.295083553560325, 40.431819192824825, 49.86556268507435, 43.24142079199515, 64.76971426317769, 21.705823867551743, 0.3153983677827543, 0.18742615326998696, 0.05778831039224902, 0.04705860166840496, 0.044253685646840644, 0.053005749885473526, 0.06272025804425921, 0.09724853410115165, 0.06354710440181437, 0.08428679373595985, 0.06851003264948245, 0.04669230821872911, 0.04652794022413512, 0.07690981135613496, 0.12950621365058806, 2.71980187585277, 71.80269656642791, 51.5477809598369, 30.574851958982407, 40.37042233251756, 66.06619881045434, 67.49938580297655, 80.173277701101, 1.00104482303704, 1.0912299805110501, 0.6310184720543124, 48.41215979668402, 96.50664683311217, 74.86034101055515, 77.3036010803715, 70.66629963536417, 68.91161949403825, 60.53442132088446, 63.98349869635798, 72.11138709898918, 74.61947610301357, 72.21389432107249, 77.2310293874433, 75.47103051216372, 75.81542245803341, 72.51795645683043, 70.4617166519165, 71.89023602393367, 71.29551841366676, 70.88599158871558, 68.19351196289062, 69.1186814154348, 65.4195607862165, 64.10465678861065, 64.06873964494275, 65.77406068002024, 66.53733038133191, 67.89004602739888, 62.39500937923309, 50.769923963854396, 50.466136394008515, 51.415036186095215, 51.40433203789496, 46.02307158131754, 45.02041570601925, 43.23846724725539, 45.969342954697154, 44.58585631462836, 46.50149091597527, 45.904878800915135, 45.25160412634573, 46.79727292829945, 46.22818408473846, 44.79012943083241, 42.09237813949585, 44.784269409794966, 52.033331163467906, 51.927082000240205, 56.03240328450357, 53.66326424383349, 54.06795086399202, 54.57036333699381, 56.0353176055416, 56.423942119844504, 54.27025102799939, 54.33282459935835, 57.64572904955957, 58.45692619200676, 59.52257140990227, 59.725699194016, 58.35093590521044, 52.58109800277218, 54.151979800193544, 56.17590711962793, 56.13022719660113, 56.53984423606627, 54.218032513895345, 57.75897572117468, 57.65981428084835, 58.56129261755175, 52.91873954957532, 52.737796691156205, 60.818526437205655, 59.24571875602969, 59.30962593324723, 52.065569123914166, 56.0562591398916, 54.64675149609966, 52.648637294769294, 50.61610037280668, 51.07921461905203, 47.98642181581067, 46.922274943320986, 46.93888618100075, 48.90727273879513, 51.78486862490254, 50.083615087693744, 53.132222390943966, 57.980103262009166, 60.82776754133163, 57.08193148336103, 57.24176414551274, 52.164581514173946, 54.7169933011455, 52.365010707609116, 46.971230045441665, 43.493997896871264, 45.08673906326295, 45.55482687488679, 45.05863920334847, 46.93073549578267, 46.28061440683181, 45.973481055228945, 43.06477685128489, 43.02986775675128, 45.563467856376406, 44.404336867793916, 45.413182243224114, 47.01437219496697, 49.895635497185495, 50.234889138129454, 60.35776561306369, 63.270678520202644, 63.46447498567643, 61.186711480540616, 69.16581261542537, 70.03392727144303, 64.96577001387074, 66.71067560872724, 67.56343026315012, 68.39666720359557, 69.22080424524123, 65.15614617255427, 70.48360347747803, 69.82273117188485, 72.50745234950897, 69.41435752376434, 72.90639661973523, 72.46148217108943, 73.42522421190816, 71.95852448863369, 76.1744213104248, 72.92863645861226, 78.36150353954685, 77.89409037559264, 77.68275307070824, 75.37569338275541, 79.4677060650241, 71.40718044773226, 83.30379978302987, 49.823467808385054, 2.143610110205989, 0.03344443018337892, 42.48441903821884, 82.3555040359497, 60.95701356087962, 49.9735886819901, 54.010903912205855, 50.99777052479406, 72.16692001588883, 25.971656384006625, 0.50163927578157, 0.15064251819445243, 0.12655970925885823, 0.10690609894452557, 0.05819636712511701, 0.05173237768993263, 0.06883923595230426, 0.2613118248841455, 0.20815039444113934, 0.16953069175924027, 0.11879176922863531, 0.10759084365300595, 0.1125699248645575, 0.374383797809001, 0.30825637521282323, 4.385054428731242, 86.3976163248862, 59.48295547116188, 44.3451718361147, 43.87454625098936, 75.09355729626071, 73.084440846597, 88.22396601400068, 1.1787812051273163, 2.1962956315086735, 0.8445204349775469, 49.272739579600675, 98.78375530242921, 76.96586147431405, 78.7209338526572, 72.58789231700283, 72.3462821591285, 62.545855891320016, 65.84784830770185, 75.5415625726023, 75.97010504814887, 74.56296259357084, 78.71245368834465, 78.25099468231201, 77.25996078983431, 75.27649664109754, 72.54725656201764, 72.72348865385979, 73.10459398454236, 74.86314942759853, 71.6911522034676, 73.21436543618479, 68.62377243657266, 67.38647645519626, 69.2595023493613, 68.40357841983919, 67.00729308589813, 69.52801212187737, 65.8128607657648, 55.03413654142811, 50.07121255320888, 52.66553486547163, 56.76998930592691, 49.474996597536155, 48.313210164347005, 46.51428176510719, 49.64651400043119, 47.88638960930609, 50.655171102093114, 50.426183131433305, 47.58917593186902, 50.37837336140294, 49.59949654917563, 44.8252542557255, 45.53759590271981, 46.92287114358718, 57.403436399275265, 52.7235584874307, 60.36430812651112, 56.27044800789126, 58.033926025513686, 57.90153034271733, 58.487975674290816, 61.45051833122008, 59.88889724977555, 58.406056973241995, 59.269860944440296, 62.02412574521957, 61.13030779746271, 64.41409649387484, 60.560516849640884, 56.24560371521981, 58.66024617225894, 57.03875795487435, 59.81733752835182, 58.56584648932181, 55.8885189794725, 61.96810645441856, 61.75082675872311, 61.84732098733226, 54.98641306354154, 55.752161702802105, 62.12687223188339, 60.53773964605024, 63.17901272927562, 54.06706833070325, 58.616248946036066, 60.24945720549553, 55.171101785475216, 52.58658932101343, 54.55022981089931, 49.58614480110907, 49.40595503776304, 48.23353113666658, 53.190504889334406, 54.372260109070815, 53.69804782252158, 58.2415331563642, 58.99720522665209, 64.09887521497666, 57.47810656024564, 62.26177823159003, 55.23995507148005, 59.4819748786188, 54.65740857585784, 50.67279038890716, 47.83323757110104, 48.00597090874949, 47.58117429671749, 48.57056863846318, 49.579488538926654, 48.13085133029569, 49.108862953801314, 43.8620299677695, 45.53040227582378, 49.797152626898985, 46.23153771123579, 49.64301524623748, 49.88997943939702, 51.85649110424904, 54.355072282975726, 61.37006659661571, 65.63482438364338, 64.19111759431901, 63.70997613476169, 72.92810301626884, 71.07483017829158, 69.209758850836, 70.57694804283881, 71.06140782756191, 70.86663076954504, 71.68598251958048, 69.18908011528754, 72.71241972523352, 72.63393309808546, 75.36341636411606, 72.84800821735014, 76.3963411700341, 76.26735010454732, 75.0350590675108, 76.91583556513633, 79.4052383976598, 77.81678045949629, 81.67939724460726, 84.11886830483714, 81.14491939544678, 79.116544108237, 83.05116776497134, 77.4484306766141, 85.95049750420355, 60.47967680038945, 2.999827236898484, 0.2740536750324311, 49.94124481754918, 91.45242967913228, 69.19642279225012, 59.157959645794286, 72.26929387738629, 60.89708758938698, 82.35429594593664, 32.58025196290786, 0.5534070850380006, 0.3483844590523551, 0.2829500089489645, 0.20043389721503183, 0.16869105939422885, 0.12467163194331432, 0.1580634893428895], [0.066144184599961, 0.036310648560644164, 0.09827686924367182, 0.05389766775131707, 0.045799574469246214, 0.02410344159861486, 0.037226962496436415, 0.09253189929070012, 0.4682302120472155, 46.99857288791288, 54.17888333720546, 56.781344567575765, 34.970738503240774, 50.244691141190074, 58.960805631453, 80.9646237281061, 3.4399691416371256, 0.6036055785033011, 0.3806907238979494, 54.754267584893014, 87.21707790128647, 70.01417421525525, 72.11035943800404, 61.2492105268663, 60.08372529860466, 58.752100236954234, 71.95805380421301, 72.74611288501372, 72.62495087039086, 71.72680654833394, 66.42060848974413, 60.77258763774749, 54.221986263029045, 70.21064573718657, 74.61386711366715, 59.05770386418989, 61.253191732591205, 59.027329029575476, 61.666017270857296, 62.7985938133732, 62.94909907925514, 63.701225326907256, 65.26563129117413, 66.4155407874815, 63.6793149671247, 63.274514598231164, 51.70773521546395, 48.856536880616225, 49.435843498476096, 47.35348070821455, 50.528623673223684, 46.152827508987926, 42.54196413101689, 41.42469267691336, 42.552350567233184, 42.91721336303219, 42.91280854132868, 41.7054049430355, 42.881959099923414, 44.62343654324932, 41.48683870992353, 40.52729360518917, 41.4346751090019, 38.5664850665677, 42.875969640670284, 45.69512613358037, 47.65885683798021, 51.344488436175936, 49.31127294417351, 48.830402128158084, 48.21885754985195, 50.41762059734714, 51.999033958681174, 53.89335832288189, 56.003181626719815, 57.77202544673797, 54.37610010946951, 57.95446665056291, 55.57517651588687, 49.21778717348653, 51.0053877676687, 52.80965843508321, 53.415068426439845, 53.6418677145435, 53.02101927418863, 54.48744050918087, 55.14687330492082, 55.170176106114546, 52.915789927205736, 48.22128941935878, 58.95267455808578, 53.06407905394032, 55.972285116872484, 50.14097975146387, 51.64304748658211, 49.399891053476644, 52.27128174997146, 49.96680690396217, 49.91454132141606, 50.912945347447554, 54.88066988606607, 53.85165960558, 53.542984762499415, 50.01101201580417, 50.64299998744842, 46.68253183364869, 47.68865900654947, 51.62931919097901, 53.46283505039831, 50.49769970678514, 50.292865691646455, 50.43543208029963, 46.51248531956827, 43.22537045325003, 40.659053864017615, 39.09737786939068, 38.35483397206953, 44.33546004756805, 44.807536909657145, 44.23799699352634, 41.99207921181956, 42.604282748314645, 41.01507563744822, 41.85468642942367, 41.78202452198152, 45.102844315190474, 46.26284214758104, 47.37030375388361, 45.50404787063599, 56.851249048786784, 62.31859376353603, 62.85317359432098, 58.24379244158345, 58.04922326918572, 82.25575031772738, 73.49759978632774, 60.27163820881998, 70.14559715024888, 61.43027497876076, 67.46762244932114, 66.45824755391767, 70.6801377573321, 66.92420159616779, 69.05480953954881, 70.03653956997779, 72.83043599897816, 68.55513095855713, 73.42683238367881, 71.76594395791331, 75.07771876550491, 75.28212131992464, 74.07314485119235, 74.44507968041205, 77.25506567185926, 74.00713136119228, 77.00287295926002, 69.16091749745031, 74.88298093118976, 32.14514343969284, 1.1208325984977907, 0.13421111199403965, 40.244941788335005, 74.95509762917796, 50.21288071909259, 50.68025858171525, 31.004088694049468, 33.87644821597684, 67.6778850247783, 15.590752670841834, 0.2504178860615338, 0.024285377904532418, 0.04463389508366104, 0.01863904943269107, 0.10617345841901918, 0.04562524733163657, 0.03625046469331269, 0.024662465533061374, 0.05971975977562609, 0.012398826619309765, 0.0626237539484376, 0.08391112720053043, 0.05025870797614898, 0.03784303891382391, 0.06755506574747062, 0.6715850339781854, 57.93325839504119, 57.91816511461812, 49.40138155414213, 42.25667445890365, 58.3179566168016, 64.74341477117231, 87.69232011610463, 3.5876664807719574, 0.3416572877716634, 0.5998289488977002, 59.88215861781951, 90.34567017709055, 73.9258284722605, 75.8387605605587, 62.78439875571959, 64.99499951639484, 61.94088128305251, 74.49370922580843, 73.9965723406884, 75.06115851863738, 73.852338944712, 68.54562313325944, 65.49359944558913, 59.12522746670631, 63.85233071542556, 73.05541530732187, 61.83362014832036, 61.87184364564958, 62.73605946571597, 64.45563439399966, 64.63725582245858, 66.56989389850249, 66.53889932940083, 65.83259813247189, 68.65901101020076, 66.90029082759735, 66.31733248310705, 54.246038236925685, 52.26962650975874, 50.79127342470231, 51.28667662220617, 51.488972863843365, 47.44271855200491, 46.241025924682624, 45.310055286653586, 43.9628662601594, 45.338833716607866, 45.55215181842927, 42.92175546769173, 45.41523364282424, 46.261461473280384, 43.99971692792831, 41.88617129479685, 43.0613330102736, 41.21008803767543, 47.11693433023269, 48.128046835622484, 50.17196647582516, 54.53182212768063, 52.45298947057417, 52.02225831247146, 50.09074987903718, 50.87060728380757, 54.377327811333444, 57.029960078577844, 60.920343322138635, 59.024959917991396, 57.35723480101555, 58.903405666351325, 57.250310990118216, 51.163549500127, 54.046773987431685, 52.83429484213553, 55.06834745407105, 55.436301077565844, 54.29418140842069, 57.33051561540174, 57.77226078894831, 59.57466048579062, 54.107460898737756, 50.29752154504099, 59.97657006786716, 56.69104768383888, 57.085916611456106, 52.469679155657374, 54.8702520708884, 50.991796755021625, 52.825885280486084, 51.880072393725, 51.67027265794816, 53.38541530793714, 57.466743453856445, 57.37017862258419, 57.14734485072475, 51.179187990004024, 53.836742831814675, 51.65610113451558, 50.88888552881057, 53.85439741996027, 56.41843511212257, 53.55189246516074, 54.27418124291205, 51.724762224381976, 47.31546117413429, 46.48242819693781, 42.51546459813272, 42.34334315023115, 41.08786306073589, 45.29378921754899, 46.16202546704201, 46.16038591630998, 45.26509315736833, 44.652540529927904, 44.19201112562611, 44.17921635412401, 43.5074947726342, 46.12660254201582, 49.023712219730506, 49.71422195434571, 47.85059405911354, 58.19696326409617, 64.4932185449908, 66.56896821914181, 61.281413185981016, 60.076359087421054, 78.64708346705284, 70.02508624907463, 63.84136769079394, 73.12939905351209, 64.76044178009033, 70.18025521309146, 71.20329564617526, 72.8260507891255, 67.3642130820982, 72.17783204970821, 71.63336784608903, 74.04236993482037, 72.91557496593845, 74.21525232253536, 74.92817448031518, 76.91402343011673, 76.29812502091931, 78.70444420845278, 76.42918709785708, 80.54212170262491, 76.739940797129, 81.5142733050931, 72.67593383789062, 84.26298402970838, 35.297671979473485, 0.8920493265313487, 0.22373329697837754, 48.613361697043146, 83.19938628904282, 58.464657183616396, 59.13090705871583, 37.32400763419367, 38.94266390031384, 78.05876716490715, 18.804785936109482, 0.2709379035138315, 0.13500313965543626, 0.0434087481229536, 0.06683961623498509, 0.030204724790828846, 0.0851646462275136, 0.016633910051877462, 0.21200792293154427, 0.1501379880092798, 0.18100098917080512, 0.14733134828988584, 0.21558420522318733, 0.10010429537825047, 0.0661822515089185, 0.13786228704116038, 1.390171584583098, 69.23569356241535, 66.54086835922735, 69.84599082700669, 49.67739482079783, 67.38709618968349, 69.27619595681468, 94.59560532723704, 4.056477724544464, 0.9058922288879272, 1.17289372749867, 62.9772577747222, 94.21237407192108, 75.94986561805972, 79.85722095735612, 64.16951317940989, 67.61853171933082, 64.61189769929456, 80.457014114626, 77.45804048353627, 79.47260118299916, 75.42317759606146, 70.64267127744614, 66.84952751282724, 63.839575167625185, 61.14161206829933, 73.2671997624059, 63.71446332623882, 65.14944284192978, 65.34353348516649, 66.19180094811225, 67.46397464506089, 66.79518699645996, 70.11706582961544, 68.3841940664476, 73.79730809119441, 68.24596974157518, 70.51640233685895, 55.80347807176652, 54.425796539552756, 54.13200316890594, 53.78692088588592, 55.08129912038004, 50.47544810079759, 48.72854209715321, 49.07435394102528, 46.81851256278254, 48.91597255583733, 50.70312992219002, 46.865082863838445, 48.015725843368045, 50.018558656015706, 48.052956981043664, 45.32025344910161, 46.03560355401809, 43.30294316814792, 50.40268813410113, 51.763628990419456, 54.72346913429999, 57.06495546525525, 54.33639787858533, 54.33203620295371, 54.15927540871405, 54.86404295890562, 56.54403724978047, 61.037379003340206, 63.42291747370074, 61.56062710669733, 58.01535752511794, 62.872397130535504, 62.3193194020179, 53.66889676740093, 57.1499022360771, 57.02058953623618, 57.86168690650695, 58.411461999339444, 58.253982759291134, 58.85709816409696, 60.554527390387754, 60.632594323927364, 56.865008723351266, 52.34521058297927, 62.90460763439056, 58.49951920970794, 60.66018035334926, 56.71177741019957, 57.17082415857623, 53.56542464225523, 54.75844883149671, 54.677463654548895, 55.54462909698487, 54.35524094489313, 60.42572067629907, 60.15912894279727, 58.87573334478564, 57.125101089477546, 57.203960341791955, 53.85940628667032, 56.287647601096864, 58.393968228370916, 59.54590559005738, 55.43477527556881, 57.74481596485261, 55.803823240341686, 53.01528869136688, 50.05196156040315, 46.36716150468396, 44.449636320913996, 43.53071520405431, 49.409798960531916, 50.11480185293382, 49.74493803516511, 48.479938353261645, 48.652459882920795, 45.62293098818871, 47.30455306268508, 46.99756876114876, 49.855486116101666, 52.460673393741736, 52.68699415268437, 50.510380729552246, 62.93198185582315, 65.91381472925987, 70.6906653988746, 62.50418070823916, 63.42463154946605, 82.19845233425018, 68.92446917872276, 70.45664894965388, 74.50058906309067, 67.71419832783361, 72.30391271652715, 72.78437168367448, 73.93219055668001, 71.6294611653974, 73.86825592287126, 75.20408184297624, 76.2626354156002, 76.01952691232005, 79.30630837717365, 77.19521814777006, 82.8377123801939, 82.36052466977029, 80.46973828346499, 81.27154919408983, 84.35702677695983, 81.2420843493554, 86.23266496965962, 78.80200139937863, 84.56473196706465, 45.036701386974705, 1.7804562420614305, 0.3692920097420293, 53.70544933503675, 91.48094531028502, 65.55634560123568, 70.86077859324794, 44.55624241982737, 46.77717862590667, 89.86223805335261, 23.914435986549627, 0.4147366212019998, 0.1725122753170229, 0.13342342039029445, 0.2150951346923267, 0.11451804049072728, 0.11116521838571757, 0.12093224187171268], [0.021773628409831755, 0.05466722222345491, 0.05498252103045102, 0.04028378737970226, 0.0797968979684576, 0.05961338463690012, 0.04232770230080332, 0.04975965531963495, 0.19144459086800777, 51.20784090411279, 50.885327939064275, 42.25033590870519, 34.564063241404874, 51.08852240347093, 51.40743855507144, 81.88373704110423, 11.184903306345786, 0.42393598885786155, 0.6562782908158918, 62.67113247225362, 86.24395355101555, 73.72630534633514, 73.86095246961041, 63.136929619696836, 69.39002313921529, 64.11328208061957, 71.83915891954976, 67.5222610658215, 72.7271286133797, 63.705308514256636, 63.946844147097686, 56.97528616074593, 76.58041015748056, 88.40469314206032, 54.85894387768161, 57.99594963750532, 61.88513655816356, 64.02473849634971, 66.50741054165748, 67.78816638454315, 65.386930588753, 68.77551324905889, 65.15048227002545, 62.148127555847175, 60.61701466960292, 53.20638264379194, 48.19490755757978, 49.205772953648726, 48.21883401563091, 50.90833264012491, 49.77803107230894, 47.13152946964387, 42.949631752506384, 42.882633747593054, 42.180274532687285, 42.13923869594451, 39.0003776550293, 41.09131082411736, 44.58737034951487, 46.81488437037314, 41.614519703772764, 40.043002482383486, 39.45723179847964, 38.12837593017086, 39.88948091383904, 43.17962777230048, 46.06629610061646, 46.729376700616655, 47.77526886232438, 46.96939829857119, 46.795001875969675, 51.99093426427534, 55.5390004957876, 56.06288010074247, 53.28870142659834, 52.454919276698945, 53.443968449869466, 53.60620160256663, 48.77076641205819, 49.40486854122531, 50.57908496549053, 52.41997880320395, 50.57500177814115, 51.62231383785125, 54.05360675627186, 55.7030693177254, 53.32827029689666, 54.46489080306023, 47.0004830821868, 47.858842803585915, 56.28310157406715, 53.86168910611061, 55.776335270174094, 51.0399438488868, 51.547694667693115, 50.293418745840754, 50.42493189534834, 49.02042135115593, 47.58417883226949, 54.176404399256555, 53.491876279154134, 57.25194661848007, 58.73137443296371, 51.66810358724287, 53.29180009903447, 51.92012763792469, 48.441801148076216, 47.0287908277204, 50.448093491215865, 50.831179618835456, 53.6063898763349, 48.77960351205642, 43.64298128312634, 40.07803317039244, 38.82280411258821, 39.43533712817777, 39.04408854822959, 37.728396154219105, 44.74955643376997, 43.91747267015519, 41.79685500360305, 40.92541810004942, 40.83442303442186, 43.162840027962964, 41.33859665163102, 44.161628446271344, 47.24483105444139, 48.75495141552341, 45.49534020885345, 49.43449812550699, 59.23886637533865, 63.51550109924809, 60.19891354345507, 58.73102141964821, 48.75890516465711, 79.253552498356, 69.14197244951802, 60.33346260747602, 71.79916643327283, 70.3609509621897, 68.32986923956102, 68.24524802546348, 69.84770098040181, 67.77682289000481, 66.33948602984029, 66.94358594955938, 70.85393797966742, 72.97550878217145, 70.84874476155927, 73.16979946628695, 74.74076363348192, 74.51867903432539, 74.907911516005, 77.15057373046875, 73.13311746043544, 74.5060411576302, 71.29616952711537, 69.76414665099114, 21.038452194583034, 0.5034546590139789, 0.8692044620552372, 49.243623825811575, 74.76328588301136, 52.74125622164819, 47.339862238976266, 35.26502217015913, 52.66916698025119, 68.7448638485324, 15.596775470241425, 0.36946100873812554, 0.16218099743127823, 0.058382128124996546, 0.05559165286080492, 0.06908924108551395, 0.04159030819972677, 0.09623501509908708, 0.03012205624291974, 0.04881919429246937, 0.08506548380659473, 0.035218754933486064, 0.08906228708163386, 0.023092778189288034, 0.021421145610210877, 0.05110823436670246, 0.18941502477372849, 57.437772827763716, 56.198025365029615, 43.97442548505722, 43.24426843274025, 56.00868078970141, 55.16654399133498, 91.96613465586017, 13.146366880786035, 0.5612957681859694, 1.1468222232595568, 67.35207726878505, 88.59330423416631, 75.45261106183453, 75.66210485273793, 68.04813323482391, 71.41104790472215, 69.9541070384364, 73.25397353018485, 70.21357967007545, 75.2065372467041, 68.91426317153439, 66.93950668458017, 63.694043467121745, 69.34101704628237, 82.35596687563005, 61.936013621668664, 59.354584140162316, 63.88713390596452, 65.91516402459914, 70.48121083167293, 69.0955472761585, 69.4907574499807, 68.96347322771626, 67.19125224697974, 64.00791545068064, 63.668351942493075, 54.27957842426916, 51.45988456664547, 49.475247629227184, 51.07286037937288, 51.24455428892567, 52.256882729068884, 47.872410282011955, 47.25082051369452, 44.44711031452302, 44.7861913711794, 44.20041676490538, 43.26225249998031, 45.1861789918715, 45.22518304086501, 45.557780419626546, 44.949695371812396, 43.656929231459095, 41.877200834212765, 39.848762789080226, 41.57321714585827, 46.03874145015594, 48.07156078277096, 49.47484362509943, 50.26686429977418, 48.73529249621976, 49.07768795567174, 56.34332564569289, 59.45223939034247, 58.02026441020351, 57.6712989807129, 56.01041447731757, 57.072564863389545, 55.946946605559326, 48.326381483385646, 51.917558485461825, 53.58594648299679, 52.90251662654262, 52.62347136774371, 55.02997098430511, 55.900635180934785, 57.06637144088746, 56.26217180682767, 55.21963719398745, 50.52380308028191, 50.57981060397241, 57.22712586002966, 55.55943212201519, 57.63115352199924, 53.23215653819423, 54.42349018589143, 51.426622867584236, 52.444807406394716, 51.55844196196526, 50.72928428649903, 55.789694862981, 57.0486266382279, 60.32399400588005, 60.98235599456295, 57.00677494848929, 55.912523884927076, 56.347208792163485, 52.39391857577909, 49.49759337209886, 51.52887513560634, 53.761507849539484, 56.606053844574966, 51.60962497034381, 46.62680672061059, 40.8516461618485, 40.1006652462867, 41.82319371931015, 39.780752812662435, 40.97589115942679, 47.3761716196614, 44.871165598592455, 43.06736169322845, 42.525517632884366, 42.69798032699093, 45.71804846486738, 44.78300248422931, 48.0843202529415, 50.82485283574751, 50.69411239316387, 48.245517899913175, 51.18904098387688, 61.94846714696577, 63.591599002961196, 64.29744520495015, 62.055940089687226, 53.522000082077525, 78.76266787129065, 65.96972419369605, 62.99559485527777, 70.77263509073566, 70.4659528117026, 70.4299532982611, 70.89599363265499, 71.69673765859297, 71.74499850119315, 71.38185762589978, 71.36721149567636, 72.5749328059535, 74.77190725265011, 71.30986644375709, 73.71622485499229, 75.93164228623914, 76.72454941657283, 76.23170360442131, 79.87651901860391, 77.71161387043615, 78.09204455344909, 76.62096746506231, 77.07549172063028, 20.170427753079323, 0.35193766677571886, 0.7024336173649758, 56.44425215259675, 81.71341988348192, 61.459194614041245, 53.52864457714943, 37.9289508634998, 53.5746814358619, 76.4540784589706, 19.208662586827433, 0.40764512914803724, 0.22367343486797428, 0.113035989775052, 0.04851583496577317, 0.01829161323727139, 0.04169505923205326, 0.09417176411877717, 0.12032367694642275, 0.2385071800240586, 0.34995644082946165, 0.08795251679276267, 0.17623639725629361, 0.20063358569337478, 0.22169605468309697, 0.1525830955154473, 0.752887984196986, 71.77449472488897, 62.94079542160035, 55.167967811707534, 44.40790622465072, 70.98330559269075, 60.67384589102961, 98.80169622359738, 14.271289898503213, 0.639468421859126, 1.9330889034655787, 69.55000877380371, 89.86853737984934, 80.48607103286251, 78.89123532079881, 71.40212843495031, 74.03516061844365, 72.09258325638311, 75.50326455023982, 74.90149451840308, 77.45771884918213, 70.31269011958953, 66.49126606602823, 62.07168840592908, 67.62006144369802, 83.46740184291717, 67.78894301383727, 58.39625889255155, 68.3109712600708, 67.74345920931908, 73.67788760892807, 72.03046075759396, 72.51680327999976, 73.63616143503498, 74.19681718272548, 66.52575938932358, 68.19543392427506, 58.03883683296942, 53.93995215815883, 52.56050555936752, 53.021886117996715, 53.36661538770122, 56.73526848516157, 51.24885320663453, 49.08317535154281, 48.09304360420474, 48.415733075911, 47.30706337959536, 46.47185348695325, 48.050705540564756, 49.057087667526744, 49.57328727168422, 47.85715226204165, 49.09963361678585, 46.226015014033166, 44.206727858512636, 46.63052904990412, 46.917497496451105, 52.57643822700747, 55.79559803009034, 52.729187088627974, 49.617786561289144, 51.589969973410334, 58.98424571560275, 63.58795119870094, 62.39990449720814, 59.60086976328204, 57.34271026426747, 58.434278426631806, 56.00762959449522, 51.814419761780776, 56.03469002631403, 54.26667382640224, 56.99412922705374, 56.7821329639804, 58.130608527891106, 61.78073483128702, 60.28882603491507, 61.04266243596231, 58.99365940401631, 50.14045807623094, 52.1776783081793, 60.46141816723732, 58.879447829338815, 61.36775239821404, 56.01754142392067, 57.25104839571061, 54.22741482334753, 54.73527154614849, 54.426420196410156, 53.37257739036314, 59.97322820848035, 57.933666321539114, 62.0762187434781, 63.36665891831922, 58.242305863288145, 58.80344014013968, 60.78606882402974, 55.19639715071648, 53.93124449637629, 56.82303936250749, 54.61101870382986, 60.09559439074609, 54.660205225790705, 48.017122207149384, 45.13246213236163, 43.69383481241042, 46.19549897409255, 43.499132279426824, 43.73483142545147, 53.06054892078523, 48.644422946437714, 46.23693881496307, 45.36362701846708, 46.36403145328645, 47.824882922634, 47.778547963788434, 48.848641149459354, 54.307293891906745, 54.022349388368674, 51.38199413976362, 54.07634473616078, 66.12964707036173, 64.83180930537563, 66.10885066370811, 62.825207094992365, 62.275745791773645, 77.58336805528211, 61.139843079351614, 69.41423985265916, 71.08130993381624, 74.27121670015397, 72.98457730200984, 73.93420665494858, 72.64683769595239, 73.5500418755316, 73.0128340567312, 75.03676922090592, 73.80942037028652, 79.71091654992874, 72.47418280570739, 78.95699777910787, 78.57495107958394, 79.73863986230667, 79.602321809338, 84.42316578280541, 80.66632747650146, 85.52911727659165, 78.92611303637105, 82.01854105918639, 27.990849402643022, 0.6075750171176849, 0.8982123506646004, 63.74589327842959, 91.27947668875419, 71.39543687143635, 64.97111228204542, 54.68791677105812, 74.87017047020697, 88.22235784223004, 26.328694051311864, 0.7125091444580787, 0.33686366112482163, 0.22784881323816317, 0.18637701117944333, 0.14127303305412495, 0.16216973593879133, 0.185502705674979], [0.05548238574016479, 0.08863464914142125, 0.03852555813688425, 0.04361667204648257, 0.07397558735383135, 0.01984616842932038, 0.02652578288689256, 0.0769829650920245, 0.014369147303964824, 35.98974281741727, 61.555429966219016, 36.160444367316465, 32.735764134314756, 51.68060810335221, 52.14521677263322, 80.49870106481737, 23.052165662088704, 0.12291034217923881, 0.8342660723194, 61.995484598221324, 86.56914941726193, 71.16675484564998, 75.69617456005466, 68.80296984026509, 72.74542254786338, 71.74531229080694, 71.82201816189674, 70.35985269854146, 73.39112312563005, 70.83074892720869, 70.56143114643713, 60.63032327159759, 62.21934995343609, 46.23470698633502, 62.38339524115286, 68.43460436790221, 70.22318163225728, 65.72642741664764, 65.60983496327555, 60.319393065667924, 59.31697645495015, 61.11128822449715, 58.33610150121874, 54.21634197235108, 48.456368830896196, 50.02605822778518, 49.91830679678148, 46.46620919627529, 48.53831498853622, 50.3995188590019, 49.19023644539618, 46.71743700581212, 44.1241737334959, 43.297565598641675, 42.1380502177823, 43.14820566485005, 41.87596528760849, 38.27788883639921, 40.010482111284816, 41.09302489988266, 41.68019194756785, 38.96164424957768, 37.9780157919853, 39.07410252478815, 41.54694118807393, 42.4439323333002, 44.28670106395599, 42.14258055533133, 44.03053106800203, 45.60430757461056, 52.77299604108257, 52.792596124833636, 50.73055121206468, 49.502880727091146, 50.92290032294489, 49.31601508971184, 46.885122253048806, 49.219485559771144, 48.324726243172925, 48.2588892598306, 47.5912900893919, 50.0452817639997, 51.90363014897993, 50.77736862244145, 51.62534975236463, 49.18583946843302, 52.39864110946656, 52.79204699300951, 48.90519780497397, 45.88642404925439, 50.108451535624845, 51.851305730881236, 51.13007599307645, 49.648624235583895, 49.61311894078409, 48.06241381552912, 48.532478501719815, 53.31736610781763, 51.35013664922407, 44.516779453523704, 49.767056280566806, 53.95856380462647, 52.80529675945159, 52.87052969778738, 56.69198120793989, 51.455060051333525, 50.79634112696494, 46.21158069179904, 45.753945996684415, 48.89257954012964, 47.14222969547395, 44.55532066283688, 45.29899420276765, 41.86766555232387, 38.33598306102138, 36.58406819066694, 37.17660496311803, 39.25529249252812, 42.21275568008423, 43.73821643091018, 40.14775722257553, 40.115354522582024, 39.56812897036153, 42.70285191074495, 42.84846598102201, 45.18227623355004, 48.73255860420966, 46.909848874615086, 46.11840871072585, 45.09525845127721, 53.184389914235766, 63.20975626668623, 58.9990173616717, 65.99559614735266, 53.67546673743956, 43.6661664132149, 75.38553853188792, 69.67895277084844, 60.34777925860498, 61.72243664341589, 64.23454999923706, 64.98206746193671, 65.40759755719093, 70.07289209673482, 71.37868835080054, 73.05872578774729, 66.53016028865692, 70.83706394318612, 69.59216640841576, 70.4774453563075, 70.90597214237337, 72.24736782812303, 68.88112698831867, 68.8182435497161, 70.67524263935705, 73.41529277063185, 70.53612401408535, 55.87108404405656, 7.9923337409573225, 0.130487434385765, 0.4233628631599488, 52.20962601323282, 71.0530924027966, 48.22398408766716, 46.6391033511008, 42.00795304390692, 41.928932974415446, 63.99571687944474, 12.395891950976464, 0.19450338076679938, 0.09881045714381242, 0.06813432014877759, 0.06787742788512861, 0.01946871690902739, 0.04238701282790111, 0.036651737717611176, 0.03777198042840727, 0.070236143656075, 0.07063753542400177, 0.04041047917018014, 0.06702693239335092, 0.03401678596292773, 0.003127258049414283, 0.11936732342526798, 0.038525772641503045, 44.30128835862683, 68.904739656756, 37.87165680239278, 32.19239034960347, 59.152715436873905, 57.35732893789969, 90.17922832119851, 26.689503077537786, 0.1041590532047614, 1.0846814609343007, 64.87653217008038, 88.92735681226178, 74.86534595489502, 79.48174030550065, 75.26505900967506, 78.76972029286047, 75.39983164879584, 75.98588866572227, 71.39719409327354, 78.35956588868173, 72.78315574892106, 69.84541031622118, 63.13026551277407, 58.940989817342455, 50.95472251215289, 63.780061045000636, 69.44922739459624, 71.58236134436824, 68.64500814868559, 67.43568651137814, 64.20709340803086, 63.64541784409554, 62.78206886783723, 58.734916333229314, 56.86029011203397, 52.457343301465436, 51.62229814837056, 51.56530218739664, 51.11699881092195, 50.58990678479595, 52.9326835755379, 51.57389217807401, 49.84517028254848, 47.46777857503584, 45.32725487985919, 45.69454562279486, 45.98525993285641, 44.06121969223023, 41.70743673078476, 43.09579887697774, 43.93343671675652, 44.58543269864975, 41.51731160379226, 41.366029708616196, 40.60337189705142, 43.2328543355388, 45.760755231303555, 46.659774241908906, 45.74324969322451, 45.727556290165076, 46.974638585121404, 53.78146486897623, 56.10552410925589, 53.05839553956063, 52.34517135927754, 52.545663310635476, 50.48137480212797, 47.86931160957583, 51.06913020533901, 49.050113693360366, 49.05745244795277, 50.55224810877154, 53.709269723584576, 52.8596882666311, 52.23077151083177, 56.829017054650095, 51.21542676802605, 51.40685804428593, 55.12992866577641, 49.944472928201, 47.28740838266189, 53.29539299011231, 54.542875366826216, 52.96105015662409, 52.470122383486846, 51.73286976352815, 51.74180492278069, 49.92215464192052, 54.55730576669016, 51.5472710517145, 46.03716857971684, 52.686397952418176, 56.83972120285035, 55.717966479639855, 54.530076672953946, 57.708655634234034, 54.986656250492224, 52.87322436609576, 47.03536864249937, 47.64944707193683, 51.98276004483623, 50.0391040309783, 48.44133438602571, 48.98403352306735, 44.429691068587765, 40.18785169047695, 38.18111219713765, 39.64664305410078, 39.81029610480032, 44.86866704879269, 47.08018564408826, 42.366100741970925, 43.00114423997941, 43.46678057024556, 44.212862445462136, 46.16114293375323, 48.01221139969365, 51.43612284814158, 50.50077876737041, 47.77242514394945, 47.69139289855958, 54.52919413966518, 64.43293956018263, 60.514982054310465, 67.69314304474862, 58.36290305660617, 48.931614968084524, 72.73470663255262, 66.85377936209402, 61.34537527638098, 65.70185768988826, 65.98872415481075, 69.66465180920017, 69.26750398451283, 71.04169399507585, 74.06384883388397, 74.62057436666181, 70.20296573638916, 73.21287493551932, 72.66379802457749, 73.79970073699951, 71.93096591580299, 74.32369801305956, 70.81703632108628, 71.55838781787504, 72.53996879823747, 75.07010152263027, 74.33097008735903, 57.68211295527797, 6.532459922375218, 0.1572838723058662, 0.5811381195822071, 58.51207471662953, 80.94350568709835, 56.10215871564804, 53.117572338350364, 50.10061071765039, 45.91746176442793, 73.88559279903289, 16.01703586116914, 0.33527479476986394, 0.03738977916298374, 0.06349884852346394, 0.07913679830850133, 0.047054307745589365, 0.056138061242358345, 0.02581704813506334, 0.1116698021970449, 0.18405902830343093, 0.16735494076724977, 0.1421248462171324, 0.13223615264700306, 0.09553389909166483, 0.11444014467058644, 0.24212015792727473, 0.14794927480961048, 54.44942881984096, 75.83012350143926, 49.690432779250614, 45.30179477507069, 69.9864822818387, 64.85364121775474, 95.41349795556839, 28.966476225083877, 0.22310861356316075, 1.8380171469142361, 67.26064682006836, 92.53610211033975, 78.93820178124213, 83.7235483046501, 75.74185448308145, 79.85537744337513, 78.14615757234635, 77.1533037001087, 73.69349864221388, 79.26160904668993, 73.68715224727508, 70.70603324520972, 62.87581351495559, 70.55990926681027, 64.89930937367102, 65.39420266305247, 72.02190214587797, 75.70951061864054, 72.34377968695857, 72.93630861466931, 66.97497275567824, 66.09196878248646, 67.39817296305011, 62.796056039871715, 59.81130100065663, 53.43393894933885, 54.12850049234206, 54.339814263005415, 52.933248396842714, 54.27867627912953, 58.563340094781694, 55.42534982004474, 54.60651974524222, 49.3935642703887, 47.857575878020256, 49.7528886795044, 49.31009623312181, 46.656546131257095, 43.33570672619728, 45.52070225438764, 47.62585793772052, 45.99332432593069, 46.05897695787492, 44.2242451637022, 45.44299617890389, 46.073423047219556, 48.88398562708209, 50.586082473877944, 48.37698790334886, 48.586960223413286, 51.10640448908652, 58.38106755287417, 58.719583788225734, 58.04089215493972, 54.99838413730745, 57.40939840193718, 53.305014564145, 50.40986607151647, 56.36306693477016, 51.33509043724307, 52.33774239017118, 53.28399066002139, 54.9233413511707, 57.48662202588974, 55.06029090573711, 60.657391548156745, 53.62007110349594, 56.65776637292678, 58.016228291296194, 52.07868160740022, 50.96472847846247, 54.95248848392118, 57.29378654110817, 55.53904364185949, 55.751408607729026, 52.1923009041817, 54.23736195410452, 54.18258213227796, 59.478064275557, 55.61818530482631, 49.60183035942816, 54.81319335199172, 59.584231069011075, 57.7065767780427, 58.29638750322404, 62.40154797031034, 57.62789795475622, 58.552122116088874, 49.22227828733383, 49.86395843567387, 54.329651401888945, 52.05998366878879, 50.0641679763794, 50.18236860152214, 46.173353272099654, 43.94790634032219, 41.197681580820394, 41.61194270656955, 42.6988354036885, 45.85251123674455, 49.80439332223708, 45.2812768566993, 45.6875402696671, 45.51891365358907, 47.35527323138329, 48.73237425281156, 51.85220787602087, 53.7447867854949, 52.20275009832075, 48.92391927780644, 51.62806795489404, 58.06321828596054, 69.33634158103698, 63.61589024143835, 72.38665903768232, 59.344546794891365, 60.57426867946502, 71.3375505324333, 62.85949253266858, 65.58768533891248, 69.06166584261003, 68.03372244681081, 71.02047397244361, 71.12674666989234, 75.29652426319738, 75.59413802239203, 77.70139217376709, 72.53479126961001, 76.21020117113667, 72.45830505124985, 76.33980412637034, 75.2311775761266, 78.2977807137274, 73.13901670517461, 75.12283386722689, 75.18940433379143, 78.64950749181932, 78.02850215665757, 70.68742552111226, 10.711169242858888, 0.23323009060996197, 0.7681760348139272, 69.03616259174963, 88.59861512337962, 66.58268082526423, 65.21705273658999, 65.06938726671281, 65.3943987815611, 87.20850360008978, 23.2643090140435, 0.5403769100385328, 0.30076146125793457, 0.21977021689376525, 0.2558884586417868, 0.1644597566055675, 0.1946008884378018, 0.19203694537281993], [0.040788578034769145, 0.055731984846774614, 0.03242259146645665, 0.06780690183081935, 0.08936565023876968, 0.10478039647662833, 0.09209047942872971, 0.04849462582158947, 0.19479509172660692, 38.39608946154195, 62.771258815642334, 45.30796074098157, 45.96347508891937, 49.49319247276553, 38.96780237074822, 81.08173785671111, 32.96896080816946, 0.01765998715024081, 0.3481640708782981, 46.898513224817094, 85.55323200841104, 72.73864469220563, 76.76196098327637, 71.91404481087962, 73.80728660091278, 74.4749132279427, 72.37634320412913, 73.2092506654801, 67.70498860266902, 64.60390390888338, 59.45660891071443, 57.479314650258715, 34.978955868751775, 52.71557254175986, 70.82474770084505, 63.77456580438922, 67.72851497896256, 61.25141097653297, 60.022924638563595, 57.554749673412694, 55.258072499305975, 52.71174430847169, 51.52624714759089, 48.790237057593565, 48.76331783110096, 47.41321448356875, 48.38574655594365, 46.36845588684083, 47.7403833020118, 47.117812941151286, 47.21935133780203, 47.74561574382167, 47.431661390489154, 42.87085879233576, 41.88834821024249, 43.11552839894449, 41.73004919482816, 41.07381313077865, 41.668930822803134, 40.63015384058799, 42.232120421624955, 38.528947984018636, 40.15403301485124, 38.240006585274976, 39.71908138644311, 43.2817780586981, 41.78469565606887, 43.14815075166764, 42.83696559167678, 44.27063503573018, 49.38484484149564, 48.360117789237734, 47.468245337086344, 44.49415914473995, 48.88710783373926, 44.41111864582185, 47.85771316097629, 45.91981126416115, 44.76746205360659, 45.89285281396682, 44.9164415174915, 49.60802378193025, 51.11954050679361, 49.06308104915004, 52.08487895227248, 48.40494655793714, 52.22082830244496, 52.44048495446482, 44.85142430951519, 41.10639233742991, 50.571765822748986, 52.865057991397, 45.92002307215045, 49.34407964829476, 49.16046173341813, 49.87555296190324, 49.83037902462868, 45.76933737724058, 48.29683819124776, 46.16854052389822, 46.06398190221479, 47.431520185162945, 52.076963609264745, 49.024798716268236, 50.02599939223259, 51.054801787099535, 51.03493890454693, 50.501543629554014, 42.99686885649159, 42.525694139542125, 42.798773473308934, 41.44277088103756, 44.32446172160488, 42.85634210032802, 39.56043720245361, 37.1811862914793, 36.141601301008656, 40.334367905893636, 43.11382216791953, 44.32200239550683, 40.12416416598905, 39.208039699062226, 42.85283157902379, 43.147330976301625, 42.411506099085656, 47.29226819930538, 45.7107489339767, 47.62245724278112, 46.429970418253255, 44.744567178910785, 50.29590552853, 56.12522617463143, 61.49630415824152, 61.14750739066832, 63.157506373620805, 57.061868559929636, 43.03338612279585, 65.57628300882155, 68.92248445941557, 64.43231198095506, 62.74300598329114, 65.42206325838643, 69.27865136054255, 66.07971529806814, 65.9168271095522, 68.11022435465168, 71.24988555908203, 70.24996357579386, 71.97095840207993, 71.05456721398139, 73.84529436788252, 71.07989003581386, 73.43824648088025, 69.19045294484785, 73.52410716395225, 67.62610189376339, 59.11568434007707, 27.677946244516683, 0.3185272547266176, 0.06535390361903176, 1.1917182851222254, 65.28004207918721, 61.885442503037, 44.571080746189246, 40.86353878821097, 29.599570305116718, 42.48468183702038, 62.73002686039094, 8.273701533194512, 0.2727029088043398, 0.10279341721005979, 0.09418138618310613, 0.04902734038149638, 0.037885066497349934, 0.03685776940396717, 0.025105526738409555, 0.04345154945528315, 0.04766474575585416, 0.049596693096382004, 0.048176082632234024, 0.020179196426104155, 0.09154685577678104, 0.09593462436309746, 0.0824779988596997, 0.1875212094596317, 45.56256571123677, 66.28010134543142, 47.05833411985829, 57.21564900490546, 55.97763915215769, 45.02963327592419, 87.68314961464175, 37.296813841789, 0.017110514416990262, 0.3400134469472593, 49.29173169597503, 90.3478039464643, 74.33788130360266, 80.27194100041544, 74.79195056423065, 76.81105336835309, 76.32075709681358, 76.5451245154104, 75.56080572066769, 69.9389196211292, 64.0039264002154, 62.75336496291622, 60.7154308595965, 40.83426613961497, 54.777691979562086, 72.09549365505096, 68.27312038790795, 69.09731234273603, 64.82653763986403, 62.461352348327644, 58.281953180989916, 58.02681084602111, 54.794613084485455, 53.44270936904415, 50.997574406285445, 51.264268121411725, 49.324707062013694, 51.7281589969512, 49.67353520854827, 49.95678132580173, 50.5420813252849, 48.90769635477374, 49.7374306186553, 49.808758920238866, 45.05906674169725, 45.5865353153598, 45.447353932165335, 44.04645589090163, 43.98999729464131, 46.44752302477437, 43.84078641091624, 43.66122030442761, 40.8170194779673, 41.85764781890377, 42.75317592005576, 42.33943254716935, 45.02554616620464, 44.494276815845126, 43.750826851014175, 45.56013776410011, 45.747113227844245, 53.06120395660401, 49.91057972754202, 50.3143249788592, 47.78767924154959, 51.17720327069683, 48.08414766865392, 51.720024001213815, 48.79539497437016, 45.22233540011991, 48.000875749895656, 49.64929496088336, 52.778338309257265, 54.503314341268236, 53.1395415336855, 54.54091418174006, 50.15624169380435, 54.73881344641409, 53.64773165795111, 44.968848305363814, 42.729398512071185, 51.5630546692879, 56.585481013021166, 49.62277189377816, 52.760703332962535, 52.99324497099846, 50.86680258474043, 52.27632199564288, 47.54055815358316, 49.5609357280116, 49.29438714058169, 46.62644194018456, 49.879498866296586, 52.06523572244952, 50.874702238267474, 53.37792750327818, 54.800175005389804, 53.75943291571833, 54.171960353851325, 45.326513551896625, 45.412927289162916, 44.6638761797259, 45.7375269551431, 47.09536521665512, 46.99650579883207, 41.99466405376312, 39.089803772587935, 38.4416477910934, 42.81865989008258, 45.49359867649694, 45.731160948353434, 43.025098154621745, 42.28608439045568, 43.596046201644405, 46.815343287683305, 44.299029073407574, 49.665192327191754, 49.25789733086863, 48.951062079398866, 49.69488466939619, 47.32668699756746, 51.33762036600421, 57.74227426898096, 64.26185754037672, 64.14653593494047, 65.63929980800998, 60.883457353038175, 48.41919260640299, 63.8502989276763, 68.62885582831599, 65.12560659839262, 64.0148933472172, 68.04887064041631, 71.3976255539925, 69.65734835593932, 69.12501996563327, 68.96725439256238, 72.74925078115156, 71.78054301969468, 72.8647175142842, 74.59321191233974, 77.53961009363975, 74.46142811929026, 75.2381907739947, 72.59288941660236, 78.52738841887444, 71.71834207350209, 65.47798448993315, 26.78374782685311, 0.12313209398980103, 0.10711175524779867, 1.7292476157026908, 76.32710349175238, 69.72437381744385, 50.89377280204527, 48.74337257877473, 48.36276538910405, 52.35588727458831, 73.30385823403635, 12.21423424059345, 0.21681670279752827, 0.11001972541693719, 0.08909912058903326, 0.0619915169062874, 0.0612887614707072, 0.03422983884510975, 0.06887563278958683, 0.07274520418216145, 0.19062607188618955, 0.20416272293415763, 0.2559997865389432, 0.16454117643016, 0.2701007226301778, 0.22391548800852992, 0.230012490684467, 0.2900844938572376, 58.2816864598182, 76.93511009216309, 59.532369490592714, 65.06136209734025, 67.49658523067352, 51.7065388925614, 96.72550724398707, 41.429411288230654, 0.19071910560371416, 0.9484324784528826, 53.502733399791104, 91.96713093788394, 79.34549285519508, 81.98706796092372, 77.48119031229328, 80.41137341530093, 79.09040543340868, 78.45282416189872, 75.92369556427002, 72.36370532743393, 66.49110917122134, 66.59625222606044, 62.43357020039713, 45.04347139789213, 56.51378008627123, 75.92990859862297, 71.14641343393635, 71.83922952221286, 66.99508666992188, 64.73282829407724, 60.11526899953043, 60.69535616905459, 58.60927497186969, 56.70171653070758, 52.86670538686937, 54.41716732517366, 54.959717412148755, 53.17047334486439, 52.06210174868184, 52.56110960437406, 51.588365724009854, 50.521155480415594, 52.32168420668572, 53.79654638228878, 47.96096955576251, 47.12975263595582, 48.40298537285098, 47.27591191568683, 49.25155093592983, 48.39150851772678, 44.8613832073827, 47.66525030136109, 43.34647755469046, 44.98645582506734, 44.48123493502217, 44.944584523477864, 49.18563550518405, 46.62605362553751, 47.12600285007108, 48.82920188288535, 51.136065452329575, 55.65641664689588, 53.67157574622862, 53.8518282674974, 50.94804663811961, 54.49815250212147, 49.06019810707339, 55.02203602944651, 49.52767010658018, 49.67963449416622, 51.12480824993503, 50.86167604692521, 56.186238642661806, 56.86697775317777, 56.73511551272485, 59.49525602402226, 54.47722273488199, 57.82283190757998, 57.761854740881155, 47.249388848581624, 43.58733069512152, 54.19829906955842, 60.199674483268495, 51.994307502623535, 56.122256940410985, 55.49774892868535, 53.91399783472861, 54.762626155730224, 51.00183017792241, 53.26397872740223, 50.720203999550115, 50.975056079126176, 52.64000023564985, 56.34933863916705, 54.740982517119384, 56.47622731424148, 57.89865132301085, 56.44434628948089, 55.23259278266661, 47.778206717583444, 48.26559651282526, 46.87219019859068, 47.840211545267415, 49.28121582154305, 49.288319233925115, 45.515336451991914, 44.53781120238766, 40.40563737192462, 45.58087533520114, 48.29374736355197, 49.96654410516062, 44.730164235638036, 43.78767359641291, 47.470775265847486, 49.41531773536436, 46.87075853347779, 52.74466476132793, 52.176085825889345, 53.36090049436016, 52.461320584820164, 50.493251739009736, 54.768368505662494, 60.970741856482725, 66.53654590729745, 66.78673036636846, 68.5933191545548, 62.732450885157434, 58.05786032830515, 70.87071003452425, 65.45529357848629, 66.64507004522508, 66.57777001780849, 69.86427691675001, 72.09399530964514, 70.5207561677502, 72.46910725870441, 75.1896632102228, 74.23043973984258, 76.17948901268744, 74.49675298506214, 78.27929850547545, 79.47981049937587, 78.1326489294729, 78.4118510830787, 74.9690769564721, 81.515591221471, 78.59708109209615, 73.35064426545175, 35.40920065295312, 0.5281894317557735, 0.17310237752333765, 1.875932615610861, 82.6901057458693, 74.30574924715104, 63.461988202987186, 58.73000552577358, 45.398359606342936, 63.40834979088076, 86.14912632972964, 18.510972953611805, 0.6264433949705094, 0.38014618860137084, 0.34182288533737587, 0.26529667718756583, 0.22446100389765156, 0.2263633993965003, 0.14373903943886682], [0.06031669548622543, 0.08730750140403548, 0.12350707870697784, 0.10738359388685036, 0.03556925931104249, 0.16069412802255925, 0.19358300273456883, 0.170471646913117, 0.23353074947672509, 26.454598211473037, 59.54760397634199, 37.37241360449022, 21.20181106751965, 46.539165281480365, 47.963758360955026, 73.0236441089261, 43.527247828821984, 0.10902031775443785, 0.23667431466521757, 31.76510499369714, 86.43037596056539, 71.69816540133569, 80.13093179272067, 73.09649036776635, 74.66324975413661, 73.92449486640193, 72.8451919555664, 67.75317099786574, 68.80129891057169, 66.47736518613755, 68.70057244454661, 59.51120045877273, 61.700714557401604, 63.29912747106245, 67.9072024745326, 65.90123176574707, 64.57932633738365, 59.96264565375544, 56.13442021031534, 52.24244840683476, 49.85412505365188, 48.341839544234745, 48.57285538027364, 47.885208975884225, 46.40665977231918, 46.79664534907187, 44.90776131230016, 45.47048022670131, 46.4538380407518, 47.82909947056925, 47.653479268473966, 46.22152782255604, 47.321144688513975, 43.2586556865323, 44.63863180529687, 43.59459492468065, 42.62566751049411, 40.222250876888154, 40.72633427958335, 41.234920563236365, 42.88137858913791, 41.120967864990234, 42.562015287337765, 40.79830977224535, 44.43336632943923, 43.24038136389948, 42.66212594124579, 43.41870015667331, 43.78283731399044, 42.41901351559547, 45.73465970254714, 44.212454518964215, 47.11013294035389, 48.13138477263912, 50.81170897330008, 49.027975836107814, 50.13875968994633, 49.58377176715482, 46.72171631167012, 43.60999807234734, 45.12005959787677, 47.80376095925608, 49.53817029153147, 52.44809827496929, 52.248857559696326, 51.624286790047925, 52.53632414725519, 48.02883440448392, 44.53327694246846, 40.619939988659276, 47.43043761099539, 50.34733564622941, 47.31491204231016, 48.97509836381482, 49.176198282549464, 48.814540063181234, 49.58481119525049, 46.21480488008069, 44.34849016128048, 43.78634783529466, 48.91454873546478, 45.54895116436867, 44.25980929405459, 46.65986445642287, 44.52250611397528, 46.8343157922068, 47.47076349873697, 49.77333207284251, 45.399595152947214, 43.3910317574778, 42.26505264159172, 40.74107846906109, 42.777769181036184, 41.226240358045025, 42.055872640302105, 38.0533919795867, 39.30558512287755, 40.84831214720204, 42.68934326787149, 41.574586053048414, 42.684812930322465, 40.59052613473708, 42.6718573416433, 42.313380164484826, 44.69542380302183, 47.63414198352445, 45.640809151434134, 45.02948814822782, 45.3121498323256, 44.12401683868901, 46.913786934268096, 49.0789548812374, 57.58131980895997, 61.956959078388834, 61.44990251910303, 63.81609978214387, 61.37558144907798, 45.394974600884225, 57.792249187346435, 69.60708710455125, 74.78013638527163, 65.42565614946427, 63.409432365048325, 64.99115167125579, 70.58185885029455, 67.33405790021344, 64.44160015352311, 66.259901139044, 70.99295462331465, 64.82044619898643, 70.58225108731177, 69.28971244442847, 74.17731515822872, 71.34175531325802, 75.59470284369685, 59.20631854764877, 62.37464051092825, 14.712126062762353, 0.06716409277531409, 0.13772347190928075, 4.323035872751667, 73.0871472820159, 54.323897284846154, 47.41905489275533, 42.3239823310606, 21.778171985380112, 26.522333621978763, 64.87746569418138, 7.605122750805271, 0.22935678070831686, 0.04133979361804743, 0.042495126986215194, 0.10677224040151605, 0.036952178249315876, 0.07350596013448893, 0.10868933712763172, 0.03877814498639876, 0.06422800334891485, 0.06762923838029947, 0.12991682145624392, 0.060737369687206326, 0.08617394408511539, 0.05924732484404118, 0.12336610320715174, 0.3100589494551382, 31.641615052377027, 68.16905206249606, 40.49514978162704, 33.599254315899266, 59.04267726405975, 49.188926373758626, 81.3128831309657, 48.345318686577585, 0.16598825523209187, 0.08455004452938035, 31.836388188023722, 87.49691547886019, 75.93129711766397, 80.53914070129395, 77.97362819794687, 78.13984255636893, 74.5699679466986, 73.2013588566934, 69.33752613682901, 70.58955454057264, 70.0436782836914, 71.74384532436248, 62.61612515295706, 61.99036198277628, 66.93414872692478, 70.75706328115156, 66.73581015679144, 67.51323176968482, 62.78101767263105, 59.56327384518039, 53.51081348234608, 52.76876772603681, 53.123703002929695, 50.18911115584835, 52.357487601618615, 51.182004251787745, 50.37319975514566, 46.88892302974578, 49.447740047208725, 49.37344251140472, 50.35712588217951, 48.14892561204972, 49.61577830776092, 49.557915502978915, 45.26193564937961, 46.92832716049687, 46.528523891202866, 45.1907132517907, 42.6317903303331, 43.46926343056464, 44.627437360825084, 46.49553675805369, 45.428808965990626, 45.12245224368188, 44.091021860799486, 45.46675789740778, 45.55577216609832, 44.87646864306542, 46.9801220586223, 46.63507115456366, 44.27015650656916, 47.12729330985777, 48.301348916945926, 47.36720508144748, 50.24712301069691, 52.093061016451934, 51.93745274697581, 52.02774570834253, 52.675525142300515, 48.464037064583074, 46.742159705008234, 48.84036494839577, 49.73450060813658, 53.02277257365566, 53.49589670858076, 54.78264201071955, 53.84577212795135, 54.71047824428928, 49.030168441034135, 44.348658823197894, 41.93442037028652, 46.06054198357367, 53.79655030465896, 50.05369132564914, 53.038752309737674, 50.961166966346006, 50.90601451935307, 52.13159830339494, 50.33070871906896, 45.87293894060197, 46.019886616737615, 49.71605762358635, 48.14449333375501, 47.11050948789043, 48.046838083574855, 45.941658866020944, 48.96027964930381, 49.483108059052505, 51.46537980725689, 46.64364937813052, 45.43453954881238, 44.75864456545922, 44.03461817772158, 45.219993745127034, 43.95075790343746, 44.03637932192895, 40.66580426308417, 42.15408486704673, 42.90977654918548, 45.07999650893673, 42.958461007764264, 44.56476965258199, 44.464953176436886, 45.727948527182306, 44.94782047887003, 45.18277437456193, 48.145462159187566, 47.588850375144716, 50.16812255305629, 47.13884861238542, 48.15212626611033, 48.829472526427246, 51.711092764331454, 58.60824731088454, 64.72859213429113, 61.33388665414626, 65.82850317801199, 64.58551583751556, 48.07814644229028, 58.99032538936984, 72.54454228185838, 76.37241471198298, 66.72369003295898, 64.92805642466392, 67.59191451534149, 74.47344626149824, 71.46998543893137, 70.54776560875678, 69.0636819408786, 73.28695281859368, 66.86287926089379, 72.63789469195952, 74.08042477023217, 76.544614607288, 73.16586925137427, 78.15376697048065, 66.18027702454599, 67.56696824104556, 18.021168939528927, 0.12374692551431157, 0.23588792541094367, 5.247464487629553, 81.22997207026329, 61.32967010621102, 56.17642487249067, 49.58878847860521, 31.60485067675191, 34.476457103606194, 78.77039494053011, 10.346473147792201, 0.2566433310388558, 0.052986252947800586, 0.07611260494037021, 0.05882251376826918, 0.08042549609296745, 0.05838640672605365, 0.05310356782208528, 0.16805195820427712, 0.23269799658127371, 0.2162208549317814, 0.2920167514633748, 0.17583910405876177, 0.284001388016247, 0.32019582486921744, 0.447454980063823, 0.42330448726011866, 42.50000261491345, 77.12951844738376, 49.35657631966376, 29.709757527997418, 65.8430237923899, 60.404108416649606, 87.2762978461481, 53.6969260246523, 0.20504277409805408, 0.2668247468048527, 36.40322731387231, 90.94942492823448, 78.6325236289732, 85.13455037147769, 80.28849340254261, 81.11210484658518, 77.33925542523785, 75.45876133826472, 71.09787802542411, 74.32046598003757, 70.7750669602425, 74.3281852045367, 63.50979797301754, 64.27388744969522, 70.443540388538, 75.76906004259664, 68.33982421505836, 71.3367582136585, 67.4112658346853, 62.592743904359885, 57.32766012991629, 56.19133380151565, 55.50251460844471, 52.90774514598232, 53.855691802117136, 52.67224996320663, 50.94249256195561, 47.55612211842691, 50.706032476117535, 52.362119920792125, 53.02815406553207, 52.97901853438347, 52.24455471961729, 52.1438596325536, 48.60927066495342, 50.57144026602469, 49.30338898012715, 46.33582568937733, 46.80689842470231, 46.96391874744047, 47.59529090696766, 48.96635147833055, 47.99318790435792, 49.19704568001532, 47.341827346432595, 49.07729571865451, 49.23156645990188, 47.90182805830433, 49.7681192428835, 48.58168463553152, 46.18379462149836, 50.06604286932176, 50.67032714043894, 52.61437539131411, 51.00519164916008, 55.17047420624764, 56.323855000157515, 53.176137247393214, 53.528150358507716, 51.718972806007635, 49.684153064604736, 50.851721071427875, 53.41741008143271, 54.77908834334343, 57.8038868596477, 56.508881045926, 57.39414430433705, 58.27367305755616, 50.905222200578265, 46.62514363565753, 42.925673915493874, 50.018421373059674, 57.40851194627824, 52.335381123327444, 56.8408037770179, 53.73427091106292, 52.88505815690564, 56.438831437018614, 53.94125830742621, 48.722913495955936, 49.84185587975287, 52.8190682011266, 51.22654668746456, 49.080461071383574, 53.005667117334184, 48.27768133532617, 53.14526427176691, 53.49171546197707, 55.27497791474866, 51.195552118362926, 49.19446083807176, 47.375967656412435, 47.945146714487386, 47.32260381021808, 45.59608628672939, 47.225623207707564, 44.18368393375028, 44.65277979450841, 46.43299456565611, 46.65945652992495, 45.89995230397871, 47.38658159009872, 46.59891082394508, 48.65765702339911, 47.33910522153301, 47.67104756447577, 52.98321939283802, 50.45406333861813, 51.50586651217554, 49.049286073254, 49.61978304770685, 52.57526936069612, 54.896371133865856, 61.89942183033113, 68.61309574496362, 66.59029022339853, 68.75479528980871, 63.944812359348425, 54.17517669739262, 63.61368979177168, 70.85217291308989, 75.84141992753553, 69.18138442500945, 70.47864560158023, 72.09998869126844, 75.01177587816792, 73.00773497550719, 72.79195754758774, 73.47118654558736, 77.19277843352288, 70.43902966283983, 76.33646226698353, 77.69506146830898, 82.53232448331772, 79.06103472555839, 84.3472679199711, 71.45355070790937, 75.76888745830905, 22.407737893442956, 0.35859797390237935, 0.42266458933872564, 5.481365226930188, 91.91412402737527, 68.73820366397982, 66.54725397786787, 59.835125477083274, 33.792776215461, 39.37073569143973, 96.17231968910464, 14.926707167779247, 0.39152336036486013, 0.17833339440966808, 0.20848217179938672, 0.259390568300601, 0.18764707770559097, 0.16478802528112166, 0.1840280936730485], [0.06112478035051496, 0.053580101324065085, 0.0648742100043643, 0.08436015431558894, 0.07077897823746167, 0.04214296019786308, 0.07219161372631788, 0.15957248337086172, 0.2672918765775619, 26.29002928733826, 67.13316194472775, 43.44679609421761, 34.87413052589663, 36.50985302463655, 52.430478988155244, 62.43147565472511, 61.39210247224378, 0.788210888783778, 0.09727721643303672, 12.722683241290431, 65.62118630255422, 71.30945067251884, 73.48325175623741, 69.25855313577961, 65.55512966648226, 68.25260639190674, 68.67680288130238, 69.47872361829205, 71.12658977508545, 70.36262189188312, 69.84588100064185, 66.73555912510042, 65.23957498611944, 68.7163168384183, 65.86140401901739, 65.13871908187866, 62.79478126956571, 53.834671820363695, 50.221353038664795, 47.46826887130738, 48.90703739658479, 49.89944019625264, 50.185914424157914, 48.36404408178022, 49.26827199997441, 46.06229136067052, 45.198954151522734, 45.47581857250583, 46.754377888095, 46.13736160339848, 47.78654175419962, 46.47417945246543, 45.51976088554629, 46.302140374337476, 45.36691788704165, 43.57396717994444, 43.757585094821074, 41.43367490460796, 40.15662962390531, 40.787542866122344, 42.16390648195821, 41.45449876785278, 42.26029872894287, 42.628260197178015, 42.85532620645339, 44.883038613104056, 45.66764600815312, 41.23132767215852, 42.50527035805487, 44.87779440418367, 45.12372701398788, 44.01149972792595, 44.0232668384429, 45.70681087432369, 50.996397695233746, 54.28815664783601, 52.8719299839389, 49.81169285312776, 49.945108352168916, 45.99977270249398, 47.47586650233115, 47.02890065408523, 48.79317491285263, 48.74203505054597, 49.623324947972456, 52.14441660911807, 51.625216391778764, 49.94433564524497, 42.53882623487904, 38.38954694809453, 44.77185118582941, 49.4607074029984, 50.364550928915705, 49.11429543648997, 51.06051275807043, 49.718689533971975, 46.345337437045195, 45.30179869744086, 43.76551220493932, 42.67708978345318, 47.14630111571282, 47.74348981918828, 46.822721265977435, 47.1728830183706, 44.21927552069388, 46.97852565396217, 42.61105275923207, 45.50163561298002, 44.522886583882, 45.00369856434484, 42.249414151714696, 40.19195448967719, 43.067475441963445, 42.84422589886574, 42.36088791201192, 40.00623810675837, 42.238215784872736, 44.629900609293294, 42.15309250739313, 40.84807680499169, 43.174034472434755, 42.15622255879064, 44.58116123753209, 44.91314672654675, 45.12750425646382, 44.97053492453791, 45.796162466849054, 46.43513225740003, 45.83589607669462, 47.16676412090179, 47.83864259719849, 46.54447617069368, 49.416878838692945, 53.65671780801589, 62.07304162363853, 62.212485805634536, 65.01854942690942, 66.42325216724028, 50.50440695977981, 51.143372827960604, 67.8339796681558, 76.7664481747535, 81.69581628614857, 70.25447430149202, 65.49739629991593, 64.43785036763838, 70.88542676741078, 64.24992176794237, 68.7672370479953, 66.97344303131104, 69.55997943878174, 67.63184424369567, 70.35672264714395, 68.7995416887345, 74.44620147828134, 64.70330853616038, 59.82458606843026, 13.425476858692786, 0.10475704611669626, 0.35493276412448577, 6.034493946260022, 76.59498568504088, 57.921863909690614, 52.89055731988723, 33.08473740854571, 40.2496172535804, 37.948841202643614, 53.147115630488244, 7.46144486050452, 0.30821696764999823, 0.05078295726449259, 0.06182234937084779, 0.06807256580120133, 0.0416067254639441, 0.07513425703490935, 0.061810678021321376, 0.050031850189571424, 0.03132355023896502, 0.026292928547087698, 0.031289761931064634, 0.06362188990498263, 0.04894616953547924, 0.02407719542632901, 0.12423072536025317, 0.2579882290334471, 31.328517736927157, 76.8529050580917, 43.486435567179036, 36.169199097541075, 49.73603425487396, 55.27520148984848, 70.57431221008301, 66.58802309343892, 1.1860335450018606, 0.2703802221484723, 10.861740208441212, 66.37394797417426, 74.47770595550537, 76.37643121903943, 71.52953486288749, 68.77550540431854, 71.72126816165063, 71.439634138538, 72.53387343498969, 74.86965271734422, 73.19258059224775, 72.89018154144287, 69.34541794561571, 67.68383918269988, 70.72862609740227, 67.79182987828409, 67.72698525459536, 65.34668707078504, 57.2556689477736, 53.404854574511134, 50.65842666933614, 51.82367263301727, 51.43320852710355, 52.22901821136475, 49.90049139145882, 51.59974451987974, 48.31461045049852, 48.709424464933335, 47.8136061083886, 48.95954616608159, 49.82941412156629, 50.05822950793851, 50.34197376620386, 48.67726887426069, 50.421350771381015, 46.7135303251205, 48.1854977915364, 45.41880692205122, 43.64140841268724, 43.48527062323786, 42.91322039019677, 45.968542791181996, 45.549009999921246, 45.00078816567698, 45.04877836473527, 45.73002346100346, 47.81674400452645, 49.902405508102916, 44.913774305774325, 46.26307356742121, 48.40304813077373, 47.589387739858324, 46.965777950902144, 46.830581695802756, 48.65655483738069, 52.75749483416158, 56.15387516637003, 55.56202480869909, 53.91104036761869, 53.46622790059736, 49.14885544007825, 48.72201527318647, 48.61084353539252, 51.131142877763324, 50.71053927944553, 51.35387466799829, 54.38703567750993, 54.649151986645116, 50.11201304774131, 42.95720192693895, 39.77373569242416, 46.04338161406979, 49.52884681763188, 53.13990239174136, 54.33775501866495, 52.76335093282884, 51.701784979912546, 49.15417417403191, 47.059518675650324, 45.57146949152793, 45.139247832759736, 48.552749310770345, 50.46963514820222, 48.98675172559677, 47.22008089865408, 45.28444220942836, 46.40751092664657, 45.549402236938484, 47.48187165106497, 46.24651332055369, 49.15420555299329, 42.48224212277321, 43.194309203855454, 46.17087041178058, 45.82460357296852, 44.64158535003663, 43.44075564415225, 43.73304674702306, 45.80649006751276, 43.478771255862334, 43.1769331039921, 44.267183349978545, 45.43964255240656, 47.68731363358037, 48.18376018155006, 48.285129916283395, 47.1582055091858, 49.48410434107627, 48.381863409473056, 46.74230875507478, 48.929920504170084, 49.840510506783765, 48.94697104730914, 51.353960960142075, 56.34372180508029, 63.8474081408593, 65.61047038724347, 67.69905013422813, 67.50592047168364, 56.91594070003879, 55.72226931971889, 70.23880835502379, 79.72277779732981, 83.07711032129104, 70.8521572236092, 67.43986775798183, 68.59035384270453, 72.41265650718444, 69.60079562279486, 72.35939856498473, 69.71103775885798, 72.00831505560106, 69.88715217959496, 74.20588570256388, 70.8330709703507, 77.00557154993858, 70.02874189807524, 70.22721382879442, 16.026397578177914, 0.1169474202118093, 0.22781764878140343, 6.595094290471847, 85.0352281139743, 66.8212942923269, 61.61953718431535, 38.608779984135786, 42.202239805652255, 44.605632905037176, 62.42274053635136, 9.46807501777526, 0.2624328873090206, 0.12874893573743681, 0.0871234487802271, 0.062426279464195815, 0.018188423109090617, 0.04493058944541601, 0.021763826314840588, 0.1114009666226564, 0.2191099563553449, 0.2243525871346074, 0.13978159776137722, 0.16476010903716087, 0.1767658099772469, 0.29350253302724133, 0.25004720675849146, 0.4929806129826654, 40.456153577373875, 84.5609272679975, 56.04801039541922, 43.104310420251664, 52.87064344652238, 66.98422170454457, 76.7583445579775, 74.1697685180172, 1.1722417560315903, 0.28355865048304685, 14.55360641402583, 73.02788026871221, 74.44914325591057, 81.67385885792395, 72.10890031629994, 71.42942028660929, 72.40956567948865, 72.8463843560988, 74.20553268924837, 79.52953046368015, 76.57788415108958, 77.78849232581355, 70.15399102241763, 71.51797956035983, 73.6432295460855, 71.659271178707, 70.2372629411759, 70.54324703831827, 60.18803681096723, 55.90367501781833, 50.62082290649415, 55.3670673216543, 55.1508427435352, 56.2136560101663, 52.99793220335438, 55.59745165609545, 52.163161616171564, 51.81478846457697, 49.985363637247396, 50.62584354031471, 51.63499486061835, 55.464895156122026, 52.028828282510084, 49.549537320290845, 51.34591617891866, 49.91262720477197, 50.64773821061658, 49.20676531330232, 48.58169640264204, 45.043722429583156, 45.60687280470326, 48.30574589390909, 47.768455705335064, 48.45561573582311, 46.3336762305229, 49.46416693349039, 49.013921983780406, 51.583372546780495, 45.2369579961223, 51.12537307123984, 51.405673488493896, 49.425704171580655, 50.21016251656317, 50.20430641789591, 50.91321599098944, 55.147449893336145, 57.431195012984745, 57.02032281506447, 55.82366651104343, 56.977682728921216, 50.00571289370137, 53.28760316295009, 51.20078456017279, 55.79438994007727, 54.47615192782495, 54.55514061835505, 55.893876937127885, 57.23521378732497, 53.42734544507919, 44.814652089149725, 40.15993618196057, 46.59754583912511, 51.441390591283, 55.99785897039599, 55.35233882165725, 54.68414345095235, 55.80682777589368, 52.844014475422526, 49.733935786831765, 48.175895829354566, 45.090343721451305, 51.703083284439586, 50.80309937077185, 53.07716408083516, 51.614551467280236, 47.292154450570386, 51.162357099594615, 49.87225424858832, 51.64911931560886, 48.69408407518941, 50.28253416861258, 46.35383329083843, 45.44249019315166, 48.34109037153183, 49.70059956273725, 46.755672270251864, 45.89821469399237, 47.32568679317352, 48.962542856893236, 46.185638135479344, 45.044259794296764, 46.867989340136134, 47.852939636476584, 51.215968055109826, 52.66880612219534, 49.68047780375327, 48.94872042440599, 50.8684499802128, 50.648659967607074, 49.774850030099195, 53.08921360200452, 52.61246911941036, 51.871584384672104, 53.076403141021736, 60.204734340790786, 66.8913007551624, 68.5665136767972, 72.3079998262467, 69.29065381326984, 58.527179764163115, 62.28473978657877, 72.9910021443521, 75.59666402878301, 76.90647678990518, 71.17609793140043, 70.60101570621615, 72.36325817723429, 73.5574394656766, 70.08142717422979, 75.88658209769957, 73.56489981374433, 76.29847803423482, 74.30960101466026, 75.51666336674845, 75.39432464107391, 82.56425257652037, 76.19746915755734, 76.34585242117606, 21.698700843318818, 0.3519516708629747, 0.5377484317268095, 7.732109975430274, 96.74307946235903, 71.50542797580843, 71.97866193709835, 47.52384493427892, 61.67690969282582, 55.69649150294643, 76.49866011834915, 14.284697540344732, 0.6684079754256433, 0.5130094608231899, 0.1632657779320594, 0.2737587618251001, 0.27956147948580407, 0.16543756058860212, 0.1930613275016508], [0.03900825098577527, 0.030772093337990587, 0.03684786771754584, 0.04126788477503485, 0.029914074862796455, 0.05377131686996549, 0.09692627155492384, 0.09290719810392588, 0.3989261905512502, 21.162263770257276, 63.20087602061611, 57.38647607065017, 48.012662472263465, 32.99837073972149, 52.16809988021851, 50.509670780551055, 73.16037793313303, 2.550221633526587, 0.025514552572501764, 2.7019298413107475, 42.99943800895445, 70.31396096752536, 66.1434224344069, 69.70574255912535, 66.74011691924065, 71.83084349478446, 71.80387327747961, 71.1664253665555, 68.3239072368991, 66.80438887688422, 69.49394241456064, 66.99829516872283, 67.09457366697251, 68.22428687926262, 64.66158236226728, 61.95787691300916, 52.733638978773556, 50.40975232278147, 47.67011404037476, 48.020593504751886, 47.80747544380927, 52.04368622072282, 48.270491630800315, 48.67239729050667, 45.560580991929584, 46.975976113350164, 45.512731998197495, 45.19825596963206, 47.553980504312825, 47.488159210451194, 47.514333186611054, 50.26108664851035, 49.01568312798777, 49.805460206923954, 48.00013442193308, 44.47510034807267, 45.510037329889116, 42.779867649078376, 41.988482398371545, 42.83018773601901, 41.747464518393244, 42.05748473444293, 42.50536449493901, 42.02720011434248, 43.14374200759396, 46.66670507000339, 45.620965880732385, 42.591362460967034, 39.31432416362148, 41.53289910285704, 44.94037974265314, 46.512281356319306, 46.75200485414075, 49.3252444267273, 50.97032177832819, 52.58350241568781, 52.31870712772493, 53.64695110628682, 50.32028698152112, 45.74254758896367, 46.74230875507478, 45.73179637232135, 46.40776588070778, 43.22908101543304, 47.141241258190526, 48.64589775762251, 51.17264939892677, 47.547437990865404, 40.65160920543056, 38.18669372989286, 43.83843298881285, 48.676029405286236, 53.5468404523788, 48.40092612851051, 47.05912643863309, 46.83266839673443, 46.724956189432454, 44.119976797411525, 45.89924235497752, 45.16671226870629, 50.10743956412039, 52.52396083647206, 47.77937166152462, 46.921635596982895, 47.12801894833965, 44.24490428739979, 44.9408818060352, 43.88038273780577, 41.41953083776659, 42.09941487158499, 42.0132835449711, 44.54173357255998, 42.96887490057176, 39.91133243806901, 41.92754053300427, 43.97367631235431, 44.2725452300041, 42.55927355058732, 42.544576429551654, 41.38597496094243, 43.88830984792402, 44.19764364919355, 44.35660162279683, 46.48442860572569, 45.642593829862534, 41.84918726644209, 44.96772650749453, 45.82649807776175, 46.644747641778764, 45.338814104757006, 44.560564871757265, 45.77151037031605, 46.28423083213068, 47.93139488466325, 54.18523365451444, 60.434718593474365, 62.677518090894154, 61.035684539425766, 71.11524628054711, 62.89291112653671, 53.917590725806456, 50.71747010754001, 66.320313484438, 80.7759734122984, 85.13942979997205, 71.68121291745094, 64.217613204833, 66.10437916171166, 70.63737607771351, 66.59800944789764, 71.05666960439375, 66.49998157255112, 71.04063495512932, 69.54288574957079, 74.98013019561768, 62.870008407100556, 65.28746320355323, 13.782878325831506, 0.24449388136065778, 0.21787690719769848, 9.22393395054725, 73.8410189843947, 54.94573024011428, 51.1845890937313, 38.34132925156624, 40.98577553226102, 32.6209230192246, 51.727582408535866, 7.26257186743521, 0.1264335652212462, 0.03765315636091175, 0.0963167030544531, 0.06484133717153343, 0.01822341609025194, 0.035818387273578875, 0.1211347342318585, 0.09754386099596178, 0.02311180589810735, 0.09659384302194081, 0.12441869269335463, 0.06402435036556375, 0.09914477791396842, 0.045573272096413764, 0.16493776482680153, 0.3789547073744959, 25.72570808472172, 71.77484773820447, 58.817764636008974, 41.96833318279636, 37.09819678337344, 58.442978243674006, 56.69327951246693, 79.11233148267193, 3.3992659709145947, 0.0540560640905413, 1.9647267412754799, 43.796189062057, 71.5164263017716, 70.56296087080433, 71.3129258924915, 69.57322136048349, 73.95283006852674, 73.28732152138987, 74.22665073025611, 71.33749561925089, 69.49878261935326, 71.4578810045796, 68.97239269748812, 70.6257031040807, 69.63846606592979, 68.3367020084012, 62.75745599500595, 55.326478635111165, 54.56602127321305, 51.826653634348226, 51.506729433613444, 53.17597250784598, 53.34417158557523, 51.113084285489975, 52.68729617518764, 49.96726582127233, 49.9343571355266, 48.61187904111801, 48.20636872322329, 49.24651853499874, 49.784620654198434, 48.503433350593816, 51.92692510543331, 53.0958188733747, 51.90353601209579, 52.039842297953946, 47.1952836744247, 48.342980953954886, 47.01065771041378, 45.19007390545261, 45.24305335937008, 45.50172582749398, 43.89576235125142, 45.408365572652514, 44.53967432821951, 45.40016781899237, 49.321996704224624, 45.73339669935165, 45.72059408310921, 43.391129816732104, 45.07723123796525, 47.37135494908979, 47.73053815287929, 48.750358320051625, 50.94646592294016, 52.52503948826944, 54.757028933494325, 55.34142678783786, 54.65532971966652, 50.876792861569314, 50.09843380220475, 49.7903355475395, 48.60114351395638, 48.617378204099595, 46.87184503001552, 48.804589010054066, 51.090656172844675, 52.72191893669867, 47.5159845044536, 41.55002809339955, 38.658648998506614, 44.20620618327972, 51.70056512278896, 55.57656111255769, 49.00197052186536, 48.26169767687398, 47.767953641953014, 47.48166376544584, 47.26215616349251, 47.00082040602162, 47.713970061271425, 50.47216899933354, 54.41821067563949, 50.52710963833717, 50.249809834264944, 49.983135730989524, 47.42849603776009, 45.34916523964175, 45.960749041649606, 43.63232420336816, 44.436390476842085, 46.01667027319632, 46.1337451780996, 45.565056416296194, 41.94350850197577, 44.45535513662523, 45.56533490457843, 45.523565584613436, 44.15470154054704, 45.40886763603457, 43.23804755364695, 44.763523993953584, 47.199594359244074, 48.46539812703287, 45.90249792222054, 48.00352727213214, 47.02360153198243, 48.78061940593105, 48.69979896853047, 47.64454410922143, 48.065363437898704, 47.664885520935066, 49.14929866790772, 47.92890025723366, 49.95961327706614, 55.932116123937796, 64.51855705630395, 66.30510253290977, 63.960392013672866, 69.87540075855871, 65.09036018002418, 57.526324256773925, 54.5125436782837, 68.7844797872728, 81.40174050484934, 85.36410316344231, 72.16945386702015, 67.40675510898714, 69.4840580417264, 75.15509928426435, 69.3358002939532, 73.50884914398193, 70.41763705592003, 73.93364967838411, 72.44742439639184, 80.76682644505655, 69.01308336565572, 73.36666322523548, 20.365944177873676, 0.1800744058263879, 0.24346657277595615, 10.866655918859667, 83.62281399388468, 61.09859935698971, 54.668693234843595, 48.29415529004989, 48.59037660783338, 42.25645088380383, 67.25801098731257, 11.197685330144822, 0.21442805597138023, 0.03322946591182582, 0.028643316942297166, 0.03954372729264921, 0.016649291182177204, 0.03518153838212452, 0.0658490568880112, 0.208062386260398, 0.09655348551008971, 0.2653526322495553, 0.2125236073568944, 0.2326367095473313, 0.20841025146505526, 0.18847043836309066, 0.4119730969109843, 0.6045992251846098, 35.70241351281443, 81.6030522315733, 73.36512565612793, 59.852223088664395, 47.18054732968731, 69.03368365380072, 62.433366237148164, 86.9984842115833, 4.069247981232982, 0.21925562031326756, 3.3622410028211536, 48.23892047328334, 74.15347499232139, 74.70884338501962, 74.0790754748929, 73.75060050718247, 77.12357213420253, 77.46601858446675, 78.23731345515098, 75.6986770322246, 72.13485856210032, 76.60763140647643, 72.73171778648131, 72.00756196052798, 73.44932325424688, 73.08178932436051, 67.26489866933515, 57.44040473814934, 56.499785069496404, 54.45217840133175, 54.89572002041725, 57.18808258733442, 57.498334223224276, 54.10633125612813, 54.9862483239943, 54.07026506239369, 53.470499361715014, 52.08663225173951, 49.65540601361183, 52.65459537506104, 51.29062644896969, 52.1795218221603, 55.003663647559385, 55.654635890837646, 54.406133697878936, 54.77251052856446, 49.99004302486297, 52.251191369948856, 50.49225545698597, 48.91133631429365, 49.47158413548624, 47.3618039777202, 47.74696503916095, 49.93358442860265, 48.246459268754535, 46.81310753668509, 49.32201239370531, 48.87028086570002, 48.39038279748733, 45.28751734764346, 48.70457641540035, 52.32135472759124, 51.68435396686677, 52.78661058795068, 53.3338047612098, 55.506754690600985, 57.89368952474287, 57.59846841135333, 58.915317904564645, 54.912241043583045, 52.76112694894114, 52.72672776252993, 49.75988618789181, 50.627161456692605, 49.751547228905466, 52.36505777605119, 55.3459688924974, 55.35410781060496, 50.71694058756675, 42.062270026053156, 38.95669814079039, 47.5726156850015, 54.77798615732501, 60.12830303561304, 53.397739395018554, 51.91344784152124, 50.99954735848212, 51.4318278528029, 49.84766490997807, 49.463515820041785, 49.71677933969806, 54.08304022204492, 60.64918987212643, 54.7898748613173, 52.222742419089045, 53.0650165004115, 48.72060714229461, 50.96226130762408, 47.229047436867994, 46.829534422966745, 48.050599636570105, 48.83358317036783, 49.74279642105103, 48.47750256138463, 43.90839238320628, 48.953329209358465, 49.46662625958843, 47.258837838326734, 45.87405681610108, 48.42795518136794, 45.707560047026604, 48.99328639430385, 50.9501019600899, 51.007003784179695, 50.00838402778872, 48.73794794082642, 47.70773741506761, 50.30926904370708, 51.57935603972405, 51.03335818936748, 49.54252804479292, 48.89099490258002, 50.18073689553046, 53.48970328607867, 52.803814103526456, 59.46650112828901, 69.02885129374843, 67.73642247722995, 67.31785851140177, 72.44219979932232, 66.04173891005978, 60.669962744559015, 61.26678274523828, 73.69294166564941, 78.51090661941036, 79.37232186717372, 72.12229128806823, 70.79547897461923, 72.491041152708, 77.33316790673041, 72.13359555890484, 78.05875147542646, 75.05849915166056, 78.76811996583017, 77.42717927502048, 86.21655187299176, 76.18821236395067, 81.35084382949337, 23.53667251525387, 0.5173240373692205, 0.43325112772084057, 12.511887223489824, 95.68096437761861, 68.72765248821628, 71.21062263365715, 54.28339096807665, 57.499334427618216, 49.14403876950664, 83.53902432226366, 14.542841469087909, 0.5040101953331502, 0.17801071817596115, 0.20261608334558628, 0.15130964288067433, 0.15965494507503125, 0.1124919294529865, 0.20748942910182863], [0.02143477814482345, 0.03418710263025376, 0.0694230715593984, 0.1101122535164318, 0.02800719200393125, 0.05389163480891336, 0.025862094105011033, 0.14796726255407258, 0.2351740846830991, 18.198520868055283, 65.2631837321866, 39.10453619495515, 42.61397100264027, 39.55147458660988, 48.0947772918209, 48.97717722000615, 76.79427346875592, 10.026710744827025, 0.3182899819747094, 0.14438103644117234, 22.381481547509473, 63.87391551848381, 63.08869623368787, 70.7499167226976, 66.44039292489329, 70.04539628182688, 65.75073826697566, 66.370527667384, 62.60775873737951, 61.165283572289255, 63.47910934878934, 61.48172078594085, 57.44094210286295, 58.42414302210654, 56.2593908463755, 48.57399286762361, 48.21667671203614, 49.161740426094305, 48.66350135495586, 49.50166479233773, 46.88015261004048, 48.07499677904191, 49.26575776069395, 48.760156400742076, 48.449539984426195, 42.95908858699184, 45.544460050521366, 46.24210457648001, 43.36986664802798, 47.35264132099767, 48.63690376281739, 52.77971898355792, 52.69847885254891, 53.963176511949115, 49.41195626412669, 48.929618481666814, 44.756620622450306, 46.67404774696597, 44.67870666134743, 44.38596840827696, 43.66091435955417, 44.478328458724484, 41.594264584202925, 42.22484050258514, 42.6811102128798, 42.83477690912063, 40.77159058663153, 42.356847870734434, 42.73639994282877, 42.03584501820226, 42.782989855735536, 42.33447467127154, 45.69156854383407, 47.4076525626644, 48.875544686471265, 48.38390304196266, 47.59166663692844, 47.521424831882605, 47.0615190844382, 44.812318278897195, 45.2195309054467, 46.50608793381722, 44.4802111964072, 42.82692432403565, 43.054496319063254, 48.974525697769664, 50.02249279329854, 45.837700366973884, 42.23056716303672, 37.85941116271481, 46.074227133104884, 48.93425864558066, 47.50469592309768, 45.9583838524357, 44.401983445690526, 45.6897367969636, 44.15167347077401, 44.95311567860265, 47.46155377357237, 48.30058013239215, 50.318498380722545, 49.08132007045131, 50.684314312473425, 47.47116358049455, 48.133483240681315, 46.01021012952251, 44.81569151724539, 44.364277701224054, 42.89970390258297, 41.894616157777854, 39.89868279426329, 39.29426908493042, 42.148346439484634, 41.232904464967795, 40.04683463804184, 40.50503023209111, 41.68342790296001, 43.69692956247638, 41.402150815533055, 41.81827114474389, 43.59011557794387, 44.91907342787712, 44.678891012745524, 45.80254808548958, 45.72917622904624, 47.488159210451194, 46.92108646515877, 46.07616478397001, 46.407667821453465, 46.38761666513259, 47.34882093244984, 45.61505486888271, 44.67392529210737, 45.549206118429865, 49.780819877501465, 52.47192667376611, 57.32309056866554, 63.385168583162375, 61.555006350240404, 65.03724736552086, 69.74669210372433, 59.45148629526938, 49.061170854876124, 46.85292743867444, 63.02092552185059, 82.13505114278486, 88.81526331747733, 69.58749878791072, 68.45711092795095, 71.325775577176, 69.89379667466687, 68.18165856022989, 70.65359115600586, 67.91465497786, 72.9583288008167, 65.41599142935969, 62.57698774337769, 23.703167323143255, 0.6324117714839598, 0.3136856709757159, 10.349584567931391, 75.74041105085804, 51.33452169356808, 59.17793235471172, 34.84828602883124, 39.19229138282038, 36.20357474973125, 46.31024399111348, 4.572819269472554, 0.1551147709570585, 0.04255480523551664, 0.04986433357360864, 0.0952048719890656, 0.06952030343874809, 0.03405489117628144, 0.013916314647142446, 0.05224112518912843, 0.004279587874113913, 0.0250933287034352, 0.10150382310272225, 0.012808929764545493, 0.04554460125584756, 0.06031256244187394, 0.12290203012526037, 0.37867606587467656, 25.426590096565988, 74.20114747939571, 43.4389905775747, 42.74433489768736, 42.776498333100356, 56.972815067537375, 55.06538606459095, 88.44493666002828, 10.987253112177696, 0.31859638650090466, 0.12146975214202559, 20.95030869207075, 66.22080295316636, 65.08502575658983, 74.24980055901312, 69.0725072737663, 72.29681322651525, 69.26969266706898, 69.69231236365535, 65.60040950775146, 65.49120287741384, 65.92866482273226, 63.32339909768874, 61.89356180929369, 61.06756164181618, 58.249970174604854, 53.023364851551676, 51.78460190373083, 52.58595781941568, 51.22579359239148, 53.97106439836564, 50.22555389711934, 50.09053807104788, 51.31818502180038, 51.415428423112445, 49.476338048135084, 46.672165009283255, 48.67289935388873, 46.961530024005526, 47.7812583215775, 50.78915142243909, 51.933804942715554, 54.48684038654451, 56.22925135397143, 57.380992597149266, 51.836369345265055, 50.21569305850614, 49.211068153381355, 48.78187064201602, 48.68014004922683, 48.27546519617881, 46.074693895155384, 46.29342486781459, 45.22196669732371, 46.16863073841218, 44.53368879133656, 44.83849617742723, 43.71190124942411, 44.48284310679282, 43.86354792502619, 44.92441177368165, 45.78244593835647, 45.14778683262487, 46.98463278432047, 49.79979630439512, 50.22358878966301, 51.447948794211115, 49.527395540668124, 46.50053778002339, 48.318607345704116, 48.492187915309785, 46.6319489479065, 48.34358107659125, 47.98674737253497, 47.952885550837365, 47.43079454668107, 51.89505584778325, 51.47947680565619, 48.33692481440883, 43.325359513682706, 37.64027618592785, 46.41684224528652, 49.761996423044515, 50.579026129937944, 49.167851478822776, 46.01832551340903, 48.268389240387954, 45.71063126287153, 48.04492004456059, 48.34922144489904, 51.08922058536161, 51.341036750424294, 51.409992018053615, 53.57698778952322, 50.42364928030199, 50.92188835144044, 48.11639739621071, 46.43739546498945, 47.18506982249599, 44.65349366587978, 42.949757268351895, 41.48660729008336, 43.78248037830476, 43.5038822697055, 43.48887135905605, 43.27680449331961, 42.16499297849594, 45.61877327580606, 45.78445419188469, 45.164492207188765, 45.965369593712595, 46.73094957105575, 48.21813583374024, 48.753421691156205, 47.34300405748429, 48.75761862724058, 51.07192685527187, 51.18895469173309, 48.055341782108435, 48.54924663420647, 49.138010086551795, 47.40828406426215, 47.11746777257612, 47.224783820490686, 49.62006153598909, 50.70980187385313, 56.341842989767756, 59.59824962000693, 66.46423309080063, 63.35413871272918, 66.09960171484178, 70.24725714037496, 64.74721947023946, 55.828836194930545, 51.61287269284649, 66.41178315685642, 82.37587682662472, 87.46465790656306, 72.62118539502545, 71.99274324601697, 74.27147557658535, 72.48027032421481, 73.28531326786165, 74.9454721327751, 71.61683113344255, 78.2287940671367, 69.87584790875836, 71.85639381408691, 29.524258836623165, 0.6334980841605895, 0.4838703566741559, 11.42895612024492, 85.09730354432138, 60.15798361070695, 66.82601682601437, 42.48459946724677, 49.7195367659292, 44.80656416185441, 58.36973582544635, 6.507507764524029, 0.34552471411805, 0.10950938062441927, 0.08716156165446005, 0.023626553780970075, 0.043817946326828776, 0.042583353502014955, 0.05389638838448352, 0.11501026730383597, 0.09393710372669083, 0.13509811923628853, 0.2027319158397375, 0.1251999031932604, 0.14569628683309402, 0.1332929556167895, 0.22607374155232984, 0.45999010904662074, 32.26354998926963, 87.68784076936784, 47.675766175793065, 56.724521190889426, 54.780382725500296, 66.16477581762499, 61.10891911291308, 96.28957502303585, 13.099479848338714, 0.3747451155176086, 0.8330495246956426, 26.550892399203395, 72.24677162785684, 68.00314364894744, 79.30816758063533, 71.30351220407795, 75.5374833076231, 70.55996417999268, 71.08989992449361, 69.69768601079141, 68.12430566357028, 71.08293379506758, 66.41261469933295, 66.62774885854414, 65.27018908531436, 61.716086326106904, 55.84265078267744, 55.912398369081565, 55.55060678912748, 54.38627866006667, 57.45385062310004, 51.984199554689475, 55.46709168341852, 55.3577713043459, 56.03606285587434, 55.077741530633745, 49.178335974293375, 52.29384714557279, 51.099712925572554, 49.655845319071126, 53.32577959183724, 55.29633914270709, 56.817610802189, 59.76330687922817, 61.32285694922171, 53.49961903787429, 52.005258760144635, 51.8646143328759, 52.79728335718955, 51.85882491450156, 51.63754440123036, 49.0948522475458, 49.9198914343311, 45.51641118141913, 47.70026529988935, 46.983424694307395, 47.30142301128757, 46.15022305519351, 47.10091929281912, 47.153027980558335, 45.60148346808649, 48.06820715627363, 47.56737539845128, 49.279031061357074, 51.96639591647733, 54.364148647554465, 55.605665099236276, 52.50545509399907, 51.517566942399554, 52.00753373484458, 50.93684434890748, 51.54186210324688, 50.77153605799521, 50.252516269683845, 50.5196532126396, 51.37531826573034, 55.44997838235671, 55.54526844332295, 50.07640184894685, 45.55340305451424, 39.569325293264086, 47.95996935136857, 52.90527797514393, 53.89409965084445, 53.33180435242192, 49.07084734209123, 52.52796557641799, 49.07205150973413, 50.46131187869657, 51.95949646734422, 51.22036895444317, 55.751800844746256, 54.517705517430464, 56.527206359371064, 52.67071631646926, 54.00638534176735, 51.55946177821006, 49.46594768954862, 47.093674675110854, 48.34188661267681, 45.46993109487718, 45.41535915866975, 45.17204276977047, 46.03023382925218, 45.649132420939786, 44.55436360451483, 44.441065942087484, 46.87972899406187, 49.76287503396311, 46.21090212175923, 47.14409674367597, 48.46087171185402, 50.63786560489286, 51.38017808237384, 51.77727883861911, 51.014597492833296, 53.290607698502086, 52.914777955701275, 50.708683998354026, 52.41683306232576, 51.388685703277595, 51.36433955161802, 50.088514128038966, 48.84911183388003, 52.5200580781506, 53.48605548181842, 58.97329838045182, 64.41057028308992, 69.24766463618126, 66.4265783371464, 70.44393262555523, 71.71787138908141, 64.65689512991136, 58.6199712753296, 59.559767246246345, 72.56843736094814, 83.5248645659416, 81.01100183302357, 74.11300397688343, 74.81527297727524, 75.75884619066792, 75.03462760679184, 76.451583831541, 79.90027289236747, 76.68497270153415, 84.43707450743645, 75.45769445357784, 79.78577890703755, 37.1611665141198, 1.0813910826559991, 1.0350448469961844, 12.701105302379979, 97.45903753465223, 65.89925489118023, 82.28808633742794, 51.01225191547025, 58.97095280308878, 53.62837868352091, 73.92157662299373, 12.213347784934506, 0.49330377951264387, 0.35212419386352267, 0.2249218670711402, 0.18313276671594192, 0.14171668989283426, 0.20355944401554524, 0.1507184528295071], [0.07087757375331656, 0.09487068145385674, 0.04627090623422016, 0.08694358665736453, 0.0743873596131321, 0.05014000648272134, 0.06350891874922861, 0.13473097925945637, 0.17898994708253493, 13.804718082950963, 69.51888868885656, 39.61228701376146, 42.128197223909446, 48.270887790187714, 48.42713540600192, 39.67788865489345, 77.20360417519846, 21.03613211262611, 0.235581444275956, 0.18255008024073419, 7.770422706680914, 49.75061762717463, 61.88439523020099, 69.22229474590671, 67.83379923912787, 69.46164561856177, 67.1778142067694, 65.55514927833312, 62.28028789643319, 58.01331004788799, 57.67777089149722, 55.0666255335654, 55.79519794833276, 51.6318138184086, 48.006029744302076, 47.54821069778935, 47.46273832936441, 47.75589235367314, 48.23420578433622, 47.0405226369058, 48.88706861003753, 46.39017405048494, 45.91913269412133, 49.059441089630134, 44.76614021485852, 46.136000540948686, 44.303073037055235, 44.234631599918494, 46.254954261164514, 49.43969526598531, 53.49045638115176, 54.120761655992084, 57.607501629860174, 58.72206664854481, 53.78001751438264, 49.877988753780244, 48.96357444024856, 49.802177183089725, 52.53121329892067, 48.19699425851145, 45.49526176145, 44.507048053126184, 41.63622217793619, 43.411200584903845, 43.06527499229678, 43.82186881957516, 45.44770302311067, 43.588432881139944, 42.36772852559244, 43.44879258063532, 41.74866868603615, 43.04621227325932, 44.83885703548309, 45.842160101859804, 45.307282170941754, 45.660185660085375, 41.96319095550045, 44.395868470591886, 41.68410255062965, 42.634363405166134, 43.037700729985396, 44.14184793349236, 45.41563372458182, 44.01177037146784, 45.76763899095597, 48.088128874378825, 51.36932096173687, 50.06113990660637, 44.16758652656309, 38.97743963426159, 44.19235629420127, 48.68866335961127, 48.77965450286866, 46.85517887915335, 44.269979999911406, 46.75986920633624, 46.934665710695334, 45.4695467026003, 44.84163407356509, 45.961980665883715, 44.6751961400432, 44.94626722028179, 45.530272837608095, 44.760845015125895, 45.37245235135479, 44.42299166033345, 43.60249065583752, 46.095443233366936, 42.90213969445998, 42.53775150545182, 40.94392384252241, 42.26254232468144, 40.301706329468765, 39.66594111534857, 44.63949472673478, 44.31274167952999, 41.415632001815304, 42.65979213099326, 43.03548459083804, 44.98495355729134, 44.73285105920608, 46.793342713386785, 43.852071069901996, 45.59688645024454, 50.502022158715036, 54.61077551687918, 53.46328220059795, 52.086891128170876, 48.46844580865676, 47.87072758520804, 45.165845424898215, 46.46225544714159, 44.52767972023257, 45.40569443856516, 46.59036005696943, 49.2198738744182, 53.24238215723346, 55.43819950472925, 61.798267825957275, 60.78929693468156, 63.719946799739716, 65.81319808959961, 70.65023360713836, 62.936759302693034, 51.05697870254517, 47.19180453208185, 70.25729056327575, 87.57187981759348, 74.43196327455583, 67.72017601997622, 71.5591879813902, 68.10101462948707, 69.67961172903739, 69.75619208428168, 75.44559001922607, 61.70379361798687, 61.673850244091405, 19.809387307013235, 0.4176486133327408, 0.0563696802653853, 9.325249752690716, 75.2470474858438, 52.12271805732481, 48.6060150977104, 29.692497138054144, 44.509683885881984, 45.151924933156664, 44.23353333627024, 3.658394414571024, 0.15675544017745605, 0.0532762976663728, 0.030034367903886788, 0.029359275903252345, 0.043480453952666254, 0.03818084155359576, 0.0759677070703718, 0.15458025609052953, 0.04331828079997532, 0.0446265138265106, 0.09253510919910285, 0.04776774627727367, 0.10243216844936533, 0.1053183663996958, 0.10631343800454371, 0.2948643309214423, 18.119165435914073, 79.41503647835025, 45.29924523445868, 45.248015157638065, 54.474127984816036, 54.533802924617646, 44.276651951574514, 86.50527754137593, 24.654451916294715, 0.24160980547387756, 0.08230140027139457, 6.553726523153244, 51.25391698652699, 64.4078952266324, 71.98533781113164, 71.64556641732493, 72.74484203707787, 70.26289955262216, 69.12836966976043, 64.714271560792, 62.35642110147784, 62.04389449088805, 59.59042056914299, 58.51052145804129, 54.06168683882683, 50.19679115664575, 51.44228489168229, 50.05582901739305, 52.099834949739524, 51.93669180716238, 50.02919220155286, 52.0574458952873, 48.95508250882549, 48.69926944855721, 50.44099400120397, 48.49497279813213, 49.69199388257919, 46.857971606716035, 48.18921227608958, 47.6031905604947, 53.64872793997488, 56.213856051045084, 57.32294936333933, 60.72052601845034, 60.3234056503542, 56.37158632278443, 54.212823606306515, 51.18318096283944, 51.68796254742531, 57.483272321762584, 51.60078002560524, 48.123983260123964, 47.927888285729196, 44.13213222257553, 44.444541162060155, 44.612657870015795, 46.51763931397469, 47.1748520481971, 45.09051238336871, 44.17866329992972, 45.46237660992531, 44.867851195796845, 45.25063530091317, 46.85990141284081, 49.037691547024636, 47.15775443661598, 47.33080940861856, 45.34438387040169, 45.53052779166929, 44.58626424112628, 44.53870942515712, 45.973512434190326, 46.43375158309937, 47.217974585871545, 47.16391255778652, 49.970995995306204, 51.01269906566989, 53.951962455626465, 52.62543647520004, 44.17830636424404, 39.32818581981044, 45.20069568387924, 50.099300646012836, 51.98851023950885, 51.2508967614943, 46.037164657346665, 51.141250825697384, 48.683646648160874, 47.691279149824574, 46.90663253107379, 49.65086390895229, 47.49125003814698, 49.15709633981028, 49.09219288056897, 46.87941912681826, 48.28618895622992, 48.619727703832815, 47.4877473615831, 47.3423647111462, 46.15565161551199, 45.952515986657914, 43.76152315447408, 42.52040678454984, 42.64001946295462, 43.35864082459481, 44.79242401738321, 45.10555075060937, 45.10697064861175, 44.52383971983387, 45.85673562942013, 47.42615046039705, 47.90704481063351, 48.99557313611431, 47.99917344124087, 48.05923669568954, 54.380340191625784, 56.450045493341264, 56.15554609606343, 54.78604662802912, 51.57676335304014, 51.18011759173486, 48.730009063597656, 48.87136736223775, 48.21908504732194, 48.01993846893311, 49.6134288080277, 51.188480084942235, 54.76519138582292, 56.93829036528065, 64.8011677495895, 65.37317483655869, 66.90876314716955, 66.52317062500985, 72.62468414921915, 64.81449204106485, 55.59772622200751, 54.64526099543418, 71.17560371275871, 84.68117144800003, 74.96346796712568, 70.93551543451125, 74.05013622776156, 70.11661867941581, 74.14432802507955, 74.32119554088962, 78.01941010259813, 67.73199019893524, 71.27904445894303, 23.988574666361657, 0.6527628052619197, 0.06950741017898245, 11.719996967623311, 85.53952724702897, 58.945143607354936, 62.304928225855676, 41.294897525541245, 48.6601516508287, 54.22395529285554, 59.097606135952866, 10.249309174476132, 0.28907448353786624, 0.10032362635097197, 0.02927661310100267, 0.06562418709959715, 0.0848412422102786, 0.03267212162515329, 0.024540079156717947, 0.21698013999529425, 0.1838270875234758, 0.2217000843055787, 0.1709187051822101, 0.19494832463322148, 0.2006021454449623, 0.18227522321526082, 0.19688024516067198, 0.3793564132384716, 25.449135880316458, 92.5044564277895, 51.20562476496543, 60.05193056598787, 61.51843024838356, 66.47344281596523, 51.21261050624233, 95.4910667480961, 26.53910763802067, 0.32914216900544785, 0.34952553169381234, 9.067338224380247, 61.41302439474291, 69.80436663473807, 77.19393945509388, 74.76771031656574, 76.74216085864653, 74.24958090628348, 75.22269741181405, 66.42968485432287, 65.5548394110895, 64.33940672105359, 62.25163498232442, 61.52431772601221, 57.63014939523513, 52.2855709445092, 56.2047012390629, 52.97969318205311, 53.69852635168261, 55.2429086162198, 53.82761939879387, 56.07091311485537, 52.19632917834867, 51.904489148047666, 54.64211525455598, 51.071597376177394, 54.57893763819049, 50.72066683923045, 50.18205873427853, 51.058633942757886, 57.16888650771111, 57.40257740020753, 60.001743839633086, 62.00107789808705, 63.642126975520966, 60.04161473243468, 56.04908120247626, 54.83202857355918, 56.602939482658144, 60.81399217728646, 53.21832233859647, 51.511502958113155, 52.02732209236392, 47.96521748265913, 47.84724827735655, 47.860752997859834, 48.909312371284734, 48.74748714508549, 49.501417683016875, 45.170642483618956, 47.477517820173695, 47.76280356991676, 47.24356805124591, 49.22165463047643, 52.98035606261223, 49.56588183679889, 49.34623302951936, 48.37174369442848, 49.53983729885471, 48.325667612014286, 48.14513268009309, 48.23742997261786, 48.76277262164701, 50.77369728396016, 49.915871004904474, 51.410937309265144, 53.7402250689845, 57.8671899918587, 55.96847257306499, 47.47410143575361, 40.68828728891189, 46.28795316142421, 53.40954572923722, 56.58080554777577, 55.666712868598204, 49.54106107834847, 54.400999315323375, 52.346002901754076, 51.31353701314619, 50.11061276158979, 53.228124341657086, 49.638963437849476, 51.86182160531321, 50.618955858292125, 48.271276104834776, 49.516930657048384, 50.29439541601366, 49.78770755952405, 51.98830627625989, 49.383417098752915, 46.0280922151381, 45.8466237591159, 45.00705611321234, 45.31820989424183, 45.35890056240944, 48.896796088064875, 48.942256358362016, 46.9437381529039, 47.076612364861276, 48.91461149338753, 49.01382392452609, 48.44196196525328, 51.32526097759124, 49.70937390481272, 48.25650838113601, 56.40767997311008, 59.850030483738074, 58.51276897615003, 56.52055009718865, 52.48903213008758, 54.5009530744245, 50.00156302605906, 52.37993140374461, 50.95570702706614, 51.23593291928692, 52.651865405421105, 55.27385611687937, 57.98778326280656, 61.53887756409184, 67.5496078306629, 66.19769234811106, 71.832608561362, 69.44328892615535, 74.79486096289851, 64.08187958502, 57.74010127590549, 62.63896119210028, 80.30537528376426, 83.2508477857036, 76.55724463924285, 75.88972783857777, 77.19171939357635, 77.1758730180802, 76.55756627359699, 79.46117924105737, 83.51028903838127, 75.33661088635846, 77.9264969979563, 31.71021926787592, 0.956172356682439, 0.23844379390920364, 13.141445286812322, 96.65600284453362, 65.77198182382892, 69.83298424751528, 46.81834390086513, 62.62740588957264, 67.58141825276037, 77.77448946429838, 14.51304812585154, 0.33607777748857776, 0.3261644158872866, 0.30072560834307827, 0.2906440444771321, 0.19770807977164948, 0.1330841660139061, 0.25467264646243665], [0.018382532552124995, 0.06063720369110666, 0.0706665548345735, 0.05417380031318434, 0.02056758002107663, 0.22642906845336963, 0.10874012109613228, 0.21717857208944139, 0.3998302968759691, 14.227268157466767, 64.3781989620578, 54.74252008622693, 38.54729290931456, 30.776975616332027, 51.41884088516236, 37.16568900692848, 78.28145580907022, 34.60402434872043, 0.15682163017411388, 0.05558077441228013, 1.718492844412404, 31.630426491460494, 59.41795787503643, 60.88684628086706, 69.95537788637223, 63.97555981912921, 63.76686619174097, 59.874525685464185, 61.15319874978835, 57.739818865253085, 57.66855724396245, 53.10071399134975, 50.96634841734364, 49.267652265487186, 50.39846766379572, 47.05870674502465, 47.99311730169481, 47.15319272010557, 49.19380187988282, 51.417868137359626, 48.956372968612186, 49.61531546808059, 47.99603162273284, 46.036376260942035, 46.97901202786354, 44.965977130397675, 45.6109050012404, 44.53711694286716, 46.60250371502292, 53.30921150022938, 58.36793545753726, 57.83817229732391, 60.997339448621204, 61.015021493358, 56.55041894605083, 52.64626426081504, 51.63269635169737, 47.07463156792426, 53.63830228005686, 54.25671100616456, 48.11641700806157, 45.38325455880935, 45.58557433466758, 45.375955027918664, 45.05705064342868, 42.800056088355284, 41.12461174688032, 42.52094807163362, 42.870870559446274, 42.50410149174352, 43.181165341408025, 41.29188514524891, 43.888211788669715, 45.33990844603508, 43.67740400375859, 44.55908221583213, 44.78603839874268, 43.407760666262725, 41.441853046417236, 40.973541659693566, 41.56136766556771, 40.47875035193659, 44.90720825810587, 44.291858980732584, 47.46269126092234, 49.48203332962529, 49.88230336096979, 46.78869470473259, 46.58968148692962, 40.621171612893384, 44.70524934030349, 45.004110413212935, 47.57960927101874, 48.15959053654825, 48.12273986877934, 49.453603990616344, 46.13486697596889, 44.216569085274976, 42.00910229836741, 42.15677561298494, 41.73769781666417, 42.13539869554582, 41.91460455617597, 44.305375468346384, 44.3881727803138, 42.68920990728563, 43.78059764062205, 42.21065328967187, 42.1646438875506, 42.71937685628092, 43.69037920428861, 43.16563275552566, 43.11977240347093, 41.40639874242967, 43.46635695426695, 44.49928568255517, 46.85407669313493, 44.956955679001354, 45.37166787732033, 52.0383321854376, 48.008261572930124, 45.171254373365834, 46.84549846956807, 50.101442260126916, 56.5653004184846, 54.182138904448486, 57.513188239066835, 57.378513659200365, 54.572253919416866, 51.490577113243845, 49.71526138244137, 45.37222093151462, 47.95836902433827, 45.67341973704677, 46.78336420366841, 46.19676589965821, 49.12584289427727, 50.75127309368503, 54.122597325232725, 56.75955187889838, 62.42902025099724, 62.02247050500686, 62.47528852954988, 67.38808462696691, 67.7088717491396, 59.35398401752595, 46.93662297341132, 55.8061727400749, 77.56397585715018, 63.90458845323133, 71.71902456591206, 61.940720465875444, 70.0469103167134, 64.20757193719187, 73.47469314452141, 58.74664814241471, 61.118572065907145, 14.873234475812605, 0.5885618180036545, 0.12839161700779392, 12.923538011889304, 79.38095108155282, 58.48051924859324, 47.52316636423911, 33.65788198286487, 42.53476658175069, 36.8372767971408, 46.13551024467715, 3.9506127084455187, 0.1305238388839268, 0.032626635154649135, 0.04143751196322903, 0.0505213535601093, 0.017013259555002855, 0.04946739660696157, 0.04277736909927861, 0.006337774534439368, 0.05911349694454863, 0.06000995388134353, 0.10204175472139351, 0.058479068890934995, 0.10383222477450486, 0.12343691271399299, 0.1803626081035022, 0.40678974601530266, 19.67967256422966, 74.27368779336253, 52.60764460409842, 44.053014093829745, 44.46735758935252, 56.13477714600102, 43.428015785832564, 84.17813531814083, 39.213982089873284, 0.11546038226374697, 0.04261239972566405, 1.3608204885836572, 33.23626249067245, 64.43817200199251, 65.05831441571637, 71.56380853345318, 68.0927933416059, 64.89945057899722, 64.27962587725732, 63.83876323699952, 62.02936603176979, 61.43237344680294, 56.22120265037783, 52.98062670615412, 53.65377995275683, 53.36843928983135, 50.89704798113916, 48.72139946106942, 50.48457545618857, 53.334946170929946, 51.735960591223936, 53.26273141368743, 53.1185450861531, 50.99182028924265, 49.80547197403447, 50.30894740935295, 47.52217008221535, 49.737199198815134, 47.359403487174745, 50.40848539721582, 56.23219313160066, 62.26566137806062, 59.69424962997437, 63.31893544043265, 63.57725881761121, 59.19226861769154, 55.246321078269716, 53.394354389559844, 51.1144845716415, 56.5570399069017, 56.56899529118692, 51.494040566106, 48.86571130444927, 46.6226686200788, 47.60139411495578, 45.05350482079291, 45.07235965421123, 45.12576664647749, 44.13541916877993, 43.80362195353354, 44.980485977665076, 43.386222931646536, 44.53577549226823, 44.82380297876174, 46.96126330283381, 46.21251421590006, 46.259782698846635, 47.73799457857686, 45.19031317003312, 43.548248198724565, 44.762927793687396, 45.03703086606918, 44.57635633407101, 46.592262406503, 48.47436466524678, 50.50478350731635, 54.033281034038914, 53.49046030352193, 49.928038197179, 47.90262037707914, 41.12232892744003, 45.86593358747421, 49.18864004073605, 52.42869430972684, 50.89410620350992, 51.03028697352256, 51.92617985510057, 47.968877054029896, 46.38364722651821, 44.47152706884569, 42.87615006969821, 43.910730115828976, 44.59864716376028, 45.07466208550238, 46.85818733707551, 45.72723073344077, 45.72885067232194, 45.329369037382065, 42.98005757793304, 44.50830321158133, 43.52472966717136, 44.398135600551484, 45.574254374350275, 42.809218745077814, 45.1068647446171, 43.98622789690572, 44.6260606088946, 48.95924414357832, 47.80649092889602, 49.16841237775741, 54.121793239347404, 51.68776642891669, 46.98085161947435, 48.72006193284066, 52.875397359171224, 58.197449637997536, 57.61303609417331, 59.37226618489912, 60.9503572986972, 57.90471922966742, 54.08898653522615, 51.35711454576062, 49.6759121648727, 49.00024075661936, 48.39359914102862, 47.752122955937544, 48.87121438980103, 52.03388029529203, 55.40620080886349, 56.52090703287433, 59.00677973224271, 65.39318284680768, 65.36158815506967, 64.52539766988447, 70.43700571983092, 68.40917956444525, 60.39830723116475, 54.472096197066776, 55.888793545384566, 76.8500417278659, 68.87812245276668, 74.07274476943478, 67.15748848453646, 71.13721155351209, 68.53145553219703, 78.2442246713946, 64.27513868578019, 69.53662564677578, 20.377438683663648, 0.8489783925394859, 0.11737147286053627, 16.081401955696844, 86.20731861360612, 65.08672806524461, 60.23799211748185, 39.28252158626434, 32.67171967414118, 44.86153225744925, 61.17192414499099, 9.36192391380187, 0.08610084397538055, 0.15355896895691273, 0.10131134351174678, 0.07456725237951164, 0.03521456443254025, 0.04541361171211447, 0.09760287274876911, 0.0873092940497783, 0.15650854536121891, 0.17195093205138562, 0.199850797052345, 0.19604854946655614, 0.38384581104882304, 0.36871192796576413, 0.447883008708877, 0.7486996895843937, 27.083744425927442, 83.23559761047363, 66.28610257179507, 54.00249435055641, 44.145025053331935, 70.84868200363653, 49.6613327149422, 94.46115432247039, 42.02797674363659, 0.34672036286323304, 0.2291985988737114, 2.2359485876175667, 40.004602478396514, 70.23143429909983, 69.08348991024879, 75.7439176497921, 73.10239745724586, 68.42764608321652, 68.17939927501064, 67.8767256582937, 63.93318645415768, 66.24979711348011, 58.196276849316014, 57.47156404679822, 55.743442273909054, 56.35113508470597, 54.42651825566446, 52.87581313040949, 52.442277477633574, 56.658417486375384, 55.961839845103604, 55.51765887968002, 55.24183780916276, 54.25879770709623, 51.006309524659194, 54.13993812376454, 50.06920037731048, 52.099885940551765, 48.95396463332638, 53.02859729336154, 57.3342183328444, 64.06951235186669, 62.091935680758574, 66.04802254707583, 66.91430153385286, 61.90268131994433, 57.30986433644449, 59.135460930485884, 52.70854757678125, 60.27670591108261, 60.59504155189761, 55.16110758627615, 50.356137444896085, 49.94932490010416, 53.45050311857655, 48.77185290859592, 47.40286334868401, 48.001503329123224, 46.29910053745393, 46.51648613714403, 48.990285781122026, 46.33807712985624, 46.713487179048606, 49.97715019410657, 51.99349557199786, 47.26313283366542, 50.50382252662413, 50.306982301896625, 48.719818745889974, 47.53935006357009, 45.99992959730087, 48.41519178882722, 46.89552830111596, 51.90790161009758, 52.515833685475016, 56.14273171271048, 57.12265353049002, 58.623258221533995, 51.04297584103, 49.55385977222074, 41.5285413495956, 48.26471005716632, 50.42261769694667, 54.61022638505506, 55.7139931186553, 56.36312184795257, 56.23780996568742, 49.61449569271457, 50.12772998502178, 49.06551684102705, 47.11368660773001, 46.043616956280125, 48.902679643323346, 47.273130955234656, 51.2937996464391, 47.76783597084784, 47.402388741893155, 49.057122968858295, 45.9498683867916, 46.56003229079708, 46.25264398513302, 46.982495092576556, 46.99173227433236, 46.29523308046403, 48.621457469078806, 47.418666578108265, 47.1967427961288, 50.07672740567116, 50.39325875620688, 51.393019922318004, 55.7029987150623, 53.23028556762203, 49.201587784674864, 53.08815063968782, 56.48420933754214, 60.80288010258829, 59.002547494826786, 63.41126411191879, 62.33441268244098, 59.36351145467451, 56.977486610412605, 54.621942504759765, 53.41236591339112, 53.45435096371559, 51.18376539599512, 51.68091012585548, 51.307229841909106, 54.73822116851807, 57.30322768611293, 60.135049512309415, 64.11366255052629, 67.95387083484282, 68.05093380712694, 68.98376757098784, 73.00060410653391, 68.0315572984757, 59.421758651733406, 57.09026259760703, 67.90689652965915, 77.88628485894974, 68.56720401394752, 76.53328680223035, 69.93851169463127, 75.90427198717671, 73.60407644702543, 83.61001137764224, 70.64289877491613, 79.00155590426537, 25.616068032480058, 1.4183153260138728, 0.3544081777574555, 17.40076372700353, 97.39024700657015, 72.31602499561926, 67.3574822948825, 48.52451216789984, 60.560783570812596, 56.31594750189013, 82.31249132464009, 15.702321548615734, 0.37036961965983917, 0.3337166638624284, 0.3321165513367422, 0.1515778042976895, 0.2000771300686944, 0.10759863476719587, 0.23560795091813613], [0.04580628539946291, 0.1458527985960245, 0.0271659757521364, 0.04010160784086874, 0.08046808292067821, 0.07320414447496015, 0.10869140556502728, 0.26874765813831364, 0.5379295961991434, 9.643207865376628, 58.210503285931004, 49.89733388347011, 39.69971272253221, 20.668286354311054, 48.09248662764027, 43.746637759670136, 68.43057217136507, 53.01320983517555, 0.43754318128189734, 0.1428363886812041, 0.11335636008410685, 12.411888357131714, 41.61787333027009, 60.23749789884014, 68.58466640595468, 65.9622246219266, 69.49448370164441, 63.15059515737719, 61.36751313363353, 57.57310244344897, 55.96329112206736, 52.41058864901143, 53.8703183204897, 50.07032217517976, 48.731334824715894, 49.135762568443056, 49.282557272141986, 51.80785763648249, 54.028538888500584, 58.61892008012342, 57.70307017910866, 52.7768321191111, 51.05903402451546, 48.78238839487876, 46.76632935001005, 44.955151388722086, 45.49383794107745, 46.543248468829745, 51.75131667044855, 59.01006275607694, 60.160792027750325, 53.74336296512235, 60.12633400578653, 60.88455169431625, 58.56048068692608, 54.593575923673576, 51.418766360129084, 51.678768511741396, 55.46596596317907, 54.2103172117664, 53.42065780393539, 48.73824604095952, 51.455330694875414, 49.23944257920789, 45.88006980957524, 46.631839121541674, 41.355015693172334, 41.50680357410062, 43.70659036021079, 44.65905950915429, 41.54297959419989, 39.789256511196015, 43.729253815066436, 43.24921846389771, 44.69680447732249, 45.53794107129497, 45.116215675107895, 43.02814191387546, 42.54768294672812, 40.80516999767673, 41.78560956831902, 39.948281165092226, 43.640812212421054, 47.094745482167895, 45.430723082634714, 46.58758301888743, 53.16612735871346, 49.964167148836204, 46.6409037190099, 42.53828887016543, 45.915963419022106, 50.32692363185268, 50.321973600695216, 48.19213444186796, 46.48268315099901, 45.01930567526048, 46.56530787867885, 42.392627731446304, 40.96852887061335, 43.35800932299706, 42.04173249583091, 41.314007313020774, 42.84133118967856, 44.267967824013006, 41.29801188745807, 40.855733271568056, 42.07976771939186, 39.215668709047385, 41.42432397411716, 41.00111592200495, 42.23566232189056, 42.36015835115987, 42.8374872669097, 42.32049142160724, 43.685597835048554, 45.626417975271906, 47.702861908943426, 47.77774387790311, 49.93516514378209, 56.94677445196337, 49.84594298947243, 44.39431913437382, 47.74412524315619, 51.53624134678995, 56.77181320805704, 61.844657697985255, 59.10094015059933, 57.74230564794233, 62.11732910525415, 56.99915378324447, 51.95057307520221, 48.67129902685843, 46.92618554638278, 46.92310648579752, 47.4253777534731, 46.39163317218904, 48.406307620386926, 45.633089926935014, 50.06579576000091, 51.39318466186524, 58.761945386086744, 59.31579582152828, 65.69631538083478, 65.7953199263542, 67.11416198361304, 60.653951629515625, 71.05059777536701, 59.060508358863096, 60.60046226747575, 73.66521050853115, 73.505185650241, 70.88603865715766, 66.61981782605572, 64.46685237269249, 70.30894817844515, 56.510708870426306, 59.92886227946128, 15.17689751040551, 0.12017883270257905, 0.05212887798646285, 22.239817303995935, 79.25072054709159, 51.70499740108367, 40.71505746533794, 32.115874713467015, 59.17043278294226, 37.01162615130025, 44.87495068580874, 10.754047612990103, 0.10166022761334335, 0.08961255271588603, 0.11858455010599668, 0.043824603630890774, 0.04829516333918418, 0.017573038086054787, 0.024371717928818638, 0.015367882724310604, 0.11836898828586263, 0.025910765586060383, 0.15790363743660912, 0.051634781918818914, 0.04069179048641555, 0.10869507512618458, 0.1888770165462648, 0.4864008676621222, 13.4651251569871, 67.41895368022304, 54.40384695606848, 47.35625774629655, 33.51550386797997, 56.686242780377796, 51.26042812101303, 76.45463543553507, 61.183342164562596, 0.5981447812049621, 0.2142040518623206, 0.07606292413848062, 11.76276158901953, 51.36996030807496, 64.92874676181425, 72.56912769809847, 66.9881283852362, 73.08113821091192, 66.53697736801641, 64.50077302994268, 59.10787490106399, 58.341467303614465, 54.50318490305255, 57.51429434745543, 52.31591440016224, 51.74845334022276, 51.81065428641535, 52.1707082563831, 55.18613230797553, 56.87119037874284, 60.53978320091002, 61.330466347356, 55.305070338710664, 54.25903304930657, 51.772152300803896, 50.174500326956476, 46.99307372493129, 48.107740725240404, 48.87464646370181, 54.81665680485388, 61.995288479712706, 62.27518881520918, 56.82437689073625, 59.64560047272713, 61.93320128225512, 61.39385969408097, 56.29482553851221, 52.78966611431491, 53.37770785054853, 57.31465747279506, 59.51558566862538, 53.879904593190844, 51.34153489143618, 53.862414744592485, 51.463618663049516, 46.97392079137987, 47.5152902449331, 43.45184026225921, 44.043992642433416, 45.28254378226496, 44.37141641493767, 43.364904849759995, 42.6240122702814, 44.94702816009522, 45.23822099931779, 47.40831544322353, 47.19986892515614, 45.98315754244405, 46.295205623872825, 43.43396602138397, 44.339260824265025, 42.60132135883455, 42.36956811720326, 45.401646552547334, 49.914015723812966, 48.365589495628114, 49.32364802206717, 56.81370804386755, 52.84632867382419, 47.5151490396069, 43.61397535570207, 46.99129296887306, 50.46372021398237, 53.03664599695514, 51.698329371790734, 51.97390725535732, 48.452823008260424, 47.15912726617629, 46.5782360107668, 41.58879680018271, 44.52021544979465, 42.627103097977184, 43.99121322939473, 45.25668751808905, 46.35798708085091, 46.05698047145721, 43.88636435231855, 43.87718600611533, 41.66833462253694, 42.54480392702165, 43.38766636386995, 45.87058551849858, 43.58879766156597, 45.347227588776626, 43.97941866228658, 47.00393869030861, 49.35088496054373, 50.96047662919568, 49.901730860433275, 54.98165522852252, 59.86653973979335, 52.005913795963416, 47.725807774451475, 50.754665943884085, 54.311451604289395, 61.87031784365254, 65.80120348161267, 61.12603633634506, 61.629511771663545, 65.34811873589793, 59.99954338996642, 55.32324267971901, 51.5032071451987, 49.302133821672015, 48.21031462761664, 50.89956614278978, 49.99265140102756, 51.91680539038874, 49.78224369787401, 52.429529774573545, 53.32338694603213, 59.78040056843912, 60.35767539854973, 68.59430759183823, 68.3191062558082, 69.36037002071258, 63.5866528941739, 72.74301421257758, 60.620148643370605, 62.706151393152055, 73.5576355841852, 75.8912104945029, 73.86656145895682, 73.93379872845065, 71.41791989726406, 78.28007513476958, 65.38064695173695, 69.54361531042284, 17.187943766194007, 0.14376243576407433, 0.1643633674229345, 26.907710413778982, 89.43634710004254, 56.89105326129545, 52.02339579982143, 32.85766943808525, 47.685893735577984, 47.27926946455433, 64.86987198552778, 18.44341208857875, 0.10066152475173436, 0.08693245539982473, 0.02157042358791636, 0.06314097054963631, 0.07350994379169519, 0.019538815869318864, 0.02859894129928322, 0.09657837570674958, 0.276838036914987, 0.13282522829549928, 0.2597203231867283, 0.178443665105489, 0.12569108812679208, 0.2200437102827334, 0.44958954616900415, 0.8121857023046863, 18.40338233978518, 78.41087049053561, 65.49423486955705, 51.43993931431925, 29.177393836359826, 65.42480891750705, 57.6604457824461, 80.42147744086482, 63.53861954904372, 0.6927745969545457, 0.35793141612122137, 0.1829438034685389, 14.053330652175413, 59.46842701204362, 71.53481437313941, 80.19820828591624, 73.29582521992346, 79.49331129750898, 67.25371991434406, 67.87125002953314, 62.043011957599276, 62.000850400617054, 57.42209119181479, 61.55306477700511, 56.974187897097686, 54.14619430418938, 55.0476687185226, 55.22964316029703, 57.22710624817879, 59.77484649227512, 65.31456678144394, 63.85074607787594, 56.95801204250705, 57.82094132515692, 55.759453388952444, 53.06462818576444, 47.244646703043294, 50.071973493022305, 51.93293025416713, 56.71504474455311, 63.67584759189237, 66.52608886841806, 60.643290627387266, 63.10204405938426, 64.06603320952385, 64.3262863928272, 60.426199205460094, 55.030406367394235, 56.403420279102946, 60.24406002413843, 62.08944105332898, 58.01821301060339, 54.8678005895307, 55.55704339858025, 53.36319900328114, 51.07012648736277, 49.43316844201858, 44.38758834715813, 45.58608032041981, 47.892716392394036, 46.54712377055999, 46.66260227080315, 46.42126275647072, 47.601974625741285, 47.084974858068655, 49.26955853739093, 49.77975299281459, 51.56745556862124, 49.176943532882206, 49.66894211307649, 45.888495060705374, 47.39874486000308, 46.48015714460804, 52.36785834835422, 54.5297864175612, 51.117932335022964, 53.94607105562764, 59.28448746281286, 54.4396464286312, 47.51780056184339, 44.98378076860982, 48.86364029299829, 54.47058216218026, 58.55471480277277, 56.47750208454748, 56.388495660597286, 50.238611467422984, 50.43374546112553, 50.156426045202444, 45.36780042033042, 49.74715809668265, 46.44559321864959, 46.08302500940139, 48.57858204072522, 48.21385652788224, 47.850601903853885, 44.83855109060965, 45.700142845030754, 43.20021629333497, 45.035505064072154, 44.947310570747625, 47.46011034134896, 46.41970949788248, 48.03287836813158, 45.63017168352681, 49.07145138709776, 51.235705421816924, 51.07534716206213, 53.745586949010054, 57.1713811351407, 62.72990134454543, 52.48425076084753, 51.32760263258412, 52.801386156389796, 57.46003227849161, 62.076532533091886, 67.4101048131143, 65.50238947714529, 65.21977878385975, 66.80976252402029, 62.43818683008995, 57.04189585101221, 53.94580041208575, 52.567216734732355, 52.185676020960656, 54.23671868539626, 50.65100554497012, 52.9446703387845, 52.35571469030073, 54.838127859177135, 56.49250515045659, 63.75400866231611, 64.51660763832831, 72.17505501162621, 71.15825899185674, 72.26245326380577, 66.07298451085245, 73.26079845428467, 65.88912733139531, 71.21110116281818, 78.06929480644965, 80.91688848310902, 78.48628982420891, 76.93139168523973, 74.41515199599728, 83.73484473074637, 72.43892069785826, 77.8527250597554, 22.763085019203928, 0.41706644779732155, 0.2927349129271123, 28.553805620439594, 98.54236479728453, 65.22951802899762, 62.69159547744259, 44.18956748900875, 76.89809076247677, 62.719342324041556, 77.81307774205362, 21.98325114865457, 0.25016596570851346, 0.3249287773524562, 0.1754675820590027, 0.1661812787454936, 0.20167960214518732, 0.10291116492402169, 0.14159978487558905], [0.013447150910994219, 0.03167619008661038, 0.04147982682972666, 0.028530508580227053, 0.06817254027531994, 0.041238325272476485, 0.09833186669575592, 0.18756248627699193, 0.26872856722724053, 10.609184676601041, 68.44615967042985, 40.82913175705941, 34.68844552193919, 26.811579004410778, 38.1596685994056, 46.059835956942656, 59.071008543814386, 67.80125141143799, 5.138671177048837, 0.44531790119025016, 0.13415950831146012, 2.1443963002774025, 17.02404360617361, 51.227644951112815, 59.135778642469845, 63.32646639116349, 58.95774618271859, 61.608095630522705, 61.740824714783706, 61.0326329354317, 58.39178739055511, 54.00532630182082, 50.3323325803203, 47.56069167967766, 50.83386644240349, 50.85137982522288, 54.88228198020689, 59.428230562517726, 58.74914669221448, 58.27919575475878, 56.92083974038401, 55.92356535696215, 52.62318503472113, 49.093067569117395, 46.92808005117601, 44.62217354005383, 45.37679833750571, 49.39976161526096, 58.221019160362985, 60.726209532830026, 56.77467261591266, 53.147754976826334, 59.97272614509829, 60.35154081160023, 60.97281679030388, 53.863069780411266, 53.09342622756959, 51.774439042614354, 56.8967838441172, 53.09383023169733, 53.45299774600614, 50.064399396219564, 51.288971208756976, 54.01210807984876, 50.13403715625886, 45.44924059221822, 38.82679316305345, 40.22769512668733, 43.46658052936677, 41.82551968482233, 40.895933643464126, 39.33234353219309, 43.808823016382036, 42.11610847903837, 44.3754643009555, 42.280130232534106, 43.724033140367084, 44.33344787166965, 41.75993765554121, 42.149558451867875, 41.833387959388, 41.34536274017827, 44.33125526674333, 46.781787410859145, 47.12073510692966, 49.81508178095664, 52.645389572266616, 50.17295883547876, 46.73193408596901, 45.837555239277506, 47.55188203627064, 49.230680004242934, 52.195391731877486, 46.64865824484056, 45.54267537209296, 48.56881533899615, 44.7727454862287, 41.77924356152935, 42.13882292470625, 41.39582403244511, 40.42035018244098, 42.78219753696073, 42.26514285610568, 41.0128124298588, 42.71608598770634, 40.04679541434012, 43.55965445118566, 40.08708600075015, 40.095954479709754, 40.82173416691442, 40.02723455429077, 43.176332981355735, 42.041273578520745, 41.71260641467187, 45.91987009971373, 51.43459312377438, 52.2705247325282, 52.21590965024887, 51.80623377523115, 55.98943764163602, 54.914700369681086, 45.57622732654695, 50.21009583627024, 52.51518257202641, 58.93523570029967, 61.7312619763036, 57.489865826022246, 54.71049393376997, 61.37710332870484, 59.92971343378867, 59.01195726087017, 53.16945745098976, 49.276767853767645, 44.86432890738211, 46.867451975422526, 47.405012807538434, 47.86973130318427, 46.83337442336544, 49.35331290768039, 48.953756747707246, 52.46792585619035, 52.76086022776943, 60.96504265262235, 63.178844067358206, 68.33940844382009, 64.93100212466332, 67.2477343774611, 66.91025364783503, 64.3182808353055, 65.23698622180571, 71.11931770078598, 66.8308727202877, 71.81713873340239, 66.55618913712041, 72.63574523310508, 60.531138297050234, 55.59665933732064, 7.515401474891171, 0.10649413516324376, 0.04469360780691908, 40.1613913812945, 74.70773727663102, 55.96629957998953, 34.05275483285227, 94.46954819463915, 51.35597705841065, 34.48235634834536, 61.84363395937028, 20.207731454603135, 0.03289162879809737, 0.03897217207498128, 0.08395082587676664, 0.029642134717094804, 0.050872520603720224, 0.06065514930073292, 0.025761319069011558, 0.05690906362067308, 0.02695794649151785, 0.07745924961542891, 0.011487190607905148, 0.09427111040079787, 0.09717328894522884, 0.05872142846666037, 0.28066124466638415, 0.2990731260468883, 13.958815259318198, 75.90911219196936, 48.87061034479449, 37.000345414684666, 22.26907426311124, 47.14198650852327, 51.0396182921625, 65.1049788536564, 75.18189691728162, 6.781493165800649, 0.5721694363221046, 0.1676726221076904, 1.6328985147899198, 21.415242918076057, 60.03694318955945, 64.47592089253088, 66.43018691770493, 62.32203760454732, 63.31176534775765, 65.07834203781621, 64.04022793616018, 61.25755733059299, 56.309573650360115, 54.215655557570926, 52.391643601079146, 53.58516985370267, 53.1613616789541, 57.57993913465931, 62.71888340673139, 61.78754798827633, 59.18430228387157, 60.04115189275434, 57.608176277529815, 53.90649826295915, 52.06367461912094, 48.67840243924049, 47.151153087615974, 48.193115034411036, 52.12314167330342, 61.44747064959619, 63.16865374965053, 59.53980630443942, 53.388325706604995, 63.67066221852457, 62.049915329102554, 61.26123651381462, 54.057313396084695, 53.565146153973, 55.10505691651375, 58.585568166548214, 55.58093063292965, 55.70917252571353, 52.922512869681086, 53.60609962094215, 55.926609116215865, 51.24669982540993, 46.42288661772206, 40.95254521216116, 43.15222217190651, 45.244312440195394, 41.94406547854024, 42.1286992872915, 40.91674181722826, 44.938846095915764, 45.098941556869015, 45.69374938164988, 44.748026709402765, 45.266681717288115, 45.834401653658965, 44.17596470925116, 44.73180770874024, 45.15829878468668, 43.07261766925935, 49.496122483284246, 50.135155031757975, 49.39556075680641, 52.66222830741636, 51.67775654023694, 52.05418640567411, 45.86561195312008, 45.96031365856048, 48.896937293391076, 51.64528323758034, 53.494602326423895, 48.996612564209975, 49.2870601530998, 51.79291340612596, 46.55971457881313, 43.66204007979363, 43.76157022291615, 42.73233244496007, 42.179368465177475, 42.81583578355851, 45.988507655359086, 44.84023770978374, 44.4031209330405, 41.46889386638519, 44.31129824730658, 42.02791006334367, 42.35141931041595, 43.27755758839269, 44.03717164070376, 43.335326256290564, 42.60308642541209, 42.847406941075484, 48.220877570490686, 52.22364456422868, 53.492499936011534, 55.05152048603181, 54.11907895918816, 59.23366139011999, 57.40428755360266, 47.80105844620736, 52.994986503354966, 55.63347078138783, 61.966031520597404, 63.09099082023867, 58.47458470252253, 58.224639508032034, 62.387705925972234, 63.73205907883183, 61.694709408667784, 56.39713271971672, 52.246398233598285, 46.51909843567879, 48.33773282266433, 49.46321771990869, 52.560478102776315, 50.20100378221082, 53.00682813890519, 51.95126341235254, 56.989324323592655, 56.432430128897394, 64.59404307027017, 66.5410017198132, 71.08379671650549, 68.80957511163527, 68.80536248607021, 69.82620639185753, 69.0480395286314, 68.22205897300475, 73.48154160284227, 69.19270438532676, 75.68182652996433, 70.01167958782565, 75.84773494351295, 68.54008474657613, 64.10795157955539, 7.679686027188455, 0.11954912375057898, 0.02029682156599818, 48.26331369338497, 82.17762454863518, 64.66999976865708, 42.608436538327126, 93.92090274441628, 66.99631044941565, 46.5052838479319, 72.86575302000969, 29.1274679476215, 0.05962969464880805, 0.06798802799875699, 0.020926754598716096, 0.005790829412533992, 0.06557193224228199, 0.02996188832537061, 0.04386739347190146, 0.1379476292359252, 0.19436762998661689, 0.14666597028413128, 0.15008557227350053, 0.2984369359910488, 0.2039368342488043, 0.16727563534532824, 0.4966660781252769, 0.5828516437642036, 17.429008714614376, 91.52517395634806, 52.76765769527805, 48.49276058135494, 38.344855462351155, 58.49052913727299, 59.76888056724303, 71.2894073609383, 79.33669890126875, 7.460892786902766, 0.7253427106526591, 0.38241690385245514, 2.5954571029832287, 28.8475578061996, 66.35468913662818, 72.64497849249071, 71.68577855633151, 67.9592287924982, 67.20798507813485, 70.26587270921277, 68.13959506250197, 64.92704445315947, 59.074573978301025, 56.17560901949483, 51.08091300533664, 56.868683984202725, 56.01920058650356, 60.749496644543065, 65.25251096294772, 65.70696461585261, 62.733035318313114, 62.56571092913228, 60.62265503791071, 56.32507877965128, 54.42750669294789, 52.35307493517476, 50.33360342825613, 49.30194554790374, 53.489911171697806, 63.36169319768106, 64.3726880319657, 60.63404560089112, 55.59074048073062, 65.66035901346515, 63.237322684257265, 63.60353477539555, 59.706008895750976, 58.951199746901, 59.79213629999469, 62.57924310622677, 59.33623137012605, 61.9324521095522, 57.62627409350488, 58.2871699333191, 59.601822899233916, 53.06165110680365, 48.96609652426935, 42.23321084053286, 45.434535626442205, 49.228648216493674, 44.370871205483716, 45.1671358846849, 43.946478597579464, 48.49011298148863, 48.795999019376694, 48.42285610014393, 47.27117761488884, 48.444103579367365, 48.39070050947128, 47.683108852755645, 48.325475415875836, 46.79058528715565, 46.082393507803644, 51.86394360757644, 55.938713550567634, 53.748399288423606, 55.38294507611183, 55.86432972261983, 54.27198471561555, 46.730016046954745, 44.33969620735415, 49.597315711359826, 53.64223249496953, 57.312868871996486, 53.44511378195978, 53.41488407504175, 57.47251326037992, 49.23564572488108, 47.88966086602981, 47.420874872515284, 45.56249903094384, 45.853476139806936, 46.10559432737289, 47.231879388132405, 46.6862423958317, 48.62330490542997, 44.93822636142854, 46.22894894692206, 41.15489636698077, 44.41650013769827, 47.67648789190477, 44.4551041049342, 45.759445159666, 43.714960698158514, 45.85432337176415, 50.70331427358812, 54.683562940166844, 58.190836521887014, 57.454140878492794, 57.146038701457364, 63.228803296242994, 58.829759243995916, 51.583992281267726, 55.660080140636815, 58.049062452008656, 63.878049696645434, 66.27163687059956, 59.73415974647769, 59.40445707690332, 65.92424823391822, 63.861662034065496, 63.141816892931544, 59.27584255895307, 53.974661211813654, 50.21380639845326, 50.95488725170013, 54.38132862890921, 54.20527696609498, 51.355957446559785, 57.39348142377792, 56.79673594813193, 58.92832448405605, 57.844734422622196, 69.32617479755034, 70.03776334947156, 73.71747216870709, 71.20357021208733, 72.13158730537661, 72.30957661905597, 72.30312039775234, 71.6413773259809, 76.12972982468145, 73.78336014286165, 79.24255417239281, 75.00091091279062, 82.48644844178231, 76.60507402112408, 72.95770122158912, 12.020816283841288, 0.3060439439310182, 0.223007214165503, 50.7590982221788, 90.73977424252419, 68.6262749087426, 54.605468550036036, 102.73447636635073, 68.57109500515845, 53.952248788649044, 88.40279471489691, 36.76664275507773, 0.21527669753038117, 0.15035279906324803, 0.2272762697670729, 0.12452282702490208, 0.18477869129950003, 0.17023396047372974, 0.16765258124759122], [0.0357055846571682, 0.08436580038359089, 0.044784071299457745, 0.06742751976895718, 0.01074403744085782, 0.04765638007572101, 0.16019261622380826, 0.19878175199752857, 0.26443320416635085, 8.322113387046322, 62.9796229639361, 52.728473217256614, 40.31627008991857, 60.257082293110514, 60.90351243172923, 40.62642366655412, 57.10557160838958, 62.724280588088504, 28.287580628548902, 0.5564235715616135, 0.15465308040861162, 0.10338043974291894, 5.1328425349727755, 23.225455976301625, 56.862820040795114, 58.916486770876, 78.91709942971507, 68.52008065869732, 62.70054240380565, 61.480677435475016, 59.03685646672403, 55.90206292367751, 58.041343227509536, 54.244453599376065, 59.565227185526204, 58.3543130659288, 59.8594206379306, 60.97864151000977, 63.28170430275702, 57.31801894403274, 62.65725120421379, 56.6679645353748, 50.024885439103656, 44.38520354609336, 45.57041437395158, 46.08140507052022, 48.06984670700566, 53.80106103035712, 58.8054915397398, 59.48744658500918, 57.404224795679895, 55.6489602211983, 60.59432768052625, 59.81222668001729, 57.457651399797015, 53.74714020759829, 51.65460671147993, 50.9863172038909, 61.25267790209863, 53.2585148657522, 52.25792607953472, 49.597837386592744, 50.09904961432181, 46.74311676333028, 51.685365938371234, 43.66048289883522, 40.512949497469016, 41.53663712163126, 41.77452102784188, 40.19590431644071, 38.651729937522646, 39.66330528259277, 41.99239300143334, 40.77785461179672, 45.64245654690651, 41.77765107923939, 43.68613519976216, 45.695769402288626, 46.320183277130134, 43.723731117863814, 43.67693724170808, 43.378327200489665, 44.712191935508486, 42.97997128578925, 46.802399466114665, 49.724451495755105, 52.28037380403089, 50.36792808963407, 46.964958175536125, 44.88656874625914, 46.97967098605248, 52.16236145265641, 52.431530183361424, 46.88709520524549, 46.90718558526809, 42.75882805547407, 45.272153423678496, 43.21194418015019, 42.54425871756769, 42.13814435466644, 46.38207043370893, 41.730261002817464, 42.544756858579575, 43.96352521834835, 41.59415083546793, 39.278712964827015, 40.06986287332351, 39.83557970293107, 41.40060147931499, 39.92773186775946, 42.29598837514078, 41.72151803970337, 42.341370198034475, 43.154748178297474, 49.79026886724657, 50.52416393833776, 49.759678302272675, 50.75522684281873, 52.92985554664366, 57.33286511513495, 59.009964696822635, 47.23690002195297, 50.49828413994082, 54.70333560820549, 60.07736321418517, 59.250272627799745, 58.84499765211537, 57.55898191082863, 57.89030451928416, 72.43367256656771, 88.35001530185824, 60.18626782201952, 51.90987848466443, 47.55141135184996, 44.5125432937376, 43.65974941561299, 47.46451516305247, 46.90654231655983, 50.48223772356587, 50.3694538916311, 53.20666505444435, 51.2913050190095, 59.22592647614018, 60.90577956168883, 63.82820029412547, 63.27542851048132, 64.99272061932471, 65.72980457736601, 68.56221475908833, 68.5926680411062, 69.80264079186225, 68.02207300739904, 68.63060520541283, 69.03820222423923, 66.86241642121347, 63.63471761826546, 43.19731373940745, 2.5365095177004418, 0.14664058213032063, 0.8431098526043277, 55.436705081693596, 70.34652448469593, 48.0655477892968, 39.75540645660893, 48.30719324850267, 26.653715372085575, 44.029068023927756, 59.293555982651256, 32.02905108851771, 0.22349204056926314, 0.13314853272130414, 0.06507250420268505, 0.04364140902555758, 0.05297744676711098, 0.04289971717122582, 0.13833442702889442, 0.020619149229699568, 0.02111990643184512, 0.0381735292443585, 0.09431701438922076, 0.021511298837140206, 0.14834218598421545, 0.09369714200616845, 0.147218840617326, 0.29288834501658717, 12.767542408358667, 72.1226913698258, 57.65858265661425, 36.670650589850645, 53.90589814032278, 68.56758840622442, 49.15270720758746, 65.51620798726236, 65.71020449361494, 33.51673549221408, 0.42764446728171845, 0.6403424362501791, 0.18789599499394818, 4.520067313025075, 34.65734897121307, 64.2920401788527, 63.31313817731796, 81.40206998394382, 70.85186696821644, 66.23542554916875, 63.61413301960115, 61.43912776823967, 57.63773133677822, 60.96504265262235, 57.741764360858554, 62.20781034038913, 62.54798573832359, 63.62118936354115, 63.99491671592959, 65.69887276618712, 61.98356059289748, 64.25034930629116, 59.12229353381742, 55.039925959802446, 48.79200604654128, 47.69241271480438, 48.82370664227394, 51.203310566563765, 55.65584790322089, 61.310403423924605, 61.18507192980859, 58.875635285531324, 57.4374629605201, 64.32050089682302, 61.821715754847375, 58.69885406186504, 56.36689516805834, 55.800803015309, 52.59371626761652, 63.65360383064517, 55.91406145403462, 56.26526655689363, 52.060344526844645, 52.18427965717932, 50.03417753404187, 52.4729347229004, 46.01930218358194, 43.459532030167125, 44.52920944459977, 43.683903371134114, 43.97786540369834, 42.87704044772733, 41.981312305696555, 41.913569050450484, 42.767425890891786, 46.50227146763956, 45.041306249557, 44.789423404201386, 46.93569729405065, 46.416387250346524, 46.07423497784523, 44.96147424943986, 47.03271319789272, 46.24260663986207, 46.36644371094243, 49.283490796242994, 52.22617057061965, 53.49047207063245, 51.07566879641626, 47.368460239902625, 44.14127134507702, 45.900901517560406, 52.55406502754458, 56.72092437744141, 50.56157942741148, 48.89870235996862, 46.09238378463253, 47.75034219987931, 44.94177218406431, 45.30964343778549, 44.59558771502587, 47.59043501269433, 46.54697079812327, 44.969346446375695, 47.42974335147489, 45.101522476442405, 42.85078802416402, 42.33851471254903, 42.37937796500422, 43.269767761230476, 43.089138692425145, 43.715635345828154, 45.28243003352996, 44.411346143291844, 44.96267449471259, 51.43195336864841, 51.77615311837966, 50.58067352541032, 54.414229469914595, 56.53722801516133, 59.79772567749024, 60.459092201725134, 48.3925401010821, 54.392872164326334, 56.752821091682684, 63.0217884432885, 60.291454022930516, 60.65900364229756, 59.396318158795765, 59.321228304216945, 74.79445303640058, 83.91817631260042, 60.50124199159684, 55.985170102888546, 50.6328724276635, 50.01511089263424, 47.12263353409306, 50.56903193073888, 50.54347768906624, 53.65816516260947, 52.46260712223669, 52.954370360220636, 52.12010183641988, 62.829898249718454, 64.64405721233737, 66.9941060773788, 67.47896594385948, 69.05941440213111, 67.95489849582796, 70.05149164507466, 69.53902613732123, 70.90658403212025, 72.13532140178066, 71.96544354961765, 73.01304586472051, 73.80867511995378, 71.57160620535575, 49.20883240238313, 2.473408877849579, 0.09041598742647518, 1.0099246400979258, 64.01646229528612, 74.62701489848476, 57.18615670357981, 50.6553711429719, 64.31077734116586, 43.16589947669737, 55.7251444170552, 71.7314035661759, 39.61760182534495, 0.21944289816723717, 0.08901077532960523, 0.08210547328475984, 0.02561491583624194, 0.0760743924747071, 0.12746107298880816, 0.09450431522582808, 0.12779288865145177, 0.19421284958239526, 0.2524929118132399, 0.16288500159017502, 0.19512043394629033, 0.2678414067674068, 0.3923932685246391, 0.26239544093128175, 0.5194971530187515, 19.254383694741037, 84.50998352419946, 67.6743862705846, 60.4065324414161, 71.2101911729382, 78.78646096875592, 57.203140566425944, 69.61618700335103, 76.40200507256293, 35.36832955575759, 0.48379328822897333, 0.3373482577022045, 0.3662503036039491, 8.224188964213095, 46.176918706586285, 75.16983170663157, 72.4752732246153, 84.11517343213482, 72.14521361935523, 70.9770925583378, 66.49834986655944, 64.58431166987266, 59.80816310451877, 63.57306972626717, 60.41326322863179, 64.98650758497178, 66.71427634454542, 66.0639081462737, 66.0779659209713, 70.44684302422309, 66.04071124907463, 67.17818290956559, 62.25694587153774, 57.67983405820785, 54.13196002283404, 52.159023515639774, 50.643274553360484, 53.869369106908, 59.52081811043524, 64.02876677051668, 63.93742653631396, 58.6474004099446, 57.72217996658818, 66.14055125944077, 64.59328213045674, 61.836581537800456, 59.82021262568813, 59.27470899397328, 56.45803536138227, 66.86323227420931, 62.49565739785472, 60.98456428896997, 56.977451309081054, 56.95744722120224, 53.47511206903766, 55.78986352489841, 48.39731754795198, 45.53002572828724, 45.64006782347157, 47.58616355157668, 44.952354738789225, 44.03160187505907, 45.09440729694982, 46.337853554756414, 44.247697014962476, 48.84520907555857, 47.6697688717996, 49.98787003178751, 50.746570171848425, 50.91563217101559, 50.99001992133356, 47.59101944585001, 46.41411227564658, 50.525038626886186, 49.35672929210048, 51.42260243815761, 54.96895067153439, 56.272205229728456, 53.68800263251028, 48.497228160981216, 43.804367203866285, 49.74683646232852, 51.96554476214994, 59.4743811699652, 53.32385370808264, 54.204339519623794, 50.03762529742334, 52.43556237989857, 48.3501196676685, 48.89312867195376, 47.37680704362931, 52.40558370467156, 47.97636878105902, 50.134766717110914, 51.20015305857505, 44.91232302881057, 43.816546163251324, 46.26654486502371, 46.795374501136045, 44.2358632241526, 45.24665801755844, 47.58337082401399, 48.27563385809622, 45.52578564613096, 46.42137258283554, 53.03605371905912, 56.311001393102835, 55.067919915722264, 58.1374099177699, 59.810822471495605, 64.71559339954008, 62.068970203399665, 51.23198701489357, 56.168768405914314, 59.73012754994055, 65.28377225322109, 63.563914914284986, 60.66641692192324, 60.62994280169087, 60.97900236806562, 74.77387628247662, 78.77570582974342, 61.82315526470062, 58.127953083284446, 53.07218659308649, 53.75488688868862, 49.94401008852067, 55.05001037351547, 52.72389973363569, 55.95895298065678, 58.17697094332788, 59.09045565512873, 54.51596006270378, 66.56799547133907, 66.46444489878994, 70.67054363989061, 70.07086030898556, 71.06505563182216, 70.4314124199652, 74.39776020665323, 73.72470501930484, 75.6077015784479, 75.13557372554656, 76.6735899832941, 77.26083155601256, 78.67905078395721, 78.07797108927082, 55.255075808494325, 4.01911445202366, 0.34570820749767367, 1.361345473316408, 69.56615324943297, 85.79848997054562, 62.91132273212556, 59.98667017106087, 68.30933955407912, 40.098892334968816, 61.3705765047381, 82.8620389200026, 45.57208530364498, 0.6158206359513345, 0.11589664635398697, 0.1583575445317453, 0.13490278213735551, 0.1780173678191439, 0.2716577197274854, 0.3076475191741221], [0.042167321793855204, 0.1364398303051149, 0.09881179013680066, 0.06611590063379658, 0.0734924616652631, 0.026133193469215787, 0.09825599334773519, 0.131365800156228, 0.30228799869937284, 9.363205548255674, 61.24528815669399, 50.16210955958213, 34.71102268465104, 54.97124133571502, 60.466223070698405, 31.0962918496901, 62.19260723360124, 59.46514398820939, 48.583124145384765, 0.27733464575102257, 0.13136553968633377, 0.03977029779625516, 1.0221836403492959, 9.93777786531756, 44.0795724622665, 46.01258316347676, 71.53546548658802, 62.718130311658314, 64.96566410987609, 60.908399704963934, 62.64852393058039, 58.66615718410861, 57.718175226642245, 58.069513690087106, 57.64949452492499, 60.229425661025516, 62.6283041123421, 63.26150409636959, 59.53022003173829, 59.26401269051337, 59.04744686618928, 52.93375046022477, 48.42598615154144, 43.34279052672848, 46.34358413757817, 44.30490478392571, 53.060490085232644, 56.01948691952614, 58.52370062182027, 63.777331075360706, 58.21726937447825, 56.62391631833969, 61.1021294901448, 59.26860578598515, 53.34998061580043, 50.26579349271713, 50.738066473314845, 54.33860617299234, 59.30831193923951, 48.66546254004202, 51.364421921391646, 47.755280463926255, 46.8578774698319, 47.50149919140724, 45.40518060807259, 48.050101495558216, 42.32709669297741, 41.43941333217006, 44.15054775053456, 39.14514841571931, 40.20775771910145, 40.71036631061185, 41.317074606495524, 41.56564697142571, 41.026332839842766, 40.239701501784786, 41.362177941106985, 43.13179446804909, 47.56564171083512, 45.981965141911665, 42.287527822679095, 40.62305827294627, 40.938942432403564, 43.5913864258797, 50.81161091404577, 53.717381185100926, 55.548453407902876, 48.44804163902037, 42.660098075866706, 39.106120832504764, 45.141511040349165, 53.29324353125788, 52.57153526429207, 46.343376251959036, 46.314197740247174, 45.15749862117153, 42.05159725681428, 45.81496630945514, 45.048252767132176, 44.368662911076704, 43.88633689572735, 41.658520852365804, 40.37583128098519, 40.557452709444114, 40.83292468901604, 38.283313474347516, 40.34138110376174, 41.12812619055472, 40.83758054241058, 39.5127490258986, 40.7050750332494, 40.14528612936697, 41.98350098825271, 47.512925055719194, 48.95868324464368, 44.67602376014956, 48.533384569229625, 49.168212336878625, 52.923815096578295, 53.20763387987691, 61.417303700600904, 47.18938835205571, 50.229597860767, 52.29199578685146, 61.07554758748701, 58.75852507929648, 61.29234875402143, 57.429908475568226, 58.46626927775722, 53.61114771135392, 64.26373243331909, 73.27258909902265, 58.03431041779057, 53.15774133128505, 43.894738612636445, 48.38702917099, 48.204278099921446, 47.46825710419686, 45.05101411573349, 51.350144493964414, 50.309782874199655, 52.61174348092849, 50.95719752773162, 61.65363434822329, 65.53860472094628, 69.38527707130679, 61.24542936202019, 67.69837548655849, 65.19118862767374, 66.18510938459828, 61.17052385883947, 63.9835104634685, 63.50831923946258, 69.83627903846003, 62.32898804449267, 68.8787264977732, 30.381112367876117, 1.2413944904842686, 0.10597355543605744, 2.8110798424290073, 69.32883416452717, 68.85294868100074, 57.57836234185004, 35.29109416469451, 34.83341632350799, 33.03997139776907, 45.02745636047856, 65.33938753989436, 42.48310112184094, 0.20257877486367382, 0.03550890307392805, 0.0635483109902951, 0.05112861230548832, 0.025512803976814595, 0.11752842129358362, 0.07226383283493981, 0.05886016698974756, 0.074847157924406, 0.057193113701237794, 0.08702473069030432, 0.06577648537894411, 0.04711812286968193, 0.03793113902511616, 0.18416690880492811, 0.37972750622899304, 12.343613620727295, 75.16925904058641, 55.417724732429754, 41.462727900474306, 62.97759117618684, 72.9009602146764, 40.928065699915734, 70.10055265119, 61.65088084436233, 53.47630054719987, 0.30856434255838394, 0.6572366974526836, 0.3254905343055725, 0.7493698020135203, 12.908103485261242, 54.47064884247319, 52.070452474778705, 79.26224447065785, 67.76113340931555, 66.49361948813161, 64.78914176264118, 64.05410528182983, 62.17871027608072, 59.5749468188132, 61.36479100873394, 63.92146248971263, 64.28127719509986, 64.96509144383093, 65.456242792068, 62.18213058287098, 63.18704182101835, 60.92988252639771, 55.56990877274544, 51.251845975076, 44.16127543295584, 47.03760047112742, 47.63355755036878, 55.33266813524308, 59.299945523661954, 61.838809444058334, 62.31647176127281, 59.53987690710253, 58.91914613785283, 61.658050937037316, 60.35811470400903, 54.65866765668316, 54.26863893385857, 53.00835001853205, 55.722649789625606, 61.38598749714514, 53.06894279295399, 57.66594494542768, 49.92165257853847, 50.44492421611663, 50.39751060547368, 48.79750913189304, 51.336259303554414, 44.01239402832524, 44.52276499040666, 45.84922036816997, 42.52841626444171, 43.937665031802275, 41.586243337200536, 43.29922868359474, 41.98024934337985, 43.89450719279628, 43.96081093818911, 43.585761747052594, 46.409036728643606, 48.10236315573416, 47.82838167682771, 45.66171146208241, 44.37362863171486, 43.26686912967313, 48.48557872156943, 52.19264215038669, 54.13915364973007, 59.87383927068403, 49.62607060709308, 42.56002664566041, 41.12254465779951, 44.72334715627855, 54.79192626091742, 57.02362152837939, 49.09314601652084, 47.46211467250701, 48.08924674987794, 45.655749459420484, 47.58975644265452, 46.366675130782596, 45.03701125421832, 45.62045205023981, 44.08296923483572, 44.09433626359509, 42.96823947660385, 42.50679223768173, 42.40939194156278, 42.94701553160145, 41.516515362647276, 42.13306096292312, 41.005187342243815, 42.531797347530244, 41.224938131147816, 45.00930755369125, 47.87976080371488, 52.60186303046442, 48.62357554897186, 50.134088147071104, 51.11203701265397, 58.426935749669234, 57.37763897065194, 63.992182823919485, 52.44016724248087, 54.906000552638886, 55.17803653593987, 60.80513938780754, 58.916263195776175, 63.26378299343971, 62.045349690221975, 62.19365450643725, 54.74681900393579, 67.25356301953717, 76.62882005014728, 58.92693204264487, 55.57312511628675, 47.4487276231089, 52.184840556113954, 49.02581068777269, 50.11546473349295, 48.957020159690614, 52.77512588808614, 50.68393384256671, 56.04224451126591, 53.668190740769916, 65.0584085526005, 66.08734038568312, 71.35901374201622, 65.23428370875698, 71.52882099151611, 68.84947346102807, 70.16829198406589, 63.18202903193813, 67.48561043893137, 66.96553553304365, 74.68479925586333, 69.46676823400682, 75.40184774706441, 34.634520776810184, 0.7299493505589424, 0.3201610444774551, 3.7130104774428956, 75.25675927439045, 76.96195479362243, 62.907733763417895, 48.39125748603575, 43.273835259099165, 29.625963934006233, 50.6671029521573, 71.81254956030077, 54.43921496791225, 0.3724956055802684, 0.08005927542164441, 0.03834251291869629, 0.06315341947840587, 0.05644107965992824, 0.0806268316603476, 0.07897561340923272, 0.13654567301273346, 0.20787653332996756, 0.20178063382064143, 0.1926112661678945, 0.2705229902940412, 0.19225619973674898, 0.2338270263205613, 0.2973906743911005, 0.5143171729099366, 16.52663803869678, 88.70502118141421, 66.61648381140925, 49.78518155313308, 60.352533171253825, 77.82783369864188, 47.62574811135569, 74.01471722510554, 70.41200453235258, 60.180654910302934, 0.688690061290418, 1.0552988633994134, 0.387081490649331, 1.489940501989857, 18.375047137660367, 60.72307948143252, 60.21255946928456, 65.38979784134897, 64.61964438038488, 74.1773465371901, 67.35136339741369, 69.73867477909212, 66.43243051344349, 63.93555556574176, 62.27115661867204, 65.55310180110317, 65.70728625020674, 65.34785201472621, 70.31027393956339, 64.83218977528234, 65.06715543808477, 64.91888984557121, 58.3926816909544, 52.33405143983903, 45.775675927439046, 53.36759205787413, 50.07507608782861, 58.897204399108894, 61.98818114496047, 63.703488534496685, 63.103075642739576, 60.62372192259758, 60.77034404200893, 67.00563784568541, 63.5339754627597, 58.33357549482777, 55.60385688658684, 55.50302451656711, 60.5031757200918, 67.0911455154419, 57.64975732372653, 62.096944547468624, 53.854016950053555, 54.18570433893512, 55.23414211888468, 52.59947430702948, 54.26111975023824, 46.40700101852418, 46.34397245222523, 48.21517836663031, 42.42232399602091, 46.20246118114841, 47.0503403294471, 45.71153733038133, 45.55251267648513, 48.00762222659204, 46.404906472852154, 47.98464105975244, 51.66090996034684, 53.89520575923305, 51.3658457417642, 48.096401153072236, 47.6515612294597, 43.916433242059526, 49.87616485165012, 55.68720333037838, 58.71467298076999, 61.09850914247575, 47.95203831888015, 42.901974954912745, 40.00395528731808, 46.4175521942877, 56.57436109358265, 58.94917972626225, 51.33076014057283, 51.720577055408114, 49.56064939498902, 48.749307124845444, 51.85126258480934, 48.82389099367204, 48.68472529995827, 52.142549560916045, 46.69698969010384, 47.90220852821104, 47.766525899210286, 44.68095417945616, 43.29776956189064, 45.479446764915224, 45.85735144153718, 46.91460670963411, 42.26356214092624, 43.646746758491766, 43.63319104717624, 46.304352591114665, 50.90354342614451, 57.09447130080193, 52.7880108741022, 54.814503423629276, 56.12795222190119, 62.42839659413984, 61.96050097865444, 69.80866555244693, 52.15912549726425, 57.063543411993216, 58.140845914040845, 63.15982841676282, 63.329596442561, 65.14552047175746, 64.65613026772776, 61.69348170680385, 58.94798340335969, 71.7954872500512, 70.45598214672458, 65.71796686418595, 57.62058665675502, 50.38646521106843, 53.25090154524773, 54.57887488026773, 52.86686228167627, 52.25440771349015, 56.2712638608871, 53.753718022377264, 60.4902671998547, 56.63352612526187, 67.92525322206559, 71.00036005819999, 74.17619336035945, 68.44677156017673, 76.41061859746134, 72.27168652319139, 73.43856027049404, 67.84703331608927, 72.29678969229423, 71.15331680543962, 80.5076519135506, 74.21916684796734, 79.32941113748859, 40.95246284238754, 1.6752194180603952, 0.33730489712569023, 4.276396439921472, 82.2699728319722, 81.51094713518697, 71.30812491140058, 52.02847919156475, 48.28178413452641, 44.932888015624016, 65.12776782435756, 85.45615334664622, 60.904296905763694, 0.8006554661739258, 0.13290913024496648, 0.14776988766126095, 0.17145942536092576, 0.2332845747831368, 0.2491720892008274, 0.15118924450249444], [0.04069220034345504, 0.04377308038754329, 0.09054279029970208, 0.07463788568613029, 0.08799329565297212, 0.06621914630335185, 0.03495890940088899, 0.09396290556798059, 0.2847265668453709, 10.252864803037337, 65.18253587907361, 51.280793066947695, 37.57813015291768, 28.742357876992997, 47.15873895152923, 30.433895703284975, 60.82038956303751, 62.508095233671135, 66.62157504789292, 3.55759832647539, 0.7731220823141837, 4.53712668149702, 0.5884352602785634, 3.8701148859916197, 14.22851449058902, 34.61977266496228, 18.901180144279234, 51.23300683113837, 61.7401736013351, 60.15754822761782, 61.93558608331988, 62.59491689743535, 63.37371526225921, 63.5318926841982, 61.99406470021894, 60.67612478809973, 59.42004065359793, 61.79007791703748, 61.383410499941924, 58.41503135619625, 54.538046929144095, 47.71491927485312, 46.76832191405758, 46.05074390288323, 42.10315681272938, 48.443997675372714, 58.96017020748508, 59.55172246502292, 61.553472703503026, 69.20715439704158, 56.598197337119814, 59.19157043580086, 57.521817453445934, 59.093577861785896, 51.273320951769435, 54.55148496935445, 52.956653179660925, 54.12353084933374, 54.932154916947894, 48.40684890747071, 50.307982506290564, 48.35916465328586, 42.37272562519197, 45.60109907580961, 43.54949159006919, 45.30144176175518, 44.655317568009906, 41.78912401199341, 41.395643603417184, 39.57082756104008, 40.098178463597456, 39.74831088896721, 43.60553833746141, 42.375938046363096, 39.00720257912913, 40.8761295964641, 38.15416551405384, 40.428642072985255, 41.1280006747092, 44.47968952117428, 44.98393766341671, 43.010604996835035, 43.49760255505962, 42.46769797417426, 46.66835246547576, 53.233470532201956, 59.7632166647142, 47.21875905990601, 35.925415946591286, 38.354288762615575, 43.324555427797385, 51.12065053755238, 54.07031213083575, 51.63859951880671, 50.20000357781687, 43.85208283701251, 43.93578621648973, 43.71921254742531, 45.30322644018358, 45.136537474970666, 43.21894953327794, 38.97145409737864, 38.072548835508286, 39.30059194564819, 38.59476143313993, 38.54319795485466, 40.868178952124815, 41.560536123091175, 37.21045894007529, 39.23092672901769, 41.73681528337541, 39.93875765031384, 41.55806895225279, 48.01261148145122, 43.44268152790685, 46.98420524597169, 43.8018294303648, 50.57662563939249, 50.249217556368926, 52.89237729964718, 59.46228850272394, 50.815529361847915, 50.18269808061662, 54.71335726399576, 52.574739840722856, 59.41934247170726, 58.88902233492944, 62.391106620911636, 57.04641442145071, 53.759632956597116, 38.33184888285976, 67.09410298255183, 64.67484389581989, 54.90840104318435, 50.326358810547866, 45.66505724383939, 45.81130281571419, 47.595949865156605, 48.909704608301965, 47.95146957520516, 49.460499517379276, 50.220086113099136, 50.99895900295627, 57.92303277600197, 62.31123147472259, 65.76216805365779, 65.19392644205402, 64.05790605852681, 62.9730059254554, 65.6012253607473, 59.52550142042099, 61.409580553731615, 61.59076267673124, 69.15508885537425, 63.77925303674514, 65.99791034575432, 13.882078009267008, 0.2548520642543032, 0.4856101423501969, 10.21615534059463, 79.28670437105241, 61.973856649091175, 58.4077279029354, 40.26878979898269, 55.41438287304294, 49.93933462327527, 56.587320604631984, 52.30269209031136, 58.26858966581283, 2.281033536118846, 0.09130733072637551, 0.05787937526380824, 0.1188666696449922, 0.02712038969020209, 0.04524757364584554, 0.054366965552852045, 0.013697041131015266, 0.02508855597566693, 0.02860106910849291, 0.040096792978264635, 0.021265637422461185, 0.021807409056852904, 0.0676561433882002, 0.13844638311814877, 0.41505295422769367, 13.200620124416968, 74.75635113254671, 55.062765921315844, 38.1188210364311, 42.30276230842837, 53.77668742210635, 36.38090118285149, 65.96173824802523, 68.38727704940304, 71.43224439313336, 3.9813135900805077, 1.0793385798892667, 1.9406058807526867, 0.49696074618447217, 3.8208891403290535, 22.024432113093717, 42.381001826255556, 25.129186184175555, 56.46012598468412, 62.555803022077015, 64.1293598759559, 63.78224580518661, 67.5126826378607, 65.17720537800943, 64.95773699975783, 64.76380717369818, 64.99009263130927, 61.319868103150405, 65.2053483839958, 62.746387066379675, 61.520795437597464, 57.294261147899014, 50.17564958141696, 48.39025335927164, 48.04051522285708, 44.88035963427636, 51.76273469002017, 60.283224890309, 63.46740107382498, 61.403822514318655, 70.38738773715112, 59.261502373603086, 61.12947625498618, 58.50029191663189, 58.89653367380942, 54.156078677023615, 57.577758296843506, 54.734236040423, 54.998886200689505, 58.00733235574538, 53.60115351215486, 55.20039796829224, 52.962732853428015, 46.264485620683246, 51.03902993663665, 48.21285240111813, 49.37619993763585, 46.68142964763027, 44.132473468780525, 44.26297464678365, 41.38743408264653, 40.78243594015799, 42.21752528221377, 45.84170510691982, 44.04387497132824, 41.72297716140747, 43.449730027106504, 41.766397799215014, 45.110061476307536, 42.44548559188843, 50.36170721054078, 46.40021924049624, 44.19903609060472, 46.15705582403368, 45.306901701035045, 49.56370492135325, 53.842477337006606, 62.2754829929721, 48.28604382853354, 38.021452119273526, 39.634703359296246, 44.64139315389818, 52.49441754433417, 53.756746092150294, 53.19805937428629, 53.45588068808279, 46.044844658144065, 45.54134176623437, 45.01617954623315, 47.36762869742609, 48.1210454048649, 47.7537860408906, 41.4215979268474, 42.81129760126914, 41.53403266783684, 41.03211049110659, 43.309583740849654, 41.76540936193159, 42.28026751549014, 41.40285684216408, 40.3857901788527, 42.53041667322959, 42.72541338397611, 42.756054939762244, 49.8606244210274, 45.68893271107828, 49.24685978120374, 46.861321310843195, 54.23870340470345, 55.37170356319797, 56.110933057723514, 61.7622761572561, 53.571637676608184, 53.50495738367881, 55.08862218549175, 53.868082569491484, 64.94946472106442, 59.74078462969873, 63.56220868326003, 59.5877847363872, 55.50011804026943, 40.66330179091423, 69.98095958463608, 67.98666969422372, 60.28704135648666, 52.774274733758745, 50.68377302538965, 48.73868534641881, 51.05537837551486, 50.7996908310921, 50.6009796357924, 49.79340284101425, 52.997567422928356, 51.01466025075605, 59.37570610354024, 63.86789468026931, 68.10940065691548, 66.37019034354918, 69.22124355070054, 67.22208207653415, 68.04015513389342, 62.30395155568277, 64.80660415464833, 64.74438359660488, 73.67979388083182, 68.49654643766343, 72.95034285514586, 13.749769599206987, 0.07574589397277563, 0.7355572367387434, 12.084905851271845, 85.25000141512963, 72.08459731071227, 59.40331566718317, 49.816372240743334, 55.452218055725105, 45.847223881752264, 71.62768825407952, 63.589818246902965, 64.33386833437028, 3.2411897951556794, 0.09024350273032343, 0.02734753475975125, 0.08718280527260035, 0.03501158943700214, 0.02067168179388729, 0.02169330409097095, 0.2507417880359196, 0.20113794733920407, 0.20103998001544707, 0.23141723546770313, 0.1677535363142529, 0.18761263439251533, 0.18368065747762882, 0.27908175522761963, 0.5498622429947699, 16.80362601434031, 88.71552528873568, 66.83041772534771, 50.384107866594874, 39.92566870104882, 65.2172213985074, 45.33683330781999, 75.04192321531235, 72.49595196016374, 82.42806003939721, 4.011776923171936, 5.3544927316327255, 7.771331225672077, 0.47863436021631767, 5.069920853261025, 30.25403738021851, 51.25591739531487, 31.505275426372407, 62.03509269222137, 66.88836682227351, 68.5489728373866, 67.82378150570777, 71.27768731886341, 68.10827885904621, 69.62029764729162, 67.01312957271453, 66.42067124766689, 65.82601639532274, 68.88993663172569, 65.37512033216416, 63.8413873026448, 58.34402468896682, 53.262197971344, 53.39882196918611, 50.649746464144805, 46.73361678277293, 55.844972825819454, 63.986887624186856, 64.42387888508459, 62.46850675152194, 66.28931891533637, 61.769544309185406, 63.765105047533595, 60.949062916540335, 62.87008685450401, 56.12757175199447, 59.05888841998193, 56.84145096809634, 58.14541155292142, 61.70210699881277, 59.06261074927546, 60.332901708541385, 57.33850156107257, 48.21806915344731, 55.15638505258868, 50.884045324017926, 51.2705909821295, 49.75571670839864, 48.84743698181645, 46.3276828488996, 44.21790269113357, 43.63346169071813, 46.2155265961924, 49.62219138299265, 48.17822179486675, 43.24295443873252, 47.160174539012296, 46.266646846648186, 49.709209165265484, 47.57133306995515, 53.52183534253029, 50.756431010461625, 47.498443665043006, 48.594306822746034, 48.289428833992254, 52.42841974381478, 55.30319152339813, 65.00245594209241, 48.288001091249534, 37.77033413610151, 40.12892984574841, 44.08542463856359, 55.30985563032089, 57.89129687893776, 55.369393287166474, 57.987861710210005, 49.01309436367404, 48.165717278757405, 47.32974252393169, 51.394859513928814, 51.76793575286866, 52.05144074655349, 45.683880698296335, 46.4950817631137, 42.55639060851067, 44.58174567068777, 44.085852176912375, 45.05203785434846, 45.76156323955905, 42.92173585584087, 43.48997746744464, 46.158212923234515, 44.465400326636534, 44.309274304297666, 54.343826847691695, 50.394109910534276, 53.01222139789213, 50.33014782013432, 58.778631148799775, 60.03050658010668, 61.31145854150096, 66.57316515522619, 56.82409840245401, 56.44370302077263, 58.888645787392896, 56.18640730457922, 67.09449521956905, 63.01394370294387, 64.26991408871066, 59.80485654646351, 56.58778736668249, 44.758240561331476, 67.69392751878308, 69.09469219946092, 62.6542035225899, 54.14746515212521, 53.10687995726063, 50.61169162873299, 54.4454986049283, 54.67574565641342, 54.01404573071388, 54.201131020822835, 54.6781853706606, 53.89740228652955, 61.92914947386711, 68.15595134612053, 72.7977861896638, 68.77807063441124, 70.84104122654085, 71.26151930901312, 70.28959520401494, 65.92278911221412, 69.00110444714947, 71.20437037560248, 78.05277378328385, 73.50156138020178, 79.9626934912897, 18.8273258363047, 0.7047169271015352, 0.7456257771099768, 12.062634633433435, 94.44966177786551, 75.28282734655565, 73.00694265673238, 54.33559771507017, 72.91018562932169, 66.9483006385065, 76.72529466690557, 74.83319820896273, 74.21273416088474, 4.0137094259262085, 0.2920034521770093, 0.12647232927021482, 0.34116055636155995, 0.09558329644102244, 0.14930295217181408, 0.14962886129656147], [0.11981369221522925, 0.05355903773658699, 0.11446161811510402, 0.008699230984934877, 0.07120901403287727, 0.06453925338123115, 0.08449954401341178, 0.06574003491550684, 0.22634099898559434, 12.129109982521305, 65.38483212071081, 44.80672890140165, 53.31679344177247, 14.61236155802204, 37.09079527085827, 27.579106438544493, 65.15934290424471, 62.28300217659243, 78.41725610917615, 13.267788752432793, 0.3672004977781927, 1.2134222301744646, 0.24191722123613282, 0.20825062938515218, 1.0688852182319089, 17.490576198024137, 32.55666675106172, 50.243357535331484, 53.863179606776086, 64.85749690763413, 61.25149334630659, 65.53801636542043, 61.11533218814481, 65.05756916538363, 59.52002579166044, 59.494091080081084, 55.74049265153947, 64.39692435726043, 60.918186018543864, 57.10210031078708, 47.316775168142016, 45.33356989583662, 42.829113006591804, 46.26392864411878, 51.848513003318544, 55.85467676962576, 59.67442989349366, 61.911957725401855, 70.90608981347853, 54.881807373416045, 53.318405535913286, 61.75702802596554, 56.57310201275734, 58.58081425389936, 49.695602463137725, 57.162061583611276, 54.77840192856328, 56.41015498868881, 51.840417231282885, 48.74853049555133, 49.025496898158906, 53.13481507762786, 44.6093983804026, 44.77055288130238, 43.08054870174777, 44.72639483790244, 46.45685042104414, 48.6377666842553, 44.004576744571814, 42.007054821137466, 41.783687606934585, 42.45076902451054, 40.10530541020055, 41.960708095181374, 40.81224203109741, 39.340325555493756, 38.68743527320124, 41.35634145429058, 37.2566330817438, 41.07536246699672, 42.92796065730434, 45.138373144211315, 43.39246342259069, 41.59065600364439, 44.40315623437205, 47.04029121706563, 50.299549410420084, 50.53585652382144, 37.05486636007986, 35.197263225432366, 43.48072067383797, 55.19400842728154, 57.26253701794533, 51.81040325472432, 46.64175879570746, 44.3815282852419, 41.2208745556493, 42.44741932038338, 41.726550440634455, 44.59749790929979, 39.31940363299462, 39.45725533270067, 37.048586645433986, 38.10742262871035, 37.2351110366083, 39.20034400878414, 39.99643610369775, 39.92475478879867, 41.935636305039935, 41.33257973578669, 41.00833308312201, 45.924467117555686, 45.63332919151553, 44.12890411192372, 43.108444598413286, 44.73306286719538, 44.86084976503926, 54.00369459582914, 50.19820713227796, 50.25643863985616, 54.64138177133376, 53.019356189235566, 48.72282328144197, 57.34775443230906, 51.55051877421718, 60.612001880522705, 59.805150724226436, 64.17605961522749, 57.412693192881925, 59.46528519353559, 41.09227180480957, 48.363698913205056, 69.38995253655219, 56.67655452605217, 57.69434682784542, 48.412512809999534, 45.654753177396714, 46.42387897737565, 43.79485153382824, 48.60332435177219, 49.35561533897154, 49.824926930089156, 50.4599194372854, 52.24621388220018, 56.22018283413303, 62.76921526078255, 63.14123638214604, 69.6537083964194, 61.72459002464049, 63.465102564904, 58.03051748583394, 62.444929384416156, 63.67636142238494, 69.84066424831268, 65.0751413837556, 56.216974335332075, 4.326264963996026, 0.1822020005314581, 0.6252145899399635, 24.760842284848614, 76.97686764501756, 62.261017291776604, 50.16751850804975, 39.16663515952326, 71.51644983599263, 23.608740183614916, 33.02519582932995, 56.23577033319781, 51.97496237293367, 5.801301685071761, 0.13473962073124227, 0.05953340888804486, 0.035158854518686576, 0.09798736461708624, 0.049081495136863766, 0.04250197198181864, 0.07725340179017476, 0.017446321397719365, 0.03790968473279669, 0.04938434501509032, 0.06549628872063852, 0.048502727201388735, 0.08166491910214387, 0.03567930018048614, 0.21889508401434268, 17.232676436824185, 77.8403539042319, 50.488725323830884, 50.1032583175167, 25.79124108437569, 44.50835028002339, 34.2225738494627, 69.66908408749488, 66.21872409697502, 82.58771619489117, 16.19206084359077, 0.8846704289317132, 2.434406299744883, 0.07583692820081789, 0.07672236496282202, 1.3663425729159386, 25.96609446310228, 37.04949271294379, 49.75861533995598, 57.288267766275716, 68.10034782655778, 63.67166242291851, 66.97717712771508, 63.02049798350181, 64.55102643659039, 63.827772755776685, 62.80803495837797, 60.508510143526145, 64.6557144964895, 60.70785676279376, 60.10808321737475, 51.200925765498994, 47.01791409523257, 45.557348958907596, 49.1767591814841, 53.99055857812205, 58.35845901120094, 62.11670937076692, 63.24211189823767, 70.85709941002631, 58.97078414117137, 54.951605950632405, 61.726551209726644, 60.27546644210816, 61.257984868941776, 53.48047394906321, 60.383088434896166, 55.88250598599834, 58.90625330709643, 56.807071393535985, 52.56436909398725, 53.97144486827236, 57.53945635211084, 48.47561590133175, 48.96284095702633, 47.40506772072085, 46.35501000189012, 51.317353479323856, 51.447595780895604, 46.54923792808287, 43.346359883585286, 44.63922408319289, 44.4168217720524, 41.47932344867338, 45.02554616620464, 43.166903603461485, 42.761365828975556, 42.51743362795922, 43.91444852275234, 42.592037108636674, 43.24988918919718, 44.370102420929946, 47.48595876078452, 45.31355796321746, 44.5956269387276, 46.42536947804113, 49.91462761355985, 52.6426007670741, 53.19633745378064, 36.9929595916502, 35.4795915080655, 43.71450178084835, 55.277966760819965, 58.97980951493787, 54.65843623684299, 48.66218343857796, 45.54706450431578, 44.10930795054282, 44.69487074882754, 44.721001578915505, 47.23884551755844, 42.98538415662704, 43.908553200383345, 39.079393802150605, 40.473765019447576, 40.58773340717439, 41.95649546961631, 41.30389152034637, 44.59553280184346, 43.36591289889428, 42.58275678080898, 42.360629035580544, 47.605575361559474, 48.04464155627836, 44.655627435253514, 48.32916244383782, 49.23683812541347, 50.18834237129458, 58.273665212815814, 52.61071974231351, 53.85205184259723, 57.31121755415394, 56.00272663177983, 51.11016996445195, 58.040437159999726, 55.044009147151826, 61.24843781994235, 59.17144083207654, 65.59170184596893, 62.896860953300234, 62.127715541470444, 43.06993084569132, 53.675039199090776, 71.31986064295616, 60.06757690060524, 60.64352989196778, 50.46924291118499, 47.41100618916173, 47.61542443306216, 46.88201181350216, 51.324841283982806, 50.380864066462365, 52.76044837890133, 53.06212179122433, 56.6859721368359, 57.94524123591762, 65.68574851559055, 64.00373420407696, 72.5215728821293, 64.37746940120574, 67.44471580751481, 60.36976022105063, 67.36540548263058, 66.61717414855957, 75.52090737127489, 69.50555263027069, 61.74536681944325, 3.917812868472069, 0.07566576883677514, 0.515954333447641, 28.231610367375037, 85.81003742833292, 68.24768773971066, 58.064540124708614, 41.49235748475598, 77.64537288296607, 21.249446292077344, 35.58952769925518, 68.99752724555232, 62.099192065577355, 8.758277027837693, 0.29395927464769733, 0.12565187208594816, 0.18249901281970163, 0.07376819203097014, 0.04560643221221624, 0.04322409412012466, 0.25209022535672115, 0.1171702751889825, 0.16764862823390192, 0.1578660838065609, 0.16822005321662273, 0.1691781074529694, 0.3195998084641272, 0.23510849223502223, 0.23266963600631685, 22.871487563656224, 88.7317011433263, 60.08103455266645, 71.14484448586741, 27.033432183727143, 54.93405334411129, 43.70883003357918, 78.80654350403817, 70.62244753683768, 91.96869204121252, 17.835040707742017, 2.389015406370163, 8.458405944608874, 0.5953079882648684, 0.3472196683287621, 1.906937113212001, 35.75662066859584, 50.53198906683153, 53.522074607110795, 60.61737552765877, 71.87120468385758, 67.50483005277573, 71.82966678373276, 68.30719793996504, 69.65492433117282, 65.43147694679999, 65.2295337184783, 61.27448628025671, 67.54098646102413, 64.03361482004966, 63.38140310779695, 52.25843598765712, 49.852187402786754, 47.99848310409054, 52.70031844415973, 57.63127511547458, 58.96925049443399, 65.84158036016649, 63.91909337812855, 63.95141763071861, 59.59443315382927, 60.64174913590955, 63.30241049489668, 63.618059312143636, 64.57791036175144, 54.30162998937792, 62.32661108816824, 59.70204337950676, 62.860327997515284, 60.60039558718282, 58.260866518943544, 60.04180692857312, 63.101934233019435, 50.85089737369169, 53.53016253440611, 50.83607081444033, 49.21418251529817, 53.789321376431374, 56.72123424468502, 48.69599034709316, 45.35807686467325, 46.09186603176979, 47.82055262596377, 44.246253582739065, 46.09461561326058, 46.815963022170536, 47.01028508524741, 44.30659924784015, 48.36035705381825, 44.47146431092293, 48.23571589685256, 47.715005566996915, 52.1411531971347, 49.322051617407034, 48.048975775318766, 49.85642356257285, 50.49462849094022, 57.268604924601895, 52.80307277556389, 37.43477929023005, 37.03838063824562, 46.05936527252198, 59.97739768797352, 62.05468100886192, 57.55496932614235, 52.90665472707441, 47.41428136825562, 44.97313153359198, 47.65920592892555, 48.43823179121941, 53.0500683476848, 48.630800554829264, 49.93249400969475, 42.94354423399895, 43.1816085692375, 44.930479680338216, 43.40231249409337, 42.32395879683956, 46.711902541498986, 46.04865327958138, 44.47777932690036, 45.209348432479366, 50.83952250019197, 53.405333103672156, 48.9026011959199, 51.14842876311272, 52.335400735178304, 54.60275034750662, 61.10382395405924, 57.718747892687404, 59.905402583460656, 61.332031373054754, 58.87064603067214, 53.8464310861403, 61.66554266406644, 57.076330338754964, 64.45566969533121, 64.5559411664163, 69.0810109722999, 63.15014800717754, 61.30646928664177, 48.23184843986265, 53.245006222878736, 68.87975415875836, 62.7514979147142, 63.20106429438438, 54.74108449874386, 50.28392268765358, 50.66229412632604, 48.42504870507025, 56.00475449715891, 54.746850382897165, 56.84086261257049, 56.35118999788838, 58.30712303038567, 61.83214925950574, 68.54874533991661, 67.68376858003678, 76.2129468302573, 66.74636917729532, 71.91190319676554, 64.15778921496484, 72.01911726305562, 70.25295242186516, 83.47534072014594, 76.59650756466773, 72.22070355569163, 6.180998394566198, 0.2299313619732857, 0.8424114255655197, 30.440096970527406, 92.31197787869363, 74.70257543748426, 63.82252462448613, 55.16384147828626, 93.35459878367763, 32.326574633198405, 50.48430873501686, 76.41303477748748, 79.58954272731658, 9.894810261264924, 0.49784766149617016, 0.3258396865379426, 0.24867289098760775, 0.15284647654381492, 0.15890082344412804, 0.15581505192864328], [0.08862383197993041, 0.038053042766067295, 0.06648147013038397, 0.08464046588708317, 0.018782905423112454, 0.025072659651238113, 0.03719284477072858, 0.06123743741022003, 0.0466465421261326, 18.388795045114335, 66.04638299634381, 50.588808521147705, 48.33362610109391, 25.26019727030108, 38.41726633810228, 24.187536893352387, 49.54093164013278, 62.89057731628419, 70.52838125536519, 40.9268379980518, 0.3462953066393253, 1.101492739492847, 0.037079934902008505, 0.08800746061869207, 0.20697034324609465, 0.972640366563874, 33.212422324765114, 51.23874918107064, 52.814812429489635, 54.71147844868322, 54.38364674968105, 58.16293278048116, 58.70821283709619, 59.18711070091494, 57.012984060472064, 64.4803531708256, 64.92873107233356, 61.25756517533333, 59.250966887320246, 51.25291285976287, 45.50130613388554, 47.540381646925404, 45.35212270675167, 52.21387394012944, 52.55683814325641, 61.71558818509502, 57.86993565097932, 73.685716659792, 54.794573860783736, 39.957945885196814, 61.677949120921475, 61.59175111401466, 57.8005136212995, 57.27049942939513, 52.6264915927764, 56.335410302685155, 55.03472489695395, 55.009778622658025, 53.661726674725934, 48.20951446410149, 50.07872389208887, 51.37162339302802, 43.128805621977776, 43.69027330029396, 42.930094426678075, 40.87205425385506, 43.572170734405525, 44.44644351159373, 47.69770399216683, 39.00188776754564, 40.48708146618259, 41.14293706032538, 44.158380723768666, 41.5763589643663, 40.3400121965716, 38.59322778640255, 37.60568872574837, 36.55541919892834, 38.1902434748988, 41.55157742961761, 43.39016099129954, 44.4287653892271, 43.523184253323464, 43.74880290800526, 47.23946525204567, 44.676004148298695, 50.01088649995866, 51.156548069369414, 37.34140726827806, 36.4519117724511, 42.47197335766208, 57.74980129734163, 53.18546856603315, 48.30517322786393, 47.65774680722145, 44.646084308624275, 43.70266014529813, 43.098532768987845, 40.84774732589722, 42.082297648153, 38.47729429121941, 37.02606439590454, 38.0323092399105, 40.42883034675352, 36.672631386787664, 35.86636466364707, 38.57700486336985, 39.776077347417036, 40.62839661875079, 41.372748728721376, 46.62893656761416, 47.72266203357328, 45.848988948329804, 43.12710331332299, 45.64044044863793, 42.582874451914144, 46.42999787484446, 49.50873290338824, 49.721293987766394, 49.32357741940407, 53.94348621368409, 54.769184358658336, 51.582337041055005, 57.234323409295854, 53.76717175206831, 55.80305053341774, 58.126595943204826, 59.40754398222893, 60.632966949093735, 59.428928744408395, 51.072468142355646, 37.11306256632651, 63.28221028850925, 64.59814194710025, 59.3566276950221, 53.79481269467262, 48.39035926326629, 46.27266376249252, 48.19533509592856, 49.22316866536295, 47.47212456118676, 46.231686761302335, 48.849319719499164, 48.02015812166276, 48.013729356950336, 55.09174439214892, 59.35307795001615, 62.723660853601274, 62.26274313465242, 61.565561448374105, 59.67924264169509, 63.06605631305326, 65.001012509869, 67.26057621740526, 69.10245064766177, 35.440418797154585, 0.35991129375273184, 0.3779013671221272, 0.30092558793483243, 42.809932616449174, 72.14882219991377, 64.26048078844624, 51.18999804219892, 46.04548400448215, 49.87334466749623, 43.109068255270685, 50.788233587818766, 51.43421265386766, 62.49715966563072, 12.179731111372671, 0.17088184103129372, 0.14379019879045027, 0.04614874202337477, 0.09381967010877787, 0.04711583226678833, 0.02151153249395711, 0.06681795126848644, 0.022909556770877495, 0.0817148220695315, 0.021616176273974202, 0.06017266712602108, 0.09424246637330902, 0.07233723171896513, 0.07676659887956996, 0.13617582108464935, 24.969365289134366, 76.78908025064777, 54.7057007974194, 57.68883982012349, 33.15662268669375, 49.038566235573064, 33.210143427695, 56.545829772949226, 68.58351322912401, 75.17082798865535, 46.89983898593534, 0.14418554612465445, 2.6519806634995247, 0.21870095733433, 0.09893329168159155, 0.1314896459300672, 0.40069432148048956, 38.93226177461686, 53.70153480960477, 53.03019762039185, 56.09052496571695, 58.33931784476004, 61.17837252155427, 61.98050506653325, 62.967083146495206, 60.248394243178836, 67.00170763077276, 65.66779974968203, 64.18042913559945, 61.27436860915154, 53.361331955079116, 46.404922162332845, 48.689381153352805, 47.06665738936394, 54.78932965186335, 56.28611003198932, 65.99070887411794, 60.43973530492475, 69.58570234237179, 58.49048206883093, 41.852148655922186, 62.673328999550115, 60.996966823454834, 61.12687572356194, 60.98703145980836, 55.38336476972027, 57.61755858698199, 57.63491115262432, 57.07119987856958, 56.604022056825706, 51.910411927007864, 54.252549371411725, 55.82280751197569, 48.76978974188528, 47.264309544717115, 45.93597535164126, 45.23639709718766, 48.06194705347861, 50.105368552669404, 51.314219505556174, 42.82247243389007, 43.3457205372472, 43.0078475706039, 45.28823121901482, 44.49133111584572, 43.34583036361202, 41.566309851984826, 39.54459474932763, 40.322404676868075, 42.05271120994322, 42.49651955020043, 46.74310107384959, 46.617075320213075, 46.26837661189418, 46.44622079787716, 51.18010190225417, 44.87810819379745, 53.0690683087995, 55.12557875725531, 36.39814392212899, 36.889867936411214, 41.91908390291276, 57.13290268375028, 54.46850330598893, 50.30838258804814, 49.70054857192501, 45.932939437127885, 46.328137843839585, 44.14785700459635, 44.41368387591454, 47.18107684966057, 44.20759470232072, 41.74840980960477, 41.199658455387244, 44.875374301787346, 39.98413947320754, 38.545174829421505, 43.04764001600204, 41.82052650759297, 42.00130854883502, 44.21185831869803, 46.86783636769941, 49.11178904194986, 47.12905445406514, 45.076262412532685, 47.979126207290165, 46.36414520202145, 49.654507790842366, 54.6847318064782, 54.26173163998512, 54.07756851565454, 59.529439480074, 57.66880043091313, 54.588833778135246, 59.231339346977975, 55.545370424947436, 58.244674974872225, 59.81078324779388, 61.31181939955681, 63.75338500545871, 59.56573709364861, 52.185887828949966, 41.93477338360202, 66.92321315888437, 67.06040982277163, 61.79619289213612, 57.54675588300152, 49.86022041689966, 49.52836828847086, 49.712041116529896, 52.31898169363699, 51.074362647148874, 48.95578461308634, 50.24026278526553, 53.41230315546836, 49.71044078949959, 57.23037358253234, 61.76157013062508, 66.29976810947542, 65.61782875368672, 64.39261759481123, 62.334965736635276, 65.08737525632306, 69.06525088894752, 69.75910248294954, 74.14646963919364, 37.635867441854174, 0.24780439242960947, 0.2516177329685419, 0.35310107854104816, 49.16050487949003, 78.90338682359265, 70.69476819807484, 58.239595505499075, 50.987929298031716, 67.012298030238, 42.43121993157172, 63.75495003115747, 61.30546123750749, 72.56115744190832, 16.221266811893834, 0.13891968755952774, 0.1520415632835319, 0.05917379572506874, 0.053543283138424165, 0.02612959285597167, 0.03226498036735481, 0.15537680367067938, 0.08489286121461662, 0.21669065069046714, 0.1630943580981224, 0.10722178845636307, 0.172727775850123, 0.14400836530952685, 0.10301680078790074, 0.22840107070101848, 33.182914333958784, 86.46931725163614, 65.26777290528821, 63.98554225121776, 34.20519382722917, 55.88426320783554, 36.65185459198491, 65.96679810554751, 71.80238277681413, 84.00952831391366, 49.36429946653305, 1.2116335068018207, 3.8095110799035723, 0.22464340943242275, 0.43479690929093673, 0.258957268970628, 2.3353664528939033, 46.46745650999008, 61.0959517571234, 58.865935264095185, 61.01975579415599, 63.04314967124694, 65.55630637753394, 64.7455995313583, 64.55774937906574, 60.67894497225362, 70.25985579336844, 69.21382242633452, 66.49766737414946, 64.28390518311532, 55.8640786909288, 48.77364935413484, 53.44483529367755, 55.2468192192816, 57.865417080540816, 59.08931424540859, 65.39361038515645, 63.44569075492121, 67.30617769302862, 58.54960395443825, 48.26736550177298, 62.389039531830825, 66.78029767928585, 62.473209673358554, 65.21859422806772, 57.586516949438284, 60.5026932685606, 57.47876944080476, 59.94802698012322, 62.135756400323686, 58.490278105581964, 57.845526741397, 59.023300755408506, 51.96367771394792, 50.62156423445671, 48.249679534666, 46.53364650664791, 52.0905860008732, 53.18890848467427, 54.61307010342998, 44.75621661832256, 45.663523597102014, 45.91651255084623, 49.12887880879064, 46.39541433703515, 46.082142476112615, 47.45061036079161, 45.003878993372766, 43.85693088654549, 46.94072185024139, 47.39902334828531, 49.703662933841834, 49.00970543584516, 47.89842344099476, 49.72187057618172, 53.3818773300417, 47.970716645640714, 54.79874334027691, 55.94490697306972, 36.25196895291729, 38.22632143574376, 42.74115385547761, 62.007090891561205, 57.98653594909176, 53.50330606583626, 53.67300348897135, 49.80606032956032, 49.9107954579015, 47.79846183715328, 48.4049936263792, 50.539123858174975, 48.523209941002634, 46.68811336640389, 44.7478227461538, 48.16479159939674, 42.39567541307019, 42.00861592446604, 45.38149341460198, 44.792651514853205, 44.99819547899308, 45.939803584929436, 52.57304145443825, 56.47124982649281, 51.55977556782385, 48.899467222152225, 53.71885599628572, 50.743216545351096, 54.69219999928629, 58.09893931111982, 59.43518100246307, 60.51654315763905, 65.51419581136396, 61.34195496959072, 56.06863029541508, 62.344489251413655, 58.74045471991263, 60.738278665850245, 60.716635027239406, 64.40969167217132, 65.26337985069522, 61.69964767271473, 55.75477400133687, 46.15531429167717, 61.44870619620047, 70.58350624576693, 64.05754912284114, 60.120069980621345, 53.34524631500245, 53.00779696433775, 53.80319479973086, 55.62084859417331, 54.28149254091325, 52.221812817358206, 53.53303370937225, 54.53381076935799, 53.48976604400143, 62.35264778137208, 64.23231817060902, 70.05015019447573, 69.86519475137034, 68.29419136047363, 64.76883172988892, 69.24035333818006, 74.44041990464734, 77.15743787827031, 81.68302935938682, 45.00166677659558, 0.6366829261664422, 0.6888002553774465, 0.6802322667452597, 51.726601815992794, 86.37645121543639, 78.98646262384231, 71.60669572891729, 63.613830997097885, 74.90391069842924, 60.98011239882439, 73.24668576640468, 70.18322836968207, 83.22241060195431, 20.32695777954594, 0.5565128054830336, 0.3138786025585667, 0.2033092703429922, 0.1580777692217981, 0.18284408946431455, 0.1085597763378774], [0.030119725420410116, 0.06059987222655647, 0.10788876758587938, 0.027612319644240123, 0.02139410845214321, 0.08225361936755719, 0.025349927938453136, 0.07960606546651933, 0.02959593386960126, 23.737225263349472, 66.6313103706606, 45.892433120358376, 43.83161590945336, 30.273582550787157, 30.290409518826394, 26.05200025343126, 50.628138126865515, 69.58116023771225, 56.14888591151084, 65.36873079115345, 1.8975182766875915, 1.0176189207742292, 0.3398520475433719, 0.09690762497484685, 0.06256699449412766, 0.05874308194184016, 1.2634692220918595, 46.26164974704866, 53.3285762417701, 59.86755563366798, 63.74503820173202, 63.867671105169485, 64.57327412020776, 64.88298054664367, 64.58502554124402, 63.22582621728221, 60.69886669035881, 58.325636617599, 53.21712993806409, 45.592226674479825, 44.75772280846873, 45.09996921785417, 55.52441712348692, 57.677221759673095, 60.67902734202724, 55.19942914285968, 57.536596944255216, 60.03051050247685, 30.57828599406827, 56.850927414432654, 63.13144614619594, 58.37639208762877, 58.06890964508057, 55.09423509720833, 51.842696128353, 56.273185822271536, 53.668178973659394, 55.27735487107308, 51.383606233904445, 48.35955296793292, 48.61465607920001, 49.390512666394635, 46.14772842776391, 42.80697514933925, 43.15287328535511, 42.08144257145543, 45.26188465856737, 42.77446262298092, 47.52059328940607, 43.02781635715116, 42.08004228530392, 41.92072737601496, 43.27638872208134, 40.21198211177703, 40.851924650130734, 39.153452073374105, 38.53489821957004, 37.28788260490664, 38.836061723770634, 39.20897714553341, 39.39201847199471, 45.1389693444775, 45.05735266593195, 46.72742728264102, 47.39787409382482, 47.358046347095126, 54.33553103477725, 50.27089257394114, 37.33852432620141, 35.83551914461198, 44.01193118864491, 57.82369090664772, 52.16808811310799, 43.452471763856956, 47.07985224262361, 46.113996044282, 44.925631630805235, 42.933283313628166, 40.72519286986321, 40.316772153300626, 38.92062802468577, 37.81372731731784, 39.457616190756525, 35.64259736768661, 39.26504350477649, 40.67179764470747, 40.297144612958355, 41.1796308332874, 41.70351043824227, 42.17072356131769, 47.50902229739774, 41.414521971056544, 43.616211106700284, 44.295946090452134, 43.76022484994704, 42.692261511279696, 45.098047256469734, 49.73614800360895, 52.897801937595496, 47.65876270109608, 54.051676950147076, 58.45457276990337, 55.189736966163885, 56.02556267092305, 51.24014946722215, 53.881955992790964, 62.10801739846507, 59.84950096376481, 64.74159871378254, 57.20295229265767, 58.55775856202649, 39.20365056683941, 52.3147573009614, 65.68525429694884, 59.72473429095361, 62.0351593725143, 50.8243429276251, 46.69938233590896, 48.25428047487813, 51.51318565491707, 46.79169531791441, 48.67018899609966, 49.212491973753906, 46.472865458457704, 48.07690697331583, 49.12613314967002, 53.49935231670257, 57.69056958536948, 59.83041471050632, 56.62710128291961, 58.82743720085391, 64.7071603036696, 71.11097089705929, 64.45777993048391, 67.61784922692084, 10.504620171362355, 0.049374730611640605, 0.41907758181614263, 0.7869049233774986, 62.4918487764174, 68.52656041422199, 60.7640290260315, 37.653977024939756, 34.94801621283255, 48.85969046623477, 35.970558504904474, 27.57426427256677, 49.420601167986476, 60.960861406018665, 12.654227095265544, 0.2417411589093747, 0.11083280517449302, 0.023217413033689224, 0.032460869049593326, 0.08884472577201744, 0.035503008027350715, 0.0536883112433697, 0.07192638642605274, 0.05450413359569446, 0.06972460376639521, 0.049402643025161765, 0.05029670976763291, 0.10245567202688226, 0.10226005913629647, 0.1193240701010631, 34.14755067517681, 74.12264516276699, 55.34143855494838, 57.923307341914025, 28.337016221015688, 34.60504024259506, 31.811953783035282, 54.07606232550837, 77.47099214984526, 61.42121038129253, 74.65664448276644, 1.851641377133708, 1.38393881580522, 0.46476277552785417, 0.23696689896525877, 0.09323081662577969, 0.4965949238788697, 2.6716471823953816, 53.046600972452474, 54.758743009259625, 64.52592326748756, 65.62561858084895, 65.02113819122314, 66.95920482758554, 66.63090244416269, 68.49503240277691, 65.90172598438879, 62.86994172680763, 63.35697458636377, 55.27055740356446, 48.85020617515811, 46.5888342549724, 48.17935143747638, 57.79781895299112, 59.6627490751205, 61.01046762158794, 57.959353923797615, 57.27270772380214, 63.20844619504867, 35.25310600957563, 57.201857951379594, 65.0333995203818, 60.96081433757659, 61.58143920283164, 58.10705861737652, 55.41930152523903, 58.95191361827236, 57.75478662983064, 58.7502488782329, 55.874637711432676, 53.047205017459014, 54.950539065945534, 51.40090780873453, 50.258023277405776, 47.421369091157, 47.411053257603804, 44.64304054937055, 50.154711969437145, 47.78128185579854, 51.5335702127026, 45.59673347780782, 43.047114418398955, 42.61684609997658, 43.60555010457193, 42.21751351510325, 43.15701530825707, 39.74780098084481, 39.833257659789055, 41.20190597349598, 42.51921830638763, 42.80440599687638, 44.074124290097146, 47.32186640462568, 45.94085478013562, 49.119108184691406, 50.21049591802782, 48.513384403720984, 57.63795883424821, 52.538854076016335, 34.8163422461479, 36.040051137247396, 42.61557917441092, 58.46250772476197, 52.72736318649785, 46.84136429140645, 49.01000353597826, 47.60726198073357, 46.76682749102193, 45.835346944870494, 44.52127841211135, 43.58892709978166, 42.19877243041992, 39.743329478848366, 43.61540309844479, 38.92369139579035, 40.42302131652832, 43.38213582192698, 44.00254887919272, 43.23319950411397, 44.89522933959962, 43.47506853841966, 51.01995937285885, 44.53632854646252, 45.587139360366336, 47.24274435350972, 47.235244781740256, 46.134360990216656, 47.640751177264804, 55.125982761383064, 58.232947088057, 53.92501185017248, 57.35033535188245, 58.06137084960938, 56.894375508831395, 58.317756575922814, 55.37539451353012, 55.3390419867731, 61.54294898433071, 60.465560190139286, 66.4144346790929, 59.66325506087273, 58.98279051626883, 42.74279340620964, 56.232059771014804, 66.68651380846578, 63.67403153450259, 64.50136138546851, 54.4221212787013, 48.151047614312944, 51.18047844979071, 52.995253224526685, 50.584548827140566, 51.18482051357147, 52.11726204041512, 50.26901768099878, 52.20745694252753, 53.771827605462846, 57.33801910954138, 59.532400869554095, 64.08802201670986, 59.645019961941635, 61.03648470294092, 67.01492601825346, 74.16197084611463, 68.4064103711036, 72.37540968002813, 10.687321232211206, 0.03149462533333609, 1.136731680843138, 1.229847155271038, 70.19557599098452, 74.04961847489881, 68.70244733748898, 42.72087127931657, 37.62296676635742, 66.02637106372465, 37.03446611281365, 43.73176020960654, 63.14337407388995, 70.09495150658393, 19.12930323231605, 0.3579331015146548, 0.16236547140344498, 0.027135066019611496, 0.09358643464023068, 0.028291297625870477, 0.0798719592632786, 0.11714810460445382, 0.16419988425989307, 0.27673299093880965, 0.10707463062698803, 0.18014369081825982, 0.17174670833253092, 0.30584647710765567, 0.21848331175504193, 0.1404943506443693, 41.321816752033854, 84.09159214265885, 61.660047423455026, 56.947876637981786, 40.164819532825106, 44.60949643965691, 40.87072457036665, 64.89567725889145, 80.89260116700204, 69.0106907198506, 79.30238600700133, 2.345981122024598, 3.445602400648979, 0.5953772426132233, 0.40821712103582203, 0.3098081935557627, 1.2284967567651504, 4.993918557320872, 62.10238879726779, 60.42788974700436, 68.61820267092797, 69.38535551871024, 70.06417659021193, 71.031613503733, 72.23028982839277, 71.30356711726036, 68.46758365631104, 66.66033590993574, 66.39899623009467, 57.7280988231782, 51.07862626352618, 49.527591659176736, 51.41479299914453, 62.188155343455655, 63.656482850351644, 62.45592378800916, 63.900850434457105, 57.502774346259336, 58.60851010968609, 39.80255334608017, 59.78568007869106, 68.11146382362612, 64.27425223012125, 63.77283603914323, 60.957315583382886, 56.227117584597686, 60.43138065645772, 58.33168099003454, 63.27628358717888, 60.36768136485931, 58.816709518432624, 59.8073511738931, 58.82146735345164, 54.97815647432881, 51.48099476291288, 51.87230217841364, 48.516773331549864, 55.47574443201865, 50.80758656224897, 56.254448659958385, 48.58985885497063, 46.249207988862075, 43.87598968321278, 48.002162287312174, 44.882932709109404, 47.095690773379424, 43.73477651226906, 45.08358155527423, 43.62991586808236, 46.25418939898091, 47.183069413708104, 45.08311479322372, 52.12144720938898, 50.23743867874146, 53.21298007042178, 53.005753409477975, 50.236367871684415, 58.36804528390208, 53.749117082165135, 35.93121713207614, 34.8373112370891, 44.087213239362164, 62.69426268915977, 56.215460300445564, 48.0146824929022, 53.266540035124756, 51.984823211546875, 51.927952766418464, 49.33955323311591, 47.80441991744503, 49.578260837062714, 48.70904007265645, 44.334146053560325, 46.45603849041847, 40.58867869838592, 43.332651199833045, 47.446656611657914, 45.67897773558094, 46.52545267535795, 47.36846808464297, 48.33774458977484, 54.43037002317367, 47.307510529795, 52.72555497384841, 50.879550287800456, 48.832312322431996, 51.279761483592374, 52.57204125004431, 57.74079161305582, 63.70483782983596, 57.095722536886896, 61.71322691825129, 62.03494756452499, 58.802604675292976, 61.91624879837037, 56.436882019042976, 57.72986388975575, 65.16734453939623, 63.81158121170537, 69.36747735546481, 62.26743821174868, 60.59257830342939, 46.41252371572679, 54.41102489348381, 66.42289915392476, 66.68663932431129, 66.6038537794544, 57.76721269853654, 51.19265348680558, 55.527743293393044, 57.19138522301951, 52.48212091384396, 53.517885515766764, 56.55445114258797, 54.26305740110336, 56.17069821203909, 56.64586982419414, 60.70504050101004, 62.1243070017907, 66.60277905002718, 63.8746686135569, 65.4162738400121, 73.55560379643595, 79.56824425728091, 74.06583355319115, 84.12592072640696, 14.989222884178163, 0.16256033352786498, 1.1321415271489852, 1.7272366655449716, 74.59933080980855, 82.56305233124765, 75.3364618362919, 53.583616595114435, 50.50607788947321, 71.28526533803633, 48.4412794728433, 40.83416415799049, 68.74642495186099, 87.4225865640948, 26.985049747651626, 0.406357090199186, 0.3459943566591509, 0.1587762115823646, 0.303222625966995, 0.18679010110997385, 0.17134123331596776], [0.05318349377522546, 0.03472504190980427, 0.06802111533620665, 0.06572233062357673, 0.050721034377573, 0.019045252232782302, 0.06431591576866566, 0.12296697905948087, 0.8768090185138487, 49.96182157147316, 63.42581218288791, 51.78203667363813, 46.85494745931318, 62.090904097403254, 52.455970471905125, 36.199934790211344, 36.15660044454759, 72.03667379194691, 54.706555874116965, 72.43539840944352, 9.925926423841908, 0.7013456499384296, 1.1328835905559602, 0.13525764938564072, 0.4710495075391185, 0.25606191626960234, 0.5473894950362944, 21.515820334034583, 63.11333656311036, 64.2893062868426, 64.70097080353769, 64.61387457386141, 64.0115632549409, 61.13448119932606, 61.067279231163766, 61.3623591392271, 60.616528295701556, 50.25038642268027, 49.88601784552298, 45.32725095748902, 47.734613495488325, 51.37085068610407, 58.6542292564146, 56.35180581000544, 61.516888756905836, 49.495051676227206, 64.9196154840531, 45.77818624434933, 41.61412354438536, 63.30075917705413, 59.45394562136743, 59.030200204541615, 58.141646077556, 55.886063575744636, 53.54520874638712, 60.980437955548695, 54.81222060418899, 54.86237202921222, 53.352530156412435, 50.32628036314442, 51.74153820160897, 50.512165407980646, 45.763999031436065, 46.89225704439225, 42.359358187644716, 42.92042186183315, 44.16244822163736, 44.74075463510329, 43.9230110568385, 44.904329238399384, 41.41103106160318, 40.76777412045387, 42.625675355234456, 39.73325290987569, 40.49740122210595, 38.614828278941495, 36.96650320483793, 39.16388557803246, 40.74098040980678, 40.66854992220479, 41.13035409681259, 44.44557666778565, 44.72211553204445, 44.40170103503812, 48.33627370096023, 54.44410616351713, 61.81103121849799, 53.25565545789657, 38.54023656537456, 35.75546749176518, 42.44445008616294, 57.88386398746122, 57.98810489716069, 45.57947504904963, 48.98790098005726, 46.16660679540327, 44.23802052774737, 41.326609888384425, 39.366017080122425, 37.6812453423777, 39.95706335190804, 37.982781471744666, 39.274578786665394, 38.41264186366912, 39.46017357610887, 40.62743956042875, 41.51932377969065, 37.87095077576176, 43.07446902798068, 45.70929765701295, 44.743872919390284, 43.668123675930886, 43.728614468728345, 44.292714057430146, 44.39810422159011, 43.448443489689986, 45.85227981690438, 49.32673492739278, 54.15888709406699, 51.70879817778065, 53.8948017551053, 56.659719713272594, 56.46930825325751, 54.356111711071385, 54.22456326023225, 55.10737111491542, 59.850669830076164, 59.50870190897296, 60.73934555053712, 58.33247723117952, 57.42466426664784, 46.068947622852946, 46.993838587114894, 63.55665460709603, 63.28786634629773, 59.9891883327115, 57.38305184148974, 49.28237684311406, 48.67833183657739, 50.59556284258443, 48.86005524666079, 51.776039369644664, 54.89559450457173, 53.37737837145406, 50.488423301327614, 48.29581445263278, 53.679298893097915, 53.63139106381325, 57.688761372720045, 54.97770147938883, 62.0840124930105, 66.90841797859439, 68.56859253298852, 70.83914279937744, 44.91087959658715, 0.8007814110286775, 0.10198405297893672, 1.0922817885875702, 3.782122639879104, 69.99977127198251, 61.634916797761, 67.48710093959686, 40.58423857535086, 46.75866896106351, 41.39009737199353, 40.37951830894717, 47.213942389334406, 49.74786020094349, 66.26050518405053, 22.89836952763219, 0.08728146207548919, 0.01781837965902542, 0.032498560575467926, 0.05058277082899886, 0.021448935449664152, 0.048629767561872164, 0.031425169886901014, 0.020116105255100037, 0.05083382933310444, 0.13928414622862495, 0.021057207880902196, 0.05197293312859632, 0.05516233718803814, 0.07396407305232941, 1.1499789958038638, 62.28493590508739, 69.03974763808712, 65.0717838348881, 41.44728945147607, 36.3745234089513, 57.599437236785896, 41.56453694066694, 48.1231713294983, 77.85338401794434, 61.40193977663594, 80.44777301050003, 12.65178345864819, 1.1591521938962321, 1.2007461103700823, 0.11620546405714367, 0.9345276149049883, 0.07662442062170276, 0.6957821355712029, 27.023263439055416, 68.73832133508498, 64.93354774290516, 71.88815716774234, 64.17419256702547, 69.66055685474028, 61.90978865469656, 66.96046783078101, 62.61546619476811, 63.0577055869564, 51.500614458514804, 52.62921764004616, 47.47526637969479, 50.238485951577466, 51.88696007574759, 63.624637126922615, 58.41747499281361, 63.42727522696219, 52.23074797661074, 66.60656805961364, 49.68053271693569, 43.94275626828594, 64.26727825595488, 61.39796249328121, 63.17236823420372, 60.935797460617565, 60.26906513398694, 55.348514510739236, 60.92523059537334, 57.50959927035917, 58.07449510020595, 55.75584480839392, 55.5651823166878, 54.34002214862455, 54.87670436982186, 51.172519960711085, 51.13129192782987, 45.675020064077074, 46.71988064242948, 48.335104834648874, 47.96991255975539, 48.44291902357533, 48.08809749541744, 44.24030334718766, 43.78289222717286, 43.27286251129643, 43.4526914165866, 43.82120593901604, 41.05520148431101, 39.061868652220696, 40.46540644861037, 44.35284006980158, 43.141588626369355, 45.7098703230581, 46.755103526576875, 47.53549829606087, 47.48129898501981, 52.282695847172896, 55.078114155800115, 65.29808890435004, 54.004039764404304, 37.994175957095244, 35.76523811586442, 42.79529825333626, 57.28299610076412, 61.146279688804384, 49.01261191214285, 49.58615264584942, 46.38082311999413, 43.94897714737923, 46.068327888365715, 43.50592974693545, 42.512699327161236, 43.596560032136985, 41.39476107012841, 44.193003485279704, 41.37397643058531, 40.90857936489967, 43.38869402485509, 41.02963939789803, 40.693676625528646, 44.462442859526604, 48.615981840318256, 47.50696305305728, 44.35420897699172, 46.4393017368932, 46.98870420455933, 49.58989066462363, 47.551838890198745, 48.6052070894549, 53.27578898399107, 56.80594175092636, 53.58658975170505, 56.217919626543605, 58.08896080140145, 57.394309043884284, 57.913662233660304, 58.06109236132715, 56.4790710326164, 61.70782973689418, 60.79593358501312, 62.57634447466943, 63.434202132686494, 58.11628010965163, 49.08022180680306, 51.34331172512424, 63.325713296090406, 64.6423823602738, 64.11326639113888, 60.28632356274513, 51.34741060195431, 51.178015201322495, 53.07058234368601, 51.45795476052069, 54.0074679159349, 58.95565163704657, 55.43984297783145, 54.29757033624957, 51.153574912778794, 55.52737459059685, 56.20536019725185, 61.224468215819336, 58.98215901467108, 65.04411935806274, 68.70045477344145, 71.06772284353934, 73.19972715070172, 49.660944400295136, 0.49816705887356116, 0.08981246335972702, 1.9049862243475455, 4.85942195500097, 79.37891144906321, 67.17775929358699, 74.20376762267082, 46.16284132003785, 48.93434886009463, 52.517794870561175, 46.865992853718424, 48.11981770300096, 57.85687023593534, 75.40831181310838, 32.14372354169046, 0.17154960923137205, 0.14472004566942492, 0.08027064674083265, 0.0651250425125322, 0.04727791731936797, 0.02762004181051687, 0.09906896585298162, 0.11379976411380115, 0.12141062547602963, 0.22795598893877, 0.28695536176523856, 0.17930450278424448, 0.27185567684711953, 0.2939674871102456, 1.5385007930378762, 70.54074456614833, 80.91216594942155, 68.3267548776442, 61.324288614334606, 87.5152172580842, 68.53951992527132, 56.60856416148525, 50.71328101619598, 86.89507484436037, 65.9462684200656, 90.12207154304751, 13.111529369508068, 4.4022677502324505, 3.384764478091271, 0.26467136558025117, 1.797511320441, 0.26182510379341345, 1.1808064964509781, 29.38697784177719, 75.57677761200937, 69.14203520744078, 77.65764990160542, 68.15046787261963, 73.59622386194044, 65.75470770559004, 70.81340420630671, 65.23157727333808, 66.22876536461615, 52.83181198181645, 56.00799829729142, 50.52729791210544, 52.29831864756923, 55.42125878795501, 64.61957770009195, 62.11459129087387, 67.42549619367047, 55.90090974684685, 57.93485479970133, 55.49163003121653, 48.20990670111872, 65.54583757154404, 65.68009245780208, 64.04589183868902, 62.76652451484435, 61.67088885461131, 59.22225906002907, 64.4589723310163, 59.13171114460115, 60.81749877622051, 60.94937278378395, 61.68471520946872, 58.95000342399844, 57.87576429305538, 54.753875347875784, 54.70120183883175, 49.429340208730395, 50.83777312309512, 52.83750334093648, 54.27890769896969, 52.747959552272675, 53.8687179934594, 46.57019122954338, 46.86549863507671, 46.315762765945934, 47.612796445046705, 45.30159865656207, 45.43132320527108, 41.62357253413047, 44.450275667252086, 47.30446284817111, 45.21783644153226, 47.97787104883502, 48.76193715680031, 50.234190956238784, 49.12614491678054, 53.10296543182866, 57.10557160838958, 67.30790353590443, 57.00895970867526, 39.2297774745572, 35.789513664860884, 44.25847961056618, 59.089157350601695, 63.12895151876635, 51.20524037268854, 52.53122898840135, 51.93863730276785, 45.874943271760024, 47.8309469069204, 46.96443257793304, 45.2317020200914, 47.35934465162216, 44.30452431401899, 46.2832933856595, 44.88966741869527, 44.603499135663434, 46.215118669694476, 43.980975843244984, 42.73936917704921, 48.92824957447667, 51.79039524447534, 52.94125787673458, 47.96624906601445, 51.354153156280525, 53.644374109083614, 52.48576871810421, 52.73122672111758, 54.36504687032392, 56.93439152932937, 59.79587431876891, 59.57896724823983, 62.08269065426242, 62.66836327891197, 59.04501107431228, 60.389434829834975, 58.90001673852244, 60.04408190327307, 65.61699721121019, 64.92662475955102, 65.121017425291, 65.85118232234832, 60.4601316298208, 51.369791646157545, 51.23008074298982, 62.78371626330961, 67.94958760661464, 65.33167616013559, 63.71730312224358, 53.734196386029645, 55.08250721039311, 56.37337100121283, 55.09832612929806, 57.896901945913996, 60.6958229311051, 58.82757840618011, 58.02109987505021, 55.8202697384742, 59.87629859678207, 59.62896570082634, 64.98818635940552, 62.18753953133861, 67.09895103208481, 74.05119526770808, 78.0339385617164, 77.20995841487762, 60.80699466889905, 0.9260475731665089, 0.20146187995710682, 2.4838869994686497, 5.025263688256664, 87.08415662088703, 72.65136411113124, 82.153423524672, 56.267027701101, 64.30490163064772, 58.745436130031464, 55.92584033166209, 66.5781779443064, 69.046596096408, 85.15941819837018, 40.48501437710178, 0.34391632784278164, 0.2692116316287749, 0.20782810125139453, 0.1646917586725566, 0.14602922864498633, 0.14865661911185712], [0.08033769475596567, 0.11545175611371956, 0.04393693510322802, 0.1156456070020795, 0.029439682576565013, 0.009625949352348765, 0.2042546534850713, 0.08841057608444845, 3.9112588330622646, 59.84264073833343, 54.878136034934755, 40.43465898882958, 62.20244453799341, 113.14676100207915, 84.20962410588419, 40.96014676555511, 30.199577231560987, 74.18777219710812, 54.263402569678526, 75.65405614914434, 34.24386055238786, 0.3882861792320206, 1.2026463761445016, 0.1163269732628138, 0.12316653730287669, 0.12578916270285845, 0.710875538568343, 4.127995525636981, 56.568387323810214, 66.87607411415347, 65.0474141490075, 62.42809849400675, 58.13014568821077, 58.501099924887384, 58.03687957025344, 57.320376288506296, 51.902512273480816, 46.551395231677645, 46.73415806985671, 48.40264804901616, 51.61072323399206, 60.71202624228693, 56.3088244776572, 59.231217753502634, 54.55132022980721, 61.04709079188686, 58.195966982072406, 32.44306314376093, 58.33798031653128, 60.1189991735643, 62.03971324428436, 58.46681840958134, 57.42349932270666, 52.64116517959103, 55.923937982128514, 57.21533913766184, 56.09531417969735, 55.97901590408818, 52.371019778713105, 50.61693583765338, 52.26268391455374, 49.37861219529183, 45.07608198350476, 45.95198646668465, 46.932810429603826, 42.965070201504616, 45.12062049681141, 42.99548033745059, 45.49417918728244, 48.59375769092191, 46.6709961429719, 41.54424651976555, 43.71619624476279, 43.121972853137606, 42.81642413908436, 38.081229040699625, 41.6523588088251, 39.575122556378766, 41.67875636008478, 43.175815228492986, 43.100011502542806, 43.00270926567816, 48.137939053197066, 45.48115299594018, 52.24300146102906, 55.09643554687501, 58.81221055984498, 53.650273353822776, 33.70009453065934, 35.84897679667319, 43.53459835052491, 58.55988448665988, 60.00588978490522, 54.54160844126056, 48.602559489588586, 46.60115049731347, 44.83828436943793, 43.58396922388385, 43.68850038897607, 39.80229054727862, 39.62670564651489, 40.1282512757086, 37.954669844719675, 37.275644809969016, 40.19348421404439, 41.569573263968195, 43.442061793419626, 43.1379408221091, 43.95372321528774, 44.20609243454472, 45.82685501344743, 41.475942365584835, 45.02391053784279, 44.084981410734116, 44.19802804147044, 43.02280356807094, 45.312647973337484, 50.42267653249925, 52.89193014944754, 51.7085353789791, 51.570071789526175, 59.25244169850504, 56.61294152659755, 57.0834808195791, 56.47456030691824, 54.162821231349824, 58.79929419486754, 58.27972919710221, 60.29726697552589, 59.10654521757557, 57.84962561822707, 51.63037823092554, 47.080197411198775, 57.95047367772749, 59.60632185782156, 63.279343035913286, 58.90322131495322, 54.02653063497236, 47.417866414593114, 48.71746924615676, 47.96451930076846, 53.99099788358135, 56.4794828814845, 57.2417131547005, 59.55157733732655, 50.687973883844194, 52.37110214848673, 54.97913706687189, 55.01530131986065, 57.56389664065454, 61.23765130196849, 68.34983410373812, 72.50554607760522, 74.03857308049356, 8.477145068107113, 0.5293815871400218, 0.24432947889210718, 3.2273570664467353, 11.766390762021466, 72.468597350582, 60.0631053986088, 69.21941572620024, 37.93933337734592, 23.885418292014833, 49.084897272048465, 35.24415908321258, 40.785620904737904, 52.68089486706642, 60.17923108993038, 41.27427762554538, 0.27087768900298304, 0.0944188044917199, 0.09799737738625658, 0.04261260273896399, 0.026990265825823433, 0.08700991454984873, 0.03186905655198761, 0.06125585033348011, 0.10346932892477322, 0.05524041686928081, 0.005530304934514026, 0.049470487771736044, 0.13309551943694392, 0.15784239636794214, 5.452974621326693, 72.05168862496653, 62.34276340853784, 56.89758008526218, 53.333134035910334, 104.38984209491362, 85.71659872608801, 48.67063222392913, 39.360400246035674, 77.95382807331701, 62.43169530745476, 79.66279691265476, 40.82436215492987, 0.11226778744810051, 1.7079068576135945, 0.11217717456841662, 0.11946213446677693, 0.046159727724208954, 0.5542852669473618, 5.811536129443876, 67.62855729749127, 66.70928708968624, 68.41091325206142, 64.0692573978055, 60.35230567378383, 61.17076704579016, 62.830996513366706, 59.31632141913138, 53.76544198682232, 47.72729435274678, 48.67874760781565, 50.88123298460438, 54.25835447926676, 61.979975546559984, 60.81492962375764, 60.6657854203255, 56.536741641259965, 60.18498912934334, 60.46530915844826, 37.03752556154805, 59.288300006620354, 62.61116335468908, 64.09236015812044, 61.307085098758826, 60.70453451525781, 56.461310540476155, 58.004547472923036, 58.766381586751635, 58.755791187286384, 57.982672414472034, 57.10866243608537, 52.91815903878982, 56.97509004223732, 54.65155247719058, 51.706295705610714, 49.25166076229465, 50.07025549488683, 47.72371715114963, 48.93359576502154, 47.2072978942625, 49.66674950815017, 52.444093535023356, 49.52707782868416, 43.6403376056302, 43.90478772501792, 45.99363027080413, 44.99921137286771, 40.309194134127715, 42.85737760605351, 42.37459267339399, 45.33158125415925, 46.49544654353973, 44.954441439720895, 46.39539472518429, 50.54984761822609, 48.47238779067994, 53.20739853766657, 57.959459827792266, 59.29041024177306, 52.927204024407175, 35.13382281026533, 36.26932936329996, 42.597614719021706, 56.98118932785527, 61.291042604754054, 55.375790672917525, 49.946747902900945, 47.65796253758092, 48.3331318824522, 46.64427695735809, 46.61845207214356, 42.562921354847575, 42.070954153614665, 44.28955262707126, 41.199850651525686, 40.11785307238179, 42.04518418158255, 43.126613017051454, 44.676321860282656, 45.29833916694888, 46.935450184729795, 47.171314070301676, 46.80973822070707, 44.846489967838416, 48.579758751776914, 47.010081121998454, 49.33296757359659, 48.644077777862556, 51.79630625632502, 52.56530654045844, 54.50029411623555, 55.95355972166985, 57.855289520755896, 60.97101642239479, 58.35557999149446, 60.03207945054578, 58.53280052062004, 55.29466036827334, 61.601749235583895, 61.063737330898164, 61.02172482398249, 62.37665660919682, 57.1348128780242, 53.94951097426876, 49.379565331243704, 58.52883108200566, 60.43502061597763, 64.95610921613633, 62.43977146763956, 57.5326471174917, 51.133386473501886, 51.02869056886243, 51.567985088594504, 56.79811662243259, 59.05230276046261, 61.27541980435772, 63.6000987791246, 54.481545186811886, 56.14912909846152, 57.214319321417044, 59.823068111173576, 61.60572259656845, 63.85663747787476, 71.51263729218515, 73.25560523617652, 77.78442090557468, 10.707461622453506, 0.6846535746609012, 0.4484963999880899, 3.0003744075375223, 14.609819862150378, 77.9765542860954, 70.10439657395887, 73.82694552021643, 46.09964016945132, 25.797691422124064, 62.35462073356875, 37.959753236462994, 44.21655731816446, 69.00571715447211, 67.77927829373267, 52.90170077354678, 0.3376233139105382, 0.10908467680095665, 0.04886641595212202, 0.07084716772360188, 0.05762681139693145, 0.03797015205266015, 0.1811163313686848, 0.22123572777115533, 0.2471156027768889, 0.2761212544095132, 0.3181302679642555, 0.16027933737683683, 0.5806062094146206, 0.38509379892099294, 6.665944553190663, 84.64159473296135, 72.3233441383608, 57.00924604169784, 83.70672133661087, 123.53220093634822, 89.1840837847802, 57.89289720596806, 43.39976295348137, 87.90409672644832, 65.70387378815683, 90.73026641722649, 42.833964978494954, 1.5262562565265165, 4.903640795138575, 0.2860800297029557, 0.4166471525546043, 0.2835832878706917, 1.6800050773928243, 7.20555188194398, 73.55819256074967, 70.37647570333174, 72.53631314923688, 67.0679093945411, 63.799174754850334, 63.533359650642645, 65.89108067174112, 61.577057915349165, 55.34157191553424, 48.9467357050988, 53.23702812194825, 53.22954031728929, 59.180277932074766, 64.16977597821143, 62.7272851236405, 61.5530373204139, 61.62310261880199, 58.95768734716601, 60.20442447354717, 43.12599328256423, 60.5195398484507, 64.51049266322967, 68.13633165051861, 63.274561666673236, 62.683684056805035, 57.86425213659964, 61.12335735751737, 63.64304481014129, 61.2422404750701, 63.10891997429633, 59.8126934420678, 59.54918469152143, 60.786716015108176, 59.72777412783716, 55.453626186616965, 51.93172216415406, 54.732929891155614, 50.18887581363801, 50.87295678354079, 50.842715309512236, 54.73179632617582, 56.87998825503934, 53.066581526110255, 47.32756953085623, 48.33186495688654, 48.27975234677715, 47.99639640315887, 41.48591303056286, 47.155326489479314, 44.373118723592455, 48.281050651304184, 48.98732439164193, 49.17538635192379, 49.53081192508821, 52.850400094063055, 50.862382073556226, 56.17566001030707, 60.07235042510494, 61.241730566947695, 53.67057554183468, 34.40971013038389, 37.67108248126122, 44.60507985084288, 59.571965817482244, 63.45992895864672, 59.23994502713604, 54.62182875602476, 52.66845310887983, 51.670857091103834, 49.83363459187169, 49.6773006839137, 45.665269051828695, 45.967468061754786, 46.67468317093388, 45.16966973581622, 43.36395955854847, 43.16084746391543, 45.225092826351045, 45.360367528853885, 47.61219240004017, 49.405735385033395, 49.47417289979997, 52.026149303682395, 49.50505372016661, 51.84715194086875, 52.23432125583772, 52.30049948538504, 51.37289816333402, 56.07628283962127, 57.20974583779612, 58.055644189157796, 61.996571094759055, 63.016163764461396, 64.68324953509916, 60.36317063916115, 62.560211766150694, 62.89671582560386, 58.08412059660881, 63.81473087495374, 62.55715623978646, 64.13109356357207, 65.6423867133356, 61.23214821661673, 57.36654258543446, 51.89897429558539, 58.69263710514192, 62.9462004476978, 68.19467298446163, 64.1806213317379, 59.68943688177294, 54.91155070643271, 54.79036123521867, 55.41168428236439, 59.109075146336714, 59.683298372453265, 63.64923431027321, 65.39775240805842, 56.8443182206923, 59.28460121154786, 60.48331675990936, 62.498952188799464, 64.61946002898678, 66.64721165933918, 76.19295058711883, 78.15139785889657, 81.87725728557956, 17.387313919682658, 1.0302161641659275, 0.7650579343880377, 6.108154096911031, 16.4864827740577, 85.5615552779167, 73.99916110500213, 81.14531163246401, 53.31942927452826, 37.11814988044001, 63.836523563631125, 49.86314258267803, 60.23972580509802, 74.98247577298072, 78.68246324600713, 65.07433729787027, 0.6398309346648955, 0.2342750651821975, 0.2474743923953464, 0.15996700333010766, 0.16760477736111612, 0.1562572991655719], [0.07643210190919138, 0.09783154999416682, 0.08941943727193341, 0.030814779757131493, 0.032318231138971545, 0.09124189915676272, 0.07290864137992745, 0.19396325813666468, 6.311432892276395, 62.8937622808641, 58.61821797586257, 41.30888077520555, 54.405812063524806, 81.33993179567399, 84.13379684571298, 44.42346234475413, 22.446416385712165, 61.99598666160338, 67.95037992538946, 59.79806300132506, 67.5273052338631, 4.47165104650682, 0.7845549333480097, 0.43938378412877366, 0.08305716899133499, 0.23102090754095586, 0.08927237137310928, 1.3047424848041227, 45.15506675166469, 68.27726241080993, 63.379818470247336, 61.74030303955079, 53.47002475492416, 54.05208095427483, 47.32604765122937, 49.55983746436335, 48.35304183344687, 49.4755418069901, 46.04110663936984, 49.271060805166925, 54.29590725129651, 59.221054892386164, 54.99974912212741, 59.34726499742078, 54.480890150993105, 66.54396703166347, 41.44881133110293, 48.20840051097255, 61.77560437110163, 58.06765448662543, 58.80580925172376, 58.39820046578684, 58.863401412963874, 54.72712478330059, 55.72583083183535, 59.825354852984034, 54.184390344927394, 58.2468597350582, 55.413406202870036, 56.22796873892508, 50.97912749936504, 49.29699159437611, 45.29347150556503, 47.66062190455776, 45.304140352433734, 42.76229935307657, 46.72736844708843, 45.09471716419343, 37.443730138963275, 36.42909142278856, 39.77816797071888, 46.08327211872224, 41.269739443256015, 42.93505622494606, 40.529819611580145, 42.53345651011313, 41.53696267835556, 39.957945885196814, 44.62161264111919, 41.06843163890224, 45.05675254329559, 43.189814167637984, 47.41776443296864, 46.22068843533916, 54.3610538974885, 56.27742198205764, 62.24547686115388, 52.017786810475016, 33.700945684986735, 36.107370776514855, 40.785883703539454, 55.378552021518836, 60.95366385675246, 59.116845361648075, 51.039241744625954, 48.180124144400324, 43.76420213330177, 44.570064852314616, 42.88515190924368, 41.74940216925837, 43.14519328455771, 39.83681524953535, 41.247864384805005, 40.36606065688595, 39.22135222342707, 42.56234476643224, 39.85214387216876, 41.15089554940501, 45.289329482663064, 45.685661454354566, 45.20569670584894, 44.65544308385542, 46.667085539910104, 42.507404127428615, 46.99527809696813, 45.0296607325154, 46.60673987480902, 50.50656034100441, 50.9197114359948, 50.21713256835938, 51.496994110845755, 58.49820521570022, 55.06895934381793, 58.262058919475926, 54.948534734787486, 53.78950965019965, 56.739108485560266, 59.544540605237415, 59.10319551344841, 59.26083557067379, 57.983135254152366, 53.4671143562563, 47.512030755319905, 53.48445123241794, 56.94256967113864, 60.878621070615715, 59.62504333065402, 56.963154269802956, 47.49458797516362, 47.4170191826359, 48.140920054528024, 56.2224264298716, 59.54194791855351, 62.48946397535263, 61.21346596748599, 61.1231259376772, 58.5586214834644, 58.636715873595215, 59.307017557082645, 59.92719919450822, 70.11507326556791, 68.5805400725334, 84.17797842333394, 36.49529710892708, 0.934647247195244, 0.1388568223844613, 0.34589859566861586, 0.8279113423439765, 22.78586026160948, 74.84422791388728, 62.65281892591908, 68.14927547208725, 37.59452566023796, 28.052403157757176, 39.02608486913866, 55.92129038226221, 33.59084867661999, 43.23449388627083, 65.39780732124083, 40.83706278954783, 0.6573331632441091, 0.07337775532036059, 0.05678197729491419, 0.08273570317654841, 0.018970968517204447, 0.04213495074861473, 0.07851805973557696, 0.02170157784055318, 0.07556399405603448, 0.07876985751452946, 0.0712268102553583, 0.14890181321290233, 0.16484237155847012, 0.21865117694101027, 9.033719589633327, 73.57509797619235, 66.69407613815801, 46.63989959224578, 54.37785733130671, 86.47806413712041, 88.41198875058083, 51.80067185432681, 32.26333033653998, 71.77222759492936, 73.8476634794666, 66.23032646794474, 74.74245025265601, 5.402949202445246, 1.1389176667697969, 0.7739497024205424, 0.054966414031843026, 0.3428433144525174, 0.09562589092961243, 1.569396812588938, 52.67744318131478, 70.24355442293229, 65.75399383421868, 65.12272757868614, 55.31837109596499, 58.29242590935, 50.6334254818578, 52.30666937366609, 51.30658265083067, 53.06504787937288, 49.10733715180428, 51.8266575567184, 56.77270358608615, 62.56360461634975, 58.612130457355136, 61.464689854652654, 55.451398280359086, 66.49893037734493, 44.63991834271339, 48.21051074612526, 62.70249182178129, 61.22576652034637, 61.74495889294533, 61.60087454703547, 60.12112902056787, 56.87188463826334, 58.02450056998961, 63.25512632246941, 58.08466188369259, 59.56649803346204, 59.18791870917044, 59.57457419364684, 56.3938771524737, 54.109688804995635, 50.02954913723854, 50.00503824603174, 47.92153404605004, 48.01628281993251, 50.62037183392433, 49.22979354858399, 43.047436052753085, 40.06071590608166, 43.856083654588275, 49.14082242596535, 44.75956632244972, 44.21924021936233, 42.252069596321356, 42.80343324907365, 43.41911592791158, 41.052946121461936, 45.859736242601954, 44.23288614519181, 47.5888817541061, 45.603044571415076, 49.48090368701566, 50.00659150461997, 56.28772604850031, 59.85772225164599, 64.2964332334457, 53.29170988452051, 33.68482474357852, 35.591998792463734, 40.39358785075527, 56.58211954178349, 63.95308071567167, 62.456767097596206, 53.46642794147615, 49.807994058055264, 47.23598218733265, 47.15405171917331, 46.606877157765055, 43.63807439804078, 46.23056496343305, 42.78788889608076, 42.005721215278875, 42.00162626081898, 42.98545083691997, 43.85040406257876, 43.26899505430653, 43.56462801656416, 48.071282294488725, 49.67971294156967, 49.263196452971435, 48.08095093696348, 49.237634366558446, 46.08995975986604, 48.3633812012211, 49.366135135773696, 49.37717268543859, 54.881042511232444, 55.725454284298806, 52.659906264274355, 56.86775438247189, 61.13703466230824, 56.582343116883315, 62.008855958138746, 55.58990109351374, 55.59902452653455, 57.933364299035844, 59.68752668749902, 59.55118902267949, 60.58711836414953, 59.983347923524924, 56.820332927088586, 50.058366790894546, 54.733851648146114, 59.32273449436311, 62.573132053498306, 63.58188721441454, 58.762298399402255, 48.843012548262074, 51.07155815247567, 52.13455184813469, 56.695982025515654, 63.21921702354186, 65.24522319916757, 66.42815512995567, 62.29783658058413, 62.43614719760034, 61.89902174857355, 61.84461062954318, 59.62390584330405, 74.9704654755131, 71.42041452469365, 87.75663914219027, 42.37546736194242, 1.2999189500847173, 0.10660638236590933, 1.1057744968322016, 1.214694181276906, 26.467508692895215, 82.28913753263413, 67.72093695978965, 75.79971728786346, 42.95060057793894, 37.97541133819088, 51.21297528666835, 54.71763264748358, 31.92595158853839, 55.545550853975364, 72.23513003318541, 53.57652494984289, 0.672603318047139, 0.04705177965543924, 0.07883842238375256, 0.044877894087544376, 0.023562801859131264, 0.11156854835609276, 0.20930524134347517, 0.2740896505213553, 0.16229770326566312, 0.1279744821330232, 0.3878541669297603, 0.2754417957077103, 0.3394609749797852, 0.3969461903456719, 10.914557864589076, 87.40324927914529, 73.59451370854532, 58.49162740092124, 66.47394487934729, 85.55831540015437, 91.66164890412362, 59.60464308338781, 36.797782451875754, 74.52374673658802, 81.33957093761813, 73.5781103564847, 81.44883248113817, 5.815113331041029, 2.0883093485909123, 0.8117955490466088, 0.2707096399559129, 0.6998083259790175, 0.33982296684576624, 2.861294515671269, 59.58317202906455, 75.24907927359305, 69.59845789017217, 69.01536618509601, 57.66887103357623, 62.46884407535676, 53.066530535298014, 55.42011737823487, 52.83020773241597, 55.89427701888546, 52.18547598008187, 53.58811163133191, 59.30916701593707, 64.03120648476386, 58.31212797472554, 65.53347818313107, 57.31810523617653, 64.57290149504139, 49.00296680388912, 53.71873440281038, 63.90605541967577, 65.111411540739, 62.70191915573613, 63.905482753630615, 62.789654731750495, 60.23132801055909, 61.52533361988684, 66.70876149208316, 59.12222293115432, 63.68550054488644, 58.76012540632679, 65.14902707069152, 59.69022527817757, 56.86155703759963, 53.23034048080445, 54.8151231581165, 50.968140940512384, 51.145867455390196, 52.5727355095648, 52.54903654898367, 48.940883528801706, 48.541248921425115, 51.02114392865089, 54.31688016460788, 47.78798518642303, 47.27847322340935, 44.97734023678688, 46.442482779102946, 46.98634686008577, 44.04386320421773, 50.33359950588596, 46.23155340071648, 49.679469754618985, 47.61263562786964, 52.172343884744954, 52.19337171123874, 59.595084267277876, 59.700023358868016, 67.58946695635396, 53.89433107068462, 33.21870203941099, 36.025185354294315, 41.864182487610854, 59.18802853553527, 66.5288737512404, 65.75459003448486, 57.04463366539248, 54.60496256428381, 50.49880581517374, 51.216807442326704, 48.78505952896611, 45.507683907785726, 49.77254367643788, 45.539384503518384, 44.02838553151777, 45.42614175427345, 46.26428557980446, 47.55337645930629, 44.72920717731599, 48.58736422754104, 53.5042082109759, 54.41896377071258, 54.501588498392415, 52.964839166210545, 53.06773862531109, 49.65773197912401, 53.04025457751367, 56.16462638301235, 52.704672275050996, 57.03650259202527, 60.03215005320888, 57.80803672729, 61.84247686016945, 63.98078049382856, 59.39695358276368, 63.780720003189586, 58.00277063923498, 58.10177910712458, 61.72452334434756, 62.4160058267655, 65.12297468800699, 63.5221299048393, 62.276169407752256, 58.624929151227406, 54.942706092711425, 55.80330940984911, 59.08736874980312, 66.6923895189839, 65.52886547580843, 62.92795750402636, 51.270967529666045, 53.425301890219416, 53.865376134072584, 61.07876785339848, 66.7999565985895, 68.34707275513681, 68.83516465463947, 68.86424510709702, 65.39949001804476, 64.75668022709509, 65.26048906387823, 63.68642230187694, 77.22092536187942, 76.13134584119244, 91.52933951347106, 52.317906964209776, 1.7794412062052758, 0.20240603735850704, 0.8638762286113155, 2.787012424199812, 28.32784179718264, 87.65994487270233, 74.22949052626088, 83.32472955026935, 53.35180844030073, 42.362052855953095, 54.57761972181259, 75.72232107962333, 46.8998585977862, 64.22386546288767, 82.59917736053467, 69.26527607825496, 1.8493178631028824, 0.2645003134685178, 0.20287025599710404, 0.1961437588737857, 0.10666885683613439, 0.26260488936978005], [0.021585101832545573, 0.09729878180810521, 0.08090541187313297, 0.06875705003978745, 0.02241209757724597, 0.04155184292504865, 0.1196259776911428, 0.3180065907297596, 6.307324209520894, 68.3605892427506, 56.28278386208319, 52.60831532939788, 52.70892804668796, 98.57977636398809, 66.65548786040276, 44.15400728102654, 22.052555507229222, 33.690163089383034, 71.78251989426153, 54.37051073197396, 72.11160675171884, 22.186443651876143, 0.35082340721161137, 0.8765870981639432, 0.0556162940788894, 0.16476502732163475, 0.1809799217528874, 0.5575280252002901, 39.553353401922415, 68.96126101093908, 63.406565112452355, 60.08039912869854, 52.94674919497583, 49.053455552747174, 49.69413941906345, 48.041440902217744, 47.23577037934334, 48.42493495633526, 44.96279216581776, 54.81518983840943, 57.225870701574514, 59.74374209680865, 57.47215632469424, 56.8252476569145, 62.07163741511684, 53.550135243323545, 39.54241391151182, 52.83600891790083, 56.43906285685878, 62.579909909156065, 59.38780269315166, 59.441798040943766, 54.02417721286897, 55.79044795805409, 54.50040786497055, 58.74255318795481, 56.21651934039209, 59.38873621725268, 53.78245722862982, 54.02164336173765, 52.80124102869342, 53.37764509262578, 47.44718613163118, 46.40530655460973, 46.65458102380076, 43.6687590998988, 43.97777518918438, 47.20325000824467, 37.35293903658467, 31.375244932789958, 33.32132693259947, 49.426112098078576, 43.195984055919034, 43.823943753396314, 43.95168358279813, 44.0729554237858, 41.75550929961666, 45.76510906219483, 43.049805164337165, 42.187374022699174, 41.515177834418516, 44.05943893617199, 49.11702148375973, 49.70062701932846, 52.105683203666445, 57.81388498121693, 58.06137477197955, 48.65095369277462, 33.19430097456902, 36.980643349309126, 41.95824092434299, 54.606327549103774, 62.34026878110824, 59.6776266251841, 52.00187375468593, 48.42946137151411, 45.87560222994897, 45.703367033312404, 40.86929682762393, 40.898895032944225, 42.14807187357257, 43.4850666599889, 40.664474579595755, 39.18373277110439, 43.68337385116085, 42.2075742290866, 43.00636883704893, 42.16839367343534, 46.02062794470018, 41.58352513467112, 42.15959187476866, 47.293029139118815, 45.18159766351023, 42.24523290511101, 44.57499134925104, 44.1341051747722, 45.99336354963241, 52.451636252864716, 48.15042787982572, 49.10259108389578, 54.33613507978378, 58.98242965821297, 54.50291818188083, 58.5035631733556, 52.58889959704492, 54.84652957608623, 53.93873230103524, 61.82275126057287, 59.688291549682624, 59.78480539014263, 58.84095368846771, 57.27119368891562, 48.14109263881561, 50.75703113309799, 58.83878854013259, 59.111283440743726, 61.11892115685248, 55.205548040328495, 47.03973816287133, 44.618078585593935, 51.47481310752131, 53.934331401701904, 60.52451341382919, 61.7379496174474, 66.69620990753174, 61.22661767467376, 61.7901171407392, 63.161518958307084, 64.41768154021233, 62.67587069542178, 69.7346112035936, 68.84402136648856, 67.08530118388515, 4.202549976687278, 0.9475889850047328, 0.12683789110592297, 0.19396157274323125, 0.5335390543745411, 31.259417341601466, 70.99300169175672, 67.84338551182901, 68.45041936443698, 41.48372434800671, 19.22517772643797, 46.871860719496205, 50.73700743336832, 29.52564931684925, 45.14724162317092, 56.68986312804684, 51.8456575178331, 1.1404372174893658, 0.20251126719578622, 0.1278452814045933, 0.06892948877066374, 0.04292768321090168, 0.04436211007076406, 0.012011302000422393, 0.09958018398573322, 0.11132153862666701, 0.033232737107262496, 0.03703262514224456, 0.23882227198731518, 0.15008426992402923, 0.33929378395119025, 8.832292152989297, 77.69271589094593, 59.987748822858265, 60.8997626458445, 68.59122460888278, 102.52117003163984, 72.12237758021202, 49.17729654619771, 24.391886495774795, 42.60149002075196, 78.06693353960591, 60.479841539936686, 80.24050712585449, 26.522541507597893, 0.49235153222276323, 2.3416037569122934, 0.08726703663987499, 0.336366071696243, 0.19880424433898544, 0.7880577324859558, 44.6577415927764, 73.12057372062438, 64.77158915612006, 63.4218466666437, 54.24484975876347, 52.1345793047259, 50.77008870340163, 50.24377722893992, 48.6595005373801, 51.541744432141705, 46.545460685606926, 59.025599264329486, 59.94315147399903, 61.998179266529704, 60.831697756244296, 61.07541814927132, 60.916330737452355, 56.52890474565568, 43.12151785819761, 53.044922198018725, 59.42729311604654, 63.57241076807823, 61.43662137369956, 62.28093508751162, 56.0060175003544, 59.08622734008297, 57.947622114612216, 61.08367866085422, 59.10160695352862, 61.823014059374415, 54.51853313753682, 57.374359869187884, 55.28057121461438, 55.558898679671756, 52.14603654799923, 49.18378414646272, 50.371983820392245, 46.74696460846932, 46.055717468261726, 49.429732445747625, 41.609436312029445, 36.432515651949, 37.97182629185338, 51.134920120239265, 47.5913881486462, 45.86033244286814, 46.559400789199344, 47.213773727417, 43.296851727270315, 46.761983363859116, 43.721699330114554, 43.935492038726814, 43.477167006461855, 45.84771417802381, 51.08946377231229, 52.289705122670824, 53.30182959956508, 61.19983965350736, 61.20711172780683, 49.300443280127745, 32.90554000485328, 37.04973589989447, 39.9478457820031, 57.53089381802467, 63.32465425614388, 62.205641269683845, 53.99595968184933, 49.16085004806519, 47.62548139018398, 46.44289070560087, 43.94172468493062, 42.60730297334733, 44.52657361184397, 46.583150740592714, 41.48836058955039, 41.51229881471203, 45.68883465182397, 43.50776933854626, 46.96316172999721, 46.918638906171246, 49.81729007536366, 47.35075466094479, 47.15623255698912, 50.40940715420631, 48.240379594987445, 45.18623390505391, 48.85165745212186, 48.987061592840384, 50.69029200461603, 53.826952595864576, 52.932334484592566, 53.88604702488069, 58.00878755507931, 61.81681671450215, 58.11098883228918, 59.51738995890464, 57.38924134162165, 57.8849151826674, 56.880808030405355, 62.73541227463753, 60.56323112980012, 60.5402538853307, 62.07601870259931, 58.82695474932271, 50.538484511836884, 53.171963845529866, 59.20373762807539, 62.28818362759006, 64.30306596140709, 58.3608163556745, 49.948689476136245, 48.29165281787996, 51.66627968511274, 55.857983327681026, 62.956386843035304, 65.95833363071566, 68.91176069936445, 64.76650576437673, 66.08611660618936, 66.42989666231217, 67.86017325616652, 65.29057364309988, 71.89265220395981, 71.62045540348177, 76.68307427437075, 6.775857210159303, 1.1522779950211126, 0.2083890308295527, 1.1298393410059715, 0.41209655964086134, 35.96756965883317, 78.82400589604532, 72.34365417111304, 75.563567069269, 47.49866724014283, 32.699713630061, 48.05645965760755, 58.2170928678205, 30.044125856891757, 54.1220913394805, 63.58307177020658, 65.85651674578267, 2.2192302202024767, 0.1179475709795952, 0.2118418963565942, 0.024867955212210937, 0.016144730353487596, 0.07015734385218352, 0.14289658787029405, 0.21967971126639077, 0.20854174279637877, 0.12021839348298889, 0.19549020926558203, 0.3546788212993453, 0.3032146280090655, 0.8629577811206541, 12.202567150515895, 90.79667998898415, 73.96378132604784, 67.67954026499103, 69.08985983940863, 100.86025807165332, 77.98266533882388, 58.037938610199966, 36.44147826779273, 49.79768606924242, 83.24375614043205, 66.48840273580244, 86.15702598325669, 29.159943211463194, 1.4870663852460924, 3.0208781073170328, 0.12462484695377851, 0.37235302129580133, 0.4933009909525995, 1.8296286680044669, 46.01872559516661, 78.70508747716104, 66.45397217042985, 67.52051168872465, 57.889539657100556, 56.05473726026474, 53.453950881958015, 55.02068673410724, 48.70973433217695, 54.347180474189024, 48.74095247637842, 62.9765203691298, 63.986067848820845, 65.34764805147725, 61.524713885399606, 63.32632518583729, 59.55990845157255, 56.19256150337958, 47.57711856595932, 54.502549479084635, 59.24523238212832, 65.6463679190605, 63.70761486791796, 64.12100914985903, 57.830119671360144, 61.88908246255691, 61.24879475562804, 64.17390623400289, 61.286120030187796, 65.33539456705894, 58.787330965841974, 61.63913726806641, 58.51551071290047, 63.865906038591945, 53.10596996738065, 53.53787783653506, 53.89054206109817, 51.17464588534448, 50.42353160919682, 54.660134623127604, 45.71160793304444, 41.83898910399407, 42.410776538233605, 58.17849282295474, 52.34867011347125, 50.9916163259937, 51.24302848692864, 51.82532002848964, 46.120652306464414, 51.58304306768602, 46.38307063810287, 46.79077356092392, 45.93430442194785, 49.671766219600556, 53.84209686709989, 55.118016427563084, 55.13904425405688, 64.17160380271174, 62.51717944299022, 50.83149340844924, 32.51837853462466, 38.76047372817993, 40.24985259579074, 58.013894481043664, 65.86951548053374, 64.88885625716179, 58.30191412279683, 54.94565963745118, 49.3183018315223, 49.17952837482576, 45.675427990574995, 46.20302208008305, 48.699473411806174, 49.31960013604934, 43.901920472421956, 45.86874984925794, 48.33570103491507, 47.289000864951845, 50.587580819283765, 50.83078345944805, 52.68804927026072, 49.077021152742454, 50.75936494335052, 56.55238013113699, 54.17963643227854, 48.87875710764239, 53.252227306365974, 54.78625843601843, 54.142224865574995, 61.26007941461379, 59.43707942962647, 57.47219162602579, 60.987964983909364, 65.13849158440867, 60.26777075183008, 60.461320107983006, 59.62349007206579, 60.87574205090923, 57.87018276030018, 66.13892739818942, 63.516367943056174, 61.9681142991589, 65.20528562607305, 59.6079888651448, 55.082071827303984, 55.99353259609592, 60.50573310544414, 64.37236639761156, 67.79372830544749, 60.938009677394746, 54.01753664016724, 52.655826999295144, 55.48304004053916, 58.9921453691298, 67.01385128882625, 67.59386001094695, 74.45061022235502, 67.72310210812476, 69.82780671888783, 70.14595016356438, 71.49588877154936, 70.48312494831701, 76.7386934834142, 77.9463363462879, 82.78842387660858, 12.918220258528187, 1.9897073363104176, 0.5676970763071891, 0.9788499075558879, 1.338219056206365, 39.491505469045336, 86.02865465225713, 78.55370752273068, 83.44920989005797, 56.49838870571506, 33.13395138709776, 66.06732845306396, 67.2542376672068, 43.53504157835438, 66.22482730496314, 74.13671078220491, 80.60016493643485, 3.8296093046665196, 0.6066685818856763, 0.3068155170448365, 0.15351042962603031, 0.2342157546550997, 0.14859703279310657], [0.025748603924688314, 0.1327399320660099, 0.08002284794084488, 0.04126786562283674, 0.05705246378877952, 0.08833675585206478, 0.003473714370498314, 0.05521402130984972, 3.6815015875524093, 60.673312448686175, 58.84065558833461, 45.8891853978557, 19.23441686937886, 30.726969319005168, 41.229142911972545, 40.99396936355099, 24.255639045469223, 19.815568962404807, 61.2175020863933, 60.81045419939103, 63.128394542201875, 52.19158311044016, 0.6713037877794236, 1.7040043444402757, 0.08291690595327847, 0.18096110663346707, 0.18208207712779123, 0.490768518779547, 23.689319395249893, 69.12912276483351, 68.05760183641988, 62.486365302916504, 61.886658437790416, 57.208667185998735, 59.81083816097629, 54.977328854222456, 52.47564508068947, 46.53195204273347, 49.491243054789884, 51.409333059864665, 59.40827354308098, 58.03212173523442, 60.82582989046651, 54.29216531015212, 59.32779827425557, 43.92701187441426, 47.427668417653734, 60.59121331860943, 60.00958857997772, 61.1548775242221, 57.74422760932677, 55.87186851809102, 55.34570609369586, 59.09769242809665, 57.076663740219615, 58.25828952174033, 55.11076788748465, 57.12078255991782, 55.588783218014626, 52.10162747290827, 51.465952473302046, 50.05888062138712, 48.4270255796371, 44.92305463360202, 46.04275403484222, 45.303587298239435, 45.78278326219129, 46.07236792964321, 45.37395069676061, 43.206484240870324, 32.90598715505293, 40.35773346501012, 44.72602221273607, 44.852232317770685, 43.18886103168611, 41.16474543848346, 43.59671692694388, 42.81837747943017, 43.046122058745354, 44.930715022548554, 43.47895560726043, 45.6334743192119, 47.18102193647816, 51.980186970003196, 54.767780150136645, 57.7504288765692, 57.92610006947672, 47.340026978523504, 33.870760779226984, 37.86397287922521, 41.385857289837254, 52.58969191581973, 60.98895342119279, 56.551811387462, 55.9037220862604, 49.72978984155963, 49.4637119385504, 47.12408481105682, 44.84824718967561, 42.95571534864364, 42.569663909173784, 38.567775526354396, 43.51406474267283, 44.05595979382915, 40.87544710405412, 39.38539751114384, 47.14777200452743, 38.289322545451505, 33.76716706060594, 43.73009320228331, 46.64985064537295, 45.772004588957756, 41.25374401769331, 45.896386869492076, 43.439331823779696, 44.65151679131293, 47.43568966465612, 50.70005478397493, 48.48410391038465, 50.04870599316013, 54.04082767425045, 58.14925155332012, 53.43326037929904, 57.49820086263842, 55.54350337674541, 54.028444751616455, 53.347831156946, 57.74893837590372, 59.53080446489396, 60.69584646532613, 61.44217152749339, 57.23182485949609, 49.779607865118216, 51.647589591241655, 59.55129492667414, 57.914980150038204, 57.71058936272898, 52.61855271554763, 48.43244237284507, 46.413688659667976, 46.13371379913823, 52.08164299688032, 62.42112451984037, 60.782550457985174, 67.01439257591002, 63.488373987136356, 65.53821640629923, 63.84860054139168, 65.99429392045545, 64.57607861488097, 75.4996402802006, 72.02509495519823, 32.577302340538274, 3.8733719241234565, 0.0582111832655726, 0.16104082877357162, 2.131085982245784, 1.043627850951687, 46.58644553153746, 69.82197807681176, 67.03163531518751, 64.52949654671454, 18.771704666076168, 27.570798858519527, 52.07611245493735, 48.77185290859592, 29.109360325721006, 48.10697194068663, 60.27516834197506, 53.42882810100433, 2.427337453249962, 0.18102012604715365, 0.11599208558759383, 0.0857992121769536, 0.08940744033503918, 0.08293448001026146, 0.06050000117430764, 0.08414557308799799, 0.030776799033065478, 0.07913542701111687, 0.021363937994465235, 0.17682927270089427, 0.13248669404175975, 0.10776861435583523, 4.982183316061574, 70.94867890880954, 68.77397567995133, 42.97703735290035, 30.632167593125377, 52.08742064814414, 47.8028235127849, 54.150712874627885, 28.404220150363063, 23.897134411719538, 67.65396641146752, 69.21241037307247, 68.22224724677302, 57.671255834641, 1.2033044763149754, 1.941285921681312, 0.05369663095822739, 0.19035804836500078, 0.025938741201835296, 0.6577895064988445, 27.737515280323645, 76.20159549097862, 67.49949562934138, 65.82660475084859, 63.08655461957378, 61.18493464685256, 61.02837716379474, 57.714484276310095, 55.61744005449357, 50.64107802606399, 50.37217209416051, 55.078722123176824, 61.3721493751772, 60.948992313877234, 62.484827733808956, 56.484232871763176, 60.31068148151521, 49.36464855747838, 50.89284320031443, 63.315938749621, 61.974856853485115, 62.3191781966917, 58.48071144473169, 58.14505069486557, 55.52679015744118, 59.76093776764409, 59.09035367350425, 62.07286511698077, 57.55974285064205, 60.70296948955905, 58.4150666575278, 54.70556743683354, 54.5955841772018, 53.26839531621626, 54.199169835736676, 48.916780564092825, 48.99742057246547, 49.359004266800426, 48.13534244414299, 50.47928025645595, 50.12165423362486, 45.961674721010276, 38.182743903129335, 45.621942550905295, 47.9517323740067, 48.001554319935465, 47.91549359598468, 43.67396016274729, 44.895574508174775, 45.86772611064296, 46.36041502798758, 45.885996510905606, 45.95821126814812, 47.9516343147524, 49.09149077630813, 54.40571792664067, 57.13841361384238, 58.94825012453141, 63.93418273618145, 47.852084559779016, 33.44795280887235, 38.94624502428117, 40.472682445280014, 53.81865678295013, 64.14253119499453, 58.93539259510656, 57.156982114238126, 51.1428629198382, 51.42963524787657, 49.73679519468739, 46.39036232425321, 44.87955554839104, 45.277134833797334, 41.08852201892484, 45.03503830202165, 47.22179889678956, 43.9279414761451, 41.52973375012798, 47.69249508457799, 42.39872309469408, 40.578492303048414, 46.7602300643921, 49.77208083675754, 48.414364168720866, 46.62940332966466, 49.956228271607436, 48.39979256353071, 49.28134525975874, 52.44163028655514, 53.742676550342196, 52.25198761109383, 55.297629602493785, 56.28528633425313, 60.11815194160708, 57.85333225803991, 60.62580077878891, 56.8414705799472, 55.24585431621921, 55.406185119382805, 58.950434884717396, 62.50628702102169, 61.99519434282857, 62.59432461953933, 59.85601209825086, 52.666091842036096, 56.566171184662856, 59.66319622532014, 60.951471251826135, 61.382445596879535, 57.28725971714143, 51.32866559490081, 49.234108155773534, 49.621544191914225, 53.985573245633034, 66.53747158665811, 63.84790235950101, 67.73734815659063, 66.46730038427538, 68.18412965343845, 66.03427856199204, 70.00515276385893, 66.72230151391798, 78.80408025556996, 77.20918963032385, 38.35848569869995, 5.729090359903151, 0.021839362584174644, 0.22407858812760925, 3.1983430491339777, 0.39615972448260556, 55.74535639055314, 72.1568944377284, 73.94743288716963, 63.40364686904415, 26.17305244168928, 22.481674571191114, 52.824704647064216, 55.38378838569888, 32.021137706695065, 61.636599494564926, 64.97379910561347, 68.99266350653865, 3.674634743121363, 0.2792771689353451, 0.14926817178005172, 0.06234644544160655, 0.10350226304463803, 0.1879864546560472, 0.16251528755791728, 0.3361577264243557, 0.14091335477367525, 0.22428792931379812, 0.14015209320331776, 0.4119634135596214, 0.33788577563339667, 0.2898497338737211, 6.760465829603135, 85.06857610517933, 75.94015382951306, 62.07530483122795, 32.893092363111435, 44.39728444622409, 59.305126974659586, 54.19441592308783, 36.91616350604642, 36.55280297802341, 75.56032719150667, 73.8633764943769, 75.26814983737084, 63.08482485432779, 1.8366602519827506, 5.428455395083274, 0.46659620779175914, 0.5368421803559027, 0.3451714556544058, 0.6792245853331782, 30.229257806654903, 80.64075362297797, 71.04554576258506, 69.95416979635917, 65.17113747135286, 65.90505999903526, 64.27674293518066, 61.94764737159976, 57.0168044490199, 53.50550651550294, 54.628308511549434, 59.26631904417469, 64.70956471658522, 64.71072181578606, 63.97310049303117, 58.631369683050345, 57.75323729361258, 50.84734370631557, 52.03954419782085, 63.65978940840691, 63.30803517372378, 64.94865279043874, 61.71674920666603, 58.190601179676676, 58.86773955437445, 66.4463000143728, 61.55619482840262, 64.51977691342755, 61.168362632874526, 64.011747606339, 61.596206926530414, 59.33192068530668, 60.113437252659956, 57.58900373212753, 57.34112954908802, 51.55942255450834, 53.01813633211198, 53.15269716324345, 50.91751098632813, 55.92018427387361, 52.870651291262725, 50.80125977916103, 44.51117046417729, 51.70482089442592, 53.46961682842624, 52.78055444840462, 51.181004047393806, 48.04899146479946, 49.83574090465423, 48.854171691402314, 48.17396994559996, 49.25428482793993, 49.79499924567438, 51.17213949080437, 52.29249785023352, 57.95296830515708, 60.03939074854697, 61.13279065778179, 64.77569980006065, 51.07062462837466, 33.7200358606154, 41.76521324342297, 42.44927460147489, 54.9743753094827, 66.69341717996906, 61.8379504449906, 62.04942111046084, 55.861340876548525, 56.1948404004497, 52.54798927614766, 50.496283731152936, 47.65797038232127, 47.68468956793509, 43.02188573345062, 47.139531104795395, 51.443955821375695, 45.97514806255218, 45.7486076508799, 53.717545924648164, 48.30757371840939, 45.783767777104536, 52.37019215860675, 56.06204463589577, 53.39905338902628, 49.3521361966287, 52.77682035200058, 51.01162041387251, 51.83848350278793, 54.79544070459182, 59.47303579699609, 57.03892661679176, 61.57159405369913, 60.13903071803432, 62.60708801208004, 60.053734856267134, 64.60024041514244, 59.59397031414894, 58.30099628817651, 57.947606425131525, 61.387054381832, 64.61316462486022, 64.50364812727898, 67.84622530783376, 60.797647660778416, 57.022644858206476, 57.53781680137881, 62.5886332604193, 63.30703496932984, 64.12409997755482, 59.78233821930424, 52.26382924664406, 52.80771293947774, 52.263315416151485, 58.876733549179576, 68.48124919399139, 65.56339410043532, 72.40406651650706, 70.46035951183688, 71.18682169145154, 70.08755391643894, 72.66670842324534, 71.53621073692076, 78.31285830466979, 79.96597259275376, 46.36749882851878, 7.669862941388161, 0.974304432109479, 0.20538901519631186, 5.371784010241109, 2.3202726821745596, 55.2475134788021, 80.89132247432586, 78.63348068729525, 75.42812762721893, 34.489346011992424, 41.55313853294619, 72.79783325810587, 66.18379146822038, 38.081480072390654, 70.8439673146894, 75.03662017083938, 82.78409357993834, 6.652547697867117, 0.6713998245616114, 0.3039120438118135, 0.19554107750375427, 0.21423221325441716, 0.46432754565631196], [0.02864677008361586, 0.011196687194188277, 0.07291980328098421, 0.04479117676495545, 0.04443230287682626, 0.01026609625231715, 0.023181845486584692, 0.04269435581180357, 1.1718573637547032, 56.961067568871286, 57.42367190699424, 74.45390501329976, 30.059640792108354, 14.687231759871207, 35.089915798556426, 41.232210205447295, 11.260867849473032, 19.782956415607085, 51.23117900663807, 66.81428893919914, 57.31154703324842, 65.25657061607608, 8.250952766787622, 3.258662238236397, 0.04739180395019151, 0.35822507294435657, 0.1546581212671534, 0.5783223480947557, 6.807142524949967, 67.93794601194321, 67.37575269514515, 61.92797668518559, 60.935617031589636, 60.592907782523866, 64.00379303962954, 61.81003885884439, 58.68904421406408, 48.286161499638716, 48.30377294171242, 51.73058694408786, 56.78905594733454, 56.383059255538456, 63.072159521041385, 60.63666574416622, 54.57540358266523, 43.270058016623224, 59.40375889501264, 59.45539297596101, 60.396499018515314, 57.40648408089915, 57.611027840645086, 55.05041437764322, 57.62283417486376, 57.67772774542532, 55.87399052035425, 56.20409719405636, 59.52893349432177, 56.338383459275775, 55.09908706911149, 54.63465490648824, 52.36255922625142, 56.80769897276356, 51.14441617842644, 46.03866692512266, 47.302619334190126, 45.788725653002345, 46.50730386857064, 43.774255168053415, 46.226175831210234, 38.52578263128958, 32.10622568284312, 36.4441180229187, 44.78036665147351, 45.12944582969912, 45.19409433487923, 45.14073441105504, 44.74086838383829, 45.51647001697172, 44.38545457778439, 44.38596840827696, 41.544862331882605, 47.93138311755273, 52.83824466889905, 51.61689704464328, 52.26557470137074, 56.333323601753484, 59.3154820319145, 49.17271914020662, 35.59896492188977, 42.30395863133092, 41.666753907357496, 54.05926673643051, 58.85419168779927, 58.15031843800699, 56.78790277050388, 53.474951251860595, 48.99434543425038, 48.41685095141011, 43.02530604024088, 42.05810446893015, 39.926692439663796, 42.560034490400746, 39.62693314398489, 28.398369935251054, 37.54035380578811, 40.60939273526592, 44.54343980358493, 39.80475379574684, 38.61132952474779, 43.41140062578263, 48.035443598224276, 43.53565739047143, 45.17084644686791, 50.485477601328206, 46.10552764707997, 43.77103490214194, 49.53846839166457, 54.363097452348285, 49.98411240116243, 48.35368902452531, 53.82637992981942, 56.994446939037694, 55.82363905445222, 58.123873818305235, 52.74018149222098, 54.1858063205596, 54.41852054288311, 56.18938046116983, 56.31015808351579, 61.53501010710194, 58.83186163440828, 59.25623463046167, 49.271739375206735, 59.46443011683803, 57.97187412938764, 59.35300342498287, 59.54442685650241, 55.98911992965206, 46.25947283160302, 45.408381262133204, 46.617753890252885, 49.533349698589696, 57.31229620595133, 62.93634353145477, 64.20563428632676, 65.95158715401926, 66.12290843840569, 71.61490132731777, 76.57025121873426, 72.61880059396067, 60.43195332250288, 57.38888440593597, 16.681189229411466, 2.5650619210735446, 0.16898585002749197, 0.1518497042237751, 1.3381212421001927, 1.8836856705527154, 60.35546318177254, 64.41884256178334, 68.1444509567753, 43.65943954836938, 14.984447398493367, 34.74654366893154, 38.33441803532262, 57.74182711878131, 27.132638731310447, 43.129374365652765, 63.20429632740637, 68.21780712373796, 5.201470774988975, 0.29186126625826286, 0.17737448215484622, 0.029335400773092147, 0.02680315842641698, 0.015199462124597163, 0.02379039509011613, 0.03471839226662152, 0.10080891240748668, 0.02633531810715795, 0.04332907114838881, 0.05319697309225317, 0.05662969050688609, 0.038776122514278664, 1.405063720960771, 66.61143179862731, 66.87103779085221, 68.76941004107076, 32.451964962867, 23.067753161153487, 40.502182591346006, 58.199983489128854, 16.478428186908847, 23.232082820707753, 57.46227587423017, 74.09132895931121, 63.777389910913286, 73.58763387126308, 10.614966250235035, 1.7175333346090011, 0.3441652451311389, 0.20997316276113834, 0.33197461056613153, 0.7593912739426859, 8.434412806264817, 73.05028484713647, 70.24723360615393, 65.132353075089, 61.68343651679255, 63.17109738626788, 66.54313548918694, 65.44298125851539, 61.42386582589919, 49.458718761321045, 51.65888601733793, 54.069202100076986, 59.01467938576976, 61.06756948655652, 64.33565693516886, 60.845175020156375, 56.681453566397394, 46.30998119231194, 60.40365734407979, 60.7848136655746, 62.1635385482542, 60.26227551121866, 59.113832981355735, 56.47388173687843, 57.99100352871803, 59.398263654401234, 57.86594660051408, 58.89976570683142, 61.01412719295871, 58.44822637496456, 58.665560983842425, 56.254699691649414, 57.613342039046756, 60.144835825889345, 55.516846949054354, 48.358635133312596, 50.887595069023874, 49.75981558522871, 50.38606120694069, 46.3098870554278, 50.138594950399096, 44.55536380890877, 38.18738406704318, 43.111119654870805, 48.85643097662157, 50.05343637158794, 47.58758737194923, 48.1672626926053, 46.97350109777143, 48.41052809069234, 46.79216207996492, 45.68339432439497, 45.43003666785456, 50.58710621249292, 54.65695750328803, 52.937096241981756, 55.2170366625632, 57.47856155518563, 60.923461606425626, 50.20210989059941, 34.768477562935125, 42.43569143356816, 41.49356557476906, 53.4787755627786, 61.150966921160304, 58.89962450150521, 58.335356250886, 55.30594110488892, 52.5934220898536, 51.54349380923856, 44.83850009979741, 42.973358169678725, 41.731955466731904, 44.66498621048466, 43.99768906254923, 31.76118458470991, 40.82069473881876, 45.01337112918977, 48.77916028422695, 44.850271132684526, 42.13505352697065, 46.44324371891637, 50.26876664930775, 47.585406534133426, 47.28990693246165, 53.23734975630238, 49.64514117087088, 48.17265987396241, 53.84753719452889, 57.20784348826255, 55.092877957128714, 54.32911011480517, 58.17369968660417, 59.63000120655183, 59.36816338569888, 58.998307412670506, 56.973403423063225, 59.620689499762754, 56.660002123925, 57.337313082910356, 57.72042666712115, 61.6518771263861, 62.61868253830941, 62.46581992795391, 52.680902711806766, 59.62451381068076, 60.12160754972889, 63.59874163904498, 60.71274795839864, 58.51110589119696, 49.180081429020056, 46.384255193894916, 49.16225425658688, 51.29454097440166, 59.819063371227635, 64.9795610673966, 67.57012967140444, 67.13851205764279, 68.49813107521304, 75.17493863259593, 79.92644294615715, 79.9874044233753, 63.05885876378706, 60.11033073548348, 16.81508129642856, 3.1903759798695965, 0.2718039812339891, 0.2517229015187871, 4.046298928799168, 2.223447503582124, 66.08577928235455, 69.63299828190958, 73.75047499133696, 50.73432845454062, 18.908126661854407, 24.94058293680991, 39.55394567981843, 65.87617566508632, 24.899735373835412, 46.69551487891905, 69.79244262941423, 78.61276272804507, 7.325675939359973, 0.37767386965213284, 0.21484453201053605, 0.06882346986282258, 0.04176308017885012, 0.050162590754729126, 0.10746303720459824, 0.16432232043195158, 0.22911031490131734, 0.21872349564106236, 0.1416975530164857, 0.20314803947844814, 0.27226596289584715, 0.18968039763069924, 2.006978635345736, 79.14004695030951, 74.06394297076811, 94.78245919750583, 41.61538654758085, 24.78530022405809, 51.84328840624902, 54.454500444473766, 19.67140813027659, 32.38356863298724, 65.51094416649111, 78.60576521965766, 69.32506868916174, 79.04114830878474, 11.002775892134636, 7.600765978136371, 1.3382188110582292, 0.8007123405414244, 0.9750368734521251, 1.1145255498347746, 9.385381648617408, 77.27108463164299, 72.80934933693179, 67.18065400277415, 65.35437883869295, 67.28879374842491, 68.69568517131191, 67.23468857426798, 65.2449486332555, 52.118179875035445, 56.27027934597385, 56.40693472277734, 61.767053604125984, 62.68465288223759, 66.93398398737754, 62.03309228343349, 55.36040321473153, 49.59735885743172, 63.0652012363557, 62.237161436388575, 64.33762596499535, 60.72353839874268, 61.783029417837824, 59.399208945612756, 62.809643130148615, 61.511679849317005, 61.24560194630777, 60.52544301556003, 66.84970794185516, 62.92793004743515, 63.51392822880899, 60.415553892812426, 58.456086804789884, 64.9852132028149, 60.972412786176136, 54.01155502565446, 55.22732503952519, 52.14792320805212, 52.10830726931172, 50.844272490470644, 54.04638567278462, 50.028670526319935, 43.404108939632295, 46.75794724495181, 55.63680087366412, 55.74138695193876, 52.190206358509684, 53.181055899589296, 52.7118972809084, 52.54787944978284, 50.338875093767726, 47.443554016851614, 46.322611224266794, 55.12989728681503, 57.855309132606756, 56.38680119668284, 58.318717556615034, 59.410175892614554, 63.44825206264373, 51.67583850122268, 35.65636488699144, 42.702714627788914, 42.56186231490105, 56.11345514174431, 62.074339928165564, 61.48848295211793, 60.2641543265312, 58.23703812014673, 54.30700363651399, 53.968683519671046, 47.23615477162023, 46.60656729052144, 46.14397864187918, 47.6193154242731, 47.5600915570413, 39.956573055636504, 47.3195678957047, 49.65107571694159, 51.60760494970506, 48.5874818986462, 47.123237579099595, 52.5062160338125, 56.04482150846913, 51.162306108782374, 50.42943869867633, 55.1395227832179, 55.29503691580988, 52.46327392516598, 58.25429262653474, 62.178525924682624, 58.398992784561656, 56.39867421119445, 61.00028514862061, 62.82413236556515, 60.69139457518055, 64.29815123158117, 57.55894660949708, 62.83693105943742, 59.081402824771025, 61.19932582301479, 61.72169531545332, 65.72391317736718, 63.87841447707146, 65.10781472729099, 55.89864261688725, 62.8066425169668, 61.04562774781258, 66.57124319384175, 67.26245111034763, 62.1716578545109, 53.93751636628182, 49.90935594804826, 52.30279799430601, 55.75300893475933, 62.42543128228957, 68.72895471511349, 69.49391888033959, 69.93945306347263, 71.12926483154297, 77.4289051178963, 78.9052930954964, 78.28389552331741, 72.42861270904541, 66.49184657681373, 19.916042435553766, 5.6902113364588836, 0.6308328949155346, 0.3533902001236716, 7.447265002035326, 2.8287283018712075, 73.85251152899959, 76.5148595071608, 80.1907479378485, 59.17841088387274, 28.25708616164423, 45.35781798824188, 54.47305325538882, 75.30787560247606, 41.24924898147583, 61.06276066072526, 80.68172670179798, 90.98990378841278, 11.10335526927825, 0.9028962122336511, 0.40299739628549547, 0.22044002288772216, 0.18999712902211374, 0.19089524453926474], [0.08554549917819039, 0.08411068544392625, 0.0388346363099352, 0.023868013203384417, 0.1014889763187497, 0.06802393453976802, 0.1526063999101039, 0.05377069633874682, 0.0578551707158406, 43.40800777558358, 66.14179072841522, 47.435462167186124, 31.07537384956114, 28.877785551932554, 34.17502295586371, 48.37722716792938, 9.038596076350059, 23.277264602722664, 56.15665220445203, 63.475434087937884, 58.1049640717045, 62.72174281458702, 27.056611430260446, 1.0046866824550014, 0.5673401406215084, 0.15458807018735718, 0.30577363746781505, 0.33176721524327035, 0.9606610190483832, 42.67209268385365, 67.76797402289607, 65.30430978344333, 67.54541873931885, 60.17001744239562, 65.37633626691758, 63.57068100283223, 61.337106920057735, 49.25928584990963, 49.20019142089352, 48.33657572346349, 54.880760100580034, 54.575717372279016, 58.64314071593746, 61.202220532201956, 48.80974300446049, 49.35372083417831, 60.505172206509506, 57.341000110872336, 59.60224259284235, 58.64426643617692, 57.50611620564615, 53.20019314366003, 59.233531951904304, 55.90953896122595, 56.941381192976436, 58.638802574526885, 58.87719246648974, 55.386330081570534, 58.49515361170615, 52.87570330404466, 58.99738565568001, 57.999668044428674, 48.46361737097464, 47.41148471832276, 48.560574439264116, 45.89923843260735, 48.10676797743767, 44.693227275725334, 43.94863982354441, 49.645737371137066, 40.604034777610536, 36.38648271560669, 43.466431479300226, 46.23721338087513, 45.305979944044545, 44.97997999191285, 46.50489945565501, 42.698611828588675, 45.496787563447036, 46.96519744011664, 44.74985061153289, 47.430398387293664, 52.27438826714793, 49.526862098324685, 54.32493671294182, 48.67868092752273, 54.20503770151446, 53.005678884444706, 37.97152426935012, 45.35162456573979, 39.35835669117589, 57.89585467307799, 53.60906101042225, 54.49018224593132, 50.92424177354383, 50.85207016237321, 51.52821617741739, 46.31366037553357, 43.756569200946444, 47.084653223714525, 42.969702520678126, 44.829074644273334, 35.73310998178298, 35.5171952709075, 34.933279868095156, 32.68611673385867, 33.88078635738742, 38.91846679872082, 41.004171448369185, 45.20236661357265, 44.590818112896336, 45.03897243930448, 48.35925486779983, 48.613918673607614, 45.472025640549205, 45.77877459987518, 49.20793810198384, 49.7999414320915, 52.941838387520086, 52.52336855857603, 57.025229700150035, 53.757389360858554, 57.972905712742964, 55.72416382451212, 51.769422331163966, 53.7582326704456, 56.30995412026682, 55.119048010918405, 55.15001904579901, 57.61105921960647, 59.116798293206, 59.777592151395744, 53.56638954531763, 58.773124141077844, 57.55767968393142, 60.815729787272794, 58.53000387068718, 57.28940133125552, 51.005309320265255, 49.59027897927069, 47.84135295498756, 46.1105522032707, 53.60169872160881, 62.3211629159989, 64.43112350279286, 66.35085305859967, 61.798769889339326, 71.32547747704291, 68.1462081786125, 68.23467331547891, 62.0921161097865, 49.90620236242972, 12.887518886596927, 1.336481323645961, 0.14338905983153852, 1.3509317030829768, 2.8805793389197323, 11.573504286427653, 67.0712669434086, 54.738750688491336, 68.85277609671317, 41.78326399095597, 22.017919017422585, 24.450174877720496, 42.02973004310362, 46.35872056407314, 44.96578885662941, 65.83655972634593, 50.491788694935465, 68.50076690796884, 2.0756322481939873, 0.19705278348297844, 0.0858943373145115, 0.04173508732609692, 0.08278251880960119, 0.07530913192538485, 0.0328395692932029, 0.000647683409624733, 0.03529213466531327, 0.021560089061817816, 0.06108657171529147, 0.011835470457651443, 0.1200785824368077, 0.0887213166682951, 0.04229313641365978, 49.07053355247744, 73.98471109328732, 51.402876838561035, 31.592463831747736, 33.47341683603103, 40.85380738781345, 45.4297189558706, 16.60828217383354, 27.17467869481733, 62.64300123337777, 70.17129651961788, 65.37124110806373, 70.5840475328507, 30.33353597887101, 0.5936504804318952, 0.504759888975851, 0.11423553024689037, 0.08113977349092884, 0.514783076941967, 1.4777612974566798, 50.07014566852201, 73.39710081777265, 67.79734473074636, 67.31329287252119, 63.23522813858525, 69.70871571571597, 65.71758247190907, 64.97902762505316, 52.5275811841411, 50.8154744486655, 49.83249710452173, 58.85179904199416, 57.90491534817604, 62.85643308393417, 59.39492571738459, 50.98868631547498, 52.860260932676255, 62.30885844076834, 59.8190829830785, 60.946297645568855, 60.58135247999623, 58.58782745176747, 55.79529208521689, 60.95962585941438, 57.92633148931689, 59.20123515590545, 62.91895566448089, 60.821201493663175, 58.14273257409373, 62.4768300210276, 56.65970010142173, 61.07243714794036, 60.18244351110151, 55.70407344448952, 49.75996855766543, 51.634732061816806, 48.99057995888495, 51.120552478298066, 48.095546076374674, 46.16411216797368, 54.23300027847291, 46.151352697803134, 41.3800561043524, 48.79348478009624, 49.926335888524214, 47.47764725838938, 48.560182202246885, 50.62738503179243, 47.358262077454604, 50.5430736849385, 48.166537054123424, 48.66847884270453, 52.72024408463509, 53.65518023890834, 50.32762181374335, 55.89508110477079, 51.277353148306574, 58.62512919210619, 53.74995646938201, 39.95470600743448, 44.93703788326633, 40.473070759927076, 59.01786827271985, 55.466464104190955, 56.007194211406095, 53.77924088508853, 52.44861995020221, 53.9783247055546, 49.13762569427491, 47.22985152275332, 48.03773426240491, 44.68533154456846, 46.36345094250095, 39.2198891793528, 40.40883018124489, 40.19706926038189, 37.66101375702889, 40.33184189950266, 41.841605324899, 45.1672496334199, 49.86148342009514, 49.51638152522426, 48.41819632437922, 50.57313080756895, 51.50025360045895, 50.97440496567757, 47.501883583684126, 52.97010298698179, 53.69281930308188, 57.13549537043418, 55.263120589717744, 57.653867967667125, 56.58735198359336, 59.73803897057811, 56.6051987678774, 54.80382280965006, 54.99038642452609, 58.87301906462639, 58.387072701607984, 58.24678521002493, 60.72768042164465, 61.60231405688871, 60.400044841151086, 57.24811446282172, 60.862794306970414, 60.00202625028549, 63.89996397879816, 61.923905264946725, 59.99434232711793, 54.33548788870535, 51.15239035698676, 49.450611222174864, 49.866966893596036, 56.65087476853402, 65.72738055259951, 67.88078138905188, 69.84977983659314, 63.109884877358716, 73.62820686832552, 70.36012726445352, 75.61688776939147, 70.4009356037263, 52.51153084539598, 15.113284510950889, 2.1616331559996453, 0.09322758373473922, 1.9126987072729298, 2.365484372262032, 14.846402522056335, 76.41778869013633, 60.773807494871086, 77.03142781411448, 50.490686508917044, 25.80977624462497, 26.302620095591394, 46.02475427812146, 55.34426658384262, 40.430434596154, 67.14569783979847, 58.09195356984293, 76.87436826767461, 4.114946290369957, 0.3314547739442318, 0.1415010361421493, 0.051449886598293824, 0.06643396501819934, 0.03460837821025522, 0.1361515973844836, 0.2720638995449389, 0.1778956670914927, 0.12115254577609802, 0.1667102318136923, 0.15902728923866827, 0.3537181470422976, 0.18077056524494003, 0.18614399787639418, 59.86594353952716, 84.24531767445227, 64.65360033896663, 45.31228319291146, 40.572428318762014, 52.47174232236801, 60.04971050447034, 18.643325490336267, 37.2287489521888, 67.4640295582433, 76.27059782705, 69.44250445212089, 76.87224234304121, 32.69078435436372, 1.6961724743727715, 1.4718299383117308, 0.24986187476784955, 0.46152102851098586, 0.6072674174943279, 2.3102613226059945, 53.956900719673406, 76.57686433484479, 70.53099355389996, 73.72368520306003, 64.19520862640874, 72.77166320431617, 68.59282493591309, 69.08549031903668, 54.494045780551055, 54.412750736359634, 53.18495473554058, 62.24408049737254, 59.6073220622155, 66.51768715150895, 64.35000888762936, 52.845979582878854, 53.954492384387606, 64.98783726846018, 61.23444280316753, 64.54440547573951, 63.65673780441285, 60.87434960949806, 57.175683975219734, 64.49787439838533, 61.36093531885455, 63.27713866387645, 64.04609580193797, 62.825579720158736, 59.664153283642186, 66.28061909829417, 59.057676407598684, 63.76623861251339, 64.66432017664756, 56.84296500298285, 54.24747382440875, 55.13009732769382, 52.99437853597826, 55.687211175118726, 52.72648457557925, 52.9602264588879, 56.52761820823916, 52.06707531406034, 47.39626592205417, 53.15747461011333, 53.58431869937528, 55.509947499921246, 54.372687647419596, 57.39291660247311, 51.32137390875047, 53.11514831358387, 52.13565011178294, 52.987836022530836, 53.63450542573006, 57.3409059739882, 55.80338393488238, 60.05132259861116, 54.41226044008809, 59.84480196429838, 58.468261841804754, 41.614892328939135, 46.81465295053298, 42.08880486026887, 61.77345883461737, 59.394929639754764, 59.89678513619208, 54.67993474775746, 54.09703523881974, 57.55522428020355, 50.16424332895587, 48.886739130943056, 51.439621602335286, 48.39861193010884, 49.89304673287177, 45.36159523071782, 45.91281375577373, 45.31190664537492, 45.84521955059421, 46.077294426579634, 48.04480237345542, 49.129557378830455, 53.36376774695612, 53.27462796242007, 53.09827035473239, 56.35333553437264, 55.60681043132659, 54.16174257955244, 53.045243832372854, 56.57509457680487, 58.826346781946, 61.63078654196955, 62.22661418299522, 62.15264612628568, 57.734790386692175, 61.17070821023757, 59.1841414666945, 56.681379041364124, 59.15819498800463, 62.122047716571444, 60.989996771658625, 59.15376270970991, 64.87874438685756, 62.88426230030676, 64.29295801347303, 59.6263651694021, 64.13774198101413, 61.00379174755466, 67.02714027897005, 65.43949819380238, 63.00939767591415, 56.29257017566312, 55.075282204535704, 54.44347073954921, 52.42089271545411, 59.639693383247625, 68.41973858494913, 71.34596009408274, 72.51765835669734, 65.59416117206698, 79.17124548266011, 71.73988373048844, 67.54209256941273, 65.50740226622551, 59.87548274378623, 18.472547454218713, 3.9565435772941964, 0.31480814300237164, 2.36452829453253, 7.758945851556717, 14.56975285084017, 82.77330706196447, 64.8937003843246, 82.36806346524148, 54.55999651262837, 33.39878982113254, 36.95941155956638, 60.34732818603516, 64.21937827141055, 64.2142988020374, 88.0544254856725, 65.74001058455437, 92.68789783600839, 7.153214225845953, 0.6103565904401964, 0.3954181207283851, 0.17113949172198775, 0.2153559876305442, 0.17351269421558227], [0.06079447771152181, 0.02213052962155592, 0.07526952517969955, 0.08894181209466151, 0.05695283022378722, 0.09170235630365149, 0.20160418844992117, 0.13399826212515756, 0.366039568137738, 28.615984993596232, 69.48580741882324, 52.09349639954106, 46.61062694364979, 35.62780610976681, 36.72841925774851, 81.07317924499512, 13.695310431142008, 15.54336847797517, 65.58485731001824, 58.39758073129962, 68.84173854704827, 54.45230391717727, 52.318856177791474, 0.2839749733046178, 0.021812905737709616, 0.08183716631103909, 0.29193438168975616, 0.48341983568764507, 0.8083743229508401, 17.418310449969386, 57.67296598803613, 62.304339870329834, 62.961305495231386, 63.98958621486541, 64.51584669851488, 65.01836507551133, 60.01646057251961, 48.197464942932136, 48.16816483774493, 49.512686652521936, 48.30368272719845, 55.95041790316182, 56.99813788936984, 60.95707631880238, 48.47953827150407, 51.58987191415603, 61.81699322115991, 54.972818128524295, 58.68263898357269, 59.14721627389232, 56.84384361390145, 55.36134458357289, 56.12630874879899, 54.17574936343778, 55.443804571705485, 56.22534859564997, 59.87075628772859, 54.096172317381836, 56.68639575281451, 57.09418104540918, 57.66236382146036, 52.92803948925388, 51.10021891132478, 51.74663336046281, 47.505433328690074, 48.29216272600236, 47.48527626837454, 46.81469609660488, 34.55647345512144, 32.404690596365164, 37.085084299887384, 39.32867611608198, 40.59015350957071, 39.4217735721219, 46.14141733415666, 50.30864538684968, 51.867250165631695, 49.12441122916437, 47.33788928677959, 46.88367097608505, 47.739928307071814, 48.151812476496545, 49.11454254581083, 50.32610385648666, 52.2384750458502, 46.42585977431267, 45.77265962477654, 54.730164620184134, 40.23635179765763, 37.6461636635565, 42.81303913362565, 57.34675422791512, 44.540043031015706, 49.807064456324426, 53.083785041686035, 47.44884921658424, 51.610578106295684, 49.66904801707114, 42.51338574194139, 44.24833243893039, 42.741899105810354, 46.98876696248209, 45.563844403912945, 45.711074490701, 36.77552300114786, 22.112067668668686, 22.73492044018161, 38.169537282759144, 44.74632440074798, 44.41484881985573, 42.330516999767674, 44.40155982971192, 47.204442408777055, 46.969645407892045, 45.706450016267844, 50.541975421290246, 52.86097872641779, 51.74280512717463, 53.918304597177816, 54.82929468154908, 56.508520187870154, 55.800351942739184, 57.542535412696104, 54.52743691782798, 50.41682827857233, 53.63010452639673, 54.48516161211076, 56.417364305065526, 54.76287326505108, 55.81460583594538, 60.00962388130927, 60.536570779738895, 58.03545574988089, 59.81640792662098, 58.34087894808862, 61.78271170585387, 56.47699609879525, 57.82337319466376, 53.48753029300321, 48.41064968416768, 47.011540243702555, 47.99441560622185, 45.127959251403816, 55.33547262991629, 62.63190092579011, 63.929181714211744, 67.61601355768019, 66.07800514467301, 68.26114931414205, 47.814535710119436, 41.23281032808366, 32.28124772348712, 10.808116505222937, 0.7089173565468481, 0.03888114933825789, 0.8612058912554096, 3.776875734329224, 28.668399626208892, 71.15417972687753, 59.511788814298576, 70.95182464968774, 57.58211605010494, 51.482908879556966, 26.403842741443267, 29.239400625228885, 51.19573254739085, 37.36953458478374, 57.033592193357414, 50.80426039234285, 67.7382581464706, 2.4680477332684303, 0.2041274216026068, 0.0758027836620327, 0.057332231437847506, 0.08057271520937644, 0.05887586796175569, 0.05984598425247016, 0.09189184049084302, 0.1018229217058228, 0.0440891835868599, 0.04710081311303282, 0.02474439289090374, 0.09490229024161255, 0.20038393296061024, 0.3568183516542758, 30.943433161704775, 80.0131743954074, 57.24747119411346, 47.24280711143248, 31.030927511953543, 51.410062620716715, 78.42764254539244, 14.656554902753523, 21.94900297349499, 68.5569901620188, 69.86331985842797, 71.78985472648375, 63.423984358387614, 54.59508211381974, 0.468562908710972, 0.11964957319921064, 0.06989546435614748, 0.42606016681078945, 0.3230687465158201, 0.46868870034813886, 22.300984705648116, 62.57428915269914, 63.59401910535751, 64.50017682967648, 63.551241736258234, 68.12192870724586, 63.21948766708375, 63.09060250559161, 50.705267613933934, 51.06386638456776, 51.7082804249179, 53.84306569253245, 60.17022925038492, 62.061804033094845, 63.230599741781916, 48.02533172792005, 57.13975506444132, 63.802065541667325, 58.06284958316434, 60.19650913053944, 60.971134093499955, 59.88077009877851, 56.85614416676184, 58.67979526519776, 55.77712366657873, 57.1384253809529, 57.5498192541061, 62.042709935096006, 58.22109368539626, 59.762510638083185, 60.41776218721944, 58.127686362112726, 57.05936216538953, 53.88122643193891, 53.32372819223712, 50.17454347302837, 51.13576342982631, 52.751917223776545, 51.48783929886357, 38.410998390566924, 37.84618885286393, 42.25839245703913, 43.921018492790964, 44.023243304221864, 43.60316530350716, 48.939922548109486, 53.544753751447125, 53.4277416044666, 51.16459677296301, 52.85365958367625, 49.29490097107426, 53.33607973590974, 51.36436308583906, 48.934286102171875, 51.00556427432645, 54.48367895618562, 49.06850176472818, 49.25503792301301, 54.961678597234915, 39.332998568011874, 38.67860209557318, 43.075888925983065, 59.741757377501465, 47.39180618716825, 50.479237110384055, 53.556893487130445, 49.37710992751583, 53.07126091372583, 51.47312648834721, 46.88996245784145, 46.20398698314544, 45.943243503570564, 50.28171047087639, 49.72607927937662, 48.04181744975429, 41.65498287447038, 28.654747816824145, 27.912735400661347, 41.46932924947431, 50.13445292749713, 47.67828041507352, 47.11473780293619, 48.720258051349276, 50.800428236684496, 50.558433686533284, 49.2989057110202, 50.76963370846164, 58.166125589801425, 52.71209339941702, 57.244447046710604, 57.80841327482655, 59.90647731288787, 58.269954650632805, 59.53644483320175, 54.75110615453413, 52.08583601059453, 55.47426177609352, 56.6717613897016, 60.022195077711544, 57.249546127934615, 57.80253364193825, 60.78727691404281, 61.69947901079732, 58.97210990228961, 61.644306951953524, 59.55222452840498, 64.71138077397501, 61.76562193901309, 60.48771373687252, 55.29977906134821, 50.54271282688264, 51.5375945644994, 51.26666468958701, 48.02256253457839, 58.160720563703975, 66.4070527784286, 67.0464854086599, 71.22176216494653, 67.50077432201755, 71.55839566261538, 53.30257877226799, 48.18414065145677, 37.51878469221054, 11.62802032886013, 0.855239904936283, 0.05792811760799058, 2.042374961799191, 2.0385135109386137, 31.786813351415823, 80.07902314586025, 64.89808167180708, 79.7717603560417, 66.35770936166087, 57.134871713576786, 32.47748978676335, 34.3714552540933, 60.14354536610266, 38.40230641826507, 63.887263344180205, 60.921037581659135, 76.20635724836781, 3.7985407008278758, 0.295169111341238, 0.04266944263250597, 0.01117904993495153, 0.07140202988539973, 0.031679248692648064, 0.18576121438414822, 0.26829545175836933, 0.19716210422977326, 0.17429005895410815, 0.1867636404330692, 0.18966941192986506, 0.2684111310349357, 0.5516173810728136, 0.5482795053432065, 40.473196275772594, 91.90915830673711, 66.14106116756317, 62.93695934357182, 47.697802051421135, 51.94041805882608, 84.80251389165079, 25.198996528502434, 26.804846256009995, 76.43991085790819, 69.68809973809027, 77.84379774524321, 68.79460734705772, 62.71611421338974, 0.549071088673607, 0.35364043508325854, 0.1869669142028978, 0.930527777921769, 0.8092367540924781, 0.9318263888839753, 24.46020241706602, 63.92193709650348, 63.107029391873276, 68.20467502840104, 64.40360023129371, 69.71790190665953, 68.12913017888224, 65.74510966577839, 53.852000851784986, 53.535940185669936, 54.916273240120184, 55.76337183675459, 60.33079539575885, 64.05154397410732, 63.71405147737073, 48.261187768751576, 55.94567967999367, 67.33231636785692, 60.02666657970798, 61.50444699871925, 63.83529586176719, 63.806431139669115, 58.947089102960405, 62.141659567433024, 58.08588566318635, 59.170989759506725, 59.34558622298702, 64.97857263011318, 60.99921826393374, 61.77481989706717, 64.52194206176266, 63.787337041670284, 60.37791090626871, 58.96599492719097, 57.52883849605438, 55.03818834981611, 56.579617069613555, 57.074988888156035, 54.247144345314275, 45.68085655089348, 43.55384934333063, 48.366891722525324, 48.52754416004304, 50.33503509336903, 48.39993769122709, 54.18653980378182, 55.164398454850726, 59.02076298190702, 55.36881277638098, 57.02782630920411, 54.77102787263932, 55.20979988959528, 53.55947440670383, 52.61236321541571, 54.38067359309043, 57.7952576452686, 50.8458649727606, 51.23308920091199, 58.435847374700735, 41.7839111820344, 40.18442746131651, 43.63706242653632, 60.810748377153956, 50.37305854981946, 53.19156000691076, 56.015019339899865, 52.43625663941907, 57.36652689595377, 57.15839024512999, 48.77516731139153, 51.37005052258892, 50.243820375011815, 55.9291821910489, 55.26590155016992, 53.56305160830098, 48.57584422634494, 36.21815027729158, 34.873346051862164, 49.66687502399568, 52.7564004928835, 52.74284870393815, 50.725609025647564, 52.827061991537775, 57.15317349280081, 57.26801264670588, 53.4381123512022, 56.21272248606528, 62.530044817155414, 58.44359013342089, 62.82730164066438, 60.88601081602035, 61.91808054524084, 60.5783518668144, 61.77479636284613, 56.07683981618574, 55.11889503848169, 57.528410957705596, 59.37541584814749, 62.769564351727894, 59.31595663870535, 59.11036952849358, 63.74985094993346, 65.59933870069443, 61.377401428837935, 65.20004533952283, 60.9770647172005, 68.57366023525115, 63.52875086569018, 63.00437704209359, 57.3935834054024, 55.1070769371525, 53.065671536230276, 54.40600425966325, 51.46011990885581, 62.3334320898979, 70.36995672410535, 69.07513526178175, 74.23761767725792, 71.60284396140807, 73.51390115676388, 54.71381225893575, 48.3044122880505, 37.107437887499415, 14.850600438733256, 2.1331540519191377, 0.16334920490701355, 1.9087439775466921, 7.557696882755526, 36.368930109085575, 86.28380483196628, 71.96300383537047, 83.98651184574251, 70.79936212108981, 62.421630505592596, 39.888312047527684, 44.1133911378922, 68.94860744476318, 47.41000598476779, 73.64268041426136, 66.86614267287716, 93.02486865751206, 6.948596921659286, 0.8164553248113202, 0.34137028059171093, 0.15915646698446045, 0.32190168817197123, 0.14074182768742885], [0.06294576751609003, 0.02587534742610109, 0.04910795198332879, 0.058129231009872696, 0.09229084972532527, 0.04689640936351592, 0.08173199776079386, 0.27982535081044324, 0.4848769042761096, 12.278675840746972, 71.93841057439005, 41.72783697805097, 37.69543647766113, 38.793845253606, 36.692239315279075, 37.663069078999186, 20.27431761064837, 9.863677428614709, 67.7525826423399, 47.63587567114061, 69.21000203778668, 50.27604656834757, 61.48729055158554, 9.939479193379803, 0.09677524498153119, 0.3085638522621124, 0.2988698982423352, 0.18464185267446503, 0.17831655579709238, 8.363902318862177, 49.79646621211883, 64.85637510976484, 63.64724959096601, 61.42424629580591, 61.891992861224765, 61.13622665405274, 58.316470038506296, 46.77092244548183, 48.99965240109352, 48.52388851104244, 54.084354216052645, 56.74313283735707, 57.365820869322754, 60.70430309541764, 41.56173636836391, 51.42634830167217, 61.98185043950235, 61.16728790344731, 60.90729359657534, 56.763282052932254, 59.463371076891505, 59.86540225244338, 55.91859179158365, 53.199153715564364, 54.644233334449034, 55.627665673532796, 60.14980546889767, 57.52930133573471, 57.300729136313166, 55.02394622372043, 53.35155348623953, 48.170388821632635, 51.69367744076637, 53.6249936780622, 48.82370664227394, 46.54427220744472, 45.00623633784633, 49.25364548160184, 41.272469412895944, 27.44701473943649, 34.06188218824325, 44.2125565005887, 47.95321895230202, 42.19483437076692, 45.920705564560436, 47.42045910127702, 48.84039240498697, 49.47295304267637, 47.83185297443021, 46.3242115512971, 47.347475559480735, 50.47369480133057, 53.87369940357824, 53.502960897261104, 57.4070998930162, 48.88273831336729, 46.06453495640909, 55.40913866412256, 41.13842633462722, 38.29359792893933, 45.3656352719953, 56.419199974306174, 45.718181825453236, 46.34536881600657, 53.80292807855914, 50.988407827192745, 48.937388696978175, 49.25902305110809, 44.233615706043864, 45.832766025297104, 47.06518650054932, 47.63995493611982, 48.18339932349421, 42.37128219296856, 36.056254448429236, 21.425188087647964, 29.10216081526972, 44.80127288449196, 42.790105035228116, 43.647354725868475, 45.86327029812721, 42.85407889273859, 46.37669678657286, 44.9933474294601, 49.49612640565442, 51.84641845764653, 53.76361808469219, 53.58685647287677, 51.030357576185665, 55.14557107802361, 56.53448627841089, 56.31390002466018, 56.56695173632715, 51.42385367424258, 51.5726605538399, 57.07458488402828, 59.464281066771484, 57.358156558006044, 58.99180804529498, 56.97006548604658, 58.275842128261445, 59.11136581051735, 65.00087522691297, 66.99519649628671, 47.49285036517728, 52.52719679186421, 61.8945659360578, 57.85133969399237, 59.74677801132203, 53.957849933255105, 48.59290261422434, 45.90032885151525, 46.315923583122995, 49.82393849280573, 57.93903996867519, 64.27251854250508, 63.95788561913275, 68.82247970950219, 69.31113643030967, 77.06767051450669, 55.1848183139678, 30.774269180913127, 4.287433499290097, 0.5814571798809114, 0.12022653699762399, 2.733632888524763, 1.8987753963278187, 41.40399825188422, 68.81900448952952, 58.34971997045702, 68.48426941902407, 53.46500804347377, 76.55553448584773, 23.953467492134344, 33.75660019536173, 44.184248755055094, 36.143597787426366, 67.18407430956441, 43.26146018120551, 61.646766278051565, 0.8894522884680379, 0.09362598009888204, 0.014765526941646973, 0.05258815152750862, 0.09393268339936772, 0.040079644100079616, 0.03136170524803381, 0.03408487585763778, 0.061094450929592696, 0.0194512328673755, 0.0415872170349523, 0.05290762551369206, 0.04861126653850079, 0.2862598458605428, 0.3195626072345242, 13.248523050738921, 83.68358719733455, 49.53284371283747, 41.0090861781951, 40.99214153905069, 43.106020573646795, 41.5947784146955, 16.882663734497562, 14.744474830165988, 71.7435315347487, 55.936309137652, 78.94284586752616, 55.43243754294611, 68.57983404590239, 11.270874796375152, 0.22744113188837806, 0.3152236997360184, 0.3477262669513303, 0.22483804173046545, 0.16374112016731696, 10.092769342084086, 56.17105514772477, 67.57454626021847, 67.7466598633797, 64.41779136657715, 63.92169390955279, 65.41901557676255, 59.873348974412494, 48.991195771002005, 50.713143733239946, 51.06173261519402, 57.802400281352384, 59.921539214349565, 62.14405221323814, 58.94390021601031, 41.07712361120409, 52.757671340819336, 62.97386492452314, 64.94938627366098, 64.1039546843498, 59.78617821970294, 60.207770255304155, 62.65399563697077, 59.29410511447538, 57.60157492852981, 55.336300250022646, 58.61302868012459, 61.16199662608486, 59.779341528492594, 60.89480476994669, 59.052396897346746, 55.12630831810736, 52.802676616176484, 53.477685143870694, 56.60898777746386, 52.0401325533467, 50.04403837265507, 49.91878924831268, 51.62289042626658, 45.216604817298155, 31.225337828359297, 39.00946186434838, 48.70811439329579, 52.68640187478835, 47.49695316437752, 47.75947347764046, 50.8394479751587, 49.71584189322687, 50.719792150682025, 52.27197993186213, 48.54335523420765, 51.03618229589155, 53.40962025427049, 56.2180333752786, 53.47626916823849, 59.05178108522969, 49.52803880937638, 48.58257109119047, 54.4617921306241, 42.328198878995835, 39.04649296114522, 45.75613467924057, 56.951799008154104, 48.83683089287051, 48.225855058239354, 56.93100652387066, 52.39949226379395, 50.24619340896607, 52.891330026811175, 49.79568173808437, 47.73536659056141, 48.74437278316867, 52.03346060168359, 51.232728342856134, 46.889452549719046, 40.219697413905976, 26.677590839324463, 34.96006181163173, 49.59507603799143, 47.82172541464529, 47.369158421793294, 49.86718654632569, 47.22921217641523, 50.031110240567116, 48.20384271683232, 52.18103977941698, 54.92711467127646, 57.228330027672556, 55.48950410658314, 51.02793355141917, 59.33798466959308, 59.72905282051333, 59.39755370540004, 56.225125020550145, 53.360194467729144, 53.09918426698255, 57.77641065659062, 59.98315964975665, 59.807810091203265, 60.89167864091935, 60.070365705797755, 61.81874259825676, 63.06566015366585, 64.02514642284763, 65.86630698173278, 50.07521337078464, 52.75354500739805, 65.41588944773521, 60.137736335877456, 62.88657257633825, 56.07004234867712, 51.929094176138605, 48.089587996082926, 49.44406870872744, 50.00985491660334, 59.77250091491207, 67.3070013907648, 66.80740125717656, 71.72086023515271, 72.12579788700228, 79.21399931753837, 62.01681444721838, 33.40943513378021, 5.459580382993145, 0.8597888737436264, 0.03339462297698183, 1.9811489697425597, 1.5949156303559582, 48.71815173856674, 75.35484990765973, 65.31825773177609, 78.70299293148902, 58.30824482825495, 82.77024761323007, 31.349865236589988, 42.37006233584496, 56.140778372364665, 29.942581576685754, 64.73997485253119, 52.81309050898398, 71.08798580784952, 1.7389058393816796, 0.11519189142892439, 0.027613451539148248, 0.04405834471746799, 0.05045578026423051, 0.06656733326493733, 0.24242826316866184, 0.14909495930037192, 0.157544985713978, 0.14156281347236327, 0.25591122677489636, 0.14119570413904806, 0.36174481794718777, 0.7296273484826089, 0.7638686594943848, 16.47685923883992, 96.24001979827882, 57.325314552553245, 53.87412301955685, 51.7829623529988, 54.95846617606379, 43.35132560422344, 28.100205083047193, 17.972231488074026, 81.43114259166103, 59.86859506176364, 81.74332403367566, 60.533899645651545, 75.48697102454402, 12.07363295939661, 0.24480955555073677, 0.49638167564426705, 1.3250375635200933, 0.5712099265187018, 0.35418907661111126, 12.625997797135385, 60.08617677996236, 65.70936902876824, 70.5556260385821, 68.585811738045, 68.53963759637648, 66.81861139112904, 64.2331418683452, 50.70755043337422, 54.27277311202019, 53.99489671953263, 59.05788429321782, 61.147899627685554, 65.8059730837422, 60.90323786581717, 40.84991247423234, 55.67072545328448, 64.3859770221095, 67.93187418291646, 67.39354456624677, 62.44004995592179, 63.040054921180975, 65.11728332888696, 61.602643535983184, 59.090483111719934, 57.138225340074115, 60.50731382062359, 64.67693059675156, 63.17855381196546, 64.87004849218553, 62.6686849132661, 59.6084987732672, 54.508362431680005, 58.51711496230095, 59.69027234661964, 55.84735370451405, 57.1663369670991, 52.66791574416622, 55.97245377878989, 51.06974601745606, 39.567273893663966, 46.57671805351011, 53.104059773106734, 55.404459276506984, 51.44722707809941, 52.5244079866717, 55.17560466643303, 56.459933788545676, 54.31845303504698, 56.34840119269587, 54.68538684229697, 55.244505020879934, 57.30469465255738, 58.6445527691995, 56.68552890900643, 60.52459970597298, 52.0304560661316, 51.76316222836895, 58.166890451985026, 41.53589187129852, 39.47199167743806, 48.00957556693785, 61.14890375444966, 51.12913070186492, 52.56082719372165, 59.99049055960871, 55.0851155865577, 54.326639021596606, 57.5359615202873, 52.37982942212013, 52.651790880387836, 50.86392748740412, 55.2298745801372, 55.534446624017534, 53.05735218909479, 47.965974500102384, 34.375667879658366, 41.54139887902045, 54.01674039902226, 53.284779056426025, 52.82625006091211, 55.512069502184474, 51.356973340434415, 53.04487905194683, 53.39582527837446, 56.21183603040634, 60.519959542059134, 59.46450071950113, 59.848959676681034, 55.14824221211096, 64.33490776246595, 63.80271665511593, 61.84011167095554, 58.817462613505704, 56.20287733693277, 55.20087257508309, 58.70860507411342, 63.963514220330026, 62.41195794074767, 63.95892896959859, 61.60795834756667, 62.54966059038716, 64.48416179226291, 65.54173084997362, 68.37958135912496, 52.69089691100582, 57.99549464256533, 67.32713099448912, 62.99122925727599, 64.08811223122382, 57.342290570659024, 55.51880028940017, 51.44243001937867, 51.43487161205661, 54.400822808665616, 65.31081307318904, 73.19384359544324, 70.05885785625827, 75.90427198717671, 73.95098655454575, 81.66064831518358, 62.144507208178126, 36.42993473237561, 8.180321176205913, 1.6205325073772863, 0.17783897658509595, 6.787003605596482, 4.404217168208092, 50.99367557033416, 81.7853561524422, 67.75097447056925, 80.88005742719098, 65.79761843527517, 88.21975338843562, 38.386428663807536, 49.426414120581846, 63.21982499091857, 50.877145874884825, 82.76368156556161, 58.868429891524784, 83.84328257653021, 3.908970375214854, 0.4371301679601593, 0.15674139012492475, 0.10978218453425555, 0.2700282200690239, 0.19449061774198087], [0.02904170181512112, 0.06944702712879067, 0.1180995398411347, 0.0692298871675326, 0.041986708904826836, 0.08563235822704532, 0.05970042754685687, 0.04708691244764675, 0.25386178835986123, 3.626173124197991, 64.41011136577976, 52.38188082172025, 48.69762205308484, 25.9229778089831, 43.581439295122706, 27.71734449171251, 16.03989347334831, 34.8417317482733, 63.059984484026515, 56.67203203324349, 63.676122157804436, 57.81609327562394, 65.01114399202409, 17.65249163873734, 0.18668192949506546, 0.32116311812593096, 0.23721868142245278, 0.1738967187702656, 0.3167613301306002, 6.278200610991448, 50.87325880604406, 56.837093214834894, 65.17460876895537, 60.571126860956994, 60.6260714223308, 58.282972997234715, 47.86985681902978, 49.59760596675258, 50.952627966480875, 50.44235898602394, 52.177133098725356, 58.722686383032034, 58.24896997021091, 68.8115127625004, 62.22943436714911, 37.79751223902549, 55.50423652895036, 54.44950726724441, 59.28059254923175, 60.724405242550766, 63.88396070849512, 59.40315877237628, 57.90277765643213, 54.07856872004848, 53.19616486949306, 53.1918659517842, 58.549184260829804, 57.85505810091573, 55.860968251382154, 54.23356902214789, 54.81043592576058, 54.746046297011844, 55.376841868123705, 54.81934755079208, 52.04322338104249, 48.28055643266248, 46.66422220968431, 41.095899997218964, 47.07797734968124, 50.31294038218837, 39.95718886775356, 35.18912430732481, 46.78374075120496, 49.141453927563084, 51.156959918237504, 47.54666528394146, 50.29294806142008, 48.19421722042946, 45.90378053726689, 45.35893586374099, 46.048508151885, 50.34633936420564, 53.66347605182279, 61.968616362540956, 61.304963096495605, 62.85029849698467, 55.15427089506581, 58.802337954121256, 45.22153131423458, 38.41996100641067, 50.03567980181787, 54.83296994240054, 46.626916546975416, 53.36622315068399, 57.13087089600102, 55.69278486313359, 53.59696049844065, 48.95309386714813, 43.50995802110241, 44.84483864999587, 46.97041811481599, 44.71099169023576, 47.94795513153077, 45.476414772772024, 39.60853722787673, 36.4721865038718, 43.799907468980365, 43.47311519807385, 43.932244316224136, 41.78425635060957, 43.381021868798044, 42.647107185855994, 42.91655048247307, 43.144569627700314, 48.083120007668775, 53.96397667546427, 54.507558345794685, 56.08092300353512, 54.2220490209518, 56.31642995342132, 54.40281145034298, 57.37048456745764, 56.76317222656743, 49.07529138749646, 54.48784451330862, 59.3989618362919, 59.18489063939741, 54.375543132905044, 61.67435622984364, 58.30404789217057, 63.11704712529337, 57.91267379637688, 70.96423502891295, 62.12036501976752, 44.040427207946784, 30.902616977691654, 57.85998459785216, 62.73393354108257, 60.69281055081276, 57.79606173115393, 57.04551619868125, 49.38832790620866, 48.46279367323845, 48.81279460845455, 47.89753306296564, 55.98608793750886, 62.413809299469, 62.5446399565666, 69.22825674856864, 61.81812678613971, 81.37796309686478, 38.35102927300238, 2.602018002540835, 0.8909192549124841, 0.3501735807907197, 0.9171441605975552, 4.31448902814619, 60.13993678554412, 64.14946202308901, 59.32551545481528, 53.12624862117153, 74.31410389561808, 66.8649188933834, 16.077426633527203, 23.625265129150886, 45.155329550466234, 36.4434669094701, 64.81480583067864, 54.919854364087506, 55.47073556530861, 0.8087536896909437, 0.08151788384683671, 0.017702005157667785, 0.08381767213464746, 0.025725952619987152, 0.05141133705394403, 0.009775789447068688, 0.05739054988108336, 0.04757575698256974, 0.04465814176646452, 0.08376393106675918, 0.03627795192803587, 0.007563046942044411, 0.08376049133197916, 0.15234326402987206, 4.0910504758358, 75.25484515774635, 62.034461190623624, 49.524096827353205, 31.37200309384254, 50.29097118685323, 26.8961609948066, 17.278866267973378, 35.31682883539508, 71.2397736887778, 58.624234891706905, 71.49479835264145, 62.92341539936682, 71.04521628349059, 20.226629434093354, 0.19080320673604168, 0.430424876150585, 0.15212741109632677, 0.5022290409091981, 0.34845371340071, 6.690921225855428, 57.39248906412433, 60.956958647697206, 69.07913607935753, 63.48603625451366, 63.76049626258112, 59.62434907113353, 49.93419239597936, 51.98698835988199, 52.840896191135535, 53.717165454741455, 55.862713706108835, 60.594778753096065, 62.063800519512554, 67.84815511395855, 52.72131096932196, 38.57983681463426, 57.13008642196656, 57.540605606571326, 61.79232935751639, 64.1032486577188, 64.99087318297356, 61.26287214217648, 59.83144629386164, 56.560468058432306, 53.151410625826934, 53.50246667861939, 58.61976731208063, 59.10942031491188, 58.499530976818455, 58.4717409841476, 58.048744740024695, 56.968323953690074, 57.19464471263271, 57.19837096429641, 53.971719434184415, 51.640152777394945, 49.70865611107119, 47.69417778138192, 49.75406931292627, 53.57561495996291, 44.41121278270599, 39.14415213369554, 50.019986398758434, 52.25562364824357, 53.61703126661239, 50.43005843316355, 52.54325105297951, 54.29463248099051, 51.43079234707741, 48.94366448925388, 50.939491948773785, 52.29440412213726, 57.9446489580216, 60.70053369768205, 64.8490010538409, 62.49348440477925, 54.81263637542725, 60.99527628191056, 45.361226527921616, 37.643084602971236, 49.49899758062055, 55.35859892445227, 49.98918010342506, 56.06138567770682, 59.35441155587474, 57.3574544537452, 56.12233931018461, 51.763523086424804, 48.65115373365341, 48.3697001395687, 50.71219451965825, 50.00347322033298, 50.39108576313142, 50.39843628483434, 43.74440593104209, 41.39591424695907, 45.053849989368075, 47.60624608685894, 47.47187745186591, 46.09051281406034, 47.1692705154419, 47.030814770729314, 48.05514174122965, 47.71211085780975, 49.57407566808885, 55.67815834476102, 58.51655406336631, 59.14755752009731, 57.518271630810155, 61.334365183307284, 57.21562547068442, 60.06269354974071, 56.74168548276348, 51.92150831222535, 55.37774401326334, 61.22922212846818, 59.78702937403033, 58.077840881962935, 63.09164193368728, 60.80498249300065, 63.90734587946246, 61.525941587263546, 66.88744114291283, 60.72289513003442, 46.91244156129899, 33.41121981220861, 59.198391437530525, 66.7751750638408, 63.29974720554968, 59.329782993562766, 59.80461335951283, 50.97475013425274, 51.52967922149166, 51.3838533432253, 51.758223964322, 56.47393272769067, 65.22156738465833, 66.48175824073054, 72.46120760517736, 63.95181379010601, 85.2385716284475, 38.62941557361234, 3.6154792722194427, 1.1338276560268095, 0.2523878658370626, 1.116190105676651, 4.898036218458607, 68.54224989491125, 66.93811816553917, 70.37239643835252, 53.876539199583, 77.00636386871338, 73.16426892434397, 21.750658519806404, 27.619751999455115, 54.74097859474921, 34.16623292430755, 66.09771897715908, 61.46987130565029, 64.50083186549526, 1.4977272648003794, 0.2431876708062426, 0.04903059625517457, 0.03008469221963277, 0.07794727826671255, 0.04823340133072869, 0.11705111021236067, 0.19721004601207473, 0.22110835799286443, 0.1574683922433084, 0.1618832190551104, 0.23909063258719063, 0.10483097360138932, 0.18704375282170313, 0.33089402822717545, 5.4714063290626775, 90.07956873986029, 69.78991662302326, 67.72518880905645, 36.441293916394635, 63.96996651926349, 37.91905864592522, 26.34535235743369, 43.13253579601165, 76.4960007513723, 68.82412710497456, 75.68280712250741, 66.6202179078133, 78.77507040577551, 22.884354899006507, 0.24042339574906135, 0.9794402855538553, 0.30009514862491243, 1.099955415533435, 0.8054178364334569, 8.458589315414429, 58.47117616284279, 61.48071665917674, 71.0706175527265, 67.01844046192785, 67.79802722315635, 61.62798989203669, 50.1786345051181, 55.91563040210355, 56.33361777951641, 53.28873672792989, 58.73242955054007, 63.31458160954138, 66.13388323014783, 70.68980247743669, 52.50280749413275, 38.710957727124615, 58.33392066340293, 62.08438904054704, 64.73369121551514, 63.67590250507478, 68.36193853808989, 64.02444039621662, 62.173089519623794, 59.50385778181015, 56.612725796238074, 56.5192674821423, 62.66362113337364, 62.25889136714321, 60.92123762253792, 64.05445829514535, 62.07752489274549, 60.66087853523993, 63.1349802017212, 62.43626486870551, 59.0768999438132, 55.542558085533884, 52.997500742635424, 51.72404050827027, 54.59581951941214, 58.81026506423951, 49.43643185400194, 46.8287617160428, 55.653678832515595, 56.51777698147682, 59.73015108416158, 55.49820392362533, 58.29222586847121, 59.28994740209272, 57.19792773646694, 53.82262622156451, 56.6161225688073, 58.307483888441524, 61.871380805969245, 67.45180745278635, 67.08923924353816, 68.61998342698621, 59.10771408388692, 63.99543446879234, 46.476576020640714, 37.760716484438994, 52.275459074204974, 59.17228414166359, 52.72698271659113, 58.916027853565836, 62.47209964259979, 59.076268442215465, 59.42182533202633, 55.78100289067915, 51.9367035742729, 53.76668145579677, 56.77610428102555, 55.56899878286547, 54.200770162766986, 55.07336416552144, 49.45591426664784, 46.420984268188484, 51.83351385977961, 51.90234361156341, 49.98644621141496, 49.534616624155355, 52.85418910364951, 50.19945444599275, 53.24595935883061, 51.343829477986986, 53.06717772637644, 60.95452677819037, 62.1723521140314, 62.02644386599141, 60.94933356008222, 66.34931548949211, 58.699414960799686, 62.86374438193537, 59.27837248771422, 54.63102671407885, 59.986827065867764, 63.601424540242846, 63.77517377176593, 61.32373948251048, 63.823364011703006, 62.90196395689442, 68.00766221938595, 63.73567942650088, 66.36550703356343, 63.84510178719798, 44.94762043799124, 33.44792535228114, 63.97957240381549, 66.29814424822408, 66.8847974654167, 63.39645324214813, 65.01658431945309, 54.40120327857233, 55.576157108429946, 54.9869151269236, 53.878280731939505, 60.686115064928615, 68.47278471915953, 67.64038716593097, 75.30453374308925, 67.0895294989309, 85.11009831582346, 40.97491841162405, 5.905037589611546, 2.206315326113855, 0.4336539367514272, 3.3821531601490515, 5.829184343737941, 72.60774735481509, 74.65353012084961, 71.5428787662137, 68.46295525950771, 84.31536336098948, 78.54050482473066, 28.528188620844197, 36.988150765818936, 62.52416910663728, 47.890186463632894, 84.11359663932555, 70.87274182227351, 83.44462071695636, 2.3137311493196795, 0.44778902504232626, 0.17153558982235773, 0.18177150508328793, 0.16586131446303862, 0.16784968034875009], [0.06221942040288161, 0.05786511453709776, 0.02637006977062312, 0.05816978004370486, 0.07583027855763513, 0.05544847102775689, 0.04657483246598033, 0.07471313850293237, 0.05602361153691046, 0.3329357751194508, 58.48226078094975, 56.22377964758105, 48.241968154907234, 37.24773322382281, 39.56808974665981, 38.46173424874583, 11.566768596249243, 42.16110590965518, 73.90855435402163, 54.43573974793958, 61.779103125295336, 56.30792625488774, 62.97126831546907, 28.693053683926983, 0.07805815417199366, 0.1251064251447397, 0.09437188926723697, 0.688087425885662, 0.26208287705817535, 3.3707851507971367, 44.88452126902919, 57.51551420457902, 69.46806261616369, 59.308641418333984, 55.388071613927046, 48.92791617301203, 49.77130812983359, 52.22041253120669, 57.12432446018342, 58.87672570443923, 60.37136447045111, 59.37661609342022, 60.74438971857871, 54.09806682217506, 67.31205340354674, 53.25632226082587, 46.01565830169186, 55.050355542090635, 61.455578188742365, 66.3149319925616, 61.26527655509211, 62.51004465164677, 59.637536079652854, 54.44798538761755, 49.78201227803385, 53.045012412532685, 57.78291394633632, 56.81284904479981, 56.25748457447175, 54.30810974490259, 50.75325389062205, 53.218243891193026, 53.53715219805318, 52.43634685393303, 55.02387169868716, 51.70903351999099, 51.01737060854512, 44.252317567025464, 44.43055399002568, 43.50159552789504, 46.75910826652281, 43.59369670191119, 40.78061203802786, 43.42015927837741, 47.69641353238014, 50.62829109930223, 45.03375176460513, 33.23218322569324, 45.21040747242589, 48.01760465868058, 47.55801662322014, 46.70524627931657, 50.18547511869862, 53.940124742446415, 59.82731211570002, 57.35955684415756, 59.28735863777899, 56.97692571147796, 52.775541659324404, 40.54056298348212, 51.96090459823609, 59.44926623375186, 61.46488989553144, 60.67889790381155, 61.88863531235726, 58.572483139653365, 56.17125126623339, 51.96411701940721, 45.19454540744905, 51.190543251652876, 49.37578808876776, 48.68233265415315, 46.66354756201468, 49.95134099837273, 48.91428201429306, 45.160569837016446, 42.4775392009366, 41.25546201582878, 41.24938626443186, 41.51171438155636, 43.655089639848285, 43.32242950316399, 45.123275941418065, 47.830048684150945, 51.51274634945778, 50.90042121948735, 53.728705067788404, 52.277706592313706, 54.07002579781317, 54.493763369898645, 56.84278457395492, 55.82413719546411, 55.75251863848779, 48.156142773166785, 51.20666811543127, 55.05617633942635, 58.624929151227406, 54.52504427202287, 61.99510020594444, 59.42970537370252, 64.74730576238325, 57.96024430182673, 85.2356533850393, 55.890774342321585, 54.16250351936587, 38.12228448929326, 37.39453184989191, 65.61076064263621, 62.864477865157596, 58.967214784314564, 56.802897991672644, 53.54380061549526, 49.664082296432994, 50.41666746139527, 48.46006762596869, 48.65537028158865, 52.221722602844245, 61.998979430044855, 68.90117814463954, 66.86555431735131, 69.99639018889397, 33.57832062628962, 1.521092946490934, 0.09914174420578827, 0.5969955267444734, 0.6147039861929032, 11.305555412846228, 65.77012654273742, 60.68086301126788, 52.040646383839274, 51.43503242923368, 77.9735654400241, 33.921657454582956, 15.658554761640488, 46.35932853144985, 43.735604132375414, 16.73028357567326, 35.86980065991802, 61.99697117651663, 42.77024999741585, 0.3029859354419093, 0.11431433771166111, 0.11301055565596589, 0.05762112319409367, 0.02646413004596628, 0.06852082682833557, 0.10145993392554023, 0.04643777933632655, 0.03692444586645692, 0.06080536382092584, 0.06495961348616308, 0.06003705807210458, 0.06305099352292957, 0.05555286199875897, 0.0573657516149744, 0.5528384026500487, 64.6059553084835, 64.56356625403127, 47.450418164653165, 47.92449935790032, 51.985552772398925, 37.04961430641913, 16.681997237666963, 44.86926324905888, 83.91953345268004, 57.52189982321955, 74.78242704945227, 61.532091863693736, 72.30934912158598, 32.47459703876127, 0.06771356167812502, 0.17544528890040614, 0.034955975284139, 1.1732603465357136, 0.15537916322148618, 3.3371841667159914, 51.26745308599165, 61.185895627544774, 71.9583675938268, 61.5920296022969, 58.75544994108139, 50.60714952407345, 53.84378740864416, 54.61106184990176, 59.72508730426912, 59.27217122047179, 62.52440052647745, 63.09233619320778, 63.57786286261774, 57.77460636631135, 62.5098132318066, 48.726698583172215, 49.57472285916729, 56.0709797951483, 62.35212610613916, 66.01362336066462, 64.634647446294, 64.76832574413669, 62.623550199693256, 57.056059529704434, 52.186244764635646, 53.323179060413, 60.11423349380494, 58.179053721889375, 58.04529305427306, 57.07482022623862, 54.30806659883069, 57.26051699730658, 55.452378872902166, 53.604260029331336, 57.29672047399706, 55.47490896717195, 53.55782701123146, 48.712040685838275, 49.503453393136304, 46.613298077737134, 49.20403926603256, 49.10619574208414, 44.26843458606351, 46.78830639008553, 49.28822117467081, 53.54882124931582, 50.409599350344756, 39.66998115662606, 48.18708635145619, 52.33256878391389, 52.95450764317667, 50.97136120642386, 53.730556426509736, 56.62337503125591, 60.985678242098906, 58.358992453544374, 59.43348261617846, 57.524041437333636, 52.17721939086915, 41.28724890370523, 52.301668351696385, 60.10139949860112, 61.26385665708973, 62.12162017822266, 63.62814372585666, 59.6364378160046, 57.68639618350614, 55.67856234888877, 48.725325753611905, 53.77566368349137, 52.40728601332634, 52.86598759312784, 49.86244440078736, 54.14238176038189, 51.638171980457926, 48.56627364312449, 45.3782025460274, 44.47682226857832, 44.23452961829401, 46.21331437941521, 47.67996703424762, 44.99282967659735, 47.996012010881984, 51.50799243680893, 53.10133764820715, 54.191682031077725, 56.79295086091565, 53.54686398659983, 57.5113094237543, 57.4861317296182, 61.01087554808586, 56.84736590231619, 56.76818893801782, 51.04635692411854, 53.70111511599634, 58.283451526395744, 63.358139530304946, 56.61465167999268, 63.11183429533436, 60.649570342033144, 66.76252934240526, 58.135676230153734, 78.95758613463371, 55.35027173257644, 56.51995781929263, 44.49042112596574, 39.378494139640566, 69.27512122738746, 65.25269531434583, 62.942905656753055, 60.50592922395276, 56.69299317944435, 51.85044280944332, 51.66627968511274, 51.692567410007605, 50.50962763447916, 54.50135707855225, 63.27365559916343, 70.68639001538678, 69.16103516855549, 74.06100903787922, 37.37640657732564, 1.8170973081742565, 0.2119873458098981, 0.6077498077384887, 0.7328658166431612, 13.990858081848392, 70.43029846683626, 66.41751766204834, 60.88089212294548, 52.999497229053134, 86.91655374342396, 35.73360812279486, 22.836417651945546, 46.61339221462127, 54.35135387605237, 19.690464965758785, 42.21050031723515, 69.8099442451231, 51.18254553887152, 0.28519369661808014, 0.1276465658579142, 0.010712006347133748, 0.11137282821319758, 0.1041145434963607, 0.017908506072877396, 0.19563487730920318, 0.1663286280968497, 0.17008656515709816, 0.1751317904000321, 0.21172823955214795, 0.28269566775810334, 0.20931887770852736, 0.21098655918913506, 0.14661819704117315, 0.8692143292677018, 79.2596164826424, 72.43677123900383, 67.05573435752623, 47.55722038207516, 57.5449162913907, 51.63995273651616, 23.66694031223174, 52.95493125915528, 89.75204298573156, 67.49131356516193, 76.64937326985022, 65.49194812774658, 75.90147141487368, 35.75732277285668, 0.1760578681264193, 0.9664696815513796, 0.2652932451136651, 2.77563730555196, 0.4014217066428354, 4.797571570642533, 51.96383460875481, 64.3635606765747, 75.11766418333977, 64.40265494008219, 61.00677667125579, 54.20864235970282, 55.64127237566056, 57.15933161397135, 61.2780713265942, 63.249874268808675, 64.43700705805134, 67.89026568012854, 65.40971955945416, 62.73266269314674, 69.62545948643839, 47.60492032574069, 51.095006081365774, 58.70308629928097, 64.55670210622972, 69.40565770672214, 66.2560336820541, 67.28178839529714, 66.33995671426096, 59.305327015538374, 54.332020513473026, 57.01766737045781, 63.16658666056972, 61.02187779641921, 61.26184448119133, 62.942854665940814, 60.45329493861045, 61.72957143475933, 59.81120686377249, 58.13004370658629, 61.98882441366873, 59.946140320070334, 58.87938899378623, 51.92728596348917, 53.573743989390714, 52.88499539898288, 57.278426539513376, 54.784701255060014, 49.96315517733174, 53.009730692832704, 55.93091195629489, 58.17506859379431, 57.30107430488833, 46.22467356343424, 54.90501211535547, 59.61949709923037, 59.69896824129167, 56.67374218663862, 61.16826849599039, 62.42485469387424, 66.85432064917781, 59.73882736698274, 62.62370709450015, 59.23468120636479, 55.58682987766882, 42.20233394253639, 57.87184976762342, 64.24139845755793, 65.2822817525556, 64.83292718087473, 65.08958747310024, 63.10353456004974, 60.65108829928983, 61.06978954807405, 55.16753635098858, 59.72804084900887, 57.647396056882805, 56.19282430218112, 53.34772133058118, 59.544885773812574, 56.119844682755016, 54.965098904025176, 51.603639433460856, 48.155574029491795, 50.07784135880009, 50.86850881576539, 52.84659539499591, 51.13528490066529, 53.87399358134116, 56.96520959177325, 58.05495385200747, 58.3386706536816, 62.3213041213251, 56.681559470392045, 62.048111038823286, 60.3514035286442, 62.26906599537019, 60.2615616398473, 61.69354446472661, 54.65320379503312, 55.791365792674405, 61.33154107678322, 65.23038095043552, 58.442746823833836, 66.32994682558122, 62.21701222081339, 69.30473512218845, 58.12120268421789, 78.09104827142532, 56.98997543704126, 54.86787511456398, 39.551054893001435, 43.291427089322, 72.71061543495425, 67.79834885751048, 63.22413567573794, 63.38729843016594, 59.53568781575849, 55.336335551354196, 54.56909641142815, 55.344144990367276, 52.7934786581224, 56.79420209700062, 67.7965602567119, 71.6946509576613, 73.27076127452236, 75.48477449724751, 38.86536575132801, 3.150855648902155, 0.6179772653887349, 1.0545971268607726, 1.7960181231460266, 13.430166052233789, 77.67089966804751, 71.29346309169647, 67.37867093855336, 64.56926938026183, 90.45767737973122, 47.1663522720337, 27.5139872489437, 58.83769027648434, 61.40013940872685, 25.996328092390492, 53.90006949824672, 79.45309131376206, 66.13896662189116, 0.777860795778613, 0.29563427992886115, 0.1676473871714646, 0.19770095515395367, 0.19474952481687072, 0.15837015433897897], [0.051973909890699777, 0.05227951768545374, 0.05167853320017458, 0.04480357589800993, 0.10907129324491947, 0.003813614654767838, 0.03101300692275888, 0.0149361462137031, 0.05376444123084507, 0.0422548933044797, 53.45927746065202, 60.798271317635816, 42.963932714154645, 27.630773859639323, 31.456471335503366, 44.50493781797348, 15.67184179059921, 16.602949711584277, 67.02765803183279, 54.65511398930704, 47.19751158068257, 60.54869874831169, 55.01743116686421, 30.521088031030473, 0.15777648216293705, 0.11049833884763141, 0.05065985459593996, 0.20339214573464087, 0.18300305270860273, 1.6347941227497595, 39.55434183920584, 66.1994731041693, 61.580729253830455, 60.28090284716699, 52.032338803814305, 48.29197837460426, 55.5680731035048, 61.05890889321605, 60.09669265439434, 60.87944869072207, 59.40132702550581, 63.496877685669936, 62.441740497466064, 53.96755387706142, 22.462111749956687, 47.35714420195549, 59.007670110271825, 59.77974161025017, 62.5628319094258, 61.82118231250394, 59.97414996547084, 61.935672375463675, 55.669454605348655, 53.997712981316354, 50.74155738276821, 49.346844919266246, 52.550597652312256, 56.57710675270327, 55.08332306338895, 57.99545541886361, 50.10498023802235, 49.49602834640011, 55.12203293461954, 53.97249606347854, 50.661227241639175, 53.29520079397386, 54.6204637712048, 47.80578882463517, 45.30587796242007, 45.997297686915246, 42.26580573666481, 40.8795302914035, 43.51778707196636, 42.6190387049029, 44.368537395231186, 39.6766060398471, 37.54921836237754, 30.70666909217835, 44.5689195202243, 48.63066327187323, 43.613500748911214, 45.874731463770715, 46.11783212231052, 46.94671130949452, 51.66330652852213, 50.55148324658794, 51.41902915893063, 52.96124235276253, 50.65603402353103, 46.38246659309634, 50.93630698419387, 53.91710042953492, 53.501945003386474, 58.47962102582378, 57.1116905058584, 56.64587766893449, 53.00715761799967, 48.46222100719329, 45.654768866877404, 35.17401925979122, 30.878967046737674, 36.442592220921675, 40.49216878029608, 43.79763641665059, 43.49102866265082, 41.50289297103882, 38.65179661781558, 39.40529961739817, 40.30079241721861, 43.446733336294855, 42.219419787007, 43.99845392473283, 47.75884197604272, 53.04523206526234, 50.18798935797907, 51.45906479127946, 52.365222515598425, 49.16913017149895, 53.42786712031211, 55.50218512935024, 57.30044672566076, 55.12965409986435, 50.852380029616825, 48.05114092365388, 51.68627200588104, 56.43554056844404, 58.675959187169234, 58.883491792986476, 56.32794995461741, 60.23523076888054, 61.36805049834713, 61.346630434836115, 69.14859341036889, 51.282820932326786, 54.68758336959347, 53.55066084092664, 33.37997813378611, 48.32819361840525, 64.79458601244035, 59.15456287322506, 62.08527941857616, 59.125137252192346, 58.68213299782046, 49.536040444527906, 52.06928360846735, 49.29169639464348, 53.78948219360844, 54.52937064632293, 66.3549715472806, 59.9399115962367, 72.9500682892338, 30.637933477278683, 1.1737915825459266, 0.17145835283783176, 0.47945805795250407, 0.366315359790479, 24.01074782494576, 66.38582491105603, 57.20276794125957, 48.88191853800128, 68.33835724861392, 58.51380840424569, 13.75698381854642, 40.17984221058507, 33.331211305433705, 42.45751550120693, 29.232150123965358, 53.29198837280274, 56.25988114264704, 32.26484829379667, 0.3306391354530089, 0.27322167290314553, 0.06572089037827908, 0.14671622565196407, 0.08309204897452747, 0.05370290521832724, 0.06045436531665826, 0.10170065407310763, 0.005381252473941254, 0.0721448670411783, 0.12285832480918016, 0.0783404728938495, 0.051296163395407705, 0.06566969272229942, 0.06820000452740539, 0.15359817733687742, 58.41462735206851, 70.59222959703015, 45.45551246212375, 31.52510104640838, 46.44307897936913, 44.451205268982925, 22.29993154925685, 20.18323233050685, 75.36259266637987, 58.24969953106296, 54.22046438340218, 67.45438837235974, 60.532295396251065, 34.75471788837064, 0.5427188101795413, 0.34631228314772733, 0.0428926078752885, 0.50708306592799, 0.6982247915960128, 1.8347332650615324, 43.60568346515779, 70.64821750886979, 66.3515277062693, 62.29821705049085, 54.75070607277655, 52.53421391210249, 57.9636057730644, 63.14986559652514, 62.968326537839836, 63.83551943686701, 62.16150283813477, 65.83201762168639, 64.06017318848642, 55.559439966755534, 26.12327756420259, 47.2763826001075, 59.897024400772594, 60.78465677076771, 62.17621564865113, 65.52535495450421, 62.17902798806468, 63.12904173328031, 57.819278240203865, 56.09730674374489, 52.65368538518106, 50.97353027712915, 53.302912173732636, 58.83041035744452, 56.58995643738778, 59.59704152999386, 52.14139638408538, 53.40659610686764, 58.353336395755896, 56.84415740351523, 53.31224349237258, 55.55670607474543, 57.09276506977697, 52.71544702591435, 48.22152476156912, 50.676438193167414, 46.39344530720865, 47.76093652171474, 49.17632772076515, 48.536702894395404, 49.853399415169996, 46.38706753330846, 43.67395624037712, 35.214819754323656, 50.12795748249177, 50.669785853355165, 48.13743698981501, 48.683662337641564, 49.65215044636881, 51.75296014355075, 54.09506228662307, 53.46312530579106, 54.03617182085591, 54.52136116643106, 51.55837135930216, 45.464561370111284, 53.45555513135849, 58.14063018368137, 57.510391589133974, 61.88517185949511, 59.38436669688071, 59.531796824547556, 54.99126895781487, 53.97022501114876, 49.555848413898104, 41.60680832401399, 40.15440564001761, 43.124491014788234, 43.607989818819114, 46.43885066432338, 47.57248232441564, 45.5674922081732, 42.045301852687714, 42.91211035943801, 43.85970007988715, 46.25408741735643, 47.366875602353005, 46.7520833015442, 53.01200174516248, 56.753903665850245, 54.314534587244836, 53.780437207991085, 54.884321612696496, 51.81761257110104, 57.19803364046159, 59.08816891331827, 58.407378811990064, 55.485770010179095, 53.724743473914366, 49.83629395884853, 52.38841156805716, 59.53613496595814, 61.91455433445593, 62.31063919682657, 59.05306370027604, 63.484565365699034, 63.1518542382025, 58.66402341473488, 62.94238398152014, 54.939289708291334, 52.31316874104162, 63.806717472691695, 41.866037768702355, 48.64089281328263, 70.29078760454732, 61.46100674906085, 65.30784776133876, 61.9258350710715, 60.50507806962537, 54.029927407541585, 56.65703681207473, 50.52395605271863, 55.56443314398489, 56.57575353499382, 68.98831752038771, 62.605919145768695, 75.562633545168, 34.98517674784507, 1.92817919917645, 0.19508142474918597, 0.6747801722057405, 1.2532173722021043, 28.35098574238439, 72.84479971854918, 61.52290567275017, 49.41054028849448, 74.38679325965144, 60.5579359300675, 18.179740559670236, 46.32156002906061, 39.890163406249016, 47.5204050156378, 20.55915032663653, 58.740670450272106, 67.10937669200283, 38.6978687778596, 0.44198348817806093, 0.2669964424304424, 0.10920316762020511, 0.15551548090673264, 0.021843106838904565, 0.06857082938715335, 0.22906090223020126, 0.09420749445956561, 0.1649454869930783, 0.15770056284964085, 0.22602359343680645, 0.1586653586597212, 0.19252339588297954, 0.28873461629113845, 0.17852424223336483, 0.2074787038708887, 71.56832710389169, 75.64565443223523, 62.775789153191354, 39.23074629998977, 44.78505388382943, 60.834588543061294, 25.854775636426865, 29.13908208570173, 81.44725568832891, 69.30819465268043, 58.0533064565351, 72.86614525702693, 68.0850584276261, 40.09384032218687, 0.5887031459039258, 0.39198169544819866, 0.17504961980927378, 0.9595501915581766, 1.830799495500903, 2.5532398973741843, 44.43322512411302, 74.31775169987833, 69.42796030352193, 64.37182511052778, 57.622920467007546, 55.96551510595507, 62.66773177731422, 66.77353551310878, 64.54135387174546, 65.70832960067257, 64.6676581136642, 70.36233163649037, 63.77783313874276, 57.17282456736411, 35.402622838174146, 50.076339091024096, 61.29846765149025, 63.474520175687736, 66.10537544373544, 68.74902156091505, 64.09676890219411, 66.28601627965128, 57.9940825893033, 59.545968347980136, 54.48529889506679, 56.46065550465738, 54.80789422988892, 61.393604740019775, 59.13463331037953, 63.69629098523048, 57.95028540395922, 59.6955204779102, 62.39549967550463, 61.744229332093276, 56.46308345179404, 59.40772441125686, 62.09620714187623, 58.02253938490345, 54.125876426696784, 59.42404931591403, 51.442814411655554, 53.28270020023469, 52.82351224653183, 54.56684497094924, 55.36617694362518, 53.07867811572168, 52.39994725873394, 41.66366307966171, 57.46617863255163, 56.30763992186516, 52.400429710265136, 53.08529515420237, 54.57945146868306, 54.9351006169473, 60.38457501319147, 57.979126591836255, 57.57541271948046, 59.90566538226221, 54.97104129483623, 48.932807368616906, 54.389020396817116, 62.00875397651427, 59.31056337971842, 64.01142989435505, 62.84783917088663, 64.35546490453905, 58.01438869968538, 56.93274021148682, 57.80578920918127, 49.73335527604627, 45.87992075950869, 49.98218259503765, 51.17222970531833, 55.29555074630245, 54.227191248247706, 53.109213767513154, 49.576421245451904, 48.158178483286214, 48.670785196365856, 50.690805835108605, 50.977715446103005, 53.286599036185976, 56.27928903025966, 62.09709359753517, 60.00670956027124, 57.89192445816533, 60.58804796588037, 54.58128321555353, 59.18971907707953, 62.67055980620846, 60.924034272470784, 57.440738139613984, 55.2903300716031, 53.00380399150234, 55.68095891706405, 62.28512810122583, 64.35803797937209, 66.81806225930491, 61.0059255169284, 63.35049090846893, 66.72152488462388, 60.07372717703543, 70.35093322876962, 56.96398581227949, 53.75682846192391, 55.784874270039225, 39.55385546530447, 53.88158336762459, 69.72099273435532, 64.95556400668237, 66.98309990667528, 66.79812092934885, 63.92471413458548, 57.92076172367219, 58.303494837976274, 54.14797898261778, 60.0555822926183, 60.136689063041445, 71.32574419821464, 65.06791637789819, 78.80038538286763, 36.50924113488967, 2.7116465328201174, 0.3839912451803685, 1.1122829346887528, 1.8722346785568424, 30.680820672742783, 79.93352674668836, 67.44106800325456, 58.0012095359064, 79.07684972209316, 71.33021570021107, 25.821172691160633, 52.192897104447894, 45.14647283861714, 56.74924781245571, 39.678492699899984, 72.96119213104248, 75.80756987294843, 50.70877029049782, 0.46839495159445277, 0.47032187722863694, 0.23981751213150643, 0.2059954657189308, 0.15896992457489814, 0.1242497549842923], [0.05145919073613421, 0.10307860110075244, 0.06174810779010577, 0.11255425836650595, 0.1295498346969966, 0.06120776682491265, 0.03804989797513812, 0.08166660449557728, 0.17571643806032597, 0.23601017772190033, 37.113266529575476, 67.79386166603335, 47.37963507252355, 51.729900529307706, 41.80821810999225, 39.04572025422127, 14.69311825690731, 27.871297520975915, 59.30821780235537, 66.16545831003498, 41.948599738459436, 56.74905953868743, 58.99205515461584, 37.8276321195787, 1.1060442823556162, 0.09314607964047501, 0.12697718121231566, 0.29497522980936114, 0.4011609303134103, 0.5917302350844107, 35.357680320739746, 70.59069987266295, 61.23590976961198, 59.51904519911736, 49.05686409242692, 52.652791084781775, 61.464987954785755, 63.37178153376426, 59.78466418481643, 60.74670783935055, 64.69429100713423, 62.20762598899103, 53.517136343063854, 53.294679118740945, 44.19349378155124, 49.63592360096593, 61.096269469107355, 60.85097620564123, 62.490001340066236, 59.91703633339175, 60.998461246490486, 60.268115920405236, 54.35247959629182, 55.07860837444183, 51.177854384145434, 47.76981676778486, 51.77465085060366, 56.83025260125437, 54.75338505160425, 55.607285038117446, 54.61521171754407, 54.22923872547766, 54.33893957445699, 49.547148596855905, 50.41177626579039, 56.64161405255718, 52.260020625206735, 53.69165043677054, 48.057981537234404, 48.67238944576633, 44.75865633256974, 44.927377085531916, 43.47590792563654, 43.81535768508912, 44.02918569503292, 44.279750624010646, 40.705832050692656, 40.725800837239916, 40.87942046503867, 44.65652958039315, 44.52476932156471, 42.68045125469085, 45.064711032375214, 46.78183840167138, 49.478369835884344, 53.7914159221034, 54.89978359591577, 56.588583607827466, 56.69269507931125, 58.592165593178045, 55.5888577430479, 54.902501798445186, 54.83222076969763, 50.48711322969007, 51.949631706360854, 48.39103391093593, 49.096523177239206, 51.312544653492594, 45.832832705590036, 32.368904852098034, 25.269375616504302, 39.97707136215703, 44.221974111372425, 39.71205249909432, 40.617174717687796, 37.93088851436492, 38.617911261896936, 40.519068394937825, 43.84247695246051, 42.814298214450965, 43.745908198818086, 46.71605633151147, 52.10763262164209, 53.50894251177388, 51.89442042381533, 49.628020025068714, 56.45707830306023, 57.40203611312374, 55.88250206362817, 52.05477868357013, 53.0325431977549, 54.963478965144006, 50.493165446865945, 48.910041932136785, 49.6188416788655, 54.79366779327393, 57.97995421194262, 59.01177683184224, 61.65287340840986, 60.12177228927613, 58.248107048773, 57.052309743819706, 42.534947010778616, 46.833923555189564, 55.76273641278667, 60.53868885963195, 58.72363167424356, 33.80573180414016, 62.09861547716203, 62.1900341587682, 66.92434280149399, 56.266372665282226, 62.35000410387593, 55.721688808933386, 58.60189307120539, 48.601743636592744, 53.62236569004675, 54.300594483652425, 66.46557454139956, 61.25347022087344, 72.26051561294064, 25.530715296345374, 1.1090296963530204, 0.3524756137161486, 0.5312502900919607, 0.44432967841144533, 37.68723087926065, 63.037238659397254, 58.91102290922596, 66.45679627695392, 73.5300770113545, 28.684267574740996, 29.20826485080104, 66.98710072425105, 29.565569239277995, 42.06035198703889, 39.02706546168174, 48.549199565764404, 61.96456847652313, 15.537977180173321, 0.7654797117556296, 0.4152565497544504, 0.09682381495593056, 0.1468986005432183, 0.11289807096604379, 0.11001181172867937, 0.10437484485127273, 0.05471973755066434, 0.04321077185112142, 0.11430931217487782, 0.03921200356055652, 0.038726089311943906, 0.03821636505064465, 0.09306691977525912, 0.17721793974839872, 0.24055692487426344, 40.44615937817482, 78.23556407805413, 50.41405124049033, 44.81724085346345, 45.55035929526053, 45.52243986437398, 21.745802625533074, 33.756286405747936, 68.88495522160684, 70.05550815213111, 44.46277233862108, 65.10117415458926, 63.99126891166934, 42.91506782654793, 1.6975043641944088, 0.5716839817262466, 0.10442519981053569, 0.8695634815000719, 1.0820998059165094, 0.7196592575600071, 37.81191125992806, 74.97445060360816, 62.515602650180945, 62.80335949313257, 51.33499630035893, 54.9463225180103, 63.45503776304184, 65.86118436628773, 64.89189217167517, 64.949637305352, 64.41456717829551, 63.11401905552034, 55.88388273792883, 53.43210720246839, 45.338013941241854, 50.565580244987245, 63.4685464059153, 62.22907350909326, 62.645209527784786, 62.150500589801425, 61.715388144216234, 59.7193802556684, 56.366801031174205, 57.5187893836729, 54.73352216905164, 50.58419973619523, 52.00538427599015, 59.039362861264145, 57.91196384737569, 58.372128471251465, 57.85812147202031, 59.673261027182306, 56.88156504784861, 55.510571156778646, 52.996641743567686, 57.88187926815402, 53.984588730719786, 58.72445537197975, 52.078850269317634, 51.007717655551055, 51.74659413676108, 49.344656236710094, 48.043735488768554, 47.15337707150368, 48.34808395754907, 48.372951784441554, 47.152600442209554, 45.965404895044145, 48.0780876067377, 46.27023973772603, 48.17640965984714, 47.42249873376662, 47.62714447513704, 48.1009550248423, 49.9093363361974, 54.45146060759022, 56.35626162252119, 58.399279117584236, 56.95346209310717, 58.50427704472696, 57.43527035559378, 55.567708323078776, 57.240897301704656, 55.033132414663996, 54.80793345359064, 52.29806369350803, 52.55447687641267, 54.79419339087702, 51.37983683616885, 37.45479514521938, 30.06070963798031, 44.421595296552105, 47.515451062110166, 42.82521809301069, 44.35469535089309, 41.88113104912543, 42.94300294691517, 44.88657659099948, 45.81560173342305, 46.28051242520733, 48.27919537021268, 49.998511422065, 54.33356984969109, 56.747380764253684, 55.91469687800254, 52.87513848273985, 57.92386431847849, 58.91977763945057, 57.971317152823175, 55.13809504047517, 55.54992037434732, 55.503063740268836, 51.69794105714368, 51.004434631716826, 51.64417712919174, 55.985193637109575, 61.511719073018725, 62.60548768504974, 62.29311796926684, 61.074821949005134, 59.476565930151175, 56.078871603935, 42.94415612374583, 49.07469126486009, 56.45994555565619, 63.24426920183244, 72.01517920340262, 38.14658357251076, 61.254188014614975, 66.32546747884443, 67.193966527139, 59.64989546806582, 64.72575233828637, 57.67737865447999, 61.42763914600496, 51.26662938825546, 57.321662825922814, 58.51113334778817, 68.90398656168293, 65.07729084261003, 73.6825866083945, 27.334336811496367, 0.9503956247241268, 0.3777699983648716, 0.4978929526142536, 0.6439994335655244, 42.64267490756127, 67.88077354431152, 64.063009062121, 69.0865493589832, 79.6494451645882, 33.16594616059334, 32.8411562596598, 64.92835452479702, 33.980775417820105, 52.2936902507659, 32.99742544850996, 52.004148729385875, 70.64874310647288, 18.341075489597937, 0.8025229433851858, 0.4239128836460652, 0.1424818431898471, 0.05175161798815093, 0.1108258184526236, 0.060918867407787236, 0.19117357960391432, 0.2979550053996425, 0.23456228686676872, 0.2646726832514809, 0.17149379206520898, 0.22268009462183525, 0.133601704372033, 0.21916054880186436, 0.384104626193162, 0.29313272706443266, 50.51901386630151, 86.26399686259609, 61.04017565327307, 70.0407757297639, 56.86323188966321, 53.86668620571014, 22.97619131303603, 39.07316507831697, 71.07126866617511, 79.71934964579921, 53.3332948530874, 71.31580491219798, 68.67721865254065, 49.44100533762286, 2.134587678217119, 0.7294123535675388, 0.38000847663610215, 1.0539308142277504, 2.0671329623268497, 1.0905815636919391, 38.37136283997567, 78.5508285030242, 63.86901255576842, 65.40379678049396, 53.98071735135971, 58.63332694576633, 65.30827529968755, 67.7178696663149, 64.67804062751033, 66.53842864498016, 70.18767633745748, 66.33343773503458, 56.79789696970294, 53.86086540837442, 43.43946126199538, 53.996002827921224, 64.59804781021612, 64.96481687791886, 64.01835287770918, 66.14328907382104, 65.70530545326972, 62.18087542441584, 58.937851921204604, 59.117629835682536, 57.64667434077109, 54.00508311487014, 56.87244161482781, 61.617674058483495, 60.102509529359885, 61.306300624724365, 60.64363579596243, 67.41197970605666, 63.65159949948711, 57.38502479368641, 56.294476447566865, 61.65965910880797, 59.17130747149068, 61.63809391760058, 58.501186217031176, 57.17189888800345, 55.74463075207126, 56.91356374371437, 51.33148970142488, 52.200082886603575, 53.62206758991365, 54.800771205656, 51.23587408373433, 52.529954218095355, 51.96982014563776, 53.16778652129635, 53.25381586628576, 50.21463009618944, 53.88377597255092, 54.09797268529093, 55.70734470121322, 58.9130154732735, 60.979618180182676, 62.86435234931208, 61.50654154439127, 63.60615884104083, 64.0005413947567, 60.84266862561626, 60.810713075822406, 56.66630929516208, 56.58657535429924, 58.15029882615613, 59.11912425871819, 60.70552295254123, 56.893359614956765, 44.907980965029815, 37.170768476301625, 52.06181541565926, 51.827292980686316, 48.46276229427707, 50.12891454081382, 46.929048876608576, 48.80462038901545, 49.541657278614665, 50.47322411690989, 51.69816855461367, 51.34106028464533, 56.04934792364798, 57.70434887178483, 62.272368631055286, 59.870477799446356, 57.81068040478615, 61.93696675762054, 64.43808963221889, 62.32312410108505, 55.49938847941738, 57.868735405706595, 59.288390221134314, 55.98985733524446, 54.343630729183076, 53.889847801577666, 57.33264938477547, 62.736177136821134, 64.09273670565698, 65.69230671851867, 64.00532668636691, 59.345264588632894, 58.21976007953767, 53.28885439903506, 52.393428279507546, 58.062563250141764, 65.67248698203795, 61.36511264308807, 39.93340361502863, 66.34644431452598, 66.16574856542772, 71.02035630133845, 63.6178239699333, 70.5082045831988, 59.16855396762971, 64.40787169241136, 54.09066923203007, 58.439557936883745, 60.80919511856572, 72.122832575152, 66.29318637232628, 80.15941604491204, 31.122348154744795, 2.5043355409176122, 0.4335873177455318, 1.1834808174640903, 1.6842044649585601, 45.50049420325987, 74.65121592244795, 71.53326895929152, 76.43874199159684, 88.28947744061871, 41.13618273888865, 39.83880781358288, 74.22266560216104, 46.01610152952133, 61.08996622024044, 58.88064807461154, 63.31160845295076, 81.69649877855855, 27.640287568492276, 0.8392494436233275, 0.7432220996387544, 0.16527773932583872, 0.438574243697428, 0.20204035294873102, 0.23732836989145126], [0.10273897900216042, 0.10814791980890498, 0.09870891985032829, 0.03158958384677047, 0.07967560326740628, 0.011831451368878686, 0.046165546161993865, 0.10195003101421941, 0.16619001214783038, 0.47283118290285914, 18.10502529144287, 73.26011596187469, 43.49848116597822, 43.435499668121345, 41.591981764762636, 49.14542336617747, 11.598948701735466, 24.372868883994318, 70.30752828044277, 64.70436365373673, 56.9262683007025, 50.28946499670706, 59.19893664698447, 48.32585196341238, 4.176338738010776, 0.8315857451769614, 0.37297900706048936, 0.3296281751846114, 0.40251926549019357, 0.5764363009122111, 33.03968898711666, 70.67175172990369, 63.44962881457422, 60.440535468439904, 47.3652478187315, 60.282503174197295, 63.89685353925152, 61.602196385783536, 62.67525880567489, 56.121433242674804, 54.725885314326135, 54.03811339409121, 50.81840838155439, 50.57885354565036, 54.280908107757575, 62.42249342703051, 62.47113081716723, 61.20457003193518, 58.097080107658144, 57.568399521612356, 59.30612325668336, 56.481451911311, 54.45256279360864, 54.15974609313473, 53.04921719335741, 48.47541978282314, 50.82452727902321, 55.92802901421824, 55.71849599961312, 52.20590760630947, 56.07871863149828, 55.44912330565914, 54.838896643730905, 54.63882046361124, 53.85272256789669, 54.087084185692575, 56.072352624708614, 55.04890426512688, 53.98007016028128, 52.488577135147594, 51.381448930309666, 48.58124140770205, 45.37706113630726, 44.367395985511045, 47.343447285313765, 45.78865897270941, 44.137290139352125, 43.45397010926278, 44.126429096344985, 43.311776345775975, 44.86103411643736, 43.84724655459004, 47.76511384594826, 48.50348041903589, 55.36551406306606, 59.54352078899261, 59.739152923707046, 59.4199033706419, 57.51512588993196, 47.829550543139064, 57.016478892295595, 59.33323860168458, 55.46759374680058, 54.42614955286826, 52.238784913093816, 48.622136039118615, 47.36825235428349, 46.802897607126546, 48.03085050275249, 43.83445178308795, 42.040610697961625, 42.08494524801932, 40.26794648939564, 41.07542914728965, 37.31487635643252, 41.23617179932133, 40.16730239314418, 41.02350481094853, 43.204538745264855, 46.810138302464644, 49.80698600892098, 49.99864086028069, 52.609915656428186, 51.963916978528424, 52.38028049468995, 49.91192510051113, 50.91767180350519, 50.438895533161784, 54.83130685744747, 53.85009850225141, 54.7104900113998, 52.29028171108615, 50.785115303531775, 45.19131729679723, 52.494068453388834, 52.428211858195645, 57.89274031116117, 56.36214125540949, 60.01514657851189, 57.190341872553674, 63.6023659090842, 49.94841491022418, 30.720764129392563, 50.93677374624437, 60.73671364015149, 57.1880433636327, 69.25030046893706, 53.575430608564815, 39.76011330081571, 53.6997736653974, 64.62739106147521, 63.3447289466858, 64.06644898076212, 58.20121511336296, 58.73338660886211, 53.35953943191036, 56.96520566940308, 56.38385157431326, 65.83743833726453, 59.12673365685248, 66.78127042708859, 21.08724844071173, 0.3606460946461847, 0.2533461805433035, 0.4439649592724539, 2.048114982824172, 50.738835257868615, 58.683925520989206, 69.0070507603307, 53.106770130895804, 75.21275812579741, 31.249878137342392, 28.49433856625711, 78.92254367951425, 40.820847711255475, 32.59194454839153, 22.875407972643455, 56.522515204644975, 55.340238309675655, 5.926576304820276, 0.7362410161764391, 0.13485090266312325, 0.1702274946916488, 0.24427013772149242, 0.18092217404515515, 0.12665809027009434, 0.08628962336168175, 0.008280758329126383, 0.013859232478294403, 0.06936632742684695, 0.007296392803020295, 0.007616240735871778, 0.0927857501852897, 0.07795844782864855, 0.11816871758069723, 0.48598966230788543, 19.882527743616414, 86.32269905459496, 47.66335971893803, 39.58746233294087, 49.28233761941233, 48.43257573343093, 14.23136507311175, 32.58288387329348, 74.85182162254088, 72.49848581129505, 58.12164198967719, 58.4274927262337, 64.19311408073672, 54.21886013400171, 4.1825091165881005, 1.118592189684991, 0.32525693877570094, 0.4904599079201299, 0.7386923136730349, 0.5811595087570529, 33.565325813908736, 74.70656056557932, 64.91674038671678, 63.516085532403764, 49.525755989936094, 61.90028867413921, 65.86159229278564, 66.16572503120669, 64.3835961434149, 58.5364757814715, 58.315379619598396, 57.866774220620435, 51.40053910593833, 49.186435668699204, 54.522463352449485, 64.80535684093353, 63.68581433450023, 63.56178114491125, 59.56500361042639, 57.54268446276265, 58.55750360796529, 57.61813125302715, 56.17074135811099, 56.770593350933446, 52.35687178950156, 51.185444170428866, 53.58384409258443, 56.06252316505679, 56.7964143137778, 55.94252217200495, 57.8110687194332, 59.9342437713377, 57.84228294126449, 56.688509910337395, 57.4696969985962, 57.00815954516011, 58.1154485671751, 59.56264234358265, 55.91146484498055, 56.36570668989613, 54.01634816200503, 52.883187186333444, 50.44705014075003, 48.339917582850305, 50.649475820602916, 51.54942051056893, 48.83910978994062, 46.04403272751839, 47.333609980921594, 47.56093094425817, 48.875846708974535, 46.474716817179036, 50.67797576227496, 54.332969727054724, 58.59872379610616, 60.30431155235537, 62.54023513486309, 61.66203998750257, 58.00456316240373, 48.48743008029077, 59.817867048325084, 62.35028651452834, 58.88568047554263, 56.40332221984864, 52.835369571562744, 50.10100687703779, 51.589091362491736, 49.35009656413909, 54.64680640928207, 48.60829399478052, 48.94386845250284, 46.500322049663914, 46.53677263567525, 45.22826602382045, 40.358274752093905, 44.9853850180103, 45.1554472215714, 44.222080015367084, 48.56407319345782, 50.411152608932994, 52.79408270312894, 53.47051112882553, 57.04957977417977, 52.666127143367646, 55.671188292964814, 53.70578273650139, 55.336531669862815, 52.41006697377851, 58.213480364891794, 57.0087282888351, 57.82489899666079, 52.99793612572455, 53.982290221798806, 46.85188016583843, 55.19253753846692, 53.514873135474424, 60.137293108047984, 58.18630226196782, 62.01976799195813, 60.106561337747884, 66.50894026602468, 51.384445621121316, 31.863436852732015, 51.79247410066667, 64.07608232190533, 58.81358731177546, 73.92386728717436, 66.03489045173892, 43.64645258072884, 53.725406354473485, 63.058627343946895, 65.88450677933233, 68.26362825209095, 61.11593623315135, 62.04760113070088, 56.87389681416174, 59.06934545886133, 58.6867457051431, 69.19678365030597, 61.51222505877095, 70.80729315357824, 26.19404104448134, 0.9185722710624818, 0.1177914882259023, 0.4571393426627882, 1.8237094436922383, 57.029956156207675, 65.65957846180086, 76.93555724236273, 57.46373891830445, 83.38050565411969, 34.62775076589277, 34.28211150630828, 79.1343516688193, 40.65349586548344, 42.711912585842995, 24.337653844587265, 65.52272696648875, 66.13263591643303, 7.483940143739024, 0.5516313545165524, 0.1533178351218662, 0.11738578338296184, 0.2986841065989387, 0.1126222563306651, 0.1493909756743139, 0.18934989197840615, 0.22546441053911565, 0.1541509710612797, 0.20539454635112517, 0.18338769013362546, 0.19099665925868098, 0.22309146851541536, 0.2155539141066613, 0.3137011459517864, 0.5710611828873234, 25.92420747203212, 98.66128321616881, 59.2323277842614, 62.468200806648504, 53.03583406632947, 68.48780739691951, 19.448276258284046, 37.799708766321984, 79.93533103696763, 79.43571521389869, 66.03782438462781, 67.2427765015633, 71.2073435321931, 63.69145470280802, 6.24776792141699, 4.28924661490225, 0.7445964613749135, 0.9399550107698288, 1.5675648205703305, 1.2507517948266, 36.99516396368704, 75.60035105674498, 68.82852800430791, 65.72717266698038, 52.6006902417829, 64.1859910565038, 68.55302856814477, 68.32635479588663, 66.2841570761896, 63.23926033512239, 57.914407483993045, 56.807942159714244, 51.40517142511184, 49.089196189757324, 56.56213506575554, 68.12934198687154, 65.02855931558918, 66.75645751337852, 61.15925881170458, 61.207123494917354, 63.549566884194654, 62.49633596789453, 59.99358923204484, 60.00234396226945, 54.65465507199688, 55.47448927356351, 57.11094133315548, 58.35603498643445, 59.03076110347625, 57.33234343990203, 60.13657139193628, 62.79427920618365, 62.667163033639234, 61.38118651605422, 60.82622212748374, 60.151664672359345, 59.88460617680704, 64.87331582653907, 61.69172056259648, 63.27641694776474, 59.2439458447118, 60.95730773864254, 56.07638874361592, 54.83640986104166, 57.03852653503419, 56.05483531951905, 52.85476176969467, 52.79072123189127, 54.43510040160149, 52.77567501991026, 55.12368817483225, 52.28751644011467, 55.31812790901431, 57.25064046921269, 62.73088585945868, 66.09288661710679, 67.0725848597865, 66.93970280308878, 61.421543782757176, 47.624006578999186, 63.10779425405688, 64.1447316446612, 60.87701289884506, 58.88644141535605, 60.66675032338789, 54.881968190593106, 54.649469698629076, 54.89287237967215, 58.79355968967561, 54.87643372627997, 55.56425663732714, 50.47633455645654, 52.51118567682082, 48.901534311233036, 44.94009340963056, 50.41519265021048, 50.82581381643973, 50.35514900761266, 52.421022153669796, 56.974560522264056, 57.8905398614945, 58.409767535425004, 61.98700443390877, 60.88408885463592, 59.97424802472515, 57.17824528294226, 57.55473790630218, 55.89028404605005, 62.06356517730221, 60.60676943871283, 60.41198061358545, 55.123127275897616, 57.98800683790638, 49.31780369051042, 57.220057748979144, 57.893850341919936, 62.72234685959355, 61.57955254277876, 62.27256082719373, 62.705774845615515, 68.06343047849595, 56.99564718431043, 40.40858307192403, 54.31277736540764, 66.01884795773414, 62.53828571688745, 68.89165462986116, 60.64051751167544, 49.76285934448243, 59.757023242212114, 65.3884171670483, 67.14868668586978, 68.92802284609887, 64.05300701818159, 65.7264195719073, 57.438733808455936, 62.55323386961415, 60.20621307434575, 72.30808611839049, 65.29011472578972, 75.15367154152163, 31.40641796973444, 1.9306587499956933, 0.46348895517087757, 1.2419188623466801, 3.9749360613284574, 61.63093951440627, 71.36045717423963, 81.85962230928483, 65.31421769049861, 88.97355448815131, 41.81252487244145, 41.06503486633301, 81.28143356692406, 59.60008921161775, 45.420258199014974, 34.694415369341456, 76.66823202563872, 78.5476121594829, 12.193965392728007, 0.9353081052822452, 0.3872012148701376, 0.2937602450049693, 0.45837259100329497, 0.35994938364432705, 0.34457675692054535], [0.02163638950385634, 0.04985699828173365, 0.0010512773212300794, 0.06698491247070414, 0.06311429536811287, 0.03525968701128037, 0.10826287130194326, 0.17732447193514916, 0.22175377174731226, 0.44765456128985653, 6.119578000037901, 60.82516308753722, 48.04005630554692, 43.54166646157542, 33.00604681814871, 46.27986131175872, 28.944314833610292, 5.884528496573049, 51.97525262832642, 68.11824952402424, 58.498632754049, 56.413551761258034, 54.44730681757773, 59.250076509291134, 9.784945653330896, 0.7179229958884178, 0.3754153811643201, 0.44401959666321356, 0.238533380231069, 0.7154486544670597, 26.622616860174364, 73.65125471545805, 61.71190507950322, 59.448752403259284, 48.61187904111801, 57.57689537540559, 64.23104340030302, 63.9064202001018, 62.216412098177024, 59.49898227568596, 52.907862817087484, 38.95510173613025, 54.72501847051806, 34.78111151726016, 30.618160809240035, 69.05773562769737, 58.671052302083666, 65.81229594445998, 55.970947588643725, 57.79555966777187, 52.931518631596724, 56.0994012894169, 54.30862357539516, 56.7797952313577, 53.247606754302986, 51.02828264236451, 49.442817472642474, 56.142508137610655, 54.62278973671698, 53.70297039708784, 55.900846988924094, 56.14872509433378, 57.26417264630718, 58.55713882753926, 54.849145796991166, 55.30702367905648, 55.31332692792339, 59.20098020184425, 54.14976366104619, 53.04405927658082, 52.70910455334572, 51.725032867923865, 49.81384231198219, 48.473254634488015, 46.612564594514915, 45.91866593207083, 45.48123144334363, 43.515641535482104, 44.27755801908432, 44.71927965840986, 44.730077943494244, 50.36525695554672, 52.8078894461355, 61.26368407280215, 61.984447048556426, 60.25983579697148, 56.37621079721759, 54.54563671542753, 53.017002767132176, 45.97257891008931, 55.30956929729831, 56.490995037940245, 55.970786771466656, 59.18838154885077, 60.20048641389417, 48.84394607236309, 45.1845786648412, 42.47617421611663, 41.986556514616936, 40.44999153383317, 39.9056803026507, 38.21804915705035, 39.68562749124343, 42.1047963634614, 41.89021918081468, 41.33068915336363, 42.04283468184933, 44.006902710084, 45.20434348813949, 46.33474311520977, 49.23747747175155, 52.84851343401017, 51.38983888010825, 55.79021653821392, 51.059438028643214, 54.0182936576105, 53.23394513899281, 51.811678025030325, 53.64292283211985, 53.39626850620393, 52.36628547791512, 49.21440216802782, 48.546026368294996, 45.938289550042924, 51.14738149027671, 49.82226364074215, 57.03580833250477, 55.037894172053186, 58.956463567672245, 57.50986599153089, 61.68118507631364, 49.11582516085718, 36.53102597882671, 55.687815220125266, 58.789378443071925, 58.42666118375717, 62.27829925475582, 76.59617808557327, 61.98843609902167, 42.88588147009573, 45.46529485333351, 49.49047819260628, 61.20360512887279, 62.590049236051506, 63.78838039213612, 55.47851754773048, 54.888887251577074, 57.60233979071341, 65.69746071292509, 63.05748985659692, 58.92886969351, 12.103741072839307, 2.7407747891641434, 0.17433789348410023, 0.1485214199149801, 2.228139638900757, 65.60976436061244, 53.6173568233367, 68.62192107785133, 56.77968932736305, 80.16845318578905, 11.501125770230448, 40.87980485731556, 35.59977685251544, 28.92634253348074, 40.02215508491763, 33.44780768117597, 62.96871485248689, 46.36334896087647, 0.8096796754867801, 0.15221719660105246, 0.030090514487857302, 0.06240033972707968, 0.14144367147837916, 0.06707483587125618, 0.04342952825789971, 0.06536616102582024, 0.031051431977820974, 0.02586893718539467, 0.12706827672739185, 0.07732204326819028, 0.07242646564038531, 0.13217866540916506, 0.21095911791968733, 0.36569786227999196, 0.47581301160877754, 6.956647096141693, 71.65963988150321, 57.55962517953689, 41.4625592385569, 41.53131054293725, 51.321138566540135, 24.21126331052473, 11.814104433982603, 57.82736616749918, 75.9233582404352, 61.91938277213805, 64.5216243497787, 57.82066283687469, 67.4410758479949, 10.887962233635688, 0.6398124259806449, 0.22064236203028312, 0.49179942797749276, 0.5684155442060963, 0.6175513817898689, 28.952749890665856, 75.92042430754631, 64.59821647213352, 62.77749146184614, 53.18966550211753, 62.87622536382368, 63.203056858431914, 68.23202963798278, 65.00195780108052, 60.4100743416817, 48.90910056329543, 38.9364351764802, 56.81597517382715, 35.796930866856734, 32.510335714586326, 68.54631347040977, 59.11219735299388, 64.77626069899529, 59.12819670092676, 59.42312755892354, 55.890448785597286, 58.596515501699145, 55.75762556445215, 57.44198937569895, 53.73977791878485, 54.927130360757154, 49.667859538908935, 59.03279681359569, 57.2559239018348, 55.28725101101784, 59.78810410345755, 58.35821974662043, 60.30882227805353, 60.15810520418229, 57.95512168638168, 58.0539301133925, 58.46113489520166, 60.18309854692029, 60.58481593285838, 56.76758489301128, 58.108753081290956, 56.2439759315983, 55.271992991047526, 52.26627288326141, 49.52642671523556, 49.073808731571326, 48.84149459100539, 47.04342911320348, 49.18760453501056, 48.425437019717315, 50.072236291823856, 53.78824272463399, 57.031489802945046, 59.94733664297289, 63.0913124545928, 61.57936819138066, 57.705337309068256, 53.772506175502656, 57.731154349542436, 43.81382796072191, 56.81916406077724, 58.56362642780427, 58.71719898716096, 60.07110311139015, 62.29014481267622, 50.65894049982871, 48.12890975706039, 45.35028703751103, 45.14370364527549, 44.21821648074735, 44.449887352605025, 44.34085722892515, 46.50312262196695, 44.12800588915425, 45.18633588667839, 44.05695607585292, 45.835778405589444, 45.71932715754355, 53.25405513086627, 50.23425763653171, 55.583915556630785, 55.76873763915032, 54.048523364528535, 56.59815026867775, 56.50298572355702, 56.3645770472865, 55.630627063012895, 53.34379896040886, 54.911315364222375, 56.51333685844176, 56.50740231237104, 52.36834079988542, 49.92619468319801, 47.24686676456083, 54.19033273573845, 51.524717423223684, 58.90940297034479, 57.8381448407327, 61.35223942418253, 58.59054957666705, 63.69075259854717, 52.89957484891338, 40.55131812249461, 57.988144120862415, 60.62301589596657, 63.03555596259333, 61.750293316379675, 78.11004823254001, 68.47840155324629, 48.136832944808475, 47.914964076011415, 51.12022692157377, 60.97299329696163, 63.43102501284692, 66.12577176863148, 58.37124986033286, 58.16725915478122, 60.36536324408747, 67.23816379424065, 66.31869746792701, 62.43597069094258, 14.534596646985701, 4.105789762350821, 0.3062983770524302, 0.2693102731099052, 3.560183168418946, 73.06153420479068, 56.98755533464494, 75.3370423470774, 61.813474855115345, 86.43689493979178, 12.183442654148227, 54.71680110500705, 42.82542990099999, 36.573293439803585, 47.39251613616944, 32.4636398976849, 72.04690333335631, 52.91247160203996, 1.4639441356543572, 0.3124514420426661, 0.24880214534219236, 0.12867816453499178, 0.16299847453351946, 0.046966778369800705, 0.12612906825398246, 0.26027089525615016, 0.1584616712024135, 0.12104088846113413, 0.27419095798846216, 0.17472956359626787, 0.14396102107580633, 0.23443493241023636, 0.3541910071526805, 0.5571747667366459, 0.7365619763731958, 10.055855916392419, 88.32629280705606, 63.02509107897359, 66.37210446019327, 44.37743725315217, 62.8416379036442, 39.93785550517421, 17.710764331202355, 60.77773770978374, 83.82971902047434, 68.68846801019484, 70.99468831093081, 65.04764164647749, 76.89894583917435, 12.606170215914327, 2.037542969469101, 1.0987011150967692, 0.7568973819575002, 1.2256324459468166, 0.9744140133261682, 31.549733531090524, 78.29425842531266, 67.42124434440368, 65.3575716480132, 54.0287350070092, 64.36411765313917, 69.19175517174506, 72.27665224382955, 67.52634817554106, 59.421495852931855, 52.084180770381806, 42.44991787018315, 56.166250244263686, 37.05780029296875, 32.942002357975134, 70.9358762925671, 61.262644644706484, 67.90735152459914, 62.17521544425719, 63.79584858494421, 57.671824578315984, 61.05932466445431, 58.11611144773422, 61.166581876816295, 56.229349413225734, 57.03246255074778, 53.76115483622397, 62.943745043969926, 60.74887691005584, 56.67974733537244, 61.204805374145515, 62.2019777759429, 64.30719621719854, 63.92471413458548, 62.77527924506896, 63.850965730605594, 63.686932209999334, 65.79427657588836, 65.54325272960048, 62.461528854985396, 61.503180073153594, 61.250163662818174, 58.39606669641311, 61.28365678171958, 55.84052878041422, 52.53122898840135, 52.027828078116144, 53.82362642595845, 52.04055616932531, 54.113418979029504, 53.05750123916134, 60.697238906737304, 61.638313570330226, 66.10639525998023, 68.72874290712419, 63.59170490695585, 62.44459990532168, 59.66730294689056, 59.95155319090813, 47.52269567981843, 61.44348552150112, 59.64735377219416, 61.02355264848279, 66.92193446620819, 66.53670280210434, 56.0642921540045, 53.74748537617346, 50.595974691452525, 49.606356774607015, 49.02336705115534, 46.55900855218211, 47.9869278015629, 51.369485701284106, 49.209397223687944, 49.249028851909024, 48.13214179008238, 50.90455539764897, 51.50727072069722, 57.45325442283385, 54.59991839624221, 57.38180845014511, 60.490706505314, 57.97389022765621, 61.251210935654186, 59.798043389474195, 63.124021099459746, 58.32606415594778, 59.124670490141845, 58.42288001891106, 59.09358570652624, 59.52583874425581, 54.18859120338194, 50.789182801400464, 49.60832972680369, 56.53489812727898, 53.40696480966384, 60.15668138380974, 60.33367441546533, 62.9950104221221, 61.98758102232411, 66.11466361630347, 53.96232535762172, 41.02936483198597, 58.896647422544426, 63.59096750136345, 63.72561854700889, 65.2533228935734, 72.54222023871638, 62.14421695278537, 48.987371460084, 50.59830457933488, 55.44729548115885, 65.22803537307247, 67.93693404043874, 69.64977818150675, 63.138231846594046, 59.55186367034913, 61.8650108768094, 71.32474791619086, 68.57023208372055, 69.87488300569596, 20.939920294669367, 4.91108839550326, 0.5910829214319107, 0.9080528419825339, 3.8044119986795613, 81.10673119944911, 62.458481173361506, 80.46009709758144, 67.74454178348665, 94.17246003304759, 19.447379996699674, 56.900008032398844, 41.89548300158593, 44.83498173375284, 56.047555400479226, 52.03107187824865, 75.61746828017696, 72.92533382292717, 2.8781494305979822, 0.7896297449065793, 0.6599415394086993, 0.24007248151446545, 0.28977965215040796, 0.2866427059615812, 0.27392255142331123], [0.00736698062316845, 0.08871351789322593, 0.07792656324924001, 0.08000011811213148, 0.08979191688159782, 0.045339737853576104, 0.16007692162548343, 0.16139151318179024, 0.151906241512587, 0.09785864652404863, 1.8073215359641661, 56.60804248625233, 51.574759021882095, 35.01198614797285, 49.11750393529093, 36.11017134881789, 55.72196337484545, 22.465551668597808, 21.91742201005259, 68.22966052639869, 51.88486553007557, 69.28782970674577, 51.320997361213934, 60.258153100167554, 18.173860926781934, 0.5386797494945988, 0.1439972570346248, 0.39258154229291026, 0.5474745001523726, 0.8033865389804687, 21.65156375977301, 71.19423497107722, 59.61465297206756, 59.35327406852477, 47.25737871662263, 57.670200717064645, 64.34354482158538, 65.85836025976366, 55.08597850799561, 68.38798307603406, 37.30125396482406, 22.25758367969144, 61.24214241581579, 32.583462422893895, 27.152884044954856, 67.67675538216868, 61.070095492947495, 61.33624792099, 56.13501248821136, 57.87288135097873, 52.866713231609715, 55.931778800102975, 56.424028411988296, 54.95947422519807, 51.34258216427219, 52.44295212530321, 51.083933230369325, 56.17892342229044, 52.03134644416071, 51.446662256794596, 56.165555984743186, 52.066475191423976, 52.56972312927247, 56.08546510819466, 54.95781114024501, 54.847969085939475, 54.732263088226325, 57.002805509874904, 51.28643343525549, 50.54918081529679, 50.98698008445002, 51.690802343430065, 53.524761430678836, 50.79608225053357, 48.70926364775627, 49.56712522814351, 49.83319920878257, 47.13117253395819, 50.345190109745154, 46.69695438877229, 47.410676710067264, 53.66855552119594, 57.105493160986136, 62.805701148125436, 62.390106416517696, 63.90173689011605, 57.935356863083385, 56.22124187407955, 54.80717251377722, 46.38579668537263, 53.22915592501241, 54.41472761092648, 55.62846191467778, 58.738497457196644, 60.641776592500754, 57.879557225012014, 50.21985469325897, 47.383314255745184, 43.233846695192405, 42.00343447346842, 41.4701529472105, 40.12776097943706, 44.788642852537095, 42.87036065132388, 45.84899287069998, 42.283358343185924, 44.443740998545, 49.282259172008885, 49.71925043290662, 52.77027391618299, 55.13325091331236, 50.34573531919911, 49.284553758559696, 50.631138740047334, 52.61676019237888, 52.26703774544501, 51.70131821786204, 53.477414500328806, 53.1621696872096, 54.10243242017685, 52.74557475120791, 50.915675317087484, 45.93371214405183, 46.417505125845636, 52.1204666168459, 54.82869063654254, 56.52300157854634, 56.868185843190844, 57.25145239983836, 59.71774070493637, 60.44159058601626, 63.617384664474, 55.07896138775734, 60.76958702456567, 61.59701885715608, 58.70807555414016, 55.38519259422056, 61.806081187340524, 71.35170244401502, 68.04464232537055, 57.916066646575935, 56.38900556871968, 56.11183128049297, 60.68551494229225, 63.90907564470845, 60.79612185878139, 57.698888932504964, 63.70088408070227, 60.30234252252887, 61.75474128415508, 49.53464408074656, 5.842822915123356, 2.204791730450046, 0.35620682962959815, 0.457110844192005, 12.451579801497921, 65.43046105292537, 55.2482783409857, 68.44983885365149, 61.952997484514796, 61.87615040809878, 16.03518957091916, 31.119933935903738, 15.98220717522406, 33.849242656461655, 23.079936042908702, 37.28075958067371, 63.08860209680373, 31.052724123001102, 0.1844701723706338, 0.10232159131837469, 0.12334613129496576, 0.09306137329868733, 0.06503942452611462, 0.03037703520197782, 0.062062418343679565, 0.07351653980872325, 0.0636500015013641, 0.22020288803164037, 0.10774529463942013, 0.0796343187891668, 0.07372598824722153, 0.1696602065837191, 0.14597436142784936, 0.2943369866378846, 0.06680672808039574, 2.4511621748247454, 66.64972197624945, 57.34756615854079, 38.55302349213631, 47.63014508831886, 39.30682066948184, 42.50159509720341, 28.256842974693548, 29.061866306489517, 75.92795525827717, 56.116730320838194, 76.65967341392272, 55.53300319179412, 68.22009778791859, 19.92099835026649, 0.19755800314728292, 0.18515726130816246, 0.6288573073764002, 0.9928563850060587, 0.7389940910281674, 24.623969216500562, 74.59891503857028, 61.7759063936049, 59.40759497304117, 49.73996839215679, 60.629919267469845, 66.55097238479122, 68.7223808227047, 58.08323806332004, 67.07381648402061, 37.19466355539138, 23.835788542224517, 61.441277227094105, 37.999435855496316, 34.72644936653876, 67.19832035803026, 62.122792966904186, 61.727602404932824, 59.95785643977504, 61.24293081222042, 56.18084930604505, 57.47742014546549, 56.70486619395595, 55.791416783486646, 51.959990685985936, 52.189402272624356, 52.69576457238967, 57.80663644113849, 55.38122315560618, 54.177330078617224, 59.40700269514515, 54.69420433044434, 53.94375685722598, 59.21027621915264, 57.401455602338245, 57.23412729078724, 58.94787357699487, 57.96021684523552, 52.68848857572002, 55.624794498566665, 52.10420447011148, 56.68734496639621, 56.32883248790618, 53.4574378690412, 52.99220946527297, 56.62213556228146, 52.155458081153135, 52.57497910530337, 53.76236292623705, 53.02121931506742, 50.64175267373362, 56.409056725040564, 60.63337095322148, 66.45621576616841, 64.21965283732261, 65.55456092280727, 57.84483640424667, 55.19594215577649, 56.42896667603524, 46.88375726822884, 55.571971939456084, 58.0828615157835, 56.503934937138716, 61.29513363684378, 63.37955959381596, 58.80247523707729, 51.12335697297127, 49.810986826496745, 47.312731204494355, 47.019008436510646, 41.90567724166378, 43.11813285273891, 50.58912231076149, 47.70633320654593, 50.407602863927046, 46.89599898553664, 49.89529032861033, 52.16626813334804, 51.74827683356501, 55.51082611083985, 58.713182480104514, 55.0616676576676, 53.63850232093565, 54.198024503646366, 54.62764170862014, 55.81094626457461, 56.09057987889936, 54.24486544824416, 55.8785169355331, 55.77887304367558, 52.97367626620878, 52.496119852988954, 49.793442064715975, 46.101111058265936, 52.77164282337312, 54.98632284902758, 59.02735648616668, 60.4129651284987, 58.35517206499654, 61.34453196679393, 62.716922221645234, 66.28323924156928, 58.54656803992487, 61.37771521845172, 64.26031604889901, 60.34833623516945, 57.73185645380328, 58.93064260482789, 66.1748484642275, 68.11194235278715, 61.44609782003588, 60.48306572821833, 57.584183139185754, 60.74690788022934, 66.09669131617393, 62.17341899871827, 61.612539675927934, 64.86463169897756, 63.74503427936185, 65.17842131276285, 52.33562038790796, 9.573562260596983, 1.82249583784611, 0.49775956138487787, 0.4291889005370679, 16.039790511131287, 75.31884254947786, 61.317408777052364, 75.0552749633789, 67.23204489677184, 69.17240219731485, 18.79335222705718, 43.41681349662043, 20.102164783785422, 41.23370462848295, 27.762871442302583, 37.56008725012503, 74.1375893931235, 34.6763018638857, 0.194242941516061, 0.14947864677636855, 0.03420545043604028, 0.09107045634018798, 0.0966079620223853, 0.07088400889188051, 0.028088519897972865, 0.17406774023848195, 0.18848366104066375, 0.28837709837863523, 0.2598717328040831, 0.19514764538936077, 0.19939351917034198, 0.3532861653835543, 0.1881673586584868, 0.4611799048800623, 0.29095198117917587, 3.2151298128789474, 81.48915444650959, 64.70597182550739, 54.49084904886062, 60.28744928298458, 52.22590384944793, 64.61221541127851, 38.303086142386164, 31.48967027664185, 80.37295772183327, 63.497203242394235, 83.38748747302641, 60.6896726546749, 76.4784049987793, 24.165369618323542, 1.2727890187694182, 0.33339919702660653, 1.0658095897205415, 2.0634248516251965, 1.132553621165214, 27.088535601092925, 75.78049767401912, 63.808980680281124, 64.07532530446207, 52.98092480628721, 63.52748786249469, 72.57839233644548, 72.3538915572628, 57.72424705566899, 70.52110133632537, 39.15473076605028, 22.76470103571492, 64.14124857994818, 32.812189555937245, 29.538206784955918, 72.77551497182539, 63.482925814967004, 64.33852418776482, 62.095587407389, 63.32275190661031, 58.91279189817367, 58.47679299692954, 59.53807653919343, 60.07792803548998, 54.554320842989036, 55.61066219883581, 55.36813420634116, 60.779161530156294, 58.84561346423242, 58.300729567004794, 62.622624520332586, 58.20867546143071, 58.39062244661393, 65.26106565229355, 62.58326745802357, 60.180654910302934, 62.135544592334384, 62.57150819224697, 55.4692489870133, 58.99100395940966, 56.444609088282434, 61.19480725257628, 59.99607209236392, 59.94019792925928, 58.41604332770071, 63.00714623543524, 58.88332313106906, 60.98909070414882, 58.68072094455842, 59.25348504897087, 55.039196398950395, 61.33160775707614, 65.23098499544206, 67.39574893828362, 65.70816093875517, 70.7830999743554, 61.54647519511562, 61.270218741509225, 59.45353769486951, 46.40084681972381, 55.46226716810658, 62.21436854331725, 59.20069779119184, 64.0273468725143, 67.35078288662818, 65.4162306939402, 54.87589636156636, 58.013549312468506, 52.74835178928991, 52.27285069804038, 46.48208695073282, 48.881228200850956, 56.10984263881561, 52.76927371178904, 55.70147683543544, 52.950985354761926, 54.71766010407479, 55.335178452153365, 57.53118407341742, 60.96908661627001, 61.807877632879446, 56.79078179021036, 57.915246871209916, 56.51653751250237, 58.43868324833532, 62.052249139355084, 60.75028896331788, 56.83562232602028, 60.62037221847042, 59.51318910045009, 53.716184862198375, 54.830459625490256, 51.77623941052345, 49.88056575098346, 56.05048541099795, 57.75309608828638, 62.49473564086422, 62.792776938407656, 59.512490918559415, 63.534406923478656, 65.52799078726, 66.86496596182546, 59.206699017555486, 65.97311312152495, 67.18188562700826, 61.886838866818344, 59.87134856562461, 64.55483113565754, 69.84774804884388, 66.1721263393279, 57.00374687871626, 57.568026896445986, 58.13624105145855, 63.26858397453063, 69.8974915473692, 66.26896181414205, 65.089877728493, 68.27146514769524, 66.0085242794406, 69.00273615314116, 57.875850585199174, 14.843428384873176, 3.4228923676475405, 0.9309032222917004, 1.288978111359381, 17.149063271860925, 80.62542500034456, 65.89232798545592, 79.70602927669403, 73.01869407776864, 74.15356912920552, 24.81139575281451, 43.76888152091734, 23.720008019478094, 47.487802274765514, 34.70899089690178, 54.16913232495708, 77.28475801406368, 49.82732349826444, 0.42074940017154144, 0.29308639406677217, 0.22072142230406885, 0.17817708182959788, 0.3035600417323651, 0.19496922351179585, 0.13369786372828868], [0.04210034655707498, 0.053731422841308586, 0.018300699040053353, 0.07492088622623876, 0.03901618765667081, 0.07346406278591003, 0.040885204704658645, 0.0789757896094553, 0.06735893191709634, 0.011912334931924218, 0.18232555519188606, 45.147594636486424, 61.89771952167634, 38.20015138195407, 42.74480558210804, 55.372884196619836, 76.08175139273368, 22.435104270135206, 16.650251534677324, 60.84069567341959, 60.532668021417436, 61.119929205986764, 52.79265888275639, 61.91921018785047, 33.23463078468077, 0.2356326802363319, 0.024969724247292168, 0.3229285524256768, 0.0830260658216092, 0.498270511386856, 17.846560708938107, 71.7238098575223, 62.983925804015136, 59.55392683705976, 55.60426481308476, 59.054358082432906, 58.572090902636134, 63.74743084753714, 62.11212019766531, 55.285525168142016, 57.76676554833689, 62.240177739051084, 48.68205024350075, 52.10580871951196, 34.31506726049608, 47.953866143380445, 60.017598059869584, 62.27692642519551, 60.56518447014594, 62.26015437033869, 60.3195813394362, 61.617952546765736, 58.22576522827149, 57.86428351556101, 54.060965122715125, 49.273449528601866, 48.12999233122795, 54.319861165938846, 55.9917792966289, 54.02620900061823, 54.811742075027965, 55.959215779458326, 54.416351472177816, 55.39127226798765, 55.30599601807133, 54.99556395315356, 55.285493789180634, 55.07819260320356, 57.05245879388625, 53.87133813673451, 53.780296002664876, 55.28508978505289, 51.26333067494055, 49.92042879904471, 50.82855947556035, 53.07456354941092, 50.06996916186426, 49.051772855943256, 50.696167715134166, 48.401475260334635, 51.795451179627456, 54.47537137616066, 58.85800815397694, 59.830493157909764, 62.548781979468565, 60.62668331207768, 56.3157670728622, 57.3967291462806, 62.05234719860939, 50.44453982383975, 53.7509645185163, 56.62728171194754, 56.99601588710662, 59.74786058548958, 64.60849308198499, 63.80951020025439, 55.729694366455085, 54.364438902947214, 49.76349476845034, 48.34465188364829, 45.68288833864274, 45.984016541511785, 46.48232621531333, 47.79420606551632, 47.01849852838824, 46.145986895407404, 48.203654443064046, 50.81855350925077, 52.90822367514334, 55.270800590515144, 51.47550736704181, 49.48915635385821, 51.322617300095104, 53.629508326130534, 49.835838963908536, 51.26206767174506, 54.91746956302274, 51.6475268333189, 52.88188888180641, 53.621212513216086, 51.134618097735995, 51.22218501183295, 46.77388383496193, 47.41536002005301, 50.159524717638575, 52.95543724490751, 54.269768576468195, 57.065610501074026, 56.13173338674731, 57.20470951449487, 56.95214417672927, 60.59601429970034, 59.58573333678707, 59.7074366384937, 58.07945297610376, 56.874567539461204, 58.00157431633242, 59.4156240647839, 57.582076826403224, 61.52898142414709, 64.90851125409527, 67.81046898134294, 66.77328448141775, 60.96006124250351, 59.982332029650294, 58.4941690967929, 58.20161519512054, 61.33529478503812, 59.821985537006015, 67.6259449989565, 40.219932756116314, 1.1558223467680717, 0.2411676961327753, 0.4646560441582434, 0.21514955757846757, 30.269775890534927, 63.456465505784564, 51.45385588369062, 67.48038584186186, 57.71431561439269, 67.59137322825771, 20.41197123066072, 13.648651876757222, 45.843619223563906, 30.18660399221605, 40.52020980465797, 45.91829330690446, 62.8408298953887, 17.596625320373043, 0.3616039496996711, 0.15964611974214354, 0.07758599120162188, 0.03269981953405565, 0.020579435231704867, 0.01962902272240289, 0.06710008612924045, 0.06490024167203134, 0.0867316407722331, 0.056268457067950126, 0.04822832982866995, 0.031459278036509795, 0.015160070841140566, 0.09358344689732598, 0.020125097212111278, 0.13339058586185978, 0.011228364929857274, 0.1702386642535848, 48.43209328189973, 74.1894039030998, 40.73032725241877, 54.72355150407361, 64.84460015450755, 77.57481728830646, 32.27216155298295, 17.613638600995465, 72.08811959912701, 64.01648582950716, 69.19383402793639, 58.90462552347491, 69.55233081694573, 36.54584861570789, 0.15790785092019266, 0.015733060558446716, 0.8301341004910008, 0.6573179027726573, 0.40587491445964385, 20.19022983889426, 78.59101710780975, 68.11266406889885, 65.05997357829925, 58.71275101938556, 62.287932595899036, 62.746316463716575, 67.08892545392438, 61.10553802982454, 59.26845281354843, 60.2721873406441, 62.42545089414043, 48.52319817389212, 59.30313048824188, 43.17527786377938, 45.36468213604343, 63.36670990913146, 62.25328630016696, 64.84348227900844, 63.78946688867385, 62.96803628244708, 63.76121013395248, 60.89804857007919, 59.68857003796486, 53.989295574926565, 52.358142637437396, 51.30186011714321, 55.89258255497102, 57.955808101161836, 56.66996494416268, 56.818371742002434, 59.92699523125926, 56.608466102230935, 59.52471302401636, 58.57807643951909, 57.27453162593227, 57.9858220777204, 60.5834391809279, 59.82119714060138, 55.03556820654101, 56.66846659875686, 59.3018517955657, 54.163068340670684, 51.73880823196904, 56.00740209702523, 59.10834950785483, 54.21449061362974, 53.750097674708215, 54.98530695515295, 51.96831003312142, 54.97916060109293, 60.09977171497961, 62.67012834548951, 59.578665225736565, 64.02148685147687, 60.78684153095369, 56.58998781634916, 59.938150452029326, 61.89634669211603, 50.991655549695416, 58.24474165516516, 57.61890003758093, 57.47668273987309, 62.00350976759388, 63.18405689731721, 62.72051119035291, 56.147924930818625, 55.796037335549634, 51.55872045024749, 49.16625899653281, 48.689047751888154, 50.02890979090045, 49.53136497928251, 48.55090971915953, 51.18438905285251, 51.25629002048124, 53.09567374567832, 54.23281984944498, 55.67379274675923, 56.874638142124304, 53.12515427989345, 52.507726146328835, 54.20583002028927, 54.89486886608986, 53.48715374546667, 54.80394048075522, 58.09047091391779, 54.3488984723245, 53.6183766395815, 55.421929513254476, 54.63797715402419, 54.896022042920514, 48.51727539493192, 48.88278538180936, 51.96748241301506, 54.515014771492254, 55.46258488009053, 57.10127269068072, 57.79013895219373, 59.00118643237699, 61.27199949756746, 61.80345319932508, 61.37755440127466, 63.63950290987569, 60.37365513463175, 60.39651078562583, 58.20647893413421, 62.18719828513361, 58.62136371674077, 62.72929337716872, 64.54584890796293, 66.33063716273155, 67.66607869055964, 63.476822606978885, 64.10950483814364, 59.73721527284192, 58.599916196638546, 65.30270945641303, 63.48430648926766, 69.99253842138475, 41.764060066592315, 1.5210848566024535, 0.3407309648971404, 0.577742756614762, 0.20149898925615897, 35.16686877896709, 71.45924598939958, 56.32604368271367, 72.57279903657975, 62.52858569545131, 74.73212657436248, 23.765158422531623, 16.958779288876443, 42.51433103315292, 39.18516051384711, 40.23081341097432, 49.63945765649119, 72.96404761652794, 18.235169533760317, 0.28462642383190895, 0.10684828228888013, 0.04374013094591998, 0.12660398914088167, 0.13107588184216332, 0.06907414149252639, 0.07910816960277096, 0.14941211970102403, 0.177968813166503, 0.20902519024187521, 0.26003595141153185, 0.17953295020326493, 0.1940399128943682, 0.26728268352247053, 0.12367839128860544, 0.26368130419042807, 0.15711081304377125, 0.37959420693016827, 64.16097417954477, 81.17803204444148, 54.93940345702633, 56.66509728277884, 75.866742749368, 84.02163274826543, 35.52571858129194, 27.35960275896134, 73.65083894421979, 71.81211809958182, 76.7406625132407, 64.38885604181598, 77.19833250968688, 42.7394986152649, 0.4849087735337596, 0.40701819343432305, 0.983436445315038, 2.0226462978509168, 0.5193405646470286, 23.173186471385343, 77.16191722500709, 72.21492198205763, 65.40732299127887, 60.71817259634695, 63.23879749544206, 66.17779024185674, 69.35967183882191, 65.01803167404668, 62.817127012437396, 56.96828472998835, 57.43710210246425, 52.69934961872717, 53.0377991737858, 34.43641362651702, 49.408516345485566, 64.14830492388818, 62.9485381803205, 66.04736358888688, 65.46009455957721, 64.38613783928656, 67.66912244981336, 63.31299697199176, 63.47557921563426, 57.98427274150234, 54.906859551706624, 51.9944251737287, 58.84375033840057, 61.29838135934646, 58.34238906060496, 60.204953993520434, 60.26935931174987, 62.915719709088734, 63.53628966116137, 59.969545102888546, 59.21384557600945, 59.45250611151419, 62.369196261129076, 63.98509117864794, 60.58165058012932, 61.12369468135219, 61.675187772320164, 57.16378350411692, 57.245749273607814, 62.07989400432956, 61.712140421713556, 60.001351602615856, 61.324900504081484, 61.36401830180999, 57.23029905749906, 59.99670751633183, 64.0448171092618, 67.22626332313784, 63.25408297200357, 68.83641981309461, 64.36660051345825, 61.651061273390255, 66.30842085807555, 66.36271430600074, 51.66047065488754, 61.32770499875469, 62.563863492781124, 60.9564212829836, 64.2548482648788, 68.1776891216155, 65.68012383676344, 59.82383689572735, 62.12114949380199, 56.82385129313315, 55.39744215626871, 54.12101268768311, 58.66238386400285, 53.97600658478276, 54.31091816194596, 57.44580584187662, 58.27522239377422, 57.25645342180806, 57.13431865938249, 58.51997437015657, 60.87980954877792, 57.84089834459367, 58.00473966906148, 56.98291909310126, 59.607545637315326, 56.87793685543922, 60.37925235686764, 61.80244907256096, 56.73706885307067, 57.50706541922785, 57.8035456134427, 57.49241536663425, 56.5754593572309, 49.349790619265654, 50.32165981108143, 53.069648819585005, 58.09257722670033, 58.05556181938418, 58.39752974048738, 60.29299551440824, 62.59813716334682, 61.04050513236754, 64.96054149443104, 64.72019041738203, 64.30502714649325, 63.75378900958646, 63.71830332663752, 61.54345889245311, 63.99778789089572, 60.609256221402084, 66.8937090904482, 67.83467000530612, 69.42748177436091, 69.39462015705725, 65.745305784287, 66.67418972138437, 63.4285343077875, 61.74725347949613, 68.1260471959268, 67.13675483580559, 73.53633711414953, 53.1435658854823, 3.7684529346804467, 0.4917575995768271, 1.6234921808204346, 0.7509712934974702, 38.575890910240915, 75.82616190756522, 63.85662963313442, 77.43472591523202, 71.45291528394146, 80.82926273345947, 29.893622552194905, 21.031640998778805, 63.29662499889251, 45.79810796245452, 60.70381279914611, 61.430882946137466, 81.56221251333915, 31.485206619385753, 0.4599670038348245, 0.3078330656693828, 0.1769012236787427, 0.18545439617047388, 0.17938042209754068, 0.19737971916554437, 0.14802551587983487], [0.05758005705091262, 0.016664021137741306, 0.09135980774918873, 0.009767782870650051, 0.0360094266192567, 0.03245873932516383, 0.037219987265885844, 0.12080201458546425, 0.21296085970055675, 0.12704719398771563, 0.44045180262577155, 24.9277195238298, 65.97385837185767, 42.6446125584264, 26.291015763436597, 36.81738253562681, 31.08493462685616, 32.24232016071197, 10.513845586007642, 50.6559947998293, 66.39534058109408, 59.86658680823542, 50.00206508944112, 54.4659576877471, 56.94945343079106, 2.198172485636127, 0.3221742622554302, 0.08061420653135547, 0.4938160471858517, 0.03471695202132387, 14.103991985321047, 68.21711678658762, 65.21710372740223, 67.67506876299458, 56.645920815006384, 58.63153834496775, 61.82061356882896, 63.928503144171934, 57.70920084368799, 57.32229432752056, 66.19241283785912, 75.08488101343956, 61.28726536227811, 56.89039822547667, 48.48123273541851, 39.601331833870184, 56.31227616340884, 60.54418802261353, 60.564023448574936, 65.79874415551463, 62.20828886955016, 61.640902334643954, 57.51199583853445, 58.64091673204976, 57.3187328154041, 51.41514993483021, 49.857984665901434, 50.495138399062625, 52.58590290623327, 53.883968168689364, 52.581301966021144, 52.6524616056873, 55.32297988091746, 56.762038661587624, 55.51696462015952, 57.0843594304977, 54.424015783494525, 55.030441668725786, 57.108219208255896, 58.24479656834757, 56.842137382876494, 57.21188745191021, 58.22231354251985, 52.26095414930775, 50.81143440738801, 52.353992769795084, 49.402326845353656, 46.88823269259545, 49.12652146431708, 49.076166076044885, 56.00780610115298, 59.32813559809039, 59.39314888369653, 59.53998281109718, 62.3885610026698, 60.88191193919028, 55.463538016042406, 61.07664977350543, 61.59239438272292, 55.76058695393225, 58.469077694800596, 58.70240380687099, 53.65675310934744, 60.190904063563195, 59.06884731784944, 61.63238686899985, 58.875023395784446, 54.59134409504553, 49.11120853116436, 49.32933153644685, 44.96589476062406, 45.962051268546816, 47.29349982353949, 50.217450280343336, 46.83813618075463, 51.822499844335745, 54.58863373725645, 52.05435114522135, 52.12670710779006, 54.47182555352488, 52.158505762777025, 54.243402404169885, 53.61605459643949, 51.32231135522166, 51.175532341003425, 52.61762311381679, 53.66803776833319, 52.25167382148005, 51.00985142492479, 54.3666942657963, 52.79312956717707, 49.98999203405073, 47.937372576805856, 48.57942535031227, 50.99356966633951, 52.65781171860234, 55.63856201787149, 55.095035260723485, 54.85994015970538, 57.155432778020064, 57.033309782705004, 59.67980354062973, 57.82025491037677, 57.632545963410415, 57.68143830760833, 58.27228453851516, 52.685609556013546, 57.184740727947606, 63.12437411277526, 62.839770855442175, 60.76600982296852, 60.926473986717966, 61.03828899322018, 63.619894981384284, 62.136650700722974, 60.30298579123713, 58.32985316553424, 64.5555724636201, 61.41351076864428, 65.22562703778668, 17.272141364312944, 0.7786852902462407, 0.179758072800694, 0.24708005629720228, 1.6304793929861439, 48.14171629567301, 60.62952703045261, 57.54342971309539, 64.02547197957193, 55.60334697846444, 80.6716226762341, 11.841401188604294, 37.231737798260106, 41.4354125145943, 26.092098643702847, 25.949059609443914, 43.331972629793235, 57.97357251567226, 5.489924328942453, 0.2227682866636784, 0.08508449044799613, 0.07782348611902806, 0.06200772349632556, 0.07363586566380917, 0.021959337698776397, 0.07428128707913623, 0.04857050683048945, 0.03930901327440816, 0.049679262052860954, 0.026415730526130048, 0.04783267605929606, 0.022658818108480305, 0.041555386081698446, 0.038938111805867766, 0.11399271101841044, 0.18551980475744895, 0.2766103862274078, 27.944404617432628, 75.81016648200251, 44.15097528888334, 34.28652809512231, 50.29635267872965, 36.5633031629747, 38.59649119838592, 11.173780445129642, 55.57767114331646, 75.2172923857166, 63.57579969590711, 59.62927164569978, 61.02944012611144, 64.02795483989101, 2.406546930151601, 0.2587840411691897, 0.3294228329773872, 1.0648406417139116, 0.011494471316015529, 16.284535623365834, 71.51084084664622, 67.05130207923152, 71.47830086369669, 60.83185465105119, 62.62864535854709, 63.97803483470794, 66.67744528862738, 60.26713532786216, 60.524395742724025, 70.48289745084702, 73.999294465588, 58.46542596817017, 57.0511055761768, 56.62727778957736, 40.49485560386412, 56.64888220448648, 61.32073494695849, 61.311329103285274, 65.90136512633293, 63.39193859407979, 62.755530111251346, 62.7799350984635, 60.32150330082063, 57.51289798367409, 53.45723390579224, 50.77720388289421, 53.59103771948046, 55.03724305860458, 56.133110138677786, 54.46551053754745, 57.970975906618186, 58.714982848013605, 57.24223090756325, 58.0043395873039, 57.85917658959666, 56.603010085321245, 59.3756119666561, 59.59198951721192, 59.736395497475904, 58.17697486569805, 59.14664753021733, 59.939382076263435, 56.23783742227862, 55.70674065620669, 55.67133342066119, 53.43860656984391, 51.460516068243216, 51.934248170545025, 53.59430113146382, 56.58311974617743, 61.24329559264645, 63.46731870405136, 60.19242594319006, 61.51567282215242, 62.03956811658798, 58.34063576113794, 61.42928654147733, 61.26662977280156, 56.771895577830655, 59.71713273755966, 59.42213912164012, 55.72618384515086, 62.798409461975105, 62.63969075295233, 65.31810868170955, 59.70630699588407, 57.661391073657626, 53.12429135845554, 53.68310359216506, 47.69571927285964, 51.46183006225094, 51.30275049517232, 52.7260374253796, 52.64011790675502, 53.251658562690984, 57.11106292663082, 54.164154837208415, 54.933543435988895, 58.153538703918464, 54.870095176081506, 56.373896598815925, 55.88487117521225, 53.64738256700578, 54.4906097842801, 54.80680773335119, 57.81884285711474, 55.62572802266767, 52.500556053653845, 54.14946556091309, 56.70444257797734, 51.6505156793902, 50.1788463131074, 50.41280000440536, 51.6320687724698, 54.78275968182472, 56.26441148019607, 57.36977069608627, 57.25978743645453, 58.9306543719384, 61.495480460505334, 61.37081576931862, 56.13223152775919, 57.75919145153415, 59.1944847568389, 58.84505648766795, 54.581757822344386, 58.90605326621764, 63.23406711701424, 66.75227626677483, 62.5527867194145, 60.447697716374556, 64.6712000139298, 64.8779873694143, 64.09984796277939, 59.80221679133754, 60.30146783398044, 67.77638358454551, 62.74244900672667, 70.72350348195722, 19.114878716007357, 1.0366234784164736, 0.34535059765461956, 0.30010290143470614, 2.0084780839181717, 55.66811315474972, 67.32742124988188, 63.31154961739818, 69.64520469788583, 61.79769515991212, 87.99262462123748, 17.350123966893843, 34.442399163399976, 42.79094834481516, 36.42827949216289, 31.8172784005442, 46.89202954692226, 72.22657926620977, 5.452743201486526, 0.3594087094308869, 0.10084943845868112, 0.033405440138472665, 0.0418850643590333, 0.036515902667757005, 0.07546952775409145, 0.053767099555942326, 0.2635018557550446, 0.1598443220099134, 0.16322565024658559, 0.11028176579143732, 0.1815496613421748, 0.13173149988776253, 0.12195453258051027, 0.21152324974536899, 0.2689919482556082, 0.31573486424261527, 0.39230118475614056, 36.904074761175345, 86.7913987559657, 56.52107961716191, 40.40996374622468, 47.46034960592947, 46.484773774300855, 44.02349433591289, 21.715321886924006, 60.84939549046179, 81.7920006475141, 68.34614707577613, 63.42101512416717, 64.75579769380631, 71.40630183681365, 3.070448776406627, 0.7223346204526964, 0.520674109218582, 1.5401566461209328, 0.3181082659190701, 19.17058813956476, 70.60682081407117, 68.3420285870952, 72.38618835326164, 63.92633407346664, 65.36522026984923, 69.11908934193274, 66.89796878445533, 63.75051775286275, 61.31927582525439, 71.11637592315674, 73.60187207498859, 55.49300286077685, 57.54581451416016, 46.02392273564493, 43.030942486178496, 57.53847575956776, 64.29695883104878, 64.45732493554392, 70.03571587224161, 66.39609367616715, 65.891465064018, 65.03800830533429, 60.792442675559755, 62.529115215424575, 55.00152987818564, 53.310329375728486, 54.51987458813576, 59.571663794978974, 57.49600825771209, 57.6648231475584, 59.026634770054976, 62.60445610169442, 63.10211073967719, 60.88054695437032, 62.52769923979237, 59.36916359009282, 63.568158918811434, 64.92843689457064, 63.33408363403813, 61.34918782018847, 63.03408507377871, 63.31011795228528, 60.930537562216486, 58.96479468191824, 59.55984961601996, 56.91466985210296, 55.44957045585879, 54.16995994506344, 58.39977725859612, 62.488824629014545, 67.28309062219435, 66.5942753514936, 62.68027159475512, 63.445624074628284, 67.13748439665764, 59.72131790653352, 65.46627621496877, 65.24229711101901, 60.21547771269276, 62.753521857723115, 59.74045122823408, 59.39381568662582, 64.2820930480957, 63.18593179025958, 67.1708010089013, 65.19934323526198, 64.78792190551758, 57.21664136455905, 58.68329794176164, 51.52556857755108, 55.363027280376805, 57.15447964206819, 56.97705907206382, 56.849268251849765, 56.967147242638376, 60.671210058273815, 58.37839641878682, 61.02690627498012, 61.763805881623306, 59.315238844963815, 62.063106259992054, 59.53129083879533, 56.254095646642874, 58.99688751466813, 58.478224662042436, 60.72414636611939, 60.59812061248287, 56.33113099682716, 56.19203982814666, 58.021343062000895, 54.96869179510302, 51.48414442616125, 51.83566331863404, 54.56122813686248, 56.52513927029025, 59.89762452340896, 60.70386378995834, 60.715313188491336, 60.08287414427727, 64.3005399550161, 64.08000076970747, 61.413397019909276, 59.326488202618016, 62.531162692654526, 61.25209346894295, 56.61198054590533, 62.63898472632132, 66.51603975603658, 68.0732128697057, 65.62969000108781, 63.49898792082264, 65.3896644807631, 70.83722083799302, 67.43146604107272, 64.55858092154226, 62.76533211431196, 71.08149820758452, 68.19423367900234, 76.1382649021764, 27.867408490950062, 1.2466331835716002, 0.9954713188832807, 0.756650701645882, 2.1409755031908713, 62.500446611835116, 73.4853619913901, 68.48909393433603, 73.979627701544, 69.8323723577684, 90.52640514989054, 21.527856126908336, 47.17310659347042, 58.309590201224054, 38.637793756300404, 43.84872921051518, 54.02952732578401, 87.08187380144673, 13.097619664284492, 0.6383618844612953, 0.20417156358880384, 0.13280080541247322, 0.20725067013934736, 0.177844783531562, 0.1567441020761767, 0.1864764953572904], [0.008460767923914378, 0.013155875663693636, 0.0834571588183603, 0.0930845091540006, 0.05698653809245556, 0.07750877719973365, 0.029010424360392556, 0.06340689882035218, 0.16455392413322004, 0.12038985928220135, 0.5457967063111644, 14.057936495350255, 61.93592732952487, 44.24833243893039, 38.86296133841238, 36.40327438231438, 51.432063195013235, 76.83578783465971, 13.80089573321804, 36.29267138819541, 66.57707968065816, 61.445199597266416, 62.55868988652384, 43.39211825401553, 69.4437909895374, 11.447682496040098, 0.40469808083388115, 0.1930469556921913, 1.410760841061992, 0.07572583013003872, 10.08697404015449, 65.85594407973751, 71.73505921517649, 64.86859721522178, 59.57939086421844, 62.554736137390144, 61.942889536580736, 64.04733527091243, 57.21046363153766, 56.077628212590376, 62.086977804860766, 47.685124951024214, 72.0046829408215, 42.66296925083284, 51.474938623366825, 54.99569731373941, 45.00907613385109, 53.69709860893988, 56.02062048450593, 60.291956086312574, 57.42331104893839, 58.56170838879001, 60.30442530109037, 57.32414176387172, 58.692927360534675, 53.87242855564241, 50.483124179224816, 50.20216480378182, 54.49754453474476, 53.55402623453448, 48.139245202464444, 52.57681085217384, 58.45670261690694, 58.418890968445815, 56.39905860347133, 55.69944897005635, 54.40275653716057, 56.26540776221984, 55.91472041222357, 59.05990823622673, 56.568136292119185, 57.705341231438425, 59.42461805958902, 60.08983635133313, 59.12676895818403, 54.41331555766445, 47.53114838753977, 45.52773898647678, 49.49039582283267, 52.954605702430975, 57.94373112340128, 59.871015164159964, 58.15912808141401, 61.31474156533519, 62.929608821868904, 59.872791997848026, 56.37435159375591, 59.9490075726663, 58.02999188823085, 56.31734386567147, 59.53886493559807, 60.523113127677675, 55.761516555663086, 58.68908736013598, 63.85243269705004, 59.07544866684945, 60.35821276326334, 55.07790234781081, 50.45354166338521, 47.17731921903549, 46.857955917235344, 48.21056565930767, 46.013434317804155, 49.38322882498465, 53.13854917403191, 55.16506918015019, 57.15932769160117, 56.69260094242712, 54.65406279410086, 56.110580044408, 54.183123419361735, 53.82972178920623, 52.59245718679121, 54.83908491749918, 50.35800449309811, 52.475044958053104, 52.42328143888905, 52.69280710527974, 51.56626316808885, 52.94629420003584, 52.75582390446817, 49.304185221272135, 46.128850060124556, 50.5578649428583, 50.72844489928215, 53.04364742771272, 57.30558503058649, 56.43410890333114, 59.803660223560954, 59.40137409394788, 57.83588947788362, 59.10077148868192, 56.9141403321297, 60.099034309387214, 58.194794193390884, 54.965298944903964, 54.99819586353918, 56.64506966067899, 59.13901852023218, 62.04033690114176, 63.076580032225586, 60.90994119644166, 64.74389722270351, 63.33265981366558, 60.29282293012066, 56.97485470002698, 61.18347944751863, 63.11431715565344, 61.31788338384321, 63.26091966321392, 4.7699173900388905, 0.7265653256927768, 0.8798467716382397, 0.4612702726116104, 10.594225737356371, 60.95513474556708, 54.404764790688795, 62.26438268538445, 54.375739251413655, 71.57370859576811, 47.77000111918296, 13.435874081427052, 43.355506850827126, 33.816039792953, 26.736371478726788, 33.07855967552432, 48.624007009690814, 50.30623705156388, 1.1141526795202688, 0.035428360420008825, 0.11848845203677494, 0.03565712959595746, 0.05759340230255358, 0.027022619634085608, 0.02302882133892948, 0.05189470789064804, 0.007861736962842125, 0.03182355092928535, 0.021164655542722153, 0.09504184847877872, 0.09368186621295829, 0.07321141464936157, 0.11304742746776152, 0.04200225665925011, 0.07675669336270902, 0.10252288092047938, 0.38007469727627696, 14.353913645590506, 73.1584716612293, 48.164273846533995, 40.31369701508553, 54.436265345542665, 56.17951177781629, 82.38215261890043, 17.04075094192259, 38.625559883732954, 75.91905932272635, 66.42588015525573, 68.37842033755395, 48.820098061715406, 78.643263078505, 13.248218086458023, 0.36693625873134983, 0.23198829272822027, 1.9204440400485072, 0.013056152083370234, 9.765725058894004, 68.629561854947, 70.68405228276407, 68.82465270257765, 63.59017126021847, 65.60251189816383, 63.98973526493196, 66.4556509448636, 59.62540811108005, 59.335490042163485, 64.92947240029612, 51.91638177441013, 74.6206057456232, 46.11366656518752, 55.58672789604434, 59.55526044291835, 44.144703418977805, 55.5129441907329, 57.50763024053266, 61.650763173257154, 61.534504121349705, 63.23849939530896, 61.69032812118531, 60.438170279226, 61.257973101831254, 56.00791200514763, 49.781125822374904, 52.237953370617284, 56.64004510448825, 55.295601737114694, 49.17147967123216, 55.629324836115686, 59.54230485423919, 59.82176196190619, 58.9069083429152, 59.024563758603996, 56.511956184141106, 60.18784069245862, 61.12511850172474, 62.60320094323928, 59.430568295140425, 57.643814932915475, 59.77467390798754, 61.183506904109834, 61.177352705309474, 57.260458161753995, 51.18875072848413, 51.49554675625217, 52.09552818729032, 54.74901160886211, 62.530558647647986, 63.72739145832678, 59.385213928837935, 63.40253291591522, 61.849631263363754, 61.70111856152935, 58.555613025542236, 61.95265231593963, 58.92853629204535, 57.22856929225307, 59.67844247817994, 63.86821239225326, 56.468723820101836, 58.80029832163165, 65.0647549475393, 63.359371154539055, 60.41503221757951, 58.60141454204437, 55.412766856531945, 49.884456742194395, 48.82049814347298, 50.3001142317249, 49.98757977639475, 51.71979650374382, 55.316154956817634, 57.652710868466286, 59.2022196708187, 60.044744783832186, 59.312869733379735, 57.14810971290835, 57.78867590811945, 56.050708986097774, 54.625939399965354, 57.29370417133455, 54.64116211860411, 54.882434952643614, 54.84642367209158, 54.698769969324914, 52.60552260183519, 53.86292465271489, 53.741680268318426, 52.05713210567352, 47.68910223437894, 52.62291046880907, 54.28694463545277, 55.031457562600416, 56.575498580932624, 59.231053013955396, 62.75061145905526, 61.85773095776958, 61.03942648057015, 59.85831060717183, 62.46632199133597, 61.57985064291186, 62.978222677784586, 56.709580882903076, 55.07764347137944, 56.988861483912316, 59.054997428770996, 64.43825044939595, 65.77218578707787, 63.122918913441325, 65.91561901953914, 64.04829625160464, 61.76119750545871, 59.89690672966742, 61.99074637505316, 65.92952774417016, 64.38522000466624, 67.62807876833024, 4.689088617601703, 0.5906802656189089, 1.4339838465375285, 0.537859728980449, 13.941189108356355, 68.8848767742034, 60.035637040292066, 66.67258939435406, 60.17801907754714, 76.92647303304365, 54.35896719655683, 18.23057447710345, 44.214839320028986, 39.54677950951361, 38.535686615974676, 30.691060020077614, 57.42760604427707, 56.452481285218276, 0.8452864003277595, 0.07405723700480116, 0.0519195789351098, 0.12664666023826407, 0.04891716161622636, 0.08676878071480221, 0.0296022406884379, 0.09357571707017, 0.12311373086225604, 0.14021627604961395, 0.1938157555677237, 0.20516789157784757, 0.17758612160480794, 0.2470421349449504, 0.22351189756826048, 0.13132211782278555, 0.3149768355632982, 0.24460231344546043, 0.8695499983526046, 20.188768756005075, 85.71013466004403, 59.26081988119311, 55.887867866023896, 49.5231907598434, 71.59470896567069, 91.84581987319454, 24.658837126147365, 45.10892006658739, 83.14279433219664, 70.7282966183078, 76.14311295170938, 53.88399562528057, 86.4517842569659, 14.041097760200502, 0.7673821225762368, 1.1755242895695472, 2.332051314653889, 0.1922268126039736, 12.801210072732742, 69.05997922343593, 73.54643329497307, 74.62880349928334, 64.42623230718797, 68.93689524742865, 66.91714917459797, 67.37922007037749, 60.617477509283255, 61.441226236281864, 63.75288294207666, 61.388172257331114, 75.15000804778069, 48.8688805795485, 53.19315641157089, 51.422272959063136, 51.05691986699259, 56.4043616479443, 59.354886162665586, 61.531346613360995, 61.760722898667865, 64.34686706912133, 66.60019813045379, 62.94507472745834, 65.19505608466365, 60.59564559690414, 54.422054598408366, 54.613532943110314, 59.96938036334131, 56.676476078648726, 51.32781836294359, 57.01070908577212, 66.92741009496874, 64.74077893841651, 61.302237049225845, 62.42681980133057, 60.36757153849448, 62.20458615210749, 64.55138337227606, 65.90697411567935, 62.20607665277297, 60.80951283054968, 63.71012126245807, 66.65056920820668, 64.23755453478906, 62.864140541322776, 57.06697940826417, 56.93468962946246, 58.21006005810153, 60.44134739906558, 68.34274245846656, 66.29034657632151, 64.32079899695613, 67.78030595471783, 68.05498953788512, 65.6430809728561, 63.21923271302254, 64.25337345369401, 62.89922222014397, 58.01778154988443, 64.05485445453276, 65.03565488323089, 59.26807626601189, 63.8086865025182, 67.20744379105108, 67.01067416898667, 65.75623742995724, 62.92469801441316, 60.26986921987226, 53.27210980076944, 54.458920955657966, 56.693287357207275, 53.859010127282914, 56.73098917930358, 61.125863752057484, 61.19819618040516, 64.83057375877135, 62.3018648547511, 62.82829792268815, 62.90237188339234, 61.608935017739576, 62.245825952099224, 56.94378168352189, 61.55589280589935, 56.53443136522847, 58.40271511385518, 57.92274252060921, 56.476803902656805, 55.65438093677644, 55.6340552145435, 57.342714186637636, 52.360174425186656, 50.85630632215931, 55.344090077184866, 56.76384687423707, 58.100767135620124, 60.253748278464045, 61.50037557848039, 64.54632743712395, 64.52915137813937, 61.05509634940856, 59.23767397480627, 60.31274857059602, 66.62541897066178, 63.98011369089927, 59.58075977140858, 59.28313424510341, 61.37018426772087, 62.46187402356056, 68.97939805061587, 66.1532283598377, 63.6941062250445, 69.21466181355139, 66.96854006859564, 65.28567068038448, 64.38299602077853, 64.60384115096062, 70.35827590573219, 66.5748203954389, 74.5627272513605, 8.234426840659111, 0.7347226911975492, 2.7472660666511906, 0.6996883259665582, 14.173665046691896, 74.7342368095152, 66.6946723384242, 73.34745145613148, 62.83569943520331, 85.47519253146264, 59.79978099946053, 22.969486021226455, 55.524978022421564, 51.019629893764375, 41.214045709179295, 51.20555416230233, 64.3928058685795, 74.0220755915488, 3.3978024365440493, 0.44331084275918625, 0.2695951046001527, 0.19376546955637394, 0.28685668964059124, 0.22014489517577235, 0.07514082240842043, 0.18189666852835687], [0.09257274709882275, 0.08723000394961528, 0.05530437371963936, 0.0461600762942145, 0.004772493632645497, 0.09560056406283572, 0.06462132438055931, 0.06966319415838489, 0.09249849019632225, 0.16760459350001428, 0.4040326875063681, 3.5331286201553964, 53.21740058160598, 53.91599432114632, 35.00576526887956, 24.91661725505706, 38.61586770703716, 56.26211689364526, 14.628496227725861, 28.191468831031557, 74.615843988234, 54.49222187842093, 67.47606338993197, 50.882778398452274, 68.30092999242967, 31.109990727516916, 0.29039160318432317, 0.24326270145754664, 1.5702430639536151, 0.04386203468687112, 4.032544647493671, 38.663979499570786, 72.38628249014579, 70.00763954654818, 57.16144184912405, 64.09555688981088, 63.739233093877, 63.173352749116965, 52.15694465944844, 68.72634241657873, 66.91625487419867, 59.26816648052585, 48.17567617662492, 60.31308197206067, 53.955582803295506, 60.022626538430494, 59.2878253998295, 60.502767793593875, 60.962599016005, 58.448646068573005, 64.96222419123497, 60.90430867287421, 59.609989273932676, 57.713664500944084, 54.43400213795324, 52.63381073551794, 50.55738641369728, 50.177763738939845, 49.65494709630167, 50.98647802106796, 48.284184625071866, 52.02896164309595, 56.558883420882694, 58.73748548569218, 58.23271174584666, 54.95396329510597, 55.22261819531841, 56.25984584131549, 55.900242943917554, 57.64715286993212, 56.323180352487874, 57.66516439376339, 59.36879488729662, 59.112585667640936, 56.36743253277194, 55.55410162095101, 50.998680514674035, 49.411105109799294, 52.279150024537124, 57.92907714843751, 59.325417395560976, 57.4966868277519, 57.97236442565919, 58.202368290193625, 61.099442666576756, 57.10385753262428, 57.44332298155754, 57.34996664908625, 57.717551569784845, 47.37564994442848, 54.568280558432306, 63.14664140824349, 56.88147091096448, 61.275247220070135, 62.1558742369375, 60.55121690996232, 58.99742095701156, 55.021169185638435, 56.05688671911917, 51.37741673377253, 48.647109770005756, 48.31473596634404, 47.635526580195275, 49.17477838454708, 52.32322962053361, 54.65512967878773, 56.66769389183291, 54.845403855846776, 54.157498575026, 55.343595858543154, 55.53090080138176, 52.59294748306275, 54.20360603640157, 54.99887443357899, 52.779032568777765, 52.208245338932166, 53.84679194419615, 53.462776214845725, 51.740314422115205, 49.27660703659058, 51.64879375888456, 48.39683117405061, 48.87894145904049, 50.49462064619988, 52.98422744197231, 52.695027166797274, 56.64977650488577, 58.27618337446644, 55.01007280042095, 60.894667486990656, 59.004971519593276, 62.14422087515555, 49.369131826585345, 50.54297170331402, 61.76937564726799, 57.70452930081276, 56.065508088757916, 54.121365700998616, 58.897651549308534, 60.15007219006939, 61.35563619675175, 60.97468776087607, 62.94447852719215, 60.97142827126288, 65.55380782773419, 60.898676149306766, 64.3355784877654, 61.212685415821696, 66.09072931351201, 43.859919732616795, 0.4243398704115422, 0.707493965183535, 0.6762682213898629, 0.11420779020315218, 32.30017708193871, 54.61727880662488, 54.05317921792307, 63.669563954876324, 61.59625007260231, 68.38743394420993, 51.5912643555672, 15.678257807608574, 41.24821347575034, 27.18727734781081, 28.507417709596698, 33.23491319533318, 52.10474575719526, 32.2940719127655, 0.2439787638403716, 0.01891921544747968, 0.05959499469627777, 0.07389274260569965, 0.05691100565356113, 0.023873371988414757, 0.0105720947519125, 0.04549606192496516, 0.02397296724901084, 0.02069846997337957, 0.02948924655004615, 0.10190896104059874, 0.032665088938008395, 0.09668270922115735, 0.05991462190004607, 0.09245532880266828, 0.1833212396670734, 0.13211926295151635, 0.4125630458997142, 4.213316882810285, 59.48150811656829, 60.89239251229071, 38.113820014461396, 33.885450055522305, 47.282917268814586, 58.13487998900875, 18.35822997554656, 31.418018379519065, 81.3381588843561, 61.617222985913685, 76.19982257966073, 55.77654315579323, 77.20987996747418, 33.57453946144351, 0.19660776300776392, 0.2486203373560021, 2.116343508804998, 0.038455962879402984, 4.629330817730197, 41.92879569145941, 74.58410416879963, 70.51451175443589, 63.17847536456201, 65.42441668048983, 66.24831445755498, 62.66500965241463, 56.2615167710089, 70.55693611021965, 67.30623260621103, 60.37940925167453, 50.57888492461174, 61.995943515531486, 53.70411180680799, 60.23052784704394, 62.487169388801824, 61.38130810952956, 64.06844546717983, 60.83898944239463, 64.68457137384723, 62.29878971653601, 62.849933716558645, 61.20391891848657, 57.80418888215096, 55.98353839689686, 52.28730070975519, 53.04694614102764, 55.68750535288165, 52.010620640170195, 49.34978277452531, 56.94588799630442, 59.27061011714321, 61.16835871050435, 60.753187594875214, 58.28896637885802, 57.57042346462127, 58.88386441815285, 61.457570752789906, 59.22186682301184, 60.34695556086879, 60.548479095582046, 62.18151084838375, 64.29588410162157, 59.08483882104198, 57.33120595255206, 52.176176040403305, 51.92104939491519, 55.11720841930759, 58.19007950444376, 61.659682643029, 60.10100333921371, 60.32134640601374, 61.57786592360466, 61.3294896771831, 58.79261439846408, 60.44890188401746, 60.239839553833015, 58.31624646340647, 50.17520243121732, 57.09963706231887, 64.82894989752, 59.532773494720466, 62.56451460622973, 62.97366488364435, 59.52601525091357, 60.23903939031786, 58.19663770737187, 58.65049516001056, 54.19815394186205, 50.79394848115983, 53.01950523930212, 52.10587539980489, 52.78371587876351, 55.65617738231536, 57.539574023216005, 56.353700314798665, 57.773339440745694, 55.42749927889917, 59.05882958442935, 57.37386565054617, 53.92745548678983, 56.547096698514885, 56.37614019455449, 53.31146294070829, 53.29036843392157, 55.598036089251124, 54.07496406186012, 52.430420152602665, 52.710395013132405, 52.93916725343274, 51.607044050770426, 49.472145034420876, 51.976786275063795, 52.7042329695917, 54.37604911865727, 59.11655118388515, 60.544093885729396, 59.34955958397158, 60.25320306901009, 59.41441205240066, 63.10562910572175, 41.770582968188876, 48.02779497638826, 64.59137193618282, 61.570554625603464, 57.323353367467085, 55.78169322782948, 59.884257085861705, 61.657446892030784, 63.5781099719386, 63.75334970412716, 63.02169430640436, 62.824724643461174, 66.7748220505253, 64.24856855023292, 64.85802642760738, 65.44975126943281, 66.96482166167229, 46.79806132470408, 0.18564173531147743, 1.0970140056264017, 0.8307075019805663, 0.19870606251060965, 39.30059979038854, 63.4287186591856, 55.573360458497085, 72.6695639087308, 64.55252085962604, 75.56668143118583, 48.13611122869676, 19.918695918975338, 48.227902535469305, 32.238646861045595, 31.5222220267019, 30.878119814780455, 61.24316615443076, 35.0001052887209, 0.2939331663712379, 0.03389274866710748, 0.04985014562525096, 0.04398584981719333, 0.0705513658542787, 0.021500372508120154, 0.08998887042605108, 0.07710058257103929, 0.1028202456091681, 0.2148053083088129, 0.19140588810607312, 0.18410597417143085, 0.1444612458468445, 0.2524259557286578, 0.1578298938130179, 0.18292797609202324, 0.1903404436645008, 0.31546602866822676, 0.49018043904535236, 7.955731163101812, 77.01514213315903, 69.73765496284732, 54.18029931283767, 33.79985217125186, 57.5068457664982, 63.948809254554014, 24.709363137522054, 35.40181482991865, 89.19328566520446, 63.090543670039025, 84.25136596925798, 58.13109490179247, 81.25555376852714, 37.139652313724646, 0.270469946366164, 0.9591465551526317, 2.9434841054101146, 0.22632803677791552, 7.408917459749407, 44.448636116520056, 73.00505991904967, 72.36729821851178, 64.26266554863223, 70.11947416490125, 68.32781391759073, 65.478117850519, 61.464042663574226, 69.88943499903526, 68.92495555262413, 61.06862460413287, 55.71156124914847, 67.43565513241676, 60.34225263903218, 55.10493924540859, 56.65063550395351, 64.49772142594861, 65.11640864033853, 60.91259664104831, 69.75958101211056, 65.90913926401447, 65.20192415483537, 62.80626204706008, 59.79543501330961, 57.50497871829618, 53.62908078778175, 55.42824845160208, 57.29579479463639, 56.08492774348105, 53.45506875745712, 60.133676682749105, 61.51360573307161, 65.20213596282467, 64.23302027486986, 60.57009919997185, 61.386956322577696, 64.01488550247686, 67.20592191142421, 63.915786820073286, 65.01472903836158, 63.35003983589911, 66.41973772356587, 68.97649549668836, 63.49442620431224, 60.68159257211993, 56.958235617606874, 56.08285673203007, 59.62228590442289, 62.939516728924175, 65.83744618200487, 62.93839885342506, 64.86863251655333, 64.42052525858726, 64.38076026978032, 61.5845339528976, 64.9453736889747, 61.774914033951305, 63.743143696938795, 52.28369997393701, 59.76035725685858, 66.80711884652415, 64.24496389204457, 67.98367300341206, 66.58433606547695, 63.882909513288936, 64.1229703349452, 60.330548286437995, 60.0596615575975, 57.83368902821695, 52.91120075410413, 56.68385013457268, 55.60686926687918, 56.692648010869185, 60.38694804714572, 59.90122525922714, 62.3926834137209, 62.19769454771473, 61.053994163390136, 61.63563066913236, 60.261930342643495, 59.93627555908696, 60.36482980174404, 59.072291158860736, 57.24235250103859, 56.79941492695963, 59.50685839499197, 56.770718866778964, 55.91677965656404, 55.14084854433614, 55.21792704059232, 54.07536022124752, 54.49469689399966, 55.14879526630525, 54.777676290081395, 58.03472226665866, 62.44677289839714, 63.093556050331365, 60.737709922175256, 63.69932297737368, 62.750129007524066, 66.80994295304822, 48.12584638595582, 54.31725278977425, 68.55975935536047, 62.91739456115231, 60.23694484464584, 58.734198539487785, 63.72985470679499, 66.09043905811926, 65.15569117761427, 64.28597227219613, 66.75171144547002, 66.56291207959576, 69.28610386386995, 65.84383964538574, 68.17699878446518, 68.6124054078133, 72.05397928914716, 54.39555898789437, 0.6514749195306533, 1.1853042292979457, 1.7895641081756162, 0.4124593788818006, 40.11646455334079, 66.82476166755923, 62.88939668286232, 74.74476445105769, 72.9247925358434, 80.71462754280337, 64.31413489003336, 25.472858375118626, 50.4139571036062, 41.970423806098204, 40.767307358403365, 50.792571729229344, 65.86027437640776, 54.92265493639054, 0.6985597252365082, 0.09751767611070987, 0.14344282388206453, 0.16041171737015247, 0.21396618156183153, 0.30561076717511304, 0.1716735929010376, 0.20574195190302788], [0.027298830719965122, 0.019045644852843498, 0.054327887407834494, 0.01055240054659906, 0.0301401608157903, 0.008457422992514988, 0.10336891778053776, 0.04764496536564924, 0.015673081619634984, 0.05533794369248133, 0.0955395681423045, 0.05222009990604655, 31.846225492415893, 56.03891834135979, 36.96862128473098, 44.817986103796194, 33.105220025585545, 53.39020059954736, 13.972055219834852, 35.9576617517779, 71.49803823040378, 45.93701477973692, 68.04483059913882, 59.079943703066924, 58.693374510734316, 53.600769119877974, 0.41439365896005786, 0.28409331856716064, 1.1796896015444112, 0.09767481606573829, 1.2204561430600382, 30.947949770958196, 58.07962948276151, 63.25862115429294, 71.55191590709072, 63.26024501554428, 60.97086737232824, 54.85434685983966, 69.72708025286275, 70.09515546983289, 60.23092792880151, 65.98199336759507, 61.80191563021753, 64.95444613118326, 64.70789378689182, 46.39584187538394, 58.62426627066828, 65.60781102026662, 65.23378556774509, 62.28728932719078, 60.302420969932314, 57.07338856112573, 58.115848648932676, 56.59547521222023, 55.62391588764807, 52.58478895310433, 52.28438246634699, 50.12314865666051, 51.25663911142657, 51.60234897367416, 48.810896181291156, 50.38125238110943, 53.279487779063565, 57.21718265164284, 58.71006419581752, 54.87796737301735, 55.260763245244185, 57.432285431892645, 56.7097181658591, 54.61992248412102, 55.51676065691056, 57.98432373231458, 58.37879257817423, 56.72192850420552, 54.464376972567656, 54.02192185001989, 47.64967456940682, 48.42507223929129, 54.91059364811067, 56.85255519805416, 56.65428723058393, 58.279815489246005, 60.24442872693462, 57.78076056511172, 61.66612317485195, 54.988672348760794, 54.18687320524647, 59.44453977769422, 60.14639692921793, 50.68792681540213, 49.168549660713445, 61.37901352297876, 55.65900148883943, 57.69716701199932, 60.946442773265225, 58.846786252913944, 57.75565347363872, 59.28387165069581, 56.538934246186294, 53.21757708826373, 51.00919246673585, 47.76012851345924, 47.991163961349, 47.96644126215289, 52.45604107456823, 56.51567459106446, 55.56188752574306, 55.03081037152199, 52.271481790850245, 56.067755606866655, 54.96041559403943, 52.592194387989665, 55.688854648220925, 52.030020683042466, 52.38395575554141, 52.83382808008502, 52.176081903519176, 52.1043142964763, 49.70916601919359, 50.93082351069297, 51.73106547324888, 49.11983774554346, 46.675142088244044, 51.236203562828806, 54.47165689160747, 57.15303228747461, 54.94221971881006, 57.35974511792583, 62.36018657684327, 60.47689976230745, 55.96578182712678, 46.28183034158523, 20.294560963107696, 22.861997389024307, 59.40031897637152, 56.270338181526434, 58.29518725795131, 55.30664320914976, 55.1664851557824, 59.224047660827644, 61.93598224270729, 63.13822792422388, 62.504392516228464, 62.52292179292249, 63.329227739764804, 62.22207600070585, 65.33572012378325, 61.84653259092762, 67.78273782422467, 26.518913315188502, 0.6129797367799668, 2.3060398717080397, 0.11062765448924997, 3.03649845623201, 36.39002069350212, 53.43301326997819, 63.430828894338305, 55.75494266325428, 50.67701478158274, 71.51008775157314, 36.97120612667453, 17.175643213333622, 23.16167235374451, 36.848985072105165, 68.0641443498673, 39.2907585636262, 58.093098901933246, 22.182158462462887, 0.27238253083440567, 0.09682184610996517, 0.02749627839112955, 0.09500933570727225, 0.05223290889614052, 0.0235646691984467, 0.003666659838692736, 0.04214049722518652, 0.10044804669075436, 0.04127207910642028, 0.05797438165773788, 0.011915552501206197, 0.06928723650954424, 0.07234526032041158, 0.04179422931385137, 0.07853207914459129, 0.034245444056127346, 0.09133095687796032, 0.07050920037492629, 0.23402905902795254, 38.3574031245324, 67.59845702878891, 32.924281089536606, 45.375256846027995, 44.70138188331358, 63.48888781762893, 19.03865529644874, 39.33362614723944, 79.88927456640428, 51.168440695731874, 77.98421859741211, 64.9445499912385, 65.45981999366515, 56.55252525883337, 0.7934913183412244, 0.36250410301070063, 2.359117630027956, 0.07422887900423619, 1.704538522228118, 34.91964963174636, 62.80103352762038, 67.02985455912929, 72.05696029047813, 63.40595322270548, 63.733012214783706, 56.35847383929838, 72.91402170735022, 67.55650335742583, 63.86866346482308, 66.3696647459461, 63.34476817038752, 59.83870267868043, 65.65563255740751, 48.94032262986707, 58.69348433709914, 65.04939102357434, 65.12283348268079, 65.53802421016078, 62.94797728138586, 59.410921142947295, 58.79973350032684, 57.839086209574056, 57.481668072362105, 53.567982027607584, 54.88678486116471, 53.78384967004099, 55.12071501824164, 53.439728367713194, 51.466254495805316, 52.033048752815496, 56.739053572377856, 57.60033545955535, 57.762556845142, 57.76504755020142, 59.676775470856704, 63.20006801236061, 61.841661007173606, 57.64826682306106, 57.73461780240459, 62.98869932851484, 62.25660070296257, 59.14483931756789, 55.15478472555838, 55.87109581116707, 49.27879179677656, 51.72292263277116, 54.02949202445246, 62.487255680945616, 58.26941336354902, 61.359480119520626, 61.50705145251367, 58.73648135892807, 61.58774245169855, 56.99147378244708, 57.73717518775695, 59.853505703710745, 59.25454801128757, 49.20459624259703, 50.99606037139893, 63.86130117600965, 59.93054889863538, 62.844493389129646, 62.38722347444104, 61.93889656374532, 57.867856794788, 60.7990244127089, 58.690287605408706, 56.27321327886274, 51.229304113695704, 50.23124525623937, 49.36673525841006, 49.389834096354825, 53.46289780832107, 58.00529272325578, 56.93493673878332, 57.589242996708045, 55.007029041167236, 59.76947676750922, 57.46138549620106, 54.36277189562398, 57.97791850182318, 54.12025174786968, 53.831730042734456, 54.234220135596495, 52.902901018819506, 53.20536674991731, 51.53796718966577, 53.40234817997102, 55.23038841062977, 52.56118412940733, 46.451931768848056, 51.9577863139491, 55.473645963976466, 60.80621411723476, 56.94739026408042, 58.12833355319116, 61.78055440225909, 65.35849732737388, 57.584818563153675, 48.806193259454545, 28.574223518371586, 23.867749975573634, 63.77649168814383, 58.63819068478, 61.31259210648076, 59.38775954707977, 58.397392457531346, 62.475076721560576, 62.883968122543834, 63.3161505576103, 63.31548767705118, 65.30652984496086, 66.2576340090844, 63.52806837328019, 66.54615571421962, 65.41857234893307, 71.6912777193131, 27.54032204228063, 0.86504049839512, 2.9451476806594483, 0.14257406485417198, 5.072148269222629, 41.043124506550456, 57.924946892646055, 68.80078115770894, 62.019391444421586, 55.15458860704976, 79.79665956189557, 38.098146223252826, 25.343237769219186, 27.44148223630844, 42.9564723660869, 64.9594275413021, 39.69773977033554, 71.23339591487762, 29.007504217086304, 0.38497208287158324, 0.05589427291265419, 0.06714091095472537, 0.052495217401414156, 0.03984850005156571, 0.05185630007256424, 0.0328347199566422, 0.053821350072300246, 0.19313131729441305, 0.0976813507957324, 0.21395400076383547, 0.13571008559196227, 0.16292545103257702, 0.2032761753446633, 0.14454649611105844, 0.16957124845395166, 0.19626608779353483, 0.16989004828276175, 0.22253459920325588, 0.5466781977203585, 55.74256366299045, 74.82216850403817, 57.45031264520461, 59.53815498659688, 50.0501415806432, 70.34988203356343, 21.591994723966046, 45.031229680584325, 84.96795946551909, 57.081072484293294, 81.0369130103819, 71.18432706402194, 69.6087815684657, 61.04040315074306, 0.8664782309243757, 0.6101273156462178, 3.952148561516116, 0.2725426432105803, 2.4915449369338254, 40.46486123915642, 67.19543349358344, 67.769315473495, 72.84054002454205, 66.84380869711599, 65.23955537426856, 62.87092624172088, 74.42713875924387, 68.35220321532219, 66.82799370058122, 72.02292196212277, 66.04596722510554, 60.021390991826216, 64.007695797951, 53.64965754170572, 58.26251391441592, 68.65012291939028, 70.28565714436193, 70.49039702261649, 66.40448754833591, 63.466714659044825, 62.3537499673905, 60.74419752244027, 59.76527983142484, 55.473183124296135, 55.641715603490034, 57.18028883780203, 56.252828721077215, 56.6783352821104, 53.173819126621375, 54.689940714067035, 60.05202862524218, 62.92161503145772, 62.509895601580226, 60.67239069169568, 65.64474798017933, 71.43439385198778, 67.3867824000697, 60.325770839568115, 62.18985765211044, 66.5331099110265, 68.0650229607859, 61.554774930400235, 59.75043366032263, 60.01835507731284, 52.21305024239325, 53.42420754894134, 61.59277485262964, 66.54833655203542, 61.36623051858718, 66.4281080615136, 66.63750771553286, 62.56593842660228, 64.43338671038228, 62.49381388387373, 60.448337062712646, 64.90426332719865, 64.4870408119694, 52.1612435771573, 55.3500363903661, 65.66699174142653, 61.24402123112833, 66.3081306026828, 66.93243857352965, 66.73020901218538, 60.728457050938765, 65.04640217750304, 63.81946517575172, 61.15230052701889, 57.30221963697865, 54.23352979844617, 54.641628880654615, 51.2909088596221, 56.70276772591376, 59.72300844807779, 60.3712114980144, 63.00665201679353, 59.18245092515023, 64.11149740219116, 61.396279796477295, 56.71381704268917, 60.0447996970146, 55.70170041053526, 55.94305561434839, 56.672628233509684, 56.3691113072057, 55.40555361778506, 53.86021821729599, 55.35502564522528, 59.02998055181196, 55.86156052927817, 49.72057227165469, 55.01238699882261, 56.45261856817431, 62.15988682162378, 57.64148112266295, 57.9651354974316, 65.28344277412661, 70.12185112122567, 60.89047447327645, 53.94487473272509, 29.801540990029615, 23.915457763979514, 65.85915257853847, 61.80656363887172, 64.01630147810906, 59.8183612669668, 61.230657715951246, 64.58957941301408, 66.32703642691335, 66.00861841632475, 65.22037106175577, 65.34027791792347, 68.42733229360273, 66.07852289753576, 69.04677652543592, 65.56286850283223, 73.95772518650179, 34.34207277913248, 0.6668056872102522, 4.0959451035145795, 0.3506524776739459, 4.068714293741411, 48.843310648395175, 64.2808888804528, 74.64068828090545, 65.75762987136841, 61.93259723724858, 82.3309107749693, 47.52064428021831, 25.035961251105032, 33.77283488550494, 54.307760653957246, 88.94183035819762, 54.07729002737231, 79.71119896058114, 42.690606271066976, 0.41348345457546176, 0.2624669935434096, 0.24933356521350725, 0.2591168604070141, 0.17996606567213613, 0.1181890955194831, 0.1252713485530788, 0.15242063891022437], [0.046850784997185396, 0.09768757142967756, 0.080705470585775, 0.07898901994790762, 0.12498165240451214, 0.12228673128711602, 0.035917856129667455, 0.05363472339306628, 0.058541991522595774, 0.14025969791316217, 0.1395218173462537, 0.4029431879039734, 20.88590337384132, 54.10613513761952, 48.433285682432114, 41.726495527452045, 25.185815403538367, 39.32621678998394, 9.124231223137148, 25.260301213110647, 76.07158460924703, 52.13510490232899, 55.751483132762296, 60.35872659375591, 58.38982620546895, 64.63088589329874, 4.554919533191189, 0.4419696985954239, 1.1253478594364659, 0.08919203173248999, 0.2209333835109588, 20.72137563459335, 66.75381383588238, 52.21244227501654, 66.27252332625851, 58.376678420651345, 65.90873133751654, 68.78084767249324, 75.00622180200394, 59.959492068136896, 67.1571276264806, 55.89635979744696, 59.47147469366751, 51.45644464800435, 65.77810072129773, 53.26803445816041, 52.51295858813871, 63.82788650451168, 60.13496322016562, 60.22150639564761, 61.28482957040111, 54.72265328130415, 58.72339240966305, 55.849432560705374, 56.60240604031471, 51.89651104711717, 55.03205376286661, 52.39560911732336, 52.74987366891677, 51.60098006648403, 48.01338418837517, 45.27970006389003, 53.66360549003848, 57.094992976034845, 56.113800310319476, 57.92612752606792, 57.25937950995661, 55.94306345908873, 58.90446862866802, 55.724222660064704, 58.837713810705374, 58.280580351429606, 58.344122748221125, 55.45465384760211, 53.6032166788655, 49.30227110462804, 51.014279780849336, 52.72875955027919, 54.56832762687437, 57.98838338544292, 60.93303218964608, 59.36996375360797, 56.446601652329974, 57.39438749128773, 59.34072248397335, 51.659513596565496, 55.82667889133577, 58.4370280081226, 60.05791610287082, 48.02273904123614, 46.19045480605095, 59.94661100449101, 54.59753359517744, 55.771145974436116, 57.06832478123327, 58.90270356209048, 57.75111529134936, 58.601951906757975, 56.53792227468183, 57.19417402821203, 51.35848345295076, 47.89468934459072, 46.749290573981504, 46.69595418437835, 51.61324139564268, 56.15115304147044, 54.81095367862333, 55.48933544466573, 54.613497641778764, 53.91726124671198, 53.0213644427638, 54.89070723133703, 55.71363618296962, 52.76246055479973, 54.190948547855506, 52.834137947328635, 51.447752675702496, 50.05595453323857, 48.002181899163034, 51.42724260207146, 50.11606877849948, 47.47048893282491, 49.25128029238794, 53.86703921902565, 54.000686137906975, 57.292511770802165, 59.4758402916693, 59.5542759280051, 56.47643519986061, 55.76805122437016, 51.904838238993, 48.21432721230292, 48.81253573202318, 45.9460009298017, 58.12960832349716, 63.39080110672982, 60.97082814862652, 58.408692805997795, 56.47875724300262, 57.23051478785854, 57.79788171091388, 60.02828259621898, 63.6907212195858, 65.16751320131364, 63.74380657749792, 62.884128939720895, 69.06106964234384, 69.32644151872205, 62.845854451579434, 4.690540384861731, 0.46210270375013357, 2.4137319768628767, 0.8891847092778453, 16.114306719072406, 65.22142225696196, 50.2161245192251, 63.771863291340495, 52.0550807060734, 54.417704689887266, 68.75360288927632, 28.69292816808147, 22.659516795989006, 35.11116720015003, 71.11459516709851, 67.66332518669867, 27.168697080304547, 59.38498643136794, 13.986590543100911, 0.28286007022665394, 0.2282230471891742, 0.027061776303115393, 0.04801401673185249, 0.031479135035507144, 0.035283006727695465, 0.04831914572165378, 0.04398562382125566, 0.08790688859599252, 0.07322935642854822, 0.1396874915207586, 0.019767069851138422, 0.13224572874605656, 0.08040370089152167, 0.11396386014718203, 0.04012871203162978, 0.05559919116597983, 0.14200544375325405, 0.1108515207024832, 0.3368974915675579, 26.455298354548795, 66.99555735434255, 49.21338627415319, 42.95096535836497, 33.214736523166785, 50.63187222326956, 13.903062689688898, 27.284216765434515, 81.32236742204236, 56.07265464721188, 68.21308459005049, 66.31311201280164, 64.09780048554944, 70.83984882600846, 6.162200435515373, 0.5210032818778869, 2.6185625599276636, 0.06743232314024242, 0.39511015338282435, 26.37711374990402, 69.93910005015712, 53.86456812581709, 71.02588684328141, 60.91709167726579, 67.35305786132812, 69.80813211010349, 72.94256087272399, 60.360377911598455, 70.74065208435059, 57.25536300290016, 64.02192223456599, 52.69654904642413, 63.89497472393898, 57.5778445889873, 53.505741857713275, 63.594509401629054, 62.646280334841826, 63.55362261495283, 63.21463569518059, 59.00194737219042, 61.32705780767626, 59.21321015204153, 57.40060052564068, 55.328173099025605, 57.90985753459316, 54.601695229930264, 56.0096025466919, 52.958684967410186, 50.79553704107962, 48.59460100050896, 53.54766807248516, 58.921095555828465, 58.550200154704434, 61.4295611073894, 61.78822263594597, 61.587079571139434, 60.74910832989601, 59.463767236278905, 62.44679643261818, 63.335232888498616, 61.82132744020032, 59.083991589084754, 57.760356395475334, 52.67588992272654, 51.269167161756954, 55.466495483152336, 58.692554735368304, 60.3802643283721, 61.8997513094256, 58.79968643188477, 58.23362958046698, 60.89576182826873, 61.55311184544718, 54.85460181390086, 57.21383294751568, 60.0891185575916, 62.35024336845645, 50.04306562485234, 49.92669674658006, 64.87823055636498, 55.85375109026509, 57.13840576910204, 60.551444407432314, 61.43083980006557, 59.28489146694061, 61.49764560884046, 59.65128790947699, 60.16303170111872, 52.33645977512483, 49.41952643855926, 49.47035251125213, 51.36612423004643, 52.7925725906126, 57.19464863500288, 59.61379397299982, 56.13000362150131, 56.177075985939275, 57.29125661234702, 56.04746910833544, 56.41125717470723, 56.615824468674205, 54.92018776555216, 56.39336332198113, 54.572238229936175, 53.631606794172725, 52.36188457858179, 50.096468694748424, 53.120741613449596, 52.75677311804987, 50.545917403313425, 51.116045674970074, 56.4254875336924, 53.623730674866714, 60.15301396769863, 61.010032238498816, 61.53119364092427, 57.83779574978737, 60.70699776372602, 52.69771399036531, 53.50897389073526, 55.23498935084189, 48.02388829569663, 60.11364906064926, 63.94666371806976, 63.445427956119666, 60.21870582334457, 57.77754814394059, 58.34199290121756, 61.45735502243043, 62.453350713176114, 65.99143059022965, 66.87678014078449, 66.60056683324999, 64.79573526690083, 72.8814503454393, 70.64481289156022, 61.5465771767401, 5.710596874836953, 0.6518142658375925, 2.5894117499551466, 1.782321083930231, 20.509555878177768, 66.85842344837805, 52.558783638861875, 70.05214275852327, 56.27662966328283, 61.27975010102796, 73.54049482653218, 36.59666684366042, 27.780147521726548, 36.39833219589726, 83.49053598219349, 70.27942057578795, 32.10921452891442, 68.5727894690729, 15.54038747664421, 0.1266536469601335, 0.13199120369409362, 0.034908876198554234, 0.05070645572437395, 0.02567557850852609, 0.07656039099299139, 0.027182913956142245, 0.09963144292874683, 0.23738725140931147, 0.25934012907166637, 0.17910616262064827, 0.22338183116047616, 0.27860270512680857, 0.13642198045647916, 0.21582540034526781, 0.16185131915394338, 0.26241554307841486, 0.5093598792389517, 0.20026901977196818, 0.5165860189064857, 40.199571732551824, 79.03313098415252, 70.10613810631537, 59.90986231834658, 36.57578022249284, 54.07809411325763, 14.94218582107175, 35.484114000874186, 84.80565963252899, 63.72487329667615, 67.93830686999907, 70.80506524732037, 66.54361401834797, 76.16410547687163, 6.038598706645351, 0.4751698348310686, 4.651223036550707, 0.32436012560802124, 0.9386150310597113, 33.469557223781464, 71.58032171187863, 60.18123149871827, 76.90635127405967, 64.96268310854512, 68.48266124725342, 70.2032167680802, 71.25849908398044, 64.163574710969, 71.48340778966104, 60.9079094086924, 66.56424568545434, 56.46859045951598, 62.59943546787385, 56.47374837629257, 58.743490634425996, 69.02189300906274, 65.720312441549, 66.05520048449117, 65.67271447950795, 60.6191994297889, 64.42719721025037, 60.903006445977, 60.243569727866884, 57.094334017845895, 60.752807124968506, 57.50364511243759, 59.348312270256784, 55.5614560650241, 52.65833339383526, 50.841919068367254, 57.96508450661936, 63.268768325928725, 62.145989864103264, 66.39806270599365, 66.60287318691131, 67.18808297188052, 64.74559168661794, 62.91873601175124, 65.54055413892193, 66.96089929149997, 67.52133538646083, 62.25102309257754, 63.02198456179712, 56.54160538027364, 55.0128851398345, 59.61747707859163, 62.32428512265606, 62.95426484077208, 68.59842608051916, 63.46435731457126, 60.176979649451475, 62.839539435602006, 65.03897713076684, 56.168536986074145, 62.48512191157188, 63.40410970872449, 70.1362148407967, 52.43838256405246, 51.25423077614077, 65.92207524084276, 57.08355926698255, 60.72287159581339, 63.04119240853095, 62.6089785945031, 62.76748157316639, 66.23468814357635, 65.53481178898966, 65.58062899497249, 58.142469775292184, 53.764359412654755, 53.72758326991912, 54.74432045413602, 55.33341730794599, 62.170041837999904, 63.51413219205795, 58.238505086591175, 60.452118227558756, 62.265869263679754, 58.222035054237615, 60.7708578725015, 59.99093770980836, 57.30467896307669, 58.60215979237711, 57.23154244884368, 53.955975040312744, 55.549077064760276, 51.98023796081544, 54.52922551862655, 55.888809234865256, 53.143134424763346, 54.87558257195258, 59.10149320479363, 56.0804444743741, 61.18711156229819, 64.43192366630801, 65.423851859185, 61.80100956270772, 62.23808319337907, 55.44292596078689, 49.99761319929554, 48.27132709564702, 46.891147013633486, 60.90355557780112, 68.65736361472838, 65.87264553193124, 62.52647153792843, 62.31271413064773, 64.63357663923695, 62.333235971389286, 64.48676232368716, 68.62831454123221, 67.92417849263838, 66.78698139805948, 66.49142296083512, 72.92283919549757, 73.96039239821896, 66.25785366181405, 8.454176648970574, 0.783782778007369, 6.467593725650541, 1.7189620579442673, 21.449963738841397, 74.2019162639495, 61.089370019974254, 74.39834856217908, 62.11162205665343, 66.89363064304476, 79.7605109983875, 40.52479897775958, 32.06813554609976, 50.33440751414145, 80.99642630546325, 82.56917122871646, 41.85777333474929, 78.70351068435177, 27.44518887612128, 0.33517884991822705, 0.35452958737169543, 0.11737953210549971, 0.15294491884208497, 0.07973010276233958, 0.1637158239440572, 0.10430120081911165, 0.23966977973618817], [0.061833005653874534, 0.0218211354372362, 0.07751567965193142, 0.04547280732602362, 0.05147312587547687, 0.033890124815966816, 0.03808468985821932, 0.1099665895585091, 0.11090963613241912, 0.15190426500574236, 0.11138054271859509, 0.30779751918969617, 5.7851228887035, 44.39853568230906, 41.3555726697368, 40.41514127485214, 30.065757728392082, 42.8577894549216, 14.234820681233561, 9.748339153105213, 62.217804539588194, 64.15208216636412, 52.08930730819703, 64.80560787262456, 56.94624885436028, 65.32318815108269, 25.70210522220981, 2.4793706353633636, 1.2362775134463464, 0.032244307484718106, 0.43292713381590386, 10.498146299392948, 65.40575404320994, 65.7687811697683, 66.82505192295199, 62.00723601925758, 69.65629716073313, 60.72213026785082, 63.403337001800544, 60.870780252641254, 63.1765926268793, 63.20203311981694, 63.71911917963336, 56.74261116212415, 57.43221875159972, 57.3729125145943, 46.06274243324034, 62.197902433333866, 64.64284519995412, 60.20808404491794, 62.173426843458614, 57.979946367202274, 61.299867937641764, 57.697261148883456, 58.59104771767893, 56.19999047248594, 56.27054606714557, 56.872959367690555, 51.55932449525403, 51.131574338482274, 50.75253217451034, 45.55983966396701, 48.521511554718025, 54.4958383037198, 57.75026021465179, 56.13123524573542, 58.233072603902514, 58.368523813063106, 56.40057263835784, 58.44767724314044, 57.815610824092744, 58.346617375650716, 58.95799329203945, 52.86048450777608, 51.6306802534288, 50.60818502979894, 51.17916837815316, 53.07151194541685, 55.07956543276387, 59.010337321989006, 60.19372817008727, 59.680340905343336, 56.97804750934724, 57.32594213178081, 60.12840893960769, 51.45556995945593, 53.72207626219719, 57.8175720091789, 56.436297585887296, 47.42826461791993, 51.00291275208997, 58.944057110817205, 58.752653291148526, 52.733729193287516, 57.90578219198412, 60.12389036916918, 57.91152846428656, 58.683180270656464, 57.75116628216159, 55.54265614478819, 55.52793156716132, 46.88324343773627, 44.737852081175774, 45.90012881063646, 48.96901476767756, 53.858649269227065, 55.39916799914453, 55.15783632955244, 54.90532198259908, 55.69742110467727, 55.24297529651273, 54.95819945489207, 53.41127941685339, 54.752804540818744, 54.93270404877202, 53.25631441608552, 50.79678435479441, 49.076558313062115, 49.124481831827474, 50.84072666783487, 50.173786455585116, 48.917600339458836, 48.22172872481808, 54.35478594995315, 53.57620331548876, 57.33470862911594, 56.37478305447487, 54.19521608660298, 53.631646017874445, 56.8021527413399, 53.76650494913901, 62.24975616701188, 52.6935209766511, 53.29008210089899, 52.19534466343542, 53.60606824198077, 62.1087351922066, 61.39558945932696, 58.632491480919626, 58.869802721085094, 56.77945398515271, 57.47821638661047, 59.85924020890267, 66.17995539019185, 63.691403711995775, 65.52857914278584, 63.27121588491625, 66.20559200163811, 33.37254524230957, 0.8311545908931763, 0.15151693095122615, 0.8252402695436633, 1.2576907128095627, 31.64880083453271, 55.243555807298236, 64.7918285862092, 60.582929272805494, 62.06418491178944, 62.71515715506769, 74.32132890147548, 25.167372418988137, 29.269665633478475, 41.02780372865739, 34.33918199231548, 33.38111954350626, 34.50682017111009, 60.500041746324115, 6.608427897576363, 0.2931982735472341, 0.3038591531015212, 0.05391856662989144, 0.055079293257046136, 0.05950422859900902, 0.024864417801220572, 0.009512586534143457, 0.017695962639165022, 0.06321094885107971, 0.09683542884886266, 0.020969253326315555, 0.06340098845201635, 0.03229206157547813, 0.011789718729203508, 0.05278882825927389, 0.07320167767184396, 0.07537486993016736, 0.1100521922231682, 0.060383429405309504, 0.12927168349344886, 7.683778530166996, 58.68874219156081, 47.579264102443574, 40.04988231966573, 42.866587331218106, 46.422070764726215, 20.587161933222127, 12.261173244445557, 68.9302429076164, 67.29687383097988, 54.353185622922844, 74.47041819172522, 62.050735104468565, 72.62183650847405, 30.827046632766727, 3.2536317984904013, 2.2662542904576948, 0.09931800571540672, 0.7807388961795838, 13.358336667860709, 69.62291779056673, 67.12950629572715, 69.84013865070959, 63.26996072646111, 71.10133755591609, 62.66297786466537, 66.87103779085221, 63.95612839729556, 66.7672283418717, 64.23915878418954, 65.0833430597859, 55.739359086559666, 57.20785525537307, 59.615966966075284, 49.3791260257844, 63.42558468541792, 65.49511348047565, 60.316447365668516, 64.11980498221614, 58.9048961670168, 59.552228450775154, 58.68803224255962, 61.100050633953465, 60.43789963568411, 57.96318215708579, 57.5746557020372, 54.25218066861553, 53.98535359290339, 51.64843682319888, 47.02270723158314, 50.31294822692872, 57.33837212285688, 61.50391747874599, 59.279243253892474, 60.48662724033479, 58.95663222958965, 62.0174773277775, 61.96627862991826, 59.86554345776958, 60.19768584159113, 59.69064104941584, 56.87298682428176, 54.015018478516616, 50.88040928686819, 53.76407700200235, 57.65296582252749, 57.5595663439843, 60.110675904058645, 62.40352484487719, 60.85870327488069, 58.97836608271445, 60.16561654306228, 62.250944645174094, 54.59204619930637, 57.23418220396965, 60.5343311063705, 60.06944787117743, 51.08802426245905, 52.2172236442566, 60.39039188815702, 59.36205625534058, 56.78279584453952, 59.13961864286854, 59.52114758952972, 60.832894079146854, 60.94412857486356, 60.550726613690784, 59.397122244681086, 56.4577764849509, 50.07138121512629, 48.47773005885463, 49.19121311556909, 51.32906175428822, 57.4024675738427, 58.26007812253891, 56.71593512258222, 57.17817075790898, 56.910951445179606, 57.91734533925211, 56.7397556766387, 56.06286441126178, 57.172746119960664, 57.32892705548195, 55.662147229717625, 54.342116694296564, 50.10510575386786, 50.07846501565749, 50.07437398356777, 50.34401732106363, 49.70864434396067, 51.21083759492444, 56.3849655274422, 57.18077128933322, 59.57109112893382, 59.148047816368845, 56.60633625522737, 56.68159084935343, 57.71229167138377, 57.11741324393981, 60.48846683194561, 51.07820264754757, 51.644181051561915, 53.54416539592128, 54.25682867726972, 63.52666024238833, 64.33777109269174, 62.359088313195016, 60.03640190247567, 59.48422239672754, 61.36482238769532, 61.6842366803077, 68.34037334688249, 66.14647403840097, 67.80567584499236, 63.88085811368881, 67.87599609744164, 36.89814021510463, 0.5921955875331356, 0.33708717493760976, 1.7020896149258462, 1.530473907628367, 37.138887451541045, 60.3077357815158, 68.68038792763987, 65.84372981902092, 69.2283744196738, 68.22687564357635, 78.77031649312666, 30.602730204982144, 26.124071844162483, 42.27095580870106, 44.98489864410893, 39.45769856053014, 41.21241008081744, 69.04297182636877, 5.751225765674345, 0.21212472069648006, 0.09128123777167452, 0.03528496791278163, 0.06455354092101898, 0.03574156397653203, 0.04637486436554501, 0.02643723652938441, 0.0314647019390137, 0.17920550890266898, 0.1670902114241354, 0.1492485292856732, 0.16379073202129335, 0.2353228589579944, 0.09906217065309325, 0.19115335488271332, 0.18158706175463815, 0.2104436939642314, 0.20108323333965195, 0.21196903630850777, 0.3927582634552833, 12.688093819925863, 76.90391155981249, 59.98075523684102, 62.27038391174809, 44.16389557623094, 64.4059811099883, 20.91970047643108, 18.03595627507856, 74.93755678976737, 77.86477458092475, 58.69359416346396, 78.5415324857158, 65.67223202797675, 78.40487710891232, 36.81567238223168, 4.170675816074494, 3.6747820771509603, 0.4014086218610887, 0.8442717934808425, 19.057670947044127, 71.6623463169221, 69.44304573920466, 72.95967809615597, 67.34773128263413, 75.25307224642846, 64.96538562159385, 69.95180068477508, 66.9933686717864, 67.38060858941847, 67.57960611774077, 67.1417833143665, 56.43853725925569, 58.60606255069856, 56.031438381441184, 51.15883873355005, 69.61093102732013, 66.23621002320321, 65.25216579437256, 66.41213617017193, 61.16648381756198, 64.6676738031449, 61.099030817708666, 63.11556839173841, 63.01678349894863, 59.83871052342077, 62.67768283044139, 55.6905726463564, 56.06205640300628, 54.5880610712113, 50.503257705319314, 52.69667063989947, 60.350199361001295, 64.16672437421738, 62.20381736755372, 63.83834746576125, 63.80149679799234, 65.8711471865254, 65.69415807723999, 63.384705743482044, 64.68370845240932, 64.8261179462556, 59.92165688545474, 59.34630793909873, 53.30496749570293, 56.685536753746774, 61.88148483153313, 61.581815750368186, 63.8630074070346, 69.58433735755183, 65.61785228790777, 63.23714617759951, 63.43812058048864, 66.53779322101225, 56.395202913591945, 60.24645266994354, 63.181197489461596, 63.48850342535204, 51.77594523276053, 54.781076985020796, 64.38596133262881, 62.52067819718392, 59.846339533405924, 64.17679702081989, 63.55521901961296, 64.07831415053337, 65.49392107994326, 64.49604657388502, 62.55964302247571, 62.34093558403754, 51.541995463832734, 51.0960651213123, 52.00724347945183, 54.121918755192915, 60.12574957263086, 62.22752417287519, 61.415354282625266, 60.58136816947692, 61.411008296474336, 62.77012525066253, 60.2548739987035, 61.68854736512708, 60.74887691005584, 61.28944620009392, 58.98584996500323, 56.806035887810495, 53.1119280476724, 53.22848127734277, 53.19370554339502, 53.6510774397081, 51.97775902286653, 53.36318723617062, 58.0010957871714, 55.96165549370551, 62.721731047476496, 62.03915626771989, 59.35659239369055, 58.31252021174277, 59.61473534184118, 58.156049020828746, 60.76153832097208, 53.59556413465931, 55.197079643126465, 55.422106019912235, 59.55469954398371, 65.0465629946801, 67.00763040973295, 62.56675820196829, 63.38225033975417, 60.422649460454146, 62.977461737971154, 63.880418808229514, 70.37965282317131, 68.54713716814595, 68.96869782478579, 69.74059674047655, 67.6853375281057, 42.028345446432795, 1.5359718448692754, 0.3871182015826626, 2.590106744920054, 3.917190927651621, 45.10207945300687, 63.64304481014129, 74.38864461837277, 70.20888851534936, 72.6178200014176, 73.26819604442966, 85.30322013362762, 35.16487621491955, 39.47696916518673, 57.662069643697436, 44.32160623611943, 49.99181201381069, 47.43320288196687, 86.80135373146304, 11.769189373139413, 0.6424738154295953, 0.2757090071756994, 0.2080304403939555, 0.25093582278538135, 0.2609917227058642, 0.12437186173854337, 0.06762651876816828, 0.10179820004850627], [0.01765047425344106, 0.052893165604121266, 0.023945336372801856, 0.03667057965010886, 0.007635489173774278, 0.026514157502641602, 0.05001100110671213, 0.08311643355315732, 0.06244851133575844, 0.12571780161271173, 0.1046820461089092, 0.14488535212172618, 0.8996747818685348, 33.475813404206306, 47.83125677416402, 36.33140479364703, 20.30508860465019, 44.121671261325965, 26.20520410999175, 3.9292693763009967, 49.74391037417997, 64.19405544957807, 45.93446523912492, 56.73644911858344, 65.91200259424025, 62.85088685251052, 59.23303773326259, 1.1422002003077538, 0.6921692649202963, 0.09725995647210268, 1.7296078608882044, 10.461273077995548, 38.267890714829974, 68.43820510372039, 67.50475160537228, 63.97402617239184, 62.42985179347377, 64.50071811676025, 66.43974181144469, 60.0788458701103, 62.98391795927479, 60.487796106646144, 57.513811895924235, 56.96882601707213, 55.773373880693995, 57.97200356760333, 46.54854366856237, 59.28780971034881, 64.44778180891468, 62.505777112899295, 60.74709223162744, 62.759209294472974, 59.49119244852374, 60.841754713366115, 61.67870613836474, 58.22105053932437, 60.08059132483698, 59.82121675245224, 54.01852899982084, 51.85290998028171, 51.48520346610777, 46.81182099926857, 45.9850206682759, 49.16910663727791, 57.4831428835469, 57.68830245540988, 57.43101458395682, 54.21777363746397, 56.84611074386105, 56.286753300697576, 55.51647824625815, 58.321459293365486, 55.56278182614235, 50.75002577997024, 49.00043295275781, 50.37353315661031, 55.588653779798946, 57.87403452780939, 56.09518081911149, 59.06996519334855, 57.834002817830736, 56.76423126651395, 58.76991956464706, 58.38483695060977, 54.58132636162543, 51.64731110295942, 57.10814468322262, 58.92735565862348, 60.15361409033499, 52.15729767276395, 51.874596764964444, 58.88988525636735, 54.55274797254994, 51.17264155418643, 56.31555918724307, 59.19244120197912, 58.97305519350114, 58.74576168675577, 57.3854797886264, 57.30948778890795, 53.66345643997193, 46.10516678902411, 46.090963886630156, 45.25385164445447, 48.38092988537204, 52.2100535515816, 54.9226470916502, 54.52975111622965, 56.267517997372536, 54.56103986309421, 58.120610406321866, 53.826776089206824, 53.066620749811975, 53.81660538335001, 52.87667212947723, 50.41887575580228, 46.56829280237998, 45.04515801706622, 47.37419474509455, 49.53155325305078, 46.85304510977961, 49.701807652750325, 52.503034991602746, 54.274314603497906, 56.937643174202215, 56.71383665454004, 55.22253190317462, 58.71097810806767, 59.90948969318021, 57.16858056283767, 59.51936683347149, 55.90282778586111, 55.90768368013444, 53.4812976467994, 56.52724950544296, 50.02933732924923, 49.71538297591671, 63.885965039653165, 60.18349470630769, 59.10201880239672, 58.263949501898985, 58.45929530359084, 53.017249876453036, 58.60492114097842, 62.10706818488337, 63.41518255972094, 56.64463035521969, 55.84218794299711, 8.768294761257788, 0.24588143513087304, 1.4099133639566361, 2.3945395744615987, 0.2386080278384109, 42.78105220487041, 64.64343355547997, 59.15420593753938, 58.87968317154915, 58.865841127211056, 63.68934446765531, 63.461564587008574, 18.89118398389509, 34.09251982165922, 38.42319696180282, 21.210854091951926, 27.14191317558289, 47.987292581988925, 38.16711325799265, 0.7186064688909439, 0.10410588670281634, 0.049077978793291316, 0.08688507286170799, 0.076624964544129, 0.04269747762009502, 0.047604040948734175, 0.08588450840644299, 0.027699946696239135, 0.08821058117093579, 0.023230528458952907, 0.09014214929794112, 0.02159473730341321, 0.04511040560300312, 0.02514112684425087, 0.06845101323579589, 0.04751458103137632, 0.01796069006705957, 0.046983697421608434, 0.10026623104368487, 0.00326628792531518, 1.6822586016308878, 43.54119577715474, 58.80048267302975, 35.57635638021654, 34.79467507331602, 50.86821071563229, 29.54487285306377, 6.786669713835563, 53.618541379128736, 75.12169637987691, 47.308396985453946, 64.74067695679204, 70.13939196063627, 68.96391253317557, 64.8982346442438, 2.4078231713464184, 0.8726536350384836, 0.04033355628170314, 5.19444041675137, 16.235715843016102, 42.147365846941554, 72.43576711223972, 70.50039906655589, 69.27705887825259, 65.09691446058213, 68.74833122376474, 66.86560138579338, 65.52108741575672, 63.47946628447502, 63.296848573992335, 58.68438443829937, 60.42439491518083, 55.17195293980261, 60.83920125038394, 50.46764258415469, 59.98573272458969, 65.38715024148264, 64.95708196393906, 65.10313533967542, 63.82904360371252, 61.677878518258375, 62.764645699531805, 62.1974866620956, 59.277552712348204, 61.280989570002404, 60.713912902339814, 56.60510070862309, 54.95812885222897, 54.537862577746, 47.71258938697077, 47.47903577743038, 52.369627337301935, 59.19938379718412, 59.357902465328095, 59.29132415402321, 59.12754166510798, 59.08787865792552, 58.15684133960355, 57.915905829398866, 60.479876841268236, 57.85471685471074, 52.03308797651722, 51.72128308203913, 53.94716147453555, 57.85699967415103, 60.22613479245094, 58.70600454268917, 59.26417350769044, 61.42588976890811, 60.163039545859064, 61.40583076784688, 60.48381490092124, 59.54358746928554, 53.829164812641764, 57.797042323697, 59.367618176244925, 62.72821472537134, 53.50438471763365, 54.88704765996626, 61.422524375300256, 56.118134529359885, 54.72992535560362, 60.77863593255321, 64.00539336665985, 61.98748688543997, 60.02967896000032, 61.59484586408062, 59.205647822349306, 55.90520866455571, 50.20021538580618, 49.11584477270804, 48.690365668266054, 51.8906706379306, 55.73724885140696, 57.3123707309846, 56.97068914290398, 57.62349705542288, 58.31077867938627, 59.93246693764964, 56.98450765302105, 57.53170182628017, 56.07282330912929, 53.30238657612955, 51.92556796535369, 50.346915952620975, 46.90538913972917, 50.04133193723617, 51.01236174183508, 49.26140785217286, 51.46963950126402, 53.12230663914835, 57.189984936867994, 58.46215863381663, 58.52806621982206, 57.466480655054895, 60.721612514988074, 59.46971354946014, 60.05996750247095, 61.80432396550333, 57.576479604167325, 57.40669588888846, 56.614486940445445, 56.82515744240054, 51.29348193445514, 51.10743215007167, 66.0141646477484, 63.178396917158565, 62.303873108279326, 64.38245081132459, 62.62068686946746, 57.38010614149032, 59.96652487785586, 63.68453564182405, 62.97429246287193, 60.49044762888263, 57.68644717431838, 11.076575286926763, 0.4717583227301798, 2.8334013156352507, 5.60222472875349, 0.2702496807661749, 50.11753182257376, 68.63869313270816, 64.6258887936992, 63.492374804712114, 66.51173299358737, 69.09870086177703, 68.29853734662457, 21.267940267439812, 33.31953048706055, 44.58165153380364, 28.818132185166885, 32.88633804167471, 56.477745271498165, 42.87797397182834, 0.6369949997432771, 0.06271447408043089, 0.0476472674598617, 0.06058531272555552, 0.03183954492992452, 0.04102939011288747, 0.059934061381124684, 0.019147048080940882, 0.0637183327137703, 0.20264966864018671, 0.104053279445056, 0.13912435560937852, 0.2727946248506346, 0.3106260383802076, 0.10671363467530859, 0.1226822394997843, 0.09106648800474021, 0.2471347702967544, 0.21058243248731862, 0.42855819567076625, 0.21712215737469737, 2.695029901881372, 65.70623897737073, 66.91739236154865, 56.82445926050986, 32.953055597120716, 65.38635007796749, 36.26169643094463, 9.019436278650838, 61.476154942666334, 79.32982690872686, 53.42741604774229, 70.22165975263043, 74.20991789910101, 73.29461712991038, 71.64129887857746, 4.843079889974287, 1.8658634010822543, 0.34544219112684654, 6.31708404710216, 17.783696882186398, 46.847200778222856, 73.82221514178862, 72.73349854253954, 69.37765982843214, 66.67499772963986, 73.21511853125789, 68.83333683013916, 67.09093370745259, 65.58788930216144, 63.338480611001295, 61.519473598849395, 62.23071698219546, 56.094443413519095, 59.595405901632006, 48.72081895028391, 62.101474885017645, 67.08497170479068, 67.38071057104295, 65.1534632713564, 66.69255425853115, 63.15202682249008, 65.61442021400698, 65.81583392235541, 60.23161042121149, 63.555709315884506, 63.70467701265889, 59.003834032243304, 56.24862394025249, 56.33258619616109, 51.61557912826539, 49.8585141858747, 55.7154953864313, 62.25770681135116, 63.47157447568832, 62.46018348201629, 60.8377891971219, 61.28018156174691, 64.02843729142221, 59.537072412429325, 63.93252357359856, 59.935479317941976, 55.45947051817372, 55.252953806231105, 57.268620614082586, 60.149523058245265, 63.76449315778671, 63.15726318667012, 63.28947844043855, 64.42994286937099, 64.11167390884893, 64.46092959373229, 64.30357194715931, 60.44119834899903, 57.016498504146455, 61.86891755750103, 64.42462413541733, 68.64030130447881, 58.367939379907426, 55.78584701784196, 64.3673889098629, 59.30527602472613, 57.11081581730997, 62.68395077797675, 66.99677328909597, 66.79372787475586, 64.85371182041784, 62.44165812769244, 64.78061845225673, 61.23635299744145, 54.557709770817915, 51.37929947145524, 51.561011114428126, 56.16875663880379, 59.03695452597834, 60.03680198423324, 58.279458553560325, 61.08759710865637, 63.58965350735573, 64.13925209353047, 61.0681813763034, 59.44828171883861, 59.64181930788102, 57.71026772837485, 54.70474373909735, 51.57267624332059, 48.449559596277055, 52.919002348376864, 53.56025495836812, 52.18021215931062, 53.0032705491589, 53.72517885700349, 59.219411419283965, 60.81920892961564, 59.596013869008715, 56.694573894623794, 62.60237332313292, 62.716867308462824, 62.742876545075454, 61.91435429357714, 58.45742825538882, 59.09721389893563, 57.50485712482084, 57.61802927140267, 55.583860643448375, 59.35996563203874, 65.37329250766386, 64.37089550879695, 64.33601779322471, 66.11797409672891, 62.53801507334556, 58.79167302962273, 63.49563821669548, 63.70872489867672, 61.43160466224917, 61.650104215068204, 62.987852096557624, 16.012942867894328, 0.3831574963706155, 3.2739320253172233, 7.4247898209479555, 1.5252342339484923, 56.882357366623424, 76.6972497201735, 70.80978778100783, 68.99759784821542, 69.81342730983611, 75.40455418248331, 74.56086804789882, 26.178241737427253, 43.35802501247775, 55.650023183514996, 32.189283832426995, 41.34418602912657, 64.42022715845417, 61.979406802885, 3.5340731759225172, 0.3321638955704628, 0.1291678172926749, 0.31580975699809294, 0.16928555894522898, 0.23151966142317942, 0.18809674067362664, 0.15663470472058943, 0.13697531044242844], [0.02636763744146353, 0.023199773859232668, 0.06501433514659444, 0.08944889335262199, 0.010379189982139056, 0.07434281160033519, 0.016927532401056062, 0.06780233594679064, 0.08152529957794374, 0.09765927980263388, 0.08956025955417464, 0.08722826493002715, 0.2195268614037383, 13.476637313442847, 42.57669671889275, 36.82325432377477, 29.95707669565755, 30.161589076442105, 54.2481327825977, 4.166540167024059, 29.4226949445663, 63.91630065056586, 47.27727297813662, 60.34088765421222, 69.00352847191596, 57.18248536509853, 70.4309731145059, 9.862838041397834, 0.8851081409281301, 0.3927472930762076, 8.939820008893168, 26.553290928563765, 29.314765045719763, 63.65962466885967, 58.998130906012754, 65.7253997556625, 61.3936008176496, 67.21163288239511, 58.437220204261045, 64.86311374172088, 58.602344143775206, 64.13131713867188, 60.13364530378773, 62.384670011458866, 59.02386557671332, 55.22980789984427, 45.71150202904978, 59.499562786471465, 64.57137961541453, 66.39262630093482, 60.13728918567781, 66.08092338808122, 61.58897799830283, 59.97103168118385, 60.635343905418154, 60.09723001910795, 59.61635920309252, 60.291556004555, 57.12047661504438, 52.956331545306796, 52.6408435452369, 50.09992038050006, 47.78960120293402, 45.661562412015854, 52.94509003239294, 57.35450483137562, 57.59184352813229, 57.90988891355453, 59.10135984420777, 55.590383545044936, 54.54748807414886, 55.70752513024115, 52.6911832440284, 50.719458749217374, 48.503754984947946, 51.07866940959808, 55.10934014474192, 59.26262417147237, 57.74318033649076, 56.37873680360856, 57.46418214613392, 58.980892089105424, 59.25349289371122, 56.781642667708866, 51.859687835939475, 49.30631114590553, 56.10473179048108, 56.10625759247811, 58.01696177451842, 51.863453311304895, 52.35928796952771, 58.7741792586542, 54.61430172766409, 50.91041934105658, 54.28785462533274, 58.640500960811494, 57.11033336577877, 56.82914649286578, 57.78218830785444, 55.827498666701786, 55.711514180706395, 52.438653207594356, 45.95633637520575, 44.461811357928866, 44.66020484124461, 49.07549927311559, 53.55873307874126, 55.12850876777403, 57.41840808622299, 53.08433025113998, 55.86378843553605, 55.369142255475445, 55.387753901943086, 54.82891813401253, 51.70161239562496, 50.817188524430804, 47.38762886293473, 45.25860163473314, 47.33177823405112, 49.22276858360537, 47.77489623715801, 49.59053393333189, 49.38530768117597, 51.5962379209457, 54.51498731490105, 56.87759168686406, 58.231856669149096, 57.97684769476614, 56.008296397424516, 57.34128252152474, 57.79527333474929, 61.57264132653514, 57.95266236028364, 59.26717804324243, 54.46812675845239, 63.698409065123535, 57.90381316215762, 51.595139657297445, 67.3322065414921, 57.98868933031636, 65.29412338810583, 64.29501725781348, 65.09946400119414, 58.35141051200129, 62.642522704216745, 51.424983316852206, 54.398292879904474, 28.687611395312896, 15.780750320803737, 14.96405597656004, 6.633468308756429, 3.433350387119478, 1.3546168924339357, 53.37077310008388, 56.942044073535556, 60.059991036691976, 58.63583334030644, 59.59162081441572, 64.61438840435397, 54.36271306007139, 23.107596597363873, 43.87456586284023, 33.74535083770752, 36.948785858769575, 37.17332586165398, 55.235448268152055, 22.51838795600399, 0.28338870153792445, 0.04963783201791587, 0.10845869869714785, 0.06694758100615394, 0.09264637580922536, 0.04761759304411469, 0.06162128959512038, 0.1386368478978834, 0.032058249625767914, 0.02090174182798834, 0.11704040796405847, 0.04968442165503099, 0.03250177814474991, 0.11410583156130968, 0.10830718182748365, 0.06636572190590444, 0.09727238241823451, 0.06239336449652911, 0.0850815869747631, 0.118257085822763, 0.08202116530869277, 0.28889184817671776, 19.464587434645622, 58.82372271630072, 34.813439692220385, 34.130908058535674, 39.70841253957441, 55.40474953189973, 7.550928833023195, 29.970432366094283, 73.42407887981784, 52.03551200128371, 69.2402199775942, 74.00800212737053, 61.26403708611766, 79.51963040136522, 12.499716108845128, 1.5621604073432185, 0.13830278759762166, 10.433071236456595, 36.46091361199656, 34.083627808478575, 66.94955579696163, 59.77381098654963, 69.5544018283967, 63.39115412004533, 69.92752121340844, 59.72401257484191, 68.01810356878465, 61.01120502718034, 69.75991833594539, 61.30133490408621, 61.61275932865759, 57.428578792079804, 54.365913714132006, 50.00949013617731, 63.07252430146741, 65.31318218477311, 68.502045600645, 60.093707730693204, 67.08183380865282, 64.43221784407093, 61.34071942298644, 61.04523551079535, 64.14521017382222, 59.99221640248453, 62.38682339268347, 58.52398695484285, 54.33942987072853, 54.02930767305436, 51.711449700017134, 49.50943500764909, 48.100876577438854, 55.25045917880151, 60.89419680256998, 59.390332621912805, 58.55387933792607, 62.085000930293916, 60.540673578939135, 57.95262313658192, 58.96207255701865, 55.4053771111273, 52.98179557246547, 50.094436906999164, 52.378688012399984, 57.00359390627954, 59.64201542638964, 61.25516860715805, 62.30985472279211, 62.187794485399806, 59.74852346604871, 62.50637723553566, 59.935695048301454, 56.36294534129482, 49.565728864362164, 57.08737181079004, 58.66205830727854, 61.81292964566139, 53.70657897764637, 56.04396250940139, 61.867336842321585, 57.89150476455689, 52.04526693590226, 59.22021942753946, 59.500970917363325, 59.38091893349925, 61.11012720292615, 60.119022707785334, 59.165231720093765, 57.70619238576582, 54.54120443713281, 46.39067219149682, 47.72661970507714, 48.22480778540335, 53.30053913977839, 57.038867781239176, 57.367229000214614, 59.01625617857903, 56.61112939157794, 57.88042014644992, 56.915587686723285, 56.399301790422015, 56.57258033752442, 55.79331521065005, 50.93269055889499, 49.55637793387137, 47.649968747169744, 47.77446477643905, 50.46236307390275, 51.69986694089828, 51.34288810914563, 51.91542863845826, 54.13173644773422, 56.832049046793294, 58.95713037060153, 59.01268289935205, 58.98702667605493, 57.926947301433934, 60.085349159856, 59.86483350876839, 61.75856951744326, 57.712683908401004, 56.8020546820856, 57.503688258509484, 61.05072290666642, 59.40071513575893, 54.334981902953125, 69.79000291516705, 59.81482328907136, 64.58009119956725, 63.81513880145166, 67.21883435403147, 59.852544723018525, 61.94288561421057, 53.605366137719926, 57.177268612769346, 31.192201645143573, 22.3192923684274, 20.222622732962332, 9.908450303539153, 4.136041287452945, 1.791329787623498, 61.01908114648635, 62.17984776343069, 63.77680547775761, 65.73245217723232, 65.00890039628553, 71.19570193752166, 59.34532342418548, 25.84447745353945, 48.17771188674435, 39.46493925586824, 40.73077048024824, 40.97923694118377, 65.31294684256277, 24.781020918200095, 0.18560851773908063, 0.06203207743143844, 0.05083250017055581, 0.0742005490727963, 0.10522714831055173, 0.04300880809164336, 0.023327243228953694, 0.11063860188568793, 0.028583054550953453, 0.19347041845321658, 0.24000197078191468, 0.09308273183001627, 0.17286151947994388, 0.32722823622245945, 0.19079003002374403, 0.25519724815122546, 0.13970577037863194, 0.16970609525038352, 0.1151924123687129, 0.18938681741635646, 0.21382675355961248, 0.5256753763364208, 35.82125348429526, 70.72085980446109, 54.29054929364113, 42.213685281815074, 48.14481496810914, 75.1559857399233, 8.367901175252854, 37.30900064591439, 79.22081639689785, 57.218594704904866, 72.55412070981919, 80.54063120195943, 65.37717957650462, 86.07715083706765, 13.45342766854071, 1.2089789202136378, 0.7712437572979158, 13.075179784528672, 44.200973741469845, 39.06225696686776, 70.05414316731115, 62.450601131685325, 72.1839117234753, 65.61712272705572, 72.110108406313, 61.70725314847885, 72.58332667812225, 61.4622187614441, 73.08306017229634, 62.413946582425034, 61.98811446466754, 58.69254296825778, 56.88141992015224, 47.639484251699145, 63.27643263724543, 67.90979123884632, 70.33895431026336, 63.49599907475134, 71.0797409857473, 66.65071041353288, 64.76538396650746, 64.57548633698495, 67.29176690501552, 62.802508338805175, 66.83132771522769, 61.785520122897246, 56.521785643792924, 57.153455903453214, 55.292087293440304, 53.06193351745606, 51.27155196282172, 58.01875037531699, 64.23908425915626, 61.335149657341745, 62.95935999962592, 64.97339117911555, 64.65341990993869, 60.11416289114184, 61.9798735649355, 56.863478998984064, 57.46098149207331, 53.382944214728575, 56.69247150421143, 61.26837914989841, 65.58435524663618, 64.28922391706898, 65.78328217229536, 63.61670609443419, 64.13663195025536, 66.08572436917213, 64.00218486785889, 58.713841438293464, 53.16734329346688, 62.058026790618904, 62.013598103677076, 63.80392474512901, 58.89386253972208, 57.73408828243133, 64.64478285081925, 61.55316283625942, 55.86951509598763, 61.34735215094782, 64.17530259778424, 62.48580048161169, 65.40895861964073, 65.05480389441213, 62.72783425546462, 60.65023322259227, 58.244910317082564, 50.54361104965211, 51.97184408864668, 49.96615186814339, 54.93484174051593, 60.932086898434555, 62.683789960799686, 62.48794601809595, 59.616461184717, 63.68975239415323, 60.171237299519206, 59.712378824910815, 61.16826457362021, 57.75659092010991, 54.52347532395394, 51.33475311340825, 51.260773289588194, 51.18707587642055, 54.326854751956084, 52.1806396976594, 53.533826028147054, 52.78817169127926, 56.975494046365064, 60.37552218283377, 61.350662631373254, 63.128355318500155, 64.0914737024615, 59.230182247777144, 60.00138298157723, 61.98889109396166, 65.89625035562824, 61.54976606369019, 61.04958149694628, 60.96352469536566, 60.53346426256242, 65.38946051751414, 59.226201042052246, 69.85638510796332, 63.63991083637361, 67.8252092484505, 67.46725374652495, 65.73158533342423, 58.80038069140527, 61.02454108576621, 60.298620193235344, 59.15503748001591, 37.73359329469743, 21.231277873439176, 17.635641136477073, 13.392943739891054, 6.503427028656007, 2.426269833118685, 66.3738146135884, 67.54625028179538, 69.53452325636341, 70.06804404720184, 70.13215911003851, 76.81929819045529, 65.34750292378088, 32.13243299914945, 57.26524345336422, 49.36508001819734, 53.53208841816072, 52.958994834653794, 72.47966627920829, 39.592683007640225, 0.41924226007634596, 0.1686682452958438, 0.16338154913917666, 0.21716291325226908, 0.16537547682321843, 0.17769119822450224, 0.20798622179896603, 0.2049300978861509, 0.16883891436361498], [0.03355606451570507, 0.06964897556651024, 0.06219980855202002, 0.09174539512323757, 0.02812318729176637, 0.13459633164588483, 0.027904723913619117, 0.08306512098398902, 0.021582198359312552, 0.08176018979640738, 0.0772087388641892, 0.23916753249302988, 0.3278499625382885, 8.282951462653376, 48.10560695586666, 43.095481164993785, 52.71106573843187, 21.317664154114265, 47.075898493489916, 13.448675717076949, 13.560226944185073, 65.80474930424845, 45.79317362077775, 61.40685842883203, 65.29407239729359, 62.21249365037488, 65.53980104384884, 24.612768888473514, 1.7279800772666933, 0.16024265708702226, 4.980799209687018, 67.96610862978044, 45.08937881838891, 41.00814088698357, 66.08055468528502, 65.1409940565786, 59.83097560944096, 62.40285411957772, 61.14030984140212, 60.665573612336196, 61.68130666978898, 60.77931058022284, 57.60766244703724, 56.84338077422112, 58.209714889526374, 49.55378916955764, 55.004679541434015, 54.03838011526293, 59.26734670515984, 64.0756743954074, 52.87124749152891, 63.20937187440934, 58.329590366732695, 62.94284682120047, 58.4022875755064, 59.84218574339344, 55.46873515652072, 59.812928784278135, 52.87107098487116, 52.61472055988928, 53.386482192624, 51.625161478596354, 49.503786794600956, 45.86367822462513, 47.840493955919825, 56.6088818734692, 58.42118947736679, 58.244212135191894, 58.60016722832957, 57.26253309557515, 57.50811269206386, 54.18877163240987, 49.40725334229008, 49.53373016849641, 52.2734861220083, 55.68642277871409, 56.808707021897845, 57.82359284739341, 56.203767714961884, 59.10194819973361, 58.262521759156265, 57.011022875385905, 56.54030315337643, 51.04743165354575, 47.814469029826505, 51.268582728601274, 55.57326239924277, 55.18164903886857, 56.80047004453598, 52.74311542510987, 56.31660646007907, 55.7355151637908, 54.452492190945534, 49.67629263477941, 49.26249827108076, 58.93791467912736, 56.017725775318766, 56.524798024085264, 56.87798392388129, 56.2314792602293, 56.06091499328614, 55.38834617983911, 48.90848475117838, 43.378417415003625, 44.51658725738526, 48.28736174491144, 56.59563210702712, 55.905004701306744, 54.86639638100901, 54.198585402581, 54.78832944746941, 54.85195421403455, 54.99869400455106, 53.03896019535681, 51.417832836028076, 45.66119370921966, 44.94008164252005, 47.15009012529927, 47.265933405968454, 49.067909486832164, 51.354349274789136, 50.255156024809814, 50.84058546250867, 49.88544910184799, 52.24991659964285, 52.78567706384967, 55.69232202345326, 54.39581786432574, 55.494575731215946, 57.17702934818884, 61.11135882716025, 57.03777736233127, 56.35654011080342, 54.22007606875513, 55.12948543794694, 53.01069559589509, 69.26734708970594, 49.78308700746106, 58.7231727569334, 59.940472495171335, 62.35506788376839, 61.03868907497775, 62.4331779633799, 59.64933064676101, 53.83074552782121, 49.26951931368921, 40.82440922337194, 29.00956738379694, 53.99387298091766, 26.57882751957063, 2.0892274283593704, 2.5721094396806534, 13.438788402465082, 58.891195328004905, 59.457044293803555, 56.08391184960642, 57.63643695462135, 52.10193341778171, 78.36391187483265, 29.38126883199138, 25.069548506890577, 36.08764909928845, 30.058022814412272, 32.12770065953655, 36.380124553557366, 56.882518183800485, 11.5862206105263, 0.15129375421712477, 0.11090903858383817, 0.11686787730263126, 0.03517236447923126, 0.05833038654659064, 0.02243892597635427, 0.03906615191109238, 0.0587495515543607, 0.029558069973943696, 0.0036823445313324734, 0.012155858003684591, 0.03088290987145757, 0.020599387991692752, 0.007143828786924602, 0.028273735060206348, 0.03603480711218811, 0.15890670699938653, 0.016507212515740145, 0.020106979232702046, 0.09817810518847359, 0.2366086149648313, 0.27628090713293324, 9.745532697246922, 64.68336720620432, 49.214829706376605, 52.3993000676555, 36.631536714492306, 48.18350130511869, 20.938059130022605, 15.74003415723001, 70.88353618498772, 50.090283116986676, 66.30902490308209, 70.84029597620811, 67.53493816621842, 74.34185858695739, 31.63861640038029, 1.6835268755112927, 0.49528690535695324, 5.535246825987294, 77.27059041300129, 49.982672891309186, 48.50597504646548, 66.65917488836473, 68.29080243264475, 61.31868746972854, 64.41367287789622, 62.566016874005726, 63.44145067276494, 64.08212277197069, 62.25517688259002, 59.15732422182637, 57.92145990556287, 57.04069560573947, 53.31218857919016, 58.10744693202358, 54.45023290572628, 62.51661069931523, 65.69864526871713, 56.67919820354831, 63.7480309701735, 58.90835961987896, 65.31563758850098, 58.84024766183669, 62.40478000333233, 58.882013059431515, 61.533343099778705, 52.692763959207845, 55.249980649640484, 56.36332188883136, 53.2546317192816, 50.235720680605986, 48.154142364378906, 49.90963835870066, 59.661407624521566, 59.785028965242454, 60.785323573697006, 61.191614443256015, 59.09579792330342, 61.63261828884002, 57.5214683625006, 53.019269897091775, 52.31784420628702, 54.17313314253285, 54.96701694303944, 61.117999399861986, 60.32952454782302, 59.79958880332209, 59.70099218430058, 63.19674968719483, 60.067525909793, 57.79237078082178, 53.34051593657463, 50.168922716571444, 52.95987736794257, 57.611969209486446, 58.75658350606119, 58.515040028479795, 56.548508751776914, 59.213437649511526, 58.93610646647792, 58.70799710673671, 54.61281122699861, 53.03580660973826, 61.41229875626103, 58.41633358309346, 59.43101936771024, 59.59042449151317, 59.62740459749776, 59.21308855856619, 57.26713795815745, 51.11556322343888, 46.33930483172017, 48.736124038696296, 50.912121649711366, 60.13684595784834, 56.90549150589974, 58.49448680877686, 56.523939025017526, 57.866044659768384, 55.52290308860041, 57.74212914128458, 53.34665444589431, 52.187958840400945, 47.465676184623476, 46.0325558723942, 48.593271317020545, 51.385728236167665, 51.298349595838985, 53.119337404927904, 53.23128577201597, 53.147221534482895, 49.559876688065074, 55.24009235443608, 55.69063148190899, 57.315559617934696, 57.320945032181285, 56.24397985396847, 59.93875449703586, 64.56943804217924, 59.13907735578476, 58.94174291241554, 56.30521197472849, 57.94467249224263, 53.120831827963556, 66.0978288035239, 54.656173029253566, 59.77740387762747, 63.60733555209253, 64.48678193553802, 63.96118433244767, 63.23106258146225, 60.380719323312086, 55.710388460466945, 55.04717842225106, 42.3025308885882, 36.864121498600134, 58.845664455044655, 24.073337085785408, 2.4810540676116943, 3.252939255006852, 17.103632419340073, 65.28906353058355, 63.03129234621602, 63.73375354274627, 63.51539911762361, 58.33212421786401, 81.62207572690903, 35.27313755404565, 33.37932309796734, 39.10281427444951, 38.33241370416457, 34.713583992373565, 38.555655402521936, 64.24583465822282, 10.20987464535621, 0.2897624917809041, 0.17818814413922449, 0.25872526690363884, 0.04739163924128779, 0.06304481885425987, 0.06028096897587661, 0.01997437898910815, 0.054431179042665236, 0.015624937781643485, 0.15460058806403992, 0.15449695168964325, 0.20144396882143714, 0.13333311394578026, 0.11411287957021307, 0.17220242339516842, 0.1075171689773279, 0.46767709656588496, 0.2355667507095683, 0.2581158286381153, 0.20100912199385707, 0.6233005345829072, 0.615607173212113, 16.751327091647735, 78.24368338431083, 63.54589946808354, 71.49430413399973, 35.66710041415307, 65.63869576300344, 20.376905241320213, 21.516995083901193, 79.89691534349996, 59.31954168504285, 71.29919759688839, 76.55392631407707, 74.61530270115023, 79.87176510595506, 34.91948881456929, 2.327788188572853, 0.4976786012130399, 9.35963717199141, 90.10313433985557, 56.715342844686205, 54.98105118351599, 69.13208807668379, 72.74266904400241, 62.487181155912346, 68.62741239609258, 64.30748647259128, 62.802527950656035, 63.821889200518214, 64.44886046071207, 59.86017765537385, 59.920797886387, 57.80750328494657, 56.104249338949884, 52.55171160544119, 56.82874248873804, 63.06020413675616, 67.35514456225981, 57.6698673156, 67.35627420486944, 61.80432004313316, 66.70669832537251, 61.8668818473816, 65.90451086721113, 60.23220662147769, 63.901474091314505, 56.30997765448786, 56.498035692399554, 59.07995154780727, 57.27448063512003, 53.01061714849165, 51.9908401273912, 52.64784497599448, 62.30301018684142, 63.32798827079035, 63.92196063072451, 64.25307535356092, 60.99568813077865, 63.39746129128241, 59.839224353913345, 55.51139877688501, 55.207293495055175, 58.3523871821742, 60.345441525982274, 62.74040545186689, 63.242919906493164, 62.948306760480335, 65.47273243627241, 66.03654569195163, 62.28117435209213, 60.168542631210826, 57.72542376672068, 52.642914556687884, 57.6908363065412, 60.36874824954618, 60.639101536043235, 62.0928535153789, 59.93528712180353, 64.60452756574078, 60.93828424330681, 61.24484100649434, 56.632886778923776, 56.028426001148844, 64.71114935413485, 60.265174142776004, 61.19992986802132, 61.90742738785283, 62.80859977968278, 63.218208974407574, 61.16584054885372, 54.3358487467612, 49.076142541823856, 50.93067053825625, 53.762519821043945, 63.29660930941182, 60.94445805395804, 60.90146887686945, 59.66381595980737, 62.63454068091608, 59.85709467241841, 60.550212783198205, 55.19644421915854, 55.79653939893169, 48.34409490708382, 49.10650168695758, 51.28388781701365, 53.131155506257095, 55.42918197570309, 55.81080505924841, 55.45520297942623, 56.14401040538665, 53.28780712619905, 57.983064651489265, 58.3565095932253, 59.923535700767275, 58.89075994491578, 59.59488814876926, 61.31363545694659, 67.03022326192549, 61.21618809238557, 59.37989519488428, 57.84280853886759, 61.264068465079035, 53.980097616872484, 65.71323256338796, 56.792911637213926, 60.420958918909875, 63.971484476520175, 66.29242543251284, 65.83725006349626, 64.6480344956921, 59.15087192289291, 60.184679262099735, 59.320553656547304, 49.28504013246106, 45.65538075662429, 65.17656995404151, 31.402266140907045, 6.067633561549648, 4.315541694241186, 18.61523347516214, 71.34815662137925, 68.14280356130293, 69.37784025746008, 69.4135259812878, 65.14817199399396, 86.87354103211435, 40.5507101551179, 32.800981383169855, 48.08226100860104, 43.578340622686575, 46.21183956823042, 50.35945969243204, 79.01128338229272, 20.169800173851755, 0.29198604665936967, 0.24286029079268057, 0.2542440968775942, 0.23437188337406806, 0.2716533683480755, 0.14641794165776623, 0.14250358476513816, 0.1427037328962357, 0.1632323458550438], [0.04290982953182632, 0.01077373771207227, 0.08160523319196317, 0.011750284353301171, 0.033490491219826286, 0.024617262515089205, 0.05039791381286998, 0.1355111632015436, 0.016888002264163187, 0.03764259200843592, 0.03191069343067225, 0.04386936231786686, 0.18731511648624175, 1.3601555242653818, 43.461265717783284, 40.5050459215718, 41.128612564456084, 20.749045994973955, 37.8062944258413, 23.819469521122596, 4.240217478044571, 62.71072879914315, 62.02285881965392, 62.037881497413885, 64.96941781813099, 59.792140222364864, 58.952831452892674, 41.6468321892523, 0.6607479542013138, 0.5151509830067235, 0.7352767259843889, 17.97015851543796, 43.28940706868326, 36.5934112764174, 49.89528640624016, 58.797489904588275, 61.99959131979174, 57.868147050180745, 55.90272972660681, 57.47945193321475, 60.196375769953576, 61.27702013138802, 58.50669714712328, 59.60003822080551, 51.22150251942297, 51.587004661560066, 59.989513889435806, 51.371415507408884, 60.09023643309071, 50.12610612377044, 55.289482839645885, 62.16364837461903, 60.75683539913547, 62.72068769701066, 57.97145443577921, 56.96403288072156, 52.308834522001206, 56.30157985994893, 54.63261919636881, 53.82389314713017, 52.18989649126607, 55.411499930966286, 50.74209082511164, 47.677546931851296, 46.29079295742897, 48.79243358489006, 57.53978190883514, 56.85682273680165, 57.19298162767964, 57.46698271843695, 54.792079233354144, 52.58417706335745, 50.73556400114491, 49.159689026494185, 53.45251529447494, 59.42153115426341, 56.01882011659684, 59.833168214367284, 57.16242244166713, 58.420318711188536, 57.38050230087773, 56.99228963544292, 49.8534268717612, 47.91325784498646, 47.12745804940501, 55.35510409262873, 54.00627159303235, 58.53538928493377, 54.97051177486297, 56.718359147348714, 56.259834074204974, 56.44502093715053, 52.116093174103774, 47.25276208692982, 47.491650119904556, 54.65909519503194, 57.30047810462214, 56.98047937885408, 58.309711794699396, 57.807228719034505, 57.22448610490369, 55.75994368522398, 53.17234039306641, 48.60233199211859, 42.685475810881584, 43.95311524791103, 52.59236697227725, 54.569602397180375, 56.37183735447546, 53.94654958478866, 53.143848296134706, 54.66373928131596, 54.49996071477091, 54.214392554375436, 46.423051357269294, 43.08113705727362, 45.18393147376276, 48.95440393878568, 47.53612587528844, 49.09016109281971, 52.09824246744956, 49.57688016276206, 49.16246214220601, 49.01010551760274, 51.67585026833319, 51.9342520929152, 53.16005945205689, 55.74010041452224, 54.975799129855254, 57.975078705818426, 56.503201453916496, 58.175292168894124, 58.41482347057712, 57.34608742498583, 55.931402252566436, 55.48757822282853, 56.947358885119044, 59.98452855694679, 50.62822441900931, 57.848107660970385, 57.51961700377926, 62.72484540939332, 60.53145208666402, 54.183676473556034, 49.80895896111765, 41.8473437524611, 29.573741497532016, 17.87696300014373, 17.17614527671568, 0.9995432907054502, 1.3068589712342908, 2.956730684926433, 51.37708333230788, 56.747859293414706, 57.91261103845412, 61.32360612192462, 53.22786938759589, 63.406725929629424, 49.05912730001634, 9.095770505166824, 36.0782628674661, 24.535076541285363, 37.64525367367653, 27.6296010709578, 43.40074746839462, 49.459875860521876, 1.8227932025347988, 0.23053104027865395, 0.08525407167091485, 0.06250194213803738, 0.03268255574268199, 0.05146208271804837, 0.04487497529255287, 0.09399262211856343, 0.01666348679141412, 0.09043088017572319, 0.05339953056987255, 0.028836261931686636, 0.0527259401015697, 0.03723004216989202, 0.1022727685349603, 0.033262085935641686, 0.09419601080158065, 0.14416922845186728, 0.07103299767139458, 0.06533552516972826, 0.05043638291798773, 0.09976422128778312, 0.2425779873925832, 1.8360207830705952, 51.424343970514116, 48.76977405240459, 38.06604554576259, 30.811657213395645, 44.030731108880815, 27.540304391614853, 8.866892360871839, 63.26540685469105, 68.75525812948905, 68.20493390483242, 74.36285111211961, 64.5928075236659, 64.3302087629995, 46.36481984969109, 1.7994329141032313, 0.7395231819921925, 2.0925624235983817, 21.381002587656823, 50.51098477455878, 41.90587728254257, 55.5431503634299, 62.87073012321227, 63.52250645237585, 58.98123333531042, 59.460413609781575, 59.79809045791627, 61.348324898750555, 60.29758860988002, 58.70137614588584, 59.395965145480254, 52.968149646635986, 56.47706277908818, 58.6311068842488, 51.987965030054895, 60.628264027257124, 50.99455025888259, 57.41355611431984, 63.80149287562217, 61.387223043749415, 63.20179385523643, 60.946438850895056, 57.56575192174604, 55.79046364753477, 56.226070311761674, 56.182869326683786, 55.10027162490353, 54.87014224452358, 56.61128236401466, 51.44263006025746, 48.44789258895382, 46.76820032058224, 51.46789404653734, 60.40582249241491, 59.525164096586174, 58.94799124810004, 60.94520330429078, 57.62307343944427, 54.63614540715372, 53.06924873782743, 53.61797655782392, 54.780794574368386, 60.50050850837462, 61.8888000519045, 60.27183824969877, 61.725586306664255, 62.02888358023859, 60.55257012767177, 59.724534250074825, 52.833769244532434, 50.36736326832926, 49.633134795773415, 55.66338277632191, 57.36955888809697, 59.13197002103252, 59.57252279404671, 58.93349809031333, 58.57378928892074, 58.79910984346944, 55.01198691706504, 51.11207231398552, 50.202780615898874, 57.20621962701121, 60.29084997792398, 59.97706820887905, 59.7347951704456, 58.853717081008426, 58.56273604977516, 56.437540977231926, 56.26722381960962, 51.254693615821104, 47.48337391884097, 48.521939093066806, 54.270341242513354, 57.509018759573664, 56.99922438590758, 56.91711741109049, 57.236049252171675, 55.35581011925974, 56.051744491823264, 56.69447583536948, 47.86161199692757, 44.14408760686075, 46.09887530726772, 49.920346429271085, 50.041147585838075, 52.124436055460286, 51.61983882227252, 52.25747892933508, 51.67257508923931, 51.85784432195848, 53.43921845959079, 53.124899325832246, 55.816268920898445, 57.637950989507864, 56.79632802163401, 59.87879322421167, 57.28857763351933, 59.30558981433992, 57.399906266120176, 58.942307733720355, 58.68177606213478, 58.52693657721243, 56.7186023342994, 61.85846444099181, 51.53384085624449, 58.415094114119015, 57.15692327868555, 62.85149481988723, 60.289971367005386, 54.55403058759628, 51.88935664392287, 47.301979987852036, 33.192790862052675, 24.185911070915964, 14.431959006094164, 2.231351569775612, 2.2421018058253877, 9.29418360033343, 63.15154437095889, 62.790137183281686, 60.95967292785645, 70.36072346471971, 60.05533518329744, 71.0094678017401, 51.23264205071234, 14.401510627039018, 39.84337345246346, 26.640559742527625, 50.153515646534586, 32.9892590738112, 51.073044730770974, 54.66817548198085, 1.8465153296147625, 0.3723460039304149, 0.06629834447296397, 0.0270508959393708, 0.04401858092375821, 0.04973275031173422, 0.08680409736811154, 0.0706783832321244, 0.01699803547272759, 0.09434938926490084, 0.12819577429083087, 0.15702023080760436, 0.15075946917697308, 0.11772440956725229, 0.16344222330277966, 0.1028645791173462, 0.27133084533195345, 0.2382565620205095, 0.2297977409175327, 0.3249756925769391, 0.34611815646771465, 0.2522936217006176, 0.2915719914580545, 3.297593233085448, 72.60737080727854, 60.05790825813048, 65.1906277287391, 30.74565549050608, 57.11267109840148, 33.74181285981209, 9.595251006464805, 70.13685810950496, 77.13792016429286, 76.23302152079921, 76.62634111219838, 70.03812420752742, 68.55327175509545, 56.87373991935485, 2.6502035846633296, 1.4746713277793702, 2.1918540375847972, 38.83664223455614, 63.35447995893417, 46.513458067371005, 60.474997412773874, 65.52032647594329, 67.18810650610155, 60.36197039388842, 62.05085277557374, 59.99633096879529, 64.65077623244255, 61.92359539770312, 60.469184460178504, 57.69522151639385, 57.90402497014692, 55.09105405499859, 60.276474491242446, 54.928514957427986, 59.737391779499674, 52.35105491453602, 56.90633873785696, 67.56718004903486, 64.13099942668792, 67.1161231686992, 63.408514530428, 61.280577721134314, 58.05368692644181, 57.98002481460572, 57.81001360185685, 56.710690913661836, 56.475360470433394, 61.4678002941993, 55.509182637737645, 52.04551796759329, 48.44311121971377, 53.484455154788115, 65.91420696627709, 61.967227843499955, 61.810572301187825, 64.0286922454834, 60.977515789770315, 56.69212633563627, 55.65544389909314, 56.500389114502944, 57.88578594884565, 66.60243388145201, 63.304567798491455, 63.814562213036325, 63.70371603196668, 66.45343088334607, 64.01150834175849, 63.37124024668048, 53.30405750582295, 54.621107039913056, 52.57254331342636, 60.469647299858835, 59.54538783719463, 63.25804848824779, 63.51899200870145, 62.21114043266543, 61.05684180413524, 61.18360496336415, 58.47946805338706, 53.5290878049789, 52.741950481168686, 60.30671204290083, 62.04971136585359, 63.925145595304436, 62.87055361655451, 61.30548084935835, 61.96365456427298, 60.61541434257262, 58.77854877902616, 55.39779909195439, 50.00646206640428, 49.6419365944401, 58.192899688597656, 62.28517909203807, 61.16808414459229, 58.2160730515757, 60.8220487256204, 60.298745709080855, 60.12318042016799, 60.373604143819506, 49.31759972726145, 46.079483109135786, 49.220838777480594, 53.92097180889499, 52.938684801901545, 54.789459090079035, 55.67513027498799, 54.57444260197302, 52.1695315453314, 55.133862803059245, 55.75810409361317, 56.15492243920603, 58.37637639814808, 59.689966401746204, 57.522350895789366, 63.29340473298104, 58.630640122198294, 63.95327291181011, 61.38334774201917, 62.96314900921237, 59.27714478585028, 60.95882569589923, 56.76247796704693, 61.64057677791965, 52.303664838114095, 58.15301702868555, 58.181689554645175, 63.34296780247843, 61.79792657975228, 58.052082677041334, 55.520055447855306, 47.5569458161631, 42.10674185906687, 43.17085343022501, 20.42035137453387, 4.220018252249687, 2.6130751640565935, 11.331058663706626, 68.20709905316754, 65.55997379364507, 65.95527418198125, 72.80399137927641, 64.00682503177275, 73.97332053030692, 58.38501345726752, 16.928375036485736, 45.60551174225346, 37.39761483284735, 53.773753489217455, 43.82726207856209, 58.50689718800207, 72.76476767755324, 6.028841320545443, 0.7684800797893155, 0.42792672471654036, 0.24404781900586622, 0.22655634630110957, 0.17382479843593415, 0.19776316149340523, 0.23527530021965506, 0.17767445154247746, 0.14689757398539974], [0.021941198651949247, 0.04800003562723437, 0.01733172996600549, 0.04276187880144965, 0.08055193890486995, 0.018318487601655147, 0.02508090275730337, 0.047819702360298366, 0.02552609560230086, 0.11992585514822315, 0.11175391099025166, 0.08092461003651542, 0.11283421753755501, 0.07069634033306953, 15.745046946310229, 46.19755429606284, 42.030930288376354, 33.256050848191784, 24.564937545407204, 56.884761779539055, 5.240215457254841, 32.193643546873524, 76.7145081489317, 51.27752573259416, 61.87160045869889, 64.7266427163155, 58.12236762815907, 64.58900282459875, 9.699902784439827, 2.8160166355871388, 0.21626803062615857, 0.8173726691353707, 5.7195310534969455, 40.62998517867058, 45.04017268457721, 50.4533023988047, 54.741159023777136, 56.13012521497665, 64.94636212625812, 59.01044322598366, 61.956653133515395, 58.57176534591183, 56.48968496630269, 49.38283658796742, 58.230519140920336, 66.95259955621535, 58.970427205485684, 61.1945640656256, 54.806411573963786, 49.146513785085375, 57.33145306187292, 55.991218397694254, 62.111029778757405, 59.64274890961186, 60.710253330969046, 57.252982124205566, 55.75575459387995, 57.12753295898438, 54.22298254505281, 54.85439392828173, 54.25956649165, 52.27783995289957, 51.53134230644473, 46.19177272242885, 45.463380736689416, 43.39917067558535, 50.42781483742499, 55.887510930338216, 57.402565633097005, 57.18821202555011, 54.68720682205693, 51.53106774053266, 51.84370809985746, 55.63630665502241, 55.476556362644324, 59.439676038680545, 55.79984203461678, 57.64891009176932, 57.51324707461942, 56.39246902158184, 56.06923041805145, 52.32246083597983, 47.28166603272962, 49.06475590121362, 51.50390924945955, 54.764002907660704, 56.48053407669068, 56.986206039305664, 54.16702601217455, 54.72364171858757, 57.791378421168176, 56.332268484177135, 51.04115978364022, 46.80277993602138, 45.54036901843163, 49.45857363362467, 52.26522168805523, 55.25825685070407, 56.151207954652854, 56.492101146328835, 55.99837672325873, 54.9973564763223, 54.56904542061591, 53.35039246466852, 45.126625645545225, 45.781296683895974, 50.55466428879769, 51.69042187352335, 55.78967525113014, 55.26250085523052, 54.89546898872622, 55.37854025440832, 52.65529747932188, 49.535361874488096, 41.74871967684838, 43.84076287669521, 46.61110547281081, 50.110769656396684, 51.349089376388065, 51.392894406472486, 51.22962967042, 53.18579412275746, 51.095755254068685, 52.32531632146528, 52.49275445938111, 54.42063862277616, 53.69632197964577, 55.37451198024135, 54.52147883753623, 58.519621356841064, 56.32404327392579, 54.465934153526064, 55.552199271417436, 51.358185352817664, 51.50522716583745, 52.717847516459805, 52.007843602088194, 57.34712685308149, 54.2009662812756, 55.24494040396906, 52.24494303426435, 54.1363020866148, 54.440740769909276, 53.10980604540918, 48.331802198963786, 45.86785162648847, 25.10518323990607, 2.1296028360243766, 0.8086525047979047, 0.26353893441057974, 0.04415389886426349, 39.08047637631817, 55.21079617161905, 56.07191331924931, 59.24796627413843, 51.990032119135705, 35.92981684592463, 68.7500649113809, 33.42006867931735, 20.912648054861254, 45.29342051475279, 26.27755418900521, 36.53347746018441, 20.49228568230906, 56.50884966696463, 30.26779313241282, 0.18702659245219924, 0.10984242202774172, 0.10455641535020645, 0.01859139301814139, 0.0420640722938603, 0.053084963376844124, 0.07430896583584047, 0.03164827575786941, 0.0603802961056992, 0.07312591923701187, 0.03741999367071736, 0.01567682683197481, 0.042495345321273616, 0.027703800118498267, 0.07321776551825386, 0.02782413720964424, 0.019430920046063203, 0.005446551414582158, 0.07712620821210646, 0.016255137029915087, 0.09958950727577172, 0.08558186537195599, 0.05758484893087899, 0.09685680270195009, 19.432941752095378, 64.56875947213942, 40.92538279871787, 42.4857840230388, 37.51280700006793, 53.05282185154577, 9.847924209410145, 34.675968462421054, 85.36017294852965, 58.34878252398584, 69.579128449963, 68.80439758300781, 63.66390005234749, 72.474151426746, 13.771547578996229, 1.8096296056624384, 0.8420220690388834, 1.6569850545737053, 6.109671073575174, 41.7756232138603, 50.85367833414386, 55.96511502419749, 59.486618964902824, 59.15569251583469, 67.39366223735195, 60.1402231185667, 62.78130400565363, 57.11607179334087, 58.58492097546978, 51.11501409161476, 62.713956909794966, 63.46516140045659, 60.01936312644713, 59.06513675566643, 54.51822327029321, 52.316569435981016, 58.47624778747559, 56.65647983551026, 65.14589309692383, 61.212006845781886, 62.37491507684032, 59.030396323050226, 58.89578057873634, 58.00029954602642, 55.26598391994354, 55.9966234237917, 56.34560846513318, 52.65966699969385, 53.01425318564139, 48.15639772722798, 47.89593665830551, 46.51694113208402, 53.64656279163977, 59.830061697190814, 60.99604898883451, 61.20235389278781, 56.03348193630096, 54.9137354666187, 53.24760283193281, 56.91674086355395, 56.255750886855594, 60.977441264737045, 57.81418700372019, 61.439053243206395, 59.50102975291591, 62.45724562675723, 59.50288503400741, 55.89443783606253, 48.71497854109734, 50.52508961769843, 53.9037839827999, 58.34001602665071, 57.5641986631578, 58.77338301750922, 58.97840922878635, 57.24470984551215, 59.966893580652055, 60.40951736511723, 56.30122292426325, 52.717435667591715, 48.178037443468654, 51.526458955580196, 57.97965611180952, 59.60802808884652, 60.079281253199426, 60.70755866266067, 61.581086189516135, 58.33581909056633, 56.46713526018205, 55.873857159768384, 48.180159445731874, 48.42904560027584, 50.81511751297982, 56.05865570806689, 56.39959989055511, 56.935874185254505, 57.656558713605335, 58.865472424414854, 54.303893196967344, 50.46943902969361, 44.613320750574914, 46.6917533259238, 47.4726580035302, 52.15925885785011, 53.85920624579153, 52.84923122775171, 52.97278196580949, 54.39933623037031, 53.164299534213164, 52.96579230216242, 53.12694288069203, 55.19054497441938, 56.37379069482127, 58.521425647120324, 55.82192105631675, 59.400707291018584, 58.510850937135764, 57.81306520585091, 56.031669801281346, 52.83709149206839, 52.579999739123934, 53.09589732077814, 54.32720776527159, 58.059907805535104, 54.4602898628481, 56.57566724285003, 53.4581752746336, 55.85809315404585, 53.77387116032263, 56.37433590427522, 54.02829962392008, 48.966273030927105, 25.994843475280273, 2.598856327033812, 0.6602193535335603, 1.2683732879738654, 0.8439474012101851, 49.321533864544286, 60.07049514401344, 61.00400355554397, 63.97312010488203, 57.50593577661822, 39.88744912608978, 75.39561902323078, 39.605834714828, 25.62871571510069, 42.86962716810165, 33.18334971704791, 48.095173451208304, 20.966149184011645, 62.94541205129316, 34.613445881874334, 0.3624966566360766, 0.04018871586829905, 0.1290641043094858, 0.028257105206590027, 0.01695298184190066, 0.03973620305318506, 0.0772274237486624, 0.02545127179473639, 0.07692095793543324, 0.08770309388637544, 0.16135610459793, 0.11913782646579128, 0.16996489507296395, 0.11130244771559393, 0.2044205268424365, 0.2119673202715574, 0.08279500604276696, 0.11183520824077631, 0.12380730090362412, 0.165938628056357, 0.22212134073338202, 0.18812355375097645, 0.17885840978593598, 0.27396854734228504, 36.09871410554455, 73.98327550580426, 63.78653687815513, 49.41726323096983, 41.09761799535444, 76.2180772904427, 12.147568656552224, 41.28597021102905, 89.9554963265696, 64.81240534013318, 72.51067653779062, 73.92103533590995, 68.04098667636995, 81.68827749067738, 17.74990370196681, 5.6319886542135675, 2.0498741658464557, 1.2298225178833933, 8.743540683100301, 52.2060017431936, 56.81497889180338, 59.38214271299301, 64.48611121023855, 60.33022272971369, 68.01332612191477, 61.862257372948434, 64.44435757975425, 58.48158221090994, 58.01990355214765, 54.19278813946632, 64.59249373405211, 62.503851229144686, 60.06404284507998, 57.89159890144103, 56.52593158906507, 52.23290920257569, 56.98921057485766, 58.45125444473759, 68.65500234788465, 63.07140250359813, 65.80044254179924, 62.54544012008175, 61.68538593476819, 60.87898585104174, 57.51574562441919, 59.317823686907374, 57.78853470279325, 54.99027659816127, 54.94941726807625, 49.560323838264715, 50.529047289202296, 47.62474398459158, 55.90976645869594, 61.518814640660445, 65.58201751401349, 64.61378435934743, 58.33449725181826, 56.3946420146573, 57.53385520750477, 62.91598250789028, 60.18723664745208, 63.79230668467861, 61.71226985992924, 65.89230445123488, 63.706328330501435, 65.5863360435732, 60.83065440577846, 57.300266296632834, 53.939234364417295, 54.7318277051372, 57.20586269132553, 60.41590690612794, 62.167060836668945, 63.14122069266535, 60.883684850508175, 57.81468906710225, 64.0730385626516, 64.1301953408026, 59.682070670589326, 55.68146490281629, 51.410796103938935, 54.29862545382593, 59.5214339225523, 61.1274052435352, 61.791513504520545, 65.59393367459698, 62.21495297647292, 61.64322830015614, 59.807825780683956, 60.316682707878854, 52.12896247063914, 50.73775660607123, 55.84029736057405, 57.40635856505364, 61.604494894704516, 59.3389456502853, 59.37106593962639, 62.39302073755572, 56.43075919920399, 55.22913325217463, 44.788372208995206, 48.2566652759429, 49.139539810919, 55.002235904816665, 56.485448806516594, 55.98917484283448, 55.06768065114176, 56.317100678720784, 56.847769906443936, 58.0395350148601, 56.00626853204543, 58.585999627267164, 58.371238093222345, 60.22977475197085, 57.48021679539835, 62.57774476082095, 60.42568929733769, 60.91439700895741, 58.66585516160535, 53.51448482082736, 53.81101992822463, 56.18646221776163, 54.581616617018184, 55.31706886906778, 56.92027099670903, 56.60181768478886, 51.77807900213426, 57.11708376484533, 54.27740150882352, 61.07748523835213, 55.05508592051845, 56.84392990604524, 37.57329387049521, 6.130028665065766, 0.7766314391647616, 1.6228981868874643, 1.0250780431012954, 51.66058048125237, 64.26897271986931, 66.2377554370511, 65.83049574205953, 63.56758233039611, 46.61930714884112, 81.59662738923105, 42.03022033937516, 30.826373946282175, 54.528684231542776, 39.65111063372704, 53.248767775873986, 32.028596093577725, 74.17002739444857, 50.61454319184827, 0.9547037354880764, 0.22743005425699298, 0.32721554980643336, 0.12195673125285296, 0.11671597738900494, 0.20580881605705909, 0.1712191648661129, 0.11780618945316923, 0.16285801997348187, 0.2132807626959778], [0.0386361007939183, 0.015914850350048755, 0.023900730903410626, 0.07301819961397879, 0.07518956858304239, 0.054889134912481236, 0.014504282340978183, 0.09682268880668188, 0.03508190481713222, 0.10191404786441596, 0.03561307954031133, 0.0946387789782978, 0.048081466943145766, 0.4702383430013734, 4.664680198315652, 46.11876564641153, 34.42221072412307, 33.07437058418028, 24.27186785205718, 56.40489901265791, 26.062259212616954, 17.67323705457872, 77.72086281930247, 58.297109219335745, 64.65269034908664, 61.69565862224948, 64.6445631980896, 58.46215863381663, 53.495190681949744, 0.6206348550415809, 1.1447046336627777, 0.3595951445881398, 0.04774580168868265, 19.252653929495043, 43.292803841252486, 50.13673966930759, 57.714429363127685, 49.180814912242276, 54.10515062270626, 60.899429244379846, 58.08045710286787, 59.628228295233946, 59.667805010272616, 64.16116245331304, 72.53198285256663, 63.45595952003234, 61.35417315267748, 55.34698478637203, 56.444248230226584, 56.45827070359261, 56.00955155587966, 54.49662670012444, 61.65430115115259, 61.61417138191962, 62.48905997122488, 59.37390573563115, 55.91933704191639, 56.3974896554024, 53.12436980585898, 53.97875224390338, 55.95527771980532, 56.55407067268126, 53.067491515990234, 47.048732157676454, 47.86141980078913, 43.69403485328921, 44.104130421915364, 48.650537921536355, 53.19831040597732, 52.5044862685665, 52.111531457593365, 47.740406836232836, 52.21282274492326, 54.8043405625128, 60.60623991873957, 55.824843222095126, 57.9474965987667, 57.88216167880643, 56.84741689312843, 56.16403018274615, 51.917327065621656, 44.687233894102036, 47.565551496321156, 50.22555389711934, 52.95092651920935, 53.336695548026796, 55.012057519728145, 55.53302672601516, 56.384024158600845, 54.72446541632376, 56.028476991961085, 54.06227519435268, 52.48163453994259, 46.77206385520197, 48.14995327303487, 44.33465596168272, 48.12327331112277, 53.5025215918018, 56.25326018179617, 57.78031341491207, 58.09281256891067, 55.485244412576, 56.560934820482814, 56.390425466722064, 52.64392652819234, 45.375880502885394, 47.310734718076645, 49.0592763500829, 53.333847907281694, 55.55128928153746, 56.11598114813528, 53.025078927316976, 48.842902721897254, 45.31731951621271, 44.35168689297092, 45.35731200248965, 47.08920317311441, 48.481683807988325, 49.994063454289595, 50.38571603836552, 50.84577475824664, 51.38821894122709, 48.07173728942872, 48.38486794502505, 51.08376456845192, 49.18793401410503, 50.50043359879525, 54.719072157336825, 58.159422259176935, 58.62474872219948, 57.659731911074736, 53.8647367877345, 54.735008747346946, 55.51316776583272, 51.84435921330606, 53.33496186041063, 56.34632625887471, 57.236853338057, 50.280023851702296, 52.20752362282046, 54.28115521707843, 60.281808914676795, 57.971332842303866, 51.843178579884196, 47.50470769020819, 30.874426903263217, 5.505376015940021, 0.5463780138281085, 0.9200568881727035, 2.740276157855988, 14.304276051059848, 60.909450900170114, 54.447047941146366, 60.53776318027128, 51.310952171202636, 50.73646614628454, 53.77412219201365, 72.14526853253766, 27.06258127766271, 41.530353484615205, 39.65779827487084, 31.461354686367898, 29.8076638098686, 29.85054316059236, 51.50564293707571, 17.766052099966235, 0.20218937237176204, 0.07415875131564756, 0.04501890023088744, 0.0208876496406212, 0.02015127252126413, 0.08525403336651864, 0.02135502647668604, 0.004757794320598366, 0.029503321500434995, 0.03513716273911057, 0.04244070026963469, 0.02273372235527683, 0.06558541538974931, 0.03486562670478898, 0.06737286705643901, 0.054123246171061075, 0.05561458570281825, 0.05935385703079163, 0.05049560534497423, 0.09922410631852766, 0.07707624395768489, 0.07051280098817042, 0.04255588158905026, 0.2631082704230662, 7.417590800792941, 60.877071734397646, 39.6340012550354, 35.329262748841316, 40.55475804113573, 55.695267723452666, 34.380072701361875, 21.914735186484553, 84.28633782171434, 62.65717275681035, 69.80916761582898, 68.0983474177699, 71.27267452978319, 64.82116791509813, 63.63468231693391, 1.7233335395013134, 2.634090733143591, 1.4170078284317449, 0.17485275053449217, 23.975701447456117, 48.18647838407948, 53.42458409647788, 59.29889432845577, 53.573971486860714, 56.41985108775478, 60.520402769888605, 59.56674122041272, 60.42956067669777, 61.39525213549214, 65.4081113876835, 70.43268326790103, 61.707668919717115, 60.74182448848602, 56.462149927693034, 57.04944249122374, 56.3545593138664, 56.30476482452885, 57.32245514469763, 63.6012754901763, 62.18639419924829, 64.19603232414492, 59.94530485522363, 61.02709062637822, 57.8868136098308, 56.33719890348373, 56.6173698825221, 58.32809986606721, 56.5481988845333, 53.63180683505151, 51.0609559858999, 49.13001237377044, 46.814951050666075, 46.5746941105012, 51.34954044895788, 56.1461010286885, 55.398214863192656, 55.678691787104455, 52.41520920107442, 55.584503912156634, 55.31884570275584, 61.82299052515338, 57.81190418427991, 60.43121591691048, 60.48060640212029, 61.50630620218093, 58.56232812327724, 55.302552177060036, 48.95606702373874, 49.46027594227945, 52.686343039235766, 56.386930634898526, 54.473504327958636, 59.42929352483442, 57.85685062408448, 59.19321783127324, 57.89518394777852, 59.46299060698479, 59.4055788747726, 54.774216759589414, 49.2342415163594, 49.86375447242491, 47.78216438908731, 51.158599468969534, 58.04113141952023, 57.985312169598, 60.23048470097204, 59.67530458204208, 58.200285511632124, 59.29210078331732, 59.56973791122437, 52.14642486264629, 49.23511620490782, 49.39157170634116, 52.79301974081224, 55.031422261268865, 56.208847184335035, 57.12051583874611, 56.43792929187898, 51.83400415605115, 47.164026306521514, 44.171446138812655, 47.04975197392125, 49.0245908306491, 50.25507757740636, 52.814133859449825, 52.669621975191184, 52.93930453638877, 53.71845199215797, 51.37887193310646, 51.01943769762593, 52.998461723327644, 52.13285738422025, 53.23561214631604, 58.14773751843361, 60.045713609264745, 60.81614163614089, 59.173700117295795, 57.60442256927491, 55.9445696492349, 56.890735549311486, 52.53291952994562, 52.93357395356702, 55.90905650969475, 57.292531382653024, 50.55503299159389, 52.485364713976466, 53.79691116271481, 56.83114690165366, 60.91653862307149, 56.68385013457268, 53.62673128804853, 36.39981485182239, 6.949005828749749, 0.86421643293673, 2.4908668571902863, 2.469168060248898, 19.403494558026715, 67.62399950335103, 60.22141618113364, 67.17880264405282, 56.600244814349765, 55.19505962248772, 57.49073266983033, 76.175017510691, 28.455860114866688, 44.87674320897749, 42.39664423850275, 37.64783851562008, 32.43030955714564, 28.43249259456512, 63.89667311022359, 18.397559581264375, 0.10500628516198167, 0.011044160046073939, 0.08286232984955273, 0.0981121220355553, 0.06138247317604481, 0.05763861298140499, 0.02395572644027491, 0.04276566710623522, 0.06924913129619054, 0.0902757473710564, 0.1296951768979911, 0.15932264677699537, 0.1690891952884774, 0.12201740541645598, 0.19938116983300258, 0.1279160296244006, 0.16247678397884294, 0.12110769898901064, 0.13215312403776955, 0.18934615346933567, 0.15479685979024058, 0.21446616118473394, 0.19729620026003933, 0.7086512482454701, 13.457099007021997, 76.53661297213647, 52.917951153170684, 49.09664084834438, 39.313170986790816, 76.94937183010963, 35.6677907513034, 24.580797649198963, 88.96714533528974, 69.13161739226311, 76.70875010951873, 69.98012804215955, 78.53663736774077, 68.81425057688068, 74.31954814541724, 2.59394797105943, 5.757626093203022, 0.797356752859008, 0.2270708815945733, 29.255680422629084, 57.87956506975236, 55.9269582071612, 61.811501902918664, 55.028621688965835, 58.54904697787378, 64.89095080283381, 61.00716890827302, 63.517383836930804, 62.46326646497173, 65.51182277740972, 67.53483618459394, 62.08397719167895, 60.09898724094514, 58.0362049225838, 59.5979005290616, 57.11207489813528, 56.72480360154183, 58.01543205015121, 67.26162741261145, 65.97411724828905, 67.79132781490203, 64.1616919732863, 63.42501201937276, 61.15752120171825, 58.132965872364665, 58.4692189001268, 60.52386622275076, 61.662993123454434, 57.68223847112348, 51.565384557170255, 53.65789844143776, 48.33668947219849, 46.86245095345282, 53.73525542597617, 60.027149031239176, 58.982009964604536, 59.37177981099775, 56.10471610100039, 58.32797827259187, 61.25914196814261, 66.00427243017381, 59.96462645069246, 63.40359195586174, 63.587445212948715, 65.14853677441998, 61.49866542508526, 56.03130502085532, 48.79816416771182, 52.48752593994141, 57.64458763983942, 60.0393868261768, 57.45446643521709, 63.1060762559214, 60.131821401657604, 62.157541244260734, 60.96606639123733, 60.547196480535696, 61.2069038421877, 60.08807912949593, 54.059019627109656, 54.06072193576444, 49.28038427906652, 54.16747708474436, 59.536201646251065, 62.77014878488357, 62.905274437319854, 62.081290368110906, 61.28192701647359, 63.02729545101043, 61.25510977160547, 57.2166060632275, 52.742774178904874, 52.520630744195756, 55.9189526496395, 58.87109710324196, 60.51693539465628, 59.31807079622823, 56.91442274278211, 51.96333254537275, 50.142878178627264, 47.10142920094152, 47.98394680023194, 51.309583264012495, 52.706664839098536, 56.033050475582, 55.356877003946614, 54.87955593293714, 55.483848048794655, 54.61216403592018, 52.76286848129765, 57.885346643386356, 53.2535413003737, 56.65318112219534, 58.36760990081295, 62.9652710114756, 64.95417941001155, 61.09443772223688, 56.88444798992526, 59.32572726280459, 58.564740380933216, 54.90529844837805, 55.26867074351157, 59.398122449075025, 55.06226778030396, 52.67817274216683, 54.65787926027852, 53.13262247270154, 56.876901349713734, 66.60747804949361, 61.62526384476693, 57.1461328383415, 43.27068951822097, 11.210237895288776, 1.0842822371951997, 2.7011620373495164, 5.718780409905219, 18.79126552612551, 75.48312710177514, 63.70730107830417, 73.30832189129245, 62.03062903496527, 62.89390348619031, 61.823104273888376, 85.23692423297514, 36.897085097528276, 53.15819632622504, 49.73581852451448, 47.17355766604024, 44.0059809530935, 46.24643879552042, 71.75210583594539, 33.286300166960686, 0.30409106323795937, 0.12853193367200513, 0.26822328627590214, 0.17988175003518983, 0.188648400587901, 0.15166038857592692, 0.1633112222677277, 0.06731336500736014, 0.13767894687912158, 0.15468718664300057], [0.07752825881564811, 0.008234286478029625, 0.02360083046369255, 0.016084161526974172, 0.05520162600723486, 0.008288931529668551, 0.07089671829054434, 0.04855338476538178, 0.10705011581341106, 0.019192948238924146, 0.02215283810191097, 0.028186209514857303, 0.040838806589524594, 0.05811512733118669, 0.8724952693427763, 35.727653964873284, 46.03704306387132, 42.12766770393618, 21.832126148285408, 31.044916645173107, 28.130974115863925, 8.75153055114131, 62.1615695184277, 65.21167908945392, 63.6129641532898, 61.29164272739042, 62.74282555426321, 65.0357803990764, 65.59922102958926, 42.208817620431226, 0.23866502477997736, 2.249098578768392, 0.09643212952200444, 6.450600547175254, 36.95613638047249, 42.83524367117113, 63.29859010634884, 59.700843134234034, 58.34286758976599, 50.89218816449566, 59.333140542430264, 60.45553461197884, 61.55224892400927, 63.123311150458555, 63.45976029672931, 65.42000793641614, 64.9033768715397, 63.230870385323804, 66.29012692359187, 61.7340390143856, 55.88209805950042, 55.00349498564198, 61.48037933534192, 62.21418811428932, 61.82282970797632, 58.271311790712424, 57.15843339120188, 57.42766880219983, 53.459175479027536, 57.24904798692273, 56.9489945134809, 55.60856373079362, 52.29603190575877, 51.629954614946925, 48.10837222683815, 46.528684708379934, 45.14660227683283, 44.238910905776486, 45.39031874748969, 45.68271575435516, 46.53304638401155, 46.98267552160448, 55.644527942903586, 55.43400649101504, 56.971850164474986, 57.64271666926723, 57.36426368836434, 56.76414497437016, 55.66867013131419, 51.39343569355627, 45.50231026064965, 43.35659726973503, 46.20541472588816, 53.11633679174608, 52.78812070046702, 54.60791610902356, 56.23422491934992, 56.41922743089738, 53.95295873765023, 56.35579093810051, 55.88756584352063, 55.979482666138686, 51.94610941794611, 50.37628666047127, 45.47464186145414, 43.91009469186106, 45.421717320719075, 46.26596043186803, 54.44220773635372, 53.761292119180005, 57.06215881532239, 55.797049307054095, 56.40877823675833, 53.90490970303936, 54.98553445262294, 46.39795995527699, 43.97194262473814, 50.276532942248934, 49.78516978602256, 51.661921931851296, 52.550405456173806, 50.54905922182145, 45.77210657058224, 42.01845322885821, 44.490942801198656, 44.92206227394843, 47.747702444753344, 53.64030661121492, 50.628812774535156, 50.59085599837765, 50.88505729552239, 48.381953623987016, 48.69032252219416, 49.02821510068832, 50.81226202749437, 52.46952226085048, 53.79959798628285, 54.53253992142216, 58.378298359532515, 56.74886342017882, 59.76978271238266, 54.837931740668516, 53.56922149658204, 56.134784990741366, 51.68026293477705, 51.83495729200302, 52.52922857961347, 53.281107717944735, 52.98545122146607, 51.21124944379253, 66.51881679411858, 53.79601293994535, 47.2824465843939, 47.68816478790776, 40.65418620263377, 16.451318725462883, 2.322370659920477, 0.13345620895345367, 4.593288158216785, 1.1721847590900238, 44.76350830447289, 58.474765131550456, 56.97740816300916, 54.73850750154065, 56.46551139893071, 56.99737302718624, 69.6217332347747, 50.8043231502656, 20.669188499450684, 57.28269407826086, 18.574025054131788, 36.83198159740817, 32.34164830177061, 37.37136240928404, 59.684902621853745, 6.3740603962252225, 0.37322148921028264, 0.04896907556441523, 0.050393776938078866, 0.030194980152431997, 0.06538470035358783, 0.10555621371754717, 0.07831497748772945, 0.010741048740343222, 0.0588569340987071, 0.03249310602944705, 0.016179849739156423, 0.0633916728228571, 0.08053828721805927, 0.042792001378632365, 0.04949302990890799, 0.05558747002073834, 0.025385135424233256, 0.035535486324900584, 0.0190189964843974, 0.04237802278610968, 0.028268759319138144, 0.03677590907881818, 0.07199637621881501, 0.016647081018515652, 0.8715944112308565, 46.69206711553758, 54.64855578637893, 37.85502595286216, 31.778562645758356, 39.78938987178188, 32.1747887134552, 11.9351242626867, 65.36459269062166, 72.09701553467782, 68.67283344268799, 66.68310134641587, 69.45821746703118, 71.08507540918166, 70.27265056487053, 52.72293090820313, 1.680427099908552, 3.49036792112935, 0.8815791109396566, 7.998066284964162, 41.37596899463285, 49.35538391913138, 66.7186301754367, 60.50437988773469, 58.39078326379099, 55.397453923379224, 62.47885396403652, 61.556073234927275, 63.22048787147769, 64.36865191305837, 63.802755878817656, 67.85995360343688, 66.40395410599248, 66.14638774625718, 67.49937795823621, 63.425035553593794, 55.23328704218711, 55.458262428160644, 63.382085600206935, 64.65926816386562, 63.05248883462722, 62.30254734716108, 59.382091722180775, 57.73816754741054, 54.676679180514434, 59.98756447146016, 59.531655619221354, 56.876705231205115, 55.48114161337576, 53.218855780939904, 50.51253018840667, 49.29850562926262, 47.19401674885904, 45.183500013043805, 47.91114368746358, 50.6631217464324, 51.691284794961255, 48.23115418034215, 58.07873910473239, 57.577067959693174, 58.67962660328035, 58.7975565848812, 60.54210524405203, 57.80037633834347, 57.9349293247346, 54.970201907619355, 49.60477998179775, 46.372456704416585, 49.40001656932216, 54.48400059053975, 56.660449274124645, 58.1299574144425, 60.152857072891734, 57.00885380468061, 56.62978026174731, 59.872756696516475, 57.987308656015706, 60.11071512776037, 55.0064955988238, 52.29869519510577, 49.023429809078095, 47.317116414347005, 45.7842972970778, 49.29153557746641, 56.969841910946755, 59.066446827303984, 61.7878500107796, 58.21582201988467, 57.00446467245779, 59.33578814229658, 56.796994824563306, 49.611346029466205, 47.367122711673865, 50.3847982037452, 51.825229813975675, 56.44229488988077, 55.126108277228575, 50.97783311720818, 48.92232287314631, 45.282869338989265, 46.2766057445157, 46.98702150775541, 48.92237386395855, 56.01618428384104, 51.4643717581226, 53.02030540281727, 52.59794458266228, 52.820715596598966, 52.26314675423407, 51.64422812000398, 53.16330717455957, 53.996375453087595, 54.60625694644067, 56.80153692922285, 61.83423596043741, 58.57879815563079, 62.15939260298207, 55.344254816732104, 55.87867775271016, 58.3332734723245, 53.025314269527314, 53.863144305444536, 54.03980001326531, 54.35004380441482, 54.39269565766858, 52.671457644431825, 65.20104554391676, 58.10314409194454, 52.9379395515688, 52.322225493769494, 44.75591067344912, 18.423619808689242, 2.873387428060655, 0.29232916211889637, 5.510663370932303, 2.26222233906869, 49.4642218466728, 61.56880917087678, 61.67635271626135, 58.82447973374398, 61.3950599393537, 60.88788570896272, 74.80804797141784, 54.46436912782731, 24.74712379517094, 63.86094031795379, 22.20004447044865, 46.298006196175855, 35.70854809976394, 40.95827579498291, 70.06273315798852, 6.863883041566418, 0.4964939228469326, 0.16193491466824086, 0.05892541469825853, 0.04755509559125189, 0.07794848868563291, 0.049648725788199136, 0.0136937000300555, 0.026232668070963798, 0.016675274969348987, 0.011699844166756639, 0.18428943690753755, 0.1704031739744448, 0.16156749889975594, 0.1943698669633558, 0.12954479383845485, 0.08844321909090204, 0.11966539291484703, 0.14917501548845924, 0.27174146845936775, 0.17358962476493853, 0.10153442065441802, 0.1595371667175524, 0.12460720394888233, 0.22920468161183022, 3.0204910184106524, 65.15851136176818, 64.65246285161665, 66.67922604468562, 34.809482020716516, 49.10770977697065, 37.470155146814164, 14.824383316501496, 76.2581717583441, 76.82360495290449, 74.19311446528282, 72.21817754930066, 72.16276230350618, 76.89996565541914, 75.09183929812524, 60.60849528158865, 2.6439434818683134, 5.710294362037413, 0.49332210433579265, 9.06024952088633, 54.77913148941533, 55.221174763095, 70.55382959304318, 61.08839727217152, 58.34307547538512, 55.577122011492335, 65.96129109782558, 61.17759981463033, 63.505899137066265, 63.07119069560882, 66.94929692053026, 70.25030874436902, 68.58043809090891, 68.24794661614203, 69.13488080424648, 63.99494025015063, 55.953442050564675, 57.32441632978378, 67.96286875201811, 66.87856874158307, 67.48489656756001, 63.17383912301833, 62.03227250806747, 60.851913652112415, 56.72210501086328, 61.329642649619814, 62.064282971043745, 61.38810557703818, 55.444604735220636, 55.89193928626276, 55.09685524048344, 53.2581030168841, 50.13473533814954, 50.12241517343829, 50.71245731845979, 51.52317200937579, 52.527745923688336, 51.96277556880828, 61.29635741633754, 62.77932320871661, 62.72539846358761, 60.57124060969199, 61.4195002278974, 61.64379312146095, 61.59130788618519, 57.62233603385187, 50.55582138799852, 47.85109220012542, 49.871960070825395, 56.94064378738404, 58.972761015738214, 62.048377759995006, 63.64146801733202, 60.22679375063989, 58.75772883815151, 61.56394543186311, 61.19934151249548, 61.61771720455539, 57.418784633759536, 56.729282948278616, 52.66677433444608, 49.3991889492158, 50.665345730320105, 52.46776503901328, 58.4503326877471, 60.05122453935685, 65.64015096233737, 61.59454384157735, 61.19377566922096, 63.218063846711196, 61.30753617132864, 53.884713419022106, 50.55009472754694, 56.366514698151626, 55.21128254552042, 56.92433064983737, 58.54084922421364, 53.91383701755155, 51.613480660223196, 46.83521401497626, 48.20464680271764, 47.975796115013864, 53.12158492303664, 57.069230848743075, 54.727113016190074, 55.22636798120315, 54.91407279045352, 53.65740030042587, 54.70053503590246, 53.622765771804325, 55.05154009788267, 56.730887197679095, 57.52282158021004, 59.8752748581671, 63.52012165131108, 62.219212670480054, 62.81353019898938, 58.576687920478086, 57.84360870238274, 58.69411191632671, 52.879637441327496, 54.644096051493, 54.89342543386645, 52.53670853953208, 51.76753959348125, 51.880998073085664, 67.22571419131371, 62.14532698354414, 59.462837634548066, 52.270756152368364, 50.50882747096401, 22.74016268791691, 3.9526498894537654, 0.2967986722867335, 9.136894595238472, 4.722972012335255, 54.2882154833886, 66.36019614435011, 65.71698627164288, 63.47830918527419, 67.48533587301931, 66.79235504519555, 79.74591193660613, 60.51165980677451, 27.001711976143625, 68.92494770788377, 27.90077413282087, 53.15640380305629, 47.10809330786429, 53.34717219875705, 82.4871858473747, 14.795119493238388, 1.0749489573701736, 0.3362621595301936, 0.17187389424971997, 0.23367960036041277, 0.16431864320991502, 0.20314307522869882, 0.23115088201818929, 0.14392257878376594, 0.17473756155419737, 0.10235379765471143], [0.02225472588062046, 0.011082256640938502, 0.02847297346189378, 0.06341250275351829, 0.02773087366574234, 0.02327290652770429, 0.04061613930389285, 0.0867328588520327, 0.06655460854451503, 0.031504316345578244, 0.056592841677728205, 0.1496690502690692, 0.05671118694027105, 0.004891619826066158, 0.4173247726453889, 19.97965543500839, 56.88892341429188, 45.351349999827725, 45.0858094615321, 21.720958332861624, 50.584497836328325, 12.774818405028313, 24.923465713377922, 80.25973458443919, 58.75370056398454, 68.98969819468837, 57.78560469227453, 65.63322013424289, 60.164820301917295, 58.59984559397544, 22.249397693141816, 3.091916398655984, 0.12403252309248333, 0.800909746077753, 17.45453549969581, 38.137071824842884, 53.14764122809134, 61.977174974256954, 63.39591195506435, 63.75276134860132, 56.147536616171564, 60.19305352241763, 60.65244151699928, 68.71960378462269, 66.35410078110235, 65.42005108248803, 60.690319845753336, 62.43174237589683, 63.19400402807421, 62.74666555466191, 63.17489816296486, 60.757784612717174, 61.41291064600791, 61.35829164135841, 59.73007655912831, 60.713693249610166, 59.155802342199514, 58.336976189767164, 56.91164178232993, 59.43540457756289, 58.93610646647792, 56.56769306428971, 55.54384854532058, 50.99746065755045, 50.569679121817316, 46.75253045174384, 46.80432534986927, 44.081129643224905, 42.12915820460166, 42.62370632540795, 44.88656874625914, 45.99534434656943, 53.211383665761645, 60.53634720463907, 55.01335974662535, 56.85658739459131, 56.099899430428785, 52.974978493105986, 48.38510720960556, 44.4558415105266, 43.22114213820427, 44.48690275992117, 48.41275599695022, 52.658839379587484, 51.611750894977206, 52.22886523892803, 55.1666538176998, 48.978024451963364, 52.56516141276206, 55.39459451552361, 54.488997690139286, 54.12367989940029, 51.69396769615912, 52.05055036852437, 48.85629369366554, 43.83665615512479, 45.38457639755742, 44.3845171313132, 46.8280243104504, 52.62657004017984, 54.23712661189418, 54.77203592177361, 56.396560053671564, 53.726473239160356, 58.029795769722234, 51.01478576660157, 47.23123219705398, 46.535191920495805, 45.93193531036378, 44.736851876781834, 40.41204260241601, 45.18359022755777, 41.99380113232521, 44.93537872068344, 45.14970879400931, 47.216511541797274, 51.09718691918158, 53.95397070915469, 52.173053833746145, 53.13262247270154, 52.190884928549494, 54.09327368582449, 51.35667524030132, 51.26580569051927, 51.955570174801736, 50.43771097736974, 54.18136227515436, 54.9068634740768, 57.26630249331075, 56.24629405237014, 53.87091059838572, 54.14577461058094, 51.83174094846172, 53.62906902067123, 57.24574535123764, 54.85172671656455, 54.44449055579401, 53.75361996312296, 57.800360648862785, 54.376394287232436, 49.99179240195982, 39.57539712229083, 50.75859615879675, 46.096937656402595, 21.602428228624408, 4.842321401642216, 2.8256431125825454, 1.1915341788722624, 1.6322185964353624, 6.578533063011785, 54.30688988777899, 50.47577757989207, 62.63742754536291, 52.267739849705855, 67.10536802968672, 54.13390944080969, 73.12284869532432, 16.806171632582142, 30.643416950779578, 36.15138369221842, 18.49108849802325, 45.43376291951826, 46.15770301511211, 47.80431009108021, 40.868841832683934, 1.4379535303000481, 0.22600888454866028, 0.2165494147207468, 0.052767653589046774, 0.12744994939214763, 0.10692767964135255, 0.021903076201617237, 0.018945632074328683, 0.05819559720675311, 0.08832668945673974, 0.022857221474330273, 0.04927370276662612, 0.020504910198430863, 0.06533672792776939, 0.03275417347228335, 0.06219743750989438, 0.03618952239893618, 0.11355611751036299, 0.07784952544757436, 0.04401494966699712, 0.044338024266424685, 0.058625027792708534, 0.12406958642626002, 0.1099302769908982, 0.0697991824258239, 0.33131684747434437, 25.936696298660774, 69.34110333842617, 44.31349869697325, 51.008039289905184, 31.71646368119025, 49.83763540944746, 19.50705885887146, 27.57230308748061, 89.47793991334977, 61.24730817733273, 74.7983048039098, 62.14346385771229, 73.30669803004112, 64.7869413129745, 66.24975004503804, 29.232469797134403, 2.3319946854345264, 0.44873554199453325, 0.6310999225224219, 19.707637102373187, 45.31523673765121, 56.44431491051951, 66.18682738273375, 63.17714175870342, 65.84979380330732, 54.2919417350523, 62.240209118012466, 62.54706398133309, 70.81793062148556, 67.99402021592664, 66.68559597384545, 63.00975461159984, 65.2625757648099, 63.88374105576546, 65.40465970193186, 64.03317551459035, 62.46912648600917, 62.71358820699877, 63.298915663073146, 62.88728252533944, 61.95037734123969, 60.896985607762495, 58.778003569572206, 59.117610223831676, 59.984559935908166, 60.4820498343437, 59.570840097242794, 59.48812515504899, 51.80409216111707, 51.89670324325562, 48.383773603746974, 47.03800447525517, 46.20650906716624, 44.79602867557157, 44.373707079118304, 46.28653326342183, 48.905923443455855, 56.382510123714326, 59.96137088344943, 57.520303418559415, 59.13295845831595, 57.17203617095948, 56.429166716914025, 52.5600544867977, 47.81525742623114, 44.98017218805129, 45.39412344655683, 50.39716543689851, 54.650450291172156, 54.95779937313449, 54.602028631394916, 57.655899755416385, 54.56802560437111, 54.98432636260987, 57.89373659318494, 61.95009100821711, 57.96544144230505, 55.28091638318954, 54.37770435886999, 51.50763550112325, 46.65682069716915, 47.01130097912204, 47.15135312849476, 51.575559185397246, 56.652000488773474, 55.924487113952644, 56.794460973431995, 59.01902929429085, 57.403099075440444, 59.177787227015344, 53.33540116586993, 48.87439543201078, 50.171327129487075, 48.81541867409983, 47.33614383205291, 45.02062359163838, 46.07008118783274, 43.90028092168993, 46.0301749936996, 46.068202372520204, 47.1522827302256, 53.7454104423523, 56.098083373039, 54.19819316556377, 54.42558080919328, 56.14002527729158, 55.95491686174947, 54.560455429938536, 54.20270389126193, 52.298169597502685, 55.365988669856904, 57.159939581348056, 56.2398103744753, 59.66910331479965, 59.21701092873851, 55.00374993970318, 54.082946085160785, 53.250054313290505, 54.772306565315496, 56.93305792347078, 56.03603932165331, 56.403741913457075, 54.102322593812026, 58.80898244919316, 57.11194153754943, 53.63805124836584, 46.335519744503884, 55.05038692105202, 48.68524305282101, 22.944100441471225, 5.860914357246892, 4.955098369429189, 1.5675153006469051, 1.6668006633558583, 7.893842045337924, 62.66988123616865, 55.925075469478486, 69.17390838746103, 56.57594965350244, 71.73493369933098, 57.967198664142245, 77.40697122389271, 21.048481695113644, 37.48162415719802, 42.43828804262223, 21.567293597805886, 61.192112584267896, 52.359374261671505, 52.90845117261333, 47.40789967198526, 1.3369419569930723, 0.17660142283045477, 0.1220504850930264, 0.07199220870050692, 0.02802287190852146, 0.05447722858779373, 0.05812109515611684, 0.0646902263284691, 0.12072598801985865, 0.015751051175738537, 0.032302373118938944, 0.11995594708188889, 0.1293150593917216, 0.20591203874397665, 0.20452433175617651, 0.288606250598546, 0.11313110725173067, 0.16602108976052654, 0.1808137419603525, 0.13923142405767597, 0.10713450039827055, 0.20307686991028248, 0.2334586606030503, 0.18833438114773846, 0.2699115908434314, 0.5955231670410402, 41.85960900398993, 79.42368922695037, 64.24069635329708, 62.706010187825854, 36.05798029130505, 64.74798041005289, 20.957088508913596, 30.516547887556015, 94.94715167630105, 67.47013276623142, 82.88869534769367, 66.96213091573408, 77.5514478068198, 70.83284347288071, 72.57962396067958, 31.56202231684039, 11.24500088153347, 0.14014840065952272, 1.6221280540189438, 26.481182075315907, 53.55876053533247, 59.626431849695024, 67.37017508476012, 63.39413119900612, 64.82951471882483, 56.786122014445645, 62.499666060170824, 65.69908065180626, 75.36707201311665, 70.82658337008569, 69.0751431065221, 64.88849539910593, 67.53347119977398, 67.07007454287621, 66.52677136082804, 66.55541250782629, 63.85152270717006, 64.04198908036756, 65.92407564963064, 66.17320891349547, 65.64682291400048, 61.62449113784298, 64.92157274676909, 61.678533554077156, 63.7977627015883, 63.881419012623454, 62.0205093199207, 62.24316658512239, 55.70296733610092, 55.81173073860907, 52.44423081797939, 51.6402586813896, 49.797850808789654, 48.187592337208415, 49.57851971349409, 50.30816685768866, 50.99742927858907, 56.899757000707815, 64.63625169569447, 62.41917510186473, 59.351536458538426, 60.958260874594416, 57.71430384728217, 53.682774113070586, 51.28079698931787, 46.60924234697896, 50.128098687817975, 53.06004685740317, 58.66416854243125, 57.94850857027116, 57.33569314402919, 59.16260373207831, 53.72061714049309, 54.96899773997646, 58.50876815857426, 64.33493129668697, 57.319430997294766, 57.34647181726272, 57.59928818671935, 55.98673120621712, 50.0029750793211, 49.256814756701075, 49.017008889106016, 52.91593897727228, 58.6722094012845, 57.83012359373031, 59.12883604726484, 62.7489483741022, 59.79551346071305, 62.57367726295226, 55.45477544107745, 52.55591246389574, 52.30597119177542, 50.87376479179629, 48.24675344651746, 47.325333779858006, 48.450234243946696, 46.07981651060043, 47.48806115119688, 50.65292750635455, 50.676987324991536, 56.503099472292014, 57.39016702098232, 57.477981044400124, 55.79784947056925, 58.65994807212584, 58.872615060498646, 57.05183513702885, 57.624685533585094, 56.47839638494677, 55.9370465432444, 59.21339058106946, 59.34347598783432, 61.75404702463458, 61.27653375748665, 59.41242733309346, 56.26895358485561, 56.77945398515271, 57.24786343113069, 60.31622771293887, 58.174291964500185, 57.54507318619759, 55.190392001982666, 61.72292301731726, 55.870880080807595, 56.796496683551425, 50.5664078650936, 57.43002222430322, 54.014539949355594, 30.15333837078464, 8.147243828542772, 5.451991087005985, 2.37874026740751, 3.58272135257721, 9.142740887980308, 67.0774721330212, 60.92449711215112, 75.19563305762507, 58.74469087969873, 77.21512025402438, 60.3091674466287, 84.24778092292048, 21.206539484762377, 41.61920301375851, 45.940054616620465, 29.36272974937193, 64.66117051339918, 54.72392805161015, 63.83435841529601, 63.130296891735455, 3.853090818851225, 0.5096426576135621, 0.39953296283079737, 0.23381420200870884, 0.28659765999163356, 0.22274078410719672, 0.14131181242485202, 0.2565782135652919, 0.20060088906076648, 0.21013361221599966, 0.11878786984110072], [0.04194567723560237, 0.054174003326484275, 0.0362646066763949, 0.028276678753055395, 0.0051945894055308835, 0.03753138668534737, 0.05331071799681072, 0.051998294469329624, 0.0597513685633819, 0.06165094485866928, 0.06724958052678455, 0.04601823894547359, 0.11673738188560932, 0.047756461802149014, 0.06456728453838056, 4.84428160613583, 45.32235583951397, 37.33846549064883, 32.53657637103912, 28.491145756936845, 29.064517828726, 49.59527607887022, 9.870746520257766, 44.47776755978985, 74.37712069480651, 59.77277548082414, 68.56288156201764, 59.17032295657743, 71.10002748427853, 51.55210733413697, 50.41677336538992, 1.4643583134297402, 3.78343834992378, 0.3755659940502336, 4.578418452893534, 33.88529316071541, 47.286325808494325, 63.737044411320845, 57.94758289091049, 64.93042945861816, 60.02229313696585, 71.30843085627403, 67.68525123596191, 67.81031208653604, 60.61897193231891, 63.362885598213445, 60.270826278194306, 59.705746096949426, 60.2441345491717, 62.28358268737794, 60.23313230083835, 62.863928733333466, 61.75183873022757, 63.714992846212084, 61.01519800001576, 60.25708621548068, 59.01213376752792, 58.94585355635613, 56.54004819931523, 58.56298708146619, 57.643438385378936, 57.020134541296194, 56.207188021752145, 52.424038456332305, 49.9668735842551, 48.74680073030534, 44.97759911321825, 44.27065072521087, 42.01087913205547, 44.086248336299775, 45.11165788096767, 46.59927168200093, 50.65155859916441, 54.57919259225169, 54.91963078898769, 52.82148045878257, 55.68741906073786, 46.79892816851216, 45.2354557283463, 43.551170364502944, 45.6993426815156, 44.97011915329964, 49.704980850219734, 48.35548547006423, 54.605346956560695, 51.6295898345209, 59.233994791584635, 24.441549585711574, 32.805331291690955, 50.16661636291012, 44.38543104356335, 60.25956515342959, 52.05847747864262, 54.31679387246409, 49.10512885739727, 46.51501917069959, 41.99022393072806, 44.261429232935754, 43.04720071054275, 50.01856650075605, 53.774824296274495, 52.73111689475275, 52.88410894332394, 52.98423136434248, 54.49458706763483, 53.43602565027053, 47.61818970403364, 43.311435099570986, 40.50889376671084, 40.45355304594963, 42.7448683400308, 41.83452544673797, 40.73208447425596, 43.11364958363195, 45.033222244631865, 48.58333595337407, 48.06725794269193, 51.58891877820415, 54.90798527194608, 53.114257935554754, 52.25161498592746, 50.59439397627308, 49.96166075429609, 50.4800804199711, 50.41763628682783, 54.566413510230284, 55.383309856537856, 58.31156315342073, 56.61731104696951, 54.67311766839797, 54.145845213244044, 57.62503070216025, 56.153380947728316, 57.91320331635014, 57.18175972661665, 55.383243176244925, 55.698319327446725, 54.72191587571175, 52.54670666110132, 51.60434546009187, 46.37596330335064, 48.32862507912421, 40.758819349350475, 31.822712844417943, 6.648556195920514, 4.026957721479477, 3.6005779427866784, 1.1136598091933037, 1.6082931189767777, 10.483686481752704, 60.321832779915106, 54.5698259722802, 58.71590068263393, 53.08268285566761, 58.99385552252493, 62.65807490194998, 57.070995915320616, 26.559278426631806, 53.93818709158129, 33.71618017073601, 32.695081310887495, 39.89383082236014, 36.244791015501946, 50.30816685768866, 26.232956840145974, 0.2692438686086286, 0.02606068324718264, 0.014288746376311588, 0.03190205004366656, 0.028956336637718544, 0.04275217246744902, 0.042436421668577584, 0.0492588636435328, 0.04421824641946343, 0.034077245621911945, 0.052149309551403414, 0.03588058595215121, 0.03852229077188719, 0.039290232628944426, 0.04199160420666299, 0.04158409522666086, 0.09907152458664872, 0.030966355998609817, 0.05225249776436437, 0.06338349866470502, 0.09063643688756613, 0.0878743834853653, 0.06055623202794983, 0.0943081813954538, 0.163974761662464, 0.12959420650957093, 5.93398517177951, 58.94499063491822, 41.13843025699739, 37.17296108122795, 44.514265214243245, 34.33355731348838, 56.029583100349676, 13.648621478388387, 50.305095641843735, 80.91413497924805, 65.77250742143201, 73.87760685336205, 65.44960614173644, 74.65750740420434, 56.74884773069813, 58.70429831166422, 2.717206737687511, 3.8290459542505206, 0.8667412748740566, 5.891730948801964, 38.655777823540475, 49.98291607825987, 65.47115564346313, 60.093362562118045, 66.91088907180294, 62.74940729141236, 71.45140124905494, 68.34722180520335, 70.82453589285575, 62.47989339213218, 66.24123850176412, 62.3185976859062, 62.8024338137719, 62.81218874839045, 64.46891553940313, 62.82623083360734, 65.7100672106589, 63.6927177060035, 66.58796033551617, 62.1441424277521, 61.34166863656814, 60.03995949222196, 61.637854653020064, 59.43319628315588, 61.78221356484198, 60.952930373530236, 60.321122830913914, 58.40756708575834, 54.391554247948434, 50.34002827059839, 47.992438731655, 47.73853978803081, 46.90294550311181, 43.687021655421105, 45.84926743661204, 47.904357987065474, 48.62062592660227, 53.2187145756137, 57.20621570464104, 57.688831975383145, 55.832625204517, 56.74364666784964, 51.088232148078184, 48.09885655680011, 46.214318506179325, 47.03085399443104, 46.510414308117284, 52.03974423869964, 52.42570938602571, 54.729948889824655, 54.23981735783239, 59.78913176444269, 30.963713776680734, 39.6676238121525, 55.616683037050315, 49.09178495407105, 61.82480266017299, 53.751768604401626, 57.387958726575306, 52.335738059013124, 48.5915493965149, 45.43019356266145, 46.753071738827614, 46.2456190201544, 53.10658185712753, 56.32803232439103, 56.87420668140535, 55.18827784445978, 57.07682847976685, 55.92570697107623, 53.836758521295366, 48.89603907062162, 47.06314294568954, 42.75023022005635, 42.89426357515397, 44.20866158700759, 44.11416384481615, 43.05320585927656, 46.54222473021477, 46.777370822045114, 50.3380004052193, 51.213524418492476, 53.923007519014426, 55.13695363075503, 57.915796003034046, 54.48986453394736, 52.766751627768244, 54.203766853578635, 53.2883248790618, 53.59455608552503, 58.42077370612853, 57.04268032504667, 60.13074274986022, 58.08344594893917, 57.491097450256355, 54.26202581774805, 58.023088516727576, 56.839587842264486, 59.527643034535075, 60.18826038606706, 57.30275307932208, 56.30204269962927, 56.55343132634317, 55.364953164131414, 54.66898349023635, 48.36682504223239, 54.05399114854875, 46.761771555869814, 36.84677285532798, 8.539817679312922, 6.815875191842356, 4.570911526679993, 1.7951161005804617, 1.883797703250762, 12.433456490116736, 67.17182866988644, 57.772676560186575, 64.5574002881204, 56.09665563029628, 65.21171046841529, 65.71906120546403, 63.83207559585572, 30.009522707231586, 59.080245725570194, 37.5904110939272, 37.34713392872965, 47.12629310546383, 36.37175029323947, 58.38107539761452, 28.017513675074426, 0.2821457085590209, 0.07818409136586613, 0.10827876762637209, 0.059026760469761595, 0.03166139118313309, 0.08481186273838244, 0.06005547482580428, 0.016218330335593032, 0.09865520942595699, 0.011352740261974114, 0.08910544081440858, 0.19490229807073073, 0.14728671600741727, 0.1401509593931898, 0.22246522228083304, 0.17933074895653034, 0.20625988862687544, 0.1394521799539366, 0.22678859351623445, 0.2887626551091671, 0.14339990763654634, 0.24898738540228338, 0.15045562338444496, 0.33482068849186747, 0.3346342226910976, 0.3460365834255373, 14.762219632825545, 70.75296832669166, 57.08122545673002, 47.60575971295757, 44.191862075559555, 45.28643869584607, 62.88962418033231, 14.750976158726601, 54.09816880379954, 86.95493805793025, 72.36987913808515, 81.27688361752419, 70.22707262346822, 79.57296679096838, 61.87498154178743, 64.57263869623985, 2.337736545070525, 7.002874189807523, 0.8782108981282482, 8.968702381657017, 50.93655409351472, 54.103338487686656, 68.68716578329764, 61.43844919819986, 68.19453177913543, 61.77431391131494, 73.77468386004048, 70.27294082026329, 72.47823069172522, 64.25779396487822, 69.80122089385986, 66.88220085636263, 63.933292358152336, 66.26566702319731, 67.0001700616652, 64.32778473823302, 68.44719517615535, 63.75275350386097, 70.51256625883042, 63.917481283987726, 63.784144232350016, 62.786520757982814, 63.04801733263078, 60.498025648055545, 68.24464398045694, 61.453420885147594, 62.98270986926172, 61.1363168685667, 55.89058999092349, 54.19579659738849, 53.11239480972291, 48.20853387155841, 50.20709522308842, 45.89794797282065, 48.88481716955862, 51.41276121139527, 52.736408172115205, 54.15704750245618, 58.73037422856977, 56.71085957557925, 57.040079793622425, 58.28917034210698, 51.00257150588497, 49.022931668066214, 49.50086855119275, 49.63481749257734, 51.2060679927949, 55.95735265362648, 54.431134885357274, 59.53530734585178, 56.43956492024084, 65.0270688149237, 28.842870573843683, 37.46124744415283, 56.28815750921927, 49.176786638075306, 66.14041005411457, 57.715504092554895, 61.94245415349161, 56.13824452123335, 52.053586283037745, 48.48515118322065, 49.52012738873882, 50.211350994725386, 53.43580991991105, 58.549945200643236, 58.52561866083453, 57.55939375969672, 58.996899281778646, 58.51740129532353, 57.59485590842463, 50.64511806734147, 48.79041748662149, 43.95308779131982, 47.11583214421427, 48.57876639212332, 46.69228284589706, 45.32812564603744, 49.21849320011754, 49.34850015947896, 50.86075036756454, 52.68148322259226, 55.53400731855824, 57.52888948686662, 59.8103125633732, 57.61148283558508, 53.51771293147918, 55.135980882952296, 55.577855494714555, 55.41018985932874, 60.118379439077074, 57.305384989707704, 64.36169755074286, 59.99852749609179, 58.79950208048667, 55.78263459667083, 59.88482582953669, 59.31169694469821, 61.48826329938827, 62.08733081817628, 57.70079128203854, 57.37142985866916, 58.73752863176408, 56.264293809090894, 57.07240012384231, 51.77829081012357, 57.14385786364156, 49.890018663098736, 43.40828626386581, 12.263488423439766, 9.954895088749549, 7.148659373483351, 3.1496284373344916, 3.671900360814987, 14.460862951893962, 73.8395441732099, 59.89924053991995, 70.89171824916717, 59.05807256698609, 70.00813376518988, 70.3565735970774, 69.76304054260254, 32.03011208964933, 67.7645694055865, 38.71514289609848, 52.21616852668024, 54.211344872751546, 47.31144858944801, 65.64690920614427, 44.282696324010054, 0.36247321434559365, 0.15813813695023138, 0.16187257043296294, 0.21229371969257632, 0.18118667356189222, 0.1404942433920599, 0.1294805190616077, 0.13339084633175405, 0.22997029456159762, 0.09807769404423815, 0.23201429375237037], [0.05621613326272177, 0.06371848593135515, 0.10207617505183143, 0.08628210037826531, 0.083591369761815, 0.08096977091965177, 0.11020062941937678, 0.07003802565797683, 0.05060659999388361, 0.07255935891261024, 0.008441599446438975, 0.030241707685373487, 0.07656963767423745, 0.019371327981653235, 0.16990058965259985, 0.36818816897369205, 37.29109502607776, 49.179245964173354, 30.028936478399462, 29.674689577471828, 24.09184086707331, 62.058842643614746, 33.014048453300234, 12.439647951433736, 72.65629060806768, 57.20716491822274, 69.94712521952968, 57.18578800078362, 70.63990208410448, 52.46105386364845, 57.84056886549919, 5.653654356156626, 6.687426884328166, 0.04305437883181919, 0.6181708711289591, 17.64775537675427, 44.160640008987926, 57.52000531842632, 60.663522212736076, 62.30332005408503, 61.10587535365936, 66.25619057686099, 62.36002183729603, 64.43873290092715, 61.81797381370299, 60.66979016027143, 57.18761582528391, 58.85283062534948, 56.91233996422061, 63.359375076909224, 60.24828441681401, 60.269986890977435, 60.11049155266055, 63.54058073412988, 62.62325209956016, 62.36653297178207, 60.07115802457256, 58.97273355914701, 58.25429262653474, 56.980357785378736, 59.76282442769697, 58.697030159734915, 57.80534990372197, 54.3450584719258, 48.83805859473444, 46.22145721989293, 44.37154193078318, 45.487291505259854, 42.589040417825025, 43.26122483899517, 42.560834653915904, 43.50188186091762, 47.68943955821376, 50.592911320347945, 53.61689790602654, 54.69474169515795, 50.69295921633321, 42.24213423267488, 41.227875986406886, 40.30534628898867, 42.7532975135311, 40.892262304982836, 50.069278824713926, 48.52364532409176, 57.75657130825905, 46.07008903257309, 64.36509432331209, 18.928260187948904, 15.686857604211378, 34.65452878705917, 34.87460513268748, 67.19642193086686, 47.003840631054295, 52.92105767034715, 45.40842833057527, 48.10872916252383, 39.05683625128962, 43.53349224213631, 39.865330880688084, 46.3485812371777, 43.85566003860966, 53.55333197501398, 52.58104701195994, 56.31823424370059, 51.39267867611301, 52.87113766516409, 48.41184600707024, 46.32247786368094, 38.86610707929058, 39.863310860049346, 39.162575506394916, 41.10369374675136, 41.198693552324855, 45.286062148309526, 44.26177440151092, 45.92771091768819, 48.0693446436236, 51.923391049908055, 53.53657560963785, 52.88554845317718, 51.99528417279644, 53.004023644231985, 51.62499673904912, 55.084817486424605, 51.044627158872544, 56.72602738103559, 56.92591920975716, 57.993815868131584, 57.50668887169131, 58.550894414224935, 58.23803832454067, 59.744432433958984, 57.40912383602512, 58.62693740475563, 57.62004536967124, 59.432278448535556, 55.796727672699966, 57.403401097943714, 51.95011808026222, 53.16456233301471, 43.299883719413515, 41.83189353635235, 48.56572451130037, 31.44021114995403, 3.1411610207250042, 3.619976514770139, 0.38062986587324454, 1.6717077935895615, 0.10378016910005002, 25.2857828909351, 54.7302116886262, 54.30591713997626, 55.4622357891452, 59.53093390310965, 58.94934838817966, 63.47869749992125, 45.14435475872409, 45.934296577207505, 60.80997567023001, 30.59546205305284, 41.48199066039055, 30.463454684903546, 39.52990547303231, 52.10408287663614, 6.1242892569111245, 0.24737565898366515, 0.09616934604221776, 0.07865538865688347, 0.08185521534253513, 0.07084553595632315, 0.037218550851027814, 0.04943795201759185, 0.030360112319730466, 0.043455946799968524, 0.010923685059101592, 0.06738647277797423, 0.06374608041838774, 0.08032782754350094, 0.14405996899210638, 0.05102939625841476, 0.044223831200431434, 0.05471579985873354, 0.08816666901111604, 0.021206778887238716, 0.05121347186486087, 0.030773403348341107, 0.03211468349271004, 0.04771437293158905, 0.07438490047089516, 0.09109230516778846, 0.15472532249987125, 0.5609251042046856, 45.706571609743186, 59.09958301051971, 27.560243760385823, 47.43226151312552, 31.80709004402161, 64.7830032533215, 37.82889512277419, 15.443508855758177, 79.48359166422199, 63.93508095895091, 77.03003145033314, 62.117964529222064, 76.64159913216868, 58.18155227168914, 64.8971716819271, 8.196863282111384, 5.823494455506725, 2.097194742771887, 0.5412067977651474, 21.35369504651716, 46.32908705742129, 60.40000169507919, 62.60909626560827, 63.42349798448625, 61.63200247672297, 68.32803357032039, 64.71636218409385, 66.93201495755103, 63.154760714500185, 62.196302106303555, 58.72761680233864, 62.00069742818033, 59.9156125130192, 64.9002036740703, 62.543627985062145, 62.13904334652809, 63.57111246355119, 65.0258058117282, 65.88521280596333, 64.17296094279136, 61.50484708047683, 61.984678468396595, 59.65264504955661, 58.047411134166104, 61.414824762652, 61.12522832808956, 59.84418615218132, 55.22896459025722, 51.998837840172556, 48.61649567081083, 45.027056278720984, 44.95047592347668, 45.55481903014645, 43.919088686666186, 46.00014532766035, 46.05006533284342, 50.75519546385735, 53.24878738772485, 55.34150523524131, 56.27590402480095, 53.043690573784616, 44.90557262974401, 45.797947145277455, 42.81424722363872, 45.70886619629399, 44.55224552462178, 53.65103037126603, 51.40779549075712, 59.064803354201786, 49.08328517790764, 67.09338911118047, 20.837226760002878, 19.061628618547996, 40.31311258192986, 37.67552260429629, 70.5107541238108, 51.211806420357, 57.99462779875725, 47.83622641717234, 50.24196117155014, 42.47009846471971, 46.42817397271433, 43.13082956498669, 50.33153633917532, 47.16986279333792, 56.923840353565836, 55.56637863959036, 57.4688183876776, 54.3563509756519, 55.40077617091518, 49.45761657530262, 49.49296105292536, 41.01837042839297, 42.950275021214644, 41.02221042879167, 42.842503978360085, 42.427289716659054, 46.95687809298116, 44.44395672890448, 48.34377719509987, 51.267347181996996, 54.66595542046332, 54.257981854100386, 55.96393439077563, 54.869989272086855, 56.81371196623772, 53.904576301574714, 57.858576466960294, 54.23119991056381, 57.96264871474236, 58.27728948285503, 59.99356962019398, 58.700807402210856, 61.27396460502379, 60.27536838285385, 60.088267403264204, 60.12363149273781, 61.604765538246404, 61.133437848860225, 61.7945376519234, 59.23503814205047, 58.2938850310541, 54.1234092558584, 56.664834483977295, 50.677454087042044, 46.74911406732375, 52.12537742430165, 32.13295663556745, 4.391838167944263, 4.057953271173662, 0.9451511093685705, 1.1973044756920108, 0.6635804570490315, 31.359937883192497, 62.713548983297045, 58.706730181171054, 63.31734688051286, 66.39050822104177, 64.24418334038027, 68.22271008645335, 53.014970979382916, 46.798747739484234, 68.45597344060099, 32.16325890633368, 52.621000274535156, 34.47941457071612, 37.70789784769858, 58.77372426371421, 4.268001096863901, 0.2071902717673971, 0.02812498951360824, 0.1150076243004972, 0.11649832414883761, 0.08061667333447164, 0.01297894957280087, 0.017323825853846727, 0.02575542402243422, 0.07692389205218324, 0.10430234995099807, 0.026086052248795188, 0.2528861294230146, 0.2644531224523821, 0.3148363043944682, 0.16519452685550337, 0.14573626130098297, 0.1759286290935932, 0.2512358228165296, 0.2868651166077583, 0.12693484719361992, 0.19264615381196623, 0.16756808174954307, 0.1478340551857987, 0.22407710191703614, 0.14004249666487018, 0.426226714325528, 1.9198752963735213, 63.22297465416693, 66.50592004099201, 45.815484062317886, 45.73442828270697, 38.543445064175515, 78.23071602852114, 44.59126918546615, 17.294381203189975, 88.72887703680223, 68.32517808483493, 85.07408311290126, 67.03105480440202, 85.27481432883971, 60.07796333682153, 72.55276356973957, 7.26479192895274, 13.816146889040548, 2.074610225615963, 1.5556995282250068, 29.56836392802577, 53.16417794073782, 60.63762672485844, 63.337174461733916, 66.6571117216541, 62.78043716184555, 70.77034442655503, 67.27874463604343, 70.38255537709883, 68.19594383239746, 66.56990958798316, 60.97818259269961, 66.06848162989463, 60.742879606062374, 70.23991446341239, 63.452382318435184, 65.97656480727657, 65.13324737548828, 67.45922857715239, 65.48229909712269, 65.74001058455437, 65.77262901490735, 63.908589270807084, 62.64078117186024, 60.31825557831795, 64.19845242654124, 62.80470486610167, 62.83417755557645, 58.509740906377, 55.233255663225734, 51.56237609924809, 47.56536714492306, 47.82085857083721, 50.00353597825574, 46.28912202773556, 49.71055453823459, 47.86875463301136, 50.89178808273808, 54.38980094848141, 57.150745545664144, 57.65027115421911, 55.259621835524044, 47.227435342727176, 46.58155433593258, 44.98625578418855, 46.45181409774288, 46.642715854029504, 56.48704521117672, 53.802884932487245, 65.01548997817501, 50.81856919873146, 71.09153163048529, 19.19007251339574, 15.897506533130525, 37.87711281930247, 36.47289253050281, 77.23377504656392, 52.54813440384404, 59.650691709210804, 50.170970193801395, 53.84100644819198, 42.59871690504013, 48.96913243878273, 43.837173907987534, 54.1898581289476, 46.23489133773312, 59.529980767157774, 57.63085934423632, 60.39227462583973, 55.2674901100897, 58.9712469808517, 51.10779300812752, 53.70509239935107, 42.481783205463046, 44.106428930836344, 41.756250627579234, 45.2745892155555, 43.922085377477835, 51.68412646939678, 47.41365771139822, 49.993086784116684, 51.30322902433334, 56.64020984403549, 55.34333305974161, 59.084438739284394, 55.95305765828779, 58.37926718496508, 56.34492205035303, 62.319009534774295, 55.94001969983501, 62.81139250724547, 61.29420795748311, 63.935920346167784, 60.58294888465636, 63.33555844522292, 62.88231680470129, 62.9113737229378, 62.392055834493334, 64.20170407141408, 60.99184028563961, 63.29436571367326, 60.206377813892985, 61.43336580645654, 54.157365214440134, 57.5492661999118, 53.363991322055945, 51.76313869414791, 48.71232309649068, 38.323768800304784, 6.469223470457139, 7.573371164260372, 2.160530234536817, 7.266585923010304, 1.172116240186076, 34.77370608237482, 66.03900109567951, 61.82000560145225, 64.6586052833065, 69.6463970984182, 66.21790824397918, 75.22210121154785, 54.04868025933543, 54.71507133976106, 72.35031435566565, 42.78648860992924, 62.553775156697924, 42.64822113898493, 54.581812735526796, 69.45697015331638, 14.842036924054547, 0.6357641109535772, 0.24276223153837267, 0.3341673380665241, 0.3004482232274548, 0.20577840236646516, 0.0970054620636567, 0.17282290864856015, 0.21019952642100476, 0.10221523533184683, 0.20276657365743192, 0.3088205530037803], [0.07498549042089332, 0.006247523631299696, 0.03991973090676531, 0.023672633969615546, 0.02604625398112882, 0.03947174950172344, 0.19269329886282646, 0.0304139357420706, 0.11033926069015458, 0.09181376080960037, 0.060053532792916225, 0.01357962666530042, 0.08109502629527161, 0.05381878750819353, 0.19254178199316227, 0.28707376831481535, 16.150006171195738, 51.944638529131495, 34.18064371232064, 20.413699034721624, 29.03493335170131, 47.380086145093365, 52.47598632689446, 11.801292992407276, 54.905498489256836, 67.8447348071683, 66.8118021565099, 63.15310939665764, 65.82527898973035, 58.21477474704866, 64.89592044584214, 16.29910820914853, 2.9645536070869816, 2.9641353843673586, 0.34945514353532947, 5.997838416407186, 37.74824334729103, 60.74001627583658, 58.7797333348182, 57.88780204711422, 63.09557999334028, 68.40437073861399, 65.2143306116904, 63.61065779962848, 58.59076530702653, 57.128242907985566, 53.622197028129335, 52.79263142616519, 54.26861932200771, 57.141524053389034, 60.08909110100039, 59.27821559290732, 58.1421559856784, 62.804861760908565, 62.38268529215167, 62.24426484877064, 63.07168883662071, 64.71684855799522, 55.56744552427723, 57.2049605461859, 62.85047500364242, 56.616589330857806, 57.648874790437766, 51.778981147273896, 50.10390550859513, 45.61170908712572, 42.1139786320348, 41.67220207952684, 42.921280860900886, 42.533915427423295, 44.54737786323794, 44.9689071409164, 49.288334923405806, 53.02250585248394, 53.679942161806174, 51.680051126787745, 46.260386743853175, 42.89271816130608, 40.93944449578562, 39.43290133630076, 40.80193404228457, 41.52949448554747, 49.81743128068986, 47.78418440972605, 53.28939960848901, 50.40973663330079, 64.35063646685693, 26.716041834123676, 11.725106835365297, 20.809852538570283, 42.88013912016346, 65.74836131065123, 51.09565327244421, 52.05135053203952, 44.22217415225121, 46.79140898489183, 41.53127131923553, 43.21336800052274, 40.00173522580055, 44.468961838752996, 42.776557168652936, 49.97422410595802, 51.79627487736364, 50.965179551032286, 51.80380582809449, 50.34597850614979, 47.564445387932565, 43.24856342807893, 41.97169073166386, 42.52234051304479, 39.7627491335715, 39.66757282134026, 44.71501604203255, 43.91535851263231, 44.261782246251265, 45.917018536598455, 47.38497341832807, 51.68972369163267, 54.86545501216766, 55.26073971102315, 54.17753011949601, 50.781083106994636, 53.55337512108588, 51.84169592395906, 53.86602724752119, 55.031728206142304, 58.28232188378611, 58.03611863044001, 59.078033508793006, 57.40353838089974, 55.501726212040076, 56.177072063569106, 55.21362812288346, 56.29565708098873, 58.899130282863496, 55.537419780608154, 57.89839244657948, 53.85939059718963, 51.92036298013503, 46.911488425347116, 48.88467596423242, 53.90348980503698, 56.359705463532485, 20.677025395054972, 1.8346396184736684, 0.14626605706589837, 0.0911978874055128, 1.5719853317545307, 1.8767156187565097, 49.30748001221688, 58.42476667896394, 58.83094772215813, 51.86622642701673, 59.874812018486764, 53.17161083221436, 60.957229291239095, 26.38966533445543, 52.20601743267429, 43.863183144600164, 31.96805430996803, 36.104460377847, 20.503825295356013, 43.72913614396126, 30.819241116123816, 0.20410351965936924, 0.09586684090355713, 0.0677490851751739, 0.0645322283549655, 0.03289107338435227, 0.034753249267176274, 0.031762369232432495, 0.04536578484300164, 0.015821348361280418, 0.007127045236918475, 0.13055183173668, 0.027833023829565897, 0.11941368706644544, 0.042093179804543336, 0.07319735693595103, 0.020286877744741017, 0.03377547975809824, 0.0656234439943106, 0.0842850853598887, 0.07525637145003966, 0.04290228739621178, 0.14433150119598837, 0.0573066555924954, 0.06957247402639159, 0.05381656968365273, 0.03912622852611446, 0.1436837891777677, 0.31099513954212593, 18.222572841951926, 61.84712879119381, 34.03672802832819, 26.2757420539856, 39.14744692464029, 52.659529716737815, 63.40463530632758, 12.874838844422372, 58.22489838446341, 73.18270406415387, 72.98026269482028, 67.77818003008443, 73.74408937269642, 61.32053882844987, 70.8201349935224, 17.735730217349147, 2.326746799292103, 2.6470387222305423, 0.2078962830766555, 8.511263805051005, 43.793867018914995, 63.02052544009302, 60.62278055375623, 61.895056232329345, 63.03525394009006, 70.60024692166236, 65.80467477921518, 66.35323001492408, 61.488969326019294, 60.1631768288151, 56.97263463850945, 55.11768694846861, 55.15460037416028, 59.32773943870299, 61.50034812188918, 61.33383174096385, 61.33194508091096, 65.15609125937185, 64.81465285824191, 66.418898336349, 65.59508685142764, 66.53513385403541, 56.72627841272662, 60.67653663696782, 64.47026875711256, 61.00916931706091, 58.942041012548636, 52.918339467817745, 52.09490060806275, 46.78461543975338, 45.26413217667611, 42.37835030401907, 44.56192593420706, 44.6161566242095, 46.03244604602937, 47.09629481838596, 50.3197653062882, 53.91466071528774, 57.31286102725614, 54.076293745348536, 49.063061437299176, 45.57897298566757, 43.32743836987404, 42.116610542420425, 45.809549516247166, 44.07211211419875, 53.18012237548829, 50.534448392929576, 55.33200525468396, 53.38210874988187, 69.05892802822974, 31.56353242935673, 14.711660281304392, 25.115652045895978, 45.6481949744686, 67.05574220226657, 54.96501653425155, 56.426405368312714, 48.2093144232227, 50.54071634046493, 46.0495436576105, 45.880775836206254, 41.47746032284152, 44.257714748382575, 45.4033096375004, 52.389168585500414, 54.19463557581748, 53.46023059660389, 55.06177356166225, 53.34763503843739, 48.33355942080098, 45.40404312072262, 43.68241679283881, 41.699537077257716, 40.428571470322154, 41.5579395140371, 44.90560793107556, 44.10031003336753, 46.06394267851307, 48.04272743963426, 48.84002370219077, 52.09015846252442, 57.19717856376403, 56.420933661922334, 54.82996148447837, 52.710465615795506, 54.95092345822243, 54.346964743829545, 54.4506408322242, 58.41909493169477, 60.404645781363214, 58.042276751610544, 59.131122789075306, 59.36409981020036, 59.25621894098098, 57.66525460827736, 57.58201014611029, 58.40988520653018, 61.302433167734456, 58.677096674519206, 60.11510818235336, 56.918517697242, 54.40421958123484, 49.2465812929215, 52.42805888575893, 58.25035456688174, 58.233496219881125, 23.491508383904737, 1.7735614507429063, 0.22892260803811013, 0.20742619620455852, 0.9775329717705328, 3.6542837706304367, 54.3784535315729, 64.27473860402262, 62.8448111011136, 54.958258290444654, 63.18942662208312, 57.64871005089053, 66.63657419143185, 30.298683758704897, 54.65201139450074, 49.1697891296879, 31.647184818021714, 50.53487200890818, 20.66334612907902, 49.31649754124303, 36.604723391994355, 0.4306057648312661, 0.12142083742806029, 0.012964252175973549, 0.07848729364453785, 0.03495172732659886, 0.07469076107466414, 0.02369817917145068, 0.0441098373172985, 0.0073325909362475005, 0.12764397648073014, 0.08069197211654917, 0.0863409435917293, 0.2236627402805513, 0.1573561910059183, 0.24961749272000408, 0.09955459664906226, 0.20986336703983047, 0.18107943657425143, 0.2921910211443901, 0.16975970608332466, 0.26369399060645415, 0.22088763274012074, 0.09485024988891617, 0.13917022895428444, 0.22043642227447804, 0.1774386956446594, 0.581078548585215, 0.5604387303033184, 35.52986844893425, 73.51268522201046, 54.59537236921249, 31.440713213336085, 47.72824356632848, 63.133525002387266, 67.87520377866684, 15.155061675656228, 65.91518755882018, 81.12220887214907, 79.00641964327905, 74.30443133077314, 79.30467667118197, 69.58523950269146, 78.61997204442179, 19.47424234882478, 10.661584600325554, 8.307786929991938, 0.8017662323770985, 12.588350888221497, 51.40204921845467, 62.8838308395878, 60.381911723844475, 61.47287584120228, 66.85418728859194, 72.5345951511014, 69.0311654921501, 69.31418018956339, 65.25875537626206, 63.287631004087395, 59.73719958336123, 57.81691305098995, 57.84908040877312, 62.208135897113436, 66.4838057179605, 65.07774191517984, 65.60723835422148, 66.43084587589388, 68.52378337613999, 69.10507863567722, 69.15346499412291, 70.62525595388105, 61.04780466325822, 61.08423563741869, 67.4978639233497, 61.18580933540099, 60.02503879608647, 55.94997075296218, 55.41207651938162, 48.53785214885589, 45.61168555290469, 45.92602822088426, 46.147053780094275, 46.65873089144307, 49.58014357474543, 46.917960336131436, 55.835398320228826, 56.25615096861317, 59.33760027731619, 56.169246935075336, 50.82010284546883, 47.02686494396579, 45.34266194989605, 42.9982691426431, 46.14740679340978, 46.50007494034306, 58.087772323239236, 54.46853076258014, 60.35915805447487, 55.74534462344263, 75.65523286019602, 26.72388461328322, 9.954921564748211, 23.00001382827759, 45.21440829000166, 72.30240652638098, 58.191958319756296, 59.47095694080476, 47.82426711051695, 52.52559254246374, 48.51173700824861, 48.745259238827614, 45.02531866873465, 48.27579467527328, 49.29697590489542, 55.497843065569484, 56.22076726728871, 55.31028709103985, 57.05243133729505, 54.861218852381555, 50.36859097019319, 48.029281554683564, 46.23803707861131, 45.68818746074554, 43.846403245002996, 44.085942391426336, 51.221835920887614, 48.78637744534401, 48.29356693452405, 49.679450142768125, 49.656629793105594, 54.42445508895382, 59.24199250436599, 59.704337966057565, 57.835148149921054, 56.718708238294056, 56.931594879396506, 57.531442949848795, 58.11610752536405, 63.439689528557565, 62.899230064884314, 59.666706746624364, 60.237827377934615, 61.0378183087995, 61.09956033768193, 61.8582526330025, 59.002798526517815, 61.71444677537488, 63.79879428494362, 59.977691865736446, 61.198439367355846, 57.06097425953035, 55.26072009917229, 53.905074442586596, 51.15306108228622, 56.808122588742165, 63.99892930061587, 29.81717947990664, 2.9722169378111443, 0.7066486944114009, 2.461715066625226, 4.778694183595719, 3.7103520910586085, 61.038434120916556, 66.27897954756214, 68.4322823247602, 59.6783208847046, 69.48247340417677, 62.23439224304692, 72.93116246500324, 33.70719009830106, 63.64822626113892, 53.17917316190658, 47.344714210879424, 48.66090082353162, 35.94972287454913, 58.05508329022316, 55.34239169090025, 0.9538563809567883, 0.31806236193064724, 0.2460999540503948, 0.2081232902503783, 0.2162463963031769, 0.13443128566347784, 0.13556901816158526, 0.1485049183810911, 0.0956368383260504, 0.20794794804626898, 0.2822043602505038, 0.18832169473171237], [0.008868415757352787, 0.017065474192702004, 0.046146543351032084, 0.035088382090532014, 0.06029995263464028, 0.058861404221745274, 0.07684763566020035, 0.0775900744502583, 0.04816929892366452, 0.07347315624957124, 0.04426322727193756, 0.0731598569320575, 0.1348340180852721, 0.11161157185392034, 0.020941316014936855, 0.026531499818027503, 0.9784606736033195, 36.99946680376607, 43.1776979661757, 31.047823121470792, 27.914453398796823, 26.031513714021255, 53.5391329949902, 30.175005543616514, 48.85605442908503, 71.80519903859785, 63.91569268318915, 62.240515062885905, 67.8530502319336, 57.029548229709754, 58.875294039326334, 27.244492961514382, 0.6464362060350757, 2.421197718189609, 0.11009500887725623, 4.166624988279035, 33.078995058613444, 58.83399932615219, 62.229246093380844, 65.05924793981737, 62.35082387924195, 67.35454836199361, 62.22721822800175, 63.87711225017425, 59.11322109160885, 55.98675474043816, 53.702476178446126, 50.78315019607545, 50.253893021614324, 52.99200550202401, 55.83139750265307, 57.07678141132478, 59.555115315221975, 62.63971820954354, 66.52107607933783, 61.42967093375422, 62.01743810407577, 57.959051901294345, 55.70010008350496, 63.66018164542414, 58.228722695381414, 59.95326726667343, 55.994532800489864, 48.95631021068942, 48.578974277742454, 46.878846460773104, 42.80494336158999, 39.730460182313, 42.21369312655541, 41.96936868852185, 43.83669537882651, 43.94313281582248, 51.10708698149651, 52.027310325253396, 54.37733173370362, 50.267456577670195, 45.50316925971739, 41.47962547117665, 42.360911446232954, 41.56734143534015, 41.25517960517637, 42.57361765830748, 49.9385226926496, 48.81625413894654, 53.02440427964734, 51.10792244634321, 61.73033237457276, 38.07979345321655, 12.513373801785132, 17.219669857332786, 53.59031600336875, 61.13191596923336, 52.9184728284036, 50.48824287229969, 45.370852024324485, 45.84964006177841, 43.51945015691942, 41.338184802762925, 39.52917591218026, 41.77501916885376, 42.49746876378214, 42.899954934274, 49.335650474794456, 51.227966585466945, 48.37595239762337, 46.156216436816806, 46.369671821594245, 43.48945579221172, 41.70615803810858, 38.459843666322776, 38.95713352387951, 38.88999039126981, 43.446858852140366, 42.8782210811492, 43.23106181237006, 46.80424298009565, 43.203840563374186, 50.146710334285615, 54.355895980711914, 53.6768631012209, 56.352755023587136, 54.412574229701875, 55.12992474340624, 54.084766064920736, 52.45029087989561, 55.83464522515574, 59.2544303401824, 55.19744442355249, 55.13038758308657, 57.53225488047446, 55.81182879786338, 55.42949576531687, 54.193376494992165, 52.92296786462107, 54.95908983292119, 55.51915722508585, 57.18843560064993, 55.35029526679747, 55.37575929395614, 57.65368361626902, 54.19729102042414, 41.860550372831284, 39.465390328438055, 18.713628092119773, 0.9925144033566599, 0.22746575395426444, 0.6908343107469621, 0.6944960271639209, 3.863716519648029, 46.88084686956098, 54.04840569342337, 55.17393373673963, 51.41069804468463, 50.87435314732214, 61.48628250245125, 54.78885896744267, 44.423517257936545, 67.29524212498819, 38.65720948865337, 33.413663448825965, 26.798113507609216, 27.038270427334695, 48.14422269021311, 11.149838297597825, 0.1256468159056479, 0.09249465975670085, 0.03781666250659093, 0.06860033143311739, 0.017463380260573282, 0.007904811692799652, 0.06312670216204659, 0.0465462458950858, 0.008990779151058486, 0.06665101304890649, 0.03965287183922145, 0.10183016123670725, 0.04216137312112316, 0.01822721588635637, 0.09292140903492128, 0.023739084436167634, 0.08508001649451834, 0.018215707330513867, 0.04427260035769113, 0.05355304692901912, 0.10007696136111215, 0.01840860060896845, 0.009407525236207631, 0.07434928504329535, 0.029225869352118145, 0.008399651344535092, 0.10768574662506582, 0.07315422618581403, 1.5425997924420143, 52.132351398468025, 48.611227927669404, 30.67651979384884, 41.260721914229855, 31.608855416697843, 61.79540841810165, 33.806971273114605, 56.05097570726949, 76.69964236597862, 70.29268603171073, 67.23157421235116, 73.99167722271335, 60.768159281822946, 66.63427568251088, 30.498573626241377, 1.5796482947564896, 2.5789255384475958, 0.18496857385241217, 5.45898320213441, 39.72194863903908, 61.50587474146197, 64.15204686503257, 64.52450336948519, 65.2417597463054, 69.80045995404645, 63.780100268702355, 66.49561205217915, 63.64933629189769, 58.72725594428278, 55.498647151454804, 53.63769431268015, 50.58937334245252, 53.379916144955544, 59.53239302481375, 62.68320945001418, 61.02574917577929, 63.302037869730306, 68.68626363815801, 60.267064725199056, 65.82698129838514, 58.73048013256442, 58.66405087132608, 64.52997899824574, 60.37464357191517, 62.587915466677764, 60.37594972118255, 51.80638674766787, 50.33530573691092, 49.71285304715557, 44.630559567482244, 42.245954621222715, 42.85146267183366, 43.22220902289114, 44.42347411186465, 46.02631538145004, 51.37072124788838, 55.61583972746327, 56.54711238799557, 50.508086143001435, 45.43206845560382, 45.09991038230158, 44.289556549441436, 43.78862280999461, 41.840546284952474, 46.72171631167012, 52.39303996486049, 51.17024890838131, 55.11010500692553, 55.371079906340576, 60.69576409555251, 47.05507070787492, 19.591631043341852, 21.259358121502785, 58.24465144065119, 61.77079946764054, 58.76484401764409, 54.67056028304562, 51.18647575378419, 49.21088772435343, 46.958447041050086, 43.52443941177861, 41.55292672495688, 42.98572932520221, 45.61102267234556, 45.887781189334014, 52.24720624185378, 53.773200435023156, 50.079657416189875, 49.328574519003595, 47.29075416441887, 45.29934329371299, 43.86842735352055, 41.52794122695923, 40.18972658341931, 41.39161925162039, 44.024263120466664, 43.45941828143212, 43.24481756456437, 48.21212676263625, 47.38137268250989, 51.62912699484056, 54.55013959638534, 56.0157096770502, 57.5834967244056, 57.6276743796564, 56.77374301418182, 56.568544218617106, 55.62906203731414, 57.61498158977878, 60.570377688254084, 57.0405504780431, 57.82654246976299, 61.197090072016564, 56.47333260505431, 56.14584999699747, 56.066771091953406, 57.174024812636844, 57.94531183858072, 58.90083259151828, 60.89824861095798, 56.73611963948896, 56.16975684319773, 59.300082806617986, 61.09507706857497, 51.37052905174994, 45.05217121493432, 20.525449322115993, 1.6494711416382946, 0.48004423778864647, 0.8300802904751994, 0.569554073435645, 4.207956963969815, 51.62703637153872, 57.79350826817175, 60.96067313225039, 54.10645677197365, 58.00211952578638, 65.07995805432721, 62.147076360640995, 48.12429312736758, 74.10917574359526, 41.26442070930235, 39.67094605968845, 36.15870283495995, 29.17104744142102, 56.60478299663913, 10.526134371757507, 0.22735261808960672, 0.07582017385791387, 0.07530672640930261, 0.030430749456788746, 0.016282283355511965, 0.034998738312072335, 0.06794133493977209, 0.04738363745291868, 0.017752545893252376, 0.08093335876061071, 0.06241908589858682, 0.015885810829668997, 0.08909155164034137, 0.20883380615663147, 0.27174088623254533, 0.1254761621596352, 0.23706158743269984, 0.12206739265351527, 0.2652106914789446, 0.45421040466716217, 0.19787153229117396, 0.1651682040744251, 0.2495121556304155, 0.19324492813358385, 0.3056148121193532, 0.1382038090378046, 0.25359765656532784, 0.41684498710017054, 4.4459359876571165, 63.815503581877685, 63.491264773953354, 47.79819903835174, 41.51060042842742, 39.292221607700476, 68.2408235919091, 41.011710243840376, 57.9861907805166, 84.95532943356423, 75.28103090101673, 76.69225262057397, 80.0972935461229, 66.84995112880584, 69.09616701064571, 33.045337200164795, 3.287634825514209, 12.641933406552962, 1.2550293846476464, 8.7544576198824, 44.56111008121122, 61.4520598226978, 64.44915071610482, 65.83305312741187, 65.15691887947821, 72.47193136522847, 64.93212784490278, 70.95935560041859, 66.93976556101154, 64.14754006170458, 60.13439447649064, 56.15206695372059, 53.33094927572435, 55.9972196240579, 62.23566309098275, 63.64959124595889, 65.37397107770367, 68.58501157452984, 68.9736557006836, 62.46950695591589, 65.11069374699747, 64.2834972566174, 59.01970786433066, 67.65507251985612, 62.7447396709073, 61.74814385752525, 59.43253340259675, 53.59756454344719, 52.6902340304467, 52.46717668348744, 48.29986233865061, 44.70179373218168, 46.75502115680326, 45.914861233003684, 48.7725079444147, 46.56497055484403, 56.16773682255899, 57.13633868002123, 56.470312380021625, 52.975194223465465, 49.45853833229312, 45.61004207980248, 46.80636498235887, 46.22963928407239, 44.02524371300974, 48.87304221430133, 56.455411295736994, 54.09679205186906, 56.04098935281077, 54.59064199078468, 65.98027536945959, 41.74728016699515, 11.261971016083995, 17.309754933080367, 57.14707420718286, 66.16940421442833, 60.303111307082645, 55.37742237890921, 51.56645928659747, 52.83433406583725, 50.87694191163587, 46.38355701200424, 43.13690531638361, 44.2094813623736, 48.61924917467179, 47.775178647810414, 55.66017427752095, 55.89616367893835, 50.675108509679, 51.13025642210438, 50.717815276115175, 47.91456007188367, 45.98541290529313, 42.89189838594006, 42.78029518742716, 42.449839422779704, 46.98229897406794, 45.69262366141043, 46.43808972450995, 49.80114952210457, 45.87581403793828, 52.10959380672824, 56.0246919047448, 58.59572710529451, 61.88605831515405, 59.885061171747026, 60.602603881589836, 61.94224234550231, 58.417196504531375, 63.28031186134585, 65.71745695606356, 58.4858105259557, 59.4642496878101, 63.90975029237809, 60.05045967717325, 59.70853882451212, 58.808633358247825, 59.81439575072258, 61.41821369048088, 59.78519370478969, 61.74613560399702, 56.11821297676333, 54.49116676084457, 56.28733381148308, 60.876663807899725, 55.61261161681145, 53.24643004325129, 25.317495253778276, 2.242848772195078, 0.9075181126113862, 4.430757395682797, 2.813304316612982, 5.241039154991027, 55.129512894538145, 63.74364183795068, 62.921316931324625, 61.001297120125066, 61.96483127532467, 72.3532247543335, 65.29790847532212, 52.30376681973858, 76.75618725438272, 47.57294516409598, 48.53858563207811, 42.16242382603307, 44.63412892433905, 68.06513278715073, 25.3224648967866, 0.436395826719461, 0.24643925439205863, 0.21538100806215119, 0.23114133656265276, 0.24655465787697226, 0.1291004168770967, 0.3564598531492295, 0.10847474823916152, 0.1250665272856432, 0.21469226437470607, 0.2707752477257483, 0.12820076918409717], [0.04912991189367829, 0.042707417610912554, 0.05550050755001365, 0.060703405179083354, 0.07575032962185722, 0.05567984490264809, 0.011360063104920331, 0.06806092126475227, 0.13667365566136377, 0.01151457920880808, 0.010192408170100423, 0.1896728746472828, 0.0572634865379622, 0.09528741030202759, 0.050895943742005095, 0.06062111201425714, 0.16174699330041487, 31.8965083168399, 57.87018276030018, 30.039118951366795, 28.000884786728893, 23.120152104285456, 53.77254539920438, 41.97695847480528, 48.087203195018155, 73.25860977172852, 62.48551414858911, 67.45452957768595, 62.660012552815104, 58.15897118660712, 61.25945183538622, 22.467059819929062, 1.3042787871053143, 1.1353854498555584, 0.09745458110926614, 4.583395940642204, 32.70583056634472, 63.21172529651273, 65.83238632448258, 68.2833734635384, 69.32535109981414, 65.83814436389555, 64.03353637264621, 65.20425796508789, 60.512342299184496, 55.97215175628663, 50.72862532831008, 49.21949732688166, 47.964260424337084, 48.528446305182676, 56.1474895477295, 56.51964795204901, 59.97267515428605, 58.172915212569706, 60.63552825681625, 64.34384684408865, 59.01792318590226, 60.863202233468336, 66.59903710888278, 60.79760059233635, 61.76612008002497, 61.06833042636995, 57.06578308536161, 49.1328796263664, 48.986457547833844, 44.59443061582504, 43.05262927086123, 38.8169676257718, 41.480021630564046, 41.50203789434126, 42.9164328113679, 47.32950325935118, 49.16504698414957, 53.70149558590305, 55.78547047030542, 45.35955167585804, 42.39916632252355, 42.21260663001768, 40.304773622943515, 39.83813708828342, 39.31965466468565, 42.66576197839553, 49.23145663353705, 51.16902512888755, 51.12031321371756, 52.54523969465687, 57.08006443515901, 48.61880986921249, 13.648799946231227, 18.849469577112508, 62.418563212117846, 59.43590271857477, 56.311499534114716, 49.54567378567111, 48.58808594365274, 42.42733286273095, 41.71630128737419, 40.28677778859293, 42.11940326998311, 40.64759662074428, 44.295636223208525, 44.5908808708191, 44.60881002487675, 50.28239296328638, 49.202960614235174, 48.1670077385441, 41.401684053482555, 41.91252962235482, 42.6694215497663, 40.57509160810902, 38.67946501701109, 39.510815297403646, 40.936534097117764, 40.78550715600291, 43.67822770149478, 45.98261625536027, 45.3387866481658, 48.56439482781195, 52.99981886340726, 55.232934028871604, 57.090305743678925, 53.32120610821632, 54.10964173655356, 52.916166474742276, 54.602938621274895, 56.644293031384876, 57.22275633965769, 57.74405110266901, 57.48402933920584, 55.03114769535681, 53.695576729313025, 48.8250441705027, 50.272928284060576, 50.963822410952666, 53.53282974612329, 56.21611141389417, 56.39059805100965, 54.55595647135089, 60.15956824825656, 52.13730142962549, 47.042362228516616, 39.7406191210593, 53.77028611398513, 22.660403251647953, 0.45283199798676277, 0.5384938659206514, 0.36368856687218915, 0.17612678539608756, 3.294021179599147, 41.08155588949881, 59.22423201222574, 54.4038861797702, 59.960794295034106, 63.18012276003438, 66.00940289035921, 55.87537903939524, 58.31328507392638, 53.3405198589448, 31.025857848505822, 34.503548914386386, 26.769950889771987, 33.00328939191757, 32.86587111411556, 1.1152844058890496, 0.17957059576386408, 0.08297564191443306, 0.03823517633962535, 0.04974407309125509, 0.029225162636007995, 0.04515674243110322, 0.0998155645004684, 0.007234048088937397, 0.03639509826297722, 0.0338333691920965, 0.060620380400289456, 0.053237353586741996, 0.05504959202822178, 0.07255043398829238, 0.025258043352814934, 0.029723692437513705, 0.0448744083874889, 0.08635876279684805, 0.03815562960000769, 0.04651339221445303, 0.09166702432858367, 0.06037128691170966, 0.02251343951830941, 0.09678458359332816, 0.02066843932674777, 0.030192476960139412, 0.06460778760693728, 0.029620699576973438, 0.13956637301992986, 36.196957711250555, 68.11042047316029, 26.018265908764256, 40.97510276302215, 29.512936915120772, 56.2127342531758, 48.35959219163465, 52.85153758141303, 79.18597006028699, 69.91725244829732, 73.24782325375465, 68.24941358258648, 63.65960897937898, 65.76979314127277, 25.801600064000777, 0.5060909820660469, 1.4082575108735793, 0.22071635080201013, 6.442005653535166, 38.000361534856985, 66.21124021468624, 68.66284708822928, 72.29732313463765, 70.31754601386287, 70.24607258458292, 67.0003818696545, 67.91521195442446, 63.89030318106375, 57.42768841405069, 53.645731249163234, 54.17910298993511, 51.42853698422832, 51.90764273366621, 57.65899842785251, 60.87337293932515, 60.334525569792724, 59.69889371625839, 64.68217872804212, 65.55556504957138, 57.46968523148568, 62.58688780569262, 68.82009490843743, 62.2100539361277, 62.354491295353064, 62.539046656700876, 60.171629536536436, 51.34423348211473, 49.22993475391019, 48.43601565207205, 45.77123188203382, 40.58194006642988, 44.09927060527187, 44.74581449262558, 44.92006970990089, 48.05182733843404, 53.365117042295395, 54.40736139974287, 56.00026338331161, 49.14132056697723, 44.72903459302841, 44.61239507121425, 44.379465118531265, 44.099776591024096, 42.78380963110155, 48.77507317450739, 49.76788390067316, 53.927647682928274, 55.74366584900887, 56.55001494192309, 58.30538149802916, 60.94583872825869, 24.83333160800319, 25.19575861192519, 69.9250893439016, 59.355811842026256, 62.81158078101374, 52.42025729148619, 51.53433899725638, 45.72424580973964, 45.6562005319903, 41.78006333689536, 44.04778557439005, 42.654948003830455, 46.57558056616014, 45.94582050077377, 48.13374211711269, 52.537693054445334, 52.94592941960981, 49.79357934767201, 44.81451480619369, 42.00153604630501, 45.08622915514054, 42.2468920676939, 39.55600100178873, 40.615782276276626, 43.15731733076034, 42.36478282559303, 44.44558451252599, 46.99228140615648, 46.84494541537377, 49.75136287750737, 56.282175894706484, 57.38198103443269, 58.22409429857808, 55.83173874885806, 57.09296511065576, 56.41739960639708, 57.90213438772387, 58.48153514246787, 60.952377319335945, 58.52103733247327, 57.823792888272195, 57.65719805994342, 54.35435448923419, 51.34211147985151, 52.42761173555928, 54.26009601162326, 56.30600429350331, 57.48062079952609, 58.507677739666356, 57.20789055670462, 61.937151109018636, 55.29152639450566, 51.67022166713592, 43.948792795981134, 54.06107887145012, 25.709569492647727, 0.5524369725777257, 0.8730870569425245, 0.3504058280058446, 0.7152369077647887, 3.5065008747962216, 43.34802296853835, 64.40604386791107, 58.50570478746968, 62.29474183051818, 68.50598366029801, 68.76414622029951, 63.793573610244266, 58.710829058001124, 61.064019741550574, 32.7849506562756, 45.12064403103244, 30.668706432465587, 36.63885585723385, 40.84344056344802, 1.096957131258903, 0.046774662670589266, 0.05228232922813585, 0.0438459238578235, 0.053125876302440325, 0.03729373855035632, 0.11625945793404696, 0.14993777859114832, 0.050342858904191566, 0.015729048172943294, 0.054100623594657074, 0.05448071428784921, 0.08492315233114266, 0.14898815132196874, 0.17327381267903313, 0.23373049924210196, 0.1924317411237186, 0.15507974541716038, 0.21473983843480388, 0.24529203772544864, 0.19276462164857697, 0.20835146187774597, 0.3451433555493432, 0.14068720561842765, 0.3266085630222675, 0.16320822940718743, 0.18384792511501621, 0.20387260543723262, 0.20705010832077075, 0.38590125559318456, 52.22136174478839, 77.3660687477358, 48.177166677290394, 41.8229740665805, 36.92224710218368, 68.00995288356658, 57.654636752220895, 58.81011601417296, 87.03920625871228, 76.78082758380522, 82.64093491338915, 74.33299403036796, 70.65199082897556, 71.62247934649068, 27.891291802929295, 3.5493544849657246, 5.4795251450231, 0.7910268441323312, 9.456426558956023, 41.143996100271906, 67.35316768769296, 69.86092721262287, 74.88815061507687, 75.40379324266988, 73.16262937361195, 68.45321993674001, 71.93693576320526, 68.98273991000268, 63.29418528464533, 56.77740650792276, 56.419376480963926, 52.49274269227059, 53.6856335209262, 61.76962275658885, 63.4582031157709, 63.09912189360588, 65.19080423539685, 67.3900850357548, 66.98189181666221, 61.041105255003906, 65.49923196915658, 68.95536961094027, 65.03066955074188, 65.26458009596794, 64.84637698819562, 61.94657264217254, 52.03226035641086, 50.99157710229197, 51.465901482489805, 48.405985986032796, 43.20418573194935, 46.5929292094323, 46.80709454321092, 47.93402679504887, 49.56623092774422, 55.44962929141138, 58.252731523206165, 57.98354318065029, 49.199301042864406, 46.93202203319919, 45.873248807845584, 46.195440138539965, 45.38118354735836, 45.51679949606619, 49.3714617144677, 55.63812663478237, 56.95745506594258, 57.32840538024903, 58.672672240964836, 62.890542014952636, 57.33735622898225, 15.726319589922506, 18.38745947807066, 68.81369360031621, 65.11018776124524, 65.34255681499359, 55.10542169693978, 53.8144245455342, 47.129313330496515, 46.6580327095524, 44.073022104078724, 47.5810174019106, 44.56117676150414, 52.531350581876694, 50.33869074236963, 49.84402102808799, 54.97352415515531, 53.25898555017287, 51.71373251945742, 43.952213102771395, 46.303317085389175, 48.086183378773356, 43.81362399747295, 40.11088302058559, 42.04430557066395, 44.80542667450444, 45.01239445901687, 46.923808590058364, 48.49380393182078, 48.65291487786078, 51.18814668347759, 56.98726507925219, 59.214151520882886, 64.50466794352378, 57.37759582458004, 58.75982338382352, 59.07078104634439, 61.706939358865064, 60.95541715621949, 65.24192448585265, 59.86542578666442, 61.33495353883313, 58.376321484965665, 58.71141741352697, 53.47162508195447, 55.323623149625725, 55.928425173605646, 59.962508370799405, 60.45915103727772, 60.90979999111545, 55.75109874048541, 60.22846075796313, 57.3921674297702, 57.14837643408007, 47.0588989411631, 61.84321818813201, 30.866521366180915, 1.4361934892592894, 1.6124358773231509, 1.4848909406892716, 1.4348570641971405, 6.205489183625867, 49.87034797668458, 70.26191111533873, 60.832003701117735, 67.89713767267042, 74.30353703037386, 75.93269348144531, 66.06498287570092, 68.85356841548797, 62.74719507463517, 42.714230706614835, 48.838996041205625, 42.9665607021701, 48.68022634137062, 57.67815920614428, 6.080733787628913, 0.7518329891947009, 0.23423968724185423, 0.23764974377568693, 0.260336012729714, 0.15144845801255397, 0.21336048180537842, 0.3227943644648598, 0.16848655988372144, 0.13511226121937076, 0.13623064233651086, 0.12258165215532627, 0.1972810930061725], [0.05087010359631912, 0.06683058405835783, 0.08113261822971606, 0.06680493543465292, 0.07354849333604498, 0.040208637984769965, 0.05470945282028087, 0.024607431691800876, 0.0323066976852715, 0.013093401193468562, 0.029304996658597263, 0.06124413301867824, 0.019415332072023905, 0.1369820673379206, 0.07056322489534655, 0.12311183862508306, 0.05533487934078421, 5.274111599691453, 50.61395483632242, 36.24374766503611, 26.867908162455407, 25.319024978145478, 50.85392936583489, 55.07769838456185, 32.505593569047996, 63.93015446201448, 65.92499348425096, 59.91218043911842, 61.29485122619137, 61.98743589462773, 62.31162371173982, 17.51405550587562, 0.3683332966700677, 0.4208288281675308, 0.29724606763451333, 6.051114009272668, 37.4324768589389, 69.13208807668379, 68.52484241608651, 70.03988142936461, 67.30333789702385, 66.53526721462127, 62.087334740546446, 63.007436490828, 59.915675270941954, 53.97444940382435, 51.070114720252256, 48.666368607551824, 47.879662744460575, 45.97226119810536, 49.19783799879013, 54.88642792547903, 57.55532626182803, 60.42668557936146, 59.07884543941867, 58.971796112675825, 63.61640014956075, 63.992465234571895, 62.72033468369515, 59.484995103651485, 60.497813840066236, 59.55262853253273, 55.561934594185125, 48.328629001494384, 48.8350462144421, 44.71583973976874, 41.90269624033282, 40.257442382074174, 41.92959977734474, 40.698261876260084, 43.47389182736797, 46.93320266662106, 48.46857132450227, 52.94036749870547, 52.19814915810862, 45.08149485434256, 41.91598130810646, 42.87466741377308, 41.81004201212237, 40.98772102786649, 40.875525551457564, 44.74047222445088, 51.526447188469675, 54.29979824250745, 53.092700589087706, 55.76306196951098, 54.46663233541674, 54.274793132658935, 12.521455845525189, 26.48852082990831, 64.22083739311465, 56.01558023883451, 61.361484450678674, 50.04932572764736, 50.56486245124571, 43.54507892362533, 43.515410115641934, 41.31305809943907, 39.47727118769, 38.89132007475823, 43.15245751411685, 42.44724281372563, 43.38422252285866, 45.71806415434807, 53.87368763646772, 50.813858432154504, 43.79576936844857, 42.52598439493487, 42.86293560458768, 40.82056530060307, 38.141441345214844, 40.2296406222928, 39.947837937262754, 40.18900094493743, 42.16032143562071, 45.0350030006901, 44.55051575937579, 43.70140498684299, 49.77233971318891, 54.29509139830067, 55.269337546440866, 55.7218143247789, 54.020996170659224, 55.55773765810075, 55.62028769523867, 54.71384363789713, 56.04087952644595, 58.45425113554924, 54.66034250874674, 54.51907050225043, 50.89999760350874, 50.054573858937914, 50.48208475112916, 49.02388480401809, 54.71175693696546, 55.672910213470466, 55.832923304650095, 50.31230888059063, 51.34964243058236, 50.01463236347322, 56.79017382283365, 48.35230050548431, 47.71514284995295, 25.10265134995984, 0.13462827751232734, 0.4046288264855262, 0.05537100038641403, 0.2318802130438628, 1.1090942928867957, 27.739084228392574, 58.05080398436516, 56.62964690116144, 61.01093438363845, 58.05283969448459, 62.68426064522036, 52.33114496354134, 60.480986872027, 44.97548495569537, 26.129659260472945, 35.87426039480394, 23.372664490053733, 45.843030868038056, 18.917679594409083, 0.10140762544207035, 0.052153415782677556, 0.00014055413650508386, 0.054161493110680775, 0.03180968473785587, 0.0432561740519539, 0.0035971263470503715, 0.0545592995871219, 0.06848275225849883, 0.10034784239025847, 0.01694891774546235, 0.04804152311877378, 0.05426255542965186, 0.06791074504895557, 0.03413273337026758, 0.07345595757567114, 0.09837462972368925, 0.00797521565184598, 0.028223389677042444, 0.06411255006828616, 0.02187328304224197, 0.051118074766089844, 0.07257585278562001, 0.07107943792136447, 0.07835461487693172, 0.035329320573157845, 0.08276915823620173, 0.034224667751620856, 0.023282808214125615, 0.036117981278127244, 5.882558486154003, 62.61254010661956, 35.536779665177875, 31.966493206639445, 35.91526485258533, 52.22167945677235, 61.58397305396296, 35.27787185484363, 71.81945293180405, 71.77571850438272, 66.0407740069974, 68.50391264884703, 65.22996910156743, 65.73659812250446, 19.606377194004676, 0.38557067333209905, 0.8119812487594543, 0.219512811351207, 7.448929067580932, 42.22425214705929, 71.51112325729864, 69.60062303850728, 73.56005176421135, 68.52126521448936, 69.48853738846319, 63.78661924792875, 65.57749109883463, 62.356577996284734, 58.18706712415142, 54.92506327167634, 53.951625131791644, 48.9449078805985, 49.39708655880344, 51.216415205309474, 55.286207660552, 60.431976856723914, 63.17906764245803, 60.66846832152336, 62.970005312273585, 66.85626614478328, 64.11647096756967, 66.03990324081914, 60.989624146492254, 63.24715214390909, 63.07161431158743, 56.91974932147611, 48.53423964592719, 51.97628813405191, 46.70010012965049, 43.626460259960545, 41.96918041475358, 44.92185831069947, 43.789532799874586, 46.846753628023215, 48.86449536969585, 51.92626614724436, 55.95865095815351, 56.338050057811124, 46.82122292057161, 47.066614243292044, 44.22881472495295, 44.41577449921639, 45.147963339282626, 44.49781871611073, 48.453552569112475, 52.94486645729312, 57.95183081780711, 54.41035024581417, 62.194215405371885, 56.44546808735017, 63.65094838603851, 26.721923428197062, 36.37975585076117, 70.13019792495236, 58.277038451164, 61.86492458466561, 54.13775728594873, 53.84021020704701, 46.254365905638664, 46.55698460917319, 44.77969200380387, 41.729900144761615, 41.96075124125327, 44.5791490616337, 44.57102191063666, 44.836993909651234, 48.843718574893096, 55.827377073226444, 51.71171249881868, 45.49486167969243, 43.39986101273568, 46.40849151918965, 42.37316493065127, 41.65223721534976, 41.23486565005395, 44.30466159697502, 42.25625868766539, 42.93819804345408, 47.18866271357383, 47.70867878390897, 43.919269115694114, 53.5207566907329, 57.01461968883392, 58.37162248549923, 57.292119533784934, 57.699210566859094, 58.331002419994725, 58.97968792146253, 57.80396922942131, 57.575440176071666, 59.95493427399666, 58.300066686445675, 57.09751506005564, 52.946796263417895, 51.348897180249615, 50.549659344457815, 50.583807499178, 56.33309610428349, 58.51248656549762, 56.89295561082902, 53.20160519692206, 54.308902063677394, 51.96561536481304, 56.574180664554724, 54.475187024762555, 53.40104987544399, 28.023867914753577, 0.09368688408886233, 0.40887427125726983, 0.28371845642405175, 0.4171866623143996, 1.3451372591718551, 30.67263468619316, 63.8309302637654, 60.33056005354851, 65.92388737586238, 61.993488111803615, 68.10818472216206, 55.88967215630316, 66.55442407054286, 50.98233992053617, 29.8403077356277, 48.611349521144746, 22.315626913501372, 56.67086316693214, 22.49914480793861, 0.15969683476273092, 0.04782925547671415, 0.09739545444327016, 0.042000080969545155, 0.042287643563242695, 0.016029104703075944, 0.0786315173571629, 0.04534839464712047, 0.0627436467085875, 0.013633262396099107, 0.03710124746806199, 0.03492161624073502, 0.023920672172079646, 0.21909690221711514, 0.21998988494517344, 0.2644636944657372, 0.23036570318283575, 0.14279491268098354, 0.16435589040479354, 0.26943275524723914, 0.20270265128102996, 0.13967975403272337, 0.19996028633848315, 0.19843284491329424, 0.26446249936857535, 0.14246327321856253, 0.21900504827499392, 0.3112455890063317, 0.1719315653486598, 0.2081882238628403, 13.30714483414927, 75.49844003492787, 54.18262135597968, 39.53026240871799, 42.62192164697955, 64.18064094358876, 71.616227088436, 42.64649137373894, 78.79489406462639, 79.76293502315399, 72.31429915274344, 75.02639062942998, 72.16050301828693, 73.30725500660559, 21.81510502292264, 2.0952769489057603, 2.8136298733372844, 0.945905430182334, 9.61728786268542, 47.515933513641365, 72.48467122354816, 73.86714981448266, 76.87926338564965, 72.63496075907062, 70.86081781694966, 65.56949338605328, 69.93736636254096, 68.4495956667008, 61.718788839155636, 58.87676492814095, 55.08838684328141, 49.150259648599935, 52.22799447274978, 54.64983840142527, 62.14120457249304, 61.93145190515826, 66.05527108715427, 65.6051241966986, 68.11393491683468, 69.36476307530558, 67.52831720536756, 66.05407868662189, 62.28294726341002, 63.482992495259936, 65.45338730658254, 59.60806731254824, 52.24494695663453, 54.860857994325706, 49.59674304531467, 46.60476300024217, 43.232885714500185, 47.20120253101472, 45.17827933834445, 48.361521997759425, 51.25475245137369, 53.29969975256151, 60.15978397861604, 57.703999780839496, 48.34444007565899, 49.03860938164496, 47.491614818573005, 46.81618267490018, 47.47883965892177, 44.64914375735868, 50.214865438399784, 57.65184402465821, 62.735890803798554, 58.46636341464136, 62.20684151495657, 59.98866665747858, 62.56123550476567, 17.658033947790823, 26.377096099238244, 73.86525138731926, 60.607349949498335, 67.86845730197045, 57.16251265618109, 55.80031664140763, 47.521052206716234, 48.41439162531207, 45.83377015206122, 43.653450089116255, 43.543949281015706, 47.81509660905408, 48.48355477856052, 46.76305809328633, 49.93739697241014, 56.13370633894398, 53.84104959426388, 45.51626605372275, 45.67722051374374, 47.925730982134425, 43.223723057777654, 43.03605333451302, 43.380449202752885, 47.66512870788575, 44.13474452111029, 45.37303678451046, 48.03076813297887, 48.22552165677471, 43.618258583930235, 54.038913557606364, 61.00646288164201, 62.55065687241093, 61.421186847071496, 58.20465895437426, 60.901845424406, 61.73400763542422, 58.68067779848653, 60.82416680551345, 63.046864155800115, 58.73246877424179, 59.838475181210434, 56.44653889440722, 55.41983104521229, 55.228313476808616, 54.26647770789362, 59.013067291628936, 60.85333747248496, 59.3241112462936, 56.26111668925132, 57.16381096070813, 55.2839405305924, 58.109380660518525, 55.947625175599136, 59.268084110752234, 33.39644816613967, 0.5003216351953246, 1.7350355631882146, 0.9037856709572577, 0.7006391330111412, 3.7864301377727143, 34.58061172116187, 69.80162097561744, 63.533089007100756, 70.10580078248056, 68.65678310394287, 74.1323491065733, 60.06912231445313, 71.74670865458828, 53.67761227392382, 39.29371603073613, 52.2935765020309, 41.37641222246232, 66.4873593853366, 40.522296505589644, 0.5015680602481288, 0.21672725437148926, 0.14823392243875613, 0.18374257270366917, 0.1176126066955828, 0.16427837762861483, 0.12516713761273893, 0.23878726176917556, 0.2955860163896315, 0.226481897876628, 0.13717305305744373, 0.10780963070330121, 0.12558398137409843], [0.01703411055308196, 0.016182665112278154, 0.0760886570318572, 0.0191906308229532, 0.04561772434822014, 0.040940087243554094, 0.05546444013053852, 0.07418045458654243, 0.044193785232041156, 0.0718748516913864, 0.06276916509734527, 0.05624552039549716, 0.019904032965461095, 0.04082659897845119, 0.10065969380159533, 0.043330465428411, 0.11956210894089554, 0.1483065628957364, 32.15180950780069, 48.74556518370106, 33.914758005449855, 29.7239996540931, 23.676842335731756, 74.26380342052829, 43.37494611740113, 44.11878831924931, 72.20087205210041, 60.31727890814505, 68.47411832501813, 58.329213819196156, 63.10924160865046, 23.7258445062945, 0.451530690395063, 0.23680382948969644, 0.2115631782479825, 11.529863015297922, 53.59956495223507, 68.67935242191439, 66.26963646181169, 66.83091978872976, 68.23786612479918, 64.77347973854312, 63.58585273065875, 61.245880434590006, 56.37648536312965, 53.00062687166276, 51.02215197778518, 49.129290657658736, 46.05186570075251, 45.12180505260345, 45.48348288382254, 46.4338888660554, 52.49603748321534, 56.54610826123146, 61.9464079026253, 64.77990458088537, 63.218028545379646, 59.363570290227095, 60.39250996805007, 62.461564156316946, 62.44984803661224, 55.96596225615471, 49.283377047508, 48.73561805294406, 47.88775459412606, 43.5497033980585, 39.51028969980056, 41.606812246384166, 41.795850876838934, 44.34208885315926, 45.83433497336603, 48.01233691553916, 48.70720440341581, 50.48071584393902, 47.93499169811126, 42.576528056975334, 41.95298887068226, 44.010158277327015, 42.546392486941436, 40.136084248942716, 43.18156150079543, 46.97862371321648, 50.64185857772828, 51.96406602859498, 54.246363793649984, 59.05422079947687, 54.57537220370386, 55.24263797267791, 14.056736250077526, 34.86010413016043, 63.945596833382886, 55.9981688376396, 60.66299269276281, 50.840306974226436, 49.847555083613244, 44.80442254774032, 42.337930279393355, 39.868664895334554, 41.384908076255556, 39.16892190133372, 43.913883701447524, 41.073828820259344, 42.16584805519351, 41.34587657067084, 51.90429302953905, 51.30873603205527, 45.010315602825536, 44.745335963464555, 43.072146984838675, 41.78855134594826, 39.680022424267186, 40.67487278292256, 39.995584949370354, 40.85463893028998, 41.50576806837513, 41.788770998677904, 43.77599670040993, 42.72598212765109, 44.34820775062808, 52.05921488423502, 55.280053461751635, 54.03117079888621, 54.77322832230599, 55.77118127576767, 52.045600337366906, 54.73491068809263, 55.06445254048994, 55.73087499987695, 54.34628225141957, 51.64811126647457, 48.25550817674207, 47.08874817817442, 46.82288600552467, 51.002657798028764, 54.19267046836115, 56.837787474355395, 61.49450379033243, 59.45094893055578, 58.75364172843195, 57.03600445101338, 54.34846308923537, 47.43405795866444, 49.89885184072679, 32.76708818251087, 0.07696384353743446, 0.281622807585424, 0.046777577635141156, 0.08813547391083934, 1.2193963676691055, 20.263393809718472, 55.14638300864927, 57.656703841301706, 57.87357168812906, 59.96939997519217, 58.20625143666422, 51.27137153379379, 59.91336499491046, 29.801546873584872, 30.788783911735784, 27.003677083599953, 29.66073182321364, 44.10891179115542, 5.493287761365214, 0.2866598969746021, 0.05472835987025211, 0.08841242235634597, 0.10989098434126186, 0.042399304708646196, 0.026884597403207616, 0.04611918635125603, 0.05125615445356216, 0.05400755923361548, 0.03372259287824554, 0.01803795194944307, 0.013056454688100325, 0.07374664963853937, 0.007041999901224289, 0.03700712973612451, 0.04694602121749232, 0.011792893206039745, 0.02129181656205366, 0.039337906280472394, 0.09301634265049812, 0.03630882144094475, 0.02586759078586775, 0.06896281359536995, 0.033979508124532244, 0.08820452907633397, 0.09421890150875815, 0.0919552112839395, 0.17811556496927816, 0.04819592813991251, 0.09253791308090573, 0.4530818345806291, 40.754206642027825, 55.399913249477265, 32.710202047901774, 45.62697887420655, 28.094890271463704, 84.72276426130726, 48.27417473639212, 48.24227409978067, 78.79366244039228, 64.91617948778214, 74.77170328940116, 64.7955273812817, 68.88041311694731, 23.395971213617635, 0.3537321817730704, 0.10087852681716604, 0.24349597523049002, 14.273466813948847, 59.424472931892645, 70.06168196278234, 68.46039787415536, 67.84773934272029, 69.73397577962568, 66.44172653075188, 65.06771241464924, 62.02645563310193, 58.2329902341289, 56.37845439295615, 54.16106008714246, 50.23981563506588, 48.34982548990558, 48.40558198190505, 47.73715126898981, 48.73861082138554, 53.84143398654077, 60.32601010414862, 64.46111394513038, 63.504632211500606, 65.69201646312591, 60.8574559611659, 61.77455317589545, 63.300861158678615, 63.18633579438733, 59.54053978766165, 50.775113259592366, 49.06134343916371, 49.26454967068088, 45.819300528495546, 41.1765282384811, 43.537869607248616, 43.62989233386132, 46.879599555846184, 48.696814044829345, 51.82083283701251, 51.906364040990034, 56.53984423606627, 53.204574431142504, 45.699499576322495, 46.20386146729993, 44.99663045329433, 44.21108953414425, 44.109476612460234, 45.46909170766031, 50.257529058764064, 52.650810287844756, 55.97607020408877, 55.27714306308378, 63.26412816201488, 56.60159018731887, 60.82698306729717, 29.66348924944478, 46.750055436165106, 66.64982395787393, 58.45303912316599, 62.4013557741719, 54.48854269519929, 54.10238927410495, 48.726322035635675, 45.09696468230217, 42.68898240981564, 43.376707261608495, 42.35791083305113, 46.1117995169855, 43.261679833935155, 43.650351416680124, 45.67256858271938, 53.92253291222357, 53.00238801587013, 46.574678421020515, 45.92574188786168, 44.15545855799029, 45.45778743682369, 40.175288338815015, 43.10450261639011, 42.47854332770071, 40.717834503419944, 44.45431570852957, 45.16464125725531, 45.15561980585898, 45.98794675642445, 46.78994594081756, 55.085637261790616, 57.215421507435465, 55.08298573955413, 56.29327227992397, 58.13725694533318, 54.767403602600105, 57.34303974336194, 57.30391017852291, 60.121764444535785, 58.14911034799392, 54.15561191497311, 51.00321085222306, 51.066765016125096, 47.72159122651624, 52.611237495176255, 55.13906386590774, 59.342279664931766, 62.170143819624386, 59.49305949672576, 57.9162549203442, 56.75938321698097, 55.9799337387085, 53.65731008591191, 56.06715156186012, 37.21651900199152, 0.2076559612948087, 0.44505292669900004, 0.2646423768131964, 0.583009948172877, 1.3709900912738617, 21.62892580032349, 61.29431778384794, 60.16587934186382, 64.7720637629109, 65.20889812900175, 65.48396218207576, 55.483953952789314, 69.64557340068203, 32.720429628126084, 37.21488729599984, 31.605368429614654, 29.23150097170184, 56.558648078672356, 3.862420911750486, 0.09672429247368729, 0.09124849517379077, 0.04013001821154068, 0.11833118950767864, 0.05452196046169247, 0.089761380616936, 0.03915547776306349, 0.05079153361880491, 0.0709931074731773, 0.06539250678953624, 0.04710413027374495, 0.06563453694745418, 0.010220536045850286, 0.33413332376268606, 0.12847823856939233, 0.15365272279708617, 0.09409530088305475, 0.11976434083114709, 0.1803270616238156, 0.33212176073462735, 0.23274385460442115, 0.1622162681193121, 0.16568646255520084, 0.1118694447101124, 0.23107398211235003, 0.18436354825333243, 0.3853123791275486, 0.335472813176532, 0.3365614241169345, 0.42866685758194617, 1.0968728003001984, 55.65211772918702, 69.67713279108848, 51.73691764954598, 47.14618736697782, 38.42441681892642, 93.6454660661759, 56.25304445143669, 53.89372702567808, 88.47061249517625, 72.09008862895351, 82.43650098000803, 69.30825741060319, 76.34997875459733, 28.224169631158155, 1.8145589218024285, 0.9913798577843175, 1.1037829133772081, 16.489114684443322, 62.76431229806716, 71.96395304895216, 71.29084294842136, 73.23935877892279, 75.04567300119709, 69.81225059878442, 70.54059551608178, 67.7155476231729, 65.89690146907684, 62.82637596130372, 57.71080509308846, 54.026930716729936, 51.56044629312331, 49.69111919403077, 50.726923019655295, 53.050876355940304, 55.782771879626864, 63.57479949151317, 66.93839273145123, 67.2228116373862, 69.68172196419009, 65.62195116473784, 62.79822511057701, 67.23646933032622, 66.40248713954803, 62.07026458555653, 51.82218605472196, 53.09899991558444, 51.77298384328043, 49.000695751559356, 42.29413701641945, 46.206493377685554, 46.1848654285554, 49.414858818054206, 51.88699145470896, 53.381249750814135, 55.010029654349054, 58.03092541233186, 53.76631275300057, 48.31397894890078, 47.19207125325357, 47.675719107351, 46.83300179819907, 44.1439817028661, 48.06579882098783, 51.31474902552944, 55.598428326268355, 59.36100113776423, 58.12204991617511, 67.29221405521517, 56.41548156738282, 62.23465504184846, 21.047675648043235, 36.083232510474424, 71.6435032506143, 62.73020728941887, 66.63032193337718, 56.11266674533967, 54.81637831657164, 50.28934340323172, 48.658504255356334, 44.152512857990885, 44.14639396052207, 44.39400142238986, 50.22264742082166, 45.213321793463926, 46.26499552880564, 46.09240731885357, 56.863510377945445, 54.64694761460828, 47.32974252393169, 49.319019625263834, 47.26539211888468, 45.7777940073321, 41.38244482778734, 45.19279210798202, 45.47805040113388, 43.794792698275664, 46.95145737740302, 45.90827557348436, 46.15199988888156, 45.45298253336261, 47.33239012379801, 57.85270860118251, 61.966176648293775, 57.94739461714222, 57.44161675053259, 60.33735359868696, 58.2420862105585, 60.107165382754424, 61.65820783184421, 62.38030833582725, 59.43415334147792, 56.1122666635821, 52.84714060444986, 54.86850661616172, 50.37117188976657, 56.182547692329656, 58.668859697157345, 60.744648595010084, 65.08348034274194, 59.9198486728053, 57.97986399742865, 56.19295374039681, 59.77472882116995, 54.44152916631391, 55.95098664683681, 43.698682861943404, 0.38190993750768326, 1.5623892531279595, 0.2347559998593023, 0.402517733314345, 2.627809057312627, 25.538150149007, 65.34449838822889, 64.31292287765011, 67.92935602126583, 70.40899215206024, 69.76377010345459, 60.35674187444872, 71.19506651355375, 38.13927619687973, 45.73448319588938, 42.35977788125315, 45.78254399761077, 70.1226983531829, 13.360598894857592, 0.6388287077988348, 0.2730511110876837, 0.3377595549869922, 0.22722696434826622, 0.17443423670145775, 0.12393169059988954, 0.10980633162562886, 0.217890206484064, 0.17163925684027134, 0.1431173897318302, 0.1464131919126357, 0.14232168484839702, 0.11358138309010576], [0.08881343108031059, 0.042042644814618176, 0.03128231555644063, 0.040378219207688686, 0.051080356427137895, 0.016441415139143507, 0.06989817630739943, 0.03687185393045506, 0.042179491100532394, 0.03362177953784985, 0.10784263377107921, 0.010835828180725296, 0.052761072893777204, 0.040645373219083396, 0.06754729761591843, 0.06400625536879224, 0.10104926483285043, 0.1485594331977829, 8.211539320407375, 61.25239549144622, 28.697621283992646, 26.742378588645693, 25.983339163564867, 31.327482231201667, 75.77477885830787, 57.60088066900931, 66.68137550354004, 59.84793986043623, 67.82878645004766, 58.69487677851031, 59.34783766346594, 19.94391283681316, 0.0948531533621492, 0.05700732205784129, 0.17131582984039861, 27.95997250464655, 70.07789704107469, 66.373077207996, 66.45778471423735, 65.75191105565717, 62.97972886793075, 60.1608390961924, 57.44708453455279, 55.65289828085131, 55.77441723115983, 54.02906840847385, 50.20114890990719, 51.203004621690326, 47.57943276436099, 46.79127954667615, 44.272623677407545, 46.19939388767366, 46.11354497171218, 49.15545286670808, 51.072915292555294, 58.728726833097404, 62.00321951220113, 62.878229694981734, 61.960614727389434, 57.50917957675073, 56.14205706504084, 51.773148582827666, 48.60404214551372, 48.404883800014375, 45.6715173875132, 41.20675794539913, 40.054808816602154, 40.17126398701822, 42.59966219625166, 46.591619137794744, 46.75483680540516, 46.16142534440564, 46.60466494098787, 50.202529584207845, 43.92006535683909, 40.52471660798596, 42.67230841421312, 41.63440612054641, 41.767574510266705, 43.49680239154447, 45.03207299017137, 52.20137726876044, 53.45145233215825, 53.980525155221265, 55.913775121012044, 56.685285722055745, 58.598814010620124, 50.39931097338277, 17.7141159965146, 44.488828643675774, 63.10183225139495, 58.34457774316111, 61.7791933398093, 52.76157017677061, 51.27751788785381, 47.19247133501115, 43.407497867461174, 40.73941538410802, 38.43445416419737, 39.03840111147973, 43.646323142513154, 41.49145533961635, 39.48226436491936, 41.456863957066695, 46.62597910050423, 51.426109037091656, 44.05263362392303, 44.20203670378655, 45.903505971354825, 40.586760659371656, 40.514361550731046, 42.31617289204752, 41.080155603347286, 40.124803512327134, 40.9444925861974, 43.47304459541075, 41.301228230999364, 44.00574561088316, 44.37805306526923, 48.24063847141881, 54.22705788766184, 56.67698206440095, 55.21534219864876, 57.06644204355056, 53.19187379652455, 56.78168973615093, 55.65200790282219, 54.37997541119976, 52.68517025055424, 49.58002590364026, 47.30312924231253, 46.51482305219097, 46.53946730398363, 50.76903750819545, 55.70009616113479, 60.136081095664736, 60.27368568604993, 60.75228937210576, 54.86418416423183, 57.13083559466947, 52.98448631840368, 54.095532971043745, 46.59175642075078, 40.635480419282, 1.135531925866681, 0.11959320444974209, 0.22042724454114515, 0.17638063629067716, 0.9734628385593815, 19.700372872814057, 51.18818590717932, 58.59272649211269, 60.47377755565029, 57.74104264474685, 57.79708939213907, 60.524446733536266, 50.90648520377375, 24.128826856613163, 31.97744054179038, 26.923631314308416, 40.38311512239518, 31.99818203526159, 0.16092957748520761, 0.1165577419282448, 0.02175875289756204, 0.08656795076545208, 0.06183401688993458, 0.04734508790856889, 0.06294557216366933, 0.0804687417562931, 0.013329525771100196, 0.09221350548848992, 0.04331385281177298, 0.03446015551866543, 0.08732788700370059, 0.03280608742047222, 0.054159528095155, 0.04833460920640538, 0.018189315601522406, 0.029865292298998085, 0.09962287806575337, 0.010567991393468073, 0.02240920942577143, 0.07619394815617031, 0.043092223575278636, 0.059521756690716555, 0.042389414513543736, 0.06373544711799872, 0.011741098001479142, 0.030092544620856646, 0.06959567882961805, 0.011985762544246692, 0.10399809813187008, 0.06186856362488001, 9.963318378694597, 73.87543386028659, 27.897265572701734, 41.64989556035688, 34.768563855078916, 39.80353786099342, 85.44335073040378, 61.506941626148844, 76.6569277548021, 65.2300710831919, 76.0525611139113, 63.58249518179125, 64.83868914265787, 21.200518646547874, 0.2636805993895377, 0.09291313528533905, 0.8760861379484978, 31.15988523729386, 73.53977311042048, 67.30103938810288, 68.60572953378, 69.18574610064107, 64.45716411836686, 61.567769742781124, 62.36625056112967, 59.049619859264745, 59.54665868513046, 55.66118624902541, 54.72262190234277, 54.30237916208083, 50.402758736764234, 47.33326088997626, 47.312354656957815, 48.53396115764495, 48.08879959967829, 51.69718403970042, 54.278880242378484, 60.235258225471746, 64.73577791644682, 66.14146124932074, 64.38740868722239, 60.55788493925526, 59.88810493100075, 54.310023861546675, 49.3294374404415, 49.331531986113525, 47.266804172146706, 42.79378421844975, 44.29862506927983, 43.03468442732289, 43.224401627817464, 49.088301889358036, 47.63879783691899, 49.53774667555287, 51.92439517667217, 54.25969985223586, 46.750659481171645, 43.59774851029919, 44.28934081908196, 42.81993073801841, 43.39915498610466, 45.481258899934836, 47.688368751156716, 53.98747559516661, 55.68301816140452, 56.38266309615105, 57.08324939973893, 61.059650221178615, 60.97968878284578, 54.78777639327511, 32.820075481168686, 58.822326352519376, 64.58872041394635, 61.34653237558181, 59.385496339490345, 57.56946640629923, 53.579639311759706, 50.81248952496437, 45.57177935877154, 44.59337942061886, 40.488226798272905, 43.522093834415564, 44.75591067344912, 42.988051368344216, 42.64810739024993, 44.705990668266054, 49.16667476777108, 54.378053449815326, 46.58344491835564, 45.909154184402965, 46.670721577059844, 44.843461898065385, 42.77207389954598, 41.81963612956386, 42.89061577089372, 40.86899088275048, 44.414731148750555, 44.88786705078618, 43.28899914218534, 46.53734530172041, 47.94784530516594, 50.73457164149131, 57.58711314970448, 59.5954215911127, 58.156802115901826, 60.14971917675388, 57.60006089364329, 60.25623506115329, 55.27458567773142, 56.93116341867755, 54.86584724918489, 52.019179251886186, 49.501774618702555, 47.88123953726984, 48.43420351705244, 53.448534088750044, 58.756250104596546, 62.624460189573234, 62.239193224137836, 62.03832080287319, 56.7237171050041, 56.4277115175801, 55.77085179667319, 56.117334365844734, 51.98578419223909, 46.45176310693064, 1.6558304068542298, 0.06502761145032222, 0.9548143585843425, 1.0734030532260095, 1.6170648869968232, 19.551354185227428, 58.187180872886415, 63.281586631651855, 66.69860255333685, 63.701456746747425, 64.47782324206445, 67.19031087813839, 60.1890762390629, 25.654968138664003, 42.98829063292473, 26.42719457226415, 47.66045716501052, 39.084383057009795, 0.3162034342606222, 0.04715628170919034, 0.08264695955139977, 0.06708088030497875, 0.027807080262010137, 0.02707432865375473, 0.053739731064847404, 0.05982492449543169, 0.09076389093552867, 0.0882338319394377, 0.008342347010189008, 0.02135311125687534, 0.020119114065422647, 0.04479774596890615, 0.1618804764603415, 0.14752170581731106, 0.16470105897995735, 0.1592395415589694, 0.21410806104540828, 0.13051475308114482, 0.19930871323712412, 0.24329424895826848, 0.1428113835713556, 0.08275798101338648, 0.13273283809183106, 0.16109857648130388, 0.11992016311494574, 0.19760395310098128, 0.18584934513895743, 0.2338800702484385, 0.3021353326978222, 0.40048570041694953, 20.66855895903803, 86.95540874235093, 46.1028172892909, 43.636838851436494, 41.89193325657999, 44.33116505222936, 94.32718184686478, 68.51592294631466, 83.89039024229973, 71.79717386922529, 83.11153304192328, 69.17535181968444, 71.1356661396642, 25.55587926218587, 0.6924639329794915, 0.5273709434174723, 1.868667160311053, 34.185519218444824, 78.94159070907101, 72.00311399275257, 76.01785598262664, 72.50423600596767, 69.7153994344896, 65.45831772588915, 63.60170302852508, 63.02330640054519, 65.25491537586336, 61.75316841371598, 57.86739003273749, 58.37564683729603, 52.18024746064217, 49.55808024252615, 49.527928983011556, 53.09946275526478, 50.88970530417658, 53.93143277014456, 56.37326117484801, 62.75337280765657, 67.89169342287126, 69.9346834613431, 68.46384171516665, 61.10430248322026, 61.08756572969499, 56.16232787409137, 51.41498911765314, 52.475456806921194, 49.242945255771765, 45.15036775219826, 46.57870277281731, 45.81768451198455, 47.529179357713275, 52.53196639399375, 49.805640635951875, 51.66296135994696, 52.159113730153734, 56.62368097612935, 48.776830396344586, 45.71541263211159, 46.1090224789035, 46.12832054015129, 44.96938959244759, 47.934199379336455, 49.68352548537716, 58.36543298536732, 59.24147082913307, 60.47491896537043, 59.26103168918241, 63.461599888340125, 60.9010805622224, 55.95897651487782, 23.820828622387303, 48.60729771275675, 69.05594702689879, 62.83591124319262, 65.01783555553806, 57.9041700978433, 55.176436208909564, 53.17123036230765, 48.794959591281035, 47.33996029823057, 41.63944636621783, 45.185782832484094, 48.29849343146048, 45.7179464832429, 43.23009690930767, 46.870699697925204, 51.4838816273597, 59.46284155691824, 47.5395461820787, 48.36972759615991, 50.66385130728445, 44.78204934827743, 43.967424054299634, 47.527755537340724, 46.87445732855028, 44.12214194574664, 44.019873988243845, 46.25538964425364, 44.04090181473763, 46.79135014933925, 49.93871488878804, 53.244884629403394, 60.77465080445813, 62.68326436319659, 59.00090402172458, 62.84661931376304, 58.91586703638877, 61.919892680260446, 59.081347911588615, 58.852689420023275, 56.64837229636408, 55.205979501047445, 50.3201340090844, 52.51886175524805, 51.96988290356052, 56.420557114385794, 60.27059878072431, 64.62657913084954, 63.70282173156739, 61.77516114327216, 56.50841036150533, 60.70331073576405, 59.2694059495003, 56.796477071700565, 55.37457081579394, 50.695226346292806, 2.2713592552369644, 0.5133856099940116, 0.7782446977592284, 0.8260048252920952, 1.5873787960698529, 25.033754917883105, 62.58033352513468, 67.94274699303412, 69.70487963768744, 70.05433144107943, 66.08157450152983, 71.29760511459844, 62.76543801830661, 33.51710027264011, 47.84319646896855, 44.46214083702334, 58.43364692503407, 58.16778867475448, 1.181167477080899, 0.25630786113681336, 0.24141862057149413, 0.1601949144875811, 0.24283634288416756, 0.18150905868218792, 0.19827333008570058, 0.21080446008953357, 0.1967653472937884, 0.17772587136395518, 0.1806076030216871, 0.06857029312560636, 0.29508318691965074, 0.11683642939333955], [0.07762241868242141, 0.061447628954004865, 0.04691101866023195, 0.023834000814766176, 0.020395371116577618, 0.0354132148617458, 0.10698456933060962, 0.05761366149771118, 0.030120673454216415, 0.05677182662991747, 0.04203528654010546, 0.027708185971864772, 0.06310165108692262, 0.05419700894685042, 0.027882737190192266, 0.07990819522209706, 0.13121403813842805, 0.02329775841996795, 0.9648011420522967, 37.876175372831284, 53.9229682953127, 25.283447119497485, 25.5420038777013, 24.119962300023726, 63.39808494813981, 67.40119318808279, 65.07963641997307, 62.265582930657175, 67.36262059980824, 58.83263434133222, 57.597797686053866, 18.296309478821293, 0.23125079520527395, 0.17912364474708037, 5.1153977936314, 52.83914681403868, 66.43166957363006, 67.18567463659471, 63.342453971985854, 65.33468461805775, 63.846364790393466, 59.76197719573975, 57.12286141610915, 55.72709775740101, 54.56299320344002, 51.84930532209335, 53.382904991026855, 49.18392142941875, 46.341328774729085, 48.25527283453172, 46.680366685313565, 46.139338477965325, 45.21386700291788, 44.98062326062111, 45.30097499970467, 50.015491362540956, 50.23085301922214, 48.9967929932379, 53.643468041573804, 53.301986494371974, 50.2809299192121, 47.683575614806145, 47.40147482964301, 46.46114149401265, 46.15171747822916, 42.228449083143666, 41.46576381498768, 41.475244183694166, 44.39707263823479, 46.474807031693004, 47.57536526649229, 45.810086880960775, 45.65229777366885, 45.28374794990786, 43.307120492381436, 42.24284810404624, 43.78205283995598, 43.26946181635703, 40.22682828287925, 42.03635492632466, 47.930955579203946, 53.35176921659901, 52.711716851880475, 55.77415443235829, 57.66286980721259, 57.4742587151066, 61.27370180622224, 42.129981902337846, 24.963797484674764, 51.65216307486258, 60.43861350705547, 59.99041995694561, 58.86173440564064, 53.687857504813906, 51.192433834075935, 50.44323367457236, 45.734208629977324, 41.006595473135675, 38.62103739092427, 39.2846239766767, 41.57923013933244, 38.96622165556877, 38.88559733667682, 41.45512242471018, 42.48663909973637, 47.69071825088994, 42.069953949220725, 44.33416174304101, 45.1878930676368, 41.84137782742901, 41.143337142082956, 40.368049298563314, 41.04492095208938, 39.023252917874245, 43.54136836144232, 40.79123773882466, 41.94657187308035, 42.27558420550439, 41.3706777172704, 44.37173412692162, 46.94089835689914, 49.76010191825129, 53.553379043456054, 54.03816046253328, 54.27129437846523, 56.396042300808816, 52.71594516692623, 52.843983096461145, 49.385162553479596, 45.56053784585769, 45.798868902267955, 43.50413330139653, 44.356452572730284, 54.048499830307506, 57.6984025586036, 61.82751694033223, 59.77777650279384, 55.49290872389271, 55.96613876281246, 56.94654695449337, 52.69861221313477, 55.450990353861165, 47.88031385790917, 47.51369776264314, 4.106193031034162, 0.5491587904191787, 0.4105319323078279, 1.2548917339694117, 2.2581734724583167, 27.08909453884248, 57.705356920919115, 57.81210030278852, 56.82858167156097, 63.025828484565984, 63.808588443263886, 50.116794416981364, 46.650003617809666, 27.96281033946622, 31.693955159956413, 24.644506746722808, 46.06522921592959, 10.84268141177393, 0.14755853932471047, 0.08878474874842553, 0.06094816261001172, 0.025155531212447152, 0.02601594371240466, 0.00961630717821179, 0.018213851482517297, 0.02873542752387303, 0.03649515317632787, 0.02687414413348081, 0.010376656146329499, 0.030700171088439324, 0.05674386059024161, 0.06590553288978916, 0.05988525008902915, 0.01120108166604393, 0.043448626829852025, 0.0020026059041077632, 0.032503988308411454, 0.02061568459706201, 0.0006944710924384005, 0.04193001839843008, 0.07448113643594327, 0.040897902612003594, 0.027799367671832446, 0.01271315536747176, 0.015457848259698481, 0.026682897944063432, 0.10545927295160872, 0.03143189039321677, 0.08327548106711719, 0.13206641820649948, 1.0006971416934844, 48.588595851775146, 54.71083125760479, 23.330138152645482, 42.15290031125469, 27.329065145984774, 74.95899646512925, 71.33074129781416, 71.42452516863423, 68.83954201975178, 73.2657406407018, 64.12594741390598, 65.63320836713238, 20.848183901079242, 0.11295093869369839, 0.18567976391603871, 6.952731590117178, 59.936334394639545, 69.38333157570132, 70.21044961867794, 65.03426636418989, 67.4496893728933, 64.48445204765567, 62.87602532294489, 59.12358007123394, 61.26387234657042, 56.53678870970204, 55.43288469314576, 55.55727481842042, 53.38271671725858, 48.295363380062966, 49.33781562312957, 48.48802628055696, 49.34655858624367, 46.984836747569425, 46.941086630667414, 48.87533287848196, 50.74456584069037, 53.14284809174077, 53.24892467068088, 57.68322690840691, 55.71184365980087, 51.54121098979827, 49.40928905240951, 47.89658777175411, 47.79530432916457, 48.290052490849654, 43.655556401898785, 43.47465668955157, 44.71869130288401, 46.81369196984076, 48.241434712563795, 49.45591426664784, 48.186380324825166, 48.66223835176038, 46.98284418352189, 44.66393501527848, 45.69858566407235, 46.19669137462493, 45.63421564717447, 45.43217435959847, 44.27211769165532, 51.91477360263948, 55.362289874784416, 55.60099355636105, 55.61507094290949, 61.74848902610041, 58.89348206981536, 66.52511612061532, 46.66828186281266, 37.711082812278505, 62.970060225455995, 60.563282120612364, 62.56027060170328, 58.722184319649976, 57.468226109781575, 54.426796743946696, 54.964655676195704, 46.06808470141503, 44.44529425713324, 42.667464287050315, 42.92949430404171, 42.89155713973507, 42.9763509381202, 41.64920130083638, 43.57761890657487, 43.78342566951629, 50.83545892469345, 44.356201541039255, 46.97061815569478, 47.79791270532916, 44.22349991336946, 44.92117974065965, 42.101105413129254, 40.75390461952456, 43.910231974817094, 45.278876366153845, 43.51285665265976, 44.87913193241243, 44.96388258472566, 44.52948401051183, 47.88072178440709, 50.82651984307074, 54.3151347098812, 56.242948270613155, 59.61306833451795, 56.33650072159306, 59.60576095888692, 56.940314308289565, 55.77094201118716, 52.34338668084914, 48.66894168238486, 48.54095866603237, 45.77627605007541, 48.375395421058904, 56.90122004478209, 58.349845486302534, 63.94191372779108, 61.10724033847932, 57.02048363224153, 53.58857839338241, 58.66738880834272, 54.05446183296942, 57.858839265761844, 52.0592031171245, 55.17334538121378, 5.435665692052534, 0.8661330623492118, 3.767743475975529, 3.4705138639096296, 2.658355985918353, 30.94951871902712, 61.675164238099136, 64.68278669541883, 62.47021690491707, 69.99847688982564, 66.89375615889027, 58.42786927377024, 50.32264432599468, 33.81478855686803, 41.850081566841375, 25.201155793282297, 57.090823496541674, 9.51887853683964, 0.20827785614998112, 0.050479099980645606, 0.09205752232622716, 0.03232332562366801, 0.05902324795662876, 0.04398259777395476, 0.06666066575675242, 0.03309735021884403, 0.06130253190114614, 0.028444994015679247, 0.07758737015988558, 0.022969868957936283, 0.07965389233563216, 0.05762701441023139, 0.12644640485485717, 0.17353860330918144, 0.19741751794372836, 0.09621099824266088, 0.13340805266653338, 0.22119160110671676, 0.1696814118974632, 0.1374502236684484, 0.20163729877000858, 0.13696415620225091, 0.13324213334389273, 0.09181136295439736, 0.14543842163778123, 0.09720063828412565, 0.28524174565269106, 0.19794855477108111, 0.23487112755256317, 0.3515514971748475, 2.462416925737935, 64.79574703401136, 73.24782325375465, 40.80102405240459, 44.6245583411186, 37.872821746333955, 81.89954419289866, 78.27407390840592, 78.15030743998867, 76.06952144253638, 80.64136551272485, 70.78109172082716, 72.59144598437895, 23.962749781147128, 0.32701177041857477, 0.7225789718570248, 7.930783417917068, 63.754746067908506, 73.48741731336041, 75.11088632768201, 69.62182737165882, 73.79751205444336, 69.55971271761003, 65.60068407366353, 62.573100674536924, 65.06351940093502, 60.34964238443683, 59.24603254564347, 58.292331772465865, 54.83278559100244, 51.537982879146455, 50.915781221082135, 53.26426506042481, 51.91775460397044, 52.53399033700266, 50.099908613389545, 52.50732214220109, 54.42959339387956, 55.1259631495322, 53.217886955507346, 59.9240142299283, 57.22365456242716, 54.413605813057195, 50.03395395894205, 50.69846230168497, 50.19000153387747, 51.160309622364665, 47.677225297497166, 47.344835804354766, 46.504369935681744, 48.70617282006049, 51.84834826377131, 51.200706112769346, 51.87230610078382, 49.25599105896489, 50.80937124067738, 49.27319457454067, 47.495756841474964, 49.805268010785504, 48.12356356651553, 46.794291926968484, 47.28885573725547, 53.63172838764807, 58.81192030445222, 55.967307629123816, 59.99333427798364, 62.37365207364483, 62.954053032782774, 68.08272069500339, 48.03961307771745, 31.756460089837354, 55.949554981723914, 66.83408121908865, 65.2370999705407, 61.804759348592455, 59.39605928236439, 58.19098949432374, 56.519377308507124, 49.8363253378099, 45.195388717036096, 43.63019043399442, 43.80790518176171, 46.45114729481359, 44.18367216663976, 42.56532184539303, 47.050120676717455, 46.86286672469109, 53.91275444338399, 45.97464207679995, 46.72988268636888, 49.66126995701944, 46.23792332987632, 47.11356109188449, 45.7509728400938, 44.88240318913614, 45.10875532704015, 48.402259734369096, 45.07475622238652, 45.481549155327585, 46.47518750159971, 45.36076761061146, 50.01723681726764, 53.11569352303782, 55.52181266969251, 57.80169425472137, 61.43219694014519, 59.251272832193685, 63.098568839411584, 60.15963885091967, 57.84180833447365, 53.35209085095314, 50.65495537173364, 50.673029653487674, 47.088952141423384, 47.25175011542536, 60.58819309357674, 62.45628464606501, 67.52014298592844, 61.6159874393094, 56.55881674058976, 53.31895074536724, 60.47052983314761, 54.012884709142874, 60.40065673089797, 52.87965705317836, 58.37179506978681, 6.5169528318989665, 1.1758114806106015, 6.418539583683015, 3.71633198953444, 5.072080118040885, 34.44984382198703, 70.43348343141618, 65.45256360884636, 68.09788457808956, 73.83265649118732, 72.41018541397588, 61.92808258918024, 59.28121228371898, 42.16560094587265, 48.44903792104414, 39.744843513734885, 69.27930247399115, 23.943286980352095, 0.38914048984166116, 0.2437290498205731, 0.11660488697910502, 0.1541643929217131, 0.1211160340256268, 0.1257519078471007, 0.14314663896877922, 0.19274625086015273, 0.19885875915567722, 0.11797845198382294, 0.23213688314201372, 0.17544945641871423, 0.17446460442677622, 0.10423328712462418], [0.05682171810598624, 0.02678102614628452, 0.030382614237286394, 0.0445545130529471, 0.06551734081679775, 0.09344203472738305, 0.11946005070762289, 0.04997373092919589, 0.05670501610204097, 0.03711496427234623, 0.04620053722793537, 0.04408265651774503, 0.04123442971538152, 0.07136154979948076, 0.0434109850996925, 0.08030786329219419, 0.14247537740776617, 0.05261895592294393, 0.3875233088770221, 12.001584902886423, 58.917314390982355, 35.16586072983281, 29.025745199572658, 25.77316680262166, 65.69357364408432, 65.2841684126085, 66.20185006049373, 64.63634191020843, 66.9172276220014, 59.77176743168985, 56.355033920657256, 14.865995741659596, 0.08181595333641575, 0.45944186588448865, 21.45810461813404, 70.23206972306775, 68.49242010424214, 66.61558166626962, 64.29116941267445, 62.43960672809232, 61.22005554937548, 59.16925607189056, 56.678150930712306, 56.0654688650562, 52.09415928010018, 52.32827771094538, 51.7413499278407, 50.734732458668375, 48.462730915315696, 46.94435396502095, 44.54734256190639, 45.402054479045255, 47.34252945069344, 45.371479603552054, 44.3994652840399, 45.504495020835634, 46.5374590504554, 48.10668560766405, 47.7066352290492, 49.79051205419725, 47.2129657191615, 46.75822965560421, 46.85005234133813, 45.64249577060823, 45.17989143248528, 40.097750925248675, 41.96221428532755, 42.203039969167406, 45.461968683427386, 47.75703376339328, 44.027914847097094, 42.83267059633809, 41.29415619757868, 43.138717451403224, 43.07306874182917, 42.45083570480347, 42.25013194545623, 42.30960684437906, 42.016492043772054, 44.3509102636768, 49.41012843962639, 54.59636472886609, 56.965668509083415, 59.75903934048068, 61.59090388205744, 58.17968130111695, 61.74951668708556, 46.0642643128672, 34.510738618912235, 55.216103138462195, 62.29948397605651, 62.18944972561252, 58.410995237288944, 58.360384894955544, 51.96414055362825, 52.77634574520973, 45.15362724181145, 43.12447924767771, 41.13657105353571, 43.449412315122544, 40.80114172350976, 40.80908844547887, 40.83853760073262, 40.17082468155892, 42.303770357562655, 42.09247619875016, 41.18574580838604, 44.51472805392358, 46.88647939312843, 43.391824076252604, 41.35186995229414, 41.227860296926195, 40.69039360169442, 40.746004965997514, 38.94285217408211, 40.163984067978404, 41.74610345594345, 40.276658073548354, 40.44116620094546, 42.57631624898603, 42.661172805293916, 42.265495869421194, 43.454185839622255, 47.515168651457756, 47.00207948684693, 45.738648753012384, 46.85247244373445, 43.964392062156435, 43.50184655958607, 42.98300327793245, 42.28342110110868, 44.47383734487718, 48.91438399591754, 56.233056053038574, 61.76328028402021, 60.78654735319076, 59.02024915141445, 57.41931807610297, 54.282602571672015, 60.38521828189973, 58.72276090806531, 60.01845705893732, 50.436699005865286, 50.71552461193454, 17.018603278744607, 0.6009993473848989, 1.9845209823500727, 2.649314187226757, 4.275469779968262, 27.05852750808962, 59.69445359322333, 52.035080540564756, 51.34323720009097, 60.10709085772115, 44.1817541276255, 41.23276325964159, 29.190749506796564, 27.366978776070383, 29.56651256930444, 29.545359226965136, 35.653376040920136, 0.7278272257216516, 0.10716770264890887, 0.11090247321032709, 0.05506401363339636, 0.07179216782171881, 0.11325917417003263, 0.09157616630076401, 0.030331133128774744, 0.009166299470610196, 0.09244209080333672, 0.06524208542560378, 0.05112175198812639, 0.043208351013280695, 0.006800126312525884, 0.024804944480438868, 0.04364125197753311, 0.03667427602434351, 0.0849889133185629, 0.08167668621266082, 0.0443318534281946, 0.024335039554223902, 0.06663631182163954, 0.03039476247654567, 0.011476705737051465, 0.10684855808053287, 0.048602996619358185, 0.04033119673089635, 0.026117350770941666, 0.0674940315225432, 0.06789659540499411, 0.04767019647143541, 0.05259035403029092, 0.06488718753380161, 0.2884700708091259, 15.768230115213703, 70.49941847401281, 30.49261554594963, 40.167710319642104, 33.487937450408936, 75.14118271489298, 75.81938405190745, 71.14759798972838, 70.38013135233234, 73.5327128441103, 65.11537705698322, 63.59323070895288, 18.30769611943153, 0.3289097379292211, 0.5785644318788283, 24.85630296891736, 74.02029483549057, 69.96761568130987, 68.44798749493015, 67.4878461899296, 66.3749050324963, 62.77882506770473, 62.323182936637636, 59.68913485926967, 59.56238738952145, 56.88229460870066, 56.854096689531886, 55.294601532720755, 52.00890656440489, 49.71201758230887, 49.35207736107611, 47.963013110622285, 48.739834600879306, 47.31846178731611, 48.36026683930428, 48.1858508048519, 46.40209805580878, 48.49727522942328, 50.46464981571321, 49.31623082007132, 49.86594315498106, 48.09593046865156, 48.18657252096361, 49.15579411291307, 47.130564566581484, 47.45189689820813, 43.30005238133092, 45.110936164855964, 45.416190701146284, 47.70521140867665, 49.00411213597944, 47.83856414979505, 45.60161682867235, 46.01734492086595, 45.32365022167083, 45.550633861172585, 45.282532015154445, 44.80963537769933, 43.152139802132886, 44.52518901517315, 46.62152328798848, 53.503961101655044, 57.51103485784223, 60.087271121240434, 58.9973738885695, 62.08575010299683, 59.47765634905908, 65.67499729894823, 45.16070319760231, 44.91944213067332, 62.95637507592479, 61.7336703115894, 65.38898591072329, 61.139964672826956, 60.67553643257388, 56.38446346406014, 53.593991264220215, 49.92728117973574, 47.243395466958326, 43.71892621440273, 46.173780810448434, 42.28340541162799, 43.67058300202893, 42.12633802044777, 42.54895771703413, 45.22977613633679, 44.62528790197065, 45.344807486380304, 47.512030755319905, 47.32090934630364, 47.070446398950395, 43.699553628121656, 42.58054848640196, 42.076123837501775, 43.95037351116058, 41.41077218517181, 43.498504700199256, 42.93244000404112, 42.341425111216886, 43.03575523437993, 43.87867258441064, 44.376703769929954, 46.32532942679621, 45.69856605222149, 49.37136365521339, 50.404700309999534, 50.44359845499839, 48.482358455657966, 47.35519478397985, 45.5174074634429, 45.86216811210879, 46.1925454293528, 47.31508854896792, 50.37681225807437, 57.54712458579772, 61.46047722908759, 61.8484623970524, 60.3961460051998, 59.55221276129446, 55.40587917450936, 61.799056222361905, 60.805919939471835, 63.03317508389873, 55.7401200263731, 60.66467931193691, 20.265251051995065, 0.5898587742159443, 2.0174817620746555, 2.922995604815022, 6.274505247992854, 32.121587645622995, 64.25510321894001, 57.2332408351283, 58.99587946553385, 68.18168993919127, 49.42587283349807, 51.535233297655665, 32.45900953969648, 38.1040572351025, 32.030959321606545, 37.28083410570699, 42.73844742005871, 0.4197911773958514, 0.09541133268465919, 0.1001017596272211, 0.04826936915877366, 0.027772194533158216, 0.10092517391087548, 0.03132667013203665, 0.08578821881524018, 0.02605285191337668, 0.042204817967309106, 0.08428865532961585, 0.08208402282287998, 0.015343908002720246, 0.019828891231408043, 0.05149986234403426, 0.24359006614935017, 0.1369272154425421, 0.25965594115757173, 0.1750175207252464, 0.1645670702020007, 0.2605810689349329, 0.2625968607683336, 0.2641698231379832, 0.14936247720353066, 0.20330781477593607, 0.14815634837554348, 0.22128117210682363, 0.2287522913707841, 0.186861822261445, 0.14623938188437494, 0.17153903721801697, 0.22196608535464735, 0.17717373647516776, 0.5482328659103763, 27.610993346860333, 81.96176867331229, 54.87550020217896, 49.14571362157022, 39.0564989274548, 80.5153162248673, 81.79842548985636, 80.0841457613053, 76.65893600833031, 79.01787296418222, 72.06027861564391, 70.26592762239518, 21.507285256539625, 1.0258381861832835, 1.4506764733983626, 27.948791788470363, 79.52920882932602, 74.12058199605634, 72.99028827298072, 70.61558338903612, 70.44429348361108, 67.27762283817415, 65.34894243363412, 60.48725481956237, 64.11587476730347, 60.541348226608775, 61.95681002832229, 60.44813309946368, 54.70036637398505, 52.48911842223137, 51.15600285991546, 52.33030557632447, 52.52352545338293, 52.29455709457398, 48.68265036613711, 50.16580443228445, 49.781871072707645, 52.09831307011267, 54.061675071716316, 50.590930523410925, 53.850325999721406, 50.50559543794202, 51.80275463288831, 52.069581708600445, 50.18945240205335, 50.00106096267701, 44.85368751710461, 47.46265988196097, 47.739426243689756, 51.964234690512384, 52.713003389297, 48.874065952916304, 47.09038772890645, 46.80438418542185, 47.75813987178188, 47.87527361223775, 48.386217240364324, 48.08870546279415, 46.04874349409535, 45.48139618289086, 49.21552004352693, 54.31426786607312, 58.44204079720282, 61.72846924874091, 62.44166989480296, 65.31941090860676, 62.52767570557133, 69.58187410908361, 49.33767441780337, 35.80249671013125, 60.38732851705244, 68.32448774768461, 68.80026340484619, 64.23606403412359, 63.369730134164136, 56.851637363433845, 56.42586800359911, 50.54521529905258, 48.742227246684415, 44.583255783204116, 48.82786043228642, 45.62687297021189, 47.11647149055235, 45.83573525951755, 44.928432203108265, 47.895744462167066, 46.357798807082645, 46.37886585727815, 48.39777254289197, 50.605196183727635, 46.7751625276381, 45.31763722819667, 44.4782421665807, 44.230458198055146, 45.95782295350106, 43.45216189661334, 44.46891477031093, 44.86291685412007, 43.02610620375603, 45.15625130745673, 47.31652021408082, 46.68446163977347, 46.60613582980248, 46.773711250674346, 51.952326374669234, 53.144150318637976, 54.31590349443498, 52.35721303570656, 49.76284365500174, 48.620065027667636, 46.79367611485143, 48.002997752158876, 50.79705107596613, 52.59947038465931, 61.08935825286373, 64.38117604101858, 62.44068537988971, 60.43087074833532, 61.90157128918556, 57.00572375328311, 65.2969906407018, 63.88088557028002, 66.79720309472853, 59.4254574468059, 60.581983981593964, 24.798759837304395, 1.610135774939291, 6.927137144150273, 8.162525382734115, 9.662859920532474, 32.835447249873994, 70.2147642258675, 58.23966218579201, 63.98956660301455, 66.76723618661204, 61.18927278826314, 57.86571125830374, 39.03587118271859, 42.08247807718093, 45.653662758488814, 45.79713521465179, 62.296997193367254, 3.942179612575039, 0.45482826989985287, 0.33222398750724336, 0.255723136867727, 0.18821061198269168, 0.296791777495415, 0.20651517976676265, 0.26907870005215373, 0.17358875142470484, 0.30879668170405977, 0.19390017845697943, 0.11485320395759999, 0.25047324357494233, 0.06603876324070078, 0.18919659778475764], [0.061373429508098674, 0.06893141931223293, 0.09424412878410471, 0.03861658470404725, 0.05472447197403639, 0.024322232479349743, 0.01468254046724929, 0.06591114831427414, 0.10972071363921128, 0.033673444507463325, 0.062067547302332625, 0.08200679349923327, 0.08922842090889331, 0.09507793122001233, 0.013937646365394036, 0.033995120996429075, 0.03428301300793406, 0.0841566737020208, 0.04410977603026456, 2.50520434591078, 49.573620673148866, 46.54304842795096, 32.53054180452901, 29.063647062547748, 39.86016904154132, 65.47341492868239, 67.56314785249772, 65.6082699375768, 66.27425701387467, 60.653986930847175, 60.76101664573916, 20.479357550221106, 0.08623506257971449, 1.3624205704658263, 38.95368576049805, 72.27164729948967, 66.73042082017469, 65.59011720841931, 62.87324436249272, 62.727724429099794, 59.34242087025797, 57.3793726582681, 58.14775713028447, 55.973085280387636, 54.221684240525775, 52.50812230571624, 52.84761128887054, 50.71517944335938, 49.61926921721428, 46.70251238730646, 44.65616479996712, 45.695396777122255, 46.56028332248811, 46.71132203071348, 45.31798631914201, 46.84906782642488, 44.811302385022564, 44.779405670781294, 47.93979267920218, 48.555475358040106, 46.23236925371232, 45.711960946359945, 46.07943996306389, 45.03540308244767, 42.41656595660795, 42.042269860544515, 44.611947921014604, 46.74899247384841, 44.98499670336324, 47.761658237826445, 45.333307097035075, 42.84223725718837, 42.963897412823094, 42.34725767566312, 43.178772695602916, 43.698172953821, 42.80175839701007, 41.329963514881754, 43.956366892783876, 45.59707864638298, 47.98462929264192, 57.580241157162575, 58.351881196421964, 59.3454763966222, 61.8653521230144, 58.546113044984885, 61.14954310078775, 50.06543882431523, 31.964420234003377, 56.31485316061205, 59.05126725473712, 62.19058721296249, 62.30033905275407, 58.364197438763036, 56.051599364126886, 56.139087830820394, 51.487454906586684, 44.63537623805385, 44.63981636108891, 42.18228670858568, 41.36336249689902, 39.525932112047755, 39.33694839477539, 40.73493995974141, 41.57113436729678, 38.38376929683071, 39.922146412634085, 41.18884448082217, 42.51386819347259, 42.79429020420198, 40.815391694345784, 41.64415713279478, 40.53092964233891, 41.023512655688876, 39.10876451000091, 41.25953735843782, 42.11015432111679, 41.91123524019795, 39.67187958378946, 40.185364907787694, 43.24078536802723, 41.532098939341886, 40.64857721328735, 40.74627953190958, 44.018018707152336, 41.93379279105894, 41.82072262610159, 42.88820351323774, 44.37063194090321, 44.193485936810895, 42.85312183441655, 45.93368076509046, 52.560674221284934, 58.373752332502804, 62.81007851323774, 59.49977851683094, 61.05015808536161, 64.7620774084522, 64.09595304919829, 61.32888955454673, 60.72831976798273, 59.78268338787941, 58.368084507603804, 53.21647490224531, 39.21129526630525, 0.1042763872312442, 3.4998465737988873, 3.8381617876791188, 3.2519971507210887, 41.77713332637664, 61.452193183283654, 55.409538745880134, 43.70109904196955, 48.86106329579508, 52.06844422125047, 30.58454609686329, 16.85864510074739, 36.72324172912106, 34.91216574945758, 36.2817907333374, 11.131291370238028, 0.024139612439959764, 0.001187080171451183, 0.08424652815465966, 0.027757659930014805, 0.06437537185246907, 0.10107541907458537, 0.06162133939083546, 0.020061098226916887, 0.06046800934258969, 0.024986288983434923, 0.0428556862677778, 0.06475506034950096, 0.03336340872450702, 0.05825765415905945, 0.04933715782939427, 0.06911790809564053, 0.046832433360959255, 0.07478098324950665, 0.014190870983105515, 0.02614161086028382, 0.05591214574392765, 0.07161696351343586, 0.017297211959357225, 0.040778182221636664, 0.007981948128285548, 0.04610173486834092, 0.07837261028227308, 0.019361964471998717, 0.027745908141256343, 0.019459142725193695, 0.018876347082456755, 0.02570347368506895, 0.0792321302897988, 0.04332402645940742, 3.326250314712525, 58.80295376623831, 48.32937425182712, 37.55116778035318, 39.23524133620724, 47.529324485409646, 79.3901215830157, 70.11659514519476, 74.51783180236816, 75.17932384244858, 69.18062348519602, 64.991406625317, 23.385333745710312, 0.009200988889431522, 2.014305132531351, 43.03977958617672, 75.18905132047593, 70.13495968234155, 68.84647677021643, 66.61870387292677, 64.73369121551514, 62.619361108349224, 60.806382779152166, 58.61590769983108, 60.27504674849972, 58.32541696486935, 53.52479280964021, 53.912170010228316, 52.47923012702696, 49.4003656602675, 47.89773702621461, 48.89428184878442, 48.324977274863954, 48.894583871287686, 48.02406087998421, 47.080177799347915, 48.07005851499496, 48.80393397423529, 47.54810871616487, 48.99323540349161, 47.88955496203515, 48.966057300567634, 48.2731431530368, 48.15024745079779, 46.011708474928334, 44.3438264631456, 46.19156483680972, 46.25935908286802, 47.378627023389264, 48.586960223413286, 48.72283504855249, 50.18574183987033, 45.5412240951292, 44.21387049459642, 45.71614219296364, 48.289766157827074, 45.484024170906316, 45.74871747724472, 42.79549437184488, 46.28952603186331, 48.04340993204425, 51.51239333614227, 59.45004678541615, 61.45868470591884, 62.31224736859722, 63.80235971943025, 62.191932585931596, 63.6160667480961, 50.03344797318982, 42.41190618084323, 60.55784571555353, 60.5343742524424, 64.74876880645752, 61.69466234022572, 61.32535549902148, 59.5003511828761, 57.69060488670104, 52.020716820993734, 48.04288825681133, 46.48229091398178, 44.94406284824495, 42.74613134322628, 43.22601372195829, 43.231618788934526, 44.65727875309606, 43.37145913031794, 42.081258220057336, 42.35719696167977, 44.08094529182681, 44.855248620433194, 44.6220794031697, 43.49561391338226, 43.25312514458933, 43.461250028302594, 41.86744982196439, 43.013656600829094, 41.74835097405219, 44.69232905295588, 43.908321780543176, 41.63500624318277, 43.938002355637096, 47.89054732168875, 43.85550706617294, 42.34869326314619, 44.651987475733605, 45.94902507720455, 43.94763961915047, 45.332306892641135, 45.96853494644166, 45.895057186003655, 45.365199888906176, 44.355507281518754, 47.927813760695926, 54.38760049881474, 60.83655365051762, 63.20886196628694, 59.48104919925813, 59.238740859493134, 64.5721209433771, 65.72966729440998, 62.548193623942716, 64.0826601366843, 63.4630197863425, 65.66390483610093, 61.69885143156975, 46.59449815750123, 0.17477581998513592, 1.9763152613755197, 5.790274431628566, 5.517459857848383, 45.467142289684666, 68.0689061072565, 58.11532697369976, 49.152911170836425, 51.03053016047324, 62.96111722146312, 36.092791326584354, 21.759352453293342, 47.31914035735592, 35.029746640113096, 47.475552712717366, 11.82466737685665, 0.04616711664223864, 0.01884084848326541, 0.04722497298292095, 0.03466585395677436, 0.018379240289270397, 0.08822760364461331, 0.08907098217957443, 0.05746350060367296, 0.03660984802991152, 0.08884969768264601, 0.04567545673419391, 0.023278535358727943, 0.05762808693332538, 0.003978086310634089, 0.024465864389053276, 0.21032524144937917, 0.1619172027154315, 0.19035412599482845, 0.08737546872467765, 0.14914837095045275, 0.27235170345633264, 0.1638623459204551, 0.13557102531194687, 0.2180136079269071, 0.14966218612126767, 0.15628683951593217, 0.20299269216916255, 0.1817724090670386, 0.23696152102803034, 0.09828873594561893, 0.11823849286884071, 0.2273515762100297, 0.21021494011004127, 0.3855801115353262, 8.015741955849434, 76.2923748262467, 62.75969959074452, 50.05043968077629, 45.808996462052875, 52.927325617882516, 77.34041644680885, 83.07445879905455, 81.1770514518984, 78.91384386247205, 74.60437497785016, 72.42340380145659, 27.490584427310576, 0.2689277194440365, 3.5769390434988084, 46.85576331230902, 77.94763072844475, 74.67536987796908, 72.94679703251009, 72.21513379004695, 70.25353293265067, 67.26250602353004, 65.88859388905188, 62.22974031202255, 64.28772557166316, 60.2708694242662, 59.85367828799833, 57.1611084476594, 57.4849550185665, 53.86354438720211, 50.736768168787805, 53.22548850890129, 50.70097654096542, 52.83060389180338, 52.97075017806023, 50.207161903381355, 52.510330600123254, 50.930239077537294, 49.76182383875693, 52.48949889213809, 51.90197098639704, 50.41532993316651, 49.72995458110687, 50.75338725120791, 48.69736317665347, 47.86749162981587, 48.38374614715577, 50.78369540552939, 50.46963514820222, 50.912976726408935, 51.20374594965289, 51.803637166177076, 46.863906152786754, 46.38061523437501, 47.94998299690985, 49.816034916908514, 48.52041721343995, 48.520601564838046, 45.61018720749886, 48.994902410814845, 49.391422656274614, 53.31342020342427, 62.26181353292158, 63.95906625255462, 64.04576632284349, 66.97144262252316, 63.828682745656664, 65.35644592777376, 51.66267502692438, 34.131037496751354, 59.65697926859702, 62.914523386186175, 67.8837388561618, 66.40062009134601, 62.81547569459485, 61.89297737613801, 59.883225502506384, 54.10142044867239, 49.64462734037831, 47.741120707604196, 47.35474763378021, 46.13149765999087, 45.44275691432338, 44.05666189809, 48.05918178250713, 46.543534801852324, 43.34603432686099, 43.357307218736224, 44.79982552989837, 47.66311260961717, 45.1128149801685, 45.1224640107924, 45.58868085184405, 45.96956652979697, 45.31393058838383, 44.87541352548907, 44.11460315027545, 47.275594203702866, 45.525620906583725, 44.24448459379135, 47.91547006176364, 51.12591043595345, 44.80434802270705, 44.73482793377292, 46.45639542610415, 49.835803662576986, 46.24304986769154, 46.04791979635916, 47.03568243211316, 49.28249451421922, 47.13221196205386, 47.28670627840104, 50.93076467514039, 56.280873667809274, 62.71639270167198, 67.52478707221248, 61.16354203993275, 60.35042685847129, 65.14783074778896, 66.73922261884137, 67.46842261283629, 69.30663354935186, 67.28713850821218, 69.319930384236, 62.361853584166504, 53.225288468022505, 0.28096817013236786, 7.449198730530278, 12.082756392417416, 5.4809626936912546, 49.97750712979225, 71.33191800886586, 64.31420941506663, 56.726133285030244, 59.03869213596467, 66.12421851004324, 40.1309577111275, 26.231711487616263, 54.45741868788197, 48.240383517357614, 55.19101173646989, 28.882562998802435, 0.12137350851609824, 0.10893879067753592, 0.12348902201460255, 0.18592301215375626, 0.10853362209614247, 0.2456621348016685, 0.22575872619786572, 0.15190411178815752, 0.18006924239377822, 0.2228169485686287, 0.16022532817817506, 0.1754422398704675, 0.1430738299724556, 0.12466400170758848, 0.13366512113040493], [0.021517768449660753, 0.03331205402050288, 0.02031856697172888, 0.09621940222719023, 0.07919637696637262, 0.05230067320348275, 0.04572560484971731, 0.09711690487400179, 0.0402722692477607, 0.07012480809803932, 0.07830705613859239, 0.07960397404648605, 0.04763628941990676, 0.035698195739138516, 0.07250010201166715, 0.023938759507971908, 0.025124824493222182, 0.08803505510572465, 0.03387288400723088, 0.17826291432063426, 15.898598913223514, 61.64005118031656, 39.805102886692175, 33.8861874611147, 31.071406372131843, 44.818699975167554, 72.23047810216104, 65.75313875752111, 63.10602918747933, 58.12763929367066, 60.631009686377745, 25.489836354409498, 0.20875663045913945, 2.9557925030108425, 46.86650276184083, 73.61167015567904, 69.12197620637956, 64.54622937786964, 62.35328320533999, 61.40899612057594, 60.36603396938693, 57.124359761514974, 55.736503601074226, 55.81335459986041, 53.20024805684244, 51.27409365869338, 50.9524828387845, 50.254618660096206, 47.518075127755445, 48.20842012282341, 44.190057785280295, 46.00146324403825, 46.66272778664866, 48.384522776449884, 46.635028008491766, 45.21518491929577, 43.30953667240758, 46.09773389754757, 44.970699664085146, 47.825612483486054, 43.39547188051286, 46.65624018638365, 44.10569152524395, 43.52337252709174, 44.097030931903475, 42.32023646754604, 42.740847910604174, 43.62894312027962, 44.757228589827015, 45.67107023731355, 41.903637609174176, 38.911877216831336, 42.45857846352362, 43.93926928120275, 44.585040461632516, 43.37986476959721, 42.72969661220428, 43.731258146224484, 43.245755011035556, 44.56943727308705, 46.61348635150541, 55.46957062136743, 61.01011460827243, 61.28131904909688, 63.56156541455177, 60.49830413633778, 59.78331881184732, 52.10016835120417, 30.026904690650206, 52.778965888484834, 61.445132916973485, 61.95972827173049, 62.08633061378234, 59.56912602147749, 57.55477320763373, 58.61395435948526, 55.528700351715095, 45.63576890576271, 43.0287028128101, 44.000619073067945, 41.38152699316702, 41.27772146655668, 40.74854666186918, 41.12123850853213, 41.997574452430975, 39.407147053749334, 38.47700403582665, 38.84090192856328, 41.13370772330992, 41.18125077216856, 43.19529764113888, 43.58667958167292, 40.40438613583965, 40.69559466454291, 41.35380368078909, 40.69475135495586, 41.608204687795336, 40.5499021468624, 40.80575050846223, 41.54180680551837, 39.841886874168154, 41.91990367827877, 39.781054835165705, 40.67071114816974, 44.19143845958095, 40.54077086910125, 43.15898433808358, 43.17225763874669, 44.124793467983125, 44.595387674147084, 44.65347797639909, 45.754232329706994, 54.8569905373358, 60.19891354345507, 61.030573691091234, 59.26259279251099, 61.864395064692346, 60.562121099041356, 63.409275470241425, 59.96049619490101, 60.1084440754306, 57.88286770543745, 60.78175813921037, 54.874872622951386, 59.322032390102265, 4.99414703538341, 1.9726274979691354, 1.783178366961018, 9.28728219001524, 54.077831314456084, 53.9680520180733, 44.440010824511134, 46.554093822356194, 66.79080178660732, 67.45493750418386, 49.30202791767736, 20.45565074489963, 33.87599322103685, 34.80103715773552, 39.4194789855711, 2.299145325537651, 0.1719863099917289, 0.0333552269054757, 0.0630453972506427, 0.05198482664362077, 0.03279037495714522, 0.06030544165461775, 0.028429417532958814, 0.05452122501728516, 0.0527665848963924, 0.037677387721956744, 0.06457430190376698, 0.057253060081312736, 0.08420271558627006, 0.04498104782654874, 0.02761348984354446, 0.032646733471342636, 0.021370807887926217, 0.058163678153387965, 0.025972437579184774, 0.03369891310050603, 0.030782496812002316, 0.03992414740364879, 0.012339017177451284, 0.02331136605672298, 0.04230613692573482, 0.03488857103812118, 0.05086941794762689, 0.03596154612398917, 0.038773651880722855, 0.05544159538863648, 0.09351554852459701, 0.03683553370196493, 0.05231098474694356, 0.033091684998643976, 0.22631481410034243, 19.953952143269202, 74.98680606965097, 39.8317357801622, 49.59705291255828, 35.958167737530125, 53.57081005650183, 83.81270377866684, 71.92243868304838, 68.31372476393177, 64.20133144624772, 68.44291194792717, 29.917696099127497, 0.42102608048627455, 3.57816870654783, 49.35359924070297, 77.25472834802444, 72.43096613114881, 67.878325985324, 65.00777467604607, 64.68401047491258, 63.53896863998906, 60.06241898382864, 56.52565310078283, 59.117221909184615, 57.72009718802668, 54.34073209762574, 51.741526434498454, 52.568267929938536, 48.90632352521343, 49.592181328804266, 49.35309717732091, 49.70322755075271, 51.06351337125225, 50.27427365702968, 49.443296001803496, 46.091807196217204, 46.822399631623306, 49.767056280566806, 46.46872343555574, 47.59745997767295, 46.03272845668178, 49.88692783540296, 45.51022168128721, 44.87292282042965, 46.290483090185354, 44.774428183032626, 45.5860097177567, 46.008048903557565, 48.69566086799868, 46.855210258114724, 46.10088356079594, 43.876723166435, 45.972767183857584, 46.571328716893355, 45.95300628292946, 46.11919710713048, 46.23449125597554, 45.09135177058559, 45.466714751335886, 47.67114170135991, 50.042861661603375, 60.320083402818256, 63.6681362121336, 62.944902143170765, 62.69183866439327, 60.97841793490995, 63.87475882807086, 51.853039418497396, 37.35523754550565, 57.84211035697692, 64.06478197343888, 63.17668284139326, 61.33660485667568, 61.450745828690074, 61.858119272416644, 60.448733222100046, 57.85205356536373, 49.70731858284243, 45.033245778852894, 45.56964951176798, 42.269398627742646, 43.16515030399446, 40.99519706541493, 42.68908831381029, 44.09115522138534, 41.18917003754647, 41.851313191075484, 41.90286490225023, 43.28906974484844, 43.95145216295796, 45.31421692140641, 46.53835335085469, 42.693583350027765, 43.352317963877034, 43.74630828057566, 43.18435030598795, 45.23099991583055, 40.96850141402214, 43.896413464700025, 44.596399645651545, 43.18449151131415, 44.568370388400176, 42.26895932228335, 43.97501384058307, 45.77138877684071, 43.85064332715927, 46.575286388397224, 44.548778149389456, 44.914778432538434, 45.07554069642098, 46.15325504733671, 48.30519676208497, 56.67589164549305, 60.49416211343581, 63.13617260225358, 58.42187589214694, 63.1868927709518, 63.09942391610915, 65.92498563951062, 61.69392493463332, 64.15853446529758, 61.71392902251213, 64.61450999782932, 59.808508273093935, 66.10511656730407, 6.712293730628106, 1.1717081911140874, 0.6783862399958795, 11.43195967520437, 59.837231789865804, 57.96189561966927, 48.09409087704074, 53.49034655478693, 68.51706827840498, 71.80963916163292, 45.41899911818966, 26.842412756335353, 38.08621829555881, 38.92535448074341, 51.296604141112304, 3.0940849790650033, 0.13537354316682587, 0.03985581619124259, 0.00882391466744124, 0.03624320984066975, 0.02795346625780146, 0.060834023170173175, 0.038865865884168495, 0.007578879106609572, 0.05388786182588628, 0.05138332887943234, 0.04689222652344935, 0.0247684040016705, 0.044677198203581, 0.07706530422212617, 0.03073825906481474, 0.09182997889095738, 0.16110910252938349, 0.1427686665086977, 0.17552532976673496, 0.11730653924807427, 0.1886489521712065, 0.24218754302109444, 0.17408847057771298, 0.10579161721492007, 0.18189250101004878, 0.1043215404535013, 0.14792149646147607, 0.1786381748294638, 0.17344497204307588, 0.1846667964972796, 0.12905200012028217, 0.1483997345090874, 0.13260350712845403, 0.17043059992213405, 0.21051788191881873, 33.992632742851015, 83.38252175238826, 55.953402826862956, 53.170896960842995, 45.04644455448274, 56.26506651601484, 88.04351345185312, 80.96064644475138, 75.82020774964364, 69.81731830104705, 74.99924782783755, 32.83883421651779, 0.5943343824436588, 5.040933066798795, 53.4173983143222, 80.6932584701046, 75.08063700891311, 69.81483936309814, 67.88138543405842, 69.08331732596122, 65.5558317707431, 64.18238639831543, 60.24220866541709, 64.91437519750288, 60.77148545172907, 58.8656920771445, 55.428279830563454, 56.761481685023156, 51.82645359346944, 52.345563596294774, 51.01824529709355, 53.68155033357682, 53.93849303645473, 54.99200244103709, 52.18019254745976, 51.097359503469164, 49.543779280877885, 51.20433822754891, 46.903180845322154, 51.658019173529844, 49.341392824726725, 51.52328575811079, 48.375642530379764, 48.23309575357745, 48.804377202064764, 48.469418556459495, 49.470627077164195, 48.56140990411082, 51.32290363311768, 47.94510356841549, 47.31157410529352, 44.98940152506675, 46.89987820963706, 48.72166618224114, 48.492450714111335, 46.647120675733014, 48.30731091960784, 47.460435898073264, 45.268737039258404, 47.713522911071784, 51.6677309620765, 61.800891891602554, 66.29662236859723, 65.10194293914303, 67.14327381503198, 64.53800024524813, 65.97680014948692, 49.97324743578511, 31.926671343465006, 57.124249935150154, 66.40021216484809, 64.61989148970574, 67.01051727417978, 62.77556950046171, 61.92965938198952, 63.077246835154874, 61.01929295447565, 51.52229732082736, 47.34272556920206, 48.8450639478622, 45.02460479736329, 45.90939737135365, 44.13670570619645, 45.33788058065599, 46.49902766750705, 43.84286526710757, 43.05914432771745, 43.424395438163515, 45.46778163602276, 46.359654088174146, 48.01573761047856, 49.337293947896654, 43.44823560407085, 43.99119361754387, 45.53484632122902, 45.63065021268783, 46.59651033339962, 45.05803515834194, 46.682347482250584, 47.29284086535054, 45.48195315945534, 46.03966320714643, 43.47462138822002, 45.85753187056511, 50.00992551926644, 45.43152716852004, 49.48266483122303, 48.390618139697665, 48.70927541486679, 47.61841327913346, 49.40011855094664, 50.74612302164878, 58.735857702070675, 64.19276106742122, 63.06357737510436, 60.06896541964624, 66.69730032643965, 66.4655117834768, 68.24969599323889, 65.68592894461848, 66.97618869043166, 63.686320320252456, 70.76864996264058, 60.48498768960277, 72.10540156210624, 8.320089444037407, 5.156317920454088, 7.4553097832587465, 10.803640100263781, 65.26047337439753, 62.979152279515425, 54.14407230192616, 59.34229143204228, 77.70971544327276, 72.99671311532298, 59.03558169641803, 32.94390862987888, 52.947027683258064, 46.74033188050794, 69.35763220633231, 8.510318513839476, 0.5336558674612354, 0.19239559709545107, 0.16990046707853196, 0.14451278824239008, 0.1490380083240809, 0.15695793253760185, 0.16285356134176254, 0.18834046388585723, 0.149920005351305, 0.11483594399666595, 0.15611427055010874, 0.15436532246249338, 0.19266316096388525, 0.148742436281135, 0.15520985779022017], [0.06816468021321682, 0.019079287604038275, 0.017886128644609166, 0.03372146672899685, 0.04243387059578973, 0.14551084759014268, 0.023735474246824463, 0.09335303829321939, 0.04472982844397907, 0.03640426833543085, 0.04541522432719508, 0.07923093519263691, 0.07058162632728777, 0.05107704309686538, 0.0802140481649868, 0.04567562910397688, 0.06845757860930697, 0.013226024419700187, 0.051010753508777394, 0.12410938469392639, 5.523034036159516, 55.87135468759845, 47.27014210916335, 40.27151584625244, 24.61217857176258, 47.979624348302046, 60.26777467420025, 66.80627945930728, 64.11426659553283, 53.493496218035304, 61.153889086938676, 34.289650301779474, 0.9661159940784978, 2.152197159105732, 40.16128547729985, 75.8646168247346, 72.38591378734958, 65.1486034547129, 60.89755042906731, 60.86736386822116, 61.106730430356926, 57.97901284310126, 58.69074652271887, 54.79411494347357, 52.36061373064595, 52.33943685408562, 50.06292458503477, 49.95939754670667, 49.70055249429519, 45.012618034116684, 45.549292410573656, 48.23611205623996, 47.89036297029065, 45.15827132809547, 46.01166532885644, 46.28305804344916, 42.416107039297785, 45.69089389616444, 46.23689566889117, 47.248263128342174, 45.30325389677479, 44.38328942944927, 43.907431402514064, 43.53298233401391, 42.86470851590557, 42.5453491364756, 44.91373115970243, 45.421717320719075, 44.74912889542119, 45.544836598057906, 44.12662913722377, 45.180538623563706, 44.252635279009425, 43.01002056367936, 46.25585640630415, 44.55392822142571, 44.86334831483903, 45.16130724260884, 45.82403875166371, 44.603620729138775, 44.82635644174392, 51.54342320657546, 59.46102942189863, 59.64321174929219, 61.99130335161763, 59.255332485322036, 59.563834744115034, 57.1685334943956, 30.481348537629653, 46.395006410537235, 61.820876367630504, 61.60896247433078, 63.96783274988975, 61.524804099913574, 58.940205343307994, 60.88709731255809, 59.65437481480261, 47.3855931528153, 43.51464525345833, 44.565981664965236, 42.93536609218967, 39.32271411342006, 40.629961644449544, 40.8910346031189, 42.850866471567464, 39.16659593582153, 38.99539232254028, 40.221913553053334, 42.96037120203818, 41.6139901837995, 41.86580242649202, 42.48976915113388, 39.95673779518374, 40.927316527212824, 41.92591274938276, 41.32413879517586, 43.267386882535874, 39.525634011914654, 42.41666793823242, 40.669165734321844, 43.54440819832587, 40.799611999142556, 40.69912872006817, 40.22505929393154, 43.39881766226984, 42.225024853983236, 42.21088863188221, 40.59941422554755, 45.333703256422474, 42.627726754834576, 45.00440459097586, 46.07882022857667, 51.873878971222915, 60.185338220288685, 62.33618559375886, 61.589574198569025, 63.46020352455878, 57.88629193459788, 58.4344353214387, 58.21714778100291, 58.834124841997706, 57.539056270353264, 66.51449434218868, 55.88310218626454, 64.27748034077307, 10.143556191075234, 1.2249613529251469, 2.1471020002518935, 16.014757944691567, 55.28187736388176, 58.00081729888917, 62.86807075623543, 60.915491350235484, 58.24388657846759, 63.26795639530305, 26.752166863410707, 30.84780577690371, 31.848241590684463, 38.97799268845589, 26.060309794641313, 0.05872509802781767, 0.05774254813009213, 0.07479497967588325, 0.07348601120494067, 0.07950403021588441, 0.012742229361808109, 0.0143235229376343, 0.0984839734531218, 0.030262443770263946, 0.04043880144074079, 0.05723731697446877, 0.043777129162223115, 0.13010152525478794, 0.021064416768269676, 0.037175236239788995, 0.06743239974903484, 0.06289645826684372, 0.03764177229435694, 0.01554100423104941, 0.03285102230767089, 0.08719524654049067, 0.07290283443346139, 0.022200456212064432, 0.015207335593238955, 0.05101776321328456, 0.04029239437753155, 0.055843262948215976, 0.07424834529839217, 0.02016478822746825, 0.01289198135641674, 0.05281425854792038, 0.06938684326145919, 0.08976422280313508, 0.08378237846397585, 0.028104820333781744, 0.07843015114626578, 5.296508823671649, 65.9835466261833, 46.13114464667536, 42.7350781040807, 35.109872817993164, 49.37775711859427, 74.36416902849751, 71.62755489349365, 75.25005202139579, 58.06561485413582, 69.47979834771925, 38.930869333205685, 1.044099638538976, 2.6977167254494083, 42.83282749114498, 79.74257007721933, 76.00575939301523, 68.2509825306554, 64.7199550751717, 61.60097652865995, 64.55272874524518, 61.14613063873784, 61.212363781467566, 57.16572507735222, 55.14501410145914, 55.496862473026404, 52.837687692334576, 52.26170724438083, 51.587255693251095, 47.65705647007112, 47.73788082984186, 51.82326078414918, 47.36884463217951, 48.78026247024537, 49.11866103449176, 47.74316426246397, 47.09710282664145, 47.00944177566036, 47.04046380135321, 47.63126688618814, 49.57986900883336, 46.40186663596861, 46.94177696781774, 46.98518191614459, 46.219578404580396, 44.2108424248234, 47.59468293959095, 47.56770095517559, 48.00545707825692, 48.56022927068895, 45.49494012709587, 45.26992551742062, 47.504970489009736, 45.808321814383234, 47.43770184055452, 47.38512246839462, 48.22373305597613, 48.69588052072833, 48.168372723364065, 46.79857123282648, 49.49531055265858, 53.52919370897355, 61.24808480662685, 61.15519523620606, 64.02896681139546, 62.55578341022615, 61.81687162768457, 60.087710426699736, 38.17686427024103, 51.34210755748134, 65.32351763017716, 63.979925417131, 65.24507807147118, 62.070044932826875, 61.360182223781464, 61.12452230145855, 60.14025449752808, 49.70734603943364, 46.10099730953094, 45.91084472594723, 46.10091493975732, 43.04450211986419, 43.30158210569813, 45.45447303402809, 44.99028405835552, 42.815722034823516, 42.52567060532109, 43.35846039556688, 44.96791085889263, 43.03339396753619, 44.546926790668124, 43.35957434869582, 43.771540887894176, 44.355609263143236, 43.8651051059846, 44.636301917414514, 45.52840971177625, 41.35160323112242, 45.25365944831602, 44.801492537221606, 46.276990136792584, 44.373742380449855, 41.852752700928725, 43.221440238337365, 45.13256411398611, 43.79462795872843, 44.51227657256588, 42.49950447390157, 45.4377951160554, 44.21117974865822, 46.16514767369917, 47.23227946988998, 54.072500813391905, 62.14348739193332, 65.56304108711981, 64.05235982710316, 64.57507448811685, 61.285013921799205, 61.96748279756116, 61.40743109487719, 63.023455450611735, 59.562144202570764, 69.69847832956623, 59.90171555549868, 71.05784631544545, 11.850592282510574, 2.1157882482774797, 3.934930091904056, 15.629294860747555, 60.992369805612874, 62.07265723136164, 65.83332769332394, 63.86452536429129, 62.61942778864215, 71.32755633323424, 34.77043482565111, 39.160210317181004, 37.2518438677634, 46.02660171447262, 28.818718579507646, 0.0477869023058203, 0.02567768333509805, 0.0802232642027159, 0.046405944552633076, 0.06372014451171122, 0.052169867520851475, 0.004016917392296056, 0.02646632297264953, 0.039599092466936964, 0.05697178706947354, 0.021897146681083307, 0.029119099678111174, 0.05721997274386306, 0.0261586275883019, 0.02498145688385252, 0.08428611191770724, 0.18837178156020182, 0.16237264198641624, 0.10665654580319121, 0.20021962242261057, 0.11797107455711212, 0.28920894729033597, 0.2417733039586775, 0.14794777327727887, 0.12447369014543873, 0.15560532769849225, 0.2826970160728501, 0.16331388825370421, 0.11150901566349691, 0.1084264234128979, 0.1294900951606612, 0.20351205381654924, 0.336256367905486, 0.23660705214546573, 0.5175859781522905, 0.380282307103757, 11.64113183175364, 80.60835484535464, 62.6642918586731, 55.275079896373136, 41.46518330420218, 60.594586556957616, 75.23991661687052, 79.64195343755907, 81.10269115817162, 69.17210409718176, 77.07587611290717, 43.729916695625555, 1.3804637184066157, 3.7907261137039434, 45.433194175843276, 84.69460948821038, 78.87825227552845, 71.5466756205405, 68.41601233328542, 68.2319982590214, 67.70640850067139, 64.7147383228425, 64.78012031124484, 60.17124514425955, 58.45514151357836, 60.2122692138918, 54.88473738393476, 56.49773759226645, 55.156130098527484, 48.17131842336347, 51.07366838762837, 57.095848052732414, 52.43022011172388, 52.43421308455929, 52.67576440688103, 50.44558317430558, 48.61331462860108, 52.17524643867247, 50.322887512945364, 51.20278496896067, 51.30349574550506, 50.239093918954175, 50.653778660681944, 50.05823343030868, 50.33285817792339, 48.34085502932149, 52.32643811933456, 50.039488423255186, 49.899557867357814, 52.686966696093165, 48.43003403755927, 50.91603617514334, 52.373549707474254, 49.47149784334245, 51.984682006220666, 50.70713466213596, 51.0724602976153, 50.54908667841266, 49.12211664261357, 48.25292333479851, 49.75605010986329, 53.835013066568685, 64.47150038134667, 63.34330120394307, 67.12996913540748, 63.859096803972804, 65.76965585831674, 57.72785171385735, 31.68013664983934, 50.96545411694435, 69.47933550803893, 66.30193325781053, 69.15155872221916, 65.76253283408381, 63.14463707708544, 62.65039490115259, 65.1847912419227, 51.46008460752426, 48.54472021902762, 48.58227299105737, 48.49847155232584, 44.541345257912916, 45.49800742057062, 46.690529546430035, 47.37116667532152, 44.89774357888007, 44.73766380740751, 46.17966436570691, 48.25001293613065, 46.01535235681842, 47.37155498996858, 44.99515956447971, 45.510715899928925, 46.36887950281943, 46.89348866862636, 45.43935229701381, 48.933591842651374, 43.08201174582205, 47.29529626907841, 47.98598251035137, 49.59354239125406, 44.620824244714555, 44.54210227535617, 46.56126783740136, 49.75739156046222, 45.516956390873084, 45.70989777964931, 45.57135182042276, 50.08620385200747, 46.52712360505135, 47.4277154860958, 49.3294099838503, 56.24657254065237, 63.80684691090738, 67.93040721647202, 65.93629775508758, 68.13230729872181, 62.08896644653813, 63.57706662147277, 65.76888315139279, 65.99841240913638, 62.89739831801384, 74.92974342838411, 63.9428472518921, 74.55361166308003, 15.453651124431243, 4.01974668906581, 10.474975878192533, 18.133950810278616, 66.0029858927573, 69.04069685166883, 71.32310836545884, 68.24185125289425, 70.94301500628072, 73.56209139670096, 38.51769078162409, 48.319305527594786, 51.589059983530355, 53.62975935782156, 47.003087535981216, 0.12912962014877027, 0.19376033676728127, 0.28678682242189685, 0.15759164046856666, 0.23820315037042866, 0.10076349105445609, 0.10901775135989152, 0.2315122456920724, 0.19932804929633297, 0.1796672147728743, 0.13030869075127188, 0.13565688844650023, 0.2440037689502201, 0.13721302752533268, 0.1407871188055123, 0.24804408601935835], [0.04780659842635355, 0.04950869257651991, 0.035306786096865134, 0.10435108080386155, 0.004113088718675558, 0.07726090179095346, 0.04107325630743177, 0.0664941642072893, 0.08388770023180593, 0.0189037557931677, 0.12052076838670239, 0.022365059778695146, 0.037092065904289484, 0.03790772737815015, 0.04518606061596544, 0.014303543364569066, 0.04382323233350631, 0.026644919135217226, 0.04996334660738226, 0.03801217963618617, 0.21492290280518994, 33.13889357351488, 51.97318946161578, 65.48077721749583, 30.93982654233133, 37.24072787069505, 59.504767771690126, 57.825075503318544, 72.65143471379434, 56.81010730804936, 59.30665669902679, 45.94948791688489, 2.8085467267420987, 0.527141239614256, 30.577558394401308, 70.04473732363793, 75.99035232297837, 68.89147420083323, 66.4740547057121, 58.31448924156928, 60.06616876971338, 58.41152475726221, 57.55043506622315, 58.105917207656375, 56.66217511700046, 52.41715077430972, 50.02070419249996, 50.11425664347988, 47.923969837927054, 46.829765842806914, 48.636950831259455, 48.1387705956736, 46.43311223676128, 47.203038200255364, 46.70615626919655, 45.98788792087186, 42.357487217072524, 48.60623867281022, 46.152866732689645, 47.054549032642, 46.28068893186508, 46.352915456218106, 45.621679752103745, 44.7180127328442, 43.07002106020528, 45.40471776839226, 46.357143771263864, 45.90199585883848, 47.052560390964636, 46.957486060357866, 44.84084959953062, 43.1602277294282, 43.183965913711056, 45.90158400997039, 45.574450492858894, 45.29922954497799, 44.76954875453826, 47.405989477711344, 46.18472030085903, 44.30454392586985, 46.05057524096581, 49.35105754483131, 53.66524111840033, 60.77728271484376, 57.70310548044021, 63.50653848340435, 59.04608188136932, 62.30801513118129, 35.7825553801752, 37.815574753669004, 62.515175111832164, 60.469270752322295, 63.98993138344058, 59.605804104958814, 62.40583904327885, 58.238489397110484, 59.37020694055865, 53.993751387442316, 46.52141263408046, 45.57741188233899, 46.75753539608371, 41.232531839801425, 41.125564882832194, 41.32973601741176, 43.83413014873382, 42.712555854551255, 40.45674977764007, 41.61846168579594, 42.67315956854051, 43.70004784676337, 41.88317852635538, 41.827939787218654, 43.07802661772698, 40.32095732227449, 41.874792498926965, 42.8492896787582, 45.48811520299604, 40.4265671391641, 43.50838907303349, 41.472835848408366, 45.193713864972516, 44.30641097407187, 41.08044978111021, 45.70993700335103, 46.02329515641736, 44.83073772922639, 42.784276393152055, 43.60687586569017, 42.653331987319454, 43.42154387504824, 46.21966469672419, 43.721895448623165, 48.26075238566245, 51.341264247894294, 58.623007189842966, 56.58164101262247, 55.53564294692009, 55.463506637081025, 58.680556205011186, 56.43532483808456, 63.446126138010335, 58.11250286717569, 64.43232374806558, 57.35961960208032, 71.14682920517461, 15.678359789233054, 0.3842249939278249, 0.36654362334839763, 18.499125434506325, 57.0112503728559, 51.61256282560287, 61.76596318521808, 56.025413620856504, 68.6704957100653, 45.766764302407545, 24.969288802916004, 36.132756356270086, 31.030029289184082, 46.17565962576097, 2.9985404543338285, 0.04946504854747365, 0.03374938297295763, 0.06467465176096847, 0.04231213922462156, 0.07696309277126867, 0.020449054727871573, 0.07143599056308308, 0.02538005051563584, 0.01567831208493801, 0.04312905708267804, 0.03329090233291349, 0.05669988714338792, 0.048582453971668604, 0.060102060632479776, 0.0460896153573788, 0.05246563108577844, 0.10979818811099376, 0.0697209878313926, 0.09571035212326436, 0.020714632513362075, 0.025792334138626055, 0.05868473285508733, 0.030351179734533353, 0.0378053282357512, 0.05307076010672797, 0.03975675336175388, 0.06413618388075022, 0.03444678345394712, 0.050913877860312505, 0.05917753040369961, 0.010243653706575354, 0.01685200570782106, 0.0625796387753179, 0.05278403254886789, 0.08716287166481057, 0.13680228182385046, 0.2159683829954555, 38.212177368902395, 62.716722180766446, 53.47409225279286, 45.02591094663067, 44.4790070287643, 66.96678284675845, 66.83680334398824, 78.15877975956087, 65.61719332971882, 64.56470374138125, 51.23846284804806, 3.1605549348938853, 0.8373306691646577, 31.30347340337692, 71.51812076568604, 78.56424300901352, 71.23480012339931, 67.08995311490952, 61.604122269538145, 62.40040263822002, 60.14210193387924, 60.07586879114951, 60.45281248707926, 59.83984408840057, 55.131187746601725, 53.67717689083469, 51.4293763714452, 50.020092302753085, 47.73109120707358, 50.70204734802247, 49.88501371875886, 49.91030908400013, 51.36361783550632, 49.92882267121346, 47.57837372441446, 46.90379273506903, 52.69932608450613, 48.95116013865317, 48.54290023926766, 47.75726518323345, 48.55863678839899, 47.94261286335607, 47.00306400176018, 46.069253567726385, 46.752342177975564, 49.53816244679113, 48.344251801890714, 48.562590537532685, 48.83497953414918, 45.826364717175885, 46.00072583844585, 47.89723888520272, 48.10397524987498, 47.80104667909684, 47.479263274900376, 45.008515234916445, 47.790668087620894, 47.446656611657914, 47.54121318940194, 47.98965384883266, 51.87023116696266, 56.62781907666115, 63.76057863235474, 61.3558989955533, 66.23566089137908, 61.31554957359069, 65.96934764615952, 42.757839618190644, 42.343386296303045, 65.19163970024356, 60.75845926038681, 66.20157549458166, 61.01756318922966, 63.91653991514637, 60.96612522678991, 63.110492844735425, 55.4544145830216, 49.707636294826386, 48.0217819829141, 46.73963369861726, 44.120710280633745, 44.77982536438973, 42.42625813330374, 44.90155220031739, 43.317836407692205, 45.30719195642779, 43.70787297525714, 44.77201984774682, 45.551598764234974, 43.58295725237939, 42.82681057530065, 46.18304152642527, 42.2334461827432, 44.213878339336766, 46.2010883515881, 45.34730603618007, 43.076818527713904, 45.97732497799782, 43.86518747575822, 46.92371053080405, 46.65916235216203, 43.73354096566477, 47.76867535806472, 48.454642988020375, 47.13487525140086, 46.392029331576445, 46.08576674615183, 44.40350924768756, 46.209121365701, 46.79042054760841, 45.58114205637286, 49.7260675122661, 55.22745840011105, 59.086929444343816, 58.71844630087576, 56.770503136419485, 57.14180646404144, 59.90105659730973, 60.92055120775777, 64.88607137433945, 62.82021784013318, 68.00368493603122, 61.59544990908716, 77.33028104228359, 18.656985144461355, 0.8093418613556893, 1.0025594707938934, 20.370496088458648, 64.48923341689571, 56.69179293417162, 67.75056654407133, 59.84644935977075, 74.11140364985313, 53.3335498071486, 31.890026600130145, 42.15211583722023, 36.14860273176624, 55.1605623768222, 3.3016161139934295, 0.07855882327402793, 0.14495439196546234, 0.028002017080002738, 0.03097484808325047, 0.05882770018351655, 0.06652493795920765, 0.07851878751910503, 0.009001198904438606, 0.007194081760732638, 0.05048762270880323, 0.02792057427277248, 0.13459196494471642, 0.08300276908783183, 0.051217654704927444, 0.009980548469860469, 0.06887077579214688, 0.20669856589407692, 0.24215677693005533, 0.18812038214696994, 0.3065441074150224, 0.10746812402841546, 0.2507242752659706, 0.12457889700008017, 0.1411944017895768, 0.1564124166484802, 0.08292105048894882, 0.12763045502886658, 0.2894301628393512, 0.12706089163980178, 0.21869230054078564, 0.09742653463035823, 0.1091515486158671, 0.1518484325178208, 0.14163372257063467, 0.19235090352594855, 0.11902342655605848, 0.2926867106749166, 55.66384561600224, 74.42997071050829, 74.7891656814083, 48.73260567265172, 53.207049446721236, 79.32216259741014, 78.2929640431558, 83.3204149430798, 69.998257237096, 72.99140222610967, 57.8929913428522, 3.4533834024783108, 1.25307910865353, 36.11541948010845, 77.0035005384876, 81.59975744062855, 75.02099344807287, 73.96146712764617, 65.10832071304321, 68.0723891719695, 62.940567924130356, 62.208355549843084, 65.2983203241902, 63.03270439947806, 56.43254780000257, 57.30653816653837, 54.69752657798029, 53.32348108291627, 50.28834712120795, 55.85701450224846, 53.54700911429621, 53.675356911074736, 55.170642868165054, 54.61918507852862, 51.637065872069336, 49.28314562766783, 56.99664738870437, 51.155692992671845, 51.866677499586544, 51.55587280950239, 51.713446186434844, 51.267633515019575, 50.633664746438306, 48.23951275117936, 52.0015246637406, 52.22977915117818, 52.164263802189986, 52.50183082395985, 51.443155657860544, 47.88622879212903, 47.414206843222345, 49.59021622134794, 51.32629256094656, 50.063379579974765, 50.13836353055893, 49.788237079497314, 51.993417124594416, 50.25611308313186, 50.06937688396823, 49.78988839733986, 53.32155519916166, 58.862918961432676, 65.81074268587174, 63.27629927665957, 68.04962373548939, 63.43210758701448, 64.05497997037827, 34.81846032604095, 42.13286876678467, 68.35760824141964, 63.77380878694596, 70.92108895701747, 64.95221038018504, 65.90144357373639, 62.85096137754379, 64.16464159565588, 58.47913857429259, 50.98885105502222, 49.22168993180799, 49.8528463609757, 46.41296694355626, 46.5850648572368, 46.44547162517425, 47.364557481581166, 47.358332680117705, 46.62494751714891, 45.310737779063565, 46.57327029012865, 47.59681670896469, 45.48002727570073, 45.31445226361675, 47.951818666150494, 44.52129802396221, 45.93990556655392, 47.482667892209946, 49.5809555053711, 45.302944029531176, 48.367636972858065, 46.602472336061545, 49.90287619252359, 50.01551881913216, 44.99321014650407, 51.00159875808224, 53.38306188583375, 49.37112439063288, 48.63594670449534, 48.19537431963029, 46.89201777981174, 49.20809891916091, 50.324864387512214, 46.85819518181586, 51.55266431070144, 56.97275230961462, 63.217032263355875, 60.2727835409103, 60.040579226709184, 59.74239280146938, 64.0905087993991, 62.305873517067205, 68.18724401535528, 63.14335838440926, 74.98915164701401, 63.5811419640818, 79.21183416920324, 22.095707462679957, 1.5337294748713894, 1.9367693124278902, 21.272425497731856, 70.14283580164756, 61.613602638244636, 72.23781293438327, 65.80092107096027, 78.704130418839, 53.815432594668486, 35.85737066884195, 55.75891210186867, 43.07497501373292, 69.78901447788363, 11.777018424003355, 0.5221768060038167, 0.2535896739291568, 0.16649865365076452, 0.126937942188834, 0.1376040694454024, 0.12704470420196173, 0.1493094332756535, 0.12300829418123731, 0.09933774014033618, 0.15542270765910227, 0.11376494541764261, 0.14098460095063334, 0.24295474943374437, 0.14065610244870186, 0.1533194439065072, 0.1851203818354876], [0.07344441263065224, 0.08726920466870071, 0.043744604899397785, 0.029056498803378596, 0.049382690265173876, 0.0460127997212112, 0.07198950441013421, 0.014455340813935525, 0.0424243251402532, 0.058726971112792535, 0.025900003965944055, 0.056323695837730364, 0.08090031738843649, 0.028254140446323062, 0.03656362994543968, 0.06165392111025511, 0.06695360245723879, 0.034053477744061145, 0.029839618777435635, 0.08067164014303878, 0.20789652822479127, 5.8824511112705355, 62.970754484976496, 38.66500323818576, 34.78450044508904, 24.732401178729152, 52.026576842031176, 65.46796675651305, 62.99487313916607, 60.67050795401297, 62.48345098187847, 56.493117040203465, 11.822058020099519, 0.34301130221255366, 17.224882687291792, 62.66740622058992, 79.62422432438021, 71.1684649990451, 66.53955044284945, 66.3446557137274, 62.57955689584056, 61.80487701969763, 58.94787749936504, 60.86424950630435, 64.09464297756072, 60.72653508955433, 54.711368622318396, 48.91554109511837, 51.7551919721788, 49.01183136047856, 47.61769156302176, 51.91052175337269, 51.34637509622882, 47.71651175714309, 46.652537468940984, 48.39066520813973, 47.92522891875237, 48.00896367719097, 48.07939767837525, 47.78789104953889, 46.85319808221633, 45.50943720725275, 44.51058603102162, 43.837899546469416, 44.9069768382657, 46.231698528412856, 45.67225087073542, 43.50616901151596, 45.65434525089879, 46.34238389230544, 44.36936893770772, 45.58586459006033, 43.85042759679979, 43.06003078337639, 43.409580646022675, 44.843375605921594, 47.53578070671328, 48.81572854134345, 47.48414270339474, 48.153255908719956, 47.858109320363695, 49.314956049765314, 49.760070539289906, 55.38563582205004, 53.97081728904478, 64.00969620673888, 56.55335287893973, 71.77132544978973, 47.36467907505651, 31.63427237541445, 60.46628190625099, 58.71648119341943, 63.99349289555704, 63.13777685165406, 58.0870702189784, 58.93436885649159, 57.55842493426416, 53.91002055137388, 46.57128164845128, 45.49084517263597, 45.77375004368444, 43.20478193221554, 42.15237863602177, 40.08523464202881, 44.161675514713416, 41.288833541254846, 42.415805016794515, 41.53531920525336, 42.55225643034905, 41.75579171026907, 44.564306812901656, 41.356761147899014, 41.50805873255576, 40.61154219412035, 42.114292421648585, 41.48876851604831, 40.94834827607678, 40.99382423585461, 41.172237165512584, 42.469557177635934, 43.99077000156526, 46.941212146512925, 48.63274605043473, 45.91847765830256, 46.14663800885601, 46.904318332672126, 47.22108894778837, 44.4730842498041, 44.958916864087506, 43.7767223388918, 45.50906850445656, 44.12911591991302, 45.5026436621143, 41.93771516123126, 45.79129480546521, 44.95153888579338, 46.91654828286941, 46.620052399173865, 54.295836648633404, 57.351770939365515, 60.9354091459705, 60.71852953203263, 66.92640596820463, 58.51343970144949, 75.3883469489313, 21.14965335015328, 0.5377963581873525, 2.0451023573836973, 21.485998553614465, 61.83612654286047, 57.58452830776092, 61.78117021437615, 56.836159690733886, 67.73155089347594, 18.957203357450425, 28.67323983100153, 29.005276310828428, 39.51651450126402, 27.50175533756133, 0.4237451716776817, 0.018298835531177542, 0.043883795414360306, 0.020100833292329506, 0.03240512849222268, 0.01356038540947221, 0.009386567943429035, 0.04114358700932034, 0.03326365641588646, 0.05871483244963231, 0.050539563470069444, 0.046250095455757076, 0.02221626252116215, 0.018029812265247587, 0.07293644271069959, 0.048455946042292544, 0.04264619569444368, 0.006553537452653532, 0.05088704563076458, 0.035975247606514923, 0.033445456741197456, 0.054327232402659235, 0.07823433141194044, 0.028328167522446285, 0.06785157241768415, 0.07117840882030226, 0.0425569809252216, 0.0075503078574735314, 0.05941123318588061, 0.09773460156734913, 0.15744712564253038, 0.04708948650307233, 0.043240273897085464, 0.08453745770478442, 0.03483562670167416, 0.05168617109677965, 0.030511290195488164, 0.15215425481719358, 7.541568586903234, 74.51066955443352, 44.435982550344164, 39.76997021705874, 32.99411104571435, 59.050949542753166, 74.04127951591246, 68.84579427780645, 65.30441176506781, 68.11233458980438, 65.48309533826767, 13.411081760160386, 0.3339072052509554, 16.66534677628548, 64.22154341974567, 81.4976816792642, 73.18502610729587, 68.23194334583899, 68.50507367041804, 66.05572608209425, 65.806173124621, 63.54769591362246, 63.71455354075279, 66.96463338790402, 65.44645647848806, 54.72040576319541, 50.56363082701161, 54.679083593430065, 50.422099944083925, 50.22055679751981, 55.356123908873535, 52.626405300632605, 52.06235278037287, 51.680376683512044, 51.90241421422651, 50.745573889824655, 48.22060300457863, 49.65366448125532, 50.28726846941056, 49.10887472091183, 47.07123479535503, 46.46295755140243, 45.99221037280175, 46.892774797254994, 47.48400934280888, 48.424350523179584, 45.514438229222456, 47.43279495546895, 48.63912774670509, 47.322607732588246, 47.125912635557114, 48.12513251458445, 48.305345812151515, 44.64515078452326, 46.9726695552949, 48.420769399212254, 49.87749453513853, 48.776296954001154, 48.80208653788413, 50.941417832528394, 53.13249695685602, 53.92464314737628, 57.46828886770434, 57.337564114601385, 67.24756963791387, 59.00143354169784, 71.9731863083378, 55.90817005403581, 36.73728773670812, 62.039481824444195, 61.35087443936256, 66.56586170196533, 63.52737019138952, 62.48345098187847, 60.958778627457164, 60.14495349699452, 56.39150804088962, 49.636449198569025, 47.81325701744326, 49.840208484280495, 46.61956210290232, 44.678286967738984, 43.97032660822715, 45.163189980291556, 45.00937423398418, 45.380677561606134, 44.6068056937187, 45.34465843631376, 45.24627754765172, 45.658153872336115, 42.80544150260187, 44.676270869470414, 42.86285715718424, 45.06908447511735, 42.52907522263066, 44.26375912081811, 42.2707518454521, 43.6825030849826, 46.991897013879594, 49.60627048246322, 48.133181218178045, 50.175304412841804, 48.776598976504424, 47.64957258778234, 49.294077273338075, 49.38151082684917, 47.506770856918834, 46.74580358689832, 44.955100397909845, 46.005354235249186, 46.178111107118674, 47.25406039145685, 44.551845442864206, 48.88886113320628, 47.66598770695348, 49.83864738095192, 48.78769928409208, 55.20565002195297, 60.6976076095335, 64.36884018682665, 63.35120477984029, 70.75860869499945, 60.26867289696971, 77.78778629918253, 23.322091410236975, 0.5572956860546143, 2.1569481299769495, 24.810560287967807, 68.90874047433176, 61.633587114272586, 69.29870251686343, 60.501077252049605, 75.07756971543836, 20.998363610236876, 34.38965505169284, 33.93380895737679, 47.5384989092427, 34.84305750939154, 0.36292299988769716, 0.07266699426597165, 0.018905795502266096, 0.056535185900546854, 0.022914413768317432, 0.08459967170511523, 0.028466300836073297, 0.08569107886644141, 0.022882307023410837, 0.04689174771849667, 0.02737603897619392, 0.032809607594484286, 0.0035754429465610416, 0.02677641621220016, 0.06735209075193252, 0.020488452714597507, 0.044228527319407275, 0.15839123707865516, 0.15753605312878088, 0.09310168484526296, 0.19748609813470996, 0.1198102831239662, 0.28724114320451216, 0.1619810944483165, 0.2598629687582293, 0.09329314553929914, 0.16245237641757534, 0.10480482702053363, 0.18505377815135066, 0.2056941326947943, 0.24001560714696688, 0.14551855443466097, 0.18553759331905073, 0.21086954691958046, 0.23003205657005313, 0.18736526460176517, 0.39650473984018453, 0.7721371996787287, 14.962744924329943, 92.04058124173073, 52.612249466680716, 50.91693047554263, 39.01895007779522, 65.89061783206078, 80.48999340303483, 75.94164433017855, 71.41162841550766, 77.638838214259, 72.08562497169741, 15.335228885373763, 0.647161967091022, 19.38748344298332, 68.67008778356737, 86.44200971049648, 76.26003880654612, 69.93480897718861, 73.7053991133167, 71.47013448899793, 69.10119548920663, 64.89766590056881, 67.7587329187701, 73.80297199372323, 69.4443008976598, 59.2782901179406, 54.24123725583477, 58.121198761847715, 52.73794574122275, 54.545248400780466, 59.15765762329102, 59.57588818765456, 54.191948752249445, 53.36794114881947, 53.451883792877204, 53.40962417664067, 51.56848715197656, 53.53855640657487, 52.30410022120322, 52.49642972023257, 51.07386842850716, 47.64374786807645, 48.638217756825114, 48.898576844123106, 51.294776316612, 53.230407161097375, 46.66299450782038, 51.07531186073057, 51.16349458694459, 50.47775445445892, 49.56971007008707, 51.04951835447743, 50.906206715491514, 46.29339348885321, 50.692017847491854, 53.520631174887384, 51.56605136009955, 50.53364430704425, 52.15596798927554, 53.61046129657377, 54.84527049526092, 55.86256465604229, 60.51504088986305, 58.90493539071853, 69.12565538960119, 60.86920345983198, 75.73179752595964, 43.48961660938878, 33.70461702346802, 66.45678843221357, 62.01417469209241, 68.08768641564154, 66.78429065212127, 63.6366395796499, 62.983235466864805, 62.665927487034956, 59.76098483608615, 51.25763147108017, 50.99837064743043, 51.15885442303073, 47.65617393678235, 47.41530118450042, 45.22087627841581, 48.46353892357119, 45.643197874869074, 47.85953314073625, 46.16248046198199, 47.50063626996933, 47.15118054420718, 49.040331302150605, 46.11346260193856, 49.293308488784305, 43.87604459639519, 47.02543720122307, 46.74619190154537, 43.719702843696844, 44.699624661476385, 45.43533186758719, 50.32178140455677, 51.09768506019346, 51.586310402039565, 53.491182019633634, 52.62281633192494, 51.16524004167127, 51.00335990228961, 51.38001726519678, 50.48049226883919, 50.4441632763032, 47.11487116352205, 49.19038549546273, 48.11258485240322, 49.7651303968122, 45.71355342864991, 52.702103122588134, 49.529246899389456, 51.974377939777995, 51.656913065141254, 57.6975945503481, 63.21514952567316, 68.44211962915236, 64.72568173562327, 71.70950889587402, 64.63077214456374, 79.54294496966948, 25.484854944290657, 0.814435794468849, 8.515844152819726, 24.542130924040272, 73.1859439419162, 65.97295622671804, 73.24699955601847, 64.68080982085198, 79.1666563095585, 24.44917271214147, 44.257326433735514, 45.07940815341088, 55.114909910386615, 51.21595628799931, 0.6722603558051972, 0.11542239962446114, 0.12396437957161859, 0.07095503290334056, 0.10198851161065603, 0.17261221914762453, 0.10271538349409258, 0.16349345926315556, 0.14569529091879246, 0.18298158692496438, 0.11663531599145745, 0.22780370598118152, 0.18690305311352978, 0.09685370004585675, 0.1204044379354004, 0.21145247854292396, 0.13053258760802208], [0.008510853794793929, 0.09431841633012218, 0.048217206232009396, 0.023770595547713103, 0.03634501526492738, 0.03708273112293213, 0.04070638063093347, 0.06611151094999045, 0.045563320614277356, 0.06330293685858769, 0.025384131849052447, 0.007811772708420552, 0.04949375386199644, 0.037455907872607636, 0.05057601776394633, 0.022412652990991072, 0.13538376277973577, 0.07100859777100625, 0.05395735366149776, 0.07000456293744427, 0.006086267390093136, 0.0423147592453226, 27.158565598149455, 55.38963271725563, 40.157606294078214, 34.59368498094621, 30.18246589168426, 76.21007565529116, 63.318602038968, 73.88882483205488, 65.4847780350716, 66.22551764211347, 40.405307892830145, 0.9494643682433713, 1.7509983840488619, 40.11628020194269, 76.42411939559445, 77.0460190311555, 70.18426387540757, 69.80511972981115, 67.78058836537024, 66.32096459788661, 63.539098078204745, 67.3134889910298, 67.62122246526903, 67.41415269913213, 61.44915334640011, 50.97959818378572, 50.143215502462084, 48.7605211811681, 50.37688286073747, 49.41631793975831, 50.37586696686284, 50.57014588386782, 49.73564986259707, 47.720747916929184, 49.0118117486277, 46.236083738265506, 48.50482186963482, 48.219896977947606, 48.056408666795306, 47.19430308188162, 47.12819937736758, 44.405992108006636, 45.85631985818186, 44.73427487957863, 47.12211578123031, 45.324928914347005, 45.87855185231855, 45.572634435469105, 44.632430538054436, 43.75563567684543, 43.53129963720999, 44.14695485945671, 45.11470556259156, 44.898480984472464, 48.297858007492565, 45.384686223922245, 47.16229261890535, 46.54312295298423, 52.63641518931235, 57.00324089296403, 56.11254515186433, 54.49924292102937, 57.275641656691036, 59.412666597673976, 60.47324019093668, 63.1034404231656, 66.10515579100579, 39.15642130759455, 50.30688424264231, 60.5310441601661, 57.1696670593754, 60.966086003088186, 57.90079293712493, 56.64594434922742, 56.851264738267474, 53.59580339923982, 48.535812516366285, 45.49152374267579, 46.299986993112874, 44.79084330220377, 42.83010928861557, 41.30271480929467, 43.52785971856887, 44.42896935247606, 41.13899115593203, 40.51362414513865, 43.10918984874603, 42.1119664561364, 43.14259275313347, 42.06383112938174, 40.92211154199416, 40.137441389022335, 40.936765516957934, 42.918323393790956, 44.083286946819676, 42.24346391616329, 42.38055075368574, 43.74099739136235, 43.848278137945364, 48.31971345409271, 49.75075098776048, 49.77914110306771, 51.43513441085816, 50.271182829333895, 52.23101077541229, 47.61691885609781, 47.835453710248395, 44.86008882522584, 46.117690916984316, 42.9622813963121, 47.225638897188254, 45.00454579630206, 46.414959507603804, 43.53078580671742, 46.76059876718829, 45.420093459467736, 51.621576432258856, 53.25236066695183, 61.373035830836145, 56.55401183712868, 70.26964602931854, 57.1508514496588, 74.76399975438272, 26.880671554996123, 0.5203334145968961, 0.22586273029446605, 29.906976261446555, 53.501125228020456, 58.25902692733273, 58.748444587953635, 63.48722081030569, 33.463795261998335, 16.281100607687428, 48.837317266771876, 28.15375916419491, 52.27365478392571, 9.598117278468225, 0.09471577081468799, 0.031798459634545355, 0.02952915015480211, 0.03498180393850611, 0.06354350761900987, 0.027494114192743457, 0.011960812975772688, 0.0750030261734801, 0.056486765313292706, 0.05991882772275037, 0.059316713257782885, 0.0464027806095058, 0.028210592178267338, 0.006763248755070832, 0.06279268399662068, 0.034154819685124585, 0.01151771825407782, 0.08160340990270339, 0.08153535831238955, 0.03608713474785609, 0.07785538602019511, 0.016046124303923742, 0.03646867334722512, 0.017757590582233765, 0.08261012604400035, 0.01144076184925413, 0.012297432967311433, 0.0533671633550717, 0.065495798424367, 0.05275909255649294, 0.04903452628622613, 0.03403154847722861, 0.04542558566637097, 0.16086573171759808, 0.027437088522879828, 0.06499951900613886, 0.02272414051056389, 0.10548752627425617, 0.20451268721972743, 32.99068681655392, 63.20190760397143, 38.88181617183071, 44.86031632269583, 34.416068292433216, 82.61973842497795, 68.92825034356886, 78.3897210705665, 72.57182628877702, 72.61045379023399, 44.19293680498677, 1.0299691774191395, 1.7596576290745891, 42.49853957083918, 79.40445392362534, 78.72968073814147, 71.78524986390146, 72.08749986463978, 68.99859413023918, 68.30769215860676, 65.3424273767779, 69.44228479939123, 69.80911270264657, 70.3293288138605, 63.28617188238329, 52.3812650096032, 51.432133797676336, 51.81927173368393, 54.06014142497894, 51.36224500594601, 55.81604926816879, 54.12589996091781, 53.70627303277293, 49.65526480828562, 50.44852495193482, 49.66642395142586, 49.33473264017413, 50.36990888657109, 50.435220272310325, 49.70711461959347, 50.85370971310524, 47.22957695684126, 48.90440940856934, 49.55412649339246, 51.149719222899414, 47.12905445406514, 48.66715700395646, 47.26756118958997, 48.260418984197806, 45.434123777574115, 47.13298074660763, 47.54471586596581, 46.69817032352571, 45.682503946365856, 51.53832804772162, 46.918729120685214, 50.13436271298317, 47.85608929972495, 53.93726925696097, 58.38788070986348, 56.978094577789314, 55.51164196383569, 60.210492380203746, 60.54017543792725, 65.59533788311866, 63.35793948942616, 77.54845111600815, 45.468585721908084, 52.8983118457179, 64.89030361175537, 60.101725055325424, 60.827881290066635, 60.32718681520032, 59.654221842365885, 60.99690798790225, 56.95877298232048, 49.801322106392156, 48.121574924838164, 48.87726268460674, 47.92087901023127, 47.350844875458755, 42.99046754837037, 45.491712016444055, 46.359352065670876, 44.7051630481597, 44.379359214536606, 46.80900473748484, 43.936205910098174, 45.872574160175944, 45.45008782417544, 44.98372977779758, 43.47997934587541, 44.513923968038256, 45.73282011093632, 46.36007770415276, 44.26585366649013, 43.1571251346219, 45.246999263763435, 49.12730593835154, 49.896400359369096, 53.12565634327551, 52.23546658792804, 53.88062630930255, 53.7589269299661, 53.53199035890641, 50.23345355064639, 48.83206521311114, 46.38506712452058, 46.91055490124611, 44.77987635520197, 50.21014682708248, 45.45703041938044, 49.113271697875, 45.780955437690984, 50.67973298411216, 47.15817020785424, 54.51994519079886, 53.89289156083138, 65.12109979506462, 59.993495095160704, 71.80750539225917, 62.186672687530525, 78.52711385296237, 29.278169332012055, 0.611041718192639, 3.3290702537182844, 32.23786827056639, 60.550463814889234, 63.64555512705157, 63.72161772943313, 67.08445395192793, 39.13603674980902, 19.21181421126089, 58.83435626183787, 29.94539587728439, 60.81567879646056, 8.47173317786186, 0.18340284335276774, 0.05344135897053827, 0.004396210875241988, 0.008651458699586652, 0.035056620085191344, 0.07077766822711115, 0.01234238126104878, 0.07975687753529319, 0.016993178475287654, 0.032437568485376336, 0.06583833165707127, 0.05419820787445192, 0.04624926041991961, 0.039799290393749555, 0.016284845919618686, 0.05695445816062632, 0.03459644639083455, 0.19370988221658816, 0.17686147903723104, 0.10133809530206266, 0.1065218675461027, 0.14961802881331215, 0.12463004102990513, 0.16035285117405076, 0.3123783878982067, 0.12681730632339755, 0.1395844373731844, 0.11228976651064812, 0.1136965414268836, 0.21344793840281426, 0.1855353869858288, 0.14738359548632177, 0.18444806307313905, 0.22262697408516563, 0.2186017489481357, 0.1280360832630146, 0.12248465776323311, 0.1301657693881181, 0.17282899138667893, 50.360114728250814, 71.94785564176499, 62.97900322944888, 52.38252409042851, 43.206943158180486, 90.7451557344006, 76.62993400327622, 86.63711624760782, 80.31438889042025, 79.2405459188646, 49.754524307866255, 1.5357447151214847, 2.8339543698295473, 45.02291817818919, 81.66164459720736, 83.21193787359422, 73.8168336499122, 77.11505274618827, 72.47925835271036, 71.89592346068352, 69.06176782423451, 71.46374102561705, 75.62998064102666, 75.3295192410869, 67.84304034325385, 56.24607439964049, 52.838201522827156, 52.66849233258156, 55.659342735044426, 55.67804459602603, 58.114832755058046, 57.02839113050892, 55.70319875594109, 52.89561717740951, 53.38635275440832, 52.62425976414835, 53.28479474590671, 53.979775982518355, 53.59747432893323, 52.840519643598995, 53.36456006573093, 50.737678158667784, 51.8616960894677, 53.906663002506384, 54.1182238824906, 50.507458563773866, 50.785797795941754, 48.71256236107119, 49.83770208974039, 50.06428564748457, 49.12443868575558, 50.04701937398603, 50.137100527363444, 49.25026439851331, 52.83179629233576, 49.10077894887617, 52.99763018085111, 49.522778910975305, 57.18402293420608, 60.91669551787838, 59.24060790769516, 58.421652317047126, 62.53864265257313, 62.88731390430082, 66.97749091732886, 66.69355054055491, 65.1618218421936, 38.88049041071246, 57.04058970174482, 64.41653620812201, 61.51673578446912, 62.65996156200286, 62.45391553448093, 60.14045846077704, 63.790902476156916, 58.90315071229012, 52.33393376873386, 48.84011391670474, 50.96870183944703, 49.75515973183417, 48.38944535101614, 45.427812683966856, 48.8570781677, 48.40895522025324, 46.019227658548665, 46.36326266873268, 48.637378369608236, 45.546550673823205, 48.05672637877926, 46.24539152268441, 45.95442618093183, 45.79675866711525, 46.806266923104566, 49.213119552981475, 49.56537585104666, 46.25122016476047, 45.68787759350192, 48.57953125430692, 51.26120475030715, 54.27239264211347, 55.064601590556485, 54.22712849032495, 57.08086852104434, 58.149153494065814, 57.371649511398815, 53.75118809361612, 52.412185053671564, 50.64992689317273, 48.03755383337698, 45.858237897196126, 52.008482948426284, 48.03449438464258, 51.546717997520204, 47.351919604885964, 51.94190071475122, 51.37062318863408, 57.10446942237116, 57.868409848982296, 67.64609029216152, 63.36504682417839, 75.1613123186173, 65.01299142837524, 80.43502530744, 32.10273673457484, 0.7951010835747566, 4.7693594328818785, 36.87850483002202, 63.005569442625976, 68.2991413916311, 70.36269249454622, 71.88694123298892, 41.519515975829094, 24.708751247775172, 68.11155011576992, 38.587889440598026, 71.49865796489101, 18.268556748667073, 0.290310888160621, 0.1967325587306292, 0.16103882162321, 0.10225894830880627, 0.12265799281698082, 0.13243911998166194, 0.12475923409745579, 0.20068702798697258, 0.1397262555697272, 0.13519098441446983, 0.1827961170384961, 0.10214250294431564, 0.2282590226780984, 0.07976614719917698, 0.1065123833776001, 0.10964027440716183, 0.10681571589121897], [0.026062475892925457, 0.012023728904164126, 0.03400689959826489, 0.0707360849745812, 0.08570935772431475, 0.030491061643847538, 0.009466700740308772, 0.06359226145451108, 0.07195127662271261, 0.04663921449513686, 0.10231128743579311, 0.0036850904777360662, 0.0019826120865951867, 0.03283309585024272, 0.010987513589732831, 0.14090932515119353, 0.08448293522721337, 0.03932950995682229, 0.030881343221652414, 0.017375515721317743, 0.02304549141216182, 0.05245396739713127, 2.656543850898743, 72.57290101820423, 36.16819104840679, 45.23775031489711, 39.96946980876308, 38.883887183281686, 82.01272026185067, 65.70395223556027, 73.32057537571077, 62.53798761675435, 62.77880545585387, 8.826667474162194, 0.17190490548889484, 8.579620911229043, 53.6256879375827, 78.95272239562004, 72.11104193041402, 71.23141904031077, 68.97393026659566, 70.29076407032629, 71.97554757518154, 72.22444549683603, 70.36148440453314, 73.02556607031053, 65.01636466672345, 52.387862436233036, 50.82746905665244, 51.46174377010715, 47.1122000294347, 50.01179648983864, 50.096539297411525, 48.819388112714215, 49.52155120911137, 48.16995736091368, 47.85474784912602, 45.96143937879994, 47.717641399752715, 50.21009583627024, 47.82604394420501, 49.037122803349654, 46.689529342036096, 46.85578684653006, 45.905890772419596, 45.91471218293714, 46.532430571894494, 45.3895656524166, 45.083303066991995, 46.45504613076487, 44.45444906911543, 44.83068281604398, 44.421811026911584, 43.863998997596006, 46.78962430646343, 47.22297168547108, 46.27042408912413, 47.4587728131202, 48.44772000466624, 52.08524765506868, 58.98587349922427, 60.26204016900832, 60.04769440620177, 58.45111323941139, 58.25015844837312, 58.246459653300626, 60.6346849472292, 61.427231219507036, 64.70609341898273, 57.24991483073081, 49.01052521121118, 59.42387673162646, 60.0600734064656, 60.81243499632805, 57.464872483284246, 56.95023398245535, 52.791854796871064, 50.92375539964246, 47.72502722278718, 45.21116056749898, 43.611535641454886, 46.44059219667989, 44.112991056134625, 42.35924836127989, 41.123227150209495, 42.569126544460175, 42.807559582494925, 42.23927482481926, 44.92236037408152, 42.85474177329771, 41.42561051153368, 42.50626664007864, 40.46217441558838, 39.79443796219365, 41.541924476623535, 41.91746004166142, 44.23153292748236, 43.534986665171964, 43.00096381095148, 43.883967784143266, 43.17450515685543, 46.94600920523367, 50.82065589966313, 48.64525841128442, 50.65100554497012, 50.42948968948857, 54.594968365084746, 52.50960888401155, 47.61681295210316, 44.275973381534705, 45.92775798613026, 44.26562616902013, 48.097628854936175, 47.093090241955174, 52.35054892878379, 53.31715429982832, 52.703817198353434, 45.63911860988986, 49.13311889094692, 48.24215250630533, 59.389312805668006, 58.6639920357735, 67.18371345150855, 64.74608198288949, 76.69358622643256, 24.829974059135687, 0.3058143627018698, 0.08586091289837515, 25.917021689876435, 60.79628267595845, 59.98565819955642, 61.33056832898048, 60.734603404998786, 20.95818873374693, 21.34414799751774, 27.02145914877615, 36.13847517198132, 50.10563919621129, 0.556908474574166, 0.04534277922263549, 0.02531405778661851, 0.03668305156151614, 0.05824379562850922, 0.05350976679173689, 0.07720739054944246, 0.04100682499307779, 0.0718240064358519, 0.037782039162853075, 0.032115438089315454, 0.038563268814956954, 0.08530697004208643, 0.055849935574036454, 0.012301386938610626, 0.04201162591456406, 0.044463586077214255, 0.10222264340207463, 0.03937634091163355, 0.04287035685152777, 0.02419639296168762, 0.09269996365952878, 0.04707359783952275, 0.050929908250128074, 0.035706205188386866, 0.04356059441042524, 0.0487166112889686, 0.09464502259488068, 0.049284190510309515, 0.012429583134249815, 0.01202621007142889, 0.0763520687037418, 0.03522943419915053, 0.05530237039971737, 0.05976531519404343, 0.0546672566974115, 0.056323002528158896, 0.037416580749014695, 0.05672980670727069, 0.09185889871009896, 3.6427343516580524, 84.32774236125331, 38.679417948569025, 52.59783083392728, 45.17154070638841, 50.90379445783554, 92.09445107367732, 70.13106084639027, 80.73100736064296, 69.08785943062075, 70.63782322791316, 10.070102945450815, 0.25097100154286434, 8.519659638404846, 54.54907271169848, 80.65793360433271, 74.06390374706638, 72.71600477157101, 71.74815208681169, 74.81742243612968, 73.56422516607469, 71.93598654962355, 72.4143195921375, 75.55631852919056, 67.99653837757727, 55.71482073876166, 53.198545748187655, 52.563498327809, 52.2210204985834, 53.56212200657014, 52.434271920111875, 51.55175432082146, 52.22848869139149, 50.58262294338596, 51.2620049138223, 47.927068510363185, 49.98437912233415, 52.32716375781644, 50.12753386651316, 50.26917457580567, 48.75586140540339, 47.99237989610242, 48.6380490949077, 48.99719307499547, 48.02941491526943, 49.33914922898816, 47.85676786976476, 48.490811163379306, 47.109293553137014, 47.51368207316245, 47.58486916941982, 46.14570840712517, 46.33730834530246, 49.10974548709009, 49.08409710853331, 51.337643900225245, 52.40554055859966, 53.482282161712654, 61.340833171721435, 63.16033048014488, 61.72638254780924, 59.56348173079952, 61.599646845171534, 59.719952921713556, 66.11920572096302, 62.33478530760735, 75.44577044825401, 66.14607395664339, 51.28667662220617, 64.76075556970412, 61.11151964433732, 63.67954246459469, 59.479578310443515, 60.392788456332305, 56.811064366371404, 55.898889726208104, 51.17641487429219, 47.23593511889058, 47.506664952924176, 47.65478541774135, 46.35105233038626, 44.14450337809902, 43.35890362339635, 43.076583185503566, 45.486628624700735, 45.0953172868298, 46.359975722528276, 45.7267443595394, 43.96723578053136, 43.89196941929479, 44.20543347635577, 43.64552690136818, 45.46516541511782, 45.19113686776931, 45.56347570111675, 45.415119894089244, 44.78313976718534, 46.23900198167371, 47.79843045819191, 49.72068209801951, 53.244033475076, 50.81307788049021, 53.23822052248063, 53.95200952406853, 56.796531984882975, 53.42985968435965, 49.6629761880444, 46.063585742827385, 48.317524771536554, 48.044896510339555, 50.09735122803719, 48.12718391418458, 54.56632329571632, 54.72933700007778, 53.7313840466161, 47.294743214884114, 52.22080476822392, 49.76506763888944, 60.823139144528305, 61.7923842706988, 72.67099165147351, 66.35115115873276, 81.22261370382002, 26.279729143265758, 0.5221776640222919, 0.9388282486507971, 29.13097062418538, 64.6191187827818, 65.37476339647847, 65.76586684873028, 68.31056333357289, 24.682404687327725, 24.859793878370716, 33.91085916949857, 40.62968315616731, 59.27230458105765, 0.3434509753940567, 0.03630624738551917, 0.11307806332385349, 0.029648227031312646, 0.04672365653659067, 0.04280951031814179, 0.017308170847114057, 0.025508508138779192, 0.05070543299699503, 0.080471231542047, 0.03506736063788976, 0.06326408853994743, 0.10189007697326523, 0.03886333396357875, 0.04632229924262051, 0.025256909542687, 0.02905126642285576, 0.07275195341677436, 0.15391892302901516, 0.2827084461046804, 0.14278001993173553, 0.1998290554770539, 0.19128130688782663, 0.1505980391295687, 0.19979695639302655, 0.1618721567454838, 0.22812884901800465, 0.18308021308433625, 0.19374032655069906, 0.1237663305214336, 0.2074614515708339, 0.17393497720120416, 0.1111865232908918, 0.41475540567790314, 0.15230080743710842, 0.10833351226944117, 0.21919165197159016, 0.0991378831226499, 0.22409516627029066, 0.4237155087532536, 9.714623439696528, 102.73867330243512, 50.011447398893296, 66.3939206830917, 54.27646013998217, 52.02713774096582, 96.25571712370842, 76.87268164850052, 86.44365710596885, 76.43613753780242, 75.31393174202212, 12.052329586398217, 0.38764649581524635, 11.251007010859828, 57.11550304966589, 84.05168594852572, 79.15290447973436, 77.97570705413818, 76.22182707632743, 80.21857323185091, 78.37994652409708, 75.33216291858305, 75.50230749191778, 81.2306074942312, 72.21467879510695, 58.14465453547817, 55.02681739868657, 55.81500984007313, 54.16132680831417, 56.4935092772207, 56.1802884071104, 55.44560101724441, 54.809906405787316, 54.48220022263066, 52.64435014417095, 49.87913016350039, 54.469264245802364, 55.886012584932395, 52.05375494495515, 54.390236331570534, 51.47010234094436, 51.38564586639405, 51.86052330078618, 52.982383927991314, 53.464129432555175, 51.77309366964525, 51.24966905963037, 52.390215858336425, 49.92181339571553, 51.50388963760869, 49.4798211128481, 50.22651487781156, 49.95367873099543, 52.97847724729969, 51.783527174303615, 52.44961623222598, 55.05909850520473, 56.393951677506976, 62.363693175777314, 64.42772280785346, 63.36649417877198, 63.17223487361785, 63.04090999787854, 62.92136007739652, 66.40837069480651, 65.99212092737999, 70.24483311560847, 53.1394709310224, 51.49048297635971, 64.81171892535302, 63.56538972546978, 65.18137093513243, 62.93722998711371, 61.13998820704799, 59.083332630895804, 57.666756876053356, 53.80411263435118, 50.59863798079952, 49.024249584444114, 51.25678816149312, 47.71506048017933, 48.205905883542954, 46.14786571071994, 44.80825862576885, 48.831045396866344, 47.24809446642476, 50.78216960353237, 46.279625969548384, 46.23190641403199, 45.494045826696585, 46.30223843359178, 46.05446230980658, 47.44251066638578, 47.17896269213769, 48.161830209916644, 47.671322130387836, 46.82691035732147, 49.769747026505016, 49.931078034062544, 52.55987405776978, 55.76398372650147, 53.540917673418605, 57.65070653730824, 57.05608698629565, 60.553009433131066, 56.11758539753576, 51.57066798979237, 48.744208043621434, 50.857816434675655, 48.54730506097117, 51.83121142848846, 50.79129695892335, 58.26660102413547, 56.90243597953551, 56.479478959114324, 49.83579189546647, 53.56279665423978, 52.39868033316828, 64.99639195780601, 64.48013744046612, 73.29683719142791, 68.14374493014428, 83.5841158897646, 28.663435866755826, 0.7210171330840357, 2.7608499700023286, 29.576410670434278, 72.8741547369188, 69.27552130914503, 72.2500664188016, 71.10005886323991, 26.57463254467134, 33.380146795703524, 42.27974976262739, 47.20259497242589, 75.46385257474839, 3.4364289574084745, 0.29042169511798893, 0.17455740831792357, 0.11440656703686523, 0.12694429305772628, 0.18199675025478487, 0.2334260559009929, 0.14581202739669433, 0.24117596988235754, 0.24278588833347445, 0.17229470634652724, 0.201365843174919, 0.19413211923693457, 0.09989021976868953, 0.10479538115642725, 0.12019849817959533, 0.13881916150210366, 0.22970855296138795], [0.030672770038607623, 0.044265027578559615, 0.08359555260188158, 0.07508341177937485, 0.07898674466677251, 0.0029350722052772804, 0.02982321300453717, 0.04590660844358706, 0.11946961148491791, 0.007706703270800533, 0.03936524412805035, 0.03713151177151069, 0.1574207109309012, 0.02586825919758168, 0.013351322887765785, 0.052938089000001076, 0.02001844053607314, 0.027275756151685794, 0.0849929582628031, 0.013473599138970097, 0.02175325621670533, 0.08856204698883718, 0.04380202701976223, 28.45108855155207, 60.573492050170906, 37.3789208166061, 65.74889475299467, 16.036635944920203, 55.88284330983316, 74.75977928407731, 72.94010546899611, 62.78921542629119, 64.86545931908393, 26.14332087578312, 0.1395570880342876, 0.3261953964829445, 18.59444687443395, 66.31145677258893, 77.219709427126, 72.31451880547309, 71.72573966364708, 73.4194818619759, 74.85942317593482, 73.90204321953559, 71.63089675288047, 70.11623428713891, 67.85308161089498, 53.64706093265165, 52.63470111354705, 53.165099697728316, 51.369309194626354, 46.571740565761445, 50.237097432536466, 50.49536589653262, 50.49977856297647, 48.432230564855764, 49.80894327163697, 49.66086595289169, 49.03908006606564, 47.03235626220704, 46.49219489866688, 47.976611968009706, 47.56270777794623, 46.491779127428615, 47.68389724916028, 45.44946416731804, 46.285348707629794, 46.72754495374618, 46.67740921820364, 45.872950707712484, 43.22458205684539, 43.39653876519973, 46.04334239036807, 44.454025453136815, 46.3473770695348, 45.99449319224204, 48.014709949493415, 47.225089765364125, 49.771676832629794, 59.34835541632868, 63.7576093981343, 63.976634548556426, 62.36793718030376, 61.633571424791896, 63.0575212355583, 61.00722774382561, 61.4194296252343, 63.34779231779037, 62.54301217294509, 65.28701213098341, 57.30081150608679, 57.54571645490585, 59.06780788975378, 57.091015692680116, 56.04583347997358, 52.291093641711825, 50.773987539352916, 48.517534271363296, 47.966076481726866, 45.34925153178554, 45.60815934211978, 46.319022255559126, 45.36427028717534, 45.17824795938308, 42.79001089834398, 41.45907225147371, 43.30874827600295, 42.7236012489565, 43.299244373075425, 42.69339899862967, 43.172108588680146, 42.10116424868184, 40.669518747637355, 40.870159749061834, 39.47751045227051, 43.96720047919981, 42.56223886243759, 43.26011873060658, 44.95876389165079, 42.057849514868956, 43.976924034856985, 44.84455231697329, 49.156551130356334, 47.120562522642075, 49.430744417252086, 50.41689103649509, 54.4290481844256, 52.546949848052, 50.05753132604784, 46.924561685131444, 47.70379935541461, 44.69943638770811, 50.46390456538047, 58.1413205208317, 64.55690214710852, 62.64499771979548, 60.5472239371269, 56.91940807527112, 52.4280628081291, 47.90840979545347, 57.65740202319238, 57.196778482006444, 68.14387829073014, 62.48917371995988, 78.93324390534433, 16.361603333104043, 0.7428025898914183, 2.9197351346092844, 29.95511551057139, 64.91111178551951, 57.45165017343337, 60.77412128448487, 48.05795015827302, 13.425929892447687, 43.92660394791634, 40.09131039342573, 46.15325112496653, 32.14167410327543, 0.08868623750224229, 0.05001999114850356, 0.06737478227624971, 0.04887089373603944, 0.09751343198360936, 0.04989322274923325, 0.08739051469151052, 0.020259827180134676, 0.05027747329985423, 0.04024485862182994, 0.08805297390227357, 0.005212365518203907, 0.03616110053694537, 0.06542575500545002, 0.06422562464590996, 0.02445959587461285, 0.02160524994495415, 0.01169748557355976, 0.0340552780506832, 0.039777403261752865, 0.08456259304958005, 0.12402879990517132, 0.0859417811396622, 0.025034223104857152, 0.06232314870782918, 0.010447805604687142, 0.09194864591042842, 0.03211488076035054, 0.02057236615538357, 0.07979233208442889, 0.015085098604040762, 0.04985964511551204, 0.030166993045338222, 0.05343777750949225, 0.005559613064472234, 0.054742375448826826, 0.0320281078963871, 0.035100447975339434, 0.03139308037897272, 0.07822411945990979, 0.034195698136764194, 33.506564786357266, 65.8976859431113, 38.60381426349763, 76.64403100167551, 21.204209596880023, 67.48033877341979, 79.21245390369047, 78.00909426904495, 70.3846263885498, 69.18219243326496, 29.51951865226992, 0.21770682035674974, 0.2369744066269167, 19.00592507854585, 68.03788015919348, 79.98494117490708, 74.49591359784527, 75.39071606051537, 76.89703172253024, 77.23661484256868, 77.32117329874347, 75.11203165977233, 73.06394254007648, 71.2871402309787, 58.10321861697782, 52.94771017566804, 54.30251252266669, 51.89968816695675, 49.46720284800376, 51.59364131189162, 53.642844384716405, 51.49397388581307, 49.15682569626839, 49.771033563921534, 53.322131787576986, 50.59138944072109, 49.62090876794631, 48.25886572560957, 49.67571604636408, 49.33887858544627, 49.673978436377745, 48.65675095588931, 48.91367012454618, 47.91503075630435, 51.4142870133923, 49.56577201043406, 47.07567099601992, 46.84184674293765, 46.114823664388354, 47.6914595788525, 46.65179221860824, 47.33873651873681, 48.804443882357695, 48.09535388023623, 48.83060216903687, 51.887395458836714, 60.758584776232325, 67.01970346512334, 66.53331387427546, 65.61985661906581, 64.48540910597771, 64.655020236969, 61.18051413566836, 62.37881783516177, 64.71385186718356, 64.27116532479563, 77.66926796205583, 63.7939933038527, 60.79683180778258, 63.765050134351185, 56.87422237088604, 56.83885043667209, 56.10417481391661, 53.39092623802924, 51.538316280611106, 49.03132946260514, 47.99782414590159, 47.6071011635565, 48.022213443633056, 46.84232527209867, 45.67167428232009, 45.07643499682027, 43.29430218665831, 46.0951647450847, 45.33647244976413, 45.77339703036893, 44.13435620646323, 46.59201921955232, 44.70122498850669, 43.1631891189083, 43.948777106500444, 44.01869727719215, 45.371922831381525, 45.17285077802597, 45.80774130359773, 48.07243547131939, 43.60894687714116, 46.9037260547761, 48.3248439142781, 50.36103648524131, 50.4227549799027, 53.573740067020545, 53.83052979746173, 57.32960562552176, 55.73202033196726, 52.52169762888263, 48.92944197500906, 48.827460350528845, 46.132615535489975, 52.10430252936579, 60.17919578859883, 65.88128259105068, 64.11679652429396, 64.1342902952625, 56.935270140247965, 56.2068977663594, 48.745702466657086, 59.497158373555834, 59.53061619112569, 71.69385079414614, 65.17152578599992, 84.00901840579125, 16.790535103890203, 1.0076249054362698, 1.260910120702559, 33.891835674162834, 67.17386830237605, 61.57835229750603, 67.5189741196171, 60.17124514425955, 17.534220410931496, 52.53684974485829, 42.13685389487974, 51.69202220055365, 35.33925694804038, 0.3096919320523739, 0.11805022676144877, 0.08871523393017632, 0.04403025610372425, 0.049571753104007056, 0.0743711262100166, 0.12888526874444178, 0.07161884042885035, 0.07249362090782774, 0.045382573659862244, 0.05575600170320081, 0.02182337049875529, 0.01732916548667896, 0.036916666243585854, 0.05220832513465036, 0.05228001947304415, 0.03532642476080406, 0.012986616197703107, 0.10133392012287533, 0.1318966990877544, 0.2693540626956571, 0.3259325976813993, 0.23073279719439246, 0.17992478885477592, 0.20834715646361152, 0.21142404135917464, 0.3118400425920564, 0.09793998973984873, 0.11566383989467738, 0.17287451233113968, 0.2028269873511407, 0.11049859165664642, 0.10935005731880666, 0.15972375509239015, 0.11559830873363441, 0.12811442341415152, 0.26821718821602486, 0.12084817904378138, 0.10788917361247925, 0.16847644752312094, 0.136968323720559, 48.75432383629584, 79.32817166851413, 53.25983278213009, 78.81530607900312, 24.054707788651992, 68.72771524613904, 88.98003424367597, 83.56145243490897, 77.6392775197183, 79.20009059290733, 32.93033330671249, 0.34298366176024564, 1.0373155316037517, 22.82509376925807, 72.35428379428002, 84.60797217584427, 78.74543297675349, 78.87039969044348, 81.4190616915303, 80.53504574683406, 80.26568089762043, 78.2241892045544, 76.90249166181012, 75.74248990704938, 60.727456846544825, 55.50728028820407, 56.46478183807866, 54.411091573776744, 50.57539401515838, 53.58478546142579, 56.76339972403742, 55.81860273115097, 52.56214118772938, 52.989444194301484, 56.52031083260813, 54.048142894621826, 52.6362386826546, 50.66206270648588, 54.10732361578173, 53.07556767617503, 53.04685984888385, 53.78168059933571, 53.47829703361758, 51.40787001579039, 53.98297271420879, 50.825013652924575, 49.83465048574632, 49.6336760828572, 48.32614614117531, 50.00737205628426, 48.88575461602981, 49.205094383608916, 50.73069241739089, 52.54235675258022, 52.477861219836825, 56.0172394014174, 64.0773335579903, 69.30388789023124, 68.9829360285113, 68.01706806305917, 65.5664025583575, 68.14277218234155, 64.30628230494838, 65.16297501902427, 67.47595356356713, 65.5560867248043, 66.3934107749693, 57.68174425248177, 61.33964469355922, 66.6666744601342, 60.359613049414854, 59.178889413033765, 56.346530222123675, 55.37934041792347, 52.33742075581705, 52.73895379035704, 48.88318546356694, 50.775419204465805, 48.78700502457158, 48.60964329011979, 48.726733884503766, 48.89311298247307, 45.541043666101274, 49.123446326101984, 46.84517683521394, 47.43523859208631, 47.78177607444025, 48.99491025555519, 47.019330070864775, 44.62204017946797, 46.844137407118275, 46.72269298184303, 47.248137612496656, 46.95847449764129, 47.77536299920852, 48.20575291110624, 46.17998992243121, 48.65380917826007, 50.28347945982411, 54.95956836208221, 52.341837344631074, 55.93540699251237, 57.15299698614306, 59.19381403153943, 57.3809886747791, 56.58607721328736, 53.53815240244712, 51.28226787813249, 48.30225498445573, 54.95940362253497, 63.89003253752186, 68.24805644250685, 68.57177749756845, 66.55262762500395, 61.457198127623535, 57.36140428050872, 52.276439666748054, 64.06520558941749, 62.67736119608726, 76.86509578458725, 66.0826413862167, 84.367797605453, 19.637230557780114, 0.7559547260884316, 7.784729551884436, 35.90458423860612, 76.33493254261633, 66.95382333570912, 74.41339477416008, 58.225008210828236, 20.697937511628677, 59.33200697745047, 53.131618345937426, 58.31211620761503, 48.8290959788907, 0.3777432159310387, 0.13076337925609083, 0.20732511856382896, 0.17314776057197204, 0.24484629712758527, 0.0992708606645465, 0.15547451052454211, 0.21120990446257978, 0.1359408006312386, 0.15332863696159857, 0.15939115035918452, 0.186182547420744, 0.07927253376692533, 0.19566429508549554, 0.1792366733594287, 0.11703848508336853, 0.12409368755235789, 0.11966902417160812], [0.011561284716721746, 0.05540612934818191, 0.08946984585735107, 0.06150171476145906, 0.05472149572245056, 0.059255843741759184, 0.05545268068090082, 0.043847777790600256, 0.012943502684544413, 0.09057685056881559, 0.025685621921213406, 0.03515362213816374, 0.028855481162487023, 0.014593663734323798, 0.04753728021657275, 0.04953180544919545, 0.06832141414164536, 0.03432357736352471, 0.02056264066918483, 0.015115811068925167, 0.07454181059954629, 0.016433296522365946, 0.09742399887932886, 3.0439732680397653, 61.94853774962887, 37.11682411932176, 33.68132598938481, 25.354779343451224, 24.047673017747943, 81.85854757985761, 64.64750889808901, 61.038308605071045, 69.87452999238046, 44.641095053765085, 1.585047069576479, 0.12687346822912657, 1.744721856328749, 33.534213573701926, 61.447129403391195, 75.26314489303097, 72.43797932901691, 75.27031498570597, 74.2553311009561, 76.46790873619818, 73.81367221955331, 72.05527367130404, 63.1235308031882, 54.17528260138727, 51.528800610573064, 52.84395563986994, 52.33405143983903, 50.64320002832721, 48.54508892182381, 47.571921425481, 49.467936331225985, 49.801663352597146, 51.15719918281802, 49.74308667644378, 49.7540928471473, 48.09701696518929, 47.10063295979654, 47.22889838680145, 46.99208136527769, 50.28098091002434, 48.23366841962261, 46.83877552709272, 46.587912497981904, 45.249125188396825, 44.35321661733812, 45.81837092676471, 46.32289755728937, 44.426192314394065, 46.755334946417044, 44.261821469952984, 44.60005921702231, 47.38551470541185, 47.71178137871527, 49.11865318975141, 54.650097277856645, 57.78740506018362, 60.19825850763629, 63.24186086654664, 63.243653389715384, 61.82688151636432, 61.22123226042717, 60.7019143719827, 62.58692702939434, 62.13892567542292, 64.48418140411377, 62.08167868275797, 62.48720861250355, 58.17005972708426, 55.82364689919257, 56.43061014913744, 53.294357484386815, 52.604228219678326, 49.686420194564334, 50.3525798551498, 49.2626198645561, 46.77758655240459, 47.41307720061272, 45.07259891879174, 44.622589311292096, 43.77674587311284, 42.16131771764448, 44.332290772468816, 42.233728593395604, 42.573139129146455, 43.13563839081795, 43.6465153386516, 43.26765360370759, 41.37341553165067, 42.72951618317635, 41.3359921978366, 41.192986503724136, 44.397794354346495, 44.14765696371756, 44.277095179403986, 45.74983143037366, 45.25433017361549, 43.682083391374164, 42.208429305784165, 44.97718334197999, 44.39018887858237, 46.80174835266606, 50.909878053972804, 52.21998891522808, 52.65170851061421, 52.74443334148776, 45.794503304266165, 47.52061290125693, 48.19897897781865, 58.50595189679054, 61.91945337480115, 63.64405678164575, 64.01173191685831, 65.41137479966687, 59.70584807857391, 61.27192497253419, 50.66215684337001, 57.29617526454311, 62.71746743109919, 66.85989825956284, 62.45240934433476, 76.90388018085112, 8.356981296693126, 0.8918739843272394, 1.9989515047880912, 29.473619076513476, 66.30478089855563, 59.27308513272194, 61.1057851391454, 13.153698771230637, 24.08931878305251, 46.51102619786417, 34.85726825652584, 61.39619742670367, 7.858358813870338, 0.29213736434617354, 0.07454496688179432, 0.01333011374358208, 0.03104780838193913, 0.16909380713778158, 0.06986440715169714, 0.022596655819084377, 0.011855968097675473, 0.04328715081717219, 0.045755620174590624, 0.0781433508100529, 0.06803196314121447, 0.0358494253258311, 0.10243498765292669, 0.03189101071667767, 0.016074702256329117, 0.01951225751620387, 0.02315212702078204, 0.037082826883922664, 0.04640474562503157, 0.0745173647338825, 0.03210183619821985, 0.026823777682898987, 0.016476452170360475, 0.033540352052378083, 0.008004381576733244, 0.054684792449998285, 0.04636856712280743, 0.02681487382599904, 0.03259604526383262, 0.03222178066930464, 0.03290890025035028, 0.044094561524088347, 0.06154605976095604, 0.10322344534459615, 0.08496603027226464, 0.028318394155752276, 0.0604373160299034, 0.0771890350827767, 0.04304982443910934, 0.055028340749202244, 3.532977854051898, 71.17884359052105, 38.87694066570651, 43.830803978827696, 32.08129509802788, 28.742577529722645, 90.47455926095286, 76.58474829889114, 69.98800416146555, 73.6994920238372, 51.22644078346991, 1.5122775421027215, 0.17138721391318307, 1.5980456817534663, 34.698020027529815, 67.77345749639696, 78.19947827246882, 76.0217155948762, 78.34956384474232, 75.8785883072884, 76.85813749990156, 77.35370543695267, 76.23562597459363, 65.59896215315788, 57.67423683597196, 54.870024573418405, 54.68737940634451, 54.47814841424265, 54.86720046689434, 50.31539578591624, 50.209252526683194, 52.45820230053317, 51.809257922634, 53.346748582778446, 50.469133084820164, 51.316663142173525, 50.368669417596635, 48.860372958644746, 48.31251982719668, 49.59612723319761, 52.098834745345584, 49.733649453809186, 49.68583968377883, 48.44507240479993, 48.25971687993696, 48.743674601278, 48.68163447226248, 48.39951015287831, 49.5780372619629, 50.06855710860222, 47.29379007893224, 50.41309025979812, 49.01938584543044, 49.85152452222763, 52.736635669585205, 56.22041033160303, 60.52579210650537, 63.185798429673724, 65.30447452299057, 66.17334227408132, 64.11053249912878, 64.47255549892303, 63.05295559667773, 64.50753911848992, 65.27418990289011, 65.08037382556547, 67.31843902218726, 70.69878470513129, 61.236972731928674, 59.670138820525146, 57.344287057076734, 55.62359425329394, 55.96997876321116, 52.79195285612538, 51.97051832752844, 51.545968824817294, 49.386021552547334, 49.2555360640249, 47.71945353477232, 48.580417709965865, 47.14044893941572, 44.37487594542965, 45.53758021323912, 44.110512118185724, 44.85069082629296, 44.756208773582216, 45.21432592022804, 46.153541380359286, 44.58074154392366, 45.43730874215403, 43.74514725900466, 44.69431377226307, 46.503738434084006, 46.9873627539604, 45.800622201734974, 46.80570210179975, 47.61130594438123, 45.893021475884225, 44.98500454810358, 47.94890042274229, 46.40228632957705, 48.81383403655022, 52.49637480705015, 54.78996115346109, 56.34846395061862, 55.40674209594727, 48.61977084990471, 49.55789196875788, 51.55266431070144, 61.8904866710786, 65.54766147367417, 66.22601970549553, 65.39130010912496, 67.62311304769209, 62.416174488682906, 63.29855480501729, 53.91498234964187, 59.52679972494803, 66.10852902935397, 70.55814420023273, 65.32178002019083, 79.38023721018146, 9.5104326932661, 1.050774164257511, 2.3875359373707927, 32.59913621410247, 70.99791249921246, 64.62369618877288, 67.3327007601338, 22.70374740323713, 26.94100937535686, 53.903325065489746, 37.223912669766335, 68.03245944361534, 7.709498001683143, 0.4884246268099355, 0.09423942500424963, 0.06254825215306013, 0.007150603398200005, 0.005894270434509964, 0.06852337790112342, 0.07451905778819516, 0.07243706829725735, 0.048527318623758135, 0.03796385097948294, 0.04206789507260246, 0.02390057385538615, 0.012487962864519609, 0.03882837354115421, 0.030371013750892975, 0.03950733811624589, 0.03285682542369731, 0.0386711799599711, 0.12604688234146566, 0.1602879788486227, 0.23666096941357662, 0.1510478859587062, 0.14505740014776108, 0.12864862418463155, 0.12977434442408625, 0.13632312447073, 0.18899862534336506, 0.18601069857756938, 0.1250055237042327, 0.20547906117093181, 0.18068225062902898, 0.1166749687024182, 0.09583789044089856, 0.12860604501780004, 0.2167539295530127, 0.17333140716918055, 0.09460123300912882, 0.19092153667682604, 0.20365145117525132, 0.1799074139806532, 0.40546625251731566, 9.500611078354622, 87.01129467256608, 51.32361750448904, 51.2397611525751, 37.63295312081614, 34.28138194545623, 96.12133672160488, 79.5711781901698, 72.82079481309461, 84.64937671538323, 55.227226980270885, 1.8491366986305484, 0.26365841348325053, 3.507682243662496, 37.8720647288907, 72.05845863588395, 81.85204429011192, 79.55160556300994, 83.35339423148864, 81.04747203088577, 81.17939702926144, 81.94556143976028, 79.57956421759822, 68.38589637510239, 60.21225744678129, 58.09394221152029, 56.761693493012466, 57.90945745283558, 58.41735339933827, 53.814581440341094, 53.74768149468207, 55.100808989617136, 54.45479462223669, 54.48979000891409, 53.72715573157034, 56.235837013490745, 53.221793636198974, 50.68516938917099, 51.33612594296856, 52.26949314917288, 56.20438352707894, 52.856766100852724, 50.88170759139523, 50.56265023446853, 51.50443876943281, 50.075997844819106, 51.07043243223622, 48.86176540005592, 50.20437702055901, 52.030605116198146, 50.978923536116085, 51.327112336312574, 52.35424772385628, 51.85607533301077, 55.850464144060695, 60.338055702947806, 63.946600960147, 64.86091721442439, 66.1593629467872, 68.40305282223609, 66.64103784868794, 66.68534494215443, 65.26658834949617, 65.29351934309929, 64.92962929510301, 69.06548623115786, 67.49445146129978, 66.8088839131017, 63.2138119974444, 61.30282932712186, 60.320408959542554, 58.65126002219416, 56.86095691496327, 55.71717023849488, 55.91730525416713, 54.356429423055346, 52.68186369249898, 50.934141835858746, 49.08381077551073, 50.101320666651574, 48.71475888836769, 46.060714567861254, 49.07653085647091, 47.16196706218105, 47.4636757758356, 47.922769592654326, 48.794602655595355, 48.92502538619503, 45.909919046586566, 48.84489136357462, 45.97170814391106, 46.95954530469833, 48.41447791745586, 49.27656389051869, 48.447366991350734, 49.31643870569045, 50.57751209505143, 48.92932430390389, 48.20403883534093, 49.126211597073464, 49.61326014611029, 53.49819913987191, 56.41074334421466, 57.85597201316588, 57.42169111005722, 57.5076537747537, 48.49535326803885, 52.24018912161551, 53.34959622352354, 64.14177417755127, 66.71222886731549, 69.26326782472673, 68.24673068138861, 71.50549073373118, 64.3248272711231, 67.83172038293654, 55.99593308664138, 64.78621175212245, 69.9123259513609, 74.0084178986088, 69.0491299475393, 80.28461810081237, 11.446498920840602, 1.0921628917417219, 3.4859459390563354, 36.61669054339009, 78.74662537728587, 67.7067615139869, 72.94993492864793, 20.365583319817823, 36.65998174298194, 65.84659314924671, 46.780646001139, 78.19772889537197, 16.459098746699674, 0.6687031950681441, 0.37672790428323133, 0.12471566667720196, 0.1413871035460503, 0.23966905961353935, 0.1654467536436935, 0.15699999076464485, 0.212646487859949, 0.14022064275078236, 0.1916489831262058, 0.20848128313739456, 0.13396921207106885, 0.11099435013508606, 0.24939096052079435, 0.30040228859551493, 0.0630572103264351, 0.1285550848490769, 0.15737552706512714], [0.0484189095215932, 0.00801302352732408, 0.014934875465358698, 0.03778532568004824, 0.00782500735611745, 0.04225081771672253, 0.028991352601517594, 0.09862927734972009, 0.05757634535491948, 0.06582205228868031, 0.027545066700587352, 0.014368909816708297, 0.034829835076966596, 0.032832823889029604, 0.08992501699756231, 0.021274349757380063, 0.02862655685373372, 0.03826802235937888, 0.030949774025488767, 0.05119251552969218, 0.04502056264168313, 0.00591186651652078, 0.08493848941138676, 0.12511078418502886, 39.11345174235683, 64.17087816422986, 29.127205148819957, 38.77921481286326, 19.99024779565873, 60.385677199209894, 53.46301940179641, 64.32851822145524, 70.48803575577276, 59.77100649187642, 6.173727791155539, 0.0770786264911294, 0.18879559672167226, 4.965269565582275, 32.00190240337003, 70.86754075942501, 73.66004866938438, 75.85701527134066, 75.2714289388349, 77.12583141942179, 74.98161285154282, 68.38478242197345, 59.97174555255521, 54.47113129400439, 53.762876756729625, 53.16191865551857, 55.74550151824952, 50.74012571765531, 50.927116870880134, 51.694709024121686, 50.64887569796655, 51.55653176769134, 50.123015296074655, 49.91339598932574, 50.09329941964919, 48.492042787613414, 46.14915224813646, 48.165038708717596, 48.809170338415335, 49.17795158201649, 46.59663977161531, 46.37139374209989, 48.160959443738385, 47.95613719571022, 46.06992429302585, 46.52300903874059, 46.865063251987586, 45.28518353739093, 46.28741187434043, 46.06146766293434, 46.04385622086064, 46.949962954367365, 47.2687614348627, 51.80043651211647, 54.73851142391082, 59.781549822899606, 59.55940246582032, 60.64770329383112, 64.87081727673932, 62.362904779372684, 62.95468453438052, 61.6450325904354, 64.27584079004103, 62.33995499149446, 62.00079548743464, 66.09276110126127, 61.486278580081084, 58.44659074660271, 57.15447964206819, 54.601726608891646, 54.93219806301979, 51.92416767920218, 52.039128426582586, 54.54182024924986, 50.36352719030073, 50.47775445445892, 48.26642021056145, 45.22257466470042, 44.51000552023611, 44.74253146879135, 44.31046670483005, 42.37881706606957, 42.17375555346089, 43.4263095548076, 45.621252213754964, 45.023118219067975, 42.51518610985049, 45.971841504496915, 41.50041011071975, 44.468216588420255, 43.11670903236636, 43.82127654167914, 41.767962824913766, 44.315283375401656, 43.17145355286137, 44.40105384395969, 45.50578155825215, 45.19247047362789, 45.301610423672585, 45.1884029757592, 46.0784476034103, 52.05122893856418, 52.51411176496937, 52.23897318686209, 51.45423635359734, 47.5379458550484, 46.704293143364694, 51.12155660506218, 59.45952323175246, 63.50753868779829, 66.71951663109564, 65.06471964620775, 67.52023712281259, 62.398829767780924, 63.245057598237075, 55.651195972196525, 60.109016741475756, 61.32734414069884, 67.64041854489234, 65.23438569038146, 62.850004319221746, 2.470971860231892, 0.750388086082474, 0.5604468201917987, 36.28583861935523, 55.182300152317175, 47.65165536634384, 36.09186564722369, 5.730335712432862, 41.88665374632805, 33.44906283963111, 45.094018982302764, 38.092066549485736, 0.3244621685195354, 0.02742307294430512, 0.011155154694983316, 0.05769407008624366, 0.08079056763240407, 0.05859848667657184, 0.044048638383467356, 0.07957852460564145, 0.05106821010309843, 0.009048482808735102, 0.03447333223096306, 0.05188031309855081, 0.061554682080543814, 0.046343320695262764, 0.09028357678964254, 0.06687838794483293, 0.026312519330531362, 0.03701092570178932, 0.06267855221766137, 0.06943068647336575, 0.04836495011864651, 0.05843755458631824, 0.0130934797174808, 0.10490618811379518, 0.04202957152419033, 0.07557613654963433, 0.010919484982056724, 0.04015681979757163, 0.03869338884889599, 0.007863888233494496, 0.02888387812662029, 0.04353534032200133, 0.040443156650590326, 0.008470805590942262, 0.01388864642414715, 0.04339511175790141, 0.0486920390187973, 0.03373182423773312, 0.019136236665109475, 0.03140051143183824, 0.01209460065564922, 0.06178366576111125, 0.37368439017764987, 47.27738280450144, 70.33262360480525, 31.646798464559744, 47.75400569362026, 23.335684384069136, 69.3831511466734, 63.844638947517645, 71.07619516311154, 76.66088150393578, 65.27906540901431, 7.56403249117636, 0.15650742687284946, 0.7279277977443511, 5.134180553497807, 37.01562304650584, 76.7596467848747, 75.86330675309705, 78.40290807908582, 78.63717555999756, 78.51001231901108, 76.3130614065355, 70.88974137460032, 64.0419694685167, 56.243007106165734, 55.259049169478885, 56.49891430331815, 58.567313455766254, 53.59660356275497, 53.60605647487026, 53.71507875380978, 53.709018691893554, 53.159431872829316, 52.06221549741684, 51.0215675446295, 51.98040662273284, 50.513110699192175, 49.63348388671876, 51.468953086483864, 50.13881852549892, 52.09874060846145, 49.756575707466375, 50.10785533535866, 52.621965177597545, 50.024501046826764, 49.85028505325318, 48.48222901744228, 48.726337725116366, 48.81568931764173, 50.12171699154762, 47.63692294397662, 48.109541093149495, 50.45445557563536, 49.84568803541122, 54.00620491273942, 58.034216280906435, 62.370090561528365, 62.020677981838105, 63.4807018310793, 66.75136627689486, 66.35593645034298, 66.68871818050262, 64.63408262498918, 65.68064943436654, 66.06232350872409, 63.810122090001265, 68.80342483520508, 64.24789390256329, 63.29300072885329, 58.811273113373794, 57.572286590453125, 55.95763506427888, 54.96847998711371, 54.83665304799234, 57.52765394026234, 53.78441056897564, 52.086624406999164, 50.958370316413145, 47.85287687855382, 46.86088592775407, 45.805129005062966, 45.863321288939446, 45.191203548062234, 44.878206253051765, 46.712102582377774, 48.09676593349826, 46.85824225025792, 45.1047388199837, 47.63264363811862, 44.297346376603656, 46.94777427181121, 45.422713602742846, 46.101448382100756, 45.97960387506793, 46.16855229100874, 44.8890398394677, 45.30097892207485, 46.386259525052964, 45.31694689104634, 45.71797393983411, 46.672572935781176, 47.66550133305211, 54.08891201019288, 55.58546881521902, 54.71750713163807, 53.84155950238628, 49.182101449658795, 48.61201240170387, 54.23269041122929, 62.1039616677069, 67.08195932449834, 69.27914557918426, 66.65159686919182, 68.53716650316792, 65.19260852567612, 67.56874899710378, 59.05276167777277, 61.63039038258215, 64.80094417448967, 71.2229702549596, 67.03060765420237, 69.93527966160929, 2.2834935976612956, 0.4042746793598898, 3.2285916324584716, 37.42771902391988, 65.0407971105268, 51.6852992580783, 45.219279873755674, 7.944984359125938, 45.26543832594349, 36.17208988435807, 48.288911081129505, 41.18342376524403, 0.6871668333488127, 0.19631907043437805, 0.08361326455469094, 0.034197594204376784, 0.012075176496329087, 0.026593792342370557, 0.07142056921316732, 0.056467230071223555, 0.03331355172239485, 0.011111002175077316, 0.06828854130881448, 0.035335889777108546, 0.007652644276423681, 0.014328995678243379, 0.1114267378204292, 0.02494149199206262, 0.08102981689115686, 0.016492727708311814, 0.08560723054312891, 0.19230265530847734, 0.10362641525364692, 0.1529855674673473, 0.10688209740985787, 0.27210284745500934, 0.12308861850009811, 0.17310662165043816, 0.13835434531492574, 0.1354898659572486, 0.1743484501756968, 0.21174513945175757, 0.11810494842188013, 0.09501942508523503, 0.12178939466755237, 0.2087241023658745, 0.17108205044942518, 0.15484244202173528, 0.45547432716815706, 0.12830159401581173, 0.09184176132323281, 0.11041085160667859, 0.22856974794018656, 0.1845185125186559, 0.5237076948246648, 63.5354345844638, 80.93530793343821, 46.30029686035649, 55.01069253490817, 29.287224123554846, 72.08296560472058, 68.98559539548813, 77.22158432006836, 83.43294774332355, 72.11055555651265, 8.227810782770957, 0.13535408453354913, 1.3789905006847074, 5.653923528809702, 42.843445347201445, 82.30483485806374, 81.48567138179656, 81.3220928561303, 83.70622711796915, 82.50602891368251, 81.44025033520114, 72.29872734315934, 66.7071533203125, 60.70573476053054, 59.31721179716049, 58.57056902300928, 61.53890109831288, 55.85025625844156, 56.624257564544685, 56.81999952562394, 57.840372746990575, 56.885801207634714, 56.85916831416469, 53.779582131293516, 54.06468352963848, 54.07771364335091, 50.810485193806315, 54.69100367638373, 54.68708130621142, 58.029066208870184, 52.19229698181153, 52.82587743574574, 55.197224770822835, 54.273545818944136, 53.51532420804424, 52.64251447493031, 50.77218717144382, 50.52269697189332, 51.746158753671956, 51.705169985371256, 50.10476843003304, 52.23991847807362, 52.52467078547324, 56.813574683281686, 60.27336797406597, 65.23330311621389, 64.18611264997914, 65.0662140692434, 68.37070111305484, 66.1481685023154, 67.13041628560713, 63.54141227660641, 66.5410017198132, 67.17750826189595, 64.16420229019658, 71.72786558828047, 65.90862935589206, 64.97129663344353, 61.46627841457244, 58.55389894977693, 57.92617459450999, 58.02299045747327, 56.57168603712513, 59.89458468652541, 54.83063220977784, 54.84856136383549, 53.56753095503777, 50.416628237693544, 48.49610636311193, 47.551325059706166, 48.79648539327806, 46.93263784531624, 47.835006560048754, 48.30455741574688, 50.78209507849909, 48.85300674746114, 48.67192268371583, 51.47719790858608, 46.37320979948967, 51.43191022257651, 48.09150995746736, 49.04137073024627, 47.825377141275716, 48.399639591093994, 47.16909400878414, 47.29440981341947, 49.54704661523142, 49.401546293689364, 49.91209768479871, 49.221729155509706, 50.51816663434429, 56.87582269791634, 58.53647185910133, 56.57039165496827, 58.083602843746064, 50.2972234449079, 50.81814166038267, 57.30449853404876, 64.02737825147568, 69.79732990264893, 72.71625580326204, 66.47979705564438, 68.86633965276903, 67.67895975420552, 69.64609899828511, 61.12909970744964, 65.69661740333804, 68.40707717403289, 75.33367695346956, 68.28871573171308, 72.49475171489101, 3.30795074182172, 1.5634139723354772, 3.1791982054710393, 43.105145885098366, 69.53120493119764, 58.14729429060414, 45.24674038733206, 9.206505879279106, 61.50034027714884, 48.82636600925077, 58.03272185787078, 59.91556544457713, 1.4851127997521432, 0.4073012476005862, 0.23586315012747244, 0.2895052088124137, 0.10147140992264594, 0.1528525592819337, 0.1480241982086051, 0.21436278528023153, 0.14755547497301333, 0.05849931276433411, 0.14381256855783925, 0.14203656224473832, 0.13413094855364294, 0.14962250276678993, 0.30572941887282556, 0.17954563661929102, 0.11812184066061052, 0.085297585465014, 0.19200496886286045], [0.03628129207138573, 0.023449229324356686, 0.018772501949100726, 0.028056363357351195, 0.056017712659893505, 0.016226592593856396, 0.13341258790704513, 0.015480252501044064, 0.08163950796569548, 0.060933400095710834, 0.022466790509380163, 0.015086960197696763, 0.06931616398956507, 0.01296275255886177, 0.06404660905020372, 0.042471558291224704, 0.09411786983330404, 0.05733369083534326, 0.03602081834669075, 0.05133831738344124, 0.03483216398425641, 0.0034905627985755286, 0.03532351745713142, 0.10291435951066595, 7.8784035963396875, 68.37075602623725, 36.700852840177475, 45.923541438195016, 24.099073717671057, 30.726445682587165, 70.65352055334276, 71.03285297270745, 71.30552830234652, 67.88677477067517, 19.26541732203576, 0.3142177956479211, 0.45054740122249054, 0.1315997174430278, 9.060088703709265, 49.557276156640825, 80.42871813620292, 74.44137696296939, 78.70791942842546, 74.82547113972326, 73.33903404974168, 68.79001032921576, 59.90520254258187, 57.17729999173073, 59.8126502959959, 58.662866315534046, 55.76327377750028, 53.37013767611597, 52.44062615979103, 49.69217431160712, 51.246613533266135, 48.859160946261504, 49.32419715389129, 49.290511838851444, 48.58992945763373, 50.32058115928404, 48.08248850607103, 47.213981613036125, 47.45270490646363, 47.231710726215, 50.128734111785896, 46.88324736010644, 46.71018454336351, 47.066720147286695, 46.73635067478303, 46.017513582783366, 45.23815039665469, 45.530971019498764, 48.11855077743531, 45.027107269533225, 45.4324959939526, 50.0247089324459, 49.94964261208811, 54.3547781052128, 54.177416370761016, 57.19797872727918, 58.71873655626851, 58.9324821964387, 62.07999598595404, 62.682401441758685, 62.48416093087966, 61.89264005230319, 63.05115130639846, 61.42774112762944, 64.16387673347228, 64.56273078918457, 62.3689805307696, 57.97565921660393, 58.93449044996693, 57.54037810910133, 56.03295633869787, 56.69725287345148, 54.83286011603571, 56.04020095640614, 56.57753821342223, 56.13152550112817, 50.50747033088438, 46.53058313554334, 45.638918569011075, 44.67689844869798, 43.775541705469934, 42.800409101670795, 42.672280957621915, 43.135544253933816, 43.328673916478316, 43.59845845930038, 41.97108668665732, 43.08643617937642, 44.04897405255226, 46.80694157077421, 45.0847621886961, 45.3246896497665, 44.57237905071628, 45.62093450177101, 44.917057329608554, 45.41204475587415, 44.83538966025076, 44.32289669590612, 45.08621346565985, 44.22850093533916, 48.150776970771055, 51.57847742880545, 50.98640349603469, 51.58215268965691, 50.06630174575314, 47.89889804778561, 47.71614697671706, 51.13750103981265, 57.86240862261865, 63.57975736741097, 66.86774299990746, 62.82809788180936, 63.87797124924199, 66.28506706606957, 62.12071803308303, 64.81127569752356, 59.99319699502761, 61.96043822073168, 68.11540972801947, 65.15122359798801, 42.44296350786763, 0.05035608541220427, 0.6790759642758678, 1.8107197794222065, 46.4961015793585, 49.720795846754505, 59.71722295207363, 15.78764976993684, 25.850000150742073, 43.908588501714895, 26.439489241569277, 57.68810633690127, 7.096787989139558, 0.2483533250708734, 0.03837969499610124, 0.07101988990701015, 0.12251678749077743, 0.023419248473439968, 0.014247148759633064, 0.04391779056600025, 0.09082271882723417, 0.03240757231270114, 0.04891368740748975, 0.10916071868832074, 0.03374315850857285, 0.05440834196164243, 0.018815602055720745, 0.048423444762104945, 0.04308203843632533, 0.03529440228556914, 0.030626592173751806, 0.008363121399475683, 0.026867791349368713, 0.007255834671894029, 0.039882449237930204, 0.016175168941939072, 0.02997720816863641, 0.015559186370322301, 0.11544635519385339, 0.03105289520575635, 0.04847564599326542, 0.1389427314842901, 0.10686423223946365, 0.0757578602661529, 0.10175866225073416, 0.12435214263537239, 0.09352224413305522, 0.029225409699363575, 0.04250392550602556, 0.04916029111031563, 0.046406932806055394, 0.03195673914536113, 0.00463655180928688, 0.010073834996400102, 0.06607023413263022, 0.03586542124169008, 7.918338717952852, 81.10658999412291, 36.38774964117235, 46.22739176596365, 31.44461597165754, 46.863764947460545, 77.79329330690446, 77.31700774162047, 79.25159915801018, 74.7550645951302, 22.65088365923974, 0.3984532997973504, 0.8588386795693829, 0.2549559304550771, 9.369013597888332, 58.732347180766446, 82.23679742505475, 76.12275585051506, 80.37046309440368, 76.20757318312123, 76.37596053461876, 70.9124126741963, 60.657379781046224, 58.89341538952243, 62.390482964054236, 60.14735790991015, 58.59233425509546, 55.22304965603737, 55.03464644955051, 52.012028771062056, 53.07227680760046, 52.03590816067111, 53.473421527493386, 51.067016047816125, 51.876181402514064, 51.573350890990234, 50.01019616280833, 49.04580693091116, 49.768966474840724, 50.75134369634813, 50.53446408241026, 50.76978668089836, 47.569775888996745, 50.126043365847686, 49.13370724647276, 50.5250935400686, 48.03088580408404, 49.505414578222464, 49.13930054633848, 48.85613679885865, 49.123411024770434, 51.74482907018354, 52.409470773512325, 58.37588217950637, 57.72613763809205, 59.831952279613866, 61.236451056695756, 62.45802617842152, 63.314805184641195, 65.96972419369605, 64.69150220194172, 65.54038939937469, 64.71549534028577, 64.31548026300246, 64.70676414428219, 64.82668276756041, 65.98914777078937, 61.70038507830713, 61.20200087947231, 61.52599257807578, 58.326523073257945, 59.581446186188735, 56.04318980247744, 58.66128167798443, 58.70551032404746, 57.100700024635564, 53.94621226095385, 50.0279252759872, 47.69242448191489, 46.30138335689422, 45.6716585928394, 44.60038477374662, 46.87141749166673, 45.7394253823065, 45.90970331622709, 45.9620826475082, 44.17638048048943, 46.71720558597196, 45.89924235497752, 46.39814038430491, 46.76090471206173, 48.397682328378, 47.16990201703964, 47.48515859726937, 48.136601524968306, 48.458133897473736, 48.39561916166737, 44.93500609551707, 47.63216903132778, 45.90857367361746, 49.42042073895855, 54.02738178929975, 55.23864107747232, 54.77305181564824, 52.65895312832248, 49.8273431101153, 50.50796454952609, 53.373828626448116, 59.02589736446258, 66.0746789747669, 67.31193573244157, 65.23959067560011, 65.24270111514677, 70.68601346785023, 64.63025831407117, 68.03267909634498, 63.96750327079528, 67.0138277546052, 70.30919921013617, 71.45734756223618, 44.199028245864376, 0.17100959385354675, 1.7965856410803336, 2.215303682511853, 49.82712737975582, 57.10309659281085, 61.97928520940966, 29.413183196898434, 22.48994684988453, 50.710704018992764, 27.447242236906483, 65.7363078671117, 8.070229561098161, 0.3877915622245881, 0.05998297992552962, 0.029868130654757543, 0.01902264497813679, 0.026856148728139462, 0.025821171603315783, 0.05064388549315834, 0.05455670637949821, 0.03682349079979524, 0.0267289417435325, 0.04273831776733841, 0.03655947391845046, 0.03290953227288781, 0.003247347119594774, 0.016484593769775766, 0.011668413494443221, 0.08172609122289766, 0.04001204450164111, 0.0448348016418036, 0.12640950239954457, 0.1293730982128651, 0.1325716991578379, 0.13941340058320953, 0.11074942416481434, 0.08497882394060012, 0.22899679599269746, 0.12279310774418617, 0.16700143715546978, 0.20544357597827914, 0.16968545684170339, 0.11150799676655762, 0.22903785830543888, 0.13193855813193706, 0.1664082552756994, 0.15740613993858138, 0.14882889696426932, 0.20007952026301817, 0.13848386013940459, 0.10320070019412426, 0.20257445412778086, 0.1309125825402237, 0.1578855730833546, 0.2705050025495791, 15.4275163719731, 98.65453673947243, 51.447611470376295, 66.59125512646091, 36.93501833946475, 42.18838207183346, 89.57168456046813, 86.0062422290925, 82.98950026112219, 81.32698797410535, 23.09089122279998, 0.3982638922189513, 1.0214897485509997, 1.0293499332281852, 10.154008326991912, 63.0274562681875, 88.37715025871032, 78.60507488250732, 86.55298925215199, 80.41760213913457, 81.60567237484841, 76.08491282309257, 64.32517636206843, 62.116768206319506, 67.87611376854682, 64.22116687220912, 61.48917721163843, 57.806161834347634, 58.70269013989357, 56.17789968367546, 58.305240292702955, 55.37423349195912, 56.435105185354914, 53.06189821612451, 55.41247267876902, 55.01734487472042, 54.66253511367306, 53.51890925438174, 53.23886771355906, 53.38741179435484, 54.420862197875984, 52.37206705154912, 51.31347033285326, 51.54932245131462, 52.98563557286417, 53.240801442054014, 50.62418437773182, 51.29043817520142, 53.33467552738806, 53.03264517937937, 51.50000256876792, 55.03455623503655, 53.77484783049553, 60.99524882531936, 59.40524547330795, 62.44317608494913, 64.65916225987097, 63.15115605631183, 65.45103388447916, 68.53123587946739, 65.25276591700893, 67.12166940012287, 66.89221858978271, 64.49646626749347, 68.04620342869913, 66.58287694377285, 67.04970959694155, 64.2971274929662, 64.91987436048447, 64.66393970674085, 60.58638880329748, 63.916590905958614, 59.23715229957335, 60.48738425777805, 60.92010405755813, 59.8609503622978, 57.246482756830034, 53.08047848363077, 49.6142368162832, 48.86378149832449, 47.82062715099704, 46.8273731970018, 49.15884571690714, 48.29971721095424, 48.52815212741975, 48.202834667698035, 46.732016455742624, 49.562998894722234, 49.48098605678928, 51.88283766469648, 50.46794852902813, 50.79772572363577, 48.32659329137495, 49.338294152290594, 50.88686550817182, 50.905594825744636, 52.71192081512944, 47.95707071981123, 51.04911042797951, 48.48873230718797, 53.58083171229209, 57.45336817156885, 57.74340783396075, 57.59235343625469, 54.940231077132694, 51.92104939491519, 55.295225189578154, 55.874496506106475, 62.16096155105099, 68.3649822973436, 70.8817554289295, 67.47796181709536, 67.16072051755845, 70.29490609322825, 68.03653870859455, 70.22056148898217, 67.5829009086855, 69.09626114752986, 73.3233210348314, 72.10728429978894, 50.25159843506352, 0.3611453388246798, 2.1267743168338655, 5.52531587500726, 54.15105804320305, 61.71287782730595, 71.45945779738888, 25.506733925111835, 37.09165426992601, 64.72853329873854, 36.61079129865093, 79.11013495537543, 18.875873011927453, 0.5965756492749338, 0.1856893706586092, 0.14401590361470176, 0.2364804178115822, 0.11815144995888395, 0.10809223287768903, 0.12442865183637028, 0.2405415265069854, 0.14500912128677293, 0.12684148405828785, 0.18777092347943014, 0.13043927809884473, 0.21126734573514233, 0.09483567889659636, 0.13050277146600908, 0.11309905413297877, 0.19320967276730847, 0.16810316352113602, 0.12002769887687699], [0.07992342505003176, 0.05805123176786208, 0.08718570874583337, 0.04863598819581732, 0.07997348889588349, 0.04199904292040775, 0.05332160027577512, 0.06484913594660259, 0.1051818648533475, 0.10913639539672483, 0.035121569019411845, 0.04565487578210812, 0.10118906055727314, 0.0557984889394814, 0.021702993187993284, 0.05342543200259248, 0.01712681676801895, 0.007238821295510618, 0.02348723494628024, 0.06975301030662752, 0.02972736965955025, 0.05205449467945484, 0.0307615002572176, 0.1739813561641401, 0.1782636344432831, 24.97879074465844, 67.81869811396446, 37.56107568740845, 43.06254110028667, 14.018954999985235, 56.56829318692608, 79.54320384610085, 63.243386668543664, 67.59677040961482, 25.40806278105705, 0.22770308799320654, 1.4307646837926682, 0.6842376808485677, 2.2073304845440775, 30.31035477115262, 84.86940599256947, 71.02603589334797, 79.11139795857092, 74.69258908302554, 71.95314299675726, 63.70436714541528, 62.844175677145685, 65.45781566250709, 72.29092967125678, 72.5685001188709, 71.029997487222, 60.56512563459335, 56.09104664094987, 51.89202777801022, 49.49593420951597, 49.861867812372026, 50.30804134184315, 49.77179450373496, 50.98859217859084, 46.964240381794596, 49.547132907375214, 47.4412751197815, 49.484504422833844, 50.0460466261833, 47.74448610121205, 46.494183540344245, 49.07524431905439, 47.637628970607636, 47.37000565375052, 45.146523829429384, 47.02074604649698, 46.608108781999164, 47.54942663254277, 48.14416385466053, 48.67468010994696, 48.753351088493105, 48.17117721803727, 51.490596725094704, 54.74577173109978, 55.708748909734915, 57.64921995901293, 59.64618490588281, 60.76898690192931, 62.20811628526258, 62.18972821389476, 64.39390020985758, 64.12225646357383, 61.902900972673976, 62.16555856889295, 63.49830150604249, 60.039645702608176, 58.4387852299598, 56.63839378664571, 57.58537553971814, 60.1432982567818, 56.857897466228856, 60.88694434012137, 61.08567122490176, 59.79682745472078, 60.83358049392701, 61.34412796266618, 53.00827549349878, 46.62109967200987, 46.8845848883352, 46.464714773239635, 44.11861573496173, 44.16813958075739, 43.808128756861535, 45.41742232538039, 45.21605568547403, 41.84848908455142, 45.22759922089116, 44.999991924532004, 45.34498007066789, 44.81315766611407, 44.82541115053239, 41.8650257971979, 45.40496095534294, 45.72865063144315, 46.091265909133426, 45.45772075653077, 45.66471992000457, 46.742673535500806, 46.731659520056944, 46.65996251567718, 49.69617512918288, 49.20838525218349, 49.83450928042012, 49.10402274900868, 50.07073402404786, 46.67730331420899, 48.00397442233179, 54.222292207902484, 63.43083673907865, 62.545071417285556, 69.52078711601996, 63.348266924581225, 66.70246216558641, 63.52812720883278, 64.81928909978559, 61.379080203271684, 73.21216106414795, 57.56261402560819, 70.09718725758215, 7.604463792616322, 0.35758591046737087, 1.26349643353493, 6.227088205275997, 45.93270017254738, 61.82847792102445, 48.23079724465647, 3.216150364568157, 40.72438878397788, 29.166466113059755, 38.576997018629505, 51.382409911001886, 0.7684569132904854, 0.1354932827093909, 0.11487993276527814, 0.07225312292575836, 0.08865383198304523, 0.05609198488415249, 0.07428986726388817, 0.03586737476589699, 0.024303530357898246, 0.020002530805105646, 0.07280271440263718, 0.02480442928630979, 0.08270739622774624, 0.01377344499492357, 0.013469212327993686, 0.060778198343130856, 0.07889733454512973, 0.054153238513296655, 0.052267750574936794, 0.04079088395942123, 0.12182510202570308, 0.011418848861789992, 0.07073388630223852, 0.033842815056202874, 0.030033247500297525, 0.03532959636481058, 0.06660658761017746, 0.05822197361398609, 0.05537123404323094, 0.09918085299432279, 0.024509803361950383, 0.02948971194846015, 0.0427490008634425, 0.014162451993944425, 0.06263336069100807, 0.03171350239896246, 0.05582629410069316, 0.02767363349125991, 0.09980150678705785, 0.017641853849073092, 0.05555443247900375, 0.009892672439286066, 0.02949060827133156, 0.12550292927170956, 0.21404933274513294, 35.274941844324914, 72.53502661182036, 39.042507833050145, 47.79264888455791, 20.503901781574374, 70.8611394513038, 81.23394935361802, 73.31155392431444, 74.80054055490803, 27.45641273836936, 0.13735447799967182, 2.2931558662845246, 1.9399099051952364, 2.712628841400147, 37.230325744998076, 84.13533441482052, 73.38763221617668, 80.54774638145201, 78.41493406603414, 73.58818300308721, 67.26985654523297, 68.25854486034763, 66.35839185407086, 74.27236203224429, 75.66765108416158, 72.62735136093633, 60.72536622324298, 57.008689065133375, 54.2240180507783, 53.48364714653262, 52.48519605205905, 52.61363798572172, 53.6253898374496, 52.32274324663224, 50.507034947795255, 52.10993113056306, 50.6356494657455, 50.09501741778467, 50.964324474334724, 49.6788735543528, 50.53765689173053, 52.17277534546391, 51.53927333893315, 50.67116260528565, 46.677832834182254, 48.349990229452814, 49.73492030174502, 48.87050444079984, 50.39865985993416, 49.72798947365054, 50.73444220327562, 51.69421480547998, 53.70427262398505, 58.092479167446015, 58.78302812576295, 60.05859075054046, 63.101687123698575, 62.88138720297045, 65.5723802505001, 64.83809686476185, 67.42554326211253, 66.69439777251213, 65.88703278572329, 65.54686131015902, 65.96661767651959, 62.85764901868759, 63.252600316078436, 58.537024913295625, 61.13449688880675, 63.36481540433822, 58.572926367482836, 64.87323737913563, 62.032994224179184, 60.54567460090884, 61.56086244890767, 62.384870052337654, 52.98026584809827, 49.17269560598558, 47.838909318370206, 47.0184906836479, 45.97431259770548, 46.89559890377907, 47.2145385896006, 47.21505242009317, 48.32667958351874, 45.09757264967888, 48.2543275433202, 46.99042612506498, 48.23007945091494, 46.73028276812646, 47.37173934136668, 45.30792936202019, 49.19194267642114, 47.76936961758522, 48.269801293649984, 46.571328716893355, 47.61369466781617, 47.327310654424856, 49.83213624646587, 49.78828414793938, 52.75969920619842, 52.85820168833579, 53.024635699487504, 52.07832074934437, 52.258381074474705, 49.38471148090978, 50.737427126976755, 56.44518959906794, 67.24396105735534, 65.0659748046629, 70.43926500505017, 64.07723942110616, 67.93990719702937, 67.72860127110636, 67.622814947559, 64.64130370847641, 74.30640036059965, 62.07495574028262, 72.51706215643114, 7.250726799811087, 0.5647700688531322, 3.2120804152181073, 6.644500955458611, 53.404642766521825, 61.46598031443935, 57.719461764058764, 8.369091614600151, 40.37143822639219, 35.946635969223514, 39.291601873213246, 60.25054370203326, 1.018546438745914, 0.06217672249242183, 0.13637586196343746, 0.045783371709647684, 0.026184218755412488, 0.016159688220209172, 0.0637529292444308, 0.025572698645954652, 0.011230983992948407, 0.038124097421044306, 0.027442590949395974, 0.04399261437356473, 0.03724046862654148, 0.05343617255529089, 0.0477899628270778, 0.04224029932952216, 0.03589205428837769, 0.05721287876968423, 0.0362339478376652, 0.059514904034233866, 0.2372419858171094, 0.1769597987614332, 0.20996121178951957, 0.13360732745739723, 0.15523861673089767, 0.1698561259094746, 0.17914963044947196, 0.19043228228486356, 0.14848484687747496, 0.19980780419803437, 0.10522563145646166, 0.17103735687992266, 0.23089379823255926, 0.1545143725290414, 0.18057898197683597, 0.25554053215009553, 0.205147743465439, 0.1152149813189622, 0.1884512095561912, 0.1403350656431529, 0.21006054274978178, 0.0889663498908762, 0.09794003570512419, 0.34412850355429037, 0.31569806137873285, 52.400723888028054, 88.63960389168032, 56.866154055441584, 61.15554040478122, 22.611699181218302, 66.93241503930861, 96.03481708034393, 74.71762949420561, 83.881313877721, 29.272505429483232, 0.3822426648149568, 3.3340644115401856, 2.278078765638413, 2.5195597304451853, 44.72471998583886, 87.81914603325629, 76.6963005065918, 83.78464314245409, 84.6541541622531, 78.15597918725784, 70.49433508226949, 70.31728713743149, 71.44723569193195, 78.45061978986188, 79.045502139676, 76.31741523742676, 63.930676137247396, 62.335930639697665, 57.576777704300426, 57.92546856787897, 56.038373131905836, 56.91448550070486, 55.75388362330776, 57.33536758730489, 54.15801632788874, 55.785909775764715, 53.93256241275419, 55.63651454064154, 53.533182759438795, 53.15676858348232, 52.760169890619096, 54.754267584893014, 53.603620682993245, 53.83501698893886, 48.712844771723596, 53.89989691395914, 52.35487922545403, 52.23394470830118, 53.289897749500895, 51.447642849337676, 53.99100180595152, 53.85329523394185, 56.70155571353052, 61.99260950088502, 61.631912262209006, 61.45620969034011, 65.43198293255222, 66.64820794136294, 67.44976782029676, 65.86830739052066, 67.75463796431019, 66.96901859775667, 66.42959071743873, 65.85053120889972, 66.79780713973507, 63.613834919468054, 62.718954009394494, 61.10966436324581, 62.822139801517615, 65.49963597328433, 62.273051123465265, 66.28210959895965, 63.391601270244976, 62.75914653655022, 65.308012500886, 64.62843833431121, 59.09893581944128, 51.766092238887666, 50.7188743160617, 49.90903039132395, 50.414718043419626, 49.35229701380576, 50.54952990624213, 51.260149632730794, 50.74123574841408, 46.764407388625614, 51.25907098093341, 49.71644201586324, 52.092813907131074, 49.504143730286636, 49.82026323195427, 46.70082184576219, 52.16627205571821, 49.52747398807157, 50.937103225338845, 48.667400190907145, 51.240165156702844, 51.50739623654274, 53.365328850284705, 52.23090094904746, 55.396167385962706, 56.52077759465864, 54.70250406572896, 56.12890928022323, 56.830350660508685, 50.54927495218093, 52.49284859626524, 58.31168474689607, 71.48822446023264, 66.90268347340246, 73.25591902579032, 65.54619450722971, 71.20772792446998, 68.59863004376813, 72.22843846967145, 66.5890899781258, 80.92717293770083, 65.18170825896725, 77.07808832968436, 9.708282928312979, 0.5434472065779471, 4.729553749484401, 10.849267071293248, 56.587108796642674, 74.17521276781636, 58.74382011352047, 6.773954860625729, 59.47755828980477, 44.802598645610196, 50.75638786438973, 70.55063678372291, 3.729450846872022, 0.45003865755373434, 0.41346166703489523, 0.2646198844717395, 0.15282341729729407, 0.20079239572007812, 0.22334283728513027, 0.0995943183079362, 0.15106375930049729, 0.09874599850586346, 0.09979484948299586, 0.15506263101293197, 0.17520295996819774, 0.14138334971522132, 0.1447062254432709, 0.24192575545560932, 0.11623456007650784, 0.10703605810000051, 0.1594409920395382, 0.09570859012103851], [0.07396335292968058, 0.05093147873037285, 0.026169243651712616, 0.0404798599230426, 0.04370054718287241, 0.039247484922769575, 0.0679144912189053, 0.06292570367335312, 0.05470153147114381, 0.025702596514395652, 0.07096684597913297, 0.026531120604504983, 0.020690996785678213, 0.07731360097926471, 0.040368846121935115, 0.016128414595920234, 0.05437793210148812, 0.018375494119320667, 0.017570138443261385, 0.08888434783946123, 0.0316187986097629, 0.05706821838694234, 0.04680386594226284, 0.3263488898594534, 0.055432214642003666, 9.258971502704005, 69.9715772751839, 37.08347220574656, 41.70661303304857, 35.66340554145075, 10.906913165123234, 81.81136146668466, 68.32490351892287, 74.41829773687547, 39.01965218205606, 0.9873122373415578, 2.1657244332375067, 0.518569267324863, 0.4692406207323075, 13.899631596380665, 86.10494475210868, 75.09681286350374, 81.35369147023847, 74.68390495546403, 77.38364096610778, 69.39116062656527, 69.95938654868834, 68.86419019391461, 74.47084180770382, 72.160095091789, 74.94566825128372, 65.16874874791792, 58.47286670438705, 50.12708671631352, 49.64371342812815, 50.98020222879226, 50.761333973177024, 49.4794955561238, 50.3322619776572, 49.4386479931493, 48.8817028076418, 47.9465901467108, 47.70300311426963, 49.656810222133515, 48.79754835559476, 48.29255888538976, 47.55151333347444, 48.59554236935031, 46.65988406827373, 46.82692212443198, 46.820744391410585, 46.417222715193226, 45.94408681315761, 47.91765089957945, 46.23217705757388, 48.484947219971694, 50.155319936813854, 52.871349473153394, 54.569155246980735, 55.446389413649044, 56.351719517861646, 56.202696907904844, 57.29206069823235, 61.8921301441808, 60.020963453477435, 61.71287782730595, 65.52576680337229, 60.61140960262668, 62.84011602401734, 66.54417099491243, 63.12429566537181, 58.62498014203964, 59.35897327238514, 54.456500853261645, 55.08643742530577, 67.57369902826125, 61.638615592833496, 63.491708001782825, 65.19649951688706, 61.82204523394185, 59.32690789622646, 60.49005146949523, 48.927516091254454, 46.870378063571074, 46.026625248693655, 44.79530303708969, 42.32595528325727, 44.758848528708185, 44.04780518624091, 44.3669488353114, 44.131241844546416, 44.341971182054095, 46.40002312198762, 47.931402729403594, 45.04214563677388, 45.378006427518784, 44.9409955547702, 46.0924308530746, 45.716703091898275, 46.48438938202397, 44.99583421214935, 44.27847977607481, 42.83627133215628, 46.42047828243625, 46.35288407725673, 48.086791346150065, 48.67917122379426, 47.674248218536384, 49.37728643417359, 47.01607450362175, 47.92069465883317, 49.97078810968707, 49.6084709321299, 56.210169023083104, 63.84155988693238, 66.57933896587741, 70.06464727463262, 66.6010061387093, 63.9064908027649, 65.6108194781888, 67.62521543810445, 65.24958487479918, 68.5240500973117, 26.086209204889116, 0.3884260362434772, 0.35932358174074086, 2.8300415604345264, 8.412937829571387, 46.73307157331898, 71.54936636647871, 13.805649645866888, 24.312325139199537, 44.53607359240132, 24.076769159686183, 54.54575438653269, 30.655378218620058, 0.10798391570607502, 0.02457122063083995, 0.030683420575974934, 0.06266747841671591, 0.04490967907552277, 0.050053783286843574, 0.02919860236767319, 0.05315380403771997, 0.03478588844319025, 0.022363742107465383, 0.041567383018592675, 0.05117193074716676, 0.021851298234034932, 0.0327161333764032, 0.038888538256287575, 0.03396364627406001, 0.08159070050403958, 0.027383054426360517, 0.03936827017535125, 0.054522006426967924, 0.04622559979437821, 0.07025121260554561, 0.06623875815421343, 0.034121678721520214, 0.03807661146105778, 0.02618034426573544, 0.03294772558635281, 0.021894271936147444, 0.04841052085882233, 0.022087082860150167, 0.029095266682786808, 0.01633470100651105, 0.0337156942564874, 0.006652129138068807, 0.03905889705844945, 0.12455461201288047, 0.05025164081504749, 0.02044611869590177, 0.0036747205200710247, 0.034681022497675115, 0.014734866187697458, 0.026893662138571663, 0.04898727398305651, 0.11293382428946996, 0.045963023158331076, 10.117922521406605, 83.22696839609455, 39.59794682841147, 49.44792047623665, 32.65738929471662, 21.50962887271758, 99.03881134525423, 69.98510160753804, 84.56557135428153, 38.51914990332819, 1.8806628714646063, 3.509314685098587, 0.4590738372456643, 0.7637530108613353, 17.583877617313018, 86.93545172291418, 74.2056268261325, 82.79404071069534, 76.77484204692226, 79.47559002907046, 72.17791049711167, 70.16259670257568, 72.65398425440635, 78.03296581391366, 74.40609132089924, 77.4344591940603, 67.69888539468089, 61.51398620297832, 54.35675890214982, 54.94338074038106, 53.10287129494452, 53.628272779526256, 50.39971889988069, 52.609115492913034, 51.80429220199586, 53.28113517453594, 49.69894040015436, 50.339769394167014, 51.42661894521406, 52.702318852947606, 51.22302439904983, 50.99987683757659, 51.25596838612711, 52.316824390042214, 48.980872092708466, 50.384543249684, 49.696355558210804, 49.56792146928849, 51.35867172671903, 48.23750057528096, 50.9798413707364, 52.054457049216, 55.03797654182681, 56.156514921496, 58.815493583679206, 60.937546837714414, 58.52474789465628, 61.91396597893008, 64.41003684074649, 63.926518424864746, 64.7275056377534, 68.69775618276289, 62.99917990161527, 67.15414662514964, 68.51748404964324, 64.23306734331193, 61.497559316696666, 62.612034120867335, 57.467120001392985, 58.829637650520574, 67.26134500195904, 62.768979918572214, 63.99411655241444, 67.04628144541095, 63.65578859083114, 63.13357207082934, 61.52752622481316, 51.32496679982832, 48.6926680995572, 47.35625774629655, 48.85351665558354, 46.295919495244185, 46.28255205769693, 46.36476885887885, 48.488512654458326, 46.45582668242916, 47.270781455501435, 48.698226098091375, 49.237775571884654, 46.096051200743645, 47.52578650751422, 46.21992357315556, 47.522550552122055, 48.38980620907199, 49.834999576691665, 47.8709158589763, 47.96555872886412, 45.97019410902455, 48.089839027773955, 49.24202349878127, 51.45686434161279, 51.00307356926703, 49.56437956902289, 50.818384847333355, 49.17417433954055, 50.15335482935752, 50.91340034238754, 53.999689855883204, 57.56980765250422, 66.9008791831232, 68.0717537480016, 73.37940308355516, 68.32950838150518, 66.99838146086663, 68.26433427872198, 70.77510618394422, 68.8882500125516, 73.9953956296367, 24.415565844505068, 0.6916666499549343, 0.6777583543331392, 3.0602089387755242, 9.179923976621321, 56.56120938639487, 71.8810498329901, 27.157177079108457, 21.99379840204793, 50.67767373977169, 25.24268977103695, 61.29993069556452, 32.89828558121958, 0.21022882162322923, 0.03895648642473164, 0.08589282046042143, 0.07747036555121023, 0.00723384794846718, 0.06625047929945492, 0.061703299307414604, 0.039337818180361105, 0.022160531539890557, 0.02769487327896059, 0.04759117067160626, 0.07638271222071302, 0.0049419963315519835, 0.06567811968946649, 0.013773310929536821, 0.05093604461440156, 0.05156562716189412, 0.05520749424073485, 0.032839492684410464, 0.019784285762016813, 0.18052152538251492, 0.15306251333846202, 0.10153327918341083, 0.14923915236948, 0.14950630255043507, 0.08802737124384412, 0.20752803993321237, 0.16883119219733825, 0.19780825342862837, 0.14235894736503402, 0.11975297974723002, 0.13954659262972494, 0.1447078495496704, 0.1444035441043877, 0.17186925175689882, 0.17647515621877488, 0.13231386460604208, 0.12077573010878218, 0.13855987138325168, 0.14521965757012367, 0.08930795615719211, 0.1420737328308244, 0.16838791840259107, 0.5517601185748654, 0.44414652211050837, 18.671529293060303, 93.67907293381231, 54.75475003642421, 60.90784665076964, 51.21344597108903, 16.63943559892716, 99.23212143682666, 79.68265979520737, 90.96045463315903, 46.13661635306574, 1.8798440766911355, 7.358393899856075, 1.6180780842419595, 0.8657831746724345, 20.997004508972168, 89.4828820997669, 77.7306765894736, 87.61582605300411, 82.08958302774738, 81.9771678986088, 77.83829073752128, 73.52058487553751, 75.34570294041788, 81.6530232275686, 78.68042361351752, 80.09231213600405, 72.28419103930074, 64.26898448697983, 57.40939840193718, 57.00375864582678, 58.02337092737998, 55.60674767340384, 54.02026660980717, 55.44308285559378, 54.20491610803912, 55.87020543313796, 53.67302702319238, 53.504996607380534, 55.432162977034054, 54.20180174612231, 56.26078721015685, 53.19326231556555, 54.5611967579011, 54.217302953043294, 52.7275396931556, 53.51905045970794, 52.970526602960405, 52.64320481208063, 53.45397833854922, 49.55842541110132, 53.23149758000528, 56.12320615399269, 58.73197847797025, 58.9519646090846, 61.71300334315147, 64.90294148845058, 62.88279925623248, 63.29915492765365, 69.2960431498866, 64.33965775274461, 67.55658180482926, 71.0085735013408, 63.29873523404522, 68.50263395617085, 70.6673586753107, 67.70014839787638, 65.99525097877749, 64.42483594340663, 61.19143009185792, 59.71585012251332, 69.39955449873402, 64.33621391173332, 66.91539195276076, 69.06536856005269, 66.80511843773627, 65.37933295772922, 64.06338953202771, 53.72120157364876, 53.36719589848673, 50.41230186339348, 51.95948077786354, 48.653636593972486, 48.31845437326739, 48.006351378656205, 49.097166445947465, 48.046363476784, 48.80918210552585, 51.36690085934055, 54.17851463440926, 48.49021888548329, 49.93006998492826, 49.43488644015405, 50.9799119733995, 51.06083439242456, 54.172713448924405, 51.1280991185096, 50.80966149607013, 46.987864817342455, 51.980422312213534, 51.251763605302386, 53.93617491568289, 54.591477455631384, 52.79369046611171, 54.31446790695191, 52.185158268097915, 52.5494287860009, 54.31123195155975, 54.47745807709233, 61.34727762591455, 69.41886040472215, 72.71673433242306, 75.59282010601413, 69.52690601348877, 68.40895206697526, 72.26548917831914, 72.65255651166363, 71.80091581036969, 74.44511105937343, 30.42551555941182, 0.4062896438183323, 0.5194490426971067, 7.936779741317996, 9.867685110338273, 59.63103671227733, 85.36873940498599, 20.58464181038641, 35.30219054991199, 64.50612314285772, 34.3470855682127, 72.87659445116597, 46.327780908153905, 0.22670810831890953, 0.08035883878267581, 0.2294174395501614, 0.20107229360409323, 0.08865196272850999, 0.22219113134328397, 0.1795132923871279, 0.11579750691570583, 0.13158597382566622, 0.14297612311859287, 0.12043980055398519, 0.12267109292048602, 0.0751994664390241, 0.12562060037687903, 0.10598144614167752, 0.15443264626927916, 0.19722438717801727, 0.16141780531935154, 0.1512626357256405, 0.1751720100160568], [0.021879827348335136, 0.049573637680300785, 0.03450741931315392, 0.05649884268941899, 0.020651577731534358, 0.08239047331435066, 0.05545261939386687, 0.023290239266991135, 0.07971794494698126, 0.030304795025937983, 0.04148024434764539, 0.047157580228221994, 0.017102158312956174, 0.026052959165686083, 0.03746836446225643, 0.04435283274600103, 0.062496211800363764, 0.007665753477222978, 0.010416849906886778, 0.0458725749875509, 0.09018829077362053, 0.06980800009783238, 0.05792299631021677, 0.07734234459818372, 0.048371013704567194, 0.8005276827081558, 36.398967619865175, 70.0510601843557, 29.02704938765495, 57.546312655172045, 16.86222622471471, 27.747378080121933, 87.69268097416048, 62.72434726838143, 58.93192914224441, 0.5793006117305448, 1.6074824140917872, 1.5347909662992725, 0.2226038841951278, 0.37619755693501045, 57.29768537705945, 82.21291019070534, 78.10949125597554, 79.06834602355957, 76.62940056093278, 73.38960909074353, 75.28824021739345, 74.94292259216309, 75.46804951083276, 74.17373011189123, 76.96266866499379, 71.7048804990707, 57.916474573073856, 52.410667096414876, 50.1753475589137, 50.76218512750442, 50.97381268778155, 51.80580231451219, 48.70782021553286, 50.343511335311405, 48.132855661453746, 48.883605157175374, 49.79718008349019, 49.08196333915957, 47.21389532089234, 50.90033100497339, 47.65562480495822, 47.88689559505832, 48.380827903747566, 48.70358797811693, 50.23985485876761, 46.23913141988939, 45.540129753851126, 48.367872315068404, 48.49737721104776, 48.14229680645851, 50.083113024311686, 53.43967737690095, 54.897641981801684, 54.623762484519716, 54.53926678626768, 55.39154683389972, 55.377571428975756, 58.53129433047388, 59.07793152716852, 60.800322717235936, 63.22830907760128, 64.6215545746588, 61.808003148724964, 64.36386269907798, 61.42173205652545, 63.17831454738494, 61.49442142055881, 63.46660483268, 55.894888908632346, 50.41162721572384, 66.46294655338411, 64.15762839778778, 62.6274686474954, 64.76703136197983, 62.332651538233605, 61.5403994437187, 54.97264554423671, 45.885996510905606, 45.566127223353234, 44.145813449736565, 44.91969708473452, 46.23462069419123, 44.83238512469877, 46.162009777561316, 43.32064482473558, 45.24972531103319, 44.47128780426518, 45.54779014279766, 46.62325305323447, 46.08977933083811, 44.42559611412787, 45.004663467407234, 43.53062891191052, 46.131650632427586, 43.73532956646335, 44.1117908108619, 44.37400125688122, 46.82500408541772, 46.97743915742444, 47.600954809496486, 46.50217340838525, 46.485758289214104, 45.658542186983176, 48.763443346946474, 47.758645857534106, 45.930515412361395, 49.42123659195439, 52.17590539686142, 58.45302343368531, 64.44356918334961, 64.88603215063772, 70.78473952508742, 64.17923673506706, 67.48018972335323, 66.32732668230611, 72.86234840270012, 41.117880959664625, 0.08133868822046826, 0.037338083549853296, 0.08884258072582946, 2.7886482977098037, 13.557997076742112, 63.65635733450613, 40.80512685160483, 9.562171697616577, 35.94899723606725, 35.54718179087485, 33.100422966864805, 59.5586258365262, 8.450524922340147, 0.4357947847775875, 0.10805608118854224, 0.006673412497020177, 0.06764246871875179, 0.04925770302032752, 0.09109384500451627, 0.04689360165127343, 0.08797398257640102, 0.050495291248925274, 0.04436743055139819, 0.04047371972832949, 0.06703110757253825, 0.08099191086066347, 0.021965885835309184, 0.04834107881892593, 0.023046540952618086, 0.02818702156805704, 0.04703884809127739, 0.07780938244034206, 0.042115407845666336, 0.018035488976766507, 0.011592789124997874, 0.04426123161289481, 0.008642165095455224, 0.04666051173943185, 0.10600052173099211, 0.05305813497773582, 0.09657174138532532, 0.04481512467346845, 0.026093107918577812, 0.020888645554922765, 0.092269039202121, 0.006042313095437544, 0.09818520682353167, 0.04676360036096266, 0.08095768971308585, 0.031666650376733274, 0.07289784720107433, 0.01608584500518778, 0.0722422827816298, 0.04548670799140969, 0.08116608861112788, 0.09702878944095104, 0.05370419607647965, 0.06421655033444686, 0.6342794325563216, 43.78019755886447, 74.38892702902518, 30.893544535483088, 58.36731572305003, 17.059150780400923, 52.25445478193222, 92.56925398303618, 70.60857019116803, 61.84601876043505, 0.9836717875253771, 1.8833045877756613, 1.925168289772926, 0.7796451677718471, 0.6192568773704191, 64.59785953644784, 82.12897931375812, 81.33072991524973, 83.28324656332694, 80.72386080218901, 74.73943787236368, 79.87928036720523, 76.26593020654495, 77.78888456283077, 76.04700703774729, 80.70236621364471, 71.67789459228516, 62.794365498327444, 54.68622622951385, 53.32652091979981, 54.35369160867507, 53.1305593059909, 54.5721637049029, 52.15407348448231, 54.27673470589423, 51.21203391782699, 51.73032414528632, 52.00358390808106, 52.43126738455988, 51.59229593892252, 55.69341244236116, 51.22676241782404, 50.225385235201934, 51.70359711493216, 52.20837085477768, 52.27745163825251, 49.21076220850791, 47.985974665611025, 49.72931915713895, 49.717689329578036, 50.90686175131029, 51.95612715136621, 55.72302241479197, 56.63173752446329, 57.04778332864085, 56.47867879559917, 58.351339909338186, 58.00038583817021, 62.28156266673919, 61.55729309205086, 63.092198910251746, 65.33054651752596, 66.19745700590073, 62.89335827673636, 67.34708801392587, 64.83915590470838, 66.01363905014531, 63.15942441263507, 64.77765314040646, 56.24825131508612, 55.99495641646847, 69.79764369226271, 64.59800074177404, 64.39489256951117, 67.38111065280053, 65.72578414793938, 64.04180080659928, 56.89122192321285, 48.53039964552849, 47.29678676974389, 46.3731627310476, 46.16189602882632, 47.52493535318683, 46.81415088715092, 48.27923851628458, 46.51741573887487, 48.67562540115849, 48.215688274752715, 48.12825472124162, 48.42515853143508, 47.83865828667918, 46.81806149021272, 47.893571469091604, 45.563150144392445, 48.09892323709304, 46.997258893905155, 47.35549680648312, 47.22349728307417, 49.53970393826885, 49.86624125511416, 51.20997467348653, 48.52252352622248, 50.93299258139826, 47.90455802794426, 52.40396376579039, 49.321463261881185, 48.98574759883266, 52.09068406012751, 55.586982850105535, 59.050667132100756, 69.13100550251623, 66.03882851139193, 72.8637839901832, 65.42524037822601, 69.99977127198251, 66.49838124552082, 76.41200711650234, 38.301815294450336, 0.07874360368136438, 0.3488850515455969, 1.6604909180633485, 1.3230438963059457, 17.73349250516584, 67.18766720064225, 51.50659607302759, 15.749014423739528, 27.954483147590395, 42.698239203422304, 33.89873512329594, 70.25054408657935, 7.4726471497166544, 0.4259711167504711, 0.07962806751170466, 0.031069207132884094, 0.02826131485973395, 0.10362118287312408, 0.06368668179117865, 0.03343985280803135, 0.055225007010683905, 0.016981267723284902, 0.06331574584868166, 0.019441993847008676, 0.020202960473515337, 0.05355196291460626, 0.028845692474034526, 0.10582012334658254, 0.010076123684073889, 0.048160592334405075, 0.04977115812981802, 0.03567191126245645, 0.01784359161261349, 0.23969639363067768, 0.10182133590381953, 0.19880709418606377, 0.1109692837382036, 0.08447338977167684, 0.18747631670726886, 0.28701628107697735, 0.1270903017552149, 0.21158318846456467, 0.14645957087557163, 0.10517097108306424, 0.22042126905533577, 0.12991435465312776, 0.21986605449309274, 0.13494949817897814, 0.10817326965831942, 0.11806421552694614, 0.23258326725373346, 0.08991952414714521, 0.23658193978330783, 0.21791960893859788, 0.17842222996536763, 0.21486463415766918, 0.1385373790417948, 0.24964888700314108, 1.4869065486615705, 60.30016168471306, 92.27952418788787, 44.47343726311961, 84.58338675960418, 24.937580362443004, 38.75876357478481, 106.70349136475595, 77.5507260907081, 68.39297233089324, 0.7421526408964588, 4.585497350462021, 2.0668319204161247, 0.981224105963784, 0.8854560674198213, 68.08314431098201, 83.58775584928452, 83.16420262859714, 86.2617140431558, 84.70140303334883, 77.61257402358517, 83.61500063250142, 79.54614562373008, 79.55741067086497, 79.87101985562234, 85.62646265952819, 77.06392072862195, 68.17692818180208, 55.97441888624623, 57.9044525084957, 57.22792994591498, 56.76385471897741, 58.59362471488215, 53.83599758148194, 57.90269136428834, 54.62017351581205, 55.002024096827355, 58.06128847983576, 55.5133128935291, 53.837382178152765, 57.41246569541193, 53.81996685458768, 52.86912548926569, 55.78880840732206, 53.85810798214328, 54.41015804967573, 50.18651062442411, 51.6105898734062, 52.74972854122039, 53.037555986835116, 53.0943166055987, 56.26278369657455, 58.25409650802613, 58.250413402434326, 60.538053435664025, 58.40182473582607, 59.05619767404372, 60.18144722907775, 63.96724831673407, 62.20130312827326, 65.45530142322664, 67.13698233327558, 70.69887099727508, 63.212592140320815, 68.98247318883097, 66.10850549513295, 68.85451762906968, 66.83925090297576, 65.28971072166198, 59.22161186895063, 58.729177905667214, 69.57176223877939, 67.45569059925695, 64.17593802175215, 70.21879642240464, 66.49983252248457, 68.04751350033668, 60.10164660792197, 50.15829309340447, 47.80074857896375, 48.66392889330464, 49.83030057722523, 52.01726121287192, 49.50330042069959, 49.28625998958465, 47.42269877464541, 51.72212246925601, 50.21646576543009, 49.82786478534822, 51.04952619921777, 50.5886947724127, 49.660320743437744, 49.46987005972093, 48.141649615380075, 51.07835169761412, 48.612636058561264, 50.14991098834623, 50.29809421108615, 51.55290749765212, 53.49947783254809, 53.555861903775124, 51.265209490253085, 51.476793904458326, 50.14816161124937, 55.93154345789264, 52.09003686904908, 50.61806155789284, 54.736989544283965, 59.65379038164693, 63.06387939760762, 71.26759898278021, 70.66532688756143, 76.66576093243015, 68.18221553679436, 70.93147539323377, 69.66034504675096, 76.57331851220901, 46.38754998483966, 0.5163380515671546, 0.27930085637396385, 0.6263891559454703, 10.456647622969843, 17.2208720637906, 78.55606094483407, 53.18725716683173, 13.708822996385637, 56.72598815733387, 54.85225231416764, 48.43053217857115, 77.86896367226878, 16.48874205927695, 0.870856025045918, 0.3365476651778144, 0.12777441061071812, 0.19884866211683522, 0.21343434800303754, 0.18550151057781714, 0.11609297170634232, 0.20408476582698284, 0.060191202623349045, 0.15774689584730134, 0.11046479185742718, 0.1320226439425061, 0.15620234001788402, 0.11913206548460069, 0.1293960042418011, 0.1315911219365174, 0.16027834146253525, 0.18715049951307236, 0.19620069452831823, 0.08512199811276891], [0.03144540801464069, 0.05881151657611613, 0.030257324387709943, 0.024811661156314998, 0.06328195754078127, 0.05714446711804598, 0.04628320577584448, 0.046068157234619704, 0.04797132265183234, 0.046273974416356896, 0.022265387909306635, 0.12419828153665989, 0.02290913542251914, 0.018167631482825648, 0.01613604674686588, 0.04691023725054918, 0.05413823468129962, 0.09959273250593294, 0.02869935244351866, 0.08613831333575711, 0.05765288136899472, 0.056594132535880616, 0.02259931031374201, 0.06323457883310414, 0.09958831217860985, 0.24662682335943947, 4.278922446312444, 68.01950777730634, 44.40140293490502, 31.943062928415117, 52.69723938357446, 7.722877696637185, 64.17017998233919, 75.57447125834804, 69.07698662050309, 13.782528254293627, 2.0319105684757233, 0.42291957404344316, 0.5049129533431223, 0.20299580248613514, 12.495129877521146, 98.75909143878569, 74.90955891147738, 84.67077716704338, 76.23943851840112, 83.38725213081607, 76.44835964325937, 79.66545627963158, 79.33539667437154, 77.92003293191233, 71.35277717344223, 72.64271136253112, 58.180155907907796, 51.61092719724102, 51.188491852052756, 50.87637316796088, 49.916173027407744, 49.573228436131636, 51.62481238765102, 50.78613904214675, 50.04947870008407, 50.06591343110608, 49.430662047478464, 47.97606675855575, 49.951129190383426, 47.548257766231416, 49.06301044648694, 49.16456845498855, 47.5890229594323, 48.06983101752497, 51.31504320329236, 48.556918790263516, 47.18023746244369, 50.073150204074004, 49.57106328779652, 48.09145504428495, 50.46263371744464, 51.95853940902218, 56.50826131143878, 56.424369658193285, 56.64210042645855, 55.65256095701649, 58.48591642995035, 57.0331685773788, 62.18743362734395, 63.80986713594007, 64.0339050754424, 64.66919176040157, 64.27715086167859, 62.23238006714852, 63.76689757070234, 61.66213804675687, 63.67587897085375, 63.20398646016275, 69.19730924790906, 60.332352576717255, 51.36512402565249, 62.10599345545616, 67.55413424584174, 62.253364747570416, 62.5255693927888, 59.95852324270434, 58.141144014173946, 47.39678367491692, 46.50855902702578, 43.90171258680282, 45.05577979549285, 44.63839254071636, 46.466468072706654, 45.30229683845274, 46.80830655559417, 45.31941013951456, 46.73737049102784, 47.92133792754143, 46.92751915224137, 48.08141377664382, 48.70586687518705, 46.16921909393803, 46.82340768075759, 47.445652484893806, 47.62483027673537, 45.21206663500878, 45.73327510587631, 46.28772958632439, 48.9654375660804, 47.035933463804184, 50.002441636977665, 49.373928885306086, 50.59689252607284, 50.911019463692945, 52.33150189922702, 51.980724334716804, 52.206962723885816, 53.96708711501091, 58.483359044598, 62.848545197517645, 68.1284398417319, 69.79816144512546, 69.04960063195998, 64.38947969867338, 59.66106245594641, 65.93049264723255, 3.8398383557796483, 0.23139826713069794, 0.15809257004049518, 3.7791364904372924, 1.4534728781830881, 22.529768713058967, 78.61426891819124, 17.477151886109386, 21.234476566314697, 58.399977299474905, 36.00752292140838, 42.451675092020345, 45.70152351933141, 0.32952885954610767, 0.16170335693224785, 0.05931434221565724, 0.06747378381870447, 0.04265928430663001, 0.03177468601103512, 0.008707621562925559, 0.029613653483289867, 0.05509444264574878, 0.09370435855441517, 0.009659925351790603, 0.018639457374510747, 0.07586953290287526, 0.02042997913855699, 0.0706265727058053, 0.06265728178644372, 0.04533566609625855, 0.052193240863421274, 0.010002918237249457, 0.012012127460160804, 0.06118542770104063, 0.04967754218547095, 0.13392491686728694, 0.0648938984640183, 0.02704788712904819, 0.05887494482580693, 0.05311692456504511, 0.020220337262857827, 0.04999258818345205, 0.031138664494538983, 0.07925182641033204, 0.022495773530775504, 0.030911856503676505, 0.03202875715590293, 0.06117958628061799, 0.05526362167250726, 0.03908395196401304, 0.030738163303824204, 0.04779670440081147, 0.017820990103627407, 0.055216901800445015, 0.042679911223991264, 0.06827747899918787, 0.02983626714276691, 0.05186481513984261, 0.09264532626876909, 0.07661326638152523, 5.682507801440455, 83.53132078724524, 43.190543728490034, 42.18959016184653, 43.323308114082586, 16.338252482875703, 87.11964622620614, 75.71539417389901, 80.33357712530321, 14.138095032784248, 1.299713761095078, 3.630272981620604, 1.183989867568016, 0.8520026012293754, 16.024181439030556, 98.47643759942825, 75.64006897710985, 87.63431610599642, 78.06122256863502, 86.26471073396745, 75.29384920673986, 83.01308155059814, 78.36853242689564, 81.13643923113423, 74.53227396934264, 76.47927576495756, 60.97913180628131, 55.197542482806796, 53.8050304689715, 55.95650149929909, 51.87928791969053, 51.46094752896217, 54.200613267960094, 56.158374124957675, 53.328156548161665, 53.78846629973381, 51.187530871360536, 52.52323912036035, 51.68972761400285, 51.66643657991963, 52.23276407487931, 52.71035186706051, 52.10991936345255, 53.26742256841352, 54.74568151658582, 51.65346922412996, 48.895831185002486, 50.794513302464644, 51.87848383380521, 50.13865770832185, 52.00868691167524, 55.64365325435516, 57.61736246847338, 59.28392656387822, 58.41475286791402, 59.42820310592652, 60.34819110747307, 60.373160915990034, 66.00092272604665, 66.13778991083946, 67.08738004007648, 66.00531578063965, 66.84139251708984, 65.26668640875047, 66.05090156678231, 64.57327412020776, 67.53652280376804, 65.03190117497599, 72.59220692419237, 60.60966022552983, 55.38474152165075, 65.89340271488314, 69.31078341699416, 64.36504725487002, 66.03980125919466, 64.27162816447597, 58.88988917873752, 49.876274678014944, 49.44106025080527, 46.59722812714116, 47.42480116505777, 46.11822435932775, 47.95384260915941, 47.69788834356493, 48.392618548485544, 48.607803698508974, 48.37687807698404, 48.65265207905924, 49.51444779672931, 48.75561037371236, 48.86407567608742, 48.871300681944824, 48.34177678631198, 50.40169969681771, 48.47452548242385, 46.76787476385794, 47.676727156485285, 49.237614754707586, 51.134622020106164, 49.85249727003036, 50.28056513878607, 52.08076438596172, 52.8735303109692, 53.73810306672127, 54.336284129850334, 55.46903717902399, 54.5774902835969, 57.139758986811486, 59.59996761814241, 65.44604462961998, 70.31688705567392, 73.02950412996354, 68.00519897091773, 67.22347059557515, 59.09250705472885, 69.220412008224, 3.2783652842044835, 0.545485184317635, 0.7131495326757432, 3.9817680947242247, 1.334294479700827, 27.368849746642578, 78.56867528730824, 30.462005369124878, 20.792652945364676, 57.29612035136069, 39.583449748254594, 48.32140399563698, 51.24774317587576, 0.42222749021264816, 0.1293413821727999, 0.03972058252040898, 0.07394638408215777, 0.05546029559486816, 0.025523374074949853, 0.020707283814948414, 0.008963128165041488, 0.057304368820041425, 0.021136823568433043, 0.050632578035395955, 0.048031104323003566, 0.006762497988905037, 0.04479494208710329, 0.027756786589781125, 0.03392130076404541, 0.028909547817743117, 0.034729638437349955, 0.035340218173880736, 0.03682468972739674, 0.009117380926205267, 0.13587085680375177, 0.2850106016041771, 0.13787252197582878, 0.09694956062782197, 0.2583185048593629, 0.15148268682101082, 0.14373812013335768, 0.12970027904356682, 0.11518334188768942, 0.2705704571018296, 0.08488581320571323, 0.19947884604334834, 0.10986997054949885, 0.12814135906556923, 0.11626546406337332, 0.1186793534866264, 0.2141342306089017, 0.214256881285579, 0.13218845601283735, 0.1517397246413654, 0.2850156577844774, 0.16388823969229577, 0.17872210742244798, 0.19996158868795444, 0.20370477089478126, 0.5798097231215047, 13.359507495357146, 94.85810602864912, 59.11807306351201, 49.67657112306165, 75.68720802184075, 11.876251447585322, 81.46693814185359, 89.5481974078763, 81.32259491951235, 16.81136485069029, 4.662960729291362, 5.018973187092812, 1.1119348243359597, 0.6843679770827295, 17.541769012328118, 101.81484530048986, 77.84699055456346, 91.5305946719262, 79.0470318640432, 92.97612928575086, 79.74092268174695, 84.81987430203347, 82.35645324953141, 80.50947189331055, 77.06093972729099, 81.14617455390193, 64.17161949219243, 57.4581495408089, 56.32745965834587, 57.066877426639685, 54.84305827848373, 54.604990020875015, 57.38394221951885, 57.26145836614794, 55.920596122741706, 57.53398072335028, 55.67274155155305, 55.542307053842855, 55.0209338434281, 53.120776914781146, 55.58615522999918, 56.305651280187796, 53.259589595179406, 55.880595791724424, 57.317971875590665, 55.01881184116487, 51.993597553622344, 55.43510083229312, 54.178698985807365, 51.767335630232296, 56.07849113402828, 57.65213035768079, 61.87272617893835, 62.09349678408716, 60.94465025009648, 63.13442322515673, 62.65678836453346, 62.356236750079745, 69.70022770666307, 69.03157341864802, 68.4319842246271, 69.69428139348184, 66.88836682227351, 66.3808278114565, 65.73715117669875, 66.93614129097232, 70.0962458887408, 66.45759644046908, 73.30639992990803, 63.04198864967593, 58.28633054610222, 66.114561634679, 71.05496729573896, 68.28582102252592, 68.10288952242944, 64.4667072449961, 61.84987837268461, 54.087794134693766, 51.63239040682393, 49.14290128215667, 49.29347715070171, 49.054416533439394, 49.34702534829417, 49.80703307736305, 50.98378335275958, 50.87583580324727, 51.201973038335005, 51.311579750430205, 51.05062838523619, 53.0022507329141, 52.613904706893436, 51.66193762133199, 51.29727486641177, 53.515955709641986, 53.560549136131044, 49.78719372903147, 50.658611020734234, 52.35621675368279, 54.690685964399776, 53.35455409942135, 54.46404749347318, 55.755028955398075, 55.30689816321097, 55.62735972865936, 58.74080773322814, 57.935305872271144, 57.73107590213899, 58.807633153853885, 63.283567428588874, 69.8903920573573, 74.18658764131608, 75.54179791481265, 72.1825938070974, 66.3499116897583, 62.835064011235396, 70.07817945172711, 5.667405695684495, 0.346015531329378, 0.29569118493987673, 8.148906913495834, 6.176290569766876, 28.065758828193914, 94.90465671785417, 24.477470651749645, 32.770763443362334, 83.65766033049553, 50.121603242812625, 58.02903090753863, 68.35078331731981, 2.034547014101859, 0.4142606967399198, 0.24401575056535585, 0.20145424972138098, 0.16167145703108082, 0.12280468333272204, 0.09832966036253399, 0.07569388426359623, 0.2437944277640312, 0.17670728085983187, 0.16116804533427762, 0.1828793601523484, 0.10135542421090989, 0.11408900060961324, 0.08735348966213004, 0.11764814551439016, 0.10471859616377663, 0.15772040452687972, 0.10675956164636921, 0.1331743345625939, 0.13665441153270586], [0.07742430068432324, 0.037732327717446515, 0.015249350727836211, 0.05301777746588473, 0.043275950611719204, 0.038752346975548614, 0.04762181035813786, 0.06850700660218155, 0.043638796665735786, 0.07190084505465723, 0.04507159175831945, 0.04584559720129736, 0.083806173154904, 0.05986162010700472, 0.023867294995955402, 0.053718299755165656, 0.0075324857795250515, 0.027102945868166226, 0.02845219332694767, 0.0330595093058242, 0.08432237852004268, 0.023621838509796128, 0.05505975035409774, 0.06418833531619561, 0.07274852900375282, 0.05869817769815845, 0.07736535021854986, 38.52667693168887, 67.32174165787237, 27.936120571628695, 63.51489705424156, 24.921369206520822, 16.902477587423018, 79.79523966389318, 68.78287161550215, 43.099191727176795, 0.9923410223376368, 2.9604069263704362, 1.301079603933519, 1.0946205018028137, 0.08378331309124347, 31.928177533611176, 86.79787851149037, 79.56764805701472, 83.78597674831268, 78.08179147781865, 85.14250493818714, 78.9194606965588, 79.03162479400635, 77.59213847498741, 77.99560916039252, 64.16850905264577, 58.58427378439135, 54.04880185281077, 53.9005401826674, 51.77328194341352, 53.20961075444376, 51.19303003434212, 51.36692439356158, 51.487541198730476, 50.766342839887066, 49.65484119230702, 50.59564913472822, 47.06988157764558, 49.77229264474685, 49.86145204113376, 50.698630963602376, 50.10192863402828, 50.91614207913799, 48.57319270410846, 50.32817094556747, 47.76441174168741, 49.41021865414035, 47.88796640211537, 49.169620467770486, 48.23068741829165, 49.86269543247838, 54.19411782295474, 55.85765384858655, 56.745168547476496, 57.27964639663697, 58.192899688597656, 60.48023769932409, 61.614677367671845, 67.56404999763735, 62.97571628324447, 62.91779464290988, 61.37630316518969, 60.24580155649493, 65.20175549291795, 65.37176670566683, 61.47233063174833, 65.66099051506289, 66.38517379760742, 63.60183638911094, 68.26171413544687, 66.74931095492455, 52.20156554252871, 56.398274129436864, 63.66705756033621, 65.0696579102547, 60.733234497808645, 54.15122278275029, 49.328323487312566, 46.63707156335154, 47.6851837865768, 45.49364574493901, 44.519599637677594, 45.3928251420298, 47.62985483292611, 45.65935803997902, 45.90643990424372, 46.80836146877658, 47.82060753914618, 52.95315050309705, 59.13948135991251, 59.29139867905648, 53.28453979184551, 46.86628310911117, 45.72175510468022, 49.735234091358805, 47.29703387906475, 45.63743199071577, 47.23596649785196, 47.955223283460064, 49.4997702875445, 47.85498711370653, 51.10499635819466, 52.72803391179731, 59.370701159200365, 60.54398405936457, 62.50263921676144, 62.55425760822912, 65.1859797200849, 64.71260455346876, 65.70870222583895, 66.16013173134097, 70.324582745952, 71.5162850964454, 56.227760853305945, 60.10132497356784, 43.8654032061177, 0.010776755140884029, 0.08950334688227984, 0.8662097324286738, 7.765655556032735, 1.7548061474677057, 48.35212007645638, 54.12187953149119, 8.148789732686936, 39.681038318141816, 45.648316567943944, 30.234580462978734, 53.08933911785003, 21.72063277613732, 0.327100943052961, 0.014891971668769276, 0.04262924599911898, 0.06285700856918289, 0.01767388398518726, 0.022353260109441418, 0.03351251624764935, 0.08772090543061496, 0.05826876243396152, 0.0611216547117839, 0.05664484755646798, 0.021047806066851464, 0.049974585117231456, 0.03494533049243112, 0.10363284273133164, 0.035983314512357596, 0.023389679394782554, 0.06924204498289094, 0.034012832949238445, 0.022025301699496565, 0.035983743521595196, 0.05077184898959053, 0.03206136568839992, 0.04101550093882027, 0.036551564060632265, 0.038234877565334884, 0.01776472669124844, 0.026389501590822494, 0.03539792374677716, 0.054225323556531826, 0.02011676792115454, 0.01381896689699422, 0.025734542380838145, 0.15591715612719137, 0.015864404417844792, 0.022077499100217418, 0.021822102623240604, 0.032402274814704736, 0.058541585495995904, 0.019209784936280023, 0.04796687551143189, 0.146350571885705, 0.027785846219968893, 0.039582866724700703, 0.08086310083707494, 0.05481460604876761, 0.06965212418787903, 0.10975630608417335, 45.93821110263948, 72.86580008845176, 30.132061473784912, 67.7266400860202, 16.25094444521012, 37.21551095285724, 86.31334027936383, 74.0881439947313, 46.38074075022052, 0.04917542900769942, 3.9135919078703854, 3.0575338823180047, 2.56923409719621, 0.16357184537956793, 38.302070248511534, 85.13193022820258, 81.42468637035739, 84.30092119401502, 77.95038423230572, 85.22965215867566, 80.29922500733407, 80.38419923474713, 80.0186029557259, 78.75690983187768, 68.40197024806854, 62.201271749311886, 57.137993920233946, 54.93087622427172, 54.299417772600734, 56.28136396408082, 54.14920668448172, 53.16463293567781, 53.3203588762591, 54.56276570597003, 54.21942887767669, 53.44418810259912, 51.010498616003225, 53.36744300780758, 51.62073312267181, 52.62016873205862, 51.7957845810921, 53.21401949851744, 51.23616041675691, 53.67984802492204, 50.38266051200129, 52.91756283852362, 50.61338217027726, 53.49937192855343, 52.24813976595479, 51.76043225872902, 57.757685261387984, 59.16360001410208, 58.978177808946185, 61.300185649625725, 61.40619947064308, 63.496830617227864, 63.522176973281375, 69.707123233426, 65.42711527116838, 66.95532952585529, 64.45549711104363, 62.62648021021197, 67.65160514462379, 67.5085327702184, 64.13941291070753, 68.47326324832055, 67.89777309663835, 66.78351402282715, 71.70016581012358, 67.17054213246992, 54.359496716530096, 62.20959501881754, 65.38819751431866, 67.49068598593435, 63.58861407926006, 58.26466729564052, 52.175034630683164, 50.12061872789937, 47.526147365570075, 48.75936408196726, 48.46857524687245, 49.33792937186457, 48.247510463960715, 48.53223923713931, 49.14142254860171, 49.33822354962749, 49.95765209197999, 54.3672747765818, 60.12161147209906, 59.95888802313036, 53.912487722212276, 48.564261467226096, 47.72109308550435, 50.04257925095097, 50.70476947292205, 47.75120512131722, 49.080566975378225, 50.85485112282538, 52.345469459410644, 49.95925241901029, 53.034441624918294, 55.232004427140765, 62.56217687360702, 65.14582249426073, 64.09474103681504, 66.88027105023785, 67.5484311196112, 67.67625331878662, 68.37911067470428, 71.17834937187934, 71.61101818084717, 73.39479446411133, 57.604453948236284, 63.296507327787346, 45.492319983820764, 0.07665235218742202, 0.9802089475335615, 4.15189697857826, 2.909635766859978, 2.607631649701826, 53.658977093235144, 62.9636275383734, 15.610788137682023, 26.940683818632557, 51.27018697800175, 35.16686877896709, 62.698075232967255, 27.368492810956894, 0.42710477366082134, 0.07140137104978485, 0.06503491992911985, 0.04149037203000438, 0.05367380919896307, 0.05767851084050152, 0.003330609146242721, 0.030516105058092265, 0.03322503792362348, 0.15012268157255265, 0.01709318550814304, 0.03468639277402432, 0.04493566860835399, 0.03149746943475499, 0.008829399856979088, 0.012971641094003235, 0.025567929748626008, 0.08369285342914444, 0.05332756810070527, 0.02633355227449248, 0.024583625509553862, 0.08806729974645762, 0.15870458236144436, 0.15981700331453355, 0.12947219934675003, 0.14488545937403557, 0.2809262804446682, 0.17753539126246207, 0.12553973213559197, 0.279705258867433, 0.13460901806191092, 0.10630114995423826, 0.17733619308039067, 0.3817599987791431, 0.21041268272505653, 0.10490457932915419, 0.19768054657165082, 0.12822381310885952, 0.17352967072398434, 0.14139055094170955, 0.12518513301808026, 0.25031159902291916, 0.09396604652847014, 0.21047634463156425, 0.1905420933279299, 0.19115824252367022, 0.1465998262527489, 0.4768034713643213, 61.42042590725807, 86.82707663505309, 41.44939184188843, 93.7357747170233, 35.20567278708182, 26.135287861670218, 96.71344987807736, 81.7874114744125, 51.549475423751346, 1.893863608279536, 10.510597863504964, 4.6358444036975985, 3.0750835470614897, 0.2083693117263817, 40.24981729445919, 88.43080043792726, 82.40840112009357, 87.96683895972468, 80.8847564266574, 92.4238124970467, 81.6460806323636, 83.54252307645737, 81.43394316396406, 82.00322028129332, 71.18246786056027, 65.44340879686418, 60.96272453185051, 58.71879146945093, 57.421177279564645, 60.408713279231904, 56.815500567036295, 57.7278164125258, 57.414921099139804, 58.090698411387784, 57.35529322778025, 57.52417479791949, 53.6067585791311, 56.87192386196506, 56.37484581239762, 56.13399267196656, 54.7926518993993, 57.170851615167436, 53.92977360756167, 56.974085915473204, 52.19777653294226, 56.811366388874674, 52.96830654144288, 56.982946549692464, 53.433307447741115, 54.75179256931428, 59.37251329421998, 63.42192903641732, 61.384481306998964, 63.60064791094873, 65.05253676445254, 65.74887906351398, 67.02709321052798, 73.23822913631317, 66.88494651548325, 69.2516968327184, 64.49063370304724, 60.11441392283286, 67.53976268153038, 72.90160348338466, 65.84724426269531, 71.68685328575873, 68.9101682170745, 68.46433593380836, 69.25598006094657, 67.37708630100374, 57.21664528692923, 64.85420211668938, 68.26690735355501, 69.26186361620503, 65.40948813961398, 60.45414609293784, 54.21138801882344, 52.15843123774375, 52.69756494029876, 51.513770088072754, 50.85048160245342, 49.4821156993989, 51.270339950438476, 50.506638788407855, 50.90129590803578, 51.31682395935059, 52.66688416081091, 58.514451672953946, 64.39797947483679, 64.65069386266893, 59.9806454104762, 50.586917938724646, 52.10223544028498, 54.05834890181019, 53.038214945024066, 49.66645925275741, 52.66032595788279, 53.49088391950054, 54.81125177875642, 52.99535128378099, 54.82273255625079, 57.85362251343266, 64.92530292080295, 66.07747954706993, 67.2681228576168, 69.73152822063815, 71.54505175928917, 69.36923457730201, 71.57821932146626, 72.89906963225334, 75.86072583352366, 74.130293784603, 62.73751858742007, 64.97282243544056, 50.99940615315592, 0.27759805742290716, 0.502387743683592, 4.349036284031407, 19.127345969600064, 4.0334048723020866, 57.58999609178113, 69.67193957298034, 12.176080365334789, 61.84356727907735, 63.23185882260723, 47.11573800733013, 68.27489329922584, 38.73705325588104, 0.5314721491548323, 0.19862557731328473, 0.1454926300193033, 0.14897013293398967, 0.0764348061995641, 0.18678562715649608, 0.11440550983552972, 0.13470418150386504, 0.1588158949368423, 0.19008331391359531, 0.15438214575331058, 0.14443804870449728, 0.09744421593965062, 0.1260416652827013, 0.1281300439469276, 0.09318233092105196, 0.1282417931924424, 0.18694088253523075, 0.25886723831776653, 0.1266365708603013, 0.17980754675884403], [0.02996735244749054, 0.06496496077987456, 0.059698152265721754, 0.038504931219522996, 0.0713020324286434, 0.04108008215083711, 0.0636257701403191, 0.02498483916203822, 0.051393594457617695, 0.0163274614756266, 0.04597599302688914, 0.0511151866146153, 0.10047671370088093, 0.04479445945171099, 0.00971952794990953, 0.013575394987128677, 0.030995955720784205, 0.030284260039127646, 0.011590362541497716, 0.04130777114281251, 0.012582917547514363, 0.07892983199487771, 0.018251617701964516, 0.025116891652766257, 0.00942957994993776, 0.12087112337711359, 0.31454157504823904, 7.666068538542717, 78.67928612616755, 44.80603464188115, 39.387962741236535, 74.20741542693108, 10.297641600331954, 50.26297723093341, 79.54189377446329, 59.130875679754446, 2.7721772847637056, 3.8252204175918334, 1.2086815555249493, 1.8743085092113865, 0.7665846556905778, 0.059389970415542205, 58.49570274353028, 88.94166561865038, 79.68123205246465, 85.58548958070817, 79.66687617763397, 82.3152683627221, 81.17373312673261, 79.9010181427002, 71.72733999067738, 68.57876716121551, 56.941812653695386, 53.17839261024229, 52.43611543409286, 54.47455552316482, 54.257267982729026, 51.54747501496346, 52.02735739369547, 53.49648898647678, 52.82831322762274, 52.226837373548946, 52.649637499163234, 51.1064358680479, 49.21689287308724, 50.1125817914163, 50.69164914469565, 51.031130283109604, 51.25092421808551, 49.97327489237632, 50.21127646969211, 49.13588023954823, 48.99351781414401, 48.14240271045316, 48.52084475178873, 49.14312093488632, 50.69493609090006, 57.14682317549183, 60.737780524838364, 59.06927485619823, 58.11713910871937, 58.50966638134372, 58.88016954545052, 62.22854006674982, 64.17027411922332, 66.21589214571061, 62.55447333858859, 56.331327115335775, 56.817124428287634, 63.54604851815009, 62.97280980694679, 64.47897641889512, 66.19293059072187, 68.01464403829267, 69.78940671490085, 63.280001994102236, 64.68895266132971, 65.52685329991003, 60.10177212376749, 62.917645592843336, 60.70915898969097, 58.0019037954269, 54.92077219870783, 49.99024306574176, 47.82418081837316, 45.77300087098153, 44.79138066691738, 46.21426359299691, 44.681044393970126, 46.295668463553156, 45.775766141953014, 48.07997426679058, 48.91138338273572, 54.877206433203916, 62.57152388172766, 63.4107816603876, 62.8677922679532, 63.45983874413275, 53.80027655632266, 47.57520444931523, 49.31855286321333, 47.29737120289957, 45.8575907061177, 47.14114712130639, 48.78981736398513, 51.5764299515755, 51.08298401678763, 52.575277205436464, 56.75340160246819, 61.47661778234667, 67.47237636196998, 67.10593285099154, 67.30631889835482, 68.6037761934342, 66.13549924665882, 67.15591169172718, 72.22778735622283, 69.88610882912913, 68.85105025383734, 53.65620789989349, 60.340036499884825, 18.93012135259567, 0.44436629741422595, 1.602363353294711, 3.376264701927862, 1.965171562567834, 3.2187550635107103, 62.56249458559098, 22.500433306540213, 18.618918541939028, 50.98526993105489, 58.59688028212517, 40.57107902342274, 63.538807822812, 9.0108698221945, 0.46272801535744823, 0.21384469533879913, 0.027118543418304577, 0.11884834482184342, 0.08088039144152596, 0.05903582328990583, 0.06275467071381789, 0.11609156210456165, 0.06410654776939942, 0.01894977660999904, 0.04022722327781301, 0.0347600904323401, 0.04812616434308791, 0.04244277636790949, 0.053642460881101514, 0.07762789621108002, 0.07735700752105444, 0.03484434861269209, 0.027078432969809062, 0.08366378805329723, 0.04921389045193792, 0.0721576836921515, 0.06314382039671464, 0.022227667655134876, 0.0170460193898649, 0.09263257090482982, 0.0346768319967293, 0.050962715965485385, 0.02958902184130444, 0.03631458242213534, 0.07232770158518707, 0.05059727287340549, 0.021900557687566168, 0.05788807419218844, 0.02114724619464288, 0.04141334188921798, 0.0300220396339653, 0.06067931171386473, 0.013171791140320561, 0.026280966084150058, 0.06945327840625279, 0.04176364325347447, 0.03463870380073786, 0.051325925911266, 0.052962151821702726, 0.037133446143519495, 0.0684439116007378, 0.2566506241958949, 8.682079103685195, 93.06902670091199, 41.92207667135423, 50.70305539715675, 60.48408162209296, 15.243546424373505, 74.10373149379608, 78.61122515893753, 70.00006152737525, 1.8495623983683127, 4.553937469759296, 4.196351651222476, 3.998215573449289, 1.4929316769684515, 0.20588199277558636, 60.479755247792895, 89.66062822649556, 81.97543421099263, 87.84204483032228, 78.91969603876915, 83.4816086676813, 84.22476445474933, 82.37351555978098, 75.43524280671151, 71.44991859312981, 59.698509323981504, 57.224976401175226, 56.350974267528905, 57.7038860321045, 54.79022002989247, 55.28288149064588, 55.882054913428526, 56.698817899150235, 56.09037199328023, 52.98235647140011, 55.37530037664599, 53.012401826920055, 52.91380913026872, 52.265876723874, 51.983273875328806, 53.10012171345373, 55.10875571158625, 54.8205634855455, 54.482565003056685, 53.69747515647642, 51.267547222875784, 51.103278360059186, 50.50150048348212, 51.02983197858257, 53.943599962419086, 59.78528784167383, 64.14399816143897, 61.41025127903108, 60.72518579421505, 60.07892823988392, 62.918586961684696, 65.26486642899053, 66.93465079030683, 67.67342136752221, 66.37862343941966, 61.173728435270256, 58.642917140837646, 65.96756689010128, 67.38318166425152, 67.66564722984069, 68.80045952335482, 69.83779307334655, 73.2951819512152, 64.6976956244438, 68.85378806821763, 65.53407046102708, 61.17688986562914, 65.2634818323197, 64.29453088391212, 62.554896954567205, 56.76029712923112, 51.60645569524458, 49.68870693637479, 50.26252615836359, 48.2814311212109, 46.95723110629667, 48.046892996757265, 49.63890067992672, 51.30763384603685, 48.934446919348936, 51.18536964539559, 57.11803297842703, 65.6761504757789, 65.28224252885389, 65.36389450873098, 63.824936882142104, 55.12568466124996, 51.16345928561304, 50.92211192654025, 48.227529910302934, 48.23992067767728, 49.97700114404002, 50.959762757824315, 53.3750916296436, 55.46998639260569, 54.72228065613778, 60.33415686699652, 63.78295967655798, 68.3356115894933, 69.83868737374583, 70.13459097954535, 70.65663491525959, 70.69246968915387, 69.46033554692423, 75.70560393794891, 73.40343152323078, 71.00763213249945, 57.590419707759736, 67.34595052657589, 19.673033952713013, 0.38539873255837354, 6.095531419400246, 4.39260155923905, 1.9941103194029102, 4.72054700697622, 63.99659156799317, 31.822534376575103, 18.595145056324622, 54.837774845861624, 63.361371563326934, 43.41541713283908, 71.41414657715829, 9.247925127706221, 0.547664612531662, 0.08822358934389007, 0.06387740321036789, 0.03421846243943419, 0.004733677872742016, 0.06475535146291218, 0.03025119376909589, 0.017181318178172075, 0.15336317220522513, 0.02005299493189781, 0.04485697988721152, 0.019301851467800238, 0.04328733084783439, 0.021592232195900816, 0.06792749173098034, 0.07218969084562794, 0.09392264764755966, 0.034261635324407014, 0.051183847244828946, 0.02875100209137365, 0.0948209393649332, 0.10388690813054001, 0.1586963545771376, 0.19507498961062203, 0.20890319840081278, 0.18660720527893115, 0.13243849178956402, 0.23839398287236693, 0.12665243654121316, 0.1310887980845667, 0.18287228149992807, 0.1435925327842274, 0.0933384366573826, 0.19070076545880688, 0.12832078451831497, 0.17528767397086467, 0.12359982131109123, 0.15897349454462528, 0.1864618171126612, 0.18153414040082888, 0.17221975230401562, 0.15028965809652883, 0.20403748288029627, 0.14755971910011384, 0.19499949930656343, 0.17255088614840663, 0.26252748384591074, 1.1211669805549807, 17.589104175567627, 102.31318243088262, 62.75902102070471, 57.60404209936819, 103.90410361751434, 14.376001492623361, 64.02063961951964, 91.84345076161047, 71.54047827566825, 2.393870810347219, 7.715405581458923, 7.389781686567492, 3.486163630600899, 1.7251048573563177, 0.40447410736833855, 63.98256124988679, 90.23443175900368, 84.37845860758136, 90.89120911013697, 82.5859119046119, 85.2083223096786, 89.1462564468384, 85.31788979807209, 76.76333381283668, 77.29081415360974, 63.961804066934896, 60.86261387794249, 58.71306873136952, 62.05472415493381, 57.6442503160046, 58.28236895222818, 57.709600925445564, 61.09237455552625, 59.37399202777494, 57.78825229214084, 57.8277740939971, 57.51695371443226, 56.462879488545084, 57.75877568029589, 54.90413742680704, 56.59988395629391, 55.448833050266394, 57.901267543915786, 57.172691206778254, 56.64166504336942, 53.87793164099417, 55.317884722063624, 53.407600233631754, 54.06674669634912, 54.79094566837434, 62.531900098246915, 67.00242150214412, 63.72148829121744, 63.162566231143096, 62.54677372594034, 64.36320374088903, 68.27909808005056, 68.44972902728666, 69.90770539929791, 66.56338276401644, 62.91485286528065, 58.23293532094648, 65.37411620540004, 67.27715215375348, 71.92477641567108, 70.49615506202944, 71.76322967775407, 73.87891692499961, 66.5078184681554, 68.56503886561241, 65.79163289839222, 62.90047345622894, 67.4130936591856, 64.5934586371145, 63.67468657032136, 60.911910226268155, 54.03696021726055, 53.93781838878509, 53.92749863286173, 50.5938095431174, 50.43269818828952, 49.11658217830043, 52.148629234683135, 54.15627087316206, 53.74743438536122, 54.12502527236939, 59.34464485414567, 68.0492550326932, 69.00021014675018, 67.41634922642862, 67.76335347083308, 58.30599731014621, 52.36561083024549, 54.89672022481119, 51.05900264555409, 49.9376872278029, 52.75964821538618, 54.765477718845496, 56.11811099513885, 56.12371998448526, 58.35974554861746, 61.91945337480115, 67.6342761132025, 70.32944648496567, 71.99907395147508, 72.35449560226934, 73.58170324756254, 72.08677030378773, 72.43464531437044, 78.30797887617543, 75.24785549409928, 71.44998135105257, 63.58994768511865, 65.89519916042205, 25.091019561213834, 0.6081518506811512, 5.433959461027577, 11.915917396545412, 11.37086974036309, 3.7743801263070877, 75.45354458593553, 28.42809561760195, 29.309728722418512, 77.85258385442918, 71.59730557472476, 55.585217783527995, 81.08573082954653, 18.18473373689959, 1.201188235032943, 0.5203375208281702, 0.16030146199609005, 0.22648928296421805, 0.2329049935384143, 0.12717868531903914, 0.14850487241581564, 0.17967654572379205, 0.27143423655821436, 0.13891809409664524, 0.08217287370033803, 0.10559028164753992, 0.08958203943386193, 0.1719444356257877, 0.19808277337541505, 0.1931282989079914, 0.2796227971632635, 0.11540908501633715, 0.16318002204981544, 0.19977952023186993, 0.14308826306894903], [0.11284767004150538, 0.018070688801667383, 0.04140087380825032, 0.0516801841196514, 0.08933807107349558, 0.039359590399169156, 0.14021809933887375, 0.04445307535089312, 0.020818780251448194, 0.03889885363018802, 0.028209923766553405, 0.03594117201564293, 0.021472979119167696, 0.08786090799877722, 0.04183275970600305, 0.03973273650532769, 0.021275090947446805, 0.028946634134157535, 0.06698616885489996, 0.044907311863836744, 0.02533568636394076, 0.06785727977272003, 0.13023888481961143, 0.01949947916962687, 0.0845974653718933, 0.053595622265411, 0.08196530217725424, 0.10566570300368533, 37.74758831147225, 70.42749789453322, 33.10610648124449, 52.14305946903845, 33.92881970251761, 12.372164553211583, 85.20896557838687, 67.81966301702684, 14.138880487411255, 4.708819120160995, 1.9606575273698377, 4.299737974520653, 0.3900263939172991, 0.3270329450888019, 26.296014824221214, 103.51064282078897, 78.84730477486887, 83.7024930215651, 78.92493632531936, 84.2315423104071, 75.06573984699865, 78.19668554490613, 65.85367694977792, 59.8601148974511, 54.738668318717714, 58.7537907784985, 53.703601898685584, 53.47531603228662, 52.97563352892476, 53.47629662482969, 52.836973820963216, 52.6282331251329, 51.30533925948605, 52.82933696623772, 51.65444197193269, 55.70404991026848, 52.713689804077156, 54.062749801143525, 52.362190523455226, 53.276012559090894, 52.50615719825991, 50.965461961684696, 51.46102205399544, 51.05837898869669, 46.820332542542495, 49.05290249855288, 47.88904505391275, 51.204734386936316, 49.10578781558622, 60.05935953509424, 59.24120803033153, 63.186543680006466, 58.987713090835086, 60.831285907376206, 62.18673544545328, 64.55181483299502, 66.09215705625473, 66.07922892416677, 62.10033739766767, 59.910944892514145, 59.0057756054786, 61.52051302694506, 62.86561927487774, 60.26036139457457, 64.0083900574715, 66.22561962373796, 61.197125373348115, 61.44180674706737, 62.026808646417436, 67.30523632418725, 66.99024646512925, 63.59794147552983, 61.9570061468309, 58.41075597270843, 53.92239562926754, 48.65908084377166, 48.43263456898351, 46.09311334548458, 46.762183404737904, 45.35489190009333, 45.59342299738238, 49.28726019397859, 46.59753799438477, 50.16359613787744, 53.32460288078555, 61.0097655173271, 63.013453406672326, 66.66706669715144, 63.262347405956646, 63.334679834304325, 62.60809213884416, 52.435891858993045, 46.478356776698945, 49.524485142000266, 45.464200512055434, 48.77816007983301, 46.3167590479697, 49.75195515540339, 53.78449686111943, 52.262605467150294, 55.57705925356958, 62.3049399929662, 65.73666872516756, 68.67711667091616, 72.70579876438265, 68.61905774762555, 68.4811472123669, 72.62930470128214, 71.6453310751146, 73.93165711433657, 59.78109482795962, 61.284927629655414, 54.993696904951534, 0.5377888811692115, 0.030354701823765234, 3.037967383861542, 7.03110593941904, 1.567888048387343, 11.083317841252974, 68.47395358547088, 12.627234324332207, 32.5385905081226, 43.001689449433364, 64.94435779510006, 54.06712716625583, 37.476230898211085, 0.19184056639430985, 0.022706539640503547, 0.0014914243999350396, 0.055511646468432686, 0.022378623365394534, 0.016658537863423268, 0.019515358257077394, 0.020538321208028544, 0.09890746685766405, 0.025470851086861184, 0.05259912573702393, 0.019900028240836917, 0.08598538686431224, 0.04782058336141129, 0.017426326502895644, 0.0676175402176957, 0.08898374008675737, 0.01683492960798885, 0.03442386593369227, 0.10787372927992575, 0.09659899113279197, 0.05789620621550468, 0.04680614122339795, 0.04878185516703994, 0.05021635097481551, 0.07582055690187602, 0.0198626374044726, 0.018557041635616653, 0.07304128184313737, 0.05512494826689363, 0.02645441030542697, 0.03560742964186976, 0.04839447131680866, 0.023468626670599468, 0.049810247766154434, 0.036326483598039035, 0.02620317943153843, 0.05392097214597368, 0.01609601290716279, 0.04767435249842463, 0.09056942717682931, 0.03942265858753555, 0.018926552654574477, 0.01941824129091636, 0.11897502512100244, 0.028151936656344804, 0.07575825097099428, 0.0672233343544987, 0.04351359491627063, 0.24932697685735844, 44.679926518471014, 78.06229729806223, 36.0323436798588, 66.23990489590552, 19.12263128065294, 28.47761554102744, 92.76821228765672, 78.26647235501197, 16.59372429693899, 5.137537121772766, 5.241760871102733, 5.960381742446653, 3.7007969521707107, 0.5282653663908282, 30.220167713780558, 103.80855468011673, 81.37340530272454, 85.59072986725839, 83.96612336558681, 83.7007514892086, 78.98519177590647, 79.43637417208764, 70.0950691776891, 63.06555032730103, 59.37307811552479, 58.77805456038445, 55.556247157435266, 55.825568860577, 56.015231147889175, 55.46702500312559, 54.986832757149976, 56.75133059101721, 54.24020175010928, 55.59055220696234, 57.06480249281853, 57.47928719366751, 55.22672099451865, 57.015745409073375, 55.85596330704228, 56.12584983148883, 54.129500696736, 52.74817920500233, 52.6663899421692, 52.18331083174675, 48.6137931577621, 51.1074556842927, 48.829802005521714, 52.38683869761806, 51.036884400152395, 61.98399205361644, 61.40763113575598, 65.28539219210225, 60.99827297272221, 63.27857032898934, 63.9397446570858, 67.38327580113565, 66.71641011391917, 69.30123636799475, 65.53944803053334, 60.05433105653333, 60.56663966947987, 64.69424393869215, 66.25342138351934, 63.82279526802802, 67.00504164541921, 68.98430101333126, 64.53984375922911, 66.64361092352098, 63.35087922311599, 69.61699501160653, 68.08989863241872, 64.70523834228516, 63.22066045576527, 61.14366346789945, 56.66742324829102, 51.239466974812174, 51.667185752622544, 48.9384908829966, 48.684654697295166, 48.94779082267515, 48.04060543737104, 51.170468561110965, 50.30754712320144, 52.16469918527911, 57.338132858276374, 64.48606806416666, 65.88569133512436, 67.41713370046308, 67.28771117425734, 68.31428174049624, 64.39627324381183, 54.68271570820963, 47.670255245700965, 51.49946128168414, 48.58780353300033, 52.2400910623612, 50.00033140182496, 53.699428496822236, 55.610317030260646, 55.61824021800872, 57.396521260661466, 64.05628219727548, 69.58167014583465, 72.20743809976886, 74.54530408305507, 72.66460603283298, 69.55438613891602, 74.47896111396052, 72.57513676920246, 75.62554836273193, 63.697502997613725, 67.15632746296545, 56.933579598703695, 0.3158893075681502, 0.10931759051257565, 5.229676048601828, 4.513099222413955, 1.8002047630087024, 13.490051819432168, 75.17149479158464, 18.844421486700735, 27.442913901421335, 60.541885591322384, 66.91194026700913, 60.21859991934992, 45.465290930963334, 0.7883617774613443, 0.0954411871310684, 0.05236574088133151, 0.018212072243313157, 0.008158647744435697, 0.025737867202429522, 0.015058218493997572, 0.04553977873236422, 0.08045728874182509, 0.020469244975115986, 0.017010172220668005, 0.03637799535006766, 0.04665446730570928, 0.059384067708085624, 0.0014265804437004152, 0.04741088720038534, 0.03671939477264401, 0.025290274587009224, 0.07262192531338624, 0.05151974998654858, 0.05321377723087227, 0.040250382115764004, 0.1514923088853398, 0.17033483893159898, 0.22915695433414754, 0.12055820710356198, 0.2806292221911492, 0.16215637536539187, 0.2873589981707835, 0.09295874049947148, 0.21183668695870908, 0.14804606235796405, 0.09650316119434373, 0.10387408381868755, 0.10486691078591732, 0.17548252077352616, 0.1593950114423229, 0.16186028238265746, 0.12994478366548015, 0.1549158945319153, 0.20955953656906084, 0.1265502863773896, 0.15738216138655142, 0.16907946597183907, 0.4841591105345757, 0.14522213969499836, 0.19384958601045996, 0.2169461256914562, 0.22140060521421895, 0.7399661033864945, 62.00944823603477, 88.85563235129081, 47.238669010900686, 77.14828306628813, 48.89547032694663, 20.088597305359382, 97.45270682919411, 85.17391527852705, 16.614808997800274, 10.027396179014637, 10.329121562742419, 8.102261106814108, 3.4983624469849373, 0.4123209621156416, 31.127121679244507, 106.76770840921711, 84.80155683332875, 88.78440210896154, 86.22361213930192, 89.51477096926781, 81.33704493122717, 84.78959360430318, 72.76383415345224, 64.95677994143578, 62.03683422457788, 63.62812019163563, 59.78608800518898, 58.58889041408416, 59.128808590673636, 59.15777529439619, 57.631137832518554, 60.11232329953102, 57.17083984805692, 59.02564241040138, 59.66767164968676, 62.86724705849925, 59.835894261637044, 61.34255901459725, 58.58151243579004, 59.6304444343813, 58.239575893648215, 57.52810109046198, 56.12714813601587, 55.397218581168886, 50.655555494370006, 53.08844481745074, 53.05590875687138, 55.17397296044135, 53.52598913254277, 65.96119696094145, 63.24597151048722, 70.10913479712703, 63.47333561989569, 66.87039452214395, 67.17910074418592, 72.0374818002024, 69.1846243027718, 70.92861990774833, 66.36924897470783, 62.47215847815237, 60.39862886551888, 62.74655572829708, 67.4084181939402, 65.77429602223059, 68.61260152632191, 71.34195143176665, 66.87124175410118, 70.2707992061492, 66.02737519048875, 70.31443949668639, 67.5297684823313, 66.98497479961765, 65.06348409960347, 62.83178098740117, 57.9582360482985, 52.53453554645662, 54.94014870735907, 53.90955771169355, 50.61300562274072, 52.64052191088277, 48.258724520283366, 54.20089175624233, 51.956354648836204, 55.55093626822195, 59.72670332078011, 68.35819659694549, 69.75361900944864, 70.9771631610009, 69.89319262966033, 72.06968445931712, 69.30090688890027, 56.77638276930779, 50.29371684597385, 55.897277632067286, 52.00983616613573, 56.11852284400694, 51.62887988551971, 55.85879525830669, 58.746487325237645, 57.36508346373036, 60.288120008284054, 67.19163663925664, 70.69778057836717, 72.48130582994031, 77.46233940124512, 74.10286072761782, 71.67895363223168, 77.47803672667473, 75.23029112046765, 78.05180888022147, 69.12188991423577, 65.461569370762, 59.89558096854918, 1.2109754066313467, 0.1550801591046395, 7.622567492146646, 18.773385401695005, 5.2011564950789175, 13.310241545400313, 87.34533940592121, 16.40325204018624, 55.09381148122973, 58.810504328820016, 75.06790499533378, 65.96230306933003, 63.60051847273304, 1.299528306530368, 0.34338640950379834, 0.2002864559331248, 0.1877900603557787, 0.09866578910019129, 0.20790952107598706, 0.12509836589977627, 0.1665671112676782, 0.14579145027504814, 0.1297025313420642, 0.1529514765547168, 0.17086731600424937, 0.25379703860850106, 0.11179192427305445, 0.12008186129312362, 0.15137544983337003, 0.22753183669861288, 0.10461731934018674, 0.17936312383221042, 0.12017649613440999, 0.19784053637375756, 0.1299709532289736], [0.02578166444906064, 0.030005844535246014, 0.02859494998119772, 0.03259038770451181, 0.03235340606601488, 0.08333394123661904, 0.022006316125513087, 0.09351473647139727, 0.013432406591281537, 0.0781139100511228, 0.018534434380971136, 0.047061049319323034, 0.04441770890186872, 0.04654533425045591, 0.014948189115872788, 0.01546802094972302, 0.033068978152568304, 0.0500281767979745, 0.02748614304789132, 0.04349849149284344, 0.059960855306276394, 0.032724667595879685, 0.06769787219743575, 0.05427511544117043, 0.017187416238049348, 0.10755712046257912, 0.2393081555924108, 0.37304060052960153, 5.442855886874661, 70.71722768968152, 55.966511387978834, 44.86046537276238, 87.70793899413079, 18.34467230304595, 34.328944606165734, 75.77713228041127, 24.627760187272106, 3.265844588318179, 3.786483825214448, 5.575595267357365, 2.5003168275279384, 0.6419310574570011, 17.212195780969438, 104.32917087308823, 76.56313603924167, 88.8549106351791, 70.47899077015539, 74.11486318034511, 67.9418134689331, 67.55298891375142, 59.20368663726315, 60.67039420527797, 59.77211260026502, 54.31766071627217, 57.345102910072576, 56.75106386984549, 56.581276232196444, 54.562420537394864, 55.50027101270614, 55.9260521396514, 54.18332738261069, 52.78011122057515, 55.31990474270236, 52.38332425394366, 54.85466457182362, 57.1789042411312, 56.38367506765551, 55.46921760805192, 54.70841507757864, 54.67959742392264, 52.93057726275537, 50.2503550437189, 51.22976303100587, 49.63698264091246, 51.41265138503044, 51.85752660997453, 50.94866245023666, 57.6100197915108, 64.28544667459303, 61.224970279201386, 63.81775502235659, 59.247221023805686, 63.07865496604674, 61.83197667521816, 66.32467516006963, 63.672470431174006, 65.86082350823187, 64.60544932273127, 57.605269801232126, 60.23984739857336, 60.60275293165638, 60.11440607809252, 61.5166808712867, 63.17563949092742, 65.79288413447719, 63.532700692453695, 67.81686244472381, 63.73856236857753, 63.452452921098285, 60.219141206433704, 58.12572517702657, 55.007405588703776, 51.80370384647001, 48.34711513211651, 45.99594839157597, 46.493473591343054, 46.40938189721877, 45.88845191463348, 47.86401248747303, 47.582433377542806, 47.578511007370494, 58.0203938484192, 62.87934364811067, 60.327167203349454, 63.82252462448613, 64.92958614903112, 65.09462771877166, 63.67831476273076, 65.91343033698298, 64.10083247769263, 53.44159541591522, 45.325144644706484, 48.884640662900864, 44.45556694461454, 48.16443074134089, 50.68103913337954, 53.75743642930062, 53.877672764562796, 55.04146352890999, 56.0386476978179, 65.46355016769903, 70.38277502982848, 70.73965580232682, 70.6895749799667, 71.4263294589135, 69.77855743900423, 74.75620992722051, 66.93621189363542, 58.14220697649064, 67.5629674234698, 8.409774438027414, 0.009255550629008681, 0.10872698268823086, 5.807920194441273, 2.4944107186409736, 1.46884317599958, 26.688985324675038, 28.900921652393958, 11.786836116544663, 54.008213166267645, 32.362493738051384, 23.21546962184291, 64.437591491207, 18.69598330989961, 0.7596407121708317, 0.17571159638464454, 0.04712669156311501, 0.0547444285644639, 0.016798017576577205, 0.022863426786516945, 0.034134794146783894, 0.049815897664596, 0.03709969614001532, 0.012221883291438704, 0.0854051671922207, 0.033964634527482336, 0.01015973068969024, 0.068055359466422, 0.01945552487497128, 0.05799875474504887, 0.018420034471238335, 0.04505153940690141, 0.07380951481360583, 0.021884766700226935, 0.05408797931346682, 0.08887695509099192, 0.026605999953443968, 0.0352083629507932, 0.02991612989365334, 0.06741997380290302, 0.08424187034008004, 0.051322195063074755, 0.01677363682838698, 0.05676017826302879, 0.03102093018711575, 0.028255377678320776, 0.030526763256338817, 0.054110958120755615, 0.03396075812258548, 0.050065504432085066, 0.04643062024467415, 0.04344204230414283, 0.08905720025781663, 0.035620920450216344, 0.040510633674960946, 0.03558904353168703, 0.0452692577645423, 0.05432125691684985, 0.030758738510250568, 0.14481726222701613, 0.06776056883315887, 0.027850779832430908, 0.034446381257786866, 0.35409113993087127, 7.706141923704456, 83.19886853618007, 52.763751014586425, 44.29338478272961, 63.54572296142579, 20.628795931416175, 56.128622947200654, 77.22497324789725, 32.184480890150994, 3.161754444722207, 4.383047155795559, 8.084455997713151, 4.8140930841045995, 1.0508097107371976, 19.70603873652797, 105.8358395484186, 80.05605374613117, 91.75854713686051, 71.27507502032866, 78.82067188139885, 73.48030997860816, 70.50685528785952, 62.8676079165551, 65.84962906376009, 60.54663165923088, 60.3383538030809, 59.13062464806342, 61.56332961974606, 58.73265312563989, 56.719104397681456, 58.72593018316454, 60.221624066752774, 56.02863388676798, 55.39102123629663, 58.893211426273474, 57.066238080301595, 57.463699694602724, 61.76049540119787, 58.77428516264885, 61.4455133868802, 58.047779836962306, 55.586288590585035, 54.606951205961174, 53.79911161238148, 53.73752255593577, 53.30183352193525, 53.230085526743245, 54.38227784249091, 54.0771056759742, 61.84129622674758, 66.38816264367873, 65.10346874114006, 67.0719180568572, 62.34053157990979, 65.0465629946801, 66.00550405440792, 67.88779458691998, 67.73970942343435, 68.81807881016886, 66.95121103717436, 60.670390282907796, 60.748994581161014, 62.7283755425484, 62.103506672766905, 64.85767341429188, 65.27619423404818, 68.18412180869811, 65.14105681450137, 68.54060249943888, 65.83615964458835, 65.93505044137278, 63.53048847567651, 61.820750851784986, 57.25242122527092, 54.439297337685865, 52.13610510672293, 49.21379027828094, 48.269601252771196, 48.79281797716695, 49.26541259211879, 49.47707545372748, 51.053142624516646, 51.10167803302888, 58.901675901105335, 66.0151138613301, 64.5196984660241, 69.00044548896052, 68.58458011381089, 66.28296467565721, 65.53867140123921, 68.55952401315012, 67.6542095984182, 55.800493148065385, 48.4890539415421, 48.86024352042906, 47.65955109750071, 51.92512081515405, 53.96297647107033, 56.31783808431318, 56.7533859129875, 57.8652209620322, 59.2835460939715, 68.40534348641673, 73.78707070504466, 74.38120780452606, 71.30981937531503, 72.82288935876662, 71.34722309727823, 75.70638841198337, 70.03993634254702, 61.81910737868279, 72.73986847169938, 8.145314022417992, 0.15941460797142598, 2.188051789999008, 10.25804723462751, 4.107602632814839, 0.8548677700661844, 28.56969710319273, 38.06483353337934, 13.389768581236563, 50.82843003734466, 35.044632034917036, 30.7178968767966, 75.32758943496212, 22.726108835589503, 0.7388407508692434, 0.2112467073264622, 0.04167701020055721, 0.04729650644285064, 0.05289826774969698, 0.03536909585818648, 0.0637656003386984, 0.018212068412873535, 0.05859674765698372, 0.08416087186384587, 0.08468050164200606, 0.04675266062540393, 0.06951776768771872, 0.04822826854163601, 0.009635794539785674, 0.05343968506842371, 0.007163460747594195, 0.030964507811492493, 0.05650042466098263, 0.0837233437285308, 0.019541717427332076, 0.021249141634231614, 0.08476893117110576, 0.17342341432888664, 0.10744989879669682, 0.2707186491499024, 0.23771349761274554, 0.14182072463295153, 0.15839877538383007, 0.1946207147932822, 0.14315817625291888, 0.23349768512191313, 0.12001033166363356, 0.21222377586508953, 0.12953627494073686, 0.1819538186875082, 0.14234626094900793, 0.09537126628621932, 0.17620497232963964, 0.1530794745251056, 0.27513502345931146, 0.13956862531842726, 0.2425831201816759, 0.1560224472515045, 0.12592407078632425, 0.2569123504743461, 0.18527350748979277, 0.3009375389064512, 0.5171613202941033, 1.368449375994744, 16.355118674616662, 97.53939905474263, 74.98438204488447, 60.030126110199966, 115.43006681626844, 26.159118221652125, 46.414033828243134, 94.20186211985927, 30.432405202619492, 8.435909190485555, 11.123923197869333, 13.986656242801299, 11.097105953001208, 0.8552331020755153, 20.28556892948766, 110.2065601656514, 81.36080664973106, 96.53359351619598, 74.11018771509971, 81.66407646671419, 74.5028797272713, 74.76319959086757, 66.12362230977705, 67.9144980830531, 67.15139312128868, 62.34869010986821, 63.705700751273866, 64.36374502797281, 63.39819477450464, 59.39856175453433, 62.55868596415367, 64.32349758763468, 59.01354974316013, 60.33569835847425, 60.66196503177766, 58.13921420804916, 61.47878685305196, 66.17938272414669, 63.01410452012093, 62.44244652409708, 62.038826788625414, 59.8032562194332, 59.383947003272276, 55.76865919174687, 57.19629603047525, 56.85352402348673, 57.80744837176416, 57.81032346910047, 55.410593863456484, 62.686716048948234, 68.66445525999993, 66.75783818767917, 70.80900330697337, 64.42180395126343, 66.85063362121582, 66.64380704202961, 68.88720666208576, 69.60560444862612, 70.54874620129986, 71.96871480634137, 60.06037935133904, 59.9398684501648, 64.2991514359751, 65.67034536792387, 69.02739217204433, 67.84731572674167, 70.24009489244031, 67.3142969992853, 70.12067441017398, 68.06532890565934, 69.08942053394934, 64.78345040352114, 62.79098441523891, 58.497726686539195, 57.78895831877186, 53.501105616169596, 51.21141810570994, 51.00950625634963, 52.290183651831846, 51.02250499110068, 54.06558567477811, 52.59498319318218, 53.69177203024588, 62.57696420915666, 69.280118326987, 64.46429498734014, 71.6579532623291, 70.47515469212686, 69.53345637167655, 70.4617166519165, 70.14853108313777, 70.68671949448125, 59.357153292625185, 50.39420796978859, 52.243723177140765, 50.33872604370118, 53.676200220661784, 56.06284872178109, 58.24212151189005, 59.60641207233552, 60.07059320326775, 61.532397808567175, 71.40666269486951, 77.61812025500883, 74.36041924261278, 73.6856617466096, 73.66289631012948, 72.20604173598751, 77.51011386994394, 74.1199230378674, 67.14645093487155, 73.05512505192911, 10.6040757894516, 0.172028245644704, 1.8834139238442145, 19.712069380667902, 10.412572929936072, 2.4202825801987804, 33.5082749397524, 38.43563479761924, 20.330952713566443, 79.99915584441155, 45.45593215573219, 40.09317351925758, 80.48253305496709, 38.323890393780125, 1.0763622363728862, 0.3167787969352738, 0.22338313350994743, 0.19186891164750824, 0.1354430273415581, 0.16409986382049901, 0.29581915226674854, 0.13107670921712153, 0.20217055725234173, 0.1993728194746279, 0.15689417870054323, 0.11310853064060213, 0.2652354207971404, 0.1823199474282803, 0.18508756262881143, 0.14263129162211574, 0.10242387171714537, 0.1360285176985687, 0.12719898664903256, 0.22201339894485092, 0.1590179889312675, 0.09669492832354962], [0.04249180216462382, 0.04024151847848008, 0.03461978142900813, 0.05340625299140812, 0.0523146964429367, 0.03376369732582281, 0.02916276094413573, 0.06793488447944965, 0.12195204279475635, 0.03885557349290579, 0.09139651868252024, 0.013963364894622037, 0.029177718810857307, 0.041634427203286084, 0.055526608165593884, 0.021847190087540977, 0.09045783114889938, 0.038994982342926726, 0.05908877145679248, 0.05017117476992069, 0.08133412233643955, 0.0024063015617655534, 0.02987617457796249, 0.0640261851461424, 0.06327021341290205, 0.05924982612111396, 0.043397907978825034, 0.07128494100705271, 0.1309279809075017, 39.3928696263221, 66.91009675302814, 62.54110982341152, 83.03417605738487, 47.91873739611718, 8.704579780178687, 80.85733121441257, 50.577386579205914, 0.05208441041289799, 4.857942240853464, 3.78235871753385, 3.8027687707254967, 1.1133820563554764, 10.190651109141688, 97.7663395481725, 81.27036463829779, 78.35551015792355, 76.37345806244882, 72.32768227977138, 63.296868185843195, 63.16849685484364, 62.19465078846101, 59.71971757950322, 59.53327948047269, 59.4814649704964, 56.81418657302857, 55.572058231599875, 58.44580627256825, 60.17508122228808, 58.46488468108639, 57.176876375752116, 56.96362887659381, 55.95701532979166, 56.893037980602635, 59.053302964856556, 60.76040083362211, 59.33127741659842, 62.453005544600956, 61.65554846486738, 65.38060772803523, 66.44828473368, 59.153076294929754, 51.51888878114762, 52.608472224204775, 49.81683900279384, 50.65715974377048, 48.577746575878514, 50.417785336894376, 58.07136112643827, 66.61524434243479, 67.30114136972736, 67.00223322837584, 63.41765757529967, 63.713725920646425, 61.02807514129147, 66.3816515091927, 62.59896870582335, 68.11637463108187, 66.258057625063, 63.620538250092544, 56.22743137421147, 62.179326088197776, 64.96395395648095, 65.8721826922509, 68.52068470370385, 65.03840838709186, 65.78064241716939, 59.86905790144398, 62.484706140333614, 62.578642983590406, 56.63353789237238, 54.640875785581535, 52.20654303027738, 48.806820838682114, 48.032329236307454, 47.032148376587905, 46.66123336361301, 47.20396387961603, 47.215797670425914, 47.728176886035556, 47.99732992725988, 57.60842730922084, 64.21928413452642, 65.2455879795936, 62.77044688501666, 63.461544975157715, 68.19065647740518, 66.1689256852673, 62.036241946681855, 64.5404831055672, 63.974567459475615, 63.514155726278986, 49.63019301814418, 47.89243398174163, 47.78525129441292, 50.25875283825783, 50.92586171242499, 56.80988765531971, 54.376468812265706, 56.57243913219821, 56.98378985927951, 62.87137339192053, 66.00715929462065, 74.3542532767019, 69.27591354616227, 76.3547012882848, 69.25148502472909, 76.24722050082299, 55.51800012588502, 71.82491287108391, 20.83113531912527, 0.5019577232099349, 1.8167482172289204, 1.0675123886715983, 4.211088486256139, 1.8132391668135122, 0.4186844254934019, 33.120517269257576, 27.09279529510006, 34.75641235228508, 47.84460852223058, 34.411133950756444, 58.41546673928538, 53.97719506294497, 2.524606840264413, 0.3452091778237974, 0.17242961442999302, 0.1821548248370809, 0.05400496219555217, 0.01980216816938933, 0.025030486511006474, 0.024702503203204083, 0.10016100886728495, 0.010849581374185941, 0.14380938163207424, 0.08096378011208388, 0.09242612553099472, 0.019338332574754473, 0.07836498004654724, 0.01872126981916447, 0.05298912577751664, 0.06056144525627456, 0.05034461707597779, 0.06384602041854974, 0.005281993334421949, 0.043455406707981904, 0.0664158623605486, 0.042569364736517595, 0.025369838563605182, 0.09340708579627738, 0.03130622899099704, 0.10282923948139915, 0.06275839390112989, 0.03154287929646671, 0.11476076012777706, 0.07048882243614044, 0.04075131168769252, 0.0210661213139012, 0.037548148689130624, 0.05581431248555741, 0.016470373262681307, 0.04480503529550568, 0.06066963985382069, 0.03896377958177079, 0.010526264499452327, 0.13327433968022948, 0.051704051588932355, 0.055932860761400194, 0.1007997346741538, 0.023963471589189385, 0.03227891167625785, 0.06936461905077582, 0.05013975750414595, 0.07196479807457618, 0.054708832289062204, 0.31691215752113255, 48.431124456467174, 73.1037389078448, 62.022674468255815, 100.32044579905849, 32.19680497723241, 20.270310909517352, 89.92724741658857, 50.93556957860147, 0.9720020621053636, 4.917895668937314, 10.294008504959846, 12.460397289645288, 0.9532457169505858, 11.025031420492358, 103.89136375919466, 82.47067266894926, 83.39127648261287, 78.35709479547317, 75.27835584455921, 66.58168454324046, 67.7087305438134, 62.63691371487033, 60.98717658750473, 61.49898313706922, 63.07916487416914, 58.809986575957275, 59.31698037732033, 58.89179545064127, 62.796966029751694, 61.3698116425545, 59.93040769330917, 57.41016718649096, 57.864562003843254, 59.830846171225275, 62.69958142311343, 63.11210493887625, 60.912494659423835, 66.03298417983517, 63.73995873235888, 65.09721648308539, 64.88722062879994, 60.95530732985466, 54.01645798836985, 55.57181504464919, 52.15803115598617, 54.07807057903659, 51.48787067782495, 53.12508759960052, 60.11410405558925, 68.91452989270611, 67.96442985534668, 69.35698893762404, 65.59639300069502, 67.05179629787322, 63.9747400437632, 68.54162231568368, 67.00137030693793, 71.20773576921033, 70.02162671858265, 63.49899184319281, 59.771030026097456, 64.7417595309596, 66.57349463432067, 67.26255309197211, 70.2499008178711, 67.79033153287827, 67.53612272201046, 65.6559032009494, 65.01995755780128, 65.62006058231478, 59.791677382684526, 57.66839250441521, 53.660400913607695, 51.376514588632894, 49.665917965673636, 49.25706186602193, 47.89147300104941, 50.082614883299804, 49.82642919786515, 51.02598021107336, 50.07397390181019, 59.66733432585194, 68.21514775676113, 67.29205716040828, 64.28016324197093, 67.31053936866023, 68.94246501307335, 69.43676210218861, 65.56799111827728, 70.77178001403809, 66.02823026718633, 64.92440077566332, 50.46472041837631, 51.10936587856662, 50.09872797996768, 53.68830857738372, 53.182267911972545, 59.45853087209887, 55.41067231085993, 59.39716931312316, 59.69612844528691, 67.70534946072486, 67.10932962356075, 77.34859851098831, 71.01808917137885, 79.84395550143334, 70.19550538832142, 78.46905492967176, 57.80495766670474, 79.71677657096618, 21.62923174519693, 0.4697805288578234, 4.041862482986143, 3.176393955945969, 6.039019871142603, 2.795804662089194, 0.5539207316694722, 38.18366173774966, 32.49492864454947, 32.03644671747762, 60.66635808637066, 35.21842049014184, 64.38498858482608, 60.70715858090309, 2.389483394161348, 0.2933695095200693, 0.21674573241222292, 0.09228161070495845, 0.1785000032114406, 0.09819512000127185, 0.11331450870080341, 0.1717198033246302, 0.09512118454421721, 0.0312257916741674, 0.04941765451803804, 0.1071934278814062, 0.010119225705913719, 0.04394286462376195, 0.11430858439134975, 0.04625507119682528, 0.06797074505518522, 0.020082194373131763, 0.1421217359001598, 0.05201100769843306, 0.034488477789226084, 0.06410991855626626, 0.034368772720617634, 0.16511493032017063, 0.08801246317283762, 0.1620322844434169, 0.1545884685530778, 0.15923781020026054, 0.1137316205929364, 0.14575760451055345, 0.23888735881736203, 0.2110447512278634, 0.12125667244676622, 0.16504092622668515, 0.13101994210193235, 0.11810874821798456, 0.11168533846014932, 0.22085793917217564, 0.13315202608223886, 0.1574758539396909, 0.19077371235095686, 0.2335704481529613, 0.20330804460231336, 0.14118398299380658, 0.1398572106395037, 0.11427273147649343, 0.09775051321353644, 0.2122586175438858, 0.1377112911112847, 0.1359894318926719, 0.1213694559109788, 0.49822785561123206, 66.9235191037578, 89.23929506732573, 79.56349818937241, 97.58875031625071, 68.56265406454764, 14.860405383571504, 93.79572422273698, 61.50203474106328, 2.599807501800599, 15.256560848605249, 13.99886756174026, 11.686197903848464, 1.835483418356988, 13.124061342208618, 104.46109587146391, 88.78943058752245, 83.81589658798711, 83.08736339692148, 80.81205137314336, 70.22084389963459, 70.24360149137436, 67.93134074057302, 64.20195902547529, 64.98644090467884, 66.51157609878048, 62.197212096183534, 61.63243001507175, 64.23116107140818, 67.5842345145441, 65.97890253989928, 65.78664364353304, 62.135579893665934, 62.43992444007628, 64.57833397773005, 67.9345021709319, 67.88227188971736, 64.10523729939615, 70.19290877926734, 67.81258706123599, 69.08709064606698, 73.3334799735777, 64.18252760364165, 55.662747352353996, 60.17025278460596, 56.73912025267079, 56.668666639635646, 55.10098157390472, 56.0111048144679, 63.549864984327755, 70.72298572909448, 70.65255565028038, 71.60002769962435, 68.57304834550428, 67.88522935682728, 65.78383130411949, 69.6935518326298, 69.96947488477154, 73.17684404311642, 69.69170047390845, 65.85542632687476, 55.888389541256814, 66.32392206499654, 65.69837070280506, 67.68874999015563, 71.04467499640681, 70.76668877755442, 68.70951544853949, 67.2622157681373, 67.73533205832204, 66.85617985263949, 60.710520052140765, 59.49939412455405, 55.882964903308505, 53.40051251073038, 50.98496790855162, 49.84699418467861, 49.456173143079205, 51.88662275191277, 51.670606059412805, 52.11441439967002, 51.55645332028789, 62.34930199961509, 70.79904048673569, 69.96620362804782, 65.46793537755167, 67.69975616085914, 72.07359114000874, 72.22066433198991, 67.57584848711568, 73.09951059279904, 69.08960880771761, 68.83886737208213, 54.98177682199786, 54.456732273101814, 54.128229848800174, 56.704215080507346, 56.34438076326924, 63.690317215458045, 58.145442931882805, 63.49728953453803, 63.34387386998823, 68.55354632100752, 71.3341929835658, 80.7136469502603, 73.23294962606123, 80.06983695491668, 71.28002505148612, 78.74272654133459, 62.92407043518559, 79.32963079021823, 22.924421910316717, 1.2020004108067484, 3.6898415271312963, 5.427828306151975, 13.256536453000962, 6.880134401782867, 1.472854167222977, 44.37759807032924, 36.309325771947066, 54.78252826198455, 67.84794330596924, 55.96025520755399, 73.11676902155723, 75.82198850570187, 5.765942498560875, 0.7179688998768408, 0.5404830591813211, 0.3930319100618363, 0.3160895016645232, 0.2085444853911477, 0.22994044777606765, 0.19552459129162375, 0.28507694481841983, 0.12227512505506316, 0.2582067173094519, 0.2504802915838457, 0.24709655783109127, 0.12417759716270432, 0.18421915600136404, 0.11045451861836257, 0.17308152461003873, 0.15267432126547062, 0.19080262450921923, 0.15038973982295684, 0.20183386160962044, 0.17734592239702904, 0.18509592830894456], [0.053997829916977116, 0.055502744526752544, 0.03635913426537187, 0.0634437361581912, 0.015455139181276244, 0.08190377765605528, 0.0380541535935575, 0.041316577323502114, 0.0413572374400833, 0.009685919672671345, 0.03604398101508137, 0.030441315724484386, 0.008359414491532071, 0.007442423046731781, 0.02934249474727098, 0.0713581560299762, 0.052470407643986326, 0.031709262102301565, 0.03175355539086365, 0.00834154549069823, 0.1471954136486015, 0.04034865204425108, 0.017794935453322627, 0.08945864565189808, 0.08132083837183253, 0.020629188811947263, 0.022667166551635153, 0.09170743546658948, 0.20731934226087986, 11.547263629974859, 66.5209819424537, 36.096564646690126, 19.435805082321167, 72.36654512343868, 23.56253662417012, 31.862113052798858, 90.30939609773698, 0.4115629947233585, 3.3691007379562627, 2.652977926115836, 2.158588416153385, 0.41579400639860864, 3.5408588763206237, 82.13254867061492, 83.58741852544969, 91.42523980909779, 77.45796203613281, 83.8532453967679, 79.62297701066541, 77.81678830423664, 70.74870078794419, 70.21645868978193, 62.228461619346376, 61.20932786695419, 58.15520963361187, 60.936919258486846, 58.41385856751473, 60.601395791576756, 59.35724742950932, 58.85763160644039, 57.391316275442804, 56.32910313144807, 59.46019395705193, 60.96219108950708, 61.49017349366219, 61.911993026733406, 62.765288968240064, 65.53146600723267, 67.39398387170607, 71.33145516918552, 69.77273664166852, 65.11816193980556, 56.754119396209724, 52.68005940221971, 50.88816381269886, 48.517232248860026, 51.29786322193762, 54.29202802719609, 66.81195120657644, 67.08053158175561, 67.00255486272997, 66.17139677847585, 63.979576326185665, 61.09697549573837, 65.71992020453176, 58.35996127897694, 70.58047817599389, 66.03675749994093, 67.93608680848153, 45.547617558510076, 56.71278938170403, 72.3164878352996, 64.53064580117503, 67.11347949120307, 62.28591257526029, 60.818899062372026, 57.35013923337383, 56.78878922616282, 50.91217264052361, 52.02598848650533, 50.29399141188591, 50.96600324876847, 47.86794662475587, 48.766345900873986, 45.352918947896654, 46.408915135168264, 44.407776786435036, 45.87884210771131, 45.73644830334572, 56.16055888514365, 63.727328700404016, 66.02142103256719, 63.94920541394142, 66.05079958515783, 64.80663161123952, 67.24225874870055, 63.83514681170064, 65.98423696333363, 63.95746984789449, 67.05919388801821, 65.67594651252993, 57.506359392596835, 48.465119638750636, 49.14636473501883, 48.95522763652187, 51.86607737695017, 54.538745111034764, 56.68015526187036, 56.78261933788177, 57.89186954498292, 60.880676392586004, 70.04113658781975, 65.82876205444336, 73.61905205634334, 76.30949989441903, 81.72977616710048, 64.95151219829437, 62.08807999087919, 35.64326024824573, 1.2067488076225406, 0.2393586407866209, 1.4983338838623417, 2.408059984445572, 8.364195516032558, 1.9927677656373672, 1.5986787768140918, 31.33789808519425, 26.61116157808612, 56.06095029461769, 27.52408539095233, 34.477931914790986, 52.03239371699672, 15.917339017314298, 0.4376520576976961, 0.12951114725682045, 0.08480808592491573, 0.08088866519110818, 0.046338130449575764, 0.12225883802579296, 0.0993013049986574, 0.019375939830957402, 0.035111517945845286, 0.033480850003299215, 0.07232525010382937, 0.12679947179652032, 0.030427911101029288, 0.040094138483607, 0.006932077775408905, 0.021878559472820452, 0.009323518907260752, 0.05020774397698622, 0.04225868160926527, 0.02541194658636326, 0.008159522999889188, 0.07639861620602108, 0.027685814289255973, 0.027882095591555682, 0.09202329351777032, 0.09453114362493639, 0.05624006201903667, 0.018798234842477307, 0.070085768257418, 0.0352649002396051, 0.03184223772897836, 0.04070467225486233, 0.06348889704132754, 0.01371850021138427, 0.06726907746445748, 0.10111171632043778, 0.015636671375813746, 0.08750849223184971, 0.1009820023130986, 0.04083644320827819, 0.02211242121824574, 0.03511847402419775, 0.06617361003713262, 0.015451690828007077, 0.05187135753071597, 0.05115550199163057, 0.11740328083115241, 0.08743143144754634, 0.05491712776523444, 0.11082532815635206, 0.07374725484799954, 0.34064712423470717, 13.557835278972505, 79.66504835313367, 39.604132406173214, 43.34669720742011, 76.1697615346601, 22.036224719016783, 56.89008443586288, 91.13391753165953, 0.9215332928203768, 3.819342500740482, 8.758238784728512, 14.183783781143928, 0.6562285257443305, 3.2847094728100688, 85.32420481404951, 86.3359723552581, 94.09954317154424, 77.77790977108863, 86.55159288837065, 80.90345044289866, 78.81415290217247, 73.3059920034101, 72.10610758873725, 64.0121437657264, 63.629653838373, 62.094430308188166, 63.98369089249642, 62.118694090074115, 62.65627061167071, 61.92956524510538, 60.78168361417709, 59.0091331543461, 60.3516153366335, 62.12265960631832, 63.683182424114605, 63.10130273142169, 63.82400335804109, 66.2674948476976, 68.86458243093183, 70.59947029236825, 74.09353333134806, 71.98615366412749, 67.2719903146067, 57.37852542631088, 54.826364671030355, 53.299044716742735, 51.3383303150054, 53.341657346294774, 58.534079213296216, 69.76074203368157, 69.20401650090372, 69.31675326439643, 68.55951616840979, 65.46116928900442, 63.8098475240892, 68.09668433281684, 62.78597554852886, 72.45951314126292, 69.5679183160105, 69.87127442513743, 49.21068376110446, 59.728762565120576, 73.5702028582173, 65.45801178101571, 72.05715640898674, 64.96516989123437, 64.15232927568498, 60.15195885012227, 60.28762971201251, 54.995528651822, 57.862008540861076, 52.39161614448794, 52.83963711031022, 49.19920298361009, 54.30067293105587, 49.22246263873193, 49.65164838298675, 47.713985750752116, 50.057978476247484, 49.94686165163594, 58.62510173551498, 67.62800816566714, 66.94144433544528, 67.9242883190032, 69.16608718133742, 69.27728637572258, 72.03639138129451, 64.96381667352492, 65.81970922408566, 66.68602743456441, 69.34793610726634, 68.01873114801222, 60.127251840406856, 50.53075744259743, 52.27085421162268, 51.90314769744874, 55.850232724220525, 55.354237248820645, 61.26843014071065, 59.73923921585084, 61.008839837966434, 62.79781326170891, 73.32693746013027, 68.50794484538417, 76.09959817701771, 76.7738300754178, 82.48344390623032, 66.17301279498686, 70.29595728843444, 39.800737288690385, 0.9565327857290545, 0.6134438634880128, 3.7968947762443177, 4.47064790033525, 5.204601806979026, 2.6657901031355706, 2.470840705979255, 37.93280263100901, 31.056030681056363, 66.98210362465151, 37.246552590400945, 39.15530735446561, 63.60567638950964, 14.41485845273541, 0.43335598983591606, 0.11291021345964364, 0.08130536339576207, 0.0259355025651354, 0.047148609338628675, 0.12096476996497763, 0.04771187548495589, 0.07239487983526723, 0.05453929703141894, 0.07193243852065456, 0.0030880051405890096, 0.028306667264851353, 0.019853199201245463, 0.09610743081617741, 0.048341772128497405, 0.01009991645978223, 0.024989079458699114, 0.02771973857776292, 0.06225243496197847, 0.019405206304884726, 0.05961436905988282, 0.05695017955956921, 0.049360535002403685, 0.08928291274294739, 0.23115353268240732, 0.230122163831707, 0.18409074434349615, 0.09862260472389961, 0.23240905885975208, 0.19461725207586444, 0.17829561095324256, 0.17694538098669824, 0.30703195220520424, 0.14854071000891347, 0.11738298716203821, 0.17264050311378895, 0.1844085176144877, 0.13165597894018696, 0.21059475118114104, 0.22236595260760478, 0.11820774976043932, 0.16227577782927022, 0.12908655068566724, 0.20473617038899855, 0.12643020975613786, 0.15324568496115748, 0.24951436196363744, 0.241507655310054, 0.14904977543459785, 0.3820478946210877, 0.41837391473593255, 0.9495161557870527, 26.491607735233924, 89.57435961692565, 53.901650213426166, 37.960337669618674, 93.82400451167938, 37.34588661501485, 41.89639299146591, 107.72380967294018, 0.5620491084071898, 11.931878501369107, 5.0124140035721565, 9.246426782300396, 0.9272915773814725, 5.049848614200469, 87.20217289463167, 87.35044633188556, 99.26881913215884, 82.5772826902328, 90.69403156157463, 86.39750649852138, 84.11839762041646, 77.56977312026486, 78.41924082848334, 67.79953341330251, 67.5145261518417, 64.89199807566982, 67.29886639502742, 64.99330113011023, 68.04477568595641, 66.49561989691951, 67.09149852875741, 62.45992852795509, 65.38649520566388, 65.94273828691053, 67.27526941607076, 65.97455655374836, 67.65080498110864, 71.19418005789481, 73.24055902419552, 73.38603188914638, 78.41502035817793, 75.56275906101351, 75.2683538006198, 62.788748664240686, 57.60579539883522, 57.05359235886605, 54.77981398182531, 56.56673208359749, 61.72099321119247, 70.53341757866644, 73.0042205318328, 71.56905666474374, 73.10397425005513, 66.43996930891468, 66.38252227537095, 69.75808266670474, 66.15113381416568, 72.98380067271572, 73.57631391094577, 70.47706880877095, 48.93003817527525, 59.16453353820309, 75.16537589411583, 70.98245051599318, 75.57669131986557, 67.07992753674908, 65.19323610490369, 61.963430989173155, 62.14968865917575, 56.687992157474646, 59.38126802444459, 53.747720718383796, 57.72006188669513, 52.46383874647079, 58.31718783224783, 50.44300617710237, 51.36176255441482, 48.92743372148084, 52.952264047438106, 50.96178670083323, 61.090507507324226, 70.13222186796128, 70.51168764791181, 70.35090969454858, 73.64652433703023, 71.42096365651777, 75.90675092512562, 67.17102066163095, 68.30802948244157, 68.6101382778537, 73.25287526653659, 70.59540671686973, 63.62979896606938, 52.47170702103646, 55.69252990907239, 55.568634002439445, 58.116456616309385, 58.566815314754365, 66.08839158088931, 62.028765909133426, 63.6763535776446, 67.44732810604957, 78.41019584286597, 72.72311210632324, 78.54861628624701, 80.76626162375175, 84.76649868872859, 70.15505006236415, 70.63423033683532, 42.078371355610514, 2.0474809071710034, 0.3593679229097982, 4.9527018012539035, 11.300133716675544, 18.308743392267537, 8.069489213728136, 2.743821245047354, 41.22087847801947, 39.200426378557765, 76.40580977163008, 45.048488109342514, 50.169620898462114, 70.39242406045237, 30.8009236474191, 0.9219256524116763, 0.36470930242250044, 0.24829376939563985, 0.2780568215154833, 0.11045460288803424, 0.21797423100759908, 0.23449945233521924, 0.19164072469838206, 0.22710768445845575, 0.24208191481809466, 0.12363498474681571, 0.25079441827631765, 0.15189254386050088, 0.1917402241979876, 0.11253435540223315, 0.08164958968277901, 0.24243676674462136, 0.09595143233215618, 0.2122737247977526, 0.08542461816461817, 0.2172409163247193, 0.19043352334730088, 0.08669635476244074], [0.048322677386984716, 0.05825134159456338, 0.03710076483266969, 0.04224638972852019, 0.01521685423569814, 0.08374685496692696, 0.054062893764386256, 0.06858053572115398, 0.03330476086346373, 0.04643263505591501, 0.046532245638269576, 0.0275765567447149, 0.01191767552236636, 0.05858383524501997, 0.030348400750588027, 0.015000035073758375, 0.035727268775864955, 0.030394888881053177, 0.039319129465448285, 0.048958112846218774, 0.03368606197557623, 0.03395016312659268, 0.005107950606954194, 0.04038029530596349, 0.08622485062768383, 0.05314252339303494, 0.051315687146157994, 0.06686160295841194, 0.06067915083540063, 0.8912223805823635, 56.14545775998024, 59.408763839352524, 27.29566812515259, 31.132256061800067, 69.14809134698683, 8.790478706359863, 68.53021606322258, 9.483125152126435, 3.129190192107232, 23.645734017895116, 19.723424642316758, 0.47790443164206325, 0.3785656266395123, 43.609558766888036, 101.78581976121473, 73.05705485805389, 91.73159260903635, 81.59184209762081, 84.45189322194746, 84.88017682106265, 84.04848529446511, 73.48671913146973, 68.62911470474737, 62.539901733398445, 62.80266915598224, 60.353533375647764, 64.03474054028912, 62.78611675385506, 61.00738856100268, 58.92675161361695, 58.08264578542402, 59.63304888817572, 61.00555289176203, 62.668104402480594, 64.06439365879183, 65.01369745500627, 66.24166211774273, 70.25297595608619, 73.17291382820376, 73.13473347694644, 72.92217239256829, 69.45231037755167, 65.6140632783213, 56.87463421975413, 49.74118040454004, 48.94003629684449, 49.22924833913004, 52.95441350629253, 61.46355628967286, 69.43159241830149, 68.39091700892295, 68.81980465304467, 65.13185493407711, 68.04875296931114, 63.10516626604142, 64.19114112854004, 70.53790477014357, 63.69463574501776, 69.82278608506726, 46.939447079935384, 59.84967747042256, 71.40762759793189, 67.35601532843806, 68.13406452055901, 64.52488776176207, 56.11667933002595, 50.135508045073486, 50.978605824132124, 52.93878678352603, 51.08771831758561, 49.46925032523371, 47.155091147268976, 46.955454272608605, 47.9476531090275, 47.76760455100767, 47.628611441581484, 46.8496875609121, 47.80210179667319, 50.50896867629021, 58.825997691000666, 66.04666540699621, 65.54958735742878, 62.93560612586237, 67.21483353645571, 64.26679580442368, 67.84690780024376, 66.62870591686618, 63.4945870214893, 65.70758827271001, 65.22874924444383, 66.4381807081161, 63.67396093183949, 51.56019918380245, 49.933215725806456, 48.053435510204686, 53.332200511809326, 56.72155195666898, 60.319283239303104, 58.894348913623446, 65.18716819824712, 59.65296276154057, 60.67688965028333, 68.14664748407179, 74.01792572390649, 72.91487678404778, 76.92613570920884, 60.5100751692249, 41.930968684534875, 3.09302177160017, 0.12493495168464801, 0.1544578352402295, 3.448062462191428, 1.9469977506706793, 2.777472974792604, 2.261319213336514, 6.3361433340657145, 18.624498113509148, 37.201574771634995, 26.473602094957908, 22.103416881253644, 58.922519376201016, 33.15720319747925, 0.4005534225894559, 0.08123811619776873, 0.0448416389765278, 0.10194988545751381, 0.022393518029862357, 0.04047083540729458, 0.060428440901300604, 0.043832141936065695, 0.023490391228528276, 0.10333201532522518, 0.05182465298041221, 0.02634436369032389, 0.11246096417908708, 0.06699412084755398, 0.09285960872206958, 0.03643320347633093, 0.07255174399864289, 0.034359556682888544, 0.04419503395535773, 0.023297124482210607, 0.04264006699104944, 0.027471487785899834, 0.036063359209126046, 0.06145949565595197, 0.07187756364263835, 0.05004642501233086, 0.07265416229323995, 0.02437483399145065, 0.047554911730150064, 0.06720449625244064, 0.03919239170969494, 0.0317411064620941, 0.07304323536734428, 0.07268428487042267, 0.021036194089139183, 0.02542879860547762, 0.0448996624759128, 0.032445788608803865, 0.08273648458623117, 0.023509790489990866, 0.02768878287996256, 0.02843615336103305, 0.05571220062613007, 0.05450945407632859, 0.06256234434042728, 0.11261637277540662, 0.03877654769307664, 0.027392582644918756, 0.14516898851481178, 0.020483042218632275, 0.026625224929903785, 0.06885172318547003, 0.02714529712384026, 1.0056599818410412, 68.31840807391752, 65.54038939937469, 22.465273180315574, 43.9239602704202, 50.29505045183244, 13.316198645099519, 90.28769754594373, 7.510829462159065, 1.346770681200489, 12.101304300369756, 14.607898881358487, 2.766188806103122, 0.5354729667305946, 50.08695302471038, 100.6994487393287, 77.00162564554523, 95.67868155817833, 83.90778987638413, 87.89559302791473, 86.8912858347739, 85.60480333143666, 75.72839290865006, 72.15051666382821, 64.3781832725771, 64.26983564130722, 62.507659850582, 66.7482989834201, 66.9895875069403, 64.2836816080155, 59.693084686033195, 61.49113055198424, 62.38536034860919, 64.46476567176082, 66.19635874225249, 69.16950748812768, 68.17491992827385, 69.72823342969342, 72.45341777801514, 74.76004600524902, 72.64614735880207, 73.14085237441525, 71.39810408315351, 66.41159488308814, 59.24652284191501, 52.693709250419374, 53.55186108619937, 52.58267871795162, 55.35895586013795, 64.43866229826405, 71.46804778806626, 70.30508072145524, 70.8667641301309, 66.3417531597999, 69.43920966117614, 66.19817087727209, 67.35105745254025, 73.61349798017933, 65.60587729177168, 71.12091802781629, 48.09232188809303, 60.64406333431121, 72.47890533939486, 69.59364121960056, 70.63817624122866, 66.91740805102934, 59.84688474285988, 54.51308104299731, 54.326160492435584, 53.505757547193966, 53.25091331235824, 51.394910504741055, 49.55045515491117, 51.69430501999394, 50.8995779099003, 50.33354067033338, 50.43380037430794, 50.504375580818426, 50.66333747679188, 53.05530471186484, 62.25720474796911, 69.08834580452212, 70.11556748420962, 66.74006200605824, 69.51930446009483, 65.54960304690947, 69.1521078540433, 70.14507155264579, 67.25230001634168, 67.6139582357099, 68.18314121615502, 67.84606841302687, 66.33696786818966, 53.56941761509065, 52.49297411211076, 50.391972218790364, 57.94822223724858, 59.047819491355654, 62.1537208557129, 61.83647171143563, 68.88653201441612, 62.45212693368236, 67.28072935535063, 70.09124878914126, 77.84615116734659, 76.40100879053917, 76.48894048506214, 64.31921828177668, 51.5496793870003, 3.33439389063466, 0.11547494559518753, 1.3583630010966332, 6.3583792505725745, 3.294807859966832, 2.4382867495859823, 1.3966659264218424, 9.206600016163243, 23.27937876024554, 44.036881385311005, 44.064871418860655, 24.97691781290116, 67.3569723867601, 34.86490511125134, 0.5611157681672805, 0.05181732917985609, 0.01661847529542302, 0.06547244806443492, 0.023266749096012885, 0.05010886117815972, 0.04341981043258021, 0.07842667310708955, 0.07169901919100555, 0.0699539398474078, 0.07882381308703654, 0.0642850500861964, 0.06224636371517855, 0.10462770749243999, 0.07133367952079543, 0.03546239004560536, 0.0520624160285919, 0.012435931130312385, 0.027572653526740692, 0.021065349480317488, 0.05505264105816042, 0.013273548684082927, 0.03454742442455984, 0.007351407970887639, 0.15495691087938127, 0.23885677658742477, 0.22431874137011268, 0.19519358002130063, 0.15253777375384686, 0.17412346547409413, 0.08537164318465418, 0.19444390170035825, 0.13665752184967841, 0.15969133425143459, 0.09008330608447714, 0.09047684545118002, 0.11330077274432106, 0.09465559460823575, 0.15663216130868082, 0.08311547594325197, 0.22185918544569325, 0.16355764210945176, 0.09386607971523078, 0.21315331630889447, 0.16565234099905338, 0.23125695455218517, 0.12687518426607694, 0.1467510060437264, 0.32324044214140984, 0.1898894323817184, 0.10968814724155011, 0.1400445191369903, 0.1911102241325763, 3.0001956945465458, 90.1550272972353, 77.05657020691903, 43.429408227243734, 51.60538488818754, 95.84527246413693, 12.94430107839646, 85.12610943086686, 11.437909910755774, 8.398548614594246, 43.069848475917695, 37.73329127219416, 1.3765425739749786, 0.507932718723051, 51.72113403197258, 103.95222325478832, 78.0974966479886, 99.36977309565391, 84.96226418402888, 89.87543290661228, 90.9908922256962, 92.18193561800065, 80.50660856308477, 75.57538124822801, 68.50261042194983, 69.3452061376264, 66.43839251610541, 71.32309267597815, 70.80988976263231, 70.7473671820856, 65.74351718348842, 67.05843294820478, 65.09821668747934, 68.6419173209898, 70.9612383381013, 72.59822384003671, 72.64293101526076, 73.73244777802499, 76.35810590559437, 79.27671801659369, 76.93695360614409, 77.23262186973326, 74.70573686784314, 71.75867188361384, 62.345026616127264, 55.46732702562886, 55.717268297749186, 54.08864528902116, 61.28524534163937, 67.44617492921891, 74.90319682705787, 71.41064782296458, 73.36738494134718, 68.13235436716388, 74.4079662138416, 67.84293051688903, 70.18285182214552, 74.30419598856281, 67.70579661092451, 73.56006745369204, 50.86856765131797, 62.70851658236597, 72.17726722840341, 72.71772276970648, 73.04511516324936, 71.44022249406385, 62.00606715294623, 57.581574763021166, 55.50842562029439, 55.8487775248866, 54.07708606412334, 56.062546699277824, 51.8240923266257, 51.093095887091856, 52.254156681799124, 51.968639512215894, 53.61328932546801, 53.29049787213726, 53.397849221383375, 54.96275332666213, 64.91082545249694, 72.70109976491621, 71.68489210067257, 68.73045306051932, 72.50593831462245, 69.31163849369173, 71.54669915476154, 72.734510514044, 71.04767168721845, 69.37769905213388, 70.34570863170009, 70.961026530112, 71.32769753856044, 57.82725241876418, 54.50849971463604, 52.59077448998728, 61.75813021198396, 62.10959419127434, 66.46714348946848, 66.10575199127197, 72.65859696172899, 65.8760658387215, 69.23000612566548, 71.45780255717617, 80.62198115933327, 78.21049228791269, 83.46027881868424, 68.36728865100493, 51.46166140033353, 3.5940042955260125, 0.24573610825163705, 0.613654507023673, 11.157343752922552, 8.982249267639654, 9.330858742037128, 6.866900324821473, 9.091302925540555, 28.898589803326516, 55.85897568733462, 43.44682747317899, 38.097510799284905, 79.56218027299451, 59.60569035622382, 0.6771457291418507, 0.22721801644131062, 0.15478795784856045, 0.1960418998233734, 0.16428544095927672, 0.22747407366912212, 0.16135437323922114, 0.12338079677353944, 0.18736475898373514, 0.21028157443769518, 0.17342925191886965, 0.16767423089233138, 0.19866283982992175, 0.14189080635626472, 0.1534824520950356, 0.0795607437049189, 0.17636687735155707, 0.14960718100830434, 0.13710146980179896, 0.07964619315199314, 0.13988123515680914, 0.1699091545155933, 0.1436411027586268, 0.15090433640345452], [0.10482053948386062, 0.10290672161406088, 0.06050944703841402, 0.03819535891976088, 0.021058600245704575, 0.058739209367382916, 0.02792455792997874, 0.0387674848729324, 0.02408907361959498, 0.08736206984688198, 0.023726828944598957, 0.04529063161762972, 0.11335088255544824, 0.060781975156597556, 0.12369223449739719, 0.08248405861518077, 0.02181455665718644, 0.034368117715442376, 0.087894409023706, 0.03070988699853901, 0.03295295413643603, 0.07809576142819659, 0.06956154961259135, 0.04897107888433722, 0.04251959966495634, 0.13520557072854814, 0.03392702344083979, 0.17695576913895147, 0.2369268325668189, 0.6023330758175542, 27.73451662832691, 70.7301087533274, 84.56915640061902, 67.38224029541016, 79.48939677207701, 43.759581581238784, 31.438942263203284, 31.04393016907477, 1.0283377165755918, 17.96487900518602, 10.875073325249458, 8.048571703895446, 0.4311021591626829, 1.2287019457547896, 55.71722515167729, 103.74587520476311, 72.85493512307444, 89.02488262422624, 86.90930520334553, 90.89397045873827, 82.28249303756222, 83.19345566534227, 75.15967276788528, 62.07928211458268, 62.45381355285645, 66.9634017636699, 68.1600933690225, 62.292231513607895, 64.01804693283574, 57.894246501307336, 61.833180842861054, 60.74654309980331, 62.33020005687591, 58.53283582195159, 64.9824243976224, 64.17225883853051, 70.29780080241542, 71.79493027348673, 75.05972293115433, 68.95746415661228, 72.99366151132892, 71.20247979317942, 73.16749311262562, 63.27973527293052, 54.392499539159964, 50.87068180884085, 55.232667307699884, 49.07478540174423, 60.28335432852469, 68.32419749229186, 70.24594706873741, 66.2856161978937, 67.90985399676909, 60.82118972655266, 61.76436285818777, 67.96408468677153, 69.2307278417772, 64.57252886987501, 71.65126954355549, 39.7048863287895, 51.65742297326365, 68.79715688766973, 65.62438695661484, 68.30471115727579, 67.8776748718754, 62.38689399534657, 58.321498517067205, 54.34296000388361, 51.138917015444854, 53.44590217836442, 49.92150745084209, 48.39970627138692, 47.107959947278424, 47.6660426201359, 46.98536626754269, 46.936505302306145, 48.48012662702992, 49.78741338176113, 54.310753422398726, 61.19886690570463, 65.24006920476114, 68.1488989245507, 64.59632588971046, 67.85729423646005, 65.71569973422636, 66.63637022818288, 66.82163946090206, 65.4604789518541, 66.85501883106848, 67.46804606529975, 67.67546100001182, 65.02504879428496, 57.36614250367688, 48.16503478634743, 51.73345419668382, 50.52024941290579, 59.78592326564174, 59.386280813524806, 63.199507113425966, 60.05974000500095, 62.139663081015314, 65.49763164212628, 69.97433862378521, 77.65690465127268, 82.79678636981596, 69.13268427694999, 57.24183474817584, 10.445133505329009, 0.3753295180297667, 0.013237016823803707, 2.2306774124022457, 2.1952262953404458, 2.8531999693762873, 1.894363097606167, 0.44213909595724077, 6.086543308150384, 30.31487334159113, 41.15926196498256, 26.66488628233633, 29.059569758753625, 46.842348806319706, 2.7765958347628197, 0.26886974190992696, 0.09672507388337005, 0.0604297470812115, 0.018102234387169444, 0.030740423263200832, 0.06300611609232522, 0.06172892877892141, 0.05770129812580924, 0.07115639145335845, 0.03303561502346589, 0.010279959570916911, 0.02855025066603576, 0.031983330057212905, 0.08376738612329768, 0.059025864146890185, 0.051863531942569444, 0.04143573846968432, 0.054058860311464924, 0.04885376017961291, 0.051079981044055, 0.052047170878898714, 0.0440948756201373, 0.06613396498705111, 0.03221533403942182, 0.01808815369112117, 0.015043934784649361, 0.05610993815465801, 0.03125053631412166, 0.06315176472848942, 0.09623425667204204, 0.021127473465317202, 0.09650653198121056, 0.08085196957953515, 0.08857963636757867, 0.0529150948709538, 0.10018108803178034, 0.05550152261651332, 0.028778870454839164, 0.02726075423490857, 0.026573383760067727, 0.020182996222208587, 0.009888046225833317, 0.023088430640317743, 0.04456215861043142, 0.007503693801305829, 0.0734101685004369, 0.09297416951026648, 0.021080751678035147, 0.020833152060907696, 0.07959193114431636, 0.07956008486930402, 0.1613214008149601, 0.3290159483590434, 0.43145235327463, 33.83313740453413, 79.88000208331694, 65.04925374061831, 62.696204262395064, 95.42152312494095, 27.232929814246397, 50.93086665676486, 31.92570055684736, 1.0395109557336377, 4.144955854262076, 3.3456481512515777, 10.107957739983837, 0.3189600637603191, 1.2382749804565985, 64.19780131309264, 102.0459827300041, 75.55774627193328, 92.7525620306692, 87.06490562808129, 89.7737729164862, 83.93261063483455, 87.24506009009578, 74.27210315581291, 65.35854831818612, 65.3113857392342, 69.40877206863897, 71.35935891059138, 65.62370446420485, 67.36997112151116, 62.56298488186252, 62.74552414494177, 63.83946141889019, 62.98472204516011, 63.29293012619019, 67.87140692434004, 67.12701166829756, 71.35601705120456, 75.1760761199459, 77.45291786809122, 72.94808356992661, 77.93904073776739, 72.63706314948298, 74.87785831574472, 66.34394184235605, 55.67650702691848, 52.28525715489542, 56.213252006038545, 52.16218886836883, 63.00795032132057, 70.4680944258167, 73.65433769841349, 68.92786595129198, 71.31961745600547, 67.02944663263136, 66.67946138689595, 70.90874918045537, 72.7368482466667, 67.57331463598436, 75.00797902384113, 42.80848918422576, 55.52793156716132, 71.34095514974287, 69.12094070065406, 71.425293953188, 71.40620769992952, 63.51497157927483, 58.50128427628548, 57.09976257816438, 55.409287714189105, 56.00343658078102, 52.95766122879521, 50.817510158784934, 51.25231273712651, 51.25156748679377, 49.768393808795565, 49.88812415830551, 50.65550058118759, 50.64237240822085, 57.03784012025403, 61.798699286676225, 68.91130570442446, 71.88843957839474, 69.13123299998622, 70.25520386234408, 71.3659563372212, 71.54023508871757, 69.28886521247126, 66.48165625910606, 69.79480389625796, 72.63507843017578, 70.8468698686169, 67.42911261896934, 59.260364886253114, 51.12847566604615, 53.78888599334225, 54.689301367728945, 63.793169606116514, 63.567554873804895, 67.03973893196353, 62.71179568383002, 65.00836303157192, 68.87387060349988, 74.06046775079544, 78.05861811484061, 83.31350372683617, 70.9390926361084, 67.78969610891035, 10.424510663555516, 0.36615763760862813, 0.5650070045263537, 3.7121853088178947, 4.199766074457477, 4.488815338380875, 0.5194304727258221, 0.3847614086924061, 8.037662611853692, 33.40884677825436, 57.18219903207595, 32.76781970454801, 31.563591264909316, 58.58862761528262, 3.37931017721853, 0.20790739135155756, 0.10752883649641469, 0.084870093081507, 0.07788147131401686, 0.0811343266057872, 0.06775117659520719, 0.03792670337603458, 0.022943477228944822, 0.05038846411832398, 0.023335361845731255, 0.06243327001650488, 0.010405842181024774, 0.029927646110375083, 0.1395154434947237, 0.03776109814944287, 0.03168381266145697, 0.043110866324916, 0.04503113082459858, 0.036185810702943036, 0.02878656963847818, 0.04067491739988327, 0.04153357555849418, 0.04711291730223645, 0.05080220522359014, 0.29236231840425925, 0.22337928774856755, 0.09825475994617709, 0.15105104224095423, 0.1793685017694389, 0.14576918775996855, 0.16411630406735406, 0.13618168931814933, 0.13388826722098937, 0.1476589887733421, 0.17487850641050648, 0.15932125249697318, 0.17547570259100007, 0.1976149847670909, 0.29279871272944635, 0.12807856283841595, 0.21344228467393309, 0.19339727237820628, 0.25369012337778846, 0.16435434290718648, 0.09710804123671786, 0.15537861163818067, 0.287932307729798, 0.15006277349687394, 0.11831025232470806, 0.38702758870297865, 0.2897230842180791, 0.37333615725078895, 0.897816681573468, 0.916084936789928, 55.75511132517169, 85.35330095598775, 103.00677514845326, 75.44920644452496, 110.79323691706504, 63.63132869043658, 42.3573342446358, 37.333982221541866, 2.313770373021403, 33.02502324504237, 25.4669963928961, 11.59664725103686, 0.35278131344145347, 2.1190575438161052, 63.446639968502915, 107.23371736464962, 76.23842654689666, 96.15614383451401, 90.5736069525442, 95.1756924967612, 87.54655699576102, 91.28605058116298, 78.48168496162661, 67.69533172730478, 68.08204604733375, 74.79441381269886, 74.55125824097665, 68.58174031780612, 71.79631879252773, 66.06093498968309, 68.2681546672698, 67.76700911983367, 66.02317825440439, 65.94728823631041, 69.93079247013216, 69.10151712356075, 75.75163687429121, 80.75424348154377, 78.78952826223066, 74.81721847288071, 81.63825158149966, 75.17040437267673, 79.38071573934248, 72.6580007614628, 62.2897368861783, 56.14239438887566, 61.35683644202448, 53.86283051583075, 66.20088515743133, 72.7459010770244, 76.79704266209757, 70.74876354586694, 72.64146404881632, 67.95041914909118, 68.8932628016318, 70.98681219162481, 75.0047940592612, 69.76293856097807, 77.33287765133765, 45.60046365184169, 55.37699484056043, 71.76393570438509, 70.87582480522894, 75.89154781833773, 76.4096615391393, 65.80785582142492, 63.79268715458532, 61.28379406467561, 58.34434240095077, 56.499275161374, 56.33074660455027, 53.1650879306178, 54.054257869720466, 53.89715125483852, 53.39475054894724, 52.79699702416697, 53.54228265823857, 53.46801257902577, 60.35036017817836, 64.14994839699038, 71.24255857160016, 72.83868082108037, 71.20399382806593, 72.20997979564052, 73.48599741535803, 73.23630717492873, 71.13551708959764, 68.75845878354966, 70.51312323539489, 74.31431570360738, 73.37724577996039, 71.40349341977027, 61.978779223657426, 54.0267228311108, 58.175986428414625, 57.45034010179582, 66.05479255799325, 67.94072305002521, 70.0589676826231, 64.2597355381135, 69.46738796849405, 72.14027927767846, 76.06297892908897, 80.27505536233225, 87.47043948019706, 76.44628863180839, 68.21489672507009, 10.832241042967766, 0.5817538704122267, 0.4036337702024368, 4.894805166029162, 12.016083944228388, 9.736848569685414, 5.06233940201421, 1.5629152184532535, 10.335273800357696, 47.990501080789876, 54.67713417545442, 38.60048417122134, 44.26400230776879, 68.82694336675829, 9.035686658274743, 0.8066395934550994, 0.2419795195061353, 0.18279326719141778, 0.22978628024218545, 0.15224767157868033, 0.31614141178227245, 0.08870046375499618, 0.15095880525487085, 0.11850475438780363, 0.26312276480659363, 0.1897409032549589, 0.13011669379568871, 0.13063124441091092, 0.25991870931559996, 0.22744660175615744, 0.07799070779114001, 0.10373634887078118, 0.16225515474234858, 0.10577064938843252, 0.19009079093173628, 0.14706994376836285, 0.1659044452131756, 0.15071759481103192, 0.17166151935535093], [0.04781456957120569, 0.04544568015262485, 0.1260458557836471, 0.04345789649373582, 0.08769194730707715, 0.04727379576633534, 0.03469117699311145, 0.02331584958629983, 0.015321272977387473, 0.03418219583709875, 0.04130237405338595, 0.036485109763640555, 0.016362441050249244, 0.05031015844114366, 0.01483811760291217, 0.0719215447503713, 0.07044172335055567, 0.047209800611580574, 0.04763504835746942, 0.06569272132530328, 0.037274360356311646, 0.014660919550806286, 0.05660285061645893, 0.05139191672506352, 0.07685351921545883, 0.04113414497565358, 0.01455267228471536, 0.10417830499429857, 0.19018353353584969, 0.3712127147422683, 4.557782373120708, 74.42465982129498, 67.64303868816745, 74.75865748620804, 26.441493572727328, 67.06575993568667, 19.72690574584469, 35.015096587519494, 0.26396959839809325, 4.279181813040088, 4.399320089047955, 13.564814156101598, 0.18586563216822763, 0.08001198481407859, 0.32288555957136617, 41.2175170067818, 90.86401139536213, 81.51337115995346, 87.185267479189, 89.44118730483517, 92.59386293349728, 84.6990966796875, 76.55832721341041, 69.21073944337907, 66.55673826894453, 70.73517645559004, 71.16089482461253, 70.7641549264231, 65.47601546010664, 59.73882344461257, 58.136782338542325, 62.54315730064147, 66.5833946966356, 65.68497580866661, 68.22194914663991, 70.7871243261522, 73.024507030364, 75.18149683552404, 76.26517711147186, 69.32486472591278, 72.39520195991763, 70.96399184196227, 73.07269727030109, 68.47372608800089, 58.00815605348157, 49.58743526089577, 53.37360897371846, 50.47944499600319, 57.389939523512325, 68.16152111176523, 74.05053630951913, 66.64218318077826, 74.03980470472767, 63.92439642260152, 69.12927181490006, 67.38910444321172, 70.50598452168127, 62.49712436429916, 72.39718667922482, 31.948183582675075, 48.88639396236789, 70.56136838851437, 62.56587566867952, 68.07529172589703, 64.92848788538288, 68.3537172502087, 61.3281286147333, 61.564914257295676, 58.15358577236053, 57.258391072673184, 50.9023549479823, 48.19123621909849, 48.33521858338387, 49.83971818800896, 48.00906565881545, 49.01730306686894, 47.88026286709694, 50.78938284227925, 53.76074690972605, 59.12026174606816, 62.72928553242838, 68.3448762278403, 65.75579420212777, 66.97323122332173, 66.23178558964884, 67.51199230071038, 66.08172355159637, 67.17709249065769, 65.23005539371123, 67.6719779352988, 65.72766296325192, 69.92558356254332, 61.557163653835175, 52.68849249809019, 49.38787683363884, 53.55816825743645, 59.06535248602591, 66.10116281817037, 63.50837023027482, 66.04854029993858, 63.972661187571866, 66.80672660950692, 74.70100648941533, 77.66428655193698, 75.300885938829, 71.88716873045891, 26.01861696089468, 1.3430327850003398, 0.08828379619385927, 1.1126754168541202, 4.8249771710365055, 6.058830291994157, 0.9496337656051883, 1.2674262807253869, 0.1407735284057356, 11.667173427920188, 45.71651089575983, 56.38300434235604, 103.97815012162732, 47.89062184672202, 42.58042689292662, 0.39404599596896484, 0.1561181622767641, 0.0717215958021341, 0.038924149853447755, 0.04370464192282769, 0.05446736903620824, 0.011158997583533488, 0.01932368305842242, 0.04730271941591655, 0.05602843789083343, 0.05416389862676302, 0.05163611491180716, 0.04011981392038926, 0.022248867223219528, 0.056701465284511934, 0.059770225817638065, 0.049215522219216636, 0.058544217008015806, 0.04130236639250671, 0.0386183467062731, 0.06823207296791577, 0.01959507162081859, 0.04367863706823799, 0.10204801365973488, 0.07195870767557813, 0.024728391229385333, 0.02491415414448467, 0.10864095101433416, 0.043395460327906955, 0.042287130284333424, 0.06407434143306268, 0.03178689553732834, 0.07095855690779225, 0.06086438706505203, 0.04776720618528705, 0.023573456226938197, 0.03177486987213694, 0.07186735169060769, 0.04904872189546305, 0.026621591757922888, 0.034182915959747574, 0.04306302796448431, 0.04423329621673592, 0.04870595883638148, 0.07638271222071302, 0.03771641990169883, 0.053831389654547944, 0.07417549033679309, 0.18026609634680135, 0.0653291589790775, 0.014405316230089915, 0.09901068188370236, 0.06188284733422822, 0.20257019467892187, 0.3885764959118059, 5.085121508567564, 82.12666511535645, 75.90555852459323, 76.31452837297994, 50.25122973226732, 69.67691313835883, 18.19228037711113, 50.19184897022863, 0.16194157963318212, 2.232345155169887, 2.4715908592747104, 14.040017147218029, 0.5411996271821761, 0.12546100894049292, 0.42333365988827526, 51.79747512263637, 95.45599291401525, 82.92050576979115, 89.29116449048443, 95.26924887011128, 95.09410719717704, 84.47040680916079, 80.15885906834757, 69.52569007873535, 67.0327571130568, 72.6873165561307, 77.34648043109526, 75.10777981050553, 67.3859037891511, 61.64806066020843, 63.82089684086462, 65.33912866346299, 68.02013535653391, 69.4971352238809, 72.64032656146635, 72.0574466643795, 76.43092078547325, 74.53130906628024, 77.12878888653171, 72.2500664188016, 75.2829214834398, 75.29711261872323, 78.02555253428798, 71.22185630183067, 60.7628523149798, 51.89382030117897, 54.993147773127404, 52.24651198233328, 62.05448881272347, 72.57988283711096, 75.8535949645504, 69.05619021384948, 76.57739777718821, 66.77332370511948, 71.65166962531306, 70.86328891015822, 73.85119361262169, 65.30640825148552, 73.86698507493543, 33.35975439317765, 49.41629832790744, 71.04108210532897, 66.03483553855651, 72.01293560766405, 68.57926137985723, 71.43901440405077, 64.39691259014991, 62.85972787487892, 59.076574387088904, 58.44200549587127, 54.00424765002344, 52.63957661967124, 50.047262560936716, 52.70398193790067, 49.312312372269176, 50.8838374383988, 50.26249870177239, 53.599745381263, 56.68511313776816, 62.93182888338643, 65.67091803396902, 70.45125176829677, 67.50862690710252, 70.35580481252363, 68.54506615669497, 70.4939506899926, 70.15599927594586, 70.93075367712206, 65.38759739168229, 69.5156095873925, 68.85119145916354, 72.40864784486833, 63.83968891636018, 54.665931886242284, 51.94090443272745, 56.174365628150206, 61.501199276216575, 67.89128549637334, 66.14784686796128, 70.57129982979068, 68.30837465101673, 69.78393893088065, 77.84156199424498, 80.0429138060539, 79.14859771728516, 75.18085356681578, 31.70229608012784, 1.1206608722286842, 0.26886526795644916, 3.6759274092412766, 4.3460366514421285, 3.3658750787858045, 1.112713047092961, 0.06663609731702075, 0.2148606505004629, 16.034548263395987, 55.28724316627749, 61.200404474812174, 83.59336483863093, 52.86905096423242, 51.782205335555545, 0.5343949278035472, 0.167600640486325, 0.08470408182831542, 0.03529737087627573, 0.030910726523988193, 0.03092626087187279, 0.017274434250148556, 0.07408704548593491, 0.021362405818616672, 0.03578731091693044, 0.005713280725983844, 0.04560927439841532, 0.05500474907157402, 0.03755090660565803, 0.04921644918560501, 0.09230776494669338, 0.060260326736756874, 0.025956866842123772, 0.037555503133203716, 0.01941313339968122, 0.00878143030399036, 0.03883600377688005, 0.029793923547972116, 0.0689909749874665, 0.023815291032435435, 0.14605771179401106, 0.18178716392046024, 0.17246612618046422, 0.08996806347802763, 0.29150289032728444, 0.2277046048472966, 0.15346800367678368, 0.10594544000923635, 0.17695708681018124, 0.10754775120726517, 0.16379615592379726, 0.1175710847300868, 0.20826665594452815, 0.11390027484946674, 0.1948295043961656, 0.15256377477799693, 0.19707380493562068, 0.08744785637264291, 0.18264761855525358, 0.2388894425765161, 0.17810077947233954, 0.12213124608200406, 0.1705124181124472, 0.4443118132410511, 0.15401505174175387, 0.1363982623743434, 0.30999542544445685, 0.24931746204533886, 0.32454040141836293, 0.6556097105626137, 10.166095110677905, 106.53455488143429, 84.36687192609234, 85.0937028085032, 36.94216097554853, 94.00487284506522, 27.007442558965376, 47.03501562918387, 0.20419518974038864, 6.738932997949663, 15.433989263349964, 27.23023318475293, 0.275766923422775, 0.27146316403823517, 0.7741390793554245, 50.82467240671958, 98.83261234529557, 85.75182161023541, 93.17856281034409, 96.53449566133561, 99.38099107434674, 88.94736090014058, 81.32899622763358, 72.23475348564887, 72.51629337187737, 77.43850708007812, 79.80681850064187, 79.58048205221854, 71.9764026518791, 65.81817165497812, 66.51241548599737, 68.96670526073825, 71.78747777015933, 75.85347729344522, 75.72434502263224, 76.60288533856793, 80.37990031703826, 80.58060799875568, 80.97255476059453, 77.47740130270682, 76.83704299311485, 78.08036373507592, 80.35169847549932, 75.140272725013, 65.27150700169226, 55.79397809120917, 58.21126814811461, 54.92232545729607, 62.97598692678637, 74.79440596795853, 77.3401261914161, 71.385254398469, 79.30806559901085, 69.30102456000544, 73.0990634425994, 71.91453118478098, 75.77723426203575, 66.44204032036566, 73.81442531462639, 35.84113205632856, 53.49030733108521, 71.87105563379103, 66.3904062394173, 73.54071447926184, 71.17057523419781, 73.21822504843436, 67.1682357788086, 65.98480178463844, 63.668673576847205, 61.70278949122276, 57.47550210645122, 56.722065787161554, 52.18866094466179, 55.68939985767488, 52.52488259346255, 53.44501572270548, 52.99371565541914, 55.5809659342612, 60.940076766475556, 65.77149152755737, 69.52064591069376, 74.42056486683508, 69.36665365772863, 71.81354584232454, 70.24844169616699, 73.08178147962018, 71.84390498745826, 75.47974601868661, 67.48793248207339, 69.44069231710127, 72.67187810713246, 75.03311357190533, 67.53627177207701, 56.954564279125584, 54.973163297099454, 59.758729473237075, 66.72968341458228, 69.86887393459197, 70.98310947418213, 73.95101793350713, 69.33088948649745, 71.94799684709119, 83.49100666661417, 82.35055400479226, 83.03847497509372, 77.20507898638326, 34.704813572668264, 1.7149419962398469, 0.35475638004079946, 4.32170569896698, 19.220602281631965, 14.47688485345533, 6.192165382446782, 6.826813211364131, 0.549530986576311, 20.785973148961222, 64.53710202247866, 68.63478645201653, 106.61028800472137, 62.804897062240116, 70.12963310364755, 1.2182870723547474, 0.31564936883026556, 0.17610637681378474, 0.10684851977613666, 0.12180674655903732, 0.09151790531412249, 0.08156857588478635, 0.1093452156431252, 0.11698014748793457, 0.1553022479938884, 0.11588864839605748, 0.09603040833627025, 0.1232251353682049, 0.1641564011093109, 0.13996737408301524, 0.28278036643901183, 0.21448945025763205, 0.17830746999431044, 0.1459255309835557, 0.159414071709879, 0.09706598300967487, 0.07555823307484388, 0.20031576645710777, 0.1578184944247046, 0.19660454543848194], [0.01724248455326644, 0.06543697819354073, 0.04524972252247315, 0.09332735136511827, 0.06644644459048588, 0.012601513374266366, 0.030350061246163906, 0.03491521557612765, 0.01848275600481899, 0.07978054965215345, 0.08126220966298735, 0.04902370529429567, 0.04189305082564393, 0.033339659998854326, 0.012588595216643187, 0.08372055516848642, 0.01998044640546845, 0.03821563343667696, 0.034536431062846415, 0.10361424977740935, 0.031923002548395626, 0.046047944004737565, 0.09622964482273787, 0.03376843174919486, 0.01853669050990814, 0.07940140507754781, 0.0977486822633974, 0.0052167398802515485, 0.06316445114451551, 0.13094720971440116, 0.336538594696791, 16.877329311063214, 61.55564177420832, 42.78704950886388, 30.166613632632842, 60.33547086100425, 59.84138950224846, 21.40927895422905, 1.8863346187337753, 0.5204399927489219, 3.199088299466718, 1.8337440923337014, 1.5076724343722867, 0.26982575835239503, 0.10424824116090614, 0.2372576293325232, 17.273573029425837, 81.45019746595814, 83.70766270545222, 93.29556711258428, 88.58634594948062, 95.87731822844475, 81.99994117982926, 67.95766768916961, 68.8486183843305, 78.06296410099154, 74.43864699332946, 72.04982942150485, 68.92605381627237, 64.69283973017048, 64.65157247358754, 65.64954503890007, 63.99286531632947, 66.35512844208749, 69.64841319668677, 71.77612643088065, 73.56944976314422, 77.20981720955142, 70.66528766385971, 70.75272513974097, 72.31453449495378, 72.05659158768194, 73.37977178635137, 71.14227925577472, 60.06045779874248, 51.70791564449188, 53.48216056823731, 51.99576270195746, 56.84807585131738, 67.35789022138043, 74.68373237117645, 65.57367855502714, 67.89384288172569, 61.27796542259955, 66.46356628787133, 67.43667494866156, 69.22514238665181, 59.54794130017681, 72.01876424974012, 26.740650784584787, 47.24181475177888, 65.90336553512081, 58.380632169785045, 72.65643181339388, 63.05548944780904, 71.3225592336347, 68.37109335007207, 68.71395557157456, 62.24963849590671, 64.01268897518035, 52.97206417206795, 50.74674275613601, 48.18917305238786, 49.088392103871996, 48.845428728288226, 49.60480743838895, 47.07255271173293, 51.73294036619125, 51.95172625203287, 58.99591084449523, 62.216090463822894, 67.91042666281423, 66.21302881548482, 67.24897384643555, 66.97514533996582, 67.99484391366282, 68.2444086382466, 70.26769268897273, 67.84871993526336, 69.76358967442667, 69.03551147830102, 65.33864621193179, 65.61576558697608, 53.99726190874654, 51.475703485550426, 53.11863530066706, 57.10273965712517, 64.59050117000457, 66.47952248973232, 64.71629158143075, 64.3115500480898, 74.81829320230793, 75.58085687698858, 78.82679862360801, 81.07330476084064, 36.79328349328811, 2.5811220657440925, 0.0591910058902877, 0.14322467268474642, 1.871309979788719, 3.247492063430048, 0.7634686390238424, 1.4567697528869876, 0.6349147952372028, 0.35319732982785473, 35.50721283881895, 40.016651999565866, 60.900303932928274, 50.71898414242653, 50.11919098515665, 23.447930851290305, 0.3331204023092024, 0.09846876660782485, 0.06946043366746557, 0.03692556818526599, 0.03907763556907735, 0.015690992755304663, 0.05242031698505725, 0.08525676063952908, 0.03988360986113548, 0.018390409851206407, 0.04105702673475589, 0.034585981629788876, 0.08859873493953098, 0.0071321780260111545, 0.06000900393231742, 0.03097212081024003, 0.07362585289463883, 0.06359807606185637, 0.06682028017577625, 0.048105728947707725, 0.055237210791317694, 0.02754850643536737, 0.05889244610443712, 0.02909450059486253, 0.04256337775938934, 0.05365928417191871, 0.019071632470454902, 0.04082601675162873, 0.047736911238321376, 0.05154981893757659, 0.06782004023872076, 0.035257147429811383, 0.03819047510924359, 0.026578344179377444, 0.030518882126817783, 0.014600321038385794, 0.04439512462986093, 0.0023240052847071525, 0.13998160799664838, 0.01153302947885447, 0.020935430544458573, 0.09368921299615214, 0.08604122701311305, 0.08917425849264668, 0.017155840009030317, 0.02827860737940477, 0.04081374402308176, 0.09690296716026722, 0.07074618201342321, 0.006022729972873124, 0.045391402823189576, 0.05191811570717443, 0.02961440041901604, 0.2350928640413669, 0.10310421142006114, 0.4028404708350859, 21.53291206206045, 76.13700189898091, 47.0394165285172, 27.56518594680294, 85.08706615817162, 48.38939828257407, 27.535189620910156, 2.156615709104846, 0.5992358129832053, 3.8860774617041316, 3.953622146960228, 3.1489184883333023, 2.120810107838723, 0.4263897684793319, 0.26767314321571783, 24.373433705299135, 90.8258310441048, 86.15578651428224, 92.37584190983927, 93.27210349421348, 95.6011833683137, 84.60794864162322, 69.32477843376898, 72.47078603313815, 79.39115708874118, 76.11429922042355, 74.303176172318, 73.66020556419127, 68.24824471627512, 64.89819934291225, 66.68183049848004, 66.8972941367857, 69.59054254716443, 71.65786697018531, 73.14874418320196, 76.06333194240447, 80.53692848451676, 75.13927644298923, 72.62166392418646, 74.23578985275762, 74.31535120933287, 76.69787729940107, 74.52274260982391, 64.17151751056795, 53.935865048439275, 55.71060811319659, 53.72087993929463, 58.32375780228646, 71.70585324687343, 75.41540345837994, 70.49653160956599, 71.26494746054374, 64.6695565408276, 70.84337895916354, 70.6478488060736, 73.21278864337553, 64.20556760603382, 73.51787059537827, 29.945348808842322, 50.698713333376, 69.87394948159495, 60.85931908699774, 76.11271458287393, 66.57865647346743, 74.71992800312658, 68.59022832685902, 71.11889408480737, 64.31398191759664, 65.28245041447302, 53.86060260957288, 53.46838128182196, 50.31306982040406, 52.18823732868318, 50.99068672426286, 52.44609786618141, 49.41995005453787, 53.40320717903876, 57.18567425204862, 61.75450594194474, 66.28406293930547, 71.29447506320092, 67.79107678321101, 70.06902463974492, 69.30526856453189, 71.48015222241803, 70.16104344398745, 70.15393610923522, 68.8416757891255, 72.25958208883964, 74.38767187057003, 70.14874289112707, 66.06156256891066, 57.989465959610484, 54.98174152066631, 57.31897207998461, 59.37645135387298, 68.12450962681925, 69.03771585033786, 67.57123577979304, 68.87358034810713, 77.83859668239471, 77.82035766109344, 79.92921998423915, 81.17932642659834, 41.21769351343955, 2.988852445156344, 0.09119588791603044, 0.8263694218570187, 2.789156980091526, 3.4201984347835666, 1.270208221770102, 0.915166060290029, 0.14414132752966496, 0.7250492070471087, 45.344501541506865, 52.410168955402995, 61.6195724856469, 47.2355781832049, 61.00849859176144, 27.904639628625688, 0.5319963984431759, 0.1633236788573765, 0.05990984534183818, 0.026670267069411856, 0.09445908539477857, 0.02413664959491261, 0.033135922745831554, 0.05177635879766557, 0.04935009705443536, 0.027550289505011136, 0.046334388110065655, 0.04875215393821559, 0.08856740194342791, 0.016950333092902458, 0.04501637980161656, 0.029986784267689914, 0.014434495561515853, 0.10043284750633663, 0.020720774623294993, 0.02929643371082362, 0.05797128666252379, 0.04422534422408189, 0.0678477879433382, 0.014366440140762398, 0.09910383817529488, 0.14941725249011673, 0.14709807451694243, 0.1063396535333126, 0.11735514752686986, 0.1599772842300515, 0.18810769573094385, 0.11577147524803878, 0.13302038153333048, 0.13391572381219558, 0.17391326626943004, 0.14554005086181626, 0.1948202194105233, 0.12606262544830962, 0.22874444663043947, 0.1196677141612576, 0.1519937440752983, 0.12129086295082686, 0.2332732673253744, 0.17521201512746273, 0.2883467306533168, 0.10882425287197675, 0.20370945935287785, 0.21002007798562128, 0.21272522637680655, 0.15002537308441055, 0.22820104514398884, 0.2594889339900786, 0.27583672935443543, 0.38739117403184214, 0.49565619037997344, 0.6486562062655726, 42.930361147849794, 86.04838417422387, 65.50251891536098, 44.568103667228456, 80.6534150338942, 83.21767237878616, 34.31463187740695, 2.4426849522898277, 1.0469290157479625, 10.980192845867528, 9.04415701666186, 4.002900109175713, 0.8140033531573512, 0.34165103649420125, 0.1948566239086851, 24.543795970178422, 94.45184261568131, 87.71716440877607, 98.5372264923588, 94.25562997018137, 102.66934148726925, 88.90461491000268, 73.44984100710961, 75.29526910474225, 83.85934860475602, 80.92229350920647, 78.5114557512345, 74.46214983540197, 70.92348160282259, 70.36778373102989, 72.00167056052916, 70.34807774328416, 72.62933608024352, 75.50365678725704, 76.72190573907669, 81.80295190503521, 82.15938552733391, 77.6381164981473, 78.22833122745638, 76.80873132521107, 77.8606168685421, 78.46841950570384, 80.17024963132798, 69.39532618368827, 57.43175591191938, 58.78115323282058, 58.18222691935878, 61.11397897043536, 75.67861803116338, 79.19589365682295, 69.72653112103863, 70.97698273197298, 67.07759764886671, 70.02055198915544, 72.90107788578158, 75.61779775927144, 66.77288439966017, 75.06612423927554, 33.24088696510562, 50.11978718542284, 73.92369470288678, 61.81099591716644, 80.55816419662969, 67.6899580801687, 77.51366753732005, 73.75617027282715, 74.52250726761358, 68.72225530685918, 70.40141413288733, 58.132589324828125, 59.251484640182994, 51.250037762426565, 55.68247295195057, 55.402553004603234, 55.24031985190607, 52.672151903952326, 58.52071962048931, 58.548038928739494, 64.82178764958536, 69.13556329665646, 74.86908789603942, 70.74911655918245, 72.64987361046576, 72.47814439958142, 75.96922643723028, 74.38462811131632, 75.49544334411621, 72.83562137234595, 75.32962906745173, 77.32460929501441, 75.04117796497961, 71.11851753727083, 62.33376941373272, 59.22733068466187, 58.819761122426684, 62.552472929800714, 73.9412747659991, 71.69300356218892, 70.67380705187398, 71.60709581067486, 81.84967517852783, 81.1463628276702, 84.16245368219192, 86.32348352862944, 42.51360147230087, 2.9224751553227826, 0.19289622023220987, 0.388407098549989, 8.136932407656024, 10.954490534720883, 4.80326489094765, 3.78177575526699, 0.9646729908643231, 1.0258598817932991, 57.34903704735541, 56.24875337846818, 75.28455318943148, 66.11342414732903, 69.41122747236683, 43.74470010880501, 0.5982392858113013, 0.30838005244731903, 0.17579188239910912, 0.15512952581048012, 0.2016730137890385, 0.16359747868151436, 0.14573077611144514, 0.2743884554553417, 0.14502326326985515, 0.11148383435342582, 0.1696989706326877, 0.1010674977254483, 0.20171876455987656, 0.2018629729507431, 0.1529095255799832, 0.06421513690222656, 0.2741616321427207, 0.2272457335024111, 0.1205611642029497, 0.151903590848369, 0.14547203757589863, 0.2200141852541316, 0.13387781778170219, 0.0799501002315552, 0.1757385780013377], [0.07520155019817815, 0.06894411338913826, 0.04330482446558533, 0.014777293094554016, 0.08371842544405692, 0.025486588448045716, 0.031107400446349097, 0.034316058210547895, 0.009200841417506097, 0.04982720512235838, 0.051979149932101856, 0.03212754993939833, 0.04008990967826497, 0.03341478641114889, 0.024033993813059023, 0.0508078359698336, 0.0317042384807381, 0.04464383507447858, 0.04290590716165401, 0.06154174668594234, 0.02287018942766853, 0.005612562667773736, 0.00944160657273906, 0.023078820067307642, 0.07912670126965932, 0.05410145863049454, 0.07341234419014185, 0.011531285671216827, 0.05729067882883453, 0.02065305628122822, 0.05695273063235706, 0.07544937198080363, 57.27644966494653, 75.67346403675695, 59.27005706294891, 25.3675486195472, 61.97238576027655, 34.073429646030554, 1.1495291489747264, 0.2137166360813764, 2.1361127447697426, 3.006648974072549, 5.076032886582037, 2.532828373293723, 0.16996276534853444, 0.15929327496597845, 0.34814111888408666, 21.193195581436157, 95.7678762558968, 89.82740740622245, 98.16552700534945, 84.2574691772461, 87.75702353446715, 77.3909051956669, 76.89994996593845, 74.92532683957008, 78.91860561986124, 78.82555915463355, 75.66818452650502, 67.65075791266658, 63.43915216384396, 63.1586556280813, 68.14484319379254, 71.71645149107903, 74.05638848581623, 78.8623352973692, 79.67370894647415, 76.53680124590474, 75.32478101791875, 69.65318279881632, 73.55286598205566, 70.71569796531432, 73.94555014948692, 73.17825609637846, 64.8385714715527, 52.47256994247437, 52.889388453575876, 51.36611246293592, 54.82346211710284, 61.93204026068411, 70.92088499376851, 70.00170107810729, 68.94286509483092, 68.66723229808193, 64.56460568212694, 58.486536164437574, 74.69966503881639, 60.65237091433618, 75.52200563492315, 28.850760421445294, 40.807366524973226, 67.17125600384128, 60.202098508034986, 67.86565672966742, 62.614709177324855, 71.63182243224114, 67.13153808347641, 73.27996315494661, 66.67768063083773, 66.597107302758, 57.058424718918346, 51.16286308534684, 48.00277809942923, 50.12310158821845, 49.08569743556362, 51.01439352958433, 47.392935829777876, 52.23945563839328, 52.63301841674313, 57.59353799204673, 61.02150517125284, 66.30531434089907, 66.76050539939635, 66.88249111175537, 67.09629166510798, 65.8006739616394, 66.21070677234282, 67.77169242981942, 67.28806418757286, 66.7648043171052, 69.62714610561248, 73.43475557142689, 68.04732522656842, 63.73255721984371, 53.57901565490231, 54.89798322800667, 57.3026510976976, 63.34023391046832, 64.40610270346365, 69.01585255899738, 69.66467534342121, 69.82267625870244, 77.99169463496055, 80.57947835614605, 54.03020589582382, 4.477299749851227, 0.21638772420344815, 0.0766471581112954, 0.7449080446554769, 3.769487459813395, 1.3457522132704336, 0.8601038890980905, 0.3411804746475912, 0.061362221641766454, 6.801765445739993, 53.95050333392236, 24.780050131582446, 15.914360957760966, 35.98806012061335, 58.91869114291284, 4.598669650093202, 0.14321475950700624, 0.08294538910230322, 0.029085652279337088, 0.025058234215623913, 0.00764987008052788, 0.016828431267171137, 0.0665501116083995, 0.02567350241025129, 0.07723012803903512, 0.059506871602347786, 0.052307679077550295, 0.10680341251915502, 0.02085089274201422, 0.07278679509557064, 0.027146101516160755, 0.024945127079263333, 0.01025276440721486, 0.08670956211825533, 0.035125445424308704, 0.025676993855966196, 0.07576275556798905, 0.0438199190032338, 0.011491568800392411, 0.016967891828126965, 0.03292704504283686, 0.017089540844843272, 0.02820699539546284, 0.024194590739845753, 0.04594244986712452, 0.05535286708524632, 0.02575364669844989, 0.029309585525263703, 0.05803891307403965, 0.024364250486776717, 0.04543410456408897, 0.05704893212344858, 0.043858238721206304, 0.029102406622241103, 0.06604518305750624, 0.020469018979178324, 0.026123538846150044, 0.09252009387578695, 0.09004402109572003, 0.07160169538110495, 0.025356920405982003, 0.01260062088183458, 0.038662948345224706, 0.03128802482669633, 0.03511047223582864, 0.008945945770509781, 0.03473714992944752, 0.0064318534831756796, 0.04558610406914546, 0.031509175258237994, 0.07863312614180389, 0.0882660459366537, 0.5529218755902783, 68.34244435833347, 86.90187623423915, 46.10096593056956, 41.554632955981845, 80.96947177763909, 36.81458588569395, 2.314352844991992, 0.24723439237042782, 0.1848659027488001, 1.0664732057240702, 5.5879796608801815, 4.463469962919913, 2.811213448163002, 0.255109362544552, 0.6931808074155162, 26.608017798393007, 97.14453404949558, 91.14475111807548, 97.80983078864314, 84.29698313436201, 92.5966085926179, 77.84747692846483, 78.2114964146768, 76.67677494787401, 82.9660915559338, 82.24166900880876, 78.47721345963018, 68.80959080111596, 64.67518514202487, 68.86664559764247, 71.32189243070542, 73.39441007183444, 78.89069403371504, 79.4609909672891, 81.46069372853925, 77.65085635646697, 76.2692799106721, 73.59398811094223, 73.97751746639129, 73.41410037009948, 76.78279661363172, 74.48779429158857, 67.32389896146714, 53.616760623070505, 57.10190811464864, 53.02519659842215, 56.99503921693372, 65.97925555321478, 76.73134296171128, 72.84702762480705, 68.42042107735911, 69.94950217585411, 66.85822732986944, 62.14121633960355, 75.23841042672434, 62.127448820298724, 76.65120893909086, 29.646056275213923, 43.35396535934941, 71.46093260857367, 62.13485033281388, 71.37558967836442, 65.13329836630052, 74.06866550445557, 70.29906380561091, 75.66856107404156, 68.64325877158873, 67.98169612884521, 57.49057185265326, 53.5822045418524, 50.64354911927254, 52.79413761631135, 51.85771880611297, 53.00321563597649, 50.403915835965066, 55.36738503363825, 58.56272036029447, 61.56096835290233, 62.926431702029326, 71.32583833509877, 69.44179058074951, 70.15585807061964, 68.5663018688079, 68.64234878170875, 70.3306467302384, 72.56033374417213, 70.34510458669355, 70.3649753139865, 72.38014005845594, 76.26837776553246, 72.33416203529605, 66.67278551286267, 55.55857704531763, 61.46048899619811, 60.88890160283735, 67.46253121283748, 68.86632396328834, 73.68228066352107, 73.31722567158361, 74.52980287613408, 79.63257112810689, 85.58250857937722, 57.283419716742735, 5.5030024916894975, 0.20935876024586542, 0.19353613347536136, 0.8480985558802082, 2.332807106356467, 0.41494787760799934, 1.0835672626572272, 0.7213583180019933, 0.15026940273181086, 13.27036084667329, 67.0584015692434, 39.44078137797695, 23.706817088588593, 45.42348630966679, 67.8776042692123, 5.337968766689301, 0.1965824514627457, 0.12845384632988324, 0.06424320253333257, 0.04767892604333259, 0.04786516201772517, 0.04357570549473167, 0.018792571537497065, 0.038596999666263024, 0.035567776930909005, 0.010029502445831895, 0.06007424781038877, 0.06341258319275034, 0.017737685702741146, 0.025291063657571233, 0.04954728042526592, 0.04894173005595804, 0.03225116397164041, 0.03747935016309062, 0.0483070147193728, 0.040777791516795274, 0.01924637521076347, 0.04938914072549632, 0.0061881733633908295, 0.010717317251668823, 0.04784356216870008, 0.21818430763819527, 0.28209548383470506, 0.14411524989672247, 0.13985938632920866, 0.15468030717344056, 0.16221640601513848, 0.15457224281084153, 0.10652571330748259, 0.13626208258492334, 0.1380952237354171, 0.09981507420419686, 0.1666399662292773, 0.07547254614051312, 0.13408129073439107, 0.10536199510698357, 0.181583491784911, 0.2031649240562993, 0.14419104663595078, 0.17182838862701771, 0.1457367822407715, 0.07457008690483148, 0.10086884346580315, 0.16256889839085842, 0.1522463385856921, 0.1530541170148119, 0.20765263647321733, 0.12066152172103045, 0.16413453695995195, 0.22094553366543787, 0.11395871203633086, 0.18941464172976633, 1.0700483235620684, 95.64393720319195, 96.09609234717585, 86.17136616860667, 40.39226601200719, 80.68146782536661, 52.14447936704082, 3.554642330254278, 0.5636067796618708, 5.234813372935019, 11.896949794984634, 19.26675485026452, 5.476539731025697, 1.0543491595214414, 0.2732293031388714, 0.46209326554690644, 30.27633801583321, 100.9852247853433, 91.23979014735069, 101.82272926453622, 87.46556789644303, 95.99160040578535, 83.57154861573251, 83.69289105938327, 83.04971648800759, 85.58088471812587, 89.09015086389358, 84.02801836690595, 74.40804466124504, 69.89103532606556, 70.13513226662913, 75.19509961528163, 77.7924382302069, 82.31351898562524, 85.28434568835844, 86.0710084053778, 81.42664755544355, 82.17484751055318, 76.3724696251654, 77.86541000489267, 76.29730132318313, 80.83902943518855, 78.39143906870197, 72.8708677907144, 57.79172358974334, 60.01327168556952, 57.01071300814229, 60.799487252389234, 68.80717462108981, 77.60067355248236, 73.79071066456457, 72.98058432917442, 68.25629341986873, 66.97875392052435, 63.976885580247455, 76.11219683001119, 62.72618293762208, 76.0751304318828, 31.528805725036133, 44.53211592089745, 75.09224722462316, 65.11936610744846, 73.13317237361785, 68.43006226324266, 76.52259442114061, 72.50553038812453, 77.93281201393374, 70.59774444949242, 71.02745579135033, 59.90712842633648, 56.08560631352087, 53.79766818015806, 55.82827921836607, 53.833012657780806, 55.75236958842124, 53.88934966056578, 58.74656185027092, 60.4172012882848, 64.65716185108309, 66.14429320058515, 72.93098988071566, 72.48562043712985, 73.29103992831323, 72.98548729188981, 71.15667435430711, 74.88881741800617, 76.2270438286566, 73.75421693248134, 70.27886359922348, 73.0281077661822, 82.68789352909212, 74.8914061823199, 70.36246499707623, 58.64155607838785, 64.04330307437529, 64.54544490383518, 71.69914599387877, 73.54371901481383, 78.05395049433555, 76.55427932739258, 77.62747118549963, 85.66403896577897, 88.50365454150786, 57.48648866530388, 6.01523805049158, 0.29209725198245823, 0.16773738718080908, 3.3476323802624983, 10.703900110337043, 5.980298557589132, 4.961835040200142, 1.3638937881877347, 0.1961400356864737, 13.254789037089195, 77.50444996741511, 34.14341649701519, 33.32269583978961, 51.945905454697154, 88.12457315383419, 9.120089200235183, 0.3725286086480464, 0.28832653657563273, 0.10319857046969476, 0.24591718079341998, 0.18840466205391193, 0.11941009411408056, 0.1280420051226693, 0.16627196823396992, 0.12604878223951788, 0.12725386918792803, 0.10676467145282416, 0.3323818016196451, 0.13260372163307282, 0.14259784422334165, 0.10021545473606357, 0.11826849287195552, 0.15181072567018772, 0.11821013995476308, 0.0999152708438135, 0.10384875695191084, 0.1320955601911391, 0.13001891033303353, 0.06685281592992044, 0.20520587421713338, 0.1296586651475199], [0.042728990646860296, 0.03535061398701322, 0.052083494937828476, 0.049037333998468616, 0.024346335520667416, 0.01934086449534422, 0.030725555411810358, 0.051294872537255294, 0.04436005312468737, 0.0294111879362214, 0.025902821254285596, 0.030573274369441697, 0.05702827456257036, 0.02543639245202705, 0.043766181765785145, 0.03211833581688904, 0.038629600537880775, 0.05507899448275567, 0.046122013215696624, 0.02289398220337687, 0.09078371729100905, 0.03944835700695554, 0.09776467051837714, 0.0472357020443005, 0.0316489901348588, 0.042655760302178325, 0.16784891426082582, 0.03231321326306751, 0.0616798340342939, 0.1103528127855351, 0.11125370154097197, 0.7812804896985331, 11.001568782714106, 73.51217531388806, 65.51134817061886, 41.414059131376206, 41.12856157364384, 60.43287900186355, 11.608700694576388, 0.04260749293250903, 0.2626685972415632, 2.388821494194769, 0.6534315693762995, 12.786886557455986, 3.195866807814568, 0.16557815304446608, 0.15336761551518596, 0.17781095308882577, 25.536871456330825, 88.7268138700916, 91.29205180752663, 98.98620451650312, 87.71558761596681, 81.82442295935847, 82.36578849054153, 83.61962902930476, 80.31096858362999, 80.44815740277691, 80.64196955773139, 78.74526823720625, 73.30749034881592, 68.13477054719003, 71.44221505811139, 72.32960424115582, 77.24664042072912, 76.2689112078759, 78.84411196554862, 73.75387176390618, 69.69972564328101, 67.59777453637892, 72.44293720491471, 68.41288228188792, 76.449261788399, 75.29130751086821, 66.36513833076724, 55.831672068565126, 52.734764699013006, 52.794255287416526, 53.157278491604714, 58.85533701988959, 69.36481014374765, 69.80522955617597, 73.46433024252616, 66.22263077766665, 75.95241515867173, 65.14301799958753, 67.70370990999284, 60.84998384598763, 78.81423919431626, 26.633795615165468, 40.690256318738385, 74.99054016605501, 63.39670819620933, 73.32632557038339, 63.32907084495791, 69.84058580090924, 68.18300001082882, 69.95620942884877, 65.36343166905066, 67.08278302223452, 54.57504664697955, 51.589311015221384, 49.730119320654104, 49.89981282141901, 47.8682957157012, 51.39998212937386, 47.77460990413543, 51.23335984445388, 52.258239869148504, 55.46766434946368, 57.8555013287452, 63.10766873821136, 65.3011561978248, 65.25615484483781, 65.20459136655255, 64.1210287617099, 66.28028961919969, 70.06720465998497, 72.71029380060011, 69.6980704030683, 68.19231956235825, 68.4239512105142, 69.64525176632789, 66.50941879518571, 60.817059470761215, 57.94112274723669, 60.13052309713056, 62.02736954535208, 64.48575819692304, 67.72707939147949, 72.25408292585804, 81.93074272524926, 67.54268876967892, 61.98804386200444, 11.34973208750448, 0.5404955617362454, 0.1650600324595167, 0.3264869695469257, 1.273045688867569, 1.5638243503147558, 0.8803739014171785, 0.6614715702110722, 0.550989679271175, 2.471897049296287, 39.558793729351414, 49.761961121712964, 17.141595079052834, 34.82569709900887, 48.20804357528687, 12.769969374902788, 0.11053725611418487, 0.0009983206555555246, 0.0354193895304155, 0.021349142921427568, 0.007814910796080387, 0.036105455740565257, 0.03344674376891025, 0.05496015892394128, 0.07785686456988897, 0.09941903739086083, 0.05815357345366671, 0.06118006125513104, 0.027263270833739833, 0.034663701249707135, 0.00499964109621942, 0.13091365506331767, 0.04300946692725824, 0.07805088399759225, 0.022735706523000714, 0.023209878558953925, 0.01251572876372525, 0.029017598773803444, 0.03453504827414309, 0.014731876529572953, 0.06323563603443966, 0.10878691374654732, 0.04265402128259021, 0.017103610049572684, 0.06771055861346184, 0.050692964916027365, 0.056192901646417964, 0.005018480634692336, 0.02324542695386035, 0.02561592324186237, 0.03744382283560211, 0.06606780563391025, 0.04951442674463315, 0.010414780511881315, 0.0071693869164934565, 0.027508284904122837, 0.04834728796155222, 0.026654119851187836, 0.05584078465378093, 0.06421627837323374, 0.02112488025769351, 0.04799402183702877, 0.06745918984374694, 0.017967060088149963, 0.12855206646265524, 0.08860386006774441, 0.0332105626922942, 0.031318201030033736, 0.10504123409308734, 0.010090229277979704, 0.06396819995115362, 0.044108734150687536, 0.09963233925161824, 0.651988382301023, 12.588618589985757, 87.29558806265555, 63.051571000006895, 34.826920878502634, 58.99019987352433, 68.44049576790103, 17.00522799645701, 0.1284279065927671, 0.7154056309692322, 1.8402134290625973, 1.216171934239326, 5.368532365368259, 5.052684487835054, 1.030118840356027, 0.7182668161488349, 0.2991494590476636, 34.89565257103213, 90.7435554073703, 95.1084787614884, 98.70388015624016, 89.93431552763909, 83.06556286350374, 84.76959736116471, 86.9229393620645, 83.13979764138499, 82.55291692672238, 83.77591194645052, 80.75518485038512, 74.61124697039205, 69.416899219636, 73.54479374424105, 74.63329069076046, 78.59595144948652, 81.18245647799584, 79.98457247211088, 78.04547033002301, 73.02587985992432, 73.69626783555555, 76.32004322544222, 73.23554623511531, 77.75300272049444, 76.32121209175357, 68.34135393942556, 57.06415922411027, 57.47150128887546, 56.41726624581122, 56.52771626749347, 62.36008067284862, 73.44442813627182, 70.98973043503301, 76.6242544112667, 67.8248248561736, 80.17325416687997, 66.87571325609761, 72.52022358679002, 63.3596614099318, 80.79945272014987, 28.163215998680364, 43.92084198613321, 78.54489787932366, 65.53908325010731, 77.13921454644974, 68.38440587443691, 72.47906223420175, 70.23741983598279, 72.51645026668426, 69.74011036657518, 69.30498615387948, 58.24012110310217, 55.07616473782448, 52.7562161414854, 53.02144289016724, 52.245488243718306, 52.925560551304976, 50.24205923080445, 54.18013457329043, 55.96374219463718, 59.02206520880423, 61.98590617026053, 67.2295424246019, 68.53438162034558, 69.75041051064768, 68.92950550202401, 68.5157189830657, 71.02958171598374, 71.17240305869811, 75.77344525244929, 73.50737433279716, 71.55461449776926, 73.06928480825117, 70.91617814956173, 70.41574647349697, 63.53928242960284, 61.770975974298295, 62.51908179252379, 65.43942759113928, 69.11341759466356, 70.78556322282361, 74.61552235387987, 84.4861747372535, 72.63589428317162, 63.92932291953795, 10.880597003044622, 0.5480479016419381, 0.11520941952063192, 0.26584118184062744, 1.1321081870025205, 0.814267561560677, 0.6508080553143256, 1.1312360725095196, 0.9119316983607508, 6.067442346003748, 46.61074069238479, 68.41193306830623, 22.96585782881706, 36.11860444468837, 63.0293821519421, 17.563879412989465, 0.23003620876660272, 0.05413264990033162, 0.027758422187499465, 0.03174530845435877, 0.019347508392867543, 0.008296464089184039, 0.05466649060948722, 0.04010085707470294, 0.039260772717816216, 0.04891213224900346, 0.05051488394758875, 0.06450163846414897, 0.027206319857448823, 0.061982197446688536, 0.015429118047318151, 0.047566399218574654, 0.052652878296231075, 0.01079744621810894, 0.044401647868536176, 0.01831251594628538, 0.01892853490707855, 0.04049610098703735, 0.093948089427525, 0.01708548440928421, 0.06338360591701443, 0.023980513215065006, 0.159356017566977, 0.15885887246939445, 0.2198805948418956, 0.12046956306984348, 0.18192666853147169, 0.060758145991712816, 0.13912858441472054, 0.1477657814299868, 0.154574939440335, 0.09549587048710355, 0.116046202038565, 0.09023875298519289, 0.14828823807258762, 0.0957140829714556, 0.3504644490538105, 0.08042943378489825, 0.23204795565576325, 0.19781735455316884, 0.17263656542185815, 0.11500752470906704, 0.20355503134910138, 0.2702747165195404, 0.26710691230912365, 0.18445428370708422, 0.0912433470629396, 0.13374998835065674, 0.2599753998219967, 0.15276928552456442, 0.17310269928026586, 0.4492507208018534, 0.4431358989207976, 1.0945666917870123, 23.814180204945227, 106.63717977462277, 82.1248451355965, 64.53285017321187, 53.94205847094136, 85.64271696152227, 21.67562161722491, 0.3049016149053651, 4.409343215727038, 5.859603795313067, 4.361712894132061, 31.260356749257735, 8.632673909587245, 0.2931469762998243, 0.5751145847382084, 0.24151684836514536, 31.53919412243751, 93.48657869523572, 98.03368045437722, 103.03509466109738, 93.11388292620259, 87.36375101151006, 87.92043732058617, 90.79990417726579, 86.51749964683287, 86.80478188299364, 90.18919898617654, 85.21775168757286, 81.340865319775, 74.19742907247236, 78.32675133982013, 78.69139056051932, 84.8092995920489, 83.92052188996347, 84.11276509684902, 80.96653784475019, 77.09999084472656, 75.8342263006395, 81.68783034047773, 73.75868843447778, 83.46511117873654, 81.63557652504214, 74.14675204984604, 61.810874323691095, 62.30185701001076, 58.96305314956173, 59.95759756334367, 65.21377363512593, 77.13821826442596, 75.17451501661732, 79.92146938077866, 71.70520213342482, 77.72493423954134, 69.37689888861873, 77.75016292448967, 66.61602881646925, 82.16746560988888, 29.598419089471143, 48.714076395957704, 81.4995095037645, 70.16402444531842, 80.2229662864439, 71.36874122004356, 75.38517767383208, 74.84940544251474, 75.48402140217443, 71.64981826659172, 72.4648161857359, 60.13551235198975, 58.442942942342455, 55.616663425199455, 56.52461367268717, 55.6398642447687, 56.53325857654695, 53.739883822779504, 57.8579528101029, 60.591727149102, 61.57760704717329, 66.56945459304318, 70.98394101665866, 71.98412972111856, 72.3221674273091, 74.24751773957284, 71.94692996240431, 76.61589191805932, 74.5948749972928, 80.44953023233722, 75.6940015669792, 75.39988656197825, 75.55178426927137, 76.32889209255096, 75.42010245784637, 69.66014892824235, 63.50916254904963, 66.82236117701378, 70.97033823690107, 72.31927271812194, 74.8045099935224, 80.53597927093506, 87.39738925810784, 75.01222302836757, 63.931048762413766, 12.167671784277886, 0.5218366016784023, 0.3757865967289094, 1.0153074190020561, 7.629568432607959, 6.879837282242314, 3.248593759152197, 3.7233084151821756, 1.1621678836884037, 4.354863455218654, 57.44566071418024, 65.57725183425411, 28.102988004684452, 51.78312317017586, 71.6364900527462, 34.047812646435155, 0.28786547421928377, 0.20454129294282009, 0.20880515446826337, 0.14353139896786984, 0.12166187933255589, 0.14798169565056601, 0.17191653470358542, 0.1312461372224554, 0.10864664304761157, 0.1913545908586633, 0.14059015760017982, 0.17571475266689257, 0.08358269764651215, 0.18152384417912654, 0.11109108405728495, 0.2710410802354736, 0.20801983773708346, 0.26920409332359996, 0.11810076558181357, 0.09897193315649226, 0.12915329226563055, 0.1397670574125744, 0.29083096993065655, 0.09658658050841863, 0.1082170592440713, 0.33686215959249005], [0.03852431324400729, 0.024673759584285082, 0.04845886483728405, 0.03797824577158017, 0.010083101787454179, 0.007422375004558314, 0.08653542267218714, 0.04983132284495139, 0.00847052213841028, 0.0323833141385788, 0.04049171896411046, 0.02947430400508306, 0.07057347515177342, 0.07671661930338991, 0.03803864414353044, 0.03216904317659717, 0.03753965277405035, 0.05601808038209716, 0.037289900449855674, 0.07292903464047179, 0.026469128769672206, 0.02618364418946928, 0.03991298933303164, 0.03144539460810202, 0.040652497836779204, 0.06147291368594574, 0.0710364374061746, 0.053226260633598414, 0.07742510507664374, 0.03469703373529258, 0.0742694356989476, 0.04249196687352754, 0.03064607953532569, 42.69858044962729, 86.72736214053246, 56.24212457287697, 32.49155540620127, 74.18016279897383, 40.039888120466664, 1.5226614042635889, 0.633346276177514, 0.5897063533625295, 0.4534039592310306, 1.4668976803941112, 6.332145948563853, 3.324296238922304, 0.40051784546625235, 0.2821204583010366, 0.507717723807981, 36.104942829378196, 111.70928293658842, 81.40118352828488, 97.1136728409798, 84.93505077977335, 87.47123179897186, 82.3025598833638, 88.25747874475296, 82.05088492362731, 85.14847478558941, 76.99287876006096, 75.91073605322069, 74.84509083532518, 81.21004642978792, 82.1176201297391, 83.31035014121764, 78.49113002900155, 79.15887432713663, 69.69791350826141, 75.51221539897304, 70.05882647729689, 69.82191531888901, 69.79991866696265, 78.47492279544954, 73.96481683177333, 69.81200741183373, 54.270713867679724, 55.04645670613935, 51.98502717479583, 53.22456282954062, 50.56375242048695, 64.04370315613286, 66.22242681441769, 77.25729357811713, 70.18110244504868, 75.37062568049278, 73.46359283693376, 79.0685421420682, 65.01478002917382, 83.74980465058358, 27.203200209525328, 42.0468904126075, 78.27219117072322, 65.81690865178263, 73.26004535921159, 67.09027474926364, 72.20422175622755, 68.20655776608375, 70.94576066540134, 67.80868822528471, 68.07307950911984, 51.6373678945726, 51.563709705106675, 52.59342601222377, 52.51206821010959, 50.26571896768386, 51.0132364303835, 50.21164909485848, 51.763044557263775, 52.228339641324936, 53.725276916257805, 55.12221728601764, 57.3351244003542, 62.25771073372134, 66.55204711421844, 64.32761999868578, 66.60233974456787, 64.38733416218912, 65.16352022847822, 67.5236338953818, 68.35869866032755, 69.76337786643737, 74.66151606652045, 72.41144841717136, 71.61956110308248, 64.10075795265936, 60.70535821299399, 63.79572699146887, 66.18020642188289, 68.66240778276998, 71.77382792195966, 78.50661554644185, 65.76943228321691, 61.653755941698634, 16.413172694944567, 0.37265783235911404, 0.07666745944128883, 0.6060014112341789, 1.0592489353110714, 0.6568868710629402, 0.9296340903928204, 0.3879861792008723, 0.8058239856073934, 2.833867097093213, 25.01908721462373, 71.89814352220105, 27.29189088267665, 34.32446133705878, 53.9288204716098, 43.16931978348763, 0.3249245485471141, 0.04996254987594101, 0.2517252610695939, 0.04913509447848605, 0.053507805606650735, 0.027882783155467723, 0.017113749223250537, 0.03943961977417912, 0.015844248644556972, 0.016334850393656283, 0.04662288533103082, 0.019227874187392094, 0.07720982670904168, 0.058981725991132765, 0.023252586045512752, 0.02262517344206572, 0.049736266655306664, 0.047462942874840194, 0.08748758569239609, 0.04248953454436795, 0.009958358733133684, 0.03470878935449066, 0.005513214470533234, 0.045396669677669005, 0.02875185053374979, 0.06239947787816487, 0.014780640898783122, 0.016725742926580772, 0.03152159928915001, 0.04201758224817534, 0.023847367133825056, 0.012977295780494329, 0.10451602719483838, 0.04450577453920438, 0.08669760348575731, 0.004639927863008193, 0.03572451468977717, 0.03231473394759721, 0.04046346181102338, 0.12901927284415693, 0.02589616969588303, 0.0019548023767363763, 0.01906124240298185, 0.017821530195614024, 0.04177189018997935, 0.04621785081502411, 0.04238246992651013, 0.03107367342548265, 0.024461547483599955, 0.09957671360743624, 0.06424960319793994, 0.028111052459045768, 0.08327073132198665, 0.0823376821954885, 0.02036847185433632, 0.02813685238511572, 0.018100432165327574, 0.11032972289549728, 0.012245587009425846, 0.11413453687583247, 48.805498999934045, 103.25643400992118, 42.02164996054865, 42.886003063571074, 88.22722942598405, 46.11907159128497, 3.636864524695181, 1.0117783277265489, 1.5044281439435099, 2.1423782408237457, 1.6019643747037458, 5.87687889414449, 4.603358353337934, 2.6760054259530963, 0.8218123631611948, 0.44451926985094625, 45.21673425551384, 110.81854404941683, 83.07288200624528, 96.9743267182381, 89.89181272445187, 87.80318198665496, 82.49651324364447, 91.49217897845854, 88.44294409598075, 86.21018194383191, 78.2510809744558, 78.52618032886137, 78.13976410896548, 84.32363171731272, 83.23386392285748, 87.50390514250725, 79.3940596426687, 80.52344337586435, 72.6770164120582, 75.98832837996945, 73.60497859216505, 73.41865031949936, 70.09233920804917, 78.92916464036512, 73.82437244538339, 72.9498564812445, 56.43005317257297, 58.21298222387991, 53.67037550095589, 56.93569375622658, 55.71670739881454, 69.48028472162062, 68.424743529289, 80.86624283944407, 72.87951269457417, 77.14039125750142, 77.07913952489054, 81.55365390162315, 65.37117835014098, 83.41126488101098, 27.418997249295636, 45.04740945754513, 79.9696360864947, 68.37190920306791, 75.61830766739385, 69.69087677617227, 74.42468335551601, 70.762695804719, 73.37786551444762, 70.29246637898108, 70.72523716957339, 55.994783832180886, 52.72101679155904, 55.669525208011756, 53.815095270833666, 53.40737273616176, 53.076932660995, 54.154419514440725, 56.4587688446045, 55.78691390252883, 57.339792020859264, 58.358309961134395, 62.54968020223803, 66.64259895201653, 69.55976763079244, 67.99272583376977, 68.13702198766893, 68.6411799153974, 70.96214832798128, 71.9984620617282, 69.37976221884452, 68.86433139924081, 74.84205492081182, 75.34993125546363, 73.22701900236069, 66.11336138940626, 61.493750695259344, 67.22150941048899, 70.31679291878977, 74.51145402846798, 74.7726760372039, 81.72907798520981, 68.604796009679, 66.4340308404738, 17.922870420640518, 0.3679186898854471, 0.051841031940233324, 2.0836959058238618, 2.6282949409177228, 0.7233301670320573, 0.458440680898005, 0.6981271613509424, 1.134732130073732, 6.206007426784885, 33.963214966558645, 85.22683589689194, 47.4177408987476, 25.73631613485275, 60.66465577771587, 51.652363115741366, 0.7272069396511202, 0.05309103462364405, 0.22720565178221275, 0.08460629836566026, 0.04497161728420085, 0.04676856461071199, 0.029499006510201483, 0.07485346282802283, 0.09779863885693973, 0.013701940263291041, 0.07460944084150177, 0.020577232728922562, 0.06259969878761519, 0.062017023803726326, 0.02623073752939461, 0.030897544066031134, 0.07279408059173054, 0.049901289655075926, 0.020366951169806625, 0.0255348366655169, 0.016232587231863892, 0.0451866083688313, 0.04332047181143876, 0.039856651227080056, 0.0663585743055709, 0.05236109838851037, 0.016632960102851355, 0.16300069618849986, 0.14380884537052724, 0.14855535761002572, 0.0767558659877508, 0.11123716170268674, 0.18920608195326022, 0.14427231324295844, 0.23942060197793671, 0.10215391765438742, 0.1279197681334711, 0.15834642093508475, 0.12245436664670707, 0.3461286365505188, 0.16718940448857125, 0.10064983425000984, 0.07854889477452925, 0.07386812053981327, 0.19333701190208236, 0.10794600201470238, 0.1142678744790535, 0.11973528311617913, 0.16085443958159418, 0.39879993926132884, 0.20520854020310988, 0.12235549533919943, 0.15186455100774765, 0.1965650919103815, 0.20076401982336275, 0.16951910850982513, 0.16924507885931, 0.21015769802033904, 0.1630484541096995, 0.26698660586149464, 69.7270880976031, 109.4111740973688, 82.76199494638752, 50.95720145010179, 90.13070860216695, 60.74356602084253, 3.710436422017313, 1.6937987049741132, 2.5329960546185895, 2.7163153790658523, 6.105959040503349, 19.40675404763991, 8.848871031115133, 2.0063701776727556, 0.7828889066173185, 0.7709176489903081, 44.277310909763465, 115.2187216666437, 85.72298434472854, 100.82590595368417, 91.72879988147368, 90.74213550936793, 85.66564713754963, 94.95618881717806, 92.41974107680782, 91.43892103625883, 83.6895570447368, 83.29831630952897, 83.80671824178388, 90.1193101944462, 89.79696196894493, 93.00669239413355, 82.89861109948929, 81.31701730912732, 75.43421514572637, 78.7236402880761, 78.39689900798183, 74.77936760071786, 74.45986701596168, 81.8175038983745, 77.84720236255278, 77.10035170278242, 60.74319731804633, 61.540046430403194, 57.888633589590754, 59.837243556976325, 57.23988925257037, 72.24432406886932, 71.7746594644362, 84.10622258340159, 76.2239843799222, 77.69339053861557, 76.64166973483178, 82.0069622224377, 68.92786595129198, 84.54514365042411, 31.27125897715169, 46.72681147052396, 85.00166047003962, 74.09166628314604, 77.97574627783992, 72.88782027459914, 77.86363709357478, 73.18313552487281, 75.52880702480194, 74.09187809113534, 71.83665644737982, 59.528674617890395, 56.090446518313506, 58.2240354630255, 57.825287311307854, 55.55143833160401, 55.33822221140708, 56.11918180219589, 60.01709207411736, 60.51556648746614, 61.18687622008785, 61.81674611183905, 65.16139038147466, 70.27785162771903, 74.26882405434885, 71.64202843942951, 71.83060030783378, 73.49505024571573, 76.09355772695234, 75.5043863481091, 71.77804839226508, 70.28262122984856, 79.73438016829952, 80.6906932400119, 77.63355870400706, 70.6211845336422, 67.49314923440257, 70.90776074317195, 72.94252164902227, 78.6579562771705, 77.65187617271178, 84.64500719501127, 73.51587018659039, 73.66802677031487, 19.66705822175549, 0.4005645461861165, 0.2613363090542055, 1.2867521662865917, 9.846834771094784, 4.784075185175865, 2.039968342550339, 1.362700897359079, 1.4212583293837886, 4.666483508002374, 38.998134059290734, 90.1796833161385, 44.04037621713454, 56.11624394693683, 70.32720288922711, 71.08020382542765, 2.0036235379595912, 0.3514995257700643, 0.3831866996422891, 0.21205466961668384, 0.2057659764203333, 0.07845577678733295, 0.07349813837678203, 0.17673867514296887, 0.23728684792595528, 0.09311231048477274, 0.218740901158702, 0.14274732329912726, 0.17497944615540967, 0.15474706407516234, 0.08684792525825963, 0.1998405621176766, 0.15109277871106902, 0.14110901362953648, 0.15548279959588282, 0.09780561025705069, 0.11111566015789587, 0.13118540177181845, 0.20211141526458726, 0.15453167079437166, 0.26765975199880143, 0.11517362789280954, 0.13744219506700195], [0.031783725848541625, 0.023031878029747356, 0.07227953763738756, 0.07284422870725393, 0.04105419220943605, 0.015574676668151252, 0.05301373252164453, 0.03140384965996829, 0.0832872941429096, 0.02743853642905672, 0.044303458379281145, 0.01425716727446284, 0.08238105809376126, 0.08014690821930286, 0.038487069879568396, 0.04914888023068348, 0.02770170678324517, 0.06509451390874964, 0.053712665178482576, 0.0680399151338685, 0.05528511043878333, 0.05684065196903483, 0.09201570924731994, 0.03520082464561828, 0.04771459892752671, 0.04887661641283382, 0.06008283948645957, 0.03742350235341057, 0.02345369753217505, 0.006523827126535077, 0.21413205491919673, 0.19735650670143867, 0.536657645096702, 4.969815102315718, 78.12594952121859, 72.13965954319124, 41.91040369772142, 46.828871542407626, 96.52946718277471, 26.77533042046332, 1.6809068548102535, 0.8102720759568677, 0.963512643450691, 1.1690197740831685, 3.7854745503394835, 5.564126747269785, 3.4326879968566284, 0.405365833712201, 0.2941915525063392, 0.1966665372733147, 70.09809724746212, 118.14391551479217, 93.34388286836686, 91.6477244900119, 87.40743837048932, 91.3387986152403, 89.37156523427656, 83.95914939142044, 82.64740682417347, 82.59743582817816, 85.20347426014563, 83.03319546484178, 80.34652094687186, 80.80532843066801, 84.2889814992105, 79.3656930615825, 75.25319776227398, 76.62954961099933, 68.0946211661062, 64.99024560374599, 69.57067966461182, 72.30614062278502, 75.81959585989676, 74.31671619415283, 66.44757870704898, 54.438614845275886, 55.47488543295092, 53.08256518456244, 53.84339517162692, 53.184978269761615, 58.708542316190666, 61.40505021618259, 66.85167697168166, 67.77959992808681, 68.94773667858493, 61.1918144841348, 77.20129782153715, 68.70047046292213, 85.05705218161307, 32.200076233956125, 38.067218334444114, 76.32429507470901, 65.88304765762823, 76.24936995967742, 64.26557202492991, 70.90197916953795, 68.29305387312367, 72.7156674477362, 67.46296267355642, 63.27024313711352, 51.38348071805893, 54.90156827434417, 49.881283544724994, 52.19509363174439, 51.747158958065896, 52.063980563994384, 49.161705124762754, 52.61482254151375, 53.63899653957736, 53.49172722908759, 50.96035895809051, 54.2751657578253, 55.11709859294277, 63.97623446679885, 62.415531219974646, 65.75444490678849, 63.79565638880577, 69.46585039938651, 69.65020179748535, 74.28886736592939, 70.24891238058768, 71.48645154891476, 72.68793629061791, 70.93825324889153, 69.15846209372245, 65.43903927649221, 66.76198021058114, 71.09342221290835, 71.05302964487385, 74.24121056833576, 68.24028230482533, 86.4144354481851, 19.424685162882653, 0.08837886004438324, 0.057160428559948365, 5.735221024482481, 6.39542309507247, 0.5923199389250048, 0.3092117174979179, 0.27023009955883026, 0.571483327977119, 5.74656795109472, 23.74452087186998, 74.65869195999639, 36.800292768786036, 26.29465964532668, 50.24546384811402, 65.09696937376454, 16.507796933574063, 0.7447874317726781, 0.15936453646469503, 0.2009096224942515, 0.1615496490511202, 0.10183827410782538, 0.03121697208693912, 0.047591814185462655, 0.07119661106938316, 0.15004392773393663, 0.03930506409115849, 0.05735475442282135, 0.05047643399466911, 0.02617144615449492, 0.11851517318357384, 0.06003816123871554, 0.010845873508632425, 0.04808027950686313, 0.046641191001981504, 0.0429071405632121, 0.04789749475856943, 0.05536252362353187, 0.0334172761969028, 0.05850439958815133, 0.0462814207909809, 0.040154559838195006, 0.02588473200317352, 0.013180339723945627, 0.040432975342076634, 0.02404023742964191, 0.07205790840089321, 0.11885960631433035, 0.04713932818342601, 0.054010190745635386, 0.07123344457678257, 0.06548244551184677, 0.04444035829135007, 0.05336792561255636, 0.05806582191238, 0.040578183477684375, 0.048052474345651366, 0.042190917301923044, 0.0372728664848593, 0.037210173679575805, 0.04142862534330737, 0.06099895806983114, 0.029499885596094594, 0.07791963781440452, 0.03914480615827826, 0.0521846185438335, 0.038752235892799594, 0.09470184333622457, 0.03758025926447684, 0.003256587097571502, 0.053087556584467815, 0.11458519575816971, 0.031919953518456994, 0.07709459942435065, 0.14905743631384066, 0.25097618029723245, 0.7962923196534958, 6.751312488509763, 87.24220460461032, 77.3270490092616, 28.935189439404397, 77.35287389447613, 103.42901829750308, 33.97429566229544, 2.5385932768544843, 1.1358982997555886, 1.8379818455826853, 1.076245423286192, 2.1140342133660472, 2.6342468925060767, 2.9622379377965005, 1.731038177686353, 0.9541911920232158, 0.3320686555197162, 81.3953862651702, 117.36278333971578, 95.33413271750175, 91.76526223459553, 92.73917890364125, 95.87998544016193, 93.09883671422159, 86.16116016141831, 86.90258226087018, 87.36889716117614, 86.3251309241018, 83.34911100326046, 81.95102137904014, 82.38134461064493, 83.85501830808579, 84.34760524380593, 76.80143571669056, 78.79498035677018, 72.77574246929538, 72.9130881832492, 73.49479921402471, 75.5904431496897, 76.97757367164859, 77.30853542204827, 70.70327189660841, 57.17052213607296, 58.78103163934524, 57.96688487452846, 57.197770841660045, 55.526919595656864, 62.23876176341888, 64.73433840659358, 71.18552730929467, 70.6408905213879, 74.10050730551444, 66.76099177329772, 80.21087754157283, 74.47274023486723, 88.17559534503569, 34.51509637217368, 42.214861992866766, 79.65488941438737, 68.4795468853366, 80.52930339690178, 66.97627498257545, 74.6607159030053, 70.58614207852271, 77.29501893443447, 69.62047807631954, 68.82397805490803, 53.77280035326558, 57.592698604829856, 52.96212096368113, 57.239775503835375, 54.1189887446742, 56.40168659148678, 52.36179436406782, 55.49175162469187, 55.59672601761357, 58.608941570405044, 56.06207601485714, 59.305130897029755, 58.96310414037397, 69.30338582684918, 66.91726684570312, 71.993449272648, 65.77357430611887, 71.7816726623043, 71.75729120931318, 78.29959284874701, 73.60115820361723, 74.59340803084835, 74.00229900113999, 76.49941321342223, 72.09947093840569, 68.27683095009097, 70.42422663780951, 75.82391046708631, 74.32966001572149, 77.17767730835946, 68.37648268668883, 92.58400993962442, 21.993539525616555, 0.22381695377970898, 0.0800341630594865, 7.542365318344486, 7.200040461555605, 0.8785301422880543, 0.49598665006699105, 0.521155335009098, 0.9332326811648185, 9.57765329268671, 31.28256128680322, 76.10694085398029, 64.8402306341356, 22.189936522514593, 48.90278162494783, 74.34106626818257, 17.78861161201231, 0.6101838222915127, 0.24259278821128033, 0.22996143858519294, 0.11251777725955171, 0.04019216326395831, 0.07538774786817451, 0.14751956077112308, 0.16842092147036908, 0.023233420440867063, 0.02199917044039936, 0.024190685606651732, 0.009505685039555595, 0.030470373439452345, 0.03256023448381213, 0.027456131553457632, 0.016207660646027616, 0.061064535196149544, 0.06954474164353264, 0.060140261606824015, 0.0966544252549929, 0.043242081864586765, 0.06777541561713142, 0.017195306943669435, 0.0774528757638989, 0.023063429360908848, 0.02595535956413275, 0.024805637790010344, 0.12004394760175098, 0.18999588795967642, 0.21052869908030958, 0.14884834027578756, 0.20178736007261663, 0.13110513107911234, 0.1998663179936909, 0.08952425342173347, 0.24179720590191506, 0.11103316781020935, 0.2192300482983551, 0.08839006791071546, 0.11533256049358076, 0.20762049142391453, 0.1692710645617016, 0.16839208592089916, 0.09014854613210886, 0.13326951332630652, 0.1091851415713468, 0.23811020858345494, 0.2405219452996408, 0.11544981025039189, 0.19376931531775385, 0.24591074565485602, 0.10243180838804092, 0.1135935255837056, 0.12169639925442396, 0.246232318721952, 0.1453525278597109, 0.23743943731871345, 0.28100684225078554, 0.4222118007319589, 0.9675502945338527, 10.077247542719688, 108.74310816487959, 88.82579880376016, 64.45081772342806, 65.57408255915489, 118.17570240266862, 43.456931498742875, 3.283270943549372, 1.799771708826865, 5.021637457032358, 3.147647640397472, 8.385956825748567, 18.21498893922375, 8.709210138167105, 0.8664029091596605, 0.6638799054968743, 0.36094477700610317, 76.7171282922068, 119.3263061584965, 97.8922946991459, 94.60356773868685, 95.60190508442541, 96.91161586392312, 94.78886050562706, 91.74112396855509, 88.08030528406944, 88.25085778390208, 91.41853255610313, 86.99635044220956, 88.4625873258037, 85.3937013687626, 86.09874740723642, 85.25288043483611, 81.15310930436658, 80.43918301982265, 78.14102711216097, 77.22728744629892, 78.21764669110699, 77.17777928998395, 79.97027935520296, 83.4262954035113, 75.86374605855634, 63.22442200876052, 65.03751800906274, 61.72503325246996, 59.94628937013688, 60.55850859611266, 65.30474908890264, 66.96037369389688, 72.62288770368023, 73.8250784720144, 75.30324720567273, 69.89078429437453, 82.39045235418504, 76.9491364878993, 89.77666762567337, 38.76103070474441, 43.46710220459969, 83.17857419290851, 73.88761674204181, 83.69999839413552, 70.24367209403746, 78.88795621933477, 75.00250339508057, 80.94771831266343, 74.77470782495315, 73.12328015604328, 57.79503799253895, 62.759224983953665, 55.546990363828606, 60.04281497770741, 58.24181164464643, 60.57451971115605, 56.86513031682661, 60.33205447658416, 62.60100833831295, 64.36826752078149, 58.405754950738725, 63.15727103141047, 62.419241782157656, 74.5567338697372, 71.63843554835167, 77.53827648778116, 70.28379794090026, 74.59125072725358, 76.349288417447, 84.82141971588135, 74.58461407692202, 78.23680354702857, 81.10098884951684, 82.83036185849099, 77.51542475915726, 73.69578146165418, 74.4798711038405, 81.67755373062627, 75.82814662687241, 81.89418623524328, 75.28620842964419, 100.44327874337473, 23.727142810821537, 0.4697644103678965, 0.24385666474699977, 7.331007421016694, 13.467757067372723, 2.587706989819004, 1.2343565326544548, 0.7774427569200917, 1.0769351475661801, 7.920777941903761, 39.26750283087454, 93.81208050635554, 51.297070903162805, 42.79175243070049, 68.30836680627638, 87.12968749384727, 27.483730085434456, 1.1312799540258225, 0.34085081169201487, 0.42164397636248224, 0.2727383327099585, 0.19943030671246592, 0.2011952966812157, 0.20079542942825826, 0.3044132185318778, 0.24080947341938175, 0.20739921458786537, 0.0831506853442519, 0.15752181921514774, 0.16852207571989106, 0.1565390050170883, 0.1961359907422335, 0.11630982055418915, 0.20199484732602874, 0.17391891999831124, 0.15173917305805992, 0.278266882824321, 0.1547449037072159, 0.14998777348908687, 0.11506215443894749, 0.1634235767227027, 0.137019973368414, 0.08140110906453864, 0.07770008467618497], [0.03223668107943189, 0.030150610255077485, 0.05605805101954649, 0.005954403548516454, 0.1148367407281072, 0.06772437117873661, 0.02924639093238981, 0.11248506530518494, 0.03882355484811049, 0.06455847452725134, 0.029250556535478082, 0.0280235767094118, 0.005887729958856419, 0.05311445776192893, 0.07135772702073859, 0.057135775850545016, 0.06396428907230016, 0.041643643241015174, 0.05004459789263145, 0.03696156665682793, 0.01674202037975192, 0.025041020219965328, 0.019535672993609504, 0.026338616115671974, 0.03321095339713558, 0.059836270257590286, 0.056625672375723246, 0.05506958309260588, 0.010750875733191929, 0.13756804799120273, 0.1535300414768919, 0.2743886699599605, 0.44033434602522087, 0.5038776314787327, 29.71348966321638, 80.96243504554995, 73.55139117087089, 26.99090780750398, 53.160306561377745, 94.90934002783992, 16.81420268550996, 1.5138450192828334, 1.655713103471264, 0.792837017966855, 0.4735341758256959, 1.6875496338452063, 2.9618167732992484, 4.851144283048568, 0.06018350727014965, 0.09331147802332718, 1.9918102170190506, 42.825527960254306, 83.20978056999945, 91.46589909830402, 85.09087870197912, 86.34997521677326, 92.82755774836387, 89.30974868036087, 87.76440543513145, 83.6677251323577, 82.47831344604492, 84.44461330290764, 86.0810104493172, 89.74496702994071, 85.17300528864708, 78.54413693951022, 82.36632977762531, 70.31093289775234, 71.31623637291693, 55.90578133060087, 68.84258577900549, 75.20975359024541, 75.6950919858871, 76.55289080835159, 65.65387925794049, 56.4889044146384, 59.61305264503726, 53.414735024975194, 55.768168895475334, 48.967288924801736, 56.43139070080173, 57.35226123563705, 66.25564928977721, 63.17334098200645, 73.41324529340191, 62.838754961567545, 75.05743226697369, 60.02113211539484, 89.02921292089647, 32.909466297395774, 34.46378000320927, 81.6985462557885, 68.62864402032667, 77.22494971367621, 66.03532191245787, 73.44067050564674, 71.02375307390767, 70.74699063454905, 66.31343364715576, 59.171707553248254, 51.82568480891567, 53.66380160854709, 51.86112734579271, 54.18889322588521, 52.47646093368531, 55.98478571061165, 53.358915775052964, 57.41355611431984, 54.7189897875632, 54.888655831736905, 56.15447136663622, 55.74989849521268, 53.78805837323589, 54.69825221646217, 56.25000853692332, 61.751434726099816, 63.006212711334236, 67.19697890743133, 70.38707394753733, 70.66436982923939, 70.57277464097547, 80.0599604268228, 76.96721861439367, 74.05901647383168, 69.59748514236944, 70.39662884127709, 72.13018309685492, 74.95984369708647, 72.4193480706984, 74.71166749154368, 84.30425520866149, 23.996027169689057, 0.3992176716846805, 1.3723395091872062, 25.835716839759584, 25.975770950317386, 2.047630570107891, 0.36573445063925564, 0.17685590191714226, 0.1871363881735071, 11.73759566199395, 33.20280075073242, 82.57309359888878, 42.83622034134404, 21.15922001100356, 62.230975858626834, 61.468161152255156, 34.19920044560587, 0.22707307260603676, 0.10362004906299616, 0.06266679276802367, 0.18394187813804996, 0.027805764506000186, 0.05583808419384784, 0.02296105320114763, 0.024264011712324236, 0.02912998387229539, 0.02585016994646961, 0.021732705908136505, 0.015447991580942707, 0.02870921774076358, 0.03142068252688454, 0.06927656490475902, 0.019778656930993163, 0.015066226985636018, 0.015819818100651667, 0.010157300275750458, 0.049766527128315745, 0.039232308720989574, 0.04644828623220806, 0.05798901010665202, 0.03966445891907619, 0.05447315300003656, 0.08785174558720282, 0.1139941359419496, 0.01248080760330683, 0.02153863476949834, 0.024943554683798747, 0.052528963574478706, 0.029397863751998352, 0.09236859232788125, 0.0355528497077044, 0.03268162111541437, 0.03363488347179467, 0.023884556872109254, 0.06275498864030646, 0.033542309407024615, 0.04171113558714429, 0.08605977400175988, 0.07072104666862758, 0.04378785056272342, 0.015173062734726458, 0.049832782242447145, 0.024773655534391443, 0.03024286256291934, 0.017383190007099224, 0.05189435165976325, 0.07017185355746938, 0.025017740723166256, 0.010183161488854358, 0.044585298296184316, 0.06265475752673323, 0.02533975429081869, 0.13176534565225725, 0.03149611345912901, 0.14710018891961346, 0.12652460711016772, 0.16505079343914986, 0.2838422255890985, 0.41509711153564915, 34.70938705628918, 97.1122843219388, 69.46384214585828, 28.3810212919789, 95.9286855882214, 92.29477436311784, 28.024134635925297, 2.4717921258941775, 1.9521730729649145, 1.1687811223729965, 0.14497024998549493, 0.7796262913653929, 1.5924075197788978, 5.067962119656225, 0.09902857769761356, 0.10707469957490122, 3.2850490029781096, 54.61585498625233, 90.85124800282141, 98.97207613914244, 89.74000130930256, 91.70353981756395, 94.9747024043914, 93.28457663136145, 89.4352331469136, 88.06549441429877, 85.77610892634239, 86.6245803525371, 91.50243205408897, 89.80981949836978, 88.95481340346798, 77.51519726168725, 82.78748250776722, 74.87570101214995, 71.33459306532338, 64.30450547126033, 72.10512699619417, 74.82125066941785, 79.6868645760321, 78.47893930250599, 69.1604232788086, 59.66127034156554, 61.161624000918486, 53.58064343852382, 57.62588577885782, 52.68751975028746, 60.818400921360144, 62.50126246483096, 70.84353585397044, 66.3614748370263, 76.0905610361407, 65.2451604412448, 77.02990593448763, 62.56899003059634, 88.5079691486974, 34.06841685695033, 37.815308032497285, 83.78707501196092, 68.49827228053924, 79.9762805815666, 70.34081351372504, 77.44010740710844, 73.83024815590151, 74.43329688041442, 69.29668641859486, 61.79424739653065, 55.722422292155606, 55.74915716725012, 55.45851738222184, 55.09734161438481, 54.774216759589414, 57.555706731734745, 55.5613148596979, 61.198141267222745, 59.27301453005884, 60.02494858157251, 60.480841744330625, 59.85131702115459, 58.78348704307311, 62.04879745360344, 60.72814718369515, 64.08746504014539, 67.46100148847027, 72.88610227646367, 76.65212677371117, 71.67584711505522, 68.11695514186736, 74.4335400673651, 76.76285528367566, 76.54237101154943, 72.34042213809106, 73.94987260141681, 74.93036316287133, 78.59378630115141, 75.64779604634931, 80.29418083929247, 91.63032485592751, 27.647153677478915, 0.3434849284108608, 1.9378103339864363, 33.58927580618089, 23.352332884265532, 1.5339421408791698, 0.41520853136335656, 0.19186482073799258, 0.24128283914779466, 19.456599527789702, 43.19521134899509, 79.39703279925932, 78.30309160294073, 18.43186070842128, 49.12204211758029, 69.60398843211513, 41.631401584994414, 0.18436811413736115, 0.04705548369055314, 0.08207790944124423, 0.1480493258925215, 0.014621602960922306, 0.05203344258329561, 0.031764263384825284, 0.012125491235976019, 0.032028393264138894, 0.0641826241307201, 0.05014525035456304, 0.01426173794654108, 0.011899523069000533, 0.0026315041196217103, 0.037194522503282756, 0.0873308441030883, 0.023673698831830296, 0.00195971000780006, 0.04006431085027514, 0.051836132807957555, 0.04144374025805343, 0.0844787140827506, 0.014191862109357552, 0.03853418045647202, 0.04111483189908247, 0.05456525592073318, 0.06569213143760158, 0.047725707202428774, 0.1288984454567394, 0.10141265097885363, 0.17751965581649737, 0.1318400239031161, 0.2262754525027929, 0.23239027438384874, 0.18057988596058663, 0.16136555812291561, 0.11243444221514849, 0.13927329842361713, 0.20348735514187044, 0.1111162040803221, 0.11027022850729766, 0.11940719830172679, 0.18260335399498864, 0.16211466953879403, 0.17154999227533418, 0.15226748261240222, 0.13921617890798277, 0.1139539776129588, 0.11508788733232407, 0.16779075286561446, 0.1049839536989889, 0.08532743225054396, 0.12544420097143422, 0.14475427447788178, 0.1419140188203704, 0.20673092544799854, 0.2040386166904242, 0.24514346263341366, 0.2508882180817666, 0.4243756313958476, 0.6570214573894778, 0.8283162657772342, 52.510165860576016, 108.7043551475771, 96.07651187527566, 47.80992692516696, 72.62204831646335, 117.19889102443572, 32.39614571294477, 1.87803978641187, 2.8269884855516496, 4.263818869667669, 2.4955906166184336, 5.201907628966916, 10.713239273717328, 13.53378918863112, 0.23776629639248695, 0.3942288151912151, 2.760632278457765, 47.497749405522505, 89.16102024816698, 97.86716799582206, 93.19356979862337, 93.67881405738093, 97.05344092461371, 95.9794959714336, 93.60303386565178, 93.52141718710624, 90.6754473716982, 91.16470813751222, 94.93594154234856, 94.41488604391776, 93.23734344974642, 82.43770907002111, 89.32845054134246, 83.10986211222988, 81.7916319447179, 74.2271214146768, 77.7817693833382, 77.31687438103461, 84.03793411870157, 81.49961148538898, 73.31808859302153, 63.58933971774194, 66.95337618550947, 58.63810439263621, 62.07284942750008, 56.169211633743785, 65.43342244240546, 65.140456691865, 74.33265670653313, 70.26007544609809, 81.28191994082543, 68.18525929604807, 80.1600593136203, 66.64416790008545, 89.89411123337285, 37.29869265710154, 44.302822005364206, 85.09182007082048, 73.8611956565611, 81.52706023185485, 73.12411954326015, 79.95542926173057, 78.36217034247615, 76.83079857980051, 72.89320961121591, 64.69212585879912, 59.49479318434193, 58.916545606428585, 60.272661947434955, 58.95759713265204, 58.64166590475268, 61.90355600849275, 59.99952770048573, 66.05442385519704, 64.68828193603024, 63.657137886170425, 65.9380235979634, 65.13263940811157, 65.56784206821074, 66.2696050828503, 64.85326859258836, 69.01195372304609, 74.69047884787284, 78.6524571141889, 84.11478119511759, 75.1604337076987, 72.97415948683216, 80.00816945106753, 82.53611349290418, 79.19453651674333, 76.5314511329897, 77.717528804656, 79.0008028091923, 83.03947910185784, 82.39867364206623, 84.73180140218427, 94.28273354807209, 30.460454071721724, 0.6114062534705286, 2.130278464286558, 30.197608201734482, 34.20777866917272, 7.802535151281665, 1.4412045623025587, 0.4761758921367507, 0.3781303661244531, 17.211376005603423, 54.90176439285279, 100.69845245730494, 62.11467758301766, 32.65091542274722, 84.12989800976169, 76.85568994091403, 59.56719229298254, 0.27140503328654075, 0.15109915256259904, 0.21464937877270485, 0.24135842138240415, 0.09287073231873014, 0.21160512922271607, 0.13852853838714863, 0.11763327574777989, 0.11758372518083743, 0.19491207335264454, 0.13878605118201626, 0.11104886495177785, 0.1271936929814758, 0.19770588876018602, 0.16597310201294962, 0.16941925660977442, 0.11254667409605558, 0.08978897510396858, 0.10378744693533068, 0.2377573178420144, 0.1257306259245642, 0.1969524259648977, 0.1358888139046969, 0.19841632805764678, 0.13719709289650764, 0.17607449223437618, 0.14903935663882764, 0.1517745356766447], [0.004056118590186441, 0.051961660144790534, 0.06732225928816103, 0.02352233326453115, 0.04388038632309726, 0.08578212841624215, 0.029817406058071122, 0.016861579891654755, 0.018630808241845622, 0.04686267468177023, 0.13949613807903183, 0.10892676309712472, 0.024341670045208548, 0.008450658436143592, 0.023632718873540723, 0.08368919152886638, 0.04451716626663843, 0.06589519070281137, 0.046507301815455, 0.07582234954761882, 0.016640065568349054, 0.023264749606530515, 0.0482967414803082, 0.05148283987035675, 0.03357188806178109, 0.030411055251475305, 0.026149710324863275, 0.02951808976039531, 0.05226313106475338, 0.056726658085901896, 0.0605137562829881, 0.05336032985078712, 0.29108316607532964, 0.05302160024462689, 0.32771353760073263, 57.880502516223544, 73.88768734470491, 68.6791249244444, 18.00871737541691, 65.98985379742038, 99.88925180127545, 19.82535331479965, 3.4880216083218976, 0.5813370572943842, 0.20733330038286027, 0.46351558438712553, 0.3033249446701619, 4.772731690637527, 2.4055518738685118, 0.25504669655234585, 0.15203505153617553, 0.3182254160844511, 13.661767302020905, 32.75251461613563, 43.488330071972264, 57.56268855064147, 78.41184323833835, 90.56710366279849, 83.73614695764358, 85.64317195646225, 93.1841874891712, 90.44692224071872, 88.83124305355935, 79.70054580319314, 81.44696543293615, 78.14074470150855, 68.7046830884872, 67.57268705675679, 75.50822242613762, 66.18503093719482, 67.02379057484289, 76.91416463544293, 80.5187443763979, 69.62636163157802, 62.20316233173494, 56.90891573506018, 67.91522764390515, 64.81905767994543, 64.12303309286794, 57.718747892687404, 57.20283069918233, 51.808716635550226, 58.198575358236994, 56.52345265111616, 61.85432241808984, 62.30161382306007, 73.96681724056121, 69.32535109981414, 80.32556764541134, 40.24070955091908, 53.08676212064682, 73.6139137514176, 72.1766710281372, 74.43343024100028, 68.84208371562343, 71.48458450071274, 67.48867773240613, 72.91027976620582, 64.19901724784606, 56.49067732595629, 53.27745991368448, 53.2090380883986, 54.385843276977546, 54.13399965532365, 54.13221497689524, 56.59023492567001, 57.00419795128607, 56.45765881384573, 56.24755313319545, 59.2855582698699, 56.86962143067391, 56.246266595778934, 58.450732769504675, 59.688879905208466, 60.38583801638696, 60.158277788469874, 60.34127596885928, 66.90350717113864, 80.21392130082654, 73.41849342469247, 77.16525908439391, 77.63642203423285, 70.09392384559878, 74.156448148912, 75.39379119873047, 75.8039612923899, 71.94025408837103, 64.80215226450275, 75.1396216115644, 73.84310568532636, 12.20518337142083, 0.39309825327607895, 2.4818069175366433, 9.335395943733955, 12.76543805676122, 1.301447939007513, 0.8406815377454605, 0.33825432521200954, 0.1382272206847706, 19.25035738175915, 35.03332776408042, 81.28388112591159, 43.74602979229343, 10.55201122837682, 48.92573141282605, 54.77544446145335, 57.00542957552018, 1.1271891670842324, 0.08000714313839713, 0.11682623276306738, 0.0750333785770401, 0.07216393496961364, 0.03874424559574935, 0.04450084476341163, 0.030017234347460252, 0.012350928887063939, 0.04826641972026518, 0.023006256219119798, 0.0701421293460073, 0.05127550583452948, 0.020891512638979384, 0.03446897702111352, 0.02908958614082827, 0.03233893849556485, 0.09601175409531403, 0.020033808259834206, 0.07936976564627501, 0.04479385807269043, 0.04876482886292281, 0.02629462351662017, 0.025150222223131888, 0.08244036862085904, 0.04457053961232305, 0.029274029469478036, 0.08366666854389253, 0.01298728939746657, 0.019747145819447694, 0.007704380587975105, 0.06449129627717119, 0.03874199329725197, 0.016442773029989293, 0.02874101230484103, 0.03636345117082519, 0.06061596390340598, 0.029620260991636786, 0.013978694313986888, 0.07589747979035301, 0.06399591318181445, 0.00978491738468649, 0.017127295572971626, 0.033704923060272014, 0.046791926461962924, 0.026991261740125, 0.032930274103437705, 0.08080781227157963, 0.04210437234911708, 0.05973999598814596, 0.012812666358396172, 0.05081292279365082, 0.01577160531474698, 0.028019213838683023, 0.021607226451798793, 0.028069670304595947, 0.00998161907773465, 0.005319717897838283, 0.027388671766065305, 0.0030017395704729304, 0.09128815554563077, 0.13424134182353176, 0.07160769384955207, 0.1050768954859626, 69.15052321649367, 86.91356489735266, 52.119517403264204, 25.182565719850604, 113.7198349737352, 92.93616817843531, 29.658943222415065, 5.480322366760624, 0.6266580221633757, 0.2790926336761444, 0.3577045315215665, 0.408294832994861, 1.2055502783867622, 1.213656101495989, 0.28278309371202226, 0.09964401443158427, 0.4633472901919196, 18.55674897470782, 39.19031058588336, 52.75429810247114, 68.10520372083111, 84.83706997286889, 91.63100734833749, 89.11190432886924, 92.20809782705, 95.16597286347421, 91.07113607468145, 87.15339429916875, 82.99885119161299, 78.84589272160684, 80.93645326552853, 72.50490280889696, 74.26303463597452, 79.03497449813351, 73.04110650093325, 71.82212798826157, 79.49634721202236, 82.29453471399124, 74.91388136340727, 64.84691827527939, 58.586795868412146, 68.68669509887695, 68.40494340465915, 65.24454070675758, 59.28616623724661, 58.1478238105774, 56.67869614016626, 62.55657572900096, 62.487538091598026, 69.30274255814092, 68.71590106718003, 80.45994804751489, 73.45787402122252, 85.33506977942683, 43.10161182957311, 53.279377952698745, 81.00198822636759, 74.3598073528659, 80.99289617230816, 71.82863127800726, 76.19693571521391, 72.77812727036016, 75.60890182372063, 67.86257374671199, 59.32715892791749, 55.01647410854217, 57.92344462487006, 56.127587441475164, 57.74274495340163, 56.24306594171832, 62.34021779029601, 61.20782952154837, 61.71228162703976, 60.01776279941682, 62.49885020717498, 62.18985765211044, 60.61914451660649, 61.793831625292384, 64.0621029946112, 65.01942411545785, 66.45744739040252, 66.57189430729036, 68.44157049732824, 79.2893558932889, 76.35508568056169, 82.06309133960356, 84.92618622318392, 72.26783475568219, 76.2876993610013, 79.48643146022674, 79.2640095372354, 77.2186896108812, 72.19366273572369, 80.51049170955535, 81.29180431365967, 14.561594320881753, 0.47611549376480045, 4.532916997709583, 10.173570167633796, 13.570013257765002, 0.5637827347363196, 0.7607832250575867, 0.3285689207334673, 0.3033156903280366, 34.43513885621102, 41.42124883590206, 79.6230633028092, 85.90890469089632, 9.912064767652943, 34.67401119970506, 62.454684319034705, 66.43980456936744, 1.6803475493384947, 0.09771590136111745, 0.1828985276722139, 0.11213238906836319, 0.03533765944021364, 0.038629129393807346, 0.058096327533524846, 0.017842542072157228, 0.019092655838316968, 0.06938073754070267, 0.04087695776815376, 0.07564113144913027, 0.014192950911819937, 0.01487133326008916, 0.06669698598524255, 0.05363928544665537, 0.03780456597826654, 0.04463938793407814, 0.010163376310599909, 0.1350357750010106, 0.03360872923005973, 0.04814363497820112, 0.026484419884640845, 0.023220312676482627, 0.048198211081926866, 0.07093157529109909, 0.0371809282730664, 0.08798212609103612, 0.044803372884709994, 0.0734557890363278, 0.16584044622798122, 0.135912669882659, 0.09917509967401143, 0.13261867566935479, 0.14665458621757646, 0.1362705401956074, 0.18453528984419762, 0.15218039373717002, 0.13488995782550306, 0.2598916204465974, 0.25135566961140404, 0.1444658423743902, 0.06547377339654392, 0.10524057783186437, 0.1957583553608387, 0.13780639326620486, 0.17281380752401967, 0.1159444732230998, 0.14036236901677426, 0.13502455947379913, 0.13256141825789405, 0.17967559577476594, 0.12307718846826785, 0.16514748905695256, 0.13441006502797528, 0.07334603928029537, 0.22085099841558167, 0.17328550318075767, 0.14701075581533296, 0.1482077528752627, 0.17173055919908708, 0.4316559181578698, 0.15703576707070874, 0.3688698340087168, 93.25626496345767, 95.17164461074337, 95.30748413455103, 31.23488879972889, 85.93942857557728, 118.92159600411694, 37.96009840503816, 4.669606695252081, 0.7522490055811021, 0.44722230383946054, 1.3979356711910618, 1.1179828739935354, 9.981753518504481, 6.26679975178934, 0.5582869425415993, 0.4382620169030082, 0.8116592466831208, 16.504058914799845, 37.36501209197506, 48.89187743586879, 67.36176552311068, 85.686278804656, 93.3869504928589, 90.36143026044293, 91.20049584296443, 98.26784595366448, 95.28791935213151, 91.73297328333702, 83.94131829661708, 78.44084524339246, 84.64296756252166, 79.13443011622276, 83.55539629536291, 81.5461072614116, 81.09394427268737, 79.88065319676554, 85.70498851037796, 88.50411738118818, 81.41998737089096, 70.25595695741715, 66.76163504200598, 75.24156401234289, 75.8570780292634, 73.50730373013404, 68.20462795995897, 65.8439730059716, 60.147557950788936, 65.56709289550781, 67.2019838517712, 71.84149665217247, 73.06151851530998, 85.08608556562855, 80.03991711524226, 86.70277672429239, 50.31073208778135, 65.58022106847456, 83.43408523067352, 78.44972548946258, 85.78167869198708, 79.24097737958355, 80.01601419141217, 74.7588457599763, 80.4512482304727, 72.25494584729596, 63.42036793308874, 59.85796543859667, 60.49009461556712, 61.56975446208831, 63.150038180812714, 63.3263094963566, 66.63921786892799, 65.48752761656239, 65.39820740299841, 64.25252622173679, 72.85768078219506, 68.84509609591576, 67.8663392220774, 66.52972098319762, 71.84509738799065, 70.91244405315769, 74.60519867558634, 72.68421003895422, 76.62863177637901, 84.59681695507419, 83.9056404175297, 89.87631151753088, 90.235804588564, 76.88907715582079, 84.04164468088459, 85.24174090354674, 83.797775237791, 80.42022228240967, 78.62394148303618, 84.66509757503387, 82.92872705767232, 16.760666255028017, 0.6434507307506377, 6.810068613098514, 13.090475067015618, 17.753557389782323, 3.1057675134751106, 2.64366205180845, 0.7291110665086777, 0.2337741202885105, 28.292514970225675, 54.506240429416785, 94.06089213586624, 60.54973425403718, 19.098594996236987, 74.06555114253875, 69.71230076205346, 85.75098222301853, 3.4916010162522717, 0.38290260359644895, 0.29424778335998136, 0.3002751180000844, 0.10481095572392787, 0.22580386409836434, 0.12495021981697892, 0.1676740163877126, 0.06246593217515658, 0.1367999835600776, 0.12126841657464543, 0.2621159720565042, 0.07943247760375662, 0.10410025595657288, 0.09743835536702987, 0.1761302481135053, 0.07409589380146035, 0.16876294908504333, 0.1036726946251527, 0.3439884626817319, 0.1757878527766274, 0.15114110353733265, 0.11313492236959358, 0.12959907882876937, 0.15380630810414592, 0.1383790746331215, 0.15906180916053636, 0.19086348253392404, 0.11723120982247977], [0.03493763896967134, 0.0806061243037543, 0.025652590125138243, 0.018254592038330533, 0.10357838154079453, 0.06660103347272643, 0.017420647876156915, 0.07220023987634529, 0.04003807616930816, 0.03330366152729238, 0.03654197647025989, 0.024373914685941512, 0.09584968819493249, 0.0801379296688303, 0.06866976198169493, 0.030646447257529345, 0.036523356703260255, 0.056914740332191995, 0.06244083896519677, 0.10761163527927092, 0.034745055956826094, 0.032359197690722444, 0.0711380742910889, 0.08535079027135527, 0.025234717890740405, 0.03561809741621537, 0.016938935619808974, 0.10086668309785667, 0.029188398076521776, 0.06486323196440935, 0.03328684589735443, 0.03661603035946046, 0.049183024769468654, 0.11122559377503012, 0.1845504277415814, 2.958979919072121, 72.55938453059044, 77.91254904962356, 72.55627016867362, 16.93920862290167, 56.576251676005704, 110.47038662818171, 38.894854130283484, 9.022145655847366, 0.023722255399691004, 0.20346274839774256, 0.5625123770967607, 0.33906058678703926, 1.2070451917186862, 0.4514051439060319, 0.2266017753150194, 0.15500388739089813, 0.16178445499991218, 2.6821407483470057, 7.1231276854392025, 7.603182158162517, 21.08087262799663, 54.57955737267771, 89.03737145085489, 83.58298624715498, 74.20699181095247, 76.97234907457906, 85.04598325298679, 88.38792893194383, 90.42560808120236, 71.31199236839049, 72.63296819502308, 81.35072615838821, 79.51504122826361, 77.80173424751528, 80.81055302773753, 74.96589199189218, 79.89948057359265, 65.03319947950303, 68.29320292319021, 70.54625157387026, 74.40794267962056, 72.25582445821455, 71.14275778493574, 66.74651822736188, 65.27175018864294, 59.60563152067123, 58.95051725449101, 55.858877628080315, 60.44589342609529, 63.775334588943, 69.15199802767846, 64.20423007780506, 78.79454105131089, 47.48520958808161, 29.987339742722053, 66.27876773957284, 77.73727401610344, 73.4913553730134, 72.22163707979264, 75.66736082876884, 73.3713073115195, 72.80214786529541, 64.04666062324279, 53.226716210765225, 54.26978034357871, 58.04210416732296, 56.80080344600063, 59.4186560569271, 61.30795194256691, 62.39311879681003, 61.41351469101445, 60.96534859749579, 58.87943998459847, 59.406928170111875, 57.53836593320293, 61.28819496400895, 58.96876019816245, 62.79711900218841, 62.74628900712537, 62.89670405849334, 66.30358849802326, 68.1874793575656, 68.46213940651187, 69.78152275085449, 75.7963675837363, 77.09139300930885, 78.4241202569777, 78.30935170573574, 74.42666023008286, 79.69440337150328, 70.51512364418276, 76.97995847271335, 49.29564229903683, 3.064625527589552, 1.1178371334268202, 2.4961083694811794, 6.216383566779475, 0.3470465324578747, 1.4687489165413765, 0.29891080733749176, 0.7088519019945976, 1.9608505815267565, 27.717164062684585, 30.618998235271825, 83.62029583223405, 40.22918562735281, 9.557320706305966, 53.54945275091357, 57.14743114286854, 65.85534003473097, 7.2027434649006015, 0.5187282458909097, 0.10312529415973734, 0.10237494934230082, 0.09548250991370409, 0.04673029851889418, 0.0276185613456032, 0.042191039875990925, 0.08693054784089328, 0.040894003224469004, 0.011533841532054208, 0.10701976340985107, 0.0342002640207929, 0.039024652928234115, 0.022843428061253602, 0.04684140425055258, 0.03447132508060144, 0.019851360590227192, 0.00699250152402167, 0.05805384412768388, 0.04809124222505958, 0.04804449553991999, 0.10404607821856776, 0.05885572367978673, 0.028840626717635223, 0.03325903307526343, 0.013928248381782925, 0.11672745338611065, 0.08568464372787746, 0.02042284494476213, 0.05415389351847191, 0.03335468681348908, 0.08712283590988767, 0.04416534038741262, 0.01550132949506083, 0.030997392135642232, 0.048455980516249136, 0.08434228914519472, 0.022031033952389995, 0.04736612085253001, 0.03714260472465427, 0.02311276733845232, 0.03024888018356456, 0.08486938828061666, 0.05821831171370803, 0.047752964610774676, 0.157799955096937, 0.03641886614082802, 0.04454457689256919, 0.01978417276404798, 0.010067906433476076, 0.013976761857197892, 0.05990451720032481, 0.029056891423439788, 0.012066383722178158, 0.016296643673652605, 0.04879317794656081, 0.07368815116464131, 0.12116504067014303, 0.05222848090793818, 0.012694003169364747, 0.023960332543919646, 0.0797750644626156, 0.07185267344597848, 0.19146476962393333, 4.824833514228945, 89.69538042622229, 81.80693703313028, 45.330290794372566, 23.809700858208444, 106.63205715917773, 113.35878864411386, 46.9686177469069, 13.120885202961585, 0.057488808318251566, 0.1412648665568521, 0.8468744699512759, 0.33122464113177796, 0.45006819790409464, 0.4732510910159158, 0.9263297999578138, 0.11866043111489666, 0.19022491760551932, 3.9042542153789155, 9.555239888929552, 10.41230130580164, 29.22957116557706, 69.26374635388775, 93.29728511071976, 80.46811442221366, 76.60443075241582, 82.63931889687815, 90.49520661753994, 87.12714579797561, 92.56876760913481, 73.90379259663244, 75.87641531421293, 79.04148563261955, 79.10512216629522, 79.80138994032338, 80.65699223549136, 77.95840155693793, 82.0289667191044, 69.17784644711402, 69.04025754620953, 73.84665935270249, 78.48513664737825, 74.10835989059942, 75.47787112574424, 70.66947675520375, 67.2049177846601, 63.98679348730273, 62.29004675342191, 60.02556047131939, 64.87803836022654, 69.21613662473618, 73.27913945721042, 67.62639214915615, 82.07446621310326, 48.50809312635853, 41.91577342248733, 72.79266357421875, 79.68651940745693, 76.95600063570085, 75.4681436477169, 79.75095610464774, 79.10793058333859, 77.23893688571069, 66.8252323519799, 54.334719104151574, 59.7890886183708, 58.66357626453523, 59.240682432728434, 62.857331306703635, 63.604295715208984, 63.28011182046706, 64.5311164855957, 66.24119143332204, 65.35908568289973, 63.184511892257206, 63.1072098209012, 67.50053897980722, 65.07130530572707, 68.83697678965908, 67.97129400314824, 67.30988041047128, 69.87623230103524, 72.41664948001986, 78.09840663786858, 72.73117649939753, 74.07512957049956, 72.08105933281684, 73.12335075870638, 79.0414228746968, 75.73076202023414, 82.09862801336473, 74.42908425484934, 82.60557082391556, 58.05571086945073, 4.9938322651770815, 1.3063738230736026, 5.334769093221234, 9.954231227597884, 0.15611226339974713, 1.0566077092962882, 0.3908657504906578, 0.7863144228054632, 3.062491758215812, 49.133303242345015, 30.3152459667575, 81.1411774543024, 77.10382692275509, 8.687199757945153, 33.95490346416351, 59.31770209343203, 79.93831203829858, 9.85041295328448, 0.5507788518744131, 0.13724480485243185, 0.08710542273136877, 0.15625820314932257, 0.07509171617247405, 0.07797877214127973, 0.02953532482347181, 0.05573907882095345, 0.021939036368782965, 0.022741341099683798, 0.0453016173184639, 0.03998135118895481, 0.0350349206447361, 0.06354313223592697, 0.008392764214095811, 0.03775360580954341, 0.01942206215443871, 0.03841506144512565, 0.06620729492316324, 0.01294146201783611, 0.12579101663563522, 0.029376126007146897, 0.014955224675847398, 0.027765385926731175, 0.017712962130204808, 0.08540103797830882, 0.08048138220704372, 0.009481326316393191, 0.02932626325937529, 0.15814500109803292, 0.19738938719514879, 0.24004891664991457, 0.11923485916228065, 0.19862203798707456, 0.11916255578398706, 0.1575933105402416, 0.1773330674416596, 0.10254181095308836, 0.08359714606476408, 0.18571445237725012, 0.1887812861992467, 0.17988509017853968, 0.17448211719672527, 0.18828199605547613, 0.12715165773707052, 0.322394895577623, 0.17563967605031308, 0.14827294695761897, 0.18742187849936948, 0.13177343554073764, 0.129268312706582, 0.1297992116381084, 0.2042469926058285, 0.1644750936858116, 0.12995256711879086, 0.061562503838250716, 0.19703524006951242, 0.24973592991309784, 0.13107146917571946, 0.11202848456319302, 0.1729330261267962, 0.113813768201057, 0.24864279905394202, 0.4176208809498818, 7.5225803928990524, 116.04306267153834, 93.2329111714517, 104.85567846605855, 28.0339523284666, 71.95709674589096, 125.96894202693817, 61.82083714392878, 13.189450194758754, 0.13517751658876098, 0.4973038310004819, 1.4490301810926007, 1.539390067900381, 3.5362184672586383, 2.541938078018927, 1.4613249729717932, 0.4124910029913149, 0.24650601129378044, 4.205136779815921, 11.42235771302254, 9.617052520475081, 26.466022114599905, 64.64212348384243, 98.9546137471353, 87.5752922796434, 76.51798171381797, 83.40217282695156, 88.36656770398541, 92.985943055922, 95.5487883475519, 83.94775098369968, 81.73176873114802, 84.2022971184023, 86.80945734823905, 86.73775642148911, 85.6557470752347, 83.61002706712293, 87.78729638745709, 74.92404030215356, 76.85181463918379, 82.85756741800617, 84.97493343968546, 82.89333943397769, 80.25312931306901, 77.38924211071384, 72.3397788693828, 68.59132659050726, 67.74544392862629, 63.8912445499051, 69.53969294025053, 70.00521552178168, 77.47120395783456, 71.27944454070061, 86.73719160018429, 53.46629850326046, 40.01676967067104, 74.4995221784038, 84.3460206062563, 80.24278210055444, 78.72473855172434, 86.83337596154983, 83.10930513566541, 82.53372084709906, 69.70339698176231, 59.61953632293209, 62.7247198935478, 63.88275654085221, 64.70681121272426, 68.41841282383089, 68.12301912615376, 71.25278811300956, 70.60179233551025, 70.56990346600934, 70.50460384738061, 70.4572686841411, 67.90474707080473, 73.91989000381963, 69.41041161937099, 77.71747389147359, 76.91695736300561, 75.00334278229745, 79.00997331065517, 81.90993062911495, 82.8765203106788, 83.42898614944951, 80.51247642886254, 78.68717009021391, 77.00870944607642, 81.53777614716562, 81.37080084893012, 88.48154806321668, 82.55656473098263, 87.39429843041205, 59.49935490085233, 5.840740136561855, 1.252659660193228, 5.552769524435844, 13.412890953402366, 1.1681834512179898, 3.5828569194962903, 1.509762077081588, 1.1877446789895336, 3.2612711046972587, 40.04306131793607, 46.98072610362884, 96.19619123397335, 54.341402822925204, 15.30548849413472, 77.06206936990061, 73.76953771037441, 94.74012897860621, 16.842035824252715, 0.6695932053750562, 0.30180021519622496, 0.09327911846940556, 0.20410396399036532, 0.13208773077255295, 0.16118571132181153, 0.16018156923594015, 0.19517779861006046, 0.1390135333302521, 0.14155706781293118, 0.11893980039824402, 0.14757828907139842, 0.11863338055029032, 0.12297765832514533, 0.15179322822199715, 0.17505934912591212, 0.15749500613779793, 0.13739812968959733, 0.11413579326002829, 0.16885820445754837, 0.3394080229824589, 0.16720731562424093, 0.1459948619407031, 0.1955440192813835, 0.10706339211713885, 0.19102980022228536, 0.1615050627339271, 0.17849229636692232, 0.11888295667426241], [0.018683641495543624, 0.031841921717709595, 0.02508359938679684, 0.0593083399167705, 0.163758096675719, 0.09837105975396211, 0.04371896393657212, 0.008598879212513566, 0.061591906292784604, 0.0184043143470321, 0.043562812234966025, 0.05036631268599341, 0.0441833243014351, 0.06397623238303969, 0.029600156929283857, 0.05779263112814196, 0.06753723122059338, 0.02022143851424898, 0.0845646768087341, 0.06962356443006186, 0.05269077283540561, 0.05358360234587904, 0.007982683093887905, 0.06718619441192958, 0.07465998732274579, 0.041784607249522404, 0.03900213377369989, 0.023855250178565903, 0.0445026642222318, 0.06523439390284401, 0.03353053080518881, 0.029961087763489738, 0.06828876347431252, 0.25272422440109715, 0.1485362207336772, 0.65146352014234, 9.622617383157055, 85.59397758976107, 71.19563917959891, 82.54391116480674, 30.92257791949857, 35.16790428469258, 106.89930392849831, 63.976352137904016, 23.210064595745457, 3.462054046892351, 0.3869521750077125, 0.030394094064831737, 0.4506015483169787, 0.2705543692554197, 0.13293038152398604, 0.3146916057073301, 0.7659681694161508, 0.13469131122673714, 4.799441560622185, 2.3265428360431426, 0.059620057262720606, 0.6024984895221649, 20.852125883102417, 83.20068067119968, 89.86828634815832, 80.36237516710835, 76.30273772824195, 77.72186694606658, 67.95258429742628, 73.86778523845058, 83.22995724216585, 85.4718428273355, 84.08034278500466, 80.21254062652588, 83.89137083484282, 76.72947591350925, 78.419232983743, 72.45944253859982, 72.01102933576031, 72.03541078875142, 70.00967133429744, 71.82143765111124, 73.64573986299577, 72.18624161135766, 66.70865166571834, 62.84941988606607, 60.85185089418965, 55.339583273856874, 58.87831426435902, 59.66751475487987, 75.03789101877521, 71.13809800917103, 82.49914123165993, 44.75518503496724, 18.759404113215787, 74.33860301971436, 68.19152724358344, 77.41170944706087, 71.02207429947393, 73.06326789240684, 70.04993838648643, 71.0508958755001, 54.59661576055712, 53.08808395939489, 55.29376606787405, 59.899217005698915, 59.60183858871461, 61.337295193826, 64.95441867459205, 62.229104888054636, 62.36598383995795, 62.18345634398922, 61.03770848243468, 63.275173556420114, 60.91131402600197, 62.83161624785393, 63.754314607189556, 67.33624658276959, 70.63990208410448, 69.78392324139996, 63.11217161916918, 62.821712263168834, 69.7915247947939, 75.37952161604359, 74.7958258659609, 72.79081221549743, 66.67396222391437, 70.36985474248087, 80.75781283840057, 70.98547074102586, 67.70736555899343, 31.378412246704105, 1.2035314834886983, 0.5727805906245785, 14.866363463863252, 33.855518448737364, 0.2689488021837127, 0.2744598548498846, 0.05748740254691052, 0.3445309755061904, 8.541975963500239, 28.42420070402084, 23.97528175384768, 98.0921551489061, 32.95146311483076, 14.757171542413774, 61.334165142428496, 49.327111474929325, 59.56531740004017, 9.560824363462388, 0.4368595244182695, 0.09831571756231208, 0.04490980164959066, 0.06701434556875499, 0.023560601271568768, 0.04181115985697797, 0.038580501962813644, 0.09132888844056476, 0.02427491314348675, 0.06245501159179596, 0.05677502121656172, 0.0365752131948548, 0.024390113615100423, 0.025956282700081507, 0.06542964673210537, 0.029080287748647314, 0.014573988681208464, 0.06130715141132955, 0.07209137878230504, 0.05132321779045367, 0.050174499591512066, 0.013976647901619154, 0.00819786665810933, 0.05747452077846374, 0.024878709171448025, 0.019638554771400748, 0.08227002131001604, 0.048218581359833486, 0.09446675393490062, 0.034269215764417764, 0.07070348793340307, 0.032516004397503795, 0.020307881960404978, 0.0288595759024423, 0.054626971963913216, 0.012172852706674848, 0.03972304166264592, 0.01914247645125274, 0.06034518629612942, 0.05187376304679821, 0.05260774422617209, 0.021583186612734874, 0.016477306358396046, 0.03513503301468107, 0.049176758170248046, 0.030440668380188367, 0.017848643962474122, 0.04128898283646953, 0.0428438923441835, 0.038967280603584745, 0.06510953689294477, 0.026278924459831852, 0.013002270246825874, 0.06170069077803243, 0.038370858171894666, 0.0957150482422402, 0.06695715710520744, 0.04652925406492526, 0.09868816652845952, 0.03673784216986068, 0.09457681778698199, 0.06065634056745518, 0.02807421320598693, 0.20311915796370278, 0.06924149339958545, 0.7538975042200858, 16.501585860406202, 103.5290152026761, 74.28341527138987, 49.275697046710604, 25.845265849944084, 85.46812442041214, 120.71135782426404, 62.310631352086226, 31.031784549836193, 3.4928439173006245, 1.1496851857631438, 0.5085494501456138, 0.3835729918172283, 0.7133161721210326, 0.25321859626039384, 0.22183175949800402, 0.5063456603355947, 0.6278327720299844, 9.991290761578469, 5.573466891242612, 0.5204446505635015, 1.3414394446919042, 33.374478970804525, 98.92535286564981, 91.38853426902526, 81.97985079980667, 77.33683140047135, 78.06552148634388, 72.22541824463876, 75.78030155551049, 82.42149399172875, 82.81158155010593, 84.9107869978874, 79.77830286948912, 84.8977098157329, 78.13391977740874, 77.49618945583221, 71.73775780585505, 73.98314998995873, 74.79926186223184, 78.52146563991424, 79.65888238722279, 79.81091345510175, 76.02432789341097, 73.40575356637278, 68.5193040294032, 65.8152847905313, 59.31472893684142, 63.6109245208002, 65.77984225365424, 78.01031020379837, 77.0587275105138, 87.66207864207607, 49.05014899469192, 24.359115092985093, 76.73505352389428, 73.90685989010719, 80.32093140386766, 74.57263515841576, 76.82704094917544, 75.32805227464246, 76.2499818494243, 61.14913517428983, 56.993517337306855, 57.790217399597175, 63.89546894258069, 62.79300051350748, 63.537815463158395, 68.01290250593617, 66.94606488750827, 68.30871197485155, 67.65107170228036, 65.4580549270876, 65.91518755882018, 68.12130897275864, 66.70195225746401, 68.53899432766822, 68.67206465813422, 76.42250337908345, 76.8978318860454, 74.76937340151879, 67.82003171982305, 72.01575971418812, 81.18095028784968, 81.68754792982533, 81.1391378218128, 75.24650619876, 77.74028639639579, 89.67232473434942, 80.20843782732564, 75.63631134648477, 39.03956213305074, 1.6750187643112677, 1.0428202104183937, 18.422264629794707, 39.28982503952519, 0.3752056262906521, 0.4658418256909617, 0.09966647612952417, 0.25485647692074703, 15.365321309335771, 55.63136054623512, 19.532111037162043, 97.32704193361344, 70.91359722998835, 11.196137955111842, 36.73599727692143, 53.03100955101752, 71.90328182712679, 15.516302162601104, 0.5368207911810567, 0.09096000944414447, 0.09166233587048708, 0.15166270216145825, 0.10330387691576635, 0.01093190518252912, 0.05659669509998733, 0.00994693253174304, 0.03989415889185283, 0.014190811611291383, 0.06499466966957816, 0.04836205430629273, 0.019452184731621417, 0.02106194613471387, 0.02507420906406497, 0.031235243283933213, 0.03483005341202502, 0.052789092559607766, 0.0505236096890463, 0.07054574276891447, 0.03669076223647402, 0.00911871487680342, 0.025773810132616953, 0.05894038405629897, 0.016738007994248502, 0.0388360497421555, 0.04256155830056917, 0.027772025993814873, 0.025422961015494603, 0.020716597528887853, 0.1483991982475404, 0.15676264140394428, 0.09526248946185074, 0.13499555538498587, 0.3125126065025407, 0.21803940976819686, 0.1535768800925824, 0.09685136347768769, 0.14734699180529964, 0.20418688534728943, 0.29345512750648683, 0.15638865260106904, 0.06471811958979215, 0.11816426660985717, 0.11474205226066614, 0.13651833899559515, 0.26608179473588545, 0.17800610632665698, 0.19112995855750578, 0.18933352834034353, 0.13968926884474295, 0.09161081645757922, 0.11905230807080386, 0.177588174720445, 0.1691083628083429, 0.25111148674641887, 0.11488885002871675, 0.06751695287323768, 0.3509651028340863, 0.1548156902314194, 0.23740885508877618, 0.2408636205138699, 0.15362027131261366, 0.24436966786461495, 0.3185395121334061, 0.8220907901563953, 24.618754425356467, 126.7888350640574, 92.62842685945573, 114.7705202717935, 40.8864297405366, 55.092254300271314, 120.83207268868725, 90.96678533861714, 35.634030911230276, 4.61015974321673, 1.160845432069994, 0.5377634470501255, 0.8977865283527683, 1.3639983438676404, 0.786810725206329, 0.9370007918727015, 1.2208606374840583, 0.3715350538972886, 9.498306685878385, 5.2245803994517175, 0.2678447162672397, 0.9788616133793708, 27.714355645641206, 93.34513018208166, 99.20966194521998, 91.67241188787645, 85.813795058958, 85.01976613075503, 78.26458177258893, 78.09289178540631, 84.32788356657952, 89.64209894980155, 93.73925778173631, 84.29646538149926, 93.54288039668914, 87.88582632618566, 86.12640011695125, 82.66501826624717, 82.40340402049404, 80.13829015916394, 85.47494934451196, 85.89127755934193, 86.36892026470554, 84.84387920748803, 79.87869985641973, 74.86485958099365, 71.88254033365558, 65.87578342806908, 68.6623058011455, 71.45576292468657, 86.40431573314052, 83.92615441353091, 93.21387983137562, 55.91667375256939, 26.883529001666655, 83.77566091475948, 78.26700579735541, 87.58062670307775, 78.3545530996015, 81.2848852526757, 79.96288960979831, 80.7457790067119, 64.22322219417941, 61.64358915821199, 62.24733214224539, 69.34275073389854, 70.07562206637475, 70.38479112809705, 74.97092047045308, 71.68018525646579, 72.4863656874626, 73.54294238551971, 71.89387598345357, 71.66279346712174, 75.45612550550892, 76.80584446076425, 76.09846068966773, 77.29741158023958, 86.35148140691942, 87.6257182705787, 82.88053681773525, 75.13817817934098, 84.37344581850114, 91.00790746750371, 87.41846023067352, 84.19700976341002, 85.87905545388499, 86.25119424635365, 93.55725196100052, 86.12272877846995, 77.31592516745292, 40.74659332152336, 2.074997559670479, 0.6615378827817979, 26.366682206430745, 49.85727079453007, 0.7265493297769178, 0.9873597347928632, 0.7630415296842976, 0.42444081015644536, 13.431252548771521, 42.23515633613833, 36.71858979809669, 113.794218801683, 49.06821150933543, 22.43720862173265, 85.99578519021311, 63.10737848281861, 87.69042168894123, 25.497957621851278, 0.6252996563430756, 0.2583002413232481, 0.1906210157058893, 0.24533712966067178, 0.1397095395312194, 0.12114116170954321, 0.22443576896142578, 0.20516920924907733, 0.2207538278232659, 0.13686358417955138, 0.3552437345347097, 0.10260146621975208, 0.09816466800628171, 0.17682066187262538, 0.14779982637734185, 0.09928610581423968, 0.15469359113804756, 0.15547740633689588, 0.2242527965215906, 0.171732765532309, 0.12135765815694487, 0.12125531647114024, 0.148723284083028, 0.24907810553427667, 0.09553077345293376, 0.15421043480596236, 0.16327760632961028, 0.19412121014489284, 0.214895706683878, 0.1121886965307978], [0.02082576505809782, 0.11552005285216917, 0.07390454802061282, 0.05607160311492701, 0.022303717203378197, 0.06232258180276521, 0.02378149123321618, 0.020458077328399788, 0.006050007969831989, 0.07126277042252403, 0.05484361013758087, 0.042085170355294986, 0.02375351944788089, 0.04754383026832535, 0.04378946317780403, 0.007650980429213135, 0.03460333352127383, 0.050948754013065374, 0.04731988361586006, 0.040281316746146455, 0.013486120846092462, 0.01767957218802504, 0.0615303204845517, 0.025706017096977563, 0.10500797821629433, 0.024946557748461926, 0.024514798255216692, 0.012737293840355933, 0.05609455893957808, 0.04678271425467345, 0.016710151122101856, 0.04744141197372829, 0.0406705009029998, 0.06842997646139515, 0.12647113417305295, 0.12897908387164916, 0.13798110727821628, 9.166904649426861, 79.8157379704137, 76.90283683038528, 87.22617780008625, 28.21823508508744, 28.822699785232547, 98.25724770945888, 78.90217088883924, 33.22453460385723, 14.531865696753226, 0.2669720808344503, 0.4694144614040852, 0.1349122816276166, 0.17070239259591027, 0.24685928507918314, 0.10178536807577457, 2.4466404174604723, 3.5824328132214087, 15.863028899315866, 11.752074110892512, 1.6652258317316733, 0.6379540192504084, 0.5443856949287077, 13.868988079409446, 27.363762432529082, 62.405992015715576, 81.94863657797538, 98.7222368486466, 98.88730587497835, 86.7802200009746, 88.05313110351564, 90.64462538688414, 90.6083591522709, 88.00009281404557, 86.30926101438462, 76.63275026505994, 75.37727802030503, 73.10218564925655, 73.05712546071699, 70.90963563611432, 67.0098190922891, 65.76477642982238, 67.48026032601634, 70.95639813330867, 66.60341447399509, 69.11014633793985, 61.03768102584347, 67.09589942809075, 58.917922358359064, 74.75923799699353, 63.9759010653342, 88.40226911729383, 38.884071534679784, 6.085384738060736, 82.41853652461883, 65.5003184656943, 72.00509871205976, 67.34966108875891, 74.61485555095058, 67.98023700714111, 63.99407732871271, 53.93119742793422, 57.99162718557543, 59.287695961613814, 63.99734858543643, 64.69957836212652, 64.75922584533691, 67.55400088525587, 69.10467855391964, 64.62619473857265, 68.42652428534724, 66.94255828857422, 65.72548212543612, 65.70905523915445, 68.34319745340656, 64.56574709184709, 66.79273943747243, 63.37658251485517, 64.9252401628802, 68.93096462372812, 69.9222417031565, 62.00767140234671, 41.290331886660674, 27.923712153588575, 16.794261355553907, 11.948100443809263, 13.583701349073841, 12.440936450035343, 6.966106872404776, 2.6170654402625178, 0.102118440122614, 0.3779127665104405, 0.4689409577798459, 1.9323414467996167, 3.7941326921986, 0.29048966243863106, 0.031866449937825246, 0.1222405361852819, 18.606506201528735, 23.993379569822743, 27.77864525395055, 99.54515795553885, 26.423183948762958, 13.065995554770193, 63.15360361529935, 48.287734370077814, 63.807501946726155, 8.58725090180674, 0.4645126631423351, 0.11706188906945529, 0.05905347012524163, 0.04163118665136638, 0.12043187920484813, 0.09340150101530938, 0.030874436939015027, 0.008817093612085427, 0.08541730968582054, 0.020860133677600853, 0.008468586808791565, 0.04353103107742725, 0.05186698699910795, 0.06741315562037692, 0.018388799151345607, 0.026544787613074147, 0.03031155958230938, 0.012595878797583284, 0.04018467858493809, 0.02979838601013105, 0.006647930976243751, 0.04656188941049961, 0.014258641036107175, 0.05598730279973919, 0.03767890840648644, 0.10619364483582397, 0.04920933222878845, 0.07769938753617388, 0.033834939672341274, 0.06446191680527504, 0.07698545487777841, 0.07167518619568118, 0.07537440261653355, 0.06926957052201033, 0.06399092211898777, 0.07037850577504405, 0.06263531804565461, 0.0170798632391398, 0.031573538135196415, 0.09017604102771129, 0.0837596946005379, 0.01940119583460112, 0.06435581362776219, 0.0822024523550945, 0.03815397101965162, 0.023987578460946683, 0.005107703543598614, 0.08525739649250623, 0.024136749186342763, 0.051794342711688056, 0.022889542723855665, 0.03146281353228035, 0.11476579332543958, 0.019775663442429037, 0.022462705345523935, 0.07692486498384707, 0.05896201454884103, 0.03148507413214013, 0.04144505409884357, 0.04389402651858907, 0.02774226922361601, 0.05506218651369695, 0.09686062548069224, 0.05720921303896655, 0.1288568315606925, 0.11283280793577434, 0.1542816196958865, 0.26123380648993677, 18.781438027658773, 97.36996835277927, 76.62278744482225, 60.96845511467227, 11.015227456246654, 68.33217559322235, 131.4264729715163, 71.07566172076811, 48.7772814689144, 21.032598057100852, 0.5029233617167319, 0.19784295721159828, 0.45488339758688406, 0.8119356512062011, 0.5871191825116835, 0.4971044336355502, 0.7280756833572543, 2.5335169944071003, 12.490318109912257, 10.875639127146814, 3.0267839710558615, 0.9850066191246434, 1.9786800828672226, 27.342971909430723, 50.16766363574613, 83.44303607940674, 92.50786104509908, 99.34943952868062, 90.69989158261208, 82.64272351418772, 84.97712996698196, 85.25292750327819, 85.5254537828507, 90.10272641335764, 81.96026248316612, 79.02860456897368, 76.71548874147477, 76.41589026297294, 77.67610857563635, 75.61094930095058, 71.52490646608415, 73.64981912797498, 75.28096814309397, 76.90409198884042, 71.66554697098272, 74.76742006117298, 65.59826004889705, 71.16681760357272, 63.81631159013318, 78.10617293080976, 67.342789096217, 91.3817564133675, 44.89553136210288, 8.309371567541554, 86.04393620644846, 70.4166486186366, 76.69518655346286, 72.6108617167319, 80.96052092890586, 73.11636893979966, 71.00301158043646, 57.65913571080854, 62.30390056487053, 63.42469038501863, 68.28312243184736, 69.60034847259521, 68.68755802031487, 70.77785968780518, 72.32620746858659, 68.16905206249606, 73.44613044492661, 70.70932803615447, 68.8052369702247, 69.02125758509483, 73.21324363831552, 74.57675364709671, 76.24383941773446, 70.65671336266303, 70.30958360241306, 71.05399454793623, 78.90107262519099, 77.4997038995066, 59.65704987126013, 37.91378305804345, 24.98326420783997, 19.34807538986206, 21.388982649772398, 18.48180817019555, 9.978565612146932, 4.400953265928454, 0.16867491026078502, 0.3317424552815576, 3.7433083355426793, 3.7971565944533197, 4.717110030112728, 0.41254119707211373, 0.015871963790437628, 0.3813396616568489, 36.42917379256218, 48.07680891406152, 14.329783224290418, 104.76872736407866, 61.235595979998195, 9.035282654146995, 45.60693948499618, 49.579221817754934, 75.21730023045694, 14.997002905414952, 0.48539585223601717, 0.0030255431192927067, 0.02503790415733332, 0.03233244206996695, 0.07876368284585976, 0.11437443730932091, 0.03254158407329552, 0.01722199553173156, 0.04007173807270104, 0.01779789446793016, 0.041023586996861046, 0.1269067317667988, 0.06875241520784556, 0.057522317004059596, 0.01929393203388299, 0.025559975840752164, 0.030626890948042277, 0.07017461913487605, 0.03644295960604664, 0.05025988009067313, 0.02623494909775834, 0.025168434048311848, 0.0074482726068386155, 0.07633439505532866, 0.02702934014040136, 0.04017246331298544, 0.02330524692942779, 0.04069948583961495, 0.028778226940982768, 0.09125473879037366, 0.04833192406823078, 0.15262970430476053, 0.19255892704090766, 0.14819109812378883, 0.14883939236883195, 0.12685121337492622, 0.12072641702909624, 0.142232267065875, 0.16409203440191286, 0.3504244592641631, 0.23141934987037416, 0.13991586233098663, 0.12404284995770264, 0.12400656037272946, 0.15488145121883962, 0.11084526942502107, 0.18841658238201373, 0.14493548491549108, 0.16230323442047642, 0.14081914128074724, 0.14582197121795148, 0.10261792178836562, 0.17813807263249354, 0.1407299533246025, 0.11928035712410366, 0.16066615049156452, 0.2423720782802951, 0.09410016554137392, 0.11423563749919977, 0.29898312603754384, 0.1396034057101896, 0.2195733169754667, 0.15025438740849495, 0.1675902063687963, 0.2879040850506675, 0.23242911504160976, 0.233419559475395, 0.42446768452082917, 30.748920863674535, 115.91496590645083, 96.29225007949337, 119.32361541255828, 39.76263930720668, 46.768329758797925, 114.21201398295742, 100.7486274165492, 52.636862339512, 22.518048670984086, 0.3615899762559322, 0.6974256086734034, 0.23698330856859687, 1.6700624818763428, 1.4694316540994954, 1.805001699155377, 4.386015899719731, 6.767445197028499, 23.00036488040801, 19.170764646222516, 2.758213156653989, 0.7595325405559232, 1.3229823641238676, 22.613348537875762, 44.13952196798017, 81.98720132150959, 95.62004996884255, 105.1609879155313, 97.37938204119283, 89.93100504721366, 91.49389697659402, 91.10365252340995, 98.92590199747394, 96.76171072067754, 90.97907020199685, 88.80449248898415, 86.4766913075601, 87.26191843709638, 85.82868437613212, 80.53196276387861, 77.27870187451764, 78.817988980201, 80.751403685539, 83.70875312436013, 78.26855905594365, 80.30546157590805, 70.88590529657179, 77.08539178294521, 66.84948044438516, 84.36335748241794, 71.92952248357958, 95.70925251130136, 47.1013468311679, 8.474918142441782, 90.70896794719081, 75.23338194816344, 80.73293716676774, 75.09126663208008, 85.20840075708206, 76.85252851055515, 76.23936791573801, 62.12792342708957, 68.17457475969869, 69.25521912113314, 73.85210360250166, 75.59642084183233, 73.5471942347865, 77.60914587205457, 79.8015546798706, 74.92294988324566, 79.14069806375812, 76.65723369967553, 75.28542395560973, 76.09213782894996, 81.00822479494157, 82.00832720725768, 86.12494099524714, 78.27794136539583, 79.62241218936059, 82.69504793228643, 93.23000077278384, 88.35518498574534, 62.35500904821581, 35.89623743487943, 20.219027880699407, 13.83198836157399, 17.28857021177969, 15.572353812956042, 8.569797335132476, 3.636398498089083, 0.20266857569015798, 0.4813723278141791, 7.463600202914208, 4.949062332030266, 5.239395681888827, 2.2448185374659877, 0.12154076083172714, 0.2678517029891091, 29.060946510684108, 36.88726740498697, 37.99973003325924, 118.40695750328803, 38.7690362622661, 17.17910666619578, 88.18356560122582, 61.186197650048044, 89.65134789866786, 21.500738820722027, 0.6384052756813265, 0.3579679125499341, 0.1176647772832263, 0.11196971029764223, 0.23629467213346114, 0.2123628667886219, 0.1391260869680874, 0.11400810938568846, 0.17660206634431116, 0.15263263076063127, 0.10264059799092431, 0.20428370353916, 0.11372598984669294, 0.2140563807540363, 0.12237791107186388, 0.11965764776593256, 0.1035676180054584, 0.2022204908632463, 0.1344354838253029, 0.0783583687077607, 0.09595659576476583, 0.11524273668445888, 0.08735266994805106, 0.19717990811313355, 0.0999669741178232, 0.13341756747855296, 0.11775840088845262, 0.13046095838710187, 0.13746625022782435, 0.20263004146756666, 0.14222638351061653], [0.1355745339946401, 0.020049698838603594, 0.04247253505332817, 0.0653033494769085, 0.0757180390158488, 0.004426663827842041, 0.001171209343386093, 0.06851835236434015, 0.01998430174294739, 0.09001484080668419, 0.026381070793215788, 0.02626936368253683, 0.04026722838921894, 0.013031051212531185, 0.03468872934219337, 0.040244448764790455, 0.020920526303891695, 0.013426456003329687, 0.05627360900924091, 0.08505727900492568, 0.07486290869212921, 0.11532283883782164, 0.030808367601205266, 0.08598871934678286, 0.050773982544459646, 0.0632541868535261, 0.061672357016152916, 0.016797230421235005, 0.011999276335230999, 0.0165505156356601, 0.07314860310044981, 0.07046328872562417, 0.05303796388268952, 0.08122026634913299, 0.01389665874622522, 0.09660996151186767, 0.022832155077447815, 0.15280268695806304, 22.69106245809986, 89.74619080943447, 60.446540617173724, 80.87222053158669, 35.026969602031095, 16.676370597654774, 74.58792455734746, 80.23914214103453, 32.70928421328145, 31.010684159494218, 5.4959456574532295, 0.2276007080030057, 0.19047538239148357, 0.31921682578902094, 0.1316236806732993, 0.6046601444963486, 2.26515872343894, 12.180747985839846, 27.529902265917872, 23.031381022545602, 40.75541080967073, 37.60264888886483, 7.757094983131656, 1.7887079283114404, 0.5536443884334257, 7.655222694719992, 21.99414357062309, 42.52244641703945, 65.36886807410949, 80.97288423968901, 87.16138024483958, 85.81173189224737, 91.46626780110022, 92.68151221736785, 92.52812400940927, 85.94440214095577, 74.77263681350216, 63.30522283431023, 63.893668574671594, 64.4147946757655, 65.85363772607619, 60.748421915115856, 64.59307816720778, 63.29843321154195, 66.85202214025682, 62.13193208940568, 70.37784853289205, 65.23003970423053, 79.69838065485801, 70.61031172352453, 91.42437688765988, 29.167444744417747, 0.46980479852326457, 74.73884951683783, 63.72610884328043, 71.28414354016705, 62.600502352560724, 68.55319330769201, 58.13804141936764, 58.586101608891646, 52.49894395951302, 59.32336207359069, 58.07595814428022, 65.44398146290933, 59.03727616033247, 65.18451667601063, 58.103014653728856, 67.11055340305452, 67.9256768380442, 70.06115636517926, 68.27850187978437, 74.7776339131017, 75.58998031000938, 74.9334696800478, 70.60716598264634, 72.5447540898477, 77.49033727953511, 76.13293832348239, 52.416323154203354, 30.61512097235649, 15.305065858748653, 4.602900906916588, 1.0119679498095666, 0.3807277719099676, 0.06805949634121311, 0.17741162209741532, 0.06972901643283906, 0.14467123054688977, 0.1297511626034975, 0.3177532301314416, 2.287761136408775, 2.7141004656591727, 0.23030961022501995, 0.3929005413045807, 0.46145833187526275, 2.5184818140922056, 30.025055293113958, 18.582314983490978, 34.25655334226547, 109.9858719302762, 15.77525802196995, 15.705666349780177, 70.13725034652218, 52.16617791883407, 73.4267068678333, 13.906235887158303, 0.2578310890784187, 0.05432252862280416, 0.016788713438736818, 0.11968505073098407, 0.04861376781557356, 0.05931181029506749, 0.015588570630267985, 0.015748872613203863, 0.05530297943961717, 0.05562006706191648, 0.04185412972865086, 0.02435912727378309, 0.02869317777484896, 0.01714726940037743, 0.01945233028832703, 0.08915719005369371, 0.007360369284381911, 0.031805509558668545, 0.009076835722812723, 0.03886835566992241, 0.05723748934425174, 0.03522756494461529, 0.1077394340667994, 0.06738142425855322, 0.013854317066650239, 0.0169288098526698, 0.02773560425867477, 0.06893081410277276, 0.062389568530864296, 0.017776918980563362, 0.05308221312119596, 0.08806484826509992, 0.06186531541208106, 0.07085505076834271, 0.008734193322579227, 0.05248961729868766, 0.10972369372123673, 0.04500627127145568, 0.09474720340222122, 0.07965961501242654, 0.0450897480421249, 0.04822637630446304, 0.015997909602799242, 0.035869485338128386, 0.08884807357624655, 0.02047201629818207, 0.03823287041497327, 0.04588020139283711, 0.024629719104738008, 0.06446591578423977, 0.03778218854999831, 0.07256449936258216, 0.037590735516841375, 0.07017651903292826, 0.021281868910356876, 0.01051165903317592, 0.022732155705471675, 0.021084246954189676, 0.03536875494906018, 0.03294913135769387, 0.04542339082446791, 0.06396358427140983, 0.03886684264627196, 0.04537581293393047, 0.039301317921208764, 0.03865166003966043, 0.02321767541880329, 0.11046020299076073, 0.0632067238761773, 0.19326103130175223, 34.941658050783225, 105.64362772049444, 61.062144848608206, 55.57930284930814, 11.673595328484813, 43.2590675354004, 122.86454293035693, 70.99673578816076, 45.016340363410215, 48.85016302908621, 6.93049616390659, 0.7435502304184822, 0.297955526339431, 0.4964895408240057, 0.17032134046237316, 0.3070547816253478, 1.3003685517657189, 19.105976896901286, 31.269805739002845, 24.224418940082675, 36.780261224316014, 28.82850685427266, 6.100067150208258, 1.5169058163319866, 4.240752391276821, 20.985225631344704, 40.534581368969334, 61.72127562184488, 79.07142900651502, 85.96888557557138, 93.33860335811492, 85.14825513285976, 88.85998618218207, 91.71566778613676, 83.98385247876568, 77.97044323336694, 76.7168301920737, 71.97009548064202, 72.22079769257577, 73.55547828059044, 73.98732339182209, 70.8048769735521, 74.44959040611022, 71.66306803303381, 75.52021703412457, 68.52802738066643, 75.6080702812441, 69.97844142298545, 81.24423380820983, 76.05981749873008, 96.20318874236077, 29.947851281012262, 0.7611802424634657, 81.56804900015555, 70.93547621080953, 78.22797821414086, 66.08268060991841, 75.19277757213962, 66.03847549807641, 63.309988514069595, 58.911575963420255, 64.31220900627875, 65.94939062672277, 70.83279640443864, 65.05445088109663, 73.69753868349137, 68.30800594822054, 74.53352912779778, 74.20686629510696, 72.26919189576181, 71.42254829406738, 77.33686277943274, 80.2209266539543, 77.52450896847633, 69.72511906777659, 74.58897575255364, 79.94648625773769, 82.32566264367874, 67.75881136617353, 47.49178740286058, 26.123065756213283, 8.933668751870433, 2.9935239880315723, 0.9477812424302102, 0.030123331779313665, 0.28217546341399996, 0.11412610224778615, 0.3775905805730051, 0.10997349201070686, 1.617646378374869, 3.44950417837789, 1.435510383978967, 0.2373050195315192, 0.32142343480260144, 0.298038539626906, 5.0729464715526955, 52.746441595015995, 33.576520258380526, 11.466933488845827, 125.76094658144059, 47.21677434059882, 5.948633263188024, 45.02775446061165, 51.65729745741814, 80.93673567618094, 21.796493376455, 0.36486362317396753, 0.03383577470817874, 0.049681138968275446, 0.12381746689037931, 0.05544749809609306, 0.034404652448551315, 0.02214056920380362, 0.030972134216778704, 0.09357764761173919, 0.005805593363249735, 0.032118613523761594, 0.0216872462507097, 0.037958886729733604, 0.03230072986034136, 0.028266924538559494, 0.028246588734609467, 0.010619099034116635, 0.012823834962722276, 0.04680146425662022, 0.043473229743540294, 0.0127598742819241, 0.06264721539111869, 0.03610780380005318, 0.027138645565437696, 0.01842897854775431, 0.05012465791115838, 0.021094897491556984, 0.07945392040475723, 0.033132808598419355, 0.01704495644286996, 0.041841611851968115, 0.04670566879212857, 0.24096115882838928, 0.1277288053965857, 0.10567213048137004, 0.10102614429929566, 0.2348314595198439, 0.14148821183029683, 0.2089869471326951, 0.1354273685043858, 0.11776366391249242, 0.22992362448525047, 0.14551821735597428, 0.11633621994405986, 0.14713510720720216, 0.13335531517382593, 0.16654705508582054, 0.19618143507790184, 0.09878186674247827, 0.1839745134836243, 0.2045276412560094, 0.14341637852691835, 0.21139851530953763, 0.17989903297876159, 0.09343189938414483, 0.17198359804047694, 0.13739599996516783, 0.13251799639434586, 0.22771241894412428, 0.07716740842067427, 0.15005404009453713, 0.17135093198908916, 0.16117438854229066, 0.28859972352943114, 0.17970679087504265, 0.17347921617329123, 0.10576357073601216, 0.4257833026349545, 0.14693742587922082, 0.20865264168429762, 50.28176930642898, 126.84021811331473, 76.01306284627607, 108.27606370372158, 47.18502275405392, 30.133298981574278, 94.10613275343373, 96.78786508498654, 48.093192654271284, 45.54294209326468, 8.850976363305124, 0.5208266526460648, 0.351146389880488, 0.538107818893848, 0.957062550850453, 3.704432008727905, 10.427121000905192, 30.717814507022982, 39.977075284527196, 32.92448505278557, 52.888941303376235, 47.698817945295765, 10.590196482596859, 1.773683166792316, 2.8724847926247508, 13.451661621370624, 28.61301968174596, 48.78270218449254, 70.13096670950614, 83.66084529507546, 96.97584075312461, 88.97110692916378, 97.90082193190052, 102.96377028188398, 99.73425542154621, 93.97161114600398, 91.40385504691832, 78.08623944559406, 80.11108459964876, 81.49608919697424, 82.83746134850287, 78.09359781203732, 86.13258961708316, 79.97444491232596, 82.96744085127308, 75.89827860555341, 85.16152058878254, 76.9753614548714, 89.69307407256096, 82.79558612454323, 101.8532923729189, 29.992668282601144, 1.0359434374878485, 86.05020415398383, 76.35914141131987, 86.12662761442124, 72.40179154180711, 81.42951088566934, 71.64519771452873, 69.68766043263098, 64.8132957181623, 71.63234802984422, 72.45382570451306, 78.06061067888814, 69.26500151234289, 79.52251726581206, 71.01455119348341, 79.90737238237935, 78.27649793317242, 79.94248544016193, 79.08749503474083, 85.29986258476012, 89.79426337826638, 87.58574147378245, 79.71283851131317, 82.8424741375831, 91.76026513499599, 93.25064028463056, 70.82607346196329, 46.269941637592936, 21.49370993337324, 5.3258466816717585, 1.5270674517077785, 0.7194112289336421, 0.19943274287206514, 0.22944907898143416, 0.12120516835561684, 0.38717473887147447, 0.21372820400903303, 2.536978976380441, 5.471401916396234, 3.9468160992668526, 1.904227613441406, 0.47763240914190974, 0.7077014217934301, 4.5864857877454455, 48.54155878866873, 32.80867903463302, 43.86288504446707, 132.44527724481398, 28.322976096983883, 22.754189083653113, 92.9797221768287, 64.94706815288913, 94.75902695809641, 31.684794464418967, 0.5927156080161372, 0.20798214621120886, 0.14833097045700397, 0.21824511969762467, 0.18538299677593095, 0.16448453188903872, 0.09718638904873403, 0.17869158647954467, 0.13784080593576356, 0.17129172871430076, 0.10279811332903563, 0.10691847892538195, 0.12541979341016662, 0.13922023917398146, 0.18109212299027752, 0.1342078484594822, 0.09777865162299526, 0.15231962255652876, 0.1195398540866952, 0.10774580025745016, 0.1923989832040764, 0.19728172119827042, 0.13498052473991148, 0.10349659399399835, 0.1463797598356201, 0.11981355431940287, 0.07990303945036666, 0.1750240018290858, 0.1262671326196963, 0.06222852535786168, 0.1275882589059972, 0.1549952918843877], [0.10483018453082732, 0.028757929441428957, 0.016569438007389827, 0.10873116552829744, 0.04900819201382899, 0.05240504502228672, 0.05089735334378578, 0.029056690325359666, 0.04115348869574167, 0.04040061195771541, 0.09265551523816201, 0.031163087377565044, 0.08467881624857265, 0.028128551822456143, 0.02153226474840795, 0.074005771218048, 0.025286147288317164, 0.028851198730990294, 0.06186693951848054, 0.03355571211525991, 0.03693629341620592, 0.034143933575720556, 0.05547015897689327, 0.08542782041214167, 0.09090749411693505, 0.038839956790569334, 0.026228132830452056, 0.035533122943654176, 0.04632486563716685, 0.029093454884845885, 0.10909298119405586, 0.034441351890563965, 0.16850695314426578, 0.07033853130715509, 0.0058245095105150775, 0.05046043041793089, 0.08369530491050213, 0.13765835443571692, 0.045855150317713145, 16.063024670847003, 101.16104895068754, 73.55492130402597, 84.2688597402265, 54.299005923732636, 10.125273043109525, 57.99323535734608, 98.38336759997954, 44.74259814908428, 34.797962019520426, 21.006496644789173, 1.5515769945998348, 0.2867435537759335, 0.19991543955139576, 0.36689464483530293, 0.8725657494318101, 2.7575757715009876, 8.941688037687733, 77.33453289155038, 76.84428368845295, 73.86460027387066, 53.04223537445069, 36.78761174601894, 20.541287852871804, 0.02905205549341777, 0.19936477555142296, 0.8955698989091382, 3.6047219268737303, 13.891850594551334, 27.861630839686242, 38.78054841872185, 52.153320389409224, 67.17123246962025, 72.6117560171312, 74.60828950328212, 82.78286980044457, 81.3983045085784, 66.54082913552561, 56.549469732469134, 52.61452051901048, 48.614612933128114, 55.4886176509242, 57.71459018030475, 66.89508976474886, 67.28840935614802, 75.26178775295135, 70.66183597810807, 73.6209975519488, 62.71519637876942, 85.77859570903163, 12.374392459469458, 0.1312431648013092, 61.69423872424711, 65.2582807694712, 63.5228673104317, 57.654013095363496, 57.77483778615152, 53.12380498455417, 57.0840613303646, 56.44378539054625, 57.37157498636554, 58.714610222847234, 61.50015984812091, 59.720521665388546, 59.298910017936464, 61.07128789347988, 59.83686308706961, 70.74272309580158, 80.83404018032937, 76.38332674580236, 79.44277548020887, 77.95355350740495, 87.4417983331988, 89.90074003896406, 81.73175304166733, 47.00125186674057, 19.847346044355824, 7.255989639989792, 0.9390641424444415, 0.15982821884174503, 0.278461683661707, 0.2521882692892706, 0.19514093445914407, 0.24724246693714974, 0.1993139532785262, 0.40848304547609826, 1.276839233694538, 1.7598916229701813, 3.5113347057373296, 0.5135176835521575, 0.402791410564415, 0.3476898011661345, 0.10815374973800876, 12.641750035747407, 44.347697842505674, 30.235384548864058, 55.772483502664876, 112.35601117534023, 10.654154650626644, 27.976013037466235, 81.32951398049632, 55.07385838416315, 76.9863284018732, 15.841014596723742, 0.18432616316262754, 0.05449424723103162, 0.11522042820410383, 0.029131688417926915, 0.04831896952143119, 0.05947350081236613, 0.05404612026928414, 0.007514362533261339, 0.017633989956530354, 0.039208537012699156, 0.007639670577425991, 0.06348330076904067, 0.0718000968317351, 0.06370367362133919, 0.07495811043847954, 0.03920669840168088, 0.09167509123442635, 0.15044773267882486, 0.07407818950953023, 0.04196675231439933, 0.03151471790437016, 0.038430804551969615, 0.05932646172661936, 0.02796372609032739, 0.08215990383177996, 0.031875888141052376, 0.052729218957885626, 0.08651081592805925, 0.024355607099771023, 0.07739636911860398, 0.025573173620467706, 0.0366964849132684, 0.02633264829074183, 0.07658224748147112, 0.09597348034261696, 0.05221813106008115, 0.06614896498860852, 0.022463873629608465, 0.06070211815137056, 0.04428155209508635, 0.003429178806630174, 0.0136338158946244, 0.01044024910492402, 0.04611480815876876, 0.02466170902123615, 0.009697136157492717, 0.02516758943637533, 0.04098052136419762, 0.055663511908102425, 0.043350249649055546, 0.0624609257905714, 0.0419112300920871, 0.012485077585874787, 0.04550832316219326, 0.062220079238496484, 0.04861208625257977, 0.03208869779031844, 0.04098667305022959, 0.03275713440211069, 0.061789825108022466, 0.04825628437702695, 0.08893796633328162, 0.08692167654273011, 0.036034132954814745, 0.015713606713219516, 0.07720406572785109, 0.06624529288420755, 0.027863531365930557, 0.09944146844528376, 0.04380683805192671, 0.05279060558325822, 0.07419118747836159, 29.051791698701923, 113.75093936920167, 72.39990095938407, 66.32347491479689, 12.038002148751291, 21.70050513359808, 108.76450861653974, 77.18188208918419, 41.02404217566214, 54.72537540620374, 36.62291926722373, 2.5158871662232185, 0.7990877438456783, 0.33592652108880783, 0.3566561861624641, 0.7214419748033247, 0.5824830022550399, 12.397811951175814, 77.70335335885325, 83.90852728197652, 89.24513939888247, 65.3326371408278, 42.195893410713445, 13.43156731897785, 0.20520892324707202, 0.11686765513713322, 1.7636800196862992, 10.161926611777275, 26.605564355850223, 44.17947523055538, 54.232596274345156, 70.80247648300664, 79.63086097471177, 81.86106574150824, 85.95565149860998, 79.89245953098421, 72.39474696497764, 69.1107346934657, 64.38986409095027, 67.08606212369858, 65.403365319775, 72.06021585772115, 69.35174080633348, 79.05992861716979, 73.86707136707922, 83.34685956278156, 76.57491883923932, 83.85461038158786, 65.792515431681, 88.24571947897635, 15.792260516074398, 0.05652656358095908, 70.9255055458315, 73.99763922537528, 73.32905554002332, 67.63694332491967, 67.09265955032842, 63.24148824138027, 68.88213895982312, 66.125669787007, 66.33448108550041, 67.74873871957102, 71.55738369111093, 68.17316270643666, 65.77603755458709, 68.5398337148851, 62.73336479740759, 73.5843155460973, 85.42687677568006, 80.42572929013161, 80.7447042772847, 79.33533391644879, 87.33707104959797, 87.28729617211127, 86.97855857110794, 60.36967785127702, 33.33133289890905, 13.95643045825343, 3.48446965698273, 1.576105413898345, 1.1947035765455616, 0.24905696150756654, 0.21386560953913197, 0.4465204140832348, 1.075857721509472, 1.09798246333676, 2.6512971904969986, 2.933982408815815, 2.707455235142862, 0.49878455638404817, 1.105322811392046, 0.27147937445871295, 0.2815884562028993, 24.836185132303548, 69.56695341294812, 28.675201016087687, 28.101638709345174, 135.54443605484502, 31.91312151570474, 3.8956576057018775, 59.309696535910334, 55.00015704862533, 85.71477090158771, 23.444096734446866, 0.2187239706155754, 0.009555650251587073, 0.15096825877985648, 0.07600696141561193, 0.006580158050412373, 0.013296483441316074, 0.07788807499192416, 0.01213101089947046, 0.0333993957047501, 0.030537712567996596, 0.046769966551613425, 0.08973224629317561, 0.012565925717353823, 0.024580574564395413, 0.03961243388813831, 0.10058971166971231, 0.11312174565729596, 0.07451950211919124, 0.02331010009642811, 0.034464070227958506, 0.07734548555867327, 0.05466943621755608, 0.049547188494715004, 0.06208551589459662, 0.0646818146830605, 0.031233155694339546, 0.05877872035207768, 0.044410718349559654, 0.0077782238029965, 0.08325579260746319, 0.02001802876381384, 0.03485813436488952, 0.03442540193998045, 0.1839005400336558, 0.13317637235647248, 0.09636260704287598, 0.1621022589144207, 0.1268959912141004, 0.15812626258740503, 0.17269376154628494, 0.1462587945523762, 0.14090079093171706, 0.12551933887504763, 0.30153468912166936, 0.13898482035485007, 0.2455649335658358, 0.06763486912654293, 0.1586810174968935, 0.14835824318710836, 0.20077393300110297, 0.12665223735835285, 0.23128565220582872, 0.07589609317121006, 0.13602663312227498, 0.13362264921588282, 0.14611256368938955, 0.14115059688206644, 0.403067110286605, 0.16259888307221476, 0.1954483042561239, 0.17291583511377537, 0.14255082174654932, 0.11969319424561917, 0.15194210974920183, 0.16929505843549006, 0.17398921622624322, 0.17038351615830777, 0.1402615058806635, 0.12757702039614802, 0.2760754117081242, 0.1671908140903519, 0.17516715301861688, 41.28661740210749, 131.24612239099318, 89.37381667475547, 109.94202767649006, 75.21932417346586, 18.633815703853486, 79.2239699825164, 113.36544882866644, 60.96754512479229, 53.298491662548436, 31.708220820273127, 2.6766991951773247, 0.549497033559507, 0.6236882363596271, 0.6827746367742938, 3.304595889583711, 6.134396714548911, 17.64512150518356, 98.35714263300743, 95.83323863244827, 95.95101956398257, 68.66714600593814, 54.89493554638278, 23.41451421860726, 0.1979837028850471, 0.31862942021219964, 1.2537337767501033, 7.1173990638025355, 18.934757594139345, 31.816301730371293, 45.35233843711115, 65.7301183669798, 79.19135155216341, 85.33838025985226, 89.62803333036362, 95.31984744533416, 89.6309986422139, 83.20799196920088, 72.31142013303696, 74.67884509794175, 72.69840117423766, 79.35191769753733, 75.46626091003418, 85.2583246846353, 78.5427797994306, 86.0847210115002, 80.09093930644374, 86.85111291946905, 68.55236176521548, 89.63263819294592, 13.113072822170874, 0.23698925341088928, 74.83322174318376, 80.40436021743282, 78.40708148094916, 71.57759958697905, 75.00366441665157, 68.96781136912685, 75.98202120873236, 73.14684575603854, 74.03324650179955, 73.09436444313296, 76.32420093782487, 74.58240970488518, 70.94001047072872, 76.66532947171119, 69.73177925232919, 82.03699188847696, 93.41403838126891, 88.20922574689313, 87.79415269051829, 85.02242549773186, 97.62157270985266, 98.28088391211726, 93.79255494763775, 56.101248725768066, 26.209622659990867, 9.37652591736086, 1.5998628423098595, 1.3456608955898595, 1.4654662604293516, 0.8579509368827267, 0.29524290093010475, 0.5580052060465659, 1.524692579142509, 2.0286290155303095, 2.316820996422922, 3.774153854577772, 4.683868433198621, 2.7761979593384654, 1.0441994138302342, 0.577425473640042, 0.20935114533189805, 22.401428761020785, 67.9645710606729, 40.516644370171335, 70.65107299435523, 133.89341631243306, 23.12024820235468, 36.379285166340495, 102.58318270406416, 67.42184054466986, 98.72437061802034, 30.740519146765436, 0.26472566589232416, 0.10138677252877144, 0.2386976754473102, 0.2938008476649561, 0.1547035656028217, 0.1521890352089559, 0.08684160503288431, 0.22850787867942166, 0.1123506321962322, 0.25094732942600406, 0.2770556058854826, 0.32423488555415986, 0.1359773123817098, 0.1597331473303418, 0.11689102081882378, 0.14458817129413928, 0.25239482191541507, 0.19901367745572524, 0.10015359313617792, 0.14883620544306694, 0.1323060658309729, 0.08431167627174048, 0.13605027459561825, 0.2134910385094343, 0.26538630947470665, 0.30978291265426144, 0.13880238417656193, 0.1294006620563807, 0.1553924318643347, 0.1518509759297294, 0.07706621586675606, 0.07346581712725662, 0.08470541482130367], [0.10534391543197055, 0.09534236178883622, 0.06310779128163573, 0.0541347413203649, 0.049235268135464964, 0.08823962356414526, 0.017962934704677715, 0.02545560019150857, 0.05531892555976107, 0.010439527067055386, 0.020997987369135506, 0.03004612160786506, 0.08868075997358368, 0.05667721094082921, 0.03255007998837579, 0.03214467391972581, 0.007571283823645284, 0.042566365502294035, 0.03280841249732241, 0.08731333133313926, 0.030523773598214312, 0.07435803376739064, 0.1397023229829727, 0.022746270875476544, 0.059325584555946054, 0.09333422317379907, 0.05404084192348584, 0.014728206010805744, 0.03791206343580158, 0.04302538623432479, 0.05753619851724756, 0.0260252038001894, 0.07210795692498646, 0.05961986957117916, 0.001085846440307045, 0.011407965625215684, 0.06442437083610604, 0.054931982210086244, 0.12777309293948835, 0.09095537461220257, 11.88109459415559, 84.86076893345003, 75.36536970446187, 72.00303554534912, 62.98068200388263, 21.218700793481645, 56.61278463179066, 100.40875404111802, 64.12352731150966, 38.00187164737333, 31.51904098449215, 13.964922389676495, 0.21721424114319587, 0.5693947271473947, 0.22325937966665915, 1.0383397605149978, 2.1555750552685033, 32.945191244925226, 86.07833539285969, 63.90651041461576, 49.15204432702834, 49.735998953542406, 50.91655000563591, 11.251894447111315, 2.2005607187747955, 10.941447673305388, 18.589926342810354, 8.94456607680167, 0.8156409427042931, 1.5834912369328162, 5.176398494551259, 15.021988403412605, 25.602267173028764, 34.33868385130359, 52.66420518198321, 60.95131043464907, 72.86086574677499, 67.83568197681059, 58.597480404761534, 51.296745346438506, 46.17525169926305, 52.30639480775403, 55.31354265828287, 66.94249553065147, 72.88382730176373, 80.13920799378427, 78.15840321202433, 99.47547312705748, 48.00197009117373, 0.03992129372613084, 0.08269601216119143, 39.45162280913323, 67.99278859169253, 58.2999215587493, 58.34728417858001, 52.960736367010306, 56.406291454069084, 52.67952595987628, 53.059933108668176, 49.430395326306744, 52.74294676319246, 55.16460634046986, 62.22146411095897, 62.02110552018689, 65.17894691036594, 65.4090762907459, 70.70757865905762, 75.83635222527289, 85.34354994373938, 93.65477777296498, 98.37416571955528, 82.16024060403147, 41.683584797766905, 12.21046386226531, 1.471504013865225, 0.1916349330736745, 1.520896092537911, 1.6063131800582333, 0.43506850278185266, 0.3915597955065389, 0.1370210612132665, 0.278939783813492, 0.4702790988789451, 0.650875716199798, 0.46730413432082823, 0.8656030520796777, 0.5571445522289122, 0.6242091148611039, 0.199691052398374, 0.46517919027997606, 2.863117927505124, 24.38450655629558, 31.016034272409257, 30.962319374084476, 75.50606512254285, 90.22526910228115, 8.862216895626439, 38.359940898033884, 80.60213396626135, 53.85820996376776, 77.09815517548593, 13.360364533239796, 0.1353487985268716, 0.027403150827834205, 0.011791057467851187, 0.06697821686224592, 0.017011020663044146, 0.059896856321082007, 0.03467906514302858, 0.05362982043035088, 0.08595983017115824, 0.15084524038097552, 0.09707600343972446, 0.06803410052652321, 0.02959474068765919, 0.01434891013383505, 0.06874611796510798, 0.08476386732992627, 0.0378613292630161, 0.04771501644544544, 0.06266410379940945, 0.14785869257344356, 0.13580698039262526, 0.033105903590518626, 0.0831263084265013, 0.03973401970260086, 0.0837313799908565, 0.048530505549523144, 0.01731787526589488, 0.10409799599719625, 0.06676904421540038, 0.05801476215222671, 0.10721146925202302, 0.0430429104955927, 0.0790533560117887, 0.05682707306057696, 0.06719533384086625, 0.08464239642865236, 0.03582080045054036, 0.016504858710592794, 0.12136250749350556, 0.09144755546003581, 0.046569006367316174, 0.11792088813719251, 0.061028808685800726, 0.028513009216816678, 0.061116345722468636, 0.015104366672946321, 0.055826500944432714, 0.03644432707299148, 0.029637980605325395, 0.013438175233351368, 0.05713836905816871, 0.05287725395793396, 0.05204378093983378, 0.046458682045340545, 0.08905675592682055, 0.06795997385896983, 0.11648723119569403, 0.04231888079835523, 0.03569709257252755, 0.030918029257126396, 0.023983527771047047, 0.06442550464623398, 0.02968481539057628, 0.025123171658525546, 0.05656709729303276, 0.06817621749735649, 0.013051364033843481, 0.1570270949554059, 0.0574148808335585, 0.049773444902272, 0.04519289412025002, 0.10078127961605789, 0.07848349384843342, 0.12647529403048177, 21.694945173878825, 101.53325050107895, 82.98233801318754, 65.7914799259555, 23.25542288441812, 15.382440493952844, 98.26680260319864, 116.00051279990905, 44.0600469035487, 44.000266059752434, 53.52988796849405, 23.35173080044408, 0.5209576843246337, 0.8817443407831654, 0.2754537773228461, 2.068134882757741, 0.3875000504476409, 41.315431133393325, 97.14698945322345, 69.0080862660562, 59.520441562898704, 57.8507552608367, 61.59073522014003, 19.55761624920753, 5.888145902464467, 8.64129331804091, 10.271773569045529, 7.038531476451505, 4.069185713606497, 5.010583237294228, 10.899898986662588, 28.854278787489864, 39.95706727427822, 45.77593872624059, 66.18037116143012, 71.8592022311303, 75.59553438617338, 70.99615527737525, 63.725191008660104, 61.651743765800234, 60.46890989426644, 66.9484967570151, 69.25428559703212, 75.87530136108398, 79.11743056389594, 85.17974392060312, 82.26375979761924, 97.93584869753931, 61.31121927692045, 0.2802287727113693, 0.06692151869496991, 49.89655333180582, 80.15561919058524, 71.93033049183508, 70.09644200724941, 65.19888824032199, 68.1324798830094, 63.744108600001184, 64.97053961600027, 63.63884395168674, 66.1910007845971, 66.33113138137325, 73.67294542251095, 74.3718490292949, 76.8286491209461, 76.9051431840466, 79.8163341706799, 81.90880883124568, 86.31449345619448, 91.5482061139999, 96.82363710095807, 87.56593350441226, 57.53935044811618, 23.97670557422023, 5.243235682287525, 0.9124633633802015, 0.6105639244760237, 1.5820633716160253, 1.0816587844202596, 0.4263881750164494, 0.20953851511641858, 0.1929295297351576, 0.8461458896917682, 1.1164366021271677, 0.665273879083895, 0.44575582769128586, 0.4325688498154764, 1.162882000207901, 0.21689343416402418, 0.4519577078040569, 3.942665251031999, 40.25968597781274, 48.12506191192135, 30.030595640982355, 65.02681778323266, 127.76353620713758, 28.981045869088945, 14.457701521535075, 62.02946801339427, 53.465808206988925, 90.09032387887278, 20.624963775757823, 0.16415013451009028, 0.08968896998633301, 0.07881154801936881, 0.03384547338130013, 0.0036139800419820655, 0.07127965500037517, 0.016042387710073065, 0.07675844770405563, 0.05180785650267236, 0.08335732990094731, 0.0906141667116073, 0.06722793088204439, 0.03363741922282404, 0.0422854257387019, 0.042681949017869855, 0.01659198205978159, 0.04511244339688171, 0.02249841844933408, 0.09069215446229904, 0.1401451371249653, 0.055707477694076885, 0.030069717115932898, 0.12017726988321352, 0.02757079001786488, 0.027934319805353883, 0.00782753448865767, 0.022975388621430726, 0.084727953128036, 0.08275024352535125, 0.07762729100161984, 0.0654091615410101, 0.10832686262625842, 0.03578678997714193, 0.015828477767025752, 0.2659448488585411, 0.2628121314750564, 0.10348763076528426, 0.14737283961186487, 0.21212259097205055, 0.17150214242358364, 0.1967836567951787, 0.31588961400331994, 0.12229450707954746, 0.10135762288325256, 0.14910390720732752, 0.1860127210496895, 0.13766238405819864, 0.13423171975920278, 0.13543432458273827, 0.09097407481843427, 0.1586920644847616, 0.21723495616066843, 0.1199002371680352, 0.13701104078321688, 0.29394131754675223, 0.24473305401061815, 0.29854719136511126, 0.22605484982411708, 0.2491680442565872, 0.21224142653086495, 0.09582351863143906, 0.10832605057305868, 0.1349596565048541, 0.12165802591029676, 0.1654948639653383, 0.12184601622603594, 0.2363843503858774, 0.24136772168980491, 0.10512823869864787, 0.10471517175075509, 0.14392627132756097, 0.11157711321908621, 0.20118343764014784, 0.19861765596414768, 25.523129432432114, 118.39479815575385, 96.64673036144626, 93.35292000924387, 82.99857662570092, 28.190845174174157, 75.08709323021674, 116.7928158852362, 81.86959297426286, 53.71010126606111, 47.50178552442982, 21.100900250096476, 0.5026805118447351, 1.5979714018683282, 0.42550671425077224, 6.54161669554249, 8.071796057685729, 41.75898451958933, 100.38131313939249, 79.1104644344699, 68.1491970246838, 54.51230833607336, 64.19772286568919, 17.12057705848448, 4.0365957204372656, 15.846076415431117, 20.319619024953536, 11.522180072722897, 3.3262760552667805, 2.15025068290772, 4.730015608572192, 19.08513734417577, 28.104637361341908, 38.11588318117204, 62.473743115701986, 71.58052567512759, 81.54279678098618, 84.62265752976941, 79.27813791459607, 77.45729523320352, 72.82615277074999, 79.11658333193871, 74.89164936927058, 84.0245980601157, 82.35964605885168, 95.98732502229753, 91.30432098142563, 108.3574999532392, 55.74483079295005, 0.26040131406437966, 0.1668353033282103, 53.234717845916755, 89.9788030501335, 81.26499099116172, 79.19991800861975, 73.661633306934, 77.43991128859982, 72.21085840655913, 74.70516420179798, 70.05276249301049, 74.35841098908456, 74.89573647899013, 85.51157643718105, 85.22802829742433, 85.16636079357517, 84.89672137844948, 85.57019233703615, 87.41389459179294, 93.15212603538268, 98.4927232803837, 105.5872554163779, 85.84351878012382, 43.71538039176695, 14.728619629336944, 3.0221749409552547, 0.8191014537888189, 1.898192679209094, 2.9746519942437453, 1.6411163705971934, 0.509035854690498, 0.41009820396861724, 0.5262370720025032, 1.012208317556689, 2.999765214420134, 2.3431793239808854, 3.48883280350316, 2.5452380170745235, 1.6595368015189327, 0.5141380309097229, 0.44535412182731016, 5.107839386309347, 41.198838680021225, 50.668358110612445, 41.49189464507565, 91.44522820749592, 110.07054021281581, 21.902666053464337, 49.40628059448735, 100.33766500411495, 64.70358310207244, 101.9703515883415, 26.078654719937234, 0.2515358841347118, 0.16107295850111594, 0.22355381789947712, 0.17340922638052897, 0.14819782437576404, 0.1786804628828841, 0.0738564913251227, 0.164509245885476, 0.1843433388538899, 0.18383392102776036, 0.3612616309715856, 0.1379964290367019, 0.15282822832945855, 0.12281315626516459, 0.15350192605007082, 0.20339376984104035, 0.17013366424268292, 0.11078343846865239, 0.15689428595285262, 0.20267121103261748, 0.2059128354754179, 0.24316049000668913, 0.19824561302460011, 0.08497910739313211, 0.1967384269641292, 0.1430243100490301, 0.10159769951696358, 0.22858393588854423, 0.11815176405493291, 0.12439214774677831, 0.12095429754305272, 0.20593302955310192, 0.11666589056051548, 0.13725605102316027], [0.059668722998110525, 0.061061470844452424, 0.011189958069383377, 0.06815413118249948, 0.07393717570530792, 0.06398975000446362, 0.022496290640124393, 0.11033144659332692, 0.014928242101544335, 0.04663811898940513, 0.07546623357601705, 0.13595612238972418, 0.0842303177341819, 0.014308642637315057, 0.0341989386886839, 0.03338748303752753, 0.05224882437276745, 0.0502804572123193, 0.06328111101362495, 0.10396743929314037, 0.031538171686172005, 0.0606318066016801, 0.030802160373798786, 0.07647612132132053, 0.11618179960116265, 0.01966125970225661, 0.0742607559227655, 0.057872744772823594, 0.055710185814889214, 0.03113032562748319, 0.05302964799827146, 0.020073930199648586, 0.03990788335701631, 0.07431452763417075, 0.07412413180234932, 0.05021578790019116, 0.05081933494957705, 0.03106862107562202, 0.09067085721800405, 0.1915953263279892, 0.08473493984990543, 4.956506010024778, 53.40649804761333, 80.17436027526855, 70.69243831019249, 96.52841598756852, 35.52050182896276, 23.138508796691898, 84.18949450215986, 96.42582247334143, 48.50307249253797, 29.580752734215032, 31.99149439411779, 10.560782628674662, 0.23139135701762092, 0.10459327950112282, 0.6472220283842857, 0.6049189596406875, 23.41857583292069, 49.35488577811949, 60.113778498864946, 49.669734431851296, 29.814598560333256, 9.989086389541626, 1.3553823674878767, 7.689590992466097, 21.636701899190104, 41.67940355116322, 36.08204403231221, 14.164654381813543, 8.829426861578419, 0.5871011028366705, 0.3092825959526724, 0.8815644633385443, 4.384086093594951, 8.110007787904433, 11.794798527994464, 16.065369267617505, 21.66504494605526, 30.367191876134566, 37.24214384632726, 46.30951443026143, 54.162907523493615, 67.06732103901525, 77.46610487661054, 78.37402374513688, 52.43586832477201, 29.7381535268599, 0.5370725583164924, 0.5763552181663052, 0.04625700556883409, 14.69859584685295, 64.1154589960652, 41.224118355781805, 53.32823891793528, 45.12534695286905, 47.89068460464478, 42.168774143342056, 48.05968384588919, 44.18816720285724, 43.55153122255879, 43.58556955091415, 44.36321866127753, 42.93514251708985, 44.23930706516389, 47.96462128239293, 58.32296156114148, 74.66335958050144, 78.58945600448116, 61.07238615712812, 24.464126748423425, 2.831318782221887, 0.3067581217375494, 0.2733622653590095, 0.7046818709181202, 1.5589478635980238, 1.079168937379314, 0.5412353575229645, 0.39237433083115086, 0.025454171437529788, 0.12142558717319082, 0.2686598644621911, 0.3132867536717846, 0.09533912123691651, 0.30857871436784345, 1.3244063070704861, 0.7078630357019363, 0.5079607575410797, 0.9724356678705063, 11.105692021308407, 43.08246674076204, 35.79848804781514, 50.34741017126268, 96.12840483265539, 58.273771116810465, 12.494169877421472, 38.49660019720755, 62.40891025912378, 57.28360406814083, 71.57711321307768, 8.398828083469022, 0.1027386878887492, 0.02353989583019528, 0.058550173341627085, 0.06227568573048038, 0.08623765195689856, 0.05354959953335985, 0.05801546312267742, 0.03887659494554804, 0.02832864249695934, 0.06987279581446802, 0.10580130056628298, 0.16136926598846912, 0.040523009825377695, 0.03613534849137068, 0.06142514810386685, 0.01236734998172089, 0.027108837084303943, 0.08300051678933444, 0.05118395449713834, 0.05562436481517169, 0.08500484794738793, 0.02877825758449974, 0.026030562585219744, 0.022007430783442913, 0.08370107355257196, 0.0500494740422695, 0.1412556122147268, 0.0024292643290884314, 0.09557659317168499, 0.05043312321386991, 0.026271227191412644, 0.1434760567762198, 0.040603142622257435, 0.1173100172872505, 0.08548317026467094, 0.02103733556014636, 0.05692878655428368, 0.05897174003503977, 0.015304745588031028, 0.06888181511913577, 0.015573240253293227, 0.01372950027636703, 0.029652563088964072, 0.013362891773032326, 0.02391145804957036, 0.02564657825015245, 0.034575980351937395, 0.05681773444877998, 0.043045660751240875, 0.05617028290045358, 0.01584099277087878, 0.06057929893534991, 0.05808280225122168, 0.02559166889817965, 0.04263948859466661, 0.023411357767819878, 0.013075860652832255, 0.048966302326129335, 0.09363400103944926, 0.04532961783209636, 0.0713040012746088, 0.028048939965364915, 0.0630191051130814, 0.03695260342811385, 0.07562586331679937, 0.03110183864801882, 0.030766385982954697, 0.029082394490439086, 0.05995655372258156, 0.07598281432423862, 0.03117325910997968, 0.011817524848025174, 0.05530450778502611, 0.09873783966946988, 0.11967558188423996, 0.1902982628633899, 8.96687847952689, 72.45680670584403, 87.50021811454528, 60.63743452872, 61.77474537203389, 28.012724461094027, 46.47023747044225, 122.51411837916221, 74.14845435850083, 40.87578835025911, 44.079811726847005, 44.89714737861387, 15.178813588234688, 0.3083582955502695, 0.5792739518707799, 0.13988570911028694, 1.345987187758569, 29.13723857172074, 63.63207786313949, 77.42918752854871, 67.2194540885187, 41.733057652750325, 12.10056689477736, 5.925082372080896, 18.266801488014963, 32.15002875174246, 35.58468749446254, 16.408608036656535, 7.609811944346275, 7.063927842724708, 2.5477093554312185, 3.246549468848013, 4.4259480795552655, 16.424696618510833, 18.93135101564469, 22.65788705118241, 31.865458834555845, 40.96597540763117, 52.54028181875906, 56.622923958686094, 66.7793563104445, 66.90469172693068, 76.89708663571265, 86.44427684045608, 91.77741373738935, 66.13850378221082, 46.3730921283845, 1.5272112310894075, 0.6753089567345958, 0.05167491726517197, 21.128754961875178, 82.16680665169993, 56.12659900419174, 71.78756406230312, 61.423112730826105, 66.47168559412803, 61.28085228704638, 66.3286602881647, 60.087977147871456, 65.34904049288842, 62.55827803765575, 65.01608225607103, 62.61057107679306, 64.95495996167584, 68.21443388538977, 75.90515059809532, 84.65948858568746, 91.33334652070077, 74.08653582296064, 40.281808145584606, 9.868316611936017, 0.9421117014942632, 0.13856728711435873, 1.2599036650311564, 2.486604956849929, 1.2072393490422157, 1.0842917979724946, 0.6547252773757904, 0.07085841389433031, 0.14566397324444788, 0.175433200032961, 0.6042034335194096, 0.4030816353136494, 0.2056375954059824, 1.1323040603630006, 1.5037409937189472, 0.31782573269259545, 0.8159859274183551, 23.236538633223503, 70.37960575472924, 43.38336744616109, 36.00094118425923, 105.47633078790481, 96.80138941734069, 23.646657736070697, 11.512679111573005, 54.298825494704715, 65.12564189972417, 82.97451680706394, 14.696018849649738, 0.1447906483325266, 0.03330677567470459, 0.014917283213787503, 0.08303720474002824, 0.01839898620551873, 0.03387732731719171, 0.053618447855114944, 0.04567919141282478, 0.058833713973722154, 0.17769345052299962, 0.1579170899405595, 0.27300980362680655, 0.3052575393549858, 0.02250813052899415, 0.20148251836578693, 0.06265252821087357, 0.04090683136676108, 0.024124679471095724, 0.05241449471683272, 0.07987917581152532, 0.011884763427529366, 0.053013970008901054, 0.02662861869940835, 0.031242454086520502, 0.10119385626767913, 0.08144950283871544, 0.12576852429417834, 0.034075904968044454, 0.10436379020252537, 0.07013281371684806, 0.03474814712160057, 0.07877352707568677, 0.06492965178744448, 0.09832759958601768, 0.05237271228144246, 0.196922839649262, 0.11139696764369166, 0.13984553545953768, 0.12316682841628791, 0.16292810169679506, 0.2081411554207725, 0.14723620016969022, 0.21959873577279432, 0.06052438192249787, 0.143994361222271, 0.1512894641247488, 0.21281734078882203, 0.13235298105545584, 0.2180330972037008, 0.24443095489855737, 0.1255224645137787, 0.18447188840758416, 0.17805637701624827, 0.2298376694201462, 0.19075912603687858, 0.13622075980228765, 0.07005386069537171, 0.1821631292301801, 0.18498369642803747, 0.2406655867854434, 0.17462330720117017, 0.15961311667436556, 0.13555916627087902, 0.1661775555581816, 0.10905547352928309, 0.13270997802817053, 0.12772403266881743, 0.09212732059700836, 0.17700922675430777, 0.14560452482152372, 0.1396830328890393, 0.14498420810747534, 0.11765274204193585, 0.2658190265778573, 0.34117324277758604, 0.2433152244456353, 10.648813363044493, 88.45339329011979, 104.68123497501497, 86.4730356585595, 115.45939045567667, 50.31331300735474, 33.627852316825624, 102.28724771930327, 114.94177879825716, 61.36343386865432, 42.69196733351677, 49.11614287284113, 16.058108960428548, 0.3301952028226468, 0.585374647090512, 1.1892697455421573, 2.949935914047303, 30.13759593809805, 64.65283547678303, 107.67444272195141, 82.25698194196148, 45.39161312964655, 16.453640768604895, 11.07179097590908, 16.539069990957938, 26.561367088748565, 74.06180920139437, 45.33686076441119, 33.57230763281546, 13.952838547768133, 1.165100958558821, 0.9496943171947234, 1.0775461792945862, 7.295766886203521, 9.386392639529321, 11.665408361342646, 20.336322438332346, 32.443392622855406, 50.444155431562855, 66.58837610675444, 78.83443940070369, 78.25319905434885, 85.32456567210536, 90.08717813799458, 85.75698344938218, 54.94695401960804, 33.546106200064386, 0.5922932790652399, 0.8290400656480944, 0.11344281310636191, 20.88851567237608, 90.73403973733225, 60.520508673883256, 77.83573335216892, 69.69029626538678, 77.80964174578267, 68.06485822123867, 79.77810675098051, 70.21631748445573, 75.80149019918134, 71.45276623387491, 74.66257510646697, 71.14074953140752, 75.31776782005065, 78.57317032352572, 86.5885651496149, 93.654095280555, 93.33372392962056, 66.68347004921206, 27.114140833577803, 3.752036834916761, 0.3338206679590287, 0.3420893920044745, 2.5551422469077574, 3.4375843405723576, 2.6962352952649518, 1.1442856754987472, 0.8084142820969705, 0.13133498809991345, 0.756053336926045, 0.9446176670251355, 1.9359105585082887, 1.0263485846019562, 2.162780939571319, 3.2808547635232252, 1.4899336378420553, 0.3529494237755576, 1.136120526540664, 21.55719545579726, 60.09492366544662, 50.25311639232021, 63.31462867798344, 116.48865176785378, 72.32892174874583, 21.358762748779792, 52.505957157381125, 77.20291383804815, 77.28968451100012, 96.11315465742543, 18.11950275974889, 0.45273507254258283, 0.08004229125236312, 0.11060039708090406, 0.23139092800838335, 0.1753266372026936, 0.088884845796612, 0.24928119544300342, 0.13440644909297267, 0.09614617188250828, 0.29675384082140466, 0.39414028607068524, 0.4659672496059249, 0.42093718364354105, 0.12993061103888098, 0.38618596450936415, 0.12827592240946908, 0.3264114332775916, 0.14054987669712113, 0.17627744424727657, 0.13498950329038406, 0.179653731625407, 0.20257425494492057, 0.10302198720314812, 0.14987698185347742, 0.23592000917321254, 0.17462047267585032, 0.35727392882108694, 0.13892276723298336, 0.22055311278710443, 0.3126684900733733, 0.17291517627816047, 0.1876263933316354, 0.19345177187313958, 0.17149753057427947, 0.21100005765836086], [0.02937955042016843, 0.08556128825030981, 0.009866998917723616, 0.05672687259052069, 0.048467667187534036, 0.04226000694137427, 0.031458358731000655, 0.030056107563958056, 0.033574894956883886, 0.048520209327820814, 0.04450937132200888, 0.038178903351147334, 0.03281967398980933, 0.026289100022686106, 0.021332513067811247, 0.027693055735360232, 0.08815044326887977, 0.009835132532903265, 0.03067958247547429, 0.052562399481933926, 0.07826135899390906, 0.02105282202753569, 0.06668952428886006, 0.06754618678842822, 0.1261382536481946, 0.126471861956581, 0.02995832984696233, 0.024658012647001494, 0.03613735181129268, 0.04387985389198988, 0.04237449112077875, 0.07011258899564705, 0.07003391176582345, 0.0344496256401462, 0.030297555495053533, 0.06013844214800385, 0.06643989453873327, 0.009924703533010138, 0.04043710455598851, 0.05136643664070195, 0.032931373439609044, 0.06732517808315254, 0.3120977852133013, 39.782482577908425, 103.30267090951244, 74.65512260313957, 76.45727126829087, 56.549469732469134, 26.21043262943145, 54.02072160474716, 112.0436728385187, 76.53055683259042, 61.114865426094305, 41.471855255865286, 24.16140998563459, 7.2256937430750945, 0.017908471598920804, 0.32354706117222387, 1.157756688133363, 12.371898812632407, 14.636825380786775, 5.935177082015622, 1.741977177800671, 12.630783088745611, 14.155664309378594, 0.952619486037762, 3.1212091493991116, 44.360300417869325, 59.41148204188193, 44.31475385542839, 3.293053334759128, 0.1753851969636256, 0.3882838196812138, 0.0927876117789457, 0.3490569923193224, 0.6109383269663781, 0.26932706575720544, 0.12944472743378532, 0.36662323520548884, 0.9895367728125666, 1.883729674643086, 5.004118190657708, 10.797439813613893, 16.361206193124097, 10.540018581574964, 4.051287203065811, 0.34915149692566166, 0.07000833975091096, 0.03932059269338366, 1.0946810533923488, 0.3310948045503709, 0.4220561929527791, 37.06727673930507, 42.36602229456748, 41.97415790250225, 35.70544550495763, 33.670155079134055, 28.388785623735, 25.982640981674198, 22.19367846365898, 20.805975275654948, 19.452028005353867, 21.998364040928504, 22.838200369188865, 25.829952916791363, 28.014156126206924, 29.988567444585986, 35.41588044935657, 16.099847882024704, 3.4526231981092885, 0.7579284137295139, 0.24956490844488147, 1.204610380434221, 1.2967418302451412, 0.28696326779261716, 0.23343932454384145, 0.04695545559027984, 0.011560051315163654, 0.023024247794021523, 0.021132045095005346, 0.2794192935670576, 0.08315819300590985, 0.06650038484123445, 0.1610562731061251, 0.03307589975696418, 0.07277254586017902, 0.3716084451204346, 5.260305837277444, 21.00555919831799, 24.931596786745136, 36.15900485746322, 74.99337211731942, 80.21256416074692, 29.112643349555235, 18.108098468472882, 53.74993293516098, 64.67383192431542, 66.50035812008765, 44.904988196588334, 1.999247766310169, 0.2472368744953025, 0.17093828638955472, 0.03991007053804013, 0.031847052591582464, 0.050688192188259096, 0.0031309096553858613, 0.05285458158581488, 0.08446544543990205, 0.04675237717287195, 0.022288184770713412, 0.07421822272120945, 0.004154826146400264, 0.10201683388121667, 0.008761633634417048, 0.08360682175524774, 0.16338913340962705, 0.07945731417426179, 0.05223384352340814, 0.02703888559593789, 0.0666895472714978, 0.0426759620407416, 0.03179122393410052, 0.033511455215874224, 0.028464799303741708, 0.051736771204178376, 0.09228613828459094, 0.011577216472717063, 0.003535858944110993, 0.05741692245787671, 0.02667808691189895, 0.03885609060225468, 0.05366945398911353, 0.08275859388372592, 0.10361691576338584, 0.05683366524716539, 0.028026995376773903, 0.022517220162215735, 0.04484648065220925, 0.030035672168577873, 0.020022190536462495, 0.05895006740766187, 0.02378646314384476, 0.028742636411240505, 0.05313981910266223, 0.03713367596989678, 0.029737805692298763, 0.038379346426095695, 0.03639135592346711, 0.04361790161760103, 0.06309349991140828, 0.05367063759495655, 0.02078719061589049, 0.06228621560899962, 0.053790668250932816, 0.06327064625257928, 0.08138273827611439, 0.09231087526366596, 0.02505386368401589, 0.03948717851251845, 0.06889244075864553, 0.08478396947705939, 0.06515152617207458, 0.059230011256952445, 0.041710277568669095, 0.06217162800772537, 0.08203814181709483, 0.016573345055803657, 0.06296936685459749, 0.04513120872058696, 0.006367029995852781, 0.015417152711550797, 0.02455802859678384, 0.07101787509576929, 0.026157497608613585, 0.06318037045158206, 0.05505919110991302, 0.07488079684516115, 0.16947348031305498, 1.0429924269837718, 59.18127029172836, 107.19887887277912, 83.8446161823888, 63.11659213035338, 20.907329320907593, 34.802990498081336, 92.08363317674207, 111.04642591168805, 55.54885741203062, 58.54703480197538, 61.549652314955196, 45.75398914275631, 11.983588087943293, 0.1954967669782139, 0.1914821291762975, 0.4894305308980327, 14.695141219323682, 17.464139423062726, 13.111219502264454, 6.418702362045166, 3.5167176685025616, 5.274963244315117, 10.005418158346608, 24.138440585905506, 68.57707269730108, 60.138967960111565, 40.22207829260057, 8.334688505818768, 0.23021919652819636, 1.2270831100402342, 0.17753848625767618, 0.5260562139653391, 1.327867676173487, 2.462760623424284, 0.6675179038316973, 1.0350019460724247, 3.6024442555442935, 8.79671331374876, 16.66653133207752, 22.288366440803777, 30.64496236462747, 20.637205493065622, 9.144967813645641, 1.138283958838832, 0.18580269038436875, 0.07158864890375445, 2.5936773275175407, 0.8194142015230271, 2.042466769776037, 65.71869250266784, 62.21869491761731, 62.2370437652834, 54.32004551733694, 54.520914016231416, 49.83590956657164, 48.17130273388278, 43.175513205989716, 43.693419041172156, 44.57112781463131, 48.49242325752012, 52.25257204424951, 58.01916614655526, 58.30116495009392, 55.96393439077563, 55.03323831865865, 29.460838033306985, 7.521702272276725, 1.3092947631112992, 0.518780094721625, 0.7483103943447913, 1.252505462015829, 0.37179711725442643, 0.3283235580930787, 0.1397743812131305, 0.14724059751437557, 0.05126902856112969, 0.007526414053920176, 0.3357620879767403, 0.12128601361426616, 0.08535895676862809, 0.08298573895327507, 0.5581821417135577, 0.05794140157259761, 0.3733389458108333, 9.087019697312387, 50.466297211185584, 38.709992824062226, 31.076242654554306, 76.13138506489416, 107.95577864493094, 55.554537004040135, 14.11350275239637, 26.257893308516472, 56.54696333792902, 73.20007231927687, 56.98473907286122, 4.762008911178959, 0.14069293595610127, 0.14250864094543841, 0.017667174970190373, 0.05312886787578464, 0.02995479052075215, 0.03679141469840561, 0.06161574694898821, 0.0588093638690489, 0.11272626042726541, 0.0005853927406508687, 0.044376849602427215, 0.062114232700438275, 0.16477026736303685, 0.03353045419639638, 0.05113505510493152, 0.12706849889288988, 0.04343972871861151, 0.07431139433456045, 0.0689724892858536, 0.08179719184315012, 0.006507063686336962, 0.02753288015693186, 0.03802225752283008, 0.07152399108294519, 0.05041402081147798, 0.029473087840503263, 0.012239079092509084, 0.0482564184424137, 0.004866156499877933, 0.05057656168637257, 0.056534358525588635, 0.08540427086934929, 0.08109128778620113, 0.1132099147165014, 0.043445355634415345, 0.006309779766466349, 0.19864698180988913, 0.22325872083104428, 0.0737759525016431, 0.10096687207659406, 0.13408919676176964, 0.18405478417633042, 0.0875031219555005, 0.11069310138062124, 0.10807859651263683, 0.16748301534643098, 0.0808818316868236, 0.0852434307096466, 0.13590844107731698, 0.23772030047351317, 0.10776207196496188, 0.1167016898492171, 0.26595499186265853, 0.21808178975216805, 0.21562345956842746, 0.17829970186275823, 0.09876718849784906, 0.20619166083633902, 0.19272345208352615, 0.3238547527261319, 0.1928663887684384, 0.15238987281918526, 0.1665567844024589, 0.157452319718657, 0.14915978566052454, 0.16718782634744722, 0.1194626477456862, 0.1795745947428288, 0.2231825716913708, 0.13220072874138433, 0.19847461202692604, 0.11826392698792682, 0.30017209449602716, 0.13346207718695366, 0.20375035312627593, 0.13905743016831337, 0.07770513319560597, 0.3205493591245144, 1.8594282625182983, 66.93430562173167, 130.33992152060233, 97.1462598923714, 95.18625936200543, 76.67002062643729, 34.86727030046525, 72.0966076081799, 130.06912892864597, 91.19199214443084, 77.34442510912496, 63.23301984417824, 42.63960369171635, 12.009793443064536, 0.19265554604991791, 0.49750696687448415, 1.286612431849203, 16.058996396680033, 19.380942890720984, 17.132799163941417, 10.907269120216371, 28.494283653074696, 31.70668325116558, 7.6073290840271985, 11.663816859645229, 68.96157480055287, 81.25979777305358, 59.76982978082473, 5.607662114404864, 0.1424512916034268, 0.7201262647586485, 0.23110076454618286, 0.47615821082745835, 0.9152294310831255, 1.4170959591865542, 0.23176261854748573, 0.28371407440112484, 1.8874539651217002, 5.791325136538475, 13.760558078365943, 19.8272870432946, 25.775755566935388, 16.547799225776426, 6.4064606447373675, 0.5166837717256239, 0.1475254749698985, 0.19621644529604143, 4.843808470233794, 1.3419813446460234, 1.532569433892927, 73.99912972604075, 81.77767615164481, 74.78893818393831, 65.48888083427184, 68.42884632848924, 64.15715379099693, 64.86242340457055, 60.03979867504489, 61.55858355183756, 61.97920283963604, 68.35119908855808, 71.51090360456898, 77.37138748168945, 71.41868868181783, 61.47869271616782, 54.124633035352154, 20.850755014727195, 3.819382214738477, 1.4038023112281677, 0.9993326471697901, 1.8294553482724776, 1.6913598487454078, 0.2990804804909614, 0.37312085590054916, 0.18010321073234084, 0.3331614033349099, 0.19158959599031558, 0.17274967064299893, 0.6706689153948139, 0.1639718964936272, 0.24910844261607817, 0.39088269635554285, 1.4581879348524156, 0.19175815065541577, 0.44527757432191606, 10.626797099267284, 35.88113238734584, 44.058509334441155, 47.989665615943174, 89.89496631007042, 93.85743095028786, 39.89845921916347, 25.77864831493747, 68.65173109116094, 79.19116327839514, 90.02261592495827, 65.05425476258802, 5.718155282159006, 0.37938380854264386, 0.34193540833169417, 0.14326267064579074, 0.15389882088188203, 0.15198540903868216, 0.15864897969990008, 0.12920472740886674, 0.17262409351045088, 0.14724873336813143, 0.10614178834422942, 0.21740305117301403, 0.1459759242472149, 0.40621913308578156, 0.18374468710634018, 0.14750042389477455, 0.20695062414292367, 0.19260778812871826, 0.1580396333649274, 0.237759324992376, 0.19822080709761192, 0.09923587342904461, 0.11579970558804852, 0.12319426968573563, 0.1861751929766709, 0.16100543551146984, 0.16658543609082702, 0.12142602384330765, 0.10167563364150063, 0.21821960896974613, 0.1547065686674849, 0.25838487871712257, 0.15255136415362358, 0.2915324919646786, 0.20471684965154818, 0.16117860202587422, 0.07451405523404961], [0.058240796394285664, 0.07447560528112997, 0.06426587490545166, 0.009213368870287893, 0.06652227963411039, 0.06360844123147189, 0.01983360267214237, 0.016966853778989568, 0.0658279205221803, 0.009393150553918414, 0.06553705991996873, 0.05764856829398102, 0.03319485788984645, 0.026415401108322606, 0.03809267632482994, 0.021980339999220545, 0.014303958967267988, 0.034523671868467526, 0.04037015613228564, 0.04636688172937401, 0.041441893986155914, 0.04394900481847506, 0.034911507710574136, 0.11623339562286293, 0.059697252112410726, 0.01978408083349707, 0.021882974054484118, 0.05431970175836356, 0.05552543222063011, 0.015546539216302337, 0.039521874634609114, 0.029865592988508365, 0.02478353040773542, 0.05714080904820754, 0.02660032707236467, 0.0764924543158662, 0.04272689922682701, 0.032674377754090295, 0.05858252140422983, 0.05954180521169498, 0.08442731724391062, 0.07993369828909636, 0.051211085500976736, 0.12877820029614434, 16.11557364463806, 67.58335590362549, 80.47533158333071, 82.05949844852572, 74.06388805758569, 34.99960714770902, 35.31033339038972, 71.27473769649383, 83.85743448811193, 75.71170714593704, 38.61751118013936, 33.81901687191379, 22.833364086766398, 2.2550051779516282, 0.2840858109055027, 0.045979302526722034, 0.09532094963135258, 1.2183542429439485, 2.8085425592237905, 6.564987157621692, 3.4117099354344034, 4.385725644326979, 20.345565503643407, 5.521268969581974, 12.09754470855959, 10.759094722809332, 3.808791815273224, 3.363843291036545, 1.4333373909035039, 0.16038458253587448, 0.2501088155493621, 0.6557281783992245, 0.617141371532794, 0.19319864110119883, 0.5564724786146995, 0.6482356546386596, 0.35752079299380707, 0.3006078453073579, 0.4313392480534892, 0.2551488313944109, 0.4869667614900297, 0.5303218528147667, 0.4993531161979322, 0.17191665727765332, 0.07064547209489731, 0.3075009818759657, 0.6626526939292109, 0.19205712412874545, 1.295608020117206, 13.86091289981719, 20.024703856437437, 20.98999131110407, 17.240883996409757, 12.775901959788415, 11.795627128693367, 9.647087089477047, 6.120622821392552, 3.521778996913664, 4.671264877242427, 3.9488716663852816, 5.512333810329438, 6.015002708281241, 4.455343792515417, 2.473866814567197, 0.5684674543238456, 0.7097811972902668, 1.6752715120392463, 0.7639957688027813, 0.054846027144981976, 0.24579927986187322, 0.1229446322747296, 0.03837242482169982, 0.01628854612429296, 0.03482927583278187, 0.16866996133279416, 0.13300668388124437, 0.14160750704186578, 0.12047148595053343, 0.2220483325541981, 0.0334487930541077, 0.028486588759528055, 2.720789577691786, 14.635047566506172, 19.43902534823264, 27.355978488922123, 61.15560708507415, 78.28336992571431, 53.12469536258329, 27.51937266319029, 45.87592778667327, 72.57905129463443, 69.00472087244835, 57.7321663210469, 23.363515561626805, 0.7010585814714433, 0.09730668017460455, 0.08257315464077458, 0.03311693142618864, 0.04749879578969652, 0.03624455815541648, 0.04062835074540588, 0.018914607428615133, 0.12779590703787344, 0.08147232459797975, 0.0313426066760815, 0.07532571772894553, 0.02077629493038741, 0.0693848590937353, 0.036608051553729086, 0.029537670967739918, 0.02682042604823026, 0.07997416305325686, 0.050879407734159506, 0.05069573432387364, 0.08352238354423354, 0.010649464844215301, 0.00860948953026485, 0.01801120782000644, 0.043752258117761345, 0.031749571733657396, 0.06722298195405353, 0.03156486793511337, 0.08165898192073069, 0.06170107765243419, 0.024994918963901942, 0.015780039942793308, 0.100095477706242, 0.02474493681332998, 0.025508521545317867, 0.06574014982869548, 0.08965060430308504, 0.04181449616988821, 0.103461307984206, 0.14288391677602647, 0.038003591790554986, 0.0540382563767414, 0.04653383910115208, 0.08276098407804966, 0.02350185190387551, 0.04457503271799895, 0.10782980179834752, 0.04189175613705189, 0.05003885606363897, 0.06792869448902146, 0.02571725752204657, 0.012714542944224612, 0.07611972955806602, 0.08393141320876538, 0.03909404134197582, 0.03827732266677964, 0.08079161717286033, 0.016444251579683156, 0.10504897924200182, 0.08794378339042587, 0.014374115384153783, 0.09942808488924658, 0.10623520510571619, 0.046434990776282166, 0.06734549473490446, 0.0545458241005338, 0.008440077804299373, 0.01195169844469356, 0.07128003038345807, 0.017498903757622166, 0.037856855309538306, 0.021787749325496056, 0.060631086479031274, 0.051744585301006035, 0.008049490748934688, 0.037586602472489884, 0.09521191233708974, 0.0855397918231545, 0.04593168633178838, 0.057187862168516845, 0.12022256100129698, 0.23207286883506084, 28.761067582714944, 88.1993256845782, 84.89636052039363, 82.06921023707237, 43.46809848662346, 27.17038566066373, 62.16646855877292, 103.28130183681365, 95.48835246793686, 58.20690255011282, 37.84669483861616, 53.168127767501346, 35.539203689944365, 2.8187225807097653, 0.2298890892416239, 0.143226174217078, 0.2703264734197048, 0.582395545657604, 3.0079612520433243, 2.701153212016629, 1.3882612677351123, 3.221395063784815, 12.83382163893792, 20.601896316774432, 35.60575454465805, 37.854602336883545, 9.802078566243573, 2.393009359798124, 4.342486906436182, 2.5222754814932427, 0.5341486152141325, 0.9433672889586419, 0.5956164459067007, 0.19376251245698622, 1.240600945968782, 1.305998623851807, 1.4257623135082185, 0.847813509885342, 0.2340957546426404, 0.3193023824884046, 0.4659250841265725, 1.182447272923685, 1.1377848372344048, 0.2738561775655516, 0.19218150616413165, 0.23902640377561893, 0.8025378361344339, 0.26756068150843343, 4.906442348034152, 34.60471468587076, 40.6964183622791, 42.121925354003906, 35.883415206786125, 32.68198451688213, 29.036363055629117, 29.30118383899812, 25.116571841701386, 24.283809508046797, 22.28555606257531, 21.054173054233676, 17.136650931450628, 14.540688087863309, 8.950296659623424, 6.342483845449264, 0.47110157087445265, 1.7180227728620654, 3.08699308864532, 1.0278785541172952, 0.2704714478984956, 0.10422817731816923, 0.1951733859436166, 0.03645575710482175, 0.024695141098251747, 0.057802969484680125, 0.16635073739434444, 0.22441480879581746, 0.20030674194135975, 0.3250008815478894, 0.22727538110508075, 0.2734816218576124, 0.033079542505044135, 2.3424924189044587, 28.040812553897982, 40.75003716253465, 18.738031118146836, 46.38146246633222, 93.37901161563013, 82.44214134831583, 30.798599643092004, 22.150659868794104, 52.342543371262096, 69.44658371710008, 70.74154638474988, 36.177702796074655, 1.420910954475403, 0.22941665814047862, 0.01721921654778623, 0.021587832935995633, 0.03344616920296704, 0.06077100094708224, 0.09301811231360321, 0.05826351090124058, 0.06356536793792922, 0.061658123102519787, 0.021844102753206127, 0.039939036322457176, 0.03923890473801763, 0.08316153314925971, 0.01959799424624972, 0.06232629732919797, 0.012723769515662665, 0.0822626592050637, 0.045864098224668734, 0.08252987067305273, 0.05401291035776658, 0.05184953551619284, 0.11271050199866296, 0.05185657586421698, 0.004292531887204537, 0.060885029304171764, 0.1252103526325476, 0.02459490232379927, 0.11589288486227875, 0.05741616403083167, 0.04072450244078233, 0.060590686832344344, 0.04741756365664544, 0.04018372480547236, 0.15467914271979563, 0.046861341688781984, 0.06363069991611185, 0.07406748726122803, 0.19169068895280364, 0.2587534282957354, 0.17881353235533162, 0.12183415718496808, 0.10554273823095907, 0.19388769122381366, 0.09646222911654942, 0.16084582875332526, 0.24404162901543805, 0.07616761005333356, 0.22515181602249223, 0.23168380342183575, 0.12646976287566847, 0.09374051024356196, 0.11941829891574961, 0.1668748334651032, 0.06528919983294702, 0.2605211915027711, 0.20738836678285755, 0.09400308687960911, 0.211385874858787, 0.14477779337715718, 0.14339543368306853, 0.20906712589485033, 0.26354766781291655, 0.12367875901080909, 0.1836147739161407, 0.11992120499452276, 0.16194268279979307, 0.13679725628706718, 0.18931823722537489, 0.1262183634624366, 0.10774915572255851, 0.13813810933741832, 0.1161348460722835, 0.14517455031314205, 0.26753533931989826, 0.19980801870265316, 0.17406314371093629, 0.2247652633776588, 0.27003217308271316, 0.2181878163208885, 0.2177711564206308, 0.34075400882190277, 28.875671394409675, 99.95810508728029, 105.13302926094302, 104.42978751274848, 94.70427067049089, 49.28269455509801, 51.70768422465171, 91.01482652848767, 105.76571541447794, 89.71927550531204, 51.45183194068171, 58.20962467501241, 39.40472695135301, 3.7454693163594897, 0.49060570977387896, 0.18357833877446192, 1.3727417972780045, 2.5970074197938366, 8.821507596200513, 14.779637898168257, 10.534240930311142, 19.050706778803182, 36.570441876688314, 10.196246370192497, 20.634655952453613, 15.698314847484713, 14.880650697215913, 9.249369540522176, 3.9839834984271763, 2.5175245106220245, 0.4424988814899999, 3.9128944614241203, 2.6663424218854597, 1.166968374483047, 2.2243660736468533, 2.6952988293863114, 1.7415801603947918, 1.2004082962389917, 0.7721142783280343, 1.3124227307496534, 1.2222920574488179, 2.5050589730662685, 1.8436512639445646, 0.401774536097242, 0.2367246313200843, 1.788297305184026, 2.4119191063988596, 0.26070434780370805, 3.715413909765982, 36.38897734303629, 52.57808562247984, 56.0948395729065, 53.550652996186294, 50.78007505786035, 46.588979382668775, 47.06151123969786, 41.96575618559315, 36.706273555755615, 31.01143921575239, 22.863140759929536, 17.460381792437648, 11.771099567413332, 6.36141614567849, 3.6108190061584597, 1.1043023822769042, 2.735374911177543, 2.8799218516195975, 1.0358953884532376, 0.20922968975238262, 0.3685034601198089, 0.21260128867241646, 0.16822576823253788, 0.14907045980855343, 0.11351903119394857, 0.4249680318659352, 0.2693046347027825, 0.8080990828814045, 0.527148655345363, 0.6551240721056539, 0.27908472764876585, 0.07859698977441558, 4.14213861188581, 30.610229776751613, 45.47899569234541, 45.184300176558956, 76.98180983143469, 90.26520667537567, 68.1201244169666, 38.4029536093435, 58.11067504267539, 86.92887783050539, 86.81393669497582, 87.53788071293985, 40.77583851352815, 1.484470143914223, 0.4007064256696932, 0.14427772182370388, 0.11511008856036972, 0.16305001692906504, 0.33632982041566606, 0.16647697336250739, 0.1829031241997596, 0.16390936839724743, 0.1802546356714541, 0.14693748716625477, 0.261819158951121, 0.21096639575496798, 0.32584431370900524, 0.17138575834612693, 0.21780996643487485, 0.12508132810434028, 0.29069901894657846, 0.13854913083055329, 0.1196878852563039, 0.13691344118166354, 0.1755150948320666, 0.15162481145272333, 0.18460209271119488, 0.139682803062662, 0.14456241541812498, 0.15371214057649338, 0.16620508875818024, 0.1892316539681727, 0.17244027837389903, 0.16722881205139623, 0.18028311882047884, 0.297337998185427, 0.19980916783453959, 0.2028718034947111, 0.14575058714516703, 0.19566800295104905, 0.23146744487026047], [0.06752835226155098, 0.04837641079399375, 0.05933774237130439, 0.011305577974135598, 0.05594843915934044, 0.08978653128349012, 0.0453271203854632, 0.021385715958932718, 0.09781111842922627, 0.042734923997833844, 0.057755066006774866, 0.029889933517082568, 0.013515941776154984, 0.024545501144002044, 0.056851507434921886, 0.03803937575749813, 0.03784038058872666, 0.11496495320311478, 0.0731608068810836, 0.072713197028685, 0.04032808258348415, 0.020877809241233815, 0.08622177861510746, 0.021021096411371426, 0.025542413275088036, 0.00894768670531771, 0.07877292186622659, 0.037735526134530385, 0.04111453695523162, 0.016534040914848447, 0.047889921979437915, 0.022999995365558613, 0.024828256535974723, 0.024767086330440738, 0.021486835734498118, 0.027701607191815015, 0.019044658514640985, 0.023294176958921938, 0.06583214166664308, 0.004206183244429168, 0.10756851985089241, 0.05220405419447249, 0.06347405791823423, 0.05772757877205169, 0.172697423446563, 0.439089545078816, 37.46076499262164, 71.77642453101375, 74.99996169920891, 69.35996209421467, 38.99236817513743, 24.653175184803626, 45.12842209108415, 80.07949383028092, 98.62640550059658, 68.65926988663213, 50.998696204154726, 37.46087874135664, 12.902430757399529, 0.55421264181214, 0.09115216727819174, 0.02686291711495048, 0.06482134993758894, 0.28209100988122726, 0.9739320520912448, 1.3090763361223283, 3.2525575593594587, 4.11039805700702, 7.350265277970222, 11.49273483983932, 3.9441341786615314, 1.9574979356219693, 4.936974567751731, 5.061512762500394, 0.19118862557074717, 0.12431904763704348, 0.08408249340831273, 0.04938299670034359, 0.07088873565437333, 0.2170090521535566, 0.20011244672200373, 0.6709873628231787, 0.2691336438780831, 0.4449341524272196, 0.3241553349841026, 0.15502527656574405, 0.08278018990231138, 0.6333799840461823, 0.3142003594867645, 0.19914547522221843, 0.34010415175749414, 0.1498445610125219, 0.06125140319307966, 0.11171183744145018, 0.08879397244703385, 1.9964085831757516, 2.682408450111266, 0.4910708170744681, 0.9974827593372715, 1.0323446628547486, 1.1681032877775932, 0.49514499522985955, 0.20830871417157112, 0.06983711909983428, 0.011744321316420551, 0.23032909950181363, 0.3226526688423849, 0.17895155075577, 0.674180172143444, 0.4836167509277021, 0.34376782935953915, 0.048108077007195646, 0.04242565430280182, 0.05527551135709209, 0.07830011538199841, 0.03110607511424009, 0.08675853045837534, 0.05919259935317021, 0.06655866114963448, 0.10848180390894414, 0.1713507634497458, 0.07501067939184367, 0.09922188466354724, 0.6688914688364153, 7.892826641759566, 14.403420821312936, 26.496243976777603, 53.33475005242133, 84.18776865928405, 68.97684066526352, 42.69378339090655, 41.58582756596227, 62.880920440919944, 79.8339299232729, 61.51918334345664, 43.7650336757783, 7.7349978204696415, 0.14735715013117562, 0.10313738302718248, 0.04617701832865996, 0.09330393205727301, 0.02353479368461957, 0.06021944445467765, 0.10221300601598718, 0.07839730129607263, 0.09071075507710058, 0.016336989694184834, 0.06372557990553399, 0.04293366252715069, 0.06463783357532756, 0.012929926648916257, 0.046364296182629564, 0.051226238720119006, 0.08534473051587421, 0.03407368331306404, 0.07288284719951692, 0.06959325799177732, 0.020791053614248673, 0.05982741811162522, 0.014516493782491214, 0.0765058761762996, 0.038931174879713405, 0.017220787028031006, 0.04780389796642046, 0.041109476944491755, 0.05533643066883088, 0.044085016068551815, 0.014402221234875822, 0.05240220283608764, 0.06370819354009244, 0.03474684094168967, 0.0422032053522285, 0.008203721485070644, 0.019222285575984467, 0.05052965029232925, 0.015853343065828085, 0.03767246560704324, 0.05292017403389177, 0.008145183749166469, 0.02131822744324323, 0.046704052346608335, 0.04346901625995675, 0.027449344014448505, 0.024374743976119547, 0.06230115815396271, 0.07937499802679786, 0.06805216487977775, 0.022149829291588357, 0.0157372280767548, 0.006592015655065377, 0.04756785861607041, 0.036901413433013425, 0.05928652939356624, 0.04646389527366527, 0.043281765219064496, 0.01890702698860438, 0.023154126510264415, 0.02233032535220827, 0.038090711309304165, 0.01360322408858807, 0.10254247744958248, 0.016739950027136553, 0.03392204386933196, 0.01420371348954617, 0.04154365727557771, 0.028471123359556642, 0.04279289387106415, 0.009748665146499632, 0.029581372453380498, 0.04588212044308743, 0.06673018823588087, 0.07613679033613975, 0.07048067126062608, 0.03014333241979682, 0.06450926103899557, 0.03538333360225924, 0.12872763849314184, 0.0781189738923023, 0.07069040315165635, 0.06631849258537255, 0.25080975535656175, 3.129193133884861, 53.99513206174297, 86.56354827265586, 86.42887761515956, 60.24777058632144, 27.053716721073275, 27.187349911659, 68.61031870688163, 105.27741955172633, 87.84935612832346, 51.079171472980136, 53.43461751937867, 50.05983767970916, 16.407736289885737, 1.0174554682547048, 0.2072124270301673, 0.05266179939010932, 0.17516759734961296, 0.15477206918501085, 1.2811041983865923, 1.3789245558361853, 6.943582661690251, 1.0148790226347986, 8.051471316045332, 11.143563485914662, 12.738268779170129, 9.68477616387029, 5.593414104753926, 5.559454223802013, 0.5100765085268406, 0.09077926632016899, 0.2523451640961632, 0.09265949123448904, 0.09132780059571229, 0.032125217201668894, 0.7533800577925098, 0.6228755090025164, 0.4725500592781652, 0.6997826467117956, 0.6952562315329429, 0.4598206197542529, 0.023049708726184986, 0.18144294529432253, 0.23081993203490014, 0.10192226032696425, 0.38501381934169804, 0.21339961357655066, 0.10476011812927262, 0.08512537656051498, 1.8276581672891494, 3.4629819325862394, 2.9217372594341158, 3.6785781960333552, 4.3785594740221585, 3.3280891708789335, 3.291756501120906, 1.3674300500462133, 0.7390862667272169, 0.6105160593025146, 0.5083393275497422, 0.2471140093140064, 0.09842985700215064, 1.2188310560680207, 2.5390004679079983, 0.24670455064023697, 0.45709671753068126, 0.0397999607206833, 0.06740682773412236, 0.06462710834438763, 0.02415694900968623, 0.05359436971165481, 0.1316063517644521, 0.1259441959160951, 0.08798552752141992, 0.3954535752775208, 0.3312599118198118, 0.09267933291172789, 0.024110886058019056, 0.4740668520812066, 8.51910364243292, 27.96816633593652, 39.820682541016616, 45.46638527224141, 78.65976056744977, 90.37606070118566, 46.92757798779396, 26.840630039092037, 46.617055708362216, 77.24282003218129, 72.47010354072818, 58.92031892653435, 14.175520327783401, 0.26595974160778907, 0.036777533185217655, 0.07400082229005714, 0.11721191972854639, 0.029699081862946192, 0.022688618928734815, 0.09781085795933202, 0.06776199375669803, 0.11792937639139353, 0.04136808141465149, 0.07073331939717455, 0.06567324737026807, 0.005924123444504315, 0.033465654649321115, 0.03129086126723597, 0.06079444323756522, 0.0687375147977183, 0.043425414365746325, 0.08487541739258074, 0.050590653873739705, 0.032364215566626484, 0.020281415537840897, 0.010711851214329082, 0.11490700631252221, 0.00546454394709379, 0.020791499860464566, 0.03940470531703003, 0.010465520430326222, 0.05024734306179228, 0.034394884827516736, 0.03628433344044513, 0.061575914207365245, 0.04888384062195978, 0.018914249282510533, 0.01923111282409199, 0.08170726078171885, 0.10669258257914936, 0.02973624670337285, 0.030355416200754624, 0.14731078648999815, 0.15185175733941217, 0.09121525461875624, 0.08077489347347329, 0.1084421741806211, 0.24115168489515784, 0.08086398183818787, 0.09298323999128996, 0.13732237891564447, 0.14230810977037878, 0.1730113969214501, 0.16514178936279592, 0.0932574688246654, 0.1339863724405727, 0.1413141872974173, 0.12965846596465957, 0.19420357991851148, 0.26972077366325165, 0.22198116196499718, 0.1470601838082075, 0.18216262361215008, 0.10377416297072366, 0.17201316903435415, 0.05079072156560518, 0.21575698869362955, 0.08892331107129013, 0.14027406972262169, 0.1708420504245066, 0.1090915562705167, 0.15687678850466208, 0.11628856927516962, 0.14009673568990924, 0.1613885867259195, 0.14372117426847258, 0.12282572776800203, 0.18408331329063063, 0.13677022870509856, 0.0912555508435734, 0.16094102283879635, 0.11067729698674333, 0.2753978835478906, 0.13439581579258367, 0.23196616810896706, 0.1870434770300504, 0.41851607001116203, 2.946125331424898, 58.836819510306086, 101.07416845137074, 102.94239336444487, 88.46323843925231, 54.70141364682106, 35.15271686738537, 60.72348740793044, 100.15092880495133, 117.59529359879033, 79.61441839894941, 67.10401873434743, 60.01612717105497, 22.415670887116466, 0.8003169165984277, 0.33512626564310444, 0.2240758761763573, 0.2294505345484903, 3.578043190702316, 6.977971551879761, 5.619645935873832, 21.0015485748168, 11.146955355521172, 12.602550848837822, 34.52438062237155, 21.45395475049173, 14.7115739891606, 14.173855281645253, 9.160406262643876, 0.7933425134228123, 0.25888819848337485, 0.38038005992289514, 0.19827221159733113, 0.1953069150688187, 0.21188282077350926, 0.8240961019069919, 1.5184621392719209, 0.7706785682708986, 1.2582155749682458, 0.9783698462190168, 0.7051988883364586, 0.14547191500183076, 1.2433097102949697, 1.921849719459011, 0.2518730547519461, 0.9652592626310165, 0.5409808937580355, 0.151477707249503, 0.25804228419738434, 2.326760527587706, 6.3717452172310125, 7.595630124691994, 6.0340963159838035, 6.016404955617844, 4.470556214932473, 3.364262494348711, 0.7751366484069055, 0.3698272906964825, 0.2738750233284889, 0.36625419533060444, 0.32231862386388166, 0.5169314326297852, 1.3067351714257271, 6.267581774342445, 0.7347461641315491, 0.8483648480426881, 0.2960737692492624, 0.25411209992824063, 0.2508010066324665, 0.13594201105015893, 0.14348636831968062, 0.42131492627724526, 0.34381728799593064, 0.580752746712777, 1.3387756650486302, 0.6487273605119798, 0.5936211239426368, 0.37977809867551254, 1.1966254153559286, 16.693250517691336, 39.702285797365256, 58.88309563359907, 70.70875537010932, 104.09644880602437, 88.63125708795364, 57.575157765419256, 52.812906157585886, 75.3152104346983, 93.38695833759924, 87.63466127457158, 72.53386559024935, 13.960386168572212, 0.32398452802050504, 0.21652558938630168, 0.20411534805692014, 0.2032819363258539, 0.08509726113369388, 0.19646416748723677, 0.19943966830690063, 0.1688541288697912, 0.16054860196046292, 0.12491251296934583, 0.11783468792395246, 0.22781795521657314, 0.17045892985357394, 0.19554179762640309, 0.1241735139140679, 0.20397477092281466, 0.12875339436915614, 0.13292201584385288, 0.24909092984612913, 0.17692193869621525, 0.06860781611213762, 0.22039575832745723, 0.12604079194246762, 0.19032156725804653, 0.10899782541298098, 0.19679076609111604, 0.18057141302814408, 0.1073249345344882, 0.10672237573852462, 0.1297275364519127, 0.1210580641523965, 0.19906989298760894, 0.15093073579332522, 0.17459286286705927, 0.24876195636968462, 0.09928425188146292, 0.1760009018283698, 0.10970798125790973, 0.10944865283466156], [0.04186904929097622, 0.01358784678872795, 0.08860596680953618, 0.07791578439214537, 0.04044416405621075, 0.03599804255270189, 0.05182311314368441, 0.04789271436992192, 0.01889821123181572, 0.022927402789073608, 0.040115121631853046, 0.04647315727666982, 0.04898516724126474, 0.07858709957931312, 0.018670179415494204, 0.029454609799769618, 0.0786820408557692, 0.03430224564527312, 0.049075588598967566, 0.03238278170747142, 0.06784660050705557, 0.07762824095064595, 0.03652622953297631, 0.08688665100283201, 0.03479841015031261, 0.03693063202644548, 0.03016865162569429, 0.027429707265729387, 0.04299022662903994, 0.02184163020443051, 0.06154075843252002, 0.07658483685865518, 0.0339996524065012, 0.08409223038583033, 0.06299032702020581, 0.014493776402706582, 0.016550666938025146, 0.060574346176919446, 0.02297742258486969, 0.10864902558105607, 0.025564920938303395, 0.12002629693597557, 0.02736931655465836, 0.022140506001549865, 0.08729926595884947, 0.2431003674263916, 0.06685814790187344, 11.594143798274379, 39.354053851096864, 69.05529591345018, 84.52316268797844, 66.50584943832891, 38.18764686584473, 29.73096774470422, 45.13965968162783, 79.53825381494339, 78.23778413957166, 73.41613215784874, 64.43983508694556, 32.54295218375422, 6.221988143459444, 0.19375419274212854, 0.07931250057393506, 0.3655725915826136, 0.5868101732865457, 0.7684086191077387, 0.8902889177683861, 2.127103550780204, 2.139898322282299, 2.4664366197201515, 5.579669629373859, 6.373512244993641, 1.6756872832775118, 1.0950888573162019, 0.20762418396770957, 0.03606249352977161, 0.11171233539860095, 0.04902770810370003, 0.06630531587307492, 0.040080406357564276, 0.15536767190262196, 0.0565897620042726, 0.12167330170350692, 0.04722042242065073, 0.08093536591097232, 0.1517034120737545, 0.043672554330119205, 0.07676296762280888, 0.5271395235773056, 0.050280821104083336, 0.10033720142899022, 0.192454754404964, 0.16985563561320308, 0.15924971520660386, 0.4876426961873809, 0.22051407294648312, 0.4483944490071266, 0.11241211075215571, 0.11648463415763072, 0.2572714771714903, 0.19503749726760775, 0.09321267566373272, 0.4026072736709349, 0.5293209742634527, 0.35476551180885685, 0.12508430818636573, 0.24283931530531377, 0.051782410892267386, 1.3047343949156425, 0.3937651481359236, 0.03855879486147915, 0.09755548254977311, 0.09140321429097846, 0.05708932027881665, 0.0764929369512585, 0.10224515106528999, 0.19846688986064928, 0.23385219996975315, 0.5526990359348636, 0.40755154384720715, 0.11259760362126174, 0.49482100132492285, 4.385208872056777, 16.67174220085144, 27.754679572197702, 38.12108424402053, 55.31092251500776, 65.09302346937119, 36.36224639031195, 42.53333883900797, 67.03807584701046, 65.71200486152404, 66.1239282546505, 53.518599387138124, 25.572572869639245, 3.1123688624751185, 0.2849984667714565, 0.0270218669527, 0.09065963402991334, 0.007103465050609122, 0.0788960398565377, 0.04806892991426492, 0.05608451935733038, 0.0492807163015729, 0.01492172652374833, 0.08328438300879733, 0.036437577838378574, 0.025025608446148616, 0.06498906956685167, 0.03536497813559348, 0.08487051442986535, 0.013301250423424909, 0.07033989494366032, 0.09506971875746405, 0.05610480536556533, 0.07787721186515786, 0.0469155730529418, 0.01754092751070857, 0.07868002604452834, 0.03680027450524992, 0.028959123282543117, 0.019957645713622053, 0.032441789629839124, 0.04319418221712113, 0.026292348235485055, 0.01444553584611464, 0.03940891113973433, 0.05124942054070773, 0.04665899488534178, 0.044226623590915434, 0.05206582128941532, 0.04638355180260636, 0.025969118503252828, 0.04698319180357841, 0.08237898199548645, 0.04900156918372359, 0.039352875638512835, 0.04594895778404129, 0.01148987000042032, 0.041550812536790487, 0.06746354888403608, 0.022200486855581406, 0.029415215643483306, 0.02406080689040884, 0.03391608753572068, 0.018763318470108415, 0.007465403769240385, 0.02356171784471841, 0.017096464364458958, 0.007820760834992172, 0.031959290218148986, 0.026047173286637953, 0.029171733748948867, 0.044249981611726746, 0.04986460170438213, 0.028117956826463345, 0.0199415463758933, 0.08015643835308091, 0.07409195610952955, 0.016770788896528464, 0.03717789073444663, 0.036565146799529755, 0.0063762761982938945, 0.08072314423418815, 0.01727092556745535, 0.01067233544158479, 0.010486567738435922, 0.03600123330890652, 0.01970312449209873, 0.06474715432212239, 0.05957559351959537, 0.034285571741601156, 0.04336305097827027, 0.03781557083129883, 0.028302880875285596, 0.06442093110132603, 0.02090571016343611, 0.10249308776110412, 0.047532457693089405, 0.06009374474806171, 0.17390817944561282, 0.07513568195844851, 0.28875376848924544, 23.066439167145763, 59.982755645628906, 83.00199693249118, 82.57329756213774, 52.464097622902166, 32.43838571733044, 40.13174610753214, 74.24080264183783, 99.47324522079961, 78.02212438275738, 67.56876468658447, 67.89736517014043, 39.96923838892291, 5.879885881177842, 0.31769513002326416, 0.15356400981545448, 0.12688140490002212, 0.31854251519806925, 0.34828293708062946, 1.3311646734514546, 1.5257022217396767, 5.470679709988256, 2.926588005596592, 2.341464512771176, 2.8151233157803937, 2.3147673904895782, 1.6763410933556098, 0.34777836093018133, 0.02696444291711575, 0.08085710236862784, 0.056523054898265875, 0.08344586668235641, 0.02493675948391038, 0.18039240892375671, 0.09931072788012606, 0.10475022027329092, 0.10598426534523887, 0.12889430858194828, 0.17860394602100696, 0.1246389123280683, 0.3849745956399749, 0.7320497797862177, 0.09091787460830905, 0.2484937643091525, 0.05943884299467168, 0.05973225850011072, 0.3533572583429275, 0.41882406800023975, 0.904392228732186, 0.6306854383118692, 0.14370617426691518, 0.12176496412364707, 0.10572177297886341, 0.09143848497901233, 0.18919894201380594, 0.7065287556859755, 1.0110846810763883, 1.1664231650290953, 0.4327865107165229, 0.1674298794880029, 0.6023717479359719, 2.085998582263147, 0.439056542011038, 0.0271454829001619, 0.14563144515118293, 0.11045691647356558, 0.05993116556877091, 0.08029453336231171, 0.07898014098886522, 0.11715091614713592, 0.3371559083461762, 0.39155188947916036, 0.8930654655541144, 0.08253860407538953, 0.22001674398779872, 3.0797109632722797, 21.407972804961666, 38.95814941775414, 43.5439924270876, 66.19687649511522, 99.7646459456413, 55.343109484641786, 40.01566356228244, 52.86852144425916, 61.039324498945675, 73.99517597690706, 65.77242897402856, 40.78410686985139, 6.42618477344513, 0.47583069291806995, 0.011041050686711266, 0.10688839465259545, 0.04292740358880932, 0.044277855720851696, 0.015535996888854332, 0.025499610027538675, 0.02591567046399559, 0.009164323921375459, 0.081099140187425, 0.02867987848848345, 0.05718603887925706, 0.054258724990030455, 0.011895099868847719, 0.038417420995932434, 0.060905510664827404, 0.05969796074374069, 0.09651518111387569, 0.09393653682162685, 0.010452684627154903, 0.016416586229517575, 0.017827576544556408, 0.02781874969631674, 0.028213725477877646, 0.05794869856007638, 0.045895358442419, 0.04174064912442719, 0.03324201826246516, 0.022599710594682444, 0.0201261390916883, 0.0601304863249102, 0.04612888885481704, 0.08764715414614448, 0.02494925246273558, 0.012780842108411655, 0.053410684810050076, 0.030302582947056622, 0.034249849061691956, 0.02182785594355195, 0.03515544542742353, 0.09772982117870162, 0.14263038763836508, 0.15148651726063223, 0.1846097229469207, 0.21367768817130597, 0.1175392461159537, 0.13456941131622563, 0.07590268152735888, 0.1420613988152435, 0.1119854380827277, 0.11054023619621031, 0.12181106729493027, 0.1400849685793923, 0.18418675048216698, 0.13146703101454243, 0.16541028785849773, 0.17000632510790903, 0.1174261715383299, 0.22066359798754417, 0.10570651250741175, 0.13086341501724336, 0.21986038544245307, 0.13089039663393653, 0.1282469106597766, 0.13181189315453654, 0.16540621227074057, 0.07380723187159147, 0.1875891461367569, 0.1742856462876643, 0.07705262546697933, 0.08013442864701634, 0.11023806047535713, 0.08097796806044157, 0.24795998488703083, 0.1761081388160106, 0.14058139355432603, 0.1310839717306437, 0.16281297400353417, 0.12849133867289753, 0.16326996077212597, 0.14453443788713025, 0.2239862132456995, 0.1656903542818562, 0.16204058883651612, 0.2628820906243017, 0.329023823742905, 0.406656262855376, 19.979865281812607, 66.3053535646008, 98.88180671199676, 107.48729075154951, 89.51224496287685, 53.785038148203206, 43.09987421958677, 61.9164292273983, 99.30376745039418, 93.26712992883499, 85.92019327225225, 85.33201033069243, 50.96306931587958, 10.344457049523632, 0.386994248556514, 0.2481748725497915, 0.4014395105261957, 0.7041619117221525, 2.7093114968269103, 7.475557058088242, 6.874380775036351, 13.295611104657574, 14.35613762947821, 12.782660203595317, 14.30473889074018, 9.49370966803643, 6.035509840134652, 0.5017266710919719, 0.10192419086853344, 0.18291421715290318, 0.09428500723574432, 0.19097228234093036, 0.1750700283915766, 0.32814983999536884, 0.22287782191509203, 0.2680595579647249, 0.313886845664632, 0.1684829745922358, 0.3978135857370592, 0.23460273630917075, 0.5404399743964595, 1.0225670520336398, 0.14220729259954346, 0.42015871573840424, 0.32828402795618583, 0.9189706980701416, 0.77691434011344, 1.4175285230721197, 1.246928464501135, 1.1337191779767315, 0.48875468813123246, 0.2811555552386469, 0.3502608841705707, 0.40183861169122886, 0.7838015318397553, 1.4322473397178035, 1.317299585188589, 2.21609894306429, 0.608325660709412, 0.1940262612075575, 0.6136727092727539, 2.6951117813587193, 0.923460218454561, 0.24649758432661337, 0.4111474379897118, 0.21974656009866347, 0.1835034000537088, 0.24141820688401502, 0.27312857789858697, 0.6979596638871778, 1.0898176821008807, 1.2841768851203303, 1.9378110694308437, 0.23526158724581045, 1.1540252883588116, 8.275122411789434, 38.21430329353579, 55.902863087192664, 57.606803447969504, 72.49978019345191, 87.16783646614321, 54.70543015387751, 55.406683260394686, 78.4833872702814, 77.62834195167788, 85.78219644484982, 82.31524482850106, 42.31682008312595, 5.515218713591176, 0.4600074532772265, 0.1085681496788898, 0.17527279654337516, 0.08895868901163341, 0.19768210939101635, 0.11429576774037654, 0.11413211603799175, 0.2112298993574035, 0.1302454272104848, 0.22144903729279197, 0.10129634351018937, 0.13257540702339143, 0.1526688973629667, 0.156998765023966, 0.15363493423548438, 0.1087951415308541, 0.14929941284560388, 0.2163964116405095, 0.1822781343493731, 0.23743750677714426, 0.135209447133445, 0.09189266020492201, 0.15712783551744877, 0.16528864841788046, 0.09367045150288651, 0.0995267187094977, 0.1976250818059329, 0.23890246607122884, 0.12120683842729177, 0.08304904845933761, 0.10578777911441942, 0.13198587172214063, 0.14189426907368247, 0.09837105209308286, 0.18410807325234338, 0.17476258198580435, 0.16708109497783646, 0.15446258498536003, 0.14845132286990845, 0.1260371530248273], [0.09820698670321897, 0.05645641290973272, 0.04372153416155808, 0.0049096506629740045, 0.05033147483763676, 0.011806153230399135, 0.050724654143015226, 0.0175553395397841, 0.02041173475464025, 0.06079580687407044, 0.04283674857428959, 0.07247950190738325, 0.0193904897558593, 0.027069496554172328, 0.06412472320540298, 0.02819835966933639, 0.05380620451403722, 0.04923123851298325, 0.11112093084281492, 0.05311290260344263, 0.028378553125226212, 0.04215902889207487, 0.0768966806091128, 0.06359550200643078, 0.03597980199922477, 0.10916202869867125, 0.011390399229111932, 0.04515800647617829, 0.06252980092540383, 0.005888581752867228, 0.06077726754630285, 0.039530902980796756, 0.04387962023517297, 0.06916950411734081, 0.005827875988137338, 0.022617535545460643, 0.028831240225342974, 0.04170782225687177, 0.021655539786743543, 0.04561535713653411, 0.03870564625568448, 0.04809448660741891, 0.06462992754794898, 0.08425354552004607, 0.08185992678326946, 0.059874482723253394, 0.40819098211584554, 0.12052240015398111, 0.6083203287374589, 19.590479827696278, 49.33177125069403, 67.77024899759601, 79.23164213857343, 51.332615421664336, 34.250822759443714, 42.31593754983718, 52.41654280693301, 67.12845510052097, 77.62041091918945, 65.59778151973602, 49.41120316905361, 18.961263010578772, 1.903644038304206, 0.43552931999006583, 0.39273181810013713, 0.05667360649714547, 1.5443234289846115, 0.9614165043157916, 0.4267453558502659, 0.5210049366278033, 0.4952450156692536, 1.1000750478236907, 1.1198723532499806, 0.28054749593138695, 0.18269839486287487, 0.0714571652333102, 0.10131551869093411, 0.042925227899104364, 0.02616871505104486, 0.01867527581541048, 0.021390431230106664, 0.09662509940925146, 0.045182961790311726, 0.04366820678114892, 0.09399559453970964, 0.13719111741069825, 0.10585234500467779, 0.2473065118876196, 0.1267481975317482, 0.12379079170885587, 0.2636625197145247, 0.12060333734318135, 0.11914826058331998, 0.6132531995254179, 0.02996574557806936, 0.04961165862398283, 0.07793034772358595, 0.0712402704201879, 0.11015903084508835, 0.11162022864746471, 0.03879095397649273, 0.07798063373493572, 0.047581675011784806, 0.10909642092883588, 0.06871417209866547, 0.08974697816395953, 0.21003403610760168, 0.10397618035635642, 0.08969289235650532, 0.14805740045924343, 0.08722984307115117, 0.15248339683298143, 0.07383124106713841, 0.1848773174588719, 0.028635922278608048, 0.2464109857476527, 0.1848882571944306, 0.9005673662308724, 0.08133766166264973, 0.5456588104847939, 2.000208256706115, 8.643053481655738, 18.25603654307704, 40.17404494747039, 45.65126226794335, 48.04049953337639, 42.35812264104044, 35.8385903604569, 53.78094711611348, 60.595618140312936, 58.31816058005057, 64.95751342465802, 37.38194496400895, 8.073639571666718, 0.8046494808889205, 0.26775456304031037, 0.050057399221846176, 0.04199616242981246, 0.08027797054138877, 0.02061713441845871, 0.03643695347672028, 0.04427109499491992, 0.03293410837349873, 0.0353193614301422, 0.03285810096009124, 0.033737328579469074, 0.12963836381752647, 0.0670384926601283, 0.04159226172393368, 0.05073194346961476, 0.07667289100467198, 0.047747035090240746, 0.0907196723405392, 0.06547373509214771, 0.04798232367442501, 0.021090586331763098, 0.043792075537625826, 0.07364882021060876, 0.03893967079479368, 0.04055097586505356, 0.020501656239972483, 0.05318472334634393, 0.04587220726534725, 0.015035056783216856, 0.04387278290044877, 0.013279083669335853, 0.0915256734456747, 0.03761953276191508, 0.021461692728823232, 0.06921526254905809, 0.030058748652077014, 0.04907918921221168, 0.022751874808642655, 0.11620560195297004, 0.04517203737651149, 0.06895891420783536, 0.06758454481079694, 0.003684691154405535, 0.03634200453938496, 0.07420879217886156, 0.06858795911314026, 0.06250178892045252, 0.020562219320826476, 0.04845875375453503, 0.03986347324004577, 0.04144968510034584, 0.05303754253433116, 0.07565610846804996, 0.05218821149619837, 0.018162408678401864, 0.029229741926575382, 0.07092516313517286, 0.050041395645107956, 0.041708212961713155, 0.06085991311157423, 0.0403119296196007, 0.04796704022033561, 0.016665526500512517, 0.017059632772279364, 0.06471166912946971, 0.037179430571174434, 0.04372998028092327, 0.03970785013910744, 0.10695612448598109, 0.062191845068047126, 0.02987488946546951, 0.037086404514529055, 0.05098065774467203, 0.026754937022023147, 0.046535984147340066, 0.05418017033427473, 0.05072401829003807, 0.037477434943279916, 0.07334998463310542, 0.03385367052208993, 0.05769772432564248, 0.021278833286956917, 0.07124292874528516, 0.0470193971188799, 0.14833906034548439, 0.04724745000261934, 0.018525411780442924, 0.19126192486334234, 0.08808585439598368, 2.588125457686763, 36.15054430500154, 73.07579594273722, 81.5721517993558, 78.01451498462309, 43.94482727973692, 28.59662025205551, 50.42259416272564, 71.80323785351169, 86.00468112576394, 78.06934971963206, 63.394943129631784, 52.806183215110536, 18.37195827114967, 3.634056107651803, 0.4438578601806395, 0.40400284072083814, 0.1220061362630898, 0.5709033074878878, 0.7796877009734031, 0.35475555266584125, 2.211181271460749, 2.330110476863, 2.124535869206152, 1.8643042589387588, 0.28079932435385646, 0.26761179489474146, 0.04056915896193635, 0.014720613121866219, 0.07633183632166156, 0.055562748363421816, 0.04058649553166282, 0.09766486458360188, 0.08603593334555627, 0.01082129261997198, 0.079214877989744, 0.06616579594030496, 0.11740021647945528, 0.004947433640594565, 0.26763998693035496, 0.46958560544636946, 0.037665268210994626, 0.16554409277535256, 0.20490565968136634, 0.08708802487460837, 0.0902808648383906, 0.023886060319660653, 0.08200113210947284, 0.2326766993369787, 0.11003899252823285, 0.23469823682981156, 0.26831582969715523, 0.21555628897922657, 0.1652400631217226, 0.1590908285711081, 0.14051406974754027, 0.30773280008185294, 0.12099436394149259, 0.1391074403880104, 0.19144370220601561, 0.23277961558872656, 0.4694935829649049, 0.1962950918823481, 0.23847129646568532, 0.04778001900582064, 0.1908099942750508, 0.20928127811320368, 0.2371407396370365, 0.05509094162393482, 1.216959962921758, 0.10400623398562593, 0.1907542996829556, 1.4016648646323913, 10.617218671306487, 25.937459199659287, 48.755755501408736, 68.60524315987864, 72.05913328355359, 60.284625176460516, 34.36717987060547, 38.96929287141369, 58.211621161430116, 67.6653491297076, 74.91921578684162, 52.96771818591703, 15.851022524218406, 1.355766514616628, 0.33445057609388906, 0.022078761230072668, 0.10125977047268422, 0.019653127678940376, 0.06371615319362571, 0.027505415904846404, 0.021551778923059185, 0.043506259624395645, 0.017864176395138907, 0.04046310941057821, 0.020603551679561218, 0.08010112680494785, 0.07665153247334304, 0.007426083827721737, 0.02199329837645975, 0.05659039785724975, 0.05207829320082261, 0.04685786748004537, 0.056591723189358754, 0.050856658753248, 0.015473033079967625, 0.0100453422712763, 0.06607883730001989, 0.026280496855296438, 0.018594984055286454, 0.01789895104124181, 0.041282953724505446, 0.03720971019638162, 0.0805620589263497, 0.02196822048825843, 0.037701132617169814, 0.03601419934702497, 0.026909615919594804, 0.033769603863719015, 0.027784955642756917, 0.073101029040352, 0.06713831391666206, 0.05250870054888149, 0.04277150852665786, 0.02646933178297214, 0.08906977942153331, 0.22475574856563924, 0.1704549308746092, 0.11058818563939103, 0.1186030587902473, 0.1407445549604393, 0.12680463522912996, 0.07884940042370751, 0.3421997086655709, 0.1027174978967636, 0.18931886541747278, 0.12212026038116987, 0.23549942690278255, 0.13225820065746385, 0.06349093866564574, 0.16138967457077197, 0.17719575384211156, 0.13062407382793967, 0.14192642944474376, 0.23467937574511577, 0.13231570321706035, 0.14806565888706716, 0.1543663796638289, 0.1183712176017223, 0.13291236313600696, 0.14548921326716102, 0.12083944564144458, 0.13833124010312942, 0.16749904190580692, 0.1749119078440051, 0.08984767276072696, 0.1294985068060698, 0.14310983610489678, 0.15364438776047, 0.16594540027360763, 0.22091864397929561, 0.1262492368057851, 0.12795870838266227, 0.21089717205013, 0.1822894111636185, 0.1740710957035903, 0.15235846321428978, 0.19142252753578848, 0.11177363775430188, 0.19125872261581883, 0.17511717344243682, 0.3374373996930738, 0.4753976387362327, 0.3167108602581486, 1.6450114067523711, 34.84151209554365, 80.00601214747276, 99.39876725596767, 102.4619108630765, 74.63015279462262, 50.61543356987738, 56.78596511963875, 71.45909693933302, 87.74039268493654, 92.40190213726413, 82.99390900519587, 75.79028790996921, 31.51840948289441, 4.228725423735957, 0.5434500257815085, 1.5509055338559614, 0.32284863413341586, 1.7976767954326447, 3.536387619472319, 4.942879696046153, 9.749667856001086, 9.720558966359786, 10.227035014860093, 3.693208636776094, 1.647678618469546, 1.3386807927200872, 0.09513556401455596, 0.1687747008738018, 0.14319471864690705, 0.15233348874795824, 0.05413822702042038, 0.22492450241359974, 0.21958178990790922, 0.2382394016510056, 0.15531657383807246, 0.17788609099243918, 0.4388293203326964, 0.24094200663028226, 1.0797173337590311, 0.530329023397738, 0.21082681453516408, 0.7450115584558057, 0.4156609828914366, 0.4821247793734074, 1.295698724927441, 0.10688283285426517, 0.20761401032007512, 0.48589466740527465, 0.31495973648082826, 0.47996569845464926, 0.40075465856540593, 0.274740518821824, 0.4434240705543949, 0.23965022917236053, 0.2753919387055982, 0.5234353965328586, 0.33204061670168755, 0.6337598410825576, 0.5763419801669737, 0.34676197675927994, 0.7039443427516568, 0.4607876372193137, 0.8086346089839936, 0.1487414863321089, 0.37311638194707136, 0.4658888941330295, 0.9749888857045482, 1.348893786630323, 2.318031292769217, 0.24644630240096202, 1.0668405602055213, 5.876585206677837, 24.66185538999496, 47.25813181169572, 71.14598197321739, 67.12406989066832, 67.1835251777403, 61.07090742357316, 49.54315954639066, 65.06594342570152, 74.66249665906354, 79.18041598412299, 89.4076902635636, 59.899162092516505, 13.539788453809678, 1.2528967184405173, 0.3871691617513857, 0.10864801434499603, 0.2587067888629052, 0.19252331927418712, 0.12333933609507738, 0.1234168871756523, 0.12402750521657929, 0.12963359875063743, 0.11484033368047207, 0.11475107677641416, 0.08911728453371795, 0.23448411525497515, 0.3529365534984297, 0.09008358953700912, 0.13296911492943764, 0.15431459212014753, 0.19504782413282704, 0.1765453145508805, 0.1018114303869586, 0.09856467315506551, 0.1337013570892234, 0.14308984121007307, 0.16247551227288862, 0.09616943797276867, 0.07449646585530813, 0.0862931243834957, 0.14544309477411932, 0.08176897682489888, 0.21447700898974173, 0.1278024494287468, 0.17806999805954196, 0.1899792025646856, 0.10885240660319406, 0.26262817844267816, 0.10803128292243327, 0.1130837400353724, 0.18813588776655737, 0.18486064738563954, 0.22203955318658586, 0.11430708285901817, 0.15241651735719175], [0.020989677230376872, 0.02348056423567957, 0.04307397536092228, 0.0638453309394179, 0.0332975251630189, 0.013563051395448706, 0.02208960711986067, 0.023113592798190735, 0.03767255753759415, 0.017800236781758648, 0.04077697563315592, 0.028959142434741222, 0.034396007146325805, 0.07361751019714341, 0.032219804162459995, 0.02621022935566162, 0.020769040077744473, 0.06587518048622916, 0.008669158203467246, 0.05559469422986431, 0.05766011323899992, 0.046608724195750496, 0.017113394907585556, 0.024537394018543345, 0.019578049147141077, 0.04991459277188105, 0.03287628788741366, 0.03474483762176768, 0.008485669611893114, 0.0425083534942279, 0.08660299928798791, 0.05760140409092269, 0.021150312461559812, 0.0319579323273032, 0.024214129812354525, 0.011434324795470364, 0.0648873484122657, 0.0630647256489723, 0.036412174362809434, 0.04082466460644238, 0.03364364368720882, 0.04325086123219902, 0.01727619433715459, 0.06759018321791965, 0.07183591144219523, 0.22991280732375963, 0.04859741949926942, 0.113957233486637, 0.4010889486920449, 0.024283736561154647, 3.903288822020254, 27.47924093277224, 50.14209762696297, 79.80905425164008, 74.13859351988762, 61.68751578177176, 44.79191018689064, 31.810763343687984, 61.907274415416104, 74.06515890552153, 64.39021710426577, 68.99289884874898, 39.36350676321214, 11.17557296829839, 1.1388303940334628, 0.08206334610980365, 0.1714258400663253, 0.43151682723433743, 0.43836933049944143, 0.5548771771211778, 0.9249121082886573, 0.14740700713328778, 0.4287093294964683, 0.03279366147434039, 0.3936552911275818, 0.5282467351325097, 0.0874190055014145, 0.03813867990468298, 0.03377732219955614, 0.04182315296343258, 0.10355084067991666, 0.022985882110773556, 0.17864335358383196, 0.045497483018064694, 0.08250518732013241, 0.027086670330214887, 0.1954204033339216, 0.27541691317192973, 0.10141485731207556, 0.131489324173139, 0.11062002425352413, 0.05714926282845198, 0.19454219078104343, 0.051725122837289694, 0.022714079860898278, 0.1801521177854269, 0.0650345522069162, 0.15097170617551575, 0.08867144434442444, 0.09315446064236665, 0.030015516395290053, 0.021396722727184816, 0.12301983146537697, 0.11733642433800044, 0.05491031724358759, 0.03186344687316207, 0.14062149059628287, 0.057407078228049704, 0.0736642032561283, 0.762191417236482, 0.2780535120156504, 0.1873263626569702, 0.25209669113880206, 0.9009409719897855, 0.06422214660673373, 0.6118798183818018, 0.1968266956147648, 1.3872128917324928, 3.050350061347408, 10.730870327641888, 20.45994377905323, 29.821107733634214, 48.57144332701161, 51.33086212219731, 46.231757363965436, 48.38620939562398, 53.72621828509916, 70.01165605360463, 76.20288202839514, 78.30426831399241, 44.89662962575113, 11.310616250961058, 0.8061447619430481, 0.5117563861272028, 0.08281549889474146, 0.09356775741663673, 0.1024097373949424, 0.023289657040168683, 0.08139327198507325, 0.031373822843776114, 0.024866273649217143, 0.027505906201117945, 0.03136560846600802, 0.05566158519697286, 0.04171968512837926, 0.09828056178746686, 0.04426746373815883, 0.01921439487036438, 0.029882410533666134, 0.03868015468000405, 0.07387031155127673, 0.07648836340635054, 0.029935586611710252, 0.12507148387451328, 0.02919335275017206, 0.07803222975663601, 0.04172895862270267, 0.06859749690779755, 0.04548164031979057, 0.044480957120897315, 0.04891075712117938, 0.05600865367018888, 0.012247831647043989, 0.02517548971809447, 0.08525193428560611, 0.03137549100023124, 0.03447685623541474, 0.06402540373645964, 0.0811272556142461, 0.08207116020663131, 0.05135021089846569, 0.021750467656660947, 0.025550769379122124, 0.05062883952632547, 0.02419060133698006, 0.006330071520360728, 0.07504403486006683, 0.049873576424415075, 0.03976275949108024, 0.0589022865038245, 0.06474874012412564, 0.024737588114916317, 0.008489065296617488, 0.04403600176315635, 0.06231489411044506, 0.042283709701751514, 0.005782391432852995, 0.02650543559162367, 0.07685926487489093, 0.019927582508253477, 0.07935285808578615, 0.0386470366990374, 0.024251740898997075, 0.09638445587047646, 0.02705157775762341, 0.073564964226417, 0.033442775433462475, 0.06580758088779065, 0.07067434594876344, 0.023131616931829243, 0.030768270559248426, 0.07072440979461517, 0.003422979240102934, 0.04864923385602813, 0.050411554008361795, 0.04082518171579127, 0.07443687187567835, 0.05470412084832788, 0.06578225402101394, 0.08597211056058446, 0.03957896350672649, 0.01772619055343732, 0.04853723946237757, 0.04706050156645718, 0.07948181366608029, 0.02241971823687275, 0.01960947024335544, 0.11954119474056268, 0.04779278203063915, 0.029728304286817872, 0.08193421432928694, 0.029134088188349724, 0.05828507244586945, 0.18563257289990304, 0.2857385996368624, 0.11809648315031683, 10.007421508912119, 46.04886116520051, 70.30832844395792, 85.03361994220366, 66.99795784488802, 58.53783292155112, 40.26032532415083, 40.50418692250406, 82.86542000309115, 86.31505043275895, 72.90719678325038, 67.04970175220122, 35.317103401307136, 10.255898756365623, 2.988379554402444, 0.5551388114690781, 0.12350115684732316, 0.379496515398064, 0.19028671025749178, 0.24216140410111797, 0.2657097517963379, 0.5860791415456803, 0.7776217763462375, 0.09518817893319553, 0.37602914016573663, 0.37027649401176366, 0.10340481666066956, 0.0909622694035211, 0.07463843726943578, 0.11811195812638729, 0.10147945384585089, 0.08920952151980131, 0.10949056550499894, 0.024312212049300154, 0.09462225446177107, 0.1554355626144717, 0.15224031713460723, 0.17994777149250432, 0.029153493195471746, 0.07456699190961738, 0.4773332671292367, 0.2596867685356448, 0.04042086349199376, 0.0688460617957096, 0.055481929917849844, 0.1612533568855255, 0.02873786176825243, 0.058625261449525436, 0.06332526066070122, 0.14507577093618532, 0.13342184224917045, 0.12296117211301481, 0.08086085619945681, 0.1474635444220997, 0.18080848659719193, 0.03796121946746304, 0.07842989833725077, 0.10179028636024845, 0.13417355836399142, 0.15989618616238718, 0.15529837158899154, 0.26714745368207654, 0.3039632491286724, 0.6261555297720818, 0.5865324817357526, 0.08220333335620743, 0.06864348516589211, 0.8120762436620651, 2.2071174508140934, 12.95244097709656, 29.085812376391505, 45.06611131852673, 68.36200914075299, 78.66435758529171, 54.982290652490434, 38.783592177975564, 35.3205943107605, 58.15359753947104, 82.6913687490648, 84.00257002922797, 57.59486375316497, 21.784096725525398, 1.3701863731107404, 0.57806420710779, 0.059732630052754, 0.025599373827478098, 0.060534969257611426, 0.035623724332019206, 0.07306006631904072, 0.02895050479339496, 0.056583246426476594, 0.042516949000738324, 0.03270664154702137, 0.029694661535623095, 0.0657458801663691, 0.06770444523182607, 0.012561814698030152, 0.017479063995603113, 0.08792267000723271, 0.07364351122129349, 0.007780382255723159, 0.038274668172122016, 0.07613392516730294, 0.08607577757849809, 0.06395675842800448, 0.10855878808445509, 0.057744091797259554, 0.0300850733483751, 0.07409086826467708, 0.02744140542833315, 0.03573192276000496, 0.0738143258457703, 0.04917071756696509, 0.027266754618575497, 0.0821309150647252, 0.021002679657671722, 0.04741303607701294, 0.010576369522529985, 0.05592656734910223, 0.0909341003505453, 0.1055588873644029, 0.019921478702716773, 0.03384433191029295, 0.038080392104964104, 0.01846192224371818, 0.03435204519079097, 0.20190175232147017, 0.09447939438565124, 0.19207914149568928, 0.14126282876297352, 0.17134929256093118, 0.16322183512872265, 0.14829873347715025, 0.12536080463999702, 0.0897767176971801, 0.10408779936692408, 0.1027134376307649, 0.18830804304490167, 0.17370254612497746, 0.16423195270040344, 0.09222072203673663, 0.13682946262340392, 0.18943894203872452, 0.1905245192709469, 0.1218496245001593, 0.11795498671070223, 0.23588953419558464, 0.21194700361980548, 0.20053057751107603, 0.1624111302437321, 0.18275294032308365, 0.10809189579900234, 0.12215125629858625, 0.10651730932295324, 0.12606884608225477, 0.16846267326224237, 0.20724034327412807, 0.1883131451904774, 0.22089287278152284, 0.19122127623808002, 0.08676253709821932, 0.09105864326439558, 0.16427293840435245, 0.16493678423425845, 0.13181518733261094, 0.13460281274972424, 0.12862498271128825, 0.2823228893741485, 0.19827274785887813, 0.20810104305705718, 0.140970581541619, 0.43907361044999094, 0.23724102054632482, 0.2825069956241116, 0.56254718813204, 0.15633776904113833, 7.4825383866986925, 45.39323699089789, 81.62209926113006, 105.82802618703535, 95.06495614205637, 89.51448855861541, 65.05909888975083, 49.91176428333406, 82.90756979296285, 93.85871748770438, 86.16325470709032, 92.02822577568793, 59.78936318428286, 20.333082560570013, 3.214510813836129, 0.5716623474032648, 0.7012157214264716, 1.499749614346412, 2.2435307743087893, 1.9673792441045086, 2.7924248047413367, 2.007099003080399, 2.5443586707115173, 0.1637554306897425, 0.9360021809416433, 1.1888967526535834, 0.19195768591617385, 0.22915785831789817, 0.15076003608203706, 0.15315381569727776, 0.2048172378131459, 0.24532637378621489, 0.3266481238026773, 0.2379308827221394, 0.19483937160863032, 0.1813462956417953, 1.1223483494212552, 0.45787567573208965, 0.24437234917234993, 0.568001672865883, 0.8373426201362765, 0.7061806453331825, 0.3976123497611092, 0.230338828818452, 0.21772972638568572, 0.43939024991085457, 0.2960495608708551, 0.551610394350944, 0.5482690865474363, 0.32051653991783824, 0.2209432813669405, 0.14742033706317026, 0.38285060154814876, 0.2502618492731164, 0.2759893034254351, 0.2442053113613398, 0.4048320849335963, 0.33569194496639315, 0.5688452888881007, 1.9114918430005352, 0.7417524978518487, 0.8536963909864427, 0.6829588655983249, 1.1076806461618793, 1.8179764093891269, 1.038985725852751, 0.22415691295698767, 1.5480040830950585, 9.288109810121599, 29.143035834835423, 47.91179872328236, 64.54234623139905, 80.59974916519658, 76.11538179459112, 65.27930859596499, 64.51398357268303, 65.32697323829898, 84.53922871620425, 95.43197231907999, 99.85865731393137, 68.92242170149281, 22.22416312463822, 1.1390146228574938, 0.6296266435134796, 0.25067264093987407, 0.1696408552027518, 0.1680507018200813, 0.06668151867005133, 0.13518225101213302, 0.14867256906244064, 0.1292285067780364, 0.19156623030862502, 0.09193485632779137, 0.1708667490991854, 0.14093091350889977, 0.22601090702078036, 0.1111460202223351, 0.07095534699938952, 0.13693090798633714, 0.23531771084714323, 0.28086287900805473, 0.13791959041789656, 0.11765345450370543, 0.2880589573854401, 0.1148842381794126, 0.2695886694615887, 0.14565530112914502, 0.22750867019978263, 0.19053032621741298, 0.14470843177649284, 0.14965935159594784, 0.14168120470018158, 0.13055325666021916, 0.16958054876135242, 0.1945191162127641, 0.14463295679419272, 0.11256714396539236, 0.17450175969110382, 0.18009156619589176, 0.2131824582935341, 0.1598662780898233, 0.12150044928515151, 0.15840766200375173, 0.1285121532818002, 0.08987931219199974, 0.11738589829615048], [0.048443102578241984, 0.03640354055190279, 0.027270380129677155, 0.04504660963110867, 0.02171261716754206, 0.10115701509940048, 0.048842548482841065, 0.061313827867589654, 0.023147624339007085, 0.006489982319650271, 0.08028958443432085, 0.05139616085216404, 0.03769772735634639, 0.03583262118721201, 0.009858418732971675, 0.015925125504333167, 0.019659737102507104, 0.09094234345661056, 0.05678569282134695, 0.01943389438242922, 0.010772929489312154, 0.062081302411013076, 0.011236361930176858, 0.061298004321513645, 0.048557939158091624, 0.013190492304162154, 0.05223855496414247, 0.09295996624015032, 0.02635018021288899, 0.043925535714914726, 0.05993804886877056, 0.0283825961542466, 0.048398002982139594, 0.0754814557430725, 0.05056143144986803, 0.008413145983321293, 0.043085064483626236, 0.04883278852268573, 0.031059023909150597, 0.06925578860025253, 0.0523611213711481, 0.06432215938524855, 0.013943466718398757, 0.05424873903393746, 0.02731048483251324, 0.06903918490054146, 0.17000272449466491, 0.07155499466124081, 0.06536997614368316, 0.20239293725500185, 0.1772508662073843, 0.23922322708512508, 8.774061626003636, 34.3210724092299, 60.947011516940215, 72.10521328833796, 68.26322817033338, 56.51998527588383, 35.82393246312296, 32.055462368073, 51.43025105999362, 59.03680939828197, 74.40587166816958, 68.56916519903368, 51.29228168918241, 23.79160696460355, 3.282113354052267, 0.453930537426664, 0.16000664071930995, 0.24380757383281187, 0.06657388331668992, 0.17310734177308698, 0.29740011259432764, 0.2584946437949135, 0.30048358584603957, 0.4335269500170985, 0.5266943958497817, 0.5982935248363404, 0.28356606621415387, 0.20621377013383374, 0.21613995604697736, 0.36124250941699554, 0.4247189920035101, 0.052075979615291285, 0.06347881149380438, 0.5496320488952822, 0.0724490499123931, 0.11231609695260564, 0.33394305816581177, 0.22859314426539407, 0.15530705902605288, 0.3106012171314609, 0.13754809906165447, 0.027808930364347277, 0.060740016520984715, 0.1641790773118696, 0.09787008421675814, 0.037604708960580255, 0.07709048553219727, 0.08500103282952502, 0.04355425503285181, 0.0377076443645262, 0.04790438954988795, 0.12855850160121918, 0.043922452211019494, 0.08373802197316, 0.32738123930269675, 0.029052367674246914, 0.03594294550918764, 0.9153222809395484, 0.13719680178309643, 0.28326903860415187, 0.44636027106354315, 0.14401040310340543, 0.09742841154577271, 0.30546327992793054, 4.360823006399216, 15.543497916190857, 27.996560373613914, 46.15758534400694, 47.8690331212936, 42.76650805627146, 45.1491282832238, 36.21678921484178, 67.29394774283132, 70.00579603256719, 70.55637913365518, 67.52206494731288, 37.48604859075239, 10.620412461219296, 0.38428836472092137, 0.5361549688443061, 0.071698528894734, 0.1721834703799217, 0.20738004706799987, 0.051792500270230156, 0.06569308904750694, 0.03445421067637301, 0.09099624540296294, 0.028284770556755608, 0.07552611100817881, 0.05172079827095713, 0.013470324113093799, 0.04090604995707831, 0.048446278012688124, 0.04959400029732816, 0.06445078554773523, 0.06737414642327255, 0.016183699330975933, 0.02904465891450884, 0.054978127516205275, 0.04535725062352516, 0.06655909781975132, 0.043321563486730864, 0.02715261517873695, 0.01798545768965156, 0.059929116283573454, 0.055752282346328425, 0.029646606755352793, 0.012864592755513807, 0.07249102386976443, 0.008029564802024153, 0.021431489712408474, 0.04236620971031728, 0.018853400833904743, 0.051465878683713176, 0.04672026276708611, 0.02600747461040174, 0.07555318455542288, 0.03160460874618542, 0.008286093173909092, 0.06371262152829478, 0.055647803275215055, 0.08689050442509114, 0.09285963936558655, 0.020836109160295418, 0.0401743363979603, 0.016673599152014624, 0.06092012762242268, 0.0328616019819052, 0.0806720921349141, 0.04141393943779892, 0.02400361076598206, 0.041228963678041776, 0.026002182858064774, 0.023623596681582353, 0.034414025534304886, 0.0761925308935104, 0.0099498245136572, 0.02703343679557645, 0.01637005979465621, 0.009318181189648327, 0.032378916793893424, 0.006570115116530008, 0.011652100609705575, 0.04474569795533054, 0.06777559181735401, 0.04027077154586873, 0.02976825194162948, 0.10242301369867018, 0.09336235392237864, 0.0990410955742963, 0.06645834959682918, 0.016936612458178596, 0.017698431357501015, 0.03527608512329959, 0.05290117122293, 0.02691506280473644, 0.05260214795388522, 0.05168346297596732, 0.0528002314780268, 0.020974152458591327, 0.05622292080173089, 0.07070503543101012, 0.054068172110184554, 0.056190476978137616, 0.017394317434199395, 0.04723950184040493, 0.031182463656389908, 0.08636113766941332, 0.057043106024784435, 0.07652255391041118, 0.20138479619016572, 0.0915469017420565, 0.05897688431545131, 0.23515916129033412, 0.06881046935074753, 1.7939805744155761, 19.005585793525942, 59.45847595891645, 80.35335371571203, 84.36052553115353, 75.81541461329307, 51.38489277132096, 40.52926263501568, 51.78724950359714, 65.24803553858112, 78.06364659340151, 82.80430163106611, 61.56658126461891, 34.63092788573235, 18.031180789393765, 4.142783351482884, 0.9832853114893361, 0.1288966374892381, 0.10662719697481203, 0.39768684415086625, 0.3488052251838869, 0.16327624269310506, 0.4953540453026372, 0.33161218969091294, 0.2435697954628737, 0.24484173124355657, 0.4446646733389747, 0.13082158661657764, 0.06249277206558374, 0.0742189811482545, 0.10641802432796649, 0.3215115962009276, 0.05585116897559455, 0.01680188823581463, 0.1369631449661909, 0.06222246943282024, 0.21290911812215083, 0.2654646343040851, 0.03501130598447016, 0.10358431106132847, 0.5895530744906395, 0.1031531720993019, 0.16225150816382902, 0.014515660661873559, 0.14932034236769523, 0.20235762060169252, 0.09798433856978532, 0.18939993284162016, 0.02920075698996023, 0.14832528608460582, 0.02688133386865018, 0.056927116482608744, 0.1381099173018048, 0.13210198000794457, 0.09275636305251429, 0.18305237344916792, 0.0584442233816991, 0.42287909395752415, 1.8395146343015858, 0.23450893650372184, 0.0406397003380041, 0.45772705467477925, 0.380706045656435, 0.028933037988721367, 0.3177737612878123, 3.7587207988385236, 17.730436978801606, 35.83648404767437, 54.36512531772737, 67.8185647533786, 68.39403921558012, 62.38741174820931, 40.0192250743989, 51.5672202264109, 65.56555532640027, 75.17995142167615, 79.86983529983029, 51.665840379653446, 21.86811781698658, 1.4101760401841135, 1.0534965343052343, 0.02299264092148552, 0.18840447819281012, 0.10531296547982963, 0.045619501672204466, 0.026437740232194626, 0.0975942465987417, 0.05040221922700444, 0.04995186677983692, 0.049824493171106425, 0.03518829144717705, 0.05025633693402333, 0.04965008559426473, 0.04697982867759082, 0.015792499405271825, 0.03336810867392248, 0.03696101890396207, 0.09660984659867902, 0.07445890456438065, 0.00919456332696662, 0.05641339324234475, 0.027617241759153626, 0.030950480741598917, 0.011808735904313866, 0.01420992550500218, 0.07293818939116693, 0.03219783276079163, 0.028894224144037695, 0.04325767558428549, 0.06747969035660067, 0.08967870440814765, 0.04511068905553511, 0.053488224399306124, 0.009047527114049563, 0.04622767589265301, 0.0384438663510786, 0.04104625170810088, 0.04142638453612885, 0.03112409158699936, 0.061409692279994495, 0.03865927878406741, 0.024909718495403087, 0.06509907979277835, 0.02921714744110021, 0.03152731238984533, 0.10437733463702664, 0.13404962065960133, 0.13714244018398947, 0.15821564972641008, 0.21939959887775684, 0.37165744410407164, 0.19679808989167216, 0.1946073848633997, 0.07160788537153313, 0.10013598843567795, 0.1310769543652573, 0.10416673706664194, 0.17163875122224131, 0.11595102327485239, 0.12432391229536265, 0.1095184970707182, 0.1423269402115576, 0.1591962269477306, 0.13092839459498085, 0.13250284317520358, 0.11958598790149536, 0.1673941797907314, 0.11639891657978298, 0.10801245248125446, 0.14468342666664433, 0.1965383401200656, 0.16877106961704072, 0.18529376285451074, 0.16964879187364734, 0.1034252635473686, 0.18069057034388666, 0.14196415161413534, 0.2078809306746529, 0.15388817225973453, 0.18068942121200024, 0.08694633691301269, 0.1705080514112788, 0.2313596716210727, 0.14611135327046917, 0.12954369067184388, 0.1209401019338158, 0.20610806532204154, 0.08235427565992841, 0.17640962505773192, 0.17268600873649123, 0.1777282922017959, 0.2552416199637998, 0.3682694355806997, 0.3023407361920803, 0.25173385657610436, 0.35561789187692827, 0.8339425380672179, 14.216826808068062, 62.138070598725356, 93.4565882528982, 103.05170982114731, 98.01518255664458, 85.65929289787047, 59.04675652903896, 52.8956760129621, 72.53465790902415, 82.54804534296836, 103.70232120636972, 96.69191606583135, 71.58536587992023, 37.883678866970925, 8.489033772099404, 1.6614472409409862, 0.3106174888389726, 0.5157574794946179, 0.7450108230113984, 0.7311488603872638, 0.37626880311196853, 1.0065553241199063, 1.2221433751044737, 0.7132596041887038, 0.9732865770497631, 1.9849469272359728, 0.41362116654073044, 0.19505645028285443, 0.2978560881268594, 0.4425819254209919, 0.9910708485591797, 0.08905304040038779, 0.12706446927040815, 1.139452089705775, 0.149954111585694, 0.21764165691791043, 0.7976247610584383, 0.5079542304719649, 0.5024953330716779, 0.9059910235866424, 0.486348896257339, 0.46745054904491673, 0.20765157927188183, 0.5704720306300348, 0.49200440246251326, 0.38261317557865576, 0.5199572347825574, 0.30289293236790166, 0.32983878807675454, 0.1932359342613528, 0.20050224757963614, 0.3380008420396236, 0.22290569219377734, 0.28146934485243214, 0.5980193266464818, 0.5750580780929135, 1.2072653347446074, 6.088636382933586, 0.5995742399846354, 1.0467887910143023, 0.9671771177841771, 0.6157757738424886, 0.3086603793405718, 1.2236699125459118, 10.76554015759499, 40.22159976343955, 64.46165130984399, 79.39144734413394, 78.81851457780408, 66.49373715923679, 68.25504610615393, 52.47564508068947, 85.27582630034416, 84.75417460164716, 88.84874466926821, 97.44330098552089, 59.724145935427764, 22.771947614608273, 1.2767769660680526, 0.9971807981210371, 0.18444475357330617, 0.24122810982648404, 0.35657534856469403, 0.11948036735937481, 0.1691886794663245, 0.2564261297905638, 0.2063100980294328, 0.11425994546903719, 0.16703543613754934, 0.20563836149390669, 0.13134343038883903, 0.19743837085702728, 0.1691044251164121, 0.17967459986046438, 0.1554271662908216, 0.17012088589610594, 0.2107016970553706, 0.2091621054757026, 0.12795107814693643, 0.10380183406654866, 0.13686807345478766, 0.11345746070747414, 0.11350936316434415, 0.101476144346018, 0.24515020420714734, 0.16368309666793193, 0.12420922893309787, 0.11349414865816794, 0.15504464326846987, 0.12767769967115697, 0.14320020383644488, 0.21679667725918755, 0.16447866365553873, 0.19072446821918412, 0.09594276021685332, 0.106435583063191, 0.18038290943349564, 0.13079664279376307, 0.16816906240438262, 0.14924060793653612, 0.09234624554312999, 0.13479347671231917, 0.14399334998621097, 0.09127109476755704], [0.08312488350296214, 0.06305866589349124, 0.004552569420587633, 0.018179101734271935, 0.015845460978697146, 0.064098741333451, 0.02142224494638222, 0.0642543567735101, 0.023409321889161103, 0.035495220743600404, 0.06942440455238666, 0.031891043275414456, 0.014626220555885907, 0.06730618676350963, 0.057435419650808464, 0.09637537772857374, 0.043049142620856726, 0.059578592753818924, 0.039799006941217574, 0.028901999936469143, 0.0023661389235301966, 0.05650666061668627, 0.09215227974158141, 0.019165361412770806, 0.0618524183218758, 0.023269143120776263, 0.05349715698450323, 0.03533041224844995, 0.07113860289175665, 0.014497907531838265, 0.06715699114025601, 0.04603124328798825, 0.041213082675371444, 0.059508828956994324, 0.07345778852581017, 0.045737092338141896, 0.07141588841594997, 0.023891884503104997, 0.04972880495892418, 0.0669718047063197, 0.05170656818776362, 0.08449775136766896, 0.02828461350873113, 0.06001774116509384, 0.014389217849971067, 0.017408317691015623, 0.15364388214243999, 0.012637043574584589, 0.14839918292578191, 0.044862396128836184, 0.045020152784643636, 0.13939273153101245, 0.23027495240732548, 1.720624284878854, 12.553705573081972, 29.53667117703346, 45.54091422788559, 61.34330034255982, 57.227992703837735, 49.93896592047907, 37.56835560644827, 25.601853362975586, 39.54106461617255, 59.2848640103494, 75.19793941128638, 76.16896137114495, 51.43926858901978, 35.967777544452304, 18.865133562395652, 5.478577892626486, 1.6218355922929704, 0.5920603270492246, 0.03458754061871479, 0.042070128218901735, 0.87291520809935, 0.9683216531430522, 0.4249755088840762, 0.8113643334757897, 0.5189352734915672, 0.3705118362221026, 0.2649433880804047, 0.6473222326847815, 1.296628081510144, 0.2611315797173208, 0.21748028815754, 0.06735523937330132, 0.7733503152285853, 0.6889094688719319, 0.2250826382829297, 0.19494801819805177, 0.024123861672236555, 0.17671229107485664, 0.10275672159848676, 0.09662330676350864, 0.046625532164809205, 0.26430934307075316, 0.37270686198626796, 0.33761577560536327, 0.25025470933366206, 0.3022033919490153, 0.16598997126904227, 0.25825522599681733, 0.2937101734982383, 0.7322007910378519, 0.9753036559108765, 0.31657731581118803, 0.6315988602657473, 0.10992476881872262, 0.12696653259016816, 0.21296374019115202, 0.1106296309960946, 0.31583166711272737, 0.6073171212788552, 1.5162233239220035, 4.442783872927389, 19.483540327318256, 30.36763902633421, 44.08796241206508, 54.83983409020209, 56.419678503467196, 34.057206722997854, 39.55565191084339, 46.45994124873992, 66.91609013465144, 71.08615013860887, 59.762781281625074, 48.5619237346034, 16.144272646596356, 1.1674682315318816, 0.5293731295293378, 0.07623343998866697, 0.05688680876647273, 0.05774740895797169, 0.10940461043989468, 0.008887753731781438, 0.03237429345327039, 0.0024468611293066776, 0.04832573790824221, 0.0366797688747606, 0.024056658524298863, 0.07234334510060088, 0.04137480766662667, 0.051965410145179886, 0.019361336279900807, 0.1124162782704638, 0.07562564115130133, 0.060767496094828656, 0.040216379303244815, 0.11156571383077292, 0.046825124882161624, 0.07759870060028569, 0.08666317549444015, 0.08397167112918631, 0.12970340468229788, 0.02887511216554671, 0.014956534686197918, 0.07239660353309686, 0.03584876649021622, 0.04652893230799706, 0.08492653077888875, 0.07123503037878583, 0.06023362474215608, 0.06522795876428004, 0.08712889566536873, 0.05328277877021221, 0.03735274264228441, 0.04970157819409525, 0.02875895408402768, 0.03566398608287977, 0.07135083222942007, 0.008606855145415232, 0.03637314218306734, 0.0949727243653709, 0.021611112432794708, 0.027978086408468026, 0.029904249785167557, 0.031858850345616384, 0.11762401374477534, 0.03957980237300358, 0.0633217136736118, 0.00872049375527328, 0.08152575156981907, 0.03581978538404069, 0.038216644672737006, 0.041388283153214765, 0.0050946067917280865, 0.0161431024166485, 0.04359194655872641, 0.04665034575267665, 0.06724411065900518, 0.030189048716678258, 0.06389021603090149, 0.018921247495698835, 0.043202965415173, 0.07180182819044398, 0.030973744916639505, 0.042952879842731266, 0.04997029885529511, 0.028332151179652543, 0.07043335767042253, 0.00954250418280642, 0.10883542243391277, 0.0673394886055781, 0.0927702522265815, 0.08828806330359752, 0.06153874745171878, 0.04477010168615849, 0.026360028273155613, 0.05659522421117272, 0.06776387067211252, 0.06756537729093144, 0.03148141606230169, 0.03552949934777233, 0.039560971931824764, 0.023551819988736705, 0.0730749897118057, 0.0502875971517736, 0.015465767693615731, 0.07476220643448253, 0.02158872351320761, 0.02687089975112148, 0.033575684027445894, 0.05821091130435948, 0.0978398314046283, 0.08531154358699437, 0.03442113483024221, 0.052403252376543905, 0.26176280552341097, 0.1722463202332297, 5.169887360065214, 26.469391430577925, 55.93424597094136, 73.02039638642343, 84.49219949783819, 62.731395767581084, 40.231397844129994, 44.56217696589809, 43.37109827226208, 64.03415610713344, 87.93256528915899, 90.58847273549726, 71.35556205626457, 40.48230794168288, 22.07546607140572, 9.607832989385052, 3.2293008460152537, 0.8264613524079324, 0.33151146445062857, 0.11268304540745674, 0.11654024448005423, 0.538590025276907, 0.5905907865493529, 0.2655228876298474, 0.7440225695890765, 0.4836857294844043, 0.1638067739024278, 0.2828367198667219, 0.1326617910977333, 1.0696639312851814, 0.1434376144841794, 0.36664419537109716, 0.12245021445015747, 0.06562976421968592, 0.169130640645181, 0.2467555108089601, 0.0716706432942902, 0.029280255849082625, 0.11254364804875468, 0.061681289601350026, 0.0639662809009033, 0.0665955865875848, 0.2932608476088893, 0.19435039300832058, 0.14861741073189244, 0.18459502938053302, 0.10929783310500846, 0.0472635148663915, 0.09482266306276284, 0.23734594394843425, 0.45775515477984186, 0.6009601849702098, 0.11730846978964345, 0.08097308041948466, 0.05793942889619259, 0.10483216103767196, 0.251529265135046, 0.13933691436484938, 0.2831810610669275, 0.42949631629932317, 1.0282327931734825, 7.124526500701905, 25.826911118722734, 46.01338724936209, 60.174610537867395, 79.60164716166835, 84.59501266479492, 55.036219319989605, 38.34732263318954, 40.0088543276633, 56.40089819508215, 77.94867407891059, 72.47043301982265, 60.08204652417091, 27.197903048607614, 3.154616221304863, 0.5811681502288388, 0.19386205792186723, 0.13418564723143656, 0.04394050124251554, 0.11232265466523748, 0.10781302447280577, 0.07623664223619046, 0.05063784872031501, 0.009573433067529433, 0.028971849918185227, 0.10199428025272586, 0.05663906742307929, 0.019925362768492872, 0.019748555421228373, 0.03216415553564026, 0.04158217617641053, 0.04538999705184852, 0.005281268902528551, 0.04214615861494695, 0.09856007662751982, 0.007173073714629057, 0.013324693671517797, 0.041452094446867704, 0.09407241783675649, 0.031755319308309306, 0.055224627797161384, 0.04296999807739931, 0.08171810092584741, 0.04076233569292292, 0.028361070998794133, 0.14821165992367655, 0.08192002638092927, 0.09028717740288666, 0.019461873828643755, 0.04273067220985409, 0.018807969904775103, 0.057791049156578324, 0.019647797622207194, 0.026133678019827893, 0.0488386529257461, 0.06539991485976404, 0.05488998143963757, 0.09402702712724287, 0.048613243045345436, 0.03579312169383611, 0.03603147846015711, 0.05997725724873524, 0.27336860856702255, 0.1775810654245077, 0.16851315845645246, 0.16685995603761367, 0.13176580530501183, 0.21410202427256494, 0.05759359765497427, 0.13009469175050337, 0.1315439462421402, 0.11676511426846828, 0.223680115154674, 0.17387431835935963, 0.09026997872898657, 0.13513912026199604, 0.20536422459108217, 0.19807201750095815, 0.09203090843173767, 0.17505334299658576, 0.18852493785802396, 0.1428805919544351, 0.10130351409316064, 0.18488684759264995, 0.26013765724435933, 0.1817982721953623, 0.15293601690040481, 0.21352181992223188, 0.1119197537040999, 0.13596205191025812, 0.11798018334253181, 0.1542603224515915, 0.17325083004130473, 0.09995172896813001, 0.16414304053591144, 0.13690830839257087, 0.19676850357603645, 0.09935146843593928, 0.1314457797355229, 0.1578943064856914, 0.16036722298351028, 0.1635347054369988, 0.16444178418286387, 0.15478205897154348, 0.21970365917490375, 0.24612066906786736, 0.12880692859330486, 0.10718447997445062, 0.29175094959716646, 0.16753621249189302, 0.2987426663598707, 0.21666605926809773, 0.12448209412996808, 0.3136036689243009, 0.22926630572445933, 3.0557467524082433, 23.323032779078332, 65.03108139960997, 85.75378279532157, 105.35920096981911, 93.1356599253993, 77.0590256106469, 60.54462732807283, 49.03190605102047, 62.19108535397438, 86.61274263935705, 101.14353949023833, 97.49529592452511, 71.55341425249654, 49.889806855109434, 31.96636376842376, 10.194048862303458, 2.887751392779812, 1.0430620490543305, 0.3165179286752978, 0.20938206464052203, 1.2269240089001194, 0.8331070732205146, 0.4344156426527808, 0.6434401893807996, 1.3606730319799916, 0.623359247561424, 0.3973824314532742, 1.3259414246966763, 3.592062722290716, 0.3038119007983516, 0.2951181511725149, 0.34267275263705566, 1.8735204805289547, 1.953419406087168, 0.785902635224404, 0.3881386919848381, 0.13345558076135575, 0.32641281223585533, 0.1636619526412218, 0.12069258658636002, 0.0928106097384326, 0.9363667162195329, 0.5511224269866943, 0.5644191392967778, 0.8058804309656544, 0.8598962486270936, 0.5706637977592407, 0.6238796970536632, 1.0098686850359364, 0.8609954315808512, 1.1422757059335709, 0.5603203850407754, 0.6753654020928568, 0.19917342210969619, 0.21961672351725642, 0.26794412383629435, 0.20729093572064755, 0.411163158113918, 1.0343630900306087, 3.856458418792294, 14.52761875044915, 45.39049525414744, 68.31377183237385, 83.68288117070352, 81.84567436095207, 85.5462109658026, 56.2028302684907, 58.36570755127938, 65.56231152626776, 76.9992643787015, 90.64897137303507, 86.97024314634263, 70.91790399243756, 25.42612529570057, 2.498329656739389, 0.8150921173153386, 0.2808701415215769, 0.3303152641221401, 0.26290203955384994, 0.18857667943642986, 0.17137374608747422, 0.22246949705145053, 0.12639663212241667, 0.20068246210294388, 0.1044256671241695, 0.178328154368266, 0.23537381912671754, 0.1529059096449806, 0.14020673059407743, 0.11145846152137365, 0.19104005047871223, 0.12141578890863927, 0.15458895884934934, 0.19497654731235198, 0.22041504842139062, 0.17434449716200753, 0.204659546274812, 0.170290099396821, 0.19868085821790082, 0.14332725185780756, 0.1885255354066049, 0.11022343585688262, 0.13253777678455078, 0.19757450468117194, 0.11694489978253843, 0.23260594345629218, 0.21511117657346113, 0.2051022531644952, 0.16627866384242812, 0.19193001482034885, 0.29638562832147847, 0.20599434723056134, 0.21279906193094872, 0.11353243007174424, 0.1285402993521383, 0.17301516607403758, 0.11670985634648993, 0.2396761382659597, 0.28571880392489896, 0.1936294429845387, 0.11201511632891432, 0.10132240582137339], [0.011623703645572308, 0.0335156035819842, 0.03749316655880502, 0.07777739826950335, 0.03815380248030828, 0.016192741083702254, 0.050731889843460054, 0.10071441546202668, 0.07875600664485848, 0.0538130380183218, 0.06852818893328791, 0.034636099101795305, 0.040010803439203775, 0.08389377530904547, 0.08215993447529693, 0.0242781613562857, 0.0199623073586413, 0.02697490959338123, 0.048029989665073734, 0.01399274915456772, 0.04789056166285469, 0.02973709323052918, 0.07843120068672203, 0.016814298860187975, 0.06292786404129959, 0.02336521820736028, 0.04638798362124832, 0.03862510360176525, 0.09048377088601552, 0.01913412609287808, 0.07528980352705525, 0.024355225971028693, 0.010151057616777478, 0.1251504905221443, 0.02663341057937472, 0.05182790119321116, 0.02121755391389372, 0.033342391102304386, 0.08106133374836176, 0.029503654748682055, 0.04586159311715634, 0.0038422151110059917, 0.02583211899975375, 0.09708418525875577, 0.006068187715080117, 0.014778294754515012, 0.12937018707875284, 0.02808331241530757, 0.10458308287085065, 0.04819290592305122, 0.06653345685692565, 0.015570333907230487, 0.09984366460553101, 0.24515377417687448, 0.05170551864730735, 1.9094121287907324, 7.099298796346111, 11.02783493457302, 8.04920614727082, 18.1944808267778, 42.83239603042603, 40.142983698075824, 31.161705217053814, 20.329068014698645, 32.41311976986547, 52.49423319293607, 64.35155037910708, 72.0155792851602, 83.74741984951882, 65.38300429621052, 45.8376415314213, 30.27115264246541, 20.592110003194502, 17.602777557988322, 15.139169212310547, 13.168899916833448, 9.485841393470764, 7.058263449899613, 3.3318757289840333, 2.2247801288481686, 1.1323654699710108, 0.7759213063024706, 0.4462120483719534, 0.9243710050659796, 1.020362802570866, 0.5375252243491911, 0.08328835900512435, 0.30593135964966595, 0.5015389182634893, 0.16691701426621408, 0.28061981463143904, 0.331154344903846, 0.5036219726166418, 0.07322200964535437, 0.1101978408593324, 0.07884186211853259, 0.2243800437258136, 0.2429936820220563, 0.27401187727528237, 0.11867288770454547, 0.336724876636459, 0.41612140173392914, 0.6237753865218932, 0.4873373028972457, 0.9009776829231171, 2.652885750416787, 4.008740273214156, 4.38216217102543, 5.224057253329985, 5.692549069081584, 6.834394662610947, 8.37873770344642, 14.254377618912729, 23.04932390489886, 40.47016036125922, 45.262657365491314, 44.50302762369956, 69.98276387491535, 45.82710212276828, 42.731822536837676, 54.00325136799967, 68.9402606410365, 71.61131628098028, 69.75880438281645, 50.67732072645619, 23.75805501014956, 1.2319300564066058, 0.2907354847317742, 0.06203187824857812, 0.059207833011544524, 0.12786729877153713, 0.20507168625631642, 0.04798203256101378, 0.09885565633134497, 0.023651520586422375, 0.021096096419158484, 0.07979558029722783, 0.03585918145554681, 0.03215996503469444, 0.15011632304278114, 0.0850973530642448, 0.059484053673523093, 0.02777971368613503, 0.05526279429754904, 0.03957362004345463, 0.03652981482446194, 0.02837021425817042, 0.0963100610721496, 0.05029760992094394, 0.06841290802244218, 0.12554656563987657, 0.040027251346938075, 0.016807689436621243, 0.019419287000933004, 0.11725472872175517, 0.06289501036066683, 0.11543457276157795, 0.032093639057430054, 0.04406895503521927, 0.037123900687982964, 0.04693894256507197, 0.0494077145272205, 0.07717896868745167, 0.05605411332761569, 0.19527313059135792, 0.06725571689105804, 0.017054197378456593, 0.01893284223643282, 0.04730274622899391, 0.06421922781174222, 0.03540511348194653, 0.03235340989645451, 0.0743421680864788, 0.14675203260154496, 0.007798103305826625, 0.03010648359063893, 0.0721565192385066, 0.03168212918324336, 0.04177528778992353, 0.05487100927219276, 0.04075065285207764, 0.026079034883408778, 0.035413701327577714, 0.06299250270991076, 0.08974612780636357, 0.05381861130797094, 0.08570825455770378, 0.04595679103306705, 0.07936668597281941, 0.035171969943950256, 0.022564811459291848, 0.05881509420672252, 0.013093480675090707, 0.044379714771264026, 0.07485348581066055, 0.006073164413758224, 0.13022371627871068, 0.05858140291586038, 0.08396053987164652, 0.05313287068518901, 0.15818310631138666, 0.023856309295121222, 0.05270687600357398, 0.10562855540023697, 0.058047048927795504, 0.049115118735860434, 0.04575530990898129, 0.05421455619075606, 0.05211433380722039, 0.11428426876063309, 0.030067934046289133, 0.013444583558837974, 0.03796350240947739, 0.12206985179575221, 0.036217415660259225, 0.044973540164890795, 0.050991907745840094, 0.08956582901338417, 0.045553786650059686, 0.09416967269874389, 0.04623685362598589, 0.02791467539575552, 0.17115256118197597, 0.1075187088140557, 0.018522824318478667, 0.04119017281599584, 0.04535281880488319, 0.030422579129076296, 0.1053995487370318, 0.16252527734444988, 0.12806554700458242, 6.2477742952685205, 19.448113479921897, 41.84781443688178, 49.07671128549884, 61.106342115709865, 53.455539441877804, 35.28124117082165, 33.99479396881596, 32.99258524371732, 55.728109728905466, 78.11659859072778, 78.50179103112991, 78.87818951760569, 65.85551261901855, 38.18519538448703, 21.57691909420875, 10.539526324118338, 3.625413900421512, 0.9659711728172918, 4.158085498117631, 1.400449175027109, 3.1756298292067746, 2.5005168684067267, 1.3002231789212073, 0.7121831587245389, 0.5821385691242834, 1.1070544152490556, 0.4290834868386869, 0.25523348411004393, 0.5471357054287388, 0.4160507990708275, 0.08109671168870504, 0.36929608532978647, 0.25607438818100964, 0.15452658397055444, 0.22406954829010273, 0.23055947746240327, 0.3566228460159994, 0.1635935716331005, 0.15365051646386424, 0.42014765342877763, 0.44909587911059784, 0.1880647181983917, 0.22707503379112293, 0.18233042751108447, 0.4707677710440851, 0.5562699862545537, 0.6464941835691852, 0.5108066516057138, 1.323936848390487, 0.521432291115484, 1.3386434076293823, 0.8191924037471895, 2.7473972209038275, 5.121211236523044, 8.1666929010422, 12.034211177979747, 19.306031503985007, 37.26098691263507, 60.149060218564934, 79.06486295884656, 77.09511141623221, 91.38478448314052, 65.85458693965789, 50.03520519502702, 36.87675153055499, 51.40072345733643, 69.86298253459316, 83.79701429797758, 64.42096064167639, 35.08305949549521, 5.063869126381413, 0.2135281937737619, 0.1604586785599109, 0.07799182627950946, 0.05013467834120797, 0.24320208858097755, 0.06345954821294834, 0.18784622992238692, 0.021264256548977668, 0.0694907401057501, 0.05988308589064306, 0.06203494260027524, 0.05396147904497001, 0.11817460879683496, 0.07751465309411287, 0.040657848960930304, 0.050421248851043564, 0.07614841955083032, 0.010265587761457409, 0.074876690613887, 0.009569684024749985, 0.051709452508798534, 0.0870410483630915, 0.016151199966008147, 0.08281880839457435, 0.04504377510578883, 0.05592601576579675, 0.1435131201099965, 0.05491965202494495, 0.006486419053192461, 0.019227876102611906, 0.017233513663673115, 0.07152192264554963, 0.057607444694205645, 0.036789170060787475, 0.04747957847411594, 0.0845476007089019, 0.08048010284021016, 0.12581524033580097, 0.05668302937861412, 0.005621566116103843, 0.04699687413390606, 0.04677249081132393, 0.047936496294794545, 0.035316071082507415, 0.06440400821907867, 0.022859441214090875, 0.04769771818011519, 0.06909137080994344, 0.03699227529127271, 0.16910974176660662, 0.15097723733032906, 0.16472756562213745, 0.19635355971272916, 0.12742191057411895, 0.1478451174954253, 0.11717959081814175, 0.16318941428776712, 0.17856459974521594, 0.1957799437185449, 0.1418887072753522, 0.10582867288781751, 0.1836060251920454, 0.21569744834015447, 0.20358340724581675, 0.14257682277069939, 0.14153400856641032, 0.14523235930790826, 0.17229561033027788, 0.1367577261501743, 0.23343269022241717, 0.24637844233262926, 0.2584598021161172, 0.21124485339368546, 0.30605791737475707, 0.11017094351231091, 0.1987345150161174, 0.15561383127445177, 0.1251450129934857, 0.11764924102012189, 0.1672480255365372, 0.14436868710383294, 0.1746569078175291, 0.1525766910204003, 0.11883868445311824, 0.14276561747875907, 0.1392641972990767, 0.1781043494420667, 0.15652903055231418, 0.152438075071381, 0.11409011143710344, 0.16322897506817696, 0.18895377855627768, 0.18297351235824247, 0.1845665155879913, 0.133002286536559, 0.3584598329278731, 0.2378057499205874, 0.32429886921759576, 0.16611583951500156, 0.14752689989343767, 0.20274683923250247, 0.30372447484443266, 0.41261829616081336, 0.12366367473958001, 4.063084466803459, 18.908936631294992, 49.991682575595, 65.63302009336411, 79.82140971768288, 93.84120802725516, 68.88869716275123, 54.75838999594412, 38.15490684201641, 50.97486780535791, 74.54260549237652, 85.12183404737904, 91.77920233818793, 102.30383150039181, 85.72613008560674, 67.90167193258962, 43.69987134010562, 29.56331975998417, 24.28456848667514, 19.509312260535456, 17.225112145946873, 10.932927304698575, 9.392511536998134, 3.958558204673952, 4.375966297041986, 1.0651923067146734, 2.0723788872841866, 0.5273380322802452, 0.7084136997019091, 1.3534111313281523, 0.35427196732451843, 0.18230461034803622, 0.3753865149713332, 0.6734270157833254, 0.3575866459117782, 0.6330151423331231, 0.9627890274409325, 1.3085573575189038, 0.3353761328804878, 0.7980844138130065, 0.6254561834277645, 0.5577331529028955, 0.738670801924121, 0.8538081785363536, 0.9921479068936842, 1.3461916413038009, 1.7049156826349998, 0.9179808511849373, 0.40254758009987496, 1.8635304488482016, 4.728783003745541, 5.008969672264592, 7.191152861041408, 11.124297784220788, 11.946263793976078, 16.78392787133494, 23.104293961678785, 36.71714244350311, 57.50604952535322, 80.81504021921467, 76.05238068488337, 77.57219714503135, 97.5250510246523, 73.47035500311083, 63.01807788110549, 69.34030317491101, 84.68733741391091, 85.44561001562303, 95.55403647884246, 76.78827224239227, 35.06356139336863, 3.3681404927084526, 0.34355240543523147, 0.18260615787679152, 0.2223799873383776, 0.29522316650517527, 0.4959667011374428, 0.15307705368726485, 0.29623722176878686, 0.1462786055860981, 0.2171146803565564, 0.14076344668865204, 0.10333867262928717, 0.09232413624563525, 0.3385556735579045, 0.2177749868602522, 0.22853322086795685, 0.1484562564761408, 0.23033197999240893, 0.15274083301905664, 0.1511512618632086, 0.09605221885947451, 0.175586003930338, 0.14540103654707634, 0.1170221597497021, 0.14808939229096138, 0.11569979240096386, 0.09835563840404635, 0.2186183577343341, 0.16455764732053205, 0.17416504872662408, 0.18811642913328064, 0.06750006829538653, 0.15474510289007617, 0.1564308487239384, 0.11583281590813592, 0.1593332647556259, 0.16191419965076834, 0.26631572734444375, 0.3856582218600858, 0.312029940466727, 0.13596715405583382, 0.12370066146456427, 0.23929579093331294, 0.15993602273444976, 0.15803768750159972, 0.21573495600492726, 0.12673892786786442, 0.19013258868888502, 0.2043982949708739, 0.11863996124555988], [0.05479178811994292, 0.05293026341185455, 0.06091217179932903, 0.04179909780261017, 0.06056928999661919, 0.0476457276231339, 0.02810183450609686, 0.035801579304520166, 0.011639352906645547, 0.056032639883098104, 0.06235952256247402, 0.08476816508318148, 0.0025405263905638772, 0.04593374327786508, 0.052557726345595815, 0.029183399352815845, 0.048559501977457155, 0.03960585319286874, 0.0699477115525834, 0.05405344406984026, 0.024284238348745053, 0.0697938274712332, 0.06168856360619107, 0.08128084092130584, 0.007727771646328151, 0.00740749805587374, 0.03477149365109301, 0.0625841318809938, 0.09650926691510024, 0.08317321599010499, 0.07709583282590875, 0.05134438479980154, 0.04785504965712467, 0.0266504445443711, 0.022489120057153127, 0.1600270339798543, 0.08218676287440524, 0.007895705780209674, 0.021878299002926198, 0.017101066637664072, 0.06037510969045182, 0.01260208315216005, 0.031964790729445317, 0.08284150757977078, 0.07929046788523275, 0.08219531241564021, 0.08400832843636313, 0.06034137117826651, 0.05455254269162974, 0.04507659048202538, 0.025766518890797615, 0.08709567809297193, 0.0846244546494657, 0.10523243431722927, 0.12893439030214665, 0.10344839174180262, 0.17676672928275602, 3.8323093662338876, 5.0779724986322465, 4.73045491403149, 9.693136695892582, 44.919940271685206, 59.74198879734163, 53.97622623751241, 33.849525067114065, 35.25820901316982, 28.46621321093652, 44.237785185537035, 48.5798175873295, 72.03497932803246, 80.4819211652202, 76.43904009172994, 81.82084575776132, 75.97048159568541, 64.7192019800986, 54.04968046372937, 42.124851442152455, 30.52470249514426, 26.434874573061546, 13.407348644348884, 11.531830083939338, 10.56613568336733, 11.977521161879263, 16.384333468252613, 12.918292822376376, 9.412417565622638, 5.2548718836999715, 4.092056073488728, 3.0424629103752876, 1.2549037462280643, 1.0890300211406525, 1.1956439647943744, 1.3349756237960633, 0.6740132875500188, 0.901297172231059, 0.5344477572268056, 1.3359956851890011, 0.7945797147770083, 0.8620373111578726, 1.4475857682766453, 1.7697897241000207, 2.45803784458868, 4.4011969431754085, 9.25253293206615, 14.169304351652823, 16.33976455657713, 16.705064696650354, 22.16010101379887, 25.834198882502896, 29.685523163887765, 30.69752016375142, 37.2117611669725, 45.78086914554719, 41.81400752836659, 38.64741140796293, 41.9460972662895, 38.62543829025761, 44.52646770784932, 51.92186132554085, 63.76529332130187, 82.63381188915622, 70.97979114901635, 58.65754365921021, 25.737094725331954, 4.476578033739521, 0.07989469675287124, 0.2827598659261581, 0.1343898096632573, 0.05868384802353479, 0.03658748975384139, 0.019612672490878932, 0.31582848018696236, 0.010092806206235002, 0.017931498286704865, 0.05404721577501586, 0.11243235079511521, 0.036114794352362235, 0.04678596629791203, 0.11831043618580989, 0.0667128516661544, 0.0874455810915078, 0.03117399838482661, 0.07578090419091525, 0.09559042871959748, 0.10616562133955379, 0.01860969485865245, 0.07786781962720618, 0.1695780206712023, 0.09138462133705617, 0.0511572448416583, 0.03233503144715102, 0.04470449774676273, 0.028861749676927447, 0.06262754608366279, 0.07696255650972167, 0.027264755129093127, 0.025871394412411798, 0.07376151940514965, 0.011032255997340526, 0.06674492010666479, 0.04812416102316591, 0.030249079366424875, 0.0849240716366518, 0.01647373830388871, 0.05849729412265363, 0.06185264814825309, 0.032070439999863025, 0.01629393172240065, 0.06000135837483311, 0.02731838702945219, 0.12942745981197204, 0.04147486641041694, 0.04774743728640099, 0.04399140395464436, 0.05218501690955413, 0.021286155172293226, 0.060799112543463714, 0.10472535305926878, 0.03181205769520133, 0.019513416224189346, 0.02173736180749632, 0.034961709452252236, 0.04757099574612034, 0.048362119423766295, 0.04153476299477681, 0.03502885705881542, 0.1749372500325403, 0.029580052866930925, 0.06989682033177345, 0.03409721370365831, 0.024203312650863684, 0.03924505259360998, 0.027910889006189765, 0.009843209972454896, 0.0657849506505074, 0.05076952391274033, 0.11396258078034847, 0.09824364401039579, 0.01489595819880525, 0.02233777747249171, 0.12930788880875035, 0.05072022998525251, 0.07653416014246403, 0.03567494114019698, 0.06518328817741526, 0.09305116134665667, 0.07135346757187959, 0.044085299521083796, 0.044372065383340084, 0.07338783703744411, 0.022317156300789887, 0.03647710414483182, 0.07436161139799703, 0.04390764373144315, 0.021398929060406743, 0.0056194536286526394, 0.0869681550970962, 0.050039338699031266, 0.034869372874738715, 0.02581589325751749, 0.028451130379952734, 0.05516077819911223, 0.11565703703390977, 0.02965503946817931, 0.11444169982907273, 0.09796646573851187, 0.05995425928924834, 0.20935787158387326, 0.051361782656561945, 0.06142574565244779, 0.2802132364482649, 0.09106317084402808, 0.45178230431291366, 8.048238792727071, 9.927484585392861, 2.5239343989279965, 33.6840049682125, 66.46755926070675, 59.95581680728544, 37.037482415476155, 32.87383352556537, 41.19845036537417, 48.55418489825342, 67.37747853802097, 87.71830189612605, 94.18414085142075, 80.19749441454488, 64.81050691296979, 54.05013545866936, 40.92520236968994, 32.37343126727689, 28.54557452663299, 21.023302039792462, 16.6218614193701, 12.521411718860751, 6.92829865601755, 2.518384245134169, 5.098274686644155, 1.211360534352641, 3.085973517548654, 2.0413439913142115, 2.012531363194989, 1.3769889887302154, 1.2890563136146915, 0.6556904868733499, 0.43023500891943134, 0.4137091747214718, 0.47506662746590955, 0.46026556362067506, 0.171622586767039, 0.11207746822507152, 0.19237737952461167, 0.6821646469254649, 0.3068712576022071, 0.15417848893951985, 0.1557426106545233, 0.9235807700503258, 0.7409657561971296, 2.5780748744164748, 2.125654970445941, 6.936525337157711, 7.597258398609777, 12.264052264152035, 21.256785046669748, 33.065894342237904, 38.5640767312819, 53.48753421537338, 62.37683311585457, 79.1309392067694, 71.77893484792402, 74.02265610233431, 58.10485816770985, 53.962643069605676, 60.148236520828746, 43.45295813775832, 50.447489446209325, 84.30008965153849, 86.31683903355753, 75.34119221471971, 38.791429073579856, 9.692408115633073, 0.4589105379437247, 0.4597446544756813, 0.07408750513868947, 0.029549901561451056, 0.06543622742737494, 0.03438224437676611, 0.22714306239879903, 0.030337641045691508, 0.030070437238581722, 0.03889752829807901, 0.10010444859583532, 0.032314121077257785, 0.04709140172288303, 0.08772963883295175, 0.07462940509280852, 0.030372840870592385, 0.06443620689453618, 0.03584225857329946, 0.0717034318574494, 0.04383676527668873, 0.010368714687384425, 0.06250318320047471, 0.04861715392419889, 0.02023719311241181, 0.04601071596205716, 0.06605311972840179, 0.06789846465952935, 0.06289150933885286, 0.055639092855515986, 0.03611161508747647, 0.05201389968034722, 0.0607211133014531, 0.09911199701168846, 0.05851446215303675, 0.10013800324691881, 0.04829195726122107, 0.15662368837623827, 0.07415765580991585, 0.012090106592363408, 0.06581247618962681, 0.040996770089071606, 0.022099070220945344, 0.036437727225523804, 0.030623284589138725, 0.06524363292321082, 0.04556189952117782, 0.06372051989479412, 0.025824678370789177, 0.028117709763107762, 0.04651355692335675, 0.045572567295523427, 0.18468718975782397, 0.24163356952128873, 0.08763311941537165, 0.13991295119687436, 0.1032938258421998, 0.12423761249069246, 0.23184295052722578, 0.1300518521137776, 0.109578596668378, 0.1565943778522553, 0.20571685486262847, 0.1774660449835562, 0.10123702532221233, 0.11323219255333948, 0.13384257773718528, 0.19610698665342025, 0.22339768918050876, 0.1587389184222106, 0.17564243396684048, 0.15125489823760527, 0.2222816063271415, 0.1617396082128248, 0.12603906824463798, 0.17042421074884553, 0.27576606540429976, 0.12956406861062975, 0.1744439813398546, 0.24568553112687605, 0.24736254355840145, 0.27794301149345213, 0.1420077266952684, 0.14925205329012486, 0.15568541453009652, 0.13903814007438, 0.17395851142223806, 0.40205823377736155, 0.1659648282633674, 0.12434577644472161, 0.12526484446660166, 0.23956617400530847, 0.17771726053568626, 0.20177124158268978, 0.1406525631224917, 0.18430261361983516, 0.20820187554965097, 0.1184980204749492, 0.30302849928698233, 0.24858489812862491, 0.14908055684739543, 0.12385173400323238, 0.1389461482364324, 0.35527330552858694, 0.3267345998075701, 0.15049952022250623, 0.37991372688162717, 0.4447860523096977, 0.24118145507189537, 5.712217304014391, 13.082592083561806, 4.614353737523479, 44.15145774041453, 99.18972846000426, 90.08418929192328, 78.79964013253489, 57.374701115392874, 57.30608709396855, 42.747084479178156, 62.77997432216522, 70.2235346455728, 91.18821882432508, 101.8395640773158, 96.06536449924593, 101.72265391195975, 92.94362068176271, 84.0522978382726, 78.8481520068261, 65.24279132966073, 53.37868844309161, 46.66894082100161, 34.73323898930704, 23.564903774569114, 26.211648564184866, 28.64585776482859, 26.648277005841656, 20.807859974522746, 14.769680961485832, 8.2497162395908, 6.020125323726285, 4.0487930659324896, 1.5486339912299187, 1.0478360638503106, 1.181716731479091, 1.5475335212484485, 0.8726535737514497, 1.7117820367697747, 1.3763503778365351, 2.0429913867865843, 2.1717585094513434, 2.4610159041420108, 3.0374952285520496, 4.22305759883696, 8.543076188333574, 14.666037232645097, 25.995086662230957, 32.50344214900848, 38.30412164811165, 40.60905933380127, 51.14365131624284, 57.16075935671407, 63.81131056816348, 71.72656336138326, 78.81775363799065, 85.31461854134837, 76.90970097818683, 67.15479773859825, 70.44565846843105, 60.50341890704248, 64.7382725438764, 72.27988427685153, 78.36197422396752, 101.17986848277431, 98.05451608473255, 90.12627632387223, 43.862222163907944, 8.919633530801343, 0.4805474962678648, 0.33072717427726717, 0.3593075245378479, 0.32417994172823045, 0.16660711637908415, 0.1880086252405759, 0.5467680445121181, 0.11156778226816848, 0.1632343530054054, 0.0971514477785076, 0.2072336017003944, 0.14381279838421654, 0.18524523884538682, 0.3357955200537559, 0.18201446220759424, 0.217885410773658, 0.12525369788730337, 0.26815014020089184, 0.28496861998592654, 0.22128465014599988, 0.1563504861006814, 0.1744479343535439, 0.21808296952757145, 0.18033207183884037, 0.14905470904083024, 0.23468691405029068, 0.20043564389549917, 0.08651849212906054, 0.08333533551664123, 0.28373972302482975, 0.12230029870425502, 0.10688601211915094, 0.18709501942559598, 0.16090057339639435, 0.2867221339575706, 0.12213496160843682, 0.27050763789203863, 0.18527919186219094, 0.16158890339636034, 0.17055162649241187, 0.19997007694215546, 0.15699016951745556, 0.10747417612301727, 0.11389478199904966, 0.15643163013362116, 0.19213788511772312, 0.15996556308481003, 0.14706618993753387, 0.15856204404225274, 0.17341000779021173, 0.17661161179984772], [0.04456232331933514, 0.11571658504826408, 0.004367021488912043, 0.06262886758533216, 0.0892401420541348, 0.01658318545519104, 0.021872122419036685, 0.04708521173245484, 0.07285049530647456, 0.046170456785588496, 0.0556702726340342, 0.001951422133471727, 0.12191971388435173, 0.03687049029394984, 0.07737747739039122, 0.027043263788425156, 0.014172189929071936, 0.07684377457706199, 0.06895304597433537, 0.05826982729617627, 0.018807098479761232, 0.030828335682951638, 0.053733372535075874, 0.028104059991516897, 0.013141788264376023, 0.043629017553382346, 0.02272605381515478, 0.04028736501030865, 0.024128364354011514, 0.04898669175623406, 0.01895734555869093, 0.1433105971063337, 0.041230894219610965, 0.010317319763764259, 0.03363163525899572, 0.03951473469515482, 0.02694668691425074, 0.0713497290628091, 0.06707518827170134, 0.12038589094675357, 0.03823305810651472, 0.013827202342180236, 0.08003590207907461, 0.023607704187593153, 0.016792528556599733, 0.01937803508143031, 0.1130860842644207, 0.11548229237838138, 0.014909685536798452, 0.022948334226384762, 0.06887232328975393, 0.09397088054327235, 0.033035021305324576, 0.04426074514706289, 0.04717239636867758, 0.040393690353319536, 0.16770985398081042, 0.4812151878591507, 0.04259992781425676, 0.4210616882529951, 7.06702063160558, 21.489532609139722, 41.66137633785125, 49.72498101572837, 51.61766190682688, 50.628142049235684, 55.27962200103268, 47.80753820173202, 47.20205760771229, 36.825882311790224, 58.5031238678963, 54.00140785401868, 67.42774763414937, 70.71590977330362, 75.73167201011412, 67.2956500514861, 46.607626330467966, 44.64821415562784, 40.430391450082105, 26.017312772812385, 24.35260395849905, 19.590291553928008, 28.82443347284871, 39.67733560069915, 41.41443175654258, 34.545212330356726, 37.08673169535976, 38.73500185628092, 41.06686661320348, 38.91734892322172, 29.69517807806692, 26.456886914468583, 23.455653998159594, 16.116451274964117, 10.782609331992365, 5.447755417516155, 4.222765382259123, 3.0064163284917034, 5.042535355014186, 4.702523716034428, 6.1037272118753005, 13.22522319132282, 20.91093986265121, 26.011580228805546, 35.95734011742377, 24.965431151851533, 33.21614073168847, 38.224677962641564, 34.40566616673624, 44.87922999166673, 51.71903164156022, 38.16906659833847, 39.97537689824259, 37.95794110144339, 42.72387581486856, 51.68733104582756, 54.74701904481458, 65.47242649139898, 86.37251315578338, 86.27730938696092, 54.149426337211366, 23.048176611623457, 6.051718054279205, 0.1459663175046444, 0.06534949095258791, 0.023745753231548497, 0.05132826630987468, 0.10177243651161272, 0.04041658106049703, 0.14893077133644014, 0.068419749187606, 0.03866044706815193, 0.05290414747451583, 0.019932133070523703, 0.015451135414261973, 0.05217899545846928, 0.10312778394549124, 0.02837701711893803, 0.06901258632781045, 0.03537009177248805, 0.03280234508096211, 0.012037959944967543, 0.10568153038020096, 0.03321096871889407, 0.07899396121501923, 0.036927046734959855, 0.06734383232410877, 0.06715474650263786, 0.03432976735395289, 0.08477918908841188, 0.10470243936945355, 0.07420572782716445, 0.06960570692054688, 0.06823631709501629, 0.06262746947487036, 0.06758374807935569, 0.08027186482063225, 0.014394514390357561, 0.019612371801368652, 0.056324791343462084, 0.11117634964325737, 0.04337549607660021, 0.03334815974437422, 0.014332806965666673, 0.029844012291681384, 0.03392015929303823, 0.05479821559762763, 0.05819889138482752, 0.0024256215810084776, 0.055662665380946094, 0.04587628668354404, 0.037491879531092225, 0.03155761116725062, 0.08617178371716892, 0.04076241613215497, 0.09602693795797326, 0.05688860907309479, 0.03317115129902959, 0.062001897397661404, 0.015505704814718376, 0.04224246352790825, 0.06474450365790436, 0.026114311317102085, 0.025858414967754678, 0.03821758313044425, 0.02616551088830156, 0.07559753338535947, 0.034835320266504446, 0.019155948107401212, 0.018534804018394604, 0.04301276876621189, 0.0434520052775981, 0.038307701883416985, 0.07286863626852151, 0.05329246978245435, 0.011972078298699233, 0.06538323712565246, 0.034438716548104445, 0.1159381913021207, 0.0688700633303773, 0.037805067765856945, 0.08371467161322795, 0.036408336262308785, 0.03673097802205913, 0.07050612070147069, 0.04901151683542037, 0.02742681911425485, 0.15985573671998518, 0.03828077006243891, 0.01844020748150445, 0.04154835339455355, 0.03380377138514192, 0.0497736057807361, 0.07299163168476475, 0.03845542661785599, 0.0726563533047034, 0.07741845543346099, 0.0783429780013619, 0.02159278952486573, 0.046537378427362254, 0.05803468809913724, 0.032158432858845884, 0.08921005778134831, 0.07486463238995883, 0.07388155006112591, 0.034214666473769376, 0.030433089855397423, 0.08136663510794602, 0.023518468350953153, 0.03367167867479786, 0.05294646617145308, 0.06961401897452532, 0.5429944179711804, 0.31363890896881785, 0.18518464129057624, 2.419040169446699, 6.486161245453743, 43.884199203983435, 58.64305834616385, 65.11907192968553, 49.26365929265177, 45.14781428921608, 32.17397874401462, 40.47183913569297, 44.32550507207071, 57.81636391916583, 85.5716279245192, 81.78954524378624, 91.30232057263775, 90.89343701639484, 76.96692051426058, 68.0328046121905, 52.46325823568529, 47.864953856314386, 41.74217324103079, 31.131899126114387, 30.87488974294355, 31.209546366045554, 39.72102688204858, 47.70689802785074, 41.3302537702745, 34.87518172110281, 27.2260715500001, 26.95092904952265, 24.179425431836037, 20.48544506872854, 19.377824606433993, 17.5391076841662, 13.222085295184968, 9.227332684301562, 6.670136096016054, 6.2651513757244235, 9.118048587153035, 6.826053252143245, 1.7120069601843435, 5.101898956683375, 7.915736225343521, 15.3793437827018, 24.68159079551697, 39.383985457881806, 49.75719151958343, 51.86903092168993, 53.24636728532853, 65.50259344039425, 73.40891499673167, 82.67844061697684, 82.71906068248134, 71.43305240138885, 61.62295356873543, 48.56885456269788, 36.88303124520087, 42.15164907516972, 35.93602203553723, 54.32978868484498, 88.24611956073393, 100.27192608002694, 74.43291248813753, 39.995294693977606, 14.624018842174163, 0.5917642493882488, 0.2787941964643617, 0.05193104344089666, 0.08407474825939826, 0.0788189024634419, 0.0359427233436896, 0.07709757184549686, 0.04703070840708191, 0.0597697853170816, 0.04556274604833415, 0.13984191952453506, 0.05185895839766149, 0.10187821027131812, 0.1380242993153872, 0.038151492725216576, 0.04598237070885878, 0.0382507011114109, 0.05406586235509284, 0.014716105652041735, 0.011934660649257562, 0.0461447392139704, 0.06141936414003853, 0.05465802916836354, 0.10644783280910024, 0.04183897650950859, 0.04290988315798102, 0.06665901100683598, 0.09190811985923399, 0.07480336067777488, 0.09527337557125477, 0.09875064865956384, 0.055764593379271615, 0.023754099759483532, 0.061412668531580325, 0.030284397934954015, 0.017319784740046147, 0.030323489486510237, 0.05032472177258423, 0.023212508155754017, 0.07760803921208267, 0.04006582770436522, 0.04182013840745053, 0.12550135113058553, 0.07777253361118418, 0.053089881661318006, 0.05383694379199898, 0.07594534496386206, 0.06774276494979858, 0.04263815943211798, 0.011782054019521081, 0.016107061810250727, 0.07053494859006136, 0.017633017024866516, 0.09595459627528345, 0.1502838511500628, 0.1029949059950248, 0.10185921895167521, 0.1929075889770062, 0.1376826241011581, 0.1279081695622975, 0.10692927310423506, 0.11564063509145092, 0.10076093232078899, 0.14368951951544132, 0.09027543327500744, 0.24819460697472098, 0.07877037079343874, 0.1607058798113177, 0.1610928001783548, 0.12415882800855946, 0.1382384362119821, 0.16662524201937262, 0.11831222117067346, 0.1447962867396493, 0.2286311269046799, 0.19940505645448164, 0.18454477401270022, 0.1436576962230667, 0.244072548324062, 0.14180333443707036, 0.10085192824443502, 0.18838785408485323, 0.1522153579900342, 0.4018924829940642, 0.3063274577500359, 0.13849507566661606, 0.15767650768881844, 0.15615609895077445, 0.3186945376857635, 0.2103533262326833, 0.22701039129207212, 0.127168710854265, 0.30129643577721815, 0.18924438634947424, 0.1583921563841643, 0.2162834289934366, 0.16958362843480804, 0.17931242413338155, 0.1641568301185485, 0.1748006259121241, 0.26773384802283784, 0.24386486188778955, 0.0845196461605449, 0.18729106132541934, 0.17119282676327616, 0.12652130527121405, 0.28653119420332296, 0.11757186613976957, 0.2082863903694576, 0.5548698226771047, 0.9432727230652687, 0.15362230910649224, 1.3429000372848203, 14.359661879078036, 58.159528163171586, 77.8864025300549, 86.84238172346546, 85.75772869971492, 75.65726464794528, 76.7219606522591, 64.18314733812886, 62.48111717162594, 53.61985145076629, 80.13737232454362, 74.7999914230839, 87.73928657654794, 86.27711326845231, 95.72374174671789, 89.88166163044592, 73.21718169796851, 78.67111190672844, 80.51767749171104, 66.48731231689453, 66.73454715359595, 60.17774058926491, 71.28308450022053, 80.18127149151218, 78.63409257704213, 70.58986833018642, 68.20907592773438, 69.84696357480942, 68.680937059464, 64.03313236851847, 52.46556458934661, 48.14890207782869, 44.337589894571614, 38.07778127731816, 34.05970919516779, 29.956262803846794, 28.423545668202063, 34.754662975188225, 42.329622699368386, 52.28985417273737, 52.07081725520473, 64.63714991846393, 71.29955061020391, 73.1244097986529, 78.22578953158471, 64.55761601847988, 74.9428363000193, 79.80143700876545, 75.29217827704646, 80.96970711984943, 82.8769596161381, 63.55543867234261, 67.85623519651352, 61.803084496528875, 67.07424009999922, 70.9240464241274, 69.72477389920142, 79.22375032978674, 105.79999692978399, 113.9691408218876, 90.57736458316927, 47.75277014701597, 14.885440891788853, 0.4604889242158782, 0.3829774657084096, 0.11301068589091302, 0.2317539311104244, 0.15834335658338763, 0.13915084692980015, 0.2084957315556465, 0.2997448932259314, 0.12923593783090193, 0.23324553494251546, 0.2693708859864743, 0.15963681943474278, 0.18541393140631338, 0.28275778216700403, 0.1302673526468777, 0.14565413667550012, 0.2455607966910447, 0.1318643088903158, 0.13226823640927193, 0.11947017072910264, 0.1049318750418963, 0.136148487067511, 0.12724092996288694, 0.18949693489459254, 0.17909715342665875, 0.08176043494454316, 0.16600244318044957, 0.1804480728723349, 0.15053854474136907, 0.19869607272407702, 0.21758885813816903, 0.11962780098040258, 0.18188408936464018, 0.17359959922971266, 0.07378209652679582, 0.10232061072583161, 0.16543815813718304, 0.24109877886310702, 0.1265813052774437, 0.3288724447690672, 0.13111158153943478, 0.08506059616563783, 0.2596529074493916, 0.1241355006312651, 0.13742759343116515, 0.13157702591871062, 0.2645348487121444, 0.17097668271631966, 0.24943170107660756, 0.11872643725045266, 0.1966216138774349, 0.15438833574373878, 0.17759379780580922], [0.06156702375700397, 0.02267735552102808, 0.07145872039179649, 0.03062772406865993, 0.039679397633599664, 0.08495625499035082, 0.051601257911252404, 0.04503142959888905, 0.024715948046275207, 0.08048643072646472, 0.036057701649805235, 0.044034825818192576, 0.13442573918690606, 0.12384567424775132, 0.015881670124438262, 0.05139899920792349, 0.03784026950597763, 0.05204393798785825, 0.06341454820827612, 0.027899066354298306, 0.0796612544405845, 0.07460433103504681, 0.05610180613134177, 0.06379163200636545, 0.029615210556995966, 0.08880680441976556, 0.025077606664009156, 0.08618679137960558, 0.04570109386657996, 0.036270494062093, 0.04378933677329652, 0.001063785741515007, 0.049967682665033694, 0.028015429364337076, 0.025705771948841792, 0.04999116325991289, 0.03912596422578058, 0.03781127690848324, 0.026636930753386794, 0.06814297694232195, 0.08034786840360011, 0.10609387720544493, 0.03338561378299229, 0.05592920269156176, 0.020013822941109538, 0.0629556040850378, 0.04267079477769233, 0.04414537613610587, 0.05680914660314879, 0.037761136453839085, 0.033070479684899894, 0.08962018295161187, 0.1014909451647151, 0.0832932926113567, 0.0518701279595975, 0.06842243049534098, 0.015191350211088937, 0.0981501353183581, 0.07056035972650974, 0.017755977967153155, 0.05201233686098168, 2.6186449297012824, 24.474360212202996, 58.388798544483805, 75.0604054235643, 68.67544574122276, 73.57275239882931, 74.37445348308933, 69.98201077984226, 63.95679912259502, 51.17215518028506, 57.221501181202555, 46.33258188924482, 49.57513078566521, 56.71968098609679, 57.11993140559043, 54.48578919133833, 40.24585962295532, 33.37423970622401, 31.689921002234186, 20.465878325123942, 14.92918316395052, 13.520827716396703, 14.89593029022217, 27.778964927119596, 24.275821601190877, 38.73238171300581, 42.85598516464234, 32.45035286872618, 45.138769303598714, 38.665136598771625, 28.431400214472127, 19.473722634776948, 38.424671772987615, 25.95332714819139, 25.344539996116396, 7.404875457286836, 9.365042198088862, 17.931172117110222, 8.58564861359135, 13.715315499613363, 11.850883518495868, 13.411556366951237, 13.123589677195396, 19.47686445328497, 33.53401745519331, 31.924565030682473, 23.46039222132775, 33.79620828936177, 35.510844953598514, 44.65889476960705, 41.52340304466986, 53.956241761484456, 54.68115852725122, 74.62085677731422, 86.64211334720736, 106.21517196778329, 71.85440909477973, 36.033206601296705, 13.92918469444398, 6.374337413618642, 1.336042631057001, 0.449287370448151, 0.0724123772834578, 0.059079942293465144, 0.03925702654786649, 0.06449247605257458, 0.031014012413159497, 0.051239698884948615, 0.0031888898229226474, 0.053014904636168675, 0.08926729221017131, 0.013704435794704385, 0.04759149625897408, 0.04244970180274498, 0.12194014544929228, 0.04029434024085922, 0.005781280126557836, 0.07758376954664147, 0.03682874999339542, 0.05005631520743332, 0.0218250367399906, 0.04606007883745817, 0.048988901919895605, 0.02378144335272091, 0.024692695362553484, 0.1024891117647771, 0.06369673286474521, 0.07130731843532094, 0.02695016303820716, 0.014567483637121417, 0.03369350451976061, 0.03861998613443106, 0.05647020249236977, 0.09575532914529886, 0.01314617986340196, 0.042257934673539096, 0.027297685418518323, 0.022521477695854924, 0.05404505540706939, 0.09369682024924025, 0.11685493041671093, 0.08099665294491476, 0.0656762580958105, 0.06980591633867833, 0.014610561718713614, 0.019037206394357548, 0.02352365476620053, 0.06681346199325015, 0.037818328747826244, 0.07145388637699428, 0.1123372256575573, 0.03737568697561661, 0.03408680639920696, 0.09332656995543549, 0.04876472161061341, 0.01747725794332162, 0.013657808810802958, 0.0294069993504954, 0.03835643273628047, 0.05456376204928083, 0.10446630042767334, 0.08042546544945048, 0.019640749613303813, 0.08344903828636294, 0.08737081857097727, 0.019781704045711987, 0.09648574035494559, 0.03105190312189441, 0.06231041249608802, 0.02658475442008386, 0.05387303802455145, 0.02082761707565477, 0.10993436023953462, 0.15210392284056834, 0.027109635730965004, 0.07979594035855225, 0.037098730869230725, 0.013669551981072272, 0.044142920824308554, 0.040699183234884855, 0.028275257659955855, 0.01635767789858003, 0.06178577633334264, 0.07385128958811683, 0.10521562634817055, 0.04874857247716958, 0.018596784361908515, 0.05351791413681162, 0.07157927198756127, 0.05420349771156908, 0.018445518386039524, 0.07163050028705789, 0.014773536390895325, 0.08338939068057845, 0.031110935942119652, 0.06542223100099834, 0.11234491718031707, 0.007904815044434322, 0.051122280588794144, 0.08169586905428479, 0.0834062216322749, 0.04188904801623956, 0.022892976712976253, 0.08193471228643771, 0.04489711523356457, 0.07988672177757948, 0.07666699212765501, 0.042855268749859066, 0.04157926121185865, 0.08885116857146064, 0.06119690752858597, 0.025244332294190125, 0.22046337324765422, 0.20285102719020462, 0.07395474210141167, 0.3174308909764213, 8.992817113476416, 40.88273486783428, 70.11825823014783, 81.53793304197251, 75.60728580720964, 69.79638853380757, 62.765696894737985, 57.31313167079803, 43.46999691378686, 56.27569221681165, 55.666191193365286, 62.934045022533795, 73.26187318371188, 77.14227399518414, 79.52767910495882, 60.89289849804294, 63.32804318397277, 57.244286229533536, 54.41224082823723, 51.85582822368991, 60.91360861255277, 64.27405218924245, 67.2406348874492, 65.21047492181101, 67.299266476785, 78.32362128842261, 80.75992307355328, 84.9999346271638, 89.43074595543646, 83.93500328063965, 81.72088023154967, 73.39182915226107, 80.39373059426585, 65.27017339583367, 48.188055176888746, 34.6564938945155, 32.452423880177165, 43.377174023659, 41.68636968058925, 46.1385069354888, 46.600817095848825, 50.493479236479736, 58.78467944360549, 60.88948603599303, 72.27009404090144, 67.38970064347791, 63.308348963337565, 52.36137859282955, 52.665397582515595, 47.61487137886786, 30.612183117097427, 42.66683278545257, 49.723627798018924, 68.56194019317627, 84.9832723986718, 115.81848344495221, 102.82151376047443, 67.21821461954426, 37.134894478705625, 15.91172512500517, 2.774496876424359, 0.4407842541413923, 0.05114848845668378, 0.05306203436527041, 0.07442894286566204, 0.1178432298043082, 0.06776020111095521, 0.11216703156429915, 0.04463849544164635, 0.048529666683246056, 0.023793139600104863, 0.012834203005167506, 0.037494181625304684, 0.06936851843831039, 0.1217216954776837, 0.037438517676726464, 0.05341124022379518, 0.028683061583808837, 0.03217447857041994, 0.030537490402498556, 0.06851385542822462, 0.04278491506533277, 0.02457996743971542, 0.046025604880865545, 0.00879799408252321, 0.08923343112391811, 0.05002334661361191, 0.04143926247413601, 0.07648464787991778, 0.0489779468625784, 0.07098760696188097, 0.018393252037405487, 0.07165388895138618, 0.17697711234852193, 0.02225753359286295, 0.0941180766770436, 0.07081912124469396, 0.02041083651654903, 0.09342100561386155, 0.004680166631231024, 0.13510525917574284, 0.12649970159174936, 0.07060452469534452, 0.147092696579714, 0.04160143945726656, 0.021620768971080263, 0.020805595878271327, 0.08157328732552067, 0.0460224830725741, 0.025781601246806885, 0.05090556197589444, 0.13128749064860806, 0.04687456819679468, 0.07341168535452697, 0.08630908965583771, 0.12976060080672466, 0.16667126858186337, 0.13151149475766769, 0.13036553447525348, 0.14125548964065893, 0.27613403275609016, 0.14819031671410607, 0.08206588186083302, 0.15244512308028438, 0.2434822622566454, 0.1745710140394588, 0.21131726402428844, 0.3427281867592566, 0.20256556750785923, 0.0739399642653523, 0.25032192588813845, 0.10883882386429657, 0.15956178878343877, 0.2765763719235697, 0.12293680285614346, 0.12106884300949113, 0.13500949818520777, 0.10997572898744576, 0.22464967603164337, 0.09667395283618281, 0.13970600020500923, 0.11889398834037206, 0.12753221191345684, 0.12304339632992783, 0.17685035544057048, 0.1539022529557828, 0.15239702808039804, 0.18631653619870064, 0.20546216127132216, 0.11192010610454506, 0.2293696203419278, 0.15480753905590505, 0.16209216187557868, 0.14893640974356284, 0.2507388156147734, 0.1779402687304443, 0.22585882324605222, 0.2319359995665089, 0.193505106914428, 0.19358539292889257, 0.15352446435680314, 0.12418440002347193, 0.20367219683624085, 0.2392180023654815, 0.15686477624600934, 0.15929401041038577, 0.1787021891364167, 0.2134565339093247, 0.1472996628933376, 0.14403580657897458, 0.264993030577898, 0.21812994603908833, 0.23536962096489247, 0.22005990538145268, 0.40108453602560107, 0.12525114681451552, 5.214088549537044, 39.67762977846208, 78.5398615560224, 103.61431106444329, 99.41734360110377, 100.96854686737062, 99.61792576697566, 96.73650556995024, 82.61470994641705, 71.32106873296922, 79.50772208552208, 69.56441171707647, 73.37639070326283, 78.8553064100204, 85.19493133791032, 81.62568430746757, 69.26118112379505, 64.8408386015123, 74.79825773546773, 58.373230657269886, 60.5446037938518, 52.62470299197782, 48.15723711444486, 57.34686405427995, 60.005132767461966, 78.87607928245299, 82.10188358060776, 63.10335413102181, 82.51301857732958, 73.17593405323645, 58.32933933504167, 47.13926830599385, 79.65661525726318, 59.20297668826196, 76.9578206154608, 58.10328529727075, 60.3041232785871, 58.8081979751587, 48.366013111606726, 60.81260365824546, 54.776374063184186, 44.29338086035944, 46.70672109050136, 58.24453769191619, 91.210615558009, 70.53331559704196, 56.25067926222279, 63.5291587921881, 67.37276384907385, 69.62196073224469, 64.15914635504446, 71.93751627399077, 74.3600897635183, 90.96535759587442, 101.94186733615015, 136.30504638917986, 124.2237461766889, 80.86009256301388, 47.14729347536641, 16.3345831055795, 1.8298757773253227, 0.6161140782698509, 0.15782526664195523, 0.15785355060811967, 0.20185609348118308, 0.2598823048174381, 0.2621238474403658, 0.12672117761065885, 0.1407420728355646, 0.18009484505220769, 0.262564470570895, 0.07873988815493162, 0.10765210004343141, 0.17278039076876256, 0.2777427254665283, 0.15176564905672305, 0.1318456776319973, 0.2973769460954974, 0.10994902316240535, 0.25147642039002915, 0.17859098381332814, 0.12745790904568088, 0.14939004104704628, 0.17061861322051095, 0.05962636599677706, 0.2403944069820066, 0.20069007701691122, 0.17531346049039595, 0.19533280884065937, 0.1483742697464843, 0.22635503371636714, 0.09123567086193832, 0.18185620376419637, 0.2179957121129959, 0.1458409855202321, 0.1525112364681498, 0.11472496849995469, 0.20361884647319395, 0.15608031753330462, 0.18614297131857566, 0.16454234088380493, 0.22436744924033844, 0.17173753059919805, 0.22735732186946178, 0.09690506624117975, 0.10055306968429398, 0.11029331073645623, 0.15610163009935812, 0.1386317457523077, 0.1191182146149297, 0.17692163226104554, 0.1929847646744982, 0.12920215335344115, 0.11696037475860889, 0.18450876788025905], [0.010810283936500069, 0.07364747189586202, 0.06523286172699544, 0.08887117878804285, 0.013263223734083436, 0.007231820688297552, 0.022134306435022625, 0.03288787879770802, 0.03161761883435951, 0.055332818564267895, 0.005762170063286659, 0.01678812163581531, 0.05042551213034219, 0.09617315349920143, 0.04082310178707685, 0.13173038139939308, 0.01419887372908453, 0.04534705399325298, 0.014187828656436216, 0.07605193843764645, 0.054915143597510555, 0.014864248862009377, 0.01362236862581584, 0.018192835775534474, 0.05636942362593067, 0.06522731525042365, 0.08599188328991014, 0.03482973548553644, 0.03701335037006967, 0.09176621739301952, 0.06948538515115939, 0.03637525275529873, 0.016508704471972682, 0.06044724835984169, 0.01906512263831833, 0.02551951490703129, 0.03979323446870812, 0.03153839385167005, 0.045723069098687945, 0.01754521951830435, 0.04061132061084913, 0.05398478343962662, 0.031128029278930158, 0.03922130386795729, 0.04693850206451551, 0.058009843867752826, 0.05763267963043144, 0.013700197413263303, 0.1298817039857949, 0.038266367609462434, 0.02984926382440233, 0.02478252683255461, 0.01742737604335191, 0.07369719100214782, 0.05239036294721788, 0.014697215839048788, 0.05131199843280258, 0.09191425622350748, 0.02683508897110099, 0.043012201861147924, 0.07083851859093675, 0.14691326346608902, 0.18054225572174598, 3.5686824542860833, 24.5196420146573, 48.840317879953695, 71.57669744183941, 81.68805783794772, 74.4874491230134, 81.94050158223799, 86.11106364957749, 79.31949538569297, 76.34638586351949, 70.24846523038804, 66.80861719192998, 62.96332551587013, 51.57612008433188, 58.77772900366015, 47.84857796084496, 54.14936357928861, 37.4052869889044, 42.16543228395524, 50.146047453726496, 50.06936511685772, 37.56985395185409, 36.01506563924974, 40.418514513200336, 39.367385987312566, 46.0018241020941, 40.508462305991884, 51.16594999067245, 46.87843853427518, 31.902691933416556, 28.675522650441817, 25.609294099192468, 33.34642617933212, 91.25815468449747, 57.83378708747126, 30.65356412241536, 33.829524901605424, 25.624971812771214, 23.31315232861427, 25.878323585756366, 37.783179898415845, 43.41247143283967, 39.026461416675204, 45.71652658524052, 55.371370161733324, 55.75828060027092, 62.949416791239095, 76.44902644618865, 92.63370636970767, 86.78447185024139, 100.27025515033354, 87.13138980250206, 49.09722135912988, 2.9622457825368453, 4.259429737444847, 6.881339059722039, 1.2684424197481525, 0.2998875387974324, 0.23028128029358005, 0.10846347908579534, 0.019453600079061526, 0.031273501714871775, 0.13390011094029874, 0.07814786306792691, 0.07821835081783995, 0.03973344896709727, 0.07252585022680222, 0.08554039703261468, 0.039970553179662076, 0.02959658695955671, 0.029121447737599095, 0.07459280907266563, 0.1314744161021325, 0.0700133040006603, 0.0216475858788697, 0.09056032605228886, 0.054745933927235105, 0.038570355128256545, 0.10554685212311246, 0.009631508277849326, 0.034271207593020894, 0.06295379611753649, 0.05546320672898043, 0.02767286548811582, 0.002029075079800321, 0.029678493249981158, 0.07161744614882816, 0.04535903177794911, 0.06102602778663559, 0.09856695609707987, 0.03541109662863516, 0.05871531891546423, 0.07746448965683099, 0.09503866921389297, 0.04175315550979107, 0.013405475727913362, 0.05075732779298579, 0.055008499071963375, 0.06156441905806142, 0.03320852106797599, 0.038576127600766, 0.03229600692828817, 0.08924122223810804, 0.016745314557826328, 0.020516336399821505, 0.09390632997477248, 0.060268761364803206, 0.08438220998692898, 0.060343853303141175, 0.0851385532728126, 0.007123230119055558, 0.08757983800023796, 0.05644745351145825, 0.030944114550948146, 0.0652749122931592, 0.01563733116903853, 0.0979920300925451, 0.033232070610768376, 0.01601870697472365, 0.038213568829721024, 0.01599546578232079, 0.03516622045407853, 0.05266463008498954, 0.012451824581911488, 0.023357790984934377, 0.07424205571653382, 0.07784718121852606, 0.1380846976873375, 0.08742429916897128, 0.009099306039241774, 0.06003699678507063, 0.04509639385486803, 0.02247566180754333, 0.011903815076596314, 0.04586652289294908, 0.04333557140442633, 0.03506197887022169, 0.0329860951000404, 0.02061773579747927, 0.05317038984128064, 0.030031052658394463, 0.08797807348591667, 0.09944515332819955, 0.034035271664540616, 0.04614477368792699, 0.014204605024368053, 0.05702825541037226, 0.056187293882812225, 0.03670422240130363, 0.033260661012102524, 0.06801390644883917, 0.0639528245665133, 0.028861314922030416, 0.03998911165962777, 0.022827164014621128, 0.10198933898561424, 0.01589791310365282, 0.0795184173471024, 0.07716927767520951, 0.06833431506229025, 0.01088478694474625, 0.12230290340319758, 0.055694871717282844, 0.030302395255515174, 0.01757692789749032, 0.03299057671439744, 0.09920432592832273, 0.07945861652373307, 0.0315709583341114, 0.16939324026386585, 0.16407321928249252, 0.08165858355501006, 0.03193097752368739, 0.051595994887212594, 0.141435842059793, 1.2053371220827103, 13.61722682752917, 46.4020235307755, 69.59804996367424, 86.92997609415363, 90.85981445927774, 81.90840090474775, 82.01250845386137, 71.85880999411307, 67.58839222692674, 61.44050059779998, 54.63578847146804, 63.18448835803617, 60.5153311452558, 45.98457351807625, 49.23924646069927, 47.81393950985324, 52.46690996231572, 37.7051325767271, 39.39230088264712, 35.539619461182625, 34.06595360848212, 38.200092546401486, 36.773891295156176, 54.115854770906516, 51.35663993896977, 43.58846033773115, 47.07041894235919, 51.821840886146795, 46.017442980120265, 30.629788675615867, 52.72877916213005, 46.41524584062638, 54.45357084274293, 89.4361823604953, 59.797113787743356, 48.30994282999347, 46.21212197888283, 42.3074338513036, 28.149468091226396, 16.81753081660117, 26.892421014847297, 31.200946569442753, 36.71766019636585, 41.88742253088182, 35.291019639661236, 41.93730331236317, 47.083692243022305, 63.820602663101695, 79.3189540986092, 88.8709060607418, 102.34778558054279, 98.66209122442432, 83.58355891320014, 32.54708636191584, 10.468437287115282, 11.849754856478784, 2.4937966225608705, 0.5218801154725013, 0.3146341491130091, 0.00631401623268762, 0.09346102604702597, 0.05630835875748627, 0.06983347252131471, 0.09225796923161515, 0.09847962973459114, 0.07830141773146969, 0.05623637330568126, 0.03840812834941092, 0.11387108689955167, 0.05879344073154273, 0.09413322989618587, 0.0039318019116763026, 0.041885455063874685, 0.08475638265090604, 0.028103100466391737, 0.015193309480955285, 0.059667087400392185, 0.034931253626822464, 0.04360592000246529, 0.03816647357457588, 0.09740923636502798, 0.028689556094186924, 0.06785470571729445, 0.007911173574205848, 0.013518477527184353, 0.054872395891335704, 0.06993364617829362, 0.03798919316801814, 0.017514769438534014, 0.04196565680866761, 0.03536205167972273, 0.10649497785996045, 0.026109061699600953, 0.054014350603064226, 0.06962263746367348, 0.04344961891371397, 0.07437507156282663, 0.005149783795669435, 0.052890951610020095, 0.06822467255856722, 0.05441849645707877, 0.03264095716839356, 0.04672022063225027, 0.05149453420252089, 0.03493970357662728, 0.0826292475985904, 0.02469331206333253, 0.0736771961073241, 0.058929076598536585, 0.023289252928788626, 0.10475991894641232, 0.07884963025008479, 0.03983238539207847, 0.1386006425825819, 0.1576486680536501, 0.1045033254570538, 0.16915514013699948, 0.10517562123676462, 0.0656067279558028, 0.07971625955354783, 0.09109293335988637, 0.12411088622625797, 0.14703240546007312, 0.12590384606512325, 0.08744587986579827, 0.15882606858447676, 0.2736158711054633, 0.32773811370134354, 0.3036103583872318, 0.09785113886239068, 0.17362610587189276, 0.10942213087072296, 0.2408346470685736, 0.18248761343138833, 0.17147307704773643, 0.15552783024407205, 0.14229107197494278, 0.12023399103312724, 0.17136167254178755, 0.13711283854659528, 0.15869754967429947, 0.1442114552182536, 0.1939898720311542, 0.12920887960541633, 0.16309209047786652, 0.15027281948395316, 0.16024300948746745, 0.256438065440424, 0.20096919349124356, 0.12664914236313876, 0.1489985241524635, 0.17466740322209176, 0.10125626178999102, 0.27149766863834474, 0.18760535655723465, 0.18440879340614044, 0.1553203583124184, 0.13522282302860292, 0.22017524757933235, 0.10128187977017895, 0.1708154365300171, 0.272014839274268, 0.14089313005247425, 0.12714287836945828, 0.1850521234014342, 0.23650620433111347, 0.2166509826577479, 0.2942539427068926, 0.04129533753580144, 0.2612872181400176, 0.3462015681209103, 0.27831772041897623, 0.13210017204044328, 0.18504274648524102, 0.42833511086721576, 0.44070157793260395, 6.9314953877079875, 36.083624747491655, 68.48702292288503, 96.36672019958498, 108.3415751303396, 101.92592682376986, 106.88402237430697, 111.37678361708119, 101.45880391520839, 97.3379853463942, 95.18098769649383, 91.54881015900644, 96.56865166079615, 84.67335808661677, 105.13013455175586, 82.06349926610147, 96.84555530548097, 70.40350867855933, 86.2963564165177, 90.78497563638996, 82.57517245508011, 75.44649216436571, 79.08772253221082, 94.92015792477517, 67.60430136034566, 83.71497400345342, 71.33973921498945, 86.08376395317816, 89.74563383287, 57.0865128117223, 61.9084236698766, 59.08902791238601, 66.49924416695872, 170.4524793932515, 103.35655643093972, 66.06111541871103, 80.99931316991007, 68.90517111747496, 54.65860882113057, 56.70236764415618, 88.77680055556759, 89.44645897034677, 70.90212821960449, 78.55280537759104, 86.33016724740305, 84.80644410656345, 85.94273121126237, 96.64185877769225, 109.87468058063139, 110.00888055370702, 124.7448330540811, 117.4942062747094, 102.07440422427271, 45.75735845873433, 14.229542151574167, 10.934084403899408, 1.635301456816735, 0.8256233135058034, 0.3217242315651909, 0.1537039127921866, 0.17312761245956346, 0.12252205051481725, 0.18214849695082636, 0.20409446450010424, 0.2315506726623543, 0.17127606987712846, 0.23625269051521058, 0.34185481588205985, 0.23377332355706926, 0.1049719797447324, 0.23798795627249827, 0.13819372732072108, 0.25686083872231746, 0.18299303227855315, 0.18894820143618893, 0.17794949242905264, 0.1932980946355289, 0.1197050303040493, 0.20278598632543318, 0.16255258071807124, 0.14067317088765485, 0.15427158394407842, 0.19623708370472157, 0.1785998857550083, 0.09405589332022975, 0.11063456460232697, 0.16568539003210683, 0.26640027280776735, 0.14740211949233087, 0.12885332287799928, 0.21479939411003746, 0.2438126606566291, 0.25132640505269654, 0.19299475446103082, 0.15449586384479078, 0.17683189272159533, 0.1092862421947141, 0.10024908599593949, 0.21338128875340187, 0.17299533971855718, 0.11992435361589156, 0.10712444166382475, 0.11789618180163446, 0.1782775925652635, 0.14306379422064752, 0.2696610800921917, 0.11861579883242808, 0.22595982427798936, 0.2411437329025038, 0.13165217914408253, 0.1798355702551142, 0.25243934694557424, 0.16614849018233438], [0.09689907543361188, 0.028183286889426173, 0.09227617148069606, 0.0248593577904807, 0.03956535778519127, 0.06533897256538754, 0.05706636828460521, 0.03242234631832088, 0.09066080614443749, 0.027244070755137552, 0.024146526383476394, 0.0610013137901983, 0.05516456267345817, 0.03376017332137112, 0.07296825834219495, 0.07121951709831915, 0.10106702275093525, 0.006005101332125525, 0.011472482677368868, 0.024582309753543908, 0.07633762794636911, 0.03557847151833196, 0.061829573579973755, 0.13274488099400075, 0.09657390175327178, 0.07777392023032711, 0.05018742349479468, 0.004684398309402769, 0.09292636562379138, 0.013563212273912805, 0.016307026080246416, 0.03917878598815972, 0.10654773067442641, 0.05875451963454966, 0.048873981070374294, 0.05169092850278943, 0.006430204000113713, 0.026554342644709735, 0.03763634073097379, 0.0333913249684678, 0.003828505728198516, 0.10196922151672264, 0.04355026754520593, 0.024931197685580102, 0.05488435452383372, 0.04539906370243238, 0.01785569580181712, 0.01754529038143735, 0.11266359443505926, 0.03680220121637948, 0.08447022582854956, 0.10748383649174245, 0.07176219846212095, 0.04687957841181948, 0.05937380212990027, 0.045422919680394476, 0.07720925214309847, 0.05586593148989543, 0.02105672907594952, 0.03760325722396374, 0.04168917950723441, 0.05037439491359457, 0.003195980684869292, 0.017264159095864144, 0.05518092631152081, 1.1824922576065988, 9.873982475649926, 27.69922314151641, 36.78961607717699, 64.98935914808705, 84.20403865075882, 89.73691832634711, 79.92288143404069, 75.34069015133765, 81.50718165982155, 88.26435073729485, 84.08556738207417, 77.34434666172152, 81.46933863239904, 59.18137227335284, 73.45565395970499, 68.1620780883297, 74.79734774558776, 74.92940610454929, 73.08535083647698, 76.13581734318888, 68.94616773051601, 75.20401908505347, 97.30472364733296, 76.10716050670993, 84.49938527999386, 83.16497141315092, 94.32063933341735, 65.67728796312886, 69.85058784484863, 49.53139243587371, 89.00762419546805, 59.62388230908302, 54.199185525217366, 57.86754692754438, 54.316382023596, 49.151291231955256, 43.15108468455654, 48.705984546292214, 51.22351469532136, 54.27534226448306, 56.58800309704196, 77.68808749414261, 83.30149342936855, 93.98886173002182, 88.18048261827039, 86.87531394343223, 63.16901460770638, 42.20087874320246, 20.558110898540868, 4.735530461034467, 2.0751770081058627, 0.6063996543807368, 0.20395051657913194, 0.12636301618429924, 0.051201356184338374, 0.04501715355042008, 0.10919475597479653, 0.02598988714688007, 0.08832557862924953, 0.1332124550977061, 0.06505766507959174, 0.05484547939211611, 0.06157309117336428, 0.05886290958451648, 0.06107115802625495, 0.06646761926071298, 0.041967307728144436, 0.043628760913927714, 0.03280922455052215, 0.011899534560319398, 0.06621127091949025, 0.03956408607923696, 0.023492455835484212, 0.056541789578454155, 0.11430129889518985, 0.020903752808789575, 0.0452960325374959, 0.05609144479216588, 0.029609633436907205, 0.0655969909782852, 0.016101727923077923, 0.02856759106620185, 0.03910669711448493, 0.07815609085223368, 0.06171530390518808, 0.058261534394395936, 0.08388681923069301, 0.042627131596447966, 0.02350469217485478, 0.09079997367676228, 0.04374848896517389, 0.053012629355033564, 0.046179458318698796, 0.06454417166570503, 0.0485233924231462, 0.0781506899323675, 0.0546742357584017, 0.04977763157277819, 0.013400134179861316, 0.05109245678590191, 0.012615211026352501, 0.042687231194107764, 0.043778251481032184, 0.09047644708545939, 0.03136230279661475, 0.041842462209564064, 0.03511513388084789, 0.07670903503293953, 0.04363223512266432, 0.037908317265851844, 0.07614140984632316, 0.009220651493618085, 0.045289325437718825, 0.0420279014525154, 0.02412242717259834, 0.08908415123099282, 0.08273159694527427, 0.07361737996219628, 0.03892529898533418, 0.023551624636316014, 0.03299819928924403, 0.02023817945061432, 0.02707028179429472, 0.023428707744085023, 0.07627975000368972, 0.04156191315081331, 0.07237236451117263, 0.04665508783692795, 0.05658333452658788, 0.06002216915329618, 0.04737869235536745, 0.03614711943232725, 0.013869614884888214, 0.022608583808065425, 0.025626409070325956, 0.05051375779834005, 0.04633941747728856, 0.057518873438839956, 0.07719029146697252, 0.02109693337021576, 0.008652284159325063, 0.044167351368213856, 0.027605576155286644, 0.06263109690119183, 0.03568306167219435, 0.021997948530160134, 0.01928090662395041, 0.08579862995013114, 0.02865397897098334, 0.022218576106693477, 0.05794285330921412, 0.06199550439393329, 0.09299958830759411, 0.019086360510799195, 0.049309509716206984, 0.018168152422614155, 0.06069215517791529, 0.03510229807767657, 0.06959193265966832, 0.033144705943883426, 0.1233284193421564, 0.19819914213111325, 0.08683429655408667, 0.03976342598757437, 0.07877445404207514, 0.038743954482338125, 0.013647974157075008, 0.03449344586941504, 0.007902172519900507, 0.03185473262302337, 0.05265499652934171, 0.03286864616036896, 0.04158052908737333, 0.050087663525294875, 0.2230200844426309, 6.148150995854409, 28.053013086318973, 50.59208370024159, 63.330349537634085, 87.30109507037749, 104.70763252627466, 98.88958869441863, 93.25435084681358, 86.94632453303184, 80.75999367621638, 78.26550745194959, 66.82627570244574, 66.86218107900312, 61.164891335272024, 63.86000287148261, 53.390679128708385, 52.6373722476344, 55.18312777242353, 50.72975104854953, 50.21164517248831, 51.93883342127646, 63.05508936605146, 56.459208150063795, 69.03665681039134, 52.40597594168879, 66.8153715133667, 54.478587719701956, 45.51769379646548, 39.4712778060667, 38.559722900390625, 48.068928872385335, 114.06924755342546, 70.48717283433484, 49.87629821223598, 58.42620618881718, 52.40579551266086, 51.71978081426313, 40.09979448010845, 53.19222288746988, 60.54424685816611, 58.6779478288466, 60.964289557549264, 76.57205550901352, 85.53948802332725, 100.49327327359109, 107.61903532089727, 106.08265861388176, 85.69071108295073, 68.8854572849889, 39.69605707353161, 9.396705531304884, 3.9882566755817788, 1.0926636068090316, 0.3643713963608588, 0.19253289537324061, 0.07215611321190674, 0.008943589092532714, 0.0463700111985447, 0.04263519850229064, 0.08973729481259662, 0.03236408533167935, 0.06143756255867982, 0.0672851882935051, 0.041255117919776714, 0.044095362085969224, 0.11603584452982872, 0.014717004847742859, 0.024862546631465518, 0.13524171475681568, 0.028285553881658182, 0.02713321591727436, 0.016411173818332535, 0.020530129812898177, 0.12365509455482807, 0.07829404030475887, 0.08861977937481097, 0.08715941660827206, 0.057271561104684114, 0.03841447538786358, 0.048605409796319665, 0.036158503498882055, 0.040372205417483084, 0.06683829090287609, 0.014858644928843265, 0.030266124822740114, 0.03933009984452398, 0.0424226972034141, 0.07405934374659293, 0.042041733169988285, 0.06782518068869269, 0.0853440486976216, 0.044632060303082394, 0.06928891424209842, 0.05638604773388756, 0.07717213518316708, 0.07703394058250612, 0.08914998116632623, 0.029234821089513363, 0.025929617094657114, 0.04969959019593174, 0.026696021030206355, 0.0004883060888283992, 0.05205126178841438, 0.10040184392804101, 0.033159196496971195, 0.018187270146764575, 0.0788157691638316, 0.023047843302089362, 0.11904531368805517, 0.05440466857004551, 0.032213951250718485, 0.227950687610334, 0.04995711065167862, 0.11795351582188761, 0.0893750501376006, 0.09288877368934693, 0.21837195321436853, 0.19315452975851877, 0.13915840055673354, 0.16003685522704356, 0.1205876861668883, 0.11397041785981386, 0.18119900757747312, 0.20346245728433135, 0.18025417601869953, 0.19044564285826301, 0.16248648265196433, 0.27771100942646304, 0.1923039729797071, 0.11851010934239435, 0.12056458861597123, 0.2087345364834032, 0.09436989743863383, 0.10524509008973838, 0.20748694697695397, 0.16242600767122162, 0.17843557521700862, 0.11958412630783936, 0.16207869404986983, 0.19737601129999086, 0.1502466958857352, 0.12176576085508832, 0.1844870722702434, 0.17320212217107897, 0.1808260759759334, 0.1899021187977445, 0.09121985114630192, 0.10928939081608288, 0.17735847091722876, 0.14171590848315146, 0.16581515000472147, 0.10893926565204898, 0.13556576994878633, 0.2311737727253668, 0.1148943888444093, 0.17707307252191729, 0.14933908087832315, 0.18068877769814384, 0.13840768035621415, 0.298065199486671, 0.2191853240853356, 0.1381881808441493, 0.32487815426241967, 0.12298629213605197, 0.12204149122079536, 0.26421879147810323, 0.13764841061445976, 0.12852258739932892, 0.26342043593045206, 0.1355621693355422, 0.23788623511791232, 0.13888158234617404, 0.11701527261926283, 0.13502063710362683, 0.22122558476703785, 0.22048646313769205, 2.26089118469146, 17.18048537931135, 39.01233696168469, 60.49551533114526, 91.13299185229887, 111.7515503975653, 118.01517548099642, 112.03346683133034, 108.07320656314974, 108.44215254629813, 106.85662854102351, 103.20394485227524, 98.2463356756395, 103.78485571953559, 85.9060178264495, 105.50359910534274, 95.62798884607132, 103.98755596530054, 103.81885482418923, 100.12441358258648, 106.61468890405472, 95.87712210993614, 103.57486770999049, 128.54357011856573, 99.15292878304759, 110.4334379011585, 113.98155904585316, 132.05630363956575, 96.24513456898352, 105.469756895496, 80.47473538306453, 117.18277792776786, 79.192230163082, 92.95106534034976, 100.29014156710718, 89.67595684912898, 85.53763666460591, 72.79351865091633, 83.36103500858431, 85.49060744623985, 80.93815557418331, 87.39925630630987, 106.60562822895666, 110.59656143188478, 121.26469442921301, 125.18430325292773, 122.14600393849035, 93.862396670926, 70.41911186710482, 39.162308785223196, 11.646316224528897, 2.586270421743393, 0.8329073387768962, 0.4145422493738513, 0.212387259028131, 0.14209849279253714, 0.16395216206869773, 0.27150971154051445, 0.15547346864496508, 0.22254258183942688, 0.18672579568960976, 0.16441049715203626, 0.15755613995415552, 0.12892190306898088, 0.15367965844850387, 0.13812943722211546, 0.1780928581232025, 0.1461683195685187, 0.2583498225337075, 0.19454812030157737, 0.0726215269476656, 0.14581248704944888, 0.10183999780565502, 0.23420132155860626, 0.21229584941700583, 0.1951089885927016, 0.14299732843233695, 0.11415774933993818, 0.11909646537875938, 0.17328530399789735, 0.1489140706196908, 0.1559549395836169, 0.13917951393992672, 0.08865914863323973, 0.20536574144517222, 0.13857815024112502, 0.20004248757275844, 0.21320236125780692, 0.13743039731296802, 0.13485376783196004, 0.26777383781248526, 0.1997470840691559, 0.12270399639683387, 0.1968343411722491, 0.2373709337365243, 0.0997767621471036, 0.18804008081074686, 0.2087181268800651, 0.14471192513742756, 0.2358337017076631, 0.10374831516415843, 0.13096564178985934, 0.10438131063335365, 0.20593523588632384, 0.17238200972637824, 0.12705880788064775, 0.2211875101972011, 0.14834911141905094, 0.1330631752047808, 0.2621544603138201, 0.1538705522374761], [0.01445641525224933, 0.08592907174099838, 0.03994650951015853, 0.00546243912052183, 0.04033354479038427, 0.04321205121795497, 0.014040059871941566, 0.02455729698281615, 0.008209103252738714, 0.03739546736582153, 0.07297471646339664, 0.037698462800753695, 0.0367903919710267, 0.053650359247600844, 0.02665120680185576, 0.07001983873065441, 0.07124872036999272, 0.033650511665449995, 0.09584880719381957, 0.017266453529197364, 0.027668586887058713, 0.030701722416485992, 0.04613940341157779, 0.018097053717581496, 0.05019073299462757, 0.029864476415358727, 0.02571501863008786, 0.04311666178006319, 0.04402130436632903, 0.062169027139222434, 0.023997801904296203, 0.028253439475872347, 0.008624190757531793, 0.0443050250290863, 0.0350068396918716, 0.07172357230897873, 0.022810922950626384, 0.024709962984366764, 0.03924472317580254, 0.013997402181097818, 0.010509152968053617, 0.0294376754262034, 0.035145003649015585, 0.04080803666804587, 0.03953759092837572, 0.04676286108611573, 0.13884773658167932, 0.02683694864953718, 0.048724095967988816, 0.043306701380999825, 0.028012299895166393, 0.11365384734686344, 0.017373167661829822, 0.0358004225117545, 0.001859954586947307, 0.05226223091144235, 0.01433835823028799, 0.055613237388071515, 0.11354159248331863, 0.05401645351441638, 0.07216414181335319, 0.03958499261869058, 0.032023350490377314, 0.021110385874166124, 0.09403397554471608, 0.04576724172840196, 0.06934299238867338, 0.07088122033183614, 0.843515205046823, 4.712862593512382, 9.994607125559162, 27.772865641501646, 33.54224658781482, 42.082897770789366, 67.74911526710757, 56.80107016717234, 86.92185678789693, 85.70378826510522, 85.30787990939233, 101.02270695470996, 84.63908441605108, 74.46449541276502, 77.93062333137759, 89.20917126440233, 100.39327636841806, 107.58316916804161, 106.25809054220878, 113.03929590409803, 107.63036312595491, 111.04825373618834, 109.49135518843129, 99.48388268870693, 93.20342279249623, 98.22815156752064, 94.98846207895588, 103.12348135056035, 86.2544890372984, 84.6322516472109, 86.86786144010483, 72.33533874634774, 67.11500921557027, 58.453376447000814, 57.170031839801425, 54.735565723911414, 66.32493403650099, 84.70807106264176, 95.48568525621968, 91.27698206132459, 78.74185577515634, 57.34963716999177, 30.394477844238285, 13.622642640144596, 2.631593163936369, 0.693985996467452, 0.4160373772103941, 0.12973430866916336, 0.19230556644258961, 0.12472733419628874, 0.03933124514597078, 0.032231306972643065, 0.03868381658028211, 0.0978513763496472, 0.09700333233922721, 0.0615847472011322, 0.03100437694229186, 0.1312016275140547, 0.022657935192147573, 0.11862335245936148, 0.013241221688898101, 0.06981263492977427, 0.091575913491749, 0.0585877231412357, 0.01710958170494245, 0.06276803511765695, 0.02340119752672411, 0.05130015854393283, 0.026146262929204012, 0.05393681867468742, 0.014044393056763277, 0.04742373449487552, 0.03359778566406139, 0.020505752895147573, 0.03432803599524402, 0.04028061194525611, 0.005311410153104414, 0.06430092342798749, 0.025130958942275856, 0.04652533935563219, 0.06891602094495489, 0.08915132182019372, 0.040811361489637245, 0.07402745150630513, 0.12707475783123126, 0.09235430478809342, 0.04742544287094667, 0.02525554016052235, 0.04646745758251317, 0.06029480452378912, 0.025836612105429656, 0.09655891707347286, 0.009200808858769316, 0.016720089197699583, 0.05120421369229594, 0.05372222978621722, 0.02240180710120307, 0.030524861443066792, 0.039868805211998766, 0.0269084514659499, 0.0796359122520493, 0.08437343828019597, 0.08342695963238517, 0.028220852010793267, 0.0815156621918563, 0.048363728208407286, 0.0910082116963402, 0.03162012585709172, 0.03846474990789448, 0.08186404833630209, 0.034379038298803, 0.01882052225541444, 0.036290312756694136, 0.03853225374534246, 0.028643726799336654, 0.07668412951452118, 0.026581387463656646, 0.048039768777427175, 0.03426184982902581, 0.01671270794054914, 0.004071667302219618, 0.03511851615903359, 0.03549267733169179, 0.010974606923428516, 0.08248570570421797, 0.020358980024954485, 0.02150259990876, 0.014184429141272221, 0.014701791299176554, 0.010930732110395067, 0.01769226243449075, 0.0659360002065378, 0.045637841817111745, 0.06351014448990745, 0.02081000279905575, 0.07473763799475086, 0.055312766212849855, 0.06503041533212509, 0.023146239635083946, 0.02421524255506454, 0.06498983565477595, 0.03003277061056466, 0.056680462984067786, 0.06558962887333286, 0.04684112845889984, 0.0615211044468226, 0.040792454439666004, 0.02546261947211479, 0.01384448815858172, 0.03681260852083083, 0.0605870096103078, 0.016807179988151597, 0.01596333318194675, 0.036818216284436565, 0.09944417273565646, 0.04423048084361419, 0.020200198726548303, 0.0647772079513919, 0.07801862403510079, 0.21121629363586827, 0.09586050535642332, 0.01974190960848524, 0.07597549818456173, 0.06032745902156157, 0.009564172022134788, 0.06388322547859242, 0.052773472026831685, 0.06453383713960648, 0.08882785651592479, 0.04520663773761161, 0.05521400598809124, 0.03838527977706925, 0.0701093407828481, 0.04239219924314849, 0.2963726354702827, 0.6490172481825275, 3.9739260510090864, 17.43017561974064, 29.429260992234756, 51.57033066595755, 57.62000222359934, 64.56608049331173, 91.94477342790174, 94.29169224154566, 105.42833666647635, 105.47163178843837, 107.55437897097681, 97.06624354085615, 98.76836392187305, 85.85235980249222, 91.72658766469648, 95.10734127413843, 107.33613829458915, 111.49102657072007, 111.6729304098314, 116.06609482919018, 120.67750776967695, 113.10413268304642, 109.13540794003396, 103.28982906956827, 99.22826966931744, 94.082716203505, 90.74586176103162, 88.00008496930523, 90.71749517994543, 83.19250645176058, 88.19817250774753, 82.77409938073929, 80.40275204566218, 76.06566967502718, 73.57606287925475, 69.50439160869968, 79.39998242162889, 88.88002164902227, 97.72230702061808, 102.97239949626308, 98.40988282234439, 78.95557003636515, 52.982128973930116, 29.370719617412938, 8.360110367498091, 1.5353201185503316, 0.3787779555686059, 0.32236569230594947, 0.18229713332989525, 0.12138478533034364, 0.013944519131684737, 0.07985723505337393, 0.003036258295328627, 0.06633166163679093, 0.011355137159567208, 0.03125421928181764, 0.09590301557534164, 0.030504493080379984, 0.06250528994226648, 0.048605003769719796, 0.10432741634788052, 0.03419116672669207, 0.04599775758481795, 0.07668012287467718, 0.07511274528599556, 0.06395504622149371, 0.06799768070660292, 0.03460609143780124, 0.04325129024143662, 0.07885805721725188, 0.03779742603881225, 0.02635005380838148, 0.06223897479714886, 0.006621265370819357, 0.011086717187877626, 0.013386264157992218, 0.025636531007025513, 0.03788583641571384, 0.11416529530599234, 0.0084459173095022, 0.06798596722224066, 0.03302854403192478, 0.04236679959801897, 0.07018134538685122, 0.07326949943578051, 0.04330085229969794, 0.05934399364876652, 0.07958120591337643, 0.025582711415124998, 0.1473189376655125, 0.05787368706097046, 0.054406763820518414, 0.026903854938404217, 0.05534646642063895, 0.061350757135979594, 0.055835069637865796, 0.04889498720125807, 0.024948833029597037, 0.007446300409238546, 0.0493553294349582, 0.035397165319732124, 0.03840411787912731, 0.07147419536786695, 0.03759801335212204, 0.03914448823178968, 0.1174164345608123, 0.08950058896575244, 0.037371239835216154, 0.06428761648074274, 0.1748096963931476, 0.10492438270199685, 0.1625462375100582, 0.11863852866114148, 0.13293608121814268, 0.13767264963638398, 0.12209361584316339, 0.057430133644130923, 0.1269929932670728, 0.14967905537736031, 0.2881050758784817, 0.08881785140763368, 0.15925710029419393, 0.18798582646394932, 0.16306023654197493, 0.13632298657490363, 0.13929766001960925, 0.12909799603925598, 0.14393172587358183, 0.1402361483703698, 0.10591521017974424, 0.11119481236223253, 0.10366208430740143, 0.14314253273750507, 0.19844223715124593, 0.11634438644133269, 0.21343249407026077, 0.14512014274875965, 0.17778793980758037, 0.10599736544874408, 0.3100543835711095, 0.10461035560095504, 0.07496276825305916, 0.11256651577329445, 0.2038382387329494, 0.0996201431318637, 0.19943424440439672, 0.1325730934378601, 0.11309713125228883, 0.10879196226596834, 0.13141009536000992, 0.11019384188036765, 0.18538492731750014, 0.11367144438648417, 0.1121835790634636, 0.16335537957568325, 0.11173593856754804, 0.17051434865401638, 0.1900321085967364, 0.17254429779225783, 0.4905133195702107, 0.10828225332642756, 0.18841026981751766, 0.26176973095824646, 0.13379083615877937, 0.1130605811974214, 0.21704712672339332, 0.19641129209870295, 0.1666462481502564, 0.25840350997544104, 0.23135312923019935, 0.22856793997268524, 0.12936908391214189, 0.13066777148314063, 0.15913993480705446, 0.1831013417892879, 0.18627182730743963, 1.2417878306681112, 8.269074116983722, 17.042274782734534, 37.67661302320419, 49.6793403164033, 62.429330118240856, 97.29567866171561, 94.72552991682484, 123.32214232414, 125.0087614982359, 126.27063505111204, 133.3783934193273, 121.24394509100146, 116.27310968214466, 121.77264921126829, 127.0129906746649, 132.77019070040797, 139.33583044236707, 140.40044015453708, 142.76347990958922, 140.17093443101453, 141.92006049617646, 141.0544247781077, 132.04960423131143, 120.88527571770453, 127.41478258563627, 123.62854219252064, 133.349273743168, 126.28608134485061, 120.2615325681625, 125.19021034240724, 115.05418608265539, 110.84891888403125, 106.85786800999796, 102.74505892107564, 99.5167286165299, 110.35748512514176, 122.51204736771123, 130.12859990519863, 121.67428401208694, 112.73077795582434, 85.62694903342955, 50.87984446556338, 26.380751748238843, 6.448518749206297, 1.235108034264657, 0.674992470491317, 0.4161004109248039, 0.31094552768814954, 0.1238160496277194, 0.141211761341941, 0.2434189374288244, 0.18587223584613494, 0.24854668566296179, 0.1214389171030733, 0.12606303913578873, 0.11550236388199753, 0.20498435223294845, 0.13924893682762501, 0.24132347245129848, 0.15504806002061214, 0.1830990282037566, 0.1664333982813743, 0.18876697567682113, 0.17442806203278804, 0.17635258215089, 0.15342730908624588, 0.08656788947841815, 0.1036698677607121, 0.123725168617262, 0.13819194999673676, 0.11112191909623724, 0.17423938989879625, 0.12598774035371121, 0.10964921465323818, 0.14131323734839119, 0.17761694898288097, 0.16505508353152584, 0.21477566070614323, 0.14682269655168056, 0.25053105256970853, 0.23314865546361094, 0.1342907851381648, 0.24730176214248906, 0.1793472811339363, 0.23612006537375912, 0.1502148266280851, 0.1417518686503172, 0.10367116244930415, 0.20552724810136905, 0.21272115078904938, 0.15777574671852976, 0.10703843297256578, 0.12104871787972028, 0.20782278460120002, 0.17899057527463283, 0.1235870199818765, 0.10684018473952048, 0.12672644063469865, 0.07777028897356603, 0.20651827476197676, 0.2069398529467083, 0.1848451417660521, 0.10307502347014605, 0.1862299989067739, 0.18848766001962847, 0.29572225746608555, 0.1592142146921927], [0.009114039825245498, 0.05826776651965995, 0.03126151052363698, 0.06535888319053958, 0.09923650928202177, 0.02714127899267741, 0.024326286999688997, 0.054147469871226823, 0.008728427553339111, 0.0640049760019587, 0.010694074144046153, 0.049186813074254224, 0.013487540981582096, 0.045137927311682896, 0.048058982262568134, 0.019203786467832905, 0.1349322918441988, 0.0741257022825941, 0.07706979349736245, 0.01907126666347106, 0.022462540636620214, 0.08474794036198048, 0.059388564644201156, 0.08618794817237124, 0.05045854584163716, 0.02567994904013411, 0.08202171689199825, 0.09589361567651072, 0.10649766682857469, 0.03463974184987526, 0.05272079965159778, 0.06365450226791924, 0.025807244124852365, 0.022814492920353528, 0.012457048343945176, 0.06383297394119924, 0.0587599856718894, 0.049895827448175806, 0.010525462979961549, 0.021260251824353493, 0.00955825207769991, 0.06560485104038831, 0.05457440301054909, 0.06226474982536128, 0.038852750458904815, 0.016734242672100663, 0.07631072293846838, 0.03436465499802463, 0.04297852080555693, 0.00915443947193243, 0.08634952377648124, 0.06807002238929272, 0.09236617149004052, 0.011323927695141926, 0.12974923206192832, 0.02555641161668445, 0.024534632271576314, 0.05214673166553821, 0.031231510520522154, 0.0590889553178943, 0.06114026298746467, 0.012712928413924192, 0.07961376465015835, 0.03145028416427874, 0.0973032710833415, 0.0538007423071371, 0.037188704065497846, 0.06690199111378001, 0.055537015470045234, 0.08739360202584537, 0.09346501736511147, 0.04478009913357035, 0.1224388916706366, 0.999919286658687, 2.949024698426647, 3.0438251985657603, 20.180825956406135, 20.588546529892955, 19.540191119717015, 38.845628384620916, 29.4609772774481, 37.723293150624926, 42.20973545505155, 55.71435789908133, 70.7871792393346, 52.33720502545757, 45.31116139504218, 42.33765571348129, 37.745886002817464, 45.646708396173295, 65.49715703533542, 59.31039471780101, 65.4591884920674, 76.62990262431484, 73.41679896077802, 72.3628737849574, 66.17441700350854, 64.16637136090186, 45.63418034584292, 41.430195762265114, 54.21328252361667, 41.99341674004832, 44.41572350840415, 54.59828276788035, 56.049802918587964, 49.95151750503048, 32.72611118132068, 14.854198232773813, 8.117403416864335, 2.1736579172072874, 0.6127205539134242, 0.12809861135939438, 0.2843248609813952, 0.12838849136906286, 0.240079881923814, 0.04166140881997924, 0.058810964992810646, 0.017018208482993707, 0.07848637433902872, 0.10375337900533792, 0.04457074262562298, 0.09854907560492716, 0.024187960248861103, 0.02430417770219426, 0.0840687421300719, 0.14171958570518803, 0.06501323197998347, 0.028607969645470865, 0.014543993466143167, 0.06293370929216185, 0.02323480131435058, 0.052465094824231444, 0.11240625017953497, 0.06737235377752973, 0.013368496663808344, 0.03941284117078589, 0.02119001305301584, 0.03181234689339275, 0.03855095778201376, 0.017485407203616157, 0.04917419943658095, 0.03392431915046708, 0.04959522986844663, 0.028900281984298944, 0.0424176678361912, 0.013566860767652192, 0.040626795586919597, 0.027143799421948292, 0.01246680160083117, 0.03677653344047647, 0.07209952229694014, 0.03170438403744371, 0.049295203024221045, 0.007967954095933706, 0.15957384700736693, 0.02200235928138418, 0.018053352231940916, 0.030812935400453788, 0.0816395309483332, 0.0868369318965462, 0.052263751595972054, 0.05425541165975794, 0.07412072271108627, 0.04935339506294939, 0.02816782340467457, 0.02147226091173868, 0.021885532788151217, 0.05530825395497584, 0.062147913756029266, 0.040658795079516794, 0.06428957766582889, 0.04851623716193342, 0.024452162906527523, 0.04602414548336979, 0.03718870789593747, 0.03740482896025624, 0.027483722210050594, 0.054430949216287945, 0.027568966728605093, 0.012323579548167126, 0.03316151774338177, 0.03293193268379377, 0.05834882628292807, 0.035092292969385465, 0.05685891167471006, 0.03233158405149176, 0.007650441294836422, 0.03637106608479254, 0.09203326798254445, 0.04372513477480219, 0.021187050207968683, 0.05416677528691869, 0.13709394681838252, 0.06384685162394758, 0.052045975781736836, 0.03679280897842781, 0.051970776591089465, 0.014076855074944756, 0.02398418277622231, 0.04144056099316767, 0.03431079518650809, 0.01921944722022501, 0.06332069477667251, 0.03495233253605905, 0.09112662590679624, 0.033329674042761326, 0.03878859442568595, 0.0839260122888992, 0.06258909613074315, 0.04118229743213423, 0.032490773291717616, 0.016402593633580594, 0.03807674169600491, 0.04341944271037656, 0.005663009078782653, 0.08808997594901631, 0.03197459857009592, 0.06445902099292125, 0.05348116489908388, 0.0534513870614671, 0.01571411903451888, 0.10590227095470314, 0.026837699415702975, 0.016118735074996948, 0.07846038097575789, 0.07565813094017006, 0.024541596010808023, 0.08173287876190678, 0.04702002531097782, 0.03410293638045269, 0.04704979931815498, 0.06244922762796764, 0.018660616722979376, 0.043369635503979466, 0.03422994992785877, 0.01663724061912827, 0.027509918586621364, 0.034711570253655795, 0.06788406220655288, 0.023746182240786094, 0.03207469944872203, 0.052318258751784606, 0.03740216680471936, 0.018415100865005966, 0.1343398760523527, 0.12413491074356342, 0.3185567031464269, 0.46969144815398806, 2.116902936850825, 5.600833267934862, 15.855642095688852, 13.26049412450483, 43.42688222085276, 43.94885555390389, 44.546263910109, 68.56961234923332, 57.70188562331661, 61.893954046310924, 70.20263625729469, 83.90552274642452, 97.47078895568849, 93.24500776106312, 83.82782059331095, 86.95101568775793, 68.60099131061186, 76.75446925624725, 93.83412422672396, 86.17916384050923, 88.17522664223948, 101.17096470248316, 97.18726435015279, 96.82016972572573, 91.11107364777597, 90.04014107488817, 74.07221132709135, 65.02017721053093, 74.43703097681846, 66.91767477220105, 66.78475349180161, 72.95420246739542, 79.07391578920426, 75.28834219901793, 60.188421203244125, 37.94109844392346, 23.232347580694384, 8.228039260833494, 1.9539364235055063, 0.6244396766827953, 0.44654937220677254, 0.03054553624092331, 0.10478952824468575, 0.047596992939830794, 0.04919169305433189, 0.08709369392524804, 0.0691382707126679, 0.022274950601821466, 0.11283395706766075, 0.05223159888579, 0.018325066381704905, 0.030292978119705955, 0.07345309240683433, 0.09094455745071174, 0.06710122760024763, 0.12571103705634035, 0.03695677860730118, 0.05258806725783695, 0.03667131126407654, 0.030403122411019383, 0.06336076117511238, 0.08614025919908479, 0.015773966780773575, 0.022817026756163088, 0.05067630250367427, 0.03485743722487842, 0.08712635991433937, 0.012132794926724127, 0.05203549186849306, 0.024602994127499483, 0.05725481442265934, 0.05503993932037585, 0.02425767808041025, 0.04216936724861303, 0.03550897202184124, 0.012685798367695704, 0.03873547771945596, 0.049880540163646785, 0.008913917549615426, 0.05735124574012815, 0.057351188283533826, 0.003320552805821682, 0.03741858789937631, 0.029824860093574372, 0.004699467737678318, 0.0672619222032447, 0.07602083526792065, 0.06916225692557712, 0.01113361613299217, 0.03766808358411636, 0.0536633444379174, 0.009826622253674413, 0.02326730450975799, 0.037402040400211854, 0.06913978756675798, 0.04642219327750706, 0.03937700357768805, 0.03943957380890366, 0.04700782536078365, 0.04415862179631668, 0.05351858829418498, 0.11095154114187726, 0.049184928497960495, 0.011953821465853724, 0.10915930908654006, 0.1970681512067395, 0.2506613181603532, 0.12323542392902798, 0.18436256766078934, 0.09122864583567267, 0.14524193540696176, 0.16354414364022596, 0.1705609727650881, 0.1497336161593276, 0.11155363262420702, 0.07012684589191791, 0.171223868645968, 0.10925643371358033, 0.11852556133582709, 0.14955640470068302, 0.18714346682592747, 0.15520932152867317, 0.17269278095374185, 0.13587004475055203, 0.10854088460966464, 0.12639195132519931, 0.18212822626434988, 0.10956705938423834, 0.14832013797375465, 0.10707653052504025, 0.2420372518921091, 0.09349424361942277, 0.23123293003487974, 0.11479917943717972, 0.20436394358834914, 0.1584345363681355, 0.09613838076831834, 0.11673129914749054, 0.1108102668677607, 0.12130914180870019, 0.1682153034714922, 0.14715260465539273, 0.09232619702215157, 0.1367785177764393, 0.07845632837063844, 0.21311366359793374, 0.13308165324551444, 0.1302068623443765, 0.18944271119131198, 0.23156551944632686, 0.12517431585658945, 0.1676122697010156, 0.12462716820018908, 0.250996925958222, 0.19154212918252717, 0.1531997656509761, 0.20127922927419986, 0.1320953610082788, 0.15904562938357555, 0.19507132771034397, 0.15533393339043663, 0.2989230034572463, 0.13759263941357214, 0.25967481756402605, 0.1687839552159271, 0.11202764186647632, 0.2282883178803229, 0.14644424911708603, 0.22769360382470394, 0.11558978217503718, 0.1420482987117383, 0.21902377146386334, 0.21201362262570092, 0.2450853012382023, 0.16522077302778923, 0.16489443489380423, 0.5254902894939146, 1.6319355729126162, 6.920125417170986, 7.213139707042325, 29.431802688106416, 33.06860862239715, 36.10053408530451, 53.79326335845455, 50.17730482162968, 55.93820364244523, 65.64002544649186, 80.2199774403726, 97.02872214778778, 86.8524229911066, 76.06295539486793, 78.07347605305334, 58.38244038243448, 66.25926571507608, 82.70734848514681, 82.63351378902313, 91.49862735502182, 101.84558883790048, 102.1590332831106, 95.56667435553767, 92.43813699291599, 86.38502551663308, 69.39966432509884, 65.00767269442159, 81.10223616323164, 76.44190342195573, 78.28613127431562, 86.0499688117735, 83.85903481514224, 72.87471171348326, 49.47746769074471, 30.436270698424313, 15.413211487954664, 4.391061538650144, 0.9583516010353643, 0.38890082689542926, 0.5404636924785953, 0.1968120020483771, 0.24458781906193305, 0.14845705320758207, 0.15650702850712886, 0.1937219710840333, 0.2263086700751897, 0.38517846695838437, 0.2735090784488186, 0.1308903047033856, 0.09941150674656515, 0.16032090530760829, 0.19392008142125225, 0.28354924292333666, 0.10708491918781113, 0.2165604770303734, 0.13499420707023915, 0.17618183647432636, 0.18112944679394846, 0.18494353809904668, 0.1928411385104541, 0.2305990229210546, 0.1407036611870412, 0.20513386195225103, 0.11648963671177627, 0.12922545774809777, 0.14823594491087622, 0.15714822877799312, 0.1901738195409698, 0.10594749312487342, 0.19903620044069908, 0.12598524290707805, 0.08879046376434066, 0.14159017813301858, 0.07551347821830742, 0.15441484238591888, 0.1278079805835601, 0.09785241822922423, 0.19457936136712953, 0.206809188990343, 0.2602962068011684, 0.2160179948494319, 0.3101490413950336, 0.12041366929488799, 0.15514601202261064, 0.25561023082944656, 0.19210888102890986, 0.18418785364877793, 0.0753834501149193, 0.20120835081944544, 0.1828448555522388, 0.11792075790224538, 0.12695817457091424, 0.17168758166653497, 0.08074572850619594, 0.25425646153669207, 0.15223760518335527, 0.19975295230265588, 0.09844259704433142, 0.1023004013263891, 0.1420586408987161, 0.2878547183448269, 0.11709463932821829, 0.22511827669316725], [0.0037007552999702674, 0.03464125487352571, 0.07573669325680503, 0.0347272482430262, 0.04384432656450137, 0.03387081940027495, 0.055775038988119176, 0.028315008047126958, 0.03162824638908909, 0.03066107379122367, 0.04817653845454897, 0.05924548240258329, 0.002998827957555712, 0.05569080379040492, 0.02502472169937626, 0.06067465389928511, 0.010516187570418322, 0.02919545566152421, 0.02012331797290714, 0.022262038189857718, 0.02072158476127492, 0.011600591730506671, 0.03495644259777281, 0.008321375353261828, 0.05109135744973056, 0.04784084255656889, 0.05107406301483993, 0.02351107751770366, 0.041505996393220085, 0.05710494081159273, 0.052038483441837376, 0.0710937254611523, 0.07048459363079841, 0.03293004810750004, 0.011527093255051203, 0.0701655026885771, 0.041740220115189595, 0.0676597593232028, 0.020349424993318897, 0.019004182259161628, 0.03356438040012314, 0.05958719592120859, 0.030328097505374785, 0.08744001163229828, 0.05273677258481903, 0.014364410007763055, 0.07794091207606178, 0.043175321132425344, 0.05242820769067734, 0.02420010657290057, 0.023554154641685948, 0.03271048730840126, 0.0456170195473298, 0.04707244870763633, 0.03443603140992984, 0.019408226606526205, 0.022072360565465306, 0.01801951795876507, 0.04647001631618027, 0.062261888486964095, 0.026864056670737844, 0.05999904095886215, 0.02314015689696516, 0.06424099236967103, 0.02511629218896551, 0.06216819210338497, 0.08520943172756704, 0.09641591910152666, 0.014105524957901048, 0.042459760537190784, 0.1344578382709334, 0.061489924668304385, 0.01652733189985156, 0.07426262517730076, 0.04905744380648098, 0.05340344527916563, 0.1981551073972256, 0.06572007832507934, 0.08308192129216849, 0.07249327616826182, 0.052908594614916274, 0.14327059199492778, 0.4520637956598113, 0.4230755495448267, 0.9555852268972705, 2.5655227995687917, 1.7119135587446153, 1.553707209325606, 0.8928786013876239, 0.20228896380191852, 0.15124573582603087, 0.08158361419073998, 0.22886308300639355, 0.44909658391148816, 0.579389845651965, 0.6374651325806495, 0.9768446570923253, 0.17722959960660628, 0.07539877953428416, 0.15506410190174658, 0.7270746822318723, 0.8540584134959406, 2.183590829372406, 0.9921732797257363, 0.277342674352469, 0.20296871361713256, 0.4605242255474291, 0.27996128545172755, 0.20384743178804077, 0.049960990887015104, 0.0166520644204631, 0.016538191196178238, 0.08879801739127406, 0.06618968256178402, 0.13142249066262476, 0.08111096092409666, 0.04451902402985481, 0.09394126358411967, 0.07126217287394308, 0.017151517357917565, 0.060526718490666924, 0.040787264193979, 0.03746289076403745, 0.02862328374307723, 0.046553332208385395, 0.05792552056992727, 0.07593108040671195, 0.05603704871910234, 0.08366780235402047, 0.03482504702743984, 0.03481197756745162, 0.04254034532594585, 0.02383409657575671, 0.03761382923731881, 0.04936092570724507, 0.04115453823619793, 0.01269548363427842, 0.03293323503326505, 0.07695555446609374, 0.009262485639943231, 0.019206984884916775, 0.08015523559503979, 0.07285817150747584, 0.02982788231043566, 0.02583383886714376, 0.029359620642818274, 0.050451421223941355, 0.039806882325079174, 0.07806301883031284, 0.019521142220905712, 0.03681214120719702, 0.04130045500313563, 0.022147123085995837, 0.04599704512304837, 0.046764366448886936, 0.04794955043302429, 0.18619272106837842, 0.04823563064658835, 0.03942387283689553, 0.07606785008383375, 0.015451502178855723, 0.018016660450807503, 0.03613528720433674, 0.05107453032847374, 0.048055105857671275, 0.06087674023283105, 0.020420412615602537, 0.06446269055407855, 0.02088360852682062, 0.04066934411023413, 0.04467771914336951, 0.022217854068824844, 0.06794391665607691, 0.09382361546158792, 0.0391430594778109, 0.029706032195639227, 0.054507473739044326, 0.0066808287069321645, 0.011202050767268145, 0.0021456782105228594, 0.03416242693821269, 0.009804240037356655, 0.030553583994567878, 0.1020123446059804, 0.04230516782451061, 0.012654621462007205, 0.030888193962915294, 0.03753378454055037, 0.017883288373629895, 0.06449843621662547, 0.045724474870029, 0.015082860669691958, 0.03427748185312075, 0.05674014889424848, 0.04747773220221843, 0.01739981986071554, 0.00855638623057354, 0.0680652573224037, 0.00993986632825146, 0.02781044147277792, 0.043096245536881114, 0.05014557211149124, 0.024204482850168022, 0.009879389432288948, 0.05096657321818414, 0.025685407416594606, 0.05808955531627421, 0.051120200660079725, 0.019698169818448446, 0.02521981748061315, 0.045310201333655466, 0.022180057205860654, 0.07167274237520273, 0.009786891018701418, 0.029871129888981104, 0.02467222932365633, 0.07097921063823086, 0.03890730741043245, 0.03029953966277742, 0.01607705606147647, 0.05919413535945839, 0.008827018281144482, 0.05584409798405344, 0.0488634052265796, 0.02953292313782919, 0.01988885867890091, 0.045309128810561476, 0.03711894792955249, 0.06786697078496218, 0.06563107423003643, 0.04955274263216604, 0.02042951374014299, 0.0193655765765617, 0.010200897381911355, 0.028711136791013905, 0.02043375403680388, 0.036032742505232175, 0.07022205529914749, 0.02419614972877166, 0.05496523808687926, 0.01616964736322482, 0.0680804718285799, 0.06325005380917462, 0.05220645588011511, 0.03088356296141302, 0.036589450938927556, 0.03363885946812169, 0.13932372233079326, 0.017725767289859154, 0.1310824855200706, 0.07759219651380855, 0.03940437589922259, 0.64907853521647, 0.37510909921219276, 0.5355924151597485, 1.2465934695736056, 1.209309992770995, 1.6168209646017322, 3.078610493290809, 3.5208481694421465, 6.2450193205187405, 6.198672594562654, 5.8926600602365315, 3.9038198128823316, 2.204789524116824, 1.0255910155753936, 0.9459192197649711, 1.2609386804603762, 2.155831725366654, 3.420547035432631, 3.2893285539842423, 4.476664325883312, 4.397577085802633, 2.1002926797636094, 0.8544960642053235, 0.753300997518724, 4.5426057423314745, 4.30694091704584, 7.023383773142292, 6.411047856653891, 4.8018994158314126, 2.613235490937387, 1.0907400519617143, 0.6483764922426594, 0.2278822146716618, 0.08135598648579852, 0.17241659093528025, 0.011467891895482618, 0.14272041829122653, 0.01884216232405555, 0.03859175579442132, 0.03929090678631779, 0.13033712793502117, 0.09000529535114767, 0.02126169206965114, 0.027206526701188376, 0.026052116468969374, 0.11520496854979186, 0.024612401687209646, 0.030426591514579715, 0.10835681666409779, 0.09608535982307889, 0.035412111695134835, 0.04475258508576982, 0.06170775793913392, 0.07297610308253959, 0.009551700110727502, 0.04589767202795033, 0.04835843837129013, 0.0366931026350827, 0.032025499367004925, 0.0059682558546023026, 0.02768233816529955, 0.01650097081437707, 0.04878568177622172, 0.0556920180397649, 0.048153877573748755, 0.016125444089993834, 0.032001855978441816, 0.048901610031363466, 0.04279153789543817, 0.03400333345897737, 0.03618797490132913, 0.06519280298943482, 0.0521069257369926, 0.013474661128355131, 0.03336201827492445, 0.05944056286206169, 0.02490388282063988, 0.06347943202502306, 0.02886823652642629, 0.03926766367869512, 0.029731175201314113, 0.012751263453655187, 0.03521192142920148, 0.03997900312946689, 0.019895182734715845, 0.053296637300762444, 0.1068685912797528, 0.0214991276152432, 0.07213577357751709, 0.02236681412004175, 0.004433538030547601, 0.010909319952911428, 0.022988823888402794, 0.028029466010329705, 0.045722601785054134, 0.12364271457397169, 0.050111439064024925, 0.03829322665208771, 0.027720700018107895, 0.024232002643627987, 0.09864381003764369, 0.12705318479528352, 0.1325350801550573, 0.15545093033823276, 0.17744698471600012, 0.19293147559848525, 0.09430320948482522, 0.1616208952280783, 0.08747258569083868, 0.10758266949485387, 0.1573709918246154, 0.1713618564028894, 0.11505554310016095, 0.1154096136170049, 0.14362847762963465, 0.13851209814029355, 0.1309708971530199, 0.15147833544160091, 0.11450126316518554, 0.14679931554823153, 0.11883075544310194, 0.19597066896817378, 0.16282363794744015, 0.23517638294687196, 0.1568120081097849, 0.14666877416593416, 0.1993059859641137, 0.15819395411639445, 0.17316230092077486, 0.11443884998199441, 0.26490284670745173, 0.16081167655366083, 0.14039636799885383, 0.12815822832166188, 0.2320490741441327, 0.17825186733276616, 0.1674938478296803, 0.212382432674208, 0.14592867194404527, 0.10701092275520487, 0.17721083045246142, 0.13799072934254525, 0.13760503471618699, 0.2157120040107158, 0.12012546701777367, 0.14065567343946428, 0.17810840970806538, 0.17340610074179788, 0.12030747418682422, 0.12196632267366495, 0.19711854447039867, 0.11455385510118739, 0.12017649613440999, 0.2421788402622746, 0.11259554284474543, 0.15787383661635462, 0.19113178184676557, 0.16347704965981746, 0.10836463076092544, 0.2570777795007152, 0.11331677632105928, 0.11674260660525292, 0.19351560231899062, 0.14556617446003423, 0.07298023229645145, 0.19494173627707267, 0.19167381969671096, 0.24338731331931007, 0.19069494319058236, 0.14219975429436854, 0.14959581226350802, 0.2240856514582711, 0.20190587387450282, 0.1530277942337336, 0.129730953204055, 0.13131122405250228, 0.33019336421162854, 0.13883949347561406, 0.18198694432935408, 0.2720772907618554, 0.3934817262474568, 0.4838677213316964, 0.9669901310436189, 0.9018948433860656, 1.9139102293599037, 3.4349016845226292, 3.999177779882185, 2.4788970091650566, 1.2905002361343754, 0.3089791025605894, 0.20368843790023558, 0.4002789179644277, 0.5185819537408891, 1.2620237061092932, 1.087595169101992, 2.213472180789517, 1.8689948007945094, 0.6083036586642265, 0.28393651569081896, 0.22399834807842012, 1.5974536490055824, 1.898133108212102, 3.532485596595272, 2.9070156235848708, 2.100469921865771, 1.116751249759428, 0.46360111044299224, 0.3947848111631409, 0.3016882131416952, 0.14617516839456174, 0.19416772700365514, 0.17792741377507487, 0.2573376671681481, 0.15100830985653788, 0.20580003668944682, 0.15014007176843383, 0.20638287638223943, 0.2156159825502865, 0.13202603005113142, 0.2193197725160468, 0.13845612775654564, 0.2724676891680687, 0.08016649708752671, 0.24990114443484815, 0.09839316905145684, 0.15798847401334395, 0.2085864210441228, 0.196336675134878, 0.16823516047048956, 0.1201081304480472, 0.1997561239066624, 0.221988792200723, 0.18601304280661768, 0.1512559247954238, 0.20018335582027513, 0.15198995960095238, 0.09516539547832743, 0.12614116478230686, 0.14119783386347756, 0.15073477050229428, 0.11148095386283052, 0.18419444200492677, 0.1838583745543034, 0.15307886165476617, 0.15358052667110197, 0.11192751417477285, 0.11510474892753748, 0.17968313407994088, 0.26664100827709325, 0.11054706203961566, 0.12886974780309585, 0.2689763200619529, 0.17573620312877242, 0.13831696022422085, 0.12308387641584682, 0.13764848722325218, 0.31384327058349887, 0.18505914076682062, 0.10462321055632447, 0.14779014302597893, 0.1554786627210917, 0.2315833846167211, 0.1943625278410412, 0.2054216811854032, 0.11378919976132532, 0.11322168182701835, 0.10138981389783083, 0.1332523682785611, 0.22249788826992437, 0.11007075453357351, 0.12916024834398301, 0.24571295707456528, 0.1853781551002495, 0.18454462079511535, 0.1613422690500175, 0.09406711650832046], [0.04339418862195265, 0.058475881965169986, 0.02871905239449153, 0.0391430594778109, 0.03219007995099791, 0.028096330164360906, 0.016432921139283047, 0.06680145739547669, 0.03553662013502852, 0.040366199288156726, 0.0698143586276039, 0.0061480724909943685, 0.04417417338117958, 0.017499692828184175, 0.02063614297507992, 0.06752818372220763, 0.02916317080117522, 0.029527018515152798, 0.0377041012078764, 0.029469284213959213, 0.0486626327338238, 0.03294734254239067, 0.01440714430739923, 0.0389552453622943, 0.042190093757404436, 0.051477576846316944, 0.03830826112760171, 0.022565648410349123, 0.014545584056195954, 0.010648049496775194, 0.02729661864108376, 0.04558576699045878, 0.05001983793091871, 0.02577268206814845, 0.01912819848756396, 0.03937374770400986, 0.045951769326723395, 0.07645277862226771, 0.02472006002320878, 0.0032510379875724717, 0.0448932005242715, 0.024892378095237, 0.008154778042808175, 0.01833974654155393, 0.08779008317017749, 0.022471335325990955, 0.03790740945166157, 0.039464954301835074, 0.05279172024118805, 0.0445181813331381, 0.03965292163493653, 0.03105491193221702, 0.07471588875858054, 0.05131511258021478, 0.012042398466878842, 0.08243630835486036, 0.020311319779965187, 0.0452854911676578, 0.01782094605357176, 0.07914478860555157, 0.08269044270198192, 0.11000311663073879, 0.05452304447610533, 0.0384538714593697, 0.04399384394468319, 0.03595050296656067, 0.042259819249832825, 0.05288091585821202, 0.11465104867614086, 0.003523477766242239, 0.029525584015514583, 0.04498518853177948, 0.07179321736217507, 0.05652577067995745, 0.027982345857327024, 0.023183084633802215, 0.057496331301668, 0.04417191342180295, 0.023072074663134354, 0.06618831892527881, 0.04342139623458347, 0.07172581694659687, 0.09325209854831619, 0.049926854009109164, 0.05937591653257128, 0.23910616885029504, 0.1711481791590491, 0.21360437355695233, 0.33907526503166846, 0.10345397652277064, 0.05323175348401551, 0.02928286820890442, 0.08043522540960582, 0.10973395929942209, 0.07867480898576398, 0.039947168345773415, 0.04127430076140069, 0.050822870445347605, 0.10017065391425165, 0.020667621527888605, 0.08043783776942762, 0.029390432699132833, 0.12230150912317539, 0.056199827081253456, 0.08020958953326748, 0.030881812450506037, 0.017552868906228293, 0.08563767487723982, 0.04259245462655541, 0.04806760075171629, 0.06687209836297459, 0.01164467242966977, 0.06226036014155515, 0.03929485596956746, 0.1291759225029138, 0.024280591770225478, 0.11704685842438091, 0.023041431146163135, 0.07820870577087326, 0.03281046178251986, 0.03364553975482141, 0.002809113704584419, 0.07021346745351631, 0.05289050344858439, 0.07475443064205109, 0.02288638644160763, 0.0367387767971283, 0.062008700258429014, 0.038679495844389164, 0.012449198815551017, 0.045301552200990344, 0.028009111054181576, 0.059285158096181775, 0.07269700192996571, 0.07298686661787572, 0.04492723014986804, 0.021024024782461986, 0.03209796362376261, 0.03457678091381827, 0.07433780904618964, 0.03843612120216412, 0.041682981855926976, 0.06979467782882914, 0.05049346412922587, 0.010862861508353343, 0.020494815074808655, 0.08786022618052461, 0.022119660749130195, 0.06576792051595065, 0.05152734574831782, 0.014864550509129562, 0.04872087839870684, 0.018399143253543207, 0.06214793290822737, 0.033434788966851856, 0.008241288521657548, 0.03450692518644276, 0.04417972368819099, 0.04813678232171843, 0.03476776663334139, 0.010436656152559145, 0.01695550227117154, 0.030547893876510284, 0.07844102193391131, 0.046087048962832465, 0.02443041558557701, 0.03453596757965223, 0.01630878233681283, 0.025358224670673092, 0.03659105589312892, 0.02974487668383987, 0.04617985668441942, 0.06927999697865979, 0.05701506337631614, 0.08433912520206745, 0.04857630994651587, 0.05780274348874247, 0.03735444335747631, 0.020487931774808996, 0.06034719344649104, 0.007247156332126789, 0.012111070588411344, 0.025482204509899024, 0.0360460800959939, 0.030340247659853874, 0.031133206118078485, 0.06078968583155544, 0.0028736408116416105, 0.027936516562476758, 0.03125742344456094, 0.016483743412179813, 0.03871330330448766, 0.04221457792746444, 0.03496461292548526, 0.03210361926786361, 0.00919261650602904, 0.029598705192667343, 0.015345994634704005, 0.04441457177181879, 0.027001556046607516, 0.02183255206252779, 0.043791363075856245, 0.05204280800816994, 0.007938224617617146, 0.01271209242047682, 0.02301218957009335, 0.05018558871421603, 0.06309070369048465, 0.038602990473830895, 0.04937207228654335, 0.03297312140104271, 0.05314288345435935, 0.11691756576540009, 0.02156459940447202, 0.022045089750580733, 0.021398521118587064, 0.1389656221914676, 0.06037695979278895, 0.030119631574639393, 0.017483290885725332, 0.03230922960586125, 0.009628272513979146, 0.03727368236849866, 0.07372352910498459, 0.05655138099926615, 0.023521781681225668, 0.023283616436885732, 0.06104680026070245, 0.04604027546461552, 0.042802581052866676, 0.048867017331142584, 0.07631327401125625, 0.039215860813255274, 0.06145147854582437, 0.027894538774665807, 0.017670507452660994, 0.09087232302033132, 0.031752932944425175, 0.07789524557489542, 0.017056987853720784, 0.07152698648672912, 0.09891583253779719, 0.040162017704137874, 0.008031891794094156, 0.053045172770057, 0.05578659542445695, 0.041135029807206125, 0.0607094266301682, 0.0641094780557098, 0.06404000154185681, 0.10419210223781486, 0.04619644248798009, 0.035070693120360374, 0.06056925935310222, 0.025867090913497155, 0.06438622731835612, 0.09565646549867046, 0.07476738518885068, 0.10803954135025702, 0.06068636355320774, 0.10283985746002967, 0.38752352338164087, 0.46626188702160315, 0.4297407289906856, 0.28498565778136253, 0.05510000827451868, 0.1818715408444405, 0.11536841340843709, 0.12715148153684794, 0.18143772057467894, 0.11677305860024308, 0.10278623130533004, 0.07054531375967688, 0.108625422412109, 0.07122455029598168, 0.02005757805290482, 0.15970840269038755, 0.10255928541864119, 0.17955050893848945, 0.05639913634607389, 0.18724975386454215, 0.09542650122555996, 0.04464349033491266, 0.05638523568068782, 0.03584765949316564, 0.03448202732890364, 0.06346484571094475, 0.06442908227684037, 0.059633494444912484, 0.019633437304066557, 0.05270142528799273, 0.07849699997853848, 0.04427453472969994, 0.08191165303991688, 0.04232811215784281, 0.046284492803557266, 0.04264016658247959, 0.03653380614254744, 0.10631639510393144, 0.02622042024027436, 0.022952130192049572, 0.020876928240120895, 0.020021815153379596, 0.04520672200728328, 0.044144533439389164, 0.009531869924807502, 0.018458739148392793, 0.059333862135967905, 0.040972044601315455, 0.029055495228197788, 0.06371238404103825, 0.06851617667463518, 0.03513644644690137, 0.014884858542392332, 0.059438080737187024, 0.014176616959664372, 0.06409861875938312, 0.07872054443484353, 0.09506877646931718, 0.02777835004962981, 0.0371786376701728, 0.04138693483846803, 0.02965921464736664, 0.13640932468397005, 0.09796573029410455, 0.032489949747199015, 0.0248069899351967, 0.012428299936976646, 0.013648726838460613, 0.018520832489875537, 0.048794376874162305, 0.059057821504651546, 0.03817523378999003, 0.06843897799450545, 0.05054394932343595, 0.038182592064502745, 0.0758029981666515, 0.05638429339254095, 0.020720590762193167, 0.06836505817069162, 0.03551294418772863, 0.023152249594849926, 0.032730646912128694, 0.0841830347874953, 0.03621274635436074, 0.023050423103174376, 0.01965363904262983, 0.015996836122095345, 0.06790918222959004, 0.03924704825265273, 0.0660692458792079, 0.051048697843667, 0.15444721726159896, 0.1253283148511283, 0.101937428867865, 0.17785068240857896, 0.1094086783667726, 0.12604899674413667, 0.20864876527940074, 0.1094115435356094, 0.15907653337044103, 0.16530478222956582, 0.09998269424202944, 0.06214796738218396, 0.2639997822623099, 0.1230223059293724, 0.05315716333326794, 0.19139189934057577, 0.25325273313829977, 0.061632635357278975, 0.11697970315693848, 0.13407192913995636, 0.10512762582830845, 0.14807272221772902, 0.13057977862415776, 0.06930093416163037, 0.11794293614765329, 0.19031237420295516, 0.15090638951909158, 0.10446384894631564, 0.12900349143291676, 0.09391847246837232, 0.0950386232486175, 0.11053044559253801, 0.1263675054595355, 0.16251752453465618, 0.08112612180411816, 0.15746310623663087, 0.1833451722538279, 0.37014123352785266, 0.09080505283970026, 0.09692074040011053, 0.2752765965077185, 0.19190629673821313, 0.08799062966699563, 0.09074460084159529, 0.14772153219148038, 0.1639546595153309, 0.17200032940074322, 0.22023313318289098, 0.18042441607723314, 0.21378218256417783, 0.12732143814284957, 0.19158443255770594, 0.19654690498305907, 0.13113021279775328, 0.11769362049357546, 0.17401990570848988, 0.13735596421024493, 0.20323555736291796, 0.11085449312362941, 0.23300806300774698, 0.20636332581841177, 0.1741565298289061, 0.24089198108882676, 0.09878205826445934, 0.14828403991076256, 0.1703953139123417, 0.21959283689577735, 0.12406229326922087, 0.2645864830382409, 0.12557704827838367, 0.2146945779602374, 0.15113353458864076, 0.1448862561054768, 0.1954447802516722, 0.16464770861691044, 0.15248298314550232, 0.1913739575613891, 0.09918377945019353, 0.08681158204713176, 0.21858452729159789, 0.30374304481571723, 0.23340966161941332, 0.14026156716769742, 0.14389299246813023, 0.23567394173193365, 0.40897858178903984, 0.3942255056913822, 0.42073809271377904, 0.5234245487278508, 0.24626930544693626, 0.21887594713799416, 0.2271597937590653, 0.1772412901083308, 0.27893098912412123, 0.15207422927262323, 0.11664512957776747, 0.11380884225570387, 0.19145920782560305, 0.12326718593436865, 0.10495280456398765, 0.1125195086182606, 0.12766032479703426, 0.20687865784331677, 0.21159080337853203, 0.20179194127840383, 0.12997187253448272, 0.16478315296192325, 0.23917140889792676, 0.16244526712163804, 0.13795529011516802, 0.12285781919115013, 0.1810434764070857, 0.15691395909074815, 0.11222487886346157, 0.2831277107038806, 0.17244798521841728, 0.19425598033253225, 0.13129415561354932, 0.13205201575352302, 0.1828048504408329, 0.18019135680890855, 0.11440586989685414, 0.2901597849784359, 0.13533067288658313, 0.14115899320571654, 0.17861240363169104, 0.10102059016184461, 0.14146639364621333, 0.18547232262790206, 0.1246153244808797, 0.1519371148559355, 0.15230256943933426, 0.22995803715480914, 0.09066770093575602, 0.18995200644337362, 0.24352439709248083, 0.11628784915252079, 0.18309026415790283, 0.12459931324326223, 0.12336873088873203, 0.11028666109327348, 0.15571530728090197, 0.24551233396895472, 0.08206805755053798, 0.16086565510880563, 0.1019610703412083, 0.20522239107278087, 0.23525817049366815, 0.1968297599664619, 0.11276520067645658, 0.17783088669661554, 0.1521414458270996, 0.06160225614064163, 0.13787731768623476, 0.14420053080445336, 0.15482532761750684, 0.1425024662767687, 0.1552348782218272, 0.12565174951188027, 0.13002583576786902, 0.21723740764202612, 0.12862910426432086, 0.1255698240692577, 0.2673571779122276, 0.17347226009493874, 0.09926139181780239, 0.15994011364396543, 0.14856836578298002, 0.0870288445824577, 0.08555748845420538, 0.09566562024936562, 0.12619260758642228, 0.14534210906394068, 0.21617511948270185, 0.17056290330665727, 0.2693335928263203], [0.061213864884789915, 0.041851881260593096, 0.031078769825398925, 0.039234484410694534, 0.06307350118614494, 0.017996395509990475, 0.0313161555752759, 0.06000004836448258, 0.07430018646822822, 0.03958922525447223, 0.05574109746263393, 0.04110866106085239, 0.045469298643330415, 0.026316740474994146, 0.02402668916470101, 0.08630519026830312, 0.010408511039830986, 0.04221941577270628, 0.050609288962497834, 0.01951840537179622, 0.01526246902592961, 0.09082506305628246, 0.051334617178766966, 0.055246583877071265, 0.039601812079068155, 0.024266514904616822, 0.09882195612355586, 0.018942975664451238, 0.0817344032768761, 0.02496894666804902, 0.12214600093542569, 0.007631465296951995, 0.06559447054901431, 0.057110544744758844, 0.046769273242041956, 0.07144221119702825, 0.051209806134143186, 0.03408101860493903, 0.03813950727964121, 0.04738929501223949, 0.01762078451593557, 0.033125749098197106, 0.0959616749277038, 0.06882474922965612, 0.05813699148054566, 0.022460625416809515, 0.029553257026559407, 0.025806954926660946, 0.04760691377845022, 0.01950832173949288, 0.016503391652217796, 0.053307845167094664, 0.06841930485660992, 0.031162133598099315, 0.028617421255236673, 0.04823531655053939, 0.02032642894905181, 0.040739873994983015, 0.042994895934938424, 0.03815747970234483, 0.04590520267224601, 0.04155878751208225, 0.04752499599670691, 0.13846475390657303, 0.04201446427032352, 0.025065829977393154, 0.04274130167980348, 0.06811100809324173, 0.008753249759695703, 0.2456103166144702, 0.05624293867919234, 0.022153604189835252, 0.025105444383957697, 0.0186989211191934, 0.03189878842432893, 0.029472794811872226, 0.08407407410202489, 0.044375665996584206, 0.029774681334534002, 0.055757388322343754, 0.12861937494768252, 0.050111232220285365, 0.06945546941771623, 0.07558791132103052, 0.10446546539183586, 0.214014123344133, 0.13368140815967514, 0.13122010555478836, 0.29179112324791573, 0.1721705847810353, 0.12834413487824703, 0.08074673974225599, 0.03456122166807613, 0.015981349654706017, 0.06586769580720894, 0.02021324328867899, 0.03633877930922374, 0.11940455529838802, 0.07064958598705069, 0.046769365172592864, 0.025048901349486365, 0.08922742499459176, 0.0607424296979462, 0.05084204179565272, 0.03535539054522111, 0.08046137199046151, 0.05074409362409384, 0.053272819627196565, 0.13654720518858204, 0.05443369564149649, 0.043842438157768025, 0.06814013475612288, 0.026474340082777124, 0.036701544924008275, 0.06542367124629599, 0.0005843986817184956, 0.06273929915961719, 0.050799608185526826, 0.03960245176248493, 0.025262833317561496, 0.01185606768910563, 0.03928154519188308, 0.027480529538626154, 0.04467532128816651, 0.05206883584539737, 0.08034945420560338, 0.03426644252613187, 0.03712853551992486, 0.027345004754381317, 0.04152488812143284, 0.03776626158205252, 0.11793581919083673, 0.02594385483872987, 0.045455470756297155, 0.06123178368133884, 0.03446815730703454, 0.03823470519555192, 0.013269072815385318, 0.04465035065227459, 0.04888657172540984, 0.02512905904422364, 0.03028140827682951, 0.0644633953549689, 0.04528414285291107, 0.07024699912196206, 0.045535526944384466, 0.025963162169641545, 0.03760063337282308, 0.05125937968372338, 0.06142451991176894, 0.0884691435062597, 0.019128338298610142, 0.04232189535433727, 0.05652562129281222, 0.04551351723831989, 0.0418291705840778, 0.036612402933139, 0.010428323031162784, 0.037540139239882274, 0.04891965140198027, 0.07567269427161064, 0.024732298277799162, 0.0177712882343199, 0.11169685276165126, 0.04900387127793605, 0.02278163349406133, 0.029679154000815847, 0.05421804189081154, 0.016373417174984372, 0.04502332821908978, 0.11067126787477925, 0.044348163440102534, 0.041397460886547645, 0.10436559050914743, 0.02626078732822451, 0.02143760117882442, 0.01564860989850375, 0.03554868985027556, 0.05975230702108914, 0.009686814080322943, 0.03542695847910739, 0.03483904728425607, 0.029812704193435853, 0.07291690746863043, 0.03600521696611278, 0.026821107866482872, 0.04850317536282444, 0.035328585128750534, 0.019554394267259106, 0.012959688207164649, 0.023229480833716454, 0.07132003549486399, 0.05357957655383695, 0.04980928249536984, 0.028017340753708157, 0.030551820077122222, 0.03672332480369556, 0.13871174065336106, 0.006816735098724284, 0.03347241537525289, 0.049439093488599026, 0.006920235013709434, 0.08596640320554857, 0.034159113607940175, 0.0862264747340833, 0.07996087908864984, 0.08102846091553088, 0.004721562671024473, 0.016845603127993884, 0.04528913774617738, 0.05037868883641017, 0.04236662722823601, 0.010527493112960891, 0.04204592750137372, 0.016329468625988212, 0.08850669713630792, 0.06267205196162386, 0.03041085223817537, 0.07809929309352752, 0.02437261808212967, 0.07041154714721827, 0.05240339027237027, 0.05561601062635741, 0.04964692165113745, 0.03305149985657584, 0.03834487246950308, 0.02583476391831233, 0.029416284336137678, 0.04020402230502617, 0.04224897910570426, 0.005508441742764967, 0.05554661455173647, 0.022037810000080257, 0.13204838449676193, 0.06194691143689617, 0.06562216462747705, 0.01763693556459921, 0.0357898811419164, 0.04873105204634128, 0.030515291089672717, 0.10019511510167392, 0.07517803895978198, 0.03566033567392057, 0.037621034294246666, 0.04985468469620232, 0.059927124454970324, 0.03023745972783335, 0.05988928354195049, 0.03318122535523388, 0.015224180909083977, 0.03095843656469257, 0.05704318263357686, 0.055021683445140246, 0.041730057958874016, 0.0692983601062048, 0.03440546450175105, 0.029494848567992452, 0.0815224803743824, 0.027163635353527726, 0.11265069351441438, 0.10379385909125691, 0.1763580979839448, 0.11868206543787835, 0.049936682917177684, 0.10022339140695911, 0.0936381608968781, 0.07000726722781697, 0.0796788668019637, 0.12313222422474816, 0.056184673862111185, 0.04756449549008281, 0.02203325943781003, 0.03783313339696296, 0.04246237289701258, 0.04159016264302116, 0.12387845515003129, 0.12040344968197808, 0.10472493937178966, 0.04253408638760448, 0.029723205971681786, 0.0396222589657672, 0.030618912142310894, 0.017872509516535268, 0.05655374821095217, 0.017189101631482764, 0.08430238362521895, 0.045864193985659274, 0.07314239778826315, 0.10845786366131037, 0.018609620165079832, 0.023124733631829583, 0.04283392170984899, 0.026847396173604557, 0.02877489828895177, 0.0230954920557598, 0.03729390325926004, 0.047221644330889954, 0.11010430152377776, 0.06300307472326583, 0.03696224847508054, 0.04899862740609435, 0.04115923818561339, 0.012779638392760629, 0.026551804978460557, 0.03529272838345459, 0.04297153408368749, 0.04175682507094838, 0.06557690415291056, 0.054301093482682784, 0.06127906662802543, 0.04489188668348136, 0.04971468212804006, 0.029885262295964266, 0.04738874725937363, 0.056153436626998655, 0.05496617271414688, 0.06476437597866021, 0.04328743426970417, 0.04679673749412741, 0.057323092008910836, 0.05111945372435355, 0.041402478762451685, 0.03166644161777391, 0.03862037683927244, 0.019139992411158258, 0.03963681463632853, 0.05122401706513859, 0.02750666271294317, 0.012038923300532325, 0.03933306460479095, 0.0520793657239166, 0.01794795577053822, 0.035956669974351124, 0.011986472133186557, 0.010944650970369337, 0.03309613213904443, 0.10021420601274698, 0.047281468136897015, 0.02071557288628913, 0.03873556198912763, 0.028338816144593784, 0.03627303364356199, 0.060733236642854835, 0.0526392802355751, 0.11127528223779895, 0.09644321481426878, 0.06893452962920552, 0.05655648697528148, 0.04577849939044926, 0.035842557347589926, 0.029829833919422764, 0.04773393115629593, 0.20488785579800609, 0.2264535832669466, 0.12344151690241792, 0.10695000344346609, 0.15851462319973977, 0.11769997902334699, 0.12299800562041423, 0.1917732425875241, 0.12748168075397132, 0.14415974428336467, 0.185905177626879, 0.11342614303312956, 0.1322962599055421, 0.07747616483679703, 0.15095935683817635, 0.18560909996590308, 0.24817304926053171, 0.14752392747229146, 0.11133123729978839, 0.2244167853026621, 0.1528510883931191, 0.2614317942530878, 0.11959150373455017, 0.15310550619277263, 0.1635772846038303, 0.09679248962070673, 0.14226713938818825, 0.11887577076953267, 0.14323421814028295, 0.13860081112192524, 0.2972162821360173, 0.10001054153807702, 0.17371339392998528, 0.11414797405802435, 0.1427532374979027, 0.2672544301998231, 0.16435500174280138, 0.12531413456364987, 0.050908170505276615, 0.22532512043272296, 0.1213866392631204, 0.099665870920064, 0.18611793556521017, 0.1346649118368664, 0.18015351206544908, 0.10208772765772958, 0.16150734567594144, 0.09142087261763313, 0.12423946642346921, 0.14852074575760674, 0.14662509183249167, 0.13069964074079068, 0.24505139418667365, 0.14525204776756226, 0.0506702963743479, 0.203110393917849, 0.17520312850754108, 0.2382143046106062, 0.15854925037391726, 0.1668333114996072, 0.11050740166777566, 0.16589931242408293, 0.1410576857386097, 0.21396979749683412, 0.1823656522338429, 0.17719184679369773, 0.19573682829016642, 0.16912065085864839, 0.16986590119138842, 0.5119333217941946, 0.21431173318095748, 0.13846847709388505, 0.11453520086023117, 0.11171866328485551, 0.14758791113572736, 0.16178886766635603, 0.19158195043283124, 0.16135595138034514, 0.09608136850499338, 0.1200709751837196, 0.2246175922693745, 0.13601085171103477, 0.15206408626850576, 0.2908899587008261, 0.2017887696743973, 0.2626883316664927, 0.25833594102051954, 0.2437210825061606, 0.5030380297572382, 0.3030514206376768, 0.17174517615668236, 0.2820686094703213, 0.23633244026812816, 0.13128733743102322, 0.2673090063035488, 0.09280513220977399, 0.14531564838703603, 0.22459911422864084, 0.22504724502082796, 0.1939883858205811, 0.14760211440584353, 0.30786478170944803, 0.09595206052425409, 0.1865983186590095, 0.23022679612040522, 0.1711216571951105, 0.17731514098423143, 0.10888183204036568, 0.17648776602600852, 0.19359437147936515, 0.25106921401475707, 0.2292536805954672, 0.19337792099723894, 0.15682814192147027, 0.19939745686227278, 0.0995673290303638, 0.104245996523288, 0.2613868095701741, 0.11382838515865226, 0.13487275149072372, 0.1318512241085691, 0.18933487665509025, 0.1267579345092658, 0.15091601158342055, 0.14082744567384645, 0.19597954026633696, 0.134231505254584, 0.13227888503141944, 0.09547856456089406, 0.09498931782981081, 0.21221438362713785, 0.27244179539622804, 0.16574679964011715, 0.2037040814156494, 0.1917182834398362, 0.1363672817786855, 0.10353915017819214, 0.07965771511437432, 0.08586502679052853, 0.14768823801029116, 0.23849424845989675, 0.17032872554996323, 0.1300902024752671, 0.19915800842065967, 0.1969099540503756, 0.11430425599457757, 0.09595303345591792, 0.12543103958089508, 0.13203631095107526, 0.13197963576643698, 0.19622269657350358, 0.10214582010502778, 0.12753763581596075, 0.1974771961930298, 0.19992323832646494, 0.1113286096182081, 0.09707767351139938, 0.14971622596344641, 0.1634835154418984, 0.09908833255570743, 0.18587074963556183, 0.18619246059848418, 0.10106754369072377, 0.165154981396852, 0.10022667026327503, 0.09669891198075588, 0.1278160704720405, 0.17315978815238323, 0.26066625791211284, 0.13122215867042542, 0.16542168724681103, 0.15918370907104787, 0.14214234366532297, 0.18341389034063588, 0.12712191820384997, 0.0800115404830825], [0.10725148202430819, 0.007753751603060312, 0.038920702457788496, 0.15056371839056093, 0.05669014633543069, 0.01221489561195936, 0.0219618255693105, 0.04389883755075355, 0.1022875540318989, 0.035737810145703056, 0.0844771052981096, 0.07935908638061055, 0.04415075407333432, 0.03954920482130782, 0.02890930650004697, 0.02278079462778424, 0.08774950349282834, 0.04894335033191789, 0.009869733851613298, 0.0703809495955225, 0.07061256095767021, 0.017668509878398433, 0.017637630789390495, 0.07313279104569266, 0.05866024102414808, 0.06832050249701546, 0.05864480435247383, 0.01252900889789265, 0.03260945180250752, 0.027601458432693637, 0.04184430082058234, 0.04461415299785234, 0.03233404702416832, 0.12731980637557086, 0.059055450462525895, 0.02238686647145979, 0.038287944475849794, 0.007266518246803073, 0.029055801663367502, 0.04112929180865327, 0.058151930195069125, 0.028790122371227033, 0.056763920602538896, 0.04788590767871469, 0.022845578853101022, 0.10450766917558447, 0.06696563003764999, 0.05899130209018627, 0.023388015068767053, 0.08918029526549001, 0.012458768211335186, 0.0680217128847876, 0.011779088301644211, 0.0323191887488769, 0.053603819406200806, 0.032170023769140244, 0.03254226972198775, 0.056159075034121354, 0.11229136763440986, 0.021487565433245995, 0.05994767476353915, 0.009033548882261159, 0.0047696634165702335, 0.010668330716960614, 0.01050634717103094, 0.0427411254795809, 0.02856351739366449, 0.05376439909600923, 0.04380247901163755, 0.017817841482258612, 0.025914967578325062, 0.09280204487543914, 0.016584694648401874, 0.025107022525081714, 0.02071511323353456, 0.05804154075561993, 0.042801619612521706, 0.12921441076022963, 0.020418424617439028, 0.057601147451468056, 0.018981592241494406, 0.041888641989639694, 0.02577795849872693, 0.045217753673392924, 0.10750780738289319, 0.06882325535820377, 0.051611232376026536, 0.061904428031055204, 0.07267922102924317, 0.13040750077174557, 0.03196959410073056, 0.0723812358093358, 0.0537435959784254, 0.016743068004988374, 0.0314822415220401, 0.027693080633217772, 0.02791844454834298, 0.03699223315643688, 0.029084372912503542, 0.040056703597187035, 0.047877300680885394, 0.04151418204269102, 0.033924912868608395, 0.006589274975516263, 0.10553633373591209, 0.1279260500544502, 0.05003194212012234, 0.03729851893900383, 0.047392370855255474, 0.05149828803334987, 0.05497876719962205, 0.04938443311520162, 0.025867629090263963, 0.06840709341509689, 0.04745824675586435, 0.0436559263917227, 0.09755277825940041, 0.04858862480989868, 0.05651977221151033, 0.02705259090890327, 0.01666042627015662, 0.015255839492554869, 0.019069778537678144, 0.013350009046975645, 0.022951406238961126, 0.04352912351849579, 0.07384405771811163, 0.06190297629443869, 0.04175173058625191, 0.04759729554456088, 0.037446730139274756, 0.019418574539163423, 0.027046515831663728, 0.032570377487929604, 0.02522129794552682, 0.07015768859174944, 0.021656945558084596, 0.027172085303332538, 0.012574853514501405, 0.0822431316238738, 0.02327328574122681, 0.019981526589441686, 0.06287356372922659, 0.03596272206895294, 0.00928574119649467, 0.04475067752683836, 0.03889961205723305, 0.03580437935588341, 0.037305743148129795, 0.045542417905263366, 0.024312189066662424, 0.01975963113739366, 0.008655204869536384, 0.034989625696213014, 0.03964528756877107, 0.05593468405065998, 0.016840956804733125, 0.03762087724622219, 0.1097701492929651, 0.0451549306331623, 0.012866735886481982, 0.07255262499975582, 0.046457517591695634, 0.06849320169778601, 0.02367111711552547, 0.019651156917755163, 0.02989198663271964, 0.042536212281594356, 0.012766955807174166, 0.04705609656089256, 0.02286545691951629, 0.02044213886913513, 0.053522311481496984, 0.05481537213669189, 0.03359254945309893, 0.08227820312904735, 0.012586844705736205, 0.08873024159261296, 0.06359387406959169, 0.040848792545617595, 0.02493149071421114, 0.01377191856473444, 0.07618871577564748, 0.030952392130969997, 0.05868298617461997, 0.019770637905645757, 0.02274249597722965, 0.02741032332602528, 0.037531478615898284, 0.07874862921814765, 0.020326879025707324, 0.05094761637249782, 0.07043904204282068, 0.054089182071507945, 0.03270353506048841, 0.030232447597588745, 0.03959075743032079, 0.028662817710409724, 0.015057575937751082, 0.0441652293046636, 0.05005696638216896, 0.02539500838235742, 0.007094296414570342, 0.05112087098701347, 0.03498717804529494, 0.0300840352992377, 0.03389315852414697, 0.014847581661606749, 0.01181351342013166, 0.03923798160206887, 0.0495294688810264, 0.020142650201676354, 0.05595430356240081, 0.029340598679658388, 0.009492546631654185, 0.04191312999013932, 0.03981814764800572, 0.03518397454172373, 0.0468342489893398, 0.01111561498199139, 0.028602708536650867, 0.08729873735818171, 0.08127396145174581, 0.020736163414473978, 0.01640851549323528, 0.0650353949036329, 0.04192159909214224, 0.04992981110849688, 0.08810588759520362, 0.04395381968107916, 0.06843712406172868, 0.05007051464710986, 0.03969779523510126, 0.044541665758456916, 0.10122482154157855, 0.034648448439134706, 0.02305786564735876, 0.06718255549428925, 0.042322420124565406, 0.022770184310032957, 0.07034747155323144, 0.04647800278279089, 0.045147511071615645, 0.03075221718679513, 0.00650635649142186, 0.04559213318110955, 0.06365983040943261, 0.05666888356509228, 0.03769070233008073, 0.04799450447242107, 0.027360920231008244, 0.07172455290152181, 0.02667314181434772, 0.024799108805675662, 0.013187215363066043, 0.009176259571235747, 0.03861848460209947, 0.03723095381452191, 0.04314090846286666, 0.11621696303688711, 0.09277931504672574, 0.08132985522670132, 0.11676007340992652, 0.03400416849481483, 0.09355246630166808, 0.15357098121556545, 0.07239940741489972, 0.1139104868014974, 0.07629442824831895, 0.07626400689684576, 0.0603230425246781, 0.1709316827116474, 0.03681261618171008, 0.03036173642612994, 0.014342065138231604, 0.0647748254179474, 0.06336208650722139, 0.043229322670207876, 0.05207514840989344, 0.011253816285921682, 0.12328896581405595, 0.013916035025050084, 0.01921138797526158, 0.031445737432448134, 0.03176830258340605, 0.04716813691981858, 0.019974729474333507, 0.008859457316688232, 0.024595333248256676, 0.08495898226336127, 0.070149912799318, 0.035955773651479714, 0.0604527986668531, 0.008739549234779853, 0.08020693120817024, 0.04068223736999978, 0.018523123092769135, 0.034673947675694386, 0.014801567548044748, 0.04703099569005351, 0.040087101966022484, 0.015875950320473602, 0.013906222396349956, 0.06632580872504942, 0.03596645291714418, 0.04198807254133206, 0.029327184480104237, 0.018363386099677415, 0.051485065355776786, 0.02275284007942725, 0.02534585043547615, 0.03000124609248052, 0.03807687959183128, 0.05834700682410791, 0.02914694697415877, 0.08171912748366594, 0.035383954133477905, 0.06463946534260627, 0.073349371762766, 0.09746431808678374, 0.010104373176281732, 0.04409558808190688, 0.048527908511459834, 0.03701412794931281, 0.02298990981803546, 0.02323256242239187, 0.02754295421313615, 0.034836971185981266, 0.025379056516554088, 0.07343096778758111, 0.0761674568357487, 0.07967506700585927, 0.015262042889521729, 0.048265787697727644, 0.057267857069570216, 0.03558618985416909, 0.025184839821210312, 0.019930892008086367, 0.04914454034259243, 0.07546477800896091, 0.022516862016111132, 0.044282766344446334, 0.03486966398814994, 0.04481768723757518, 0.025426622915772662, 0.04618703109783031, 0.013115792985885374, 0.03544188953275162, 0.034050451696760235, 0.025509283802802526, 0.05344049329118383, 0.051106905204153834, 0.16171094120269822, 0.2818185890153531, 0.18850026982686213, 0.24907399930300253, 0.13367759304181223, 0.1190956456646804, 0.1701318869186986, 0.142520270160129, 0.21256768805605752, 0.23381061671722322, 0.16413418455950676, 0.14086267039660486, 0.15961585926913446, 0.13951870702928112, 0.1934077831045274, 0.1626536736805593, 0.13676379356653462, 0.1901952393593327, 0.12329304140181312, 0.19114641412611932, 0.13332549903181293, 0.20628757504445894, 0.1062675110334831, 0.1584500726312399, 0.1449314093277339, 0.1989794180037514, 0.14510681281887716, 0.1675574024838786, 0.08995010637708249, 0.14463527037972404, 0.12501048795398206, 0.09646717804454027, 0.1239424924396219, 0.30527387234953146, 0.23262203130270206, 0.1333475776857907, 0.13862541786605312, 0.09293846981299501, 0.0993211543367755, 0.14662879969804518, 0.1936553061128624, 0.14984436182966157, 0.1552828659694041, 0.1142981043085456, 0.11137770819327525, 0.20445559834761007, 0.14042891141387726, 0.24592243615658055, 0.10110618516562447, 0.2136463704969614, 0.2146008854070979, 0.20487847888181288, 0.15695427063732378, 0.1707457991377, 0.23289515696946653, 0.1316614947732418, 0.12986613707917352, 0.19488941247184433, 0.26756141695284075, 0.06855337790423824, 0.201025148553233, 0.16856808696062336, 0.1592526416624746, 0.11104327250993061, 0.138494600692103, 0.1349431549709651, 0.12931844550034693, 0.11772057146675165, 0.1297198755726699, 0.09586632762464786, 0.15659877519694068, 0.12593292676272894, 0.12132596509951739, 0.11837484885848339, 0.166031799669708, 0.132527434597573, 0.2509120893814872, 0.1767070050681791, 0.12131463465911728, 0.11005171724865515, 0.109585790233987, 0.09031512429036441, 0.28591504500758264, 0.17168609545596186, 0.11891973655550711, 0.22140926200776334, 0.21793195827593728, 0.23964262958015167, 0.22843880819216852, 0.27078762770660464, 0.25742527698316886, 0.1172273870437376, 0.27352158100374285, 0.15369830502858087, 0.14858042400690818, 0.19828236992320708, 0.16032090530760829, 0.11738345447567203, 0.18152266440372314, 0.10606649722303114, 0.1522950770994348, 0.1757449518528677, 0.0989050230371856, 0.09805907044679889, 0.18774418701087275, 0.2373038550778743, 0.20518673734078485, 0.1229090321688883, 0.12228043404437842, 0.2111824172278566, 0.09897031671097202, 0.1242193489545776, 0.16492058913553917, 0.1106664108773393, 0.19890017386886383, 0.189533707114958, 0.2993920024844908, 0.24421154731704345, 0.15524849926512088, 0.13318944181646072, 0.13810147501287923, 0.07094331941897832, 0.11569307380986792, 0.12523014068363175, 0.11514487661301129, 0.17103004840112504, 0.2962097038905467, 0.21722917985771933, 0.1698345222300099, 0.18752836472084447, 0.16459593639498757, 0.09130850284089966, 0.13528282303483258, 0.09040880918262467, 0.09396659811177561, 0.14739179262711158, 0.19382222134980465, 0.19679658835934055, 0.19339160332756658, 0.13610809891214296, 0.10842582586431697, 0.10769282527748616, 0.17227641216689543, 0.1908522670067126, 0.08193964589267008, 0.1039889203985372, 0.11546821934321236, 0.1091526211389611, 0.1621703947744062, 0.12977645882675726, 0.11809892697079528, 0.09815074052781829, 0.11769755818550626, 0.23382239914949865, 0.29727444353122867, 0.18753593366953636, 0.11111146965695005, 0.10547027397420138, 0.14394779839823324, 0.11633606672647501, 0.10593935727111756, 0.1457233757020966, 0.09767644017213777, 0.17100150396506633, 0.13572513155879515, 0.10279652752703237, 0.09768636101075719, 0.14049491754943325, 0.10088246450909685, 0.17134950706555, 0.10693007749655556, 0.11491053797785314, 0.12063991804156574, 0.13333490659152308, 0.2323705246371608, 0.33873159798883623], [0.051934142266550375, 0.05536638087623062, 0.04695095099328507, 0.032925206431818586, 0.07795821800227128, 0.051791504355928594, 0.03858041386270235, 0.04450597372206469, 0.029340209890036818, 0.037975323146149036, 0.036867544685880986, 0.0364094662419971, 0.020986971024784352, 0.04396350686288169, 0.06514238674313792, 0.019774052742568236, 0.05419251201073489, 0.11617830624022793, 0.12899596844950031, 0.025884266604759523, 0.09714939466287052, 0.061678953033180973, 0.022765524580233523, 0.024644420332004948, 0.07224673375246987, 0.06516753740969204, 0.011843106439036709, 0.029022120607776508, 0.06444367625179791, 0.08368360674789838, 0.02084832634746788, 0.08461238876465829, 0.017637513960982044, 0.035043209716076815, 0.027021617974124612, 0.06712875313936703, 0.13676756271912208, 0.043184360969931855, 0.00859666043036287, 0.025359410191735914, 0.028900417964905504, 0.06089950836594067, 0.025986836201721625, 0.030548761471084533, 0.0267938734407747, 0.0037637097721603973, 0.07190190225599274, 0.037716914028409994, 0.02293484341803818, 0.016529030699823654, 0.04587768096356623, 0.029465710413792444, 0.03847187069515067, 0.042423639491560965, 0.030675809492447206, 0.01640539176972403, 0.03641266848952059, 0.076402431323884, 0.03642555791884661, 0.006329820626565526, 0.07269035228678296, 0.01597796067325098, 0.06681345433237092, 0.04678300153764506, 0.11455498125043609, 0.036389291316511176, 0.01880913627363982, 0.011201033785548663, 0.04154559930846576, 0.020355475172700904, 0.028967104003494306, 0.13432875245569215, 0.029360995770642356, 0.043779959857103326, 0.025490348024534124, 0.06147119764899535, 0.028606854987541036, 0.02622500719172099, 0.05373609214720707, 0.012705746339634063, 0.06287782317808559, 0.09624657536586446, 0.03191962793108917, 0.04929013918304155, 0.08522597922673149, 0.09527724431527239, 0.02254641194257044, 0.09070639603681142, 0.033395929156892726, 0.07794455099370211, 0.02888409837689852, 0.06433605622019499, 0.08469143371668555, 0.03173936744250598, 0.07269532419741154, 0.1232329571259118, 0.03478918645170427, 0.02437401619259148, 0.08247852746036746, 0.08251847894561869, 0.04436418616903886, 0.056872080726128434, 0.05806105301505136, 0.022873537231897636, 0.014777646452609091, 0.04552789670865863, 0.028207012632441138, 0.017497040248746355, 0.08338803470495247, 0.034018666708781835, 0.06842072211926983, 0.04846998843394461, 0.04272675750056102, 0.05010197404772044, 0.02574310341339198, 0.02925022520245083, 0.04267920259266131, 0.10100885369484464, 0.03483735039950379, 0.06633402118759771, 0.05974743470189072, 0.059945893609115196, 0.03307311502735942, 0.12688522001788502, 0.05858959239577094, 0.05033292274381365, 0.02380908380502895, 0.07041827339919345, 0.05140063097520221, 0.03617283700394534, 0.059148759971703255, 0.050261975341146035, 0.01013624434915161, 0.022657908379070224, 0.04434452835290183, 0.00913474909705861, 0.026154841198736144, 0.01620245124814251, 0.03418507249725442, 0.04289656854985703, 0.04683642850948438, 0.06696803555373224, 0.01483986428337953, 0.01773720115212904, 0.10047394812347428, 0.004143148093604513, 0.003056528263597659, 0.0319802139945809, 0.03754667396987638, 0.02402819452747222, 0.0449526374558768, 0.010821248569916333, 0.04859072389081121, 0.043953781376682946, 0.05978066376560639, 0.07002801288880649, 0.060022337692639524, 0.04755750876821337, 0.051284809972369866, 0.02793273208813081, 0.023966223760057363, 0.05353128237109031, 0.04854043787946144, 0.026129253862065174, 0.07617756153546995, 0.02211864376741071, 0.0339324128693871, 0.011917642963629578, 0.07011389134511833, 0.013384911055195958, 0.048023075721557104, 0.02869276983302928, 0.026461230403172876, 0.0286516098440775, 0.13795323699953096, 0.05539265769203344, 0.0460377129005088, 0.02477421860901579, 0.02088713827693174, 0.03502793392286666, 0.054057554131554025, 0.020350093405032833, 0.04911769279128602, 0.015140920558253364, 0.02100387667005341, 0.025187743294443336, 0.03168185913725005, 0.05056253461647899, 0.09979321771571714, 0.03452827222645283, 0.08283135691477407, 0.008080919506028295, 0.052086226041278536, 0.09516257627476608, 0.05986742322303115, 0.020968228683716828, 0.04642973158268198, 0.022110620911623684, 0.03709628321831265, 0.015041202723589397, 0.023264757267409758, 0.03002509249434356, 0.05595476321515538, 0.015184373065318554, 0.040791014194368355, 0.02757807551402479, 0.009859316971062893, 0.02160775696768636, 0.038934262214048256, 0.05111415239591753, 0.045392387246172276, 0.020403449513739156, 0.09346356945893458, 0.07515791383001112, 0.0507888638023888, 0.009026859977072286, 0.07289528080652799, 0.029053265912338134, 0.03634606863582327, 0.029521328397095207, 0.03720787924624259, 0.012409635162311456, 0.018458199056406176, 0.037211587111796104, 0.026725578617544907, 0.024316913913935426, 0.1274167854459055, 0.03888183881738975, 0.0283363129523012, 0.09168216222596746, 0.0920345856537742, 0.052303745216059114, 0.03461862080580285, 0.06439781822865048, 0.061686751808250145, 0.0022786466551253633, 0.13363777179150813, 0.06320149149565447, 0.0486582851848535, 0.01321813562929991, 0.07992569267028764, 0.052448374955284024, 0.030589992323169307, 0.06263819087537066, 0.03485449544724918, 0.033247277456065344, 0.06445164356621043, 0.14394977490507788, 0.08191261064982222, 0.026841552837962107, 0.03189097049706165, 0.09502314827254704, 0.0708399971406306, 0.0115485695723985, 0.027357809914035663, 0.026120457257474625, 0.06385668436245573, 0.04450439558094067, 0.0598147968130727, 0.03378549635770821, 0.07755460457936411, 0.022384058759217302, 0.06818373281989368, 0.06804338551216549, 0.05739602740974196, 0.01957740180284506, 0.08204721995899755, 0.021858984011135275, 0.04339780455695526, 0.08690551974840703, 0.04886962203008514, 0.0936492768326594, 0.03229521785772616, 0.027090713359235276, 0.05959332462460284, 0.028606659635120345, 0.08095593537173926, 0.07038611302813215, 0.06787015771072719, 0.07035871772395988, 0.02622380443367987, 0.04580436251877297, 0.021232417934844573, 0.12479070498938523, 0.012473264510082382, 0.052106416288522944, 0.037907627786719994, 0.0416350209214274, 0.06901873035296317, 0.027972271801122738, 0.05258258972917834, 0.003891108757553382, 0.04339156477081199, 0.04660461030359711, 0.010397327113746396, 0.03464476355621892, 0.15736423492912324, 0.034081995367042484, 0.023931330370326197, 0.06076187683990406, 0.03783763416351811, 0.043707859492109674, 0.017753128120074832, 0.05384166672405216, 0.031795435502464255, 0.028629477563945037, 0.09687543396026858, 0.05145826760018545, 0.0030105807039240797, 0.019992270972579718, 0.030397028181581732, 0.031738268106334636, 0.045207702599826365, 0.004274530736203756, 0.00435636472708035, 0.010644133829872214, 0.06534704713210945, 0.057698980709838296, 0.10398111396258879, 0.10928917631146409, 0.054745095060958024, 0.020528084358140346, 0.06780702440488724, 0.00350560661078611, 0.09291015520331361, 0.07725747737793193, 0.0611540487396621, 0.04081273278702171, 0.04548378153553894, 0.06042241561977614, 0.05356780944332, 0.09601322498412863, 0.02028737761711161, 0.039753627723022815, 0.077322885964907, 0.0320606800397077, 0.03607709133516877, 0.06896281359536995, 0.07423817931163697, 0.021246770592105967, 0.06384930310530529, 0.014857572405749272, 0.018831059794812914, 0.034259072760300296, 0.06062450961420133, 0.02678687714280621, 0.036272478229816885, 0.07634856768192784, 0.11505180459109046, 0.01593888061301362, 0.048703503524584156, 0.01987468413708191, 0.1833289924768671, 0.10582166318331035, 0.14948203288499387, 0.22772971720945454, 0.15174911687931708, 0.1363815616575941, 0.1463323696366241, 0.1482585445046425, 0.08709930934973302, 0.12472453031448588, 0.1718657737177226, 0.08585360441957751, 0.17767800619044613, 0.11546653394977893, 0.12099245638256112, 0.11068960801968653, 0.13875203687817822, 0.22519750550629633, 0.20589912250157327, 0.10336769203985892, 0.1922279770576185, 0.12914963036535249, 0.12488386128097774, 0.09302326808533362, 0.09688189208147027, 0.12452500271460704, 0.15285836622839974, 0.09774949431659714, 0.15467332045157112, 0.18291913543737706, 0.1987767877477792, 0.18990620970726016, 0.13130062139563023, 0.10295530691021874, 0.13107706161756671, 0.1899249941831635, 0.18642127573970826, 0.18958675104283518, 0.11193804788373171, 0.220222974857015, 0.11067613253309844, 0.10787395910630304, 0.11036878571875634, 0.12753894582631128, 0.1689703750514215, 0.15294914764742698, 0.2227647779809852, 0.11269811435692734, 0.16391698331121476, 0.2310060760787418, 0.16370387297243844, 0.10489130302542642, 0.17413013043903536, 0.18151000863121403, 0.17421211716869187, 0.1981843106688992, 0.15532506209227348, 0.2837888752260516, 0.10346642545154018, 0.08438417117201513, 0.23845217491109527, 0.15800229423949796, 0.14503634805160184, 0.08024118299926482, 0.15170275323813961, 0.18966611775179065, 0.13207184210900338, 0.14609597022494963, 0.19209397295790334, 0.11221802237653926, 0.21396468002949992, 0.24984119039389396, 0.14976211463011083, 0.09520320191739068, 0.17661326654976414, 0.13717202649962518, 0.18947157738429887, 0.09761221136056608, 0.08184086651571336, 0.055906338797461604, 0.11672938392767984, 0.1939031815216426, 0.16852904712000202, 0.1298073168483473, 0.15403875450213111, 0.26922879199827876, 0.25499333086754045, 0.17802815433711777, 0.20462536343163062, 0.1749586545291447, 0.1370531909408108, 0.18549916634876884, 0.14737317669055156, 0.27777768971939243, 0.32149275043799036, 0.28622037701068387, 0.08593317797227253, 0.0824398783245875, 0.16232080847745942, 0.11563256818560824, 0.17924041186849918, 0.1323860147667508, 0.28989367667705784, 0.11488886535047524, 0.0849003382327576, 0.24805900941212333, 0.11321399030425858, 0.22836455895054728, 0.14147698098132688, 0.175609415577304, 0.08531114522127375, 0.13076399212643025, 0.184688200993884, 0.10899371918170683, 0.164733387890362, 0.14954604719194675, 0.18467900793879263, 0.2539704655927997, 0.155813213317625, 0.0923426679125236, 0.2156346291303635, 0.1668597108894779, 0.1556083614066724, 0.2120255582755612, 0.17065293395951872, 0.2081818500113103, 0.07170005340970333, 0.18085308823614352, 0.13059862438709507, 0.16776447604981162, 0.19312750217655014, 0.16587596206415087, 0.1407473128769667, 0.12136344978165244, 0.09624320457899764, 0.08626919179674118, 0.12248486460697268, 0.09967505631427612, 0.17033030369108723, 0.177773445424053, 0.20367451042177218, 0.21124964910409144, 0.16880382753668294, 0.2039757821588747, 0.15198343253183752, 0.1716967900433848, 0.12570493133558383, 0.09934492604506594, 0.18518805804271854, 0.10552388480714253, 0.12384997966188578, 0.1219367823233047, 0.19017175110357423, 0.14399765540034543, 0.1812299268860971, 0.15504899464787977, 0.18866808904755503, 0.14494890677592448, 0.3147340163348183, 0.13231919657799507, 0.08920923806726934, 0.16889834746478066, 0.14847896332221647, 0.14005804824973309, 0.17585415002559462, 0.04960475234134544, 0.11042389042314985, 0.1308913925482381, 0.2210903242831269, 0.13169809845426392, 0.08905646481340931, 0.13910881934627412, 0.16593792325546666, 0.09398661598923708, 0.1430925684830835, 0.13787284373275696], [0.018423075840297728, 0.015027574977026352, 0.014262775038068574, 0.0577422570166809, 0.03723593338602974, 0.012969982513647168, 0.03913383577920256, 0.023129387615969586, 0.058220265237914945, 0.016522289126089985, 0.03634971138390322, 0.05619886564090849, 0.02465486019519308, 0.09288269861210739, 0.03304283157171261, 0.029842288593851754, 0.049371348333454905, 0.07730778637191943, 0.054913358612646984, 0.07224789054523553, 0.0931264601287342, 0.052060899174501823, 0.04406396014195296, 0.030113767171579025, 0.06318608929793681, 0.010658827396259915, 0.0952900609662456, 0.07443222172197796, 0.015468326427282826, 0.006193104575598433, 0.005644639726773266, 0.0379441203849931, 0.03629043916120164, 0.013443710218604295, 0.061028391167881994, 0.08510918146179569, 0.0103427768654881, 0.04953218849315759, 0.06171449568242796, 0.06474289487326337, 0.05585652393018527, 0.03410521549202743, 0.003840294624340811, 0.05142679670825601, 0.07772168835564967, 0.03684193436657229, 0.01337870287017957, 0.05423221834785035, 0.01576673874120799, 0.05594760029306335, 0.018677468742093733, 0.09203450904498178, 0.055978902645649455, 0.024725870800114447, 0.047114817200288664, 0.044672950246040864, 0.07954991888254881, 0.04114650197387223, 0.09008938882259593, 0.013549304905257398, 0.04652726989720137, 0.02205409894457027, 0.02840152235641595, 0.08586290472697827, 0.05948323012900449, 0.017027968443149043, 0.034660736489440166, 0.036341587021466226, 0.11643436346803943, 0.026432911963051847, 0.06126648363386912, 0.0495028932909331, 0.03331879176379692, 0.014278336199030522, 0.047367875193876606, 0.044691719400185737, 0.04704367061476073, 0.045629357393350334, 0.013720154961300714, 0.06824905713719708, 0.024076965599951726, 0.03139081467393666, 0.08582570349737521, 0.0633520316032152, 0.0343405423806079, 0.06474284890798793, 0.031186309417769797, 0.04940455441453284, 0.12006100837982471, 0.05071896210973782, 0.08366659193510011, 0.013885234460054387, 0.07007925651006161, 0.05285221054368923, 0.031305347989884116, 0.029187959491185127, 0.03833152721786211, 0.05469364076552372, 0.016972884806173465, 0.059074652456347986, 0.01472140602286785, 0.034564672894175016, 0.0484308643236516, 0.02326531459637467, 0.03228916959356397, 0.039652396864708395, 0.10640810348934705, 0.04817008799422653, 0.04568105300648078, 0.04697595227269396, 0.024335715626817078, 0.054601989836702426, 0.09947935149313943, 0.0213899371033955, 0.039409956849750974, 0.07725563876691365, 0.06693166935996664, 0.036133310697492094, 0.021586275862289533, 0.03307262090064826, 0.09096969279550737, 0.12987634137032494, 0.03926168819288573, 0.03176628202650576, 0.016092328024247003, 0.04447120482162122, 0.05098047771400983, 0.05558977977583005, 0.02685459548487298, 0.0615527285563369, 0.033138898997417385, 0.018960166677472093, 0.011647578775732508, 0.03991174444015469, 0.06488131930030162, 0.01061934705508212, 0.06443074468763606, 0.07170448139790567, 0.018045530474234014, 0.03071826800043064, 0.039134115401294925, 0.02894495640160336, 0.020208888078829455, 0.02730756603752173, 0.05124302370653999, 0.032564593524101286, 0.05389027883328738, 0.05312412196109372, 0.03984431338105952, 0.03152530715470353, 0.0050287529161470316, 0.03066754531896403, 0.008641738001437438, 0.026309558400704015, 0.06087934876221323, 0.02270184543674752, 0.04921821118783086, 0.10184960454822549, 0.03659049281850457, 0.04034086093006115, 0.0016065365320349473, 0.051484034967518626, 0.024084936744803866, 0.015708863671358316, 0.009410708331533018, 0.026260168712225654, 0.05443335090193057, 0.052491800649271864, 0.12163762498887316, 0.02787935682722638, 0.008678820487412234, 0.04021286295967237, 0.029780308250337843, 0.028207876396575765, 0.03509636855714264, 0.11340389583980846, 0.0713480436693757, 0.10584079239877964, 0.025010955099376942, 0.05018923146229598, 0.06571192714956499, 0.06443129627094155, 0.03545819954465955, 0.027013351885421623, 0.023845471066212463, 0.04834522718503591, 0.026880144517147736, 0.01786880165098175, 0.0335257159425847, 0.10745121646792659, 0.008935638057488588, 0.0164748816901157, 0.024497680020548647, 0.1090168167326239, 0.027628443879826416, 0.020736335784256942, 0.03031618292293241, 0.026148827408530542, 0.02088565972723788, 0.04959471658953736, 0.036835633293395086, 0.04908947394259515, 0.047861626521954616, 0.07428028350395542, 0.06388178523329478, 0.044941774329110507, 0.025714072511501374, 0.12593504116539994, 0.02660340866104009, 0.06517954966834476, 0.026424747380998828, 0.023250218833826726, 0.012421525804506195, 0.055404217958810835, 0.05620571446695155, 0.02459793603197942, 0.07128540832068651, 0.07195903709338558, 0.023008772817951058, 0.07731206880341615, 0.0409388346897979, 0.028450209159223784, 0.07833534010475682, 0.06182332230251163, 0.025470950678291342, 0.02373836814395843, 0.06205291502297886, 0.04166361132276155, 0.03414299511801332, 0.003270515054839874, 0.02206220990046859, 0.09000672793556606, 0.09176747377721534, 0.0018077298943441544, 0.0658104690392652, 0.09579910340929225, 0.01712864963337779, 0.024335776913851023, 0.0760592852208403, 0.05661971221167234, 0.052546269500688206, 0.06021810763124978, 0.007506462251542197, 0.15777455162136786, 0.04744922224011633, 0.012437384782148706, 0.012543039798225849, 0.028026646806768356, 0.013054658211917888, 0.02449903408095481, 0.03735388794373121, 0.005706531970175885, 0.05504470438726487, 0.01758544104954889, 0.04524435224612394, 0.05501209202432825, 0.04519338824696118, 0.04170712511686068, 0.01913409544936111, 0.09836467824155286, 0.056831727044716965, 0.06427340554974734, 0.03248002507813996, 0.11458887298020626, 0.06307126420940604, 0.06595172033074402, 0.023563975888875224, 0.06870699385481496, 0.11968234644061136, 0.010984720241638922, 0.0379477899461504, 0.0816704196134402, 0.01852450013581303, 0.05612411844213644, 0.06753468014780553, 0.015569281493944508, 0.06336065392280299, 0.00893536801149528, 0.07691475262324657, 0.02739297718019976, 0.02790571216704144, 0.01344188214129498, 0.07842321038967179, 0.07434003070117005, 0.020040471309555635, 0.019430854928589637, 0.014323937582723318, 0.03373782653661986, 0.0626641842386415, 0.06655573469376372, 0.048246892139075265, 0.021385348236729062, 0.05944494871542819, 0.04332850807376447, 0.06195595127440268, 0.04711946352354942, 0.13128114744059502, 0.049003698908153086, 0.10455626979350083, 0.02123408226086007, 0.09435313543485058, 0.0044473932094631664, 0.04011401463480246, 0.08739562449796547, 0.018058810608401414, 0.04883817795123305, 0.032583711248251705, 0.02857485549494384, 0.05394133476300105, 0.041997767384013826, 0.01313223419035034, 0.02795468816804069, 0.03778660887732141, 0.02149132117929478, 0.043195507549230135, 0.04359995983841439, 0.022655037464573983, 0.052129207404270295, 0.044402337347668026, 0.05410620071474583, 0.020201257843103622, 0.019252871636361368, 0.025108234859221888, 0.07675454831652104, 0.03220362438549919, 0.012087963461395235, 0.022323183497534167, 0.02013389573192164, 0.03669553496424229, 0.020377088428264665, 0.00386698464881779, 0.029464716414710688, 0.033999893724197344, 0.010762478134805157, 0.06867365370835028, 0.0003697286358088135, 0.006741614910894104, 0.025777337967508265, 0.06435464151323804, 0.06458668954550259, 0.048524395998327, 0.0058268963532041645, 0.04473316858732893, 0.021567349660120184, 0.07006879940989517, 0.021377865472928654, 0.031549450415637226, 0.021203193595753084, 0.019633554132475008, 0.04042828305354042, 0.026086157585884777, 0.1100620900791499, 0.13061290426600364, 0.15472570554383341, 0.11824277530033743, 0.19534333488873898, 0.16649316846122666, 0.11307967210849447, 0.10288078187694473, 0.1115052694935472, 0.1516792343388642, 0.09850752299591418, 0.117347547934661, 0.11514295373232135, 0.12309799541629131, 0.3644157068863992, 0.1397709951045052, 0.12960260283322106, 0.16520234095233102, 0.1955477424686955, 0.15483810596408384, 0.1400072412985948, 0.19926342211904066, 0.15374891279685884, 0.16479216215591277, 0.1330990740849126, 0.24174287494632507, 0.20098537326820437, 0.1998358889813385, 0.2013742854638446, 0.2017706593558673, 0.08902531567840807, 0.08554490929048869, 0.17139780124829662, 0.17544021739834742, 0.18741149034711624, 0.11945185356683309, 0.2519147759003024, 0.10973245010621126, 0.13557320100165185, 0.1818050903778884, 0.13848114818815263, 0.2329268270442563, 0.27021082478665537, 0.1433765113113388, 0.07561066413238164, 0.17809448222960197, 0.1117263548076153, 0.19880139449190712, 0.18214357866635247, 0.10655362955144337, 0.16137151828696653, 0.2432805053409069, 0.13350154603681258, 0.08569602779443226, 0.12095730826859513, 0.1633299761001141, 0.2700018053573947, 0.17431051350168644, 0.15091403507657591, 0.15261530185178404, 0.18612512146993992, 0.14946786025839467, 0.12888626465874334, 0.21703643213597038, 0.11770030078027519, 0.1501002811616467, 0.17508020203921104, 0.14335385043053858, 0.20417871885001662, 0.2660544913622641, 0.1454307914020554, 0.13833481007285658, 0.0927731863433315, 0.10670339207976096, 0.1046241834879883, 0.1107606396920258, 0.17494963001339667, 0.11769510670414857, 0.15120882570983904, 0.14630878945031475, 0.15420887198659683, 0.12474168302311052, 0.18549861476546337, 0.1399316284204683, 0.14571053606848564, 0.10415015126308126, 0.2105920392298891, 0.16595166687282825, 0.2253876791726197, 0.23244941637160318, 0.16228328549092816, 0.15498991394715925, 0.22130593206853638, 0.17643216336446424, 0.2545586832228207, 0.09605761977934069, 0.33869326294910523, 0.10278975530978172, 0.1859362654748463, 0.24868835064191974, 0.15462075149820698, 0.14053653144548017, 0.09370883250789297, 0.17779006953200988, 0.10391570537561372, 0.12241118993129461, 0.1434391313382695, 0.16463399564306583, 0.1411753415220207, 0.13190311890455986, 0.142090157755921, 0.16528631951059067, 0.1377079050026594, 0.16449395477050738, 0.1784734046387096, 0.16221056842515547, 0.2065198375813423, 0.19929823315431996, 0.17407736230281093, 0.18292497302736008, 0.15380734998372295, 0.2226700129047517, 0.15310569005387445, 0.12868207158340564, 0.11481437862159745, 0.2046001591389218, 0.2500698676392917, 0.16847490002551388, 0.22285594244397458, 0.12478851397792179, 0.15915026167227378, 0.2269889101866753, 0.2193778113371903, 0.1011152633075272, 0.26706845469532475, 0.1917287328791234, 0.08228971743054929, 0.13138309842155826, 0.21630904697362455, 0.16011026177194812, 0.09789577114485926, 0.14932781938583622, 0.20766359153053454, 0.18601969244980043, 0.14109268063499084, 0.09833961950554963, 0.11285566033855562, 0.1702913711027753, 0.12104916221071636, 0.12629359329660095, 0.13028773058566356, 0.08398677072217388, 0.10162918573065151, 0.11486343889226837, 0.13657072408785745, 0.13755862510973407, 0.11148921229065427, 0.2027322222749072, 0.21853056405821156, 0.2353553104424669, 0.11273290240956892, 0.13763768538351984, 0.11676425624999309, 0.16030132410026368, 0.09491415694355966, 0.1344271794322037, 0.1698742362280046, 0.14248723644883404, 0.14021256818406044, 0.20550388241967849, 0.1435838300254076, 0.08999122997685786, 0.12301466037188807, 0.1651788526965726, 0.11362102814018728, 0.14903485204183287, 0.2592027235415674], [0.04210090197082009, 0.057144421152770526, 0.041880965788638404, 0.004489942211582656, 0.041565084754819834, 0.04355751473696963, 0.04331638856280235, 0.06396056971542778, 0.014640824106942504, 0.05204091194055734, 0.058047071910433234, 0.062279922196701656, 0.10406219670849462, 0.05267817451949081, 0.05581739981989226, 0.031611647178989746, 0.08156233226820346, 0.04280988187078507, 0.02651098398341527, 0.04513709610628505, 0.08636620151059282, 0.043172578537656416, 0.052802207984871445, 0.008763131336309016, 0.016061845385739883, 0.01787778786233356, 0.01819779236440457, 0.039659322299543893, 0.03542477512852319, 0.042173718628022945, 0.06196549672993922, 0.09194403406112425, 0.07926641272441035, 0.006736644436680382, 0.06879995096354716, 0.059901422205110716, 0.03621368098162836, 0.02316135838026962, 0.029702598206518643, 0.04243655190352471, 0.018185077220081322, 0.03452337309417706, 0.022141136108867587, 0.030719436284515168, 0.07113310238046032, 0.008918701768702558, 0.031300872121186506, 0.012018939897027469, 0.09969112117804828, 0.034546420849379034, 0.022859473772827658, 0.012924790986993862, 0.07384993361249086, 0.006761397695123789, 0.025001997616322293, 0.06845789270535593, 0.03429315218161191, 0.019875218483409094, 0.0517109846846471, 0.02022766106341395, 0.026010272746545174, 0.047436087662654544, 0.036724427970306533, 0.034947119307734316, 0.02151565021655012, 0.05839207960713295, 0.03644073412062661, 0.04066295493694563, 0.05252767654676592, 0.033339686811931675, 0.011717975552704547, 0.04235634632829217, 0.017735981157109622, 0.022338070501122746, 0.04277872124446496, 0.020567681527726596, 0.007398513759741741, 0.051559900654660124, 0.04673214096035208, 0.01694421588082708, 0.047802603277828426, 0.033340403104140874, 0.018041269110155203, 0.004770963850821699, 0.07932547044249312, 0.135734339935645, 0.06297462987863729, 0.09577155488753512, 0.04291112805085798, 0.04744051182041726, 0.12442557216291467, 0.046720661132806734, 0.044473943585950526, 0.011700316268439976, 0.021898531385006446, 0.03590985817173797, 0.02982533698330724, 0.03161523055525557, 0.05907800792145634, 0.04607467664285533, 0.09176266274505085, 0.05315904790956167, 0.03327901264832866, 0.018575205580301343, 0.017568485608564752, 0.04127435055711577, 0.050788476927987034, 0.0395820968063368, 0.049688102707507155, 0.025414325289368152, 0.06188332230874127, 0.05237608689874892, 0.026639016427760644, 0.11455727951420892, 0.054510476803707505, 0.013521638597481915, 0.027394702793249202, 0.03932574463467445, 0.01931139500811696, 0.03245261062176959, 0.07567701500750358, 0.08600222547688792, 0.023691711474149942, 0.024313613990201585, 0.07267819447142464, 0.04367355790530001, 0.08052196188439285, 0.03326287117576407, 0.060468744786997, 0.01193023074583541, 0.08104619585097798, 0.021170835957051288, 0.054430148654407075, 0.10246088142476736, 0.014070138399068628, 0.018930063252487493, 0.06038518374665611, 0.05959624725003397, 0.03864734696464674, 0.04005526335188939, 0.03785398631026188, 0.02767474623396993, 0.03760400032925029, 0.015743611504383866, 0.024283433956424558, 0.05522636298630988, 0.03623305534523341, 0.02493186992773366, 0.07840958168549884, 0.05005878584098913, 0.048791189948397304, 0.006842594396608372, 0.05625817233756666, 0.06132199819530211, 0.024129023189626397, 0.05020088749006391, 0.010797383015855186, 0.04531707314233627, 0.07841971702873707, 0.02661718483713846, 0.06026338342757476, 0.04722665837635437, 0.04169813507506925, 0.09407875338389028, 0.024075837535483223, 0.07691725773075897, 0.026523118816135872, 0.059650382853203246, 0.05456955367398839, 0.020897447905172745, 0.048002812695959886, 0.016625260919212334, 0.07541241589933634, 0.01696540778803249, 0.0197347620081517, 0.07383496425445042, 0.014208031352609398, 0.012400410506093215, 0.03198412295821453, 0.08312334366623433, 0.07578528621384213, 0.04232757972673543, 0.06513476416829132, 0.05175699592537938, 0.032956010827253905, 0.021279603205320817, 0.008527740287864882, 0.04504102101970104, 0.0765448930342832, 0.07038566103625683, 0.04916620147865146, 0.05696667343257897, 0.02828671833530309, 0.03999088132273286, 0.004394195106391225, 0.023736489313324134, 0.032387416539413315, 0.018287459125501976, 0.033539405933791594, 0.04998371305484926, 0.031248335726559166, 0.054269293172945904, 0.018687598339672533, 0.0676402164202544, 0.044708217103635116, 0.0421797056051512, 0.09480079125252464, 0.014741537855908036, 0.0035711298715473427, 0.05103837863932695, 0.011066211886974353, 0.033972766550798575, 0.014031237411883571, 0.02662860146243005, 0.03148507030170051, 0.024723430810075615, 0.014698918469460502, 0.022163090273557652, 0.0770269921650329, 0.024510400910531322, 0.022904130953153776, 0.016349496079548713, 0.06779099784551129, 0.03415887229024403, 0.141116444682402, 0.009922123731925123, 0.027488372363750974, 0.03458527299845892, 0.0536143416238408, 0.05921206564732617, 0.033827703971896446, 0.04775587574488694, 0.04990839895101325, 0.0764836672873747, 0.02903621087992384, 0.028170598558180278, 0.04709679115143034, 0.02801464220899488, 0.047335718653254935, 0.043426892915440184, 0.05103175197878192, 0.041604879192046584, 0.06208990557840275, 0.06615798950435654, 0.0430524674424481, 0.06050966920391206, 0.08350332327667745, 0.05403856281191111, 0.08946691174060108, 0.027086224083998994, 0.01563469965701863, 0.05805593554771716, 0.014426568466719362, 0.02775991797417162, 0.029708828416562853, 0.02693705910426234, 0.07759408109010228, 0.005055624407701074, 0.06730067093045482, 0.01907126857869087, 0.05955615403851675, 0.026766566236713724, 0.06001243983665782, 0.03398619607211121, 0.12881462011606465, 0.044580674955561284, 0.054094487230383584, 0.01984649210146839, 0.025365523573371674, 0.046021445023436705, 0.1359211734586185, 0.022600750559039658, 0.03152164142398584, 0.07136734142418831, 0.03826156040773757, 0.04005685298433227, 0.05843083982566192, 0.08654145944503047, 0.03337776521220803, 0.09463011452387418, 0.03835104713817278, 0.021227080217232148, 0.04920215015449832, 0.06402556844536336, 0.0866387372896556, 0.014007443678565325, 0.06042562552817887, 0.09687412394991807, 0.03341748687108198, 0.04827660868965811, 0.08890078808631628, 0.055202346129883686, 0.035960385500783884, 0.01618388702251738, 0.1308527357515789, 0.04576166843875282, 0.04430786721528538, 0.039074992565738584, 0.048772378659416596, 0.009979402210803763, 0.057194469676863764, 0.02465054903539919, 0.06607281584893504, 0.050274240408813765, 0.023612919331137693, 0.01827662855747246, 0.05319467099804071, 0.013691813538541958, 0.040323930386934555, 0.037275283492260405, 0.0458438313686319, 0.007459158716242641, 0.032025878580527446, 0.07447375134835321, 0.03161866837481578, 0.027698395368192467, 0.014106834968251568, 0.0302626678509818, 0.07438529117573654, 0.010744224174789364, 0.026667507237664638, 0.025103552146784724, 0.05656822344228145, 0.05657261312608758, 0.03160562381268509, 0.01259989980157585, 0.018672085059205853, 0.005348044477643506, 0.07176556158810854, 0.035683421733518766, 0.057295474539240526, 0.04085949862435941, 0.03187146589850947, 0.039219193295725895, 0.04326573482924893, 0.059122234177325046, 0.038594356662924253, 0.01812257402155909, 0.10489034541552106, 0.0555574661871839, 0.0240456402647279, 0.012715390428990848, 0.04305567352041122, 0.03936301481219069, 0.03690427094097099, 0.025764553875271833, 0.009270057461464839, 0.010680204122177055, 0.01996733098020477, 0.05843442128670793, 0.026901552844191753, 0.029293221887201074, 0.08859181716557472, 0.17666499280641157, 0.24339131229827482, 0.19175281868346278, 0.11192137781049936, 0.20078055200076875, 0.2076804761083857, 0.13002533014983902, 0.12860999803148931, 0.11999864116190903, 0.15067702279456202, 0.1265730008843445, 0.1343063367230277, 0.14229736921768035, 0.14253281868032872, 0.18263070333388545, 0.2053221203987637, 0.2168693636814433, 0.0720958297531451, 0.11253697542293419, 0.19974411164800968, 0.0643299198559215, 0.13899140871099888, 0.1525847809088807, 0.17717701533148367, 0.10926178100729182, 0.11614140378491533, 0.16578021639537427, 0.18450787921826686, 0.11753278799475202, 0.17587267403160373, 0.2676279440281853, 0.13085151001090004, 0.09495971619241661, 0.20767704403448492, 0.16122649784290022, 0.0872035049683144, 0.1133484234132113, 0.07474316148868493, 0.12813663996395566, 0.1315697021181545, 0.16129696261017554, 0.06429361494918985, 0.11356174825660645, 0.14115640382853248, 0.20108119554577336, 0.15569408664539938, 0.17037430778145793, 0.35571889290886544, 0.19260493828163994, 0.13343567779708293, 0.16012086442882018, 0.16539207028765834, 0.11654119442908034, 0.11179684255752834, 0.09758942024481874, 0.07779892534017563, 0.2107679176955454, 0.15536365760189874, 0.20757362216470704, 0.11961093172430994, 0.08941541531033094, 0.16396524685044445, 0.1874626496986997, 0.1625859361862944, 0.128435444897942, 0.12276404236833896, 0.2750453605286537, 0.2632313960742566, 0.26342595176350686, 0.17764722477764855, 0.14257352859262498, 0.23911752227333286, 0.14805504090843663, 0.1485024668997334, 0.14910884081355988, 0.06506789235338088, 0.1518986725638951, 0.13200842535063145, 0.06397510240335139, 0.17119472666132837, 0.08511979177954697, 0.20821869884046817, 0.13184187783589288, 0.10183039872396378, 0.20160507711191333, 0.17346597817395965, 0.22767963038096506, 0.3030281009212617, 0.0692367053500587, 0.15382032751316024, 0.16331767272805015, 0.2761878121283747, 0.19023529043601406, 0.21343722849363284, 0.14819751794059433, 0.1359206371970715, 0.13708224099489952, 0.23177915072489172, 0.17196092183791822, 0.17690575891925445, 0.1363349222247639, 0.16377845929274637, 0.29898205351444984, 0.13476674024376178, 0.1812142833706833, 0.15205406583845615, 0.11295934267822774, 0.11880958077287483, 0.06277639313691086, 0.1425151680145533, 0.17821970696170486, 0.14173555097753002, 0.15380333568299973, 0.1788680624937819, 0.2159495678760352, 0.1590376773909215, 0.09540794657603388, 0.2643390672822153, 0.19083801777132098, 0.1935697340917203, 0.2028055981762948, 0.14377432544865917, 0.08337004696049037, 0.1404940135656826, 0.14791501535763665, 0.13452746034149202, 0.13791503985562634, 0.12229383292217409, 0.2420448974495934, 0.19706334017457502, 0.1418540801011747, 0.1495439787545512, 0.18998364587464642, 0.18095131602979478, 0.11858620485591313, 0.16543198346851334, 0.14707749739529627, 0.14872591942548752, 0.09208991252366575, 0.19356634798309497, 0.11271643918007614, 0.12447192048233365, 0.044783332024610815, 0.12803877989250806, 0.08848857915689869, 0.14380798735205205, 0.15133392786787403, 0.2422121957304978, 0.20950482256950873, 0.15754668642916989, 0.10629447732841778, 0.1447634215676977, 0.13173369089922599, 0.1616657113716487, 0.07890633607824003, 0.0701667360901352, 0.16187212610196683, 0.1233871782859487, 0.11635866632024128, 0.11010028722305452, 0.1030149315333655, 0.2045141121432666, 0.1500901841228047, 0.08573008040266653, 0.16083390842522347, 0.13837496840184735, 0.14346920795017673, 0.14074290021052285, 0.10052065650421767, 0.08102106816706159, 0.10745316233125426, 0.23981495339783931, 0.1321236756179602, 0.2040852408014959, 0.14932386637214692], [0.020409070683883566, 0.026965417763999393, 0.030046324621164994, 0.04140898284892883, 0.018758051615628987, 0.03425266060437407, 0.06397593360874923, 0.026112353962455547, 0.04222731030876598, 0.043650594419769706, 0.07661456873099651, 0.06939068902283907, 0.016837620491822882, 0.013058419703626105, 0.07083176935632383, 0.018704969383355592, 0.05672301533782194, 0.015655073765364867, 0.002660549146258423, 0.054930028685879324, 0.07115059216777164, 0.016119328793138266, 0.046284837543123195, 0.03990249775890862, 0.04041777232721929, 0.027912944037046646, 0.03834912808792245, 0.015783096633611188, 0.0465938352769421, 0.018925254135542822, 0.048775986933539954, 0.0375018616567456, 0.00552762458438895, 0.011401492182255514, 0.018963937745279363, 0.04707494232382986, 0.021684610908250176, 0.01064511921046482, 0.02284126003242789, 0.058614766044962796, 0.02465280899477582, 0.03593091409833681, 0.011361155737822336, 0.05294385764207091, 0.04243051513068138, 0.04158347852588181, 0.07257072765740656, 0.05625022417535225, 0.04398466238091069, 0.012111265940832035, 0.017650144835633617, 0.04178784014056287, 0.018976202812947093, 0.07540631783945907, 0.017259210167873292, 0.03228890146279047, 0.01721356856456447, 0.037587180868872715, 0.054934912496396614, 0.053866116420155576, 0.02111684591058762, 0.021072891615932027, 0.03891738146663674, 0.04584660843735741, 0.04003764332963094, 0.02887605253847376, 0.07549611100506398, 0.042091777863641905, 0.03505370512063946, 0.03354791334019073, 0.06835128390981306, 0.03896986998076882, 0.03004625758847162, 0.013325924200246171, 0.04161303419800055, 0.0422712148077065, 0.047891063450445095, 0.1455822776282026, 0.04048721436711569, 0.01631397258249983, 0.039983434948108854, 0.07083657272760907, 0.07454043930216182, 0.011936658223520124, 0.05083795471657669, 0.11574433275288153, 0.024512429128310854, 0.07261834768277985, 0.06301746951536306, 0.012154699295699116, 0.14869993372309595, 0.052021296259256146, 0.027458163601676785, 0.03426694048328265, 0.024950763571166226, 0.017562586731547793, 0.013367293905767222, 0.05885002781606971, 0.04659846627844438, 0.017946921551840442, 0.025060808271049492, 0.04352981299762765, 0.03766961959040454, 0.03523205421985157, 0.06206412671975071, 0.0362659664824605, 0.03225936111243021, 0.019529278074661573, 0.006583258791285898, 0.008184107718989253, 0.0286857218241259, 0.04368522925482642, 0.02665260299709776, 0.06609339297058121, 0.051706361344024065, 0.0631369754011112, 0.04123088655873172, 0.0236855655337774, 0.00420002150349319, 0.006403200837197684, 0.032350372357834736, 0.025027485361563104, 0.11846179217700997, 0.0297460813571008, 0.023897258609893824, 0.06721547429239558, 0.05996330295719447, 0.019234621506785194, 0.056030935337466586, 0.025298111666474613, 0.039187109533457026, 0.07005134026610083, 0.06692207793915464, 0.06343136383821407, 0.03559422611649479, 0.05882208092859196, 0.09225442990540497, 0.027811902785493482, 0.010609572730778206, 0.0817393981701424, 0.036091126065941594, 0.05023896589034027, 0.03557937933252223, 0.06453166911078077, 0.05495512572627875, 0.009842511874833896, 0.008076598770135354, 0.007177190958417111, 0.009753548957016921, 0.02158604603591225, 0.08185597376958018, 0.03229881081009104, 0.021907785727131753, 0.045178583597824465, 0.025212966739350272, 0.006322113303242312, 0.0525755838551108, 0.07554330202119966, 0.047894043532470544, 0.05619213172805406, 0.060196266464528546, 0.042004608549177654, 0.04619559596082376, 0.056917272252781745, 0.11455174069851638, 0.09985366205294287, 0.08212069545181529, 0.006445296889831943, 0.050280510838474, 0.06525720800122907, 0.08896540760272935, 0.022730594801325953, 0.06229447020638374, 0.02856963652095968, 0.01859098507632171, 0.062017540913075216, 0.06935858993881172, 0.08357269253822104, 0.06760492274958281, 0.02010827583651389, 0.05674256590164958, 0.03359058060713353, 0.07098925405091817, 0.033477195763900396, 0.07412339635794202, 0.016911624585308375, 0.003321831933252754, 0.08253214595418784, 0.09292634264115365, 0.05039209537508507, 0.07503460431771894, 0.07124092925580279, 0.04212251331116404, 0.08276944168873372, 0.09418517831833133, 0.06059580046923892, 0.018619600375513398, 0.0029715755766618157, 0.07125124079926361, 0.03482787772232006, 0.036614758653506156, 0.026925408822153846, 0.06224633307166158, 0.021945180393935695, 0.07599926989285216, 0.09338863073818146, 0.03740760985942137, 0.027642426899664348, 0.018035504298524994, 0.026772055256691192, 0.012201225730560481, 0.0437612519899924, 0.08767020573178608, 0.0244558458742235, 0.05427950512497656, 0.0334442463222771, 0.03308326952279576, 0.0344841149184973, 0.02669461334364549, 0.045243080540169636, 0.09762574047330888, 0.017600071413682836, 0.07590012279369178, 0.03435353906224332, 0.07523783212227207, 0.010028903939641051, 0.030880167276688644, 0.032086319087313554, 0.0219350871855333, 0.037789937529352405, 0.019848313475508365, 0.01633711226825272, 0.06686990735151115, 0.025076442210364248, 0.03380916464412886, 0.08373512616080624, 0.001961668200355264, 0.05556650602469041, 0.03394381608814001, 0.07095098795910036, 0.024283918507036664, 0.060310451869642547, 0.07617395326134659, 0.053478023938594334, 0.009890407691859912, 0.028514482020851106, 0.03168130563872476, 0.04792507392384353, 0.0232743755012991, 0.07293432064714932, 0.05968723168236114, 0.030986607532888174, 0.03346109642617164, 0.07746949221097654, 0.010637144235173061, 0.01901020562546628, 0.049131007399410016, 0.030656793274946754, 0.0185880126551755, 0.047637503669266744, 0.026642149727370952, 0.06963666453356705, 0.06613420247430764, 0.018634316924538825, 0.0248427490042823, 0.01262221211237052, 0.01894754729413938, 0.059251488531909646, 0.0619280158782438, 0.05081495675708979, 0.041966510996703184, 0.12147821741358888, 0.03474805902148928, 0.02158017014153302, 0.061319757388123584, 0.05507505679082486, 0.07167650386691093, 0.07993424221152261, 0.07075604156500871, 0.024013590976415623, 0.056821813866976774, 0.036751788800522205, 0.027943482216928276, 0.02418524446716953, 0.03035230971422167, 0.059655550116252516, 0.06525303282204174, 0.06235681827210131, 0.02804673171692318, 0.05476568367392306, 0.05989075060032549, 0.056592975743114955, 0.02993260844490461, 0.03335545290141337, 0.05897457072991998, 0.034204247677999164, 0.0933274126521522, 0.05761866788229635, 0.035987482030665686, 0.05372116492400247, 0.06236067552480006, 0.06731085989984774, 0.06796824760855207, 0.03314854787482369, 0.011115503899242369, 0.05535883491017646, 0.06462700109207822, 0.04056864568302709, 0.01662470550546723, 0.09066464424493814, 0.05474905956596617, 0.04334495598149877, 0.020419167722725583, 0.053714883003023364, 0.037387427273056204, 0.027756365241422772, 0.04794639032033663, 0.062137506451577916, 0.017763951027225104, 0.029330455675540917, 0.03563376774470653, 0.05270640102906093, 0.025420235657703974, 0.04359265135961675, 0.05675048725078664, 0.030069655828898954, 0.006530300569495247, 0.031001232151362686, 0.04780604301260845, 0.04696555645956148, 0.037550163500371485, 0.06294952517735862, 0.0335665752420262, 0.07205597019844479, 0.08133850435936645, 0.014529034641811685, 0.0843809612636124, 0.05814249199184199, 0.0252625115606333, 0.04212299211611671, 0.033683384498280865, 0.053087617871501756, 0.04857307322503579, 0.06473017781372033, 0.08415285092327865, 0.018864541667543592, 0.04516850571118055, 0.046279264253474055, 0.009570008654507899, 0.04010369160002278, 0.060032473035877755, 0.06659937106193074, 0.17751463027971406, 0.11774152397148072, 0.18350517737769312, 0.14483247673319233, 0.20172302400873554, 0.11479553285866015, 0.1992805212015106, 0.2057630193209456, 0.19304163904199678, 0.18150734264523755, 0.13586373218605596, 0.2704428881406784, 0.10460128511993155, 0.20937510856216957, 0.1684014168718169, 0.153889796366134, 0.11083080568501066, 0.2063429785231429, 0.1529431721616176, 0.21794953233292028, 0.2167351144335924, 0.16081953661576395, 0.1930429107479511, 0.07343849843187679, 0.10669171689979493, 0.13634521844646624, 0.11001574175973093, 0.14921626166230248, 0.18424909471744494, 0.2305408002388093, 0.16971049259506887, 0.1517212006353563, 0.1469522420196764, 0.19808075090329494, 0.13680834924021076, 0.11384980497701515, 0.17559496715905207, 0.11239656682817206, 0.15135180836002673, 0.1392715210996328, 0.19865240571239304, 0.1027153145461794, 0.1531870026261576, 0.09485209616081369, 0.3024003991196233, 0.09441190970040138, 0.29778962233854883, 0.2074865639329918, 0.1457421908215169, 0.13140994214242505, 0.08436405370312353, 0.1674236894975747, 0.14086116886427327, 0.20338535819563175, 0.07724457645728704, 0.06527488164964222, 0.24590368232419416, 0.19213918746719438, 0.112067639317003, 0.165283837385716, 0.0521014865127302, 0.08597704416681683, 0.20821329025972277, 0.22457087622775188, 0.13149149986284395, 0.2037534940867655, 0.229542940073917, 0.09909339639688693, 0.0927158446621991, 0.12786580490008478, 0.13541816012753596, 0.15719139017164707, 0.18509168418184405, 0.12266520936522754, 0.18159291466637967, 0.24232911606950147, 0.1476453524082899, 0.18691520326800887, 0.14211923845352667, 0.1052330318658102, 0.1335475419557864, 0.25720954662369144, 0.13357132132495605, 0.1578054862517503, 0.16245185547778684, 0.24497262502629913, 0.16966143232439795, 0.276832643656, 0.21554343402385714, 0.14974904517012258, 0.317119277052341, 0.11155029248085715, 0.1229217951937068, 0.16207664093423277, 0.19881219633163946, 0.12989963044322309, 0.08424537902277324, 0.13395096385671248, 0.15205536818792745, 0.10956235560438327, 0.0933755919217102, 0.15400475552005155, 0.0900605685948845, 0.2525493112062254, 0.10683564949900874, 0.2006861699684974, 0.09829334013404385, 0.07730786298071185, 0.10195060558016263, 0.1847167454299427, 0.1153608444597452, 0.11743531096726657, 0.1533951487151846, 0.11411618140916671, 0.15112625675336008, 0.1253616933019892, 0.1657401499969344, 0.15524675258465354, 0.0984452247259117, 0.10412371356881435, 0.1445141672006538, 0.16324929171992889, 0.20050135891764395, 0.2035857974401405, 0.06212693826866247, 0.18883022389584975, 0.1541665226461426, 0.09898511752966913, 0.17787584073601231, 0.17523642268873033, 0.16592963418412596, 0.25235766665108744, 0.13412109666293667, 0.18300706700932595, 0.1400865773640333, 0.09567906509243673, 0.20058625678141273, 0.1646689445741715, 0.10009243633718261, 0.18784727180196395, 0.14656902951819284, 0.12176309486911183, 0.0982089095839089, 0.13453741948450768, 0.17965236798890177, 0.14679341667121457, 0.07834651732757207, 0.1049950696347702, 0.1422966797385485, 0.10996996034537593, 0.1411175018837375, 0.11802498416434373, 0.15520804982271888, 0.1453001427674486, 0.1548680906454402, 0.07837238811677502, 0.12199257650683004, 0.13230480944677708, 0.15699381609597515, 0.1102172228838167, 0.24590996424517325, 0.1384923483936056, 0.1764482971761496, 0.2534103940331167, 0.20278745721424782, 0.16023387771941003, 0.11752207808557058, 0.10314312868661459, 0.18396150531067004, 0.09132979242431541, 0.14180790032109908, 0.16804339334128365, 0.1220092848844586, 0.11729587530416828, 0.16833404709975566, 0.15625616535544395], [0.0339696217598694, 0.02972174274374641, 0.018969869181033105, 0.03971111750410449, 0.04753600851061845, 0.042741611945412816, 0.04010287571638342, 0.031121050217939965, 0.02762976346627599, 0.050646796627270604, 0.017341574195832495, 0.0403593044968382, 0.022208789333460793, 0.03337284309729453, 0.013319025578488027, 0.033554091839300054, 0.029041992928532344, 0.01651309607099862, 0.012656590307972605, 0.008613882086900695, 0.04476085500491243, 0.048493181745852196, 0.013966853467507229, 0.05435712898390428, 0.06137360187788164, 0.03533714233086475, 0.04734434863372196, 0.03783842706451974, 0.023942385019073566, 0.023976558286155907, 0.006867441500822503, 0.055907798194957364, 0.06739697584341611, 0.005961375427432359, 0.030068428173000296, 0.02625111355296066, 0.056704345775107225, 0.0150324156950979, 0.007494234530660775, 0.012297206013763865, 0.013103666771653921, 0.009569080730509615, 0.06395927119639612, 0.01974491841880785, 0.02374693300695189, 0.07695475007377325, 0.05330568096870857, 0.04829765312493809, 0.057658278458421273, 0.09697244367412022, 0.06040720494403955, 0.025199234613307545, 0.008767364929700571, 0.03315387984677669, 0.04167094661463653, 0.03319635559173842, 0.008481199488854937, 0.05115018534143606, 0.014272844306223336, 0.05014254606419033, 0.024109436236622355, 0.019294790052358183, 0.05180490706416388, 0.08339199537952101, 0.023725162703363646, 0.024277741923147154, 0.0835933922339351, 0.07207704527724175, 0.023444786014395858, 0.05102728185574374, 0.06677223114116539, 0.049362660896393566, 0.031567238977239016, 0.027290511005107435, 0.013583564357231221, 0.016901791846800237, 0.052990512396659584, 0.02569549487933757, 0.014218962469678974, 0.0898505072860468, 0.02548706150733896, 0.01761702110900754, 0.052193708177055084, 0.02076951696747734, 0.06683268313927036, 0.0421885117858408, 0.0416438079499189, 0.104973450633547, 0.08509837962206333, 0.03213326687053327, 0.020949633814574733, 0.022492098223958767, 0.03220498802200441, 0.0379492033783707, 0.03314155349207502, 0.13050514633857435, 0.047812642860076124, 0.016430728212599794, 0.03543244749908486, 0.029127725828138572, 0.042420456396235574, 0.10271529922442091, 0.03276186116460351, 0.023903190045647567, 0.02344132521219792, 0.05160662818760161, 0.023026007881027558, 0.03634184366092086, 0.04052779404446483, 0.018680774411487005, 0.01905911842421178, 0.05314662196342984, 0.025499249966214263, 0.022771781603355083, 0.016611957802407203, 0.04619880969966612, 0.011000629972606417, 0.02075537498439512, 0.005692492930158492, 0.011699211186609201, 0.1442997391906477, 0.0676498078410664, 0.022093495016076395, 0.014596446548708746, 0.053498076290012374, 0.009140529230447307, 0.01555625991445155, 0.02000770572903416, 0.06667792571768646, 0.015341771575021408, 0.037598055486957875, 0.037945679373919, 0.04709476484887062, 0.004092735677747236, 0.023267501777398492, 0.043554408250436674, 0.0432732118473899, 0.033297605602250945, 0.04255939410218308, 0.04434300000749288, 0.0336649026271076, 0.05528511809966257, 0.028347725747153166, 0.029077123805520036, 0.04415500586131408, 0.04941986085125997, 0.03351423994547898, 0.009887232257413768, 0.038359872471060485, 0.06381811566590782, 0.03160198297982495, 0.038755284922738234, 0.052880827758100726, 0.015566315776067636, 0.03103428884529539, 0.04067073072937708, 0.06217792142002333, 0.04578355174030989, 0.024349802068524787, 0.03062507148922211, 0.049520011525601156, 0.04842421468046885, 0.025426050265049262, 0.02936245133769849, 0.08300332833201655, 0.019523335147588965, 0.1319236347391721, 0.08969054812745703, 0.06845010925204524, 0.006412164065911765, 0.039193027562672095, 0.011095108723478212, 0.04838432831269118, 0.019420489758974122, 0.04475926537246955, 0.060855082927211646, 0.04843727264913821, 0.015094284955862791, 0.04315047690104093, 0.04846234670689991, 0.04660543767855533, 0.023475295465980327, 0.012138666033053832, 0.018294777180398666, 0.022485590307042006, 0.0846478816181902, 0.0032112196100980888, 0.039534963246795445, 0.041083326533196435, 0.03466042622383084, 0.06241564233336718, 0.01701796908051737, 0.007067287505994882, 0.06252407058773023, 0.08181772299952085, 0.05840340621709343, 0.04384135414335517, 0.044378975496417096, 0.021336146239792148, 0.01215361719650607, 0.02388954601971613, 0.01667305139914876, 0.013889513061111494, 0.04779833999852981, 0.12625282209727073, 0.0401152748494379, 0.012003522377551324, 0.07299749991826474, 0.03992433126475062, 0.014068060385574017, 0.039946157109713366, 0.04860499993928018, 0.021804396416090673, 0.023612245173764326, 0.06184970637062385, 0.03279347378279894, 0.023352727143754883, 0.01347195492276261, 0.03637919044722954, 0.029716560158938653, 0.04860509186983109, 0.013975236384618669, 0.03292330653376637, 0.0370997995618851, 0.01648988360689292, 0.052885723059936884, 0.02318451147256119, 0.013309727186307073, 0.024741544959045226, 0.04308777260443857, 0.014025137436786487, 0.07787567202843006, 0.03525886346676177, 0.014964085440301608, 0.0116703248838143, 0.025290058167170615, 0.06397988662243852, 0.01974368693246957, 0.08280055251933875, 0.12916674476958093, 0.03723291116916845, 0.11038802984741428, 0.06656497371413055, 0.04025082644676009, 0.05287929558225217, 0.032539879527664, 0.06808922821355444, 0.032025204423154076, 0.042658464592551036, 0.030950597570007368, 0.05290570646344174, 0.03072487742399737, 0.04154288352677419, 0.015626436441145357, 0.03403668126632129, 0.06526999400868531, 0.040020609364634564, 0.026291821550037113, 0.05130027728756109, 0.02254151089507486, 0.04182042569042214, 0.017695585340862314, 0.035404485289848624, 0.06935478248182805, 0.07037145010526143, 0.048623343914627075, 0.007589939979821324, 0.055660914870039116, 0.05111420602207223, 0.015193769133709853, 0.048110291001296816, 0.035001752868054375, 0.07241746410727501, 0.008350665767436788, 0.02731704446036489, 0.022991357724212354, 0.07255000497905478, 0.004263655639313643, 0.03299386706203222, 0.1342141457022198, 0.03675638149762827, 0.05221398652441079, 0.0410695752549556, 0.03960676483749863, 0.06350339908573417, 0.012383925251572604, 0.0764218133483683, 0.015798495000889225, 0.028127463977603663, 0.02454917836603859, 0.021342899304844683, 0.03550805654677172, 0.018701207891647375, 0.03919185161770832, 0.03959633455040955, 0.015169677583711043, 0.05776571462892237, 0.06217205701696296, 0.01655838718908208, 0.07123217287082827, 0.0544170523813415, 0.03409628290683031, 0.03617964369515258, 0.06275378971270497, 0.020862401297856725, 0.016104217708831834, 0.05906700689886367, 0.044326486982285015, 0.013620031100036878, 0.03206190003472711, 0.043793010164893446, 0.011163995349629512, 0.10416510529936322, 0.011791291124668094, 0.03215394741404922, 0.03407928341579053, 0.07115603905291328, 0.015593173861083005, 0.038601243793363535, 0.03152892117448632, 0.038489394956418586, 0.04896721014031961, 0.002332594327350718, 0.09057303545095267, 0.051277562780606176, 0.02749999391756231, 0.07824303417076027, 0.05959060501247164, 0.03895701119495977, 0.0259716734064803, 0.08908348473449869, 0.03210393527913238, 0.08456740408174454, 0.09314346728065322, 0.05373812228020641, 0.012849457730959742, 0.025031863554050366, 0.017735408506386222, 0.08294325937787372, 0.055921580116715164, 0.018545538825433583, 0.0329675174678766, 0.09863034987281408, 0.008091892757933707, 0.09778024508587776, 0.029320619106593154, 0.026618985143760522, 0.014763769727470654, 0.10258491872058761, 0.033231538179661, 0.016572385530678496, 0.008945398017643921, 0.14050676126874265, 0.1196634547123986, 0.1418578032884867, 0.154753836292413, 0.07162080161393651, 0.08042079997399161, 0.1040631773010377, 0.12098833482952849, 0.12077349313204327, 0.19063213930254985, 0.1355136146829013, 0.11266285899065195, 0.13431545316932664, 0.22016908823242112, 0.15211326911324455, 0.1308413516850241, 0.1192820808219333, 0.10501999813582628, 0.254824010114516, 0.1479565986101666, 0.1819430628130513, 0.15374474527855075, 0.1440911640923831, 0.10619015147488926, 0.22148300563135456, 0.17498620305090182, 0.08813742743504625, 0.20669855057231842, 0.3012672937925785, 0.09947300062424715, 0.1883627570444538, 0.2061225903490859, 0.15960335671421022, 0.0990611057908785, 0.15433693124401957, 0.13829808381776657, 0.18836292558379714, 0.13032284805611258, 0.19901364681220826, 0.0820179324176523, 0.1260216014399644, 0.06655542825859401, 0.20541236555624395, 0.13603427867975929, 0.1252232229096755, 0.128005585302749, 0.11394627842931979, 0.11311593871082991, 0.14998588891279313, 0.24986005147858975, 0.16243800460811586, 0.13124587675256114, 0.11383638311658176, 0.15091026592398846, 0.11761333447911086, 0.16871520648560218, 0.12438086327165367, 0.20502723783494967, 0.17040346508785603, 0.1290700797952952, 0.2213179443271891, 0.1061616683258645, 0.2719848699146702, 0.26686372535844005, 0.1361556423287238, 0.29226496395084167, 0.20986408716247928, 0.16404904154760225, 0.15862339236322912, 0.118341455085864, 0.14781013792080266, 0.2056788262580672, 0.21159178397107511, 0.11325899796981005, 0.1204446345687874, 0.12216983393075005, 0.09715047484684376, 0.17921139245792744, 0.07740422151982784, 0.15602151262423686, 0.09814162408151934, 0.18857819629051994, 0.08724175573837373, 0.18484213870138894, 0.14998247216065086, 0.06510697815927767, 0.1346833592340831, 0.2059501899226058, 0.319707581713315, 0.20054415258909428, 0.20721215123851455, 0.15746017978076013, 0.19766157823464564, 0.17130715772509578, 0.09184399063909247, 0.40735983800503517, 0.29651065387072106, 0.07753313113484653, 0.0830681240486522, 0.11085715144872667, 0.16973946604036516, 0.20514991915514394, 0.16606636555685153, 0.2753414688331466, 0.06364645451427468, 0.23896323216538276, 0.1472605004786484, 0.11330478704504429, 0.08729019547782599, 0.0798463489439699, 0.11433123761127073, 0.20574369858349525, 0.12680529406474483, 0.14150920263942213, 0.1034923268842601, 0.12441522231505764, 0.08828165880855053, 0.07903015886944148, 0.26570500205120734, 0.08737442684510062, 0.2938448211118099, 0.15967754466879755, 0.11021787405855234, 0.14067977456556213, 0.1544964920368887, 0.10968273866080469, 0.19766655780615347, 0.18076120365050533, 0.16432244300601945, 0.08674543035487015, 0.10866803222245748, 0.1365008109038876, 0.1968590551686864, 0.09627817649274104, 0.14966934138248045, 0.13686444219802657, 0.13027271526234765, 0.06511583413568235, 0.12585777353735703, 0.15023724236074956, 0.10440363443546719, 0.1150840109274272, 0.1055863592773676, 0.18691469764997884, 0.1760650999964245, 0.14610180781493265, 0.13394293525526602, 0.10349613434124379, 0.15755692136383828, 0.08887684783868252, 0.08646740172539027, 0.09911545206822696, 0.1626122589673727, 0.10680725061965567, 0.1718632149840555, 0.19113008113157368, 0.2571435404881354, 0.16614355657610202, 0.11944087552687815, 0.10182518166519942, 0.0727915678233389, 0.16050662034221236, 0.1337035021354114, 0.09998699965616388, 0.12801307764264847, 0.14970671115142686, 0.3188581740663898, 0.17362088115224916, 0.18913852832009717, 0.10697739874763836, 0.12152232875626896, 0.09776417256122637, 0.1478088202495729, 0.11403886015496909, 0.09437997149483812, 0.10394737545040347], [0.08859712615488999, 0.03785954044771291, 0.03773911525645564, 0.053443615099475275, 0.061943264858376604, 0.033294698298578305, 0.020905415219585263, 0.08381536620999537, 0.02258206950500608, 0.01596324412422555, 0.03661950073775746, 0.01831546921523348, 0.02152199533978297, 0.008478307506940778, 0.08335587433389119, 0.058629233615412835, 0.08250376239659325, 0.013233876820924062, 0.03273895513566752, 0.03139177802950144, 0.08863896221643494, 0.03528295693198039, 0.027620384634862986, 0.03155521905770706, 0.042486818762676376, 0.01296333765851394, 0.03438140934092864, 0.02664657388513367, 0.06474478711043635, 0.007768137776668394, 0.05190297397935102, 0.037132300842072696, 0.04153122749900626, 0.03674659089395597, 0.07576788069620248, 0.05468031849652048, 0.026841529855324377, 0.04134657732661694, 0.11280086973021108, 0.040985405174714905, 0.06016021053637228, 0.044112683333937204, 0.02116343554770274, 0.028649146871400938, 0.06422683889526995, 0.06083139931903251, 0.016461216596766345, 0.11943345979577112, 0.0901477110962714, 0.03459412514442398, 0.03934723340095051, 0.045859949858558756, 0.03951416779009085, 0.038629539250846834, 0.033763440686368176, 0.0636223687099353, 0.0763773572661223, 0.040569361975236286, 0.056264611306570234, 0.030471218051388863, 0.03549153203024499, 0.04638763888168239, 0.06954048219467364, 0.09109127860996993, 0.022618498901025425, 0.060957014755976785, 0.039905845563137726, 0.04883437049424937, 0.023954046792500926, 0.038513434795482505, 0.05915842417086806, 0.005270002143187148, 0.06290836327318704, 0.057485498818418676, 0.04451734246686102, 0.03595393121002182, 0.04355351958844451, 0.007778901790809488, 0.03585846133289799, 0.029809237645578482, 0.07047169271015352, 0.0211327173371589, 0.03593382140200946, 0.04747929502158396, 0.08029098637522229, 0.057911654378497796, 0.03031650659508042, 0.01203892617336204, 0.020588743199984876, 0.050136068790790536, 0.009192811858449734, 0.025787477141186118, 0.0027104803631382607, 0.03125620919520096, 0.01842628000304103, 0.05378186973112245, 0.07610871321371487, 0.037241391762490236, 0.10012696391992992, 0.03562582724337136, 0.035244721483679554, 0.07513910637147005, 0.034150257631535494, 0.02478224529524244, 0.034605099353939295, 0.04692332586273552, 0.02090052374818873, 0.02267511279862975, 0.05031306191437668, 0.043755617413309314, 0.05836818915521426, 0.02284670117191009, 0.09149290786515321, 0.0418098421857482, 0.0462204976488025, 0.045685021341928554, 0.025798012765364784, 0.013359162840060891, 0.1322863620495604, 0.06311938602236972, 0.06448682998457263, 0.00618647312700388, 0.06240721919663972, 0.03927194611019185, 0.04875271701283994, 0.10913389795009168, 0.014107892169587076, 0.017232263025136727, 0.01759328770511333, 0.14054835984303107, 0.031437986537874225, 0.013051174427082222, 0.08675263924223763, 0.02469959206909182, 0.01640845612142115, 0.04514843037712478, 0.0454306916423863, 0.044027061517079996, 0.024398601869301453, 0.017172333882040074, 0.01920278863831153, 0.05535338419459521, 0.028598690405488018, 0.03501249725119241, 0.03895118126585599, 0.03726495279660148, 0.07501555937192134, 0.04240234990814521, 0.05953959121759381, 0.017852704228472807, 0.04048820262053802, 0.031169332909367742, 0.032148998486058365, 0.01311847333601045, 0.0300462001318773, 0.023416141986907012, 0.05586937505511507, 0.03668180666863918, 0.0191486798482196, 0.04297024322553508, 0.022355656049424605, 0.07789307754606971, 0.05527566457467695, 0.03165844557506423, 0.037337826910398664, 0.03916365575165518, 0.08172070562478997, 0.010621439432725312, 0.0215405423284298, 0.044981308296443, 0.032993886214230335, 0.09110877605816049, 0.13314415069837726, 0.04441053831889745, 0.05230906569669324, 0.032565041685536984, 0.039764379767040094, 0.08275490900081012, 0.03919380514191524, 0.02706129941338253, 0.032765005955532674, 0.03936394177857907, 0.03589703385988551, 0.0347910174018433, 0.11337751943257549, 0.051455547988054254, 0.02900011473215155, 0.0288907173765643, 0.06003526925680138, 0.02788011716949123, 0.019018680473128637, 0.04181369177756771, 0.052519456423338384, 0.03811588878893564, 0.07111689962086178, 0.03737605469782026, 0.05011238135217179, 0.0691173105470596, 0.049172479569190936, 0.06361265854549504, 0.01265192004446421, 0.0033706192851006506, 0.023353822649486607, 0.044053043389031966, 0.05999584637221791, 0.012976845703838814, 0.045988809677862355, 0.028682977314137166, 0.07722861884582428, 0.030183749303462046, 0.05145616851927293, 0.0513421056882268, 0.047063309278699665, 0.029679002698450804, 0.0481899296714654, 0.04159216596294315, 0.010628004806236395, 0.024595216419848225, 0.030670017867739645, 0.0889485230248782, 0.04603765544391448, 0.06513530809071756, 0.021950883918531963, 0.061103835506665136, 0.13251047341092942, 0.06228576361712429, 0.014907255122858672, 0.023842065805389036, 0.062191756967935836, 0.028263124742455063, 0.06798048203270282, 0.02107420354150236, 0.030801455572908445, 0.06225483664762109, 0.05817724174008735, 0.04917442543251861, 0.04633546063315965, 0.03241566603162116, 0.08947458028072312, 0.08235835890856483, 0.012174710469891228, 0.11684225166156409, 0.01667853850390642, 0.01229686127419794, 0.06716289001727296, 0.037318709186248245, 0.006989083335464521, 0.010742693914160615, 0.017212285367291302, 0.010229874657647265, 0.054124157815690965, 0.049698559807673584, 0.055233372690817045, 0.015812221381272522, 0.014206525989838186, 0.012927293221676543, 0.063459915935152, 0.05603750454141729, 0.03452982738493912, 0.04832704025771349, 0.05179553397841031, 0.05694975821121086, 0.007352880774922068, 0.04970914714278714, 0.022420017011163217, 0.060981851326481956, 0.00533120394984801, 0.08425559863568315, 0.008969612141710617, 0.022357299308022185, 0.04561090999613366, 0.04075747103460374, 0.10478631067540377, 0.020349695039312207, 0.03842521211012237, 0.07088013248698366, 0.0768924211602538, 0.02252578310998938, 0.05782859512574731, 0.02298788734591536, 0.0667160002875232, 0.04834913806388936, 0.019559791356685664, 0.0697697569886523, 0.11783073491026318, 0.04367207552516653, 0.04270831776422359, 0.026654646536635778, 0.054445562343443596, 0.022224597557778322, 0.051451905239974303, 0.023573506022653273, 0.028469746316512747, 0.06071634057368483, 0.0640586136479772, 0.03276746892820924, 0.03386940596805465, 0.07447959659921546, 0.04748982873054282, 0.006821515966176747, 0.057490114498162465, 0.05653854902653445, 0.028297305670416648, 0.03393453876337698, 0.017525617243541826, 0.05946525004542163, 0.07860589171609572, 0.06088455432965871, 0.02865919411452788, 0.030825351770486564, 0.01622302070890944, 0.07322058472181521, 0.042508265394116604, 0.029431447131379, 0.05276994419194037, 0.06135158834137744, 0.0056629262455258405, 0.0345340830033585, 0.012215405060429008, 0.014849381968228808, 0.027863418367961724, 0.0542095344844124, 0.054869572857334736, 0.026916317273712447, 0.018611991207205483, 0.033577848225831985, 0.02341600217586083, 0.0035049994861061176, 0.07057970344659782, 0.03226553578109991, 0.01229020205491613, 0.052705654093334754, 0.05882901785474631, 0.04606038527262788, 0.05497264232666743, 0.017845476188907222, 0.007629785649178009, 0.0132671365281567, 0.045628484053116654, 0.03220690707225473, 0.01225791336412752, 0.03499888003833833, 0.028375157440501838, 0.044903374171905944, 0.012658169406706528, 0.05704247783268652, 0.035465339484113845, 0.03830569856349499, 0.051123042846278804, 0.07670936445074697, 0.04949511749850166, 0.00827521472538431, 0.1591783464555779, 0.22364876683681245, 0.19976542421406318, 0.12921706142444767, 0.13768893666565418, 0.20271414259989418, 0.08827514706119415, 0.3684903446945452, 0.10556994967402951, 0.08811920220332761, 0.11328410267108872, 0.19717362619215445, 0.156219944718384, 0.18098074912784562, 0.2458583912061107, 0.172307760484757, 0.1919292180889076, 0.12489133829911872, 0.104170935228467, 0.10546053699668377, 0.19043093397011682, 0.1777922911869903, 0.1811664641624497, 0.1538326308852242, 0.07418350361648106, 0.14810201741995352, 0.11754866899742235, 0.14209317614234265, 0.12544984703943615, 0.1119916663775521, 0.1333778994458337, 0.10051061309153035, 0.14436386074990998, 0.1220558017432209, 0.1221064478158951, 0.1876258723918469, 0.13701292535951062, 0.16229781051797254, 0.23410554524631272, 0.11963288780421981, 0.18830704713060012, 0.1401160411056011, 0.11187277719258301, 0.1615636991036515, 0.2798380985135033, 0.2568126977571557, 0.16504613562457024, 0.18022203096939673, 0.32536158638615764, 0.19512077102497702, 0.18668841059890487, 0.11808365117758514, 0.13809412056880613, 0.1708866520634582, 0.17776164767001906, 0.12107126384733186, 0.09179846969463172, 0.1804880320184654, 0.1270962082931111, 0.12844957155926576, 0.13788997345874388, 0.234873425816336, 0.15760958224775332, 0.19324437655027837, 0.07628812334470211, 0.22048307702906672, 0.14169156220891785, 0.11867112570231962, 0.19039734867551636, 0.13302735293344145, 0.15462591493081662, 0.1429384009492013, 0.17498801101840314, 0.1636899608157335, 0.09067261155935065, 0.3492960423952149, 0.16050631390704265, 0.07823162712156773, 0.14614961170140775, 0.11233605354303315, 0.19164090855948387, 0.3304105041728866, 0.12608933893422927, 0.1737772703411118, 0.1792283689663295, 0.207842534347888, 0.11525425864684007, 0.10413692858550819, 0.17240663179226462, 0.14164432522750672, 0.11515928672686701, 0.1944274614535032, 0.11911063800535857, 0.10467558032682828, 0.09278495345384845, 0.12001583983580913, 0.2117722742860356, 0.1388508468986519, 0.2843441051100531, 0.14048790018404686, 0.18238327225610135, 0.1311636295530104, 0.13877026977077608, 0.12529759472536464, 0.1604186274832295, 0.0946159955234297, 0.1197096115098365, 0.16111032827006233, 0.25537504183669246, 0.17670518177891933, 0.09122445533472685, 0.1636818709272531, 0.17408393533720126, 0.10594547831363256, 0.19068227209631475, 0.18160190853861072, 0.10023489038670257, 0.12185915463393736, 0.28798133735695197, 0.1888671952990755, 0.1481612206947419, 0.14949674177314007, 0.14128486145167582, 0.1504735498418731, 0.11705961378832018, 0.22432125413850432, 0.20214026613581568, 0.11810658018915884, 0.09162989970777305, 0.2743716628080414, 0.2821207034491724, 0.2393320115703729, 0.1582196793488918, 0.11009976628326601, 0.1141990797834531, 0.10575642313567862, 0.16567832670144497, 0.1413958369483871, 0.07605532454627176, 0.20998080831862267, 0.07304135079105055, 0.1666446240438569, 0.10624134913086893, 0.08379321094722518, 0.1025671071763481, 0.07674055955102367, 0.29267040832388785, 0.1401094527494523, 0.1029632282593558, 0.1406754385079107, 0.10611662235591682, 0.23921101564361205, 0.1710400841529331, 0.09693352640756676, 0.12192151419097379, 0.18399669938991148, 0.20575089980998348, 0.08607940117437994, 0.14312062262287065, 0.07330342180906765, 0.16807452715452642, 0.09811124103444238, 0.11728693505809193, 0.13043639760824943, 0.11292270835368864, 0.11611941706148848, 0.14431754307400796, 0.11488741744429835, 0.07114739758112738, 0.11667622508661402, 0.09821290856287365, 0.1536092549682625, 0.21925652429701822, 0.11987238987198762, 0.16109773378458717, 0.2379256426807373], [0.07059622030224531, 0.05893786745746771, 0.015160951842253488, 0.052526443145207824, 0.10255396876844669, 0.019228724544988047, 0.032107823175348105, 0.016149706094555797, 0.025944454302530617, 0.02927437037860434, 0.06489703942450785, 0.03294564948807801, 0.06262085813608381, 0.021270758720235, 0.04213693108589899, 0.02588775422003481, 0.03312436247905416, 0.06259991712267361, 0.10122247731253024, 0.04682986696641292, 0.04701859655699903, 0.04654822240193044, 0.025659467679478472, 0.06394299182800517, 0.03450353141693819, 0.060811450389484246, 0.053234660787688154, 0.035228752380897926, 0.052114682377225933, 0.04061637679114938, 0.11041835926833654, 0.016268239048640096, 0.022029691383302696, 0.006354984699658329, 0.034104594960808754, 0.040124682409148064, 0.026056437204862316, 0.11774832683224833, 0.04951791244468862, 0.033449850255443205, 0.08082422187491771, 0.11017563963128675, 0.023158144641427264, 0.017867003259579503, 0.05577646391165834, 0.027749447467466517, 0.04367092639328011, 0.0023194796202944653, 0.019248997146684318, 0.015556958969682457, 0.04264079477457751, 0.029632541381063002, 0.010517929462836155, 0.08644968977258091, 0.040551289961102514, 0.06887781614017102, 0.06868333705971319, 0.030799484811723236, 0.032628933418421976, 0.08493927082106953, 0.07748263061887796, 0.023113437665386066, 0.006097040980333282, 0.0026619364836087994, 0.017178035491416534, 0.0036948092606654695, 0.05959420562571576, 0.02672946842898044, 0.03375730815253431, 0.03696396834247055, 0.051469877662677924, 0.04087473228273373, 0.06998335762370018, 0.030947496829133843, 0.0080130809839184, 0.021029910252940272, 0.03569859027441952, 0.013973324995247588, 0.06048784718938893, 0.03355782651793092, 0.06693337773603779, 0.043648028025223364, 0.03308167989035288, 0.03480806668859816, 0.01782665149338784, 0.015274070469932932, 0.034455325334302844, 0.01699963659648934, 0.015295664573298588, 0.02905555460001192, 0.0075149739671859055, 0.0444438363305263, 0.05580460232111716, 0.026696051673723326, 0.005139711654684957, 0.05012861092484767, 0.019317878027176185, 0.014304274978536754, 0.01840891278979759, 0.03551050802812942, 0.026359719922766093, 0.05026266865071751, 0.022969943651508902, 0.04194170506971498, 0.042618988081812866, 0.016036669821328214, 0.01762748012439378, 0.041660497175349344, 0.041848146581962224, 0.051553488498733896, 0.001765416943066333, 0.07489984179095877, 0.06267518143079455, 0.002667126489893323, 0.0873559717870047, 0.0814675901746077, 0.053818006098510764, 0.05334665901177833, 0.06060856349405743, 0.01772767101835099, 0.0532955379645911, 0.05195996709047787, 0.03318083848083212, 0.022704049854749636, 0.04511537368319208, 0.06369648771660943, 0.03605571748208135, 0.02948910865421978, 0.029126115128277775, 0.02878184670642499, 0.08541495013501375, 0.027691607829183344, 0.015862757328807587, 0.08271976088684413, 0.029759620045942646, 0.04127735362177895, 0.045520729956126986, 0.070792461384929, 0.02281058395671989, 0.04194829725630341, 0.023009450805764046, 0.022713987930347363, 0.023076090879077395, 0.0617731512043505, 0.028842513209148764, 0.021435940683248545, 0.08091432913657158, 0.032685076171952876, 0.009012794602782497, 0.019250739996712056, 0.03864274660666143, 0.04767919800454571, 0.07876186721747921, 0.007861926569603384, 0.10202871590492227, 0.012648758016556743, 0.06773718016883058, 0.07229800801724195, 0.052355731942600785, 0.056398500493096734, 0.02131612261667127, 0.05958216272354607, 0.10329708171587798, 0.035331806528472134, 0.0598870657174097, 0.015209886666026809, 0.07430669821558461, 0.10225020724559024, 0.06713115099457002, 0.04862730075875598, 0.04173841980856754, 0.011916738022269021, 0.011176045912678444, 0.015805320844294566, 0.0274447972826179, 0.0021126267834446367, 0.0633281909470116, 0.008380634169424734, 0.034547661911816366, 0.06771852592787436, 0.0768872500667649, 0.03451361313402172, 0.029804807742156332, 0.05392544226901186, 0.03058259765948019, 0.016475364325507995, 0.03747746941723651, 0.09431558180480235, 0.06513272637441274, 0.023873308786161007, 0.05256799958466042, 0.007565659780671159, 0.059593328455042456, 0.06434233814117409, 0.04599306912672135, 0.037823507502194376, 0.03139751985849392, 0.04349715849985519, 0.018550246435728286, 0.019759816913715294, 0.0269712170495862, 0.05798588829836058, 0.02895760259801342, 0.05178294715381438, 0.07414527582905947, 0.019246643341536966, 0.07740285022244339, 0.040201973019828724, 0.03477917751297355, 0.026801880974803242, 0.023267946108394576, 0.07909400463705102, 0.04825032804341567, 0.12854111140533803, 0.03042994506446825, 0.08805436052141652, 0.01388727512676269, 0.036107608447632486, 0.04986891094895621, 0.04998556698762602, 0.0194569421376312, 0.09745846517504224, 0.027871069671105475, 0.015556439945113756, 0.032648035820813916, 0.02483594231307507, 0.035093005431155046, 0.05701602864710074, 0.06276384078627152, 0.054383796504548484, 0.014184903158175369, 0.009129479369749467, 0.0338545783362802, 0.06350513427488266, 0.012735151666997662, 0.0730705693844826, 0.05208941679748316, 0.029788378986620137, 0.049696962514351455, 0.022118904237304966, 0.017289704297699274, 0.018618671493905208, 0.04583841129656761, 0.024612451482924725, 0.05016776567865765, 0.032577168857378346, 0.04554280477966513, 0.03401348029353446, 0.08927479221095001, 0.07163112081827656, 0.06034998200653542, 0.05073629867946429, 0.0236138692801638, 0.06634801761397431, 0.031233063763788635, 0.02826800855297235, 0.030008991241394996, 0.02864961035459513, 0.008090610518270444, 0.036174618158369296, 0.05247330728677973, 0.06367209930753996, 0.008265411672783236, 0.09212389618398682, 0.056355986443738786, 0.05133238786290731, 0.01857754980934964, 0.12116114894348769, 0.0342650865505059, 0.01751521185431029, 0.027516746345246514, 0.041542412382700754, 0.004570181781966841, 0.03521608894750957, 0.01194653501208391, 0.06352607528829286, 0.025313090600614107, 0.08394257510982214, 0.06552136277840023, 0.04085705097344133, 0.04835746543962629, 0.0529390964056215, 0.05139951631727238, 0.07429800311764402, 0.057757624740441965, 0.06965021662894758, 0.04470661981031299, 0.02227026022850506, 0.015686363669022197, 0.025124824493222182, 0.014505950497433305, 0.019766504861294262, 0.068377438151548, 0.08753812451276087, 0.017752858074081522, 0.06740082926567524, 0.0561645946976158, 0.01599947146455487, 0.04581433315310748, 0.03065681242714486, 0.08326277166845338, 0.025782497569678292, 0.020878301452725165, 0.1088571563483246, 0.0731551684739609, 0.12872750059731547, 0.0812816376527471, 0.039920117781167073, 0.09586299514217723, 0.03089070290086731, 0.03142496304316146, 0.027138842833078197, 0.047402996494765245, 0.006619850023379249, 0.050993420769490545, 0.005901078562132053, 0.02221746336398346, 0.038189889051981514, 0.007931885718848676, 0.028549162821183284, 0.04246796150842021, 0.0753133300872099, 0.08672841554207188, 0.04511889002676453, 0.1069449932284413, 0.03867180815206901, 0.04031830347113071, 0.023342268128368645, 0.04446001610748711, 0.03300735020949956, 0.04092433647583089, 0.01297267818553073, 0.04290964950116412, 0.056661103942221215, 0.04277532364452078, 0.02367051190606529, 0.03186632544853755, 0.04260693751876393, 0.009798949242629593, 0.027914409180201834, 0.043683992022828716, 0.016138590158774488, 0.04614709110389795, 0.08024196440894758, 0.061177008394752784, 0.03883104335757033, 0.012720243595991165, 0.030398518222594456, 0.07196806927001284, 0.05344558011500105, 0.05461500950097557, 0.05192773011062415, 0.1812349217793634, 0.10628873166898567, 0.10051095017021704, 0.19880847314432745, 0.19499523985770442, 0.11909270388705116, 0.09469995109905159, 0.0867306755014485, 0.12293930030277661, 0.10711699528920074, 0.1578912114904773, 0.23704701644038004, 0.12172306677506817, 0.12859683664095017, 0.16402572183118713, 0.1353091917811863, 0.16646350553679853, 0.11959054612464483, 0.15003999004200583, 0.10336856538009259, 0.09622873317810798, 0.1900287990969035, 0.08697867348429658, 0.0820390151573285, 0.08046488833403395, 0.20794178869935775, 0.14980116979249064, 0.18709080594201244, 0.1750228833407164, 0.1353598608364982, 0.27257843483840266, 0.12566576126001536, 0.09027894961857989, 0.05734581034630538, 0.08577756253221343, 0.12324472423642875, 0.2927916034335091, 0.2699792517289039, 0.1465880131769565, 0.169267448626699, 0.13222487583275766, 0.13066656106422025, 0.15006833529520422, 0.11463386532399925, 0.06948303326123184, 0.1814519085230366, 0.16109598710411982, 0.12124403965689483, 0.07610637664554581, 0.08666817038770645, 0.11189656422263193, 0.2388297949707316, 0.13201319041752047, 0.25103271758604434, 0.17594215820633596, 0.1387290695622083, 0.18525308358573145, 0.13949175605610495, 0.12262485951425568, 0.1371819243556069, 0.17985040171732827, 0.14100752230132782, 0.14486198644003562, 0.12098503299057485, 0.1070519850679463, 0.10175372098362255, 0.11632661320148938, 0.12302705567450294, 0.18890983575294096, 0.12059724694418332, 0.164462391948027, 0.12058537258135697, 0.23393803246078954, 0.13745190906188182, 0.1543411294058446, 0.1306587469673926, 0.10978428361516808, 0.1141837043988128, 0.2631036432520036, 0.11519707784417177, 0.26076290756464005, 0.16817742808451577, 0.12174102387601331, 0.13600787928988858, 0.17145672873143228, 0.13404189849332457, 0.132165948349622, 0.2061858079245975, 0.15250357558890698, 0.2628134185027692, 0.07696814895156892, 0.13731657196917843, 0.15177170115132488, 0.15575931137127264, 0.2081126416282308, 0.059932962044953346, 0.16610349017766216, 0.13989703188980782, 0.09889732385354658, 0.0881730505235253, 0.11433050982774266, 0.18034699523160536, 0.0740393488517692, 0.23009343553454648, 0.053782835001907045, 0.08968055068004517, 0.147605347296884, 0.1742357279985182, 0.14373081165456003, 0.2188468357968715, 0.10829871655592035, 0.1779971430979429, 0.12425016867177141, 0.11658925112457046, 0.12193127415112912, 0.22034870520714792, 0.1570531725883484, 0.16220131408303015, 0.10874261088188618, 0.13660853818779992, 0.15547106312888284, 0.13618369646851095, 0.1286631338899174, 0.07304125119962039, 0.21604511436195145, 0.1391605762464385, 0.16552501718603796, 0.2333717709106784, 0.1549378046465497, 0.14004681740076314, 0.2518207156249593, 0.15777020024195795, 0.17564684663328434, 0.11232946518688433, 0.20410777910822825, 0.2141643531860844, 0.17298551847136792, 0.26789178470930747, 0.14420259924184892, 0.1066393624510496, 0.10394874674778792, 0.09478545417228053, 0.10349371350340306, 0.11156070361574812, 0.1065666453852769, 0.22106456840711258, 0.1767615352066294, 0.14713342181376873, 0.1516634069623486, 0.08838580846185647, 0.09638989509473886, 0.16115106882587557, 0.15452813146816147, 0.22107192285118565, 0.11204865565823932, 0.11870559965891224, 0.10718183697111185, 0.17291548271333018, 0.13240463070331082, 0.17506334810487686, 0.13856600008664594, 0.08350272572809651, 0.19294031625313146, 0.16246801993298918, 0.1407916234025071, 0.08647155392193988, 0.188323671238557, 0.2238678986266736, 0.19375984647100974, 0.16942866416948457, 0.10780079770953425, 0.08490924783531698, 0.2315789106632433, 0.14078177151180085, 0.1859799171647718, 0.16820344443042434], [0.059859869596097744, 0.014085925555968238, 0.0995529418991458, 0.010899375174044362, 0.10545977856963874, 0.036943222681481036, 0.0225797827325521, 0.02322750815731143, 0.0737707277819995, 0.05620684827707949, 0.02675585058187285, 0.020459544386774785, 0.07517468349467363, 0.015682895205945017, 0.00892556591650411, 0.05472871227069728, 0.03827985075692977, 0.028707938373930035, 0.01212407588853591, 0.017920407248781096, 0.025210402260023742, 0.08024466869932029, 0.04922969867625544, 0.018358858520044916, 0.03959325487695394, 0.037402461748570204, 0.01992169320733557, 0.06413168311419506, 0.02354320724524798, 0.023030428208350655, 0.006393496418416861, 0.04270500060351145, 0.04259024829333348, 0.032385826906970436, 0.09366849031780036, 0.059739444404840476, 0.060462524153051846, 0.04530586527600404, 0.08621437054487967, 0.06473406187949643, 0.019534588979196646, 0.06293618375615728, 0.09566840880941, 0.028873767681239598, 0.031068446790619247, 0.05628348771302451, 0.10431984739918863, 0.013714758829484064, 0.04616863732676833, 0.05099070881823859, 0.012158691571394523, 0.05283098224730742, 0.10197110609301638, 0.058683989749800776, 0.022027289697660074, 0.043457781580547174, 0.04885118229374771, 0.059937872668547984, 0.051589215009082715, 0.033494923038468245, 0.02066807160454412, 0.05633509522604366, 0.031355624425134836, 0.10489026114584939, 0.027353282334403168, 0.046828583769139745, 0.051053095188352375, 0.13256175533658074, 0.05777545160643997, 0.06584056863381017, 0.025835847932725184, 0.06632991495632357, 0.0449591875076294, 0.03960939251907891, 0.06577012684917258, 0.12518723975987206, 0.021389555974653172, 0.06445034121673915, 0.030294889509077036, 0.058921718324023875, 0.007381512832287098, 0.12596630521358984, 0.062238813918684764, 0.05913841012384623, 0.04499145896143971, 0.02926939846797576, 0.06992413136627405, 0.020960267114963745, 0.08897878349788728, 0.013613497327652671, 0.04324368298834851, 0.047471515398712895, 0.04016749523279648, 0.012410165678199022, 0.03527398221194744, 0.025958988905674028, 0.04463088435811862, 0.07129172854606183, 0.06852229005627095, 0.0572643100824808, 0.0686688426761858, 0.00819301444871892, 0.007143247038907102, 0.020027106905716564, 0.04287606420656366, 0.015838396690425374, 0.09873081464320423, 0.040652827254586646, 0.00932078397337107, 0.04188147906754767, 0.014750096015632154, 0.0352844622947516, 0.03985655546608952, 0.030828538696251573, 0.12893359357070538, 0.034568549299071875, 0.004135859724614889, 0.018302891966736606, 0.08385260574399464, 0.061629191792059335, 0.05365960209840729, 0.06363071906830996, 0.06722422301649086, 0.047068614437575304, 0.01244758332764069, 0.025240036456154722, 0.01627420878879005, 0.016122339518680688, 0.051015782876000296, 0.011621123844487293, 0.04174989963611288, 0.018636054028907133, 0.018747667293815364, 0.02694647240963194, 0.05362481404576571, 0.028769654417110067, 0.048875137863139954, 0.13404798123144335, 0.020156903267507593, 0.03740832232119095, 0.020066098865842628, 0.019469082716011235, 0.010246938308550706, 0.01635057434830214, 0.02297914628269932, 0.038298868889650034, 0.034519404758729284, 0.03464200947013113, 0.015188835527477487, 0.08500001393258573, 0.06613275456813074, 0.0436734123485944, 0.0589072967188493, 0.05229740200804607, 0.05927224951465765, 0.10000814368287403, 0.024188128788204446, 0.08955904147437505, 0.01278302641660576, 0.037451679067265604, 0.053056066540340265, 0.1252941856341016, 0.07246629455156865, 0.03969954191556862, 0.0022926301537682455, 0.058677749963657516, 0.07760849120395799, 0.044223287278005195, 0.03738788692581077, 0.081064275525991, 0.04224327941154761, 0.04125398027920916, 0.012162935698495038, 0.022191131006806128, 0.02843139978546289, 0.014378400688480227, 0.05917973673692154, 0.028011687024826967, 0.029963811206060554, 0.017773755037436084, 0.04149447826127853, 0.053867974183371956, 0.03379017715492556, 0.046435373820244305, 0.07456241070383018, 0.033596448840633515, 0.07892543465019235, 0.011796117478591061, 0.06613438633540947, 0.07042515286875349, 0.017095782546206348, 0.017937492924712358, 0.007268653716892005, 0.07706845284349496, 0.036535644753565716, 0.03155163568144124, 0.023445766606938936, 0.061616788828565236, 0.07237484663604729, 0.006780341134271435, 0.05997077231445621, 0.05288409512309779, 0.03434957072679554, 0.03632571367967514, 0.03559835533040666, 0.05537499553493916, 0.025213577694469885, 0.006980378182619931, 0.05473047810336275, 0.019054292070288813, 0.05131706993486132, 0.037871495249771306, 0.037781453105591, 0.08540485309617174, 0.04478818519161113, 0.04681044280709279, 0.03869374507978078, 0.08781072923973685, 0.036473718036206505, 0.03274016172414826, 0.03651298004232588, 0.0191283842638856, 0.029707882297976367, 0.037649980926465605, 0.0674398537845381, 0.0597796103947105, 0.03254287110100831, 0.03304555118384381, 0.05206915760232557, 0.021126343485628887, 0.02472699311892352, 0.03971061571651409, 0.07436986982582078, 0.022181066526700894, 0.06753624296717106, 0.06228649523109198, 0.011758716108517782, 0.08883205467774984, 0.025100549082121542, 0.03540122175529119, 0.026031075864129012, 0.011524443548443097, 0.029800634478188814, 0.01742698916895015, 0.019008455114559304, 0.025456010048548063, 0.028927139111704407, 0.004286701958100762, 0.00869525307338805, 0.04356311483969612, 0.04337305225612175, 0.0162268434876516, 0.05167698570256753, 0.009517295102048065, 0.03526269773682279, 0.026952108901534832, 0.00806340769368915, 0.04876127038451453, 0.022702601948572744, 0.051931618006839875, 0.029162312782700026, 0.020524058566098253, 0.05113311690248309, 0.0350905807628747, 0.07938752356435984, 0.06403122983512378, 0.020022906828671694, 0.03383109774140101, 0.06851918740017761, 0.026332083300897674, 0.022844649971492832, 0.03187066916706822, 0.08809140087255547, 0.03707274516683914, 0.025096105772160718, 0.028197490159542333, 0.034335616435254776, 0.058736099050410336, 0.05767846870566568, 0.04407613327906978, 0.014954098526598706, 0.03327880197414949, 0.06580494554533113, 0.021238180831254973, 0.06441438104957342, 0.08055493430865389, 0.027181964007116137, 0.06289667277146252, 0.036300275730149406, 0.0803211625785597, 0.12822415784842547, 0.006966886416663446, 0.05086643403516181, 0.023958311987019355, 0.026433588035645026, 0.033676332658937866, 0.04144003239249991, 0.08425584378381891, 0.025021251321079272, 0.009424841696126087, 0.039543191031102216, 0.011390075556963924, 0.10598335370060899, 0.026272878110889467, 0.050506583384929166, 0.036067212631385175, 0.016485763969080105, 0.04204609987115668, 0.05254942578293624, 0.0673809033187647, 0.06472244798656433, 0.04510616913678185, 0.017856904305517673, 0.05418697319504234, 0.050909400076395085, 0.044343302612222975, 0.025776882145193317, 0.03561840002094546, 0.03645600991383676, 0.016435782477680235, 0.076216907811261, 0.1337267145995171, 0.08063474534860543, 0.010780395973744172, 0.04840020165448228, 0.040033046802085255, 0.1157820396005146, 0.018691658605671218, 0.07284651931014753, 0.043181606883844065, 0.0727330616885616, 0.02453194138774228, 0.03808351774369517, 0.021593840980541804, 0.04762215509770378, 0.07043245368667188, 0.06685656209987018, 0.051476385579594684, 0.05380240471793279, 0.05188387157695909, 0.0251081295221323, 0.04839467433010859, 0.08415666604114157, 0.024295794785082824, 0.08377283300843932, 0.01121916134105695, 0.10799036616639746, 0.09411210885211345, 0.031083848988336903, 0.015583168752791901, 0.005623406163536974, 0.021425209706649188, 0.1930058627359329, 0.0966944610099158, 0.14941221163157495, 0.15973703905699715, 0.11212061429696699, 0.16839583975172814, 0.1847471897640536, 0.15746856078265176, 0.14756704290066996, 0.16261754497405023, 0.21894285725730084, 0.09156993800593961, 0.15575998552864598, 0.13058509527435228, 0.12615162188247328, 0.11061348952353002, 0.18350738371091505, 0.21113275940860474, 0.11725560206198886, 0.1287345945714943, 0.15449345832870853, 0.16066976642656713, 0.13914975908494767, 0.1432638504211941, 0.18016495741903785, 0.12319635344488968, 0.11727791820322314, 0.15907117075497107, 0.1138507089607658, 0.08400801434031419, 0.0884377875275189, 0.12554198443408937, 0.13443470241562014, 0.10984052979056874, 0.16245173290371895, 0.10064882301394978, 0.13856472838069164, 0.15951312687848845, 0.14265530081766267, 0.22802997771049702, 0.14456710387622157, 0.2077288009346493, 0.17969068770687427, 0.08956695516263286, 0.22910297577900274, 0.11625927407294513, 0.22808415544850213, 0.09609339608540458, 0.21627316341525127, 0.12096160602185035, 0.17094954788204164, 0.1136306961697917, 0.2328332264216677, 0.1130444014204606, 0.06544928156560467, 0.11144303251057865, 0.14346206801072245, 0.07637843745009554, 0.10725845342441913, 0.16248219255958835, 0.0844637523855894, 0.11339998879139462, 0.14290780339750553, 0.20171102707184133, 0.1309972352558567, 0.13916538727860298, 0.1109335610582944, 0.21256411808633038, 0.10947241688207274, 0.15450992921908058, 0.09176540533981978, 0.21629435340723685, 0.10202434154287462, 0.2090618092446558, 0.11718823995080688, 0.15478464834872754, 0.12367132795794357, 0.11418194239658695, 0.1235740807568354, 0.15836325954766045, 0.06063011354736744, 0.19992238030798976, 0.13670103564377756, 0.16082869902733835, 0.1511058175275403, 0.14105137317411362, 0.36579677955277506, 0.12945654050957772, 0.21244534381454994, 0.1902906326276641, 0.1009506616561163, 0.13223880331122106, 0.20919095634693102, 0.12091921071612066, 0.10619044258830049, 0.11094593337827152, 0.16877819423473653, 0.15147721695323146, 0.20116626194888548, 0.1141012886599187, 0.06623207786751371, 0.09291730280364714, 0.11556116113018607, 0.11580273163534942, 0.11985065595757578, 0.09545145270925376, 0.1803002025811903, 0.24684468344334634, 0.1381254382431507, 0.14122530577644227, 0.10379481670116225, 0.21633936873366758, 0.07174591909372999, 0.1927955716007179, 0.336205315806212, 0.1281860832785887, 0.08363401021568045, 0.10106836340480274, 0.1939479363781791, 0.20240927024954752, 0.11476091334536193, 0.18948541293221136, 0.17111485433434287, 0.1340803254636065, 0.14110285428262528, 0.1186428110926382, 0.2244090171711099, 0.10987701855840222, 0.15293949493958106, 0.1059672122280444, 0.1347024961104316, 0.22613849130369004, 0.12700552646551402, 0.2378070369483002, 0.156108126524956, 0.11232659235716828, 0.1469488405892926, 0.21364532861738436, 0.0862413828050898, 0.09763051320107714, 0.09571372291013118, 0.13906098481628204, 0.19142818126466968, 0.15770725845809908, 0.14024517288611782, 0.2516723090722676, 0.21512177923033315, 0.1642596697615039, 0.1245605568551729, 0.19960594002998647, 0.22655288358369183, 0.16236632942192017, 0.15335695157127996, 0.14098552025614247, 0.16460307633444188, 0.24223448888909435, 0.094074011299639, 0.1502105825009846, 0.1406852444333415, 0.11143955447140241, 0.18427177092000363, 0.23158939074604745, 0.22755124936661414, 0.13471596393614046, 0.12103996149474576, 0.16610229508050028, 0.23874295124363518, 0.1506518185018532, 0.21304912835119233, 0.2733296913004691, 0.170797985047102, 0.14461490776269667, 0.07837238811677502, 0.18272706187300145, 0.10296934164099156, 0.06089688834523963], [0.03640863503659925, 0.06787260919208489, 0.03916080590457686, 0.05631340727690728, 0.03013158063103836, 0.013536240233318701, 0.04886494123286778, 0.04335623279574417, 0.02325728024926878, 0.0314573455797208, 0.04498626871575271, 0.05446404421461686, 0.03591344729366322, 0.048455490219977596, 0.023773096824785876, 0.0268643707667868, 0.05686648828428119, 0.0984246782477825, 0.022338669964923494, 0.04939663689583541, 0.03782883181326813, 0.07016531882747527, 0.022215722429175532, 0.016958223798522548, 0.01123760107739438, 0.019836649786861196, 0.03296299371868372, 0.07127107481562323, 0.0076591545873652064, 0.04153213531319653, 0.06186371811875894, 0.03991886522741087, 0.008222797074385228, 0.02640975504032066, 0.011335700551318306, 0.008051567804819394, 0.04745555778725013, 0.05295725651986657, 0.04028614693050904, 0.07493278357170283, 0.011380615328708965, 0.010988772846758367, 0.07944786831015542, 0.08356989631729742, 0.1245564429630195, 0.04918742211415403, 0.009578380080300474, 0.016880657396189148, 0.08051922695050318, 0.03409195451005813, 0.04935311544085703, 0.04035430960357189, 0.044833047300456993, 0.014703335923953884, 0.014630842938899033, 0.030381802184086655, 0.03453866037870607, 0.029677497335679592, 0.04334340848389172, 0.046594766073770104, 0.033014233509499225, 0.054317403494590716, 0.06318983929832617, 0.06956478250363181, 0.05054516740323556, 0.04837187938392163, 0.029579146967960462, 0.055415647990641095, 0.0306287927613143, 0.04685818923697357, 0.03986478708083591, 0.06842949382600284, 0.058630007364216356, 0.04834156145431823, 0.040643626538616036, 0.03770299804126544, 0.010540906354905137, 0.02889120192717641, 0.06893669765803122, 0.01832152514027492, 0.05079164470155394, 0.0710131176897595, 0.05780314951534233, 0.03896594378015688, 0.05707148958237902, 0.07835645348794999, 0.06390785903579767, 0.07578360848128796, 0.08094144098821186, 0.0656383520653171, 0.020762350214945696, 0.0554597286898042, 0.058089218237587524, 0.006270112212552059, 0.0531200731864139, 0.05389915013145055, 0.11350400054887419, 0.025079979621354612, 0.07498863904226212, 0.09164459327416075, 0.03782171102601194, 0.033454374004636085, 0.006672592782941197, 0.038697847480615305, 0.03212125844232017, 0.03192750139973097, 0.05478888081627027, 0.03674651811560316, 0.049885335874052784, 0.025151880803487958, 0.06612925354631678, 0.03150471662651868, 0.06794197079274925, 0.02842020149522972, 0.05051159359995396, 0.06425708021608091, 0.10210018424737839, 0.03366974813322868, 0.06972185351074704, 0.018724341831740834, 0.01830702118064848, 0.02136895395514946, 0.021771521668039986, 0.07056698638705478, 0.045863653893672654, 0.02315012944651948, 0.03559350599384597, 0.015789952162923594, 0.014894876099612205, 0.03194666700437665, 0.04264493164936862, 0.028033920811609398, 0.08966243270063594, 0.017096046846540227, 0.027636257976654078, 0.027562234730970477, 0.030536756873311057, 0.07252225727443734, 0.06877363584334813, 0.019350266309394952, 0.024830642899858858, 0.08777717458865336, 0.04116704462156181, 0.03856503847806204, 0.06886183554607053, 0.04283769469287607, 0.038005388266737425, 0.04791673122634811, 0.05527861784362505, 0.028019539426050843, 0.04370495218843703, 0.05189515222164412, 0.03505224189270408, 0.011880441734026517, 0.06036500882117018, 0.050031528432643226, 0.017098341279873447, 0.053639408020723256, 0.05452797808233769, 0.013718228250171148, 0.10186857288523067, 0.01786527764653006, 0.05357731659446032, 0.048068171487219875, 0.09431788772945443, 0.04120454845589496, 0.04874433984138793, 0.06625432506083481, 0.019297611171139345, 0.06629601556567416, 0.033877886561376434, 0.05176792033917962, 0.013365917820333233, 0.03062288430819829, 0.041952277083070054, 0.03924052884441711, 0.03943152222481947, 0.04514702843622335, 0.009856827185308982, 0.04665307302568709, 0.059536591983370246, 0.042701817508186066, 0.023274534464543386, 0.041629271431555676, 0.028287170327178417, 0.054322429031374, 0.0761243260856117, 0.0634503934622532, 0.020223384377576654, 0.06090920703906206, 0.03244770765905419, 0.031129136275980743, 0.04166545759465906, 0.038152009834565466, 0.07568342716342981, 0.023471652717900374, 0.040531398488148566, 0.063950874872746, 0.031888704792025595, 0.030927695371511004, 0.0800426283310498, 0.03645265061828879, 0.07212924650840222, 0.025090528652071956, 0.030957879235727653, 0.0634811940272489, 0.030268426916952577, 0.041944589390749895, 0.06583663860275861, 0.02967424337722121, 0.013107387086136207, 0.01608983632327328, 0.02232887936125119, 0.016418692971309348, 0.037810173741872274, 0.08272103259279844, 0.041780926197046236, 0.04966784734278918, 0.023176737595349554, 0.02586364160261808, 0.03620354180795051, 0.03776415867070037, 0.04957778987685039, 0.026154456239554192, 0.00717413378879428, 0.0181376812754259, 0.03753175440755102, 0.04477396659973649, 0.03739907947038451, 0.08983099502661536, 0.011410543511080886, 0.059478591466622974, 0.1458997904292999, 0.08944045106369643, 0.05008706597671394, 0.05859369862704508, 0.05763297457428229, 0.051175780338986274, 0.025931808106120557, 0.05028838239189598, 0.07729124653363421, 0.08145569282914362, 0.03626395933209889, 0.033820966228602395, 0.07099853137568121, 0.047525938284853776, 0.05067144550623433, 0.030775513920572498, 0.0571435209994595, 0.04100064266352885, 0.0651480940981738, 0.05898516189547316, 0.02616895062308158, 0.006083021092513997, 0.04781776415784994, 0.08084378009962459, 0.05880685493109688, 0.06811153669390949, 0.029276948264469544, 0.06558666411306589, 0.028096194183754346, 0.03835811046883464, 0.049771606291253725, 0.05934991933886082, 0.07099625609454609, 0.03354010307380269, 0.018217808326646205, 0.029231205154510758, 0.05150047521437368, 0.0696459801627263, 0.024801575608791846, 0.052903549925934885, 0.02261495765959544, 0.08948003482674399, 0.051616893765786966, 0.06843196828999827, 0.008274201574104448, 0.03827363012298461, 0.02838957904567642, 0.042277374154617714, 0.02196994801652768, 0.06287498482232613, 0.045731568844207836, 0.05215526205457507, 0.04745102637717801, 0.051201517062802474, 0.039411186420869444, 0.04641689960995028, 0.03976502711133611, 0.017464596425153075, 0.03403033039742901, 0.013245232159181709, 0.13036024846857594, 0.07038995112863279, 0.03313986426820198, 0.028836127866299886, 0.09536906761387665, 0.012816513077385966, 0.021215265226219932, 0.009131723049757703, 0.04588196339506296, 0.00964785276371385, 0.06236185146976383, 0.05898691240638014, 0.011948528755906851, 0.03529328379719969, 0.04192759756058936, 0.0822139973001134, 0.09392119208050352, 0.04528704249570447, 0.0253502439497219, 0.09413754297119957, 0.035001752868054375, 0.016495525844455246, 0.06764728741179551, 0.04905419559368203, 0.01965672637696468, 0.07710510248979253, 0.04486402406567528, 0.06983577844596679, 0.06600507069379091, 0.03741782947233127, 0.053696278557782216, 0.03165437956340611, 0.07388624618010176, 0.027310115195089774, 0.023077429617725076, 0.05396880667596575, 0.04073533875447127, 0.03072566457933957, 0.019529075061361638, 0.038377354597492565, 0.02831181920614214, 0.11912996640368817, 0.039863281718064705, 0.0036115288000268444, 0.06595558907476164, 0.03507491809526279, 0.05514833693122191, 0.05536755682119439, 0.11015379080368627, 0.026604450540617112, 0.03598475858809487, 0.02147359007428731, 0.025626382257248607, 0.062398156376495484, 0.0092552853710649, 0.03614632653132562, 0.02817519700094577, 0.06788120469859532, 0.01982055427957206, 0.018139680764908274, 0.10921311910234152, 0.20357268201487683, 0.16187646215961826, 0.18810130655765536, 0.10006562325983279, 0.1376760357450093, 0.1939886769339923, 0.13565531030537623, 0.1841471284147232, 0.16960137103113437, 0.1669073155930927, 0.14191516795225684, 0.172364680817531, 0.13322135703938623, 0.10652753659674238, 0.10547582045077317, 0.13167339977958512, 0.18174533551979452, 0.12978670908318413, 0.10838238101813102, 0.1140490108199658, 0.10555889502528215, 0.12876182133632322, 0.09420827586924839, 0.21993091149676233, 0.18708037182448373, 0.11400833921206575, 0.19993615456886832, 0.09892574571553739, 0.19347440211042283, 0.13074474799777233, 0.13819735857748217, 0.10839143617739601, 0.0751481002437011, 0.11303590550538033, 0.06635238431514272, 0.1249214761980599, 0.1446255257413272, 0.1611428257198103, 0.32581848122419854, 0.07261177464838951, 0.16385811711511306, 0.1573425546408661, 0.1499796529570895, 0.25485420930049113, 0.20583624200474834, 0.10708003920773346, 0.05607336128671324, 0.14260185852406487, 0.15438263604958213, 0.11770491262957936, 0.12432690769914659, 0.14090900339426535, 0.1853714441700328, 0.07505162679139646, 0.17246039584279063, 0.23170703120769995, 0.18768113797470448, 0.31001356640650385, 0.14098084711980435, 0.13575533074477028, 0.14261178702356356, 0.22236598325112175, 0.2016303273698976, 0.26139505267623936, 0.1522349238756203, 0.14924610844783245, 0.1466759447489054, 0.13601420717614313, 0.14311358993572576, 0.25838371426347767, 0.12532818461618117, 0.14265599029679454, 0.12499088376399972, 0.20958359172988325, 0.09027253746265367, 0.09083968767475697, 0.10105950742839806, 0.19288646027205453, 0.17200389937047036, 0.2121455276445035, 0.13507536642493742, 0.25100601176100396, 0.09799129464813779, 0.12941797564346946, 0.1819032415627472, 0.185620897719937, 0.21840771419867394, 0.16148416385535272, 0.1598256907515949, 0.08930859201016927, 0.15614289159495987, 0.22548226038775138, 0.19934168566138516, 0.12162486962493389, 0.23929900850259492, 0.21448396506809422, 0.1476120582271007, 0.18285038670705211, 0.2216140373099235, 0.08834923542435132, 0.11378699342810339, 0.155253708663006, 0.15095226286399752, 0.1713038175817459, 0.06456643418078462, 0.14933656810993148, 0.13761025943583058, 0.17678597341141394, 0.13444392611422848, 0.12961273051558003, 0.09890471660201589, 0.16136928131022762, 0.05679221222958258, 0.14172033647135382, 0.17838345059464056, 0.3030784482196454, 0.19924679801108378, 0.17990539150853313, 0.06609791288933446, 0.16920816874311817, 0.10876498831015442, 0.2476854342967272, 0.17492335319759386, 0.16703597239909634, 0.1559473553131665, 0.18847233826114287, 0.15511852478788746, 0.09798699689488258, 0.15471046039414021, 0.11081966676659162, 0.17633289369123598, 0.3548892196868697, 0.24333963200690287, 0.19269990254073374, 0.16893562530317616, 0.15844288672651016, 0.15233770223154178, 0.10732159439113834, 0.19270952460506272, 0.16753397551515412, 0.173729665637497, 0.08661639816578358, 0.09832270428418152, 0.17603338395635929, 0.09824241060883769, 0.12719445140852084, 0.16159889318289297, 0.16609189160648855, 0.08403645152406347, 0.18675977934993085, 0.1818420158158387, 0.08289268991399197, 0.0907481478286847, 0.11373565787629736, 0.11945222128903675, 0.11061735060666839, 0.17412017129601973, 0.16792763745592487, 0.10958744498390345, 0.1492643719839473, 0.10178490076214076, 0.196089152126543, 0.23966919750936572, 0.2482388868567444, 0.12790770990954292, 0.1498760472262098, 0.14272450920074217, 0.1293870256913285, 0.1431331251777949, 0.04715463078971352, 0.20672848928839932, 0.17205223951849247, 0.14602610300625526, 0.15679117051824448, 0.08704647226559539], [0.03570619752750762, 0.003816523634257817, 0.007953066134735221, 0.0353845976473343, 0.07802283751868433, 0.040779806328036135, 0.05100298537722519, 0.06155046859696027, 0.059680486278187846, 0.046109119955930984, 0.06273995416479246, 0.05924049517019622, 0.02220665003293224, 0.020454118569051067, 0.009222868360548971, 0.005106536217123992, 0.02096140092509168, 0.01561117213925407, 0.07255304634811417, 0.03020474202780714, 0.07169654472701012, 0.030848700215198824, 0.016464424589949272, 0.034701454062615676, 0.05820990006829943, 0.01225045741340446, 0.004711073490926215, 0.026804949156939987, 0.018600859949665687, 0.025089770225026918, 0.07400531922617266, 0.0277536322227529, 0.12156399627847057, 0.0629169472883786, 0.0680345448575193, 0.01959193066032904, 0.014703570538380695, 0.04776713340693424, 0.037406713536549965, 0.025521897440475803, 0.06424288077640437, 0.03506050798140707, 0.10123710193100477, 0.013812926293711269, 0.01832144278582306, 0.021965200186616952, 0.005241773239592271, 0.03472586928476249, 0.02808361693525747, 0.05146883195266128, 0.046287112824258306, 0.08949616863842934, 0.06896727222708926, 0.05592533394754414, 0.038252221795940594, 0.017733447321300066, 0.08328773081302644, 0.05358210081354745, 0.027281118767155756, 0.003358449739020979, 0.025636373959001035, 0.018266960527868043, 0.01754089112153217, 0.0851309460197245, 0.04595955278003409, 0.0583679631592766, 0.04343520496941863, 0.03862986483821466, 0.14487471882133715, 0.016273180315751704, 0.05623166186494693, 0.04715559223005849, 0.05524502488814535, 0.03275281366621775, 0.07070312021119941, 0.022649429700968247, 0.018313948530703783, 0.027336531821938775, 0.0115817689502071, 0.026031684904028813, 0.01714470683627071, 0.09364838050978799, 0.029716845526690447, 0.03687309116245278, 0.018277298884406205, 0.057382448501284086, 0.036861320221496206, 0.033334423787891865, 0.09991353182422538, 0.0647817355310244, 0.011515160478020628, 0.13778265986231067, 0.00751871534908611, 0.060249498083947174, 0.07041265797470847, 0.027191635867160176, 0.011676957290018759, 0.08786574201357943, 0.06412709807796825, 0.057456211277073434, 0.014342945181734621, 0.05195313358619329, 0.037495212013562845, 0.031912792511584784, 0.04550221361099713, 0.03435411745862615, 0.04742650007228217, 0.058407309435067646, 0.05359627344014664, 0.06758170262459787, 0.03823775039505094, 0.0416222962010051, 0.03707608914062862, 0.029191240262720856, 0.02325686847700948, 0.023778107039810672, 0.025147807130950595, 0.012521078930266443, 0.013984437100589277, 0.062480947498472474, 0.060735228471457965, 0.010978899888634201, 0.0453652409205754, 0.010601527849963356, 0.03461641447258092, 0.02357898163609207, 0.04397669506649818, 0.03213199133413934, 0.02148206109151004, 0.040756459798543684, 0.11853079371634992, 0.10910159202232476, 0.06455145716186493, 0.04524567374779333, 0.027004382911048112, 0.04111392791533182, 0.031448110389793595, 0.033855643198494954, 0.06323139190733915, 0.03962179165213339, 0.05181563995598305, 0.013276296066901377, 0.07142640680315034, 0.06483576005144466, 0.027326700998650446, 0.03939358938124873, 0.05073955455314248, 0.015232740984027906, 0.03454615271860554, 0.06106246292831437, 0.019419296577032057, 0.06556113040254963, 0.014960302881175473, 0.029225277549196637, 0.027999747544527057, 0.050289424271473, 0.044715119555832884, 0.00915408707148726, 0.02913432567560625, 0.006098435260355473, 0.06207011369687896, 0.017752093901377053, 0.07006522177928878, 0.08486106856575898, 0.04781410225757188, 0.014594947889206872, 0.048671569149460525, 0.0433040124123856, 0.030812613643525593, 0.028715093635142814, 0.03894972569879986, 0.07844320528449551, 0.027335537822857022, 0.06655604112893343, 0.012452237311780695, 0.012531326313863599, 0.027996717666786526, 0.05376843254893057, 0.02977778973628677, 0.016945031764466437, 0.029849775188091784, 0.02032654003180083, 0.04201488561868187, 0.04025864054358775, 0.01964415678934705, 0.051823645574791785, 0.05839448895365481, 0.04402015906488223, 0.03196554532605073, 0.03706094358236559, 0.04774119750025773, 0.021050751674920324, 0.03634254080093196, 0.05121832503186119, 0.06271628587837182, 0.07415921096840213, 0.032551190815865993, 0.06413085956967647, 0.0330826872959733, 0.037892520532853184, 0.04696253807313981, 0.05804372027576451, 0.0161067170706848, 0.06570907730248667, 0.005491222480251905, 0.040124621122114124, 0.03823978052805028, 0.05713520128460181, 0.07795087121907743, 0.03680172624186643, 0.0421355176536787, 0.04460571453936639, 0.012741812801499282, 0.05204104983638372, 0.03076533644249843, 0.017763652252934633, 0.11342788205271769, 0.042639840995111776, 0.011290293562436297, 0.04076045494706881, 0.027792208580180045, 0.041507563043025233, 0.07292996926773941, 0.05230592090576407, 0.030561145282380527, 0.017496159247633432, 0.026884105191716266, 0.05528124169476571, 0.035226875465483434, 0.06432575999849266, 0.03801430936061567, 0.08986309411064272, 0.06967945820501736, 0.022018010457677227, 0.040586756001557076, 0.0174505157291048, 0.03448911364220324, 0.04478164280073778, 0.029071136828391787, 0.04785534843141514, 0.04418385290210286, 0.032301599370135416, 0.06987922329215274, 0.021438729243292924, 0.027539432123904268, 0.02982439086472075, 0.11616531338903213, 0.041588898597946095, 0.037810725325177756, 0.023484787295362162, 0.06383746704687515, 0.020770763775574106, 0.006356028973260114, 0.022141180158923232, 0.015917929065894457, 0.026612301026621175, 0.008304979156462416, 0.03098695801811353, 0.033861388857927055, 0.03311493959758551, 0.013270072560126503, 0.09589901659637691, 0.05591478108638718, 0.01597420396959229, 0.0738912640560058, 0.03529374344995426, 0.05333845804054892, 0.08519605583240909, 0.10245608571436136, 0.012123055076376807, 0.05014595515545338, 0.01867983403855995, 0.02990081196560735, 0.06481901336941989, 0.03285610530104849, 0.02007129868762868, 0.030602238238638932, 0.03535576592830401, 0.04449560472200956, 0.020154030437791542, 0.047706650765312296, 0.01743069128884423, 0.03925316163428849, 0.01056798564780864, 0.04226622374487981, 0.016140275552207907, 0.04293516022904266, 0.05601991516267581, 0.0008221394056172652, 0.008790655917818508, 0.02984019717381847, 0.017505178017722025, 0.015023704317788926, 0.0305455879518582, 0.04692045303301946, 0.037366133859200824, 0.034783410148755196, 0.05462259760186557, 0.03335981960258177, 0.014777628258020889, 0.062343021028585015, 0.01098751167451302, 0.025314919635533326, 0.02513896456108459, 0.02049318522274975, 0.03423894763052945, 0.03960933506248459, 0.06193885602237237, 0.08871963893574092, 0.04674637870442483, 0.07681736752631203, 0.0046027390823339025, 0.04634101477061068, 0.01750500181749944, 0.061822054426996946, 0.0960581407191292, 0.0379819383153752, 0.032370696670465895, 0.0272522583198283, 0.02937081893305144, 0.017980554726936163, 0.04647635186331407, 0.14561290582341535, 0.019423383656108094, 0.024623508046891902, 0.02025352993739709, 0.044202089625140356, 0.06919839329296543, 0.05054351648375873, 0.0797595281995112, 0.06264629608560955, 0.06692777763331129, 0.03029276744552678, 0.011443549451688606, 0.028757766647745046, 0.04547079251478276, 0.009386145637460775, 0.0648859311496058, 0.005549211984485268, 0.013992051056946718, 0.018136160590896205, 0.047839827490069216, 0.045870146488830935, 0.09139550744646019, 0.009274017178423462, 0.02399066962572115, 0.08027421671055979, 0.03201539658250348, 0.05789346362073576, 0.009918724216761128, 0.040657983026317054, 0.03644688580665858, 0.1251366013480771, 0.0879647282342757, 0.13308776662715022, 0.12430538828935354, 0.27717677035158683, 0.12989613708228837, 0.16842101340092, 0.13852418700773872, 0.14162194013835924, 0.16624553820058224, 0.1750981438183977, 0.11549071934554847, 0.13570320612240222, 0.15150997487287368, 0.12169568679265438, 0.12031893486217146, 0.1273323932001668, 0.10322136158544211, 0.23938073476235713, 0.15940818815462052, 0.20481653301225555, 0.1672319530118858, 0.09766297234642891, 0.15087833537930442, 0.2500433303535946, 0.1398755354626525, 0.1299226130809515, 0.13170165310223259, 0.10567279697786416, 0.19016258869199984, 0.08950458794471719, 0.14221316083304344, 0.2870050349062489, 0.18673258322861888, 0.19227850821710404, 0.12427033210593848, 0.08559842819287893, 0.17096200447169044, 0.08866742238282196, 0.14516583223256374, 0.22159369001465462, 0.15084234456862175, 0.19926152222098845, 0.1790423474965557, 0.1251397116650497, 0.13441587197444133, 0.146135515683601, 0.15122233950082334, 0.20564832063692234, 0.139129166641543, 0.11587770099961951, 0.21546975168729984, 0.10573513355226287, 0.1409992025864701, 0.18023706161447112, 0.16393518556029568, 0.20365739601754373, 0.26431749424626755, 0.16801062009988293, 0.11871955012001338, 0.08873463127641909, 0.176904104169338, 0.07141382763943366, 0.1819008973336989, 0.1331479351727232, 0.2051975545022757, 0.10939389286983399, 0.08954132186068643, 0.2505284631925245, 0.1259486545478144, 0.14041859987041644, 0.21836223921948866, 0.1720202783302915, 0.11668236911176674, 0.18414253188717752, 0.058382978482592496, 0.1232223085037643, 0.10432610633753, 0.08927483051534622, 0.15085124651030188, 0.11469471568782484, 0.18631672005980246, 0.07665484197317593, 0.08616441395133735, 0.16680450659365426, 0.27954649480600513, 0.14732449946384277, 0.20286717632364845, 0.2194762996007358, 0.1437543765191109, 0.13439276676264503, 0.28922184821098085, 0.17488086596131328, 0.17872175502200283, 0.1353221846323821, 0.06931172834048349, 0.1284540761562605, 0.2761081083407325, 0.10627582308746154, 0.1489173035107313, 0.11962816870260624, 0.17065227512390385, 0.14691674150526524, 0.21947245383935593, 0.23984513726205597, 0.1761822195182885, 0.1899133956119899, 0.11721460103628137, 0.20419148187483513, 0.13303535089137095, 0.22409263818014055, 0.13327722017082477, 0.07909866245163065, 0.1447760007314144, 0.13580083636747253, 0.1057954170110245, 0.12410052105664246, 0.14354926413826405, 0.12717655559460964, 0.1432218228376681, 0.12802908888026593, 0.1560454298892329, 0.19577882523017545, 0.08361332584172489, 0.17006148343845723, 0.13591141349846317, 0.07298970114319556, 0.16200036922049138, 0.09496758391539897, 0.09214192223284515, 0.15466645630376955, 0.2236954522349181, 0.2698190474221783, 0.1371924504036865, 0.15060369285844988, 0.11159973579549021, 0.1291951666315717, 0.1321128278129524, 0.2441202296364692, 0.12352139689028264, 0.1169749457509287, 0.14775087335898032, 0.11870390660459958, 0.13929597462617582, 0.10163830217695045, 0.1039057692152358, 0.20055683900512036, 0.1464659906923771, 0.14321497401162503, 0.08570495271875013, 0.10037644045247186, 0.18887793585177393, 0.10201016125539619, 0.2017445817229248, 0.11509886537227901, 0.14401809462616522, 0.2559564412841874, 0.06827001730280538, 0.1366826648553533, 0.15295630290863976, 0.09060687355456815, 0.1254810114961959, 0.10256286304924758, 0.22496789363363098, 0.14113942732013043, 0.14998682354006077, 0.13628161782699247, 0.2226278627471578, 0.12123536754159198, 0.13348996278739747, 0.1574536067463698, 0.15061107794603995, 0.13899261912991925, 0.15671664548497047, 0.20972562443104484, 0.30123487295162293], [0.10315815933168897, 0.04075528002314029, 0.00948986819674892, 0.04930936415950137, 0.05083621952742819, 0.024854008581549413, 0.07598912688873469, 0.05083496697367199, 0.02659895960541983, 0.034844819756765524, 0.017011857614101424, 0.05071277594974926, 0.05453851179129655, 0.01338986189840662, 0.02910510516695438, 0.04488918622354827, 0.03369901652237581, 0.025208312755210266, 0.08145540937661164, 0.04610592919972636, 0.027267394301992272, 0.05151105871904762, 0.011094700781658534, 0.028390278100907326, 0.05949967037585955, 0.01858399643923246, 0.046003016778418136, 0.030074934174697247, 0.04031454964030174, 0.007250153651130536, 0.021723717781564882, 0.013443420062802974, 0.010913549715863361, 0.05885013123793949, 0.034043108744006005, 0.012216132843957074, 0.04052363418703599, 0.06406211850023077, 0.027576510779439446, 0.03939093105615147, 0.021587474789891033, 0.06509872739233317, 0.05351083548439126, 0.025343875843851317, 0.035672635215544896, 0.038783725936927145, 0.0589198797130056, 0.012638627461368039, 0.06293864289839422, 0.03149648884221191, 0.07038217533620135, 0.021620723005804806, 0.03839064239253921, 0.022008361580270915, 0.08738080069663064, 0.07294258673585231, 0.0054890496633766645, 0.013293185432802045, 0.06647577043622732, 0.05256304682622995, 0.021072610078619856, 0.05500357312661025, 0.07165683072901542, 0.048557678688197374, 0.07004901901969025, 0.015761540834641746, 0.0667521366549115, 0.08461486322865372, 0.13038327707157982, 0.1176399713562381, 0.06774585228413343, 0.03346269754993339, 0.09221971080067659, 0.12628903507345146, 0.04416085877305558, 0.017253947143833485, 0.018741998243175687, 0.09965876928500592, 0.03167720515311005, 0.026953974325630455, 0.04532629301050498, 0.03958742877828979, 0.00944682363150341, 0.07764936199471836, 0.007871089459982732, 0.06485986117754253, 0.07581871829085773, 0.031064258204893242, 0.03007108841331736, 0.06481471561616467, 0.07159005850553513, 0.06937919004309563, 0.07837346063986902, 0.026302454850426125, 0.11305865831673147, 0.048578504788418936, 0.04761933589414243, 0.030597524882684794, 0.03456246656095309, 0.019877897875924266, 0.03719956336182453, 0.07075771929756289, 0.03265997913155345, 0.04175411695013604, 0.026645899727760304, 0.08741902082317299, 0.08249705146637656, 0.08252529712814478, 0.057711322386298454, 0.03520887239926285, 0.014454533548785314, 0.03316749705963078, 0.033719218260939085, 0.08158085627421256, 0.05076868887690287, 0.022910778681116722, 0.009019740147426004, 0.07637299822583314, 0.06305517636299615, 0.047811359662802956, 0.038937966249162154, 0.06679760397321756, 0.05365800097464554, 0.03963972194000118, 0.0318705044581645, 0.010523277714157538, 0.10248643811792137, 0.022389904010079564, 0.025622908048511996, 0.017270661267121474, 0.015235092873955447, 0.01163201186911113, 0.017295166504599394, 0.01982000078104677, 0.018725303272085807, 0.025809754978024194, 0.03123947400449505, 0.030418476728241772, 0.05759151772625985, 0.018471308736010425, 0.1370849223026345, 0.11489013705642954, 0.03902115573685977, 0.042118521993078535, 0.025384807921645623, 0.030858102029249556, 0.04872801067728189, 0.06510828050874895, 0.04197923571712548, 0.05937853655327232, 0.11129276436423102, 0.027766429721528006, 0.02266126384417857, 0.054317365190194505, 0.04976953785385817, 0.04594582448443098, 0.026045721550021442, 0.007882552050549777, 0.07522832497113174, 0.03857425834623076, 0.03968269947255331, 0.020962285756644224, 0.0354970631850583, 0.06645542314095844, 0.04255772020006853, 0.031171675223196228, 0.03268069414902599, 0.0356277309718632, 0.017916450404652187, 0.0341237892937516, 0.045618394675153884, 0.08273477621016004, 0.08598554774277634, 0.027414176748284412, 0.008585135595151975, 0.027940829637490457, 0.030217811487795367, 0.07689250542992547, 0.03460767340936488, 0.013236903825834876, 0.06044845111788281, 0.07740868015154716, 0.06255744137771188, 0.067082213297967, 0.028591412570207354, 0.027509786436454426, 0.034363827623066404, 0.03228336264709792, 0.03503802330082944, 0.04082596695591365, 0.026528471855506785, 0.03404687789659347, 0.04365419503301383, 0.09473600319676823, 0.011111436929974345, 0.09551107733240051, 0.024537505101292365, 0.01848999553570344, 0.05367910669695947, 0.0059801594245307635, 0.015176341591042378, 0.017371691027355772, 0.039693593242836576, 0.029250562281137513, 0.012004673424657556, 0.11432016764076487, 0.015055616667884734, 0.01594979928115443, 0.05097249124739921, 0.050740596432719505, 0.02712947740820387, 0.0562486230515905, 0.01846907750493096, 0.052476950034859686, 0.034571759207474614, 0.02928676951165882, 0.03215845201104399, 0.024620451356074022, 0.06520072433857188, 0.04543120875173519, 0.0447561971903328, 0.016253384603788296, 0.06015176058656747, 0.02534731557863134, 0.012854045640016276, 0.08567664576994796, 0.014040759884782377, 0.08057920397409508, 0.0592130730529466, 0.016109699067930063, 0.06662979241340392, 0.04314195034244368, 0.034514126412930994, 0.026981015314137744, 0.026003889318916108, 0.008078680614069586, 0.03078638662343785, 0.022504514593991543, 0.10712733747617853, 0.01515113921355336, 0.08148164788801825, 0.033008882385348125, 0.034939136671563314, 0.05033184639028004, 0.063788793650606, 0.04295833055831252, 0.054163718596100814, 0.014638312296160768, 0.05061085561230298, 0.08765879868259353, 0.055272431683636485, 0.0773658405148214, 0.05817678591777241, 0.008201067948022918, 0.06448373498935854, 0.06147076480931813, 0.0246394541670358, 0.05595362557458782, 0.05519905195180928, 0.06192607384535575, 0.05774679225719264, 0.05456816705484545, 0.16133871440204883, 0.006977629363386622, 0.04050247483856736, 0.07907976306253865, 0.03219697857275605, 0.05004377434811285, 0.01135391716454779, 0.027456321160218893, 0.04911149513997859, 0.06625106152627738, 0.08970644445188584, 0.0386759411964205, 0.047222333810021805, 0.023282515185494578, 0.03563183720313734, 0.019169255054645964, 0.03524199421066911, 0.041554221628053535, 0.023301786127229853, 0.09941918294756644, 0.0329379694566371, 0.008768122399135703, 0.033666124537346825, 0.028298391600049315, 0.024612727274577466, 0.03339245111771649, 0.018762694108450127, 0.03229545534498269, 0.12013138887742836, 0.02045893534687498, 0.035598753696127285, 0.025731332472435413, 0.02028721290820789, 0.03866098716013855, 0.03960105748246274, 0.046910731377260345, 0.01186367398458383, 0.04640229031323426, 0.06878970070712029, 0.019370759161369457, 0.055027823639853354, 0.03660839246285539, 0.0392377364539331, 0.033057831573270025, 0.010516696061278063, 0.027229216310285756, 0.019615602777189305, 0.009917170973494649, 0.041699625116081974, 0.04217499416441687, 0.06149009703808735, 0.02793223987663946, 0.04407354773232534, 0.022205269159448725, 0.0438549981692866, 0.019376790188553355, 0.015604625917941093, 0.04047497228208569, 0.0411942828777096, 0.01063370066995342, 0.06119040727254845, 0.06461975390031453, 0.09695912140511698, 0.027272176605859594, 0.06446288207605963, 0.04228733329763336, 0.03447118335433545, 0.03340255581743775, 0.06777964442247345, 0.023057028696301485, 0.03514781519169769, 0.01063660893123597, 0.06418947295676317, 0.05548492532163378, 0.014185200974855934, 0.04338761558756233, 0.05472567473207751, 0.01612223226637129, 0.027131103429823156, 0.03173577832058072, 0.03010744886142352, 0.05425112539782159, 0.021139983681120703, 0.022048177084915584, 0.13896554558267518, 0.06122593460003696, 0.05908069689007056, 0.05478001334854672, 0.053867951200734225, 0.04482334096645636, 0.15991611977017697, 0.16983380210736107, 0.08302926806913269, 0.2099001545819544, 0.19446348290770285, 0.2190612791286361, 0.23807774177722393, 0.10346143055827388, 0.09605726737889553, 0.20967071124863243, 0.12177442530951194, 0.15305451538053252, 0.0649810945915599, 0.0717220631157679, 0.10662308308265864, 0.08204975571002691, 0.3170680104484481, 0.1328672865225423, 0.1414037276540072, 0.16590055348652025, 0.10956817021172856, 0.09221041815415507, 0.10266960974061683, 0.10099214531721608, 0.09652923116640699, 0.0729115525140397, 0.1445211845660402, 0.12010951706719016, 0.1299774190110545, 0.18321224067720676, 0.09122256309755387, 0.07944014614387866, 0.17045626386759744, 0.13693801728227448, 0.10308948721015647, 0.1067225672605057, 0.12915050370558617, 0.1247046503328508, 0.1670316516632034, 0.16417860233735654, 0.13536226635258045, 0.13456299149942014, 0.2874455354627102, 0.23383793541260306, 0.08981895212444568, 0.11162599728953455, 0.19095748152223327, 0.17903696955932727, 0.16878072232488664, 0.130032270906433, 0.17388236228256457, 0.09936265331963379, 0.11326037692807375, 0.12369290099389131, 0.251687370360859, 0.13977848744440463, 0.11384185298436111, 0.10849075181589973, 0.2739118261923713, 0.0804926743430476, 0.11317809142412678, 0.1348606473015201, 0.12365741580123864, 0.1321473170913035, 0.16554271381708885, 0.16246443464150354, 0.18091958466797106, 0.14596086295862354, 0.24690791634061646, 0.18929942210595455, 0.20229639485478404, 0.08619866574243193, 0.18579015718592753, 0.21513716227585272, 0.1435780843659755, 0.11002658956473875, 0.14107990228841383, 0.15355657876258896, 0.1374114749412383, 0.17406896597916083, 0.18212700052367103, 0.18319917121721854, 0.1652776473952878, 0.23064829769634435, 0.18448983018677081, 0.1951336872673804, 0.2383345038059258, 0.13542913050661165, 0.19099626089296035, 0.28973282885647594, 0.13085630572130605, 0.1959075126796961, 0.18631911025412623, 0.16180800454270455, 0.21670270891439533, 0.20646981203988676, 0.16501429701043716, 0.1756278170092452, 0.10925850981185514, 0.09109241242009787, 0.15173736509055863, 0.13043367033523898, 0.10666919391482108, 0.17024908304935502, 0.1301228837861169, 0.23168236317653812, 0.19743607259325444, 0.2961468233937218, 0.10757212046413653, 0.11864461906013951, 0.10271024304412066, 0.12254504847430414, 0.09888878197319086, 0.20414208452547752, 0.23666043315202961, 0.12242124866574042, 0.08224633387139729, 0.1646014522280424, 0.13009269992190023, 0.10300488045979893, 0.14292245099861778, 0.12947592253406204, 0.16189892385755816, 0.20299750320132703, 0.18213591778710966, 0.13829285909812297, 0.2032837442933552, 0.14253669508522557, 0.09786998462532798, 0.16443533372254143, 0.10518226321906814, 0.15719172725033376, 0.141913942211578, 0.10025395065425866, 0.12396950469983202, 0.15055602686780115, 0.13905157725657188, 0.17047072760760787, 0.11014642869873394, 0.09795981609532911, 0.22145361849857917, 0.24821519941812564, 0.06891424362097057, 0.12781253880670956, 0.1380233493663611, 0.127527262985466, 0.15304622630919182, 0.24031372260182138, 0.15135102695034397, 0.18059897687165968, 0.19836444858341448, 0.16848234640013787, 0.19378143482871596, 0.11258885489716647, 0.15625703869567764, 0.13823488156401342, 0.17893765392082353, 0.10065289094082772, 0.1795999522531225, 0.17385377188123044, 0.12342181312100542, 0.14557228784166998, 0.08248440335474669, 0.2036537187955072, 0.22375140729690754, 0.11748787225975145, 0.11787558169735056, 0.12504745935720782, 0.14273295148966775, 0.06911800768707069, 0.2610209566210547, 0.15158595547320383, 0.11366800465170415, 0.18362819577657408, 0.15833420949357171, 0.1373809080330595], [0.06685626332557972, 0.04648520017883951, 0.04082485229798383, 0.05654509524784743, 0.09378075284222442, 0.03850523765469271, 0.027988656506603284, 0.07715657593742495, 0.04641830538129134, 0.01564081782670391, 0.05204198829409096, 0.019257948884079536, 0.03894388810881684, 0.014894121503006789, 0.05934229293357461, 0.00562937063683245, 0.008501396439368687, 0.05792156372579837, 0.07798440288752317, 0.03587137374486174, 0.037933276410424904, 0.09288233088990373, 0.03759907055345755, 0.030621422995482723, 0.052738917631007014, 0.01923509839651806, 0.03274912878330196, 0.040243280480705926, 0.0227543531030777, 0.05588782628277137, 0.030245907762418353, 0.0332528545761541, 0.016616954610893325, 0.04548342530465415, 0.07902183149370455, 0.06363137407348522, 0.013136389259729656, 0.0045062455202212505, 0.06635919483678956, 0.13880796129665068, 0.03445222650864913, 0.057097934937525185, 0.03927216061481065, 0.019705430416750814, 0.004821247946951659, 0.057966134721233006, 0.07449317933811296, 0.06057244627886723, 0.04805576086284653, 0.027399682364757025, 0.05564943121205415, 0.036112419479796966, 0.03965652607862027, 0.05693483481844587, 0.08945821664266049, 0.040016510794239665, 0.03944106001947676, 0.0480889899265622, 0.10119365708481881, 0.060593969519099886, 0.09300751731761041, 0.09947233412775303, 0.03303773708701615, 0.06603962125917597, 0.05995991301812953, 0.04274570285492847, 0.04854247950377965, 0.03875778619981101, 0.042865752663102843, 0.019529959892914183, 0.037715140534865285, 0.034405736462964166, 0.10170711985518856, 0.012513976337598457, 0.06400752324430693, 0.07173518620191083, 0.013857783614507607, 0.045276972269939805, 0.03698828780362683, 0.05206927634595383, 0.10046621063543905, 0.018436616444359386, 0.04718514407173761, 0.012370100237369057, 0.02616669257892476, 0.0904676983613641, 0.07023327082635895, 0.05193636392153079, 0.02101118897929067, 0.05674181130504417, 0.08347594329426367, 0.0197866280758453, 0.010190240141274709, 0.004509621573942564, 0.022708820667298093, 0.007873402087904153, 0.010445236337311085, 0.07523334284703578, 0.009931356049022608, 0.045053033278353756, 0.009011833162437524, 0.08310870372600133, 0.06233490432702726, 0.06210643009492948, 0.026949553998307358, 0.10122030162282529, 0.019257701820723953, 0.021898282406431054, 0.0037720680308167736, 0.024678082235397834, 0.04375296291865168, 0.03517815993437844, 0.05933433711048096, 0.04471808814653947, 0.02427044110522876, 0.04176151352904497, 0.006074959932330756, 0.081447311827252, 0.028307801074979287, 0.028734975531997702, 0.03469001253946655, 0.026072140092090256, 0.04419464325051635, 0.05440227837572175, 0.03486870254780497, 0.01829558540315878, 0.02789116415735935, 0.047607794779563145, 0.03175223388919427, 0.07304682831970916, 0.014068529614427639, 0.02537029630113994, 0.014464511843999068, 0.046161895753034664, 0.09274095702435702, 0.04855472541924927, 0.07172793901014714, 0.027262401323945775, 0.01420664473346645, 0.07686372350661025, 0.014893396592308438, 0.023105129441847245, 0.05454932895278739, 0.027184614671334147, 0.028266166111514456, 0.056612721659363284, 0.03641324688590342, 0.06773252235425097, 0.05299800473655905, 0.024390881618244514, 0.07420465530407044, 0.06329241081050808, 0.031179889600964326, 0.041105638843991106, 0.12330822526447235, 0.03412967284901008, 0.06612635007308376, 0.013869099690759135, 0.01215907748818638, 0.02462170199461041, 0.06611302780408053, 0.03473785089989824, 0.04023995948955417, 0.03874056454327318, 0.03289398068802492, 0.0325086308012326, 0.029519388279426965, 0.04939217060323685, 0.023938931877754872, 0.006830870857342117, 0.042826065478185495, 0.04094613933815591, 0.0031055471176401747, 0.06900782892180067, 0.007418459337655336, 0.006221639914363022, 0.046207680997829285, 0.013012577002237161, 0.05718830266907331, 0.0977275075931703, 0.07296311023134379, 0.05492632082032581, 0.052587764653106855, 0.017651460591643568, 0.05620106431325117, 0.027937774861892386, 0.01739760778183418, 0.03514190099292225, 0.035797473073246024, 0.05478535298137896, 0.020054848864674568, 0.0475377896650424, 0.02688040881748161, 0.0667790723063292, 0.021283550473350673, 0.02091497216644066, 0.04381737942176481, 0.04982650415190766, 0.05128400558004937, 0.03611263398441576, 0.03763303506158052, 0.03186275164837078, 0.03333476852745779, 0.03242975438854868, 0.016951551172702063, 0.029882362653170864, 0.023043583853230364, 0.01931444595327541, 0.023093021422203992, 0.031768026791753314, 0.010412976374819635, 0.04791318806969831, 0.04011432873085141, 0.017059330167549274, 0.03288050520143682, 0.062490971758961684, 0.019082533901617415, 0.06539447563550164, 0.11403476924545343, 0.022540823331162817, 0.017730474900153857, 0.07084715240184339, 0.11600045126772697, 0.06609312483980771, 0.0161389502200989, 0.04631875991641034, 0.0067377950049816605, 0.05547225039692656, 0.04115255023803442, 0.05175680823383793, 0.03947961339426618, 0.002268870176199163, 0.02685205398818418, 0.01928030716014966, 0.01768003950165885, 0.016343961094295787, 0.033001428349844875, 0.021885479161996516, 0.029223710899391485, 0.05546759258234694, 0.055572508323577144, 0.042024488530812726, 0.05934309349545549, 0.04947662413600953, 0.0622919574379921, 0.07333889934084109, 0.04040380271392004, 0.07549426473316646, 0.014880923723291247, 0.033150597160021146, 0.054395165249344804, 0.01654442715188188, 0.0620032035775723, 0.04630727242798575, 0.02926606407028533, 0.07146081181182977, 0.03177306381985545, 0.032711318513799104, 0.015064899738307203, 0.02289717104436169, 0.10266747235530808, 0.0740281256636785, 0.045954473617096106, 0.030523595482771917, 0.027045102399443428, 0.05605939933429322, 0.05930830927325353, 0.030294031490601843, 0.04097886661428117, 0.036799159847320094, 0.06835203467597885, 0.07665283482281432, 0.05079097820505981, 0.06689469029586162, 0.10685870874552958, 0.03834073942515158, 0.01682982746241314, 0.022807100171884222, 0.05218586726715008, 0.10832585139019836, 0.038305166132387616, 0.06713164129084156, 0.03706192800534829, 0.032847053972223116, 0.028073981464389833, 0.01372952517422457, 0.01567964890836588, 0.015430501793631384, 0.056942319497466094, 0.015502657699999551, 0.03526668522446867, 0.06553973356682448, 0.03223683429701674, 0.033092746030419104, 0.036887485954550006, 0.030278056642160784, 0.023342869507389206, 0.02912135389182837, 0.07523608544180471, 0.07232519647767467, 0.0540120370175329, 0.04025189130897484, 0.05025088238800245, 0.0052897494958503355, 0.031157318735495213, 0.07350580691690407, 0.022844692106328668, 0.09038761919063908, 0.03733201230305337, 0.059139520951336434, 0.05078681068675173, 0.0359344917289432, 0.07931138208556561, 0.0211128507620625, 0.02880767727601192, 0.026604751230127392, 0.0010792036200948662, 0.027222961202384006, 0.06923967011032567, 0.06036971643146488, 0.049022805140984636, 0.03700974975682555, 0.027470382704069058, 0.05197354216849612, 0.03180123861849068, 0.035084371620248404, 0.06436937338402195, 0.039734866229757186, 0.08690341300661526, 0.033262357896854805, 0.03007027444489781, 0.02425180410125083, 0.065397042030048, 0.03908482913468634, 0.04019697429612279, 0.023160525259651968, 0.04510538389665946, 0.05677287233993412, 0.044565717088839704, 0.024517295701849847, 0.052583888248209996, 0.028882064413459554, 0.01323276503582395, 0.023719618142011668, 0.05687222245239443, 0.013009651503976316, 0.07136640679692069, 0.011054936030338849, 0.021219666401344924, 0.03637147211139241, 0.030263468412862673, 0.029490340140558062, 0.23293589752527977, 0.06130223312685567, 0.24804491339431656, 0.16168985846302203, 0.2987141066020535, 0.1800165968316217, 0.09520373051805843, 0.16543581390813475, 0.2280905752653076, 0.1118092378601432, 0.21896187155958147, 0.1346151008000297, 0.12281713992237084, 0.13708728185344127, 0.1372460152713522, 0.10346018949583655, 0.16626534923430414, 0.13555912030560358, 0.1699570809761363, 0.12596233687814207, 0.219298827672197, 0.23132020277121376, 0.11186422765134804, 0.1569459662442246, 0.09790560005292778, 0.08898049953483766, 0.24402935628689107, 0.1433842947646495, 0.19222857460619944, 0.12818841984675777, 0.0881966766751101, 0.09005954203706595, 0.19817859565298404, 0.10977221006948142, 0.256713320831618, 0.2216046450719718, 0.1693672085961988, 0.10515572593337107, 0.19431665449613528, 0.25206279940903187, 0.11569681997981765, 0.13371252665115943, 0.17624827161911996, 0.10483224530734363, 0.08948291531733929, 0.2750361674735623, 0.1789170461556604, 0.1252139149413955, 0.10036294964412529, 0.10470289902220811, 0.22413869538614828, 0.20692669155616916, 0.17968645890153226, 0.18670463634114112, 0.1772271328034901, 0.10030769938302618, 0.12729623385014074, 0.16433494556094372, 0.2933765268854557, 0.1431669556205311, 0.12341971404009289, 0.1926521752630511, 0.23710822686553004, 0.1791631135969393, 0.11715215720957327, 0.1260165912249396, 0.11044344864785673, 0.07334140444835348, 0.18960133735691348, 0.14543932562153186, 0.12978324636576638, 0.11681369956462614, 0.13463719477576597, 0.12519457888218666, 0.1491186314172322, 0.12485739294319384, 0.14367833463174684, 0.15888087451457977, 0.17310453789128413, 0.1379745955308599, 0.20884108399191212, 0.1234094791054245, 0.08656524647507938, 0.14207250709014554, 0.2654032246960748, 0.18476733787646218, 0.14212617921012063, 0.15646080276177776, 0.09658985170385531, 0.1558464308900218, 0.17710083554829323, 0.07601439246847745, 0.12477729845071032, 0.1611560330756249, 0.11508278518674836, 0.15516827453769025, 0.1325491302075886, 0.25051380026965375, 0.2893248104280041, 0.14139353868461427, 0.1178361434910086, 0.1602607061185183, 0.18213936518276894, 0.21708173857581234, 0.09360682023989578, 0.3177445886596557, 0.1167519452170499, 0.11526995578840857, 0.08964435302562292, 0.10509230151411988, 0.17248605978825401, 0.13246582580670235, 0.11267799688803573, 0.08089836386422958, 0.12868630038874765, 0.12471382806618368, 0.14214110260288562, 0.14048120457558863, 0.18310504965484145, 0.16766004294397371, 0.10663155601510119, 0.09130146249287552, 0.1649115033327572, 0.18303751134343688, 0.16333011399594047, 0.17612948202558104, 0.17477031947383959, 0.20857019530188656, 0.21502215715665973, 0.16440357171720074, 0.11649144467927756, 0.21698640659451487, 0.07271286761087757, 0.10974426318200366, 0.16316998629800736, 0.1247117902723051, 0.15586181393554135, 0.14258086771493958, 0.14904255888635112, 0.27381802638692243, 0.12080308710855824, 0.15379329993119165, 0.10349462514803295, 0.09854912923108186, 0.1935749281678469, 0.14734006637046415, 0.162842974006649, 0.18099723533997614, 0.11027457988670758, 0.11662609995372834, 0.19181724667789476, 0.1414502445127695, 0.15769970483116566, 0.15426611407629906, 0.32021562058118086, 0.11199830069897637, 0.2149581888149823, 0.13810507562612334, 0.1459885646979655, 0.13648032571279234, 0.12491438222388107, 0.08503438829774819, 0.10002492866929501, 0.13944182244520034, 0.15156346313174696, 0.13921754254448798, 0.16528282614965595, 0.14347939691956968, 0.08675135987540407, 0.0594407965188786, 0.12295949438046064, 0.09954840665863407, 0.10592618055881993, 0.12210352136002434, 0.1247157815903906, 0.09470709103850589], [0.043547938637916124, 0.014092646062283987, 0.04865458498017923, 0.07208882004863794, 0.08593851760510476, 0.044121527819023024, 0.0832778636005617, 0.02957932316818305, 0.019390775123611093, 0.08359074923059634, 0.01724069190752362, 0.016763083967230013, 0.04673619356547152, 0.036013034893380064, 0.019176766546743534, 0.028695056605483257, 0.01557835580540761, 0.01841417389861759, 0.09282063016848219, 0.07003791840566743, 0.018070365129519376, 0.0730399641719076, 0.054512372871320096, 0.06710511166602373, 0.012771097470014807, 0.024017331400705923, 0.03158659227342615, 0.02133958788979198, 0.014023049847192824, 0.07224570719465133, 0.0588997277701574, 0.022762473635075074, 0.02479757088416767, 0.011509826590847826, 0.039308982630891186, 0.050774105118527535, 0.06675079600104401, 0.0669858930632472, 0.08042513603164304, 0.022956998680808374, 0.0795143724028622, 0.04841892484335169, 0.06000690102096527, 0.0638435421241147, 0.124786154427115, 0.043462182755672166, 0.06326172515870103, 0.048243471556493354, 0.0318753193207686, 0.06139433604755229, 0.014110254593223575, 0.025778356864447557, 0.03309410200604508, 0.05759838570450103, 0.026438378000391588, 0.058798370507335475, 0.04963872067990804, 0.013953522580014843, 0.007569595557382151, 0.05549828206459361, 0.03344785076596084, 0.01175989684153108, 0.04284488059760582, 0.0875658875391368, 0.03915362766072635, 0.0030159078878275454, 0.039831630795473055, 0.04839739394223979, 0.0417947540840795, 0.05438174338891141, 0.019792762524898977, 0.014295612439332951, 0.02540621433346983, 0.08666070103044472, 0.017998358610296444, 0.12095984401962451, 0.014171813588379132, 0.03278444543661129, 0.04931217187174386, 0.009891652584736867, 0.04412492924940683, 0.02390784594500738, 0.015550877189173576, 0.02248951459243413, 0.007206849573600678, 0.040334732226666906, 0.00512360992293144, 0.022690888464210496, 0.06150571757086343, 0.02532401692963416, 0.010109478194687155, 0.045994248902124744, 0.031728416215628386, 0.020301529176292882, 0.01290785278298802, 0.03694264045465858, 0.02663345845986999, 0.023162697118917303, 0.01611548494697819, 0.004154293236487936, 0.04287748913010282, 0.021547088549742778, 0.018858690671021902, 0.09882198676707284, 0.009853899771828326, 0.051858376170839035, 0.013047895570766303, 0.06811070165807201, 0.07809767664800729, 0.050401058603799155, 0.025487839086582104, 0.0240247720296705, 0.050567820623156526, 0.07619638431576953, 0.11217907446646884, 0.03606046339677226, 0.05877035467194454, 0.03335680504659972, 0.055191904351475744, 0.027080535881161213, 0.054242070238556594, 0.08508586174538059, 0.008386037004510722, 0.03932261899594338, 0.05768009281206516, 0.025603981846342647, 0.037193476793266116, 0.07834586615283644, 0.02359785804254634, 0.03159085555272478, 0.03997362136179882, 0.006180441621015029, 0.05564880301995624, 0.030788885985290816, 0.03578845238793762, 0.01727865156417172, 0.03642106481317071, 0.029218486179747892, 0.03837314111390903, 0.04094535409803352, 0.029168673227691365, 0.019609098690712166, 0.005868549032452246, 0.04956152583021791, 0.02372910422573407, 0.07545482652682452, 0.036541256347611066, 0.05102211459269447, 0.08058134135940383, 0.010584890335467795, 0.01728752669277451, 0.03975771863253848, 0.009649112020739386, 0.06257021589384926, 0.0526481936685741, 0.021622831662816387, 0.030884819345608838, 0.02745044718105947, 0.01667050415680053, 0.03654149383486759, 0.06865113838425568, 0.03260666324246315, 0.10944067019849055, 0.061171718557635625, 0.05192903246009543, 0.07525586583200963, 0.04691686774153383, 0.0366480911390916, 0.010734263116553908, 0.03549373070258768, 0.04149642029416658, 0.019550381881755688, 0.10305457658344701, 0.024831259600637902, 0.03117007409943448, 0.0184524936165901, 0.08901861240907062, 0.06522209053078006, 0.05172687334819667, 0.049956241141884565, 0.06187800182810715, 0.031105665257200602, 0.03956064251401732, 0.017423101272734425, 0.050236954909539035, 0.05603378901498453, 0.07337878953905837, 0.030793607002124194, 0.03981976026308633, 0.035286461784233975, 0.012319831462997583, 0.022433712748029543, 0.019781824704560063, 0.017994750336173083, 0.06363680563686837, 0.01604249304716265, 0.0753307049613326, 0.007593583685511183, 0.024821892260543765, 0.051083248409052054, 0.023216078125481165, 0.049616301116803964, 0.06415611365810037, 0.08264961021561777, 0.04398929338241297, 0.01020435243844986, 0.06201324699025962, 0.009375589903474096, 0.043740912355602755, 0.03902146217202948, 0.03396199535458319, 0.0696238938478693, 0.020920934245711374, 0.048211460572577296, 0.12231012761232354, 0.048279148271127094, 0.030700113631845004, 0.1189872059189985, 0.05271347202060204, 0.02575907826183304, 0.04604475324853294, 0.046049085475744746, 0.05293931474067992, 0.019241412876233942, 0.024766182346690088, 0.007981633553431641, 0.039096963967406945, 0.03445222267820951, 0.018271384685630762, 0.013853591198341982, 0.017824209588129195, 0.019898371575700662, 0.04056625548870333, 0.03757772351344747, 0.06792595955513178, 0.01363101871609087, 0.020234444771983454, 0.07545378464724749, 0.09436671817374807, 0.09905148372654954, 0.06070717050123119, 0.031418131454096686, 0.006311526925738661, 0.09507346492741378, 0.11424981012579896, 0.01627137617869002, 0.031587463698440024, 0.06147323544287394, 0.0437642588850952, 0.04858463349181318, 0.01737102836130127, 0.012687112208485845, 0.012967895881663407, 0.06834936869000235, 0.009896561293111695, 0.03993008841550158, 0.03495137109571407, 0.02656241721143165, 0.06636585214085157, 0.041915558488859285, 0.05689741142334477, 0.07317611331781072, 0.08133150997661776, 0.0506679329931015, 0.02998652571301547, 0.035628558346821416, 0.043827798217535026, 0.05065076113227875, 0.06560308903816246, 0.030097999166877522, 0.07396065630018711, 0.04845221136366168, 0.0497153333027757, 0.030579355192340674, 0.01243579802253554, 0.00678003422029677, 0.10498955380171539, 0.01794131953389414, 0.036311610000989133, 0.053884521682536414, 0.0641152045629438, 0.03236174493307068, 0.009912265137949539, 0.047685820834651116, 0.05513105398765015, 0.07029009922858208, 0.0421973179665304, 0.04639939450088047, 0.03072253127972926, 0.007445064613655691, 0.01725377477405052, 0.005111909366302914, 0.04441730670570847, 0.05272776722126911, 0.08123433938430202, 0.012651328241542704, 0.02234614123740504, 0.05846679616238802, 0.02305881942682449, 0.03508111957700984, 0.027396732926248547, 0.020923044817942767, 0.05948953503262132, 0.05567746619964319, 0.02530872581466552, 0.03384417103182885, 0.028938572973974293, 0.0058246871471525205, 0.046606977515283136, 0.012147622558498576, 0.012038698262204568, 0.06942513999679396, 0.009274583125877525, 0.1196004746241435, 0.015199326143990603, 0.039464004352808967, 0.017164199943504026, 0.021742929351486025, 0.06326590799876759, 0.05503739207802762, 0.015493592007025598, 0.02494758622150027, 0.07083239754842174, 0.01482274030305205, 0.0646887247961375, 0.02020573179658142, 0.019659750509045778, 0.034142148590856986, 0.02233892851959794, 0.021020117734048157, 0.03682299284264445, 0.02797732606620318, 0.03339456168994789, 0.08712664336687134, 0.0023946802473566947, 0.03873989804677906, 0.0564759711344396, 0.06974282899811383, 0.05761785582909661, 0.04312685841033536, 0.06737589310373991, 0.07229260709737578, 0.011698369447502398, 0.03552787524137286, 0.05837835131152984, 0.01927662227723387, 0.06173195482622232, 0.018817394701463562, 0.06495477947136087, 0.005788718840302599, 0.051244950417669556, 0.042815052964273966, 0.12981882348896998, 0.12332567674738747, 0.1611409411435166, 0.21021901569779844, 0.18056081037127203, 0.22719555474337072, 0.17350635100756923, 0.13649331856398814, 0.13450414062507693, 0.19667435137014236, 0.11577414889489451, 0.12609774291875864, 0.17264624877322107, 0.1852468782735448, 0.14760329418124693, 0.07991703587674326, 0.2091415896410904, 0.1414442690269601, 0.18892901859456496, 0.15740863738521454, 0.12155402181369644, 0.10378435960099583, 0.16032016986320097, 0.1700615140819742, 0.14787125641540175, 0.10255143301741731, 0.17510810296141333, 0.18568589261943297, 0.10023819988653546, 0.11955547461947126, 0.26544618690686844, 0.1021963665862718, 0.1927869454506905, 0.08656161521831829, 0.09645791604153572, 0.11728858214712913, 0.180059926764619, 0.1449605819558905, 0.23282600987342097, 0.11213340030442323, 0.13953361510028764, 0.17283023244911627, 0.13509828777563188, 0.12164596768636858, 0.14264843666986113, 0.1107927464369324, 0.18413778214204699, 0.09858994639568752, 0.0895287886622452, 0.15395555735355423, 0.19430197625150605, 0.09558543382633118, 0.23902169999576386, 0.09711269139041824, 0.11600710857178896, 0.0868068476237597, 0.11282996574957525, 0.18722479471996908, 0.17578866482982713, 0.1615411454751607, 0.12507807223066209, 0.14212519861757755, 0.10719593298891861, 0.20912216165133063, 0.1254927173196789, 0.09536749713363186, 0.09994756144982192, 0.15954988377709545, 0.24655554653896442, 0.08469778458557783, 0.23184946227458217, 0.19991740073648193, 0.13717896725621917, 0.18186145912735693, 0.14102826796231732, 0.3424595656894869, 0.08511648227971408, 0.1655954666315548, 0.15037573573570098, 0.1387267100114015, 0.1759450233751728, 0.17081942018722335, 0.08027428565847297, 0.17952737308317618, 0.11756944530192884, 0.11819626610245436, 0.0983845888667049, 0.13112589206186034, 0.16481306103448715, 0.11297479467166048, 0.07820884366669963, 0.13805927889000985, 0.15696537891222587, 0.09038836229592563, 0.15401132855444186, 0.16200767769928903, 0.15679038910856172, 0.08178356313897718, 0.05692304855573082, 0.06536947818653238, 0.13926925347937694, 0.12604181850028615, 0.07291399633451816, 0.24429797735666078, 0.145922573884168, 0.1743771018640649, 0.08961228458511253, 0.24743121567993398, 0.2077561655953046, 0.14373795159401434, 0.16918529335769916, 0.1339206880619449, 0.15665967918692097, 0.15839103789579484, 0.18742871200365407, 0.2010938206747655, 0.1966166189841686, 0.1180911281957261, 0.19909969380786344, 0.118955007243541, 0.13955517281447688, 0.24808954567678515, 0.09637981337765533, 0.1460264860502174, 0.15502294765845423, 0.18622212352291231, 0.1550582030247296, 0.19031667961708962, 0.14937065902256197, 0.1208093077425034, 0.20681317264754928, 0.17069198912189854, 0.13814158737659454, 0.1638457218124982, 0.10879711803769875, 0.17732479369207738, 0.22721990101760436, 0.18552280782211214, 0.08464482492737233, 0.08905320127885188, 0.08234269241051329, 0.22478162701572144, 0.1387446058253127, 0.15840101236056897, 0.13879084689242227, 0.12953193888308542, 0.1844578996420868, 0.21018132417192384, 0.18772751693764042, 0.08934930192246553, 0.13470405892979714, 0.1234753933104296, 0.10989074685400534, 0.17582153000177878, 0.11670572713257805, 0.07640617749383373, 0.18757682744293444, 0.1466536975555843, 0.062485815987231276, 0.253939239849006, 0.17686022265303522, 0.08155711520943912, 0.1751520151212331, 0.1923224203769238, 0.21547178948117843, 0.13506916111275075, 0.14601563824520958, 0.09187048195951408, 0.13871193983622138, 0.10301808015473428, 0.1726597319206884, 0.12818080493279044, 0.2528418955062666, 0.1592243117310347, 0.18912564272121077, 0.10280951271734892], [0.03973162567783748, 0.08442136474073896, 0.02472341165787751, 0.029541733148958416, 0.03367094323039055, 0.061324530115891854, 0.06382061311254097, 0.0449161448576037, 0.12061506614930208, 0.02800068983267392, 0.10649758255890301, 0.0360381510859776, 0.035024586118637555, 0.06079858777323558, 0.08183626998816768, 0.07036841639708127, 0.03456947626546025, 0.01785131186367043, 0.013831751946840557, 0.05896153191344873, 0.022019148098244783, 0.034913905565777135, 0.04057609205765109, 0.043717159799510436, 0.039970491892628135, 0.010001829434787075, 0.050762211603503075, 0.019092155965946375, 0.03416037765301524, 0.09211339311854494, 0.043283649795358224, 0.016333578687701977, 0.07476451235913462, 0.025494756860538356, 0.028558124134677555, 0.037062456606016043, 0.03379358624618861, 0.04679136338733858, 0.051178227989904346, 0.0426186548335658, 0.03232630187525384, 0.050129698769700144, 0.04540788520488047, 0.05858309597017304, 0.03001083942851232, 0.10939225344167602, 0.0473227909195327, 0.10901166862177272, 0.052404531743377454, 0.04903505105645426, 0.011942449848227685, 0.009211613571331387, 0.028341081849629843, 0.013054835369750379, 0.06568165135479744, 0.023751102440479784, 0.02030791068870214, 0.016846457316029458, 0.12198266332908986, 0.026592164405531464, 0.037431538615736275, 0.03377737199527121, 0.05682732970003159, 0.04009106647103064, 0.0344999882602884, 0.027045529493461215, 0.07757524298804422, 0.07370353421016086, 0.025216073225883227, 0.03786497201109606, 0.01320095610759792, 0.05138190012545355, 0.046654697132086566, 0.018245906516489004, 0.06645047421296758, 0.0642970240404529, 0.14564952482619595, 0.02673151388373827, 0.054502900194136374, 0.034268583741880236, 0.03420952219335783, 0.032285423423614235, 0.031214118409421177, 0.06203440250828863, 0.05339075503269992, 0.0668954563837859, 0.02265284070745111, 0.0581029771767076, 0.03781202001376979, 0.05498886806890369, 0.0256106314895254, 0.007844107843289573, 0.04038000036211264, 0.02493832804893534, 0.061233557174883546, 0.09151796660115642, 0.04890952755006091, 0.058755634292479486, 0.07408744385165554, 0.07577868253593484, 0.041842734170777184, 0.03613774634657368, 0.04235653018939399, 0.019958580340889674, 0.05351010387042358, 0.01699753751557681, 0.08784969247156575, 0.021457145996992628, 0.07101940727161785, 0.08802432987478473, 0.0350123516944868, 0.017369488524573467, 0.030644035995787675, 0.0519308365971571, 0.016226416393633813, 0.05175135368781705, 0.02477197397139765, 0.09409667984131845, 0.0424687467485426, 0.0291300930398246, 0.0619744063324986, 0.03099626790161335, 0.05508419621976153, 0.04922262768471434, 0.01894612237060022, 0.01262954453141579, 0.023979507724664385, 0.03737444208273965, 0.039820775329586, 0.027435962373631138, 0.00958155455713671, 0.019654089119285345, 0.06081069579287883, 0.03281506214050516, 0.024850298800776084, 0.07389776814248293, 0.02841304431879713, 0.022876400485514634, 0.055201438315693414, 0.055284041746128956, 0.06239063722351867, 0.007312423192835864, 0.05841603900696482, 0.07003236426821641, 0.01860097869329395, 0.005142559107738517, 0.059936754180178534, 0.07618831740992685, 0.02409608906976158, 0.023851103727675738, 0.014342312201587184, 0.02753282270033754, 0.0597257582440732, 0.04282773938030005, 0.0213265624798594, 0.04062837755848323, 0.013778776966876561, 0.02036306135837109, 0.0341660620254134, 0.014220610516326082, 0.024424650773946798, 0.010181485671519993, 0.057241224022882606, 0.07170145535060475, 0.027564791549417763, 0.03636655382691853, 0.014548248126952639, 0.018326650268488356, 0.04889964884627731, 0.02930826210837451, 0.028406745160839734, 0.00833589559225666, 0.035487556033917976, 0.06211624368123951, 0.03522953762102031, 0.03456470353769199, 0.04167321806533202, 0.03878546495651526, 0.025328452578715743, 0.008607421092869294, 0.0347151861886584, 0.029407041485331235, 0.0012067273341780228, 0.03568495390936732, 0.031186732681347962, 0.028857382975759047, 0.040623968722479004, 0.06638537972204148, 0.03189655144759004, 0.07629009219066751, 0.06693110245490266, 0.031784955419660095, 0.0025190685072072573, 0.02942615154860241, 0.02486294308196633, 0.02989516206716578, 0.01931614092280788, 0.031646818275593465, 0.011119464573810899, 0.08116892313644772, 0.03751348704099655, 0.005604790226976958, 0.027080334783081087, 0.08725785890654211, 0.012254671854597908, 0.030233520120682738, 0.03258783663172395, 0.11653327307994328, 0.039888106797251015, 0.02132236048759472, 0.04945721529844788, 0.03572149247291588, 0.03776860964154044, 0.10239083034497115, 0.014315022234504503, 0.044382384587680145, 0.062123544499157905, 0.0500433721519526, 0.06494462114548491, 0.0998413893243959, 0.03258426283155719, 0.035173743437494964, 0.03282654579849013, 0.08932901591423059, 0.009694100534092755, 0.012439922448397886, 0.04718291092543833, 0.016557847097095464, 0.044907572333731, 0.015656221939641383, 0.16136617099325504, 0.018982004013753707, 0.020623155869543552, 0.05519476568987293, 0.07170356209239653, 0.043076932460310004, 0.015071130905961318, 0.0439206097695616, 0.014894358990263316, 0.025814393640405713, 0.05050751035131755, 0.014560359977035513, 0.026277834699759563, 0.06835743559584503, 0.06147794688360826, 0.01554495054146936, 0.07034509668066617, 0.06996454250427984, 0.08860923034409363, 0.05011207491700208, 0.022131745786135717, 0.07024272435134457, 0.037741911477379264, 0.055490747589858315, 0.03261506339655288, 0.021519329353806474, 0.03171418038677545, 0.014638538292098432, 0.08646770049968074, 0.04861787404684771, 0.058071674824121504, 0.06916957306525401, 0.02164561128724487, 0.04367924993857742, 0.010479560906758473, 0.028061584246555166, 0.013814008392904316, 0.03342894371598959, 0.007187068704590803, 0.01574954677057723, 0.01092046844742952, 0.0923715724099067, 0.06820006581443934, 0.016053045908319616, 0.0726768997828326, 0.05947672604252735, 0.011681851634245006, 0.043482763707757964, 0.02570887652015494, 0.059237982401804584, 0.007703996107598106, 0.02869252468489351, 0.034633413963620706, 0.04372613451954338, 0.02496560652469916, 0.05618813657952894, 0.024095907123879563, 0.038224531547917474, 0.06676496862764321, 0.07946954859841256, 0.06799176650782747, 0.01837984358351077, 0.03459431283596543, 0.053782095727060115, 0.03253824392994566, 0.050445480212088556, 0.03677937562667555, 0.06840454234230904, 0.04650495375596708, 0.06780581398596687, 0.02170420743735327, 0.0275118223151132, 0.04705501254647971, 0.029148655350229917, 0.09865232893536169, 0.10273298819459255, 0.0290863340975897, 0.041199159027347644, 0.06963815074414015, 0.05054870672944573, 0.025365025616220893, 0.01643393812100253, 0.02363448853664581, 0.027153452129794226, 0.07844350405878599, 0.06527195519377148, 0.08407289432662149, 0.01064883473689758, 0.0754650614614929, 0.024434236449099356, 0.036487162879277626, 0.04737413413221798, 0.05542923072953859, 0.034250722401925636, 0.03576871413256853, 0.01885041309100005, 0.025274046929553155, 0.009976601201830613, 0.06562230252330342, 0.047796968701145345, 0.05034800318460311, 0.016605369446258393, 0.07356735442074076, 0.08218671690912978, 0.047462287869664936, 0.030080235503133268, 0.08207558053395442, 0.011374009735581857, 0.04701052582071674, 0.04149776860891331, 0.01150613691988251, 0.10813793002237236, 0.04218715964065444, 0.04685866804192624, 0.049357692816204606, 0.04429328090120708, 0.01612543068345516, 0.012832423765963365, 0.04078144575619409, 0.024929324600605235, 0.010786606073980371, 0.020187962387177735, 0.2103107317440933, 0.16408437352267005, 0.12052117441330226, 0.08234954889743559, 0.25258378516281804, 0.11855063539358879, 0.1972244637868097, 0.1509617623542586, 0.22022781653269646, 0.26544486923563865, 0.21674479778495528, 0.1014396325955468, 0.18483228681068267, 0.19226986674531815, 0.15432153287674152, 0.12485733931703914, 0.08237606320049494, 0.11358895969967689, 0.1137281119102432, 0.1701150789496399, 0.0789805853198613, 0.12094569437566305, 0.1115759487654413, 0.27180722944678803, 0.1597820237399109, 0.115037654947129, 0.10085853958322157, 0.08959572176418959, 0.1515381822302457, 0.14373569929551694, 0.11488389343984666, 0.2072561859724022, 0.14000406969458828, 0.16277463896380318, 0.0989279137443631, 0.1058208664518691, 0.1735858249688341, 0.19984187978890636, 0.2005494539175303, 0.20675942391878177, 0.1698348439869381, 0.2216681231173777, 0.14513433069711731, 0.19627287533254395, 0.18435892108226978, 0.20994840279942562, 0.19664156280698317, 0.25250352979187046, 0.12095418262986407, 0.14848185913457027, 0.09415269619034183, 0.08671664843155492, 0.1611317634101837, 0.09471118960890079, 0.3169013710031587, 0.12737073590077702, 0.12013113606841334, 0.18225435498020343, 0.19650834011695079, 0.13049443642939293, 0.09563634036889962, 0.20224272273480895, 0.16332280551714284, 0.10242587120662774, 0.13595082106128817, 0.05723542090685618, 0.15451662482753878, 0.18397465137945068, 0.09647136088460685, 0.12622392526076687, 0.3918042694849353, 0.1672341440233492, 0.2183595119464782, 0.08776337734513706, 0.16150976651378218, 0.2100343425427714, 0.2047129885684098, 0.15526884656038978, 0.1333394571537933, 0.15875825448141945, 0.1361417914590528, 0.0836455091954239, 0.12983734749497908, 0.12878011551595506, 0.11483459568191921, 0.12104121787894158, 0.09176968011043726, 0.11833106693361076, 0.12928358849979218, 0.1247221171375244, 0.16836044648962636, 0.09668529093746217, 0.14152078588883724, 0.0861439670646383, 0.14484553087142207, 0.19636615419820433, 0.22027425678266635, 0.11834866397323147, 0.2593994242770057, 0.1975502350157307, 0.11074609934322296, 0.11746796929547865, 0.08685549420695152, 0.13775886517138253, 0.13402539695943558, 0.11469963397229872, 0.13167421183278485, 0.14095708307239319, 0.1700429747542066, 0.16644749429918107, 0.12262737228264733, 0.11257511127980487, 0.20315242150137502, 0.15609968423603043, 0.13414444702286876, 0.19095153667994086, 0.16220434779121032, 0.21674230033832215, 0.12469817688989064, 0.12625148144340323, 0.13588377304615515, 0.18790049959094296, 0.11752402394889824, 0.23992088803600883, 0.1489909552037716, 0.11720410563171872, 0.0810654936057906, 0.12089998957010047, 0.09421209864799054, 0.2596932649612427, 0.15272814660303055, 0.1323712292698122, 0.19948407076299193, 0.17358542660311346, 0.23612866088026957, 0.12998674996197224, 0.13911444243163834, 0.16366711607383144, 0.2765592115540659, 0.11705652645398533, 0.19425712946441867, 0.0874714978459862, 0.17773684174303087, 0.22770233722704075, 0.14301202199872465, 0.09089460085716941, 0.09508628923926624, 0.17360813344918913, 0.12839992140089312, 0.07121721117366707, 0.12460586329501484, 0.11918200675638453, 0.13047715348582115, 0.1915787328635493, 0.12703606273017584, 0.26108616602516943, 0.15611727361477193, 0.13487874229829158, 0.10909870387085023, 0.13960717486277704, 0.20498265151775655, 0.07954324625672833, 0.14209688400789616, 0.2028062110466342, 0.15605161987966107, 0.23230123964528884, 0.12298650664067078, 0.1427830383181572, 0.14239810977972325, 0.1008109195578483, 0.18868069885478866, 0.16331935812148357, 0.11683577821860391, 0.11211248610409037, 0.07347815114283755, 0.18620600503298546], [0.06789567609948498, 0.03754023500087281, 0.023806940674060778, 0.022578344402474262, 0.020088183265479825, 0.08424503428320732, 0.026752148461978764, 0.019042747125269908, 0.058800852632210146, 0.004175770032640186, 0.02203473415706427, 0.05330350910944324, 0.0329286806405552, 0.032476026099175215, 0.05318099249815268, 0.03415950431278156, 0.03696194970079007, 0.027537765882668958, 0.03827713880567782, 0.03833238140589768, 0.0450837342519193, 0.011581185765774741, 0.03323893092813031, 0.02112686251019759, 0.049362097821769216, 0.037034812323268385, 0.030678561663315184, 0.05580605788817329, 0.04797416483803142, 0.03496391961591379, 0.06087335029376611, 0.007056183540337389, 0.04398793740678699, 0.04803090130970363, 0.022267843221103954, 0.01036469942905129, 0.07109663659526456, 0.027538545377131914, 0.09774325070001426, 0.010527621432688209, 0.11908415434581619, 0.030833928124798887, 0.0558166184102095, 0.04144953188276099, 0.018918376581202594, 0.07752619803913179, 0.026566261057591727, 0.015422249111467072, 0.052618408170078075, 0.03594704407958254, 0.06516422024897991, 0.018783219519161412, 0.03737449953933397, 0.024329617566939805, 0.044168469856583306, 0.07529974734831242, 0.045190492434607404, 0.0819289283226094, 0.07319198665960182, 0.049924272292804335, 0.05451642547643954, 0.03828348201369086, 0.017783298577752807, 0.05346277878890115, 0.043728486409470926, 0.03716309374618915, 0.04083250551634739, 0.056456198405113914, 0.04504380191886618, 0.04975440761735363, 0.044603335836361495, 0.0181991579161296, 0.06670333685413485, 0.004382600844462192, 0.026057768282630754, 0.047743951586345514, 0.03532951209513891, 0.01417523512857095, 0.01745127415614984, 0.04143167054280639, 0.011641738312919776, 0.038043351753825144, 0.0799411140202034, 0.060005571858416644, 0.08865590808132003, 0.00973699571219303, 0.014569663157265995, 0.04781945338172298, 0.043957573511908134, 0.03957867622375488, 0.09760108010302629, 0.08469202360438724, 0.03681377680491536, 0.01664092550204406, 0.031457558169119784, 0.017393200861049757, 0.04153693868448177, 0.05349427649390794, 0.06469532081316556, 0.055384230724866354, 0.027235618890112927, 0.019786808106507507, 0.06149560137982331, 0.018124360921642473, 0.07011129430705501, 0.025190294367231192, 0.0052757162014923755, 0.024353981078151735, 0.09863270176274162, 0.09366762463844593, 0.0708383500515934, 0.057613841528373386, 0.03652518382295966, 0.05649325407801136, 0.018318868730397477, 0.017287859941021572, 0.022657979242203218, 0.01651542306306862, 0.05104814626036152, 0.016165818838823228, 0.030488539299356843, 0.03629827241022741, 0.07260148608756643, 0.06205630879248343, 0.028625451771902944, 0.06306142381001865, 0.04718361189588905, 0.013063453858898533, 0.0819781801152614, 0.09236555095882186, 0.02169060937669729, 0.04690098290842387, 0.013405821425089193, 0.056984722464075016, 0.0318303250617558, 0.00998294536745356, 0.10190225011038204, 0.02439482697105456, 0.020200110626437014, 0.025581045173889688, 0.022022723813631365, 0.056766517640602206, 0.07790939521885688, 0.08285499072723812, 0.03611462581301889, 0.033496336470688545, 0.05557270750643746, 0.03189612626879206, 0.07630176737063354, 0.06380413456128971, 0.054843606307141246, 0.07674422145130173, 0.025185255423909234, 0.0875267098026891, 0.06536471311964336, 0.021480867909567974, 0.013893718883815794, 0.036675980569975036, 0.06805835487020594, 0.032629316462384116, 0.03349221874809554, 0.09264300502235852, 0.011746142690460528, 0.07486780399396535, 0.028004939705433867, 0.022729830628621484, 0.014783748342925984, 0.04099657856709054, 0.03964213511696266, 0.023777980635303165, 0.051723548526605295, 0.02759868519440774, 0.022636844791592132, 0.033255348192347635, 0.05378257070157317, 0.015476889375056473, 0.04646707836899065, 0.031778935883795066, 0.05305027874607233, 0.01755050552498189, 0.01987943962787188, 0.05742495872020241, 0.02352260522574427, 0.05255922021704817, 0.029945329334887288, 0.05307896873883663, 0.05766864745847641, 0.03941003728898303, 0.02683282709650455, 0.04807175677870551, 0.033523731774860815, 0.025957044957566167, 0.056063340856663646, 0.041249939165408575, 0.028635866737233538, 0.020466862441671473, 0.02593411020033302, 0.05708819029912834, 0.04077842353933281, 0.025608180008167704, 0.03132472235348917, 0.02129119028517556, 0.06606916927041546, 0.05785507112441044, 0.035860901322936824, 0.04034134739589307, 0.021779764774105242, 0.03639225607677814, 0.00744257147626711, 0.003720376008723472, 0.01994340988476911, 0.007554613750412941, 0.064037530908301, 0.08045064675952159, 0.03242187517424745, 0.013126217527315022, 0.09140394973538576, 0.04509464334396105, 0.06434837491401742, 0.06759852591541506, 0.10343418847168646, 0.04966631516694062, 0.06593400071705542, 0.03349408034175154, 0.06709367397331423, 0.04113394196235365, 0.026431082928132628, 0.05786426417950181, 0.05861772314435052, 0.002298158196349358, 0.04917535239890699, 0.0792636854513999, 0.03951335573689111, 0.0637595673962947, 0.014679953962894938, 0.020316042712018378, 0.024839703804783286, 0.06120372954155169, 0.05092812709570412, 0.035192746248456745, 0.11865002764088493, 0.0194141503814007, 0.04670498314343634, 0.0405730506885917, 0.022377047139490326, 0.04197681487928476, 0.018761602433158026, 0.02329749028919445, 0.032124788192431294, 0.062021417317972075, 0.01789041107610589, 0.02078607212752104, 0.09480739493043193, 0.0369536146641739, 0.023920917320215417, 0.01939360773371112, 0.029981752985247204, 0.029843602434641896, 0.030286872398949442, 0.012968054844907696, 0.04329563907137321, 0.053541957806315155, 0.01794107055531875, 0.014527497677913597, 0.04180672037745676, 0.05412640628374873, 0.04646538148423837, 0.013009739604087607, 0.039718912448734045, 0.05479693240035446, 0.028336230597849336, 0.014752938201831234, 0.07190401665866375, 0.028811567087447452, 0.02300310376731138, 0.018792265102327354, 0.05572096467198384, 0.025745876651677876, 0.0467899882595145, 0.016647358725388205, 0.029668271721851443, 0.01329162548626623, 0.00973516859249362, 0.05202517649459262, 0.03508726743260219, 0.010644875977548861, 0.09198112803841792, 0.06240469110648959, 0.050182853780326345, 0.03898716441565945, 0.02031356824802295, 0.02497229447227813, 0.019322166204332344, 0.02141520076791846, 0.05694264125439429, 0.03334251750681189, 0.007796200056139741, 0.13162605554586457, 0.00557901855039921, 0.03454729802005234, 0.021455661701639334, 0.07385021706502284, 0.06315023255264086, 0.018362537657301274, 0.05041501672577955, 0.05380725788493311, 0.08057284544432357, 0.05746208334101304, 0.04104601039040474, 0.02471569140682057, 0.030500145531409693, 0.03978994412107333, 0.07746782980018085, 0.025656554630146395, 0.024749646338844494, 0.045749863023839654, 0.022279121950569174, 0.06205687569754739, 0.10289303928373322, 0.008917236625547371, 0.06393683248109396, 0.02485427671232291, 0.011161016225213967, 0.04781094980576346, 0.030963310799110803, 0.050713557359432025, 0.043602311728341926, 0.023190873832772338, 0.05287727694057169, 0.06499416405154813, 0.051441425157170144, 0.040396364000175274, 0.012919665858780426, 0.02664459546306922, 0.009429458333479782, 0.05017921486268601, 0.039322132530111464, 0.05356536179240193, 0.06238982133987931, 0.07651852428792946, 0.04063798430105371, 0.05025471282762386, 0.04066976545859249, 0.022335921624495138, 0.07685137416927085, 0.06773289007645461, 0.018519447785952402, 0.06504958285199058, 0.06297495163556549, 0.010527508434719376, 0.012744817781382272, 0.010956406589567421, 0.18523681187821975, 0.12112233892924364, 0.1939381151309898, 0.13149903816801886, 0.16265986367098748, 0.16513049722679202, 0.15157090950637095, 0.16870533927313744, 0.1499319410011653, 0.13759581101757867, 0.1394046212155973, 0.19861498997817117, 0.1103748454742374, 0.18397468202296766, 0.16611703461216343, 0.13799650564549432, 0.14647299273600503, 0.15392416307041723, 0.19518601107260874, 0.1379448713193978, 0.05511265255570893, 0.22657142291145943, 0.1576605883817519, 0.12282243358992762, 0.16050256007621366, 0.0933949356417983, 0.24483687424611664, 0.13872252717133493, 0.1386277927386184, 0.14491325304392846, 0.14912613907889014, 0.15968018001125706, 0.15676999584801737, 0.15386846847832203, 0.11939216765665239, 0.06424223726254798, 0.20951637517540686, 0.1488438050352758, 0.2529359251380928, 0.10459571566072204, 0.2252402225689542, 0.13136086654999565, 0.2093970033550455, 0.13402368092248518, 0.1970486772517043, 0.17001196351503173, 0.13972869172932642, 0.09136683277545438, 0.16361258593538117, 0.11411579836520458, 0.13182430377890988, 0.1375868171453476, 0.16810441990533184, 0.08403181669212158, 0.145324197928271, 0.24951027105412177, 0.10040183626716176, 0.3380958062987174, 0.18904685823907777, 0.11533338786853899, 0.12630998757818054, 0.12987067231968527, 0.1278079805835601, 0.11635755549275106, 0.17588448710739615, 0.1761033277838461, 0.24949007697643774, 0.23610639836518998, 0.12189436403493728, 0.14933652214465604, 0.11221658979212085, 0.126397842541337, 0.17636614190714975, 0.1324368063961306, 0.19974426486559455, 0.1281484223962311, 0.20421175256131158, 0.14063059172082332, 0.08976235354859984, 0.12748965572926307, 0.1392933546054748, 0.13310287388101702, 0.1858857956023947, 0.12811166549762412, 0.20394700789643874, 0.13142241405383234, 0.12445741843792701, 0.12486294708064488, 0.09291678186385863, 0.2744164329863364, 0.216302182825823, 0.1991467928934482, 0.1203831023867092, 0.14380840103953116, 0.12755621344812457, 0.09225176391942848, 0.09781249738748997, 0.15563384149103396, 0.1775877610329659, 0.10626023319820244, 0.1866732727015211, 0.08143315452241129, 0.1841168832634726, 0.1117183568496858, 0.2189659777908556, 0.17116333237819134, 0.2367300705443467, 0.1582142554463879, 0.15272397908472246, 0.20048508721013225, 0.17936948236198197, 0.1380371849142736, 0.17229239276099592, 0.15628950550190865, 0.06895237947784125, 0.22479927768149685, 0.09575524487562719, 0.07155451202584852, 0.13647635737734456, 0.12724834569399396, 0.11661987165890395, 0.23903297681000926, 0.11011897210752773, 0.13288257763751093, 0.07014854916281278, 0.18723984068680197, 0.20481857080613414, 0.11203478180593061, 0.18274687290672334, 0.15957688071554707, 0.12263399128231312, 0.12784870581761484, 0.13651565768786017, 0.136064401256942, 0.08965114056463204, 0.1216030361190919, 0.28976782375285703, 0.10425367272428929, 0.09539936639128194, 0.13198245496999833, 0.11001074686646463, 0.15537393850184258, 0.3459334679909291, 0.19418142465574129, 0.14507037767719838, 0.0763982255011797, 0.13125004427086923, 0.158651722294669, 0.14678554128735297, 0.11284632938763789, 0.21267124782166175, 0.11756452701745496, 0.1763464994127712, 0.14721625124014195, 0.12434299554555647, 0.16811180499292191, 0.08811110465396797, 0.15698526655474018, 0.13912095417899473, 0.11651039003364502, 0.18433619891443562, 0.1723187002203157, 0.12276101632103806, 0.2481189940965945, 0.13905838011733948, 0.0657972080572959, 0.10664474038827805, 0.1290653913371986, 0.17140503311830182, 0.08729093858311254, 0.1771149162443415, 0.2507820536172198, 0.2095265641447998, 0.09191589565166543, 0.1455898465768945, 0.06843510158960858], [0.03651524383214213, 0.021024725752912705, 0.043903602617642576, 0.05289517275448288, 0.06568645472608267, 0.11342184527987435, 0.05231679169340961, 0.05890380335791458, 0.05099854206726436, 0.014311273191725055, 0.02921394902401634, 0.031350631447088335, 0.025888443699166663, 0.007979232825398927, 0.02758429231753032, 0.04132069504609512, 0.059651367276185946, 0.03511927841651825, 0.03963842342096952, 0.04055256166705682, 0.01768650528373978, 0.016582170388691368, 0.050925629649070964, 0.027799555363373894, 0.04106887811494451, 0.05520103611953317, 0.03495839612197972, 0.032737373164103876, 0.03536031649057423, 0.02444538685883726, 0.015105887357476018, 0.05645511822114068, 0.029359635964576757, 0.07055174123736159, 0.027056951864412235, 0.039405364152644916, 0.031048344643486124, 0.020443190324811206, 0.028474166643835848, 0.020329533520364956, 0.015074252714252761, 0.013113441095957834, 0.031915378058329225, 0.0527677110456411, 0.04433188024127195, 0.03204551724446637, 0.03849617866498809, 0.023847679314654202, 0.014004544993381829, 0.036002776976073944, 0.017513264075762803, 0.028175128053032586, 0.08050811101472186, 0.035703746046149926, 0.06514344394447343, 0.016512619181265755, 0.05064536787329182, 0.03173874691128731, 0.06584695014621943, 0.016080432594002738, 0.008858940207339343, 0.05159550842138068, 0.043968716260766795, 0.08935048169786892, 0.028081058201590375, 0.04542276263237, 0.07708935938294857, 0.009690679951510843, 0.05826043888866421, 0.02175434597677762, 0.0425187876117566, 0.06143673518372159, 0.0800971584695001, 0.03427534446781201, 0.020171922421263113, 0.014473492309691445, 0.06559106911863051, 0.030640582854468978, 0.009288856301516777, 0.042707597641574765, 0.06164579291737849, 0.06798750705896847, 0.00966264687914161, 0.05088341054356387, 0.05497696306256037, 0.0257506953447216, 0.05024206471599398, 0.10157086345697604, 0.03673182454921546, 0.03832166766627662, 0.049370452010583495, 0.0337513288362853, 0.040329944177140156, 0.024700808233671614, 0.02458053051433977, 0.0272801420050523, 0.06405323954118837, 0.03230864354859918, 0.039151509427615715, 0.05830893225427117, 0.032050102280693195, 0.04815514927970306, 0.047177961997447476, 0.038276479970062935, 0.05811572487976763, 0.05396269329433, 0.03118790479587211, 0.020221149316057563, 0.046064882208743406, 0.023079092028520765, 0.05832396672978517, 0.05813437145984462, 0.04186040398875072, 0.03766248348138986, 0.07626874132021781, 0.01581729862899069, 0.03736363258212805, 0.010915179567922269, 0.02752294399655394, 0.07352937944233418, 0.037888510062569575, 0.011459909259311615, 0.025493184465073773, 0.09858789328005045, 0.03370548613489636, 0.06649954980539699, 0.04172307889788382, 0.017045975339809255, 0.01306525033508097, 0.037231834815634836, 0.046615776035093495, 0.024238612067194718, 0.027137163185304212, 0.009036412135878158, 0.03608814981435576, 0.07004777795725292, 0.03464853270880638, 0.03591587196194357, 0.04853060897139292, 0.0035865244083857586, 0.02059355997780879, 0.05856296700996257, 0.05548212910071016, 0.06541675347233973, 0.08325946982949974, 0.06617537970023771, 0.0393462106735716, 0.08508488881371676, 0.032312757440752564, 0.06113340267010274, 0.04515027281858268, 0.05315488039125359, 0.04805335534676429, 0.04292261170884294, 0.01907910757337607, 0.05167999642810995, 0.030890605224656965, 0.05682776253970881, 0.02664948501924594, 0.053725642707919886, 0.05992117578223829, 0.009668163669806336, 0.0024307249235965673, 0.028307793414100047, 0.031208045247401443, 0.0420257717280859, 0.049336498993779385, 0.027331291780536695, 0.05356133600035983, 0.03398880460149339, 0.051379199665520466, 0.12137002281604276, 0.0485809141349408, 0.014116063454909431, 0.05833754563824304, 0.010682804033070082, 0.0474838838882504, 0.03187679404002284, 0.03531871025540656, 0.07774279407796361, 0.03476338844085413, 0.023353054646342512, 0.0517394065466379, 0.03780681827676393, 0.0452960325374959, 0.028621770719426776, 0.09142941449798885, 0.10067372853236814, 0.007279977932827728, 0.021610309955694025, 0.04474200541153551, 0.02499737236047945, 0.03351281885237944, 0.0065891212791264545, 0.027901600190107862, 0.05998061271384359, 0.04788821360336677, 0.05336987147588403, 0.04419042210605356, 0.017951677042630412, 0.040197407135800015, 0.04795469088299621, 0.034400703265301646, 0.07966053431793567, 0.06818213935701117, 0.03570692914147531, 0.05293296770222726, 0.03578791612639062, 0.017753798447008577, 0.03876029513776302, 0.04360914523262651, 0.032895152802549066, 0.03225260421693806, 0.033691183273350044, 0.019963879754105886, 0.08604197011839959, 0.06125776938373043, 0.027867708460337696, 0.025507638628985134, 0.010993105073970173, 0.01835091227305032, 0.02135011202265178, 0.014282841753635197, 0.04364609748365418, 0.062594439594015, 0.03774475749401796, 0.06578378619686251, 0.0309427643209816, 0.028059019767228636, 0.03607817534958163, 0.02014772170373509, 0.1152365313722722, 0.05933007766162196, 0.03901349102717735, 0.050735172530215596, 0.06346562712062752, 0.03515550671445747, 0.009790962776018968, 0.051505439464123025, 0.03716879727078542, 0.023769950118636893, 0.08437835656466984, 0.04625253544579591, 0.04171180208363841, 0.038402240963712815, 0.020420853116159, 0.03767010222579684, 0.04633182554595894, 0.017599226801746318, 0.04727825439805466, 0.029386422228849227, 0.014266397676340515, 0.03565665079100478, 0.07900570534289846, 0.06452953938635127, 0.06251909867710163, 0.06223100748273635, 0.1101009613804279, 0.08603815500053667, 0.021857128163138707, 0.05133536028405351, 0.03186799552021248, 0.03707823035637698, 0.05432068235090664, 0.012137616492597567, 0.06027248838255483, 0.05413848365987501, 0.11307443972797164, 0.0755758990623778, 0.05572070037164996, 0.06601523668054612, 0.053471948861354784, 0.03728718849860373, 0.037234098605451085, 0.17894137710813554, 0.08667239919304849, 0.02938585915422488, 0.0091293960576877, 0.016953876249552254, 0.03516209124016666, 0.04944626024113067, 0.007232626517032905, 0.009288108408180697, 0.029036388995366234, 0.04592353132583442, 0.005988335976707599, 0.07907650718886046, 0.014985831803642215, 0.04869776935647092, 0.07856006433646526, 0.060776562745412516, 0.0347863634177033, 0.08594394150760867, 0.01721262819163742, 0.04324204356019055, 0.012877953328913259, 0.034202071988294204, 0.022648571682493054, 0.03631412276938077, 0.06398706869672864, 0.027404901338741187, 0.033890235898715836, 0.09585062282220011, 0.06386700356679578, 0.07052493582089102, 0.053854839605910164, 0.027532920376547886, 0.034300656012830236, 0.04381849407969464, 0.03542163416803364, 0.03468843439834253, 0.027115377559957486, 0.030146609360892928, 0.0336557210633351, 0.06767223889548933, 0.0483359000645578, 0.028709098997135318, 0.036269808413400766, 0.003625598483561208, 0.02862205034151914, 0.04571559974142621, 0.029426819960316344, 0.004602875062940462, 0.08833394430938267, 0.03349514903440591, 0.05952638386177921, 0.030758054776778145, 0.04049768678904061, 0.06757737422782568, 0.020366238708037044, 0.021792093044026725, 0.03931814121202596, 0.03192934767162848, 0.03715929395008472, 0.08097039911174968, 0.03671074180953926, 0.040093816726678805, 0.0319772798778309, 0.017176394148038763, 0.014506097969358728, 0.056431798504725586, 0.0688101246111816, 0.0272186826013269, 0.007098643005930729, 0.02427969736257388, 0.03193770760610219, 0.030602458488917163, 0.13198092279414977, 0.056671266098536795, 0.0250813375122004, 0.05256185172906807, 0.03689385214520078, 0.09577161617456906, 0.15082947429149382, 0.17764630547213942, 0.13194932932815245, 0.11851964713705164, 0.25094392799562026, 0.1429008166756361, 0.11238990952411007, 0.06282471030229522, 0.14270066854453858, 0.1570696588004789, 0.25769475607141373, 0.1761514687490079, 0.12052931026705813, 0.16400952673246785, 0.18711728194067556, 0.12655994674611476, 0.11906864872622876, 0.15359269214733956, 0.12751864449631783, 0.15502112436919444, 0.15456118050121492, 0.14974143025615524, 0.1879996773336203, 0.17613210204628207, 0.21239763185862573, 0.14748507149277196, 0.20954013922281806, 0.14929005125116918, 0.09223966739110409, 0.17620137171639552, 0.1821707135006305, 0.20876162535240575, 0.24069632223296553, 0.2156990264812785, 0.1597314466151499, 0.15866103792382827, 0.1555602204415106, 0.13038050383329391, 0.289709355922476, 0.21487439411782452, 0.07989219164535885, 0.09760527826485135, 0.1442529925055081, 0.1368822001161114, 0.25564173236489296, 0.10426874933463913, 0.14513347267864213, 0.07445196380778667, 0.1133051471063687, 0.12914910942556398, 0.09659743597430569, 0.20008453047804295, 0.14361997405367513, 0.12373051591097348, 0.159247416942831, 0.13351326718205406, 0.11832869206104549, 0.1517212006353563, 0.1614787552746073, 0.19910949973329423, 0.10393242141412151, 0.11378280292715758, 0.18732936572163336, 0.06746567860846558, 0.14923607269602437, 0.16292108433140864, 0.17252128451101242, 0.16046646201322157, 0.14434791079932643, 0.1765905290601715, 0.1251366013480771, 0.1227381869008945, 0.14352842654672363, 0.1813304223000042, 0.11545573211004657, 0.31510480289017, 0.1695748184236788, 0.14982360084691357, 0.11740803057628295, 0.17316484433268348, 0.22009110048172936, 0.3046786526758825, 0.06697358969118326, 0.12311992851356346, 0.11917345721514956, 0.1486193565952201, 0.15847918397236258, 0.11885552306569393, 0.08831774921066339, 0.0885037936630749, 0.36506531880267207, 0.20190509246482005, 0.1134405914513815, 0.11832139890400634, 0.08556893380779414, 0.17932112689220137, 0.08544853542961421, 0.2362588345403633, 0.1917534162320437, 0.11697715208415063, 0.16094419444280286, 0.08594579544038543, 0.16068073680564282, 0.206886931592899, 0.12614959941035317, 0.13320965121590322, 0.11289387280421873, 0.2376617100690642, 0.12060538279793917, 0.2595599656624179, 0.12600895332833453, 0.10820128549371036, 0.13960578058275486, 0.1744008505897176, 0.1281659658096971, 0.14402368706801247, 0.12100592420826997, 0.11940354406232796, 0.2113155939526135, 0.14656858518719673, 0.16494775461333414, 0.0941863197893385, 0.1938809649718385, 0.15638520520540977, 0.1378243656889085, 0.2782559124452453, 0.13249948771009523, 0.12567530671555188, 0.1149948459539202, 0.09052972083971386, 0.22484121333447196, 0.09648537263274194, 0.19865710949224813, 0.06456466451767953, 0.14420589341992332, 0.16308038465438351, 0.16553539001653272, 0.09250431246454678, 0.10549605283285342, 0.08883030033640324, 0.11341726407408716, 0.11631109226014345, 0.12837613437084422, 0.1166607041452681, 0.10219160918026202, 0.08440308588286562, 0.38000669931211783, 0.11201645698278181, 0.1393184822893912, 0.13138991660408436, 0.1555989691687207, 0.12755635134395094, 0.10532280204877739, 0.11207477925645729, 0.11264392129716375, 0.1099997535047512, 0.09538716261064815, 0.1610950218333352, 0.08796324968458184, 0.13463311918800877, 0.15664972004390534, 0.07692013056047502, 0.15411718658381893, 0.10293393305713132, 0.11112629345828488, 0.14663544934122794, 0.1349773071706295, 0.1122810101256736, 0.09742167763291829, 0.24528379461938338, 0.3083359257828805, 0.1797314282626875, 0.07708524549079519, 0.17553516633568272, 0.13799978450181025], [0.00972835136757743, 0.05669434832769537, 0.05687594180926681, 0.05498469288971636, 0.02714474362531497, 0.0092059244108837, 0.03494901154490729, 0.06872639120105775, 0.04360870090163043, 0.020764857237677903, 0.030773181182843064, 0.029881979609208725, 0.01840592696211271, 0.07829571803731304, 0.01492305281346724, 0.04857323410349989, 0.013847327471951084, 0.027867235401044452, 0.05201826638151562, 0.04104518301544651, 0.05376329209895865, 0.04812837833718908, 0.041919457876393874, 0.021875228905569644, 0.030856414720596328, 0.012486029450120706, 0.025021098103494416, 0.018757534506280097, 0.031210504389638384, 0.06580889855902042, 0.0482416176237166, 0.019941808761007363, 0.03187453982630565, 0.028287030516132235, 0.06586850019952943, 0.03846841563861217, 0.04488274725454469, 0.04587755838949834, 0.010448989210530155, 0.033339169702582785, 0.05175693080790582, 0.014499076773532698, 0.00962569079767432, 0.09894558739277626, 0.008065972173015678, 0.11236137274893061, 0.024390958227036942, 0.027394005653238105, 0.039874466601759195, 0.003919296244519853, 0.04499929221046548, 0.03760552101377999, 0.05745833334062369, 0.054937099677420435, 0.02497445675544441, 0.04167042567484802, 0.06133117592863499, 0.06008172099809012, 0.07411896070886044, 0.026463394601558967, 0.056596101381846016, 0.04050203816845052, 0.030520753296572837, 0.06546041282314448, 0.021407486262520956, 0.06508736630841609, 0.07746208414074875, 0.032192937458955476, 0.0427608484131915, 0.05946870893239976, 0.06823277010792686, 0.026607118441813418, 0.06126147341884433, 0.031167783496540882, 0.042777449538510655, 0.03444331307565013, 0.03875096418684529, 0.05937978910702852, 0.04962675055609115, 0.052184281465146816, 0.03744202635941967, 0.06071435640596094, 0.01708772330124292, 0.015046145905920816, 0.006790939960703855, 0.09416057157420343, 0.03371302444007128, 0.04620187022092362, 0.02057386768771516, 0.06595885260931908, 0.013929082460010485, 0.03283327205046531, 0.03224705774036627, 0.07945922939407249, 0.052190459964256135, 0.04228459070286444, 0.1434824765930253, 0.04788663163180313, 0.030225805615285234, 0.019821609565687758, 0.057852297886124546, 0.0017576522828500359, 0.0362870492221367, 0.063483216499369, 0.029917543325873635, 0.05172194357240393, 0.048073721794231285, 0.0052198971201094894, 0.06387727680586039, 0.03388835515286173, 0.05046304277775269, 0.02238751764619543, 0.06408572549961748, 0.034786842222655975, 0.023568762023182168, 0.1118354763715498, 0.022047037529128215, 0.00766376547905947, 0.09739082727220752, 0.015033809017510185, 0.025091970812589414, 0.029355742322701602, 0.01330099665679999, 0.01804420897256463, 0.02095531052609365, 0.025763356862890146, 0.02228747230894383, 0.014042848431985947, 0.04615957833706372, 0.04789858643386153, 0.01594982417901197, 0.037589578724075715, 0.016769013487763943, 0.01783602649436122, 0.04729959377718549, 0.080041624755869, 0.042750789678745696, 0.02548288632815163, 0.03460348290841907, 0.1060744721983229, 0.024317214603445703, 0.09635454779791255, 0.10073801097009452, 0.05628003648692562, 0.02542921037773692, 0.04852791234189945, 0.022823714703742056, 0.043150201109388185, 0.0605413354482622, 0.08128516931807803, 0.03776643395183548, 0.036361627881565405, 0.010716451572314387, 0.022976618192549196, 0.07972310071871166, 0.02953477898582576, 0.03542557185996444, 0.06948673346590611, 0.03479716908787528, 0.05638805871468879, 0.05415036185314098, 0.02004045215735753, 0.04393572851474728, 0.0243415359798218, 0.03153094364660642, 0.024648652967786597, 0.031875164187963934, 0.030590084253720222, 0.03857979716192331, 0.08895098216711514, 0.04281758105442409, 0.015340889616298582, 0.034494713744929725, 0.07551017637935377, 0.039290156020152, 0.012010049446666194, 0.03698798519889674, 0.0400143159523366, 0.044127690996373856, 0.025359921555425373, 0.04101899046931536, 0.017709683273888884, 0.07182121021492828, 0.017433192565917008, 0.033390060923392736, 0.042096749774270484, 0.031841182442862666, 0.02198453433060598, 0.06275287040719582, 0.07794655048318448, 0.0408299659348784, 0.056013150606304414, 0.023464284867288607, 0.06446156440482986, 0.06152290092300504, 0.017499221684110743, 0.07140258912958446, 0.058299608964232676, 0.058885256369267745, 0.018773570641755097, 0.04565380708945375, 0.028989242029286204, 0.02413447198998784, 0.015830044416830908, 0.04525566353432594, 0.04947272857891456, 0.026556763482550462, 0.041585922346360264, 0.02201121142734924, 0.028602767908465, 0.05953839995087155, 0.06806190185729535, 0.04617495372170403, 0.01515314349108526, 0.05855624075798739, 0.12110544669051325, 0.014756179711360846, 0.021231908486374927, 0.035548597919724645, 0.03943365194924897, 0.04262164257647049, 0.08814033856915851, 0.030542180775814963, 0.020306349784556418, 0.011576515502266346, 0.013358052970180589, 0.02842683964709361, 0.06337278875552359, 0.05293196795748607, 0.04346854894632294, 0.07246634817772335, 0.02112491090121048, 0.050793272638393026, 0.050261029222559546, 0.06445416399548132, 0.044147042377341184, 0.02094044842036261, 0.0073974924687776845, 0.02809142911686532, 0.04219613436068739, 0.064817029201696, 0.08390476100987966, 0.030562916860705426, 0.01823756381899359, 0.05409048442097922, 0.05741141428570113, 0.04858169937506319, 0.04109427776007403, 0.049865927036491134, 0.0230271072171989, 0.015841651606493663, 0.036038342607958664, 0.022039930148410703, 0.04305326800432898, 0.03139905394956229, 0.02701369470976774, 0.034360897336756034, 0.03795491073340659, 0.04507706545653843, 0.06579700887443558, 0.042302999795684894, 0.02334548378243081, 0.06615477959595381, 0.019222789278794682, 0.031899567918791887, 0.052219146126580816, 0.018606816283276966, 0.015710569174599745, 0.03222128654259347, 0.06401409627869725, 0.0050179707074177364, 0.10005503592471923, 0.11161594621596799, 0.03974701638423628, 0.07011654967021558, 0.08990941944742396, 0.0680880407772718, 0.021218028888406775, 0.03635290214010785, 0.08379073648322975, 0.061561147862624746, 0.08166071327943956, 0.033404566798238985, 0.07426712977429552, 0.06264230859796367, 0.022483675087231304, 0.01799362418692439, 0.038732784920402115, 0.10873215378171976, 0.025107713919433377, 0.028394752054385124, 0.041977580967209036, 0.03351874837291337, 0.043234049432700684, 0.02328052718733107, 0.06017277437833048, 0.0349201989780751, 0.022504416917781198, 0.005378330327315076, 0.034576788574697516, 0.04346871365522666, 0.04483849801603825, 0.04207178296881818, 0.02047423220750305, 0.031121188113766334, 0.024305091262043967, 0.08423905879739793, 0.01841958630980263, 0.020533374195257505, 0.044398365181780634, 0.04410832429364805, 0.04330361021622535, 0.06409464659349573, 0.08073814423574556, 0.06375733808043503, 0.09962021207977688, 0.016356601545046416, 0.06330140851317875, 0.05439539890616171, 0.03246480291108451, 0.03239091373078766, 0.009015448139830223, 0.0587761462966521, 0.057749565495478536, 0.07824874152579615, 0.09738534974354891, 0.03629800427945391, 0.08520773867325437, 0.04238127482934825, 0.04258638337975548, 0.07207695334669083, 0.01259790605775291, 0.04796258924949554, 0.04941375896094307, 0.020371344684052373, 0.03551802335066661, 0.12424655273676881, 0.06810870982946889, 0.09891468340591078, 0.03537765689074032, 0.012943963294908887, 0.027150121562543417, 0.046892414214990796, 0.052590706430736094, 0.04130970551482132, 0.027243626424141472, 0.026797933706773386, 0.05732227229483186, 0.03278256086031756, 0.0376495327650299, 0.02673271089611996, 0.023711802129964196, 0.12114288540737284, 0.18754094388456116, 0.1963113789116183, 0.15234999028184723, 0.12954992662754752, 0.08828409496814975, 0.2345509181219724, 0.16649512964631283, 0.08780690646099468, 0.15783966909493172, 0.11538911310415115, 0.11426660277309919, 0.11697883747758404, 0.23623773647892862, 0.09104584193518085, 0.1282761215923294, 0.11087013663904322, 0.2910023591210765, 0.16213923031764646, 0.10674898963301413, 0.12685162706240533, 0.16047439868411711, 0.15429496494752748, 0.0848383080935286, 0.09170700645735187, 0.0899481222093586, 0.16298125287698162, 0.07595420094026674, 0.13021268461260105, 0.2500052864272749, 0.13138576440753477, 0.16033789713776883, 0.10671964080463495, 0.08301795295049107, 0.25837427606025054, 0.1853193655129402, 0.1324408360186123, 0.09918542653923074, 0.07699901463403817, 0.14129488188172543, 0.1329998197334428, 0.1118435662600302, 0.15908828515919948, 0.21449447579441533, 0.122852640436782, 0.2649435412979895, 0.11567969025383074, 0.1073719876547975, 0.1466186566939277, 0.14753449948564654, 0.34871304948483745, 0.16854135049206598, 0.17779019210607777, 0.07748971693217754, 0.13606464640507776, 0.10996622183630544, 0.19683048008911072, 0.15615358618238281, 0.18943175613399477, 0.08565003187545846, 0.10605908915280335, 0.2163273411532564, 0.10909519518815702, 0.1842502132058144, 0.11830805365236537, 0.18950192978785885, 0.15567715610227278, 0.1324548247841097, 0.11974141948045262, 0.21473268317359112, 0.13245765930942952, 0.18296824167332343, 0.12285478548296999, 0.14653847793177252, 0.07691462238829944, 0.12396072533221976, 0.07926782998707026, 0.1703842209591981, 0.11567359219395346, 0.09086109983224062, 0.16055324445328406, 0.17638301116324243, 0.1700567183715682, 0.17210087077992578, 0.13558663818384373, 0.16073525162233462, 0.09787101884402576, 0.16195389832700455, 0.124115651293147, 0.12049868973272464, 0.09272465467332833, 0.10666141046151038, 0.0951801733143868, 0.18530880882134362, 0.1292543699063601, 0.21836418508281633, 0.2606349095942513, 0.2157355382317497, 0.0778273395412872, 0.1887836457500535, 0.2829688240683848, 0.12407353943994931, 0.13744656176817033, 0.1838708311439522, 0.18483735831274142, 0.21821147311599026, 0.20149381050179083, 0.11696197588237063, 0.2028699955272098, 0.10327724003863913, 0.13999873772263527, 0.12907846079718682, 0.19405952474522978, 0.09597858248819267, 0.11002148741916304, 0.21048958263089582, 0.07669489304985731, 0.09324350304180577, 0.20911405644109174, 0.1114539952287751, 0.1591504608551341, 0.10931030501641574, 0.14956369785772217, 0.06741949116751071, 0.158728392374131, 0.13141090741320965, 0.07221772200277737, 0.1537303275038158, 0.11352903630223968, 0.11933461913178045, 0.16318558384814572, 0.11224345649562537, 0.0643108749101239, 0.0919245141408136, 0.11905453738666351, 0.11683914900547075, 0.17551664232967362, 0.11596793083534127, 0.14173829357229895, 0.25749909721555253, 0.05755960250333433, 0.15407842253485035, 0.20242453072099917, 0.15693416849019068, 0.1201308755985191, 0.10928647202109137, 0.0910807142574941, 0.09841186925768854, 0.117385882974392, 0.18986669489212576, 0.09493815847822736, 0.2623741130434698, 0.1308954068489613, 0.21159599745465865, 0.20991618114133037, 0.0954573822297877, 0.10982503183186056, 0.19329893733224562, 0.14280246630791696, 0.16469670760054744, 0.2075847457613676, 0.21076100758246838, 0.135991990626339, 0.11855438156353852, 0.09809942029777075, 0.16398208546302012, 0.12720893813116899, 0.16078100239317264, 0.1380624504940164, 0.3649932146072388, 0.10038191032025123, 0.11695012450218202, 0.12180362092030626, 0.15296577175538387, 0.13419266459682297, 0.05390097725114996], [0.06262506778922773, 0.01949668677914287, 0.06710577816251787, 0.024089853114057935, 0.021637567364039923, 0.03608550681101699, 0.03354222513735294, 0.05302057751724797, 0.0206826368512045, 0.036515079123238404, 0.04334843019023538, 0.06130669941945423, 0.01790698155790808, 0.046547341400817524, 0.03841758953527578, 0.014032637437565193, 0.04101479996836955, 0.023352725228535074, 0.04797282801460355, 0.014043708365680951, 0.08090114476339472, 0.0136959015752279, 0.05234679552696405, 0.03716709655559352, 0.035906403115199464, 0.02921367897802303, 0.03976343364845361, 0.05806418248422204, 0.053315456250622395, 0.03177884203802434, 0.052044818988971175, 0.037824748564631715, 0.027717700783884334, 0.018336165080507918, 0.03342008390914529, 0.008230019368291383, 0.0539269706144208, 0.01989994971682468, 0.08677153863132962, 0.04580195700269073, 0.094785752946571, 0.07013055375747143, 0.037050678004180236, 0.005611075499590727, 0.03001769208499501, 0.02931482365144597, 0.032214207890173124, 0.07264237986096451, 0.029272342160824808, 0.04912244636685618, 0.03047547750024786, 0.0894704970320867, 0.02082212039479806, 0.012620009609588213, 0.04513302817940713, 0.03363335895682535, 0.029621507799733552, 0.017144540212147178, 0.02036683051095855, 0.026768565726196094, 0.05708955010519393, 0.12405314617940497, 0.02632699647708045, 0.022707893700909712, 0.0076869434692085755, 0.01732465131358514, 0.041324180746150595, 0.012227773549966516, 0.05928395916858028, 0.0038031664124930343, 0.015088228073211448, 0.02976197768152962, 0.08932359201172668, 0.06344896470827442, 0.06748756574046227, 0.09022054307523275, 0.03223553577798509, 0.044677416538639415, 0.04587488091220299, 0.027070308607372067, 0.06512876569984422, 0.02473723571447115, 0.06908584731600939, 0.03856110844701048, 0.06081518889855474, 0.06317313475113723, 0.018536498987927072, 0.022250479838300138, 0.03481841270601557, 0.02592787999028881, 0.025475041587807, 0.03382452470701068, 0.011215396018909111, 0.023802405433549036, 0.0369132916262794, 0.01617167175056473, 0.037830827472310875, 0.0882898865928573, 0.043352896482833934, 0.010937819381304567, 0.04963803120077618, 0.023145111570615443, 0.022258941279423815, 0.08518883162328313, 0.013939673625563663, 0.015114706944704298, 0.016592175496982473, 0.10071115958834849, 0.09078652883369116, 0.06950583203785843, 0.027476873384007526, 0.03612816258664093, 0.05632024078119186, 0.03781736730748127, 0.0679730509798373, 0.020665909321377837, 0.006890406422767669, 0.018494931057155616, 0.05496038108943932, 0.026448164773624272, 0.016601853102685946, 0.011636811409956746, 0.005416161185430904, 0.023811893432491252, 0.02741433379630889, 0.04580224428566233, 0.05917907407086703, 0.022493122866557493, 0.012061851354496134, 0.040755191923029004, 0.024792675582331516, 0.040038742665802284, 0.02100149796704852, 0.007862076435553571, 0.07865420122060084, 0.05172980363450704, 0.08451973043021657, 0.021721126489161004, 0.032821627514016245, 0.11468164622783662, 0.02413597735275905, 0.0306001563947047, 0.058471810207852436, 0.06930837287537514, 0.006229832267103296, 0.03414978265702244, 0.022789300118963567, 0.12090983379992748, 0.007760605695957859, 0.06823499176290727, 0.006546139916134698, 0.04628909699198219, 0.05441396504700665, 0.010788345093568488, 0.06631987154363625, 0.03615966412208734, 0.09159809939803616, 0.009528052891724774, 0.053555632475763566, 0.03471979037708333, 0.03435659958350082, 0.03735975234679157, 0.05896237077972582, 0.01538558605863082, 0.06955272427970363, 0.05101960565474245, 0.05765299245174374, 0.0451850149059488, 0.007581913772399628, 0.044727901732849504, 0.054248693068662, 0.018835866996537776, 0.03739974596687863, 0.037400132841280395, 0.05076663193082617, 0.008007726508132633, 0.016844011580331192, 0.009667150518526475, 0.0334708065906119, 0.03348014137196926, 0.0338325456475779, 0.039628138690586054, 0.031229183528452154, 0.04474773957964875, 0.012742927459429109, 0.0460969353274953, 0.12055511976922713, 0.045543072910438624, 0.03198731179919935, 0.05182329700478623, 0.08707435020515997, 0.056624603683068875, 0.03434691240169829, 0.016067786397592678, 0.03500872043772571, 0.06618328572761628, 0.06700480777409769, 0.08427625236612174, 0.02000138933409847, 0.016130588370405378, 0.010668998171064642, 0.042382293726287545, 0.0821921791160299, 0.011115302801162246, 0.02831591586131723, 0.03137568635265193, 0.03882743891388659, 0.04457712413803224, 0.08306826194447857, 0.022338696778000846, 0.10883729934932725, 0.04132665904058565, 0.09592909320828416, 0.022806219170771302, 0.0049856700465053085, 0.05268416532705869, 0.03052179517614986, 0.05937263001537612, 0.03490964228647851, 0.046150366129774245, 0.055680867630027, 0.01596644349891933, 0.02172824536119738, 0.0544920064238531, 0.059735165803783366, 0.05517040792432043, 0.11965404715268843, 0.05243271611811173, 0.04540262984171991, 0.006772693661567305, 0.05797494090192261, 0.05963209250401105, 0.05488588286924267, 0.04171303165475688, 0.018822653895063747, 0.03692294433412533, 0.013654527081657323, 0.05041301340585755, 0.019911749386078408, 0.04185069382431046, 0.06795076548211998, 0.04753130090032374, 0.04875598437783699, 0.04161773797785563, 0.03673409983035057, 0.03982075234694828, 0.02319966852214308, 0.028115003557515242, 0.029598245539912776, 0.023151895279184948, 0.02069309778181055, 0.07856072317208014, 0.050600505764445955, 0.018789660403384797, 0.014919857269213086, 0.01803096905801325, 0.026446559819422906, 0.020099460079725233, 0.04276317349004169, 0.04927911900825078, 0.027874587929897734, 0.031751161366100275, 0.029229012227827506, 0.0438469619069609, 0.02959066509990202, 0.03386059595692543, 0.04506796050155836, 0.008588852079194641, 0.04005662698839461, 0.0658646467772703, 0.05511523044157413, 0.024624848700759393, 0.007409690024947087, 0.05811832574827056, 0.06345517768134033, 0.034190136338433916, 0.025183313391021183, 0.04746658945335977, 0.06503858182939791, 0.036050492762437755, 0.048926297214723406, 0.04110144451260567, 0.05002709278356164, 0.016173483548505653, 0.0217329204127553, 0.020869631252642122, 0.060694043584648645, 0.04801273353457932, 0.021587181761259996, 0.019047403024629723, 0.04325595188645586, 0.03950024414206705, 0.007362525343083807, 0.029724171242466377, 0.006272947216676849, 0.02557921996941009, 0.048327898276188684, 0.029672115568011522, 0.07990231166683859, 0.028466157194587494, 0.022265112117653894, 0.056218565591881355, 0.07162742061360229, 0.004940992277566223, 0.04022400570853103, 0.026071345275868813, 0.01910628262727011, 0.04407288889671045, 0.03623390570282936, 0.04946749236795211, 0.02097522306646551, 0.07149363101850595, 0.0009764609949929911, 0.003150932320896837, 0.018426025278806206, 0.08867452401788005, 0.04647596881935193, 0.04098794092574427, 0.01927625647025003, 0.012700980315135132, 0.048079256779484214, 0.010368417828313766, 0.011080950461027604, 0.04099609976213786, 0.0660668863284011, 0.04014525570035462, 0.011496558905609194, 0.007782687222765339, 0.017776622121492704, 0.027279063736298875, 0.06229859175941637, 0.05098092587544553, 0.04114219272929815, 0.053786933572301944, 0.022622706638949535, 0.02177667169411096, 0.06216032821084223, 0.06811256325172801, 0.04446737821243944, 0.018222274619244763, 0.08503738370153212, 0.03115694909807175, 0.022400755645526994, 0.037812472005645116, 0.029860404658041177, 0.048290969007798744, 0.03933168947696686, 0.012986334660390933, 0.0701955869613636, 0.0255645455552205, 0.06725072199779172, 0.026381587902564677, 0.14081900338492087, 0.16167164089218264, 0.12638458922024698, 0.1123905223944495, 0.16075752945917268, 0.1750576943759957, 0.1234494612341927, 0.10592206666666655, 0.10628510807310382, 0.14899584284472853, 0.1992690298826464, 0.1423217001701555, 0.16204915369950956, 0.17232738765737704, 0.21647131971774564, 0.16036639560855206, 0.12367344236061459, 0.09205018320391256, 0.1711937460687853, 0.11476059924931296, 0.1556818292386109, 0.2003375693194328, 0.07478236220777035, 0.14952179284826403, 0.14049617393362906, 0.12666052642969355, 0.2039938924774047, 0.12065269638814273, 0.09500650118195242, 0.1366674503491771, 0.14260659294743694, 0.1557048271980978, 0.11360638053907503, 0.09197324499367707, 0.220879374312297, 0.18985759376758532, 0.20146859088732352, 0.15346910684339463, 0.1263283047404501, 0.15364794240843865, 0.16167510360960038, 0.1828117605539099, 0.14789849850198916, 0.14944021980608665, 0.17116366945687803, 0.0901706554296036, 0.13713615826301037, 0.271087474520168, 0.253019857731077, 0.17917880307762854, 0.1388407345380514, 0.2772367397142995, 0.10260553414663, 0.1081768472889258, 0.08984540514047108, 0.14378672075127402, 0.2308463773900463, 0.08248612705257632, 0.1237031895547144, 0.09074085467164555, 0.14550695586348736, 0.27581144845293415, 0.1208603521808982, 0.11600638078826091, 0.20590082321676517, 0.12053885572259465, 0.10674722763078828, 0.08433470487474434, 0.1725046144377801, 0.17921123924034257, 0.07374037537843951, 0.11937374324207345, 0.17323589132678124, 0.14036745584059146, 0.2053029835224152, 0.2689073108617337, 0.12190994626331715, 0.1823396512096928, 0.17272164714672875, 0.1358737066508301, 0.12101776026670011, 0.14550844207406044, 0.21056875015699097, 0.26274257069153173, 0.169239241269327, 0.18716733812564806, 0.19084800755785358, 0.12496916517134636, 0.10056462995107136, 0.16737496630559046, 0.09952075854544679, 0.11473812989049381, 0.1006372091210177, 0.14003874283404122, 0.10939796079671192, 0.15691290188941265, 0.1465806740546419, 0.23437068827690619, 0.2507915377857224, 0.10407463031550569, 0.14373332442295167, 0.1663150989841069, 0.21691618697537532, 0.17449783732093152, 0.18153945705102337, 0.10963729432513637, 0.14057742521887825, 0.16224041521068544, 0.1756872501104109, 0.16350156447339445, 0.16589488443588057, 0.09743018886975705, 0.10610830264105912, 0.13568656669268686, 0.1501901279534063, 0.10461981678681989, 0.10116128987001796, 0.13638862498825596, 0.08873672269645239, 0.14515786491815122, 0.10549572341504598, 0.1001049465529861, 0.17475833785870384, 0.08895055315787755, 0.1355076545188504, 0.1403194221277391, 0.10204952285294572, 0.17577648403183108, 0.08626717698550032, 0.17308941531565883, 0.13487719480068455, 0.13360423246218314, 0.169871692816096, 0.1579699959726103, 0.2000604293519451, 0.11990102623859722, 0.16950803087844005, 0.07353140191445429, 0.10504188526782299, 0.3149721471052016, 0.19258777791213608, 0.13487311921292736, 0.1584678611928417, 0.14313284938614215, 0.10791772570941718, 0.10882248320887167, 0.07437002304340563, 0.1948604543483065, 0.09306647544426304, 0.2147224788824397, 0.11452875806078797, 0.06804393709547098, 0.22890855798557883, 0.10893790201554376, 0.11675920006969284, 0.14656611838408057, 0.16589419495674873, 0.19637445859130354, 0.21576684058433582, 0.09828130489275341, 0.3063011349689576, 0.15489749309997405, 0.17390516105919115, 0.13950101039823026, 0.18715635242481388, 0.1854179610287951, 0.09177082924232369, 0.17097217811932489, 0.09869448675383484, 0.15744344842049385, 0.11149677357846692, 0.13821398268543905, 0.27442945648104916, 0.09578624845392282, 0.16400353592489997, 0.10295683142518806], [0.07243816380298908, 0.01491347958724345, 0.02267035539261997, 0.06666653399025241, 0.05718716119806613, 0.04366862812950727, 0.01981091114782518, 0.006688285136460177, 0.024930680576231212, 0.013345243022476715, 0.04414996117233269, 0.04838201855759948, 0.028341420843536337, 0.01184376910509121, 0.09879816909350696, 0.013330776409636582, 0.024242503793850064, 0.020457292088277398, 0.048702074770605376, 0.013018977666844525, 0.014851824831097357, 0.05102139063960603, 0.03273864870049781, 0.011989016502705074, 0.0755733403287107, 0.055932584969747456, 0.07941087392429191, 0.014923148574457775, 0.04044634357635533, 0.11026308856784336, 0.05103880381812492, 0.0670959952197248, 0.041782906534330505, 0.058100878095795075, 0.03686002170246455, 0.010950457916835384, 0.048904842922403935, 0.040250849429397814, 0.017148330432152557, 0.01718245581873963, 0.03092746554513372, 0.036958981110083486, 0.04427663764105209, 0.07827172416352457, 0.09674648604085369, 0.005844990871170717, 0.040617004983247294, 0.07656650437462716, 0.04716936649093705, 0.02035044772069781, 0.05145066417753697, 0.025909398119115544, 0.016301525568950082, 0.02287529157324424, 0.07432695358030258, 0.023765931987474044, 0.056142872274522825, 0.05437586749453218, 0.04366334595326935, 0.07327844734273611, 0.010912506878676434, 0.014911139188634773, 0.03887535388311071, 0.07327902190867933, 0.0240367996100817, 0.0745430669837421, 0.030405581553256324, 0.053071652599159753, 0.03377337301630647, 0.04262850289383242, 0.03527349957655515, 0.07047379945194529, 0.03420088455201157, 0.04895458884176709, 0.034115783674942876, 0.039801309035430034, 0.061916018941349564, 0.07177621787113529, 0.04322371873704176, 0.03925326505615827, 0.03275019364551671, 0.050764781828489036, 0.05046246055093023, 0.06585334698038717, 0.04082848738518454, 0.05759512216994359, 0.012156595363311712, 0.037905003935579336, 0.02757400950236667, 0.026218428411671234, 0.013504901491556198, 0.030087595692865794, 0.07024073252274145, 0.023160827864382057, 0.019561871285400084, 0.05180805568553267, 0.012986071317666962, 0.03529691122352116, 0.014043368414164552, 0.04637715496843861, 0.06811475426319145, 0.022604971703502442, 0.03029446241505925, 0.052761513394333666, 0.05258170872806542, 0.023025607600087122, 0.02102264007853885, 0.01575038850968403, 0.01805756571552446, 0.05281302897680191, 0.0504374516106421, 0.04637443918674704, 0.0386359399154542, 0.027059156282414353, 0.11257176347557576, 0.05615494965064911, 0.036925671607135765, 0.03010791617505733, 0.0280779842737942, 0.06092404233171575, 0.042476599149766474, 0.10122700489216274, 0.027981727241328167, 0.03164599090063524, 0.07943964052584865, 0.0356999117760889, 0.0628759998888258, 0.03495245127968731, 0.08171861420475668, 0.011188876927800236, 0.020026007569545222, 0.028651615589736935, 0.019975985858529326, 0.05539844548630138, 0.0423576410168842, 0.04548750089241132, 0.02462047242349194, 0.03081659730073185, 0.04116080866585817, 0.04743020027695645, 0.0237891367907005, 0.09396315071611636, 0.04540441482658348, 0.023754398533774, 0.021329393174739617, 0.06812056887053675, 0.0039716504538627045, 0.055980404177981044, 0.021170316932482586, 0.05525883362298051, 0.011723244322403785, 0.013920110612807256, 0.09751581451705388, 0.05298483951558029, 0.0382864965696729, 0.0793736650338096, 0.05562536072947326, 0.014549003681167962, 0.013551760217054717, 0.028145053356345144, 0.04027930959578484, 0.025095276481982683, 0.030022997243870652, 0.035252141045226205, 0.0243901097846608, 0.0703352754334769, 0.055000240644139636, 0.0811988618525286, 0.043149277973439426, 0.08893111750723855, 0.03355714086923869, 0.004087955289099727, 0.08592615294600688, 0.028126209508627657, 0.005986929247756639, 0.03728333507634459, 0.08896424314908444, 0.02706357086407802, 0.026157137547289173, 0.028946143837885994, 0.05927508020953787, 0.0430390609037732, 0.02591343731769631, 0.028978378902519905, 0.03933687589221424, 0.07220538032631721, 0.026360920765587402, 0.025693324935292045, 0.021435002225541303, 0.07158415962851818, 0.045755386517773715, 0.023166416475789684, 0.07049869730948441, 0.01496942124269422, 0.06304033723990284, 0.034362732117334684, 0.02858548113445361, 0.05295821412977192, 0.06356459418912569, 0.007942497951819772, 0.07177464739089051, 0.026075359576592044, 0.014874428255303253, 0.034638558244032246, 0.1086695567374268, 0.08019203079804298, 0.05231922785300882, 0.041226366639978466, 0.023411311802544424, 0.09359562769532205, 0.038356919202112386, 0.09068796396135323, 0.03605050808419624, 0.07659232919855465, 0.03028238695415278, 0.026420643064944495, 0.05044802745443679, 0.02444901620037854, 0.05091277852414116, 0.024502793657443216, 0.0327633626969351, 0.028603951514308012, 0.027318639838467204, 0.028167528460823724, 0.02218055899345106, 0.061094006598596616, 0.059169681832915356, 0.0334079873808209, 0.036532063292519706, 0.033683606663778905, 0.02773994606198563, 0.07698725518440047, 0.04510873170088857, 0.050792495059149886, 0.06942572222361643, 0.057188206908082774, 0.04012474752662163, 0.024759124761687654, 0.0851753484758158, 0.029755847062915567, 0.02111015413256903, 0.018785653763540813, 0.015558479654212153, 0.03754853173309276, 0.03040942731463621, 0.009284200402156962, 0.03618656529954845, 0.05924127657987899, 0.0231739183917882, 0.06033395161671985, 0.027124388669166836, 0.05167346935899508, 0.10467300627140269, 0.0866550779450805, 0.028928173330402183, 0.023483538572045586, 0.022050597922756307, 0.05711726333585478, 0.029142021028805646, 0.04299288112369757, 0.014406179994224541, 0.02877644004089938, 0.009754076600074768, 0.024982414493757873, 0.03685460546083989, 0.04448384527237185, 0.017209650024831775, 0.041868673907893325, 0.023113950944295334, 0.02966711492908578, 0.09420612316218116, 0.024174356442545692, 0.04029055193607365, 0.021274196539795207, 0.022214602025586273, 0.07063178210369042, 0.07214331954357124, 0.11647036193960136, 0.03859675068768763, 0.03481637491213699, 0.05548525473944122, 0.05037519164503582, 0.06901613331489986, 0.01513509062914959, 0.03512294414723593, 0.07708516888200276, 0.028333694846819968, 0.03522447761028044, 0.04798061146791424, 0.01501490675558847, 0.08314250352522058, 0.07287368478794252, 0.028784834449329687, 0.02580089134074027, 0.08023373662464081, 0.04034150827435717, 0.05486639359244897, 0.0630714021052324, 0.054141908072896545, 0.05571905328261276, 0.04487173091019354, 0.03211155785397897, 0.08962799704843953, 0.037947215380207185, 0.015474250202157326, 0.028947490237412915, 0.05512833437551895, 0.029710360592411413, 0.03577853537975781, 0.0374371808532986, 0.08603215653208957, 0.04154352321019096, 0.035424177579942255, 0.049514637418812325, 0.005691618153509955, 0.06451830087650208, 0.010480985830297634, 0.06478715943352831, 0.019903726530291384, 0.07415967828203594, 0.028540806717149196, 0.02805457837248762, 0.031788644133015506, 0.055099395404179255, 0.06129944456681129, 0.01526651013973019, 0.01562680703617873, 0.02678343549280638, 0.04949454293255845, 0.022549313500583656, 0.014846709278982975, 0.00740467933111734, 0.02201422406811147, 0.028241093968972567, 0.04129639856757657, 0.043185261123242884, 0.018249585653745362, 0.007736478714392551, 0.01452633130904888, 0.04344760027203349, 0.07719832006841898, 0.052451661472479184, 0.09324099027341412, 0.04182130669153506, 0.027799103371498567, 0.05651092772642451, 0.011141483855974531, 0.048731071198539394, 0.028167955554841508, 0.007374415506473593, 0.03240160448777099, 0.03844485460450092, 0.20516499576549377, 0.16478807124639713, 0.14613030628571588, 0.24179798731159782, 0.16474048186454082, 0.1115944191452957, 0.1277984964150575, 0.10777910976039787, 0.13197675527584168, 0.1511722373505754, 0.08687485324879808, 0.12988378774494896, 0.07434507922059105, 0.1259646887680696, 0.26157787189848963, 0.08204050902878085, 0.1066312725625692, 0.12057539045570359, 0.13732529004975674, 0.18000461521648592, 0.1412172924967543, 0.1407671239106886, 0.23446208256627285, 0.09302172824860581, 0.14843100621815652, 0.13271432940758046, 0.12077500232525411, 0.11202077005779552, 0.15355212013086966, 0.23199497301492, 0.12572045227692974, 0.17430967080496973, 0.051027017555409865, 0.17541259226779785, 0.11221432983274422, 0.23765902876132922, 0.13620931444869888, 0.19387949408302385, 0.20758701338162347, 0.11690716229138837, 0.1833634051464258, 0.10880582845739781, 0.16198017514280735, 0.17739266908216864, 0.165336528913148, 0.14863014311319397, 0.3273016580891225, 0.15615939312884886, 0.13291706691586203, 0.09263116130304914, 0.11828081156577795, 0.09889885602939515, 0.06485858181070897, 0.12219143761021477, 0.2955408478456159, 0.23080585133885187, 0.17690784267840848, 0.1519976051584367, 0.09746805659585422, 0.13716468737731058, 0.14126736400348527, 0.17110058977719278, 0.13072121377673843, 0.15243001582641758, 0.08259671184444621, 0.14241265012852608, 0.16451057887846426, 0.16985350588877357, 0.13073697986622013, 0.1933066288550054, 0.2159300785992415, 0.18741466195112277, 0.16827015536687068, 0.24828917286809415, 0.09249940184095214, 0.11716289776227168, 0.19780692043564013, 0.16455698848491715, 0.08788209032988356, 0.10494981682108295, 0.12317589123643215, 0.26744466515318044, 0.1288347835502317, 0.21712790303412946, 0.19315223149474592, 0.07494412167298217, 0.07057327596891312, 0.2182496702598949, 0.1401297847229627, 0.11770177166908981, 0.13276447752310386, 0.11071234550927916, 0.13674563728272915, 0.05486329476679525, 0.20553861684616537, 0.13566637261500283, 0.1679766977265958, 0.14922260487031552, 0.11972191488190044, 0.0953792795659073, 0.17748876715139036, 0.16400295369807752, 0.11994825555912911, 0.10378616756849712, 0.12245808983401907, 0.15543646659822236, 0.16695260671117615, 0.0952582223521125, 0.0892715133546341, 0.23772785410044656, 0.22847394098437604, 0.15413099148821446, 0.1786331799361975, 0.21818161100870181, 0.29622018397335087, 0.1593820185911271, 0.1546898373072186, 0.13377608130535773, 0.13908980504399346, 0.12695024556089796, 0.19562242071955435, 0.18550140332550774, 0.17786004400301367, 0.16083597686261902, 0.3228553144201156, 0.13000962534739127, 0.17376482907322147, 0.10216560815611195, 0.16798504808497045, 0.061306557693188234, 0.12641619034712354, 0.15383459207031036, 0.1118636301027671, 0.1969598876612802, 0.24113248673177537, 0.0947921957460142, 0.10418506188979072, 0.2178881686901854, 0.12012726732439573, 0.11933618195114598, 0.11666385276663689, 0.28742387049621154, 0.13634520312470777, 0.23418704167969767, 0.12206232881233578, 0.12044229800061834, 0.07482571512340538, 0.09288778543592462, 0.13132037114231818, 0.13820345663735945, 0.13339467677137545, 0.09712137116660034, 0.23085673489878256, 0.1611507164254304, 0.1792886294424534, 0.17002964482432412, 0.26966135588384443, 0.17037521176520856, 0.1453475942534785, 0.11669643448605654, 0.14718075072573078, 0.15506719689696066, 0.19607592944896993, 0.2571691584683234, 0.08336403317028478, 0.16519625821421224, 0.2096665590520828, 0.17193988506351748, 0.07894143822693056, 0.22958099932199527, 0.13156593296556704, 0.12193552593910888, 0.17096188189762254, 0.10609726331407025, 0.0860946080196769, 0.09385471097043446], [0.0303188833828655, 0.02642280726333059, 0.047445058552247864, 0.020376046548687646, 0.032684313914468216, 0.05377220170151803, 0.021744595592721336, 0.019811583389978737, 0.037083045218981085, 0.041244281606087764, 0.020922793924147566, 0.020721261089126912, 0.006594916255468684, 0.05026297891632684, 0.0606226250379076, 0.026501601321562648, 0.006175346657513611, 0.06455222324978921, 0.032179086589284485, 0.04229854882484482, 0.04246562110981153, 0.03419812663548416, 0.05306893681746818, 0.009898155713604103, 0.05332411304416676, 0.04310148940872281, 0.012504069863127605, 0.03542230066452776, 0.02309852959437957, 0.028958975810617692, 0.022888560216092778, 0.07368216801795267, 0.07363488507126609, 0.036287053052576325, 0.04775725087271102, 0.013888795811292386, 0.05089897745018525, 0.04575824402573128, 0.040496755992212606, 0.024052862558634053, 0.06841020373206946, 0.015240170121673616, 0.04914678498021057, 0.017742437363091498, 0.023782634619443167, 0.09142170765347059, 0.08865456742745254, 0.07508428511960853, 0.051141137843050306, 0.00873443559788528, 0.0715225278550098, 0.06255211323619851, 0.029941006683774536, 0.021339712379079674, 0.04197029547104913, 0.010487915095572752, 0.017723806104772998, 0.05569712401578023, 0.042746434468896165, 0.05690942751243711, 0.07793653005313489, 0.02214541470992469, 0.02597641166029198, 0.061788656823937936, 0.058692317125537706, 0.030798167140493472, 0.05036540487180314, 0.08923262673159761, 0.04968766220695069, 0.04053982928575527, 0.013100207884675794, 0.06470519568650954, 0.054312948693311026, 0.03942763815904337, 0.043731527778530316, 0.010256202226775068, 0.018196336797348434, 0.030752067799649896, 0.018313052207832376, 0.019688149388398857, 0.0004710516042260063, 0.037051773509911956, 0.018554888928549427, 0.03567191126245645, 0.042085308251121355, 0.023607629494020538, 0.040584875255702965, 0.03857206733476731, 0.07388908836630083, 0.042189726035200784, 0.023186859532049107, 0.05803722001972699, 0.0473722227428469, 0.06180308992043138, 0.03776569850742817, 0.012824557958200816, 0.01705063890004831, 0.06744726185476588, 0.07999572076744611, 0.044657954074923074, 0.035398739630416516, 0.03316731319852895, 0.049124541617329084, 0.059319605239697044, 0.023856043079567534, 0.005875881930302468, 0.02584490500720999, 0.1052462928477795, 0.06233788823949234, 0.019665714503536304, 0.07721633079551882, 0.027650999423537045, 0.037027603435900905, 0.01981528359465301, 0.023815017156002503, 0.007671716514103596, 0.03697208121358868, 0.05636343664880242, 0.03787983794726672, 0.034035765791251775, 0.029020869969240123, 0.052192869310777996, 0.06011357876442133, 0.07112632250233043, 0.034407912152669126, 0.06163548903479692, 0.0060080847657856444, 0.06925338308417028, 0.036859006635964885, 0.03240720459049748, 0.02689174117310153, 0.030063812493256507, 0.03324121003970504, 0.007101208921672116, 0.05855517589577264, 0.05010615688778701, 0.07553054665726039, 0.014691618609152015, 0.03950249261012481, 0.0523783736712029, 0.041842941014516744, 0.10833716650883998, 0.033666331381086385, 0.016059974215984825, 0.014551184158922445, 0.07077641184291533, 0.04040469520635182, 0.03489449289777587, 0.05217757053493012, 0.03282549242759424, 0.07337446880316542, 0.006767547465935951, 0.07781283749688057, 0.041359076051101576, 0.03720647347490153, 0.11250890596138854, 0.0948791237427823, 0.03209950154527061, 0.021124064374054154, 0.06144729187531818, 0.021545213549548102, 0.04226193365250384, 0.018096707062795758, 0.029774692825852867, 0.09209925879634197, 0.03291795157917565, 0.06660162336042812, 0.036606059725125956, 0.04008681085261126, 0.017393468991823254, 0.04733693290261492, 0.023143391703225435, 0.06092842435464264, 0.02892695716582239, 0.02833733184924049, 0.030157890005577958, 0.06848918739706278, 0.010011565454694773, 0.04664404084905983, 0.0976957762313466, 0.009001139532624474, 0.04070589416510156, 0.05818957958610789, 0.005628963652622676, 0.014294973713526083, 0.03277159431168149, 0.05699129932890496, 0.029080144107161515, 0.037257717096156655, 0.03026477267755376, 0.07962746230224449, 0.030738239912616632, 0.007048055826265726, 0.06313876421641439, 0.029442308342925487, 0.018956861008078824, 0.02455674731473048, 0.03453777554715353, 0.045178016692760496, 0.07021693017093406, 0.10295043459102031, 0.036325238705162084, 0.009290763860448234, 0.033070330297754656, 0.02802977819115885, 0.07396316140769951, 0.02076895006241337, 0.03575491305861262, 0.016366489824929064, 0.014657127415581096, 0.03843278488925388, 0.06907787234071763, 0.07548792918603267, 0.02043888491067675, 0.017646099891393416, 0.059280140220277736, 0.09669123577975458, 0.013668097371626045, 0.049688891778069164, 0.021823288144303427, 0.004997239410576801, 0.05173161926288759, 0.08299985795371956, 0.12536502578445982, 0.040583289453699704, 0.05844714217669061, 0.0397464111747761, 0.051759815128940734, 0.039091145529622034, 0.12182140948190806, 0.027083950718083692, 0.05110383319157747, 0.00964232448173026, 0.07560865698202003, 0.03178199065939313, 0.049435734193051056, 0.035409870887956316, 0.09128772653639318, 0.023555625530500567, 0.026973413806709073, 0.08294262352489656, 0.019296191993259618, 0.05539375702820479, 0.054518379000646454, 0.026953911123376702, 0.042523257734794775, 0.09172985886013316, 0.030832265714003198, 0.0561655254944438, 0.01147262440363486, 0.03639808600588191, 0.07130810750588294, 0.038852260162633274, 0.032698440575791944, 0.0191861568694754, 0.024356158683076504, 0.06328962608090331, 0.02159213643491028, 0.030385324273318536, 0.010517857642093254, 0.03413739501528683, 0.060878134512853246, 0.026608420791284695, 0.010673641621495688, 0.13671191409230232, 0.012180594025149703, 0.03149788886789353, 0.017399454053731698, 0.014304318070982494, 0.0161817783655058, 0.04899328011238287, 0.08109511056494328, 0.06597339295812192, 0.05142780411387644, 0.02293413478670822, 0.022009939721394933, 0.0538707014563824, 0.013948370638724058, 0.0409590594109989, 0.003988931961019614, 0.028396860711396705, 0.03658161385946217, 0.04086905557121481, 0.016565167067211964, 0.00350151258903826, 0.01465038967228705, 0.1112601673230529, 0.04182401098190777, 0.061335305142546856, 0.03841046108714035, 0.016510541167771144, 0.043492776476928306, 0.005431916741203638, 0.06346596036887457, 0.02527444529527378, 0.030758631257941167, 0.0750699975798207, 0.05245487521132154, 0.03492482614913776, 0.03222275360096847, 0.005347379896369193, 0.05681409553113965, 0.015559107846310063, 0.07263839620375827, 0.11654289514427224, 0.04220451919301864, 0.04551569292802484, 0.024745940388510787, 0.035306636709719896, 0.04683233759996872, 0.04607291081018987, 0.00514236088248811, 0.08974304813290797, 0.017823280706521005, 0.0033126963347557092, 0.1235773366305136, 0.02396760463354088, 0.039737470928699746, 0.02031591822273068, 0.014690779742874928, 0.011850749123691311, 0.08266417354705834, 0.0207084444381537, 0.033541654401849356, 0.04810067659784709, 0.041463444039465926, 0.031242779673888322, 0.05606411843590679, 0.06557190925964425, 0.046043087007297624, 0.03587943682026479, 0.0386401993643132, 0.03328086658110542, 0.033289546357287515, 0.02917783946970538, 0.03284031622892907, 0.029157503665755355, 0.040013622642765125, 0.0315030561309428, 0.02039933370636596, 0.03813262014920193, 0.08478527182653066, 0.10027851143311109, 0.02872366615901551, 0.0711540931895856, 0.03759202637499379, 0.046631783442271334, 0.0408994960748861, 0.027375640610473293, 0.02460047178300879, 0.026880123449729818, 0.032913508269214825, 0.15537631337440785, 0.12103763258745595, 0.11638602332001734, 0.18647431966758546, 0.1359867659066954, 0.1007817852340879, 0.08182074138594252, 0.07457885095068524, 0.13458267995907416, 0.1668779131385588, 0.21150216700569277, 0.09158535169497614, 0.13213980942964554, 0.12001784698617075, 0.2025880445275576, 0.1092201134850902, 0.07890522525074982, 0.2124047105110461, 0.16970768871326603, 0.11024917641113843, 0.1729643284793823, 0.10688639516311307, 0.1470327425387598, 0.1516994743818237, 0.1489140706196908, 0.1473139427722462, 0.14160019856306816, 0.11780401376346428, 0.11550358962267639, 0.14601395285177618, 0.1393108980189408, 0.11979600324505761, 0.14261422318316277, 0.1481538968941858, 0.0643437170994378, 0.14648699682326088, 0.16813673349397798, 0.13391768499728174, 0.09364352351234806, 0.183189120143652, 0.1487581257618243, 0.13512352271185768, 0.17614823585796743, 0.08661639816578358, 0.13436996798601844, 0.21933573778838883, 0.2596430095934099, 0.2540919211723151, 0.1813192527380682, 0.160497427287121, 0.17392288833375902, 0.1405273537121473, 0.11825173086817227, 0.20631555257545364, 0.19600944833890085, 0.15248595556664854, 0.098739042427511, 0.12879392042035057, 0.0988955924948377, 0.1607043936007446, 0.14686051065162306, 0.2823309792626289, 0.1465605565857503, 0.13436999862953541, 0.20766040460476953, 0.17531186702751345, 0.18751826768200244, 0.2506100055911849, 0.22892312897789865, 0.15042563870308862, 0.1301672709204497, 0.20611518993973735, 0.23632488664119478, 0.11772614092596116, 0.19240603121297975, 0.15238193614828974, 0.15661993454540932, 0.24047985642908082, 0.10089226277364839, 0.16564703967061736, 0.1724572242387841, 0.2471546885827857, 0.17645997235611563, 0.06412023776060631, 0.1163007730558034, 0.09631248190999032, 0.1108228843358736, 0.1315599115144822, 0.2519043877480492, 0.10448265640485672, 0.10817332328447413, 0.14759601634596625, 0.07397024772099911, 0.11810455005615951, 0.12704064393596304, 0.13292984526243903, 0.16444892412231815, 0.2758881798194301, 0.1782533228998223, 0.12398916251596906, 0.1441581201769652, 0.1302305038177198, 0.1234184423341386, 0.1908829105236838, 0.15192707910412742, 0.14920450987354403, 0.07154777811299409, 0.1534305113337694, 0.1602612577018238, 0.12257971395287784, 0.3493357257496926, 0.12213554383525926, 0.16175304539501667, 0.10549711003418892, 0.10972088983943386, 0.09237230785431401, 0.1554358690496414, 0.12816724517653066, 0.10379781976582543, 0.192803998567885, 0.21518714185203278, 0.07526102926461928, 0.1317998042870914, 0.14698935131872856, 0.13521949820701154, 0.1414399023257917, 0.09749573535255848, 0.19492321227106357, 0.3387739166857735, 0.16112139057968894, 0.10734879051245029, 0.14147085227793263, 0.1721799923407455, 0.13099852228356948, 0.15077198705365583, 0.10540032248583533, 0.1157471749390806, 0.10029717333494656, 0.07650859578843079, 0.2183495068381871, 0.11137406161475567, 0.3097098278662851, 0.12764684164956694, 0.10701938802676816, 0.06646254775865425, 0.13265558578554662, 0.11674785430753425, 0.12617609839165403, 0.16920672849782054, 0.15978593078832473, 0.17256456847873428, 0.09664483383418092, 0.16348486375664512, 0.1984141676897003, 0.12184803869815604, 0.21243947558104995, 0.20681865783708714, 0.19242679219572775, 0.15390047563179848, 0.24398104678238594, 0.20432367800704895, 0.2711981282599511, 0.10307721448160949, 0.15049909121326863, 0.14274219051003456, 0.19357757883206492, 0.11181831600204592, 0.1301548143308009, 0.15468635926804236, 0.0957425584596011, 0.1428777114638398, 0.06319396468179841, 0.1922364040247856, 0.16821095209208228, 0.1165013118917423, 0.12493557221586667]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.04665586158573147, 0.03277670411813644, 0.017194136744365096, 0.06682717496709478, 0.09029534390015949, 0.0836803891786164, 0.003018344047426757, 0.03407324281250758, 0.016536973116378632, 0.024620639047615474, 0.0747238101077176, 0.03082039135117685, 0.08309125990396546, 0.04412857965836602, 0.0466678929965823, 0.03230213563168242, 0.049798794751686436, 0.019896477423307878, 0.010711399222453757, 0.034404690752947525, 0.07916646889380871, 0.03378931147557113, 0.04384229643150203, 0.04977426078591136, 0.051950528887250734, 0.03393216772125133, 0.02928844149855356, 0.030785835040132367, 0.0697975889629414, 0.027382784380367207, 0.019809942046600967, 0.06199302226905862, 0.03297902027805967, 0.07727140485639535, 0.011793973390012981, 0.03229598011521082, 0.05336824736948456, 0.013702208394064538, 0.017815706012169683, 0.05642699896387997, 0.005693431387865736, 0.06402883964080004, 0.023102758399721597, 0.021461675491844936, 0.03605034337529252, 0.10452489849300155, 0.04865781021034045, 0.032290540890948426, 0.05495116888214985, 0.025776104565950173, 0.010482485447409413, 0.007074959876556551, 0.008257978704697903, 0.05909576583954115, 0.051822626677852486, 0.030798960041495103, 0.008331641889057093, 0.039209720618542165, 0.03222911979161924, 0.01496246229151204, 0.05692774850514628, 0.06840465725549767, 0.05196889201479574, 0.03959865579682012, 0.07728647380586594, 0.06846068126540031, 0.062255235013341716, 0.03673955437637145, 0.007561419005205314, 0.058207483060898325, 0.031903494119403825, 0.009486054994105812, 0.03725884324540535, 0.03914783220557917, 0.014775521516229117, 0.03756413311367074, 0.08322540956038622, 0.018426314476997625, 0.051539886607638294, 0.053562301271144426, 0.011897384726081886, 0.03911126299851364, 0.06622305335176569, 0.0800779909496346, 0.024240000601557475, 0.05677049363692922, 0.0271062879267359, 0.02814886464376844, 0.0584767974402395, 0.03677418155054893, 0.01833641405908331, 0.03285408665936801, 0.007886876616882341, 0.11967098535669428, 0.10212135125672626, 0.05435864966843398, 0.03989445000526406, 0.07263743093297367, 0.028811630289701205, 0.06297349989894899, 0.007733594872162588, 0.03297909305641248, 0.05886662511094924, 0.010620996059339133, 0.09816018639192467, 0.07410086571208893, 0.07323757655197576, 0.044264671347674825, 0.02437775661688178, 0.01641356209743648, 0.07294463219061013, 0.024171828352395567, 0.015594451312696742, 0.014016232622276633, 0.020423191599547863, 0.04447012463764799, 0.01954421487396523, 0.05198233685786686, 0.04602820574936848, 0.028343364791644197, 0.04352695548967008, 0.08552532808314409, 0.06490353585010575, 0.02800453559405381, 0.09741636864360302, 0.03172757351891168, 0.059206699201416586, 0.014888823047400484, 0.057747485566764116, 0.04010148526680085, 0.04128327165099402, 0.04416379288980558, 0.0662480584616142, 0.016039089701559036, 0.005492877230168351, 0.02154600262011011, 0.05832199405338015, 0.03299396282302276, 0.05517336119326854, 0.031547456671814286, 0.028266051198325814, 0.05166027732493897, 0.030893087349531632, 0.04336190184638385, 0.025568479416711677, 0.06944950925366533, 0.0813044211076152, 0.028691005915583625, 0.07385578652423236, 0.06804901625840895, 0.005882833699410361, 0.03946232662025479, 0.0036106334347653416, 0.04086062094316848, 0.015761112783014054, 0.043450323714604305, 0.015940291172404204, 0.020248632720341126, 0.03725477914896704, 0.0421317063662554, 0.050677478448638034, 0.01967168615890607, 0.012604991413442599, 0.05085346033616413, 0.03350226216078286, 0.014855992349405444, 0.044819966349149906, 0.018950366497700735, 0.052605097392393704, 0.02885080419570929, 0.06422489686238189, 0.12431558491962573, 0.051012500189244754, 0.04903518512184101, 0.02914866684154878, 0.0796230266531629, 0.03286830525124266, 0.010387116119325643, 0.029452476244900497, 0.09160677917421826, 0.09798342692515544, 0.04904442797264746, 0.01892691654633851, 0.07798937479815177, 0.04214363818567607, 0.028817709197380373, 0.023352780769909584, 0.019118576423234997, 0.037618804978387016, 0.05308594013894758, 0.05567188141867519, 0.008879318146125205, 0.03859997974828847, 0.026990330943296996, 0.007707884961423735, 0.05761412498090537, 0.042297376710320675, 0.018973686214115833, 0.0209288670861673, 0.07176684861582133, 0.05616392820112168, 0.061492567671643156, 0.07449920845007704, 0.05401883987830051, 0.04500591504057089, 0.010237632255490509, 0.040719886761038535, 0.01835976441901538, 0.016703421039687052, 0.061665492868351365, 0.06777233594367582, 0.0531670535283704, 0.03127457423796577, 0.054432190278725284, 0.016552049726728472, 0.04828588218398152, 0.09272352852407964, 0.0854177693385751, 0.03694170582739096, 0.08178101206618933, 0.08295075937865243, 0.05983720488485791, 0.07124686643721596, 0.03297954121784818, 0.10410705115646125, 0.02995331005583848, 0.029059637848648335, 0.048768885298481876, 0.06551839035725401, 0.07371343206614256, 0.08113941342960443, 0.042403269213654345, 0.02036207310494877, 0.008211729019099187, 0.02633693455267818, 0.03368426549939379, 0.07310888144157587, 0.009849070545075642, 0.03538025775924325, 0.022581303417081797, 0.013903018233606653, 0.03751455573365092, 0.0634439698150081, 0.04487600951125065, 0.062262420918071465, 0.06725563262138637, 0.08785540748748087, 0.08233077974329073, 0.03718116959076255, 0.011660495018135878, 0.03528784840337692, 0.03528944569669905, 0.035890338251427296, 0.05687133379040226, 0.04731984531146385, 0.04640917744367354, 0.03754563209029936, 0.024634853809050495, 0.10296642284600005, 0.038366997088756294, 0.05479782489278624, 0.025821690627884482, 0.04234996481588291, 0.04984261115051566, 0.026309087256630583, 0.031503109757097504, 0.015802225849080472, 0.041621805904733564, 0.023760720674369126, 0.13888714414450432, 0.06568790263225956, 0.03988148396714561, 0.008026068089454766, 0.04021701515622197, 0.017292084915923978, 0.018451560904542287, 0.02840837692811845, 0.01960757609096266, 0.04835312938197486, 0.050297345620610064, 0.01565907274432961, 0.05764603254295165, 0.0520225411521331, 0.02135775183447667, 0.036230021637053265, 0.033413890088277484, 0.04900156152284434, 0.03474819691731565, 0.07718910403068989, 0.03703438714447041, 0.04248354373680007, 0.03589700321636854, 0.007684809435534502, 0.06676047935240692, 0.06160268898031885, 0.037989024628674796, 0.015203344275153454, 0.008294158164531955, 0.05846701832788606, 0.04786825318249965, 0.09234942480801575, 0.035740663823221004, 0.04418928829592563, 0.006258539018040944, 0.05099986356893375, 0.0299979136100099, 0.049983762850564335, 0.05688706923636699, 0.006750341609961564, 0.035020820796489716, 0.019908305820858768, 0.042555134653324084, 0.04424041700399211, 0.08895924059493888, 0.07667689764451596, 0.03192232456058264, 0.13016135672167425, 0.050306335662401495, 0.07462773502113358, 0.04185017671496157, 0.021864551555124984, 0.03362162248982537, 0.037208917295379985, 0.06419018541853275, 0.09164722095574103, 0.06316432090956839, 0.04754771816454107, 0.010971623968573348, 0.04213246862374006, 0.03890359954487893, 0.02221096310794594, 0.045223043510510076, 0.10195091201533234, 0.06839167972606036, 0.06017432187593753, 0.037081409621262745, 0.06814103107899427, 0.022249401569546714, 0.04928359296172858, 0.027579791550975175, 0.05505799218231151, 0.004321492404767102, 0.09216352591230985, 0.0865422178720755, 0.05743720846611166, 0.051106311486012516, 0.062356209232201504, 0.07040657523658968, 0.06122513403815608, 0.045135763113296805, 0.006641440296305284, 0.04008667295678489, 0.14484453495712052, 0.13332065735613147, 0.09048328058974398, 0.2224531180916294, 0.2697110903118887, 0.21063965925526237, 0.0874882675106487, 0.11513122492620062, 0.07718227818728456, 0.05911754188878883, 0.11575804572672614, 0.12417629481323304, 0.17699344534306757, 0.12909911452762543, 0.13328492701534303, 0.08189875211927199, 0.17136095241913873, 0.13311669410717103, 0.10617587159598067, 0.15223159905402892, 0.1486948622210372, 0.09791201220885401, 0.12330183609118386, 0.16383931731745122, 0.16787761191446937, 0.162232892227269, 0.11242870421659563, 0.12192594217917613, 0.1324435173263473, 0.1122104227843304, 0.12696776599172624, 0.12388382542638049, 0.13375345106807449, 0.18349002415855087, 0.19248714460240257, 0.18234277684842387, 0.142001781852976, 0.13091711778073542, 0.100870322015497, 0.13662338497177248, 0.1922994377391954, 0.2382477060441048, 0.17496007945268385, 0.11179832876810145, 0.11901479274515184, 0.1400351268990386, 0.16992387872549797, 0.09308348259618206, 0.18608792024033685, 0.0746083376748908, 0.16898847004819303, 0.1632931272709562, 0.12168455553511459, 0.1417358880562167, 0.16861386837497835, 0.2220008504246512, 0.107484579597029, 0.1497761953261591, 0.10523032757543749, 0.13769993768824687, 0.12503266619938996, 0.19273480550656397, 0.08026399709764989, 0.11365408483411997, 0.22403461468075553, 0.16698297443649462, 0.14588028583074772, 0.16567570668074394, 0.1887550093834439, 0.13529337972642916, 0.1249541728306682, 0.22791460486910037, 0.158123642566704, 0.09540973922177669, 0.11872634531990175, 0.13585841553586145, 0.2212653294085495, 0.12736623896466148, 0.14481379950959838, 0.18620421238724263, 0.16266021607143266, 0.12079824543287679, 0.16870852619890245, 0.1620874427739651, 0.19021857439750628, 0.13486881379879292, 0.11990620499296535, 0.09569170554318736, 0.1571873299056484, 0.15770693670117086, 0.12351168289540276, 0.07637731130084685, 0.07555717587350838, 0.19959837108129458, 0.2586310687324693, 0.1220766699782783, 0.11446256806413013, 0.11514676885018427, 0.11770258372228955, 0.2280722657639173, 0.13740693970072654, 0.09978879738839404, 0.14973642004113044, 0.22962071331998996, 0.13351211805016766, 0.1343118831995995, 0.1850389466891366, 0.14615525010853045, 0.17660137686517932, 0.1412745652299735, 0.19739389179214356, 0.13958653645409694, 0.11085240170359613, 0.17335812831597944, 0.16438215189883787, 0.2217991701177051, 0.13127385428355587, 0.21272191687697367, 0.22654966601440985, 0.13646649016487983, 0.1081969800795759, 0.2460813381138348, 0.15335269212242097, 0.10645433689557737, 0.266889343338628, 0.1230927860184062, 0.1323321587856739, 0.12489990316211216, 0.11188373224990023, 0.15228470426894006, 0.1692704363696037, 0.22799386432574642, 0.16506645227632216, 0.16533154934164018, 0.12526695886927267, 0.09711387882670088, 0.16372299452702846, 0.1821346001158799, 0.17090261733580023, 0.1557687036092243, 0.19059095441574053, 0.10369865734490658, 0.12720159900885436, 0.19846405533532943, 0.08857709295567005, 0.19524961169208252, 0.17197506382100045, 0.13904987654137996, 0.35822577774524694, 0.17701325637678947, 0.09874971403229622, 0.127648894765204, 0.12490068457179493, 0.11314478192117908, 0.10394983459264041, 0.16576106419726727, 0.21776789288607337, 0.1681505690418905, 0.17344466560790617, 0.08162461521644747, 0.21398095173701165, 0.11289274665497004, 0.11253340545320704, 0.09943379224428248, 0.0958058066786297, 0.051138655718175635, 0.17522442575183608, 0.15156917814766208, 0.10423603738027234, 0.18001128018142717, 0.14581142984811338, 0.20733302459120753, 0.11054457225386174, 0.09347348263667477, 0.10480480403789591, 0.17080101875528214], [0.036021710839122534, 0.02160697172756397, 0.06445179678379528, 0.013595858153196113, 0.018431772853458123, 0.016314349880802537, 0.03153182847815896, 0.023729253612879305, 0.07783897641685703, 0.04881834393487342, 0.014868130054955762, 0.08836845657037151, 0.06554941691818737, 0.013562963295337415, 0.011708690567062268, 0.07172830673235078, 0.04077346312002309, 0.08540157423985582, 0.05142846294949132, 0.04714677455805002, 0.015039337299493773, 0.04455536724098268, 0.03507209506126181, 0.03157268203194103, 0.06175069716728984, 0.0511806718103828, 0.012475585756492952, 0.0874524375784301, 0.06405672524124384, 0.07686706364996011, 0.061141036736268195, 0.027226395191504594, 0.02881276026938952, 0.0846750854003814, 0.057395169391266765, 0.04576468682517448, 0.060155181169149384, 0.051152062256850546, 0.022672552149742845, 0.06309762912532015, 0.019007101054153135, 0.06352373488968419, 0.032785410707395886, 0.02697084549694292, 0.057202142047425436, 0.020631952474134106, 0.03550549015222538, 0.06413981896795093, 0.02881071098419207, 0.043225254743329944, 0.03153506328441924, 0.04335973381755814, 0.0017615547826168158, 0.06265553510597636, 0.024357891957005186, 0.026756005714677518, 0.02545715151955524, 0.062078287855031035, 0.04407419890706097, 0.0938295526430011, 0.10522666567515944, 0.014188433865896397, 0.031505716371259866, 0.03955134220661656, 0.03301858105846951, 0.03459754955744551, 0.050805150831659, 0.04154391774547197, 0.015433626474752543, 0.059398470161062096, 0.03392908038691648, 0.07058625349835043, 0.06318394425174882, 0.05409300101981048, 0.07470573043270458, 0.05689299875690092, 0.03885468866135325, 0.05439948598523775, 0.05531587652982243, 0.05407266904630008, 0.0235352284395166, 0.03764533460320484, 0.057128739332960504, 0.04896958501288488, 0.012491296304600134, 0.031705027551300106, 0.019281596103082263, 0.028094010833170147, 0.045153501879183516, 0.013939530941687766, 0.06903274210109826, 0.07494850369590907, 0.049822880556025816, 0.019333670929735227, 0.03438272318171878, 0.04760499089776028, 0.027487638834563476, 0.011969742688140082, 0.06344170219475223, 0.09995885358582582, 0.03294148963064917, 0.03858210691701501, 0.014243076044705608, 0.04260321816189155, 0.030307374827022997, 0.07345082478657847, 0.03236716117469534, 0.023532884210468303, 0.01453246288527284, 0.023909753503938837, 0.07834742897220197, 0.014123858399538985, 0.03043133934449044, 0.04648168383526706, 0.054570066952897664, 0.04482158662510976, 0.0373520799762299, 0.07858268691286927, 0.019634149765836138, 0.05425288740004744, 0.023797211357422417, 0.024955057493981816, 0.048586073737110824, 0.038109756255101775, 0.044683897642478834, 0.09994567687352819, 0.043180794830644326, 0.025251297948641643, 0.03454208479172761, 0.12380804400891067, 0.030551996277344805, 0.09694106471274169, 0.02077310034374316, 0.07394398622695478, 0.003118378132761967, 0.07870597344252371, 0.028407928766682747, 0.07052086789401309, 0.03625490417283389, 0.04053163980584472, 0.0396866524862426, 0.03725341551246182, 0.04418912358702191, 0.03712799159749862, 0.05465396890236486, 0.06668563256220472, 0.03132269796614926, 0.03732574187339314, 0.009705218385093877, 0.012466705839840636, 0.01806229247801727, 0.0707714858975622, 0.03767831851878474, 0.036754849321779706, 0.026111269948042692, 0.059866795030933236, 0.02953123199873634, 0.0343634330877854, 0.07299560002021252, 0.038055061407747774, 0.06025766841165962, 0.0029369802430136913, 0.018755557999435454, 0.05803103385973842, 0.14513122038014475, 0.0689633958221924, 0.023038594705623486, 0.03791420082111032, 0.0259638516487734, 0.06225795079503329, 0.06814152903614507, 0.03977362261784654, 0.021818683955878503, 0.03298178968590594, 0.0490704941142711, 0.01813049728591596, 0.018644998105423107, 0.056443933337446184, 0.07735552131048135, 0.037104771472513676, 0.012467078350093818, 0.044080676180460764, 0.04389052932721473, 0.035731501411646605, 0.09699387881424158, 0.03836954816154415, 0.031061894823646838, 0.07973250827842182, 0.03229322602912303, 0.003471440525778059, 0.0033873451391099804, 0.02652745104334768, 0.0034964264834284665, 0.05828892586812858, 0.016735029827442863, 0.07661958660690055, 0.03591964877541027, 0.010755706875164424, 0.01456832346100841, 0.03319345977938464, 0.07788533239715523, 0.044913777645917675, 0.03147969811013149, 0.01845246871873256, 0.09077044098728126, 0.13575652584193215, 0.0518464137079014, 0.0016776597758214322, 0.06902433811656891, 0.04278236016210529, 0.0439059506771305, 0.03979779269185759, 0.045039944666167425, 0.028694305839317463, 0.015426600490876985, 0.0729970096219932, 0.07102005078547424, 0.056252652674072215, 0.010645358612941158, 0.01674703442521634, 0.04219427659747101, 0.019359183572833578, 0.026538957683970372, 0.016081846026223034, 0.06979090867624169, 0.04803668910397157, 0.07803831249475479, 0.057815096656521486, 0.030788098829948617, 0.08073894096718681, 0.03280702970861908, 0.03136798333857329, 0.04149920119333171, 0.02985560894763518, 0.05829162249762205, 0.036438979779280005, 0.0215367655149631, 0.023922664000682776, 0.05600312251537558, 0.023769264469944665, 0.00973558706802226, 0.03337879177002657, 0.014805097298155871, 0.11545615345840493, 0.030279832050925305, 0.03660096907086911, 0.024575543281952703, 0.1099680221429275, 0.08026836379881828, 0.043992104925095074, 0.010602287234618299, 0.00528934394805542, 0.010855852761456083, 0.03108161967247725, 0.009822143512147089, 0.07531713754419359, 0.07600265600147747, 0.041924353178230025, 0.02026363080667873, 0.02438490804765494, 0.004802657865859088, 0.0761333812448767, 0.03503921839799132, 0.0734043692148501, 0.03271825160951384, 0.03681941521203807, 0.06054132012650371, 0.032381904536798116, 0.019736857258624608, 0.05869555767745741, 0.02248904727880032, 0.06762545390595352, 0.03683886235399592, 0.04060187091630313, 0.02964155057505254, 0.03163494965842655, 0.030643388651491656, 0.01355851328210725, 0.019817443962599483, 0.05249679171209855, 0.05995119493755122, 0.029258020147080385, 0.026294525840409824, 0.0320384519985847, 0.06841082426328814, 0.05593870601226246, 0.01696145668956301, 0.021660869843476725, 0.04105591207682606, 0.09126454471580445, 0.11865178198223153, 0.06783542328424032, 0.01619721120674043, 0.00420406979936806, 0.04725250235247997, 0.05975795691953071, 0.021868728649532123, 0.038923349291566885, 0.07729634101833067, 0.012267268255292889, 0.02274976423641126, 0.030109777768713333, 0.013973188057031124, 0.016030242343643503, 0.012284390320400558, 0.021909785216614124, 0.08302859391175932, 0.023405562312672698, 0.009439277665449247, 0.007492619521555401, 0.026246097592276432, 0.0756702734337699, 0.05365443866579764, 0.12994682145935874, 0.030097865101490772, 0.0510803219531813, 0.09517350068856632, 0.00517072097864002, 0.05400850152176234, 0.033023388260194374, 0.032566834331279805, 0.040829456486408754, 0.036020860481526584, 0.04570917609418112, 0.06199518646744471, 0.027613748398218906, 0.0332665981935157, 0.031077844774230357, 0.020258632082972797, 0.048260888565451875, 0.0221380066396969, 0.013933633979890617, 0.07430605470172821, 0.05517826415598393, 0.010169855499219511, 0.026899478661136764, 0.018735072808340192, 0.037202214026042534, 0.047042272504298925, 0.02366527761032264, 0.01631945968725749, 0.054558108320399645, 0.04937902836489582, 0.017509992880326126, 0.013493796089483846, 0.03959875155781065, 0.048164334673915184, 0.07522258697257889, 0.037151108300613786, 0.03629046597427899, 0.055223681678574894, 0.031563301285308216, 0.12957739854051223, 0.2611607217019604, 0.30868464900601295, 0.09337255055265081, 0.11761364857515982, 0.08755872461704478, 0.12375322275704916, 0.10582917850584754, 0.172286432596945, 0.18878729232857305, 0.14586738491010282, 0.148410796818714, 0.1631808034594982, 0.10832014403516248, 0.08521238116607552, 0.1553212163308936, 0.08901161802632195, 0.15617004175099636, 0.12947938525147978, 0.29071427941803013, 0.2149987761532107, 0.1379033493539018, 0.1371862757350168, 0.0978637256869866, 0.12737695653472217, 0.18258789434067665, 0.12165269393834377, 0.2459805975517919, 0.18651809393157884, 0.16243216701813284, 0.14102984610344135, 0.15572428583137451, 0.3087592659698379, 0.11775674613853616, 0.11618375312536956, 0.23107971245002365, 0.13226754693014006, 0.19340271160246866, 0.1127512961806309, 0.256327381057124, 0.11271961078408266, 0.14821794184465564, 0.1210785186999748, 0.1318473783471892, 0.12864631059910023, 0.1681518407478448, 0.10237846568587328, 0.1404280227518851, 0.16490686083993605, 0.09150567855085097, 0.19212221095879234, 0.11324252707943802, 0.14802851894449803, 0.14665262503249032, 0.06948726206657387, 0.1488990706181334, 0.22658384885759125, 0.19186996884884375, 0.16037759581400504, 0.18788476414497823, 0.1835562141552087, 0.10698646922866184, 0.08884287950011993, 0.1535624010308135, 0.10424356036368879, 0.16478954213521174, 0.13016814426068338, 0.22951765917241576, 0.11467811456250568, 0.2640980866647536, 0.12908782239162153, 0.1715841597967571, 0.14716778851805196, 0.11660366889930542, 0.15977143640479735, 0.14320843162075167, 0.12204719857583124, 0.10427976567899028, 0.13405276162009086, 0.18271610681568423, 0.12677313369368354, 0.16849941483909087, 0.1460735391705267, 0.1256080518566793, 0.11959397053766636, 0.17649202547486753, 0.13655429916276088, 0.19123238451298208, 0.2323454735620368, 0.16809518088496503, 0.18840381935719522, 0.1622620648554256, 0.16825229019647645, 0.11275943203438675, 0.12128242832278052, 0.19474403962733286, 0.14215939678251743, 0.11987163144494258, 0.14418458085386984, 0.2784732669111221, 0.15787677839398384, 0.11166204172637194, 0.13671347691166785, 0.12784158886079827, 0.09628409835239572, 0.16750028296824426, 0.08960204965044415, 0.10128909631842568, 0.1604476775373182, 0.10493864725914695, 0.12482936944692366, 0.07403965528693891, 0.12551333274572127, 0.20232831007770954, 0.24096860520301328, 0.15624576188143224, 0.1594848582340825, 0.15987367849917183, 0.186052113290756, 0.1735974082182492, 0.0739902196331851, 0.120449575835899, 0.2342669906154756, 0.0910634236530431, 0.12774749794193815, 0.18101222001977507, 0.19357468301971115, 0.05566937248072317, 0.1049269720791809, 0.1995175334835245, 0.1494894639378594, 0.1326627410467594, 0.12180860049181408, 0.13307868082436825, 0.12467861100430451, 0.21052327517780567, 0.12651790384083025, 0.19319352363386463, 0.1292957999413052, 0.17924329235909447, 0.30886703921902564, 0.1106656218067773, 0.13176750602020373, 0.1419820780715635, 0.3124050784014887, 0.1413236408224029, 0.13977315547245164, 0.23813158243654237, 0.10939394649598869, 0.15971859165978047, 0.08946148783809717, 0.13641556063967367, 0.1538453939100427, 0.09693833743973125, 0.09473153690416967, 0.23562716440327708, 0.1824993498983883, 0.13769344126264896, 0.0891505633931487, 0.08512920700013639, 0.08460356343177058, 0.09400507870821223, 0.1269660576156551, 0.1392469296772634, 0.23430227662526795, 0.12943603999672398, 0.21276866356211327, 0.11807281869433581, 0.2108265847087868, 0.1325139054848302, 0.18463242979299638, 0.173300595112866, 0.13040904826935262, 0.1191332835644003, 0.18200238866190757, 0.0519319818986039], [0.04174762052453814, 0.04005647760124938, 0.010640531301408285, 0.02298968956775723, 0.048877125861303466, 0.09517660334465966, 0.045925530815316785, 0.014855324895301414, 0.034967198472229705, 0.04433221348951902, 0.03056748849039357, 0.022773089698485793, 0.029890284002307924, 0.031710945580515175, 0.04963448421368676, 0.015962957798863853, 0.04775544673564935, 0.026686044650212414, 0.04414741776042408, 0.020384237943818013, 0.07829406328739659, 0.033051729682953127, 0.026805579264257706, 0.051200505826742425, 0.025397699266191454, 0.058254256559115265, 0.02133872029521773, 0.033971770636497006, 0.03462370762962007, 0.03167824320224745, 0.03618296085586471, 0.08653756771837512, 0.05283892274864259, 0.043930890669505444, 0.0370199425566581, 0.05372065930597244, 0.014350482529299635, 0.048517194771838766, 0.041555857225771875, 0.048679367924529704, 0.004859738119487321, 0.07661432358286074, 0.00405651934993183, 0.052759778205185175, 0.039880334835259185, 0.04064726928669599, 0.033148471266031265, 0.039258719602179144, 0.06565632448802072, 0.05963132258564715, 0.027917527158053655, 0.03949020839025898, 0.001829594043703119, 0.04987930293164907, 0.036980021714923844, 0.007945977906215816, 0.016271900948918155, 0.03854437708674419, 0.007474799358826732, 0.07936456390926916, 0.010484037733065986, 0.028710378363968867, 0.0418888220203019, 0.04208813128512233, 0.00916208694463656, 0.042521645119714166, 0.034773638697281, 0.01130671657231306, 0.031897204537545486, 0.03661142234059592, 0.015219618855494887, 0.1059999471650489, 0.01597538182977587, 0.04301924603961168, 0.10343985752232614, 0.0313354303474508, 0.059007301836484866, 0.031747961033796596, 0.02865016193790061, 0.03326135432167399, 0.047377102722924565, 0.037059338628164226, 0.03931226531764673, 0.04421663380438282, 0.06554166410839365, 0.021945021430691405, 0.04215581515323251, 0.02841872103031605, 0.012979173653518722, 0.03226481948889071, 0.02490176841796887, 0.028341572145901384, 0.06483428916263004, 0.05208364815541333, 0.05789886454060193, 0.03133373537791833, 0.020030910532260617, 0.02471653410353728, 0.026999954922845768, 0.042454099147430355, 0.056445568935164524, 0.03148972428584051, 0.0174570657808574, 0.07066663910424517, 0.03717873726160296, 0.02252687478528148, 0.03996043698862195, 0.03472113486139044, 0.012315078845037328, 0.013998154862483424, 0.03924286541258616, 0.04833196237262699, 0.031512074901031396, 0.048197276454659245, 0.017830730911584634, 0.04371003135137501, 0.0035482580771654727, 0.04204794997349382, 0.05824742305483069, 0.015710872736939743, 0.009749385269148456, 0.056537066646400964, 0.05028563979712706, 0.02588229009791488, 0.06909150870576983, 0.057851949316119, 0.06306874761057478, 0.05926191115811948, 0.0425197184085846, 0.055892342371085, 0.07146544664377166, 0.09321341876901927, 0.007439580381727748, 0.030683186919158025, 0.054003012501784874, 0.06824774712684654, 0.023134803857594248, 0.0490746118368641, 0.03382377394084488, 0.07556160386171072, 0.11756492538317559, 0.0459751081953366, 0.03098998789585406, 0.041929815385130145, 0.03728483277823656, 0.034247550797919114, 0.030695193432151314, 0.032651778160324024, 0.04280081522020121, 0.07260703256413822, 0.09454924628258714, 0.010221760828919228, 0.013224413719839387, 0.04779694954894724, 0.04453707689179048, 0.01878494513221085, 0.05257458794080923, 0.07592979337899916, 0.05600904437503027, 0.02076277156330405, 0.04369363323935578, 0.0852291125263418, 0.024062501859941313, 0.0378261964708086, 0.06386179416891068, 0.032305115713707866, 0.040098478371698054, 0.05663218795351925, 0.01704924653524593, 0.0479918806212804, 0.06287170979644983, 0.08163989100965761, 0.022863160570963256, 0.015331501208786524, 0.09115397524569305, 0.04862617077906767, 0.04096758596959614, 0.04494037238820907, 0.03886921751883723, 0.024963873250770475, 0.07514525039662277, 0.05310249529899128, 0.034930882074179194, 0.02432723120305567, 0.05279202667635776, 0.05003847301967683, 0.021554891155251575, 0.09987420087019283, 0.06149362104253904, 0.026054788200605302, 0.029220633141155687, 0.021909890553703713, 0.018310315358722885, 0.08699784866504132, 0.06201480214874591, 0.06669052020316163, 0.04984739153916317, 0.05141275431660395, 0.052596141824558865, 0.039258397845250946, 0.05940953247068871, 0.03823570877073273, 0.029829807106345415, 0.018347225474914717, 0.006001058303105135, 0.029590956213313247, 0.044263081715231946, 0.04398237560845671, 0.026045895835024216, 0.02015752379872626, 0.031368431500008995, 0.03268143342387292, 0.03819957240334442, 0.05098064242291355, 0.012697560690163125, 0.07471248732819673, 0.04270876209521967, 0.05940739508537997, 0.025826714249447952, 0.049974412747448495, 0.03719518133889764, 0.03857914215674804, 0.04367307526990772, 0.03677299794470591, 0.08687523629276023, 0.07253610814410834, 0.054274150170385844, 0.05850597772927535, 0.027926082444948055, 0.047078638698064515, 0.005457488277311167, 0.050596740442298116, 0.030059773294675737, 0.0482981204385719, 0.03133567549558657, 0.016277100770704208, 0.017811423580672954, 0.01128933307970123, 0.03516231723610432, 0.035693905646762544, 0.019223532384081234, 0.07700030932263022, 0.03522440866236726, 0.02749127966742362, 0.024107254801257968, 0.013684805749254602, 0.03865954308440128, 0.04053188495398049, 0.0289513168465947, 0.07433479065976797, 0.06077781146872909, 0.012465002251819018, 0.05133378597336912, 0.01029016098923861, 0.02725556015878195, 0.02117253284180357, 0.04690602759740526, 0.03339616664414925, 0.030067581645843965, 0.05363568866385087, 0.037529877492136536, 0.03512488618012398, 0.022924614229029226, 0.08256207700938949, 0.0877623814308355, 0.0428851806528626, 0.014387405094420238, 0.06222827637928629, 0.07175285218944473, 0.019781868754615708, 0.02158781952945696, 0.09262888602191403, 0.039419709149027066, 0.05830626626829467, 0.05070136123967748, 0.04283959842136791, 0.029095670794166868, 0.015364352974199481, 0.028899761044510433, 0.0307437825587488, 0.017593672664295283, 0.02927423248277797, 0.03726688333817067, 0.023942003890331236, 0.05697404319841055, 0.03727111597395232, 0.038852811745938756, 0.04611706045726615, 0.04763257772391362, 0.008782014446032625, 0.03459096503173632, 0.04783364516052027, 0.035975979220482616, 0.03713771708369736, 0.09829854953192896, 0.09429940968872079, 0.017797798706939625, 0.047825448019730474, 0.08763460562594476, 0.025612636724667206, 0.12048329902632583, 0.013891341138420808, 0.06457940404934269, 0.025686795950957367, 0.005543332259666416, 0.052421619334528526, 0.018850811456720677, 0.011173882671902257, 0.045860624015932126, 0.04783243857203953, 0.01231740775232714, 0.02799238735479453, 0.020933938588226036, 0.019882994275840542, 0.030617770671303716, 0.03465776406829396, 0.0599015792531352, 0.021484144850664084, 0.028630343243299473, 0.02552437190447123, 0.03601267866249527, 0.06400551609394532, 0.09053603340420993, 0.04821460536350647, 0.041182879658956686, 0.024686170208658424, 0.11039922239198802, 0.09651685118555062, 0.025032058906471057, 0.1427945449587799, 0.0029761620493034924, 0.021702797835572593, 0.026721752008363128, 0.05228868775790738, 0.007437001538252639, 0.034271563823905685, 0.036810589879150354, 0.06349540112780468, 0.018973042700259436, 0.04404783399114686, 0.07146934603130625, 0.052286768707657055, 0.04164431356794892, 0.04834243096411229, 0.020308923839982, 0.01965216240815578, 0.018974082664616646, 0.0691486512040419, 0.03210769294040098, 0.04763563824517112, 0.06404305440223505, 0.0017077025122782818, 0.13532661262058443, 0.1843594113785413, 0.1325598860820455, 0.15898452621073494, 0.16775483866372418, 0.15328457158419395, 0.10531328723675783, 0.0845497687377276, 0.2021658075072112, 0.2576266355331867, 0.08575585160043933, 0.16460797929715726, 0.2650257578540233, 0.11326782330269776, 0.0774737056945601, 0.13237184214015163, 0.08453650775575831, 0.12453982651594186, 0.19029507593762493, 0.2349540335877288, 0.11153948298024555, 0.13871420745647725, 0.16961588073642025, 0.1804823936113427, 0.17529588643341296, 0.1423997338861227, 0.10979367585311975, 0.15262958173069263, 0.1521116450068451, 0.1254918286576867, 0.10949877796754723, 0.23872194511275138, 0.10058970400883306, 0.09257600297250095, 0.11092976126218997, 0.13019693384487785, 0.17327845517185428, 0.15140439263514935, 0.1005642622288677, 0.23643819104519584, 0.15775785090461855, 0.1531713437889853, 0.12010053851671758, 0.15009758453215324, 0.10668510556100838, 0.20713771813579146, 0.12849769720266904, 0.15574939819353242, 0.24657629219995392, 0.15709284062106765, 0.12493934136845412, 0.21325839292858878, 0.11484311457963721, 0.12025695068821793, 0.1438126145231147, 0.11431119675117155, 0.09800482376088059, 0.12356334786501624, 0.1456310467854623, 0.26554813788783166, 0.17372897615836513, 0.09301618177203402, 0.08814026962124533, 0.13273181153401253, 0.1149935742479659, 0.21695587032985306, 0.12997554975651926, 0.1008225717551766, 0.09126040784101333, 0.05540924349559411, 0.10259297030467181, 0.30290374952939253, 0.09543283677269375, 0.12247648360508105, 0.29221860030966423, 0.11057428114356534, 0.1673169887714809, 0.08328361692087305, 0.11610224903110536, 0.15227534267450535, 0.2182609470741403, 0.16249877070226978, 0.17051350595729967, 0.1933439986239518, 0.10730802697399933, 0.12394721154123546, 0.12416985967466909, 0.21792317890832502, 0.25429597635182644, 0.10469596592649337, 0.18624843098223212, 0.1771577099157918, 0.1505967367800974, 0.15055982666390558, 0.1522370689218083, 0.2567270491272211, 0.10250618786460931, 0.18880701143174403, 0.07294243351826746, 0.2863180991863051, 0.13373057568265548, 0.13709998359122585, 0.11032028469227015, 0.11403801745825237, 0.13988051503416032, 0.08539284849839826, 0.09549026272349781, 0.14189834466143963, 0.122001409500597, 0.09067284904660718, 0.20933102786300645, 0.11753480280599288, 0.20786452107131484, 0.12671686453564515, 0.10654605294187224, 0.11524094403871607, 0.1062473935645915, 0.1371601827803158, 0.18904068357040807, 0.1632974020415737, 0.09572607990834983, 0.1359857087053599, 0.17332074322527455, 0.10025159876433112, 0.14902199708646344, 0.16612756066024306, 0.09813457607261597, 0.14462112839664185, 0.0814097122319283, 0.1580451491979822, 0.11125685782322, 0.1616774171951317, 0.12076748700271692, 0.12728102700484376, 0.14817346277977192, 0.19116685335193911, 0.22614616750469133, 0.17243418031402175, 0.09552410082711328, 0.19607055151174146, 0.165018173415334, 0.21119596166235788, 0.09549136589010877, 0.13957532092688546, 0.16126651827606464, 0.1440963734902682, 0.24991873381358964, 0.1422689167121726, 0.10451703077001918, 0.1371521082135939, 0.18679482021158744, 0.1624827747864108, 0.07388125894771469, 0.14575510706392028, 0.11159450341496738, 0.13989620451484958, 0.13379717936679242, 0.23446275672364622, 0.15182056223913548, 0.09179724395395288, 0.1055745308798167, 0.13968124024329648, 0.18167425788217978, 0.10807016188459051, 0.20587249328532528, 0.09642973932768069, 0.2023850005841063, 0.22345257171940422, 0.11243028235771965, 0.13542350742124742, 0.13153098403446137, 0.18302808846196822, 0.1245106615486645, 0.13247619863719712, 0.21383328062872733, 0.13561363512229535], [0.1073140177815672, 0.02849025640546555, 0.032123003207567724, 0.051703400414196715, 0.06144490551143404, 0.012975552930466592, 0.010209784001833009, 0.050486948551429864, 0.046264563026207114, 0.049141701986832965, 0.01236093016491542, 0.033620802775746396, 0.043706223894391334, 0.05155653369823291, 0.01611496592240949, 0.04801225472962664, 0.036307817865763946, 0.04670152425645821, 0.022776900985909086, 0.06886361287005487, 0.0816915023531164, 0.018775146867659305, 0.018047367170032476, 0.07236755347900814, 0.01938073745658321, 0.04675205158550413, 0.10196100905417435, 0.05497066198938316, 0.07354625635930608, 0.05409276736299357, 0.022423698063639384, 0.04558646030003025, 0.008097126096066448, 0.08461400521017852, 0.031772012364179376, 0.016340312600556402, 0.041616305393437227, 0.021849363862026124, 0.10839723546298281, 0.037999359154773336, 0.022203219874251275, 0.01139801222785947, 0.059741133628713514, 0.0540894080674456, 0.0283813608374687, 0.02274924329662275, 0.04376811613779395, 0.07836167820759359, 0.06765039006788885, 0.029349797480409185, 0.022582919862602028, 0.00654964812002295, 0.028678522512857473, 0.033103471261359034, 0.08147283021600978, 0.07202596253445072, 0.05360440546346288, 0.049418524027832096, 0.05729227229171703, 0.06452772375797072, 0.0253383963999729, 0.040402216911916776, 0.12305234423688344, 0.06846720067363593, 0.01750227071404938, 0.048587816587138566, 0.003988900120490261, 0.030954816799250343, 0.11664240996563628, 0.04361276116762911, 0.02597163318686428, 0.008281259159106881, 0.07257553868957105, 0.0070790517436821136, 0.038151603807965596, 0.05904180260615484, 0.045789128860398653, 0.028657412960103927, 0.05855931660100337, 0.036848258422387224, 0.01476629398718116, 0.02325580744523435, 0.051552814341360526, 0.04031059279617283, 0.04646028699954191, 0.03946069102253645, 0.031303072708749005, 0.06458299700170755, 0.056671289081174525, 0.09023472336271117, 0.03855996697600331, 0.049702960982798576, 0.04425037997744737, 0.009122736838405893, 0.020741503047306212, 0.03629330433003845, 0.05961592804880873, 0.03606634312159112, 0.0777403042922097, 0.061948133347135406, 0.038369751174844084, 0.03608014802598665, 0.02602375972445213, 0.051669642749813297, 0.026261513196532766, 0.061355368985283765, 0.04882349970660383, 0.05461214816257839, 0.0073934724223950225, 0.10392499036125599, 0.029836426106011196, 0.019483157666400075, 0.0459961373088581, 0.02984777186816979, 0.05910933325668016, 0.02325219917111099, 0.047099648659387906, 0.08927564256854596, 0.01983527848947673, 0.025327581153701872, 0.0692041312915183, 0.06005373580621616, 0.06520571157095895, 0.030091066071162784, 0.030502639147603226, 0.009000969078061322, 0.0717645503520485, 0.06207761752809729, 0.07640290629839705, 0.044804073855160706, 0.024279132372729724, 0.0687761026464643, 0.03297610531350778, 0.026297563379029595, 0.015743816432903613, 0.010020860974046012, 0.01851772791856239, 0.04072573967278004, 0.026954244371623765, 0.027971005840827862, 0.058801296963206226, 0.06069457984619564, 0.06369128597960358, 0.05921905236919561, 0.0028308641377671234, 0.03747265838507203, 0.018135729666438796, 0.06619306100953011, 0.027610059684863495, 0.03357822360891489, 0.052523689059120034, 0.021974904605397777, 0.04766291480571513, 0.02014124059989568, 0.03929274156689644, 0.024185803711354256, 0.04880284214572561, 0.0334777320254474, 0.03415568536447902, 0.05708936624409211, 0.05770954506231412, 0.03987324086108035, 0.04334094168077554, 0.045733208272365794, 0.012018552065015802, 0.04578115388510689, 0.04658656510254068, 0.05004873093698294, 0.07531235715554607, 0.03904983423830521, 0.019736165864272945, 0.030306285066950708, 0.013585029500386408, 0.012439819026528107, 0.06005943550037281, 0.023814955868968563, 0.04101576140871452, 0.019908518410257755, 0.017271482896420266, 0.016483341216019565, 0.030388472894687327, 0.032418144326056206, 0.044806023548928, 0.07779330225481142, 0.06113150660249014, 0.007364182008220064, 0.03617246162086245, 0.06061931936851433, 0.0010831004939034522, 0.05335102954338636, 0.03753512519441786, 0.06062726753072874, 0.03424320324894882, 0.013692292343494634, 0.016795326692743168, 0.02967757394447202, 0.04959402711040551, 0.03835351777172858, 0.03725961699420887, 0.05998563825062687, 0.029385087320641167, 0.019632129208935846, 0.08517773867013954, 0.043854251233560425, 0.020519193907779072, 0.03773370667571022, 0.03310179352880486, 0.04350771519145177, 0.03238955392472206, 0.07991515130044953, 0.022794273944811958, 0.03280118445775682, 0.04487119464864654, 0.057878241453680306, 0.05470993928611279, 0.020767710915195848, 0.05255456623290816, 0.09842987232390912, 0.08946243778712328, 0.09123855901341285, 0.059100795206764055, 0.02861645406923227, 0.03338135050369367, 0.006074381057142971, 0.04279024703728576, 0.034412393767026164, 0.0218694219591036, 0.07326471138625376, 0.024592845377722578, 0.03221831412144727, 0.043605632719493685, 0.03778180167559655, 0.017749558150347684, 0.013987768625449992, 0.07468375903103622, 0.031953770554654544, 0.005317071064059893, 0.11125643647486165, 0.06586699100631861, 0.08762693708582271, 0.01247947269509877, 0.07556064625180538, 0.031139708289335814, 0.04359681887792484, 0.1117021234465703, 0.005117284909506599, 0.036766742836804166, 0.02062109892346686, 0.03932990449210329, 0.007402373406465256, 0.060382333899577784, 0.08206341505771683, 0.030127989593893293, 0.011571633606968869, 0.013214148141654029, 0.010631482845412628, 0.05861031890456235, 0.014560300605221382, 0.04239192345149575, 0.028007314577999137, 0.03442416853842235, 0.05758810097411756, 0.0656170548210221, 0.055162662775405956, 0.026679147943674077, 0.07501390462200488, 0.06766035687178373, 0.06533691178887122, 0.009871227723065644, 0.009162153977329933, 0.038690688388962904, 0.0024568640829754937, 0.04631566875163586, 0.034826341716031876, 0.06807576038784559, 0.07194452738809971, 0.0121359579122415, 0.02223865718640868, 0.08115776889627019, 0.03712655135220097, 0.042119885629583756, 0.012753041735249422, 0.02334266649408927, 0.03586129968865745, 0.014581997172846911, 0.0147190704123087, 0.04244014485588959, 0.020652543002318953, 0.021097961843254107, 0.06760021130884848, 0.04556825805094935, 0.03498807436816635, 0.07138659321372548, 0.005284110609922679, 0.030308658024296168, 0.0195037616011236, 0.045934536178866704, 0.058745655997265736, 0.05147565013518737, 0.06586162839084864, 0.0354152909600206, 0.05868129695074693, 0.02758157653583875, 0.07834844020826202, 0.001867830569315101, 0.03536890433620542, 0.0157336839624951, 0.01945156611562256, 0.020308249682608633, 0.06283335560452073, 0.04356614088699703, 0.07096699919671783, 0.03866228950960982, 0.01855572204916708, 0.014515302515768958, 0.04511912368358143, 0.028631902232225385, 0.058098380649161924, 0.055323790218080246, 0.07980486528287012, 0.02102419332180533, 0.0502133249275146, 0.04018215815566721, 0.037262796259094635, 0.009366679343304807, 0.019511742322074793, 0.06498328560302336, 0.026630254297126687, 0.030982359575348038, 0.010126200936464293, 0.04981328147433458, 0.03376731326082542, 0.005178699305566449, 0.018324865283624783, 0.014039583939818606, 0.0330983997593003, 0.021610530205972252, 0.06626336489834132, 0.04371513732739034, 0.0277425354391697, 0.020097908751678564, 0.018174480308868715, 0.01771043595527449, 0.022065168915076122, 0.029208383395246444, 0.019968436062035542, 0.05457703452256899, 0.04690164557447837, 0.04782100087933002, 0.06652665399615804, 0.022426750924017642, 0.0416730878303849, 0.16330107926361023, 0.1230849106345446, 0.15428486790868545, 0.11647069901828805, 0.13655943195185355, 0.10668954887096921, 0.07988005681263824, 0.18422128572579355, 0.16063293291916772, 0.17451588635242757, 0.12679199477837932, 0.12714995702187862, 0.211179337554401, 0.1892980891129663, 0.11661510659201492, 0.13372196485438656, 0.10710236300984699, 0.11128482003245624, 0.1206206202867531, 0.10644931901967335, 0.21173799951230327, 0.14264621501488073, 0.19743688464645417, 0.21319793326960457, 0.19963270714206083, 0.18449375255694314, 0.27294814887066043, 0.1140339418704952, 0.13675440132858294, 0.10110312081392735, 0.16229949591140594, 0.1552146535006262, 0.10707347383422237, 0.14473192003225127, 0.09360739480583899, 0.10576747012354674, 0.16169592587938234, 0.09720416228857734, 0.20583438807197157, 0.10772742946902591, 0.12377716300468292, 0.16939866416636976, 0.23950127103636343, 0.11744782118307007, 0.1460621397822134, 0.16193750404542492, 0.1619857675846546, 0.1502616805655341, 0.15210272774340647, 0.0934262226726259, 0.1273608227230368, 0.14623029608159296, 0.12217200195957577, 0.1747735217213631, 0.16058718214832968, 0.13568106618139053, 0.1641052877230029, 0.12524703292236214, 0.2274879551823101, 0.1138875960943199, 0.1421253824786794, 0.12333737490999123, 0.2470524464884112, 0.21546359234038862, 0.06063462197480183, 0.18830367634373327, 0.12477185922644793, 0.08684529757667935, 0.2554098069066963, 0.11412425597588863, 0.16042861726976212, 0.1031656823151054, 0.11606204473683912, 0.11147480217679856, 0.26637300007766296, 0.243807420615227, 0.15356385659786964, 0.07570255637889908, 0.11629749419948748, 0.10564353241915665, 0.21474697837425819, 0.06798338550593584, 0.1450742234385783, 0.19737843213783157, 0.11413923299480831, 0.22729654045354938, 0.14896739033922074, 0.2245019436363251, 0.1139059055957102, 0.14793026050732982, 0.22107734675368956, 0.22787363448690987, 0.06527053793111155, 0.09718007648423796, 0.12298159601707613, 0.13364589232350552, 0.2111270443926896, 0.1103533337253236, 0.16611001724677701, 0.17377599863515747, 0.13923951394615636, 0.22061508930017873, 0.14244258884460698, 0.0843078151886021, 0.1375014443070658, 0.18950680210705728, 0.16239893412397755, 0.18650393662673814, 0.10526271011199682, 0.18807631676956532, 0.191286776755606, 0.09541306404336806, 0.17323036017196794, 0.12153048759266255, 0.35627295833922207, 0.06949013489628993, 0.1543551794583759, 0.19245662365949925, 0.09676807439855992, 0.1680399459456244, 0.12131159329005789, 0.11941727235793106, 0.18501768008835856, 0.1529940557215483, 0.11768150098261335, 0.2191576376677521, 0.1515735142053135, 0.15432200785125458, 0.14905489290193205, 0.14034641906619072, 0.22401190783467986, 0.1892513424278267, 0.13797957510236772, 0.16743905722133576, 0.16257324977026832, 0.2248492725794354, 0.15750965373891015, 0.10912488109522289, 0.2597473201251799, 0.12379328915548903, 0.15741628294269885, 0.11761823744182626, 0.20122005664292844, 0.12072013510811715, 0.19923647114586449, 0.090539411851956, 0.11894802052167155, 0.1469620479451072, 0.1458067413900168, 0.11548318870125279, 0.2235677760214575, 0.1397598102208107, 0.12066081692014011, 0.15570288133477012, 0.13367883410424958, 0.17648712251215212, 0.15436172184924926, 0.151220056558809, 0.07765752083111195, 0.15187679309277766, 0.21766137602108143, 0.21379653905187884, 0.21262310685649996, 0.11235619399456248, 0.17325620797853317, 0.22555925222414158, 0.16430178927558084, 0.15686604795196366, 0.2825072714157643, 0.12326741576074593, 0.14557784964000026, 0.1377153207337664, 0.16919594197984666, 0.12745167308997724, 0.17179129464972406, 0.12053061261652939], [0.0021065991078954073, 0.01761070279885204, 0.03422927194004578, 0.05274811068609838, 0.029983560952748504, 0.08166633636480378, 0.019875877319023978, 0.035580348433746446, 0.1170337736426342, 0.02501625259737334, 0.030436843686226397, 0.02528507285000336, 0.06035351750230598, 0.02131399480746158, 0.03211687450417348, 0.0609738763511902, 0.07508963241332, 0.09429365636840945, 0.1232008503810052, 0.007718544117280192, 0.026252820013811993, 0.08046763858968213, 0.01973617735559181, 0.06179901816311383, 0.028245018254364693, 0.07457914206409648, 0.01248288753202125, 0.08653457231459119, 0.04937837719016018, 0.062383604536373774, 0.07495074067264795, 0.0240062307866831, 0.03738160117439205, 0.037372649436996835, 0.050449490682372165, 0.043838810731446555, 0.0857467198323819, 0.0629324643992849, 0.022470730116530772, 0.06702030573280589, 0.03784788058950536, 0.031793246406220624, 0.018553958131721424, 0.04046537320039446, 0.02784425659375566, 0.020510642451324293, 0.04031967093807556, 0.06327440008340825, 0.02738027161197557, 0.016854487832695726, 0.028994709981845754, 0.036364075532483484, 0.04509947735876326, 0.03163905014404126, 0.051969186958646586, 0.005171144721023138, 0.08766468223785201, 0.011270326438299831, 0.07338062815007663, 0.007046198063049346, 0.04726773601085429, 0.052345631073319146, 0.026035394684802142, 0.03648466543264447, 0.008081382989222485, 0.06609542310358056, 0.04044571538425742, 0.016401930967526093, 0.06405102554708719, 0.027740244836276098, 0.02373096198895045, 0.060367333898020376, 0.05419179188808607, 0.017620414878512104, 0.03187477156790274, 0.028633375036259814, 0.05236776718389123, 0.022640811211820093, 0.036137822955366106, 0.056539870528203834, 0.05184775436176889, 0.044569022758232976, 0.0173938347988071, 0.10015605227841486, 0.06151321757164213, 0.058959248971434376, 0.037368370835939725, 0.00865054035168742, 0.10799467158053191, 0.02741508264725487, 0.04054038852994, 0.02023353695779318, 0.09730134054177231, 0.027422574987154336, 0.032581485762831666, 0.04153693102360253, 0.03541857747721576, 0.00995402171787235, 0.023266032803803686, 0.04365982960969691, 0.02848449733949477, 0.058715196341396346, 0.04363407756412222, 0.028678886404621507, 0.04383566977095701, 0.04237287850569814, 0.028846971840868076, 0.11412672277900482, 0.03852434005708464, 0.062369849427693316, 0.010971836557972335, 0.04940258939900706, 0.05515677538970786, 0.023578341952675295, 0.07482143269190866, 0.022342303136904395, 0.015386265961663618, 0.05085878464723787, 0.026908158437318863, 0.05928383659451239, 0.025784169556573037, 0.004725343314930797, 0.049051039311433994, 0.04425978753715754, 0.02371517291683103, 0.042013996956689705, 0.017825504276721228, 0.029116100443887617, 0.024019654562336304, 0.026045700482603525, 0.021771167352375005, 0.026270311716343128, 0.06864684063100046, 0.0355360800430419, 0.010874861318077291, 0.003120468116380395, 0.02217574987650639, 0.029373308718805353, 0.030264487309801965, 0.05207589917605923, 0.05740375340645833, 0.045553430419174895, 0.024062342896697023, 0.0323973833433082, 0.040446960277134375, 0.05098801218874512, 0.05874725329058786, 0.014667996288006826, 0.022204608408614032, 0.042543988074025804, 0.02843410982149503, 0.04896310007860584, 0.09244649580890134, 0.03378820064808092, 0.03480761086628322, 0.07616517389373434, 0.03651166620153574, 0.04689225716696632, 0.06916352097065219, 0.010165292488020516, 0.009006179433556335, 0.04431308044361011, 0.05186907075826199, 0.05321085077500152, 0.018697465552137266, 0.014022583491168918, 0.04960262261691594, 0.08849843870848419, 0.06281533338610204, 0.041435286477808995, 0.011430091202078808, 0.03634585796164409, 0.017515133330298048, 0.09845058734138167, 0.013383597214405817, 0.03988221941155292, 0.006575920147776243, 0.041740626141789465, 0.028760760136309172, 0.037535860638825164, 0.01468177437932501, 0.08157930877660552, 0.030761659220461885, 0.02806164936402873, 0.05925656769484763, 0.03163527524579437, 0.00891473247564488, 0.023809750301523075, 0.046538546711446784, 0.015804647644531104, 0.04004503607810025, 0.0394186059824161, 0.012065613803814256, 0.07477241072563395, 0.04948774773267008, 0.047016106771245125, 0.025858416882974487, 0.016126673661112305, 0.016106891355687575, 0.049424480361443375, 0.037140605235171896, 0.033685292057212324, 0.03376191234095924, 0.0731191776632782, 0.09216236911954419, 0.03130142178927218, 0.07059099558260172, 0.07044664163502955, 0.029137455144776937, 0.04708009426512065, 0.015547648128572733, 0.03699917774347048, 0.0775377429841507, 0.030082518445147626, 0.07044756860141793, 0.0043734178442748324, 0.07488033719240658, 0.010800966392121008, 0.02672096293780112, 0.04025427384241935, 0.045641235586616306, 0.07100297468564204, 0.048201819356050224, 0.07280618478093417, 0.029164842788069963, 0.05452614330175904, 0.019865659621333884, 0.07170858762917981, 0.014108576860669401, 0.03897566160547637, 0.04192137309620458, 0.06710406212556748, 0.04368142562828237, 0.033022254450066436, 0.066797933391025, 0.013400165780988193, 0.022672207410176917, 0.05882889911111805, 0.024336362971113096, 0.02568546487318893, 0.08620323162646064, 0.09825757914973844, 0.0505544638801967, 0.0381300920590518, 0.016843860277966145, 0.06915757612835977, 0.01772198281551321, 0.057642064207503875, 0.09791970373161378, 0.04920318820363572, 0.013703206223585914, 0.05661468284444944, 0.07307301320496105, 0.0017765113326247723, 0.016037287479717166, 0.028247174791871544, 0.03798349730430111, 0.044378029377830606, 0.027248525556417245, 0.013208530801949243, 0.06565996340566105, 0.028554799313086177, 0.033159407171150374, 0.002987550903907827, 0.03951935803577785, 0.08058152522050566, 0.06128622955011745, 0.018758068852607283, 0.044767757457110195, 0.07496308234910812, 0.012644113608515792, 0.03137434761400425, 0.06959822224152666, 0.05025786527943227, 0.004279076510424456, 0.03416490523264774, 0.021327234722012957, 0.025963570111461227, 0.0888573355792511, 0.050795164875566005, 0.013910909896836647, 0.054087324308291565, 0.0381482215297799, 0.11977562530627174, 0.05591435207714958, 0.034198356461861444, 0.037091115955263376, 0.024766048281303337, 0.057955915108323104, 0.056991107806923895, 0.023167762875316605, 0.04737811395898462, 0.025928598197717822, 0.03359765159867464, 0.07937238566697606, 0.03311736809630548, 0.04870685515925289, 0.049993369593134815, 0.013970001131266117, 0.043613113568074284, 0.041915914719744075, 0.04862227139153308, 0.1185286793136789, 0.0278504389233046, 0.01498503986025049, 0.0558108919029755, 0.0544336075413852, 0.025009116488358667, 0.04575323764114611, 0.014098137955091173, 0.029935600018248926, 0.04780356854861302, 0.09597783938290612, 0.03273887852687509, 0.07379518130854254, 0.000524620721285652, 0.05057778742705142, 0.018253123064735727, 0.04191732049108513, 0.0356442861319069, 0.04270519595593215, 0.033414334419273564, 0.033254681695853515, 0.036598816363801884, 0.04225889228344445, 0.025779172748086915, 0.07452436677751041, 0.020944368875315113, 0.0660939445538867, 0.037979789438747594, 0.014695035361294306, 0.06636007583790249, 0.09290322210759887, 0.14496013762489443, 0.03802848198721486, 0.018326872433986396, 0.01649020727904093, 0.009006873700737713, 0.027672635661738536, 0.014372490320144402, 0.042072146860582214, 0.010602467265280505, 0.030439486689565164, 0.04062313751708116, 0.02354511480417944, 0.041405320948650765, 0.029550250131456606, 0.04090107804644973, 0.0719126351478119, 0.051793450219256264, 0.025885295077797868, 0.03553676952217375, 0.10045482656888424, 0.13780300715757957, 0.06687491756653594, 0.1553132030512056, 0.11189575216943219, 0.21157839275415868, 0.20591911739639698, 0.09127569129510273, 0.2153758599513, 0.11163136756588375, 0.10853529982869664, 0.052472004937308456, 0.14016680209146393, 0.10278050096765642, 0.08493883415095269, 0.15872120646940124, 0.19444166472361935, 0.17667055460474185, 0.187238201258644, 0.10779221752478231, 0.25973723840809637, 0.13591339000530783, 0.1290432360744284, 0.10811955923394811, 0.13015695937698887, 0.13993032607099704, 0.10631794260153848, 0.14632011222983562, 0.1911909391562785, 0.11962806145029685, 0.15078387673824065, 0.11610943493583512, 0.1366772562746079, 0.07667005647935214, 0.11984370754010255, 0.1267737005987475, 0.19192908019308122, 0.19075284411589946, 0.11184549680159939, 0.09445052819266435, 0.26532894481093655, 0.09173271636809073, 0.1945930283756987, 0.20331656350003136, 0.1614582087964781, 0.2044144594260762, 0.17880217893229378, 0.16431407732588632, 0.09842698417243459, 0.13417726622954493, 0.06744181496962424, 0.18095068783769686, 0.11455674325266194, 0.22778113703093222, 0.12386898630328717, 0.11692697332511026, 0.2632002009739799, 0.17443405284035593, 0.326602648823492, 0.14723272213051397, 0.16572989974050753, 0.14874421360511936, 0.1333235838120022, 0.11501251960233336, 0.1656669119913732, 0.16956896551193731, 0.20623494480406085, 0.1221553089037057, 0.13994647520444087, 0.2355982675667732, 0.0696595629016238, 0.11718224148235976, 0.2299381648340533, 0.05543655453009471, 0.12279463992003473, 0.1831155144158871, 0.11167856624289868, 0.1048742805517489, 0.23644323190373762, 0.1721877604722977, 0.128170631285156, 0.10270697950956323, 0.106188029411339, 0.16448002729204395, 0.30139575141572184, 0.14014984090482036, 0.13330823140999964, 0.16276201383481104, 0.15084885631597814, 0.19125208829439458, 0.2499553068510948, 0.09570377908887402, 0.1562371816966803, 0.12059026788319312, 0.1415582016230591, 0.17786533000969118, 0.15740561899879288, 0.09322464195710999, 0.13712641362461353, 0.16393054306747454, 0.12921260279272834, 0.16262387286030477, 0.19866840162825203, 0.15589703865829976, 0.08450815484168069, 0.2367687120192474, 0.1114097536511479, 0.3714985881120928, 0.12198457088802131, 0.12433901188835023, 0.13277056026122264, 0.16063045079429306, 0.1555392602759023, 0.10315521755405974, 0.11441032852857344, 0.16446556355203354, 0.11332205466685757, 0.14148232827503837, 0.21031077770936876, 0.1793896611179075, 0.08936739691923704, 0.1469966444757677, 0.2276324240430709, 0.18052972252330474, 0.12399500010595207, 0.18375757270522658, 0.13726617870551927, 0.13206042739893162, 0.103803075128986, 0.0905655584328117, 0.17250104446805295, 0.16931502268679682, 0.1287966630151195, 0.12241779360920192, 0.10639098908511863, 0.10353679062738534, 0.2217648034134219, 0.12718186458392491, 0.29083786472197504, 0.06778856168591207, 0.08391937030659569, 0.10658118573407974, 0.09451773708626147, 0.04925839632989899, 0.18702222575103084, 0.16785294388330754, 0.11103578783091038, 0.1409368123859167, 0.1588254863576543, 0.08466757007784421, 0.1387137324819642, 0.20215348881338874, 0.2552055219008077, 0.12600481645354342, 0.14231485134411243, 0.15437414779538108, 0.1597524374242752, 0.22108819455869738, 0.1510064559237611, 0.08441808588442304, 0.11292905922258094, 0.10561920146668151, 0.05832739497324633, 0.26285668714873256, 0.09397057410810264, 0.12104495638801206, 0.12213585793130821, 0.12115822248761693, 0.24253891690844492, 0.1726040526503517, 0.11156919953082839, 0.2081647968941158, 0.15742336159511922, 0.18074859384327166, 0.19539590384210312, 0.13916226163987191], [0.03559859664810281, 0.041196584971922065, 0.024046540418038928, 0.02025745996844865, 0.07719733181499666, 0.0731904621446325, 0.0020428605925952715, 0.03744321762614193, 0.08795501423939582, 0.059385982927896326, 0.07459614155513626, 0.06371247980202879, 0.02161081557372405, 0.010433382084292751, 0.05205685423026162, 0.03395112073649803, 0.09516675911483266, 0.031587107467555234, 0.017673958678759875, 0.04170196168425103, 0.01267616385443797, 0.07288004331771405, 0.033414813224226236, 0.025736852135929852, 0.05447988691289098, 0.023596645708406166, 0.029542114277700746, 0.029201199405736504, 0.027707207294541503, 0.02029502892025536, 0.09968133057437598, 0.02412728033959866, 0.04378585873412029, 0.07593016876208206, 0.03878400555901951, 0.003918056618497377, 0.04992391989235917, 0.032820704378067486, 0.06231698553047835, 0.015440032885019338, 0.032723683172896985, 0.037144554418421565, 0.05893070070493606, 0.007150956277450126, 0.013328957908426323, 0.06087879334846812, 0.08981869165455142, 0.0242886854891455, 0.02783756098529745, 0.062062295769611676, 0.09961595263091788, 0.08257814187316165, 0.03849489929815454, 0.04479262850157196, 0.03487630980089307, 0.013660424043454472, 0.021734082951180397, 0.002814751393499694, 0.017201121551014723, 0.10892505472105359, 0.034387162661239985, 0.0506116638350631, 0.07276277823914444, 0.0025353394965115456, 0.06494980756073229, 0.013504527066083205, 0.06288870545705, 0.04247207923101322, 0.014025260010854372, 0.01846590781614425, 0.04919905515928422, 0.03085543987371268, 0.041994534492973364, 0.03257824138047234, 0.0941113121206722, 0.04061540002904592, 0.06459782080304238, 0.035052693884579406, 0.11963422079720806, 0.0487448531202972, 0.046396609771275715, 0.0736491343066577, 0.029033587028783177, 0.039304527829611496, 0.03604426063717373, 0.023330958755386454, 0.08157622910314992, 0.05290205605448254, 0.0038356961815753173, 0.025071081510114095, 0.03132662225154138, 0.07080073513451123, 0.01598447720865689, 0.12811087642706212, 0.05703290556407264, 0.05498863441208678, 0.008242543948243463, 0.027368703684318933, 0.04424040168223362, 0.07140742314438667, 0.006904015495937559, 0.008602443436581281, 0.03714230978080342, 0.026873808970013936, 0.035012983717024326, 0.00716531946842048, 0.043479270346823244, 0.055776368150667804, 0.03163117667539947, 0.020698672986679503, 0.014239812510148173, 0.01957767567927799, 0.010315935059841122, 0.02143505968213562, 0.026615409428373944, 0.01860436288669946, 0.06428007051468858, 0.048464847983972686, 0.002220366995090679, 0.0316986900889465, 0.09333406229533496, 0.03141950275148115, 0.07798175988418442, 0.05322664367756056, 0.03887169964371189, 0.04840581707896725, 0.059741501350917166, 0.024242193528240728, 0.047593453613620613, 0.03657717054950134, 0.01884172756915852, 0.011015107119155508, 0.03428540703269743, 0.04890669685518069, 0.027455447819985213, 0.030419951447496013, 0.021407530312576604, 0.021725249957413446, 0.06136858783241722, 0.017385620421039003, 0.0305385725016916, 0.02961773290148666, 0.05233285655718177, 0.051375560747880133, 0.027475310564641992, 0.055111281258324464, 0.02057788773409782, 0.06012299781545036, 0.06795722360332167, 0.023440808102849032, 0.08429498321587041, 0.02803646996917744, 0.07575146343198515, 0.05737179221825735, 0.07399078653824907, 0.018539942553146713, 0.045174684210289875, 0.05108731250549036, 0.025666590381954468, 0.07805104487605634, 0.04356396902773169, 0.03285166199108766, 0.012889290472582705, 0.07434471149838741, 0.008536816514547794, 0.029109176924271934, 0.047096388955270095, 0.03200379609611006, 0.015028971172268353, 0.016343738928797747, 0.013513739273372679, 0.07913356541746086, 0.01981663765505918, 0.0690714601847914, 0.04934295711498107, 0.061662761764901305, 0.012842154997821539, 0.056102399849483085, 0.00908312626228097, 0.04467460116551769, 0.03673320350747916, 0.01223136458711158, 0.03727621045864878, 0.09825505105958832, 0.021564243173587228, 0.08691888798268572, 0.07736702795110403, 0.03330248175188899, 0.018544339897832083, 0.009759952494454001, 0.027527151734478054, 0.057889411015616316, 0.004149571262044652, 0.04208072321489454, 0.04325878258133608, 0.03545177589741445, 0.06908425385312689, 0.039258152697115176, 0.0867917403698929, 0.07463476770827848, 0.0024755788927582367, 0.061777180826832215, 0.04147972340785688, 0.13173859386194137, 0.059026197395137245, 0.14472451962290273, 0.0210685555582806, 0.10697492428364293, 0.028297257789921378, 0.06057212452193903, 0.028603918955571232, 0.033662975915978034, 0.04579362196607455, 0.030714533321799773, 0.03775730218377806, 0.11846075029743296, 0.07479675699986758, 0.006353967239133894, 0.04645846754072174, 0.06078741438085995, 0.042181666790237354, 0.053714254810925455, 0.01948716047580444, 0.007614303491033254, 0.057657918397096865, 0.04586353515004439, 0.068243280834248, 0.06871504543889916, 0.044327850618790236, 0.015589419072644125, 0.014317070562092048, 0.02443763021860392, 0.07584175455474085, 0.06642972089109883, 0.031092607288531242, 0.07481716558217041, 0.023753883339644923, 0.05184107024462954, 0.04506873425036188, 0.06393180694431067, 0.04847439343950922, 0.031882838473745415, 0.03363373050946863, 0.007203832144788917, 0.0217677659219912, 0.02355661186870308, 0.06608178673852837, 0.09442849550396205, 0.006843563976637539, 0.01741404611346943, 0.04522368702436647, 0.08154091244984059, 0.07513333772940022, 0.02842807113343189, 0.05693203093664301, 0.02116778501189284, 0.012122578186643942, 0.06479839028249826, 0.009382374569653504, 0.035834241463171865, 0.06675724646136647, 0.017518845026291186, 0.013501701159252515, 0.03746916502413731, 0.049892226834931684, 0.061349056420787695, 0.09664951463139827, 0.08790861229382216, 0.06620555590357512, 0.03687918539189043, 0.060290598701084816, 0.0401164737770394, 0.03059551390188356, 0.10274277113738561, 0.01797712073781558, 0.034058484128646316, 0.035413831562524846, 0.032034996942046194, 0.045555901052730705, 0.04486203989795139, 0.0406678349170233, 0.025391924878462188, 0.017351835943578232, 0.0218579861816139, 0.0367146871623493, 0.013197845790625341, 0.11696090335927664, 0.023768703310540127, 0.06577480764638993, 0.08993447818342717, 0.01754703897712452, 0.008756808238103986, 0.048274467473909746, 0.068528349811752, 0.06026391585868213, 0.0076728757008940225, 0.10263970166805292, 0.01107950351246062, 0.0743194765621616, 0.043550593132573756, 0.05736513491419535, 0.04039019316194519, 0.025555059471498096, 0.028547912182646896, 0.0439719568126865, 0.012335017240876633, 0.056243413653705394, 0.02335380541250831, 0.1058656442910433, 0.02378392164715596, 0.06928670024799724, 0.009177292832323622, 0.01899309505167748, 0.05021541251710827, 0.054391361622800755, 0.07627586593791362, 0.015038858494541098, 0.020926944205477353, 0.04556246642624179, 0.019322761837693474, 0.012029505207113201, 0.0278613556762256, 0.13748241468302666, 0.017647300734214725, 0.03584220877758438, 0.03368331171992806, 0.08770519296728796, 0.017080730833714048, 0.03362368709678131, 0.06769088547556631, 0.03160490560525608, 0.10849383148935535, 0.04616849560050234, 0.030862095262554866, 0.01646549136738383, 0.04059086223283122, 0.06749482825398445, 0.015723605118241283, 0.059909642328538244, 0.050720337237561905, 0.037873808835302634, 0.03956583659014395, 0.07283481348666453, 0.033628455994109956, 0.11172397993505002, 0.014685971583540161, 0.03351665312244046, 0.02727064251479122, 0.0313598053499816, 0.021016293040086186, 0.0602789081993603, 0.0694498080279558, 0.17075275521605246, 0.22641206130145058, 0.0743227324358398, 0.06384058502472698, 0.18617408981005992, 0.24087160315004089, 0.06722947837965143, 0.15985182967157135, 0.21620191723829318, 0.21135065013602858, 0.10440993933908402, 0.20668407151054954, 0.12041671066394738, 0.1372391051582752, 0.2417937278627388, 0.181250779799396, 0.18577181704102025, 0.1289452074636375, 0.1186112023048824, 0.12501875404268503, 0.1271078221860432, 0.29825472963913796, 0.15600951568734261, 0.18471918158954193, 0.1714261311797365, 0.1666202624478648, 0.058902378434375416, 0.2934434829700378, 0.15159372360475604, 0.31647867433005766, 0.14725890701576588, 0.17515448192434926, 0.1424073947653655, 0.23382472805678847, 0.20975735579286853, 0.08030277646837697, 0.10131443850696088, 0.12783284013670299, 0.21555046671100203, 0.13121402281666958, 0.10526095577065023, 0.1355878179592471, 0.16630985894270484, 0.1512235499197437, 0.17938472751167514, 0.15418415799015953, 0.19954898905369545, 0.1051005752637021, 0.1770437619979343, 0.22178554907441142, 0.2010076817485594, 0.2173111053003419, 0.06617758603345963, 0.06374689247158748, 0.1448598720373646, 0.1045891962524864, 0.15478538379313486, 0.14537664430756725, 0.12004260694788349, 0.21176816805476145, 0.20892343844377229, 0.1684400583467176, 0.23969691457046619, 0.14284034169489337, 0.1762561163594646, 0.09562868715053606, 0.11181696002641994, 0.14181196058709777, 0.09663155753045313, 0.1048965813712247, 0.24486489774238682, 0.11178628586593176, 0.1628548943347508, 0.17138491564941022, 0.2500805775484731, 0.18588064749154354, 0.15957329542406146, 0.10483359362209037, 0.22887592264000448, 0.14115326286804292, 0.08145533276781922, 0.19062925881195456, 0.15117219138529994, 0.17405934391483185, 0.12624144569159518, 0.12002087303347166, 0.11948392966822272, 0.09423257617820656, 0.15904968964957422, 0.14033603091393748, 0.22312254104162418, 0.1836375267274918, 0.13495889041692982, 0.17993773574069624, 0.1527690710199456, 0.23433956978542192, 0.10671416327597634, 0.20595634926951703, 0.15978291240190307, 0.13564643900721304, 0.15754526150563072, 0.12657177514366566, 0.18171026401462095, 0.07464430550293577, 0.18371592816566268, 0.12948644858214164, 0.10587806257629588, 0.1571860428779356, 0.1464363737332244, 0.12818636673112072, 0.19680732891203898, 0.0637305747988003, 0.08681551973906257, 0.22158031411949666, 0.11600903145247891, 0.08720811681761857, 0.11947279841068292, 0.14234338045841263, 0.17100436913390316, 0.08970512678065608, 0.20798962322934983, 0.11991421061177408, 0.2232918311511317, 0.11931688419633335, 0.2305502690855534, 0.2133559159213497, 0.13080952839264948, 0.1033450311590587, 0.12134404477453041, 0.10934199041296398, 0.1536319311708212, 0.09847918540359506, 0.16512009375278028, 0.17211456843201192, 0.1691706610783454, 0.08881552250034387, 0.07914419871784988, 0.07922322834811865, 0.17285188209385643, 0.14979721677880134, 0.11310509856670134, 0.12821407613134192, 0.07932848882891479, 0.18229937030663415, 0.10858943926230555, 0.13313106591663054, 0.24115260420066698, 0.14128852335195388, 0.20604746776723093, 0.11142240942365701, 0.13268815984408702, 0.09953313086542392, 0.136014896655275, 0.137235029570518, 0.19578532165577336, 0.11946288523294273, 0.12482381530947263, 0.08240765666649227, 0.11238000400724912, 0.15364143066108227, 0.1429993049391816, 0.06959334992232823, 0.17148458368835912, 0.14800031158712604, 0.12102730572223665, 0.11096631131705739, 0.15093191556872862, 0.12605868775637882, 0.25125728860016794, 0.10888850466618616, 0.22197077381274394, 0.10694074910134078, 0.09685341659332476, 0.11724210359276303, 0.21057880123055753, 0.2508071813011362], [0.026828079266593825, 0.014012028714792143, 0.05288796769755502, 0.03631499994005408, 0.06603424332194752, 0.0455711845068201, 0.11955702977795755, 0.040239676037022186, 0.03169370860221886, 0.012989322403295627, 0.014628409652129538, 0.03076158452688927, 0.004160126038421427, 0.02818418512751739, 0.01896427865440567, 0.039079815089221925, 0.020165127221374743, 0.07290392993919312, 0.06723681750196604, 0.03212160892754553, 0.02986935639543639, 0.004428662359714508, 0.0336889386357319, 0.09835423646314491, 0.07747711478582314, 0.04759556418585201, 0.043894991789373665, 0.023484565129864122, 0.06030813828411122, 0.006647675294399022, 0.022217097556999615, 0.029316886343182098, 0.022952036346278848, 0.024041830892524412, 0.035988604349474755, 0.024133081540405273, 0.07823594785746067, 0.03809274527274313, 0.01072255346263128, 0.0294287983823808, 0.026836764788435354, 0.03701080695816106, 0.08430829016311515, 0.011656063199493916, 0.04936372958904794, 0.022488248632139256, 0.029173396159744555, 0.054570155053008954, 0.04740758919187131, 0.06176419180607604, 0.04304486401979962, 0.03498693672759879, 0.05162192696344949, 0.01832243870012462, 0.03416966646909714, 0.03899271855311048, 0.04214103731717314, 0.06846978238994075, 0.14850307977007282, 0.08217606062610304, 0.03315209103147349, 0.030741721782232487, 0.0491245607695272, 0.018144687149493445, 0.08385166345584778, 0.028002576324187463, 0.003845044608873826, 0.025697611197228395, 0.053355070657186934, 0.0373100753753416, 0.05052229967869578, 0.00977305164034929, 0.03622331453727619, 0.0702121421214073, 0.03341918375583426, 0.08228826186349315, 0.03979798421383866, 0.05416468769732503, 0.06443767012247155, 0.03427438685790666, 0.04353847745205126, 0.13868246077289506, 0.07328837584223478, 0.024340216393372225, 0.04781689464805588, 0.03504770665219234, 0.029831785528409867, 0.06753561477507315, 0.05374734214837513, 0.04347278924298383, 0.02156528696838406, 0.03820188598887574, 0.014474671127484932, 0.033153401041824015, 0.03011121418357136, 0.03651076604822471, 0.026456917328159177, 0.04233579601972334, 0.03903316033463325, 0.04760570335952986, 0.06541989443282928, 0.014902615502867249, 0.03512425798802607, 0.04367964830429804, 0.07464103430749909, 0.03296515408663019, 0.036567471876379945, 0.006002490887523539, 0.013049587667469057, 0.009524677316808413, 0.039282583241020484, 0.08884821913295216, 0.018819256295119564, 0.015244423824873184, 0.024714222433225765, 0.0743034576636649, 0.03265382744552147, 0.022050318300663944, 0.0010530200515565793, 0.08411374979562337, 0.030400209361687306, 0.06583833165707127, 0.024638864279334104, 0.037564075657076416, 0.010088476851852912, 0.02598274720742578, 0.06400746195727298, 0.054386393542611794, 0.026604785704083984, 0.05844007501558912, 0.11105612746530003, 0.038953169264019503, 0.06906642698712888, 0.02249030557821595, 0.03740023243271055, 0.020168333299337857, 0.07234585786899252, 0.055877350030406836, 0.022396839021014112, 0.06145071245790009, 0.12020098796534924, 0.0906810308656385, 0.05387761539989903, 0.04843236585598319, 0.045145971234887845, 0.0657829971263005, 0.02511939101461922, 0.042689575423156066, 0.06536809156738943, 0.05406414248770284, 0.026044229593788906, 0.08531889037018822, 0.01885144922491764, 0.025010342229037516, 0.027932778053406267, 0.026013746955281785, 0.0160866187539913, 0.0673447669513764, 0.023443188721073732, 0.046536983892081246, 0.027911978766262054, 0.009503615644550132, 0.01253352402859638, 0.02492201803702741, 0.062483333862356605, 0.08497770545223067, 0.058462349021987575, 0.006240386564675118, 0.043868308946970976, 0.07487567171694771, 0.0441764333405562, 0.025429652793513193, 0.03377929104552154, 0.10295821038345176, 0.05462480010464788, 0.08526595369462045, 0.03786470771076218, 0.003057886633248399, 0.04426337282864317, 0.045537066781112266, 0.03617212837261539, 0.007845312995355456, 0.061268594206100514, 0.048305314004180894, 0.04562128282662842, 0.039568866467884475, 0.01328639597857311, 0.015003736236042555, 0.010943131243449547, 0.050130200557290554, 0.03362366411414358, 0.07124156510877995, 0.04308459333955281, 0.06741802793957534, 0.004906200394485026, 0.048459638586087574, 0.055168665074292696, 0.018918278904992248, 0.022772633876170845, 0.04625299509855048, 0.059387285277367606, 0.06040604049039464, 0.013592089958218558, 0.05308991230483498, 0.030570462826759588, 0.06953747913001046, 0.04342955124053744, 0.01634855762184147, 0.08855519816279413, 0.021343073589847456, 0.037848148720278856, 0.04818301572794876, 0.0011035734754724189, 0.03514129578346207, 0.036000045872623884, 0.024239598405397227, 0.01962113776244223, 0.018987922042968775, 0.10315435187470529, 0.0465258794476188, 0.04225300489774635, 0.004947088422223685, 0.03792919699222811, 0.006579919605545941, 0.03146392052933093, 0.133286030181954, 0.07453664716693663, 0.07335481864790763, 0.1015447092152411, 0.03468774491921067, 0.05804184719078964, 0.03459356206979963, 0.028740635006538326, 0.022473769570370356, 0.04756095999431226, 0.019946962617517962, 0.05036834281899276, 0.06472840815061523, 0.06729089564854099, 0.0639918222722988, 0.058031363277545864, 0.0803174240694892, 0.03266614230890428, 0.02660251425338849, 0.0446685720535536, 0.048928131995302056, 0.050541509333397114, 0.02931640945344923, 0.043233153109829274, 0.06408451508069712, 0.018259110041863976, 0.051810438218977184, 0.026412338671845295, 0.07389462718199338, 0.04099921390955006, 0.04994370411300371, 0.01692824103238602, 0.06745554326522736, 0.04324311225284492, 0.031471458834505854, 0.060851639361992005, 0.10706769753127329, 0.07995701800551146, 0.06003714234177625, 0.05528110379893934, 0.06730325264675964, 0.03636770678924457, 0.016751943133591164, 0.027828618824001283, 0.04559627005590066, 0.03676602271415534, 0.03553091277999263, 0.051171451942214084, 0.04037816175109437, 0.03797915358577044, 0.09673717807257369, 0.07759966587107028, 0.020341854129407196, 0.060940202956478444, 0.02785177383151266, 0.07452997454111615, 0.016423980893206694, 0.019139760669561166, 0.034122586535710486, 0.06247145949953026, 0.008274931272852325, 0.02763581939131743, 0.07446484940667307, 0.04822364520101298, 0.03459115272327777, 0.022767966485492164, 0.03487408048503342, 0.02489660881579884, 0.017837564415869214, 0.011441343118466679, 0.032913335899431864, 0.03429200688016511, 0.04306181754556395, 0.05633815191686154, 0.022717538747876402, 0.03854360333794067, 0.033180555028300134, 0.048241341832063855, 0.023010605683309898, 0.028136046077575416, 0.07430481363929088, 0.01569339061050766, 0.09624580927794019, 0.0589493204719357, 0.01713814720841906, 0.050057253665140564, 0.02936956446407543, 0.09109529291069315, 0.03389726475542111, 0.061291890939877886, 0.036169316829933275, 0.12120375875383617, 0.03809744522215859, 0.0462651873878654, 0.06608894966062039, 0.07356201478790853, 0.06205724725019067, 0.036679209630575874, 0.06385152092984607, 0.019817593349744717, 0.03535908308901614, 0.00584074099841077, 0.03865316540243165, 0.004762527307555561, 0.02823886465311291, 0.039825789375050415, 0.006064048446264239, 0.05273536298303835, 0.03720282306594234, 0.056511195857198014, 0.13043368565699748, 0.019118947975878275, 0.05159334039255496, 0.011369590365868664, 0.045568805803815206, 0.08087372647658472, 0.024627629599924532, 0.04646925405869561, 0.019524622175301758, 0.04854899125113603, 0.03686145045644334, 0.0666422643248112, 0.07862061592600039, 0.016874478897079825, 0.01652945587862163, 0.0895893172691426, 0.04404573491023433, 0.1386178795608782, 0.10650032515367193, 0.27340317445416606, 0.19708578655075645, 0.1676720705243849, 0.2129055175089067, 0.2603560842333302, 0.17853404815879562, 0.09327818384213794, 0.348525082151736, 0.09968873098372452, 0.14977110850234188, 0.13906754252891387, 0.11278383193477509, 0.17677310313428604, 0.208872095231087, 0.1620427338827041, 0.15299589433256658, 0.14685953005907998, 0.11659925623286156, 0.10396662723994064, 0.09345745607729881, 0.12665596054566483, 0.23428269541792332, 0.1362548507149181, 0.26313502221338214, 0.14909960179319307, 0.12547977043375855, 0.22999712296070593, 0.10865845612340397, 0.11663736910709452, 0.13286166343717806, 0.17548812853713192, 0.07919128248167616, 0.09281394988178246, 0.16149786150743886, 0.16162480227649212, 0.1749289762829581, 0.1342503203740043, 0.0734194917904754, 0.0684309876974552, 0.13888484588073147, 0.21316802519704067, 0.11590580876556136, 0.10794822366968279, 0.12452073560486879, 0.1943431304947984, 0.1700278675003398, 0.2447862511560802, 0.2635640927380131, 0.1824955194587669, 0.18181238353492754, 0.15027262030109284, 0.1169008497268923, 0.1893485896289349, 0.12965941591368568, 0.1449859241444257, 0.09500797973164628, 0.26611614611841017, 0.16105826493472825, 0.24476541356453974, 0.12453952774165139, 0.24180491274643331, 0.14390659818966545, 0.1684805077891196, 0.13502368613356544, 0.08539657934658951, 0.09709253561713042, 0.21162241216628783, 0.1778119643248858, 0.08870552759617568, 0.05496822582978395, 0.1870637017512514, 0.12842498013689635, 0.1406903312571587, 0.2699124182183897, 0.12024883015622055, 0.0979650944411274, 0.18892146496763154, 0.1470954544962414, 0.06518698838208953, 0.17723235752313368, 0.17906468662042774, 0.09484575295280065, 0.14103559176287345, 0.2844576393404315, 0.18896589806723982, 0.1707769942379767, 0.2075311962154604, 0.1962676965781758, 0.14086299215353307, 0.10029088375308823, 0.08304368584386765, 0.122694535210969, 0.19862042920243358, 0.1496671656927755, 0.18085216893063438, 0.1973645965899191, 0.17508994667760788, 0.2303424294316961, 0.16381042048094735, 0.07642749772076646, 0.11231925323485367, 0.10629328989213514, 0.2023119770831639, 0.11561219024682239, 0.1447543510866742, 0.14335562775452293, 0.1073966863294763, 0.1204667362054029, 0.16093037421664885, 0.16241523647500625, 0.11688817097174546, 0.2032281416318109, 0.13337413029324624, 0.14024983070069744, 0.13395716916889916, 0.13674419703743151, 0.09184938389807941, 0.22442366477222214, 0.1936519353259956, 0.17586332775892752, 0.11099249620230929, 0.10986482243864767, 0.1054880855184409, 0.11404924064634309, 0.2069703126025777, 0.27078974210927564, 0.08314523079823102, 0.13819962619773804, 0.1698893588036299, 0.1983186671690595, 0.22267494651098407, 0.17642819502901647, 0.15942013912623929, 0.14103252741117633, 0.28288688330400374, 0.252973509411658, 0.12616680574513253, 0.10884209505973325, 0.20612660464980911, 0.18955849772018774, 0.20643371397689467, 0.20708617574024588, 0.1468930540666465, 0.0900253285503676, 0.1475024923321701, 0.1244021834985864, 0.1569470081238016, 0.1024637695762419, 0.07073008650613409, 0.2517635195005325, 0.06540216715826143, 0.13573925822011887, 0.1608440973946164, 0.1892284517206492, 0.10354308020924369, 0.14873252310339483, 0.21104194734606052, 0.33729493798267457, 0.0933713324728512, 0.11755621496347651, 0.09707297739242354, 0.09370158531612928, 0.14026381946619482, 0.23119287895819834, 0.15148276342980324, 0.09756469092662297, 0.12642073324851452, 0.13025408400402916, 0.2304393242323591, 0.1327455704731326, 0.1043079577146038, 0.19122038757608784, 0.22897241907494686, 0.18848854868162065], [0.034594898893227505, 0.017848458186152483, 0.03753571508211955, 0.05245037061432677, 0.06881843666516005, 0.05077603949053634, 0.04949352020517953, 0.061084327077673334, 0.05612626731876404, 0.037813050402027946, 0.06760947331185303, 0.047293239077853585, 0.011832275871007193, 0.020908912410959605, 0.02392144975132279, 0.03590702747685775, 0.0026589762719888845, 0.03884686307320672, 0.02617869909191805, 0.022699275211761558, 0.04358552291148132, 0.003925389995152552, 0.07569133319080838, 0.016254434144244562, 0.04277048196883933, 0.06039981602600986, 0.06716041555327755, 0.10821164300244664, 0.02383188641209516, 0.07778027876009865, 0.010113077850321369, 0.05151437971019938, 0.016893408929688797, 0.03887332758055099, 0.0309977445360874, 0.024337720861958883, 0.029002654313620542, 0.023953983590247172, 0.04687426176162497, 0.02154136012728897, 0.06466815533537058, 0.013509436732067937, 0.010337624924197313, 0.03527239257950456, 0.05418917952826428, 0.010298199166784124, 0.07383182329396087, 0.024650943570680196, 0.07241217810059748, 0.07076723410958244, 0.0217731170461423, 0.030854434383312063, 0.015711272060270273, 0.022835001094086517, 0.07446761498407972, 0.05066840796761456, 0.1287404474832358, 0.01762381630889591, 0.02833749847336402, 0.04312328844060821, 0.014472977115562367, 0.008721294317154155, 0.09269992535513255, 0.030541085270083243, 0.01927552294106253, 0.03741235960455191, 0.015115080412567384, 0.06315428132732069, 0.03141397925754709, 0.040146171175424135, 0.014121350419196873, 0.036704793136807225, 0.04402551784991257, 0.020223198601255016, 0.025962463114410642, 0.04721193033601007, 0.04783401671316355, 0.021600471471526453, 0.06014691891088601, 0.007119139688344853, 0.07102300788486196, 0.045152011838170795, 0.06386267900046322, 0.0547271762644091, 0.028204022974316633, 0.10922665587596356, 0.02697389261166175, 0.04286998529888449, 0.088144613339776, 0.031462616264639844, 0.037611611412778016, 0.07097611564301676, 0.06677411571745911, 0.03406576962480622, 0.02283548947513825, 0.13998638838529587, 0.004235077208103312, 0.04389862304613475, 0.034020781111452854, 0.03580411122510991, 0.03398782017851069, 0.04143585721331258, 0.02047575863769218, 0.019008615993023403, 0.041582402172348196, 0.04269442475971676, 0.037192090174123164, 0.02982338154388051, 0.009484373431112017, 0.03294217910978102, 0.04136696292628204, 0.039026169782324184, 0.037243816430770585, 0.013919607867606947, 0.047473457431600946, 0.0015066126915400909, 0.060374826237919836, 0.11600832665158857, 0.05019690766329727, 0.060653092354656234, 0.07286324300953458, 0.055767362787117886, 0.02571182595866342, 0.027294057992196856, 0.03255299112248806, 0.015070385885454956, 0.013822166271687997, 0.020089311329948328, 0.09196782875205241, 0.04229337007047669, 0.024394955290781877, 0.015456895437842656, 0.038755434309883464, 0.038039046339690685, 0.10827647702347849, 0.016636185333012574, 0.039509755123646996, 0.03020875441331056, 0.03598034592165101, 0.07573754361440098, 0.054879183430344834, 0.03529970744444478, 0.06289798661225265, 0.016796320691824924, 0.037334279923309246, 0.05712423090552611, 0.0643220980982146, 0.026282189909609097, 0.1034076358642309, 0.03277849293343964, 0.05501409151381063, 0.020720565864335627, 0.011938290948408746, 0.03223468158994952, 0.012986764627238436, 0.08967295108783631, 0.04224201153603293, 0.03507071993343773, 0.042302505668973735, 0.004561925748167861, 0.0490459754702545, 0.06702558407860418, 0.05434122882903584, 0.0490888572418161, 0.041772981865271445, 0.03989193723687241, 0.03584141970702237, 0.04222730264788674, 0.04703711290212889, 0.03379366285498104, 0.02598357649760381, 0.03868136892936403, 0.014528723418592446, 0.017698831638441454, 0.07449258178953203, 0.06601768816190381, 0.07492021972974462, 0.05250136142656688, 0.050783405425928296, 0.0633507598972609, 0.027570968133307276, 0.062252063409335194, 0.02559876861801792, 0.04615244988892828, 0.008086003457015802, 0.008239636644570818, 0.048672442489694205, 0.018222500615182425, 0.01804582924852448, 0.08940195514550132, 0.06725845182494772, 0.046075255039238164, 0.016093774015204083, 0.06787874555635838, 0.039713523020186735, 0.012043805195829801, 0.034510717321667946, 0.03450702094743329, 0.025274271010271004, 0.05065989290033618, 0.017195519533068422, 0.03889248743953724, 0.05611275352777974, 0.01115272332343363, 0.03444877528255025, 0.007878406557269515, 0.06778142940733703, 0.07351783449731528, 0.05539539262592312, 0.015014024796865642, 0.06529593374580145, 0.03662248081978291, 0.015856449552361044, 0.033587838012364604, 0.09720810764138738, 0.017377762274155696, 0.022073308599271604, 0.009406482399020706, 0.06444765224812493, 0.02093348085069128, 0.04503045666722521, 0.09711376391351224, 0.06466537443620544, 0.0735161567647611, 0.037899851994288546, 0.046696682580776756, 0.03084497128222739, 0.02163977178204204, 0.03041647532353959, 0.052036158364987185, 0.059352129502522374, 0.008562198922699018, 0.06239186679463714, 0.02368474581969842, 0.011891160261697106, 0.07638940782917124, 0.042102495433702584, 0.061356242325517445, 0.009682327677916375, 0.034377034978881, 0.05364264857264296, 0.02735088256398036, 0.06070474200251122, 0.025048577677338354, 0.01597170365012942, 0.07017785968679575, 0.04074471567066447, 0.02043309137074938, 0.04884669684895104, 0.021163929674413898, 0.04268197200050758, 0.02364696236327291, 0.03548016711588829, 0.03804828536005751, 0.05776782137071414, 0.10655752893897796, 0.029750869406627554, 0.02353900142254368, 0.03570468833429679, 0.10123682613935202, 0.047454282250856204, 0.06410591191642227, 0.029797708022318063, 0.07401304905332866, 0.007072659218758946, 0.03123431248710521, 0.06026099706369062, 0.06505945772533456, 0.062331935736320676, 0.04936099465515825, 0.07836812100703679, 0.02702640027799193, 0.026487943889092536, 0.03568209640140976, 0.006893666605690435, 0.05011943702195441, 0.026948025652898416, 0.0202868566773231, 0.05751669391869538, 0.00462228964616154, 0.06953615379790146, 0.04854661254813114, 0.0455916582065965, 0.02739625029085625, 0.03529752409386058, 0.043203735333536906, 0.023203759431658734, 0.02150822682456384, 0.04670361567649149, 0.04779115409380005, 0.04876848310232163, 0.004904372795980665, 0.07177175157853673, 0.03723627812559566, 0.09894163437908697, 0.028669563114583015, 0.05190549823906153, 0.023082545169839458, 0.032599370085424, 0.009034034390483172, 0.007104056853530629, 0.04420307021768344, 0.04755272454912624, 0.026866270664839015, 0.06347853187171203, 0.09571570707785507, 0.022820472236602538, 0.04544859894761636, 0.02138610857899391, 0.024796906302893357, 0.05850233498119539, 0.04170918206293737, 0.050831577034607056, 0.008133820750029578, 0.03180806637711583, 0.01768276102900986, 0.015462285823999875, 0.03854502060060059, 0.09810274511936212, 0.03705100359154805, 0.045053167343740506, 0.0036270794272798327, 0.027948291333872947, 0.06748682263517572, 0.0697392973327829, 0.04610232092560299, 0.0704818740186672, 0.032185265088393804, 0.026734855942307945, 0.045135157903836626, 0.025657092806913202, 0.03502385450466987, 0.06389190525477452, 0.037718292986673695, 0.029483912662873347, 0.02066548797301948, 0.02926573465247789, 0.08171066221210264, 0.113121967822794, 0.045212057809675896, 0.08282649991733414, 0.03947508198419406, 0.012759676056673691, 0.04734993341468996, 0.033751030061994834, 0.052148876711726196, 0.01735171719994997, 0.06126222418501012, 0.0016412087138779764, 0.08262422206180711, 0.030057745076896205, 0.010788617054781607, 0.22087010464841322, 0.14992637920283503, 0.16286738156791658, 0.09759211687431221, 0.1847503000810262, 0.21266104353051032, 0.10866026409090528, 0.15347027129703952, 0.18346774632171278, 0.09377170534383866, 0.10694084103189169, 0.13266503931053225, 0.16598565053314934, 0.2052289641071712, 0.17695547802554024, 0.12649295235713645, 0.12481170345938976, 0.1251962336321031, 0.07993287857501738, 0.08589370912241359, 0.12671196923380898, 0.07637161926756944, 0.21314991487851068, 0.13862785402565234, 0.16606028281873272, 0.1592544649517344, 0.13447311406414356, 0.18168495246960273, 0.14638757393244775, 0.15407404051192347, 0.23861798698142653, 0.1791963005258191, 0.15234505667561485, 0.10889310885461108, 0.16428262175571534, 0.1724281282194199, 0.1397985742697793, 0.1486361798860373, 0.1920344326044283, 0.10720586148841728, 0.1305592015025116, 0.08014237297879112, 0.11780281866630239, 0.1309418624206897, 0.1594458030717027, 0.22654378245915138, 0.20054153256839324, 0.18213591778710966, 0.26363846455370227, 0.150317712236316, 0.12397575597729414, 0.06589231787309532, 0.08528672999912694, 0.12289291367896142, 0.25406193649095876, 0.14342630702641704, 0.2866507345630277, 0.12002085771171317, 0.09043586740811026, 0.13897461606369865, 0.19594837580957722, 0.2443458578519283, 0.141897410034172, 0.1423107297910798, 0.09917069466844683, 0.10718690081229133, 0.17289309762418273, 0.17818319521123366, 0.12932728615499314, 0.2357450040477899, 0.07123328369831847, 0.09346381460707034, 0.1675734903302885, 0.15287692087792581, 0.11460639341103454, 0.0935492487323861, 0.12778511285902033, 0.12349102916496417, 0.1936366901763024, 0.15063246712088585, 0.13489251655917014, 0.1122304330009126, 0.11667200394215123, 0.1728590526768277, 0.15816992959908902, 0.25616258022285276, 0.11386062979938523, 0.22635733198014, 0.23806494810888845, 0.10911761092082148, 0.18609908980227288, 0.1927569148040587, 0.2056888160445998, 0.10367106285787399, 0.17560106521892935, 0.2686509165552355, 0.14135904940626315, 0.21434648292920283, 0.13589426845071778, 0.09050385005051091, 0.1615346643713213, 0.1992120635845969, 0.14347251745000963, 0.09064140113731546, 0.15256608836352825, 0.1634895675365002, 0.14881737500188813, 0.1753846300585616, 0.08723203408261461, 0.10338947191954621, 0.12019834496201047, 0.16421309161570766, 0.1480187743061012, 0.23684162826788044, 0.18109253667775663, 0.09567937152760644, 0.20934201356384063, 0.18366136738369543, 0.19909574079417414, 0.14319585245703498, 0.1727542671705446, 0.13712583139779108, 0.10605837669103377, 0.09789890444446957, 0.15138962245996923, 0.11755668993798957, 0.09463644241012874, 0.10188151977115101, 0.19112847234693267, 0.15852426058582722, 0.1351233082072389, 0.11707680480134104, 0.09568071984235318, 0.13236848667504328, 0.16926651399943138, 0.16424293840123763, 0.1759478732222511, 0.09894741834291527, 0.17208470632472347, 0.19746101641606903, 0.1566672328138544, 0.15193578186294726, 0.2611747257892163, 0.2476328346998461, 0.11730604895180273, 0.1419992077975504, 0.2532305931972881, 0.11993484135957495, 0.2493684375358205, 0.07652992367624276, 0.1492776712703128, 0.0987381844090358, 0.10568755949216505, 0.21327088016175458, 0.09634325566190867, 0.14503659319973763, 0.1537046329148354, 0.13051876738186807, 0.17058911883542616, 0.151871093398621, 0.16187649280313524, 0.16446404669794346, 0.1770055648540297, 0.10290070782385527, 0.24801425455558687, 0.18520138797260102, 0.1086674653173935, 0.18210003422873636, 0.1534446686386101, 0.1587881319104664, 0.17269288820605125, 0.16838834741182868, 0.09619105697399187, 0.2935835238425963, 0.08508480454404509, 0.12794472727804415], [0.08293416591421252, 0.06207407437144749, 0.05734585248114121, 0.04108316948517196, 0.0627969817498759, 0.06573664114600228, 0.061294756108714696, 0.062210767439776854, 0.018446487487263737, 0.01700240217389599, 0.018461119766617497, 0.02675126554564603, 0.05784834104199564, 0.018641801603559046, 0.06277764952110668, 0.03129938782583321, 0.045664463372480486, 0.056391525262546156, 0.016424538222171606, 0.022924800005350864, 0.01425342110451311, 0.04397573745659283, 0.07384499234537925, 0.0829346102452086, 0.04506724420934916, 0.07603951249151461, 0.0682193865518897, 0.005089223587645158, 0.028388688468464443, 0.05270096563523816, 0.06399508580685624, 0.01346841846938215, 0.042720467918702675, 0.012800190616549264, 0.0465039195372693, 0.030402588064692197, 0.08909699086460376, 0.0694898437828787, 0.015702583665599026, 0.02095419395294401, 0.055546304286127134, 0.01224495402927841, 0.09678045437941629, 0.056073548978254686, 0.01713711107450147, 0.014957779579074874, 0.1204401069891549, 0.025205501212528156, 0.0091662640390437, 0.004147246663999414, 0.022632384244653008, 0.04682148596452129, 0.05559058416815055, 0.09841375383398226, 0.0629284386072428, 0.1483468284770366, 0.07617419074860311, 0.018835077925975767, 0.043973021674901254, 0.0791192702167938, 0.02225668706570662, 0.05035610073396275, 0.0183352668424167, 0.015786929946062307, 0.057689745519911094, 0.010899212380360452, 0.03367606069772475, 0.0691636129012031, 0.0816299701710382, 0.037281461991369724, 0.01025646556949904, 0.04337323228678396, 0.08281331554415726, 0.05359816950775924, 0.027340952149261872, 0.08213818523912661, 0.032444409650540164, 0.011901887407856844, 0.07163976995094169, 0.011439978524351553, 0.02151139651335055, 0.027201374759897593, 0.048663732069995136, 0.032690921422815135, 0.06207773627172555, 0.039906795512163834, 0.006504145370150406, 0.03987727431400169, 0.014480513505517476, 0.023470369520627206, 0.01665174074831509, 0.021838326450257052, 0.071139024240115, 0.05887640422330268, 0.037263412959873676, 0.0616291496572235, 0.010022201627913502, 0.0013506771703701347, 0.03804865691270079, 0.03984789867254515, 0.007630697772612856, 0.05743869084624514, 0.0878180760229307, 0.022068359671280752, 0.05979122811808221, 0.018160748182825984, 0.08993490719266477, 0.031243091854717464, 0.016953054620253465, 0.01526214152334198, 0.030862175701786915, 0.04062009997846138, 0.041890449957140995, 0.05445003246648177, 0.04886254337766478, 0.013759348019506904, 0.03380285974051203, 0.029231496267921986, 0.027115856364910162, 0.04510914538836768, 0.043689726190941955, 0.07573313860883636, 0.048789910581563754, 0.0803235604337627, 0.0901236942398452, 0.028378681444953528, 0.02739204255293214, 0.029273048876934958, 0.05703508125377759, 0.06287313088954938, 0.016912350453616633, 0.03701978550863363, 0.024999165006222266, 0.12606623372243297, 0.04062459308413729, 0.008114681958461241, 0.04041686451302902, 0.0536726332539993, 0.05365225531521344, 0.04116417562228538, 0.020535672459030346, 0.05675630951901117, 0.061198029847395044, 0.045175266437112324, 0.05133541391020821, 0.01229377968552252, 0.029483108270552852, 0.02506554844008098, 0.037204044976181565, 0.05325160665257324, 0.08766344883629391, 0.011150482516255111, 0.021426785932553392, 0.03156653992200811, 0.005064291734954403, 0.07886679061958868, 0.043227418941716035, 0.059548167571906126, 0.025927054530550397, 0.038111319074467305, 0.038496879635438803, 0.04579551803368715, 0.020618524868041277, 0.0241474227063478, 0.044790897142863086, 0.10168438236559592, 0.053933049522099964, 0.019772631649468696, 0.04410063277088827, 0.05258677639968453, 0.04041648912994612, 0.028491265726305788, 0.05282925088859854, 0.020820657166862683, 0.012707452800485396, 0.03503652176849785, 0.05499181367697255, 0.03172268779317458, 0.012829693620123211, 0.06167609552522341, 0.09336085239004704, 0.06088580305297529, 0.04863615290472104, 0.09342662103834654, 0.011852310985446939, 0.05689558813408498, 0.043928094448581825, 0.09786561792415958, 0.0271731520807671, 0.009653824419083615, 0.03656344225389823, 0.01667430012246534, 0.012833694514307766, 0.038782653413833156, 0.053817266823663834, 0.041548759421153415, 0.02242013383957167, 0.018596564111630284, 0.025100480134208358, 0.05012970643057939, 0.027948266436015407, 0.05056466434090849, 0.060814342371398405, 0.006189333507791162, 0.056769076374269305, 0.04679029852512383, 0.04498235400645964, 0.019547532034677365, 0.0312391962976225, 0.05400536439171242, 0.009795960542114993, 0.03797796231904819, 0.05308874785119007, 0.012953366066569523, 0.05699263615233283, 0.03766262137721624, 0.06662338791835694, 0.04493024470585008, 0.03533058461823291, 0.06908728756130704, 0.04778970618762317, 0.04155769583679015, 0.04930728423078695, 0.0047906599713549505, 0.049019078123233015, 0.02055983295694234, 0.010048652728719097, 0.07951999548822641, 0.07515598328844195, 0.05801064059919408, 0.023172566246601845, 0.018158501629988034, 0.07437808228836906, 0.03189558426158563, 0.06059725986673467, 0.025641207973803246, 0.010915421843228322, 0.07265338088355719, 0.04335600296936689, 0.051793603436841126, 0.024188576949640148, 0.022041550424370556, 0.05062156169104481, 0.041677151926823204, 0.0401247245439839, 0.0291220931666753, 0.06378821142378353, 0.09072039246318803, 0.02651143980573022, 0.0706883347142608, 0.009972764058939872, 0.020535136197483348, 0.028381458513679046, 0.04757090381556942, 0.05554881705451877, 0.047407903287920265, 0.027992891057604746, 0.06730597991977008, 0.05842558446250135, 0.10021087353027637, 0.036284816075837424, 0.031130940413042426, 0.04153423439410906, 0.05265176363830125, 0.019064188011050708, 0.009527467792072605, 0.0007252416722739356, 0.022937988208967353, 0.03658283193926177, 0.0613670977914045, 0.012123877663285503, 0.039402092957208236, 0.04233982181176544, 0.038594881433152387, 0.007946608013533538, 0.03852463883137511, 0.0210268727143205, 0.08408972527831794, 0.05098578287288547, 0.051811690772733385, 0.09347771144201679, 0.02357295060890817, 0.09962220390838, 0.011437080796777962, 0.008212760364967249, 0.07097661360016755, 0.05909870378673077, 0.043035414325253624, 0.028492953034959016, 0.0914403772161853, 0.02664743956448811, 0.04124001449634952, 0.02973047806130302, 0.027442129381421595, 0.04043242375877115, 0.057219539904185844, 0.04839850476973, 0.04599648204842403, 0.039333168026660724, 0.02012381018439849, 0.026126003734046416, 0.09536440213841778, 0.03656205180431566, 0.06950498934114172, 0.023696669978239847, 0.06851582427419002, 0.021844472390629595, 0.06795094168234257, 0.007678039133503674, 0.039671755906554966, 0.025359006080355857, 0.07877560317396157, 0.023329445731736, 0.046404397055026025, 0.0032672043579946007, 0.07265665207899387, 0.03144254667624351, 0.01681122876283142, 0.03342834233696903, 0.02865780558016512, 0.027617705242347815, 0.020156411056016243, 0.041790682326761946, 0.05956910092443709, 0.01760505481563028, 0.01112977707488162, 0.018106193146518162, 0.04251950007352618, 0.02403816133136711, 0.03031382337212563, 0.05461805853091421, 0.049009299010879574, 0.008872486557060433, 0.033915195043288895, 0.05477408382801279, 0.025505229282463272, 0.039533932858537284, 0.03449432687052796, 0.05317068861557111, 0.031038573192011927, 0.033200220505316416, 0.04726740276260723, 0.06930848778856379, 0.05457035806630889, 0.0036302541435185463, 0.021102901195145903, 0.05224004883559481, 0.04393356814680081, 0.04605953491503193, 0.072207992686139, 0.021004409101160786, 0.013869967285333382, 0.1510224211961031, 0.0791712799259732, 0.1748717648367728, 0.12866353225563804, 0.12544223978634805, 0.15576248297527914, 0.14513684346550895, 0.14350596484878372, 0.18886999918087838, 0.1102575803956678, 0.21842626884820002, 0.1200604874400362, 0.1355946361417732, 0.1371286812448694, 0.11518653647433366, 0.11178907442597613, 0.1902215161751355, 0.1673422237077067, 0.1150074787437916, 0.13298426814857991, 0.07928784020365247, 0.11167095132893133, 0.10801435237930668, 0.21625869967524083, 0.23080586666061034, 0.16522544616412732, 0.15964880104987852, 0.09537390162867886, 0.1464777118376186, 0.1047055650081846, 0.19465898854597924, 0.12377065891820578, 0.0984911670187308, 0.11422432238055814, 0.13526803753789396, 0.17744126970008497, 0.22846059573273506, 0.11723850297951892, 0.12803520992278092, 0.08953772890832155, 0.11652535173080622, 0.13289603014146129, 0.22520219396439292, 0.21273576774664466, 0.19535056675874418, 0.15442561358213425, 0.2096447408679993, 0.12907358847798842, 0.13795617877716018, 0.0836748963281993, 0.16486247370560325, 0.35499273348719845, 0.16416467485889313, 0.20849130356744414, 0.09718037525852842, 0.25139579729687783, 0.13729021854458318, 0.1066647582657395, 0.1551984430801484, 0.12520832249954825, 0.13961175606856424, 0.17630215824371384, 0.1525776562911849, 0.14012740985039743, 0.14785110830299317, 0.1714807532487377, 0.16324334687763647, 0.20393312638325078, 0.14376911605077405, 0.11810029826817975, 0.16946565089446886, 0.17964007993859632, 0.19758268650020325, 0.20669735547515655, 0.09869767367959985, 0.1813746255732352, 0.34470815632131796, 0.13112590738361882, 0.21107541006659308, 0.1592022943640909, 0.1414460769944614, 0.17919726579660372, 0.18441790985243936, 0.18395513145914003, 0.2188146907475687, 0.24197064820797215, 0.11840168491847093, 0.13921152109340315, 0.10357904037640941, 0.06799849275980266, 0.1426890240080895, 0.14295600564970126, 0.2524077534795769, 0.19634311027344198, 0.16850975702606863, 0.12475279895889184, 0.06974855933578746, 0.10076719892000961, 0.1408061943948269, 0.07674812849971556, 0.13412688828764424, 0.20903537921126814, 0.170606340491964, 0.1844693143521586, 0.18518680165852272, 0.09736235944494125, 0.14131401875807395, 0.08716145440215066, 0.13416232751502147, 0.16368476673960686, 0.1002595584178644, 0.12675009742980042, 0.12870698476270323, 0.1886778030424349, 0.1503569972250731, 0.09357290552748788, 0.07455714001891113, 0.1504937132760402, 0.1379662911377607, 0.12984911460549603, 0.12781917312813382, 0.1332702487707138, 0.09073432760253068, 0.1885361840287524, 0.14347890662329812, 0.21717920028153928, 0.07264192020820995, 0.12299693309732022, 0.15481720708550947, 0.10369578451519051, 0.09352954495097361, 0.19490617447562758, 0.11420657978423181, 0.17917028417991054, 0.178022577217029, 0.1544219363600977, 0.13615645438192353, 0.1880474812200954, 0.11584479752327166, 0.11789172316991514, 0.13455626524744496, 0.10984046084265556, 0.17792971203884772, 0.13183187272760177, 0.13252479925511346, 0.1463939171404608, 0.12363018903640971, 0.21231052766163505, 0.21567995089196393, 0.1487952503826349, 0.22800982959808844, 0.09752211175979146, 0.11737724916348535, 0.11702936097619035, 0.16047960808200223, 0.1344118576737181, 0.10298965829274348, 0.127240868675853, 0.15458342769453604, 0.16868425653346125, 0.15258586875373317, 0.10981861201505508, 0.22043375628850154, 0.14198788501802953, 0.10807636719677718, 0.21377105896751727, 0.2332857239150232, 0.13124357848878832, 0.18369625502776715, 0.06913350564577887, 0.12839808278987486, 0.0963769252261808, 0.1627568350804429, 0.2592737552139067, 0.14244176146964874, 0.09723767097438536], [0.042273225788507736, 0.03980134733982625, 0.048352562476910894, 0.04067591714462446, 0.026839639533371217, 0.049561839926266865, 0.08515103284509913, 0.05224834173737515, 0.013180851087635084, 0.019992144568072214, 0.04494584608642806, 0.10487071824290099, 0.018206284449045217, 0.02967623903626396, 0.04174868921719251, 0.01979667531897224, 0.028050092927690957, 0.042886218702, 0.040178710760007945, 0.09875584273569046, 0.07952570284326231, 0.02926674588853794, 0.08664231492026199, 0.0553156390425659, 0.0422070357918499, 0.012921643323234975, 0.009660312226192366, 0.06312919960867974, 0.03965975513922111, 0.06449673550143357, 0.01915072721819724, 0.0928019299622505, 0.052473077460402445, 0.01818356611165068, 0.015939806621792098, 0.07897831003872618, 0.04135087507987215, 0.009608792813284504, 0.040727080326647534, 0.03015988757984052, 0.028134992706679532, 0.022719400341532404, 0.029569655138578628, 0.03638425811884865, 0.016202956866172534, 0.014795420650062303, 0.05413376838870106, 0.042833718696549054, 0.01168373333770902, 0.02532041823160985, 0.15111896359632093, 0.027084239916275107, 0.03355042610858237, 0.03900375021922012, 0.02692006152844237, 0.07845163991254184, 0.03967094385335523, 0.05580074123797878, 0.011981096111177918, 0.02829332967408963, 0.03087079036049545, 0.057538351224314783, 0.01704760519186816, 0.019385695960673115, 0.028572765990130367, 0.03340394626702032, 0.04523307160143891, 0.08174204883436043, 0.07377730847726907, 0.025617499467766574, 0.008120342390611768, 0.052390064172927416, 0.013596473896365254, 0.10051435160060083, 0.05963594592627018, 0.039418885604508465, 0.030768128832982435, 0.018028078991318905, 0.018049240255007343, 0.04057871207835213, 0.01390615153321696, 0.030494330924064405, 0.047138952800343116, 0.0324323361048535, 0.013915444179738482, 0.08492282291333522, 0.020100994170793605, 0.05898137742112722, 0.0920983165081951, 0.0066151610864777005, 0.06739556624163544, 0.0696307503347916, 0.08301000861871628, 0.04178947956872083, 0.11226031042995954, 0.028221441898494962, 0.060501154136633685, 0.06054550296657028, 0.06560053030449538, 0.058569179983028484, 0.05984655115753413, 0.0347790970737415, 0.02209463840230338, 0.06787969550538449, 0.018663537433190693, 0.040270752393670624, 0.04253122504920729, 0.0310880720480195, 0.02217387487631171, 0.015554506530714853, 0.03756027203053236, 0.030559909965602622, 0.02040490891123491, 0.054011290081806725, 0.060529495559392445, 0.044815699239411665, 0.0386853181126137, 0.08095889247112698, 0.020773469981166626, 0.025366889125096704, 0.04862595627444887, 0.03007890059492521, 0.017133801574668577, 0.01988497844356443, 0.023409697272244002, 0.021977114769059326, 0.03828987501741898, 0.010578396782699612, 0.054664100415163466, 0.0301399463111715, 0.018072906626208175, 0.014885392888719517, 0.06397971425265556, 0.02632267191074789, 0.015665508840503474, 0.02990357945823381, 0.04323005811461518, 0.05602112941203579, 0.039649198447624524, 0.060240331841933156, 0.022163509706696196, 0.05723207693306669, 0.022412750667201418, 0.040347265425108136, 0.04623707579148393, 0.07100026273439008, 0.04453247270336555, 0.0500860394188954, 0.017393687326881676, 0.03277611423043474, 0.059824231185860215, 0.0484127693268801, 0.03954910139943804, 0.04358144732372415, 0.016667983727529645, 0.033874033139117306, 0.041563805387986284, 0.06060233902967265, 0.05751079887211804, 0.05752424371518916, 0.05012023375339566, 0.027577284528242967, 0.04436612820192691, 0.01140059873221382, 0.05970296712832586, 0.027138228047518965, 0.05313498508786002, 0.05535892684072737, 0.03213599797398333, 0.03454925154425925, 0.0532290683458409, 0.041697633287478844, 0.017190551452879465, 0.0351102500703306, 0.08931928659759222, 0.017916754924602086, 0.009448254300702003, 0.08905615071736037, 0.025008884746761575, 0.017444919456817934, 0.011828067175473177, 0.02497909733304574, 0.013293165322994033, 0.07497455834621385, 0.01823791621943876, 0.024927551107060526, 0.022835778673329664, 0.02007382869299862, 0.02893640686036839, 0.006788097295699822, 0.015986430732863807, 0.04808754202038531, 0.03290223145496941, 0.025273458957071268, 0.056184218039796244, 0.034853051371511914, 0.09945876671061402, 0.0368325766025772, 0.04753687035953326, 0.0927567920617519, 0.0659504103203935, 0.021220597198172923, 0.03646441772880574, 0.024571431305019126, 0.026302677015924168, 0.02952325702344458, 0.03293759024311458, 0.030737119509027373, 0.0252695633999763, 0.03560968194036715, 0.0252096246807806, 0.017453693078770753, 0.06748178177663396, 0.08794887787512234, 0.021775350192441575, 0.03889141874688287, 0.06323812198975394, 0.014933015786922507, 0.04625055893895127, 0.03172203661843894, 0.011084168030309581, 0.029128442120347774, 0.07127916470410363, 0.038498266254581755, 0.025451681651775877, 0.010535402970779087, 0.1020408583985221, 0.008188122019712484, 0.012610279335339945, 0.039567908857979124, 0.030335233614389456, 0.08521247309662643, 0.0734875740243062, 0.03271721356037644, 0.04524678074484391, 0.015714297149961275, 0.036762242070249015, 0.05539728486309609, 0.03425615396530878, 0.01850010789630394, 0.040790642641725085, 0.12436988523169873, 0.04675554111599923, 0.0274208857632813, 0.07333269402865442, 0.04595654971537091, 0.03426211795979931, 0.04675541854193134, 0.035149581024363157, 0.049694905568274765, 0.06515128102393881, 0.018404992334845088, 0.015172972719395354, 0.035958144693605365, 0.025877932972845533, 0.05526156472643057, 0.014949201309542744, 0.017639021238973065, 0.02013602545635114, 0.04594893480140356, 0.016213308629249374, 0.02158822938649645, 0.03554412396624684, 0.026583432918414477, 0.06569975401244818, 0.021733408793807033, 0.03595459770651595, 0.02535635733135766, 0.053421249162525906, 0.008962421448931338, 0.10469303947062263, 0.05704396021282, 0.06458288974939816, 0.10018999763433972, 0.037370967874003035, 0.03454463203407584, 0.01806180026652592, 0.022341893279864904, 0.06684276485635389, 0.08070124178043298, 0.08288919655305725, 0.040455827744857925, 0.03969111111796191, 0.029362556674788078, 0.031129496337305156, 0.02660882490266475, 0.032717025868834994, 0.028384486476199764, 0.07476154759886765, 0.03180102411387188, 0.022409086851703546, 0.025297004669424028, 0.030721855207136085, 0.08209614999472134, 0.015399434055472094, 0.019108021646858226, 0.019215180110486767, 0.04425776506503744, 0.038026681680592804, 0.040243866537968, 0.02585069471669774, 0.039053404208032355, 0.058820793900879166, 0.019074763854845397, 0.009703927526941464, 0.011132009263570991, 0.037436889739887375, 0.05706659428054287, 0.021003235071416826, 0.011105814802220032, 0.0751186058586163, 0.041781849332994996, 0.011252971673985163, 0.061077302051407684, 0.02563018588379266, 0.05839664932160128, 0.012518873554654421, 0.06225644543226208, 0.029299011596688823, 0.04169795504440704, 0.065557545111064, 0.03582822384252664, 0.021358671139985807, 0.06319111483472009, 0.04690652938499566, 0.08851504749468259, 0.05420270864100707, 0.03172065957539505, 0.041582229802565235, 0.024426805396233837, 0.0028116111512175735, 0.09413679220503378, 0.03872390979179933, 0.012910914261855427, 0.07457243113387978, 0.016985707202806108, 0.02233603462246397, 0.02669874447277717, 0.015342938901496031, 0.04451825411149091, 0.06570017536080654, 0.026773641058694453, 0.0350599410763431, 0.048955082968478246, 0.015135435368715516, 0.038453254758590655, 0.13749692438831254, 0.02974866690384525, 0.05348172414326861, 0.01902592383445271, 0.03791482901320823, 0.027539204212746797, 0.11154572659682845, 0.11659210863252802, 0.12847079985564755, 0.13851458026516822, 0.16745045660964905, 0.18937437614846617, 0.14754836567707602, 0.21890167237049152, 0.10908725851726149, 0.15810257514878628, 0.18095493196479737, 0.22191763795431585, 0.09957002565985727, 0.11654212905634796, 0.103498823309858, 0.11287923286398573, 0.1689781891482492, 0.18230116295237697, 0.11625349010911681, 0.1224139401869428, 0.170865063705752, 0.13868235352058567, 0.1997000003053296, 0.23519173534887455, 0.19600010206622465, 0.19313027541483604, 0.11754358983448437, 0.2321441456555359, 0.11582936851247666, 0.2136491284134888, 0.12740431353449821, 0.192629361164666, 0.1625376113600308, 0.12838832282971951, 0.08864552758994604, 0.11650085223898773, 0.1938252703797433, 0.14834502050953527, 0.13979264474924535, 0.16790336779048368, 0.13192450807940576, 0.13152856319662065, 0.10971039443487123, 0.16854234640636753, 0.09658001513490755, 0.16996517086461668, 0.1391656783920142, 0.14358245106714387, 0.14111140382386025, 0.12512861105102685, 0.24815929032141165, 0.12319452249475064, 0.1684665649888977, 0.13746643408892617, 0.06442986368652313, 0.21070356630990583, 0.12560698699446457, 0.13845715431436417, 0.09674074804230083, 0.2909338402171289, 0.24060610771900226, 0.14404247154391583, 0.11634735120159966, 0.09235610509471548, 0.17530155548405263, 0.21035263675355145, 0.09970839646074081, 0.13316898726888243, 0.15159429050981998, 0.10699751621652996, 0.1698715855637866, 0.19840054664640658, 0.13589921737870864, 0.1762477200358145, 0.11604902124212635, 0.1427507706947865, 0.11713789265242316, 0.17147188195057456, 0.1301158357772135, 0.11728035436282236, 0.13257139272266819, 0.16239554801535222, 0.163358842293101, 0.10780052191788152, 0.14589245130698528, 0.15032554165490214, 0.09019581375703697, 0.17868171926707993, 0.10969335663943522, 0.13052835880268004, 0.1540115124155437, 0.23701496332162814, 0.27565155058137836, 0.23975775727341253, 0.15442339192715385, 0.1015967725505752, 0.1460919865677434, 0.17530071278733594, 0.16833873555785225, 0.3197797778392992, 0.14034044358038134, 0.18281189844973628, 0.13715172516963176, 0.20497017960634925, 0.2105908747762442, 0.11920481319389037, 0.1868438498387414, 0.10015478057246055, 0.10474231424591235, 0.13470457986958567, 0.09954489797594086, 0.11216340030753806, 0.1680415394085069, 0.2114048278740337, 0.10100108556329243, 0.11830390911669501, 0.1710766112251628, 0.2136028260593453, 0.22446930829075076, 0.09006367891185707, 0.0958650482578143, 0.10848140554322351, 0.17741157613213987, 0.18282654605084853, 0.09278178184984193, 0.19537670567872065, 0.1399991360883559, 0.12681316944860643, 0.10170464539119314, 0.11139211830713096, 0.12681336863146675, 0.12382792399054575, 0.09514789036925762, 0.22854178573095033, 0.18534008053041276, 0.1613256296203021, 0.15192441311815094, 0.14205364600544976, 0.17495430314973479, 0.18429993231210018, 0.08831211846441993, 0.17013796965681738, 0.09232823481603016, 0.0943060516710243, 0.15232117005413578, 0.19746866197355334, 0.1287039357327646, 0.13841471304335903, 0.09276215467722186, 0.12004123565049903, 0.14226658780488277, 0.15090994416706024, 0.1484676558644541, 0.1414794018191676, 0.12494605229867083, 0.1785495997436585, 0.09732799274065802, 0.11879102612334876, 0.17064246919847306, 0.1202573030886631, 0.13318270024272705, 0.11267821139265453, 0.1657383573511916, 0.15315254399132344, 0.17356118758118924, 0.15995879086755938, 0.15680261587183322, 0.17050437418924225, 0.17283747964087995, 0.11656784662796606, 0.19326334488728356, 0.12584788334225455, 0.154997636113436, 0.12453048024326564, 0.16649405712321882, 0.2158078569318018], [0.05366650838104468, 0.016773133125576763, 0.07126034192380405, 0.01977632610848354, 0.02479221784479676, 0.036879832736186446, 0.02290575122911363, 0.05633586131396794, 0.05330818990666059, 0.04680055644242995, 0.012357320933182155, 0.03751319975802495, 0.05819044909590195, 0.05072608289699401, 0.06453289485145962, 0.058395247380699844, 0.027588911827713735, 0.00865576985938054, 0.016537233586272886, 0.1372495086322869, 0.030522082459121466, 0.052489659433523496, 0.018861894833765203, 0.024286182296852914, 0.015215905244281937, 0.022470132567949837, 0.06922699135517882, 0.07203788286255253, 0.014341842972733563, 0.04730932692426348, 0.04500491912626932, 0.03943438739365628, 0.0661372208607293, 0.024892368519137946, 0.08403270535411374, 0.04522197864829533, 0.0427127763959429, 0.05544556755452387, 0.07015892199330753, 0.04800965003068409, 0.03915769558760428, 0.06115276554238893, 0.06677495841417583, 0.06341608804500391, 0.07936582029346498, 0.037278570009455565, 0.04641416084562098, 0.032544583307519075, 0.03015797810568925, 0.022686897146124995, 0.027716739343539364, 0.028038944433172865, 0.033221801202143394, 0.07036503028845595, 0.01595835073760921, 0.013723886767101866, 0.08251425014027665, 0.010375070344326238, 0.05127596165684443, 0.03585404100557489, 0.04301338546699093, 0.03943676226622155, 0.0624608530122186, 0.0749751788774325, 0.04206410293737727, 0.03396423999220133, 0.0473300036373398, 0.0544226371623095, 0.08247338701039553, 0.021485316965188232, 0.04503944287857702, 0.05892123185819196, 0.02824367185483777, 0.04964794820895599, 0.03464525385249046, 0.0237834102834665, 0.06738222098999447, 0.016822448120482506, 0.03935475255392733, 0.037906283302412885, 0.014222167590032182, 0.0844168295002272, 0.03355491155337903, 0.07322214754118074, 0.05899540832146041, 0.08957008846224317, 0.020582924762199965, 0.026678642325644052, 0.08437391325470903, 0.061254038535539186, 0.01695460403308032, 0.038342106892096425, 0.025754780508577827, 0.05297038726688874, 0.04138189397992627, 0.03791498989167233, 0.0336495463946654, 0.05046938981620535, 0.019715709401474848, 0.020654291598006122, 0.07619365704275909, 0.02154400887628717, 0.022771297052742976, 0.053411313002147985, 0.04308224144962527, 0.04720877022332242, 0.10690481191681278, 0.043125992730980924, 0.030166678949289268, 0.04069982674874125, 0.013045410573061918, 0.033744200388149875, 0.014035192340792669, 0.08254323124645219, 0.01753937043700247, 0.061638848330344886, 0.022250125522635156, 0.024586119125747395, 0.023003789416003614, 0.057391538134505676, 0.02880257513043621, 0.009063875430353708, 0.04180281332904293, 0.04020646612550463, 0.03932131281603248, 0.026046979849437074, 0.008787549431285551, 0.030998160138786323, 0.029127337038517002, 0.030160284030341336, 0.03158397799838455, 0.012761361450107108, 0.026781411105466467, 0.06106980205062897, 0.0461694187364511, 0.107883044909085, 0.02964116944631021, 0.007131627400315577, 0.05974633153527976, 0.03310549756391876, 0.02899644900143387, 0.050514355346920996, 0.029231000225991014, 0.012855379590614429, 0.025469849426900188, 0.0922496188732405, 0.025268534926937956, 0.04450731054549256, 0.0605633681369645, 0.03270039026955924, 0.033064289694471706, 0.07258035738261477, 0.0017451661269954077, 0.04979883305608265, 0.010028498870651088, 0.056034543611589945, 0.06593680459885828, 0.0684488145634532, 0.04810511224692868, 0.019341178591393175, 0.029964445143817898, 0.07704362393386903, 0.09878093211521065, 0.0369633324894934, 0.03872585182468738, 0.08155282511706315, 0.055350928882797884, 0.007134429366898633, 0.019978098345980532, 0.035601645678041444, 0.06216530395191043, 0.03870282705212313, 0.025620163538523262, 0.02094749642926599, 0.02932558144112268, 0.05296940284390604, 0.05493909916690281, 0.04969528095135766, 0.06717416683151838, 0.028585337492967808, 0.055822708809207526, 0.066278089108246, 0.0337495744949387, 0.04962630622509507, 0.03929271092337947, 0.04827255608453866, 0.044616765357674136, 0.03162624115394729, 0.03698011364547476, 0.037516654814563455, 0.025116947194140767, 0.03594602518264325, 0.04655994737761156, 0.03810569598910309, 0.024567355717261954, 0.011480247936091356, 0.051068474403432304, 0.02363246606452571, 0.03338878921743843, 0.0783008661481642, 0.005041886057193962, 0.026919086681558724, 0.013271551109820366, 0.03475272066650852, 0.07675078682481282, 0.03435096117637811, 0.04479916706200569, 0.02508232001996329, 0.03115914968563424, 0.03316454379068267, 0.05433437617255315, 0.021380954722483313, 0.03438247037270377, 0.032401363170074846, 0.033246231746048696, 0.03685136107848056, 0.048984853145215786, 0.020229294745912476, 0.06758324246132566, 0.04295442734033831, 0.038269566026546305, 0.05446348113999252, 0.04560630580770873, 0.022081974968915025, 0.018894039883068012, 0.031013782586782213, 0.054772455891173695, 0.026289456253570896, 0.02602885803958822, 0.06235868369619693, 0.07031400117181963, 0.053186067830651045, 0.031252736901684154, 0.01339610647259941, 0.0802285272267557, 0.03232451305995065, 0.031274173957025336, 0.03877556710053356, 0.03421172469614014, 0.010056102933782724, 0.058430855147420406, 0.03026908766778727, 0.06048614647419703, 0.0196059194258264, 0.008751066409111505, 0.012426401954144241, 0.03901638300909151, 0.06800385537527262, 0.028132221383613445, 0.053838721115983305, 0.05120653493870651, 0.038166209274242004, 0.03605296722643318, 0.039104663151045965, 0.03527513900471311, 0.07414074058854773, 0.03864220268423519, 0.08180008765550391, 0.058242765240251064, 0.0009708019394067027, 0.0758116779428336, 0.03310821717604995, 0.08101444150651656, 0.029913741614549395, 0.04080815541167413, 0.020199754395552223, 0.022073615034441316, 0.046963239043590524, 0.025114126075359604, 0.051610424153266415, 0.054498472205934026, 0.11716104382949492, 0.05117023003197486, 0.0394105697200904, 0.05515648427629664, 0.04095050220888469, 0.050879691186691486, 0.012431383440871874, 0.05630267821552773, 0.033018726615175124, 0.05698374570197156, 0.02402818878181279, 0.08591154364929085, 0.04012303532011086, 0.023228136349409338, 0.014639661568517407, 0.012160736068542446, 0.03773993497053462, 0.047728288918733604, 0.028788988561099096, 0.020496416198570403, 0.03390020653305035, 0.027442242379390427, 0.014813236024741445, 0.020784442275462132, 0.05157615704041335, 0.03349041078059423, 0.0307089715234695, 0.08035064164188602, 0.02734285970819333, 0.09232544625598578, 0.043402719010989514, 0.030121994955885797, 0.03794324321431979, 0.030492182047436797, 0.02025011701569442, 0.060366721027680946, 0.02251046518194339, 0.0775010014073022, 0.011076643131673338, 0.03835489672999229, 0.07545576115409214, 0.0547530010883366, 0.02082677246371825, 0.02762951831814022, 0.017093346386607138, 0.0672843302750299, 0.030920049814026684, 0.05837308445705041, 0.02720046886092713, 0.03606106860623245, 0.1274094310018324, 0.03083541242015218, 0.07076918763378937, 0.037552572846893346, 0.05880374078368468, 0.08408568799495698, 0.017088996922417034, 0.041741032168389335, 0.023528442815727284, 0.059940320319466056, 0.032122681450639526, 0.09614904471222432, 0.060674324481477665, 0.030459753545602004, 0.0195083255699325, 0.12362375389784576, 0.05373280563001191, 0.04641912509537032, 0.03749169950043002, 0.050098139777659416, 0.061186431276221434, 0.07202102892821835, 0.0491414032125425, 0.029464545960147536, 0.019822890847741116, 0.05776224425062538, 0.08416868596067352, 0.014479891059078999, 0.05248607414203787, 0.03981915505362615, 0.04855588987289418, 0.17309142246602044, 0.12543184397321555, 0.13540326737828795, 0.09117900333817928, 0.14893890719019598, 0.12254302600218404, 0.1290456875557861, 0.11622267039192301, 0.11016010336818234, 0.1779330368604391, 0.12701923943935864, 0.1300917959381496, 0.17471370557623525, 0.18233899237407794, 0.15306467370640847, 0.185639008038467, 0.14065239458314835, 0.09138608456499155, 0.11374416911313612, 0.20105812097749404, 0.11343142137892785, 0.15549631338686715, 0.21185603833967642, 0.22397053908676873, 0.13304653577506542, 0.21991257135185505, 0.15960778470241255, 0.16237604341680006, 0.166289450360402, 0.17001649875554348, 0.10104783990931127, 0.09847149388083527, 0.1423235234594153, 0.06941341885155247, 0.1824411425379015, 0.1876354638126589, 0.18189551939647045, 0.14205110259354115, 0.1656726729725638, 0.09603840629419974, 0.19471541858248173, 0.11808932788910405, 0.2889335540033156, 0.11801109499027652, 0.08602686286453279, 0.1562961551450914, 0.17512875669185193, 0.12015245629534607, 0.20619523080606617, 0.12409702769570774, 0.18418451350542808, 0.11066119381857496, 0.12749568484122717, 0.20897449054304632, 0.1813884611211477, 0.1442849230501921, 0.14667111839498245, 0.1944449282581768, 0.19759618496942907, 0.16425131940312926, 0.11345577531404073, 0.18099182675923073, 0.22302803643528493, 0.12793665271132224, 0.20732973041313313, 0.0827008921412691, 0.09723886607154723, 0.12779896372869132, 0.16266816806408668, 0.1800584099105289, 0.15976906153223208, 0.19490425925581686, 0.17908396139260263, 0.2229058454113622, 0.12522256407406063, 0.12900433412963344, 0.17638103465639776, 0.12982193380594254, 0.14615321231465186, 0.1745783378400149, 0.1213172700015768, 0.2219623008803014, 0.12635727818574638, 0.17251178502075135, 0.1796577612478887, 0.185025203071775, 0.14135514235784932, 0.12577594768616462, 0.22903266422931226, 0.18035090228001918, 0.09096713406184027, 0.1459794329299081, 0.10826760572531532, 0.10052616467639323, 0.14395394242338597, 0.2474975129289012, 0.12858365992865256, 0.16380861251344606, 0.13128114744059502, 0.14370042860748308, 0.14287679215833066, 0.13747703674579823, 0.17697113686271254, 0.09510629945584843, 0.17149379206520898, 0.15841412778583266, 0.16346874526671826, 0.15961527704231201, 0.10952182955318883, 0.09290577318038672, 0.10651571586007073, 0.15593839208445243, 0.21755323504968999, 0.1477552400601487, 0.17987019742929167, 0.16499033378016564, 0.14243175636135763, 0.09518231069969554, 0.10351211493534428, 0.15783825949315103, 0.15439497006516303, 0.15514959731409628, 0.1496367060369061, 0.23006513624662356, 0.15927488885579572, 0.17038276539214198, 0.17071615153503034, 0.1669010336721136, 0.14774266089643204, 0.11022069326211369, 0.13223852751956833, 0.09941645567455601, 0.18276820079453532, 0.13231688299246375, 0.12205109796336583, 0.2085609869250367, 0.09577729288608798, 0.07518833518148431, 0.2673987918082745, 0.1641385206171582, 0.2582563904504622, 0.14880959154857745, 0.17335717836695333, 0.07618912180224735, 0.13094172452486333, 0.2459177936637594, 0.13813789483279953, 0.10364168338597783, 0.08204513619984351, 0.18233332332343827, 0.16499969537460035, 0.16748413383480043, 0.16377893426725942, 0.18994344158038018, 0.199642620319801, 0.14731665472349814, 0.19124111791531886, 0.29265217543129, 0.05841131990535125, 0.14945171112495084, 0.26925039567774345, 0.18238178604552824, 0.28547053015039814, 0.08216205653884719, 0.19393845220967648, 0.20180288101396254, 0.14790959145513274, 0.17182474204849812, 0.23864751201002832, 0.07284050551994194, 0.12652218627232698, 0.15382095570525817, 0.0833543574798011, 0.1596089185125405, 0.1258910064315123, 0.22209674931101261], [0.005801336308415499, 0.025654043776974566, 0.07639388944352828, 0.040222699528620134, 0.011902319289924157, 0.03536517731845379, 0.04084333799959671, 0.0681386179020328, 0.10983230966714122, 0.00551328533366623, 0.056550917516071955, 0.06542532599621242, 0.011080365361375435, 0.04993521585880269, 0.06589284647376308, 0.0627895200534934, 0.0287218026501397, 0.02681995490415683, 0.030066185450601964, 0.009380770573062042, 0.04643494481100671, 0.028036012231642683, 0.05241971943647631, 0.04086107676548343, 0.020624322238408273, 0.02987158954173567, 0.06202399520383728, 0.02414670832935841, 0.05621568127084644, 0.03987628223013975, 0.08310914805699741, 0.006080429800110119, 0.02653318904190054, 0.025283716874377384, 0.07194553096328052, 0.10406780447210036, 0.05064023508419914, 0.09963399400153469, 0.10166103200566384, 0.03336294141087321, 0.023563627318869677, 0.013091447669261647, 0.03882201501138268, 0.018663861105338703, 0.040489462835173455, 0.08778278235225909, 0.03939721297713057, 0.017201362868710872, 0.017177334520965815, 0.019676012640458443, 0.021653028933571714, 0.008200265470922233, 0.08288951830998545, 0.05597060208298987, 0.14762633810600928, 0.06942360782094541, 0.028945360512983416, 0.06320098204718483, 0.029819139331999808, 0.024306619607452905, 0.05842993967235089, 0.06896056129687256, 0.05382059164525521, 0.08390826203169362, 0.048537591862822735, 0.13406990666783627, 0.058713809722253395, 0.04890457096119081, 0.013767667734364589, 0.03388195065781474, 0.02849660344391821, 0.042699649479360356, 0.038659677149788026, 0.03543263902106593, 0.04199152376743094, 0.09585377910444814, 0.03997157207660137, 0.06389998365193605, 0.048161910005634835, 0.01865273942389796, 0.05497861015159757, 0.02460531537391005, 0.027405184791273168, 0.04462276765656087, 0.025707392224801645, 0.016815559074823416, 0.013607698042065868, 0.034280442782948096, 0.03421539042685782, 0.030654253693477764, 0.05825108878554837, 0.06254608795467405, 0.07636690016595588, 0.02494121620040988, 0.046966755387162974, 0.0379015795225578, 0.05410738815102847, 0.02217059410477598, 0.06069998842694106, 0.10847723802491542, 0.02087806205024883, 0.04124967103463508, 0.04680274745389339, 0.06385016112378047, 0.028831782232549404, 0.11497571673845092, 0.0795330572873354, 0.0025998050771323185, 0.035525975343320644, 0.04688608249829662, 0.01896957615240207, 0.020695315606351343, 0.04719134938392428, 0.009373173853682895, 0.015040139776594458, 0.02001496824255634, 0.036962623858163436, 0.029485511871415283, 0.04193708172909195, 0.07152081947893867, 0.048537882976233966, 0.08439087444135258, 0.03494590505837433, 0.016996191116049886, 0.040349889276248795, 0.027930395519961754, 0.04384319275437344, 0.03909386131131361, 0.039819415523520404, 0.01948622776375663, 0.02664790496290211, 0.03838891486426996, 0.027037663685698664, 0.024943522125061963, 0.016556807132738254, 0.05150224487747877, 0.04117869298845049, 0.04200899440254416, 0.018605506272926446, 0.033579644702014425, 0.037020088113363714, 0.0371357903725678, 0.03125457551270243, 0.012529007940282746, 0.04024208155310443, 0.07239654990694216, 0.04290188136961191, 0.024669373730918574, 0.07128994356119825, 0.07563730867038812, 0.05814777799851953, 0.06356704184004376, 0.01463544904254377, 0.06744251210963534, 0.038717470822795745, 0.022775633110394402, 0.023763130020890987, 0.02844166919408787, 0.03391413018107414, 0.04257036065081916, 0.02796744161676015, 0.014444935424703986, 0.08500466408628611, 0.023186911242984, 0.01177557483090148, 0.028857007592676148, 0.05437516269364184, 0.025279248666559017, 0.06110015062374934, 0.038744237934870106, 0.02663973846562928, 0.06518485865766002, 0.026010320627040444, 0.04852728798024116, 0.06935677431043118, 0.06804863321444682, 0.05014638416469098, 0.10088974234437752, 0.057004606276149714, 0.030890710561746554, 0.06857701937758154, 0.07264836300765315, 0.047430709725426096, 0.07620288074136743, 0.051285648838646954, 0.033980530851911155, 0.05502316582527372, 0.08710335429397323, 0.0571361129292317, 0.09353150613605977, 0.0729337077768099, 0.09979788319117601, 0.049288028610810164, 0.06447906951389967, 0.0329395437673215, 0.020556368324304783, 0.04694155492489377, 0.03516172734840262, 0.033566307111252705, 0.02984637375770798, 0.038191880880584644, 0.019139237814552842, 0.02977926637076082, 0.03138312123595707, 0.02220110164114064, 0.02535194083447418, 0.04358776754909947, 0.034488956594178756, 0.009711862282617199, 0.07534355991670201, 0.024874775309956847, 0.07004696590405318, 0.05696421812078165, 0.128489239591985, 0.021577486918578227, 0.05800875985333997, 0.02988311150411685, 0.0548297630983495, 0.11102885473519565, 0.035346913782338944, 0.020843856224429705, 0.1030488309240149, 0.05772010941478995, 0.06497338774704164, 0.0529260844022276, 0.029104375468206503, 0.0738585137972428, 0.006896875556483264, 0.05205742496576521, 0.05810684592072522, 0.029027243820770137, 0.018543533590291778, 0.02275775644868132, 0.057922946514501694, 0.059809016679684, 0.06215359046754818, 0.047509624442506226, 0.007524421746512094, 0.015625180056949538, 0.06064054766489614, 0.019513027434567773, 0.059994509548790036, 0.018039501362269925, 0.052152902503768285, 0.06748298453467508, 0.0543649354198527, 0.03799669699923646, 0.05861028060016613, 0.05315540516148171, 0.04044500292248784, 0.05882580411590396, 0.10645865763147032, 0.03384882118552923, 0.10500433163777476, 0.03252026767680242, 0.06299913703133503, 0.04823235562071205, 0.0654903055739499, 0.04149601426756671, 0.02702609958848165, 0.055789479745491866, 0.031204496345092213, 0.014393897689578515, 0.04621957834329336, 0.056027051271690484, 0.005794305536490415, 0.07222841659020032, 0.03950102938218944, 0.08725263418689852, 0.022886727350733937, 0.049301155527392705, 0.050091340747331424, 0.047167650453986666, 0.024253690592764367, 0.09554328366873727, 0.03476915325248434, 0.04373873283545818, 0.057393713824210636, 0.07253086044182701, 0.001237705535811162, 0.030557406773310036, 0.0069245342033795055, 0.022095318305336183, 0.04690559858816767, 0.020811603922817497, 0.052767113497060154, 0.01070801885948787, 0.05126302243180333, 0.050113875223624135, 0.048088001673139875, 0.05689874824677264, 0.035180998290137905, 0.04085791665279577, 0.06446905674472933, 0.050415710035351016, 0.07780464035609076, 0.037584832809384794, 0.05051685662399377, 0.03374336152187279, 0.02117647053373437, 0.022669526102441936, 0.02627359248787886, 0.03980287568523519, 0.03905261896790997, 0.010439315435266303, 0.03952108173360748, 0.014834705638819405, 0.038786874558295936, 0.008188020513062517, 0.06430959554329034, 0.019585146951759537, 0.08048179589452283, 0.02058964909895534, 0.03870996699157742, 0.027381631418041168, 0.0010494519970492432, 0.02849228079280546, 0.0071583054546687395, 0.05712618442973303, 0.05143875151031441, 0.09335555872249027, 0.017510107793514768, 0.02907671777892017, 0.039670863414123174, 0.0950665777969745, 0.036191655953805295, 0.0407233341566978, 0.04154815804213286, 0.08678903607952018, 0.010900587508184536, 0.014192285372935718, 0.03011495460786166, 0.02753415952376541, 0.05588982194181412, 0.05214248753843769, 0.10702290437034062, 0.010500002047798086, 0.04625276910261281, 0.04244425874804297, 0.03976644820443565, 0.06290607650073306, 0.022701433664488218, 0.013564046352140367, 0.0243223856969346, 0.03851531937177624, 0.031646375859817194, 0.019536630603514855, 0.0663884976998933, 0.027059403345769933, 0.047677420680561376, 0.03350926420441078, 0.01534936542157084, 0.11056099717895831, 0.1821175776422024, 0.16758939431559655, 0.10501252877856455, 0.17326757672332949, 0.12546446399703143, 0.07250714235969129, 0.1431326961685573, 0.25471727874490524, 0.13867136781975148, 0.1500701432627055, 0.25808932199593515, 0.08865209296345712, 0.2663664423650311, 0.08939344390866258, 0.23286364011226163, 0.1649675043600221, 0.15595711527332184, 0.1489916906481789, 0.0721532786865869, 0.12588649417363829, 0.1999765120807194, 0.1010188511422565, 0.15199936716066254, 0.17097622306356508, 0.1566845770444601, 0.23358425305735683, 0.12119644261415928, 0.17136829154145333, 0.19864846802046224, 0.1397899327979934, 0.13665612756965623, 0.1486829418929354, 0.1569835198742728, 0.1664750274991797, 0.33320405911053386, 0.14633754839099225, 0.26436992530380526, 0.16425487405109793, 0.20850670193472218, 0.14670442789793015, 0.1190746165511589, 0.1689867846547596, 0.17339675446912167, 0.17774589690229586, 0.23065914550135214, 0.12904694393998192, 0.13830122477825613, 0.094986452660974, 0.08727075982718699, 0.21381814273134356, 0.14797653221795637, 0.1198523796554054, 0.22001672866604022, 0.2445016035269345, 0.24530139931988335, 0.1427597339235006, 0.18813188878759263, 0.22752791432844055, 0.193554044611031, 0.15539385678787387, 0.12808622371765876, 0.16283885245361637, 0.14504436133128984, 0.13296497805464652, 0.2769254015818719, 0.21812703490497606, 0.13793995303492393, 0.18649468228461283, 0.15231131816342955, 0.14251637843347367, 0.1351276595866488, 0.1189687738435403, 0.11037767999955725, 0.12534088635396573, 0.15147179305072755, 0.10789802192800468, 0.19876684392652205, 0.2120154459149607, 0.23025177058673676, 0.14586712444020858, 0.13242621906101704, 0.1401517101593556, 0.18794537702154732, 0.14567189459358493, 0.15125077668457262, 0.18734788972764246, 0.11208708262852124, 0.1488599082034442, 0.11920425394970564, 0.1697825661469852, 0.13145979914453723, 0.17233805160128302, 0.1170654513783032, 0.2380013474894147, 0.1785721840156663, 0.11977589343704524, 0.1146669679832074, 0.18959816575290697, 0.2921849230845129, 0.09328466494597736, 0.1382565465305121, 0.11329856641109913, 0.1898154589317499, 0.10727113217956598, 0.17024254065848168, 0.25015848869037244, 0.09851007406870205, 0.24856409118060144, 0.1315002945522147, 0.16675766797796374, 0.11701694269093776, 0.1281307027825425, 0.06952544388872, 0.1970086414967814, 0.09997566921576377, 0.1579360276340477, 0.13999904415780498, 0.18424835927303762, 0.1796639359165584, 0.11645576796464382, 0.12198855454522757, 0.056675253586182674, 0.07841420119568225, 0.06817664650659408, 0.05701383380519767, 0.1369376802035878, 0.1787266733064767, 0.1332939055658156, 0.17507123881049697, 0.16864734641726942, 0.09279227725440457, 0.15437344299449077, 0.0829716046310721, 0.12372322275393433, 0.21239452154165317, 0.13838960068120112, 0.1191389909194362, 0.1274678452060588, 0.08928460579726005, 0.17241138153739516, 0.11489985871218866, 0.14127811987794217, 0.1514498063273007, 0.19868507170148436, 0.21081664088752963, 0.11833737949810683, 0.1814935224190835, 0.14795005621929325, 0.12675415003491988, 0.12370581723629467, 0.16409140620981494, 0.1375746669908685, 0.2787590483503957, 0.11831614354084577, 0.14980348337802196, 0.12846262569749547, 0.10052158347060604, 0.20286803434212364, 0.1713965601858593, 0.13127111168878694, 0.10386003376615625, 0.18351760332382497, 0.16113032316488607, 0.1777244617621745, 0.12746068994484602, 0.11738880943026274, 0.07962926260886655, 0.19432017850058694, 0.11706349785409628, 0.06082335539582757, 0.24172672581288124, 0.1158474711701274, 0.10819727119298712, 0.15475394354472238, 0.15866750370590918], [0.038561399560421705, 0.03470211289823055, 0.010355199938790213, 0.07435069464507603, 0.07825340700125502, 0.056867403759350704, 0.023589904134672497, 0.01675480255676854, 0.025469901137835076, 0.015424614407933288, 0.05433031207611484, 0.010887146495553035, 0.004632673967975162, 0.020537641304995746, 0.047097089925720814, 0.026475016155370304, 0.04119001959841098, 0.03329446081132178, 0.02475387705940633, 0.05339821289864279, 0.02764552955575768, 0.03621402955163391, 0.03830703921736248, 0.03202940833063857, 0.0030287175961289437, 0.057926079814112, 0.037705238848443956, 0.05826742561053365, 0.0652830021816396, 0.019511294160639087, 0.07129743590109772, 0.026059465167383035, 0.033283678123787526, 0.016192256533090147, 0.03785328533981116, 0.0028330991992862116, 0.06788390132808877, 0.0477222406545714, 0.003374761666148721, 0.04056430196449642, 0.07265873583814791, 0.04135750174041718, 0.010542628137514958, 0.04427124055162553, 0.029158656628081397, 0.029813828427464734, 0.05311963268585744, 0.06670472347327779, 0.01540071821035517, 0.01619940030298406, 0.009644232998271624, 0.061966393052810625, 0.033947251992480415, 0.027124346534331, 0.03904243765939628, 0.006150941969075751, 0.04886862228534395, 0.023631372474013798, 0.03722888920756598, 0.06496355117809388, 0.030651329152826822, 0.043248501681392236, 0.058033221040762244, 0.03286091633321297, 0.04500031876828402, 0.045931038987492366, 0.0375517952676502, 0.027537501582335082, 0.0415580444067957, 0.07434425950651208, 0.027540366751171892, 0.060338904375150326, 0.0299391393444591, 0.04666126633603727, 0.10119672143651594, 0.05717928581420453, 0.048511230777348244, 0.027801482074503458, 0.049631626705729195, 0.09741779356714218, 0.038262801470174905, 0.01645230316376734, 0.00788431165875086, 0.05600699892027244, 0.0183354104839025, 0.027727776755308433, 0.06821308164827286, 0.0397244512644266, 0.013608735133593362, 0.060010183707720814, 0.01100201563413946, 0.04360184824514774, 0.0504054329658468, 0.0712679568377714, 0.05173320123445123, 0.02189896230946385, 0.004889126209872625, 0.04101927392184734, 0.07016371004283428, 0.022153014302133553, 0.045034804216195504, 0.03756863388022588, 0.0436439715896643, 0.07837251069084292, 0.015968896895496836, 0.00534207473749355, 0.03655236845295276, 0.04724653452754982, 0.10677799372182739, 0.022230785632986697, 0.0671371954282926, 0.02353924657067945, 0.03552504837693226, 0.035606203901190916, 0.05961216655710052, 0.09566018102510322, 0.03631891081890753, 0.017173753059919805, 0.053214397762090936, 0.04117230764560161, 0.03780235581460499, 0.016238493769760096, 0.03854113653482449, 0.027498932885787183, 0.019011869951481783, 0.08396427071983777, 0.040395417881588784, 0.06825217511504889, 0.018037296944267808, 0.07385359551276892, 0.009657620384748425, 0.049554385890763615, 0.03763689997515852, 0.06753777514301962, 0.035919775179917776, 0.05825000477113551, 0.034079654968433806, 0.0439540226943791, 0.06662641396565784, 0.02278013004650993, 0.039031961407031746, 0.028554904650175766, 0.03254919132638363, 0.04136533498944294, 0.028867303814378478, 0.03732468084161801, 0.027567695022650787, 0.09821724462052507, 0.08009323609932777, 0.0519544780705004, 0.0723981127263077, 0.09329368180084614, 0.06171911136217176, 0.059473573590718934, 0.007538698752590967, 0.06776083696393237, 0.03147400990729371, 0.015953497570608894, 0.014674007205382712, 0.06177965912126726, 0.11412786425001199, 0.05732093930184361, 0.04913999744120145, 0.010350565106848316, 0.025692405629782908, 0.01408614772146628, 0.0386312514573576, 0.1318778380030586, 0.031844164440107924, 0.030595249601549683, 0.02086681587952039, 0.05250979605461321, 0.0392711493787506, 0.019553032545973698, 0.03308910711277877, 0.04037065408943642, 0.0515616511655671, 0.04775550802268329, 0.036605140419616815, 0.05738076693829029, 0.029240976605984955, 0.009269388092140998, 0.048614932269218473, 0.0379250064912823, 0.07451727280333158, 0.056140964715591365, 0.06213241962776069, 0.03869239676503405, 0.08055805994738495, 0.06260279761326891, 0.012409826684292528, 0.031133252083353942, 0.04037266123979803, 0.058645543627320766, 0.043243533601203275, 0.06118397596442412, 0.05666870353443008, 0.07201431033712241, 0.011586654675944198, 0.021313832013777668, 0.02437046537506244, 0.022179191526506218, 0.02025020703102552, 0.02025402597932806, 0.045206817768273816, 0.018309777181956078, 0.053381481538376505, 0.04912726122946028, 0.04681315092790512, 0.0227539949569731, 0.034247772963417154, 0.05727503914386035, 0.027626459712102532, 0.017316712727469784, 0.03462734271682078, 0.009797288747053715, 0.04497402663072271, 0.03369830789104585, 0.02483583889120529, 0.015868327745627013, 0.126998616352437, 0.07009067888101263, 0.04826828131392118, 0.037783808825958165, 0.03904763939640215, 0.05375013070841951, 0.08134197473766343, 0.06421824721919914, 0.03514523730583249, 0.046744563076044285, 0.022110670707338763, 0.0368436887079189, 0.060639927133677475, 0.029314994106009126, 0.03632200581412162, 0.011922015410457409, 0.03923783604536326, 0.020107567205183932, 0.06419580850389696, 0.09180531852067479, 0.033737278783753995, 0.022258910635906844, 0.029278934347413244, 0.02509494131851581, 0.018670116213240454, 0.003933890698282349, 0.05819386201760462, 0.053352362536374605, 0.0035300797683322023, 0.025785119505599145, 0.042207533749000686, 0.03969712873860713, 0.07954735248800247, 0.06918934579457968, 0.030258019612501227, 0.05262123886495829, 0.018371006759304195, 0.03569568297074687, 0.024590156409108353, 0.02146091514958009, 0.06602043841755198, 0.04900218205406301, 0.05432209961356656, 0.04127305586852374, 0.019588199812137795, 0.0568782132599623, 0.0748148366748806, 0.04059993654429432, 0.109858364317446, 0.08409603784281401, 0.0574940215465763, 0.00584568944759667, 0.044433459669591925, 0.07672965811986117, 0.031094057109927943, 0.0462676924953778, 0.09016699352932554, 0.041407155729229414, 0.04954229319287885, 0.06305268657724224, 0.07152055134816517, 0.06507477948382016, 0.025438991405310172, 0.0383614506121845, 0.09927633819320511, 0.038368778243180246, 0.05379446421659762, 0.040236699785436356, 0.03918005769411403, 0.08072852983229584, 0.0298070925993905, 0.02621948369778693, 0.035772575215706905, 0.01055985649732212, 0.012806289634036442, 0.018979585091132792, 0.009263938334169648, 0.15809112979519754, 0.05290085329644142, 0.06433747348285491, 0.021596851706084226, 0.013905843182827437, 0.02697990640186735, 0.043543361262568546, 0.021972259686839198, 0.03899736104593162, 0.02257454460636983, 0.04412774845296818, 0.04254468138359728, 0.06165454930235302, 0.011638557132814201, 0.043104944465261315, 0.01111760872581433, 0.004964741003218918, 0.04648218945329709, 0.03129925184522665, 0.03233162618632759, 0.036246113313902775, 0.023200942143317194, 0.01553309533084112, 0.01516876785430096, 0.04258497760841443, 0.062340830017121575, 0.05514793473506167, 0.053127305056419105, 0.01729952362966874, 0.05635239732181353, 0.1205160263024511, 0.01274636049093979, 0.06303279893472791, 0.02411057387718991, 0.04442326686975937, 0.03994859326931258, 0.0069560237687021015, 0.03658386615795955, 0.04890117336124663, 0.04000429935272663, 0.0640772449062957, 0.05677293362696806, 0.016041112173679137, 0.02950825702188717, 0.01646598166365537, 0.00773248021423276, 0.05962611701820166, 0.014647165399735734, 0.013111547901174955, 0.010134204640053213, 0.06663153143299204, 0.021734400877668973, 0.025301317744437727, 0.01690846255740091, 0.08101419635838078, 0.15320773296538862, 0.15222467361919342, 0.14639345748770624, 0.21626444533467296, 0.17298574829774518, 0.07840050354359612, 0.09989125398738731, 0.1828526696490665, 0.11670755042183785, 0.12104373064733322, 0.22097288300433468, 0.10340610368838234, 0.16493563510237202, 0.17157620780410307, 0.08525616309094815, 0.137209503520881, 0.12762823337388615, 0.10210104992673283, 0.22716710223786293, 0.10727271032069, 0.11463575756117222, 0.1909253977599644, 0.2594154814798986, 0.12405466303349504, 0.11886570437420761, 0.14514389147441234, 0.11830570942331707, 0.15340562879798875, 0.15902643122019308, 0.11395645207695423, 0.18790005525994688, 0.1537823755173914, 0.10381214561000948, 0.2118750066766816, 0.1141536201260263, 0.1637993122060453, 0.13010431381483234, 0.13321322118563036, 0.07118357991379115, 0.14218749688758006, 0.147209816101578, 0.21391837767535643, 0.11473773918565243, 0.1644758138084604, 0.156895496371773, 0.1680204719905892, 0.15458830001373447, 0.16176565520225034, 0.2103199860862186, 0.19718845765436852, 0.1253016473304841, 0.12206940746475613, 0.07618332251666055, 0.15930459774549932, 0.17467247472415048, 0.1436050046956347, 0.17605854228379267, 0.18442653600246678, 0.1357554226753212, 0.16861278053012588, 0.21527053818346994, 0.13180550398124805, 0.19643491825028775, 0.17774313898576846, 0.16827018601038765, 0.14505962180274148, 0.19914961209700954, 0.3488882384713619, 0.16212613021414127, 0.1373237272303912, 0.19468201714898312, 0.12469372591905056, 0.09743389673531057, 0.14205608216504897, 0.14135826799658038, 0.1749515145896904, 0.13072689814913657, 0.14432710385130298, 0.1489964863585849, 0.24411377917614677, 0.11531025967410496, 0.12594468621236662, 0.09143922808429888, 0.14179216487513435, 0.20578194169267533, 0.15877356091814657, 0.17901417078270068, 0.13346596891360898, 0.09722959640766345, 0.17433669838693835, 0.12976596342219462, 0.10914161245548919, 0.21083464395375023, 0.2106977746851983, 0.17055803098745886, 0.11441428154226273, 0.20907092569095476, 0.14987552628642128, 0.15400642559172648, 0.11942473405431356, 0.12451430046630484, 0.12072722908229598, 0.09594652936944077, 0.18749125542179232, 0.11525118663426369, 0.16693644225597384, 0.10813986822482079, 0.14443276269781974, 0.19692732892449827, 0.1053628224819418, 0.2887650146599739, 0.08317552957563631, 0.1715770198573028, 0.1533575491198609, 0.12452217585016644, 0.2170041491908412, 0.11991500734321534, 0.11809576302766801, 0.10507393072569564, 0.11543837255768238, 0.09798675940762605, 0.1849902541406693, 0.20274247253133407, 0.11578799210368626, 0.09528215493886702, 0.15577374446776607, 0.10969367839636342, 0.1722439606824229, 0.15746273851442724, 0.12983854259214095, 0.1009622066011352, 0.16348454199971693, 0.2023056798404263, 0.11353367879506081, 0.13810052506385312, 0.16017559375013077, 0.13986762943527392, 0.18062514643515312, 0.1414359646338609, 0.14753019407151208, 0.18634884978734678, 0.13722251169383526, 0.08668573678381021, 0.14115995847650115, 0.14947823308888944, 0.14510665960129232, 0.1172491669234249, 0.11451951904042114, 0.18280848169759398, 0.08635805799595772, 0.16438130920212116, 0.2836609998297307, 0.09593047216654786, 0.1905543507347184, 0.08479441891634658, 0.15533071582115468, 0.109550925572553, 0.08444712827763251, 0.1106654073021585, 0.16180397492022286, 0.21048061940218174, 0.11083105083314643, 0.14976327908375572, 0.08826630640654795, 0.14919723203826338, 0.14498598543145966, 0.1618348022982959, 0.31857478282144, 0.08331921702671437, 0.15353456139564514, 0.09995306196111826, 0.23518597436768396, 0.11455328819612343, 0.06895181257277727, 0.1339576288216537, 0.13199576957812234], [0.04693516575160527, 0.011895027090494913, 0.052631067773026806, 0.028850108970918005, 0.01722121220682898, 0.01931698744996421, 0.05033864925104765, 0.04616435872571123, 0.035650146704527645, 0.027981007118679346, 0.0610082583772319, 0.10537013862161868, 0.06869421550823797, 0.03375504436271806, 0.07075061000162555, 0.052012685430987235, 0.0888810843049038, 0.025176430091021523, 0.025806435902092247, 0.07659681847379093, 0.023960221461170626, 0.02558954300418977, 0.017449493001725887, 0.016325777997412992, 0.03192034996895781, 0.046181453977741545, 0.06045724197681393, 0.021924478783001824, 0.041666250495660695, 0.1251300512963245, 0.03034753507123359, 0.035058313139504006, 0.0419486534871882, 0.02271971252236155, 0.01979833772976793, 0.09629451714816595, 0.01963035954583076, 0.05231404909864069, 0.02912310631795516, 0.0625591114493868, 0.02686338059814467, 0.02017577009786281, 0.08371548366642768, 0.07687886906487328, 0.03861147106715268, 0.06938583968627839, 0.0126403387102689, 0.02082912243842598, 0.012285988571332588, 0.04650317260154313, 0.03379663527612725, 0.046941351911593834, 0.02567009331898824, 0.04450315834894296, 0.027231346034715255, 0.026576974797212792, 0.05062818069071059, 0.021336303287816626, 0.04903268001432862, 0.05821841513557781, 0.037401756947679866, 0.0366228370506677, 0.032649353492043676, 0.019488719464730353, 0.030051911317352808, 0.0743498825918763, 0.05087626294323033, 0.015574226591495738, 0.06420988919994523, 0.023908861011507052, 0.10136610347657435, 0.025179952180253404, 0.023928754399680806, 0.0700622187146256, 0.10104502836662917, 0.09225198608492652, 0.05191361494061928, 0.05443600156614858, 0.01367818866480863, 0.07936716094733247, 0.03187779186954422, 0.02556646269025101, 0.050304064211706, 0.029595299931843917, 0.02098292225010453, 0.01205202148881771, 0.03136117856258587, 0.07890736263605856, 0.049063767862295916, 0.023660533610851537, 0.015233698593933257, 0.08875198316790404, 0.01684668139674731, 0.044427668044884364, 0.033139971520511374, 0.029766851915947856, 0.05484867014832074, 0.03071690244870561, 0.060851834714412696, 0.08451443676265978, 0.013020429403461035, 0.043979862840065075, 0.053881652683259985, 0.06016171972958311, 0.0318382176825957, 0.020753283564361836, 0.03149908971071484, 0.06529377337785498, 0.025985104843012752, 0.044234912662256154, 0.02276543648012223, 0.07058098281343138, 0.05691399722690544, 0.009590014083040579, 0.04870921854049929, 0.10793719200357314, 0.026844559733064908, 0.010950579533293363, 0.025741910231449915, 0.040971067839212, 0.05730336907530024, 0.024795864423316334, 0.05560726573270175, 0.014921750463995964, 0.033580901086210244, 0.03868967332246323, 0.03412567003960571, 0.034897384879690026, 0.06809663628378222, 0.047357789646353454, 0.03612005354596242, 0.005572056726387312, 0.012518915689490255, 0.011844013295617076, 0.09987476011437756, 0.04826731987357621, 0.059821009786138614, 0.046922207374366066, 0.05418410802620554, 0.05701535065928775, 0.0707587075509852, 0.10351527887847155, 0.04393287100678971, 0.036697894515049075, 0.04468510806139919, 0.036321684057193424, 0.03210345264374009, 0.0071328373404309885, 0.04124131301538118, 0.03165918676513097, 0.047680634419403733, 0.04818034591153265, 0.018530083001561223, 0.019696777453646064, 0.05135579950987332, 0.042968454410231886, 0.04054343372943901, 0.05194111749710095, 0.04878181686264373, 0.03197197280373545, 0.007314510782429528, 0.07701114180587953, 0.012820811788251084, 0.047723665578110565, 0.04840017867184455, 0.030017377988946055, 0.017890508752316236, 0.0795842779259528, 0.04970379984907566, 0.058243653902243224, 0.055475073430927536, 0.02314176951204577, 0.025107250436239188, 0.056990789880435315, 0.01710879263438044, 0.05438137949714738, 0.04047644317090031, 0.020011457644643325, 0.03364180890663016, 0.038431639587807084, 0.020906418794766072, 0.0025887896903910705, 0.05075975629170576, 0.0028815554575093334, 0.03206517889104303, 0.06340254361050264, 0.054278394297486356, 0.06408197549922813, 0.05474579986184836, 0.0287005762689777, 0.026941935253900387, 0.054166277329767906, 0.04731274750684539, 0.06475869926714128, 0.0453093471456199, 0.06695280572579754, 0.07651012030340011, 0.022464670361049717, 0.04353806759501177, 0.02480429139048342, 0.019897427372333985, 0.02670909049019458, 0.02169477497978557, 0.043237159749673265, 0.0283414495718335, 0.08213977104112988, 0.025885911778576916, 0.021559970318189552, 0.02394635526974115, 0.053551882475374214, 0.025414164410904053, 0.03850449454940615, 0.055164593316975145, 0.02869208609955686, 0.036105459571004875, 0.03042223630473018, 0.015556948435973498, 0.06975707823350545, 0.06994280092898877, 0.0445777063648547, 0.03915720529133274, 0.04323291179213313, 0.006676706675094583, 0.0274394097692904, 0.02799084560284692, 0.033362998867467526, 0.04429434193298221, 0.06669579854895992, 0.07384637130364295, 0.02572611541367106, 0.04167232557290024, 0.0544660551954181, 0.030961782453701864, 0.0083329854157543, 0.03217701432144931, 0.05436311213059291, 0.021903717800253825, 0.030765537540578557, 0.0053940758281838036, 0.09305489985572715, 0.03586034973963134, 0.03068928306381549, 0.025440060097964543, 0.04192175997060634, 0.021669610906692765, 0.07683969132842557, 0.059929223535882856, 0.041055126836703676, 0.01348044892262307, 0.0482692504151454, 0.125632589652894, 0.0666338526794026, 0.016492216344622355, 0.1424612967117179, 0.0189995780707367, 0.09056883728912762, 0.12470837352016281, 0.02210594394484595, 0.008754236097898214, 0.01273143231012528, 0.01843873850790964, 0.026726856069158644, 0.0660145548622935, 0.06632082149266236, 0.11458834437953849, 0.03824961326655842, 0.04127759110903548, 0.11078161517939261, 0.07051475451237733, 0.05543077439670602, 0.017542624395460855, 0.07433584020022424, 0.03621514420956373, 0.013533644152865296, 0.04219727583169457, 0.05364743279173009, 0.06109539321773957, 0.010215567965661327, 0.01389918396354563, 0.0213868938191163, 0.04572593809796437, 0.06016932698267122, 0.031573806265969916, 0.030022572065072677, 0.022041898994376103, 0.033478930953048894, 0.11187624757088001, 0.02622128208918918, 0.04722006235932631, 0.023956502104298245, 0.08880667418481843, 0.017786219287964127, 0.03392886205185806, 0.04883248208751602, 0.035645845120832804, 0.00852138271570326, 0.030490243844988368, 0.029185885308130138, 0.06405926099227321, 0.07600683884154405, 0.07149390681015869, 0.06138627297214924, 0.029908227696714383, 0.030083853353355682, 0.08329359904652642, 0.01236860636591671, 0.018210396425978794, 0.10180671894622427, 0.021361858065750812, 0.017353410254262628, 0.06475737393503228, 0.032279490072640686, 0.06600312483046325, 0.022112093715658112, 0.03396107604907405, 0.0853412754593357, 0.02906981724194221, 0.04734591911396673, 0.12334807715829342, 0.04429453345496328, 0.10149962494089719, 0.023557088758435943, 0.012462833265383399, 0.03891738529707636, 0.035098184185523185, 0.032242782969748786, 0.013829887480354838, 0.032159478568862525, 0.05262235352288812, 0.052811879844915484, 0.032397034773302656, 0.017655955612539284, 0.026903994749450398, 0.0031338169590585056, 0.04479334096334154, 0.0806008612797145, 0.04951970509043144, 0.02952418398983296, 0.04381840597958334, 0.005903003836846761, 0.05541996872653404, 0.041663680270674734, 0.039767934415008754, 0.07257911632017744, 0.024477012883571368, 0.034603693582598245, 0.052481615510318554, 0.058800741549461126, 0.029615461450791167, 0.01938343983173611, 0.0020027579246802377, 0.0732628191490808, 0.12044413661163662, 0.12060902171557951, 0.16095260608821146, 0.10111016882283073, 0.14066111266372666, 0.17377966053543553, 0.2009861853214041, 0.11304779518996516, 0.08856567058471904, 0.13291746528158266, 0.1320026030824069, 0.1630929484963417, 0.1737329444938129, 0.08855885240219294, 0.21005724857170738, 0.19260893726060468, 0.1807925213248499, 0.1695712944192271, 0.13486954924320022, 0.15075165508014543, 0.18012910450418151, 0.09301664142478859, 0.1867700449281162, 0.1618050014780414, 0.22103861334823796, 0.17600136148112436, 0.13549041754055408, 0.1631312835360727, 0.1487313739715084, 0.22767091230038675, 0.16381852569118624, 0.08938730754438909, 0.08403573140141465, 0.2299649166243692, 0.10479300628386198, 0.2528075288019834, 0.2034178862888967, 0.14158018834648595, 0.09911536779855529, 0.10822713330027559, 0.15882807573483837, 0.16142791767995204, 0.18063467656893117, 0.1415720218492131, 0.09594958606025866, 0.15751797345376786, 0.06751910558030491, 0.19330934080625736, 0.09623870764288212, 0.17529432361404743, 0.1180071879418627, 0.23027308315279024, 0.3290189820672235, 0.16433260133189542, 0.1276919718891863, 0.15965891341047903, 0.17838401749970453, 0.11453566817386497, 0.16669886306889597, 0.14279719562299792, 0.1773362696891831, 0.10751073383876394, 0.09972235458272119, 0.1501481923004312, 0.11764371752618782, 0.09902415737029045, 0.12280919559059605, 0.11578827555621825, 0.10524728110120182, 0.1559061397828402, 0.23884664890506577, 0.1975827477872372, 0.07920538616036216, 0.15541486291875764, 0.22919879805657173, 0.3829929406844801, 0.10091158351109875, 0.1790806978580452, 0.11239239164898474, 0.15770290707868917, 0.2393465059539003, 0.08983540769305923, 0.13377028968065016, 0.15346665536203694, 0.18121986049077204, 0.275508230852504, 0.18327951851871707, 0.17135370522737506, 0.21213327023771503, 0.1099558336840522, 0.1459964554035856, 0.15009625153916498, 0.12907676008199492, 0.17810537599988524, 0.19423402425262237, 0.14307122527351304, 0.12935935459550352, 0.12263019914708792, 0.15848269265505577, 0.19827334540745906, 0.19520200698846774, 0.1348353970435358, 0.13180535076366318, 0.13304690349726908, 0.16765233609945546, 0.16024003706632123, 0.17733953322374052, 0.19020722097446843, 0.09617964992479933, 0.15053880521126334, 0.13756878343561005, 0.08429162775076206, 0.1647362224156818, 0.06572351039898011, 0.17425204567130537, 0.17011684095186574, 0.10510317996264466, 0.10606609119643128, 0.12187546464584528, 0.1014397781522524, 0.12564201253436266, 0.09790552344413535, 0.17294893011210427, 0.11940562016060276, 0.18855539751389336, 0.10803893614079683, 0.13217636714539222, 0.1968426455653483, 0.2239231642095312, 0.16572208564367988, 0.14188237938909762, 0.19879687457315384, 0.25270790672831, 0.26360411317117755, 0.1685885874734771, 0.15423948486005107, 0.1515489227829441, 0.23283232243791704, 0.10046989551835483, 0.244316915050149, 0.1422272874943672, 0.1598845722694551, 0.19695832484191467, 0.12863273552108195, 0.17115055403161436, 0.15922331581673316, 0.18670491213279386, 0.17620590695690724, 0.12145099064875996, 0.13099767958685277, 0.1885104128309796, 0.11330941421610695, 0.11545452935200547, 0.12503031430946243, 0.28965367665213926, 0.15764492954457962, 0.22277449197586507, 0.14763594484857975, 0.1413461178421013, 0.14662343708257522, 0.18345015694297132, 0.24972322817531326, 0.11324281053197001, 0.12325708123464739, 0.18763898781711058, 0.1447176248315842, 0.14725893765928286, 0.12777173696386238, 0.1391381298702571, 0.13775319612074283, 0.19279384024200902, 0.1504637745599593, 0.1739921273603555, 0.11978588322357786, 0.12170055145097357, 0.268542836870878], [0.052042064902883385, 0.041124978733639565, 0.05808408161805523, 0.08559985311641809, 0.025575812793366855, 0.06437842854328694, 0.0559678863012983, 0.05545436607433423, 0.05290873251074264, 0.07528192814319365, 0.03401565598323941, 0.03532099702786054, 0.05657971476114566, 0.02503569207845196, 0.019115123281916304, 0.05541297817422498, 0.031130557369080283, 0.02526744899730529, 0.06091742333204997, 0.07375509958834418, 0.07571282195708445, 0.015831698209137445, 0.04894398235445542, 0.04088586737071315, 0.007447592703805816, 0.0411832933464358, 0.055589163075051004, 0.02679195630574419, 0.018781436449517647, 0.0037166317539935514, 0.0555716771181793, 0.04129131174375934, 0.05203937210382954, 0.04176653140494901, 0.03516211805324401, 0.0215643638324353, 0.061908695140793446, 0.023046085130303137, 0.04157599767730121, 0.024229736938591928, 0.03371095600267572, 0.03430432940442716, 0.042755428341127215, 0.0401760179609541, 0.029446397337221333, 0.06055441639956929, 0.03949641370244565, 0.05152203675900256, 0.025326851454953996, 0.007048131956253202, 0.061028368185244264, 0.017878427545750336, 0.04357159160257828, 0.08390917367632351, 0.03644302089308058, 0.011892376426276902, 0.029273556410184795, 0.0650293428090311, 0.0957662535590991, 0.0018753918571277493, 0.07038386072963476, 0.015863931358551547, 0.0353769367680915, 0.036454937390742764, 0.025352059578102444, 0.03913952015160073, 0.031592581165774215, 0.0484662460944345, 0.054147136622979763, 0.020331960103865114, 0.020961431568608652, 0.01698592553786453, 0.03276943777417464, 0.06885430490177485, 0.11902596230708784, 0.06102153468095969, 0.12844792447022854, 0.052910142112523324, 0.030458543126681642, 0.16582336246726975, 0.05267681854386484, 0.051604483141413623, 0.11892197353224601, 0.029359304631549506, 0.05777025369987373, 0.03166366454904839, 0.1345044623820051, 0.027653774577042753, 0.07579665495863847, 0.05582981044426561, 0.05634597750500806, 0.02353048252482568, 0.054449021230421724, 0.04547246641689732, 0.03301265153793558, 0.06110108908145659, 0.06863222367340518, 0.0381253844487571, 0.038813116900142164, 0.036264334715181784, 0.031149345675423264, 0.011009136421395647, 0.03801140588738265, 0.11215586966324238, 0.0714454440880687, 0.027150956598380883, 0.031003877069921266, 0.043784977733007366, 0.06835398820018576, 0.039918099139486594, 0.07868413993668172, 0.14928600630692898, 0.009678101745404063, 0.05393853088119819, 0.09807368740439416, 0.10916971256055179, 0.0496453013751776, 0.08954529785701344, 0.057197625959111806, 0.0641899249486385, 0.04994561167193517, 0.032082664847914735, 0.039787377726527, 0.0986766522269576, 0.04725193927785562, 0.0022276534488604918, 0.037173845790206425, 0.0370387691673973, 0.019130096470396367, 0.017916603622237043, 0.008350240588638811, 0.056163698374744386, 0.022904619334205505, 0.0306373825221653, 0.03761995794071305, 0.026624297963515408, 0.043765909804572026, 0.05119079949274179, 0.022540484337256323, 0.013252816429632086, 0.018730706107171795, 0.027052121680049647, 0.08832368639207656, 0.05857426680684571, 0.056135736165508154, 0.03793981880129826, 0.06511337499344541, 0.026758844070436976, 0.03607891462442856, 0.022157532305667, 0.02901043010605199, 0.006012034906645216, 0.031254912591389114, 0.04042702283890497, 0.02416733333149985, 0.007521642762566767, 0.016858708977158514, 0.016116392761168462, 0.11809461389578159, 0.03711903602966378, 0.037307872872559295, 0.014119918792388372, 0.07019756346820824, 0.05695911980564556, 0.02040229272097349, 0.0131304195195797, 0.030626607495510293, 0.018779442705694708, 0.04539710251734622, 0.07348436411590346, 0.04069762807639857, 0.027025339246216803, 0.043360055574486335, 0.020068381807856986, 0.05543137577572658, 0.07427823038831835, 0.016879255455287717, 0.04305745467483517, 0.0904711151135064, 0.0409335563439996, 0.03363778694502769, 0.05316039239386878, 0.05475648295795245, 0.029076407513310833, 0.017215840015259963, 0.026158014717962474, 0.03344728386089687, 0.07617378472200326, 0.005436782357132724, 0.017420891109072877, 0.04652045937555452, 0.013141609191323721, 0.080353322949621, 0.05289117760595776, 0.07043184847721169, 0.05033156293774805, 0.04309994574155539, 0.009423200352748316, 0.04315693885268223, 0.01745897525500867, 0.06084466413144143, 0.00236467378037501, 0.021547513728540753, 0.05178460573417045, 0.022880476073271806, 0.0606803804065191, 0.016689390139353853, 0.025675306547312968, 0.06836209341042465, 0.03553676186129451, 0.02999633355366607, 0.032046451871733994, 0.03730771965497444, 0.015043289355573156, 0.0666582985450664, 0.04491051794179986, 0.04272957670412237, 0.03544000495645789, 0.02979215771530665, 0.02027958650292168, 0.03874071776085804, 0.026667570439918388, 0.04259528915187524, 0.040552508040902116, 0.06394245173601855, 0.03414134036809687, 0.08562452880845917, 0.030273799108521595, 0.027766395247571414, 0.07763689774419032, 0.05432328321940957, 0.022238628458111517, 0.009867550501029098, 0.02327839554768176, 0.04747136218112804, 0.08191478633952719, 0.08515836430653449, 0.04141312355415956, 0.020445071070665316, 0.07885807253901037, 0.026219554560919924, 0.0662827086184294, 0.05299208670734398, 0.03438935750314305, 0.03010925108326539, 0.015359402130988818, 0.039395401179189646, 0.06082027955281158, 0.041249494834412495, 0.022964355040101275, 0.1266617291877347, 0.027497552012303667, 0.04350473127898671, 0.057540400509512236, 0.05429274695474775, 0.05859912252954899, 0.051850010490705895, 0.024533781913980365, 0.08380315476848234, 0.05025338749551485, 0.05711796047586588, 0.028058901023600372, 0.07636502325054138, 0.003916001827042971, 0.05793529202140147, 0.030654152186827797, 0.01910649904710872, 0.057768415088855454, 0.07203442780601402, 0.1264478221175171, 0.13792499899864197, 0.02712486172846008, 0.03208274720236659, 0.024146633635785793, 0.02730327786036557, 0.09040717741534596, 0.027111769285834125, 0.08775480482126437, 0.009997312388863536, 0.04983875389781691, 0.09089096960040832, 0.030065863693673766, 0.06790837783726954, 0.023500555300063664, 0.02562646652692028, 0.04318993809002061, 0.021878452220511053, 0.06339558753215017, 0.061879422921206684, 0.09241009897161877, 0.06104515317166525, 0.03234208328649402, 0.01878442036198272, 0.06934761955973602, 0.07809138706614895, 0.006179900571418506, 0.07556636126772051, 0.028366232516183972, 0.08077143075605554, 0.05988466403176708, 0.03240304473306864, 0.038478190920525984, 0.009806992208224632, 0.023378862233291713, 0.029006205131149584, 0.04520852231390534, 0.033946796170165466, 0.04825486711436703, 0.04286714311268541, 0.04125139856290433, 0.02847672154706332, 0.02956466024531232, 0.04143836998170422, 0.028496021217095758, 0.022856242797007004, 0.008197038325541204, 0.03769719875567863, 0.02034426922158849, 0.04954196760551103, 0.04289070031635704, 0.05226566298534313, 0.008823265407925412, 0.010956964876142242, 0.038658114330422495, 0.008342467669037082, 0.09256759132709234, 0.03377191361881072, 0.03085639365317841, 0.026699489493283535, 0.05136940140096892, 0.023989769472410123, 0.016361044855007244, 0.033603286175357724, 0.07346619251033953, 0.04876138912814279, 0.007521039947131349, 0.010711070762256221, 0.02065797265048229, 0.04758884559475607, 0.04246285553240488, 0.06172759961637278, 0.014557972655541476, 0.030435144886254307, 0.037008363137682604, 0.04983595001601404, 0.099386386723528, 0.013595773883524441, 0.024702313596442826, 0.05629640012498825, 0.013998762944773322, 0.051987515612235, 0.0561995129852045, 0.11287419966632321, 0.15954328009918814, 0.15996308095993536, 0.13119411985239676, 0.1480227273197905, 0.19626329923349042, 0.1988758122728717, 0.09571586029543992, 0.17631735742813157, 0.13683266487092743, 0.17818198479231329, 0.14517254316278044, 0.09784142486751081, 0.07071179998738152, 0.23302980458303807, 0.11397816300872834, 0.20860073156654838, 0.16968916470725692, 0.18660443204064525, 0.11157215663021612, 0.12917003894765533, 0.11928470084263433, 0.1292547835938392, 0.14154081142717792, 0.11277442437506492, 0.12226695089691109, 0.15000628217333747, 0.19608786509883022, 0.10565645632243927, 0.1330371741806307, 0.1111832291128174, 0.13916010127192543, 0.11422002462730294, 0.15521980161147733, 0.08160200796180195, 0.04977010092848251, 0.1584406191062543, 0.13957119937385284, 0.12171922867456753, 0.13416796592214417, 0.14386452464086397, 0.17176817411616926, 0.08509376777275916, 0.14009434549558547, 0.08805686562892892, 0.143832532809146, 0.09228460610874238, 0.08918864562386468, 0.16844509920525938, 0.1228521731231482, 0.14681379461000044, 0.2382670880685891, 0.1257143925214487, 0.18851349250443522, 0.26375815813099185, 0.1293662647085805, 0.12724354232270874, 0.13310958481123372, 0.14571894771389424, 0.1840532213569649, 0.16330564514763896, 0.11864194541328377, 0.1915204642160285, 0.14836994901059136, 0.13316437541957826, 0.11786061233931011, 0.1647565697109507, 0.09715622050627586, 0.13153412499495093, 0.11606988181630451, 0.1723473365869253, 0.09045259876837654, 0.14467784954655558, 0.09525227750982009, 0.2291534916167298, 0.11485156452944202, 0.4004168444343152, 0.26286453188907716, 0.19057197075697685, 0.288148436454996, 0.1454252602472421, 0.1731830465817644, 0.31011116600805716, 0.15666511841118336, 0.28563269564220983, 0.11377254500985147, 0.2507056286858936, 0.10830086160210833, 0.1788920257240534, 0.09259386048201593, 0.15885706450189316, 0.2061869723782424, 0.32669439551330387, 0.21736974167006634, 0.19846267637706574, 0.14208680229081264, 0.20170690551880868, 0.1355474757691545, 0.18578701622543797, 0.15540686496082814, 0.13049247524430677, 0.25183588416586, 0.1438790649896668, 0.15682789677333447, 0.25114579216366817, 0.14031883990091665, 0.2037742550695135, 0.09731041102279579, 0.1649345012922441, 0.17575944623639508, 0.16784388872404254, 0.2718070149421692, 0.15259035802896947, 0.13703181708772338, 0.19270935606571937, 0.22658427786682883, 0.11256255509872591, 0.23157040708728377, 0.1517177992049725, 0.1689250226463041, 0.1290805139128239, 0.22674792956921364, 0.082559916641443, 0.14767161390233427, 0.07397842187915118, 0.11050004722370256, 0.1583384842641892, 0.11838561239381952, 0.11093533838227873, 0.1756857485780793, 0.1707528318248449, 0.13272292491409088, 0.10849174006932205, 0.2007183303395587, 0.10688208974897863, 0.08394995253653297, 0.20938364278164603, 0.10595245737462275, 0.09931916250817238, 0.20486380063718368, 0.1384635128441357, 0.07156101611232565, 0.1747441039450707, 0.10185998503959949, 0.30520480186227833, 0.14856082747780508, 0.1656184492692832, 0.10370713027734911, 0.13765289988969603, 0.20095397898506737, 0.18886765495183008, 0.10115123113557216, 0.10630575414266318, 0.14848535249550499, 0.08381364251216573, 0.10248274557412633, 0.11067676072519635, 0.10793930640624416, 0.1838277157155737, 0.1065055805168325, 0.08379938561589488, 0.08763233034480965, 0.09919534737785017, 0.11426353842140206, 0.22407860344936772, 0.07755144829711608, 0.09292831914799829, 0.14158285433246245, 0.1656657322159698, 0.32698293486910485, 0.15990128830796288, 0.1345373735192322, 0.11108573676357347, 0.22041924658321568, 0.2066572584331997, 0.18182105565023038], [0.00608236656614369, 0.09056153647120922, 0.03286387343260069, 0.020120956506880543, 0.039795659136988466, 0.056378731594210675, 0.027480690417090253, 0.04210223879424795, 0.08015885919092164, 0.023842665269189788, 0.021850099306433432, 0.034222553348949844, 0.008070650097403315, 0.021869234267562147, 0.015160546773263525, 0.04270362930612699, 0.019741507412324992, 0.08513340516196144, 0.05408732813873118, 0.021526461632381526, 0.019357105559338967, 0.07352101376220103, 0.04214518568328312, 0.07263704788901153, 0.05946339228220525, 0.07635394561915629, 0.026265989065230377, 0.012874273234046997, 0.0769006719271983, 0.02779331940767025, 0.09358717774551722, 0.03088452248653818, 0.07510222689879519, 0.016146689623353944, 0.07074500223801983, 0.023739660917330655, 0.042878186270113916, 0.02072649921530918, 0.03237147424970904, 0.09599868463532579, 0.0707679235887143, 0.04012787316535269, 0.047213573594607657, 0.027421314772518895, 0.06516660278242442, 0.08334273592598977, 0.11349005774865228, 0.051751300061662356, 0.04470319539729146, 0.06146856230653583, 0.04506162112398494, 0.03804790614653499, 0.02302311972955302, 0.012646444431025416, 0.05206801613131839, 0.044261568691581495, 0.01717999476128288, 0.02175317577747328, 0.034926048059376984, 0.04751591785480419, 0.04882480588651473, 0.08524176063797168, 0.03428486694071082, 0.03600464240016957, 0.028924216486273274, 0.05782324783203583, 0.023813818228401007, 0.03414827729425123, 0.03416865523303709, 0.0189314785999276, 0.05176185292281932, 0.07357682326748487, 0.014490156637264356, 0.01226332386009275, 0.052095131813398296, 0.0828294110514464, 0.04593851217519372, 0.06267377565945349, 0.057624765942173625, 0.04711156515705009, 0.018360258545726538, 0.04209853858957368, 0.04172529289198499, 0.03805712218426409, 0.06173271708370698, 0.07784477570244382, 0.014090468457359222, 0.04870439601701595, 0.011458421133518701, 0.03861050962680771, 0.014968462675178965, 0.06344594249141312, 0.02016257231814727, 0.029372266839228334, 0.02799005653228491, 0.0677462200063371, 0.04702139660836228, 0.05306437859431871, 0.01618481207368595, 0.058608614358930826, 0.09716892990493968, 0.04704740912383122, 0.0514171669830478, 0.041054797418896234, 0.05158867874753572, 0.11091319844126703, 0.024489530760254112, 0.04486424623117332, 0.023332387509365237, 0.04532427819926412, 0.03649188581133082, 0.0715838608542277, 0.06365246830448028, 0.013737037623932045, 0.03267430880617711, 0.04333963550086464, 0.013601252369792953, 0.05191417035436438, 0.05267850776773788, 0.01514633009660869, 0.042790327476517814, 0.03932296373550931, 0.015822263836349933, 0.03888120679485221, 0.040273652036464026, 0.013315325373813752, 0.0489528383308601, 0.017923054082559484, 0.04528687012592151, 0.011321868833845422, 0.040843184782011856, 0.11971059976325882, 0.025318347878994483, 0.0248509997712268, 0.043630591864066745, 0.03989615455089558, 0.007515488203705079, 0.0222512784849612, 0.022618029672171802, 0.02157566554453825, 0.018587851776711403, 0.026919475471180294, 0.06309104843005058, 0.030954740190457915, 0.04951869002393177, 0.09939030909370031, 0.10939413035709052, 0.02099106959517925, 0.03615017995358475, 0.019563225345806252, 0.02490382919448518, 0.015166643875530891, 0.04406418613789063, 0.04500272811480588, 0.02870202417515459, 0.058310728730453606, 0.021445769591317065, 0.003050036626049288, 0.006339229143885595, 0.06331891362224856, 0.045370392861866185, 0.10717606066816276, 0.016345671385586742, 0.08351182685263696, 0.0397118337963137, 0.07396427989606896, 0.04770112344093862, 0.045194184978402434, 0.008708779313301128, 0.025913038951975685, 0.031121182368106903, 0.034330230837147084, 0.03183126351946304, 0.04219878119446578, 0.015935244568203007, 0.01409183592430406, 0.03216779062284097, 0.032634495216752255, 0.05475042703291101, 0.013562792840774262, 0.042159473223070947, 0.11933413649638815, 0.08313339473980089, 0.04337198356346738, 0.02620916449344687, 0.04032145209249951, 0.024615774389296293, 0.0332943229154954, 0.031047342983525128, 0.010096572485992746, 0.023058614498304746, 0.03557873581866584, 0.03282556903638667, 0.026140863924557646, 0.18963990222302177, 0.045923634747704195, 0.0880232879952077, 0.06573245064505646, 0.03136510667841762, 0.07583515087683355, 0.056134249954935045, 0.019024927920151143, 0.005455662115221663, 0.056571981103550044, 0.04910756893936665, 0.020563443146285512, 0.041509528058551015, 0.06898328346470672, 0.007883686818287619, 0.0335986819869328, 0.04302262831779738, 0.04429270250482425, 0.07812948461862342, 0.03980950617621984, 0.014576567524683573, 0.04352272668432805, 0.05541026239253341, 0.023796119682130315, 0.05263583667035546, 0.027863968036047397, 0.05478504654620925, 0.11054683221323837, 0.07644426738542896, 0.033740438896441655, 0.010768869223313467, 0.044244963735822714, 0.06879330898124365, 0.006164967123749516, 0.025541915317937255, 0.030338828481974143, 0.059538365476914955, 0.02795070068039481, 0.0880319677713898, 0.023312884826032866, 0.035168798339943734, 0.020699195841687824, 0.07640015604274888, 0.045050068518086794, 0.0556200172662014, 0.0951485109004763, 0.009055835337588384, 0.015404121555958786, 0.048238637541691144, 0.0402884490247215, 0.05379819506478887, 0.03727666245052411, 0.021646105413956028, 0.036835043405693386, 0.016160460053792885, 0.07432557462203888, 0.0049890197659542244, 0.03202852349908602, 0.05278365333534537, 0.10467945673172513, 0.05606883753752036, 0.010429338097662456, 0.06686924851589626, 0.029990488302803812, 0.04734780752070008, 0.09010303284852736, 0.054977093297507496, 0.058127039998409256, 0.05691163384565904, 0.0511988012811109, 0.03271690712520673, 0.0332047097805527, 0.06454306083821482, 0.07753409640563112, 0.05919488612562419, 0.04710023471664998, 0.06565797157705792, 0.04619156250790243, 0.030418564828353065, 0.05105116081634357, 0.06645797421374629, 0.08142557791284016, 0.036916899900402755, 0.019261769747601885, 0.0557439013444368, 0.05501218395487917, 0.04101720931489141, 0.015841877602431324, 0.08211188544068607, 0.03892879617670852, 0.06604874536635415, 0.06912723138567901, 0.024428010069494768, 0.039107283171747005, 0.019969292165290926, 0.0675035156910458, 0.0347246358832044, 0.0419114982228606, 0.051597496419544184, 0.04407907888713864, 0.008318212367744457, 0.07515617481042301, 0.07080088069121684, 0.037753525370311354, 0.05659020250482906, 0.04616152036995177, 0.023467942937127045, 0.021254653636846813, 0.03496663922804498, 0.02309809100904292, 0.02715188164954945, 0.02957916037449914, 0.007657327467665798, 0.05771621385769499, 0.029446025784578056, 0.03001856351000888, 0.023982372893501195, 0.0044404792659465345, 0.010232080990869192, 0.04704524109500551, 0.01881435716284379, 0.026198625038828582, 0.048017479449270234, 0.0639507101638423, 0.06068848178631837, 0.015186612914887168, 0.06949501487636758, 0.022223622710894675, 0.02102908670842167, 0.05481292065533419, 0.03306220210487804, 0.049132240800968105, 0.01608147638879957, 0.008748999886935758, 0.027900458719100685, 0.06722017041137142, 0.03936376940879611, 0.034651953291388295, 0.023161099825595177, 0.03849757294501028, 0.018119773970195846, 0.039601934653136044, 0.04911768129996715, 0.02918521498119639, 0.012602128159825601, 0.08230900752448267, 0.06792568376347904, 0.06620143435054249, 0.037254897892595305, 0.0591433628822767, 0.021895147191600937, 0.05814037375873136, 0.05793698124527451, 0.028462342076724576, 0.09610857228718458, 0.061475135340926156, 0.03795414081504268, 0.06792048968735241, 0.18450663815582954, 0.20142329976924006, 0.09403593672980225, 0.06682538998223121, 0.07935619822913602, 0.23495585687698858, 0.18643911026658552, 0.14291204752460604, 0.16295149802200257, 0.14382139389072696, 0.08324391058375759, 0.10610238078140444, 0.1301388337367004, 0.08572886232286693, 0.06528589033311413, 0.1418531301521486, 0.10792962305488125, 0.16546143188832269, 0.22941059072411832, 0.14179801778687587, 0.13972038733622721, 0.18340734794976252, 0.11800894994408855, 0.18631880381895652, 0.1489325180169075, 0.1902728593878208, 0.06887128907105616, 0.14557691501273265, 0.12316079164344458, 0.09506203489558351, 0.19570652185188187, 0.15317427024485605, 0.11538163608601017, 0.15670919911034648, 0.1882940696011628, 0.1724563662203089, 0.08929223603298587, 0.11689420008370954, 0.08768250910385002, 0.22656756182832105, 0.20183747754462306, 0.10652777408399891, 0.16677894990050024, 0.11386370181196159, 0.18551056573708213, 0.17593589160711537, 0.1611833058057293, 0.0613515270543435, 0.13419851750856446, 0.10611961009882151, 0.18369394144223583, 0.0984790321860102, 0.17961896655540313, 0.08844854340197579, 0.32961432431494037, 0.17723260267126947, 0.18431605080202704, 0.10554658399233896, 0.10609865759409244, 0.1289005751811689, 0.11826257867318009, 0.1531940046697855, 0.16851194803753208, 0.20260204861481346, 0.09901847299789229, 0.09163442728740555, 0.16465475662581383, 0.17744906847515415, 0.08495050933091872, 0.07135193539603103, 0.11976342152563796, 0.16669650351808918, 0.0861197510253518, 0.13590278734843578, 0.184771244924876, 0.1795819491869019, 0.1656691336463536, 0.2514617421453999, 0.1184857247637645, 0.14087304322709962, 0.16931549766130988, 0.150232523259136, 0.14581158306569825, 0.25329646143701773, 0.1507374058447538, 0.2158960030083695, 0.0893454485002064, 0.09101349004213849, 0.11498114064095483, 0.10991340773480554, 0.12188852644495426, 0.1299263362682635, 0.13744484573121996, 0.2742111520661462, 0.104897064006617, 0.14613324806334513, 0.12862240865586266, 0.15021380007026658, 0.10017063859249316, 0.19232738462667312, 0.21735483359905983, 0.19462232357792317, 0.1326942579039643, 0.13712679666857566, 0.12067869741229281, 0.12473039854798587, 0.28055901789376814, 0.08175957692606796, 0.18956220558574124, 0.1659068966945333, 0.14910755378584709, 0.27126863899250186, 0.11155591556622137, 0.10668511322188763, 0.12627005907556704, 0.10729389265179635, 0.17015920561407843, 0.1248102785358506, 0.11815426916244531, 0.12255690751537202, 0.11445067071866606, 0.17880106044392433, 0.09993656042722926, 0.21577456275061255, 0.11389538720850984, 0.1738029189648167, 0.12414236477906666, 0.1647013347716101, 0.1156268684914516, 0.14659584259554265, 0.12548461977031924, 0.19901795222634272, 0.17667703570858126, 0.1328133845761899, 0.20014089922751152, 0.09097822701498386, 0.08653825719750698, 0.12576185166835785, 0.16686580894935518, 0.07702246458540041, 0.0817559686519446, 0.27761380819063036, 0.24200886067363525, 0.07186145281359073, 0.1945963072320146, 0.2157094605988072, 0.27135342960396125, 0.10905427077124197, 0.11407349499002581, 0.14108517297333287, 0.09082817337325505, 0.14223090342936978, 0.12944374684124224, 0.2545298323515923, 0.155939357355237, 0.17585071795169385, 0.10439605016501681, 0.1107752413278626, 0.08777803260712855, 0.14728968842856346, 0.20032813111620568, 0.21301070138091044, 0.08722968985356631, 0.20959255495859733, 0.12819498522026887, 0.16779850567540816, 0.14997654264011692, 0.17126404229671727, 0.21294794345815338, 0.12311607509130433, 0.15735176301771597, 0.10273239064601161, 0.1800230779354611, 0.15485842261583577, 0.08932455728251128, 0.1281704550849334], [0.05115478952986099, 0.03907093996061914, 0.004321824695404259, 0.016926120884055575, 0.056093578347034996, 0.02354617583595457, 0.04101286559636074, 0.0707776605662319, 0.20877320860182086, 0.03836684004073182, 0.021864258526493947, 0.033283773884778066, 0.06485974626435388, 0.02384310768496606, 0.04684656002228299, 0.06318008316861046, 0.03453206436167802, 0.06307619015475915, 0.04652429747605517, 0.05258025699144891, 0.06429428910656322, 0.06449779270276909, 0.012353180227951418, 0.03923163839405583, 0.0166675815313694, 0.005413893565175034, 0.04184334321067699, 0.033480221811201305, 0.08880147244781257, 0.07556528108374727, 0.009677079018025149, 0.03937912947167793, 0.04385715087635383, 0.012837646570387147, 0.0020822810831539816, 0.046063346202455224, 0.05943750234080419, 0.04703036366751598, 0.047144648664060144, 0.040015587658290906, 0.03307612958334146, 0.03017447389391882, 0.07878370072332122, 0.040510216157042214, 0.04758149881156222, 0.01852710100431596, 0.021435779804784446, 0.07068932296768313, 0.02174837049096823, 0.07709022506230301, 0.07153868464933288, 0.020097209696447658, 0.011581970048287224, 0.045033808301893935, 0.017857453973603346, 0.004472668365304989, 0.0330057107813416, 0.08664534096756289, 0.021822357347475427, 0.04005344772350885, 0.03168138607795681, 0.009551038402282904, 0.04633824919320403, 0.041206295136362314, 0.04527642451707394, 0.0444732770894564, 0.09300165674498967, 0.037928549647932096, 0.03514978020722347, 0.07501483158839327, 0.02657206225839834, 0.03755419695329282, 0.08476637243743866, 0.049081108262462, 0.016145347054266644, 0.12949216359805676, 0.04038504122065441, 0.026025929668497656, 0.09577713966850313, 0.06192390964696966, 0.05745688926488642, 0.07200030624986657, 0.02458865296155695, 0.038925969312267925, 0.07488884076836609, 0.020296622383137865, 0.05472457922634579, 0.05698339713196601, 0.08798820116827566, 0.0695340853605059, 0.04240276359562432, 0.03127506453423731, 0.058014053520896745, 0.016301569619005727, 0.06235612496252983, 0.05035126671916054, 0.029868111502559438, 0.055021859645362825, 0.09711646820388495, 0.059821327712627194, 0.07391289837898747, 0.010244840185248084, 0.02754462045437146, 0.025279518712552327, 0.025372322603699662, 0.05880915319486972, 0.01189092277444058, 0.06772992531618766, 0.017291730600258997, 0.08791782067067201, 0.050625602804845383, 0.005753056968622391, 0.07093834750834974, 0.07005807417895525, 0.008465447763521827, 0.028526907966982935, 0.054512173688459786, 0.0163890108946831, 0.05532040793989455, 0.026554672062517177, 0.021432278782970483, 0.04852033573232832, 0.02291963082708178, 0.03726922756721897, 0.027039331842153787, 0.003191048515051784, 0.02790850838796506, 0.0288649634157698, 0.011040125635542698, 0.07917160934378063, 0.037171516882916616, 0.028077174135814273, 0.022051568939200333, 0.06297610076745191, 0.03699789454619731, 0.07195582718498285, 0.07665851919521248, 0.051627201478808164, 0.058108531314158635, 0.035463412772984274, 0.05496685836283911, 0.049322621311031045, 0.07439206339298718, 0.056246500988040245, 0.0290793186474231, 0.0338133781277124, 0.05419001839454136, 0.03966077786660002, 0.027074778730410243, 0.026840945713282115, 0.03586731730930267, 0.01284274967357276, 0.053332976681450685, 0.052244771767648, 0.02610318005956229, 0.04646907402803341, 0.018114604791926763, 0.029310734657150124, 0.06086293915887514, 0.09012997616082431, 0.03890701629702122, 0.041305836770803704, 0.03991369030348236, 0.035171885674278584, 0.058140676363461444, 0.0052490726210958055, 0.07180482359422792, 0.07220285989704632, 0.015703909955317938, 0.055772913094129295, 0.06394498365660829, 0.0436837200616156, 0.02053084802032719, 0.09551144505460417, 0.006485152135287682, 0.07174419539590036, 0.023019938549447446, 0.01321167846570813, 0.005539693820831036, 0.020808150781498804, 0.02192616034599562, 0.04228013207114512, 0.012510545221307586, 0.1163314318945331, 0.04045643678475772, 0.056108245100345344, 0.010965012629786807, 0.0202494869083767, 0.05703775107019371, 0.057193113701237794, 0.10527953340281403, 0.03435738865406283, 0.054353064887465975, 0.0349906254409542, 0.03946384347434487, 0.043673722614203735, 0.013783733555746656, 0.02621383188412555, 0.04724078120723848, 0.030476551938561663, 0.03960889839236775, 0.02717291076307095, 0.02687161412811087, 0.031278898804298336, 0.05605455382817215, 0.05090375783883276, 0.02409756953467525, 0.04646297213771651, 0.02212522637790009, 0.02893059416824291, 0.050362604820439895, 0.0542753414371081, 0.053189174317184, 0.038911812007427216, 0.037755478894518274, 0.048153383447037595, 0.0934061052037343, 0.05522945415108435, 0.06622802526239427, 0.10486148688341342, 0.01633951778433496, 0.034482881516939214, 0.011487135066530638, 0.0870331040313167, 0.009316018906482046, 0.017263128707605987, 0.039958632851560275, 0.03600871798792674, 0.028383120924474734, 0.04322134769491611, 0.003365841290477904, 0.06970787240612893, 0.03882782961872797, 0.08745550193012723, 0.012231039957353666, 0.03224676662695504, 0.029773484322152315, 0.04090685817983843, 0.046372485662540125, 0.048958714225239335, 0.020142397392661344, 0.09491159820989256, 0.08683570615586736, 0.019134654693545836, 0.05432211876576466, 0.05108224866431087, 0.07264928997404153, 0.010839514978860897, 0.005928445138007162, 0.0167650317457775, 0.027036537536449974, 0.11746897287065945, 0.06673507587683779, 0.028561376177916126, 0.048599702441283775, 0.01656469592313853, 0.038262529508961786, 0.054102542644907395, 0.021539289774673603, 0.05325157983949589, 0.15165482677759665, 0.032707786848468166, 0.03834283084518487, 0.051184724415502245, 0.058100077533914204, 0.02420425876945017, 0.014783680352622704, 0.06436080086014925, 0.13155776646829423, 0.04194934679675968, 0.11428665895495685, 0.04603826065337466, 0.015265020098717464, 0.034551588112428304, 0.04256719670769188, 0.05089685921707461, 0.03348673738899731, 0.022323779130895293, 0.040254315977255185, 0.05374165394553735, 0.02281088081579055, 0.03398503544890592, 0.09119408760940836, 0.03218117800931777, 0.04744820334317704, 0.03638824177605491, 0.05321255149019342, 0.02940590959042311, 0.017815635149036686, 0.033848445802446336, 0.0184332724705699, 0.05612094683812992, 0.02556867093869275, 0.05440212132769728, 0.06523892914335574, 0.03030571433144712, 0.027978335387043418, 0.026282651477583477, 0.019134083958042246, 0.053264787195310484, 0.06250060914504914, 0.023872266906583985, 0.0431664000385471, 0.055793199102364244, 0.04569361301799936, 0.06366816161560916, 0.018412921344861388, 0.023489952643191623, 0.025746828515923796, 0.023409461700207284, 0.09482400371663033, 0.05745644876432996, 0.026861574545863177, 0.023210014539560484, 0.020380219812655163, 0.04431854265051023, 0.015484095389594235, 0.04687068030057896, 0.02087410520611992, 0.015906292190324637, 0.037504045007329796, 0.010921405947526858, 0.04053715946933916, 0.022730115996373278, 0.04369783140118084, 0.0493896386826471, 0.049764646382461634, 0.025228439800200925, 0.025502000221862428, 0.014824500390058084, 0.023282406017965367, 0.05117888682551923, 0.014650041102281502, 0.02415967819791648, 0.02838824413746836, 0.03152503710871022, 0.020233303300976273, 0.027127274905421564, 0.004232143091353318, 0.059623271001562964, 0.0436427190359081, 0.060406297129849275, 0.048330801749421705, 0.04036401976801215, 0.0174232755577372, 0.043781695046251824, 0.0690798182040453, 0.06638528779149055, 0.03027411320457055, 0.02138706427367945, 0.04233169361888882, 0.046021851050036575, 0.2873517050137443, 0.10180566174488875, 0.04847001524702196, 0.07801729104211254, 0.15283172169039327, 0.1912859187371308, 0.21333443481595288, 0.24770988782327025, 0.38172494259572803, 0.07557633573249464, 0.06484070897943552, 0.10804237587557686, 0.15343637956726938, 0.17984274083808546, 0.19785846283118572, 0.11706227211341744, 0.1505604548560035, 0.15717576197799177, 0.10278344274528566, 0.18524343087788553, 0.09342027016945424, 0.15544826435225625, 0.14713850863758596, 0.08276524352690867, 0.138708078753083, 0.19235945306718352, 0.08639423266774224, 0.07316467562510122, 0.1582520389028134, 0.12287865678269057, 0.10006713245304362, 0.1915635030356146, 0.1729255644304137, 0.1370651112689126, 0.11321081870025206, 0.13670796107861305, 0.18411472289552613, 0.12977926270856013, 0.14936258445584005, 0.12992290419436273, 0.12958377239204225, 0.15522375462516663, 0.10741364751611987, 0.18372515186427102, 0.25675521051931766, 0.1307235886493037, 0.10308435442106378, 0.2472106896100506, 0.08496599196786843, 0.15740790194080723, 0.181996627680717, 0.19405869737027154, 0.08016959208274081, 0.137961725253732, 0.1345835992645833, 0.22912661725234604, 0.12137990535026598, 0.1914122159923277, 0.08225178075653893, 0.11179079046292652, 0.11821373290712796, 0.17001568670234374, 0.08464136987083382, 0.17124700450128125, 0.17970086135450872, 0.2537172888555835, 0.1539382437664655, 0.10316400458255123, 0.13021801658455404, 0.1468963482447209, 0.14485149103547298, 0.11826742800974077, 0.1577976108678887, 0.14925721672273454, 0.1218603267484615, 0.23907661317817627, 0.19098251727559876, 0.18875758343886948, 0.225299533096052, 0.25781558345883127, 0.13415809870967943, 0.1790275466778586, 0.1397965211541422, 0.1504902965238979, 0.2366859898451836, 0.08279711278455873, 0.16321821919372007, 0.1602209155117312, 0.1969291062484826, 0.21272878102477522, 0.11249743762516207, 0.1732382661993465, 0.17846260279897722, 0.1293177406994566, 0.1953285034265249, 0.13473059621549424, 0.12277657556678019, 0.1894046825867507, 0.12006937405995785, 0.3376339472109272, 0.3122491641871391, 0.13727751680679862, 0.178957388345753, 0.267044767256706, 0.09656499981159165, 0.15358101696737353, 0.14112462650143331, 0.20195416805724944, 0.10327600663708103, 0.1466002552619865, 0.22086890955125132, 0.22948592781059204, 0.10918992962087355, 0.19983720665256824, 0.14728872315777888, 0.13347317014009724, 0.2570796793987674, 0.20075741614545548, 0.09522211662824116, 0.12614376182037015, 0.15922409722641592, 0.08724318066191289, 0.18696769561258056, 0.12723085590668265, 0.07194657284285753, 0.10793659445499221, 0.12845493417473572, 0.17173465010860275, 0.11431872739546722, 0.13793478960231428, 0.1101779915212143, 0.11598575770133927, 0.1299942423018717, 0.17045431800426977, 0.10742653311500627, 0.2653011204975267, 0.12249224969456274, 0.17295551846825308, 0.17374236737528156, 0.12872037597961966, 0.11218512656107066, 0.1939479363781791, 0.2200853395005388, 0.11047124231774962, 0.11316757303692641, 0.15760552198175462, 0.14502327859161362, 0.13763489682347546, 0.12224763015946075, 0.19106706273892235, 0.17675965063033566, 0.15018775308084104, 0.15520051151754397, 0.1765894871805945, 0.11194444471789945, 0.1364313114073969, 0.10144928530339273, 0.09916394543383392, 0.16622402645166845, 0.13106458970615942, 0.19163202193956222, 0.14184539266411336, 0.1831726032880045, 0.21212769311762628, 0.15247466343064464, 0.17151081453888647, 0.10534262840425777, 0.15629768732093996, 0.1404552648384725, 0.21191176357528857, 0.22788995215969704, 0.16276422016803296, 0.10730296313281983, 0.2421232682442473, 0.1384566946616096, 0.08957836987270464], [0.010368594986146257, 0.10406318496191695, 0.029441645676870982, 0.03239052302594627, 0.02875007704020508, 0.010353249287413014, 0.024575171729309425, 0.07482699449023894, 0.017519138054922223, 0.021712080905995062, 0.029709211460524992, 0.04168192082415185, 0.0357172713284531, 0.05905849566202491, 0.02855732165757687, 0.03440361439941391, 0.027694624300385197, 0.022119381127037832, 0.06949093928861041, 0.060841492527434905, 0.03917209037970151, 0.07021571975201368, 0.039382867980748415, 0.015134125358364997, 0.06142487231221411, 0.04061954073427666, 0.05147791775544325, 0.05304364442464806, 0.07300613372917138, 0.02546529120375072, 0.05270306088571107, 0.026837406387071938, 0.031068073322756157, 0.02230655555913766, 0.025772337328582525, 0.05839286484725534, 0.051595427982148626, 0.034264048501368494, 0.03567484154876682, 0.01718384818354201, 0.027512609470455397, 0.08194966632271967, 0.02820624845973667, 0.04198860497243943, 0.028119688185172218, 0.02619091627909051, 0.013429228284005678, 0.04233938131120898, 0.03158324829963667, 0.048784632235765464, 0.045669370165635506, 0.0446506915614009, 0.037164135625766176, 0.05842627394163321, 0.02051757171659941, 0.11744143967066081, 0.07164419793914403, 0.04042501185810374, 0.03175980283788616, 0.03800654505950309, 0.05997493600232467, 0.14665748202993026, 0.04160410544324306, 0.008822856508495827, 0.01570383526174532, 0.053430430726298404, 0.05961307437129079, 0.031307845436517275, 0.026564192620196173, 0.030512841523534832, 0.03234599033490785, 0.03220341371132001, 0.0066759204773622904, 0.06476531826680706, 0.05782023710649341, 0.04733600976666616, 0.01338864286099711, 0.06768067352353566, 0.07179111828126254, 0.027238857526812824, 0.0691642564150595, 0.020632145911334984, 0.012389630691388683, 0.04302763087194293, 0.023264433595261747, 0.024767523000557578, 0.06984316353355685, 0.04761085530082065, 0.03631570857138403, 0.05032931063925067, 0.032318166021497986, 0.0656855124379358, 0.07800166284845722, 0.1301277714270738, 0.04459867419134225, 0.07038185357927315, 0.11898119212879289, 0.008962263443296956, 0.04692962693591272, 0.028877103994149837, 0.04916763023263024, 0.01718731473139938, 0.037175703553422805, 0.05726581544525201, 0.036690758406034404, 0.03438983630809573, 0.10367523803706132, 0.03363238602516151, 0.050060708721679066, 0.051491247685325724, 0.00841928809325421, 0.04280502104290551, 0.0430752317451181, 0.04612402802693748, 0.026842853272213574, 0.10710516689164985, 0.04236897911816355, 0.015977216610354523, 0.04672624208333512, 0.020442401254249197, 0.030683133293003328, 0.03923752577975392, 0.023790082909286987, 0.034761009737849236, 0.042042755897367196, 0.005267261463638035, 0.013228351411770188, 0.05649997266910731, 0.006259769546769319, 0.02679570630613354, 0.061257236952623056, 0.033413660261900194, 0.03680557966412556, 0.032680085109126185, 0.05338962888345123, 0.005004655620488789, 0.042351182895682515, 0.046052371992939906, 0.029532771835464145, 0.02277193290572013, 0.01597886657222144, 0.0438591503658362, 0.06526781065810112, 0.11466678412210558, 0.08297599431487822, 0.016191672391047882, 0.03020380931575933, 0.04938877300329266, 0.02536450659165219, 0.012026826772207936, 0.024349980183967182, 0.023281818045483484, 0.031790046073916944, 0.005231902196687917, 0.055654966197307074, 0.03848357268819406, 0.035571959770975575, 0.04028951771737587, 0.05354139473169081, 0.005223386650604587, 0.02623106311676243, 0.04538931906403554, 0.01885391411281401, 0.042740370882975484, 0.0554276219448976, 0.01478873557531305, 0.04670415576847811, 0.043053670200489225, 0.03687989019278077, 0.06425790376059952, 0.018337170570908536, 0.021005669315796227, 0.04023152486150784, 0.04356006197931786, 0.050366871930178136, 0.04559747281394178, 0.04771331573025354, 0.05413604366983618, 0.018106993708399036, 0.027877370744282683, 0.061581361092506885, 0.02026538514802533, 0.061236989248784325, 0.03571347919322791, 0.05379254899678692, 0.025819340653176752, 0.023845580233741673, 0.015809499853921515, 0.048594975678790966, 0.05221480623848977, 0.04636446855241253, 0.06923095202974736, 0.030205707298591736, 0.033825118425152, 0.025466626111958778, 0.033448371705749345, 0.07690539868969111, 0.055275270039395946, 0.049978446200369835, 0.025130054958525206, 0.04764511475279447, 0.06963031366467476, 0.02766573129432096, 0.05261618651509766, 0.0340737829044942, 0.05073772360300345, 0.05939190478755101, 0.03054260786983275, 0.058868785478895715, 0.03409086283476603, 0.06012690486386419, 0.0743870378562039, 0.020956911649855397, 0.041721397334890026, 0.051380835263238805, 0.051099868686569315, 0.030264125333257744, 0.12282836311046155, 0.028363411397402807, 0.04972147349748881, 0.04160300610707172, 0.06608769327642457, 0.0182293149672689, 0.12628977051785878, 0.04273650596939749, 0.06164364021031126, 0.06482525698600278, 0.020251877102700454, 0.013279682175526697, 0.020745226234618216, 0.037053520190379316, 0.057245334084596367, 0.0571816070606151, 0.00573682404431184, 0.028954894477201086, 0.06955187392210768, 0.041559695326272524, 0.1012036392104722, 0.04160056611703288, 0.050068802440599094, 0.007838171140681352, 0.0513109450619067, 0.022902541320710894, 0.028489618637268583, 0.01236614530845996, 0.012674815539691239, 0.039889558533867525, 0.0071348215081548745, 0.03281013619515204, 0.05350905432996731, 0.04805389926919053, 0.07480201236302815, 0.05446144717655355, 0.03273653046738717, 0.007508730829407972, 0.061386418528854854, 0.037580144351288196, 0.07194704781737059, 0.11671505808349579, 0.05524037090400535, 0.07732633336056625, 0.05325563244461533, 0.04488874955343143, 0.05582530201683122, 0.019912166903997143, 0.06759770620133608, 0.036400391930533994, 0.02304837573319674, 0.017035684863766356, 0.1192363377119745, 0.004479172451782131, 0.0377210509032011, 0.061730089402126695, 0.037504611912393765, 0.06360878980147743, 0.028575830341827486, 0.06481664615773386, 0.04678592799351581, 0.03781205065728676, 0.04586970598827447, 0.010900750301868446, 0.026369943366115613, 0.07958279171537969, 0.06831196827753898, 0.018591203411380132, 0.020125263836234808, 0.023483722433147412, 0.05393870325098115, 0.06835231812851084, 0.021309022896832997, 0.047021025055719, 0.016934913658206503, 0.018070855425790917, 0.03436904468183075, 0.04959055673210852, 0.05672078219152266, 0.010842998763696562, 0.025924675827545506, 0.015984646705610138, 0.059040837335370244, 0.019637288811105876, 0.018565363265694152, 0.027805990501937848, 0.02316913608792088, 0.033484500412258415, 0.02230445647822513, 0.06052053616111798, 0.05544742914817988, 0.018475217699644067, 0.00792276783613488, 0.04229975924376519, 0.025476658033327233, 0.04100613934438556, 0.0291400617589393, 0.038755790540768255, 0.014906754292878173, 0.014308216500907175, 0.027131710554503148, 0.04454499441048792, 0.05778568271066874, 0.029263177834030603, 0.058207655430681286, 0.05980320973321796, 0.04389552805092066, 0.03768840789674752, 0.03141729833347903, 0.07253426953309006, 0.07621689248950252, 0.024957890104081844, 0.03157917654231912, 0.05881453879297741, 0.021587760157642827, 0.005301708128348354, 0.06631135264591825, 0.09816513531991551, 0.03563389414921403, 0.02141432168202535, 0.02326435507124951, 0.05659758759241912, 0.07842697188138001, 0.04017012674481638, 0.008930702536036412, 0.04221443620119845, 0.025940750267416723, 0.031954481101204316, 0.05326105251667961, 0.07899545508647159, 0.033372115313766465, 0.049083291613046205, 0.015731468053174116, 0.02352113242170984, 0.0908478158676336, 0.1324665306075927, 0.24746483161805138, 0.07345951988451904, 0.1882707498847477, 0.12363368239734443, 0.05055172128542777, 0.17556743395905341, 0.20920135982094273, 0.13262995248360018, 0.12894002870926935, 0.12649386400176635, 0.21078645702331297, 0.07296615926128242, 0.12946034030568215, 0.15992963356116127, 0.131757638807739, 0.13173540693617639, 0.10734070062396989, 0.13369395667987485, 0.1216010672731265, 0.12568698189551794, 0.1332419648045494, 0.11664053305022179, 0.19210186366352344, 0.11793547445127081, 0.1626238422167878, 0.1816475827006563, 0.1473672931352931, 0.10590615502047925, 0.10108218363095677, 0.12089419794539291, 0.13983101043249332, 0.12334190248962372, 0.10647460758205383, 0.0773053655340787, 0.12646721946375986, 0.13659825728785607, 0.11272987636226801, 0.2109925806402199, 0.1793195947163528, 0.13835354858348448, 0.19933338126828595, 0.14780521963632878, 0.09635853911599807, 0.19096318121638992, 0.16782058432938593, 0.13246391058689164, 0.23636133710463203, 0.13951254768236993, 0.17665705613551602, 0.11744284927244149, 0.15265129266246674, 0.09390172578634755, 0.15093614437407063, 0.09140594922486814, 0.21216529271294995, 0.2162979386987225, 0.1219050356397225, 0.11251187838253476, 0.12338910116663865, 0.19677720633485626, 0.20822078259962223, 0.12517554925814753, 0.11494548690895881, 0.27927082572733203, 0.1542073091672313, 0.11008825964264332, 0.10404879016981972, 0.15474292720037122, 0.18972256311005165, 0.11083737105852175, 0.15277933659813098, 0.07490557212863239, 0.20194520482853537, 0.14615223172210878, 0.1212252781636292, 0.12205019397961518, 0.14343062776230997, 0.1682181839620875, 0.24766611355927684, 0.15183697184247358, 0.2386161943356837, 0.24001968273472404, 0.15045281950264208, 0.13967687354212807, 0.14978851401998153, 0.15974545070240576, 0.09019067330706505, 0.15388709973664055, 0.1880020215626686, 0.164741339883016, 0.21974456827006034, 0.2335572254753882, 0.18775164870725525, 0.17955812385245679, 0.14931447413419524, 0.26182868908489904, 0.13998684803805045, 0.1641393633138749, 0.09552809214519878, 0.22670034018735732, 0.13358310375723148, 0.11412642400471434, 0.1406684058207658, 0.08805808370872852, 0.09144468263031975, 0.1751591397389289, 0.1381885945316284, 0.09459975445943494, 0.1776870766714696, 0.10438209970391567, 0.16758511954497907, 0.11491506555748564, 0.11609496353494546, 0.14311930495164088, 0.22085443048948245, 0.1620691332725748, 0.13708041770563972, 0.19768223196508425, 0.11957630455013245, 0.10203665257581782, 0.15004090934751496, 0.15348953074745594, 0.09461578867969014, 0.09146843135597245, 0.1232352477288054, 0.08835560927588133, 0.12014076579362155, 0.12213775782936043, 0.10171524038718593, 0.23341631126259607, 0.1519793875875973, 0.0871457112953067, 0.07737537064859945, 0.10197437728845304, 0.09373369206103588, 0.1437009342255131, 0.14509642466662392, 0.1348172867250058, 0.11570515501643382, 0.08634632918983699, 0.16697626350627792, 0.14559436649564775, 0.1954108119131096, 0.15069183893501759, 0.12302651941295593, 0.16259178909803593, 0.16874145265788804, 0.13853452919471648, 0.143855438838082, 0.11872317371589523, 0.1658329079228063, 0.10709863216165574, 0.15608595594042735, 0.14338032642920173, 0.10658586653129709, 0.13649871182297507, 0.16836465997320993, 0.18486669948024137, 0.1602105733247534, 0.09679868727201417, 0.07835662968817257, 0.26605390913544164, 0.24626667010447673, 0.09985774530157929, 0.09916707873344423, 0.09310077320063308, 0.10387671916114707, 0.12638723988446499, 0.1705598849202356, 0.14365847763274947, 0.15453602217378157, 0.12599023780034435, 0.0916081121672065, 0.09417839844020144, 0.10814676301613932], [0.030833139054236874, 0.0196716018892344, 0.008343813110954099, 0.07449546994100656, 0.03556911375433688, 0.012668287512966463, 0.0684532348907763, 0.024292962174982797, 0.04520224422336586, 0.03166769800196973, 0.04971188590711644, 0.03479704651380739, 0.04175934166977963, 0.02418262444646849, 0.059779736799218004, 0.021512578203973752, 0.03848168811190032, 0.051588858778197924, 0.05604243431721003, 0.03309905859491518, 0.020148524180835774, 0.012909886746426985, 0.01959822024218738, 0.08795829309571175, 0.004840988596345509, 0.0459163875559405, 0.012957765326474704, 0.032411119299790556, 0.0342442910938013, 0.013217310169561496, 0.03463395405560732, 0.03412508015190402, 0.061379987220730514, 0.03684930030196425, 0.0425196647824299, 0.03143036587824745, 0.032713815960432255, 0.054716910686223745, 0.07167992061905323, 0.044428001293131424, 0.01784539000401574, 0.011825902977087086, 0.02439088736390395, 0.016411064650803324, 0.05603509136445581, 0.0339337382014961, 0.03924323696522944, 0.04308455503515659, 0.017146156657667413, 0.07404264302984362, 0.03860800451929531, 0.011718855596207564, 0.07546576626238323, 0.0187172842467384, 0.03835912936577394, 0.023759801368859988, 0.055989850042087425, 0.05228680318161365, 0.012418059256648826, 0.028496806457218145, 0.06942035194726721, 0.0661445063568892, 0.05142588889406574, 0.04147975022093423, 0.027732930611819032, 0.014564476742018617, 0.011349171249856873, 0.04487883637569124, 0.0643216154628223, 0.04561580146753019, 0.033693952681196314, 0.04906492465506158, 0.0689344376986546, 0.021949388131859805, 0.06227958511801497, 0.03931499259065717, 0.06196574187807499, 0.042106007946835416, 0.03236910320758339, 0.09465996897028339, 0.09361375333561052, 0.061267337821904695, 0.04487001870368277, 0.02139760947395717, 0.07133471373949321, 0.08749154636696463, 0.099686095641265, 0.10251122106227184, 0.06998431523360553, 0.04040198708553949, 0.04160921524969801, 0.06796515261333796, 0.16118453154640813, 0.046818582491288264, 0.06444567574128028, 0.027516937867227583, 0.041797557965882366, 0.054317120042058735, 0.04640253546137003, 0.0924430177697251, 0.050357092817824696, 0.06365382811054587, 0.015774406323720132, 0.07695567704016164, 0.015386784986232319, 0.02622336393312341, 0.05479969797776111, 0.055941812498795415, 0.0711862918650431, 0.023139442519975767, 0.05011998094438065, 0.05021891353892223, 0.02453841483070245, 0.07023387603581914, 0.04661214477833241, 0.043120764180897705, 0.037433074622024456, 0.040413574165394234, 0.0801726870779549, 0.024736027210770596, 0.029635425702097918, 0.14104018829041912, 0.047100782469515844, 0.0665210462325523, 0.024636755622322523, 0.08199095846183839, 0.054133959910682136, 0.029247836923346888, 0.02518157628665288, 0.020953954550467675, 0.07417110065298696, 0.0355601160516662, 0.03347747538599276, 0.03186889758874332, 0.024523432066123334, 0.019089005429357774, 0.026885131749534802, 0.07552034236610898, 0.03972745432908978, 0.07445772478897726, 0.02803747929001768, 0.047297375952644695, 0.09243423074123361, 0.05572683673592345, 0.04300101314701381, 0.011641631060610376, 0.06394259346228454, 0.020471974163346236, 0.06892457814706911, 0.047756051945109526, 0.023329510849209565, 0.0570703404504926, 0.015868360304363793, 0.030563049010872364, 0.01651627150544476, 0.032616829229218346, 0.026673000088081728, 0.040303127269350716, 0.023585627448835203, 0.03801747713418257, 0.07399521452645141, 0.09874987491076032, 0.015405524454470125, 0.04198040400121001, 0.03825374248047029, 0.03680710034865526, 0.0702432299693746, 0.05181147626811459, 0.03184796998187179, 0.013358291415047022, 0.0650859720283939, 0.05901276787382461, 0.05164410903929703, 0.012606689255804786, 0.0023207582689205846, 0.026791542618265076, 0.022127141597710794, 0.03926815014452704, 0.030684290085768992, 0.03683434626568229, 0.06603748387386722, 0.03833901572732195, 0.027684262961209304, 0.0177692657621998, 0.02937794355074725, 0.04064440028741956, 0.11373685297345924, 0.05126661921460783, 0.055702678153231266, 0.05733376744413569, 0.03688320352305328, 0.025394117805145444, 0.017177905256469405, 0.04041185429800422, 0.017306964258633314, 0.030158807395867286, 0.02524549674783503, 0.06809093658962558, 0.05871992693432878, 0.07177031133323908, 0.027709495982215292, 0.07241559485273977, 0.005755719602964218, 0.02173223093362345, 0.018095462169918804, 0.016211424052955645, 0.02545897863925465, 0.07736476799172741, 0.005682113396394397, 0.015005880324620635, 0.003366811349312024, 0.02825085584434771, 0.04547215615128798, 0.04701208097920303, 0.03100959400105621, 0.05671212922841792, 0.024171728760965412, 0.05667772038929886, 0.05206034759119634, 0.03343827849734695, 0.07510513803290744, 0.014118811795337787, 0.053361980770263946, 0.05256849371137158, 0.07204331442593567, 0.02081778625236644, 0.02736860983854821, 0.02028988655506363, 0.03097878960562089, 0.045150709488699516, 0.020312022665635716, 0.03680412792750905, 0.056993494170808026, 0.10798914042571861, 0.04511469569537909, 0.053281530046895634, 0.008144745163829818, 0.031875445725276105, 0.04368328339149875, 0.03718509579137449, 0.020113644197643287, 0.016851224298138293, 0.010690803906219381, 0.01914666120653912, 0.14232891671840223, 0.023862757840223854, 0.05832688552477668, 0.045200849943343675, 0.03369152418247635, 0.12220754843926239, 0.015670552571874954, 0.045894542558779644, 0.0646030838270822, 0.1340588750017266, 0.06866548721107744, 0.11829188919716305, 0.01649889663132208, 0.008407611955678271, 0.04327614213370028, 0.06735300239656242, 0.06318973587645639, 0.03688655898816163, 0.01980722051924996, 0.006120599620419765, 0.043840335246415875, 0.020915835930575288, 0.03413500865140269, 0.021953764409127257, 0.07712066939641392, 0.06457529781806855, 0.05673936365412609, 0.0889129612234331, 0.07116605948296285, 0.03667093588099365, 0.04560247919852695, 0.0864921770088615, 0.03564749987074926, 0.04159320784252017, 0.01891880750566, 0.03489798625871059, 0.045421605839604334, 0.028133826337814815, 0.04905940499156714, 0.02119007242482997, 0.04518432542681695, 0.028021544661192645, 0.0629045443248845, 0.024423482489862272, 0.018601541767918298, 0.026186584051878705, 0.028526243385708625, 0.029933868659540053, 0.028731487916722417, 0.013703712799225845, 0.020502801541419282, 0.06117542259274952, 0.04346820803719663, 0.07395876406301415, 0.016317027358097896, 0.06768824247222754, 0.04148856406250308, 0.03314508898784557, 0.07776635894251448, 0.02223218374344851, 0.019254591503751375, 0.04112364957109094, 0.04218858839463323, 0.009846379661241607, 0.018638539984221422, 0.04287926262364753, 0.012494579948965582, 0.0619727592434614, 0.05044062704508824, 0.05065855224646869, 0.03182525164447725, 0.06343732017182535, 0.025724621542218714, 0.019323223405667854, 0.08295288910308192, 0.02130274289107371, 0.03285969442297374, 0.02803453176672901, 0.032051554017309705, 0.029488252550964395, 0.051740207108518774, 0.06837755306473664, 0.0037602305359717824, 0.03866936050115093, 0.030922562582418326, 0.04329950781539083, 0.0517099121615531, 0.03347065337302704, 0.060297979958235264, 0.02745017330462654, 0.013816567126571411, 0.024732367225712346, 0.0434716018067012, 0.06933440454304218, 0.017096703766935298, 0.02823481970887271, 0.021781308441272667, 0.0027868327555141503, 0.020087528260304563, 0.0283759560871629, 0.03557723811677387, 0.017920495348892385, 0.02780328621156514, 0.03540395668918087, 0.07653948445353778, 0.055910651872475306, 0.041758487481744065, 0.031160019195428303, 0.10321985239223128, 0.0774621837321789, 0.09529383011883306, 0.19960178783343685, 0.08969509102884801, 0.10504648945624791, 0.20760803483426574, 0.12216080175412279, 0.12625561831819435, 0.17174307707576983, 0.23535075988019669, 0.09033993787823186, 0.1640697259215578, 0.23409572399912343, 0.17020550796822195, 0.1485129010172621, 0.10176781700142931, 0.11817825537535454, 0.13103982974444667, 0.11928372025009125, 0.22498592734336856, 0.0738280541413734, 0.16091560404146873, 0.25463662500823697, 0.11691280835939032, 0.2246049058533484, 0.09109557636322514, 0.12859666810160683, 0.11841598778001725, 0.11550884498583695, 0.10442480144481506, 0.24225903434618828, 0.11030742207602148, 0.12555070251466768, 0.10076913712245804, 0.10716540438513603, 0.11529944251261412, 0.16839099807604668, 0.1461532736016858, 0.14060002481264455, 0.16235889836905465, 0.14599889156318482, 0.16442762687802315, 0.12158031395125775, 0.21023410762990677, 0.13689217458088554, 0.25557135952816856, 0.20060781449560197, 0.1985595098906948, 0.18184328752179302, 0.11664170516474594, 0.12740562354484875, 0.2461868590645252, 0.05975217678614202, 0.11524449868668472, 0.21612533908938208, 0.15531190070173434, 0.15697261078223107, 0.1433655409322631, 0.1418623691725154, 0.1747968107942612, 0.2459920122618637, 0.15463592003910773, 0.11712350552120518, 0.13671010612480103, 0.16577131445369414, 0.13399530502576984, 0.14270347242634143, 0.2552244749160544, 0.11166718217634386, 0.1967591726251187, 0.176337153140095, 0.17625562606319306, 0.22149261237392504, 0.15522614481949037, 0.12555179035952016, 0.20229434173914695, 0.285011766057822, 0.12939675500796688, 0.17974351713013265, 0.24069989220269267, 0.20545307546854022, 0.22941429858967183, 0.09243257599131716, 0.1672022134786652, 0.16411320907213997, 0.18166008525558058, 0.1407708317762421, 0.13699885998522082, 0.08466446742175088, 0.18255213335637124, 0.16865511454882162, 0.21639792849459957, 0.21519323991191006, 0.19617374355514205, 0.2264160909239323, 0.1290716732581777, 0.1454850610706114, 0.1749502428837361, 0.20347615493641746, 0.13477528978499675, 0.14644751265164346, 0.14242172060954955, 0.19805709410819317, 0.11583894461153016, 0.14649977516983786, 0.15369878000309392, 0.12655386400799598, 0.08441663797824614, 0.10493739087495113, 0.18585691408764932, 0.08665745281764577, 0.11141504731870468, 0.12107897069185011, 0.09855377938478224, 0.1614062527134534, 0.14207791567089098, 0.10515633880371049, 0.14547669539047828, 0.11901929734214661, 0.2182140931366913, 0.20246514870274454, 0.09128787975397804, 0.17211732634853932, 0.22645327683177688, 0.18315092299974736, 0.13539453397595114, 0.2236977964639664, 0.1441443918813621, 0.14766471911101572, 0.11667471589340318, 0.07801324609787234, 0.07362887894193973, 0.18345758799583683, 0.10555831279845969, 0.11937460892142789, 0.12739329719014708, 0.15331930601068083, 0.109198241674852, 0.24338734396282705, 0.09628760703508893, 0.1276311521688777, 0.21537733084011465, 0.125850610615265, 0.21292191179048633, 0.1417221444388551, 0.18073520262635526, 0.1113225575236063, 0.19864354973598836, 0.1481088509242381, 0.1784608254749929, 0.1499991422338832, 0.1137267712563757, 0.17001916474151998, 0.10816140295637232, 0.08591067030905716, 0.08032762069976138, 0.10034634085792689, 0.16235037947133665, 0.06286497205315579, 0.2305034151481044, 0.24310752268760438, 0.18447198033813508, 0.11076121425796902, 0.1242006793918629, 0.09918880498697681, 0.11442106142039261, 0.10036105740695231, 0.12797200766902778, 0.11934505324930915, 0.24936126695284921, 0.21154678396640286, 0.15317341222638084, 0.10779005715683584, 0.1479812972848454, 0.15778608890550752], [0.06638147267362764, 0.07595292923431243, 0.03463783812138342, 0.03520986448312479, 0.031784377023277265, 0.03676459779061618, 0.03231394870747482, 0.014553650004428723, 0.036069794347690004, 0.0814122326611992, 0.05800442762612816, 0.05068914979816445, 0.013571706273773266, 0.024751266614804347, 0.041067935826797644, 0.06863722622755074, 0.03890029387548566, 0.04009107030147026, 0.035255952332649505, 0.02942171972996045, 0.022345038070794077, 0.03518727638067738, 0.012185437616050966, 0.0406854817523591, 0.04169000305175301, 0.044207751014900785, 0.030667673638691346, 0.06640561976500096, 0.04540922202830834, 0.042080225257743756, 0.0654174812558678, 0.07296850349033072, 0.05018109560854012, 0.0556150415251332, 0.041734290594655665, 0.03127551269567302, 0.03873587991561621, 0.06695060705345485, 0.016468865984690287, 0.02058202843932856, 0.0567215942447224, 0.04874356609258441, 0.04067742250739567, 0.04461400744114672, 0.01786055279925706, 0.0316330248625168, 0.04088970547121379, 0.04403747648241059, 0.09806142233672643, 0.03353558698548906, 0.04594788909138692, 0.0542539714144603, 0.04546169905112155, 0.07114393486370964, 0.010453866317778105, 0.09564262228987871, 0.040472340770065784, 0.058236012175198526, 0.017611899811233726, 0.044413556705319115, 0.03838291639582284, 0.009548333154300289, 0.04016739947180595, 0.06151903983986667, 0.05374451911437416, 0.05672898699319171, 0.08264040183876792, 0.05949063819923228, 0.020056700882231517, 0.0897051114588976, 0.10008816156656512, 0.0776424595425206, 0.08172378529824557, 0.021630224411285693, 0.07413723190585453, 0.10185875929892065, 0.08214735531158025, 0.058553532637175054, 0.12813670891186885, 0.10332782482427937, 0.08445862725737595, 0.07961905831771512, 0.024838238661628098, 0.11545474385662426, 0.04681968948833885, 0.04616357348558884, 0.058060367366359125, 0.0638814673068062, 0.039145468824332764, 0.013278960137658063, 0.10187203560264842, 0.04429177553843587, 0.1402997183463266, 0.09340129417156981, 0.047536958459644556, 0.026456668349583785, 0.12539782200849828, 0.02181785275048066, 0.05229255267148537, 0.10028092461007257, 0.06922281617599149, 0.10318347087670719, 0.1573951695595057, 0.04179975663822505, 0.039179621023997184, 0.024410851615210696, 0.05801255581900478, 0.03911239297820195, 0.03572290590513618, 0.009762047744926908, 0.015915302341924082, 0.0506467774750725, 0.1171020320766876, 0.03558078510386329, 0.05490559048109478, 0.012164059932523919, 0.060645990719598156, 0.029845565534947865, 0.03091891217345913, 0.026425582416836294, 0.048681286974780025, 0.03216135548427701, 0.019286585250689138, 0.018437604697781707, 0.014213018584996464, 0.029350033052445903, 0.022932072094972097, 0.02831180005394403, 0.011687601124116731, 0.018231247424057895, 0.03567053613463237, 0.029929300860291528, 0.019961884095063134, 0.0284996792869342, 0.06114465650171042, 0.05378346702444458, 0.018299446486297156, 0.014853480538623709, 0.057879409737764835, 0.009796535108058203, 0.04486392830468474, 0.06997622534512513, 0.03337826699979844, 0.04488978760256883, 0.01909257539908492, 0.0654818403023866, 0.06101396190182817, 0.012123761792486955, 0.13611160759483615, 0.020148254134842468, 0.03767722301305302, 0.021776202465257338, 0.040506167382362394, 0.007551523064443422, 0.039143178221439166, 0.03611035104240141, 0.04284506445870765, 0.011910052947519768, 0.005101218609319579, 0.08864588765127045, 0.06241908589858682, 0.015557480867080873, 0.07581251297867106, 0.05403349897073162, 0.004711891289785384, 0.005211971461727855, 0.05635479134657691, 0.018395908447282932, 0.020985069211512324, 0.055034603517983234, 0.020481649853829897, 0.06797660562780596, 0.01930057210096669, 0.06917294385212083, 0.02118737004967707, 0.05013284356062932, 0.024380177454722506, 0.04421977093443275, 0.07197242064942276, 0.03819186555882616, 0.0310926360168284, 0.06536583926889204, 0.0567543100295288, 0.024643748089851394, 0.02776542997678682, 0.0784795331738649, 0.09334871755732645, 0.055875446301914995, 0.006815765039890164, 0.02616305366128443, 0.059664823610575936, 0.07158905493035432, 0.0499188254076627, 0.036333014497593526, 0.042723788909854434, 0.07851821295316182, 0.026686686248848998, 0.05453011546764643, 0.038703286704877694, 0.04074322179921212, 0.012435988586906706, 0.04498382872571388, 0.025818526684757204, 0.06003436527305073, 0.031183231659534, 0.018008829117001548, 0.04880052089931504, 0.04499497147457254, 0.020468911726868922, 0.03513468061423591, 0.036435731566481055, 0.010164246778003871, 0.12229488246263036, 0.06913241014004716, 0.044917849403235226, 0.050779912064993576, 0.03844037299014388, 0.03825280402276305, 0.12194896312130075, 0.038556439141111995, 0.009865381514593478, 0.014609621345786559, 0.031103878357117216, 0.04817407165143279, 0.008483375178559894, 0.026555844177041325, 0.04656977245524045, 0.06425017776388316, 0.0793458330595205, 0.055724343119729916, 0.008239630898911386, 0.02554827576292859, 0.03510505599420398, 0.018893972850374637, 0.02315383922729281, 0.05774470083715935, 0.05927205416223696, 0.027474303159021565, 0.08221416583945675, 0.03004871673070856, 0.022275846924692876, 0.026435417070564245, 0.02428365420670279, 0.07052366411493671, 0.026343804446139166, 0.09962949706541915, 0.05183349746549803, 0.037774202083387685, 0.019693630747497082, 0.02122342789305314, 0.06199807461891925, 0.024759295216250806, 0.04547917351667439, 0.060307636496520815, 0.1459718639812162, 0.04266779171302915, 0.10424143063925928, 0.06528325499065461, 0.03856006656743346, 0.09265330124406085, 0.0770778374205674, 0.07488876415957367, 0.04735705803238577, 0.0554004717888611, 0.06786749938562994, 0.08630566524281617, 0.07953619058694571, 0.0386810050376, 0.1262795738875866, 0.07701424446197287, 0.06154327503135128, 0.030006229494427963, 0.057904617860913284, 0.0296422592063825, 0.030710955691193382, 0.11599484350412123, 0.07790217100973092, 0.05643404697278335, 0.09471377132520561, 0.05091166769665095, 0.04172294483249707, 0.09011610230851559, 0.11067816266609777, 0.08319725582916891, 0.04347891028549883, 0.017303988007047487, 0.069533173715876, 0.028804710600525144, 0.05107360719252498, 0.05431210599659432, 0.025756986841799754, 0.018157404209036502, 0.0075306064700858015, 0.021952663157736103, 0.02780369798382444, 0.05660657763421055, 0.04751950697672944, 0.03751681186258793, 0.028141778330468846, 0.017649528134854573, 0.06474761397487695, 0.050415832609418905, 0.019403172341445764, 0.09463244343116399, 0.07323621291547053, 0.05279656574730912, 0.009289145499708192, 0.03738296864133689, 0.01718127795855605, 0.068364123543424, 0.025679820720406792, 0.06684769846258626, 0.017959747778912707, 0.0019941649318958123, 0.12160863622181839, 0.11496443992420552, 0.04035211859210845, 0.023558626679943937, 0.0707451401338462, 0.01758484924662738, 0.03480314840412429, 0.08314280229951106, 0.008801100569056168, 0.023621556972483956, 0.09490088830071111, 0.04507261448569837, 0.07928672171528302, 0.04867944836376175, 0.03125959338860647, 0.031188490853134184, 0.049098682319444996, 0.027270433755831856, 0.12431032189558591, 0.057369493954484506, 0.058119390610485315, 0.07947841223569647, 0.06247135607766048, 0.05920663408394303, 0.02214860738134913, 0.045509905133756905, 0.04506939308597677, 0.06254401185639924, 0.06981982849538326, 0.09049549969213624, 0.006249222910076741, 0.05646135417684432, 0.0877921439466938, 0.03819358925665579, 0.02568454173724017, 0.041155315815441074, 0.062293822862087726, 0.05220301231489547, 0.16094345899839557, 0.2209252783007199, 0.1268359452425953, 0.1846601162105799, 0.0633000218940358, 0.1396276447321138, 0.21490483845193542, 0.13678360460025651, 0.2576171973299596, 0.22145533453552957, 0.15796267217205417, 0.2801924601437584, 0.11711428948347608, 0.1927234827270431, 0.12999315445701923, 0.15300395357753002, 0.10621255188579522, 0.11596651357268134, 0.1056228863495973, 0.17659690291170152, 0.156434464658941, 0.15392822333641593, 0.11109572655010609, 0.17983978373869774, 0.07078456301842967, 0.12417298531340015, 0.14672123586698887, 0.1172305892912611, 0.14535566882020043, 0.1333198912682072, 0.14506469330480024, 0.16380580863164318, 0.1845193398936141, 0.13079434452999023, 0.11839348777768113, 0.1138220572723977, 0.20224684428784157, 0.12966647924434754, 0.0950298515418845, 0.2044757771035356, 0.1337871742585013, 0.13673733288962997, 0.18421160237443063, 0.1993218439841463, 0.12254150914809397, 0.16040028733832223, 0.38245900804477356, 0.09274726958885308, 0.20520616533054462, 0.14801891220192756, 0.10042457375675441, 0.16929594709748225, 0.16950642209379904, 0.15990036900245375, 0.1732145481172108, 0.2673690982403294, 0.11928064057663565, 0.1045538642774186, 0.14840626157820225, 0.10611260039431435, 0.1671404821137267, 0.1497111544613877, 0.15671731964234384, 0.14343831928506975, 0.09894874367502429, 0.12835684427691083, 0.12632752333076733, 0.19166087281079064, 0.06501978203173607, 0.22532974760378563, 0.22268557981137307, 0.17150309237260974, 0.2506055469594656, 0.15139585841567288, 0.19445117953563892, 0.222061233474843, 0.31209974639838745, 0.46280330647864654, 0.3453612003114916, 0.24726232393614708, 0.1831249066538388, 0.1473867670903283, 0.07539075859371694, 0.2076968857117238, 0.16987000742266256, 0.16373966460026082, 0.14845310019389277, 0.1966704749652455, 0.20980316785074052, 0.1660029334767211, 0.21940911368977642, 0.1818107287850111, 0.37507851698225547, 0.2506278707615791, 0.13942492254559072, 0.15635937272060305, 0.1926547186749597, 0.1779253759811963, 0.21360448080926173, 0.36497826057095684, 0.3072857724562768, 0.25490057294166857, 0.24644256389189154, 0.10899551182744965, 0.13990009624150493, 0.17173198412262625, 0.16628148304598947, 0.19164349793666796, 0.12104147068795659, 0.08338409701302167, 0.11883162878333561, 0.16996998189678117, 0.19705034732337923, 0.13451169425201032, 0.18533687828288925, 0.13533811926120712, 0.11383403122665421, 0.1458683808244044, 0.09983992609646052, 0.13209902290855685, 0.14958488784970778, 0.1254872091475033, 0.10772471751777396, 0.1876653565634643, 0.13822801741621188, 0.1114301545725715, 0.1545183102209722, 0.1594780400515564, 0.18797899295966472, 0.15361507723648704, 0.11026788427824936, 0.07194127151442152, 0.0885876956125421, 0.18363709771825423, 0.18740116348189695, 0.12935843528999438, 0.03859922898212268, 0.23845750688304826, 0.22418246965014169, 0.1250291421949383, 0.11601632460951807, 0.14270719561365344, 0.1488979061644885, 0.09314175890458208, 0.1108481575764956, 0.22743049858798906, 0.11945932292409482, 0.06238877946030229, 0.2001019359956826, 0.14016433528834774, 0.1396214853852026, 0.16717068129970183, 0.06366694736624919, 0.09378544896120027, 0.11555143947442693, 0.13645296105213706, 0.16628983340436415, 0.09171865099380094, 0.19888848336713932, 0.16800174880171978, 0.23865811466690035, 0.1183519428295474, 0.22494301109785036, 0.18780415637358544, 0.15419915799171696, 0.1704378777574147, 0.1264725590965921, 0.14572846252591382, 0.09816594737311525, 0.14731515319116656, 0.13262748568048402, 0.187506515893244, 0.1453615676972174, 0.131427010581378, 0.12126046458199141, 0.14379519368371657], [0.024026445931785052, 0.04392825915748554, 0.012766876325552023, 0.02177805831325391, 0.034271831954679186, 0.05588150605739606, 0.013980792437289512, 0.0968143537700657, 0.03960371197712037, 0.022149057458004644, 0.026338374797975826, 0.0354751760530616, 0.09175273424555218, 0.10109944359189081, 0.06703329092312245, 0.008246642518638363, 0.07180419540213001, 0.04654285595602086, 0.021882223288318323, 0.021928246020369475, 0.05333961483331458, 0.06559840824094511, 0.05140336973953152, 0.05758063927773507, 0.01928844109868571, 0.02904810439494829, 0.028503599741886702, 0.025787952115699172, 0.06163083122021729, 0.023739147638421387, 0.011891139194279188, 0.06894973647450248, 0.031586134535891396, 0.09748425169457352, 0.1184914167970419, 0.021284839416283275, 0.019118459594826546, 0.008522614202041541, 0.07280379458661042, 0.05096885616019849, 0.0101834018489406, 0.03818929150340058, 0.029318301690622207, 0.008034732065073425, 0.0019825353581015203, 0.05986164692008208, 0.061719513558332, 0.04684194817297882, 0.06092689983967332, 0.030827761117008426, 0.07980454352594192, 0.03670625253430298, 0.055663822173711755, 0.0571847212080273, 0.039102449156944795, 0.07316482118180684, 0.019672442670731295, 0.05741588823917893, 0.043015216417129964, 0.04551302311160872, 0.053915444821599996, 0.01745110753202631, 0.05069341690790269, 0.07962640510090897, 0.04121532731298958, 0.03886107400420212, 0.0922397056955003, 0.008408776409323178, 0.06665301253838886, 0.03761315891038507, 0.028111923884059635, 0.0473663698311054, 0.04500132234346482, 0.031083167170084296, 0.08594692158963411, 0.07698477305952581, 0.14249086770559513, 0.02221468054959851, 0.036193402634272655, 0.04497011192142964, 0.14632113878765415, 0.05356175351827856, 0.026931939721708337, 0.040599178117249286, 0.08624312182467792, 0.039018577850994565, 0.006928868824616075, 0.03642795194360999, 0.02101193783023665, 0.059953458727367466, 0.06210904628519089, 0.054342033221356334, 0.03325031882512473, 0.04425759269525448, 0.09203267809484275, 0.049877560081621336, 0.049948001866258925, 0.08654191143690579, 0.04207308148784984, 0.019709732000445648, 0.08997901853534485, 0.05612859622605386, 0.06533709564997305, 0.03683179136245482, 0.026261664498897812, 0.05108350121806707, 0.045379838725972566, 0.09202998146534928, 0.014262424552843217, 0.07164863358822561, 0.03578485943557274, 0.025347361543906793, 0.02592225690492459, 0.057352249315308954, 0.07980424475165145, 0.05391738302404842, 0.04110258598361285, 0.03615428618485889, 0.07828178289797037, 0.04128431353057104, 0.024975655683045907, 0.057877540483229586, 0.007082218080834156, 0.027120253709595532, 0.04505402919265532, 0.05647481434167393, 0.07767289621575225, 0.06287662042004448, 0.02835014083933446, 0.04349841488405101, 0.05419078831290526, 0.012234113885149842, 0.044698058777759155, 0.015275627543639033, 0.05908795940359274, 0.010577897867938925, 0.005821636201994073, 0.06096006761635504, 0.008866103129431365, 0.09277785947966961, 0.08107308553712023, 0.04736749598035409, 0.06604841594854671, 0.02801520911405885, 0.011254076755815938, 0.015166196671705094, 0.022633460598186623, 0.05971751896844757, 0.08375256232196286, 0.07634312845766544, 0.02174400570501964, 0.056256107730610724, 0.016004284411939164, 0.005103266458102172, 0.04179891777194796, 0.029727134087513533, 0.026386555982753638, 0.1090971946776394, 0.055270707985806855, 0.08481763138045227, 0.015106685046527176, 0.04800355963168606, 0.06013347789825452, 0.05805708084916396, 0.03738684121579413, 0.03513461549676234, 0.04592988985560594, 0.016474111771751798, 0.027757541186386542, 0.03181555680179548, 0.01484024541212186, 0.04220033635295207, 0.010927998134115291, 0.018361011227112145, 0.04487006849939785, 0.020929453143429373, 0.005611064487076815, 0.023278629204498667, 0.050938224134546135, 0.04048845925999265, 0.018021004169338176, 0.0444277638058749, 0.02157544912469964, 0.061412373587729475, 0.06284696515649557, 0.07276967303046296, 0.03616947004751813, 0.01150146569876421, 0.054563214296414975, 0.03296016685424313, 0.04958669947940977, 0.05007459023486703, 0.007286220591800709, 0.05362946419946609, 0.03427392337471247, 0.037026013803458026, 0.037110578418979724, 0.0479286668762084, 0.02758611560679011, 0.06262525931120881, 0.05705275873263037, 0.039001551546877435, 0.03699517876450573, 0.09165089051689833, 0.02429896064342991, 0.03528628941445101, 0.006046962770332973, 0.03824784743389295, 0.022664695918079347, 0.034205511723074226, 0.10920511348353279, 0.02793242948340072, 0.07596272749886399, 0.043790144996056636, 0.15817074165228875, 0.04720158814903229, 0.05204059018362915, 0.08419490915032164, 0.057594390555975906, 0.033025269006048484, 0.018973603859663974, 0.024249446465663856, 0.03176478240939398, 0.03208947345434177, 0.0439200543558165, 0.033801208821035204, 0.06851158780796875, 0.007448395659711453, 0.05288745058820613, 0.01873893772191819, 0.023441422888408267, 0.039940388467643535, 0.08143635676993478, 0.025391082181745482, 0.02953302464447916, 0.035571331578877666, 0.0594727079113645, 0.05745376745659498, 0.012063604738232831, 0.08394710268945464, 0.046820536015495184, 0.028249120655199213, 0.05399311464580317, 0.045629686811157776, 0.05880676300054597, 0.03362845982454958, 0.08227181395575886, 0.07075054105371237, 0.06565126830772047, 0.05326441181222758, 0.04708644513401294, 0.09779538298326154, 0.16553411831057843, 0.02320221959493093, 0.1371901214963967, 0.13859365586071246, 0.14225940190015302, 0.05373251068616106, 0.018743494029847846, 0.01987420150168961, 0.11304168180832941, 0.04023320259406202, 0.03237901638532358, 0.030805628836875966, 0.013055351521489362, 0.03132631390115186, 0.06956586268760505, 0.04061114058018692, 0.09609144256119767, 0.07737775318204396, 0.036171281845459057, 0.07015577337193875, 0.046106607187539346, 0.042606022043694416, 0.014629719662480058, 0.1362727312070708, 0.0621371463902535, 0.027848311114094915, 0.08475816763576963, 0.03437324284365581, 0.012957476128283288, 0.06372297520659144, 0.03312410583959953, 0.04401854261936199, 0.02317548121115373, 0.017217433478142467, 0.034024841377451535, 0.01849844357028844, 0.02865187605963119, 0.026796673492137945, 0.02540959661165553, 0.031044747860681628, 0.013806397309376588, 0.05994317016654438, 0.060103271051400134, 0.04096081758278512, 0.06246066532067715, 0.0690013018526858, 0.016195590930780577, 0.006988308150246139, 0.11735265008023671, 0.06017173249875346, 0.08995412833868496, 0.05553951674711801, 0.0660138194178862, 0.010704304290665014, 0.032946863737438, 0.023106565856705272, 0.021953546074068835, 0.060195619120232524, 0.03535207338450897, 0.01899654436255655, 0.05579563909240308, 0.020488632745259715, 0.04015166402584122, 0.04670693666764325, 0.019600493608102686, 0.0031924760720181853, 0.028115945845662106, 0.05137924563079592, 0.04714292113579089, 0.0173911860498089, 0.049747566452189806, 0.0249113138735054, 0.056457473941507845, 0.058793310496595606, 0.015130103396762525, 0.018190240652690974, 0.006968476527911281, 0.05278159638926868, 0.026745154079230084, 0.031020420738646103, 0.05018662676335343, 0.0403065248692949, 0.024366249976259087, 0.02615597309364427, 0.03748586574088662, 0.018478657434424086, 0.010559682212319347, 0.057705944449070005, 0.07486935915245164, 0.00979662225055959, 0.03557363750352975, 0.0018035384357884348, 0.034295894776380835, 0.023961929837241772, 0.03938493641814397, 0.0832176567505925, 0.04390265266861647, 0.008422485552728176, 0.045820963644092126, 0.08512658697943534, 0.14074651614552544, 0.08449167629042942, 0.11266445245353446, 0.17662900199572887, 0.13332931414967583, 0.13455076473614863, 0.09279195549747637, 0.23581658730343466, 0.09983149146841419, 0.1572269519730922, 0.08377994230437665, 0.10344190297708397, 0.1997844385163438, 0.2073176262239295, 0.14648606219599325, 0.1470720122057584, 0.18580716433784655, 0.12600801104018766, 0.10316211234537825, 0.11590750181987403, 0.12371402203796372, 0.21089165621707517, 0.20705427583907882, 0.0795500950827714, 0.20935633940802467, 0.10432522533641708, 0.08563594351853095, 0.1589759307042245, 0.10620278426476064, 0.1018459732914644, 0.2005290146917105, 0.09578625611480206, 0.1247660369582234, 0.1167543430722529, 0.23261544294655326, 0.11272328034523996, 0.1258084987620673, 0.07321512251491509, 0.254434822127223, 0.10584576430940822, 0.18794464157714, 0.19185740500688556, 0.16807547710355253, 0.09823382276320651, 0.08272012860904779, 0.15614439312729145, 0.21241601796880846, 0.10532876221282829, 0.24377354420721534, 0.2862763933597073, 0.24775844247591114, 0.14079157743723164, 0.15838444953964603, 0.11112175821777313, 0.14836296228872192, 0.10402262826720554, 0.16127459284278656, 0.10695617811213579, 0.09390749442841738, 0.1416878696651228, 0.2249596811710827, 0.18205707201794272, 0.1709774794477609, 0.12608949215181414, 0.15181896877625298, 0.1923799229365203, 0.28869392170060065, 0.10214822562111002, 0.15667981197757108, 0.10542443127281244, 0.13285124464140785, 0.19028225162577247, 0.12434229074466614, 0.1308838235995462, 0.15004457124779302, 0.15752594076818036, 0.28998223644110466, 0.30531196224112667, 0.2215754877655737, 0.2313158054265284, 0.22461638185045413, 0.10305589425467676, 0.1215007327376835, 0.20837557832560233, 0.16124552746693935, 0.11346058634620522, 0.11997822491872696, 0.08800287941290487, 0.09608946605435303, 0.17089203000068667, 0.20499507746388837, 0.24797944352030757, 0.2642760335678055, 0.1636813193439476, 0.29245378930241833, 0.20564528692874218, 0.10817870122170258, 0.1332861374342634, 0.11456952159923893, 0.20254575647413733, 0.2244730008345458, 0.21157948059901116, 0.11645666428751524, 0.1446836718147801, 0.1081436450382875, 0.15410567994319624, 0.1702269737518603, 0.17568610097852447, 0.0995744000219049, 0.17622755660164743, 0.15112120057305983, 0.1614763037932496, 0.13807643925951374, 0.10741269756709376, 0.23601983042974628, 0.11427964158957044, 0.10767249330397576, 0.13372017220864374, 0.22171721403156558, 0.14907438217872573, 0.25679838723473014, 0.21661290808791117, 0.1302897224142667, 0.11632678174083272, 0.1743369741785911, 0.20991739156025074, 0.26223223355989306, 0.1396306324750185, 0.13168564186461512, 0.08708106113537666, 0.1038136701249788, 0.12203391461122422, 0.16722550255156335, 0.1647549762480682, 0.11735626601523931, 0.10158951769793227, 0.11930126366355728, 0.16876319423317912, 0.12189499988791444, 0.11589365861108226, 0.1554699446405134, 0.18509010604072004, 0.17701458936977774, 0.13539568310783756, 0.13498426324898197, 0.14966024025794, 0.1822214591647348, 0.1583998172634071, 0.18356073407396195, 0.22208429272136382, 0.0778840913347179, 0.13065313920378685, 0.10080971679980717, 0.1575552819356803, 0.13332304755045524, 0.09835573033459726, 0.16865123814392477, 0.13412298123923042, 0.1414754641272368, 0.24326142975159232, 0.09272276243615536, 0.1096940691012048, 0.12750735236031394, 0.11372302508642597, 0.11626546406337332, 0.09538042869779373, 0.114993198864883, 0.16799834737133595, 0.10634244975423622, 0.11177327003209822, 0.10505633368607491, 0.16139839265135028, 0.14981776325693055, 0.09511537759775117, 0.2278275926026606, 0.23271745521455045], [0.03607570471602582, 0.10156528633688727, 0.04036033105465674, 0.026649580780236472, 0.020595760565371286, 0.06131845503865231, 0.03522687929592306, 0.02615136507477972, 0.02530784672877241, 0.01519963545199003, 0.032303357541921644, 0.03616714497066794, 0.019456162643168243, 0.012042408042977895, 0.007209819600722122, 0.04305762321417851, 0.040757084160201976, 0.08055320294994502, 0.02202359140820561, 0.04855156147612199, 0.03318653817498877, 0.01823888532066297, 0.015121220607280493, 0.04642714603593753, 0.0688139703725615, 0.012181275843402312, 0.031004771477572864, 0.023211925928931565, 0.004515880991088888, 0.029607940382594546, 0.03049538812539991, 0.0629251444291684, 0.029246297086619084, 0.015762903513537062, 0.06367984445645444, 0.02366399249782966, 0.044581425721727075, 0.05330257448217562, 0.02588518974070828, 0.03399836154834878, 0.03470181795437971, 0.015369864976814678, 0.0389520775887274, 0.04772897073698621, 0.03685427987347207, 0.043947434338230285, 0.015147777045175675, 0.015932063388097432, 0.055951446054443243, 0.09644836292511995, 0.05734910452437978, 0.08867150563145838, 0.00392371537483057, 0.08443018241274743, 0.09138157996799677, 0.08883651330946915, 0.05618627881631256, 0.01842081013526167, 0.055772430458737005, 0.059746791188034325, 0.031298311472299604, 0.022688730011483835, 0.08110005949293414, 0.021204894310944987, 0.05180792162014593, 0.014747577501581082, 0.10200464542234138, 0.05707265786646355, 0.021879218308435335, 0.03602595496622305, 0.051415167493565436, 0.028604855498058662, 0.07506710942834616, 0.09614243337343778, 0.10687645900273517, 0.12650256676058616, 0.03766391223536865, 0.12330835549941949, 0.04718984019071345, 0.07994259256989726, 0.12535597828607406, 0.0786171455477034, 0.04543052693348258, 0.05184151840606525, 0.09076868664593467, 0.010929955488761828, 0.05217303146397875, 0.01348699418632614, 0.011537592490053466, 0.03166781483037818, 0.046989561824668805, 0.0496907418804063, 0.29277425920290334, 0.038943807669584794, 0.056821741088623964, 0.023956345056273767, 0.03709712591502936, 0.029207917996832443, 0.02813529148097, 0.0664520523540916, 0.0680975249457744, 0.15423236024235526, 0.04211159272780342, 0.036539042353509896, 0.0542153682439558, 0.013894452413003293, 0.05241572045751157, 0.06309900425314423, 0.10115884604953951, 0.05440718516887677, 0.033516128352212335, 0.06693280317009458, 0.02605265081529656, 0.012281818180194786, 0.0392330824697931, 0.10026371827529323, 0.039061501757392, 0.030236398696058223, 0.024518218837798606, 0.02725253411148104, 0.04053271615937833, 0.05746349294279372, 0.04994326744288687, 0.04703064328960834, 0.02662709226921922, 0.06989980041379891, 0.006587103595055881, 0.0389411072096517, 0.009793546407543605, 0.032851470469106595, 0.019291984255335504, 0.0006708963525353842, 0.04799194190831435, 0.018550074065945322, 0.017747815300319946, 0.05859797722810219, 0.04984185655391024, 0.05231330982379375, 0.03645120654255152, 0.08211472762688514, 0.10703843297256578, 0.012400706407553967, 0.0784581823034152, 0.014237234624282969, 0.06023866560069784, 0.04343916564398716, 0.057440694166167136, 0.05493609993267925, 0.031202558142643784, 0.0057468291526029435, 0.06321605099665542, 0.045424559108552434, 0.03883993763837122, 0.06872933297868698, 0.06984180755793087, 0.06659012438068468, 0.019172918870143833, 0.050061053461244995, 0.021809630711833318, 0.015836356981326977, 0.04551912500192562, 0.08542151550852484, 0.012929883556470517, 0.008354919470636355, 0.04926920200007097, 0.0696667411454743, 0.026421209970008463, 0.028747583424011548, 0.062084355271391334, 0.05575458827098051, 0.048776795156300075, 0.031065495436890956, 0.0414558865820929, 0.04549451059691849, 0.028927889877870202, 0.005738344250036585, 0.03319993322234481, 0.0882746567649226, 0.04225006695055673, 0.018572357648442832, 0.018056297840009776, 0.05499956265632665, 0.04442132483687132, 0.06415379241168981, 0.013198175208432781, 0.04798447638149223, 0.049140556685386166, 0.024080759650396726, 0.030539018747907494, 0.005551407783998237, 0.0379794868340175, 0.00935773622439874, 0.030992623238313585, 0.0238349182050555, 0.02507879410029179, 0.0748576992942441, 0.07395931564631962, 0.031541023448470144, 0.013372431482909428, 0.04901731612100717, 0.047415089192650015, 0.03136543418100524, 0.03841789214000587, 0.023246143246069554, 0.03148068253311419, 0.03457169025956142, 0.04024463262589228, 0.025925464898107514, 0.02316941571001324, 0.02384717944228361, 0.05702706797408962, 0.04536057927555615, 0.031064463133412986, 0.02155566681927491, 0.01499043599206714, 0.059278811057729114, 0.04281365868425177, 0.061093244341111956, 0.0673650452987321, 0.0456784789510552, 0.023141949542707974, 0.05311409770060451, 0.036250974141782334, 0.04325459974126951, 0.026343021121236588, 0.019477691629060337, 0.038387601023479816, 0.07642962744519596, 0.056418637114186446, 0.015194215379925746, 0.10073832506614347, 0.018114292611097618, 0.048490879651639736, 0.04117656326402099, 0.05998065484867943, 0.06024030119841618, 0.02994407295069147, 0.02271222592812152, 0.048706085240888985, 0.0733213789100128, 0.05169190143445327, 0.039399055418588465, 0.030865310916617036, 0.06863411591057816, 0.03304031497288135, 0.0494760648918248, 0.06917811494560973, 0.019680302732834415, 0.14115992783298417, 0.025026104488079588, 0.03592898738720725, 0.14625032161993368, 0.06680212389197081, 0.1502460370501203, 0.06144770173235767, 0.11080692672441084, 0.06602133474042339, 0.06085600223272078, 0.15989330567179189, 0.09416305369907811, 0.04965305418497132, 0.017469353831162857, 0.05106816413782297, 0.010658677051504774, 0.05977754961819418, 0.04277786322598977, 0.021000944468523228, 0.15621911734342575, 0.2573662575694823, 0.09491071720877964, 0.17481070762920767, 0.003964789178890867, 0.01166478894095147, 0.03889225761315996, 0.02836360483460369, 0.06391338252973172, 0.05376558653229187, 0.0844426696459132, 0.004294438967331043, 0.10139627201903252, 0.02968778589650268, 0.09722020416971176, 0.05081959541947131, 0.07542934644246295, 0.016484597600215388, 0.05270702922115884, 0.03454979546668549, 0.06700344413759247, 0.05442004395468582, 0.039623254880068765, 0.06823548205917881, 0.07195481594892279, 0.057131776871580275, 0.011678887831587947, 0.03986860219869883, 0.0639543260988449, 0.039569161411735325, 0.012746211103794557, 0.03232032638944445, 0.019495658306104523, 0.03333705529991177, 0.02637817689608182, 0.05193136519782486, 0.04306449885329893, 0.03903288837342013, 0.02407025658495484, 0.028195247437144, 0.02120775181890255, 0.0378501788532782, 0.03816756524986798, 0.03323045033480852, 0.07473197660499042, 0.0504028742321797, 0.04347359363530432, 0.023789395345374945, 0.03714727786099238, 0.058720436382798426, 0.031018409757844867, 0.03151077829721955, 0.03042698604986072, 0.0252019829537359, 0.05109831352808303, 0.029026424106691154, 0.060600282083595955, 0.015347110250243738, 0.016117978563171723, 0.053192081620856646, 0.04107874149696962, 0.031128565540477156, 0.009392347119207825, 0.06069461432015223, 0.02646457246174255, 0.015748093118740907, 0.033031344083288026, 0.07446914715992828, 0.010257880916939148, 0.028231148232495593, 0.04258614206205934, 0.04703870253457178, 0.05951017727174106, 0.06009003688250819, 0.08252435483999791, 0.020508242680901484, 0.07936145359229657, 0.031336125572242086, 0.052294862426577084, 0.06345711971422838, 0.0692074254695927, 0.09494751241178283, 0.04935943183579272, 0.05881266570800255, 0.04591751753562882, 0.08329772059955905, 0.15178386662756244, 0.16714284166453347, 0.08567002677028218, 0.10420733972662881, 0.15698284571689947, 0.14164432522750672, 0.15695281507026765, 0.1120952031605186, 0.15103737523238506, 0.09077606407264549, 0.1082979734506338, 0.12924281730046197, 0.32922649996415265, 0.09385805877466356, 0.129539308648917, 0.19435644510292238, 0.17800900213901075, 0.16813532389219732, 0.2136429690665776, 0.12581513308349157, 0.12586878988170816, 0.1536027738644231, 0.22755943118564545, 0.12587913206868595, 0.09023395727478689, 0.2645683727197109, 0.10557480667146946, 0.10689193397880563, 0.13348884429902802, 0.11316899029958634, 0.10797329006656524, 0.15549856568536452, 0.08905994285258556, 0.20150275840874643, 0.1229026276738413, 0.156063417633695, 0.15296865224597916, 0.11926700421158345, 0.11669094929651869, 0.131623987108469, 0.11354969769355752, 0.11453897001281862, 0.20682362208683647, 0.10199839414487924, 0.1765938232382459, 0.139732307664329, 0.12261621038159057, 0.1440527064785842, 0.10769413528783668, 0.14699256888801052, 0.20584784057592193, 0.1683969429183391, 0.12160426185977076, 0.2243631285044455, 0.09374200411501432, 0.2075376619975413, 0.09139199876376698, 0.19120940187525368, 0.19098231809273844, 0.30609009306757684, 0.07871829979722539, 0.130803108575844, 0.19658330948122088, 0.10212357291170668, 0.13018102985956978, 0.2097027796891428, 0.18486493747801552, 0.10738577723743455, 0.13343598423225264, 0.0786165556600017, 0.06119511871328277, 0.27716619833823175, 0.1851580733613622, 0.2206228727534894, 0.37186854729248636, 0.1728559576816136, 0.2829936453171315, 0.23201875238408967, 0.28324654626269496, 0.3163524536836532, 0.19908052628799794, 0.30385762092567264, 0.19312598532246006, 0.16369749912090842, 0.09277869451550708, 0.16901413399365642, 0.0931398130412544, 0.12121254578232767, 0.07758027618570675, 0.1271254881735771, 0.1962329927952059, 0.45659759592625404, 0.20965388795781523, 0.23236205170471824, 0.24247992813827532, 0.27297113150838886, 0.12436200984783712, 0.11750145499864895, 0.1896523281691536, 0.3462478091880199, 0.36342613579284766, 0.15997242723261157, 0.11645605141717581, 0.1306057030395154, 0.26744301040326396, 0.12014248183057194, 0.22267912935105064, 0.2308341046614993, 0.16794616146193397, 0.1179257910999079, 0.2964098979869197, 0.16651595191609475, 0.1962534626645427, 0.15569696713599468, 0.16630028284365134, 0.2516902202079373, 0.18611890083599478, 0.15430864727785512, 0.12849574367846214, 0.19001916171081606, 0.15341074626532294, 0.13454413041472435, 0.16367981781161603, 0.09477927184273159, 0.1808971842570651, 0.11685295390986628, 0.13411178103377744, 0.10184614949168698, 0.19449296197102917, 0.17266477277923017, 0.07662135627000563, 0.29256162383864004, 0.07636464020657925, 0.17463591700840383, 0.17485776074951695, 0.08850508069078769, 0.1525371915270244, 0.14337496381373177, 0.21204371455936663, 0.26662479785661547, 0.08682947786104295, 0.17542474242227693, 0.13282099949015727, 0.18384188834217288, 0.158386594585834, 0.11410031572825487, 0.1875495240693131, 0.12250541108510188, 0.15524587924441985, 0.1644380150302764, 0.08818200609136014, 0.16250240195903087, 0.21981512496788658, 0.25568155361519707, 0.11038197775281246, 0.21348204463720324, 0.1335920056989116, 0.16537883228832678, 0.08747715157486739, 0.12127573271432232, 0.16859761198922513, 0.1250297857087947, 0.1213952117869931, 0.2169248131254027, 0.2557275188906539, 0.12417285507845303, 0.15703797340393066, 0.1419761025857541, 0.19231345714820972, 0.1842727361907882, 0.16757804089255873, 0.1944520375541141, 0.16102478689243718, 0.1859428691527536, 0.1440763479519275], [0.031878619244502436, 0.07924636420343192, 0.04471527277341774, 0.03722058481446678, 0.020334754409568927, 0.04545931651767704, 0.031149322692785534, 0.02749742560779616, 0.07307005610557334, 0.04646884803209574, 0.011661808858926018, 0.06297156169650055, 0.03851234695063003, 0.01159959294337539, 0.07949309048032568, 0.05987238747278049, 0.018347817277836225, 0.03670996806073574, 0.03131866834366755, 0.1124767532512065, 0.012991551719155284, 0.07046612325094401, 0.05911055899735901, 0.07576880766259086, 0.03831555045420124, 0.036882123339080045, 0.05951138769066142, 0.030254671808272123, 0.023946621485294837, 0.02357537336196871, 0.04886623975189944, 0.03757861217543964, 0.04635967667244616, 0.03387434723516626, 0.06174189481703986, 0.06769109231930587, 0.0543262594709954, 0.06334182348162418, 0.028500462611836773, 0.04316545391996061, 0.016911268354423584, 0.06848970067597206, 0.07610103701271358, 0.013096452138627009, 0.07878796017218022, 0.07619178778822384, 0.07375621041583438, 0.005095890467806209, 0.020329470318111203, 0.04906875509468298, 0.0189069771928893, 0.05902758018384057, 0.06911535702285267, 0.03565172484565166, 0.07994572586950757, 0.04598119093345539, 0.04001105624821879, 0.06898130695786207, 0.03768307592479452, 0.037940818546039444, 0.0992030848658854, 0.0618577158198722, 0.049182614912429166, 0.029636565257885286, 0.0358396883483135, 0.1018492674695388, 0.018741714790643706, 0.041633052075462, 0.03694715271253259, 0.03259139511013224, 0.03202468348336557, 0.014567232743326216, 0.09421862571710542, 0.18409904873659536, 0.11322573443213779, 0.13337011599252302, 0.11858513999369838, 0.10721508518702562, 0.07156939711421728, 0.11304722062402195, 0.0532278502660413, 0.10448533005171246, 0.06557927902547583, 0.042098086597698356, 0.19087546414905981, 0.05188304803244049, 0.024835796756369453, 0.08206614233072727, 0.059456570269239534, 0.04778193039519172, 0.0301959473384364, 0.12182756882881927, 0.20925104828371158, 0.046054034403735594, 0.08904829065525725, 0.03387356199504387, 0.05022808744181549, 0.06327730738708089, 0.023610056077520696, 0.12427191790794173, 0.020484539920524247, 0.043357887545660626, 0.06326911790717034, 0.03210262143834224, 0.05473550364014603, 0.04249299343134608, 0.0602216546183392, 0.05565985000782436, 0.0315240852444643, 0.023779041667078293, 0.01669219785159634, 0.0944991977584939, 0.033394538707310156, 0.06354592462641097, 0.0674374406075766, 0.03340547078198964, 0.047414303952527624, 0.026343896376690077, 0.04497868827574196, 0.03569651800658434, 0.07115227756120505, 0.06121591800042699, 0.017817768703905806, 0.04813507011520767, 0.01904961318829127, 0.09648466017097236, 0.015565686626359822, 0.025317286847219355, 0.010632321711689716, 0.03377791591769746, 0.031660648077846534, 0.0034015859954149253, 0.045054427558375944, 0.03602073407701908, 0.03662829925756782, 0.06491936322662138, 0.04085277237238423, 0.04233849264921681, 0.07995766151936785, 0.06080236075626266, 0.0852151160999652, 0.03957873751078883, 0.014636534972176438, 0.042247416286338726, 0.03145943316931446, 0.045777281310649655, 0.02674375596876827, 0.034769792935901114, 0.03398018228190561, 0.00949037285716904, 0.03869658343554024, 0.00982663949065271, 0.0912890901728984, 0.027852133892837073, 0.016698112050371788, 0.11749597746999034, 0.024969662960258224, 0.046456644251461954, 0.013401558145790572, 0.04253135911459404, 0.026359899953428297, 0.05573232575590092, 0.040812280795146386, 0.022285160638632315, 0.028399754608530673, 0.03144217320838042, 0.06531147766978511, 0.03792411399885051, 0.01828996231779456, 0.028775112793570565, 0.031187322569049658, 0.018906226426723505, 0.03733544820739377, 0.025431483743652224, 0.06125362484806007, 0.022355386003431295, 0.0706727295032432, 0.037518819012949546, 0.03126179206094915, 0.04075488165741967, 0.07205802331408186, 0.0835532109223066, 0.09701203509804704, 0.0709290701835867, 0.09719751264539458, 0.0419828899565243, 0.022755209206333084, 0.014837567934826499, 0.07533747717858323, 0.05125761002061829, 0.04846682449081733, 0.05145070248193318, 0.052265670646222374, 0.04172982813249673, 0.041354820432682196, 0.1360139313844904, 0.04367918099066423, 0.07270790336112823, 0.03490579652509863, 0.03467841013785332, 0.11724477723961878, 0.037330595040393454, 0.020028813366567897, 0.0935528799891472, 0.03735422119197827, 0.009553976349472519, 0.060132585405822725, 0.03389985413260518, 0.0330266671165103, 0.056873172401420535, 0.042060506154572776, 0.02003873420518733, 0.023334486590277766, 0.039458312319531556, 0.045295117062426386, 0.03904254491170568, 0.03311853254995039, 0.04691806283869571, 0.01906392179549702, 0.06632238431202789, 0.03269134660161311, 0.017460440398163853, 0.02246932626040953, 0.025497593301078005, 0.01784224521308657, 0.06297579816272182, 0.02804777168128039, 0.015384152516602509, 0.03319484256808797, 0.09254332932253038, 0.07959685708966949, 0.03286683819286766, 0.04463994334782324, 0.06423461468770139, 0.041662289821092165, 0.1461475432640122, 0.03503723806070705, 0.042059448953237266, 0.12732058778525362, 0.04915331587976506, 0.01939521268791249, 0.054601300357570576, 0.033664316569845525, 0.051499816378758806, 0.10991413551833361, 0.036488557159299814, 0.05317316691000616, 0.030063674597430135, 0.0006357282484626218, 0.042520836896954045, 0.06836452190914462, 0.09512834746630923, 0.16024281030460713, 0.02300607618845759, 0.1564021204267779, 0.20982794313421174, 0.10537407631354948, 0.0817515483246215, 0.10115849364909435, 0.04223082665233843, 0.20031731395471483, 0.07518337093173497, 0.03586319575627004, 0.008963969904148291, 0.02379814406947023, 0.05336029154639091, 0.05229424189535841, 0.1441633602183673, 0.17501632562808453, 0.09969607776691837, 0.06578455994566602, 0.07779481144802225, 0.056473814596932743, 0.04364519733034315, 0.030360688800893487, 0.2330147739379637, 0.12668353971093893, 0.061540754602080396, 0.041542990779083584, 0.029354650647409504, 0.024059263223241416, 0.05399927399271438, 0.046732975996189544, 0.01018277174162288, 0.06425673164607537, 0.12908422177837742, 0.03438417491833529, 0.020345448996991884, 0.037143252068950285, 0.07850663736462593, 0.032562812369677334, 0.035883830334510536, 0.038512120954692364, 0.0968991520424043, 0.04759374089659222, 0.016661837787157106, 0.07278920061165288, 0.045119253918528564, 0.052344558550225156, 0.033328750906812574, 0.05073610715748322, 0.007462610421146477, 0.053195295359699, 0.024573798516705155, 0.02165171126234195, 0.013122105550381446, 0.045459948540214574, 0.062061705881909984, 0.04643672213499104, 0.026136273142671394, 0.02379963028004333, 0.018211880721332088, 0.03915099997914607, 0.06587514218183295, 0.08454835147506769, 0.033690321424435225, 0.03899199843046166, 0.11739499175981169, 0.056227310485537016, 0.053994497434506496, 0.004926452407568333, 0.03733669693071035, 0.032750281745628, 0.023188022070474202, 0.06926462925489872, 0.09236687629093086, 0.029213989243632364, 0.08299719962862231, 0.030095304452603864, 0.02482565566747179, 0.00885456393007189, 0.03128271200694144, 0.05759260557111233, 0.028173950192849004, 0.02905713848679537, 0.014237459662610726, 0.05866084623360827, 0.04766158181272688, 0.02495519922024781, 0.039527275554475286, 0.013733556711926095, 0.03413813045969413, 0.054428991861641414, 0.008217018856216342, 0.12083259681540152, 0.03223793746362771, 0.015192168009948107, 0.03318175012546201, 0.03190541316965415, 0.02207972267041764, 0.10230982420785774, 0.02391917447018768, 0.13118987572529625, 0.19219157255945668, 0.11754353620832968, 0.20192171657277694, 0.14012724131105408, 0.1342035736888647, 0.13596520819250615, 0.20031644061448114, 0.20543042990949847, 0.11031159725520881, 0.1127049248785742, 0.2003370177361273, 0.11740686612263804, 0.11506514984273142, 0.18398646445524308, 0.24036561739781212, 0.1560799038458255, 0.0833238595195355, 0.09109224388075453, 0.2979484783305276, 0.11473170241280911, 0.38860058171614525, 0.1269228579176049, 0.2290658358364336, 0.20767240154166378, 0.10431935710291709, 0.1371031245517154, 0.14965006661030555, 0.13358445207197822, 0.1354720927174053, 0.1345000956808367, 0.15609784562501217, 0.09675421586800968, 0.1784830573465555, 0.14869201237395888, 0.2191618817948526, 0.16947579389858633, 0.09834512001684598, 0.161231538701442, 0.19691640451069803, 0.08776798919444123, 0.1822191455792035, 0.23313583115175848, 0.16772097757747098, 0.1300458766279682, 0.20932157433802084, 0.12319486723431658, 0.0891931961861349, 0.1482811134548918, 0.2466389122268846, 0.07626115704976744, 0.19975600133259452, 0.15761699797886033, 0.20473232462761864, 0.2513195562266535, 0.16648995089194468, 0.18999987161688267, 0.1332682416203522, 0.19851274788379672, 0.23432541248058122, 0.1594808439333593, 0.20530131345074024, 0.23653738410963168, 0.12989379285324004, 0.10416040918038738, 0.22126061030693595, 0.07694007949002328, 0.1564433053135872, 0.19121781352066225, 0.12824258992388365, 0.136416265440564, 0.09789195602699634, 0.1766467445920552, 0.26231110997257695, 0.3137585412590735, 0.2738678833890346, 0.21039817301977068, 0.2651891797300308, 0.2665195680193363, 0.4470167777711346, 0.17466577911569228, 0.15467486794917815, 0.21652410317572857, 0.16891604409583155, 0.2888715621684828, 0.10468703334129627, 0.0940360899473871, 0.13652261376621264, 0.10963075959514226, 0.13482096394704235, 0.12612591963261366, 0.17537298552211256, 0.29286784450373343, 0.19223344692539787, 0.19828361098564443, 0.17832456907678038, 0.18856359465468317, 0.14739661898103454, 0.15532455647424345, 0.3244494208164754, 0.33761789000803427, 0.12494893278926612, 0.16538629398470925, 0.1348298658887225, 0.11556285418449871, 0.12772650713281286, 0.17988660703262976, 0.10950417122653416, 0.1355829456400487, 0.2087903076842908, 0.12490859059917352, 0.15356131318596103, 0.18150795551557697, 0.25596351993660776, 0.17160585540677273, 0.14491113864125746, 0.13494724588048074, 0.1411747133299228, 0.15887316767006152, 0.09144817599125447, 0.14570263004110706, 0.13577425311650002, 0.1290421022643005, 0.16277923549134887, 0.15812796330259693, 0.19822580199087822, 0.0896146594576778, 0.06442113794506558, 0.1233952681744291, 0.12116867192690411, 0.15496984244354312, 0.17282658587059668, 0.12155530118052998, 0.17510500796619924, 0.13659317046403885, 0.1235632329518276, 0.08279240900470365, 0.14799527072858426, 0.18565768526206095, 0.10597822857239556, 0.1743850845002359, 0.250063156709075, 0.09187522404376539, 0.15398620087052547, 0.12994363453359375, 0.10681292733117458, 0.12598498243718378, 0.08427439843334499, 0.12280673644835911, 0.18866929946647537, 0.09774178747207889, 0.1707583476578997, 0.12904544240765034, 0.10588478116739182, 0.09757648101977764, 0.11175992478045726, 0.08655082103946517, 0.13648553511067746, 0.11156026694563129, 0.1151787376992645, 0.2231179445140785, 0.20852194708441535, 0.1352302847249854, 0.16261441933531917, 0.12276377423756546, 0.14560438692569733, 0.1677407426459174, 0.1971086312926585, 0.15549185475514782, 0.14928574583703472, 0.17288583511066052, 0.10324606026012091, 0.135370739285023, 0.12732812609042854, 0.14776421861062128, 0.1179575760878863], [0.03816750779327366, 0.009614802773050483, 0.03689721910162799, 0.0205458116327082, 0.07176394514258831, 0.12859242397450632, 0.06930855673647697, 0.010812598479641302, 0.0472255896837, 0.03866251550554749, 0.021826429104792978, 0.02315672929398716, 0.027008008422149767, 0.02779413529130961, 0.02005706477399555, 0.05015847303213612, 0.009991796555808716, 0.013839692448175723, 0.08376576201689821, 0.009638253682022615, 0.051491538798736955, 0.02753214662774436, 0.009438966442230008, 0.022214935273833336, 0.08934426106392376, 0.02754470663926294, 0.04550848021021774, 0.03795406037581064, 0.0335583781012364, 0.036222988949908365, 0.003275858996916683, 0.10968030250120549, 0.038285056324375254, 0.0984471935718771, 0.058611310988424294, 0.03778155269702116, 0.024983713012789528, 0.013457520868659261, 0.02739131668462388, 0.038016753181094126, 0.0698682452521978, 0.0377747766493309, 0.0549148639754182, 0.0531235090907543, 0.004529696429193381, 0.0670052750877315, 0.03780733538611281, 0.04373933038403911, 0.05537487296087127, 0.016861633517809452, 0.043910026264887665, 0.0712807888105031, 0.04707737465298945, 0.03702671477390874, 0.0400788358773195, 0.06784463932196941, 0.05781862066097318, 0.034035543625753735, 0.031828722022774245, 0.1470641674654138, 0.048330491483812375, 0.05365114831816285, 0.043890222892045014, 0.05155562971448226, 0.07888747499354425, 0.051748189744689775, 0.0468452921467683, 0.06264858668850315, 0.02910870386497869, 0.018493808738346544, 0.039754570011169686, 0.07652920355359394, 0.09726315871962617, 0.11414382186147476, 0.17880050886061885, 0.18805074475465283, 0.14125800240905056, 0.11618054321696682, 0.28534691420293623, 0.016825885940042716, 0.16322076260562868, 0.10594881845698242, 0.14598022966134935, 0.17033670818613422, 0.17860564673619886, 0.08018612426014678, 0.02735920993971729, 0.06186068824101841, 0.08627368873285671, 0.083565023998099, 0.0936455689671059, 0.1928280384069489, 0.4069268144667149, 0.07649624645109139, 0.16562295386627798, 0.17916174996043407, 0.056853035780330824, 0.040710643910232096, 0.06936314050108194, 0.06186549927318289, 0.03919439886005656, 0.06023475089140477, 0.06340340545941746, 0.06192762517340242, 0.05317398662408514, 0.048553729504947706, 0.11411680194038538, 0.07344572264100276, 0.015293282039854077, 0.10062413200015023, 0.04163294865359222, 0.039133180774027304, 0.02902116491309097, 0.025845766856124806, 0.04639708474578877, 0.045597863518783165, 0.10626046302457971, 0.03278117041073499, 0.03556167121015249, 0.013166937973320246, 0.06548424581846883, 0.05890415575835974, 0.018490746301869233, 0.04489543367057078, 0.036219135527649236, 0.0512751151296881, 0.024424319440919547, 0.018484853170511704, 0.0187595933675766, 0.08282072361438506, 0.02800010760585147, 0.018849832779397408, 0.00922646705857328, 0.030176754920713367, 0.052561058828066436, 0.019037396001118808, 0.11857724928807829, 0.031810542756331064, 0.01548382247077121, 0.05978243342871147, 0.051266531114496534, 0.03960015732915171, 0.08183132872105607, 0.03027036703462082, 0.028796848623202215, 0.025411059839590907, 0.04944911774908824, 0.052023399170608296, 0.01426408792124881, 0.04571589851571668, 0.008433377407791634, 0.00816183562781061, 0.0425286854677383, 0.06777906985653025, 0.026014819478375778, 0.022312333777306542, 0.09882996940324384, 0.0449494160561552, 0.09766838858805357, 0.03478839738114226, 0.07481685148612147, 0.03732062440605895, 0.033908947596266385, 0.07548845778670042, 0.015877617519318817, 0.021508814797045726, 0.037601242412722884, 0.005280278255081466, 0.049445884858047774, 0.04418166572107904, 0.05656793615930984, 0.029367785224871292, 0.03734998855619662, 0.08312817768103654, 0.013041927745836157, 0.02989998842108875, 0.03982473600415453, 0.02367133545058389, 0.0491023327284042, 0.04837531528826203, 0.0281182172963576, 0.005811836501027668, 0.01471972541748396, 0.04303105528496447, 0.029149155222600507, 0.06183567163985103, 0.025287518585701625, 0.026809509295309265, 0.038025134182985754, 0.03203334219212974, 0.022916135550927252, 0.06873451173305511, 0.057688979431986816, 0.05140443843218589, 0.044129276798377116, 0.027575250564804, 0.037838392590563145, 0.025561553981876182, 0.07843572826635453, 0.07299626651670664, 0.04005458153363678, 0.07208793904752502, 0.009800644212162063, 0.008084595770454936, 0.021500159918721166, 0.010567687831128077, 0.00733820875475724, 0.060598068089494785, 0.0851513852455443, 0.0880774427505751, 0.017984703093046145, 0.023489954558411436, 0.0017914651295042508, 0.011435036299630039, 0.0341335952191824, 0.025375379294517542, 0.060638280044640266, 0.06238339769263422, 0.018490539458129677, 0.029088764511529478, 0.0568274024783844, 0.058492475429609905, 0.056927518678768996, 0.008092334216100075, 0.0384576482728364, 0.06544240975692388, 0.04385633116227485, 0.01644435117111331, 0.02915669927343486, 0.023622681206512838, 0.019895904772584478, 0.017002474952248797, 0.03813821259104917, 0.0456596331881179, 0.02821277744407135, 0.047345896131329, 0.08055334084577138, 0.025720590004517187, 0.03418645145551812, 0.0873797205126574, 0.028357700211927298, 0.05374412457909315, 0.02781525633538202, 0.02312551695673216, 0.022666387057172197, 0.13070886443939903, 0.022973701312777497, 0.060910746875789866, 0.052631902808864275, 0.0656360614624235, 0.0971092669773967, 0.1856270570668482, 0.16534775976211796, 0.15446456149220467, 0.24168584736124163, 0.22969278687190628, 0.16552962903534213, 0.07944878761566455, 0.13086830265820026, 0.0911446059903791, 0.143410372397592, 0.06407665118815438, 0.030322928327105703, 0.015433758624919481, 0.06201906542804453, 0.1095549705167932, 0.22811585616680885, 0.18161945195207674, 0.3361812300018726, 0.1845659027176519, 0.08831116851539382, 0.22093152957818202, 0.035063016919359084, 0.03798515588465718, 0.06117705436002824, 0.14188285436361067, 0.18079973787309664, 0.10608364993165578, 0.023909466220967235, 0.10209220927208663, 0.00970635219522181, 0.07374147854505048, 0.09406782897009004, 0.05554830377560951, 0.0409393173251902, 0.05108617103448318, 0.04496378020473546, 0.0090723397443071, 0.051716071508464315, 0.02543770629281719, 0.022351781559747555, 0.014833512456877338, 0.07556723460795418, 0.02089161414562935, 0.03148471598603553, 0.028076413793549426, 0.05856902293500401, 0.0745932150992655, 0.07487105986764354, 0.033400801476091146, 0.023620844510714376, 0.042997512125199845, 0.026555957175010157, 0.09046589039386281, 0.06678670254205504, 0.23316230715042163, 0.03237426280975342, 0.012933096337702968, 0.036479034686401006, 0.07589650685868918, 0.08801220270294337, 0.036580300018672025, 0.07180035730162937, 0.014472925404627478, 0.04463181515494662, 0.012050743079594067, 0.07049885052706927, 0.021423053169142336, 0.12130385580202266, 0.03935407456611434, 0.05881277296031195, 0.026334281973240357, 0.08425272580596709, 0.02507745919208373, 0.014289181131208617, 0.04878879592363392, 0.03329160713380383, 0.00562114859818511, 0.041300592898962, 0.09258163371874441, 0.07968458947875807, 0.027240795729261254, 0.05896869483554076, 0.05833599431019637, 0.03571922485266001, 0.013518971653895514, 0.10664332312561813, 0.04738999981312983, 0.01828588098437796, 0.04708146939294473, 0.061871876955152526, 0.03557604685005161, 0.031118351673226685, 0.032118921874151114, 0.023501396081560565, 0.05795288523058257, 0.056949811837365555, 0.037480166046729976, 0.058587914663216764, 0.1109930171420978, 0.029809852431137717, 0.06061328642611062, 0.1140500833430598, 0.08608182967309991, 0.09146499162119243, 0.21295283109911028, 0.12854578454167614, 0.30202657885609135, 0.14502779851036687, 0.09547960644047107, 0.14929952009791328, 0.13583766987487195, 0.08900514458336177, 0.14673045956559722, 0.10420193114588339, 0.09856902453447543, 0.09941133820722181, 0.17133622310094296, 0.13398113239917064, 0.11668121231900108, 0.09368743567216782, 0.15760739123628986, 0.11769780333364203, 0.1501789737132288, 0.14825773245144278, 0.1495575997978449, 0.20959359683817436, 0.08910425337812594, 0.16008108914379152, 0.11860739484789873, 0.11600692471068715, 0.1764432869611248, 0.09699317401335125, 0.1760615913137313, 0.1309754783588071, 0.34398818689007915, 0.08467743729030894, 0.15838435760909514, 0.10015837352482543, 0.09373906233738508, 0.11265063222738043, 0.13597703659005705, 0.1891359236211546, 0.21434994564662058, 0.11005093583897238, 0.10546096600592138, 0.12942574377502167, 0.18857084184644685, 0.12216041871016065, 0.16474665653321052, 0.10812189580211717, 0.2047715483293418, 0.16771003784191224, 0.17632146365940574, 0.08474055527439041, 0.1378354433202936, 0.13876041788006985, 0.17187896575177872, 0.15361904557193481, 0.14669102135925524, 0.11733915161101088, 0.3098944856995537, 0.1134900424268938, 0.2090886682872811, 0.1772716578336493, 0.21539634514239528, 0.14788021964411582, 0.23809303289219258, 0.15103555194312526, 0.22264359819312252, 0.08478962320594058, 0.1517710269939515, 0.2163663809938777, 0.14920254868845786, 0.19472965249611487, 0.22780039648134864, 0.2715867799856971, 0.3123906759485122, 0.3133160182304921, 0.27279692311440745, 0.40316906126756824, 0.3951601636025214, 0.3168983066514615, 0.21256721308154447, 0.3392921904883077, 0.32740523317648523, 0.2460234065450007, 0.11318329316113265, 0.11867610527382744, 0.15346758998930454, 0.20349639497937697, 0.2841716433965391, 0.191960183362807, 0.3294925469784968, 0.696356088644074, 0.46426916975648175, 0.36288478742203406, 0.4719493237714614, 0.13026068768193647, 0.13078147425286232, 0.16878910332677827, 0.21205586471384574, 0.23817503494360756, 0.23684835451985561, 0.3030368649671155, 0.17822084077183278, 0.10574559065242929, 0.21485058410513788, 0.23933457030404, 0.19254970334229932, 0.1842387984957426, 0.2137974430356295, 0.1399686764324865, 0.22280358799522926, 0.170009542677191, 0.11941875856850417, 0.1180224713959521, 0.1401279614337029, 0.1934492131394725, 0.1504804905984671, 0.1585208744772019, 0.1501610778993176, 0.14520988228820986, 0.2170772952658515, 0.14269394229256338, 0.11882226718890092, 0.08009686735608885, 0.11684780579901512, 0.09925381520823126, 0.26140069108336206, 0.11069684755057098, 0.2546688773098492, 0.23729941176791347, 0.22934794005367065, 0.12947492661976046, 0.09104532099539235, 0.27080445099742184, 0.08673927866883817, 0.33373949328257196, 0.18962706258941084, 0.1356927260395981, 0.12697226292784178, 0.20398906612348175, 0.11585976688131211, 0.16659908777763768, 0.13067229140189388, 0.11955137604907637, 0.15795781517461424, 0.14713336052673479, 0.17611792941968288, 0.1090274117286167, 0.0964492132827159, 0.16772911343122685, 0.08830646473553874, 0.2713414479888255, 0.22349374128445504, 0.1428890035998437, 0.17774834838365355, 0.20282321819855323, 0.18260162263627977, 0.12249640189111234, 0.11938027797206757, 0.23718863545406252, 0.1020801433872792, 0.12542686440170775, 0.13152523837502927, 0.13305660217039048, 0.11507165392920857, 0.16339890869154086, 0.07838264603408114, 0.17997201051442854, 0.17124574811708543, 0.1120484181709828, 0.26869770920565056, 0.12014082708065549, 0.2079023351712573, 0.08070943126034352, 0.16795373041062586], [0.05831638628977442, 0.052985624755702676, 0.04347462402356248, 0.02755202086372001, 0.039353331460827784, 0.05954271302588525, 0.020676368336764075, 0.025024511025197087, 0.019891279516741633, 0.03018114268929968, 0.016450276861207622, 0.048141895958613005, 0.015101184535230842, 0.016599233081984906, 0.054725264875038024, 0.022019171080882513, 0.015779844590372617, 0.009729943872850028, 0.03548343831132497, 0.05406251455086374, 0.007043083436832193, 0.03583049529322213, 0.064630180356964, 0.05175145327924721, 0.01833095185218319, 0.0675647414379543, 0.04701457459539656, 0.027811669128676577, 0.034398588862630634, 0.025922777844713103, 0.07139698902685797, 0.04130731149005794, 0.017140926192364386, 0.05607338426935096, 0.051753345516420184, 0.06381165754470615, 0.034264661371707916, 0.03292851593165148, 0.018180605181823337, 0.07316930279616388, 0.06634764223089142, 0.06977294391441731, 0.018701443463684093, 0.04580965618632975, 0.053829079899456234, 0.010369126459643727, 0.03899263428343881, 0.011348570828446218, 0.01456261802119233, 0.06269371309768289, 0.060765871988429185, 0.10080829187626801, 0.06630993538325833, 0.027809594945621588, 0.024883298038114465, 0.045729270580434994, 0.023545178006433194, 0.04358240110318988, 0.021741529325804403, 0.12707537070157068, 0.10887730446073318, 0.056574781154913295, 0.021535045647573088, 0.04568568017754344, 0.01556730402948996, 0.06113096651050353, 0.04161290396305342, 0.005369692207163861, 0.07478952512986238, 0.07678097834990871, 0.04460277276173715, 0.07250572509703136, 0.035107423205890005, 0.1593137601570737, 0.19636397850849938, 0.25832772855797126, 0.1542175441018997, 0.1127335612451838, 0.14368044903441785, 0.1816169391836851, 0.16618379151388524, 0.10308127474760818, 0.1033513130800378, 0.09245537476794374, 0.1438827881769788, 0.029201176423098774, 0.003765487096144728, 0.026492145881357215, 0.032808944928429784, 0.02678734637165983, 0.1461422112920592, 0.11385286932871228, 0.3627697210158072, 0.12514487509765934, 0.2879456989467144, 0.15628045034264365, 0.03675205310085609, 0.05811192125322358, 0.07317324048809468, 0.11495898537818464, 0.06210011753043341, 0.18404709265357067, 0.08140703092419332, 0.058769079135550614, 0.07254941509135308, 0.07213847020701056, 0.017766722350291187, 0.10543699511477064, 0.04645954006381574, 0.040662771075843804, 0.04286242401107185, 0.021006703534494006, 0.010111992878298606, 0.0540713130706741, 0.056197636069790016, 0.07316636867941388, 0.022484358820703723, 0.04941313076884516, 0.01723850855693942, 0.04300266406649063, 0.008171523767223042, 0.04772573784594575, 0.03139390583871113, 0.02544546484827034, 0.015440149713427791, 0.01772414126823987, 0.01951031739853563, 0.05137266110508673, 0.043711674609972585, 0.05497749549366775, 0.05993800290349511, 0.08118147931752667, 0.020576480047536955, 0.03298547073838211, 0.06846075787419273, 0.052592315215377085, 0.016651064675721913, 0.022786297054300388, 0.027902779965511257, 0.062140314163820404, 0.05795843170715436, 0.05128470655050009, 0.04858945984573615, 0.028101888132251562, 0.03995083790693072, 0.12350330189351114, 0.011332737706271152, 0.08649952379205535, 0.0412745880443723, 0.04995084788289763, 0.01432607305281225, 0.046360959869719325, 0.0316853046176895, 0.08418583866929816, 0.0348566098499202, 0.032298182617993124, 0.02617313729358777, 0.03090836888840122, 0.025059775967571526, 0.0345558820352439, 0.031376931245528886, 0.023850123135132656, 0.015663486368383373, 0.007796249373049866, 0.009487555568827497, 0.10018333266939848, 0.026274431354155945, 0.04494406110156448, 0.03104016282445481, 0.07466561040811001, 0.01713591214689997, 0.04354876984331397, 0.029504338482154474, 0.055835563764576955, 0.03354387605682977, 0.058783240270830935, 0.03091411263261351, 0.035421729929024176, 0.02760267076683381, 0.041556263252371745, 0.06995947100222111, 0.10761100708717301, 0.020605836536795385, 0.065458252455198, 0.05127551349540872, 0.03116400285263456, 0.061478410366802454, 0.009441844059995586, 0.036965799292609576, 0.06511668449327832, 0.07476795209391464, 0.007734458157492261, 0.038985731831241044, 0.010772529208371717, 0.04889249741550415, 0.0157057284565282, 0.05424817212887349, 0.0892614546201883, 0.051964452535274534, 0.08272461788428408, 0.005884897348756392, 0.02257169858973113, 0.05086914215597415, 0.04077905556187034, 0.05824068148109702, 0.0018154955121703568, 0.10973130097432483, 0.01992849606810318, 0.07449229833700004, 0.05466282870920916, 0.0601716137551252, 0.10929243218514229, 0.05191557612570544, 0.02855830608055957, 0.002852246130538744, 0.02213033043869561, 0.024425849701548298, 0.037917740147320494, 0.032415302139857126, 0.01723243922535931, 0.013082677877748446, 0.0618395327229894, 0.030214879286265185, 0.02788296127091012, 0.04551364747326701, 0.03845968989715461, 0.007738244547058018, 0.02521902841005114, 0.05638310212581869, 0.06490319877141906, 0.0746742365581374, 0.03815483669900606, 0.005539700045295421, 0.03325902158394456, 0.08082845834113898, 0.11183964388985788, 0.09166595180548968, 0.039452639438452265, 0.030462781508122722, 0.09611003551511996, 0.05631220068842654, 0.0743599949524768, 0.0684146317202718, 0.04723525771330442, 0.03388015801207193, 0.1427572824421429, 0.20493480166600597, 0.1284187824855889, 0.12873611142558436, 0.1667823053656086, 0.11359264458259268, 0.23074045807363527, 0.23418074443696008, 0.33313315001226246, 0.20747574677150096, 0.22279868503251385, 0.26288524690654974, 0.13085895638552406, 0.18313109664426697, 0.10764499074749409, 0.13608876285293411, 0.014406653053517786, 0.05788766050470933, 0.06543004509782599, 0.01518657939854048, 0.09009184796483287, 0.12670331244026461, 0.13833292549656284, 0.414972729500263, 0.20323567993698582, 0.22905747015630046, 0.286678099223683, 0.0680312889838411, 0.013961171010328878, 0.024926070642146855, 0.29022119458644624, 0.13064625973422683, 0.14280310982177336, 0.03329491663363672, 0.016800804221401774, 0.029955265495265206, 0.10817133911675024, 0.10074784753904228, 0.049146030383605155, 0.02589816535492578, 0.08047418864143473, 0.017713341343727325, 0.04323846209914454, 0.03723975999521152, 0.06311817177300973, 0.027543138074237975, 0.014230356112332835, 0.08013486531713317, 0.025986931962712158, 0.03205692812409853, 0.02278291286089488, 0.060980598772725755, 0.010727975449915375, 0.055922399830794146, 0.041451673098509355, 0.03512502790638997, 0.0707064297110323, 0.018404115164171786, 0.05396779160946608, 0.11748411842892248, 0.07798612658535281, 0.07695819746943251, 0.027436531193914915, 0.047876005992293365, 0.08679657438469511, 0.04187793208045825, 0.059417817711589806, 0.03561029864114619, 0.04762871281033562, 0.05488407490174136, 0.05651095836994149, 0.046235972624872966, 0.05581208700013738, 0.018722187209453796, 0.003599999655571376, 0.018910976171854044, 0.05712585884236521, 0.02420059303873249, 0.01511587427117892, 0.015847903841565696, 0.006304132740854496, 0.05821375349055856, 0.051485563312927564, 0.02740690465866318, 0.06102303238285165, 0.08893167675142327, 0.0364808235017042, 0.03920892388710091, 0.03974740708907766, 0.053011495544905626, 0.037219569747967106, 0.03457921324297786, 0.008668218788150097, 0.03904738275694751, 0.033217507279327804, 0.03480966398192029, 0.011934305375982678, 0.01997861737054923, 0.03823455963884631, 0.05030038698966946, 0.03316734767248554, 0.03853667790310518, 0.03956247346415635, 0.05482824624425942, 0.031027390223537243, 0.0658102545346464, 0.004624383939024542, 0.09706952233588505, 0.09967271974610706, 0.16987403704514428, 0.06218542908168128, 0.19349068913969303, 0.1756990785079618, 0.06971004043495463, 0.17233055926138358, 0.11557207022222782, 0.09192377869640628, 0.24545959647624727, 0.11968193275313224, 0.07309693813083634, 0.2556473860937742, 0.16144172258434758, 0.05384108066679009, 0.07129792619736926, 0.13768692951529257, 0.23569626553404718, 0.15359335098295443, 0.14200467766532976, 0.13282047855036874, 0.19983786548818314, 0.21111676349274575, 0.18021125977318134, 0.1125796618420751, 0.13277947752466127, 0.09042160285096015, 0.16267684017938955, 0.12070986186905254, 0.12137399115149053, 0.09516143480375891, 0.16433736639878443, 0.17023095740906655, 0.17157225479041377, 0.199141169808084, 0.13872530040962083, 0.18061647431985026, 0.13471256250575667, 0.13263830284197486, 0.16787902151625003, 0.2053092194781188, 0.17767566196139783, 0.21815937913713918, 0.08222905092782552, 0.16110593092537698, 0.163423775905563, 0.12526072291356902, 0.16062683485929044, 0.18683142389260954, 0.09284401883281047, 0.1573036833395881, 0.15590376491027494, 0.1681082963102287, 0.13992752218919416, 0.12361401692032815, 0.0685460847471991, 0.16177873998399706, 0.1946803470773082, 0.21145183502906756, 0.20661472523164368, 0.1983769971036142, 0.1058875697274362, 0.29423610818001533, 0.07589977039324661, 0.1868692533143105, 0.10606602224851809, 0.1436544020449923, 0.30999873494428976, 0.22851610646372844, 0.22110081968768952, 0.2159446649133198, 0.2358435842418863, 0.348289770584914, 0.2142340825089524, 0.3010251793649889, 0.26123990454981405, 0.40485460791857014, 0.20662686006436426, 0.37685225567510056, 0.3855607141890834, 0.2238886902529386, 0.23384706718066048, 0.20426928576442505, 0.23990104635876996, 0.11852129422608884, 0.2058344800025225, 0.26290513454906406, 0.10165177000265929, 0.11991452470782304, 0.26571968029583654, 0.2189563863700436, 0.580437547497211, 0.38293536151609114, 0.42300837895562576, 0.4474757563683295, 0.3796738494307764, 0.12407484178942059, 0.14615843703429546, 0.5347206683889513, 0.3541862880510669, 0.2949009805677399, 0.2493011137290347, 0.11742392690071177, 0.19479037262499335, 0.22019272970576442, 0.2928254032327283, 0.1698656100779772, 0.1938834930619886, 0.16483186083214899, 0.18742820638562405, 0.21205741221145277, 0.14167378896907454, 0.2212013457451136, 0.11824118183745493, 0.18073063674232653, 0.14934239037815603, 0.054656707666694164, 0.16684760670027426, 0.21029012397893015, 0.12766567209074575, 0.20514743703026928, 0.17687030437011875, 0.08187115763223941, 0.11501649559866037, 0.20364155331926964, 0.1329360352528672, 0.10129324851497527, 0.1841410303548459, 0.18889076016362638, 0.20263836118242434, 0.18128010564513747, 0.13514509574780542, 0.19602552086355227, 0.15972472036317473, 0.17283793929363453, 0.08059582808205197, 0.16055315252273314, 0.19037566838725922, 0.16480933784717516, 0.09480378665630856, 0.19699008684725533, 0.10310032735428504, 0.13098339970794418, 0.12357765072656256, 0.22575468125362552, 0.14667899377884405, 0.18845298688017553, 0.12980978365146345, 0.12949784797045494, 0.1413433446038154, 0.21540895494962894, 0.07102421064290308, 0.257394265743994, 0.16837075803308718, 0.14299742036288784, 0.15052990326958318, 0.17337395569249509, 0.17625040134354947, 0.10051468101840827, 0.18994667447142063, 0.18727474365263216, 0.07243338341434157, 0.12426933619163691, 0.1090609893623379, 0.175883062183857, 0.10125986240323513, 0.17681741365982642, 0.1312366836974698, 0.16814782644712156, 0.09205198351053462, 0.15917977137911707, 0.20175199745403183, 0.173607750405227, 0.20649354544378098, 0.15026321274138268], [0.022532540005481532, 0.010718790055703252, 0.04072750933588513, 0.03699182712983701, 0.03333972128588827, 0.03547698785100253, 0.02500908776006151, 0.03171846856393161, 0.040033337915496486, 0.047034462237910885, 0.024325607096656196, 0.020895735698661978, 0.013853744415926838, 0.010679961846871002, 0.029248264017364675, 0.004542705559757569, 0.03406653188229088, 0.05487633741370613, 0.09060295118439583, 0.009599909066192566, 0.030155419372022155, 0.028235380868277246, 0.056966416793124336, 0.03198515717691231, 0.015719396422707265, 0.06644442211836576, 0.014879548595467163, 0.015015398009469914, 0.03441519381838941, 0.025419067373619448, 0.019723818442153356, 0.0827931674317487, 0.04607808190367876, 0.03910715293679987, 0.05854385311625177, 0.027955243581785794, 0.051124517565533045, 0.03253056389850474, 0.062042381314020005, 0.03227530340213449, 0.048686615116293394, 0.08366456946298, 0.01678382771299972, 0.0788795919488034, 0.07380807456830818, 0.04381342640807552, 0.020635729287600806, 0.01783708369569673, 0.06276012142939914, 0.0387161378298075, 0.05912797983675715, 0.03749870154405794, 0.012134307950374582, 0.03602416232048023, 0.02640327776692087, 0.07519323048332045, 0.014738335608384542, 0.03671685519117502, 0.027845723652130658, 0.10854967163815614, 0.08533353797130047, 0.017952751480944214, 0.05538235380945187, 0.19464213461164506, 0.06595106149512915, 0.07970934944047083, 0.042270552141652, 0.050060118833977374, 0.06845960108142707, 0.09404688412624021, 0.12471183623758056, 0.1664893226998468, 0.18999866119796233, 0.5927385906538656, 0.7390759705055145, 0.8589754722291424, 0.5029239133000374, 0.23844411566613183, 0.13157616790023544, 0.11476870445955185, 0.11598647016310885, 0.03906573056273403, 0.0837504938845673, 0.01700122431371241, 0.0762114302826024, 0.3072620543741411, 0.2533879016916598, 0.6310872361063957, 0.31557058434813257, 0.34642774791967484, 0.09069017029457516, 0.08479138520816643, 0.9586436950391339, 0.588775280742876, 0.7893169358853371, 0.7291283494522496, 0.3000043212406097, 0.18167243459291998, 0.10088749004588013, 0.2301697225700463, 0.052108182121188416, 0.2151147312214298, 0.08968944496084606, 0.12132538287269494, 0.041708569192597945, 0.189172787772071, 0.14238971345607312, 0.04896958118244525, 0.043949292101446664, 0.06055571874904056, 0.035603832859065265, 0.03861612122085306, 0.01316718407906592, 0.01410697477929775, 0.03938057737785482, 0.022099445604028243, 0.00990574189927429, 0.04449166703007875, 0.037799165058400364, 0.021118753469519077, 0.12946153540284405, 0.050958521634099946, 0.08311330025354702, 0.02911373897786102, 0.04455357842567948, 0.02323100726390558, 0.01913753135370151, 0.025760321239490184, 0.03100631514474029, 0.011741107577578196, 0.011468413792881034, 0.02690384344708535, 0.0882376777008176, 0.13635317043912026, 0.022393690399645318, 0.06325408726209594, 0.025204894087848165, 0.06398520327263302, 0.032149144042763984, 0.03879164345562458, 0.0192293967871416, 0.13292261339243383, 0.021824190212834268, 0.07859104493212316, 0.044246894277391896, 0.015597907326845153, 0.055051580026385286, 0.041340046427062446, 0.05300897894607437, 0.016694044123493856, 0.026562150995877963, 0.016039114599416576, 0.01944714387307965, 0.027169817683076667, 0.030600171716463183, 0.030191879411558473, 0.028398858285659266, 0.031337134893082326, 0.029817708662801215, 0.018816720544090195, 0.05275893550846846, 0.008918478645594611, 0.024194761194408904, 0.035920981768398516, 0.032002041754763455, 0.04008173168967328, 0.03557913801482609, 0.05310568222475629, 0.09869021198321735, 0.0055262714815926895, 0.010461834589800528, 0.0495885495817469, 0.05217079831767948, 0.015147712885312017, 0.020000293828366746, 0.050924223877729914, 0.08040510283242311, 0.04026085836812854, 0.02146160845915156, 0.04369679718248306, 0.05821779077391952, 0.01431551731882557, 0.05665217901790335, 0.045725941928404, 0.052502108362293055, 0.020964478683327476, 0.03959808506131653, 0.006562618946190924, 0.018141728134885914, 0.06305108545348048, 0.026369286445720543, 0.03361603770885737, 0.012752641454308987, 0.025256516922625805, 0.05557163498334347, 0.0748523136961364, 0.019140193509238384, 0.009259939355204904, 0.052472499064019615, 0.05188141243472215, 0.05118604591717163, 0.08225090741630524, 0.010825460138280067, 0.014800940313556743, 0.035776804021048936, 0.04892119123870808, 0.05376804950496843, 0.033210432457347075, 0.04905488124237426, 0.057674588470329205, 0.017144421468518915, 0.026830025129921498, 0.051317740261795065, 0.015120035086217669, 0.05623719685019986, 0.02557214514742936, 0.03212976776393912, 0.02666267896852186, 0.0651759413942214, 0.015612068462125478, 0.050030383131196426, 0.036126618919473504, 0.04612683573917997, 0.017392492229719798, 0.05218939510204139, 0.038680453454294515, 0.02304614258689746, 0.03042999294496352, 0.1119591995713211, 0.06057634949684144, 0.042406674474477775, 0.10529604259758227, 0.007010007111896431, 0.04728431798397534, 0.028838338029961434, 0.12570102428716998, 0.09973578410403383, 0.02267895856000964, 0.07778308264190152, 0.24958133336997804, 0.03413376758896536, 0.10011037811636926, 0.02333392734609304, 0.020628016697423115, 0.04863782680683559, 0.11167501925580925, 0.14959788070090357, 0.13766388559053022, 0.023042743071733464, 0.39809262560259917, 0.19358703235705055, 0.643312038192826, 0.6321779614494694, 0.3672521014607722, 0.12406842197261511, 0.22862161209266033, 0.18088014646162912, 0.06941607717664973, 0.07114290064501186, 0.08976187091320754, 0.05310711097873507, 0.18964420763715623, 0.6729901005183497, 0.6228715866323441, 0.18103367048165492, 0.35339182423007104, 0.19403147060544262, 0.1428296777509874, 1.0885905931072852, 0.6234216377619775, 0.7507783619146194, 0.6318042331164884, 0.32466132073633136, 0.13919483569841232, 0.05348391515473205, 0.19599228796939697, 0.23521407447274656, 0.22414528374229709, 0.04351842893107284, 0.029397836938921004, 0.02405408063843366, 0.1230596220721641, 0.08683440380639608, 0.09749490031672102, 0.03510243597350294, 0.13232339473982013, 0.05679461008478558, 0.03602496288236111, 0.0596785442452998, 0.0141029748427231, 0.0660688015482118, 0.043147002692304315, 0.017618085971222292, 0.03946197038937, 0.043525170504806504, 0.09977421107431574, 0.08228040946226928, 0.06573755279063218, 0.03634683855418717, 0.0494614057993937, 0.06271593347792664, 0.04272530959438413, 0.021355097339819037, 0.03999948832056215, 0.01790805216578226, 0.03320367556185492, 0.05387476172238108, 0.05793133900771218, 0.03388062532570574, 0.051090713935874166, 0.10541097876886207, 0.04018132311982974, 0.029073898575358817, 0.03220095456908307, 0.022380454315533562, 0.025922099856900114, 0.09440162880045753, 0.01818261041696514, 0.03263114358208353, 0.00892218651114813, 0.018926954850734725, 0.030552040327400453, 0.06052050168716139, 0.035350012607992656, 0.023559766235731305, 0.06589526731160379, 0.020763792375463153, 0.023383340017209132, 0.045596940382834406, 0.07325762507295416, 0.061254777810386116, 0.021319962632391724, 0.047219847854707515, 0.01457051064203223, 0.028004229158884095, 0.0457881176243386, 0.03569326979378539, 0.019055517810967662, 0.051557502799457124, 0.027204801088138938, 0.03227921811142757, 0.10086060035973789, 0.04087861634850983, 0.05232929041789425, 0.07242443550738596, 0.036551874326241594, 0.01866847103942306, 0.038118171730949994, 0.04168541418508657, 0.03552703637509577, 0.10473371873940192, 0.06386932481320635, 0.1143821518147184, 0.10037167538558284, 0.07371880234249177, 0.10327490347047007, 0.21226998628868213, 0.10421636424237683, 0.1503934017232349, 0.1757964942484133, 0.17684943613506135, 0.22462203557933533, 0.07254380732774734, 0.06202579168001972, 0.07627932099445213, 0.24278631734271205, 0.2327556217149381, 0.16065027714977342, 0.09518992561366289, 0.10257125171201845, 0.2435501070032197, 0.14143711376574733, 0.13244857350664754, 0.07255974195657239, 0.143141552144962, 0.16194628341303718, 0.11662348759390655, 0.1950961949243661, 0.08648718977647443, 0.08951916659791624, 0.203585812761899, 0.09475494855113568, 0.1510775948484098, 0.1672518406544001, 0.14472335516925783, 0.10721104790366466, 0.1360937883897174, 0.12186940489036423, 0.14847286526233922, 0.1932998106724793, 0.14042305850213574, 0.12967988578302245, 0.08053810335695744, 0.15410833060741425, 0.12446019933709215, 0.24353297727723278, 0.21497749423067417, 0.0860180222098866, 0.13449324685479366, 0.11162635735085896, 0.20119969402590107, 0.16773390914163283, 0.21232669211683736, 0.16334655424279554, 0.19582419295705136, 0.16482176379330699, 0.08823736360476864, 0.18738196531851448, 0.18582188854775122, 0.29240380972623825, 0.16087230475198838, 0.2506873038627448, 0.15354476568679656, 0.14666771696459863, 0.30006471961256, 0.3266312392248262, 0.16486682508501316, 0.2242493184824144, 0.11272940138775496, 0.09601155491245371, 0.3101053743833496, 0.3475205570219025, 0.25661205932978665, 0.23143070329341198, 0.31473407762185224, 0.6300185128085075, 0.7842758934824698, 1.0419719978686304, 0.6218675211552651, 0.30481964349746704, 0.1346619700592372, 0.3732027353778962, 0.1854673583781527, 0.10280133855919685, 0.17756854754782495, 0.22610959446718618, 0.23786809415586535, 1.2759285083701535, 1.7379062478580785, 1.4928434236395745, 1.0368769615888596, 1.4981826274625718, 0.6904130849626757, 0.13960522899944938, 1.059214369423928, 0.9030320855879015, 0.8834576811040602, 0.9941681113935287, 0.484929703055851, 0.30164659924564824, 0.15647094576589524, 0.26335807637341563, 0.2834708261634073, 0.395251082917375, 0.21963673373383863, 0.16964791853341366, 0.1578534127122933, 0.23242123965774816, 0.37142764837030445, 0.22578544734466463, 0.2122337043645882, 0.18399435516086318, 0.13438381885568942, 0.1909910974603507, 0.1842632826658026, 0.08123626992587121, 0.1251363485390621, 0.10177530168044953, 0.09780917256589859, 0.11839727225202708, 0.1994113996624947, 0.16623357190720497, 0.2537120181706644, 0.13771570377772854, 0.13290939071486074, 0.08779546110740594, 0.22594618791293716, 0.07165384298611073, 0.10931050419927606, 0.1231415551756659, 0.11527420757638833, 0.17995625974670534, 0.09616965247738747, 0.10446820798660479, 0.1259797577175402, 0.317720839934003, 0.17382076881345243, 0.11391598731279375, 0.0909688730814284, 0.10577745224920013, 0.15926422491188974, 0.10930661247262072, 0.2500249442434119, 0.12067687412303303, 0.08695982006048003, 0.11560278268711222, 0.14256628140086128, 0.1177032195752667, 0.11930256601302855, 0.10235396619405478, 0.19871589907955742, 0.16956272955623367, 0.12782286567192885, 0.10304617259891764, 0.16782760169477234, 0.1887940492240652, 0.12161827360790585, 0.12218736968333684, 0.08576309113132377, 0.08507800168327748, 0.11703671542026343, 0.07155216779680022, 0.15629624707564232, 0.10086318973692195, 0.15852202360908832, 0.14925173153319668, 0.1454599487084535, 0.20036487269305414, 0.10876437543981499, 0.1452692541023416, 0.1884313065919184, 0.1574729887708541, 0.13415210790211154, 0.05312017660828368, 0.08210708206940083, 0.1046628785890437, 0.15823590509112806, 0.2601789953487535], [0.010307329019621737, 0.01286764465828216, 0.022919893212195848, 0.04576629944025509, 0.029339242704032414, 0.08571662789871616, 0.036962340405631455, 0.03806128204169293, 0.010863347974185263, 0.039517913960040583, 0.07472442297805702, 0.020662050153459274, 0.0350439413300445, 0.027796096476395766, 0.07353818945346341, 0.01647690033179618, 0.06205072401151542, 0.012845120715698408, 0.02606899147072146, 0.036293400091028986, 0.13397045313350617, 0.06700795639546649, 0.06369101784883008, 0.04388718535342524, 0.010428197584265183, 0.035628114015825336, 0.04109554946602833, 0.022753843654608055, 0.02358663293923582, 0.011824039468211273, 0.037631698238152655, 0.02100931397909599, 0.04850738501596836, 0.13192156630177654, 0.01646308393608178, 0.012407176020074517, 0.03599529995793297, 0.11010290724375557, 0.020727133153066523, 0.027933705019794648, 0.031225010264484637, 0.02128544845618308, 0.02526857323133417, 0.10750001626870326, 0.04411251862503348, 0.0226259222930117, 0.018980422042190068, 0.006814493812740811, 0.03582937680485268, 0.03489883278586692, 0.020607418508359024, 0.01358651188051989, 0.023977674859305544, 0.008852822037654058, 0.06271226008632971, 0.032154173409986886, 0.03956675589565308, 0.040468154099559596, 0.05279800599260677, 0.14418081170128239, 0.02538473897373244, 0.03545419290481556, 0.05758764898224224, 0.1873440286445041, 0.06458763183364946, 0.02027879360192005, 0.026166037573749502, 0.1589243116998865, 0.2929750048825818, 0.2455971092586556, 0.030521065477401983, 1.45845600433888, 7.24879454220495, 16.210899006935858, 18.722886846911525, 21.903279904396307, 40.09753127251902, 55.380909365992395, 72.55471691008538, 81.91836372498544, 68.5019043953188, 67.37630967170962, 73.50051018499559, 80.28883857111778, 88.30309590985699, 94.83275967259561, 96.06806308992448, 95.7413374993109, 102.11611470868512, 101.59425120199882, 95.84779062578755, 64.37340582570722, 44.0261576252599, 41.60151704665154, 30.855179832827663, 26.375380062287856, 6.524870136091787, 3.463687468920985, 1.0257007193661507, 0.238976837886918, 0.32361993145558143, 0.4896997954816588, 0.4157731688070682, 0.025865721531332504, 0.08224872406572104, 0.20124817206974954, 0.0597374985415128, 0.16951014528111105, 0.06641750178870655, 0.09547062022911926, 0.025291015777075966, 0.07403450717608775, 0.04303382852325036, 0.011991313808868009, 0.06613825507942708, 0.024240877772230777, 0.03553172483319237, 0.018273577612314015, 0.06524753997162466, 0.03253739357234971, 0.03828326367863244, 0.09854182841316347, 0.052439886701082995, 0.032312596562288465, 0.07760493655598934, 0.02726332254467472, 0.03436610673464114, 0.01895496111002661, 0.04923497702205374, 0.026696402158948685, 0.04598734261948736, 0.029436576090032057, 0.03640110056186396, 0.027469112913334565, 0.002624786725538152, 0.0209689928564213, 0.047197420630724206, 0.049804291432543155, 0.025475577849353996, 0.03163128584292868, 0.040226981960116856, 0.017163066133376093, 0.007519990885480037, 0.04154183781675754, 0.028573263947281147, 0.03318240513063727, 0.06226684507583419, 0.03370055252866399, 0.006299898189853036, 0.04332013473275208, 0.03735526307155529, 0.09622679497565954, 0.043776838048811884, 0.015978886682029455, 0.027732030458508, 0.023916305470911246, 0.017830188904378205, 0.03714135983177731, 0.011407061641465032, 0.05339670370543196, 0.04048610737006511, 0.05927016958594323, 0.04614486944891753, 0.09200966481359736, 0.03051816391938877, 0.004431032444230251, 0.041970115440386924, 0.07553864420662004, 0.0560551169027965, 0.03970822552219033, 0.09005522896205226, 0.04252128122795013, 0.05287301366127307, 0.0442451935622, 0.0767686979604825, 0.013872073069515248, 0.06878025484301391, 0.05962367702816283, 0.019291323504500815, 0.03268642448669961, 0.03994485092980247, 0.0714056917856778, 0.07027983365039672, 0.02481387323519636, 0.06319651192414664, 0.04122145218594421, 0.02860768236249926, 0.0442933383578014, 0.04949528220740538, 0.032408131556885864, 0.07996903792504342, 0.054505531706156275, 0.03577396949572909, 0.041264985132241444, 0.012748921139826699, 0.03643617972791676, 0.018957636672102155, 0.04758163287694897, 0.029942680585889087, 0.022621141904364192, 0.04866905255062927, 0.05058727542599363, 0.048059721537415064, 0.02956813062360931, 0.10617517445596958, 0.025491060486303705, 0.018341154228114796, 0.04848162530951443, 0.07256340385685045, 0.011078342889255334, 0.046422553338831475, 0.050246373960568066, 0.11709102339321568, 0.05391173695604648, 0.04934811288671148, 0.035421017467254595, 0.03192885354491732, 0.08854795097103042, 0.0255234889881385, 0.0903000706626523, 0.03925694227819482, 0.006461945416841416, 0.0382194523849795, 0.016226176991157474, 0.03403985287032781, 0.05173103320562551, 0.028720379641820348, 0.11760559699107563, 0.04959477404613168, 0.07427335806911992, 0.06631744304491628, 0.07011016815780632, 0.012439011761377896, 0.029498579416183696, 0.1278451741522839, 0.14202831913867306, 0.03536305525490353, 0.09517375349758134, 0.05458996991717047, 0.13170287884291143, 0.07883528142326302, 0.05663830899603425, 0.05709516169923929, 0.1245685241695854, 0.14210655203750058, 0.5183187872171402, 0.012500424242217936, 0.6394650510722591, 5.184164297196173, 16.059131718450978, 17.382771815023116, 23.231516038217855, 43.89553485378143, 60.812587968764774, 84.39465799639302, 93.56706573117165, 78.12391773346933, 78.10034428873371, 84.79686567860266, 90.52988821460356, 101.7284119513727, 112.10172391706898, 112.97400413020965, 111.89771359966649, 116.69316414863833, 117.63614900650518, 112.12419125341602, 71.53311990922498, 49.03502825767764, 47.231255731275006, 33.93111428906841, 28.68707991415455, 7.6193786051965535, 2.7993644581687067, 0.8878018899310021, 0.17463636133939991, 0.389768865800673, 0.4779902947766166, 0.3292525469535782, 0.019340851088805545, 0.06358640471232996, 0.24015362554740524, 0.25857091550865485, 0.25274777394388953, 0.03251479397858343, 0.07459229579375637, 0.04819448406417524, 0.08658239918370401, 0.036690375362072265, 0.0409603119647551, 0.04434448621806599, 0.015707890739694478, 0.018637697287504713, 0.031224364835408427, 0.054055068176239736, 0.04241081901014813, 0.057754158192584594, 0.012267537343676293, 0.06780681756114768, 0.015724438238858936, 0.07851062868271144, 0.06862849282521395, 0.020213300745273312, 0.08632711570469603, 0.0614114657735392, 0.011049817605394752, 0.011654081904599744, 0.030154894601794022, 0.03308978127015214, 0.020612292742777257, 0.0612501927741593, 0.09117171018114013, 0.020089355380003972, 0.07405758174436708, 0.023660742369810903, 0.024159178325545885, 0.021450471455952334, 0.05694813410481138, 0.0266520016180772, 0.04816268758487798, 0.10862215121667232, 0.03886319606775238, 0.018062030092903206, 0.024180764768032298, 0.019751217576765248, 0.017753488181399244, 0.028127124983697172, 0.010850266065268267, 0.011574156909069468, 0.014187400604808524, 0.014999639580867466, 0.01205390414989163, 0.00848269431791719, 0.03578046209088737, 0.039511000016523946, 0.0957886616308843, 0.042971840518857204, 0.012166453957287295, 0.006696772911856252, 0.021481886806507266, 0.06018071487966565, 0.023510491460441582, 0.06086677342893616, 0.02534757413330578, 0.02430509892292321, 0.10226037323234544, 0.19429822242067707, 0.019392604158530315, 0.03176014566223227, 0.0390347806105931, 0.034922443615693244, 0.049505203046024814, 0.18854802774806179, 0.11003988885110426, 0.10088168309941407, 0.21215962366231028, 0.1609863292786383, 0.19016151616890586, 0.15081890227813877, 0.13663715923265105, 0.09531312021276644, 0.13023643333825374, 0.11743940953766147, 0.13249066237720752, 0.13622318064012837, 0.11160759585759333, 0.18558493755277128, 0.17669367513829665, 0.20630833602720694, 0.08673936293850984, 0.16395289751310504, 0.13843473858169972, 0.2396753874997939, 0.1359730222893338, 0.15962853036340208, 0.13228365009830845, 0.14652140949281955, 0.10914421715443173, 0.13512940626711617, 0.12186186658518931, 0.1500122116938714, 0.09435331163507316, 0.1368734667137746, 0.13293687794958392, 0.15507410701003768, 0.25599681411779696, 0.14970453546172188, 0.15421202826884486, 0.29035584220001776, 0.1968399949011303, 0.14352093420682416, 0.09886111853824509, 0.1716084447839568, 0.19039154172905032, 0.12408574322058309, 0.13390392605816165, 0.116167044747741, 0.14820842703263606, 0.09903166503194841, 0.1178285362379205, 0.14913749250192798, 0.17731756182207217, 0.21683148829446686, 0.187672067493681, 0.12466119016490637, 0.19312302822307234, 0.16243489429114327, 0.11202284615607032, 0.11358476919873108, 0.17800072838942851, 0.18785882440786209, 0.23216441634201238, 0.11871074010888416, 0.12647864949559012, 0.22878967646148898, 0.28239640317136244, 0.17810627998363587, 0.12848812110361554, 0.1191581967436979, 0.4956148829190962, 0.4943177734892215, 0.592140858211825, 0.12657480119096656, 2.950986864105348, 12.51719222914788, 24.72544877759872, 28.262683383880127, 38.041044358284246, 59.386571068917554, 80.82175531694966, 109.61268194260137, 118.5708341290874, 100.74545814144997, 99.64025974273683, 106.84702657884168, 120.29339005870204, 128.41959968689952, 137.6113211724066, 144.80152776164394, 137.99894548231558, 145.9115114519673, 146.19864463806152, 137.68537552125994, 94.53747580128332, 68.68478098223287, 65.8696174621582, 48.60863131861533, 38.9334463304089, 11.504210714370975, 6.075440058785101, 2.9210797721339814, 0.25094472472706153, 0.3920829109847546, 0.910380217096498, 0.7302929869582577, 0.08346774615347387, 0.19619684876693835, 0.4091833417694415, 0.28907543348689235, 0.3601618351474885, 0.17641025324982984, 0.31817712190170444, 0.13520809881869825, 0.3488890352028032, 0.16993132510012196, 0.09950156038206431, 0.13476206710742367, 0.14911067942457815, 0.11397505269175577, 0.22437193851557471, 0.1610906551321668, 0.20029613928448772, 0.11277986359932732, 0.1649969834233484, 0.12890601440543129, 0.09857545967303938, 0.20412014376732612, 0.22508122868114905, 0.16137775424267017, 0.28499638301230246, 0.14300347245748968, 0.1373861480744616, 0.08927598730811188, 0.14868465792988578, 0.16098314235287328, 0.11890457567548561, 0.10129622093612149, 0.19083677670888363, 0.15695761078067366, 0.1937352856921573, 0.10771710260380661, 0.13119459482690982, 0.14257780336324247, 0.2923245655913507, 0.11056649002937541, 0.2090843781949051, 0.18008206670563068, 0.06123302091333655, 0.15523903041837678, 0.10566564937753063, 0.08426265430546577, 0.12213440236425209, 0.11223216435962147, 0.15562886191952616, 0.08614003703358673, 0.10028242614240417, 0.16166175835795943, 0.12134880984141944, 0.06548714929170187, 0.123052803889638, 0.15236243154973755, 0.15767500615648686, 0.2229753755513699, 0.09926051847756871, 0.10964357624611548, 0.13117464589736155, 0.15294789126323116, 0.0826020974425539, 0.11313638559752896, 0.20493932158475925, 0.12410075088301975, 0.13206471749130758, 0.295414075615906, 0.11752914907711169, 0.11221175577731864, 0.15511483224409242, 0.1759019845555867, 0.10204953051382497], [0.07626598340369041, 0.034068178971328085, 0.07226823784050442, 0.050166233502809084, 0.042001977037157745, 0.08620752937971585, 0.022378359065060655, 0.05270705220379657, 0.06703181237342858, 0.03476075692883423, 0.010609715414654103, 0.0321959481844979, 0.0690156736621453, 0.05858774995431305, 0.08678555804034395, 0.025339551277518756, 0.09348855158614536, 0.049995461013168103, 0.041511002777805256, 0.0330813811160624, 0.033299436552389976, 0.05416213662453717, 0.11932932546422367, 0.016888027162020727, 0.029510538048681714, 0.05058242608943293, 0.059121548528632814, 0.033975241014793996, 0.048688763992921005, 0.031120264977817575, 0.04502412878097065, 0.08698042782564318, 0.025789275532588366, 0.0075983161936634255, 0.050392129849041664, 0.04778369239741757, 0.029047156361141996, 0.03720135983800696, 0.027599882206789432, 0.05942803349406008, 0.03077786581050004, 0.06351828417410293, 0.040068474538143606, 0.01559445610074627, 0.0191241784411813, 0.05946067267007405, 0.09958295722401912, 0.04238423192873598, 0.050846894962653044, 0.007776107485105674, 0.06627906203990983, 0.038439698832770514, 0.012954264304660743, 0.049666820784970644, 0.039325108781697295, 0.031459833450254895, 0.04971018902236416, 0.004831031368549673, 0.07087607222098498, 0.16569240739749325, 0.07063447873318388, 0.2672265752428963, 0.33673220043701513, 0.6963494083573741, 0.04656519507989288, 0.0532696939884655, 0.20084772258996966, 0.8456794953634663, 5.028802156448364, 23.40822469803595, 63.319100179979884, 83.43298696702527, 107.18944165014453, 116.48273683363392, 113.71445348185878, 118.00625601122458, 119.84001897996473, 122.76070210241504, 112.81602674914946, 124.45282828423285, 124.04491747579269, 120.56298240538567, 126.52427119593467, 119.54916738694715, 114.01245947807067, 117.0589408566875, 118.49746227264406, 118.7066658081547, 118.36384281035393, 119.04066347306775, 126.98918188771896, 134.36562261273784, 128.96218115283597, 140.5939228303971, 137.60335091621647, 131.4742866639168, 124.15560676205544, 121.98800302320912, 98.01462558008011, 79.20394236041655, 55.68737983703614, 15.694752354775707, 7.9853215236817645, 0.6098023717922549, 0.010839123316409608, 0.4227601358246419, 0.6109078060234747, 0.6269029251510098, 0.01606406991355001, 0.07637797779734097, 0.020242873654370348, 0.015847188506966398, 0.16566899575052724, 0.016502487668467146, 0.04753772837800845, 0.02540814870547864, 0.0049519052000475995, 0.016667729003294822, 0.002195432508972684, 0.01940414910354922, 0.051094379666591846, 0.04185151736882906, 0.06168373342182848, 0.07780548305280748, 0.015427558100782337, 0.07396681564709834, 0.08033987810654987, 0.04293030323160272, 0.08207135172861238, 0.03019643954992775, 0.029980169098463752, 0.042828953629660035, 0.007004262410074233, 0.04513940969181638, 0.0520405097443971, 0.029788239175573956, 0.06374331484098109, 0.010998168915149667, 0.05523823734913623, 0.06051337323902596, 0.03562717555811809, 0.023830509369051265, 0.060033618337324554, 0.10672441353240322, 0.07080438937391005, 0.0362636031012141, 0.05849953109939253, 0.04085097972664141, 0.0222806656177366, 0.016503832152774258, 0.043909332955316197, 0.022595070017081116, 0.020923050563602198, 0.02307263582253889, 0.04864343840088095, 0.053027870674287124, 0.026781598797007918, 0.035538991177154165, 0.023777247106115666, 0.01093385583390632, 0.019277101082186547, 0.07073134289032991, 0.025300000073207964, 0.059492269966511004, 0.06792713933053517, 0.0476347763962563, 0.10869460015167152, 0.04217602455267503, 0.042085392520793026, 0.0864452311408616, 0.043183342072992556, 0.015496035827504051, 0.034317387373096524, 0.0928055612190116, 0.033377868634077816, 0.036534231321345416, 0.00895431240825283, 0.03411542361361846, 0.05333825502724898, 0.028829918723673593, 0.0727645785457665, 0.0435734378744758, 0.06223526310115572, 0.05926690222094617, 0.022197897478397337, 0.024605378576163805, 0.06600344658739145, 0.056658445617123965, 0.10132196149037731, 0.04536770006281234, 0.03916714528215028, 0.01470705432321636, 0.039669358051351966, 0.05746029069527023, 0.03667682326669174, 0.0730469968590525, 0.03658419174532737, 0.007802063980395155, 0.03343926675076927, 0.017227155133901585, 0.030770367724941145, 0.028652952413164803, 0.017771307386518005, 0.03716484808753576, 0.02697840678475557, 0.06465346942986212, 0.09418476463085222, 0.05788579891105333, 0.0583033551341824, 0.04538206804183222, 0.07043423101065621, 0.059851427307172175, 0.05006286525918592, 0.07743199986796226, 0.003040633614986174, 0.07556973971546659, 0.03446681282272743, 0.04838954920189516, 0.04193648035007139, 0.05791452720821385, 0.07084077088943413, 0.04768473682023826, 0.054495802389517914, 0.07195074036116562, 0.0883881067256293, 0.02538116517356567, 0.0054582897968019455, 0.04134148284192047, 0.025667894646645557, 0.025897133051447814, 0.009283663183000059, 0.02069653560137076, 0.04897596652529413, 0.030411371262744073, 0.05219159760482369, 0.19189829878028364, 0.11153290994585523, 0.14347959610243, 0.3775095284706162, 0.7543255328651398, 0.15243424463175959, 0.1603344037768341, 0.08724747075428886, 0.7054947821363327, 4.065327081949481, 25.98862651855715, 69.51492709498253, 99.16927722192581, 129.34017212160174, 131.74640501699142, 137.67073723577684, 139.7252904215167, 137.89721488952637, 139.96639067126858, 135.54010575817478, 144.21707891648816, 146.1203384399414, 143.33209806872952, 146.60445305608934, 144.0465185719152, 138.6050615003032, 139.40320107244676, 151.79552170538133, 145.18165249978344, 141.92575577766667, 140.5980020953763, 146.0383922823014, 156.97938888303696, 147.45926303248254, 161.09475535731164, 163.02918987889444, 163.13016737661056, 142.49700976956277, 148.85082583273612, 121.61284400570779, 95.34012609912504, 63.80760392835064, 18.619850104854955, 7.205965201700888, 0.18488649519220476, 0.011315177055826832, 0.508158500156095, 0.6462742856913998, 0.6662822346533499, 0.1341554786889784, 0.14738213991926563, 0.06707190175450618, 0.03822478052649287, 0.16876658034180442, 0.015308626780977413, 0.04685640042167037, 0.04087438371272818, 0.032366686200182286, 0.046471479544115644, 0.10133909121636422, 0.04960365683561371, 0.026952704534895962, 0.008984314326587464, 0.08531676830663797, 0.040041017946937395, 0.021475767679212075, 0.06620702679238974, 0.050594193199949886, 0.04062701009153839, 0.0601797036436056, 0.0848002411845711, 0.03159304081852878, 0.01905919886344383, 0.03419742566503344, 0.024108898059855548, 0.025963441791733908, 0.12142473681559487, 0.03533204401572866, 0.02844082075171173, 0.030923619783753832, 0.07704379247321237, 0.05244545616029252, 0.059591397913473274, 0.013986392540016003, 0.032759467139840126, 0.11050701862381351, 0.09616134042340903, 0.010301041352983204, 0.1368917762151649, 0.05109993380404288, 0.028174335152030956, 0.02281905880438224, 0.040221948762454336, 0.04805683721638015, 0.07197075823862707, 0.00835939821216368, 0.05170540756455833, 0.04125093124927052, 0.027583884375710643, 0.0821580498990032, 0.018400729055546464, 0.018327747689439886, 0.022719589948293664, 0.07381232635628793, 0.025698352387295138, 0.09038103083449026, 0.038589323465261734, 0.08662000643990694, 0.04238134377726144, 0.06856964961174997, 0.02305439143862215, 0.016111667913895462, 0.06729468012288695, 0.024934082006615017, 0.016694687637350252, 0.04460388358922736, 0.016273029013386658, 0.17934371116420916, 0.12580148139668088, 0.16374023150532477, 0.1676399254750821, 0.12271204798091805, 0.15625993450803144, 0.19422092414911718, 0.18474121427824422, 0.17745800106035126, 0.12752847340438636, 0.23028393095779806, 0.1403403976151059, 0.1670552931365467, 0.11808361287318891, 0.2032697708496163, 0.15978355591575946, 0.11157234815219719, 0.1210473235996981, 0.2348971745419887, 0.16303155421008989, 0.19041129147573826, 0.11331721299117613, 0.25860655391889237, 0.10474376981296848, 0.10248894322543375, 0.1323638748257391, 0.1250056079739044, 0.16493125307944514, 0.20948115045264845, 0.13477239397264298, 0.20379388224213354, 0.2789662291686381, 0.1560218037376481, 0.1348717096111467, 0.1625257982842384, 0.165438219424217, 0.1309402689578072, 0.09686058717629603, 0.14024203192562829, 0.19515420310199263, 0.1859087016313307, 0.16979611058148647, 0.15477010799992472, 0.10512403287594357, 0.15906845880371911, 0.10868900770982427, 0.2260479243892816, 0.09267918735502229, 0.21571922055896253, 0.11336458020753439, 0.22190846022098298, 0.1692283628208022, 0.14142956013881391, 0.12860391529337054, 0.0917149201456097, 0.11997797977059119, 0.18161229669086396, 0.09311234112828971, 0.2274037467976732, 0.3462616600576909, 0.24281817127860364, 0.4330394423056034, 1.0286263785054608, 0.8870293055811237, 0.16300507821142673, 0.21419240732587155, 0.8338020068983879, 2.720837626726397, 8.837614809313129, 37.170101673372336, 88.80235087487006, 121.03632619304042, 153.05460253069478, 158.15751198799381, 156.29487253004507, 158.869077005694, 156.28040682884955, 157.9757022857666, 144.22981877480785, 153.87746872440462, 156.63160016459804, 155.31664909855013, 158.9481362988872, 151.7406399019303, 146.9577801612116, 150.1723821701542, 150.08891413288734, 149.33126911040276, 150.02461864102273, 150.0177937169229, 160.6721435054656, 173.09248555091122, 165.22143394716326, 177.0863369972475, 182.41079761135964, 174.91309289009342, 170.11289627321307, 170.57659887498426, 145.80556038887272, 119.63427497494607, 83.32678487223964, 26.95182138873685, 13.527300607773567, 1.3572077405068184, 0.12302268131245529, 0.7084118610908909, 0.8140161008604112, 1.025810116721738, 0.22478119800648383, 0.2218170812533748, 0.14734656279606206, 0.3907170681463134, 0.5400262256303142, 0.13280629060201107, 0.13974940674679895, 0.1891835436465279, 0.1725992416181872, 0.19401245630316197, 0.2311757798757284, 0.11395265994172905, 0.3191416265983736, 0.13227459493904345, 0.18410255741928855, 0.1416475121532717, 0.15768249849638633, 0.19244183816256064, 0.10543894863897756, 0.14559064330833574, 0.13218647950599272, 0.16093451109143997, 0.12822680851264348, 0.23795956505402444, 0.1077610913724188, 0.11333712361632817, 0.11567464939528897, 0.25440811630218263, 0.1252869767467341, 0.132211729763977, 0.16220333655515026, 0.1674175301506635, 0.15416944910201336, 0.13259665830241096, 0.2317670158921711, 0.14726203265449694, 0.18117884414330607, 0.21340002726402976, 0.10112113920190643, 0.21328102316587202, 0.16193640087881397, 0.11451680708916918, 0.17577438495091854, 0.22212533971234677, 0.10233698202477348, 0.15780620637439913, 0.11039149256483202, 0.11834081923288685, 0.2398282833277218, 0.17607899683137096, 0.17567621844430126, 0.13435602518579653, 0.14072904934085187, 0.10113930314659111, 0.2551828916635244, 0.16029518007511095, 0.17040960911300876, 0.13642605604423633, 0.20091777366976585, 0.14456940213999442, 0.22213791887606346, 0.12221704792952347, 0.12184219344729379, 0.15810472019497426, 0.1453127832181992, 0.21425758608646933, 0.13267587179378157, 0.12482608292972851], [0.06528616612476688, 0.03748179015312945, 0.04081477058090029, 0.01865536519025843, 0.05100267511161585, 0.07824750046335882, 0.08493372434449774, 0.05747117297423463, 0.01668067205877554, 0.02663623552859551, 0.042195161429023555, 0.03175322980349583, 0.005382011858596197, 0.04280348886705695, 0.09450924883206045, 0.04706905876857139, 0.04458853118722478, 0.009193761807475841, 0.020758663416810093, 0.12428468093276025, 0.03247554729422254, 0.033213925818281795, 0.08830327780977373, 0.010619804792616878, 0.04744969721462938, 0.019012019338627017, 0.015564444606312582, 0.028330245535940896, 0.015685723027995518, 0.036833327368743, 0.021951119490568678, 0.00966638730343191, 0.023621551226824525, 0.03696923519694998, 0.08741204942306204, 0.026607196965825655, 0.03617273358207557, 0.03724828272336914, 0.12407408336237555, 0.05226693469129744, 0.04006799956363055, 0.05770413265112908, 0.03923220146868018, 0.13040794510274165, 0.007994212238343373, 0.05051764569455578, 0.011985578683144864, 0.012264785172808315, 0.06925603374838829, 0.038020028206970424, 0.009931747711473897, 0.028020010570124276, 0.07713492629268477, 0.06567589803448608, 0.0683821112878861, 0.05429159016198209, 0.05993240280076862, 0.06429581362153254, 0.29084528045308206, 0.25512813169869686, 0.3666349410289719, 3.41876799541135, 8.79174170955535, 22.954141709112353, 38.62744654378584, 58.444190256057254, 66.71428418928578, 75.09209032981627, 90.63295241325133, 113.44179384170042, 104.47574200168734, 109.07458766814202, 101.67784475511121, 83.87852899489864, 101.27704128142327, 98.79884858285227, 88.45788832633727, 107.39288714624222, 90.95923869840561, 100.67990749113022, 91.37858713826826, 87.25153984562044, 84.282164419851, 102.74503538685461, 108.95783439759286, 76.44378615963844, 82.98293421345373, 63.96018020568356, 91.83009116880356, 97.99754758034983, 106.35058787561233, 82.26429323996268, 93.24572947717483, 104.53583271272721, 104.48339062352335, 84.27861075247489, 91.60316636485439, 109.3767749109576, 118.38785556054886, 117.45174269522391, 125.11683064122354, 119.84132120686193, 106.87540884940856, 90.36175189479705, 45.57827872614707, 40.69910126347696, 19.972304913305468, 17.319433381480557, 1.8440448492765429, 0.2330773633213774, 0.15689139014049885, 0.07189477763829694, 0.09551210389021905, 0.024519417765400103, 0.14739105718270426, 0.05133583908900619, 0.007979666143881098, 0.03644109801239064, 0.05967742958736997, 0.040334115525887865, 0.029974680078486284, 0.029645773634735136, 0.006048212451259456, 0.07154122040036225, 0.032733561876680584, 0.0051013301708735526, 0.054916419133904486, 0.06909425896141799, 0.004373680708193851, 0.1695464118834465, 0.0090327866247765, 0.10725217150344003, 0.025645911753658327, 0.06202023754256868, 0.01684337572735404, 0.08693965662631296, 0.017141083240388863, 0.023438680293639342, 0.010642258829677538, 0.0892235868940911, 0.07324986460228121, 0.04083548942881246, 0.02249302902078677, 0.06279294829695456, 0.060195914064083374, 0.012765334573604408, 0.06318888934930006, 0.009443524665379477, 0.03931975382710657, 0.10333223749072322, 0.02788987712964656, 0.08259062910632742, 0.021166136007635825, 0.03906391110391386, 0.052498074909371716, 0.031562881852169676, 0.012772057952749874, 0.02814427194666238, 0.01901975874188206, 0.032795300902498346, 0.016892907142098394, 0.0881750193694907, 0.06176342188771214, 0.07898325130583779, 0.04339218530203066, 0.03985238028690219, 0.041415126874081554, 0.04555431908116706, 0.0438505242158088, 0.026161352946092526, 0.04723060372916441, 0.05460894591505489, 0.07716649677604437, 0.017317308360830914, 0.043238783856072736, 0.023510556577915148, 0.012288806817284035, 0.023861999413178816, 0.015597270516258095, 0.04231181363725374, 0.06155272089545766, 0.020711487722432902, 0.08335941366010136, 0.07551603695197452, 0.060260817033028415, 0.01318647034255968, 0.05456476945490126, 0.059229739295739325, 0.02721305377030325, 0.021465929195044503, 0.04024725264659332, 0.021744241277056358, 0.05792113471656077, 0.01686027754218348, 0.06885335495274875, 0.06788796159408747, 0.008764165555006795, 0.03213699388828489, 0.07870594279900675, 0.05132415624816091, 0.0447494326339614, 0.007947549344070496, 0.022556959058067972, 0.042709233239293105, 0.058513945043687864, 0.0387714761910179, 0.04565073124643776, 0.05117401067588118, 0.056391624853976315, 0.01849874234457891, 0.07229146562636861, 0.04041945005977347, 0.05134071523864424, 0.017639808394315264, 0.144459116122415, 0.025659908180034934, 0.030816940125077966, 0.04815227261954739, 0.04122843890781364, 0.06320616846243221, 0.07100883525826278, 0.058268858194952054, 0.03681975612116437, 0.041430234127948364, 0.0433756914290209, 0.02376034720650604, 0.035896206484927286, 0.024162913004176754, 0.09736654994588706, 0.052672907665011384, 0.05445039252780619, 0.053093378852692344, 0.05736129298325508, 0.03902361104865709, 0.31328381189415533, 0.1545935706986535, 0.2705234499467958, 2.8435874658246196, 8.922601784429244, 24.938009861976873, 44.937128097780295, 72.89801843704717, 78.98421902810374, 91.87049942631876, 105.15163698504048, 129.73944587092248, 122.52127278235652, 122.93782064991613, 112.42721003870811, 119.54248366817352, 126.21651418747442, 127.25897035291119, 123.94473229685138, 147.81037792082756, 123.3697912769933, 148.28647521234328, 119.9346814617034, 127.5742583121023, 132.83538049267185, 132.50833326770413, 149.95341977765486, 112.90851623781266, 132.1409954563264, 109.49806244142594, 136.58813168925624, 137.72951003043883, 160.36806568022698, 116.18687245153613, 146.40376890859298, 134.66190276607392, 128.4490723763743, 124.20645636896934, 134.79567127843058, 124.73468196007514, 139.4573611597861, 136.68637921733242, 150.25399884869978, 139.16591336650234, 130.48992080073205, 109.41903452719413, 59.617924228791274, 49.87264256323538, 23.490537597287087, 20.256308048002182, 2.2398868924187076, 0.2649199457899217, 0.15703469454761476, 0.03543586425122715, 0.09888001792733708, 0.03902675583958626, 0.07377218334905564, 0.04460568772628904, 0.06430295356098684, 0.013163571974502937, 0.04588988857463964, 0.05485579859645617, 0.044342119006379965, 0.04302309563143119, 0.04145519327252142, 0.03281095590923102, 0.040565696244518605, 0.011227476267865109, 0.043536451149491534, 0.017960119331555984, 0.057654229683741454, 0.25600289685591576, 0.013178959808072016, 0.03917188353596195, 0.011459684220983857, 0.04228074111104493, 0.02131541590056112, 0.03684183094470251, 0.028607502331837054, 0.03382673104023261, 0.049589556987367334, 0.06594117130002668, 0.011395777166340382, 0.05054186939472153, 0.009264718786242509, 0.09028600528836252, 0.005578409031694455, 0.014755780388030314, 0.03863652980315589, 0.05386653776851393, 0.03616249481696756, 0.009289068890915764, 0.04316086505329417, 0.0508546899072826, 0.04602597643350882, 0.043698854128559755, 0.018599676343822674, 0.06214620921039774, 0.041947232394088665, 0.03113972169587449, 0.08469238366571166, 0.0021233979796600197, 0.06664625564289671, 0.08523013908416034, 0.045040706923652085, 0.06083425299655046, 0.04487108356589752, 0.009749029038263666, 0.02218763381543179, 0.026866617319624753, 0.09601600588329377, 0.01635830800589775, 0.020919034347659158, 0.07097854414173672, 0.04456815707887854, 0.044186335026977525, 0.05195478067523049, 0.03394628672169582, 0.1590258796368876, 0.18924959574735936, 0.12118787775116584, 0.0973560851848414, 0.14833366708649745, 0.15239840703866175, 0.19798016355883694, 0.15620209486974826, 0.16268630902613365, 0.1622260740447429, 0.2547981316644338, 0.14443659313744114, 0.10800313685209521, 0.09437143727536164, 0.13874348733694325, 0.209415634613364, 0.19064104124422998, 0.08609225612974937, 0.15556782003371947, 0.3214852427763324, 0.09674561270062002, 0.09442412880279365, 0.17061256112590914, 0.1496275436253317, 0.0966443665205471, 0.10759728645244915, 0.0955428776421374, 0.1275812415406108, 0.12992134137499717, 0.14060121990980642, 0.13873732799003202, 0.18306737345072532, 0.1300220512935231, 0.14154729253101733, 0.2002884630834864, 0.10581317492910933, 0.1720635010109794, 0.14044073981142816, 0.15923102266125141, 0.23507991715544657, 0.15495340219668804, 0.153083810582757, 0.15102317196226892, 0.26197819880420165, 0.17123289316171603, 0.20005494416240724, 0.09674685376305735, 0.18790926363679672, 0.13843334430167753, 0.07243588852185397, 0.1099468857770966, 0.11074330312229934, 0.176335008093907, 0.14933286024437797, 0.15344569519642862, 0.1514552608733216, 0.26210766766340504, 0.20881428623632078, 0.7404738051756736, 0.27722837403416634, 0.743307656338138, 6.773105177187151, 16.192408953943563, 34.72295453471523, 59.73986287270824, 89.89735111113518, 98.71123067794308, 111.36808380003899, 126.12528770200669, 149.60442296920286, 134.86898822169152, 135.39089879681987, 124.69455611321234, 106.08887949297505, 125.59453610450991, 123.90572824785788, 116.34414380596532, 136.83244828254948, 121.98091137793757, 133.50312479080694, 122.14830244741133, 116.6449817534416, 117.28781900098248, 131.94410816315684, 143.69562333629978, 106.29362721596996, 111.14581877185454, 88.65175539447416, 122.36402496214836, 126.58386768833284, 136.75925685513405, 113.04763486308437, 122.77831354448874, 139.21240129778462, 135.8497690385388, 112.21387232503584, 120.13309847924018, 134.76369611678587, 146.10323690599012, 147.2519108556932, 160.54654921254806, 160.05567243022304, 150.47046661376953, 136.08423263795916, 77.62768299348893, 63.28141404736427, 33.129428894289084, 29.08683023145122, 4.035897538546593, 0.3442301481000839, 0.36204006823320545, 0.22298565645131374, 0.19098731298600474, 0.1946983195000118, 0.2255732716331559, 0.157788785535001, 0.15717661999646695, 0.1870222563945478, 0.1160825146061759, 0.12795414249863357, 0.20313898431918315, 0.12989750071879358, 0.12391197149671855, 0.18550449832072183, 0.1975145966054932, 0.08543748844174609, 0.157975098118186, 0.1872923943184076, 0.12436627695757536, 0.4643387611835234, 0.11796848517992806, 0.25190558284521103, 0.1437922978713628, 0.13332174520098394, 0.1105470160743402, 0.16716588558929582, 0.08071114729729392, 0.09434147557664303, 0.166595563773186, 0.12888660173743002, 0.28094368596230784, 0.16018028220822736, 0.14493822751026, 0.2493724671583022, 0.12373546483896433, 0.11534688633776481, 0.13202014649587293, 0.12827595305298606, 0.15111007697639928, 0.12352379474548564, 0.17672497749088273, 0.16591365359002547, 0.10987080558533631, 0.18468283837841404, 0.10696294266850719, 0.19683352911904936, 0.12085307434561754, 0.1303263260952888, 0.09666137367246613, 0.3021033408661043, 0.11444965182172676, 0.18322111197536994, 0.19554314594114983, 0.17781312877853073, 0.10927635199961164, 0.15063078172745245, 0.1321956419175671, 0.10189758463492317, 0.10842483761089464, 0.15753606845053936, 0.13854982030968513, 0.28107952867304126, 0.20464748805088384, 0.23685578557272113, 0.2069214208712501, 0.08323448770228895], [0.015786491360725657, 0.03290922200727848, 0.030504418386807366, 0.023390424415288914, 0.06063490542733382, 0.025517931020247842, 0.07710748502323705, 0.10054679542419412, 0.020567683442946405, 0.018776016377453363, 0.009180808218286164, 0.056672874883177786, 0.03611098689537856, 0.062410838962081945, 0.04682265807904544, 0.06466994798111339, 0.03125089446022626, 0.06974040049939387, 0.08622213101555264, 0.07616772496652219, 0.02179772762070981, 0.08027918862118837, 0.030513645915855325, 0.09098730515688659, 0.1002050819055688, 0.02236774683208956, 0.05294982546700105, 0.03505406518196387, 0.0274702467234625, 0.04532796691261953, 0.03319828230286798, 0.031530606567919735, 0.02200397572690441, 0.03401363734155893, 0.04291366763232697, 0.008477646756106088, 0.04060580094735469, 0.0631153027737333, 0.009542669849320045, 0.03154942934821931, 0.04617092026878269, 0.06880564299682457, 0.03243501741258848, 0.03640838988846348, 0.04677942007659905, 0.03823217327496217, 0.07999287858124703, 0.034344978029689485, 0.018186502143620484, 0.012841079601897828, 0.05789914033225468, 0.08774287683228332, 0.030631512373445496, 0.08789187327267663, 0.04816017864692596, 0.09641496149162132, 0.27990226603804097, 0.4287142324591837, 10.1022457884204, 38.969092830534905, 68.50256335350775, 83.88855457305908, 97.16168265188895, 86.29666236139114, 104.71815232307681, 97.76307613618913, 89.71894602621757, 101.46106320042765, 115.59555945857879, 71.44208169752552, 85.01621246337892, 56.20326172920966, 78.56034417306223, 30.461615093292732, 37.83666926045572, 46.40944465514153, 30.26963664639381, 35.27009379479193, 36.1518818332303, 30.93210339546204, 35.07407726780061, 35.94720863526867, 22.343783647783344, 38.481200971911036, 27.07218716221471, 32.235926697331095, 34.5403564360834, 41.06695290534727, 24.2897028692307, 31.274791071491858, 27.129910722855602, 38.0248135905112, 17.681607392526445, 50.02670934123378, 55.17831110185193, 55.89801896002985, 46.57848704245783, 63.6066020688703, 70.74087173708024, 96.58984030446699, 90.90860089948102, 110.41641481461065, 109.21802874534362, 104.84722968070739, 125.45664910347232, 115.09093869117, 117.47726948030534, 116.46929094868322, 100.59066572496968, 50.41516519361927, 7.4621150955077145, 0.25804430666950445, 0.2937010417301809, 0.09825380233627173, 0.02910122876205752, 0.1061512878344905, 0.028055409577885465, 0.0265000538239556, 0.057337314431225105, 0.08054548078366826, 0.0566166976556903, 0.05006983282885725, 0.03465128296445455, 0.06742388085131684, 0.0047214219023683866, 0.006762996424860772, 0.02989750821143389, 0.025245025603761597, 0.02823534256388103, 0.012583403055736376, 0.07891433403616951, 0.004763182791535773, 0.05865081814267944, 0.027728347490812023, 0.03105668925620135, 0.0159608539299018, 0.04920441777475419, 0.099770212095351, 0.07409560268804913, 0.012752650072798135, 0.06807789777315433, 0.031917097925719236, 0.049747765635050116, 0.07811059289041065, 0.08871157969077749, 0.006740502646989039, 0.061266292111888054, 0.05259559024125338, 0.013579919693931458, 0.009300952829841164, 0.00567493515254389, 0.03858866079920723, 0.09056102319229996, 0.046888258188001575, 0.012644774359350484, 0.03697381257229755, 0.06470021611500172, 0.07128196858590649, 0.020466975439640305, 0.051909167800218835, 0.03057232442041559, 0.030851980986734553, 0.01886873599892903, 0.03848094883705339, 0.0461579120958284, 0.011478537644800401, 0.012700146236907572, 0.00367469011595653, 0.018595441792821212, 0.08651889815566041, 0.05877694685853297, 0.010593481053928695, 0.03861833904539386, 0.04036453304692142, 0.04116973359017603, 0.014085930344017764, 0.015456601451601715, 0.05981654349354006, 0.0574546484577079, 0.04725287390512325, 0.010708939122606911, 0.03921775688086787, 0.019127528160630215, 0.044653353716937766, 0.06535946541736204, 0.032399976550931894, 0.05134441927375813, 0.058645103126764304, 0.05952859019500114, 0.05180753474574416, 0.058303657738912495, 0.033025096636265516, 0.05608244325905558, 0.07191299520913633, 0.06528375294780539, 0.07852385902116377, 0.05740044390662544, 0.03888417155511918, 0.01870764111499152, 0.032699202833276604, 0.018536970132000504, 0.038182630368898955, 0.015022125219055002, 0.018809346947818995, 0.055419815508949186, 0.037056657320429245, 0.04994489537972597, 0.02895657220975526, 0.06366014067504196, 0.0125859129512983, 0.09830337588585193, 0.012932193311562222, 0.06306805813144292, 0.03849500272002432, 0.019269396152888096, 0.011630967116704392, 0.05093121443003897, 0.07184230827636297, 0.0422154474372585, 0.051869741085195736, 0.005406845077466701, 0.057445976342405045, 0.09833371296765343, 0.002564176482396321, 0.0810351028978344, 0.02840632572770119, 0.08063650735083126, 0.07336362099815762, 0.014694727968514688, 0.07915842497060377, 0.03405753034918058, 0.13705878338265803, 0.23827716978567265, 0.5405931306942817, 9.807589496335677, 41.8984914595081, 75.26064242086103, 99.55785074541646, 112.33622674019107, 105.2970470920686, 111.2296712013983, 112.27427682568951, 103.47825973264634, 115.73896915681901, 117.44778110134988, 103.84716649209301, 119.71873144949637, 100.99141428547522, 119.39196663518106, 62.4026736905498, 81.52022746301468, 74.74719632056453, 48.93792998406195, 55.299057345236506, 51.265954740585826, 57.07256094101937, 63.996124805942664, 59.39060718782487, 42.73363467185728, 73.95990602431759, 65.19402450130832, 56.95767471867224, 52.32075852732505, 53.02034070414882, 47.887252530744, 59.91638129757297, 55.7237558980142, 62.05855238822199, 42.25805121083414, 77.52132400389641, 84.58922324642059, 88.46008485363376, 78.58306254110029, 103.99250599645801, 124.27420354658558, 127.77873931392547, 132.3945688432263, 140.79360285112935, 138.4088331653226, 128.65422018112676, 146.51872573360322, 138.28410179384295, 139.7550690558649, 135.60680174058484, 116.38166519903369, 57.908296431264574, 9.194821138535778, 0.09914584277618317, 0.15966488889628844, 0.09097749923145579, 0.04960951357779484, 0.08583066008624532, 0.016698569787906545, 0.032038727790237434, 0.08489019522864012, 0.06679729753804785, 0.03583657803134092, 0.048735231055968234, 0.06879813533516661, 0.02925808334933414, 0.1378988907221825, 0.018229560115404667, 0.05367418458204597, 0.03909310671470819, 0.06553781834701378, 0.04775230960559942, 0.055093649744747154, 0.025122635396978548, 0.013690441283547591, 0.024158711011912075, 0.06646782610445254, 0.018325286631983136, 0.07775113677545901, 0.049991967652233384, 0.030508068795766563, 0.06683811470265351, 0.03480511341965006, 0.036959919567790725, 0.02565859242402498, 0.10108628986223091, 0.05421236517929262, 0.003549333233686705, 0.06403994408526248, 0.05885278956303674, 0.030633163292922323, 0.08677595129777348, 0.09092297675388475, 0.022492634485505765, 0.07094415445481578, 0.03499894898625151, 0.0155199550077199, 0.0631789800019995, 0.06090357246237898, 0.019426308196759032, 0.05706019744637513, 0.06249798529390847, 0.046224607710516265, 0.013698411470789824, 0.06565519833877202, 0.027397899295113264, 0.051453625107364315, 0.024098783784035235, 0.04657705795140036, 0.0468632952129889, 0.021332664370176294, 0.06669468772146972, 0.024024526881534728, 0.008883970215045398, 0.021516623148213954, 0.051815494399277434, 0.04165774691970118, 0.0395159297923167, 0.14780474466181573, 0.12586413206712854, 0.0858912040149012, 0.16395110486736222, 0.19529589872446754, 0.12483155279750786, 0.18426541239023211, 0.13278557558453855, 0.14318595460105327, 0.11289863021022851, 0.07706743394655567, 0.15175699226317868, 0.1227141164183136, 0.22390938994865264, 0.16822155474895434, 0.10221502082722803, 0.09065453188433763, 0.15667058827896274, 0.20919248852277958, 0.19352491794814988, 0.11388434022064171, 0.10684700292204657, 0.1598300421310048, 0.12069014276588157, 0.14764322268386043, 0.11833078348107877, 0.17234494639260156, 0.12035472648999385, 0.21250632441332265, 0.1497687336297766, 0.1606343271991899, 0.2059460377260562, 0.16976779597180505, 0.08704653355262934, 0.1044148039974032, 0.06944346481994276, 0.17835959461667847, 0.15659515926193807, 0.11111494003524704, 0.10332284525277154, 0.14409150117106978, 0.19005507591270632, 0.16429777497485762, 0.23524082626306245, 0.2707685367955316, 0.17721619306793138, 0.19122317613613224, 0.07585528366748365, 0.07817070014894971, 0.15411436738025758, 0.27402039617300034, 0.20061115463895185, 0.1883583596997684, 0.14657546465675678, 0.0741961440672317, 0.397240980978935, 0.37529991639237253, 1.4929755584847544, 21.462593770796254, 67.04553619507821, 105.66153726270123, 119.4512571827058, 134.44760014933925, 121.53156465099705, 134.1738030218309, 123.67510857120638, 116.41560154576456, 129.78431778569376, 143.0266866376323, 94.04143717981155, 115.12036431220271, 81.76344579265964, 110.96050247069329, 49.58073193027128, 59.7071110817694, 68.10226194320187, 43.36497937479327, 49.4508465643852, 48.5298309018535, 37.14894833103303, 54.86442342881234, 51.11567304980371, 30.7505270742601, 51.11194679814001, 39.23201322555542, 48.32185899057696, 43.9019283171623, 56.75061671964584, 35.34895304710635, 46.726360397954146, 40.87756126157699, 57.83408518760436, 25.140700301816388, 73.87334715935492, 80.44505873034078, 75.90136158850886, 68.76300088820919, 97.68199289998701, 101.90365560593145, 130.34038436028266, 117.0891901754564, 139.69083632192306, 136.09501131119268, 135.40787481492566, 163.24328853238015, 152.9646861168646, 155.4274639006584, 154.1158546939973, 136.12650009893602, 77.61524123530235, 14.830026626586916, 0.547229168155501, 0.5890728905797005, 0.39486813088578565, 0.1539378147572279, 0.20654255974917643, 0.16333949091213365, 0.1495702708921125, 0.29004925381272073, 0.16374557879903626, 0.2283293035842719, 0.1497806539578784, 0.19930356512627295, 0.16341225394318182, 0.1389706170847339, 0.1700651300169768, 0.12296932328852916, 0.11147140840729398, 0.11455110484553922, 0.14204992281813777, 0.18907143433968868, 0.13309970227701048, 0.10566997777430281, 0.09733267353787538, 0.1976449081614133, 0.0739988457832125, 0.15132761530337796, 0.15528240631664955, 0.2914920425222766, 0.15608669138483464, 0.1622233161282155, 0.1901174967567767, 0.1230366777388319, 0.21598326042294505, 0.2305392987064777, 0.09403334735261817, 0.20741570079999588, 0.16532039510146265, 0.13723240954981697, 0.19934870302677157, 0.15282793721604734, 0.11677113571955312, 0.1783959837930818, 0.0950553392871253, 0.12932895622666807, 0.15856683975265873, 0.25132470433750465, 0.11792032889300778, 0.12537356766481556, 0.35064840208618875, 0.13858256290756887, 0.1059550773953238, 0.12139454529049898, 0.1407639216631651, 0.1434134520710476, 0.08260399734060611, 0.13530415092264453, 0.08487320339847958, 0.08145455901901569, 0.12666457137393375, 0.11048513149181682, 0.168184093049457, 0.12337510474026205, 0.12411434894367573, 0.18907570911030616, 0.14151736913669494], [0.06301219500000439, 0.08050890774616311, 0.013269794853253952, 0.06834749943546711, 0.026331646630780834, 0.0461436820126349, 0.0726132915024796, 0.08027037094917991, 0.07649198700223239, 0.03434073773302859, 0.0289242567058893, 0.030491105693903182, 0.03451656640296982, 0.04597554486545344, 0.06789733084940142, 0.07724180321900115, 0.04744343061540877, 0.023913258356192423, 0.05833970983662914, 0.03600515950951846, 0.020422044382881255, 0.020227513591488524, 0.01799537086739175, 0.07956679579952071, 0.028962162736382698, 0.057542530233941735, 0.07323163170968333, 0.05902421322741336, 0.06599043075355791, 0.034283039821011406, 0.04055476800027875, 0.026663946844036543, 0.07536170853962822, 0.010631366017004176, 0.021538642430377584, 0.06090446112437114, 0.06092915979904994, 0.04991551973826943, 0.06073813960557023, 0.03692529622405287, 0.027622975927266865, 0.013308626892525825, 0.021136409880953933, 0.04385185720879705, 0.037177741347301396, 0.06006581701278206, 0.04978878581295571, 0.04053642785537147, 0.1099937397145456, 0.015335812368580412, 0.14716846267542533, 0.06116436794400216, 0.12260700966561995, 0.10665970208543925, 0.37733838442833195, 2.613054326465053, 17.580325911121985, 55.25382849477953, 90.88375660680956, 82.37353909400203, 86.28675445433586, 87.56761227884601, 85.35668203907629, 83.93468164628553, 81.19174465056389, 95.116072470142, 83.02810422835812, 76.75927023733817, 67.54524615503126, 42.13444948196411, 30.492397854405066, 29.010120437991237, 39.724149088705744, 57.6693574074776, 52.68857879023398, 69.5623093266641, 71.12328713940036, 92.55151702511696, 80.23126602172852, 109.57285419587167, 76.32507954874347, 94.71647708646714, 112.5743067649103, 90.87506463450771, 104.86156986605738, 101.97918476596956, 98.58268676265594, 109.82638051432949, 117.50716578575873, 109.75874316307807, 151.70461685426775, 108.45591222086261, 131.52540299200243, 74.80887951389437, 57.84884898893295, 93.88877068796467, 78.40901913181429, 36.758256727649325, 42.303378120545425, 45.142526934223795, 42.85930741217829, 46.5204438086479, 52.04534538330571, 74.18748978645571, 71.89318564630324, 97.06239177334695, 101.7390101955783, 99.62156572649556, 102.60388497383364, 112.15522504621937, 108.33293807122016, 62.69590616226197, 20.260012726629935, 3.646420644175622, 0.2589473711146463, 0.44735590957345506, 0.0499111645284199, 0.10050191033271053, 0.2247742266063729, 0.008789249188867549, 0.10064532965301506, 0.09297188656825213, 0.09653535986980123, 0.05159549309962219, 0.05175097830473416, 0.02257729869245762, 0.009845350230593356, 0.035379250353622826, 0.03667274001805532, 0.015967876083337735, 0.06393037052945265, 0.012826703961998706, 0.02142432295987683, 0.04573064187781946, 0.02805937791333324, 0.10969870393314671, 0.04973871047578512, 0.005669524656578658, 0.049419090932896065, 0.011690860828234544, 0.06239503839864366, 0.08925405421083973, 0.021091091949793122, 0.05333686074722679, 0.018732203809063763, 0.06784871490972658, 0.045967148541803324, 0.03632460285218493, 0.032379518172913985, 0.018684683375120647, 0.022242096921188698, 0.09439681010741381, 0.06741802793957534, 0.008087358475031873, 0.017653249406946764, 0.05933996785672442, 0.02568358412733482, 0.03886093610837575, 0.030748453779867103, 0.0337077307725145, 0.17637850656624765, 0.12035762996322687, 0.07555283215497771, 0.0239217197973161, 0.01300638413897926, 0.060323532820949634, 0.04138530307118932, 0.09608906002775316, 0.01979315322974036, 0.05886311642825604, 0.0705909189738093, 0.04400615114718676, 0.02707296501724951, 0.05938972909784606, 0.045348310377448804, 0.027805649592811545, 0.007377413304282293, 0.041388516810031674, 0.05775860533298505, 0.030433239242542657, 0.0707924767066875, 0.012645083667349913, 0.08746975882639808, 0.07314078900362216, 0.04686494996290534, 0.03475507638687569, 0.03785530015105202, 0.00672707264687145, 0.01382467425203011, 0.10354326407034552, 0.04560429099646788, 0.07012108491072733, 0.06128040728189292, 0.01586981299859021, 0.06857177933617946, 0.015868077809441716, 0.07390362871510368, 0.02130700233993271, 0.06143137256825163, 0.05308454585892539, 0.09435612317775527, 0.03925834804953587, 0.03039282235887743, 0.034287184356681766, 0.08969866099857515, 0.0328444377819617, 0.051040868425080856, 0.050914912079010284, 0.01733579023200418, 0.039035347515657064, 0.018197562538027283, 0.041197879660514095, 0.07153526023631135, 0.03651900532385034, 0.01408761382223137, 0.033046562419903856, 0.05702825541037226, 0.02465709908715179, 0.03704561799344036, 0.06059329536172652, 0.01935544314854328, 0.01087630347859475, 0.04054653255509273, 0.023183199546990857, 0.031690722774533976, 0.03161795399782639, 0.06034175422222865, 0.024147644871845845, 0.0851719317236735, 0.20357678824615097, 0.2560341685649849, 1.8044524447571848, 17.56599553169743, 59.82570394392937, 109.5370037324967, 98.40770982926892, 106.76247596740724, 99.18932053350635, 105.55868487204276, 103.31726212655346, 120.23916721343996, 144.1508536184988, 113.97245130231305, 115.16511071112849, 112.39623115908716, 56.62372019983108, 50.79594496757754, 25.355234338391213, 43.390592452018495, 24.63853297695037, 26.085983668604207, 42.80063267677061, 30.851588902934907, 48.285165217614946, 41.74130247485253, 38.64812135696411, 45.923988588394664, 45.016630618802964, 39.68232877792851, 43.385905219662575, 32.50691344661097, 52.130249008055664, 30.090345105817242, 55.64127629803073, 47.09456897551014, 52.73545111379316, 63.825686054845015, 62.17581948926372, 35.36057895229709, 52.46038313834898, 41.90091940664476, 55.217868205039736, 44.19320744852866, 41.22095692542292, 39.59243589831937, 68.72473424480808, 66.31734032784739, 83.22714882512247, 101.23028662896927, 114.73176725449102, 107.45500964503135, 128.08681795673988, 124.9861215776013, 123.66279232886531, 119.69558946547971, 132.88376685111754, 128.65683247966152, 79.77201923247307, 25.273188160311793, 3.5472775899594833, 0.34829090439504196, 0.20847353032760083, 0.01981353116852622, 0.13914309412000642, 0.24530329921793556, 0.07206929246744803, 0.0417511751725068, 0.07586928775473949, 0.035063308032770316, 0.09553841134953885, 0.012321708378412071, 0.02637496507245927, 0.06100551578246298, 0.04550717786074646, 0.049672455361653725, 0.07982193372182309, 0.09785077114018703, 0.0246245097068529, 0.028116434226713838, 0.046285783661709684, 0.04266552409277328, 0.02391778402060511, 0.08352963839687648, 0.01817305921576917, 0.08777895957351693, 0.049774659151631984, 0.024840366470837788, 0.037389970684964816, 0.06440987645257866, 0.04724124852087229, 0.018802457902159904, 0.04074327542536682, 0.03598223815882399, 0.04274886679805575, 0.06808640900999308, 0.07551949966939227, 0.036606971369755846, 0.08929199854572935, 0.029517384959504973, 0.028940664394007578, 0.04777826466447404, 0.03564353153530148, 0.025424144621337616, 0.053293182244223934, 0.017342280911942645, 0.08441569569009928, 0.03814775804658571, 0.051741003839960026, 0.03873877189753037, 0.031205628240000338, 0.06899227733693777, 0.02405899509246792, 0.037910615529624686, 0.09199797431187284, 0.05036884460658316, 0.047512493441782655, 0.04190605516815859, 0.04820504841665107, 0.009785794555359792, 0.026333845303123517, 0.026621103376871156, 0.03298795286325678, 0.13860102562654403, 0.17835308286932208, 0.08206342271859608, 0.2083665538098543, 0.13738760364151772, 0.13693142892612567, 0.1805627868781167, 0.2053387291849621, 0.15525406106345116, 0.11242041514525491, 0.16696716238173748, 0.1713417389339978, 0.071976434950146, 0.23519286915900248, 0.16967517594175954, 0.1956725228698023, 0.18968519334110523, 0.2062999397035568, 0.22261618756719176, 0.11654396766736624, 0.16422953186256273, 0.11041045324095797, 0.1186677778980905, 0.20561991409669, 0.18509798142458164, 0.18140137736355105, 0.1765008661295137, 0.12309889173916272, 0.2023593519604014, 0.12006290061699769, 0.11836850565047034, 0.22036506884521057, 0.10945522586905188, 0.12433062322557935, 0.13359373705762048, 0.1972357406010551, 0.107477922292967, 0.21795628922841243, 0.1856722102891053, 0.2362113677325749, 0.1482256486891739, 0.20586636458193103, 0.07920622119619962, 0.112145887537589, 0.13010328725701378, 0.14430194552386963, 0.28833101052911053, 0.09862144793113393, 0.2640304870663151, 0.158109286079003, 0.277608905227915, 0.16447063505409226, 0.3836056271628026, 0.3379013118965011, 0.5689251458933277, 7.629796420374225, 33.61536349019697, 86.64423927184075, 132.6108483345278, 111.68127721355809, 113.48087633809736, 111.0577537167457, 108.37727654364802, 107.6656879917268, 105.76376991887247, 117.27389458687075, 111.15179646399714, 100.42636548319172, 87.0014181444722, 58.3497082033465, 44.34033947606241, 43.190830061512614, 59.750994559257265, 83.83163313711844, 76.7622277044481, 100.56239328076764, 108.15061846087056, 137.06501345480643, 119.93724669179609, 162.56376143424743, 115.21890994041198, 136.254698845648, 164.49932559843987, 130.0975347334339, 148.19550760330694, 147.3868090106595, 145.29918239962672, 160.8447591720089, 165.91301056646532, 149.7883507513231, 197.6986119054979, 147.4560780679026, 186.07011795043948, 110.47907075574322, 86.96008420759632, 122.7569523165303, 116.09793663024904, 52.34253552652175, 52.97981477552845, 63.512143550380586, 56.48477808121712, 64.8525429541065, 76.3767057849515, 99.86885547637941, 94.82017670908283, 120.37888203897785, 127.88028947768674, 125.54673025684973, 126.89223658653998, 144.33172195188462, 142.51489577754853, 102.11204328844624, 37.735742753551854, 6.544071608974088, 0.6694337977997719, 0.5379001171358171, 0.13917392149807947, 0.32020302609570567, 0.3229058455796011, 0.19674668539195292, 0.2721499465405941, 0.21453399060954972, 0.24553009188703953, 0.228949390471943, 0.19287018856454283, 0.17687885391135372, 0.12999077958445396, 0.23314726118358875, 0.12868089180800224, 0.21425320406354245, 0.18036904324206615, 0.11964740517038493, 0.10215374145416484, 0.15861093577358032, 0.12280699691825336, 0.20921640578777562, 0.1846271131428019, 0.08914232028708344, 0.14912247717861207, 0.12391156547011868, 0.13384015689934456, 0.2481548776549678, 0.12534164478101079, 0.0624701418283005, 0.16274057869468966, 0.18412704158934856, 0.18715005518207628, 0.11450852567870771, 0.23678677637250195, 0.11264322415715265, 0.11137188592505072, 0.2070282288496533, 0.17807352206399366, 0.07296934618704742, 0.08597907429981617, 0.2266028478381134, 0.1207765038575857, 0.12381581980134211, 0.11885402153336233, 0.14525154214953223, 0.26424848504604836, 0.22052616181392826, 0.2494103578670371, 0.17010513512838274, 0.11951276521769263, 0.1552944951840947, 0.18546339004270493, 0.1785756007678086, 0.0933783268555999, 0.14232344685062287, 0.1125527261906574, 0.1636784541751108, 0.10240559285927205, 0.142705540863737, 0.14548152174440124, 0.22217796995274483], [0.03893122850586811, 0.022645221963044138, 0.03011336689063859, 0.13665264953048, 0.05767358872558802, 0.048480142929380944, 0.05187493899176198, 0.05617430869249567, 0.03186396398251096, 0.025878758432583946, 0.022528602313550732, 0.06820990238338709, 0.06221424930939271, 0.02826104289852083, 0.014045330556860615, 0.08040023817410392, 0.020651242568067486, 0.05199958149704242, 0.015105076261886187, 0.019628609034923777, 0.006109918918340437, 0.05505503891336341, 0.038254730733892614, 0.04770094341027641, 0.024525847158304626, 0.05919971630998677, 0.060423507295068235, 0.03379784569504761, 0.02484813268717018, 0.06480490969073388, 0.04191365092992783, 0.03790303125917431, 0.09332809447040481, 0.04838739649482793, 0.07255954277371207, 0.02394889485121014, 0.09489383263092849, 0.043813790299839554, 0.009197768447319827, 0.05139384343619308, 0.057688573405386946, 0.053715139642478, 0.03494942906282602, 0.034640979081872976, 0.028610426872487993, 0.0789753606002177, 0.04470749315054667, 0.03959092980010375, 0.08083098643128911, 0.03594094985014489, 0.150422559029633, 0.228313721355892, 2.4547334928666396, 16.895854665387063, 41.016060152361476, 78.02411694680491, 84.90025151160457, 84.31024074554443, 73.81620607068463, 82.20647750362274, 84.16555235462805, 83.54676708098381, 55.696879817593484, 38.3199131104254, 42.32351556901009, 23.193694583831295, 32.214669412182225, 36.875621887945364, 29.46062230294751, 68.45631860917615, 82.8362532584898, 120.37702283551617, 106.6443027988557, 87.83865590249339, 105.47139644622804, 55.31777097332863, 51.67745451773367, 41.048137295630674, 45.20135464206819, 64.00229469422372, 60.70994738609561, 60.0183472325725, 63.84054791542792, 84.93107349641862, 99.69253709239345, 73.06057714646863, 79.5182026586225, 55.717856653275035, 57.50440212988085, 68.17880307474445, 62.45790458494618, 59.50477561643047, 79.5404895659416, 56.467782451260476, 76.64148930580386, 100.79986926048034, 86.72110203773745, 106.26085973555043, 165.13928382627427, 106.27194435365739, 93.6312827756328, 67.21331165682885, 49.404382167323945, 43.87455801809988, 34.419849457279334, 34.06036815335674, 58.936977232656176, 65.5879089140123, 88.49031848292198, 90.0281229326802, 83.07907150637719, 96.26466797244166, 97.84801113990046, 93.3470521434661, 66.93705912559264, 19.21360085087438, 1.7041335375078264, 0.257886155478416, 0.3225744665870744, 0.18717066294723944, 0.15002210954985312, 0.04298369572948545, 0.09090596194108648, 0.03702129853228408, 0.07243627922669535, 0.061248131997642986, 0.14404671567101635, 0.03927714784719771, 0.03181211898223527, 0.020642242950177, 0.06354628851817501, 0.04786272968856558, 0.04452671172217496, 0.08003986275364315, 0.03341644116106533, 0.032110309130662394, 0.028324283456670183, 0.012745559929058918, 0.026303843384788885, 0.03475249084013124, 0.021718705651320277, 0.03771631647982905, 0.0745480771987669, 0.04089591461384008, 0.007523160574266748, 0.03919659753239924, 0.02744495433064238, 0.016951041724232417, 0.04784565741917299, 0.058120068598298304, 0.04318706142986494, 0.034975410934777997, 0.01640990019715842, 0.04549542990242762, 0.029407665846989523, 0.041438189951042016, 0.1547344542679287, 0.0549103363957857, 0.0523093453187856, 0.057315354520875605, 0.0900580098612174, 0.09335677680228988, 0.08077552932645045, 0.01704940358327041, 0.026374917191964005, 0.04926183606467901, 0.11617663616855299, 0.04780742197087215, 0.010495729192400412, 0.08323618075660161, 0.05017835684421082, 0.11088578781533627, 0.05088472055391439, 0.020945876153306137, 0.11466410281437059, 0.0288641398712512, 0.041295850814710704, 0.010469238829588699, 0.09099787717024166, 0.08244416075608424, 0.06815472873108042, 0.019812795724118912, 0.00988238387846298, 0.017835315947811452, 0.03701909219906215, 0.04180923697628802, 0.01575278828010684, 0.022053313704447883, 0.04749663925218967, 0.059095922887565634, 0.027144795336249857, 0.03432943793614546, 0.09670821228815664, 0.1049293852561424, 0.02651660515355968, 0.019674725612745653, 0.08280654332690662, 0.06320074072948868, 0.012478467204698153, 0.02201878037604113, 0.055314443945404024, 0.054151223702055794, 0.08413631874587267, 0.016239968489014333, 0.023681585707010764, 0.05616384010101038, 0.01313062732092916, 0.032998379319906235, 0.08077980409706793, 0.05091015850344012, 0.005139055691899793, 0.021584636434131575, 0.02464235572504901, 0.037100772493548935, 0.0913229359373931, 0.03627404871006166, 0.032707568513409745, 0.013973884239432313, 0.04877307196898807, 0.0854638342054621, 0.032273219642980445, 0.03662169557966052, 0.09006244551029899, 0.06132336949268657, 0.08976223097453195, 0.057499265418417995, 0.053819565087436676, 0.20191269205702891, 0.9190339462891702, 15.527609375215347, 44.897802414432654, 85.460632693383, 103.7632905283282, 100.97918433527794, 92.59769116678547, 105.52045745234336, 108.62695109459662, 118.05706639443676, 95.97405956637476, 74.06335461524226, 67.92643777785763, 38.66107694564327, 56.47598804966096, 41.989459068544456, 28.380715347105458, 43.24888898480324, 49.66180732173305, 89.2814919256395, 90.96313753435689, 81.43751252082087, 83.6839480553904, 67.52789358938894, 61.99011095108525, 50.166635974760986, 52.44565856072211, 65.57969547087147, 61.63863128231418, 60.5728840827942, 71.27489459130072, 81.40410177169308, 88.14943313598634, 72.9662206096034, 73.28325010115101, 53.496281100857644, 58.03712667957429, 61.61711315954886, 60.719933740554325, 62.86789032720751, 81.25844063297396, 60.54216800197479, 75.9661905227169, 82.68100584706953, 79.90392854136806, 73.26039052778675, 106.23174005939116, 71.12997085817399, 41.849724631155695, 36.04663287439654, 31.41909703131645, 52.95352312826341, 51.56107779472105, 63.35998304428593, 97.6654875663019, 109.58598629120858, 115.69541515842562, 109.89169582243889, 95.75215539624615, 113.30674663666757, 116.92203444819297, 112.86539370013823, 78.25182622478854, 22.465977245761504, 1.9955923624577063, 0.2518890200242881, 0.27770396141755965, 0.16566400085726093, 0.19469304881509275, 0.029469274637860157, 0.08600070862279785, 0.057030162969303716, 0.021011210046708587, 0.06638650587129016, 0.07260219854933601, 0.04528640664272732, 0.03887125148227619, 0.061886800347917506, 0.0630154010779675, 0.06011093576108256, 0.04899932837654506, 0.07053505584237076, 0.0509662629525748, 0.031177217869328398, 0.015442677803577916, 0.015984830566711964, 0.01629576075731987, 0.041859672374783025, 0.08085001605532824, 0.05955362594836663, 0.05095154257310976, 0.03525540457978364, 0.012047736184491266, 0.08680716171980866, 0.012939722998247994, 0.012972863961852366, 0.05810823637030779, 0.025458624323589668, 0.020073920623549533, 0.018651168943653186, 0.0769822679520134, 0.06867995095108786, 0.024507403591527574, 0.019807373736834815, 0.026004052112600016, 0.029776223086481615, 0.03131272541659494, 0.05070152211814158, 0.05622436487746816, 0.026125597707446546, 0.024273605048356038, 0.03316847382173423, 0.03539240791372234, 0.06597058141543981, 0.014894160765012907, 0.005588555387446598, 0.016273915760159012, 0.08842777475834855, 0.06277349349411745, 0.10977960281795072, 0.06549604357250276, 0.02183471051525445, 0.05166765092121017, 0.051155199386900475, 0.16508327556713936, 0.08736564747748837, 0.15293128247703278, 0.2521900006479794, 0.14041306871560313, 0.20338079231160305, 0.2754867191035902, 0.2595943476884596, 0.09023823204540438, 0.14751501020885285, 0.11534419736915058, 0.12228693046997632, 0.2030254347670463, 0.14581593444510815, 0.12838154295158963, 0.13513365039421668, 0.15289060320825348, 0.16869956297018837, 0.12732894580450752, 0.1578281777760675, 0.15771996019588364, 0.24876563359172116, 0.1126141664421847, 0.17873643326663202, 0.13444427851467364, 0.11779260671427173, 0.1480231410072696, 0.10170110606498296, 0.10716560356799634, 0.21409532866410672, 0.10816933962726787, 0.12209874097137682, 0.11179903356899178, 0.18851933009441824, 0.2677733781597307, 0.16336504760528767, 0.212009240602774, 0.18476027454580032, 0.13047559066645562, 0.13585545843647373, 0.2478275895719567, 0.14690171086019085, 0.1851138854098897, 0.2784821535310438, 0.10990753184042631, 0.14250949896391363, 0.14405724171909595, 0.14068722094018615, 0.23681371202391965, 0.13874886527417168, 0.497382584839098, 0.485168170904921, 9.601293417715258, 36.705449858019435, 75.97179166732296, 117.99011153559532, 121.73101717425932, 114.4298702670682, 96.67530875052176, 104.62975778887349, 106.98197180225004, 106.72265606541788, 80.73300776943084, 53.94483550902336, 59.04665846978465, 32.26818230844314, 48.99546330974948, 56.41568553063178, 41.85094448827928, 105.26165946837395, 133.24034167874245, 177.03394982122606, 162.04349825459144, 134.590452871015, 168.49546770895682, 95.33589778407928, 86.61234255759948, 63.2831242007594, 67.19282119504868, 97.9638465758293, 98.87324810028078, 94.52682264389531, 99.99908601084064, 134.439080761325, 156.18297515376923, 117.12669587904408, 121.22540012482675, 84.42468766243228, 89.26521408942439, 103.29751691510602, 98.84583857751663, 90.212905791498, 123.4878153954783, 87.45791142986667, 112.18392110640004, 149.14484670085292, 132.74085137151903, 163.84303462120795, 243.2695871783841, 153.77194127728865, 137.29687260043238, 95.40242118220176, 71.69839289880568, 56.52059324326054, 49.34079270209036, 49.274736066018384, 77.19459841328283, 83.94378938982564, 114.70174543319212, 117.46816958150556, 105.56200319720854, 121.96028755557154, 131.9701683905817, 130.52377085531913, 101.17756997385334, 35.62799438353508, 4.6113104685660335, 1.089232636074866, 0.4340390644727215, 0.34787939260563544, 0.5013133206915471, 0.1313031188422634, 0.1976768387060973, 0.15453856558569018, 0.22723102461426492, 0.17266769923510092, 0.1926887636223147, 0.1697953291718037, 0.23981175115031583, 0.12569939251989126, 0.1866516537002979, 0.15594332569068478, 0.18392519274305913, 0.09894505113122926, 0.09720923379063608, 0.21334926627816694, 0.08082557785054369, 0.06489175341783032, 0.11788462153485707, 0.12614534762237342, 0.23429813975047684, 0.12128957592311407, 0.17287808230086682, 0.10459214569099488, 0.11948551547022597, 0.15236583298012135, 0.16003250384763365, 0.1021641679108143, 0.21288463395209084, 0.0981504034491316, 0.19994517908461634, 0.1651820396223376, 0.1661582807860067, 0.18504525925363266, 0.10331617262695106, 0.10921641328041592, 0.23469812957750213, 0.14341922837399668, 0.23150728144232305, 0.2863972207471248, 0.24764610334269463, 0.25946631907455386, 0.17345503843840093, 0.10802336157329621, 0.20847264166560867, 0.168065395386469, 0.28637151083638596, 0.15274518439846654, 0.10376995714801936, 0.2770499981218769, 0.12561587361438623, 0.33388256786331055, 0.14003679697071353, 0.1308516479067264, 0.13392534587652455, 0.16647213168682592], [0.006906228053623871, 0.059922175526979475, 0.043770632736625216, 0.04650586540059698, 0.045723364042538794, 0.02762814893597557, 0.036576634287954345, 0.027695281220780268, 0.051691292394553466, 0.059467479361281286, 0.010862254383673352, 0.029252640294632124, 0.0897012810192762, 0.10153881799910339, 0.07790913474896262, 0.003742460168958191, 0.03800692427302561, 0.036152041547240756, 0.02317321742133748, 0.03009813131704446, 0.05084675323638705, 0.08245882367895496, 0.023026390924989697, 0.037628132098865126, 0.05853560234930727, 0.03800709281236895, 0.022951218547419678, 0.004223169328930278, 0.011123841808688258, 0.029483336181710326, 0.08246561121796409, 0.038780259389069774, 0.01896632793960312, 0.058559852862550374, 0.04630161869910456, 0.05860833090639884, 0.06530428410417612, 0.08138798597839572, 0.005395165588256093, 0.039403376154481404, 0.04741143878369082, 0.028270404492955536, 0.01946522546331248, 0.05303024937729201, 0.03955925589487438, 0.03001476371390445, 0.06046695980213343, 0.02518296673623545, 0.13292128039944556, 0.40818099232931293, 5.302381102115878, 32.5690673243615, 52.53794800850653, 80.71287032096618, 84.49261526907645, 72.3862668006651, 82.85449227979107, 78.22844889856155, 72.77926475771012, 26.665725669553204, 35.10833917125579, 33.00559966794906, 30.160337840357137, 45.66363734583701, 89.87309517398958, 134.30391588518697, 95.60971844580867, 109.6275241913334, 110.1359575025497, 56.48126363754273, 40.16287403721964, 14.589653976501959, 5.545766622789445, 2.3680165073563977, 0.8731916739094643, 0.7046537401695406, 0.7701174854751557, 0.7385905159096564, 0.8836310621230834, 1.6703778649530105, 0.906600461852166, 1.023773119574593, 1.3115360299425742, 1.6093095031476792, 1.5001034856803956, 0.48902640419621624, 1.4481192106200804, 0.9244847538009767, 1.9275188926727542, 1.5708344838311596, 1.5928976934763694, 0.8505058492864332, 1.7858616358810857, 0.5743757695440324, 0.8338600457195313, 0.5194911468894251, 1.694063955257016, 4.663923180872395, 13.804644538510232, 44.918551752644206, 75.46189138966223, 95.20867178517004, 148.06106444328063, 120.44105160620906, 81.37291108408283, 59.055711300142356, 42.08581209182739, 33.30185628706409, 39.37870594762987, 52.243491757300596, 77.10181082448652, 81.32010029208276, 94.16765905195668, 79.4866354234757, 91.83701807452788, 98.35763685164913, 80.19751794876592, 55.20125696735998, 37.37762251207906, 15.056731777806437, 5.254219789658824, 0.638719923313587, 0.24184237444593062, 0.010933319572359325, 0.06934656235840052, 0.025624183584905924, 0.023658152992626833, 0.01596002751255348, 0.047313268446633895, 0.03769813721338588, 0.04107337888149966, 0.06577702164049111, 0.06498952155872699, 0.027002147849529024, 0.04207589303053195, 0.08765361226734616, 0.02884625171821925, 0.027585251842655485, 0.009246867979996869, 0.021794385562140136, 0.12102072502696708, 0.022920507997755083, 0.0773710116083103, 0.009593649170241289, 0.04722059479043369, 0.05616901885537852, 0.06082528210695713, 0.020911515194682345, 0.02347748264700415, 0.054505129509996024, 0.02566276951843212, 0.01943399397385938, 0.04390624179054172, 0.0184863910920197, 0.028544568208857413, 0.04838546595325874, 0.08835485084883629, 0.06642338534396502, 0.10016014318793051, 0.01531681051522854, 0.024425367066156, 0.06604697570324906, 0.019980842855969266, 0.03063816201662825, 0.056756995167703404, 0.018682297011236512, 0.04455562771087693, 0.08155040427922242, 0.03729488385180312, 0.03971564508373699, 0.08074546037542243, 0.029642856754963438, 0.01732699554263344, 0.054682995973815846, 0.04378176782460463, 0.10760917613703398, 0.04642797724133538, 0.022918248038378455, 0.04955878323544899, 0.02355265693979398, 0.017032490277122107, 0.014277611288332171, 0.035029749551247207, 0.022876569024857976, 0.07040231578773068, 0.02948740985424769, 0.08143037362324615, 0.058605442754924304, 0.04368066720123734, 0.002698273230869804, 0.08219229402921854, 0.005991926535047712, 0.02967276865796697, 0.06278960049272546, 0.02132737836349876, 0.029051011698620937, 0.022719176260814555, 0.05303170494434815, 0.06686428426614692, 0.03694614913735179, 0.06349160516213986, 0.03508281646176212, 0.030145059948066072, 0.03204561875111634, 0.025349983479827646, 0.031136800985663172, 0.026468824249722307, 0.020956471149298935, 0.010844571159161147, 0.074507252373282, 0.01046865564515634, 0.10621418365307393, 0.029223879438734827, 0.05266364566200683, 0.1538489332362529, 0.015505779508290993, 0.04608074788965526, 0.046532360551458214, 0.053211632184684284, 0.030174533265732953, 0.013457711433030426, 0.07448240048101834, 0.04556297204427181, 0.02965534398812921, 0.1133489060486036, 0.4277041302092614, 2.1756899501046827, 31.65736140743379, 62.28634403597925, 96.19077051839521, 97.88002552524691, 89.04266665058752, 94.09868809484666, 92.64313574760192, 106.4612457829137, 61.53705758433188, 58.13551933534684, 63.034720497746626, 44.61021031102827, 40.24378861150434, 62.87029081775297, 50.40719101505895, 57.48781050405195, 78.2856684346353, 88.40929015990227, 63.56904537447038, 52.32577131640527, 22.244916385219945, 9.07128510936614, 3.2298406622102185, 0.7494201186683871, 0.27853084607951106, 0.39761804945526585, 0.7659475156857122, 0.9681285376990996, 1.278813289057824, 0.3635517129253957, 0.7958742195079405, 0.9278472669182286, 0.8447489743271183, 0.3523244798904465, 0.27064369510739084, 0.6672905289357709, 0.8736642582281944, 1.903483098553073, 1.473330980347049, 1.6246820072973929, 0.8474479940149092, 1.0518089345385953, 0.26999111076997173, 0.31124102312230295, 0.4774897942139257, 2.091478378542008, 8.257011848111308, 19.345672938131518, 49.59935926621961, 71.37962971964191, 83.15197267839986, 102.9002514193135, 72.62728075827323, 47.658523436515566, 25.09329257472869, 35.04168633491763, 40.94881896049746, 67.5590842769992, 87.13688896548364, 103.85209298902943, 104.53183189515146, 107.86891383509483, 95.34051049140193, 109.63922069918726, 119.97499558233447, 94.07451844984486, 64.21236115117227, 42.644094805563654, 18.263108576497725, 5.283038914203644, 0.43564778782667657, 0.3560443577026168, 0.04330136940904683, 0.043364265227630254, 0.03719281795765123, 0.028276510213712053, 0.02130033929021128, 0.06876085749677113, 0.046089377870122274, 0.07670731899598915, 0.03806631140891583, 0.03817027337068031, 0.019681748723791494, 0.045268522320134987, 0.061754485472075404, 0.059466571547091014, 0.09092084702945526, 0.028950077699377175, 0.08570607886799882, 0.03283769620822803, 0.0394100334585434, 0.03491460270578823, 0.026475374301474904, 0.04123464422000032, 0.09919604451786126, 0.035812836966567466, 0.021084241208530242, 0.0515550819616164, 0.045825851285049034, 0.059446729869852145, 0.026903469979222265, 0.018663629363741607, 0.03002194770341439, 0.0830585326278402, 0.0392924657752437, 0.08326084878776344, 0.026995002164415298, 0.03172789719105969, 0.002598600164468911, 0.07256562551183086, 0.05694130826140604, 0.02769711600135892, 0.04221739330058617, 0.06710881953157725, 0.05248236244604473, 0.051888920096380096, 0.03284234253148879, 0.02898951207527951, 0.017005499084329894, 0.07912095561022721, 0.06527043067880216, 0.002630956845560802, 0.025797685262777155, 0.07509199962500604, 0.0634817149670374, 0.14631249731586826, 0.11148860708119408, 0.11166601772269896, 0.12485074330001109, 0.13782093361500772, 0.15087994416394543, 0.10996699558510897, 0.23109875739582125, 0.11097297628199863, 0.1535961395429988, 0.08432072377012623, 0.1098057647205649, 0.22641927784969731, 0.22495004378499525, 0.18213712820603004, 0.22202165737267465, 0.17164733140699326, 0.20402185468664094, 0.1013834553680593, 0.06551648279832256, 0.1418669657000611, 0.15465350941784922, 0.15113917299576346, 0.16124255504579316, 0.09245753513589021, 0.13783982534322048, 0.05649753650950809, 0.18685698058576355, 0.14182525987346328, 0.09807509700617484, 0.16117025166749954, 0.13583351767832233, 0.2382933955279089, 0.1493569000834419, 0.16299645206139934, 0.29169802824335717, 0.18523342576959442, 0.202184101686843, 0.27392895591835825, 0.13375173503112409, 0.1573791736436467, 0.12408047253566405, 0.0963294814010301, 0.1513726153080502, 0.11952834744607249, 0.13787880389680787, 0.1448201733611284, 0.14348718037288036, 0.1745555390633883, 2.6526401119847454, 16.519693482306696, 64.18606950390723, 94.554608714196, 122.53216128195487, 113.12164998823597, 97.62023125925373, 104.85084610600626, 102.69817090803578, 96.94399895206575, 39.963417591587195, 52.632112349233324, 44.24850894558815, 42.60027408599854, 64.99439154901813, 110.43681113950669, 178.5327031535487, 131.3902538053451, 152.5097853137601, 169.902249305479, 85.2440707914291, 66.63038469129994, 23.62675759100145, 9.569663424645702, 4.073103671112369, 0.9080077960125862, 1.1234406069401772, 0.9577165447896527, 1.1221487988387386, 1.3894705834888643, 2.0069725066423416, 1.2705774148625713, 1.5852256599933872, 1.35464851654345, 1.950740549833544, 1.6908401346975759, 1.2496865036026126, 1.7839141790905308, 1.2970591745068951, 2.962604679407612, 2.390013404430882, 2.56415119574916, 1.4654259335610176, 2.169422002569322, 0.6487796383519328, 0.9021033418755379, 0.9107821987521265, 3.1972009039694265, 9.202925735904325, 20.766806487114202, 72.54103568292433, 117.23789507342924, 148.24900873245733, 208.885070431617, 172.02337295778338, 116.64353832121819, 87.99981824813351, 62.876692125874186, 49.780219754865094, 53.27683625682708, 69.49673514212333, 99.3464114589076, 108.13182246300482, 117.02593018931728, 101.0067036844069, 115.88177481005269, 133.12929153442383, 117.02878567480273, 84.3788194656372, 59.935032167742335, 30.101629764802997, 13.314208042237068, 2.3606958937260414, 0.5195366218686104, 0.09795900404212937, 0.19062755809676266, 0.3014301947287975, 0.08212625725014557, 0.11830369461207621, 0.11745526755769407, 0.18328716407620138, 0.14443584237127535, 0.2509472987824871, 0.13920477951966947, 0.10456315692394011, 0.15279069002116882, 0.10901988874520026, 0.1713365142143542, 0.2155417792739407, 0.13361040713085284, 0.23631714915315952, 0.28484739423278843, 0.10205139210748096, 0.11473331119745009, 0.13567176587398977, 0.1488673392563097, 0.15307323856940194, 0.12834231924986647, 0.08256740132046324, 0.14071100030935582, 0.16628091614092552, 0.15324484226444077, 0.135349442040728, 0.12339660882829659, 0.1236979112089161, 0.2019839229122285, 0.1668374790179153, 0.19961861112425405, 0.17188074307576304, 0.16404649813569364, 0.13512048900367754, 0.16228726914813443, 0.12681971950035903, 0.12535438482319156, 0.1378773789732687, 0.13673593860960778, 0.17731788357900036, 0.1866835842449819, 0.2460680235057108, 0.12681571286051505, 0.09868395304487598, 0.14331704756665614, 0.1984040553290998, 0.14096627612748455, 0.11958306144562461, 0.15621701826251325, 0.26006883190524194], [0.03215627249089941, 0.029720517003067562, 0.06694380419268724, 0.019471792752043377, 0.07987577438114152, 0.0175180597861688, 0.040601602785529635, 0.051990518676898176, 0.002339638027009524, 0.03351537375560692, 0.03691051072711426, 0.048220665118987524, 0.05344725401711561, 0.02030327585676024, 0.052316477597360654, 0.0035218546174526698, 0.061054779066433834, 0.015240736069127679, 0.10108769180313235, 0.05451808788723523, 0.0857910686623185, 0.03919413455972268, 0.03312073505273269, 0.027670592122200518, 0.013765255515013012, 0.04447253398416985, 0.07659235218119237, 0.04747592806515675, 0.01814843331944318, 0.07754649170824597, 0.018109008519639893, 0.05725833076623179, 0.059595258996611646, 0.08627633939707473, 0.03348001113702213, 0.038071815750651786, 0.04079854866910366, 0.09854668541060341, 0.01827659791395549, 0.038857963687229546, 0.03152081404902762, 0.031184020730096008, 0.03273735018146615, 0.031008873878407384, 0.056747828925689386, 0.03592274760106399, 0.09403355419635774, 0.996073586565833, 12.745263345779913, 41.01735453451834, 58.881730648779104, 62.368215668586, 37.320771678801506, 54.94456137380293, 67.40688062483265, 83.09208593060895, 72.80224200217955, 51.022285338371034, 18.843727227180235, 90.39109122368598, 72.15759261961907, 53.81244374859718, 87.70468342688777, 68.63981493057744, 70.3007661142657, 71.1206199276832, 71.77800916856336, 26.097076131451516, 4.521396015920947, 0.5207468569278717, 0.40634210551938704, 0.23491117862924454, 0.1422438809588071, 0.13930755787559096, 0.3994491221683641, 0.2613035817780803, 0.5929504599302047, 0.29206587302107967, 0.7485785251182895, 0.9370061238446544, 0.3680230617042511, 0.17347483415036433, 0.746020588182634, 0.4967771915178146, 0.8513805991218937, 0.1426547492343572, 0.8647007843659771, 0.46485838330080437, 0.8173035373610835, 0.6947757411868342, 0.9609232662666229, 0.602762452777355, 0.7895099287552219, 0.179245927701554, 0.31169034901165193, 0.06826278543280018, 0.06049838855922703, 0.30434803977128, 0.46511217290836, 1.423977389931679, 0.8624376993506186, 1.0703417658805847, 6.19048954979066, 34.314627955036784, 77.81933784484863, 111.6414337773477, 110.45577187691967, 103.8751486809023, 61.40497569114932, 33.42404596267208, 25.131188554148522, 36.50531876471735, 54.89123282894012, 58.26925646874213, 79.55282149776336, 78.43427135098365, 83.67580521491267, 88.28385276179161, 98.71612579591813, 96.23823904222058, 83.46440515210553, 56.71232261965352, 14.281831268341312, 0.3824699477803323, 0.08434172224013076, 0.04564290565829124, 0.07394755619668192, 0.011582924785362858, 0.15753119613134092, 0.0969671806500804, 0.017677697187830365, 0.04360736407820256, 0.04307613955930837, 0.045513965399755586, 0.050505675570738894, 0.07569507936075812, 0.04041422150969025, 0.07467183104205517, 0.04349284542484149, 0.00703669713637341, 0.025217080631503658, 0.06125653981261196, 0.04254426769611817, 0.03277981826554864, 0.024465050420633728, 0.061545822273699514, 0.006967303934582179, 0.026257826398397167, 0.07598462995261916, 0.05802103258188694, 0.057240339191330064, 0.0268410146611953, 0.0192077586337203, 0.03852805175307778, 0.009022228017960106, 0.02556604708755209, 0.0402023981986267, 0.03316922841833965, 0.00979174514331164, 0.012896978164902859, 0.05558859233954742, 0.030845072788877353, 0.029461707604388078, 0.049466205340239315, 0.006375594858846237, 0.0502850575703046, 0.04839308086722609, 0.0594858271670678, 0.047388494450358615, 0.03405164296348249, 0.03362685487034821, 0.023172872681771556, 0.052119121856747136, 0.057326623674241774, 0.018561804787285866, 0.022486605373541677, 0.011393147569540287, 0.024970925090113477, 0.03487264790061501, 0.022438481645358187, 0.02772837047344975, 0.07164202224943908, 0.008333217157351394, 0.04591654460396498, 0.021829098921209093, 0.06010358131700947, 0.08553205433511928, 0.07160436136708145, 0.05286799961580865, 0.017397326244522008, 0.0358619355416346, 0.0691055894018181, 0.0804277943567403, 0.008236548352626064, 0.04528709612185917, 0.06879284166760984, 0.12322826100693596, 0.019758888032107104, 0.05800160076168757, 0.013654423659787545, 0.06512868909105178, 0.05319323841362231, 0.06494139591532369, 0.08137977351584742, 0.024979491868326743, 0.09843356486770416, 0.041025115342269984, 0.020972940124451153, 0.028918011174086603, 0.07318149891591842, 0.007384065341489811, 0.024848209295962608, 0.040485747308740695, 0.01666405944213752, 0.013817861815163446, 0.0436104131081412, 0.03617679001763463, 0.04280209075659514, 0.08291346621849845, 0.021485200136779778, 0.02601216689893796, 0.08535010079222341, 0.08712260608351038, 0.4322268375225606, 8.095017959994655, 38.38720921547183, 66.91150880629017, 79.50063828499087, 53.26876794138263, 68.04090038422616, 83.1341023598948, 108.14813167818131, 112.03521620842719, 93.6162208741711, 39.73760281839679, 50.214724233073575, 48.64834531661003, 34.38516786021572, 40.38809261014385, 44.468624514918176, 64.75525248435237, 89.55957228137602, 72.05710934054467, 34.281966378611905, 8.090656284363039, 0.553555706095311, 0.3153003391719634, 0.6532985152256104, 0.2714994153188121, 0.02947321807545039, 0.379653042482753, 0.4178228523702391, 0.3507241835036586, 0.48432084701714984, 0.5793818783375525, 0.601604005261775, 0.26438518577525694, 0.14134647024254646, 0.42896376261788033, 0.2519939434263976, 0.41735624353731837, 0.16749798470447141, 0.29985137944740636, 0.3568052362290121, 0.5735610197148016, 0.4307363368570805, 0.9508016513239954, 0.7228649984444342, 0.5372220373922779, 0.12964830763878363, 0.15412149199795339, 0.25732795317326823, 0.11151332107763137, 0.706422790404289, 0.9372793414419698, 1.1799027578484629, 0.4125756403851894, 0.5646153190924276, 8.221332007838834, 42.77875761831961, 72.00122341032952, 98.75871489124914, 77.48415562414354, 55.50320886796521, 30.27722251030707, 31.81136738869452, 45.30306170063634, 62.97275881613455, 94.72999357408094, 97.14609515282416, 110.42655806387626, 96.95166326338246, 98.4146132007722, 105.1509701821112, 118.43988187851446, 113.94104880671348, 102.81741096127419, 69.10099152595767, 18.676373420223115, 0.4566027440371052, 0.027826676791113232, 0.027495062226549755, 0.11635635273470996, 0.10662364232684336, 0.03152732579638401, 0.01635264853135713, 0.008456818740664711, 0.029052379165565776, 0.06697601818990323, 0.05138763046312717, 0.0204993867044968, 0.06900314046370407, 0.0579339896719302, 0.023760735996127613, 0.028483336716289484, 0.03520751642363687, 0.028840686089449355, 0.0704300405097104, 0.038408511393373056, 0.010625938284060648, 0.028188735689787615, 0.027746568892091036, 0.005282265295635068, 0.0031574311405194984, 0.04124456122818013, 0.10926657671769781, 0.04474332308276527, 0.05149265345666678, 0.01231190053776147, 0.051221048474432006, 0.031068965815187945, 0.03615519782948879, 0.04346615492155956, 0.016401333418945153, 0.08263136966214066, 0.010997316642333905, 0.048349609207962795, 0.03482327353389513, 0.02579800127404592, 0.039200730576750734, 0.029193584491769155, 0.04971467829760044, 0.07715269187164885, 0.012324103360785352, 0.030633243732154373, 0.037381018947569594, 0.05698355417999049, 0.02937179186471528, 0.03977936827727864, 0.06669144716955001, 0.03511008536142688, 0.07425025285732362, 0.17458051352971987, 0.23308790469121551, 0.14059317598660148, 0.10381926256682604, 0.0968442235382334, 0.11001184237219634, 0.1377242839624805, 0.2102786633035829, 0.14491666979607076, 0.23675429424451244, 0.14640036760078323, 0.12085658302831075, 0.19342601599712528, 0.1492100716718743, 0.20931110957697516, 0.11916508387413718, 0.13715190903073357, 0.08885598726450436, 0.1692901248292577, 0.2802425316504894, 0.23680516248268468, 0.17522497733514156, 0.15587693651116666, 0.08488956703654221, 0.1050846636175148, 0.126509660734765, 0.17605567711495584, 0.2284517244345719, 0.13821078043791557, 0.2711754214138754, 0.13475514167258817, 0.12232626908488813, 0.21430185064673427, 0.16983262233195767, 0.14143457035383872, 0.12084793389564562, 0.14445327853243198, 0.19484890174240838, 0.21530917965837065, 0.10568650995170879, 0.18703521860222663, 0.13394192401920596, 0.11159883947261881, 0.10274828697044043, 0.16418981786456802, 0.09856575333903875, 0.1781605649739504, 1.3572855750399253, 29.744303803290094, 78.22574246314265, 98.64680182549262, 94.90941847524336, 62.77121566957044, 76.62451328769808, 90.7362284198884, 109.85189160993023, 96.74025535583498, 71.63944751985612, 31.475649764460904, 108.93057392489527, 92.74355626875355, 78.55570793151855, 126.88640794446393, 111.49330939016035, 104.24939770852367, 105.57774759108021, 105.62913064033755, 43.86434808854134, 7.720023682040553, 1.1066469790474063, 0.7629280873844702, 0.6563086891847273, 0.3067951697495676, 0.24112657253299993, 0.6368050712250894, 0.9220640998213523, 1.0268222108002634, 0.9539830612559473, 0.9874556490009831, 1.3315026101566132, 1.060861397174097, 0.6210729960472353, 1.4500533068372359, 0.8598298134823, 1.4900337808555173, 0.5434955007606938, 1.2676846668604882, 0.7370474309690538, 1.3208458981206341, 1.5919786331153687, 1.9671513789123105, 1.1687542786521297, 1.5852863341569903, 0.4075651189252254, 0.4023621868221991, 0.3566970339705867, 0.19470996403646088, 0.4230034759929104, 0.6983207058041327, 1.6342693831651443, 1.105452617329936, 1.50355713261712, 10.769638053832516, 61.127307184280895, 122.18178379920222, 166.1083132220853, 154.53451279670963, 143.49544125218546, 85.27377097837388, 50.96964320828838, 35.55632091337635, 49.98246892806023, 71.0427059665803, 81.30052766492291, 103.45125813638012, 97.6024393881521, 102.54049162710868, 114.27274011796521, 131.84200102283108, 130.23088747455228, 123.3404048796623, 94.4622447413783, 35.248340329816266, 0.6482925902931922, 0.1874432676742154, 0.3059412881491646, 0.2270818672954075, 0.2643995882282334, 0.18675369661181204, 0.25566373441007834, 0.12443945367610264, 0.21688925132395762, 0.10207457392806969, 0.12406272227845846, 0.1580848785177354, 0.18751846686486276, 0.1436801732427651, 0.2660424791036114, 0.0934215495362878, 0.114662065020492, 0.09778603671058532, 0.17626976804627528, 0.12632491097094553, 0.12477133062578018, 0.08696781801840953, 0.1599965743239849, 0.12245887890458108, 0.12501935159126598, 0.1927172161278225, 0.2164312226757888, 0.0828124268821651, 0.14388242045477515, 0.09939434637706127, 0.13806526969757774, 0.18527347684627582, 0.10336102707491768, 0.20642157914417408, 0.1125296746050158, 0.20768677335112326, 0.10236665261008086, 0.20284142044763412, 0.16324316301653463, 0.12457187197381452, 0.12705639470368624, 0.1220787613983116, 0.19110107704276041, 0.14241854900554304, 0.1086648682793302, 0.07848418332756528, 0.1276797298041563, 0.11533085977838886, 0.1767681235627782, 0.1286437978307086, 0.21065268274997512, 0.1311045488522899, 0.17710417569164308], [0.03851066155719661, 0.009874232702948635, 0.023084288019867196, 0.08556753952777194, 0.02426932261685931, 0.03827445366750321, 0.010107164609155828, 0.09035468507077425, 0.03142995985164758, 0.044319534734372175, 0.034098060230814645, 0.05030432851203988, 0.0532390543019339, 0.04851258675297422, 0.04614632501597366, 0.03932128983339475, 0.04306387066120102, 0.0704265701314134, 0.015128329903217814, 0.03537336296792473, 0.027112035501387813, 0.02429611462679121, 0.017635933904638215, 0.026474638857067596, 0.020554455019713893, 0.0250912526051604, 0.043811993823657115, 0.07418927991943014, 0.05528511043878333, 0.02295436716878847, 0.03660277320793079, 0.01007091907423831, 0.03773907695205943, 0.02687218486361446, 0.015287674276248343, 0.026937683465920632, 0.05785871770293002, 0.06407849362961228, 0.057796622446227464, 0.0542289509828533, 0.03212795788121801, 0.07995619063055323, 0.11166663059303839, 0.03426255079947653, 0.0748585419909608, 0.42793447752633407, 12.78750531135067, 39.183297388015255, 63.58295017673124, 71.44132075771209, 61.64100039389826, 52.095485041218424, 32.70921753298852, 62.88898091162405, 41.056586080981845, 19.984895721558605, 17.038691697582124, 18.360100946118756, 47.665599392306426, 88.65360675319549, 67.30387918410763, 81.07881961330291, 77.18629867799821, 48.783051275437884, 28.66137662241536, 4.057210717470416, 0.42460119832427273, 0.29263124590919865, 0.2191231330676425, 0.06635112027006765, 0.26411953712663344, 0.04611388502282001, 0.04022187598410153, 0.16950833731360976, 0.14897836071829643, 0.4633514883537447, 0.21579644222173, 0.3647286384817093, 0.4073891025637427, 0.7067013399735574, 0.12866745462581036, 0.12766986259169158, 0.19329418758711508, 0.3398805460141551, 0.15486770760147803, 0.2733043184684169, 0.6611344915243887, 0.3923493257213024, 0.3086943936444098, 0.5366324561257516, 0.3444613840791487, 0.17773837391887942, 0.39893293212498393, 0.39069264526328734, 0.4005981621242339, 0.22738965077986642, 0.07656661162693655, 0.10362646121892238, 0.3046220847435536, 0.5461266757019105, 0.26739171315585414, 0.07280645291170768, 0.5426148060829409, 0.6040383262499687, 0.6892204392821558, 7.5754421757113555, 34.726974964141846, 90.63556471178609, 105.79267778704244, 87.94397154162007, 77.70325922196912, 35.363830597169944, 21.94017960179237, 26.393011116212417, 26.824973898549235, 48.18505064133675, 63.52598167234852, 81.36797674240606, 76.2312956779234, 70.95694726513278, 78.86751282599666, 86.18780874436902, 85.97363164347988, 41.08962420494326, 1.7525348499897988, 0.23938343139185062, 0.09171076028818086, 0.1023870458706252, 0.038361691929880655, 0.06827037736412979, 0.03053646384468002, 0.09168996100103663, 0.022618767031798923, 0.030539890172921365, 0.038348013429992625, 0.0007128311676018301, 0.012827462389043743, 0.03680189478120977, 0.07283834515199547, 0.013781590424778481, 0.04128007323391015, 0.09325268843601789, 0.051805650169450435, 0.02271763450886694, 0.03854911534055587, 0.045930977700458425, 0.0724259447005968, 0.10650329757481815, 0.04462653297870871, 0.04181908503655465, 0.018377453389187014, 0.020815851880357634, 0.0660393224848855, 0.06330253083198782, 0.018437156536346002, 0.08882912056099984, 0.03145191593155746, 0.08918486881039797, 0.0328561780794013, 0.009384188282814239, 0.08802549432842963, 0.046848486733412555, 0.023093571090289665, 0.06158519153212828, 0.005952417465572756, 0.053517339570868405, 0.019761320361266696, 0.07084329897958426, 0.05239185298823061, 0.01107619784306735, 0.02497333826707496, 0.04216562873954254, 0.021811040313613993, 0.039648999264764215, 0.03995393673258443, 0.06529102312220682, 0.040629526690369656, 0.03330929993441509, 0.006330285067369621, 0.039917831008713094, 0.047203760008297624, 0.019301891687416264, 0.030796885858440114, 0.07124328880660957, 0.06742830883951918, 0.014656445597328488, 0.05549926265713669, 0.08420089229701028, 0.017433202142016064, 0.012221266590659658, 0.041662240025377086, 0.0658244654656418, 0.09925849600544862, 0.017926200788708466, 0.06412204955854724, 0.039789641516343247, 0.03313188163203097, 0.041957888677115404, 0.04988931953125904, 0.029338405752975135, 0.04205528143492918, 0.03229516806201108, 0.02273451908671808, 0.06353740572869297, 0.040415393624214396, 0.04720803094847549, 0.07616242363808617, 0.02525807974199134, 0.006345587194852171, 0.05196258711117891, 0.024457989005191673, 0.03535561654115877, 0.07515599861020043, 0.04108393174265662, 0.030415036993461753, 0.02929990408912061, 0.08109324131040804, 0.04232992012534411, 0.04084266384222335, 0.042209100398805835, 0.027204517635606953, 0.4506061142010074, 7.963253778796043, 36.60947730464321, 73.37675940605902, 85.91394885893791, 74.68733310699463, 69.22294585935532, 44.55785059159802, 84.75558665490921, 64.75104770352765, 49.20817736656436, 41.505748456524266, 30.80317116552784, 33.75397220734627, 84.22037924489668, 72.37762189680531, 55.59068164517803, 75.21260907573085, 50.165945637610655, 32.56899868288348, 3.8868035904822813, 0.3863115722854292, 0.8487415181532983, 0.3094470597082569, 0.12621989563828515, 0.2579802617190346, 0.05003285376475223, 0.11555340832039235, 0.22649656079949873, 0.24534620014169525, 0.8118466624329168, 0.6082355074824826, 0.8877484476374042, 1.0567717133991181, 1.591571564635923, 0.6562905482226803, 1.0253515671337805, 1.0392975542814502, 1.056837903395776, 0.9385625080716227, 1.049762928197461, 1.8853167636740593, 1.6126585944044975, 1.5785828809584341, 1.7476805491793541, 1.270765198334571, 0.9875093977297507, 0.8555151450057185, 0.645071037354008, 0.5565124377608299, 0.30902280021579037, 0.19078914136175187, 0.24017202697934645, 0.36256327564197205, 0.26422326543158103, 0.04613139013188981, 0.07286468325483222, 0.6875962103086134, 1.3602447581868018, 0.21629571704374206, 7.099033055766937, 37.061891325058475, 81.34048092749812, 87.50905913691368, 59.78189891384494, 42.83326287423411, 26.440781662541053, 29.78671050840809, 41.15217816445136, 55.151105542336744, 85.80649160569715, 92.55048151939147, 101.36050931869015, 91.82564320102816, 88.30275858602216, 89.6871042251587, 101.18466946386523, 100.85154256513043, 47.27596682886924, 1.3263587893978244, 0.2562004862533462, 0.017648413476924744, 0.08863979725227242, 0.02293544479705874, 0.056255012224879, 0.02112964915502216, 0.01454984637788467, 0.051225614358460715, 0.0332498821550079, 0.03289400367066264, 0.01872742150519644, 0.06530884998820483, 0.021046354330234954, 0.028559252199146058, 0.021066270701046434, 0.06097407553405051, 0.039604999004833163, 0.018189828880431674, 0.017918105154568632, 0.011352156119931851, 0.055918810708868893, 0.059001667259801785, 0.025519195065322905, 0.06871647802331755, 0.08872510114264104, 0.007326843840400539, 0.0593650917102012, 0.053517810714941834, 0.023430264817791122, 0.059163962986560605, 0.057296914784538175, 0.027747354132213423, 0.04198008607472143, 0.04941756258748713, 0.05358621087526122, 0.10719617813705437, 0.05369077038560664, 0.05695154319607443, 0.056497195600381786, 0.05446777506280811, 0.009253420904579182, 0.03548271435823652, 0.05301374018252377, 0.05631171805303424, 0.03678259702639715, 0.037259613163769245, 0.008986230504008071, 0.028716876704786575, 0.025287989729775057, 0.011240050643532267, 0.027792696961231773, 0.13924023406880517, 0.1687122953514899, 0.10316021244732604, 0.21464112034488111, 0.18460402325276407, 0.0955275022574971, 0.08950941429864015, 0.16614056883319733, 0.3175461412437501, 0.14282076048754877, 0.13665042787549958, 0.1391745190466604, 0.11778768076891862, 0.09651073780391486, 0.12153419545821606, 0.12853268443817092, 0.12689976036668787, 0.15194704335543419, 0.061517124620055964, 0.09682596000211854, 0.16148506783910338, 0.13265915575527376, 0.16395974633914812, 0.11577769588198393, 0.12346113641415873, 0.13702409492144663, 0.10727529203699482, 0.2323886196339323, 0.12628871331652328, 0.10895130089333943, 0.11236609185054419, 0.13647042785681066, 0.09930138926832907, 0.16476395479854078, 0.1126743196659992, 0.10835755976938433, 0.14342033154060765, 0.12105807947415499, 0.16544326028275877, 0.09663912647914502, 0.11641440687761193, 0.13548442673298622, 0.20953485321614052, 0.18927046398241676, 0.3893103774997496, 1.7963882968310387, 27.11724538956919, 80.56314560674852, 101.61029369600358, 101.04377008253529, 84.69000462562808, 80.0924768755513, 59.0995987000004, 98.40022594698014, 63.67499643756498, 30.819050881170458, 26.877684670109904, 31.14132065926829, 73.57260334876277, 125.89007885225358, 95.40875973240023, 127.7298273578767, 114.39497686201527, 73.54315419350901, 46.71698985561248, 6.426807449709985, 0.6418952658291787, 1.2403279735196022, 0.28550371707927796, 0.13845163848130934, 0.5349347439985122, 0.2101064160946877, 0.39793652752714775, 0.508658908788235, 0.43246729720023375, 0.9370462055648527, 0.5713250235684457, 0.7716863109700142, 0.8075509929368574, 1.019868890364324, 0.31252700895551716, 0.5367242641025974, 0.29693972439535204, 0.4005396023633019, 0.3943668335916535, 0.569826616875587, 0.9184328430602628, 0.6123152627579628, 0.6448060322192408, 0.8685133281734683, 0.6948977636714136, 0.7908461699562689, 0.7022922281776706, 0.7465107005930717, 0.607991278652222, 0.511924281956688, 0.4558074221976342, 0.528401791328384, 0.5353232425066733, 0.6498147150681866, 0.32526515123824923, 0.14518699158103238, 0.6118417591337235, 1.689200338817412, 1.7435138888897437, 12.129907204258828, 54.68472788410803, 132.34883400701708, 159.19832075795821, 128.77161672038417, 109.88391384001702, 54.54659769611975, 32.41181362059809, 34.961450330672726, 36.20098206304735, 70.52627102021249, 88.33529072423136, 102.09287858778431, 95.47177653158866, 90.13722758139335, 99.01675978014546, 113.79652515534433, 121.53622442676176, 75.81885845430436, 5.136347663018012, 0.6845116338902905, 0.1954786413379254, 0.21117671753369996, 0.20657649744422207, 0.23260628053497887, 0.18504374239954258, 0.21238817833364013, 0.13675968733526048, 0.13549112234144442, 0.21408921528247096, 0.1152376575215209, 0.10803139017474268, 0.1794653659265849, 0.15499250332434333, 0.14357494340548593, 0.09366046171635391, 0.14159688906323525, 0.18893085720558322, 0.11373703683456106, 0.11643093139413865, 0.1380370776619642, 0.17979752632879442, 0.278770417095192, 0.15410898944302914, 0.19537960149107442, 0.07088618458158548, 0.08414885960519315, 0.1466289988809055, 0.13088560092353052, 0.18291942655078827, 0.180222797057321, 0.203831190724046, 0.186413032633643, 0.11235087734436798, 0.0940548437797735, 0.14808562313837392, 0.15236679825090593, 0.16487983325796743, 0.1401613015801676, 0.14284951942822627, 0.1483419101925627, 0.1309483435245291, 0.20458966373435913, 0.16999366933539992, 0.12149553866155686, 0.18277986065274288, 0.17007413921096634, 0.0997222473304118, 0.17866754664048073, 0.16903336280055586, 0.10536922697698879], [0.06726252741270489, 0.024829782966163852, 0.039552518151580326, 0.14932225758750595, 0.011017481034110871, 0.011380865264894261, 0.020468373550102115, 0.005882018294575955, 0.009108217557020968, 0.04214184170949363, 0.050645210825267344, 0.022799376090387666, 0.011299160072549937, 0.0271768388789027, 0.09292429718639582, 0.020686599440992843, 0.026915158565726974, 0.02233231909603121, 0.07344090394795903, 0.07652011775081197, 0.010851043644511412, 0.04212540912351782, 0.027174088623254534, 0.02589173979246088, 0.023027637733086463, 0.03388737456031865, 0.018995016017147613, 0.031452917591518456, 0.07223479044173034, 0.0734437461341581, 0.036454136828861894, 0.02881186394651811, 0.016377826010988607, 0.041119210091569734, 0.023397014686657537, 0.05241831749557488, 0.03444572625261161, 0.01731330938186617, 0.039272152953931404, 0.01640312989512759, 0.07595512790665512, 0.02166164550750006, 0.13869505525837023, 0.12932917073128686, 7.8643570984563524, 43.20020452622445, 59.948780075196304, 62.995355590697265, 42.28655899724653, 55.87434353366975, 45.99832142553022, 33.90980797429239, 31.174356822044622, 19.90717591777925, 23.257340923432384, 39.553184740005, 58.70056421526017, 71.47639459179294, 69.6928144270374, 38.68494849051199, 40.99308683026222, 46.35246438364829, 9.57918203646137, 0.825089380866097, 0.4388221803932421, 0.20302757981323427, 0.10665250851983026, 0.10419345821344084, 0.23624792544832154, 0.06638209320484631, 0.3831975474472969, 0.06624652628576563, 0.200732916653637, 0.0731780591811384, 0.10440358080931249, 0.21964031902532424, 0.22780802671707448, 0.2530710783696944, 0.05796279457788314, 0.4873896726677495, 0.2647021010277733, 0.287749182072378, 0.41496460896826565, 0.5389683501374337, 0.2737775156574865, 0.32255513052786555, 0.657776145925445, 0.5610284954309464, 0.2911752192003112, 0.7662386290969387, 0.25888308101604063, 0.18179936004021477, 0.1496455466915523, 0.2214420812144395, 0.10733161482118792, 0.06540467226577383, 0.07891462514958075, 0.14078097478035959, 0.17929258245614269, 0.3401546522734627, 0.4091281221518594, 0.3621780866336438, 0.4897633807793741, 0.32564724525136335, 0.045777036162513884, 0.2744981898896156, 0.1043940966408099, 1.909075172678117, 17.142856121063232, 52.178188216301706, 98.81551081134428, 119.50748828149612, 96.38819125390823, 70.72664137809508, 55.205014597985056, 24.78753205268614, 18.949678290274836, 40.588404132473855, 61.371623777574115, 66.89934945875599, 71.05601849094515, 79.77252914059548, 74.34421200906077, 84.44630776682209, 63.36609801938457, 12.085551081165192, 1.1222893912946026, 0.30408539418731967, 0.014528892915545693, 0.04224137185261615, 0.05561569269986884, 0.08298823639990822, 0.06794353361211478, 0.08058999049206896, 0.032482495711695765, 0.050524406420487555, 0.043012148234993226, 0.007041940529410157, 0.05358089422506671, 0.005537269152550688, 0.03623664829759829, 0.008539145421837608, 0.042309764352056294, 0.0744823238722259, 0.06957707821481651, 0.015269619499092862, 0.016864337808182164, 0.01812284598277221, 0.043802597755265814, 0.02337765564481097, 0.00849355265663396, 0.020715695460357016, 0.08439881111224813, 0.04074557368913966, 0.03010246737469589, 0.03337219192255889, 0.03239561368020312, 0.019204269103225202, 0.012546209487012558, 0.04266741632994625, 0.038460907976954214, 0.05314811583488219, 0.03634617205769305, 0.04029973733028577, 0.027815128015654705, 0.022813269094894492, 0.04139993152010345, 0.043919832190318454, 0.06984860275781925, 0.02898175351982636, 0.03622526040060386, 0.05326299454956766, 0.09718193807789395, 0.029737194737179146, 0.04519491659237012, 0.0597315383774619, 0.042702445700283975, 0.039117211671245676, 0.0410491360291358, 0.05156632430190521, 0.020998134841060927, 0.0857462525187481, 0.02203204901888967, 0.040548758040512764, 0.015106044405500497, 0.03949277861524494, 0.035905740449144956, 0.07192136088926947, 0.04910709779529322, 0.07167890938299318, 0.0633441562193536, 0.022493203305789543, 0.04574856833524762, 0.03992048167293111, 0.07010364108869145, 0.010676302819422657, 0.018722641116548932, 0.050791564262321884, 0.014552520024740409, 0.015040656885943346, 0.012178017096894403, 0.010425633104938653, 0.026057549947572332, 0.09904326360312202, 0.02229935624786923, 0.06378828037169672, 0.031050947427208868, 0.04539323760376823, 0.049175011489780686, 0.00274065058141376, 0.050191954904866797, 0.03109309758480278, 0.03300392962691765, 0.02171015802530512, 0.0688383472903121, 0.028094847784227425, 0.08180997785060637, 0.07924119310994303, 0.1673489652814404, 0.05780191611378424, 2.478945548495939, 31.43262528604077, 70.2512893369121, 77.38260546038228, 56.24406614611226, 73.28533680208268, 79.51210729537472, 70.54761655869024, 46.968876623338275, 47.88540901676301, 33.37958589676888, 17.938322597934356, 35.338711738586426, 31.657859548445675, 47.13496154354465, 37.10571596699376, 42.240839850518014, 47.23595080837127, 14.972472402357287, 1.9190017109917057, 0.28624988671752716, 0.10608706668379808, 0.10633135680109264, 0.27220921110241647, 0.10302056227960896, 0.3048736986614043, 0.6747351262357928, 0.7301161738653338, 0.935909882668526, 0.6916736366768038, 1.0141987365580376, 1.5744390194454503, 1.2421133873924133, 1.2267894225735818, 0.42174779659798073, 0.9841428396682587, 1.5454218152069277, 2.377835425638384, 1.6554451565588675, 2.966531462246372, 3.0902636099246243, 2.1959936090054053, 3.3084123557613743, 3.6832178696509335, 3.154255118100874, 3.258087856154288, 3.532141898908923, 2.444240172063151, 2.0264899754716508, 1.230232650714536, 0.41053934803893494, 0.5694607945699846, 0.4588596084185185, 1.0652903659689812, 0.7947414512595823, 1.0598032152460468, 0.9717502949699279, 0.7049047718605688, 0.1642046186832651, 0.5167580516107622, 0.1037642727756212, 0.19676617466874663, 0.23509767507353138, 2.336284532662361, 19.148677779782204, 55.100024515582675, 91.38220356356715, 84.78214894571613, 57.79856420332386, 51.54675722122193, 35.821018142084924, 23.409779917809274, 39.31880351035826, 82.791028330403, 99.32242224293371, 97.09062499384727, 97.10561629264586, 94.23385297098469, 86.2663345952188, 101.20213970061272, 72.44672621450117, 12.708405813863202, 0.5333366233014292, 0.1345316125380416, 0.03648630869124205, 0.0937988631607544, 0.05306458543805827, 0.07488212217727015, 0.019488290455492756, 0.06466037188205989, 0.03863241208056289, 0.030567969210566055, 0.010612146786203789, 0.027150202001775467, 0.07061306657570024, 0.0498298213126198, 0.024309130460624735, 0.02706196399465684, 0.009336074130729803, 0.06053053360852984, 0.05717537110491146, 0.03371467152910848, 0.019418224053938064, 0.04225404294688375, 0.02503798842700499, 0.07281415975622593, 0.017238219358748006, 0.017711179060561043, 0.05960634811931561, 0.08686870922364535, 0.028336085041143724, 0.03535970745067443, 0.018274895283543778, 0.0371974834331101, 0.026359204728637012, 0.05847914933016705, 0.02427690688730969, 0.050455738129394676, 0.017956242926659125, 0.04395765012070056, 0.020759887242269133, 0.01831915026770965, 0.0080347990977668, 0.022116023746709672, 0.040935130654684, 0.03126967702090981, 0.018033114104201237, 0.013011882735055783, 0.04950994513027611, 0.0284606815811487, 0.056530030128816446, 0.02585469944132192, 0.18081323634232246, 0.1147156298881577, 0.09759714241109549, 0.2693444099878111, 0.19172407506454378, 0.09975744140965324, 0.11878998424377173, 0.16029079805218405, 0.0811846509215332, 0.21737090612371124, 0.13895704200671566, 0.14731328393663132, 0.14940390723847574, 0.16849178460336503, 0.21717117168009284, 0.09429692756384613, 0.08385681156669894, 0.22574392537916863, 0.21422496606265345, 0.15137425473620816, 0.06432833405391825, 0.1671617640362632, 0.15117562345920071, 0.11124574188743869, 0.12838215582192908, 0.10539706661215714, 0.08673072146672396, 0.09364988204211959, 0.13071765912876976, 0.14775884067339284, 0.11990114115178586, 0.13786175077961338, 0.195426915081278, 0.12932773048598922, 0.1644397463889853, 0.1748903041645404, 0.1510593619558119, 0.12693063371003638, 0.19616012251184833, 0.1777112544063599, 0.1470551889149412, 0.12742076910311176, 0.35319582829552315, 0.30813220768205585, 14.383617754905456, 67.74663632915866, 102.3150416343443, 89.61183394155195, 69.20357719544442, 83.72913375977548, 75.22191293777959, 60.028490481838105, 54.92979757247433, 40.813371673707046, 41.956334652439246, 58.474447419566495, 87.6538573541949, 111.83059400127782, 118.13813394115819, 57.82650324606127, 64.91973707752844, 71.2423389188705, 16.451128490509525, 3.1852528741282806, 0.9594705184140514, 0.3531915075596302, 0.29354148093731175, 0.46591319444198764, 0.3769008562930169, 0.4015694390381537, 0.6111000021619182, 0.5414210572358101, 0.7388886773297865, 0.6639635622982056, 0.795869377832259, 1.0154692167716644, 0.5940970790482337, 0.4837574966011509, 0.18727595407155254, 0.39001082701067774, 0.8272161635179675, 1.0114550999095364, 0.5422881461920277, 1.3533768105891444, 1.5628907036396766, 0.6845074663719823, 1.1372582590387714, 1.5983181639063744, 1.3670570571576397, 1.463883829212958, 1.5811749547719958, 1.7212065117013071, 1.0259821494260142, 0.4215974595037199, 0.22048577365856017, 0.21587579360892697, 0.16080718727842455, 0.2641458905512287, 0.24824135365986058, 0.38569790521456354, 0.49377366720188054, 0.6935758636363092, 0.8456610479662496, 1.325899259217324, 0.1749515145896904, 0.26331082407024603, 0.37990873198836084, 3.6892960725292085, 24.13583613211109, 81.47207644677933, 147.7989089104437, 156.47906703333703, 132.92631672274683, 101.09618863751813, 78.78542546303042, 35.5962545641007, 26.13010052711733, 59.119234085083015, 80.54196480781802, 87.43049406236219, 98.16777060108801, 105.18273353576662, 95.46917207779424, 114.24926081011373, 99.26258256358486, 27.727419099500104, 1.6548499368852185, 0.485737772598382, 0.27912572867447333, 0.17505302123965757, 0.2559631368926456, 0.2675543383004204, 0.108381875400101, 0.13832198576100413, 0.08005840974228998, 0.13456735820058854, 0.06338206991072624, 0.1285137084402865, 0.12645421129080558, 0.10464779431781462, 0.13839410527819587, 0.12903640257014384, 0.2602361455079048, 0.15855669674854125, 0.12258362100129166, 0.09015975399844109, 0.08405463079050665, 0.11919799501136427, 0.11145230983534168, 0.21011763162189917, 0.12764281202708522, 0.06455654398568215, 0.11525397519430808, 0.15961809624587336, 0.12430730350916425, 0.10844816498818899, 0.1323391761510603, 0.09085228216023215, 0.11893766301293528, 0.12177639415547734, 0.108111699171845, 0.17741445662273517, 0.05905910087148509, 0.12131076591509966, 0.20210985244522173, 0.057100443875477205, 0.13700042280458635, 0.14569035731256008, 0.14173734362327284, 0.15884405632893886, 0.1609654610435809, 0.1433678698395529, 0.20188037846838275, 0.131256663270535, 0.15061604219578928, 0.17071155500748467], [0.024992408110730113, 0.023216103023338704, 0.020720562033896005, 0.02891756109743109, 0.00981093468820496, 0.10108919333546393, 0.01941264501862949, 0.01859363382531991, 0.043864926668785276, 0.0805986243029756, 0.0010047544774058606, 0.04910063201321229, 0.010547459279487451, 0.04748751514501149, 0.04043495950980052, 0.021924783302951726, 0.01620160663620599, 0.034111420804214095, 0.0183236337972865, 0.019020695284369494, 0.025480000091896906, 0.08967399296741332, 0.024724047510854663, 0.07904176510149434, 0.009333788315885732, 0.0574394531037298, 0.01562292009757291, 0.0802296916804006, 0.057337831540573994, 0.10745703873615112, 0.10504237556409453, 0.028714708675960862, 0.03599580174552337, 0.042275715574261644, 0.05371604362622865, 0.08671203658225075, 0.05418870838419084, 0.09263524455168555, 0.05174008453445089, 0.07377991317621163, 0.09612859016464603, 0.09172487162774609, 1.5996249260440951, 23.197764042885076, 63.84168932514807, 72.15107364039268, 65.94690384403353, 61.08618113302416, 64.97946693051246, 46.88816601230253, 28.360268031397176, 17.64016559047084, 25.526239871978763, 46.65787581474551, 42.3098421865894, 59.47167081217612, 62.427976900531405, 56.78503944027809, 60.53496260796825, 36.30142219604985, 10.564738338993443, 0.4244691247661268, 0.3310993091473657, 0.18072029455534874, 0.10734248560883346, 0.49564678282026325, 0.13321273088935884, 0.024959230757949334, 0.45513810649994885, 0.159960798017921, 0.2770391196733521, 0.12005121777615241, 0.38994224681969614, 0.2938649845459769, 0.4317779406424492, 1.817120229524951, 1.0752585794656508, 1.3160181958829205, 1.5350220184172354, 4.677617646032765, 2.586291994779341, 4.167517327493237, 5.9335782258741325, 8.548638109237917, 5.345746336444732, 2.6506872619352033, 9.144186281388807, 8.868715282409422, 9.720169671120184, 6.344571036677207, 4.214405340533103, 1.855001622630704, 1.3666727874548206, 1.555798200349654, 1.4076046813880245, 0.27118679015867175, 0.5965516860446622, 0.21939777558849705, 0.5365152140298198, 0.6072392867457482, 0.2887092434590863, 0.0307054819929744, 0.07972914515243423, 0.21097496061796145, 0.10844451840966941, 0.20043936708281118, 0.08560991185086389, 0.22620138712227347, 0.3389613324355695, 0.5237667755253854, 13.842668975553206, 50.108129901270715, 85.85416409277147, 77.78042793273926, 85.12563090170585, 95.56967104634931, 60.80010306450629, 20.901975285622385, 19.21078262790557, 16.23448323818945, 35.0633809643407, 61.71500767430952, 80.0854636776832, 80.12729183320077, 72.34185772557413, 77.91755399396344, 35.90624732355918, 12.685567813534892, 2.03111163070125, 0.23896297169548852, 0.15608969444949783, 0.05030601007503368, 0.0751638510114243, 0.034780533488599524, 0.009975794894290308, 0.05482124037019188, 0.01703653522136231, 0.04941387004369209, 0.04773078253492714, 0.10617083073743891, 0.06052944193323774, 0.06723156213880548, 0.06764995339777201, 0.04246822963919371, 0.06320916003577652, 0.07970928815343688, 0.05360254003936726, 0.04659569304015848, 0.11124765710724939, 0.05842649610713125, 0.03794433872005151, 0.04680316880225174, 0.08610928626430613, 0.05200543440878392, 0.024144172578329043, 0.027804751354720325, 0.03113135984618097, 0.04526368830533278, 0.00463716946767583, 0.029763979086231802, 0.039250721644249656, 0.02281891899333606, 0.04647556279275206, 0.009543451259002812, 0.06081299022621205, 0.019368072107975042, 0.013746862701560943, 0.04680140296958628, 0.03774665356163056, 0.037174025820868636, 0.01991803705271694, 0.09609240783198227, 0.05526071053839499, 0.0272776005083635, 0.008914263246791258, 0.08301073640224435, 0.017716428678062175, 0.03589107752627423, 0.03225408276663192, 0.04473097374542587, 0.02806784701533616, 0.019085152007098642, 0.044071460142731674, 0.022582027370170243, 0.012184265501526816, 0.09459487447935729, 0.11034361206956449, 0.03165932274573753, 0.02920999409510724, 0.04653780360616023, 0.06193285372348563, 0.014537877211677692, 0.04398630180906865, 0.020693386980001966, 0.03911467208977669, 0.011169117605013233, 0.03630212200204692, 0.03993815532134425, 0.03442829392189461, 0.05961156900851958, 0.05592286331398834, 0.02373484413950674, 0.056742638680002386, 0.07457498220666763, 0.03640321496453497, 0.037452931621021805, 0.04520013365113447, 0.02204292746741445, 0.10301646370921405, 0.023361519917905815, 0.04489902279249603, 0.04147099766639933, 0.04127558012823424, 0.037992533311368, 0.09690983896894802, 0.1679361410318844, 0.05274340307580368, 0.14004359983148115, 0.34448081206890846, 14.118208616010605, 71.87020840183382, 93.65422864114085, 83.3075652583953, 72.27997841373568, 80.60886475347704, 70.92366987659086, 56.15382417555779, 35.505510530164166, 34.0498326670739, 33.96476430277671, 34.24341340218821, 50.332050169667895, 39.61548766782207, 54.61838491501347, 61.71158736751926, 48.370653275520574, 16.076498012388907, 1.1798784881830215, 0.6646730210031233, 0.32648985003752096, 0.24707959664444773, 0.8125118718993279, 0.21804092662228694, 0.31303541554558667, 2.0416876890005606, 0.7326065112025507, 0.7503902924156959, 1.2733998053496884, 2.6191205170846756, 2.7562218183471314, 3.561642290123048, 6.747546522848069, 4.760717470799723, 6.3872420114855615, 8.75026362557565, 8.035987759790114, 6.591899029670223, 9.423361958995942, 8.623642652265488, 8.254741776374079, 13.096984240316576, 8.293363394275788, 13.54600933290297, 15.935445658622251, 12.86297171346603, 9.303596308154445, 8.328004787045142, 6.2894514395344645, 10.271256796775326, 8.787009369942451, 5.433102423144925, 3.940628315171888, 3.5452244743224117, 2.221991078507516, 2.282888081765944, 2.4583246679075303, 1.3421194856205296, 0.15634860152438765, 0.2692129493000046, 1.7558263314347116, 0.770517444658664, 0.2141308138567594, 0.14985522495642786, 0.4278033845607312, 0.31875622308542656, 0.1855014492907832, 13.514563691231514, 54.23814642813898, 75.42894348021477, 47.67957087486021, 55.49573675278695, 57.3606707972865, 31.27481656689798, 19.640690088272095, 32.49889612197876, 37.077290550354995, 56.46235781331217, 91.09435650610155, 93.77361774444581, 94.42307595283755, 88.3670933015885, 95.18183492845105, 39.35129250249555, 13.099245486720918, 0.7742269036750641, 0.26406934304583457, 0.05055499248086445, 0.10096901712278206, 0.05198192700082737, 0.02267529665973158, 0.055275641592039224, 0.015612460124576765, 0.07223854427255931, 0.03191924105668741, 0.04194449746019898, 0.09808089629176164, 0.07812776092079379, 0.07957031214309317, 0.04603472515760411, 0.0353827360536783, 0.03875804666970526, 0.021495004146990758, 0.04614095473962446, 0.019469912006189267, 0.043792887590825565, 0.056234189955097054, 0.041957643528979634, 0.061970897649805394, 0.05917679112885268, 0.05808873943263485, 0.029511631639193625, 0.0031816864418121238, 0.04324507343793108, 0.017572109204446597, 0.008014585389079707, 0.018272788541752006, 0.03655312304955818, 0.051611994633511196, 0.05442024313754613, 0.0162142260195387, 0.042115924955015226, 0.054094288047523274, 0.03646169428623492, 0.028624633973043774, 0.04988997836687392, 0.025542679490641724, 0.027289771730260506, 0.044951373410801736, 0.0522062030711001, 0.013163664862663757, 0.049055674143375895, 0.08644931438949802, 0.12876234227611175, 0.09244762195815003, 0.1150820957076165, 0.12650883335980678, 0.0981331128446806, 0.19664084268433435, 0.0871768374476702, 0.0878583109607139, 0.09162647529475151, 0.17562332773400893, 0.12137977511531885, 0.12708342228565486, 0.0855716304372876, 0.22482060556930883, 0.20889906152602167, 0.10896557311136877, 0.15627424503045698, 0.11750514754244398, 0.20710143621169752, 0.1850158414773403, 0.11299907965886016, 0.15317777892754925, 0.10453414517424761, 0.1583650062281278, 0.11360591322544122, 0.11521649817305228, 0.10009075860462843, 0.25650791733735995, 0.11361666143901887, 0.163135236549762, 0.13066916576316281, 0.0869784819623155, 0.20258231418988398, 0.1929435797876889, 0.16673797951830974, 0.16206634471253042, 0.09690987727334423, 0.2925619915608437, 0.15245822318378957, 0.21123973592635126, 0.24901720154429638, 0.46448477754189127, 3.5279873734520333, 39.79988613436299, 100.52442473749961, 105.67498314765193, 95.7352029123614, 90.5027218787901, 97.52214847072479, 72.69948374840521, 45.23109405271469, 31.714631934319776, 51.125616258190526, 74.03629026105328, 67.0672425916118, 91.90599687637823, 108.66818304984801, 96.60592986691384, 87.43971947700747, 63.939681899163034, 21.580402158921768, 1.0832222166561312, 0.9258673279996842, 0.7621282303044874, 0.2153598180701656, 0.6783547997474672, 0.3058278152058202, 0.32345485482965747, 1.2871647505990922, 0.7170344564703204, 0.8740187424325174, 0.9368609961482787, 1.6172719145974808, 1.569858916824864, 2.6455416025653964, 5.981519885601537, 4.6691703315704105, 5.101043389689538, 7.8961822294419814, 12.807105395101733, 7.935449077237037, 12.776203982291683, 18.58561173562081, 20.70365240496974, 18.792869775525986, 9.058700184668265, 18.4316449780618, 18.614239154323457, 22.846629542689172, 14.291977459384551, 9.480891362313303, 6.331411975045358, 7.0437511705583145, 5.668354909266196, 3.839508141240766, 1.690664240910161, 2.601906214990924, 0.9165589919974728, 0.8481176774347983, 0.9740613677328633, 0.564662877830767, 0.1651421264414826, 0.24069295144609867, 1.0075674181984318, 0.38919809965356705, 0.27366477815854934, 0.21237834176469236, 0.4578743580608599, 0.5226485935911056, 1.0977420955896378, 21.62458765891291, 79.38051962083387, 126.27538111902054, 114.79326217405259, 118.77777837937879, 131.7122490175309, 88.99501769773423, 33.28472337415142, 29.528628356995124, 28.603396146528183, 48.49942861064788, 82.44917023566462, 103.14288923817297, 105.84851664881553, 94.44947350409724, 115.45268320268201, 66.09354557529574, 35.776695359137754, 5.977018475532533, 0.22532037068759242, 0.42464495726650764, 0.22204436421875032, 0.21240109457604348, 0.14697041362524033, 0.1554555728310539, 0.17594231142392083, 0.21930261214654292, 0.13178319550089299, 0.15933642103787393, 0.26755240775885125, 0.20929091549929113, 0.16997980314397043, 0.18514423781344969, 0.151127926825035, 0.18759823193953884, 0.18641191414527356, 0.11187285380137545, 0.16248568592052307, 0.21957912392193274, 0.1316682976340094, 0.16918904718852815, 0.19646930027632944, 0.1804245539730595, 0.10028775811435715, 0.13718802241548417, 0.10985770548183112, 0.11420372993715348, 0.1466201735480178, 0.15755004189427824, 0.08453169672359383, 0.13478937048104503, 0.10067874640827218, 0.20644914298768968, 0.08655974596378305, 0.16428819887580412, 0.04516099038864336, 0.12342893007782199, 0.09773811791092159, 0.21033486351370814, 0.188244886756424, 0.11257520321035579, 0.19704742086750848, 0.14519580159216158, 0.0889919602101849, 0.1537304347561252, 0.2747667803158683], [0.08795208778352508, 0.04289691711986258, 0.014412695572020547, 0.054014293146469904, 0.03133212659327734, 0.006837576520704334, 0.0675339600251567, 0.05340988807860882, 0.022738487422165853, 0.06034140182178348, 0.01999456157547332, 0.06428131923800515, 0.03378921954502021, 0.015047723089434929, 0.06711477969562815, 0.039904259761134465, 0.044298203016120585, 0.04938671222677635, 0.044272703779560905, 0.050095657652784745, 0.040043971215885495, 0.07686347069759523, 0.036714844210373784, 0.08300816234681876, 0.05815869858188014, 0.029464314218550443, 0.0465511143838446, 0.07329104182821128, 0.02840523788284871, 0.0509290004359378, 0.06695644464343786, 0.055029803977137616, 0.010156089856830097, 0.11854045408507509, 0.12775070785034087, 0.05462851563108064, 0.10566590218654565, 0.09794445603244728, 0.1219086668964836, 0.04219232690370372, 0.06072403975732385, 2.8425112655085902, 46.768490575974994, 82.29058880959788, 65.78910296963107, 64.40292950599425, 79.59093124635758, 67.62450156673309, 40.72562040821199, 29.11118030548096, 41.760694672984464, 70.96777300680839, 31.02271995236797, 56.392084629304954, 64.84212906129899, 42.39434572958177, 54.01785042978103, 37.8702800504623, 10.657512199494148, 0.8419623141807895, 0.5730603046474919, 0.05761982467506201, 0.14012725663281259, 0.11660432007404105, 0.04863158702069233, 0.12316691268595958, 0.1640781528887249, 0.3174773465481497, 2.0911788075200977, 1.1025707784198946, 1.4874285916166923, 1.1408940510403727, 2.8377480372305843, 1.7886470089997015, 2.0910513304894973, 4.219540703681208, 4.865753641051631, 6.330758410115396, 5.999713799645824, 1.5136862858649225, 2.6408707951345756, 9.35216897918332, 9.547499091394487, 8.975591044272146, 8.190792923973452, 12.072671978704392, 15.980396020796993, 11.533225467128139, 8.968817110984556, 7.4436789751052865, 12.31144920472176, 6.438677032147685, 9.039256015131551, 7.819579810865465, 1.5236936004892474, 3.3815211682550372, 4.352401187342982, 10.207678118059713, 6.552046768126949, 4.985965951796501, 3.969093445808657, 3.1147100271717196, 1.1461492916268687, 0.36586943533151384, 0.11043972546054472, 0.12925099911949328, 0.05704769872189049, 0.042139175723517136, 0.10722839213427036, 0.054769046799910646, 0.17020353146137732, 1.1540124180816835, 20.062276240318052, 70.08920915665166, 70.94447412798482, 78.84155458019626, 144.40110083549254, 120.61737783493535, 84.18863158072196, 84.04122106490597, 56.51713763513873, 16.964802088276034, 44.77332207464403, 66.88996714930381, 67.23167619397564, 71.42294837582496, 83.44582880696943, 83.69082004793229, 65.88464798465853, 30.692413237787065, 5.702551603317262, 0.5421365220700541, 0.0656336636072205, 0.09306534929501434, 0.011996329769552236, 0.034288613110660546, 0.01883153285410616, 0.07546100119549422, 0.02908283307577574, 0.029588847556301666, 0.0427908982120214, 0.05039454685644277, 0.023980630043473457, 0.045629269293239044, 0.03520350595335326, 0.040278129820381446, 0.04673520914248882, 0.0679479232959209, 0.07240479301300741, 0.06396413968515492, 0.022558002852864807, 0.04121584059189885, 0.10292638709107715, 0.03409984904611784, 0.08183895129590266, 0.021123905410809864, 0.015768396363954152, 0.014838479579456392, 0.023958965076974804, 0.11308593870771509, 0.043670451418767055, 0.03032060708069513, 0.05062927236600269, 0.08699466940015556, 0.027333067189301216, 0.01938442616993862, 0.04737357871847288, 0.05633259011853126, 0.00827669135985836, 0.041814974974840886, 0.0022741734198549945, 0.15216501069165048, 0.027080457357148972, 0.05788924630671259, 0.004517889099060408, 0.005188055154341724, 0.030913572540626894, 0.02634952137727411, 0.04703053220685932, 0.02588806065520452, 0.0586412190609882, 0.045265285598654906, 0.05835837939934385, 0.0189976092247713, 0.04182423697784544, 0.032928370374945864, 0.01872203973752837, 0.03541805270698763, 0.02889237978735999, 0.06871318384524315, 0.03034591862571336, 0.03972407971178332, 0.01339901090344234, 0.06124586820782674, 0.01547699471214606, 0.03915597955065389, 0.007935466222284783, 0.03909793306863116, 0.015410217700616248, 0.07435741323617197, 0.07120548236754633, 0.0664887786091816, 0.0745441931329908, 0.03827323558770361, 0.04481140914703569, 0.09423014767948659, 0.041939583006164724, 0.11579999670145974, 0.042861826462490905, 0.036648232865357594, 0.09360829878958965, 0.057787666878392624, 0.11474890874758845, 0.03247909428131196, 0.1304730625763055, 0.07029815081266627, 0.13781258325663306, 0.7630594867852427, 42.11717928609541, 95.52483835527974, 84.4270803082374, 76.86131461974114, 98.15860009962513, 108.33262428160637, 86.74803303134057, 38.209361107118674, 23.269564990074407, 38.67136924497543, 34.650398531267726, 62.49359030877391, 55.67747192998087, 42.519418347266416, 53.28701088505407, 46.792095399671986, 16.087057032892783, 0.3939616343667431, 1.0947304507417064, 0.27106893519240044, 0.20657067517599753, 0.17735700002841412, 0.250076976935229, 0.21702357718060095, 0.3111186635590369, 1.0817737588959357, 2.5288050020894697, 1.6579579249505074, 0.4489757258805537, 2.2698435043134997, 2.6130653581311627, 4.228412124418443, 5.48523856747535, 4.298962325819077, 5.276614562157662, 6.928439861343754, 8.338556943401214, 9.488815530653923, 12.453991078561353, 17.622607100394465, 14.513435459906056, 13.147343550958942, 12.848650159374362, 16.405385809559977, 16.70033824059271, 17.961615593202655, 14.969518857617533, 13.28375279903412, 18.15457659382974, 14.910972579833, 17.908137998273297, 10.262576591583992, 7.478753299482408, 6.489958590076816, 4.611262909827694, 5.853266225707147, 5.481477504776371, 5.647549186983417, 4.88112295827558, 3.799698780621252, 1.282269510049974, 1.5225117413267013, 0.965166106339424, 0.4696944512186512, 0.2480230492449576, 0.16062134966975258, 0.07185933841091972, 0.05190333021023581, 0.03720728935854089, 0.9244683288758802, 20.238082754996515, 63.06052969348047, 62.34255160054853, 77.53827648778116, 113.27401837994977, 65.30898524868873, 41.65992113851732, 28.355235630466094, 58.146482359978464, 40.70053292858986, 69.86380623232934, 88.2140894859068, 78.53895941088277, 84.78946808845767, 98.35305552328788, 96.23580717271375, 69.49152623453449, 25.96068355344957, 2.941517036768698, 0.1826251108920382, 0.015318078390743225, 0.04157910799427379, 0.05949773983429036, 0.04464830136707714, 0.05503513977953023, 0.044231798514843955, 0.06323054538018281, 0.043772873543803735, 0.05219210322285372, 0.044190196110115904, 0.09624134298534164, 0.07069169017936915, 0.02703336401722364, 0.04111731019351752, 0.04569639774760412, 0.05971047478998381, 0.014640423826002067, 0.0030100252901789763, 0.048593945290532806, 0.0767943082797912, 0.10507839701829419, 0.04316115999714502, 0.008051547695011383, 0.05057883696750768, 0.019892813607810006, 0.07245202999441855, 0.032119877568836656, 0.09748779868166293, 0.033607534132897854, 0.025885394669228026, 0.0443926501658655, 0.07797612913794096, 0.059492415523216616, 0.04126667435611448, 0.07450276309804571, 0.020329876344711072, 0.08308965111932448, 0.02246965567821697, 0.02014425324065791, 0.09276104384973165, 0.004907819712834974, 0.06570569885474059, 0.007514258153781656, 0.06408244281286193, 0.16950683578127818, 0.13063159681135608, 0.14106131699537078, 0.1966521807856137, 0.16741492545172093, 0.1199864986683092, 0.261002539867355, 0.13678377313959983, 0.1433938555419445, 0.21166874516394832, 0.17694066188508467, 0.2545593114149186, 0.10291614449552952, 0.14243538761811872, 0.15591969953909998, 0.10581260036316611, 0.09756629205038471, 0.12014229030859087, 0.1100361733246715, 0.15249669611934694, 0.3036578864820542, 0.21095809136186877, 0.1376747793608135, 0.17017409836332645, 0.14695568941533566, 0.0880617149654896, 0.11941402414513212, 0.14479561258227597, 0.17623201523336673, 0.13886333413181767, 0.13247198515361355, 0.22583320526586426, 0.11320501941466525, 0.22449031442163453, 0.30779531285647427, 0.11425962371210899, 0.2535758843465198, 0.22743547815949688, 0.4000367422498042, 0.19587069449405517, 0.35268696205269906, 9.432548149939507, 74.81987783985754, 119.25410316836451, 90.34493277149816, 97.03814368094169, 112.97379232222035, 94.23237031505954, 63.503231925349084, 48.999346456220074, 65.89376357293898, 116.1187251921623, 53.92000298346243, 82.68635595998457, 100.39641426455591, 63.00916233370381, 79.14866047520792, 57.277767581324426, 21.013380404441588, 0.9260819551925507, 1.6764381720173744, 0.2667247570089756, 0.569340059113118, 0.4277637624932874, 0.26914593192838854, 0.14015696552251616, 1.3448408750757095, 1.4751471603108992, 8.821132029256514, 5.4007266894463575, 6.612383117598872, 8.386762872818979, 9.882781332538976, 7.380521460886925, 12.796915077394056, 11.115260643343772, 12.137719585049538, 19.60478275052963, 18.4825946054151, 19.596963505591116, 22.69784619731288, 23.191119547813173, 27.06009057260329, 28.443106528251406, 24.88292605646195, 37.82387056658345, 40.98816033332579, 35.37235782992455, 27.95431644685807, 26.653193696852654, 34.44250506739463, 18.383129181400424, 18.781671408684023, 28.38466125149881, 18.481051152752293, 16.77323941261538, 18.013765465828683, 23.180285961397235, 13.893692147347236, 13.115355641611162, 11.041241595821997, 7.087881757367042, 3.0233602321917012, 1.7537295794294727, 0.3587815898560709, 0.23197074931475425, 0.14609370260469376, 0.23994425371769937, 0.1575620081876555, 0.18609748101763188, 0.2507897144964626, 2.205072915361774, 34.357017009489, 105.41740894317628, 97.51170712132608, 99.90753004627844, 172.4291813758112, 154.46737750884026, 109.9391721910046, 102.53786363909322, 76.43361153141146, 27.188920820913008, 59.38254671712076, 87.67295929693407, 89.48621611441337, 96.26506020945888, 109.1915919703822, 116.51890893136303, 98.94454110053279, 55.90984490609939, 12.266485114251415, 0.5599044299414081, 0.13708026448805488, 0.14107872251301043, 0.17600627976559824, 0.21398203958186413, 0.24543108268370553, 0.1994703731109058, 0.20553140029791864, 0.12307200971389971, 0.10111550079478372, 0.09409123295617682, 0.17227052861163694, 0.10954449043398905, 0.09004461864430098, 0.14001203700900078, 0.1271111316858761, 0.1240416088952653, 0.130991596848734, 0.1325924601405859, 0.1551257413361342, 0.18884721572601026, 0.28665030555379006, 0.1451551376451408, 0.11258996572465667, 0.1675737048349073, 0.12306931308440625, 0.2406192691095414, 0.19000523423235263, 0.30219582300032344, 0.16332185556811674, 0.09657526538977701, 0.1499429267019995, 0.16897373051652986, 0.17466495174073404, 0.1442449179387862, 0.18069455400109294, 0.10020007169054401, 0.1786782105843867, 0.160158280163042, 0.08496358645178619, 0.27289522751685114, 0.11741287991284363, 0.1148508444067932, 0.08380343822101433, 0.15725284574493287], [0.029888675217666937, 0.015461732325474582, 0.04282339183132976, 0.04197857305107098, 0.03022749100871865, 0.06867559957167796, 0.027946261200873602, 0.021540584463265636, 0.04147197825894241, 0.01449020739058934, 0.038229744776242205, 0.024614828270709804, 0.045013334602117545, 0.013888538214227846, 0.02708723148961942, 0.04111631427921596, 0.03251914535799334, 0.04853365034045232, 0.018118781886333903, 0.056797076887901754, 0.04618226220050166, 0.04346226319490422, 0.10418257210403682, 0.028855680345347332, 0.02484270112378703, 0.03528695974138475, 0.012693742699470493, 0.038196825978135875, 0.09864999236719263, 0.19359313041692783, 0.10960425295296217, 0.08922567065324515, 0.013812132435099734, 0.03388941618463686, 0.1787003811689154, 0.07755345544747769, 0.016692617284734885, 0.06409047524474802, 0.1323319442810551, 0.2843499886653116, 12.548528044454514, 57.09696592823152, 85.50428082866054, 72.2523727724629, 66.56385344843711, 107.30138609486242, 64.54997916375437, 20.997200627480787, 25.489614740494762, 43.37174546334052, 67.97651075547742, 58.78819780965006, 40.24758546583114, 36.42791863410704, 37.346655399568625, 40.80180852643905, 13.547918546584345, 0.6415632126792785, 0.06527914109850122, 0.4647303853304156, 0.30064480138882516, 0.07622829953869505, 0.10251933393338997, 0.18101678590380377, 0.0836351823302046, 1.1265108421925576, 0.4550455324351788, 1.6439543279909319, 2.992146500656682, 1.6537907743646254, 0.21969881749922232, 2.5999541003857893, 4.372074325238505, 7.356099313305271, 7.217476867860364, 9.225154788263383, 4.080794948724009, 8.794020606625466, 12.877361909035715, 7.4935842714002066, 7.072872317606404, 7.815304917673911, 5.98711367576353, 6.016840829003242, 13.522498646090108, 6.674619365123011, 10.252701044082642, 17.669504919359763, 10.046501063531446, 9.012763346395186, 8.63947824124367, 9.84673475065539, 21.238522491147442, 16.971099453587687, 10.97576743172061, 15.203733386531955, 7.90527722527904, 9.610289373705465, 8.493944579555142, 7.611732434841895, 7.7567762905551545, 5.054814334838621, 6.6727214282558815, 3.1495649439673272, 2.0155734064117556, 0.4535921104252339, 0.08688533333160224, 0.16635617661860683, 0.2412125429198627, 0.053369729749618046, 0.057205635408360156, 0.006364628310210162, 0.2829749221282621, 1.3830090915003133, 28.91347715931554, 48.31341020522579, 51.050734289230846, 73.11985984925302, 98.13377934117472, 193.4637543462938, 81.72135091597035, 32.140781764061224, 27.86431177969902, 34.0619606356467, 44.57961974605438, 70.56809917573007, 71.43189137981784, 73.54683337673065, 81.94892683336812, 88.9486474375571, 77.16522770543253, 12.688675311303909, 0.74102918827726, 0.03223121504209215, 0.05392270733512217, 0.08633579548087814, 0.09516024736747627, 0.03420238225390354, 0.019128918610212785, 0.11797757864358926, 0.015316072197991516, 0.014541194372389828, 0.03708504470846346, 0.06621516264614559, 0.0692436154631357, 0.036636680259459445, 0.002655295219512717, 0.08676053760873695, 0.04090609209191415, 0.0694698718706927, 0.05334597336308611, 0.033176506253620314, 0.05526923709699223, 0.018386387889603936, 0.05515415536900682, 0.03038108206143783, 0.040492917891711964, 0.0291892790776347, 0.0768925284125632, 0.06877588814184551, 0.01680636410451224, 0.027721630814935894, 0.015256804763339462, 0.06568849251996126, 0.052736898989326535, 0.04896626785217274, 0.05302008722097643, 0.027432131934009736, 0.04817460791297978, 0.00675661395484161, 0.035237501104993206, 0.07367795453436914, 0.007066611433401705, 0.028673964289708004, 0.05834467025593885, 0.023506285637737285, 0.05864801043043694, 0.07635101916328554, 0.06863655207017738, 0.05127820246402295, 0.043519731280544115, 0.08626349210258454, 0.004865022210945045, 0.04171184804891387, 0.04375361409338732, 0.06241171996319487, 0.007196848774554149, 0.047619297589746215, 0.013114715674741855, 0.011276224357706886, 0.022066065237947532, 0.07279298508599882, 0.04829577237908398, 0.05185682867323199, 0.012137982299581412, 0.0481092682739179, 0.030170371493084297, 0.05294073200333984, 0.02517095830802235, 0.028247896829740177, 0.045416526676666354, 0.0608444266441849, 0.1040292242842336, 0.024302187788810943, 0.05041196386540129, 0.03429087307003718, 0.03809212857196408, 0.06035039952445415, 0.047352553435391, 0.01329602091573179, 0.062205194150127714, 0.05227132437510356, 0.04236837773914299, 0.0360244955687273, 0.12010560235789708, 0.2647707731493058, 8.51245032202813, 56.44556222423431, 100.02535020151447, 96.18243155940887, 88.16866843931138, 110.58799497542843, 74.57744398424703, 46.63371401448404, 43.40322640634353, 41.85551012715986, 46.2892436212109, 62.21637679684547, 41.49292622843097, 40.24888769272835, 49.31646223991148, 55.26534849597562, 20.714858616552046, 1.8846999709644627, 0.3568119471592288, 0.16575361782264325, 0.23080773591514558, 0.23164934478700164, 0.4580413345848361, 0.4991262315982773, 0.9095112282422282, 1.3626576287131156, 0.44244942285360833, 0.8843446883463091, 0.9426372990973535, 2.4023080737360063, 2.1891662334242175, 3.024972571480659, 0.8005289697358686, 2.70234463195647, 2.9065760729774355, 2.8650555783702485, 1.6265572679619638, 2.313442119667607, 2.895903794034835, 5.0924097626439995, 10.892041498614896, 22.460350605749316, 19.370044585197203, 17.00435526909367, 15.497038422092317, 9.036764329479588, 9.064185619354248, 10.183479055281609, 15.526769007405928, 6.77223539160144, 9.729128364593754, 9.076649931169326, 12.350911190432887, 3.2431379873906416, 0.24441669034140728, 0.7803157704972452, 1.5337126822240892, 3.6738429146428264, 4.778898146844679, 4.887648801649771, 2.6419717554123174, 3.7103869020938878, 2.0410143896456687, 2.581166192408531, 1.6706230130887803, 0.7632950741437174, 0.7901057612992103, 0.7581557273384064, 0.7606011412797437, 0.2154460489269226, 0.16132282573849926, 0.04199007586125405, 0.26397609482369117, 1.7611194474081842, 31.868224105527325, 52.273446898306574, 56.5590520828001, 70.00498802431169, 72.71353367836245, 171.32297885033393, 73.28345406439998, 23.209566454733572, 44.57937263673352, 61.40510120699483, 69.55535104197841, 86.18916588444864, 85.39053209366338, 86.38969313713812, 97.0563199443202, 102.62503439380278, 85.71735966590144, 8.808190168872956, 0.5185381947986542, 0.05203366857923327, 0.011399385440463742, 0.06439850770778234, 0.07784768683655609, 0.0293831606095116, 0.021641947471746997, 0.08865852810202107, 0.023291022591893713, 0.12905460481922473, 0.023844929059006037, 0.04941014302594047, 0.06411893541113504, 0.05779161223120267, 0.13259252142761985, 0.029039857458443414, 0.03658291620893344, 0.16543161574630968, 0.04099932499229908, 0.02702257366881015, 0.02190872610005881, 0.008684572850113675, 0.01486367333845626, 0.03883754361360785, 0.026381909659492876, 0.08444435503934661, 0.025053515114010345, 0.025147958433315642, 0.06761131958375055, 0.0020174382042305004, 0.07183957334247328, 0.020191101432447473, 0.02207613929415182, 0.03799001671253674, 0.014918099097426862, 0.01790938707399032, 0.04175959447879465, 0.02241032982936069, 0.05590801653001578, 0.09125257842242719, 0.059715952318642414, 0.04489382105549017, 0.08927886013782795, 0.0552940889892559, 0.19475536240685373, 0.18900866109517314, 0.12071769894851793, 0.1692133628192448, 0.11792825790302408, 0.17604069243515694, 0.12670439262423785, 0.15090416786411118, 0.1389559235183462, 0.13579536649969318, 0.1627948483632457, 0.11207218987927323, 0.18668712357119208, 0.12754770987216504, 0.0789437518124619, 0.10438333310547376, 0.15706037381483665, 0.07976194137647268, 0.09727805146887418, 0.2145668098162259, 0.10690020772838786, 0.14815205828316752, 0.19790782953702635, 0.0922002598282791, 0.07788268939381646, 0.13992795119843177, 0.21347246853814972, 0.10021804411324764, 0.2522904654183696, 0.3085365488884911, 0.3786769851801857, 0.22943289920447335, 0.18074255707042833, 0.0961302832189587, 0.3101194397576394, 0.26714962937178155, 0.14766504086794394, 0.22026789825289483, 0.24157637339686197, 0.7517628155408368, 28.837861707133634, 94.20674939309397, 121.79896047038417, 99.47365314729753, 97.10979753924956, 130.32793475735573, 84.89367761919576, 33.51686885279994, 45.477469890348374, 70.96589026912567, 113.1148329088765, 109.89579077689879, 59.933926059353745, 63.162836874684984, 54.30325777299943, 71.15766279159054, 24.96883773034619, 2.677082361713533, 0.8947573554131293, 0.4286573887352021, 0.5680099466154652, 0.38253950856385693, 0.3079637296257481, 0.34545055680697967, 0.9835224310236593, 4.162272628276579, 4.117668905565816, 5.87261135539701, 6.59158573035271, 7.5642462603507505, 6.617380707494675, 13.60890846098623, 18.376406238925075, 22.604199609448834, 23.329677274150235, 26.80633479549039, 17.91929910259862, 24.802770460805586, 26.680197254303966, 26.06490485129818, 22.136168672192483, 25.68663735543528, 20.16312626100356, 15.738643677003923, 35.30403014152281, 29.158884171516668, 33.47913957411243, 41.75815689948298, 29.585690998261978, 22.87811048569218, 25.650322091194894, 25.26895396171078, 45.934900622214045, 37.523264038947325, 33.539312654925936, 36.743445857878655, 28.347128091319917, 26.834817086496663, 30.63197735817202, 30.11143765141887, 23.647720698387396, 27.822407137963083, 19.45062379683218, 15.330034686673073, 11.904986731467709, 3.217828158409365, 1.1157922302522967, 0.42196456883703515, 0.5394490856316783, 0.13736786921658825, 0.21464714179596595, 0.1429585030963344, 0.5489504757908084, 2.5978188601232346, 45.21341593034806, 74.376540184021, 69.79537656230312, 93.66266958175167, 120.66017089351531, 203.0914629659345, 94.44422537280668, 52.12326718914894, 41.596668997118556, 50.375137406010786, 62.0998235671751, 92.90930778749528, 93.91505056811918, 96.03638602841286, 102.18521902638098, 112.3874842736029, 112.70063846342026, 32.710643314546154, 0.849570241426268, 0.47607106066519217, 0.2220524847507477, 0.26682244854107984, 0.1483811032507689, 0.1077221817667446, 0.13278899233668082, 0.18542539208166062, 0.19019396765337837, 0.14241352346875977, 0.1232209831716553, 0.12906329225628607, 0.17774912979333632, 0.15462652780115604, 0.21393388329494387, 0.14444351857227666, 0.10458415539394464, 0.21316125297979002, 0.15541216628926416, 0.21555645751856992, 0.14217536205485945, 0.07906648675881087, 0.1247917928342377, 0.15956905129696095, 0.19440907534332047, 0.19941872346305078, 0.2350463471826046, 0.10154102433232531, 0.1495535701753632, 0.10396078198907838, 0.09744844474499265, 0.1027446863571963, 0.12268573286071902, 0.1549524828911789, 0.15430023563244652, 0.07649869027156984, 0.14425515287345456, 0.06878832174885659, 0.13298996784273656, 0.19095997896886643, 0.16427244810808092, 0.16513362286552308, 0.18536620412863072, 0.11260714141591904], [0.02310707338995511, 0.059354477562010295, 0.007421384357111229, 0.054502949989851446, 0.006559520599342162, 0.056828367749168995, 0.03849932728635688, 0.07064349558805266, 0.023481163699480317, 0.07252528332173824, 0.033514136523609205, 0.050864499663153005, 0.037979161246649684, 0.04596237964447468, 0.013781611492196399, 0.014604887880024411, 0.041412185096452316, 0.009365521592929239, 0.05863790190027607, 0.02051323182850836, 0.06856946575064814, 0.006226307783846654, 0.05152668691270294, 0.061346068677882996, 0.02267704334019894, 0.03885896726241035, 0.052592024101965854, 0.018827721566682862, 0.06982545158074749, 0.01204691551280238, 0.03947065782643134, 0.06329812965686284, 0.04014740840742185, 0.031749943286300666, 0.09229706269839118, 0.16446377090629072, 0.015936515316547408, 0.028140824551003116, 4.7551570207841936, 29.812572656139253, 69.29119510035362, 89.61618777244323, 63.39945777770012, 62.602875386514974, 70.40448927110242, 86.13896739098334, 81.30146118902391, 38.53523554340486, 56.236233172878144, 40.87947145585091, 34.61272024339245, 37.70037474170808, 49.10231259561355, 46.95472863412673, 17.010599682407996, 3.0224605385334264, 0.02248244168567321, 0.04718581439867135, 0.015958718459812865, 0.26632485911250114, 0.15886477134641142, 0.11145813210356621, 0.15861897969678526, 1.2156665613574367, 1.315325407251235, 3.3250642880316708, 1.147257483774616, 20.81924073157772, 53.8784376267464, 81.59516042278659, 87.07078133859943, 82.66888572323708, 71.0449024938768, 47.310318946838386, 26.357041020547193, 10.293579005425977, 6.830283528374088, 2.4331258910317577, 2.4254083825695902, 7.321567256604472, 8.895516837796858, 21.850339674180557, 11.642725294636143, 7.17059277719067, 7.367644319611212, 12.191636485438194, 7.80634573390407, 10.500288894099574, 12.63729226204657, 11.331644077454845, 14.594858961720622, 16.24499224847363, 19.79863609037092, 5.724244761851526, 3.4766813007093247, 3.10614945427064, 5.203037271576544, 14.445485299633397, 27.751722105087776, 42.2895243090968, 47.17855868800994, 44.61119482594152, 42.00193220569242, 35.98662845550045, 23.826627846687074, 7.672794422795696, 2.566357528971088, 0.6954923091876892, 0.20718371405476527, 0.14943438221610364, 0.24851968872451016, 0.08247588445702869, 0.10586431895893429, 0.07232483641635026, 0.5160800944412909, 3.7028895366576413, 28.1441120947561, 57.61799004770095, 55.967954820202245, 41.69186492120066, 88.21964356207079, 98.94724753595169, 38.150957015252885, 19.341479924417314, 23.451129544165827, 29.20212438029628, 50.91220794185516, 64.46999026883033, 68.07268727210261, 69.26262455601847, 82.15950319843908, 85.19333101088002, 38.4016788390375, 1.7811641073034656, 0.19963757946125923, 0.16100776441875966, 0.11396806596988633, 0.05166556716205613, 0.013955775836122133, 0.022878283146588553, 0.045142098660430605, 0.026687772178481665, 0.03903869531988617, 0.042030318459916505, 0.06784300755469069, 0.0073930635229654375, 0.026859140301483776, 0.03407898847193968, 0.01283300982322544, 0.03776481367587563, 0.009376591563435092, 0.09898661906200071, 0.09478294140388889, 0.011648516275829846, 0.07030873814777983, 0.03643228034038217, 0.0389949057341343, 0.11708587528236451, 0.027409193346336968, 0.0519409834317142, 0.06312191794295946, 0.019995116989218423, 0.024196086526517908, 0.040226671694507526, 0.0504457560037413, 0.05600389626417911, 0.05756803713138065, 0.10525729387037217, 0.023266356475951693, 0.05363421394459663, 0.023486627821600246, 0.022159570099545584, 0.0538697898117525, 0.13530246552921113, 0.05685350692440426, 0.06496324474292417, 0.04368878773323471, 0.011385947300661958, 0.026102808506919012, 0.024433056673695965, 0.03759237877543896, 0.07398337080714203, 0.04317761173531894, 0.012215666487933168, 0.019914444100352067, 0.025867789968728058, 0.025417858869918895, 0.043610799982542955, 0.06719017806913584, 0.04111515365601067, 0.042634294518539985, 0.026841217674495235, 0.03343313804737503, 0.049264237750321634, 0.07463818446042077, 0.028370363645315654, 0.02491527454807393, 0.057165285557388305, 0.06678942215418623, 0.010670987126838056, 0.06550810179643093, 0.018683034370863633, 0.0875705070493202, 0.010217113548048563, 0.030344300264973315, 0.07666052634557409, 0.053407892419566075, 0.032035722810354446, 0.0777218185905968, 0.011860453542472135, 0.009360139825261168, 0.09172147019736229, 0.08039492152390942, 0.021062114674057213, 1.9421447981749813, 25.12311435514881, 79.60133337205457, 107.16480916546239, 91.18399835401966, 92.74242662614392, 95.68942100771012, 138.13600878561698, 92.13921316208379, 21.449375383315548, 23.155527960869577, 47.77718297896847, 45.561455680478005, 42.728759165733095, 53.77629126271894, 59.867979249646595, 24.205524882962628, 3.4224270764858495, 0.21206124265107418, 0.1695189093269648, 0.04682283427926802, 0.4120024227567258, 1.2238470320740056, 0.4694312540513854, 0.9896450057145089, 0.8629542877597194, 0.9388599953343792, 1.4079219030757106, 2.550473155513887, 27.798790547155566, 64.4462207055861, 94.4059665741459, 99.58933168841948, 95.53684865274738, 82.01385774920064, 56.82354927062989, 32.491014119117494, 14.714128432735322, 8.500805785579066, 4.112415871312542, 1.9281671869177974, 2.283005507722978, 4.697555053618647, 3.4483664458797825, 7.7561016428855165, 8.249065126142195, 6.34483628696011, 0.977734054528898, 1.6530347375139114, 5.109597588739088, 5.32855115590557, 1.9935576329308173, 0.9774466796267418, 0.6007092758532494, 3.1372759130693253, 3.121880364994849, 1.1862784479894948, 3.9897341833960627, 10.633918162315123, 22.106945053223644, 38.44445620813678, 53.34577583497571, 58.46851287349578, 60.603517793839984, 58.59422483751851, 51.26834346402077, 31.97831915270898, 12.293549468440395, 1.3242711078736091, 0.8637551867192792, 0.08987489952555588, 1.1839944028085279, 1.4682625426400093, 0.35879718740620925, 0.11031013402727344, 0.08051403287437656, 0.4871598769339823, 4.928583147064333, 33.11560646180184, 57.723560640888834, 53.59195163173061, 51.754285904669, 70.68246764521446, 48.19171867062969, 33.89713087389546, 29.997634003239295, 41.94699941142913, 55.904377122079175, 74.03855739101287, 82.21095685035952, 73.7257719039917, 84.54972497878536, 94.39879648147091, 95.1261608062252, 37.444781334169456, 0.29682119527170736, 0.06743498146533966, 0.19110267050564292, 0.10261904793761431, 0.11924978255504563, 0.040534340265777805, 0.0035796233926028496, 0.04500940840150561, 0.048500769846742196, 0.018136761969916763, 0.06298112247379557, 0.06338784621367533, 0.03326308184994325, 0.057286679849869786, 0.06795171543114609, 0.04817463472605713, 0.02976522972476819, 0.005418660547283869, 0.07625426991932815, 0.0064610289841619956, 0.026226133340969685, 0.04791401544465654, 0.006140793219298846, 0.020756041480889244, 0.014899119269102814, 0.06773715718619286, 0.08984051749951417, 0.08674767499248828, 0.020665771425551465, 0.018408966415952292, 0.04067554176154156, 0.020045245952543714, 0.04134414116701773, 0.03505388132086204, 0.01306914110412641, 0.02686147686965283, 0.041834820482519366, 0.03502069056154259, 0.037372871602494875, 0.020078545879392375, 0.010215882061710282, 0.04038059791069358, 0.036189062746181604, 0.12970233215920388, 0.1957132174603401, 0.09769586816189751, 0.1841320211608564, 0.06928028043119178, 0.20298438777606334, 0.10789759291876709, 0.16102291763790194, 0.20865385210321796, 0.20962148243861817, 0.15750199285966737, 0.15087710963862558, 0.26083066038066344, 0.1250379139016713, 0.15698661486948692, 0.06487716710375202, 0.1340961681618806, 0.19534190996519982, 0.19489578632337434, 0.12708680073340095, 0.19447708862923807, 0.1618436429529421, 0.2292406877442714, 0.16089735582711237, 0.1450308781838225, 0.11964075552720217, 0.18916028521714673, 0.1327832619990072, 0.08361164810917071, 0.20868674791868658, 0.14201387072042113, 0.2045320079571778, 0.2519701640572279, 0.06259539337348073, 0.22225205065502276, 0.3852421135431336, 0.12454748739518466, 0.1073372838718276, 10.51999782362292, 58.89037163026872, 107.23326236970964, 121.36132594077819, 89.58294960760301, 89.7223271093061, 101.35895606010192, 98.44496450116559, 105.57227980706, 62.18395840737128, 87.76671963353311, 75.94130700634372, 53.1702733039856, 56.76466272723291, 79.64518547058105, 76.58543863604146, 32.2367190161059, 4.340518857202222, 0.4818008773990216, 0.3814435738228983, 0.3518863082412751, 0.4998001744670253, 0.7977659663846417, 0.42312837896808503, 1.288732227779204, 4.087749556187661, 5.844849309613628, 6.339960780835921, 4.325612869954878, 28.987202029074396, 61.719220299874586, 94.36821768360754, 97.3515175234887, 93.62994132503387, 80.97616334115305, 54.59884758918516, 33.57553574346727, 15.362476610368299, 15.679382547255486, 10.880647993856861, 15.948453218706193, 20.804349453218524, 26.001629175678378, 46.19874669659523, 26.78986280195175, 18.45043509237228, 34.383763651694025, 33.278008276416415, 30.079335012743552, 31.133415122185987, 33.99577848372921, 26.1454919076735, 33.80142111932078, 33.62951932414886, 41.61841853972405, 22.156237479179136, 16.514070764664684, 15.173311483475471, 12.95736845462553, 21.749413167276693, 35.860755674300655, 51.55654745717203, 56.155004808979655, 55.732440025575706, 50.5536287830722, 48.66250899530227, 37.172427638884514, 18.828667286903627, 9.296067318608685, 3.8905126817764777, 0.521140564833918, 0.5796983645808312, 1.2334046224432609, 0.31205108449343716, 0.19928982150891136, 0.26017691158959944, 0.7740658413498633, 7.286130112986411, 51.11373147656841, 87.62512207031251, 79.70562135019611, 51.981540187712646, 122.78225944888209, 136.18814406856416, 56.795410187013694, 30.55155504134394, 37.39593213604343, 42.2487473487854, 69.44310065238707, 86.80861796102216, 88.03448415571644, 89.76717548985636, 97.97992829353579, 115.98565486169632, 73.48561302308114, 5.762210363341916, 0.4647127040211232, 0.3348074504925359, 0.21383807633913335, 0.26221657472272075, 0.19465255340741527, 0.14446218047411213, 0.1253383735855741, 0.1633585052144143, 0.10584219433968106, 0.12635152486543502, 0.1794727050488995, 0.1644640926632189, 0.11994009672273552, 0.1487305465965502, 0.08287601217988037, 0.1678702421486378, 0.17295325084799723, 0.23471752692374492, 0.18410373719469195, 0.088836949979586, 0.10907759048765707, 0.13624702129633198, 0.10259876192937936, 0.23779995829587985, 0.18915905947646788, 0.1857088446136444, 0.22637899694663866, 0.18460932458120008, 0.10508728363821584, 0.10577971220857675, 0.13481347160714288, 0.14041167443558095, 0.13894930451868043, 0.2493565018859602, 0.1310491606953644, 0.1386296926366706, 0.088445647589622, 0.08917883969843389, 0.17231232636878568, 0.2338506677939046, 0.09964665743492304, 0.09417315073792012], [0.014540918580737087, 0.03466297346617907, 0.025387069796242064, 0.06273343858699645, 0.11208808620370204, 0.07478125138028015, 0.02860033749452522, 0.07379092952056278, 0.07161567648572308, 0.04454713562623628, 0.042336619564241944, 0.02431421728444196, 0.053797394502908, 0.08479979685357503, 0.040630193186863776, 0.03975254753904958, 0.05205648650805797, 0.041841255621083324, 0.10397824113287273, 0.0692746113805521, 0.061724048798843745, 0.029081833331034552, 0.025521535463931582, 0.03025967053197805, 0.04836598816778391, 0.03734725362230693, 0.059007424410552754, 0.024645450720263105, 0.028534520965730472, 0.07972493932972993, 0.06276978179812431, 0.036595323002867164, 0.04201863944951085, 0.0766713894723404, 0.12449389954488124, 0.32867494730218766, 0.6936764969460426, 23.261428033151937, 75.9563296841037, 83.85747371181365, 83.99206592190652, 61.99874801020469, 63.31704485800959, 37.50748826611427, 38.95771795703519, 29.183801028036303, 26.988479860367317, 70.8690155706098, 69.96804714202881, 37.07243857845184, 43.912299063897905, 42.91401663134175, 28.928129173094227, 5.401280233936926, 0.04130900837481022, 0.25771838222299853, 0.017472213254340233, 0.1463206638131411, 0.07468804146253294, 0.3262006365243466, 0.15452661461407138, 0.16658551269961944, 1.092035169562986, 1.889339644582041, 2.314604857275563, 22.029966577406853, 87.8076691781321, 132.50461486078078, 129.17836650725334, 128.23194565311556, 126.94530625497143, 128.45945096785024, 133.1707117634435, 142.18938612168836, 135.34634067166238, 123.25467755717617, 112.0517921447754, 90.1664492391771, 55.027444977914136, 18.96484217336101, 7.022915540202972, 18.111803147100634, 20.73908709710644, 18.814719338570875, 9.695351854447397, 4.272842772545354, 6.744676818770747, 5.9441700962282, 9.766683097808592, 4.257983363443806, 2.606093590298007, 3.5328846977603052, 2.66711954147585, 11.150599237411253, 38.31692818672427, 80.88387781573881, 117.10242425241779, 137.7650780831614, 147.2125930170859, 148.84773500504033, 153.318813385502, 145.30553663930587, 150.9510354072817, 142.0072155614053, 133.80078561844365, 92.45354406295284, 47.61371035729685, 20.72464689131706, 3.243307629900594, 4.614116924424326, 12.317968183948148, 4.487524878594184, 0.3711856871602997, 0.05964310501792258, 0.03723066270111069, 0.06104077114873837, 0.1864053717544002, 9.116302151833812, 34.46214437484741, 57.471579736278905, 52.4039480763097, 67.38147935559674, 82.63771072510751, 75.38851953321888, 33.4747661313703, 21.650524331677346, 21.205500056666715, 21.165442851281938, 54.98944505568474, 58.527164074682425, 70.83986451548915, 78.49078486042639, 90.66313112935713, 60.57373131475141, 6.490914667806318, 0.5119800225140587, 0.034980873141678116, 0.0358393129652306, 0.04813741051381634, 0.025601348419102932, 0.0412662300251184, 0.01989806897097057, 0.08714010353170096, 0.013068942878876003, 0.06602018560853697, 0.03377309339421411, 0.04887295451255576, 0.06677387056932335, 0.049508278889040795, 0.04005212239139984, 0.05606304974325242, 0.05359907732194951, 0.04546397816269629, 0.09031409007166663, 0.06423794333973239, 0.05915195455834751, 0.040187643345205054, 0.05682869333653681, 0.03416236565117875, 0.029962560567524166, 0.07630297778955392, 0.03714192673684128, 0.11369919975198085, 0.033626785922435024, 0.03495496021763932, 0.018511449828022913, 0.012513480295667486, 0.04694359654921198, 0.07654742878531257, 0.013460498077854996, 0.01621987974841989, 0.0601584600254653, 0.05742217782103727, 0.013322909644264127, 0.04346527392044664, 0.04891651044149072, 0.03152559443767513, 0.08032922182352313, 0.008235581166621658, 0.015289684299439674, 0.07311500248409088, 0.009096743475135055, 0.03713470635815494, 0.0378734449435386, 0.04037492886005391, 0.006350483454298229, 0.08588935774300369, 0.03730269411819116, 0.006302304663545182, 0.05321935818140065, 0.021336083037538395, 0.02741116985318161, 0.05009861475217247, 0.03824554533968049, 0.12811696682606014, 0.028606471943578897, 0.046499437922912265, 0.03847927110449922, 0.013389392669552998, 0.025533775633741772, 0.049139894019331665, 0.06066282933217384, 0.04895655385729286, 0.04498177561007681, 0.066289794931729, 0.054022287273959774, 0.052872350995218566, 0.05478357182695501, 0.008116203600600844, 0.059198632295573914, 0.028508962357356667, 0.07776843504078927, 0.8617169638314556, 17.134770154953003, 75.46582944931524, 102.13227487379505, 100.80769046660393, 89.07863478506766, 94.6533347714332, 75.87585049290811, 63.98486368117794, 45.956630552968676, 44.85391893694478, 33.11161348896642, 47.5135055665047, 42.94163403972503, 45.14357028468963, 53.11668980506159, 38.503578093744096, 8.010766919582121, 0.22812267434933495, 0.21188836725008106, 0.034562623608977563, 0.23536860972883242, 0.4444947550373693, 0.5157075918489887, 0.1954777986412087, 0.3522917832578382, 1.58105532248174, 0.7801453312558513, 5.109614749108592, 31.07011002878989, 97.86235132525044, 141.92453199817288, 134.80100570186494, 132.43382392391084, 130.36194170674972, 131.46940723542247, 139.53838163806546, 148.27031504723334, 138.70679209309242, 131.00516334656749, 126.34966296534385, 102.5688817424159, 68.34488407258065, 27.60121880039092, 9.211178402746878, 0.37753560610355874, 2.235774777589306, 4.248046528908515, 1.7147521290086931, 2.963927498748226, 4.902319446686776, 5.491170171768435, 6.19357890659763, 3.205064275572377, 0.3699909577206258, 1.522147941493219, 2.7172886171648583, 16.87613691053083, 50.64034454284176, 94.26885620240243, 127.39849690468081, 148.88349133153116, 153.27353354423278, 157.3287936179869, 158.18816923326062, 154.14792399252616, 153.9653455057452, 149.3385019610005, 142.72659394048875, 106.69428948433169, 60.131323260645715, 25.87608979594323, 4.5403013498552385, 2.688797991121969, 12.327852556782386, 4.660713701478897, 0.5281563367574446, 0.03417246652046039, 0.049792225547735734, 0.060829568368893486, 0.053243922790692705, 12.948154807090761, 41.660336909755586, 62.71724385599937, 52.09801889234974, 63.055583584693174, 45.49603054600377, 32.100597081645844, 30.349129361491052, 28.341458305235836, 43.86453243993944, 45.4256671474826, 89.47194653172647, 77.92120964296403, 83.71637036723476, 90.17934599230367, 104.21883460014098, 67.76828781250985, 5.300169375634963, 0.402341012151972, 0.09505269628378654, 0.02763126308338777, 0.07058082193496727, 0.03378743456015664, 0.047174618023657994, 0.032961078498873024, 0.05471856926657981, 0.041041130410327066, 0.03098512515275469, 0.08047892306480678, 0.03955121580210905, 0.0529655302694488, 0.036631352117946075, 0.06866376351324782, 0.013987450698961415, 0.014122276427975346, 0.04782335276925757, 0.0784008942484375, 0.034573816153551304, 0.02810688494073768, 0.01275390549938405, 0.014197857704974953, 0.0896428821368083, 0.007481098516784128, 0.04543816866052728, 0.10119204063929858, 0.03060797240675217, 0.04907607506479948, 0.06118499869180303, 0.03767779757899623, 0.10154318470027178, 0.034707693848758936, 0.04695991422199915, 0.008442838593656498, 0.020707747298142603, 0.07586128979681, 0.02009754485991453, 0.09837972420838573, 0.04295513214122865, 0.07762369804925497, 0.20289484741947345, 0.16807835759414783, 0.15989992467145767, 0.13061085115036658, 0.37336422671233455, 0.13344819567376567, 0.21225353072006858, 0.24269784950921613, 0.2020789024930808, 0.14138725676363514, 0.24561941773901064, 0.13180593299048562, 0.13850826770067215, 0.19953441806137565, 0.12411991840288525, 0.15470843792202013, 0.16056770819329447, 0.09881385857419622, 0.2753775362526217, 0.17713799081262083, 0.11863985399325049, 0.07553584032481717, 0.13808390095589623, 0.06659386288975516, 0.17861343018950956, 0.21106041006503568, 0.20392204875186568, 0.15773005723472566, 0.12441158339741731, 0.19505779859760117, 0.15644201828587442, 0.10269880535141115, 0.17314457364620703, 0.21105434264867537, 0.20648655872191155, 0.584977507110565, 2.988137348044303, 45.688764049160866, 118.18914828761932, 120.55062693934288, 119.73459351447322, 83.10312348027384, 96.75424252786945, 56.056643532168486, 55.576788610027684, 52.96361538671678, 39.36058459743377, 110.63666374452653, 112.28946424299671, 64.29010645035775, 75.76934245324905, 75.34579707730201, 45.13709837390531, 9.797357013148646, 0.5329061431750175, 0.29564482129869923, 0.20051268169716482, 0.5024040153911037, 0.3118963653762495, 0.3431444482937936, 1.2240120167693784, 2.20613710341915, 7.06924363490074, 6.82236671447754, 6.579530325628097, 27.161679960066273, 97.10689498532204, 147.08966593588553, 143.8094348292197, 143.58655006654803, 142.70991602251607, 139.39068086685674, 144.9617644279234, 156.17051770610195, 139.85846273360715, 131.1761316176384, 124.23293236763247, 99.20601414095972, 62.766928518972094, 24.59582228814402, 15.269719419940827, 38.88296934866136, 44.71335687944966, 42.69699973444785, 27.254018437477853, 16.443022912548436, 14.993292343231941, 14.843897108108768, 17.627262953789003, 12.848754102183928, 13.048762621418124, 13.10385132989576, 8.341153552455287, 13.52046391656322, 45.81799830159834, 91.0278566422001, 127.74807422391831, 146.73028269121724, 157.16792937247985, 167.94959929681596, 170.07197810757546, 165.11254895117978, 168.77892955656975, 157.91757275981288, 146.70568158549648, 100.47129231114542, 55.046699893090036, 29.57018586897081, 11.52635347458624, 10.36824720521127, 17.603979764446137, 6.897440879575669, 0.5350848359446372, 0.2357869550225235, 0.11763863070237061, 0.1576534637640561, 0.42315755159624163, 17.249399462053855, 58.11710772975799, 101.05178740716751, 78.19682675023233, 99.65186211370654, 116.47070300194525, 106.18151018696447, 50.458931000001975, 34.06622032965384, 33.75798479203255, 34.35685226994176, 73.95735648370558, 78.35884417257002, 95.38396250817084, 95.55391880773729, 113.7093230216734, 100.86819694888209, 18.30981812169475, 0.7669094769704727, 0.14518287002799973, 0.20826734542366, 0.1594032239048712, 0.1373390643106353, 0.2777229910415988, 0.1645739956368362, 0.20226115481026713, 0.19493900900406225, 0.10590767187456931, 0.18136814446939578, 0.13735092335170315, 0.12964049354195595, 0.12791587640681576, 0.14309166449933283, 0.1435416339025382, 0.13135559586507659, 0.14545432562308927, 0.1780019388083489, 0.17214692798593353, 0.13686756783675763, 0.1255169869851201, 0.10057511769475476, 0.1592409511607501, 0.13739713377529575, 0.17592387934846265, 0.20258202307647277, 0.18251919157562718, 0.13792247090849186, 0.08292578491232089, 0.18698465679922413, 0.2109353998375516, 0.17809126466032, 0.15227695145914633, 0.12462766615733986, 0.10614355800733452, 0.2400166337047854, 0.10975165593047297, 0.23859901864442135, 0.20339075145461868, 0.1835639669650024], [0.047458461260483156, 0.0615467875444841, 0.033564353587045785, 0.0828354784678067, 0.0549823907955039, 0.06468556085301023, 0.03895477421822087, 0.06881450663410849, 0.0718555769192115, 0.16016195738507857, 0.034527414207977634, 0.09090569381031299, 0.05280410788292366, 0.01150970210156013, 0.03741224852180289, 0.06251319213920543, 0.1378688907190677, 0.06898444791835162, 0.09485402670238288, 0.06506304301682019, 0.07896191575714658, 0.08326251885943836, 0.03832759718681055, 0.1312900034169997, 0.0672930636773667, 0.03267255446483051, 0.031044010501054507, 0.04038458539833946, 0.059054293669760234, 0.12429843987188033, 0.0680240571138359, 0.07112703496410001, 0.09410345205856908, 0.051433070968355865, 0.40252652800371574, 13.415912159027593, 69.93511492206206, 98.31652256750293, 87.23788999742078, 81.13763947640696, 71.05088803075975, 64.25052973531908, 33.03960269497287, 37.124680626776914, 36.255353958376, 72.37812396018737, 49.379977180111794, 42.73413281286917, 39.85624274899883, 36.970433419750584, 35.988993644714355, 11.062468482602029, 0.9858667213589916, 0.45374165078805345, 0.05945010831759823, 0.23966040281999498, 0.22671268952469673, 0.10766140801171142, 0.367885840035254, 0.6256462345200201, 3.5013432031677616, 2.1410529700017746, 7.146097085168285, 36.65420016934795, 95.81003389050885, 132.07153812531504, 125.56864846137263, 108.5806671265633, 104.96763860025715, 105.6961404123614, 107.08494970875402, 101.98828466476934, 106.7483554347869, 108.46736554176577, 110.34156814698251, 110.61993091337143, 120.26613743074479, 129.16805851844052, 139.55716194645052, 134.40569354641823, 92.9298766966789, 8.766171778402022, 2.5099560522264053, 2.9855466225454887, 1.6092643958906976, 12.218177203209171, 53.533574996456025, 68.4067084712367, 70.45984960371449, 35.399700672395774, 12.718007776045031, 14.058048282900165, 65.13666768227854, 107.96014032056256, 127.37061669749599, 129.10976425293956, 120.84028613182807, 116.61648181176956, 117.58030229999174, 113.32082794558619, 115.87573435998733, 112.59271837049916, 109.70807398519209, 105.34492354239188, 110.72083780842443, 119.0690378988943, 125.64328332101147, 104.57552709887105, 70.03406847676924, 27.765503352688206, 2.5810102781941815, 0.8463198835811309, 0.5275560302599784, 0.4680389965013151, 0.1849225779334384, 0.07947399956925262, 0.11563516522367155, 0.34946688000232945, 2.116280750882241, 17.875509761994888, 42.224883648657034, 46.102381906201764, 68.15542574851744, 75.56952122719058, 79.29971095054381, 79.3485366144488, 30.05118808438701, 25.741464245703916, 8.479247458519476, 38.18697614054526, 57.28833444656865, 71.30938791459607, 72.3324675713816, 82.89656362225934, 80.28148804941486, 21.948395006118282, 0.8706466072509367, 0.030471309981939775, 0.017322213238766117, 0.05797866791967423, 0.05421801124729457, 0.04432122778868483, 0.07774182880717902, 0.06421454318408525, 0.06234864794438886, 0.058853184098317746, 0.023647910397079204, 0.04199528908957878, 0.08627271580119288, 0.06238119902029153, 0.0681605969645804, 0.017845815182813717, 0.06922955774972517, 0.06360692054694218, 0.030854761885899692, 0.008864644689545518, 0.060681816821377126, 0.05194524671101282, 0.060106002154850194, 0.07480093983993416, 0.10059837612413591, 0.0330358678324809, 0.019162208960962393, 0.04024450239094515, 0.017916369965420138, 0.14579108255284448, 0.052652093056108684, 0.06200750899170676, 0.021185904906521884, 0.05732094696272285, 0.060456721037025415, 0.025947541636865468, 0.07266468068044032, 0.01800359290603909, 0.07726913723613947, 0.012830555469038026, 0.01969129609454784, 0.059162733415442134, 0.0708912024574895, 0.04144267539583868, 0.050098365773597074, 0.046077553303011005, 0.014599593254857728, 0.09802481865570431, 0.09231243042215224, 0.11070351251551222, 0.04511480294768849, 0.037151330466111826, 0.03218776636546658, 0.04258389742444119, 0.05521993550862517, 0.05687547066519338, 0.0685739167214882, 0.1312382618385938, 0.035394801938485716, 0.012032357927021241, 0.02827127974840903, 0.02836619995744719, 0.01643060563853191, 0.048171271600069544, 0.06725521127302801, 0.013776609895660753, 0.056882844261464574, 0.05413442339387633, 0.060973489476788434, 0.04065444370010688, 0.09416785707036335, 0.02591520315036178, 0.05385856662366179, 0.029704647491716092, 0.18651159750598093, 8.155745075594995, 63.97188455827775, 110.88174127763318, 109.62318604992284, 101.72423854950937, 102.49095209183233, 100.56984578409504, 61.64257326433736, 32.93898605531262, 29.786728159073864, 34.530526976431574, 25.055892775135657, 48.925354865289506, 48.23322126942296, 51.03295810760991, 46.927656435197406, 15.725618466254204, 0.8819484266061938, 0.4715745535589034, 0.16267775948489868, 0.16253673801979712, 0.7533176063049225, 0.28588461599523024, 0.7902587950229646, 0.09498983876959932, 1.9140434673716946, 1.2422972484942407, 11.345036029815676, 47.02223654716246, 109.05805095549553, 137.40840911865234, 127.56131449053366, 112.45088546506821, 111.31668506130096, 111.07756953085624, 111.89018264893564, 107.14188683417537, 112.8912970327562, 113.68993082354146, 115.47509562584662, 115.44312830894225, 124.69188890149518, 134.48558438208798, 146.22912929904078, 145.8209517694289, 111.60047638800837, 15.974615427755541, 0.8355088507936848, 1.228510975357025, 2.0547569038406497, 18.61410971610777, 67.0845716230331, 83.79673188732517, 86.56099873204386, 49.233711996386134, 20.367828876741473, 21.49953269189404, 84.21556257432508, 119.6315214710851, 130.92724154072425, 130.8768077050486, 123.38351957259641, 118.0046243052329, 121.00710453525667, 115.19443435053672, 117.60023578520745, 116.61504622428649, 114.58240339832922, 111.3823926064276, 112.82741731212987, 123.45909580107659, 130.06778747804705, 115.77788691366874, 81.9241766775808, 34.86809007583126, 4.3560779190832575, 1.8168615982417138, 0.05614749944558548, 0.2422690547762379, 0.2621437044393632, 0.052170836622075695, 0.037800858112713026, 0.372243685227248, 1.9748517270049744, 20.92851600339336, 50.8284104254938, 50.73252808663153, 63.92218420582434, 59.402135033761304, 43.29780878559236, 50.92113917873752, 24.807259613467803, 18.506660307607344, 20.356781521151145, 49.258422928471724, 68.33410539934712, 83.42893123626709, 84.69437414600004, 94.52923882392146, 87.8303090987667, 22.728725056494437, 0.6280139977893522, 0.05313917941924545, 0.02159382565878332, 0.015240669036434304, 0.0925066796762328, 0.10816040704207075, 0.01961146207195857, 0.09158692983610016, 0.11918556906523244, 0.0586278853006661, 0.009392568327095962, 0.014007998134700522, 0.04216209707421161, 0.060362319852555954, 0.04876032043548842, 0.08521398995071651, 0.06329577010605605, 0.03637124228501513, 0.010068952143492719, 0.025572530106611313, 0.026499883369392446, 0.037785153310265274, 0.040421916862889644, 0.06506551748081561, 0.029622982518987793, 0.005308406130831328, 0.025369432537005316, 0.04674108503686805, 0.09126484349009492, 0.1121906653767632, 0.05437389864856678, 0.0006982018209284082, 0.03197900549088034, 0.005166477809149412, 0.02457703523818524, 0.026232610614369475, 0.014130723504950444, 0.04481330904508791, 0.055772269580272905, 0.07231274754890511, 0.16945972137393492, 0.12400128202693117, 0.14776985701774398, 0.32960105567209186, 0.15454654822186117, 0.16742232586106948, 0.1264232000516307, 0.40820924565196043, 0.14536130722732316, 0.2324663162712128, 0.19140032630774284, 0.21274364313050625, 0.14689152189079793, 0.10993959262005745, 0.14780053117823216, 0.14142271131277084, 0.22507876187803286, 0.16605717250176016, 0.12797847345110872, 0.17781242397764038, 0.1921161588641905, 0.18518920717460496, 0.23590792030576738, 0.22098026809192475, 0.1910830892982983, 0.09656612596084034, 0.12583662184976763, 0.20750173247389256, 0.2080425599049176, 0.18993896762690238, 0.1626158595806168, 0.18819340564791234, 0.1995190196940976, 0.12627356775826024, 0.3783827461302281, 32.68233949138273, 109.86849108049947, 143.82631671044135, 116.23626293674593, 112.06104893838207, 99.3127026096467, 87.14555740356447, 46.10347232510967, 56.88768394531743, 60.135779073161466, 98.67998507715042, 80.44441546163252, 69.93746834416544, 61.10929958281979, 63.83395833353843, 58.622669866008145, 17.986163746926096, 2.6446093042050642, 0.7727602436657875, 0.20005908103719836, 0.28346362493691907, 0.7675630419004349, 0.21922997168956265, 1.7411278620842965, 4.59611177444458, 11.133417294871423, 7.596548449608588, 11.649026582317969, 43.21927116763207, 112.82338511559271, 147.83140182495117, 142.47625258661085, 118.49325749181934, 116.74359013957363, 114.9226454765566, 117.74799931433894, 111.87507367903187, 120.45653712364935, 116.86901184820361, 119.46965309881396, 120.04480592666135, 134.19772947988204, 143.71189332777456, 157.70709837636642, 152.44186555185627, 110.16468494169175, 13.803652178856636, 10.788433071105711, 12.199271378978608, 5.913738877542558, 19.362250835664813, 72.85504494943928, 84.94329560187556, 96.77054389830559, 58.436223922237275, 20.434838648765318, 20.178896150281354, 84.71844180937737, 130.86056124779486, 140.93800883139335, 132.1491853652462, 125.25005786649643, 120.63724071748796, 126.73363947099256, 118.94175698680263, 122.38991260528566, 121.50576330000355, 120.45050451832434, 118.19588691957536, 124.8035038671186, 132.86184864659464, 143.5124643387333, 115.7343799837174, 77.39318801510719, 33.16865651838241, 6.9823273439561175, 6.554892937983237, 0.7627320914499222, 0.8385748572407231, 0.31914793916286965, 0.17436669839005317, 0.2198190473380589, 0.5409348671955447, 3.0911853669151186, 25.495374741092807, 67.23755190449377, 70.53607694564327, 104.16003042651762, 116.1080014321112, 114.42385335122387, 116.24486077216365, 43.131041372976, 41.08741983290642, 17.566972201870335, 54.178879414835286, 74.74258361324188, 97.28582566784274, 91.98045915172946, 102.99023059106644, 109.83945769648399, 46.02128298051896, 1.5883162425410364, 0.28464784365027185, 0.1240977708009943, 0.2534267729929378, 0.19376528569527213, 0.20103172158762334, 0.2096880708009966, 0.18572887015198508, 0.21595799484320227, 0.21155396987113262, 0.1385360307270481, 0.16154584925501578, 0.15902964878947506, 0.16155364803008496, 0.3226767546467243, 0.11887420028928788, 0.2137896902258358, 0.24971997996251433, 0.10620290683882852, 0.12275799027373716, 0.17547885887324813, 0.11784070171415807, 0.22940052432879326, 0.16409437863096116, 0.20200345815429765, 0.1289183637427707, 0.14711836052517738, 0.09296545909056741, 0.1872731042244742, 0.2378313985442923, 0.1961959601049462, 0.19846350375202396, 0.08263755965256885, 0.3237866321879049, 0.13218439574683868, 0.13672691409385976, 0.13520993742971651, 0.11574502989289262, 0.1335173887350867, 0.13398007519783514], [0.1025104090090721, 0.05166865449639098, 0.06096501654434589, 0.26604379677484113, 0.1545259864219735, 0.18321095364949397, 0.04914598824876932, 0.22267454814526344, 0.33340311939677886, 0.18934448339766075, 0.09428820948326781, 0.05642926275369622, 0.039809391263031194, 0.08418628300029425, 0.013759596998082295, 0.024953305067855026, 0.10881555777403618, 0.04176845428563895, 0.05219922784054953, 0.05878798235508223, 0.10470443885893592, 0.16220275432832781, 0.14539389660762203, 0.17787438516895618, 0.10696470467073303, 0.20101787071795235, 0.12751263836699148, 0.06473413848828885, 0.13827200618482408, 0.11016388784252829, 0.1337503407511019, 0.0887567558956723, 0.0653526242521982, 0.036587930254397855, 25.333235725279778, 104.4649633284538, 94.42233070250481, 87.5945903408912, 76.90690040588379, 75.21693937240109, 49.70210183051325, 31.474490704074984, 59.66525154729044, 83.92457762072164, 85.60242637511223, 60.558143815686634, 44.477732258458296, 34.90004562562512, 38.7937746509429, 25.928374990340203, 3.036886770879069, 0.3084815437755277, 0.21195828043405088, 0.24208591379705938, 0.06911367162941925, 0.22820358855589745, 0.27947503412442826, 0.054553335592631376, 2.50036830863645, 2.0237272785555933, 12.131738951129298, 70.21731376647949, 121.39617227738904, 133.484187587615, 118.52582885373025, 102.04985018699401, 103.00682221689533, 105.31039884013515, 106.90872546165221, 103.8676961775749, 102.22052035793182, 101.17243951366794, 112.29193533620527, 120.12714432131861, 121.91907913454118, 121.7698564837056, 112.08099811307846, 96.07706100709977, 94.51548699409732, 97.92976117903187, 134.50654552828883, 99.94150561671104, 20.242779793277865, 25.16495231659182, 49.4459161450786, 116.41229891007947, 122.7408862883045, 131.0393742592104, 121.92647672468617, 129.63566780090332, 94.54208850860597, 101.07658463139688, 111.76531007212978, 94.71505718846475, 101.0658138029037, 106.14183149030133, 112.82183970174482, 124.98942421328638, 128.72185753237818, 124.33845981474846, 123.47862135979437, 120.33265298412694, 111.66413645590507, 113.0288153309976, 105.30493105611494, 105.63655960944392, 107.16929635693951, 115.4152245675364, 120.12905059322235, 131.47046627536898, 107.27177220006143, 38.664873799970074, 3.6955728453974572, 0.5696770765127674, 0.30127075650999624, 0.25755005738427567, 0.17091642224019574, 0.12461341692194824, 0.05688672066636144, 0.2868879460279019, 6.150199943973172, 33.264319204515026, 41.49805276624618, 53.18871236616566, 70.30388047618251, 61.1903985085026, 75.1323809162263, 74.82053679804649, 124.65641498565675, 47.20334414512881, 28.461680912202407, 50.65280199050904, 66.85557580763295, 75.03602397057318, 82.9921910070604, 92.18410861107611, 48.115495251071074, 1.4499290167324006, 0.15694186001295046, 0.055412300186411995, 0.1685975200586742, 0.05086481375920196, 0.2101989135506653, 0.04397733858035457, 0.2014081312283393, 0.09772232117792291, 0.055161188056151715, 0.07350805921540146, 0.14296656234129784, 0.16883079383161761, 0.16448036437073063, 0.21848352625966075, 0.3451150715831788, 0.2013256082371358, 0.09294787737270517, 0.15622778945872862, 0.07590076630754818, 0.07011525498162355, 0.07367647598467528, 0.12239773742734425, 0.0799371763282726, 0.04796178102673543, 0.06194192037406949, 0.1407618838692865, 0.04419174743816257, 0.15289627225889316, 0.21148295352055183, 0.09826122572825802, 0.007384774930429675, 0.1665755229130868, 0.2870686814909981, 0.14473241032852283, 0.03912540115115624, 0.030596628559813387, 0.06489779019067365, 0.04922714377302797, 0.005604685847497275, 0.05830266948549017, 0.14981183373639662, 0.19225368696835735, 0.13639628586749877, 0.029362031904559945, 0.042291458681105606, 0.20136765114242033, 0.26634168240331835, 0.09513900374933597, 0.09573177194162723, 0.10085300076752902, 0.027770804083575646, 0.05756409177857061, 0.05992554248340669, 0.022225392373999762, 0.06123538812502258, 0.042321623393124154, 0.035619480204918695, 0.04822461813267681, 0.10713496771190437, 0.14090791554941287, 0.22259645314226228, 0.0425130074783679, 0.0948638556104514, 0.11868661600014857, 0.09081615345372308, 0.08749943707258472, 0.14223401374634237, 0.02433047175497538, 0.12018113862723113, 0.0925683880585336, 0.11333206743602792, 0.03341218937308558, 21.308515225687337, 114.18796985380112, 114.57075395891744, 105.85397658809539, 96.92984704048403, 101.13452588358234, 78.54697673551499, 51.09396665327011, 35.71731459709906, 37.19393399453933, 41.8858535828129, 58.179999013100904, 57.41548199807444, 42.32460206554782, 50.69639521260416, 32.103644763269735, 4.425543094834974, 0.6260971845157686, 0.15422142050679655, 0.11644549472557923, 0.4472572987358417, 0.33408411027443025, 0.9244108416380422, 0.2272723473969006, 1.7760711547828492, 1.6627700602815998, 17.720901696912705, 78.32690038988667, 129.70497608184814, 137.37191538656913, 121.11232603749922, 106.33793430943643, 108.47479451087214, 110.78863989922309, 112.36478159504553, 111.01881242567494, 109.14212303776895, 105.72896280596333, 114.383680435919, 125.8593039358816, 125.04896579250213, 124.36933671274494, 118.09627440667923, 101.9122063729071, 98.09235126741471, 101.04188734485258, 134.87109061210387, 110.19381246259137, 29.12937814189542, 35.91792029719199, 65.76095604127454, 136.02279263158, 134.85913522781865, 140.1243994312902, 133.82568482429753, 145.7994258019232, 110.53668252883419, 111.78988764362951, 116.65764316435784, 96.22529522065194, 105.8829785931495, 110.38875426015547, 119.70007665695684, 129.81748534787087, 135.30826230202953, 131.24235691562777, 128.6084775001772, 126.53712088061918, 118.51507371471776, 116.53226067942958, 111.31866193586781, 110.92520113914244, 115.7046405730709, 119.06289546720444, 127.8120873051305, 141.44812091704338, 125.91832776223461, 52.07033088130336, 7.953872940232677, 0.16778347503033378, 0.22303197412721573, 0.26488697336566064, 0.1185041951436189, 0.05397034651269356, 0.09482740514701414, 0.4190935777320016, 7.507620473061839, 40.68145452007171, 48.180547760378936, 48.835214876359515, 61.860986525012606, 51.21913733020906, 35.61735299325759, 34.58036461184102, 51.134567106923754, 43.63905499058385, 52.257557376738525, 66.94210329363423, 79.96682766945132, 83.35353543681484, 91.02902550851145, 104.9785270998555, 52.035421786769746, 0.9344268590211869, 0.13669386506080627, 0.037228195897994504, 0.10443976314197626, 0.062258556004493475, 0.16995059987229688, 0.06889081665224607, 0.2080092350802114, 0.04260992909210824, 0.029284076712604974, 0.037712742679662285, 0.048456520608235756, 0.1585350624255596, 0.1639310180419876, 0.12017417488799942, 0.2750022144567582, 0.1861158824495731, 0.09808346268630798, 0.18668693971009026, 0.11817296170779776, 0.07351521447661423, 0.0347734241926622, 0.1437239475067585, 0.067957675595197, 0.05081976395881465, 0.017920960747306387, 0.047060110861615795, 0.037089553135897846, 0.0583709164282247, 0.32126868504189676, 0.07518742353685441, 0.03810221794992685, 0.12572224492267256, 0.3042254963469121, 0.11822048980262011, 0.040872487645115585, 0.03581834513874304, 0.08097497265665762, 0.07644625921403209, 0.16642907754548136, 0.22599359343369163, 0.17429303137525437, 0.377237199535293, 0.3364998000043054, 0.23288683725460885, 0.1297684455470693, 0.3024505012698712, 0.4056262423194224, 0.3012321456786125, 0.20064412706321288, 0.22691499802374074, 0.10697939057624149, 0.16677308166700025, 0.2353996209680073, 0.17598688241935548, 0.24836660903548044, 0.14933224737403855, 0.14611887625388562, 0.1804581239459015, 0.20091621085040032, 0.21105664091244822, 0.4230953146132731, 0.32984062668777286, 0.22168906796122753, 0.25484181399787625, 0.23841661310965018, 0.19293199653827375, 0.27746411461022596, 0.22411798036867575, 0.14532458097223314, 0.27071530900655255, 0.2552736424390347, 0.21784894498846225, 57.33632464562693, 153.12658586809712, 127.56016915844334, 112.60524642082953, 113.38349957619945, 100.32879260278519, 69.94921192046135, 43.56581649472637, 86.98808208588632, 122.98862318838798, 119.82091703722556, 91.19325514762633, 74.55845186787268, 57.84698194073093, 68.81475264026274, 43.23479198640393, 6.404738233935449, 0.9229115769267083, 0.2788397633740979, 0.3316666125770538, 0.4786498045488712, 0.42599967650828824, 0.993455465762846, 1.5942581430558236, 7.062282408437422, 6.223360482723483, 14.915616666117023, 76.4992327843943, 134.07419050893478, 146.82920486696307, 130.33341823085664, 109.33153429339009, 113.77772915747859, 117.28774839831938, 118.93279829332907, 118.3669650170111, 116.09035076633577, 112.9266768117105, 121.0098501943773, 132.09475855673514, 130.17026332116896, 130.05313350308327, 120.43169283097791, 102.10130383891445, 97.81688321021296, 102.41298321754702, 141.8634214708882, 117.81455409142279, 31.388737886182724, 33.370466386118245, 76.37125369041198, 144.81346745644848, 134.9970457630773, 137.9539166727374, 132.84137387429516, 150.1506522393996, 135.19729060511438, 125.54290202356155, 125.76180165813817, 98.81367514210363, 102.48794755628033, 109.51139065527148, 120.40508347172891, 131.9123055857997, 141.09760222896455, 135.96842858099168, 136.94594598585562, 133.4775980057255, 124.82633990626182, 121.80501660993023, 115.51557448602493, 113.89695352123631, 118.4570618598692, 124.44855290074503, 134.6704064646075, 146.4820594172324, 121.14806667450937, 41.3763573092799, 6.110714914337282, 1.0531695066921174, 0.43729000454468114, 0.5844414907117045, 0.2879210002720356, 0.22599146370926212, 0.23694975391751338, 0.8779857908525776, 11.98356455372226, 54.7966331051242, 60.18690324598744, 72.8942294274607, 103.93716919806697, 92.18660323850571, 116.34213555243709, 91.56808468603319, 143.6896142651958, 67.56762719923451, 45.423643204473684, 64.54875538426062, 89.06280409905219, 92.45130831195463, 98.22790053582962, 115.0180845875894, 85.06856041569864, 5.6881859225611535, 0.7270328231876897, 0.2040194491705587, 0.4205736289581945, 0.3376217817346896, 0.42467412989466424, 0.26338832152466624, 0.30471263633620355, 0.1958717363736322, 0.22556620830249405, 0.16304606391537577, 0.2570653382328249, 0.3732011725585307, 0.2628447055335968, 0.28356165354771, 0.5157993385388006, 0.3934915015293706, 0.3084615335589455, 0.2973161187143095, 0.16568601822420476, 0.12114301564231997, 0.1974177018048302, 0.21562079358245098, 0.21517629404702496, 0.17419060541977807, 0.1727706920956412, 0.1783641605007072, 0.13164375217691546, 0.44098913669586187, 0.3469898725949949, 0.2324332212728839, 0.2009432997194029, 0.2693543997743438, 0.4709676587052884, 0.19802369267469455, 0.0982111465606478, 0.10305413225245091, 0.14270889632884534, 0.18347850219616968], [0.0709629312698399, 0.06036217812628997, 0.10434937242779041, 0.060752243284256234, 0.05441236775368453, 0.08269932166102432, 0.11339353067019295, 0.09189275213547292, 0.26271977191490514, 0.09140172041952611, 0.09691258156371695, 0.07420738257708089, 0.028036567645387787, 0.03118636878958393, 0.019893514578260725, 0.05768301926793591, 0.036585873308321165, 0.07726302385450372, 0.05709549111704673, 0.12915359870080026, 0.11275078290172162, 0.26798252016305923, 0.1448501886860017, 0.10566548083818729, 0.1671004463588038, 0.1775066170000261, 0.0754539455257116, 0.06483577537320315, 0.09183898808494692, 0.0859732826751086, 0.04672708861049145, 0.1489301737878592, 0.20854897466638397, 37.93601505218014, 114.66155682840656, 101.68849006775888, 100.33560968214466, 91.22632072817896, 84.68771396144744, 42.21998853068198, 40.775560025245916, 74.01684314973893, 84.18217535941832, 61.680279008803836, 52.52543172528667, 38.646611244447776, 32.37295077693078, 38.75350367638373, 8.911591691355552, 0.16412131428237886, 0.3391421291856997, 0.05079275552904414, 0.3443924055224465, 0.17469542671836194, 0.21599444530663953, 0.6830941873692697, 2.0787377847779185, 1.720500730218426, 14.525981160902209, 79.8498704356532, 130.32868000768846, 128.6279324562319, 106.21365793289678, 91.72406950304585, 95.79880022233533, 103.2195794197821, 94.48635162845736, 89.99814817982336, 89.20646482898344, 96.39352567734258, 88.2390671391641, 83.65824084128104, 91.551053754745, 104.75000196887602, 103.85283039462183, 104.16766335887294, 90.73883287368282, 94.17130685621693, 103.25876389780353, 118.88754983102123, 107.29497694200086, 114.2730382180983, 60.108624504458525, 73.88493384084394, 76.2033684022965, 118.58720610218664, 79.97112658716019, 87.48693696914181, 80.39363645738172, 101.37086437594508, 86.83082642093783, 61.414393301933046, 96.22211810081237, 107.48059918803554, 110.44038834110384, 105.64435728134649, 108.25430239400556, 114.87628306111982, 120.15023139215286, 122.28240043886247, 114.1897584545997, 101.96251469273722, 98.92019887124339, 91.97168873202418, 95.52566205301594, 105.06453683299404, 112.71096998645415, 112.8869196676439, 114.11971276806248, 107.0775442738687, 118.44986823297317, 148.85412062368087, 109.3991324209398, 42.385673369130785, 4.884459914699678, 0.6995811349441928, 0.16604765768974059, 0.3621035616003698, 0.11688638598688188, 0.056938910406203046, 0.08215343804969903, 0.8500224171626953, 16.587595593544744, 38.90764890178558, 41.15499442623508, 45.412303632305516, 53.27303940250028, 53.069652741955174, 161.13465370670443, 94.50819923031716, 16.39315782054778, 22.64859103387402, 45.59688645024454, 70.01895950686547, 71.14733126855666, 88.1138337043024, 92.15122345955142, 60.476083909311605, 3.087899401303261, 0.18553224602533927, 0.12015017335333171, 0.18716957510238696, 0.1270176766199931, 0.11970532141746053, 0.07854266647970484, 0.03693409091342361, 0.022669543339420232, 0.03546500240542716, 0.13751904900756576, 0.038823225430303046, 0.12553620813114028, 0.09457184587635341, 0.050356644656389, 0.06874381970133513, 0.060815928173401666, 0.10497431631290144, 0.09291488196580641, 0.07480362114766914, 0.08171522809613137, 0.055699862780109535, 0.10995453899546016, 0.03837068963255133, 0.06637532864847491, 0.09197397277720513, 0.06473507311555647, 0.15800296839687133, 0.0318247421960076, 0.022865117925609794, 0.05819003540842284, 0.0950927090560717, 0.1810942680364655, 0.09198112037753867, 0.03281053456087266, 0.019631901297778375, 0.022166869002244165, 0.04103823842841291, 0.05812714342027903, 0.09364825027484087, 0.14042806871716054, 0.07247411630927555, 0.05574692356129808, 0.09939065383326623, 0.02230104547174227, 0.0742331920792499, 0.20837180917301487, 0.09562798234964572, 0.057191968399790995, 0.021037320238387874, 0.03378493711352348, 0.05724117422716753, 0.013621644672727393, 0.15322475543906613, 0.04227733968066112, 0.04862656148390905, 0.09681853661013227, 0.08609591803002743, 0.1690745017220897, 0.14335270129865216, 0.08008618809042439, 0.1364511071193603, 0.22450968112436034, 0.1292809991226081, 0.12169364133789656, 0.055655862520178484, 0.1331128943110666, 0.06806505813954339, 0.1364362909789047, 0.19250281876133335, 0.10911224064447227, 32.08113820322099, 126.39844940554713, 113.7191838602866, 117.12671941326512, 105.74290290955575, 112.90096175286078, 74.01015158622496, 41.65298246568249, 22.470474243164066, 60.00711748676916, 58.22718904864404, 54.35346411120508, 44.7766560892905, 40.05107079782794, 49.373877894493845, 12.120727877463064, 0.3165640165248225, 0.3526754400903179, 0.019872349484132665, 0.2917922570580437, 0.5581673715383776, 1.0441695057576703, 0.6646977196778021, 1.3406652668791434, 1.4126269086714716, 21.67085985983572, 89.72789687495079, 135.93899511521863, 130.88255005498087, 108.40912618944722, 98.89722947151431, 99.83912391047325, 107.29618503201394, 98.47764568944132, 92.78106981708159, 93.68907497775172, 101.59876977243732, 94.92539036658503, 87.39047019712388, 95.45281579417568, 110.47514054083057, 107.65893367029007, 107.9040268928774, 93.11658151688115, 96.94217112756546, 108.20966582144462, 126.03973296380813, 112.30179617481848, 121.53820130132861, 66.86589164118614, 82.36509030865085, 94.65571957249796, 125.13713282923545, 86.74022751469766, 94.14500344184138, 87.57400574222689, 106.5867224047261, 97.95496632975917, 68.09846508887507, 101.95521123947637, 111.34458095796647, 112.65225210497456, 109.1028993360458, 109.26111990405668, 116.54900920006537, 124.26466434232651, 123.72391070089034, 118.0716105430357, 105.20767981006254, 102.68951031469531, 97.32931690831339, 100.0091508127028, 110.79007548670616, 118.53923551497923, 121.5014643822947, 119.76292087185769, 112.12528951706426, 123.26088274678877, 154.63738872158913, 125.65986710210001, 57.14849018281507, 8.2480727664886, 0.13163183184881366, 0.20103599635824082, 0.294696465735474, 0.12595145842961727, 0.03042450584020586, 0.16658218787802806, 0.46505698393429484, 20.925707586349983, 47.579954439593905, 43.846277729157485, 42.39026254223239, 52.14012161377938, 56.6914556103368, 169.6114447809035, 102.18495230520926, 31.879573483620923, 41.289865124610166, 62.043616002605816, 83.10811273513302, 83.79380579917662, 93.98278205625473, 106.63035485052295, 69.59377458018642, 2.0895850994894585, 0.22194298014285105, 0.18389833370043387, 0.252619025207335, 0.07767334054674833, 0.030860992095943902, 0.07403518899434036, 0.05521610889944339, 0.08914058892837456, 0.036098151092207244, 0.12968327189164777, 0.057295612435066895, 0.1944340344878935, 0.20177717110322368, 0.09307990496557567, 0.04913249744042274, 0.05782292607510763, 0.03577990284670265, 0.07731294980452907, 0.12656332519386085, 0.07036910587621313, 0.03465935370073684, 0.04413784932224982, 0.08969394955784084, 0.08714252436954169, 0.018084122153419643, 0.04120496980425331, 0.09314046421599004, 0.0681265213737084, 0.025531050275951147, 0.07928906594433131, 0.06305307728208362, 0.09300062252629189, 0.10371745714256841, 0.0332758870095976, 0.059563964304904786, 0.047041165507248336, 0.025292027013136015, 0.21908741804861256, 0.20884257020248523, 0.2819920619649272, 0.2669984649025625, 0.19085559182830397, 0.14729577116668224, 0.1515871505703657, 0.24389599570103232, 0.5216822196399012, 0.14361430500303546, 0.1947957505622218, 0.1803321637693913, 0.13276691368270305, 0.2505386521619174, 0.12420419573543534, 0.20140348873551817, 0.15544711522036986, 0.20083572565307542, 0.14546685882153051, 0.21349361256485988, 0.5719600185271233, 0.4286638851608, 0.43190118886770745, 0.23421273626867803, 0.34598516360405956, 0.4047075496806253, 0.1930842335305868, 0.19206590349635771, 0.286821817318278, 0.18783749652005013, 0.3380062659421275, 0.1990822729684653, 0.4863079258751485, 69.30125990221578, 151.4787510902651, 126.41063228730233, 128.90059994113062, 124.52408206078314, 107.80199819995512, 60.119481625095496, 56.04668463430097, 113.54391667150684, 121.64825516362345, 88.99720638029038, 85.42320543719877, 64.4322374559218, 56.01694914602465, 65.83708532394903, 15.56058179947638, 0.5428122116192695, 0.691764954357378, 0.17646731147843023, 0.7239481241952989, 0.3158333218626438, 0.7161207280812726, 1.8293395157783263, 5.684363572828232, 6.7300453974354655, 18.94393397915748, 87.43213361309421, 138.99081876201015, 141.04835294908094, 112.88593123036047, 102.02979118593278, 100.61991876171481, 111.56297068442069, 105.3925411162838, 99.24177831219089, 99.14065960914859, 107.14041202299057, 97.43551115835868, 91.88210964202882, 100.27479725499308, 117.2262691682385, 114.57855947556035, 115.50558813156621, 98.76034659724083, 100.6147647673084, 112.92029903781031, 130.88925730797553, 114.19638726019092, 121.22743975731635, 77.98424213163315, 108.11556816101076, 111.73318586041852, 125.23458803853683, 95.63091493421986, 102.24754548841908, 97.60662063475579, 113.32831967261531, 104.58143418835056, 76.49538101688509, 105.41016040309783, 113.52731720093759, 116.93257777921616, 111.13582457265547, 113.30899023240613, 120.94122440584245, 128.00153778445338, 127.89162512748473, 123.50872162849673, 109.89644973508774, 107.52927580187398, 100.29263619453677, 106.69829030190746, 120.27608456150179, 125.55809728560911, 125.53366091943558, 124.51310726904102, 117.77369868370795, 133.6326414538968, 168.3631112498622, 127.20074669007333, 54.064746287561235, 7.6591803662238584, 1.264788854506708, 0.35914149796289785, 0.6137054365488791, 0.36426656488930026, 0.2610795470255037, 0.28974612814284145, 1.2552241548415155, 29.430119991302494, 62.658118048021876, 62.86303051056401, 69.44573648514287, 86.12876138379498, 64.55966349570983, 175.1218100517027, 107.37900980057256, 26.192595651072843, 36.81615875613305, 58.947034189777995, 88.2830604430168, 90.16457434623473, 104.9819552513861, 109.22318273975004, 98.69984795970302, 8.427501590021196, 0.8601611924748268, 0.218726008409454, 0.28570939636518883, 0.23598123492012102, 0.3501351231769208, 0.21729207567630276, 0.2112038064027025, 0.17255713742586876, 0.1540808127291741, 0.2688646244425928, 0.17554494161759654, 0.35059633875085466, 0.2258041092465001, 0.20049447944808393, 0.2364354484504269, 0.1412764957715427, 0.2236925717443228, 0.1607749656203293, 0.3150719836834939, 0.13462018762384692, 0.11786474155322199, 0.1150697463702771, 0.29093313541623855, 0.13229151016041157, 0.1536125644680954, 0.16477495582113344, 0.16980056921320577, 0.19812596541258598, 0.07267915974220923, 0.11344801484336776, 0.26655771919796545, 0.33761341605455647, 0.3225352428853512, 0.2233272550567504, 0.16120570621663527, 0.11320526456280101, 0.16496114583025057], [0.04549473276241653, 0.11912127130574758, 0.035753346408807465, 0.0990032967961123, 0.04951914584624672, 0.18116939061832044, 0.07895246989304021, 0.1649016974073264, 0.1769112287870338, 0.07709325877048316, 0.05665420532046307, 0.07922467625429554, 0.0464340484881353, 0.04131662328877757, 0.046900182346543, 0.020715731849533417, 0.043297473851951866, 0.045259084116907856, 0.08970440665800726, 0.05665063918117554, 0.13230548360415045, 0.20227361139991593, 0.051225698628132386, 0.17734822066080186, 0.1456752347369348, 0.10622012849536636, 0.06604354362934828, 0.22062815876016695, 0.06905961646548203, 0.12912868552150267, 0.1275402558366618, 0.45610656421030726, 44.87511934772615, 119.84209783615606, 98.82031963717554, 103.32968819525935, 73.25464817785448, 52.97641408058905, 33.782601587234005, 22.080796572469897, 66.42220881677443, 71.73473758082237, 50.65827761926959, 36.990327681264574, 35.532076743341264, 39.39079861487112, 22.47628131220418, 2.7872901770376393, 0.2014511394044084, 0.020262734483807318, 0.05364091721393409, 0.16812231571924302, 0.16634646262372696, 0.27414848607394005, 1.1939912986370826, 1.4287199031922126, 10.043415138798377, 68.36615900839529, 134.1695825515255, 120.15486763369654, 97.04493722608014, 93.32751089526762, 96.34599439559445, 98.51198996267011, 96.53710011513003, 98.61495217969342, 97.72826902327999, 92.78230928605603, 87.09819870610391, 94.6322794883482, 91.020843444332, 87.73512101942494, 87.6172302615258, 96.51328348344373, 89.93791626345727, 95.68287064952236, 98.58665620127033, 111.28807529326409, 105.42298655356132, 111.4569176397016, 111.81583804468956, 130.26244686495875, 82.84215250322896, 40.16185422097483, 93.60469695060485, 108.22061707896572, 92.28725910186769, 101.86634602085238, 85.5996258028092, 110.85968971252443, 70.43378153154927, 85.96982694441273, 116.25516091623615, 94.17380932838687, 106.8924476254371, 101.4629694723314, 111.95677664972122, 114.012922317751, 122.9547417548395, 121.48338225580032, 123.88799128993865, 117.70129957506734, 115.88414392163678, 102.43849431314777, 96.60702028582173, 93.87571704003119, 99.74176283805602, 104.04122967873852, 107.8250382023473, 106.90376758575441, 112.70105423465853, 102.69585670963411, 109.30956902042513, 125.00512153871598, 118.80731382677634, 48.28751079497799, 6.176338128505215, 0.37627719943561866, 0.132850555162276, 0.4339581655879175, 0.09340502501976106, 0.17148392485274425, 0.09098067083546231, 5.941280290003746, 29.67910420510077, 36.93617543866558, 43.13418319148403, 33.296639534734915, 44.34379508418422, 56.24834152960009, 51.73199507497972, 44.961662523208126, 22.147567079913234, 36.593489723820845, 55.78302291131789, 80.56386732286023, 79.66528369534402, 87.72850005857407, 59.04632899069018, 1.938448454583845, 0.4472534376527033, 0.24478311019559063, 0.051909995175177054, 0.02689225636723061, 0.15637832573584973, 0.04542935098851881, 0.1736122243587048, 0.03683035494759679, 0.09616524747182285, 0.028615502204986352, 0.038158127046640844, 0.06292386123189522, 0.1914207042465287, 0.02505478873518446, 0.07896012311140377, 0.05338784389858765, 0.08666156670979916, 0.09334454237813912, 0.003055437545915465, 0.07628389453936009, 0.020724859787151217, 0.11643968011823394, 0.0486464721090611, 0.10962974069820297, 0.024549002165816004, 0.12927638727330393, 0.08785821903016298, 0.04818011608515536, 0.11870700926069291, 0.045847746077924974, 0.11867995103520733, 0.028184585408457828, 0.05373432631454161, 0.09420485145622685, 0.024846592850442377, 0.0634117175133959, 0.057318981947197076, 0.09441160326523167, 0.014890843604300773, 0.18867550477866205, 0.06050588856000574, 0.1542797044760758, 0.09953650931317, 0.15553028172542974, 0.19470113870357314, 0.03559460149957769, 0.023561024535146934, 0.04359331019523163, 0.03452748315589082, 0.06726274957820293, 0.043734864091440555, 0.034334597538315484, 0.07961389488510548, 0.01993210051178692, 0.05009712854159936, 0.06780815821501517, 0.08144577199052419, 0.16650777009706344, 0.12641223733343426, 0.09962101647209737, 0.043732424101401726, 0.2218911925991697, 0.022666350667995792, 0.11721093147512406, 0.060024685752127445, 0.12388739539610764, 0.2323843448633148, 0.4611810080466732, 42.27006543067194, 135.24682229565036, 113.89686722909252, 122.2632278934602, 103.80562859196817, 84.32865235113329, 62.92082663505309, 35.52810730472688, 40.21803432895292, 64.79109510298699, 46.54548029745779, 44.66548827386672, 44.03015059809531, 49.931968412091656, 32.146257392821774, 3.7803938552256557, 0.40020289139882215, 0.050480367856160294, 0.2545306903700675, 0.8711219494861941, 0.43894123045667527, 0.9540364422625112, 0.5581377086139495, 0.9361235905558833, 13.493540767700443, 82.26596416965609, 139.75136633842223, 123.2490764125701, 98.64668415438746, 96.3878539300734, 100.4894293508222, 103.21059719208749, 99.4243803331929, 104.07361276688115, 101.6719376656317, 97.39163552561115, 92.70945518247544, 99.03614413353705, 94.09217696036063, 90.35275397762176, 90.46034459144839, 100.66875227036016, 92.64957627942486, 98.64969653467979, 103.25997983255695, 119.17269829780825, 109.67754225577079, 116.10520085980816, 113.77227706293907, 127.48925270572786, 86.45128219358384, 47.75363306845389, 101.7553037212741, 116.79891124848398, 102.5670539179156, 109.63751839053248, 96.58832626958048, 117.6893049670804, 78.90368492372575, 91.02090620225476, 117.01547315043788, 100.10395449976768, 112.25678305472098, 104.17081694449149, 115.16820153882428, 117.96774618087278, 126.82373631385066, 124.45556609861313, 128.88050171636766, 123.55804935578378, 121.64638027068108, 105.26592700712143, 102.60572064307429, 100.29212628641437, 105.14107796453662, 110.1285049992223, 112.39167336494693, 113.26542054453205, 120.98377427747174, 107.19820422510948, 113.22189792510002, 134.27504724071872, 135.71447864655528, 62.78487336251044, 9.90432789248805, 0.09203804071031271, 0.13474337456207122, 0.6775652388891866, 0.08873522116412079, 0.12741837890878802, 0.13670624504166265, 6.338344274028656, 37.60778327142039, 43.29081519957512, 42.26777476649131, 37.545711763443485, 52.52742821170438, 48.737818502610736, 32.35502554524329, 35.186704204928496, 41.430136926712535, 59.74982961531609, 70.4148207941363, 96.14266657060193, 84.68750999819848, 100.45106072579661, 68.66856590394052, 1.464625892619933, 0.41782110568977177, 0.27319348086753203, 0.06585271878828926, 0.106875034079196, 0.09204324244731858, 0.05743369978341845, 0.06882777527695702, 0.06753586758408817, 0.07541434644090553, 0.011819306002449126, 0.09694776798207914, 0.10055039603743823, 0.21679658532863666, 0.009075537203781067, 0.028146671717085188, 0.031427835872877515, 0.05779584869742394, 0.10566523569005151, 0.032921862458029104, 0.06403538969255264, 0.017876757474075404, 0.12995374689419426, 0.029552873982597264, 0.09313884010959057, 0.0791342702183512, 0.19880441287832878, 0.03994687723236219, 0.04567892711249091, 0.030416168888369878, 0.039314322263723424, 0.06209365174835248, 0.057735335412285024, 0.026735654588969007, 0.03611520420940172, 0.02653244976705361, 0.06948471099378602, 0.24822889707021176, 0.2603231424525861, 0.14374783412823755, 0.31026533354193936, 0.2412687584517464, 0.3022940967592501, 0.2449169763994794, 0.16639031349651276, 0.2971708990873829, 0.1509105417156412, 0.1417634825432493, 0.1118220008849617, 0.1323509892268527, 0.1290023576227888, 0.23865209321581551, 0.08364123442480642, 0.19362950427157266, 0.09799134061341325, 0.2027282692612179, 0.1148387632002273, 0.284186658719855, 0.33902479515921685, 0.45485348951432014, 0.3389508829962823, 0.31459235135586033, 0.29852816174107216, 0.1726995531709925, 0.24437467807963972, 0.1457891520112753, 0.3569044599369649, 0.2878563424512264, 1.6902054461740679, 85.6095729335662, 153.6619423281762, 124.21747822915356, 138.95791792100476, 101.1037588119507, 70.76999141323951, 49.78728786591561, 41.83618460932086, 103.7043216151576, 107.54090170706473, 80.09779560950496, 61.24583728851811, 60.318341870461744, 60.94892171121413, 42.86191971071305, 4.537693954283192, 0.5970867831380137, 0.14040012182968278, 0.5514174627680932, 0.8285367765253591, 0.21931949672439408, 0.7638088433492569, 3.7417896428415856, 6.553428913316419, 13.654182418700188, 78.94351267045545, 149.94973274969286, 133.01558986786875, 107.22398988662228, 100.85115032811319, 105.33337608460458, 105.41675782972767, 104.83263846366637, 107.36375178060224, 105.0036616479197, 101.47100248644429, 99.95003284946566, 104.53624848396548, 101.276398012715, 94.94553565979005, 96.18068218231203, 104.8471433885636, 98.00788694812407, 101.75905350715884, 104.2720062501969, 119.90799365505096, 114.40729310435634, 115.0487732118176, 116.68200892786827, 128.13482776764903, 85.7006739031884, 59.28204774856568, 110.21040408842026, 127.25893897394981, 109.18548091765373, 114.5884281589139, 104.28206320731871, 127.59951837601201, 89.93916357717207, 96.97282837283228, 117.84221464587797, 101.8656478389617, 112.21040494980352, 105.9124355931436, 115.6927401019681, 120.32135655803066, 130.65467603745, 127.46640097710394, 134.045651343561, 127.76549739222374, 127.57133222395375, 109.3232031791441, 106.94837277935399, 103.82413433444117, 109.0910537781254, 114.56444678768035, 120.27435871862598, 119.14403361658897, 123.50527778748544, 110.97772167574976, 118.6439000406573, 140.74756991478705, 140.2453967063658, 56.12135087290118, 8.480366314611128, 0.3223216269285448, 0.4502550620705851, 1.0102148342036432, 0.22510646361737485, 0.329173946332547, 0.37971730193784164, 9.629448190812143, 50.52503470451602, 59.428893443076845, 61.78625752848964, 53.4900680665047, 59.49327130471507, 75.4500929001839, 72.32430119668284, 57.39247729701381, 36.004749805696555, 50.66624003071939, 75.68420348628875, 99.26897602696573, 97.4115768555672, 104.91639675632601, 95.0105764019874, 5.552137042245557, 0.7853208374111884, 0.39932268701734086, 0.26200819880731646, 0.14682398357939336, 0.43372003481753413, 0.17567834816873076, 0.22258606499000905, 0.1614879023644232, 0.18916727193901617, 0.15463239603465603, 0.25339919382766374, 0.2881355661778681, 0.4569417532653578, 0.17438324588921764, 0.1936652192906026, 0.206984898916656, 0.17153551321356528, 0.23768912069499495, 0.1166414829992479, 0.19595632780223124, 0.1358344369838315, 0.216627448436714, 0.1983401942397318, 0.22103084521668576, 0.15416581784525227, 0.29057497398987897, 0.1729414377722048, 0.11624962902597843, 0.1509875182302729, 0.20760991941055945, 0.2779503046504913, 0.24296708344932527, 0.1065854911482142, 0.09636337313080028, 0.15169568990747775, 0.18105207191359612], [0.07064471366785227, 0.06837203723168181, 0.041382085501907334, 0.09872590401960958, 0.10893939588699611, 0.08370506487065747, 0.018158788912959637, 0.08493745519268898, 0.3513105165573859, 0.04179581511585463, 0.06200814101424429, 0.059050256386399276, 0.06171219741865512, 0.05840072490935845, 0.06496381164798815, 0.06137039579991853, 0.0538296276523221, 0.0771665733848368, 0.05230754884260316, 0.1215417720677872, 0.05281508975331822, 0.24180462163302208, 0.11836819921530063, 0.17657680076456841, 0.1310168930719937, 0.05162610597307644, 0.052822972798059066, 0.01632843057685081, 0.03401754055953315, 0.03029265253233814, 0.7537517636533707, 50.680019317134736, 130.06905048124253, 101.39013105823149, 107.4938960229197, 64.66976050407656, 54.621499276930294, 37.404867295295965, 30.72788127007023, 73.23486374270531, 47.80278428908318, 41.54438772509175, 43.42125361965549, 37.273652245921475, 32.645698670418035, 8.228311865560471, 0.18493725617806758, 0.05686032510693035, 0.2510842753033484, 0.040766334671887665, 0.1570042195699869, 0.08142149466420374, 0.3764926540034433, 3.1419560361293057, 6.983545239894622, 53.696059180844216, 122.80633495699976, 128.91046862448417, 100.0582431977795, 94.98005251730643, 97.89386364721484, 103.26840508368709, 102.9635114054526, 97.8548203745196, 107.5830279627154, 111.10196667332804, 110.05158732014318, 96.10098746515091, 83.55785954383113, 81.59014763370638, 86.81929465263121, 80.53673236600815, 86.36902224633002, 80.36665055059618, 83.7974222244755, 101.99642750524707, 111.4491121230587, 112.90325241704141, 113.9682072977866, 112.93929115418466, 112.27404932821952, 104.63790062935122, 120.53689864373978, 59.07787269161594, 75.32402792284566, 92.7722680184149, 84.93233649961411, 89.0486208085091, 86.69737169819494, 90.49812486094814, 50.27330875396729, 96.39577711782148, 97.72668438573038, 108.88847120346563, 102.41356372833253, 106.96253253567605, 105.54333271518831, 112.90180114007767, 111.09880524296915, 114.74358927819037, 112.04699116368448, 112.59703297768871, 107.69163839278683, 102.70829062308036, 95.76916279331331, 94.21195045594247, 98.11808986048545, 99.48447888897311, 93.83484594283566, 90.5610082995507, 95.28930787117251, 109.95133153853878, 101.28282285505726, 100.14532766034527, 105.89856609221428, 133.40680706885556, 119.45137485381096, 51.25414448399698, 2.0680020124681535, 0.376087301560948, 0.22299354715693384, 0.06173856233456924, 0.06801114087143252, 0.16635686609773867, 2.16166821218306, 16.989354164369647, 28.58402159906203, 35.44848711259904, 43.807685529032064, 73.42205493680893, 82.44043903966104, 52.03759085747504, 33.91782137655443, 25.68700998060165, 25.25186419487, 46.489162906523674, 60.053640719383, 74.91028062758907, 86.67243326863935, 74.16867809910929, 14.155850621961779, 0.5901903983566069, 0.09153246864556305, 0.16817151388574034, 0.04145242769511477, 0.057466469194379546, 0.07276228028199366, 0.07015820187065872, 0.06579205994644473, 0.06688824749641842, 0.059718878774513165, 0.10326610878109933, 0.06402675971208562, 0.013796643094880687, 0.09373774466615531, 0.10846367060777642, 0.16504705493007937, 0.030821498348227436, 0.039536008956812085, 0.12337086827404077, 0.0387433416119987, 0.03020853224781252, 0.014674696684514564, 0.049964583839379975, 0.01291758688767591, 0.011725624940628487, 0.022651848623589165, 0.07665183124763351, 0.09385952200259894, 0.0718273695618395, 0.09691312548614318, 0.09243194013834001, 0.1111508006109826, 0.04433961772930719, 0.033086873966479496, 0.03309491405924482, 0.03868994528367635, 0.046568466275329554, 0.12922827695165912, 0.07877364198887542, 0.07149848035506665, 0.03475845100418214, 0.04277166557468234, 0.12886527384961807, 0.29311072501924734, 0.03900108806368324, 0.03813041764641962, 0.024357646808869416, 0.06952668495115734, 0.07280809233986563, 0.015219540331482649, 0.04530002002514178, 0.04730150899699619, 0.09761796468087743, 0.044367070490073775, 0.11423796640648959, 0.11379289230512035, 0.24535343201170046, 0.12255458626896144, 0.10278620832269231, 0.1325837267382491, 0.10847192137472092, 0.02139989816163096, 0.03411930001851532, 0.031277471965539365, 0.10171220667900578, 0.6836777012194357, 50.9768799812563, 143.28278603092318, 113.50286514528337, 124.73637642398958, 94.31812117176672, 91.38741247115597, 53.57195146622197, 20.934954574031217, 29.992003440856937, 48.58441460517145, 43.7471241335715, 54.790580887948316, 46.70588562565465, 43.36512842485982, 11.725723628074894, 0.022702036958728588, 0.21507705501731367, 0.2876346366059396, 0.1337164949866072, 0.5139352014708904, 0.2909484265312072, 0.6394565934615751, 2.127108944039191, 9.605674705197735, 64.07998900259695, 132.54032411882955, 131.72533404442572, 104.16490985501198, 97.07100529824534, 103.39618021442045, 106.85007033809539, 109.70020571062642, 102.6180447301557, 113.09613889263524, 116.30415916442873, 116.27267037668537, 102.29189180558728, 87.82476286734305, 87.48348528339018, 89.60398920120733, 86.02110801204559, 90.5271739344443, 87.23435201952535, 91.00202391224524, 106.79412164995748, 117.77318877558555, 116.40637613111927, 116.80075476246496, 113.37694137327134, 116.51701834893997, 106.47196169822448, 125.11763864947905, 68.26909603611116, 81.75658948959844, 103.40055757953276, 91.42707547833844, 98.13901962772493, 96.71969429139169, 98.94155225446148, 58.31080613597747, 99.19020698916529, 105.05433082580568, 113.09434244709631, 108.38010065017208, 111.86991968462544, 107.33476546502884, 111.81780707451605, 112.62128891483431, 116.42877286480321, 113.42285663850846, 113.97157269139444, 111.35395542267831, 108.54813498835411, 100.07205778552641, 100.91603417550364, 101.08693184391146, 105.0499063922513, 97.09633596481817, 93.94038907943234, 97.65751731011176, 115.69443456588255, 108.66007158833166, 105.88476719394808, 106.98497633780204, 140.64552553238408, 134.4694712854201, 64.40082711558189, 5.128029296475073, 0.3213159373450664, 0.19419559728234045, 0.05289030426572408, 0.022555840569698525, 0.3078279482020486, 1.5656174863538437, 20.395491392381732, 39.079287898155954, 39.34083154124599, 45.79336581691619, 54.901489826940725, 54.19217624971944, 35.19306628934799, 31.43065037265901, 38.72718457252749, 46.504405237013295, 65.72168527110931, 75.47489012441328, 84.81261791721468, 99.23070153882428, 86.43985240690171, 16.531021287364347, 0.5490684533311475, 0.0916226601768886, 0.10892843316879966, 0.15780789176783255, 0.05227651462079056, 0.08983640360736078, 0.06536354866599844, 0.01677565930050708, 0.06174395176311655, 0.04226070408138537, 0.15290258482338923, 0.0608615180657756, 0.03866254614906446, 0.025483842022837173, 0.01203515510555477, 0.0751884041293975, 0.029134917478527755, 0.023571518024489767, 0.03575183721559663, 0.03095887515002922, 0.034584981885047696, 0.08377326201767692, 0.0521499339130617, 0.03377322745960086, 0.03428334625618112, 0.05123927370615063, 0.05440322832474786, 0.0012486179794875846, 0.015090521548934763, 0.07747221948398698, 0.08570669939921749, 0.030966126172232534, 0.04867465265335576, 0.01809105141869476, 0.028806960983802716, 0.21646485393566472, 0.1842433950232883, 0.15335940305263768, 0.26854853656503463, 0.23439532566455104, 0.21526437883655872, 0.11998272951572173, 0.1721757022483695, 0.3701391497686986, 0.10740086916954288, 0.1968653370896655, 0.20958409734791328, 0.19469065862076898, 0.2140910998587647, 0.1587165792983386, 0.20665635444944908, 0.15010979597366628, 0.31352338290983633, 0.14684849839297034, 0.2585656141802188, 0.14343818138924339, 0.40612107383147367, 0.3002767727500008, 0.3083177235337996, 0.25804427602598745, 0.1957594278839327, 0.11388954195764758, 0.19916208400841684, 0.15434779437078586, 0.20049830988770534, 0.7850017158254501, 95.66470223088419, 162.56434194503294, 124.25862389226114, 141.89881693932318, 88.93685679281913, 80.23299186460434, 57.632283164608864, 47.20457969173309, 111.18512092098113, 77.45500456902289, 63.6916978897587, 72.35107529547908, 61.710626386827045, 57.393308839490345, 16.21324360370636, 0.35959165122720504, 0.31632530352761673, 0.6310841717546987, 0.39686768165519165, 0.4936973954881392, 0.23493409997993903, 3.129266433177456, 10.087663396712273, 14.512600975651896, 61.466733409512436, 138.2610539467104, 143.46448590678554, 109.11980475148847, 99.77689158531928, 103.64096749213435, 113.36438194397958, 111.54318624927153, 105.87008184002292, 115.09784206267327, 121.87432489087506, 120.67276170176845, 108.01663814052459, 93.032925205846, 91.70246508813675, 94.57844888010334, 90.46614969930341, 95.23299832497874, 89.5676366744503, 93.33670493095153, 111.5666812466037, 123.42933285620906, 118.47596768409976, 118.9101819069155, 115.12918180035008, 120.49685124428042, 111.88802534534086, 131.63016165456466, 75.8740540473692, 93.41251650164205, 110.92211031144666, 101.34468647741504, 104.7788235449022, 110.12849715448196, 109.02336151369157, 66.81058622175648, 101.10459819916757, 108.52184726345925, 116.48944408662858, 112.64480744638752, 117.4761712166571, 111.39295947167182, 113.3693241303967, 113.13509587318667, 118.0974824966923, 117.5986433029175, 118.95312401556201, 114.30144402288623, 112.2514094075849, 106.05042457580568, 107.29193318274714, 110.00166339258995, 110.13825601147069, 100.87872459042458, 99.86802393390288, 106.6424592848747, 121.8981493673017, 110.70428540629726, 108.32819200331166, 112.1261759727232, 145.82114004319715, 130.54337486144036, 57.474713710046586, 3.889943692953356, 0.5000182337337925, 0.42398100418429224, 0.21870198389214857, 0.1588363494844206, 0.44091844210220926, 3.4092435000404238, 30.201297190881547, 51.77756124927152, 56.44915903768232, 71.78743854645761, 105.96778808101531, 117.48245485367315, 75.15632306375812, 46.65300423099149, 38.59423191316667, 36.276538679676676, 60.9850702747222, 80.57684252339025, 95.8290260068832, 106.92141040678948, 113.1122676787838, 29.288585186004642, 0.8140061723609125, 0.10180207645340313, 0.2770559429641693, 0.23873371222326834, 0.13625929402487894, 0.11596118926160759, 0.22516611122315933, 0.10584224030495652, 0.1555414053220903, 0.14521564326940045, 0.34222456055783457, 0.2756869438434801, 0.2340745952941718, 0.1814045489675576, 0.20848312174841283, 0.25040294734701035, 0.0949770910665393, 0.13694223076585801, 0.16431881174925836, 0.19149890650183926, 0.14603665969785184, 0.0830896741019622, 0.27321931335233873, 0.1111955401457606, 0.16512672807420456, 0.2389451218468528, 0.14700358523236168, 0.186693083735243, 0.13584002942567872, 0.14484329389468317, 0.18440591291554514, 0.20318009259720005, 0.09685144774735936, 0.12771218894950806, 0.16963874080008076], [0.032984436519684336, 0.015127047663554551, 0.0445271828662484, 0.11001498333268589, 0.07689907080343655, 0.10657003915478146, 0.06907540553760144, 0.15799866298273688, 0.12590982155093264, 0.10548197979768438, 0.04826766078270251, 0.04787854940420197, 0.04951447270990861, 0.05830816616634688, 0.026379199623460733, 0.03652393893008271, 0.09156351818913415, 0.03138459020955188, 0.06144974335667588, 0.13112696458495435, 0.024898508713851054, 0.1558900979017058, 0.21455444515712802, 0.1377445086836815, 0.02666820246245592, 0.06742622508036514, 0.05674526636158267, 0.2677786794881667, 0.1151102647605923, 0.6339954897280663, 48.94338992334182, 127.2267363148351, 109.91225688688218, 93.36445177755049, 74.56737918238487, 65.38353381618377, 24.356551824077485, 37.37144477905766, 78.11874804958221, 69.82073076309698, 46.11165438928912, 35.93512773513794, 32.906614734280495, 21.300572426088397, 0.6759098148153675, 0.2427686053899027, 0.2061654606293286, 0.11545082148645194, 0.14578153709730796, 0.05051877950468371, 0.1456634063393839, 1.7486937464244905, 2.790395468473435, 25.816934570189446, 108.30619535138531, 129.74656105041504, 101.84165077824747, 91.95456366385184, 102.10290416594475, 97.14172563245221, 99.2183852964832, 103.84784113976264, 120.22212843741141, 112.33170816975256, 114.84741441665159, 104.00384949099634, 107.33616967355053, 104.76052961041852, 93.24782402284684, 79.86499509503766, 83.6043788540748, 84.39613280757781, 91.18398266453897, 93.89489743017381, 112.4987619153915, 111.25118932416363, 113.86049116811445, 111.14040590101673, 107.54878567111109, 103.20847911219444, 108.45568472339262, 106.1208232756584, 110.92326348827733, 88.77886372227823, 46.66703454909786, 104.63795554253363, 90.17088151747181, 91.99328530219294, 99.81995136507096, 70.41715068201866, 79.7446410886703, 113.0344400098247, 101.77696304936563, 108.82359520081552, 104.60148534467145, 104.1841059346353, 102.65622508141303, 107.04403938785677, 111.3514764847294, 112.62335208154495, 107.2377730954078, 109.54963376445156, 108.80975707884758, 111.81059775813934, 103.18271698490267, 100.87181337418096, 91.80701978745, 90.97204915938839, 86.28029823303224, 91.51949436433854, 87.0404927961288, 86.39611013474004, 90.44618483512633, 102.03749472095122, 104.43651829996418, 97.6223885628485, 106.96512914473011, 128.23799394792127, 106.30302521490283, 15.456345792739624, 0.1521073549144691, 0.16560148808263964, 0.015588756406589624, 0.15526267189172008, 0.19277882491869314, 0.2431687177909959, 10.523954514534244, 30.51685775479963, 24.315463035337388, 38.97063039964245, 50.253677291254846, 54.37922623849685, 76.73638712975287, 39.14739593382805, 25.035527829200994, 21.158062911802723, 47.93139096229307, 73.92752293617495, 75.50647304904076, 79.1231336901265, 94.57563261831962, 24.571421223302043, 1.2764894073047948, 0.046721752808098836, 0.10136554423238962, 0.09274084211116837, 0.07696762035090117, 0.07803413731556746, 0.08675946508564296, 0.09336366393272916, 0.01889834721242228, 0.10520060336397541, 0.06416915630501124, 0.1739512182651989, 0.015869559231965293, 0.0879355019799644, 0.03538855832190283, 0.06919878399780682, 0.08829912561322413, 0.06474608945990763, 0.05350623895684558, 0.036583341387731415, 0.010915540586856586, 0.03518777050738854, 0.06123169175078792, 0.0374747115007091, 0.10272541158502141, 0.0324118624050771, 0.053666129167522156, 0.11796251735499791, 0.0644642380516856, 0.08667478938737223, 0.033043486576887875, 0.023248204022585865, 0.1331773069837401, 0.026929605068759094, 0.025576305004858205, 0.028871086373504613, 0.03290859381518057, 0.10106300078933278, 0.030776262771518483, 0.08952455219602393, 0.06213928377556224, 0.1072935785557474, 0.06832974151738229, 0.04840850221714185, 0.07268767863992723, 0.015649745623851498, 0.06465490201428052, 0.08191156110936597, 0.019917698058810447, 0.028698115211520946, 0.06227413823287334, 0.029007028675668185, 0.03522263516882255, 0.08929679425613535, 0.041459276521157835, 0.15785577226310007, 0.17380753081412087, 0.22821019223380476, 0.16607421029719616, 0.16750232076212285, 0.03515332719431289, 0.19151995859799847, 0.09267946314667502, 0.44941708445549017, 51.324484348297126, 141.6125309851862, 125.59037839212726, 111.2190180440103, 98.19900835714033, 82.71178076344152, 50.03515420421478, 44.61663123100035, 34.82389673109978, 67.75270031344506, 44.47000518921883, 48.26827156928278, 40.819204238153276, 28.363539288120887, 1.4482427652805083, 0.37256329710925784, 0.12333863129418705, 0.2098378869554689, 0.3027750161145964, 0.12084654727650267, 0.8343454390283555, 0.18074424246386175, 1.5665750349721603, 30.730554365342666, 119.04722167599587, 133.71231263683688, 107.539246466852, 98.2069472343691, 107.25660831697526, 101.58705757510279, 103.90957140153455, 107.33969980670561, 123.25546203121063, 115.73477222073464, 119.38682833025534, 110.43976076187627, 112.3909124251335, 111.60317497868692, 101.88796612524219, 85.24733420341246, 87.80944208944999, 87.31367803389027, 94.52285320528092, 99.77284369930145, 116.80642650973414, 114.26515425405195, 116.86324596405031, 112.59793512282835, 108.39255025309902, 104.0980883567564, 113.86719057636877, 109.04813520369991, 115.78082869129797, 95.37183453959804, 55.932382845109515, 110.99202263739802, 99.5106803217242, 98.73071701295915, 109.56686081424837, 77.07018083141696, 82.10587655344318, 115.68984539278092, 104.38693169624575, 113.27523431470318, 107.52215277764105, 112.30944479665449, 107.2441900930097, 108.58039256065123, 111.22862785093247, 117.51666576631608, 112.8695906362226, 111.82891522684406, 111.99222703133862, 113.97933113959529, 106.48393277199038, 104.36840241955173, 97.66118864859305, 93.43957301109069, 88.94186958189934, 95.79450914936682, 91.79928487347019, 89.16560157652825, 92.65133350126206, 107.60108655498875, 112.61269107941659, 105.1789523709205, 106.14423198084678, 136.14196992689565, 122.83758055779242, 26.839761234098866, 0.11135663311447828, 0.14992121577022538, 0.18592719499382282, 0.08194217398282021, 0.17094265309072312, 0.05430242647567103, 12.219450012330087, 39.10539519402289, 31.229075847133515, 36.03925881847259, 45.86889497695431, 46.16756777609549, 38.47357196192588, 38.932097035069624, 35.71296076620779, 38.351005738781346, 61.12783670425416, 86.23082145567864, 87.50487004556965, 91.56390343942951, 113.02309651528637, 33.274725252582186, 0.8713378637067734, 0.08679960809287526, 0.052738128560445005, 0.11677921794715429, 0.03643657426319776, 0.09139254268619323, 0.025844751789625135, 0.04461518721655012, 0.1449357760289023, 0.02647446648728463, 0.055967043604581594, 0.05235090558867782, 0.024440208104469126, 0.03398972390700252, 0.03575165718493443, 0.03666602525739901, 0.08367825179330765, 0.052990903101500966, 0.043795634016034105, 0.023982405452237978, 0.03892629489963574, 0.031561569926599344, 0.036960570742526365, 0.046554845232035846, 0.08331060619844545, 0.018185816494928255, 0.01712067082764641, 0.03494410092131265, 0.04060788470650873, 0.05972922862237019, 0.060934330892538836, 0.06600383729223283, 0.11402705474005592, 0.11058666878530096, 0.1472304698320166, 0.09665216529561628, 0.16111789721875422, 0.28134294034492585, 0.20955202890740288, 0.20697179881315078, 0.1354785891430032, 0.2874309491486319, 0.2306852844213286, 0.1372051214979541, 0.1816241710536903, 0.1367148405481731, 0.15949434240258512, 0.12141054120635796, 0.09760612096156805, 0.15172987275065916, 0.18821128614006505, 0.1579397814648767, 0.08186215609912911, 0.1778111369499276, 0.18762440150303228, 0.2691377807528742, 0.2985504702214272, 0.2761329295894792, 0.20894783068328135, 0.36658211160571347, 0.07318409595398173, 0.4179674591268263, 0.1957010519841025, 0.7941120334209935, 99.46167422879128, 160.34362146931312, 131.71491622924805, 122.44066023057508, 96.32898699852728, 87.56312508736887, 39.48509631618377, 60.17766214186146, 115.18072174441431, 107.1109942466982, 69.77503515058949, 62.14568391922982, 53.74337865460304, 37.97908659904234, 1.914354070059715, 0.7746746054580136, 0.37085234698268676, 0.33667790012494214, 0.5271077768937235, 0.23901256822770645, 1.434249709690771, 6.380343542945001, 8.783993067279939, 32.23957842396152, 118.09962411080639, 148.28070148344963, 112.03164685157039, 102.18389326526274, 111.03348993485974, 107.95838309872536, 109.85330366319226, 110.80615720441266, 127.41228011346634, 119.42267094888996, 122.8269430898851, 112.46613564029818, 115.72991632646131, 115.26541356117495, 107.76048383405133, 91.90949563057193, 95.55375406819006, 93.41100246675553, 98.91895940226894, 102.35656384498843, 121.00702608785322, 117.91529624692856, 117.39937120868315, 115.69023762979816, 110.05694527779858, 109.42512989044191, 120.82106651798372, 116.72890478564848, 122.72043505022604, 98.84747812824865, 61.12170603967483, 120.87401067056965, 107.27455708288379, 107.53916801944857, 120.08825009868993, 91.08242465603738, 87.02906300944667, 121.4770358608615, 106.254544719573, 118.24301027482556, 108.99897221596011, 114.75492492798837, 109.71142368931925, 114.15663796086466, 114.18290999627884, 121.36076896421372, 115.88436357436643, 117.83753133589222, 116.50146222883656, 118.55315992909094, 111.53063466472011, 109.21774633469121, 99.01281387575212, 98.79442414929791, 93.00356234273603, 100.99544648201235, 95.00807392981746, 93.81830138544883, 97.63184147496378, 113.98007638992803, 116.43721380541402, 106.61553613601193, 114.58036376583962, 140.2292679202172, 120.84818578535511, 22.462011729517293, 0.35334561380647844, 0.2294641709135425, 0.3938301736789365, 0.23121969203554818, 0.4261954579382174, 0.7014532699700325, 16.917706189617036, 49.30516189144504, 40.45092505793418, 58.66323501833024, 74.00102815320416, 78.16635777873378, 108.57669768794891, 55.26330886348602, 37.50637039061516, 31.50814660133854, 64.02582891525762, 94.37869041196763, 95.52960795740928, 96.13178591574393, 126.68871264303885, 52.82672859007313, 1.6701989068138985, 0.20438105799257758, 0.1616661250591278, 0.1947393205257193, 0.2070048018809288, 0.1069284763727938, 0.11409591072269025, 0.28612277740913056, 0.27971576959375416, 0.1448308066615174, 0.14442785973510436, 0.2842244421762805, 0.1176190877994222, 0.2689887306863262, 0.21307840823165833, 0.17007849059037625, 0.20467443902406002, 0.23010388497383366, 0.11674713418488541, 0.1233572548916263, 0.166042432970097, 0.15309004653846064, 0.09787058217390891, 0.18929185315726266, 0.198122747843304, 0.1375790490137954, 0.08110939810473113, 0.14035611773931211, 0.10568056510941637, 0.22062517101726226, 0.10386512058997348, 0.1730550639331341, 0.276671918409486, 0.14482288531238033], [0.05643965090594946, 0.04372193635771832, 0.027319348469797163, 0.029030685470769965, 0.024631910116201448, 0.013516731804326899, 0.059656028921205195, 0.11904185863151667, 0.05634148056889254, 0.010343739263442977, 0.0536586023536661, 0.05703926026340454, 0.18623085692524913, 0.012641213965722391, 0.04425159039636774, 0.03676861209133941, 0.01078168395906687, 0.028798851943124208, 0.056048789016541936, 0.036104743278795676, 0.07418152710963642, 0.030058537977897835, 0.13552303756436995, 0.08374561390448963, 0.13095657130883587, 0.1084286220852406, 0.2250816883339036, 0.07980768448643147, 0.5740977102710355, 45.80809431691324, 124.15490858016477, 105.83955011060162, 98.61497571391445, 82.51776464523809, 47.63031767260644, 34.02760067293721, 66.1588373491841, 66.95915775914347, 49.377227598621005, 43.036257297761985, 33.47398950207618, 32.06090465668709, 13.446148730093434, 0.17002379191258263, 0.03782534228277303, 0.13918712885389406, 0.0897768632538857, 0.1851171949097226, 0.21237512419541038, 0.914072638317462, 1.9286529479488252, 0.8329941212169586, 55.16073888347995, 122.91565925844255, 109.01416747800766, 94.33814094912623, 103.00431189998504, 103.41981641707882, 96.41603223739132, 105.04111243832497, 112.20461553142918, 112.05221576075401, 104.94621461437595, 106.62305924200244, 108.73512221920876, 109.30122221669843, 102.0480380519744, 107.65087712195613, 97.68765680251583, 80.2098891042894, 74.06573941630703, 79.80340603859194, 87.61503373422931, 100.39965414231824, 102.8465384821738, 106.96808661184004, 105.16134877358715, 105.38625747926774, 99.23729896545412, 99.950495689146, 89.12180439118417, 90.09442667807303, 91.2531497401576, 115.72388372113629, 66.16035922881096, 61.78612024553361, 91.45581076222082, 75.96259763163906, 93.24809074401857, 43.156544623836396, 94.8306651269236, 99.57760380160425, 100.79346795235911, 99.96942504759758, 110.35939139704551, 106.82068394076441, 103.01204681396486, 100.89057014834498, 102.17393044502505, 105.62167029226981, 107.35565600856658, 107.20844945599957, 98.42354051528439, 97.32215466037874, 101.86691868689753, 100.90007012890231, 100.23953514714395, 88.73094020351287, 83.96584879967475, 87.25693702697755, 84.55733437691966, 88.39722494925223, 85.25621444948258, 84.17662128325432, 90.14116564104634, 105.81969507278936, 98.45111477759578, 95.47876619523572, 104.3619461982481, 132.98871378744803, 27.035099191050378, 0.14855007160334818, 0.22171874620741416, 0.07483845516558617, 0.314355262465054, 0.20189606794907203, 0.09326142949923392, 3.114927718716283, 26.148390539230842, 29.99503739418522, 46.431558978173044, 58.64874578291371, 80.57571288078063, 66.67857493123701, 44.96594967380647, 33.515335206062566, 28.71857850782333, 44.3072582060291, 53.50362770019039, 82.47400668359573, 81.83046340942383, 97.78392745602517, 39.18232071784235, 2.2179527532669807, 0.3537003431589373, 0.08034836636075089, 0.1177860490016399, 0.023168959887698296, 0.02149738284999565, 0.026874211166174184, 0.06496047150463828, 0.032759788896768324, 0.018317878561755343, 0.025280192869925694, 0.048072565001465624, 0.013959229935050733, 0.034515099344594825, 0.024017815951318033, 0.02408738439572194, 0.03366083853066929, 0.04454021785228003, 0.04842334134023517, 0.10991559108538974, 0.050488545844751986, 0.03228781361793799, 0.06712221074849367, 0.09275091616737266, 0.03123313654214144, 0.0201545245645027, 0.11864951436197567, 0.018829586990778486, 0.03883986486001842, 0.03319856958583959, 0.03868391617171226, 0.04420304723504571, 0.0778630085950417, 0.021880580029720743, 0.05564786073180938, 0.05596536587202742, 0.058567295406734755, 0.05225193468974002, 0.026126358049711394, 0.08308150760468938, 0.10857241678862803, 0.027664484486224192, 0.10075195377031643, 0.012000447492145244, 0.07584642769107897, 0.13560864022902905, 0.07054937402567557, 0.02672989935343785, 0.02493705634298104, 0.09099690423857781, 0.05984766964590358, 0.1035127814318384, 0.03741415608073435, 0.06554919475268933, 0.07560993634885357, 0.18014286344330158, 0.034597802366460526, 0.24514487223519435, 0.12992648948584834, 0.19565254329673706, 0.13461240417053624, 0.3095901342889955, 44.94589067274525, 142.86659117667907, 116.88641932702835, 116.18163216498591, 98.01041295451503, 74.8769953943068, 60.491216413436405, 30.93177587755265, 31.68079756921338, 58.40815544128419, 40.721046924591064, 42.68931188891011, 42.040559707149384, 19.63844060897827, 0.17019050796666454, 0.049702198725313916, 0.21466747376947634, 0.07210539053044013, 0.2941357506619346, 0.5146817694748602, 1.3756050049297273, 0.7690097836236801, 1.566697609040045, 61.73468620546403, 132.38019727891492, 112.42829261287567, 99.81889232512444, 107.47903808470696, 106.6084837144421, 100.6213935728996, 110.06910462533276, 114.86730867816557, 114.54620776637908, 109.2727771882088, 111.64305763859903, 111.55950330918836, 112.4750864890314, 107.29450625758018, 108.17827901532574, 103.02060542568084, 82.31278942477319, 79.82357486601799, 83.68983161064887, 92.97503886684295, 104.62775738008561, 108.37569975083875, 111.49975776672365, 108.97881123327441, 110.2880277941304, 102.57470253975161, 102.00926934519123, 91.09265419744676, 93.64909818095546, 97.79057979583742, 121.51471414873679, 75.1626459244759, 69.87714229091522, 98.19820819362518, 81.56473067498978, 100.92485166365101, 52.547906906374045, 99.96044281990298, 104.32025924805673, 106.48171271047285, 105.76418569011074, 116.997265508098, 109.82357994202646, 106.92625845632246, 104.2360616499378, 106.15770924475886, 106.51055782072007, 111.14509705574282, 109.52911192371, 101.85825809355705, 100.03980021322928, 104.29077086910125, 103.40862981734738, 102.63422842948668, 94.57982170966365, 87.05531935538016, 90.8667492097424, 88.96805532516973, 92.24004160973334, 92.50853569276872, 89.34654835731753, 91.4282835683515, 108.50529486133208, 106.87653849201818, 96.62705575266193, 106.17711713237148, 141.15657898687547, 39.28447884898032, 0.09678885836394564, 0.3311733745278851, 0.09212257851275707, 0.07888552146933733, 0.1343068883063332, 0.3112153438550811, 2.8001557963509716, 30.24268407975474, 39.53322379819809, 40.0903651022142, 53.22824201276226, 64.43278658774592, 31.8747313176432, 33.90699563487884, 34.5012935515373, 50.21426923813359, 61.119693863776426, 71.4571749779486, 91.59245829428397, 90.60739424920853, 112.9339018175679, 54.029570471855905, 1.922741690951009, 0.3613736943131493, 0.143878314223501, 0.02821186962988108, 0.16303982795967212, 0.06419744027117569, 0.033635798946864186, 0.033636254769179134, 0.039896644847167116, 0.0495931307875341, 0.041792233654808615, 0.011712174351897933, 0.0225289010878412, 0.037935218443312956, 0.03513605957249961, 0.057334744206239144, 0.025865451485339194, 0.07695540124850889, 0.007200435502454639, 0.07088705026093992, 0.045828727945204706, 0.016621158518377813, 0.06831620474376025, 0.10256375171123974, 0.04485646277786263, 0.07791234465736536, 0.04387905716054863, 0.06901921298835548, 0.05391060697635817, 0.07820587124555342, 0.11021507783762871, 0.040836259347176364, 0.06407098979839394, 0.2023537135532787, 0.14998372854484668, 0.10938851493260554, 0.19957390223299304, 0.21960903199449663, 0.10673734509656507, 0.10211795748722169, 0.23780438628408218, 0.1879964904078553, 0.2639432143299811, 0.23562455970433452, 0.1200168357501107, 0.2805162701875933, 0.2098933517211868, 0.1806821280549611, 0.10455132852638922, 0.14143486146724996, 0.15472723771968197, 0.33376462096648835, 0.1482533351067574, 0.13180222512493212, 0.22120353675657706, 0.2509692395406385, 0.23377854827671285, 0.37277246975610334, 0.2117021925627224, 0.4255417091471534, 0.23379365553057965, 0.44252425432205206, 88.80026417393839, 157.72186217769502, 126.52769934746527, 129.54879514632688, 104.45294518624584, 70.12902121390067, 53.934813853233095, 92.60841492683657, 105.19857206652242, 74.50161672407582, 67.29996465867566, 58.10823140605804, 54.34150088217951, 26.921440670567176, 0.7471507210885325, 0.26018349994574824, 0.4021465790367896, 0.14685763016102776, 0.49758234992623335, 0.481910152180541, 3.630477925462108, 5.779392305881747, 3.153958243708457, 65.8336728618991, 139.60226920343214, 119.62342569904943, 101.86522422298309, 114.22421255419331, 113.13727671100249, 108.99478312461608, 112.54825438222578, 118.13446260267689, 119.47781947351272, 112.6891851425171, 115.7830644422962, 115.82793635706749, 116.43516632818408, 113.96311606130293, 116.35299267307406, 111.10407690848075, 90.44183100423506, 83.93124565001457, 87.4255910996468, 97.16871153923773, 107.79108616613574, 113.37184229204732, 113.61717085684501, 115.40594423970869, 114.8465907189154, 110.06849273558586, 105.74719398252427, 95.97943321351083, 99.1307124783916, 105.94765063255065, 129.81932101711152, 79.69727454646942, 75.98730856372465, 108.84393661252915, 94.14433663891208, 111.94344059113534, 58.58702336588214, 101.99589406290363, 110.93837245818108, 112.68032843066801, 110.66270043773036, 122.9983820453767, 115.80586125773769, 111.81681079249229, 107.01033053859588, 112.63960638353902, 111.14919201020273, 114.63276663134175, 113.54622302516815, 108.0897746547576, 103.50231170654298, 110.13801282452, 109.69976640516713, 109.59320345232564, 97.6681940017208, 91.02925300598146, 95.80616643351894, 94.63279724121095, 97.88999619022493, 97.2403653975456, 93.8604982437626, 97.54199566379671, 114.2665506178333, 108.68704965037685, 100.09000655143493, 113.76316931939895, 143.26453916488157, 33.42690144815753, 0.39032881478628806, 0.5603835106857362, 0.16243268795792135, 0.48496601562346187, 0.35981865840092786, 0.38893857970833784, 4.754980023830168, 43.40488164655624, 51.11796371398434, 71.26690080088954, 80.73324311164119, 114.20346321598177, 93.41822747261294, 63.23953490103445, 49.017510952488074, 42.407234637968, 58.553259603438846, 74.53718477679838, 104.0554835719447, 96.85212135314943, 125.53572408614622, 74.461012348052, 5.47842001722705, 0.7363813021971334, 0.19219872782066946, 0.15606269751104618, 0.24457205297245135, 0.13586627559796458, 0.1536498116629739, 0.10299555716976043, 0.1356817250170054, 0.10095691293357842, 0.08837324461989826, 0.21698064561332428, 0.19809270187491373, 0.17363811813054547, 0.14803843212223824, 0.10516200785435016, 0.12078927454328346, 0.1286614331747255, 0.14761837079159676, 0.10791546575004056, 0.19500354425080363, 0.13668412042240943, 0.2373681604982384, 0.15349040408768963, 0.09370110268073698, 0.14363028559713595, 0.11583810191481345, 0.11962062273655208, 0.20596097644057967, 0.17205530387018958, 0.19549681294348933, 0.18836350781061958, 0.32569887957745985], [0.10910857108331497, 0.11154702894629971, 0.029095193904434002, 0.06863724921018848, 0.042019704311725595, 0.040492672743576194, 0.06895009653582689, 0.027527419865251552, 0.048326603587596655, 0.08901154141752951, 0.03255248550445803, 0.059086963489291176, 0.029273692390791355, 0.06158998724253428, 0.07035343171728235, 0.02985746288041194, 0.04957554906967187, 0.0441445219480703, 0.06424497219643767, 0.024746453667420055, 0.026157219901741035, 0.0801600159836873, 0.14091024445670267, 0.14435400885920371, 0.054728478613880374, 0.23186250109105344, 0.05745636066421867, 0.8344542848006372, 56.10989362962785, 118.82895746538718, 115.15393980087774, 100.39238206801876, 82.29000045407204, 54.175741518697436, 43.809787919444425, 32.039623837317194, 91.4067497561055, 90.68476692322763, 47.91322254365491, 43.67398369696833, 31.274579263502556, 7.289309684307345, 0.6688933687344675, 0.1041596967186178, 0.11890367169173495, 0.031569135044851614, 0.039589880259647485, 0.10702745493261084, 2.252298987680866, 1.5333856546109723, 2.7073704138878854, 88.8077009877851, 118.81302479774722, 100.91494375659575, 103.58541888575401, 106.92284599427255, 97.79809505708756, 102.77289990455874, 110.13783239549207, 109.31366397488503, 103.79660714057185, 103.46680641174318, 106.793564673393, 107.21489783256285, 102.18166535900485, 99.6933372559086, 105.69813297640894, 104.74034509351178, 98.96504725179365, 79.08711064246394, 77.94454774548932, 79.80873261728595, 95.08917285550027, 105.2654484779604, 108.60501720059304, 107.59411258082237, 99.35235777208882, 94.09577769617881, 90.6568867160428, 93.8889354275119, 97.03685714352517, 93.36422428008049, 85.5644029186618, 95.93066246278825, 100.74200645569833, 45.86616500731438, 68.12534901403612, 91.39658297261884, 48.570666697717485, 73.84618866828181, 109.806839266131, 98.76789323745236, 103.36698993559807, 99.91512375493204, 105.10377622419789, 104.44438657452984, 107.46309757232667, 107.488326257275, 105.62377268268217, 99.83459749529439, 107.58962538934524, 107.21678057024556, 106.34493181782385, 101.7041717037078, 106.37950358852264, 100.42492989570864, 93.80178820702338, 84.01726322789347, 83.52341328897785, 88.08603978926136, 90.00871504506758, 86.33714906630978, 82.5311948407081, 82.43686183806389, 82.67114500845634, 74.42647195631459, 84.65267935106831, 95.6334723195722, 99.4530136354508, 93.72308192714569, 126.28902312247985, 19.616314518836237, 0.37004329684761267, 0.17152998205875197, 0.12919472230057563, 0.11059309626298566, 0.03742967702208027, 0.4204642928896412, 0.14675880481879558, 14.79430462083509, 29.00934969225238, 36.597129683340754, 41.209601663774066, 78.48443846548759, 69.43644046783447, 49.549498096589126, 22.13853386140639, 12.01759405674473, 34.023333134189734, 66.79288064279865, 67.37674113242858, 76.81001001788725, 87.78528813392886, 58.94590846953854, 6.602585036908427, 0.31837762243324713, 0.06241929274232638, 0.05866140547779299, 0.04084960076837771, 0.0379470928061393, 0.07473498733053285, 0.026092634859284567, 0.010235147257786124, 0.044432341181222475, 0.05503668727713728, 0.020373196701609322, 0.02752597195907466, 0.08154475055034123, 0.04300100931657418, 0.0608186899203687, 0.07059952214119897, 0.06484583410764895, 0.016066713874498685, 0.09396359504711244, 0.04347016922228279, 0.006462023940853655, 0.04616591388419752, 0.06021317019457779, 0.05342506811082844, 0.04543958209274758, 0.10969635204321916, 0.0503921183577228, 0.04697346248694005, 0.042706050143967715, 0.03640643636425657, 0.062331652283788695, 0.06914631463587284, 0.04314505299853702, 0.04892281917554717, 0.06952111549194782, 0.05750531368258019, 0.04752353659921116, 0.02930010327198092, 0.04402167974941192, 0.03918265473217734, 0.0890050066875354, 0.025791851503233758, 0.02992274123243988, 0.030965526708431786, 0.09042384748857829, 0.013815202532456288, 0.05184021222615435, 0.06562971059353122, 0.024807141237561742, 0.040577666368335485, 0.017993040044882128, 0.1124261225002908, 0.04461060984120254, 0.05733490508470324, 0.05754639897795935, 0.06854888096812271, 0.2959256384882235, 0.03177772929531432, 0.21242582389423925, 59.837259246457016, 141.33317978151385, 125.28275474425286, 118.75791549682619, 100.25258879507743, 93.52912856686501, 58.97547529589746, 29.64847049405498, 61.222067725273874, 86.6209403930172, 48.46570407190631, 46.80304665719309, 42.14037226092431, 10.097581109692975, 0.7615654927588279, 0.31881720368419925, 0.1224595454010752, 0.0387093196472814, 0.28464058113674967, 0.6209873167737838, 2.0675006845305046, 1.1996397568333534, 3.3622115850448613, 97.335294600456, 126.91285256416568, 104.02069999325661, 109.37826541162308, 113.53626020493047, 99.96261581297844, 106.78160928910779, 116.37763300249654, 115.22519357742803, 107.15570142192226, 110.20339089055216, 110.07361535103091, 110.0497438061622, 104.75698378778274, 105.3698855061685, 109.32461523240613, 111.71650009770548, 104.93886409267303, 81.84139113272391, 82.0364898250949, 85.74462013859903, 95.52334000987392, 111.98465685690604, 110.13773825860794, 110.73040839164489, 105.28010245292418, 98.10974305675876, 94.26388263702394, 97.93349527543592, 102.2461255904167, 95.14991467998874, 89.13101411634877, 100.52690367544852, 106.84755217644476, 52.595901027802505, 75.30129386532691, 101.74869060516359, 56.11864835985246, 77.5356798787271, 114.700058814018, 104.44477096680673, 108.09930601427632, 103.63868467269405, 106.52276423669632, 105.7804713710662, 110.27204021330803, 108.40161877293741, 106.61046058900895, 104.56043381844799, 110.8128958363687, 110.05833379683956, 110.38467499517627, 104.99644448680263, 109.69743651728477, 104.31957675564675, 97.92360305786134, 86.94867011039489, 87.87263147292599, 92.67764476037796, 95.899471775178, 91.87974837518509, 84.6852977814213, 86.63455886225547, 88.57499461020194, 78.24837453903692, 86.23689328470539, 97.77299188798474, 106.75855359723492, 93.36208266596641, 133.2158347099058, 30.50594964335042, 0.3536025596962821, 0.22853844558760045, 0.2973163332189283, 0.07256963215167485, 0.04727089612354194, 0.4314658977091313, 0.03733983406076028, 16.721799488990538, 38.879721626158684, 38.65957860023745, 40.416412122787975, 61.812160861107614, 28.941739797592167, 32.30554484551953, 28.61322364499492, 28.542770031959783, 52.331509743967366, 83.40580494173112, 84.70002235904818, 86.23712862691572, 101.14485740661623, 77.85066189304476, 10.553709614661432, 0.24379081182902862, 0.02916085146998446, 0.04950278220818408, 0.05736548731464052, 0.018009974418448347, 0.04727771047562842, 0.015449274778215876, 0.01300786077345331, 0.05633915166160273, 0.08446028966817164, 0.026390480268145763, 0.040761944988081535, 0.04079806986415098, 0.09788146828331294, 0.05050803512154568, 0.036388739733205694, 0.029193006095386324, 0.03868319604906344, 0.057015480894234874, 0.025444871130129023, 0.05228745818678891, 0.05890722011005687, 0.050198746274315545, 0.07734611375077118, 0.020804617200948058, 0.0038446673105711183, 0.012369715278187107, 0.07932363183147485, 0.049234528860618035, 0.10995119119123106, 0.10010866207941886, 0.21573913884499382, 0.1231124208519055, 0.17075905245879006, 0.14634573021002356, 0.11236383189116755, 0.139508732564507, 0.1559307771704851, 0.12314661135596615, 0.24730907062128668, 0.1733486135039599, 0.17887049865338112, 0.11191494267193541, 0.13344258791015995, 0.09698446359365218, 0.178132250364269, 0.16546745333940754, 0.13637647483377688, 0.11879924624677628, 0.14783742597266553, 0.11746381709892904, 0.20178657866293387, 0.1469890908488343, 0.17831033516314723, 0.25972007803859254, 0.2157535259762118, 0.441232813942817, 0.1910785234142696, 1.4544532255780314, 101.62742660891627, 151.24643694969916, 139.04472781765847, 130.80605599188036, 105.82889695321362, 77.58070084356493, 63.75163562836186, 50.20616954372775, 145.9429688607493, 131.21957578966695, 67.6251526801817, 75.22014787120204, 54.06844116026356, 14.853007793426515, 1.6209088097656927, 0.571154339178916, 0.2896682936097345, 0.26065390857477344, 0.24232464211602367, 0.6637742466503574, 4.731953259437315, 4.393214919874746, 3.5535077846819356, 103.8756742785054, 129.89193193374143, 110.10858720348729, 109.68562233832576, 121.33804275143532, 103.9471947762274, 112.24275665898477, 119.38352569457024, 123.18451419953378, 111.55457681225194, 114.9853563308716, 116.17247735300373, 116.9584732670938, 110.57410978501844, 111.84805639328496, 113.22585951897406, 116.17596041771674, 109.7838463321809, 88.88124542851602, 88.39363990291473, 90.63911837916221, 102.53486694828158, 116.62573076063588, 113.39555694210915, 115.86646187689998, 109.03599154564643, 102.64502279220089, 96.73243414971137, 101.7643565516318, 104.85330935447448, 103.04565368160125, 94.62565852749734, 107.88199101724933, 106.57726949261081, 58.8433071105711, 85.09684854938139, 107.21594118302869, 65.54334686648461, 81.65478829414614, 117.39289929789882, 107.95709656130884, 110.73622134424026, 108.6358234959264, 110.92070610292497, 111.12677958703811, 115.01284430103918, 114.34874780716436, 111.8807375815607, 110.72012393705307, 116.67214808925506, 115.49445644501718, 116.4551547265822, 106.5680205437445, 113.70379247973042, 107.91708838555121, 99.6785891440607, 93.33135481803649, 94.90907330666819, 98.14489533824306, 98.58846833628994, 95.12506254257696, 89.61021008030062, 92.55846746506231, 92.8354887808523, 81.26273170594247, 91.97182209261003, 103.68053636243268, 109.44088997379427, 101.71313039718136, 138.88180825018114, 26.38369352586808, 0.489927446169238, 0.5663509066066434, 0.30891527211473835, 0.3691540219851079, 0.10517647925523982, 0.6770727975714592, 0.4761668522992442, 22.644062657510084, 48.90710799924789, 57.433670028563476, 60.95363247779108, 115.17701902697164, 95.88011880074778, 69.73402284806775, 31.7244045196041, 22.95168826656957, 47.137660134223204, 84.60319472897439, 91.86278020181965, 97.09745776268744, 108.9018072620515, 100.4805883284538, 18.01202393347217, 0.46078003762710484, 0.06741334714235798, 0.12403584025319546, 0.1877172053941796, 0.2311665408553616, 0.17145271443070906, 0.16544623270390496, 0.15310440302616166, 0.22650261289410054, 0.19473434095421147, 0.11175366584211589, 0.17198496167698216, 0.21021962856813786, 0.2104621260396896, 0.11776452193096762, 0.12821415274013437, 0.19345230813468658, 0.11625279296910572, 0.17404106505695852, 0.14990186438925807, 0.2833203358515617, 0.2671836130321026, 0.1672270347274119, 0.17499766372624906, 0.1965083247951923, 0.17270356747171572, 0.07559233164835362, 0.1582223300131098, 0.14189213934925296, 0.18799612268565163, 0.14409654202961153], [0.005672686684486126, 0.05302839544451526, 0.07379042390253275, 0.08660946507006885, 0.10753168634349301, 0.11669362294337443, 0.048886747925632426, 0.022042123075093956, 0.05425078448869529, 0.03654449689953077, 0.09447923350718715, 0.040154142320276275, 0.044698782730847604, 0.0121764772601666, 0.02945114899757168, 0.04166477194596683, 0.044318094489074526, 0.02109543566832379, 0.049589779152865374, 0.036201262696375774, 0.014661036379214738, 0.023576708270176768, 0.020236329348277182, 0.08823761641378365, 0.09839995659046596, 0.11334419460786928, 0.07726709178138165, 49.54220248806862, 126.55626989180043, 118.2887686452558, 99.80788615442093, 67.26230990502143, 53.05452023783038, 19.443628249629853, 36.1444567864941, 85.03966039226901, 65.780838535678, 31.901275957784346, 37.84858542103922, 27.529568864453225, 3.746430297051707, 0.8821865267330601, 0.24284328364076155, 0.13943921774625778, 0.03584160739856382, 0.10833963331195617, 0.17018387364524026, 2.6925208107117684, 2.7108223447876596, 7.368700908076379, 105.82330365334789, 112.40438968904557, 99.78513640742149, 109.30359917302286, 108.7012956988427, 101.51192849682224, 107.06438864431074, 107.89345218289284, 105.80151880941084, 105.63964259239935, 107.91079690379482, 103.1502083809145, 99.3392413662326, 91.20160979609336, 92.36717347175845, 100.00116486703196, 102.998028262969, 100.49989423444195, 93.80254914683681, 74.54710837333434, 75.99862067930161, 81.26886629289197, 94.98784234446865, 99.06247108213364, 103.66009296909456, 96.78864955902101, 93.68365426217356, 85.77267293007144, 99.2801155582551, 101.86385139342278, 111.7752807371078, 97.08227034538024, 93.8529908272528, 83.95628606119465, 113.6967400581606, 63.57409738725232, 38.10734418130691, 63.33932784295852, 40.504414419974054, 97.86248468583631, 90.35842572489094, 103.42720616248347, 94.6992108129686, 104.25224534926876, 97.98355256357502, 101.50920637192266, 96.72260469005954, 101.29867707529377, 98.81150214902817, 98.26047189774053, 95.85417624442809, 103.74411798292591, 99.72312373499717, 103.40218928552444, 96.94717607190533, 99.84483488144414, 91.07181856709143, 85.65291512397029, 81.44890308380127, 91.89765791739188, 92.28616868295978, 95.45052512999504, 85.87381516733478, 79.29543556705599, 76.22365490082773, 82.35548834646903, 77.61548442225303, 78.33449409854028, 87.87111743803948, 101.14985450621575, 96.14836185209214, 112.20107755353375, 5.554484090497417, 0.3401801783230997, 0.09717420825073797, 0.021104697671328342, 0.08434822632660789, 0.06884875842520306, 0.1069050647258278, 0.35325815720904263, 6.238546429141876, 24.43434419170503, 33.320656207300004, 39.388586398093935, 61.9322403015629, 68.75896084693171, 62.17922802894347, 29.42955516999768, 21.70172695190676, 25.560693971572388, 67.58895704823156, 79.78820293180405, 77.97945684002292, 89.25092097251647, 88.76742609085576, 8.1954159275178, 0.5459054295093783, 0.01620341077326767, 0.07291535997102339, 0.03964584298251618, 0.08876503730613379, 0.010683503088300988, 0.06474699344365828, 0.06980087548013657, 0.055606779266869834, 0.021296690796471892, 0.08323298616995735, 0.05798003155617945, 0.02450974399013625, 0.07127118206793262, 0.05410621986694394, 0.03402039423705109, 0.03194287295393165, 0.045827486882767374, 0.06115620910760857, 0.05597013859979569, 0.017950776889319384, 0.09763864905483301, 0.02697233553795565, 0.09036681990349486, 0.030975826760573737, 0.10740369603398348, 0.03897119914331744, 0.14454335515056888, 0.021095169452770103, 0.04180368666927661, 0.06993743065263956, 0.05965650389571825, 0.12514453801897266, 0.0854995568853713, 0.09475447357662263, 0.06999949909626477, 0.04080186582981579, 0.055409224343396006, 0.011644416747825041, 0.027350085832539107, 0.0033077986388947937, 0.03317102489452208, 0.05150092337580939, 0.02901881685360305, 0.04204063766425656, 0.01884341870825137, 0.035481369873929414, 0.062293531748676495, 0.048608569909007325, 0.06805050246898206, 0.05804679228834087, 0.05128541518183005, 0.04525383641462653, 0.06488474371332316, 0.07871911951130436, 0.25274095576136346, 0.07360889936887449, 61.288045913942405, 148.0864029545938, 122.32061216908117, 120.51626697663339, 81.47850128912157, 72.91111130868235, 36.3267332507718, 47.34500838864235, 35.7248886939018, 66.68481934455134, 34.37307911534464, 46.35333514982655, 38.9775533829966, 5.655054152011872, 1.1921238827128564, 0.39676030677172447, 0.05927727122100131, 0.03881459544983603, 0.6716297735129634, 1.9316996489801717, 2.9937706070561565, 1.3486672697528717, 10.640707785083402, 118.05698010229297, 119.26479554945423, 104.988827243928, 116.05126042519848, 112.79071177205732, 104.35615677987377, 111.13288279502623, 111.50549227191557, 109.56487609494118, 107.54952307670348, 110.7762687436996, 107.31290217368834, 102.72853789790985, 95.5015943896386, 97.7644411210091, 103.51036825487691, 109.02073352567612, 103.38941020350303, 97.59726970426499, 78.9620654813705, 79.6598316008045, 84.75038559206071, 102.88895499321723, 103.17682558490385, 108.03338666116039, 104.18030123556815, 98.04127416303082, 89.79968409384452, 105.25641133708339, 104.9967739658971, 114.94088449785787, 99.8305731434976, 99.28938804134246, 87.08167768293812, 118.07223812226327, 70.97670032132056, 44.496151708787494, 73.16437090596845, 45.0366033277204, 101.39241387767177, 93.00212675525297, 106.36721872514295, 100.60554719740345, 107.91853966251497, 102.05518461042836, 105.50049258816628, 100.70337895424136, 105.99665672548356, 101.0147523880005, 103.02981515084545, 99.74531650543214, 107.70171103938934, 102.57915835226737, 106.59369637889247, 101.36272938020768, 102.72366631415584, 95.8947100177888, 90.31633084820163, 85.97396112257435, 97.78014629117905, 97.74163646082725, 102.08027993479084, 92.14308846381404, 85.14080262953236, 78.71985912322998, 88.11823460363573, 79.55981900615078, 83.69952770971483, 88.93213425913166, 109.18273525853311, 97.8629239912956, 123.81029698156543, 9.529310080312914, 0.49963362695228675, 0.37376630029851393, 0.5355347440608087, 0.17355167276916966, 0.025661608895226836, 0.03004180853285136, 0.5273334970397334, 6.362529118214884, 31.2833006535807, 36.869326483818796, 36.337998297906694, 55.08033421731765, 41.52544659952964, 28.577128033484186, 32.61274879978549, 36.83183254734163, 48.92857120883081, 77.139402820218, 95.43841285090294, 89.44728266808295, 97.26295824973815, 108.79511094862416, 13.102324547306186, 0.6838332477115816, 0.08462404862286584, 0.06727505295026688, 0.027305227554132862, 0.025804945861079523, 0.030355293626686743, 0.07027201189268982, 0.02988636546257523, 0.021427002352392, 0.014609706573068135, 0.04367375708816033, 0.05319805327622641, 0.06219356493543714, 0.01504947551556172, 0.047227451277355996, 0.062299434456133077, 0.08320323897585755, 0.07217012496004183, 0.05858393483645013, 0.07911639738707774, 0.0192469536071463, 0.06670349773259894, 0.03151425442117597, 0.05017597048032669, 0.0677001015132954, 0.07833262049262563, 0.061646685409810276, 0.0863598276590628, 0.009226219995217699, 0.023991690437880256, 0.1795570360076043, 0.23912406466420622, 0.25612096632680587, 0.14474238479329696, 0.19154994327935482, 0.16609756065712822, 0.15222678802186443, 0.17796463032643642, 0.15611842274665833, 0.10895385196612728, 0.2096946898006624, 0.11870782897477189, 0.21672118695512896, 0.11121067038226513, 0.135161520672902, 0.19185591879631245, 0.1436351272728174, 0.14046350794453777, 0.11503944759287181, 0.13213380330031918, 0.1448303929740383, 0.1961393921726173, 0.16705897035858325, 0.1548871355912378, 0.25950569599386186, 0.44545123113259194, 0.11721746620511818, 98.80929777699133, 163.16360165995937, 144.88890247960245, 134.1346734569919, 94.27822282237392, 75.198363027265, 30.051949024200443, 57.36440881606072, 126.28699917947094, 91.03396769492858, 49.16933021237774, 64.34955781505954, 47.599954605102546, 7.480223698000755, 1.8006413718385084, 0.9646291093480204, 0.31211669226327254, 0.21442324493921575, 0.33741362032390415, 1.3977048642212346, 5.968142642128853, 7.722375633255129, 10.531981645091888, 123.34529999763735, 119.56517065725019, 107.07071934976886, 118.62293889445644, 118.35711986787858, 106.9582022390058, 116.85393425726123, 119.01994551381758, 114.07086356993645, 108.40366625016736, 116.43220886107414, 111.0105440693517, 107.75182324071085, 100.07219899085261, 103.28835425838348, 110.13467880987353, 115.33172515130813, 108.78282608524447, 103.86263632005262, 82.52688023351854, 83.69575438960906, 89.55532827684956, 108.13038687552176, 108.79726825221893, 112.97296862448417, 108.6608874413275, 104.40662983925112, 96.22759372957292, 111.5137214045371, 111.03221124218358, 117.36366195063438, 106.42693288864629, 105.0527697224771, 94.86422492611794, 127.0040084469703, 73.98008269648399, 52.621306219408595, 82.78003784918016, 50.05915126492901, 101.36980533599855, 99.62205210039693, 112.97805201622748, 107.0702329758675, 114.12449021493237, 106.76660230082851, 110.43404979090538, 105.86748523096885, 110.36354910942816, 103.40446426022439, 106.66659755091514, 104.07864909018241, 112.32885268426712, 106.82306874182918, 112.28376896150651, 107.71169739384806, 107.90721970219766, 100.39553565363731, 94.09014517261137, 90.79041204144879, 101.03773747721027, 103.15104776813139, 106.57173895066785, 95.24215313696092, 86.93910737191477, 82.2907300149241, 91.44816214038481, 82.60517074215798, 86.82498208938107, 95.21749711805775, 112.37727826641454, 101.44779774450488, 125.11493221406015, 8.49040562106717, 1.0332928958439058, 0.38437435042954265, 0.5338626499137571, 0.44579790124008734, 0.28510152091903074, 0.18450513662349793, 0.6437919769556292, 10.782595603696763, 41.55307185265326, 54.297401674332164, 54.304246210282855, 88.17847436474216, 103.79994899995866, 86.28782918376308, 43.771474207601244, 33.01578606328657, 39.45913414801321, 83.7926055539039, 103.47578079469743, 100.1982718129312, 104.15235827046057, 127.83564506038543, 20.412598809888287, 0.8302038451356273, 0.15180942332071645, 0.1805948246751101, 0.18145822108753268, 0.1532373652462998, 0.1710942006039043, 0.2250618926219402, 0.22179213743056023, 0.27882729146269064, 0.07327611077456705, 0.16028690632552872, 0.11661588034081845, 0.10936275139571199, 0.23319348692893985, 0.10625223524027294, 0.1496087897929453, 0.175623235803458, 0.20017921894548402, 0.16618867915484214, 0.21392622241570106, 0.16380700372880505, 0.14602461679568216, 0.1086449116889027, 0.12125003812534195, 0.10359888205364828, 0.18703383964396295, 0.1091880756880968, 0.22754513598497839, 0.06802901370270599, 0.07902274313833445], [0.0776076868116375, 0.04731709122537606, 0.08051845320169965, 0.028272166495181383, 0.1040734658618608, 0.06891445046471012, 0.010295267922863846, 0.016863960509879455, 0.03627587582976107, 0.023666099239621433, 0.015323175748269406, 0.015514052300263318, 0.03374277929505033, 0.029607553508192785, 0.0916887199385993, 0.1658394809571966, 0.06944518851777239, 0.02405193176180605, 0.07333923641952776, 0.035523144648440426, 0.09511494858851356, 0.10427364463647527, 0.0979419892293311, 0.0951538275506708, 0.30177269731798484, 0.26404777000988683, 35.78743088629938, 117.50164308855611, 106.95117335165702, 100.31760600305374, 84.37698379639657, 71.47947757474839, 36.68569680183165, 68.18623988859116, 59.665275081511474, 77.68533399028163, 42.661529740979596, 41.35687097426384, 23.82186608929788, 1.512831699463629, 0.4853306428319024, 0.44142546973401503, 0.31810811270148526, 0.01444274537085045, 0.280142878933299, 1.594295037850257, 15.724595708231773, 0.28347631135294515, 14.297414845035924, 103.56407334727626, 109.09628621993527, 107.03154271648778, 109.84620417318037, 103.97150562655543, 101.29866923055341, 112.46666123790126, 101.73438179877498, 106.30982660478162, 105.34598258233841, 103.039001341789, 95.33452495451897, 98.20551164688604, 95.47689130229335, 96.38371190717145, 82.90167054822369, 83.84200388385405, 95.95036845053397, 98.15618391959899, 86.46077432940083, 73.18386508572486, 74.20867058538622, 85.45580817807107, 95.7004036441926, 101.30143057915473, 102.30002680132466, 97.94071243655299, 88.15945871414678, 91.36687494093373, 101.90691117317446, 99.91085621618457, 102.60961947902557, 102.50344876320132, 93.9623857313587, 83.81206835469892, 93.9771338432066, 106.23366986551594, 41.931631565093994, 26.055954002564956, 61.55551233599263, 95.33359143041795, 97.04012840024888, 101.32163863028251, 100.04209087740992, 98.42453679730816, 95.07174184245449, 95.35010460884341, 96.2379958552699, 98.73420007767217, 102.5999390694403, 98.83046288644114, 94.42713168359573, 101.9014512338946, 103.56572074274864, 104.2855933404738, 101.67716226270123, 96.05746484571888, 86.10565862348004, 78.67499505319904, 83.25848071805893, 93.90291475480603, 96.8101284580846, 95.03050204246276, 92.47587803871401, 89.99916015132781, 80.49036210583103, 81.19361954350626, 80.57090405494937, 84.20053205182477, 80.03252736983761, 91.73807236456102, 98.7825393676758, 109.28131226570376, 67.92638286467522, 0.11524352575502089, 0.06516250421202953, 0.11010471521125687, 0.06260711451872222, 0.14178545394491765, 0.058489449382308996, 0.028430015081539754, 0.4654468920442366, 2.7440497231098915, 20.31794417288996, 48.43261103476248, 39.48778706212198, 56.10329228062784, 97.01457023620607, 73.63265483610093, 36.44419254795198, 20.099254385117565, 28.01286174405006, 35.17634522530341, 73.9362855111399, 77.66519654181697, 82.99789413329094, 71.40117137662827, 3.8319970475089167, 0.33601805327400086, 0.12287441265559006, 0.01828882659244682, 0.03062353548293393, 0.02522514370690671, 0.07611157838255167, 0.04435844050960676, 0.055838896247047576, 0.04302876468207087, 0.08964222330119341, 0.08360064708657804, 0.028256519149327954, 0.01900071954174388, 0.04816865924024775, 0.08476536120137862, 0.018660283474732312, 0.0012141213993609493, 0.08354876761234577, 0.06435733048185226, 0.048249424059665015, 0.022770856552186514, 0.04564660969340513, 0.00840785135815461, 0.038674029807049426, 0.062506347143602, 0.08353682430160624, 0.24801469888658295, 0.09561839858971297, 0.03414111054171959, 0.11534401350804876, 0.050938208812787655, 0.015118954902244432, 0.04554733235929762, 0.10420570029847084, 0.07338091160260862, 0.012284267746332673, 0.046576383794026996, 0.0028279671284009615, 0.06756333183617362, 0.0354639183910143, 0.03146428250587516, 0.05143171499272989, 0.029599358282622792, 0.06431247603388564, 0.02687316354093773, 0.07949842245227869, 0.09153819132235744, 0.007398592283753979, 0.06203474341741493, 0.05970682438102461, 0.02707186759629798, 0.08564280000545325, 0.14997007685803598, 0.2871563832365698, 0.25245174224818906, 48.20927912189115, 140.9572284452377, 114.50445805826496, 130.31136666574787, 111.64283014112904, 104.19486107364779, 61.298903034579375, 41.76325990307716, 24.634353691531768, 67.02378273010254, 48.55188638933244, 50.51234975937874, 32.81539413236803, 2.088874905340133, 0.4561230504224378, 0.2791717858804811, 0.32669105536995396, 0.08920084940449846, 1.4875890410715535, 3.6268060966845486, 13.162802592400583, 0.417372607175381, 19.896222699073054, 121.17262855652841, 117.40833774689706, 112.56700331164946, 116.53003277317171, 108.08659753491803, 106.2327677203763, 116.72058936088317, 105.03810790277298, 111.40078852253576, 109.97012753640453, 109.90067020539315, 98.76294320629489, 100.80608229483329, 100.83004013184579, 101.14209605801491, 87.0347818251579, 90.39952431955646, 98.54704026252993, 102.10688929403983, 92.44946479797365, 77.09357384712466, 79.00517232956426, 87.77109699864542, 100.0489079567694, 105.6276793633738, 105.44698361427554, 103.99525165557863, 90.81032199244346, 94.64822784546884, 103.31247683494323, 103.01041510797317, 103.39357576062604, 106.14875055128529, 99.2267007212485, 89.69782014046946, 96.16481227259483, 112.0203661149548, 48.77721871099165, 30.5941362919346, 67.69235857071416, 99.50138430441581, 100.62912848687942, 105.36489625130932, 102.36203162900864, 101.70748218413323, 98.1157599726031, 100.31169106883388, 101.16946635707733, 103.13991608158236, 102.63807235225555, 102.85737991333009, 99.77838208598476, 104.64153274413079, 107.60555021224484, 107.933609408717, 105.19319057464601, 101.25509954267933, 90.78153964011901, 81.91636331619756, 86.65732429873559, 97.66259285711475, 100.60120905599287, 98.67579598580637, 96.33487055378576, 93.56094683370283, 86.3406321310228, 84.95502348869078, 83.19471866853776, 88.8828928239884, 86.39046976643225, 93.62770557403566, 102.49093640235164, 109.2163029024678, 78.98660382916852, 0.9142165402731589, 0.43918061761125443, 0.4647483730748777, 0.1828221946714386, 0.280957383614394, 0.03825572281775456, 0.06400355107841954, 0.4502155932207262, 2.604600638151169, 26.577109521435155, 49.123893476301625, 38.68676847027194, 52.476970841807706, 59.66118797179192, 39.98528088292768, 27.309396420755697, 28.364121760091475, 55.94066296854327, 64.27892769536665, 86.93774238709481, 94.15324041920324, 88.26571572211482, 95.10990650423112, 8.478859143872416, 0.35239741146083803, 0.10108625921871393, 0.024639277966813217, 0.03707611595370597, 0.027565973240040967, 0.025935594495686314, 0.03746856364511675, 0.07795336866571058, 0.017791398042332263, 0.04546441100237351, 0.026190977566124454, 0.03806754481047392, 0.040946556856074644, 0.03456479163780328, 0.051603092691831054, 0.03992097196920265, 0.10155532719387163, 0.045634436556288314, 0.0628744792042961, 0.031153630022139802, 0.053868353396894476, 0.06263749373535957, 0.07250309741545109, 0.04234401231271125, 0.08546577240791052, 0.07255154481578259, 0.07909429575046224, 0.12179227515814767, 0.028552931973770745, 0.20745733001780128, 0.14826206850909418, 0.15320204859299047, 0.15947097672089455, 0.18617484057622571, 0.27097384835923877, 0.0915350350401094, 0.1274725336641554, 0.1062791249264152, 0.1272629779733477, 0.11885965227960579, 0.09405596992902218, 0.19346016819678968, 0.12720794987774667, 0.30477015421755854, 0.22375024284326264, 0.1927319096942102, 0.1393430737117606, 0.1595057264691399, 0.19639518893053456, 0.2030147861448988, 0.16259175845451895, 0.3267010145129696, 0.23859535674414328, 0.42920204660584854, 0.32775815456144275, 75.853312553898, 161.18754294610795, 129.9715482034991, 131.21407662668537, 110.0842292847172, 96.89569104102351, 56.05790653536397, 96.62343932736306, 86.52780763564571, 103.93458043375324, 73.27349124416229, 71.9081534108808, 44.730893796490086, 3.2518463846175902, 0.9220109639629241, 0.7624966879525493, 0.6208201870322227, 0.1998579216700408, 0.6869186208613458, 2.9350193854301208, 29.719575220538726, 2.5280739703486046, 18.61028540518976, 130.92342115217642, 117.25200776130923, 116.03867746168568, 118.74475202252789, 111.27286434173585, 107.99116626862558, 121.8127436791697, 109.21950355652841, 115.46903164156022, 114.19473201997819, 115.470733950215, 106.58539664360785, 107.74128775442801, 104.4499171164728, 108.34490914498608, 94.1557821150749, 95.99507562575802, 104.73101769724201, 107.4924369012156, 98.0842633401194, 80.20669629496913, 82.53292852832426, 93.62177495033511, 106.88085309920773, 109.97288104026549, 109.86118762723862, 109.50818215647053, 95.8079001211351, 99.99360253733974, 107.29606736090876, 107.45600592705512, 107.46007734729399, 108.17485086379513, 104.17248002944454, 92.98340136005034, 101.49677245847641, 114.95746043420608, 52.66752350714899, 43.775879029304754, 69.05721003009428, 100.89629680879655, 108.75007429430562, 110.9021689814906, 106.92296366537772, 106.28693565245598, 102.63675443587765, 104.65233495158535, 105.0261603632281, 105.73461886375182, 109.19630665932934, 107.38344207886728, 105.38421000203779, 110.82313322251844, 113.0657248343191, 113.72678541368055, 108.7657637749949, 103.05710700250442, 95.134123217675, 86.71998023986818, 92.5475868102043, 101.9808086272209, 104.09410322866133, 102.36229835018035, 100.14621411600422, 98.00136012415733, 88.95857103409307, 89.39184388806744, 86.70227466091033, 94.61669983402376, 87.33987946664134, 102.29695166310957, 107.85875489634853, 116.83076873902353, 76.57488746027794, 0.6129233527087397, 2.090165855423097, 0.3625541438739146, 0.2553336271235059, 0.4425943666888822, 0.39163910092846044, 0.18049181649281135, 0.9709512959084204, 5.576730303225979, 33.80929331625662, 73.2333497078188, 51.49967308967344, 79.8480583006336, 133.68954720035677, 101.04629608892627, 53.23399612980505, 29.102886453751598, 43.0561476369058, 52.06411784695041, 90.44893833898729, 103.99201962255664, 99.25793063256049, 112.5814062549222, 13.776796690879332, 0.7028008492723589, 0.31601626365896196, 0.14856324831564582, 0.14882829941568837, 0.1613895366749456, 0.13700531044554326, 0.1273496148567046, 0.302593391989508, 0.10123330213490034, 0.14513526532438495, 0.14032286952339834, 0.09684383283339201, 0.09117061467540842, 0.153856793298356, 0.15399923968699672, 0.1000423035434177, 0.13161703103011654, 0.18330052464960084, 0.18675882940090474, 0.19508026029554107, 0.11638539512791943, 0.1289969490420434, 0.1611509309300492, 0.1268283073459902, 0.2491048266810756, 0.23743208287464035, 0.3368203618353413, 0.1703767899063326, 0.10705033031802987], [0.03229834349645722, 0.03458307432611624, 0.05005112879218594, 0.03479696990501496, 0.0689363529184653, 0.0198936180001305, 0.02286977765540923, 0.03962456489041929, 0.02354916166363945, 0.013098497593384838, 0.028399187703466708, 0.02390516272205259, 0.029746313098697897, 0.026909449295471274, 0.06169264685482748, 0.0016283316137794888, 0.04238793596384987, 0.005493362259585411, 0.03440227374554642, 0.024496850730370612, 0.07871734984819928, 0.06601188887631701, 0.09167704475863327, 0.07288878438093009, 0.2708470761295288, 43.39980609955327, 127.02282797905707, 108.39052631009011, 111.04878717853178, 84.2305774073447, 61.623753732250584, 28.23031794640326, 26.453758824256163, 59.13261721211096, 91.8855142593384, 40.48363370280112, 31.993802708964196, 29.836706999809515, 2.016307870226522, 0.389469662500966, 0.17455676480406718, 0.4725624392590215, 0.3341690234599575, 0.0900489547019524, 1.0924287548949643, 7.556680498584625, 0.5679446146372826, 19.015354456440097, 107.42611746634208, 101.42746417753159, 112.62571334838869, 110.2686042170371, 104.49928406746157, 106.39720916748048, 102.04125235157629, 101.35689289339128, 105.89531052497126, 105.69134727601083, 99.51571664502545, 95.99382046730288, 97.07313122287874, 93.5079477679345, 93.46873975569203, 92.63071752363636, 83.59265096725957, 77.94313569222727, 82.59494120074858, 83.70904337975287, 75.98246835893201, 71.50880905889696, 77.34394657996394, 85.24541224202802, 96.50323437106226, 99.71099576642438, 96.25662711358841, 91.19027414629537, 84.76200365251111, 85.76267873087238, 96.4022647180865, 101.90094917051255, 91.64688510279503, 96.05292274105935, 94.16345427113195, 86.13744551135649, 86.74349092668103, 95.56316775660362, 81.6245860438193, 16.49879901639877, 75.03751447123867, 89.95835181205504, 90.16507640961679, 89.97379026105328, 98.42509377387263, 93.40165938100508, 100.26124154367756, 95.10885530902495, 95.63258586391326, 94.13387960003269, 96.7588395457114, 99.21652609302153, 97.26415849501088, 90.36161068947085, 96.2377840472806, 98.70540203586702, 100.26462262676608, 95.6765320993239, 84.56110769702543, 72.7033982738372, 79.31259985893004, 91.02602097295946, 94.68290159779211, 96.83922460002285, 97.0593793930546, 85.71912473247897, 84.62057082883774, 82.89757559376379, 82.01418722829511, 80.36066501371323, 87.10869496868503, 81.06445589373189, 93.68734129013555, 96.94788209853634, 106.56289792829945, 27.22039588036076, 0.7445517831271695, 0.44360848323952773, 0.22591477830804166, 0.14667067406398637, 0.033468941166516275, 0.1531331160015637, 0.12643890485407847, 0.3669360135832141, 1.6555657694416663, 21.901865889949185, 41.31258349264822, 47.13861327017508, 61.77181928388534, 102.72239546622001, 96.04084968566896, 56.60447312939552, 21.651357835338963, 21.35857447501152, 38.164363676501864, 71.98630271419403, 74.86439674131333, 79.37397710738644, 60.28616666793824, 0.7660654932260514, 0.09648901921126152, 0.10101156564609659, 0.02038220781081867, 0.05054577261269574, 0.05482746100413704, 0.04471860525588836, 0.02728915694470127, 0.04652386846681757, 0.03485491296516792, 0.02526387711235833, 0.03438465755372759, 0.07578163197444332, 0.05458878248088783, 0.035801288191108935, 0.06315060410528414, 0.08037376983632004, 0.03733147604150638, 0.023233098683938868, 0.05591798333391067, 0.07123814835663765, 0.05231711345033781, 0.06687987415540604, 0.026319630541688493, 0.10018067434430124, 0.07041478769913798, 0.04530378151685, 0.04869747824305969, 0.04958312950968262, 0.03242992292789202, 0.06336215162469495, 0.06333741464561994, 0.03786491838494136, 0.08064802931321245, 0.08992038216562041, 0.011119199315867117, 0.040600901815078916, 0.02720385305433264, 0.01636699161251947, 0.030646543018519882, 0.054658358586170984, 0.08920841835319035, 0.05841768609600202, 0.036545795418562434, 0.054115186926097646, 0.043202138040214784, 0.027191963369747805, 0.022821843533987002, 0.08198832311937887, 0.0699639066513027, 0.10160762035558302, 0.039500408850970774, 0.14606203252990402, 0.1785141605162813, 60.03097726452736, 150.72529515912458, 121.11451472005537, 133.11292740606493, 89.11112769957512, 76.47319609119047, 56.270997139715384, 36.57037911876556, 33.31309779997795, 65.17724460171115, 48.33168845022879, 38.919314030678045, 37.759806494559015, 2.354504187260905, 0.2719474541804483, 0.09292026756391411, 0.31865295443323355, 0.11882070436953537, 0.5197113512023803, 4.33198917296625, 3.5304748915856887, 0.5485523552183182, 24.031858021213164, 120.06638680734943, 110.05966740269815, 119.43539511772894, 115.3548514458441, 108.84224999335505, 109.68814834471672, 105.32263663507278, 103.34772325331166, 111.25685322669246, 108.71587122640302, 105.53353463449787, 100.41448854630994, 101.46686046354233, 99.2597584570608, 101.1707450497535, 95.70529091742732, 89.2752161333638, 80.3110078073317, 85.99649906158449, 86.81712950429609, 80.35103951731037, 74.65138850673553, 82.22813683171427, 89.80962337986116, 101.84838156546317, 101.08639055682768, 101.09888722819667, 97.16794275468396, 86.34799049746606, 89.34334770325692, 100.85782620214648, 105.63848157082836, 96.26662131278746, 98.29804820399131, 99.55046100001182, 89.98248223335513, 91.92085481459095, 99.0778075495074, 88.4475411138227, 21.02458073246864, 76.81516401229366, 92.89062946073471, 95.02168455431539, 95.24200408689438, 100.90437689135152, 97.9010808083319, 101.59717729014736, 98.6005884601224, 98.7468771780691, 98.53411997518232, 100.8165079547513, 101.35254690724035, 100.48093349702897, 94.34696628201394, 101.36624382388209, 101.64211980758175, 104.62796918807491, 97.05533935177712, 89.46443127047631, 77.00899185672884, 84.5767265750516, 93.39201035038118, 99.3156365425356, 100.04579359485258, 101.76263855349634, 90.55721928996425, 87.36482574093728, 86.04085322349303, 87.85815792699015, 83.35621049327236, 91.01993345445203, 86.121842322811, 97.3483011799474, 98.12229464131018, 112.4848767249815, 37.02715873718262, 0.7157425870818477, 0.8432292397464476, 0.8942441990779293, 0.35631313198997133, 0.18143799636633168, 0.09007864826989752, 0.02474717379006888, 0.3711525002314199, 1.352407249712175, 28.771987461274673, 39.17742167749713, 46.0714187160615, 70.33308644448557, 76.6076784749185, 50.67270409676337, 26.720599628263905, 20.038565512626402, 33.31850674844558, 57.7727157838883, 82.95289670267414, 86.74695830191337, 88.77975017793717, 84.26081103663292, 4.279782425972724, 0.12192757394645484, 0.06890396272102672, 0.020959198422309373, 0.04918290219540077, 0.056577477784406756, 0.04740912136771987, 0.04651171065145924, 0.06718961116407188, 0.06016222917805276, 0.07808735744366724, 0.07610469891299164, 0.06602682759084048, 0.03475637873634696, 0.03899840675594826, 0.03097474849182031, 0.05297727439732802, 0.06131340268879168, 0.08223602232793648, 0.026655780346763712, 0.084588211029768, 0.05171212232521465, 0.018074582443542538, 0.02493996364665368, 0.009292928058834327, 0.1635603540607037, 0.03216183811966931, 0.03544102385339718, 0.10957283568718743, 0.16847840870820707, 0.1688983321430222, 0.1368858313728725, 0.10715889263777964, 0.1376467558645433, 0.2685848184891286, 0.11258239677596478, 0.17107212194992652, 0.14662239520299822, 0.07464936934411526, 0.12761629772402588, 0.20851802471424305, 0.12841630802159348, 0.1743642162651785, 0.21842631481347546, 0.0928631020830043, 0.20708992957107483, 0.18474754216449876, 0.12155266583807046, 0.1457458374000365, 0.12712476039004902, 0.2598914978725295, 0.1953510110897403, 0.22085037022348375, 0.17648186714899156, 81.11355612354895, 175.14319481388216, 137.74261074681436, 146.05450537896925, 111.23013404107864, 85.7239257135699, 42.818110758258456, 38.85901151164886, 98.44890256081858, 137.8019012943391, 63.25056068358883, 55.12217021757557, 46.51939261344172, 3.9773505253176538, 0.6988467937034946, 0.4581454306119873, 0.8869211952532492, 0.4541167887228151, 0.36163493029532895, 3.3855442943111544, 16.219010468452208, 3.4427969253832296, 21.9382341061869, 136.1332622651131, 111.02395073060067, 121.55448698228406, 119.65571465030794, 113.1935784124559, 113.70572228585522, 108.96593016962852, 106.14656186872914, 114.42441032778834, 115.52746711238738, 111.76970312672277, 103.37665465570267, 105.34467251070085, 102.7981835026895, 105.5156486265121, 101.9542855601157, 93.7394303660239, 86.29084156405541, 93.03345080344909, 93.10494776695006, 86.64338419514318, 81.67086216711229, 87.56797313690187, 93.82475760675247, 106.36775216748639, 106.08585142320203, 107.42133217473184, 101.84813837851249, 91.49815667060115, 95.75786636721705, 107.79225503244709, 111.26791431057839, 99.20578664348972, 100.05457970403857, 102.06102109724476, 95.08602711462206, 98.02252523360714, 105.41700886141871, 90.64581778741653, 29.488110273115097, 80.71675346743676, 94.3050596790929, 101.66484602036016, 99.01140182249009, 108.48744807704803, 102.77829708591585, 108.68096213186942, 103.84419333550238, 103.97938959060177, 101.81406867119574, 104.69340216728949, 104.65083660617952, 105.2743757924726, 98.01305663201117, 108.38386612553751, 107.00014022088821, 108.0977370662074, 101.56384498842301, 94.20433321306783, 79.97800642444243, 89.32228457543158, 97.28726910006617, 106.7511324728689, 106.32224482874717, 106.3528314713509, 94.93409802836757, 92.00404828594577, 91.27313029381537, 92.59845995133924, 87.21789375428231, 95.75484614218436, 86.94374361345845, 102.02855956169867, 104.0134749873992, 116.06372571760609, 35.067205275258715, 2.004488420582587, 3.426334002325612, 0.6902310011848327, 0.26351582919878347, 0.28345384965500525, 0.2819237269220814, 0.34472200719098894, 0.736701159227279, 3.1903159185763332, 36.53292440599011, 63.733157342480084, 55.11774186165103, 81.74365351277014, 142.99681386639998, 131.15344462856172, 81.98225129035212, 31.718836715144498, 31.953033593393144, 54.460282018107755, 89.38452474532589, 102.77179379617016, 96.77380731028896, 101.33432357541977, 5.8608623858421085, 0.19177187895101888, 0.2761169643171372, 0.16226252450818018, 0.17155377674968014, 0.15814852510248462, 0.1472997854674055, 0.12023392208521405, 0.0994365195172929, 0.17725218387861408, 0.16755950156479113, 0.15704025634594504, 0.18488120918552722, 0.14372908029585116, 0.11889221867726696, 0.1686452320145984, 0.21387213660824686, 0.11904122277853951, 0.15401051650124212, 0.13253725584476225, 0.21901131487421452, 0.13553940120243257, 0.08989236633022947, 0.06295062451352997, 0.15088287061981617, 0.24760649659700934, 0.1259902454612236, 0.29651289084745996, 0.1663319222749241], [0.12138116939534103, 0.024274558827821768, 0.15984746297040295, 0.03153929400498108, 0.08029808801028036, 0.023677774419587468, 0.12285873083578003, 0.05686900488311245, 0.04167065933166493, 0.08531984031921433, 0.03390706301997266, 0.06324243506476765, 0.04190567212419645, 0.09625180774638731, 0.10406988057037515, 0.06413995303333768, 0.03502070588330108, 0.09815927474729477, 0.10267285029253653, 0.03230557919690206, 0.054253507931266105, 0.07341479567149956, 0.03417890165902434, 0.14197263986833636, 54.25634622573853, 121.01973456721153, 103.06511648239629, 106.94494462782338, 69.53683745476508, 67.5987708184027, 92.39031545577511, 79.78963851928711, 81.0005134151828, 72.62014204455961, 57.107779902796594, 43.42420324202507, 28.155794874314342, 2.797180433427134, 0.357746574426851, 0.2778422556096508, 0.13398427335966018, 0.0988317160837112, 0.3518673399042699, 0.38702216480047474, 7.323049912529608, 0.42420552923314037, 14.253465667847665, 111.36955861122378, 101.90016469647809, 113.48885443902786, 102.5031271288472, 105.93687980405747, 106.02200308153706, 106.1450086101409, 101.3300403471916, 106.60968395971484, 100.59088537769934, 99.23554958835726, 96.34227598867109, 91.71311824552475, 88.17005695835238, 91.21154123736967, 94.55031764122748, 97.102933391448, 84.94382904421899, 75.209471179593, 74.51192471288866, 74.16452823146697, 71.68982644234934, 70.6341911131336, 81.1263979634931, 92.71334617368638, 97.68768818147721, 93.28029340313327, 98.63948268275108, 93.26731035786291, 82.81508814903998, 84.87948648391232, 93.13394977200417, 90.44911876801523, 102.35071166869133, 94.56057071685792, 99.1652685596097, 86.67856785558885, 89.54371806113951, 86.47782095016973, 102.80640479057067, 33.561230859448834, 59.13903813208304, 103.6583435919977, 92.4905163241971, 100.06301279990905, 92.61527907463812, 95.12336023392217, 92.7024890530494, 97.5643688632596, 92.67949611909928, 98.15374420535181, 94.99716974073841, 99.91628477650305, 97.18982958024549, 91.74201826895438, 89.2610877560031, 97.95467607436642, 98.30977609080654, 96.48530913937478, 76.4323563729563, 73.48532276768839, 72.59914951939737, 90.29027062077677, 91.75191833126931, 96.06658043399935, 91.26919223416238, 89.750026887463, 83.1172126339328, 80.68741413854784, 80.55686196973248, 86.75548553466798, 81.38686687715592, 84.11104709871354, 89.61717620972665, 93.03600818880143, 97.808575630188, 77.61979118470224, 12.144304263976313, 1.3642392019110343, 0.27931262348448077, 0.350205235543751, 0.08690046356810678, 0.09861330441649883, 0.09874030647258605, 0.06270548020819984, 0.2432183143232138, 1.9941484399380225, 21.518556187229773, 39.08312397618448, 51.78771234327748, 67.69276649721208, 110.31756324152794, 133.96430138618717, 114.25261051424089, 47.67768421480733, 30.246802568435672, 51.58549062667355, 65.33958758077314, 82.45903107427782, 85.2928650763727, 41.999017884654386, 1.7723104598060733, 0.04615109774374193, 0.03327079252490113, 0.11783672571783105, 0.03024379719018696, 0.04123572440397355, 0.07725379249501614, 0.05537761172520057, 0.0348770835496966, 0.07288162911971731, 0.052212465839881095, 0.05388867387908602, 0.020887180411767577, 0.012739891836029148, 0.07280603156334932, 0.052278058287957986, 0.07169533430808975, 0.09148725413627203, 0.026758891950932243, 0.033419608934632236, 0.10571576684953705, 0.013927031259593225, 0.0747585675168422, 0.038052085156161944, 0.03344699657792526, 0.01809733717011348, 0.051523917504856666, 0.03459027172216485, 0.12191639672363959, 0.06012797355651856, 0.10813299641613999, 0.05680447346681068, 0.06494596946023165, 0.05993784202503101, 0.08301244477831549, 0.015490953791736355, 0.09340989733895949, 0.009859189608945482, 0.05805655224849621, 0.0329293969327644, 0.019636848310549414, 0.03917719252527722, 0.0472135812554869, 0.05201306081407013, 0.0965786285157646, 0.06284139952772567, 0.10084658095072355, 0.05190084808536115, 0.11704606935381891, 0.0038694600704231212, 0.06716135018054517, 0.5780320927020043, 71.41372296117967, 145.58076150955694, 113.51577758789064, 128.0723601002847, 84.88730769003593, 104.8401851038779, 103.18297586133404, 52.4519500424785, 38.45966715966502, 64.69145121112948, 63.07597990958922, 49.530156889269435, 42.53932829826109, 3.4879375225113285, 0.29689703797621114, 0.0743925690110172, 0.16154584925501578, 0.12053391445548305, 0.7642490681140655, 1.1446155223154253, 1.4211064601136794, 1.6145034567002328, 19.942124236014582, 120.8084600202499, 107.2295125838249, 118.80921225393973, 106.32196241809477, 110.42806425402242, 110.42388300741874, 107.81128637252316, 105.72469526721586, 110.25391886311193, 102.73152674398115, 103.91896940046742, 99.12710389783307, 96.40753638359809, 92.23448753356935, 94.11094942400533, 98.94574919054585, 100.43069577986195, 90.29560504421111, 80.52023487706339, 79.13465761369275, 79.02450961451378, 76.49166260996174, 75.32533799448322, 83.02149895698794, 96.6091226762341, 100.7027356855331, 97.02624320983888, 102.39813312407463, 98.20567638643327, 86.05588374599334, 89.01049537043419, 98.60178086065478, 96.034864148786, 103.11933932765838, 96.60079940672844, 102.46018502020068, 90.54474615281629, 91.7550797616282, 91.65019558322047, 109.06917479730423, 40.295093213358236, 60.69934914189001, 106.21585446019327, 96.82399795901392, 105.70576590876426, 96.3111323695029, 98.61286547876175, 93.99557682775682, 102.28760073261877, 98.24212305007443, 102.80744029629616, 97.97295431936942, 102.42066321834442, 99.78595226041733, 95.29567780033236, 93.27482561911307, 99.5952230884183, 101.0770082473755, 100.14459809949322, 79.06829111037716, 75.82639724977555, 76.0316470361525, 94.30437718668293, 96.73197915477138, 96.58420778089955, 92.92707612437587, 94.52782677065943, 87.87169794882499, 84.65871195639335, 84.07236468407416, 92.22802346752536, 86.37056766017791, 88.71627053906842, 92.7567118983115, 98.08691486235588, 99.6664454860072, 89.18969277412661, 16.156196651920197, 0.9627579549147237, 0.7078257118982654, 1.5782594079932861, 0.8183247019206324, 0.03220437132122536, 0.05218785526531358, 0.07009774987255374, 0.28515006024991313, 1.6186362865471071, 27.801997084771436, 35.1946234703064, 52.21249326582878, 82.37929713341498, 95.8364628207299, 96.99025938587805, 75.0671911239624, 30.626256581275697, 50.40430415061213, 68.87693005223429, 73.74905509333458, 93.05675752701299, 96.23790956312611, 67.01480050240794, 1.4639065054155167, 0.12025171830769509, 0.004943137323754209, 0.06304540108108232, 0.044874439031005874, 0.10538067999145678, 0.03806204429917759, 0.0672379742947317, 0.008705231368601804, 0.02507838807369192, 0.037010868245195, 0.0918153772551206, 0.08876465426217164, 0.022164838869244825, 0.06961000467380209, 0.012892408450434526, 0.045434629334317106, 0.03918224487513785, 0.04198600027349688, 0.05038170722283183, 0.021027073812400623, 0.03142327956494785, 0.022293081987769376, 0.0269153060376524, 0.06978090356795058, 0.06466543572323938, 0.053892872040911075, 0.0515289162285626, 0.19489557181875553, 0.20922668668771946, 0.2517439995802218, 0.20674823903508727, 0.12685746465238834, 0.18353585153818133, 0.26908449167686127, 0.1128954969106182, 0.1439728647951157, 0.1887323178591267, 0.13578879346530284, 0.13426309872058131, 0.10692774858926574, 0.13262086668081824, 0.189224406776409, 0.10817320837128548, 0.23198864512866546, 0.31071361755171134, 0.22379294458416202, 0.18628371699202448, 0.2096368654841377, 0.1552181468615609, 0.16694117667934588, 0.8606178421647319, 92.78757310682728, 164.2838619601342, 128.37943461633498, 139.74855792137885, 94.27553207643571, 98.1453581779234, 110.88116861158802, 98.23016766578921, 119.44491078776699, 98.6264447242983, 79.52833806314777, 64.33255434036255, 57.93046566747851, 5.770933224308876, 0.6472423756795546, 0.6422729778193659, 0.8086941799809857, 0.3778128380015973, 0.6164284194669416, 1.3952378159569157, 15.804645399893484, 6.2511220382105925, 19.38446125676555, 131.39109319256198, 110.35689676961591, 124.67972170922064, 111.00742186269453, 112.9323014905376, 113.75796825655046, 113.30057282601635, 109.80257957212388, 115.57532002848964, 108.65880858513617, 109.0703671978366, 101.36032104492189, 102.29531211237754, 97.89014524029147, 98.71993049498528, 102.24144228043096, 106.03990477900352, 93.6623401026572, 85.652020823571, 82.7206531647713, 83.32250164401147, 81.02977429666828, 81.67929526298278, 90.3365702782908, 102.45837288518106, 104.88793603835568, 102.39557573872229, 107.10820936387586, 101.45139848032306, 88.0759906768799, 92.78801241228658, 103.81145723404424, 101.02962601569392, 108.38079098732241, 102.32787562954812, 106.37050567134735, 95.31412862962293, 96.25048468189856, 97.64998635938092, 111.1484310703893, 45.83231103035712, 65.22247345216813, 109.38429017220776, 102.46909664523218, 107.46854182212584, 102.28897356217908, 101.77125207839474, 97.49236199163623, 103.4339604839202, 101.29023613468294, 106.85347495540496, 101.82807153271091, 106.79853823877151, 107.15927862351941, 99.29009406797348, 97.35014469392839, 104.09693517992574, 104.48143728317754, 103.38844530044064, 84.37713284646311, 80.48366269757672, 80.17033592347177, 98.34780739199732, 101.92897058302357, 100.92715801731234, 97.79468259503766, 99.85324444309359, 93.92165583948936, 89.02840491264098, 88.87278879842451, 96.49211052925357, 91.73762521436139, 94.56839192298152, 97.20056118503695, 99.9253454516011, 106.2831231086485, 90.1040521744759, 15.627309160847819, 6.479332889280012, 3.221288424345755, 2.059045525327806, 0.7358547852885339, 0.25270259007811546, 0.30083316708764724, 0.16280117624950025, 0.5026982544410614, 3.4953716397285466, 39.47472949181834, 57.504272691665165, 62.061898169978974, 82.8616859066871, 137.04246767105596, 164.33024006505167, 160.5602147502284, 65.14726200411397, 44.878959348124845, 68.25501472719255, 84.71990093108147, 107.4346996122791, 107.02733793566304, 82.64204102177774, 2.8789880823704506, 0.24328329390095127, 0.2574425905702576, 0.30844045081926935, 0.13624004989622102, 0.16378362272535602, 0.19293363596643173, 0.12068317902664985, 0.13574665862946741, 0.12458339393619569, 0.10078435162863425, 0.15097968881168675, 0.16593274450109852, 0.11953511200244389, 0.21258129377759274, 0.12608196150751846, 0.18622642893704677, 0.13720582629884445, 0.14270855925015866, 0.11524502728735248, 0.12408379735725543, 0.10353227836951133, 0.1416271801797613, 0.11115088488065428, 0.09169468010265021, 0.19350974940724913, 0.14050879906262123, 0.10339249030596788], [0.035952954447918364, 0.05799002517315169, 0.02472641472254069, 0.004605157526149865, 0.07932772274099051, 0.046677036255958586, 0.03610540211441056, 0.03312453867927675, 0.06057789699444848, 0.029294794282665657, 0.007423836796078832, 0.04006034634526699, 0.020606683063951713, 0.12239772210558578, 0.06819495600798438, 0.039428442551363865, 0.035940034375075376, 0.10127797272176513, 0.06644467492738078, 0.07465650928356955, 0.013613293356742832, 0.04258423067268826, 0.11825837285047579, 70.6675547938193, 130.49224284387404, 114.57459788168632, 120.65856272174467, 67.61987316992976, 76.34912367789977, 23.900825362051688, 30.530213425236365, 114.76572713544293, 73.82765939158779, 49.53584824838946, 45.274400941787235, 34.14316546532416, 7.205490104613766, 0.04983910246782246, 0.2527213439105019, 0.009114787718581577, 0.03991426869986519, 0.25554733501086313, 0.1816992629920283, 2.514401323372318, 0.8473014567167529, 4.794703827750299, 116.0029132904545, 103.41264632440384, 116.41220477319534, 98.67891819246354, 103.15164396839758, 98.88983188136932, 99.47995247379427, 100.29504452982258, 102.21300509668167, 94.65247184999528, 98.90909856365573, 92.02130671470397, 90.68551217356037, 83.33520227862944, 88.82208039683681, 88.00271295732068, 90.54367142338907, 90.12908474091562, 86.14141494997087, 71.41837489220404, 74.80181140284385, 69.68833508030062, 71.60085139736053, 72.36058312077677, 83.16199041181996, 92.68625828527635, 95.34714714173349, 88.43167904884585, 96.50194783364573, 87.94614453469553, 84.47398401075795, 79.78229584232454, 94.32065502289804, 87.63448084554365, 96.00189270511751, 91.44126661362188, 95.40212308206867, 89.54480848004742, 90.82642724437099, 76.62205003922986, 108.14360526300247, 56.6937227402964, 49.4925727382783, 101.15749528331142, 83.90908425854099, 94.3432164961292, 88.32888157136979, 95.03956271756081, 87.19741113724248, 92.95626640319826, 92.70160259739046, 93.77615944031747, 92.83868943491291, 96.28730004833591, 94.60746657463812, 93.08621452700709, 82.54775508757561, 82.93170805900328, 88.49449188478532, 81.9330176999492, 72.49985079611503, 72.11492507688462, 75.22519988398399, 85.94024442857312, 91.43679511162543, 94.9168945127918, 91.06853946562737, 83.27984979075771, 80.50335299584174, 79.8912279067501, 82.47052361888271, 79.157972181997, 82.81992050909227, 83.50653925249654, 84.52946985921552, 91.4220077760758, 93.78408262806555, 96.6209525446738, 54.73596188329882, 5.525786559427939, 0.8178950798126959, 0.7861366904070302, 0.1538167728651916, 0.14904871823326235, 0.0927065366939191, 0.18407882401539435, 0.08627103040775946, 0.41869309760870477, 6.787022727151071, 23.057743272473736, 53.49508870032526, 68.48459889811855, 93.25132277704056, 110.61072903294718, 103.008908917827, 104.33783931116905, 26.69786753193025, 19.880490072311897, 38.49114418029785, 64.42477710785406, 78.26931215101673, 86.23916825940533, 15.52053047764686, 0.7146473877852964, 0.01626934604569068, 0.04045218116633835, 0.08199215355900027, 0.04599303465276476, 0.0742564964739065, 0.08322268228737578, 0.03873379998690179, 0.046177114089650494, 0.02277213017336063, 0.03052360314365116, 0.07651893031452933, 0.05410017543322137, 0.04511702077222928, 0.012136102511337208, 0.03186161209258341, 0.012809527313126432, 0.0534463576942442, 0.019495983893472343, 0.06825606684170424, 0.03896762151271105, 0.04713988742761074, 0.048289084431505015, 0.09689349831352312, 0.05884430896971495, 0.04356143710714194, 0.03325675013324907, 0.06505494546746055, 0.04527190842876031, 0.06946531364754324, 0.07165961162818056, 0.07266232879051278, 0.09379484886003119, 0.03779524268822805, 0.03666459650342022, 0.029693786280169606, 0.016675435847813086, 0.008079218790836392, 0.012657659958236882, 0.06109939985758355, 0.10713945698714065, 0.07460371050382815, 0.047013352685157335, 0.03046954606449412, 0.04037398274146742, 0.05461982436357968, 0.11732052801357162, 0.036491816863417625, 0.05481354501699248, 0.22174463997925484, 92.58760283070227, 151.6145592351114, 128.48511895825786, 144.11743502463065, 87.39118406849524, 108.43286437373008, 46.082056183968824, 67.06707000732422, 76.15161665024297, 66.8138417889995, 61.54952287673951, 49.137029494008715, 49.04884284542453, 6.929865152605119, 0.0861640309073752, 0.08123345072230986, 0.11279161538808577, 0.09543217793707887, 0.38314435030183486, 0.5882300712889241, 1.4278009654052797, 1.4927469578481491, 9.190136847957488, 123.80969293655889, 107.20863772976784, 120.53161128874748, 103.75278642100673, 105.91323575665875, 102.82699723397533, 103.61529950172671, 104.5004843127343, 106.46050837732132, 99.69863245564123, 104.56044166318833, 96.0657645810035, 95.99013343934091, 88.74057354465609, 93.48264848032306, 94.90630411332654, 96.55666489754954, 93.18144183005057, 89.47795560283046, 74.98132259615006, 78.95043173143941, 72.04096486491542, 74.57990723271524, 76.03923290006577, 88.04003823188044, 95.66130545831497, 100.18629289442494, 94.66423896051224, 100.10548422413488, 91.86070919036867, 86.86793988750827, 81.81839819877379, 97.4402101578251, 91.71164343433996, 100.78854145542269, 94.2976777784286, 99.38968304664859, 94.01855407222625, 94.90901839348578, 81.87619824563303, 108.43890482379545, 63.441901745334754, 50.33222667632565, 102.291225002658, 86.99740163741573, 95.94954475279778, 90.65902833015689, 100.69012918779927, 92.15151371494417, 96.67815639126687, 96.98761570838191, 97.6268522201046, 95.01310240837836, 98.1160423832555, 97.48206184756373, 95.58082626711939, 86.99731534527194, 85.81382643791937, 92.60972499847414, 85.36984551337459, 75.2118952043595, 75.86568370942148, 79.28948925387475, 89.42584299272107, 96.17328459216704, 99.55851754834576, 95.27118652097641, 86.80187148432579, 83.44797826582386, 82.91052726007278, 86.98075509840443, 82.32057140719506, 87.01466791091427, 86.7661230025753, 90.51276314643123, 93.01729848307949, 97.32509643800798, 97.17475983404346, 62.29881717312721, 8.837687373161316, 0.7923935449892475, 0.9313428954732035, 0.4030097149793179, 0.35081982192012573, 0.08998355377585658, 0.25898543036272453, 0.19176466240277215, 0.4137575914782863, 6.772683032097356, 29.768616614803193, 47.061283742227864, 59.28670752433039, 106.13442605541599, 120.66967871881302, 95.04102183926491, 68.0216964598625, 21.503457023251443, 37.5504421418713, 48.54631662368775, 80.44593734125938, 86.78804905183854, 105.0252111496464, 32.01384798172982, 0.7505162985574815, 0.045274490145065134, 0.026221326139244824, 0.0582194340325171, 0.03120973447127448, 0.06880525995286242, 0.06741235122805642, 0.019352426677341425, 0.059171800066025994, 0.07267804125383978, 0.01384566410354549, 0.05466091348939846, 0.043112976897147395, 0.015987138406583862, 0.08797311689704658, 0.04056267785809694, 0.04733411752949319, 0.036634665448218584, 0.08305831046234216, 0.01598420812027349, 0.038316297389927416, 0.03686864402205233, 0.03269150748007721, 0.021167369409193917, 0.03294310224572978, 0.04946905901775726, 0.026962906910827564, 0.11403349753949912, 0.09957494394433114, 0.10607590478274131, 0.13394170951458717, 0.16517900591415746, 0.17389780661511808, 0.15156501062935399, 0.11224553259390016, 0.12427284487433012, 0.23687982541178507, 0.08057577956107356, 0.11675388341949833, 0.10888317269423317, 0.28595681212121443, 0.18774479988121218, 0.15543277405442732, 0.20708130342104744, 0.14195854385052958, 0.11506576271307085, 0.18254540710439607, 0.21973431801363347, 0.15423214573773647, 0.5621718050491425, 111.19818241365495, 170.17709762819354, 142.2210474937193, 156.15423202514648, 96.02368539379489, 105.63149190718129, 37.70963153531475, 41.45910755280526, 154.4145667168402, 107.03015419744678, 72.4433921998547, 70.38075893155991, 64.41913281717609, 12.510454577784385, 0.5327683086356809, 0.5993784891982233, 0.32204074845198666, 0.30743074693506767, 0.6896604801858626, 0.3706845124402354, 9.194116092497303, 6.290562941182045, 8.243475748646645, 133.7295553761144, 110.82572198683216, 129.1169108113935, 106.1629181523477, 111.52355870892926, 109.1429938039472, 107.94948716317455, 109.62165632555562, 114.06883962692754, 103.06837989437966, 109.45303363184776, 102.18310094648793, 102.28194467483029, 92.83601437845539, 97.15426937226327, 99.27620103282314, 101.96194202669206, 98.41911608173002, 94.83446982599075, 79.01648444514122, 83.01587427816084, 76.76399277102563, 78.13766171855312, 79.25476058836907, 90.39735917122134, 101.04908881648895, 104.1330131407707, 96.93441267936461, 106.59598704307311, 97.46580754556965, 90.94239604088568, 89.3346243519937, 106.45144770222326, 97.06216427587695, 103.32079225970854, 99.4799054053522, 103.51907591665946, 98.87721753889515, 101.88204334628199, 87.82719473684989, 114.16539269108927, 68.43932690158968, 56.0744510927508, 105.07561360636066, 92.66859193002024, 100.71491072254797, 96.734952311362, 104.00337880657565, 96.83158382292717, 100.98619753314604, 100.15656917325913, 102.1592450910999, 99.05756811941825, 102.05601615290489, 100.01693279512467, 101.03923582261609, 93.40520520364085, 93.35103727156117, 98.12325169963222, 89.9667299947431, 78.68601691338324, 79.99671613016437, 82.93934883609896, 94.3304923272902, 101.8103345747917, 104.51404002404983, 101.08733192566903, 91.99050826411094, 88.23704319615518, 87.4267521212178, 93.1320748790618, 86.32048683781778, 93.11060382473855, 90.92807938975673, 92.26361505446896, 97.822233323128, 102.02817516942179, 99.14073805655204, 62.2696739627469, 7.729595736149819, 5.097125922479938, 2.8229192716460076, 0.7678537263024239, 0.3608356247986517, 0.21724598782677806, 0.3270066223077236, 0.24109073493990207, 0.6415147346354301, 12.565605063592235, 46.17369451830464, 71.59044927166354, 79.73327405991094, 97.7336818941178, 121.59918631276777, 116.32409264964443, 139.47851057975524, 36.48356922211186, 32.07340328924118, 56.443628495739354, 88.2519168238486, 98.8963665500764, 116.33008603126773, 41.156171137286776, 1.2482716311370174, 0.18094422205561594, 0.15084170105476535, 0.23476459536581273, 0.23268275143158054, 0.17229231615220347, 0.23121288917478056, 0.130509267891607, 0.18090458466641365, 0.12102019642629933, 0.1248288944724106, 0.23429236344752774, 0.08125735266554741, 0.08502273610041988, 0.17806831266610854, 0.14884408082692854, 0.1617983824783756, 0.13476122441070695, 0.16110988393906625, 0.2012520637964049, 0.17724314404110755, 0.17849130045262077, 0.18252366552910498, 0.13655897229909897, 0.25241572079398944, 0.16955453241544385, 0.1885310972049352], [0.06907579624244282, 0.05078228310711923, 0.1272712593838092, 0.028052596119983543, 0.02122250092666476, 0.026521176783247825, 0.04140949612783809, 0.04495516554602692, 0.0526699927004595, 0.022223837215513475, 0.03530806546369868, 0.02438206777667567, 0.054483621591521855, 0.05299633466488412, 0.13476595883407902, 0.08303593303407393, 0.05902419407521525, 0.03900732784982651, 0.05370511538198879, 0.09782861587741683, 0.21357958295172264, 0.2880701422691345, 34.79340422538019, 131.1726877766271, 105.7774668355142, 106.65141797834828, 67.84730788200133, 112.07731108511649, 33.603765041597434, 49.68629075634865, 50.20709914545859, 50.96171609817013, 62.17701581216628, 43.74740262185374, 25.11912334349848, 1.0489940210696191, 0.2189737765659248, 0.15316981161313672, 0.10099142519456726, 0.010219762297046762, 0.06909879420192973, 0.17548809789361494, 1.32111850284761, 1.402623393843251, 0.572570376098156, 90.20108376779865, 111.44386399176814, 107.0413564866589, 100.82691008044829, 95.43036414730935, 89.58142772797616, 86.52161029077347, 90.72264917435186, 89.74472384299003, 90.97674031411448, 93.50753199669623, 89.93265244268602, 84.5544945809149, 81.23401995628112, 81.49641867606871, 77.44568501749347, 84.57981740274738, 87.21093546959662, 91.12814380276589, 83.79645732141311, 72.62480966506466, 73.77471523900186, 71.2665948560161, 73.55621568618282, 70.17825480430358, 81.54523649523335, 91.42099580457135, 95.33906705917852, 92.074093972483, 95.54104558883175, 89.04342759040095, 81.74584219532629, 77.8147957401891, 85.97854245093562, 86.46017028439431, 94.35312440318447, 92.22370101559548, 95.2052200994184, 87.3678538107103, 89.16171058531731, 83.59534955793812, 96.23175144195558, 76.79340270257767, 46.393190353147446, 99.40767888099917, 87.84657124550112, 91.57621183703023, 84.58167660620906, 91.82794170994913, 90.86058324383151, 93.74934611781951, 89.85045525335497, 93.50192300734982, 87.22832725894067, 94.27722654035016, 95.54703112571471, 98.87992397431405, 90.76295545024257, 82.0626598788846, 79.0833765460599, 77.53182811121788, 69.24603293018957, 72.66508456199401, 73.26029639090262, 89.7839867684149, 89.17445828837734, 94.17182460907968, 87.29470945173695, 83.62223348309918, 76.74796596650155, 76.98660296778526, 77.41294107129498, 80.53412791221373, 78.60249396293395, 81.64386057084607, 83.83230778478807, 90.33989644819691, 91.28496800699543, 92.78166601734777, 81.29903716425743, 46.839587457718395, 2.4116366957464526, 1.2722061790766255, 0.5050039952320438, 0.1995555314445688, 0.16184096164520712, 0.05461890888851016, 0.14642354942137195, 0.014780065375230005, 0.5682524594087754, 2.2179890351910747, 15.561779102971478, 51.49739811497351, 37.33225637866605, 59.479880332946784, 127.12673940966208, 152.8835715017011, 99.77396549717074, 31.284863718094368, 25.843851835496967, 52.40761549242082, 81.75003128667032, 86.9125529258482, 70.74753192163283, 0.6341572874976743, 0.1306352127463587, 0.04180040398252107, 0.06478178149629986, 0.0514760829748646, 0.014153446630394508, 0.015848630667483855, 0.03605704281419035, 0.12725858062866235, 0.05531549348586029, 0.028666092736286022, 0.13990123005163285, 0.0816699906042026, 0.01739014991589131, 0.04077608697116375, 0.04543856319580828, 0.013143661349350888, 0.04533866150004249, 0.1126619167025051, 0.07781755659849414, 0.021051851011091666, 0.10001741334675782, 0.10767887481638502, 0.0926249253473455, 0.042833703374790574, 0.06320431836009507, 0.04199748776192146, 0.04656838583609751, 0.05833304104124827, 0.04881334904160711, 0.11302264452341104, 0.022143051328678286, 0.05115835183870889, 0.06920203221060577, 0.03237533150240779, 0.09009393938486615, 0.02057714462881127, 0.020773935379580628, 0.060784510907626925, 0.03693247063746376, 0.0653495445787426, 0.12340035499824632, 0.04438401635495886, 0.03245374443189752, 0.033906128392705036, 0.040136943646376176, 0.08426153581709632, 0.1810298400420335, 0.23444164334045303, 49.91012473260203, 155.77862585744552, 113.80393059022965, 129.94048303173435, 85.0925967001146, 114.07149114916402, 50.889054190727975, 66.84344783906015, 12.309792003323956, 57.306416573063025, 60.223632320281006, 40.728515117399155, 36.10291888636928, 0.3190593181117889, 0.2971382637418086, 0.0980714580885345, 0.1536989178989203, 0.0760935599945726, 0.09029004257172348, 0.5109304514142775, 1.8404666670868475, 0.48416900839055743, 1.8152660516000565, 100.98625244632845, 116.93864176350256, 111.3810746900497, 105.65526147042553, 99.14677066187706, 94.67839087209394, 91.09314841608848, 95.683317799722, 92.10308028805642, 97.6730812749555, 97.22553883829426, 93.26069724175238, 88.32086424673759, 85.65115005739274, 85.74960154871788, 82.42471033527006, 88.84428101201212, 90.8767669431625, 95.68582027189194, 86.60301516132971, 76.35820788721885, 78.99619794661, 74.63522049688524, 77.43254507741621, 73.75657035458472, 88.88550512252316, 96.8831237669914, 97.56674581958403, 94.54266117465113, 99.01605375351446, 93.89976901392784, 85.69384897908857, 82.72823118394422, 89.8956331129997, 89.57378695088049, 97.01078907135995, 96.04376792907716, 99.0250281364687, 90.44874222047868, 94.44129928465813, 88.86786230148809, 100.18455136206843, 82.61128179488644, 49.398298571186686, 102.34084298533779, 93.864012687437, 95.0405276206232, 87.16261186907369, 94.50055845322149, 94.30448701304775, 94.16976144236904, 93.16779982659125, 96.16590269150274, 91.78754129717427, 96.88490452304964, 98.91051061691778, 100.50094542964813, 96.06895739032377, 83.656601290549, 81.86699636520879, 79.44403848340436, 72.85615890256821, 76.22445506434288, 77.3952276475968, 92.49099485335812, 94.91630615726595, 96.58791049834221, 89.62098875353414, 87.3470260250953, 81.66217803955078, 81.6533370171824, 81.19593374190792, 85.07669541143602, 83.03925160438784, 85.03996633714246, 88.70589194759246, 92.36119577961584, 94.55301623190604, 96.06884756395894, 84.13638561002671, 54.040733537366314, 5.417321747349155, 0.16847079379423974, 0.4833332371086844, 0.28365998859367064, 0.7905900514414235, 0.0813348654417261, 0.14500130718994528, 0.03884445372668486, 0.6158002273690316, 1.0453127540888325, 20.787451882516187, 50.17855605771465, 38.06486883471089, 70.97043237378521, 120.73812407831993, 135.16197358408283, 49.50203349513393, 24.897026977231427, 37.79380559921265, 59.420476036687056, 93.31776772775959, 96.14039944064234, 97.25248552137806, 3.438915740097723, 0.06959449905421465, 0.0034168565217705987, 0.040828299693643086, 0.038711514489184466, 0.01383584572918593, 0.0618433440104127, 0.045007692364555214, 0.046680238503482074, 0.10076743640726614, 0.029856361629020785, 0.09502415184772785, 0.04874588733899498, 0.05294305324975041, 0.03610615288057635, 0.1126265540839203, 0.023923340073275953, 0.04924328907603218, 0.10078723211922955, 0.018784956623529716, 0.025430826823257154, 0.04998245667065344, 0.09227915156272151, 0.10025686944925016, 0.02848463715054095, 0.04220952557760381, 0.02610124377233367, 0.13584488642311868, 0.13378990153151174, 0.15628877005750136, 0.19921698186907077, 0.11032567795125708, 0.18839237400360648, 0.17752192343675322, 0.1382894270242222, 0.14278864608176295, 0.10032020193795044, 0.15300911701013967, 0.2083445057993935, 0.09396607717198711, 0.20783355579741541, 0.21214440915613406, 0.14654140438764326, 0.14735696627007377, 0.14122575010743835, 0.21752931778469395, 0.22226867476297965, 0.2865646875673725, 0.4915484269299815, 64.16006026729461, 177.72025477501654, 129.21745684839064, 140.59214991907922, 88.97896735898911, 135.4103066844325, 43.72498627631895, 73.86530630050167, 73.086056863108, 79.8156673677506, 82.24930978590443, 71.10947255165347, 44.30970968738679, 2.3872552427553364, 1.276763728068721, 0.2378364087593171, 0.48792406496021057, 0.1393476395957893, 0.3452805772183403, 0.5546612016135647, 6.585286894152242, 8.585976131500738, 2.2913488793757657, 106.41107866840979, 120.45314035108014, 115.91663683614424, 107.55057427190967, 103.59697418828165, 98.76541429950346, 97.07685747454244, 100.07412095223704, 98.61062188302317, 101.139617120066, 102.09063499204575, 98.87113002038772, 93.33563020152431, 92.32438825791883, 91.77701365563178, 88.52856159210206, 94.10780368312713, 96.23110817324732, 101.24492491445234, 92.3266161641767, 81.16559028625488, 82.09581959632136, 78.83482379298057, 82.48120031049176, 78.42783866390106, 92.20270849043324, 101.75935160729193, 101.14009564922702, 96.99163221543836, 105.49909622438493, 98.78315910216301, 89.70959509572675, 86.41336071875789, 95.09337763632499, 93.97570610046388, 102.42818632433492, 99.11992596041773, 101.34781652881254, 97.08565142846878, 95.5515810751146, 92.53376437771706, 104.40948532473658, 89.65872979933216, 55.61854224051199, 104.16931075434532, 98.94133260173183, 100.50216136440154, 91.3257057436051, 99.73419266362345, 97.65550121184319, 98.36708191902407, 95.83288561913275, 101.20006868916174, 94.980907594004, 102.6770842459894, 103.79714842765563, 107.68069498000607, 100.7712673371838, 89.45493913465931, 86.51081592805924, 84.02990894932901, 77.62651412717759, 79.93576249768658, 81.93794419688564, 101.07022254697739, 97.40410866275911, 101.18449687957765, 95.48490862692557, 92.94175363356068, 87.06732965284779, 85.19411548491448, 86.96276710879418, 90.316589724633, 87.5575396322435, 87.76471922474524, 92.29801424088018, 99.01793649119716, 99.87913208623087, 98.78165291201685, 84.62836850074031, 55.853300017695275, 4.023195678187955, 6.236639176645587, 2.687414865339956, 1.0238076854617366, 0.3988482947311094, 0.1711148236908259, 0.6243881955742836, 0.14550890172681502, 1.0020074584791738, 6.742917635748464, 30.12833129975104, 73.1467123954527, 46.14018570992255, 73.67059200040757, 135.00517291407434, 162.85429923765122, 128.83220165006577, 42.89813887688422, 42.96114390896213, 67.80555032914685, 107.44771403651085, 107.792890456415, 115.33546709245252, 6.030942730365261, 0.5197227505906936, 0.2653254514500018, 0.1068045539901622, 0.11626896508518728, 0.06483229733402691, 0.1490518438719934, 0.10826215884017368, 0.18339153589500537, 0.21168202912855535, 0.2620354102503869, 0.19002073985194007, 0.19167608731696684, 0.2775031850943642, 0.11320577784171028, 0.2637907015460153, 0.11480861764040687, 0.20347214063569424, 0.16098369393617878, 0.23185988107035238, 0.1787440175370824, 0.10625228886642765, 0.21414823469615754, 0.24910622096109777, 0.11313734320743431, 0.1872144678547498, 0.09790648871491994], [0.01717395798843955, 0.043431010638033195, 0.04816279100674776, 0.06910503015763338, 0.050470416374023885, 0.062269380826863556, 0.07008130196481943, 0.0778769513952636, 0.0893572768977573, 0.031948049793079976, 0.03303316354210819, 0.03782493625617316, 0.032981598163924875, 0.01787638783665194, 0.07186920562338445, 0.07160797730208406, 0.13184146414841377, 0.01585156478423385, 0.014389251366317754, 0.09033959313866594, 0.17546038083251447, 3.7789180634483217, 112.42300525788339, 103.56171208043253, 120.42881381127143, 75.63511110121205, 104.05465202946817, 208.3933621068155, 111.00953209784724, 42.528263292004986, 122.08453255314981, 47.87778785151821, 48.36547574689312, 31.970533247916933, 0.2809303253889084, 0.22532580991185483, 0.38228345133604547, 0.14471578622056594, 0.0922140953761916, 0.18045014130973047, 0.25142752865870155, 1.1256474304583766, 0.6990278968887945, 1.959349907213642, 57.088273955929665, 122.50903498741889, 104.27570112289922, 102.12632856061383, 93.90789616492488, 92.17099220521989, 85.07874288866597, 87.52940839336765, 74.09238799925774, 80.82468140509822, 76.16860835782944, 78.90495577166158, 75.89209695016184, 77.32437395280408, 71.46975794146138, 74.02298558142878, 77.16874999384727, 84.49055210236581, 80.4292594232867, 83.1910159510951, 78.39010546284338, 70.23717664903211, 72.65406270180979, 68.39998552876135, 72.14286019725185, 71.21969115349555, 76.72968772149856, 90.68344900684973, 92.4510415907829, 91.31452698861399, 92.10730075836183, 83.06227591729935, 80.41297374233123, 76.96058196406211, 80.88332083917435, 83.52462922373127, 86.42828925963371, 90.21261553610526, 91.64800690066431, 88.60795820913008, 89.33365160419096, 82.31986538056405, 90.58936703589656, 87.72208306097215, 48.00273103098716, 89.98583193748229, 87.63021330679618, 82.52147520742109, 79.3430531409479, 85.53518126087805, 86.30260082983202, 89.27774213975476, 89.58198470454063, 91.1981345761207, 90.94744805366763, 87.97716263801821, 92.60315895080568, 93.28941683615409, 92.47234790555893, 81.65918134873914, 72.24882694982713, 73.59125029656195, 70.70116166145571, 69.08520006364392, 71.0828318134431, 83.63850347457394, 89.89731188743346, 88.89703689082977, 83.52709247219948, 76.87347396727532, 77.87607100702103, 80.16978679164764, 77.74132974686162, 75.6897654071931, 77.9751657670544, 78.32717495579874, 82.90991537032589, 88.18922950375466, 92.022718767966, 90.05601098460536, 81.64133456445511, 81.19950309876474, 38.59661279186126, 1.004829910253325, 0.9441641429739615, 0.30258269740208504, 0.6805146161106326, 0.036697794923618916, 0.09580232863945347, 0.07910403272797985, 0.054133902454087814, 0.08981695263496331, 0.2998509197946518, 15.054528386362138, 42.40773670135006, 67.68034827324652, 117.75260417692124, 104.59502912336781, 103.5836930428782, 38.97840453732399, 40.358721902293546, 65.07131707283759, 77.78740190690564, 76.0950796065792, 88.50472927093507, 12.250188646777985, 1.592509501403378, 0.3097071312367916, 0.23215169928246931, 0.06817578848811888, 0.09403277278667498, 0.04043159638381293, 0.09986460944938083, 0.02449928114431039, 0.026288217106353373, 0.03557296334615639, 0.07303015824647681, 0.06535477695926543, 0.021129147367431753, 0.04974082104801651, 0.036889860827115276, 0.025671091148509614, 0.012274633233074941, 0.04895148618567375, 0.08949842859780596, 0.028134640306234363, 0.05721183305966759, 0.040412206698449395, 0.031498040170258576, 0.04964936164117629, 0.010049307733894357, 0.03775291633041155, 0.022549717611963713, 0.03830331219961086, 0.050667266496607376, 0.13021296040425379, 0.040950739696141214, 0.08718234561984578, 0.021672751867182313, 0.08219081547952468, 0.0479162102865596, 0.03260393979989233, 0.04874212201684714, 0.03121101192288822, 0.04945805799516459, 0.03622673128941848, 0.077084104019788, 0.012372338171717862, 0.09260864597895453, 0.0834327819006097, 0.07185180776662405, 0.03624831581668508, 0.2830433491016588, 8.11217587801718, 138.75059712317685, 113.32239689365511, 137.94343609963695, 84.67500548208915, 107.46391342532252, 198.67540759425012, 98.60008639674034, 20.13269651320673, 105.92515976198258, 56.13723254972889, 48.519283648460146, 43.42365803257112, 0.3608130098831269, 0.18930265499699503, 0.2972472014446413, 0.09521897566775162, 0.04171659779404441, 0.17035285731957805, 0.2123170700525084, 1.5057496149693768, 0.779555811276359, 0.3550545414609294, 70.30938748390444, 127.7511650516141, 108.75687568418442, 107.65918470198109, 99.18673961393296, 96.50796474949007, 88.59262174175632, 90.95965446964388, 77.72321624140586, 84.16582692054011, 80.5899824634675, 81.15211302234282, 82.27573871612549, 81.54499330828267, 75.16953360649848, 77.77719589971727, 82.811628618548, 88.4692318208756, 85.89028127731817, 86.3959453951928, 81.38255226996638, 74.0606560245637, 75.7376967706988, 70.93318554662889, 75.33998412470665, 74.5268532537645, 81.38899280178933, 96.0542877258793, 94.17883780694778, 94.13378546314856, 94.5202644409672, 88.0753944766137, 82.45830935816612, 82.23817025461506, 85.46178587021367, 87.16097231834166, 90.87460179482737, 95.88859896506034, 94.9944083921371, 90.52072555788102, 92.91585030094271, 85.51356115648824, 93.87799985947149, 93.52360586966239, 51.42526180513444, 90.42850279038953, 90.8558528654037, 84.84088251667639, 85.34426381511074, 86.94124114128851, 90.79355778232699, 92.71610752228769, 92.97953390306043, 94.60522297889956, 94.6079372590588, 90.66204855518957, 95.78217721754505, 95.80087907852666, 97.72310718413323, 83.69119659546884, 76.30496563449984, 77.09365229452811, 74.81619081189557, 71.98117225400864, 74.54419012992614, 89.43690407660701, 93.17416191101076, 93.22193637970956, 87.51481717632663, 81.36356799833237, 82.4687114838631, 83.91494427957844, 83.24364631406723, 78.04580765385782, 83.07736135298207, 81.64958723129766, 87.5949590436874, 92.321501393472, 95.41124651508947, 90.91846173809421, 84.3696254299533, 85.54796034289946, 45.9264204579015, 2.4996350705623627, 0.18052029964183608, 0.5509757058274362, 1.5102142528180154, 0.3671704058445269, 0.2774733383088343, 0.04614628671157745, 0.05746342016444091, 0.0390665847507696, 0.35669170199863376, 17.92657509926827, 41.91935846882482, 57.01133666499969, 122.81413262890233, 114.0304631571616, 95.01779356310445, 23.967780220893122, 43.332117757489605, 72.54396177107289, 87.37779309672695, 82.7753859181558, 105.81188955614644, 25.85185347064849, 1.7259872680710209, 0.38434324725981683, 0.25873072144965975, 0.1367020468798376, 0.09248157497495414, 0.04505644620005642, 0.12398160888903564, 0.08382307305451363, 0.09700867197205944, 0.031221999538942214, 0.03845697411546304, 0.014178835741815068, 0.05652049233415916, 0.03879519427315362, 0.007812263004692092, 0.038068345372354796, 0.08733587730075083, 0.04192864710104562, 0.041743617715133775, 0.039366971656319596, 0.1313007592914566, 0.02064018983453993, 0.05491178813240221, 0.06411537693272676, 0.10186262038205901, 0.0416901256258209, 0.12252120781810054, 0.116712445723674, 0.152758008710319, 0.28910567863814296, 0.11418411042541267, 0.23043736304727294, 0.1646737709280945, 0.17493919589586798, 0.17786418087780478, 0.16178822415249963, 0.14854746690440565, 0.12379810784853275, 0.16609728486547548, 0.11542472853175095, 0.22868092261975814, 0.1523003937496293, 0.2798391097495633, 0.2595647460510654, 0.220816555102506, 0.18633614804956222, 0.45852743269455054, 11.261149279532894, 159.44943089638988, 130.15339712942801, 152.83312982128513, 101.93577197290237, 123.04996121314265, 206.61619893966184, 136.43115843496017, 64.90167064051475, 178.8947065414921, 72.03053920499741, 78.93355769495811, 54.98058442146548, 0.7731435940630975, 0.91325709175679, 0.6533028053179865, 0.6193498498009098, 0.28467848716724303, 0.6445515071672778, 0.6085044962744559, 4.627977600020747, 6.9368906078800086, 3.428148098530308, 73.86464734231272, 132.7414946402273, 113.24432603774534, 109.00755436189714, 105.56101475992511, 98.75210961987896, 93.13753481834166, 96.16934653251403, 82.59996967930948, 87.6021291363624, 85.71307643767327, 86.04933338780558, 86.61555890114077, 85.43492547927364, 81.85569993911251, 83.0491045982607, 86.74303593174105, 95.89743998742874, 90.96367097670033, 91.02343220864573, 88.74359376968877, 77.33000647637152, 81.29225146385932, 75.0750986222298, 78.43040389399376, 78.7572471557125, 84.97580420586371, 99.24115073296332, 101.38832676795222, 96.85196445834254, 100.52542886426373, 92.34556905684933, 89.02849904952511, 85.17171875123056, 90.59503093842538, 91.21970761206843, 95.1680987881076, 98.67208542362337, 100.83036961094027, 95.56958475420552, 98.42815322260704, 91.3393634365451, 97.8693723678589, 97.3980603679534, 57.9044956545676, 94.88413487711261, 97.72137349651706, 89.71174455458119, 90.28521076325448, 94.01551815771288, 96.05045164785078, 96.90364560773297, 99.01418670531243, 99.51154324316211, 100.81284446101036, 94.35982381143879, 100.12317411361202, 100.02689561536236, 102.08693227460309, 89.55256692824825, 79.7326700149044, 82.75468364838632, 77.98580323496174, 75.5774679491597, 78.6959405099192, 93.35757194026824, 100.34785532182264, 97.05466470410748, 92.59004254494944, 83.67702114966609, 86.66760875332741, 87.88308066706504, 87.10719662327921, 82.23052947751938, 86.2358420894992, 85.1656469222038, 91.62123280186808, 98.31649118854155, 100.77225577446723, 92.00634679486676, 85.20509812139696, 86.38940288174538, 46.424228068320986, 2.0507823171154147, 4.361938430416969, 2.3414691705857558, 3.7192303759436456, 0.4091233111196949, 0.8759483646961951, 0.1640794245946792, 0.21882229033977757, 0.23935039768055563, 1.1932005733251572, 24.014505455570838, 69.63353172425302, 81.13115187614196, 123.08237568024667, 115.43031000321912, 128.37459441154235, 56.786706447601325, 56.968410245833866, 83.18677194656865, 99.41787704344719, 96.3979579556373, 121.6739623777328, 36.08577028397591, 2.3784161815720224, 0.7164601969622797, 0.44462526577614975, 0.34793399935287816, 0.17540899165455373, 0.21276538470579734, 0.3410674307134844, 0.2077362779527903, 0.2215808963463191, 0.14098274701785657, 0.1625621108518493, 0.09895520179622597, 0.11862430240838759, 0.18116897693084133, 0.12859268444440058, 0.10179457645262442, 0.1420158165837488, 0.17127066129638305, 0.14751617466249775, 0.13666069345368495, 0.1708898543109817, 0.11975468046242192, 0.13440586686615022, 0.17019041603611362, 0.14855523503595783, 0.11511077803950157], [0.022564148793237346, 0.019730831977100145, 0.04141693867202248, 0.035768775419602473, 0.05734790176633866, 0.08181861166151301, 0.04621888503372189, 0.10379128503583132, 0.046521777046784285, 0.05958670562493706, 0.062333621129754095, 0.12319915732669255, 0.015447194849501456, 0.09190218267782081, 0.001350777360306482, 0.126914530541868, 0.06948067371042506, 0.058808999977284865, 0.1373608058859264, 0.22108346013532532, 0.4086122079001319, 40.04893310608403, 121.09799369688957, 111.34907599418395, 99.28577161604359, 95.21239803683375, 60.265048626930486, 40.86640604080693, 48.38868833357289, 110.73935139563777, 28.145955608737086, 43.889227682544345, 34.78344532751268, 0.28114823143809076, 0.11038440625153242, 0.055803445528351495, 0.015420479448361984, 0.06774282623683253, 0.08910465940472581, 0.13982488172909907, 0.2539161346372097, 0.13757390090294425, 3.2011316091783586, 22.154888183839862, 128.47576802776706, 99.82178703431161, 109.80727072684996, 92.26939662810295, 98.09574803998395, 89.10501664684665, 95.45955442613172, 80.71060319100657, 82.41320994592483, 71.51167238912275, 76.17430363931965, 70.30006793237501, 71.97246459222609, 69.0844940370129, 70.14376148100823, 69.17186091023108, 72.75301625651699, 73.58459011200937, 81.70281379453598, 79.78757535257648, 74.17196504531368, 65.46880614372992, 71.88650192752962, 68.00284554881435, 74.51015180157077, 71.7028408665811, 74.0731526959327, 87.87200389369842, 92.55019126399871, 93.4007493911251, 91.49618764077464, 82.0520773241597, 75.18552903206118, 74.78333703933224, 78.7195453336162, 83.53170517952212, 90.53269663164693, 94.42713952833607, 89.11262604498094, 90.06788792148714, 89.94453722430815, 84.70777296250867, 86.48420656881025, 92.52739444855722, 48.23470000297793, 84.22374463850453, 91.11893407760128, 83.88324368384578, 83.12536331915086, 78.39652246044528, 82.05787458727437, 83.87989397971862, 91.3425797800864, 88.55863832658338, 90.85108326327418, 85.23453943191036, 89.95058551911386, 88.36738355698125, 92.41058626482564, 81.1456960247409, 74.1301368897961, 69.92567769942745, 71.67882027164583, 67.2714098038212, 70.96643155620944, 80.6668060056625, 84.35942726750528, 82.91284930321478, 82.77067122920867, 79.78221739492109, 79.8100583784042, 78.73071624386695, 80.0767481711603, 78.11258208367133, 78.82806947154384, 77.7070874552573, 87.95852353495937, 87.30489192470428, 91.06517407201952, 84.36920965871504, 85.96680671938005, 87.69474414087112, 85.64911826964348, 31.341475286791404, 0.39067830409734483, 0.47052014078344073, 2.839949957786068, 0.42582433430417893, 0.28557615835339795, 0.06699045894727593, 0.06873833451179728, 0.03482690479065623, 0.017831389747199514, 0.11819601329343936, 11.609775424003603, 33.080599308013916, 49.955235911953835, 77.91223526000977, 49.09506797790528, 58.3179997628735, 27.023736084661177, 25.290532881213775, 63.834527077213416, 79.53432360003072, 73.80266604884979, 64.18801892188289, 2.9392565258087653, 0.11225462605756138, 0.037028365693385565, 0.05003250519474668, 0.03917163838782618, 0.0707563096957822, 0.08274250603731602, 0.049444708913084, 0.02533413312067428, 0.04792476748867382, 0.04837780124357632, 0.08012165030043933, 0.04133782477208203, 0.053877554112865086, 0.028014017847336592, 0.09014961865520285, 0.07316536510423308, 0.08151364738061544, 0.030163210486212087, 0.07878496476839628, 0.02071161412694041, 0.06460267780048233, 0.057213066461225676, 0.05742216249927879, 0.022889900869960268, 0.0698953417820796, 0.05481485119690338, 0.05015909356335479, 0.07329066644512838, 0.038458939130988815, 0.04796189977036369, 0.013223575811172205, 0.06492143166401694, 0.10114828169706369, 0.036697082461849335, 0.036806836048321384, 0.0514244869531643, 0.06298519806155274, 0.12365606748649191, 0.061264116422183094, 0.05776236682469326, 0.07544053898703668, 0.059548623394221074, 0.08251343808707692, 0.1010904037543843, 0.2403181659117822, 0.3150009520111546, 59.19857578892862, 136.84691398374497, 127.07557601313438, 105.66782089971728, 105.80476653191351, 78.65080187397619, 78.54743957519531, 47.31025618891562, 71.07969391730525, 40.21248809752926, 35.58438939432944, 45.1438723071929, 0.2640356658206832, 0.1970834882869836, 0.2027972478179201, 0.23396043287169552, 0.12735817971969807, 0.2669099664255496, 0.10227525065983496, 0.41715819448713337, 0.30778247322286334, 1.6859892659610318, 29.605626444662775, 137.43613243103027, 100.22847406325802, 112.52888571831488, 96.47560519556846, 103.84343239568896, 92.30421158575243, 99.12704898465066, 84.6256777548021, 87.25590152125206, 75.39579160751836, 79.11454369944911, 74.86693843718498, 75.46423696702527, 71.4066783843502, 74.94713521772816, 73.43123328301215, 78.23143774463286, 75.9778948753111, 85.48670076554822, 82.1102225395941, 76.03825230752268, 72.0122766494751, 75.12293584885137, 73.59584731440391, 76.98031148602887, 74.92497382625457, 77.52912167579898, 91.88290196080362, 95.01417713780558, 96.7671706599574, 96.2843112022646, 84.01388998954528, 78.36319800346129, 77.6736923956102, 82.85879119749993, 88.79763618592294, 94.08990983040103, 97.07922658612652, 90.30931765033354, 93.82576173351657, 93.5387775974889, 89.11235932380923, 89.10846048785795, 96.61804999074629, 52.2145878115008, 87.03874341903195, 96.50168895721437, 87.40068404905259, 85.668455554593, 82.04535438168435, 84.45253649065572, 85.04367689932548, 92.91509720586961, 92.27939867204236, 93.30425908488613, 89.6512851407451, 94.41934970117386, 92.53359963816982, 95.8734429267145, 82.4350183240829, 77.58822394955543, 72.37875153941494, 74.16426151029526, 70.49963812674247, 75.60472842185729, 84.86928047672396, 87.5936254378288, 86.22541642958119, 85.84340110901864, 83.33084844773816, 83.89051575814524, 82.92780137831166, 84.76338432681176, 82.98614271225469, 82.14437853905463, 81.4823216776694, 88.12450255117109, 90.98706399240803, 91.1534744693387, 89.33103146091585, 87.76194218666323, 90.8138599703389, 91.38941287994386, 41.14559250493204, 1.4613715511175895, 1.0301092795787319, 0.9335690244070945, 0.3014596737921238, 0.18004495740657855, 0.059417266128284324, 0.037275310305337754, 0.09994352416646096, 0.0968693359003913, 0.315542392312519, 11.56256381542452, 40.10867864854875, 52.45194219773816, 87.36324110338765, 63.11130085299092, 49.16539999746507, 42.49937503568588, 42.18782509526899, 74.92593872931697, 87.78637855283677, 84.2751512219829, 92.16124903771185, 8.720730139363198, 0.3895263223638458, 0.1052544363624146, 0.08891108430801861, 0.04793389542629162, 0.04112574865200347, 0.09572671576132698, 0.03537025265095215, 0.01875544500146662, 0.08288735028115973, 0.053299946800595334, 0.02845292685613517, 0.029131370491438338, 0.04294241125124597, 0.027072158709709204, 0.0861233133341997, 0.06645914632827044, 0.06913346734138266, 0.022223343088802312, 0.08120186491719178, 0.02556815382934386, 0.09096022394876327, 0.10620568773799366, 0.08736298149151188, 0.10985842560447993, 0.018994343774994055, 0.11656740229696998, 0.09147285934417479, 0.21156046629673053, 0.12937898176812357, 0.173851013964703, 0.1891415620282773, 0.12475165748788465, 0.17168005868311853, 0.17660082528187385, 0.26997021189139736, 0.21356329592245243, 0.2081251901484305, 0.2565452258192724, 0.18122877775421067, 0.17045091657388597, 0.16130235586916247, 0.1820202538323018, 0.10964225857488571, 0.22718861398677673, 0.3862942893418574, 0.4657988328366511, 71.48905600270918, 155.8163276795418, 141.3156860105453, 126.6643076558267, 119.73964552725516, 83.7736605059716, 53.80445780292634, 71.45646895131758, 160.19475967653338, 37.13008957524454, 67.94776762685468, 56.11098404853575, 0.8635366371562405, 0.3110863346486323, 0.5808694985124373, 0.8478357570786631, 0.20254799345087623, 0.8706261373815999, 0.3655660951570157, 0.6020359562770013, 4.05288091109645, 9.409929802340846, 29.849672394414103, 142.29663941168016, 104.95751104047223, 118.32051630943053, 102.54953661272603, 105.54235212264523, 96.89194125513878, 104.62433707329535, 89.65841600971838, 92.94001994594451, 81.09494839945148, 85.537934764739, 80.72403338647659, 79.9775122058007, 78.31681205380347, 77.80056538120394, 78.59224088730352, 84.3948305806806, 81.97607747970089, 91.17221555402203, 88.93582128709363, 82.18120959497269, 74.97598032797538, 79.24409958624071, 75.79443777761152, 81.37070671204599, 80.22399394742905, 82.24875280933996, 97.8176441500264, 100.6243981084516, 101.06215030916276, 101.21626807797341, 89.90055176519579, 81.58498579455961, 82.70125312189903, 85.37398753627654, 91.80076752939533, 98.52060348756852, 100.66299423094719, 94.72626732241724, 97.76754763818558, 98.04833442934098, 93.14345759730186, 96.36323713487195, 100.57599606052523, 59.24604431275399, 91.61360771425309, 98.96475699640091, 92.54804964988463, 91.76614084551412, 86.35197562556114, 88.42454033513224, 89.93191503709363, 98.09417124717467, 95.84141285188737, 98.97787340225713, 93.70306999452653, 99.77600512966033, 97.73634126109462, 101.4067775972428, 86.5507221221924, 81.84285809916835, 75.49593756275793, 79.04401948375087, 73.71814681637672, 80.04008969952984, 90.01382981577228, 92.23059654235841, 90.40440374805083, 90.06625621549546, 88.47568804217924, 90.1324736687445, 87.76392690597042, 89.007828158717, 86.7528183229508, 86.90043280201574, 86.40641812355288, 95.65508457922166, 95.54451296406408, 95.40948929325228, 92.10862651948007, 91.15122302885979, 93.75301745630081, 92.8766893571423, 38.15543636198967, 1.2953411763714207, 3.4851268991347286, 10.791610190945288, 1.4102551004578991, 0.5415906384587288, 0.2479658837640478, 0.3505624163775675, 0.28106494235896295, 0.1976521400314185, 0.3684350331464122, 18.21718938889042, 54.88505117354855, 64.63680474988877, 92.8569676799159, 65.19813122287874, 80.03457484706756, 39.35177887639692, 40.19068364174136, 83.38902504213395, 103.59771943861439, 96.18119993517476, 105.82000101766279, 8.832617709713599, 0.548936870069273, 0.2031415736963672, 0.12639804172419733, 0.1271163947099159, 0.12807670890563919, 0.24743611864264936, 0.15937058855929684, 0.13793410012318244, 0.1175407323265268, 0.0995346860239102, 0.20033931599990015, 0.17548347072255227, 0.11859947349876167, 0.09683124600879608, 0.21157545097652944, 0.18249274622048103, 0.1622823048983851, 0.20987487368045316, 0.17640225529190035, 0.07967835352305444, 0.13981967233121395, 0.2619739087118257, 0.134625458308766, 0.25432563927625457, 0.1622336583151933], [0.011819013931427994, 0.04542417223415068, 0.07302442024792395, 0.01896141348556886, 0.05783461657683215, 0.048025508050716696, 0.043945971110294905, 0.06456012927716778, 0.05502754784820061, 0.030707483397676583, 0.014551300987330897, 0.03690722804035872, 0.003763531656718002, 0.040814226658474055, 0.09333187128387152, 0.05999306547305277, 0.0625798149755405, 0.10690091252927819, 0.14924099098049826, 0.05787863981940093, 1.397569174728086, 94.33040603514641, 103.99931523107715, 89.26183300633585, 87.77701977760562, 48.0907254834329, 18.589798865779755, 22.03102561735338, 77.25732495707851, 104.04567764651392, 69.24393838451755, 51.797145643541896, 2.039510038110518, 0.09405200159357441, 0.06527115846233023, 0.04119468507386985, 0.13495288428760346, 0.06585297159730427, 0.08046311867092887, 0.0647263243914612, 0.3306800751916824, 0.5284045492449115, 2.5168243675462665, 107.94614530378773, 110.7944606965588, 106.54867541405463, 100.07971425210276, 100.78704311001687, 97.1491938252603, 97.77508643365677, 92.64901145812004, 90.643370228429, 80.96397261465751, 76.18440766488352, 69.8458339321998, 70.80774814851823, 68.11548033068257, 69.22613082393524, 66.0980406115132, 68.35886339987478, 69.7337875058574, 72.18672014051869, 71.39342077316778, 73.0351915667134, 66.65751964815202, 69.16174903992685, 70.2670729544855, 70.42143391024682, 72.82284229032456, 72.8861415001654, 70.71310135626024, 79.28941080647131, 88.41788799531999, 88.48741592899447, 81.30073162817186, 75.9090494340466, 68.1044820047194, 75.29042105520926, 77.91675383044829, 81.48951530456543, 86.94037037511026, 89.06988789958339, 81.89937945335143, 88.84803864263719, 84.77075838273572, 85.5331337836481, 82.1975423443702, 97.31911090112503, 46.62322951901344, 74.69981408888295, 89.49426481800695, 77.47469486728792, 78.70997475039574, 73.89008783525037, 78.45990796242991, 78.77270913893177, 81.88849879849343, 84.40248704725697, 89.31710704680413, 85.27093902710946, 87.95707225799562, 85.53391825768256, 81.56250276873189, 68.21353958499047, 69.13916403247465, 68.44116257083031, 69.81682408240535, 65.6359697157337, 68.74819001843854, 76.34670749787362, 82.6518783261699, 77.25847813390916, 82.05315989832725, 81.26563425986998, 84.75007964718728, 83.26026931885751, 81.52497353092318, 75.68124601917883, 77.44165282095634, 77.38943822922246, 83.65273383355911, 86.37602759945779, 91.4958110932381, 89.99980342003607, 83.46759796142578, 86.84319757646131, 84.70938113427933, 86.386594464702, 28.8639219345585, 0.36118404158661443, 1.118731678974244, 0.5144824027534455, 0.05117924305640402, 0.03913562076406614, 0.05730941733946243, 0.10511467894238812, 0.07576555178891267, 0.033025575441218195, 0.6276784512785174, 3.446029938997761, 31.512357265718524, 25.056981232858476, 49.766683655400435, 38.5303561149105, 23.268345132950817, 26.882024772705574, 36.69554587333433, 61.10147837669619, 77.08257552116149, 83.96144790034141, 47.6201508891198, 1.6483204162889913, 0.1300937877667527, 0.07828394326591685, 0.08025612937466753, 0.09322767566529014, 0.07652026330751759, 0.044322131772435484, 0.04134209954269952, 0.0496805222674964, 0.06940175133246569, 0.02760588450567617, 0.04756390943282074, 0.01614171005184612, 0.00602912920106563, 0.01749558851212984, 0.046789459658846747, 0.055827971833247336, 0.028543438229169098, 0.019511742322074793, 0.1357782827389817, 0.023554359570205696, 0.09669205549383357, 0.14580697121639408, 0.017185232887465148, 0.02603541958265968, 0.06802745088334046, 0.021140075611671614, 0.02282599381531679, 0.040956780299424164, 0.08100024589727964, 0.05639756969626873, 0.0920892077227754, 0.009454844572070626, 0.04448150104332355, 0.018176016315156897, 0.051299066868640726, 0.11779885799173387, 0.07176976741081284, 0.05648509524161777, 0.1234026762446569, 0.12007724944381945, 0.023476482902262962, 0.06928412619257165, 0.17121867456984136, 0.22185569208475853, 4.170456653641117, 120.02113050030125, 116.20564491518083, 99.58808437470468, 107.11685426773565, 63.0799924942755, 38.60255518267232, 26.498813129240467, 46.8723431710274, 100.66315897049444, 37.90194142249323, 59.003516320259344, 3.043264544779255, 0.15530724288715472, 0.035383188045553626, 0.21761279072492354, 0.05889670172285649, 0.16752648317525465, 0.08232325675987429, 0.13991419225931168, 0.37563837403731964, 1.0516650325828985, 4.769949259296541, 118.57954179086994, 111.50900671558996, 115.93383250697967, 103.43667476407944, 104.32801769625758, 100.89091531692013, 102.5400366321687, 96.96411286630939, 95.95049396637948, 86.16669070336127, 80.48523164564564, 73.79646870397752, 75.55111746634208, 71.88527030329551, 74.12541435610864, 71.47133473427066, 74.06283686237951, 73.48948048007104, 75.78594192381829, 74.22108880935177, 76.52425750609368, 69.06931446444604, 72.38746704593783, 72.63092071779313, 74.02644511192076, 74.06071093774612, 77.75981195511358, 73.4486093828755, 81.02555382636287, 92.73080072095318, 91.2149223204582, 84.3539987071868, 76.37410133115708, 70.63845865188107, 79.71831414007372, 81.90798513350948, 86.70565574399888, 91.04424430478005, 93.40882162893973, 83.24124582352178, 91.62648877789898, 87.07036556736116, 88.5792778384301, 85.53368291547223, 99.2894115755635, 49.908292985731556, 76.71697924214025, 91.82565889050885, 80.39550350558373, 81.739393818763, 78.00247330819407, 82.34226995898833, 82.14551602640461, 83.33658295293009, 86.6896838526572, 91.99351279966294, 90.39066760770737, 91.51279495608424, 87.2165915273851, 83.26536840008151, 73.06725302050191, 73.78963593513735, 72.22613211601012, 73.41906609073763, 69.59412759350192, 70.14483621043544, 80.37401676177979, 85.93307433589813, 83.85107240369244, 86.12264248632616, 84.02773595625355, 85.20228970435359, 85.74365523553665, 87.82196229504001, 79.81193327134656, 81.62895556419127, 82.13450201096074, 87.79271710303523, 89.95890878861951, 96.19385350135066, 89.21279553444155, 83.99791025346326, 91.6556869014617, 88.0498912257533, 92.48094574097665, 38.93537221416351, 0.5984058639695568, 0.7921225950121881, 0.7913320535613645, 0.09453856701692266, 0.3113235461135065, 0.06660735369810174, 0.05233030931483354, 0.12397939489493448, 0.058623970591373024, 0.7654987720231857, 2.74668776219891, 36.7404217104758, 28.335172707034697, 51.51526058873823, 38.141864961193455, 25.006429726077666, 36.947734663563395, 51.86679124832154, 72.34599190373575, 87.89086264948692, 93.14611696427869, 72.47200196789157, 2.8272042159111272, 0.11382862264590879, 0.058187223865740725, 0.07500379226140438, 0.0735185546199641, 0.07883697447757568, 0.06127209139747485, 0.08698978942007789, 0.016600788240471197, 0.08254808824389212, 0.06140657047170305, 0.05085052238897451, 0.020390008501107657, 0.011768574702493366, 0.03491449928391845, 0.021269925599617344, 0.022817610898205352, 0.05148717592800817, 0.028322672756809383, 0.07868153523773917, 0.02256886023397167, 0.051354022185888984, 0.012495953161569854, 0.058829481337940505, 0.04756321612324926, 0.09951993883136781, 0.10666933181064744, 0.12801618795962105, 0.10399072070515926, 0.16775732078859884, 0.13200379817956878, 0.2110017277300358, 0.24282233879691173, 0.22951424242027346, 0.05393054824502719, 0.16008686544674058, 0.21684251996057652, 0.1816114080288718, 0.12768722214405576, 0.208275297416314, 0.19164316085798128, 0.20607539933295022, 0.23334468204167583, 0.305139132805409, 0.40147628274656116, 5.21087710895846, 140.620485121204, 130.28636547826952, 117.01624193499165, 118.35214630250009, 72.67248999687934, 30.650122242589152, 35.094289241298554, 107.26201334307271, 121.14552497863771, 95.1010968608241, 83.8920376377721, 4.101962019358912, 0.44170558212264893, 0.13301469716093234, 0.7037232191331926, 0.36616085517791014, 0.5554279636952185, 0.3083467735878883, 0.49112061278954633, 1.9254472683514319, 3.44889743674186, 4.149106212200658, 123.60256041249923, 117.23822455252372, 121.03744014616936, 106.62918598421159, 111.06681439184375, 105.71694466375537, 106.6930264811362, 99.18124045095136, 101.06634724524714, 89.77257267121347, 84.88225567725398, 78.99200885526596, 79.61711698962797, 77.33037517916772, 80.15439541109147, 75.90336199729674, 78.82455502786945, 77.14039125750142, 80.84408929271083, 78.83275278152959, 85.78262006082844, 73.59456862172773, 76.53370257346862, 78.70593470911827, 76.75467321949621, 79.4511301286759, 80.65317184694352, 78.44497942155408, 86.69768548780873, 96.39594970210906, 97.01038114486202, 89.70311534020209, 85.61458572264641, 73.28423069369408, 83.83193908199188, 86.20578888923892, 88.14363587287166, 96.30474675086238, 97.1908337070096, 88.71712561576598, 96.37468261103477, 94.18150501866495, 92.17868789549797, 92.36252154073408, 104.27209254234069, 56.27351137899584, 82.20400641041418, 96.99854343168198, 83.53922044077228, 86.70885639805948, 84.56255112924885, 89.76691661342498, 87.29681968688966, 89.97643393854942, 91.11876933805405, 95.92681854001938, 93.14097865935295, 95.64001483301963, 93.26028931525447, 88.75212100244339, 75.8784314124815, 76.05871139034149, 76.88322497952369, 75.6652113699144, 73.23546778771185, 74.08081700724941, 84.51706732473066, 90.34492492675783, 88.15889389284196, 89.92221893802767, 89.53869742731895, 92.16976842572613, 91.89902290221184, 91.51039446553877, 84.49208182673301, 86.036664132149, 85.32891165825629, 93.25589626066147, 97.01402894912228, 101.05310532354541, 91.90071736612629, 86.06518760804208, 94.80943725955103, 91.48260839523809, 97.90413241232596, 38.880035415772475, 0.8065624943663998, 5.205483359675254, 3.099114683366591, 0.39767431095242506, 0.6544813549806995, 0.18454816012132555, 0.4627366874727511, 0.30909769297126805, 0.13713398257330542, 0.9320453061692177, 5.24242228077304, 49.11108693768902, 39.6803322915108, 68.8834882551624, 56.475215342737016, 30.351712242249523, 40.82332664920438, 55.27349525882352, 85.60701554821384, 101.85726965627363, 111.35712469777754, 79.91707632618566, 2.8281693641216528, 0.19762920335896556, 0.18293801184383132, 0.1763872706121014, 0.24049795142585234, 0.16886005839032514, 0.20512094570984765, 0.22083843457362345, 0.11835558940806698, 0.16601162091378244, 0.1441995348901518, 0.12229661382133923, 0.14701041873664628, 0.13381213340307438, 0.08296366796017655, 0.11401485095942214, 0.14024727196703035, 0.10813202348447616, 0.11487898281625203, 0.2047650825472609, 0.07950456647743141, 0.21190823957083688, 0.1953095657330367, 0.18578683236433616, 0.14145010661694313], [0.03948610598942445, 0.03317770135078219, 0.05569056630314839, 0.027528067209547567, 0.04890463224822476, 0.08270631604377301, 0.0058721367179626425, 0.03313761196970459, 0.047342249552809426, 0.018958176764088775, 0.08153554983437061, 0.10416885913019219, 0.05680069282290436, 0.08535310385688659, 0.08373462820365545, 0.02624690964547617, 0.07348552856954836, 0.0835255781308778, 0.09622717801962169, 0.3601271773297941, 23.121619070729903, 116.05268032320085, 103.43345842053814, 82.87678703185051, 50.39681634595318, 45.19942483594341, 34.556681340740575, 62.572186762286776, 85.909375375317, 102.22710993982132, 64.07836906371578, 7.175962992252843, 0.22224354707906324, 0.1142111073638643, 0.14137708311600072, 0.07002766814924057, 0.10392012570293681, 0.0867821489490809, 0.041060297930192564, 0.03541684611850689, 0.5285478996173029, 0.26104234579590063, 69.07100108362013, 121.38186347100043, 103.62792168894123, 109.59421542383011, 95.57864542930358, 104.3118339969266, 100.35289164512389, 103.39510548499324, 96.15022890029415, 97.71505063579929, 88.55629274922033, 81.19015216827393, 73.88269808984572, 69.44922739459624, 67.42439793002221, 67.43225835984754, 67.35899632976901, 67.75745422609391, 68.10311701989943, 70.69432104787519, 68.943618189904, 70.12102742348948, 65.46049464133479, 68.83707877128356, 69.57624158551617, 70.69112823855492, 69.59590050481981, 73.47824681189753, 75.25473533138153, 70.58139601061421, 72.8512716293335, 76.65646491512176, 67.93018756374236, 71.97051909662062, 69.63357094795474, 80.86637620002993, 77.3155721541374, 83.65034903249433, 87.92264953736337, 92.65261219393824, 84.89142617871686, 86.89747533490582, 80.64542124348303, 85.24987589928412, 76.01051330566406, 92.73251871908866, 48.910289041457645, 69.85822077720397, 94.36282834699078, 78.57682597252631, 81.50203551015547, 75.3799295425415, 78.88516349177208, 74.1607706008419, 75.4334306716919, 76.90130710601807, 84.40063568853563, 84.99505519866943, 88.74896741682484, 76.46104458839663, 69.29582349715695, 71.17522716522217, 75.49342724584764, 69.20743680769398, 70.9917151543402, 67.293257405681, 67.47047009006624, 71.0878053788216, 76.30644044568463, 76.87274440642327, 79.08835795617874, 86.1614582615514, 83.50685304211032, 81.9671501651887, 82.09052439658873, 78.21955296301073, 76.8058366160239, 77.4593113314721, 85.73266475431382, 84.80366706848145, 93.94366033615606, 76.8929446128107, 84.9256214018791, 88.02069310219058, 83.39461834199967, 73.41822670352074, 86.44641845457016, 21.62742745491766, 0.16623944014070496, 0.7365138660515509, 0.0935943483284885, 0.11198241203542679, 0.047204434165670994, 0.057809109679393234, 0.06439885244734826, 0.17584380783861683, 0.1442251069050643, 0.4762617552713041, 3.3195026122754623, 26.355299488190685, 45.929589733000725, 65.90534240968766, 64.88101543918734, 38.61791518426711, 27.322175502777103, 57.115973734086566, 63.65021098044611, 75.64352850760184, 90.03400648793867, 23.566643345740534, 1.059516637075332, 0.18761762928578163, 0.059800842521531936, 0.01813797813449656, 0.09393875081572803, 0.061139634795366764, 0.0689279412730567, 0.056485807703387354, 0.054230111606058576, 0.035406699283949794, 0.034693777861614386, 0.06334355867077267, 0.07176247425377369, 0.03659345757877154, 0.013142650113290837, 0.032293095794175906, 0.028058431794746753, 0.05916299771577601, 0.048994525005259824, 0.03202590156316517, 0.07299026038738028, 0.030755024899037618, 0.02934414949718743, 0.05268133463217847, 0.04841731222827108, 0.04346494833307882, 0.1102962218705685, 0.01692553674201331, 0.08639247832639564, 0.08021322845090782, 0.07128762231478769, 0.04369823359734109, 0.027432327286430427, 0.027736190315936844, 0.012673534257637878, 0.037770019243321115, 0.03584633033061701, 0.04587420292439, 0.02642311561372011, 0.05904930260693354, 0.045796766757003726, 0.20316541435257082, 0.33910351835431596, 0.5002692347813038, 34.6394355066361, 136.21032899425876, 115.47538588123938, 96.25814899321526, 65.23434254430956, 65.57322356008714, 43.52757730791646, 82.87681056607155, 94.85776086007395, 91.49474420855123, 63.54632700643232, 10.439551972573804, 0.694903708513706, 0.18589891102765838, 0.0750011645798241, 0.0831880014870436, 0.04389143331096538, 0.04900646448555974, 0.11658447073592294, 0.14388039798265503, 0.2281203914073206, 0.80182641624443, 76.91569435981013, 124.1549321143858, 107.67416031129899, 112.7202581590222, 101.3817685650241, 107.45664135102304, 103.03574577454599, 109.91664994147517, 101.01257155018469, 101.11407464550388, 91.52296173957087, 85.96861885439965, 76.18119132134223, 76.40246791224327, 71.13337547548356, 72.44008956416961, 71.98519660580543, 72.51029214551373, 70.44328935684698, 74.03609414254466, 72.8524326509045, 72.36317972983085, 71.19613339824062, 71.3222768229823, 72.84971837074526, 75.13842921103202, 73.17147039598035, 76.89896152865502, 79.10971918413716, 72.69310597450503, 73.79192659931799, 77.64502771439092, 71.84254784737864, 72.82690586582308, 75.56663436274376, 84.88606037632113, 82.57426246520012, 88.14630308458882, 90.59782366598807, 93.16523459649856, 88.70805709592759, 92.00345208567958, 85.90721022698187, 91.3300831087174, 80.02247041271579, 96.91618150280368, 52.69480751406763, 73.6071829642019, 97.70513488400368, 84.99938549533968, 85.24609473443802, 79.49349957127725, 83.74035958320864, 75.81628537947132, 78.40495555631577, 79.01369171757852, 88.08819709285613, 88.26075000147667, 91.76494060024139, 79.76347631023776, 71.94803607079291, 73.20110782500237, 76.26670683583906, 71.14460914365708, 71.8748446433775, 70.46970259758734, 71.9568221799789, 72.91575539496638, 80.08246698687154, 80.0576070047194, 84.88034940535023, 89.03752834566178, 87.7436404074392, 86.08453273773195, 84.79462992760443, 83.28113632817423, 80.32253957563832, 80.97185657870385, 90.60873569980745, 90.01073114333614, 92.90445189322196, 76.77014304745582, 88.4829758059594, 85.24000721593058, 88.90732134542158, 78.2900457997476, 96.4586684011644, 30.14253027977482, 0.27233880253568776, 1.029204315235538, 0.22217049293460386, 0.11912324781259222, 0.09004168452755099, 0.13229975326647683, 0.09612215502608208, 0.22743166304163395, 0.5305318221930535, 0.5883077832479632, 4.223202726533336, 27.151154279708866, 42.133512035492934, 58.00022109862297, 37.256629159373624, 40.575958451917096, 40.09480130287909, 67.74044682902675, 71.48576905650478, 88.50945180462253, 100.74716045010476, 42.09715558636574, 0.4144784802150342, 0.17697391010099844, 0.09606024746092097, 0.04258809558626625, 0.07580339653237213, 0.04137972212066093, 0.12389745413055345, 0.04422790678818861, 0.07828820271477585, 0.03853894935380067, 0.05219705598128419, 0.0326745041585978, 0.11425174832824739, 0.048529042321587765, 0.01800698092988422, 0.05224754117549427, 0.06994590358508211, 0.04116609850297532, 0.015571563478348958, 0.0726570887491107, 0.022455818215084654, 0.05330850400270955, 0.08381595609769707, 0.10990537913335909, 0.15014302886782155, 0.22942441095027233, 0.20929376534636945, 0.06597382962823876, 0.11325838509947063, 0.18866196034416077, 0.12158727002961021, 0.14211243559275905, 0.1601377490066713, 0.11902577844598602, 0.14902766613710314, 0.12856118290895416, 0.16572036960672948, 0.15061480113335196, 0.163105420407749, 0.0974120325859516, 0.1818030372622513, 0.30332733486448565, 0.538989371590076, 0.7897637183627775, 41.086823632640225, 158.3947055570541, 126.70275472825574, 116.00430965423585, 71.00415691252678, 70.96213263850059, 49.56904718952794, 101.20130031339585, 107.48725152784779, 114.12299186952653, 94.91694942597421, 12.793427109718325, 0.9838166087865831, 0.2269571635030931, 0.5723416528874828, 0.3280753456056118, 0.49778321817997967, 0.21604393458654805, 0.23697108180532533, 0.4081120444161277, 2.037408505716632, 1.0429201082837198, 80.96955022504254, 129.52091493914205, 113.2289581914102, 116.94353688147761, 105.62983666696857, 112.94196621064218, 107.90874158182453, 110.58721834613432, 105.74023569783857, 105.21721116958126, 95.91061130646737, 90.86823971040788, 80.17484664916992, 80.37826861104658, 75.89055153631395, 77.75302625471546, 77.43567512881371, 78.7755960033786, 75.89285004523494, 78.56489412246212, 75.95064224735384, 76.3047852054719, 75.2938570514802, 75.4210202924667, 75.77962690784086, 79.95156180474066, 77.18418059810516, 79.68892774274273, 83.11835012128277, 76.45029729412448, 80.35982562649636, 84.03015998102005, 76.77266120910645, 76.15279336129466, 78.9027278654037, 88.90979243863015, 87.68167480345696, 91.3764847478559, 95.31103780192714, 98.05508875077771, 91.31837091138287, 94.59332250779676, 91.70156294299711, 93.94131475879301, 86.79896893039827, 103.05258843206592, 58.81468949779388, 79.23609795108919, 103.56735244874032, 89.68141678840884, 87.80110313046364, 83.2977750224452, 86.87688289150115, 81.29550703110235, 83.81231938638996, 84.6742602317564, 92.88797009375789, 92.94265577870031, 97.10693420902376, 87.14033280649494, 74.79840678553428, 77.64180352610927, 80.4288907204905, 73.77500549439462, 76.65765731565415, 75.30592226213025, 76.06469692722445, 77.07617421304026, 83.75266013606903, 84.00230330805626, 89.19559201886578, 93.69138917615338, 91.72050014618905, 89.86527396786599, 89.59351647284724, 87.8999625482867, 84.58017041606288, 86.27906660879813, 95.67511220132151, 91.0726579543083, 96.4655403937063, 78.52701187133789, 90.913448949014, 90.00804824213829, 94.80991578871205, 83.22003364562988, 97.70599780544158, 27.684280872344974, 0.7081400530953562, 2.3775981222429583, 0.42116802125688524, 0.32626379281282425, 0.3349902697147862, 0.3219492162667936, 0.3913755973260249, 0.44241709394320367, 0.7721359126510159, 0.737203651618573, 7.22142767521643, 46.52778648561048, 66.68838870140814, 85.69309588401549, 88.57300989089474, 52.13049219500635, 42.04446246547084, 75.88441694936445, 86.73232786117062, 98.01443730631183, 117.76124908078103, 43.34473994470412, 1.0563059319411556, 0.37016381779986046, 0.23130307304522685, 0.1296325721928189, 0.28386122456962065, 0.16870745367580847, 0.1754082868536634, 0.18346144907897521, 0.149595306645478, 0.1546264818358806, 0.12910099910391917, 0.13885571921785034, 0.1870020316733468, 0.12264110057825044, 0.11117677099161571, 0.10153036804929857, 0.14271623545115994, 0.17114418018008434, 0.11039480972554415, 0.1919325275887405, 0.10781854796673983, 0.21312216717389323, 0.18014917600779765, 0.27622657617734325], [0.07944134124104055, 0.05798487706230052, 0.018769215431905562, 0.10880818800820459, 0.05110714269141036, 0.0326501272408472, 0.08362906894856885, 0.12380186934024097, 0.09475365386254365, 0.007884741625598362, 0.07556099865225054, 0.06579560693353415, 0.035144624435493065, 0.04871294172781129, 0.08504271567348512, 0.037614327194469596, 0.05225727432257226, 0.11165179913082432, 0.18797309408264776, 0.17995926281136854, 43.81655400799167, 107.44241099203788, 100.39246051542221, 78.46650538905975, 59.26154551967498, 29.929337693798928, 57.60604643052625, 30.88149109194356, 41.070314376584946, 48.260740618551935, 16.0698260607258, 0.30562274879024875, 0.07919279167488699, 0.2897914192609249, 0.07283442278182314, 0.29420874351936005, 0.1276178911869084, 0.29228224689441346, 0.19279189437868136, 0.3239840070807165, 0.4684559934802594, 39.84926093009211, 122.26086662661646, 103.47389805701472, 111.09900920621811, 101.67973533753427, 106.16058826446535, 101.45562679536881, 103.74472202793245, 99.07013539345034, 105.05552322633805, 108.02569097088231, 96.14884038125315, 85.92401366080009, 74.46142027454992, 67.53288284424814, 66.96442942465505, 66.32520860241306, 66.52935228040143, 67.64073233450613, 66.7336763874177, 67.73607730865479, 65.51434878380068, 65.4176898156443, 64.84191333093952, 69.15765408546694, 69.26347178797569, 63.44572605625276, 66.94901450987786, 76.65799463948896, 74.26773363544096, 73.58140514742944, 68.76578577103155, 66.9069274779289, 66.19539383919009, 70.371792393346, 74.25031046713553, 80.14444828033447, 80.2483283319781, 90.45264105642997, 83.17768773724957, 85.67764959027691, 83.40235325597948, 90.62393096185501, 81.58938669389295, 82.18889744051042, 77.09672743274321, 89.37831171097295, 50.5134754796182, 66.00905772178405, 89.33786422975602, 75.2856279188587, 77.42160166463545, 78.55590405002718, 83.0160782414098, 77.16612985057216, 79.40594442429082, 76.43366644459387, 77.32118114348381, 78.37367857656172, 77.64640054395123, 66.5485954284668, 68.97928822425105, 69.28563317944928, 69.23813327666252, 67.08847045898438, 65.55997379364507, 65.16280243473669, 64.30317971014208, 69.26786484256868, 73.13372935018232, 81.14841030490014, 79.74503332568754, 80.92666302957844, 84.92918291399556, 82.86441587632703, 80.97334707936933, 78.17802290762626, 75.04613584087741, 83.97497223269555, 81.8230579745385, 92.53899681952693, 76.55010592552924, 82.80063813732517, 85.32294181085403, 78.66498516451928, 77.5556839666059, 90.15697279284078, 86.21238631586876, 93.07716169664937, 15.210572038927387, 0.8873821963225642, 0.524250514084293, 0.25695304506488387, 0.10184328432285017, 0.14662861583694337, 0.05310385127461726, 0.07180405750630364, 0.287266822471734, 0.06346478059347119, 0.04578696083157294, 8.800538605259312, 27.652543014095677, 44.68998347559283, 60.78186012083485, 39.83230844620736, 22.808696300752704, 31.162991754470337, 66.88082018206197, 75.4095277478618, 71.82170437228295, 74.42236915711435, 6.6701159938689205, 0.47664997798781245, 0.1379477671317516, 0.05280442963985186, 0.02408765444171525, 0.04445117162240129, 0.06627017541998817, 0.04651256866993443, 0.03151277778670192, 0.0318628435789217, 0.040558066008792776, 0.031469982200031804, 0.12694485230191102, 0.053813539805912206, 0.016749817239601287, 0.0181803121531923, 0.03161050953842219, 0.04234331900313978, 0.04131091593374168, 0.01880368555805856, 0.029695169068872932, 0.08433064460874566, 0.09112132457836021, 0.06205321379726934, 0.03184298657992434, 0.03314848658778975, 0.12959399200495214, 0.04664260060376218, 0.05678529828606595, 0.04378243815153838, 0.07340010210511184, 0.12078415707594926, 0.032705266419197285, 0.06579880918105764, 0.03462835395288083, 0.002696843998086068, 0.07854334829795746, 0.06634268564202132, 0.07777063371313196, 0.04398871498603014, 0.029896763190927527, 0.05650227093288014, 0.25372216117478186, 0.10463095570523893, 62.50216460997059, 125.60496176442794, 107.77163905482139, 93.53686348084481, 63.11779237562611, 44.99468495768886, 56.7765082851533, 25.299199358109508, 49.50304546663838, 57.259763902233495, 21.20747889241865, 0.20343700784348673, 0.026557045019862634, 0.02303439654379843, 0.07398181564865575, 0.3260270103571877, 0.10991464879724289, 0.04997363133776573, 0.36722256111041196, 0.28529935546459695, 0.3415878495622066, 47.35470448770831, 126.12902179841073, 108.812589030112, 113.02521459517942, 107.16538183150753, 110.99436037002071, 104.64646708580756, 107.97693590964042, 103.4164353339903, 106.00444655264579, 110.40056059437414, 100.53931405467372, 93.08304525190785, 78.41089402475666, 72.59640386027675, 69.58425106540804, 71.96891876959032, 69.00181047378048, 72.97594808763074, 71.03395123635569, 71.74060544660016, 68.81610978034236, 68.49657781662481, 67.53837416248938, 73.00087867244598, 71.42317587329497, 68.2529515604819, 70.02401936438777, 80.41864548960041, 77.73630911304106, 78.4043279770882, 71.4555746509183, 72.24020558018839, 70.0343430426813, 74.95338747578283, 77.0065756767027, 83.33964240166449, 84.62078263682704, 91.57471349162441, 86.99560519187682, 88.544721757212, 86.01069804160826, 92.56166811912291, 83.88202774909236, 86.00304941977225, 82.64285687477359, 94.99547527682398, 54.83526060658117, 66.93945177139776, 94.03246279685729, 79.69237942849436, 80.9329309771138, 83.59250976193337, 86.90374328244118, 81.57463858204504, 84.13888023745629, 79.77356464632096, 78.65884273282944, 80.53921130395706, 80.05785803641044, 70.22433480908795, 72.55865496973838, 71.34263392417662, 73.51426985956007, 70.2133757068265, 68.0377624880883, 68.34515079375237, 66.59903710888278, 72.98005873157133, 75.0010834970782, 83.53889880641815, 82.61973058023761, 85.29146871259137, 86.46752080609723, 85.71327255618188, 84.8884294879052, 80.53945449090774, 76.92309979469546, 86.77664279937746, 83.39982724958851, 94.51868764815792, 76.94804606899139, 85.99212169647218, 84.72861643760436, 84.90626058270855, 84.99441977470153, 96.5657255726476, 85.84006709437217, 102.15902543837025, 22.46882292532152, 0.41005447566989933, 0.4044100317743517, 0.3129880100248322, 0.1924235593046873, 0.24329213455559748, 0.16653087530885974, 0.23367675051333445, 0.49963212541995516, 0.04285123529693773, 0.1467435443473439, 9.233543757469423, 30.59394801816633, 43.10490269814768, 51.61050358126241, 43.07872087724748, 38.85225326784196, 49.57153004984702, 76.85872585542741, 82.54120472938784, 77.586301988171, 94.07412621282762, 14.055175146748944, 0.6497180654156594, 0.21982352129153668, 0.1326762701595022, 0.06343684902775192, 0.09588881230522549, 0.10438446691560169, 0.03628736714862528, 0.05363722467013905, 0.032665491134168646, 0.036444752251789454, 0.08670649776655821, 0.029520102656416358, 0.06484283870386501, 0.00938030134420842, 0.047718720480559335, 0.06633766776611728, 0.07968676516846304, 0.04282144596800209, 0.013041492990939128, 0.03673830182261525, 0.01915788822506945, 0.09599349055919917, 0.046650686661802956, 0.1888348510669124, 0.07548167790857054, 0.17927183679515318, 0.20482503658821508, 0.2195852373035685, 0.12822642546868132, 0.2242274696548139, 0.23570971803799753, 0.17014005341597144, 0.1506125335130961, 0.2567418346241597, 0.2615603438067821, 0.15894332600216712, 0.20610683958136267, 0.18263638770628363, 0.18131493200217524, 0.19639244633576564, 0.27055467569058944, 0.35545633925545606, 0.18941658759309402, 76.87519981015113, 145.1570200151013, 126.01623796647596, 110.16507717870898, 80.6269625694521, 45.87925003420922, 76.23637122492637, 46.41766202065253, 54.757703581163966, 73.69792307576826, 28.74351497619383, 0.7546358904050243, 0.1058022351935506, 0.7395979521736022, 0.13618936551915062, 0.8314706481272175, 0.8866984168848685, 0.6486775954404186, 0.6136226377660229, 0.9715038598064454, 1.376472829330352, 46.20488128354473, 130.30204711421845, 114.03969641654723, 115.81204291312926, 112.02341771894886, 113.17917546918316, 109.33879067820888, 111.61545199732628, 106.2747763049218, 109.99434424984841, 112.05162740522816, 108.57924722856092, 97.11985449637137, 82.70723865878198, 76.57499728664276, 74.91844700228783, 78.59230364522627, 74.99713759268485, 77.73372034872733, 76.2181322036251, 76.07087858261602, 72.7217157425419, 72.0093584060669, 71.01563376765098, 76.2462712872413, 76.80990803626277, 72.16701415277296, 73.66661471705284, 84.7501894735521, 80.17142634237968, 81.25481636293473, 76.26558503796979, 77.19766570675758, 74.29002054276006, 78.16001922853532, 80.56280043817337, 89.07994485670521, 89.79151771914574, 96.9914282521894, 90.92491011465751, 93.33282962922128, 89.12149844631072, 96.85092895261704, 88.99897144686791, 89.47196222120716, 88.2126852773851, 95.67744993394422, 62.528487636197006, 73.67969189920734, 97.93475043389105, 83.94083976745605, 84.87510127405967, 88.2733564992105, 92.45884710742583, 84.17735084410637, 86.86160918205016, 84.7211011763542, 84.19745691360967, 85.9755849838257, 84.64655260885917, 73.5163644052321, 76.10023360098563, 74.89887437512799, 77.49914692294213, 77.1319346274099, 71.25244294443439, 70.16307523173671, 69.88675209783739, 78.30267583170246, 80.38310097109887, 90.4437372761388, 89.28988579780825, 89.60638969175278, 89.54181963397612, 91.24015885014688, 88.32541419613747, 85.4375691567698, 81.00429458002891, 91.51727430282101, 87.93008635121008, 98.70650029951527, 78.52590576294931, 87.64168231718003, 89.11803891581874, 92.28089701744818, 88.7614405539728, 101.43065698685186, 91.0423380328763, 106.70584478685933, 19.3602406209515, 1.1697973839698301, 2.4431046458982655, 0.6287712603807449, 0.31452101324835136, 0.9047038120127494, 0.37799403311744817, 0.3663315702109568, 0.3537267272270495, 0.367906064756455, 0.34641261002229107, 16.635020971298218, 45.63595325716081, 64.6113956359125, 84.08999966036889, 56.03171294735324, 34.95382916542792, 47.40866061179869, 90.02357298328032, 98.8118237833823, 92.15208638098933, 103.62455629533338, 12.048557246884993, 0.9569022239696596, 0.44071987211223573, 0.30211857069403897, 0.16740715732016873, 0.2319492988528744, 0.1971813330366727, 0.1831958157521102, 0.18394402318423797, 0.10647980165818047, 0.14488716008922747, 0.19380722134824724, 0.19001435067865158, 0.20000753864165277, 0.1476913942925392, 0.2116840975659509, 0.27650377743186494, 0.15121378995958837, 0.10368080749627083, 0.08688000135964925, 0.12126046458199141, 0.1738331487943088, 0.1397725885673877, 0.12971249048507985], [0.020032768295476996, 0.013810851153046375, 0.08667481237000997, 0.06703118418133067, 0.055827910546213395, 0.10885559352895907, 0.012974584786852282, 0.10549195426245851, 0.03361097003723826, 0.07874195659232718, 0.07814599381339166, 0.02232987910599238, 0.034508652714712006, 0.09779755101208726, 0.03050363123146517, 0.14384184843830525, 0.05009994391472109, 0.1397755303450169, 0.09785866950668635, 1.0342172268898258, 74.7157310670422, 100.88687527564265, 94.36563676403415, 91.44277280376804, 65.02750812038299, 47.479463315779164, 57.73224084608017, 116.26513942595452, 73.03043765406456, 46.31747684171123, 3.2060836015209078, 0.09435223145109993, 0.48031837469147104, 0.24820231381923924, 0.3103819934110488, 0.1546289333172383, 0.09378317368006515, 0.3707098852722876, 0.20094585845306998, 0.5169330260926678, 19.95608787382803, 113.6577203196864, 98.89024765260758, 108.86638041465514, 102.87477170267414, 106.25228543435375, 100.50391858623874, 104.91657718535393, 95.68563984286402, 103.83031598983273, 102.01489402401833, 93.80141950422718, 99.32882355105494, 90.51553233977288, 77.51970014264508, 69.66786815274146, 63.29463243484498, 64.32543131612962, 68.20505942067793, 65.55675745010376, 62.90156779750701, 65.3216976504172, 66.57045871980729, 69.8535688461796, 65.52431552640854, 67.74428290705528, 63.61480374490062, 66.22170509830599, 74.63940174348893, 79.18108278705229, 77.49563247926774, 75.087736498925, 71.28951718730312, 67.86201677014752, 67.94710866866573, 75.22005373431791, 75.61032172172301, 78.9810105293028, 81.06301246150848, 85.46865001801523, 88.77299585650044, 86.65517483988117, 85.55518534875686, 85.41361131975728, 73.07980460505333, 81.78099447681059, 75.61437745248118, 94.44704947933074, 53.89533519744874, 62.83716247927759, 93.24485086625623, 73.30952213656518, 80.10371838846515, 78.49883356401998, 83.73297768254434, 81.0235220386136, 82.29519367218018, 75.66310113476169, 74.96750016366282, 68.30712733730194, 70.41053756590813, 66.7441334262971, 71.7001344311622, 68.48957246349704, 70.18141623466246, 66.84512661349389, 64.17528690830355, 62.778711318969734, 64.35093064461985, 65.63277298404326, 72.6703562275056, 73.97916486186367, 79.38072358408283, 76.70340784134405, 81.12307179358699, 82.07958882854831, 79.52893426341396, 77.83676101315406, 78.16503986235588, 80.61916489754954, 87.7537993461855, 82.57635701087214, 80.97632023595995, 86.9386366874941, 76.86628818511963, 81.47881507873535, 89.3778096475909, 83.6092661273095, 87.36376670099075, 87.19798380328764, 85.24952288596862, 9.539382726915422, 0.6449714459238515, 0.15898458749776886, 0.0434056148233433, 0.09376768338223619, 0.052316489088679516, 0.069707780475578, 0.061292005853066524, 0.14526311007718887, 0.11187005758045182, 0.23104724564379264, 13.648450855285892, 30.09569129636211, 52.352047274189616, 43.60959799058976, 31.386100092241843, 23.45121583630962, 56.29977949203984, 63.484647735472656, 81.74754450398108, 88.18904122998639, 40.89717703480875, 0.5401784626226271, 0.046943320757559234, 0.014004224194063535, 0.03853901447127423, 0.10733402799814941, 0.06531827286967347, 0.007887565617209241, 0.04423713048679694, 0.027759678571695284, 0.04299020364640221, 0.010115603067641778, 0.04223595944143111, 0.10435476568677735, 0.020040254889717026, 0.04620600326527511, 0.0767974952055562, 0.021080477801602215, 0.035762240689608364, 0.040937022891856974, 0.024889532078598297, 0.0640786430167575, 0.07212013772298252, 0.058933960409053875, 0.10037038835787004, 0.046223194278295965, 0.06135074564466073, 0.023847798058282466, 0.01240033102447107, 0.10086115960392261, 0.022935837417119936, 0.02974064404805822, 0.05998463084500644, 0.05610405076895991, 0.042146212241101655, 0.03427838583687141, 0.0244526244745019, 0.14513080669266565, 0.059507139733121286, 0.1292800644953405, 0.008485734729366678, 0.07357111591244898, 0.14374420287147646, 2.169923330506971, 102.02943032787692, 114.15614374222295, 106.66357732588246, 103.75358658452188, 71.51961911109187, 49.230197552711736, 42.61901124831169, 76.91848708737281, 71.136913453379, 51.57371174904608, 3.299642426352347, 0.37715893599294853, 0.35923796375432326, 0.3806196002950592, 0.4536315792750928, 0.2576869419745861, 0.09134159017834934, 0.5478865941686015, 0.415395395529847, 0.6065259056706583, 25.978551910769557, 124.19974911597468, 103.89232866225704, 114.2940072090395, 106.86361820467057, 109.75595828025573, 104.30453054366573, 108.29135310265326, 101.36010923693257, 106.58505931977304, 106.21976898562525, 97.70340119638752, 102.08312757553594, 94.09731526528635, 80.25856571812784, 72.72131566078433, 65.66435590867074, 66.99784801852319, 72.28095116153841, 68.81630589885097, 67.29634038863644, 70.5394894076932, 69.94226148051601, 73.17962108119842, 69.07341726364629, 72.16511572560957, 66.70177967317643, 70.15341051163213, 77.83786712154266, 83.4506925459831, 80.8637325225338, 75.03139557376986, 73.66896029441588, 71.30871326692643, 72.17412933226555, 78.15211173026793, 79.98520789607879, 82.85730069683444, 84.14755652027746, 87.94679564814415, 89.2269709802443, 90.15857311987108, 90.21361181812902, 88.59865434708135, 77.2885391789098, 85.99039585359635, 81.05741131690242, 95.4276341776694, 57.9434016443068, 67.70522394487935, 95.85171299595987, 77.53404817273541, 82.75290289232808, 81.19107000289425, 86.0655092423962, 85.21212700874575, 84.38787229599492, 79.22200095268988, 78.26316187458654, 71.4278748727614, 73.2062461299281, 69.73661945712182, 74.90977856420702, 69.99235799235683, 73.66537524807838, 69.88236688798474, 67.58701939736643, 64.83455104212608, 67.72645181225192, 68.06518770033314, 76.24271761986518, 76.35794901078748, 84.96893221332182, 80.27914247205182, 87.02039457136586, 86.27819584261987, 83.32949130765854, 80.61261453936177, 82.97110434501403, 85.17200116188296, 94.98080561237951, 83.55279968630883, 83.2743820067375, 87.19523814416702, 83.43941965410787, 86.73381051709576, 91.15743606321274, 87.92716026306154, 92.93190063968783, 89.04704401569983, 92.89460674408944, 14.493036193232383, 0.8353055617020977, 0.43776326302078467, 0.37564355279168776, 0.14352401388027977, 0.10749696723876462, 0.4484708126514189, 0.02449585864650867, 0.1720351710795395, 0.14423174122648855, 0.1500217111841325, 16.097816094275444, 29.732348419004875, 34.68850435749177, 25.94931064113494, 32.88117620252794, 35.67401947513704, 66.37157886259018, 75.93195607585292, 92.02624890112108, 97.35311000577866, 57.846040571889574, 0.6953992754701646, 0.04252618419066553, 0.01349418487910542, 0.019668072139123277, 0.05944203375087631, 0.012914423902158537, 0.047887742459293337, 0.06551033111229058, 0.04151957147123833, 0.0607624935406831, 0.008512407038060409, 0.05570997131027042, 0.11376859199616218, 0.08319625991486734, 0.018563924935616313, 0.10620414790126587, 0.02402067537449541, 0.04250382974503502, 0.008053310654847132, 0.01723921718826938, 0.0900530532723473, 0.010481536455993212, 0.09737182829168536, 0.14059211878526595, 0.16025929651673765, 0.1840935635470575, 0.14374921308650127, 0.09686116940311848, 0.2095069676156967, 0.09551792615844358, 0.20549966893609495, 0.11124397988521284, 0.2423034368022796, 0.1601132495148528, 0.11100539712295418, 0.10477828973483656, 0.2637382092014436, 0.14914130761979089, 0.36925382791988315, 0.16712975688278678, 0.20262113952588653, 0.3717043899720715, 2.68652277127389, 118.99026886109384, 135.47875988867978, 120.48422121232556, 121.19656285931988, 88.27900471225863, 63.90083866734659, 79.64788406125962, 160.33811446159118, 98.19728251426451, 71.93593163644114, 4.622597088736873, 0.5289946820947432, 0.8963972738673611, 0.5416889428611725, 0.5615957682171177, 0.42315467110564636, 0.309810032166781, 0.9298083294303188, 0.6682723472195288, 1.133818585545786, 29.3572364699456, 128.00615833651636, 105.66100382035779, 118.86307424114598, 110.7553154422391, 114.65447302787535, 108.39499781208654, 113.3818914044288, 103.44121686873898, 112.80173363224154, 105.5751274478051, 102.14443422132923, 107.66877097468223, 97.84848966906148, 85.3610437147079, 77.82127549571376, 71.79032541090443, 72.01548514827606, 76.34172608775478, 73.61279979828866, 70.85309859245055, 74.79493941030195, 74.5775616553522, 78.72853540605115, 73.65799334741408, 77.05328326071464, 71.91145604656589, 73.6218055602043, 80.55719144882696, 86.04654850498324, 83.59523188683295, 79.47388772041568, 77.43739312694919, 75.64035138776227, 75.09958205684539, 83.41283382907991, 84.47442331621724, 86.83001841268232, 87.54727871187272, 92.30261125872212, 95.20189392951228, 95.06602302674325, 94.77578332347255, 93.91676072151431, 82.1713173773981, 90.4230663853307, 87.3723174679664, 97.91822156598492, 61.29662805987943, 72.85578235503166, 101.91443427916496, 83.29083242724019, 88.04763978527438, 87.09378996203023, 88.51732792392855, 89.39841778047624, 88.75394882694368, 85.40378186010545, 82.72581500391807, 74.70399533548664, 77.08468575631419, 74.55551793498378, 77.34577440446424, 74.67580918342837, 75.84386748652305, 72.7143338418776, 70.20640957740046, 68.33372100707024, 70.68797465293639, 73.06548010918402, 81.18813607000536, 81.05250050944667, 88.41842143766343, 85.16546649317588, 90.31986882609706, 88.65639163601784, 87.24291847598168, 85.13577415097146, 85.04242174087032, 90.91208396419403, 98.78606165609052, 86.04743496064218, 85.56197104915496, 90.81787647739534, 86.62884789128458, 89.87581729888917, 95.7003487310102, 92.79718291374945, 98.41873168945314, 95.47621665462371, 92.90891555047806, 13.928328637153873, 2.332885063463642, 1.528356318031588, 0.7657021836888406, 0.39819056228283917, 0.36172171273539144, 0.7661254319452471, 0.13323123957360947, 0.4455644895713176, 0.21883399616326057, 0.4958777736511923, 26.000252423747895, 47.195385656049176, 70.5674715965025, 56.93296770895682, 43.019426407352576, 36.65962872966644, 76.51916626961001, 89.40640372614708, 104.66498067302089, 112.47197997185492, 64.88216077127765, 0.9017847105860711, 0.14182005047557816, 0.11531938378128315, 0.22468600392101273, 0.3107031987559411, 0.17439368000674635, 0.14975206355654425, 0.14553867190355255, 0.16109413317134305, 0.1542107259193736, 0.08271350194850276, 0.0646026931222408, 0.19061569905569478, 0.24282307424131902, 0.13324498319097106, 0.2296216479472576, 0.17378954306965874, 0.16009631897172621, 0.10035176476043078, 0.1008748495951295, 0.1739201457389901, 0.2253943901028364, 0.25524442384560264], [0.053077038197267445, 0.0643016052462401, 0.022135838610871185, 0.051622271703015414, 0.014707456519376608, 0.058163616866354025, 0.032852133135161096, 0.039570969379236626, 0.029348918394516074, 0.08321011078453834, 0.08552884442671653, 0.003767732691372775, 0.09470038776916843, 0.03333562271549337, 0.01567913754467642, 0.08076695680257776, 0.0848741380257472, 0.12006210388555644, 0.3742159632665496, 7.641232090611612, 102.22879655899541, 89.72992866270005, 83.96363658289756, 51.69252426393571, 45.19949936097668, 49.24007015843546, 101.90819771059098, 53.18222868827082, 42.587808793590916, 17.04946840963056, 0.6556839904477519, 0.6881553319192703, 0.21835281633802, 0.36658971119792233, 0.16469499156359704, 0.42024231125270173, 0.25106169103134063, 0.6732097532479995, 1.5154982983104646, 11.257363211724067, 91.56613134568738, 99.2478422964773, 115.80378240154637, 98.87426791652557, 106.13840333877071, 97.93524465253277, 104.67062104132869, 97.27043428728658, 101.17265132165726, 100.60793199846822, 95.29103371404833, 95.4822257257277, 97.13545768491684, 92.3613997428648, 80.9844316974763, 65.58113498072471, 64.72719577050978, 63.19637706202846, 65.66436375341108, 65.2694320678711, 69.04417991638184, 65.14226490451445, 64.71190244920793, 65.8436905953192, 65.861372640056, 62.50174099399198, 63.26068039863341, 68.02545409048757, 72.05652098501884, 72.46819726882443, 76.72678516757104, 73.17809920157157, 64.23063155143493, 68.2523867391771, 68.31176357884561, 76.90188761680358, 88.80919933319093, 78.83876185263358, 82.77108700044694, 83.92014534242692, 83.26530564215876, 82.3058311400875, 83.29902233616, 78.24598973797214, 75.01236423369377, 80.49549256601642, 75.39488161763838, 90.07355182401596, 58.83714898940056, 61.09463776311567, 87.99054576504616, 70.21725885329708, 77.10949867002427, 77.04951778534921, 81.93395122405022, 75.68415641784668, 80.65514087677002, 73.13999729771768, 73.84049338679161, 64.2671056716673, 65.28666304003808, 63.88409406908097, 69.8730081127536, 64.3314286201231, 70.19850207913306, 68.92618717685824, 67.76205908867621, 60.199635259566776, 62.69987167850618, 64.4732262242225, 70.36370446605068, 75.19856699051397, 80.10556974718648, 77.99497373642461, 78.96641931226178, 77.85090507999544, 83.1202720826672, 75.88095741887247, 81.1533760255383, 83.54209161573841, 82.76038677461686, 80.27613009175947, 89.9632312405494, 80.17359933545514, 84.20188134716403, 83.84275697892713, 85.01320008308657, 82.83380569950228, 83.4847544085595, 82.40237635950889, 91.81049500742267, 70.56827960475799, 1.4053275003548593, 0.38490126570386274, 0.013573675119738667, 0.12211220879708568, 0.0900251140457488, 0.37457905829914157, 0.7391836518241514, 0.07509635100441595, 0.08639319844904446, 0.28972317614862997, 2.7669595518419823, 20.572345179896203, 57.132592816506666, 96.32615504726287, 54.22135868380147, 30.75935240714781, 25.325995029941684, 61.02645128004013, 60.86263348979335, 74.6810337804979, 69.76846125818068, 5.91980335212523, 0.7129249156963441, 0.14276742544626037, 0.13568262900075606, 0.06757155962048039, 0.11077109679219224, 0.02175034125215344, 0.054615901993407365, 0.03448814454097902, 0.025050349255663254, 0.03023674152040434, 0.018016181645854827, 0.0909040313995173, 0.026146408485909624, 0.03610434108263543, 0.05185695124729987, 0.02861609975356729, 0.03621933088006993, 0.03243766041592725, 0.0370962908791919, 0.057670248582238154, 0.04347823995856508, 0.061911763322930184, 0.07019888113943801, 0.06132751402835693, 0.0364369917811165, 0.1748395125351606, 0.10426791429880167, 0.08657107640418314, 0.08463167119771244, 0.03067812307797853, 0.0516738485725176, 0.06516821156706541, 0.08324662253500954, 0.055432080576616916, 0.029850550852115118, 0.02931064655703883, 0.056939787576876344, 0.09628681030364768, 0.05443165401717829, 0.2171992871069139, 0.2826974450820877, 15.457531329124206, 124.37473389410205, 100.88323531612274, 99.86706687558083, 66.49932261436217, 70.05078561844365, 55.04973580760341, 68.70029787863456, 53.828827488806944, 54.1068176300295, 17.893793890553138, 0.607192708599952, 0.5820739725905081, 0.38330685287233324, 0.2413322058536353, 0.7653659017335984, 0.3773279962760787, 0.6808222770210236, 0.9431325596186423, 1.22899109798093, 15.379639921649812, 109.35401731921782, 105.17087228836553, 120.30576905896588, 105.49700167871292, 109.39760269657259, 105.84403730207875, 109.23617362976076, 99.77711123804893, 103.08204543206, 103.42581764344247, 99.10440906401604, 99.51459484715616, 101.42186303292551, 95.26020388449393, 85.07700135630947, 69.86013489384806, 68.52957279451432, 67.50087630364203, 70.99766146752143, 70.4630502577751, 71.99696371632238, 69.14168219412528, 68.31770989202684, 68.91492212972334, 68.5532246866534, 65.69790786312473, 67.32895097424908, 71.40467013082197, 75.01585514314714, 75.76828341330253, 79.45190675797002, 76.5578329947687, 69.26011423910819, 72.31759394368818, 71.258648134047, 81.59311294555664, 88.82664603571739, 83.13429063366306, 88.04803986703196, 87.2702338618617, 86.21387681653424, 86.06725861949306, 85.71435513034945, 81.1467158409857, 78.69904702709567, 83.59284708576818, 79.59218640481272, 93.05234093819895, 60.16154512282341, 65.1839400875953, 91.13946376308319, 72.94970743117794, 79.17541888452347, 82.83404104171261, 85.03315710252332, 79.49284845782866, 84.602002328442, 77.09302471530053, 78.22366360695132, 68.6857537300356, 69.4461130326794, 65.18581105816749, 70.92266574982675, 67.52663058619346, 74.18170036808138, 72.63589428317162, 71.11173968161307, 63.417367319906916, 67.29582263577369, 66.6447562556113, 72.81142819312312, 77.44472795917143, 83.58152712545088, 81.04110994646626, 83.46256163812454, 82.63190561725249, 85.54275928005096, 77.8119324099633, 86.12377212893578, 87.06236393220964, 86.84254646301271, 81.42574541030392, 90.62352303535708, 85.15746485802435, 88.56139183044435, 87.44353986555531, 89.96759291618102, 88.20687232478973, 86.20883264849263, 88.1762307690036, 94.6961356747535, 80.01899519274312, 2.8800360906508664, 0.577398813780277, 0.09426045411777112, 0.33599948330271634, 0.15973259574703633, 0.3976014406690675, 0.295088212456434, 0.16386603846425013, 0.10309082020314471, 0.3454466037932904, 2.101884916905434, 26.061747343309467, 52.20066731975925, 42.9221280928581, 36.516670103996034, 39.46325655906431, 43.932303151776715, 69.41027041404479, 67.11852365924467, 80.53408868851201, 89.50196835302538, 12.804473484716109, 0.9699500496349028, 0.20484484762193697, 0.14518412641219555, 0.10997975860992748, 0.12332741576697558, 0.042032164731814016, 0.10081135622796514, 0.03855298025413387, 0.04054520722298373, 0.051857625404673244, 0.032136266104756825, 0.05797771030976888, 0.03676392363324281, 0.03412337943671211, 0.047333236528380264, 0.04834121288431268, 0.025883843341181358, 0.04550801672702355, 0.05111075096553372, 0.06486886271065281, 0.04066918323177003, 0.06841064806306554, 0.09871696377353323, 0.11508967997806688, 0.1884917662509026, 0.3808675676343903, 0.1521355775935996, 0.17959512589919954, 0.15228488813004187, 0.15409271773551741, 0.26445811734564845, 0.26234221314230277, 0.1870615873485804, 0.13907639850531855, 0.13529382405742524, 0.15844230449968771, 0.10508459466960161, 0.16753299492261103, 0.22221377690232572, 0.3440979519678701, 0.4557835815414306, 17.92339994061378, 148.3627260884931, 112.26341970505254, 118.67821293492472, 80.9374495475523, 69.5137268497098, 68.91291387619512, 144.53821120723603, 71.32626979581772, 70.55412769317627, 24.03084997207888, 0.621157510867042, 1.2051505643513896, 0.3905398260441519, 0.7277688804653384, 0.658653469816331, 0.8803377420671525, 0.7014717173672492, 1.8957529649619136, 1.8276843981396769, 14.622584235283638, 112.50835603283299, 109.92821308874316, 124.69956890229257, 108.13452889842372, 114.58860074320148, 110.6199073791504, 113.26597752109652, 102.64134360897927, 109.18362955893241, 105.85647121552499, 103.34373028047624, 103.5852227672454, 103.05571063872307, 98.76205675063595, 89.47340565343058, 74.21569162799467, 71.96560044442454, 71.56297699097665, 75.67548797976586, 74.06344090738605, 75.14581111169632, 73.38686343162291, 72.29697796606249, 73.50955517061296, 71.40619985518917, 70.60011356107651, 71.46824390657487, 73.8881423396449, 80.41393080065328, 80.11342233227145, 85.71764207655384, 80.43598236576204, 72.21493767153832, 77.3817817626461, 74.68144955173616, 86.19188800934823, 91.21902511965845, 86.01823683707946, 92.65741317502915, 92.46053372659992, 90.7483014752788, 88.6267149832941, 89.99258625891902, 86.59813573283535, 84.73225639712426, 88.19458746141004, 84.29404135673278, 96.37140350957071, 63.59974184343892, 69.99504873829504, 94.8706340789795, 78.87520851627474, 82.601028719256, 88.03153453334686, 85.7863227782711, 83.73007512861683, 90.38663541117023, 82.06075360698085, 84.3551597287578, 72.95343368284165, 71.86883557227351, 69.38737946171915, 74.53365464364329, 69.7280216217041, 78.12334506742417, 76.35746263688611, 74.46727245084702, 65.0834999545928, 69.43762502362652, 69.81636908746535, 79.25785141606485, 82.48012558106454, 88.13347693412535, 84.09339643293812, 88.33205084646903, 85.60955724408551, 88.78360194544639, 82.16570838805168, 90.8988263530116, 90.84807872772218, 88.1132531935169, 83.27226392684445, 97.0171433110391, 91.09878093965592, 92.82051317153439, 92.80366266927412, 92.96521725193148, 92.21295372132333, 90.96644801478233, 92.36744019293016, 100.55594490420435, 82.54414650701708, 2.862412146022243, 1.102538418865973, 0.9050734954014902, 0.37894373699542017, 0.4868804080592048, 1.0699875268243975, 2.068383953263683, 0.3528998732086151, 0.4798249834247174, 0.6610056661790418, 4.5589840892822515, 37.37041711807251, 83.9704615069974, 127.35411136381089, 72.57868259183823, 41.61275463719522, 42.190562909649266, 81.22728132432508, 84.19384048831078, 95.19684976147067, 102.57155679887342, 12.277774676199883, 1.3181272052949475, 0.35191808556837423, 0.3618929180647097, 0.33760069899501344, 0.2041237750240872, 0.10529253391488906, 0.2313170771324827, 0.16317089028175802, 0.14090779297534498, 0.12966563654763083, 0.13020672444855014, 0.34604087351791324, 0.1634539138045042, 0.08350473287845812, 0.21192592088012926, 0.24193785964481293, 0.14176930481147382, 0.1695566161745979, 0.14040664889879767, 0.1804904834998231, 0.1401664037257433, 0.14643815105720875], [0.07597553648895795, 0.07447383561802488, 0.015061812403972351, 0.13849872224513562, 0.028024187664531415, 0.05154571270630245, 0.10794165063529246, 0.07463561806587443, 0.01939581598215286, 0.032847153563653274, 0.04126358319134001, 0.07219686908947845, 0.11218850500881673, 0.12000366669869232, 0.04353992152778853, 0.18486907435280664, 0.05123766492150965, 0.1474259295050175, 0.6984850776291663, 26.256385157185218, 105.17722652804468, 89.02176826230942, 75.8048555927892, 64.56764159664031, 29.582580558715332, 58.972031454886164, 113.47121161799278, 52.08939360034082, 39.18298752077165, 1.1705775679119172, 0.12515498745825984, 0.21315498638056943, 0.08179003658193736, 0.14644636351975704, 0.49647170629712845, 0.23782370702153255, 0.965637771352645, 1.2451387605359479, 2.8545303883091098, 106.95358953168316, 113.03289459597681, 107.52119571931901, 103.67153844525738, 103.81497167771863, 99.05202188799458, 105.79737678650888, 97.20293814136137, 98.20734731612667, 98.49352344389885, 91.14744186401369, 95.2883037444084, 97.18166320554673, 94.42589221462127, 94.2928767973377, 77.38804186544111, 68.74163181551042, 65.11704406430646, 61.46958497262771, 63.14100496230587, 65.75427232250091, 63.63484313411098, 66.88599771068942, 62.176992277945246, 64.43766993861045, 61.443983662513, 59.773548187748084, 65.43459915345716, 68.41753421291229, 71.68061671718475, 74.33677519521406, 74.42252605192124, 67.78600123620802, 66.23726906314974, 69.23259488997921, 70.24971254410283, 76.83872961228894, 79.43426393693494, 95.74138456775297, 80.82551294757475, 82.85616320948448, 82.19226283411827, 83.46169087194627, 75.20551743045931, 78.57069138557681, 73.95054724908644, 78.55141685855004, 75.43882000830867, 91.74751743193596, 51.38272762298585, 61.44938084387011, 90.83941028964136, 72.67711054894232, 76.1400064345329, 76.11324018047702, 79.18385982513428, 74.92240859616187, 75.09991153593987, 67.94523377572337, 64.05540358635687, 62.13564265158869, 62.94239967100082, 62.496281054712114, 64.7867451944659, 66.02750855107462, 72.98016855793615, 72.18496291868149, 66.22892225942304, 61.559109149440644, 61.353686778776115, 62.50794618360458, 68.86713981628418, 74.78695346463111, 75.6179311198573, 79.25989104855445, 78.53531160662251, 77.42426103161228, 76.56927062619117, 76.7088834701046, 80.315840167384, 85.81426574337868, 84.93636085141091, 87.27614879608156, 81.47957601854878, 82.68505373308736, 82.13747516755136, 84.1408492672828, 85.7758108262093, 87.09843404831426, 76.7308016746275, 83.8263536268665, 77.95684045360935, 100.1190399354504, 38.62870170224098, 0.4857065774981053, 0.3366787581434173, 0.09341650101686678, 0.04648239629703664, 0.18014012084853265, 0.05839354283506832, 0.3529712419596411, 0.39255485178962835, 0.06167423776200703, 0.16354412831846746, 6.617526325487322, 27.642233064097745, 64.53973001049411, 65.41728188914638, 29.148940963129846, 21.859227764991022, 31.249181916636807, 56.71985749275454, 67.08723883475027, 83.75535872674759, 34.67989475496354, 0.5275197483358846, 0.09969187194421407, 0.0885848151219468, 0.02981387439274019, 0.036140764732995344, 0.038255209538845286, 0.04711718824241431, 0.020329839955534668, 0.03417411360949759, 0.10660291198761233, 0.04003657846741619, 0.02572912039355405, 0.05552375831851556, 0.060861445287422794, 0.031184524432906223, 0.09522872796702771, 0.03881516618533962, 0.06395923672243953, 0.029814531313135263, 0.021711916197091344, 0.10782417105210405, 0.01795636741594682, 0.07125268104456126, 0.13769440653343357, 0.027289024794534333, 0.12138585785343764, 0.04373594810585341, 0.004326821503890378, 0.13597907438393564, 0.10519586127972412, 0.02634100822521554, 0.06527910279410501, 0.06337439370972496, 0.09102644458893808, 0.0770511162737685, 0.08486376519525245, 0.10548971728571963, 0.10072880259324467, 0.032681425762993675, 0.12276371295053153, 0.49683991879705464, 37.16582628988451, 125.08254128117716, 97.13303366015035, 92.96492699653872, 76.51052136575022, 38.17171812057495, 36.13595701033069, 95.43375307513823, 57.89940049571376, 45.00440066860568, 1.1592493951320648, 0.11331977938572246, 0.13482865546980213, 0.10754070319836179, 0.3477508430519412, 1.831060333117362, 0.9341919458200856, 1.7755830648445317, 1.4044425155847304, 5.899028518507558, 121.48124848642658, 114.80525678203954, 111.42331861680555, 106.41704851581206, 109.27444811790221, 101.36599279219105, 107.03905797773793, 100.99418347881686, 101.39662650323685, 104.13935169096916, 98.01232707115912, 98.16401297046293, 102.05399220989597, 98.28140166498001, 98.14016495981525, 80.63266569568266, 71.5140179664858, 69.4272699663716, 67.15534687042236, 67.29934492418843, 68.19787363852224, 66.81595202415221, 68.51202411036338, 67.47643209272816, 68.9332317536877, 66.96252315275132, 64.43844656790456, 69.7050129982733, 73.16572804604807, 76.69224477583363, 78.25964743091215, 77.50401850669616, 72.2132981208063, 69.696470076038, 74.62954090487573, 73.62335881879254, 81.42105425557783, 85.20977358664237, 95.53920991959112, 84.32285508801861, 85.94869321392429, 85.08646995790544, 86.40514727561705, 78.30703750733407, 83.13008585283833, 77.36097751125213, 84.28724781159433, 79.36904276570966, 95.1526838733304, 54.86954996662756, 63.67203897045505, 95.73657574192171, 76.17252288326141, 81.18499032912716, 79.28567671006726, 80.50144672393799, 78.45146702181908, 78.24066315927814, 70.24106764024305, 66.31308847858061, 67.78823698720625, 65.0327640964139, 66.4886066990514, 67.75539890412362, 70.41581707616007, 77.26293394642492, 73.6698075263731, 70.85804077886766, 63.610834306286236, 63.860234291322776, 65.52453125676801, 73.01700745859455, 76.79850962854202, 80.41736679692423, 80.89020067645659, 82.9529437711162, 81.23642829156692, 79.28414698570006, 80.47159748692667, 86.26085112171789, 85.58288512691375, 87.07311907122212, 87.8706467536188, 85.7747047178207, 88.33513382942446, 85.57711139802011, 89.3351891732985, 86.18153295209332, 90.06152583706765, 80.44595303074007, 86.16552183704992, 81.2127685546875, 103.36498168206985, 47.845702863508656, 0.15860764159550592, 0.20597951576834728, 0.4170480616871388, 0.751521896210409, 0.67429514661912, 0.12777690039647202, 0.5093514216282676, 0.6456540609079023, 0.08275379051244067, 0.1322958308963045, 5.691996995479831, 33.142015780172045, 59.888732510228316, 41.55378180165445, 29.734613587779386, 32.72543653365105, 38.99559236341907, 69.26100069476713, 76.71963076437675, 91.9169795128607, 53.50765205198719, 0.5466248780008286, 0.017547550340813976, 0.0573989155612165, 0.025845519792769226, 0.09974528359429491, 0.006721990132298802, 0.06488490459178725, 0.01364726744096486, 0.06961277025120874, 0.017724181487855893, 0.021155970020880623, 0.04432723008757157, 0.0787901588445229, 0.09518586534766421, 0.04545056779358176, 0.07551199200773433, 0.06671798445524708, 0.04460149722534322, 0.08258845341662246, 0.019767734432412733, 0.1018904293737104, 0.05050038573362174, 0.12149803610819003, 0.2731240733015922, 0.10259408113216201, 0.2544592603320076, 0.14497705284626256, 0.11985821724538842, 0.23709238416725592, 0.2503807461189647, 0.15760933709961755, 0.1518205315956185, 0.18870691438355755, 0.17405100887821567, 0.1831229761122696, 0.20028052641259086, 0.15331020488614036, 0.18673538711042176, 0.20434105288117163, 0.2703989453373417, 0.7930549546595543, 45.5834601771447, 146.67689138843167, 112.95467469000049, 107.10520482832386, 82.89825808617377, 44.95610844704413, 77.04504628335276, 145.73814269035094, 73.18942700662922, 64.8890680651511, 1.9002296150692048, 0.24048144989196332, 0.2926009701144311, 0.2483911238490574, 2.0099425988812603, 3.243835924133178, 1.3880684587263292, 4.029267016918429, 2.342985902101763, 4.827799316375486, 120.37603439823275, 117.16183247104769, 116.34207279451432, 113.53054923395958, 113.73342990875246, 107.15220266772856, 111.34005454278763, 106.46916897066178, 107.3139690583752, 105.96764687568911, 102.39999232753631, 103.58086893635412, 105.82994030367945, 103.03940142354658, 102.23433494567873, 85.15383274324479, 77.2495194404356, 74.45292442075669, 69.65596768163866, 72.82049671296151, 72.0829499152399, 70.8012762377339, 71.60735468710624, 69.86807377107682, 70.95570779615834, 69.78715527442195, 67.40546072683027, 73.8898838720014, 77.2860445514802, 84.66314423468806, 81.13046938373198, 82.65192539461198, 75.6462114087997, 72.98412230706984, 77.51358124517625, 76.28733850294545, 85.6786144933393, 90.93885806299026, 92.95950628096058, 88.96744343542284, 89.52894641507058, 89.67349360066076, 89.52742453544371, 80.3319218850905, 84.67115371457993, 80.78612450630435, 86.48235521008893, 85.4296459690217, 97.49280129709553, 61.096516578428215, 68.77046123627694, 99.50866422345563, 83.4443461510443, 83.4256992032451, 82.06931221869685, 83.56999535714426, 82.69570689047538, 81.05444600505214, 74.89582277113392, 71.13317935697495, 70.37602070839175, 68.31698817591514, 70.78986998527282, 71.10822523793867, 73.08087933448054, 80.78475952148438, 76.47620062674247, 73.73666040359005, 67.77349672009869, 67.51010171828732, 68.8313050423899, 76.86924565222957, 80.33177283502395, 84.26965990374165, 86.52346164949479, 88.5434195303148, 86.56268535121795, 84.6245010437504, 86.67555547529652, 89.76929356974941, 91.25579341765373, 91.80217173791702, 93.20942401885988, 89.24237020554082, 92.5396243987545, 90.72313554825323, 92.71293824718845, 92.04683349978541, 93.29006794960269, 84.3317980920115, 90.83255398658015, 85.24864427505001, 109.41099366834088, 47.1511491652458, 0.8847985188326529, 1.1229005455970764, 0.5399656127537451, 0.5401966035846741, 1.2666013572485217, 0.7620942160006493, 0.8367940398954576, 0.7150743745507733, 0.2208642670584302, 0.2365413984103549, 10.778470250868029, 46.04109487225933, 87.17153918358588, 90.60100078582765, 40.424150959137954, 32.878412892741544, 46.09478035280782, 81.98705227144303, 88.87545601014169, 111.36057638352918, 54.34993005567982, 0.545649065846397, 0.173722188619356, 0.20578085384782285, 0.2267922860600295, 0.11693796668682369, 0.20892207480726704, 0.23042680635567636, 0.1449201325134885, 0.160836007506136, 0.20473846865277137, 0.11609514739604727, 0.14495210902344796, 0.11370570383845799, 0.25763683982433816, 0.10594088178608688, 0.2170052370356937, 0.1363739007783513, 0.1338420108321213, 0.16409117638343768, 0.09877013027547829, 0.17766956390152056, 0.17709594790733632], [0.0439978007888121, 0.06114049281384196, 0.014862778930804663, 0.03589411889533362, 0.052997767249302524, 0.20338863705194768, 0.03618082730099559, 0.05858286614379576, 0.06564683265863888, 0.0015751041839041958, 0.043502938633243886, 0.04070454585035482, 0.011802844688176148, 0.04306067990499639, 0.036631106969810305, 0.04122879513869843, 0.083312138374294, 0.12746869556365475, 0.30217385159865506, 47.42168680314095, 93.69462120917537, 84.77256267301499, 84.90366397365447, 81.97978019714355, 70.09030742029991, 109.62342923687352, 94.84056518923853, 54.53078269958497, 10.507409957147415, 0.4105209312852352, 0.12334220892479345, 0.023031330276881496, 0.32640083062071956, 0.2486597449188271, 0.271074726817108, 0.6176575309326572, 0.2543756341741931, 0.3207322396337986, 88.31364708562052, 115.2600791377406, 99.93940322629868, 99.03554793327086, 94.17908099389847, 97.05187982128513, 95.51211418644075, 97.53269964648833, 97.01676676350256, 101.93868237157022, 91.87516704682382, 89.18950450035834, 88.40761138546853, 90.41205236988684, 94.5655050585347, 84.93192857311618, 68.19774812267673, 66.13470692788401, 64.46305944073585, 66.59928029583347, 63.3679219215147, 63.53772132627426, 68.52080237480902, 66.70994604787519, 64.19384756395894, 61.589236874734205, 57.220842223013605, 63.99016280328075, 64.79461346903156, 70.30444529748732, 74.51265427374071, 78.15625375316989, 72.3620500872212, 69.64980956046813, 64.01219867890882, 69.51371116022911, 66.99028568883097, 79.69216762050506, 75.43479565651187, 82.15835002160843, 87.54660406420308, 78.26765691080402, 82.32070476778092, 78.41800135950889, 74.80170942121937, 78.65648931072604, 76.537672012083, 78.2333283270559, 74.72115962736069, 87.12982085443313, 50.03256936227122, 58.6700834766511, 87.73600747508388, 69.47877853147446, 71.210049967612, 70.33903275766681, 79.44141834012925, 69.30181687878024, 70.25078727353004, 58.69116229395713, 63.482815988602184, 60.53569609119047, 58.936263361284816, 61.091437109055065, 62.324469474054155, 64.29492312092935, 71.6710461339643, 70.30167610414567, 69.02233231452205, 61.30458654895906, 57.83885871210406, 59.004936218261726, 66.66968684042654, 68.6911666008734, 75.48300943066998, 74.1530199973814, 79.10840126775926, 76.98242172118157, 74.78168964385986, 70.78782250804286, 82.1944122929727, 76.79162979125977, 81.82134782114338, 81.91441782059209, 78.4310079390003, 78.82480605956047, 83.69543275525494, 82.38075625511908, 86.66591428941297, 82.22644236779983, 82.31882987483856, 74.39104510891822, 82.04245967249717, 79.90649377146076, 91.55649800454417, 8.452437077799152, 0.91524597858229, 0.5423853474278604, 0.10662613977347651, 0.23991103614530257, 0.17210689223101064, 0.06319019935965058, 0.2364078846069113, 0.011637152319083051, 0.05722018341804224, 0.2648758804125171, 17.80076115362106, 32.829614685427764, 61.78565740585328, 59.204847658834154, 35.69902850735572, 41.263785285334436, 53.26960340622933, 66.53531428306334, 70.70788460393106, 68.74471479846586, 2.971248112378582, 0.1951372878806245, 0.05954115786739896, 0.012249758358173555, 0.08043688015952226, 0.02505831082441634, 0.046582562293136315, 0.06913385038534481, 0.04181631179826875, 0.02932489770765026, 0.0517093031216533, 0.04977948933599457, 0.07712492118439368, 0.06300799300773971, 0.023881107561230182, 0.14626676186678872, 0.1004580747816832, 0.0796304347233907, 0.030916845651283383, 0.020705780367397016, 0.004908306178666892, 0.017738899952101133, 0.037969956700239456, 0.0296155380595836, 0.053243137550570314, 0.02626577647583139, 0.049442943080418536, 0.038306227164162744, 0.0546922043506657, 0.060748071935508526, 0.015791574354103256, 0.012986799101195028, 0.01871417201454601, 0.11943296949949958, 0.028234884826346274, 0.07942142295500926, 0.05731572607351888, 0.04130643814982426, 0.07932733969702836, 0.10059576376431412, 0.26470872002743906, 74.88662089070966, 106.85738163609659, 98.71749862547844, 98.50620838903613, 97.68338926376836, 62.648331734441946, 81.01571652197069, 101.16097834802444, 56.60777576508061, 11.806095934683277, 0.667988894687545, 0.17351005887312276, 0.4061309410439384, 0.2053119007858538, 0.32465320020433397, 0.8241447025249082, 1.1422641839711898, 0.38876902912893607, 1.0862488155403445, 105.57061672210695, 115.21242234014697, 107.90060658608715, 101.19016862684681, 101.19717397997456, 100.14993252292757, 101.65626387442313, 98.02438443706882, 100.56797089115267, 104.76473439124324, 97.29582771178215, 91.91743450780069, 93.22109699249269, 91.90514179968065, 97.1464717003607, 87.24474630048199, 71.28124098623954, 69.8683875606906, 67.37399547330796, 70.14347907035582, 65.77288396896856, 66.84154941189674, 72.34333253675892, 68.97493439335977, 66.86888833199778, 64.94491477166453, 62.47362936696699, 67.63131864609258, 69.73968675059658, 74.11248622402069, 80.70817916624009, 82.90418086513397, 74.33992093609226, 72.61854956226965, 70.3027900572746, 71.29819347012427, 71.50902086688627, 82.53774519889586, 79.78546511742377, 84.93162262824275, 89.42087727208292, 81.21290191527336, 85.81301842966388, 83.45186141229446, 80.21394483504757, 80.65976927357336, 79.78100146016767, 82.01879993561776, 80.66406819128221, 89.71111697535362, 55.61921688818163, 60.85750695197814, 92.16375935462214, 73.892605996901, 73.4359165929979, 73.87611635269658, 83.10840299052578, 72.38609421637751, 75.43187741310366, 63.845278293855735, 67.9665950036818, 64.00175340713994, 61.501305180211226, 62.527350148847034, 64.72670547423824, 66.12782709060177, 74.74209723934051, 71.55861531534504, 72.76818013960316, 62.78624226970058, 61.760032561517534, 62.13064947435933, 69.06098335020005, 70.83747186968404, 78.24038074862573, 79.34270797237274, 82.2814339976157, 79.12236490557271, 79.28852435081237, 74.90963735888081, 87.34004420618858, 81.87502153458135, 85.85422685069423, 84.85746629776494, 82.36083845938407, 81.48039187154463, 88.4622892256706, 86.67234697649556, 88.2636917791059, 85.30028620073873, 84.16905110882175, 78.68396159141295, 87.97512300552862, 80.51041326215191, 102.25433903355753, 13.548805982835832, 0.7726528687823204, 0.20321809055824436, 0.6336845806048763, 0.6596767794220679, 1.2500021318274162, 0.3037186832197251, 0.9522705789535277, 0.0894975399358138, 0.18511843597215993, 0.22073919554391216, 18.59675518928036, 39.257998927947014, 43.2179218722928, 30.9794169856656, 39.3854602690666, 50.86756352455386, 62.13169674719534, 74.92453452079528, 78.85772259004655, 88.76888521255987, 7.583774270549898, 0.3813406728929089, 0.05998955679035956, 0.10216838139439784, 0.044747992388663754, 0.0881741613510155, 0.06793254025040135, 0.06510075752533252, 0.013410079916338287, 0.08522537401727132, 0.024443923630901886, 0.09209967248382107, 0.05608278416818189, 0.04979709403649454, 0.07744413470068286, 0.057342343798448006, 0.03003314790886737, 0.0544676295061025, 0.061788139714589047, 0.004844995714994449, 0.033683135519705476, 0.06974249191942715, 0.11034510594101683, 0.15670602750633994, 0.1783929807284186, 0.1392083954546721, 0.16515136546184941, 0.2690971168058534, 0.11904159050074317, 0.10261170115442046, 0.08930497607516666, 0.2157691694916256, 0.1368139570038165, 0.17722420634761935, 0.1737478832083364, 0.20895893895818343, 0.11902226210241357, 0.30247768206942466, 0.15299590965432508, 0.19687770174876337, 0.4905652603314769, 90.6513483293595, 125.76900312977453, 107.6040126431373, 113.6504796243483, 99.42689849484353, 88.26108732531148, 154.4442355248236, 113.49292585926672, 73.71409108561855, 16.50116224442759, 0.8713120618654836, 0.5296236096370606, 0.3231912592966711, 1.064529303581484, 0.9738499887527959, 1.2615354935969076, 4.008788322248767, 4.984845134519762, 0.8173085628978668, 107.5198228897587, 119.22980800751718, 114.85467864621071, 105.58116789787047, 106.74414280922183, 106.42284577892673, 102.71405650723366, 103.22827139208394, 103.68234065271194, 106.49430351872599, 105.4339535005631, 96.28616256098594, 96.51135367731895, 98.58070204334875, 103.50664200321322, 94.01661642136114, 75.76781272888184, 72.94263147538709, 70.82845041828772, 76.08197889020367, 71.78788569665724, 69.85728725310295, 77.82977919424735, 73.52168313918575, 70.71899275625907, 68.78356195265248, 66.52954839891004, 71.2242175686744, 75.30409443762996, 78.00975322723389, 85.12493271981516, 85.37350900711553, 78.91247887765208, 74.54697501274848, 74.42410284473051, 76.40256989386775, 76.49494955616613, 87.53347981360652, 83.35975631590813, 89.41568405397477, 87.5725152415614, 84.40767242062478, 88.16302022626324, 87.34704955931633, 83.13134885603382, 86.21731281280519, 85.92911274202409, 84.85534821787189, 83.9662959498744, 91.4649812636837, 59.129145914508456, 67.31807816413142, 96.5684869212489, 78.83192123905306, 76.81557193879159, 77.33731777437272, 84.82957824583977, 76.25667341293828, 79.3307133643858, 65.83069970530849, 70.4735622098369, 67.50529289245605, 66.85501098632812, 68.49980200490644, 69.99563709382089, 70.06747922589703, 78.9274387974893, 76.40688450105729, 76.3948114456669, 67.67742218509798, 64.58353896294871, 67.03976246618456, 74.48395821356004, 77.09680588014665, 81.98033717370804, 85.27584198982485, 87.14445913991621, 83.32369404454386, 84.28116813782724, 79.15703865789598, 93.46053415729155, 88.20636241666733, 89.8735031004875, 90.24351596832277, 85.69977960278912, 85.3177329032652, 89.82245737506499, 90.20404907964891, 94.7183519794095, 88.8757384207941, 88.57224895108132, 84.35293182249993, 92.49845520142587, 85.18664729210639, 104.21518679588073, 12.150159382051038, 2.3709948120578646, 4.311800733689339, 0.6683322246516905, 0.5075832294119943, 1.8253545102573212, 1.4072194310926622, 1.770062083678861, 0.15693286614071938, 0.2069658386490999, 0.7524045520732481, 29.529522657394413, 49.33886289596558, 87.50925525542229, 78.46007270197715, 47.50558237875662, 58.31622292918544, 73.557721876329, 91.23250238357052, 89.94822425227012, 103.10208874364054, 7.358849385092336, 0.5017616047013191, 0.1855691408197726, 0.20192498010733437, 0.21161424566901502, 0.15965951095905997, 0.12755057504100184, 0.09163007590799563, 0.09586956051568832, 0.09946482646609507, 0.1159375477882643, 0.16161459798534072, 0.1791291452583767, 0.12967535054251073, 0.14814298780214402, 0.22291270955916376, 0.17205334268510344, 0.11754271649425069, 0.1518028656080846, 0.12197064340955789, 0.07702479349269022, 0.15080837623005913], [0.09688098809771961, 0.03680521577236153, 0.013536514109751631, 0.022837094429339615, 0.005050218699785371, 0.028959420141613776, 0.053615594177596995, 0.03156490623950958, 0.08298793762561776, 0.037159489302505413, 0.0566624254438906, 0.05694700412512307, 0.04071849248101635, 0.06788649070527285, 0.12434005376792724, 0.0257546866628071, 0.04959523369888625, 0.2440250508727566, 4.613294697576954, 93.72997745390862, 92.49934165708481, 79.98842423962009, 57.057020510396654, 39.962833158431515, 28.280726286672778, 55.038427614396625, 62.973390317732296, 36.466126441955566, 0.1992991524598291, 0.08944521613058545, 0.04843033955342347, 0.2671609674730609, 0.4861395703929086, 0.2179781533777714, 1.1041022188240484, 1.5842437191355614, 1.0507973307563414, 47.66509732892437, 118.77420902252199, 94.60698804547711, 106.3462418894614, 91.03774101503434, 94.46133475149833, 91.45883883199384, 93.28622402683382, 95.29960801524501, 101.14758737625615, 86.85603157166513, 91.59463128735943, 85.72854626563289, 82.96984134181854, 81.37275418927594, 76.05874276930287, 65.27814757439398, 65.58143700322798, 67.7062516058645, 64.28601934063819, 64.33187969269292, 65.90752324750348, 64.42021539134365, 64.84671038966026, 65.4329635250953, 65.44438938940725, 57.71704950640279, 59.47832315198837, 63.03953716831823, 65.76525495898339, 76.3986239894744, 81.88665528451243, 81.4900016784668, 72.19837742467081, 64.02392264335387, 61.933264040177875, 67.28454189915811, 70.51222893499559, 73.451260905112, 83.84132139144405, 77.05087492542883, 81.47036629338419, 82.9121668108048, 78.18735030389603, 84.40816663926648, 77.2103428071545, 75.15739779318534, 73.80547446589317, 80.563930080783, 75.06304910106044, 84.16641527606596, 50.56350531116609, 60.99189519882203, 85.89516855055287, 73.39219785505726, 70.98041088350358, 66.83352424252418, 71.36211241445234, 64.56057740795997, 61.969475361608694, 59.641831074991536, 56.770471757458104, 54.88423924292288, 55.80158356697329, 58.22615746528872, 56.94068301108576, 59.37668669608332, 71.46502756303357, 70.83655403506371, 69.49322069844892, 61.77971501504222, 58.03055278716549, 57.022111415863044, 58.895439332531346, 61.653163663802616, 64.88458087367397, 68.65532398223877, 72.39734357403171, 73.32732185240715, 69.56754961321431, 73.09359565857919, 79.8464579736033, 80.80623057580765, 80.9373946343699, 77.37691802363243, 74.04488025173065, 76.16213644704511, 81.16356634324598, 81.99346926904495, 84.54472003444549, 80.42957321290048, 78.48672128492787, 74.63964493043962, 76.99467520559989, 81.17771041008734, 88.69031229326802, 68.06059852723153, 0.5678908659085151, 0.8690734303766682, 0.9210668372050409, 0.4497702509885835, 0.1235895787155436, 0.30861003204218806, 0.2066729019486135, 0.49056498453982417, 0.2211408860861294, 0.16471760647912181, 4.080850107054557, 23.136220093696352, 38.59069785764141, 91.48383217473184, 30.07852504330297, 29.46022810474519, 59.9740989746586, 63.045758047411525, 65.15898989092919, 80.24477466460198, 26.055565687917895, 0.5602851449962586, 0.2469620787568631, 0.10523493176386242, 0.05396163609299449, 0.01901814229636183, 0.0749934883788228, 0.08588532812052196, 0.034359284721675425, 0.07486838622078781, 0.04898715906986787, 0.03390430127300563, 0.013880050917636725, 0.06638410035520792, 0.048394191694716295, 0.08294551933725035, 0.029518915220133723, 0.006577803287655116, 0.05460957027671318, 0.06751696819499617, 0.08409846634153398, 0.04767687292769552, 0.018039313670728477, 0.03194446067115472, 0.03973650565791515, 0.02149697490817597, 0.024688995157879208, 0.10315119559245725, 0.08829809905540559, 0.01505968938281219, 0.05583534542951853, 0.054375147371883356, 0.007132610865688373, 0.050822564010177894, 0.028270073159928286, 0.1038733943395557, 0.14382330911053767, 0.12990808805390713, 0.16122836709743546, 0.3942600715785258, 9.96781341491207, 116.33168635829803, 104.03484406009798, 92.27897505606376, 70.0393715212422, 54.48819360425396, 33.72960644383585, 68.14620033387216, 69.21765065962269, 39.84509929533928, 0.2831394778143975, 0.2379628898756158, 0.34839261022786944, 0.7548510691811963, 0.8024185102793479, 0.4566940004306455, 2.8423752082932383, 0.5259102282504882, 0.7067645269055521, 61.934640792108354, 124.3126113953129, 101.6246574155746, 108.38065762673656, 95.70488299092939, 95.61020481971003, 96.93106297523745, 99.0452048086351, 97.68621337029242, 102.41260667001049, 93.40466391655707, 95.53897457738077, 91.29898655799128, 85.3629421418713, 85.12851776615267, 79.67850992756506, 70.62756230754238, 69.43878604519752, 70.49682186495873, 67.50833665170978, 67.18099917134931, 69.86832480276786, 68.10491346543836, 67.28329458544331, 68.59670023764335, 68.11826521350493, 63.47601067635321, 64.64952891872775, 66.69412320660007, 71.1579373575026, 82.65506329074984, 85.5159616470337, 81.82376400116952, 75.63362060054656, 68.72303978089364, 65.36509083163354, 73.06373073208717, 72.33395807204708, 78.72799411896737, 86.703427837741, 80.44418796416252, 85.28352199062225, 84.85384987246606, 79.9658235426872, 88.66789987010341, 80.58762904136412, 82.13159945703323, 76.96317857311618, 83.09043069039622, 77.56348948324882, 84.9531093720467, 51.86395537468695, 66.06859930099981, 91.66724220398935, 77.87247811594318, 75.91881613577567, 69.9406611534857, 74.64516762764224, 67.60078691667127, 66.70827511818179, 62.431754143007346, 60.2397846406506, 59.87855788200133, 61.02227003343644, 62.08614626238423, 60.71791371991558, 63.561777222541075, 74.10634379233085, 75.8689235871838, 71.55004101414835, 66.35542654222058, 62.0025291750508, 59.96089627665859, 61.263997862415934, 65.19583271395776, 66.9174551194714, 72.40388608747914, 77.13176204312232, 73.83685342727169, 72.13252867421797, 77.53715468991187, 85.06535191689768, 86.8525485069521, 86.33379936218263, 80.2112776233304, 76.80658186635664, 78.23665449696203, 83.81383342127647, 86.40569640744118, 86.6842866713001, 83.61252953929286, 82.38440405937934, 77.73211217695668, 78.96614474634971, 86.14899296914378, 90.62073815253474, 82.56337396560177, 1.6714740448421048, 0.6798794372908531, 0.7561807526696114, 1.2362175747271509, 0.355268984792694, 0.8257809437571034, 0.12718693608598364, 1.9101286967915876, 0.7556376882618474, 0.46379174376207016, 3.2120769831442066, 27.469321258606453, 39.89927507215931, 62.094163587016446, 26.375042738453036, 44.68961477279664, 68.51661328346499, 74.62539888197377, 75.12776820890366, 93.51659267179429, 47.11087819068663, 0.7657254114747049, 0.14579387111288888, 0.05604962022193978, 0.058416709333898566, 0.0500190488603567, 0.06501409765933791, 0.06446423039080636, 0.021351450761299462, 0.0419902635527955, 0.06986033922481923, 0.014517368080334799, 0.02310453763892574, 0.10404377229391568, 0.02235110548715438, 0.037980724066015215, 0.05296308261853072, 0.01868445737918298, 0.046722741061521154, 0.05321805583192937, 0.05029442299517894, 0.04257061345983417, 0.19096456017465363, 0.1466586005182997, 0.13596998858115367, 0.12390843983138762, 0.09491067124350418, 0.24940308003175646, 0.14185731299221516, 0.126878057095793, 0.2688968614224465, 0.14429615389916206, 0.14578538285868783, 0.1120325601509502, 0.10815191878786973, 0.18174329772591594, 0.234936781287674, 0.20075245189570612, 0.42875857362824105, 0.6179371836685366, 13.533192007772385, 136.0813928419544, 118.95104515937068, 109.14100908464002, 81.15561177653652, 57.18389741836056, 41.97977865895918, 77.75760758307673, 74.87009986754387, 61.19016708866243, 0.5149949462183061, 0.2561886272122783, 0.700645690723773, 1.319283078755102, 1.2344118135590707, 0.9196473682119001, 7.076181327143024, 9.090592976539366, 1.7347612424242882, 63.24144901767854, 130.61288710563414, 104.64736138620685, 111.43113982292914, 100.8087024381084, 101.6511804826798, 99.93201348089404, 102.12054698697983, 101.36855802228375, 104.91385506045435, 99.93390406331709, 102.78833050881664, 95.85359573364259, 90.47177437813052, 89.94037166718515, 83.41653654652258, 73.81927336415937, 72.45417087308823, 73.91726986054452, 72.50914681342341, 70.88743502093901, 75.18517601874568, 70.95573133037936, 74.09646726423695, 73.4163361210977, 72.47455150850358, 65.72596065459713, 67.51781309804609, 70.55830109503962, 75.52715178458922, 86.01735822616085, 89.31396130592593, 87.77858872567454, 78.28518990547427, 71.67910268229824, 69.63587730161606, 77.0197940641834, 75.72545897576117, 85.07522060025124, 89.56132950321322, 85.49079572000812, 86.88157404622724, 85.04900347801947, 86.25845063117244, 92.9171839068013, 86.51394597945675, 84.41578388214111, 82.32898096884452, 87.43778182614236, 81.78520710237565, 89.6557487980012, 57.952987917007945, 68.41799705259263, 95.3299436261577, 83.2611479297761, 77.66184683768981, 72.06526787050309, 76.87129312945952, 72.33587218869117, 70.35087047084686, 66.9721878728559, 64.3222188949585, 62.63517218251383, 64.53275211395757, 66.14614455930649, 63.47456332175963, 66.63664479409495, 77.91678520940965, 76.60228129356139, 76.34121617963238, 70.73718470911827, 65.69537008962324, 62.92482353025868, 64.99048094595632, 68.37532166511782, 70.6401138920938, 78.06082248687744, 81.88192490608462, 79.88735260501986, 76.63780227784189, 83.96983392776983, 86.54112016001056, 89.29675779035016, 87.87136062499016, 85.35573282549458, 83.52172666980375, 84.67614296943911, 86.37981660904424, 91.39678693586781, 91.84176414243638, 89.21885951872795, 86.526379892903, 80.6114221388294, 82.14890495423349, 90.48605180555775, 94.01480428634152, 84.15646814530896, 0.9685129299759866, 4.016985585612636, 4.612619559611044, 2.499793681406206, 0.5654322139678464, 2.4036046622260927, 1.2136385734042814, 1.271400622302486, 0.7648260242515995, 0.5901714606631188, 6.779685443447483, 42.53452731717018, 57.12600323461718, 127.53540331317534, 39.51633014986592, 43.465309681430945, 76.11250277488463, 89.08763270224296, 85.1982339735954, 109.88314505546325, 48.860855410175944, 1.1368933560386782, 0.31274981796741486, 0.2887484058737755, 0.23767189903845712, 0.11596174084491308, 0.22306560538709166, 0.1840822867328121, 0.16404447566357352, 0.17596500294823803, 0.24710170594194245, 0.1595448122750367, 0.16165915365901687, 0.16573253508296706, 0.3010126155230307, 0.1481977630887301, 0.07326756123333208, 0.05494989717619554, 0.13705271596629776, 0.2128410282274408, 0.11846369207506219, 0.11981802061200143], [0.10204191559985762, 0.03699073928498453, 0.05472304705049723, 0.03075161963821419, 0.03511650900867197, 0.042728967664222565, 0.08429968699572549, 0.04555637219680413, 0.013179779522150997, 0.020426351712235523, 0.04367545397291261, 0.06897630440371652, 0.09172733076998303, 0.009660115916161768, 0.0274786947580475, 0.08133396145797546, 0.19136078084909147, 0.29750491342236923, 20.988624365099017, 93.88086318969728, 83.5612641611407, 80.24078953650691, 59.85210541755923, 40.413062418660815, 38.261563931742025, 35.674180292314105, 47.06756345687374, 8.011208676522779, 0.02327366303952952, 0.3715703552288394, 0.9210705144270774, 1.1918670900406376, 0.11928706805432036, 0.4880294786585916, 1.1526176477632215, 1.5107431599209387, 9.369829450884174, 116.79774238217263, 97.44807843239077, 104.59535860246228, 81.90184270181965, 93.37156695704307, 89.41904160284227, 95.40831258220058, 101.25928863402336, 104.15653167232391, 87.28113020620039, 94.22123078377017, 89.14436586441533, 86.00690118728146, 77.17875203778668, 72.99126102078345, 65.15372607015794, 66.44568027988558, 65.70912584181755, 65.33427276918965, 65.10384528867661, 66.79799541350334, 64.16145663107595, 64.21118444012058, 61.18763323753112, 65.25143623352051, 57.46744948048746, 58.360094639562796, 60.265978228661325, 64.18167644931425, 72.27503622731855, 81.4151785450597, 79.01814753009428, 81.12241283539804, 71.55585396674373, 65.37937610380112, 61.542329249843476, 67.18174442168205, 68.24741317379859, 72.60644512791788, 76.85104585463002, 83.1239983343309, 73.72925496870472, 86.22962905514626, 74.46828442235147, 81.66464913275935, 75.11254156789472, 79.59834452598326, 74.06714362482872, 80.15139872027983, 72.83391906369117, 85.16575674856864, 46.72945122564993, 60.017507845355624, 80.74099371510168, 73.62235469202842, 69.68370668349728, 61.51863028926235, 64.8468594397268, 59.44523403721472, 64.07888289420836, 59.09020070106753, 63.94821305428783, 60.02248925547446, 56.341180109208636, 56.46677440212619, 56.07767528103244, 56.751248221243586, 65.82379633380522, 70.3050885661956, 70.49780245750182, 62.221848503235854, 58.506485339133974, 57.64014751680436, 57.63656247046686, 59.18456900504328, 59.072628482695556, 60.46304202848866, 61.29096415735061, 64.89529286661457, 65.80228213341006, 66.99181541319817, 78.90193554662889, 80.85991213398596, 80.93071091559626, 71.47153869751962, 66.36114535793182, 75.55753446394398, 79.8399233048962, 84.6168916456161, 81.06218091903195, 80.8813988777899, 74.72804730938327, 72.90567490362352, 71.84023364897698, 82.9216589466218, 82.76681161695912, 92.90134537604548, 52.542133177480395, 0.052465301667971, 1.6955675713477598, 1.4033994102670302, 0.4339029153268184, 0.31744887872088345, 1.0667275469149313, 0.2933755462929126, 0.5673542366393152, 0.02096125728360588, 0.048612013474226966, 12.970538793071626, 25.909957501196093, 47.129564362187544, 56.11996235386018, 21.92260346105022, 36.624280329673525, 57.54405336995279, 66.53260784764444, 72.62016557878064, 72.19634563692155, 4.14995736652805, 0.4327159693404552, 0.11836295917389855, 0.026425367912217498, 0.031691289679597945, 0.04209778399296826, 0.05858347518369556, 0.06766160559510032, 0.07517966306618146, 0.09293183549157075, 0.055833288483441844, 0.03148466235988083, 0.041896651438888044, 0.039413618750029036, 0.06421283097757448, 0.04633493586293152, 0.05432075895969907, 0.05638920784657521, 0.03659745655773628, 0.0608659383930987, 0.008504574746644546, 0.023903057895480626, 0.0038491254634854775, 0.09206437115227023, 0.04942369512132099, 0.009724669357491358, 0.0725752782196768, 0.06288955581464595, 0.05025932467692802, 0.08205235274809022, 0.04241785552773265, 0.0532308035349894, 0.0346297980286181, 0.02560084663151253, 0.03790799933936327, 0.0863645850650726, 0.0791866016844588, 0.2747507844000094, 0.36354932273107193, 40.45024648789437, 109.28967475891115, 91.968794022837, 91.5329324045489, 64.56222088106217, 51.426520885959754, 53.25646346615207, 38.619142886131044, 51.180721636741396, 9.562132473914854, 0.1679372135549784, 0.7968974065396094, 2.005977940655524, 1.5475436948960828, 0.1694999869552351, 1.130602242004487, 1.4266019458732297, 1.5714791008541662, 14.728839282066593, 126.65595300735967, 101.96940237475981, 108.94751856403967, 85.39457997968121, 98.5953011051301, 91.46638547220539, 101.18862321299892, 102.1853288527458, 110.30030481276974, 91.78961230862527, 100.33010267442273, 91.73334983087356, 89.51007981454173, 80.77888381096625, 76.81188491082962, 67.57450703651675, 70.52219959997362, 68.57957516947101, 70.24929677286457, 67.47207041709655, 69.13408848547166, 67.17302891515916, 69.80842236549624, 64.73176533176054, 69.33856164255451, 60.99196187911495, 64.3314992227862, 63.37598239221881, 69.4409433487923, 75.60617969882104, 86.5558918060795, 80.65078704587876, 81.58856299615677, 72.6263786131336, 67.8349994844006, 63.41999923029254, 69.51257367287913, 71.67634917843726, 75.01517265073716, 79.65187703409504, 85.0960248516452, 79.45521723839545, 90.73834649978146, 77.27097480527817, 85.20480786600422, 78.54003414030998, 82.84239569017964, 77.40641424732824, 84.58559113164102, 77.77568970957111, 87.50217929963144, 46.900847035069624, 63.331667454011985, 83.21809599476477, 76.63127545387515, 72.98101578989338, 64.63804814123338, 66.51318427055114, 63.31245568490798, 66.10594026504025, 64.60837541087982, 69.06128929507348, 64.31915552385392, 59.38019721738754, 58.45844022689327, 59.85135624485632, 61.191681123548946, 68.24437725928523, 72.96075282558319, 72.8693223768665, 63.40392143495622, 62.974410133977095, 60.744428942280436, 60.990302716532064, 61.890302319680494, 62.37013370760026, 63.426427995004964, 62.51512019864975, 66.93300339483446, 65.76614533701252, 69.96091627305555, 82.79725705423664, 84.83110012546663, 85.30083533256285, 75.61542080294701, 70.80894839379096, 78.22423627299648, 83.63491842823645, 86.63528842310753, 85.39681573067942, 84.91522712092247, 77.81128129651471, 75.62104548177412, 75.35301423841908, 85.24292545933878, 86.2826281209146, 93.73419792421403, 68.30512692851406, 0.47698141826737317, 1.3999561821260762, 0.8325350200456958, 0.9268299021547841, 1.2010877242972775, 1.0182055602631261, 0.5444208736861906, 1.994611892488695, 0.15177801371582095, 0.17050544671233625, 13.536797646553287, 30.915231320165823, 42.544450913706136, 38.492222832095244, 32.09490376134073, 53.442383812319854, 68.43727157961938, 77.1545353243428, 79.54583967885664, 92.06272694372362, 11.399468721881991, 0.7963640254832084, 0.1993372576731828, 0.050801270596322515, 0.051863305946631785, 0.1452702193731262, 0.03364789547518857, 0.04935377044603229, 0.03902924562534017, 0.08532278209684357, 0.0043727116069696365, 0.07383165475461753, 0.039824559803931944, 0.0670185360697008, 0.056247925911579406, 0.0941728596245089, 0.014665593644754301, 0.075800332180675, 0.11910103126278809, 0.022507632571843364, 0.026557129289534305, 0.2871427162280006, 0.08302849432032916, 0.26472588039694295, 0.280498527591267, 0.13076530979766002, 0.18813329838937332, 0.17564042681647887, 0.23563196011368306, 0.1839204583196871, 0.1675371930844361, 0.20431828474806202, 0.20177807508697435, 0.2895688860406799, 0.17857028411761408, 0.12731226040951668, 0.15103287063539028, 0.533181444531487, 0.32116299555186306, 51.05575492305141, 131.049038979315, 107.03897953033449, 111.49656495740338, 78.63437498769453, 57.10414778801703, 54.40499228815879, 50.61331156761416, 73.37113472723192, 12.21073744758483, 0.24738249248794972, 0.8851148825018638, 3.730261551757013, 4.62489559765785, 0.8377786160957429, 1.4547720407286, 11.204778936601455, 6.503094117487631, 13.191089745490784, 131.76832322151432, 103.42876726581206, 113.43885206407117, 89.29126647210892, 104.25503023209112, 96.67410850524904, 106.60540073148667, 104.5778726762341, 113.92134281896777, 96.80327999976375, 105.07215407586868, 96.43287489491125, 93.90525248742874, 85.74553797321936, 79.76153865937265, 72.06770758475028, 74.71824138395249, 72.39120114234187, 73.20991746840939, 71.6953883632537, 74.08829304479784, 71.91930863165086, 72.93784618377686, 66.56774443964805, 74.05808294973066, 64.40660868921589, 66.22413696781283, 67.14554094499158, 75.34117652523902, 80.54779344989409, 90.65686318182176, 84.17735084410637, 85.81249283206078, 77.63331551705637, 73.14300183326968, 66.32369456752654, 74.77138949978736, 74.72647051657401, 78.27915730014925, 86.3872298886699, 90.09788620856501, 83.59447094701952, 92.33838327469365, 78.99826895806098, 90.81297351467995, 82.74686244226272, 85.96876005972587, 80.78527727434712, 88.61321418516098, 83.25062813297396, 92.67748002083071, 51.63319841507943, 65.76020294620146, 85.73220191463348, 81.92102309196227, 74.81979939245409, 68.68052913296607, 71.49493955796765, 67.65129919975035, 69.80759082301971, 68.22464773731848, 71.08670711517334, 67.57771553531771, 63.02258468443348, 64.907981734122, 61.76110336857458, 65.1655912399292, 73.09040284925892, 76.55136892872473, 75.44340133666992, 68.9117685441048, 65.89827429863715, 65.86147462168049, 65.95064578517791, 64.66275515094881, 66.38575430839293, 66.87026900629844, 66.81091570085096, 71.69499612623646, 68.66027401339623, 73.9638440839706, 85.33957266038465, 89.68989695272138, 88.68001999393587, 80.36068854793426, 73.69088634367913, 83.3713665316182, 85.40830827528431, 92.25424058975713, 89.43763363745906, 89.59508542091616, 82.00711127250426, 79.61841921652518, 79.44378745171332, 91.21860150367984, 90.9904529202369, 98.85342444142988, 65.00305998709895, 0.3672995069815267, 6.515769746995742, 7.015454211542684, 2.2594092642107317, 1.4933831172604717, 2.6812221782822765, 2.499071720146364, 2.1622550968200933, 0.23327654618169033, 0.1797617040574551, 21.507218576246693, 43.19028877442883, 65.50971646462718, 76.74223930604997, 31.026697235722697, 54.216553780340384, 78.7771100382651, 91.44103911615188, 91.63151725645989, 104.02441840017997, 10.054758633336714, 1.015961412941256, 0.215974266550714, 0.14092673066883318, 0.1913616082240497, 0.17723568234472506, 0.10887517473630368, 0.1324523579809935, 0.2882622771205441, 0.2444232786975561, 0.13895469777766736, 0.16768915428509637, 0.16512910294676983, 0.24844868769568784, 0.16517476178705692, 0.1532426512529773, 0.20130386666184474, 0.19648402448623412, 0.2340662909010726, 0.1430553978969974, 0.11163534356221078], [0.06715606417386763, 0.09621120508640044, 0.048622891922751744, 0.08923394440282738, 0.01940199065082256, 0.08876405671359071, 0.026241209951319525, 0.03778371689540725, 0.03175504543187638, 0.06837980536323401, 0.010503093212572558, 0.05577084848717336, 0.15664998051379958, 0.032965889531037504, 0.06601202677214338, 0.12505495169710729, 0.033675792566951246, 1.1464787707213433, 70.04043840592908, 87.92392823003954, 91.55297571612944, 58.86114212774462, 65.0293908580657, 34.18808052616735, 54.6474261437693, 65.39757982377084, 27.665333863227602, 0.9537882910620783, 0.13217702598100708, 0.554501119880907, 1.1892406954880685, 0.7916302149814944, 0.7846286003628086, 0.7024244855969184, 1.593164292074019, 0.1325485020154907, 68.49410672341624, 117.1600752492105, 95.42124071428853, 88.632904483426, 85.92955204748338, 96.25329309894194, 90.68395107023179, 104.61969298701133, 102.22794932703819, 87.98020639727193, 93.54093490108367, 93.7325740629627, 86.72713464306247, 81.32806270353257, 68.34186384754797, 67.7305938351539, 68.58118334124165, 66.12518341310563, 63.95983895947857, 66.72730645825787, 65.05818497750067, 65.7997561270191, 64.4981764208886, 65.0669514748358, 63.786105417436175, 58.145195822561945, 58.07593461005919, 61.000445965797674, 59.861585786265714, 69.34036593283378, 77.57882595062256, 77.05379316883703, 73.89393175801924, 70.73506662922522, 66.10654431004679, 64.61797737306165, 60.26664895396079, 65.65174941093692, 67.69547293263098, 74.00491129967475, 72.75010585784912, 83.26546253696566, 72.33444444594845, 81.39504109659504, 82.85377840841971, 77.38961865825038, 79.18504438092633, 79.29784390234178, 77.53436980708953, 78.61194687504923, 74.31848910547073, 81.80414430556759, 45.824615340079035, 59.85764380424254, 81.964812432566, 75.64456401332733, 67.36273042617306, 59.76433846258349, 61.11808569200578, 62.90548232293899, 67.6216225470266, 71.1442796645626, 71.34808601871615, 63.01122157804428, 56.18947459805397, 51.151233257785925, 53.98443183591289, 57.297606929656006, 63.498395642926624, 68.6469457995507, 71.02811474953928, 66.43417989054035, 61.12676589719711, 56.915677901237245, 56.63671108984179, 56.36128225634175, 59.83871444579094, 59.18312949519004, 60.25282652147355, 61.401453402734575, 59.532475394587365, 60.28017720868511, 71.319060479441, 75.54675579071045, 74.48809239172166, 64.14826570018646, 67.21866961448424, 75.74260757815453, 82.5213183126142, 83.35075839873284, 82.77559772614511, 76.47806767494448, 74.57036018371582, 68.25834089709868, 70.4659685011833, 77.25603057492164, 85.57085913996544, 78.21140227779266, 94.50641062951858, 44.31548733865061, 0.17870986533741798, 1.1057371117414967, 1.6725276915296432, 0.19988341707616084, 0.294185362515911, 2.4057749586720623, 2.741239099733291, 0.14200568890138981, 0.20331754409257444, 1.0301491161507945, 24.943771823760002, 30.341312077737626, 74.25788848630845, 32.93658948713733, 19.38497704844321, 56.86289456582839, 53.036183157274806, 71.9573163986206, 79.48441536195817, 40.08228501965923, 0.4100434133602727, 0.01507229440199632, 0.013365519454612607, 0.03683268768532622, 0.05888158680811044, 0.020460419642228275, 0.036692160346935836, 0.016455336871947494, 0.020102386535595984, 0.05471132207481612, 0.06496184280202275, 0.01470384345720372, 0.034229723931921106, 0.12152787523284075, 0.05341728082707813, 0.07200923117418444, 0.06888094943978133, 0.019300311631072434, 0.06870433552971772, 0.026329223877720298, 0.0315314052145808, 0.07746545492761558, 0.02463633810440379, 0.039805204592525, 0.023791639982993086, 0.04514979401363, 0.06120665599742244, 0.06993531624996854, 0.05221947937482788, 0.05437286059942938, 0.026226702161253463, 0.06938801537598334, 0.07351206585524545, 0.056589888408780105, 0.12002244351371644, 0.1548191069835617, 0.141640831866572, 5.750206439725815, 102.70876130750104, 100.04114166382821, 102.81047621080953, 70.79088195677727, 77.52598377966112, 39.1919344471347, 30.02819907280707, 56.37238648629958, 33.63602653626473, 0.3318403000312467, 0.15466896907216118, 2.030181661248207, 3.167631380981015, 2.4720850779164225, 0.6169967341326899, 1.3459581377044803, 0.4621044810741179, 0.2506612875168362, 81.51405365236344, 119.69362828039355, 98.45433112113707, 92.8675659241215, 90.02809939845916, 99.93786565719113, 93.18218708038331, 107.41950435023155, 107.33336910124748, 92.0495948483867, 98.00354880671348, 95.32660176677089, 91.2274346813079, 85.24161538770123, 70.57630477413055, 69.08348206550845, 71.84116717307799, 69.88674425309705, 66.98856769069549, 69.17424571129584, 68.00715231126355, 68.37661604727468, 67.55760162107407, 67.99993515014648, 66.55554586841215, 61.84373594099476, 62.32128058710406, 65.78033647229596, 65.08966984287386, 72.56635066001647, 82.1075161041752, 78.03219702935989, 74.30865180107855, 73.49025710936516, 69.23509736214915, 67.92828129183862, 63.02761708536456, 69.36862268755513, 72.38850255166331, 75.97895391525762, 76.61072223417221, 87.01226742036881, 76.71621045758648, 85.56241819935461, 85.78183558679397, 79.79891100237447, 82.31863375632994, 80.93128358164142, 79.15749365283598, 82.71812715838033, 78.10416467728155, 83.80192510543331, 50.19452010431598, 61.74267215113487, 82.68999591950448, 80.52839340702181, 71.9687932537448, 62.43592362250052, 64.77115377303093, 67.6607442671253, 70.75143860232446, 73.77680193993353, 72.99526183835923, 66.43647055472097, 61.24024398865239, 55.53090472375193, 57.18341888919954, 59.58603143692017, 67.08337922250071, 72.74464591856926, 75.40457771670434, 70.94807486380301, 62.904972414816584, 60.364974929440415, 60.727084221378455, 59.49274178474181, 63.375060635228316, 61.45177348967522, 61.743107534223995, 60.93286352772867, 63.9330844725332, 63.572846151167354, 73.09694536270635, 79.6635264735068, 76.80823710656936, 66.215696027202, 70.2774593907018, 78.78774750617244, 84.08776390937068, 86.06798818034511, 84.95126585806571, 79.2159055894421, 76.1476864353303, 71.61298721067368, 74.1682937068324, 79.80066822421166, 87.52439560428743, 83.76577654192525, 97.09733224684193, 60.042575713126894, 0.36973419569192395, 0.8069865393542475, 0.23055543251816304, 0.8768347590681046, 1.6626811940823834, 1.753874094255509, 2.2704144543217075, 0.8131046400916192, 0.20945729447468636, 0.7355546626833178, 28.237160521168864, 35.13485831599082, 54.54965714485415, 26.462333125452844, 31.81857474388615, 72.70034666984313, 62.79804468154908, 79.36506548235494, 89.11908226628458, 65.58910523691486, 0.9515097617141662, 0.13697794578488798, 0.07427475234914212, 0.04480227354853865, 0.05431148163493603, 0.06679868415719079, 0.037422487286910895, 0.030036876841838804, 0.017617524811817754, 0.03084566650701867, 0.05181628730027907, 0.0436376360425305, 0.03629195984573134, 0.07193046967468916, 0.029299649364885785, 0.07022606193899147, 0.05587274584198191, 0.022375141495778676, 0.0701016262774506, 0.009070364195072364, 0.22717621868416188, 0.19293766558891345, 0.19787272738833583, 0.23523583136979612, 0.10370461750895747, 0.12298420837689793, 0.1854230784961293, 0.18162795552803626, 0.15968031790708342, 0.25657873450508045, 0.08199933946373002, 0.24700395312280427, 0.23249403333231328, 0.16028912798050912, 0.1745392673558766, 0.2663950021228483, 0.2596841025496683, 6.191495147443587, 118.44997021459766, 112.3767291345904, 119.04489178811352, 82.75462873520391, 88.10864048619425, 47.93537216801798, 73.16251954724713, 92.50763354762908, 46.269584701907256, 2.0151991877825033, 0.21362108959546014, 7.232777053310025, 5.949084826054112, 4.472934642145711, 2.3304068609591457, 2.888508165074933, 4.030443237673852, 0.4162384599687592, 83.92191040900447, 123.18863268821471, 104.384091900241, 96.10627482014318, 94.59543274294947, 102.6329654262912, 97.41675438419466, 106.48665489688997, 110.22279877816479, 97.34084867662, 102.53536901166363, 100.22855251066147, 95.79434440981959, 90.02907999100225, 75.88498177066927, 72.20899920309745, 76.52212373671993, 71.98922095760223, 71.07082151597547, 73.36137587024321, 72.20728120496197, 73.05114776857438, 71.44055981789866, 72.02151775360107, 71.62782945940572, 64.72240263415922, 67.00626542491298, 70.17980806289181, 67.61489960455125, 75.09503995218586, 84.83039409883561, 78.40185688387963, 77.94487722458379, 73.78528210424608, 72.16870861668741, 71.01703013143232, 67.62797678670576, 73.49416379005679, 76.39346999506797, 80.07123331869803, 79.98214844734439, 88.33765983581544, 78.55688464257025, 88.39723279399257, 87.35772625092538, 85.4266571229504, 85.96850902803483, 86.88461780548097, 83.08506488800049, 88.3865874813449, 84.11651488273375, 87.69677592862038, 52.390306072850386, 66.03358822484171, 87.152876546306, 83.53711020561957, 74.31531198563115, 65.50743756755706, 67.75649716777187, 69.0814345882785, 74.16260627008255, 77.84659047280589, 78.48909039651194, 69.34241341006371, 65.54100128912157, 58.34942187032392, 61.86279473766204, 62.71102689927625, 70.48239538746496, 74.78271730484502, 77.96252789035921, 76.00717144627725, 67.44633966876616, 64.3470710323703, 64.05127333056542, 62.11892158754411, 67.24987599157518, 66.08501049780077, 65.17385959625244, 66.09105094786614, 67.13062809359643, 68.63499041526549, 78.41957815231817, 84.74339592841365, 81.98225129035212, 71.94165045215239, 73.86539259264546, 83.45206537554341, 89.12640925376647, 90.5936816430861, 88.97153838988274, 82.77889251708984, 80.76761876383136, 74.46792356429562, 78.2374938841789, 84.93931831852083, 92.37438278813516, 87.6146101182507, 102.33395530331521, 56.23554283572782, 0.9320231815499644, 3.871342097559283, 5.248191106703974, 0.8257003513074691, 0.9304441824074715, 7.433665654351635, 6.858823674340402, 0.5716412646635887, 0.2077238979719339, 2.2875811976771203, 41.12289767111502, 46.45318692730319, 100.31950443021714, 44.446463123444595, 30.31059599691822, 77.71415556630781, 74.88776622279998, 92.3749319199593, 104.73190415290095, 64.5917720179404, 0.7289963371811375, 0.15407532753963626, 0.13495464628982928, 0.15241184422085363, 0.2230288178449677, 0.1442394480710068, 0.14228803826676262, 0.07286261481743667, 0.16982586543646552, 0.14147829865255665, 0.18456999362716753, 0.12304981614673331, 0.17487504369308873, 0.20840157934975242, 0.24927649166314836, 0.1706134651096598, 0.17995776127903693, 0.1225171552129811, 0.16619293860370116, 0.09474662117539875], [0.0367444496782076, 0.10265295498914297, 0.0008625188227949454, 0.04347197335934447, 0.05941851868204052, 0.14315172579259644, 0.013059833135846402, 0.009131502799479472, 0.024481965642001842, 0.06713258357898844, 0.019669996935033032, 0.026396438516976855, 0.07113955284078276, 0.054370052887186895, 0.18539349218049359, 0.1436415317678644, 0.22803886433041867, 37.432355265463556, 99.04311026296308, 84.70085390152471, 71.68211506259057, 53.94106611128777, 21.704327483331006, 48.55710706403179, 112.37954539637413, 53.62774325955299, 10.46531213868049, 0.12518327908530352, 0.11631335988039933, 1.1281234266296511, 0.8471090154301736, 0.5797282113663612, 0.4281297993035086, 0.6468297300800201, 1.3580348703169054, 12.527518849219046, 123.18169793775006, 93.96294270792316, 100.67451030977311, 80.9527938596664, 88.41962952767649, 87.87225492538946, 104.63970491963049, 102.29452763834308, 87.3478340333508, 92.94416196884649, 90.96712266245197, 88.67425410978257, 85.37117911923318, 71.56169829830047, 66.87780780176963, 65.39689340899068, 64.38381187377438, 64.1755340176244, 65.63050977645382, 66.29859139842372, 65.11804426870039, 65.15615401729461, 62.03863459248697, 63.61658450095885, 59.769837625565074, 54.37834762757825, 59.07516625619704, 62.08434197210497, 63.666088734903646, 77.74253783687469, 74.80634566276305, 72.86839669750583, 73.44486744173112, 68.89099567167221, 67.9780875482867, 62.12429131231001, 59.99751160221716, 61.43361683814757, 66.54055456961355, 71.40116353188792, 73.4004819008612, 76.79148074119323, 77.6755202201105, 71.50724795556837, 78.42450464925459, 76.9808292388916, 73.68263367683657, 79.62555008549845, 76.74183137955205, 77.9827045625256, 73.38954633282077, 81.07707808094641, 51.82377069227157, 61.53042877874067, 77.03260452516618, 73.53387386568131, 65.57131336581323, 60.04653338463076, 70.47073025857249, 69.75651371863582, 76.8935957262593, 71.90179132646131, 70.07625749034267, 63.7249517440796, 58.620139937247004, 54.65103472432783, 54.74867036265712, 54.88283111203102, 60.79796537276238, 65.80574558627221, 73.11682393473964, 66.68324255174207, 59.854737327944854, 55.573611490188114, 57.45985577183386, 53.69101893517279, 56.74236013043312, 58.13158912043418, 57.33565784269764, 59.116849284018244, 59.40986602537094, 59.45507526397706, 56.8317509466602, 58.93809903052546, 59.44102141164965, 57.9046094033026, 62.16380919179609, 71.27363943284558, 80.99376693848642, 78.3045821036062, 74.63813874029344, 73.41163712163126, 66.88657822147493, 67.23349617373559, 64.3548765490132, 70.6873784526702, 78.31113246179397, 88.04613359512823, 76.92218196007514, 94.79606197726343, 33.90893328574396, 0.8906892446740982, 1.2593569846883899, 2.4361694051373393, 0.8056973053082344, 1.3329833048966624, 0.8687299165514208, 1.0008504818524084, 0.14545981081262713, 0.39233486198129197, 8.668514567036784, 28.34359403579466, 50.605102046843506, 63.58322082027313, 22.71284337966673, 28.762299206949052, 59.95736222113333, 62.85523283866144, 71.79016067135719, 78.48340295976209, 7.169015003788856, 0.6821205202610262, 0.14387316611264983, 0.03761937188345098, 0.07182088845800008, 0.036570003796969695, 0.03421061003821031, 0.06086594222353832, 0.09212618678688042, 0.06268596411832879, 0.07731444367598142, 0.04844828516304974, 0.09259861022714647, 0.06181160498770976, 0.03479180264196569, 0.040544425813300956, 0.033649297416090004, 0.03183049743153876, 0.07435109301079666, 0.08522081579412184, 0.03485455673428313, 0.015905996288863883, 0.04697036366128633, 0.046120323991823586, 0.053607607710986376, 0.04436014122479866, 0.030191084595337033, 0.03312015282591024, 0.042848898728768674, 0.051020915665092974, 0.05393940422143187, 0.09047686077293851, 0.08326356839989463, 0.16604384257187768, 0.05259116225305104, 0.10451564415087623, 0.15083413210607347, 60.423006396139826, 112.3565681519047, 95.14320742699408, 86.84071079377206, 71.25076417000064, 39.5587819622409, 43.57249629112982, 73.19851906068864, 57.91662754551057, 11.039544190129927, 0.07860811337107614, 0.4257711678022339, 2.564843494084574, 2.4055741823488668, 1.8272497504949572, 1.9552301927920313, 0.4871777114608596, 1.1096035881388573, 18.632844917235836, 131.92231547447943, 95.2014938477547, 106.6973332435854, 83.39361421523556, 93.84263576999788, 89.9993327356154, 107.04704392340876, 104.8675318687193, 94.51889945614724, 95.41931090816375, 96.99926514779368, 92.17750333970594, 87.47430693718695, 74.33897172251056, 70.82631664891397, 67.64358781999158, 69.21901564444266, 67.17279357294883, 67.94415904629615, 68.53760580862722, 69.89342797187068, 67.40659821418025, 66.01378810021185, 67.61282859310028, 63.88100716375536, 60.32560610002088, 62.977975568463734, 62.47515909133419, 67.93577301886775, 80.21448612213135, 76.44988936762657, 74.698927633224, 74.39009589533653, 72.38902814926641, 71.43739054279943, 66.09692665838426, 63.43889720978276, 63.66549645700763, 70.4603281328755, 73.9197801774548, 75.78660088200724, 78.05692365092617, 79.48373286954819, 74.73706876077961, 80.43456246775966, 79.33240782830023, 79.92998092405259, 81.8024576863935, 77.54721949177404, 81.84126561687839, 75.7135114362163, 84.83420664264311, 54.63282708198794, 62.68257010367609, 81.45019746595814, 76.79096298833048, 67.25106839210757, 62.79147863388062, 73.78798853966498, 72.24224521267799, 80.01254681617984, 78.12214482215144, 75.3721946285617, 66.64161835947345, 63.23488689238026, 59.830720655379764, 57.632871520134714, 56.21353049432078, 64.46669155551542, 68.53564462354107, 74.71191067849436, 70.65888635573849, 63.49054305784164, 60.80783013374575, 59.96137872818978, 55.79042834620322, 60.18242782162082, 58.97501245621712, 60.66769561459942, 62.257024318941184, 63.14717092821675, 61.98443528144591, 60.42057060426282, 62.68306824468798, 61.516155273683616, 62.04200783083516, 64.51857274578464, 72.55545431567778, 82.9745089623236, 79.17227314364526, 77.08154786017634, 74.91613280388617, 69.36447281991282, 70.00236788103658, 67.62610189376339, 72.84928691002631, 82.9951092504686, 89.76607722620811, 82.94294957191714, 99.62031056804042, 50.75362651578842, 0.44410077133967035, 0.7645942979762632, 1.1459762170430154, 1.3631074755422532, 5.242201157154576, 0.6005015740952184, 1.5375515794561756, 0.1890218071639538, 0.5069077850109147, 7.841647065454914, 37.06162460388676, 44.68346841873662, 40.90668093773627, 29.944856551385698, 42.75574115014846, 70.69343459221625, 73.06774723914363, 77.07055737895351, 91.15043855482533, 16.496857443163474, 0.7915159146631918, 0.2090353945330266, 0.21050254483857464, 0.05652700791195516, 0.11459802007002216, 0.07697473730771773, 0.06669528527005066, 0.02039417027375631, 0.0296586170987857, 0.01863907816098823, 0.10518653798968562, 0.020421004418524045, 0.02479558480122397, 0.040322248823940754, 0.0556555790676465, 0.027834965862453948, 0.10516176270621438, 0.0952701043758181, 0.11620853606972004, 0.14809483151522376, 0.24236173609331732, 0.10732301165379825, 0.200563074960824, 0.24463413673783505, 0.28327841552034505, 0.12248471905026706, 0.2189706662489522, 0.20180263586582678, 0.12863678046532218, 0.08576757274568082, 0.18796359459238668, 0.2065344238954206, 0.294418498393028, 0.28251520808665986, 0.3073002668398042, 0.31849605962634087, 68.69149607996788, 129.70548598997055, 110.49752942977413, 98.47129144976216, 79.30683397477674, 37.604559083138746, 61.569942735856586, 152.43825697129773, 74.45079849612328, 20.061099529266357, 0.43305056590226393, 0.729660198332802, 4.425263625960197, 5.066287757888918, 4.186029934114026, 2.678645916523472, 3.2036720793093405, 3.5372348514295395, 16.359425437065862, 133.22422858207457, 99.15289740408622, 111.32005829964916, 87.23898041632869, 98.93548827017509, 96.15273137246409, 112.20442725766091, 106.41607576800932, 102.56339042417466, 99.60685683834939, 101.93506594627135, 97.18525609662457, 94.39716477547923, 78.77063028274044, 75.14891762887278, 72.71500064480689, 71.2442373460339, 72.13521157541584, 72.61690216679727, 71.98841294934674, 74.08074640458631, 71.27551432578795, 68.82734344851586, 71.29247465441304, 68.25255147872433, 61.528655867422785, 66.19994378858998, 68.38334683449038, 70.86912539697462, 82.38077978934012, 80.04645178394934, 76.29305731865668, 78.2045381299911, 73.9384114357733, 76.23805784410047, 68.20476916528517, 66.1004646362797, 66.9355764696675, 74.3077810349003, 77.3877751442694, 82.43068018267232, 82.63040727184665, 83.48533491934501, 80.26466892611596, 83.66118261891027, 83.22135940674814, 83.71939843700778, 86.7747365274737, 83.0667160403344, 85.39432110324984, 79.24442906533518, 87.23886274522351, 58.3548229740512, 65.26479190395725, 84.59422034602012, 82.00515793215844, 70.09033879926129, 66.2086671398532, 76.95003078829858, 76.96234703063965, 82.8713192478303, 82.13817334944203, 79.00989486325172, 70.75402736663818, 67.40979886824086, 63.26066470915272, 62.833338168359575, 60.474460048060266, 67.89051671181956, 72.05167293548584, 78.66438896425309, 73.31856712218254, 66.76361191657283, 62.896605999239036, 64.53519967294508, 61.063360783361624, 64.49224187481788, 61.88170448426278, 62.709093170781294, 65.03268172664028, 67.84753537947132, 66.62971788837065, 63.07669378096058, 65.40251808781778, 65.84012123846239, 64.70763883283063, 69.48929048353627, 77.55676654077347, 87.47185153345909, 82.88503969869306, 83.05265826563682, 82.44854265643706, 74.38153728362053, 74.86694628192534, 71.58091791214483, 77.41595345158731, 86.94444179534914, 95.93784824494394, 85.45525120150658, 104.71253548899006, 48.06227653257309, 1.0643231339993016, 3.2563752512778006, 6.1090935045673005, 1.8710739021339726, 3.7900257254800493, 6.100657957215463, 2.2995336401847104, 0.380614513471242, 0.41974331222234235, 13.506782689402181, 49.56723505450834, 67.70980527324062, 89.1113159733434, 30.68575305323447, 43.68195395315848, 76.88849664503529, 88.64810759021391, 88.598419004871, 110.86289821132537, 16.27494837007215, 0.9978176929777669, 0.24153514254477718, 0.2931484165451219, 0.16115609436265885, 0.3891706124188439, 0.13833948320919467, 0.24766833521425727, 0.2027579781509215, 0.16341015486226929, 0.15507563918588624, 0.2016824213487487, 0.13720047900513296, 0.19903921882712072, 0.12340796991221367, 0.1203805972791968, 0.18388923257589343, 0.15308353479110426, 0.20194958685146225, 0.22736420133902183], [0.08501211812178935, 0.028498532070267587, 0.04952879089321341, 0.017805687497339902, 0.09892639689027302, 0.06983451440089172, 0.03749476768256676, 0.09138678170500264, 0.005312216460644718, 0.015323677535859809, 0.029078339970099832, 0.014045985562035875, 0.028146401671091878, 0.06134124232396003, 0.1424727727088236, 0.09432912623930363, 2.813432283939854, 83.61529873263451, 77.97562076199439, 89.45806918605682, 58.027387434436434, 47.719280950484745, 34.05133101247972, 48.462876043012066, 62.69763984987813, 33.78690442731304, 1.973707375507201, 0.1300585630439943, 0.36259563519589366, 0.8423264204494415, 0.8479993321722554, 0.885687425972954, 0.49461774287685273, 1.0110694206049367, 0.27423364440760306, 81.66725358655377, 110.03683920829528, 100.39687710423624, 94.41346614591538, 81.46899346382388, 85.36916302096459, 89.93753187118038, 103.10245744643673, 85.14071633738857, 94.33826646497174, 89.89859842484998, 87.89950755334671, 79.69057513821511, 68.47554606776085, 66.02825380140736, 66.193707220016, 65.83160185044812, 66.09018018168788, 63.026762008667, 64.50809217268421, 64.3237917653976, 65.00571935407578, 63.39682978968467, 63.867937826341205, 60.05311512177991, 57.716606278573316, 56.798210759316724, 58.318752857946585, 59.846982802114184, 69.17767386282645, 77.19152327506774, 71.70555514674034, 72.58181264323574, 69.12159181410267, 67.93427467346191, 64.61405500288933, 63.95619899995866, 60.859189648782056, 59.68368668710033, 63.42665157010479, 67.05661296844482, 71.59874900694817, 74.52620214031589, 77.03296538322203, 71.32797210447251, 73.53994569470807, 78.49086330782983, 71.92500391314107, 77.2698373179282, 72.59183822139617, 74.55468639250725, 70.91867277699133, 78.24749592811831, 53.429867529099994, 69.96152031806209, 78.94595238470262, 69.69343416152462, 60.394498609727435, 64.7248423484064, 73.20374365775817, 71.27309030102145, 73.90520464989447, 74.62907022045505, 65.08917954660231, 56.28396057313489, 56.934167954229544, 52.57200594871275, 56.6259402613486, 54.27216122227331, 59.292971549495576, 65.767522088943, 72.23654208644744, 70.50032846389279, 63.187834139793154, 56.60109596867716, 57.123406625563106, 54.46617341810658, 54.42871478296096, 55.35923827079035, 58.028419017791755, 55.27745685269756, 58.91854209284629, 56.93722740296395, 59.27808223232147, 56.37649713024017, 59.59229546208536, 56.94007504370905, 59.350610779177764, 60.731116417915594, 64.93345360602102, 64.8216385995188, 66.78161559566375, 60.71938853110037, 62.491178051117934, 61.36961944641606, 61.60804856208063, 59.53296176848873, 70.27358408897155, 72.8281924032396, 87.06503114392682, 75.83403802687123, 98.05154292814194, 22.202988209262973, 1.0486160026442621, 1.296955109123261, 4.4091907335865885, 0.08680497070834522, 1.5101299218593107, 0.6217101973391349, 0.5308793196755072, 0.0952540701555629, 0.14102492781896747, 21.86404247437754, 35.144526958465576, 64.66039388410508, 33.96103805111301, 29.459037665397894, 46.11160339847688, 67.39443102190572, 69.45831944865566, 64.91985082626343, 39.56026461816604, 0.5884497853056078, 0.0861319777886233, 0.04552888113164133, 0.028762849641122648, 0.0668675554615836, 0.11994732859274072, 0.009991351267202728, 0.07416011495215279, 0.1554880549590434, 0.02701691610948934, 0.04514382618869986, 0.08476727642118932, 0.0947756942121252, 0.0360516457247638, 0.05950733125510235, 0.010330115347319554, 0.036942153988826665, 0.04254421406996347, 0.03166896970792404, 0.019429146552518494, 0.0555723742581904, 0.06651688637512346, 0.04308655835507859, 0.0700393816336028, 0.052780251904961564, 0.07524029892538825, 0.0334536079167118, 0.0798144183992859, 0.07112713455553017, 0.07564473972325364, 0.016090338110863682, 0.011712581336107707, 0.031231204085352442, 0.13275651020869134, 0.10007923664224726, 6.669830641438884, 103.48880306366952, 89.21237976320329, 99.66393516909693, 72.1666846736785, 59.52956499591951, 47.67757046607233, 40.220576024824574, 62.28009962266492, 41.934640023016165, 1.8765373960618053, 0.2203572700701414, 1.682493821267159, 3.4813119038458797, 1.6474394764631026, 1.534891477034938, 0.5440826305458623, 0.5123460593242799, 1.1644486193695378, 95.86002057598483, 109.59590988774454, 107.02529830317344, 96.95170248708418, 85.72147815458237, 88.14147856927688, 94.98028785951676, 104.8333994034798, 93.92462899607997, 99.58210668256207, 93.6836228832122, 91.61429805140342, 83.79090324524911, 70.94540765208583, 69.14324329745385, 70.40718001704063, 69.60980922945085, 68.36793191971319, 66.59977451447519, 66.00409984588623, 65.248306182123, 70.30930903650099, 66.57049794350901, 68.05320093708654, 64.29652737032983, 61.12004687709194, 61.41014145266626, 62.245257208424235, 64.13566312482281, 73.37690061138522, 81.30741534694549, 72.99264169508412, 73.90551843950826, 70.43793139919158, 71.23907550688713, 67.92915990275722, 66.17287158966064, 62.706861342153246, 62.05636370566584, 65.79788123407673, 71.85500529504591, 77.50039423665693, 77.29854906758955, 78.56561583857383, 74.38662067536386, 75.66205778429585, 83.32774193056169, 75.25087571913197, 79.52439215875442, 75.4464372511833, 77.72068239027455, 74.36072518748622, 81.08068666150494, 56.499102577086425, 73.3044465895622, 81.31217710433468, 71.52776195156959, 64.2809045699335, 68.88755967540126, 75.38403234174176, 75.54928964184177, 78.37791473634782, 76.12588590191257, 67.43983637902045, 58.93515725289622, 60.157744346126435, 56.23063202827208, 59.154555028484715, 57.5673875501079, 62.88322287221109, 69.84296275723365, 74.4683942487163, 72.05102966677758, 65.68459533875989, 59.962861384114916, 59.20221574844853, 57.75321768176172, 56.725144847746826, 57.234107678936375, 58.33146918204523, 56.938655145706676, 59.86896768693001, 58.9804841626075, 61.603106375663515, 60.18677773014192, 61.53513170057728, 59.055409277639086, 61.136383548859634, 63.11159110838368, 67.35217140566918, 66.87923554451235, 67.78804871343797, 63.63765547352453, 65.2315027483048, 63.47126853081488, 64.02267925200924, 62.62467984230288, 71.75301582582536, 77.36320541751, 91.44497717580488, 79.71051646817116, 99.42552566528322, 39.416952979180124, 1.25535543166822, 0.3039649345221058, 1.1097088792631704, 1.791609624220479, 4.179851710796356, 1.782270951136466, 2.09876736806285, 0.28569177634293036, 0.12956066718024592, 23.57202091524678, 44.76260223696309, 53.933813648839156, 21.117644848362094, 41.190119251128166, 50.8554002546495, 77.1461885206161, 75.38580525305964, 74.55389407373245, 69.6801059476791, 1.975010582996953, 0.1258334808892781, 0.05670845966726061, 0.039153723421716885, 0.011310380387810931, 0.09714928741056113, 0.033929210621863604, 0.08980959819089021, 0.07065726984893123, 0.04310219420961315, 0.024907581110094345, 0.05632551912699015, 0.04488896405805023, 0.011542459063592457, 0.016279389458377997, 0.08400141832328613, 0.08392931412785284, 0.052428311112547116, 0.015592019941147058, 0.11372651844736069, 0.1737769332624251, 0.18508278224016392, 0.13395845619661195, 0.18657781814615573, 0.16394638576574866, 0.15944572646291028, 0.2153979079617608, 0.2052129069042783, 0.17509740837399038, 0.13368914564771037, 0.05887142082135524, 0.08603633171127689, 0.10347796273567986, 0.31304347479055006, 0.18626074967605455, 6.899163290377587, 123.67927412832938, 103.12675260728406, 116.05551227446526, 80.32178648056524, 69.74040062196794, 49.425347235894975, 69.63116261266893, 81.43712028380364, 55.945024644174886, 3.3693762844608677, 0.26019070117223647, 2.956120756364638, 6.236373436066413, 4.7763942037859275, 2.9047242239598305, 1.7691696218905912, 4.322360734785757, 0.9268067356559538, 95.12935361554547, 117.14788452271493, 111.03204650263633, 104.24593817803168, 90.71333746756278, 93.95487831484888, 97.5233094922958, 105.24692704600673, 97.89791153323267, 104.26443607576432, 98.28746564926641, 97.20098480101555, 88.38555982035976, 73.02356566152265, 72.86433312200731, 73.95752906799316, 73.40826388328307, 73.28797263483848, 69.66244743716332, 70.32528092784267, 71.2696699942312, 72.39983035672095, 69.75803559826267, 69.76436630372079, 66.71459013415922, 65.32615346293296, 64.75546821471184, 66.09134904799923, 67.82246358932989, 76.13232643373551, 83.37905437715592, 74.28790246286701, 76.57925698064989, 74.08830873427853, 75.49944416169198, 73.43503013733896, 70.36744640719506, 65.8374854057066, 66.55294925935807, 72.40507064327117, 75.64275972304806, 80.47795172660582, 81.89006774656235, 82.61275660607123, 78.32722202424081, 81.04776228627851, 88.880994396825, 80.30754827683973, 83.54088352572533, 78.5271530766641, 82.25345965354674, 78.67186500180152, 85.5628575048139, 61.34009184375886, 77.47337695091002, 84.7712133776757, 75.48535500803303, 66.34511855340773, 72.77077674865723, 79.85350255043276, 76.37752948268768, 81.63327017138081, 81.12164405084427, 72.97460663703181, 61.43711951471145, 62.651967771591686, 60.22996694810929, 63.272816211946555, 60.91773494597405, 66.75718707423057, 73.73591515325731, 78.19353980402794, 76.15519385184012, 70.45245985830985, 63.61505085422147, 64.46594630518268, 61.07163306205504, 59.57386424464565, 61.4204494414791, 62.60616625508955, 57.685729380576845, 64.27737443677842, 62.821480843328665, 64.55041846921368, 62.92929503225512, 66.88475824171498, 62.81258883014802, 64.34318396352953, 66.38969236804594, 74.2074546506328, 73.11967157548474, 72.87375465516122, 67.26143913884317, 69.77686297508978, 68.21066841002434, 67.50389652867472, 66.5523373696112, 76.65673948103382, 82.09057930977114, 97.04072460051506, 84.51694180888515, 105.38340983852264, 33.69596427486789, 2.0570252595409273, 8.087072708914357, 8.78670342506901, 2.128891170986237, 5.5212719113596025, 3.9309042692184453, 1.704375743865967, 0.5446774212102736, 0.33141604053878015, 37.06316609536448, 52.969938247434555, 87.83859314457064, 46.99656071201448, 41.97490707520516, 61.24799066974271, 87.53660202026369, 87.78939877786945, 85.30030973495977, 79.4467527635636, 1.85297008002958, 0.2183836130725761, 0.09547095730780594, 0.17486149925858746, 0.13827361496946505, 0.36554427697293224, 0.10096979087158557, 0.21002073682123618, 0.22005737729130254, 0.11881140406213461, 0.11512615342414188, 0.14792927991478674, 0.19755518394372157, 0.09611124593404033, 0.12399537548903497, 0.15618046054676657, 0.13451459006436411, 0.19893846294331938, 0.06933530852679284], [0.06097575326660468, 0.06466270845022894, 0.08619752427142474, 0.014802311610941206, 0.020511197865069396, 0.024046287609023914, 0.035595099456728466, 0.10664259534209006, 0.08108803957340219, 0.0037912678700165767, 0.12618327663550455, 0.09094483324236448, 0.15916009824122154, 0.02003122079786995, 0.11233415364498094, 0.4335421798450332, 29.177935123443607, 95.92149980606573, 80.15578393013247, 72.24919565262334, 48.622791074937396, 45.1600952302256, 27.290506286005822, 66.29376688311177, 54.60209923405802, 17.566638800405688, 0.11211201879045657, 0.04917803753708159, 1.139335766915352, 2.8230462583803364, 0.522001892808945, 0.4742648704878746, 0.4914314299821854, 0.6424134477011619, 48.32926834783247, 117.92181522615495, 94.55069418876403, 107.03897168559413, 84.13053343372961, 79.9448702412267, 76.06380262682515, 91.62673196484967, 83.37648914706323, 92.45372449198078, 88.34715981637278, 87.61050731905046, 70.90125745342624, 67.33619951432752, 63.93814040768532, 63.51499119112569, 61.931871598766705, 64.98233418310842, 63.82195195844097, 65.4113002746336, 64.77591553042012, 63.64586499429519, 63.04837426831646, 66.9660532859064, 61.54909141602055, 59.516248549184496, 60.0115458426937, 62.45224460478752, 58.60847088598437, 67.5528790873866, 71.83891573259908, 74.24929065089073, 70.96090885900682, 69.02106931132656, 65.91582298278809, 68.64514935401179, 65.8057338191617, 65.41055502430086, 62.3053361523536, 58.572569431797156, 56.61378091381442, 65.04661790786251, 68.20896610136955, 73.17623215336954, 69.05129509587442, 72.07276744227256, 64.3611954873608, 70.31897375660559, 67.22383929837135, 69.97608015614172, 68.06227730166528, 69.96832955268123, 70.03932445280014, 77.16807534617763, 53.566985745583814, 72.31718601719027, 76.06577165665166, 61.67384239935107, 59.737481994013635, 67.60778442505868, 71.66939873849192, 73.65265892397973, 72.44016801157306, 72.67980913962089, 63.04200433915662, 57.395983895947865, 54.33818647938391, 54.906180981666814, 53.188065175087225, 55.326333507414795, 57.65133411653581, 65.11350216404085, 68.97320070574361, 73.40727544599964, 65.35036625400667, 61.02672584595219, 54.884819753708385, 55.06731587071573, 53.28068410196612, 53.77091761558287, 54.90924043040122, 56.90680549990747, 56.268569192578724, 60.025015261865434, 56.08825391338718, 57.38928841006372, 54.83402505997689, 59.31428963138212, 56.10648116757793, 58.860067398317405, 54.81830812269642, 55.97951796747024, 55.07724731199203, 59.17391584765527, 57.37993747957292, 59.34692375121578, 56.713185541091434, 63.805450547126036, 59.32933192099295, 69.9511181923651, 70.29214474462694, 85.81142594737392, 77.82194229864305, 96.55034203683176, 16.347091544059015, 0.7242704939938361, 2.80295955557977, 6.263923673860489, 0.2253869437282124, 1.111373312530979, 1.6822152104108565, 1.1241161126282908, 0.5053764978243459, 5.427657683049479, 25.955127516100486, 37.52378963655041, 75.63757434968026, 14.863265772019664, 25.55675002836412, 46.066845232440585, 66.85563072081536, 67.17145996709024, 67.9071867850519, 13.07538276718509, 0.8017737093952395, 0.1383240541983997, 0.05537268577984745, 0.056328357482749614, 0.021663585625168298, 0.053407314023183244, 0.07422990556205473, 0.07484849857827348, 0.03286332567973483, 0.11181866840249109, 0.05378735875109992, 0.09514445063447761, 0.06629984600529557, 0.04690607739312034, 0.06369583271143418, 0.013768021092419664, 0.08327189577563156, 0.04102541794700008, 0.04444449133570156, 0.043820815326105204, 0.04169459957929869, 0.022203882540305777, 0.05595118175410936, 0.02548632223249203, 0.015360428688807354, 0.020343928312462185, 0.06088722414607483, 0.0320492097882614, 0.12465024276846841, 0.03049440561763702, 0.06578198589024044, 0.02732321721381478, 0.1576176721362337, 0.3387040494670791, 44.580549347785215, 111.21275009647493, 90.70121734373032, 83.68088860665598, 58.911234717215265, 58.369276908136186, 33.28167569252753, 48.03551420088738, 59.25852921701247, 21.00729484711924, 0.025432182798883127, 0.7321240596713559, 5.13124809149773, 4.8285808486323205, 2.6602958431166988, 1.042130853860609, 0.3210388893081296, 0.4390057350598997, 62.169488783805605, 123.979868888855, 100.75254194198116, 107.97448835065289, 87.8892230987549, 84.22598823424309, 81.74308084672498, 94.77502238365912, 89.04625169692501, 96.79497241973878, 92.47707828398674, 90.16385263012302, 73.77190682195848, 70.3904079621838, 67.9561536542831, 68.96388115421419, 65.81646934632333, 68.65510432950913, 66.61059241141042, 67.89947540529313, 67.92126809397053, 67.29113932578795, 65.32953454602149, 68.85793009111958, 64.96797046353741, 62.09123357649773, 62.25227432866251, 65.25626859357281, 63.389863660258634, 67.59127909137358, 74.82816973040181, 75.79889359012728, 70.85647183079874, 68.93898194836032, 67.79778403620567, 69.9374604994251, 68.01973527477634, 67.45614559419694, 63.28879594802857, 61.570280059691406, 57.77146454780333, 66.79380632215931, 72.32690565047726, 74.58856782605572, 72.9824984458185, 73.935650087172, 68.19294714158582, 73.04871589906755, 70.66167908330118, 72.93730489669308, 71.77661280478202, 70.51092670809838, 75.68731000346523, 79.34662249780472, 60.055762721646225, 74.52281321248701, 77.7084759742983, 65.99044215294623, 61.06236450133785, 72.641707235767, 76.23325686300956, 77.19157818825015, 73.76407777109455, 74.3318957667197, 67.46266457342333, 58.89092076209284, 56.50904970784342, 57.68720026939147, 55.64623809629872, 58.0570327081988, 59.134103790406265, 68.1128288084461, 71.41480553534724, 73.58025197059878, 69.09873224073841, 64.5635780211418, 55.78418785525907, 58.00655180408109, 55.168109017033736, 56.88576982867334, 58.72714611791796, 59.53909635543824, 59.002123878848174, 61.802174506648896, 58.80613873081823, 60.52452518093971, 57.390441586894376, 60.79300749686457, 58.88159336582307, 60.75039094494235, 59.3551254272461, 60.25455236434937, 57.51752638047742, 62.53341021076326, 60.5337074495131, 62.53108424525108, 61.140235316368845, 66.80467913227697, 61.35379268277077, 72.56378542992377, 73.29096932565012, 90.07620334625246, 82.01115131378174, 101.57258402916693, 35.88321516590734, 1.0467788625148036, 0.7844399588723338, 0.7103420349378741, 2.2962177665002885, 4.776223580683432, 2.4978202389132593, 2.848686056752359, 0.5787582827671882, 3.968067255712325, 34.10534989449286, 37.948213623416045, 45.90698511369767, 18.000476475684874, 47.75938718549667, 56.191694659571496, 75.21380932100358, 75.02580227390413, 80.19840440442486, 33.04474884463895, 1.0076217797975386, 0.08328732478642657, 0.019009230778582634, 0.018965385651456255, 0.02789312534244551, 0.03789266225911918, 0.016580607569325837, 0.07041740771983901, 0.049166710927121104, 0.036825180023668275, 0.022439224750644738, 0.04076842226148133, 0.00760383106910834, 0.09040159263437794, 0.013625985518428347, 0.0850333694008089, 0.09935577385007374, 0.03613060640711938, 0.21337109978400895, 0.11961578872174987, 0.14762656793238657, 0.16681564551207329, 0.2095248481078494, 0.1050154016082806, 0.12995737815095534, 0.17941837409330955, 0.2462187896092092, 0.14897943324139043, 0.23587641877032098, 0.18718641371496264, 0.27404549321339977, 0.1908909084816133, 0.30274391294487063, 0.5610839601966643, 52.804920211915054, 128.4035728823754, 103.64996540930964, 98.53695192644673, 70.02026173376268, 61.01969303623323, 38.83248452217349, 90.27032929082071, 78.42469292302286, 32.455973625183105, 0.29399825320128475, 0.7604550329908248, 5.989230284767767, 10.158493557283956, 3.655859337699029, 4.596818781668141, 4.895050804461203, 1.3711338706554905, 57.246851459626235, 128.34838513405094, 103.6550017326109, 113.12467021326866, 91.52014547778715, 86.06177514599216, 87.78671587667158, 96.88215886392902, 93.92277763735865, 102.23697077843451, 95.34032221763366, 97.49854364702779, 77.50931370642878, 76.23204092825614, 73.46888803666639, 71.46243095397949, 69.38362183109408, 72.50487142993559, 70.2342740951046, 72.61551364775627, 72.17884402121268, 70.62436165348177, 69.50612529631584, 73.71253782703032, 68.22188638871717, 67.86565672966742, 65.80195657668575, 69.5385632976409, 66.98761063237345, 72.10955142974854, 77.11116959971767, 77.99170247970089, 72.98132957950716, 72.2440730371783, 70.18023952361077, 74.33007578695975, 72.67682813828992, 72.46262750317975, 68.01922536665394, 64.05407390286847, 62.638223786507886, 70.26870466047718, 76.69373527649911, 81.07809789719121, 77.06090834832962, 78.9981512869558, 72.81403264691754, 78.43314955311438, 74.78746337275352, 78.7574040505194, 76.48497104644775, 74.31920297684209, 80.017057541878, 81.38629421111077, 65.80843633221042, 78.30995575074228, 85.50672838764807, 69.17788567081575, 65.17880570503974, 75.5335295584894, 79.13254737854004, 80.83666816834481, 78.60867561832552, 77.80459757774108, 70.63699953017696, 61.81949961570002, 59.78655476723949, 62.02847565374067, 59.75561903369043, 62.16336596396662, 64.16781871549546, 71.25485127972019, 74.69880996211883, 76.50968197853335, 72.38320735193068, 68.20862877753474, 61.347183489030414, 60.88569702640657, 58.871230463827814, 60.19920772121799, 62.19183060430712, 62.006718266394834, 63.175208030208466, 65.63569514982163, 62.777569909249586, 64.33899094981533, 59.93446734643752, 65.61099206247638, 63.04936270559988, 64.56128343459099, 61.166605411037324, 63.461850920031154, 62.31065880867743, 66.61838223857265, 64.45696799985825, 65.93286960355698, 65.13856610944195, 71.441022657579, 65.3490444152586, 75.35205718009703, 78.21679945914977, 93.08268439385199, 86.42335491795694, 107.80155104975547, 32.725554204756214, 1.7487197321268821, 10.400993112594852, 12.831039697893205, 1.701296438132563, 7.059991253960518, 4.3413229430875475, 3.8546457934764127, 0.5492311704062647, 8.308635142541702, 44.379680848890736, 53.21656511675928, 100.80469377579229, 22.298847013904204, 43.80071547723586, 63.70080563329882, 91.11621979744204, 84.72070109459662, 101.4665388291882, 34.37812328338623, 1.461286975010749, 0.128179686444421, 0.18694894178019417, 0.12899370082924444, 0.21452824495011763, 0.13880601543332302, 0.15534657384118727, 0.27552015118060574, 0.1850808823421117, 0.1781111523028343, 0.2375701472403542, 0.1089097559452057, 0.22882888484145367, 0.2793577613849794, 0.16284662058516858, 0.09564639144246617, 0.1794017959506281, 0.15217268689265176], [0.025815740039932634, 0.029252148083140774, 0.04514441224596193, 0.01209605239226573, 0.01700764987617731, 0.08774160512632902, 0.03813471923011445, 0.01575293479442236, 0.008368843118660152, 0.025090848493780342, 0.04518300009470794, 0.023890135907417825, 0.038408220279961824, 0.05885958859336473, 0.1556562572236984, 0.7896820840335662, 65.61722078631001, 83.92491494455646, 82.7335185389365, 61.86923919185516, 47.69123600375268, 20.398378256828558, 51.452228100069114, 58.02923879315777, 36.763285206210234, 6.778999028667328, 0.16332194749866763, 0.6036915642119224, 3.3873098511849684, 2.7445015311241154, 1.3784477427121133, 0.3003856491657996, 2.0639445656730286, 21.002260485003074, 120.27655524592247, 95.07597800224059, 102.18760382744574, 91.7490000878611, 83.9586865517401, 70.12497332788283, 83.28378000567037, 79.3679052783597, 86.4842850162137, 86.00356717263499, 82.46736218852382, 75.06239798761185, 64.24041002027451, 66.35854874887775, 64.89859157992949, 64.32859274648851, 63.81100854566021, 62.903360320675766, 64.87445723625922, 62.877637417085715, 61.77137997842605, 64.06424460872528, 60.717615619782485, 60.941861444903964, 57.51691841310071, 55.29640582300002, 59.417769601268155, 58.96410042239774, 63.47554783667288, 65.4706653471916, 70.44326582262593, 73.48971582228138, 69.72301667736423, 64.8505582347993, 65.30720057026033, 63.5804908506332, 63.189897306503795, 61.40419121711486, 57.96096209556826, 55.53024576556299, 55.895547866821296, 56.18810569086383, 68.07003574986612, 68.20946816475161, 68.85429013159968, 65.8200308584398, 66.10429286956787, 63.51573251908826, 63.126166635944, 65.88283584963891, 66.91470161561044, 69.56583161507884, 73.5832094377087, 74.85607347180768, 52.40750566605599, 75.06169980572116, 73.8316680539039, 60.1996313371966, 59.57307192587084, 69.07023229906636, 69.13414339865409, 70.51960299091955, 69.99929274282148, 71.85735087240897, 70.86060600896036, 61.5179281850015, 56.08682617064446, 53.58642893452799, 53.667210148226836, 52.80204119220857, 56.25420939537787, 63.425816105258086, 65.46056916636806, 67.94810495068951, 65.08983066005092, 58.64658847931893, 56.1559618673017, 52.40079449069116, 52.89173010856875, 48.7421448769108, 49.794175547938195, 53.98500842432822, 57.644136567269605, 56.90282821655274, 58.25648915383124, 54.63526679623512, 56.365467425315614, 55.94403620689146, 57.02650447045603, 56.13936239673246, 57.79666577616046, 56.10015438448999, 55.91921937081122, 54.24644224105343, 59.34766115680818, 57.22740434831189, 61.16063556363506, 59.88991706602035, 65.1747578190219, 60.85775798366916, 66.82885662201913, 69.53536264358029, 83.24654886799475, 79.26389186613022, 91.66907002848964, 9.881653651114434, 1.441902621619163, 3.804211467504502, 1.965047149888931, 1.6132133646357445, 2.0229441528358767, 0.6369483603104469, 0.31422450657813783, 0.037345120067437815, 20.527561518453783, 28.475264080109138, 65.62799553717336, 62.50394928839899, 12.858499230877047, 31.776852492363226, 54.01173937705256, 67.57701735342702, 64.78302678754254, 56.46556238974295, 13.599623230195816, 0.864114206164114, 0.029386311146100203, 0.06938313539590567, 0.019409733884517225, 0.023446163057439753, 0.07237051823927511, 0.05403387818425413, 0.03680444585399763, 0.020629202218485937, 0.05568591997988763, 0.04055924578419617, 0.018128515033411886, 0.07509144804170055, 0.16182674305333247, 0.035549176316107475, 0.04233959198538815, 0.08455869366204546, 0.07693803403526545, 0.028360366197903792, 0.05052979967947449, 0.023786227571808045, 0.032713103498662674, 0.0201742647350916, 0.0359814720708997, 0.04117141898360945, 0.03407030103487834, 0.011350766627959186, 0.06042739902172358, 0.033919734114240256, 0.042705912248141346, 0.058623292603560036, 0.11019192666055695, 2.487570840504862, 84.77259405197637, 94.83254001986597, 90.80254001002159, 73.54697458205685, 55.830926818232385, 32.9364953502532, 41.57473118074479, 43.18012591331236, 46.22609346143661, 5.493897689927009, 0.28048541216600326, 3.0297826230525975, 5.661433396800872, 3.6609535159603244, 2.5215942148239385, 0.8445849089372544, 1.0221282981576458, 30.497632257400024, 125.4092590270504, 96.58580026318951, 106.4983827837052, 94.11782141654723, 87.31784359101327, 74.8621766797958, 86.3835350159676, 84.47694147786787, 90.89670042837821, 90.95114292636995, 87.47917852094098, 76.49854244724398, 69.13579079412645, 70.35703643675774, 68.09833957302955, 66.91318758072393, 68.37615320759436, 68.03485993416079, 67.97350621992543, 66.76506319353658, 65.49088908780006, 66.67184414402132, 65.2565823831866, 65.84045071755686, 61.826956041397594, 59.661905765533454, 62.65056748544017, 63.250137067610225, 66.83765057594546, 68.68897791831725, 74.38006247243574, 73.71854689813429, 70.56543196401289, 66.64787061752813, 68.946395227986, 65.66870189482167, 66.69712774215206, 64.13025417635518, 60.419119327299065, 58.733257170646425, 58.521045177213615, 59.2481114018348, 69.89746801314816, 70.73734160392516, 70.6756191868936, 69.2077035288657, 69.47058862255466, 66.62090824496362, 65.99438021259924, 67.39904372922837, 68.58830636547458, 72.00541250167355, 80.09369281030472, 76.70965225465837, 57.012042691630704, 77.89791860888081, 76.69604163016044, 62.63161851513771, 64.02964930380544, 73.7782532168973, 74.2286668285247, 72.99614044927782, 74.27799455581173, 74.26801604609336, 73.61632993144374, 67.42628066770493, 59.61517072493031, 56.22138700177593, 56.081374076104936, 55.644104326924975, 57.762121462052875, 65.74558035019906, 68.84448420616889, 70.71765915040048, 68.04758410299978, 62.0994274077877, 60.08607087596771, 55.38807945866739, 56.08516700806157, 52.555363332071614, 54.04953141366282, 56.00628029915595, 61.281770121666696, 58.58158303845314, 60.698188120319, 55.97943952006679, 59.36335063749745, 58.95806781707272, 59.65850507059405, 58.38950064874465, 60.883061193650775, 59.25219458918418, 61.07308041664862, 58.48855226270614, 62.46598466750115, 59.363585979707786, 65.91940018438524, 62.32062162891511, 68.14604343906527, 62.96091718058433, 70.0601287041941, 71.09528926111037, 88.2325481599377, 81.77368317880939, 99.90516093469436, 24.044082087855188, 1.7482085982638023, 1.9724882538280182, 1.6362303231031665, 4.954550708493879, 3.0169518147745444, 1.4746116342083102, 0.5046747919292219, 0.022277647231314934, 19.884947846012732, 40.59032217148812, 60.59263713898198, 38.670286670807876, 18.64530040371803, 44.75042719994822, 67.8736505200786, 76.4176082611084, 73.05350903541812, 79.25817305041899, 31.46608114242554, 2.110525162950639, 0.004322996809928408, 0.024638948549005776, 0.018211955414904703, 0.03082090463008612, 0.05238980753347278, 0.005657322312359729, 0.050594327265336636, 0.07278178488054583, 0.07101559215375493, 0.031614908798327374, 0.018067785328434362, 0.021967998322760387, 0.05832473281770945, 0.02085009409535316, 0.030413024097440705, 0.08341721499398833, 0.2062765280565908, 0.1211091775387045, 0.22265964007425695, 0.21484474651515487, 0.1304020309039662, 0.13634471282843622, 0.1667074585754064, 0.13649958516320876, 0.16568568114551807, 0.16707142694823204, 0.13955880407123797, 0.14598491811944594, 0.15174689522433668, 0.13732161282772018, 0.3405175940884698, 2.9368606930778873, 101.43086879484116, 110.30254840850831, 106.39209439677578, 83.82578096082135, 68.71739941258585, 32.043773704959506, 70.83190210403936, 82.3855729256907, 57.236994543383204, 10.24863942976921, 0.6520729584078635, 5.5095464760257356, 9.4847951012273, 9.124542070973305, 5.919506722880948, 6.239138216741624, 4.332116159700579, 25.840706094618767, 128.9628008873232, 102.2650549488683, 112.56498721338089, 98.87588393303656, 91.17007393990794, 77.80086348133703, 89.89660586080244, 89.33411444387129, 96.25485420227052, 92.54141299955307, 91.34407812549223, 82.02758604480375, 71.96352158823322, 76.49202346801758, 73.08193837442707, 71.882595246838, 71.41336210312383, 69.69672895246937, 72.78314005944037, 69.59678696047875, 68.9837440367668, 71.52645972467238, 68.30660958443919, 68.79915729645761, 66.19132241895123, 62.849133553043494, 66.62518362845144, 66.8381134156258, 70.3771738852224, 71.0154611833634, 75.69164030013546, 77.01734650519587, 74.63158838210568, 68.67029959155668, 71.48745567567887, 69.37384728462466, 71.86368157786708, 69.67845855220672, 66.17401692175096, 61.30074654856036, 63.104624978957645, 63.36772580300609, 74.13002706343129, 75.98634366066226, 74.64491659595122, 72.9231059166693, 73.86653792473578, 72.80010823280581, 68.99317341466104, 72.24295908404936, 73.59939313703968, 76.71299411404517, 83.91444221619638, 80.54427900621968, 62.38898069627824, 81.89107187332647, 81.05212396191013, 66.30071732305711, 65.24741972646406, 77.45499672428255, 78.2021297947053, 79.17944323632025, 76.08146898208126, 76.88764941307807, 78.22920199363463, 68.23515968938028, 62.16395824186264, 61.13993721623575, 60.261573406957815, 62.06908787450483, 61.50097570111675, 69.72010627869638, 71.1729286563012, 73.76018677988361, 71.75185480425435, 64.74925910272907, 62.8194922016513, 59.183866900782434, 59.076570464718735, 55.18103322675152, 56.379940971251465, 59.161627061905406, 63.3555389988807, 63.26455962273383, 64.96835877818447, 59.4605665822183, 62.837613551847404, 61.114292760049146, 62.23141124171596, 61.06875404234856, 64.18634014744913, 62.89840636714813, 63.04380078469554, 62.54019983353154, 67.46773227568596, 61.44274811590872, 68.32425240547427, 67.1272470105079, 72.9076047097483, 66.44224428361463, 73.58944600628269, 77.70739340013074, 92.68277522056334, 84.60728968343427, 106.51396243802964, 23.61238798787517, 2.7997189423730298, 10.818552951658926, 7.882019531342292, 7.985347999680427, 6.081035810132181, 1.5986619841667915, 1.1157001771273152, 0.16011919435714522, 33.79915398936118, 44.75018009062737, 85.46108768832299, 80.91635504076558, 19.491277202483147, 50.46663061265023, 77.62008144009498, 91.14560619477304, 85.01240776431176, 96.10095608618953, 30.038020687718546, 1.5072649981706374, 0.25001296262827616, 0.15239699743688107, 0.11478326013011318, 0.12323319461316833, 0.2447420325610907, 0.15413581784213745, 0.09150557895942081, 0.18111213320685973, 0.1597136886970651, 0.14880116458141035, 0.13216420166915463, 0.1793676284292052, 0.21938994616991092, 0.18173102499736896, 0.11444951392590039, 0.13042349668760456], [0.029753468359910676, 0.02379397846638195, 0.055489380122913476, 0.14042658250658743, 0.038287354588148095, 0.06960811243662912, 0.03947361875625868, 0.02136624966477675, 0.05353369554805179, 0.08346517209804828, 0.029671450986737208, 0.1414272618750411, 0.04958555034752335, 0.07927826410459896, 0.3427914043347682, 8.834465146064758, 84.93021841972106, 71.83240459811303, 77.7291468651064, 53.32146498464769, 42.23690179086501, 31.6522309472484, 81.46306284012334, 47.59018005863313, 27.237701377561017, 0.11090493235256403, 0.08079186232099611, 1.42217040302292, 4.141308050001822, 1.9651219200703407, 1.7916125659981084, 0.5896847803265818, 2.0101635999256566, 99.32325378541024, 96.70581694572203, 96.82115031826882, 94.84070639456473, 85.36848837329497, 76.87581169989802, 74.7314597714332, 73.01696039015248, 81.20844610275762, 81.17603948039394, 81.22492790222168, 74.82871886222594, 66.18331293905935, 65.1640340589708, 64.6823081662578, 64.60414709583407, 62.256361438382065, 61.76904616817352, 62.35610338949389, 61.97002841580299, 63.463541461575424, 63.01609708416847, 59.95483621474236, 64.14057393227854, 59.65466114782519, 54.771828036154474, 59.282345848698775, 59.15001292382518, 61.04337630733367, 63.601353937579745, 68.38671222809823, 70.72861825266193, 69.41864075199251, 67.23443754257696, 65.59933085595408, 64.03944346212572, 63.30006099516346, 62.65089304216447, 60.976519507746545, 54.96876632013629, 53.46263893188969, 54.82422697928644, 55.429185898073264, 58.06752504840974, 62.9301187299913, 65.11274514659759, 65.29081290768039, 63.457591226024014, 61.507063219624186, 61.21829440516811, 61.474064319364494, 64.64051923444195, 66.38293804660921, 74.36365127563477, 70.32266078456756, 50.8832137815414, 75.46043226795813, 67.71051914461198, 60.5756885774674, 61.67754511679373, 68.85226618859076, 64.78295618487944, 68.7350030099192, 68.712645499937, 71.2138468219388, 68.01862916638775, 68.19997602893461, 62.990527153015144, 53.684448965134166, 52.609899966947495, 50.686632433245265, 53.24025623260006, 60.940967144504675, 62.33915875034948, 65.2188491821289, 62.95314696527297, 62.050323255600475, 57.06599097098074, 53.27769917826499, 50.789229869842536, 52.960685376198064, 51.53975971283452, 52.09765018955354, 58.640638243767526, 54.53905105590821, 55.314178082250784, 55.81486863474692, 56.94330707673104, 55.851197627282914, 55.31271503817651, 58.039205535765625, 55.41894851192352, 57.021754480177364, 54.992751613740005, 58.63503709916146, 59.556080218284364, 60.94470124090872, 65.31948543364003, 68.5969591140747, 70.29543953557169, 74.57103483138546, 68.0551778116534, 70.84996854105304, 71.62608792704921, 82.66872882843018, 81.89486088291292, 82.06107524133499, 3.6664865093846477, 0.4265921382654098, 4.857006755567366, 3.225731489158446, 2.0634174971811237, 1.227751751580546, 0.08980350013101294, 0.09600547983521417, 2.381290053167651, 36.17774594214655, 42.89942541430074, 82.48967263006395, 49.45124664614278, 32.21044501950664, 45.59783566382624, 56.18814099219538, 60.83564758300782, 69.61066430614841, 65.89926273592057, 28.30236600291345, 1.5315436115187984, 0.06659797678190855, 0.04288762830378067, 0.04329591103258633, 0.054313986742448424, 0.003954295210743083, 0.04385474919071121, 0.07314701729844655, 0.02155441426551871, 0.05729044900245725, 0.05059581730634936, 0.07239812804806618, 0.0792748167089397, 0.05924626381226605, 0.06550923560655887, 0.0354686796274637, 0.04194974899291993, 0.0043751539910332335, 0.05911436645434268, 0.0369557635408015, 0.06261581727754205, 0.07126989504021984, 0.010877844272932459, 0.09301493304871744, 0.09677579656483666, 0.07723633335122178, 0.009028284900611448, 0.09530413400141463, 0.08215045030679434, 0.17694628497044887, 0.5783715615830114, 17.529605742423765, 103.75289624737155, 80.64913965040638, 89.88069672738352, 67.36648805679815, 57.74822842690253, 40.65990501834501, 53.198208424352835, 51.12527893435571, 33.19189656165339, 0.010954093961646, 0.3368940901371741, 5.317658733937049, 5.599961030867792, 3.465792065666568, 2.3014381960515053, 1.4838022378183182, 4.091094847648375, 109.877653737222, 98.93641394953575, 104.97960182928271, 97.9554605484009, 85.5949503375638, 79.98817320792907, 76.63773167517878, 75.9217736028856, 84.98903043808477, 82.76321088114094, 82.36593754060807, 76.00202529661118, 72.28109236686461, 69.36412765133765, 67.12355998254591, 67.70795391451928, 62.50478867561587, 66.36832329534715, 66.00110315507459, 64.93975293251776, 66.3399096458189, 66.09274541178058, 63.04330264368365, 67.63268363091254, 63.42767530871976, 57.91265418452602, 62.913260382990686, 63.61740427632486, 64.86341184185397, 67.27156669862809, 71.97532792245188, 72.92512201493787, 72.85780629804059, 68.74175733135593, 66.64785492804744, 66.8188859570411, 65.33101327957647, 66.0208797454834, 63.77524437442903, 60.229711994048095, 58.44106412702992, 57.056106598146506, 58.65684939968971, 59.82766120664535, 64.40105461305188, 68.59422914443478, 68.55988487120598, 64.8711310663531, 65.74854173967915, 65.25765711261381, 65.21549555563158, 68.37186213462584, 70.43671546443817, 77.90704204190162, 72.69931900885798, 54.87214265331146, 78.08236414386381, 70.40030802449873, 63.4094205979378, 64.34791041958717, 72.93750885994204, 67.79785463886877, 74.05481953774729, 73.1467123954527, 74.60239025854295, 72.64154249621977, 71.01098183662661, 65.11627920212285, 56.92022000589679, 54.70841899994881, 55.246925123276256, 55.392299928972804, 64.49084158866637, 66.50758312594506, 67.99685216719105, 64.31859854728945, 65.45425807276081, 59.35454099409042, 57.451591337880785, 55.26397566641531, 56.65080024350075, 55.04998683929444, 55.03243031040315, 60.284574185648275, 57.45841233961044, 56.70250100474204, 58.56523067720475, 58.05732688596172, 57.55837786582209, 56.93465825050109, 61.16803315378005, 58.247812871010076, 60.15204514226606, 58.363483567391675, 62.69472945121027, 62.9083142742034, 65.11052116270989, 68.12569418261128, 71.84949828732398, 75.06425719107352, 77.87958545069542, 70.83410647607619, 74.8597526550293, 71.57504220162669, 85.9166709838375, 81.23698526813139, 95.19077793244394, 13.549316871550776, 1.445410936590164, 1.8547594162725636, 2.028217902106624, 4.317289600449224, 2.548884105297827, 1.010235426647048, 0.15960953138287992, 1.3898792454311926, 38.9251152161629, 50.31328555076353, 68.29889820468041, 36.459976165525376, 47.621978713620095, 63.19854613273375, 63.819857412768954, 67.8827033504363, 77.14350561941825, 77.76705265045166, 44.22370387661842, 3.5070661863973065, 0.022961625851871028, 0.027940373815175508, 0.060144655121069764, 0.05894864248412271, 0.06631190422922373, 0.053396167443884965, 0.05410722727256437, 0.00606701607936092, 0.07948912214487791, 0.010449266917402706, 0.0918758905402595, 0.017150871928841356, 0.07945447198806271, 0.12368292652911718, 0.03708292647535282, 0.19950328424813288, 0.10621058303982982, 0.2865104178988165, 0.28395425828714527, 0.15264445915818214, 0.1311638440576292, 0.13870555066293286, 0.2776722760210114, 0.22219984942386228, 0.16391615593625655, 0.126920904393398, 0.3551407110306525, 0.23662194489471375, 0.279811775732425, 0.6403194536124507, 22.96960957588688, 125.84437539500576, 93.90716660407283, 103.19011457504766, 78.17013109883955, 61.97247597479052, 42.686436791573804, 110.92394598068731, 70.42033564659857, 46.34993837725732, 0.4217385728993724, 0.8794172108173371, 6.607593903618475, 10.20772224472415, 7.154721396584665, 7.322310055455855, 4.426693820184277, 2.555637691290148, 113.92390020432012, 100.59635316171955, 110.54025973043134, 102.17217322318785, 91.54502114941998, 84.06758723720428, 80.22198569390082, 80.40021819453086, 90.61708250353414, 86.66336474880096, 88.99479020026423, 82.32060278615644, 76.26137241240471, 72.73742091271185, 72.85700613452543, 72.39245630079701, 67.66069719868322, 68.50858811409243, 72.16576683905818, 68.2840951796501, 69.9300785987608, 68.47351428001159, 66.80085089898878, 71.74178215765184, 67.9736944936937, 61.39964126771497, 67.48272357448455, 65.799230529416, 69.68515796046104, 68.56580765016618, 75.60556780907416, 76.33852543369417, 75.13671121289654, 72.807874525747, 69.78749259825676, 70.89946885262766, 71.30561459449031, 71.42402310525218, 68.11430361963087, 62.766983432154504, 62.17965556729225, 61.28715945828346, 61.99590429182976, 63.542090846646225, 69.17288072647588, 73.16334324498331, 74.13374547035464, 69.78335842009514, 69.27196764176892, 68.42228028082079, 69.65366917271768, 73.00250253369732, 72.20244884490967, 80.82373219151651, 76.51764438998315, 61.41795089167934, 80.09570890857329, 74.20154756115329, 66.2778812839139, 70.46051640664378, 78.80410378979099, 70.92176360468711, 75.83301036588608, 75.42090262136152, 77.72650318761026, 75.13014516522809, 75.00062850213821, 69.17147651795419, 59.48442243760633, 59.708687874578665, 58.07664455906038, 59.41514553562288, 67.7176578583256, 69.24684878318541, 71.01936786405503, 67.29568927518784, 69.28182063564178, 63.66109163530412, 58.485516348192775, 57.819297852054724, 60.35043862558181, 56.877474015758885, 58.15409568048293, 65.60498691374256, 59.374427410864065, 61.29103868238388, 61.16874702515141, 63.02398104821483, 60.96199497099846, 60.44671320146131, 65.91426187945952, 62.18304057275096, 62.4085533234381, 63.39789275200137, 66.94343689949282, 66.30244316593294, 67.38862591405069, 72.983533951544, 74.83490836235785, 77.80753151062997, 82.12824190816572, 76.20912644170946, 78.32329965406849, 77.26212593816942, 92.10178590589955, 87.74345213367094, 98.56141182684131, 12.267360783392384, 1.5091700443337042, 15.611013673966932, 6.55054057798078, 7.889854956057764, 4.4485296549335605, 0.926778911342544, 0.1984828551329913, 4.630155005762655, 55.02314606020528, 60.743930801268554, 107.73700452619984, 64.86431398699361, 45.828769130091516, 66.09847991697251, 78.27193229429184, 81.17597672247118, 93.3474914489254, 92.93444233555948, 44.503219819838, 2.6856446506515628, 0.19637144020488187, 0.151343013670656, 0.2094403332880428, 0.235150795610201, 0.15953175813680695, 0.17519113157064686, 0.1811345182960072, 0.08498484539168497, 0.22026817404454757, 0.11846153936799496, 0.2900048513566294, 0.1996170789484055, 0.21159224362382967, 0.17596878742258396, 0.08539213603662868], [0.013437537465154404, 0.03267290686527568, 0.027614010783332973, 0.08510688319802286, 0.12804159143519017, 0.07065995881754546, 0.024544689090802305, 0.07827285031277327, 0.024223259665192138, 0.038180734301286365, 0.06519513189672463, 0.047128951522491636, 0.013724364614444635, 0.05953620893940811, 0.10941593321941553, 41.900484023555634, 81.9890840591923, 76.04072340073125, 62.91385266088671, 41.07416222172399, 23.027693994583625, 38.59345920624272, 58.07745256731587, 33.556786814043605, 11.21031536209968, 0.3457755006609425, 0.728744508758668, 1.824163458039684, 3.147369642411509, 2.8126460938684406, 0.531639646618597, 1.4457170040376726, 37.66357506475141, 114.87740485898911, 90.15879277260073, 97.0705581480457, 78.59673592352098, 72.45832074073054, 68.92577140561997, 70.179470739057, 68.0738482936736, 69.27198333124961, 69.70540523529053, 67.40640209567162, 63.725238077102176, 64.58106002499981, 62.66230321699574, 63.54167507540796, 61.27894209277246, 63.134168271095525, 61.052856676040165, 60.64131767519059, 62.45946568827476, 59.78094970026324, 64.36372541612195, 65.09143098708122, 61.461724542802386, 55.54419763626591, 55.31523319982714, 56.62745821860529, 57.85373233979749, 60.195575606438425, 67.86642551422119, 68.80970847222113, 67.81399126975768, 67.2723747068836, 61.37446749594904, 63.84161480011479, 64.38041117883498, 59.507709549319365, 59.46379469287012, 56.815716297395774, 54.68046819010089, 53.632340277394945, 53.906109948312086, 54.13808284267303, 56.868609459169456, 57.21826522581039, 63.39188368089738, 64.30114007765248, 66.96249177378994, 61.14131004579606, 61.501360093393636, 58.531996434734715, 63.1906896252786, 68.43425135458669, 73.35776728968467, 67.14408182328748, 49.68006987725535, 77.58799645208543, 66.88528383931806, 61.13259453927318, 60.059402681166134, 68.84013822001796, 66.11922141044371, 68.21385337460426, 68.93097246846845, 69.565015762083, 67.13363262914842, 67.87676488199543, 66.25510800269343, 59.2878253998295, 50.8409776995259, 52.2256528177569, 53.70428046872539, 61.26418613618421, 61.83397316163587, 67.94244104816069, 60.21089246196132, 64.29527221187469, 58.575562200238636, 55.04670773783038, 54.065154214059156, 52.64859807106757, 51.71680373530234, 50.677932616203066, 52.83065096024544, 56.40670722530734, 55.59166223772111, 57.443746597536155, 56.76424303362447, 57.7457534113238, 55.480780755319905, 56.230275092586396, 55.365074757606756, 54.50776623141382, 57.474878449593824, 65.17475389665174, 68.56379939663795, 75.02679071118756, 70.96567846113636, 73.54389159910141, 77.17702619491085, 74.68943549740699, 79.59548904049782, 77.2058085472353, 74.37868964287543, 77.32427981591995, 76.22359214290496, 84.87219087539181, 66.45793376430389, 0.5184443643496883, 1.2421022331522358, 4.625191246309589, 2.0006517296837223, 1.6160358776969295, 0.5560473917472748, 0.1508539737833123, 0.06152452119896489, 18.04190258825979, 31.582508856250396, 40.78443634894587, 65.68381870946577, 10.401957035064697, 18.658783551185362, 33.1828123523343, 56.786977091143214, 58.07709563163019, 63.68474352744318, 63.9221606716033, 32.582809348260206, 1.196358816758279, 0.09138808405447392, 0.05727182540501799, 0.01461692024848514, 0.09066072187476582, 0.08121114990283405, 0.17388320497928128, 0.07438980343361055, 0.044593801872143825, 0.008589754147725481, 0.17499263818946578, 0.06323885743416126, 0.09014283111619373, 0.02930096512089574, 0.08489011095896845, 0.01862326419101127, 0.030412294398692828, 0.029581933612785036, 0.06248950087014706, 0.0380038982257247, 0.014644548251864412, 0.04418268461801833, 0.04474559453346076, 0.027664662601666588, 0.01658036625162969, 0.025616091781205712, 0.06018373709652693, 0.020619963198119116, 0.07089255077223625, 0.19177667466142487, 64.51288530903479, 93.59264742943549, 85.97807176651494, 71.58989229509908, 51.87518904286047, 31.985089163626398, 37.89819555897867, 42.3150707060291, 41.8955026134368, 11.733416376575349, 0.5653518666663478, 1.669916251013356, 4.361736428353095, 6.720585621172383, 3.084386673665816, 1.1294528649699305, 1.1859733611345291, 47.41525019368818, 114.33418012434437, 94.41136375550302, 98.3448342354067, 82.64965041991204, 76.84290301415228, 73.29173811020391, 73.71564434420678, 71.73646342369818, 70.37760534594136, 72.3212339032081, 69.25240285934942, 67.2532884536251, 67.45565137555523, 65.77382141543974, 66.6641249195222, 64.43110781331217, 66.95565900494977, 65.75833197562926, 63.608167094569055, 64.4614512689652, 63.03565402184764, 68.06172032510081, 67.90771238265499, 66.29793244023477, 57.38048268902687, 60.480233776953916, 60.07601391884589, 61.88426186961513, 62.9230349294601, 68.54434444058326, 70.71357988542127, 70.26885371054374, 68.13452736023935, 65.50273464572045, 67.26640485948133, 65.98257387838056, 62.837754757173606, 61.00086173703594, 58.48533199679468, 58.53747206349527, 58.53115312514767, 57.90919465403403, 55.59525120642878, 61.631449422528675, 60.56008146655176, 66.75244100632207, 69.1283461355394, 70.83238847794073, 66.20718448392807, 65.95632537718743, 61.79063097123177, 66.04639084108415, 71.11586601503434, 77.17428838053058, 69.46275172695037, 55.00851561946254, 79.7418640505883, 72.04121589660645, 65.07523159826955, 64.61451392019949, 71.49643790337348, 68.66604774228989, 73.40482788701212, 71.67522738056799, 71.65633724581811, 70.62281623963388, 72.3009003362348, 69.53558229630994, 62.655337087569706, 53.35790380354851, 55.10621793808476, 55.43827010739235, 63.59767083198794, 65.3122212040809, 68.81430549006309, 61.911334068544456, 64.83025212441721, 61.57797967233966, 55.882431460965066, 56.38140793769591, 54.67497687185965, 55.5545997619629, 53.425125383561664, 55.699582330642215, 59.12690624114006, 57.81365356137676, 59.22999397400887, 59.345903934970984, 59.89130558506135, 59.07743730852681, 58.64179142059819, 59.19817178480087, 58.981656951289025, 62.549491928469756, 67.7622865861462, 73.4925477735458, 77.77190069998466, 77.01722098935035, 78.09544917075866, 81.72585379692816, 79.4145736386699, 80.49667712180846, 77.84324861341908, 78.6788546654486, 79.76281735204881, 82.02374212203488, 84.48153065096948, 84.49950295109903, 10.464106009852502, 2.6168141634233537, 1.3299114761813995, 1.7582937474212341, 3.4207269741642863, 1.8179053164297536, 0.8823477116323287, 0.19893355998060397, 20.393928327868064, 40.1210968725143, 43.45932806691816, 47.536310226686545, 18.345768605509114, 36.07919639156711, 44.75598519848239, 64.2853525377089, 66.19680589245212, 74.40478124926167, 76.19916362147178, 50.53026714632588, 1.9238654500053776, 0.03841440260951077, 0.07678948958674747, 0.01703228343338255, 0.05892103650577127, 0.05210030673732681, 0.05868326579671233, 0.017215600612783627, 0.05075096926321426, 0.043912562015917034, 0.05995893625602607, 0.0854464746530979, 0.023242665206893318, 0.03208218221252244, 0.043788340858994954, 0.1527492753079822, 0.11557268309256724, 0.1538111191363104, 0.21003026695501423, 0.2244165554762848, 0.22136810776447097, 0.2841616536100065, 0.12920250575388634, 0.10830548111229174, 0.10357547806756151, 0.14529680262409872, 0.21503469035510095, 0.10654410707854456, 0.3080566407692048, 0.38522142916917806, 73.20645009317707, 111.2052740589265, 100.57976153589065, 86.29943155473279, 60.9737777709961, 34.01981084577499, 55.429201587553955, 80.36792139853202, 53.945918083190925, 17.857557073716197, 0.9000288370636202, 2.406683477663225, 4.951618246493801, 15.039660642223975, 6.018109715753987, 6.657081467490043, 2.1956391248010823, 46.86147428327992, 120.35236681661299, 100.06984556874922, 105.66183536283432, 88.92578786419284, 82.89942695248513, 76.58386184323219, 77.26439306812902, 73.48125134744953, 76.22938940601965, 76.18618842094176, 74.43459126257127, 72.17812230510097, 73.53214017806515, 69.51535071096113, 70.06245859207647, 68.18081132827267, 71.21000289916992, 69.23199084497267, 68.44957213247976, 68.1358923450593, 65.61545571973248, 72.3191785812378, 71.51698327833607, 68.97435388257428, 61.792403882549664, 62.38290102251115, 63.83878677122055, 65.28660028211533, 66.95529814689391, 72.55488949437296, 74.96198531120055, 74.16874085703205, 73.04759410119826, 68.37415279880648, 70.70326405186808, 72.65421175187635, 67.76072548281762, 66.83951762414748, 62.955245433315156, 64.02372260247508, 60.88786609711186, 60.55102471382388, 59.563316991252286, 65.25081649903329, 64.48948052621657, 70.35993899068525, 73.30351306546119, 74.22836088365125, 70.83676584305303, 69.14407483993038, 65.78406272395965, 69.30598243590325, 76.20293694157755, 80.28757556792229, 74.88629925635554, 59.965697257749504, 83.49495257100752, 73.95960007944416, 68.28188296287291, 66.81548918447187, 74.80509834904825, 71.99104878210252, 76.22410205102737, 74.8173753676876, 76.29231206832394, 73.84575720756285, 77.04128080798735, 73.18836796668269, 65.04296618123209, 56.324553182048184, 57.6831288491526, 59.834482208375015, 67.0683487000004, 66.9144505839194, 75.6240107936244, 65.78491780065721, 70.22657840482651, 64.99674104875135, 62.44242298987604, 59.26265555043375, 57.94160127639771, 58.95774226034842, 57.22742396016275, 59.71490090893161, 62.44346241797171, 62.569335199171505, 64.2807476751266, 64.69156495986446, 64.50240473593435, 62.818644969694084, 62.26764217499764, 63.46454558833953, 62.35411082544635, 65.45210076916602, 72.13454477248654, 76.81806656622118, 82.30245005699896, 78.21095512759301, 82.0144147257651, 84.39239871117377, 82.88639683877268, 86.56414447292205, 83.25032218810051, 81.70818744167205, 84.44076153539842, 85.44696715570267, 89.89289529861944, 83.07774574525895, 10.716272246453071, 3.9279887224397356, 14.16677148111405, 5.600656270980836, 7.368877414734134, 2.044187341966937, 0.7704470871436981, 0.2371054995925196, 30.88991438188861, 50.350967761008974, 57.53575363466817, 82.34723567962646, 17.248183527300437, 31.099147335175548, 52.370290217861054, 78.71570925558768, 78.71687027715868, 85.52907020814958, 92.38028203287433, 50.90441026995259, 1.7470076175466662, 0.28334975362785403, 0.11377002458058058, 0.24431991811481216, 0.12993692360337705, 0.17370012528713674, 0.26778370502494997, 0.2004508430799169, 0.12154279096472649, 0.10374869054724133, 0.3323459793483058, 0.1592113495233559, 0.12927562118537966, 0.0924455228772375, 0.34289335531573145], [0.008934254311175357, 0.07108931279470844, 0.20806177339005857, 0.03239639125944626, 0.047555896153132764, 0.04811214493407358, 0.01876899518162733, 0.06103286512135979, 0.041443127387714, 0.026205374273441495, 0.01687085338597817, 0.055228699554478934, 0.13054325155192806, 0.2749366066869228, 6.598573432814691, 88.39012545924034, 75.06257841663977, 75.71468814726799, 59.52950616036693, 52.81910742482832, 30.088821265005297, 68.53209880090529, 38.07234094988915, 33.681816285656346, 1.3456605278676557, 0.07445852152041851, 0.41800401684257293, 4.487144898983741, 4.361195631565587, 1.6123374503466392, 0.43427183262763486, 0.9033114931756451, 91.67844449320148, 100.84816148204189, 91.38851073480423, 81.9547946991459, 74.75010671923238, 77.99642501338836, 76.79212400990149, 72.59243442166236, 68.68680492524179, 67.79402640558058, 64.36094445566978, 62.55533233765633, 62.21035595863097, 63.47165684546194, 63.97964300647859, 63.08024352596652, 63.49185705184937, 62.6341837452304, 62.1417772385382, 59.34293077838037, 61.73984019987045, 62.18400547581335, 61.31774610088718, 63.76597581371185, 59.65952880920903, 53.74979565220495, 57.645132849293375, 55.96193790435792, 59.85811841103339, 62.53506937334615, 67.72683620452881, 65.10557505392259, 65.40623649474114, 63.18466486469392, 62.002027111668745, 62.18324845837009, 62.87253049112136, 59.41683607716715, 57.610902324799575, 53.49780298048451, 54.83296994240054, 53.632465793240456, 55.53377589871807, 52.04794591472995, 54.77509537050801, 53.599462970610595, 60.721130063456876, 64.03551716958323, 68.61377823737361, 63.96982139156711, 62.33813893410468, 54.84246600058771, 63.883576316218225, 67.93222719623198, 76.57678588744133, 58.763706530294115, 51.07805359748102, 75.2554178237915, 67.58777249243953, 62.9581440648725, 60.127577397131155, 71.31545974362281, 67.79395580291748, 68.1074708507907, 67.66876943649785, 70.08975044373544, 68.35573334847727, 71.53785028765279, 71.29043502192344, 63.467357927753085, 50.97000798871441, 50.807096265977435, 51.56858913360104, 58.108913898468025, 60.28671579976236, 58.92620248179282, 60.38962702597342, 59.0813636010693, 61.711395171380815, 56.984586100424494, 52.42426987617247, 53.1367644956035, 51.38047618250693, 51.95074958185996, 48.708832187037316, 51.90836444977791, 54.51388512888263, 54.04071784788563, 55.963424482653224, 55.135572956454375, 54.15445089340211, 55.724277573247115, 54.98199647472751, 56.08459434201641, 65.02570775247389, 72.86359571641492, 72.99148851825346, 73.90502422086655, 75.14625041715561, 77.45822875730454, 77.6695974411503, 78.71415599699944, 80.42099106696345, 76.40618631916662, 77.15459023752521, 77.91332567891767, 82.13149747540875, 79.54121128205331, 84.11999794744676, 55.164739701055716, 1.665035719352384, 0.8060899713347036, 4.169495182652628, 1.4686915518776065, 2.0562383340251063, 0.029819045486229084, 0.21088381147673055, 3.229699456884015, 31.826015480103035, 29.84178843036775, 49.050086236769154, 37.986476344446984, 21.8907557764361, 29.882596769640525, 36.47435165220691, 53.50591444200086, 62.40718833861813, 57.703701680706395, 57.98095441633656, 23.847810606802664, 0.8179662953461371, 0.05446469921979213, 0.07825761282395932, 0.06212629858524569, 0.039910239077383475, 0.06129162663954401, 0.014411640285904852, 0.04208188383809982, 0.04728038029204454, 0.040638804015132694, 0.043290782073933276, 0.09933691276537795, 0.039815466340270736, 0.042630827970682614, 0.08847675842022704, 0.07190790072443985, 0.15480413762552125, 0.02867907984182239, 0.10489694909342837, 0.04236758866858098, 0.07824464295540126, 0.07743727055288131, 0.06313578796482856, 0.09309491262801232, 0.09455165945954862, 0.010764692128906328, 0.2517534531052074, 0.37415299083917375, 13.181199489101289, 105.60769880971601, 84.24618844063052, 85.31299468009703, 72.8625915896508, 68.34627259162166, 44.00713805229434, 51.45851173708516, 39.70238777898973, 42.95619780017484, 0.9509433469464703, 0.2973278858248265, 3.8290864036929224, 8.605694866949513, 5.473058137201495, 4.072267470821258, 1.412698737075252, 1.5030366831248807, 94.07554611083, 105.25898441191643, 94.07484792893933, 86.3011573976086, 79.14646394791143, 82.76835703080701, 78.99491140919348, 79.79918556828653, 70.36670900160267, 71.10595810797908, 65.13063507695352, 66.33238653982839, 67.01379637564382, 67.51826809298608, 64.97849026033956, 67.88508815150108, 64.45875267828664, 65.9023614083567, 64.03634086731942, 63.9042236728053, 63.91675956787602, 64.72252422763457, 64.32508614755446, 67.69476690599996, 62.27052119470412, 58.236206577670195, 60.67261034442533, 59.66537314076578, 63.48212957382203, 65.36714615360384, 70.04312130712694, 68.15278991576164, 68.05269887370449, 64.69605607371177, 64.97640355940788, 65.44748021710303, 65.7690086672383, 62.56675820196829, 59.601501264879786, 58.93422765116538, 58.67810080128332, 57.532211734402566, 57.94114628145772, 55.074674237158995, 56.57397670130576, 55.23184753233387, 63.97386535521477, 69.07249942902597, 72.69841686371835, 68.75181428847775, 65.48833170244771, 58.01793059995098, 65.1366166914663, 70.17088859311997, 80.72888928074991, 61.60653844956429, 54.941623518543864, 77.32686858023368, 70.0469103167134, 66.55951530702653, 62.04977412377635, 73.29092225720807, 68.39467463954803, 70.20822955716041, 69.52663144757672, 76.0311528175108, 72.08774305159046, 75.2161156746649, 75.12825458280503, 68.05464436930995, 53.42880848915347, 54.199040397520996, 54.37095395980343, 61.09735988801526, 62.34694465514153, 62.42768664513866, 61.96900859955819, 61.4485453790234, 61.79982500691568, 60.712787182100364, 53.928341942448775, 55.46814680099488, 53.262174437122965, 53.76508112876646, 50.90472013719621, 56.61934675708894, 57.20743163939446, 58.468701147264056, 58.36209897072085, 59.26268692939513, 57.97635347612443, 59.639642392435384, 57.604806961551795, 60.34178979935185, 68.20936618312713, 77.65481795034101, 76.65287986878427, 78.32113450573337, 77.8668769713371, 81.97646187197778, 79.58707163410803, 84.73571592761625, 81.5247303439725, 82.70346533867621, 78.20045102027156, 83.35610851164788, 84.22717279003513, 86.70530273068337, 78.82599846009286, 78.84206448831867, 4.114684472160955, 2.6280088530432795, 3.583024845969293, 2.590842434475499, 3.9713706268418223, 1.2139461117406045, 0.48695833452286263, 1.930510925669824, 43.147295674970074, 39.392045928585915, 42.328587193642896, 28.111944736972934, 28.05368773398861, 37.695056007754424, 53.11181037656723, 63.64254274675923, 73.47386160204488, 66.76400415359005, 71.99866602497717, 35.35754303778372, 1.2201421082981172, 0.06643899055498262, 0.03229919385405318, 0.029249658297386863, 0.07265310509190445, 0.03211133951892055, 0.04564644881494103, 0.030692031404243845, 0.060329891350721164, 0.09297730280987679, 0.05027557340180201, 0.04650938557460905, 0.053070051475398006, 0.027792687385132717, 0.23844157225422322, 0.1845940947532654, 0.2738699365046717, 0.18080090232674154, 0.11602026230144886, 0.11169688340516822, 0.10411372378228173, 0.14792849850510398, 0.1826044724833581, 0.16238572676816296, 0.15472025099781253, 0.10905696740073544, 0.30291046045960923, 0.5475558893334481, 13.824601557946975, 124.8991547861407, 96.15317852266374, 100.77789614277502, 83.13440830476823, 76.08906269073486, 43.916452853910386, 95.61245626018894, 57.093780963651604, 56.115604600598736, 2.0091809236234237, 0.2296447531590539, 3.727296485054878, 13.898288184596648, 10.834642514105767, 8.24616551399231, 5.0003424190705825, 1.4294236009159398, 101.18609720660795, 111.77251154376616, 98.76394733305901, 90.42354491449173, 82.57006552911575, 84.77034261149745, 85.1910795704011, 81.09561520238077, 76.74610676303988, 75.50460600083875, 70.70541351072251, 71.1906813037011, 70.79882083400604, 70.79110160950692, 70.16366358726256, 71.00155245873236, 69.73970244007727, 69.71191636977657, 69.11524541916387, 66.51661242208174, 70.08817365092617, 70.52171322607225, 67.97000746573171, 71.4977950434531, 65.9953058919599, 62.210473629736136, 65.6059871181365, 62.580674771339666, 67.01613410826653, 71.66721790067612, 74.28888305541008, 72.05887440712222, 71.95002863484045, 67.94400215148926, 67.25709315269225, 68.670283902076, 69.70055718575755, 66.62157504789292, 64.29113803371307, 62.07558331951019, 62.74999956930838, 60.62164306640626, 60.310940357946585, 57.28799712273383, 59.0191077416943, 58.44286449493901, 67.23475133219074, 72.73647169913016, 75.1454580983808, 71.91431937679168, 67.36921018169772, 60.322417213070786, 71.87078891261932, 74.06538640299152, 84.0080770369499, 65.8400349463186, 60.15405731816446, 80.13738801402431, 74.29717494595435, 68.76424820192399, 65.1503881331413, 79.41513845997473, 73.98143983656361, 75.15164759851272, 72.94401214968774, 77.57000061773485, 76.04111563774848, 78.2434872658022, 78.09741035584481, 71.56292207779424, 57.31885440887944, 56.746435473042155, 58.77517946304814, 66.28906003890499, 66.62583474190005, 64.65955057451802, 65.28804763670891, 64.54861417893441, 66.39171631105485, 63.14348390025478, 56.82942105877785, 59.706550182834754, 56.43946686098653, 57.84892351396623, 55.51225777595274, 60.4095644335593, 59.879675757500436, 60.9629245727293, 61.71319161691974, 61.61118645821849, 61.24963414284491, 63.14035777122744, 61.35928400101201, 65.35598308809342, 71.7449906564528, 82.53806683324999, 79.57389247032904, 82.55086944949242, 82.56062830648115, 84.70694142003214, 82.85859507899131, 85.49798934690415, 86.33106939254269, 85.08337128546931, 82.8651140582177, 85.98560271724578, 86.45043496162661, 88.8310783140121, 83.47788241601761, 77.6075533897646, 6.648874888497015, 5.0227342497917915, 15.426816228897342, 5.214632288102181, 8.016355316485129, 0.676061438937341, 0.32206131025187434, 4.567345601897086, 55.07592547324396, 48.4479945705783, 67.00421794768303, 48.62991409917032, 28.864957440283995, 43.041713314671675, 57.1519418685667, 75.2302832757273, 86.94363378709363, 78.94008451892485, 88.6758779710339, 37.19018813102476, 1.093666017536194, 0.20055769702359555, 0.12368546994102579, 0.20241998015872895, 0.25794067029510775, 0.16803233103165705, 0.12246847798627232, 0.1289501870351453, 0.15435078211369055, 0.3958424108643686, 0.12260671855220873, 0.29627163443834553, 0.10903959252661276, 0.11712019602137229], [0.06095959647228161, 0.05872845732336564, 0.054427984456020984, 0.048328683516311075, 0.09250627364963294, 0.026311351046446833, 0.02236299517173921, 0.050594342587095116, 0.06156163432845666, 0.04204693490699415, 0.06382345529874006, 0.04258876974363962, 0.11978207576659419, 0.32023201486276043, 36.76338326546454, 90.42984424098846, 66.27650845435359, 65.3773521607922, 35.49623412470664, 16.5999000687753, 26.808486215529907, 58.33569749709099, 46.84283910259124, 17.74658537680103, 0.17952988585156782, 0.20900456715495358, 2.6565612564163827, 7.113617408660151, 2.3771431273029697, 1.2046706868756203, 0.6461520793457186, 6.199114351503312, 104.44863842379664, 91.90046633443525, 97.4690866470337, 87.32266810632522, 88.65927065572431, 87.68937049373504, 87.83043461461222, 83.83034659970193, 81.62132263183594, 73.62877168963033, 67.84653909744756, 64.02668006958501, 64.4850717821429, 63.276989613809896, 63.49297100497831, 63.34736085707142, 62.62198909636467, 62.29722861320742, 62.33429893370598, 60.88244930390389, 61.54452969951015, 62.19883987980505, 62.47312730358493, 61.464132878088186, 55.83716730917654, 56.02088720567765, 59.2613729353874, 56.15219639193628, 59.33834552764893, 63.3839604931493, 69.00179478429979, 62.130888738939845, 59.529404178742446, 62.42039103661815, 64.84173682428175, 61.20032210503856, 58.90887345037153, 58.47728329320108, 56.08989738648938, 55.96183200036326, 57.09746406924341, 57.09292980932421, 56.43609362263834, 54.28172788312359, 58.17231901230351, 52.702354154279156, 56.59917792966289, 64.20159816741943, 70.43737442262712, 70.67105354801302, 68.8110185438587, 60.41115691584926, 61.2817269755948, 66.7202461919477, 73.3327268785046, 58.37845917670958, 56.124606440144206, 72.57914543151855, 65.36264327264601, 61.94550575748567, 59.190009332472286, 68.76250666956749, 67.41766714280652, 67.84701762660858, 69.56305457699683, 72.9497701891007, 69.21346156827866, 69.12796174326252, 69.819593275747, 63.483690677150605, 51.340071847361905, 54.36471346885928, 50.196359695926795, 53.876280323151626, 55.10079722250662, 56.6826577340403, 56.914301149306766, 56.931116350235484, 57.82051378680814, 59.063501127304576, 54.8075569060541, 51.92925499331567, 51.43829976358722, 51.891176623682824, 48.0780876067377, 50.10562350673061, 54.338033506947184, 55.339614652818256, 55.21014505817045, 54.35807681852772, 53.3838620493489, 56.288537979125984, 53.628272779526256, 57.703913488695704, 71.39258923069124, 71.33932344375118, 75.24911849729477, 77.9222059249878, 77.28384017944336, 76.06302599753104, 77.9391662536129, 76.83144969324913, 78.69293597436722, 80.75025050870835, 76.23066809869583, 80.65696870127033, 76.58480321207355, 81.49645789977043, 75.14461086642358, 83.13698137960127, 32.336384480999364, 2.6818397064362807, 2.261630306320806, 1.3748726248741152, 1.8007910347753957, 1.0820794586212406, 0.29844257439817157, 0.20818796339294604, 15.925281816913238, 25.95797907921576, 40.552867458712676, 51.21278701290008, 32.20709727656457, 22.79454635035607, 17.676210211169337, 18.426155621005645, 41.84687699041059, 59.85432940144693, 54.67891100914248, 58.33810975474697, 13.050717922949023, 0.22747487040056338, 0.01842540857802716, 0.08541339497652747, 0.11281090548201916, 0.016532087390641534, 0.0951926452257941, 0.013009687893152719, 0.005311721855128605, 0.004780812389893277, 0.06048342303162622, 0.0685475173316175, 0.11299700356058537, 0.02508571378946785, 0.06590302012139751, 0.08164343799674705, 0.06940323754303879, 0.06777643451407071, 0.041755020933886694, 0.020984276310510693, 0.09996112886696093, 0.030568850211678978, 0.0704773081346385, 0.045187294017523534, 0.09311413377403252, 0.047657111689688704, 0.1731806870309576, 0.27727130560144303, 49.418820411928245, 102.8737989548714, 74.56848529077347, 77.68695785153297, 50.776376262787856, 33.82060543183358, 23.084185930990405, 43.46880843562465, 54.767584031628026, 18.65446109925547, 0.4797939415420256, 1.9610087020743279, 5.06405298748324, 11.496169855517726, 4.054416764167048, 1.4334996789693835, 0.9415173398390894, 10.074055713991966, 111.21705685892414, 92.54748482857981, 101.80627884403353, 91.11216406668387, 94.35400301410307, 92.29827311731155, 92.31375079001151, 87.78351522261097, 88.36601072742094, 75.06571631277762, 71.96403149635562, 67.12677632608722, 66.68710216399163, 66.77705780152353, 66.9780243596723, 66.10539113321613, 66.0390873878233, 64.29472308005056, 65.16117857348534, 63.85628446455925, 65.66936085301062, 65.74529401717648, 66.24392140296199, 64.94080805009412, 58.378745509732155, 59.77898067043674, 61.910710411687056, 58.958193332918235, 62.60361279210737, 64.38721256871378, 71.15022597774383, 65.45058673427951, 64.24019428991502, 65.00618611612629, 67.56461481894216, 63.10065554034326, 61.7852298675045, 60.91169057353851, 57.084598695078206, 56.60845433512042, 61.602396426662324, 59.95120802233296, 60.12987198368196, 57.73591218456146, 60.64981352898383, 55.9248754285997, 60.510506629943855, 70.43506022422545, 74.49777280130695, 73.89910144190635, 75.67248344421387, 64.84550229964718, 62.439120354190955, 71.45704946210309, 78.34940694993543, 63.41400584866924, 64.17566345584008, 74.02237369168189, 70.73400758927869, 64.69420079262026, 62.540274358564815, 72.6387733028781, 69.88053906348445, 70.7857358071112, 72.13783171869093, 77.306731131769, 72.63826339475571, 71.2079397324593, 70.66717824628277, 65.67686434715026, 53.568515469951016, 55.63250587832544, 54.03096291326708, 56.90129456981536, 60.14611451856552, 57.56710121708532, 60.77535290871898, 59.147957601854884, 60.67930975267964, 61.990189398488695, 56.99197192345896, 55.747097922909646, 53.32208471913492, 53.80980791584138, 51.110958360856586, 52.9312244538338, 57.59534620469617, 58.440930766444055, 58.57496599997244, 57.17151449572656, 56.915481782728634, 58.33366178697156, 55.720178696417044, 60.558402692118, 73.59874202359107, 76.93056798750355, 78.99043990719703, 79.22187543684437, 80.8020414844636, 76.30673070107737, 79.13723068852579, 78.81569047128, 81.74075880358296, 83.1945853079519, 80.64819828156503, 81.75458123607021, 80.3400411913472, 83.55366260774674, 79.71250118747835, 83.9344306145945, 53.8784376267464, 1.5485613048076632, 2.434414634781499, 3.015305154746579, 2.6222287502981003, 4.066371167859724, 1.268238701647328, 0.7973946282459844, 12.395219264491914, 39.343679181991085, 43.52308619406916, 33.434969763601984, 27.37367230076944, 45.34705892685921, 37.173600427566036, 26.872650307993737, 50.11057353788807, 71.5808629989624, 66.62584258664039, 73.15002287587812, 17.866658933701054, 0.18650433499245875, 0.0660726473095917, 0.0653956477500258, 0.21606576809239006, 0.02536204170375582, 0.05795764263659235, 0.03698842952989283, 0.019371693788637078, 0.0752049592894412, 0.030001721066993572, 0.060909873535556186, 0.09781344733651608, 0.02406894082894489, 0.21309746849921443, 0.12076351866726914, 0.07815187736865013, 0.21768058950622238, 0.22626560061208664, 0.10935479940305795, 0.2565559816937293, 0.16254585446609607, 0.17663986512249516, 0.14382851850842276, 0.2135494910180569, 0.11707367916260997, 0.3687857481981478, 0.6020196539259727, 56.16569719006939, 120.35326896175262, 88.3804528943954, 90.17925970015988, 54.568143275476274, 33.090311096560576, 38.103782669190444, 82.07355622322329, 69.64413781319895, 27.912221570168775, 0.5309314136543583, 1.9562223072974914, 7.062056872152514, 18.673264941861554, 7.602944364470821, 5.760547278388854, 2.4626485907262374, 10.452414404961372, 116.31973097401281, 98.55843867025068, 107.19106551139586, 94.91407040626773, 99.7321294969128, 97.26120102790095, 94.9215699780372, 90.84935742039835, 91.16248023125434, 79.67196741411763, 74.58890514989054, 71.27135661340529, 70.64279679329165, 68.77450912229477, 69.70054934101721, 70.34392787564185, 68.1818546787385, 68.14304674825361, 68.41428649040961, 66.80561265637799, 68.52791755430161, 69.5433956576932, 69.17237866309382, 68.58224238118818, 63.884552986391135, 63.2708118807885, 66.33316316912251, 62.985871299620605, 66.66986726945447, 68.14936960897138, 76.29008416206607, 67.80480507881411, 66.37660734115109, 68.35332501319148, 70.86432441588371, 67.24904444909865, 64.71076496185796, 65.72658038908436, 61.63442650148946, 62.337574112799864, 65.54902253612396, 64.60064049690001, 64.80375651390322, 59.83472147295552, 64.40927590093305, 59.250021596108716, 62.879386794182565, 72.37805335752427, 76.95290196326472, 79.84851329557358, 77.45851116795694, 66.88654684251355, 65.7226501741717, 75.99420409048759, 80.60152207651447, 67.16556072235107, 65.9801184746527, 79.18378922247118, 73.82113256762105, 67.17779067254835, 67.04541067923269, 76.9441629225208, 75.31593999555035, 73.7760566896008, 75.91996931260633, 77.23856033817415, 75.52109564504316, 75.33420255107265, 77.26232205667804, 70.32840313449984, 58.01540067118984, 61.02773389508648, 57.940616761484456, 59.82553920438213, 62.02729894268898, 61.79658905152352, 64.14421389179846, 62.37642126698648, 63.22029175296907, 64.19943301908432, 60.71019057304629, 57.36336546559488, 56.794766918305434, 57.13173381743893, 53.70245656659527, 57.61458543039138, 61.64994339789114, 60.5699932959772, 61.59177464823569, 60.04092439528435, 60.21408919365176, 62.03642237570978, 58.80894322549143, 62.44541183594735, 78.68636992669876, 81.06584441277289, 85.23010715361565, 81.90953839209773, 83.01084579959993, 80.11759573413481, 80.87629979656589, 81.03646586018225, 84.42307164592128, 87.97921011524816, 83.60286481918828, 84.6850153707689, 82.77254612215104, 89.57762302890902, 81.4720215335969, 88.3651948744251, 54.74316335493519, 4.221555331060964, 11.157659503721423, 10.320526669102332, 6.196075495212309, 6.411252800495395, 1.260484298390727, 1.448573224967526, 24.628862373290527, 44.30905465156802, 57.0869795737728, 68.91902492892358, 41.76433855487455, 37.46251829208867, 28.815794452544186, 33.77892240401238, 63.627688730916674, 83.54531580402006, 79.56727935421853, 88.99831248867898, 18.54113009668166, 0.32055239283269454, 0.06925074774171076, 0.16175990954281824, 0.2801120821987429, 0.1115688241477455, 0.19180806894456187, 0.09889431312800416, 0.13855953430456502, 0.17152258164940343, 0.28263658705738287, 0.1503350717886802, 0.23313207732092953, 0.1471761541981851], [0.02738466895666094, 0.010981686533458773, 0.085572273951144, 0.022129068308840358, 0.02540962342473288, 0.01919874177885152, 0.12147784969138524, 0.0706275379765899, 0.19815732905220604, 0.1109644880277976, 0.06211597172002639, 0.026670041073474194, 0.35313291715518125, 1.0144290532315932, 77.62136797751151, 81.0550892737604, 73.48382442228257, 44.550331407977694, 36.65209777893559, 34.941944383805804, 83.78450978186824, 69.56762806061776, 39.52828161178097, 3.395911118676586, 0.06087471393027133, 0.9299983192355403, 4.261464466971736, 6.366649077784631, 7.9456379240559, 5.583636126210613, 1.1790214503003706, 41.10081080467471, 102.751326868611, 98.07187649511523, 91.0329871023855, 94.48858737945558, 93.2571671085973, 94.04826994865172, 88.34599095006143, 88.2604048329015, 82.41419838320824, 80.14625257061374, 74.66912546465474, 68.7157049486714, 64.7989437657018, 66.24018730655794, 62.37020823263354, 62.65246591260357, 62.132010536809126, 62.674238989430094, 60.80561007222822, 60.38333162184685, 60.171613847055745, 62.51905433593258, 61.82663832941363, 58.00634784083213, 56.87016664012786, 58.162007101120494, 57.07958198362782, 59.49092180498185, 60.31922440375052, 62.72320193629112, 61.051589750474506, 58.623897567872085, 60.549549902639086, 63.134007453918464, 58.63331517865581, 59.268456735918605, 59.213084636196015, 55.259531621010076, 54.03088446586363, 54.100863472107925, 56.631408045368815, 57.26852255482828, 59.76820591957339, 57.45238757902577, 56.03560001619401, 51.50716873907274, 54.94835038338938, 64.79251500098937, 69.7596908384754, 70.31167814808508, 71.7740083509876, 67.92772431527415, 63.86833790809878, 63.90824017986175, 73.11053245298325, 55.32744746054373, 64.07217171884352, 70.07103289327314, 65.01629798643052, 64.38769502024498, 59.77127713541831, 69.92439116201093, 70.65811757118472, 70.05193879527431, 67.45343915877804, 67.13748439665764, 66.37978446099066, 68.45952710797711, 62.95833626101094, 54.1755061764871, 50.22389865690663, 52.841559071694654, 48.81431648808141, 52.21245404212706, 56.96295422892417, 56.10862278169202, 54.13607066677463, 57.553443524145315, 58.782553518972094, 56.561699682666415, 54.21877384185792, 51.57731248486427, 52.02664352232411, 50.70944493816745, 48.71975206559705, 47.62901152333906, 52.836240337740996, 57.78416910479146, 52.81629900778494, 55.08505282863494, 53.22144846762381, 56.838520957577614, 51.96545847000615, 59.39783219368228, 71.4017048189717, 74.5660691107473, 73.61454133064517, 75.61254962798088, 73.07138719866353, 72.74801131217711, 73.90565180009412, 73.29827277891098, 72.89311547433176, 76.57105922698975, 75.85795664018201, 77.90395905894619, 79.98205431046026, 79.57200973264634, 80.29638521132931, 79.92023775654455, 77.83392906188965, 10.011006555249615, 1.4542899569196086, 2.743209600448609, 1.544964736507785, 3.1711806356906895, 2.8046721604562577, 0.08201844569656157, 5.312938651730938, 32.58266618174891, 27.912564777558853, 61.22365628519366, 50.157814564243445, 15.36382100274486, 13.049605931005171, 20.20414052471038, 32.03706645196484, 46.498933530622914, 56.76794182869696, 52.52461587229083, 35.21829105192615, 0.4948374262500194, 0.11536796907744101, 0.04497051028715027, 0.07165648598944949, 0.09456015537462889, 0.11327274924805088, 0.07050248178383035, 0.06355700991867531, 0.041020633727912946, 0.010576421233464875, 0.12750215062330808, 0.06901028806403761, 0.04158055590045068, 0.03341682420502747, 0.059544406080197905, 0.06683957026970964, 0.04100372616742407, 0.024751176599473245, 0.0973103957010373, 0.11002218455917413, 0.054633690555009155, 0.04302525216893804, 0.025272443890571598, 0.08525289189551147, 0.14378149603163043, 0.31830260710370156, 2.168732155715266, 92.38406319772044, 90.54090223004742, 83.49135183518933, 60.33453733690324, 44.29613044185024, 43.95197383819088, 58.53122372781077, 56.68840008397257, 49.5776254130948, 2.68794315957254, 0.15797067012998367, 4.0945183413644, 5.704477487071868, 8.743439682068365, 18.999315884805497, 2.2785903897977646, 0.7837718689153272, 44.54720527895036, 105.49380886939265, 99.19736139235958, 97.78282919237691, 97.39291421828732, 97.96498406317927, 93.6791592259561, 94.40246781995221, 89.00521586018225, 86.1940610024237, 83.21002375695014, 78.30109903889318, 71.99282169342041, 70.65282237145209, 67.77194346151045, 65.3308250058082, 65.72311693622221, 66.40321670040008, 64.1826609642275, 62.507797133538034, 63.949750623395374, 65.14397505790957, 63.94299237958847, 64.0121006196545, 62.448639946599165, 57.75519455632856, 60.639152526855476, 59.03580527151785, 61.39671910193659, 64.91381037619807, 68.4902157322053, 66.48190729079708, 61.307387121262096, 62.39528786751532, 63.908283325933645, 63.06616613941809, 63.16002061290126, 58.79516393907609, 59.00750929309476, 58.4042997514048, 58.33607404462753, 61.0723900794983, 62.563632072940955, 63.42873827103646, 60.370360343687004, 58.31597581986458, 55.116498470306404, 59.05670365979595, 69.5970929053522, 72.44096817508822, 72.12968103347286, 77.21606946760609, 73.18718341089064, 64.671909962931, 68.3301124265117, 75.36589530206497, 69.07787307616204, 80.12468737940635, 70.22059286794355, 68.50931767494448, 65.77934019027218, 65.42624058261995, 71.36512479474469, 74.68724681485084, 70.05036200246504, 72.28532068191036, 72.72138626344743, 73.70161794847058, 72.54575037187146, 68.968611532642, 59.582462080063365, 54.285171724134884, 57.046841959799494, 52.19907875983946, 54.92280790882727, 58.593393295041984, 57.99099568397769, 58.94907774463777, 58.59364040436284, 62.807305397525916, 59.65271565221972, 57.950367773732836, 55.54989684012629, 52.96413706194971, 54.23243153479792, 53.853875744727354, 50.21617551003733, 55.02014544702346, 58.62071260329216, 54.873323286733324, 56.27321720123292, 56.339509179515225, 57.26882849970172, 57.25338612833331, 61.68820611892208, 75.11350647095712, 77.08796485777825, 78.41037627189391, 76.10286943374142, 75.3610315630513, 73.60431963397612, 77.31007299115582, 75.97689859328732, 74.93912573783629, 77.70398093808082, 79.26830845494425, 78.25031218990203, 82.27893152544576, 79.20813929650092, 86.22620090361565, 79.10680878546931, 89.54365530321675, 23.28124776963265, 5.956570669527977, 0.7124822394501779, 2.990235570938357, 4.82369504628643, 3.6859360721803482, 0.1292576640844345, 1.505327837601785, 37.0799381502213, 38.74439593284361, 48.86415412349086, 32.82199352018295, 15.20803132364827, 12.114450124002273, 35.497575575305575, 48.03503174935618, 59.87701246815344, 67.26038009889665, 66.91175199324086, 45.026142366470836, 0.6897454240149068, 0.11492352316816969, 0.0499111109022652, 0.030468025379964424, 0.04070629253082218, 0.10971399504811534, 0.024317540190813523, 0.03374788910150528, 0.05546953844567461, 0.054254871567771326, 0.04442397933152895, 0.10062515855796876, 0.03826703793639618, 0.1388707805064417, 0.21503087523723804, 0.14909535766609255, 0.10699497280462135, 0.08103137971052239, 0.1442609751416791, 0.175219721971981, 0.11768919250537312, 0.24021149582920537, 0.22809282756380497, 0.15734716649017028, 0.17799323604952905, 0.43291077017784124, 2.375455282388195, 110.29967723354217, 102.50914404469152, 95.37387417208765, 63.983628134573664, 54.16136995438607, 48.863616758777255, 115.03033022726737, 92.65141979340585, 65.48322477648335, 4.540700451020272, 0.2237641243564506, 4.072992864155, 10.720270122251204, 14.613599065811405, 16.255109021740576, 11.856898473155114, 2.116127533297385, 53.06915852331346, 105.89345132150959, 108.90930683382096, 98.76840314557477, 105.04024167214672, 101.58953651305168, 100.94315344287504, 96.83629066713395, 96.03801773440455, 90.03870548740511, 88.61537933349611, 81.74591279798939, 75.7056902300927, 73.71288299560547, 74.1748675992412, 70.28349199602681, 68.06230083588632, 68.3092846408967, 68.82812792255034, 66.48875574911794, 68.05214189714002, 66.96394305075368, 66.67706874109084, 66.12630521097492, 67.25066046560964, 63.08290289294336, 64.82847921309933, 63.86958914418375, 65.84693831782188, 66.71783001192155, 69.19205327187815, 68.8100536407963, 63.113611129022416, 64.3309187120007, 67.64124224262854, 65.12377092915197, 67.53129036195817, 63.63839287911693, 63.38865949261574, 59.69526944621917, 60.91469903146068, 63.28620718371484, 67.11062400571763, 67.43981284479942, 64.76790605052825, 61.69417596632435, 57.823130007713075, 61.737133764451556, 71.48444329538654, 75.89602716507451, 74.8785408081547, 80.09202972535165, 76.13941807900706, 68.22798175196495, 73.57494108138546, 78.92453624356177, 66.1432812290807, 68.87152502613684, 73.62889720547584, 72.55736843232187, 69.33883620846656, 67.53780149644422, 76.56894899183705, 76.97387095420592, 74.63351034349012, 73.84070519478091, 75.17758231009208, 76.31958038576188, 74.82070938233407, 70.3783505962741, 61.78322553634644, 55.796429572566865, 60.256544928396906, 56.6881255180605, 60.778894808984575, 61.6892808483493, 62.54308669797836, 62.189171237330285, 64.27197333305114, 65.29858704536193, 62.05974478875438, 60.591613400367, 59.68914270401002, 56.22646647114908, 59.116849284018244, 55.32700815508443, 53.775106706926906, 58.80022379659838, 62.10613073841218, 58.097135020840554, 60.59714001993979, 59.409528701536125, 61.756765227163996, 59.3509873267143, 64.58895183378651, 80.47646122594034, 81.39140113707512, 80.97329216618692, 78.02653312683105, 80.54780129463443, 77.80368758786109, 80.88026139043993, 77.4207858116396, 78.71338721244567, 80.85942576008459, 82.73851563853603, 81.37955557915473, 85.93555327384703, 81.24202159143265, 91.37169945624568, 83.84986431367936, 96.54947127065351, 23.52889249401708, 7.703536979613766, 14.281933249965792, 6.010684178721521, 9.842946721661477, 7.860763717082239, 0.21163276967502412, 6.93493873842301, 55.658954420397365, 44.88289348540768, 80.88168128844231, 66.37538356165733, 21.633707169563543, 18.75140443924935, 35.47303330513739, 53.53219432215537, 72.5737560949018, 78.86959952692833, 85.37298340951243, 52.6599847116778, 1.0234887477371002, 0.2709006103536775, 0.20869686027928708, 0.17259355724578904, 0.17968633632746436, 0.2260358814871119, 0.1139243376711684, 0.09268662606876704, 0.13028105029896384, 0.13669145954472406, 0.27086009962424157, 0.20552752389302179, 0.09846818438100238], [0.14867419316884012, 0.023681334813215563, 0.050286643372307864, 0.0574549165884814, 0.1260614609946647, 0.11688053307514037, 0.09555478264848072, 0.08602875510170575, 0.1905889625871374, 0.14678013270660756, 0.15009931589086212, 0.17266900158457218, 0.7947116657610863, 22.828474852346606, 94.66785538581111, 66.92773957406321, 67.87015961062524, 27.118998689036218, 34.95368011536137, 48.129811902200025, 48.35569727805353, 55.634992661014685, 20.5629236467423, 0.14361050520693103, 0.5449180953925656, 2.260508018155252, 5.508924780353423, 3.91794377757657, 18.339484968493064, 0.5180040782978458, 6.020722994881292, 66.00151892631285, 75.67349541571834, 103.69181709904825, 98.57521072510751, 91.83043633737873, 95.46901518298735, 95.2152927460209, 88.10828747287874, 84.86989236647084, 81.45619084758144, 76.73949364692935, 78.20241220535772, 69.21237899411109, 69.06769844793504, 62.70863817584131, 60.25467788019488, 57.41644297876666, 59.82754353554019, 60.816808439070186, 60.10184272643059, 60.731845978767645, 61.6425536524865, 62.722621425505615, 61.63489718591014, 56.33504552225913, 57.36818998090683, 57.558236660495886, 56.78790669287405, 59.639250155418154, 60.52040669225878, 64.71141607530656, 60.044034834830995, 57.983445121395974, 61.36150406252954, 62.10034132003785, 56.804643446399325, 57.276786988781346, 59.518535290994954, 57.765545691213305, 56.87848206489318, 53.454719666511785, 60.87533412441131, 60.9601043885754, 59.88604960903045, 59.31303447292697, 60.439641168040616, 53.51516339086718, 54.200366158639234, 61.20067904072424, 69.34708887530913, 68.79057515052058, 73.97576808929443, 66.58537941594278, 68.82578234518729, 60.582282081727065, 73.5238012190788, 50.346437423459946, 61.24697085349791, 70.92982015302105, 62.321508084574056, 66.17298141602548, 61.810533077486106, 70.3469402559342, 68.63009529729044, 68.42967787096578, 63.57706269910259, 61.71490569268504, 62.26015044796852, 56.85140202122351, 53.03607333090998, 50.550286923685384, 48.77337478822278, 50.57717869358678, 50.36250737405593, 52.27133666315387, 56.16782703707295, 56.30375285302439, 54.64828122046686, 54.29313021321451, 56.15694638221495, 58.38306796166205, 57.125673755522705, 50.847994819764175, 50.63380202939434, 50.59785742913523, 50.0020533223306, 48.86109467475645, 51.64914284982989, 55.780457681225194, 53.27018783938501, 54.34099097405711, 53.92923624284806, 52.83263175718246, 53.34861563098047, 59.20014473699755, 71.58061196727138, 70.11847788287749, 67.2486835910428, 72.81978284159015, 75.4459273430609, 75.85594838665378, 75.72814187695904, 75.01846744168189, 75.48180918539725, 75.68631372144146, 74.8216978196175, 80.55782687279486, 80.37100438148745, 82.45019005190942, 76.68235255825904, 73.43207267022902, 84.29954836445471, 51.600560372875584, 1.8807565180524703, 0.3111662835844102, 2.349536260289531, 2.2641234628615843, 1.8368302622149069, 0.5129956405970358, 0.05017451874371018, 17.548229156001923, 31.24129991377554, 38.15986079554404, 64.05103014361474, 67.97640877385294, 69.11733212009554, 13.901580033763764, 23.653017859305105, 26.7461460251962, 55.6727062502215, 54.30331660855202, 60.2014591616969, 6.504516466971367, 0.2692659625843648, 0.07656505646845026, 0.06416355237184514, 0.0750506691814911, 0.09773935897335892, 0.08157085882680071, 0.20597844324525327, 0.03715506131430307, 0.04493511319460888, 0.1349030119637328, 0.04234043085166524, 0.05376515369261465, 0.02847699350827644, 0.04615281378069232, 0.06835992538159893, 0.051015782876000296, 0.051866232402502536, 0.08306973283329318, 0.036820637122277296, 0.07761055964135355, 0.04641601860883736, 0.15745547600090504, 0.17283593214327292, 0.3109995215650528, 0.7720959535048855, 29.614796946125647, 108.78543053903888, 74.05761226530998, 76.08462256769981, 42.97707657660208, 44.68171511926959, 41.88874044725972, 46.69476178384597, 58.46425710185882, 25.765057302290394, 0.14566483126292307, 0.46407467535426544, 3.949336957546973, 6.247079545451749, 4.945529257097553, 8.00874101538812, 0.6282007393817748, 10.682430036606329, 80.89392692812028, 81.9491700203188, 103.61438166710639, 100.75000809084986, 96.50161050981092, 96.26864525579639, 96.84078570335143, 89.18883769742905, 88.17708584570116, 88.13379072373914, 80.92237195660992, 81.82253237693541, 73.11297216723042, 70.08554566291072, 65.16694053526848, 64.4983607722867, 62.88534487447431, 63.08149868442167, 64.31992038603752, 63.216000680000555, 63.06500904021725, 63.57948672386908, 64.46696612142748, 64.16842668287217, 59.58078330562961, 59.494926544927786, 61.97240144975724, 59.99501697478756, 63.9686760594768, 63.27981372033397, 65.40861345106556, 62.232313386855594, 62.49109175897414, 61.51060904225996, 63.62862225501769, 59.643702045563735, 61.71394078962265, 61.93391515362648, 61.202844189059356, 60.40012328855453, 59.17640655271469, 62.23851073172785, 66.15696245624174, 61.674152266594675, 66.26539245728524, 61.27965988651399, 58.88403700244043, 56.785357152262044, 65.73122447536838, 73.35630032324022, 71.67954198775753, 74.46107510597476, 74.12153905437839, 70.73688660898517, 66.7379988393476, 73.04003961624639, 74.28477241146949, 82.43434367641326, 71.65648629588466, 66.75773620605469, 69.86985452713506, 67.12594478361069, 70.34778748789142, 72.04320846065399, 71.41731585225752, 69.97661359848516, 65.47856500071865, 64.93266913198656, 59.36609629661807, 56.956129304824344, 53.80199063208796, 54.05663874841506, 55.41843075906077, 49.972525719673406, 53.70742228723342, 58.53792705843526, 60.00104173537224, 56.35499469695553, 57.91413291808098, 61.219714303170484, 62.05324149900868, 59.41238810939174, 54.99392440242153, 54.342540310275176, 53.44987553934897, 52.374459697354226, 51.363029479980476, 53.950252302231334, 58.97437310987904, 56.758645811388575, 56.2225244891259, 56.88263585490566, 55.85264890424667, 56.62827407160113, 61.771564329824145, 73.38499638342088, 73.0268761419481, 72.03617172856485, 75.63566023303618, 77.01595798615487, 78.72413450671782, 79.57030742399155, 77.05070234114125, 76.75095481257286, 78.61190765134751, 78.21895676274454, 82.83784574077976, 80.18531153278967, 81.78723889012491, 75.96153074695219, 77.94865054468956, 83.66673669507428, 73.5339052446427, 2.858411083298345, 2.8655363138644927, 2.963665680539224, 3.394712344292672, 5.548858921374045, 1.487292656975408, 0.0984794611952478, 15.192984131074722, 42.4996417568576, 44.74371994695356, 45.37773970634707, 35.613034463697865, 41.0543542523538, 18.145635551021947, 36.337374641049294, 38.023009300231934, 64.88134491828181, 65.3668245192497, 71.81132578080701, 9.038073420524597, 0.3276171024528242, 0.060759758606793425, 0.07378142236942246, 0.049727717114071694, 0.04590436763640854, 0.009185235248878598, 0.1393081401024134, 0.04591164930212883, 0.09638813309251301, 0.09955857264538927, 0.021185096683761766, 0.014973452780395748, 0.20230767166902944, 0.17623020726586544, 0.1269341653753673, 0.1300092729469461, 0.26724710639926696, 0.17874308290981478, 0.1843717607158807, 0.13569225106508503, 0.31060244287213973, 0.23002503920466671, 0.34826550091947284, 0.35281538903232545, 1.1951644550408087, 33.92646628041422, 124.70358540934902, 85.44460588885893, 90.53785062605336, 43.08932696619342, 54.64286442725889, 60.08086196837887, 67.06412822969499, 78.32982647803523, 33.4186448589448, 0.2734510702711921, 1.086845628676876, 8.458835444142743, 10.448594016413535, 14.751429192481504, 31.454531723453155, 1.1658751363715818, 10.552129880074533, 86.6955203394736, 89.62638593489125, 103.70393722288071, 106.00049280351209, 99.21616523496567, 102.64262230165544, 101.90604825173656, 93.59228657137965, 92.87873683437225, 90.90469421878939, 83.98233059913882, 86.11870442667316, 78.63695590726792, 74.11248622402069, 67.45904030338411, 66.38415398136263, 64.39723422450405, 64.39035830959197, 68.13321728860178, 65.28540788158294, 66.87144571735014, 65.69444833263275, 67.42053047303231, 68.00170021672403, 64.78818470431914, 66.0215465484127, 65.80921296150454, 63.15889881503198, 65.97436043523973, 65.90113762886294, 68.16138775117936, 64.40841297949514, 65.79088764805948, 65.40549908914875, 68.02508538769138, 64.15731460817399, 63.53996492201283, 65.04815547697007, 66.86120048646005, 61.11478305632069, 59.946250146435155, 67.35789806612077, 71.1837387084961, 63.541200468617106, 69.75980850958055, 66.00944995880127, 62.14759019113357, 58.82109865065544, 69.90390070023076, 75.47458417953985, 73.48500113333426, 76.71394332762688, 77.36253861458071, 74.93343045634609, 69.02831000666465, 78.38183710652014, 59.71020975420552, 59.44852882815946, 75.0042998406195, 69.2622793874433, 74.4540854423277, 70.92582718018564, 75.7163590769614, 76.72541233801073, 73.04170270119944, 72.52581688665575, 67.16562348027384, 68.86906962240897, 63.03931751558858, 59.85146214885097, 57.807138504520545, 55.52316196503178, 58.14673339166949, 55.29175389197565, 57.677974854746175, 61.414252096606845, 62.771705965841974, 61.16129059945384, 60.93615047393307, 62.910867737185576, 64.08295431444722, 64.33924590387653, 58.41482347057712, 56.325263131049375, 56.829727003651286, 56.572168488656324, 56.544405952576675, 56.66042181753344, 62.74353942563457, 58.89179152827109, 60.03586453776206, 60.93461290482552, 57.267494893843136, 61.40912555879163, 65.36001920700073, 77.82023214524793, 77.20263927213608, 75.8310099570982, 79.16485201927924, 81.67381963422223, 82.79330330510294, 83.04732384220247, 81.86570982779227, 81.86620404643398, 81.7127295463316, 80.15792554424655, 87.50488573505034, 84.60836441286149, 86.9919103191745, 80.62941012843963, 83.26841215933524, 90.08287137554538, 75.70383887137137, 6.765636003786518, 5.326128602027894, 12.376687046020264, 6.250995051476264, 8.055673645388696, 2.050968384550464, 0.21881265295369012, 24.518757520183442, 52.639972779058645, 57.60522273279006, 90.43727321009483, 93.40431090324157, 94.59460904521328, 22.936902892205026, 38.63662881235923, 45.48984104587186, 78.44410081063548, 75.1458974038401, 84.76043470444219, 10.630955792242482, 0.49674130795944127, 0.29097180753465623, 0.16171307092712772, 0.1338128535257232, 0.2195275049175947, 0.18673347189061104, 0.39813966340115, 0.10655234252373058, 0.2372475169719227, 0.20739187546555074, 0.10243866487496323, 0.1488799184200264], [0.16721315321422395, 0.06315740313561213, 0.006232541345525534, 0.2410614397376776, 0.12195483135480074, 0.22510497740680174, 0.11773796166263281, 0.0780413921682104, 0.1642833418783642, 0.005684267061071531, 0.061685384341305306, 0.03976743645785798, 0.11379514460361774, 49.555632683538626, 88.85788379176971, 66.5629199243361, 51.708860935703406, 26.585256284283055, 84.19387186727216, 96.01609952988164, 45.506224786081624, 47.10552807777159, 7.520334835975402, 0.06849664143256604, 0.1398544527229763, 4.269066510661956, 4.196391855516742, 5.605711225540408, 3.262859174320775, 0.4796530426509919, 60.2342305644866, 71.18617842274328, 84.39009235751244, 96.54859265973492, 87.22956672791513, 90.82776085022958, 91.08682555537071, 89.7445277244814, 86.99085127922797, 78.00365786398612, 76.39174415219215, 76.23780681240943, 73.82649837001678, 71.23440788638207, 66.23588838884908, 61.62868415155719, 61.986235649355, 54.72017042098507, 58.64742394416564, 60.757286471705285, 60.67356740274737, 58.64196400488577, 62.58112584390948, 62.61650562286378, 63.20991316149312, 50.59101681555472, 58.03667168463431, 58.88949301935012, 58.64693757026427, 60.8084184892716, 64.34037162411597, 60.45284386604064, 56.06727707770563, 56.244356401505016, 62.329497952615064, 61.77853830399052, 56.201394681007635, 60.53371137188327, 62.5588507037009, 61.17590142834572, 58.3808086764428, 57.04899141865393, 63.543130274741884, 61.920088798769065, 65.32555726266676, 63.903415664549804, 61.55695576821605, 56.98134622266216, 56.41963927976547, 55.845808290666156, 66.56538317280432, 69.65012335008191, 73.460298045989, 67.60743925648352, 74.26086164289906, 63.748972339014855, 68.33234817750993, 35.98838175496748, 44.513198329556374, 60.965732989772675, 59.20371801622453, 66.53553393579298, 66.26873431667205, 72.28128848537322, 59.82572355578023, 68.89549855263003, 60.622556978656405, 57.57983323066466, 51.70573872904624, 50.025462027518984, 48.52371200438469, 49.99666006334367, 46.53683931596818, 47.724846793759255, 49.39101865214687, 51.26356209478071, 53.06999791053034, 56.57429049091955, 53.4180925738427, 52.50844394007037, 53.81856656843617, 58.6955161248484, 54.67321965002245, 50.63950515562489, 51.84604583248016, 52.354169276452836, 47.928711983465384, 51.98044584643457, 47.863031894929954, 52.044192206475046, 53.98909161167761, 52.16398531390775, 53.53238651829382, 52.250999173810406, 52.014366503684755, 60.25130071947652, 67.49123511775848, 66.83995692960679, 70.60729149849185, 73.22311232166906, 68.6885307681176, 70.10714223307949, 67.54047655290174, 68.95097655634727, 70.59496741141044, 71.91440566893547, 68.87412947993126, 72.41759869360155, 72.93907780801096, 71.64529969615322, 71.72147212489959, 77.13049903992685, 72.68175463522635, 83.92313418849822, 17.672070149452455, 1.8899876936789484, 2.914049413896376, 2.1512565257087832, 1.0957268553395425, 0.5360219146936172, 0.08805936307556207, 3.881015152700486, 53.1114455961412, 34.41171838391212, 38.995082455296675, 84.50423332952684, 122.99616198385917, 69.9143655838505, 22.607262980553415, 22.226891133093066, 43.92399949412192, 54.489056525691865, 65.45326963547738, 23.12058944855967, 0.43851022939047507, 0.12515191544568346, 0.12376787035816139, 0.02149097069406942, 0.07631528116161786, 0.05536012193788925, 0.16075127818171056, 0.17644484978049033, 0.03979350259948162, 0.10985716155940488, 0.07276427977147602, 0.21960829655008934, 0.10893050926707445, 0.11753167716726182, 0.04585063805983913, 0.28059738357701614, 0.06353290113169821, 0.06169653475104321, 0.061735785265843716, 0.05070890337529202, 0.043548195277370756, 0.06340399534711916, 0.08028318760015311, 0.06670135268641096, 0.004284951925998735, 62.87240105290567, 100.2495450358237, 75.57197663091844, 60.48969845617972, 31.755654042766942, 88.2769258560673, 76.7617883989888, 37.961173134465376, 62.91804959697109, 8.366092962603416, 0.1434581762840671, 2.3016796669652386, 3.741346905308385, 5.774613878419323, 2.175492851003524, 0.6458681978044972, 0.692532513170473, 71.89706879277384, 86.5565586090088, 94.89224633862896, 95.80950829290575, 87.22714270314863, 92.32127389600201, 94.2454396524737, 91.08022028400053, 86.28444810067454, 79.24352692019555, 79.91515436480123, 79.34481820752545, 79.80302164631506, 74.31754773662936, 70.06794991031771, 65.21256554511287, 65.59059965995051, 59.19735200943486, 64.1405660875382, 63.970750993297955, 63.615831405885764, 61.777698916773645, 65.2639054482983, 65.5639079309279, 64.61898149982576, 53.6234914102862, 61.02234063609954, 60.767751355325025, 61.35522042551349, 63.02938607431228, 66.1572213326731, 62.203625171415275, 58.73144503562682, 58.54053935697002, 61.97266817092896, 61.38533246132636, 57.56878783625942, 65.33849323949507, 65.98753959901872, 65.5276652305357, 62.48430213620586, 61.96751809889271, 66.41363451557775, 64.89244130349928, 64.83893625197872, 65.88749562540363, 66.09962524906283, 60.97066340907928, 56.68525826546454, 58.51447128480481, 68.049819853998, 74.13802869858281, 75.80217269159134, 72.37332297909644, 78.93089832798128, 69.1563283243487, 72.02409082843413, 52.259310676205544, 57.89057908519622, 65.70996915140461, 64.07966736824282, 70.61428900687926, 70.50778881196054, 71.55574414037889, 62.658051367728945, 70.13103731216924, 65.00324826086721, 61.041022885230284, 53.26538685829409, 52.92805517873457, 54.601942339251124, 54.8820819393281, 49.02423389496342, 51.646483482853064, 51.23999257241526, 54.13700811324581, 55.370064012465946, 59.50936478953208, 57.18931028919836, 54.471139138744725, 56.08903446505147, 60.26902983265539, 58.87330932001914, 53.81600133834347, 54.16434311097669, 54.57787859824396, 50.81774942336544, 54.05890980074483, 51.66328691667127, 57.63646833358273, 57.71829682011759, 55.03224595900505, 59.43358852017311, 54.32845900135656, 55.21311429239089, 63.80152033221338, 69.21747807533511, 68.14416070138255, 71.31662860993417, 74.80788323187059, 71.36233991192233, 73.80002237135365, 69.00585835979831, 69.65031162385019, 72.68170756678428, 72.66491982244676, 69.38704213788434, 73.88701269703527, 73.50986896022674, 73.95010009888681, 71.42929477076378, 81.71681665605115, 79.44395219126056, 90.61854946997859, 35.29090196855607, 4.007599844086555, 0.6799847284151662, 2.7758388173195625, 2.096331576185842, 1.9825597972639146, 0.023011369856014367, 2.112841077389256, 57.27331569117885, 45.53331659686181, 46.9149048097672, 86.76250657727643, 122.75643456366755, 56.33754014968873, 36.25715432628509, 32.947568201249645, 52.556802841924856, 63.56262053212812, 77.25788193364298, 30.268312846460653, 0.4300297892862751, 0.2108313804191928, 0.05417858453227147, 0.04287158642264624, 0.11383433000094469, 0.06312878975164025, 0.13873875291357118, 0.1429517002355668, 0.02941139669518077, 0.09166256569686437, 0.04650839732118672, 0.1676827191465324, 0.29451864140649, 0.2841734513640404, 0.18896427396084034, 0.4311849579455391, 0.21396005285843728, 0.3317743245392077, 0.15404448483980474, 0.19396606201846756, 0.32102258695710095, 0.20103743660353846, 0.38647321683745234, 0.10345899439867466, 0.314556559728038, 75.36246715053436, 113.29701915864023, 86.775175832933, 69.90929003684752, 42.22413055358395, 96.80287207326582, 107.4138169134817, 59.98142596214049, 74.8080244371968, 12.015589725586677, 0.32178165751599497, 1.5754023290449575, 11.201546903579466, 10.998646616935732, 18.99910996037145, 8.04498322548405, 0.4978573142040161, 72.98514212331465, 84.47905955776092, 93.33938783214938, 99.15271697505828, 90.3972101211548, 94.11643289750623, 101.41436346115606, 96.08681201934816, 94.56165329102548, 83.9947017546623, 84.63805675506592, 84.37118653328189, 82.4621375914543, 78.91343593597412, 75.51658491934501, 68.45325916044175, 69.73395224540465, 60.57897160130163, 68.49831150424096, 69.25010435042843, 67.64740820853942, 67.7283816183767, 70.24739050096082, 67.81490125963765, 69.15826597521382, 55.171517556713475, 67.23753621501308, 67.00688515940021, 67.4448727023217, 67.18339181715443, 67.58647811028266, 64.21982934398036, 61.13194734819474, 59.38082087424494, 69.50402290590348, 68.7507866274926, 60.579344226468, 68.77469739606305, 70.1756425057688, 68.10812980897965, 66.57542444044545, 63.789106030617994, 72.654658902076, 67.57569943704914, 71.46569436596286, 70.74958724360313, 69.03291486924695, 63.42309790272867, 58.56115925696589, 63.36300719168879, 71.82536002128356, 76.1859687682121, 77.5291608995007, 72.18044434824299, 85.19195033657937, 71.84062588599421, 79.35641273375481, 41.94761130117601, 45.657243882456136, 70.52204270516673, 67.36982991618495, 73.58498234902659, 72.15080691922095, 73.59097573064989, 62.61072404922978, 75.02911275432956, 65.28734553244807, 61.59700316767539, 57.879290503840295, 57.401118278503425, 55.939870649768466, 57.97334501820227, 50.774348397408765, 53.53417511909239, 56.54379014045962, 59.16232916616625, 58.02383376706032, 62.91118152679936, 60.31485096100838, 58.23379039764405, 59.04640351572345, 65.19954327614077, 59.829202698123076, 55.48335775252312, 56.328985460342906, 57.19605676589474, 53.02711463743641, 60.027403985300374, 55.26389329664169, 61.95891241873465, 61.313611922725556, 58.74226293256206, 62.01024447717975, 58.15455852016326, 58.19084436662736, 67.28811125601491, 73.86616137719923, 73.11044616083946, 74.28850650787354, 83.86018014723255, 75.88364032007034, 77.37742793175482, 73.21578533418717, 75.80340431582543, 75.50186818645847, 78.93838221027006, 72.4308406153033, 80.16915921242007, 77.18275285536244, 79.21689402672553, 74.99043033969018, 86.55820600448116, 81.73675014126687, 97.98466651670395, 34.9779321301368, 6.750880537494537, 9.449438856494043, 8.985320483484577, 4.294464347823974, 2.4406570869107402, 0.17522523780503582, 5.359987481947869, 72.75905670658236, 53.86953776882541, 60.573848985856586, 97.67524642329063, 138.07309396805303, 87.19195119796261, 37.833849076301824, 35.4817174326989, 66.464036972292, 71.0536180003997, 91.21432612019201, 36.56895137602283, 0.5686239201215006, 0.32814772559269784, 0.4074363242233954, 0.11814456282844467, 0.27733093788546903, 0.22226784738802144, 0.2785469645694379, 0.272743113098606, 0.11488199354179444, 0.33354824709315456, 0.18111735792650333, 0.26081466446480445], [0.13138187268087942, 0.022858924104741985, 0.026762879438578125, 0.2008488410783391, 0.0247472848728179, 0.1358980988903392, 0.034967148676514626, 0.04045637932816341, 0.05327750425485354, 0.054510143555460445, 0.18810371207373758, 0.2298623834165835, 1.922723549988962, 83.8786780449652, 76.65679439421623, 73.35895184547671, 45.7890433649863, 43.446360711128484, 48.57522056948755, 62.13630160977764, 58.57237331328854, 31.951058680011382, 2.5468479048821235, 0.025716261607745004, 0.708781115470394, 2.119222773659614, 5.7705076471451795, 1.5539503962762895, 0.5722008765705171, 42.99384078671856, 116.12012155594365, 95.83527042019753, 107.86759591871693, 92.67459315638389, 92.1022173666185, 86.23860343810051, 96.10390570855911, 90.42819684551608, 86.7675821242794, 73.64084474502071, 77.8869987303211, 72.88566297100436, 74.15831519711402, 72.73975864533456, 72.10220090804562, 63.450452512310406, 61.17154367508427, 58.112624460651034, 57.972937091704345, 60.32322522132628, 60.74679020912417, 58.54792910237467, 60.39796990732993, 62.154564165299945, 56.975525425326445, 53.16539779786141, 59.624804066073516, 55.48702516863423, 58.0660149358934, 58.98832890295214, 62.45344877243043, 56.743387791418264, 59.33116366786342, 58.752598377966116, 59.937781749233125, 55.230631597580455, 59.91980160436323, 61.98369395348334, 68.61751233377765, 62.39172635539886, 61.42323432430145, 58.87035185290922, 64.59824000635456, 65.6796923760445, 66.29835605621338, 62.42150106737691, 64.02885698503064, 58.40181296871555, 57.81108048654372, 54.373299537166474, 61.08224307337115, 64.14317446370279, 70.9327305516889, 66.26803613478138, 75.58583044236707, 63.15915376909318, 47.73663743849724, 18.200944892821774, 22.487059985437703, 48.93239159737864, 55.96135739357241, 64.97917275274953, 69.7165604560606, 73.41407683587843, 68.9874702884305, 67.66592964049309, 61.74728878082768, 56.93889833265736, 50.1487538891454, 50.604294038588, 50.10350542683756, 50.317733518538944, 45.5731168870003, 49.14367791145079, 49.935125920080374, 53.344967826720215, 54.50795842755226, 55.63374142492972, 53.46598079127651, 49.93874626774942, 50.58516463925762, 56.087700859192886, 58.314650058746345, 53.70087977378599, 51.54410569898544, 51.948902145508804, 48.95635335676132, 51.299012476398104, 47.54825384386125, 47.65102778711627, 55.28149297160488, 52.46825141291465, 53.49505732136389, 51.8809078585717, 52.301915461017245, 57.0412878836355, 62.203680084597686, 64.71011777077952, 64.76916905372374, 65.90226727147257, 65.51932627154936, 60.161486287270826, 62.60637414070868, 62.70485308862502, 62.41212268029491, 61.310791738571666, 63.08579367976036, 63.378018102338245, 66.35074323223483, 65.8211212773477, 68.65423356333088, 71.89320918052428, 76.89788679922782, 75.72302710625434, 69.10239573447936, 1.8293200265015326, 1.8215396375425401, 5.2504425471828835, 2.4600843412260858, 1.5392218962792428, 0.29709190010063113, 0.2093980758781395, 33.233371703855454, 69.05105975366408, 32.380089490644394, 88.23641561692762, 100.66035055345105, 115.74671976027952, 19.613655151859408, 20.166511266462265, 45.69595375368672, 64.29180091427219, 67.14505457109021, 53.042961012932565, 0.9567365038298792, 0.0745817237804013, 0.0446338337966271, 0.16575179453338348, 0.014904121823248365, 0.06763617913689345, 0.06905371758846507, 0.1642134899814283, 0.06484692195250143, 0.12341795969874629, 0.03743346532686584, 0.05791338573720667, 0.11308985341700817, 0.01146773293223833, 0.033636561204348846, 0.14108146510777936, 0.056701997715619304, 0.13008618817454384, 0.046250589582468235, 0.0307125874584721, 0.04965626409337406, 0.08622952376402195, 0.13356916095700958, 0.19670375382467625, 3.0105706088004576, 96.18054097698581, 84.64341471272131, 80.3482703239687, 60.1500565005887, 52.68531537825062, 60.98721973357662, 62.165315381942264, 61.953248516205825, 42.319322555295884, 1.3172253053034506, 0.09853794434738737, 3.19819399906743, 3.870243343614763, 2.7003361332801084, 0.5665614888552697, 0.9081800125779644, 61.90014746881301, 116.96634154165946, 96.91832311691778, 107.99856385877057, 97.72263649971255, 92.17771514769524, 88.61843878223051, 96.35343120944117, 93.87459524216192, 88.70485644186698, 79.73491361064296, 81.84291301235076, 76.65391537450975, 77.2750932939591, 76.68938144560784, 75.14956089758104, 64.56932429344424, 65.3203248208569, 63.228583643513346, 61.80848952262633, 63.206281046713556, 64.02922176545667, 61.280789529123616, 63.09557999334028, 63.24925845669162, 59.183631558572095, 54.463168882554584, 62.43089514393961, 58.755308735755186, 62.042247095415675, 60.33920887977847, 64.16365315837245, 58.54326932660995, 60.642078615004024, 61.0666085058643, 64.20466153852402, 58.396859015187914, 63.20235475417107, 65.9224517883793, 71.17072428426435, 65.25132248478552, 66.51305875470563, 62.014539472518436, 69.33188576852122, 70.17109255636893, 70.58489476480793, 67.05070587896532, 67.76264744420206, 62.087903484221435, 61.40633283122894, 56.452344002262244, 62.53863088546261, 66.9457197189331, 74.78241920471191, 70.0710250485328, 79.75221910784322, 62.32646988284204, 54.4674599555231, 26.073979254691835, 29.274474459309733, 54.998513575523134, 57.83963141902801, 69.4187270441363, 71.92725535361998, 74.84596160150345, 71.20099713725429, 70.28965796193769, 63.202896041254846, 58.74752283096314, 50.25693285849787, 52.6737992994247, 52.731183575045684, 50.796686295540106, 50.60088942127843, 51.931251479733376, 52.82894080685031, 54.90263908140121, 56.864887129875925, 59.1241801938703, 55.19929970464399, 53.266132108626834, 54.01100589383034, 60.33103858270953, 60.72530346532022, 57.67532333250969, 55.11525507896177, 55.371138741893155, 51.46499933735017, 53.210277557373054, 51.929470723675145, 51.210053120889974, 58.617531561082416, 56.65736236879903, 55.86855019292524, 53.59860789391303, 55.34343504136609, 61.020053894289084, 65.59554969110798, 66.28784410415157, 67.95435720874418, 68.51811947361116, 69.7349799063898, 62.17181474931779, 65.49315229538949, 62.985930135173184, 66.16735673719838, 61.4919856286818, 65.2210888554973, 65.68966304102253, 68.75846662829, 67.60180673291607, 71.76646171077606, 73.4161086236277, 82.35075012330087, 73.98429532204905, 82.63374128649312, 9.932279682928517, 2.592875202817302, 2.596753691473315, 0.7498102719264647, 2.8710222388467486, 0.7252653051287897, 0.35137045527658156, 30.489307026709284, 78.50037113312753, 40.862385611380304, 89.27061911552184, 103.68525889612015, 109.3207791543776, 25.88937290253178, 28.041587222007017, 56.39170415939824, 72.80701160430908, 74.49044581382506, 62.12563668527911, 0.8647817445378151, 0.10075769176886928, 0.08461500112448009, 0.13690726651299384, 0.04249554067369431, 0.10818325944485203, 0.07235456062781234, 0.0247891649844185, 0.09109368412605218, 0.07387385853836614, 0.048524549215911865, 0.04202734603877029, 0.3084392863656244, 0.1311151974744374, 0.2858079152722513, 0.5378532325548511, 0.28807961111587865, 0.2612002518388533, 0.1895739726962582, 0.22382122855032646, 0.19394458091307074, 0.243598738264653, 0.25416670667548336, 0.2454461592940554, 3.662119930790317, 112.2211757782967, 93.88611916572818, 91.89152333044237, 62.66843388157507, 60.50386605724212, 57.29239802206717, 77.64741251545568, 79.76892840477728, 52.84120998074932, 4.127309601153097, 0.29799637414755364, 3.91002647338375, 8.703282456244192, 16.306312622562533, 7.600810595097081, 0.674683828988383, 58.647302350690296, 120.22065362622662, 101.7716835391137, 113.48720704355549, 100.75968065569478, 95.56820407990487, 89.39925716769311, 102.12253170628702, 99.32501885198779, 92.43624641049294, 82.68874076104935, 85.97821297184115, 80.52655773778116, 82.66197450699346, 80.95661424821424, 79.48709041841569, 68.34938695353847, 67.83568982155093, 66.99634967311736, 64.2004685248098, 67.97973494375906, 68.87262328978508, 65.06993247616676, 67.78117672089608, 68.10911040152273, 63.342293154808786, 58.52998425883632, 67.57675063225531, 63.71875832157751, 65.58821878125592, 63.97420267904959, 67.5980334128103, 61.876927037392896, 63.51242203866283, 61.57238245010377, 67.1552448887979, 63.18615144298923, 65.12726968334567, 69.0248740103937, 74.93234003743818, 69.65624224755072, 69.20189842101067, 64.75538192256805, 71.70133467643493, 75.28602015587592, 74.67007467823645, 71.53729331108832, 70.8862033967049, 68.29260672292402, 64.78721980125674, 60.18503227541524, 66.29237051933043, 70.520614962424, 79.26340549222886, 70.87724470323133, 85.3374545804916, 66.83899202654439, 63.76276339254072, 25.009406805038456, 31.224518052993286, 61.17021006922568, 62.08967639553932, 73.23225144417056, 75.48173858273414, 79.06203100758215, 72.89616707832583, 72.3576727221089, 65.88627184590986, 62.23006194637668, 54.454826001198064, 57.31468100701609, 56.185614985804406, 55.286792093707675, 51.158595546599365, 56.052544655338416, 55.703916549682624, 61.51987760297714, 60.94079063784692, 64.99399538963073, 59.942343465743534, 55.93189647120815, 55.091305086689616, 63.53622298086844, 62.31182375261861, 60.05236594907699, 59.59796720935453, 58.438306700798776, 55.32114421167682, 57.73214670919604, 56.374841890027454, 56.017725775318766, 62.77629121657341, 58.53131001995456, 60.137293108047984, 56.936874389648445, 57.98999155721357, 65.20632897653888, 71.6317439848377, 70.31336476725917, 73.06606061996953, 73.88021915189682, 74.53900475655833, 67.45747135531518, 69.68274962517523, 68.37671802889916, 69.06558036804199, 65.71007113302907, 69.56460783558508, 70.5580186843872, 74.61480848250851, 71.75372969719672, 76.25097813144808, 77.94561463017618, 87.58369399655251, 78.77623142734652, 87.11602195616692, 10.025390867264042, 4.91352173589891, 15.255714597240573, 6.896232789562595, 4.941202882797488, 0.778556035891656, 0.3869472107579632, 42.67341060023154, 90.48042712673065, 50.033569566665165, 96.86137814675608, 101.3709742023099, 127.38697298111455, 30.278652214234878, 32.89843659247122, 64.74610943948069, 83.40273764825638, 84.71697484293293, 74.16185317500945, 1.386694035703136, 0.16569309687662512, 0.24400838079952428, 0.39964392300575013, 0.16917401654345376, 0.2518450465774344, 0.2748296914562103, 0.31096731522871607, 0.2178861615398238, 0.24876535780006842, 0.19177037741868727, 0.10315248262017004], [0.07886216344852602, 0.04415407506448608, 0.09429274472377955, 0.03861982908640658, 0.043277398517896096, 0.0754731513499733, 0.09461571973177696, 0.1540324879029105, 0.07125639657099402, 0.10190614183703739, 0.24853585317971247, 0.6618425406275258, 15.03386632088692, 93.85827818224507, 65.99672578996228, 65.6320002771193, 34.4903697506074, 33.751508958878055, 55.84271746297037, 40.141148028835175, 37.865973288013095, 18.764738536650135, 0.41657851107658883, 0.17320946129339357, 4.290326737588452, 1.9716811035909962, 2.7231035309453167, 0.9133974390645182, 22.412634972603094, 116.5125076232418, 87.9092977892968, 90.34925522342806, 85.93239184348815, 94.78240428432342, 90.1331247821931, 89.82838015402518, 90.30429701651298, 92.97989476111628, 87.5810895427581, 80.7493797425301, 72.57678416467482, 75.94066373763546, 75.08185294366653, 73.40271765185942, 71.44309366902998, 67.39699625199842, 63.404976552532574, 59.64609861373902, 59.691429445820475, 60.39134110173872, 59.13742996031239, 59.11687281823928, 57.49441185305196, 62.02075250687138, 52.52848332928073, 53.79745244979859, 57.6082782591543, 54.757652590351725, 58.34890803983135, 62.8227085451926, 60.06445469394807, 56.06311544295281, 57.916392203300234, 60.59087991714478, 54.15382331417453, 57.60165337593325, 62.7150002602608, 67.75961937442904, 66.08711288821313, 64.47276338454216, 66.45357993341261, 63.46955837741975, 65.12940345271942, 65.57351773785007, 66.00020100993495, 67.21916383312595, 65.37633234454741, 61.08658905952208, 58.57958655203543, 55.71289485500705, 54.1237622691739, 58.5328632785428, 65.04060491438835, 67.87277190916001, 71.78516357175766, 56.25579403292749, 39.185988133953465, 15.261856048337876, 15.436601561884727, 39.10197488723263, 48.530980156313994, 67.79339098161267, 66.55919367267241, 66.8913007551624, 62.847525381272845, 65.5116541154923, 58.29073929017591, 51.558320368489916, 49.19482561849779, 49.830759494535386, 50.333372008415964, 49.196233749389656, 46.403137483904445, 48.3692333775182, 50.78516237197384, 50.70266708250969, 49.62576466221964, 52.881606471154, 54.35347587831559, 51.14268249081027, 49.53708771736392, 54.18354703534035, 54.56545645190824, 56.959890857819595, 52.91117721988309, 51.157599264575595, 51.38533207678026, 50.09404074761176, 47.08212721732355, 44.768336742155014, 51.63308074397426, 52.87041202668221, 51.998480904486875, 51.46468947010656, 51.052142420122706, 55.52125961549821, 60.023960144289084, 58.7403448935478, 61.118979992405066, 61.69375627271591, 57.641461510812086, 58.28806423371839, 56.23467991428991, 57.82669151982954, 57.00316636793075, 55.917426847642474, 58.224816014689786, 61.869721643386356, 66.79922703773745, 65.9725090765184, 73.30976532351586, 70.85576580416772, 75.27822248397335, 76.16071654904273, 81.29251034029069, 45.2805825971788, 0.7522158492957393, 0.3975040555721329, 1.0763882220752778, 0.7334266542907685, 1.6502817239492171, 0.09226003000813146, 4.827862564594516, 71.65975755260837, 42.86621078368157, 51.60655375449888, 100.51228892418646, 56.50444092289094, 38.033576165476155, 30.178494491884788, 24.518369205536384, 60.6955954336351, 63.76333605858588, 68.49405181023383, 4.993359129275046, 0.21355888325600855, 0.1407748767204823, 0.11867387595796779, 0.021953931033250787, 0.03219631590670155, 0.1621383569774128, 0.054884350693394104, 0.05326682881962869, 0.058515209088762926, 0.07395081207036011, 0.04922432456946662, 0.0369833235538775, 0.036886673901350274, 0.013917930135052773, 0.11549681740542574, 0.06827108216502013, 0.17991490632055268, 0.0904075451375496, 0.1649323715678146, 0.10008732653072766, 0.22078618737718753, 0.34447443821737844, 1.0313755922740506, 18.7299176954454, 106.68290676609163, 74.89041774503647, 77.18942088465538, 51.47844522230087, 34.801672581703436, 50.68375733590896, 38.6445520001073, 46.458721391616336, 17.934627725232033, 0.18877403900748302, 0.3338558160729947, 3.9372222269735033, 3.211891406005429, 1.8152714448590435, 0.7921168953180314, 33.13783061119818, 119.25294999153384, 88.93569577124812, 97.1214234444403, 86.52373621540686, 99.23136834175357, 91.39718701762538, 93.75747326881655, 93.79508879876907, 96.02444633360832, 88.03002049846035, 85.22969922711773, 76.43535306376796, 77.64774199455016, 77.34208737650226, 78.39368266444053, 73.30641561938872, 74.47836491369432, 68.05996310326361, 63.56460525143532, 62.97793634476201, 63.98656206746256, 60.83714592841364, 60.956405593502915, 60.67797614682106, 65.41324577023907, 55.851891886803415, 57.09000764354583, 59.50309684199672, 59.53158893892842, 60.733842465185354, 65.14615981809555, 62.85209886489376, 59.44302182043753, 59.61495499457083, 62.7927141804849, 57.70618454102547, 61.89882955243511, 65.7991873833441, 70.82002516715758, 70.80207640124907, 68.6542021843695, 70.61160610568139, 66.79578319672616, 67.66032065114668, 69.17524199331962, 69.45218486170616, 71.98556530860164, 68.65743421739148, 64.59325859623571, 61.22626858372843, 59.04590145234139, 56.44932377722956, 61.05450407151253, 66.72014421032321, 71.54857404770391, 73.31400932804232, 58.04079017331524, 47.18047672702421, 19.540538249477265, 19.763411245038434, 47.6277445977734, 53.26635176135648, 71.52315708898729, 68.27425003051758, 69.1786152316678, 63.666782994424146, 65.8455890224826, 60.29938113304877, 54.3828465861659, 53.00043467552432, 53.959775817009714, 53.064177113194624, 52.081011495282574, 50.095845037891024, 52.835142074092744, 54.475845982951505, 54.93357481495027, 53.67709452106107, 56.961997170602125, 57.02073466393256, 54.17045024133498, 52.38389299761865, 55.49583088967108, 57.97517676507273, 58.4980090971916, 55.0251543137335, 53.25288234218475, 54.20949743640039, 51.98447412060153, 50.644486565743726, 48.79443791604812, 53.44474507916359, 56.188470471289854, 55.407024506599676, 55.500016058644945, 54.636314069071126, 56.70878071938792, 62.18489585384246, 61.87424021382486, 63.47586947102701, 65.51763965237525, 59.69878388989357, 59.80364453408026, 56.78190938888058, 59.69802687245031, 61.18094951875749, 58.79694861750449, 61.71179133076822, 65.58432779004498, 70.59256692086497, 70.17992573399698, 75.09263161690005, 73.73574256896973, 78.1570460719447, 79.82689319118377, 83.03825532236408, 51.82341767895607, 1.4017331383882032, 1.066200968719298, 1.3664690693539958, 1.9188369714444684, 4.583659720036292, 0.18724517265875495, 4.546182453632355, 75.52182520589521, 52.78413949474212, 56.907848850373306, 97.76865374657416, 58.19076199685374, 35.293584869753936, 39.40406407079389, 33.89161209906302, 66.03697715267059, 69.47626036982383, 79.4590925401257, 7.154621376145271, 0.3285927001026369, 0.1035209785726282, 0.07423473957685695, 0.0682742078037512, 0.08243096106114887, 0.060951468279404994, 0.05346405432529507, 0.08130742417227838, 0.07368533196107996, 0.20637500099837783, 0.04915898876084436, 0.12603844771341932, 0.16804628915363745, 0.15677499074128368, 0.13637716431290875, 0.16542321942265958, 0.3780015714226231, 0.29282261467268395, 0.2556817527980574, 0.20058716076516336, 0.2674214680108332, 0.5190933940391387, 1.2068304419517517, 21.622700998860022, 121.34973141454883, 82.19155680748725, 86.70313758234825, 49.31146906268213, 45.733655575783025, 64.92679342146843, 57.7762576841539, 58.60256379650485, 30.377923480926025, 0.6631185366742073, 0.43540640884349424, 11.014694994495763, 7.120404089650801, 14.089605712121534, 2.580698694913618, 34.54669498628186, 125.18879044440486, 95.39772218273532, 99.54726819069155, 91.82263866547616, 105.6696879479193, 97.38640308380128, 95.00291993541103, 95.90247631073, 100.28849417163481, 95.4908549401068, 88.56718909355902, 79.76313898640295, 82.02666036544308, 82.55231288171585, 82.52788436028266, 78.66154916824834, 76.11032978180917, 70.347960072179, 67.20720844884073, 65.94959458997174, 69.39636168941375, 66.14408923733619, 64.03774507584112, 63.418685236284816, 69.72388744354248, 58.091800597406205, 59.886634042186124, 64.20280233506234, 63.90473750329787, 63.67180362824471, 68.95201206207275, 65.70065352224535, 60.28973602479505, 61.883202829668605, 67.55981383785125, 60.96637625848094, 65.24845523218956, 68.17554750750142, 73.00388320799797, 73.03370891078826, 70.70195398023053, 74.07240744559996, 68.55485639264508, 71.26970137319258, 72.30932558736494, 71.85880999411307, 75.20692948372134, 73.28249700607793, 67.26615382779029, 65.2871690257903, 63.19548668399934, 58.5764878795993, 63.89123670516476, 71.17587827867078, 73.31516250487297, 76.31131987417899, 63.54196140843054, 55.139248217305834, 20.4598908270559, 22.088317717275313, 54.576964685993815, 56.53993445058023, 75.58319460961127, 72.40459211411016, 74.6804375802317, 66.88106336901265, 70.08930329353579, 64.14146823267784, 56.39889778629426, 55.20635997095416, 57.111890546737186, 56.272138549435525, 57.336563910207445, 52.658960973062825, 56.507559207177934, 57.89316784950995, 57.28936210755379, 55.77973596511349, 60.19437928353587, 60.26603706421391, 57.75249988802018, 56.47727066470731, 60.86761882228237, 61.6876373752471, 61.8951895929152, 58.55990409851075, 57.573267182996204, 57.145411122229795, 56.182759500318966, 54.07841182524159, 53.97288045575542, 55.726093630636896, 58.697085072917325, 60.41696594607446, 56.82868757555562, 58.75578334254604, 60.72930428289599, 66.48514716855942, 65.37977226318853, 67.85048500184091, 70.60814657518941, 64.26474048245338, 63.94325517839002, 61.89860205496512, 64.42042327696278, 64.2980767065479, 61.691763708668375, 65.83300605896981, 71.54384366927609, 73.2848112044796, 73.18662643432617, 80.82510502107682, 77.14795358719365, 81.39593539699432, 82.84162690562587, 87.73057107002505, 55.011312269395404, 2.9250935825609394, 9.222286555074877, 5.286455788920003, 4.195168076022979, 7.441937442748778, 0.22244285251344406, 7.4268598518063955, 89.19692562472436, 59.47143546996578, 70.03839877343947, 101.36186645876978, 69.70431481638263, 52.037006424319365, 42.296341388456284, 40.45959741838517, 80.28843064461985, 79.27142281686106, 93.12489694164645, 8.749570346647694, 0.4030902461419183, 0.21703627891838553, 0.15503977094927143, 0.16613278537988665, 0.2354075729606613, 0.338188840016242, 0.18783673043212584, 0.09046101807466439, 0.13455692408305986, 0.33898076042532926, 0.16047691145250875], [0.0680887915434376, 0.04851811024690828, 0.07613709677130946, 0.0782138845252414, 0.18247391577930222, 0.043725743814702, 0.1036930419204216, 0.058238004003801656, 0.1461206995431454, 0.13759574973054473, 0.35535763648729174, 0.5018051184954182, 21.63496428920377, 85.38744911070793, 65.17496570464104, 54.05607784948042, 36.055524887577185, 41.37274480635121, 55.68866245208248, 57.18736871596306, 33.366367509288175, 6.524922597792841, 0.3658459930410308, 0.5543683721653877, 3.716570273522408, 1.6552282004587113, 2.2081919350931725, 4.391801886020168, 100.9951562266196, 99.74817983565792, 92.29231111464962, 91.63619272170529, 87.94364990726595, 91.85833223404424, 91.66462990545458, 88.50889482805806, 86.36670020318802, 91.94729158955236, 82.52356975309311, 84.53004252526068, 76.83188899870842, 77.2883273709205, 78.01136139900454, 79.6973765280939, 74.76135607688659, 76.99870740213703, 69.90507741128245, 69.2798202268539, 63.36245021512432, 62.74996034560665, 59.97398130355343, 58.63222083737774, 58.68555330461072, 57.47215632469424, 51.82584562609273, 54.31018860109391, 56.90074543799124, 56.50307593807098, 61.01845748962895, 60.40092737443986, 57.436011683556345, 57.901542109827844, 59.05449144301876, 54.12678249420659, 54.2169342502471, 60.95889237619216, 68.57374652739495, 68.39258793861636, 67.55403226421726, 70.37883697017547, 68.65878351273076, 67.2730101308515, 66.61669561939856, 68.1060274185673, 68.212049084325, 66.89803938711843, 65.5833471975019, 63.10042804287326, 59.06654096418812, 57.54642640390704, 56.863886925481985, 55.01553273970082, 63.45770497475902, 66.74257232296851, 68.89097998219152, 47.73685316885672, 45.99901176268055, 25.466651224320938, 23.104146872797322, 43.37576589276714, 51.4275485469449, 64.08993221098378, 64.20624225370346, 63.62530392985191, 55.47179068288496, 53.77629518508912, 50.21241395704208, 49.33447376374276, 49.77760745633034, 48.8157912992662, 47.99217201048329, 48.23622580497496, 46.70250062019595, 49.48249224693545, 49.979801716343054, 50.930395972344186, 50.59986960503363, 52.4629169894803, 53.40108909914571, 51.71375605367845, 49.17747305285547, 50.76431105213781, 52.38147289522233, 52.896021181537265, 55.62649680722145, 51.88334365044871, 49.626658962618926, 48.83521095398934, 48.03557303643996, 44.032456951756636, 48.54879948400682, 52.182161577286266, 52.69321110940749, 53.30792888518303, 50.88504945078204, 54.98894691467286, 54.45800312103764, 56.54454323553271, 55.761571468845496, 55.99390129889212, 56.14979982376099, 56.528022212366906, 53.4360295726407, 57.613079240245206, 55.983228529653246, 58.923037129063765, 63.048166382697325, 68.27155143983903, 70.30418642105596, 74.56401378877702, 71.60213009003671, 77.62688282997378, 75.44638233800089, 79.48346614837646, 71.58792326527258, 59.406912480631185, 8.777983996175951, 0.7359405258490194, 0.5346079002464972, 1.2259808014477453, 1.4088761421941942, 0.15692021036821027, 0.18628333394806232, 42.675544369605284, 67.65393503250615, 37.69791933798021, 39.03249402200022, 37.334468595443234, 43.24061278373965, 22.338847344921483, 29.664665960496475, 55.17630677069388, 57.94357030622421, 73.81129526322889, 20.577377580827285, 0.38520025449895096, 0.20448858609362958, 0.13955074482627455, 0.08073715598232324, 0.05826924506935382, 0.13029562129128364, 0.025473411735748092, 0.15192543967596947, 0.06535846950306047, 0.05863613989805022, 0.058014938352449294, 0.05928181412239229, 0.07543648638191723, 0.13536523877372666, 0.04277420898659095, 0.026835454778084834, 0.021365910670870257, 0.06566695012753049, 0.042289206382608226, 0.07370682838823527, 0.11900635811710551, 0.32947428344238194, 0.5487848169380619, 27.920550723229688, 99.91414316238897, 72.17452941402313, 65.54891270975914, 38.61027048480126, 33.13948977378107, 49.9908039646764, 57.339862623522365, 46.30529003758585, 5.469194602581763, 0.4309272766113282, 3.2249470151239827, 6.094587599077533, 2.2470123681329914, 1.5877380606628235, 8.665575731185175, 113.43136818178239, 99.7122117011778, 100.17433751013972, 89.64828844993346, 91.19405531114148, 93.50988541879963, 96.93208279148226, 89.73095632368519, 88.17227701986991, 93.41951401002946, 87.37524355611494, 85.63979871811406, 82.01386559394099, 80.40512900198661, 80.68767301497921, 83.59652626898982, 80.69016764240881, 77.62551784515381, 74.86518906008813, 72.18669660629766, 67.28042341047718, 65.90008643365675, 63.73212183675459, 60.27929859776651, 61.747210333424235, 62.21529422267791, 55.69274956180204, 56.247819854367165, 58.67475109715616, 59.65048774596184, 64.40280006777856, 61.24234637906475, 57.84667599585749, 60.760545961318485, 61.138168227288034, 58.36616254621937, 55.867475463498025, 65.39945471671321, 73.39431593495031, 73.94297707465388, 71.27881696147304, 72.46785210024926, 72.4238823306176, 68.90796384503766, 70.05878725359517, 71.33021570021107, 72.71928387303507, 70.02801233722319, 68.98988646845665, 65.5344509309338, 62.72213505160425, 60.38316295992944, 59.00476363397414, 58.49527128281132, 66.57868785242881, 70.73453318688178, 72.56101623658212, 52.17186143321376, 51.08243880733367, 32.941806239466516, 29.557775489745605, 50.592573996513124, 56.99460383384459, 67.1527345718876, 66.14543068793513, 66.81392023640295, 57.08863873635569, 57.47687885838171, 53.85302066802979, 54.176416166367076, 51.8445945555164, 50.60928721581736, 51.54524318633541, 50.76219297224476, 50.20686772561843, 52.970632506955056, 53.37411495947069, 55.3358962458949, 54.949197615346606, 56.340791794561575, 57.36667986839049, 52.91902980496807, 53.35567197492046, 53.81455398374989, 55.108900839282626, 56.2055798499815, 57.23244459398332, 54.94403577619984, 51.70105934143067, 52.124349763316495, 50.49469909360332, 48.97111323571975, 50.919770271547385, 55.32948317066316, 55.10709654900336, 55.89047624218849, 53.09158663595877, 58.18242696023757, 57.57112164651194, 58.83738040924073, 57.43066549301148, 57.77963484487226, 58.04481452511203, 59.15180152462375, 57.81765045658235, 60.6066321557568, 58.17484894106465, 63.94897399410125, 66.24676119896674, 70.96449390534433, 73.24768204842844, 79.7145486647083, 74.59550257652037, 80.13476002600886, 76.74107043973862, 82.26070819362518, 72.1329366007159, 67.66530206126552, 19.69225552774245, 0.9693150546762251, 0.3378793404948327, 1.0328182890530557, 1.927666104128284, 0.30822122709885724, 0.23529082116100097, 43.359892060679776, 79.14007832927089, 45.85455086923415, 40.52927047975602, 42.7316774091413, 32.275226885272616, 29.078956073330296, 37.643053224009854, 63.86829083965671, 64.34812222757648, 83.12031915110927, 26.966734240131995, 0.48528489206106434, 0.1228038176533676, 0.06611250686429201, 0.07442170333477759, 0.07079110540930303, 0.14520433581163808, 0.08488390564678178, 0.1011294206123679, 0.02540733473705909, 0.015086550340657274, 0.04901340524215372, 0.1299262290159541, 0.1611349503359487, 0.24715406039068777, 0.11871886064088154, 0.33685406970400966, 0.15443859111157157, 0.26551847496340353, 0.2593443885205254, 0.20926725870418936, 0.28294161262531436, 0.4957599799719549, 0.7192288387206294, 33.5227406409479, 112.32578539079236, 85.08139441090246, 74.05670227543001, 48.42115379148915, 52.907945186861106, 66.64058285374796, 79.08747934526014, 59.9047161686805, 8.677051605716828, 0.47131534004884384, 3.6804229357550224, 10.622492298003166, 9.729441173614996, 7.342609791986405, 8.74816809931109, 116.32405342594271, 108.06724456048782, 101.74405436361991, 94.5693568260439, 94.4329995493735, 97.24191865613385, 99.58326770413308, 95.0562406355335, 90.26358281412433, 97.7709444107548, 90.69647912056216, 90.78523451282133, 83.88471065029022, 84.71260532256096, 86.78078482227941, 87.2390902426935, 83.57790285541166, 83.97553705400037, 75.68901231212001, 75.65285590387161, 68.57053018385365, 69.00439923809421, 67.23868939184374, 62.999066152880275, 64.0082057060734, 65.73838672330304, 58.61933585136168, 61.59903495542465, 63.048499784161976, 62.75252557569935, 67.75471641171363, 62.9312248383799, 60.565631620345584, 62.68608062498031, 62.5541046357924, 59.92506150276431, 58.7337003984759, 68.60398015668316, 77.32657048010057, 74.47798836615779, 76.43539228746968, 77.22750709902856, 76.42540593301096, 73.83912840197164, 74.49296397547569, 75.6123064410302, 77.30007879195675, 73.20557148225846, 73.60024821373725, 70.49745728892665, 66.10827799766295, 63.50363200710666, 63.653572451683786, 60.151166531347464, 72.48403579958024, 74.88956266833891, 75.48243676462482, 57.916835431129705, 57.11611493941277, 32.69399677553485, 30.30382206363063, 58.20544342840872, 61.94566265229256, 71.14347950104745, 70.84794459804412, 70.9050464630127, 59.12322313554826, 60.46357547083209, 56.74480768942065, 55.802932862312566, 54.41457463848976, 52.758977490086714, 54.793220643074285, 53.9739747970335, 53.08680526671871, 56.52765743194088, 55.99344238158196, 57.722238802140765, 58.60793744364093, 61.50907147315241, 60.76504491990613, 58.195217809369495, 56.40576193409582, 57.034306064728774, 58.302223990040446, 61.31632228051463, 61.366720814858716, 57.352394596222915, 55.712133915193625, 56.62586573631533, 53.747387316919145, 50.849387261175345, 55.4667975056556, 57.74161531079201, 58.53952346309539, 58.712880457601244, 58.17563733746929, 61.23348574484549, 60.83357657155683, 62.4279494439402, 60.984952603617025, 62.71072879914315, 62.92177584863479, 65.36042713349866, 61.512680053710945, 65.25637449756746, 63.20750090383715, 67.76871142848846, 68.82497433693179, 74.89540699989566, 76.37337961504537, 82.83983046008696, 78.4932481088946, 86.37478028574299, 81.10196159731957, 85.87765124536331, 74.78303893919914, 77.75377934978854, 18.675777219956924, 2.4618572525439726, 4.466078339084502, 4.544035936555555, 3.884313866015404, 0.6679394360511535, 0.5401639988826168, 55.22523833859352, 84.84513436594318, 56.52277408107635, 51.920339445913996, 57.47274860259026, 59.72218867271178, 33.65254755943052, 44.71809118024765, 73.98272637398013, 73.16975239784487, 94.81983154050766, 31.878045720438806, 0.6054908289544044, 0.28378522864753203, 0.26906506368710154, 0.3045671409176242, 0.13626828789710999, 0.2972976406735759, 0.12756009751390066, 0.29621954045949445, 0.1684642360816079, 0.20832800426550452, 0.12447983417059146], [0.008923567384631645, 0.03744758815774995, 0.08031758494795331, 0.04955316015008477, 0.03406049893988717, 0.052101137942724654, 0.09388141679547488, 0.09357426150311386, 0.1787558459346333, 0.08936175851211434, 0.07102093178658717, 0.17415487507898963, 40.89071296876477, 77.82834360676428, 61.75846361344861, 45.96808387387184, 52.09182154747748, 29.605206751054336, 34.20224028248941, 37.07068135661464, 24.674289303441203, 0.2531294236260076, 0.16596784664978906, 3.2479166600012013, 3.4147801706867837, 1.5325419773017208, 0.4602831223558995, 68.80406810391334, 105.88738733722319, 91.5356388399678, 87.90858391792544, 74.59293734642768, 83.7612658162271, 87.82514725961994, 93.85121007119456, 90.47200187560051, 87.06641181822746, 87.66518515925254, 88.05977559858754, 83.07846746137066, 84.52718703977524, 80.53039381580969, 82.70484601297687, 79.64557770759829, 80.53859156946983, 79.42180648926767, 77.81609012234595, 72.86438019044938, 69.9644934746527, 63.89513161874587, 60.46211634912799, 57.134624604255926, 56.45407768987841, 57.71092276419363, 52.53026408533896, 52.51156222435736, 53.82170054220385, 56.99984019802463, 62.2259081563642, 59.77965531810638, 58.96350422213155, 58.03374167411559, 55.72428541798746, 51.97083996188257, 58.213229333200765, 65.66654066885671, 71.18974777960008, 68.65949738410212, 66.53271767400926, 69.86623025709584, 66.62588181034212, 67.22318818492275, 65.57788333585187, 65.48290314212923, 64.53991436189222, 65.36181565253966, 64.10145221217986, 62.679373371985655, 61.32828943191036, 59.00838398164319, 55.52297369126351, 54.13242678488455, 60.31059518937142, 67.31145720328054, 65.38095681898056, 53.71204283929641, 53.89468016162996, 45.124201620778734, 42.7561883003481, 50.68067435295352, 51.786002189882346, 64.55732576308712, 60.92139843971499, 58.24406308512534, 54.59702760942521, 50.4166203929532, 47.972497401698945, 48.57996271502588, 51.14814243009014, 51.52689826103949, 48.11803302457256, 48.04338247545304, 47.96695509264546, 49.209805150185865, 50.63338625815607, 52.25719651868267, 47.73297786712647, 52.52925211383451, 52.852161238270426, 52.2761062652834, 52.909890682466575, 54.0088995810478, 52.1631851503926, 52.566891178008056, 52.45581749946841, 52.824708569434385, 49.132412864315896, 48.787758119644664, 47.447813710858746, 44.78630904228457, 45.06561317751485, 53.35025125934232, 51.365688846957305, 51.269896722609005, 50.783385538285785, 51.07963823503064, 50.53453076270319, 52.864979543993556, 51.369701431643584, 54.19322352255545, 53.71060332944317, 55.72075920720255, 52.317122490175315, 57.33069212205949, 56.67794304509317, 67.59815892865582, 68.6822549758419, 74.12969758433681, 74.04611187596475, 76.50422988399383, 74.66740746651926, 75.83337122394194, 73.88113698651715, 76.83870607806791, 73.00159254381734, 65.35332764348676, 67.60081829563265, 10.098145930997788, 0.46912543175201266, 1.6720898569591585, 0.5983815330170816, 0.8067110541366762, 0.5122170807613481, 13.975562799361445, 74.9668961186563, 59.62708296314363, 30.786940397754794, 26.971201819758264, 50.248774328539454, 26.86446236025903, 16.824714637571766, 33.18837819560882, 62.88969478299541, 67.2487541937059, 45.191215315172755, 0.1908394580166186, 0.20176209449287386, 0.06385792159445344, 0.10454420390869341, 0.014664871606885668, 0.03324670672056175, 0.08485538419336082, 0.13797856386630766, 0.014099944007372665, 0.058794888637719624, 0.05149967848293243, 0.0911574379631108, 0.04045139592621596, 0.11910477743273783, 0.05860789806672162, 0.05465090838110736, 0.014281367034380956, 0.008609535495540308, 0.09534608497614823, 0.13384300674642288, 0.02544477536913849, 0.18483383430828973, 0.14237377882724808, 51.815400354323856, 89.20699827132687, 68.75442658701252, 55.132419370835834, 55.36482372591573, 30.76324143717366, 32.68413005336639, 48.65662544004379, 33.4985827630566, 0.04425569279720226, 0.5457462670822297, 6.245444407386165, 3.622529487456045, 0.5016954759916952, 0.4934964353038419, 80.77112536276542, 107.9029521634502, 95.21421017185335, 90.81142025609171, 80.84824700509348, 83.37947014839419, 91.71531477282124, 92.91679166978406, 93.04403335817399, 88.22023976233699, 90.43673192301105, 90.66488050645398, 86.33287368282195, 87.12280765656503, 84.87884321520406, 85.7568108650946, 81.50918991334977, 84.41963564965033, 82.85128378099012, 82.24907444369408, 75.41346580751481, 73.2803475472235, 65.52348006156184, 63.33172628956457, 60.55215043406333, 60.05782588835686, 59.02537568922966, 55.143986440473995, 58.04131577091833, 57.72001481825306, 59.737191738620886, 65.71768053116338, 62.700232536562034, 59.19528099798388, 59.55016136169434, 58.90887345037153, 54.36942031306606, 59.271308299033876, 68.92917602292954, 72.46095657348633, 72.27711508350988, 69.3934512907459, 73.07466630012759, 69.20250246601721, 71.99310410407283, 67.89394486335017, 68.4244611186366, 67.76616188787645, 68.75458348181941, 66.42969269906321, 66.28592214276715, 63.62566086553759, 62.104114640143614, 57.92628834324499, 57.17975539545859, 63.83377398214033, 69.30537054615637, 67.67814390120968, 58.30011767725791, 59.733787121311316, 51.694512905613074, 47.74842416086505, 54.669564001021854, 56.95273645462529, 67.35243812684091, 65.65591496805992, 61.425803476764315, 56.208435335466945, 53.38657240713797, 50.585866743518466, 53.06370642877395, 55.60715167753158, 52.934299592048895, 51.0231404150686, 50.46351625073341, 51.5333584047133, 50.53130657442155, 55.570744237592145, 55.533054182606364, 51.94489348319269, 55.68754849895355, 56.39521075833229, 56.038957565061516, 54.438010800269346, 54.54691148573353, 53.925670808361424, 55.60301749936996, 54.40297618989022, 55.90812690796391, 52.065784854273645, 52.888890312563994, 50.77929842856623, 47.703736597491854, 46.903898639063684, 54.85447237568518, 54.13905951284594, 54.40672989814512, 53.8946605497791, 53.71180749708607, 51.60420033239549, 55.54474284571987, 54.634372495835834, 57.471485599394775, 55.51978872668359, 57.69594715487573, 55.40409841845113, 60.105580745204804, 59.9601431815855, 70.71993412510042, 73.1907606124878, 76.45990710104667, 76.98993698243173, 78.13260186103084, 77.48779558366346, 77.20878954856627, 77.12776122554656, 79.89610733524447, 75.27761843896683, 72.60421722166001, 77.30404823057114, 22.09088098618292, 0.12507589654095713, 0.6437157971724388, 1.5746513177310268, 1.5236975228594196, 0.41862911394526886, 11.768518647839947, 79.779142256706, 68.99009827644595, 39.04308442146548, 30.870961489215976, 44.069507660404334, 26.839561193220078, 29.881239629560906, 43.59574417914114, 71.54272187140681, 74.77658271789551, 55.257484143780125, 0.19977846303053443, 0.18316049909880086, 0.03032991696419495, 0.0703316594984743, 0.01682075698138966, 0.02226310305207247, 0.058485821955987526, 0.11070397982914602, 0.037455084328089035, 0.05569246237076098, 0.017926740880695083, 0.1851345391403283, 0.19337468810619848, 0.20105727828077732, 0.12387742093133351, 0.36841134570779344, 0.09781068941998868, 0.15437854514006646, 0.1318649524041722, 0.2233240681309854, 0.24245495367194378, 0.3200507584598757, 0.42308100409084753, 58.26201969577421, 100.8984148886896, 80.19284248352051, 64.78325428501253, 70.44602717122724, 40.76114923723283, 48.62628198439076, 60.24080053452523, 42.29736120470109, 0.39233467812019013, 0.8515820496024624, 11.247525907331898, 10.764798829632422, 6.827643773248119, 1.0266726704374438, 83.57893051639681, 112.47263108530353, 98.24507267244401, 94.83439922332765, 83.63711495553294, 89.02193300185665, 98.28732444394021, 100.15891475062217, 95.99545217329457, 89.26788914588191, 92.93562689135152, 94.59270277330953, 87.4825752935102, 91.38127003946613, 87.20389089276715, 89.91631184854816, 86.74833113147368, 87.46026485197007, 86.40429219891949, 85.34008256850704, 78.46914906655589, 76.0558480601157, 69.91730736147973, 65.47268144546017, 62.769317242407034, 61.63183381480556, 63.74589327842959, 59.10571367509904, 61.73762406072309, 60.78579425811768, 63.885317848574736, 69.62545948643839, 65.99747104029503, 61.334400484638834, 61.747296625568026, 60.11815194160708, 57.25424120503088, 63.70404158869098, 72.22541039989841, 75.0008716890889, 74.58100549636349, 76.04581463721492, 78.59043659702425, 73.05318740106398, 74.96664508696526, 72.01936829474666, 71.66398586765413, 72.34855713382845, 71.08159234446865, 69.9249481385754, 67.84474265190863, 68.8157646117672, 65.65802912558279, 60.35779699202507, 60.84201751216766, 65.97414078251009, 76.1518519924533, 73.77498980491393, 64.21286321455433, 63.76292813208796, 55.97628201207807, 51.444489263719134, 59.559143589388945, 62.20291914478425, 71.25711840967979, 68.56096744537354, 62.94792629057362, 60.70899032777356, 57.105132302930286, 53.562882946383574, 56.29443330149497, 57.75988178868448, 57.38297731645646, 56.702100922984464, 55.07053221425703, 55.28190874284314, 54.60294646601523, 59.748923547806285, 60.19501078513361, 56.23044767687398, 60.34122105567687, 60.759157442277484, 60.066196226304584, 60.2119162005763, 58.069301882097804, 57.27053865309685, 59.11375453395229, 58.15658246317218, 58.27899963625016, 55.537898309769176, 55.3052782243298, 54.1354234756962, 51.1045374408845, 52.02295257199196, 57.969606999428045, 57.154110939271995, 56.34070942478796, 56.54582192820888, 57.19521345630769, 55.37854025440832, 60.1894017957872, 58.74417704920615, 61.44947498075424, 59.69701882331603, 62.658635800884625, 60.14975055571526, 64.32178743423955, 62.10831549859817, 74.36177638269241, 75.61257316220191, 78.78293868034118, 80.8729971608808, 82.09474486689415, 82.7996575447821, 81.40694941243818, 80.25325482891452, 83.15099208585679, 79.14797013805759, 73.13616121968916, 76.54553244190832, 18.363801702376335, 1.1507030408228598, 7.150977003958918, 3.6923930289283877, 2.1317709261371247, 0.609778960145289, 18.745222783857777, 90.06170626609557, 76.02565365452921, 48.444656633561664, 41.353980187446844, 70.27091687725436, 37.043954326260476, 31.076213236778017, 52.19889440844136, 80.8663526658089, 84.08296292827976, 63.56278134930519, 0.23370391599112944, 0.26341302019934504, 0.16079168165883712, 0.25012475017818714, 0.13157625983078636, 0.18755713898328044, 0.1230928396445609, 0.19292648070521895, 0.08238163265970447, 0.11941881219465887, 0.155537452308401], [0.03095346082362437, 0.04497245232003831, 0.09352357712604346, 0.0848801518159528, 0.06762615104596462, 0.03601807575192183, 0.06063622309856358, 0.06450492498134414, 0.09257466231863345, 0.06161563586623919, 0.045766517775313514, 0.06480712368483506, 53.386042887164706, 74.62706196692683, 57.00509225168536, 46.92527555650281, 20.178951063463767, 37.73917090508246, 49.75945080480268, 39.68816526474492, 18.022839869222334, 0.5455701281466793, 1.2680892838585762, 4.882866942113446, 1.2494279948934433, 1.602827663863859, 22.108639517138084, 111.12677958703811, 91.52785685754593, 96.70089829352595, 83.08846166056972, 76.78152576569589, 73.61703595807477, 81.55281451440628, 86.38686903061406, 88.94206570040795, 88.71183041603335, 85.22098372059484, 86.04063357076338, 88.18207510056035, 86.20384339363345, 81.25709918237503, 84.14302226035826, 82.68649716531077, 82.1197303648918, 83.24302657958, 78.55362907532724, 76.403668157516, 71.86705481621527, 68.59509991061303, 60.36743033316828, 57.416666553866484, 59.158936315967196, 54.86407826023718, 50.55104394112864, 53.23854607920493, 53.15950247549242, 57.74071708802254, 62.69262706079791, 58.114373837747884, 54.56419344871275, 56.72840825973019, 53.74139001292568, 53.23216830530475, 59.67306098630352, 66.37353220293599, 71.26027984003868, 68.02816052590647, 69.57440591627552, 69.12034450038787, 67.85820422634002, 67.01844046192785, 65.39848589128064, 65.87410465363534, 64.78899271257463, 64.16136249419182, 61.980599203417384, 63.82529774019795, 59.436628357056655, 59.12691408588041, 58.2697702992347, 58.11627618728146, 61.35551460327641, 67.25208036361202, 65.08818326457855, 56.7429994767712, 56.83191960857761, 57.11379681864093, 51.70145550081807, 58.045999080904075, 58.23931701721684, 61.99279777465328, 63.54632700643232, 60.50234809998543, 57.92942623938284, 53.05100971652616, 51.37132529289492, 51.453032185954434, 48.796724657858576, 47.109579886159594, 47.54249188207811, 48.127317274770434, 48.3434320265247, 48.944288146111276, 50.55189901782621, 50.93151777021347, 49.90517862381474, 53.58242419458205, 53.475704346933675, 56.57156836601996, 53.864517135004846, 51.588220596313484, 53.03166850920647, 52.12707973295643, 51.00954155768118, 49.596821492718114, 50.65470041767244, 48.129509879696755, 47.723685772188254, 46.427546393486764, 42.71775691739975, 49.07555418629801, 52.478182854190955, 51.58740474331764, 52.19753726836174, 49.44393142577141, 50.898020728941894, 51.92037082487538, 53.05491247484761, 54.716844251078946, 53.833997172694055, 53.99411224549817, 55.10984220812398, 59.632899838109175, 67.96752068304247, 70.09100560219058, 72.14916736848893, 75.58258271986439, 72.8483533859253, 76.08701521350493, 75.57083129882812, 75.47634140137704, 76.51847593245968, 77.95695812471452, 77.99705259261593, 81.90950701313635, 79.70014572143555, 80.31260813436201, 14.57346929657844, 0.8987408900453199, 1.6165864804098684, 0.7045944143206843, 0.03737635347211073, 0.6260142631588445, 49.42692402870425, 71.67634133369693, 51.774164476702296, 37.019031586185584, 46.75286777557866, 30.644574049980413, 14.4923537008224, 23.755934969071422, 57.985198420863, 58.16474883787094, 61.37664441139468, 2.437344155003948, 0.11320376303046943, 0.07112159573983762, 0.018473888537095442, 0.04789789695472968, 0.06130272725356683, 0.034139038273884405, 0.02478262642398477, 0.11889939692111746, 0.0617501532448636, 0.05680986672579762, 0.05271159510518755, 0.02794532082794655, 0.051774922382807544, 0.07805996213949497, 0.03877300836686646, 0.027180514185719436, 0.038158812695333076, 0.06479505780002763, 0.049390749510137305, 0.06817624047999421, 0.06133394533648126, 0.1763311623325271, 63.436210386214725, 81.92757345015004, 66.12669744799214, 57.12245348961123, 33.81116820919898, 34.36357913478729, 49.52068436530329, 49.94489654417961, 18.154374591765865, 0.7178602992526947, 4.379076736588632, 4.6802436728631305, 0.5568686380021034, 1.2320081360878483, 29.11661671053979, 116.55242950685563, 93.80202354923372, 102.14943916566911, 83.78873025217365, 78.00007281764861, 75.01812227310674, 83.53722787672474, 89.83563653884396, 91.90580860260995, 91.85332728970437, 88.4926954392464, 87.24809600460915, 91.41604577341388, 86.77596815170781, 85.91040303630214, 85.91511772524926, 84.45492913646083, 83.68241833102319, 84.11852313626198, 81.15981655736124, 80.05515160099154, 75.00030686778408, 70.72171488115865, 64.25380883678314, 61.209516140722464, 60.96576436873406, 58.08605432510377, 53.39056145760321, 57.90891224338163, 54.78627804786929, 60.14971133201354, 63.93428471780593, 58.487956062439956, 55.52760601043702, 58.69231547078779, 54.97671696447558, 55.83244869785925, 63.254808610485455, 69.91656995588734, 73.34940479647729, 72.11694117515319, 72.21000332986155, 71.01168001851728, 72.5175642198132, 70.5296834822624, 69.42624230538645, 68.19470436342301, 68.31403070880522, 68.03167496958088, 64.60792041593983, 66.9467709141393, 64.29388761520386, 61.784096302524695, 61.2551333058265, 61.3405546834392, 64.59615330542287, 70.48538423353627, 66.55063506095641, 61.276635739111136, 61.11740319959579, 60.635124252688506, 54.30719191028226, 64.60811261207827, 62.92269760562528, 65.81144086776241, 68.44167247895273, 64.25010611934047, 61.5047804001839, 56.41295163862167, 56.468582614775634, 55.46451076384514, 52.42645463635845, 50.26907651655136, 48.89227751762637, 49.21639865444553, 51.20023542834867, 53.001368199625325, 53.22740262554538, 53.62611547593148, 53.943015529263405, 57.439808537883145, 57.372437907803445, 57.18048495631064, 57.45716894826582, 55.8929394906567, 56.773464525899584, 55.82474908521099, 53.45435488608576, 53.514571112971154, 53.29779348065777, 53.08875468469436, 51.25318742567494, 49.3364937843815, 46.92405962174939, 50.92358281535488, 55.73345199708016, 56.16606589286558, 54.88643969258955, 52.40395592105005, 53.563530137462, 55.415692944680494, 54.97297110096101, 56.43281452117428, 57.994957277851725, 57.51116429605792, 58.11655467556369, 64.1650220655626, 71.94560420128607, 73.999066968118, 75.71322118082355, 77.43620072641681, 74.0065900741085, 76.19335851361676, 76.85703139151298, 79.4055208083122, 77.37167773708221, 81.04551869053995, 78.62955831712293, 84.04396672402659, 78.80543739564958, 87.6252789651194, 25.872744014186246, 0.6003574269913858, 1.0711878946711941, 2.3501491306289553, 0.046655570472320246, 0.3069983362670868, 51.32545709609986, 79.71585873634585, 60.23061413918773, 43.048502937439956, 48.82784474280573, 28.654989042589744, 23.502979355473673, 30.95001489885392, 66.52228416935091, 62.590068847902366, 72.3763196699081, 3.6120574945403687, 0.17200265830803305, 0.20439602735061801, 0.038045282295394334, 0.04094365338284162, 0.05911457712852186, 0.034774354989490205, 0.011369955215242603, 0.09314133755622372, 0.07114453241229057, 0.06453410527037998, 0.16891826575081195, 0.062380379306212555, 0.24153402405640773, 0.17300995667615246, 0.14068847732438197, 0.20351393839284299, 0.22878108095497857, 0.1392960052696928, 0.18018838438776233, 0.13374739897347268, 0.14699551066563976, 0.2993756388464282, 69.76615490451937, 94.31141391877206, 75.05564366617511, 66.58690914030998, 33.435071745226466, 49.0516669519486, 65.44620544679704, 62.1723795706226, 25.29672238134569, 0.656499537008424, 5.741285989361425, 7.992737254788799, 8.472349970571457, 3.581492424972596, 29.946247031611783, 120.1916673106532, 101.07935382473855, 106.24808849826937, 88.51484898597964, 82.36557668255222, 78.88721096900203, 86.60349369049074, 95.64403134007608, 94.76089400629844, 97.96137548262074, 91.65161548122283, 90.80532489284393, 93.91426609408472, 92.09254480177357, 91.46215715715962, 92.05525090617519, 89.95243687783518, 88.08296465104627, 88.90856865913638, 87.0109808829523, 83.92540916319817, 77.30905317491101, 72.29777812957764, 65.68970618709442, 62.41759046431511, 64.39149971931212, 60.3554121909603, 57.98173496800085, 60.281824604157485, 59.639654159545906, 63.46949169712683, 65.96483692046135, 61.76846957975819, 57.614095134119836, 60.25969851401545, 58.513274961902255, 58.46470032968829, 66.4611344183645, 74.10149574279785, 75.88906888038882, 75.53441601414835, 74.57543573071881, 73.79720610956993, 73.67572246059295, 74.97419957191714, 74.76240727209276, 72.27276909735896, 70.39989225326046, 71.55967435529156, 68.07122815039851, 71.05437894021311, 66.24763980988534, 66.75724198741298, 67.47640071376678, 64.7624304217677, 68.93571069163661, 73.43587736929618, 73.09605106230705, 68.19418661056027, 63.637851592033144, 64.16203321949129, 57.90812384697699, 67.55372631934382, 67.04749738016437, 70.97611981053507, 72.79267926369944, 66.05927190473004, 65.71795901944562, 59.09215011904317, 56.91707426501859, 56.47215981637278, 52.49650424526584, 53.415801909662065, 53.317570071066584, 54.302873380722545, 56.46990053115353, 56.81293141457343, 59.01656604582264, 57.21588826948597, 56.886224823613325, 60.27531346967144, 61.239161414484826, 62.34260259136077, 58.77616005559122, 58.63902614962671, 60.04878482510967, 60.19344575943486, 55.88593805989912, 55.51170079938827, 56.80845599020682, 55.25518563485915, 55.582276005898755, 53.20546088680145, 48.996314464076875, 55.16591248973724, 58.42123654580886, 59.98061010914465, 58.64983227945144, 56.45543090758785, 56.946358680725105, 59.1153391715019, 59.97108659436626, 61.08121149001583, 61.35112939342376, 63.35489180780227, 61.22554686761672, 67.85912206096035, 76.28746401879096, 78.4003742279545, 78.16238834011939, 82.35104037869363, 78.4849169946486, 80.91480962691769, 81.81340109917426, 83.13447890743133, 82.22899190841183, 85.41130496609597, 81.99715629700692, 88.51863015082576, 84.76899331615817, 88.33143895672214, 21.465594383978075, 2.261358437038237, 8.3402023776885, 3.179812791847414, 0.12319309757121148, 0.9355295353358792, 63.44182329793131, 85.04781892222744, 68.56732952979304, 53.940485600502264, 66.12042165571644, 43.79299625273674, 25.630347421092374, 38.5821549354061, 76.53642469836821, 72.70667737530124, 85.13648017760246, 4.265875172230506, 0.3471257459492453, 0.3588625193843919, 0.16445131431664192, 0.20943507792488222, 0.1676676118926656, 0.179306601865157, 0.09136497118179837, 0.15808824930460225, 0.12331133558144494, 0.17551351669094256], [0.04321588165757637, 0.08052639753347443, 0.051247551286172484, 0.017767804449484233, 0.04446925512785393, 0.018015122529299512, 0.06751333693823508, 0.06538945775959762, 0.028029548364781567, 0.067485727129444, 0.0337106840414626, 1.3104742933665554, 67.98500660927066, 72.80342655797159, 59.69981547324889, 42.666487616877404, 45.06054939762239, 114.41218037759106, 39.52128802576373, 55.13495714433732, 7.791757948936955, 0.30021039889224116, 2.452519314904367, 1.6935303903395131, 0.6306031298252844, 0.34797895339227497, 85.14933770702731, 100.14142097965365, 93.47493710056429, 86.36525677096459, 79.93202840128254, 69.27057127798759, 72.04674643854942, 70.46066545671033, 79.22364834816226, 86.23823473530432, 90.61643139008554, 84.60576780380742, 86.5694788963564, 84.61289867278069, 84.9853983233052, 83.69987287829, 83.08871269226074, 83.75537441622826, 78.87447895542269, 74.5331290460402, 77.13337021489298, 74.9222360118743, 73.02598968628915, 65.95159499875962, 60.64989197638727, 59.890003358164144, 59.094617289881555, 51.8365183953316, 52.95424092200495, 52.07477884907877, 52.046741747087054, 62.342029925315614, 60.263620884187766, 56.10284905279837, 56.30358811347716, 55.40862483362998, 54.35034190454791, 50.58796913393083, 64.79144027156215, 69.90759557293308, 73.24122582712482, 66.6249639757218, 68.82492726848972, 67.89967152380174, 68.01773486598846, 67.90619834776848, 66.114561634679, 66.08600677982454, 65.3813059099259, 56.81807364186933, 62.40676472263952, 61.07675567750008, 61.20967695789953, 59.77157915792158, 57.20327000464163, 58.29810157898934, 62.97789712106029, 67.7815140447309, 58.90978344025151, 56.695625089829974, 57.90264821821644, 52.73216024521859, 53.84087308760613, 55.28700782406715, 57.782572700131325, 55.93079036281955, 62.59500318957914, 62.320723610539595, 61.953303429388235, 59.86517867734356, 60.650174387039684, 61.06550239747571, 60.34048365008447, 53.1454643126457, 46.32971855901903, 49.16700424686555, 52.838189755716634, 49.09223602664087, 51.89431451982068, 51.869497683740434, 52.87408728753367, 51.603839474339644, 55.4735126033906, 55.81606495764948, 57.08533217830043, 48.90509974571967, 54.12772778541812, 52.74030700806649, 51.49514275212442, 51.77617665260069, 51.59579077074605, 49.75042935340635, 47.003499384849306, 45.78916495846164, 43.793027631698116, 44.57864699825164, 52.31349822013609, 51.10594164940619, 51.17412028774139, 51.97936327226701, 52.56719320051132, 51.13114680013349, 53.867353008639434, 52.643750021534586, 53.56082370204311, 53.032747161003854, 57.927708241247366, 65.89641509517547, 68.77415610897926, 72.42898925658196, 75.52100150815903, 71.20009499211466, 76.36087509893602, 72.38147366431453, 77.17341761435233, 75.52474344930341, 74.70178311870944, 74.73198536903628, 78.55278968811035, 74.84073700443392, 79.91684098397532, 76.91869889536213, 82.86780480415591, 2.1700387952789186, 1.636226523307062, 1.8363217024072525, 0.2697649003276902, 0.44130026032367065, 19.70171432341299, 74.19919413904991, 62.70005602990428, 41.79103420626733, 52.349340838770715, 48.403522737564586, 26.55903131731095, 25.213287684225268, 50.30085555968746, 56.57383549597956, 66.87958855782786, 8.112584294811372, 0.3044279887070579, 0.22114911387043618, 0.07289174148031781, 0.16036415863181316, 0.041097322959573045, 0.06759530834613309, 0.02744894564872788, 0.1310371484367117, 0.05423233326103899, 0.03636175428607291, 0.05945462057547224, 0.06634991751202653, 0.012605346686717485, 0.05064447538086003, 0.11016590265376915, 0.0327955422201945, 0.07483034229446804, 0.041654946868337935, 0.017703788227311546, 0.02485446631908417, 0.0743047983175324, 1.4983460186950623, 79.37721698514878, 81.78467366003221, 71.20373495163457, 44.380127999090384, 45.55879239113101, 122.85898885419293, 44.95566129684449, 64.57064613219231, 6.129738899969286, 0.2859907651380185, 3.63147862015232, 1.7079562549629521, 0.5921389583137728, 1.1966854766491921, 91.31928090126284, 102.0734000975086, 98.60643279167914, 89.57985877990724, 81.18613566121748, 74.4674450351346, 74.04103632896178, 73.22270439517114, 81.17878513951456, 88.49443697160291, 91.47708569803547, 87.61107998509561, 88.23425831333284, 86.2903473454137, 86.11197363945746, 85.3876373844762, 86.18105442293229, 84.65498570472964, 83.64664631505167, 79.14052547947054, 82.08491540724232, 77.83599222860029, 75.92953989582678, 69.73192830239573, 63.21406695150561, 61.139556746329035, 59.99184377731816, 54.3899578432883, 56.33670076247185, 56.63800939436882, 54.93409649018319, 63.08217725446148, 61.010957917859486, 57.340717700219926, 58.224996443717714, 55.9422750626841, 56.7092945498805, 53.11069642343829, 67.53666400909424, 73.68052344168387, 73.31067531339585, 70.29092880987352, 71.87642928092711, 71.95180939089867, 72.2817591697939, 69.97789229116133, 70.97953227258498, 69.26842181913315, 67.79293598667269, 62.110241382352775, 64.12217801617038, 62.98439648843581, 64.12530806756789, 63.43103285758727, 60.932177112948516, 60.460339515439934, 65.89746629038166, 70.94907114582678, 59.65002882865168, 59.50553263387373, 59.38784191685339, 53.484082529621745, 55.19194918294107, 57.588066285656346, 58.84207156396682, 57.65814335115495, 65.87793288692352, 65.50254637195219, 65.48145578753564, 64.28383458045222, 63.41098954600673, 64.85499835783436, 65.17098449891614, 56.806945877690474, 50.06528192950834, 50.71668955587572, 55.204018315961285, 51.80129551118421, 54.78281459500713, 54.85753182441958, 54.632038685583304, 55.97742734416839, 59.872133039659076, 57.296147807951904, 59.843382066295995, 54.83317782801967, 55.839983570960264, 56.141598147730676, 56.04788095720353, 53.61821190003426, 54.1992522055103, 53.949754161219445, 50.69319063617338, 48.90915547647784, 47.70449361493511, 47.33646546640704, 54.945667482191524, 54.20431206303259, 55.160605522894095, 52.99677902652372, 55.96594264430385, 52.673720852021255, 58.4345490701737, 56.044488107004476, 58.44939131890574, 56.14515573747697, 62.642432489702784, 70.95463306673112, 73.31348373043922, 75.76054065458237, 78.47939429744598, 74.0117754474763, 77.36111871657833, 75.35323389114873, 79.60645598749961, 76.8513596442438, 78.30857507644161, 76.78294566369827, 80.29862096232753, 74.89555604996221, 85.50528495542466, 73.91199819503292, 92.28426241105603, 5.576814143888412, 1.8744084070767126, 3.482177276765147, 0.9426362572177764, 0.4809014288888824, 16.686007861168154, 82.2688667235836, 69.73820409467145, 52.35105491453602, 53.09306144714356, 39.42898681086879, 27.99767040437268, 37.903910452319735, 58.13480546397548, 63.570477039583274, 77.98421075267177, 11.43535448658851, 0.5551551751071407, 0.31596177948578713, 0.15603046053119246, 0.24027551013615825, 0.02816588137178652, 0.09051495832541297, 0.03049229887584525, 0.10594893337017107, 0.05942170177736591, 0.07571990827038404, 0.1384479612592728, 0.2514362007740044, 0.1884824199782264, 0.10868435755612389, 0.14039186340185905, 0.1236361645222191, 0.13936283878020703, 0.1990936570350201, 0.17343819982582526, 0.4804550754206796, 0.16023576229570374, 1.7737021657728382, 89.05632434352752, 93.01995000531598, 79.37090196917134, 57.18276385338076, 57.82003525764712, 121.90635496570219, 57.16426987801829, 74.71300894214262, 9.161610430286778, 0.3357636507961058, 6.919854283332826, 7.20445950185099, 4.954782618630317, 0.9848415731422364, 95.2044277806436, 104.2379443876205, 101.89188849541449, 90.39073821037047, 86.84673555435674, 76.47730673513105, 78.35287432516776, 77.46117053493377, 84.49236423738542, 92.61533398782053, 94.68046188354494, 89.65536440572431, 91.87940320660992, 89.31732669953378, 90.32513264686831, 90.53010002259286, 88.7079551143031, 89.85134955375426, 88.4855410360521, 82.4003210375386, 86.07543283893217, 81.06509916244015, 78.86530845395981, 72.83338562134774, 66.41867868361935, 64.51581139718333, 63.972304251886186, 57.49551403907038, 60.65288082245858, 59.63308811187745, 58.53856640477335, 65.76433712436308, 64.06948881764566, 60.44747021890456, 60.024548499814934, 58.20589057860836, 60.23375595769575, 55.67784847751741, 71.02752639401344, 78.31855358616, 77.07454250704858, 73.5380708017657, 74.23066723731257, 75.66750987883538, 75.99338823749174, 74.93806669788977, 73.00895091026061, 73.10486070571407, 71.38521517476728, 65.37275906532042, 69.61501029229933, 65.51050486103182, 67.40294256517964, 67.332135938829, 63.31848436786283, 64.35089142091813, 69.90437138465144, 73.87168407440186, 63.71943689161732, 64.22225729111703, 61.18067103047525, 58.245298631729625, 57.94139339077858, 59.706244237961315, 63.53167303146855, 61.3488151950221, 69.12284697255781, 70.18265570363691, 70.11680695318407, 65.4967216522463, 65.76325062782534, 67.12259507948353, 66.47869879199614, 58.50998409332768, 53.61600360562725, 54.79486803854666, 58.30856646260908, 56.13103128248646, 59.23881538452641, 58.352324424251435, 58.51800534033007, 56.92825302000969, 61.67105751652872, 61.35981744335544, 64.26229292346586, 57.77277461944088, 60.31200332026328, 58.897663316419056, 58.30279273371543, 57.176915599453835, 58.285612752360684, 55.42935848236085, 53.67844773877052, 52.64521306560886, 51.12299219254525, 50.72083942351803, 57.23015392980268, 57.279010972669056, 58.58190859517744, 58.7015526525436, 60.48079859825873, 57.49270954439717, 61.82554398813556, 59.98715654496224, 61.7089044663214, 60.44963144486951, 68.40029147363478, 73.23879395761799, 76.91012459416544, 78.85312557220459, 83.76737686895555, 75.60312025008663, 82.38719678694203, 78.06745129246866, 84.34701688828008, 81.92154084482502, 81.34196358342325, 80.9109421699278, 85.79940780516594, 78.75612535784322, 90.63743175998812, 80.14215761615385, 97.19490512724846, 3.48890928972152, 6.372889568728786, 7.720107032406715, 0.644717533742228, 0.6156945072354809, 23.575388270039713, 92.64970179527037, 77.09682156962734, 59.25425775589482, 69.86905436361991, 67.43429799233714, 35.90443911090974, 41.0382725346473, 68.32425240547427, 72.20168790509625, 90.39245620850595, 15.219272836562126, 1.0176683794106207, 0.3851933597076324, 0.31565427179298094, 0.4030355168206077, 0.13127748554031696, 0.13523086695180786, 0.19816494396617337, 0.26152801489637745, 0.15514909169606625, 0.1903036101571014], [0.02462869063169966, 0.07907680596315092, 0.06266379353380011, 0.024983783875922524, 0.01887638538685297, 0.040427091786818165, 0.07954569007720678, 0.07983243678726497, 0.00501270768337793, 0.0598649985547508, 0.04842412658035756, 1.5580113977193835, 66.54568502979895, 72.89264478991109, 63.36327391286051, 57.45823583295269, 54.94527132280412, 36.159000935093054, 48.31719529244208, 63.62001265248945, 0.6883957609534265, 0.09914771969159765, 2.83796327729379, 2.337023654291707, 2.1643349336039637, 25.445007585710098, 111.70210499917309, 87.18195699876355, 97.68091032581945, 82.07336794945502, 79.9903226667835, 73.98719787597656, 74.26740415634649, 62.97415125754572, 65.39679927210655, 71.28477111939462, 84.26000302837741, 85.40063611922726, 86.33259127216955, 84.20387391121157, 87.61282151745212, 81.70902682888894, 82.56709237252512, 77.4170046467935, 76.53342800755655, 81.58749611146989, 77.60517643344018, 76.9923923861596, 69.37411400579637, 60.55133458106749, 59.050812259797134, 59.659571955280924, 57.68043810321439, 50.482288714378114, 53.70524929415796, 51.71027691133561, 53.921834730332904, 63.037395554204146, 56.736327525108095, 55.187724790265484, 55.88961332075058, 53.690995400951756, 53.35806462072557, 53.486239833216516, 64.73025129687402, 69.59080926833614, 68.78763337289134, 68.20157635596492, 69.32093451100012, 67.40709243282195, 69.66768772371354, 66.0808841643795, 67.14700006669568, 62.24204478725311, 61.62718580615137, 59.39149756585399, 58.78751923961025, 60.58676927320419, 63.53589350177396, 61.171731948852546, 60.93025515156408, 61.750010905727265, 64.33996761998823, 64.39497886165496, 52.957527868209354, 55.86845997841128, 54.89222911096389, 53.154258266572036, 57.44566855892059, 57.5540554138922, 52.86780757288779, 54.332008746362504, 58.575530821277255, 66.61392642605689, 64.83599447434949, 63.25209825269638, 63.76665046138149, 63.93028782260034, 61.89200070596511, 55.26488957866546, 53.38955340846893, 49.17542949799569, 49.16244253035515, 53.90039505497102, 53.16320911530526, 51.39968402924077, 54.34506239429597, 55.02570344555763, 55.321677654020256, 55.34220733950215, 55.6006326983052, 52.569515243653335, 50.83433712682417, 54.17177600245322, 52.5035095983936, 51.13500249001288, 50.11795936092254, 47.77507274381576, 50.15367646371165, 47.09489060986427, 46.1917805671692, 42.441563221716116, 50.46289259387601, 51.456687834955034, 52.76800678622339, 49.77594437137727, 50.162325289941606, 50.61429608252741, 54.01108826360395, 53.78975283715033, 53.73263920507124, 55.69158854023103, 66.19171465596845, 68.78347566050869, 74.03510570526123, 70.84241405610116, 71.27816584802443, 70.85875465023902, 73.44281996450117, 72.07840781058036, 73.1104540055798, 70.91618599430208, 75.24488233750867, 72.41808506750291, 75.42689600298482, 72.65268987224948, 79.65117885220437, 73.72770955485683, 88.12985266408613, 46.052654097157145, 0.40467966408018147, 2.2086148156273753, 0.5114433319578248, 0.09658918520736118, 1.9343869628444796, 59.49540507408881, 68.95513426872992, 52.84326138034944, 45.729607689765196, 46.28359148579259, 22.51395371652419, 19.545768730102047, 41.87082306031258, 59.37023439714986, 61.42500723561933, 13.838196492964222, 0.3933669662763996, 0.18928619942838149, 0.0677671954937039, 0.07087716772671669, 0.06774551520544676, 0.08165536598572809, 0.02515510794886899, 0.004472383476358148, 0.08734025166279848, 0.07392912412122374, 0.050002386448003595, 0.056949566689229784, 0.07277012502233829, 0.04670140551282995, 0.021598177038193233, 0.08097021525064785, 0.04180967364640486, 0.06747828075482, 0.008257373495237723, 0.03907967336295594, 0.10078116470286924, 2.0959037926889237, 75.56593618085309, 80.24907358231084, 73.84992276468586, 63.633944911341516, 60.988267006412634, 41.81067743609029, 55.2791944626839, 72.68057792417466, 0.2039409558018369, 0.5150594201780135, 4.477149719192136, 1.3299127019220784, 1.076892614364624, 31.78195353477232, 116.49990897024833, 89.68952824992519, 102.17529542984502, 84.89548975421538, 83.6132041869625, 76.50334342833489, 77.48498716662007, 68.11701005504978, 69.06276410625827, 73.97066900807043, 88.33137619879939, 88.89309098643642, 88.83953494410362, 85.15551936241889, 89.80797598438879, 83.89176307186004, 84.49600419690533, 81.04886054992676, 81.48673042174309, 85.18671005002915, 79.92680380421301, 77.95141189329087, 70.25805934782952, 62.758515034952474, 61.985678672790534, 62.96628690535023, 60.63293949250252, 54.28034720882293, 56.501550136073945, 54.9880055458315, 56.048359486364554, 63.4488796418713, 58.65572760182043, 57.25253105163575, 55.105511911453746, 56.031226573451875, 56.32706742132864, 57.66416811173963, 68.49067072714529, 71.67179922903739, 71.20630018172726, 69.25854529103925, 72.01927415786251, 69.79165815537976, 74.58448071633616, 69.87172157533708, 72.0666563895441, 66.62719972672002, 63.000866520789366, 60.8189029847422, 63.496771781675285, 64.85212718286823, 67.86285615736439, 64.90296894504179, 64.3959947555296, 63.72914083542363, 68.33549391838812, 68.1182259898032, 58.368512045952585, 58.93019545462824, 58.428732195208156, 57.56302587447628, 61.10514187043714, 59.98198293870496, 55.54006738047446, 57.05376102078346, 63.31123582778439, 68.86644947913386, 66.45890651210662, 66.56781504231115, 67.64387023064398, 66.69917521938201, 64.13664371736589, 59.13318203341577, 54.48800925285586, 51.38311986000308, 52.53502584272816, 57.509764009906405, 55.10056188029628, 55.304423147632235, 57.51458460284818, 58.876666868886645, 58.09627602177282, 56.63194541008242, 58.221372173678496, 56.343835553815296, 55.35893232591691, 55.575819784595126, 56.463824779756614, 54.72508515081098, 52.196588054780044, 51.85045849892401, 53.60473463612219, 50.70376142378777, 47.49335635092951, 46.77670009674565, 52.54212533274005, 54.96141579843337, 54.50232198161464, 52.565486969486365, 53.98946815921415, 52.79011718688473, 56.534262703311065, 57.11848405099685, 55.95765467612974, 59.69714433916154, 69.80378612395256, 70.15048442348358, 76.37104188242267, 73.39532006171443, 75.59767600028746, 74.28449784555744, 77.19382178398871, 73.62844221053585, 74.37724621065202, 72.48973108107045, 76.40819457269485, 73.4791724912582, 77.64187412877237, 74.63209044548773, 79.62319666339506, 78.81747907207858, 85.47573381854643, 59.944143833652625, 0.6598747365417019, 0.9772646571359328, 1.456196351397422, 0.3285878584269555, 1.5053028324919364, 60.895561787389944, 77.57816699243362, 59.56302281348937, 52.97973240575483, 36.022671115013864, 20.38104726422218, 30.51658318888757, 51.29883596974035, 65.83385329092702, 70.94467024649344, 19.905410851201705, 0.6493885863211848, 0.19784954556774711, 0.024315952473590453, 0.10039827395831386, 0.10340714556795937, 0.1457705207529568, 0.08570695986911174, 0.06945035961126128, 0.04837453770901888, 0.053877063816593546, 0.11430650063219572, 0.24390832971661325, 0.13636469240150145, 0.18917159267490913, 0.12726048052671457, 0.206178913133279, 0.1792062290253178, 0.0862074144665272, 0.21554628387093547, 0.12889797048222634, 0.29117984637137384, 2.8336932870649525, 88.34652439240487, 89.54490261693155, 82.36447057416363, 71.86147720583024, 69.12652615577944, 49.2971916352549, 66.29699107139342, 79.95541357224988, 1.1345762158593824, 0.5674622243931217, 6.832515357002136, 8.526661069162431, 4.398749384187884, 31.404011595633726, 118.81093809681555, 94.9260885484757, 106.86603438469672, 91.13648276175223, 87.91450669688564, 79.70966923621394, 82.74272041936075, 70.73843202283307, 72.74593245598578, 76.89785542026644, 92.5097437827818, 92.988492596534, 93.3382817237608, 88.69416406077724, 93.4722855783278, 89.32150794613747, 90.1891597624748, 84.46107156815069, 84.5899449625323, 86.41714972834434, 84.30842861052483, 82.98283223182925, 75.9069235094132, 65.56262139351138, 64.64956814242949, 66.54674406974547, 65.11688716949956, 55.903714241520056, 60.59721454497307, 59.578347513752604, 59.78822569693289, 65.8687545407203, 60.01744508743287, 58.464355161113126, 57.68415651013775, 58.770747184753425, 60.283338639044, 60.15681866676577, 71.01586910986131, 74.10400605970814, 74.9243619365077, 73.20203350436303, 75.19660580542781, 72.40190136817195, 78.00424621951196, 71.85807258852067, 73.6928318392846, 70.18746452946817, 65.82647139026274, 64.86582802188012, 65.78084245804818, 67.73001332436839, 70.39731133368709, 66.11049805918049, 69.0950922812185, 67.5281838447817, 72.39047158148982, 72.43870888986896, 63.184154956571525, 63.93211564710064, 59.90410427893362, 58.58969449996949, 62.090919786883944, 64.22378309311406, 60.58526700542819, 60.80751634413197, 66.94495877911969, 72.67891483922159, 69.94817641473585, 70.59853676826724, 71.59226140668316, 71.39079278515231, 67.03744826778289, 61.729096827968476, 59.93345145256289, 53.98105467519453, 57.70313293703141, 62.02757743097121, 59.50991784372638, 58.40284847444104, 62.54391039571455, 61.36562255121047, 61.15450489905573, 62.117623283017075, 62.58884899077877, 59.32373469875705, 58.03878976452736, 59.470807890738214, 59.423421736686464, 58.91603569830618, 55.029637582840465, 54.93506531561575, 57.748373554598906, 54.606613882126354, 51.48892971777147, 50.13405676810972, 55.62244892120362, 57.47275252496043, 59.655845703617224, 55.96982579077444, 57.41911803522418, 57.09883297643354, 58.979209392301506, 60.69667408543249, 59.95228275176018, 63.23957412473617, 73.37766155119866, 74.50965758292907, 81.12471918905936, 75.33271205040717, 78.29905940640357, 76.59980235561248, 81.30169653123426, 78.16439659364762, 79.02101870506041, 77.86202107706379, 82.17076824557397, 78.720792647331, 81.02628338721492, 78.47775474671396, 85.57282816979193, 82.30924360213741, 90.98795044806697, 57.5505409702178, 1.4755706537154414, 13.432366501900459, 1.9424159320131427, 0.30490504697926585, 3.2495998471013965, 74.16738371695243, 83.89047653444352, 67.82109075976958, 64.51736857814174, 61.8216137732229, 32.315717512561434, 30.905174363044004, 59.50431277675014, 75.33686976278983, 86.71123335438391, 25.374469641716253, 1.0563267695326959, 0.30573554757621985, 0.1872042482418399, 0.28848612801201884, 0.19819500525632214, 0.271701815748407, 0.1984344996632107, 0.14772300308029498, 0.2792029503372408, 0.1715643640847937], [0.03977984708223132, 0.04575175143057301, 0.03729701357623262, 0.03236327710891924, 0.013586886305992883, 0.06761095186154689, 0.1060585605521356, 0.14502327859161362, 0.015646258966186117, 0.07596332504744492, 0.03187269163918832, 2.0441291192846913, 65.13609893860357, 66.04255476305562, 50.341585451556796, 36.2089523192375, 41.20837003953996, 60.89886442307503, 59.62583172705866, 43.11640308749291, 0.17463718871435813, 0.4711259631139617, 2.814877187052081, 1.1008190724157518, 0.6008216149864659, 81.36450936717372, 96.1973051871023, 94.22434514568698, 86.06709387994583, 77.73015099187052, 73.85586123312675, 73.22886251634168, 71.01284888482863, 67.76617757735714, 62.454825524360906, 60.28642946673978, 68.32138123050814, 79.79349813153668, 79.43800587807932, 85.79715636468704, 84.19934749603271, 83.2640661731843, 76.71352755638861, 78.2798868610013, 78.46392446948637, 77.46763460097775, 70.76853229153541, 63.77271052329772, 60.90761523092947, 58.069376407131074, 58.5242497536444, 59.91865234990274, 53.68369979243125, 51.14241969200873, 51.74142445287397, 51.19303003434212, 57.27823826574511, 60.51380926562894, 54.20910912175333, 55.55528617674305, 54.285528659820564, 53.88777679012668, 50.33512923025316, 57.71601007830713, 68.84004408313383, 66.41587026657598, 66.86451881162583, 67.9009266822569, 69.70225949441233, 67.30611493510585, 69.77491747948432, 69.65166091918945, 67.02550072823801, 68.90324915609052, 63.3270743585402, 58.69068768716628, 57.357532901148645, 61.275902255888916, 64.26074358724779, 68.39522377137216, 61.75536886338265, 60.519100542991396, 62.869039581668, 59.30318540142429, 49.29112765096849, 52.29741258005942, 53.97257843325215, 59.846370912367306, 60.221012177005896, 59.605819794439505, 50.09715510952858, 52.10390244760821, 53.69820863969865, 58.28132167939217, 63.54547192973476, 65.80960519852178, 64.63256859010266, 63.193015590790786, 61.54556128286547, 54.884925657703036, 53.422932778635335, 51.98925156747141, 51.123188311053866, 53.75318458003383, 57.89229316096152, 56.31832053584438, 53.919198897577104, 53.80024909973145, 53.17239138387865, 57.01087774768953, 57.50504539858911, 58.16598438447522, 51.96290500702397, 51.286264773338075, 52.573316020350305, 54.30396772200062, 52.70482916985789, 50.60407830822853, 49.03744051533361, 46.08459395747031, 46.24167311576105, 45.10073408003777, 44.97450044078212, 52.52557685298305, 50.786754854263805, 50.58493714178763, 48.9399068586288, 50.86032675158594, 51.15502618974256, 55.8980542613614, 53.98966035535259, 62.31297692944927, 66.5274146295363, 73.08507627056491, 68.65381779209261, 72.55915703312044, 70.52545516721665, 71.03259409627607, 68.82464485783731, 69.04104202024399, 66.4799068820092, 69.90306915775423, 66.4007063834898, 72.3008297335717, 71.01211147923624, 72.66186037371236, 67.32208682644752, 81.7304821937315, 74.18702694677538, 93.36750338154455, 13.48510669123742, 0.9459244904498901, 4.075335990036688, 0.23760023917401993, 0.15122336605864187, 29.961053979012277, 78.4689764822683, 58.76889190366192, 45.79166350826141, 40.94292756049864, 44.55124924259801, 18.752914551765688, 33.134833920386534, 52.60665616681499, 62.28693239150509, 19.99193637601791, 0.35480026155710226, 0.16337152870912708, 0.08407724570603141, 0.06844701425683114, 0.04850741948992495, 0.07585770450532436, 0.04586717789812435, 0.015989018194828064, 0.06426184528296994, 0.07140362334828224, 0.025593248954523477, 0.02747560167805322, 0.042836534069670786, 0.0659521110355854, 0.024231539160433798, 0.023491975115311724, 0.010130133840345569, 0.12499929540940832, 0.07117042618413126, 0.06994932799810363, 0.08285116028761672, 3.7965192093003184, 75.33383384827646, 73.098098539537, 63.52354588047151, 48.798599550800944, 36.11862405653923, 46.458654711323405, 74.62394760501, 42.99391531175183, 0.1602943833436697, 1.027748686892371, 2.67056705970918, 1.13910814687129, 1.5739550970254408, 90.51954100208899, 98.05502599285495, 98.47413909050726, 89.84387351620583, 79.81829535576605, 76.59743324402841, 76.77448903360676, 72.30272031599476, 69.92121404217136, 65.64799570268201, 62.59357936920659, 71.14250675324472, 81.03395554327196, 85.68973049040764, 87.71261445937618, 85.80475007334064, 83.8649340598814, 82.04219295132546, 81.80784702301025, 80.26739105101555, 78.87215691228067, 73.77851209332867, 67.25743832126741, 62.7150434063327, 60.066211915785274, 60.70416973483179, 61.71145792930358, 56.97319553744409, 53.43379382164248, 54.716808949747396, 54.3711147769805, 60.38316688229961, 62.45587671956709, 57.101127562984345, 56.372578682438025, 55.53166958593554, 56.91814507207563, 51.93575043832102, 59.741455354998195, 70.52787919198313, 70.0540647199077, 70.50982844445014, 70.5096637049029, 72.72065670259538, 71.46353706236809, 72.22208422999229, 72.95937999602288, 69.1617255057058, 71.48335287647863, 67.32778210793772, 61.2430053372537, 58.509709527415616, 64.71515801645094, 67.732052956858, 69.74348360492338, 66.36816640054026, 62.62436213031892, 65.60636758804321, 62.33604438843266, 52.25708669231784, 54.673521672525716, 55.512226396991366, 62.64055367439025, 63.16651605790662, 61.13573243541103, 51.88097061649446, 55.40298446532219, 57.281348705291755, 60.29723559656451, 66.9958476097353, 68.1557866065733, 66.46856338747087, 65.23316583325787, 65.41719951937276, 56.96888093025454, 57.70818102744318, 54.585452695046705, 54.307293891906745, 56.35524180627639, 60.5278984192879, 57.84730749745523, 57.39816865613384, 57.9970008327115, 56.90648386555334, 59.94865848172096, 59.72664448522753, 58.626431419003396, 56.496713853651485, 54.5248128521827, 54.1367413920741, 56.54270364392189, 55.93348503112794, 54.306281920402284, 52.18928460151919, 48.97002673918202, 50.094542810993815, 46.413778874181936, 49.12489368069557, 55.71850776672364, 53.49038577848866, 54.506848396793494, 52.25592567074684, 52.256259072211485, 53.982270609947946, 58.456530032619355, 57.77688526338147, 65.64057850068616, 71.31126280753844, 76.02077422603485, 70.95859466060516, 77.013275084957, 71.00672998735982, 72.70899941844326, 71.7143726348877, 73.41360615145776, 67.63667660374796, 71.9687383405624, 69.47803328114172, 75.65405614914434, 73.26488556400423, 74.23964946500718, 69.1933790329964, 83.86212564283802, 74.66852926438855, 97.48101065235754, 20.63294972142866, 0.9736676598268171, 1.4196445192060163, 0.2971635752868268, 0.09179846203375248, 28.280045755447883, 87.90254346786007, 63.95333959210304, 57.63000426753875, 41.56826711470082, 36.71860156520721, 22.61043029446756, 42.48023386924498, 59.29121825002856, 73.04026711371638, 31.71075074903427, 0.3540097813933127, 0.1305218470553237, 0.0675579768815829, 0.14009566316681524, 0.07020409819820235, 0.0707062152064135, 0.024870268797742266, 0.03860418940143239, 0.04156408117963903, 0.06081970881730799, 0.17668299587263217, 0.30884362757205963, 0.22060506887012915, 0.13361921714198205, 0.11756062762992037, 0.15685682425335531, 0.19920152221475879, 0.3108858341170896, 0.09686555142604536, 0.26751747414950405, 0.23333211819971764, 3.946733484345098, 89.40898464572045, 82.75648009392523, 67.07034126404794, 47.108207056599284, 52.80466525785385, 86.71803474426271, 83.14780712127686, 51.08376456845192, 0.2824577514923388, 1.4546177199771329, 6.451795399188996, 6.393525648501612, 1.4692639727746288, 90.42515308626237, 103.21243286132814, 102.3107897850775, 94.23867748629664, 83.69828824074038, 81.57645071706465, 82.37906963594499, 78.87461231600854, 73.5685319285239, 69.79491372262278, 64.77853567369523, 75.95832224815123, 84.22734537432271, 89.54163920494818, 91.24640326346122, 89.6636562962686, 88.21197140601375, 85.9113993183259, 84.93404665300923, 83.89352029369724, 83.40874671936035, 77.6379752928211, 69.07137763115668, 65.85680700117543, 63.37369565040835, 64.1516585503855, 65.62453992905156, 59.823664311439764, 56.89817628552837, 57.77541437456685, 58.27758366061796, 61.86946668932515, 64.6760323739821, 57.300697757351784, 57.40635856505364, 57.6888241306428, 59.74407157590313, 54.595223319145944, 63.46523200311969, 76.0031706287015, 72.47976826083276, 72.70976820299703, 72.65602388689595, 75.82030188652777, 74.00992408875497, 79.2252722094136, 78.56356836134388, 72.36062234447849, 72.93011126979705, 71.07153538734683, 65.81104863074519, 61.989816773322325, 68.00516759195636, 71.15617229092506, 74.54721819969916, 68.21976830882411, 68.95961361546671, 69.18860943086686, 66.98085631093672, 56.58713233086371, 57.18717259745444, 57.507124254780436, 63.24892505522698, 65.05286624354702, 62.188096507903076, 53.943690176933046, 58.777344611383256, 60.56988346961237, 66.25423723651518, 68.86706921362108, 70.04759280912339, 71.74526522236486, 68.63230751406762, 68.3044836598058, 59.83800449678975, 60.758247452397505, 57.27760284177719, 57.25090719038441, 59.27606221168273, 65.32608286026986, 62.54473801582091, 60.28822198990853, 61.718110269115826, 59.91895829477618, 62.36170061172978, 63.45501815119098, 62.81295361057405, 59.518939295122706, 59.23406147187757, 58.232927476206136, 61.464313307116115, 58.440895465112504, 57.90311890263712, 54.816966672097486, 51.8365183953316, 51.80803414314024, 51.00319908511255, 51.65513230908302, 59.04847060480426, 56.56776758932299, 58.443637201862956, 54.89998755916473, 55.849146227682795, 56.89028447674167, 64.33347609735304, 61.528067511896936, 67.68303901918473, 73.71536193355438, 78.6112565378989, 74.13657742161905, 81.4369555442564, 75.91177155894619, 76.09736242601949, 76.04915649660173, 77.48004498020296, 71.19606279557752, 77.44355124811973, 72.76086099686162, 80.3346126310287, 78.61682630354359, 78.62242744814965, 72.89209565808697, 89.54736586539977, 79.08831088773667, 104.45192537000104, 17.85487025014816, 7.731421109168761, 12.760300732428028, 0.32615540669329707, 0.5534195263058909, 37.09459996992542, 94.38178908440375, 72.01680306465396, 66.25258199630245, 58.45527487416422, 59.452157020568855, 30.701789663683986, 50.71927439781928, 69.54663553545552, 83.86212564283802, 40.347276426130726, 0.5332077366690482, 0.3282091045571912, 0.12255071752494383, 0.20228124163564176, 0.19868782961801176, 0.141584386508311, 0.2049768445712905, 0.19880602166296976, 0.09529435105862157, 0.12142863620312945], [0.21540156986203887, 0.04094890874600218, 0.13686669449652397, 0.07993657111881242, 0.09232774451975861, 0.023801796393649235, 0.04322988957527184, 0.048778875085014495, 0.08679402331190725, 0.058381086245419524, 0.020097640620905067, 3.130450498673224, 63.96216492499075, 54.11238739567419, 56.26928698632025, 21.51100170227789, 68.33377592025265, 49.59469164571455, 78.92701518151068, 24.07683191760894, 0.37773742430633117, 2.015993835464601, 2.5472232266779873, 2.1725302357827467, 16.472962364073723, 112.96644964525777, 82.10147565410983, 95.59187950626497, 79.26204835214924, 81.84280318598594, 70.64526004175987, 76.40222472529258, 65.99659242937642, 67.73674411158409, 60.177320895656464, 65.48799830098307, 56.20927080031365, 64.31667266353485, 69.58806360921552, 79.90121426120882, 75.35208071431806, 78.63186467078425, 74.01510161738243, 76.1992028451735, 68.08370913228681, 63.12509975125713, 57.149133451523326, 60.20553842667611, 56.54673191808886, 59.76419725725728, 58.851991238132605, 58.38401717524375, 51.152002042339696, 52.706292213932166, 50.40782643902687, 51.04856914089572, 58.703502070519235, 58.88349963772682, 54.1953847485204, 53.805485463911495, 50.92508900550104, 53.59436388938658, 51.21281839186146, 57.59283981015606, 67.45631033374418, 65.78380776989844, 67.6497616306428, 70.49664928067115, 66.73976390592514, 68.37492158336025, 67.59332656860352, 68.90550059656944, 68.20269030909385, 70.81045458393713, 68.75905498381584, 66.16336376436296, 53.983788567204634, 62.44795745418918, 66.15242819632253, 67.59411104263799, 66.18726668819305, 65.12655581197431, 63.246218619808076, 52.68799043470814, 47.660861169138265, 53.71605150161251, 56.09020725373299, 61.183624575215006, 61.91382477360388, 63.208724683330914, 53.1483825560539, 49.887594638332246, 44.71939732951503, 48.348738993367846, 59.881672243918146, 64.40090164061516, 64.3043799554148, 59.293775635380904, 54.23160391469156, 51.23620748519898, 48.960781712685865, 51.17110790744905, 50.30214994184433, 54.92506327167634, 55.77660199134581, 56.76648662936304, 57.37356755041308, 55.117675181358095, 56.646740590372396, 57.03030524715301, 54.67323926187331, 55.297366803692235, 55.51070843973468, 51.64131772133612, 50.262859559828236, 55.089614545145345, 53.53438300471152, 50.29360309723885, 47.85935271170832, 47.72173635421261, 46.87773643001434, 44.04952318437638, 42.952036165422015, 50.87428646702921, 50.84453136690202, 50.00833695934665, 49.46227635106733, 51.44940399354505, 51.2174036425929, 52.60820942540323, 54.87976381855627, 64.97752143490699, 69.8968090549592, 72.41527665045955, 71.49621040590348, 71.61881585274973, 69.41493803454985, 68.97819780534314, 62.04578899568128, 64.12634749566355, 62.937575155688876, 67.8748115416496, 65.17696219105875, 68.64518073297316, 67.06399486910912, 68.73699557396674, 63.34508588237148, 74.99410167817148, 75.7642355272847, 85.33004914560627, 57.29865420249201, 0.44880295773186996, 1.9989480727141904, 0.1868133748611135, 0.30360922457710393, 6.784877190666815, 68.69908978862148, 67.30447538437383, 50.29250091122043, 43.382461378651286, 57.18334436416627, 24.553543060056626, 45.05545031639838, 55.009441298823205, 59.81529005112187, 31.202339010853922, 0.08390904344137638, 0.03758759455635183, 0.0459523783666232, 0.01677781775323374, 0.03920215166985028, 0.039124014532013286, 0.06030140820169642, 0.08430897198136776, 0.055142093314639026, 0.07463472174300302, 0.18277118853744, 0.047448708961207064, 0.04091540006019416, 0.017351623354179245, 0.03107110894615612, 0.047011410652269284, 0.02333820977758977, 0.0333914322207772, 0.0328087151020525, 0.024376239762791706, 0.03804146334709179, 4.420005688744207, 74.72241478581583, 60.91066683492353, 69.03069480772942, 29.025413759293098, 52.06895020700271, 54.91110747860324, 90.78528942600374, 24.633635897790235, 0.34163798235597154, 2.0152517720576255, 0.9196543549337696, 1.4776800308496723, 21.488110749952256, 118.59571764546057, 85.30514209501206, 102.88809991651966, 79.77063855817242, 85.41553328114172, 73.94784865840789, 79.0002222984068, 70.07716748022264, 71.85206351741668, 65.73092245286512, 67.76447526870236, 59.38033450034357, 67.09462858015492, 72.79464829352595, 81.90943641047325, 77.11014193873253, 80.85272635183027, 77.1220188756143, 76.97289820640319, 71.21183072367023, 65.54987761282152, 59.957103344701956, 62.82477563427341, 60.904971553433334, 61.352796400746996, 59.61304480029691, 60.19313981456142, 54.74681900393579, 54.33478186207434, 55.416120483029275, 56.41715249707622, 61.135850106516195, 60.5201635053081, 52.99901085515177, 54.49107262396044, 52.15755262682515, 56.51427430491294, 54.534085335270056, 60.97807668870496, 70.13663061203496, 70.24567250282534, 70.6601885826357, 71.65046938004033, 70.48134419225877, 72.20186833412417, 69.46418731443345, 70.99242902571156, 69.31778877012192, 72.55870203818046, 74.04870064027848, 69.39684806331512, 55.59156810083697, 65.14055867348948, 69.75809835618543, 72.75136886104461, 68.6115267968947, 69.22381662553357, 65.82619682435067, 57.194919278544766, 50.46361823235789, 56.61153339570569, 58.46039356723909, 63.482317847590295, 63.535391438391905, 64.38657714474586, 54.48130984460154, 52.10362395932598, 48.802043391812234, 50.636108383055664, 60.34848136286582, 66.54102525403424, 65.0792794842874, 60.52951835816907, 56.7138562663909, 53.49777944626347, 52.270183486323205, 53.191771814900065, 53.30487728118897, 58.29588936221216, 59.55992414105324, 60.553009433131066, 60.090958149202415, 59.80409168427991, 59.81817691556869, 60.84930527594782, 58.488226705981845, 57.51278423493909, 58.08118274134975, 56.204065815094985, 53.28933292819608, 55.21064319918233, 56.67928057332193, 53.3283644337808, 51.638226893640336, 52.17269297569029, 49.73412013822987, 48.349327348893695, 46.12448838449294, 53.14698226990239, 52.52711834446077, 52.61035888425766, 52.48569811544111, 53.958234325532, 54.31051415781821, 55.78315627190375, 58.49614597135975, 68.07190279806814, 72.31978262624433, 75.0890544153029, 72.87383310256466, 75.00160909468129, 70.87790366142028, 69.44640328807216, 64.37255467137983, 66.88219301162228, 65.99035586080244, 70.09182929992676, 67.76094513554727, 72.15973423373315, 70.21303053825133, 69.27022610941242, 66.51196049105737, 74.4151206170359, 79.93358950461112, 83.88271024150234, 67.51058809218868, 1.2573303450499813, 1.3286683299849111, 0.6335275632239158, 0.381336321513499, 5.793086771042117, 74.58418261620307, 76.84692736594909, 59.94923507013629, 51.5468317462552, 39.65263643572408, 27.146043431374338, 57.896529320747625, 61.479896883810724, 68.29936888910109, 40.792783152672556, 0.11773076809702382, 0.026922698786121704, 0.02182009164243937, 0.035224389510169145, 0.013354641963697731, 0.02549896459846247, 0.04823944193401164, 0.031947580564226356, 0.13398004455431817, 0.06404699209416587, 0.3570580146005077, 0.08338111693099623, 0.23616917160970552, 0.10008580967663758, 0.10677803968710285, 0.23122310878769045, 0.1249067979534307, 0.14376156242384067, 0.18994627610570003, 0.16865804100469237, 0.21915714737148057, 5.452535806163665, 88.2323363519484, 69.44745448327834, 73.61576511013892, 29.621812105178837, 93.83092357266335, 68.56610575029927, 97.57476314421623, 29.82989972637546, 0.45833459304225066, 4.1627555701040455, 7.758608527721898, 4.9292278866614065, 20.914899495340165, 124.49515850313249, 88.26481357697519, 108.00358449259113, 84.78655768978982, 91.68945066390499, 76.9057236948321, 83.37739913694321, 74.14033505224413, 75.92907705614644, 69.07460966417867, 73.74721157935359, 62.57036678252682, 71.5270245459772, 75.86810773418796, 86.95924482037945, 79.97838297197896, 85.12670563113305, 79.90764694829141, 82.18763443731493, 75.22281508291923, 68.9881214018791, 62.005043414331254, 67.85206179465017, 63.88946379384687, 66.9267354472991, 62.94236436966927, 62.649367240167436, 60.0231364465529, 57.38772338436496, 58.607709946170935, 60.077355369444824, 62.476061236473825, 60.46956493008522, 54.45960737043812, 54.75974321365357, 53.82644268774218, 57.34055296067269, 56.7990501465336, 64.35549628350043, 74.0603579244306, 73.03519941145375, 72.09648993707472, 74.95512900813934, 73.06260108947754, 74.57743613950669, 73.58462933571109, 74.09567494546214, 73.45178650271508, 78.02041422936225, 73.99243816252678, 71.74350800052767, 60.160431169694476, 67.6803796522079, 73.79279736549624, 75.01207397830102, 72.2476973072175, 73.08843381943242, 70.92363849762948, 63.96656974669426, 54.60651190050187, 58.20190937288346, 59.52614468912925, 65.31491587238928, 67.08717607682752, 67.96044472725161, 55.50209491483627, 55.36898536066855, 53.042211840229655, 54.55011998453448, 62.803528155049975, 71.12072190930768, 69.09040897123276, 64.16781871549546, 60.43290253608458, 58.52014303207398, 55.81524518228347, 57.681952138100904, 56.38979004275415, 60.7023968235139, 63.239244645641705, 62.831533878080315, 62.94065421627414, 62.43465669693486, 62.85746074491932, 61.639882518399155, 59.71774854967671, 60.47317743301392, 61.20272651795418, 58.04843095041091, 56.65522075468495, 58.229718977405184, 59.78300502223354, 55.81528048361502, 55.72787046432496, 54.805733003923976, 51.86192750930787, 50.10862411991243, 50.227201292591715, 56.45299903808102, 57.3999886358938, 55.24163776828397, 57.37804297477969, 58.764432168776, 57.787118727161044, 59.61148369696833, 61.003489725051395, 72.12732761136948, 77.00286511451968, 78.53133432326779, 78.08111683014901, 80.704876530555, 74.99866731705205, 75.67664900133687, 70.45146357628607, 70.37391047323905, 70.74217396397745, 74.37730896857478, 73.70298293329054, 76.5799080940985, 74.357555912387, 74.29075794835245, 70.17816066741943, 77.60057941559823, 84.86812729989329, 89.86851384562831, 66.04997588742164, 0.7770506424769279, 7.975474903660436, 1.0333686466178587, 0.3182947930068739, 8.262323717917166, 86.52037866653936, 82.34507053129136, 68.41854618441674, 60.39286690373575, 74.29923026792466, 35.90454893727457, 62.58185932713171, 70.21563499204575, 78.8466771956413, 55.60843037020776, 0.41378339331957603, 0.12794361645055394, 0.13988483577005326, 0.1343468168089467, 0.1472064912799866, 0.13796739430437166, 0.17333344496305914, 0.15903760078212908, 0.2434860926962668, 0.2484327530668628], [0.058118505778932766, 0.14309448370289418, 0.029223417870760448, 0.04409609753037653, 0.015935903403817887, 0.05114312967165344, 0.028648193091935212, 0.03797218218565949, 0.032402167562395334, 0.08731866330509225, 0.11121787160875336, 2.5082405055722883, 60.80446081776773, 60.45856660412204, 54.20331970337899, 43.649421814949285, 55.18177847708426, 44.86541932629001, 87.88401419116606, 7.231390985750384, 0.0746059398196878, 1.7123075117987974, 1.3026380106326074, 0.5122555383751469, 58.733578805000555, 101.69880590131207, 83.90454999862179, 89.81458910049932, 73.79017722222113, 76.52716006002119, 71.84792933925506, 71.49870503333308, 68.34205996605658, 68.67802666079614, 59.57591564424577, 61.20010637467908, 60.169170210438395, 60.67738386892504, 58.222015442386756, 62.51926614392189, 66.4741253083752, 67.17710818013838, 66.11606782482517, 63.78705855338805, 59.42823840725807, 58.53995884618452, 59.15534734725953, 60.03001628383514, 57.714237166989236, 58.9570362337174, 57.55438489298667, 56.09057595652919, 51.0726015029415, 52.29429429577243, 49.96246091781124, 52.2391418487795, 59.0190645956224, 58.02634800634077, 54.63386258771343, 53.92723191169001, 51.67789774556314, 56.12611263029037, 52.28507280349732, 57.31451626746886, 68.94894476859801, 66.1505219244188, 66.91383869417253, 66.81594417941186, 67.36400127410889, 66.37529726951354, 68.33468591013263, 70.9046071575534, 67.18569817081575, 65.02494681266047, 74.12085656196841, 70.90252830136207, 58.49414948494204, 51.604514122009284, 61.83522047535066, 69.39459662283622, 67.65242099761963, 62.976567437571866, 57.33848194922171, 48.5998805107609, 51.56132490404191, 56.91274004597818, 58.24873462800057, 60.86837976209579, 59.429532789414935, 59.20301198959351, 54.54428349771808, 45.90816574711954, 46.435387211461226, 50.40843832877375, 60.47353829106977, 62.31671494822349, 58.4747023736277, 53.86786291676184, 50.27843921415268, 53.22341357508014, 48.65685685988396, 48.910347877010224, 44.95715571988014, 48.214374280744984, 53.0329668137335, 59.0768999438132, 58.00025639995452, 59.89590652527348, 58.03090972285117, 55.652466820132354, 56.220096541989236, 55.766513655262614, 54.320826069001235, 53.860359422622196, 48.83983150605233, 52.096944162922526, 54.64459811487506, 52.56877783806094, 48.44893986178983, 49.2787015822626, 46.62116242993263, 47.67263220202538, 42.33178784770351, 46.10440584921068, 51.64451053065639, 50.67590867319415, 51.345508252420736, 50.10332107543946, 51.621525441446614, 54.38359183649863, 57.8391646569775, 65.98504497158912, 71.20011852633569, 70.98347817697834, 69.44701517781904, 68.93900548258136, 62.38831781571912, 57.575106774607015, 58.31856458417831, 62.05128423629269, 66.71313101245512, 65.57416885129868, 70.55676352593207, 66.86420502201204, 66.47796923114409, 62.87903378086706, 67.7294877267653, 67.03670301745015, 78.37480821917134, 75.60548151693037, 89.14788815283006, 19.75039093725143, 1.894235252853363, 0.887742257646976, 0.22539786814201265, 0.2673166671827916, 48.20606670072002, 68.08858071604084, 62.155599671025435, 44.403215069924634, 56.69067898104268, 25.396770277330955, 19.661168782941758, 52.02389394083331, 52.90075155996507, 33.618509231075166, 0.2564773197856642, 0.08115069790472908, 0.07762501572048472, 0.028452848332122933, 0.03474563818364855, 0.09572625610857241, 0.021351563759268295, 0.03012107373515685, 0.07731530169445662, 0.07235760965775098, 0.014461343112822263, 0.0938140929886891, 0.05821469577870542, 0.019027959713111484, 0.061403628694073814, 0.041756449687865474, 0.06346246317750023, 0.022443884480444175, 0.027359514459667188, 0.07851635135950581, 0.15892464877857318, 3.832924442906534, 77.21839935548844, 67.31921565148139, 60.525411636598655, 37.498945343878965, 49.4154393288397, 56.07831070500036, 93.84949991779943, 6.380009160887811, 0.22876508503911958, 2.911424122510418, 1.5175467561329565, 0.43529845173320464, 66.09984490179247, 104.57220092896493, 88.58027412045388, 92.9165720170544, 75.58332012545678, 78.72484053334883, 75.33495564614573, 75.36362032736503, 71.41148721018146, 73.54815129310855, 62.67230526093514, 65.46439739965624, 62.435378413046564, 64.5375217160871, 61.6748582932257, 66.3657815994755, 69.50733338632892, 70.75477261697093, 66.5678071975708, 65.384153550671, 61.522631106838105, 60.39696970293599, 62.34522273463588, 63.00043113770024, 62.37026314581595, 59.617245658751465, 58.770998216444454, 59.34222475174935, 54.48332202049994, 56.80145455944923, 52.727594606338016, 56.34427093690442, 62.02319222111856, 58.34608001093711, 53.54670316942277, 54.39383706738872, 53.665876542368245, 57.24193672980032, 54.25959394824121, 60.19597176582583, 71.40900827223255, 67.6266118018858, 69.44560312455701, 67.72280400799167, 71.37843731910952, 68.73260251937374, 70.2404086820541, 75.0342510592553, 71.20502148905109, 64.89413184504356, 71.38807850499308, 70.7394753732989, 63.66839901093514, 54.64806941247756, 65.03897713076684, 71.35829987064486, 71.79758964046356, 65.88828794417843, 61.13362612262849, 52.75743992097917, 53.324720551890714, 59.701588384566776, 60.08545506385065, 60.87520468619562, 60.39459666898174, 61.05524147710493, 54.96129028258785, 49.563367597518436, 47.99498434989683, 51.688825468863214, 63.49380254745484, 65.39131579860565, 60.64609512206047, 56.35199408377371, 53.84538381330429, 54.79495825306062, 53.822371267503314, 51.2570744945157, 49.98940367852488, 51.712767616395034, 54.68747354322865, 61.759404982289965, 62.43448019027711, 63.831479395589525, 61.687664831838305, 58.4332742998677, 59.66095262958158, 57.59631503012873, 56.679849316996915, 55.37510033576719, 51.99637066933417, 53.78403009906892, 57.57373786741688, 56.56229588293261, 52.87670350843861, 52.81783265452231, 50.165553400593424, 49.644811691776404, 45.59259145490585, 48.66100672752627, 54.62648068704913, 53.88798467574581, 53.83999447668753, 52.45016928642027, 55.39397085866621, 55.890864556835545, 60.80542964320029, 67.08334784353933, 72.24522621400895, 74.14766988446637, 72.67015226425664, 71.82546200290804, 66.80670307528588, 58.911254329066125, 62.21042656129407, 65.59349436913767, 69.93995512685468, 69.04871417630103, 74.1832693161503, 68.60777701100996, 71.14570740730532, 67.34781757477792, 70.5734649781258, 69.55952444384175, 81.3287530406829, 76.11957088593515, 93.56250793703141, 26.628218004780432, 1.167315504243297, 1.0616341040980433, 0.5265905756142832, 0.11339487898493968, 50.447434533026914, 79.38393992762413, 69.33824785294073, 52.79784425612419, 47.79439041691442, 22.641673934075143, 26.27940750891163, 62.002686069857695, 62.4812936782837, 44.9859380722046, 0.5211019540025342, 0.04708109017942221, 0.07356973695418528, 0.0790166297566987, 0.07107997418291147, 0.02540435848547326, 0.025469638752721013, 0.03298079377160438, 0.04470244080068604, 0.031729312538499796, 0.1454601478913138, 0.333605305321755, 0.1608677082244427, 0.19178778293632692, 0.10378746225708917, 0.18882829335428056, 0.18061604531061265, 0.12449066665384079, 0.07895420891262832, 0.13854395207618514, 0.29657626164055645, 5.166891649846108, 90.14135391481462, 77.17211538745512, 70.8810023338564, 56.54577485976681, 74.70794123987999, 59.94512834856587, 105.81924792258971, 8.548056617859872, 0.18717414098641566, 4.506515033783452, 5.732460656473714, 1.3190058162135463, 68.20465933892035, 108.67187792255034, 91.05586236523044, 99.10677817560013, 79.57634787405692, 84.20152048910819, 80.27648310507499, 80.44814171329622, 73.19253352380568, 76.57141224030526, 67.23804612313548, 67.11064753993865, 66.71590805053711, 65.97938891380065, 64.80954200990739, 67.94012684975901, 74.87211596581244, 74.56990518877583, 70.98896949521958, 69.10829497921851, 64.43132354367164, 63.83505267481651, 67.02308454821187, 65.36435734841132, 63.381622760526604, 65.82182730397871, 63.179789358569735, 63.22124881129112, 56.986755171129786, 60.30849279895906, 57.77766189267559, 58.82653897808444, 63.45472789579823, 58.47063879812918, 53.904435096248505, 55.58107576062603, 54.03029218796761, 59.40839121418615, 58.11113395998555, 62.46170536164315, 75.27480217718309, 71.82351650730257, 70.8085875357351, 71.77200009745937, 73.91773270022485, 72.44911886030629, 75.73142097842309, 78.12757338246992, 74.26213249083489, 68.28822151307138, 75.1869724642846, 74.31723394701558, 63.735263655262614, 56.969661481918834, 69.45406759938886, 74.29668072731265, 74.53106587932956, 69.23258704523887, 65.64514021719656, 58.270386111351755, 57.81818389892579, 61.56253337860108, 60.506850980943256, 62.6957884911568, 61.3636064529419, 63.22481424577775, 57.87577213779573, 50.859918825088016, 52.359433097224084, 53.47482573601508, 65.84168234179097, 69.91613065042804, 65.99492149968302, 61.43360114866688, 56.54229963979414, 59.537217540125695, 57.62468945595526, 53.35193003377607, 53.38980051778978, 55.00948052252493, 59.1883501698894, 64.17267853213896, 64.86864820603402, 67.89970290276312, 66.82907627474877, 60.91698185090096, 61.450212386346635, 61.51764185197892, 60.49001616816367, 59.61417052053637, 57.326777596627515, 57.51132511323499, 61.45024376530802, 59.49225148847027, 55.30083025655439, 57.39530532590805, 54.74918027077952, 55.14276266098023, 50.07790411672285, 50.381115098153394, 57.70930282531246, 56.34044270361624, 57.49677311989569, 55.63540843225295, 58.69986995573967, 59.58673354118102, 64.2032612523725, 70.1060047457295, 75.72123850545576, 78.65833282470703, 76.81681140776604, 76.92430788470854, 71.01542980440202, 63.7576093981343, 66.44558614300144, 69.54143447260704, 72.99709750759986, 74.40867224047261, 77.96208074015956, 72.36407403023013, 73.91716787892004, 69.54565494291245, 75.21204425442603, 73.48951185903242, 85.00223313608478, 80.0944302158971, 96.95924128255537, 25.52342753256521, 3.3524029629845775, 4.4721325174454725, 0.2984789482528164, 0.5205813206491933, 63.36305033776068, 82.98660555193501, 79.8707688239313, 61.15153958720546, 76.94691642638176, 38.93770210204586, 32.18735206511713, 71.73051711051696, 70.17167306715443, 64.63583984682637, 1.1690325217862283, 0.14700364651939563, 0.14035981028310715, 0.1604187347355389, 0.17540669339078088, 0.22762644855726152, 0.13199658163132208, 0.10571528421414476, 0.12462650170369495, 0.18603498356476908], [0.03653547621422237, 0.041599528067895485, 0.03420257760632423, 0.02295420437510456, 0.041687988240512154, 0.10791820834480947, 0.06462566043821073, 0.120437870012416, 0.038964043882104664, 0.11228509337431002, 0.14203233343939628, 3.8067284034144495, 56.4637698665742, 52.62484027493385, 40.15032245266823, 53.870808616761245, 48.39025728164181, 58.22174087647469, 76.68654949434342, 1.2439895060754593, 0.07627994918655004, 1.1362453069417708, 2.280728081541677, 3.1316870258700464, 93.83331621846845, 91.74131224232336, 93.86330666080599, 81.5051498720723, 74.93367364329677, 71.21030099930303, 72.34257159694549, 71.25005029862928, 70.06773025758805, 69.65464192052042, 66.28031315342074, 62.65609410501296, 59.91655388186055, 61.06385107963317, 59.6217171607479, 59.70186687284901, 61.56488680070447, 59.48176699299967, 59.20532226562501, 60.07184443935272, 59.527054679009225, 60.215399265289314, 57.30922106773623, 56.73261304055491, 56.78916577369937, 55.22996479465116, 55.95303804643693, 54.38761618829543, 50.60075998306275, 49.3371605873108, 51.47137711125036, 55.3272395749246, 59.56437995356899, 55.67408300215199, 56.358815085503366, 52.62862928452031, 51.338016525391616, 51.589271791519664, 53.89062835324196, 54.05773308969314, 66.13552278087985, 65.20229285763156, 63.89009137307445, 67.5533027033652, 67.84761382687476, 67.74083122130364, 65.11405129586497, 67.86411131581953, 68.29340688643917, 69.314831303012, 56.40731127031388, 57.83379885458178, 65.93851781660511, 52.68132632778537, 56.7838470397457, 64.65298452684956, 66.21391527114376, 60.24594668419131, 51.34405305308681, 49.9490346447114, 51.43403222483974, 52.49002841211135, 50.027081966400154, 51.141180223034276, 48.2930217250701, 50.16871875332248, 50.336203959680375, 47.88219267322172, 47.67389912759104, 47.0174708674031, 64.55931832713466, 56.56939145057433, 55.54526059858261, 52.933938733993045, 53.669104653020064, 50.992526315873675, 52.7070806103368, 54.524463761237364, 53.86856894339285, 49.64737299949893, 47.784266779499674, 50.73295562498031, 58.013910170524355, 59.69219823037425, 56.90271054544757, 57.10326917709843, 53.67171302918465, 53.870859607573486, 53.67478424502958, 52.95781027886176, 50.62795377546742, 50.647055718206595, 55.191462809039706, 53.93796351648147, 53.33267119623, 48.77641070273615, 48.47817720905427, 47.26069704178841, 43.99426483338879, 42.85843664600004, 50.30850418152348, 50.63544158012637, 51.93567983565792, 49.98367309570313, 51.064697927044286, 52.97961081227949, 57.472521105120265, 62.90260722560268, 71.65504286366125, 68.2116803815288, 66.80937028700306, 61.02157969628612, 56.9458213160115, 54.65347051620484, 60.36867764688308, 64.97147314010128, 68.80665686822707, 67.4971108282766, 70.31823635101318, 66.61689173790717, 67.18347026455787, 64.88312567434004, 63.97956455907514, 64.7442384689085, 75.04033073302239, 76.08065312908542, 84.81287679364605, 57.65373852945144, 0.4246198602261082, 2.942531950050785, 0.17633960462145268, 0.2063023911849145, 19.37441606675425, 71.19831423605643, 60.517315864562995, 50.96389301361577, 36.456802968055975, 42.721643986240515, 33.42363411380399, 45.089457265792355, 59.40718704654325, 44.36472877379387, 0.44746006688764023, 0.05627817106283, 0.06098573539225806, 0.039256210664227124, 0.05219786037360469, 0.04346248536040226, 0.10976434234649905, 0.11266149535414674, 0.04200768822263326, 0.1005836059489558, 0.03882381148756512, 0.023793875044512174, 0.03279752255747876, 0.014761856422879764, 0.06210978939047745, 0.07574566414639836, 0.02798405423339817, 0.15240448977678053, 0.04696479037163719, 0.1055098117719735, 0.2350707241003552, 7.700326519627725, 67.70548282131072, 60.134602362109774, 46.617381265086514, 37.124731617589156, 48.228969420156176, 71.50103492121544, 79.32396688768941, 1.3669485791075615, 0.43774548978094135, 2.0124803723827487, 1.4936187046189464, 4.269644079669829, 101.96076531564037, 92.69308320937618, 98.65754127502443, 83.84626357786118, 79.61152368976225, 74.22920811560847, 79.33801681764665, 74.2051326074908, 76.07492646863385, 72.75413020964592, 70.72884575013192, 66.02382936785298, 64.09054017836048, 62.472264382147024, 64.84619263679751, 61.36086863856162, 64.38894625632994, 61.871953472014404, 61.39235350393481, 59.826409970560384, 61.65677616673132, 62.87141261562225, 60.76699433788177, 59.7809418555229, 58.884115449843875, 58.23117025436894, 60.23070435370169, 55.92882133299305, 54.0933011424157, 51.76788083968624, 53.22180148093931, 57.9431898363175, 62.40582727616834, 54.8643292919282, 55.25156136481993, 53.55393602002052, 51.15721487229871, 52.81483988608084, 56.742387587024325, 57.21494690064461, 68.76871970392042, 69.18500085030833, 66.62828230088758, 69.92169257133239, 69.39485549926758, 70.3439514098629, 69.52023013945549, 72.31129461719145, 70.23118326740881, 71.00746739295222, 58.05626000127485, 60.991510806545136, 68.04393629873952, 55.0794203050675, 58.52865065297773, 67.07410673941335, 69.81297231489613, 63.009334917991396, 53.73025440400647, 52.846728755581765, 54.29189466661023, 52.82386133747717, 51.09419022836993, 51.13305699440741, 49.26243159078783, 51.009196389106016, 50.160493543071134, 47.6434576126837, 50.03577786107218, 49.43826752324259, 66.26337635901668, 62.09395962376749, 58.59517012873004, 55.79821425099527, 56.5076925677638, 56.135161538277906, 55.88782079758183, 57.39802352843746, 57.850492462035156, 50.706244284106845, 49.72853468310449, 53.54184335277927, 59.71495582211403, 61.849862683203916, 59.446355835084, 60.49503680198424, 57.34111385960733, 57.05307460600331, 56.64127280635219, 55.914469380532545, 55.46965299114105, 53.60313038672171, 57.74272534155077, 55.98433071567167, 56.49051650877922, 53.230779786263746, 50.58328974631525, 51.00635659310126, 47.04832815354871, 45.826917771370184, 53.183699577085434, 51.32804193804341, 54.98202785368889, 53.135670154325425, 53.66947335581626, 55.649630946497766, 60.39822093902096, 66.72984030938917, 71.68614725912772, 72.17875772906889, 70.26540986953243, 64.26676834783247, 59.313509079717825, 59.14260356656967, 63.30766647092758, 67.09233007123395, 73.56449973198676, 70.34759921412315, 72.54888042326897, 69.91697788238525, 69.73832961051696, 66.61994334190123, 65.72050856005761, 68.80273449805476, 77.94218647864558, 78.80268389178862, 86.14965192733273, 67.92485314030802, 1.0492255634838537, 1.9362227546591915, 1.0463543885177182, 0.4460391270056848, 18.80041249336735, 81.36537228861164, 69.93346752658968, 62.068993737620694, 42.521363842871885, 28.68275550103957, 35.77258079282699, 54.351969688169426, 64.25511498605051, 57.16172818214663, 0.6989513493834004, 0.1388187018493491, 0.07383009959613124, 0.016360880146103523, 0.022502421258738445, 0.05118737507972026, 0.10560233221058885, 0.07848622112144386, 0.024738718094604633, 0.06616055589890288, 0.1304787009834282, 0.14805756899858677, 0.14381215487036014, 0.1770876588359956, 0.12503894045948982, 0.2274522708067971, 0.20840973052526676, 0.2390045243045015, 0.24022122514584374, 0.44046071988921015, 0.5701743595061765, 10.874491833871412, 82.63138786438974, 67.81479927801317, 55.896120532866455, 71.9512681038149, 72.87291526794434, 73.94933131433302, 90.6526505562567, 1.890796192230717, 0.5361415469838727, 4.399476003262305, 5.935093241353189, 4.028713472427861, 105.51839428563272, 96.40972506615424, 103.82218099409535, 87.56497644609021, 82.98331860573062, 76.9788052958827, 82.96575423209899, 77.69615973195722, 81.13567044658046, 76.81034734172206, 75.30961713483258, 70.54320781461655, 67.29023718064832, 66.82193756103516, 69.03558208096412, 64.81635124452653, 68.90851297686177, 65.07275266032066, 65.70971027497323, 64.39228027097641, 65.05445088109663, 65.24114001181819, 63.6324740225269, 63.474845732412035, 61.65419524715793, 60.138077582082445, 64.3307343606026, 58.72852286984844, 57.779772127828295, 55.998047244164255, 58.8360232691611, 60.608793381721746, 64.15229397435343, 55.82328604113672, 56.05199944588446, 52.829466404453406, 52.61974903845018, 54.13959687755954, 59.54545059511739, 58.55940595749886, 73.40279609926286, 73.14914426495953, 70.79740093600365, 71.31516948823007, 73.64023285527384, 75.79718343673214, 72.73582843042189, 74.24249710575228, 73.95050018064438, 72.25485955515217, 63.132152172826956, 68.56429361527967, 70.20110653292748, 58.95027406754033, 62.353848026644805, 71.74318636617353, 73.4972938414543, 67.20498054258286, 56.88684455810055, 57.922452265216464, 57.726016044616706, 55.03715284409062, 50.69851721486738, 51.01877481706681, 48.688726117534024, 51.30850853458528, 50.094895824309326, 50.321228350362475, 53.07249253795993, 54.79307159300774, 72.77786839392878, 65.02414664914532, 62.56517356441867, 60.40953697696809, 61.21356794911047, 58.99628739203177, 58.778023181423066, 60.71885116638676, 61.52943249671691, 55.48724874373406, 52.38907052624611, 57.48782227116247, 62.940591458351385, 65.14715217774915, 61.53759887141567, 62.802975100855676, 59.24061183006533, 60.27674121241416, 60.091707321905325, 58.79136708474929, 56.68170459808842, 57.54417104105796, 61.43929250778691, 59.524862074082904, 58.53949600650419, 58.18387039246098, 56.192890982474054, 54.32092412825554, 50.126113968510786, 48.41790999135664, 55.17506730171942, 54.07340688090171, 59.20873472767492, 56.582951084260024, 56.965739111746515, 59.07202836005919, 64.32985967205417, 69.38619490592711, 75.06649294207173, 75.88760191394438, 72.19898931441769, 67.48908565890405, 62.24609659564111, 61.45197353055401, 66.8439655919229, 71.03528484221428, 75.42269906690045, 72.8699734903151, 74.70471705159834, 73.60816355674498, 74.45983563700031, 74.08846562908542, 69.08986768414898, 72.74824665438744, 81.58880618310745, 84.43587426216372, 91.29156543362527, 69.76992822462513, 0.7158247117073305, 7.249908985630159, 1.3305944588876542, 0.5194445687436289, 25.289181624689412, 91.12433910369874, 77.27738395813974, 70.68961420366841, 53.469252048000214, 65.39096670766031, 47.49201882270075, 64.15899338260775, 72.76798402109455, 69.26212249263641, 1.6586328177682816, 0.3190140269937054, 0.2003026357100856, 0.10722647691445966, 0.11575062233473986, 0.19013896254041504, 0.17522267907136874, 0.20104152751305412, 0.16839593168227904, 0.14325762978724896], [0.058521127117977995, 0.049004170052226514, 0.004070250997169605, 0.05919492059958078, 0.039229194573577375, 0.19144004030573755, 0.07214786244496223, 0.16817159049453276, 0.01951288187786216, 0.3153096854446396, 0.22375984958583311, 7.691409011040965, 53.85713131197038, 58.46071520159322, 45.28490897147886, 58.671499452283314, 37.20403017536287, 75.98223301672166, 50.13022853482155, 0.26458289774675525, 0.46342953739147036, 11.050438573283534, 3.4609092050983064, 15.184111729744943, 122.54202212056806, 76.73280992815572, 98.54148618636593, 70.4331696418024, 80.2979306251772, 65.74027338335591, 76.79317520510766, 65.88718183578985, 76.29192767604705, 70.29143871799593, 71.67560392810454, 63.846239274547955, 65.0242917768417, 59.77706263142248, 62.037097023379424, 58.19634745197912, 63.60484484703311, 58.99249053770497, 59.63690065568494, 57.18587037055724, 61.27838511620799, 54.77624070259833, 58.77345362017232, 58.09424815639373, 58.16583533440867, 56.267357180195475, 55.724952220916755, 50.11133840007167, 50.94033133599066, 49.793355772572184, 52.685719382378366, 56.23240886196014, 59.10949483994515, 53.75886024967317, 56.34644000760971, 52.76420600952641, 53.02565943810248, 49.29230043965001, 55.59780859178113, 49.467704911385816, 62.93708093704716, 65.41904303335374, 65.10102118215254, 66.70851830513247, 69.7958472467238, 65.39448507370489, 64.2578096543589, 64.99930627884405, 69.58175643797844, 68.66540447358163, 61.3428924160619, 62.36371670999835, 66.74688693015807, 57.29632039223948, 54.818982770366055, 58.278728992708274, 62.426262824766106, 56.763015331760535, 51.02781980268417, 48.12761537490353, 49.230727072685, 49.4255708109948, 54.79390313548427, 54.7449754899548, 57.26508263618716, 57.2399284762721, 53.83179672302739, 49.12029274048344, 45.66341377073719, 44.044192683312204, 59.14491776497134, 60.087784951733006, 58.208875502309496, 54.36502333610289, 54.396618027840894, 57.089485968312914, 56.57206258466167, 55.97392858997468, 58.63892416800223, 57.0014601369058, 55.34856550155148, 50.700486244693884, 52.422312613456484, 57.866354527012, 57.966198459748306, 56.08024051112514, 54.516705313036525, 51.9697730771957, 53.600788731728834, 55.46674259247319, 54.28651317473381, 51.765017509460456, 53.38044174255864, 56.148607423228604, 54.23143133040398, 50.03805283577212, 47.50556668927593, 49.7640674344955, 44.1584748606528, 43.43641750274166, 47.879701968162294, 51.41774262151411, 50.27684673186272, 51.021391037971746, 49.29561484244562, 51.961700839381066, 56.32914627751997, 61.27926764949676, 62.25144670855615, 62.103487060916045, 57.69625702211934, 53.00542785275368, 53.11852939667241, 56.79363335332563, 61.06420409294867, 66.93235228138586, 67.54754466395225, 69.74342084700062, 69.93676231753442, 69.06129713981383, 64.45865069666218, 63.45375122562532, 61.396601430831424, 66.60849786573841, 71.405148659983, 80.43992827015539, 73.90757376147856, 87.0079057447372, 11.397838977075393, 1.21541601996268, 3.160588520188486, 0.30066024572137867, 3.6964404246499463, 65.81588883553782, 68.55740593325707, 55.962781213944965, 38.27214648646694, 33.185142240216656, 23.649613241995535, 35.94773423287177, 51.22428740224531, 48.52959555964316, 0.8596116316414649, 0.10230061583100789, 0.11308521092418702, 0.09267025476982517, 0.059835412239115086, 0.130065810235758, 0.03565234920730995, 0.12926969166484573, 0.027196965923893358, 0.12926956909077783, 0.09988144040107728, 0.06985605679332249, 0.04034286808042277, 0.09571939196077087, 0.0798933101337283, 0.1646295676548635, 0.0807659991926724, 0.21192587491485382, 0.08662059632760864, 0.2536091938494675, 0.4992172428436818, 12.783901633754855, 67.66603946685791, 65.00388368483513, 57.17841394485966, 53.149841677758005, 44.84436012083485, 89.94797322057909, 49.04437134342809, 0.1083608845909757, 0.75675715722384, 14.85005032631659, 8.418502692253359, 18.6383617308832, 127.6031740250126, 79.24139315082182, 103.39363851854878, 72.99356737444478, 82.58620216000466, 68.75222221497567, 77.95752294601934, 69.67791726512294, 81.0344026934716, 71.91897130781605, 75.59983330388224, 67.09251050026187, 67.85504279598113, 61.98183082765149, 65.8939047782652, 60.15039774679369, 65.16969796149962, 62.227963478334495, 62.13388150738132, 59.76737829946703, 61.10248642583048, 58.386802058066095, 62.38029656871673, 61.67339524915142, 60.68487167358399, 57.20672953513361, 59.46752094453382, 52.41047882264661, 54.411558335827245, 52.86909411030432, 55.32600010595014, 59.02443824275848, 60.62631068691131, 54.725830401143725, 57.69054605114845, 52.29611819790256, 53.815707160580544, 50.50980021876674, 55.92229843139649, 52.46359555952011, 62.86604681322652, 66.7405483799596, 68.74196129460489, 68.04789789261358, 73.03084558056247, 65.87691307067871, 68.17424528060421, 67.0032295103996, 70.3725141094577, 71.26098586666969, 62.78823483374811, 64.76628611164709, 68.99254583543348, 61.2214832921182, 60.25352470336422, 62.258824686850275, 67.21929719371181, 61.525961199114406, 54.88239180657172, 48.07168629861648, 51.01531528657483, 50.76540539341589, 55.21523237228394, 57.27472382207071, 59.76751558242306, 57.48984229180121, 53.90685519864483, 50.01833900328606, 48.056345908872544, 46.74346193190544, 62.18905356622512, 66.88740976395147, 60.35835004621937, 60.366347759000725, 58.94110356607745, 59.796258711045795, 57.14210064180436, 59.030259040094194, 62.007785151081706, 61.144632293332016, 60.398244473241995, 53.84095153500957, 55.55520380696943, 60.92972955396099, 58.481805786009765, 57.71939508376583, 58.01299233590403, 55.56858693399737, 57.5045080338755, 57.05107419721542, 55.56516662720711, 55.34463920900899, 57.138511673096694, 57.83230050917595, 59.05384032957016, 52.46554889986592, 50.73871366439327, 52.58355340650005, 49.05895079335859, 44.83216939433929, 50.15675552429692, 54.59515663885302, 52.95746511028659, 54.571367463757916, 52.94618437367102, 54.85551964852118, 59.39049343908987, 63.62549612599035, 65.74956155592396, 64.55663150356662, 57.201230372152025, 55.202253249383745, 58.013125696489894, 58.39730616538756, 64.62375894669565, 70.59084107798915, 71.1932465337938, 71.9536764391007, 73.44398883081251, 71.89634707666212, 66.8193252625004, 65.44951984959265, 64.0918973184401, 70.7011930404171, 72.3937899066556, 84.43675287308233, 75.98569254721366, 92.10759885849492, 16.457153251094205, 1.5291573395652156, 1.071901275746284, 0.3186844866121969, 2.931327699653564, 67.47301963067824, 75.78754225084859, 64.15270582322152, 48.71627684562437, 30.905317529555294, 24.600784086412002, 45.57923578446912, 57.969928633782175, 56.00762174975488, 1.1949866000683078, 0.10935050931068198, 0.03722171479415509, 0.1724917441606522, 0.09292986664560535, 0.0317326411905308, 0.046470345733987714, 0.1584051185918431, 0.05434748010649797, 0.06047826725989581, 0.3337885229097259, 0.2978422372571884, 0.1902663323187059, 0.30137191075951825, 0.2881948000961735, 0.2616612835516853, 0.2577299041853797, 0.3896443918347359, 0.23034163270025487, 0.8138102990004324, 0.8239491355995979, 16.93228171717736, 81.89581794123497, 73.58344477991905, 60.2844722040238, 76.60519169222924, 57.620727862081225, 91.93632464255057, 60.010055342028224, 0.30870184001903384, 0.7371273492613147, 19.026089983601725, 7.797007060820057, 18.55264421432249, 132.08421522571194, 82.07432500777706, 108.96563991423577, 77.0155579043973, 87.50709795182752, 72.38898892556468, 84.18386982333276, 72.06121213974492, 84.4630955111596, 75.77282551796206, 79.50248179897186, 71.0012622033396, 72.06608372349893, 65.38816613535728, 71.04071340253277, 61.681389039562596, 68.7127867052632, 65.66004522385137, 66.39374025406377, 61.052982191885675, 67.18748677161433, 60.96358745328842, 65.51384672041863, 63.26300244177542, 64.4441379270246, 59.621332768471014, 61.21687450716573, 54.892076138527166, 56.687603842827585, 56.36427502478323, 59.99685656639838, 61.811603884543146, 61.51855968659925, 55.17004666789886, 58.23132714917583, 52.10946829088273, 53.45688089247673, 51.839366036076704, 59.62835773344963, 53.581867218017585, 67.60393265754946, 72.04906063695108, 71.48613775930097, 71.27850317185926, 75.61116110893988, 70.56742452806043, 70.38497940186532, 69.54115990669497, 73.11333302528628, 73.50055725343766, 65.51388986649053, 65.25324836854013, 71.75876602049797, 64.05120272790232, 63.7307176282329, 64.09408207862609, 71.6236089891003, 66.03688301578646, 57.76493380146643, 51.84226859000422, 53.22158575057984, 50.19246085997551, 56.34534566633163, 58.68917365227976, 59.32084391194006, 58.80404810751639, 54.8425954388034, 51.678929328918464, 50.30121249537314, 51.65071964263917, 67.0375031809653, 67.94500627825337, 63.80223028121456, 61.362139486497455, 60.897287630265765, 64.24260262520083, 63.658797048753314, 63.82730207135601, 65.33404527171966, 62.050429159595126, 61.78218218588061, 57.752778376302416, 57.44826516797466, 63.49558722588324, 60.20883321762086, 63.04136107044836, 59.52403445397655, 58.637876895166215, 59.1473025660361, 62.15545062095889, 59.43902492523194, 60.757839525899584, 62.385423106531945, 61.88991792740361, 61.767265412115286, 56.31478648031912, 53.10185932344007, 56.884440145184925, 50.46136286950881, 49.056107074983665, 53.443152596873624, 58.23359427913543, 55.59391367820002, 58.780180485017844, 53.237855742054606, 57.15842946883171, 62.991060595358576, 66.78098801643618, 68.68842878649312, 68.73189649274273, 63.31391872898225, 59.996982082243896, 60.38415531958304, 63.18623773513302, 67.8612244513727, 73.99632915373772, 73.69365553702079, 76.34099652690273, 76.40711199852728, 74.5135642636207, 71.46985992308586, 68.24505190695486, 66.39287733262586, 74.70517989127868, 74.32176820693478, 87.89115290487968, 81.14020470649966, 94.47401185189524, 14.097334742546083, 2.995728114920278, 7.3377323246771295, 0.38509732292544463, 5.297450192513005, 80.14940615623229, 80.48213297320952, 72.75966075158888, 56.53145036389751, 50.51319306896579, 36.659793469213675, 56.26342304291264, 66.55269822766705, 68.91614590921711, 1.9929963662739725, 0.16535563514597956, 0.1752154472013635, 0.27712136687290284, 0.15150258978528364, 0.23174525899512155, 0.16348705476810857, 0.2928071090530965, 0.2061759100686158, 0.15210252856054615], [0.0363174744040495, 0.035085735256753625, 0.04355513220352512, 0.05832025886423165, 0.08931501948785397, 0.1196119812647662, 0.02539257988363745, 0.023727121973229993, 0.0363941827879077, 0.18590796618692337, 0.3475805570281321, 12.356455460671457, 59.54607425197479, 44.53830934339955, 29.075480853357625, 40.03741702725811, 41.50930996864073, 96.00364208221437, 28.101348453952422, 0.10611638486866029, 0.747092682267389, 2.2628729622210226, 10.784552866412747, 42.87110197928644, 109.08369541168214, 80.32272000466624, 96.65117832922168, 68.63285664589175, 76.49058003579417, 64.82280746583017, 71.19105785123764, 66.75280186437791, 74.66435586252521, 71.12501298227619, 74.87950571121709, 69.35818133815643, 66.04428060593145, 57.029920854876124, 62.533892662294456, 57.76298830586096, 61.27398421687465, 56.68121430181689, 59.038115547549346, 55.35817138610348, 59.087608014383626, 57.325294940702385, 59.05353438469672, 53.95544944270965, 56.058628251475675, 55.90878978852303, 55.77090278748543, 50.61892840170091, 51.86349253500662, 49.27331224564583, 52.95770045249693, 57.432905166379875, 57.43892600459438, 51.70609566473192, 55.496580062373994, 51.92516788359612, 51.907383857234834, 49.72406710347822, 54.7627987400178, 51.89776620557232, 54.36153242664953, 63.15263478986679, 63.60733555209253, 65.98306025228193, 68.61672785974318, 65.55482764397898, 61.85927244924731, 61.49755539432649, 67.28243950874575, 69.21976873951574, 62.156901897922644, 67.09024337030226, 66.12578745811217, 60.54360358945785, 58.82129476916406, 59.05905708189934, 62.22000891162504, 59.01153364489156, 52.857421136671505, 42.763699639228086, 54.22147635490664, 57.589850964084754, 65.37410051591935, 62.478128325554636, 68.41452183261995, 61.45581745332288, 58.60339141661122, 55.4000505324333, 48.586226740191066, 40.51722095858666, 54.306599632386245, 62.94387448218561, 62.36053174541843, 57.980107184379335, 60.21108073572959, 52.082662813125125, 53.35690752152474, 57.88793933007025, 59.79438381810343, 61.02629046286307, 61.80322177948491, 57.48362141270792, 52.06025038996051, 53.08918222304314, 54.56393849465155, 54.83860246596798, 51.89366732874225, 54.72865450766779, 54.891632910697695, 55.58291142986667, 53.36992586812666, 50.46924291118499, 55.21735437454716, 54.60508808012932, 52.86916863533759, 51.65394383092081, 48.99216459643457, 49.02808958484281, 47.052423108008604, 41.40667330834174, 46.28801984171714, 51.6633379074835, 52.219298578077755, 50.720796277446134, 50.348112275523526, 52.40832151905183, 51.42592076332339, 52.811694145202644, 55.38226650607202, 52.96109722506616, 50.97003936767579, 52.92907891734954, 53.327089663474794, 55.373064625647764, 61.3712001615955, 65.59141551294636, 67.11925322009672, 70.1914418128229, 69.03122825007286, 65.56943455050069, 63.29110230168989, 58.6753119960908, 60.89909976528537, 68.48778386269846, 74.19552280056861, 80.62515827917284, 69.92382634070613, 87.24583671938989, 47.118114963654556, 0.15092472966399886, 1.3868640459352926, 0.04993980472546913, 0.029534282943894787, 37.02144776621173, 75.34054110127111, 60.082921212719334, 40.49379264154742, 24.077534021869784, 19.48410907099324, 33.54422738475184, 50.73245748396843, 34.811925657333866, 1.1089790732629838, 0.07300182065415768, 0.02760616604298834, 0.029675511252735893, 0.0293715811905361, 0.11103060907654225, 0.04018734074047497, 0.062072986526595014, 0.00683955877320841, 0.08157040683492538, 0.05072283085375544, 0.10606822092086078, 0.07550141999437925, 0.10644276896792074, 0.07308815110234484, 0.044921944143190506, 0.054327282198374315, 0.01837148173381725, 0.08894401842788344, 0.2955170071894123, 0.4546543372975242, 21.6957139584326, 72.02765234055059, 50.95586392187303, 35.57800769805908, 39.17824537523332, 50.161525126426454, 104.8700814093313, 30.1202178770496, 0.10545099154114725, 0.6101210643687557, 1.0210851928399456, 13.296382830988977, 47.27096972926971, 110.78070102199432, 83.37026826796993, 99.17386639502742, 71.16731182221444, 78.82377839857533, 69.83491405364006, 73.80537248426869, 68.71701502030896, 78.7428520571801, 73.01776839840797, 78.82033455756404, 72.90551800881663, 69.66363983769571, 60.493977762037716, 67.04512042383995, 61.828756409306685, 64.75881007409865, 59.84213867495137, 61.65172807631954, 59.00035881227063, 60.75889856584611, 58.60517609503962, 60.89212971348917, 57.5276735521132, 57.288785519138465, 57.654848560210205, 58.075181514986106, 52.681208656680205, 52.99704574769544, 51.83847958041776, 56.28539616061796, 59.84236617242137, 57.26707912260487, 51.40281408063827, 54.43837950306555, 51.184949951787154, 52.8343693671688, 51.231422193588756, 56.18055905065229, 54.97850164290398, 55.38756170580464, 65.94195381287606, 67.25560265202677, 69.05582151105328, 71.68337806578606, 67.41622371058311, 64.00420096612746, 64.27895515195786, 70.50326239678168, 68.57826509783345, 65.22559958119547, 68.43050941344231, 69.11450016883113, 62.009091300349084, 61.508134026681226, 62.014896408204116, 66.82021956289968, 63.22936027280746, 57.31334740115751, 43.80068409827448, 56.56769698665988, 60.970153500956876, 66.03107790793142, 66.03369020646619, 70.13444192947881, 64.246430858489, 59.7071110817694, 56.906425030000754, 49.01010159523257, 45.88718498906782, 55.65795029363325, 62.68163265720491, 66.85996101748559, 60.84218617408507, 61.15603854579311, 56.89522274078862, 59.6246354041561, 59.822683718896684, 61.83838582807972, 60.47569951703472, 65.25036542646347, 60.034154384366936, 54.600334167480476, 56.49449379213395, 57.7342765561996, 56.0993738328257, 55.62168798139019, 56.19184370963804, 57.93500777213805, 58.42394298122775, 57.308005132982814, 55.79587651837257, 58.57631137294155, 56.94793939590455, 55.42084693908692, 55.485860224693056, 54.72238263776226, 51.553511542658654, 50.47198072556527, 46.29841804504395, 48.737806735500214, 54.13763961484356, 53.7692702201105, 53.613760009888686, 54.535375795056744, 53.89128731143091, 52.375977654610914, 56.49051650877922, 58.17450769485966, 55.13743215991605, 52.83719347369287, 54.97069612626107, 56.96047529097527, 58.98271206886538, 64.46387921610187, 68.90238623465262, 69.74691960119432, 72.82201074784803, 69.9529460168654, 67.70044649800947, 66.41287357576432, 62.9099577473056, 63.86111682461154, 74.29315059415757, 78.32046770280408, 83.27466441738991, 74.57411781434091, 88.7558158751457, 54.893982410430915, 0.42155118779309336, 0.8864443821291771, 0.1832919444648489, 0.01959981945072932, 36.73178857372653, 82.72360278714089, 68.02364980020832, 51.642008058486454, 26.791023823522753, 27.926871622762373, 44.526475552589666, 60.02442690633959, 43.333596491044574, 1.8339680351557273, 0.2553644545015789, 0.06434521097089015, 0.0684376833059134, 0.06255588238878597, 0.10999311152244769, 0.10641979399107157, 0.011588416678170043, 0.0356805642255612, 0.12097047732001352, 0.1481168182386506, 0.1835426850424659, 0.15784921455046824, 0.1643499762060181, 0.1641410640290668, 0.24042924866080287, 0.13782251175613175, 0.19591247692944544, 0.19935648648008225, 0.41764113631459976, 0.8920329628932862, 24.88404000959089, 84.57234920993929, 59.7705554193066, 40.534400939941406, 55.50656641683271, 60.621525395301084, 111.66219880503994, 35.60344426862655, 0.15323437750339508, 1.4091487469211703, 5.929263128388313, 18.662649046990182, 47.25297389491912, 119.12843827278384, 85.22885983990085, 104.18486687444873, 73.3136563147268, 83.46438946262484, 72.61030474016744, 79.61764258723106, 74.94060839376142, 82.81423307234242, 76.16004974611344, 80.61678009648477, 76.028744482225, 75.00252692930161, 63.55724296262188, 70.78084068913614, 64.28223817579209, 68.1361198425293, 62.06410646438599, 64.46899398680657, 61.83279645058417, 65.01720013157015, 61.7904152408723, 63.319311987969186, 59.85840866642614, 60.3246255074778, 60.95835108910838, 63.78587007522584, 56.80447086211174, 57.67473889935402, 54.878438057438025, 59.94608932925809, 63.026420762462, 59.00035096753029, 52.043427344291445, 54.32190864316879, 51.79719663435414, 53.861791087735085, 52.55437097241802, 60.472659680151175, 57.707977064194225, 59.631915323195926, 67.81537194405833, 68.17274693519839, 70.57405333365165, 76.07838599912583, 71.40521141790575, 65.53922445543351, 67.86950849717664, 73.82092075963175, 71.86842764577558, 68.59274648850965, 71.70881071398335, 72.43758709199967, 67.06704647310319, 63.44542011137932, 64.36687900174049, 69.99984971938595, 67.07417734207647, 61.09169990785661, 48.671487300626694, 59.51703694558913, 61.01588441479591, 69.94440309463009, 68.22138432533511, 76.4643786030431, 66.2396695536952, 60.87759340963056, 57.29543785895071, 48.95537276421824, 48.6902597642714, 61.1058831983997, 65.8311076318064, 71.38893358169064, 63.40849491857714, 66.4373726998606, 60.04989877823861, 62.146962611906, 61.89294207480646, 66.66131650247883, 66.22557255529588, 68.30693121879332, 61.28046397239932, 59.05522100387081, 58.45514151357836, 61.22227561089301, 59.071671424373505, 58.34859032784739, 59.889928833130874, 59.738831289352916, 60.61372772339852, 62.07862315639373, 58.13087524906282, 61.46112834253619, 58.80904912948609, 58.42041677044284, 58.45269003222066, 56.92326376515051, 54.76501095679499, 53.87654312195317, 47.95002222061158, 54.340849768730905, 56.05873415547033, 57.1797122493867, 56.51879679772162, 55.85614373607021, 56.9322616823258, 56.015235070259344, 60.0952099984692, 61.74120910706059, 59.92068806002217, 56.56375892700688, 58.20050516436177, 60.81480410791213, 62.29069394450035, 67.62178728657385, 72.43467669333182, 73.97627015267649, 77.16323514138499, 76.31255149841309, 71.16444849198865, 71.12300472874796, 65.6701845507468, 67.12151250531598, 77.13623354511877, 79.58544777285668, 88.63215138835292, 76.2035958997665, 94.34989237016248, 55.506221248257546, 0.40135628273410184, 5.2899717034832126, 0.154017579831904, 0.10145264076850108, 48.00084829330445, 90.00033686237951, 73.86324313379103, 58.22011701522335, 39.2086241322179, 31.211733087416622, 50.92640692187894, 71.04500447550129, 55.6651125415679, 2.600914590781735, 0.4598752877885296, 0.1829636911110532, 0.2554024984278987, 0.13597438592583905, 0.22091896573622383, 0.20470785577931713, 0.1495391830441452, 0.10959876010254507, 0.16564512445080667], [0.009643592357244945, 0.02456944522207543, 0.028132162011799314, 0.042129886907435236, 0.05314203692720302, 0.027151883564769264, 0.012320353360396, 0.010104475640541604, 0.03423844201249942, 0.10500104512057959, 0.07364021704321908, 29.897801837613507, 66.8774861674155, 42.22535825544789, 48.58950191928495, 43.98478054231213, 49.89127774392405, 93.42647229471515, 15.080200299139946, 0.585171235424857, 1.3608380166753646, 1.4000874589527808, 2.832700437115085, 62.719220730566214, 83.80993458532518, 92.98700994060886, 86.77279103186824, 75.83745048892114, 67.41489010472452, 66.72368218821865, 65.91692124643635, 68.33579986326157, 71.38596826984038, 72.55694481634325, 74.71532314054429, 73.78394065364715, 70.6251225932952, 59.97025112951956, 60.23969442613664, 58.6822271347046, 60.00898845734135, 57.13307134566769, 56.94893960029849, 56.84521644346176, 56.96296991840486, 55.70712897085375, 57.492419289004424, 55.5779770881899, 55.524401434006236, 55.82589049493113, 51.957158734721524, 50.279031492048695, 50.401597715193226, 49.50974095252253, 52.99968158045123, 61.2717955343185, 55.70896464009439, 52.5542179999813, 53.51942700724448, 53.807576087213334, 52.7187692734503, 47.98794369543753, 50.95946073532105, 53.01351578004899, 53.84093584552888, 60.48740386962891, 63.84730615923482, 65.9652134679979, 66.37408133476012, 66.26278800349083, 63.25302000968688, 59.53116924531999, 65.64643067698326, 64.78291303880754, 66.96777912878221, 66.94784564356651, 64.51951019225582, 62.24486889377717, 61.35000367318431, 64.65844054375926, 61.770870070303644, 58.0438417773093, 50.520225878684755, 44.95209586235785, 59.68093710560953, 63.93959168464907, 65.63482830601355, 63.92689105003112, 64.5021419371328, 62.27476519923057, 64.40098401038878, 60.39552234834241, 54.07728218263196, 44.42597266166441, 44.77490671219365, 57.84084735378143, 57.44373875279581, 58.560641504103145, 56.00831600927538, 57.50204086303712, 63.77766447682535, 61.44512114986297, 56.483522922761985, 54.1120736060604, 61.07405316445136, 62.27827179816462, 56.63970778065344, 53.91624535283735, 54.51082175777805, 54.68426504442769, 54.40199167497697, 56.810115152789706, 57.93125014151297, 59.36590017810945, 53.195890303580995, 56.781929000731445, 56.30432159669938, 57.82156890438449, 52.6614438333819, 53.6720189740581, 53.74809334355017, 45.57525850111439, 48.35230442785448, 45.688462026657604, 43.65603100868964, 47.72539200321321, 52.23895357501123, 49.96363762886294, 50.797525682756984, 49.56861965117916, 52.25926753013365, 50.864660970626346, 51.652437640774636, 51.65181398391724, 51.81623974154073, 52.63538752832721, 54.02032544535976, 59.49509128447502, 62.776856037878225, 65.72011240067022, 67.20353711035945, 66.24984418192219, 64.03282250127485, 60.691590693689164, 57.233982163090865, 58.00670085414764, 66.69329950886389, 72.48945651515838, 78.16747173186272, 83.15180009411228, 74.27781412678381, 80.8016727816674, 75.03169367390295, 5.131944802499587, 0.7947923807847885, 0.9179819543515483, 0.407898765538008, 7.823404121783472, 71.95319006519934, 65.9498534664031, 52.14955099167363, 29.75615916713592, 18.75234776927579, 26.459530591964725, 45.486989482756584, 18.331030299586637, 1.626454796041212, 0.028963545525086024, 0.10230696669990018, 0.03947175333216306, 0.05837174380318292, 0.019767349473230784, 0.06757195798620101, 0.11932666713912642, 0.13984000430472437, 0.1197086998652066, 0.023048180380776044, 0.017841329738017053, 0.04266263977173836, 0.059144171105036815, 0.12470882551203813, 0.06514131422004392, 0.04600623434770011, 0.06829843916479619, 0.048834799503486966, 0.11535566570537707, 0.056249404461273265, 43.41602117784562, 77.94042141206803, 57.85601908160795, 44.76710119555074, 40.83414062376946, 61.78054655751875, 95.97734651257916, 16.0895977481719, 0.5975376718467282, 1.1342111902852212, 1.5160349275796645, 4.4834917014645, 72.93730489669308, 89.59161804568383, 95.90768521831882, 88.85869964476555, 77.57022811520484, 72.15895760443904, 68.74447945625552, 69.97037702991118, 71.70977561704575, 75.49902839045372, 76.54449693618282, 81.23780112112723, 77.65831670453473, 74.43554047615298, 63.063871552867276, 60.588934421539314, 60.13279807183051, 62.28952900055916, 60.789732317770685, 60.75765125213131, 59.11431151051676, 59.241447294912035, 57.41009266145768, 59.10368188734978, 58.36264810254497, 59.490380517898075, 58.846303801382746, 54.341222393897276, 53.02312950934134, 54.045095212997936, 53.22615138946041, 56.03854571619342, 61.795302514107, 55.32549412019792, 53.9602739580216, 55.01630936899493, 55.31990866507254, 53.886423572417236, 49.786311195742705, 52.71338385920371, 54.341489115068995, 57.88821781835249, 61.74991284647296, 68.02411263988864, 67.66808694408786, 70.28092676593413, 68.4591584051809, 64.22532458459177, 63.18602592714372, 68.38700248349097, 66.61644458770752, 69.22138475602674, 69.03989668815368, 67.68094447351271, 65.78686721863286, 63.13231691237419, 66.2661926208004, 65.40235727064072, 62.87829245290449, 52.18577800258514, 47.23164404592207, 61.487294473955714, 67.69956788709088, 69.19606193419426, 68.16398436023344, 65.62780334103492, 63.83701778227284, 65.1233983039856, 62.223884213355284, 55.62195078019173, 46.515525156451815, 47.80784806897564, 57.53549868060697, 59.815603840735655, 59.623505761546475, 60.94430900389149, 60.41110984740719, 66.84387145503875, 63.43074260219451, 59.615323697367025, 57.70046964768441, 63.53318706635506, 64.41836011025214, 58.42599438082788, 55.70188868430353, 57.52144875064973, 56.43651723861695, 58.77760348781463, 59.1716722519167, 62.703295907666615, 61.49644536356772, 57.21599025111045, 62.9410425309212, 58.18904399871827, 59.12168948881088, 55.32336427319435, 55.57225042773832, 57.77566148388771, 48.81772110539098, 51.967207847103, 49.48618711963777, 47.60557928392964, 50.6719353122096, 54.54012186296525, 52.636638764412176, 53.31522841607371, 52.67842377385786, 52.89353439884802, 53.891365758834354, 52.89456598220333, 54.56426012900568, 55.43181780845889, 54.41986591585221, 57.37920007398052, 62.89956346634896, 66.7560338973999, 67.53740141468664, 69.6780506257088, 68.1655611530427, 64.56853981940978, 63.45107224679763, 60.26589585888771, 60.821609420161096, 71.9571908827751, 75.46727288153865, 80.77531445410945, 83.88060785108998, 77.83427423046481, 80.24589646247126, 79.91558582552018, 8.34713222519044, 1.0747415620473124, 1.233783376313025, 0.47236249031078437, 7.007461401724047, 78.57922646307176, 73.73797831996795, 64.05823945999146, 34.751807489702784, 18.005428468027425, 34.509648200004335, 55.22742702114967, 29.217647160253218, 1.7995480111529751, 0.012304631320969954, 0.019141001731998498, 0.02619480034486661, 0.004431434640390498, 0.07382197906413386, 0.10628001358840736, 0.09241684820623168, 0.09667722403161949, 0.05369161691276297, 0.06605214679673796, 0.17596996719798735, 0.11093988128366972, 0.14462491287098778, 0.21209006287878562, 0.23820310440515322, 0.07566873359704211, 0.2403973487596358, 0.1300921023733193, 0.3173380104764816, 0.11376856135264521, 49.850814573226444, 91.82033231181484, 54.34741973876954, 62.7881524639745, 68.2214706174789, 66.1316631686303, 107.3538830972487, 19.458858813008955, 0.7545711100101472, 3.0541785397837242, 3.50935390880031, 6.115947846443423, 75.87833727559736, 94.23191532011955, 97.70013778440415, 93.7889777460406, 81.03309262183406, 75.60504221147107, 72.16116197647588, 74.08133476011216, 74.3527941549978, 77.40713596343994, 80.66134606638263, 83.95994171019524, 81.5958821388983, 77.28471879036196, 65.67123182358281, 65.60801106114542, 64.52491521835327, 66.99717337085356, 63.36261103230139, 64.33017346166795, 62.73911891445037, 62.187472851045676, 61.20717448572959, 64.64763441393453, 60.53575492674305, 61.56704410429924, 61.90093978758782, 57.98054256746846, 57.24151703619189, 57.83105711783133, 58.64166982712285, 59.59890073345554, 65.02130685314056, 58.07371847091183, 52.737831992487756, 55.42101167863416, 55.67711499429519, 53.92327031781597, 51.08733392530873, 53.98670681061284, 57.79217466231316, 60.64606374309909, 63.7218060032014, 72.3823130515314, 70.74832424040764, 71.4808504043087, 70.83884469924435, 68.72536182403564, 65.35736376239409, 71.03166841691541, 70.4210259837489, 71.94136804149997, 73.25016883111769, 69.92200636094617, 69.67727399641468, 67.78976671157345, 69.73374828215569, 69.69758402916693, 66.10321814014067, 55.69791924568915, 49.33428548997449, 63.39735146491759, 68.79826299605831, 73.57110500335693, 69.8841162650816, 69.35110538236557, 67.75074697309925, 68.83685127381356, 62.953103819201075, 56.885279532401796, 48.895442870355424, 51.78699454953594, 61.16103564539264, 63.27653461886991, 62.56670721115605, 65.6884196496779, 63.8852237116906, 72.15485480523878, 68.22921337619906, 62.36594461625623, 59.387332008730986, 66.40354617949455, 67.99016844841742, 61.42212037117251, 60.27825916967085, 62.23889512400474, 61.488577089002064, 62.53882700397123, 62.788619226025006, 63.18288018626552, 64.7172604068633, 60.341766265130815, 65.06127580519646, 61.616301228923184, 63.64830470854237, 60.60141932579779, 59.000927555945616, 60.99458986713041, 52.301970374199655, 55.37792051992109, 51.2321949005127, 50.579394832734145, 52.15843123774375, 57.45700420871858, 56.25627256208851, 56.21452285397438, 55.87986623087237, 57.26645546574747, 56.22796089418473, 56.967115863677, 58.115778046269575, 59.41430222603583, 58.22205858845865, 59.43248241178451, 68.07864927476453, 69.3080299131332, 71.94977760314941, 74.19081595636185, 71.62080057205694, 68.12691796210505, 68.54627424670805, 63.69187831878663, 65.17191802301716, 77.5541542422387, 79.42972183227539, 83.3349669364191, 83.50129112120598, 81.53950199004143, 84.84540893185525, 82.10366433666599, 7.284612155729725, 1.6675973947971099, 2.3558235745276175, 0.5451118849938916, 11.143901790342024, 87.15373946774392, 79.86276718877977, 70.3791742940103, 46.527186362974106, 27.78798637851592, 41.777286298813365, 66.52348441462364, 44.72239794269685, 2.151372971073274, 0.11152040739093097, 0.24814329440555266, 0.10675920924592404, 0.16222680948915022, 0.11936098787813418, 0.15267015374716253, 0.27903839465110536, 0.23631871197252508, 0.2374278847128153], [0.0431395180132841, 0.0197006672650816, 0.14355637343420138, 0.079917058859381, 0.043376216199249036, 0.15037809528650778, 0.12316590911077878, 0.02457723059060593, 0.11988264012841449, 0.06636012946405719, 0.17186745911115603, 45.69855820748114, 54.24200211801837, 25.8053086649987, 40.213888383680775, 46.581546491192235, 61.87540515776604, 85.28434568835844, 4.126923737987395, 0.12216934363447851, 0.258231109548961, 1.4344048884607132, 14.27637525143162, 82.20937221280991, 83.33610442376907, 97.9781553822179, 84.04562196423932, 77.68710690159952, 65.5560435787324, 68.46658737428727, 64.15039554719003, 69.57861854184058, 67.24844824883246, 72.81500539472027, 75.23932041660433, 77.63457852025186, 72.5828795279226, 68.88170749910417, 59.275944540577555, 57.2906368778598, 57.81102949573148, 59.135672738475186, 57.32819357225972, 58.71885814974385, 57.30676174163819, 55.46367922136861, 56.28838892905944, 55.997741299290816, 55.74210866805046, 56.04660618689753, 49.81702335419194, 51.19875277242353, 49.40968521179692, 51.29512148518717, 51.951416384789255, 62.32468520441363, 53.68124831107355, 55.36965216359785, 51.68174166833201, 53.164978104252974, 50.54707842488443, 49.9705998359188, 52.50357627868653, 52.33777376913255, 50.37815763104347, 56.98577457858671, 62.324112538368475, 66.62690162658691, 65.85453987121582, 65.3946380461416, 61.71334458935646, 60.9102039952432, 63.92004259171025, 65.30301932365664, 62.10793895106163, 68.2718260057511, 68.46472032608526, 71.28464560354911, 64.44773866284278, 59.4554792681048, 65.0535212793658, 54.693855239499, 45.23834259279313, 46.02571133644351, 59.18019556230115, 58.943339317075676, 58.17114230125182, 63.10345611264629, 60.11317445385841, 60.65414382565407, 61.137666163905976, 58.20500020057925, 52.649068755488244, 42.425254006539625, 32.78730015600882, 39.63879439138597, 61.29974634416642, 53.44766332257179, 56.04319372484761, 58.32421671959662, 59.86114648080642, 57.219081078806234, 57.54960744611679, 60.67931367504982, 59.71515194062264, 61.800660471762384, 58.48883075098838, 54.099529866249334, 53.33141211540469, 55.92183559171615, 59.03363620081256, 59.72128260520197, 60.53273470171037, 54.60863782513527, 58.59478181408298, 58.29269263052172, 54.238640646780695, 52.51830870105375, 50.973883290444654, 49.953361019011474, 53.761966766849646, 45.926432225012014, 46.852154731750495, 48.31776011374689, 42.50390929560508, 46.07413299622075, 53.24690857241231, 48.95757713625508, 51.293430943642896, 51.49025940125989, 51.10331758376091, 49.47427488142445, 54.71795428183771, 50.318000239710656, 52.62067079544068, 55.34682396919497, 61.07105647363971, 60.603980633520315, 62.54532637134675, 65.79657508480933, 62.369490438892, 64.2886983194659, 62.385670215852805, 57.45845156331217, 57.4854374700977, 64.7029947465466, 73.08366421730288, 75.0653789889428, 74.87345741641137, 80.5626827670682, 89.8704985649355, 66.54088404870802, 90.60972413709088, 25.61309683707453, 0.2786732771463933, 1.2446804560961262, 0.09369892699103202, 0.44180544934445815, 47.67844907699093, 73.10748869372954, 50.8395891804849, 36.83993224174746, 37.64599500163909, 27.740043247899703, 46.39995251932452, 22.727760153432047, 0.5321220981497918, 0.059911274095816966, 0.12097463717744236, 0.040173003404972055, 0.07837008985300219, 0.04932578525415832, 0.0744521476688885, 0.038440790508062615, 0.025012299583684054, 0.040652176079851006, 0.017348534104624586, 0.08229127258903558, 0.08210057032204444, 0.029562220255273487, 0.036874508425112695, 0.10147550849304085, 0.03693836185360148, 0.08470609663955628, 0.03011293788140099, 0.032601660688317595, 0.6063219424216979, 59.668734612003455, 61.284802113809896, 40.8938116412009, 37.170446841947495, 47.58750500217561, 74.5927490726594, 87.85532597572573, 3.9864038459716307, 0.31044159505155783, 0.3975609605831485, 2.0812397666515845, 18.8454609147964, 90.79105531015705, 87.32747693215647, 98.78233540442683, 86.09360125757034, 80.40409349626111, 69.36474738582488, 72.00236874241983, 68.74814294999646, 73.19058802820021, 71.42848676250827, 78.12775381149785, 78.83552197487124, 81.52754660575621, 75.95811828490227, 71.87635867826401, 63.419987463182025, 61.21412100330476, 60.87941338939052, 62.01619079036098, 60.62842876680436, 61.11096266777285, 59.05952384394985, 59.74944914540937, 58.11034556358092, 59.37298790101082, 58.36471911399596, 58.0070891687947, 54.209650408837106, 52.314412132386245, 53.813742053124216, 54.08121239754462, 55.78987136963875, 63.48889958473944, 53.14612327083465, 54.164955000723566, 50.73385777011995, 54.57965150956185, 52.12269844547395, 50.924908576473115, 52.21434854692029, 53.43042450566446, 54.08213807690529, 59.15360189253285, 65.79839506456929, 67.78486374885806, 67.48792463733305, 68.25872528937556, 62.62753532778833, 63.47506538514168, 64.75350310725551, 67.78659743647422, 66.85046103692824, 71.34606207570722, 70.01536661578764, 75.86691533365558, 66.73166813388949, 62.61752936147875, 67.67425290999874, 56.743705503402225, 48.22614139126193, 48.66876909809728, 62.121439749194735, 62.59616028877997, 58.92222912080827, 62.70283699035645, 61.02359187218451, 61.996284761736476, 61.22927311928042, 61.45847682029971, 53.11478353315785, 44.526036247130364, 36.10392301313339, 40.65692401701405, 64.32255621879332, 57.450826475697184, 59.440178102062596, 61.73420375393283, 61.18463654671947, 60.76900651378017, 61.572370682993245, 64.01450111019996, 61.56840908911921, 62.208994896181174, 61.842374878544966, 58.262274649835405, 55.38307843669769, 59.34428791845999, 63.13348577868555, 63.98153358890165, 62.589751135918405, 58.89667487913563, 63.425137535218276, 59.32750017412248, 58.5398058737478, 55.36538462485037, 50.04679579888621, 50.82099714586812, 57.83909013194423, 50.43427105872862, 49.66722803731119, 49.61114598858742, 44.72375508277647, 49.07537375727008, 55.28111250169816, 52.642039868139456, 53.93431178985104, 54.06595045520414, 52.86798407954555, 52.09975650233608, 57.00732015794324, 52.30035828005884, 54.33401699989073, 60.09845772097188, 64.10227590991606, 62.5766033511008, 65.05649835832658, 67.61923774596184, 66.56211976082095, 66.78025845558413, 64.49642704379174, 59.905794820477894, 61.21867095270465, 67.58939635369086, 75.01440386618339, 78.99506830400037, 78.05124405891665, 81.279997979441, 88.95109499654463, 69.97251864402526, 91.27385985466742, 31.77653478037927, 0.259723816547663, 1.0914566199625693, 0.11648739973503737, 0.2699157890052565, 50.555754707705596, 81.37669224892893, 60.41383589467695, 43.01990885888377, 25.283841317699803, 38.98940678565733, 57.41688228422596, 38.68841586574432, 0.7206315150664699, 0.019291624194011092, 0.10216058261932866, 0.034943024567779035, 0.044598080473200935, 0.07216553609337538, 0.04092924326898591, 0.04382078468258824, 0.011963503859606723, 0.04355017944509464, 0.1744660140285569, 0.07875387692042897, 0.24866968874008427, 0.18042907389181276, 0.09667235171242107, 0.31270388333547505, 0.3702965348718628, 0.14511419790646723, 0.24137555110839107, 0.10965623967950383, 0.6820857705127809, 65.76025393701369, 71.21301527946227, 34.07518294549758, 58.021680385835715, 74.14698739205637, 76.28361225128174, 101.79430777026762, 5.081310435648888, 0.3001348319793901, 1.462655269330548, 4.9020718470696485, 18.068864960824293, 91.98884517915788, 91.41553586529147, 102.84252197511735, 90.32386179893248, 85.44526484704788, 73.41792860338765, 75.72934996697211, 72.48779343020531, 78.92317125874182, 74.02984188448998, 80.51228031035393, 79.89834308624268, 84.1487410760695, 79.48569405463435, 75.07033686484061, 65.09725178441694, 64.38444337537213, 65.49948692321777, 66.5272577347294, 64.73900210472846, 65.01866709801459, 62.85754311469294, 62.434095798000214, 62.14637817875032, 62.25826378791564, 60.7485003625193, 61.025243190027055, 56.822254888473026, 55.18528899838848, 57.7312877101283, 57.41970639075003, 57.740230714121175, 66.96933238737046, 53.71744394302369, 55.896159756568174, 51.38585375201318, 55.54297385677215, 50.795976346538914, 52.87198097475114, 56.496823680016306, 55.380564197417236, 57.895780148044715, 60.98769041799731, 70.11723056916269, 71.66830047484368, 71.39023580858785, 70.94558808111375, 66.9396008214643, 65.79895988587411, 69.11884615498205, 70.17290469138854, 67.71762647936421, 73.42207062628962, 74.18829779471122, 77.71281411570888, 68.69971736784905, 67.7663972300868, 69.12009346869685, 62.022584253741854, 52.08759323243172, 49.75429681039626, 63.27162381141417, 66.92986549869661, 59.89531032500729, 64.97455220068655, 62.05630879248343, 64.8162571076424, 63.38578047290925, 62.889404527602665, 55.77892795685799, 48.207843534408084, 42.13015448662543, 46.61722437027962, 63.5976904438388, 60.93814303798061, 62.878261073943115, 65.59869543198617, 64.48013744046612, 62.174105413498424, 64.13565135771229, 66.01629841712214, 65.85280618359967, 66.93250917619275, 64.65121946027203, 60.42562261704476, 58.2553045980392, 62.15385813866893, 64.82808305371192, 64.68075883003974, 67.07466371597783, 63.27352223857757, 63.93209995761995, 63.447353839874275, 61.63413232372653, 58.29328098604756, 53.30171192845991, 51.71140263157507, 59.02555611825759, 54.4190892865581, 51.72158902691257, 51.78929305845692, 47.68383449123752, 53.86211664445939, 58.683109667993364, 54.91812852121169, 56.913289177802305, 56.2572806112228, 56.945076065678755, 55.04906900467412, 59.5787162165488, 55.191109795724195, 58.720776188758116, 63.3764373871588, 68.48981565044772, 66.96044429655998, 68.2346890049596, 71.7982485986525, 69.10542380425238, 70.46594496696227, 68.62483932125953, 63.639628425721206, 65.48877885264736, 70.82634802787535, 81.71898180438627, 80.65940057077717, 82.56707668304443, 87.62720877124418, 86.57214610807358, 75.7909704023792, 94.95474538495465, 30.493319611395563, 0.6562605788630824, 3.9359616752593753, 0.2218058044391294, 0.878830632615474, 61.5467615281382, 86.24355346925798, 66.55694223219349, 54.16782225331953, 57.92429185682728, 46.50356977216659, 66.3061458833756, 53.65367404876217, 1.4319842957681226, 0.19770999499146016, 0.33950071962129685, 0.2217195429388554, 0.17234804138781565, 0.16356467479659667, 0.11592903655142554, 0.11132916886239283, 0.1813290433417405, 0.14581766580381703], [0.08735414849774492, 0.07668801358029728, 0.10472668605225702, 0.04827322641147241, 0.023711782977766088, 0.021316390747444767, 0.021949476231971098, 0.06776046924172871, 0.0664756402012802, 0.10451051136178356, 2.626992714020514, 58.37647445740239, 54.7178719120641, 36.699852635783536, 48.01910692645658, 44.9352139811362, 71.86295201701503, 64.85168787740892, 0.26877860809045456, 0.0320362686480005, 0.834268217365588, 0.340767614543438, 55.312212974794456, 99.91200154827487, 87.17938392393052, 91.47707785329511, 82.13999332920199, 76.52739540223153, 65.09562007842526, 64.03874528023505, 64.59786345881801, 68.19267257567375, 69.3362945125949, 73.06868076324463, 76.01559669740739, 79.60426730494346, 76.16555675383538, 70.64722122684603, 65.67707223276939, 63.231580334324995, 60.010910418725786, 58.585403427000976, 56.956968692041215, 54.89055818127048, 53.71596128709855, 57.36461277930968, 54.98920186873406, 53.661048104686124, 56.17366352388936, 53.8454818725586, 48.27347263213127, 49.167157219302275, 49.4713919393478, 49.550517912833925, 53.15757266936764, 57.293688481853856, 51.821891876959036, 53.61956511774371, 52.2443272221473, 51.9624186331226, 53.91101683339765, 49.75892128482942, 47.60014680124099, 51.64055285915252, 50.899770106038744, 55.875214299848004, 60.08846744414299, 63.49482236369964, 63.54112594358383, 62.29252176900064, 61.55091139578051, 61.091131164181625, 61.737278892147934, 62.09617184054468, 62.7220566042008, 66.02993257584112, 67.6227286554152, 62.330137298953154, 66.1967666687504, 59.85532960584087, 56.79729292469641, 51.67216716274139, 43.59420268766342, 47.56231161855882, 57.01926377511794, 56.88719757141606, 58.918636229730424, 58.710899660664225, 62.24095044597503, 62.50563982994326, 60.27386611507785, 57.38062389435307, 53.569068524145315, 38.325243611489576, 36.43563001386581, 33.170347059926684, 48.09167077464443, 61.02641205633841, 57.386927143219985, 63.86268577268047, 59.016703328778675, 61.95204434856292, 59.22032533153411, 59.9272305734696, 60.95669192652549, 60.11100146078295, 57.18205782674975, 58.07771928848759, 55.235087410096206, 59.23430465882825, 60.60309417786137, 61.46059882256293, 52.036975045357984, 60.45459716550766, 61.771882041808105, 56.754546934558505, 48.08435555427305, 48.280795697242986, 49.72258052518291, 49.16962831251083, 55.0996244338251, 51.675132474591656, 46.78342696159117, 48.71767320940572, 44.597411617156, 45.190544589873284, 49.65373116154825, 50.795333077830655, 52.76916780779439, 51.461979112317486, 51.764025149806855, 50.883241238132605, 50.25288889485021, 53.9768930404417, 52.431741991350734, 55.04409543929562, 58.53376150131226, 62.063977026170306, 61.03595126059748, 60.55570017906928, 59.674865276582786, 56.59081935882569, 55.431613845209924, 55.525903701782234, 62.45147582023375, 70.16673872547766, 74.93568974156534, 74.64972542178246, 73.18810909025132, 66.19289921176049, 85.87124209250175, 82.35810064500379, 76.24797359589608, 54.259680240385, 0.41116389355832533, 0.68247641406713, 0.08754367098933266, 0.4809709590288901, 20.964093862041352, 78.27173617578323, 59.028670480174405, 44.845332868637584, 23.630983944862123, 20.997031965563377, 41.07280508164437, 32.49931385440211, 0.9322278802433323, 0.038534705226700154, 0.12938147921475673, 0.05427311212124844, 0.11588179190913517, 0.04945213996594952, 0.06624454211804175, 0.03316320313681518, 0.04017904783869463, 0.03202941982195743, 0.06152429903346685, 0.011008697836058996, 0.12086970611445366, 0.08319285848448355, 0.05769683949408993, 0.026033157708063245, 0.07238171844472809, 0.08977373761515464, 0.17791042194491435, 0.23448028481535374, 5.656878054141999, 75.307373539094, 62.42547050599129, 41.71320653730824, 42.510522411715606, 53.98784822033298, 79.06442365338727, 68.28661334130072, 0.17232162667618645, 0.10735216896019636, 0.3310161426423058, 0.3410986258137611, 64.8533078162901, 104.21495929841073, 89.33743276903706, 93.37114334106447, 83.73645290251702, 78.89595785448628, 65.2047247271384, 68.0405395261703, 66.80955856077134, 71.4783557768791, 73.71700148428641, 78.33445487483856, 78.2742464926935, 83.45650549857848, 79.04908718601351, 74.60470445694463, 69.58247815409015, 66.30998980614447, 63.18873628493279, 62.67119915254655, 60.797753564773075, 57.656295914803785, 56.91349706342144, 60.79826347289547, 58.782051455590036, 56.529842192126864, 57.215170475744436, 57.07685593635806, 51.43792321605068, 51.69811756380143, 51.61180973052979, 50.975875854492195, 56.457800019171934, 60.93987672559677, 52.747457488890625, 53.63090468991188, 50.97202408698298, 52.66062798038606, 54.0710416916878, 50.93284745370188, 49.3245933132787, 52.68984571579964, 52.70853188730056, 56.473128641805346, 64.0079782086034, 66.92602157592773, 66.3941168016003, 65.59979761800459, 62.77218057263283, 62.21863215969455, 63.11825913767662, 65.45521905345302, 63.67444338337068, 65.29749662645402, 69.85743630316951, 62.702354538825254, 66.9515875847109, 63.05554043862128, 58.35593300480997, 53.484882693136896, 47.46038098489085, 48.19606857915079, 60.23539158605761, 60.845210321487926, 60.40248847776844, 59.19999176456083, 64.12361360365345, 64.80755336823003, 63.11497611384239, 60.091726933756185, 55.09952637457079, 41.52848251404301, 40.66496095349712, 37.14683809588033, 48.982084105091715, 63.90610248811784, 58.597551007424634, 64.17704020777057, 62.210457940255445, 63.70946230426912, 62.492390063501176, 62.05976047823506, 64.00417350953626, 61.47749639326527, 60.20777417767433, 61.37529119368523, 59.439377938547445, 62.36147311425979, 63.15525101077173, 62.41180104594078, 57.68822008563627, 64.13887162362376, 63.85928507774108, 58.43628275778986, 51.43185138702393, 50.17122122549242, 51.244369937527566, 49.21677912435224, 55.94372241727768, 55.2930090504308, 49.24990354045745, 51.92362639211839, 47.73685709122689, 47.67270672705866, 50.820738269436745, 53.040160440629535, 54.100271194211906, 54.01330440275131, 53.94830288425569, 53.77386331558228, 52.37482447778025, 54.855856972356, 54.90164279937745, 56.716911792755134, 60.95743717685823, 65.74581177003923, 64.41045261198475, 63.0164187185226, 61.9290239580216, 58.177731883141306, 59.34751602911181, 57.832865330480764, 65.93705085016066, 73.76789031490203, 77.28256933150753, 76.96311581519343, 72.19774984544324, 72.18283699404809, 85.57863327764696, 81.1472257491081, 75.94699444309359, 59.1404462629749, 1.3531652477479752, 0.5842307246019763, 0.2513811343740071, 0.5629555436391984, 21.00534935151377, 85.13720189371418, 67.3438952046056, 54.251764897377264, 26.445584604817054, 33.01148714557771, 54.24477915610037, 51.534613563168435, 1.3246933755374726, 0.02420647659399096, 0.0516674593992291, 0.0671431019661888, 0.038567669990081946, 0.021200200107188958, 0.046862827899355086, 0.012769641902958675, 0.08223540945759705, 0.058448547948031664, 0.2295966121938921, 0.3056930143746638, 0.1960479672397337, 0.16301136013240586, 0.17074042120047156, 0.1410368175035523, 0.17452572292137533, 0.1929081099167947, 0.284828671043919, 0.3234307077382842, 6.131341678480949, 85.60715675354005, 67.6167509632726, 48.48329982449932, 63.454806343201675, 66.75398642016997, 83.7410028519169, 80.65686671964585, 0.4401411692942343, 0.19824149147156747, 2.450715760069509, 1.1850974468454238, 67.03667163848877, 106.102490117473, 94.2764969794981, 97.74029501022832, 86.10293649858045, 82.34969892809468, 71.60857062185966, 70.48304650091356, 70.80254708566974, 74.2723306532829, 75.65691163462978, 80.3136436400875, 84.50217800755655, 86.08613306476225, 81.65345468828755, 79.03021274074432, 72.22435920469223, 68.4545692320793, 66.82284755091514, 67.34135350873395, 62.49790491596345, 62.11029237316501, 60.172912151582786, 66.00584137824275, 61.58725215542702, 59.651174160741995, 61.102270695471, 59.91327870276667, 55.847949904780236, 56.398250595215835, 56.009210309674664, 53.01741461600027, 58.39402314155333, 62.11513650032782, 52.4597712486021, 54.30240661867204, 51.73782371705579, 52.798895451330374, 55.99874542605493, 51.74537035726732, 51.3185223456352, 58.02760708716608, 55.798763382819395, 60.0769199863557, 67.42861840032762, 68.64195654469152, 69.44954902895036, 69.59269200601886, 66.58759947746032, 65.29635521673387, 67.1096355684342, 69.08791434380316, 66.05212534627607, 73.00199262557491, 72.0960270973944, 69.99844551086426, 68.8903445582236, 66.56505369370984, 63.34531337984147, 56.27544118512062, 48.22534122774678, 48.62523471155475, 60.41522441371795, 61.63204562279486, 63.53324590190765, 62.59426578398674, 65.60143716873662, 67.37137533003285, 65.78324687096381, 61.877174146713756, 56.61237278292256, 44.18748471044725, 43.72507256846274, 40.18552964733493, 54.36885156939107, 66.50877552647745, 61.70475459867909, 68.56743151141752, 63.85419776362758, 68.40334307762885, 65.17227495870283, 65.59256868977701, 66.41445821331394, 66.30422392199117, 64.97849810507991, 62.97446896952968, 62.368698120117195, 66.52585352620771, 67.84931613552955, 68.69294735693163, 61.925278094507036, 65.49426624851843, 68.90918762453141, 61.40597589554326, 55.4446518036627, 52.344704597227036, 52.08875033163255, 49.49756591550766, 57.537628527610536, 58.83293636383549, 53.257718624607215, 54.750898268914995, 51.703000914665964, 51.942218426735174, 55.05430536885416, 55.30120680409094, 57.457317998332364, 57.80067443847657, 57.21465272288169, 57.030599424915934, 55.050351619720466, 58.74658538449196, 58.32330672971664, 61.21084582421088, 62.585220798369384, 68.84376249005719, 66.84820959644934, 65.50713162268362, 66.6760959932881, 63.2084854187504, 61.42584662283621, 61.96703956973169, 68.17100540284189, 78.47747233606155, 80.11903916635822, 80.76753247168757, 74.48595077760758, 80.3565465250323, 89.9591519755702, 79.77681236882364, 79.52272907380136, 60.86523009884743, 1.105405794036004, 2.2854121269718295, 1.014124763108069, 0.7082088171474396, 28.984617187130837, 91.65075255978493, 72.46799330557548, 61.904850390649614, 42.2062994587806, 34.02004226561516, 57.60808998538602, 70.48170505031463, 2.644209222447488, 0.170862918659564, 0.20840496545837772, 0.12327620278923743, 0.2608797819383683, 0.13063355799644225, 0.1323527052638031, 0.15121444879520327, 0.13822741986763093, 0.11379165124268302], [0.08954681471110353, 0.09745352390793063, 0.05711455904548207, 0.08912421762943269, 0.01642558010174863, 0.07162630978611208, 0.03980336598150673, 0.08068443381137426, 0.16724082431004894, 0.41416444545311315, 8.545514921988211, 70.54025819224697, 46.4557796139871, 54.02480479209654, 51.49557421284338, 43.75873042691139, 84.07118012828212, 43.41176932857883, 0.27517571804984925, 0.6155414122246927, 1.1827312770389742, 6.166273816939324, 91.2986021657144, 82.71038439966019, 88.68774706317534, 85.78860559771138, 79.41292624319755, 69.4084269000638, 65.02833966285952, 65.525213749178, 66.59396940662016, 70.56458473205566, 73.14656334538614, 72.68846973296135, 76.6393869153915, 77.407410529352, 80.08975475065171, 77.73642678414622, 71.86118695043749, 67.37584683202928, 62.7684856999305, 61.009534097486934, 57.77694409893405, 56.744113429900146, 56.09099565013763, 56.55944039744716, 55.456944511782744, 55.87359828333701, 54.54254588773174, 52.4497260585908, 50.53147131396879, 47.02688455581666, 47.66900008724582, 47.993960611281864, 52.87661721629482, 56.27041662892988, 52.332760980052335, 51.88854863566738, 52.183569708178126, 51.22571514498804, 52.5034664523217, 48.46160127270607, 47.498694696734034, 50.637959741776996, 48.90543314718431, 50.08728250380486, 58.422476014783314, 63.098313885350386, 64.2054146335971, 62.388815956731, 64.27629578498103, 58.373697419320386, 57.01702802411972, 59.59761419603902, 64.49128873886602, 63.32484645228233, 65.73766500719132, 63.28366548784318, 54.88542379871492, 66.21633929591026, 49.60956919577814, 53.11153188828499, 45.20319031130883, 51.72406012012113, 64.11661609526604, 64.43500272689327, 64.94471080841558, 63.294153905683956, 60.11020521963797, 63.845631307171246, 63.028931079372285, 62.21064229165355, 62.0095855189908, 45.632427046375895, 43.717023864869155, 47.80117219494235, 38.1090739465529, 50.39799305700487, 60.70613091991794, 57.79115876843853, 63.171673974683216, 58.146584341602946, 60.98343856873051, 61.85574231609222, 59.23881930689658, 57.327063929650095, 58.335689652350645, 55.58683380003899, 60.51080473007695, 58.12212051883821, 60.6136884996968, 52.487827962444676, 57.71451565527148, 61.9057446910489, 56.3089382263922, 50.566329417690156, 44.88087346476894, 47.29793994657455, 48.712291717529304, 50.20764043254238, 47.91861188027167, 56.40250244448262, 47.83288063541536, 47.261473671082534, 47.98646888425274, 42.218980481547696, 47.087045869519635, 53.895146923680464, 51.48162234214045, 50.711504182507916, 48.94980299857355, 50.632170323402654, 50.31605082173502, 53.339625558545514, 51.99695510248984, 52.74875579341766, 54.92525939018496, 57.34876640381352, 57.25753991834579, 56.83649309219853, 53.96769900475779, 55.66904275648056, 54.55988668626355, 57.833469375487304, 67.22798916601366, 73.18913675123646, 76.93762040907338, 72.06198876903903, 70.7779852036507, 76.21048358178909, 64.42958201131513, 80.53114691088277, 79.10635379052933, 73.36154845453078, 7.316527991525589, 0.5281868577003479, 1.3277681460303645, 0.3660948490423541, 3.474248940906217, 62.04804828090053, 67.49739323892902, 49.2499819878609, 29.553151015312444, 21.88341506065861, 43.08406314542217, 42.58843637281849, 0.34610825861173294, 0.07747070262989691, 0.06542491230873332, 0.04052137422765936, 0.09317919762144167, 0.02701339402025746, 0.047666645653906374, 0.08995630402838992, 0.08545098691097192, 0.08730946258912164, 0.11805272420808194, 0.008130871311521098, 0.060125070083285534, 0.18687415627702592, 0.04188077043621771, 0.027554912845634168, 0.0971043793364398, 0.13244077473157836, 0.2553012982131012, 0.36231680983497255, 13.885585588793601, 83.21582886480516, 54.37788086552774, 48.76692248928932, 46.89357496077015, 55.598765650103175, 91.37285263307633, 46.15068197250367, 0.5182404011007279, 1.1875996738672256, 2.513914949470951, 10.041258815796146, 103.51095661040276, 86.41307046336513, 90.71045060311594, 87.74743726176601, 81.79030618359967, 72.05692891151675, 68.29940026806247, 67.66063444076046, 69.6050396273213, 71.20569613672072, 76.63594307438021, 77.75774878840294, 80.08792692615141, 81.29698968702748, 81.63240724994291, 79.74250731929656, 75.42917882242511, 71.54173343412339, 66.17979849538496, 64.02398540127662, 59.24486367933212, 60.06661591991302, 57.517518535737075, 58.959189614942005, 55.972351797165416, 58.30962942492578, 56.93167332679995, 56.74903992683657, 54.01388883590699, 51.94209291088966, 51.3035898823892, 53.18072642049482, 56.22473670590309, 56.719104397681456, 52.171645702854285, 51.93671141901324, 51.551122819223714, 51.89227488733108, 52.90634878220097, 48.9853867407768, 49.09127896831882, 52.670994804751494, 52.621325831259455, 53.03593997032412, 58.26714231121925, 64.11018733055361, 65.24786295429354, 65.62690904063564, 64.99137916872579, 62.14156935291906, 58.76765243468746, 63.110441853923184, 65.13488300385015, 67.23195860462805, 68.18420025610155, 67.57518952892673, 57.82315746430428, 68.68852292337726, 53.18590002675211, 56.27150312546761, 48.34747991254253, 54.42386673342798, 67.76927624979328, 67.68978549588111, 66.11337707888696, 65.3923003135189, 62.87418965370425, 64.65033692698326, 67.9876502867668, 65.73303268801781, 66.14854504985195, 48.50201737496161, 46.11107387850362, 50.42332372357769, 42.89636596556633, 53.48464342855639, 64.02481302138298, 60.73167339448006, 65.32753805960378, 60.98241090774537, 65.23425625216576, 63.53794882374426, 62.373299060329316, 60.56706328545848, 61.035335448480424, 60.22085135982883, 62.15982798607119, 60.712536150409335, 64.43860346271147, 56.73011056838497, 62.458818497196326, 64.04414246159216, 59.50075518700385, 52.12176884374311, 48.06534382604784, 48.564512498917125, 48.885315310570505, 48.46545304021528, 48.37227713677191, 57.95750256507628, 50.52186150704661, 49.83477600159184, 49.27845447294174, 45.85664149253599, 47.916105485731556, 56.08397068515901, 53.565950239858324, 54.786372184753425, 52.79687150832146, 52.804669180224025, 52.031264074387096, 56.08081709954047, 54.40156021425801, 55.308149399295935, 56.751318823906686, 59.25443818492275, 58.668953834041474, 61.36275137624433, 57.12779183541575, 59.96865080248926, 57.07791105393441, 64.3828744273032, 70.12750717901415, 76.06727000205748, 79.14630705310454, 70.6600473773095, 72.49209234791418, 77.65394718416276, 68.84774761815225, 82.00603654307704, 79.24816316173923, 79.28478240966797, 9.825486290839411, 0.47328921155102793, 0.6446933866508546, 0.24358116420767, 2.692904712692384, 67.73840719653715, 74.3850831062563, 59.46963510205669, 32.961347487664995, 26.087495742305634, 55.24213983166603, 59.19175478719897, 3.1672102164837623, 0.193406633972641, 0.061168209874942425, 0.08448749345036284, 0.12372817168192518, 0.0895729766137177, 0.08556369376639206, 0.08466718703388207, 0.06658276227573234, 0.07463998476704282, 0.2035621559667972, 0.226313664968456, 0.13522665346822432, 0.2763191808856303, 0.2539065432163977, 0.14472056660921345, 0.2776593138133326, 0.3379241719601616, 0.4592023561558416, 0.4409005156447811, 15.23564971262409, 95.67224102635538, 59.27374409091089, 68.9691214407644, 68.6655221446868, 60.19024902774442, 96.52483094123103, 54.76936478768626, 0.5926418184272705, 1.865985239705732, 4.579480434617689, 11.174245245995062, 106.22991223489086, 88.3280029604512, 96.3870773007793, 91.3291338951357, 85.20392925508561, 77.72624431117889, 71.12520125604445, 73.26971792405652, 69.83001109092467, 75.74807536217475, 80.4120009945285, 79.19526607759538, 83.38793462322604, 83.61840524981099, 86.95537736338954, 83.85806991207986, 78.29003795500725, 76.76245520191809, 69.72279702463459, 67.59681747805688, 63.19766752181515, 62.93527272439773, 62.35036103956161, 61.8722084260756, 59.05744891012869, 62.09723872523155, 60.60502006161598, 59.92614015456169, 57.59040794064922, 55.179950652583955, 53.324359693834865, 56.30095620309153, 59.38901862790508, 58.52322601502942, 52.3590487049472, 52.475884345269975, 51.65920372932188, 51.228660844987445, 53.598556903100786, 48.227118061434844, 50.07479759954637, 54.87954024345645, 54.28589344024659, 56.8525787322752, 62.6873867742477, 67.5599079747354, 67.09941387176514, 67.82324806336435, 69.77981259745937, 64.11448624826247, 63.046824932098396, 65.75209148468511, 69.00827453982446, 70.17892160723287, 72.39834770079582, 67.79987858187768, 64.20072740124118, 69.96014748850178, 57.77014270905526, 58.713413899944676, 52.323578711478945, 55.863172623419, 70.17990219977595, 68.9547420317127, 68.50062570264264, 70.32895226632395, 67.5778724301246, 67.80638971636373, 70.489134019421, 67.46523764825636, 68.84017744371968, 48.75826189594884, 48.676527546298125, 52.384889279642415, 45.02595409270256, 56.42274187457178, 67.43774967808878, 64.85168787740892, 67.97979770168182, 64.28220287446054, 65.39917622843097, 65.71780604700889, 64.52893957015007, 64.68735625666957, 66.0281753540039, 62.243256799636356, 65.45172422162949, 63.98773485614408, 66.83574430404171, 62.03521820806689, 64.73911193109328, 69.94048856919812, 62.07028027503722, 56.212165509500814, 51.27217561967912, 50.16964835505332, 48.64236370209725, 50.7004980118044, 48.27273522653888, 61.557822612024125, 55.233345877739694, 52.56256872607816, 53.15421904287031, 49.56059840417678, 51.66774272918702, 59.783813030489036, 58.24536138965238, 56.67119264602662, 56.19869216795891, 56.60202164803782, 57.67463299535937, 60.53808481462541, 58.65107174842589, 58.86839459019323, 61.23640398825369, 63.9743281948951, 63.43288813867877, 64.82896166463053, 61.26056578851516, 64.46333400664791, 60.030894894753736, 66.23370755103328, 74.37410046977382, 79.51839877713113, 82.12744174465057, 74.2977789909609, 74.17973918299522, 79.26043233563824, 72.54442461075323, 89.17637240502143, 76.17240521215624, 82.35271130838703, 9.980353232352964, 1.9034710862944204, 2.4713653229898025, 0.37754899732047514, 5.029875905283037, 80.92821628816667, 78.87898968112084, 66.47715337814824, 44.23823625810685, 34.80976050899875, 59.04046112491239, 75.06018577083465, 4.067987674666989, 0.28962873282932466, 0.3719510089966559, 0.11099444206563697, 0.197359356548517, 0.2584568909820049, 0.1767313973076882, 0.23821398285367798, 0.26479292841207597, 0.21719272939428208], [0.0648039290981908, 0.044636438495569655, 0.029524092059282046, 0.03335677057264313, 0.1758635575853048, 0.051275413903978564, 0.04726086037173387, 0.041808620275508974, 0.08989398277574971, 0.39743464800619316, 16.119738221168518, 69.42385750432169, 42.14097238356068, 46.614972929800714, 52.90909051895142, 50.22933506196546, 90.6501010156447, 20.79100751107739, 0.503038274905374, 1.0128277456087451, 1.9219546428611203, 29.606622726686542, 98.77414549550703, 82.00220046504852, 87.2379998237856, 78.45685635843586, 72.3096158427577, 67.17679439052459, 66.33471642771076, 66.12195138008364, 69.44754862016248, 69.42164528754451, 75.13207497135286, 78.17147254943848, 76.59796668637183, 76.62794143922868, 77.00990969134916, 77.4046491807507, 74.56931683324999, 71.05465350612518, 66.54092327240976, 63.30771353936965, 58.39575290679932, 56.87400271815639, 56.71650778862738, 55.694094934771144, 55.63957398937595, 54.966389363811864, 52.21039479778659, 52.48687874886298, 48.36393817778557, 47.94049086109285, 49.583285393253455, 47.02819854982438, 52.72650418743011, 55.676942410007605, 52.17014343507829, 51.32250355136011, 50.51593480571624, 50.88385705024966, 50.27909424997146, 49.894513699316214, 46.398481630509906, 49.0921458121269, 50.62114846321845, 48.116832779299834, 53.74473971705283, 58.78477358048963, 61.62858609230288, 62.451620947930124, 61.91177729637393, 59.707440560863866, 52.76557491671655, 57.87765487547844, 58.36716667298348, 61.94167360182732, 65.39659530885758, 66.71452737623646, 59.96166113884219, 57.440930335752434, 54.880167822684015, 49.09719782490885, 47.556651638400176, 53.84489743940292, 62.74318641231906, 60.67827424695415, 58.04726208409956, 58.081249421642674, 54.87227601389731, 58.94382176860687, 55.02640554981848, 62.70658285387101, 58.2265850036375, 48.560076298252234, 39.524990743206395, 44.47503759014992, 53.55793291522611, 43.853769456186605, 59.17971703314013, 58.212903776476466, 57.553678866355654, 62.78868590631793, 59.21927021395776, 58.999570415865996, 59.08706672729985, 59.29328533910937, 56.71546443816155, 58.619178956554784, 58.015616401549316, 61.05546897457492, 56.38711498629663, 56.43090824927054, 61.98617289143225, 61.61275932865759, 49.657771202825735, 43.93150691063174, 47.739732188563195, 47.147230717443655, 45.84644333008797, 47.921471288127286, 44.68164059423631, 56.52621399971747, 48.7871579970083, 43.97299381994432, 46.814982429627456, 45.646084739315896, 43.214772209044426, 50.183510011242284, 47.93905527360978, 50.85604352335776, 47.79080144820675, 49.33449729796379, 47.78237227470645, 49.50311999167166, 48.99059957073581, 52.81312581031553, 50.693869206213186, 53.91148359544816, 52.69859652365408, 53.85711954485986, 52.934546701369754, 58.63770823324881, 58.203705818422385, 69.0411832255702, 69.03544872037827, 76.54498331008419, 70.68236566358998, 68.12023424333142, 74.3703349944084, 76.69149952550089, 73.74077104753064, 71.67004985194053, 65.06495891078826, 91.08411127521147, 25.314237725350168, 0.2200266418437804, 0.2530139282105431, 0.028847538745932044, 0.12151825316851178, 36.82131275053948, 77.78857077321699, 52.87599355943742, 39.38637025894658, 32.93682482934768, 36.775338649749756, 52.56685195430633, 5.228415006591428, 0.19092244066057668, 0.03269403173978771, 0.1088455041509963, 0.11337375794086726, 0.1446833500578519, 0.05793407394160187, 0.024841425587393107, 0.053904217803069664, 0.07567528364879471, 0.048487792317304886, 0.017909314295637514, 0.05788822357933368, 0.05127433372000533, 0.07623631281838303, 0.04163320146260723, 0.10992842305812145, 0.011665526300578589, 0.17523731135072249, 0.43809258889767433, 24.385779365416496, 76.13462494265649, 54.91186057367633, 43.40707425148257, 51.60743628778766, 62.736867473971465, 94.25681452597343, 22.315483746990083, 0.6996077948039578, 0.2067648018560102, 3.102974540764286, 42.941998820151056, 103.76890736241495, 86.7650168941867, 90.59541533070227, 81.58237349602484, 75.6400768218502, 71.35701333322834, 69.47469926649525, 69.0229206700479, 73.18078210276943, 73.78710208400604, 78.96915712664205, 79.83538120023667, 79.81550262820336, 77.12267783380325, 80.93910478776502, 76.95040733583512, 76.06439882709135, 73.93947832046017, 69.12689485857564, 65.48305611456594, 61.93463294736801, 59.06670962610553, 58.52514405404368, 57.67170298484064, 58.91669465649513, 57.43562729127946, 57.151204462974306, 55.75471516578428, 53.25700083086568, 50.57234241116432, 52.599713571609996, 49.88661796815934, 55.58919506688272, 57.72007757617582, 51.55940686502765, 51.431098291950846, 50.53496222342215, 52.41915510546777, 51.29509795096613, 49.727605081373646, 46.718872593295195, 52.154034260780584, 52.6336459959707, 50.18090947981804, 53.53120588487195, 61.334310270124874, 62.84580738313737, 65.61677755848055, 63.113058074828125, 60.40724239041729, 57.52592809738652, 58.434384330626465, 60.87060766835367, 65.77087179307016, 65.75907330359182, 69.26055354456749, 62.82546989379391, 59.943073026595584, 58.28737781893823, 51.952698999835604, 50.47161594513924, 57.07034872424219, 63.034936228106105, 60.362013539960316, 59.05678995193974, 61.83748760531026, 57.48001675451956, 60.22262819351689, 56.81679494919316, 64.96385981959682, 59.20265113153766, 47.61328674131825, 44.8869845174974, 48.21793187049128, 56.73069107917048, 48.07893876106509, 62.69742804188883, 60.987996362870746, 60.71898060460245, 64.82953825304585, 62.381285006000155, 61.88023359544816, 62.55241409424813, 63.19698502940517, 59.20505554445329, 60.74389942230717, 62.98714999229678, 63.89817930036976, 59.25184549823884, 58.25589687593522, 65.76506668521513, 63.949570194367446, 52.23748268619661, 47.48253453162409, 49.480079989279474, 47.16150422250071, 45.869969706381525, 47.7951866580594, 45.89142114885392, 56.88893910377257, 51.5930921800675, 49.092494903072236, 49.966379365613385, 48.640943804094874, 45.74026084715321, 52.16282821470692, 51.201580801317775, 52.29599268205705, 49.318737214611424, 54.207563707905436, 51.239110039126494, 53.697659507874526, 53.55012347621303, 56.12812480618877, 53.25036418053412, 55.18696777282223, 56.17025890657979, 58.81880406410464, 54.638541975329005, 61.04759285526892, 61.199992625944084, 69.96083782565209, 72.50864475004136, 79.37203945652132, 72.9840438596664, 73.09226989746094, 75.6695181323636, 80.71726337555917, 75.46971259578582, 77.42307647582024, 68.09326402602657, 95.37003024931877, 29.87885090612596, 0.15596731956447327, 0.11852755316443021, 0.12598451512354997, 0.10047936436509895, 40.28817415237427, 85.50415531281503, 63.778350891605506, 43.17792154127552, 26.280754843065818, 47.04957154489333, 65.68702720826673, 10.868040515530495, 0.5865231661065933, 0.17952262333804564, 0.0672133828723623, 0.11635055344912315, 0.04437259398400784, 0.09759122821232004, 0.055907641146932884, 0.13544134194812468, 0.005473163872656803, 0.19224195050135737, 0.1582896384981371, 0.1868459642414124, 0.3452325894707634, 0.21950536497658302, 0.13697805303719737, 0.1933933040427585, 0.12890800623403442, 0.2921615114375469, 0.5325609745998536, 26.451607404216645, 93.72365459319084, 55.615094477130526, 59.51734289046257, 71.33791139048915, 66.75711647156747, 102.61496174720027, 26.396278450565955, 0.6745948402150985, 1.3696271902130497, 4.308927107241846, 49.69582603823755, 104.54666629914315, 89.62105935619724, 93.34794644386538, 87.03392674846035, 77.034102870572, 74.10017782641997, 71.27635371300482, 72.39870855885168, 74.86388683319092, 75.53139578911566, 81.20528467239873, 84.95930671691895, 82.92717379908409, 81.3584767618487, 82.56835537572061, 81.71800121184319, 79.65181427617227, 77.42678703800325, 72.85912421441847, 69.30067939143028, 64.50385993526828, 63.254898824999415, 62.07323774214714, 61.919147429927705, 62.01447671459567, 60.972703041568884, 58.11259308168965, 59.50179069272934, 56.45692925299368, 54.64986193564631, 57.50585732921478, 51.72345215274442, 57.62663102919056, 59.57500173199562, 52.84588152362455, 53.04246679429085, 51.00701162892004, 52.943101390715576, 52.439978968712595, 51.548090827080514, 46.038231542033536, 52.93449963292768, 55.29786102233395, 51.46865890872095, 59.09724135552684, 65.04662575260286, 67.39153631271856, 68.67663814175513, 66.43699615232407, 64.42962123501685, 58.98711689056889, 62.85412280790268, 63.692776541556086, 67.1835251777403, 70.69616456185618, 72.73339656091505, 65.40025880259853, 62.563259447774584, 63.31901781020626, 55.981071226058475, 52.91284422720633, 58.08289289474488, 62.73882081431728, 62.128429412841804, 60.853596348916334, 64.10919497090002, 60.45328317149993, 60.943555908818404, 57.347319049219934, 65.22829817187402, 61.64706437818466, 48.3159322892466, 45.94362789584745, 53.743304129569765, 57.538789549181544, 49.306805364547245, 64.88241964770903, 63.68695574422037, 61.20937493539626, 70.06384711111747, 64.21169827061316, 64.20415947514196, 63.54032185769851, 65.23716665083363, 61.849807770021506, 65.00830027364916, 65.24162246334937, 68.1959124534361, 65.42968834600141, 61.134528267768125, 70.12607159153109, 68.84177777074999, 55.2193469385947, 49.42855181232576, 53.47682222243279, 47.76471768656085, 46.5403498372724, 49.11762945113644, 45.6034799545042, 58.075879696876775, 55.757170569512155, 52.03560613816785, 52.891706574347715, 52.325057445033906, 48.65928480702062, 55.61069750016736, 51.712265553012976, 55.222524058434274, 53.90360355377198, 56.97093232985466, 54.05745852378107, 55.12961095379245, 56.76742407583422, 60.4899416431304, 57.60357141494752, 59.105380273634395, 59.92618330063359, 60.90836440363238, 59.45391424240605, 67.815842628479, 64.3316129715212, 74.69661343482234, 75.94284457545128, 83.07237994286322, 76.41490967042985, 74.1131373374693, 78.11427654758577, 83.41776032601634, 77.32194208329724, 80.37550726244527, 73.64846198789536, 93.59234148456206, 29.17488548063463, 0.33202829800786515, 1.3804938716273154, 0.1292259633661278, 0.28120786372211676, 50.22668353972897, 90.67030906677248, 70.91252250056114, 58.964669166072724, 48.84050223135179, 51.94454831461753, 78.74456221057524, 12.024245415964435, 0.7659768108879367, 0.38114893640722003, 0.2237157842084285, 0.28401646462659685, 0.23614652605066377, 0.20626797851535583, 0.13411098430233617, 0.2676822443402583, 0.18128252648297818], [0.046579314080337365, 0.011379894248450236, 0.12428496438529223, 0.026315731154153907, 0.09510872795456841, 0.05522852718469597, 0.016211644303233876, 0.02392390889355973, 0.075405590055931, 0.1343194368265329, 28.576584785215317, 59.71821531172722, 35.19116001744425, 53.03910140068301, 48.03458459915654, 51.66091780508719, 89.89885730128135, 10.73478485307386, 0.38246954941461164, 0.8648971480227287, 2.8567602557520715, 47.716876537569114, 95.26840948289441, 82.84988741720878, 88.24370338070779, 75.34385158169654, 71.60489143863802, 67.35578783096807, 67.89548243245771, 68.95267886500206, 72.72769343468451, 76.72706757822345, 77.16002664258404, 77.67291576631608, 77.79269710663827, 74.03432907596712, 74.72126160898517, 75.75402952009632, 74.86556560762467, 73.17035644285141, 67.54050793186312, 63.171336650848396, 59.506030774885616, 55.23602485656739, 56.28598059377363, 54.27815460389661, 52.37158460001792, 55.536866726413855, 54.71615391392862, 51.236219252309496, 49.34877864776119, 46.82007366611112, 47.57525936249764, 49.691880133844194, 52.954531177397705, 54.84598044426211, 52.64443643631474, 48.26524349950975, 49.78893133901781, 51.11508469427786, 51.45138479048207, 48.24770266009916, 47.932469614090465, 47.57744804505379, 48.18968296051026, 49.02521056513633, 49.77736034700948, 53.86725102701495, 57.409661200738725, 57.290154426328606, 60.331956417329856, 58.21131521655668, 56.20335978846396, 55.874884820753536, 57.64453272665701, 61.60458118684831, 63.14344467655305, 67.42715143388318, 63.971872791167236, 52.93708839724141, 47.967696420608036, 44.77834270846459, 44.20911265957741, 50.270563094846665, 60.38008389934417, 57.872477346850985, 56.974780174993704, 61.46379947662354, 55.902286498777336, 54.60715516921013, 57.5721336180164, 57.526669425349084, 59.05293818443053, 43.71100694902482, 40.90734381829539, 42.47583689228181, 58.28749156767323, 47.935038766553326, 56.06766931472286, 60.6737203751841, 58.81209681110998, 59.63365685555243, 61.321919502750525, 63.753679183221635, 56.41202988163118, 57.82442046749977, 55.81516673488002, 58.56432460969495, 58.506375512769154, 60.09122094800396, 55.18129602555306, 61.40935305626162, 60.562348596511356, 53.75012120892925, 43.14294968881915, 46.76090863443191, 47.73692377151982, 46.73929245241227, 46.72374417704921, 46.785478361191295, 45.52965310312087, 51.11311958682153, 52.66609576440627, 46.25388737647764, 46.93973341295796, 45.853319245000044, 42.93955126116353, 49.12657245512932, 50.99169869576731, 51.0340210699266, 48.790899938152684, 51.121493847139426, 51.949455199703095, 50.07707649661649, 50.36054618896977, 48.453583948073856, 51.63954088764807, 51.27436822460544, 53.06340832864085, 53.88962030410767, 58.79850187609273, 59.072989340751406, 65.18013538852816, 69.34281349182129, 69.05799450412874, 70.10012903521138, 67.4597777089765, 74.33475909694549, 75.56512032785724, 78.54259152566233, 74.41222590784874, 80.82937255982431, 71.25645160675049, 67.81874518240652, 54.990413881117306, 0.8066212073449166, 0.21831815852032554, 0.059190791385668906, 0.19717754856232675, 21.944939397996475, 76.41083040545064, 53.53031942921301, 50.49163964486892, 35.167790535957586, 27.91581250006153, 58.23399436089301, 10.876528524583387, 0.22438586599403815, 0.12676770979117963, 0.06052225219806837, 0.014290304407627593, 0.06873807404190302, 0.07611625917976902, 0.007395719454037927, 0.05229062979079543, 0.10748428082273853, 0.041527994607965794, 0.05980219466671829, 0.03731185269932594, 0.04749868087650788, 0.06970629426500491, 0.11022160490674358, 0.042362291170584584, 0.05655289019247698, 0.1275242905643198, 0.1008284782930728, 40.75583442564934, 65.78659657509097, 44.66637865189583, 49.70441995128509, 51.96251669237691, 62.021191812330684, 98.7134664289413, 11.795124084718767, 0.35521643116108836, 0.15350465332308125, 4.284672150688787, 62.959556118134536, 94.11395395955732, 86.23318272252237, 90.48317278585127, 79.04167390638783, 71.83179270836615, 71.06577734793387, 71.37376969860446, 72.98665615820116, 78.0678435294859, 80.50587900223272, 78.6741792002032, 80.96395692517682, 81.40963231363605, 75.90859443910661, 78.38915624926167, 79.14599326349075, 78.52894952220302, 76.28239631652832, 70.79758920977193, 65.46979850338352, 63.30466193537559, 57.62009243811331, 58.96315905355639, 56.9846135570157, 55.30890641673919, 58.1903423032453, 56.731942315255445, 54.43934440612794, 51.9223790784036, 48.71228779515913, 49.53145519379647, 52.73035595493933, 54.49642665924565, 56.38415359681653, 52.38309283410349, 48.2128288668971, 50.015656102088194, 50.56951438227008, 50.67294728371405, 49.794759981093875, 47.66248895275978, 50.13323307037354, 50.79605087157219, 50.24475389911283, 51.78722596937611, 56.05210927224929, 59.10574897643059, 60.17011942402009, 62.47067974459741, 60.888517210560465, 58.32895494276478, 59.219411419283965, 59.9086699178142, 65.88719752527052, 65.50231887448219, 69.54603149044898, 67.19978732447471, 57.80558132356214, 52.82120589287051, 49.281117762288744, 49.0300311580781, 51.68336160721318, 62.15669008993334, 60.53582160703598, 58.830367211372625, 63.32055145694364, 57.78574197523056, 56.06178968183456, 57.80072935165898, 59.26228292526738, 58.74109014388054, 45.878241985074936, 43.311082086255475, 49.323565652293546, 58.112357739479314, 50.500523813309215, 59.66599679762318, 62.22274672600531, 61.79168216643795, 62.35567192877493, 62.48393735577984, 65.5841552057574, 58.61273450236167, 60.18054116156794, 58.67550026985907, 62.47341363660751, 62.69570612138318, 64.04362078635924, 59.9702746637406, 63.950805740971724, 62.348517525580625, 53.45470789940127, 45.11556848402947, 48.37632502278974, 50.067529447617076, 46.21773881296958, 46.35048750908145, 47.29812429797265, 43.8883412268854, 51.18117270931121, 54.87163666755923, 47.99967158225275, 50.661588099695024, 49.77364978482647, 45.2581544845335, 51.83463565764889, 53.03841890827302, 52.31357274516937, 52.7878971253672, 53.49117025252312, 53.72819515966601, 53.045208531041304, 52.79312172243672, 51.7537328504747, 53.98629496174475, 53.72311176792268, 55.643778770200676, 55.93199845283262, 61.33975844229422, 62.14484453201295, 69.66209442384782, 73.36103854640838, 72.70324922377064, 73.61179567152455, 70.15639151296308, 76.35840400572746, 78.14807168899044, 82.04985726264216, 76.07247890964632, 81.95608908130278, 75.85281833525627, 70.58064291554113, 64.36029726459135, 1.3190576650442616, 0.6289060918554183, 0.23735630145717054, 0.33026430395341694, 23.97510328600484, 83.54132283118464, 62.93177397020402, 56.465942859649665, 28.339014668618482, 37.045578187511815, 67.85259523699361, 22.859414508265836, 0.2536242857815758, 0.28471274661921686, 0.049669996219416784, 0.07324935132337194, 0.02146416719281866, 0.07785724761385111, 0.017482693337144393, 0.12031531892716886, 0.0815941938649743, 0.23280563193463513, 0.14452461663994098, 0.23217209254301366, 0.08722387524622102, 0.16194838249394972, 0.2360928232871717, 0.11964810997127526, 0.1300374649825596, 0.4474373293980476, 0.2662640317313133, 46.36584751067623, 78.71775673281762, 45.79406399880686, 66.64099862498622, 69.71214386724657, 64.32152855780818, 107.10899383791032, 12.68431265507975, 0.3621088935723228, 0.8706659739536624, 5.083190721850242, 71.44099912335797, 95.77048855443155, 93.54272350188225, 93.34924867076259, 85.57459323636948, 74.29377817338514, 77.2772035291118, 73.5226245080271, 77.10401519652336, 78.48126919038835, 84.4038128083752, 79.60174129855248, 81.72872497189431, 83.41550888553743, 80.53641857639437, 82.21990769909274, 84.77053873000607, 79.76607291929184, 78.99633130719586, 74.00581344481438, 70.23676087779384, 65.36253736865136, 59.70886045886625, 61.46714133601035, 61.09872487283523, 58.74993508861911, 61.138179994398556, 59.52619567994149, 58.29590505169284, 56.33627322412307, 51.09615533582626, 53.31293775189308, 55.57532556595341, 56.96822981680594, 58.74879760126914, 52.17480713321317, 47.863635939936486, 49.082171224778705, 51.43159251059256, 51.32493149849677, 48.812112116044574, 49.10729792810256, 51.48599578488258, 53.100706146609404, 55.43936052630025, 56.147858250525694, 59.405504349739324, 61.83416535777431, 61.10288650758805, 65.28159533777546, 62.76265313548427, 60.92889408911429, 63.41686525652486, 64.44376137948805, 68.32868468376898, 69.89236893192415, 74.77251129765665, 69.05120880373063, 60.16290226290303, 54.64146021873721, 53.62156552653159, 53.36494838037799, 53.808913615442094, 62.86733335064304, 62.68586489462084, 60.97179697405908, 66.11359673161661, 61.30957972618842, 58.3949762775052, 60.18995092761133, 62.00487475241385, 60.24306374211466, 44.99308070828838, 47.45388161751532, 51.449392226434526, 61.51902644864975, 53.16455056590419, 62.26248425822105, 66.10028420725178, 63.10888467296478, 65.15116084006526, 63.594007338246996, 69.97367182085591, 62.10138074813351, 62.782869031352384, 61.27280750582295, 64.45595210598361, 63.559741512421645, 69.73723919160905, 61.03622582650954, 67.58355986687445, 65.09019936284712, 58.48006817602343, 47.94913184258246, 51.3317838791878, 51.05468803836454, 46.284721128402225, 47.90113379878383, 46.6772876247283, 44.34008059963104, 52.88573672694545, 58.883495715356645, 52.386634734369096, 54.43815200559555, 53.24857950210572, 47.84885252675703, 55.746344827836566, 57.22853006855134, 55.83669662475587, 55.56417426755352, 57.20891037294942, 58.85988696928948, 57.520122989531494, 55.728964805603034, 55.51174394546017, 59.0123063518155, 57.729444196147305, 59.07607624607702, 60.79433718035298, 65.8453066118302, 65.06698285379719, 71.98592616665748, 74.50804156641807, 74.28006556726272, 75.4437308157644, 73.28204985587828, 80.04362767742526, 80.60856665334394, 85.77065683180287, 80.95557874248874, 85.54529313118228, 78.56115218131774, 78.239635498293, 62.89119312840124, 1.4192451728928475, 0.8215871945984903, 0.642085500782536, 0.43626592885102, 29.637276049583193, 89.44987927713703, 69.72458562543316, 67.7497350015948, 54.869400916561005, 42.5974460571043, 81.27836627344932, 27.27422256623545, 0.38200557592415046, 0.5346249380419331, 0.1628735255930693, 0.2046866964308485, 0.12730742639471448, 0.2884744528320528, 0.13940552519934793, 0.208004868379043, 0.1905187736115148], [0.028222684876152107, 0.024215028050445744, 0.06874136055909819, 0.011735393519272969, 0.05642355539866033, 0.08986772128170536, 0.056068262971577146, 0.026363659529916705, 0.044473614168143084, 0.10667033538582826, 42.49291881438225, 60.35309407018847, 28.242481216307613, 36.944722283271055, 49.97795820236207, 61.773862838745124, 85.09800172621205, 4.18439430575217, 0.032348851673305035, 1.1261141925088822, 4.635445792828837, 56.65562083644252, 95.24755816305839, 86.86247210348807, 87.20949203737321, 79.4293374399985, 69.50739614425167, 67.81994542767926, 71.44815352655226, 73.31786894029187, 74.62511647132136, 76.74831897981706, 78.51317374936997, 77.92837973563903, 78.06872214040449, 76.32215346059492, 78.23277919523179, 73.38087004999961, 77.97348699262066, 73.99122222777336, 67.56073167247158, 62.53060571609005, 56.55505518759451, 54.23958201562205, 55.19456932621618, 54.27438912853118, 54.242315907632154, 54.53363818507041, 54.71956637597854, 48.93936164917485, 48.42409556911838, 46.7254739422952, 49.32026693897863, 49.60496041082567, 52.83158056197628, 55.93840760569419, 51.916668107432706, 52.29831864756923, 50.71805454069569, 49.70623600867487, 50.708636929911954, 50.035016921258745, 47.64781928831532, 48.93328589777793, 47.135071369909475, 48.03515334283152, 48.9748316426431, 46.47556797150643, 53.33982167705413, 56.5061196973247, 58.92635937659972, 60.026333178243334, 58.63631579183764, 55.97410901900261, 55.69601689615558, 60.911549368212306, 62.590982760152514, 63.62452730055779, 63.20559855430358, 58.19814389751804, 49.99823293378277, 46.92562072507797, 52.80710104973086, 52.89486015996626, 56.31122496820266, 54.189614941996915, 52.03574734349405, 51.4846190329521, 52.26086001242361, 50.10487825639787, 52.68688824868972, 51.37133313763527, 51.26244029691143, 42.11441401512393, 37.87515163421631, 43.42396005507439, 59.72629147191202, 50.71022941220192, 53.48891881204421, 60.28247963997626, 58.867288481804636, 66.47135611503356, 59.60363503425353, 49.89972260690505, 57.013964653015144, 58.73236287024714, 62.89360538605721, 61.92374052539949, 61.981881818463734, 61.57475548405802, 61.4228734662456, 61.52504728686426, 51.1064790141198, 46.38720481626449, 45.348851450027965, 48.16623895399032, 47.1653599123801, 44.67267797839257, 44.54281614672753, 45.457873728967485, 44.46611812037807, 46.23285170524351, 51.56524335184405, 44.91396650191277, 44.47117797790035, 45.09260300667056, 42.681082756288596, 45.37685325068813, 49.794905108790246, 50.7820362429465, 52.065569123914166, 48.374803143162886, 47.80188998868389, 47.833402310648275, 48.48702607616302, 48.141610391678356, 50.720831578777684, 51.337055544699396, 53.81043157269878, 55.269482674137244, 59.03766447497953, 63.04273782237884, 65.03282293196648, 71.23008543445219, 72.1327091032459, 72.80647816196566, 73.19811897893106, 74.35208812836679, 77.49575015037291, 73.90569886853619, 81.69326674553656, 74.5164668175482, 83.43545806023383, 67.48844239019579, 65.53839683532715, 8.84773354376516, 1.4683789880045, 0.897736824568241, 0.5585053082435363, 11.948929044508166, 73.40176843827771, 63.69993486712056, 54.02002734522666, 45.05448149096581, 43.1775136147776, 54.85189537848196, 24.665038393389796, 0.24241018349364882, 0.07131694816052914, 0.037490845312394445, 0.024261447232997706, 0.09193740740057924, 0.07121847521874212, 0.05778043883882704, 0.024219923352281895, 0.029815960067114042, 0.02705562461708342, 0.06642956767351398, 0.04233202686713588, 0.016424285413156596, 0.025842482254149455, 0.03922822930279278, 0.0442925684394375, 0.046801923909374786, 0.0939206328363188, 0.3727669232795316, 54.21755398473432, 68.94325733184814, 37.19596970465876, 37.73999068044847, 59.40814410486529, 69.01913166046143, 93.0468809989191, 3.806349894692821, 0.06112891339486646, 1.7380842254046471, 7.682025720996242, 69.3115129778462, 92.11774995250087, 91.47733672972649, 88.55725765228273, 82.89532415328488, 71.16375031009798, 71.56858598032306, 74.26196775128766, 76.15739037913661, 77.59955175461309, 82.4479699903919, 81.40262696050829, 80.95941482051727, 79.87775848757836, 79.917311668396, 80.12942560257451, 78.37248617602934, 78.15728141415504, 75.82216108998945, 68.50671322115006, 65.31252322658416, 59.228221062690984, 57.498051812571866, 59.02645041865688, 56.974862544767326, 54.59405837520477, 58.146478437608295, 58.17554320058515, 53.19768674911992, 52.43323249201621, 49.55080816822667, 52.46922023834721, 52.96230139270906, 55.879344555639456, 55.69918617125481, 53.91776331009404, 50.490717887878425, 49.88558638480402, 50.347186596162864, 49.81942776710757, 50.26057281801778, 49.91468252674226, 49.50616767329555, 48.836234692604314, 48.75472784042359, 51.19570116842947, 50.366598406145656, 54.81429946038031, 58.577833252568404, 61.8011546904041, 62.94356069257183, 61.43346778808102, 57.569168306166134, 58.73642644574566, 62.17809838633384, 64.89101356075656, 66.22528229990314, 66.68949480979674, 63.43360201005013, 55.80698467070057, 51.85806005231796, 54.20914834545505, 53.79826438042426, 58.33357549482777, 55.54771207994031, 51.04231688284105, 53.66850845275387, 51.950722125268754, 50.90866996395973, 54.511002186805975, 50.722824142825225, 51.676752413472826, 42.223973658777055, 40.9513214326674, 48.05287853364022, 63.01957622651131, 54.0898573014044, 56.43321852530203, 64.28917292625674, 61.73488624634282, 66.42395819387129, 58.94329617100378, 52.19916505198325, 58.78578162962391, 62.277420643837225, 65.17584431555964, 62.9611760570157, 65.04020875500095, 64.97233213916903, 63.729395789484826, 62.68618652897497, 53.563059453041326, 48.442373814121375, 48.01567093018563, 48.54067625537996, 48.74997392777474, 46.67317305841754, 43.53055046450707, 45.601334418019945, 45.70848572638727, 45.5445110413336, 54.40600425966325, 48.574377259900494, 50.40199779695081, 49.84337775937973, 46.59585529758085, 49.099143320514315, 52.02307808783747, 52.5033958496586, 53.76539491838025, 52.22391913014074, 50.63807741288216, 52.117752336686664, 52.53935613939839, 51.15345331930345, 53.78027639081402, 53.941497572006725, 57.46561381124682, 60.984234809875495, 61.05942272370862, 64.73517387144028, 69.18828779651274, 72.62341330128332, 74.35004065113684, 74.89310064623433, 75.61236135421261, 76.26568701959427, 79.02444685659101, 76.22947569816344, 83.12421014232021, 78.32413904128536, 85.02809724500104, 73.15344318266838, 71.68806922051215, 12.650686175592485, 1.7541846969435293, 0.5043314006780425, 0.458075440819225, 11.406179897246822, 80.97308820293796, 71.27552217052829, 61.21881608040103, 42.22320095185311, 49.377231520991174, 67.76825643354847, 35.94011306762695, 0.2205766010428629, 0.09864915733135517, 0.09702908821524152, 0.03855261636236983, 0.12519029645068994, 0.017135462070244457, 0.05713056645265991, 0.006032420985115272, 0.06217544312558829, 0.14643998966822702, 0.23812885516353194, 0.23478649015868866, 0.13604348705660912, 0.13039604009639832, 0.1535983918414962, 0.16779732590000476, 0.11724248663672518, 0.25810191648141034, 0.395248937871187, 62.259805279393355, 79.53464523438485, 38.04831251021355, 50.519480628352014, 72.37921437909527, 74.65668370646816, 99.18262896999236, 5.193164665852824, 0.08983942199378245, 3.63788630212507, 10.088363539788032, 75.94066373763546, 99.26524977530204, 96.57479409248599, 91.00318493381624, 84.8299155696746, 73.97167313483455, 74.71336195545813, 77.64480806166127, 79.91716261832946, 80.89636664236747, 82.53554082685902, 83.05725528347878, 84.77584961921939, 84.04733211763444, 84.7374653047131, 85.95902473695817, 79.69257554700299, 82.6516116049982, 82.18646557100358, 73.49320673173474, 71.85289505989321, 62.09053147223688, 59.04430112531109, 62.29509876620386, 60.97463284769366, 58.00391597132529, 60.68077671912409, 61.29165841687111, 54.498109356049575, 56.828334562240116, 53.010107240369244, 55.600785670741914, 55.99754910315237, 57.19846117881037, 59.05183599841211, 52.88470514359013, 51.461445669974054, 50.165894646798414, 51.43191022257651, 50.57783765177573, 51.75971446498748, 50.70338487625123, 52.28724971894295, 52.41353434901084, 52.20559773906585, 54.893680387927645, 54.175937637206054, 57.88859044351886, 63.029158576842285, 64.01106903629919, 68.14511775970459, 63.75654251344743, 61.14626399932369, 61.78442578161917, 65.67621323370165, 66.91995759164134, 66.19111845570227, 68.65276659688642, 67.78719363674041, 59.805782225824174, 57.986382976655044, 55.56578243932417, 54.14238176038189, 58.644254669066406, 58.262325640647646, 53.82480313701015, 54.99659553650887, 55.47292817023493, 52.574347603705625, 53.76631275300057, 51.90155521515877, 51.86765024738928, 43.57277085704189, 42.512648336348995, 53.573591016954, 64.89266880096929, 53.98632241833595, 59.94055486494496, 66.89186557646721, 65.69266757657452, 68.27054731307491, 62.00857354748634, 54.502780898924804, 61.67430131666122, 63.81158905644571, 67.2646084139424, 65.58628505276096, 68.0876079682381, 65.64145711160475, 67.3731247071297, 67.15411524618825, 55.609179542910674, 50.61373910596294, 52.431687078168316, 50.57518220716908, 50.07406803869432, 47.266431546980336, 43.48395270685996, 46.48730762543217, 45.56801780577629, 47.087579311863074, 57.28560447692872, 52.44053202290689, 52.47232283315351, 51.974770176795225, 49.182293645797245, 52.46564303675006, 54.43117803142917, 55.96507187812559, 57.615981794172725, 54.31287542466195, 51.97975158691407, 54.46148226338049, 55.26730968106178, 55.12611612196892, 57.23693178546045, 57.222466084264944, 61.05072290666642, 64.64074280954176, 64.5379335649552, 69.49448370164441, 70.48281115870323, 77.38291140525573, 75.8290958404541, 77.5989241753855, 81.5445069343813, 81.74432816043978, 83.813276444712, 79.80429249425089, 87.58141117711222, 81.22929742259365, 88.57982697025423, 74.78991877648139, 75.0028250294347, 12.689983421756377, 2.5666399396234945, 2.181707846541559, 0.7187973167146406, 16.443427897268727, 87.42519886262956, 79.77950311476185, 70.16793897075038, 68.08792175785189, 60.12071717169977, 75.57494194276872, 46.159730880491196, 0.5520723147257682, 0.38395600513585154, 0.22692984480771328, 0.13093443136782418, 0.17321329173301497, 0.14751747701196902, 0.18636657706191465, 0.09857917519947214, 0.12823224773690586], [0.019919375791364623, 0.09853422882095461, 0.019435790450041814, 0.019124988579161225, 0.06108106737355552, 0.0647716767965786, 0.04355643455299639, 0.1499634731801287, 0.02395237480560618, 1.2554403754972643, 55.133615693738385, 52.00055583830803, 38.95621176688902, 47.04918715261644, 49.03559307898245, 67.26040363311768, 73.36534530885758, 0.9819048823368166, 0.0598177500820208, 1.9866801245558647, 3.055394474537142, 60.3050724921688, 91.82296814457064, 85.49605954077937, 88.40612872954338, 79.87182786387783, 73.48609155224216, 70.20504459258049, 76.52713652580016, 75.24925970262098, 83.03849850931476, 78.44665819598784, 79.58176858963506, 73.94926071166992, 77.09408375524706, 76.10164565424766, 76.33866663902037, 71.81836251289614, 71.3556718826294, 62.186280450513294, 61.0258040889617, 58.83040643507435, 56.788098889012495, 53.24951302620673, 57.75936795819191, 53.46390585745535, 52.010961886375185, 56.57642033792312, 53.83025915391984, 49.503594598462506, 49.73923490893457, 46.29596264131608, 50.076896067588564, 49.05943324488979, 52.584796797844675, 54.76545026225429, 51.93201634191698, 49.11893560040382, 52.10375339754167, 49.2068398383356, 50.18336096117574, 46.99878077353201, 51.00657232346074, 47.73622558962914, 50.84338211244153, 45.57215590630808, 50.062665708603404, 50.84618660711473, 50.9805356302569, 53.678569332245864, 56.793127367573405, 59.71425371785318, 56.526527789331254, 56.55086609625048, 53.91614337121287, 57.27757538518598, 61.38446561751827, 64.73897464813726, 65.63553825501474, 53.11397552490235, 46.836575077426055, 51.913208576940725, 43.91995160810409, 49.779874586289935, 53.513602287538596, 49.51405555971208, 51.72930432904152, 47.25663738866007, 54.156384621897054, 49.3885201023471, 46.953720584992446, 46.16854052389822, 46.47283407949632, 40.83963978675104, 42.683404799430605, 40.10082606346377, 54.8348173787517, 51.58933062707224, 55.296719612613806, 60.461869239807136, 60.27286591068391, 56.579048325938565, 44.30170805223527, 56.92454638019685, 62.80100607102918, 61.30863443497689, 61.0909781917449, 63.0059067664608, 62.525102630738296, 61.88458350396926, 58.309323480052335, 53.63934170815253, 45.849020327291186, 46.16982706131474, 44.89324069792225, 47.60837985623268, 44.01900714443576, 45.695079065138295, 46.387930454746375, 45.523961744000836, 43.40757631486462, 44.26873268619661, 51.18401250531597, 48.066736267459014, 46.87082913614089, 45.73245140814012, 44.47564163515645, 46.035556485576016, 50.14017174320836, 49.72294922797911, 50.34004788244925, 49.969356444574174, 50.36577470840947, 48.796312808990486, 49.687565526654645, 48.51501218734249, 49.96218242952901, 49.13498986151911, 54.044349962665194, 54.633482117806714, 59.59389578911566, 62.04176464388448, 69.38995253655219, 67.2927474975586, 70.84086864225327, 70.40943145751953, 74.05965974253994, 71.61795293131183, 77.82879075696393, 75.21397406055083, 77.99658190819525, 77.47198058712867, 82.11281914864817, 76.39258353940903, 85.43591391655707, 26.321386675680838, 0.6480056444002736, 0.2536053021228121, 0.21328932755897123, 2.475314904605189, 64.0480177633224, 69.41124316184752, 56.13752280512164, 43.83856634939871, 23.744169819739557, 48.38317348111061, 30.188021929033344, 0.14139629660114167, 0.04761293139909545, 0.03126606683156664, 0.08486675293815714, 0.12382960172309992, 0.04318841740549092, 0.04816863625761002, 0.05039375395544114, 0.03602459516015745, 0.05048350498621022, 0.0707895962160922, 0.0629123469303933, 0.07440368494679851, 0.032562984739460295, 0.04771182568924082, 0.08850484320353116, 0.07292448407820157, 0.16618366893981734, 2.1382085161824382, 67.3326301574707, 61.709328082300004, 39.625379885396654, 42.07082863776915, 58.10148885173183, 75.94188751712923, 78.7709754513156, 0.811490768626813, 0.011739092766337339, 2.8530553319761833, 8.222598443108222, 68.73515205998575, 91.91194318955945, 88.55564163577172, 91.15485514363935, 82.80868684091877, 76.75901920564714, 74.69124763242661, 79.75036774912189, 77.96092756332891, 85.0309213515251, 81.40454107715239, 81.50379273199266, 79.17809394098099, 77.98007657451015, 76.6604265089958, 78.03953970632246, 74.9850723820348, 72.61527830554594, 66.8389763370637, 64.29439752332627, 62.81115324266496, 57.66768255541402, 56.622049270137666, 59.772242038480705, 54.191238803248254, 55.70110813263924, 58.418483041947894, 56.747431755065925, 53.09692890413346, 51.99136180262412, 49.29983139038087, 52.248857559696326, 51.827312592537176, 55.06328367417859, 55.725360147414676, 52.94646286195325, 49.24312568479969, 51.64522440202775, 50.22774650204567, 49.29417533259238, 47.57340800377631, 49.692915639569684, 50.10323870566584, 53.03007602691651, 48.98575152120283, 51.24916307387814, 51.75160692584131, 53.944815897172504, 56.62205319250784, 59.72199647657333, 60.65592065934212, 57.74065825246996, 59.166620239134765, 56.08112304441391, 58.866825642124304, 63.844246710500414, 68.28218890774635, 69.46560721243583, 55.915751995578894, 51.569055895651545, 55.55893005863313, 46.31600595289662, 51.4318278528029, 52.337730623060665, 50.04923159076322, 53.087279873509566, 50.333976053422504, 54.910385762491536, 49.572891112296816, 46.1784758875447, 45.71644029309673, 49.3915952405622, 40.83852191125193, 44.06167860954039, 44.620196665486986, 60.12756563002064, 54.036415007806596, 56.38147069561867, 62.118482282084805, 62.71909913709087, 57.819368454717825, 46.997011784584295, 57.30383565348964, 64.42704423781365, 62.35671920161094, 62.692438787029644, 64.6481050983552, 63.656192594958895, 63.39781430459792, 58.87781220097696, 54.44285492743216, 48.97233701521351, 48.325989246368415, 48.78970361525013, 48.19348765957741, 45.28043354711225, 46.014838526325846, 46.090183334965865, 44.746030222985056, 44.80868224174746, 44.34547385861797, 53.629971165810865, 51.193861576818655, 49.56690557541386, 48.498298968038256, 47.46745301831154, 48.77692453322872, 51.561301369820875, 52.05815584428849, 51.37665971632927, 51.94470520942442, 51.944944474004934, 51.36854825481292, 51.98853769610005, 51.256580275873986, 53.284492723403446, 52.018700722725164, 54.502318059244466, 56.464162103591434, 61.021210993489916, 63.89213885030439, 71.62313830467963, 71.40505452309885, 71.9199989688012, 72.70130372816517, 75.62160245833859, 76.3148735415551, 79.47731587194627, 77.38214262070196, 79.406995619497, 79.15398705390193, 84.05201542762019, 79.50216800935807, 90.40914981595932, 32.209142792609434, 0.9277441208401035, 0.5425685956593483, 0.11567659525861664, 2.2168593925814477, 68.07534663907944, 77.26089431393531, 63.996979882640225, 46.74921604894823, 29.409203952358617, 59.510737619092396, 46.751412576244725, 0.06853560466439494, 0.08646750131682043, 0.05957122681842697, 0.03396442385330316, 0.09236435586165997, 0.07297195088598998, 0.09488231832942656, 0.049744571048405864, 0.08185042729300838, 0.10837320328479814, 0.2966085292639271, 0.19387711921045858, 0.23076019249856475, 0.2001671147562804, 0.1031725541237862, 0.17322314362372124, 0.5914458019598838, 0.23970247636879646, 2.3155570126348928, 76.89263866793725, 69.22449127320321, 48.25133477487872, 59.801251888275154, 68.5844938216671, 83.06957937056019, 88.39246319186303, 1.4251701581862666, 0.23371100996530828, 5.0988306826160805, 15.346383125551286, 74.53517652327015, 99.1506459636073, 94.73934450457173, 94.54407322791316, 86.17773609776651, 80.04048978128742, 77.49019607420891, 81.47861896022674, 83.10607310264342, 90.58245581965294, 84.73155037049325, 85.82527975882255, 81.98851139314714, 82.07377587595295, 80.63702737131428, 81.05690140878, 79.19945516893941, 76.81360290896508, 68.48481070610785, 65.24838070715627, 65.04571968509306, 61.94360733032227, 57.85861961303219, 63.24064493179322, 57.07211379081973, 57.52411203999674, 61.63168084236884, 60.538214252841094, 54.4120603992093, 54.646602446033114, 51.759953729568, 56.34971126433342, 56.505951035407286, 57.05453372770741, 57.37241045121224, 53.2277830954521, 49.71686955421202, 51.859723137271025, 49.35584675881171, 49.300784526332734, 47.26470962647469, 51.37806784722113, 51.273948530997004, 56.07789101139192, 49.242376512096776, 53.58181230483517, 56.23566442920316, 54.61680419983403, 60.40761501558366, 62.70804589794528, 61.74608461318478, 61.89532295350106, 60.82676341456752, 58.18700828859883, 62.62269120062552, 66.93188944170552, 73.43875638900265, 73.43653632748511, 59.39454524747787, 55.86443170424431, 58.00265296812981, 51.69264585741105, 59.46530872775663, 58.15390740671466, 51.568059613627774, 56.09678899088214, 52.595332284127515, 56.46645276777206, 51.013087380316954, 47.27276617480863, 46.172176561047955, 48.58845072407877, 43.319264150434925, 46.36643194383191, 48.45311326365317, 62.83913935384443, 56.07305472896945, 60.51799051223263, 64.1372948308145, 64.8295460977862, 60.14463186264039, 49.45084264201503, 60.17712477714785, 67.36691951751709, 64.62334709782755, 65.9143481716033, 67.38150288981777, 67.78395375897809, 65.84423188240298, 64.7556878674415, 57.731330856200195, 51.62321206062071, 51.41976656452302, 50.032698800486905, 47.62278672187559, 45.62250344983993, 46.41629311346239, 47.296684788119414, 45.30632511261971, 44.03241772805491, 44.822457605792636, 56.45482686258132, 54.63607088212044, 53.59681929311445, 52.40691338815997, 51.699255051151404, 53.494547413241484, 53.534108438799464, 55.28688623059181, 53.96010137373402, 54.96715814836564, 55.45021764693722, 55.250282672143754, 56.028033764131614, 55.29644112433157, 56.52263287575015, 54.557996103840495, 59.254979472006525, 61.38860764042024, 66.20636078619188, 67.24347468345397, 76.24892280947778, 74.87266509763657, 77.5167348307948, 77.45919366036692, 79.4204415044477, 80.28365319774997, 85.37088101910007, 81.32274396957891, 83.08296249758813, 82.79785325450283, 86.46633625030519, 84.7654474935224, 94.13228711774273, 33.75603145168674, 1.5464216518786646, 1.1118073473053596, 0.2920439016194113, 5.637253455577358, 77.38844194719869, 82.3152683627221, 72.9945715012089, 62.08402818249118, 35.41490770155384, 67.50495556862124, 57.59481668472291, 0.22365164732740772, 0.14728127678315486, 0.12879162215657775, 0.2848267405023498, 0.2064533871147902, 0.14053227199662116, 0.14160528538688538, 0.23630533607736712, 0.26272029285469367], [0.02191398337843918, 0.079357017943215, 0.10863992445651563, 0.02988092623831284, 0.028979384392920523, 0.06805047182546509, 0.07947207668856268, 0.18521818061990125, 0.24625343210514516, 2.5338467186497104, 61.952554256685325, 48.00645728265086, 49.1652548697687, 43.28069548453055, 46.81146798595306, 82.56544497705276, 55.89301401568998, 0.07720919851694377, 0.01658177202297074, 3.143330336578431, 1.4345050314741752, 72.9582581981536, 87.6428041150493, 88.80260975130143, 84.58646189781928, 79.7631311416626, 73.24598758451401, 73.4681349415933, 77.7497471532514, 79.94217949528849, 78.60790683377174, 80.19552538471838, 76.94991311719342, 75.66512507777061, 75.66459948016752, 77.5136753820604, 69.12359222289055, 59.11743763954409, 57.70919692131781, 58.32440107099472, 57.947123973600334, 58.24038782427388, 57.126995594270774, 54.180644481412834, 55.89612837760679, 54.75807620633034, 55.572811326672955, 54.31235374942903, 53.5835499148215, 50.824605726426654, 49.50663051297588, 47.26375256815265, 49.60582725463375, 49.83083794193883, 50.57782588466522, 52.19448566436768, 53.783684930493756, 55.75321289800829, 53.21965202208489, 53.828164608247825, 48.67333473697786, 48.16178706384475, 48.76273339794528, 49.485908631355535, 51.205307052981475, 49.5847955057698, 49.191872073758034, 47.2125970163653, 48.0297875404358, 49.000785966073316, 52.94885158538819, 56.257908190450365, 56.50741800185173, 53.40943198050223, 53.51840326862951, 54.67064265281924, 63.16767315710745, 64.522063655238, 62.63905140661425, 58.12170474759994, 50.62343912739908, 46.95820777646957, 40.61146766908708, 51.156869703723544, 46.346745567937056, 50.56095577055409, 51.363017712869954, 43.810784201468195, 61.57312770043651, 53.81855087895548, 47.498337761048354, 51.1297151350206, 47.73951253583355, 47.33687339290496, 44.788729144680886, 53.46634164933236, 56.748792817515714, 49.47766380925333, 55.20036658933086, 59.48317120152136, 60.29844760894776, 51.19358701090659, 57.10229250692553, 61.691759786298206, 58.311210140105224, 60.397334483362016, 58.39321121092766, 60.33655343517181, 57.96833615149222, 53.801512102926935, 54.09843160260109, 45.47883095279817, 44.913044744922274, 46.907322868224114, 48.87783927302207, 49.88890078759963, 49.849214246196134, 46.32148942639751, 45.19869527509136, 44.89943019805416, 43.67019468738187, 45.06153783490581, 51.441421970244384, 45.74962354475453, 46.64291197253812, 45.8475729726976, 45.894661026616255, 42.657717197172104, 48.24668284385435, 48.73655942178542, 49.304149919940585, 48.240022659301765, 49.90147982874225, 51.15401814060827, 50.095005650674146, 50.58795736682031, 51.3775344048777, 48.675480273462114, 51.20689953527143, 50.68833474190005, 55.52492703160932, 56.93890225502753, 61.96494502405967, 62.919959791245006, 68.03074144547986, 66.61740949076992, 72.1243073863368, 71.17543897321148, 75.93829462605139, 74.3566773014684, 78.52339544603902, 75.81313963859313, 78.89475760921356, 74.78444314772084, 86.06674871137066, 46.30209330589541, 0.10665803967464356, 0.1517259810240038, 0.041739706836280324, 0.2106276929618851, 41.391627096360736, 76.91007752572337, 59.860632650313846, 43.88894919426211, 29.057563466410485, 48.143073435752626, 50.4503135527334, 0.32471715322425293, 0.05841891949756011, 0.05052744395910733, 0.1443840395058355, 0.05805831042028243, 0.046228185341122656, 0.10840280492219234, 0.06017257902590979, 0.08729512908405836, 0.09303079106875005, 0.05422962514022666, 0.08646620662822839, 0.07689198449013696, 0.04857110820951001, 0.0809804272026785, 0.09904060527802476, 0.1549564205831097, 0.34054020900399457, 3.770037081933791, 72.52158857161, 50.94566575942501, 57.69200909522272, 44.67028533258746, 56.351260600551484, 90.29773096884452, 58.29345749270532, 0.08613527196669772, 0.03365911100240004, 7.008044854287179, 5.163268850695703, 79.26197774948614, 89.91294645494031, 90.23877774515461, 85.99786404640444, 80.194105486716, 76.43794967282203, 74.71780992323353, 78.75385822788363, 81.96049782537645, 82.13920885516752, 82.74292438260971, 79.50967542586788, 79.93523690008348, 77.41458846676734, 79.3736162493306, 72.0135788763723, 61.53782636888566, 60.72502889940816, 60.28134215262629, 60.4840620102421, 59.857800699049434, 60.15842291616625, 58.41742792437154, 57.8671899918587, 55.76704317523588, 56.69820600940336, 56.07333321725169, 55.218707592256614, 52.71226990607477, 51.35829517918249, 50.50772136257541, 54.04608757265153, 51.97908870635494, 53.31979013258412, 54.9773366989628, 55.11942848082512, 54.43156242370606, 53.645786162345644, 52.382751587898504, 49.46406102949574, 47.78094453196372, 49.293755638983946, 52.46847891038465, 52.54088978613577, 52.176795774890536, 51.38455544748614, 50.313473824531805, 50.74700555493755, 52.508204675489864, 54.83901431483608, 57.15842162409137, 59.979229434843994, 54.62385662140385, 56.587426508626635, 57.44674721071797, 67.6366844484883, 66.77755986490558, 65.27617462219732, 60.930466959553385, 55.93390472473637, 49.51576179073703, 48.95121505183559, 55.36412554402506, 49.33994547013314, 50.38688490467687, 53.264261138054636, 46.696499393832305, 62.80104137236073, 55.2819715007659, 46.54688058360931, 50.56243450410905, 47.36201186333933, 48.13906477343652, 47.70151261360415, 57.5202916514489, 59.39252522683913, 51.254136639256636, 57.89061830889795, 61.562560835192286, 59.41369425865912, 52.181773262639204, 59.55084385410432, 64.9818125078755, 61.7152508612602, 63.83153823114211, 61.75112485885621, 61.435554489012695, 60.66986468530471, 56.400745222645426, 54.8982774057696, 48.5724788327371, 47.10490049854402, 48.62286952234084, 51.195552118362926, 51.269241686790224, 51.07011079788209, 46.468068399736964, 45.17022671238069, 45.19654581623693, 42.614979051774554, 44.16111461577877, 53.76822294727449, 48.6867178640058, 48.76065846412413, 47.045092198156546, 47.398054522852746, 44.79979022856682, 51.19439894153226, 51.05933604701873, 52.48282694047498, 50.572248274280184, 51.824908179621545, 53.46255656211607, 52.76193495719664, 53.408400397146906, 53.61592908059397, 51.33176426733694, 56.41915682823428, 53.82901576257522, 57.978004793966974, 60.81318024666079, 62.9431684555546, 64.87689302813622, 71.46156018780124, 70.48277977974185, 75.87706642766153, 74.36391015206614, 77.99605631059217, 76.27885049389255, 81.6270806712489, 77.74045898068336, 82.7807987889936, 77.8632527012979, 87.43671494145548, 51.44949028568884, 0.17523337365879169, 0.5345063476312546, 0.056703790361362125, 0.1551061141635141, 44.17844756957024, 84.11972338153471, 67.64664726872599, 50.942147393380445, 33.09901091360277, 61.414926744276485, 66.74118380392751, 2.204309278918851, 0.10971836941016298, 0.12966981938769742, 0.07074777547630572, 0.061492778345822334, 0.0636522729520596, 0.10455548072293883, 0.04613379947841168, 0.09236477721001833, 0.15810832080821838, 0.1415438451353581, 0.1802040585466931, 0.21718226463323642, 0.13665176086848782, 0.23992856423701012, 0.3867517970502377, 0.2969494690337489, 0.4858278338947604, 5.082493030255841, 87.38271959366338, 60.04388970713462, 63.9950422317751, 62.03261767664264, 64.810193123356, 96.62059168661796, 64.40233330572805, 0.3536489846244935, 0.09750561022590246, 8.834735789606649, 11.948397563349817, 84.62828220859652, 96.35803607202347, 95.75201419091995, 90.38867504365983, 85.30747198289441, 78.42453602821597, 77.63154260573849, 83.50311894570628, 81.97610101392193, 87.59275467165055, 86.26445970227643, 82.75070636503159, 83.32574936651415, 81.00951133235809, 83.4916264011014, 76.59631144615912, 63.206512466553725, 63.7944757553839, 63.1123520481971, 63.98958229249524, 64.03884726185953, 62.082933841213105, 62.13157515372, 60.450317859649665, 60.22553466981458, 58.72387486119425, 58.44127201264905, 60.03162445560579, 57.194511352046845, 55.41077821485458, 53.942564456693596, 58.17740240404683, 55.73034547990369, 55.94537373512022, 54.7451598413529, 55.22577178093695, 56.89919610177317, 53.2721725586922, 53.08417335633309, 49.91947566309283, 47.60349650536814, 50.27955316728162, 51.32752418518067, 55.03223811426471, 55.86966806842435, 53.74417097337785, 55.370405258670935, 53.298315155890684, 54.800869264910304, 57.314171098893695, 62.86419937687536, 62.18634320843605, 58.74025075666366, 58.46069951211253, 58.82209885504938, 70.84822700869653, 71.07649326324463, 66.48214263300743, 63.400858063851636, 55.84834998653781, 53.40849453403104, 51.53832412535145, 56.017961117529104, 53.95966599064489, 54.141193282219675, 57.04805789455291, 48.72326258690127, 64.21906448179676, 54.800955557054095, 46.759453435097974, 52.08895821725169, 49.04256705314883, 50.354333154616825, 49.63402125143236, 58.891677779536096, 62.571139489450765, 53.817931144468254, 61.12222379253757, 64.48968448946553, 65.04380556844896, 54.05585427438059, 60.01118498463785, 66.894728906693, 62.205554977540054, 65.01546644395398, 63.614901804154925, 64.63003866134152, 62.90628248645414, 57.87844327188308, 61.56681660682925, 51.187695610907774, 49.555652295389486, 51.54272894705496, 53.56861352920533, 51.77076770413307, 51.33454915015928, 46.5030167179723, 45.31961018039335, 47.19591125365227, 42.12210970540201, 44.598200013560636, 55.95943935455815, 51.10553372290827, 53.2703878802638, 52.127648476631414, 51.274674169478885, 48.873489364500976, 53.06416534608411, 53.836064261774865, 56.41521876858127, 53.700766025050996, 55.14554754380257, 58.85488594731977, 55.91299849171793, 58.073742005132864, 56.461965576294936, 53.50088204106977, 58.913964686855195, 58.465194548330004, 61.60416541561004, 64.2735226692692, 67.38800617956346, 69.06432520958685, 74.41500294593074, 72.39882622995685, 79.21030444483604, 77.59471154982045, 81.73862503420922, 79.84324947480233, 82.12444505383893, 82.30903179414811, 85.21561007345878, 82.24209262478738, 91.55264623703496, 55.04775893303656, 0.2837946974942761, 1.5141738855069684, 0.1991675691979547, 0.9878845356645124, 54.972484727059644, 91.11857321954544, 76.29391239535424, 64.55370541541808, 43.273819569618475, 67.72971522423529, 80.37975911171206, 2.247582337548656, 0.23879233327123428, 0.2510056593605588, 0.18049236807611682, 0.20783236070025354, 0.14466134801266656, 0.3126068046737102, 0.17495998752213296, 0.3033547914556919], [0.04626247926705307, 0.05316585077032928, 0.029271164300641226, 0.11198647230142549, 0.05374223234192018, 0.1328320311562669, 0.08679612239281978, 0.11525002218061879, 0.28045148979271617, 6.8977237805243465, 62.38569375007384, 45.66342553784771, 29.321231072948827, 35.16454673582508, 55.80808293434882, 82.65493777490433, 43.10474188097062, 0.21655129929704053, 0.6717022760741173, 5.021806609246039, 3.587080086431196, 86.5044459988994, 87.36655942855343, 82.97346561185776, 79.48812592414119, 75.50166422320952, 73.404506252658, 74.36533005006852, 77.84487247467041, 80.18999484277542, 80.7765382336032, 82.35432732489802, 78.76671575730848, 79.77514143913024, 73.89421416867164, 65.95314825734785, 59.6063022459707, 56.38490276951944, 58.04629718103717, 58.65410766293926, 54.36938501173451, 55.28261869184433, 55.16861108041579, 55.16642632022981, 54.27845662639987, 52.92407005063949, 53.98972703564552, 56.69390316932433, 54.123507315112704, 51.201631792130016, 46.1740553763605, 48.26809114025485, 47.27633160929526, 49.74926833183535, 49.74087053729642, 55.16815216310563, 56.917705766616336, 57.953917518738784, 53.87990851556101, 54.63987558118759, 51.51725707515594, 52.92103021375595, 54.80126934666788, 52.391219985100534, 49.78412251318655, 51.929662919813595, 48.51276859160393, 47.544833537070986, 46.77295815560126, 48.064900598218365, 48.14618387529927, 49.557327147453066, 51.3830453349698, 55.79263664061024, 49.993757509416156, 52.17825489659464, 55.546974674347915, 62.957759672595614, 62.66837504602248, 65.90764091860864, 62.04215295853154, 51.892047389861084, 59.113213246868504, 60.296462889640566, 51.41227875986407, 56.76223870246642, 51.35811082778439, 41.09790432837702, 56.58224897999918, 55.40410626319147, 59.041449562195815, 48.35157486700243, 47.29171514511109, 57.760124975635165, 61.2366001067623, 57.45063427955874, 58.25879158512239, 52.660816254154334, 55.84034442901612, 56.46274612795923, 55.73476991345806, 57.99065051540252, 63.249501643642304, 58.68050913656912, 59.785170170568655, 56.847303144393436, 53.45036583562052, 53.466486777028734, 50.67401024603075, 49.67595138857442, 46.89161377568399, 45.91502597255092, 45.85085207416166, 49.11626446631647, 47.84704823647776, 47.918384382801676, 52.67424644962434, 46.6998294861086, 45.558121665831536, 44.421559995220555, 43.654073745973655, 45.96290634524438, 49.42677890100787, 46.84551415904876, 44.80521486651513, 43.791439071778335, 46.09917340740081, 43.50384696837395, 47.07330580680601, 49.050815797621205, 49.66263494183941, 48.78675399288055, 50.44219032410653, 49.46778335878926, 49.506803097263465, 51.444257843878965, 52.3434062927, 48.46824969014814, 50.842880049059474, 50.37196028617121, 51.08110520147508, 50.052040007806596, 53.14102418961064, 53.736957734630955, 58.5913928862541, 59.29992983418127, 66.32348275953724, 70.78481797249087, 74.2336090149418, 71.43386040964435, 74.14418681975334, 73.06459365352508, 77.72566380039339, 75.04415112157022, 82.62941883456323, 54.47912900678573, 0.1006407178037109, 0.43403321156098, 0.24148695561433994, 0.19966004115919914, 28.710745534589215, 80.19912612053656, 57.37152007318313, 52.161879001125214, 30.17164211119375, 32.57876930698272, 62.82363422455327, 2.76756237110784, 0.15991317799254773, 0.08591906663270728, 0.03257342268742862, 0.01817127231568579, 0.022470260887677153, 0.12466662938916877, 0.016816893983031475, 0.029757457762776367, 0.03956738025731137, 0.05266616609127772, 0.040824706741278215, 0.14953984187976008, 0.05458721200064306, 0.08126392569993773, 0.1069954477791344, 0.1640903796519964, 0.2744395075546157, 10.488982662077873, 71.38159090472807, 55.18603424872122, 31.377967057689546, 41.009015575532, 66.3243535257155, 88.07910503879671, 48.1194450778346, 0.41030946037461685, 0.5667338279947158, 4.42435069430259, 6.815823220437573, 92.59144675347113, 88.65634456757577, 88.24173435088127, 80.77369843759845, 77.60687089735463, 77.6374340057373, 76.94594367857903, 81.59165382385254, 84.12991369924238, 84.21617446407195, 83.6307607158538, 82.05215577156314, 79.98955388222971, 75.06881498521375, 66.86760963932161, 61.7982207575152, 59.84787710251347, 61.76749290958528, 60.08180333722023, 56.33657916899651, 58.443633279492786, 58.28198063758112, 59.51366370724094, 55.748698249939956, 55.50004351523615, 55.07521944661295, 57.66291295328448, 56.14317886291012, 53.12737434141098, 50.41572609255391, 51.7585220644551, 51.40689726798765, 52.300115093108154, 52.62343214404199, 55.156592938207815, 58.25482999124835, 58.080104089552364, 56.74464294987341, 55.18509287987986, 51.7419304386262, 52.88710955650576, 57.20432512221798, 54.355033059274, 51.643239682720555, 53.77107058801959, 49.202740961505526, 49.813501065777196, 48.622277244444824, 51.074088081236816, 50.02289679742629, 50.246973960630356, 53.00792640255344, 56.58285694737589, 54.96796223425097, 54.83640593867148, 57.132126054456165, 64.07611762323688, 66.12410083893808, 68.8739804298647, 62.82214764625796, 55.885439918887236, 59.71383010187457, 61.13434391637003, 53.23571412794052, 55.82564730798045, 52.26559039085142, 45.17962078894339, 58.13923381990003, 57.37193976679156, 56.93715287793068, 50.36710439189788, 51.192112199721805, 57.794194682951904, 61.1393920067818, 61.55506518579299, 58.884864622546786, 56.38367899002568, 57.93381929397584, 58.98072734955819, 58.27392016687701, 57.94806534244169, 64.22660719963812, 63.707344224376065, 61.418943251332934, 57.042790151411495, 55.465287393139256, 54.49778379932527, 53.31914686387586, 51.51367595118862, 50.496409246998454, 48.30387492333689, 48.98332357406617, 50.843966545597205, 49.57236159232355, 50.12320356984293, 52.576971669350904, 47.93567419052125, 47.22270888666953, 45.809090598937004, 44.43203272358064, 45.960929470677534, 52.386277798683416, 50.01042366027833, 48.05173712392008, 47.38183552219022, 47.78554154980568, 46.52703731290756, 49.17329965099212, 51.88153936016945, 51.43027067184449, 52.463438664713216, 52.3051945624813, 50.43884061997937, 53.47261351923789, 54.57068104897776, 55.10362917377103, 50.976358306023386, 54.45723825885404, 53.055010534101925, 54.49289652609057, 52.9043052273412, 55.254499220079, 55.94627980263003, 58.85635291376422, 60.64163538717455, 68.48010386190107, 70.61619527878301, 76.02570072297128, 74.03620396890949, 75.83301036588608, 73.23687199623355, 80.79181978779455, 77.22058019330426, 87.56144631293513, 56.12612831977106, 0.11538778777204214, 1.5103555807182867, 0.14318285960583918, 0.22083461945576055, 31.366099926733206, 87.12893439877419, 65.5125758724828, 59.54779617248043, 31.55428936404567, 41.893459058577015, 73.45002928087789, 6.4914539937050115, 0.2863976191128454, 0.12777729876219265, 0.048963280109268044, 0.039054139652439666, 0.04512108486866759, 0.11086080568812548, 0.05922519639434834, 0.09203387319200462, 0.13919103590230789, 0.19261549497323652, 0.18366525911035078, 0.2864509081888584, 0.166559343136126, 0.18636020321038463, 0.21723207567007313, 0.40965865336118207, 0.40530491440046224, 11.8890981904922, 85.87206579023793, 60.01027891712805, 35.10326362425281, 49.55079247874599, 75.13240445044734, 95.67262541863226, 53.79214940532562, 0.41258771393087607, 0.9674038185227303, 8.52493424569407, 9.512812591368153, 96.78850050895446, 93.9985264501264, 88.28271527444163, 84.68941627010223, 79.66984148948424, 81.08267922555247, 78.88936042785645, 84.93083030946794, 87.29178336358841, 86.43389824898013, 90.21325096007317, 84.96481372464089, 83.62818764102074, 79.47380927301224, 69.29609806306901, 66.1743385561051, 63.61578041507352, 64.47167688800444, 63.18668488533267, 59.907720704232496, 60.80667303454492, 59.58013611455118, 61.32724608144453, 59.92474379078035, 58.144430960378344, 59.41102312457178, 62.91957932133829, 59.38688093616117, 56.11930731804141, 53.74354731652045, 53.70658290001654, 54.369267340629335, 53.10476187736758, 54.460101589079834, 59.353321136966834, 60.051522639489946, 58.94283725369362, 56.420608105198035, 54.795966302194905, 53.55020976835682, 53.5553559180229, 57.13265557442942, 53.97666162060153, 52.447145139017415, 55.05090467391476, 53.44108550779281, 54.92170180043867, 53.760648850471746, 53.462705612182624, 53.61361880456248, 53.811392553391, 56.99896158710603, 59.462370872497566, 57.282811749366026, 55.41719129008632, 60.46571708494618, 69.72055342889601, 68.45728351223853, 70.33733044901203, 67.41765929806617, 61.38565801805066, 63.797193957913315, 61.10851118641516, 51.38255111632809, 54.787713635352354, 53.5990079756706, 48.22024999126312, 65.08213496977284, 60.95095742133356, 55.50933953254454, 50.898165856638265, 53.725775057269686, 62.03797171192785, 62.5762777943765, 65.66011974888464, 63.193713772681456, 58.58457580689461, 60.587416464282626, 61.23599606175577, 61.36630504362045, 62.23987963891799, 69.28291889929002, 65.96609207891649, 64.95197896034487, 62.70357047357867, 59.60534518764865, 58.89523929165256, 54.765230609524636, 53.96249401953913, 53.96591824869956, 50.407642087628766, 52.84994117675289, 53.566052221482806, 50.44194713715584, 51.543132951182706, 54.03616397611557, 49.19444907096125, 47.6833128160046, 46.18423392695766, 44.878351380748136, 47.02246404463246, 52.74949712138022, 51.39978601086525, 51.45535815146662, 49.65878317433019, 50.82218562403033, 49.86339753673923, 53.07739550067533, 54.40694170613443, 54.570100538192264, 54.869279323085664, 55.87190774179275, 53.65852209829516, 56.85071560644335, 57.53693819046021, 58.91741245023666, 54.27563644224598, 57.991619340835086, 56.36374942718014, 59.25504222992928, 56.40055694887715, 58.01344340847385, 61.74198573635471, 62.78110788714502, 64.83142883546891, 73.21631877653061, 74.9559840848369, 80.01810089234384, 77.36136974826937, 80.77561255424254, 79.74399781996205, 83.96467208862305, 81.82712155003702, 88.29711821771438, 61.7598246758984, 0.24759102162093888, 3.212646217115464, 0.5362156430079091, 0.3519286269382123, 39.75704992971113, 95.44855610016855, 71.53312775396532, 72.05541487663024, 45.33800609650151, 45.383564426052956, 87.94815278822377, 7.26380104018796, 0.39981267685371064, 0.3215329853757736, 0.12190161122670098, 0.1267649825181692, 0.10440358080931249, 0.2632074022004681, 0.1679081481791312, 0.32769864485148464], [0.04175413610233415, 0.015197470295994032, 0.045780590810482545, 0.10384834326443174, 0.03675221014888056, 0.059979490395034515, 0.1162798511945913, 0.14634179251809276, 0.3499202814794356, 13.529185306641365, 70.9889930294406, 38.802862782632154, 58.60151260129867, 59.17686154765468, 55.79856334194061, 89.6268173956102, 31.11059085015328, 0.4280850904122476, 0.15342828967878896, 2.737797219907084, 15.360170256706978, 88.65200642616519, 84.7062510828818, 81.82870618758663, 73.85535916974469, 74.21839021867322, 71.99661854774722, 75.34390649487896, 80.29397687604352, 81.76728971542852, 78.5811484244562, 79.7282063576483, 76.27967419162874, 68.58395253458332, 62.53960755563552, 57.47251718275009, 56.85962330910468, 60.18979011043426, 57.977683159612845, 56.90140439618019, 54.539670790395434, 56.646972010212565, 55.6766168532833, 53.287528637916814, 55.148465787210775, 54.58423283792312, 54.11326208422261, 54.40106207324613, 53.33654649796025, 48.824753915109945, 46.94194562973515, 49.348409944965, 48.819588153593, 47.95161470290154, 50.61481775776033, 53.773451466714185, 58.08174756265456, 55.54637455171155, 55.424514355198035, 54.144150749329604, 52.58072537760581, 48.13397353695285, 49.14933396923927, 50.67531639529813, 51.30960679823353, 50.47509508748209, 49.96488494257773, 46.3316209085526, 45.26181797827444, 44.20602967662197, 44.2210719662328, 47.689973000557195, 46.37364910494897, 50.26671524970762, 52.28413535702614, 51.38589689808508, 49.67210746580555, 54.27230242759951, 58.78868026118125, 60.07415863775439, 61.196442880938136, 60.62432988997429, 60.93945703198833, 63.0251891382279, 53.689442142363525, 55.95252421594436, 50.307484365278675, 43.89020435271725, 45.51120227383029, 42.86570479792934, 60.511420542194, 57.66849448603969, 41.49860582044048, 42.77838499315324, 54.40430195100846, 58.6970889952875, 55.838732334875296, 54.60852799877044, 55.12843032037058, 57.05796187923801, 58.822487169696444, 57.955094229790475, 58.6704521794473, 54.798174596601925, 52.87487960630848, 49.96752862007388, 50.59849677547332, 47.649219574466834, 46.19285921896658, 43.821515806259654, 44.70840292592203, 45.54505625078755, 46.626720428466804, 48.50285283980831, 51.90947448053668, 47.794123695742705, 54.317158652890114, 49.5541343381328, 46.180127205387244, 46.10394300953035, 47.940996846845074, 48.21379376995949, 51.60311775822794, 46.27114972760601, 44.39557037045879, 46.0417499080781, 43.50291736664311, 41.479217544678725, 47.9413616272711, 49.561088700448316, 49.89609441449566, 50.036385828448886, 48.96431184584095, 49.724043569257184, 50.76256559741113, 50.94874482001028, 50.9704198375825, 49.44650057823428, 51.32512369463521, 49.5192095541185, 50.65337857892437, 49.5246930276194, 51.691606429315385, 51.50263840152372, 50.857961562372026, 52.922281449840916, 57.62059450149537, 56.86920958180582, 62.96375305421891, 58.99672669749106, 67.46386481869605, 64.56430365962368, 78.83603188299364, 73.61679277112408, 91.06878265257805, 58.838031522689334, 0.21789751496286164, 0.43565790018727707, 0.1666729539752968, 0.17490993133716046, 15.737548355133304, 79.47211480909779, 60.97708432905136, 55.374237414329286, 33.01897102786649, 29.23919862316501, 67.03187065739786, 7.228683079442671, 0.31190086997324423, 0.0737031128618025, 0.015228677845199504, 0.053655193262403054, 0.017071459254610444, 0.025310275227492376, 0.06750792069661041, 0.047904646189342585, 0.0500461109162819, 0.03623752929871121, 0.09458473147523981, 0.08929628863810532, 0.030283438409828854, 0.11682072459089181, 0.09865434374660255, 0.23088901784391175, 0.544924162808926, 20.055470928069084, 80.87618997020107, 48.49504732316541, 57.72160730054302, 58.668879309008204, 66.37253592091223, 93.13633457306894, 35.4334605124689, 0.6217301156251662, 0.40151121635590836, 4.532984168298783, 20.3705451180858, 93.39775270031345, 87.71723501143917, 84.64157904348066, 76.57086310848113, 76.7197641249626, 76.97589489721483, 78.0136755974062, 81.18163278025966, 83.01505058042466, 79.58583216513358, 81.42662402122252, 78.50371299251434, 70.85770345503285, 64.63339228783884, 58.91075618805424, 59.37461176226216, 60.557222058696134, 61.07349618788689, 59.745840564850845, 58.812002674225845, 57.854795302114184, 59.90146844617782, 56.02526849316013, 58.21289593173612, 55.972214514209384, 55.58413520936043, 55.45154733042563, 55.8665733183584, 51.35334514802503, 52.13774073508478, 50.851066035609094, 52.05538272857667, 50.35086970175467, 53.691544532775886, 55.237676174409934, 59.71522254328574, 55.39644587424494, 56.16736419739262, 55.805855028090946, 53.71567495407597, 48.77275113136538, 50.27903541441887, 51.168401472030155, 52.523611745526715, 51.44912550526281, 52.959277245306204, 48.8825108158973, 48.76763636066068, 45.54964150151899, 46.14378644574074, 49.867523870160504, 49.1506754198382, 51.77387422130954, 54.86303883214151, 53.545287193790564, 51.76214241212415, 55.93632090476252, 60.24061226075696, 59.22299254325129, 64.11497262216383, 64.20866627846995, 65.94406404802876, 64.29288741080993, 54.42106223875477, 55.727878309065304, 52.6690806881074, 46.640609541246974, 48.20894179805633, 48.58212394099082, 58.58079856441867, 59.11352311411212, 46.36365490574991, 50.25811349191974, 56.14336321430822, 58.515663685337195, 58.93443161441434, 58.48478286497055, 57.67997526353406, 59.009521468993164, 63.138035728085434, 57.438310192477324, 59.8562042943893, 56.97134417872275, 53.32898416826802, 51.41566376532278, 53.390679128708385, 49.353356053752286, 48.022609603020456, 46.985707513747684, 47.45602715399958, 48.62262241301998, 48.545045775751916, 49.10647423036637, 51.876714844857496, 48.89194019379155, 52.583867196113836, 49.74578134475216, 47.41587777291575, 45.62053049764326, 49.122265692680116, 50.24789571762086, 53.78129228468865, 48.823377163179465, 48.22262694758754, 47.94936326242263, 45.86994617216049, 45.25297695590604, 51.352599897692286, 53.57836846382388, 52.960971709220644, 52.025878660140506, 51.95362860156644, 52.90481905783377, 52.79401602283601, 52.45030264700613, 52.99160542026643, 52.80995653521631, 52.60446356188867, 52.9943863807186, 54.544695346586174, 51.57436286249469, 54.398324258865856, 54.435782894011474, 53.96280780915291, 53.9793445217994, 59.34546855188186, 58.46581428281723, 65.913681368674, 60.14778544825893, 68.42547309014105, 66.68090481911936, 82.09336419259348, 76.50397100756246, 93.75189565843152, 61.29378041913433, 0.3036018701330308, 2.0150722010481745, 0.3498470434738744, 0.14330998423599428, 15.649569592168255, 85.95179188636043, 66.42590368947675, 64.42488693421888, 35.43458231033818, 38.651396536058, 80.83207115050286, 14.031517371054619, 0.26561527783351563, 0.12824717112967085, 0.11646262445156613, 0.017970888612551555, 0.014394590999149989, 0.03760098960370787, 0.010826280809968952, 0.07756209691926357, 0.15618625217147414, 0.1046488285365124, 0.1574093268643464, 0.15656114495810003, 0.16610511428406163, 0.2618040823407712, 0.21872167235180257, 0.33078236325133237, 0.7068766821776667, 21.341416066692723, 97.16471856640231, 50.55745701636038, 73.04567998455417, 79.01664133994811, 72.10538587262555, 101.9910381686303, 40.36458584570116, 0.7943864154719538, 1.1038196855975737, 7.564363931455921, 23.308763196391446, 97.8317960616081, 91.26758406239172, 88.30998359187957, 80.920348013601, 81.04216898641279, 82.50233404098019, 80.45512353220295, 87.08426644725185, 84.8794472602106, 82.99690569600752, 84.76753419445407, 81.39676693947085, 73.95889405281314, 68.00120599808233, 62.84022585038216, 62.713835316319624, 65.13352586377052, 65.19813906761908, 63.453770837476185, 61.4643721426687, 61.163585186004646, 62.82929812708209, 58.01345909795454, 60.4224572643157, 58.66165038078063, 59.07147138349472, 58.01869938450476, 59.991761407544544, 55.97359518851004, 54.98957449390043, 54.68139779183173, 55.12643383395288, 52.137791725897024, 56.95915737459737, 57.16811772315734, 60.974307290969364, 55.74658801478725, 55.712224129707586, 54.87551196928948, 53.932440819278845, 51.168989827556, 51.57261740776801, 51.208213529279156, 53.221507303176395, 53.82844309653006, 55.30898878651281, 51.74177746618948, 52.478127941008545, 49.416361085830204, 49.01543994103709, 52.42599179667812, 51.85409845844392, 55.15202337695707, 58.76014894054782, 55.76920832357099, 55.0555173812374, 59.539123812029445, 61.80193916443856, 63.48575384386125, 66.67801795467254, 65.70309323649253, 67.4670890069777, 66.31448484236195, 54.507009213970555, 55.38082699621878, 53.84703120877666, 47.72636867338612, 54.55734106802172, 56.21109862481394, 61.31232538530904, 56.12454368222145, 48.337815192437944, 52.299209025598344, 60.44267316018382, 64.26132802040347, 61.41773123894969, 61.87770758905719, 60.3934552592616, 62.8028731192312, 63.51188075157904, 61.74240150759297, 63.53324590190765, 57.37238691699121, 56.498020002918864, 54.33492698977071, 58.056212932832786, 52.827022767836056, 51.012475490570075, 49.62492135263259, 50.40377855300904, 51.35812651726508, 51.117967636354514, 50.38534341319915, 53.98766386893488, 49.34963764682893, 53.675286308411636, 50.684012289970156, 48.286126198307166, 46.8571126076483, 50.295073986053474, 50.30016130016696, 56.515294121157744, 50.794831014448604, 51.06224252331642, 51.415534327107096, 49.70215674369566, 48.03005818397769, 53.62504466887444, 55.69315748829996, 55.305921493038056, 53.22048356456142, 53.15496037083288, 55.41915247517248, 55.633623753824544, 55.81918324193647, 56.770554127231726, 56.00322477279171, 57.03962479868243, 55.48220065332229, 55.69565603809973, 55.38790295200964, 58.46300586577385, 57.15217328840687, 56.98349175914642, 57.76309028748543, 62.82287720711001, 64.50366773912984, 69.83661636229485, 65.85721492767334, 73.44144713494086, 70.18001987088111, 85.92587286426176, 79.2278060605449, 97.17508146839758, 63.880065794914, 0.777873482194639, 1.8664934317911825, 0.4520074422321012, 0.29931744680769984, 21.882875734759917, 94.87731779775312, 74.1226137838056, 76.28983313037504, 51.420386299010254, 42.939202170218195, 91.95475978236045, 16.600735533622004, 0.6645470761483716, 0.5554893120161949, 0.2272459173635129, 0.2016771966291051, 0.15515290681392918, 0.19954566423210407, 0.13818206746251355, 0.15610169138639204], [0.05836428210680043, 0.10905517475499261, 0.06287659360696712, 0.04536412626264557, 0.027295450356999235, 0.05822547463580005, 0.06498083412166565, 0.19720831465336586, 0.20698641577074606, 26.212666419244584, 69.91053735056232, 31.483461164659072, 32.52380513375805, 49.64436061920659, 56.23196955650084, 86.41719679678641, 25.192191216253466, 0.4204122295543071, 0.3326335074680467, 1.079595004839282, 34.093433733909364, 90.91852449601697, 80.77329835584088, 75.91364645188855, 69.03945738269438, 71.26472780781408, 71.95813225161645, 76.97576938136932, 79.99054231951314, 79.65520320400115, 76.26309825528052, 73.48450691469255, 62.96267048005135, 58.713037352408136, 56.33276270281885, 58.727640336559666, 56.93801972173876, 59.1011715704395, 55.71598176033267, 57.29668909503568, 55.282477486518125, 54.848663345459975, 52.4310241976092, 55.154541538607695, 51.1826200639048, 53.92909503752186, 52.999658046230195, 54.51718384219755, 51.605906563420454, 49.493055189809496, 45.87760656110702, 47.70514080601354, 48.71291145201653, 48.69356239995649, 50.23546572654478, 54.19991900843959, 56.79498264866491, 54.02554612005911, 52.570229115024695, 52.80853271484376, 53.67952246819773, 52.11282583975023, 51.2544818078318, 50.688593618331424, 53.94560821594731, 51.38942703124016, 48.569505676146484, 45.84031658787882, 47.388891866130216, 43.4787045755694, 47.7931038794979, 46.47953741012081, 47.255252791989236, 47.127583565250525, 48.91757680523781, 49.48537126664193, 49.29427731421686, 51.886901240195, 50.573017058833955, 53.07719545979654, 52.94901240256525, 60.24756662307247, 59.81224236949798, 62.96525139962474, 61.23572541821388, 59.304632756017874, 46.39820314222767, 47.97724739197762, 43.72267992265763, 47.5618330893978, 40.293971415488954, 59.59014208086076, 58.22960915104036, 46.68552852446034, 53.58975510443411, 56.345126013601984, 58.144105403654045, 53.55634827767649, 55.33913220128706, 55.1108031888162, 54.921133056763686, 54.55454049571868, 51.46576419953377, 50.27654470935945, 49.685227794031945, 45.55285000031995, 49.81934147496378, 44.593995232735914, 43.239965592661214, 42.038453394366854, 42.308335996443226, 47.004213256220666, 43.52889130192418, 49.77830171585084, 50.81680413215391, 49.33145353871007, 47.79211936458465, 44.30904680682767, 46.77050667424356, 46.14939543508714, 47.89400292981056, 47.536600482079294, 51.63631277699625, 46.40876608510172, 45.6757104012274, 44.94785578020158, 45.44317268556165, 43.68370333025533, 47.92824129904471, 50.20423189286263, 48.17275401084654, 45.95706985842797, 51.65611682399627, 48.59015695510372, 52.73032065360777, 49.646843479525664, 51.591052547577895, 49.085132614258804, 51.423649710993615, 51.590111178736535, 51.772705354998195, 49.29977255482828, 52.88779597128592, 49.14629413235573, 52.04507866213399, 51.44866658795265, 54.389185136364354, 53.06447521332772, 58.1989715176244, 54.143276060781176, 63.37063227930377, 69.4206960739628, 80.62872763602965, 70.67418359941053, 94.4441233911822, 46.38230969828945, 0.1289219796777733, 1.3905242301764027, 0.4291586247423003, 0.12994063146893056, 2.19329918584516, 67.21320183046403, 67.24577319237494, 56.0089082871714, 40.29597966901718, 25.403477530325613, 61.19633305457331, 17.53899197424612, 0.34832850399036563, 0.07132128421818057, 0.029170996389321746, 0.05802318911939379, 0.024956493908839843, 0.08080073361915928, 0.00599592982325703, 0.022437100771874673, 0.0652541513104112, 0.04241299469985309, 0.008369249145260022, 0.04697071223129188, 0.025008032473945813, 0.10092928014214962, 0.04438474030804731, 0.22403055441475686, 0.18350742967619052, 33.36133118598692, 78.00250468715545, 43.505921902195105, 37.44659346918906, 53.46775370259439, 63.43195853694793, 90.711407661438, 25.807365948154082, 0.5808626343646358, 1.2482289753613935, 1.6335612727749733, 42.77823986545686, 94.27504570253434, 86.28206329960977, 78.07883401070872, 72.80796081789079, 74.06049128501647, 75.60950586872717, 78.49387568812217, 80.65233245972665, 79.49150700722971, 79.5873462000201, 73.88451806960568, 65.5001929498488, 60.817792953983435, 59.384943285296046, 60.3655005270435, 60.8904666285361, 59.75484240439631, 58.38607641958422, 57.989611087306855, 57.17927686629757, 57.17230681450137, 56.95254033611667, 54.812781503123624, 54.20737543413716, 55.89536351542319, 54.43537888988372, 57.157962706781205, 52.84050003174813, 53.09187689135152, 49.41057951219621, 49.93800886215703, 52.08381991232596, 50.228236798317205, 51.74457803849251, 56.684481636170425, 57.89238337547549, 54.87121305158062, 53.72453166592506, 53.47990128301806, 52.16504435385428, 52.42231653582666, 52.210618372886415, 50.08412107344597, 54.86640814811953, 53.363010729512865, 50.25555610656739, 47.71249917245681, 48.132788981160815, 46.45836445593065, 49.42477849221999, 50.13128757476807, 49.83599193634526, 49.66536883384951, 50.973522432388805, 50.46190807896276, 51.50985948501095, 53.0854049805672, 51.77046960399997, 52.847171983411236, 55.55648642201578, 60.61231567013649, 61.95581766866869, 65.60634013145201, 63.04776237856958, 58.329307956080285, 50.52433260025517, 50.20434564159763, 46.770843998078384, 51.49115762402935, 45.08552312850953, 57.0856342008037, 58.39563131332398, 51.14281192902596, 57.7319819696488, 58.98154320255403, 59.79639599400183, 55.128547991475756, 59.50607392095751, 55.920247031796364, 58.455012075362674, 56.77870873481997, 52.22446041722452, 51.87437318986463, 51.91865674911007, 48.55288267135621, 51.67640332252749, 46.56358203580303, 44.41527243583433, 44.49687734726937, 44.73231369449247, 48.96253501215289, 46.937783994982325, 50.12436066904376, 51.69681925927439, 49.77873709893996, 49.360094685708326, 45.734173328645774, 47.880105972290046, 46.901917842126664, 46.94524434305007, 49.27767784364762, 54.575952714489354, 49.24138023007301, 48.09102358356599, 47.05829881852674, 48.615338571609996, 46.862141086209206, 51.75863189081992, 51.25388560756561, 50.602399533794774, 51.35126236946353, 53.405282112859915, 51.32572773964175, 55.39806189075593, 51.36960337238928, 53.44428616185343, 50.82797896477484, 54.42139171784925, 53.93359007373933, 54.45212741051951, 54.50448712994976, 55.50804907275785, 52.36253569203039, 54.28170042653238, 55.02160456872756, 57.67514682585194, 56.14279839300341, 59.35858888010825, 56.99360362945065, 66.25939907566195, 72.73987631643973, 84.6863332871468, 74.04252682962726, 94.13121238831552, 48.3848326436935, 0.35180543999998803, 2.1507377922534943, 0.5406414861640623, 0.0939723744147247, 2.4723513087918683, 70.09810509220247, 73.45584223347326, 63.46669112482379, 44.28835238179853, 31.85767096857871, 69.7885202592419, 28.542044393477905, 0.43934434592243166, 0.10967657931389348, 0.07934820793208577, 0.059488554440078244, 0.04774286374149304, 0.06642088023645264, 0.01820366634356399, 0.05288713649215718, 0.22971989106266733, 0.2233233173648196, 0.1387216078658258, 0.1144869909471562, 0.14612045439500965, 0.16753679471871546, 0.20456092011544014, 0.44927995471704396, 0.28376724090306993, 37.2108825560539, 92.13690680842247, 40.64607866348759, 42.448647022247314, 69.19168456908196, 69.93080815961285, 98.92906342783283, 29.984080253108857, 0.8992232802894808, 3.308995072880099, 3.799502662112636, 44.538568219830914, 99.42099140536402, 87.93681713842577, 82.64451995972665, 77.32328353389617, 77.84975190316477, 78.787214063829, 80.32919191545056, 86.75197109099358, 85.09577381995418, 83.67493444873442, 79.03473131118282, 70.17845876755254, 64.20901144704511, 63.02267882131762, 63.58297763332244, 65.76772212982178, 63.61963610495291, 62.02665567398072, 61.93350330475838, 61.60140406700873, 60.329516703082675, 58.78569533748012, 58.62647064270512, 56.59253343459099, 57.58024507953275, 58.07104341445431, 60.09385678075976, 55.61188597832957, 55.93486570542859, 53.73901697897143, 53.472884162779785, 55.8387597914665, 54.560067115291474, 54.149073323895855, 59.958687982251575, 61.12442816457441, 55.39457098130257, 53.647562996033706, 53.94314496747909, 53.86764718640236, 53.29762481874036, 51.88313968719975, 51.41545980207382, 56.61627946361419, 53.89513907894012, 52.952142453962765, 50.79952216917469, 51.522273786606334, 51.18280049293272, 53.658031802023615, 52.94855348525509, 52.51550812875071, 51.67122187152986, 53.538230849850564, 54.172976247725956, 53.063549533967056, 56.082374280498875, 55.68752104236234, 58.10294797343593, 58.66013634589411, 66.75477089420443, 63.150732440333215, 69.31565500074818, 64.19473401961788, 59.94584221993724, 52.77217626571656, 52.10775421511743, 50.31936130216045, 53.364634590764204, 50.30242843012656, 62.013774610334835, 57.86787640663886, 52.16402453760947, 59.9791431427002, 62.460709079619384, 62.73462780060307, 58.45673007349814, 60.33376070760912, 59.533059827743045, 62.81328308966852, 59.169008962569706, 54.1150349955405, 56.23265204891082, 55.54001638966223, 50.849406873026204, 54.65317633844192, 49.65258190708776, 48.587211255104314, 46.75156162631127, 46.65369064577165, 51.52460367448869, 47.763690025575706, 51.74346408536358, 50.851524952919256, 49.66940103038665, 53.11657997869676, 46.93826252414335, 49.463209875168346, 46.926926874345355, 48.12048450593026, 50.839385217235936, 57.87931011569116, 52.93692758006435, 52.35989593690442, 50.45371032530262, 53.704347149018325, 50.28333040975755, 53.999070121395974, 54.14390756237892, 53.64798661201231, 52.88708209991456, 56.69165957358576, 55.68424978563863, 60.34635151586225, 53.07511268123504, 56.58762654950542, 53.80509322689426, 58.75564213721984, 57.82459305178735, 57.23542951768445, 56.163477128551854, 59.75152015686036, 53.32896063404699, 60.006384003546934, 58.43981289094495, 60.77861239833217, 60.043603374112045, 64.32266996752831, 58.85699226010231, 69.08425085006222, 73.78311695591097, 87.93414208196825, 75.21964580781999, 100.26118663049515, 52.816879518570445, 0.3739091297311168, 4.068523813639918, 1.5707921957777393, 0.20801602261922053, 6.11858367919922, 84.0684501586422, 80.04446706464215, 72.83046737793954, 59.49456176450176, 36.83267977929885, 78.34477855313209, 34.28033467262022, 0.45752995557362036, 0.3467349798208283, 0.2702136746337337, 0.31297409786812724, 0.17990415044609578, 0.1950772419091194, 0.132901637905067, 0.1783119592695467], [0.055312632147463105, 0.06257879224816157, 0.1395382116278333, 0.04980164076832514, 0.05609624050257187, 0.01701209510135795, 0.04880725864260908, 0.33903046420985655, 0.10700715360261741, 34.64222431182861, 62.88723937926754, 39.957683086395264, 45.11183438762542, 49.55281249938473, 60.70019245147706, 86.98338308641988, 15.19662703237226, 0.683592205807086, 0.9924805116268897, 10.027061796957447, 72.86956556381719, 81.02112939280849, 85.29404963216474, 73.95990602431759, 70.4661097065095, 69.32065994508805, 74.26280713850453, 75.69022824687343, 75.73565713820919, 74.04095788155833, 68.59443310768374, 59.799023982017275, 58.55977858266523, 57.47396061497351, 58.21832056968444, 58.78584438754667, 57.574373291384795, 54.985083380053126, 57.64422678178357, 57.02310769788681, 56.19527186116865, 55.23843711422336, 53.75893085233627, 50.86313909099948, 53.58216924052085, 51.88727778773154, 53.00530233690816, 51.79854200732324, 52.18754306916268, 49.51214536543816, 47.265023416088475, 46.88554586902742, 50.38273895940473, 49.234480780939904, 50.300545692443855, 51.775807949804495, 54.39475097963887, 52.71536465614073, 54.47080181490991, 52.15987466996717, 51.62609500269736, 52.951377591779156, 50.23393600217758, 48.0128272118107, 47.99738091807212, 48.691805178119296, 50.16912275745023, 43.42186943177254, 45.42152904695081, 44.54141978294619, 45.155078518775206, 45.75566791719007, 47.5808055939213, 47.49545874134187, 46.796410006861535, 48.619496283992646, 50.71031962671588, 52.265759052768836, 53.080596154735936, 48.570078342191636, 51.43487161205661, 53.4999289051179, 62.30572446700066, 59.58468606395107, 60.968941488573634, 53.79386740346109, 47.26845548998925, 49.47275692416776, 48.157142977560724, 49.29996082859655, 41.014601030657374, 30.59077285951184, 53.90729450410413, 57.76935431265063, 55.99862383257959, 57.792610045402284, 55.134788482419914, 53.31556573990853, 53.23396475084367, 49.89838900104646, 51.18525197429042, 48.67891234736289, 50.3794990816424, 48.14219482483403, 46.13039939634262, 46.4202586297066, 46.040906598491055, 44.533841763773275, 43.56727561643047, 45.018266247164824, 44.79376939035232, 47.99147382859261, 50.013942026322894, 47.14923504860171, 48.374701161538404, 49.90355868493357, 46.23318902907833, 45.014681200827326, 46.819759876497336, 43.80278256631667, 50.53588790278281, 46.010351334848714, 50.89360806249803, 47.51059909020701, 45.204139524890536, 44.284924230267926, 43.40605443523776, 43.02173668338407, 49.43143083203224, 52.14177293162192, 49.22017589692147, 47.53450593640728, 49.983222023133315, 49.749535053007065, 50.70337703151088, 51.802225112915046, 50.11040095360049, 50.47372225792178, 49.87357608733639, 49.158743735282656, 50.22086666476343, 50.44334742330736, 50.96722310589206, 50.543760099718654, 52.424717026372115, 51.696579994693884, 54.93797571428361, 54.441238910921165, 57.26394122646701, 59.97675834163543, 72.20985427979501, 72.91175457739061, 80.89336995155581, 75.52982684104674, 95.60782001864527, 29.608164218164262, 0.797072442308549, 1.0417432746579571, 1.2194592481659305, 0.3227618210498364, 0.6337484416942443, 44.62674702367475, 73.03068868575558, 54.572630466953406, 44.599090391589755, 25.835081415791667, 55.53843175211261, 31.990400052839714, 0.1997645508738295, 0.14237135798940737, 0.07455705574923947, 0.08704254223454384, 0.08824684011239199, 0.01036760769033384, 0.07970371869422736, 0.03069253510705406, 0.005796995462714545, 0.02517412608158925, 0.1272791883938255, 0.08676308868152481, 0.026272699995447072, 0.07297958112171582, 0.05609026118632286, 0.4425305975300651, 0.14136082673024747, 44.914754898317405, 66.5352201461792, 48.210750010705766, 36.97381450283912, 53.884772254574685, 66.7675813551872, 94.45607877546742, 15.649888284744756, 0.5083673663677708, 0.4880755971516333, 16.008983235205374, 82.07448974732431, 83.06320944140035, 91.86465509476201, 75.41225771750175, 75.30751474442022, 70.94240311653384, 77.54054361774077, 78.45126305857013, 79.22947699023833, 77.25942734749087, 72.71528305545931, 61.20964950130832, 59.610079488446644, 58.32689177605414, 60.77818878235356, 61.36021752511302, 60.01172627172163, 56.817622569299516, 61.05346464341687, 60.37691462424494, 58.57076121914772, 56.74592556491975, 56.55822838506391, 52.650437662678385, 54.14273085132722, 55.80054021650746, 57.74944828402612, 53.53071166623024, 55.80902430319018, 51.084184262060354, 50.79769042230422, 48.728036111400975, 52.96559618365381, 52.71678847651328, 54.14992055585308, 53.71704778363628, 54.45928965845416, 53.407776740289506, 55.03089666366578, 53.4609797693068, 55.65190199882754, 52.654395334182254, 51.7505871095965, 50.00904298597767, 46.83765765159361, 49.335705387976866, 51.334294196098085, 46.35317825501966, 48.640551567077644, 47.21267546376875, 47.323090184119444, 47.49253265319332, 50.59370756149293, 51.04294053969845, 49.83931810625138, 51.46886679434007, 52.34539493437737, 54.15672979047222, 55.796158929024976, 51.37310997132332, 55.14728515378891, 56.35937598443801, 63.65838127751505, 61.43917091431157, 62.74991327716459, 52.65408546693864, 53.20621005950436, 52.125275442677165, 50.07113018343526, 49.59557417900332, 47.817889336616766, 33.432294707144464, 50.627157534322436, 59.61328014250725, 58.977785571928955, 60.79813795704996, 58.609977076130534, 56.20936101482761, 55.897658101974, 52.51752422701929, 52.69068902538669, 50.529015910240915, 53.03411214582382, 49.460413225235484, 48.101339417119185, 50.0908753948827, 47.78007768815564, 47.677386114674235, 48.02898737692064, 47.79364908895185, 46.88348662468695, 49.5954212065666, 49.163007351659964, 47.03442335128785, 46.5155839920044, 51.73497215394051, 47.61694239031884, 45.424004062529534, 47.8390936697683, 44.86561544479863, 51.089314722245746, 46.669540943637976, 54.06558567477811, 48.99258036767283, 48.69096186853225, 46.45686218815465, 46.97637619510774, 46.25239295344199, 51.203577287735484, 53.45549629580591, 53.13153989853398, 51.09890491731706, 53.26556728732202, 52.9377983462426, 53.58982178472704, 53.732752953806234, 52.759510932430146, 53.94509830782491, 52.873345959571104, 52.532060530877885, 52.67601936094223, 53.59268511495283, 52.08789525493499, 54.030582443360366, 53.87840232541485, 54.59409367653632, 57.6989830693891, 56.59235692793324, 58.98508510281963, 63.604060372998646, 75.98441385453748, 76.60498772898029, 86.04855675851145, 78.5955592124693, 96.53214223923223, 29.329495506901896, 0.7833413887889155, 1.4180573076009753, 1.3633007748473076, 0.2452704493677424, 1.0099785726877952, 46.963530432793405, 80.18485653784968, 62.519077870153616, 46.037698099690104, 34.511593695609804, 67.93251745162472, 44.134238535358065, 0.038421983049521526, 0.04245332922906645, 0.08307796061759995, 0.050664868641404376, 0.18473957485008627, 0.04184135138207386, 0.05565482447104109, 0.05968992448141498, 0.24080648567647706, 0.12328413946013297, 0.29423227774039395, 0.17520899674104107, 0.17555355244586546, 0.22306206606088147, 0.15144251317026156, 0.5994651490642179, 0.20101070013498107, 52.19789028167725, 78.9785708150556, 51.75114408616097, 57.84859011250158, 70.0657690725019, 73.22711313924482, 105.12981291740172, 18.722176897910334, 0.7276126598158191, 3.1103137856529606, 21.573379155128233, 93.18789020661386, 86.64220748409149, 95.81170482020225, 77.40173878208284, 79.23449762405889, 74.5433742769303, 81.74067251143917, 81.34640370645832, 84.63614263842183, 78.88612839483446, 75.59422431453582, 64.41895631051833, 65.22275978519072, 62.11758013694518, 64.12220939513176, 62.413770075767275, 64.27349521267799, 60.17281801469865, 63.07999641664567, 62.43023618575066, 62.76829350379206, 60.192527924814534, 58.91103467633648, 52.907909885529556, 58.341286874586544, 56.50381726603354, 60.60080351368074, 55.7887181928081, 58.344083524519405, 53.964015899165986, 55.20833684552101, 52.75365091139271, 59.31455243018366, 55.61457280189761, 56.14322985372236, 55.722622333034394, 56.326545746095725, 56.21968861549132, 55.67639327818348, 55.97124568877682, 55.9737560056871, 53.116093604795395, 52.222330570220954, 50.997037041571836, 48.82695828714679, 49.800823965380275, 53.96523967865975, 50.09333864335091, 51.28224434391145, 51.512875787673465, 51.31485885189426, 50.586207989723455, 52.669406244831706, 53.12622116458032, 50.997892118269405, 54.86106980231501, 56.14173543068671, 57.08726198442521, 58.47552214899371, 54.339904477519376, 56.01466632658436, 58.385115438892, 67.03362003449472, 65.74287391478016, 65.23303247267201, 57.852743902514064, 56.3628904281124, 54.51788986882856, 52.84754460857761, 52.22847692428097, 48.550984244192804, 39.65589592533727, 56.67660943923458, 61.12522832808956, 64.57368989144602, 65.84421619292229, 61.64536991427022, 59.100763643941576, 59.09977520665815, 55.09067750746205, 56.32316858537736, 53.72723810134396, 55.43766606238581, 52.048475434703214, 51.041320600817286, 52.357452300287065, 51.992114897697206, 50.328696543170565, 51.29201104564052, 51.56387052228374, 49.938193213555124, 51.92645049864247, 49.583340306435865, 47.081946788295625, 47.389072295158144, 52.23892219604985, 49.98537540435792, 47.609352604035415, 49.29005292154128, 45.38359580501434, 53.78360648309031, 47.732244383904245, 58.16898107528687, 53.79892333861321, 51.658748734381895, 48.95019523559078, 51.14734618894516, 49.58816482174782, 55.044989739694905, 56.830687984343506, 55.41343365946124, 53.4472083276318, 55.83253891237321, 55.88724813153667, 56.02533517345306, 57.68881628590246, 55.00359696726645, 57.149851245264855, 56.40251813396331, 55.23185145470404, 55.73043569441765, 56.87256320830315, 56.40892728682488, 56.79946591777187, 56.614204529793035, 58.10255965878887, 61.25876542060607, 60.19617180670462, 63.668045997619636, 67.14116357987928, 77.46350042281613, 79.9050974076794, 88.02824758714246, 79.51730835822322, 101.10320183538623, 33.40978030235537, 1.003072994851297, 6.496358427309222, 3.207918535317144, 0.41645645794849245, 2.073020439955496, 58.985077258079286, 87.48058272946267, 72.35280113835489, 63.02112556272938, 34.669763272808446, 76.53867613884711, 52.57972517321187, 0.24051521904766562, 0.2740742061888018, 0.22002625879981827, 0.3006229525612247, 0.3539332338879186, 0.15329459201424353, 0.18791985097191027, 0.11627124036632239], [0.029187488347111695, 0.027404790255992163, 0.06922720585979762, 0.06374558629167658, 0.035408089733532364, 0.03534919289391368, 0.028533536542747772, 0.05216286930766317, 0.06201137007484513, 41.45442032044934, 59.44770513042327, 22.746320809087447, 48.42495064581595, 57.17303245298324, 62.111971147598766, 79.75003042528706, 6.929802394682362, 0.23405928885744465, 0.3498106389757126, 4.795383868678924, 49.290704034989886, 92.24937685074346, 76.59387173191195, 73.17491423699164, 69.35483163402927, 71.36760373269358, 70.57708140342467, 74.27799455581173, 74.7766690100393, 67.04316708349413, 58.401883571378654, 58.48445730824625, 60.539708675876746, 63.11952606324227, 66.69350347211285, 68.15526885371055, 68.2580820206673, 68.86444907034598, 65.46777456037461, 67.47434539179649, 63.33654688250635, 60.319408755148615, 57.78728738907845, 55.75616252037787, 52.764041269979174, 55.282140162683305, 52.771560453599506, 52.882951844123106, 52.544306170555856, 48.87163800577964, 47.22416408600346, 46.41688539135841, 50.7731952205781, 50.50684667402699, 48.4331327099954, 50.84101300085745, 52.75086995094053, 51.105969105997396, 50.03348327452137, 53.73017595660303, 50.231268790460405, 52.563349277742454, 54.51147287122665, 54.742551465188306, 50.0187861534857, 47.59778945676742, 46.51370125432169, 47.298736187719534, 47.385702979180124, 46.70128468544253, 46.45581883768882, 43.5207994522587, 46.52968883514405, 45.8406303774926, 45.5468919200282, 49.509835089406664, 54.26298679844026, 56.57332951022733, 54.677530334841826, 54.45407290612498, 54.88919319645051, 58.09664080219885, 62.024380699280776, 60.09696329793623, 55.92174537720219, 44.347160477792066, 45.52509923135081, 49.424060698478456, 52.33260408524544, 51.53017736250355, 49.43819299820931, 31.8132403204518, 30.770140886306766, 54.12766502749536, 50.25439508499638, 57.97794203604422, 55.17097234725953, 53.67941264183291, 48.984100203360285, 47.05522760268181, 45.44689893722535, 45.197028267768125, 49.869712552716656, 47.94066344538043, 44.44255252038279, 44.712388054017104, 42.41494209535661, 42.18413022256667, 46.6753891975649, 46.15649884746921, 47.863212323957875, 46.648418980260054, 47.67760968977406, 48.50624961237754, 51.31740447013609, 50.95498923332461, 51.803335143673806, 47.43468946026218, 45.95475173765614, 49.36369149915634, 47.823984699864546, 50.56902408599854, 47.35818363005116, 47.297771284657145, 46.00397356094853, 44.71573775814426, 41.93372611076602, 44.37788440335182, 47.91688211502568, 50.354191949290616, 49.712339216663, 47.755260852075395, 51.269614311956595, 47.373272988104056, 49.19323313620783, 50.755395504736136, 53.79462834327452, 49.72836209881691, 50.13607678874847, 52.020834492098906, 51.89292992314985, 49.94451215190273, 51.04614903849941, 49.56589752627958, 51.493338461845156, 51.781585601068315, 53.1120417964074, 55.45779174373996, 54.601193166548214, 62.86094773200251, 74.85976049976965, 77.18369422420379, 84.21695109336608, 76.10675258021202, 90.31723299334126, 27.720056810686668, 0.6802706937155416, 0.510550870169555, 0.710120543597206, 0.3949989480597358, 1.0659620718609903, 25.63695073127747, 78.70619358554964, 53.24011894964403, 42.94692923945766, 27.779011995561664, 48.98364913079047, 45.395221710205085, 0.10326841470575142, 0.04799463470736819, 0.06018846385901975, 0.07109406253983898, 0.07552064880127869, 0.006951726015446889, 0.03607874608508522, 0.04432925639013129, 0.007647346778427281, 0.006206156798608361, 0.11088330569046159, 0.15987758554758566, 0.023907999162592238, 0.0485842083130152, 0.08760996057742065, 0.035941941934006835, 0.06840695551927052, 52.74575518023584, 66.97806358337402, 25.827175878709365, 42.66451466468073, 63.564095343312914, 69.44620716956355, 86.47562442287322, 7.538998944144096, 0.3219949363941147, 0.12290578395608934, 4.493117688163634, 58.21987382827267, 94.86317373091175, 81.41735938287552, 78.9831756776379, 73.16313928173435, 72.93028385408464, 73.05599581810736, 76.45510611995574, 76.68558459128104, 69.17961935843192, 60.827583189933534, 61.04832633849114, 63.73521266445037, 65.63028227898383, 68.30134576366794, 71.62542112411992, 71.57273584796538, 70.53832838612219, 69.78392324139996, 69.1840281025056, 64.2871803622092, 63.304607022193174, 61.06062296898135, 57.10198656205208, 56.03223462258616, 58.43131703715171, 52.96543536647674, 53.96355698185583, 53.605526954896995, 52.09466134348224, 50.65135855828562, 49.90901470184327, 52.32610079549974, 52.751932913257235, 51.3926237629306, 52.459284874700735, 53.39122826053251, 52.56735009531821, 51.04844754742038, 54.41962272890153, 51.4014216392271, 52.383532139562796, 56.9738035048208, 55.91870161794848, 51.13204110053278, 49.14154806444722, 49.425378614856356, 50.86120144013436, 48.973545105226584, 49.90931280197636, 47.83016635525612, 47.33989754030782, 49.09100832477693, 48.29567716967676, 49.72360034142771, 54.521894608774495, 56.44198894500733, 58.681462272520996, 57.329468342565725, 55.80349376124721, 57.32644419516287, 62.04878176412275, 64.01943152950656, 62.88605874584567, 58.14898090977823, 43.43109092404766, 48.627180207160215, 51.13167239773659, 52.54549464871807, 54.82819249553066, 53.49679100898005, 37.352256544174686, 30.87967895692395, 53.15530946177822, 53.926294465218824, 62.3052930062817, 59.67009567445325, 55.377194881439216, 52.18906887115971, 49.73957615513956, 46.347102503622736, 45.964977356695364, 52.31972302159956, 50.74957862977059, 44.914111629609145, 46.98336585875481, 46.40434557391752, 45.29025123965356, 48.086489323646795, 48.37533658550632, 49.4018247819716, 46.259676794851984, 48.35072763504521, 48.018742146030554, 53.861575357375614, 49.76310253143311, 51.95995146228422, 47.67119269217215, 46.03655276759979, 50.148420487680745, 48.10188854894331, 50.55225987588206, 50.508352864173155, 50.290845671007716, 47.13597743741928, 45.04844104090045, 45.42439629954677, 46.61751462567238, 49.67855584236884, 52.13894490272769, 53.11879611784413, 49.59799820376981, 51.986760862412, 51.512844408712084, 52.485258809981815, 52.86126898181055, 55.649450517469845, 52.2018793321425, 52.25634144198511, 54.52447160597771, 55.33459401899769, 53.825163995066, 54.86340753493771, 53.261229145911436, 52.957598470872455, 55.12213883861419, 56.514490035272416, 58.95257257646131, 58.01555364362655, 66.4530857147709, 77.28998261113321, 77.86949711461222, 87.06542338094404, 77.81385437134774, 91.80272871448149, 30.45627086393295, 0.5653514376571102, 1.4278339378295408, 0.6082387556952815, 0.2634808649459193, 0.9406834684552686, 27.56111256537899, 84.74321549938571, 58.70880119262203, 49.04626192585115, 35.14207939947806, 56.39014697843983, 59.60204647433374, 0.24118703219198415, 0.1005946146324277, 0.049820421413788875, 0.10587673724418688, 0.12113023729574297, 0.10778581302973533, 0.031301781850596594, 0.061760349875135775, 0.06674030825736062, 0.11512567844962883, 0.2510219923551044, 0.27338126433953164, 0.08992402108326074, 0.1715298594846841, 0.1623512681333288, 0.15753862718420644, 0.2946218181281321, 60.88261012108096, 78.18294940456268, 32.07459765095865, 66.21764152280747, 74.67262421884845, 76.65133445493638, 95.29810966983919, 9.499373570565256, 0.5508886782392379, 1.9631566900399424, 7.635017585369849, 65.61578519882696, 101.14781487372615, 85.44309969871276, 81.54905688378119, 77.8554158056936, 75.3851462948707, 76.72748334946172, 80.31329847151234, 80.18670789657101, 72.89437063278692, 65.53702008339667, 65.8192777633667, 67.1839331042382, 67.62325425301829, 73.13918144472184, 73.74124957669166, 75.60959216087096, 73.5668453093498, 72.7231905537267, 72.94668720614526, 70.6552856199203, 66.99450615913638, 64.26110444530364, 58.59091435709308, 58.62674520861719, 60.45644067948865, 55.1963657717551, 58.43910294194376, 56.56810883552798, 53.996014595031745, 53.67134040401828, 52.59480668652443, 57.62921979350429, 55.15144678854174, 53.672540649291015, 53.98306292872275, 56.616805061217285, 52.7691521183137, 49.41048929768224, 54.770843521241225, 53.87416616562874, 54.4114367423519, 60.11063275798675, 56.620499933919604, 51.35812259489491, 49.43349792111305, 51.655053861679576, 53.98683232645835, 51.53306422695037, 52.13919201204854, 51.07825756072999, 49.871140295459384, 52.50790657535676, 49.96843076521351, 51.66596197312879, 56.32572989309988, 57.39995333456225, 60.27681181507727, 58.6510560589452, 59.13885378068494, 61.61670131068076, 64.7454583260321, 67.2915864759876, 65.74121475219727, 63.12620585964572, 50.775882044146144, 50.915188943186116, 52.21426617714667, 55.72992578629525, 56.83222555345105, 54.33265985981111, 40.54361066510601, 37.129407082834554, 58.64716899010443, 55.70115520108131, 66.07373760592553, 62.696219951875754, 58.1999913338692, 54.30090435089604, 51.89319664432157, 48.55691486789335, 47.86159238507671, 56.167179845994525, 54.13125399620303, 47.57442782002111, 49.9689563628166, 47.66469724716679, 47.69575849656136, 51.39555769581949, 50.200548787270826, 51.172166947395574, 49.376286229779645, 50.5097492279545, 50.002088623662154, 54.70000159355902, 51.46530135985344, 53.35401673470774, 49.25344151835288, 48.32216101308023, 51.39964872790922, 50.96177885609289, 52.413624563524806, 53.94377646907684, 53.144515099064, 51.87314548800069, 48.56811323473531, 48.094283073179184, 49.850155615037494, 53.64297774530227, 53.62336197207051, 55.35615136546474, 51.69541112838253, 56.7896560699709, 54.43814023848503, 54.46333362210182, 54.4149511860263, 58.09147504068191, 55.2054342915935, 54.855582406443936, 56.88230245344101, 58.645968744831706, 58.02397497238652, 57.50293124106623, 56.99764759309831, 57.69859475474204, 58.40504892410771, 59.916043973738155, 62.54047832181377, 60.21258692587576, 71.02827948908653, 81.66181718149494, 80.10662094239267, 91.10262486242479, 80.28803840760263, 95.12550969277659, 32.182174536489676, 0.9158440787465343, 5.574147912763781, 2.6848243849892772, 0.4786238188464796, 1.6848230962791753, 35.69147010003367, 92.71909636835899, 68.58712180968254, 65.94826882885349, 41.59869294012747, 65.22965531195364, 70.8204330936555, 0.3240337415087608, 0.23973740997814366, 0.17051565100348767, 0.20811651803312764, 0.1691097724101236, 0.2225870762260691, 0.12295618488062775, 0.1547232693842342], [0.07912066449681598, 0.048796824525080384, 0.010773965623229744, 0.1027948497944782, 0.027214197156530236, 0.17769787851120197, 0.13514704161113308, 0.08237247790900931, 0.06716305089573707, 53.80708186857162, 53.20062460437898, 50.26876664930775, 47.48414270339474, 53.175529280016505, 67.68859309534874, 76.57035320035874, 4.453426243797425, 0.11841819411323917, 0.3465871861384761, 1.0812819917355816, 47.42077681326097, 88.26672769361927, 76.74868768261325, 77.90192727119693, 69.51644897460938, 70.23450943731493, 70.11625782135995, 72.71180783548664, 61.712697398278024, 60.126400686079464, 55.48551113374772, 63.185496407170454, 68.02248877863731, 71.82721138000488, 74.29785743836435, 78.13661836808728, 71.79228659599059, 74.94040443051246, 71.87195777893066, 69.73766280758765, 67.24804816707488, 65.8384895324707, 59.76247925912181, 60.44912938148745, 53.59991404318041, 52.41592307244578, 51.24493475883238, 52.66488375202302, 53.0413410740514, 48.401098712798095, 45.69932306966474, 46.578781220220755, 49.96528110196514, 49.3980279276448, 51.38017023763349, 50.923465144249704, 51.58339608100153, 48.94412340656404, 51.224361927278586, 55.45490095692297, 52.460069348735196, 52.964745029326416, 59.2174227776066, 56.1253163891454, 51.83557310412007, 52.0069924477608, 54.6617074935667, 54.260888330398075, 55.22748585670225, 54.366839393492675, 55.13094848202121, 53.44325065612794, 52.501862202921224, 48.968983388716175, 48.61289101262247, 55.27182825150029, 59.31424256294005, 59.976715195563536, 59.42462982669954, 58.17283676516626, 59.0890436018667, 60.04293657118275, 60.14680093334567, 58.02824643350417, 45.48343973775064, 40.003833693842736, 46.594078463892785, 48.52000928694203, 45.199311087208415, 51.343492154152166, 50.509384447528475, 38.558028436476185, 28.62892097042453, 38.84908007037255, 52.48443118987545, 52.918253175673954, 57.372292780107074, 54.29460110202913, 53.128409847136474, 45.85839479200302, 46.94968446608513, 47.119527016916585, 46.40724420547486, 43.559728976218935, 43.91483291502922, 44.21282322176042, 44.85621744586576, 42.56988356190343, 47.3629806887719, 46.84762831657164, 49.43942854481359, 44.08008629275907, 43.92163038253785, 46.59360777947211, 51.07726912344656, 45.8675496039852, 48.70167386147284, 45.18776755179129, 45.16790859160885, 46.030382879318736, 46.596074950310495, 52.6373722476344, 49.32125537626205, 49.957232398371545, 45.37471555894422, 44.33749575768748, 43.4647919285682, 45.11816901545371, 49.65116200908538, 50.31360718511766, 49.59765695756482, 48.44456249667753, 47.56919930058141, 50.11259748089699, 48.95694171228717, 51.51613135491648, 49.83892979160432, 51.431082602470156, 50.235332365958925, 51.79099144474153, 52.314894583917436, 52.89846874052479, 51.92243399158601, 51.80506883128997, 51.29401537679857, 54.081302612058586, 51.78535892117409, 55.16962697429042, 52.714850825648156, 60.87176084518433, 72.8313381441178, 79.07469241849839, 76.9152864333122, 81.10239305803853, 75.1484469444521, 67.03253746032715, 0.4304431396866999, 0.20856060388107456, 0.8239128536755039, 0.06677447577878352, 0.4432034372322021, 15.191917246387852, 77.4723885136266, 56.717966910331484, 39.16623900013585, 26.798278247156453, 44.880987213503936, 52.90582318459788, 0.04831872437329543, 0.03422291341027425, 0.1079355908798114, 0.029651511633287997, 0.0486418909032739, 0.020626563045586792, 0.062299802178336736, 0.0492112206355218, 0.0025825223729630275, 0.04234940557169818, 0.0698966134880339, 0.09127505544212558, 0.05772417351122826, 0.11037261615837775, 0.0463724282059458, 0.021543530071334496, 0.1217127092663319, 62.303822117467085, 57.72850282730595, 49.95074872047671, 42.957868729868245, 63.17006972528274, 71.61250083677231, 85.07010582954653, 5.024925874125573, 0.2746972808193776, 0.3350477875961412, 0.9289002394483936, 56.98990483437815, 91.46872320482808, 81.99154730766051, 80.96093670014413, 73.1474341115644, 73.77398567814981, 73.30852585454141, 73.80058719265845, 63.40945982163953, 62.603228399830485, 59.03311452557964, 66.12871354626071, 70.8640733841927, 74.20885101441415, 76.12417574851744, 77.55440527392973, 74.46844916189872, 74.96953979615243, 74.37152739494078, 74.15506747461136, 71.16244808320077, 67.88889285056823, 64.64264908144551, 62.38677240187123, 57.87062206575948, 53.74877975833032, 52.91418960017543, 55.95705455349338, 53.06738953436575, 50.72679358143961, 48.541162629281324, 49.68939335115495, 52.81598129580098, 52.261052208562056, 52.549903392791755, 53.232760583200765, 52.92797673133112, 49.632032609754994, 49.96544584151238, 55.628881608286214, 52.25107762121385, 55.05938483822731, 58.37873374262164, 58.19004420311221, 52.21905539112707, 51.65285733438308, 56.641300262943396, 57.13644066164571, 57.76247447536838, 57.4521836157768, 58.77395568355438, 55.94644846454744, 54.09368553469258, 51.770030298540675, 51.019284725189216, 59.928881891312145, 62.84372460457587, 60.80887740658176, 61.39377340193718, 60.682871264796105, 62.87236575157412, 64.13948351337065, 63.17619254512172, 57.46575893894319, 45.136733593479285, 41.60316444212391, 48.66803953724523, 51.18766423194639, 46.93022951003044, 51.0101338355772, 50.62992672766409, 43.977532002233694, 29.904536547199374, 37.40833859289847, 54.93007606075656, 56.74798480926022, 61.012923025315814, 58.14038699673068, 56.20753319032731, 50.247562316156205, 49.59009070550242, 47.58513589059153, 47.69750002891787, 45.85956365831437, 46.15593794853457, 46.70794094762495, 48.57687973207044, 45.171591697200654, 49.02896819576141, 49.26621667800411, 50.14552577849358, 44.471225046342425, 45.24836817095357, 46.47029238362467, 51.77205816391976, 47.52480591497114, 49.90588857281593, 47.38555392911358, 46.01656436920167, 44.475951502400065, 48.08217863882742, 54.455767370039425, 51.316361119670255, 50.54197934366042, 46.57695731809063, 46.81480984533987, 45.73145512611636, 46.15408266744306, 51.416052079969845, 53.12187517842939, 52.90082216262818, 51.10039934035271, 50.526682099988385, 51.7692889705781, 50.89500442627938, 54.12014584387503, 52.73528637424592, 54.00929181806503, 54.36575289695494, 53.72061714049309, 55.61865206687681, 55.714079410799094, 53.791866994673214, 57.1991515159607, 54.285744390180035, 57.61413435782156, 55.72341072943903, 56.939016003762525, 54.62459794936642, 64.310530231845, 75.02673579800513, 82.02296549274077, 78.28998304182484, 83.12643804857808, 78.52170882686492, 77.57325618497788, 0.7387188509587319, 0.3508927228470003, 0.5985061908441206, 0.057387872403787996, 0.2878698255986937, 16.427088283723403, 83.1405899601598, 65.1475287252857, 45.037662367666925, 29.51438426971436, 55.91907424311484, 68.1211991463938, 1.0652783537103285, 0.13654518271646193, 0.1520482742137486, 0.028856881188168645, 0.04500965354964138, 0.02796433513022719, 0.05956998192555001, 0.0926333906189088, 0.1923271854438128, 0.14134400343943027, 0.18030009532888092, 0.25863284605645365, 0.14559905495374434, 0.2585215488028142, 0.1736967698220284, 0.17588457903794705, 0.21930802072728836, 71.81560900903517, 68.29295189149919, 65.48713537954515, 63.321947820724986, 73.52213813412574, 79.4298630376016, 92.94671150945848, 6.184642766752551, 0.5469707207333657, 0.5699239406854876, 1.2488582706259144, 66.3445301978819, 96.76420534810713, 86.262082745952, 83.81595934590986, 76.47704001395934, 76.74925250391807, 76.08498342575567, 76.6563315545359, 67.76365157096618, 62.593740186383656, 61.09593999001288, 67.30421650794246, 73.07650196936824, 77.23456736533873, 79.39532264586418, 77.92872490421419, 76.30658165101083, 79.6181760295745, 75.82229445057531, 77.40370781190934, 71.8963941451042, 71.3282702046056, 65.4709359907335, 65.92711940888437, 60.30483322758829, 57.061566537426366, 54.968899680722146, 58.70319220327563, 57.5806490836605, 53.505137812706735, 52.12308676012101, 52.801354777428415, 55.93431265123429, 55.279767128729056, 56.50474294539421, 55.08329168442757, 54.69294524961903, 49.81763132156865, 51.56157985810311, 57.828864512905, 53.244598296380815, 54.51606988906861, 60.059347767983716, 57.89150868692706, 52.266402321477095, 52.46845929853378, 58.26067040043493, 60.729488634294086, 61.10694223834623, 58.628212175061634, 59.90794035696215, 58.361451779642415, 57.87653699997933, 56.32442766620267, 52.9236582017714, 60.23348531415386, 65.67328322318293, 63.06826852983045, 62.75658915119787, 63.94369448384931, 63.11000254846389, 65.37532429541311, 66.08191967010498, 62.02926405014531, 51.96310112553259, 46.896618720023866, 52.03257414602464, 54.9868013781886, 50.39485516086702, 57.519997473685976, 52.33598124596381, 44.09711722404727, 34.30757553346696, 43.09995266699022, 58.395984326639486, 61.64308317245976, 64.47030405844411, 61.96427822113038, 59.67135867764873, 52.11030375572943, 52.22961441163094, 51.46421878568588, 51.946297691714385, 50.10872217916673, 48.51110942902104, 48.94451564358127, 50.369634320659024, 47.96772387719924, 52.16311062535932, 50.87432569073093, 52.91935536169237, 44.618007982930834, 45.21281973008187, 50.240380456370694, 55.757009752335094, 48.2541000458502, 51.5538174875321, 49.3525323560161, 46.62013084657731, 45.03838016140846, 48.34172187312957, 56.119064131090724, 52.885144449049434, 54.311859530787316, 50.075997844819106, 51.039865401483354, 49.55790373586839, 50.861636823223485, 55.05578410240912, 55.623119646503085, 55.76334830253355, 53.50674990684756, 53.226288672416445, 54.431134885357274, 53.11014729161417, 55.88078014312252, 55.302105026860396, 56.748541785824685, 57.00962258923439, 55.922922088253884, 58.065093178902906, 58.771123732289965, 57.994529739502944, 59.06643506019347, 57.34689543324133, 60.46575238627773, 59.27112002526561, 62.34708193809756, 58.49799340771091, 68.62407053670576, 78.11955605783771, 85.60798829601657, 81.66046004141532, 86.87555713038292, 81.70744219133931, 75.18487791861259, 0.6177005544304848, 2.7294673314017635, 3.1664426576706672, 0.1363954125272651, 0.8096687051077044, 22.864713630368634, 92.30533338362171, 71.62767256459883, 57.17903760171706, 39.2841415251455, 63.43710468661401, 79.21932589623236, 1.1331229777105394, 0.2837755452961691, 0.343894662876283, 0.15398279944014165, 0.24671067934363122, 0.08631678883947673, 0.14348627638912972, 0.2431767004271669], [0.02924606917546161, 0.01529133904935612, 0.05213948447377451, 0.035291383899147474, 0.06798035945863494, 0.08213191097902675, 0.08363237078752249, 0.06136609804666331, 0.29208422848774546, 56.3997999314339, 47.719316251816295, 36.024502861884336, 39.770966499082505, 58.95629490575483, 66.34888402877316, 77.62191710933563, 3.977994284322185, 0.21529552797155999, 0.6874684268428434, 1.0662528175500132, 45.27757021688646, 86.9340318249118, 78.51677448518815, 75.54922688391902, 69.78464495751166, 69.72932384860131, 65.80551024406188, 61.840911834470695, 58.73301006132557, 62.599788481189364, 65.5157059238803, 72.8418500961796, 73.33358979994252, 76.85211273931688, 76.09762130245086, 77.82860248319565, 82.71663665771484, 77.81238740490329, 71.30081361339938, 71.78256696270358, 70.33176852810767, 68.2958544454267, 61.54406293745964, 61.977955525921246, 55.706199369122906, 54.54197322168658, 50.420421169650176, 52.12096868022796, 51.21002566429877, 48.72066205547702, 45.12886139654344, 46.67543626600697, 48.7346217709203, 47.75723380427207, 47.592953174344956, 47.28961275469872, 49.36797472738451, 48.612949848175056, 50.465191102796986, 53.17336805405156, 53.731768438892985, 52.56767172967234, 57.6358211425043, 56.531693550848196, 57.67166376113892, 60.81570233068159, 61.201953811030236, 60.0622973903533, 62.133916808712875, 63.936312583185014, 60.75267768675282, 59.29915320488715, 59.59952046794277, 58.64379967412641, 56.92840207007624, 58.42821051997524, 57.724219599077784, 60.39070960014098, 61.13969010691489, 55.732067400409335, 58.4140193846918, 61.402449684758345, 55.80326234140704, 49.17485683195053, 42.63699139318159, 33.78739080121441, 46.74033580287811, 46.16820712243357, 46.99571348005726, 46.29452313146284, 48.9902897034922, 42.70439732459284, 35.0719395760567, 29.95329356962635, 46.421929559400006, 49.621897205229736, 55.80332902169997, 54.64512763484832, 55.77706090865597, 49.1345662455405, 45.63806741468368, 42.653347676800145, 44.578874495721635, 43.05370792265862, 42.8309408310921, 41.41727939728768, 44.37335798817296, 42.58440025391118, 47.51859288061819, 51.3121328046245, 49.47314916118499, 51.42903904761038, 43.498363494873054, 42.00615267599783, 44.46019534141787, 44.74557522804507, 43.64600935289937, 47.32029745655675, 48.32778569190733, 51.36442976613199, 54.44883654194494, 51.53117756689749, 48.47780066151773, 45.63874598472349, 45.80728238628757, 43.19349727322979, 42.68513848704677, 42.913691074617454, 46.98211462266984, 47.25220903273552, 49.603536590453125, 49.537699607110795, 48.80796224840226, 49.82804521437615, 50.400546519987046, 51.186781698657626, 51.0820661821673, 53.59608580989223, 51.10663983129686, 59.293842315673835, 55.94832727985998, 56.90782531615227, 52.17182613188221, 55.77566454487463, 52.044227507806596, 54.3606302815099, 53.17505467322565, 57.87798043220275, 53.037399092028224, 58.22580052960304, 61.82225704193116, 79.35385534840246, 72.16823793226673, 85.77020968160322, 74.68716052270706, 96.73898450789913, 30.934786296659905, 0.4075301546723612, 0.23681326769292357, 0.07202154220712763, 0.33600512170983904, 6.980225443840028, 76.97518102584347, 54.38116388936197, 47.760536439957164, 42.14582435546383, 44.20535110658215, 58.342298846091, 2.5941747330850173, 0.14029700639507464, 0.12952455379549535, 0.08518115542228184, 0.04521613339743307, 0.07757167301831708, 0.20519969954846368, 0.06905826048985605, 0.036095492767109986, 0.006437440658168447, 0.01866817034991278, 0.057604862977900816, 0.05521752233166368, 0.012777237664727915, 0.10604545278775115, 0.01062642187706285, 0.8469329990686909, 66.07458483788275, 55.179589794528106, 44.89639820591096, 38.98692392533825, 67.63252673610565, 72.12121655864101, 85.40406427075787, 4.688491436742968, 0.24800397365564303, 0.22249287805489956, 1.0636240940901542, 53.56911167021721, 92.28161088881954, 82.55898875574913, 79.11462214685257, 71.64834345540693, 71.39320112043812, 68.61225635774674, 64.0010787594703, 61.80583800038984, 64.67214138277116, 69.27894946067565, 74.3231253470144, 76.66407431325605, 78.87630677992298, 78.07248761576992, 80.56783676147461, 84.3190739231725, 78.4978686609576, 74.53734167160528, 72.68135455346876, 71.84664280183854, 71.03099376924577, 63.873801769748816, 65.2946803646703, 59.64335687698857, 56.641198281318914, 54.19759304292741, 53.8492787268854, 53.662522915870916, 51.74964574075515, 48.121716130164366, 50.778768908592966, 51.69193198603969, 50.894776928809385, 50.39409422105359, 51.56991489471928, 52.73801634388586, 49.995742228723344, 51.611735205496515, 53.28764630902199, 52.46118722423431, 53.432487672375096, 58.69871285653884, 57.18004565085135, 59.8064451063833, 63.837790489196784, 62.48457670211793, 65.29823010967624, 63.69583599029049, 63.45590460684992, 61.16263989479312, 62.05961535053869, 60.892243462224165, 60.23548572294174, 59.09302088522143, 60.17286900551089, 60.60163505615727, 63.347607966392275, 61.38733679248441, 58.842969786736276, 59.888716820747625, 63.76088457722818, 57.83648960051998, 49.03281211853028, 45.48542445705783, 35.9795799563008, 47.489657555857015, 47.87965097735005, 49.58173997940556, 48.435690095347745, 48.82980592789189, 45.59375247647686, 39.84019633262388, 32.20438495759041, 45.712604215068204, 51.953554076533166, 57.36781343337029, 58.35742350547545, 58.388496521980535, 51.09964232290945, 47.946464630865286, 45.398238012867594, 46.538435720628314, 46.23697019392445, 46.17538113747874, 44.34836856780514, 46.92649933599657, 45.94596955084032, 49.16041466497606, 53.20260147894583, 52.389294101345925, 52.89105153852894, 45.38695727625201, 43.459143715520064, 43.73794578736828, 45.902097840462964, 44.5072441716348, 48.773606208062944, 49.73297480613955, 51.50236383561165, 56.30685152546052, 53.11526206231887, 51.713320670589326, 49.26119604418355, 49.49938197289744, 46.84460416916878, 45.285367888789025, 47.99628265442387, 48.59713485164028, 53.30152757706181, 51.016739106947384, 51.99305234416839, 50.12095212936402, 52.17356374186855, 53.106625003199426, 53.63204217726185, 53.32562269703035, 56.256464758226954, 53.53805826556299, 62.94676134663244, 57.557762053705034, 59.187608841926824, 56.085296446277255, 59.417675464384025, 54.80654493454964, 58.46096231091408, 56.44521313328897, 61.83546366230134, 55.66322195914484, 61.51375870550833, 62.755141796604285, 82.22694443118188, 76.60846294895296, 89.77673822833647, 79.48952228792253, 97.30713982735911, 37.97801971435547, 0.4715311010518382, 0.04124193354659984, 0.059269483937251, 0.37676418620732527, 8.49962221037957, 82.79917117088073, 62.534539853372884, 50.226879658237586, 37.71374610162551, 51.821754594003, 70.46984380291354, 4.666398196451126, 0.3588816409389819, 0.13697201626435404, 0.05979572505419774, 0.10549954619378814, 0.052753040461891124, 0.08311031251064233, 0.006175545840373924, 0.14311401894496334, 0.0866678562916575, 0.12976248538301838, 0.09103837257791912, 0.23330015701151666, 0.20101235488489752, 0.3970074160925804, 0.14906437707043466, 1.2439533467254331, 79.43577012708111, 60.93350287406676, 50.934639976870635, 54.66671636027675, 77.44706569179412, 77.92765801952731, 92.39321800970262, 6.035565733909608, 0.45794211087688325, 0.8020377339374635, 1.718003896455611, 62.7420057788972, 94.28485162796514, 84.80442016355454, 79.33222739927231, 75.69336614301129, 74.947951070724, 73.31442509928058, 67.21571214737432, 63.011617737431685, 68.83286614571848, 72.6906584155175, 78.37987592143398, 79.07986994712584, 81.82665086561634, 83.10945418573196, 82.64306868276289, 82.98336567417269, 79.02457237243652, 77.85958920755695, 72.65426666505876, 75.58507734729399, 74.42558550065564, 67.05305145632836, 67.7589447267594, 62.464807956449455, 59.1112873631139, 57.66962805101949, 56.90096509072089, 56.355712490697066, 52.993829404154134, 50.30948477406656, 53.093363469646825, 53.50123505438528, 54.980321622663936, 53.137411686681936, 52.775698554131296, 55.10823795872351, 51.864767305312625, 52.537230214764996, 55.093909540484034, 52.26890871601721, 55.22717991182881, 61.016366866327104, 59.36010291499477, 61.51104834771926, 64.34945583343506, 66.89457985662645, 66.55478492859872, 67.14146168001237, 65.88811535989085, 65.67750761585852, 64.94109438311669, 64.38767148602393, 64.10305253921017, 61.53856377447806, 62.7430961978051, 65.57902082320183, 63.292569268134336, 64.67349460048061, 60.32975989003336, 61.95913991620464, 67.0877016744306, 61.768995177361276, 54.8123029739626, 51.59770096501997, 40.37110874729772, 50.1342018958061, 51.44774875333233, 54.13576079953102, 52.25542752973495, 49.99937042113274, 45.64600236954228, 41.5579120574459, 33.67448537580429, 49.89738879665252, 53.31080398251934, 59.53501709045903, 61.74561785113428, 62.13642712562316, 51.96301875575897, 50.38374700853902, 47.95328171022477, 49.790610113451564, 48.42029871479158, 47.13423982743294, 44.72213122152513, 50.307856990445046, 49.02033113664197, 52.469730146469615, 54.54708014765094, 51.765166559527, 53.23964826522335, 45.5255542262908, 44.191167816039055, 45.242186515562, 48.02099358650946, 46.90380842454972, 49.79875295392929, 51.34827744576239, 53.865768371089814, 57.81720330638271, 56.50255034046789, 53.62675089989939, 50.96066098059378, 52.76912858409267, 50.8952711474511, 48.99033677193427, 50.616606358558904, 51.70131429549187, 54.46508692156885, 53.469263815110736, 53.40544685240715, 53.439371432027514, 55.81570409959363, 54.42496891944639, 55.81401748041953, 55.46899795532227, 59.12457635325771, 56.07163875333725, 65.54598269924041, 60.079563663851836, 63.50213366170084, 57.507143866631296, 63.05850182810138, 58.10173988342286, 61.33159206759546, 59.26069044297742, 66.63725668384184, 58.57972383499146, 66.16868249831661, 67.32202406852477, 86.0632578019173, 78.37791473634782, 93.12473220209922, 81.03936056936942, 104.154507729315, 34.397597851291785, 1.1761647390742456, 0.6394418845734289, 0.1395553873190957, 0.9832685188420358, 12.106155291680368, 90.73170200470956, 68.21518698046285, 67.82175756269886, 58.221536913225734, 58.770127450266195, 82.49341457120835, 5.295832214816924, 0.480946566789381, 0.4161016060219657, 0.19623896828101528, 0.27932117302571574, 0.26595106949248626, 0.3925604289097171, 0.12213971135356735], [0.05693048343903596, 0.021607688019773173, 0.02667697033874931, 0.030940289856986176, 0.055991661840028344, 0.1642702264531005, 0.04461856566429619, 0.039337278088374485, 1.116200892194625, 56.61465560236285, 58.22183109098866, 32.84842048921893, 30.90752974633248, 59.688770078843646, 71.5117508365262, 72.77161613587411, 1.6688507146412328, 0.22625099897624987, 0.6072417382271059, 0.49155351375379874, 49.90157004325621, 89.71188575990739, 80.48745955190351, 79.1769015404486, 70.79819325477847, 64.7084076173844, 58.84746090058358, 61.360841181970414, 63.94806792659145, 73.75744112076299, 74.77738288141067, 77.7489548344766, 73.8810585391137, 77.67170767630301, 68.95897034675845, 69.40832491843932, 69.57974818445021, 79.72460562183012, 74.26981249163228, 68.28008651733398, 66.00013825201219, 67.16258756576046, 62.53980367414413, 56.68825495627619, 56.94139296008695, 53.613281480727665, 52.40518754528415, 52.059328632970015, 53.22791645603796, 53.51915244133242, 49.83875328494657, 44.78039018569454, 48.01953446480536, 47.31049545349614, 47.62009597593739, 50.009356775591456, 48.903573943722634, 51.115041548205966, 52.6646170308513, 49.02490069789272, 52.40297532850697, 64.57397622446861, 62.61217924856371, 56.85421828300723, 60.05727283416256, 59.530690716158965, 59.17358244619062, 60.73500740912653, 62.165154564765196, 59.88266068120157, 61.88567392287716, 60.78040884387109, 60.766982570771255, 60.81844798980221, 61.975931582912324, 60.0103416750508, 62.08066278888334, 63.31865695215041, 57.47547464986002, 54.60457424963675, 54.351083232510476, 49.25942313286566, 42.72864149462792, 46.0896538149926, 34.14400877491121, 36.551594888010335, 44.617133294382405, 45.1623192141133, 46.08671988210371, 47.29353512487104, 48.89025749698762, 43.477594544810636, 40.2197797836796, 34.16600542683756, 40.76325555001536, 46.6255162608239, 55.37161334868401, 60.886430509628795, 59.48638362269248, 55.150140639274355, 50.584066375609375, 48.527697132479766, 46.83238206371185, 45.82096361344861, 49.04581869802168, 48.92844177061512, 50.63879912899387, 49.93959349970664, 55.82804779852591, 61.436001639212336, 59.668036430112785, 56.902467358496885, 51.94220273725448, 46.017548884114916, 44.351047546632834, 44.35838237885506, 45.78930224141767, 50.32333858551518, 51.71281076246693, 49.025030136108406, 50.50959233314761, 47.32599666041713, 46.13486697596889, 46.424463410531324, 45.078509930641424, 43.38810174695907, 44.72657526693037, 44.310651056228146, 47.000110457020426, 49.14807096604378, 49.888857641527736, 50.210570443061094, 52.40511694262105, 51.99818672672395, 52.81099988568214, 54.765693449204974, 53.98979371593845, 55.493155833213564, 58.92215067340482, 58.75694436411704, 59.4297642092551, 58.35505439389137, 55.33032255788004, 54.8287102483934, 54.29806455489128, 52.7865517523981, 55.775319376299464, 53.461156275964555, 53.82014728361561, 53.48108191643992, 57.17301284113238, 60.46600341796876, 73.56681393038842, 75.11481654259467, 78.83802444704118, 76.9027348487608, 84.72729067648612, 4.152233321820536, 0.2689361464112036, 0.19211687898683935, 0.2615859004999361, 8.519656696627218, 70.49552748280188, 57.317238392368445, 42.733497388901256, 36.1527879007401, 29.60206101017614, 63.16544525084957, 3.69219470408655, 0.23531122974330382, 0.07238778586108839, 0.08736743246235194, 0.05651810597027502, 0.01822292387876059, 0.0302043762208233, 0.07999713803010602, 0.09471135814824412, 0.048252806337850715, 0.037479909407275344, 0.05708124571209473, 0.050473882921881257, 0.05103265596253257, 0.08349836668780736, 0.12478853696055951, 1.866544300029355, 69.27938876613494, 63.2677092859822, 36.952798443455855, 34.072237245498165, 69.4428417759557, 76.0399938398792, 78.99022025446739, 2.038807320979334, 0.2672820706521311, 0.13954311459054872, 0.7543889649452702, 58.31355963983844, 95.28373810552782, 83.095137534603, 84.51377253378593, 73.53527022946265, 68.01550695973059, 61.89624863286173, 64.07509388462191, 67.71676355792631, 76.6305458930231, 77.25354379223239, 77.37425081191525, 77.56955346753521, 76.31070013969176, 72.04481663242464, 72.66575920966365, 72.98321231718987, 83.92505614988266, 74.53815752460112, 69.35116814028832, 69.89272194523966, 68.74800174467026, 65.45845893121535, 59.91349051075598, 60.40340239001859, 54.31368735528762, 52.68955546040689, 54.28922745489306, 53.05782287351547, 54.64814393751083, 50.90367678673037, 49.21462966549782, 50.02662304908999, 51.32724177452826, 49.670232572863185, 51.085859114123934, 50.4231236826989, 54.56076921955232, 53.81009424886396, 48.41984764222176, 55.70045309682047, 65.92013758997764, 62.94626712799073, 58.38486440720097, 60.75866322363577, 62.04120766732001, 62.582651645906516, 63.84541165444159, 63.94642445348925, 63.86801627374465, 64.7029790570659, 64.30450547126033, 60.3063904085467, 61.826438288534845, 64.62347653604323, 62.7661911133797, 63.94428283937516, 67.09374212449598, 60.493001091864805, 57.319274102487874, 55.54383677821006, 49.06406948643346, 42.606510654572524, 45.65565140016618, 34.819880224043324, 39.0546005002914, 46.70634846533499, 47.57092514345723, 48.41852972584386, 48.13782530446207, 49.34311474523237, 43.76344119348834, 42.334913976730846, 36.440811464863444, 41.150844558592766, 48.893446383937714, 55.28533297200357, 64.30828663610643, 61.770211112114694, 58.81257141790083, 52.845642259044034, 52.803261049332164, 47.290624726203184, 47.97467039477441, 49.85983994699294, 53.70193881373252, 54.12919082949239, 53.98605569716423, 60.82042094199889, 64.26242236168154, 62.34671323530136, 58.0149378315095, 54.26152375436599, 46.6567579392464, 43.642679260623076, 45.231239180411066, 46.74334426080027, 51.72125954781809, 54.59854948905207, 48.98652815049695, 50.95612672067458, 49.72012512145504, 48.82972355811827, 49.59402092041508, 47.509336087011526, 46.59290959758144, 45.911170282671534, 46.814633338682114, 50.24548345996488, 50.74396179568384, 51.860707652184274, 52.9815641526253, 55.56067943572999, 55.9174229252723, 54.83048708208146, 58.03518902870917, 56.28939697819372, 60.084882397805494, 61.959116381983605, 59.84425675484442, 63.37487236146004, 59.436989215112504, 59.202066698381984, 57.997275398623565, 57.71789673836001, 56.556616290923095, 58.000946737104854, 57.01140334529262, 57.830527597858065, 56.96410740575483, 59.748605835822325, 64.17132139205933, 75.4711481832689, 77.38084823854508, 84.41276365710844, 81.28006858210411, 94.32475782209828, 7.012663445165081, 0.6600512431994562, 0.2886791821689375, 0.467229885079207, 12.32298783717617, 76.68036783895185, 67.48390813027659, 44.701385805683756, 33.076978960344874, 35.43678668237502, 76.10902755491196, 5.71154510782611, 0.3432350611734775, 0.16058031800052813, 0.07329707094017537, 0.06715834711588199, 0.07153047984766384, 0.06011588085863379, 0.08927654655229661, 0.12347530904075793, 0.1469099846097731, 0.24110602605487072, 0.12009376629946694, 0.20488960247847343, 0.27534330744416485, 0.1908850555698718, 0.2733281897681375, 2.3921018213995042, 80.67310533215924, 73.46144337807932, 42.4923304588564, 44.18805737649241, 79.3360948562622, 82.90809539056595, 87.23006879129719, 2.6608116347943587, 0.4624010796748823, 1.0297013530808112, 0.9170269797886572, 62.5819456192755, 96.69100607595136, 87.24285571805893, 87.18176088025494, 78.00822350286668, 71.06671871677523, 63.409985419242616, 66.13705250524706, 69.78884973833638, 79.49517834571101, 80.2809153833697, 82.47652484524636, 79.83425940236738, 80.75548295051821, 74.12829337581512, 74.71592718555083, 76.17065583505939, 80.50154086082213, 74.89436364942982, 72.81833940936674, 71.81843311555924, 73.4021528305546, 67.69992874514672, 61.34051938210765, 64.32756508550337, 58.406394297076815, 56.695307377846014, 56.96620195142685, 57.22086967960481, 58.38389165939824, 55.69854290254655, 50.57893591542398, 52.42745091838222, 55.20843098240515, 53.58060813719227, 54.82210105465305, 52.51646518707276, 56.81458665478615, 53.919591134594334, 51.74049485114313, 54.37159330614152, 67.73091546950802, 67.41373692789386, 59.12793782449538, 64.92400461627592, 63.48657361922726, 64.71982171458583, 66.495039386134, 67.67666909002489, 64.64321390275033, 67.3130496855705, 68.07741765053042, 62.87231476076188, 66.72454510965656, 66.58585010036346, 64.63068977479013, 68.48902333167293, 69.86626948079756, 63.95020561833536, 59.404645350671586, 57.898525807165335, 50.873439235071984, 44.84563096877068, 50.327217809615604, 39.574498899521366, 43.01785745928365, 49.531231618696644, 51.827595003189586, 54.33591934942431, 52.908290355436264, 50.477813290011504, 46.13337647530341, 42.72094188197967, 37.12354313942694, 45.02047061920167, 50.074860357469134, 60.22121614025485, 67.36589185653195, 64.68890559288764, 61.80119391410582, 56.970461645433986, 54.15725146570514, 48.449285030365, 50.33636085448727, 52.26970495716218, 55.3297185128735, 56.29431170801963, 55.351118964533654, 62.716098523909054, 67.15650004725303, 64.60344499157321, 58.95535745928365, 56.215570126810384, 48.02855983857186, 44.62091838159869, 47.00427209177325, 46.64682257559992, 52.30367660522462, 55.21698174938079, 52.42656838509345, 52.84444201377131, 53.86500350890621, 50.80399367117113, 53.231383831270286, 49.99904094203826, 48.38818627019083, 50.312191209485455, 48.97924430908696, 50.655881051094305, 54.666606533911924, 54.49819564819337, 54.77742525839037, 59.19743830157865, 58.40042052730438, 59.92703837733115, 61.31076428198046, 58.73141365666544, 61.52996593906034, 63.870044139123735, 66.77013874053955, 66.41356391291465, 64.02018070220947, 60.419582166979396, 61.02653757218392, 62.048915124708614, 59.32002021420387, 61.764802163647076, 60.293274002690474, 60.03513105453984, 60.00858445321361, 62.36230857910649, 68.71597166984313, 78.4060851989254, 82.37370383354926, 86.93367096685594, 84.78493382853847, 94.09285945277061, 6.301090582724541, 0.6949049342543848, 0.7446036319578848, 1.0788371293775498, 16.076845142149157, 82.96613862437587, 75.74048165352114, 59.318627772792695, 53.2311406443196, 42.64953905536283, 91.97900787476571, 8.294012546539307, 0.6667990682105864, 0.3455643055419768, 0.2047775084933927, 0.17696252603444362, 0.15890090005292049, 0.1352292275236499, 0.21883581945252037], [0.03755028607443937, 0.1123655402672387, 0.07701996713876724, 0.02277655433112335, 0.05271667809856515, 0.03749064229909451, 0.014859083514179916, 0.09755642483791999, 1.388527621184626, 63.34750990713797, 42.86313564546647, 44.38044178870417, 44.336119005757, 61.30352358664236, 70.24403295209332, 68.3244171450215, 2.2192498320533387, 0.17898953339505583, 0.16802198884467925, 0.5257354989167183, 57.446386352662124, 87.49415413025888, 82.40455719732469, 81.20151135229295, 68.19129974611344, 64.81881449299475, 63.605084111613614, 67.36223620753135, 70.16892740803381, 78.99350720067179, 72.89100523917907, 76.51307090636223, 75.62878039575394, 74.78262316796088, 72.89433140908518, 72.95549684955229, 66.15833528580205, 64.1346864546499, 76.61488779129522, 67.72632629640641, 63.37527244321762, 63.41422550139889, 61.23695704244799, 60.72894342484013, 57.51432964878698, 53.539905701914144, 50.68620881726665, 51.39114110700546, 52.57276688852618, 52.077387225243356, 47.931081095049464, 43.360413735912694, 47.39168851606308, 47.975494092510594, 46.48051408029372, 49.14390148655061, 47.96730026122063, 49.89204260610765, 52.79920139620381, 48.03590643790461, 57.13552282702539, 65.29253875055622, 56.98897523264731, 57.839372542596635, 56.08195458689044, 59.79148518654608, 60.47842164193431, 60.967298015471435, 63.05887053089758, 61.1846875375317, 60.65740331526726, 63.397292629365005, 62.25114860842305, 61.5896487236023, 62.39084774448026, 60.016939101680634, 59.57863776914535, 54.6049351076926, 47.43101419941072, 46.54269933700562, 42.946372262893185, 45.2734281939845, 45.21388269239857, 43.32008784817111, 35.23376087988577, 39.16210089960406, 43.14414208935153, 45.790808431563846, 43.04452173171505, 46.34319190056094, 46.378265734641786, 43.315141739383826, 43.28023264485021, 39.71124449083882, 42.72734711247106, 45.56918274971747, 50.94110012054444, 58.75780336318478, 57.47249364852906, 57.730973920514515, 57.89909847321049, 55.4994983057822, 54.549100168289684, 54.77405594241235, 56.939212122271144, 58.004300363602184, 60.65151191526844, 57.17763731556555, 62.051068505933216, 57.31814053750808, 56.053191846416844, 58.43334882490097, 56.932402887652, 51.03879851679648, 46.714130447756865, 48.83253589753182, 48.602398672411525, 45.10406417231406, 49.84214613514562, 45.067076221589126, 47.722399234771736, 46.894214307108236, 46.08575497904132, 47.0874616407579, 47.222630439266084, 42.92621128020748, 44.01098981980355, 47.623951665816776, 49.24166656309559, 48.07747963936099, 52.67385813497728, 53.813024259382686, 55.97076323724563, 54.92372966581776, 57.138939211445475, 55.06107930214175, 61.783437344335745, 61.71863586671891, 61.949561488243845, 67.7752225629745, 69.43191405265563, 60.98538406433598, 60.249755305628625, 56.827357892067205, 55.548457330273045, 54.77375391990908, 56.60117833845077, 56.70274419169272, 58.16566667249126, 55.61173300589285, 56.75373108156266, 58.247424556363015, 64.23360078565537, 67.26983301101193, 79.66357354194888, 74.18529325915922, 92.67981775345342, 27.308851211301743, 0.6849600711176473, 0.2811404173412631, 1.189806497385425, 12.548984019987046, 67.15889269305815, 62.32880761546474, 43.464223184893214, 30.372389016612885, 32.26880792648562, 67.16541951702487, 4.943864210959404, 0.11244114548448594, 0.012290027769913357, 0.10574187512599653, 0.05805400117570835, 0.059554231157826806, 0.02213541343207321, 0.036136309931715654, 0.035583623459622744, 0.017423269812077764, 0.11933614364674977, 0.011143479515017282, 0.049488521481473605, 0.06460283867894642, 0.05296154661224254, 0.15024968362863989, 2.206067726496727, 72.29985698576897, 52.1321984260313, 45.04073358351185, 44.78520685626615, 73.06786491024879, 75.97737712244835, 74.47086534192486, 2.270653718902219, 0.19902435672138968, 0.2570538315922022, 0.6049726470824212, 63.104373947266616, 92.406201054973, 85.5572328259868, 84.44257367041804, 72.03030386278706, 68.38442940865794, 65.91739977559736, 70.86388511042442, 74.14838375583773, 81.85841421927176, 77.65486501878308, 78.9899770675167, 77.98779579900926, 76.22541996740526, 73.65039179402014, 74.93648206034015, 69.64537728217341, 69.86990159557712, 81.81929249917307, 69.30311126093711, 67.12355213780558, 66.77923863933933, 64.16047996090305, 65.21122409451392, 60.81825971603394, 56.34962497218963, 53.90257589278683, 54.43717141305247, 54.649434397297526, 55.00957858177924, 51.64392609750071, 47.72464675288047, 47.64488143305625, 50.10159131019346, 48.37086900588005, 50.30624097393405, 50.68620097252631, 52.572598226608775, 54.29822929443852, 50.975165905491004, 57.83105319546115, 66.41597224820045, 58.82913950950869, 61.67407381919123, 59.74977470213368, 63.21326286562028, 64.26428156514322, 64.7012375247094, 62.76975262549616, 64.12962659712761, 62.03258629768126, 64.45876836776733, 65.48303258034491, 63.683558971651145, 63.75269074593822, 61.85724066149805, 61.358181814993586, 56.54457461449408, 50.471427671370975, 48.340309819867535, 41.3314304813262, 48.47768691278274, 48.798956486486624, 41.637928408961145, 38.746074707277366, 41.42781488357052, 45.4199993225836, 47.77034628775812, 47.593133603372884, 46.77368379408314, 48.09025872138239, 45.85126000065958, 44.391447959407685, 42.58154084605556, 42.68564839516917, 45.90930323446951, 51.53054998766992, 60.35366281386345, 60.29623539217057, 58.018291458006836, 58.433137016911665, 59.66494952478717, 56.339367974189024, 58.71707347131545, 59.30317363431377, 60.87180399125623, 62.83703696343207, 61.01320151359805, 62.59651722446565, 56.87282600710469, 59.414396362919966, 58.350575047154585, 56.418556705597915, 51.8572049756204, 48.06956037398308, 49.486885301528446, 48.816975855058246, 45.875033486273985, 51.68367931919714, 45.244312440195394, 48.57076475697179, 48.43393287351055, 48.09595008050242, 48.78000751618416, 48.14485419181086, 45.55869825424687, 46.59444324431881, 49.65005982306696, 50.74565625959828, 54.591281337122766, 55.06613131492369, 58.166231493796076, 59.48959996623378, 57.459953831088164, 61.54706355064147, 57.78701674553656, 64.91639521814162, 63.20677526535527, 64.63446309489589, 68.65487683203914, 71.9081534108808, 65.35097422138338, 63.215890853635734, 59.19210780051447, 59.33400738623835, 57.67932022771528, 60.41626384181362, 59.443100267840975, 59.65775982026131, 58.368939584301366, 60.56835374524517, 62.04443185560165, 65.20436386908254, 68.581646180922, 83.23788042991393, 78.06140299766295, 96.81110905062769, 36.418187233709524, 0.9394182589265608, 0.24409390685539095, 1.9494028990307164, 16.390571998011684, 75.80402405031266, 69.76500957242905, 50.0208689320472, 31.647076952841978, 39.48595531525151, 77.82507235004057, 9.290718186286188, 0.46159662606735385, 0.04129192078365915, 0.05232500798639752, 0.06010582212418799, 0.03873543558462012, 0.025860454676853075, 0.15898230455575452, 0.12183296208780621, 0.24466021437077756, 0.1606735968661885, 0.1355198046733295, 0.15932347415195358, 0.1963882328521821, 0.1581874270472796, 0.21083842842809616, 2.7144505371970515, 84.09254135624056, 55.28208132713072, 53.706378936767585, 59.777631375097464, 81.92823240833899, 82.03070825146091, 80.28950537404707, 2.9643952413912746, 0.3046245362249113, 0.5885893971689287, 1.06589195949416, 65.98413498170915, 95.04969027734573, 88.88422642984699, 87.16869938758113, 72.62656688690186, 72.19538073385917, 69.41212961750647, 75.03010903635334, 76.18571773652108, 85.35101029180711, 80.2160236912389, 81.28662678503221, 82.16419435316517, 79.60018019522391, 77.37323099567045, 77.3525365706413, 74.1265126197569, 73.3447136417512, 78.23166524210285, 69.90842711540961, 70.29354110840829, 66.90541344304239, 68.750363011514, 67.86662947747016, 64.4025529584577, 60.89131386049333, 55.73238119002312, 56.0559610397585, 57.06188032704016, 59.066211485093646, 56.19099647768083, 49.76629926312355, 52.30283721800774, 53.451993619242025, 52.701534378913145, 53.7140981612667, 53.58637402134558, 53.97624977173344, 54.58963786402057, 49.594750481267134, 59.01196902798068, 67.47709105091711, 59.57842988352622, 63.22845420529766, 61.44801585905014, 66.38589551371913, 66.01410973456599, 67.03911135273596, 68.11078133121615, 67.64825544049664, 64.88636162973219, 67.09389901930287, 66.72651413948306, 66.39638393155991, 67.23879137346822, 64.12708097888579, 63.837006015162316, 60.55980690063969, 52.179137429883404, 50.40911297644339, 45.47747381271855, 44.7722630346975, 45.7354167199904, 43.82301807403565, 38.6822695116843, 41.36577867692517, 46.746666508336226, 51.06732591505974, 51.00803536753501, 51.15248057150072, 48.22611001230056, 45.428883491023896, 46.14487294227847, 41.311081224872225, 44.20384883880616, 47.941706795846265, 54.6786246761199, 62.54487529877694, 62.61719203764393, 63.32718026253485, 62.20082067674207, 63.06603277883222, 58.626627537512014, 60.65101769662673, 62.2137095851283, 63.05953733382687, 63.23351798519012, 63.01419865700507, 65.48586453160932, 60.67354386852634, 60.98302671986242, 63.364489847613925, 58.82101628088183, 53.52730704892067, 48.95918530802573, 50.95760937659971, 49.38304839595672, 45.8491026970648, 51.672888878853094, 45.85485681410759, 51.98871812512798, 51.013938534644346, 51.40165305906727, 52.3323412864439, 53.99011535029258, 47.956968738186745, 49.586438978871996, 52.13090796624461, 54.22772076822097, 55.197558172287486, 58.09794302909606, 60.80547278927219, 61.75154847483482, 60.1806745221538, 62.792117980218705, 61.13888994339974, 69.57204464943179, 67.25666169197329, 66.82518528353783, 68.62593758490779, 72.84161475396925, 66.99605157298427, 65.77507657389488, 62.88624701961395, 62.231383785124756, 61.34960359142673, 63.57948280149891, 64.16848551842475, 65.86240814578149, 61.89202031781597, 62.99365328204248, 64.88021919804235, 68.6883895627914, 72.38378001797584, 86.9539103969451, 79.94455645161291, 100.35032641503119, 35.7852461261134, 0.8315667461964392, 0.3227653450542881, 2.8161843169120053, 22.015948026410996, 80.2842729322372, 78.9387587578066, 60.432420084553385, 47.70094386992916, 45.75036487271709, 92.77253473958662, 11.976963204722251, 0.6727221536059534, 0.3472603016322659, 0.2864073024642083, 0.2856266895128835, 0.22601185696980647, 0.11399733052859384, 0.21746194801263272], [0.052736358897339915, 0.0301055298111732, 0.06177915733367686, 0.03632949815402108, 0.039526095779071894, 0.00995291184799205, 0.07704580728445323, 0.093634276831102, 1.5915667842472754, 58.73461823309622, 51.53458218420706, 38.41161420268398, 33.904363724493216, 59.57838673745433, 76.31061384754797, 50.14015605372768, 0.3142156199582162, 0.03635382527605661, 0.30745811159572295, 0.7856371397933652, 67.3100608394992, 88.9536366924163, 80.2033152118806, 80.20455468085505, 67.63549204795592, 60.109303074498335, 63.001815734371064, 73.71653079986572, 74.92394616526943, 75.16383832500827, 76.49243923925584, 77.703871111716, 73.02236541624993, 71.68155024128576, 72.01124898848995, 68.98124156459686, 70.27289375182121, 61.91921018785047, 66.0178752099314, 72.33198119748023, 61.24191884071597, 64.99893365367767, 61.16775074312764, 58.02697558556834, 54.17263107915079, 51.82015818934287, 52.691104796624955, 51.88278667388424, 51.141395953393754, 50.56840435151131, 47.70057516713297, 46.29601363212832, 46.26964745983001, 46.965723037719734, 49.34608790182298, 46.6581464582874, 48.712009306876894, 49.68121913171584, 54.19484346143661, 55.276131091579316, 54.558996308234434, 67.41665517130207, 61.695650777509144, 58.92402948871736, 55.68926649708902, 59.55862975889637, 61.99908141166934, 61.00973413836572, 61.294910061743956, 54.176153367565526, 50.2402235615638, 53.25007784751154, 56.26961646541473, 57.579899910957586, 56.20107696902368, 57.16668998041461, 51.82875994713076, 48.301670551300056, 46.91875657727642, 44.860394770099276, 51.67862338404502, 46.420431213994185, 42.28300140750024, 45.30548964777301, 39.01774983252249, 44.58072585444297, 44.46235656738282, 45.81500161078669, 41.45312593829247, 42.89523240058653, 48.63184782766527, 43.726241434774096, 43.83436941331433, 43.46787883389381, 45.553752145459576, 46.17121558035574, 49.27322203113187, 58.57192224071872, 57.2755475198069, 59.89708715869535, 59.89680474804294, 58.47841685818088, 60.167816992728945, 60.11218993894516, 57.02101315221479, 59.51565627128848, 57.56852895982804, 59.48013920937816, 57.575903015752, 55.24873333592569, 58.653436937639796, 59.473247604985396, 55.308757366672644, 53.13441499587029, 49.700540727184666, 50.26444027500768, 44.876515711507494, 45.25151783420194, 52.61122572806574, 51.01367181347263, 45.63471378818635, 46.85542206610403, 43.920073201579434, 44.249214972219164, 44.86683922429239, 41.889050314503336, 43.602176866223736, 47.14221400599326, 48.782439385691, 53.352847868396395, 55.66234727059641, 56.714577982502604, 60.01039658823321, 61.11169615099507, 59.56624700177101, 62.43873203954389, 61.932946328193914, 67.63979881040513, 78.81034035836497, 70.42616428867464, 65.80705565790977, 62.72728904601067, 58.73630877464049, 57.960032493837424, 55.45148457250288, 55.13607501983643, 53.621840092443655, 54.84713754346294, 54.34497610215218, 57.40065543882309, 63.675412208803245, 65.33956404655211, 68.21221382387223, 69.83832651568999, 75.02146413249355, 74.95973387072164, 84.83864676567816, 57.28290980862033, 0.5909881103904017, 0.23250180146386548, 1.2689197231684963, 10.526172614866688, 71.97713221273115, 63.11778845325593, 44.591406468422186, 33.270363576950565, 40.70252157026722, 62.201295283532914, 7.084224147181358, 0.3171729032070406, 0.11832598010979353, 0.08499781526024304, 0.031892075578892426, 0.0727800765044747, 0.07968196945805704, 0.06926441475027992, 0.049831418605941924, 0.04160822316583607, 0.04244009122973488, 0.07215153200611954, 0.028197901931801633, 0.023096327091597264, 0.1457189936791697, 0.14692804896302764, 2.9686593480648535, 67.08257905898556, 60.13567709153699, 36.179950314183394, 37.89088818334764, 66.9763534299789, 83.32459618968349, 51.77357612117645, 0.20899647726647316, 0.006223041855264456, 0.11175109178669031, 1.1108018722264998, 74.05043432789465, 92.97547817230226, 83.2645211681243, 84.54530838997134, 70.22008295982116, 64.81805355318131, 68.02978438715782, 77.69709325605824, 77.63399016472601, 79.52414112706339, 77.78560546136673, 78.90855650747977, 75.62771351106706, 75.0178163282333, 73.39346085825275, 69.55368011228501, 73.00500500586726, 66.48908522821242, 71.04984468029392, 77.51839007100752, 64.76283834826562, 66.38731541172152, 64.84896183013916, 61.576771582326586, 57.693075979909594, 55.564389997913, 52.75663583509384, 54.95268460242979, 55.141189790541134, 54.24448105596728, 49.75363785220731, 49.357721651754076, 49.0421316700597, 48.971603531991285, 51.226307422884055, 50.07140867171749, 51.20677401942592, 53.77941739174628, 55.496340797793486, 56.16609727182696, 54.26988624757337, 70.08377275159283, 65.16488521329819, 58.80402457329535, 58.33953357511952, 62.239816880995235, 63.10421313008955, 64.27330693890973, 62.91814765622539, 56.565053309163744, 52.500540364173155, 54.68342173484064, 56.556424094784646, 58.35782358723303, 57.59216124011625, 59.30896697505828, 53.10840968162783, 49.3879395915616, 47.249173118222146, 44.40776109695435, 51.868513168827185, 50.79928290459418, 44.84552506477603, 46.338814535448634, 41.27755672700944, 46.90211396063528, 43.536304581549864, 48.08214333749587, 45.879861923956106, 46.40218827032274, 49.06960002837643, 43.62896665450066, 42.50247370812201, 44.110245397014005, 46.24818817261727, 49.207063413435414, 49.95301192806613, 60.51081649718746, 61.499826446656265, 62.74310404254545, 63.14175021263861, 60.00229297145721, 62.29111756047895, 61.6322809650052, 60.81822441470239, 61.19675274818175, 57.81251607402679, 61.35715807637861, 59.61805758937713, 58.43227017310358, 59.51421283906507, 63.265351941508634, 55.30520369929653, 55.38147418729721, 49.57629180723622, 51.21939620664043, 46.005589577459524, 47.756010024778305, 53.896837465224735, 50.79137148395662, 46.76921621445687, 48.720010942028416, 47.352629553887155, 46.69506772871941, 48.68260329769504, 44.00565147399903, 46.0160779953003, 51.55441368779829, 50.00450088131813, 56.035556870122115, 55.99384246333953, 60.492302909974136, 62.27007012213431, 63.30652506120744, 62.90998912626698, 65.81144086776241, 62.81933530684441, 71.85118490649809, 80.03191548009073, 75.22597651327811, 69.40859163961103, 68.25353207126741, 62.31235327259187, 59.51272626076976, 58.25366896967734, 57.473285967303866, 54.710678285168065, 57.09938603062784, 55.073321019449544, 61.38821148103284, 66.82419684625441, 68.34817101878505, 70.69731773868685, 73.47745449312272, 78.87863666780534, 80.22233870721634, 86.4921062223373, 68.74485600379207, 0.7873887232234402, 0.21088586459236763, 1.579150644040877, 13.191644760870165, 80.35363612636444, 73.81073828666442, 49.697081196692686, 40.296199321746826, 52.54301963313934, 72.0222786934145, 13.627883907287353, 0.6794906936345563, 0.23236707724150152, 0.16878020138509814, 0.12002479540364397, 0.07199426947702324, 0.09391308687026463, 0.07495896845695472, 0.2563265383604073, 0.12209727008256221, 0.11388643930155425, 0.12265271447118252, 0.18143419657022725, 0.19017613312650114, 0.19898617489924356, 0.2045426565793253, 3.3663648847610723, 79.55770092625772, 63.2166321815983, 48.76808351086032, 49.18376453461186, 75.19548400755852, 88.04563153174617, 60.600862349233324, 0.6930794999484093, 0.16600930732825112, 0.865636759948346, 1.7011940887858792, 73.700056845142, 95.15755545708441, 86.52431672619235, 86.01289456890476, 72.40274075538882, 66.09229826158094, 70.18857848259711, 78.18428301042127, 80.09906645744078, 83.18670134390555, 80.74243714732509, 82.95230050240794, 78.38711661677208, 78.288939691359, 75.83337906868228, 73.43339058660692, 72.06227902443179, 69.38374734693959, 71.08657375458749, 75.08300612049719, 65.31504923297514, 71.20922626987581, 68.26453039723059, 64.5798558573569, 60.98639603584044, 57.6239481279927, 58.397619955001346, 57.81259844380041, 56.919690485923525, 56.05814187757431, 53.46276837010538, 53.42637661964663, 52.69430545068557, 53.61477590376332, 55.98261271753619, 53.217694759368904, 53.518685679281916, 56.66681135854414, 57.166607610640995, 57.03225074275848, 53.14637430252568, 69.71530529760545, 66.23047551801129, 60.73842771591679, 59.636932034646314, 66.25677108764648, 66.2530997491652, 65.96187160861108, 65.22655271714734, 58.2237373628924, 53.7983859738996, 59.19310408253824, 63.19650257787397, 61.95948508477981, 60.91269470030262, 61.568605207627826, 54.78213994733749, 49.84402495045816, 47.36199617385865, 45.6012559706165, 48.7732022039352, 48.426790237426765, 44.71562793177944, 47.39157084495791, 41.36071489703271, 48.83790169992755, 45.21081932129399, 53.58979432813583, 49.972690459220644, 49.54366160977272, 52.67216759343302, 44.83976310299289, 42.499916322769664, 44.318546787385024, 49.36252263284499, 50.42555162983556, 52.0182849514869, 64.31065182532033, 62.67198362658101, 63.018003356072214, 67.11582506856611, 64.95331648857363, 65.41679943761518, 63.2130902813327, 62.30255126953126, 64.30789832145938, 59.6861695474194, 65.47879249818864, 62.58267518012755, 61.547675440388346, 61.90524262766685, 65.24095173804992, 58.74017230926022, 56.24946724983954, 51.270359562289336, 53.601133900304, 45.4365203457494, 47.11196468722436, 55.81682589746291, 51.859797662304295, 48.647505929393155, 51.78917146498158, 51.18321626417099, 50.350328414670884, 52.155050154655214, 47.369958585308446, 48.77924265400056, 53.45057764360982, 51.865787121557425, 58.50082535897532, 59.61856357512936, 62.54493413432952, 67.86294244950818, 67.19158957081457, 65.41397925346129, 67.91263887959143, 66.34568337471255, 72.24739136234408, 77.35560386411606, 79.31065436332457, 75.00790057643768, 71.91589616960096, 64.28481909536546, 62.47713596590104, 60.98976927418863, 60.64556167971704, 58.275787215079035, 59.77296767696258, 59.45879367090041, 65.06247605046919, 71.04105857110792, 71.52776195156959, 73.51499942041212, 77.59080486912882, 81.1463628276702, 83.96253831924932, 90.72858764279275, 73.63956605234455, 1.0863565581460153, 0.2853436966336543, 3.013160598854865, 18.223320053469752, 84.90473870308169, 80.62180073030534, 62.21832229245094, 54.31324804982832, 58.06495589594687, 87.90834073097476, 18.17361185627599, 0.777980060346665, 0.3067161094757819, 0.3403369199124075, 0.2959519612693018, 0.13634491201129653, 0.3179075815264256, 0.17215509448320637], [0.035310585892969565, 0.05642823236543806, 0.09736947640175782, 0.07555879997990786, 0.032885917612621864, 0.08429806288932601, 0.11646885274639053, 0.19701654752415998, 2.430887443404044, 65.90792332926105, 40.49187068016299, 40.538056588942005, 38.47174805979575, 54.88912259378741, 80.58216125734391, 20.934689814044585, 0.28473214396545965, 0.19217297194465516, 0.24007997385436491, 1.629708524673216, 68.75608967196557, 88.42592885417324, 75.84416558665615, 76.61677837371826, 63.75523244180987, 62.476951614502944, 69.47538960364558, 73.36002657490393, 76.19388411121984, 73.64904249868086, 73.80179528267153, 70.89364021055161, 70.90978468618086, 69.62977409362793, 70.25164235022761, 68.8848767742034, 62.159231785805, 65.93597612073346, 58.30318104836249, 67.68479624102193, 67.50356704958024, 64.77286784879624, 64.59536883138841, 61.298440194899044, 57.51369030244889, 53.96669487799368, 52.82089994799707, 52.764857122975016, 49.208840247123476, 51.394157409667976, 48.14320679633848, 43.54547900538291, 45.260033299846036, 45.16305269733552, 43.57745416702763, 44.83149474666965, 48.38344804702267, 52.24933216648718, 57.02406475620886, 60.73540749088411, 62.09784277023808, 66.5700743275304, 63.90217619557535, 57.75695570053593, 54.12440946025234, 54.37972045713856, 58.209608985531716, 60.54321135244062, 60.108200888479914, 57.044488537696104, 50.549569129943855, 51.5282710905998, 49.43536889168524, 49.31690154537078, 48.4379062344951, 46.4562895221095, 49.328645121666696, 49.22168600943781, 48.951548453300234, 50.00972547838765, 45.319147340713016, 34.81289448276643, 46.819497077695786, 43.54670278487667, 52.18611140404978, 40.92149965224728, 45.64270365622736, 44.75118813976165, 39.02951694303943, 42.59976417787614, 45.91695970104587, 44.66922237027077, 43.72718280361545, 44.75778556639149, 46.46551101438461, 45.96814270942442, 44.53863097775368, 46.75755500793458, 55.20326129851803, 55.482738018035896, 56.471704821432795, 59.83100306603217, 58.60934165216262, 57.90276196695144, 57.34655810940651, 57.95579633405132, 59.30674299117058, 54.74354774721208, 54.57807863912275, 59.30225187732328, 62.465929754318736, 58.823130438404704, 54.398359560197406, 52.290807308689246, 48.05920531672817, 47.20629376749839, 52.12185905825708, 54.7523142445472, 59.388567555335264, 48.58313983486545, 44.68536684590001, 44.40616861466439, 44.97355514957059, 43.45672361312374, 42.430298174581225, 42.99994007233651, 44.639667311022365, 48.71221719249603, 47.75437831878663, 52.826669754520545, 55.56281320510372, 59.01951174582205, 60.70448744681574, 62.76124892696258, 64.28461120974633, 63.347643267723825, 72.98916647511145, 74.29595901120094, 57.011411190032966, 60.53612362953925, 62.702652638958355, 63.84958505630494, 60.20199652641051, 61.28862250235773, 57.823785043531856, 55.93852919916953, 52.752772300474106, 54.264673417614354, 56.05897342005084, 61.68321294169272, 62.79608741883309, 69.46108079725697, 72.40872629227178, 76.32414602464246, 75.07054082808956, 84.8219374687441, 79.89362839729556, 80.3530320813579, 0.33983081158611084, 0.04463139763702789, 0.7833267411878033, 9.368423281177398, 75.32008201845231, 60.91011770309941, 48.105810919115626, 28.03749226754712, 29.86785258016279, 66.16247730870401, 11.394476525245175, 0.40350402555158066, 0.04773955424166015, 0.05495656980201603, 0.1095288239359375, 0.06455737136064038, 0.05200431975085409, 0.1013177709894315, 0.13656963624300497, 0.0836497150181282, 0.11563963917714935, 0.043521861004973614, 0.09358169255597938, 0.07435803376739064, 0.13651400293794372, 0.2646271469852617, 4.132991644643968, 76.33475995832875, 47.333978683717795, 40.91028167355446, 46.574450923550515, 61.2178001865264, 88.30561407150762, 22.3359545969194, 0.32710845071461897, 0.19294079122764451, 0.3654607427456687, 2.351059610805204, 75.72273685086158, 89.89397787278699, 78.95209481639247, 81.24766980448078, 65.63797404689174, 65.32074451446533, 73.08958699626308, 77.21150382872551, 78.28473491053428, 76.60050053750315, 75.53600065169796, 75.38231434360628, 74.08347637422624, 70.47385246522965, 71.14284407707953, 72.62817505867251, 66.27146428631198, 68.99537778669789, 62.96299211440548, 71.69126202983242, 68.52117892234557, 67.52801910523446, 67.18034021316036, 64.59822431687387, 61.038363518253455, 57.42997515586115, 54.234898705636304, 55.39957592564245, 53.28963495069935, 51.97866901274651, 50.74973944694766, 46.671894365741366, 47.451026132029874, 48.61482866348759, 49.0037355884429, 47.92526422008392, 50.02641516347086, 54.76086108915268, 60.30433116420623, 66.78890335944392, 64.8221367405307, 68.64664769941761, 65.40456556504773, 61.308869777187226, 57.545241848115005, 57.58384581535094, 59.72635030746461, 62.68658268836237, 62.16038496263566, 60.364461098947835, 55.212839726478826, 56.066504370781686, 52.058297049614694, 51.71557603343841, 49.702521524121686, 48.1257208701103, 49.98062541407924, 48.20862408607237, 51.506537237475, 51.475668184218875, 49.681517231848936, 38.54808522808937, 46.88609500085154, 45.542055637605735, 51.843837538073146, 42.883688865169404, 46.501192815842174, 47.21062014179845, 42.861472560513405, 45.10390727750717, 47.01112447246429, 45.54673110285113, 43.2814525019738, 46.34082278897686, 47.985672643107755, 47.41448533150458, 46.04604882578696, 48.19610388048234, 55.97680368731099, 56.63327901594101, 58.9046137563644, 61.083804176699736, 61.27509424763342, 62.28074681374335, 62.25208997726441, 61.76659468681582, 61.03109928869433, 55.844404082144464, 55.85733221423242, 62.318903630779644, 62.44766719879643, 62.328513437701815, 57.7321937776381, 54.4260593383543, 50.20061938993393, 47.142739603596354, 55.33075009622882, 57.028296993624785, 61.36207280620452, 50.75590933522871, 46.50515833208638, 47.03341530215356, 49.097397865787634, 45.74033537218648, 44.9718253843246, 45.44333742510888, 47.890664992793916, 49.17580212316206, 50.08319931645548, 55.4234004020691, 59.57018506142401, 62.570068682393725, 62.68331927637901, 65.87257492926814, 65.69037691239389, 66.77589677995252, 76.87734926900556, 79.19288127653061, 62.048005134828635, 64.7412064767653, 64.24849794756982, 66.81886242282006, 64.39410417310654, 65.06937157723212, 59.61044819124284, 60.51277375990345, 57.45582357529671, 58.390190985894975, 58.20759288726315, 65.50972038699736, 63.76028445459182, 72.8093179579704, 73.83264864644697, 81.63966363476169, 77.11706884445684, 89.95745751165575, 80.29782079881238, 92.7160055406632, 1.9750206340705196, 0.12010885823157527, 0.6649197013147417, 13.245993121977776, 82.9115156973562, 68.05855889474192, 56.57782062407463, 29.100691887640185, 37.74221858670635, 79.57542219469624, 20.21627045446827, 0.5147067745847087, 0.16979971119473058, 0.1756383890226003, 0.11957566103627605, 0.05677346222763581, 0.050971610246286284, 0.023201114513100158, 0.2092707060998486, 0.1353646871904212, 0.25954617607978087, 0.14186489726266555, 0.2580425599890371, 0.12735963528675417, 0.33300037165322616, 0.37402572831319225, 5.344193568152766, 89.29351006784748, 53.17363869759345, 53.24910117733864, 55.82934610305294, 68.81080673586938, 95.3615971534483, 28.903141713911488, 0.4968030852896552, 0.28550151074605606, 0.7042546390045075, 2.725363551608978, 74.93509354129915, 90.24267658110588, 79.75690241782897, 85.04535567375922, 69.51472313173356, 68.90892874810004, 74.77196216583252, 79.94443878050774, 81.10644878879671, 77.82657854018673, 78.34064437497047, 77.92759526160457, 77.05083570172711, 75.42581342881726, 74.6268815378989, 74.74731399166969, 66.2634861853815, 71.87662539943572, 63.92480042672927, 68.02584632750481, 74.27476252278974, 70.70617445053594, 71.32042546426096, 68.549482745509, 62.62275788091845, 59.227271849109286, 57.26067781448365, 58.1013084227039, 55.7183861732483, 55.283583594906716, 54.64887349836288, 49.73255511253111, 51.148507210516165, 52.83236895838092, 50.25079827154837, 48.91133239192348, 53.35289493683846, 56.238531681799124, 62.810710014835486, 68.2007997266708, 67.03198832850303, 72.64366842085316, 69.08527066630703, 63.21889538918773, 61.18203601529522, 61.10105476071758, 63.61746703424762, 66.40278523968112, 64.83100521949031, 61.74928918961556, 55.11831060532601, 54.93909751215289, 54.46483588987782, 54.66746553297966, 51.795541394141416, 50.721184592093195, 51.993421046964585, 50.900178032536665, 51.37201170767508, 50.934283041184955, 50.11380557091006, 40.291794500043316, 48.53029766390401, 45.031013950224846, 53.656019626125214, 44.00059161647674, 45.82540373648367, 50.467026772037634, 46.47051988109466, 47.640123598037235, 50.38087583357289, 44.68106008345082, 42.47583689228181, 48.473878291345414, 48.131502443744296, 46.453641922243186, 47.760501138625614, 49.83606253900836, 57.334528200088016, 61.07110746445195, 61.18445219532136, 63.35321695573869, 67.24910720702141, 62.52703635923324, 62.03257453057074, 64.12870484013712, 64.1824334667575, 57.767883423836004, 60.38861897683913, 64.73752729354366, 66.87386189737629, 64.55375248386015, 59.84284077921222, 56.787761565177675, 54.04434211792485, 49.20735366882817, 58.712111673047474, 58.797952744268606, 64.00064337638118, 51.82510037575999, 49.84003589999292, 49.21920707148891, 49.770570724241196, 48.97820880336147, 47.95771398851949, 48.09095690327306, 51.21061794219479, 53.10360085579657, 52.5118407126396, 56.78192507836127, 60.138022668900035, 66.16826672707835, 65.09166240692139, 69.25139088784495, 67.79570518001434, 72.03496363855177, 76.49862873938777, 76.76782100431382, 67.31406165707496, 69.62143513464159, 67.58943557739258, 68.23664234530541, 66.67207948623165, 69.31886349954914, 62.483439214767955, 62.19962435383951, 58.80817836330783, 61.55064859697896, 62.10483635625532, 68.07225581138366, 68.23636777939336, 77.5989398648662, 78.37386685032999, 86.19323730468751, 80.36708201131513, 93.66679591517295, 79.65492079334875, 97.70125173753308, 4.7594858465656165, 0.17467769944379408, 0.9836306026385677, 17.931329011917114, 90.0410589095085, 77.52019436128678, 66.71608847956504, 44.16683735386018, 43.26841062115085, 90.61278358582528, 23.866614449408747, 0.8438419262247702, 0.6084786331461323, 0.28507093868909344, 0.3421667668848269, 0.09931719366220698, 0.1132709795849458, 0.20322547564583443], [0.025414689181132183, 0.08222152794440908, 0.05080632294618315, 0.1097050394802805, 0.14536227249810774, 0.09321608475499576, 0.11982149865117767, 0.2668452473177064, 2.9813751818672305, 61.33342381446593, 51.443116434158824, 39.02215857659617, 54.35100086273686, 52.9355037596918, 75.56985855102539, 13.406497490021492, 0.37473380805984624, 0.2839379559361166, 0.26874425670792984, 2.237752142452425, 73.40693027742448, 84.35631290558847, 78.16271781921387, 71.6350858442245, 59.83994999239522, 63.37354267797163, 65.95319532578992, 70.97688859508884, 72.48445941555885, 71.19319162061139, 70.82670888593121, 69.9502395814465, 66.0979543193694, 68.41980918761223, 67.692013402139, 68.89199195369598, 66.63157709183233, 69.85800112447431, 61.316232066000666, 64.59891857639437, 72.66437069062265, 66.5716903440414, 67.43780459127119, 65.68998467537665, 67.52386923759215, 60.9970138918969, 54.413209653669796, 52.15499131910263, 50.0805321047383, 52.34893683464297, 50.75952576052759, 45.21585956696541, 41.62550626262542, 46.060428234838675, 46.449880369247936, 45.655423902696185, 45.22890144778837, 52.387242701745805, 57.76311382170647, 62.52110181316253, 52.51607295005552, 51.49591153667819, 57.710993366856734, 53.97985050755163, 48.066822559602805, 47.65022370123094, 51.82775974273682, 49.540370741198146, 51.61732066062189, 55.44967243748327, 58.37741582624374, 60.040269359465576, 60.809234342267445, 62.50680477388444, 60.19611689352221, 54.51771336217081, 51.32468831154608, 49.34288724776238, 46.83570823361797, 42.40546957139046, 38.175687559189335, 47.085335716124504, 45.57996926769134, 47.46551144507624, 49.324918870002996, 40.60849843486663, 46.83524931630781, 40.27776025956677, 36.98270259364959, 38.20455228128741, 44.80537176132203, 47.24665103420135, 45.77260078922395, 46.50312262196695, 40.41331737272201, 40.93942488393476, 46.09928323376564, 41.91215699718845, 44.16039682203724, 50.62729089490829, 53.606617373804895, 56.84560475810882, 57.11500883102418, 60.41428696724677, 57.81367317322762, 54.06614265134258, 50.54054375617735, 49.91336461036436, 56.92966507327173, 60.64636576560236, 60.013212850016934, 60.40311997936618, 52.77019546877954, 51.32191911820443, 48.95704369391165, 50.650515248698575, 60.78169930365778, 61.837852385736284, 58.899024378868845, 53.28403772846345, 46.24676042987455, 43.689998734381895, 44.20404495731477, 45.390075560539, 43.29028960197203, 43.10078028709658, 44.79037654015326, 47.93310503805838, 47.999628436180856, 54.50091385072278, 55.17432205138668, 58.8279196523851, 59.81427807961742, 63.69577715473791, 61.61058241321195, 70.81831501376244, 63.80164584805889, 51.33726343031853, 59.11327208242109, 66.86800972107919, 65.07688683848228, 67.32151416040236, 64.7808224155057, 67.72238039201306, 62.67125014335879, 62.87535067527526, 57.04320984501993, 60.46509735045895, 54.55081424405498, 62.7736710732983, 65.04143253449472, 75.33235119235131, 72.52084332127725, 80.155454451038, 72.84734141442084, 86.66901296184909, 74.54844982393327, 86.75953342068581, 5.352955652821449, 0.22877343539749423, 0.46910425708178555, 10.867537471555895, 78.23136714196976, 57.41237940326814, 52.88961595104587, 33.39122356907014, 36.546405592272365, 67.08876071437713, 18.669395523686564, 0.4173209728492845, 0.10895366810502545, 0.10218138956735212, 0.0221685927000738, 0.03305691609820051, 0.07533436686161064, 0.05448902634182765, 0.08141439302914566, 0.12399775802247948, 0.07210454783372341, 0.04926121936389997, 0.06192127813494975, 0.03834305301068291, 0.06652373520116653, 0.21749407774017704, 4.011156698388438, 71.46745943254041, 51.58861675570088, 38.48746499707622, 62.00181530367944, 58.66282709183232, 84.36922534819573, 13.938753316479346, 0.7182209121604121, 0.1943829517451025, 0.5427774618710242, 2.790764661565904, 82.43119793553507, 85.35421094586773, 80.26543771066974, 77.04819986897131, 63.7249517440796, 67.2139706150178, 67.83299907561272, 72.91188793797647, 73.67921337004631, 74.12775993347168, 73.18967803832024, 71.37975523548742, 69.51040067980367, 71.21236416601366, 71.8917186798588, 72.52795065602949, 69.69190443715742, 68.69141763256442, 67.42254657130088, 70.37296125965734, 72.42926382249402, 69.98376800167945, 68.94348482931815, 69.36109958156463, 67.46766167302286, 64.01359112031999, 56.56794409598074, 52.72056179661905, 53.233133208367136, 53.087193581365774, 53.455715948535556, 47.69279710708126, 45.37975580461564, 47.171278768970126, 49.370183021791526, 49.3239696564213, 48.69054609729398, 54.6299990530937, 59.47636196690222, 64.20376331575456, 54.73176494721444, 57.32892313311177, 60.15823856476815, 55.31773959436725, 48.32211394463816, 50.10152462990054, 52.904328761562226, 52.140859019371774, 53.26653219038441, 58.683588197154386, 60.400966598141586, 61.84446550184681, 62.32201799269646, 63.003165029710345, 60.13557903228268, 56.36328266512964, 54.835142935476, 51.35441203271189, 47.2756177379239, 44.65166191900931, 39.108093784701445, 46.933791022146906, 45.48689142350228, 48.33535978871007, 48.75080939262144, 41.36639056667205, 45.90039160943801, 43.85671907855619, 40.73635201300345, 40.762651505008826, 44.889334017230624, 46.59159560357371, 46.86776576503631, 48.76640865879674, 40.51137662702992, 40.920252338532485, 47.36788365148729, 44.69995021820069, 46.548508367230816, 52.867799728147446, 53.49109964986002, 60.07834380672824, 58.87923602134951, 62.602141903292754, 60.0655843365577, 55.06495068150183, 52.25408215676585, 50.140626738148356, 59.20555368546517, 61.31016023697392, 63.304712926187825, 62.04198429661413, 56.629446860282656, 52.776302599137836, 49.992976957751864, 51.871972699319166, 64.28050056580575, 64.39336284514397, 57.518212795257575, 56.19550720337899, 47.520805097395375, 46.5266921443324, 45.047079978450654, 46.256821309366536, 45.36075584350094, 46.52969275751422, 47.02489199176912, 50.15017770951795, 48.25869706369216, 57.000130453417384, 57.3203331424344, 61.76303709706953, 62.47539051117436, 66.69682964201897, 63.46226669126942, 73.3721310092557, 68.38396656897761, 55.428879953199825, 61.004599755810155, 68.00578732644358, 68.50095518173711, 71.90602748624741, 67.49609101203181, 71.10653077402424, 65.11656553514543, 66.33220611080047, 59.28565632912421, 61.0695698953444, 56.87730535384148, 66.10648939686438, 67.51199230071038, 78.58849110141878, 76.14246968300112, 84.47257195749592, 76.3889043561874, 90.91201336153092, 75.60509712465348, 100.10757092506655, 9.824197792237806, 0.5474939894291663, 0.45858786171001775, 14.500757378916587, 87.42142554252379, 65.1643164696232, 62.376170235295454, 30.63915333440227, 44.319029238916215, 76.99083912757136, 25.426140985181256, 0.7641469639155173, 0.28975483090166126, 0.04700692520747262, 0.11826774210578973, 0.03789399908254704, 0.06425615708013216, 0.06977391684608114, 0.16969253549412375, 0.22416633583845633, 0.1963773544036573, 0.1731088279836601, 0.19829559260078017, 0.20886720759013008, 0.2569247917422364, 0.5712767293856991, 5.74681947308202, 82.07539973720428, 65.19607982327862, 49.17217785312284, 71.68374676858225, 67.3265661731843, 90.06760551083474, 17.420616803630708, 0.7449853276052784, 0.4361834977903674, 0.824632608602124, 4.113064533279789, 81.88646701074417, 89.56070192398565, 82.96804489627962, 79.37638544267224, 66.0201580293717, 67.84275008786109, 70.70461334720736, 77.01333784287976, 75.53339619790354, 76.46204871516075, 77.32609195093956, 74.55830281780612, 70.50372523646202, 74.15036847514492, 74.54783793418639, 75.81963508359848, 72.40497650638704, 71.61385797685193, 67.86303658639231, 68.5418027447116, 76.4987228762719, 72.34151255699896, 71.3063520000827, 72.46748339745307, 71.68337806578606, 66.94314664410007, 59.22580880503501, 56.507680800653276, 54.29558561694238, 56.008029676252804, 55.53163036223381, 50.70920567358694, 47.572607840261156, 52.15382245279128, 51.54026962095692, 51.657764219468646, 49.479240602062596, 57.32079598211474, 61.9338406285932, 67.01454162597656, 61.97748484150056, 60.00122608677034, 60.65134325335103, 59.337561053614465, 52.84573639592817, 51.92122197920277, 56.52535500064973, 53.99585770022485, 55.15915032356016, 60.894581194846864, 62.912828922271736, 63.30525421327161, 63.20275875829882, 61.81325520238569, 60.04067336359332, 57.06277070506927, 55.27466412513487, 51.49327962629257, 50.04469340847385, 47.18696040491904, 39.47642395573278, 47.27662578705819, 45.168846038080034, 48.99247446367818, 50.96304970402872, 42.09583766998784, 48.22909493600169, 47.781379915052845, 46.47087289441017, 46.07055971699376, 47.721261747421764, 46.4957760226342, 49.537056338402536, 49.234873017957135, 40.74053325960713, 42.042258093434, 47.97780044617192, 45.063942247821444, 48.7235136185923, 56.17186315598027, 56.289377366342855, 63.593116960217884, 62.06787586212159, 65.07232904434204, 64.72554445266724, 58.438930357656176, 54.61273670196534, 51.97355031967164, 61.07823048868487, 64.28691364103749, 64.28938473424604, 66.44508407961938, 58.271029380060014, 53.986530303955085, 52.669496459345666, 53.03508881599673, 64.11330169247043, 68.7164423542638, 60.531150064160755, 58.96218238338348, 50.28988076794533, 47.87386940371606, 48.02390006280715, 51.02643128364317, 47.114353410659305, 50.386033750349476, 49.3155247934403, 52.623338007157855, 51.465293515113096, 59.938829022069136, 61.21606649891023, 64.31665697405415, 66.78884060152116, 67.73785021997267, 66.18899253106886, 74.21025522293584, 67.43259568368235, 61.49662971496583, 62.68140908210509, 69.70560919853949, 72.18546498206355, 75.32395732018256, 69.93976685308641, 76.14156753786149, 66.94430766567108, 70.51356254085418, 63.209669974542436, 65.10830502356252, 61.07049557470507, 69.97255786772698, 71.92515296320762, 82.53771381993448, 78.70396567929176, 85.62348950293757, 78.71552882655975, 94.10876074144917, 79.32198216838222, 101.68655241689375, 12.882206036198525, 0.5637699870332595, 1.312776479509569, 18.358039740593203, 94.33354393128427, 71.3504865092616, 72.63486662218648, 51.78649640852406, 51.56415685530632, 90.56671142578126, 32.135059025979814, 1.1315627324004327, 0.5877090702133795, 0.3355165721187669, 0.25669565484408413, 0.16868873048693905, 0.2072991022179204, 0.11031279235237068], [0.10643580522868903, 0.15372635916836802, 0.07580474484711885, 0.061052737442115625, 0.0757798393287005, 0.05064269039599646, 0.1896113577869631, 0.4210731182848254, 4.069765734095728, 60.65126872831776, 51.42029216212612, 39.78820923836001, 40.494392764183786, 59.31364636267386, 78.70620927503033, 13.505289246959071, 1.0935485915791605, 0.4010795104888178, 0.2814608565982311, 2.7071470839361993, 69.75958885685091, 82.61986394082346, 73.12379790890601, 69.28350725481587, 62.677341584236395, 64.46125907282676, 63.85387612927345, 67.74020364207607, 66.14044927781629, 68.21378277194115, 65.58567708538425, 65.82654983766618, 66.45625498987013, 67.72673422290434, 67.3579922030049, 71.21257597400297, 65.44371081936744, 66.52519456801876, 61.84521467454972, 57.64774122545796, 66.76023083348429, 67.04804651198849, 67.80799004339403, 66.46177768707275, 64.78295618487944, 65.78645929213494, 54.44213713369062, 50.031200455081084, 49.718940565663004, 50.35762794556157, 48.66089690116144, 46.47565426365022, 44.251960631339784, 42.98106954943749, 45.484510544807684, 44.18158154333792, 45.38218767412248, 49.243674816623816, 55.76183426764704, 62.22556298778903, 59.23852905150383, 57.6020142339891, 54.29191820083126, 51.51069102748748, 48.90304834611955, 45.741621909603, 48.47762807723015, 50.35325842518961, 50.77376788662326, 53.75798556112475, 53.27478485722696, 53.73684006352579, 56.457831398133315, 58.55151022634199, 62.74199008941651, 62.05431230606572, 60.70343625160956, 61.81222361903038, 59.57240120057137, 52.75620437437489, 46.60336271409066, 46.24335973493515, 44.34665841441001, 45.150658007591005, 43.87873141996322, 43.871349519298924, 44.74598315454299, 38.37718363731138, 36.781755647351666, 36.24222578540925, 41.71142185887983, 45.583099319088845, 46.65205893977996, 44.35660554516701, 41.011318006823146, 41.95280059691399, 45.043369416267645, 45.161071900398504, 43.037916460344874, 48.2269258652964, 43.59003320817025, 47.51858895824802, 53.06433008563135, 53.26270395709623, 53.343030175855084, 51.37962110580937, 51.5283848393348, 48.3857112546121, 49.23602227241763, 53.92835370955929, 54.726018674912, 52.20130666609734, 47.04120120694561, 46.06138137079055, 44.579960992259366, 52.92180684305007, 54.234306427740286, 61.73368600107009, 59.02333213436989, 53.39822969129009, 47.504186014975275, 44.36795688444569, 41.00097863904892, 43.97802229850523, 41.283467738859116, 42.61463388319939, 46.02863350222188, 44.91718676782424, 47.7252939439589, 54.41261737577377, 51.33531401234289, 57.83825466709753, 60.424575344208755, 61.951487371998454, 64.93701119576731, 62.68276622218471, 47.05506286313457, 59.8458610042449, 61.8730164343311, 66.33659132065313, 65.59461616700696, 68.29907863370835, 66.57831130489227, 70.76046005372079, 67.13358556070636, 67.49796590497418, 62.54935464551372, 61.21141849025604, 54.79289116397981, 61.18438159265826, 60.56546688079835, 74.75338582069644, 70.78051905478202, 83.06914790984123, 74.15458894545033, 85.53533815568494, 69.74531142942368, 88.56338439449188, 16.005340333907835, 0.43295364045808393, 0.3648350021291164, 10.303652632621027, 78.55496268118583, 60.95611141573999, 53.31487932512837, 39.055934106149984, 44.397276601483746, 65.8439024033085, 21.10228092439713, 0.38342737382458103, 0.18132058573105644, 0.11848478247561764, 0.0617509231632275, 0.04539730553064616, 0.03762167780810306, 0.08603011873821098, 0.04737913285592391, 0.025611384170911005, 0.12740209187951781, 0.057452518733278404, 0.1447322111456625, 0.14005931995568738, 0.24525270677141606, 0.40429946996511956, 6.182124605101924, 73.02573080985778, 51.84607721144154, 42.3406720161438, 49.26691485989479, 66.14677213853406, 85.68492950931673, 15.645206935944097, 0.8521501191200749, 0.33855015772484964, 0.47164307246285103, 3.2489884476507864, 73.19358471901187, 87.1020269393921, 77.27712508170836, 74.64857224495181, 66.87685858818793, 69.3727647104571, 68.27308900894658, 71.91163647559382, 70.16705251509144, 71.08846433701055, 67.6837372010754, 68.21316303745394, 69.69911375353414, 69.95075733430924, 70.73748280925136, 74.19501289244621, 68.1926804204141, 68.07613895785424, 64.97370496872934, 65.28682385721515, 68.98244965460994, 69.63077822039205, 68.68767569142004, 72.05058251657795, 69.09455099413472, 69.22439713631907, 57.26675356588056, 51.40053126119798, 50.03092196679885, 53.56252993306806, 51.00221457019929, 49.1187826279671, 47.60214721002887, 45.83073815991802, 47.035239204283684, 48.697174902885195, 48.30739328938146, 51.88850941196565, 59.455530258917044, 66.05067406931232, 61.17297534019717, 60.242589135323804, 55.472775197798214, 54.8867730940542, 49.941523305831424, 47.17804877988754, 50.885206345588934, 52.401822151676306, 54.00059984576318, 55.40412979741251, 55.84875791303573, 57.584912700037805, 59.77305396910637, 60.95659778964136, 64.40957792343633, 63.17927552807716, 62.84237138686642, 62.71979339661137, 62.58235746814359, 54.30905111374394, 47.035305884576616, 45.6211345426498, 43.34519493964411, 45.2469325834705, 45.52322433840844, 43.336075428993475, 45.43142126452538, 41.82508037936303, 39.7765362647272, 40.2616746194901, 42.75404276386384, 45.97293584577499, 47.361454886774865, 43.583726036933164, 42.714371911941036, 41.764201271918516, 44.997673803760165, 45.11729432690529, 42.38968203144689, 46.84521213654549, 44.41929286526096, 49.94792069158247, 53.77037632849909, 55.561130508299804, 54.975457883650265, 54.58431913006691, 53.07325347777336, 50.94829374744047, 50.73157495067966, 55.167057821827555, 55.20327306562855, 55.79226793781404, 49.41647875693537, 49.65626893504974, 48.467190650201616, 52.83999012362573, 55.1064532802951, 64.31580974209693, 60.9326321078885, 55.59640830562961, 49.808582413581114, 45.241688374550115, 44.35433057046706, 46.649203454294515, 42.89811142029301, 45.502518146268784, 47.19205556377288, 48.289805381528794, 50.958997895640714, 56.942848159420876, 56.22114381482525, 59.39547092683854, 64.76523883881109, 65.71192641412058, 67.66474508470105, 67.89169342287126, 51.86025657961446, 62.06201191871398, 62.54403198918989, 68.21791695010278, 69.28053409822526, 70.4422930748232, 68.88036604850524, 73.29000442258774, 69.37379237144225, 71.76110375312068, 65.33108780460974, 65.03802399481496, 58.380330147281775, 65.02665304368543, 62.199883230270885, 78.30072249135664, 72.5022905103622, 86.22709520401494, 76.59847659449424, 89.22159733310824, 69.67880372078189, 94.08619926821802, 24.957768801719915, 0.4953475488770393, 0.4089692661598806, 12.887377681270724, 87.12341170157157, 67.29907820301672, 62.34692112092049, 41.995205340846894, 51.19422243487451, 74.14808565570463, 30.508218734495102, 0.36968409354167603, 0.22203488005024774, 0.09446149857174005, 0.08331371651541802, 0.03237363461765551, 0.08088962280101354, 0.017220926839077187, 0.23109118844712936, 0.2707111108447275, 0.2542142194485472, 0.21390342363907447, 0.3557956855623953, 0.20223395868895516, 0.290012757384008, 0.7562126832142954, 7.9881387660580305, 83.25127924642256, 65.04295833649175, 51.23353635111163, 58.38058510134297, 76.48765394764563, 92.62960357050743, 17.48328058950363, 1.3585526231796512, 0.6061734439384553, 0.6768549834528278, 5.222130388982835, 74.9772511759112, 87.34536294014224, 78.3336704008041, 76.93863238057783, 67.5099762024418, 71.33256127757411, 69.3463279354957, 75.13569139665174, 73.61135636606525, 75.9875831296367, 68.67375127730831, 73.47182196955528, 71.13863145151447, 75.1397628168906, 71.04429844887026, 76.21963054903092, 68.66887184881395, 70.29306257924726, 66.2947553203952, 61.556485083795366, 69.7101983716411, 69.94979243124686, 74.37964670119747, 72.03890169820478, 70.268108460211, 73.03516803249236, 60.63832098437894, 52.790136798735595, 52.782095939882346, 54.840108656114154, 51.96195579344227, 54.0882569743741, 50.605231485059186, 50.794925151332734, 50.75950614867672, 50.16663205239081, 51.513268024690696, 56.12170780858686, 62.85169093839584, 72.35269915673041, 63.66302928616924, 61.527620361697295, 59.55714318060107, 55.532501128412065, 51.59812458099858, 50.05397373630155, 53.88069691196565, 55.99714509902462, 56.32433352931854, 60.62994280169087, 60.10325085732245, 59.48421847435736, 64.05522707969912, 64.77186372203212, 69.73308932396674, 68.66977399395358, 64.52731178652856, 67.26968396094539, 63.63160325634865, 55.00956681466872, 46.89135882162279, 45.88647504006663, 44.424286042490316, 47.38486751433342, 45.77593088150025, 44.131155552402625, 46.77719823775753, 45.561490981809555, 42.38580280734647, 41.780373204138975, 47.12327680280132, 48.073243479574884, 48.543653334340746, 43.32296294550742, 43.13975687949888, 39.98354327294135, 45.13092064088391, 45.984408778529016, 42.78668865080803, 48.75515537877237, 46.896818760902654, 49.676779008680775, 57.53512997781077, 57.84631121543146, 57.816532581083244, 56.86441644545525, 55.870111296253825, 51.78440578522221, 52.70300526772776, 57.152130142334975, 57.9680262842486, 58.109357126297496, 49.95865229637393, 51.20598170065111, 51.058241705740656, 56.595271248971265, 58.43455299254387, 65.86048618439706, 63.570959491114465, 58.22154475796608, 53.18092253900344, 49.60996143279537, 45.61286226395638, 50.15980320592081, 45.98349878864904, 48.70308591473488, 50.53619384765626, 49.45249395985758, 54.082910783829234, 59.3419344963566, 55.6628179550171, 63.9846008823764, 67.48455139898485, 69.50863561322613, 70.22654702586513, 66.00460975400864, 56.46205971317907, 64.57980486654466, 64.62066811899986, 73.3036542707874, 71.59755660641578, 73.10956754992085, 70.72568431977304, 76.42906158201157, 72.61719242219003, 73.43101363028251, 68.3478101607292, 68.55126350156723, 60.00385407478579, 68.08778839726602, 67.58924730362432, 81.250133052949, 75.29553582591396, 89.34848600818266, 79.65549345939391, 92.1246454792638, 73.82038731728831, 95.23639509754797, 30.114963862203783, 0.5586761152071338, 1.2375603736408296, 17.190440354808686, 94.01529066024288, 75.86916677413448, 72.7141926365514, 56.65277711806759, 59.45858578528128, 85.23000517199117, 37.42809949382659, 0.7409620176880591, 0.5632777908636678, 0.31776613105208645, 0.29169720086839895, 0.23942126081355158, 0.21928926689490197, 0.09943032186598548], [0.019627107502592188, 0.034255204016282674, 0.048653941466322834, 0.11243096417597226, 0.03700169051186212, 0.0638734501966786, 0.09622248956152508, 0.3318190947175026, 3.913162163188381, 62.88212853093302, 46.61877762886786, 32.8658240456735, 44.43702590081, 56.98758671360632, 83.19591891381049, 17.012682460969497, 0.5545355631939827, 0.3196572037714143, 0.44322654244399845, 1.1795988967341762, 62.37027099055629, 85.50672054290773, 77.0938954814788, 76.7373598775556, 69.21538352966309, 69.41891531790458, 64.75579769380631, 66.29155466633459, 63.452095985412605, 63.94254130701866, 64.2666232201361, 66.23238963465538, 63.81876307149088, 67.3824756376205, 65.78692213181527, 73.75678216257404, 67.41748671377859, 60.52405057414886, 60.698933370651744, 48.09817014201995, 63.53395585090884, 65.97363087438768, 64.4125157786954, 66.4625778505879, 65.3315192653287, 64.61041112099925, 53.6840331938959, 51.50187353934012, 51.23604666802191, 50.23796427634455, 50.95065893665437, 44.02443570475425, 43.03713983105075, 41.56401526543402, 41.57651978154337, 43.458143511126124, 42.73759626573132, 44.479716977765484, 49.38030665920627, 54.002827752021055, 57.817642611842004, 51.69603870761011, 49.80180848029352, 50.27431680310158, 48.839192159714244, 50.50859997349401, 51.72534665753765, 53.813620459648874, 54.10502902923092, 56.11765207782869, 55.13766750212639, 59.57341317207583, 57.18377190251505, 59.454494753191554, 58.8421735455913, 57.94228376880769, 56.651765146563136, 61.67193612744732, 60.51331112461706, 55.06453883263373, 43.24491170144851, 46.07798476372996, 45.47987822563418, 45.34820033657936, 45.439262082499845, 43.22797490704445, 44.53002921996578, 41.58295639099614, 37.238445051254764, 37.472826280901515, 40.579614100917695, 43.62998647074546, 52.10135682936638, 41.66696179297663, 44.92264278473393, 43.59540685530632, 45.23832298094227, 39.736394728383715, 43.72735538790303, 51.79669849334225, 54.68914055055188, 53.41455459594727, 52.01624531899729, 55.624818032787694, 55.31619810288953, 52.99098960814938, 55.11242312769736, 51.050663686567745, 49.67619849789528, 46.678013263210175, 45.26970978706114, 48.16902383681267, 47.390727535370864, 43.19891014406758, 44.71609469382994, 48.02263705961166, 47.61530676195699, 55.4979960380062, 57.95787911261282, 55.19183543420608, 47.59800910949708, 42.43496579508628, 44.308262332793205, 44.20114632575743, 41.395945625920454, 40.79799206026139, 45.68952891134447, 46.493905052062004, 47.835861636746316, 53.075759872313476, 58.01026628863428, 57.24823213392689, 59.221835444050456, 60.50088505591116, 63.0863388892143, 56.068108620182166, 60.4220179588564, 59.96816442858789, 59.32447602671962, 64.90128232586768, 62.05593616731706, 65.4370859361464, 67.17301322567847, 70.64427944921678, 68.29055924569407, 72.56129864723452, 67.196061072811, 68.28769591546828, 60.847587277812345, 59.717050367786044, 57.55676577168127, 67.71830112703385, 70.3052846847042, 80.12191818606469, 74.6661287738431, 84.24086970667686, 75.10015472289055, 89.11701909957394, 26.881640380428685, 0.4534350930442734, 0.404096671169804, 10.577618422046786, 78.25104959549444, 59.380915011129076, 56.211949779141335, 27.17438843942458, 34.51441780213387, 59.03281642544655, 23.93486172922196, 0.14947558242467143, 0.07717286296669515, 0.07676892012598054, 0.09498593938206473, 0.05293665641558267, 0.05478460221521316, 0.045808897759284706, 0.06333007169286571, 0.02695259728258656, 0.07244764797149167, 0.05542152771545995, 0.10118823318231492, 0.04877869505435229, 0.12054685368052415, 0.3086847409365639, 5.1204860883374375, 70.45013781516784, 53.06560877830752, 35.31049420756679, 51.33385489063879, 63.56808439377816, 90.18206027246292, 18.50211428057763, 0.5301212603526732, 0.47234149950165905, 0.42774464093869735, 1.6635676497413268, 67.96749714882144, 87.56985587458458, 79.26313092631679, 81.79462863552956, 71.82773697760798, 72.45410027042513, 67.44874015931161, 68.83114030284267, 63.73316518722042, 66.80846814186343, 66.81478315784086, 69.3948398097869, 65.65469511093633, 70.53348033658921, 68.76745670072495, 73.66083314341884, 70.17878040190666, 61.38819186918197, 64.66436724508962, 53.59065332720357, 62.64579003857028, 69.52489775996055, 64.20672078286448, 69.69243787950086, 68.06501511604556, 68.15831261296427, 56.16042944692797, 53.71609072531424, 54.85785738114388, 53.55222586662539, 52.28773217047415, 46.75739419075751, 46.75201269888109, 44.988868082723315, 44.86524281963226, 46.47800376338344, 45.054579550220126, 47.57042308007517, 51.51303660485053, 55.537898309769176, 59.23742686548541, 53.44871451777797, 51.391129339894945, 52.76961103562386, 51.099034355532744, 51.81264685046289, 54.57312468559512, 54.56135757507817, 54.684543532709924, 58.15397408700759, 59.02092772145426, 61.451404786879024, 59.87804012913858, 58.848249296988214, 61.4290355097863, 59.140520788008175, 58.848923944657855, 62.36010028469948, 62.42243851384809, 58.36054178976244, 45.99249278345416, 45.50928423481603, 47.15615410958567, 46.475395387218846, 45.9882370118172, 45.62172289817564, 44.26204112268264, 43.206213597328436, 38.24114407262495, 41.32687268718597, 42.029341728456565, 46.91520683227047, 49.35139486866613, 42.33643977872787, 45.84825154273741, 42.27379168233564, 44.62735891342164, 40.25991347528274, 45.691066480452015, 53.342920349490264, 55.985491737242675, 56.61573425416024, 55.5534230509112, 58.54439504684941, 56.94124783239057, 55.9355874215403, 58.23402181748421, 53.4084435432188, 51.85053302395729, 48.38478165288126, 47.329362054024976, 49.71717157671529, 47.953673947242, 45.63354099950483, 49.07009816938832, 49.746126513327326, 50.16390600512105, 58.84575466955862, 59.003512397889175, 55.90782096309047, 46.94624846981418, 44.82705854600476, 45.98431464164488, 45.6664026168085, 44.471158366049494, 45.29504437600413, 49.281576679598906, 49.449018739884906, 51.25890624138617, 56.38636973596389, 59.48418709539599, 59.53948859245547, 61.75713000759002, 64.05604685506513, 65.61192166420722, 61.14898220185311, 63.70814831026139, 62.799052730683364, 63.6836217295739, 65.35022897105064, 62.76606167516401, 68.47529503606981, 68.01657384441745, 71.68795939414733, 71.08680125205748, 73.6604409064016, 70.09012699127197, 71.75768344633042, 64.83226037794545, 62.63073990421911, 62.16832383986443, 69.63659901772776, 73.17566733206473, 81.89171514203473, 78.12633391349547, 88.22258533970003, 77.8844884134108, 90.41886944924632, 36.49145318615821, 0.6055230046472242, 0.57497019248624, 12.705853331473566, 87.12887948559177, 66.80622454612487, 64.39346090439828, 30.93210339546204, 42.10332155227661, 68.92608519523375, 33.882206255389804, 0.24318727244052196, 0.15891711047339827, 0.06908149593659947, 0.06592231787621014, 0.03383550657740524, 0.06961159813668459, 0.06853666186573044, 0.16257159502035187, 0.15279128756974975, 0.15980687563217458, 0.29856082773016346, 0.13130868064059367, 0.1667920959692809, 0.35267136450256076, 0.709104772296644, 7.014111290054937, 83.00309519613944, 61.17764296070222, 44.71065436640094, 62.925223612016254, 72.00326304281913, 97.07563369504868, 21.31867220324855, 1.080298702563009, 0.7337663683199114, 0.8709662191329465, 3.5294276187496805, 69.14369829239385, 92.37291582169073, 81.42977760684106, 84.17226745236306, 74.44653880211615, 75.61775069082938, 69.95030233936926, 73.03945126072054, 68.84653168339884, 71.26558288451164, 69.22435006787701, 73.34983625719624, 69.14794229692029, 73.3078904305735, 72.29857829309279, 78.30018904901321, 72.02066267690351, 64.0188745529421, 61.96465084629675, 52.494209658715036, 64.59333312126898, 70.51914015123921, 67.39401525066745, 73.19007812007781, 70.5804624865132, 71.0699664392779, 57.87853348639704, 57.38399713270126, 56.729800701141365, 55.141225091872684, 55.65917015075684, 49.42408815506966, 49.96381413552069, 47.9774631223371, 47.81833648681641, 48.059762293292636, 49.19052277841876, 49.6821173544853, 54.95017036314934, 57.95518836667461, 63.18891279159054, 57.45176392216837, 54.62790842979185, 54.53929032048872, 55.40971133016772, 54.807035230821185, 57.46163260552191, 58.932470429328184, 58.99301613530805, 63.61871042559224, 62.861787119219386, 64.75527209620323, 62.43015773834721, 65.30667497265723, 64.19459673666185, 62.58578954204437, 60.03624893003895, 66.39891778269123, 63.75648760026502, 59.94554019743397, 45.623625247709214, 46.84077201351043, 47.928425650442804, 45.67718129004202, 48.04529266972696, 46.605170926740094, 45.59359165929979, 46.56433120850594, 40.41525110121697, 43.751042581373646, 45.21426316230528, 48.232323046653505, 50.22272194585493, 42.961041927337654, 46.09154439741566, 42.76149918956142, 45.18401776590655, 41.82699057363695, 47.69583694396481, 56.0046015247222, 59.20637346083119, 57.89802766615345, 55.8722254537767, 61.4885849337424, 58.999750844893924, 58.32970411546769, 61.792902023561545, 55.81690826723653, 55.27103593272548, 52.667692169066406, 48.53134101436984, 51.645844136514974, 52.318052091906154, 47.176397462044996, 50.49880973754391, 51.63536748578472, 52.72194247091971, 59.96543445894795, 63.066436782959975, 60.46514441890102, 51.71640757591494, 46.93926272853729, 51.297141505825905, 49.64244258019232, 47.28081095603205, 47.26534897281278, 51.37300798969885, 50.82156196717293, 54.00640103124804, 59.04104948043824, 63.91078972047376, 61.66494254143008, 64.59221132339971, 66.1097998772898, 65.66095913610151, 61.53939139458441, 65.06013047310614, 64.66756397678007, 65.15884084086265, 68.44313944539716, 68.0422261453444, 71.23556890795308, 72.39390757776076, 75.25769279849145, 74.42419698161464, 76.26581253543978, 72.01187656771752, 74.82787947500907, 67.86542923219743, 66.63026702019476, 63.60422903491605, 74.80518464119204, 75.46437817235147, 87.94062968223326, 81.41331149685769, 90.76857228432932, 81.51946652320125, 94.9970599143736, 43.05386873983568, 0.8013084182335485, 1.4309449902465268, 16.45537837859123, 95.05788803100587, 72.98784071399321, 76.22188983425018, 40.35994175941714, 47.220002451250636, 80.20952040149321, 43.14780166072231, 0.4958129319692812, 0.4267482976278951, 0.25097555210513456, 0.19631311027032716, 0.15747571604386454, 0.1421780740061114, 0.14282252248977462], [0.037000943576135946, 0.02876767024938618, 0.07332736205670141, 0.012689608697509094, 0.13355774624693778, 0.058746441237388126, 0.10363114967701897, 0.22366571270169752, 3.464948265783249, 60.464579597596206, 50.72185139502249, 37.76860829322569, 40.81839230752761, 58.872583681537265, 81.53910190828385, 18.329426050186157, 0.72486890059325, 0.46401121263061806, 0.20566928080253064, 0.8742493042542089, 56.884871605903875, 86.38072659892421, 72.73529498807846, 77.25912924735778, 73.42028202549105, 73.33785733869, 64.08613927902715, 61.441814591807706, 58.64474104296777, 62.08776227889523, 61.65648983370874, 64.2824774403726, 63.9339630834518, 68.37735345286708, 65.33539848942911, 72.35179701159078, 63.11470154793032, 65.22342266574984, 63.87946567227764, 47.56734009711973, 67.14101452981272, 64.69666011871831, 66.4296377858808, 64.58391551048526, 64.53536441249233, 62.178274892991595, 55.82239174073743, 49.98819166614164, 48.55733848387196, 50.985877898431596, 51.301416889313735, 45.8712758556489, 42.957084255833784, 41.29392085536834, 41.79444274594707, 43.66476220469321, 41.51853930565619, 42.731202802350445, 44.876621615502145, 47.010096811479144, 47.63527162613408, 48.64874539836761, 51.59560249697778, 49.55237319392543, 50.145549312714614, 51.571248500577866, 51.39570674588604, 52.33392592399351, 52.79626354094475, 52.79270202882829, 53.738150135163345, 56.11256868608537, 53.472691966641335, 57.7012070532768, 55.90544792913622, 57.87498766376127, 61.55052308113345, 62.91764167047317, 58.05168259528376, 60.800605127888346, 52.538030378280155, 44.69066989037299, 49.01574196354036, 48.4741489348873, 45.967111126069106, 47.75087956459292, 42.99191098059378, 43.688021859815045, 37.55411348035259, 39.60162208926293, 40.48543014834004, 48.23734368047407, 49.134746674568426, 44.76224922364758, 45.835099835549634, 45.44620075533467, 40.10363448050715, 43.249751906241144, 49.74888786192864, 51.957421533523075, 56.63820943524761, 58.513973143792924, 56.45316769999843, 57.722968362992816, 56.647364247229795, 55.733173508797925, 52.42319122437508, 51.69904716553227, 54.77915894600653, 52.24607267687398, 48.62690956361833, 51.24665667933803, 48.46585704434303, 44.52430648188437, 45.35810039889428, 48.75269605267433, 51.52723558487431, 56.41794089348086, 52.16145930751678, 48.16870612482871, 43.32048792992869, 42.68195352246685, 41.99285584111368, 42.89265148101315, 41.6345630153533, 43.73461569509199, 46.86291771550333, 45.8023048985389, 47.99235243951121, 55.68693268683649, 58.621257812746116, 60.623929808216715, 57.68193644862021, 61.579023022805494, 62.76049975425967, 60.491306627950365, 63.81152237615278, 62.56254949877339, 64.66470849129462, 65.74090880732383, 61.51701819512152, 62.330776645291245, 62.86618409618255, 62.34309288763232, 64.34594531213084, 69.66280045047884, 69.41788765691942, 67.66464310307657, 61.28925792632565, 63.40748294707268, 56.20350099379017, 61.07862664807228, 62.08581286091959, 74.58553975628269, 73.10109523034865, 83.84595763298773, 71.44183851057484, 90.01240207302956, 41.55336210804601, 0.5291960712882781, 0.34657128215316807, 10.685849362804044, 76.57388333351382, 60.16440060830886, 58.55694663140082, 36.74129639902423, 32.055609456954464, 56.86866829472204, 26.144050436635172, 0.17691456893038365, 0.018859156069435903, 0.08804381149069918, 0.04500618317134438, 0.07910622373944329, 0.07507041126729981, 0.06788259131773826, 0.03196928383512122, 0.10012577648364729, 0.09121068873472753, 0.0236898786087911, 0.10395569516526115, 0.09845902196942799, 0.0614369152143838, 0.5067047717109804, 5.0819943989476855, 71.7857676167642, 53.6444604012274, 34.29694591029998, 46.03491321686776, 67.0538673093242, 88.24116168483611, 21.92455287902586, 0.5887558527531163, 0.5600088630472461, 0.22374199973719738, 1.548155707217032, 62.214949054102746, 88.29401954527825, 75.84156113286173, 80.90306605062177, 76.14876116475752, 75.08790908321258, 66.4215498585855, 63.72165695313485, 60.42959205565914, 65.67904518496606, 64.1073122332173, 67.77221018268217, 65.56281358964982, 70.2901678700601, 70.00132453057074, 75.96086394402289, 64.60844209117275, 64.65829541606288, 69.83299993699598, 51.87533809292702, 68.24575008884554, 67.25645772872433, 67.6169627712619, 69.27013197252828, 64.78184223175049, 65.55562388512396, 55.20151192142118, 53.60419727140858, 51.60267453039847, 53.464847226296705, 52.205715410171024, 47.898615637133204, 43.73746333583709, 42.876255973692864, 45.10905734954342, 45.430366146949034, 44.39907304702267, 45.16661813182216, 47.3354378054219, 49.87752591409991, 49.72557721599456, 53.35800578517299, 51.60187044451314, 52.03064826227004, 51.97023591687603, 54.787337087815814, 53.62703723292197, 55.2826657602864, 55.88650680357411, 55.9316336724066, 58.3748152948195, 59.15472369040213, 55.948919557756, 60.66482051726311, 57.45571767130206, 62.900618583925315, 63.07998072716498, 63.07945512956189, 59.80207558601134, 61.132084631150775, 54.981753287776826, 46.6750636408406, 47.75927735913185, 48.38255374662338, 46.825133523633404, 47.255550892122336, 44.91726521522769, 44.983749389648445, 40.754881289697465, 41.551781392866566, 44.04757376640074, 51.36765787678381, 49.17191113195112, 46.578424284535075, 47.01131666860273, 45.5209925097804, 40.95513397647489, 44.08367526146674, 49.97186283911429, 52.915793849575905, 58.724074902073035, 60.60613009237475, 60.18797797541465, 58.66709855294997, 58.27659522333453, 58.79904708554668, 57.801125511046386, 55.68762302398682, 55.97919633311611, 55.212094476146085, 51.26645288159771, 53.28239817773142, 50.56032819132651, 47.367534560541955, 48.401902798683416, 52.41629569761215, 53.93572776548324, 57.78772669453775, 53.54989990111321, 49.213154854313025, 44.950252348376864, 44.34332439976354, 44.21265848221318, 44.893793752116544, 42.96554480829547, 46.43035873290032, 48.834983456519346, 48.079746769320586, 51.13881895619055, 59.666110546358176, 59.92808957253734, 64.68169235414075, 61.49229549592542, 65.10464152982159, 63.95887797878635, 63.6982011795044, 62.78875650898103, 63.45530840658373, 67.5394332024359, 68.73624247889366, 65.67577000587218, 66.83224554984801, 64.34318396352953, 66.14188486529936, 67.05451842277282, 71.73902080905053, 72.82776094252064, 71.56601290549003, 65.50963801722374, 66.17629974119126, 60.25696462200534, 65.01201475820234, 63.22080166109147, 77.92702259555941, 75.55631852919056, 84.51494924483761, 75.66703134967436, 93.01042649053758, 48.66257959796537, 0.8289770625772015, 0.7299049174593342, 12.481087792304255, 86.46068803725704, 66.75453555199408, 66.10048817050073, 42.603180562296224, 39.98142911541847, 67.56018254064745, 39.91168937375469, 0.07977285812939368, 0.1301988030994131, 0.09525500478283053, 0.05102446265218239, 0.032438947443640044, 0.08924578812213675, 0.08563077242504205, 0.19716585806060224, 0.16515059937392512, 0.12450403488811948, 0.15416200272738934, 0.40792196268035524, 0.3980590403079987, 0.25024199227411903, 0.5750999371370962, 5.876810742962745, 83.16628932952881, 64.96556605062177, 49.138080689214895, 57.26597301421627, 75.04950907922561, 96.6870758610387, 24.061315021207257, 0.9015036482484111, 0.9264026702411714, 0.4317517710789558, 2.7131880242978377, 63.29865678664177, 92.78423124744047, 78.19536762852823, 83.6567581853559, 78.95923353010609, 77.89493760754986, 68.82193057767807, 68.74913138727989, 64.2934443873744, 68.15722219405636, 65.46233815531578, 70.76473543720861, 67.63045572465467, 74.38554594593664, 69.98746287438178, 77.61273091839206, 65.79517087628766, 66.68747871152817, 63.21254899424892, 54.115482145740145, 71.76943486736667, 70.70267569634223, 72.28224554369527, 72.06143179247456, 67.14763549066359, 68.27939618018367, 57.11373798308834, 56.75372323682232, 54.070021875443004, 55.80116387336485, 55.80872620305708, 51.134869129427024, 46.83236245186099, 47.861466869231194, 47.47312476558071, 49.84172644153718, 45.393562547622196, 48.489332429824344, 49.98863489397111, 54.36995767777967, 52.30518279537078, 53.5320060483871, 58.01405529822073, 54.71110974588702, 53.86048493846771, 56.912661598574736, 59.4983821530496, 56.998812537039484, 58.91821653612199, 60.269614265811065, 62.62131837106521, 64.78792190551758, 59.69555970161193, 63.982816203948, 62.259197312016646, 66.67811993629702, 67.43234465199133, 68.22176087287166, 62.33808009855209, 64.0137872388286, 55.07584702584052, 48.64905918798139, 49.24536143579791, 50.62625931155298, 48.41044964328889, 48.581096280005674, 46.589265715691354, 46.025934911543324, 43.494849051198656, 43.80601852170883, 45.67456114676691, 53.59542685170328, 50.25719565729941, 47.658472445703325, 47.98127174377442, 47.09792652437764, 42.39827202212426, 44.010793701294936, 52.229390836531124, 56.94184403265677, 60.48781964086718, 65.48611164093018, 63.14916741463446, 63.42215653388732, 61.99431965428015, 61.73703962756742, 61.80657540598224, 58.10237530739077, 59.070973242482836, 58.32439714862455, 52.713332868391475, 58.328982399355986, 53.5948855646195, 50.486030655522505, 50.676575476123446, 54.60045183858564, 56.73585684068742, 61.390274647743475, 55.91805442687004, 53.43980289274647, 49.15815930212698, 48.462432815182595, 46.262704864625015, 49.06212399082799, 46.37884624542729, 49.918757869351296, 51.904030230737504, 50.812195347201445, 53.87632739159369, 61.19470919332197, 63.20183700130832, 67.95824819995512, 64.4949600773473, 68.42236657296458, 62.42105391717727, 66.39028072357178, 65.47972602228965, 66.32951536486226, 68.96169247165804, 70.51501381781794, 65.60352779203846, 68.00217090114471, 66.33039397578086, 68.38058548588907, 70.14296131749308, 75.27774395481234, 75.25150329835954, 72.75947247782062, 67.97079978450653, 69.13779904765468, 62.16055754692324, 68.79925927808209, 66.96739473650533, 83.22350886560257, 79.85441254031274, 90.82183807126938, 79.06460408241519, 97.57486512584072, 53.409361377839126, 1.5625338905280637, 1.1300895146785246, 16.123024186780377, 94.42837899731052, 74.62013506120252, 79.45140469458796, 54.120294893941576, 45.11788268243113, 77.3950864422706, 51.305500076663115, 0.2845516230069822, 0.1724034295447411, 0.14843321255137845, 0.1983840451125176, 0.39964508745939503, 0.23406626025755561, 0.2381146212498988], [0.06697872248027595, 0.0861930426570677, 0.1520727737055671, 0.089990823950258, 0.037785394627961426, 0.04579235409055987, 0.07155272704098495, 0.2323864592659858, 2.8574314713478093, 61.041983865922504, 52.130676546404445, 34.62522083713163, 39.99944063924974, 50.92170400004233, 83.4128495185606, 25.69955372041272, 0.3053837293578733, 0.37345327677265294, 0.14554147578535542, 2.018473141135708, 54.089402306464414, 85.69545715085923, 77.39832632003292, 87.62142719761019, 74.46382860983573, 76.80753107993834, 62.74329623868389, 62.171873584870376, 57.4296142978053, 61.23724337547057, 59.69400644302369, 65.37679126185756, 61.78882668095251, 69.39339637756348, 65.43503453654628, 71.82855283060383, 61.24311124124835, 75.08397102355957, 57.70759659428751, 51.75910649761077, 70.16085517021918, 63.50544414212627, 68.23565390802199, 62.16352285877351, 62.65559596400108, 60.093452776632006, 56.313119472995886, 49.43694176212434, 49.99917038025395, 49.13108710319766, 50.572550296783454, 47.71247956060594, 43.88548181902978, 41.31807481088946, 40.40360558417536, 42.134351422709805, 42.21699183987033, 43.0621410185291, 44.18263666091427, 43.554076840800626, 47.78090138589182, 50.03340090474775, 46.467927194410755, 47.99806733285227, 52.67888661353819, 52.907501959031634, 49.98049205349338, 53.364367869592485, 52.82319453454787, 53.2118151264806, 53.966494837114894, 54.900062084198005, 54.97634041693903, 58.62016739383821, 54.0249812987543, 55.745348545812796, 55.94133761621291, 60.7322499828954, 59.08924364274549, 58.03227470767114, 51.69588181280321, 51.588114692318825, 46.5979027748108, 43.84744659546883, 47.37146869782479, 45.662272361017045, 41.65910920789165, 43.68076155262609, 45.539078558644945, 40.15897127889818, 40.12457601485714, 47.899682521820075, 48.4100377944208, 44.2119603003225, 48.966414236253314, 43.81863678655317, 44.3858075910999, 46.1233312852921, 50.713626184771144, 53.97724605375721, 57.902620761625236, 54.48165109080654, 54.644354927924375, 53.376990056807, 53.76005657257573, 54.79710378954488, 52.12715033561953, 52.69063018983411, 48.94358996422061, 50.51729979053621, 48.87731759778915, 48.3683116205277, 47.179962896531634, 44.37742548604166, 44.7200249087426, 48.68669825215494, 46.609556136592744, 48.58862330836635, 44.57884311676026, 44.29916635636361, 38.66366963232718, 40.766754304209066, 40.62761214471633, 40.812948057728434, 40.255492964098536, 44.9548375991083, 48.35995697206067, 46.522891367635424, 51.357236139235965, 59.97984132459087, 59.87836568586288, 64.5636329343242, 58.46725379267047, 63.12402894420009, 68.98361852092128, 60.80171123627694, 61.61718376221196, 63.551951685259425, 63.06211825340026, 65.14504194259644, 66.02359402564265, 68.28244778417772, 66.8277426688902, 68.8918193694084, 64.6510233417634, 69.8604408387215, 70.56128209637058, 70.86059816422002, 66.9328857237293, 68.82375055743803, 63.7794138539222, 64.5370392645559, 59.375121670384566, 64.27676254703154, 63.94360426933535, 79.82993695043749, 71.14114176842475, 90.8302947013609, 43.44379548103579, 0.35331447999323573, 0.2924479976777108, 10.19148265161822, 79.98339576105919, 57.329774287439164, 54.880756178209865, 32.21279255805477, 37.369122735915646, 59.58399964917091, 30.477906657803445, 0.041839520431934826, 0.060779516014360616, 0.13219355815841308, 0.022397995813779777, 0.053837449410029, 0.04668164810526275, 0.025012935436661207, 0.044092665456475756, 0.05582719425400419, 0.14075534147841318, 0.08561181940979536, 0.12169082979521445, 0.04680996400214011, 0.09630829906992375, 0.30423462811496954, 3.705627351037918, 70.47669226123442, 59.582450312952844, 40.36329930828464, 47.86573440797868, 58.561108266153646, 91.39368041869133, 29.00633731196004, 0.37921986572684785, 0.39193664947825096, 0.23721462115645411, 3.0844683079950275, 57.06321785526892, 89.97058176225232, 77.4646379101661, 90.93117021745252, 76.74209025598343, 82.94713866326117, 66.315441900684, 64.65432989981868, 59.86952074112431, 63.461921522694254, 61.80772466044273, 67.27927023364653, 64.61582399183705, 72.28954899695613, 67.82606432514807, 73.40850707023375, 63.65657306486561, 73.68701888668922, 64.78778462256155, 52.52015613740491, 72.98602073423325, 65.99723569808468, 72.21355699723767, 65.28720824949204, 66.7751750638408, 62.934084246235514, 58.37680001412669, 51.89024309958182, 50.53438955737699, 52.61838797600039, 52.74932453709265, 50.52722730944234, 44.91225634851764, 45.32979657573085, 44.71434923910326, 45.36434873457878, 45.26080208439981, 44.310792261554354, 45.04057668870495, 46.66358286334623, 49.10610552757017, 50.212959166496034, 49.98790141074888, 51.501038074493415, 54.53759585657428, 55.80128938921037, 52.99905792359383, 54.62153850063201, 54.860983510171216, 55.94107089504119, 57.68692962584957, 57.83168077468873, 55.88267464791575, 60.37195282597696, 57.62821958911035, 59.229111440720104, 59.60749072413291, 62.33567568563647, 60.51668436296525, 60.308928182048184, 53.59555236754879, 51.65638746753816, 46.34582381094656, 46.13583187903128, 48.03496899143342, 46.68565404030585, 43.93937126282723, 45.47529689727291, 50.14470208075739, 43.30950921581638, 42.12769123815721, 48.518554087608095, 48.70405081779727, 46.8693111788842, 49.29421063392393, 46.296919699638124, 44.39496632545225, 44.991362710152906, 51.60373357034499, 55.828106634078495, 59.756481955128336, 55.97325394230505, 57.975239522995494, 58.40761023183023, 57.00722994342927, 56.836112622291814, 55.708125252877515, 55.7186685839007, 53.14422876604142, 52.16536206583823, 50.625129668943345, 49.124462219976614, 48.50552397389566, 48.15688410112935, 44.832251764112904, 48.30280803865003, 48.02997973657424, 50.449446708925315, 47.54988554985293, 45.41241738104051, 42.69682715016027, 43.52507483574652, 42.584329651248076, 43.65323435875678, 43.94746311249272, 44.996053864878995, 50.07581741579118, 50.32459374397032, 54.092681407928474, 62.86501915224137, 64.08040085146504, 64.66094693829938, 62.10682892030286, 66.00297804801696, 69.42762297968711, 63.678907040626775, 64.20757978193222, 64.69405958729406, 64.98692335621004, 68.59751609063917, 67.47400022322132, 70.70707659567557, 67.49332181869015, 70.46550566150297, 67.85542718825802, 70.9123420715332, 71.92018724256947, 74.34765585007207, 69.09845767482635, 71.11770952901533, 67.2289462243357, 67.37060654547908, 62.7835476013922, 68.69571655027329, 66.245788451164, 83.6664072159798, 74.29429592624788, 93.28546308702039, 47.52733584373228, 0.5917858224241965, 0.3359179409040559, 11.894423788593663, 89.49104847446566, 65.41610517809468, 65.00485643263787, 37.23021984100342, 42.069812743894516, 68.94869373690698, 43.37238088730843, 0.028532891113671566, 0.1004204751863595, 0.0713119992325383, 0.09486193272976146, 0.05384334445660634, 0.09486383262781367, 0.019999661805829214, 0.1295701819922655, 0.12582017394203332, 0.2308726695276076, 0.2822963520884514, 0.1805654375423347, 0.2149828874896611, 0.1763773880778782, 0.5048843016547542, 5.141842903629427, 82.07433285251741, 66.85003742094963, 47.405742368390484, 57.6950018636642, 65.70345017217821, 99.93850892589938, 31.719001454691735, 0.4258927306340587, 0.973914830434707, 0.38190135732293135, 3.9572194507045135, 58.38116953449865, 91.85074637013098, 78.72381287236368, 93.35652858980241, 79.46470152947211, 82.97745073995283, 67.38663335000315, 66.952819208945, 62.914135071539114, 66.01683185946557, 63.996838677314024, 70.50883216242637, 66.41995737629553, 74.9036596667382, 70.41161229533535, 74.42508343727359, 66.76072505212599, 69.0258389134561, 63.492300279678844, 58.04453211445963, 74.00361691751789, 70.46897303673529, 74.01336008502592, 69.48801179086009, 69.77877709173387, 66.76674196797033, 61.71356424208611, 55.78220705832205, 55.00617788683984, 55.16838750531597, 56.26622753758585, 53.8762410994499, 49.39090882578204, 47.363647491701194, 46.235016853578635, 47.60296306302471, 47.87630519559307, 47.988343777195105, 50.79068899154664, 48.270475941319624, 53.60505234810614, 55.537098146254024, 51.04012427791473, 54.025683403015144, 58.33796070468042, 61.09285700705744, 55.7583119792323, 59.97945693231399, 60.95816673771028, 59.36512354881533, 61.084749467911266, 63.83895543313796, 62.026487012063306, 64.00455397944297, 61.29435308517949, 62.290882218268614, 63.52005104864798, 64.37977967723724, 63.392852506329945, 63.45009557662472, 55.382870551078554, 53.133191216376524, 49.23360217002131, 47.07589064874957, 50.35583934476299, 46.29979087460426, 46.37358634702621, 47.72592152318647, 51.73373660733623, 45.09111642837525, 44.01130360941733, 51.55588457661291, 50.98774102426345, 47.086222171783454, 51.16427513860887, 46.81686908968034, 45.44885619994133, 48.54541447854812, 53.918889030333496, 58.347899990697066, 61.823374917430264, 58.87494102601082, 60.97879056007632, 62.513327675481, 62.44559618734545, 60.68132585094821, 58.580167062820934, 59.30766867053125, 55.75791189747473, 54.88199564718432, 54.374009486167665, 53.78137073209209, 52.38372041333107, 48.74734986212946, 48.982209620937226, 52.81944867103331, 51.053766281374045, 51.878656418092795, 51.80863426577661, 49.49052133867818, 46.43530876405778, 45.78285386485439, 46.00609948558193, 45.40534534761983, 47.08488072118452, 49.70578885847523, 52.86581500884026, 53.02446311519992, 56.86164725211359, 64.90953107034007, 65.85228843073692, 68.5332441329956, 63.915720139780355, 65.47491327408822, 71.64504081972184, 66.60125717040032, 64.46645229093491, 67.34089851379395, 67.68337634301955, 70.25135209483486, 71.82098265617125, 73.32533713309996, 69.68977066778368, 73.7299374611147, 68.28845685528171, 75.03051696285125, 75.37138662030621, 77.79485441023304, 71.90176779224028, 75.25898718064832, 68.40146033994614, 72.18003642174506, 66.68965170460363, 71.63434059389176, 70.68130662364345, 89.23311341193416, 78.43772303673529, 99.67076009319675, 51.00564664410007, 1.2519923669676627, 0.6109754056219132, 14.028160802779661, 100.34294451436689, 72.59331303258097, 75.22270525655439, 48.3477113323827, 50.89115265877017, 79.26448022165607, 54.77605635120023, 0.17813298580867631, 0.220240548913998, 0.23902710857650927, 0.2020826563239098, 0.14892776827177695, 0.2718496094307592, 0.13401585150389903], [0.04822409336244868, 0.06746175623829327, 0.05938612848460194, 0.06656053040416972, 0.0070527701398297666, 0.047610893605216864, 0.03304078228651516, 0.1786125415275174, 1.7477724797302678, 60.48879631104008, 47.010559651159475, 22.148673188301828, 38.24926730125181, 53.43966560979044, 76.85609002267161, 39.55621673214821, 0.529334518697954, 0.49444984704736744, 0.11532536692797177, 4.181153937693566, 62.22275849311583, 76.92532770095333, 80.09857223879906, 76.16197955223822, 76.0324707338887, 75.56795227912166, 62.34635237724551, 55.76170482943135, 57.903287564554525, 62.89377012560445, 66.90229908112558, 66.27832843411353, 67.54574037367298, 65.60816403358214, 70.582870821799, 64.98843346872638, 72.12339739645682, 71.46929510178106, 41.54131258687666, 65.89917644377678, 64.27112610109391, 67.06389288748464, 65.08468058801466, 63.26205322819372, 59.31190875268752, 60.97308743384577, 53.313934033916844, 50.23212778952814, 48.12480695786015, 48.16810992456252, 47.50149919140724, 47.08706940374067, 43.28919133832378, 42.979763400170114, 42.067424020459576, 43.29254888719128, 39.96202515017602, 42.58492977388444, 43.42752156719085, 44.88057536463584, 43.622537889788234, 48.430877347146314, 43.922191281472486, 48.658327748698575, 49.494682973431004, 51.427619149608, 52.45399751970845, 50.72376551166658, 53.01888550481489, 55.467519221767304, 55.24858036348897, 53.840716192799235, 54.37476650361092, 55.03544269069549, 55.078169068982525, 54.67272543138074, 58.776556214978626, 60.05595491778467, 57.72987173449609, 56.561860499843476, 57.56310039950956, 52.07039363922612, 48.78807190925845, 47.32268617999169, 46.33642188964352, 46.91506954931444, 44.48216453675301, 54.237177602706424, 50.40528082078504, 45.02764071187666, 49.186431746329035, 47.38833096719558, 47.37619515388243, 44.8317575454712, 46.84835003268334, 43.12162376219227, 46.00139656374532, 47.523033003653254, 52.25439202400946, 51.07581000174246, 54.93120178099602, 54.92656161708217, 53.50918962109474, 53.9977208260567, 53.832338010111165, 54.63249368052329, 51.13430823049238, 52.73661605773434, 49.39395650740593, 51.114366900536325, 47.908566690260365, 48.56721108959567, 47.17604837109966, 47.890935636335804, 42.33873828764885, 44.704170688506096, 45.27237699877831, 46.27206756222633, 41.60414895703716, 38.9278922542449, 39.99278829943749, 40.589204295989006, 41.80822987710276, 41.66822479617211, 40.02550871141496, 45.32306186614498, 46.23899805930353, 47.625701042913626, 55.01639566113872, 65.26642360994893, 58.507658127815496, 61.25618450103268, 59.03186721186484, 72.03896445612754, 68.71736018888413, 58.65915575335103, 60.98200298124745, 64.59036388704854, 64.54861417893441, 64.92051370682256, 63.869612678404785, 65.55613379324636, 67.14763549066359, 67.8198669802758, 65.65405968696841, 69.31627473523541, 68.61278195534983, 69.38143314853792, 66.23996765382829, 70.79227832055861, 67.576993819206, 75.49659652094688, 68.68447503735943, 72.29329878284086, 61.16085521636471, 76.82431882427585, 67.2086597258045, 97.13138626467799, 37.51608217916181, 0.6634245428346819, 0.16449495068480893, 10.584460016219847, 82.39724589932351, 60.77687086597566, 55.21928025830177, 37.627861884332475, 38.405758104016705, 56.39101774461808, 35.51404560765913, 0.10551947214069868, 0.06865031100929746, 0.02811725777123244, 0.055898796661847064, 0.09885492088693766, 0.1308751821277603, 0.04707865785026262, 0.12137319442004928, 0.07495598837492928, 0.01732912909750256, 0.0666926269449534, 0.09618246146748144, 0.027660278663519892, 0.05544963165096218, 0.2613475858684509, 3.063963627622974, 69.39483196504655, 50.287852902566236, 33.2291002427378, 48.377301692962654, 59.44726974733415, 83.75883394672026, 45.077847050082305, 0.5461853886804273, 0.9750393862205168, 0.11882705523842767, 5.342487827424081, 66.34960574488487, 75.89149290515532, 83.21595438065069, 78.40226481037756, 81.48018006355532, 78.04368957396477, 65.69938267430952, 59.777019485350586, 60.023367866393066, 65.42884111404419, 70.46980457921183, 68.65795981499457, 71.43961060431697, 69.00805488709481, 71.2450610437701, 68.97262019495811, 68.26397342066612, 77.77637220198109, 48.37375979269705, 67.76578534033992, 67.17485673965948, 70.1334378027147, 65.94134192312917, 65.08162898402061, 62.28364544530069, 61.7520191592555, 57.967128061479144, 51.37584386333343, 49.12904747070805, 51.060524525180945, 53.50211366530388, 50.35179145874516, 46.63392974484352, 45.143236883224986, 45.071077039164884, 45.52853130525159, 42.3579579014932, 44.91531579725204, 44.200989430950536, 45.56133408700266, 46.361595661409446, 49.861028425155155, 46.592956666023504, 49.4090223312378, 52.24391929564938, 55.94719371488018, 54.26073143559118, 54.91442580376902, 56.34725586060555, 59.27481097559775, 58.6729311173962, 55.97092013205252, 57.49989532655286, 55.826451393865774, 59.61856357512936, 59.532761727609945, 62.27317271694061, 64.18774043360065, 59.90844634271438, 58.27932911534464, 59.17210763500583, 53.576164091787035, 50.191315527885195, 50.1884521976594, 47.46744517357119, 47.47153228329074, 43.952232714622255, 53.80134344100953, 54.31732731480753, 50.79824739886869, 52.94201489417784, 48.05007403896701, 50.225365623351074, 46.46269475260089, 45.58731194465391, 45.429063920051824, 45.22213535924112, 47.63282798951673, 54.60049106228737, 54.77541308249197, 58.1160016213694, 57.93499208265736, 56.561770285329516, 57.19021635670816, 55.680060694294596, 56.92352656395205, 54.9648831736657, 55.15907579852689, 53.151928378689675, 53.331988703820016, 52.27005012573735, 53.49478667782199, 47.7352685313071, 50.00736028917375, 46.062118776382945, 46.02497785322128, 46.48624466311547, 47.462808932027514, 44.032421650425086, 42.21305378021733, 42.263738647584, 43.30538680476528, 43.94261898532991, 44.95778722147788, 43.3940206035491, 47.9657313131517, 49.30077668159239, 49.6583281793902, 57.30815026067919, 65.41931759926581, 61.00694141080303, 64.04822172657137, 62.19564707048478, 72.00135677091538, 70.75695345478674, 62.87561739644697, 62.18634320843605, 67.41588638674828, 69.1923592167516, 68.37061482091104, 66.64769803324054, 69.83157219425325, 70.08416498861006, 71.27556923897036, 67.4089987047257, 71.16887292554303, 72.27649534902265, 71.49831279631584, 68.1337271967242, 75.94116580101752, 71.99667346092963, 77.56266578551262, 72.01069201192549, 76.46022089066045, 63.972943598224276, 80.15770589151691, 70.40562675845239, 99.20166031006845, 37.90624426257226, 0.6104568560277263, 0.08877650564236027, 12.5686135215144, 92.06352710723878, 67.6684791811051, 65.84402791915402, 42.471996891883116, 40.76909595920194, 64.78551749260195, 48.752656828972604, 0.11477811201926201, 0.11400787189843194, 0.06049733135789152, 0.035862927625496546, 0.13426964111145467, 0.028018127909050356, 0.09059676885484688, 0.2873115007194781, 0.16824885812257567, 0.09571955283923496, 0.20617083856655707, 0.24715160890933008, 0.22127697394499857, 0.33227994256923277, 0.4059678256031006, 3.919304594878228, 79.88334394270375, 61.748194848337484, 29.87863909813666, 53.017787241166644, 69.68820171971475, 90.83876702093309, 48.857219373026204, 1.2207729970255208, 1.5888059259422365, 0.17585217351875, 6.854506615669497, 67.32243199502268, 80.01336266917568, 82.43832880450834, 83.2281215729252, 80.9904250790996, 83.30125024241786, 67.06860757643177, 61.90908655043572, 63.016732508136386, 69.53903398206158, 72.23694216820502, 72.6249744046119, 71.80837615843743, 71.36678787969774, 70.91950431946786, 71.90480370675364, 65.33589270807082, 71.83602886815225, 53.34000210608206, 69.5043602297383, 68.42929347868889, 73.09059896776753, 71.70599445219963, 69.15918380983415, 64.97919236460041, 65.46124773640787, 61.14613848347818, 55.759076841415904, 52.858797888601984, 53.17474088361187, 54.664037381449056, 52.01344866906443, 50.06630174575314, 50.4743145358178, 49.378082675318566, 48.897545260767785, 45.24314749625422, 48.23662588673253, 49.10071619095341, 51.654540031187, 49.554601100183305, 53.89693552447904, 49.84554290771485, 53.54659334305794, 55.865671173218765, 59.21857987680743, 59.46865450951361, 59.75315186285204, 61.28934421846944, 64.19678934158819, 63.636851387639204, 59.86639853446715, 61.33431811486522, 60.40060574008573, 62.779801737877634, 61.14130612342589, 65.77713974060552, 66.33607356779038, 63.076921278430575, 59.97021975055818, 63.508076052511896, 55.86492984525619, 52.564380861097774, 51.56962071695636, 50.037739046158336, 49.35971421580161, 46.983510986451186, 57.76175668162685, 57.67506053370815, 53.95597896268291, 53.744371014256636, 52.00136384656353, 50.74601319528396, 47.78623580932618, 46.54324454645957, 44.878512197925204, 48.33164922652706, 48.53699707215833, 57.06710492410968, 58.05199246252737, 60.07160125240203, 62.044957453204745, 61.5654202430479, 60.734893660391535, 59.700662705206106, 61.869313716888435, 57.54513202175018, 58.63838288091845, 55.11282320945494, 57.16243813114782, 56.385416600012014, 54.800979091275124, 51.07447639588387, 54.36467424515755, 47.835720431420114, 49.291582645908484, 50.74635444148895, 49.346688024459354, 46.54002820291827, 45.583683752244525, 45.514701028024, 46.250192503775324, 47.33343347426384, 47.37155498996858, 47.218206005711714, 50.740208087428925, 50.34926545235419, 52.104682999272505, 58.95281968578216, 70.45395035897532, 64.59352531740743, 67.97946822258734, 64.78328958634408, 74.31764187351351, 72.50880164484825, 63.837472777212824, 63.41325667596633, 71.51023680163969, 69.80583360118251, 70.6064050428329, 68.9316314266574, 72.35887296738164, 73.10759852009436, 75.39784692948865, 69.39156855306318, 73.98206741579118, 74.05257594200873, 74.67271051099225, 72.93672438590758, 78.86239805529195, 74.18724659950503, 82.35944994034307, 75.51894618618873, 79.81903276135846, 65.18808603286743, 84.6163268243113, 74.7044973988687, 104.24660498096098, 43.86106506470711, 1.5690681915129385, 0.30322339205491927, 14.428777963884416, 102.33952506895989, 73.52391104544364, 75.94453903936571, 54.4620902307572, 55.74726658482706, 75.02443728908416, 63.25946838625016, 0.2428202243942407, 0.21838517589194162, 0.18906173566656728, 0.2441146984816559, 0.18091226086741496, 0.1934456738132623, 0.1607667991230565], [0.037400799337774515, 0.03866792791673253, 0.005705670600066022, 0.02661403430054986, 0.046868156040868456, 0.057156134637132774, 0.0998548494892255, 0.3811008260855752, 3.2940961949286924, 58.363377663397024, 46.03865123564198, 33.07814782665622, 33.2568431669666, 57.34562850767567, 68.00104910327543, 54.50012153194797, 0.05415048825764849, 1.3195795854253154, 0.6459676666605858, 10.4490666620193, 78.41119212488975, 74.04899089567124, 76.61979075401061, 76.34979832556941, 81.40625123054751, 68.01884097437706, 59.17031903420726, 60.21969033825783, 66.92562149417016, 69.19065690809681, 70.30217816752773, 68.48026860144832, 69.20065895203622, 71.74175077869047, 66.99387073516846, 74.01197941072526, 81.97877607037945, 43.739349995889974, 53.98620474723078, 66.49308604578819, 66.40129473901564, 65.06831645965576, 61.12277684673187, 59.82657471010762, 57.73191136698569, 56.75240139807425, 52.68494275308425, 48.01138770195746, 48.874422888601984, 48.35871750308622, 47.34261574283723, 47.15745241411271, 44.36608199150332, 41.68910749496953, 41.644843547574936, 43.323312036452755, 41.46641492843628, 41.2653777676244, 39.81374779055196, 42.299867599241196, 45.708591630381925, 43.46899670939292, 43.120337224775746, 42.597493125546364, 48.6021044946486, 51.03826507445305, 50.493177213976466, 51.25687053126674, 51.818667688677394, 52.30886197859242, 52.14318498488396, 52.16274192256313, 52.635995495703916, 53.62378951041929, 53.3270465174029, 57.1099607406124, 59.69246887391614, 58.08235945240144, 56.00945349662535, 56.98325641693608, 54.8428503928646, 53.292251171604285, 51.97557034031038, 48.00661025508758, 45.649061818276685, 45.53509343054987, 42.87435362415929, 56.91286556182369, 54.64846557186496, 56.40387527404293, 53.34647793923655, 48.94884594025151, 47.27520981142598, 46.19262779912641, 45.87771638747185, 43.83896643115629, 47.49987925252607, 49.75497538043607, 52.71614520780502, 54.05407744069254, 53.22458244139149, 56.374237845020915, 55.29746094057637, 53.801786668839, 50.45489880346483, 46.96779797154088, 49.83562323354906, 51.20396168001237, 50.26693490243728, 50.692033536972545, 49.51724836903234, 48.57147470597298, 45.79735878975161, 44.83113781098397, 40.78214960713541, 41.562477696326475, 43.34441046560965, 42.93671930989912, 39.72949527925061, 39.27020142155309, 38.69684111687445, 39.27653212701121, 38.86111390206122, 41.61379406529088, 40.21910905838013, 44.74405727078838, 46.89825434838572, 46.46183967590333, 52.280216909223995, 63.976654160407286, 60.18010577847881, 60.08967945652624, 57.526720416161325, 67.59822953131892, 67.58170066341278, 56.34181945554672, 59.156190656846576, 61.54306665543587, 63.90087396867814, 65.88605219318022, 68.13506864732312, 68.44004861770138, 67.99825637571274, 66.7328997581236, 64.9281740957691, 71.03759904061594, 69.37054464893957, 71.74829329213789, 69.17637163592924, 74.88858992053618, 69.626110599887, 77.27366555121638, 68.42346483661284, 77.06677621410739, 66.76490629872968, 82.2545971408967, 68.02901560260405, 99.78435977812737, 21.009512947451686, 0.2784292321772345, 0.10301336871399995, 11.400239467620851, 86.45990356322258, 55.29952018491684, 59.98351266307216, 32.821312988958056, 38.93791783240534, 65.01854942690942, 34.67671371275379, 0.1999380085016451, 0.05745501234947194, 0.0344745579716419, 0.14393978511854527, 0.07462153736982616, 0.031829298503937266, 0.027877681009892016, 0.05649613456860666, 0.008089489157071278, 0.036292243298263326, 0.05650891291518366, 0.09697937676983495, 0.12208023228712621, 0.053234940409780517, 0.29923311584899503, 4.022942685311841, 70.43182034646311, 51.377475569325114, 36.47071953742735, 41.881213418899044, 63.654478519193596, 73.46882527874362, 61.54048181349232, 0.17125158570706847, 1.9116341514933495, 0.8821583346974466, 12.752104939952975, 82.7562604411956, 76.93306261493315, 80.8110394016389, 76.70292146744268, 84.0061786097865, 71.50248619817918, 63.16372333034393, 62.83442858726748, 70.88292429524084, 70.91212241880356, 70.86580707180885, 69.1103110774871, 72.62054212631719, 73.06933187669324, 70.31389036486226, 68.18065443346578, 84.58785041686028, 49.89985204512074, 57.1216219471347, 68.87421577207505, 69.00400700107699, 68.15020899618825, 64.56560196415072, 64.44003905019453, 60.002704820325306, 60.306872860077895, 56.66121021393807, 51.056837497218964, 50.88573978793237, 50.85374501443679, 51.67626996194163, 51.308481077994074, 49.47758143947971, 44.2518586497153, 44.32773690069876, 45.35293071500717, 45.348498436712454, 45.08487985980126, 43.0398109651381, 46.543993719162486, 46.81194259274391, 46.9971529899105, 44.5102055611149, 45.7532399700534, 50.194096488337365, 53.297989599166385, 51.908148719418435, 55.946542601431574, 54.80578399473622, 55.09141491305444, 56.38312201346121, 54.6613819368424, 58.556024874410326, 57.789829084950114, 56.201355457305915, 60.13934058527793, 59.913729775336485, 58.79571307090021, 59.54232054371988, 59.668750301484145, 56.00018885827834, 54.994175434112556, 54.12054200326243, 50.11300148502473, 47.337081278524096, 46.48158880972093, 44.51674022982198, 57.99234497931696, 56.50944586723082, 60.76877901631018, 55.58126795676447, 53.10278500280073, 47.62749748845255, 45.61234843346381, 45.68918766513948, 45.99539533738167, 47.92963374045588, 54.02909194269488, 57.01394504116428, 55.87026426869055, 57.02843819895099, 57.70458421399517, 56.382102197216405, 57.59998244623984, 53.67960091560118, 51.898927227143325, 53.594811039586226, 52.23816910097676, 52.299256094040416, 53.285830251632206, 51.146883349264826, 52.1806828437313, 49.53219652175904, 48.89075956036968, 43.19147725259104, 42.72070653976933, 45.5270564940668, 45.9428551889235, 42.77491369555074, 42.001249713282434, 40.43863627218431, 42.567310487070394, 40.89571791310465, 44.311215877532966, 44.17470955079602, 47.66664666514243, 50.35350161214029, 47.71062820188461, 55.39795206439111, 65.4502494104447, 62.733086309125355, 63.562738203233295, 59.2208940752091, 68.41563578574889, 66.04562205653038, 58.71483772031723, 59.844911790663204, 65.5660613121525, 66.54710492780133, 68.38318209494314, 68.54628993618873, 71.6269116247854, 69.07635904127552, 70.47806509079473, 68.0741620832874, 72.94548696087253, 72.40510202223255, 74.73953985398816, 70.31627516592704, 76.45065815218034, 72.90037185915055, 81.28092365880167, 74.20166523225846, 79.77627108173986, 68.25484214290496, 84.86797824982675, 71.88835328625095, 101.98993990498205, 22.1102947573508, 0.19654926453386584, 0.1553886014247133, 12.678520294927782, 95.93216865293442, 61.312686243364894, 69.51285608353155, 35.400077219932314, 40.422566321588334, 72.32294405660322, 46.476324988949685, 0.06962492806656707, 0.03775243369501926, 0.07127807685925115, 0.12714785028008685, 0.04147441441854162, 0.06527971566444443, 0.05493475927881176, 0.24875947424480993, 0.20334020497337466, 0.18861314522162562, 0.13907207776942562, 0.34434613381181994, 0.21488881189255946, 0.24996256936461697, 0.5489228966255342, 5.5770122235821145, 81.96131367837229, 60.30641002039756, 41.83707498734997, 46.796123673838956, 75.74514142928585, 79.43891586795931, 66.68349358343309, 0.5462466144273358, 3.3863579409737743, 1.224379738973033, 13.670529876985858, 82.01201423521965, 75.53545151987385, 82.3742921890751, 79.56360017099689, 87.10125815483832, 75.09161180065524, 64.0803380935423, 64.90723648378926, 72.82563501788725, 72.81369532308271, 74.81135845184326, 73.97371276732414, 76.29249249735187, 76.01991914933728, 74.04244838222381, 68.94226104982438, 77.57314635861304, 58.27432024863459, 59.05990039148639, 71.37148687916418, 70.11114305065524, 69.91440480755222, 65.35988584641488, 67.5351970426498, 60.735905631895996, 63.89984238532282, 59.235650031797356, 54.35176964729063, 53.79989216404577, 53.51655975464852, 55.68523430055188, 53.14055742756013, 50.790249686087336, 47.39226902684858, 45.29272233286212, 50.10685120859454, 47.24186966496129, 47.05077571253623, 44.77849960327149, 48.89186959112845, 50.208232710438395, 49.58479158339962, 47.39266518623599, 46.457391708127915, 56.016654968261726, 56.192051595257176, 56.03547057797832, 59.033640123182735, 57.02959529815182, 58.20314099711757, 58.95146254570254, 60.08781633069439, 63.403693937486224, 61.66189093743602, 59.503257659173784, 64.92561278804656, 65.65235737831362, 61.54137611389161, 64.06743741804554, 63.17502367881037, 59.8249351593756, 58.34391486260199, 54.34715693996799, 51.46109657902872, 48.16239110885128, 46.7210259745198, 46.391319382575254, 62.46597290039063, 58.77736814560429, 62.540968618085316, 56.89861951335784, 55.81805752169702, 49.74533027218234, 48.02676731540311, 48.224227274617846, 45.80162240612892, 50.14850677982454, 55.589583381529785, 58.79235159966254, 59.601822899233916, 59.616924024397335, 61.74264861691383, 61.81575375218546, 61.30563382179507, 56.389621380836736, 54.70729720207953, 57.34886446306783, 56.71242067890783, 56.52245244672222, 57.58207290403305, 55.65320422572475, 56.41070804288311, 53.863018789599025, 50.517817543398955, 45.50792709473641, 46.86129777662216, 47.731279480841856, 48.35630916780042, 45.92216468626454, 44.61609386628674, 44.92506680950042, 46.29211087380686, 43.09127246179889, 47.849695836344075, 46.45955293409286, 49.92935219118672, 54.208171675282145, 51.34031111194242, 56.54900297041863, 68.45527525871032, 64.59448237572947, 67.03139212823683, 62.63503882192797, 73.45369277461883, 70.34714421918316, 58.78877832043556, 62.48517682475429, 67.82779801276423, 68.30854723530432, 70.44005732382499, 71.21835754763696, 74.64678364415323, 73.1817626953125, 74.241147810413, 69.46435989872103, 76.88921051640665, 74.06493140805152, 78.1418586546375, 74.05712589140862, 80.18617445422758, 74.95628218497001, 83.82278427000969, 75.4388435425297, 82.87969743051838, 73.18514377840104, 91.07283838333623, 77.27335960634294, 107.71867921275478, 27.014742089856057, 0.7074734340271642, 0.3839037579394156, 15.593078636354017, 107.35768779631584, 68.00797600899973, 81.31821755440005, 47.74255237271709, 55.40437690673336, 85.20194453577842, 54.44183903355753, 0.2474917672694691, 0.2200709370475623, 0.11200027720582102, 0.24203827844992762, 0.19275343676488246, 0.1847542224511985, 0.13016969175829043], [0.04669979289774934, 0.03350273713529591, 0.08798545857350673, 0.10865729166975907, 0.04360650989016698, 0.04363449891248057, 0.055010356835179755, 0.21256192707486693, 2.3786500528935464, 58.46856778667819, 47.441679123909246, 47.718908325318374, 38.57223918361049, 54.86998142734651, 64.00480108876383, 67.52183744984289, 0.843206502256855, 0.9597023672634556, 0.18542453406318543, 20.34297085577442, 84.61324384135585, 70.35469870413505, 77.58574501160653, 72.42924813301333, 71.0861893623106, 60.331387673654866, 67.04062538762247, 70.48046558134018, 68.21528111734699, 69.33451375653668, 71.18188734977477, 71.42784349380001, 72.64576296652518, 67.42556679633357, 74.0798834831484, 84.42011417881136, 42.284429150242964, 48.035945661606334, 65.73040470000237, 65.36691473376366, 65.97130883124568, 60.58390986534857, 61.286637783050544, 56.65680539223456, 57.01201131266933, 54.295479712947724, 53.33356941899946, 48.880447649186664, 47.58674013999201, 46.257178245052216, 46.96252238365912, 46.60228406229327, 44.6169214863931, 42.73462703151088, 43.40438742791453, 45.17687905219294, 43.65322651401643, 42.10474537264916, 42.62322387387676, 44.45040902783794, 43.32264523352347, 43.2393301686933, 41.64196452786846, 41.26655840104626, 47.212573482144265, 49.98271603738108, 50.21247671496484, 49.31757619304042, 50.8192007003292, 51.40670114947904, 51.98573320142685, 53.05727374169135, 52.33383178710938, 53.27482408092868, 54.35589990308208, 56.121845091542895, 57.23402138679259, 54.22870136076405, 57.86096911276541, 58.82571920271843, 58.848943556508715, 54.83415842056275, 54.73288282271355, 53.33713877585627, 41.32475460729292, 45.34280315522225, 44.19242689686437, 58.322498721461145, 57.394022710861705, 58.660909052818056, 56.83694416476835, 51.297780852163996, 46.19234538847401, 45.90563581835839, 45.71679722878241, 49.51988812415831, 51.48865907422958, 52.36341822531916, 52.575971464956964, 53.34242613084855, 53.53801904186126, 51.35260774243263, 52.11126081405148, 52.03229173537224, 50.169330643069365, 51.12777748415547, 50.445779292814194, 51.76502927657097, 48.46217393875123, 50.82739845398934, 47.07321951466222, 49.75035090600291, 45.552112594727554, 46.0698183890312, 39.54479086783625, 40.896243510707734, 41.6913628578186, 42.38887794556157, 40.187122129624896, 38.56829327921714, 39.369351094768895, 40.943217815891394, 40.719281858013524, 42.22822943041402, 41.77952597218175, 44.824477626431374, 47.16335558122205, 44.50992707283267, 49.31929026880572, 60.77054408288772, 58.67050709262971, 59.619312747832275, 62.37766858070128, 58.316026810676824, 62.901936500303215, 63.084977826764515, 59.632456610279704, 64.33192676113498, 63.22434748372724, 63.09980830838604, 61.38128457530853, 64.07326998249178, 59.68546744315856, 66.7965441365396, 64.64539474056613, 72.17787127340995, 67.76083530918245, 75.31248046505836, 69.36412765133765, 75.70202673635175, 70.35937416938044, 78.11273113373788, 71.66157753236833, 80.83722514490928, 69.42813288780951, 82.78198334478563, 68.35767884408274, 95.19854422538512, 6.16619291805452, 0.11794026250079756, 0.4137030766615945, 16.181330219391857, 80.17195193998276, 59.09699424620598, 53.05599504901517, 40.4358043209199, 54.1227149963379, 59.82347996004167, 49.76236512584072, 0.08895817573272413, 0.06180760600874501, 0.029924725400163766, 0.08525077749284045, 0.06172516345677357, 0.06095817920962169, 0.08899461087440291, 0.10145503096282484, 0.029779724108295578, 0.06935499698644684, 0.08420967932550177, 0.05350691694465857, 0.06676817853604594, 0.1594193883600735, 0.2526888924260294, 3.2891250810315533, 71.37337746158724, 49.53722892269012, 45.35342493364888, 43.89382077801613, 64.16738333240633, 69.06436443328857, 74.7287376465336, 0.9215882672898231, 1.1716878438188185, 0.1302436192429835, 24.48373663809992, 87.39869148500505, 72.88561590256231, 80.10520888913064, 76.16491348512712, 73.44170601137223, 62.88800424145114, 67.3257032517464, 71.54344358751851, 71.09462245818108, 70.39837037363361, 73.19938982686689, 72.77445593187886, 73.181182184527, 69.85988386215703, 69.00589758350004, 84.6897457491967, 51.29423895189839, 50.43792670772922, 68.22631082227154, 67.50686184052499, 67.72046627536898, 62.28770902079921, 64.61433349117156, 59.35913801193238, 59.401099528035815, 56.42309881025746, 55.234004835928644, 50.460374432225386, 49.5919067628922, 48.1835562183011, 49.005190787776826, 48.811221738015455, 47.79625354274627, 45.57497216809181, 47.414618692090436, 47.822133341143214, 45.54687623054751, 43.74153475607596, 44.49522995179699, 44.05104898637341, 45.40249378450456, 45.38255637691867, 43.05723021107335, 43.235627451250636, 50.442747300670995, 51.12832269360943, 54.08010628915603, 53.991366586377545, 52.34351611906483, 55.29307573072372, 55.05044183423443, 56.0573495587995, 56.278194688981586, 56.836002795926994, 58.430944411985344, 58.946943975264034, 58.58647031168784, 60.55669646109305, 58.858694568757095, 62.12032187369562, 57.99094077079528, 56.83592042615337, 55.597800747040786, 53.34416374083489, 44.54578145857781, 45.13057939467892, 48.01214079703055, 62.52219223207044, 60.079547974371145, 61.15284965884302, 59.220035076141365, 52.46891821584394, 47.530842442666334, 47.16426164873185, 46.84219583388298, 50.08450154335269, 52.03552376839423, 55.78806315698932, 55.12872057576334, 54.92703230150285, 54.9590309973686, 53.19543923101118, 53.726328111463985, 55.09008130719585, 53.72470032784247, 54.32135951134467, 52.82785823268276, 55.825023651123054, 51.98666672552786, 54.53570135178105, 51.61599097713348, 53.109335360988496, 49.38529591406546, 46.464487275769635, 42.03163631500737, 41.57123634892125, 42.48067709707445, 44.63807090636223, 42.00964750782136, 40.25830138114191, 42.528871259381695, 42.613053168019945, 44.21699662362376, 45.38660034056633, 43.682350112545876, 47.914163912496264, 48.37252424609277, 46.820618875565074, 51.44244570885935, 62.8729070386579, 60.324135211206254, 63.432252714710856, 64.65080368903376, 59.48446950604839, 64.01422262191772, 63.14141288880379, 60.21736829511581, 68.18401982707363, 65.32037581166914, 66.37602683036559, 63.58124786807645, 67.26728347039992, 60.87214915983139, 67.35388940380466, 67.44066007675664, 73.65757757617583, 71.62448760001891, 77.79835316442674, 70.85310643719089, 79.22098898118543, 72.72553613108974, 80.36652503475067, 73.18324535123764, 83.87945467425932, 73.95397540061705, 88.10219210963096, 74.4328732644358, 96.24680549867692, 6.141604069740542, 0.10899008792494574, 0.5902640653714057, 18.043793170682846, 89.83475008318501, 64.82707892694782, 63.72926242889897, 46.004020629390595, 65.2770689225966, 66.036098541752, 66.06122524507585, 0.18706984577640412, 0.06261955195617291, 0.06528375294780539, 0.06745428688103153, 0.05339146366402988, 0.0701616722489557, 0.0982411772072796, 0.13416027439938438, 0.11550722854031671, 0.11446288982105833, 0.2327369751348611, 0.12806893311320774, 0.2603002517454086, 0.27666545262740505, 0.3715340120177115, 4.439166467035971, 83.50256981388216, 56.38534207497874, 61.94181088478335, 53.133618754725305, 73.02316557976508, 75.15829993832496, 83.17428311994, 1.0953300830817994, 2.4817311667626907, 0.24842225766230017, 25.049079618146344, 89.44245815277101, 75.43689804692423, 81.54365185768374, 77.97642092550956, 77.70790330825314, 64.45293580332111, 71.51201755769792, 74.16640312440934, 74.41097859413394, 75.4451193348054, 76.09747225238432, 76.78904102694604, 76.58722723684004, 72.94737754329559, 68.34985763795915, 80.05995258208245, 59.64725571293985, 54.26351239604335, 70.54167809024935, 71.78637166177073, 70.87744866648029, 66.89114386035551, 65.83849737721106, 59.78433470572195, 63.55299895809543, 60.081634675302816, 59.17516708374024, 53.46347831910657, 51.28654326162031, 52.251536538524014, 51.6406273841858, 51.7158035309084, 50.278568652368364, 48.24823610244259, 50.08899657957016, 51.50318361097767, 49.83924750358828, 48.15183208834741, 46.74271275920253, 49.13976338601882, 49.35520741247362, 48.24454907448062, 46.624461143247544, 46.78782786092451, 52.17676831829933, 54.19756166396603, 57.75055831478488, 56.36615384009577, 56.13597346890358, 59.67909359162854, 56.678045026717655, 59.098002295340265, 60.26518590988652, 62.282158867005386, 62.05607737264326, 62.467879172294374, 62.86550552614274, 61.068863868713386, 62.553630029001546, 62.54472232634022, 60.74542130193403, 58.52772497361707, 58.14274041883407, 56.623959464411584, 44.89153446689729, 45.93301396216116, 48.11642485280191, 63.52231425623741, 63.506205081939704, 63.94204316600677, 61.24396239557574, 54.82077137116463, 49.12004955353276, 46.97400316115349, 48.00302520875008, 52.40383432757471, 53.77258854527628, 57.39219880873158, 58.322761520262695, 59.19533591116629, 61.09642636391425, 57.46735534360332, 58.36994763343566, 59.24092169730895, 57.30402392725791, 56.56079361515661, 56.16663463654057, 60.707009530836544, 54.45126056671143, 58.080621842415106, 55.69340067525064, 55.97004152113392, 52.781370301400464, 50.797984600067146, 44.39462900161744, 45.66202525169619, 47.314119723535356, 47.89009232674876, 46.367589043032744, 43.78335506685319, 47.65700547925888, 47.31799894763578, 48.30865237020677, 49.67393529030585, 46.73564857052219, 51.83756959053778, 50.174790582349225, 49.80589951238325, 54.61706699863557, 66.94196208830803, 61.776306475362475, 67.74560866817352, 64.64871306573191, 67.51019585517146, 69.6198034286499, 61.71847504954185, 65.05216413928618, 67.57023165302893, 68.16796948832851, 67.46032684080063, 65.70722741465416, 68.47374177748158, 62.14775100831063, 70.15153561868976, 68.88758320962229, 78.46732124205559, 73.03106523329213, 81.73798176550096, 74.17752696621802, 81.91537487891414, 76.40831224380001, 84.09751492161905, 76.02177835279896, 88.55132702858218, 77.55604482466175, 93.23382116133168, 77.50914896688154, 105.78274634576614, 8.258556281366657, 0.5104098487044535, 0.8958512676819679, 20.029918647581532, 100.9860327935988, 70.576610719004, 74.44475020131758, 57.79550083221928, 77.11357009026312, 73.59099142013058, 75.54896016274729, 0.18492547374579216, 0.14585975467437698, 0.20241052663374334, 0.27858781237756053, 0.11400778762876027, 0.22664185703521778, 0.21808915951799965], [0.08098679339332927, 0.06627356918949275, 0.025619924136046923, 0.009853764748831671, 0.024316285721837513, 0.03573382265805718, 0.05381915523039718, 0.22836157120764258, 2.34189254141623, 67.34471890234178, 48.65039671621015, 39.86449149347121, 37.567994748392415, 52.39103171133226, 56.74865161218951, 75.77738331210229, 2.4787979693182054, 0.3773616428577131, 0.21051032829188535, 28.812307465460997, 90.1028048607611, 71.07381036204677, 77.02889396298316, 69.85184300330378, 66.56834848465459, 63.2523649738681, 73.24596405029297, 70.75976187183012, 77.28373035307854, 71.62735877498504, 73.02609166791363, 70.06125050206339, 69.92351255109234, 70.92071240948093, 73.6450416811051, 40.383362231716035, 48.01170933631159, 63.94978200235675, 63.70844641039449, 64.54013009225169, 61.8430926722865, 60.57742618745374, 60.222247723610174, 58.65355853111514, 53.06336910493913, 52.366273710804606, 47.419913891823064, 45.90809122208626, 46.5092219075849, 44.70060133164929, 49.5264777060478, 48.31628922493228, 46.01686246933476, 44.48212923542146, 44.752647261465754, 43.49703773375481, 40.942358816823656, 41.01359690389326, 40.923892298052394, 40.79592889355075, 43.4644663718439, 40.699258158283854, 42.70211058278238, 42.024705486912886, 43.46409374667753, 47.69488773038311, 49.43497665466801, 49.43596509195144, 49.60452110536637, 52.54323144112864, 50.955342246640114, 50.66016427932247, 53.82649760092459, 54.35629606246949, 51.826924277890114, 56.529128320755504, 56.77228781484789, 57.895599719016786, 59.41879726225331, 59.66521624595889, 55.99464654922486, 55.63376103678058, 53.020003380314, 50.89876205690446, 50.54280696376678, 47.18190446976693, 47.44983765386766, 54.07383049688032, 55.36808321552893, 54.47490069173998, 54.28861948751635, 49.921985980003114, 47.967680731127345, 45.13181886365337, 47.5730549904608, 50.17053481071226, 54.27941760709209, 50.97642498631632, 52.45911621278333, 54.05004916652557, 53.81338119506837, 52.9341152406508, 51.253799315421816, 51.43146307237687, 50.76103587304392, 48.239010687797304, 48.92536271002985, 47.534333352119695, 47.881718066430864, 49.77325362543906, 50.4600331860204, 47.20245768946987, 47.50637077516126, 43.70882218883884, 39.361274934584095, 39.07410644715832, 38.7019205862476, 39.8271309175799, 39.42294636080342, 40.07023549848988, 38.930104471022084, 40.71522220488518, 41.506442716044766, 41.60015990657192, 41.09679821998843, 47.48041252936087, 47.01576463637814, 45.68595955448766, 43.86297133661086, 54.55845109878048, 60.704852227241766, 57.49683587781845, 63.930123083053104, 51.47160068635018, 49.40621783656459, 66.54092327240976, 59.65486903344432, 65.32773025574224, 64.38054453942084, 65.5875127546249, 64.47599541756415, 66.21961839737432, 61.21872586588706, 65.41117083641791, 63.130747964305264, 64.38458458069833, 63.851016721417835, 67.61976334356493, 69.1623373954527, 72.00509086731942, 70.26437436380695, 71.4399165491904, 70.46323853154337, 76.40946542063068, 74.68119852004513, 75.70700030173026, 78.36643003648328, 65.34173703962757, 0.5545517429709435, 0.13481086690820035, 0.9232561939185666, 22.18690453037139, 79.1983647500315, 55.099314566581484, 52.236611920018355, 34.383159606687485, 32.009396091584236, 61.92604295669064, 47.53901273973527, 0.1124238855235519, 0.14185840083706763, 0.08015343528841773, 0.024781586459627556, 0.06131682327137359, 0.046105465716532165, 0.045439356096809914, 0.06375339655806461, 0.07693262545452004, 0.021491028150663744, 0.05873711411691001, 0.0449678864360096, 0.06715050237553735, 0.024063202830392028, 0.15578411729826083, 2.84099355340004, 78.24295382345878, 51.92994140809583, 42.61151952128257, 48.71737510927262, 57.63441301161244, 62.897857235324004, 83.24554474123063, 2.6203077695062085, 0.4843369042200427, 0.2284301973638996, 31.586313555317542, 94.56053149315619, 73.53210879910377, 79.98392920340262, 73.43432411070793, 69.1140216396701, 65.38550284601027, 75.3369011417512, 73.07431328681209, 77.99518554441391, 73.23585217998874, 76.33585037723665, 71.46466670497772, 72.7933225324077, 69.84857174658006, 71.92367815202283, 47.88811152981174, 50.344652745031546, 65.43044536344468, 67.03659319108533, 66.8711397724767, 64.20213160976287, 63.215282886259025, 62.56136102061119, 61.08298047896355, 56.71648033203618, 55.17428282768496, 50.12187780872468, 47.87947839306247, 48.752998075177594, 48.668384705820394, 51.20865675710863, 50.8009381448069, 48.434725192285356, 46.6992058292512, 47.0443900938957, 45.98134932979461, 44.36537204250213, 44.18593929659936, 43.122529829702074, 44.87632743773922, 43.2894580594955, 44.10331064654935, 43.339448667341664, 43.32068797080748, 45.02148651307629, 51.93096906908097, 51.08026581425821, 52.199776941730136, 54.10770016331827, 53.934562821542066, 51.75327785553471, 53.73938175939745, 55.55363878127068, 56.587838357494725, 56.26107354317942, 58.19916371376284, 57.740564115585826, 59.36237004495437, 60.22304004238498, 62.07468117437055, 58.18121494785432, 57.19494673513598, 56.23777466435587, 51.533130907243304, 50.92302976116058, 48.27512394997382, 50.151985922167384, 56.149066340538766, 58.427630009189734, 55.64448871920186, 57.402957870114236, 50.136904408854825, 49.563285227744814, 45.277542760295255, 47.4252640047381, 54.143225069968935, 58.923998109755985, 55.29227556720857, 56.7074941819714, 57.7512368848247, 55.582170101904104, 56.08317052164386, 55.306349031386844, 54.618024056957616, 53.6456645688703, 52.604655758027114, 50.75778030580091, 50.04730570700861, 51.1147669822939, 52.56460443619759, 53.64028699936406, 51.201992650185865, 49.41964410966443, 45.13659631052325, 42.28304847594231, 41.413972839232414, 43.23443112834808, 43.31139587586926, 42.02436031833772, 42.66709558425411, 40.79452076265889, 43.92022225164598, 43.49146796811012, 43.49681808102516, 44.93336262241487, 48.383189170591294, 48.857254674357755, 48.6773237874431, 47.08186049615183, 55.86889143913023, 62.054637862790024, 60.6365559178014, 64.34501963277017, 54.97541081520819, 52.59074311102591, 66.03662413935508, 63.94463977506084, 66.30626355448078, 66.40734303382136, 68.57486832526423, 66.66351302977532, 69.37994264787244, 66.06379831990888, 69.44608949845838, 66.11341630258869, 66.32476929695376, 66.71958723375874, 70.39424404021233, 70.32095847591278, 74.15598530923167, 72.50071371755293, 73.9503275963568, 74.12421411083591, 78.58030119249898, 76.5222570973058, 80.36195939587009, 84.82094118672033, 63.884556908761304, 0.5059528410915406, 0.4635737457823369, 0.8356302604079248, 26.0434651759363, 87.04628221450314, 61.314855314070186, 61.66782548350673, 42.94108098553073, 42.064246900620006, 70.44086533208048, 52.88759593040713, 0.16862601852945744, 0.0062308530792624, 0.09502936124561295, 0.04715774493712572, 0.031320686985348026, 0.04557815590693105, 0.04707693415243299, 0.16662101321403058, 0.1597308031012935, 0.09616622806436594, 0.1060065891473524, 0.12836152507412818, 0.11519439653643679, 0.2061739182400127, 0.2934756586628576, 4.2792068181499365, 92.24579180440595, 58.301565031851496, 54.40328605713383, 50.35709450321813, 70.33593408523068, 67.16815733140515, 91.209227038968, 3.264605364491863, 0.9342682481773439, 0.2112739647348081, 33.49252662351055, 96.88068405274423, 77.21175486041655, 81.94615764002647, 77.46909372268185, 71.42734143041795, 68.60687486587032, 79.40549727409118, 75.93447423750355, 80.54037232552805, 75.69317786924302, 80.00346260686075, 72.84960854438044, 76.34586811065674, 70.78917964812248, 74.67485212510633, 58.77058244520619, 52.86311249579153, 67.86143625936201, 67.98187655787315, 69.41439674746606, 67.14897694126253, 66.7927315927321, 66.25874796221333, 64.43575189959618, 59.45332980925038, 57.678665191896506, 52.60225526748165, 50.77566239141649, 50.88401786742672, 49.89677298453547, 53.54789949232533, 53.58946877141153, 51.281110778931655, 48.34871545914681, 49.98918794816541, 50.35649830295194, 48.15755874879899, 48.25566507154896, 45.688618921464496, 47.44814318995322, 45.93624207281297, 46.91083338952834, 46.35178581360848, 44.86798847875288, 47.84610686763641, 52.88044544958299, 55.489621777688306, 55.432002159856985, 56.58097813206335, 57.25868525043611, 56.76573353428995, 56.58385715176983, 58.5110862793461, 59.02104147018925, 59.069882823574936, 62.70060908409857, 61.436950852794034, 63.673364731573294, 62.233129239851436, 63.266077579990515, 61.68981821306291, 60.239251198307166, 58.17594328234273, 51.31144246747417, 51.566435752376435, 48.68655312445856, 50.71317511220133, 61.11883486470869, 61.468165074625325, 58.172326857043856, 61.820295856845, 52.93815528192828, 50.30715488618421, 47.01131666860273, 49.8845979475206, 53.81592289094002, 60.902622053700114, 55.88495354498587, 58.81878445225378, 59.85663575510825, 60.20176510657034, 59.348720196754705, 58.46999945179109, 59.07906116977815, 57.11631890266173, 58.876078513360795, 54.752714326304776, 53.31236900821809, 55.26072009917229, 56.50031851183984, 55.825737522494414, 55.287709928328, 52.5515547106343, 48.98794020375898, 44.35984150055916, 44.41118140374461, 44.9175319363994, 46.53525467841856, 44.281425476074226, 45.99732514350645, 43.04211339642925, 46.81404890552644, 46.42487918176959, 48.03654186187252, 47.379297748688735, 52.76430799115089, 51.048671122520204, 50.92734044597995, 47.99106590209469, 58.91817339005009, 64.93548147140011, 62.50204693886542, 66.2998700910999, 58.78981774853122, 60.92591308778333, 67.28177270581646, 65.57908750349476, 68.86735946901383, 69.79270935058594, 70.85838594744283, 69.32771236665788, 73.33292299701323, 67.86864557573873, 71.72608483222224, 68.83751807674285, 68.50514427308114, 69.15599884525423, 72.98729158216908, 72.99510494355233, 76.39250509200558, 78.13883842960482, 76.9440923198577, 74.84662840443274, 83.78738095683437, 80.52025056654408, 85.63868476498513, 89.00880875126009, 72.87550403225806, 1.092207508702432, 1.8520421943356915, 1.3416033262206664, 27.664294435131936, 99.65847522981706, 66.46588048627301, 73.43107638820526, 49.96286884430916, 46.37568873743857, 80.42159511196999, 71.0512645782963, 0.44499733935921426, 0.18841005531289887, 0.2244260243230289, 0.19365598027023578, 0.12403312830194352, 0.17850269984093406, 0.19122199636072884], [0.043093131389468915, 0.013742747851797651, 0.053476426645272204, 0.0938543432482308, 0.08258587170031764, 0.07604315907003419, 0.10237475015944052, 0.10304453317075969, 2.1722517475005123, 60.53329952301518, 53.401249916322776, 40.68695760542347, 25.663909181471794, 53.22956385151033, 48.66974576827019, 83.34102307596515, 5.71418192117445, 0.4007766912541082, 0.12719301882410242, 29.889074563980106, 88.70196957742014, 70.60029399010443, 75.37567769327472, 68.41056808348625, 69.02763535899501, 70.75310953201787, 73.954634358806, 73.15269793233564, 66.94728082226169, 60.9973825946931, 66.18562713746103, 66.84520506089734, 69.07907332143476, 58.30005884170533, 40.2170733482607, 53.36532492791453, 64.89913678938343, 64.76857285345754, 63.741876771373136, 61.87117292035011, 62.95885401387369, 58.739940889420055, 58.425578609589614, 55.60605733625351, 53.52131366729737, 47.77659070107245, 44.274549561162154, 45.514744174095895, 45.444337629502826, 46.843078367171756, 47.586179241057366, 46.098043764791186, 48.43355632597401, 44.61174003539547, 43.98137592500256, 43.473013216449374, 41.5295180197685, 42.57881872115597, 40.03480865109352, 40.33372463718538, 41.79751788416217, 42.54754958614227, 40.808417720179406, 43.637317380597516, 42.07432739196285, 45.42451004828177, 43.85362040612006, 46.6350515427128, 47.05671025860695, 48.33783872665898, 45.800492763519294, 50.02885487771804, 52.683542466932735, 55.437313049070305, 54.099988783559496, 55.32475279223535, 56.12700300831949, 53.591335819613555, 56.817163651989354, 58.618904390642726, 56.64806242912047, 53.15481132076633, 52.00059506200975, 51.4653641177762, 50.833948812177105, 51.30348005602437, 46.82435689433929, 53.643856356220866, 46.24986694705102, 41.83450583488711, 52.97844194596814, 47.53211329060216, 47.93581147347727, 45.83563327789307, 49.67441381946687, 52.83252585318781, 53.83279300505116, 56.78792238235474, 56.52817518480363, 57.13205152942289, 56.90098470257175, 54.88789489192348, 52.744605925775346, 51.970420268274125, 49.42782617384388, 46.36763218910464, 49.346476216470045, 48.487426157920595, 47.8977801722865, 48.7821138289667, 49.48600276823967, 47.95549784937213, 44.28650494544737, 37.67673069430936, 40.7585604729191, 38.48390348495976, 39.899129944462935, 39.42535077371905, 40.10710185573947, 39.417270691164084, 37.99061444497878, 41.24212987961308, 42.553990117965206, 43.07579086672875, 43.00816528258785, 46.42236886485931, 45.782469472577496, 44.88032433294481, 44.98548699963478, 45.65661630322857, 53.00738119309949, 58.13322082642586, 62.04538106918336, 59.22496549544796, 48.29893665928995, 60.34286060640889, 61.31265878677369, 64.43097053035613, 64.31750812838155, 61.83740915790681, 63.6329564740581, 63.98892333430629, 65.08322538868075, 68.63710065041819, 70.90729790349161, 66.98497479961765, 67.00539465873473, 65.24669408798218, 65.9487081343128, 65.78207015991211, 72.52974710156842, 69.15775606709143, 72.27145118098106, 71.7561851009246, 76.77613642907913, 68.677932523912, 74.0472807422761, 24.125063342432824, 0.35718028223322285, 0.8452051337207518, 0.49152611844962646, 25.64200274405941, 74.27282487192463, 48.62838045243294, 49.04509698190997, 31.27214151044046, 48.06836405108052, 58.10948264214301, 38.2271098321484, 0.19148029056527924, 0.01943022865171154, 0.045209127523365526, 0.10342609858320606, 0.009746264418466918, 0.05661507354929082, 0.14151292582673414, 0.013207393161381685, 0.04843770548881543, 0.06197879984674435, 0.10425210990492376, 0.024110646655542717, 0.0697626706753527, 0.04297931370655856, 0.06600044352272827, 3.04115308388587, 72.91317447539299, 59.02244175634077, 43.96395275669713, 32.982685181402395, 62.62093397878832, 51.07790062504431, 91.3037875390822, 6.54247667520277, 0.66983406341845, 0.05886619610171165, 29.77448840295115, 91.91766985001104, 74.39380645751953, 77.4182362710276, 71.0111544209142, 73.92310634736093, 72.46021916789394, 75.92556261247205, 75.96218970514114, 69.10871075045678, 64.54588420929448, 67.77340258321455, 68.25773685209214, 70.3959071251654, 60.74745308968329, 45.40403919835245, 57.412920690351925, 66.69615499434933, 67.20028938785677, 65.36873863589379, 65.3762891984755, 66.60330464763027, 60.429748950466035, 61.402359470244384, 57.99779707385648, 53.86379934126332, 51.72558984448833, 47.2519423115638, 46.9960900275938, 46.96595053518973, 49.066215022917724, 51.3246569325847, 48.43749438562701, 50.96239466820994, 45.827482592675, 46.853778593001834, 47.05189358803534, 46.223006556111, 42.866712847063624, 43.493586048003166, 42.138732710192286, 45.27582476215978, 44.25162722987514, 43.72673957578598, 45.31600159983481, 44.98394943052723, 48.34080011613908, 45.830820529691636, 49.082885096150065, 50.55154208214053, 50.726801426179954, 48.50215073554747, 52.76894815506474, 57.0438374242475, 55.483063574760195, 54.19647908979847, 58.3207768009555, 57.670573342231016, 57.904264234727435, 58.124552388345045, 58.87422715463946, 57.99901693098007, 54.860450067827784, 54.84015180218605, 55.23185145470404, 51.5452314192249, 51.88595594898347, 48.32111374024422, 55.17019179559524, 49.56253213267173, 46.02748424776139, 54.89343720097696, 48.84192605172434, 51.43214556478685, 45.69656564343361, 52.3644184297131, 54.205782951847205, 55.70861947151923, 56.21988473399993, 58.883032875676314, 57.779007265644694, 58.62890643458213, 57.48681029965801, 55.585606098175056, 55.06380927178168, 52.70947325614191, 50.50132397682437, 51.90705045577019, 51.421990548410726, 51.43856648475894, 52.028145790100105, 50.61745359051613, 52.158168438942205, 48.855077758912124, 41.45917031072801, 42.16052932123984, 40.910434645991174, 42.12824036998134, 42.14967220060287, 42.41640513943088, 41.252375110503166, 41.03415796833654, 42.72307957372358, 45.690423211743756, 45.24357111223283, 44.57917259585473, 48.56639523659983, 47.612204167150686, 46.654212321004565, 47.873332039002456, 50.06895326798963, 56.354676984971576, 58.53359283939485, 64.25711931720858, 63.33896698490266, 50.19906220897552, 63.09055543714955, 63.549688477669996, 67.65861049775155, 67.04746600120299, 63.82239910864062, 64.87696755316951, 68.7762035862092, 67.73199019893524, 71.56345552013767, 72.6021618996897, 70.4756881344703, 68.80693143413913, 68.45508698494204, 69.11182511237361, 69.1273106298139, 73.98587211485832, 72.24135875701904, 76.92642596460159, 74.85108421694848, 79.10909944964995, 72.04124727556783, 78.13613983892625, 24.176307147549046, 0.3920864962762402, 0.3913626044748291, 0.33430207761064656, 29.10718341027537, 84.89206944742511, 55.52665679685531, 58.356011452213416, 36.15584734947451, 45.544495351852916, 69.67248870480445, 52.38004907484978, 0.6009531369613064, 0.04233990991187673, 0.050714384734390244, 0.019062510278496533, 0.011894686181368607, 0.017391590161188956, 0.11240261126189463, 0.13389782799828437, 0.1841884358756004, 0.13153665308510104, 0.21673384272763807, 0.2675589041844491, 0.1677473463238247, 0.21458386293342038, 0.46346330654717266, 4.169283374663323, 83.19387143658054, 66.74737330405944, 55.86001511543028, 34.14240060314056, 75.33605390979399, 59.61547274743358, 101.93854901098437, 6.518131013839476, 1.055203378200531, 0.25408619083464146, 34.276208339198945, 94.97263923768075, 76.40536262143043, 81.82015542061099, 73.08067537123158, 76.03750705718994, 76.11698212162142, 77.72215720145934, 80.46190923260104, 72.20847360549435, 64.9243458624809, 69.34285271552302, 72.55085729783582, 71.87634298878332, 63.92829918092298, 53.548158368756695, 59.19624197867609, 68.0854114409416, 68.40197809280889, 68.03984918901998, 67.67942259388586, 69.18179235150738, 63.75606006191623, 64.02405208156955, 62.08268673189225, 57.06704216618692, 53.034010164199344, 47.168929269236905, 51.073664465258204, 50.14856561537712, 50.61004423326062, 54.03393214748752, 52.25707492520733, 53.04504379149407, 49.846303847528276, 50.9892079907079, 50.031302436705566, 47.26617267054897, 45.51149645159322, 45.79627229321388, 46.29122049577775, 47.44006310739825, 46.65928786800754, 46.35215451640468, 48.782211888221006, 46.765976336694536, 52.08827572484171, 49.46135067170667, 52.911338037060155, 53.09821151917981, 54.59576068385955, 50.746072030836544, 55.35670834202921, 58.66765552951444, 60.68449904841762, 56.98774360841321, 61.61711708191903, 60.98277961054156, 59.61723781401112, 61.43998284493724, 64.10528044546804, 61.18317350264519, 57.704682273249475, 57.06435926498906, 56.6140397902458, 52.84987057408979, 53.91844188013385, 50.30652338458646, 59.10688254141039, 55.150446584147794, 50.225722559036754, 59.115990284950506, 50.51020030052432, 51.50872984240132, 47.94116158639231, 54.92027405769595, 58.9032958399865, 59.39520420566682, 59.246028623273304, 59.737713413853804, 61.1268521893409, 62.25550243931433, 60.017845169190444, 57.872889195719075, 58.24687542453889, 57.71237011878722, 53.058168042090635, 54.71623236133207, 56.537667320620635, 54.764752080363614, 55.49934925571565, 53.5460049875321, 55.53501929006269, 52.15290461817096, 45.0726342201233, 45.2152241429975, 42.63801905416673, 47.084943479107274, 45.2894942222103, 45.48525187277025, 46.23359695557625, 43.01191899084276, 46.47420690905663, 48.126085650536325, 49.51221596810126, 47.58519472614412, 52.49565309093845, 50.94363004930558, 50.20009771470101, 51.640509713080625, 52.98323115994854, 59.21266102021741, 61.85712691276305, 66.59899004044073, 64.31349946606544, 54.53037477308705, 67.19368411648658, 64.90849948698475, 72.117960991398, 70.38035884980233, 68.19977991042599, 67.13509175085252, 70.1553560072376, 69.92066491034724, 75.72127772915748, 75.79619499944872, 72.90488258484872, 71.11021780198621, 70.79594181429955, 70.52713394165039, 69.7496025023922, 75.97395681565808, 75.3666405523977, 79.08901691436768, 79.77674961090088, 83.61936230813303, 76.27257470161685, 81.95088017371394, 30.71017961348257, 0.46754195865604187, 1.6149677672693807, 0.6332641515520312, 33.932800908242505, 94.45914606894218, 63.494406592461374, 68.72780938302317, 45.31972785149851, 66.02189171698787, 75.96881851073235, 63.26140995948546, 0.7442724981134938, 0.13472128058633498, 0.14424070445520265, 0.2677619787714174, 0.13502520298765552, 0.1056357719484837, 0.21208439382814595], [0.034185057175495935, 0.12155451210996798, 0.08172752380731606, 0.04541364235563144, 0.07178158814748449, 0.051490470106082584, 0.03353147692377529, 0.08115778421802868, 0.7537810588555952, 53.97475534869779, 55.514866152117335, 46.306721702698745, 29.29320573806763, 56.161759130416385, 50.673606241903, 83.08225647095712, 14.589776550569843, 0.7636669025786462, 0.29666620036286695, 18.66590657541829, 86.47069008119645, 66.37105326498708, 75.82334564578149, 68.20990747021091, 74.99195221931704, 69.15385723114014, 72.95262567458614, 62.87648816262523, 65.10367270438903, 66.8695237559657, 73.45064901536512, 67.05636978149414, 66.93573336447439, 56.12331598035751, 60.19071186742475, 67.52227675530219, 65.07731045446089, 66.89212445289859, 66.20013206235825, 62.91597466314993, 61.373604574511134, 58.96995652106501, 55.60178979750603, 53.05458299575314, 47.40464802711241, 44.27207454558342, 45.24352796616093, 45.44179985600133, 47.85029203661027, 45.717699373922045, 45.81244422543434, 46.77524097504155, 47.37817987318962, 46.39519076193533, 43.174054084285615, 43.06422771946077, 43.945474470815356, 41.1307071101281, 40.35525060469105, 42.62533018665929, 42.10490618982623, 39.74851485221617, 42.23324614186441, 41.84730452875937, 41.394109956679806, 41.50115928342266, 41.80403686338856, 42.18230239806637, 45.45699119567872, 46.13758125612813, 48.336744385380904, 48.67984979383407, 48.352288738373794, 49.853615145529474, 51.879460503978116, 51.85791884699176, 52.789085603529415, 53.08596980187201, 53.710803370321955, 55.749769056996996, 53.628970961416925, 53.52099203294324, 56.011112659208244, 53.80349682223413, 52.979045990974676, 53.18998321410149, 49.89724759132632, 44.49849728615054, 29.94322092302384, 30.703382145973947, 44.5571171083758, 50.60265841022615, 57.164932758577415, 51.43364783256285, 52.986408279788115, 51.82391974233812, 53.73977007404451, 54.8341231192312, 54.54137702142039, 55.45324179434008, 53.62776287140385, 51.23741165284188, 53.239836538991625, 50.98619168804538, 50.8346587611783, 49.28465574018417, 47.88399304113081, 43.860916014640566, 48.65252656321372, 48.144054028295706, 44.80795660326558, 42.33621228125788, 40.506869823701926, 38.660076741249334, 39.01898145675659, 36.94838969938217, 39.99519271235312, 40.70876990595172, 40.41634936486521, 41.833878255659535, 40.7189445341787, 42.90623072654971, 42.279828210030836, 43.773200050477065, 44.684311728323664, 44.408188635303134, 46.35773997153006, 44.74516730154715, 45.19271758294875, 44.118376470381214, 50.3769063949585, 56.86718956116707, 57.24030502380864, 62.838433327213416, 62.09516379141039, 58.40150310147194, 60.47051022129675, 60.10394903921313, 59.20367094778246, 61.162824246191214, 60.81972668247839, 64.82896166463053, 67.3875198056621, 66.31590474036433, 64.95323019642984, 69.5924174401068, 67.97778160341325, 69.55506863132601, 69.60027002519178, 71.6331325038787, 71.80740341063469, 68.84875174491637, 69.41413002629434, 74.87133149177798, 76.17560586621686, 69.680035345016, 60.60704008225472, 6.2813512548323605, 0.4874737278348016, 0.4543985865048824, 0.18397126527082536, 30.06802878072185, 72.76757609459662, 56.493987806381725, 53.437743648406006, 40.2761560101663, 47.68498766806818, 57.09107845060287, 52.04928736532889, 0.9320114144394476, 0.0648780251222272, 0.018622101652586175, 0.020539675268434712, 0.058263667949265054, 0.02616466627636504, 0.02807377653587009, 0.037899591524394295, 0.09771773997213572, 0.046690446625073115, 0.0285752959955003, 0.10068040115818863, 0.06294643784302377, 0.028296648750021577, 0.03340896797336398, 0.6727132669860317, 62.12724485704976, 60.19617572907479, 50.354674400821814, 35.39850042712304, 65.01453684222314, 56.452736239279474, 93.00527249613117, 15.931950826798717, 0.5683680467547909, 0.06470981519669294, 17.916076875502064, 91.44980169111683, 67.97388276746197, 78.48257926202591, 71.31756213403517, 76.21635929230722, 71.91086769104004, 76.01023089501166, 65.90173382912913, 70.17666232201361, 67.99979394482028, 72.86692188632104, 68.56282664883521, 70.59997235575031, 58.61631170395882, 62.06578523881974, 70.59162555202361, 68.98132785674065, 68.39579643741732, 65.09712234620126, 65.26970271141299, 64.68600696133029, 60.67973729102843, 57.143932388674834, 55.13233307869204, 50.027152569063254, 46.62897579131588, 47.23774725391019, 48.52471220877863, 50.547823675217174, 48.19757869166713, 48.19930453454295, 48.49363526990337, 48.88339727155624, 49.117990309192294, 46.30644321441651, 45.42722825081118, 46.64938780569261, 44.79552661218951, 45.285065866285755, 43.40481496626332, 45.545209223224276, 45.31860605362923, 44.27807184957689, 43.76556319575156, 44.15452111151911, 43.472479774105935, 43.608684078339614, 45.75007853969451, 46.6972799454966, 48.170875195534, 49.7832517470083, 51.70798232478481, 52.06868740820116, 52.96992648032404, 53.4127934517399, 56.189305936136556, 54.11183434147989, 54.34381508058118, 56.08209971458682, 58.23666157261018, 54.68080943630588, 55.4035924326989, 57.5670188473117, 55.979808222862985, 56.49110486430507, 54.95105681880828, 52.430781010658514, 47.14630896045316, 34.92660399406187, 35.64937522334438, 48.45591775832638, 50.83629438954016, 57.40495827890212, 53.777071814383234, 54.951174489913456, 53.268952292780725, 55.12199371091781, 56.915336655032256, 56.601621566280244, 55.62289607140326, 56.346585135306086, 55.1166122190414, 56.66750169569447, 53.9227839439146, 51.606314489918375, 52.934954627867675, 52.79287853548604, 47.36943691007553, 51.270277192515714, 48.31247275875461, 46.991610680857015, 43.75000315327799, 42.26101260031424, 40.15411930699503, 40.173899819774014, 41.97526008852067, 42.820699522572184, 42.76309167185138, 42.71873750994283, 42.84324922869283, 43.50880484427176, 43.578964279543975, 46.254899347982104, 46.546354986006214, 47.06038159708823, 47.86765244699294, 48.96607299004832, 47.56790099605438, 49.53699358047978, 47.4244285398914, 51.70454632851386, 59.71308092917166, 62.76585378954488, 64.66414366998981, 65.61599308444609, 61.62886065821494, 63.95672851993192, 64.03257931432417, 62.54106667733962, 62.721676134294086, 65.15710323087632, 67.11045142143004, 68.71859181311824, 71.03900324913764, 68.51571113832536, 70.50794570676743, 72.27349081347066, 73.20998807107249, 75.82038817867156, 74.87205320788969, 74.63999009901478, 73.77932794632451, 73.17948772061256, 76.92084835421655, 78.51623319810437, 72.51575208479359, 64.10826536916917, 5.839956152823664, 0.29120479019418843, 0.11864661088874263, 0.14212958064050446, 35.867031466576364, 82.39377852409118, 64.86383153546241, 62.937932091374556, 47.0968988633925, 53.381979311666186, 66.18174399099043, 64.24068850855674, 1.1596446965009937, 0.04079615081390066, 0.03494165327039457, 0.0287667605199761, 0.04972815378418854, 0.09613034450599263, 0.024330466009315946, 0.0805488898749313, 0.17920684189565722, 0.12115800032211889, 0.21999532416943582, 0.2027670333101865, 0.13912864570175448, 0.14019010648612054, 0.22677483457711436, 1.2784105106707544, 76.55422441421017, 66.15283612282046, 60.125847631885165, 38.92084375504525, 78.86640671760806, 63.253635821803925, 102.17369510281472, 16.17611837002539, 1.2031149768060254, 0.4051281932380892, 21.868043291953303, 95.20480432818013, 71.58549139576574, 81.64238575966128, 73.80596083979454, 83.4706574101602, 72.5536657148792, 80.08189432082638, 68.65883058117282, 69.22340869903564, 69.0149974822998, 76.81419910923128, 71.6296729733867, 73.48242021376088, 64.2428065884498, 64.12104837356075, 74.01918088236164, 71.09077853541221, 71.22977948957875, 71.00649464514949, 66.72687499753891, 67.90867728571739, 63.38390950233706, 59.3625073279104, 58.22351771016275, 52.15424214639972, 49.945178954832016, 50.44689324594314, 50.52881194699196, 53.273349269743896, 51.854337723024436, 49.59340510829803, 52.25436456741826, 53.308921244836625, 51.87326315910586, 48.47180335752426, 47.83101750958351, 50.99126723504836, 46.00451484803231, 46.86454549912484, 47.55634177115656, 48.537581505314, 45.81493100812359, 46.90558525823778, 47.66211240522323, 46.78406630792926, 47.3398583166061, 47.8963210505824, 47.33154289184078, 50.960029478996034, 53.53986255584225, 53.326160061743956, 54.770274777566236, 55.543573979408514, 55.55878885330693, 55.91627759318198, 59.77125752356745, 56.44576618748327, 59.102297290678955, 56.49979291423675, 60.94394030109529, 58.38905742091518, 57.169780808110396, 60.87946830257293, 60.08270155998969, 57.857540961234804, 56.93831389950168, 54.51017456669962, 51.09459031012751, 41.73830970641106, 41.78820617737309, 52.09779139487974, 54.422713556597316, 61.7626017139804, 55.2673214481723, 56.72840041498984, 56.380921563794544, 59.817721920628706, 61.51557868526828, 60.36552406126454, 59.650550503884595, 58.469791566171956, 57.767914802797385, 58.50984288800148, 56.229459239590554, 54.690658507808564, 55.08431150067238, 55.749023806664255, 49.110494659793, 54.0421808919599, 51.63864658724878, 49.1612736640438, 47.11475741478705, 45.042808517333, 42.66354976161834, 45.91704207081949, 43.40429721340057, 46.227972276749156, 47.56785784998248, 46.52772765005789, 46.15460042030581, 47.81466907070529, 48.30092137859714, 48.14688990193029, 49.09487970413701, 50.37606308537145, 48.416113545817716, 51.932196770944905, 51.06306229868243, 49.67658289017216, 49.764793072977376, 54.231278357967255, 63.078921687218454, 65.23083986774569, 67.78378901943084, 67.66084624874976, 64.57126978904971, 64.42974675086238, 67.82868446842318, 64.58913226281443, 66.31524578217538, 67.43585125092538, 69.33027759675058, 73.39371973468413, 74.8211016193513, 72.21477293199109, 75.25348801766673, 77.2119431341848, 77.47997437753986, 77.96237884029266, 80.49119364830756, 78.04044969620244, 77.00484983382687, 77.03376554673719, 80.99136644794096, 82.89646948537519, 75.018765541815, 71.15815701023226, 9.470988358220747, 0.8127747319879071, 0.8668316119620878, 0.2552593165948506, 41.253928369091405, 94.85202635488203, 72.37592743289086, 74.23463667592695, 57.1876040581734, 70.03885376837947, 76.49636160942816, 77.44621061509656, 1.8941538636722874, 0.28570565785611834, 0.20112676245550956, 0.10469824886850773, 0.13621119902499262, 0.28747761922497905, 0.09286467256324907], [0.023545243123906757, 0.042871260835278424, 0.037635057533700625, 0.01892683227666684, 0.056681780655297546, 0.06297628462855374, 0.04214936852334969, 0.062085358846572146, 0.05928825692183549, 41.78120866898568, 54.01499886666575, 41.67606953651675, 34.503497923574145, 54.332361759678015, 46.46328310812674, 80.86032006048387, 23.87360215187073, 0.3079625651721032, 0.4338676446387845, 5.244009369804013, 78.15050355849728, 70.67459937064879, 76.23510037699054, 69.95843733510664, 72.46897389811855, 72.06718983188753, 76.93794988816785, 73.61731052398682, 80.17423475942304, 69.62157633996779, 68.44917205072218, 65.39859964001563, 67.77250828281527, 66.22114812174152, 65.90228296095326, 63.27940971620622, 67.3491511806365, 61.79194888760967, 64.63862472964873, 59.70549898762857, 56.225925184065304, 52.41547984461631, 48.931360014023326, 46.80907926251812, 48.326848245436146, 43.53006801297588, 45.32852572779502, 44.69499234230288, 46.13309014228083, 45.33547616774037, 46.783913335492535, 46.91629725117838, 49.36346007931618, 50.05313827145485, 47.38765239715577, 43.294192360293486, 42.15812098595404, 43.84570506311233, 42.955425093250895, 41.40257443151167, 41.582109159038914, 40.87433707329535, 42.00168117400139, 41.1795170845524, 43.90018286243562, 41.22709151237242, 42.975036944112475, 44.675019633385446, 45.028178076590265, 47.32254889703567, 49.726804917858495, 44.64499781208654, 44.89840645943919, 48.93242689871019, 50.90951719591695, 51.523360283144065, 51.102419360991455, 51.01180868764078, 51.24739016256025, 49.367170641499186, 54.31360890788417, 51.65659927552747, 54.927820697907485, 53.552167031072806, 54.90137215583555, 52.06119175880186, 54.3551742646002, 41.035067958216516, 19.139432753286055, 18.726195366151874, 37.00727232040898, 53.09711325553156, 51.50255210937993, 53.0425020956224, 51.886003017425544, 54.468001242606874, 53.48971505318919, 51.03937118284164, 51.24559371702133, 50.04691739236155, 50.46838783448743, 50.733767555605986, 50.28825298432381, 50.69322593750493, 48.45015971891342, 48.61302045083816, 48.06274721699376, 46.002220261481504, 43.819323201333326, 43.490483453196866, 41.130075608530355, 39.14171241944836, 40.71247654576456, 40.988948729730424, 38.726517769598196, 39.95103074658302, 40.68589464310677, 40.39251312132805, 40.51818193927888, 39.90436630864298, 42.38220991626863, 41.73459914422805, 45.53614070338588, 44.368090245031546, 44.91151502055507, 45.34607833431613, 45.37081280062276, 44.736440027913744, 45.23759342009022, 44.53419085471861, 46.28954956608434, 49.67581802798856, 55.93417144590809, 59.16452177109257, 59.80020853780932, 61.16471875098444, 59.63920308697609, 59.508603849718654, 59.594229190580315, 57.018134132508315, 55.814362648994695, 57.36649551699239, 57.74886777324062, 61.13610113820722, 63.11772569533318, 65.17442049518709, 68.02880379461473, 67.34554260007798, 69.71601132423648, 63.93583013165382, 63.36035959182247, 65.58491222320065, 64.89803852573519, 71.10693085578181, 69.5067136518417, 76.46331956309658, 51.961842044707275, 0.7089644249889159, 0.09940925444806777, 0.09945308999909509, 0.11896727231120872, 38.89401866543678, 72.11959269738966, 53.29579307186989, 47.20309311343778, 38.71828863697667, 39.81217099774269, 59.06874925859513, 45.0299156865766, 0.6186679089742323, 0.052731375495392474, 0.09008641640144972, 0.03626206326448629, 0.020040526850930145, 0.09714904226242535, 0.03282107976115039, 0.036799064086329554, 0.04767811399013285, 0.149618182030897, 0.03549295312334453, 0.046973941291892723, 0.007735126090401243, 0.027654713034749995, 0.04041400700507145, 0.04128900581910726, 51.35814220674577, 61.177795933138945, 40.0547460586794, 35.492570630965695, 65.57354127207111, 55.62789317100279, 91.03515225072061, 24.808049971057525, 0.19630716542803472, 0.6156718310329222, 4.663905530206619, 78.50476418772053, 73.84083071062642, 78.54685906440982, 71.54928791907527, 74.13784042481454, 75.09532236283826, 79.64055707377773, 74.63474196772422, 80.36390489147556, 70.17947858379733, 70.4346130740258, 69.08491765299152, 69.48830989099318, 68.94739151000977, 68.8158901276127, 65.2382766815924, 70.26249947086458, 65.59893861893686, 65.73978308708438, 62.99388470188264, 60.785045085414765, 54.13244639673541, 51.73134003916095, 47.60900743546025, 52.040058028313425, 46.81037364467498, 48.5116389489943, 46.20814077315792, 47.81342567936067, 48.082853286497055, 47.8946344314083, 49.33546612339635, 52.31008968045635, 52.642200685316524, 49.44466490899363, 46.22687793547108, 44.303390749039195, 47.35342187266196, 45.57002998167469, 43.38094734376477, 43.56367488061228, 43.514872750928326, 45.789384611191295, 45.702904193632065, 47.18021785059283, 45.819582939147956, 45.317727442710634, 46.08062059648576, 46.912112082204516, 49.301102238316695, 51.27541549744145, 48.89601945877076, 47.49519202017015, 49.26343571755194, 52.76818721525131, 53.52602051150415, 53.975477064809496, 53.035790920257575, 54.04330268982918, 52.79451808621807, 53.9119307456478, 51.14980159267303, 58.26611072786393, 56.51469399852138, 55.2176328628294, 54.868169292326904, 56.89133174957768, 46.56871249598842, 21.719642377668812, 22.07177512107357, 41.90919560770835, 54.94448684876966, 53.08571484781081, 54.89057387075117, 54.10888079674014, 55.30633726427632, 55.97852560781664, 53.21287024405695, 52.61657584098078, 52.489024285347234, 51.624639803363436, 53.48439239686536, 53.43896350552959, 52.411988935162945, 49.970262512083984, 50.79615285319667, 54.28721135662448, 48.421871585230676, 46.342984014941806, 47.71357390188402, 42.53315448760987, 42.02720011434248, 44.007518522201046, 43.08028590294623, 42.12092514960997, 43.38738787558771, 45.01868201840309, 42.62197656016196, 41.787131447945875, 43.53436693068474, 44.1387963294983, 44.79327124934043, 47.85134323181645, 45.74131204235939, 46.50491122276553, 46.673110300494784, 46.770647879569765, 47.33314714124126, 47.46392288515645, 47.67356964849657, 48.48531200039772, 51.60645569524458, 58.462927418370406, 62.020352425113806, 62.88040661042737, 64.03966703722554, 62.850808405107074, 61.78445716058055, 62.95688106167702, 58.7942421820856, 58.16667079925538, 59.27040223152407, 60.89005477966801, 63.560510296975416, 64.74082992922875, 69.42149623747795, 69.67750149388468, 69.51337383639428, 70.86899203638878, 67.64172077178955, 66.29777554542788, 67.79019032755207, 69.42401439912858, 74.47026914165866, 73.72974134260609, 80.45013427734375, 59.84399395604288, 0.5419432227649997, 0.1675805230174334, 0.16808059457088673, 0.10369226817161807, 46.40129396992345, 83.68923541038268, 60.57312726974488, 59.040543494686005, 43.79421610986033, 46.08388400846913, 69.82832447175058, 54.04221227092128, 1.2779313686393923, 0.08787149533389077, 0.02265768238313256, 0.052649296835185065, 0.037057852417591124, 0.02369190491135082, 0.06326427623148888, 0.15853840256890944, 0.18360708239338092, 0.20158096066405698, 0.12987854770354687, 0.1266726306188972, 0.131426504963348, 0.14888413190360994, 0.1113268169724653, 0.364955737585983, 67.11314216736825, 67.58336374836584, 54.54108676602764, 44.998548492308586, 74.85488107127529, 58.45175650811965, 101.32363903907039, 26.09148087040071, 0.535933722651774, 1.1277609751109154, 6.928567828670626, 86.5743818590718, 75.54705389084356, 84.33630881770965, 72.63340750048238, 78.93337726593018, 76.75458692735242, 81.0458089459327, 73.16203317334576, 84.76189382614629, 74.1720199584961, 72.66390785094231, 70.6482018193891, 73.9331554597424, 71.41636663867583, 72.62877910367905, 69.32783003776305, 74.3398738676502, 67.16094017028809, 69.11805383620724, 65.43626223841022, 60.128644281818026, 55.92000776721586, 55.09441944860644, 52.312705901361284, 55.12372739853398, 48.77008784201838, 51.58714194451609, 48.27507295916158, 49.112640196277255, 51.368026579580004, 50.53365999652494, 52.239659601642245, 54.78872168448664, 56.08122110366822, 52.17320288381269, 49.91390197507797, 46.69554233551026, 51.583674569283765, 49.668718537976666, 46.03652531100858, 45.42031311219739, 44.77760922524237, 48.85567788154849, 47.77781055819604, 49.78751928575578, 48.00491579117314, 48.11247502603839, 48.85515620631557, 49.56799991669194, 51.33411768944033, 54.982090611611646, 51.36973281060496, 49.50891333241617, 53.78194732050742, 57.85180645604288, 56.92056125210178, 57.28454543698219, 56.73587253016811, 56.66841560794462, 55.113019327963556, 57.82021568667505, 55.690741308273815, 63.392675999672186, 59.153876458444905, 59.20942506482525, 61.01320151359805, 60.7235070197813, 50.33301899510045, 32.01627200649631, 30.758487524524813, 47.91538376961985, 60.45196917749221, 58.1075567583884, 58.76490285319667, 56.41082963635845, 58.70306276505994, 58.18705927941107, 55.72412460081039, 56.09896590632778, 55.62428851281443, 55.25501697294174, 56.13080378501646, 54.931244927067915, 55.837771354183076, 53.97181357106855, 53.69911862957863, 55.45807807676254, 51.554970664362756, 49.561696667825025, 51.261608754434896, 44.27624794744676, 43.26744571808846, 47.34937398664413, 46.56286816443167, 43.99864612087127, 45.770792576574514, 47.593235584997366, 45.82713350172966, 45.42829121312788, 46.220876709107436, 48.15281660326066, 46.15842865359399, 53.132351829159646, 50.40968564248855, 48.724149042560214, 48.15803335558984, 50.032071221259336, 50.766535036025516, 50.83027355132565, 51.56234079791654, 50.933996708162375, 56.01818469262893, 60.465713162576, 65.28808293804046, 64.38037195513326, 65.68282634981217, 65.22081036721507, 64.70663078369634, 64.83986977607974, 61.924438707290165, 60.22171820363691, 63.78046504912838, 63.22402584937311, 65.75990484606835, 68.30586433410645, 74.0265235593242, 73.78110870238274, 72.49694039744716, 74.75297004945817, 71.19720028292748, 70.56971519224106, 70.63787029635522, 74.1759737076298, 79.50230136994394, 77.60543530987155, 83.73277371929538, 64.05578797863376, 1.4383238265591285, 0.4996694185801091, 0.5712831032372291, 0.40810248363883267, 52.63865878505092, 92.06021662681334, 66.23486857260427, 67.24301184377363, 52.849705834542554, 57.241858282396876, 82.76444250537504, 69.18480473179972, 2.15407720015895, 0.20591274354486697, 0.20332442356213448, 0.1807840177488904, 0.10054470400416082, 0.125071790309683, 0.23981751213150643], [0.058972107757243424, 0.05456040658417249, 0.06771968272064002, 0.016564603992587617, 0.026919123070735126, 0.07510699196568421, 0.08601405387443882, 0.09079884752751359, 0.05650196066727081, 40.40892431812902, 53.7790879126518, 52.60124721834737, 35.13986326033069, 47.291766135923325, 52.6463976214009, 75.42342078301215, 34.344790981661895, 0.06720213670163386, 1.1746095193009223, 0.12026298746106126, 40.51760142849338, 76.37776482489802, 74.99458805207284, 72.48352589145784, 77.05369118721255, 69.11076607242708, 73.26164568624189, 69.7389179660428, 67.5728988647461, 67.5634773315922, 65.12831303381151, 62.90892224158011, 64.58700633818104, 58.39438007723901, 62.873950389123735, 62.395229031962735, 63.00380045367826, 63.460705587940836, 61.533539218287316, 53.865854663233605, 49.378282716197354, 48.66006535868491, 48.48808119373937, 48.14536802230343, 45.06880206446494, 44.453629293749415, 46.61457284804314, 42.69848239037299, 46.413602367524184, 46.78618438782231, 47.94235790929487, 51.415801048278816, 55.276703757624475, 53.9668478504304, 51.00688219070435, 44.23224679885372, 44.04451824003651, 42.60803645656955, 44.227069270226266, 41.01185144916658, 41.26247129132671, 43.10280030773532, 41.188534613578554, 41.96697212034657, 43.32553209797029, 43.20595079852689, 44.618486512091856, 43.502019143873646, 42.38555962039579, 46.14696356558031, 45.07607021639424, 46.76874553003619, 48.1672901491965, 47.94945347693659, 48.73053858357091, 47.85999598041658, 50.67607341274139, 49.91737719505064, 49.702078296292214, 50.9071716185539, 49.29723085895662, 51.5025128856782, 51.24499751675514, 52.363155426517615, 49.472380376631214, 54.95948991467876, 58.231158487258426, 34.13514421832177, 20.63058453221475, 20.388717459094142, 27.464045670724687, 51.38724227105418, 52.242264055436664, 51.774144864851436, 52.59432815736341, 52.630810122336115, 50.032357554281916, 47.07299986193257, 48.45239939228181, 47.707482461006414, 47.83005260652112, 48.767895237092056, 47.86507544978973, 46.104460762393096, 47.75155813463273, 45.33456617786039, 45.34072037666075, 46.48362844221054, 47.47073211977559, 43.195125056851296, 43.21301890957741, 42.87846426809988, 40.753171136302335, 40.70869930328862, 40.81687827264109, 42.22657026783113, 41.08281889269429, 38.610282251911784, 38.71900643071821, 38.91264992375528, 40.655151105696156, 43.49337816238404, 43.678157098831676, 44.14768049793859, 45.68131939057381, 43.84559131437733, 43.53756758474535, 44.90785152681413, 46.649450563615375, 47.33213909210698, 45.83006351224838, 45.90103880051644, 49.39530972511538, 54.13512145319293, 61.02221512025403, 61.28953249223771, 62.35300079468758, 60.57595137626895, 57.659931951953524, 57.191440136201926, 56.06819491232596, 55.48996694626347, 56.27655121587939, 52.99510025208997, 55.39753629315285, 56.73140102817167, 59.74458148402553, 58.32032572838568, 59.21053901795418, 59.76133000466132, 58.016977463999105, 58.63046361554054, 62.072210081162, 68.35897322623961, 73.49953743719286, 77.91955440275132, 62.27327077619491, 0.201186976966358, 0.2455551736056805, 0.3636392308098655, 0.2682833169256487, 45.80150081265358, 67.38306399314635, 55.70888619269095, 52.45799049254387, 27.16203493456687, 49.61253842999859, 52.90829820017661, 38.60719926895634, 1.485796640476873, 0.022842194659695513, 0.06910562770621431, 0.13548769026754365, 0.07141976482084683, 0.09133461111735913, 0.04880977524144035, 0.017703908886159622, 0.07115178726493351, 0.07681686956916126, 0.028524383707272432, 0.007601085122704747, 0.05146333527180457, 0.04683144510753694, 0.04650531381729149, 0.03172034164890647, 51.83929935578377, 61.333439503946614, 51.127628434088926, 45.97158262806554, 59.84617479385869, 53.065334212395456, 82.29206362078267, 36.63473344618274, 0.06106856481863126, 1.5029525973143116, 0.11910043371420716, 37.74904743317635, 77.56093209789645, 77.85997359983384, 74.59157236160772, 78.58249771979548, 71.39466808688256, 75.08390826563682, 73.00711524101996, 72.22835217752765, 69.49205967687791, 68.0288508630568, 63.66326462837958, 65.7397360186423, 61.17304594286027, 64.3234230626014, 66.16173990311162, 66.07915832150367, 63.734302674570394, 65.82466709998347, 56.74791028422695, 51.944532625136844, 49.19505311596779, 49.76979409494708, 49.99462827559441, 46.13670264520953, 48.03479640714584, 48.13600924707229, 47.69443665781329, 48.64079475402833, 48.739512966525176, 51.65444197193269, 53.62391502626481, 57.47510594706382, 58.86424472255092, 52.5619254573699, 46.92368699658302, 45.48419283282372, 46.28895728818832, 47.227062717560806, 43.770830938892985, 44.763221971450314, 46.164402423366425, 44.672171992640344, 44.92110913799655, 45.77751944142003, 45.47672464001564, 47.566135929476836, 47.94552326202393, 44.36833343198223, 48.04638308863486, 48.53146653021536, 50.23315937288346, 49.32948843125374, 52.48796524540071, 49.558880406041304, 49.9325999136894, 51.73405039695002, 51.27574105416575, 51.65085300322502, 53.02692244129797, 52.39917847418016, 54.2317686542388, 52.49015392795686, 53.07437919801282, 51.696650597356985, 57.80755427575881, 59.13260936737061, 34.83805256505167, 21.642408947790823, 22.04424988838934, 29.263172149658207, 51.259737783862704, 55.954508935251546, 54.0316963964893, 53.82446189080515, 53.979403357351984, 52.42532107137865, 51.958245231259255, 49.06683083503477, 50.49700152489447, 51.40966646132931, 50.51538175152194, 50.37023052092522, 48.80593438302317, 48.146783997935636, 47.28986770875993, 47.15208661171698, 49.438789198475504, 48.48930497323313, 44.779746916986284, 45.547527343996116, 44.118819698210686, 45.06652316739483, 44.234109924685576, 44.60566036162838, 45.66042100229571, 43.34753267226681, 42.38949768004879, 42.11188016399261, 42.34288815529116, 42.73142637745027, 46.644637815413944, 46.87126059685984, 46.6469677032963, 47.669313876859604, 47.68257933278238, 46.3466122073512, 48.25845387674148, 48.03350594735915, 49.53692297781668, 47.96749637972924, 49.3613733783845, 51.49768052562591, 57.100076367778165, 62.41938690985403, 62.463152716236735, 64.32168937498524, 62.444898005454775, 62.42530968881423, 58.51577351170202, 59.75476787936304, 58.94894830642208, 56.93143406221944, 55.84802050744334, 57.25703785496374, 59.58059895423151, 60.67586983403852, 60.87093322507797, 61.949486963210575, 61.59049595555952, 61.11095482303251, 63.24301796574747, 64.67302391605993, 72.69130952896612, 77.70755813967797, 81.89757516307216, 67.32637789941603, 0.4066377541711254, 0.34464898369004654, 0.24084659804019237, 0.43272782838152307, 53.612336189516135, 77.7969568006454, 63.776213199861594, 59.21615977441112, 33.41032551180932, 54.89822249258719, 62.42042241557952, 50.35815746553483, 2.1448022655902372, 0.04548963061684082, 0.051470479041698484, 0.08938922276419979, 0.03451970736345938, 0.08278578234415862, 0.047256949492880417, 0.12882736781912466, 0.20678616038733916, 0.2420519301367383, 0.13343693418127875, 0.14888863650060472, 0.21441365351840375, 0.20725845359265807, 0.19760012266135987, 0.2190791596207888, 64.50553870970204, 67.82548381436256, 69.20213376322101, 47.995474646168375, 67.56812926261657, 63.207155735261985, 90.70236267582064, 41.80587645499937, 0.23415668927613767, 2.567405046955232, 0.25925656420088583, 46.00247913791288, 82.53837277812343, 82.89254711520287, 77.0600454268917, 81.71435340758293, 72.77547574812367, 78.38700679040726, 77.17725369238084, 75.61405581812706, 71.86805109823905, 69.4591353016515, 67.12500341476934, 70.27324676513672, 62.902811188851636, 68.19857966515326, 70.43254990731516, 69.83745574951172, 66.00997555640437, 69.29992629635719, 59.006187454346694, 54.81845717276297, 53.942819410754794, 55.185724381477606, 54.37975968084028, 50.731080732037945, 52.412306647146906, 51.105216010924316, 49.94321384737569, 53.09582279574487, 51.078602729305146, 54.22755602867373, 55.88759722248201, 60.45802923940844, 60.85837771815639, 55.83784980158652, 49.13012220013527, 48.92369570270662, 49.27468899757632, 49.980444985051314, 48.21236602721676, 47.17256138401647, 48.91630595730197, 45.95239439318257, 47.12917996991066, 48.57920961995279, 49.46220182603406, 49.48579880499071, 49.99781324017433, 47.04952055408109, 53.09434798456008, 52.813494513111735, 52.06317255573889, 51.97430341474472, 55.726450566322576, 52.94121865303286, 52.86949811443206, 55.664818363804976, 55.153529567103234, 55.08242484061949, 56.497412035542155, 54.74256323229883, 56.27491166514736, 54.40539236991636, 56.83487707568754, 55.32768280275407, 60.4346558355516, 60.48447385911019, 35.464502150012606, 23.45878012718693, 25.386140654163977, 30.930308911108206, 53.25524753139865, 58.87847508153608, 58.35143796859249, 59.00370067165744, 58.23427284917524, 54.754353877036806, 54.656816297961825, 52.51168774020288, 52.73556486252816, 54.69782860048356, 53.259824937389745, 52.65215566081386, 53.02022303304365, 52.5494013294097, 49.546736747987815, 51.355992747891335, 53.7509213724444, 52.81519682176652, 49.43599254854264, 47.75728087271414, 46.9205726346662, 47.6451442318578, 45.94402405523485, 47.33090746787287, 49.495020297265825, 46.75997118796072, 43.9803796429788, 45.28954521302254, 45.10384844195458, 44.80790169008317, 50.34592751533755, 48.28442781202255, 47.59392199977752, 50.8922666118991, 49.16987542183169, 48.96035025196691, 51.95416988865022, 51.979779043505275, 54.016571737104854, 51.65542256447577, 50.65397870156073, 53.086711129834576, 60.65042934110088, 66.51571812168245, 66.97430595274895, 67.12660374179964, 64.90974287832937, 63.30224183297927, 61.21468974697975, 63.523549802841686, 61.55792459364861, 61.1489978913338, 57.83843901849563, 61.13699151623634, 62.6497830114057, 66.35570895287299, 64.00775463350358, 65.33191150234592, 66.09383583068848, 64.45869384273406, 66.66453284602012, 69.38814040153258, 76.21150339803388, 81.41667689046552, 85.44034619485178, 71.67140699202015, 1.1570403652806436, 0.67180149978207, 0.7550464522454047, 0.6471725084608602, 61.35793078330256, 85.81322239291283, 69.72811575858825, 71.01123286831763, 39.043951265273556, 70.51180531901699, 74.67572289128458, 65.76435281384376, 2.989787930442441, 0.1876448254070936, 0.2429794174649062, 0.27662607570809705, 0.1902777317070192, 0.14401000473768483, 0.14293343669945194], [0.005306461225113562, 0.0688535081703336, 0.10461468399772722, 0.0309155777757687, 0.007146706883495133, 0.04025060428126205, 0.02840072754019451, 0.038749060458353454, 0.1485531665985623, 37.40244719289964, 58.92466491268527, 36.63943244564918, 21.874938818716235, 44.35829608671127, 58.932164484454745, 69.51688043532833, 42.68818616867066, 0.04335187758589464, 0.9822699079109777, 0.10517896138011448, 6.788790735506243, 56.65352629077051, 72.22349628325432, 74.97372104275611, 72.5114296328637, 71.48048954625284, 74.43158672701928, 69.71007285579559, 67.0231943745767, 65.90310665868944, 58.839584781277566, 60.39846412597164, 59.07556633795462, 60.696258314194225, 59.865370873482, 56.89232803160145, 57.340576494893725, 55.96514640315887, 50.958923370607444, 48.14155155612577, 46.304995859822924, 47.53740456796462, 45.62354680030577, 45.08712345553983, 46.18933300818167, 45.292765478934015, 44.99106853238998, 46.43790145074168, 45.93011925297399, 48.187659017501346, 54.574199415022335, 56.508641781345496, 58.175323547855506, 56.07723205320297, 55.620193558354536, 48.60661914271694, 45.04671127565446, 42.80047578196372, 45.59817691003123, 42.973009078733384, 42.645891251102576, 42.791940704468765, 41.21492432009789, 43.29787938825546, 41.55382887009652, 44.52961344872752, 46.966844835589015, 45.871468051787346, 44.176847242539935, 43.42814522404825, 47.92752742767335, 47.365518462273386, 47.974258545906316, 46.78914969967258, 45.895355286136756, 49.54879599232828, 50.598151606898156, 49.70816581479965, 50.21074302734868, 49.77226911052581, 48.87844331802861, 52.32351595355619, 50.05479743403774, 50.86659469912129, 51.2295590677569, 56.06479813975673, 49.938248126737534, 25.631945786937592, 21.599194234417332, 28.398011038380286, 23.451645335843487, 34.533268713182025, 61.903187305696555, 51.295662772270944, 49.27203355296966, 50.95976668019449, 50.575652891589755, 46.61606334870862, 48.00500208331693, 47.85191197549143, 46.07132457917737, 47.80736561744444, 45.70907800428329, 43.26297029372185, 45.939340745249105, 45.629414666083555, 46.67162372219948, 46.12271155080488, 43.6025651808708, 43.00770636527769, 41.789896718917355, 41.80109508575932, 42.13009565107284, 41.747821454078924, 41.301189007297644, 39.527967822167184, 40.07257323111258, 40.059260706747736, 39.116169944886245, 41.255242363099136, 42.01838654856528, 40.32122012107603, 42.78575904907719, 43.55548889406266, 45.05762330947384, 47.592509946515484, 43.47637468768705, 43.93156182381415, 43.98835774390928, 46.60572398093439, 44.94594558592766, 45.559655312568914, 47.15077654007943, 49.59160081801876, 54.61024207453574, 58.19539431602725, 61.140804060043834, 61.502803525617054, 60.11601817223334, 58.03578130660519, 58.78728781977008, 58.048658447880904, 58.488010975622366, 57.75790883648781, 56.002075518331225, 55.25371474604453, 55.57017157154699, 52.68824538876934, 54.50927634393015, 51.33886767971901, 53.713835362465154, 54.44812659294375, 66.4354036700341, 68.90787755289386, 75.86142401541434, 71.306336310602, 80.95078560613817, 2.068253044159182, 0.10073881536241501, 0.264557586201737, 1.0420342654951158, 55.79449976644209, 64.86074855250698, 52.063180400479226, 48.08015469581851, 19.687750685599543, 34.30521034425305, 53.38157922990861, 33.907340803454005, 2.1307395879299413, 0.13376820592149613, 0.13926297155839784, 0.09484148584306241, 0.08952087497398739, 0.0034449657241273075, 0.06846748412616792, 0.061078397557139404, 0.12406475241145781, 0.06645550741063011, 0.05288779532777206, 0.05145550585321842, 0.07150867698533882, 0.04194005415023815, 0.024242641689676433, 0.09822082225113146, 45.71956249975389, 63.35735113390031, 44.287650277537686, 27.36734747886658, 50.99111034024147, 63.38635706132459, 76.40479780012562, 47.89186916043682, 0.06457705215941514, 0.9699790384019575, 0.09918340406711064, 5.920114199961386, 57.765204445008315, 73.58004800734982, 77.36140112723075, 73.22780347639515, 76.12295981376403, 77.08046528600877, 74.18927838725429, 71.5916181379749, 66.01435292151668, 61.8566797625634, 64.09305441764094, 63.506613008437625, 61.381837629502826, 64.19511841189477, 60.74633521418418, 60.97078108018445, 59.7446991551307, 52.18534654186618, 50.787041187286384, 49.65295453225413, 48.889323972886615, 48.29547712879796, 48.54640683820171, 48.92332699991042, 46.9252049538397, 47.73275821439682, 47.999491153224824, 47.945040810492735, 50.86593966330252, 56.35593998816706, 58.546328775344364, 60.03426813310193, 59.97936671780002, 56.73651972124654, 51.25532119504867, 48.21883793800108, 45.484208522304414, 49.90175439465431, 46.35970115661622, 45.23292579958516, 46.28529379444738, 44.49528486497941, 45.62637482920001, 43.304268929266165, 47.006119528124415, 48.31896035901962, 49.01754233144945, 47.496894328824936, 45.69227064809492, 48.955968964484434, 49.642246461683705, 47.78638093702255, 50.77001025599819, 50.31382291547714, 51.97819832832583, 50.386979041561005, 51.621345012418686, 52.742393708998165, 51.40440264055806, 51.84739905018961, 54.135325416441894, 52.28468841122043, 54.12595487410023, 53.51028004000264, 58.24478872360722, 50.92231196741904, 26.676200359098374, 21.36701149325217, 30.189522235624253, 24.152872946954545, 34.59510487894858, 62.14927288793749, 53.34638772472259, 50.22740525584067, 54.07516410273891, 50.433510118915194, 48.152718544006355, 50.278639255031464, 49.87014401343561, 47.3127390492347, 48.376834930912146, 47.60312780257195, 47.01989096979941, 47.699280784976104, 48.65775116028325, 49.38026743550455, 47.4882572697055, 48.688063236974905, 45.70189222212761, 44.349713940774244, 42.81182319887223, 44.01237833884455, 42.706060409545906, 43.843159444870494, 41.811269713986306, 41.639313005631976, 42.72685681619952, 42.51620200372512, 43.3565305894421, 46.084087971718084, 43.78137426991617, 45.09687839015838, 45.160091307855424, 48.030262147226644, 49.35286183511057, 48.07113324442218, 47.18073560345558, 47.52860669166812, 49.67323710841518, 47.077612569255216, 47.60998410563315, 48.93650224131923, 51.870191943260934, 57.693479984037346, 61.59107254397485, 64.37992872730379, 65.25242859317412, 62.5854875195411, 62.97987007325696, 60.546768942186915, 60.908113371941354, 62.163691520690925, 58.7818867160428, 57.95770260595507, 59.19304916935583, 58.362483362997736, 56.76048148062922, 57.27624570169757, 53.581690711359826, 57.296222332985174, 56.71683726772186, 68.87422361681539, 73.43620684839064, 78.68924110166489, 73.29688425986998, 84.17899039483841, 2.4071921600449473, 0.3386237021655806, 0.11823195813884659, 1.3453775043449094, 65.01792577005202, 71.70547669933688, 56.93093199883738, 55.442129719641905, 34.53042107243692, 46.40910733130671, 64.58512360049833, 44.490946723568825, 2.4284347363056678, 0.15643625730468383, 0.08829780028111513, 0.02793977435137476, 0.12697782472617206, 0.049118301831185825, 0.11872508127482669, 0.15868291739494572, 0.18489207231229354, 0.22727689795917083, 0.11338994537870731, 0.24104666956249746, 0.13524556051819556, 0.1307422352293807, 0.11198661019725185, 0.27105517625328035, 58.169867530945815, 75.02497857616794, 49.97869168558429, 29.310583799116074, 60.608667865876235, 75.04591618814777, 82.22040191773446, 52.511346493997884, 0.18331492710257732, 2.0998536194524458, 0.32402874661549447, 9.999770925891015, 62.76820721164827, 75.4798323108304, 83.17700524483958, 75.84487161328717, 80.31134513116653, 82.95984714261948, 77.8441821375201, 74.01516437530518, 70.2800795339769, 63.63475291959701, 67.36979853722357, 64.12727317502423, 65.66958050574026, 68.56770607732958, 62.16331497315438, 63.340900713397616, 62.62369140501946, 54.29511101015153, 52.72056571898922, 51.56858128886069, 53.21338407454952, 51.7297318673903, 53.88213249944872, 52.8267325124433, 49.370790989168235, 51.917448659097, 51.42353596225862, 51.870423363101104, 54.036540523652114, 59.76952775832146, 61.034033221583215, 62.67141488290603, 61.79920527242846, 60.03354641699023, 54.15654543907412, 50.24328301029821, 47.51481563814225, 52.463242546204604, 49.27765038705642, 48.35456763544391, 48.3454442024231, 47.95239525456583, 49.140685143009314, 45.83223650532384, 49.30029815243137, 51.78169542743314, 50.509690392401914, 49.998503577324655, 46.69714658491073, 53.44283488488967, 51.35981313643917, 52.83302399419969, 52.25357617101362, 51.49650381457422, 56.38381627298171, 54.47603817908995, 54.725524456270286, 55.13674182276572, 54.44686751211844, 53.80080999866609, 57.452520939611624, 57.21457819784842, 56.7436662797005, 55.46465589154152, 60.015613340562396, 53.82689376031199, 26.896200218508323, 21.889453549538892, 29.799064013265795, 25.005368724946056, 35.784893112797896, 66.77751279646351, 56.89064141242736, 51.377506948286495, 56.87066870350992, 56.06044038649529, 51.86170001183787, 52.514857015302105, 52.30835991521036, 50.64998965109549, 51.056033411333644, 52.44657247297226, 50.61049530583043, 52.04995416825818, 51.42727790340301, 51.88717580610707, 51.76328774421446, 50.239274347982104, 48.80464784560665, 47.498145564909905, 47.217225413168634, 48.92069116715462, 47.405648231506355, 47.13898589534145, 44.367376373660186, 43.71529017725299, 45.108978902139974, 43.826956133688654, 46.40894259175947, 46.43410067404471, 45.485914753329375, 48.519675885477376, 49.26413389944261, 50.199336774887584, 52.27295660203504, 47.80337264460903, 49.70570256633144, 49.495071288078066, 54.20454740524293, 50.38620633463706, 50.78159693748721, 51.75802784581339, 54.48249832276375, 59.75787831890968, 64.46445188214703, 65.69733519707957, 65.7158487842929, 64.49393633873233, 64.22306137700235, 62.10575811324581, 62.87293841761928, 63.941423431519546, 63.11595670638546, 60.69787433070522, 60.453079208250976, 60.92428530416181, 60.30260532133041, 60.580924941647446, 57.375516968388716, 60.939488410949714, 59.25075115696077, 73.59172098098263, 77.23778370888003, 82.11430964931365, 76.764706642397, 87.27923177903699, 3.4914968282945695, 0.4116352827798936, 0.5057346898942224, 2.004275141704467, 73.19502030649494, 79.90283027771981, 67.5890511851157, 68.28757824436312, 32.06945150129257, 52.847262197925204, 79.22229905282298, 58.69015816719302, 3.1831097891253815, 0.3062924015666208, 0.20407751863521917, 0.2877966795236834, 0.1823743856361797, 0.11234731503552008, 0.22918810346914878], [0.09133181489643552, 0.08569105588380369, 0.06675314023009231, 0.013983432567798564, 0.14847858027825434, 0.027646789770393122, 0.037857594584385236, 0.0531867036836282, 0.1173955126996002, 27.871658379031768, 51.308551680657175, 51.19930582661783, 38.64898035603185, 38.19587207609607, 48.81485385279502, 67.35325397983675, 61.20820214671474, 0.9187534355348157, 0.20195085855741657, 0.32884167867802805, 0.5378963173397127, 27.66996422121602, 75.83581878292945, 67.41492932842624, 70.15061778406944, 63.99117085241503, 65.41948626118322, 58.49427500078755, 58.29676405076058, 57.64901599576397, 59.02596404475551, 56.85590882455149, 56.02424867691533, 54.970700048631244, 55.85174283673687, 56.10452390486195, 50.54592524805377, 46.44628747817009, 47.502758272232555, 46.507378393603915, 46.61130943605977, 44.78945478316277, 43.002509224799375, 45.387184773722005, 45.06526016419934, 45.657957753827496, 45.14238180652742, 45.70089201773367, 50.624235368544056, 51.526788434674664, 56.81808148660968, 58.66027755122031, 57.395987818318034, 60.62263150368968, 58.12639590232604, 51.33408238810878, 48.213852605512066, 45.05127299216486, 45.91923859811599, 48.25695553133565, 45.36090881593766, 41.26317339558756, 39.189267235417525, 43.40381476186937, 42.09952862031999, 41.01815469803349, 42.315596303632184, 43.330635101564475, 42.516602085482695, 44.099062719652736, 45.949448693183164, 50.24910380763393, 46.624406230065134, 46.49946697296635, 47.217723554180516, 50.91281590923187, 48.87937291975945, 51.081811228106105, 51.597634284727036, 47.54871276117141, 48.19642943720664, 53.51474369725874, 52.58467912673951, 53.24719490543489, 56.346192898288855, 53.358594140698834, 52.02885573910129, 33.442457568260934, 32.93006658554077, 51.279204507027906, 40.447202728640654, 32.692718082858676, 53.098658669379454, 54.46469468455161, 50.283648121741514, 51.37885624362577, 49.058444807606364, 48.38911194955149, 48.3383878584831, 46.04337376932944, 45.99805078198833, 51.146542103059836, 44.83727239793347, 44.26337472854122, 45.83367601517708, 44.251211458636874, 44.45397838469475, 43.2987383873232, 41.59987749591951, 43.24033037308724, 43.772811735830004, 41.38053463351342, 39.20558821770453, 42.42681903223838, 39.37443448651222, 38.14948220406809, 37.81876756298927, 40.768397777311264, 39.3201292714765, 44.497006785485056, 44.59219486482682, 40.932788233603205, 43.95185224471554, 46.73144771206764, 53.42964395400017, 52.209622090862645, 51.22753512474799, 48.344514600692264, 43.04267037299372, 42.49521340093305, 43.178047057121034, 43.84994906763877, 47.70780801773072, 45.444678875707815, 49.96569295083323, 54.86741227488364, 58.09644076132006, 58.71514366519067, 63.42067780033235, 62.251297658489605, 61.7398048985389, 61.99674367904664, 63.40293692004297, 63.42865197889267, 62.10475790885187, 59.875219944984686, 60.09199757729808, 57.519840578879084, 58.19507268167312, 54.89743801855273, 55.997400053085826, 54.95035079217727, 62.12077294626544, 61.687272594821074, 74.55359597359934, 66.74338817596436, 84.35071960572274, 4.2341098573900044, 0.26995823027626165, 0.13604803761887935, 1.7879315441654575, 63.19557689851331, 65.56211933012932, 59.41030533083024, 40.541402370699, 27.230827423834032, 39.160865352999785, 53.84049654006959, 32.59625915558108, 2.4450964745013946, 0.1469602246558474, 0.1213447419145415, 0.06184468849471981, 0.05857797850283885, 0.07488776058439287, 0.02943344853608118, 0.035463435755622004, 0.030934502062718236, 0.0891338856590371, 0.07308709390100933, 0.0263955517702045, 0.02509076422410867, 0.07680799827099809, 0.04074585714167164, 0.10561061362105031, 37.104735374450684, 60.36349227351528, 54.57435630982923, 33.35781674231253, 42.81364710100236, 56.297771238511615, 72.27373400042134, 69.56812227925947, 1.1696892736419555, 0.1395366181649508, 0.6105267845334545, 0.38962168498866023, 28.14529076699288, 77.83469000170308, 71.8068778130316, 73.08762581117692, 67.20993057374032, 66.02420591538953, 62.795291177688114, 60.85031724745228, 59.60570996807468, 59.89034460436914, 60.41388688548919, 59.10079502290296, 57.28406690782117, 58.39572152783794, 56.8338768712936, 54.199671899118734, 49.56285376702586, 49.30212597693167, 49.96646173538701, 49.34973570608324, 47.406091459335826, 45.403089984770745, 49.3183018315223, 47.06504921759329, 47.953403303700114, 47.05701620348039, 48.76331390873079, 52.68009470355127, 54.813522831086196, 60.953820751559356, 62.76535172616283, 58.39649423476189, 63.074783586686664, 60.909176334258056, 53.596807526003936, 50.66012505562075, 48.42620972664126, 47.821439081622714, 52.009624358146425, 47.663285193904755, 45.192286122229795, 41.56885547022666, 45.73325549402545, 44.66137370755596, 44.13979653389224, 42.96981626941312, 45.20545744126843, 46.20275535891133, 47.88161216243621, 47.717625710272024, 52.29932277433334, 48.636021229528616, 49.93290193619267, 48.588917486129276, 50.73711333736297, 52.598933019945704, 52.97135030069659, 53.65270914569978, 49.354034623792096, 51.088267449409734, 54.27818990522816, 54.02098048117853, 55.37160550394366, 57.55316895823325, 56.954685872600926, 52.82048025438863, 33.39046262925671, 33.47832372111659, 50.709954846289854, 41.13088753915603, 33.83065062184488, 55.12904221011747, 56.441165247271144, 53.28100573632025, 52.42690570892827, 49.7141944977545, 50.13680634960052, 50.01334190368653, 49.37239523856871, 48.59890384058799, 51.06337216592605, 47.26347015750024, 47.93803937973515, 48.75918757530951, 45.93654409531624, 46.694863765470444, 45.42747143776187, 44.331722028793834, 45.53968260365148, 45.62354680030577, 43.67939656780612, 42.286798261827045, 44.16475457529868, 41.05117713251422, 41.28060440863333, 41.19084488961005, 44.71100345734627, 43.711289359677224, 48.18111258168375, 48.3153360889804, 44.926753428674516, 45.15220734380907, 50.095574394349136, 55.830942507713075, 56.18039823347523, 53.95413152633175, 50.68056060421852, 45.16446867296773, 45.51480693201865, 44.34171622799289, 46.535764586540964, 48.51898947069722, 47.852547399459354, 51.431031611657914, 59.03276543463431, 60.184094828944055, 60.802244678620376, 66.21469974517822, 65.59989959962907, 65.77300948481407, 64.83617098100724, 68.29094363797095, 66.62304985907771, 65.99499994708647, 63.62413114117038, 64.8379203581041, 61.45551935318978, 59.752700790282226, 57.506802620426306, 59.62308214556787, 58.48930535777923, 65.351170339892, 66.70663556744977, 78.36188008708339, 69.56199553705031, 91.0707595271449, 4.620063727901829, 0.3721163307707156, 0.10398900466820887, 2.320862263441086, 71.83629558932397, 69.39886416158369, 66.65163609289354, 49.38832398383848, 36.81811601884904, 55.001647549290816, 68.17610448406589, 45.6753848445031, 3.157793586292575, 0.14776444843699857, 0.14106752230755745, 0.06277129099133515, 0.18577149528409206, 0.02222614697060518, 0.09167213413503864, 0.22069470115726997, 0.13731082630974634, 0.2507258380853361, 0.16358004252035774, 0.24674775799916637, 0.16902226984741228, 0.18283635197627932, 0.17247107510845508, 0.20767675292107368, 51.12883260173183, 72.84789054624497, 64.23797815076767, 50.63643001740979, 55.076792317052046, 63.73234541185441, 78.45185925883632, 76.87822787992417, 1.5528836341634875, 0.4428246527189209, 0.9596410802295132, 0.7590410798307389, 35.29576570756974, 82.6287441868936, 76.21731635062926, 76.28900158789851, 69.20850369238084, 69.56027753891485, 67.1677964733493, 62.84714098899596, 62.02279213936099, 64.77822188408145, 63.83743747588127, 60.572868393313506, 60.33813415035125, 60.75777284560665, 62.94752228644587, 56.28895767273442, 50.2734068132216, 52.097234418315274, 52.46099110572569, 53.865713457907404, 50.28506409737372, 47.880090282809356, 52.020999231646144, 51.06412526099913, 51.07010687551191, 51.347881286374985, 49.95908767946305, 57.340148956544944, 56.9104415370572, 62.323987022522964, 65.14509685577886, 60.69723106199696, 65.72933389294532, 62.52134892248339, 57.31879949569703, 55.01084158497473, 49.36295801593412, 51.79892247722995, 54.68886990700999, 49.9830533612159, 45.75783698789535, 44.02824432619157, 49.2833064448449, 48.211020654247655, 46.83876375998221, 45.14267206192017, 47.391637525250836, 48.564516421287294, 49.05050200800742, 50.9548205714072, 54.367506196421964, 51.72787658629879, 51.85443970464891, 51.65565398431594, 55.14221745152628, 54.70753254428987, 56.11645183255596, 56.167254371027795, 52.80596748475106, 54.839806633610884, 57.440357669707275, 56.703144273450306, 57.27377068611884, 60.91700146275183, 57.728942132765255, 54.29452657699586, 33.885430443671446, 34.00911061994491, 52.985659107085205, 41.43749137078562, 34.99194283639231, 57.99291764536212, 60.667091569592884, 55.316708011011926, 56.02582939209477, 53.158321842070556, 53.26931315083658, 53.58973549258325, 51.79083847230481, 51.70762538909913, 54.9165831073638, 50.174072788607695, 52.1427966702369, 51.23582309292209, 49.6975322692625, 51.2811892263351, 47.97568236627887, 46.840638652924575, 48.59962163432952, 47.18869801490538, 46.205618689137125, 45.532657638672866, 48.5543143364691, 42.93502092361451, 43.04301161919871, 41.46595208875595, 48.30088607726559, 45.5880218936551, 51.3770950994184, 50.82217385691982, 48.75178998516452, 49.62306607154108, 52.83360058261503, 60.08096002763318, 56.95628227726106, 55.63210579656786, 53.23757725377237, 47.821172360450994, 48.96911282693186, 48.397823533704205, 49.36432692312425, 52.69249723803613, 50.30593895143079, 53.81511096031436, 62.54556955829744, 62.558838936590384, 65.41913717023789, 70.39094140452724, 66.62366174882459, 67.91949518265264, 67.7039295627225, 71.8280743014428, 68.22635004597326, 67.26808363391508, 66.90616653811547, 67.90607283192297, 64.47157882875013, 63.296919176655436, 60.047670871980735, 62.8061600654356, 63.30381470341837, 71.70116209214734, 70.24548422905707, 81.2967465000768, 73.54147541907527, 96.09618648405998, 5.731188337649069, 0.492760623174329, 0.31158689649835714, 3.1926982681597433, 80.41073799133301, 79.00273261531707, 75.5904588391704, 60.73156749048541, 41.234669531545336, 57.92860646401682, 79.95870836319463, 57.88342075963175, 4.147217100666416, 0.350644908725254, 0.23109708732414633, 0.16817892961684736, 0.2342434563944417, 0.19264457567084223, 0.19781542401159966], [0.01775331389639647, 0.08431365277858512, 0.04945701994602719, 0.05267864949400387, 0.09571294150044841, 0.009659487724063859, 0.04247371865917118, 0.18521942168233857, 0.08897861495854394, 20.23133235592996, 45.6063707413212, 43.513590135881984, 45.7119099555477, 36.927765877016135, 51.976374426195704, 61.26113453219014, 74.46764115364321, 6.80168160507756, 0.4094802161618587, 0.9285964396211409, 0.5165991956187833, 10.267621740218132, 73.06471132463025, 63.481172515499985, 64.68365746159708, 59.41499648555633, 58.20292134438792, 55.11279967523391, 57.42811595239947, 54.965491141042406, 52.82144123508085, 50.533742366298554, 51.41046662484446, 48.793661286753995, 48.418161023047666, 47.121841215318256, 47.99148559570313, 46.26333244385258, 46.528806301855276, 44.0744145454899, 43.149664786554155, 41.57759058860041, 45.80258730919131, 45.15073645499445, 47.17050606204618, 45.603672150642645, 47.176930904388435, 48.45738080240066, 53.21977361556023, 57.300387890108176, 59.444096549864746, 58.18014021842711, 61.03857924861293, 60.84690086303219, 61.2059977746779, 56.20924726609261, 49.43290172084686, 45.775162096946474, 47.86949203860375, 48.93572168965494, 45.933974942853375, 42.82734009527391, 39.825660028765284, 44.05706982458792, 41.55262470245361, 41.05832761333835, 39.65511537367298, 40.20257234573364, 41.538837571297925, 43.30982692780034, 45.0817576531441, 44.3898593994879, 44.42509405074581, 46.20288479712702, 46.108775369582645, 46.96372262893185, 51.555951256905836, 49.74980569654896, 48.25213493839387, 45.564166038267075, 53.76240214993877, 55.19003506629698, 53.28073117040819, 57.034035421186886, 55.407059807931226, 56.07772234947451, 58.04905460726831, 38.712628656818026, 37.52828859513806, 46.53404658840549, 46.84785189167146, 39.89340328401135, 56.69724110634097, 57.41203423469298, 50.632931263216086, 53.654305550359915, 50.627177146173295, 48.705305976252404, 49.7082717187943, 45.86215634499827, 46.5631897987858, 48.01366659902757, 48.63754703152565, 46.32962049976472, 46.78477625693045, 43.71793385474913, 45.22641858746929, 43.453154256266934, 43.33276887093821, 43.23563921836115, 42.78890086758522, 41.0638895342427, 40.20112499114006, 41.99444440103347, 39.586242475817286, 41.7679589025436, 39.55249440285468, 40.90008351110643, 43.29136825376942, 47.26028519292032, 45.11782384687855, 44.45242512610651, 45.179024588677194, 52.68203627678656, 57.93586677120578, 57.8529517881332, 59.48482644173407, 56.502420902252204, 48.391006454344726, 44.25693811908845, 44.8693024727606, 45.22319832155782, 45.460529173574145, 41.797917965919744, 45.42413350074522, 49.36652345042075, 54.40434509708036, 58.08364206744779, 61.93016536774174, 65.1167106628418, 64.03929441205918, 64.27509946207847, 66.5163064772083, 64.693671272647, 65.37017814574703, 65.03837700813048, 65.15096472155663, 62.95490026474, 62.86145371775474, 57.585285325204175, 60.024689705141135, 58.12853359406995, 60.61213524110856, 58.87304259884743, 72.41794386217671, 67.4489676567816, 87.47017275902533, 6.315901452495206, 0.2540841683625214, 0.21243757568299773, 1.8224712004584653, 65.86339658306491, 63.43440217356529, 60.63313953338131, 37.50655081964309, 39.043806137577185, 34.05519846946963, 46.943867591119584, 43.810035028765284, 0.7434638157006234, 0.0625824120136038, 0.05478987673057183, 0.06463578812056972, 0.06277212985761224, 0.03360738474575262, 0.04785511477459823, 0.11351512414553475, 0.0857432647758434, 0.047108876188435865, 0.05922337693552818, 0.028612548936038252, 0.06703417958511461, 0.05997130091512396, 0.1715257072881345, 0.16399633469841174, 31.07431284842953, 56.787177132022, 44.49621054434007, 40.85221098315331, 44.43451166152955, 56.3395131018854, 68.68926817371, 81.0893472548454, 8.856174484375986, 0.4085911558039727, 1.0256000860564172, 0.5620607529436389, 11.313764933616886, 77.25973329236432, 67.38183236891224, 67.43783597023257, 63.78565042249618, 59.35217580487652, 57.249098977734974, 59.50771739405971, 57.28296472180275, 54.48782097908759, 53.78134327550089, 54.871558220155784, 51.89401249731741, 50.02832535774478, 49.00766580335556, 50.84490006969821, 47.68068875035932, 47.24144604898269, 47.05786735780778, 45.86409791823357, 44.22521006676459, 46.39251962784798, 46.102024970516084, 49.317058440177675, 46.822458467175885, 48.58234751609064, 50.987784170335345, 56.234483795781294, 60.45794294726465, 61.10436916351319, 58.801541712976274, 60.31436850947719, 62.98945242358793, 63.906945797704886, 59.243694813020774, 51.31953039476949, 48.22194053280739, 49.38734731366558, 52.27953049444383, 49.610067336790024, 44.84053188754667, 41.43436916412846, 44.61124581675376, 44.04308265255344, 44.425588269387525, 43.48881252350346, 42.86184126330961, 44.21736140404978, 46.64670098212458, 47.97336424550703, 46.1984250622411, 47.02117358484576, 46.593596012361594, 49.35512896507017, 49.30066293285739, 53.14457785698676, 53.21396066296486, 51.907615277075, 49.30330268798336, 54.988829243567686, 56.997506387772106, 55.37854809914866, 56.54341359292307, 56.72263060846637, 59.004849926117934, 60.25193222107426, 40.00821498132522, 38.38236116593884, 46.50715089613392, 46.79891247903147, 39.53014473761282, 57.29701072938981, 59.72174936725248, 52.81532233761203, 56.76239559727331, 51.718560957139545, 51.877036479211625, 50.22594613413657, 49.086987895350305, 48.555047819691325, 49.49550667116719, 50.864735495659616, 52.21643524785196, 47.76631016885081, 45.65944825449298, 47.75862232331307, 47.130580256062174, 43.943795696381606, 45.41559450088009, 44.371820419065415, 41.842076009319676, 43.281715300775346, 44.549048792931345, 41.177873611450195, 43.12555005473476, 41.531565496998454, 42.20835085838072, 48.72101506879253, 49.86738658720448, 48.29778348245929, 47.79764598415744, 47.5083476497281, 56.52702200797297, 59.70879770094349, 61.390808090086914, 62.35112982411539, 59.60354481973956, 52.06366677438059, 46.445585373909246, 46.09640029168899, 48.50488462755757, 46.488998166976444, 46.71123573856969, 48.8733010907327, 50.59409195376981, 57.66591748883648, 60.621309664941606, 64.12821846623575, 67.40807302536504, 67.49336888713222, 67.3960627278974, 69.11850098640689, 69.03826498216199, 70.09265299766295, 68.82546071083316, 69.00960030094271, 66.94232294636389, 67.20161514897501, 61.424183537883145, 62.52727170144359, 60.02790212631226, 64.54549981701759, 61.52178779725106, 78.00454431964506, 70.50993827081496, 94.09209851295718, 7.310999410767709, 0.20037844777107242, 0.13617856367941827, 2.442189507907437, 74.28316423969885, 71.90329751660748, 68.91969957659322, 48.09622856878465, 35.97519866881832, 42.17124523655061, 58.23459840589955, 54.69122332911338, 1.3252963173773982, 0.08726044062284694, 0.10826074157751377, 0.029729767514753248, 0.04951295968625815, 0.04346300246975115, 0.05283652489343959, 0.22198238770567605, 0.1541863336798645, 0.19930912692460323, 0.21974901158002116, 0.12947725552705028, 0.20841325452971846, 0.1444091978332689, 0.38232083642675035, 0.3316660303502314, 44.86652543467861, 70.56115658052506, 57.9159725096918, 61.6368152249244, 53.344940370129, 67.35710574734595, 74.8489426028344, 89.84520712206441, 9.334980172495689, 0.6441532640207199, 1.6751988256169905, 0.6599112636139316, 14.836459313669513, 82.32348180586293, 70.60398886280676, 71.40073991590931, 67.42702591803767, 64.35162490414035, 60.3681363597993, 63.80638407122705, 61.623000637177505, 58.2957834582175, 55.360905278113584, 57.47496866410779, 53.53256302495157, 53.29446338838147, 51.4504591111214, 53.297691499033284, 50.0667175169914, 50.895883037197976, 51.02459169203236, 49.62766701175321, 49.05948423570203, 51.05813187937583, 49.5799631457175, 53.012511653284875, 50.03072584829023, 51.36589673257644, 52.47069897190217, 57.78268644886633, 62.1974160594325, 64.47396362981489, 61.82359457015992, 61.15126109892323, 65.92216153298655, 65.59528296993625, 60.76344459287582, 54.15051675611927, 51.30883016893941, 51.43733486052483, 54.49395164366692, 51.908180098379816, 46.53553708907097, 45.72963906872658, 48.343604610812285, 46.21560896596601, 46.7370920027456, 44.070578467461374, 43.91851209825085, 46.059141697422156, 49.81567013648249, 50.910234989658484, 48.11196904028616, 50.82321328501548, 50.36889691506663, 52.3817043150625, 51.41735822923722, 55.87533981569352, 54.6964910722548, 53.27279229317942, 50.971863269805915, 58.11917089646863, 60.9190881636835, 58.36392679522115, 60.924622627996634, 58.88015385596984, 60.16644808553881, 62.64434660634687, 41.21913302329279, 38.04216615615353, 47.40560508543446, 48.245749319753344, 40.11955538103658, 59.85469418187296, 63.33450725001674, 54.62819476281443, 59.32066348291213, 55.68931356553109, 55.12078954327492, 55.411056703136815, 52.5210072917323, 51.107965592415106, 53.53834459858557, 55.21238473153884, 54.55483859585178, 51.787382864183, 49.17347615764987, 52.06982489555113, 49.11922585579657, 46.47081013648741, 47.775617953269716, 48.3390546614124, 47.54972865504604, 45.950499888389345, 47.34715000275643, 43.53948562375961, 46.59787924058976, 44.630896891317065, 45.25983325896725, 49.679002992568485, 52.97677493864491, 50.62427851461595, 50.46468119467459, 50.38094251386581, 58.19049135331185, 63.44465132682555, 63.32684293870003, 66.45875746204008, 61.81170586616763, 54.34883963677191, 49.32999441700597, 50.108749635757945, 51.97315416028423, 50.6180380236718, 48.705105935373616, 51.380754670789166, 53.27852679837135, 60.93336559111073, 63.733675095342825, 68.24956263265302, 70.94192458737281, 70.26460186127694, 70.17291253612888, 72.97306906792426, 70.56336095256191, 72.76317519526329, 70.85897430296868, 73.63813046486148, 68.93395346979942, 69.39845623508577, 65.11016030465403, 66.0498974400182, 63.87355858279813, 66.99332944808468, 64.8891386678142, 82.6184283533404, 72.39466067283385, 98.36984326762538, 8.374925159638929, 0.432690657795437, 0.3583324784713407, 2.596670831403425, 84.69383285891625, 78.97577024275257, 79.4365232221542, 56.841529415499785, 53.67233668604205, 51.86191966456752, 70.08203906397667, 63.758793953926336, 2.2393507534457795, 0.2720093234412132, 0.3886027574058502, 0.11438771361304868, 0.24365074031295317, 0.24948761017332155, 0.1902722005522059], [0.024478236709030408, 0.07022607726074996, 0.06458590047494059, 0.10592992672876966, 0.10405082030281906, 0.1749733480955324, 0.06707239971165696, 0.030683257782291022, 0.15643205914285876, 15.041711061231553, 43.613390922546394, 42.05844571513515, 31.157065053139966, 44.271215546515684, 47.1745696375447, 49.25171175310689, 76.05668744733258, 21.532445300009943, 0.6308743249504798, 0.32938560110426723, 0.19382879438419498, 3.483733722279149, 70.64466384149367, 71.09321040491905, 65.4472605643734, 62.824438310438595, 63.45059764000678, 61.61630907366353, 59.57830436768071, 55.1137214322244, 54.980592266205825, 50.48688573222007, 48.50257042915591, 48.000236403557565, 48.290511408159816, 47.506198190873675, 45.92436121356103, 43.90972598906487, 44.353165626525886, 44.285508663423606, 42.74606466293336, 44.39188334249681, 42.19842333947459, 47.52453919379942, 49.06512460400982, 45.55909441363427, 46.59148577720889, 54.22999182055074, 52.709590927247085, 59.07855518402592, 58.01364737172281, 54.61685126827609, 71.43528030764672, 61.467058966236735, 60.28759048831079, 58.65107174842589, 51.90623460277435, 48.47909112130442, 48.22371736649544, 52.396938800811775, 52.02154836347027, 46.75660579435287, 43.24725335644138, 41.926991401180146, 41.4996805498677, 43.322190238583474, 43.884967988537205, 41.15422956405148, 41.72828412825062, 40.43473351386286, 42.53852029000559, 44.97308446514992, 45.596808002841094, 44.37096926473802, 44.115662190221975, 48.259081455969046, 52.12662473801644, 49.19599056243897, 50.57584116535802, 51.00162621467344, 49.87953808999831, 53.77761702383719, 51.71531323463687, 52.87202019845286, 56.0314501485517, 55.24567780956146, 56.66482663923695, 43.01382526274651, 33.61855237714706, 43.212152065769324, 41.755324948218565, 46.00891966973582, 54.93878372253911, 52.53618686429916, 53.41904963216474, 54.41365288149927, 51.288869227132494, 50.58445076788626, 49.70665962465348, 50.28882565036897, 47.2735781054343, 46.26214788806054, 46.24025714012885, 47.46717845239947, 45.69602827872, 45.2396644315412, 42.42362622291812, 44.70670846200759, 44.87778263707315, 42.8977584069775, 41.963112508097005, 40.97712278366089, 42.312348581129505, 41.2610710051752, 42.548075183745354, 42.67767421660885, 42.1430943858239, 41.87609864819435, 47.88436174392701, 51.101442690818544, 44.94410207194667, 43.86331650518602, 49.94304518545828, 56.35479073370657, 57.56338281016196, 56.176358192197746, 59.101975656324825, 58.16456448647284, 55.725324846083126, 52.868921526016734, 46.19933505212107, 43.6701476189398, 45.41201729928294, 45.86808304632864, 45.901011343925234, 43.15422650306456, 49.1519933362161, 52.53599074579055, 57.02297825967112, 61.22226384378249, 62.733764879165165, 62.373279448478456, 66.59380466707292, 63.610869607617786, 68.2146692276001, 67.04890158868605, 67.95946413470854, 66.6239284699963, 70.76632791949858, 65.06415482490294, 68.39966389440721, 59.73210442450739, 64.7355661084575, 57.19658236349783, 74.58573587479131, 68.16446288939446, 88.29270162890035, 5.234150002079626, 0.0838108616130006, 0.13934469781816006, 5.676883122613353, 73.81977542754143, 59.816639346461145, 57.46052649713332, 36.516936825167754, 52.3784448254493, 50.1350805067247, 62.08231018435571, 48.260689627739694, 2.650583319125637, 0.1367348354429968, 0.07920772272853122, 0.06938228503830972, 0.07697597070927582, 0.10191302130659742, 0.05530012576209922, 0.03850891104628963, 0.066880977322017, 0.09926401949938267, 0.033703681997834675, 0.08972752719156205, 0.1370340080991868, 0.08166697221778094, 0.15082071024564006, 0.15471861156965458, 27.108363182313983, 56.31390002466018, 45.4938457858178, 32.18267463868664, 49.885221604377996, 56.543409670552904, 56.71921814641645, 83.6492899925478, 24.381433379265573, 0.7938672530074274, 0.4450840605122428, 0.298699765436111, 3.9565582861823425, 72.08095735119235, 72.29269473783432, 69.00408544848042, 65.68290479721563, 65.88407531861337, 65.51809072494507, 62.84364223480225, 57.75522985766011, 57.81060980212305, 52.793827749067745, 53.069040852208296, 49.74633047657628, 51.96776874603764, 50.8285947768919, 47.0634606576735, 45.98935880968648, 46.51054766870315, 46.523922950990745, 47.600723389656316, 47.82341595618956, 45.84493321757163, 49.807044844473566, 50.19115078833796, 48.937459299641276, 47.08986213130336, 54.9921711029545, 57.255339468679125, 60.51723741715955, 59.32369547505533, 54.814758377690474, 66.764890609249, 63.6196517944336, 62.70246436519008, 60.30649631254135, 55.56791228632773, 51.74411519881218, 50.80097344613845, 56.28736519044446, 54.66791660554948, 51.52430165198542, 45.700052630516794, 45.13414090679538, 44.57359106309953, 44.81942169127926, 43.87249485138924, 43.35107065016224, 43.82254738961497, 44.363065688840805, 45.06154960201633, 46.95649762307444, 46.621154585192286, 45.90685175311181, 47.026158917334776, 49.93043084298411, 52.14130616957142, 50.26518160297025, 50.154782572100245, 52.22104403280443, 53.110621898405014, 56.13519291723929, 53.61584278845019, 55.59422354544363, 57.72065024222098, 57.22015188586328, 59.951882670002604, 42.14614598981796, 34.69547833165815, 42.632002138322406, 41.25803116829165, 47.26328580610214, 57.50351175185173, 54.7545813745068, 53.82700750904699, 56.57875022580547, 54.51806637548632, 52.573904375876154, 52.19252447928152, 51.47919831737396, 49.630585255161414, 50.987784170335345, 48.30702850895543, 48.70074033737183, 49.48671663961103, 48.69093048957087, 46.53741198201334, 46.38162720587946, 46.574290106373454, 44.944192286460634, 43.87751940757998, 44.86377585318781, 45.460689990751206, 45.63056784291422, 44.84108494174096, 43.5261691770246, 47.118762154732984, 45.650058100300456, 50.80673148555141, 52.01123252991707, 46.41488498257053, 47.37116667532152, 52.82317100032684, 58.131789161312966, 59.60628655649001, 59.24906846015685, 61.20137722261491, 61.626993610012924, 60.875679292986476, 56.71211865640456, 48.40913564928117, 48.01379603724326, 48.99812659909649, 48.008685188908736, 48.300674269276286, 46.58686130277572, 51.20353021929341, 53.50906410524922, 58.53332219585296, 64.11257605398855, 67.3708575771701, 66.6048579062185, 71.03905031757971, 66.18698427754065, 69.78410367042788, 70.14962934678601, 71.90723557626048, 68.16511400284307, 74.97335233995992, 66.04041314894154, 72.37864171305011, 63.76588559919789, 69.70340482650265, 59.753347981360655, 79.56290198910622, 70.83866427021643, 92.46786071408181, 4.97274217105681, 0.04551870365356726, 0.24064798208494342, 6.708083556544397, 80.78819551775533, 70.04987562856367, 69.75833369839576, 47.22039468826787, 40.7722181658591, 50.165306291272564, 72.48151763792961, 57.03245470600744, 5.029976906314974, 0.1265116449024889, 0.12064606972759771, 0.07174032665188275, 0.04060896872092159, 0.10811544534179474, 0.027194610203526197, 0.1006358148409955, 0.20254779426801592, 0.2024803938524377, 0.2589351443513747, 0.17801146894212694, 0.5276703918653151, 0.15814357617449376, 0.2377530277496384, 0.40858153373964373, 42.109981736829205, 69.5381945948447, 59.95212585695329, 44.81993552177183, 59.85077181170064, 63.015292998283144, 62.05896815946026, 90.59607428889122, 26.160465555806315, 0.873979886452998, 0.80325317839461, 0.3989939127237566, 5.232243239879608, 77.41520820125457, 77.39410584972751, 71.50287059045607, 68.18864822387695, 69.1374695685602, 69.50460341668898, 65.98528031379946, 61.253211344442065, 61.17902363500288, 56.33731265221873, 55.267752908891254, 53.30223360369283, 53.393530691823656, 54.69071734336115, 51.85813065498106, 50.9849561414411, 50.159881653324256, 50.744095156269694, 48.9750159940412, 48.37814892491987, 47.69582517685429, 53.076371762060354, 54.37515874062815, 51.39288263936197, 50.81302688967798, 60.18555002827799, 58.386072497214045, 61.876883891321, 62.28470448524722, 57.652248028785955, 66.72719663189304, 66.0856145428073, 64.29709219163465, 65.02062436073058, 57.7509662412828, 53.84517985005533, 53.13308923475204, 59.843644865097545, 56.66425789556196, 54.8105614416061, 48.41185777418075, 47.850550913041644, 46.94602881708453, 47.60831317593975, 47.61729540363435, 44.518666113576586, 44.84865511617353, 45.46171372936618, 48.22905178992979, 49.33851380502024, 47.74261513063985, 51.24194983513125, 49.17438614752985, 51.59974451987974, 57.001534661939075, 53.34066106427101, 54.47803074313749, 57.93155608638641, 55.55093626822195, 59.53895122774186, 56.4627069042575, 58.05941358689339, 61.06675363356068, 60.67760352165469, 61.675917333172215, 42.10461985680365, 34.2566631686303, 44.66428802859399, 42.26837881149785, 46.579138155906435, 60.18729156063449, 57.54020944718392, 56.96067925422423, 61.20784913339923, 55.41531247477378, 57.541958824280776, 54.32271665142429, 54.77923347103981, 53.966192814611624, 51.7059858383671, 50.62552582833075, 51.70805684981808, 51.410670588093424, 50.98197906248031, 49.23546529585316, 48.43925945220455, 48.553443570290845, 47.688580559146025, 47.17411464260471, 45.76672115633565, 47.38608344908684, 46.94767229018673, 47.48957126371322, 47.9111554545741, 48.826758246268, 46.86300400764712, 53.149716161912494, 58.38218935074345, 49.53607182348929, 49.45767148848503, 54.32983967565722, 61.95084802566036, 62.160428108707556, 62.49799905284759, 65.233259970142, 64.60983061021375, 61.3002876312502, 58.412368066849254, 50.009592117801795, 50.72359684974917, 53.17212074033676, 50.51291065831339, 50.937675891384, 47.882514307575846, 53.699318670457416, 56.92116137473815, 62.098815518040816, 67.09804888694518, 71.81247111289733, 68.86616706848145, 72.2175342805924, 69.49397379352202, 73.29905725294545, 74.52153451981084, 75.74872647562336, 71.6185962000201, 77.25819572325676, 68.59563335295647, 74.96154600574125, 67.40339756011963, 72.39541376790693, 62.98847967578519, 84.11605204305341, 74.00625275027367, 97.01594306576638, 5.892050621971007, 0.26144255012754475, 0.28130218446735417, 8.17876301465496, 91.736432813829, 75.16187713992211, 75.49168571349114, 55.58162097007998, 67.05647960785898, 70.2041659816619, 81.4308209573069, 73.79741007281889, 7.006759297463202, 0.3347552645831339, 0.2532022785876067, 0.2031138106699913, 0.14128118422963928, 0.20529395900666716, 0.18835174070010263], [0.0825470999904698, 0.09177738695495552, 0.09517877137348538, 0.08978574987380736, 0.032342761274307005, 0.0642770674500254, 0.04779564719947596, 0.13052812897630278, 0.763949313231053, 25.97254676203574, 46.184280995399725, 45.38641206679806, 22.51893316545794, 45.26810553766067, 45.562326446656265, 47.216193829813314, 73.47467745504072, 31.43486692059425, 0.04451334348789627, 0.09201755551921745, 0.3272216785098276, 0.29589873348032275, 52.53490032688264, 76.49440826908236, 64.77779434573266, 69.47468357701456, 63.11303846297726, 62.85894732321463, 58.3308651370387, 59.7654406486019, 54.498132890270604, 52.78446112909625, 48.227777019623794, 49.203348928882235, 47.93590561036141, 46.06710018650178, 45.84616091943557, 45.67508282199983, 45.5452759035172, 45.507287748398326, 44.40054785820746, 46.17589496797132, 47.318363728061804, 44.477540062319854, 45.52880587116365, 47.75981864621563, 48.78431820100354, 55.8246902496584, 54.24298663293162, 59.427826558389974, 55.41530463003344, 59.66894641999276, 71.34274375054144, 60.648244580914906, 58.16128146263861, 55.53341896303239, 53.23423539438556, 48.50810097109888, 48.41991824488486, 59.759870882957216, 55.83574348880399, 53.819394188542525, 47.70689802785074, 44.66674343232186, 40.564709094262895, 42.57695951769429, 42.880009681947776, 44.52810725858135, 42.497245188682314, 42.60019171622492, 43.89240872475409, 41.24304379186323, 44.41848093463529, 45.2814612080974, 43.484996057325795, 44.51193532636089, 46.38437286500008, 46.61236455363613, 49.19062868241341, 49.19748890784479, 49.7892019825597, 50.022073099690104, 51.51877503241263, 53.21701618932909, 56.48555078814107, 54.472715931554, 56.97143439323672, 40.73813276906168, 28.247360644801972, 36.726112904087195, 35.73767954303373, 51.48582712296517, 60.03096941978701, 53.80073939600299, 54.92369828685638, 53.61505831441572, 49.48408080685524, 50.405861331570534, 50.07423277824156, 50.51290281357304, 46.77177359980922, 45.770470942220385, 47.324247283320275, 46.34137584317116, 44.95288818113266, 46.41356314382246, 42.94819616502331, 42.27657656515799, 42.30335850869456, 40.25858379179432, 43.39780961313556, 43.211045957380726, 41.09686882265153, 43.59570887780959, 41.94973330343924, 42.5922606837365, 47.02528030641618, 46.66916047373126, 50.336094133315555, 48.6078429222107, 44.44736134621405, 46.253687335598855, 50.23313583866243, 55.60171135010258, 59.1310521864122, 57.41620371418615, 54.50635417815178, 56.57751860157136, 62.96295289070376, 59.796686249394575, 55.35282127318844, 45.119459475240404, 43.608433046648585, 44.778119133364775, 48.1801986694336, 44.527436533281886, 46.47090819574172, 46.49946697296635, 51.35225080674695, 55.203677069756296, 57.862530216093994, 61.64243598138133, 65.37887796278923, 63.28339484430129, 65.99721216386365, 64.99069275394564, 66.54367677627071, 65.32410990807318, 70.9533465293146, 67.31843117744693, 71.3063520000827, 63.37093037943687, 69.27172445481824, 59.84760253660141, 74.17130608712473, 69.02517995526715, 82.2151537864439, 1.8596281808230186, 0.03632531914439413, 0.4450482075973865, 11.503435065669398, 75.38318510978453, 56.335692713337565, 44.97280989923785, 37.2176839459327, 55.61844025888751, 53.65132062665878, 59.370328534033995, 53.47894030232584, 4.768263130418716, 0.12282845504101246, 0.15299914254536554, 0.07083633524035254, 0.03660943817287203, 0.03244910193907638, 0.0438905599707317, 0.1422608115019337, 0.051095168737153855, 0.08176890021610646, 0.07416634324697718, 0.09586051301730257, 0.10935999347918457, 0.02616834924406102, 0.19086841614015643, 1.064807178993379, 36.83902617423765, 61.42265381351594, 51.90451660463887, 33.41987648317891, 57.03945221439485, 53.57788208992251, 57.80089016883605, 81.65828704833984, 36.75411470474736, 0.0825603609724391, 0.1327747431012892, 0.425660299557832, 0.46264622781065207, 53.31745632233159, 79.22520945149084, 68.6948065603933, 73.83038151648738, 64.8398893879306, 65.26087737852528, 62.42085779866865, 61.4629130209646, 57.867346886665594, 56.1410843172381, 51.50944371377268, 51.339675687974506, 48.247247665159165, 47.89350871116885, 48.08696785280782, 49.66441569789764, 47.156683629558934, 49.67644560721613, 46.3168296506328, 47.04842229043284, 48.86305585984261, 48.11577373935331, 47.22626647641582, 48.97071315396217, 50.93215319418138, 57.377587979839696, 57.568634863822695, 61.81370235258534, 58.54252407627722, 59.15795180105395, 70.14518137901061, 61.871847568019746, 60.34448054529006, 57.06901119601343, 54.826925569965, 50.14548263242168, 50.709327267062285, 61.59617554756903, 57.58175126967892, 55.03636444768598, 50.6159552451103, 44.84718030498874, 43.6896300315857, 44.929801110298406, 44.036877462940836, 45.66024449563796, 43.41179678517003, 44.55613651583272, 44.701695672927364, 45.659652217741936, 45.92433375696982, 46.36993854276596, 44.53603829106977, 47.05171315900741, 46.825768947601325, 47.639786274202415, 50.91867200789913, 50.68607153431062, 52.23048910017937, 52.34135881547005, 53.63523106421194, 56.387503300943685, 58.15638242229339, 57.05400028536397, 58.659536223257746, 42.4003077322437, 27.572875753525768, 36.01492443392354, 35.74960747072774, 51.172233627688506, 60.75665104773737, 56.189125507108635, 56.140954879022416, 56.2475609779358, 52.36781520228232, 52.33361997912007, 51.51539787169426, 52.30761466487762, 47.06281738896524, 48.39507002984324, 49.59992800989459, 51.032467811338364, 46.75445241312827, 47.916215312096384, 44.11666631698609, 43.08822085780483, 45.405474785835516, 43.744786400948804, 45.12836325553156, 44.923964623482, 43.71534116806523, 45.826807945005356, 44.75030560647288, 47.51911455585111, 49.26473402207898, 47.870300046859256, 51.440904217381636, 53.287222693043375, 45.67079567140149, 50.360467741566325, 51.250700642985684, 59.852113262299575, 60.566149373208326, 59.47387910658314, 56.500546009309836, 60.095111939214895, 65.28378794270178, 61.17694477881155, 59.73781147310811, 50.13306048608596, 46.95077488499303, 47.24455256615916, 49.17603354300223, 46.91057059072679, 49.25790909797915, 49.11721760226835, 53.73468668230119, 57.37385388343566, 61.389898100206935, 63.6012323441044, 68.77235966344034, 67.11909632528982, 69.27300314749442, 65.56255471321845, 69.03367580906038, 69.75328953035417, 73.20226100183302, 70.6025218963623, 72.82479563067037, 66.29726563730549, 73.05237154806815, 63.41422550139889, 78.69172788435414, 72.80367758966261, 87.1461457590903, 1.7166679616897338, 0.0672432373187715, 0.4217209835206309, 13.496865957014023, 82.13272909964286, 64.27448364996141, 56.32834219163465, 44.7930202176494, 49.375337016197946, 48.32227083944505, 68.04158287663614, 65.31721438131025, 7.2487626729473, 0.19706562311658937, 0.2685322955010399, 0.08505086684899946, 0.11997002011705792, 0.027056555413911422, 0.12279616443500405, 0.25409754425767933, 0.1247445252093096, 0.1585646334194368, 0.27932117302571574, 0.19929293182588395, 0.23518597436768396, 0.11010248589539721, 0.34321146566540967, 1.141237626152654, 50.82118149726622, 72.96608724901753, 62.07632072510258, 34.23966753867365, 60.534825325012214, 62.286281278056485, 59.12949892782397, 88.425536617156, 42.53057356803648, 0.17277436931767773, 0.32726920660465, 0.7513961965037931, 0.90621079889036, 58.57835100543115, 82.63388249181932, 72.53008442540323, 77.55410717379662, 70.20934351028936, 68.75395590259184, 64.67337300700527, 65.33242141046833, 60.850544744922274, 59.086129280828665, 53.354738450819454, 54.96913894530266, 53.01801081626646, 51.369073852416015, 52.11883491085422, 51.68276932931716, 51.66265149270335, 51.84431998960434, 50.20228639725716, 51.76285628349551, 52.408509792820105, 49.664760866472804, 49.732225633436634, 51.288653496773016, 52.01237393963722, 60.09369596358269, 60.11710466877107, 63.29617784869287, 60.69710162378127, 58.8246758522526, 69.4475015517204, 65.66583071985553, 62.29568319935953, 60.15896028087985, 58.86588427328295, 53.330584495298325, 53.68825758657148, 65.29104824989074, 60.323790042631096, 58.456530032619355, 52.6025612123551, 48.76576931245866, 45.51025698261876, 45.335770345503285, 47.386448229512865, 49.061814123584384, 46.070218470788774, 46.41827391039941, 48.28999365529707, 47.89908632155388, 48.75964649261967, 50.251468996847834, 47.75553541798746, 50.55897105124689, 50.89074080990207, 51.89291423366916, 56.790468000596576, 54.44264311944285, 56.32461593997095, 56.298057571534194, 56.17867631296958, 59.256689625401656, 61.68981429069274, 58.956106631986565, 59.93445165695683, 43.232870025019494, 27.52286357264365, 36.3766767901759, 35.13791776472522, 52.901351682601444, 64.19110582720849, 59.7616163376839, 58.59158508239254, 57.930599028064364, 57.73733600493401, 56.21864134265531, 56.2404614879239, 56.05272116199617, 50.883649164630526, 50.2823184382531, 53.139051237413966, 53.50393364506384, 49.782620245410556, 52.384763763796904, 48.37015905687886, 46.82491387090376, 49.70349427192442, 46.86757356889787, 47.50937923308342, 49.018381718666326, 45.21502017974854, 47.69001614662909, 47.19577004832607, 49.443370526836766, 52.88050428513558, 52.524000060173776, 54.42966007417249, 56.62548134403845, 48.91084601802211, 52.3077166465021, 53.176533406780614, 61.7453589747029, 64.17284719405636, 62.29539686633695, 59.3167293456293, 62.33376941373272, 68.3543997426187, 66.40118491265082, 60.40720316671557, 51.11347260013704, 49.21332351623043, 50.95229456501623, 53.46398822722897, 50.9301527853935, 50.99713510082614, 52.31609875156034, 56.62670904590238, 59.46702280352193, 65.02142060187556, 67.55013342826598, 72.44045042222547, 71.4068195896764, 73.98385601658975, 68.56144597453456, 72.11198329925537, 70.88457953545355, 76.97722850307342, 72.86533724877143, 76.39665495964789, 68.78459745837797, 76.91349783251363, 64.06553506851196, 84.02912447529455, 74.8221371250768, 92.50922602991905, 2.1116403418202556, 0.25078902501733075, 0.5581100681616414, 14.666210797525222, 94.46031493525352, 69.84742641448975, 62.795024456516394, 57.68233260800762, 68.6055177257907, 75.62044928150793, 76.54779172712757, 79.62097660187753, 9.809920364810575, 0.46681659596581615, 0.35666838228221864, 0.19385635822771058, 0.28948666948464613, 0.13231020270576402, 0.17362226011051288], [0.11274859955113743, 0.052497458208592675, 0.06964860018342733, 0.10687224551915162, 0.012371157438704565, 0.01992207816651752, 0.05887242056609643, 0.13027539657008264, 1.3708210616342484, 37.621695918421594, 45.8496557512591, 48.072690425380586, 29.44680771520061, 32.70817810489286, 41.684565390309984, 45.4229607120637, 69.22317335682531, 51.32866951727098, 2.3333836947717974, 0.26174760633899324, 0.8813403979424508, 0.6740667911306505, 22.489064316595755, 86.50842328225413, 64.79873980245283, 69.59524939137121, 57.44231493242326, 61.54642812667355, 55.74008864741172, 55.340367747891335, 52.153030134016475, 53.32087662912185, 48.13408336331768, 49.75683850626792, 48.00657495375603, 48.72037964482462, 45.832479692274525, 45.62352326608474, 44.289238837457475, 45.9588937605581, 45.87407642795194, 47.41461084735009, 44.84090843508321, 44.34418339883128, 45.905824092126664, 49.203921594927394, 51.197250504647535, 54.29154949803507, 54.779009895939986, 60.39907209334835, 55.578977292583836, 61.33815027052357, 59.57097738019882, 60.03878670354044, 59.66985248750257, 53.98440045695151, 53.07918017910373, 47.087077248481016, 51.333137096897254, 59.630848438509055, 51.8916473081035, 52.424199273509366, 50.66828358557917, 47.84692272063225, 43.62213388566048, 44.34430499230662, 43.550228995661584, 42.03609604989329, 42.44180248629662, 43.97697110329905, 42.681070989178075, 41.4705491065979, 44.11108478423088, 45.144327302132886, 41.74722525381273, 45.96895464005009, 46.516152735679384, 44.436445390024495, 46.26969060590191, 49.01575765302105, 47.21119280784361, 50.084505465722856, 51.5466199382659, 52.62020403339017, 59.163643160173976, 56.31595926900064, 57.92753957932996, 43.4762256376205, 28.801699415329967, 38.4889554977417, 34.15173584415067, 48.01360384110482, 58.30028633917532, 54.847384652783795, 60.24268327220794, 51.25524274764523, 52.31078786234702, 48.027139940569484, 48.79634418795186, 47.57099574612033, 47.1238886925482, 44.61753337613998, 42.69694874363561, 44.02078397812382, 44.22619458167784, 45.55734111416725, 42.08969523829799, 41.19652448161956, 41.97416182487242, 45.12881432810138, 39.280885957902484, 41.78153814808015, 42.722695181446696, 43.37054521806779, 41.44968994202153, 43.87661726244035, 45.22731288786858, 51.312489740310184, 54.399430367254446, 53.07604228296588, 42.958817943449944, 44.58216928666638, 48.37839211187055, 58.38941435660086, 61.289328528988754, 61.63812137419178, 58.389245694683446, 52.86014718394126, 61.19088880477413, 60.286586361546675, 57.72443925180743, 56.4535834712367, 47.59341209165512, 43.5214937117792, 45.6388871900497, 46.101126747746626, 43.78081337098153, 44.04000751433834, 47.953348390517704, 48.835591423896055, 51.97938288411787, 56.89095912441131, 60.76872410312776, 61.70239333183535, 66.50879121595814, 63.48228646862892, 66.84012166915402, 63.40371747170726, 67.28976649622764, 65.02785721132832, 70.5572420550931, 65.77850864779565, 63.89880687959733, 61.351835420054776, 75.16198696628695, 73.36736140712615, 72.18274285716396, 0.1448407198392576, 0.1341872866595945, 0.5956613693025805, 19.33601410158219, 76.1937899743357, 63.89523752274052, 44.7224763901003, 64.21012147780388, 97.88913326878702, 42.187299497665904, 55.53160290564261, 55.21042354645268, 9.165065057816046, 0.17825609613810817, 0.18828792557601007, 0.07175239253669016, 0.09231010917574169, 0.010416721587159462, 0.13967455995659675, 0.03177317490260447, 0.0998487820728652, 0.041772698412739465, 0.1138558111063415, 0.06521036172465933, 0.04002013439012151, 0.042770753930052446, 0.1147979230529839, 1.5961812076068695, 52.3615276428961, 54.06590730913224, 62.82359107848137, 34.33469480083835, 36.691282256957024, 49.79507377070766, 53.05397502837643, 75.35953321764546, 57.77990156604398, 3.103408452964598, 0.2731176688065452, 1.0744158827489423, 0.8214647431046733, 23.097959333850493, 87.4792726578251, 66.9739450946931, 70.45845323993315, 60.853290404042895, 64.09789462243357, 58.67394701127083, 57.946978845903956, 54.51089628281132, 55.657977750224454, 52.68784138464159, 50.91290612374583, 49.53818990338234, 49.68090534210206, 48.84308707329535, 47.417289826177786, 46.15677733575144, 48.39720772158716, 49.070694369654504, 50.224541925614886, 47.458600228832616, 48.89812184918312, 47.92827267800608, 52.64162409690119, 51.252995229536495, 55.30960852100004, 57.106881680027136, 61.40321846931212, 56.591815640849454, 58.60312077306933, 63.81431510371547, 60.39050955926219, 62.02711851366105, 56.04394289755053, 56.05754959967829, 51.52063031350413, 53.53532437355288, 60.58893834390948, 56.65606014190182, 54.14064415039555, 52.750116855867454, 49.46848154067994, 46.01385793378277, 43.96810654670962, 45.18021306683941, 45.534089303785755, 44.72217044522686, 46.981090884054865, 44.59382657081851, 45.200436807447865, 45.43025239821404, 46.51952989639775, 46.180319401525686, 47.6555149785934, 47.130262544078214, 46.008139118071526, 48.36943341839699, 51.16958602782219, 50.34493123331378, 50.81505867742723, 52.412130140489154, 54.0911046151192, 61.23260713392689, 58.7899903328188, 59.93993513045773, 43.13044909507998, 28.947113444728238, 37.95320287827523, 32.14141718802914, 47.91010425936791, 61.03821446818691, 57.79041351810579, 62.79258474226921, 53.93058161581717, 53.74254318975634, 51.233763848581624, 49.171687556851296, 50.37995015421222, 48.87939645398048, 46.116000375440045, 45.73646007045623, 46.14758722243771, 45.17365094154112, 46.64155875482867, 43.930859719553304, 42.70575054230229, 43.3512040107481, 47.0745413534103, 40.87722786011235, 43.54430229433122, 44.531774674692464, 44.60973178186725, 42.129981902337846, 48.440730341019176, 49.289103707959576, 54.71989977744318, 57.317916962408255, 54.11450939793741, 47.773766594548384, 49.09986895899619, 49.41265052364719, 58.99703656473468, 62.016222169322354, 62.57253193086194, 61.43198120978571, 53.786803214780754, 62.506424303977724, 65.26385053511589, 59.83864776549801, 60.085215799270145, 50.38161716153545, 46.07249344548872, 48.32893886873799, 49.59898271868306, 47.19911583008305, 46.85619869539815, 49.659128342905355, 51.73097525873492, 54.6911213474889, 58.79396369380336, 64.57523530529392, 63.7386094370196, 69.98609004482147, 65.69298921092864, 70.20105161974507, 64.65427890900644, 69.24432277679443, 66.64860802312052, 72.55949435695526, 68.05390696371755, 68.02816052590647, 65.65904894182759, 76.11932769898446, 76.5937069923647, 76.35751755006852, 0.11821063791191387, 0.18406616824288524, 0.5497624677035117, 23.881482193546912, 82.67852690912063, 69.76954383234825, 48.36136510295253, 72.81989266795497, 97.04260733819778, 43.05904626846314, 65.2905854102104, 67.88111871288669, 13.48513218664354, 0.22954606571264807, 0.1776338642042491, 0.09601761466793476, 0.12122057438377412, 0.039390632281861, 0.10582397676884167, 0.21896018616614804, 0.1663225760022479, 0.17802689795292195, 0.2839752184527536, 0.15359027130949884, 0.1386924199159107, 0.11689702694815014, 0.23133437539781296, 2.133680384966635, 64.52194990650301, 67.56703099896832, 65.42920589447021, 41.151680023439475, 49.02495168870496, 59.373713539492705, 57.41632138529132, 81.82212445043749, 66.10253564773068, 3.2787180523718558, 0.4804598864528441, 1.7867082549679665, 0.878391020721005, 26.08733492512857, 92.9957332918721, 69.73447784300774, 75.00827712397422, 62.19112065530593, 68.10897704093688, 63.29894704203453, 61.21342282141409, 56.88812325077673, 60.0391750181875, 54.52632688706922, 55.00939423038114, 53.024325832243896, 54.83291502921812, 51.766272667915594, 50.06193222538118, 49.6583713254621, 49.92724587840419, 51.36617914322884, 53.23784789731426, 49.31846264869937, 50.190350624822806, 50.13755552230343, 55.32681203657582, 56.39358689708095, 60.112335066641535, 59.31468186839935, 64.01764685107817, 58.05354572111561, 56.0270570939587, 66.86960220336914, 63.22811688146284, 65.21358536135766, 59.7409297573951, 58.01971135600921, 53.503055034145234, 54.938968073937204, 68.16950705743605, 61.24222870795958, 59.61679458618165, 56.14030768794399, 55.16831298028269, 48.27109175343668, 46.919831306703635, 49.243929770685014, 48.26627508286507, 48.063025705276004, 49.32778220022879, 46.4920929170424, 46.8404935252282, 50.45904867110714, 48.86041218234647, 48.196382368764574, 51.762683699207926, 49.79075916351811, 49.59375812161354, 51.91870773992231, 54.7558561448128, 52.29083084291028, 55.85672424685571, 55.58951670123685, 58.648949746162664, 65.02189520866641, 62.81917056729717, 63.79653107735419, 44.66839867253458, 30.49384128662848, 40.2058514471977, 33.286398226215, 50.0676667305731, 63.803332467232984, 59.73259079840876, 65.45857660232052, 54.59339549464565, 59.08645483755297, 52.36910566206902, 53.34969820514802, 53.52092927502048, 53.9658554907768, 48.80388690579323, 47.89101408373925, 48.284788670078406, 47.857148339671475, 49.305479603429, 46.884357390865205, 47.27093050556798, 46.85040535465364, 49.097790102804865, 42.31386653838619, 46.597479158832186, 46.12757136744838, 48.57283969079295, 46.45204943995322, 49.811767378161036, 50.478974311582505, 58.356333086567545, 59.025940510534475, 57.066555792285556, 50.76669585320258, 49.977554198234316, 52.86000597861506, 64.99796090587493, 66.93832212878813, 67.92137792033535, 63.89919519424439, 55.6510155431686, 64.48223198613813, 67.69263313662621, 63.38407031951412, 60.66982546160298, 52.759977694480654, 48.26130151748658, 50.12514122070805, 52.12379278675203, 49.63740625689107, 49.69737537445561, 53.398755288893184, 55.004926650754875, 57.171122258709325, 61.72894385553176, 66.82912334319084, 67.46055433827063, 73.05293636937296, 68.99496201545962, 75.25919114389728, 69.988310106339, 74.67149457623883, 72.1010555759553, 76.79799187567927, 73.59538447472357, 72.11818064412763, 68.67421411698865, 82.38924426417198, 80.36346558601626, 81.69217632662865, 0.34284257900811016, 0.278677843030422, 0.639721782457444, 26.13052022072577, 93.64283807816045, 75.78023095284739, 60.074166482494725, 80.55089212233021, 113.60017914925854, 64.29344046500422, 74.85537528991699, 80.956677006137, 16.242153433061418, 0.26981720881116006, 0.3536426414164805, 0.20705505724876158, 0.16498428168556384, 0.16106100752949715, 0.2131612989450655], [0.01400453445967287, 0.07505744139874175, 0.015414932971790194, 0.060029431666818366, 0.06477891632746305, 0.09288910310715438, 0.06245205449240823, 0.033413189117826765, 0.7538902723500807, 43.402124220325106, 49.82295790026265, 36.27565222401773, 38.835410610322036, 56.9221027435795, 41.41160765001851, 45.90920125284503, 56.93565061015468, 65.78597291823357, 15.347060714998554, 0.4354438552212331, 0.437539320198759, 0.5691637976034996, 2.881606999904879, 73.97592498410133, 69.21132779890492, 68.1434311405305, 61.43050639860092, 53.730819225311286, 53.028056006277765, 48.03589467079409, 51.10133286445372, 48.90096164518788, 49.857643419696444, 49.41171699954618, 48.808562371038626, 47.158746796269575, 48.169871068769886, 46.72909821233442, 44.917198534934755, 45.46993893961753, 45.37587265814505, 44.853840489541334, 47.24545863366897, 46.77543317117999, 48.40020441239881, 49.11895913462485, 53.429777314586026, 54.842265959708925, 57.213303427542414, 55.83599452049502, 59.328465077184866, 56.876297304707194, 45.35551555695073, 61.69321498563213, 57.604771660220244, 54.220013310832364, 50.557382491327104, 48.148082302462676, 52.127950499134684, 56.10600656078708, 48.8801730832746, 53.7796135102549, 49.633350526132894, 51.17631289266771, 44.294212402835974, 39.67236595769083, 41.131805373776345, 40.04617175748272, 39.94540214538574, 41.61171913146973, 42.15707763548821, 41.13370772330992, 43.08989963223858, 44.69637693897371, 43.01255441481068, 45.24282193952992, 47.164861771368216, 45.19627125032487, 45.83653150066253, 45.48684043269004, 45.655176793375325, 44.295279287522845, 50.90089974864837, 52.36404580454673, 55.61023466048702, 57.187894313566154, 59.665259392030784, 42.73664312977945, 31.06987664776464, 37.962263553373276, 34.35626391441592, 48.88222056050455, 59.90437492247551, 53.62875523105745, 56.83503004812426, 54.16164452029813, 49.195665005714666, 48.77003292883597, 49.416290483167096, 45.59643145530455, 43.212509001455004, 44.59048471143169, 43.191241910380704, 44.67473722273304, 43.44055952564363, 43.85699756683842, 43.31586345549553, 38.62648556309362, 37.36551023298694, 41.871956625292384, 37.0799381502213, 39.19116174021075, 43.50586306664252, 41.265460137398016, 43.920394835933564, 51.35173697625437, 49.74112549135762, 53.75796987164406, 53.47818720725275, 54.18982282761605, 47.74868695966659, 46.67625211900281, 48.355430556881814, 51.96746672353437, 57.78599692929176, 56.502279696925996, 59.741471044478885, 57.55630685437111, 52.27065024837371, 61.482975944395996, 61.834796859372055, 56.732475757598884, 57.72922454341766, 46.82228980525848, 44.149072939349765, 48.04644192418745, 46.13640846744661, 43.51017767383207, 45.42373734135782, 45.651470153562485, 48.71905780607655, 46.014077586512414, 55.326996387973914, 57.5438258724828, 62.348890150746996, 59.58807106940978, 61.36774063110352, 60.60958177812638, 60.81112100232033, 58.34737831546415, 58.675778758141306, 61.47528025411791, 59.025140347019324, 65.14902314832135, 69.6961013732418, 80.43965370424333, 49.93917772846837, 0.16043647733186522, 0.30594698784332125, 0.35330942381293545, 36.28514043746456, 72.04369483455535, 62.981505701618815, 50.80316605106477, 52.01988920088738, 65.65265547844672, 46.75569972684307, 51.16755031770276, 65.4891554001839, 14.611335858221977, 0.16251136518774495, 0.07005839593588345, 0.023845599385939782, 0.04341597999295881, 0.06468956749285422, 0.05326065798139861, 0.006993884791529948, 0.058271095171690955, 0.06200660117751649, 0.07210781136828084, 0.04485182411548111, 0.06383940141888396, 0.016772654320624088, 0.032694610136170546, 1.0116917291475882, 53.446188511387, 55.06092240733486, 47.339721033650065, 27.749670705487652, 56.5182751224887, 51.02331299935618, 50.83326239739695, 63.961341227254565, 72.85429969910653, 17.1117046571547, 0.5944801230103739, 0.64556494956055, 0.6810771697951902, 3.175453812845292, 76.59829616546631, 72.22763046141594, 70.69436811631726, 62.78343777502737, 56.08207225799561, 55.55700417487852, 51.35527103177963, 51.0461647279801, 52.88758416329661, 52.42622713888846, 51.21417553194108, 51.95955530289681, 49.033286725321126, 49.87176395231678, 50.86392748740412, 48.30305122560071, 46.936866160362, 48.93770640896213, 48.48992863009053, 49.611310728134654, 49.73930551159767, 49.784903064850845, 51.84023680225496, 55.72576022917225, 57.966288674262266, 59.61392341121551, 59.37934998543032, 56.6765937497539, 58.482825602254565, 50.387230073252034, 62.66156581140334, 60.43836639773462, 55.35800272418607, 55.68249256380143, 51.056747282705004, 55.69869587498327, 58.17759460018527, 52.7868341630505, 58.217504716688595, 52.64026695682157, 53.63869843944427, 47.9938978533591, 40.693033356820386, 42.74478989262735, 42.58274893606863, 43.54441996543638, 44.37875909190024, 44.431114888960316, 43.6471664521002, 45.61344669711205, 46.31572354224421, 47.037871114669315, 45.42355691232989, 48.89334832468341, 49.16636882289764, 47.21523677149127, 47.19617797482399, 48.44195804288311, 47.69557414516326, 53.433091717381636, 52.98831455169186, 57.37496391419442, 59.31134785375288, 62.13275578714187, 42.76888109022572, 32.54495847609736, 38.896301484877064, 33.58678902349165, 51.010212282980646, 62.856833165691754, 57.40833543962049, 59.00555203037878, 54.509950991599794, 51.18928024845739, 51.146887271634995, 51.317361324064194, 48.76576539008848, 44.731195818993356, 47.71953590454594, 46.06463693803357, 44.071982675983065, 46.04439750794442, 46.341736701227006, 45.3297612743993, 41.7758350218496, 40.51751121397942, 43.01246812266689, 42.38347684183429, 42.53677483527891, 46.29649608365951, 43.51484137196695, 43.892561697190814, 52.7472339137908, 52.31684792426325, 56.1578328378739, 57.216347186796135, 58.19446079192623, 51.17913307682161, 49.70304712172478, 50.85576503507553, 54.875339385001894, 60.43163168814875, 57.579507673940356, 62.152477464368275, 60.698576434966064, 50.80296993255616, 58.90498245916059, 66.09975860964867, 60.42399875579342, 60.233548072076616, 50.22964885157924, 48.03485524269843, 48.31654810136365, 49.2241806368674, 46.31435855742424, 48.4075157104, 50.14046199860112, 49.79905105406239, 50.16804018328267, 57.85042185937205, 58.95164297473047, 63.28171999223771, 63.05744671052503, 63.325944715930575, 62.161039998454434, 62.5266598116967, 60.411380490949085, 60.640741086775265, 64.66628136173372, 62.73137223336005, 69.09022069746449, 73.47519520790347, 85.3645424689016, 53.62025937726421, 0.3671928675424668, 0.45221471498089455, 0.3285583487201122, 42.71172038970455, 79.81522806229131, 68.75164170419016, 52.48694935152608, 66.86162410243865, 80.07626179725894, 56.939569057956824, 61.49862620138354, 75.26470599635955, 20.62776238687577, 0.20414617543499317, 0.13461055023775947, 0.0387721924832271, 0.04649345094578401, 0.01964385801505658, 0.05219601027126755, 0.1812647225996179, 0.19840419322492617, 0.1311184763307533, 0.2284880063586658, 0.15719848414582593, 0.13539326226999684, 0.1481991420469938, 0.11630816580427271, 1.5194776654243471, 64.33362906978977, 67.10515622169741, 51.868124854180124, 52.00123833071802, 74.18930976621567, 62.05628918063257, 61.92907102646367, 68.90004850202992, 80.96132109242102, 19.96335602575733, 0.5964702968635868, 0.946986165738875, 1.0838593566609969, 4.011062316356167, 83.0244093556558, 76.77550100511121, 76.47194093273532, 67.63761012784897, 58.76364769474153, 58.3761332111974, 53.55852519312213, 53.636690185916045, 55.88369054179038, 55.60439032893027, 54.73498521312591, 53.11688984594038, 52.15250845878355, 53.43151884694254, 52.87151813507081, 49.818062782287605, 52.09028397836993, 52.17122600924585, 50.057747056407315, 52.58113330410373, 54.22850524225543, 53.329439163208015, 56.178609632676654, 59.238038755232296, 60.74379744068269, 59.31059868104997, 62.88112048179873, 57.85721148214033, 54.47002518561579, 55.81285645884853, 64.0432010927508, 65.6769427945537, 56.1558206619755, 55.53572923906388, 53.55112760297714, 57.94781431075066, 63.73449487070884, 57.699916593490116, 62.976069296559984, 56.214656214560236, 58.48506919799313, 49.455208240016816, 43.07987797644831, 45.82208541131789, 43.165597454194106, 42.607008795584406, 45.69790709403254, 46.94772328099897, 44.14223232576924, 48.23541779671946, 50.42185283476307, 50.269115740253085, 48.61679377094392, 52.21174409312587, 51.385065355608546, 50.71707787052278, 50.257066219083725, 50.167636179154925, 50.714802895822835, 55.98430325908046, 57.31453587931972, 61.67392084675451, 62.38420324940836, 65.34531031885456, 44.441760201607984, 32.42196863697421, 39.812822111191295, 33.33225465589954, 50.6375478929089, 65.25679026880573, 59.398997137623454, 63.55521901961296, 55.90502431315761, 56.38226693676364, 55.26367364391204, 55.395524117254446, 50.05118100873886, 48.42912404767929, 50.644129630058046, 48.31401425023233, 49.14657262063796, 50.588832055368734, 50.1910880304152, 48.35281825834706, 43.91962212900962, 41.950831567087484, 47.1750363995952, 45.06427564928609, 44.59255964525285, 47.49576076384514, 46.050728213402536, 46.255287662629165, 54.161907319099676, 55.76659210266606, 59.02032367644772, 61.976994545229026, 60.11125641484415, 53.55643849219046, 52.58617747214533, 54.134113404058645, 58.21789303133565, 62.507506878145286, 59.928583791179044, 65.17147871755785, 61.242958268811634, 54.36360736047068, 65.80767539239699, 66.21003212467318, 62.7769737089834, 63.132136483346265, 53.63618027779364, 49.23375514245803, 53.81249866177959, 53.48285875012798, 49.49258058301864, 50.235920721484774, 52.54029750823975, 52.849752902984626, 51.96450925642445, 60.97443672918505, 63.277503444302475, 66.17366390843546, 65.32348232884561, 67.34227134335426, 66.91266982786118, 65.8650988917197, 64.21480478778963, 65.44847257675664, 68.32087916712608, 65.07076009627312, 72.38428992609825, 76.89775343864196, 86.41709481516193, 58.82051421749977, 0.337649054464794, 0.660401682459539, 0.5217978682729506, 45.76161815274147, 88.79185461228894, 75.76908357681768, 67.00261762065273, 70.64530711020194, 78.44915282341742, 64.05356791711623, 68.47751509758734, 89.53497117565524, 26.64772002927719, 0.5140785211997648, 0.274488200103083, 0.1583744903966304, 0.11793374309256194, 0.18711282330895626, 0.18142604539471288], [0.10336229111999275, 0.04771826848868401, 0.01123271152121766, 0.06016755348912651, 0.14763844229521292, 0.10907865534987181, 0.03919885366133625, 0.053661773957672625, 0.9663911728608994, 47.75582175101004, 48.90265218673214, 49.18164253234864, 46.66827401807232, 98.16941015182003, 46.67654237439556, 38.28355273892803, 58.44664565978512, 63.841959968689956, 34.33861324864049, 0.10640733740142277, 0.1557359150460651, 0.11666068116263037, 0.16985615655299158, 40.46571631585398, 88.0931471240136, 62.37817456645351, 68.5893654054211, 58.08545812483757, 61.16985705591018, 51.337396790904386, 55.55072838260282, 46.77013404907719, 54.08197333735805, 47.886707321290054, 51.53449589206327, 48.12955302576865, 51.22995130477413, 45.6993426815156, 47.66610537805865, 43.10760128882624, 48.53359637721893, 44.2138312708947, 46.90975473773095, 44.47422958189442, 48.911646181537265, 49.602359879401426, 57.36595815227878, 52.51411568733954, 61.65837649376162, 55.130152240876235, 68.88077397500315, 44.16253843615132, 45.908224582672126, 62.317726919727946, 56.956235208818995, 57.36160432138751, 52.24614327953708, 52.19359920870874, 54.873303674882465, 52.48517644020819, 48.28931900762743, 54.2617198728746, 51.54955387115479, 49.76167871106056, 46.70690151952928, 41.30433474817584, 40.598869016093595, 42.98100286914457, 39.81845463475874, 39.320890211289935, 39.641602808429354, 42.268935788062315, 41.30376992687103, 40.175806091677764, 42.80404121645036, 43.886999776286466, 43.17021408388692, 44.243849169823434, 45.325619251497336, 45.835492072566865, 45.047362389103064, 43.4270744169912, 47.48897114107686, 51.00016317059917, 54.631858256555375, 56.032528800349084, 59.063701168183364, 44.57252025604249, 33.62301211203299, 35.22502576151202, 35.53838391457835, 50.33166969976118, 59.79483096830307, 55.26134375602969, 57.0175418546123, 52.97872827899072, 49.515000850923606, 47.297684992513354, 47.4857783317566, 46.59521202887259, 45.16259378002536, 43.44177153802688, 43.11048815327306, 43.58358483160696, 43.845940405322665, 42.97759040709465, 42.53619040212324, 39.76207840827204, 40.36322478325137, 40.78576603243428, 39.75795207485076, 40.198238126693234, 40.56302639745897, 39.9358590187565, 45.834833114377915, 50.58944786748579, 46.6773307708002, 55.06540567644181, 52.771705581295876, 56.02726890194801, 50.55948880410964, 47.52023243135022, 50.09034979727961, 49.42377436545588, 53.596917352368756, 61.909941627133286, 54.79504062283424, 61.9520757275243, 40.09162810540969, 36.45058601133285, 69.92317522725752, 59.37042267091813, 59.405233706197436, 52.402841967921105, 47.342874619268606, 44.88788666263704, 45.23504387947821, 44.731427238833525, 47.5933297218815, 45.8347507446043, 49.391830582772535, 46.619444431797156, 48.12982366931055, 53.4397558243044, 57.865577897717884, 53.58448736129269, 55.68770147139027, 55.259817954032656, 56.46912782422958, 54.26719550163516, 56.514278227283114, 56.44762146857477, 57.7520723496714, 71.61565442239085, 70.0222150741085, 88.7536350373299, 22.786805552821008, 0.7459605881764043, 0.41949240310538205, 0.062476492697192784, 55.427652251335886, 62.75405137769638, 63.97124128956949, 46.37754401853008, 44.51320617429672, 22.642115200719527, 31.909863987276633, 47.50575104067403, 62.24456687127391, 18.326431320559596, 0.213959792388543, 0.17621175986864876, 0.03866289471907001, 0.12841189535514963, 0.030599359663263447, 0.11471998892844686, 0.0493958669774715, 0.037131009983920285, 0.0701808933949759, 0.15541749826121717, 0.11964097769270021, 0.061817335325383374, 0.07042960383959355, 0.024543147338854692, 1.5876121770951057, 58.092459555595156, 54.949538861551595, 50.747017322048066, 38.06353130648213, 103.81402246413693, 55.43803868755218, 46.70968640235163, 64.23785263492216, 72.82860032973751, 38.34930343012656, 0.1223818334420362, 0.12330695355851805, 0.325987296359193, 0.213486043616168, 43.99062879623906, 88.05195439246394, 62.181608907638065, 68.26164353278376, 61.1309471438008, 62.60459338465045, 52.94496451654742, 59.011019814398985, 50.97538163585048, 54.751945541751006, 51.96825119756883, 54.57761972181259, 49.68536115461781, 53.87864158999536, 51.563282166757894, 49.32489141341179, 46.9253187025747, 50.78895530393047, 47.46221273176132, 49.334277645234145, 47.7685929882911, 50.025297287971746, 51.60509463279478, 59.62476484237179, 55.77746491278372, 63.58492705129809, 54.81175384213848, 63.429130508053696, 50.399314895752944, 51.416856165855165, 64.4805649788149, 57.4865710350775, 58.889179229736335, 53.360947562802224, 54.97715626993487, 56.692593097686775, 55.227246592121745, 54.56628014964443, 57.78092922702913, 55.17191371610088, 50.633237208089525, 50.09600977743826, 44.697322230185236, 41.93792304685039, 44.910016675149244, 41.20836611716978, 41.2864879638918, 42.9508476872598, 43.838915440344046, 46.02193017159739, 41.820644178698146, 44.26682249192269, 45.737734840762236, 47.416881899679865, 46.24752921442832, 48.78731489181519, 47.46545260952365, 49.59034173719345, 45.57811006422966, 49.49463982735911, 53.671940526654645, 57.895030975341804, 59.89900912007978, 58.8262055766198, 46.845149378622736, 33.901621987742764, 36.11749049155943, 34.87820194613549, 50.52700765671269, 60.22267918432913, 58.299517554621545, 57.17986129945325, 55.7912677334201, 51.41765632937032, 48.9392832017714, 48.37031987405593, 47.67089459203905, 44.92216817794308, 46.682735796897646, 44.11210460047568, 44.84730974320443, 47.396183552280554, 44.6206202814656, 45.35836319769583, 41.220105771095525, 42.07786536985829, 41.388187177719615, 41.20649122422741, 40.706118383715236, 42.135351627103745, 40.84702953215569, 48.41064576179751, 52.787822600333925, 49.97566361581126, 59.28358531767323, 53.91566876442202, 58.75310828608852, 54.89762629232099, 50.10398787836875, 52.15938437369562, 52.29026209923529, 56.78763997170233, 63.165668825949396, 59.26427941168509, 61.891278989853404, 48.93350162813741, 44.749721173317205, 65.52859483226653, 63.89303315070368, 62.51198622488207, 57.98934828850531, 49.19048355471704, 48.69934397359049, 46.53830236004245, 47.56288036223381, 49.24559285563808, 48.22338788740097, 52.220028138929806, 49.28756221648186, 49.51242777609056, 57.094585049536924, 57.86484049212549, 57.14713696510562, 58.971152843967566, 56.21948857461253, 57.927963195308564, 58.94412379111014, 59.21144508546399, 58.29415175222582, 61.369254665990034, 75.71868112010341, 70.65010809129285, 93.86875091060516, 23.900503727697558, 0.994929051206958, 0.23474450854043807, 0.1876596109040322, 64.06302475160169, 72.48620094791536, 68.7383762482674, 50.79402692856328, 60.94446589869838, 28.83070338156916, 42.46008465366979, 55.909774303436286, 72.6866340637207, 24.236064457124282, 0.11546670248912227, 0.07435982641313346, 0.024840749514799927, 0.032768016681075096, 0.04336827569791386, 0.1414339574834993, 0.20846551704791286, 0.13395436528709628, 0.09629317649429846, 0.20983739665919737, 0.2883482628291653, 0.1287393902819003, 0.18353347666561606, 0.2311447992800705, 2.5651175697003645, 70.7685479810161, 64.89489670722716, 70.17554052414434, 60.34104062664894, 110.57691820206182, 63.499533130276596, 57.93743571927471, 69.09142094273722, 82.26659174888366, 41.258258665761645, 0.25913114028592266, 0.21998075317711602, 0.5229156824850267, 0.44691681861877447, 49.743310251543605, 92.0362195660991, 71.50981318566107, 72.61640794815557, 65.75215032023769, 67.36882578942084, 53.95085634723787, 61.888709837390536, 52.28173094411051, 59.305785932848536, 53.59394027340797, 57.315559617934696, 54.615615721671816, 57.85366173713439, 52.83474199233517, 52.19299124133203, 47.91484248253607, 53.76708153755435, 50.53996324539185, 53.088531109594534, 50.872984240132, 54.56344427600984, 54.20763823293871, 65.57886000602477, 59.01056874182917, 65.2330050160808, 58.36653909375591, 59.04459922544418, 55.6998255175929, 55.05854545101043, 65.83545361795734, 62.451024747663936, 61.200867314492505, 58.14488203294816, 57.19382885963687, 61.086373329162605, 61.75687505352882, 59.87198006722235, 61.77006990678849, 62.02711459129088, 55.17333753647343, 53.30210416547714, 47.350201606750495, 44.83320490006478, 48.747898993953584, 43.10649518043765, 41.48312030300018, 44.772827856002316, 45.20524563327913, 49.282937742048695, 44.136878290484034, 47.05217599868775, 47.11414552504017, 49.874670428614465, 48.27478270376883, 51.83343933474634, 50.64669486015074, 51.57391178992487, 47.16182193448467, 50.754807149210286, 57.19662158719955, 60.31182289123536, 60.73613705173616, 64.53678038812453, 47.885495308906805, 34.31229806715442, 34.714976433784734, 35.09748205061882, 53.14427191211332, 64.38004247603878, 62.73625558422458, 61.30557498624248, 59.10209724980017, 55.93975690103347, 52.036065055478005, 52.63740754896595, 51.70938653330649, 49.90167202488069, 49.51749155598302, 47.28301532806889, 49.360396708211596, 51.33808320568454, 48.22851442521619, 48.31881523132325, 43.661510559820364, 45.01897619616601, 44.93256245889972, 44.4934021272967, 42.98847498432283, 43.511644640276515, 42.18596981417748, 50.53816679985293, 57.01485895341443, 53.24296659038913, 63.40308204773934, 58.76058040126678, 63.87672001315702, 58.23744996901482, 52.55982698932771, 53.255792740852606, 55.00113371879824, 57.93212090769122, 66.93410165848272, 60.50695688493791, 67.91004227053735, 49.55412649339246, 43.940304786928245, 69.41733068035495, 63.75618557776175, 65.14444181996008, 59.693837781106275, 52.884932641060125, 51.03508010987313, 50.97387152333414, 50.72375374455606, 52.56431418080484, 51.62147445063437, 55.14929340731714, 53.8492787268854, 52.21865530936949, 59.85825177161925, 64.8268396623673, 57.568062197777536, 62.32201407032629, 61.113241564842966, 62.963874647694254, 62.03968186532298, 63.25593825309508, 62.92450974064489, 65.01663531026533, 79.66642902743432, 75.42942985411614, 97.81195671327653, 29.724148704159646, 1.110585406422615, 0.6800120624323046, 0.3469059706455277, 69.02680381651848, 76.95674588603359, 80.25272923131143, 61.82106464139877, 64.67152949302428, 32.09631581460276, 46.9159403154927, 63.851624688794544, 88.87409102532172, 32.22862324407024, 0.26993638144866117, 0.321901933320107, 0.17408441031171432, 0.21470508868655852, 0.1540381263100332, 0.2618038371926354], [0.030870447536149336, 0.026138851028536598, 0.047006745176810416, 0.018518507413025347, 0.049384842972241105, 0.03296532645641315, 0.07343526554083632, 0.0073661867645569154, 2.3422573218422555, 53.03017408617082, 55.21878603966006, 48.800843146539506, 31.83444073123317, 73.6035273152013, 36.66609671808059, 33.94279510744157, 59.31559970301967, 69.9674980102047, 46.50378550252607, 0.3588503539081543, 0.007985406536458722, 0.3494560015538047, 0.309978203787919, 4.265495192620063, 80.01725366038661, 68.44913282702046, 72.00493397251253, 64.45486953181606, 65.07042669480848, 56.69446799062914, 59.35842806293119, 57.08519097297423, 60.255403518676765, 57.918067055363814, 57.39625453948975, 51.20748789079728, 51.623808260886904, 50.60880476428617, 50.70273376280262, 46.51619588175128, 44.51738742090041, 44.480768172971665, 44.19525884812878, 45.37005186080933, 50.16705959073959, 54.36542341786047, 55.61334510003367, 58.76659339474094, 57.50997189552554, 60.7606989337552, 60.8240609015188, 33.97858281289378, 58.32846464649324, 60.34389218976421, 60.74317378382529, 54.08513084534676, 53.418065117251494, 53.31425959064115, 56.332625419862815, 50.4294426210465, 47.389374317661414, 50.394411933037546, 47.8419138539222, 47.29368417493759, 46.45147677390806, 46.52589982555759, 40.90448441043977, 42.546361107980054, 42.62620487520772, 40.30909999724358, 44.622122549241595, 40.39645510335123, 41.03779008311611, 40.73813669143185, 42.796541644680886, 44.3578097128099, 46.20088438833914, 44.63812189717447, 44.79272603988648, 45.600910802041334, 45.97614434457595, 45.996783856422674, 46.535101705981845, 51.90382234511837, 55.61792250602476, 53.20795159186087, 58.80031401111234, 46.44108249295143, 37.58367246197116, 36.74085709356493, 38.855308794206195, 54.2002720217551, 58.151773637340916, 56.11962895239554, 54.01702673204484, 54.123311196604085, 48.63135753139373, 45.151120847271336, 46.72516407505159, 46.64455936801049, 43.72169148537421, 47.348138440039854, 42.65476365243235, 41.84675539693525, 42.91534631483017, 40.72536937652096, 41.45077643855926, 39.16184202317269, 41.61188779338714, 37.23453837056314, 40.82240881458406, 40.20088572655955, 41.509674749066754, 42.15952127210556, 49.52479893161405, 47.166058094270774, 50.378169398153986, 51.458429367311545, 48.77648522776943, 52.033425300352036, 60.1540102497224, 48.25455896316036, 51.96422684577204, 47.59316105996409, 52.290430761152706, 58.770107838415335, 60.20672298246815, 58.9256808065599, 63.718679874174065, 43.3300075223369, 36.93718741017003, 60.67894104988345, 58.24420821282172, 59.34722577371905, 53.62862579284176, 44.26518294119066, 41.681372580989716, 43.31238823552286, 45.06251450507872, 45.50073739021055, 45.93578315550282, 47.054219553547526, 47.13069400479717, 50.95491863066151, 49.02625783797234, 53.14551922582811, 52.08283931978288, 52.552613750580825, 51.97805712299963, 52.65223018584713, 51.625553715613584, 58.99103926074121, 65.76149732835832, 75.67311886818179, 71.659271178707, 81.71843267256214, 4.859889207347747, 0.3900336870743383, 0.01942427614853988, 1.1822998163200196, 66.7315112390826, 62.19857315863333, 67.15891622727918, 38.65362836468605, 50.35411350188717, 44.45349593316355, 38.35876810935236, 55.81325261823593, 61.33706377398584, 36.475469527706025, 0.12410136375335917, 0.028023837179306055, 0.06431812210188759, 0.021984132134445736, 0.010869624149504929, 0.08183336651493466, 0.06066802340830046, 0.016281519182807496, 0.00804900428310277, 0.03621451601746582, 0.09607117953560046, 0.06711841095238924, 0.06986495107412338, 0.05683385293870684, 3.1406731759348228, 63.22019761608493, 65.30731039662516, 50.66790703804263, 45.43739503429782, 89.53897983797135, 42.66250248878233, 42.2297199310795, 66.07393372443416, 75.39475610179286, 52.9199319501077, 0.5399197087653222, 0.22755272025542878, 0.16206628342549648, 0.5876756687798809, 4.968352548537716, 84.0288342199018, 70.01053425573534, 76.40442909732943, 65.08904618601646, 67.42443715372394, 60.975786024524325, 62.267987343572806, 61.26470388904695, 62.06822887543709, 61.34462218130789, 60.168919178747366, 56.00285606999552, 55.29752369849913, 52.94053223825271, 55.58633173665693, 49.45302347983084, 48.9738118263983, 47.105331959262976, 46.70648967066119, 46.3340449333191, 52.84842714186638, 55.25586812726913, 59.964147921531435, 61.783453033816436, 59.35131680580878, 59.44659902203468, 62.96105838591053, 38.77247225853705, 58.609690743107954, 60.29871825248965, 62.126499606717026, 56.93006907739947, 53.66066371240924, 54.27703280602732, 58.92128382959674, 56.087810685557706, 52.435860480031664, 53.1955647468567, 50.7257463086036, 49.25854059957689, 47.81179789573916, 47.94194998279695, 43.569605504312825, 43.085463431573686, 42.418409470588934, 42.53895175072455, 45.3304555339198, 42.682337914743734, 44.94199183679397, 43.80054681531845, 44.40510172997752, 47.23552327002249, 47.08890507298131, 47.3926063506834, 46.05861217744889, 46.38243129176479, 50.59474306721842, 48.2226897055103, 48.83974913627871, 54.522286845791726, 56.708568911398615, 53.85105948294363, 59.105988241011104, 48.931579666752974, 38.3804117479632, 39.118950905338416, 37.59188982748216, 54.23665592747351, 61.17819993726669, 58.39405452051471, 56.72254039395241, 55.30360337226622, 52.3593036590084, 48.206274586339156, 50.20297673440749, 46.23328316596247, 46.9693826090905, 47.459117981695364, 43.53387271204303, 45.87691230158652, 44.31013722573557, 42.01568403551656, 43.87294592395906, 40.81754899794056, 43.34212764616936, 40.851222545869895, 41.88946216337143, 41.52057109340545, 45.53871377821892, 43.43351494881415, 53.43145608901978, 49.38048316586403, 52.11092741258683, 53.883646534335234, 54.94689518405546, 56.3954068768409, 63.17630629385672, 50.33991844423356, 56.64142185641874, 51.23822750583772, 56.18425784572479, 60.54052452887259, 63.177706580008234, 61.207194097580455, 71.81116888600012, 46.19948017981745, 37.820046255665446, 65.0218520625945, 62.18291505690544, 63.8687889806686, 55.461882775829686, 48.795069417645855, 46.18080969779722, 47.4466448445474, 47.77629260093936, 48.88222056050455, 48.68384668903966, 50.321263651694025, 48.841318084347634, 55.18209618906821, 53.11040616804554, 55.565409814157796, 55.255432744180005, 53.89105196922056, 55.1741494670991, 55.02335394582441, 54.04392242431641, 63.31299697199176, 68.15269577887751, 77.05325188175325, 74.18036676222279, 86.90186054475846, 3.988170138289852, 0.2226483019729776, 0.14569201206247653, 1.5180017510729453, 73.77913967255624, 70.43511513740786, 74.08244871324109, 44.24899139711934, 60.617544189576186, 43.01934403757895, 46.237742900848396, 61.67808248150734, 73.94574626799553, 44.14770403215962, 0.07049091385617372, 0.058161870185886665, 0.01720998135785903, 0.053154144946846275, 0.012354518966599098, 0.06420853322431927, 0.09553666466907149, 0.2105391944848722, 0.1107144445901917, 0.12467478822556236, 0.2477108684158133, 0.17985391040002147, 0.12267964246172099, 0.12922046285483146, 4.4911162987832105, 77.69794048801546, 74.71296187370055, 66.43034381251182, 41.32944968438918, 88.27660422171317, 54.01703065441501, 51.99508805428782, 72.7792412234891, 85.50341006248229, 59.160191474422334, 1.062812898908892, 0.25590807049264835, 0.8636241550407103, 0.6650477299286474, 6.678558895664831, 89.13841170649376, 74.58984651873189, 79.9732054433515, 69.20972747187461, 71.29771494096326, 63.12315817802184, 65.32326659848614, 64.79259737076299, 65.43090035838466, 64.13977376876339, 63.67265870494228, 59.18263527654833, 57.325867606747536, 55.84389417402206, 57.90830427600492, 52.76768907423943, 52.020838414469075, 48.84315375358828, 50.019794202619984, 50.60720051488569, 57.309393652023815, 59.00845850667646, 64.0094098737163, 63.50510681829145, 62.26284119390673, 59.054664027306345, 65.20658393060008, 48.77884649461316, 60.966784184978856, 62.18315824385613, 64.20952919990786, 58.88371144571612, 57.54172348207044, 58.77967449926562, 61.46640393041796, 64.42098809826759, 57.583002505763886, 56.53343116083453, 55.1909960469892, 55.51434447688442, 53.31741317625969, 51.64549504556964, 45.63359983505742, 47.68710182559106, 43.594920481404955, 45.35413488265007, 48.45383497976488, 45.620914889920144, 46.39867382664835, 47.60219035610076, 45.94052922341132, 50.61548848305979, 50.376620061935924, 49.875329386803415, 50.0836778456165, 51.816027933551425, 53.379268953877116, 49.64947931228146, 52.95815936980709, 58.422907475502264, 59.59985779177759, 59.68447508350496, 63.14139327695293, 50.36607673091274, 38.44071426699239, 38.003534732326386, 39.9499285605646, 56.44471499227709, 62.48689482288977, 60.61628903112104, 59.854792241127264, 58.93512195156467, 54.412338887491536, 48.94101688938756, 52.0864204437502, 52.92292079617901, 50.438911222642474, 52.56642049358737, 46.63270596534976, 48.38840200055031, 48.94643760496571, 45.17965609027494, 48.362271170462336, 44.04587145774595, 44.75905249195714, 42.01400918345298, 45.30848633858466, 45.65142308512042, 45.65425111401466, 45.3894519036816, 57.18375229066419, 52.71361527904388, 55.23680540823168, 58.91931872214041, 58.257599184590006, 60.38110763795915, 67.31828997212072, 54.96102356141614, 57.83493634193175, 53.66681398883943, 57.117385787348596, 65.15130204539146, 64.4560266310169, 65.03114023516255, 64.9007998743365, 40.963151301107104, 41.11815552557669, 64.43022920239356, 65.59130176421135, 66.49093658693376, 59.02712898869669, 49.6347665017651, 48.45855751345235, 49.1904325639048, 51.96351689677085, 52.29842455156388, 51.18578933900403, 52.04744777371807, 51.997390485578975, 59.469791996863584, 56.14262580871583, 59.62570621121315, 58.97841707352669, 56.166571878617816, 58.27347301667737, 58.29730926021453, 58.44371957163657, 65.54655536528557, 71.76293942236131, 81.61575286619126, 75.88227533525037, 90.73860537621283, 6.645462916743371, 0.7423010168056334, 0.2711079137459878, 1.8658071395850953, 82.31799048762169, 75.66219114488172, 85.83529749224263, 51.305500076663115, 68.50559926802113, 58.88030682840655, 56.46031818082256, 74.98091466965215, 85.5265598912393, 52.43477398349393, 0.30859281038565023, 0.15689189575852888, 0.17275066655730048, 0.1752080008267395, 0.1025273931783534, 0.15984672752599563], [0.01852493872114968, 0.11175335174606693, 0.01925610069696221, 0.060392775677985726, 0.04549978511227716, 0.07244682059653344, 0.05722274598214896, 0.06841024203646569, 1.2423677285832744, 47.2251368338062, 61.64029044489707, 54.530755242993756, 24.402351379394535, 28.613647260973533, 37.2430303019862, 30.790237149884625, 64.01270466466104, 60.11446099127493, 60.361342814660844, 1.7224934168400305, 0.18194206689874973, 0.1618643886139316, 0.2768641145479295, 0.5127768458858614, 30.777461990233395, 76.4895131511073, 48.32958605981643, 69.60380800308721, 64.50351476669312, 62.237110445576334, 64.64122133870279, 66.06663811591365, 62.10485204573601, 63.005628278178555, 55.930743294377486, 53.688041856212, 54.23907210749965, 53.81795860105946, 49.99377319889684, 47.529967754117905, 43.20754328081685, 45.64755562813052, 43.5152728326859, 51.120552478298066, 49.00962698844172, 56.88603262747488, 57.66447405661307, 59.565293865819136, 59.13298983727733, 64.21947240829468, 38.26925962202011, 45.39308794083134, 59.81922811077487, 58.59517012873004, 56.179088161837676, 55.31808476294241, 53.077419034896366, 53.73913465007659, 54.58684513645788, 50.803479840678555, 49.35749415428408, 48.750660342554895, 44.57002170624272, 45.2321413255507, 45.192964692269605, 46.419521224114206, 42.0447370313829, 38.79741461046281, 40.93471019498764, 39.99196852407148, 42.97221675995858, 41.49654265372984, 42.52004984886416, 44.545326463637814, 42.70459344310146, 43.68499379004202, 44.39642936952653, 45.29114946242302, 44.97788152387066, 44.780139154003514, 44.091614138695505, 43.29074459691202, 45.019340976592034, 49.7196073685923, 50.347739650357155, 51.62771494157853, 59.135515843668294, 49.107239092549975, 38.60617553034137, 39.54437117422781, 40.78782919914492, 56.08132700766287, 55.194051573353434, 57.15060041796777, 51.24371097933862, 51.300867757489605, 49.4923883868802, 45.453876833761896, 44.81313805426321, 44.73448668756793, 43.571798109239154, 46.481329933289565, 42.17368887316796, 41.57233069019933, 41.500578772637155, 40.721348947094334, 43.02083061587426, 40.013518025798184, 39.522751069838, 37.8908371925354, 41.29207341901718, 38.92182434758833, 42.326896652098625, 45.11384656352382, 44.237161528679636, 45.39357431473271, 49.196355342865, 52.501662162042436, 49.93001899411602, 50.33487819856214, 55.63466710429038, 52.66096530422088, 50.43562427643807, 51.409387973047075, 49.890873739796305, 57.062048988957564, 55.376967383969216, 60.07049906638361, 59.297015513143236, 48.24388227155132, 42.378224788173554, 52.7772988811616, 60.51447606855824, 62.12183590858214, 58.81779209260018, 49.55068265238116, 43.468820202735166, 46.26175565104331, 46.395790884571696, 49.848621968300115, 47.63527947087442, 49.07234176512688, 47.33060152299943, 48.30973886674451, 51.02554090561406, 50.30912783838088, 51.966333158554576, 49.539892212037124, 50.799075018975046, 52.70438201965825, 53.27446322287283, 64.34944014395437, 71.96391382525044, 70.45741773420765, 83.78130128306728, 54.624335150564875, 0.3713180977971323, 0.3465445303628522, 0.6684003145464006, 8.354853410874645, 73.20976841834285, 63.03579914954401, 65.44238898061937, 33.719541641973684, 48.75619480686803, 44.333130159685695, 42.848313008585286, 50.700144998488895, 61.26685727027155, 40.767377961066465, 0.43389412063744764, 0.028865131955113144, 0.026890706954403754, 0.028435672640860565, 0.045643093349832686, 0.009449110403957387, 0.04918559882489424, 0.06592348999073429, 0.08544707986255808, 0.02645020831316229, 0.026755164933180618, 0.14898197665329904, 0.056898844007763176, 0.06099384060249694, 2.342212950029681, 58.99164330574774, 70.8648500134868, 61.098583667509025, 31.708001167543475, 38.82831112031014, 42.72994372152513, 38.78653787797497, 72.27612664622646, 66.37227704448085, 65.84381611116471, 2.1618567310994674, 0.2200075968979828, 0.2726488229968856, 0.10140566425698419, 0.4526619877546065, 36.29394615850141, 80.2565731540803, 60.876071530003706, 73.45417130377986, 65.3473577960845, 65.14068811170517, 66.305267272457, 68.4598958107733, 61.3057436481599, 66.1838306919221, 59.167389023688536, 58.51617751582977, 55.67522048950196, 56.04398212125225, 51.08622781692013, 52.25782017554007, 47.671286829056285, 49.43041886052778, 44.86178328914028, 54.399273472447554, 51.0102475843122, 57.69762592930948, 59.12492544420304, 62.41313465179936, 59.21814057134814, 62.537371804637296, 42.06800453124508, 47.023738814938454, 61.28828517852291, 60.79527854919434, 59.4272421252343, 57.54005255237703, 55.994748530849336, 55.30545080861738, 59.831862065099905, 53.30266114204161, 54.59549788505801, 52.572723742454286, 48.21935176849366, 48.85701540977725, 50.03442072099256, 47.098777678705034, 43.425019095020915, 40.90152302095967, 44.378182503484915, 45.032531907481534, 45.6184281072309, 42.918880370355424, 42.818130370109316, 43.54267843307988, 44.55112764912267, 47.18695648254887, 45.82310914993287, 46.05797675348098, 45.63798504491007, 45.318543295706476, 46.176812802591634, 47.55903251709477, 47.19246741264097, 51.18142374100224, 52.67093204682874, 51.963156038715, 58.39424671665315, 52.247806364490145, 41.30555068292926, 40.164411606327185, 40.86811227183188, 57.33950176546651, 57.346424748820645, 59.307143072928156, 52.39352633876186, 52.04653386146792, 50.2608395391895, 47.17392636883644, 46.36239190255442, 47.672573366472804, 44.87691579326507, 46.706983889302904, 44.02869147639121, 45.19049359906105, 41.56205800271804, 43.152249628497714, 43.5744692433265, 40.62086174564977, 42.47933956884569, 42.79298797730477, 42.70042396360829, 40.48878769720755, 44.137592161855395, 46.21502061044016, 48.521656682414395, 50.90073893147131, 50.661996026192945, 55.09314075593026, 56.08776753948581, 56.221304632002315, 59.0137380169284, 55.543268034535075, 53.2230644841348, 53.44077171817903, 50.95791532147316, 60.74118121977776, 58.065093178902906, 63.811796942064845, 58.95464751028246, 49.14499975019886, 42.668962632456136, 54.010778396360344, 64.25988066580989, 64.2989984635384, 62.514214131139944, 54.36908691160141, 47.78007768815564, 49.939009066550966, 49.19169556710028, 52.188778615766964, 51.25580756895004, 51.70109856513239, 50.44177455286826, 50.66161163391606, 53.696984860204886, 52.007290547893895, 52.983329219202844, 52.57464178146855, 54.26428118059712, 55.38481604668402, 56.33629283597393, 65.8000659942627, 74.74377601377427, 73.87051520809051, 87.23175541047128, 53.871114561634684, 0.28532613789842975, 0.3614821110761935, 0.9392180341866709, 10.258221780100177, 84.65431105706, 68.3025852326424, 76.86775515156408, 37.740449597758634, 55.08133834408176, 43.67087717979185, 51.02577232545423, 66.81479884732154, 68.5052619441863, 51.703726553147845, 0.6288632522186925, 0.01589969042763715, 0.07569238273126465, 0.12593925464898348, 0.06652250946048768, 0.14026438637125876, 0.1450719558183224, 0.21069855609488106, 0.14804312058033484, 0.14395783415004132, 0.24719699195796446, 0.37343458422730047, 0.15010244152959318, 0.24105762461981467, 3.57042987019785, 73.27809610674458, 77.31603499381774, 73.69196107310634, 32.87928954247506, 47.57964064998012, 56.104370932425226, 47.291679843779534, 80.09417918420608, 72.77131803574102, 77.17466492806712, 2.5705221055015444, 1.0348086467673703, 0.5437738664688603, 0.4559339492792084, 0.7739140333667879, 36.79237350340813, 85.58760766060122, 45.24699141902309, 75.77335111556515, 70.87507171015586, 66.9448724869759, 69.20211807374032, 70.86310063638996, 65.59294523731356, 71.76500258907195, 61.65565829123221, 60.185208782073, 60.24887669471003, 59.31663913111533, 56.14604219313591, 54.693666965730735, 50.717811353745006, 51.649727282985566, 47.92298140064363, 57.7257610905555, 54.39401749641665, 61.49076184918804, 62.096411105125185, 65.44242035958075, 61.72222091305641, 63.36192461752123, 50.95213767020933, 50.148655829891084, 63.201472220882295, 63.704292620382006, 61.17173979359289, 61.07101724993799, 57.719246033699285, 58.153275905116914, 62.14265977182696, 61.45160875012798, 60.235454343980365, 57.62501893504974, 52.00434484789449, 53.59101026288925, 54.59845927453811, 52.256612085526996, 46.795017565450365, 43.01437439457063, 46.6467833518982, 46.632333340183386, 48.80294945932204, 43.53861877995153, 47.63501667207288, 47.85332795112364, 48.764102305135424, 50.00032747945478, 50.4015741809722, 50.420727114523615, 49.5436772992534, 49.77988635340045, 50.84960299153482, 49.767750540087306, 50.42800311119326, 55.30086948025612, 54.25640113892094, 56.800473966906154, 62.71323519368326, 52.985106052890906, 39.9747650084957, 40.92153103120866, 42.04112060608403, 60.54207386509065, 58.854097550915135, 62.24501009910338, 52.585545970547585, 55.17887200078657, 57.182171575484745, 51.94065732340659, 48.68268958983883, 51.280110574537716, 49.3894693159288, 51.75283855007541, 47.592862959830995, 48.08845443110312, 44.30057840962564, 45.911099680008434, 46.37589270068754, 42.621647081067486, 45.73710333916449, 44.211650433078894, 45.17204276977047, 41.93409089119204, 46.09081483656361, 49.257905175608975, 52.96188169910062, 56.361348936634684, 54.93923087273875, 61.933942610217684, 60.94646630748626, 61.38024906958304, 62.45122086617255, 57.62931393038843, 54.619239991711034, 56.681202534706365, 53.85012203647245, 61.93751588944466, 60.68093753630116, 64.93261029643398, 60.013883575316406, 50.20941726623043, 43.16090237709784, 55.71955896192982, 65.98267586000505, 68.68047421978366, 64.01827443030574, 56.28635321894, 50.57260128759569, 53.46103468248921, 52.70935166266657, 56.678417651884025, 54.12180108408774, 54.808517886746316, 53.118317588683105, 55.759186667780725, 56.96475067446309, 56.073478344948064, 57.17747257601831, 57.05350606672226, 59.14802035977764, 58.27978411028462, 59.490384440268244, 71.98150957784345, 79.85697777040544, 76.8168035630257, 89.47320169018161, 62.222381945579286, 0.44007687919562866, 0.7424686368434661, 1.6270513640296076, 11.474004541673969, 92.89173556912331, 76.27712465101673, 84.2986697535361, 45.99412056707567, 69.18886830729824, 59.71388109268681, 54.66111913804085, 72.61694923523935, 80.56401637292679, 61.8988883879877, 0.7247006676850781, 0.09496315592719663, 0.18190232225723807, 0.2281778939669171, 0.1169148997794236, 0.1339760608971119], [0.06690442727337922, 0.11603972093472559, 0.10002043173317948, 0.039906412468201695, 0.032891241923695615, 0.15807662008991166, 0.09531546444181474, 0.1751746913237918, 3.8247519395043774, 50.789539737086145, 59.231519776005904, 48.18346600378714, 38.056396515138694, 24.77117184669741, 36.853303601664884, 37.102754577513664, 70.64565227877709, 55.915234242716146, 69.61673613517516, 13.046660231005761, 0.564233623445034, 0.15020777861918175, 0.06182508047429785, 0.18150608626104173, 1.6629821134190408, 52.79307073162448, 29.219327895872055, 60.90976076741373, 70.37845257789859, 65.89415580995622, 66.90884943931334, 67.81347351689493, 66.52677136082804, 64.44962532289567, 60.085349159856, 54.384388077643614, 53.58795473652502, 50.74399317464521, 47.94817086189024, 45.671395794037856, 43.64382851508356, 43.18937878454886, 45.36190117559126, 48.370578750487304, 55.962832204757206, 58.976471577921224, 59.208126760298214, 59.33461143124489, 61.681655760734316, 46.14934052190473, 39.80740924035349, 61.261624828461684, 54.46231772822719, 61.082984401333725, 55.439772375168346, 55.800151901860396, 53.84601531490203, 56.21951603120374, 53.19967539079728, 50.05311865960398, 47.32658893831315, 48.33641098391626, 45.33793941620858, 42.328748010819965, 45.321539986518125, 44.45576698549333, 48.15543674653577, 44.92953831149686, 42.858722979022616, 41.355443231521114, 40.79024537917107, 41.81503518935173, 42.70171834576515, 41.65448473345849, 41.833395804128344, 43.538101027088786, 42.418958602413056, 44.01424538704657, 42.920394405241936, 42.24173807328747, 43.899802392528905, 44.22488451004029, 45.30808625682708, 47.756115928772964, 50.85446280817832, 53.259946530865086, 57.73466487084666, 51.10191337523922, 40.959511341587195, 38.1527966068637, 41.51289109260806, 55.70484615141346, 55.86831877308508, 54.61387811168548, 52.25377228952224, 50.37402345288185, 48.96186036448325, 45.501211997001406, 45.18584559040685, 45.72132756633144, 43.53973273308047, 45.63280751628261, 44.442113214923495, 42.58745578027541, 42.73379941140452, 41.41379241020449, 38.27246812082107, 39.97697722527289, 38.775782738962484, 39.58433620391354, 41.05484847099551, 42.71356390368554, 48.22010486356674, 44.99172356820876, 42.72072615162019, 44.283465108563824, 46.65037232060587, 52.18101232282577, 48.57205129438832, 48.953862651701904, 52.34975268763881, 56.215319095119355, 50.062842215261156, 53.742288235695135, 50.42998783050045, 57.93896152127174, 57.58297112680251, 58.402240507064334, 51.65802701827019, 48.347793702156316, 47.086739924646196, 49.411085497948434, 57.908386645778535, 59.24119234085084, 59.09548021131947, 57.79311995352469, 48.17627237689111, 45.341759804756414, 44.59516017667709, 47.2103024298145, 47.29323310236777, 50.40912866592408, 47.98551574830086, 49.469736699135076, 48.345550106417754, 49.29868605829055, 49.211107377083074, 48.78561258316041, 50.15764197995586, 50.34777102931854, 53.93220155469833, 67.29620702805059, 72.9997568745767, 73.53064967739967, 78.7009297647784, 18.489698017797163, 1.1948972435728198, 0.32999019769410937, 1.2272255411071162, 19.43921950555617, 69.71142215113487, 62.99761879828669, 65.47665088407456, 38.12837985254104, 59.038107702809, 50.50344205671742, 48.39789021399714, 49.339145306617986, 63.98641693976618, 50.860887650520574, 2.0488076488817892, 0.03936340168659245, 0.055045811384315455, 0.03135815634572458, 0.02649809263886944, 0.08600365040042708, 0.036546963702646956, 0.03382985667896367, 0.12149154734347137, 0.11887072225011165, 0.07707029911539248, 0.07350921600816712, 0.2188797622558571, 0.23298544809222224, 5.2084084672312585, 60.072452406729425, 67.36050251991519, 53.01911300228488, 34.94478810218073, 34.96857727727583, 46.67090592845794, 45.37337018597511, 76.68611803362447, 62.900959830130304, 79.23850628637499, 13.720900954738742, 0.4585294858101876, 0.6854697340919126, 0.13038316981927042, 0.38020131628840204, 1.6064037622944003, 58.79011977103449, 41.06879249695809, 69.72817067177066, 70.03431950846027, 69.0986067248929, 66.91983992053618, 69.91331438864432, 65.7983087724255, 65.46575453973585, 61.205519245516875, 56.600923384389574, 56.99468228124804, 54.86409787208804, 50.12103057676747, 47.78013652370822, 45.70483399975685, 46.47443440652663, 49.177551500258915, 51.74016537204866, 56.630835379323656, 60.15853274253107, 61.059257984161384, 59.85515309918312, 61.87026293047013, 51.10265078083162, 42.711822371329035, 64.4681820561809, 56.60264138252505, 62.79174927742251, 56.601048900235085, 59.31242650555026, 56.130042845203036, 58.91424317513743, 57.04781470760223, 53.271235112221014, 50.35126586114207, 53.86049278320805, 47.32776957173502, 47.45427777690273, 49.46472391005486, 47.900396393191436, 48.01236829450054, 45.43219397144933, 44.9084359599698, 44.551668936206454, 42.72054572259226, 44.905235305909194, 45.06071021479946, 43.9979479389806, 43.79942501744917, 44.29676978818832, 45.85990490451936, 45.63699268525647, 42.26645292774324, 43.772133165790194, 45.76333615087694, 47.35916422259423, 46.455018674173665, 50.50318710265621, 54.42402362823487, 54.68741863004623, 57.90630778958721, 54.24686193466187, 41.40287253164476, 38.08500628317557, 42.901351298055346, 59.39915795480052, 59.53697827554519, 55.753460007329146, 53.75281587723763, 52.552280349116174, 51.46041800898891, 47.58082912814233, 48.783494503267356, 48.89510946889078, 46.563111351382354, 47.55839709312686, 46.02519358358076, 43.757212469654704, 45.04431862984934, 43.89342854099889, 41.764542518123505, 40.802236064787834, 41.61358617967175, 40.90162892495432, 43.21260706070931, 43.7825745151889, 48.147603773301654, 46.59419221262778, 45.717667994960664, 46.9284644434529, 50.489133250328806, 56.07918931591896, 51.47650364906558, 53.28768945509388, 56.16847030578121, 57.701344336232836, 52.128409416444846, 56.925911365016816, 51.90141400983257, 61.39967656904652, 59.20720892567789, 60.99665303384105, 53.34770564110049, 49.34222044483308, 46.85074660085863, 49.94898757626934, 58.483519861775065, 61.88417165510116, 62.70091502897201, 60.830952505911554, 51.4997789936681, 47.31697128665063, 48.6091176925167, 50.412564662195024, 50.02860384602701, 55.638381588843565, 52.87435400870539, 52.71867513656617, 49.66435686234505, 53.49448073294855, 52.36194733650454, 52.49728479693013, 52.80596356238089, 52.95648059537334, 57.11374975019886, 70.17070816409203, 74.84274525796214, 74.6092700958252, 82.11613747381395, 20.100140840776508, 1.3019459574453294, 0.42617964588346025, 0.8598745530170779, 22.181409289759976, 78.93458535594326, 70.10984082375803, 76.9010482295867, 44.14638611578172, 60.60849528158865, 52.45915151411488, 40.724271112872714, 65.32743215560913, 69.45297718048096, 64.32252483983194, 2.684096049877905, 0.03365272182911154, 0.08479218960048691, 0.009201754019745897, 0.05065367609683064, 0.024531171469378377, 0.1656082296563733, 0.25586037385848265, 0.1501359502154012, 0.2079986017798224, 0.24202352359650597, 0.34579731884502596, 0.3423247342148135, 0.5320416895612594, 6.698489439102912, 74.07495698621197, 76.14330122547766, 65.48976336756061, 53.74584582544143, 39.73054255208662, 56.48460549692954, 55.55852213213521, 84.8792903654037, 70.19810199737549, 87.85717733444707, 17.46315686933456, 1.6917360285597465, 1.083585526193342, 0.311712657492007, 0.7095325557935623, 2.0828856912351426, 61.857068077210464, 32.72067085389168, 66.01038348290228, 77.30789215334, 70.42937278747559, 70.57633615309193, 70.89695853571739, 68.99725267964025, 68.34457028296687, 65.39648940486293, 58.61971239889822, 61.01801818416965, 58.77308099500595, 53.85812759399415, 52.40728601332634, 47.788761815717145, 47.80311376817765, 49.743455379239975, 53.52028208394205, 60.189746964362364, 63.939572072798214, 64.28828254822763, 61.6125592877788, 64.25574648764827, 53.7406212283719, 45.62605319484588, 63.69358062744141, 58.01216863816785, 64.41354343968054, 57.8680686027773, 62.146778260507894, 57.93818489197762, 62.126134826291, 64.58216221101823, 59.363515377044685, 55.129171648333156, 58.97392988204957, 52.63875292193506, 52.580658697312884, 55.78459578175699, 51.18201209652809, 52.83229051097747, 47.67449532785724, 48.967269312950876, 48.28708717899938, 45.8800894214261, 49.08434421785417, 48.574961693056174, 45.66811277020363, 47.591117505104314, 47.28212495003977, 48.86933165211832, 49.60057127860285, 45.80141059813961, 47.72806705967073, 49.19272322808543, 50.039433510072776, 49.08908244102232, 53.13040241118401, 55.003577355415594, 57.79143333435059, 61.532668452109064, 55.44994700339533, 41.40283723031321, 38.00147156561575, 44.91793986289732, 60.53574315963253, 63.154772481610706, 59.49906072308941, 56.25638238845333, 55.39850904095558, 54.951927584986535, 52.935582207095244, 51.499378911910526, 52.8420062218943, 50.94569713838639, 50.840667832282286, 49.42066392590923, 47.1744990348816, 48.65309138451853, 47.03811822399017, 42.08104248969786, 44.487612708922356, 43.2372473901318, 43.18289118428385, 47.7211283868359, 47.93310503805838, 53.23421186016452, 50.698827082110995, 49.06213183556834, 51.06798879561886, 53.74308447684012, 61.517492801912375, 56.69815894096129, 59.34366426160259, 61.23130490702968, 60.612307825396144, 53.04314928670084, 59.37555313110352, 56.60691676601287, 64.5189179143598, 62.55706994764267, 63.78321855298935, 54.70868572112053, 48.725357132573286, 49.5056224638416, 49.5081014017905, 60.889784136126124, 64.36206233116889, 67.64599615527739, 64.09186593947872, 54.7527535500065, 51.085306059929636, 50.8145958377469, 54.00752675148749, 52.58521649145311, 58.6268275783908, 54.55763524578464, 55.67158837472239, 52.49278976071266, 57.45894970432405, 55.4586507428077, 55.122793874432965, 57.726270998677904, 55.84255272342313, 59.602662286450794, 74.48661758053687, 80.35136899640484, 79.44976514385593, 83.87643444922664, 25.28211939719416, 1.4919907984233673, 0.6533212527152031, 1.8422830921988336, 26.825874082503784, 85.12214783699282, 76.6051132448258, 82.0405847795548, 54.7789510603874, 77.9447203297769, 69.27024179889311, 61.18569950903616, 68.14930685104864, 81.00108608122795, 74.19159258565595, 4.024159600657802, 0.18676345657196738, 0.1905689370487967, 0.23611821144098238, 0.14713870782044627, 0.3270277050473998], [0.08273226344176839, 0.04283535812470702, 0.037637049362303755, 0.056809966317227775, 0.0842366379595572, 0.06193396072053622, 0.08309235540969719, 0.10377579473800237, 3.973456347180951, 58.96926226154451, 50.54135568680302, 52.46143433355516, 34.02529824164606, 17.92808128941444, 42.47498181558425, 34.594916605180316, 66.230742239183, 59.47653847355997, 64.76973779739873, 34.9615954583691, 0.1723571425123561, 0.34642321267916315, 0.09481193017094366, 0.6839143304574875, 0.09663103659066463, 17.351230075282437, 32.420329086242184, 46.335837456487845, 67.62993797179192, 64.60167992499568, 71.70183673981698, 64.14181732362317, 65.84869553965908, 59.71029996871949, 56.56572403446321, 53.61197140909011, 54.77345974214616, 50.27900011308732, 46.70900390994164, 44.1665235642464, 43.70143244343419, 44.2983034349257, 48.74178794122512, 53.285316421139626, 57.55147057194864, 57.413312927369155, 61.693120848747995, 58.64739256520426, 52.53209190983927, 45.62764567713584, 58.30033340761739, 58.82194588261267, 58.06040202417682, 62.26796380935177, 56.70196756239861, 53.578678331067486, 55.65796598311394, 54.856045246124275, 53.29459282659715, 45.993516522069136, 50.19909751030707, 49.579006087395456, 43.529742456251576, 42.646142282793605, 46.04130275787846, 40.36513497752529, 47.529147978751894, 47.48754732070431, 46.181143099261874, 41.18201955672234, 41.984716923006125, 42.901229704580004, 44.53610104899253, 39.78041941119779, 40.61653929371988, 41.547145151322894, 40.84028697782948, 42.34125644929948, 43.810176234091486, 41.72639746819773, 43.824743916911466, 44.05561070288382, 45.74287706805814, 46.048629745360344, 47.20326177535519, 52.081772435096006, 55.3316875427, 54.17544341856434, 42.58650264432354, 38.181743698735396, 45.99431668558429, 57.218061262561434, 57.86301658999536, 51.829324768435576, 51.73231278696368, 48.934356704834975, 48.376477995226466, 45.14414295073479, 42.29404287953531, 42.114582677041334, 43.76260180627146, 44.15751780233076, 40.16078733628796, 41.64290589670981, 42.379985932380926, 41.66960939284294, 40.219807240270804, 39.89557627708682, 40.129306393284956, 41.245440360038515, 43.658902183655776, 45.07772153423679, 45.172744874031316, 42.84803059793288, 43.340550853360085, 43.00256021561162, 51.014832835043634, 49.30647980782294, 47.23104784565587, 48.699171389302904, 52.686880403949374, 52.86716822654971, 50.71492448929818, 55.20322599718648, 52.26527267886747, 58.1220656056558, 59.06373254714474, 58.852454077812936, 59.69568913982761, 54.96052934277443, 52.74435489408432, 54.49071961064493, 53.027502952083466, 58.23775199151809, 61.53591225224157, 59.19384148813064, 55.12521789919946, 45.92740497281475, 46.48255371278333, 46.66969783844487, 50.256724972878736, 51.837600969499164, 48.97551413505308, 50.250311897647, 49.2686132461794, 49.56805090750418, 49.12063790905861, 50.252037740522816, 49.13860236444781, 52.15700349500103, 56.92750384730678, 66.71984611019012, 71.08146682862314, 78.23944722452472, 71.7357260181058, 3.0580391326258263, 0.9666926437808622, 0.4146297059712872, 0.3932403472642745, 26.010678083665912, 70.82170394159132, 61.95979887439359, 61.80781487495669, 34.33640103186331, 60.07151496025824, 46.82968739540347, 64.84432951096566, 41.01631902879284, 61.98268982671923, 63.27027059370472, 6.91253710177637, 0.2402555458848515, 0.087126222018513, 0.07275569192584484, 0.016449899562904914, 0.06967309201436658, 0.06513055834558702, 0.05933349824420387, 0.0493167607384103, 0.08740835687926701, 0.09650659326824451, 0.027329242495339245, 0.11180459536732205, 0.1263056515205291, 7.386578581025524, 70.71947913016044, 59.998233318328865, 52.835883402055316, 46.207030742399155, 30.268736462439264, 48.95379989377914, 42.72406408863683, 73.68090783396076, 66.7823451565158, 70.86290451788133, 39.97212525336973, 0.09863883046613586, 0.5248293088328454, 0.07710271995634803, 0.9232756219083263, 0.10397810323704636, 20.389770615485407, 39.85319506737494, 51.00201845169068, 65.02960266605501, 66.68066947690903, 73.24466182339576, 67.27215505415394, 66.41679594593664, 62.8952645486401, 59.52246942827779, 56.4347521720394, 56.357779579777876, 52.14186314613589, 50.716391455742624, 45.180005181220274, 46.01397952725811, 45.90320787122173, 49.35692933297927, 57.6438541566172, 58.51854270504367, 59.80644902875347, 63.91279012926164, 59.4600841306871, 53.79897040705527, 48.96222906727945, 60.528071003575484, 60.806237651455795, 59.770963345804525, 62.59155934856784, 58.22099170377178, 55.52731575504426, 57.58372029950542, 58.06345755054105, 56.642229864674235, 50.615645377866684, 54.74872919820971, 52.226150958768784, 46.242508580607755, 46.44922925579933, 48.56013513380482, 45.30336764550979, 50.05139281672817, 50.45553422743275, 49.25261389824652, 43.79758150346818, 45.606759055968254, 46.82529826318064, 45.4627453127215, 42.60511821316135, 42.675399241908906, 44.6543683544282, 42.940606378739886, 46.82478443268807, 43.78241369801183, 43.18533874327137, 45.429789558533706, 46.473916653663885, 47.00123617725988, 48.50937966377505, 49.26890742394232, 53.66997149682815, 57.041738956205315, 55.6267870626142, 42.97461725050404, 38.81231961711761, 46.86706758314564, 57.86711546682543, 58.82911597528766, 56.773621420706476, 53.103804819045536, 50.929984123476096, 50.51896287548927, 46.887601190997714, 45.569602443325905, 44.925984644120746, 45.43960725107501, 45.93273547387893, 42.49947701731036, 42.88371632176061, 45.860501104785556, 42.725605580114554, 40.472894253269324, 41.97251835177022, 41.67496735049833, 42.2616558690225, 45.50841346863778, 48.70347815175211, 49.276250100904896, 45.177079093071725, 48.15132610259518, 47.344549471332186, 51.11777936258624, 56.37603036818966, 53.18482921969507, 53.80987067376414, 58.91138768965199, 56.32838926007671, 54.49360255272158, 56.71581745147706, 53.503411969830914, 60.68937063217164, 62.10425976783999, 61.36573629994547, 60.13450822522564, 59.2699590036946, 55.29339736507785, 56.22547411149549, 53.33074531247539, 59.63775181001233, 64.8601366627601, 60.341409329445135, 58.60406214191068, 49.23666946349606, 48.37360289789016, 48.47259959866924, 53.84736853261148, 53.68040892385668, 53.08698569574664, 53.396511693154615, 52.66357368038547, 53.46289780832107, 53.71352549522154, 52.83352605758175, 52.55653612075314, 55.87185282861033, 60.318428162605535, 69.86517906188965, 76.24507104196857, 79.334792629365, 72.38848686218262, 3.3427259854732023, 0.920840933197929, 0.24254507625535612, 0.5827920727672116, 32.21012730752268, 77.89944833324802, 68.6406856967557, 70.19630555183657, 38.72185407146331, 62.42845150732226, 56.17300064333024, 65.28326626746886, 49.67352344143776, 70.88526987260389, 72.79684482082244, 8.721346932072795, 0.2832238700601363, 0.19787239030964915, 0.061094117681345636, 0.19520957593715962, 0.049753009506891814, 0.17650563119640275, 0.14464647058517704, 0.07907069258151517, 0.21183354599821955, 0.3179698797964281, 0.08216330526216377, 0.23190177075805204, 0.29274769127368927, 9.416047719217117, 89.14586420982116, 63.55166142986667, 72.84224233319684, 48.111910204733576, 25.990220962032197, 62.556858139653365, 49.177963349127005, 81.8816032717305, 70.67728227184665, 78.74890819672616, 42.60087028626473, 0.31928365929953517, 0.46113531856286916, 0.2916649945320622, 1.6826531675554093, 0.2706951455723855, 22.520472695750577, 36.96542847541071, 46.75449948157034, 69.95455418863605, 68.9913220559397, 75.89432485641973, 68.38621016471618, 71.29369843390681, 64.03307745533606, 62.78416341350925, 58.0523140968815, 57.799007431153335, 55.73558968882407, 52.996861396297334, 49.69497096153998, 48.78860535160188, 48.9585381169473, 52.79952303055794, 60.54894193526238, 61.99653187105733, 62.187994526278594, 68.04950606438422, 59.487034736141084, 57.008618462470274, 52.72569617917461, 61.46982815957839, 62.55424191874843, 62.32595212997929, 64.60947367452806, 59.82562549652592, 56.39947829707977, 60.64235318091608, 60.07707688116259, 63.24251590236541, 55.01455999189808, 61.03487653117026, 58.118237372367616, 50.39292927711241, 51.73364639282227, 53.70337832358576, 48.50157022476197, 53.375154387566354, 55.049320036365145, 52.92278743559315, 47.229384760702814, 47.60139411495578, 50.39344702997516, 48.416058632635306, 43.32551248611943, 44.204037112574426, 46.27480145423643, 45.03567764835973, 49.167231744335545, 48.011768171864176, 47.4209572422889, 49.206310318362334, 50.42457103729249, 50.364656832910356, 51.09062871625347, 51.32326056880336, 56.37106464755151, 61.53054252747567, 57.547991429605794, 43.77761271692092, 38.89350875731438, 48.241505315226895, 60.86906617687595, 62.07661490286551, 55.061463694418634, 55.16517900651502, 53.48800882216423, 54.52947655031758, 49.74111372424711, 47.465942905795195, 48.376481917596635, 49.04010380468061, 49.555652295389486, 46.7944605888859, 47.5603739676937, 47.77198191611998, 45.01524994450231, 41.97038066002631, 43.7172866636707, 43.979936415149325, 44.41585686899001, 48.26120738060244, 51.57202905224216, 53.1683317307503, 48.68922033617574, 51.19533246563327, 51.06254846818986, 56.94447986541256, 59.79126161144626, 58.172326857043856, 59.678360108406316, 62.84209682095436, 57.87932972754202, 57.22871834231962, 60.017613749350275, 56.87366539432157, 64.21471849564584, 64.94872731547203, 63.904525695308564, 61.96179928318147, 60.24479742973082, 56.60752865575976, 58.59659787147277, 55.42301208742204, 62.75563209287582, 69.59619076021256, 63.543910826406176, 62.914542998037035, 52.624102869341456, 51.29750236388176, 51.39906429475354, 58.305220680852095, 58.098472549069314, 56.5152156737543, 57.252633033260224, 55.64190387725831, 56.341576268596036, 56.63348297918997, 55.936124786253906, 55.57946758885538, 59.26377734830303, 64.03133592297955, 73.13581605111399, 79.47220110124158, 83.84043493578511, 77.2900139900946, 6.304677590247124, 1.1317450000393776, 0.8196396765209014, 0.8760358825806649, 34.14277322830693, 86.43323929079118, 75.8413807038338, 77.27789386626213, 48.887417700982866, 76.3067856142598, 68.75477960032802, 85.21116210568337, 57.82690332781885, 78.91900570161881, 87.27896505786528, 11.777367514948692, 0.6724608869802567, 0.3911866187568634, 0.2642617230453799, 0.2820489669759428, 0.17771240353824633], [0.015267095239382359, 0.04814876393685418, 0.07199828377774647, 0.028117545054204045, 0.0065291969240793305, 0.10771684213391236, 0.06399491343707328, 0.08462080807094613, 9.243037854471515, 63.77714280159243, 53.15709806257679, 49.21206051303495, 22.887430037221602, 29.1579016177885, 42.052091475455995, 37.618644314427534, 67.21001686588411, 65.01046542198428, 60.863790588994185, 56.77244078728461, 1.1687893348355447, 0.09526696341532855, 0.1318877511807988, 0.21572573230631892, 0.18190584626168976, 2.0980750697274364, 24.179482306203536, 49.240842865359404, 72.38657274553853, 61.37109425760085, 63.3706989595967, 62.67542354522213, 62.29690305648312, 58.65014606906522, 52.693156196225075, 51.441504340018, 50.68898193297848, 47.66692907579484, 45.92254907854142, 43.82290040293048, 45.43108786306074, 47.46645281391759, 54.12886135039791, 55.86562410477669, 59.680482110669544, 60.23636825623051, 56.28169344317529, 55.1429509347485, 50.853544973558, 56.344482744893725, 59.54073198380009, 59.59259748458863, 57.893426725941325, 59.16614955471408, 55.470849314043605, 53.92975399571081, 55.666834462073545, 55.42572636758128, 53.354812975852724, 48.60918437280963, 50.71856837118826, 49.59235783546202, 45.3550095711985, 42.211174964904785, 44.88747481376895, 40.979786073007894, 44.59452867507935, 46.96494248605544, 49.63046758405624, 46.012022264542125, 41.92630106402982, 41.223192676421135, 42.74491540847286, 41.22827606816446, 42.03748064656412, 40.00896415402813, 42.70898257532428, 42.53274263874177, 42.43505208723007, 42.01100464790098, 43.81780524407664, 44.41519791080106, 45.80849439867082, 46.22618367595058, 46.04100858011554, 54.16856750365227, 55.16699898627497, 55.84627113034649, 45.075532851680634, 44.05128040621358, 50.03062386666575, 58.78745648168749, 58.42877534128005, 54.22701866396012, 50.38726929695376, 47.87912537974697, 47.34733043178436, 46.332472062879994, 41.75632907498268, 42.760283254808, 44.04091358184815, 42.68353816001646, 42.71869436387093, 42.63281799131825, 41.23496763167843, 41.4050063010185, 41.00303003864904, 41.63679876635152, 39.36643677373087, 40.271292271152625, 47.846287296664336, 46.588606757502404, 41.76534660400883, 42.02901224936209, 44.10638578476445, 44.64016152966408, 44.74341400208012, 52.46205799041256, 49.558558771687174, 51.005438758480935, 53.04162740707398, 54.91994850097164, 52.486490434215916, 54.161530771563136, 52.74447256518949, 55.230419789591146, 57.88888854365195, 58.37414064714986, 57.90509185483379, 57.899274979868245, 59.75287729693998, 60.835761331742816, 56.9635739634114, 53.99390435987904, 59.9987236146004, 60.34728111759309, 56.63873895522087, 51.60593402001166, 46.640056487052675, 46.40844837311776, 47.1443203187758, 49.08956097018335, 51.08245057444419, 52.06682428236931, 49.330571005421305, 51.135939936484064, 51.17024498601114, 51.189154732611875, 49.61195791921308, 53.83546021676833, 54.151422823629076, 69.40353962682909, 67.21081702939927, 81.52036866834088, 53.21766730277769, 0.7761090284874363, 0.35794036402817697, 0.04174452935976367, 0.23362424284700425, 39.67966941095168, 73.97794108236991, 59.98113962911791, 66.1816341646256, 40.039582175593225, 42.12403951152679, 45.91548881223125, 24.502038417323945, 39.6847959487669, 61.72427231265653, 68.4132666741648, 10.39998310227548, 0.24643530137836936, 0.1581228764787797, 0.1005371810207444, 0.13488343075638817, 0.16253425589492246, 0.018809532724140633, 0.019469743466845924, 0.03116926970711399, 0.05518785940723554, 0.035423909449168754, 0.07461586831918648, 0.1323339514314167, 0.20033573070841454, 12.882308998415548, 79.671065268978, 56.77195833575342, 70.49010676722374, 36.8871497338818, 28.745940962145408, 48.517306773893296, 45.14521375779183, 74.78912645770659, 69.43919397169545, 67.43651020911433, 63.831055779610914, 1.5133398915490799, 0.4186648136425403, 0.05458039381811696, 0.4936131258164683, 0.1650931274578456, 2.380953955073511, 28.509202388025102, 53.35700950314922, 72.68708121392035, 63.78237132103213, 65.49878089658677, 64.76208133082237, 64.36438829668107, 60.70888834614908, 55.560989302973596, 52.54502788666756, 52.891012314827215, 49.00457497565977, 49.88687684459072, 45.91257056882305, 47.77103270253828, 48.92115400683496, 55.76700395153415, 58.31986288870535, 61.55544565569971, 62.09978826584355, 57.451324616709066, 56.63527157998855, 53.28545370409566, 57.77152730572609, 61.42403056544643, 60.5828155240705, 59.58992635050128, 62.04075267238002, 57.41573302976547, 57.751585975770034, 58.84725693733462, 56.30487465089368, 57.99471409090104, 53.341049378918065, 55.43754446891047, 52.51644949759207, 48.119558826569595, 46.967327287120206, 49.17959505511869, 43.36135118238388, 47.9112966599003, 48.56231204925045, 51.265637028601866, 49.87847905005179, 45.140463767513154, 44.455719917051255, 45.34483494297151, 42.779232225110455, 44.07730140993672, 43.0093772949711, 43.8618181597802, 44.92665929179038, 42.993774106425626, 44.44139149881179, 48.35714855501729, 46.85323338354788, 48.52351588587607, 49.02890543783865, 46.784215357995805, 55.50487587528845, 56.719959474379024, 56.611419646970695, 47.63755052320419, 44.19719649899391, 50.5951980621584, 60.1311271421371, 59.64058768364691, 55.06728056938418, 52.21346601363152, 50.31674115888534, 50.62258797307169, 48.02100143124981, 43.80379061545096, 43.956009957098196, 45.76990612091557, 45.533959865570075, 44.663464330857806, 43.99207222846247, 41.90848958107733, 43.359817535646506, 42.919558940395234, 42.7073351798519, 42.63171580529983, 43.35114517519551, 50.19632831696541, 51.22936294924829, 44.79769176052463, 43.842555399863954, 47.18531300944667, 46.96409133172805, 49.08482666938536, 54.62676702007171, 53.65763564263621, 51.8388992740262, 55.81442932928763, 56.60530467187205, 53.83902957362514, 55.73166339628158, 54.52033742781609, 57.09268662237353, 60.861221436531316, 60.45549931064729, 61.6197842936362, 60.09929710818876, 60.851917574482584, 63.46516532282676, 61.42268127010715, 54.48271797549341, 60.046458859597486, 64.04757061312276, 60.416142248338275, 54.55974940330752, 48.30719717087285, 50.297262668609626, 51.793333099734404, 52.604851876535726, 53.9465025163466, 54.50359282955047, 53.93346848026399, 55.545743050113806, 55.420180136157626, 54.898120510962706, 53.31283184789842, 56.30248984982891, 55.12103665259577, 70.64052181859171, 71.12087095937422, 84.81086854011782, 53.803116352327415, 1.653133164490423, 0.6310823331436803, 0.062296067499705864, 0.6474690764181076, 45.469676140815984, 81.32730176371913, 67.31620327118905, 73.52117323106336, 39.692397502160844, 53.35675847145819, 58.861601045054776, 32.586876846128895, 47.50715132682554, 66.17964160057807, 81.26070776293355, 13.665405300355728, 0.3301778892355581, 0.3529528252059414, 0.03465957586623488, 0.1671590980502867, 0.012926912092934213, 0.07581501042530422, 0.10334566701203586, 0.20454539917409423, 0.11515510388680043, 0.1253040988118418, 0.28963826296310274, 0.170499318008942, 0.378868292656637, 16.814681214670983, 92.06479011043426, 66.6280391139369, 69.22944130436068, 28.378967931193692, 40.101873336299775, 59.42496715053436, 51.85436517961564, 81.81830406188965, 77.77995724831858, 73.53617237460229, 70.329909324646, 1.7528557488995216, 0.623399697003826, 0.3101419933861302, 1.1804408580064774, 0.23097331815909958, 3.4068361453471647, 28.66813486622226, 51.44669755812615, 76.81901577980288, 65.1334160374057, 68.58153635455717, 69.40752475492417, 68.20096446621802, 63.88065807281002, 56.665442451354004, 55.58488438206335, 56.106351729362245, 52.08663225173951, 52.085412394615915, 49.31391269929948, 50.096900155467374, 52.642683136847715, 58.70397667731009, 60.87019974185575, 66.06292755373063, 64.76577620352468, 60.9202923313264, 58.902676105499275, 54.599428099970666, 59.00242197898127, 64.80071667701968, 64.08159325199743, 61.00859665101575, 63.552077201104936, 61.38711321738459, 61.456182233748905, 61.865697291589555, 61.817930667631096, 61.22387201555314, 57.90185197707146, 60.45478543927593, 57.45188551564371, 51.919256871746434, 51.98945553072038, 54.10681370765933, 48.50175065378989, 51.986180351626494, 52.84602272895075, 56.145963745732466, 53.037595210536836, 47.31508854896792, 44.99237075928719, 48.50911294260333, 46.02444833324802, 47.67763322399509, 44.8347463915425, 45.536803583945, 49.069760845553496, 46.197809250124045, 48.93843204744401, 50.41305495846657, 49.522065039603945, 51.02012019003592, 54.79507200179562, 50.15058171364569, 58.745808755197835, 58.23037009085379, 59.21417113273375, 48.58285350184287, 46.14974060366231, 53.89534304218908, 63.503298605642016, 63.994842190896314, 59.548698317620065, 55.42999390632876, 51.84051921290737, 53.581012141320016, 51.13565752583166, 46.650164434986735, 48.176754828422304, 48.618660819145944, 48.90311502641248, 50.80047530512656, 46.891715757308475, 45.07097897991058, 46.61628692380844, 46.107531978238015, 46.847522412576986, 46.30281109963694, 46.20493619672714, 54.170607136141875, 54.14524509060768, 47.42760958210115, 47.63485585489581, 52.25831831655195, 52.622447629128736, 51.7748155901509, 60.6726142667955, 57.8951447240768, 57.6194570141454, 59.14726726470455, 59.0312082536759, 56.556639825144124, 57.210091006371286, 58.47133698001985, 60.342354620656664, 62.40534482463714, 62.95741450402045, 62.11485408967542, 62.50249408906507, 63.44927580125871, 65.85721492767334, 62.98340412878222, 55.21896254631781, 63.71754630919426, 65.48863372495099, 64.2629950277267, 58.95353355715352, 51.90420673739526, 52.07007200487199, 53.06914675620295, 56.48915544632943, 57.97000315881545, 56.78361561990554, 58.00448863737045, 58.4582244965338, 57.426170456794004, 58.241897936790224, 56.129599617373565, 60.63182161700342, 59.37106201725622, 74.51121868625765, 75.43924362428727, 85.58352055088167, 59.73906270919308, 2.520158137044599, 1.7286079016423996, 0.1978248468930683, 1.1272249587120549, 50.719454826847205, 87.6757049560547, 74.9705909913586, 80.41782963660457, 53.6535995237289, 55.74846290772962, 65.71083599521269, 36.03465395589029, 57.56794452667237, 76.42686505471507, 93.34162358314761, 17.644660626688314, 0.5585943583038546, 0.4804018169881836, 0.3308922815467081, 0.29238830410665084, 0.24950017401527977], [0.049927409422854264, 0.11426756804388379, 0.06651375307551315, 0.10069152475484919, 0.0997426865562316, 0.014874004034115183, 0.10340899950073612, 0.3786646051993294, 17.56783904567842, 70.09361790072533, 49.77876455553117, 28.638111083738266, 38.60143338480304, 48.38433842505179, 45.421987964260964, 37.74808253011396, 51.542026842794115, 73.43842690990817, 51.75771797856977, 74.07070513694518, 9.209351558839122, 0.19801440768905226, 0.18138775632025736, 0.06788515005140536, 0.18764520845105573, 0.22880699004857774, 15.75750635516259, 52.120894155194684, 68.44619889413157, 66.24354485542544, 67.34484441818731, 59.562210882863695, 58.46471601916898, 53.35133775588005, 50.415933978173044, 46.89341806596326, 46.42892314541725, 43.843692887213926, 45.952335557629986, 45.32885912925967, 48.223729133605964, 49.23532801289713, 53.709873768591116, 56.4945996961286, 58.18146205717518, 55.68340255368141, 55.87869344219085, 56.23415431668682, 57.90053013832339, 59.316929386508086, 58.40927331678329, 60.64473405961068, 58.6444390204645, 57.35794867238691, 50.850120744397564, 56.60748943205803, 53.9530764087554, 53.73188218762798, 51.71503474635463, 49.57143591296289, 49.15037731970511, 48.981158425731046, 44.549437107578406, 44.279272094849624, 44.96441210469892, 43.17256358362014, 41.92738756056755, 42.494483840081, 45.77066313835883, 46.28294429471416, 46.69707598224763, 43.50504721364668, 43.1306726701798, 40.58295988267468, 41.2320964567123, 40.883440894465295, 44.79631500859415, 42.7352193094069, 43.464689946943714, 41.92411238147367, 45.28081793938914, 47.66234774743357, 47.299485360422445, 42.55581794246551, 48.810221533621515, 52.42599179667812, 54.72521851139685, 56.8761835559722, 49.85420742342549, 46.129120703666445, 47.7083061587426, 57.196484304243526, 53.66153055621732, 54.91274702933527, 45.73402427857923, 44.85138900818364, 46.94510706009404, 47.378627023389264, 45.1544980079897, 44.17919674227315, 41.9964095084898, 43.268720488394464, 41.905528191597234, 41.78257365380564, 38.9276373001837, 41.49300467583441, 38.95803959138932, 41.57088333560575, 39.97006993139944, 45.5303002941993, 45.51858417449459, 43.963733103967485, 45.22342189665764, 41.86008753315095, 41.86120148627989, 42.10983268676266, 45.9745361728053, 49.385484187833725, 49.88222491356635, 49.288248631262014, 50.5679101328696, 55.03663901359805, 50.03712323404128, 55.514548440133375, 53.233525445384366, 49.34744504190261, 56.156840478220296, 57.18144985937304, 59.317643257879446, 59.17627319212883, 60.706793800477065, 60.08625914973598, 60.958633499760786, 56.215319095119355, 56.497572852719216, 61.06627118202948, 58.204078443588756, 52.70775133563627, 45.507291670768495, 49.033200433177335, 46.01448943538051, 49.36083993604107, 49.91108571329425, 53.885803837930005, 52.65741948158511, 56.055451131636104, 52.29099558245752, 53.10160044700869, 49.839047462709495, 55.39881498582902, 53.48535337755757, 69.26928474057105, 64.06863766331827, 87.05456626030707, 32.76794129802335, 2.384898388578046, 0.4109788986463701, 0.29932584313134997, 0.11225022105199677, 46.26102609019126, 69.92574045735022, 61.495048999786384, 65.01679220507222, 38.94199709738455, 29.448706142364014, 44.745798803144886, 28.570277613978234, 43.68067918285247, 62.185978428010024, 65.41627776238226, 12.637322660415405, 0.32245832765775345, 0.20570481196045878, 0.07725520209679682, 0.1290135271847248, 0.03604946620461922, 0.057579854037612684, 0.028905070033825697, 0.07192180522026555, 0.07072796444258383, 0.05797843426285733, 0.11839802301819287, 0.24537932578354116, 0.28865570923493755, 22.659134364897206, 82.76043384305893, 56.116032138947524, 43.046475072060865, 21.395458482926895, 37.79331530294111, 51.69584258910149, 43.487898611253314, 63.88878914617724, 76.24878944889193, 59.245938408759336, 79.87269863005608, 11.469728177593602, 0.16299907208210038, 0.409895098738132, 0.06361533985323002, 0.1985148776082262, 0.05377890880129511, 16.43169608808333, 54.35255804369527, 71.26180956440588, 67.73370035233037, 69.63005650428035, 61.3786526649229, 60.2425616787326, 55.071214706667014, 53.45437449793662, 49.95797372633412, 49.079158844486365, 48.24844398806172, 48.12006873469199, 46.291193039186545, 49.33840397865542, 51.39265906426215, 55.70045701919064, 57.65955148204681, 60.098763665845325, 56.672749826985026, 57.297575550694624, 59.4638103823508, 59.87178394871374, 60.74928875892394, 61.13714448867306, 62.117729187011726, 61.45837091630506, 59.342636600617446, 52.95356627433531, 58.5853995046308, 55.6686544418335, 57.17422485351563, 55.5827231560984, 54.83328765438449, 53.90998525004233, 52.29508269217707, 48.90249136955508, 51.009251302288426, 48.417753096549745, 47.76467846285912, 44.56413815098424, 46.022953910212365, 47.72726689615558, 50.36609242039342, 50.72239268210627, 46.53406227788618, 45.3581827686679, 43.005917764479115, 42.42035888856457, 41.53389538488081, 44.887851361305486, 45.920940906770774, 45.59075578566521, 45.33711179610222, 47.128654372307565, 48.846695653853885, 51.24339718972483, 44.33130625755557, 49.19738692622031, 53.484937606319306, 57.01699664515834, 57.17564082914784, 50.83320748421454, 45.68585365049301, 49.01989183118267, 58.11087900592435, 55.87270006056755, 56.17255741550077, 47.440898572244954, 46.73321670101535, 48.44126378336261, 50.15872063175325, 47.187560527555405, 45.50816243694675, 45.92879741422592, 45.73043138750138, 44.50641262915827, 41.7416751000189, 41.664988840779955, 44.07710529142811, 42.99588826394851, 43.0005088160115, 42.19068450312461, 47.851908053121264, 48.666133265341486, 48.65628811620897, 47.99869098970967, 46.46857438548919, 47.5283399704964, 47.591796075144124, 51.25072809957689, 53.5232081720906, 55.43345735919092, 53.81968836630545, 55.767721745275686, 59.05321275034259, 54.669422795695645, 58.23270782347649, 52.51058163181428, 51.214151997720045, 59.01250247032412, 59.42261372843097, 60.69989042897379, 60.79319577063284, 63.1801345271449, 61.477170836540964, 61.740914929297666, 58.64097164523218, 57.94966174710182, 63.397971199404815, 62.659051572122884, 56.5124386356723, 47.80875413648544, 51.259471062690984, 49.36191074309811, 53.85760591876123, 51.948380470275886, 55.95972568758073, 54.634494089311175, 56.57448660942816, 56.72030464295418, 58.09226735945671, 54.184943399121686, 58.117488199664706, 57.02508849482383, 73.75978669812604, 69.14861694458993, 90.37933195790937, 34.58462822821833, 2.829288955657713, 0.5105049661811322, 0.5198199518265263, 0.7182763769261299, 51.328430252690474, 78.91524022625339, 66.81274352535125, 73.50500522121307, 42.01783349437099, 41.49395781178629, 55.01629760188442, 27.25525006171196, 52.26361743865475, 67.33906284455331, 77.1448862937189, 18.75974928179095, 0.4828105506397063, 0.3246775618003261, 0.09177980779279625, 0.19140495347880548, 0.11742503006732273, 0.23171000362884617, 0.1431863682885324, 0.2764606926470034, 0.23670267524017444, 0.21741901644535605, 0.2745816934733622, 0.4128846802538441, 0.37763706678825043, 28.110275768464614, 93.22601564468877, 64.88153319205007, 44.705374856149, 54.60521751834501, 67.98133527078937, 59.16590244539323, 55.01932567165744, 65.32606717078917, 86.32007106657952, 62.894927224805286, 89.62736652743432, 13.26621097903098, 0.7268144574857528, 0.5210693493004769, 0.37288042686639294, 0.7825200812470529, 0.5370272059113749, 19.276760816574097, 54.53452856309953, 73.65609492025068, 70.15677590523997, 73.92578140381845, 64.12757911989766, 62.2903879996269, 56.96921825408936, 53.92756923552483, 50.65038188811272, 50.87264299392701, 51.18343591690064, 51.2412908769423, 49.38526453510408, 52.77949148608793, 55.15338051703669, 58.50490854632471, 62.39371499707622, 63.113112988010535, 59.25237894058228, 58.82328341084143, 63.03985488030219, 63.553787354500066, 62.9158373801939, 63.666124036235196, 65.69346381771949, 64.23079629098216, 60.44587381424443, 55.932810383458296, 62.347089782837905, 59.74954328229351, 61.63370870774793, 60.49324427881549, 59.29802356227752, 58.397372845680486, 56.96604897899013, 53.612359723737164, 53.626868571004565, 54.01275134855702, 53.16566059666296, 48.91575290310768, 47.9201102256775, 54.97977249083981, 55.486523105252175, 53.382591201413064, 48.79069205253355, 46.43800343236616, 45.765889613859116, 45.27020400570285, 45.18276260745141, 51.56234079791654, 48.01096016360868, 48.4791225002658, 47.3821218552128, 50.62014041408416, 53.06587942184941, 53.892452255372085, 45.98584436601209, 52.41744495207264, 60.01880222751249, 61.149715685075336, 60.58218402247275, 52.07131147384644, 49.63656294730402, 49.86886532075944, 61.41536212736561, 57.59736622533491, 58.99801323490759, 51.24670767015027, 49.67414709829515, 50.66660873351559, 51.677003445163855, 51.21741148733324, 48.97173297020697, 49.606713710292695, 50.4151612712491, 47.08108386685772, 46.5979027748108, 44.07421842698128, 47.48638237676313, 46.04947697731757, 47.184563836743756, 44.12795489834201, 51.97946917626166, 51.85416906110702, 52.29681245742306, 51.91359689158779, 49.63015379444246, 48.867594042131984, 49.89753784671907, 56.066112133764456, 58.54082961236277, 58.851579389264515, 58.98177854476437, 60.258043273802734, 62.346124879775516, 55.840411109309045, 60.15739917755128, 55.535242865162516, 53.735479001075994, 62.69084238236951, 61.494546936404326, 63.85947727387952, 63.06260070493145, 65.71418962171002, 62.90620796142086, 64.8024268304148, 59.62214077672651, 59.838871340597834, 66.90890435249575, 64.68512050567135, 60.318392861273985, 49.525097031747144, 54.60615496481619, 52.06067792830929, 56.043668331638465, 55.7403318343624, 59.46017434520107, 58.768644794341064, 61.391627865452925, 60.518119950448316, 60.762346329227576, 57.910292917682284, 62.28967805062572, 57.82145907801967, 76.20343116021927, 72.84581953479399, 94.96882669387325, 39.37830586587229, 3.749477488379325, 1.2278987178879401, 0.5948525030286081, 0.886157987819564, 60.390960631832, 85.89236797824984, 77.1414581421883, 78.36412368282195, 53.16222460039201, 41.10996169428672, 64.6328470783849, 38.65191428892074, 59.16273709266417, 77.58063808564218, 90.69865995837797, 25.804857592428885, 0.9475930912360069, 0.5984996944185227, 0.36376493051648146, 0.28878027513142557, 0.28933887580229395], [0.08667931696700473, 0.054592662716224316, 0.12401158590951275, 0.041323135036133954, 0.1570583819862335, 0.06574606402747094, 0.12867392040789127, 0.28852326795458794, 30.50297844794489, 68.79303055424845, 46.39857968976421, 25.636609485072476, 87.02507003661125, 99.13206177373087, 57.30011724656629, 51.15789736470869, 37.03226566314697, 73.823180044851, 56.60908191434799, 72.51344573113226, 27.38015990103445, 0.11391411805825849, 0.19817497971798145, 0.08529104307414064, 0.19169793614456732, 0.1676519683772518, 4.994106831089144, 46.33948133837792, 70.02450573828914, 63.28146503817651, 60.46054740105907, 55.18142546376875, 49.07315761812272, 49.266946238856164, 47.05756533530451, 45.95568133938698, 47.69022795461839, 48.7302718623992, 46.844113872897246, 46.04102034722605, 47.5897172189528, 54.96358094676849, 55.131776102127574, 57.676809910805, 59.65482196500225, 55.59395682427191, 58.151471614837654, 60.535594109565984, 60.04188929834674, 58.230095524941724, 60.28601761787169, 56.79005615172848, 58.2237373628924, 53.9951281393728, 53.548013241060325, 56.471402798929525, 50.850669876221694, 54.9782153098814, 53.80220244007727, 51.65267690535515, 50.68787582458989, 49.39417223776541, 46.53800425990936, 41.62115635410432, 45.26712102274741, 46.282485377404, 42.52964788867582, 43.85758592236427, 44.38548987911594, 46.34251333052113, 47.90457371742495, 44.072665168393044, 44.26548496369393, 42.224491411639804, 41.250488450450284, 40.12479174521662, 40.5354795917388, 43.69451338245023, 45.859116508114724, 44.7527963115323, 47.354877071995894, 46.420074278308505, 49.109596437023534, 51.389560391826016, 51.604498432528594, 51.280416519411155, 52.82161381936843, 56.938141315214104, 49.66598464596657, 45.9888881252658, 51.26326007227744, 54.495402920630674, 54.759649076769435, 53.7803077697754, 48.58896063220117, 44.876535323358354, 47.987116075331166, 46.11418824042044, 45.3679024019549, 45.7145889343754, 44.26299425863451, 45.91577514525383, 41.79583910972842, 41.53533097236387, 41.059441566467285, 41.87083874979327, 40.54082185991349, 41.89448671956217, 42.8944440041819, 44.98805222972747, 44.820716073436124, 42.88209246050927, 40.81048480926022, 44.3700945761896, 44.78051570154006, 43.730057900951756, 44.757636516324936, 49.353532560410045, 47.699323931048, 48.01878529210245, 51.620795880594564, 54.96730719843219, 51.16381622129872, 55.70679949175928, 53.453688083156464, 51.26231085869574, 52.62609543338899, 53.18435069053404, 55.43802299807149, 57.34124329782302, 61.200686885464584, 59.24405567107662, 59.62987569070632, 58.144140704985595, 54.402764381900916, 60.8021270075152, 55.56242881282684, 52.99337440921415, 45.93919561755273, 45.31379722779798, 46.88996638021162, 47.11816203209662, 45.19107018747638, 51.03277767858198, 50.37170533211001, 52.88852553213797, 52.779197308325, 52.4548408292955, 52.99082094623197, 53.93196229011782, 54.878438057438025, 70.38378700133293, 66.04064064641153, 84.75384512255269, 14.705207982370931, 1.7359362374390326, 0.5558361353412752, 1.2247182885485313, 2.4705136783661383, 54.38292503356934, 70.48303081143287, 58.56108080956244, 71.80073538134175, 43.11182175913165, 28.50824532970306, 61.76338618801486, 39.49386673588907, 43.60074520111085, 56.44012581917548, 65.96240505095452, 13.029559677647008, 0.2812982008101479, 0.4135784801215895, 0.038931247658066215, 0.022570490086030577, 0.029367212574147893, 0.1298010042838512, 0.08134601968190364, 0.13177767966783818, 0.0845896436141864, 0.1500974006710514, 0.11718564291274357, 0.11144880115264848, 0.2851918886505789, 37.66690123465754, 80.00478836797899, 55.08227971292312, 31.422423201222575, 45.52411863880773, 90.14016151428224, 64.21664437940045, 55.92357320170249, 44.6732271102167, 80.21905960575228, 63.91722632992653, 79.73998915764594, 29.537608623504642, 0.09867473700714689, 0.5350654692419115, 0.042066768923353766, 0.4812954432300983, 0.027877815075278766, 5.52331252444175, 48.667062867072325, 73.98915906106272, 66.16843931136593, 62.48778127854871, 57.833842000653675, 52.69590577771587, 51.42330454241846, 49.961209681726274, 48.649447502628455, 50.06294419688564, 50.32849650229178, 48.56749742261825, 48.09872319621425, 50.99316173984159, 57.56070383133427, 58.32873529003513, 59.55527221002887, 61.381147292352495, 56.32887563397808, 61.23065379358108, 62.685986488096184, 62.46001874246905, 60.69701533163748, 61.29700852978615, 59.42071922363774, 59.77364232463222, 54.90191344291934, 55.79276215645575, 57.40444444840955, 53.92908327041134, 58.252217692713586, 56.52459013846613, 56.8744969367981, 54.405066813192065, 55.316602107017275, 50.11865754281321, 45.867239736741595, 49.814713078160445, 50.158065595934474, 45.37001263710761, 46.0020515995641, 46.89085283587056, 50.329837952890706, 51.09080130054105, 47.94083210729784, 46.34638078751103, 42.30232300296907, 43.45403678955571, 41.33459583405526, 44.76122548503261, 44.80674066851216, 46.98774322386711, 48.47042660559378, 49.62988315090057, 49.272755269081365, 49.091690817186915, 51.003956102555804, 53.38138311139999, 53.82305768228347, 55.58918329977221, 56.73808866931547, 49.600453607497684, 46.863992444930545, 51.401664826177786, 59.95403212885703, 57.57229835756364, 55.021565345025834, 51.26677451595184, 48.45528625672864, 52.58980958692489, 47.793802061388575, 47.032877937439956, 47.54160542641917, 47.427793933499245, 47.98406839370728, 43.7314268081419, 44.07414390194801, 43.830627472169944, 44.60767253752678, 43.33816997466549, 42.88738373787173, 45.95298667107859, 47.58906218313402, 47.86803291689965, 46.17927997343002, 45.52056889380179, 48.68610597425892, 49.1397516189083, 48.30456526048722, 49.88173853966498, 53.71368631239861, 53.78603443022698, 52.888105838529526, 53.57300658379832, 58.41463519680885, 54.9917592540864, 57.110949177895826, 55.52717062734789, 51.668182034646314, 53.943976509955625, 56.653816546163256, 56.88753881762105, 58.020652724850564, 62.98296090095275, 63.64380967232489, 61.868548854704834, 58.98840735035559, 55.58243290070565, 64.55109311688331, 58.15090679353284, 56.727698310729004, 47.21856686376756, 48.55416920877273, 48.57077652408231, 50.375211931044056, 49.851901069764175, 54.15269759393508, 53.45409208728422, 56.31145246567265, 55.564574349311094, 54.8793911933899, 54.933959207227154, 57.1471958006582, 58.38862596019622, 73.21645998185681, 68.42241364140665, 88.18755857406124, 16.63104761031366, 1.50910422205925, 0.6554967585590579, 1.7009316577065376, 3.2740156208315208, 61.728885019979174, 78.57560219303255, 67.98537531206685, 77.51144747580253, 54.886157281937145, 36.97721127540835, 63.962639531781605, 39.03010137619511, 50.66787565908125, 66.29473178617417, 74.20822343518658, 19.639617320029966, 0.35143597111586605, 0.27788316470480734, 0.05969051436911668, 0.11715837784351842, 0.010897655306654352, 0.25221051648259163, 0.11380602305214252, 0.3571246642499201, 0.29429037784857137, 0.2122131425647005, 0.3342715260242263, 0.2933248006288083, 0.5295060611059589, 45.312059617811634, 90.37560570624568, 60.379224900276434, 38.64216719904254, 109.4613725908341, 107.61950600531794, 69.95467185974121, 69.6974898922828, 51.2376783740136, 86.21062124929121, 70.63395577092325, 87.05862199106525, 35.03298651787543, 0.881255025104169, 1.1254342741543248, 0.14869000522359727, 0.9436411194262967, 0.2504830801438901, 6.778079723158191, 51.607597104964725, 77.10368571742889, 69.61784224356376, 64.6664970920932, 61.058328382430545, 54.05126117890882, 52.67371692965108, 52.83119224732923, 51.55023636356477, 53.75218437563989, 53.41115782337805, 50.99869228178456, 50.14570228515133, 53.659675275125814, 58.8919327335973, 61.440728095269975, 61.760797423701135, 63.61662764703075, 59.13853214633081, 62.72223703322872, 65.71198524967318, 63.62607271440568, 62.24885402187225, 66.70981268728933, 60.09749281790949, 62.11415198541457, 58.44039340173045, 58.34097308497275, 59.48987060977567, 56.18885094119657, 63.28568158611175, 59.90174693446006, 59.27201432566489, 57.9625859568196, 59.22910751834993, 54.85707682947959, 49.62105389564268, 53.53329258580362, 56.22217539818057, 47.828393443938225, 49.971015607157064, 51.43932350220219, 54.68509658690422, 54.611552146173295, 51.4045242340334, 51.26373075669812, 44.79064326132498, 46.64917992007348, 46.40066639069588, 48.11511870353453, 48.7574891890249, 54.093893420311716, 50.13838706477996, 52.44721966405069, 52.64831173804499, 53.330831604619185, 54.228940625344556, 55.95357541115054, 55.25450706481934, 57.32264734083607, 59.90364928399364, 51.484517051327614, 48.85234386690202, 53.46881666491109, 61.117163935015284, 59.517429182606364, 59.25651704111407, 53.86793744179511, 49.1890440448638, 57.67003597751741, 51.94065732340659, 49.39702772325086, 49.75744255127446, 50.61397837054346, 50.75395991725307, 46.53527036789925, 47.39153554362636, 46.14593982696534, 46.52625676124327, 45.187849921564904, 44.799511740284586, 50.1869224732922, 50.39092494595436, 52.62347529011389, 49.27761508572487, 47.37260618517476, 51.70434628763507, 53.971629219670454, 52.44898473062823, 55.07317589175317, 59.590326432258856, 56.94381306248327, 57.7285381286375, 59.38620236612136, 61.098160051530414, 57.42314630939115, 61.310368122593054, 58.52597951889039, 55.220935498514486, 56.62515186494397, 59.31162634203511, 59.79865527922108, 62.2125760201485, 67.23099370156565, 63.96588333191411, 63.91369619677144, 61.39407934681062, 57.37500706026631, 65.78859306150868, 60.912427979130904, 59.29392468544745, 51.04074793477213, 49.18790655751383, 51.836996924492624, 52.98039528631395, 52.93989681428479, 57.37600726466025, 54.99705445381903, 59.46198648022067, 57.20854951489357, 57.637303798429436, 60.13846197435933, 60.12649874533377, 60.7695831021955, 74.6117490337741, 70.95216197352256, 91.66071538002261, 21.49604178244068, 1.8693714709051195, 1.0424282185492977, 1.667939131298373, 3.9487549758726552, 67.35709790260562, 87.18616962432863, 73.86642025363061, 84.41365795750772, 59.6746926922952, 44.39124399615873, 82.81049897593837, 54.541004396254024, 57.80452228361561, 74.376540184021, 86.22895440747662, 32.36988348345603, 0.5938570790233151, 0.452854153249533, 0.1572911501411469, 0.26816696349170904, 0.20586383649178092], [0.042599418365787116, 0.061499393515048496, 0.07364731867827716, 0.03944394051007206, 0.0216628520959808, 0.113036526036599, 0.12265115165181699, 0.157908555721083, 31.914472772229104, 76.67692399794056, 37.28992223739624, 34.399990497096894, 88.20957091546829, 86.43282351955291, 60.397891459926484, 48.46161696218675, 27.13121883330807, 59.326931430447495, 64.32984790494366, 60.6157712782583, 56.328546154883604, 1.4573448704135035, 0.043287633452564485, 0.3245851715966579, 0.12807251074381415, 0.11282087228591405, 1.0993695114889452, 33.66121991988152, 72.84878484664425, 64.44270626191171, 64.66474379262617, 54.52269477228965, 48.61776259637649, 49.37641174562516, 47.92601339278683, 48.603775424342004, 47.55502385477866, 47.83016243288594, 45.44197636265909, 48.394324779510505, 55.01808228031282, 59.49246329645957, 57.34641298171013, 61.36674434907975, 57.1406219082494, 56.57252934671218, 61.254352754162205, 59.209248558167495, 58.15905355638074, 57.704894081238784, 56.68670562005813, 56.430041405462454, 55.716538736897135, 52.668696295830514, 56.7362843790362, 58.14914172695529, 54.53584255710725, 55.738182375507975, 53.378951241893155, 51.78141301678073, 51.63417116288216, 51.54196408487136, 46.97613693052723, 43.05916393956831, 46.72433645494523, 45.90786764698644, 44.10796649994389, 44.10589941086308, 43.982685996640114, 42.82839521285027, 40.51396146897347, 48.48100131557834, 46.219182245193, 42.446199463259795, 41.341875753095074, 41.390654348558, 41.92186094099476, 41.25154749039681, 43.275890581069454, 45.19632224113711, 45.83537047909152, 46.424620305338216, 51.45625245186591, 49.03284741986183, 51.49082030019453, 52.203201170890566, 54.78208895652525, 57.31872889303393, 49.70164291320309, 45.87308406829835, 51.387352097419004, 57.32093718744094, 55.596737784724084, 54.40853418842439, 52.05580634455527, 47.05530212771508, 48.53696569319695, 45.335644829657774, 45.275487438324966, 44.386082157011955, 44.2623862912578, 42.768661437496064, 42.871541284745746, 40.20545921018047, 39.983390300504624, 40.709487699693256, 43.29080343246461, 42.995362666345414, 45.57784334305794, 43.04540034263365, 43.2068137199648, 41.40841484069824, 40.09420902498307, 44.1207730385565, 47.20195954845798, 44.521702028089955, 45.37273868437737, 50.26509531082646, 49.313336110884144, 48.105136271445986, 51.562458469021706, 53.04099198310606, 50.881193760902654, 55.78554107296852, 54.05974134322136, 51.135551621837, 51.83199590252292, 51.49607235385526, 52.384850055940696, 56.192941973286295, 59.75750569374331, 58.82894731337025, 62.83853923120807, 59.73758005326795, 56.31783416194301, 60.312419091501546, 55.97589369743101, 51.9434618180798, 45.13221502304078, 47.428452891688195, 46.59799298932476, 44.85645671044627, 45.29760176135648, 46.86227052442489, 51.32471576813729, 50.59144827627367, 53.36894135321341, 52.126522756391964, 53.27320021967734, 53.93229569158247, 58.27891726647654, 66.96444511413574, 68.7257932847546, 70.53028752726894, 6.687973564670933, 1.2473270753698966, 0.11161079810511683, 1.3673234106071535, 3.7105847366394538, 63.10989664446924, 64.54154999025407, 64.18484572441348, 62.5035805856028, 24.659545113963468, 34.84433227969755, 58.52927038746496, 34.06050935868294, 41.68270226447813, 59.8983697737417, 64.63696556706583, 14.93741229657204, 0.14533898342520962, 0.18175667362107387, 0.08451036117490261, 0.0783243314212849, 0.031746869358504494, 0.01617811838044755, 0.033326031294681376, 0.05942853145121087, 0.03983204065251254, 0.10429494188077028, 0.10651208460330965, 0.3290140484609912, 0.11837446581452124, 40.74758175880679, 84.39141027389034, 48.08592842471216, 38.59725606056952, 86.60969888010334, 91.01861553807413, 71.82328116509223, 62.09080603814895, 29.773433285374796, 67.61063991054412, 68.1539430925923, 69.4831637413271, 62.65392503430767, 1.8406984546492178, 0.14464552063615094, 0.37305368531134825, 0.29289646554858456, 0.11622270869631922, 1.1511542359667442, 38.090858459472656, 74.7771946076424, 67.62435251666655, 66.96952066113873, 57.54785414664977, 53.52899759046493, 51.71625460347822, 49.85264239772674, 49.72838563303794, 50.04259886280183, 50.955608967811834, 48.316971717342255, 49.68977774343183, 58.29014308990971, 61.504517601382354, 58.17652771549841, 66.94599428484517, 57.268408806093284, 57.380780789159964, 63.819018025552076, 61.89185557826873, 62.15649789379489, 58.612793337914255, 60.50197155244889, 59.55637439604729, 58.65464502765287, 54.8122323712995, 59.72572665060721, 59.970596298094726, 56.62982733018937, 55.94320074204476, 54.585484074008086, 54.339135692965606, 55.25175356095838, 56.00572332259148, 51.06035978563371, 46.70235941486974, 50.3621151370387, 47.89071206123599, 48.32241988951161, 47.254468317954775, 46.05723934788858, 46.552148326750725, 43.5171438032581, 51.94903550609466, 48.29310801721389, 44.19074812243062, 43.435589882635306, 43.85831156084615, 45.30521900423112, 44.98803654024678, 45.72808973250851, 47.61911538339431, 48.647721659752634, 49.91740857401202, 52.717439589961884, 51.736639161263746, 53.69940104023103, 54.27351836235293, 56.351668527049405, 58.949458214544485, 49.318717602760564, 46.80840461484848, 51.10795382530459, 59.47050979060512, 58.12259904799923, 55.91020968652541, 51.6217254823254, 49.49804052229851, 49.11049858216317, 48.01960898983864, 47.89481486043623, 48.610600348441835, 44.55099428853681, 42.587753880408506, 44.381285098291215, 41.21292783368019, 42.286692357832386, 43.587518968889796, 46.04477013311079, 44.61511327374367, 49.65492748445081, 47.46957109820458, 46.506115390408425, 44.95712041854859, 43.24708861689414, 46.73049065374559, 50.29161837793166, 46.58824197707638, 49.97390247160389, 51.95165172699959, 53.23126616016511, 51.84762262528943, 56.087363535358065, 57.19426816509616, 53.5032158513223, 58.09448349860407, 56.469904453523704, 54.222825650245916, 54.17086993494342, 51.59142125037409, 55.55178350017917, 58.42777513688611, 62.97208416846491, 60.45824104739774, 64.37733996299006, 62.28033496487526, 59.63955610029159, 63.19673399771414, 61.465082091669885, 53.58657013985419, 47.31118186827629, 49.34974747319376, 50.59803393579299, 47.718068938101496, 50.027905664136334, 50.23325743213777, 53.8836230001142, 52.8620691453257, 55.33600607225972, 54.69663619995118, 56.347153878981075, 55.63603208911035, 62.42181485699069, 69.36663796824794, 71.09530495059106, 73.6057238424978, 8.055614809836111, 1.0948514313467088, 0.3670484446469815, 1.124791986038608, 4.260932495517116, 71.07898004593389, 70.62053342019358, 73.05070061837473, 68.54702734178113, 34.065157367337136, 31.127207971388298, 67.04014685846144, 36.67763240875737, 42.37097232572494, 65.68567006818711, 76.47672622434555, 22.62986759985647, 0.2721019587930172, 0.20626338198781016, 0.08400624467720909, 0.08099685978865431, 0.025577452221524813, 0.2502171250600969, 0.20845350478926014, 0.17212677987352495, 0.1342310609235879, 0.14721317156668634, 0.24077639374281132, 0.3175908194914941, 0.2884441157502513, 47.11361992743708, 100.74273601655038, 49.85223447122882, 48.14122992177164, 98.98958559959166, 90.36158715524982, 75.4463509590395, 60.55743778905561, 41.964520638988866, 69.54356039724043, 75.08801106483706, 74.72312081244685, 71.12415006083828, 2.1585925836716933, 0.42263792947896067, 0.7497818347427153, 0.6488100367207682, 0.33317038188538245, 1.57256547481783, 38.83484971138739, 79.2809541763798, 70.34980358616, 71.28270795268398, 61.40136711059078, 55.961051448698974, 53.80983537243259, 53.01125649482974, 52.48934984207154, 51.88225715391098, 54.51307319825696, 50.70534606133738, 53.305799038179465, 60.28595093757876, 65.59911904796478, 61.15734077269032, 67.67631607670938, 61.04407448922435, 57.04604964102469, 66.83872530537268, 65.13812680398264, 62.79311818461265, 60.8106150165681, 61.18717824259112, 62.29505562013196, 60.614476896101436, 57.46716706983505, 62.735173010057025, 62.8658938407898, 61.81405928827102, 60.891196189388154, 59.785597708917436, 56.98849278111612, 60.77629427756033, 61.06575342916674, 56.02122452951247, 49.315681688247196, 54.06264781951905, 54.74993728822278, 52.76811269021804, 52.139909805790076, 52.75340380207185, 51.73194800653766, 50.918668085528964, 56.94985743491881, 52.855942403116536, 46.34081886660668, 44.8855253957933, 48.140363077963556, 47.383765328315, 49.7082717187943, 48.96861860829015, 50.249951039591146, 50.35028526859899, 52.1421298673076, 55.68460672132431, 53.1328538925417, 58.37153227098527, 57.76211361731253, 57.915101743513546, 60.30667281919911, 51.38282568224015, 46.918764422016764, 54.137019880356334, 61.78679881557342, 61.162000548455026, 60.629974180652255, 57.044570907469726, 52.719769477844245, 54.928393363952644, 51.78692394687284, 51.409368361196215, 49.86369563687233, 48.02442566041024, 45.64168383998256, 48.92810052441013, 44.044631988771506, 44.154121029761534, 44.93787334811303, 49.378318017528905, 48.8694336337428, 53.72152320800289, 51.218945134070616, 51.184467500255955, 48.85098280445222, 46.66870940116144, 51.289830207824714, 55.47394406410956, 51.50863178314702, 53.5494331390627, 57.29096635695427, 58.188392885269664, 56.1974330871336, 61.52104646928849, 58.50811312275549, 56.06218584122197, 60.9870824506206, 59.81114018347956, 56.91957673718853, 58.00612818810248, 56.44274596245059, 57.47713773481308, 62.18067146116688, 65.5021619796753, 63.779406009181855, 65.98828484935146, 63.88129349677794, 60.61283342299923, 67.84231862714215, 62.829231446789166, 56.89808607101441, 48.75527304987754, 51.15148821184712, 52.98687111946845, 51.42991373615881, 52.06372560993318, 52.6962980147331, 58.284561557154504, 55.78720023555141, 58.864970361032796, 59.429838734288374, 60.431780738215295, 57.77024076830957, 63.410095245607444, 74.19611900083481, 73.90227856174593, 75.43556444106564, 12.383917935432928, 1.6293750006345011, 0.4876342385766968, 2.159725658355221, 5.641347919740985, 79.50349377047631, 76.49727944404849, 80.71982076091152, 75.13580906775691, 41.11610020360639, 48.754296379704634, 76.93373726260278, 45.858128070831306, 56.23729221282467, 77.05962965565344, 88.91428747484761, 34.79857783163748, 0.39493658850269936, 0.44135235430252173, 0.3227852326968024, 0.17938213813449108, 0.09085818103724912], [0.10965194192624862, 0.0561105816685144, 0.0802117575620932, 0.07998327949955579, 0.0047808583551687345, 0.04809006244965619, 0.11043542004641026, 0.08279292228361292, 32.334821416485696, 78.24644473291214, 41.25502663273966, 47.64204948179184, 77.79390519665134, 91.9924851386778, 60.081669976634366, 35.65078335423624, 28.261400768833777, 51.085910104936175, 69.82398633033999, 55.361528934970984, 68.00253175920056, 12.305861788411296, 0.20576956171181895, 0.35445475590325176, 0.252197876031841, 0.2012820637995197, 0.060794006567448385, 20.782470472397346, 70.85976662174349, 60.262557921871064, 62.29425937898698, 54.03619927744712, 54.6652925399042, 53.23625149265413, 51.59117021868306, 48.088823133899325, 48.70322712006108, 47.094941600676506, 47.08204484754994, 51.77913411971062, 56.77591600725728, 57.38375002338041, 59.309818129385675, 58.1371118176368, 48.961048433857584, 60.77729840432445, 59.22562053126674, 59.87396478652955, 57.68223062638314, 55.203998704110425, 53.97601835189327, 52.17084553933913, 51.75334061345747, 53.97031522566273, 56.336014347691695, 56.02374661353327, 53.90236016242735, 54.62502156534503, 50.63920313312162, 49.780321736489576, 48.75280980140933, 49.94406892407326, 44.72430813697077, 41.711025699492424, 46.89584601309992, 44.063502511670514, 43.52760868687784, 42.56414121197116, 45.917446074947236, 40.06861948197888, 32.385757315543394, 35.478375573312086, 43.921387195587165, 45.00440851334603, 45.56798250444474, 43.36235138677782, 42.26776299938079, 40.81693710819368, 44.516869668037664, 45.185480809980824, 48.455709872707246, 50.54259515577748, 50.762173360393895, 49.35944357225972, 49.375321326717255, 50.16610645478772, 57.532749099116174, 55.239456930468165, 47.97929879157774, 46.83781062403033, 49.762620079901914, 59.735034435026115, 55.97213998917611, 52.054998336299775, 50.537927535272416, 50.633860864946925, 50.83268973135179, 44.93560229578326, 44.90690231323243, 45.25271807947467, 43.88383442355741, 42.791018947478264, 44.075030357606956, 40.1743979607859, 40.289570516155614, 43.1694806006647, 42.353655061414166, 41.33512535402852, 42.59304123540079, 40.020166443240264, 38.82784828062981, 42.8591779739626, 41.292363674409934, 43.47469983562347, 45.435837853339414, 43.85860966097924, 46.03161058118267, 47.25968114791378, 48.19062825172178, 48.74612216026553, 52.48517644020819, 53.2120700805418, 51.88779554059429, 56.23783742227862, 51.52290528820407, 52.3782604740512, 51.80980705445813, 51.1747557117093, 50.886167326281154, 53.15585859360234, 55.16075457296064, 57.47863215784873, 60.036617632835146, 60.722381299541844, 59.258686111819365, 57.981052475590865, 57.493913712040076, 52.474742935549834, 47.75673174089002, 48.957071150502856, 47.482899312050115, 46.17929566291071, 46.62364136788153, 48.19358964120188, 51.26431126748362, 50.834054716171764, 50.258544952638694, 52.09203727783696, 54.54991209891535, 54.1112655978049, 62.018838390227295, 66.17443269298923, 73.39877174746606, 55.009382463270626, 2.0670133300365943, 0.6288248252484107, 0.09525081428188471, 1.699983669865516, 5.150813854509785, 66.5705136329897, 61.00934974608883, 69.73674497296734, 43.07302559575727, 19.13868554176823, 39.82647195939095, 59.45192167835852, 36.807713893152055, 43.8853523808141, 55.0073310636705, 72.22343352533156, 23.36673386635319, 0.2871791207261624, 0.07051293122311754, 0.06499272380625049, 0.19692331462377505, 0.032252788078039885, 0.1685898745011899, 0.11353257562844984, 0.06059467815042985, 0.055770365851781065, 0.07947718649501763, 0.08955549448728563, 0.10461678307863975, 0.06475230243297354, 39.08262583517259, 87.7251660439276, 49.11798638682212, 44.35394225582, 81.25233742498583, 93.78867180116715, 66.19583314464938, 43.12577755220475, 32.961378866626376, 57.51789900564379, 77.9168087436307, 60.51494283060874, 74.32048951425861, 14.461287548465116, 0.23976809946039032, 0.6277122817212536, 0.17958239351789798, 0.6005202666405709, 0.09122182765314657, 22.74306720302951, 76.25112718151462, 64.23308695516279, 62.91831239577263, 55.70111205500942, 56.13471046570809, 55.57406256275793, 53.00287831214167, 50.62928345895583, 49.517640606049575, 49.73255511253111, 49.092600807066894, 54.66009539942588, 61.40664662084272, 60.37976226499004, 64.39910911744641, 60.46574846390755, 49.96873671008695, 62.621843968668294, 63.11223045472176, 60.62869941034625, 60.339197112667954, 57.086489277501265, 55.816751372429636, 55.5798049126902, 54.16600619592975, 56.03650608370381, 58.42260937536917, 59.605804104958814, 55.08535092876804, 57.991623263205256, 52.986051344102435, 52.15889407742409, 53.731427192687995, 53.84514454872378, 51.0473963522142, 46.044879959475615, 52.00108928065146, 47.35074289383427, 47.01989881453976, 45.639608906161406, 48.14333623455417, 44.5816986022457, 38.14773282697124, 42.14372196505147, 48.84555032176357, 48.046838083574855, 47.839466294934674, 46.04137728291173, 43.563757250385905, 43.45394657504174, 47.391727739764804, 46.74709012431484, 49.88122863154258, 53.2078613773469, 51.93623681222239, 51.351980163205056, 53.0019957788529, 52.16819401710264, 58.299172386046386, 56.94599390029908, 47.316708487849084, 46.146485036419286, 49.831328238210375, 59.592593562218454, 56.79762240379088, 52.87191037208804, 51.80143279414023, 51.87994687787948, 51.8957148059722, 48.7387010358995, 49.048850690164876, 47.67395796314363, 45.05665448404128, 45.08156937937583, 44.94011302148142, 42.464477708262784, 42.17893308208835, 44.420112640626975, 47.69722546300581, 46.16694411923809, 47.04660231067289, 41.9151105419282, 41.301883266818145, 46.23423630191434, 44.95321766022713, 48.38539746499831, 51.18926848134687, 46.81135815958823, 50.80492327290197, 51.224652182671335, 51.56845969538535, 53.49599869020524, 55.078451479634936, 54.79588785479146, 55.04911607311618, 59.507105504312825, 52.99610437885408, 54.276950436253706, 54.30195946847239, 55.035415234104285, 53.919877467616914, 56.036341344156575, 57.873724660565784, 60.27612540029711, 62.743747311253706, 63.67605155514133, 62.00374903217439, 61.671904748485936, 58.992851395760816, 55.23076495816631, 50.682965017134144, 49.40692778556578, 49.994012463477354, 48.07811898569907, 50.896789104707786, 50.99600938058669, 55.20042150251327, 55.00048260534964, 53.31148255255915, 53.952339003163004, 57.58472834863971, 55.83855975058771, 65.88135319371378, 69.26116543431436, 76.3945996376776, 57.282329297834835, 3.9926433563232426, 0.7816462507171016, 0.3467772372307316, 1.0877969260177305, 7.209372270491816, 75.2759631987541, 68.44703828134845, 76.24371390188895, 49.32939821673978, 21.45353505688329, 33.50453692097818, 69.23404616694297, 40.740937263734885, 40.2361439120385, 59.38957168209938, 81.43477470644059, 29.632114210436423, 0.19397243586999757, 0.2128081170902137, 0.14560895280972605, 0.2014029218304542, 0.02183782466266665, 0.29099426923259614, 0.1599824016973857, 0.1730757176635727, 0.1939910211630406, 0.18539389054621422, 0.23053618838950513, 0.22721257721704824, 0.17991369590163234, 47.60182165330457, 98.34661499146493, 57.114855858587454, 63.87967355789677, 86.34813954753261, 96.08922035463395, 73.98493074601697, 46.83463742656093, 42.65039805443057, 65.0570749467419, 82.59924011845743, 65.08193100652387, 82.98222034208237, 15.369946764361474, 0.4540863290669457, 1.331583754189553, 0.34781249780808726, 1.1410563391062523, 0.2121125552202425, 24.844155388493693, 78.795545178075, 65.44874322029852, 67.01425921532416, 59.93212569144465, 57.92353091701385, 57.413634561723285, 55.43554406012259, 54.26177086368684, 51.4493686922135, 51.84044076550392, 51.97178133072392, 57.38716640780049, 62.692991841223936, 63.47572434333063, 63.91522199876847, 61.20634294325306, 49.711719482175766, 64.61154860834922, 65.63646001200523, 62.397296121043546, 62.27448278857816, 59.256014977732015, 58.587454826601096, 56.40794277191163, 55.37048370607438, 61.155085409841234, 61.667052776582786, 61.66392664755545, 58.97173335475307, 62.86386205304054, 58.224745412026685, 56.93199888352425, 58.020719405143495, 57.726286688158595, 54.6777186086101, 49.391881573584776, 58.05840553775911, 52.600372529798946, 51.558822431871974, 49.690609285908366, 52.98416860641972, 50.35190520748016, 45.6758947526255, 48.55309447934551, 52.72625315573908, 51.55095415730631, 48.727196724184104, 49.16470573794458, 47.9735250626841, 46.91525390071254, 50.53324422528667, 49.4108070096662, 52.89678212135069, 57.334924359475416, 54.914323822144546, 54.67934246986143, 54.27318103851811, 55.09015190985895, 61.98559630301691, 59.390928822179, 47.28537267254245, 47.31003261381581, 50.37883620108328, 63.606327502958244, 59.95548732819096, 55.1140901350206, 55.22539915577058, 55.24068070996193, 54.7878626854189, 52.17145742908601, 50.82756711590675, 51.00400317099787, 48.92821427314512, 47.54402945118566, 48.275665237057595, 45.64019333931708, 45.78452479454779, 46.05850627345424, 50.192939389136534, 49.363997444029785, 50.7657427172507, 47.94240890010711, 47.8898177608367, 50.70506365068498, 48.921503097780295, 52.85495396583311, 55.102342636354514, 51.36356292232391, 54.118243494341456, 55.7765745347546, 58.69818725893575, 58.22876584145331, 60.3850103962806, 58.38356218030376, 57.3533320426941, 62.38794519055275, 56.31498652119791, 58.013588536170225, 58.522151285602206, 56.83155090578141, 56.33050341759959, 58.47012104526643, 61.031730790292066, 62.33624050694128, 64.861113332933, 66.33667761279692, 63.836186239796305, 64.4266402336859, 61.62985301786854, 58.903550794047696, 53.42942430127052, 53.05856812384821, 53.16080078001946, 50.12727891245196, 53.44078348528955, 54.75828801431964, 58.32913929416288, 59.119285075895256, 54.08406396065989, 56.98575496673585, 61.61393211733911, 59.288566727792066, 68.6032662853118, 71.29973103923183, 77.59173054848948, 63.068684301068714, 5.773929424824254, 1.136950965850584, 0.5921635957014176, 2.961583882570267, 7.70696169907047, 84.70420360565186, 74.07048548421552, 85.44011085264145, 57.162242012639204, 33.416232601288826, 51.84816391237321, 79.32095450739708, 52.96928713398596, 64.62508863018405, 70.1716495329334, 94.06589708020611, 37.30519594684724, 0.7522656143673006, 0.29196327852626003, 0.3200851404859174, 0.3604472182210415, 0.1235097217103166], [0.10719758773883505, 0.09223459588904535, 0.24896778887318027, 0.0973894483139438, 0.16879605940513073, 0.09442490255159718, 0.2545215279584931, 0.5300641408370388, 29.793780580643688, 68.48498329039543, 61.522929206971206, 38.98071481335548, 59.775705491342855, 85.43097173013996, 42.78635132697321, 35.556552333216516, 16.68583723806566, 61.011514894423954, 59.958409493969334, 60.713999194483605, 67.06921162143831, 32.459570438631125, 0.2498491270647895, 0.4044822279003359, 0.05268341456089289, 0.3254725772046274, 0.2192320554487167, 8.45588876355079, 66.96337822944888, 66.39097890546246, 64.19112543905935, 60.25040249670706, 59.77546622676235, 61.73019116924655, 58.7204663215145, 55.31420553884199, 48.62646241341868, 48.04499849196404, 47.48947320445892, 55.44509895386235, 58.72599686345747, 60.87899369578208, 55.61722432413409, 48.761121303804465, 50.44930942596928, 60.2500847847231, 62.07181392177459, 57.42739815865794, 55.505275957046024, 52.51982273594026, 53.79715042729532, 52.55792463979414, 51.50081842176376, 52.6592198494942, 55.614917970472774, 57.68254441599692, 52.451193025035245, 54.014218315001465, 53.785308791745095, 51.96617234137751, 50.2484134704836, 50.117488676501864, 47.38806424602386, 43.789477886692175, 44.32981967926026, 44.060592113002656, 44.76699136918591, 43.50666715252785, 40.377890525325654, 42.28601378779258, 37.91226510078677, 42.68188291980375, 39.13638584075436, 42.68010216374552, 43.89332263700424, 45.02405174316899, 42.67113170316143, 42.757231650813935, 43.83421644087761, 47.02833975515058, 48.19260512628863, 49.09724489335091, 50.77876106385262, 50.82532352016818, 48.5339964589765, 53.10595820027014, 59.803142470698205, 53.90892228772564, 44.72177428583945, 42.39205114303097, 48.01307824350173, 55.035144590562396, 56.05009709635089, 50.28443651814615, 49.631620760886904, 49.583230480071045, 50.28012583332677, 48.67698646360829, 47.81561043954665, 45.06696247285412, 40.99134922027588, 38.497086571108916, 40.976503049173665, 42.1853304678394, 40.89344686077487, 39.92676696469707, 43.84381840305944, 40.85686683654785, 39.96729681568761, 34.51802246032223, 39.71896371533794, 44.06438504495929, 41.81787890772666, 44.87542921496976, 45.28610529438142, 43.45031446026218, 49.75856434914374, 48.783231704465805, 49.11218520133726, 47.956560811688824, 51.002936286311, 51.83984064286756, 52.70862210181452, 55.574431265554125, 51.51015758514405, 52.03340176613101, 56.20677225051388, 54.07803527770504, 53.44941269966864, 54.25328285463395, 56.385557805338216, 57.63846874237061, 61.899476743513546, 63.00938198643347, 62.06059986545194, 57.649447456482925, 59.275658207554976, 53.93733201488372, 52.709967474783625, 51.169919429286836, 49.589988723877944, 47.83148034926384, 48.179178853188795, 50.72627190620669, 53.2824021001016, 50.68279635521674, 56.43885497123965, 52.801656799931685, 57.621473112413966, 56.94057710709111, 68.80186373187651, 61.76422165286157, 73.33274256798529, 33.5664358446675, 1.8583644421831256, 0.630455611934585, 0.22431959938858786, 0.7945930140633738, 9.6181478423457, 73.11625126869448, 56.756598334158625, 71.76547327349263, 42.8095325346916, 40.736214730047415, 26.69835782820179, 55.59023841734856, 34.0320094170109, 41.322569847106934, 58.422224983092285, 67.29220621047482, 19.489088519926995, 0.4229693391150044, 0.67265338955387, 0.01817132594184049, 0.06137529110175468, 0.058284528523443214, 0.08677930676288183, 0.07907502097828735, 0.17691502858313823, 0.12358581722383538, 0.054113712206843405, 0.131583537666067, 0.32052043164449356, 0.3432455106127647, 34.85552672416934, 80.09289264678955, 59.67167246726252, 37.19260823342108, 77.26979024948614, 95.46481824690296, 47.95033208785519, 41.29813740330358, 27.19599677670387, 67.34575440806728, 70.05076992896296, 64.88036040336856, 74.30414892012074, 35.964247411297215, 0.19811983670919173, 0.7147983377498965, 0.021217312596197573, 0.0608858222051734, 0.22069042638665248, 9.287465560820795, 71.47497469379057, 69.91828795402282, 68.23512046567856, 62.754980979427216, 60.083650773571385, 63.563758019478094, 60.430356917842744, 56.98250724423317, 48.849731568367254, 50.76551129741054, 50.26461678166544, 57.749891511855594, 60.61175869357202, 65.50328377754458, 59.228609377338046, 50.09273852071455, 50.125972763184585, 62.062270795145345, 62.49996416030392, 59.88899138665969, 56.83384941470239, 57.100088134888686, 54.60774352473598, 53.41181678156699, 52.375812915063676, 55.96812740448983, 55.92035293579102, 59.12181892702657, 54.552897022616484, 57.894783866020944, 57.86910018613262, 54.89518657807381, 55.250639607829434, 55.047217645952784, 50.9020568478492, 47.93415623326456, 49.95541634098176, 48.796940388218054, 48.784373114185954, 48.332998521866344, 44.85512702695785, 44.988883772204005, 41.94413215883317, 46.51936907922068, 43.97816742620161, 46.31859079484017, 48.110984525372906, 45.79264410080449, 44.89451546822825, 44.6379610799974, 46.40500453210647, 46.964899339983546, 49.66783208231772, 51.0059682784542, 52.43854338122953, 50.90163715424077, 51.76959883782172, 54.01304552631994, 59.8451667447244, 52.96520786900675, 43.252905491859686, 43.086514626779866, 47.3741162976911, 56.54810082527899, 58.47894245578397, 51.109907165650405, 51.32735160089309, 51.05607263503536, 52.57415540756718, 51.113649106794796, 49.844915328487275, 46.916461990725615, 43.1996161706986, 40.65590027839907, 41.67220600189702, 44.581580931140536, 43.38450493351106, 43.465682306597316, 49.44165645107147, 44.398574906010786, 46.27629979964226, 40.87676109806184, 45.03164545182259, 47.26094807347944, 46.23231826290008, 48.060746808205884, 48.01612592512562, 47.113110019314675, 53.083592845547585, 52.28300571441651, 53.775393039949485, 51.75126175726614, 56.451751724366225, 53.64464083025533, 56.08519446465277, 58.59232248798494, 54.30506990801904, 53.71822841705815, 57.35308493337324, 57.09109806245374, 56.63188657452984, 55.98397770235616, 59.07397385566466, 62.08964109420777, 65.4240519000638, 65.96864946426885, 65.39698362350464, 58.61955550409133, 62.38093591505482, 56.321732997894294, 55.932437758291925, 53.98435338850945, 56.06152296066285, 48.45368592969833, 52.41591522770544, 52.00127363204957, 57.071156732497684, 54.35264433583906, 59.73273200373496, 55.760845830363614, 62.12552685891429, 59.06424637763732, 72.09528184706166, 67.31165332178917, 81.47406901082685, 34.78157435694049, 2.840323563544981, 0.8973613801983096, 0.26923783183578526, 1.1812955669818388, 12.53583819635453, 79.141537450975, 63.31019247731855, 81.00094487590175, 49.30731527266964, 41.31340719038441, 27.39277816587879, 62.46102679160334, 40.20283514453519, 43.98472170675955, 66.04035823575913, 77.0288625840218, 24.817850012933057, 0.5665826328819799, 0.5226786242377374, 0.20108470422846658, 0.11907492298632862, 0.02981444321302397, 0.18405222544266334, 0.17212667262121556, 0.32655110642794644, 0.2707391190192392, 0.2142209057966548, 0.27141048783256166, 0.38645630161608424, 0.5396457557235995, 43.07311581027123, 90.42586695763373, 80.42878089412567, 54.38505880294308, 71.9291930044851, 92.85223730148809, 59.92398285096692, 51.07668076792071, 28.387879556225194, 73.7510633468628, 72.78362643334174, 70.70417404174805, 80.70098553934406, 40.724392706348056, 0.45033078220102096, 0.8966793780845981, 0.17710946169832062, 1.2293294024082924, 0.26832208097461735, 10.608132500802318, 73.30807085960143, 71.39588402163598, 68.3765297551309, 66.29619090787827, 63.13864761783231, 68.26579340042608, 64.34106588363647, 60.01846490367767, 52.835585301922215, 52.123600590613584, 53.174764417832904, 62.10482066677463, 64.10313098661362, 67.86815920183736, 59.27938053684851, 50.4005818213186, 50.26618572973436, 63.982474957743, 65.78613373541063, 61.207245088392696, 58.00151548077984, 57.7488128600582, 57.3058399846477, 56.11284325199743, 53.828470553121264, 56.44623687190395, 60.11598287090179, 62.68792021659113, 55.66564598391133, 60.111605505789484, 61.65263806619952, 60.055107685827444, 58.43359201185165, 59.12821239040744, 54.958932938114295, 51.78205236311882, 54.16513935212166, 52.82251204213789, 52.050220889429895, 52.870686592594275, 48.851280904585316, 50.751245637093824, 48.39894140920332, 53.182342437005815, 47.963385735788655, 49.976785413680545, 51.83282744499945, 50.85292916144095, 46.48944923954625, 47.652322169273134, 48.86645655478201, 50.061151673716886, 51.780495182160415, 54.30944727313135, 55.08209536152502, 56.00080074802522, 54.88759679179038, 57.27098188092632, 63.84859269665134, 57.881855733932994, 44.42623546046596, 42.99820638472035, 49.00097816221176, 59.10489389973303, 60.65217087345739, 54.06570334588328, 54.35574693064536, 52.769654181695756, 55.082550356465006, 54.225983158234634, 53.64024385329216, 50.357741694296564, 47.03409779456354, 43.37642485095609, 43.72603354915496, 47.90131815018193, 46.51758440079228, 45.89044055631084, 53.98483191767047, 50.28800979737313, 49.49436526144705, 46.91350060124552, 47.9825778930418, 52.662848041903594, 51.95386786614695, 52.931569622408965, 51.76892419015208, 52.09656369301581, 56.00151461939658, 56.39615997191399, 59.02110422811201, 56.60256685749177, 59.94921545828543, 57.26203103219309, 58.900718842783284, 60.441833772966945, 55.33204447838568, 56.34373749456098, 62.03125661419284, 59.79517613687823, 59.10202664713706, 60.67735641233383, 62.23970313226024, 63.48196875664496, 68.62274477558752, 66.47615709612447, 66.79225306357107, 62.86208521935248, 65.10992104007353, 59.4247631872854, 59.51178096955823, 57.378172412995376, 59.04454431226177, 52.71080293963033, 55.71972762384723, 57.38363627464541, 60.45624848335021, 58.50602249945364, 63.53229276595577, 58.23152719005462, 63.33064371539701, 61.13421840052451, 74.15878588153471, 69.88468108638641, 82.86694972745835, 39.71791644250193, 4.801159068461388, 1.4436016207741154, 0.8630457893013955, 3.7982953075439703, 13.450845768374782, 89.70250345045521, 68.065548558389, 88.26191886778801, 57.11174149667063, 54.31353046048073, 37.61403945184524, 72.66683393909086, 48.812574955724905, 59.27996889237435, 76.34483260493126, 87.05655097961427, 33.60193329472696, 0.9412383612605834, 1.0305739578700837, 0.2614005072222602, 0.16244067059409234, 0.2126838423071369], [0.06644878115865492, 0.05905560368011075, 0.07182323268704838, 0.06484502971532845, 0.09529294911772014, 0.1252751636709417, 0.27730531990528107, 0.2571744904402764, 17.874646840556977, 68.2602628584831, 54.96279647273403, 40.941291932136785, 18.061084939587502, 23.689152694517567, 52.162235936810895, 35.039842820936634, 10.166486367102593, 66.5313526891893, 55.645798790839414, 65.17055696056735, 60.16586757475331, 54.5601494850651, 0.7909784273755166, 0.06980662113956868, 0.30456484265385136, 0.2890067307218429, 0.29485366697753634, 1.15766818965635, 50.04905900647564, 69.45086694532826, 60.91332227953019, 65.1764169816048, 59.85913038253785, 61.8791510212806, 61.69640387258222, 61.05144462277813, 55.13592596976988, 48.48572384926581, 48.905370389261556, 57.75650070559595, 59.90942693525746, 61.639082354883996, 46.41906622917422, 51.78244852250623, 50.26308313492806, 57.91603918998473, 60.15905049539382, 59.35676497797812, 56.83630874080043, 56.39610898110175, 54.44764806378273, 57.00060506020823, 55.213126059501406, 53.55595604065926, 54.68217834349602, 57.16614869333083, 51.36754805041898, 54.836794253318544, 53.95168396734423, 50.88040144212785, 48.850363069965, 51.01916705408404, 54.80246566957044, 46.046966660407286, 46.99645088564965, 44.426874806804044, 46.07145793976323, 42.787304462925086, 42.7390161637337, 42.861990313376154, 36.17629074281262, 39.32173352087698, 35.66086384557909, 39.99395324337868, 41.5413635776889, 44.49233132023966, 44.25314518713182, 42.032926774794056, 44.485490706659135, 42.429603915060724, 47.33974849024127, 52.679922119263686, 51.35467483151344, 48.4853708359503, 52.66497396653699, 56.507166970160704, 59.755630800800944, 48.21319756969329, 40.241803892197154, 40.98435171188847, 41.12343111345845, 55.04358553117322, 57.98351964642925, 53.235702360830004, 48.855164051055915, 49.56176334811796, 51.04876525940434, 51.59353540789697, 45.750231512131236, 44.79750348675636, 40.99083146741314, 42.767319986897135, 42.051365836974114, 43.94110102807322, 40.55189471090994, 37.76202655607654, 39.893658238072554, 36.73239261873307, 33.885434366041615, 41.15615152543591, 42.97604891561693, 38.90247137315812, 39.69919496966947, 42.81942867463635, 44.74859545307775, 44.45413527950164, 52.74328408702728, 52.40091216179633, 50.851454350256155, 50.16643985625237, 53.395884113927046, 51.005701557282485, 53.8889927248801, 52.78626149700534, 54.56663316295993, 54.94147446847732, 57.818548679351814, 59.05075342424455, 55.6030684901822, 53.37339716572916, 56.63928416467483, 57.077381533961145, 61.05559841279061, 64.80698070218487, 60.17743856676164, 58.812379221762384, 57.96266440422305, 57.37164166665847, 54.37878301066738, 57.01801253903297, 55.06976342970326, 50.82795543055381, 49.71229999296127, 49.199552074555434, 54.58734327746976, 55.463039875030525, 58.646184475191184, 59.4610058876776, 63.905306246972856, 60.126918438942205, 69.08185035951676, 62.45007161171206, 76.5504667835851, 20.302095836208714, 1.6625609489217883, 0.5419636313473025, 0.020946119386222095, 0.6782607241503654, 20.418935398901663, 76.10598379565825, 57.43337585080055, 73.31963400686942, 54.45095069946782, 49.303490961751635, 19.60318046231424, 56.18863913320727, 31.22986032116798, 35.56418134320167, 54.90710273865731, 65.40394190819033, 12.683561521191752, 0.5121513504174449, 0.20681626764276337, 0.07428092701781182, 0.10456186223534808, 0.03031366823932096, 0.05757406241290512, 0.08114143590172453, 0.015048296697768233, 0.14766566906004183, 0.04032495694475309, 0.12044690218904328, 0.1250555262630505, 0.384486842780344, 22.124003441103046, 77.75264186243858, 57.88488380370602, 39.60051598087434, 31.68525142054404, 40.04955676294143, 55.9873156393728, 39.351767109286406, 16.25744381258565, 73.68515968322754, 63.56130261575023, 70.37197282237392, 64.61538860874792, 62.1551093747539, 1.029815469538012, 0.047686897188184724, 0.42670024859328426, 0.19932135368787474, 0.4520074422321012, 1.437733387274127, 52.927313850772, 73.92834663391113, 62.75914261418005, 67.10175944912818, 63.30705065881053, 65.8482954579015, 65.2483767847861, 64.40648317337036, 56.9935957847103, 49.46679099913567, 50.48434403634841, 58.67335865574499, 63.07464238136046, 60.85914650271016, 49.64155612453338, 52.20524472575034, 49.16723958907589, 60.94343431534306, 61.64335381600165, 60.673367361868586, 59.21750906975039, 58.68941291686028, 56.22914544997677, 58.940244567009714, 57.17637431237006, 55.96503657679404, 55.13782439693328, 59.91649504630797, 52.58459283459572, 56.75111093828755, 57.93323093844999, 52.21383471642771, 52.857103424687544, 54.394923563926454, 59.370952190891394, 51.94579170596216, 49.4057628416246, 48.38139272505238, 50.44119404208276, 45.435908456002515, 46.911100110700055, 47.04094625288441, 41.318180714884114, 42.13410039101878, 40.58056723686957, 44.48005822397048, 46.17669120911629, 48.009701082783366, 46.06704919568954, 43.69503113531297, 47.54726932894799, 43.14790756471696, 50.487407407452984, 53.333538040038086, 53.34199859249977, 50.11849672563615, 53.81900979626564, 58.66534133111277, 63.747634810786096, 49.98680706947081, 41.3184945044979, 41.37422353990617, 43.151343560987904, 55.92030194497878, 60.11479831510975, 54.30586222679385, 51.98337193458311, 52.02592572858257, 54.48927617842152, 53.307548415276315, 47.29627293925132, 48.01985609915949, 43.78730097124654, 44.52906823927357, 44.553343788270034, 46.67342801247874, 42.28438600417107, 42.5114441687061, 42.4220690419597, 41.40821872218963, 37.042099045168975, 46.48428347802932, 46.384812170459384, 40.68168986228205, 43.6507514984377, 45.50474213015649, 48.62559164724043, 47.07600439748457, 57.23075797480922, 54.48465562635853, 56.021365734838675, 55.029743486835116, 57.44358970272926, 54.189183481277965, 56.366000867659054, 54.748933161458666, 55.95867057000437, 58.546046364691954, 59.5249052201548, 61.257561252963164, 58.60488191727669, 56.27317405516102, 58.969783936777425, 60.00826281885947, 65.25417404790079, 66.27532389856154, 63.10813157789169, 60.375973255403586, 61.417852832425034, 59.22097644498272, 58.40504500173754, 58.85524288300545, 59.22792296255789, 53.3816655220524, 53.21210538187335, 52.12435368568667, 57.11964115019768, 57.371633821918124, 62.306446183112364, 62.281554821998846, 68.65220177558162, 62.515049595986646, 72.7211352317564, 65.1953031939845, 77.62504716073313, 20.10482611194734, 3.665736846385464, 0.7982994087280766, 0.2313888289274708, 0.578281469643116, 23.823656651281542, 86.13308383572488, 60.724730799275065, 83.1124508765436, 58.31690149922525, 58.10852950619113, 23.26898055691873, 65.61194519842824, 35.375134868006555, 39.732994033444314, 65.3874404968754, 74.56511205242526, 17.19026580933602, 0.6151859474278266, 0.35843084416081833, 0.08770582115938587, 0.13843248628320234, 0.04513964334863328, 0.2135766258523349, 0.10159875671829909, 0.2977419410261416, 0.46165343914781853, 0.19855399405763996, 0.3304186553484009, 0.3020977637460155, 0.5622021421309441, 25.703864405232093, 92.4359953788019, 68.33656864781534, 56.19198491496425, 30.932844723424605, 39.220446155917266, 70.62265150008663, 43.56082331749701, 21.286950034479943, 79.77595729212608, 70.18989639897501, 77.4404525756836, 71.32797210447251, 67.61994377259286, 1.3024099002922735, 0.4081373559611459, 0.9062777243314252, 1.148231702466165, 0.5474064715446965, 1.8855326166076047, 54.808780685547866, 75.97975407877277, 67.48839532175373, 69.38662636664607, 66.4154701848184, 67.64703950574322, 67.72296090279856, 66.77566143774217, 59.85235252688008, 52.650131717804946, 53.75083900267079, 63.37669234122, 65.02932810014295, 66.23051474171301, 49.16630214260471, 50.81127359021095, 49.210267989866196, 61.456554858915275, 62.218840045313684, 63.40598067929668, 61.52583176089872, 62.98143902132588, 58.34311077671667, 61.91650375243157, 60.37000340800132, 57.53162337887672, 58.842812891929384, 63.82580372595019, 54.9944382329141, 61.06370987430696, 60.02376794815064, 57.680222372854914, 56.1728084471918, 58.52986658773115, 64.42019185712262, 56.7684752710404, 55.54842595131167, 51.66906849030526, 53.618792410819765, 51.40862311086347, 50.89773047354914, 51.92687411462107, 46.359814905351215, 49.99525585482198, 47.44522494654502, 51.007470546230195, 51.0489260765814, 50.47135706870787, 50.47442828455279, 45.39247605108446, 50.860334596326275, 44.189222320433586, 53.11984731305031, 57.84591897841423, 55.52376601003832, 53.82064542462749, 56.72091653270107, 61.5052197056432, 65.2435758036952, 52.09191568436162, 41.338184802762925, 39.582535836004446, 40.87490973934051, 57.39505037184685, 65.26264244510283, 56.888491953572924, 56.38465566019858, 54.079470865188114, 57.467159225094704, 57.16889827482162, 50.12567858542166, 52.36326917525261, 45.50478527622838, 47.27440964791083, 46.09384682870681, 50.09715903189875, 47.31509639370827, 45.17532187123453, 47.293778311821725, 47.361725530316754, 44.72383745255009, 49.84155777961978, 49.35716075281943, 45.83389959027691, 47.55521997328728, 51.064219397883264, 53.24519449664701, 51.39074494761806, 61.8678310609633, 62.40445444660803, 60.53000080970026, 58.845825272221724, 59.64802449749362, 56.72849455187398, 57.980750453087595, 55.450809924833244, 59.80948102089667, 60.18166295943722, 62.85739798699657, 65.326176997154, 59.92197851980887, 56.53547863806448, 61.08434938615369, 62.54442422620712, 67.15281301929106, 67.32629945201259, 66.9813113058767, 63.351032195552705, 63.7148908645876, 62.44494507389685, 62.457037741138095, 63.584311239181034, 62.787697469034505, 57.09296903302593, 55.68221015314902, 53.59647804690946, 61.94350534869779, 59.85012462062221, 65.5380791233432, 66.21580585356682, 71.17219909544914, 65.11409836430704, 79.03913221051617, 67.44695940325337, 82.18207251641059, 26.23510433781532, 4.661359421668514, 1.7314462267583417, 0.29703615954326046, 1.4364149805999573, 27.854239133096513, 95.02841534153109, 70.63908623110864, 90.61857300419962, 64.82998148087533, 64.72271642377301, 32.208801546404445, 76.69802634946763, 42.49619399347613, 49.75772888429704, 72.33406789841192, 85.7312213220904, 23.81360753890007, 1.054541110511749, 0.5312316588336422, 0.238149018597699, 0.2879565773952392, 0.13583762390959647], [0.08634247576757785, 0.12614104220823896, 0.041192134001081994, 0.044695032730458245, 0.036574224941432476, 0.12124682055605997, 0.11657956011232831, 0.26982054895450996, 5.140001841129796, 66.08177062003844, 51.43984517743511, 58.7046552473499, 33.36965837786275, 23.741449656025058, 51.77871050373201, 47.94786883938698, 9.943996783225767, 52.28643386594711, 59.755807307458696, 65.84566746988605, 61.651473122258345, 59.44017417969243, 3.733280060752746, 0.15816629834232793, 0.2722168413381423, 0.1335171589087094, 0.14070793595765868, 0.03431500483965201, 24.221616406594556, 73.47759569844892, 63.511068820953376, 67.31472061526391, 61.57879944770568, 66.1424575313445, 62.57738782513527, 64.77004766464233, 56.230788923078975, 47.098099108665224, 45.233847556575654, 55.69818988923104, 56.51958911649643, 61.34802679861746, 55.60938742852981, 58.00987405161704, 50.716411067593484, 54.3354957334457, 62.30459482439103, 57.202497297717684, 57.676551034373624, 57.993513845628314, 59.18169783007715, 57.09993516245196, 58.56263799052085, 56.12636758435158, 53.32458326893469, 56.89249669351886, 52.198494326683786, 54.42924430293422, 55.540487074082904, 51.496817604188, 50.4349966972105, 50.28484444464407, 52.956939512683505, 46.86803248620803, 48.104053697278424, 43.229763507843025, 43.58257678247268, 42.655897217412154, 37.152545144481046, 42.442865448613325, 34.68741786095404, 24.003503207237493, 23.092358189244425, 29.9293984905366, 34.95267206622709, 37.66424186768071, 47.052489788301536, 46.29157743146343, 43.96704358439292, 44.77907226931664, 47.166324815442486, 46.033736505816066, 46.083868318988436, 46.12083273549234, 52.39723690094487, 54.088884553601666, 58.06188860247212, 47.422961573446955, 41.84143666298159, 39.07444769336332, 37.441502232705396, 51.19494022861604, 60.61675579317155, 55.64215490894934, 52.17491303720782, 47.47560370352961, 48.82568743921096, 49.552530088732325, 45.44032112244637, 44.12282051578645, 43.23945960690899, 41.51850400432464, 42.042214947362105, 36.880167914975075, 34.89761375611828, 37.65740909884053, 37.15322763689103, 33.437876239899666, 38.32309415263515, 43.22220902289114, 31.493355343418738, 41.456969861061346, 43.9584457489752, 44.42132073064005, 46.445805026638894, 42.85438483761203, 50.18442000112226, 49.61071845023863, 51.18639730638074, 49.361679323257945, 55.48362055132466, 52.232332614160356, 56.1848932696927, 51.965693812216486, 51.537610253980084, 59.66101930987451, 57.890037798112445, 59.444347581555775, 60.360805449947236, 58.0736949366908, 61.612590666740175, 58.23120947807067, 68.11262484519713, 63.96042339263424, 56.126551935749674, 59.358506510334635, 58.644917549625525, 60.233351953568004, 57.84056102075885, 57.14090824127198, 59.69357105993456, 55.30424664097448, 52.608025074005134, 50.256328813491336, 56.1000680923462, 56.696178144024266, 61.81927996297037, 62.16151068287512, 66.73045219913607, 64.84409809112549, 68.28177313650808, 64.60856760701826, 52.83647175758116, 7.281078100204469, 3.263896396083217, 0.24833317695846482, 0.25575676812760295, 1.252957882900392, 47.366055826986994, 67.75423003781226, 64.12397838407948, 63.91916398079165, 63.70834442877001, 69.92743492126465, 19.868064003605998, 50.92261398992231, 36.89936399459839, 38.52407247789445, 53.50767166383805, 68.75900791537377, 7.630237196722339, 0.3367553362923284, 0.22546655558530362, 0.021447142803921335, 0.06427666908430477, 0.0441174790443432, 0.06208699444429048, 0.07877498264274291, 0.03527214743136879, 0.033526290508527914, 0.051108663375940055, 0.09807252295074925, 0.1658836842304276, 0.27300778115468644, 6.339633753222804, 74.42344388654156, 59.651083946228034, 59.103136677895826, 31.064024471467544, 32.33508617647233, 62.200659859565, 46.362344834112356, 11.535826979144929, 59.8539097078385, 62.39357771412019, 73.07915349160471, 67.9513369837115, 68.58559993005568, 4.703012541417153, 0.15343130806521063, 0.5596526015189387, 0.27472323587825226, 0.1788517907862702, 0.036245412343452056, 26.19298004334973, 76.30328686006608, 67.44121705332111, 69.24953168438327, 63.73595007004277, 70.51349193819108, 63.726528536888864, 66.01127778330158, 59.747958644743896, 49.213405886004054, 47.68801573784121, 58.763941872504454, 60.726099706465206, 62.6726229729191, 59.760761260986335, 56.456246760583696, 49.5797513377282, 56.00402885867704, 61.99371560927361, 59.343260257474846, 60.390862572577696, 59.35150900194722, 62.60705271074849, 59.87676143646241, 60.795706087543124, 58.553479256168494, 55.556870814292665, 61.00885552744712, 54.701103779577444, 56.03322698223976, 57.952811410350186, 55.1493404757592, 54.213647304042695, 54.18179765824349, 55.211270778409904, 50.51167903407928, 50.33833380668394, 47.654393180724114, 49.55000015997118, 48.65452304963143, 40.60096356176561, 45.876422005314986, 40.140755791817945, 28.1227881293143, 28.624988794326786, 32.96971782561272, 40.926779162499216, 40.268546612032004, 47.35679511101016, 46.940106038124334, 47.779952172310125, 45.32972597306775, 49.292386731793805, 49.46734013095979, 49.52659537715297, 46.43610892757293, 52.576308788791785, 57.106187420506636, 60.75012814614081, 47.690263255949944, 42.224028571959465, 39.75558296326668, 37.22242216910086, 53.07454001518988, 61.895522994379846, 56.219900423480624, 53.11490512663319, 49.28158844670942, 48.37432853637203, 52.52470216443462, 48.59734665962958, 46.232808559171616, 43.31543591714675, 43.011671881521906, 44.33890388857934, 41.94235140277494, 39.78896625580327, 41.70312996833555, 40.93594966396209, 38.95103423826156, 42.381574492300714, 46.22703875264814, 35.026294954361454, 44.08058835614113, 46.78738071072487, 49.08203786419284, 47.90201240970243, 47.32193700728878, 53.20270738294048, 54.16128758461245, 53.36260672538511, 52.07855609155471, 58.35682730520926, 53.16313459027199, 57.6648937502215, 55.405989000874186, 54.1164509711727, 62.24744589098039, 60.72151053336359, 59.71845065393756, 60.9634070242605, 60.02903569129206, 65.93046911301153, 61.78428849866314, 68.27198290055799, 65.00619003849646, 58.93311369803644, 61.61202192306519, 61.45890043627832, 62.848933512164706, 63.28637584563225, 60.53314655057846, 61.87364401355867, 56.823023673026796, 55.643943509747906, 52.26761041149017, 58.54066487281554, 59.633966722796046, 64.54886521062544, 63.49433991216845, 69.84361387068226, 66.6715617333689, 74.04658256038543, 70.29142302851524, 57.76040738628757, 8.892786868156927, 3.4264580472823116, 0.41195103357876506, 0.3070773965408725, 1.1088854266751198, 54.90170163493003, 73.34758481671734, 71.34101006292528, 73.55674128378593, 69.60664779909196, 79.863614420737, 25.026431852771392, 59.49296143747146, 44.75870340101181, 37.46751931405837, 61.0648669735078, 77.34931238235967, 11.146291494369509, 0.5710756466273339, 0.24280972898967806, 0.06234918037549623, 0.12001343431972689, 0.026063977425257047, 0.14925015339207265, 0.2729732765545768, 0.13542297115970042, 0.26117509351141993, 0.22487040128438707, 0.17856553437248354, 0.31839432314999644, 0.566660160979917, 7.829051844535336, 90.59356397198093, 68.07599775252804, 77.0233634210402, 42.854553499529445, 38.13793082391062, 67.05498126245314, 55.1866461384681, 20.266843534285023, 66.0474028125886, 70.73777306464412, 76.57746053511097, 71.75914256803452, 73.63380016819124, 5.181049444983083, 0.282516096748652, 0.905383485219171, 0.5450800157362415, 0.8501747767290763, 0.14942773257292088, 28.203065318446008, 74.46573488173946, 69.83176046802153, 70.83392604704827, 66.38491492117605, 73.1679637970463, 64.98739796300089, 69.09440978880852, 61.85493430783672, 52.5414663745511, 50.54371695364676, 61.44644298861104, 61.27762809876473, 65.0001770450223, 60.22385589538082, 53.35000022765129, 50.61966188492314, 55.85211546190324, 66.7182771621212, 62.64438190767842, 63.18564153486683, 60.84815209911716, 63.10573500971641, 63.451758661577784, 63.82981631063647, 61.34711680873748, 58.19951672707835, 63.32739599289433, 55.56315837367889, 61.40474034893898, 60.72118105426912, 58.9019779236086, 56.94759422732938, 56.97842797925396, 57.88369532554381, 54.70737564948298, 56.33021316220684, 51.75637260560067, 53.55769757301577, 52.38336740001556, 47.27796723765712, 50.20036051350255, 45.58989678659747, 34.896358597663145, 34.716027628990915, 39.32719738252702, 44.969970103233095, 45.51278691137991, 53.392197085965066, 52.195984009773504, 50.1783089483938, 47.83638723434941, 52.13740341124996, 50.967230950632405, 52.587860168949256, 51.462457641478515, 54.195694615764005, 59.83181891902801, 62.84803921176542, 47.38831135534471, 43.654556197504846, 40.050796231915875, 37.72164575515255, 55.40693036971554, 61.954837076125614, 58.28627955528998, 58.27517140296198, 51.67384201480497, 51.203671424619614, 55.28831789570471, 50.9930323016259, 48.50494346311016, 48.37748996673092, 46.85396294439993, 47.55833825757427, 46.68541869809551, 46.223626290598226, 47.61982533239549, 48.17470735119235, 45.08560942065331, 46.32306229683661, 50.26469915143905, 42.041858011676425, 49.067446647151826, 51.39260807344991, 53.45207598901565, 53.32433223724366, 51.931451520612164, 56.8226549702306, 57.69488419255903, 58.57817449877339, 55.482796853588475, 62.4717583963948, 55.77692754807011, 62.865478069551536, 57.37213980767035, 56.346173286437995, 65.58386495036464, 63.7576093981343, 63.05551298203007, 63.901831027000185, 62.83644468553605, 68.28491887738629, 64.84784003226989, 69.893890811551, 65.16364182195356, 63.22648909784133, 64.38193698083201, 65.80180360424903, 66.5391738953129, 64.85024836755568, 63.38929491658365, 64.73249097024241, 60.821091667298354, 57.55719723240022, 54.90474931655392, 61.73177972916634, 62.114626592205425, 67.4104735159105, 68.20887980922576, 72.49657169465097, 69.12837751450078, 74.55927556560886, 73.23943722632625, 68.43880914872693, 12.351528963735028, 6.763211488723756, 0.7512492301963991, 0.7921759760187519, 2.2614040345914903, 58.30706027246291, 82.03956496331, 76.70233311191683, 77.64853431332496, 76.3987808842813, 83.8640554489628, 33.744609509744954, 68.65730870154597, 55.36309003829957, 57.70705530720373, 69.96104178890106, 91.71424004339403, 16.78813853571492, 1.1519791594436093, 0.5228502279327762, 0.1151500860108964, 0.21328508343187072, 0.18100480428866803], [0.1204447954472515, 0.010625921047082352, 0.051875276070448666, 0.06201730342581869, 0.036902175690498085, 0.12781031715172914, 0.1319265765168013, 0.10144529398530723, 0.44120667502284056, 51.015511405083444, 61.29310184909452, 50.362519141166445, 49.929061935793975, 31.06278108012292, 34.06347859290339, 29.710167415680427, 22.78286945435309, 52.828787834413596, 59.959868615673436, 56.74280728063276, 58.94153110442623, 67.9148667858493, 17.353267746586955, 0.2435808577725003, 0.7159626075337011, 0.4733333995025005, 0.21840442002059954, 0.3403689117441255, 6.507260655203174, 57.491062148924804, 60.42807802077263, 66.79669318660613, 67.5124708298714, 70.03871256305327, 64.89711284637451, 61.92886706321471, 57.096667828098425, 47.738983015860285, 48.95724765716061, 55.35040901553247, 54.717346314461004, 62.06451046851374, 60.89653061282251, 55.66117840428507, 51.66346342332902, 49.72873864635345, 60.37966028336556, 59.40630843562465, 59.432568703928304, 60.066019719646825, 59.94628937013688, 57.98456691926526, 60.23228114651096, 56.87144925517421, 51.07263680427305, 55.643370843702755, 54.946044029728064, 54.3354957334457, 54.51031577202582, 52.630100173334924, 54.86684745357883, 50.5958217190158, 51.754148621712964, 50.782993301268554, 44.34403042639456, 44.03302177306145, 42.96850227540539, 46.90852311349685, 35.959022814227694, 34.93521751896028, 37.582401614035334, 27.34613333978961, 22.02237286875325, 22.706965707963516, 33.023583735189135, 37.000565067414314, 44.43742990493775, 45.646120040647446, 45.29350680689658, 45.3474001730642, 47.1267088767021, 50.95607572986234, 45.835586209451, 47.61009000962781, 52.32504960029356, 51.73944757830713, 53.5158262714263, 50.13892442949357, 37.39772465921218, 35.4850318354945, 32.11934404988443, 52.65204975681921, 57.35787414735364, 54.90281951042914, 53.498661979552246, 43.84542657483009, 49.06202200920352, 48.14049643854941, 48.022629214871316, 43.86053554473385, 45.28553262833626, 44.908765439064275, 41.56607058740432, 30.239302996666204, 28.305756891927413, 23.972622386870846, 24.197058446945686, 31.499193791420232, 38.12674422417918, 30.398872860016365, 40.62769059211978, 45.80213231425132, 43.38023347239341, 43.978936210755386, 45.71767191733084, 49.54460297861407, 50.71901944375808, 51.29523915629233, 53.89531950796805, 50.69607357825003, 53.98374149876257, 52.31616543185327, 56.47764721224385, 53.390322193022705, 52.943121002566436, 58.90067569671139, 56.34520446100543, 53.52721291203653, 57.94166403432047, 56.29314676407845, 57.99362759436331, 57.06772858096708, 65.02748850853213, 57.21897909718176, 53.193113265498994, 61.13235919706283, 60.25106537726618, 61.23642360010455, 59.55151850177396, 61.955688230453006, 60.258419821339274, 58.15044787622268, 55.13868731837119, 48.51796965445242, 52.82410844679802, 58.71258627983832, 61.313843342565725, 67.38837488235967, 66.17626836222988, 69.09109146364274, 67.21885004351216, 64.03629379887735, 43.9102594314083, 5.928403639024304, 0.9539956863849395, 0.5014288467505287, 0.6671567393406745, 5.589739824495008, 58.666596489567915, 68.41450614313926, 61.64271446966357, 57.00547272159208, 71.1357367423273, 63.66893245327858, 20.069334545443137, 56.665195342033144, 27.2994355617031, 35.67396456195463, 51.19272408946868, 67.09173387096774, 4.90646097929247, 0.1994065886303302, 0.12275978291947996, 0.04144642156578841, 0.1798994619879992, 0.030278355416451252, 0.28372951873367835, 0.030467192259346767, 0.07524776828264998, 0.10049169071980062, 0.02173960644511446, 0.07931610884805841, 0.15295932129506143, 0.02935999028024174, 0.4003699292098323, 60.87776207154798, 67.43885578647738, 56.87039021522769, 57.72770658616097, 35.51054685346542, 47.27391542926912, 33.42861160155266, 24.099403196765532, 57.321694204884196, 66.1041908879434, 61.133014232881614, 63.41106799341018, 71.33289075666859, 19.29032829500014, 0.323935559680385, 0.8104719942615879, 0.423230636384218, 0.5683234297940808, 0.3550382697534177, 8.496877531851492, 60.71542301485616, 62.042513816587395, 69.06026947882869, 70.51426072274485, 71.43472333108225, 66.83973727687713, 64.7864039482609, 58.74685210566367, 50.96301440269717, 50.336219649161066, 57.74622409574447, 58.47942882968534, 62.00139953244118, 61.79638901064473, 55.38542401406073, 47.75594334448538, 50.206232301650516, 60.54621981036279, 61.9476552163401, 61.84342215138098, 63.40635330446305, 61.62454212865522, 59.80478986617058, 62.41180104594078, 59.185165205309474, 51.877891555909194, 58.65374680488341, 55.816751372429636, 55.64042122133317, 58.01741676945841, 55.57838109231765, 56.73144025187339, 55.11497659067954, 57.1150480547259, 52.88444234478859, 48.866633061439764, 47.15529511051793, 46.99925145795269, 49.16832216324345, 41.604211714959916, 38.643873430067494, 42.47039656485281, 32.23302022103341, 28.257252862376554, 25.863795126638106, 38.085261237236764, 41.577131671290246, 48.75929740167434, 47.993156525396536, 46.17164704107469, 45.74625815114668, 49.912497766556285, 53.37570351939048, 50.23280243719778, 49.562696872218964, 53.748316918649984, 52.55109187095396, 56.23764522614018, 50.59700627480784, 36.44651066872382, 35.69572194930046, 33.31379598186862, 52.250552023610766, 63.055654187356275, 55.80297600838446, 56.0149016687947, 45.18863831796954, 49.28688364644205, 50.23548926076582, 51.24673512674148, 45.88951487695017, 46.60310776002946, 46.38658508177727, 47.04489607964793, 35.42090892791748, 34.78319429582165, 29.859947043080485, 30.33161793985675, 35.99577934511247, 41.63841478286251, 35.40435652579031, 45.02880957818801, 49.700026896692094, 46.333487956754624, 47.57873850484049, 48.866115308577015, 52.334988886310214, 52.82905455558531, 55.295723330590036, 57.43103027343751, 53.48927967010006, 57.85098275830669, 54.81988491550569, 57.602202507757376, 55.80399974699944, 55.30360729463639, 59.82018516909692, 58.29928613478138, 56.96824158391645, 58.40708463422714, 56.85478702668221, 60.87054098806074, 58.90783402227587, 63.57586245382986, 58.52021755710725, 55.891186191189675, 63.452131286744155, 62.55877617866763, 64.46451071769961, 61.07971706698018, 61.858562500246116, 62.75431025412775, 61.48261508634014, 57.05472592384585, 53.38138311139999, 55.77921428988057, 61.79983285165603, 66.52645757121425, 70.88999240629136, 70.14539318699991, 70.39256526577857, 72.92980532492362, 68.75229281763878, 49.303632167077836, 7.465721714881159, 0.9829994074759946, 0.8453481776579734, 0.7175102277148155, 6.1248133836254, 66.94144433544528, 75.58390848098263, 71.53715210576212, 62.24501794384372, 78.1200816554408, 73.14354312035346, 23.54856121924616, 64.93915673225158, 34.75951102472121, 32.92443013960315, 59.801910846464104, 75.20920445842128, 7.619163855429619, 0.5271313724017913, 0.24041147542095956, 0.04661017210192738, 0.16961319942868527, 0.04724223294385499, 0.5141559267236341, 0.07132170556653893, 0.1873961992321476, 0.27465272514570144, 0.21175687591875755, 0.211057391678614, 0.2080719623594515, 0.290092583745718, 0.6487075648000163, 72.14013022761192, 79.53743796194755, 66.84975501029723, 67.07592671917331, 45.49291618408696, 50.30017698964765, 36.69642448425293, 33.62652263333721, 65.00520944595337, 74.48055359625047, 68.44794042648809, 71.54131766288512, 78.5400890534924, 22.030664759297526, 0.39467807979353015, 1.672489693568599, 0.8449686270567679, 1.1414093524217606, 0.5203937210382954, 11.688608200319353, 66.46578634938886, 64.46402826616841, 70.36310042104414, 71.57162973957678, 75.98451583616196, 69.17603431209442, 65.40394975293067, 63.05612487177696, 54.21033682361726, 53.965247523400095, 59.978268454151774, 58.842879572222316, 64.69712295839864, 66.1033828796879, 55.37297833350397, 47.062942904810754, 52.54283920411141, 64.04727251298966, 64.42388672982493, 63.97568533497473, 65.63244350494878, 67.25182148718065, 62.278844464209776, 65.08557488841396, 62.547907290920136, 54.31054161440942, 60.77744353202082, 59.09740609507407, 60.37947200959729, 59.704247751543605, 60.81967961403632, 60.80004815132388, 56.58154687573833, 60.76506845412716, 59.86209177201795, 53.227371246584006, 51.96295599783621, 50.46932135858844, 54.732765151608376, 46.24363430084721, 43.362602418468846, 46.809902960254306, 39.93146596416351, 35.151869635428156, 34.340390082328554, 43.325806663882354, 47.88840570757466, 55.064899690689586, 50.100959808595725, 51.421276677039366, 51.30249554111112, 53.48270577769126, 57.00191905421596, 52.456201891745295, 52.87557778819915, 57.50120147582024, 56.999255764868956, 59.109836086150146, 53.01214687285885, 39.16114776365219, 36.47560681066206, 34.114822418459006, 55.57276425823089, 64.51616833286901, 58.680591506342736, 57.13796646364274, 44.52287873914165, 53.25186252593995, 53.404215228173044, 52.52776161316903, 49.055875655143495, 48.893709182739265, 50.467011082556944, 53.153975855919626, 41.57235814679054, 42.38600284822526, 36.13381539621661, 37.168395442347375, 41.41159196053782, 45.66042492466588, 39.87941611197687, 49.567811642923665, 55.38485527038575, 52.61782707706575, 51.73362285860124, 54.684912235506125, 57.86294990970243, 58.7105348802382, 56.26880845715923, 61.59277485262964, 56.60311991168607, 62.56904494377875, 57.58590113732123, 61.12772687788933, 59.51345582162181, 60.287013899895456, 63.79008662316107, 63.838771081739864, 59.94196299583682, 63.45774419846074, 58.10663892376808, 64.59217994443833, 61.249610608623875, 63.363191543086884, 60.44151998335316, 57.177480420758656, 65.77963044566494, 67.54570114997126, 65.02345238962482, 64.82141894678917, 66.5304740782707, 67.67012657657747, 62.631610670397365, 60.046066622580256, 55.249529577070675, 61.388901818183164, 64.64742260594522, 69.51864550190588, 73.19347489264705, 73.50947672320952, 72.78910206210229, 75.71598252942486, 61.14100802329279, 47.42522870340655, 10.337577212241388, 2.1217784429750135, 1.097861115009554, 1.302447653105182, 8.853695546427081, 72.79052196010467, 83.60208034515381, 73.8114756922568, 71.68411547137846, 81.34867868115826, 76.39455256923553, 32.87919148322075, 77.23614415814801, 40.07484820581252, 55.91869377320813, 67.1598340618995, 89.99311970126244, 12.067019843286085, 0.8448477077387995, 0.5136088786586639, 0.22082976245832062, 0.3213731181477347, 0.15553696201212946], [0.07497941534365378, 0.10201368525984789, 0.08818739935034707, 0.11410115076409233, 0.07536458136934428, 0.059749794252697504, 0.11342146989679146, 0.08262906373748857, 0.3113522284453915, 27.38515307826381, 71.81794674165788, 42.14846018821963, 37.05087730961461, 36.25690329459406, 39.72720461506998, 19.23922569521012, 35.905376557380926, 72.04117667290473, 60.85834633919501, 54.88819691442675, 56.867526885001894, 69.66348294288882, 32.62618095644059, 0.06819253517014366, 0.013142201951855134, 0.37378125433479586, 0.10096173162662214, 0.12645509995279774, 0.8797625632536028, 33.18518538628855, 62.870475169151064, 64.73796659900297, 66.21594705889302, 62.36881186885219, 62.1090332923397, 62.811659228417184, 51.99943404043875, 49.24671857587753, 49.41300745933287, 51.57104061495874, 59.64363928764098, 58.82465231803156, 57.22510583939091, 55.148214755519746, 52.44087326911188, 45.421682019387525, 54.10106351298671, 50.21143728686918, 56.31217810415453, 56.42202800320041, 57.852920409171816, 58.87254053546537, 60.70652315693518, 54.71249042018768, 51.637693451296904, 56.63350651341101, 55.4499940718374, 51.79175630692513, 57.11809181397962, 50.238074102709376, 51.046247097753714, 48.03496899143342, 50.22201199685374, 48.04315497798305, 48.01259971434071, 43.24005972954535, 41.589114512166674, 42.570766095192205, 38.12108032165035, 36.65700074165098, 41.78758252051569, 36.03818408904537, 34.45541358763172, 28.69353221308801, 33.33009735230477, 41.09367993570144, 44.178153391807314, 43.907466703845614, 46.033630601821415, 46.237444800715295, 45.45779528156404, 44.99509288418678, 45.77433055446994, 50.69163345521497, 55.36848721965667, 51.02389743251186, 46.525762542601555, 48.41703530280821, 38.125500832834554, 27.720460814814416, 33.86730909347534, 53.26675184311406, 51.35578093990203, 49.71348062638314, 51.994880168668686, 46.87425336530132, 43.92448586802329, 47.86135704286637, 46.70358711673368, 45.3474001730642, 42.56008155884282, 38.490281258859945, 36.861469976363644, 26.7940067860388, 18.503151747488207, 13.253893756097364, 18.567262887954712, 34.09552435721121, 33.706790016543486, 37.7954843736464, 42.66300455216439, 42.084239221388295, 43.8336084735009, 43.332772793308386, 46.21688373627202, 50.25346548326554, 53.02867574076499, 47.11449461598551, 53.000940661276545, 49.241592038062315, 52.47492728694793, 50.755340591553725, 57.29805800222582, 51.92630537094609, 54.57009269345192, 58.67609254775509, 55.74437972038023, 54.636906346967145, 59.46184919726465, 59.303256004087395, 57.74180358456027, 57.784926122234715, 76.7450241888723, 54.13081076837356, 53.745908583364184, 59.036746640359205, 61.1193290833504, 60.45177305898359, 57.858949092126664, 61.362500344553304, 59.62964427086615, 59.6365515647396, 56.64198275535338, 49.2579443993107, 48.04854039222964, 54.57053984365156, 59.46563428448093, 64.48470700171687, 66.91067726381364, 64.47210050398304, 67.6049760080153, 45.00162755289386, 21.951438765372, 3.929885433566186, 0.4681780874248474, 0.5530186478168734, 0.7196984812617303, 10.507513899956981, 69.59696738950669, 57.60993349936701, 49.778964596409956, 58.43806351384809, 83.6165774253107, 44.73685579915201, 21.20701409155323, 59.93270227985998, 29.423728489106704, 62.02849526559154, 54.2012643814087, 56.8008779710339, 1.6147786354826343, 0.07655232408714872, 0.0999474312148748, 0.07624961976562777, 0.07983466610312462, 0.018651768407453934, 0.12259976247385626, 0.12204655506197484, 0.015456463555775344, 0.12159454020401164, 0.07998952311613867, 0.06592363554743991, 0.13715615315783408, 0.0970526913841886, 0.22300194348058394, 31.849316320111676, 80.98958569188272, 47.23642149279195, 43.01273876620878, 37.34303505189958, 47.847915080285844, 25.853610692485688, 44.91137381522886, 73.93051178224626, 66.9079629836544, 63.42643191737514, 64.2610534544914, 74.2035871936429, 38.04040893431633, 0.0011113455571654825, 0.10129147885187019, 1.0018664370140722, 0.638499412565462, 0.13719254233423742, 1.2233966949485964, 41.31190492260841, 64.06166761152207, 67.15770029252576, 68.13544519485967, 66.01272121552499, 64.16667338340514, 65.15585199479135, 52.75894611112533, 51.57136224931287, 50.96723487300258, 53.855927144327474, 62.13205760525119, 59.983689169729914, 60.623980799028956, 54.438261831960375, 49.72964079149308, 46.06936731646138, 50.67766197266118, 51.97933973804597, 57.580774599506015, 57.68365052438552, 59.39933838382844, 60.92382246448148, 64.30041836154076, 57.231538526473514, 53.663401526789514, 57.113616389613, 58.59167137453633, 53.34253595721338, 58.2531512168146, 53.71332153197258, 55.34028145574755, 51.72348745407597, 52.29281556221747, 52.085734028970045, 52.22003990604032, 48.86724102881647, 47.13572248335808, 47.355249697162265, 42.93489540776899, 40.18785169047695, 44.19012054320305, 41.68808767872472, 39.362235915276315, 33.43027468650572, 38.414548135572865, 46.66963508052211, 46.7876591990071, 46.52919069413216, 48.72925989089474, 49.21923060570994, 48.534828001453036, 47.33300985828523, 47.524386221362704, 54.24520277207898, 57.13120821983584, 53.83308718281408, 47.44812357810236, 49.46569665785759, 36.82782780739569, 27.175696549877046, 33.31440002687516, 55.88405924458658, 52.57934862567533, 51.45920207423549, 54.51326931676557, 49.64364674783523, 46.32137175529234, 49.04519896353445, 49.02990956460276, 45.739696025848396, 44.44339582996984, 42.19499518794399, 41.82309566005584, 31.223629636149255, 24.23501914547336, 18.17943657598188, 24.595167252325243, 39.085571535172, 39.00985017899544, 42.53082067735734, 47.09011316299439, 45.55921208473944, 46.23389113333918, 45.922364727143325, 49.719226898685584, 55.027660708273615, 56.77235449514082, 50.340644082715436, 56.95053600495862, 52.82115097968809, 55.261155482261415, 55.37451590261152, 59.08019865712812, 52.29322741108557, 56.398552617719105, 61.66456207152336, 56.770914985287575, 57.75664583329232, 60.914906917079804, 62.17811015344436, 59.34134614083075, 58.660250094629106, 69.75453684406897, 55.84860494059902, 52.98019524543516, 60.94603876913748, 63.70064089375158, 62.87372289165374, 61.50956569179412, 64.88729907620338, 62.90273666381837, 60.973401223459554, 60.266978433055264, 53.41153044854441, 51.699411945958296, 55.67132949829102, 60.19712102028632, 69.51454270270564, 69.15986630224413, 68.2544812848491, 69.27337185029062, 49.946359588253884, 23.024159939058368, 4.992486892207976, 0.4124691848072314, 0.6883998058976666, 0.7393835088418377, 14.35895585244702, 76.28275717458418, 67.2234941297962, 56.85606571935839, 62.02386294641803, 92.23626828962757, 53.05079006379651, 22.233298324769546, 68.0260738249748, 26.966889173753803, 59.92302971501505, 64.1986995358621, 65.62199431080973, 2.3727486018211614, 0.2686596499575723, 0.09396674366848123, 0.15631486301220235, 0.12354593468649734, 0.009663773028390303, 0.3739047783517069, 0.24458107748819938, 0.21778218808674046, 0.26612245868290624, 0.22239512523576138, 0.14092498398836584, 0.21792524734572058, 0.37413178552542964, 0.4013876310519634, 38.346495013083185, 93.03939711663031, 57.073941615320024, 54.756617084626235, 52.48752986231158, 56.664905086640395, 27.262190695731874, 48.570364675214215, 81.46035640470444, 74.34010920986053, 67.98108423909834, 69.1818472646898, 80.12533849285495, 41.2890100479126, 0.20973434251162315, 0.4235823013849797, 2.2878376226271353, 2.027288177801717, 0.2035434174561693, 2.4112133249159786, 45.14314666871102, 64.78331312056511, 69.56378413784888, 69.80806150744039, 68.72591095585977, 67.94023667612385, 68.23285333571896, 55.58197006102532, 54.94498106741137, 53.90606680224019, 55.11204265779065, 66.18656850630238, 64.87910916728359, 63.25541265549199, 62.28921128857521, 51.98593716467581, 46.62036226641747, 53.92761630396689, 50.276336823740316, 58.755234210721916, 61.049503049542835, 61.702173679105705, 60.751010679429584, 67.3820520216419, 59.306484114739206, 55.92043138319447, 58.45503953195388, 63.09406595845377, 57.544618191257605, 62.489789532076934, 57.072584475240404, 59.73188084940757, 53.56858607261412, 59.55273443652738, 56.47387389213809, 55.39264117517779, 51.67300262758809, 50.85807531110702, 50.17207237981981, 46.9062206822057, 46.98192634890157, 51.25523098053471, 44.519972262843964, 45.072128234371064, 39.97523569291638, 44.068664350817286, 49.90411173912787, 54.37036560427759, 51.86495557908089, 53.47837155865085, 52.9628622916437, 53.63761586527671, 49.56092396090108, 50.16602016264393, 55.18383772142472, 60.859138657969815, 55.63013676674136, 51.778749727433734, 51.7289670052067, 40.747554302215576, 27.715367617145663, 34.10930756599673, 59.605109845438314, 57.57975086089104, 55.33604529596145, 57.016227860604566, 51.22070627827799, 49.71595564196187, 52.961112914546845, 51.797702620106364, 49.4371888714452, 47.05874596872638, 43.23450173101118, 47.853080841802786, 38.25091469672419, 31.624970474550803, 24.632971056046028, 32.157653839357444, 46.13346668981737, 43.42753725667154, 46.26635266888527, 50.8858339248165, 49.62887902413645, 51.09657895180487, 50.36526872265724, 56.329648340902025, 57.53840123453448, 61.62393416127851, 52.40759588056996, 59.34225613071073, 54.66015815734864, 58.3858528444844, 57.05425916179534, 62.62755886200936, 54.30638390202677, 59.927010920739946, 63.02735428656302, 61.25999704484017, 58.14616857036468, 65.63543235102009, 64.09931844280612, 63.970966723657426, 58.30168270295667, 70.2628367946994, 57.69996758430236, 53.675717769130586, 64.71317329714375, 64.46504023767287, 63.418277309786895, 63.41409998555338, 65.12554776284003, 64.71376557503977, 65.06497852263912, 64.3248272711231, 55.47497564746488, 53.5635732835339, 59.30266372619137, 64.71866853775518, 71.34473631458899, 73.91665012605729, 67.54581097633609, 72.09837267475744, 51.359538570527114, 25.947092540802497, 7.434182426621837, 1.043573550639614, 1.3800852096849874, 1.8279948782536293, 14.421802028532952, 82.03550138781148, 70.73306622043734, 63.774663863643525, 71.36330481498473, 95.80669987586238, 58.22218018193399, 34.620933686533284, 79.25900459289551, 43.13688570453275, 77.52332441268429, 69.93990021367227, 81.09123783726847, 4.8813141738214805, 0.6047955888413614, 0.3654160032108907, 0.2295441198493204, 0.1782643698876904, 0.11935652924641488], [0.06492549193001564, 0.0514433327161016, 0.030883656807183742, 0.019413887996286638, 0.06701405445534377, 0.04530673861623772, 0.10988207473870247, 0.015510258249818318, 0.5222609531014196, 9.698955532043211, 70.33001130627048, 51.57248796955232, 49.2742810710784, 31.0964055984251, 53.89890063193537, 24.57332749520579, 26.197157367583245, 73.15163104764878, 61.53690461189517, 55.16713234686083, 52.40546995593656, 66.6018533706665, 37.43146880980461, 0.23856288993791228, 0.03136752943147815, 1.4377735915683931, 0.25400342269530224, 0.12976740366749226, 0.15483232966113478, 33.29381542821085, 75.71248377523115, 63.61985575768256, 63.18264484405518, 59.38644555307204, 61.03997561239428, 52.23913008166898, 50.18162727355958, 47.21098099985431, 50.959331297105365, 53.0682328439528, 57.60579932120539, 56.3014425769929, 63.058968590151885, 42.34735573491743, 48.45871048588907, 55.17384352222566, 50.0045754063514, 56.87100994971491, 57.101127562984345, 60.23132408818891, 59.74406765353296, 60.226825129601266, 58.437169213448804, 50.81696887170115, 53.312270948963786, 57.81584224393291, 55.32016361913374, 50.28561715156802, 52.88117893280522, 50.591734609296246, 49.49843275931574, 52.76973655146938, 55.2839836766643, 52.73780453589655, 56.36319245061567, 47.239186763763435, 47.53061494519634, 42.83348252696376, 43.337146236050515, 41.50001787370251, 37.191074586683705, 30.528050238086333, 33.08802435475011, 40.87255631723712, 46.47779980013448, 44.62102428559334, 41.96469322327645, 47.06446870680779, 43.89489158507317, 45.59010859458677, 45.365093984911525, 45.652391910552986, 50.635822050033084, 58.08517179181499, 62.26954452453121, 53.618521767277876, 41.796984441818736, 47.10346098869078, 43.219926203450854, 32.78886910407774, 48.25619066915205, 46.9328849546371, 43.53599079193608, 50.72333405094762, 53.59471298033192, 50.249272469551336, 48.22123842854654, 44.94970321655274, 48.05273732831402, 41.163266704928496, 42.52814954326999, 42.757498371985655, 36.822242352270315, 26.779133158345378, 25.305810513034945, 22.415353175132505, 23.950060913639685, 34.24784568048293, 41.114441041023504, 42.09013454375729, 41.78747661652104, 40.55016494566395, 43.62614647034676, 45.67010533425116, 46.83326459700062, 50.24136889365412, 52.3886743668587, 54.502569090935495, 52.43885717084331, 54.308686333317915, 53.675239239969564, 51.27221092101067, 55.09250925433252, 49.736234295752745, 51.058759458603404, 57.41421899487896, 57.73992084687757, 59.527552820021114, 57.39725474388369, 60.1661656748864, 56.904138288190296, 51.29668651088592, 53.26526918718892, 52.419245319981734, 50.63257040516023, 55.727309565390314, 57.11163559267598, 59.964555848029356, 58.65881058477587, 60.389128884961536, 57.75748129813903, 57.37903925680346, 57.40612714521347, 54.5908655658845, 50.20038012535342, 48.68822797652214, 53.07269257883872, 64.25451094104399, 63.5000273489183, 64.33004794582244, 61.71519987044796, 66.58938023351854, 34.926521624288256, 1.0157220257866768, 0.4578825398798912, 0.19215072475133405, 0.6036187552155987, 21.058877937255367, 74.51986359011742, 44.69441575388755, 50.83536086543914, 69.3736982345581, 66.5003110516456, 23.472271119394613, 43.8566602430036, 50.940115605631185, 48.67543320502005, 63.858237804905066, 55.31167168771067, 54.57187737188032, 0.7209429757729654, 0.030936903748360854, 0.06519780554358037, 0.0622064083994877, 0.04287903279727025, 0.06819310973608686, 0.014179213040117777, 0.05173347319566435, 0.08286422974760495, 0.03814954303144928, 0.11766161334009902, 0.04791502285027697, 0.13109593802402097, 0.0818528481308491, 0.5645035315425165, 10.66900376350649, 81.73493016150691, 56.09209783615605, 50.115578482227946, 37.74913764769031, 57.75827361691383, 23.005101142391084, 32.35689651581549, 81.16544123618834, 66.71373505746165, 62.588354772137066, 62.54933895603303, 72.68516709727626, 40.4373340452871, 0.25246297309715904, 0.029752731000283555, 1.35761039631982, 0.6333763068241458, 0.11170721027038752, 0.2388076550297199, 37.040212385116085, 77.09726087508663, 66.31244520987234, 67.50260214651784, 61.68330707857686, 63.40757316158664, 54.449118952597345, 52.68097331446987, 48.83068061644032, 54.055881730971805, 53.341382780382716, 61.079615085355705, 56.125571343206595, 65.6079130018911, 42.927560575546764, 46.37539063730548, 52.69581948557208, 49.97478108252249, 56.36784830401021, 58.842612851050596, 64.18182549938079, 61.85677389944754, 62.003027316062685, 60.94454434610183, 53.657443446497766, 55.581134596178615, 60.48951018241144, 58.17312702055901, 52.3990176570031, 57.648772808813284, 55.10139342277281, 55.10420576218636, 56.28512943944624, 61.09334730332898, 54.1791892820789, 57.565226324142955, 51.86366119692403, 50.23658752441407, 47.79764990652762, 46.6073949106278, 46.42226296086466, 42.75323083323818, 36.43687732758061, 38.49557645859257, 45.4761205950091, 49.72251384488998, 47.4221614099318, 44.73796975228095, 48.691201133112756, 46.19081174173663, 49.73552434675155, 46.02196547292894, 48.32379271907192, 52.041128835370465, 59.419797466647246, 62.848235330274036, 54.551277083735314, 43.786124260194846, 50.198371871825195, 41.22085102142827, 30.241250453456757, 47.90832350330968, 48.56584218240554, 47.039589112804784, 52.36209638657109, 54.46192941358013, 50.12823597077401, 48.925339175808816, 48.97542784290929, 49.58894929578228, 44.85587619966076, 46.55636879705614, 45.71512237671883, 41.41472985667568, 32.11842033170885, 31.328794264024307, 27.60246023055046, 28.409799721933183, 38.680916293974846, 44.433413397881296, 46.91320642348259, 46.53519584286598, 45.84373689466908, 47.89193976309992, 48.32361229004399, 51.24310693433208, 54.08727638183102, 55.67142363517515, 56.510320555779245, 55.199578192926225, 56.10643409913587, 56.71403669541883, 52.68416612379013, 56.87823495557232, 52.09158620526714, 52.50674555378576, 59.215453747780096, 58.83142232894898, 62.31427915634648, 62.14389139606107, 61.940469434184415, 57.36399696719263, 53.286477442710634, 51.61370423532302, 53.64832393584713, 54.162464295664144, 58.92827741561398, 60.197270070352864, 63.150351970426506, 61.527604672216604, 63.22633612540461, 60.75778853508734, 59.94270824616956, 60.89702483146422, 60.19022941589356, 52.56148222954043, 51.42219843402986, 56.17592280910861, 66.10821523974019, 66.08656375638901, 66.06330410126718, 64.36470208629486, 68.85683967221168, 41.38796360261979, 1.556635013511104, 0.39840013329540536, 0.03210354840473062, 0.5269408310132643, 25.424852486579653, 81.81534659477973, 53.319335137644124, 51.57652016608946, 76.49928769757672, 76.83223416728359, 27.169161881169966, 43.71873009589411, 61.50991086036929, 41.70180028484714, 62.40851409973637, 63.595972445703325, 62.19158741735644, 0.9527510080126025, 0.052162053424023816, 0.035641903598462386, 0.02482911646966973, 0.09498957063882582, 0.04720919923256001, 0.10896992449077869, 0.2183138377844326, 0.26256385770055557, 0.13695539215639715, 0.14253877884437963, 0.09451927692298928, 0.21489492527419524, 0.29671838627226893, 0.6238940995066398, 14.16280302309221, 95.18882459209811, 67.18912632234635, 69.91576979237219, 45.07028079801991, 72.28075504302979, 33.06201119576731, 39.94504128732989, 82.96312624408354, 75.87143390409409, 69.41099997489684, 66.59518534137358, 79.55846186607116, 45.06604071586363, 0.635799350998094, 0.08032238065835931, 3.172057285424202, 1.675348243405742, 0.24247583722875965, 0.686186853676073, 42.69706641474078, 79.41084738700621, 69.91598944510184, 68.38868125792473, 63.30657605201968, 65.90514629117905, 58.77847425399288, 53.598435309625444, 50.09986154494747, 54.08058874068722, 57.87963175004529, 63.6161804968311, 62.00855001326531, 66.31983495527699, 52.569997695184526, 53.18270721743184, 51.75781211545391, 52.7675792478746, 57.34559712871429, 60.80968933720743, 63.90432957679995, 64.76926319060787, 64.94626406700381, 64.67374563217163, 54.53563467148812, 58.569145202636726, 63.96122747851957, 62.39023585473338, 54.25422814584548, 58.68933054708666, 56.45700770039713, 60.02532512910905, 60.093009548802534, 65.93483863338348, 58.566780013422814, 63.67217625341108, 54.5137046998547, 54.522859511836884, 52.65438748944191, 50.14814592176869, 49.82598597003568, 48.09673455453689, 43.917433446453465, 44.30245722493818, 50.281985036788456, 55.898689685329316, 51.4990141314845, 49.89683574245822, 53.86348555164953, 50.34341719842727, 51.94010819158247, 50.79703538648544, 50.81140695079681, 56.914893427202784, 62.09131986864152, 66.12774864319833, 58.696210384368904, 44.43369188616353, 54.10153811977756, 44.815970005527625, 31.86330153096107, 49.63453115955476, 51.70935123197494, 48.70560015401533, 57.74099949867495, 59.18784418413716, 54.52864500784106, 53.08307117031467, 49.899036192124896, 53.44711419074766, 48.1538168076546, 49.40593542591218, 49.684831634644546, 46.84772637582595, 37.883282707583525, 38.6603513071614, 33.0823016166687, 36.29872752774146, 43.127362189754365, 48.705054944561375, 49.56046112122075, 50.68337686600224, 47.51277600565265, 52.40902754568285, 52.733034933767016, 53.812781072432, 57.37941580434, 60.34227617325322, 61.50152483294087, 60.591483962151315, 58.801663306451616, 57.76758924607308, 56.35290799602386, 60.26044768671836, 56.09187033868606, 57.691503109470496, 61.60537742799329, 62.41953595992058, 64.50163595138058, 65.40675424760389, 64.05075557770269, 64.70697202990132, 55.122256509719364, 62.307599359943026, 60.19035885410925, 54.232847306036184, 62.11123766437654, 61.209249419550744, 65.79236245924427, 63.105699708384854, 66.46505678853681, 62.06778172523745, 64.24916475049912, 66.16996903573313, 62.49880313873292, 54.9960817060163, 54.623382014613, 58.55406368932417, 69.47733509925105, 69.7645781117101, 69.68625622410929, 65.69884138722574, 68.80031047328826, 45.18837944153817, 3.392489831293783, 0.7446361753729083, 0.5663031027201684, 1.3023058349086394, 28.562605457921183, 89.89277762751426, 59.5966963614187, 62.09218279007943, 80.2028759064213, 81.61084990347587, 36.36387025156329, 55.48897458660988, 68.94288862905195, 64.37384120879635, 81.74424971303633, 69.92519132552609, 80.790282218687, 1.8536412956253177, 0.23031351727343377, 0.25636668136763957, 0.21515767811046493, 0.14843106750519047, 0.21447230520988667], [0.06264123224443005, 0.04894740293703733, 0.02552129031579581, 0.022992999067590125, 0.06697977968161145, 0.04784133285284043, 0.039424343980968966, 0.01897619323684804, 0.16056881135990544, 2.5940881957930904, 62.95255860974712, 52.73201119515204, 43.99613972633116, 18.13981083131606, 45.74582669042772, 31.33666842214523, 24.738914274400283, 61.47187563680834, 67.0391191974763, 51.13928571824105, 46.1926160320159, 63.64646511693155, 43.729289116397986, 0.7280022002035572, 0.05226804168834802, 0.12140124089895718, 0.5416130695131518, 0.13159539670713488, 0.032275016119162885, 23.819553852081302, 74.47761966336158, 62.308175948358354, 64.64239412738432, 57.21456250836773, 53.36485424349385, 48.344604815206225, 51.81356468508321, 51.173892790271395, 55.91021360889558, 53.929342146842714, 61.598917284319484, 58.40044798389558, 62.20891252640755, 41.915314505177165, 34.40764304130308, 52.178082312307055, 52.76189573349492, 63.092591147268976, 58.437883084820164, 64.00630727891, 59.558370882465, 59.07111052543887, 53.22687310557212, 50.25564239871118, 52.51675152009534, 56.14639128408125, 57.327542458811116, 53.70019728137601, 54.60226005123508, 51.09421376259097, 52.45673141171856, 53.25460426269039, 54.393656638360795, 53.344595201553844, 52.30502982293406, 49.69892471067367, 46.18632062788933, 42.703726599293375, 39.683317215211936, 45.346184238310784, 43.09785027657786, 39.203885909049745, 39.64628219604492, 37.82847542916575, 36.274424522153794, 39.557099265436975, 42.33059544717112, 44.95726554624496, 43.81292581558228, 45.41912855640535, 44.148766994476325, 46.55925566150297, 50.49520115698538, 58.71676752644201, 59.444528010583696, 56.76035204241353, 47.134985077765684, 45.553661930945616, 45.91403361289732, 50.61964227307228, 44.21594542841758, 44.81536988289126, 43.79964859254899, 53.32923127758888, 62.365058160597286, 54.55814907627722, 48.081394164792954, 46.05869062485234, 45.95822695762881, 44.507452057253936, 42.46799607430735, 41.98270082473755, 37.813954814787834, 40.183117389678955, 36.30167322774088, 35.04474186128186, 30.802017988697177, 31.596511717765566, 35.51965851937571, 42.98232078552247, 43.327732547636955, 43.72500588816982, 43.19481518960769, 49.332677318203835, 49.32425598944388, 50.20625975824172, 47.611706026138805, 51.37167438384026, 53.11865099014775, 53.89008706615817, 51.60485929058444, 51.22701344951507, 56.87320647701141, 50.31023394676947, 50.04746652418568, 54.14858302762432, 56.08105636412098, 59.092228566446614, 58.36272654994842, 59.51010611749465, 59.85340764445644, 58.4753966331482, 29.898021490343158, 42.41483619136196, 58.371171412929414, 56.756276699804495, 63.512680915094194, 60.52517237201814, 58.53004309438891, 61.28842638384912, 59.631542698029556, 58.695068974648755, 58.30573451134467, 57.68679234289355, 54.68656747571884, 52.7463553028722, 47.230114321554865, 57.333426014069595, 58.1033637446742, 65.90098857879639, 64.76542711257935, 65.83175090051466, 34.99737531908097, 0.7645341753959657, 0.7048374786973001, 0.17896550887775037, 0.4643468510720038, 35.499344564253285, 62.87124787607501, 52.95891246488018, 66.18775306209442, 73.04458956564628, 35.48552997650639, 26.45724188896918, 61.839221292926425, 35.46665160886703, 52.89152222294962, 46.959443323073856, 70.17583077953708, 33.28264844033026, 0.23207274626099297, 0.03890293304838481, 0.03263054986394221, 0.008601750127009807, 0.01210107984426882, 0.012073064008877884, 0.058109787698354454, 0.0356300943531096, 0.014688243034235654, 0.005096288833526834, 0.11019282298342836, 0.0020054219954369233, 0.08730021590787558, 0.05104263425774632, 0.196919085818433, 3.469958358233975, 72.57912974203788, 60.55781041422198, 40.74508713137719, 23.50653498403488, 54.210434882871574, 31.270511765633863, 28.06574509989831, 64.99080650268063, 74.98876725473713, 55.7359113231782, 55.308863270667295, 69.60973862678775, 49.532690740400746, 0.8544437863653707, 0.2759429091407407, 0.31697102371723423, 1.5732711337266432, 0.08798477675525412, 0.13249279210163703, 29.024225281130885, 77.63175441372779, 65.48562918939899, 66.54039767480666, 58.64169336134388, 55.74310495007423, 50.04171240714289, 54.647720321532226, 53.274227880662494, 59.035138468588556, 57.28560055455854, 65.35808155613562, 61.92257165908814, 65.12037023421257, 45.64035415649415, 37.07217970202046, 55.0931917467425, 53.44536481365081, 63.634839211740804, 60.84372374319262, 65.56770870762487, 61.05388825939548, 61.41373826611427, 54.63776142366471, 52.1978549803457, 55.399038560928844, 58.04547348330098, 61.40260265719507, 55.40394544601441, 56.61699725735573, 55.21408311782345, 55.90682860343687, 56.938678679927705, 55.40987999208512, 55.277072460420676, 55.91574022846838, 52.58122744098787, 48.4399184103935, 48.12355179940501, 43.65781176474787, 48.98226845648981, 47.54871276117141, 43.16668395073184, 44.68132288225236, 42.39178049948908, 42.810622953599506, 45.11554887217861, 46.76814540739983, 47.98577070236207, 46.42940951931862, 48.88717451403218, 46.01568575828306, 49.469701397803526, 54.02527939888739, 62.12613874866117, 62.310254804549686, 59.15677116763208, 46.997957075795824, 48.08321806692308, 48.79260224680747, 52.71486651512885, 47.13172951052266, 48.66659610502182, 45.60496261042934, 54.60128730343234, 63.83767674046179, 56.52611986283333, 50.66546340142527, 49.027442393764375, 47.607462021612356, 47.060263925983065, 43.71497246526903, 44.11206929914413, 41.14304296432003, 42.83104281271658, 40.256136232806796, 41.119591113059755, 35.703723584451986, 35.2626177572435, 40.22787555571526, 45.26668956202846, 46.0618834341726, 44.937077106968054, 48.18994968168197, 52.63976097106934, 52.9329385295991, 54.48046653501449, 51.225220926346324, 53.85975145524549, 56.78134848994594, 56.98674732638944, 54.272922162086736, 54.39286039721582, 59.06836486631825, 51.63643437047159, 51.35977391273745, 55.286474381723714, 58.31126113091746, 58.21414324545092, 58.374003364193825, 60.457487952324655, 60.73541141325428, 59.96052365149222, 32.58726516077596, 45.27360470064225, 60.20141209325483, 58.831955771292414, 65.31429221553188, 62.700946407933394, 61.64894711586737, 63.556089785791215, 62.300845038506296, 61.7822253319525, 61.51755163746496, 61.346963836300766, 58.4052489649865, 54.4290207278344, 48.98104075462588, 58.98365736007691, 61.768336219172326, 67.3547758594636, 68.70615005493164, 67.97255700634372, 34.94163843893236, 1.319847409763644, 1.119536377729908, 0.1415411485058646, 0.6741192528317053, 42.350713283784934, 70.36084113582488, 59.118877149397335, 66.3662758181172, 82.98453454048403, 36.72947045295469, 32.855582737153576, 65.41325361497941, 46.08975971898725, 50.76016510686567, 48.890720336667954, 78.78629622920867, 39.70993441920127, 0.2384508572398655, 0.04586759541604308, 0.024986087885354797, 0.07908773803783041, 0.056871988795577526, 0.05348856913887205, 0.1379836200466079, 0.1590445108952061, 0.1510564814652166, 0.09597518105780888, 0.2893170576182104, 0.21177133965876796, 0.2365447079101878, 0.24412893239528904, 0.417746304864845, 4.601447178471473, 85.57814690374559, 68.57643727333316, 63.186814323548354, 27.518341079834972, 63.80326578694006, 41.48858808702038, 38.67958661048643, 71.80064124445762, 79.93296977012389, 65.03973807058027, 61.42062987050703, 76.41560785232052, 53.80241032569639, 1.348756258526156, 0.2743545943690885, 0.6969424829848352, 2.621845583761892, 0.30248206409235157, 0.18208132636162544, 34.74799494589529, 80.16333841508435, 69.0149268796367, 69.4325259424025, 63.02574219242219, 58.13226376810382, 52.297141936517534, 57.66304631387034, 56.03427817744594, 63.269140951095096, 58.496699025554044, 68.4190482477988, 65.63756612039381, 68.52748609358265, 47.739590983236994, 39.147035075772195, 58.030435116060325, 56.17498144026726, 68.26571495302262, 63.03632082477693, 69.18971553925546, 64.2849995243934, 62.11450107635991, 57.486053282214755, 54.08022396026119, 58.60932204031176, 61.565486923340835, 64.31657068191036, 58.121877331887525, 57.82577760757939, 58.0273639002154, 60.306786567934104, 62.310545059942434, 59.9720867987602, 58.84882588540354, 60.38661072331091, 56.733566176506784, 53.28058604271182, 50.930203776205744, 49.99487538491526, 55.321630585578184, 52.21992615730532, 48.478314492010306, 51.3972560821041, 48.35121793131675, 48.00316641407628, 50.42353553156699, 52.52028165325042, 53.52149409632529, 52.084408267851806, 51.839134616236535, 50.010659002488666, 50.914118136129076, 57.198892639529326, 65.70548980466782, 64.22918419684133, 62.41777481571321, 49.25369255004391, 49.681717272727724, 50.31083799177601, 56.069304943084724, 51.60218423412692, 50.618657758159024, 49.858070958045225, 56.02279739995157, 69.18216105430358, 61.662577352216175, 53.433699684758345, 52.36414778617121, 51.361691951751716, 48.82191019673502, 48.56810538999496, 48.957745798172496, 45.99764285549041, 47.9503163983745, 46.86867183254611, 47.748785018920906, 40.99968425689205, 41.67489674783523, 46.64668529264389, 51.537198405111994, 51.23300683113837, 49.343122589972715, 51.942587129531375, 55.005444403617616, 56.81661059779506, 58.19615917821085, 53.83980228054909, 59.63530032865463, 61.663220620924434, 61.506082627081106, 59.571032293381236, 56.503668215967, 62.60445610169442, 55.18686186882758, 55.33889293670655, 57.26751058332382, 60.99648829429381, 62.060611632562455, 62.1815186931241, 62.50573004445722, 63.926840059218875, 59.28313816747358, 41.66819341721074, 48.92383690803282, 60.60012102127076, 63.61800047659106, 67.45215262136152, 65.60165682146626, 62.20064024771414, 67.84942596189438, 65.32278806932511, 65.17943720663747, 65.13581260558098, 64.53680784471574, 59.158853946193574, 58.144925179020056, 51.662741707217315, 62.23791453146166, 64.77272664347004, 72.42032081850114, 72.36522720706078, 69.24141237812658, 39.36025119596912, 2.2953043445464107, 1.3433247564300415, 0.3689637563882336, 1.3245035083063188, 47.252044293188284, 76.42364086643343, 63.914645410353145, 77.79035937401557, 86.95176878283101, 49.07224762824274, 40.57236556083926, 76.07514612136349, 51.99105585775068, 66.07292175292969, 63.6124110990955, 86.24229046606249, 57.22339568599578, 0.42094168824053585, 0.12818294231809918, 0.13833481007285658, 0.15159456630147275, 0.16118195749098257, 0.11103536648255204], [0.026358124544663776, 0.12178178741446427, 0.047354181372230096, 0.018547771971732862, 0.012911095250127538, 0.07588643280248489, 0.029548315759447795, 0.10213513317848406, 0.05591158266930331, 0.11470947820212572, 54.26190030190253, 49.04167275274954, 53.44208963455693, 22.249244720705097, 34.577666021162464, 28.464463833839666, 29.961134387600808, 68.81423488739999, 61.73356440759475, 64.01854115147745, 42.39284738417595, 61.341872599817094, 47.66712127193328, 1.2804772320293611, 0.5168823417155973, 0.5342276142008844, 0.24337533170417433, 0.2941962409644358, 0.0898753515174312, 24.49310718044158, 70.2812562450286, 63.810067176818855, 63.59938098538307, 55.95109647320163, 54.85976365304763, 53.71276847777828, 58.35099474076302, 57.903871997710205, 61.88675257467455, 58.43993448442029, 58.81487777156215, 61.16790763793453, 62.8031280732924, 53.13345401517807, 50.86766942854851, 57.63572308324999, 64.50351476669312, 61.359001590359604, 59.96945488837458, 57.31580280488538, 56.74494889474685, 52.71118733190721, 50.53080843340967, 53.29597350089781, 52.332615852355964, 55.306564761746316, 59.21271985576999, 54.21957400537307, 53.30350837399883, 56.28379191121748, 49.61968891082272, 50.236312958502005, 51.41743667664067, 51.910090292653734, 52.31464355222641, 53.33414208504462, 49.93096036295737, 48.57151000730453, 41.948615427940126, 34.30445332680979, 40.352249991509225, 38.8155085040677, 35.22235462742467, 30.246959463242565, 30.984488610298406, 31.898353792005974, 37.379960244701756, 44.22087584772418, 46.65013305602535, 45.292067297043346, 45.87350376190678, 47.094031610796534, 49.007187274194536, 56.80791862549321, 55.079859610526796, 50.26953543386152, 47.08120546033306, 46.20091968967069, 49.255465461361794, 46.877348115367276, 46.29304439790788, 45.92380423699656, 50.89890326223066, 55.43584216025568, 65.40679739367577, 60.03877101405975, 47.66543465275919, 46.014057974661554, 46.02034553404778, 39.54293558674474, 40.10517989435504, 46.85306864400064, 46.344054821998846, 42.11961507797241, 34.83905669181578, 34.81328279741349, 25.763188292903287, 20.653752011637536, 25.9607365054469, 37.98524864258305, 40.611875595585, 45.24768960091376, 42.829469942277484, 51.90657192660917, 51.25492503566127, 53.45286830779045, 43.93001248759609, 51.23175951742357, 52.35207080841065, 53.86194406017181, 56.690259287434245, 52.73028142990605, 54.346090055281124, 51.55433524039484, 51.0725034436872, 52.11888590166646, 54.403780275775546, 58.4183967498041, 55.52355812441919, 59.44109201431275, 54.043530187299176, 59.487728995661584, 34.65955726562008, 48.93692585729784, 60.890509774608, 56.89934122946955, 59.847018103445734, 60.39633820133825, 62.342563367659054, 59.54241468060402, 60.95001605249221, 61.768638241675596, 62.22426076089183, 61.58787188991424, 57.46009895878454, 56.116765622169744, 51.690108083909564, 55.432323794211115, 58.24405916275517, 63.09784712329988, 60.42634825552664, 71.91674340155818, 24.709088571609993, 0.557964634030096, 0.9889892344513248, 0.10052464016142393, 0.5688863512008422, 51.31924406174691, 53.14241270865164, 56.75783780313308, 64.14846574106525, 71.79778575897217, 29.215364340812933, 34.30512405210926, 54.21652632374918, 30.868657096739742, 47.75437439641645, 48.01114843737695, 69.33355669821464, 17.928681412050803, 0.2782925927350598, 0.08509354560726112, 0.043816927429889484, 0.028724520347051086, 0.037973181930400675, 0.045680700606035615, 0.021057267252716328, 0.13533056563427373, 0.0031604071527028517, 0.025654783051821495, 0.050211635703641566, 0.056900544722955075, 0.026243785921964916, 0.03162573745113707, 0.026181832391528354, 0.13984640879977134, 62.14066720777943, 59.79304628987467, 57.08359064594392, 24.27157171310917, 47.7344605230516, 32.63071913872996, 37.76607836446455, 76.93096806926113, 68.66722445334159, 68.98563461918985, 48.44277389587895, 69.43531082522485, 51.37976231113557, 1.6768452404968202, 0.8382711187005044, 0.635369238593886, 0.6455180036925501, 0.2085481166479088, 0.01902903989708472, 26.659241991658366, 76.14323062281456, 65.15189432328748, 68.47603244166221, 59.091530384555945, 57.79812882023474, 56.937819680859974, 60.84079765504407, 60.1878995280112, 64.29884549110167, 62.064820335757354, 59.69963504422096, 63.28679161687052, 62.41597052543395, 54.74009998383061, 51.56229372947447, 59.14638080904561, 65.01986342091715, 63.077917560454345, 61.349627125647764, 59.94772887999012, 58.22118389991022, 55.77917898854902, 53.322700531251975, 53.085997258463216, 54.90392561881773, 57.94836344257478, 61.37450279728059, 55.291573462947724, 56.22570160896548, 58.85509775530908, 54.935720351434526, 54.01781905081965, 55.46327521724086, 54.60823774337769, 54.66131917891964, 55.330436306615034, 55.20819171782463, 50.95579724158011, 45.42587503310173, 40.09831182418331, 45.34444270595428, 44.371781195363695, 40.723859264004616, 35.734051350624334, 37.15145080320297, 36.46688345939883, 41.59955586156538, 47.94296195430141, 49.40644141166441, 48.560809781474454, 48.84324789047242, 49.28068237919962, 51.52295627901631, 57.397443017651966, 57.06773250333725, 54.45139784966746, 47.597463900043124, 46.802776013651204, 50.40231158656459, 51.12991909826956, 48.69372713950373, 49.65791240815194, 51.000641699760195, 56.70437197531424, 65.51568238965928, 61.92613709357477, 50.58583928692726, 49.17248379799628, 48.13511102430282, 41.781389098013605, 44.780186222445586, 49.49833077769126, 49.66865578005391, 46.31937134650446, 40.56947869639243, 38.200072934550626, 30.746198738774947, 25.679135822480728, 31.054196973000806, 43.38267318664059, 44.56392242062477, 48.49656528042209, 45.384937255613266, 56.81670865704937, 54.80384242150092, 56.81732839153659, 47.98898312353319, 55.07188150959631, 54.72353973696309, 57.182634415165076, 57.0896154065286, 53.30370449250745, 56.192910594324914, 53.40143426772087, 52.937664985656745, 54.150571669301684, 57.463072115375155, 58.801180854920425, 58.05520880606867, 62.31670318111297, 57.913858352168916, 61.567930559958185, 37.45036678929483, 53.260248553368356, 63.45983874413275, 58.21812445117582, 61.81597732728528, 62.61458758384951, 63.14779850744433, 62.700730677573915, 61.72133053502729, 64.22796041734757, 65.04268377057969, 66.36215732943627, 60.48755684206563, 60.38006428749331, 54.41165247271138, 59.34801417012369, 62.22825373372724, 66.73746539700416, 63.36494484255391, 73.81809665310767, 26.177763208266228, 0.3967670483454582, 1.2655155961551976, 0.07677973728747138, 1.1886742807203725, 59.65197432425715, 58.91618082600256, 63.83111069279333, 69.22613082393524, 78.47222420477098, 33.33780480969337, 38.740661836439564, 60.00573289009833, 40.23037018314485, 45.79296181278844, 54.13823581510975, 81.96460846931704, 22.250741104925833, 0.4184006971697654, 0.06665189405001941, 0.06469374267204155, 0.012846565749045583, 0.036914525027837486, 0.022637829214574832, 0.13326549902558327, 0.25347309066883983, 0.20388564425370387, 0.11079286901100029, 0.11989302061978849, 0.21555961380081795, 0.21263386273095686, 0.1940216953235288, 0.15828775392184335, 0.34209224185155285, 76.3960744488624, 66.78887198048254, 73.79455458733344, 34.64355007294686, 57.59426363052861, 42.00652137879403, 41.399052143096924, 81.32497972057712, 76.4142507122409, 77.48079807527604, 56.162810325622566, 74.97725902065154, 57.57726407820179, 2.283523015437588, 1.038352263069922, 0.9178966428003005, 1.422454774860413, 0.6760996207594873, 0.2507971302275696, 31.84058120173793, 74.49200691715365, 70.67960431498867, 70.3462028503418, 61.701569634099165, 60.39023499335013, 60.44015107616302, 63.36786700833229, 60.66393406160417, 66.896117425734, 63.58804533558508, 63.881199359893806, 65.8711628760061, 64.90456142733174, 56.192945895656464, 53.62329136940741, 60.836992955976925, 67.97210201140373, 65.93047695775186, 65.78170537948608, 62.051947116851814, 63.04505202078051, 56.98712387392598, 55.14636731916859, 57.38127108543151, 56.62986263152092, 60.035919450944476, 64.11452939433437, 56.75661010126914, 57.733366566319624, 62.374134525176025, 58.07597383376091, 58.76585206677837, 60.23655260762861, 59.11601774154171, 60.044532975842884, 61.88162603685933, 58.45851867429672, 57.79786602143319, 50.459338926499896, 47.494023153858805, 51.86617151383431, 50.84551588181527, 45.964655722341234, 41.543936652521936, 43.12170220959572, 43.718330014136534, 47.669058922798406, 51.84848554672734, 54.31307938791091, 52.00065781993251, 52.9791558173395, 53.22556303393457, 55.56488421655471, 60.44519524420462, 61.031271872981904, 57.82626005911059, 51.94154770143571, 50.01061977878694, 51.84434744619554, 52.77223117889897, 51.89911942328177, 51.688915683377175, 56.422765408792806, 61.23592938146284, 70.0442195707752, 66.30895430041899, 53.563577205904075, 52.902810804305545, 50.66761678264987, 47.137118847139426, 48.14482673521965, 53.85706070930728, 53.202252388000495, 50.251606279803866, 46.79690030313308, 45.418583346951394, 39.83160634194651, 32.83189946605314, 38.19934729606875, 48.5145728818832, 49.033879003217145, 53.94854999357655, 52.30548481787405, 59.441958858120834, 59.09355432756486, 61.3653911313703, 51.17626974659582, 60.560265817949855, 59.16850689918765, 62.75056831298336, 62.39428374075121, 58.24015640443372, 59.30789616800124, 55.135518043271965, 55.593368468746064, 56.63438120195943, 60.900123503900346, 62.86104971362699, 59.81640792662098, 64.49454430610903, 60.48537208187965, 64.555615609692, 41.43498105387534, 56.5769890815981, 66.92975567233178, 58.97034483571207, 66.51125446442636, 66.1414534045804, 66.5412135278025, 63.74797605699109, 63.94766000009353, 67.06186894447573, 67.51385150417205, 69.39155286358249, 62.4250586571232, 62.06937420752741, 56.135322355454974, 62.47328419839183, 65.91197121527888, 68.97587576220113, 67.4150626890121, 74.07567870232367, 31.27916647541908, 0.7820233498369494, 2.4970852848022216, 0.25938358157873154, 1.5191399738673241, 62.81212206809752, 66.29018183677428, 68.54936507440382, 75.9356980169973, 83.61997419787993, 41.779090589092625, 45.91073097721223, 69.8862971028974, 46.095066685830396, 59.70114123436713, 64.87059762400966, 92.11560049364644, 36.217620757318315, 0.5718246967561784, 0.2071948529731843, 0.10929806293138575, 0.16439431737507545, 0.16769747399995405, 0.1602516662810118], [0.05566272283754042, 0.039569667029765346, 0.027099659350971063, 0.04023199600558128, 0.05547358338991481, 0.0737773314599068, 0.027851611037828752, 0.03162877882019647, 0.2349359232691988, 0.14401849299188585, 42.4179191743174, 60.653022027784786, 40.60199906749111, 27.417459680188088, 32.40471216940111, 30.244145162643928, 15.191480882706182, 68.00297890940021, 62.67014795734037, 64.0593965591923, 54.7372248864943, 58.431799488682906, 58.13510748647875, 5.21464797758287, 1.014074752888372, 0.5963846788771692, 0.5534213649169092, 0.46846926212310797, 0.12190668272875971, 18.92394361957427, 67.2239883484379, 64.40326682982906, 63.996838677314024, 59.55254224038894, 57.47280351577267, 58.195362937065866, 59.68389457271945, 58.57566810423329, 61.09640282969321, 63.79174970811414, 61.58068610775856, 62.738008883691606, 56.30303898165303, 52.92369742547312, 51.89709548027285, 59.096433347271336, 61.54804806555472, 59.14783993074971, 60.319495047292406, 55.63720487779187, 56.79484536570888, 56.08455119594451, 53.610308324137044, 52.920284963423214, 51.21083759492444, 52.27906373239333, 54.518823392929576, 54.10732361578173, 51.470914271570024, 55.195883320223906, 52.98665538910897, 51.97356600915232, 46.09681214055708, 53.91145221648678, 49.861134329149806, 53.58103567554105, 53.825528775492025, 48.9104655481154, 46.34481968418245, 44.690426703422304, 37.81402933982111, 41.37422353990617, 34.86834502989246, 30.396795965010124, 35.128425628908225, 36.64910893286429, 35.24411201477051, 44.725582907276774, 43.22498213860297, 42.13307273003363, 42.17599130445912, 43.96687884484568, 49.795352258989894, 55.61760087167063, 49.40089125787058, 51.019394551554036, 52.25398409751154, 51.297745550832445, 45.808784654063565, 46.37131921706661, 45.45235495413504, 44.662420980391964, 46.84365887795725, 51.5768692570348, 57.9436997444399, 55.665143920529275, 46.96307543785342, 47.936662627804665, 45.576556805641424, 29.481318689161736, 18.74284778871844, 29.653314621217792, 24.015376221749094, 27.59309361057897, 28.818846056538245, 21.786783549093432, 21.208532048809914, 23.287350977620772, 32.63473956815658, 40.46160174954323, 43.429776930039935, 42.401908059274, 46.444247845680486, 51.812568403059444, 50.598634058429354, 54.60020080689461, 51.26236184950798, 51.23183012008668, 54.82624699992519, 53.328391890372004, 53.00679675994381, 53.55950186329504, 52.18899826849661, 49.06866650427542, 49.86468799652592, 50.89937002428117, 54.40573753849153, 56.00507613151304, 59.4415666211036, 61.729669494013635, 69.89174919743692, 63.62815941533735, 46.30450556355138, 58.070458981298636, 59.82761806057346, 56.918960925071474, 58.05486755986368, 59.00996077445246, 58.76685227117231, 61.055618024641475, 62.40212848109584, 62.65390150008663, 61.261801335119436, 64.40413759600732, 62.02911892244893, 64.6963777080659, 58.68670648144138, 57.34489502445344, 58.150220378752685, 64.18483395730296, 61.24567254897087, 65.9933525516141, 15.263756436686363, 0.3908390293438589, 1.031544499339596, 0.26692087551759136, 3.1455356892078155, 54.699515219657656, 59.06805499907463, 61.46093222402758, 55.04273437684583, 75.43904750577866, 19.186120725447132, 43.87895499506305, 50.97482858165618, 32.836498445080174, 51.254030735261985, 55.333770321261504, 59.81883195138747, 5.639978522254575, 0.23924265507488485, 0.09713792632664404, 0.022125682200215036, 0.10289243407427304, 0.05723943520757941, 0.026166916659642613, 0.024660910374575087, 0.05860655358241451, 0.03493132257473565, 0.03874825606603296, 0.06293284361280742, 0.0383551150650507, 0.0092095039567099, 0.08365636466131096, 0.21472039512328564, 0.1097586043479462, 49.051686563799464, 68.38569241185343, 46.19214534759522, 27.723775217610022, 39.12867838336576, 26.98200598839791, 21.1915324964831, 74.34329417444046, 66.42151063488376, 71.53055467913228, 55.81831247575822, 63.78109262835596, 64.76275597849201, 5.2747254506234205, 0.35886680947676786, 0.659088914192492, 0.8980039134621621, 0.814811729135052, 0.18825849247795923, 23.08645109976492, 72.14478215863629, 68.36239353302987, 64.31438592172438, 61.48779653733777, 59.957672088376945, 61.284303972798014, 62.691458194486565, 63.16049521969211, 63.227905073473536, 64.98843739109655, 64.32180704609041, 64.49553274339246, 57.13340082476216, 55.53165389645485, 52.306002570736794, 60.82593187209099, 61.56929554477815, 61.56285893532538, 60.75732961777718, 57.83544232768398, 58.39200704328476, 58.849139675017334, 56.30352143318423, 55.07647852743826, 52.81943690392279, 53.65554501933437, 57.394379646547385, 55.336943518730905, 55.71134159641882, 58.33625055128529, 56.95697261441139, 55.91713659224972, 50.34997932372555, 56.35700687285393, 55.603201850768066, 54.218565956238784, 55.06003987404608, 52.2881636311931, 50.83511767848846, 48.047124416597434, 42.874683103253766, 46.67610699130643, 40.06606209662653, 34.63231640477335, 40.62306219531644, 42.87851918128229, 39.413258106477805, 48.97612602479997, 49.373230703415416, 45.97805846122004, 45.19720477442588, 46.5825859192879, 51.31600810635475, 56.76744368768508, 50.2298528148282, 53.12763714021253, 51.94635652726697, 52.57040562168245, 46.751714598747995, 47.395234338698856, 47.45852178142917, 46.4187995080025, 48.64412092393445, 52.68553895335044, 59.735607101071274, 55.26066518598988, 48.908700481537856, 51.835247547395774, 48.058534591428696, 31.65814784265334, 24.527796622245546, 37.32470189371417, 30.83289096432348, 33.123831672053186, 33.52151686145414, 26.223307809522076, 25.414226785782848, 29.734189971800777, 37.4378034376329, 46.12937565772764, 48.29706568871775, 48.813786968108154, 49.65759077379781, 57.49369013694025, 54.130477366908906, 56.91294400922714, 54.03622673403833, 54.55789804458619, 56.41981186405305, 56.70261867584721, 56.557400764957556, 56.85112745531144, 53.37305199715399, 51.11262929054999, 52.290466062484256, 53.21968732341644, 56.74152466558642, 59.7630048567249, 59.71360652677475, 63.74933711944088, 69.79024610211773, 63.5309434706165, 50.083383667853575, 60.96704306141023, 61.054943376971835, 60.4957506733556, 60.09553555519351, 62.3050811982924, 61.37495386985041, 64.49056310038414, 65.09284696271344, 64.54576653818931, 63.19151332301479, 65.29764175415039, 64.6459517171306, 65.23225584337789, 61.319848491299545, 61.34856024096089, 61.497884873420965, 67.46672030418151, 65.91315577107092, 68.43671460305491, 15.688749167226977, 0.39853003116384633, 1.325523324551121, 0.4913776506099009, 3.728174850825341, 61.334074927914536, 65.58719504264094, 66.97844797565092, 63.49332009592364, 79.37225910925096, 22.895541498737952, 49.76825652583953, 58.46508079959501, 37.872425586946555, 51.36586927598523, 59.18747940371114, 69.96952979795395, 6.72557536632784, 0.2947284575671919, 0.160115180056422, 0.1510669309045038, 0.1320645795954812, 0.039111787768741774, 0.020593402929784312, 0.1082730985757324, 0.12154385582694124, 0.1636670547867975, 0.038245307852423964, 0.2583519982234124, 0.11313354341132988, 0.0806771942804898, 0.2562824423394857, 0.28232675045728683, 0.21940707589589784, 58.76822117836245, 79.436154519358, 56.99962054529498, 40.01300027293544, 48.623042106628425, 44.9021170216222, 26.611593038805072, 78.85738526621174, 72.87972450256348, 77.75402253673923, 64.05162634388094, 69.94408146027597, 71.30763069275888, 8.07119446416055, 1.9212346427863645, 1.2312647243661266, 1.9172985443184454, 1.0338067263364792, 0.21493491506384266, 28.955781882809056, 74.10723024798979, 72.01898390246977, 69.25052796640705, 66.08728547250071, 63.80498378507553, 64.11408616650489, 63.71802876072546, 66.95503927046254, 68.26017656633931, 71.1596239766767, 67.62290123970278, 66.43905147429436, 63.03293189694805, 57.97585141274237, 55.501443801387666, 60.530746060033, 66.23351143252465, 65.78869504313316, 64.78408582748906, 60.748637645475334, 61.25589032326976, 62.675360787299375, 58.09224382523568, 57.488795018965206, 54.566248770683046, 56.92937874024915, 60.22617401615266, 56.80598881936843, 56.51658458094443, 60.37947200959729, 60.98430149016842, 60.615477100495376, 54.76686231551632, 60.25680380482828, 59.02903526060043, 59.40738316505187, 58.49558507242511, 56.8419804880696, 55.072960161393695, 51.17397908241519, 48.036836039635446, 55.8740258216858, 46.743944383436634, 42.871615809779016, 47.56135456023678, 48.91547049245527, 46.22446960018527, 55.386290857868815, 53.65857308910739, 50.65681849756549, 48.909041727742846, 48.033749134309836, 52.500218729819025, 59.769319872702326, 55.19663249292682, 55.771381316646455, 54.2986293761961, 57.429786882092884, 47.98771227559736, 52.6336459959707, 51.71275584928451, 49.883123136335804, 52.692940465865604, 55.92775837067635, 64.66402207651447, 57.987857787839836, 51.85586744739164, 54.675251437771706, 51.7826642528657, 36.55927488880773, 30.67196592207878, 43.76955616858698, 38.74687094842234, 40.16252102390413, 39.336242368144376, 35.85994374367499, 33.571068163841005, 38.07384321766515, 43.40147702924667, 51.02657641133955, 53.7293718707177, 51.799879535552, 53.87903774938276, 62.20555105516988, 57.81211991463938, 60.81620831643382, 58.402299342616914, 58.23440228739093, 60.02325411765807, 58.387158993751775, 59.200674256970814, 58.83290498487411, 56.055470743486964, 54.7211863148597, 53.44898908369003, 56.160425524557795, 59.00004110028667, 61.82851714472618, 62.50280787867885, 67.89414098185878, 70.60798968038252, 61.13667772662256, 51.406340291423184, 62.890938174340036, 63.40061879927113, 62.497700952714496, 63.49798379405853, 64.73988463801723, 65.43512475106024, 66.39347353289205, 66.92326807206678, 66.84900975996449, 66.44058904340191, 68.88141724371141, 67.24134875882056, 68.65019352205339, 66.08040563521847, 62.539403592386556, 64.27378546807074, 70.54473753898375, 69.84937191009521, 72.87257794410952, 18.975193308245753, 0.5450755417827637, 1.7036437315325585, 0.467696218120475, 5.263589841704215, 67.1822621745448, 71.088315286944, 73.73223597003569, 68.96296331959387, 84.29759502410889, 31.243929862976078, 55.438262262652, 65.44611915465325, 47.57234504145961, 66.25219760402557, 68.63171915854178, 86.57080465747465, 13.437709750667697, 0.5804667814124016, 0.520796683286467, 0.22938189307047477, 0.2767218366986321, 0.11102226637904683, 0.11916637090184998], [0.02654816031516079, 0.10388677789559288, 0.09647895281593646, 0.049655961488643964, 0.024239968042820696, 0.09618985421595075, 0.14333719567906472, 0.12803145609195196, 0.06721849267881724, 0.5622983627742337, 27.48801919721788, 60.3538824665931, 45.85318980678436, 39.375787704221665, 41.844358828759965, 35.99678739424675, 13.22900337557639, 45.94966442354264, 70.17283408872544, 58.768076050666075, 68.23332402013963, 52.61578744457614, 64.45474401597055, 12.539703692159346, 0.5005724830252509, 0.5371072467777037, 0.2807311118850785, 0.3396973284261842, 0.21163865323028258, 15.86501754099323, 65.77194260012719, 61.317922607544936, 62.52416518426711, 58.55673482341152, 59.08867097670033, 61.63241040322089, 63.42552584986534, 62.94272522772513, 64.97144568351008, 62.73231752457158, 62.68120119648596, 57.76328640599405, 51.72719801625898, 54.5629971258102, 56.52753583846554, 59.73342234088529, 60.16552632854831, 58.92552783412319, 57.564924301639685, 54.51435973567348, 54.00240413604244, 57.91694525749453, 56.539824624215406, 59.44526933854627, 55.739876839422415, 52.4050110386264, 53.31003519796556, 53.504051316169004, 49.47793053042505, 56.658456710077104, 53.43238569075062, 54.65674177292855, 50.096868776506, 51.436773961590184, 53.33953534403155, 52.387885970454064, 54.05161419222432, 54.61742001195108, 46.79051468449254, 44.562243646191014, 45.271639593185924, 44.26396308406707, 38.244321192464525, 37.69356158471877, 44.76796803935882, 46.83319791670769, 44.753090489295225, 42.01952403591525, 46.20782306117397, 44.33178086434641, 41.487650640549205, 45.10465252783991, 51.41072942364601, 58.70539657531246, 57.04732833370086, 62.2128309742097, 59.76335394767023, 65.07580034194454, 57.822361223159305, 55.74678413329586, 63.68710087191675, 57.64423462652392, 56.70977307904152, 49.66557279709847, 48.54547723647087, 53.26612818625666, 47.81101342170469, 47.548136172756074, 42.04752975894559, 38.28884401629048, 32.49060423143449, 29.29767135650881, 25.305467305644868, 26.010501577008156, 24.909676621037146, 19.740726217146843, 21.340247200381373, 26.516550087159683, 38.24785132561961, 40.9567892166876, 42.50324249267579, 45.789796460059385, 47.10591247004848, 47.802862736486624, 50.660713411146595, 51.18808000318466, 51.05258564795218, 50.977444802561116, 52.64666434257261, 54.2256340672893, 53.95243314004714, 52.88611719685217, 52.680530086640395, 47.03652574170021, 52.85055306649978, 54.38136785261093, 59.30852766959899, 59.51957079672045, 55.4717710710341, 59.08247755419824, 50.85294877329181, 66.49470990703952, 68.80292277182303, 57.875438736331084, 60.31478820308563, 52.42128495247134, 53.68223282598681, 53.62640573132423, 57.046465412262954, 57.411869495145744, 62.30228454835954, 60.97288739296698, 62.683527161998136, 62.71109750193935, 64.64701075707713, 59.496248383675855, 61.38638757890271, 61.23603136308732, 61.58358081694573, 59.33740808117775, 59.55391114757907, 62.15901605544552, 6.624180626484656, 0.5030493065714836, 0.8431918546557428, 0.7140821987582792, 10.341553515003575, 61.91007498771914, 60.04885542777277, 57.841400407975726, 63.343218834169456, 59.3810679835658, 19.658240733608125, 65.898862654163, 38.448417802010816, 37.16777570786015, 31.957216801181918, 55.7894830549917, 47.442977428436286, 1.7867415951144312, 0.11881308179468879, 0.07625876685544368, 0.014397004176111472, 0.0754759092665007, 0.06710580880603484, 0.01831349079316903, 0.08619170966407946, 0.08931317321595647, 0.042248377726683696, 0.06979763492821686, 0.014518628294970241, 0.04702623445360411, 0.06354613913102977, 0.20155040907763666, 0.08690902843110024, 0.5228434863590425, 31.668999079735052, 73.0577765741656, 47.78505909827448, 40.75271614136235, 55.65158036447341, 35.21867152183287, 14.385411258666748, 64.6044530407075, 73.56401335808539, 65.71647636352047, 74.68713698848602, 58.23962296209028, 71.62804911213537, 15.038992858702137, 0.6492077895710546, 0.832232445959122, 0.4081749861999866, 2.2120236004552534, 0.2678097520143755, 20.0397990980456, 70.69680783056444, 63.068044954730624, 65.69695080480268, 62.036559658665816, 62.05017420553393, 63.90176826907743, 64.58297021927373, 65.41373214414044, 67.46463360324984, 65.90953934577205, 64.43511255325811, 60.03896713256837, 54.13659626437772, 55.88500845816828, 57.39927084215226, 59.840722699319166, 61.59621869364093, 61.79240780491983, 57.74408640400056, 57.21983417387932, 56.327616553152765, 59.25755646920974, 58.402636666451734, 60.09481776145197, 57.99039948371149, 54.087476422709805, 53.32462249263641, 56.57474156348937, 52.398794081903276, 60.09586895665815, 54.62656697919292, 58.01785999728788, 51.83141539173742, 54.617235660552986, 56.967951328523704, 53.63773353638188, 56.49378776550294, 57.0123133351726, 50.23883112015263, 49.09312640466998, 50.71841539875154, 48.188592541602354, 42.824884691546046, 43.035939585778024, 46.98354236541256, 51.42979214268347, 49.57795881455945, 45.94173731342439, 50.123995888617735, 47.5127681609123, 44.80871754307901, 49.0915927579326, 52.671234069332, 59.00575991599791, 57.16738423993511, 62.85609968246953, 59.87401185497161, 64.46228673381191, 56.99633752146075, 55.556639394452496, 61.39493834587836, 60.067192508328354, 54.94180394757179, 49.92224093406431, 52.331972583647705, 54.96127459310717, 50.20491046290244, 48.77446520713068, 44.393871984174176, 42.09424518769787, 34.5804391368743, 34.68298166028915, 29.059236357288977, 32.68231399597661, 31.822365714657693, 26.586644803324056, 25.538607105132073, 32.1091478486215, 43.80444957363991, 44.90523922827936, 45.85325256470711, 48.30016043878371, 49.4572086488047, 51.305162752828295, 53.70246833370578, 53.96490235482493, 56.14468505305629, 54.21719704904864, 57.171436048323116, 58.15978311723279, 55.40855030859671, 54.26914884198097, 55.13500029040922, 49.50702667236329, 54.210917334402765, 55.59722415862545, 59.80546843621039, 60.206358202042125, 59.24871936921151, 61.62899009643063, 53.58767624824278, 68.1364885453255, 69.70371861611643, 58.3978670643222, 62.19993029871295, 53.45395872669836, 56.5085986352736, 57.01104640960694, 60.46740762649044, 60.979567189370435, 64.32204238830074, 63.90760083352367, 64.21875853692332, 64.44277294220464, 68.33456039428711, 64.73972382084017, 64.87533192480764, 62.121118114840606, 65.6194761491591, 64.30649803530785, 64.18708932015204, 65.05522358802058, 7.265598956615695, 0.463980415896062, 1.1711194678660364, 0.7188294311204265, 12.560916850643775, 68.70699728688886, 67.44444124160275, 62.96218802852016, 68.33172059828236, 64.27132614197271, 24.150025306209443, 69.79645913647067, 42.921731933470696, 48.01261540382139, 34.834334158128314, 57.989289452952725, 59.815921552719615, 1.695619542752543, 0.13059533020902064, 0.26795037511375647, 0.02866864955473331, 0.08850641368377594, 0.053922879704905134, 0.016191865828248764, 0.15804329526520547, 0.2237011825725917, 0.2064507364505722, 0.19772553125456457, 0.18930772649905375, 0.14402285969305423, 0.4242774189239548, 0.3751542983997253, 0.2155958650813949, 0.6765626443009223, 39.91052442981351, 82.97990614368071, 63.285563915006584, 53.99734820089033, 58.33269688390917, 54.22149988912768, 21.4190907632151, 62.422807216644294, 80.36585823182138, 72.84200699098649, 79.500732421875, 64.38836574554443, 77.38233873921057, 16.43367590442781, 2.5258791590890577, 1.5015124745907322, 0.4803393348570793, 2.3259606092206897, 0.25990565517737024, 24.170949189893662, 72.58962600461899, 64.79367994493055, 67.838513928075, 63.04578158163256, 64.08691983069143, 66.9265942419729, 66.98390791493078, 66.94036176127773, 69.11934037362376, 68.52539154791063, 68.413862874431, 63.63343108084894, 56.94449163252308, 59.443727847068544, 59.49382828127954, 62.42547442836147, 64.36893040134062, 62.79623646889964, 61.843339781607355, 58.620155626727694, 59.96260643005372, 62.59924719410559, 59.34955958397158, 66.17945332680979, 62.341739669922866, 58.23208024424892, 55.555713715091834, 59.18098788107596, 54.379677311066665, 62.747779507790845, 59.21276692421206, 59.72251422943608, 56.358940601348884, 59.67500255953882, 60.40359850852721, 58.21217029325424, 63.260264627395145, 62.31445174063406, 53.20541774072955, 52.23189330870106, 55.35735161073747, 55.01104947059385, 49.58370900923207, 48.853242089671475, 54.761696553999386, 56.63022348957678, 52.73295648636357, 53.541913955442375, 55.52047906383392, 52.9445997361214, 49.33379911607312, 53.55560302734376, 57.23697100916217, 62.328744857541984, 61.87483641409106, 67.77672875312068, 63.99613657305318, 68.13876352002545, 60.257349014282234, 56.85723458566974, 66.49205054006269, 65.27597065894835, 59.372999668121345, 56.31572000442013, 54.9854560052195, 58.00399441872874, 52.12876242976035, 53.54465176982265, 46.55068920504662, 43.95616685190509, 39.963025354569965, 40.68118387652982, 37.7444778719256, 38.323105919745664, 39.54977227795509, 33.63113926303002, 32.72299681940387, 37.51542714334304, 49.06374392970916, 49.76863699574625, 50.985007132253344, 53.69608663743543, 52.50510208068356, 55.36396080447782, 58.194939321087254, 58.153966242267245, 59.26266731754426, 59.252182822073664, 61.41198104427707, 60.11689286078177, 59.53557014465333, 58.55471480277277, 56.612278646038426, 52.012299414603945, 58.0233826944905, 58.578986429399066, 63.98966466226886, 62.35775470733643, 60.272787463280466, 63.11125770691903, 60.1430433027206, 67.75437124313848, 68.97156899975192, 64.09361139420541, 65.14266498627202, 57.35390470873926, 59.11829663861183, 61.15356745258455, 62.81036092389015, 64.0047069518797, 66.50721442314887, 68.16097982468145, 65.79820679080102, 68.09049483268493, 69.64314153117519, 67.64507047591671, 66.40541322769658, 66.55720110862487, 67.35852564534834, 66.3312961209205, 67.31099436360022, 71.08784460252332, 9.946386487253251, 0.6750176594622674, 1.8362199659309082, 0.9968241075834922, 13.803528624196208, 76.20765163052467, 72.70677151218538, 68.22916630775698, 76.94093088949882, 70.06541605918639, 30.993382584664133, 76.51505562566942, 53.601498680730025, 51.014974040369836, 47.705411449555434, 66.23433513026085, 72.70891312629946, 4.216553328498717, 0.4286312804587426, 0.4335399735118113, 0.2877783853440516, 0.2537323654659333, 0.20525620619375862, 0.11386255268007518], [0.11388153633883885, 0.05206854473198614, 0.05802202083530927, 0.07267618732106301, 0.05712996507363935, 0.043160608413839535, 0.0762985191578346, 0.19958902480861834, 0.20290635406009613, 0.48768510681486904, 13.884198050345145, 63.340865412066066, 48.13364013548821, 39.57495389446136, 25.048267687520674, 42.17570889380671, 14.972720492270687, 21.799992130648707, 68.59005574257144, 59.57211878991897, 59.70334952877414, 56.671965352950565, 61.26224456294891, 29.22684119593713, 0.23788971315708854, 0.5885494380227981, 0.06959811498921725, 1.0322926914499653, 0.25744473561644554, 11.075907503404926, 63.58387585609191, 62.18794745783653, 62.012954834968816, 58.178673251982666, 61.83470272248792, 64.33810057178621, 65.97920848477271, 69.07548043035692, 66.77202932296261, 65.5130700911245, 57.55048213466522, 52.365453935438595, 55.84661237655148, 60.561548432996204, 53.5934695889873, 59.536178112030036, 58.61518990608954, 60.87602446156164, 59.94575200542327, 62.25509059044623, 60.1318645477295, 57.67215013504029, 63.09302260798793, 59.435663453994266, 52.59271606322258, 53.66528426447223, 54.26107268179617, 54.00800528064851, 50.55329145923738, 53.358268583974535, 54.30181826314619, 54.345642905081476, 55.93041773765318, 51.579560002973004, 54.29484428897981, 54.06116516359391, 56.067288844816154, 55.81313886950093, 52.33260016287527, 49.039099677916504, 42.71170077785369, 46.852601881950136, 43.6867392447687, 41.4086344934279, 44.04974675947621, 44.798354641083755, 45.51314776943576, 45.31889238665181, 44.596988001177394, 43.628703855699115, 43.568216985271825, 46.61518081541985, 56.519181189998505, 62.27498877433039, 65.16066082062261, 63.357343289159964, 60.17648150843959, 58.65783391460296, 53.224288263628566, 51.28101271967734, 57.00011868630686, 60.27842783158826, 65.15227871556436, 58.59882185536047, 54.68782263417398, 52.31923664769819, 46.59141125217561, 46.350832677656605, 43.410455334571104, 45.44638510673277, 44.99249235276253, 43.25169740184661, 43.418715846154, 33.54649843708162, 27.98947657308271, 25.614624600256644, 32.67705409757553, 38.3582660459703, 42.4041320431617, 44.19495682562552, 45.90294115005001, 48.44312690919446, 50.31159500921927, 51.11681445952385, 50.11280536651612, 52.234615433600645, 49.842522682682166, 51.576884946515484, 51.04423492185531, 54.71711489462084, 51.114257074171505, 54.10263638342581, 52.33358075541835, 48.41691370933287, 53.307065963745124, 54.61637666148525, 57.00928134302939, 57.83980400331559, 57.30565563324959, 56.73735126372307, 52.13658363588395, 40.53401654766452, 61.34015067931145, 58.042861184766224, 57.33824660701137, 50.07384054122433, 51.58885209791122, 50.23858401083177, 50.492753597997854, 54.141550217905355, 58.30246325462096, 56.2682044121527, 57.703289831838305, 57.25365284950503, 63.709340710793775, 68.09983791843538, 76.99965661571872, 64.14135056157266, 63.401069871840946, 60.47694683074952, 63.01456735980127, 48.75840310127505, 1.5085102281262799, 0.3377029257676294, 0.4686567085164209, 1.2017162841173912, 21.76193533405181, 64.05864738648938, 52.838225057048184, 66.15097691935878, 69.18578532434279, 48.24538846169749, 25.503486202609157, 49.49452215625394, 33.89446366217829, 31.4765146470839, 29.21989663954704, 62.59131223924699, 38.513776256192116, 0.6741337165717156, 0.16233485852999074, 0.03779037036902962, 0.05441962643676708, 0.006853867380414159, 0.029760483810077273, 0.17777384378977362, 0.0219303087121056, 0.04017113031999719, 0.05994417374172519, 0.058984077881060304, 0.07817298309096406, 0.050199286366302165, 0.14250796678806507, 0.3016504909723036, 0.30964526197602676, 0.6862330640996657, 15.815270120097747, 75.2522171697309, 54.34581548936906, 47.211643880413426, 29.866262059057917, 49.97755812060449, 13.57330902930229, 27.915135891206805, 79.92539959569132, 64.93592077685942, 67.18705531089537, 62.79045097289547, 68.21845823718657, 32.03889427646514, 0.2999883866117847, 0.5384464910434139, 0.6041669677342139, 2.1358837764109335, 0.3333666842551001, 14.508363835273252, 67.61489960455125, 65.00974370587257, 65.35208817451232, 59.931702075466035, 64.39617910692769, 67.23856387599822, 66.85621123160085, 69.99927705334079, 61.250877534189534, 59.03322827431464, 56.36878575048139, 54.6268258556243, 58.97336898311492, 60.16089400937481, 53.21569435058102, 60.64322786946451, 60.31922440375052, 60.20149054065828, 61.88543465829665, 65.05058342410673, 61.38404592390984, 61.98116010235202, 65.88908026295324, 60.31367424995669, 55.55370938393378, 56.11641653122441, 54.45439454047911, 55.61319604996712, 51.638795637315326, 56.75430766997799, 56.50515871663248, 55.409291636559274, 57.29340607120145, 55.53255604159448, 56.249565309093846, 56.583680645112075, 57.719265645550145, 58.30915089576476, 55.94175338745118, 52.34920355581468, 46.97286959617369, 50.39657315900249, 46.0778239465529, 45.79950824860604, 48.4391966942818, 47.731193188698064, 49.52565008594144, 50.38108371919202, 48.85062586876654, 47.57842863759687, 47.460847746941354, 48.331770820002404, 56.5862694094258, 62.91963031215053, 63.95466143085111, 62.7956324238931, 62.528460179605794, 61.746959301733206, 56.63569127359698, 50.92610882174585, 59.47337704320108, 61.79411403594479, 65.92414625229375, 57.94711220648981, 56.34220384782361, 51.64438893718105, 49.36935932405534, 47.90484436096684, 46.16852483441753, 46.87433181270477, 48.70402336120606, 46.346745567937056, 48.94773983186292, 38.3352574225395, 34.03578273711666, 32.061404758884066, 37.72279893198321, 42.4390999732479, 46.5845274925232, 47.46957109820458, 49.46340599367696, 52.317248006020826, 53.00941690321892, 53.80524619933098, 53.665021465670684, 54.5553171250128, 53.6246955779291, 54.18186041616625, 53.47369609340545, 56.89812921708631, 53.46137592869421, 57.173687488802024, 55.44478124187839, 51.98746688904301, 55.298559204224624, 56.72868674801242, 60.448019350728686, 59.50065712774954, 57.96331944004182, 57.815999138739805, 53.021921419328265, 44.73605955800703, 70.41049834220641, 61.33154892152356, 60.67413614642236, 53.55528139298963, 54.410773861792784, 53.89222475790209, 53.02442781386837, 55.864070846188454, 62.17883579192623, 58.907171141716745, 58.7917907007279, 59.001606125985425, 64.56859473259219, 61.92841206827472, 72.39864580092892, 66.50573176722374, 66.19839053000173, 64.87621445809641, 67.81915310890444, 50.854078415901434, 1.6259817827132441, 0.448438790176184, 0.5862544224627557, 0.8978138623699066, 25.827332773516257, 70.36118630440005, 61.10836605871878, 68.21766591841175, 75.97099934854816, 56.66982373883648, 30.834355969582838, 56.50506850211852, 39.12681133516374, 42.39666385035361, 35.64468406861828, 70.27954609163346, 46.23321648566954, 0.37359414502016963, 0.1842263265843353, 0.05979323526844383, 0.10095275307614958, 0.0761061238365308, 0.03543529351572356, 0.17626486508355987, 0.24377619487143334, 0.18559416125137962, 0.18061439056069623, 0.15902473050500118, 0.2142049098807958, 0.12986331787561217, 0.31627054356278916, 0.3069153536231287, 0.37218344007288257, 0.7728644929105236, 20.544916045281198, 91.59592566951629, 65.36776196572089, 59.34995574335898, 37.5301399538594, 58.95507112626107, 23.754320913745513, 32.82729460347083, 79.72750033101728, 72.7904042889995, 72.42873038015058, 68.08533299353816, 72.93763437578755, 36.2364952025875, 1.395801901817322, 1.3126274294430211, 1.3646234716138532, 5.497536178558104, 0.6039479278749036, 19.316827827884307, 72.80827460750457, 67.36579771964782, 66.76889142682477, 63.11496826910204, 66.41923566018382, 70.75128955225792, 68.3511677095967, 71.989762244686, 63.288611596630474, 60.34915208816529, 56.22987501082882, 57.03937768936158, 59.515860234537435, 61.82069201623241, 54.06956688050301, 62.08744848928144, 64.82372922282066, 64.57599232273718, 63.71454961838261, 69.2321869634813, 63.57152039004911, 64.67210215906944, 66.84016089285574, 64.920364656756, 56.04289954708469, 56.61668346774194, 58.96504571360927, 57.87302255630494, 54.92969559084985, 58.03762482058618, 59.95697390648627, 61.75241924101307, 61.59967822413291, 57.774104302929295, 60.61116249330583, 60.74565664414437, 59.572781670478086, 63.10682150625414, 58.697657738962484, 54.83106367049679, 52.37937442718014, 54.75854689075101, 53.281182242978005, 50.67933290235458, 53.16715894206878, 54.29294193944624, 56.61094504017984, 55.607606672471576, 52.92379156235726, 50.70171002418765, 49.745451865657685, 52.894969986331084, 60.98052032532231, 68.2998081945604, 66.86339701375654, 67.12376394579488, 65.26774152632683, 63.74728571984076, 57.78509478415213, 53.35138090195195, 63.735181285489, 63.73416539161437, 70.52609843592491, 63.48933496782857, 62.33116103756813, 55.42300816505186, 52.12021950752505, 49.520366653319336, 48.91519984891338, 50.1324878200408, 55.84972281609812, 52.379056715196185, 53.22560225763629, 43.4127224645307, 41.5325500119117, 38.981660104567005, 43.281217159763465, 48.87186158087946, 53.240570022213845, 51.61865818885065, 53.173803437140684, 56.09660463948404, 56.290067703493186, 58.51578135644236, 56.701026193557254, 57.75974058335828, 56.4131320676496, 58.44735168641614, 57.012038769260535, 57.60698387699743, 54.92530645862703, 60.40359850852721, 56.73037728955669, 53.60917083678707, 57.52280196835918, 58.93864816234958, 63.982949564533854, 61.911871433258064, 61.57553211335213, 59.94401047306677, 54.07939241778467, 49.77120614820912, 65.19102388812651, 66.4164900010632, 62.118996112577385, 57.015478687901656, 55.88573801902033, 56.26072052986392, 56.438184245940185, 58.500884194527906, 65.37075865653254, 61.72541372237667, 59.62322335089407, 60.92754479377501, 68.31823548962994, 65.85996058679396, 74.625791118991, 72.1676888004426, 69.76567637535834, 68.46083717961466, 70.95431927711734, 57.13605234699865, 3.4039524678261053, 0.5007131367681489, 1.4283529164329654, 2.5136067982642882, 27.95973716243621, 77.16754974857454, 67.88912819277856, 76.58012774682815, 82.69378492909094, 59.67905436792682, 36.00528324803999, 56.10967789926837, 49.583944351442405, 44.42552551146477, 45.5094450519931, 75.86937858212379, 64.82567079605596, 1.0475944703625095, 0.565343102620494, 0.18555110711003506, 0.22818094299685573, 0.3162038939133767, 0.16991316881631652, 0.3088558543353312], [0.0370802375067386, 0.08770219756350403, 0.025531977242339524, 0.04677589990258698, 0.03176946320661134, 0.06753445032142824, 0.011621601691830062, 0.14470446344104507, 0.12567909118989784, 0.24644371302377796, 4.861516500672987, 61.88180646588726, 47.06277032052317, 36.55149682875603, 33.26846514978717, 43.66048682120539, 42.45639370333764, 20.335687014364428, 52.610770733125754, 65.62396334063622, 59.16695364059941, 62.05060174388271, 59.41085446265436, 47.79410408389184, 0.14728132274843034, 0.1717159575632503, 0.66227026283741, 1.9650542591848683, 0.0701743433432233, 6.038412394062166, 57.63245967126662, 61.21523103406353, 65.15614225018409, 59.88108781076247, 63.104660280289195, 62.95535918205016, 62.720624939087905, 55.79222479174214, 45.163154678960005, 29.381180578662505, 36.502243626502256, 56.03882812684583, 60.38436320520217, 56.343890466997706, 52.955888317477324, 54.70604204362439, 59.93242771394792, 62.086209020306995, 58.829688641332815, 60.73927102550384, 59.01293785341325, 58.828923779149214, 59.9946718062124, 59.173182364433046, 58.6992423765121, 55.27376197999524, 53.05910548856182, 56.033219137499415, 50.225114591660045, 51.760530317983324, 57.34243962072558, 53.95730864617133, 54.52307524219636, 52.744888336427756, 52.536359448586744, 53.644374109083614, 56.659841306747936, 55.38143496359549, 55.96008262326641, 53.68593946579964, 48.35060604156987, 46.51489757722425, 48.13815870592671, 44.499713220903956, 46.809549946938795, 47.45131246505245, 46.465393343279445, 46.729306097953554, 42.56880883247622, 43.753576432504964, 44.731180129512666, 48.837552608982215, 58.822094932679214, 60.58917760849, 63.4621411754239, 61.04899314142043, 59.30203222459363, 55.342972201685754, 54.26885466421805, 51.950004331527225, 56.05742408383278, 54.94080374317785, 60.286249037711855, 64.20441050683299, 62.538348474810206, 61.67651353343841, 51.48004554933118, 47.0211265164037, 45.203731598392615, 41.41622427971133, 41.02063755835257, 42.948325603239, 42.85619305026147, 39.74682823304207, 38.25718656662972, 38.487661115584835, 43.15659169227847, 44.13683906678231, 44.545961887605735, 45.689728952223255, 52.22257767954181, 49.644529281123994, 49.996813035780384, 51.763095548076016, 51.2351562899928, 51.897625000246116, 56.958035576728086, 53.35000415002146, 51.453047875435125, 52.04558857025639, 50.53640173327539, 53.86350908587056, 52.24771222760601, 47.29557475736065, 51.80544930119669, 55.625312251429406, 58.170224466631495, 55.94207894417548, 56.7937235678396, 50.5961472757401, 56.4605535230329, 47.387856360404726, 50.836086503921024, 60.79295650605233, 54.44153701105426, 51.18994705138668, 46.23118862029045, 48.790323349737356, 54.795605444139056, 54.11811013375559, 56.47788647682437, 56.67195750821022, 54.75807620633034, 50.57597060357371, 46.29542527660247, 47.78902069214852, 55.37020521779215, 59.937189471337106, 62.58589544603902, 60.721043771313084, 66.28874624929121, 27.60427824912533, 0.19870362635101044, 0.2126072028711919, 0.15519085880969802, 0.24360733377116345, 47.80272545353059, 61.39136898902155, 56.408056520646625, 61.6525988424978, 61.175120876681426, 61.171629967228064, 15.070700318582597, 19.918574325499996, 37.63603218140141, 35.80822337058283, 38.61229050544001, 59.99912369635798, 24.151786450416814, 0.09892636624675605, 0.008878997346806911, 0.06275675447297192, 0.014939673090984505, 0.10736378285312846, 0.0539811100480297, 0.05785110661940229, 0.03721046096254741, 0.06284384717864376, 0.10607780468079353, 0.05053720774970228, 0.07401336314937762, 0.047715506741716984, 0.059338918316268155, 0.20102606785874214, 0.1424410719905169, 0.38783737428246007, 5.803618825251057, 73.65009369388704, 52.52623973354217, 38.5140194431428, 36.747113273989775, 45.72859964063091, 43.18809224713234, 20.85594431046517, 56.5428291597674, 75.66918080852878, 65.30190929289788, 68.5310632951798, 64.4398860777578, 54.00365929449759, 0.1407385947963884, 0.3982029422636955, 1.163222756116621, 1.9877394096505259, 0.14917927493731822, 8.676395589305509, 62.72978367344026, 64.08320142376807, 67.46398248980123, 61.69094001093219, 63.62852811813355, 67.2075379279352, 64.68201791086506, 57.22957341901718, 46.44224351452243, 30.550282232223022, 36.89271165478614, 59.07551142477221, 60.19305352241763, 58.97935844236805, 53.19221112035936, 56.017549268661014, 59.948850677859404, 63.50772303919639, 59.53769606928672, 64.80221110005533, 62.76076255306121, 59.38900293842439, 64.48485605178341, 60.80225252336072, 60.25680380482828, 56.583751247775176, 53.488114726158884, 57.56225708992251, 51.16005074593329, 54.14342511084772, 58.728942563456876, 55.93321438758604, 57.069179857930834, 56.04333885254399, 53.68325264223161, 56.71478194575156, 57.92004785230083, 57.949583299698375, 59.17462187428629, 57.62811368511569, 53.46508256850704, 49.61246390496531, 50.254195044117594, 47.66937663478237, 51.83358054007254, 50.069137619387725, 49.68509443344609, 49.799862984688055, 46.94125529258482, 49.473325667842744, 47.28576883192986, 52.62999426934027, 62.85413065264302, 63.91657913884809, 66.12536384213355, 61.835816675616854, 61.24128733911822, 57.71311929149013, 56.226046777540645, 52.27963639843849, 54.95437906634424, 55.44879382656467, 61.364261488760675, 65.15710323087632, 65.86287098546183, 61.31219594709335, 54.906110379003714, 48.48345279693604, 47.826271441675004, 44.941658435329316, 44.156294022836995, 45.962678847774384, 47.50093437010243, 44.4281417323697, 41.493130191679924, 41.17544174194336, 45.98218871701149, 46.36520424196797, 48.896560745854536, 48.4223501143917, 56.072034912724654, 51.39605583683137, 53.11818815046742, 55.233773416088475, 54.62559423139019, 53.67476855554889, 59.92408091022123, 55.15054464340211, 53.94750272074054, 54.5769529188833, 53.10935889520953, 56.62428894350606, 55.37027974282542, 50.7021414849066, 53.193787913168634, 56.644904921131754, 58.93995038924679, 58.84331103294127, 59.15545717362435, 53.66733174170218, 56.486645129419145, 51.44632101058961, 57.733060621446185, 63.549900285659305, 57.625430783917835, 53.196427668294604, 49.767840754601266, 51.15313952968967, 59.5152993356028, 57.5000875226913, 57.82556579959009, 61.07310002849948, 57.92639424723964, 52.12340839447514, 46.600354256168494, 49.86211099932271, 58.768417296871064, 62.90212477407148, 66.88663313465734, 64.81162871083906, 70.33773837550994, 30.618415763301236, 0.18529109686853426, 0.6799683034900696, 0.37349124409018025, 0.3971649850568464, 54.08459348063315, 68.94687375714703, 62.55037446175853, 65.01927114302113, 68.08490937755954, 66.76809126330961, 25.0558300172129, 26.78565998231211, 46.052787457743, 47.368836787439164, 38.39971765395134, 68.54261859770745, 32.152152715190766, 0.10068061566280742, 0.12850700517094907, 0.05775366023543382, 0.16182631404409487, 0.042557160955883806, 0.026969133290432157, 0.048553706522309975, 0.11032376273144638, 0.1706126990217355, 0.37031844498649724, 0.1890579971574968, 0.15876616050879802, 0.1188435797549544, 0.16299119669823878, 0.3142584595949419, 0.2991643824404286, 0.4728975567606188, 8.000883527340429, 89.69568637109573, 61.08758534154585, 57.700952099215606, 46.55232091103831, 63.856782605571134, 53.16147150531892, 36.58422508547383, 61.89012973539291, 81.19075621328047, 70.94938493544056, 78.22423627299648, 67.24661257959181, 59.41472191964427, 0.19638477013476435, 0.6821571086202899, 2.545902123374324, 4.605407301456698, 0.220841069916083, 11.924071023541114, 69.60209784969207, 66.05106630632955, 70.64182404548892, 62.39120075779577, 66.80220019432807, 67.93420407079881, 67.72212936032203, 58.601202734055065, 53.12704093994633, 35.905415781082645, 43.24505682914488, 64.839124525747, 62.48283909213159, 62.36819605673514, 57.02490022105556, 57.30578114909511, 62.18629221762381, 64.61886775109076, 62.739930845076046, 67.87492136801443, 64.37781456978091, 63.61379177339616, 63.20809710410334, 63.43370006930444, 62.88151271881596, 60.07155810633014, 58.55919414950956, 59.23872909238262, 54.26273576674923, 57.64552900868078, 63.30923541899651, 60.450372772832075, 61.54367070044241, 61.09681075619113, 58.04281019395398, 59.701933553141934, 62.60076515136227, 63.9787918521512, 63.11168132289764, 62.19220322947349, 55.676659999355195, 56.208560851312455, 55.32268962552471, 52.162483046131754, 56.73180895466959, 56.94182049843573, 54.53659957455051, 55.2785982624177, 51.06816137990644, 55.278629641379084, 51.15408089853103, 57.93926746614518, 66.8138967021819, 65.27762982153124, 67.34363632817423, 63.557792094446, 64.59666713591545, 60.95567995502103, 60.05298568356422, 55.01636428217734, 60.54419586735388, 56.159499845197125, 63.42001491977323, 68.00741903243527, 68.45023109066871, 64.65913088090959, 57.98189578517791, 53.80237110199467, 50.591573792119185, 47.42177701765492, 48.92673553959016, 50.951270826401256, 51.90334381595735, 51.13265299027967, 48.61333424045194, 49.237508850712935, 51.7288964025436, 53.35094551886282, 52.435503544345984, 53.25423163752402, 58.490525214902824, 55.821728860178304, 57.54339441176384, 58.7847775028598, 60.18298087581512, 58.697779332437825, 63.93467695482316, 59.896722378269324, 57.81846630957819, 56.42897844314576, 56.04293092604607, 59.60472153079126, 58.17828885970577, 52.69468199822211, 55.75389931278845, 60.57646520676152, 62.02923267118393, 61.03298987111738, 60.14225882868613, 56.582021482529186, 58.57575439637708, 51.52082250964258, 55.25546020077121, 66.45859272249284, 59.93563621274887, 56.46754710905014, 53.8041950041248, 54.919120880865286, 62.54236890423683, 59.533310859434074, 61.02902435487317, 62.50550254698723, 59.62896570082634, 54.9547516915106, 48.477710447003766, 55.961180886914654, 66.45394863620882, 68.53982587014475, 70.46950647907873, 68.75406572895666, 73.16603399092152, 37.129544365790586, 0.3107753029513744, 1.2995557631215742, 0.5552721720549368, 0.5621827141411844, 58.39153635886408, 73.60495505794403, 67.89223470995503, 71.19205413326141, 71.82696034831386, 71.91011459596696, 24.9214005854822, 26.47105843790116, 54.08793534001997, 50.66622826360887, 53.60364421721428, 75.6769157225086, 47.734134966327304, 0.32929060620165646, 0.27997243969190505, 0.15212523540662182, 0.29671936686481204, 0.13704470268660976, 0.10143422401480137, 0.15744845863551865], [0.01724620965579825, 0.07778325118124485, 0.006742156918100532, 0.04640262356148132, 0.07954336116991698, 0.030917722821956685, 0.022611351300691886, 0.12234288553196578, 0.03704151176216622, 0.1335327258153308, 0.8581788020749247, 44.152144155194684, 53.298134726862756, 35.498681683694166, 30.437749431979274, 47.88488341915993, 92.4769449234009, 18.87809895700024, 30.995720317286832, 74.64019406226375, 54.575376126074026, 70.77006986064296, 50.28277735556326, 70.62797807878064, 10.64531853122096, 0.28399752693310865, 0.4653068205281612, 0.7054934338215859, 0.0977948390608353, 1.7552273119649582, 50.772014587156235, 63.9413449841161, 64.26418350588891, 64.01205747358262, 62.291250921064815, 64.92121973345357, 62.31231797126032, 56.626312886514974, 55.39457490367275, 47.45821583655573, 52.645318969603515, 62.13050434666296, 55.339567584376184, 60.002426332043065, 31.91008560119137, 44.71770678797076, 58.379082833566976, 58.47893068867346, 62.43089122156944, 61.5858518692755, 62.427247339679354, 61.44808253934307, 56.27224837580035, 57.05938177724039, 61.37831534108808, 57.48904212828606, 50.214041740663596, 54.672752887971946, 51.197603517963046, 51.425269649874785, 60.62008980781802, 55.92679346761396, 54.43044847057712, 53.77711103808496, 52.96663953411964, 55.6047551093563, 56.317030076057684, 56.03856140567411, 54.144884232551824, 52.63220648611746, 52.228535759833555, 49.595821288324174, 44.9763596442438, 44.95655559724377, 48.43006541652065, 47.78632210146996, 45.068166640497026, 42.23890612202306, 40.01304341900734, 41.930698040992986, 44.775840236294655, 50.647357740709865, 59.934337908221835, 61.26424497173679, 61.360535237096975, 64.18570080111104, 57.07154504714474, 56.4444012026633, 55.90542439491519, 50.43614202930082, 53.974072856287805, 54.73915861498926, 56.17074528048116, 57.363945976380386, 61.07202922144244, 61.20646845909857, 56.48636271876674, 49.53874295757663, 44.31976664450861, 43.65208510429629, 42.57328033447266, 43.19691758002005, 45.90634184498941, 46.27260884931011, 47.64366549830283, 46.86362766450452, 45.72487338896721, 43.14049428509128, 46.02416200022544, 52.015150977719216, 51.194308727018296, 52.12992345133136, 51.42849383815643, 52.727935852543006, 51.9262190788023, 52.84575600777903, 52.790195634288175, 52.3582838427636, 54.760774797008885, 52.94652169750583, 48.335834395500925, 55.47654067316363, 49.87735332981233, 50.57380153286842, 52.52738114326231, 54.21239214558756, 57.38875496772028, 58.92996403478808, 61.54777349964265, 55.332699514204464, 55.13279984074255, 49.117009716649214, 45.58173433426888, 60.23984739857336, 55.16040548201531, 46.15805602842762, 45.16198581264865, 56.48812778534428, 58.53961367760935, 58.50886621782857, 59.921488223537324, 60.76484487902734, 60.717262606466974, 61.48501949925577, 57.29888954470235, 58.72833851845034, 61.251179556692804, 63.824293613433845, 65.33100151246595, 67.57806854863321, 62.25898942639751, 5.829721218155277, 0.20969485834000573, 0.38105768001367973, 0.5770689056765649, 5.28003437865165, 60.4714241335469, 47.07730270201161, 65.39425757623488, 58.44275074620401, 73.1936082532329, 45.856865067635816, 8.14576558528408, 47.13349849947038, 32.82519809661373, 26.787413281779138, 50.6440511826546, 48.089486014458444, 18.038817644119263, 0.24493056679925612, 0.14987097572415106, 0.10294038351745376, 0.0539159466091904, 0.0533478694306987, 0.040407050926718986, 0.01363895059893689, 0.01920442806646949, 0.009841877937076554, 0.016894086917501785, 0.02867906068962428, 0.0827609534345327, 0.05686425513798191, 0.028338189867715684, 0.05519040664958377, 0.048949046195634914, 0.1512298165189643, 0.839503417091985, 52.419276698943115, 62.09728187130344, 41.90980357508506, 42.329944333722516, 56.39858007431031, 92.00325596717097, 26.36036522926823, 31.24414755452064, 86.98402635512814, 63.85306027627761, 77.26828405933996, 54.74060596958284, 75.88067500822007, 10.451606396705875, 0.27867416580838544, 1.0988860793652073, 1.8067911579724283, 0.026454450525042993, 3.174692382735591, 58.66103849103374, 67.97020358424034, 65.73961442516696, 63.97571279156593, 66.09451047835812, 66.59342027479603, 64.36110135047667, 59.74531496724775, 57.454572339211744, 49.494643749729285, 52.91513489138696, 62.234772712953635, 58.830994790600194, 61.678462951414055, 33.68489926861179, 47.12354744634321, 58.498299352584354, 58.60923182579779, 64.63254113351145, 65.80110149998819, 64.2485293265312, 61.7468612424789, 61.02698080001339, 59.477601435876664, 61.37075693376603, 59.01726815008349, 52.470820565377515, 57.39719983070128, 53.569445071681855, 52.815330182352376, 62.60241646920482, 57.87956899212253, 57.40058091378982, 56.9929446712617, 54.096482184625444, 57.68366621386621, 58.612648210217884, 58.23179783359651, 58.31628960947837, 56.58604191195581, 56.48323266736923, 52.533825597455426, 50.0236459701292, 49.30570710089899, 52.36546570254911, 52.28252718525549, 48.76033682977, 47.46128313003048, 43.99023263685165, 46.03414050994381, 48.84121610272316, 54.15246225172474, 63.089468940611816, 60.62196077839021, 62.282782523862785, 64.76907883920978, 56.29661413931078, 57.35066090860675, 56.1753579878038, 48.31496738618421, 56.79263707130187, 56.458490356322265, 57.85849801955685, 60.92179852147257, 63.01521062850953, 63.91999160089801, 58.611310681989124, 51.1176577691109, 48.80113732430243, 45.62156600336875, 46.74252448543426, 47.69618603491014, 50.218646603245894, 50.32329151707311, 50.99975524410125, 51.46200264653852, 48.06350031206685, 49.19414704845798, 49.42278985054263, 55.32627859423238, 53.06518908469908, 55.842693928749334, 53.95977973937989, 55.25362453153057, 55.6669678226594, 53.4227954956793, 53.906839509164136, 54.314805230786725, 57.53273733200566, 55.29578608851279, 50.5996617194145, 57.814712601323286, 51.44237118382608, 52.13397918208953, 54.090775136024725, 55.74955332663752, 59.45166280192714, 60.73938085186867, 61.082184237818566, 58.57059647960048, 57.78070565192931, 53.096054215585035, 50.72445192644673, 62.87681371934953, 56.268122042379076, 47.87726617628529, 48.96970118245771, 58.89261130363711, 59.87357647188249, 63.309360934842026, 62.90396044331213, 63.026699250744244, 64.53136359491657, 64.3541548329015, 62.450173593336544, 64.41523790359497, 65.22453661887877, 65.70150075420257, 68.8919448852539, 70.0018971966159, 65.75803779786634, 6.685140142517706, 0.3335777874435148, 1.4829330651029464, 0.7378301889665666, 6.9467195772355605, 68.83338389858123, 53.1580315866778, 70.92415625049223, 65.18402245736891, 84.27642991465908, 57.337222868396395, 13.501121728650986, 42.58150554472401, 42.08569049835205, 32.40035833850984, 49.685439602021255, 57.66733346446868, 20.78161147332961, 0.3970213588928023, 0.1678351859652227, 0.0627268425699684, 0.0821466658324484, 0.05909429112028691, 0.03619896443260293, 0.0381475243897688, 0.11422197815150985, 0.16982905236223053, 0.12616047019799873, 0.1675408243411972, 0.30940768278894887, 0.1695268000325849, 0.11014170193624113, 0.2583549093575247, 0.1414483139712003, 0.2904518483386886, 1.552530743422047, 69.71460711571478, 71.3213276094006, 55.43558328382431, 44.55500295085292, 66.92694725528841, 96.4996728589458, 32.75885904988935, 40.19428437755954, 90.08838622800766, 64.84164268739762, 85.37460727076378, 59.23418306535291, 83.19121991434406, 12.715743587863061, 0.3709736340228589, 3.24296711914001, 2.7441215515136723, 0.1645519476263754, 4.985116758654195, 65.22519949943789, 68.83954986449211, 69.22973155975342, 67.19246818173316, 66.47586684073171, 67.75298272409748, 66.37877248948621, 60.931800565411976, 57.18669014592325, 52.593210281864295, 55.198491696388494, 63.41225647157239, 61.295961256950136, 59.19041333660003, 35.778123101880475, 50.090942075175626, 61.13950967788697, 62.88110479231804, 68.47130206323439, 65.59359635076216, 65.09418056857201, 63.82111257122409, 59.72012942837131, 62.66673941766063, 65.21577012154364, 60.06334858555948, 55.8164454275562, 58.908167423740515, 55.90316118732576, 56.83017023148076, 67.40371134973341, 62.33986085461032, 61.53731646076326, 60.67042950660952, 57.562574801906464, 63.417920374101215, 63.983804641231416, 62.70891666412354, 62.349749149814734, 60.04924374241983, 60.89564023479339, 55.33364872778616, 52.6136262186112, 54.27769176421627, 57.042864676444765, 59.27343814603744, 55.21352614125898, 52.45556646777738, 46.78534500060543, 50.45796217456941, 52.231850162629165, 59.675563458473455, 67.34329115959906, 66.70935769234934, 64.53955742620653, 68.62033644030171, 61.89991212660267, 61.43502496903943, 58.85385044159428, 49.63988519483998, 59.04762729521721, 60.54079909478465, 60.54932240516909, 64.30655294849028, 65.55405885942521, 64.88619689018496, 61.614940166473396, 55.49241842762117, 52.39213389735068, 50.84807718953779, 51.45676628235848, 52.55525742807696, 56.020742077981275, 55.739233570714156, 57.28465526334701, 59.3600127004808, 55.44771125239711, 53.585632693383005, 54.70666177811162, 59.61825763025592, 56.80235278221869, 60.422920103996034, 57.097597429829264, 60.669409690364716, 58.55094932740735, 60.41888006271855, 58.71674399222098, 58.75748957357099, 60.865234021217596, 58.93577306501327, 52.83869574146887, 61.81537328227874, 52.623659641511985, 55.819351903853885, 57.29699503990912, 59.10886726071758, 62.55219051914831, 63.36674913283318, 64.12550418607651, 59.34251892951227, 57.962225098763746, 53.147076406786525, 48.41514079801498, 64.31435454276301, 58.07089436438776, 55.656993235311205, 50.886257540795114, 62.841390794323345, 62.6872024228496, 63.80927878041422, 63.66315872438493, 66.75016603162213, 66.28082306154313, 67.93578086360809, 62.542647392519065, 66.70004598556027, 63.99168860527777, 68.77238319766137, 70.9678122305101, 71.78420651343562, 70.81047811815816, 10.295428402962225, 0.37675719948545583, 3.2272599877849704, 1.0967662834352063, 7.302778122886536, 75.66177537364345, 58.49482021024151, 77.11921045857092, 71.68679837257632, 83.95596442684051, 56.5562318986462, 14.692685815595812, 60.638160167201875, 47.50428799659976, 39.82418521758049, 68.63561799449306, 67.27288461500599, 37.25200468494047, 0.5660982814527328, 0.3075348429622189, 0.20186660420750419, 0.24424128685026403, 0.15017947933125883, 0.16220617108047009, 0.1715284958481789], [0.033041421969931935, 0.027252049560868935, 0.012701333673190207, 0.05587351576034581, 0.03525494875746869, 0.012690644831426684, 0.20405891802041762, 0.0364547458687617, 0.03773419697198176, 0.09998685409945827, 0.191033891131801, 25.89022601804426, 58.10428942403486, 33.949396456441576, 32.86417076664586, 30.294318160703106, 46.82654949926561, 33.30068349838257, 16.901983368781305, 68.16001492161905, 46.83132694613549, 68.6767558128603, 53.96887179343931, 63.58708043252269, 45.667085109218476, 0.2675147162329766, 0.17295738772278832, 1.1355686980870463, 0.15569756468457563, 0.9890638207716327, 41.15304500825944, 69.8674383471089, 62.62815506227555, 65.01736487111738, 62.82387741150395, 57.09453798109486, 57.13737418574672, 57.99786767651958, 53.8711537853364, 53.883611233003684, 54.44953472383561, 57.41341490899363, 58.74679719248126, 49.5375427123039, 31.752529874924694, 45.3042580235389, 55.49440706929853, 60.15746193547403, 53.83277731557047, 60.88049204118791, 51.067298458468535, 63.24490070343018, 46.83839897955618, 52.60264750449888, 64.13350582122803, 59.04932568150183, 53.63934170815253, 53.98323943538051, 53.904325269883685, 47.87111982222527, 55.35028742205713, 54.53847838986305, 52.838236824158706, 54.881893665559836, 57.31685792246173, 55.01169666167229, 55.755546708260816, 57.072615854201786, 55.841999669228834, 54.968452530522505, 57.26804402566726, 52.20922200910507, 49.521029533878455, 45.61844379671159, 43.68445642532841, 43.840645205590036, 44.31750735928936, 39.41312866826212, 43.22196191357028, 45.64484919271162, 49.8863120232859, 53.61597222666587, 55.56919490137408, 55.93344580742621, 59.29196350036129, 62.4060586960085, 55.58682987766882, 57.08124899095105, 58.04111965240971, 48.34587566314205, 54.39850076552361, 57.75029551598334, 55.057149087229085, 57.23256226508849, 57.71217792264877, 59.115566668971894, 56.32967579749323, 51.831540907582934, 44.81007076078846, 43.6155717603622, 43.69694132958689, 40.62426244058917, 42.39648734369586, 46.800383367846095, 41.90175487149147, 44.55486566789689, 47.16517163861183, 47.770091333696925, 51.35845991872972, 53.17203444819297, 53.66801815648233, 52.100529209260024, 54.21764812161846, 52.51459813887074, 50.593142740188114, 52.55902290344239, 52.01621786240609, 52.079544528838134, 52.84842321949621, 51.22330288733206, 51.577665498179776, 52.61075896601523, 46.92228278806133, 48.476835758455344, 52.22999880390783, 50.16895409553282, 55.126763313047356, 57.30391802326326, 56.06661811951668, 58.245977201769435, 58.88509212001678, 54.85348786077192, 45.53263410445183, 60.3113639739252, 51.14291783302061, 47.31789304364113, 44.59488168839486, 54.386043317856334, 61.14176111836588, 59.53318926595873, 63.13363875112226, 59.78291480771957, 58.88510388712729, 65.50710808846259, 63.51599924025997, 65.93381097239833, 62.67950281020134, 66.8374466126965, 61.03916760413878, 66.64940818663567, 38.68944352672946, 0.2049338210734629, 0.0024834265059325844, 0.7302518020714484, 0.6052087860242014, 22.282098493268414, 66.10166488155242, 52.81374162243259, 70.49934002660936, 52.539509111835116, 62.69260744894705, 28.12535532059208, 22.487766012068718, 54.57032411329208, 32.13718887298338, 36.736224774391424, 42.47384825060445, 46.53631764073526, 5.7554844790889375, 0.2390907551612585, 0.10281563375986393, 0.05512792834891908, 0.05798246005489942, 0.07776925475486825, 0.027598468774569132, 0.005879681726406899, 0.039708332774499734, 0.0662924072915508, 0.013998015051437242, 0.07578667283298508, 0.0059620974653009935, 0.032336475522888285, 0.13988851299208982, 0.054223247458257025, 0.08437091019004585, 0.035486927841820066, 0.1391188397763237, 31.13099501978967, 70.11471240751206, 38.70490943231891, 45.124236922110285, 43.81094894101543, 58.28214145475819, 37.29680991941883, 22.021511908500425, 72.55987874923214, 51.76267977683775, 80.21651006514027, 57.11332613422025, 72.39771227682792, 51.57237422081732, 0.3708685267596476, 0.24260820190031684, 2.233641253363702, 0.14056542828198404, 1.4315523447528964, 48.4554470739057, 72.43526504885766, 66.20140291029408, 67.63066753264397, 64.59081103724819, 61.30709686586934, 58.33041798683905, 60.03329930766937, 54.421364261258034, 57.08198639654345, 56.155044032681374, 59.72976276951452, 61.434271873966345, 51.02771389868952, 35.195192213981386, 43.33659710422639, 56.68366578317458, 59.378439995550345, 55.971135862412, 64.80321914918962, 55.06921037550896, 63.27281228957638, 51.56245062428137, 55.07834165327011, 66.39749788468885, 61.315733924988784, 55.64607727912165, 56.17859786556613, 55.42031741911366, 49.30545606920796, 57.92073034471082, 57.57291416968069, 57.01318802372102, 58.859816366626376, 57.75697531238679, 59.019931439430486, 57.410908514453524, 58.088592098605254, 58.601610660552986, 60.16295325371527, 59.40898741445234, 56.59469466055594, 53.389647545353064, 50.977334976196296, 47.813664943941184, 49.351449781848544, 45.70959575714604, 43.118909482033025, 45.50660917835851, 47.83139013474988, 51.25940438239805, 56.54399018133841, 58.492360884143466, 60.54312898266701, 61.02134827644595, 64.73661730366369, 60.23811763332736, 57.72035606445805, 58.26881324091266, 50.32377004623414, 55.88029769159133, 60.14514569313296, 56.47761583328248, 58.64849475122268, 59.02885875394268, 61.706150962460434, 59.1131151876142, 53.56597377407936, 47.52669257502402, 45.88943642954673, 43.62420097474129, 46.154808305924945, 47.466409667845696, 50.83146202948786, 47.0204597134744, 49.12981233289165, 51.183914446061664, 51.93808817094373, 54.49066469746252, 57.59293786941036, 55.97341475948211, 55.413049267184356, 53.781256983357096, 54.51998441450058, 56.782748776097456, 54.822191269167014, 54.37164821932393, 56.7269765946173, 56.49077146284042, 51.70717431652931, 54.050782649747795, 54.66239783071703, 49.22359228134156, 50.93454976235667, 53.498669824292584, 53.982466728456565, 56.245642938921534, 57.079378020378854, 57.30960153764295, 60.585992643910075, 59.41853054108159, 56.72881618622811, 49.077127056737105, 63.451103625759, 54.20533187927739, 51.26846897986628, 46.66016255655597, 59.11220519773422, 62.62360903524584, 62.624318984247026, 63.628794839305264, 63.07535625273182, 61.67032403330649, 67.22936199557397, 64.36426278083556, 67.35487784108808, 63.414747176631806, 72.20634768086096, 61.61614041174612, 67.50963887860699, 38.56026810984458, 0.32511956388911895, 0.08846922011505212, 1.5133835279172467, 0.8453856240357123, 26.670748264558856, 73.8106990629627, 54.14223271031534, 74.59322760182043, 61.7252685946803, 74.15233750497141, 33.01027905556464, 19.49072022591868, 53.88262279572026, 42.46503860719743, 36.46081163037208, 45.7935344788336, 57.145407199859626, 6.023523076888054, 0.1486495098159198, 0.08734797382907522, 0.03299962804322282, 0.18234032536706618, 0.03391164422575985, 0.02773915890664343, 0.04460848394721266, 0.12658123632953053, 0.1335231343945188, 0.21980688186182132, 0.17775538107079847, 0.12420326876904696, 0.06434594641529745, 0.2358974708664802, 0.18386206709809844, 0.19109016795071865, 0.2774162494367169, 0.32395639727192543, 44.27580471961729, 79.37334952815887, 51.014154265003825, 46.73502099129462, 47.625614750769834, 61.71217572304511, 43.64685658485659, 26.404952772202034, 80.77300810044812, 58.83720782495315, 80.7555849321427, 63.53007270443825, 74.51951842154227, 56.57117612900273, 1.0490364316971073, 1.1101100641873576, 2.9990898313060885, 0.3079881831522911, 2.6807301659737868, 54.99775263570971, 74.0396870336225, 69.04261096831291, 68.4240924158404, 66.65188712458458, 62.984110155413234, 61.06158394967357, 62.75709121457992, 57.796693232751664, 58.2199405085656, 59.23430465882825, 63.123224858314764, 63.70307276325842, 55.979969040040054, 42.698631440439534, 45.59367402907341, 60.628687643235736, 59.05154574301935, 59.36554324242377, 64.94497360721712, 57.6405672104128, 63.13439576856552, 51.605231915750814, 58.99564804569368, 67.81557590730729, 64.23941766062092, 59.03267129775017, 58.745663627501465, 56.864239938797496, 51.22323620703913, 61.49855559872043, 61.38215141911661, 59.35504305747248, 61.17589358360537, 62.77832300432267, 60.29711400308917, 60.95879039456768, 63.4598034428012, 63.38936551924675, 61.398472401403616, 61.36113143736317, 59.58575687100811, 57.5093953071102, 55.323697674658995, 52.502179914905184, 53.608323604829856, 50.352462184044626, 46.596737830869614, 50.93113337793658, 53.90119521848617, 56.98895954316663, 61.02599236272997, 62.71646330433508, 62.336181671388694, 60.636057776789514, 69.24661344097507, 61.39530704867456, 64.10394291723928, 61.386854340953214, 51.46329310632522, 58.712700028573316, 63.3205004661314, 57.9605737809212, 62.28033496487526, 61.08471024420954, 63.60460950482277, 59.78100853581583, 57.83677593354256, 52.010479434843994, 49.79911773435531, 48.57957440037882, 49.67584548457977, 50.51178101570376, 57.5822925567627, 51.30203662380096, 54.62425670316143, 56.06189950819939, 58.83230486223775, 59.298929629787324, 62.317660239435014, 60.5605286167514, 58.21004044625067, 59.434349459986535, 56.64787807772237, 61.19048087827621, 58.491003744063846, 57.66216770295174, 58.15484485318584, 58.87731798233525, 54.9528964104191, 56.06879503496232, 57.10530096484769, 51.251677313158595, 54.042996744955744, 56.27808486261676, 55.28098306348247, 60.875910712826645, 62.420877410519516, 60.54327018799321, 62.76863082762688, 63.19126621369393, 56.7529897536001, 48.41526239149032, 67.77761520877962, 56.71608417264877, 53.04681278044178, 50.105705876504224, 61.37686014175416, 63.52472651389338, 64.0221183530746, 69.73784323661559, 66.71079327983242, 62.38428954155215, 71.4312167321482, 68.97190632358675, 72.06406762523036, 65.88301627866684, 73.56169131494337, 63.47195494559504, 70.4617166519165, 44.33880975169521, 0.6956902050202893, 0.20744289692130782, 3.429111775852019, 0.920952843321908, 27.872935110522857, 78.46923535869968, 63.19990719518354, 79.14789953539449, 66.65479752325243, 72.46372576682799, 39.03293724982969, 32.0344659205406, 72.5170543116908, 44.08025495467648, 56.09696549753989, 56.877030787929414, 75.16304600623347, 13.682952023321583, 0.46518985422388204, 0.2742828578958588, 0.11804385290991877, 0.2547405065307694, 0.11180841048518497, 0.11984576065573962, 0.13382302717335764], [0.02644097120801528, 0.0564132055508033, 0.03267412111463566, 0.04747262239576348, 0.061422363374262094, 0.07989629021575374, 0.0848374500750534, 0.03355882243223248, 0.10018636637757863, 0.06034866816574528, 0.12282981867751769, 15.490763610409154, 55.33843009702621, 40.80062004827684, 41.06667049469487, 34.35159629391086, 53.90576477973692, 40.54323411756947, 16.074508390119, 68.64285868983116, 54.589033819014034, 59.87054447973929, 64.67799748143842, 49.987305210482695, 67.30073344322943, 6.414194578124631, 0.3233076740176447, 1.3566975872362814, 0.5108323308729357, 0.1778360194857082, 28.354080492450347, 69.08057951158094, 62.87055361655451, 67.36258922084686, 60.699984565857925, 63.22638711621685, 63.039070406267726, 67.0322628944151, 63.582726601631414, 62.01939536679176, 59.463673099394775, 57.56887020603303, 61.51089537528254, 61.43588396810717, 82.80927519644462, 50.03060425481489, 36.47356325580228, 52.13105701631116, 54.98884493304838, 56.464071889077466, 60.253497246773016, 58.34225962238928, 36.323430615086714, 61.690798805605986, 59.172668533940474, 58.1881183193576, 53.36257142405356, 55.656028332248816, 52.48862420358966, 47.299928588251916, 53.08087464301817, 57.87046909332276, 52.16943740844727, 53.60992393186016, 57.802380669501524, 55.655314460877456, 54.27027063985025, 55.58053839591242, 58.340270980711914, 58.30418125275643, 57.31922703404581, 54.673843306879846, 50.309551454359486, 49.299427386253114, 48.03578876679944, 41.800608711857954, 43.553296289136334, 42.80598278968565, 42.90480298380698, 43.43604879994547, 52.40833720853252, 54.42509835766208, 57.48899113747382, 59.15320181077527, 61.16165145750969, 60.82064843946888, 56.064472583032426, 62.66054991752871, 59.04057879601756, 48.72534928783294, 54.77638583029471, 58.60108506294989, 54.6947769964895, 52.64333817266649, 56.43726641131986, 58.78512267143496, 57.74163492264287, 51.752403166986284, 47.3281265074207, 44.38876505820982, 42.34327646993822, 40.67184863551971, 43.33537332473263, 44.582294802511896, 41.513428457321666, 44.757189366125296, 45.9569953333947, 47.62041761029152, 50.92029586915047, 54.587268752436486, 53.9968422151381, 53.41424865107383, 51.45520910140007, 52.19748235517933, 50.486764138744725, 51.072307325178585, 49.26946832287697, 51.15504187922324, 52.591817840453125, 46.7318634833059, 51.40937620593656, 50.39408245394307, 48.090960825643236, 49.19840674246512, 50.647800968539336, 51.093386142484604, 49.911485795051824, 55.3134249871777, 58.71014264322097, 55.293389520337506, 61.13896446843302, 52.315698669802764, 45.749486261798495, 60.566631824739524, 55.01572101346908, 48.685725504352206, 41.57537444945305, 54.137392505522705, 60.47450711650234, 61.03742999415244, 62.32357909602504, 58.28210223105646, 59.11685712875859, 59.53023964358915, 60.55030299771217, 58.6207361375132, 62.935794399630645, 66.0589659598566, 62.7853322798206, 65.14241003221082, 18.758772611618042, 0.25025500044707333, 0.4451803424425664, 1.703788981803002, 1.4510095071408058, 40.0503961501583, 58.21382553346696, 58.04153542364798, 64.76108897116877, 51.49345221058015, 48.04675179143106, 35.847541209190126, 30.615705405512166, 53.836028960443315, 26.163348497882968, 34.509577597341234, 41.973773510225364, 32.917169832414196, 1.1236609951142342, 0.078873363653979, 0.0714526376536777, 0.05802333467609941, 0.07525663191993391, 0.06398119280234942, 0.023885594921246655, 0.06567600528679549, 0.046481530617682204, 0.06112698285329727, 0.0414015862700199, 0.0017717700862821433, 0.060102259815340085, 0.14912541895624132, 0.02764505841168425, 0.025791460798392375, 0.09826956842575343, 0.05913125486263345, 0.22538841461702702, 17.888153522245346, 68.74298895559004, 40.74589906200286, 42.17674832190237, 45.94718940796391, 57.88788441688784, 40.98665414317962, 17.801922175192065, 74.28531369855328, 56.067822287159586, 68.82528028180523, 67.43201517289685, 55.42279243469239, 75.16419133832379, 8.254128906034655, 0.3131960795050667, 1.69726436416949, 0.8257613931932758, 0.22392409883679884, 33.26293853021438, 72.97348483916252, 63.35802578156995, 70.48426243566698, 62.464556924758426, 67.39923984773698, 66.53055252567415, 69.1671383765436, 64.02384419595042, 67.06983920066588, 60.37874637111541, 59.643454936242875, 62.38214400506789, 61.997908622987815, 77.4641986047068, 55.36833032484978, 39.03941308298419, 53.327458366270996, 56.29664551827216, 57.47014414879584, 56.12340619487148, 60.772901427361276, 41.49598567716537, 61.91667633671915, 59.67523397937898, 59.104136882289765, 56.58875619211505, 56.705089769055775, 56.53323896469609, 50.45865251171974, 55.5237542429278, 60.81168974599531, 54.99505012266098, 56.21169090270997, 60.47982977282617, 57.07585965433429, 57.93614918185819, 56.250455687122965, 60.49937494339482, 58.75546563056208, 61.090099580826305, 58.06420672324396, 53.44108550779281, 53.50265495238766, 49.81351283288772, 46.53542726270614, 46.449276324241396, 44.91527657355032, 46.02704494230209, 48.27140946542063, 55.69513828523698, 55.45083738142445, 59.84022063593711, 60.59522982566588, 60.44889796164728, 61.43545250738821, 58.0073441228559, 61.332454989033366, 59.73476379148422, 51.04782389056299, 56.34492205035303, 59.837941738866995, 54.645657154821585, 53.28118616534818, 57.049313053008056, 61.403771523506414, 59.37295652204945, 53.78217874034759, 49.985077304224816, 46.63622040902415, 47.84888782808858, 43.618490003770404, 45.89109166975945, 46.85723420112364, 46.27177338446341, 46.37329216926329, 50.04843142724807, 51.058512349282545, 54.43524160692769, 56.26356424823884, 56.71758644042477, 55.433108268245576, 53.56344384531821, 56.474948621565304, 52.67554475415138, 55.302964025928134, 54.963710384984175, 53.818021358982215, 55.63598502066828, 48.29126842560307, 55.04743337631226, 52.29433351947416, 50.31195586727512, 51.57160935863372, 54.333059941568685, 53.039305363931966, 53.272690311554946, 58.05256512857253, 60.64647559196719, 57.437615932956824, 63.3951117915492, 52.79448670725669, 50.11804565306633, 60.41882514953614, 58.53931557747626, 51.263464035526404, 43.94527050756639, 56.33548482771843, 62.32312410108505, 65.16156296576223, 64.41958781211608, 60.99944968377391, 62.372534198145715, 62.30753660202027, 65.85684622487715, 63.79134962635656, 64.24739183918123, 69.48543871602705, 65.52587270736694, 67.85886318452897, 21.314902805512954, 0.2328777361300684, 0.5360846726163742, 1.6231820684286857, 3.0562181722733284, 51.815086564710064, 61.340213437234205, 65.00192642211914, 71.36877259900494, 60.30326427951936, 48.636256571738954, 33.13038595261113, 32.828634092884684, 54.651791741771085, 34.25596106436945, 31.059031294238185, 50.54370910890641, 43.14515798322616, 1.024029789672744, 0.11021146956350535, 0.03385827088007524, 0.03675374998560837, 0.011548604046355092, 0.0422980968329695, 0.0233233783153757, 0.04343238576585728, 0.06309377570306102, 0.2219359168121892, 0.1860733032827416, 0.1195127422350549, 0.16560891913550516, 0.41182190179824835, 0.14099855907261372, 0.08957872993402904, 0.21137825994481965, 0.29241821217921476, 0.5781814492037219, 27.539231623372725, 82.38208986097767, 57.53269810830393, 55.819889268567486, 49.36865721979449, 71.81351446336316, 50.994205090307425, 25.620100229017197, 78.31942435233825, 66.3147044950916, 70.19156732866841, 75.68687069800593, 60.65015085281865, 80.65405045786213, 9.844950072226986, 0.4683771170675755, 4.1029879643071085, 1.5040325974264455, 0.31783376129404195, 41.24361645790839, 73.05066923941337, 64.30573317312425, 72.54870783898139, 67.35501904641428, 71.9400344356414, 69.10433338534448, 70.4297258007911, 65.87679539957355, 66.79605776263823, 61.427427338015654, 64.4345320424726, 62.30322983957107, 66.02017371885239, 79.41901376170497, 49.31657206627631, 44.61824724751134, 57.83761532075944, 57.37459128902805, 57.82468718867148, 55.456889598600334, 56.43674081371677, 45.91447684072679, 65.577749975266, 61.15225738094699, 60.53014985976681, 57.521264399251635, 59.865755265758885, 58.283773160749874, 53.34619552858415, 56.92016509271438, 65.42321251284692, 60.36957979202271, 60.450000147665705, 64.46159247429141, 62.10300853175502, 59.96420283471385, 60.52831419052617, 63.52351057913996, 62.016669319522, 64.03425808875792, 60.8335961834077, 54.289592235319084, 58.2631258041628, 53.34068067612187, 50.39105046179987, 52.282252619343424, 49.24917005723523, 48.9529408947114, 54.19443161256852, 61.16634261223578, 60.75838081298336, 62.96098778324743, 62.55927039730934, 64.02544060061055, 66.48806541196763, 63.37449973629367, 65.28536473551105, 61.97006371713454, 51.177211115437174, 57.317183479186035, 63.64957163410803, 59.589773378064564, 55.75153412357454, 58.78044328381939, 64.57914590835571, 61.52285468193793, 59.88725769904352, 55.24042575590072, 50.92945068113266, 52.73878512843963, 48.92256606009699, 50.38201332092286, 51.608134469678326, 49.226118287732525, 51.00491708324802, 54.49014694459977, 54.628363424731845, 57.76136052223944, 61.00317985780778, 60.96337172292895, 60.83518866569766, 57.02673196792603, 61.04903236512215, 55.98538583324802, 59.05133393503005, 57.738822583229314, 56.26768665928995, 57.501978105114354, 49.97326704763597, 57.8708887869312, 54.61802013458745, 53.052782627844046, 54.573665972678896, 57.3772192770435, 54.92392970669655, 54.8043405625128, 59.871513305171845, 62.72997979194888, 61.39140821272328, 65.7744058485954, 55.265666207959576, 49.6086827401192, 63.90938551195207, 59.83138353593888, 55.74492885220436, 45.39172687838155, 60.09617490153159, 64.32596475847306, 67.89087756987541, 67.1916131050356, 64.45474009360036, 64.89852882200672, 65.95974568397769, 66.35446948389854, 67.622814947559, 65.61562438164988, 69.9576057926301, 64.67411041259766, 72.05401066810855, 24.035666642650483, 0.24444900393005342, 1.4446887301821865, 4.158547847501693, 4.171953037861855, 53.60584074451078, 69.53106372587143, 71.7843790977232, 75.66296777417584, 66.36186707404353, 60.92972563159082, 46.39393560348019, 42.939967032401796, 70.40681131424444, 36.92792277182303, 51.62048209098078, 57.80832698268276, 62.00195258663547, 3.2452631765796296, 0.21205905163961075, 0.21471468010737052, 0.13375383411203662, 0.2047252306534398, 0.1458865830734853, 0.07635091957185539, 0.18888673054114466], [0.04336372896608326, 0.0643665005543059, 0.07103861309587955, 0.016254920610076478, 0.06722311218900066, 0.01664172414870512, 0.0326736269879245, 0.009697020286694169, 0.16203072162405138, 0.05940900387002095, 0.19859366209035922, 5.983644339346117, 56.2508753807314, 42.136700922443026, 47.68980826100996, 23.935659931552028, 56.29712012506301, 33.76955970641106, 23.021175015357233, 68.10451338368078, 57.25734379983718, 55.79998716231316, 62.87815124757829, 57.8431184061112, 71.02084267523982, 18.330345845991566, 0.1859297690492484, 1.473768569769398, 0.6379668895275362, 0.07730001057948797, 16.863126408669256, 62.522427574280776, 57.80469094553302, 65.89748982460269, 56.238688576606016, 65.58173510336107, 59.944802791841575, 62.87146752880466, 56.65126308318108, 67.69476690599996, 59.60776921241515, 65.50515474811678, 58.03033705680602, 75.8561445051624, 68.11593532562256, 62.41486441704535, 56.529948096121515, 43.28163293100173, 46.84696151364235, 51.32467654443557, 54.09933374774072, 35.772004204411665, 49.4404052149865, 64.34914988856163, 58.836874423488496, 54.80960046091388, 52.31823252093408, 52.971864131189164, 55.954673674798784, 48.88023976356753, 49.56390496223204, 57.717178944618475, 51.27855731594948, 55.00809200348393, 54.771969241480676, 55.12355089187623, 55.293926885051114, 56.533266421287294, 58.359561197219364, 56.931132039716175, 53.27931911714616, 57.304435776126006, 52.22015365477532, 50.89569476342971, 45.7375269551431, 43.93788468453192, 44.87373867342549, 44.72401788157802, 46.371813435708326, 51.75097150187339, 54.9758775772587, 55.672969049023045, 56.270671582991085, 58.48509273221416, 56.74245034494708, 54.77260074307842, 55.35372734069825, 60.41045088921825, 58.05533039954401, 49.93885609411424, 57.01727513344058, 61.197835322349306, 54.63632975855182, 53.68125223344373, 56.69690378250615, 60.11214679287326, 54.90152905064245, 54.21292166556082, 45.493704580491595, 44.43169147737565, 42.27627062028454, 40.54549732515889, 42.556092508377574, 42.1394387368233, 42.43385184195734, 47.06170343583631, 48.76536530833091, 50.75048861965057, 50.22134519392445, 52.02286627984817, 54.74876842191143, 51.65286910149359, 54.213682605374245, 51.705424939432454, 50.24059618673017, 53.06422418163669, 50.65707737399686, 53.16773553048411, 53.71641628203854, 46.58682992381435, 54.512394628217145, 50.79996147463399, 50.06572907970798, 51.86424170770953, 56.53118364272579, 54.88964034665016, 56.284650910285215, 52.201487095125266, 57.38510324108986, 57.26405105283184, 59.45850733787783, 47.79497877244027, 49.345829025391616, 60.42606192250406, 52.35846034942135, 54.30183003025671, 44.47909332090809, 45.94785621089321, 55.647920793102635, 58.57347157693679, 60.54758479518276, 61.491840500985425, 59.45334157636089, 60.211261164757516, 60.35376479548793, 61.138572231415786, 63.98130216906148, 63.15434494326192, 63.38771812377438, 57.78439267989128, 6.7700986804500705, 0.11283688352353151, 1.1071719637801571, 1.261660641720218, 8.58820011538844, 46.01936886387487, 56.31190353824247, 59.294560109415364, 60.72725288329586, 65.31096996799593, 77.69247270399525, 33.56648291310957, 37.77438594448952, 35.72649294330228, 26.527067922776748, 38.57561242195868, 45.69553798244846, 28.558514425831458, 0.09589814325614322, 0.09425049497475547, 0.05289907597245709, 0.042074039097755186, 0.029247363864053643, 0.039576902730210174, 0.03962809655575022, 0.014226263287597367, 0.06779357956181611, 0.025251813142770724, 0.02601889315091314, 0.025449565333885052, 0.021253619418149034, 0.006815747802911868, 0.03833970137601418, 0.009969418169930577, 0.056614579422579664, 0.049017331442765655, 0.18682814503629364, 7.464656791379375, 68.81872992361747, 45.567923668892156, 46.774464345747425, 37.08858305408109, 65.19299684032318, 35.713545199363466, 26.47888552758002, 73.83283692021524, 61.868137005836736, 59.867963560165904, 73.9058949870448, 60.51654708000922, 80.31092935992827, 20.43880024263936, 0.2141668199892006, 1.9057975421028754, 1.329654560935113, 0.08354362716237385, 21.218500752602857, 65.34369037997338, 61.19795299345448, 66.0816058804912, 61.01315836752615, 68.2333867780624, 63.31511112951464, 65.71497017337431, 59.33121858104583, 69.6475032068068, 61.09790117509904, 69.84470428959017, 61.549907269016394, 76.40473504220286, 64.17040355743902, 65.90537378864904, 60.82076611057405, 46.72862360554357, 46.81818700605824, 52.105271354798354, 57.47103844919513, 42.33461979896792, 50.934341876737534, 67.66503534009381, 60.08362331698018, 56.64919599410027, 52.57690498905798, 54.70121752831244, 57.186878419691524, 49.25637937361195, 50.276623156762895, 60.517335476413855, 54.949770281391764, 60.62299628411571, 56.427735051801136, 58.537252410765625, 57.13243592169977, 60.342993966994754, 61.28081306334465, 59.09416621731174, 57.166254597325484, 57.769499440347, 53.61621149124638, 54.054210801278394, 49.159030068305235, 47.595267372746626, 45.76620340347291, 48.5129568653722, 49.61843767473775, 54.071535910329516, 59.6532137932316, 58.962649145433986, 58.98954876007573, 60.56478438838836, 59.98042968011672, 57.54949369738179, 59.13092667056669, 60.6236199409731, 62.021011383302756, 50.12585116970924, 59.439695650531405, 61.0096517685921, 56.19078074732135, 54.03847817451724, 57.50965026117141, 60.69970607757569, 57.7745436083886, 56.308291035313765, 51.65174730362431, 46.301465726667836, 45.09489759322136, 42.817169389417096, 43.10766796911917, 43.74497859708725, 46.196938483945786, 49.29384193112774, 50.584744945649184, 54.34914950401553, 55.222253414892386, 52.39361655327582, 57.2532606124878, 54.82161075838151, 55.86124281729422, 55.55539992547805, 57.27305681474748, 55.521428277415616, 55.71320864462084, 57.7268240528722, 52.820998007251376, 47.094153204271876, 55.18067236869566, 49.81999651078255, 51.166051972296934, 54.76020997570407, 57.58500683692194, 57.99811086347027, 58.382436460064305, 56.953383645703724, 59.13429598654471, 60.67558350101594, 62.46478049985824, 48.44220515220396, 48.032788153617616, 63.49468115837344, 54.38570991639168, 56.26909479018181, 47.109968200806655, 49.18005397242885, 58.738211124174065, 61.190935873216205, 61.899319848706654, 64.62226060128981, 61.035300147148874, 63.939964309815444, 62.75625574973322, 66.24834583651635, 65.96767671646612, 65.37681479607859, 63.82136360291512, 63.93114682166808, 7.40634830728654, 0.4507293930697826, 3.6588082246242033, 1.0374043978029683, 13.946666698301993, 56.06189558582922, 61.24877514377717, 68.07458569926601, 65.31597883470597, 69.96936505840671, 74.3733238404797, 38.02169530622421, 43.65199488978232, 41.11441750680247, 31.241588207983206, 36.819500615519864, 52.699573193826986, 36.98814684344877, 0.16262325998996535, 0.06807126345173006, 0.03728176842653944, 0.06557581630805809, 0.04298789772175012, 0.07365604441973471, 0.03660271192089685, 0.006822298333469418, 0.15468723260827605, 0.10056743383287423, 0.15251108325056492, 0.1507696734681245, 0.17543093241270513, 0.12954490109076425, 0.08986052005521714, 0.11028532043940599, 0.2151574176405707, 0.19501636856265608, 0.44035585777413466, 12.543860423949457, 87.31483121072093, 54.46141558308756, 68.32299724701913, 36.69884458664925, 75.64588192970523, 43.19665085884833, 33.742664014139486, 78.93828807338592, 70.13173549405991, 66.6988378955472, 75.56726194197132, 67.04320630719586, 86.44678715736636, 23.06807871787779, 0.22052807703373895, 4.534333953934332, 1.6671191107842231, 0.18530338491883971, 27.12278965980776, 69.0631720327562, 59.131766057783565, 67.46131527808406, 64.48036101556593, 70.58277668491488, 64.34866351466026, 65.33616335161271, 63.26093535269461, 70.16698191242834, 64.5325912967805, 70.5899703118109, 65.45310881830031, 76.29509695114629, 64.89356702373874, 66.32459671266618, 55.19402411676223, 45.80675678868448, 49.568345085267104, 54.72729736758817, 57.340647097556825, 48.38607995740829, 53.97362962845833, 69.73177925232919, 64.88155672627111, 58.260419368743904, 54.16436272282755, 58.4479949551244, 61.82362987149147, 54.308721634649466, 54.085660365320024, 65.01878476911976, 57.235723695447376, 62.18051064398981, 60.41803283076133, 60.58603971235214, 59.64219585541756, 63.61571373478059, 64.95793311826645, 61.58526351374965, 61.53348038273474, 60.76935952709567, 57.28303140209567, 57.38417363935902, 52.75045810207244, 52.35781708071309, 50.238042723747995, 52.668068716602946, 52.651422177591634, 58.77953329393941, 63.60156182319888, 62.63612924083587, 64.11589045678416, 65.39289259141492, 63.80177528627458, 61.14405962728686, 60.196913134667184, 63.367608131900916, 66.50082880450834, 52.810140886614406, 61.88821561874882, 65.29267211114207, 58.12091635119531, 56.3669853825723, 59.37580416279455, 65.972454163336, 60.74628030100177, 61.47524887515653, 55.47914512695805, 50.97380092067104, 47.4273193267084, 48.06113120048277, 48.05800507145543, 47.14914483408774, 50.84363314413255, 54.082075318982525, 54.844246756645944, 58.55120035909838, 58.3065660538212, 57.31956043551045, 63.173015425282145, 59.665683008009395, 60.96720780095747, 59.530851533336026, 58.50411622754989, 60.16351023027974, 58.26343174903624, 60.080206932560095, 55.76471328735352, 50.226099106573294, 58.701419291957734, 54.069739464790594, 53.2001264633671, 57.074314240486395, 59.93791118744881, 58.93947578245594, 59.372697645618075, 59.369026307136785, 61.76934426830661, 65.09520430718699, 62.68556679448774, 53.64646865475563, 56.98981854223437, 65.42687600658786, 59.32577040887649, 55.4331200353561, 51.48568984000914, 51.38318261792583, 61.23578033139629, 64.24734477073916, 66.0913255137782, 66.51662026682209, 62.68945386332851, 66.38529931345295, 62.517579524747795, 65.86325537773871, 69.15952113366896, 65.99583933430334, 65.10268818947577, 65.96165980062177, 10.304549874797946, 0.5403743359831072, 4.503791928291321, 1.7747013895742356, 13.397516242919432, 60.266633264480106, 67.80422456802862, 72.2919887112033, 71.30432805707379, 75.02269575672766, 87.90037047478461, 42.597724545386534, 47.29842239810575, 48.28700480922576, 40.27251997301656, 57.558236660495886, 60.80238588394658, 52.80821108048963, 0.40674077767518263, 0.14821979577743238, 0.1354057341814041, 0.13654800192002328, 0.1672627037811664, 0.2407731148864954, 0.21944801563457136, 0.16614694268472735], [0.02377031784084055, 0.053361896500592275, 0.1052928250283003, 0.02696608426049352, 0.04090701139742329, 0.04608363604112979, 0.029126883131421866, 0.02198316111800171, 0.058305331641027046, 0.019755055677265893, 0.11293985340143405, 2.117801404768421, 54.08067503283101, 51.397918962663226, 34.92533706849621, 17.984643828484323, 47.457117572907485, 37.361670232588246, 18.293561858515588, 63.238334655761726, 65.90938245096515, 52.55435528293733, 57.77426904247653, 60.660176430979085, 66.19876707753828, 40.25666183040988, 0.3429152960738828, 0.7960725443497781, 0.5282936197134757, 0.3000485398355992, 10.53945670204778, 53.03824240161527, 52.4218850751077, 60.18328682068856, 62.07206495346562, 64.1987269924533, 58.26700895063339, 60.29076760815036, 60.054840964655725, 62.184409479941095, 60.23983170909267, 58.9824688819147, 60.59322157213765, 59.25037068705405, 58.055306865322976, 61.49418607834847, 65.8888292312622, 72.32805098256758, 58.641885557482325, 53.136042779491795, 45.82244626937374, 45.48789947263656, 61.74871260120023, 58.90193869990688, 59.01535795580957, 58.544402891589755, 52.89014154864896, 52.19604284532609, 55.17271387961603, 51.01509563384518, 45.340222235648866, 56.02836716559626, 54.55834519478583, 55.063315053139966, 57.22606289771296, 54.86989513520272, 59.214277036728404, 57.860286620355424, 56.47494469919513, 52.29040722693167, 55.29645681381226, 55.95170051820817, 53.38933767810945, 49.375180121391054, 46.73337751819242, 44.41154226180046, 44.41513123050813, 46.42005074408747, 52.20436611483174, 52.381818063797496, 57.670522351418775, 53.321041368669086, 56.437827310254505, 56.70536041259766, 58.27148437500001, 60.02107720221243, 57.257979223805094, 59.467065949593824, 59.12500781397666, 52.08776973908948, 56.23308350962978, 59.93444773458666, 55.301661799030924, 56.9052993097613, 60.757839525899584, 57.4955258061809, 56.040746165860085, 51.59055832893618, 51.56132490404191, 47.79647319547592, 44.410683262732725, 42.6207527806682, 42.58971114312449, 42.388250366334, 44.292196304567405, 46.9589412596918, 53.04903284195931, 53.78850944580571, 52.552315650447724, 51.37129391393354, 52.47162072889267, 54.29807239963163, 52.19164194599275, 54.485628374161266, 52.80585373601606, 50.857585014835486, 49.46819128528718, 51.69247327312347, 48.554765409038914, 46.13938162403722, 52.9304164455783, 46.14102117476925, 53.212787874283336, 54.438010800269346, 59.5490474085654, 56.4043616479443, 58.2104326832679, 55.41280608023367, 61.18782543366956, 53.59088474704374, 58.73754039887459, 26.045744073006418, 27.751755445234238, 65.1818573090338, 60.264625010951875, 56.21480526462678, 52.61386548319171, 46.0496848629367, 45.22872101876044, 59.14649848015078, 57.7799133331545, 61.05687318309661, 61.60402813265401, 60.12320395438903, 59.50903531043761, 59.72536579255135, 59.362248451479026, 62.35708005966679, 58.28864866687406, 49.56528955890287, 2.1859842106219265, 3.4380324713645445, 3.81993894615481, 0.08255073124723089, 33.99032638918969, 59.38016191605599, 57.97048953271682, 51.36202535321636, 62.763021838280466, 60.33833419123004, 63.87981868559315, 30.118492034173784, 22.884431385224868, 35.14885333276565, 42.35682041414323, 41.444673230571134, 51.15158234873126, 25.937421937142652, 0.1104281268893711, 0.07878806742448961, 0.04660473287766499, 0.05091942050644467, 0.05924952734682349, 0.06646193488831482, 0.06187637389126805, 0.013869229925706262, 0.008376376635785545, 0.10119813869917586, 0.07678194362069331, 0.037185482665776246, 0.05406770096611112, 0.07297834772015772, 0.01291227885597055, 0.009390637785526774, 0.06817701422879774, 0.09677483895493132, 0.139858482345458, 2.743776628086644, 67.04228847257554, 59.79410532982119, 40.31521889471239, 26.569011788214407, 55.95353226507864, 43.88007287056216, 24.95306391869822, 72.75099231350806, 73.49177898899202, 57.10751318162488, 65.82958575217955, 66.47964800557783, 71.71562779334285, 44.25070547288464, 0.6028385712735115, 1.9455665758540555, 1.2312009858508264, 0.2706194560854666, 13.332661813305272, 59.53402080843526, 55.07891431931527, 65.29696318411058, 63.24690895695841, 64.55934970609604, 62.32035883011357, 63.75895869347357, 61.88836859118555, 64.03588587237944, 61.28646912113313, 62.23156813652285, 61.904061994244984, 59.87303126242853, 59.26753497892811, 64.95941185182141, 66.22391731508317, 74.16562649511522, 60.25002594917052, 57.26404713046167, 50.54782759758734, 48.188969089138894, 62.71531797224476, 61.41693892017488, 59.02882345261113, 58.79023744213966, 55.46581691311252, 54.95145297819569, 56.60037425256545, 52.786469382624475, 47.267427829004106, 57.65847283024942, 56.68324608956614, 58.30951175382061, 59.45731493734545, 59.84326439519083, 60.332689900552076, 61.76359015126383, 59.10190505366172, 57.94937933644941, 57.22548630929763, 59.70773473862679, 55.0086058339765, 52.3264185074837, 48.47461569693781, 48.34710336500599, 46.00314986321234, 50.44910546272032, 53.9718214158089, 54.86225435810705, 60.633025784646314, 56.49773759226645, 60.10355287982572, 62.442850528224824, 61.002489520657456, 61.039038165923095, 59.29483467532743, 60.37249019069057, 60.1012033800925, 51.75896529228457, 56.77302522044028, 62.3521770969514, 57.3302802731914, 58.519338946188654, 61.90161051288728, 62.9042193197435, 58.668808706345104, 54.83155396676833, 54.806164464642926, 49.619814426668235, 47.27127175177298, 45.74116691466301, 44.460477752070275, 46.610069967085316, 45.76898436392508, 51.176285436076505, 54.52314976722964, 56.22702737008372, 57.15572303341281, 53.786003051265595, 54.39933623037031, 54.35494676713021, 55.40614981805125, 56.52658662488384, 57.08894468122914, 53.45298205652545, 51.34197027452531, 54.5682531018411, 50.356670887239524, 47.582256870885054, 53.88631766842258, 48.52919940025576, 54.91350404677853, 56.98515092172931, 59.239395895311915, 58.421942572439875, 59.682231487766394, 58.91241535063713, 65.35845025893181, 56.00101255601453, 61.88106121555452, 26.909328391475064, 29.540487643211122, 67.98051157305318, 62.5950934040931, 60.38978392078031, 55.92053728718912, 48.748569719253055, 47.16036281278057, 64.44880162515949, 61.417354691413145, 63.045240294548776, 63.21108202780447, 63.191999696916156, 61.59650110429334, 65.43339106344408, 62.11418336437595, 65.03205414741271, 61.09878370838781, 53.2504661621586, 2.122810026330333, 5.077973969521062, 4.455821831380168, 0.5165008299293057, 38.88867247489191, 57.17667241250315, 65.76255244593467, 57.076702963921335, 68.27693293171545, 65.9007610813264, 70.08122321098082, 36.19655762949298, 25.662216678742443, 38.96995182960264, 51.79152488708497, 48.413101165525376, 57.904601558562256, 34.633806905438824, 0.2620783111741466, 0.12125769900458476, 0.08332582070462166, 0.04180354494301062, 0.043826017063111074, 0.07847518179445498, 0.04262611652994829, 0.023631657841765595, 0.09414983102150502, 0.1895462709569162, 0.24938222711845753, 0.12417889185129635, 0.18587649529499395, 0.13212934466859988, 0.11492628874557634, 0.1190602983678541, 0.22694786319569235, 0.23170818033958637, 0.33311874755928594, 4.466238175669025, 80.77865631349626, 69.16716975550499, 50.99331863464848, 25.405668174066854, 68.93919375634962, 48.428523925042924, 26.767785741436867, 75.46620599685177, 81.7715415646953, 61.85595020171135, 70.64890000127977, 70.58642448917513, 80.21462732745756, 46.961765366215865, 1.081370857934798, 2.9313544208003632, 2.2279454815772275, 0.4422695454089873, 18.376521948845156, 65.77128756430842, 59.65812852305751, 65.51675319671631, 63.774503046466464, 67.56554049830284, 62.996159676582586, 66.87731358312791, 63.1167019567182, 65.71296191984608, 66.51034447454637, 65.88210628878686, 65.05727890999087, 60.80091891750213, 61.89287539451354, 68.82169523546773, 67.85932602420931, 70.38556775739117, 61.33781686905892, 60.66437336706347, 55.69597375008368, 52.06389819422076, 63.1860141600332, 64.93727007219869, 63.65217216553227, 61.420265090081, 58.02335131552912, 59.07160474408058, 59.28552296853835, 56.39843494661393, 49.96719129623906, 61.97110706760038, 60.660423540299945, 63.295813068266845, 65.14652067615141, 61.903528551901545, 65.75144429360667, 65.31510022378737, 64.58466860555833, 60.51331504698723, 60.04542727624217, 61.95131478771087, 58.851387193126065, 56.757237680496715, 54.59902801821309, 51.135006412383056, 50.44014676924675, 55.30051646694061, 58.9516233628796, 60.260828156625074, 65.33265675267866, 58.91986785396453, 63.45360217555877, 64.91419084610479, 61.129644916903594, 64.79897514466317, 61.30019741673624, 63.810514327018495, 63.763359592806914, 55.99048491447203, 58.478773793866566, 65.21681347200948, 59.30472689290201, 60.76160500126501, 68.03839006731587, 64.22290840456563, 63.87764961488786, 56.215530903108665, 57.77256281145158, 54.76193974095007, 51.865194843661406, 50.656771429123424, 49.23353941209855, 49.14085380492672, 48.353445837574625, 52.949949849036436, 56.44072986418202, 61.66687234755486, 59.7818910691046, 57.84209466749623, 59.133476211178696, 60.04157943110312, 56.700010299682624, 61.134045816236934, 61.25545494018063, 56.17420088860297, 54.66659868917158, 55.13895011717274, 52.9700598409099, 50.91325129232099, 57.82438908853839, 49.44992480739471, 58.00304520514704, 58.10729788195703, 63.98775054562477, 60.94010030069659, 61.16578171330114, 61.51794779685236, 67.93486302898776, 59.40566908928656, 62.75069382882888, 30.750691813807336, 34.870976940278084, 69.56682789710261, 65.59464754596834, 61.79246271810224, 58.00305697225756, 51.41776223336497, 49.99322014470255, 67.90963434403943, 63.56991221827846, 67.20255651781636, 67.14347777828094, 63.99361056666221, 64.49022577654931, 66.26150146607431, 62.24363726954307, 64.37360194421584, 61.01849671333068, 58.264608460087935, 3.710670783635109, 4.309827781492665, 7.462421530677427, 0.4632701298161861, 48.81568539527155, 70.68898662444084, 70.0438351784983, 62.79623646889964, 73.91842303737518, 71.25794995215632, 76.4135289961292, 39.489850228832616, 31.802008613463375, 51.09973645979359, 57.30004272153301, 58.19642982175274, 66.37310858695739, 51.06661204368838, 0.34472645050094974, 0.22086176961179704, 0.18662073439167393, 0.22034207088572366, 0.15755099184330434, 0.23139675027660786, 0.18714329828658413, 0.08948630908684385], [0.04864944069976768, 0.029632886120628928, 0.03807570747730713, 0.04675205158550413, 0.08179798091371214, 0.045301096378675396, 0.022337494019959724, 0.020356279565021396, 0.09424523961159492, 0.14002965703125925, 0.03274472377773735, 0.12937334336100087, 35.45773606146536, 50.68371418983706, 38.57027015378399, 34.40338726966612, 38.644673593582645, 36.68098211288452, 10.528518192229733, 44.47166435180172, 71.09117077242944, 57.450646046669256, 55.508198122824396, 62.195141084732555, 62.364689457801084, 57.52235481815954, 1.768607742363407, 1.099263484920225, 0.788813524188534, 0.2264259121711216, 4.358236203270574, 41.56310919792422, 58.62524686321136, 53.416107854535504, 59.6058629405114, 61.03657491745488, 61.87080813992409, 59.702282644087276, 59.43009368834957, 55.16937202022922, 58.211087719086684, 58.8859824980459, 60.51477024632116, 60.56548257027904, 62.11078266943655, 57.214993969086684, 57.44464482030561, 57.87585842993952, 60.53933997308055, 58.57493069864089, 68.376600357794, 62.32257104689076, 56.245411519081365, 61.75245061997445, 58.2021447150938, 57.5051748368048, 56.08937178888629, 52.00254055761522, 52.95131875622658, 51.963928745638945, 44.728203050551876, 49.904445140592514, 58.53679741582563, 53.996783379585516, 55.709498082437825, 58.44642600705547, 56.85039789445939, 58.24489854997205, 55.30119111461025, 57.75089956098988, 54.603366159623675, 55.16576736204086, 50.475173534885535, 48.57108246895575, 45.73098444169568, 47.245360574414654, 49.21306071742889, 52.35715420015397, 52.54861293300506, 55.62852859497071, 56.173938089801425, 57.65363262545679, 54.49385750678278, 58.29323783997567, 57.639947475925574, 57.8889669910554, 57.8024551945348, 59.22707965297084, 58.103779515912464, 46.747294087563795, 53.4779400979319, 61.679996598151426, 57.615216931989124, 60.554597993050855, 58.20032865770402, 59.130197109714636, 56.44216545166508, 54.506134525422134, 53.66178158790835, 52.86448140298167, 49.273108282396876, 45.86431364859305, 43.22312293514129, 44.123808953069876, 45.088727704940304, 47.893516555909194, 50.79181078941592, 53.25756565217049, 53.99374746507215, 54.25273764518, 53.777942580561486, 50.62180349903722, 52.53970523034373, 51.70023172132431, 54.200150428279755, 55.495862268632465, 54.68624191899454, 52.404391304139175, 47.26947138386388, 50.09336217757195, 51.17759158534389, 49.26386325590072, 54.88780075503934, 56.795233680355935, 55.85574365431263, 59.63244876553936, 55.58280552587202, 56.97306217685823, 54.79139281857399, 59.76141629680511, 33.81104269335347, 28.319812705439908, 48.71535508863388, 46.36412559017059, 48.105151960926676, 61.73607472450503, 59.692339435700454, 55.594184321741906, 46.14668507729807, 48.72881666306527, 57.45115595479166, 59.01389491173529, 63.74163358442245, 60.81566310697987, 56.586979358426994, 54.78458750632502, 59.46836817649103, 55.26817260249969, 56.39055490493775, 27.006422742720577, 0.4977979577116428, 10.323963645965824, 1.1537938685186448, 1.6365949809551241, 51.89899390743625, 51.41800934268583, 57.45612167542981, 61.31210573257939, 56.815873192202666, 60.91650332173994, 62.407066745142785, 26.501570555471606, 33.441743696889574, 36.69411813059161, 43.00276810123075, 28.7582826998926, 58.364746570587165, 15.326778138837508, 0.2690616009696838, 0.04125629386474048, 0.012136592807608747, 0.04958518262531969, 0.014257823237248007, 0.04669511210053198, 0.06863420784112907, 0.04829261226639633, 0.040858253731482455, 0.06479401592045061, 0.025378830520616426, 0.049371210437628536, 0.06518232290663066, 0.03632833370037618, 0.03995871329079232, 0.0532134439826252, 0.10520146138245061, 0.08649885729556123, 0.06397257814364088, 0.31157632448500205, 41.19078605405746, 64.44128244153916, 35.191791519041985, 36.46105089495259, 51.318232090242454, 44.06724837518508, 15.522292602446774, 48.28076824065178, 79.11862296442833, 60.45462069972869, 61.79578888800837, 68.90105262879403, 67.22454532500237, 66.2343272855205, 2.5662501540876206, 1.3536420608720472, 0.9204420158939978, 0.7107631381480926, 5.305053707092039, 50.039508035106046, 62.082804402997425, 54.407522216919936, 65.18614838200232, 63.908495133922955, 63.65703590454594, 60.78949305319018, 62.49886589665567, 57.09847996311804, 59.887591100508175, 61.40974529327885, 62.143726656513834, 62.22433136355493, 61.616242393370605, 60.425540247271144, 61.28967761993409, 57.85639955151466, 61.9919740769171, 60.083556636687256, 66.01679263576385, 64.91616772067162, 58.691005399150235, 61.31318830674695, 62.15159100870933, 59.35510973776541, 57.52282158021004, 51.78815164873677, 56.12183724680255, 53.107852705063365, 46.71555426812942, 52.34686974556216, 61.44791779979583, 57.05753041851906, 57.28604378238801, 58.72660090846401, 58.238493319480654, 59.855592404642415, 59.47647963800738, 59.77542700306062, 60.17509298939859, 58.605321222735995, 55.17165091729934, 51.891498258036954, 48.62938850156723, 48.93608254771079, 51.99920654296876, 57.88009066735545, 56.21308334412114, 58.965751740240286, 56.12040558168965, 60.592480244175086, 57.80906046590498, 61.463658271297334, 61.11101758095526, 59.99004340940907, 56.2612186708758, 61.13328879879367, 60.324507836372625, 49.708601197888775, 54.904482595382206, 61.30113486320742, 56.53914213180543, 61.967745596362704, 61.04201132251371, 61.5068906353366, 57.07027419920891, 58.077464334426395, 56.71906125160956, 56.58462201395343, 52.29674185475996, 47.35683433471188, 45.98822524470668, 44.30768574437788, 47.615236159293886, 49.53594630764377, 53.973304071734034, 55.75019267297561, 55.52757463147564, 57.92621774058188, 54.201770367160925, 56.14123728967483, 54.33994762359127, 55.253773581597116, 57.84683289066438, 55.994532800489864, 56.861533503378595, 55.361281825650124, 48.41279129828177, 52.58920554191836, 52.58624807480843, 49.65514713718046, 56.77604544547297, 58.390438095215835, 57.39656440673336, 60.96283435821534, 56.48852394473169, 59.19633611556023, 57.11600903541812, 60.38015450200727, 33.71858458365164, 36.051818247764345, 52.8312942289537, 48.33573241387644, 51.88196689851823, 62.152230355047415, 62.71450604161909, 58.854505477413056, 50.611256245643865, 51.03143622798305, 60.396855954200994, 62.11941972855599, 65.1551224339393, 64.0472960472107, 58.84104390298167, 56.97608632426108, 61.33820126133581, 55.81167582542666, 61.99452753989928, 31.67710465769614, 1.2755314909642743, 13.15544814832749, 1.3471938068828275, 4.395892427813623, 61.40106508808752, 54.787933288082, 63.938767986912886, 66.87654479857414, 64.2966881875069, 65.6776370540742, 70.56154097280195, 29.121590275918287, 34.30730488992507, 43.34849365295903, 49.59398561908353, 29.1124923383036, 66.62925504869031, 17.66069527595274, 0.30169259516462205, 0.14459535719886904, 0.025908434763550762, 0.0735646577912473, 0.028659176877549583, 0.10427587395233494, 0.056140635297783924, 0.0547947030844948, 0.12966388986716348, 0.14946396853173935, 0.1931082886914092, 0.15873418399883857, 0.19948284502231306, 0.1410821545869112, 0.13352454399629948, 0.20299874426376438, 0.2537748373804554, 0.3487900566429861, 0.09768174150057378, 0.42315194383263594, 56.0822016962113, 71.51074670976209, 57.57481259684409, 47.6485017807253, 56.64999615761542, 49.245871343920314, 19.357614594121134, 55.08618247124457, 83.23484451540055, 69.4600845152332, 67.42089917582851, 72.32536023662936, 73.20352400502851, 69.39919364067816, 3.8892555621362503, 1.7528921533976833, 4.0201695696000135, 0.6319119144351252, 8.554552062865227, 60.05917910606631, 63.6110657261264, 59.443366989012695, 67.92566899330386, 66.40643304394138, 67.07851548348704, 63.42085430699011, 65.55312925769438, 60.392235402138006, 62.98021131946195, 64.9947484847038, 65.27069507106658, 63.66842646752635, 65.14776406749603, 61.94013603271977, 64.54432702833607, 63.921317362016254, 64.0996322324199, 64.19738554185437, 67.14762764592325, 64.04775888689103, 62.446894491872484, 65.05583940013763, 63.447318538542724, 61.459943786744155, 59.80092633155085, 55.51350508966754, 58.269727153162805, 55.470617894203436, 49.579967068087676, 55.567265095249304, 64.80928705584618, 60.228374465819336, 62.188724087130645, 63.77903730638566, 62.057916964254076, 63.842285525414255, 60.84502597008983, 63.12455454180318, 62.64569197931598, 62.780193974894864, 58.28955865675404, 53.56077271123087, 53.01002094822546, 51.5820271738114, 56.129117165842366, 60.9515614663401, 58.07613465093798, 61.44452887196695, 60.45742127203173, 65.65558941133561, 62.78918796969999, 65.67989633929345, 64.54813957214355, 63.77627595778435, 61.810909625022646, 62.98114484356296, 64.14226447382282, 48.51764802009829, 55.854527719559215, 64.66463396626135, 60.37447098762759, 62.76942706877186, 65.03139518922376, 65.78842439959126, 60.72759805187103, 62.88152056355631, 60.88295921202629, 60.63726978917276, 58.072832015252885, 50.659532777724735, 50.56628627161826, 48.523135415969364, 49.876364892528905, 53.24153884764641, 56.12483001524403, 59.74316158602315, 58.43746339121173, 61.934723161881976, 58.30334578790973, 59.59719450243058, 57.24345860942718, 58.486512630216545, 61.683601256339784, 61.26157383764944, 59.31681171540291, 58.3735679811047, 52.54251756975728, 56.260155708559104, 54.96887222413094, 54.21693817261727, 58.376266571783255, 60.24751563226024, 59.686757902945246, 60.33250554915398, 58.91339594318021, 62.620184806085405, 58.37982023915937, 62.96919338164791, 39.470685528170684, 33.87980968721452, 49.90038548746417, 51.24637034631545, 55.39832076718731, 65.02762579148816, 66.5572089533652, 61.4601359828826, 52.31081531893823, 54.05240258862896, 63.963070992500555, 65.13188631303849, 69.85116051089379, 67.53641297740322, 59.94370060582315, 58.16756117728449, 62.72979936292095, 61.53522583746142, 64.51188902701101, 38.53354500186059, 1.0757176193498796, 15.992628912771902, 2.4907844874166676, 4.661707041725036, 66.44331116830149, 59.72711516964821, 69.44439503454393, 71.59903926234092, 69.83079556495913, 69.55639439244425, 75.56244527139972, 34.629825699713926, 50.02564637891708, 49.40681403683078, 61.2883714706667, 41.88482592182775, 77.86013833938107, 28.928846966835764, 0.4099682448131423, 0.3501465225652341, 0.12234224967898862, 0.25685906139833314, 0.2543805677804255, 0.19835301855158424, 0.14764478550322596, 0.17686696422676887], [0.06892637845369116, 0.07163585524164862, 0.026733229920688658, 0.012447176343430916, 0.03435624335261603, 0.02670198119425726, 0.05243452025517341, 0.0413057103662962, 0.015282421785917495, 0.18041929860989894, 0.10199671641232506, 0.4841949328059151, 16.342466089033312, 54.83565676596857, 47.81597521997268, 35.9072083042514, 23.554995867513842, 40.016687300897416, 11.567963938559256, 46.54028315697947, 66.5727101602862, 65.65765650041642, 53.29916238784791, 59.73240252464049, 58.60550165176392, 60.76740226437969, 26.2069966331605, 1.426946624152122, 0.5467150312277579, 0.3905050150088726, 14.34924896686308, 32.59541192362386, 50.99695467179822, 58.09344407050841, 60.87164317407916, 63.41609254960091, 62.43265628814698, 61.09656364687028, 57.1800809521829, 55.66506155075566, 56.99627084116782, 59.315846812340524, 59.63872063544489, 59.043948111995576, 61.069491447940955, 56.93607422613329, 59.60300745502595, 57.45224637369956, 59.071612588820926, 60.86963099818076, 56.21433850257628, 62.60073377240089, 61.54400017953689, 59.23321816229052, 59.793587576958444, 57.28603593764767, 55.775087956459295, 55.469637301660356, 53.85271080078618, 55.995995844564135, 48.16968279500162, 47.44566425200432, 54.87425288846416, 57.06639497510849, 55.19616573087631, 58.15489192162791, 53.58480507327665, 55.748698249939956, 58.013537545357984, 58.47329032036566, 55.47033548355103, 53.01822654662594, 48.10763482124575, 45.25524408586564, 47.27303681835052, 47.809491542077836, 51.26976336202314, 52.23367798712946, 55.041942058071015, 56.678527478248846, 56.82713823933756, 58.317701662740404, 57.3387800493548, 57.65514273797312, 60.49348746576617, 55.467927148265225, 57.13641712742468, 57.83809384992046, 59.32827288104642, 48.08271600354103, 49.43800472444104, 60.41366331038937, 56.67741744749008, 54.630438358553, 58.28622464210757, 58.100465113116854, 54.66030328504501, 55.77867300279679, 55.10659840799148, 51.736599937562026, 51.93275374750937, 49.25187649265413, 46.01265376613986, 46.42236102011896, 46.46418525326637, 46.04296584283152, 50.58668651888448, 51.709770925583385, 53.77227083329232, 53.94097197440363, 55.3271258261896, 53.09364195792906, 55.146802702257716, 51.668856682315955, 54.25449878938737, 54.370157718658454, 54.89318616928593, 51.12690671797722, 44.35329898711174, 50.386194567526545, 50.084434863059755, 49.09624861132715, 57.994353232845185, 58.1784692887337, 53.58080425570088, 58.01303155960576, 52.723409437364154, 55.475611071432795, 55.70635234155963, 32.53617432809646, 35.6276099912582, 66.01366258436634, 59.83407428187709, 57.327099230981645, 51.59910909591183, 52.81530272576117, 57.68984002451743, 60.63899955441875, 52.681918605681396, 48.67330335801648, 48.384291356609715, 60.502771715964045, 58.60374050755655, 61.65069257059405, 55.0161014833758, 59.59703760762369, 61.49616295291532, 54.125574404193515, 55.658683776855476, 13.728430924877046, 7.038725633775035, 11.676244889536212, 0.5123812993687968, 28.25140460844963, 51.224938515693914, 47.66778807486258, 65.54787720403364, 58.050545107933786, 62.065604809791814, 62.961505536110174, 56.32437667539043, 32.638608986331576, 41.458934968517674, 36.173658832426995, 56.84433391017299, 42.62140781648698, 56.06214269515007, 5.20591187861658, 0.0367406192385862, 0.16350386273716727, 0.03984060168506638, 0.03471479931425664, 0.08153699007966826, 0.08906257053416583, 0.039550219887807485, 0.07018964977995043, 0.04936790859867488, 0.07670903503293953, 0.026708138625948664, 0.05203513180716865, 0.04901849206597094, 0.14418563805520535, 0.0563841401749561, 0.020952673268414313, 0.10363263588759208, 0.14475445833898362, 0.10298516901750719, 0.2717534194309866, 20.09402390449278, 67.75127257070234, 52.36020580414803, 42.54973434632824, 36.57586259226645, 45.916681212763635, 15.356751911101805, 48.924233067420225, 78.17564595130183, 72.47264523659983, 60.22215750909621, 68.79205780644571, 63.39289565240184, 68.32029865634057, 33.889372425694624, 1.8475447066368598, 0.4888376707751905, 0.35253585887051403, 18.273614645004272, 40.345527049033876, 56.219684693121145, 59.864413815159956, 65.04656691705027, 65.62180211467128, 65.81113492288898, 62.390486886424405, 61.19953370863392, 55.89866615110829, 59.76536612356863, 60.203828273280976, 61.78410414726504, 60.58083472713348, 64.15743620164933, 58.87858883027108, 61.365210702342374, 59.454561433484486, 62.087993698735396, 62.47144852915118, 59.674814285770545, 63.786034814773075, 64.4715827511203, 61.067957801203576, 62.02856586825464, 58.00360610408168, 57.51570247834729, 55.51306186183807, 58.42662196005545, 56.2871612271955, 50.8884423009811, 48.51025435232347, 57.355214780376805, 61.10808364806637, 59.45353769486951, 61.778334340741566, 56.17328697635282, 59.01366349189513, 60.18326328646753, 61.590429275266594, 58.69587306053408, 56.0932667024674, 52.7784049895502, 49.42059332324613, 50.39312147325086, 52.180384743598204, 53.316001122997655, 57.749389448473536, 57.705039208935155, 60.20306733346755, 60.916617070474935, 61.91186358851772, 59.809575157780806, 59.74260460945868, 61.467411979552246, 56.38769549708213, 56.80579662322999, 62.807305397525916, 60.946442773265225, 48.817670114578746, 51.041630468060895, 63.0129474209201, 58.07736627517208, 57.409300342682876, 57.650522185910134, 63.33984559582126, 59.23652079797561, 58.98289249789331, 57.14689377815493, 56.91426192560504, 54.4794741753609, 50.21020958500524, 48.72272522218766, 47.91443455603815, 47.11506335966049, 50.88752838873094, 53.15130864420245, 54.36108919882006, 56.141009792204834, 55.216530676810976, 55.361528934970984, 56.26284253212714, 56.88911953280049, 56.1730202551811, 54.47690502289803, 57.08157847004553, 56.27712388192454, 53.149249399861986, 44.92737316316174, 51.71760782118767, 48.91003016502627, 49.21028367934689, 59.299906299960234, 59.63134265715077, 55.0965218390188, 56.91679969910653, 55.82423133234824, 57.78434953381939, 56.529500945921875, 33.017182427067915, 46.403196319457024, 72.20344512693345, 58.32173778164772, 56.577691185858946, 54.216334127610736, 58.00353942378875, 60.42643454767043, 62.842104665694706, 56.08755573149651, 50.815137124830684, 51.30769268158944, 62.67731020527502, 62.4659062200977, 66.25110718511766, 59.48091976104244, 62.227892875671394, 60.926046448369185, 58.69068768716628, 56.85271601523123, 13.595059552500325, 10.5665083085337, 14.00384504948893, 0.7743937269814554, 37.98947695762881, 55.340042191167036, 55.329385111408854, 67.96083696426885, 64.38087794088548, 67.12840803207891, 69.69590525473319, 60.94186536727413, 38.384577305086204, 40.066536703417384, 47.18480310132427, 64.20271212054838, 43.76837945753529, 64.06706871524935, 5.609771368965026, 0.12582780417775916, 0.15842135965583787, 0.039997063652281804, 0.06674365606158972, 0.12023314067553129, 0.02496123407787133, 0.041318523186829784, 0.006400733555276548, 0.13512580565387203, 0.17806791430038793, 0.07399718337241681, 0.18744162824605742, 0.199004331183049, 0.14745588354285688, 0.127958195103753, 0.1727825971019845, 0.25862818824187406, 0.3426283501809643, 0.3673201913554823, 0.64661473516495, 29.72376431188276, 78.57011087479131, 70.98423127205142, 52.96475679643693, 37.265132857907204, 56.51496071969309, 18.496115015399074, 59.600022531324825, 79.98568642523982, 76.8794830383793, 63.01608139468778, 74.02009087224161, 67.99432616080007, 72.51246513858919, 37.49534853043095, 3.120157709044795, 1.971126578507885, 0.6697125312301421, 20.56856401505009, 49.49866417915591, 62.67606289156022, 64.82814973400485, 66.75895998554846, 67.49998200324275, 68.1270670121716, 65.75759457003686, 61.989067600619414, 58.19854005690544, 60.572868393313506, 62.80248480458414, 63.3676395108623, 65.64465776566537, 68.75084154067501, 62.16351893640334, 65.48968492015716, 60.52637261729087, 62.97277842798541, 64.74849816291564, 62.52308261009955, 64.22020981388708, 65.50685313440138, 64.27431891041418, 65.83339829598704, 62.03144881033129, 58.507124685472064, 59.2072638388603, 61.48996560804306, 60.654006542698035, 55.086315831830426, 52.21581159099456, 61.53990914744716, 64.12477462522446, 63.111045898929724, 66.9431858678018, 60.73447004441292, 63.04993929401521, 65.8004503865396, 66.3988079563264, 62.69239956332792, 59.64884427285964, 53.60940617899741, 53.269360219278646, 54.849020281145656, 56.83585766823062, 58.05939789741271, 59.543881647048465, 59.1599129861401, 64.9370974879111, 62.88581555889499, 65.12629301317277, 62.43996758614818, 65.4746190963253, 65.53677689644599, 57.65897489363148, 61.03791636805381, 63.87520205590033, 65.50416631083336, 51.92567779171852, 51.97817871647497, 65.61517723145025, 61.31971905308386, 58.414847004798155, 62.50897384458973, 64.66675989089474, 61.727849514253684, 63.44061128554806, 59.95622081141318, 60.0692674421495, 60.46462666603827, 56.68365401606406, 54.05246534655171, 52.0642747417573, 50.871442748654275, 54.084926882097804, 56.10752451804377, 57.93861243032641, 59.69900746499339, 59.738744997209125, 59.45173340459024, 60.065784377436486, 60.08253682044245, 58.381808880836736, 59.647141964204856, 61.45815518594558, 59.470541169566495, 54.37731604422293, 47.91324215550577, 55.14695959706461, 53.16358958521197, 52.940057631461855, 62.30425357818604, 60.557982998509566, 56.25633139764109, 61.35641282604587, 57.480934589139885, 58.172436683408684, 58.75768569207961, 38.62072360131049, 43.51661036091466, 65.86141186375772, 62.85129477900844, 57.57304753026655, 58.84025550657704, 63.165613912766986, 63.03400270400509, 64.03826282870385, 59.847351504910385, 54.02451845907397, 53.92348212580527, 65.69341282690725, 67.66469801625898, 67.75250419493645, 60.40991352450464, 62.156576341198345, 61.98385084829023, 59.260027562418294, 61.61055103425057, 20.49476658144305, 8.83191756663784, 20.38314965463454, 0.9678831444151941, 41.826496354995236, 60.09280558555358, 59.43747951138405, 74.44166721836214, 68.6292637548139, 71.30406918064241, 75.11302794179609, 69.1372577605709, 42.47688024274765, 54.88072872161866, 48.635236755494155, 80.6617618376209, 59.70586769042477, 75.84853510702811, 11.346472597891285, 0.4339399326953196, 0.41043071677127196, 0.12493550326795348, 0.12583571020513773, 0.18372893633861698, 0.2756056159494385, 0.17003113103489723, 0.12461311048677853], [0.05614198361253066, 0.04901116060453558, 0.06926400106280081, 0.10367409656605414, 0.021913148342601715, 0.09422869977330971, 0.08384011851082887, 0.04636161487489458, 0.05408220684095737, 0.09686907543049705, 0.06051236583340553, 0.22484328177186752, 3.1746781641437165, 47.05777714329381, 39.97888741954681, 47.41382245094546, 26.65740828360281, 51.10123088282924, 19.275444861381285, 21.68059910497358, 66.97022668776974, 55.926981741382235, 65.52755932654104, 55.02585641799435, 67.57650744530463, 57.401498748410134, 55.415171269447576, 3.8412624213003346, 0.6201393493721562, 0.46116660559369677, 43.05884230521418, 32.538139435552786, 39.0803430157323, 55.72549350800053, 58.759231105927505, 61.41598578422301, 63.02541271332772, 58.6561708296499, 58.01249419489215, 56.03951846399615, 54.48045476790398, 59.43713042043871, 59.03281642544655, 58.72533398289835, 63.1197770949333, 57.339611591831336, 57.326652080782004, 60.94215954503706, 63.49863882987731, 64.36143082957115, 62.42012039307625, 59.136598417835856, 59.29440713697865, 58.06536774481497, 55.64637537925474, 55.49171632336032, 55.201629592526345, 54.78909430965301, 54.17639655451621, 52.94564308658723, 49.49440840751895, 45.87399405817832, 47.387393520724395, 58.819188456381525, 56.05234069208945, 56.786122014445645, 57.70243475514074, 56.44387168269004, 57.904570179600874, 58.731401889554924, 54.782343910586455, 50.46894873342207, 45.77507188243251, 45.539561010176136, 48.77097429767732, 48.911842300045876, 54.09181848649056, 54.15959312069801, 55.139283518637384, 56.65990798704086, 56.80001504959599, 56.95312084690217, 56.02203253776797, 57.980515110877256, 58.382004999345355, 56.75619433003088, 56.0768594280366, 57.58119037074428, 59.60265444171045, 49.81545440612301, 52.27411370123587, 61.337126531908595, 55.92671894258069, 57.089234936621885, 57.83345760837678, 55.8012423207683, 54.94979773798297, 56.82104679845995, 55.0084646286503, 56.331554612805775, 56.51852223180956, 52.36629724502564, 47.057679084039506, 45.66593193238782, 46.7899969316298, 45.28869405869515, 47.67841377565938, 51.79442744101248, 52.96991471321353, 52.26520992094471, 53.38701955733761, 53.65942816580496, 54.73327505973078, 53.550476489528535, 51.80528456164945, 53.09923918016496, 54.844544856779045, 45.476450074103575, 44.398100299219934, 50.690072351886386, 52.21890634106052, 50.11176201605028, 56.5887914934466, 57.005959095493445, 56.44873542170371, 52.936280388985914, 49.55646422601516, 50.55699809905022, 30.736245724462695, 41.79561161225842, 69.29348576453425, 57.346369835638235, 54.69695783430531, 58.26754239297683, 74.02569986158802, 67.35112021046301, 57.64760394250193, 61.146436583611276, 53.97048388758014, 50.78182051258703, 49.13425637829689, 54.125750910851266, 55.83377838134766, 60.317000419862815, 61.41627603961576, 51.84525351370535, 59.85201520304526, 59.455847970901004, 33.96760802115164, 13.898421545182506, 21.459761819531842, 7.407014129623291, 1.715359238366927, 65.66623472398328, 62.46929514792658, 62.326250230112386, 55.72293220027801, 61.338946511668546, 50.93383981335548, 71.24422950129356, 49.623587746774, 39.48178975812851, 36.30169676196191, 31.1261450090716, 34.551221401460715, 36.147253436426965, 43.98620044031451, 0.8899383559342354, 0.05096702904049909, 0.04384504285671058, 0.18747067830014616, 0.048951256359296466, 0.015861452106506597, 0.043913603895494056, 0.04572396159111973, 0.07252827872552219, 0.013902987590089682, 0.05573951932150991, 0.05427673954756991, 0.02217434027472571, 0.08894763436288604, 0.058707052826761245, 0.05555150219269338, 0.022956071714419993, 0.021588083829790838, 0.10347345047780585, 0.058731276526926994, 0.23029629561689594, 4.17526695036119, 59.39927562590569, 45.21273736030825, 47.222308804911954, 41.315042818746264, 52.65817257665819, 19.375067180202855, 25.07811104097674, 75.87012383245653, 65.89410874151415, 70.07674386424404, 61.47793962109474, 74.78087379086402, 61.24096570476409, 65.41477157223609, 6.7697250746911575, 0.35297957699625726, 0.15818021049903286, 52.39684074155746, 40.63562554697837, 44.981023342378684, 59.01613850747386, 64.06691574281263, 64.97704290574598, 63.80312850398403, 63.43970914040843, 61.532507634932, 57.96125627333119, 59.08496825925766, 62.74242547250564, 61.654540415733095, 61.533362711629565, 63.02333385713639, 60.53503321063135, 60.097751694340865, 62.77737771311114, 63.13871822049541, 64.5224323580342, 65.84019184112549, 61.84368887255269, 60.08036774973716, 59.21908194018949, 56.67447566986085, 56.46727254313808, 57.302423600227606, 57.265125782259055, 56.90370682747134, 53.77050184434461, 52.22980660776938, 49.420142250676314, 50.93764059005245, 60.53559803193616, 58.4172631848243, 56.823380608712476, 58.80999834306779, 59.630581717337336, 59.20629893579791, 58.92508068392354, 56.6469249417705, 55.06478986432476, 51.36077411713139, 47.95119893166327, 52.82930166490617, 51.23854914019185, 54.27292608445691, 57.04211942611202, 57.823467331547896, 59.63200553770989, 59.259247010754, 58.135405586611846, 60.33023449682421, 59.70342405380742, 59.380044244950824, 57.8168502930672, 57.67923393557149, 58.58480330436461, 59.15904614233202, 49.444613918181396, 53.73370216738794, 61.49411547568537, 57.50484535771032, 57.69593931013539, 59.23543430143788, 58.66770652032668, 58.925696496040594, 60.00408549462596, 58.904088158761304, 58.90291929244996, 58.280454835584095, 54.26207680856028, 48.39718418736612, 48.4945099584518, 49.74254931173017, 47.983103490644886, 50.47714648708221, 54.17682017049482, 55.31224043138566, 56.408480136625236, 56.32869520495015, 56.98815153491113, 56.50134225045481, 57.73928150053948, 55.59929124770626, 59.36655129155805, 57.68614907418528, 47.19370688161543, 45.04446767991589, 50.52437182395689, 52.40242227431267, 51.5415757702243, 59.14709468041698, 58.89379193705898, 60.75543511298395, 54.981945483915275, 51.52301903693907, 50.64725968145555, 32.152142909265336, 51.330583633915076, 77.27541492831323, 56.68046512911397, 56.795123853991115, 61.444670077293154, 70.22948095875402, 67.9177850292575, 62.24883441002139, 61.95764157079882, 58.39429770746539, 52.23036358433386, 52.570640963892785, 55.635098565009336, 59.583909434656945, 63.13960859852453, 64.36457657044934, 52.76351567237608, 68.0027671014109, 58.9605075313199, 36.06666049649639, 19.425212721670828, 29.282838913702196, 9.085706683897204, 2.791398124348733, 72.82004171802153, 63.95533607852075, 68.45147055964317, 61.23344259877359, 69.29543126013972, 53.783171100001184, 77.5767235602102, 57.33507340954196, 45.10067524448518, 39.42045173337383, 43.00432135981899, 40.25861124838553, 41.17937195685602, 53.887015850313254, 0.5167403396579527, 0.06415657331085493, 0.06958584992154952, 0.09705942529704302, 0.12573244921382398, 0.023756302262265837, 0.03650712330014475, 0.03969620560265837, 0.010777039551025918, 0.3540036526899184, 0.11516044351963267, 0.1609774733022336, 0.16332583922532298, 0.23716658744360172, 0.1896236764807855, 0.1497078296397963, 0.134745764756395, 0.17466461466204736, 0.15052421889718504, 0.36592064064837276, 0.5584868608463196, 8.163102461445717, 75.01871062863258, 55.58930489324755, 64.37449232224496, 41.36151113817769, 70.60065484816029, 27.994993386730073, 30.70830668172529, 80.70025597849201, 70.24422122586158, 76.50564193725586, 68.89191350629254, 79.1078442911948, 67.0549734177128, 70.04541981604793, 10.494982907848975, 1.6582660761571701, 0.6648525920125746, 56.19462467009022, 49.77790163409326, 51.56684760124453, 64.06173036944482, 69.11373138427734, 67.55612680988928, 69.97536628477036, 65.070438461919, 62.89454675489857, 59.5012297937947, 62.438371181488044, 65.40047845532818, 64.90467125369658, 64.14323329925537, 66.167097860767, 63.58508786847515, 62.20473912454421, 67.72112523355793, 68.10654517143004, 67.55427545116794, 65.97953796386719, 62.31212185275171, 64.40798936351653, 62.51948187428137, 59.071887154732984, 59.16447862502068, 60.82819115731024, 60.4558523239628, 58.77350068861439, 56.66221041833201, 54.52320075804188, 50.99709979949459, 53.881630436066665, 63.593081658886334, 61.53274689951251, 62.010334691693714, 62.2821000314528, 62.630971324059274, 61.89923747893303, 64.57571383445494, 60.46416774872811, 59.27790180329354, 54.38170125407558, 49.93367464311662, 56.018004263601, 55.02307937991235, 55.91261409944104, 60.52554499718451, 62.54984494178527, 63.31507975055326, 60.94672126154746, 61.44005736997051, 63.20247242527624, 61.5203796663592, 62.79185518141716, 61.8566797625634, 60.99815137924687, 60.47006699346728, 62.65296013124528, 51.538888946656265, 56.95435247113628, 64.97928257911437, 60.95264796287783, 60.78539417636011, 63.654231409872736, 59.69003308203913, 61.00372506726173, 63.68446503916095, 61.41387162670013, 62.56814672100929, 62.2955733729947, 58.48000934047084, 53.42340346305601, 50.72755452125303, 52.659937643235736, 50.858922543064246, 53.99967808877268, 58.74334158435945, 59.27781943351992, 59.23377906122516, 58.99753078337639, 58.52517543300506, 60.91092963372508, 59.9032570469764, 60.40181775246898, 61.78513573062036, 59.774654296136674, 47.817512789080226, 47.03897330068773, 53.43558634481123, 56.605398808756185, 53.47177020965084, 61.74342524620795, 59.840958041529504, 58.95818548817789, 53.11081801691363, 51.7472727068009, 55.55893398100331, 37.37656347213253, 47.340466283982806, 68.70691883948543, 58.96022119829732, 58.36968875700428, 63.85147171635782, 70.96237582545128, 69.63822287897911, 68.1550335115002, 62.670940276115175, 60.51787284112746, 53.633944526795425, 56.45314808814757, 58.223282367952415, 62.96461205328665, 65.77730448015275, 67.12636055484896, 53.26141349730953, 70.59373578717633, 58.18843995371173, 45.384419502750525, 20.781264343569358, 33.095790647691295, 12.676978803450062, 2.937830253954857, 77.00563430786133, 73.37071895599365, 76.72418855851697, 64.38740084248205, 72.91957578351422, 60.7329442424159, 81.43872061083394, 59.66662437685075, 49.99886835775068, 49.4969932494625, 45.40427846293296, 49.01459270907987, 51.24555841568978, 68.62938142591908, 2.136087739659894, 0.2252921939737374, 0.21642489478953425, 0.2906848309982208, 0.28675084693297265, 0.10444012320330066, 0.2373841257705804, 0.14123465204911848, 0.1861344370990992], [0.04782522202379281, 0.03414205666030607, 0.036820686917992375, 0.04491375849371956, 0.01893904563339968, 0.019820588753528653, 0.06294456858848853, 0.06663387566204033, 0.022624980004864837, 0.060323701360292976, 0.047611812910726, 0.12322053884065921, 0.28112491172167564, 38.582755058042466, 54.1382711164413, 52.54042694645544, 23.180968453807218, 40.8033460955466, 50.315180055556766, 10.36122420141774, 66.99537692531463, 44.62922988399383, 55.06273454235446, 57.89172441728654, 64.9889826005505, 57.14813324712939, 58.48404153700798, 3.6598824637551464, 0.30801845894705865, 0.16478629392241279, 25.613804824890632, 50.92477913825743, 33.00761968858781, 55.98507596600441, 55.67646388084658, 65.00256576845723, 61.83805634898525, 61.91834726641255, 58.12210482935752, 61.64107491893154, 60.13409245398737, 62.34916863902923, 59.11282493222145, 60.65816425508069, 59.397408577703665, 60.181470763298776, 58.681556409405125, 59.53968863333426, 60.43113354713687, 63.58926911507884, 57.03240763756537, 58.97180395741617, 59.89431796535369, 57.307789402623335, 57.67674323051207, 56.40635421199184, 55.3487184739882, 55.30170494510282, 57.176186038601784, 55.84954630944037, 52.11800336837769, 45.888295019826586, 48.719422586502574, 51.04692566779352, 60.157030474755075, 54.86038338753485, 57.421785246941354, 58.04490866199617, 57.3995767870257, 55.64380622679188, 50.777360777701105, 49.268009201172866, 46.948676416950846, 48.517075354053134, 47.480173264780355, 50.20565179086501, 54.47504974180653, 52.75518455813008, 56.96175006128127, 53.45399402802991, 57.13193778068789, 57.30631851380872, 57.65845321839856, 58.305134388708304, 59.813144514637614, 50.42700682916949, 56.253291560757546, 57.783694498000614, 58.94627324996456, 50.13226032257081, 53.548032852911184, 58.779305796469416, 57.051905739691954, 53.028734576317575, 58.035538119654504, 56.70774129129226, 58.07062764321604, 56.32780874929121, 54.904914056101155, 55.9482959008986, 52.09877198742282, 53.14544470079484, 48.44756703222952, 46.47340674554148, 45.76763899095597, 44.795306959459865, 43.990452289581306, 49.18656118454472, 51.248951265888834, 53.43899880686114, 53.46312922816123, 51.883131842459406, 54.98526773145122, 55.37022875201318, 53.03792468963131, 56.80476503987467, 49.55764093706685, 44.55574035644532, 46.579455867890395, 52.66761764403313, 50.493428245667495, 51.17821524220129, 54.05457165933425, 57.11944110931889, 49.36652345042075, 51.7275078835026, 46.318986954227576, 33.667111319880334, 54.46305121144941, 71.24456682512837, 55.27910032579976, 54.02444785641086, 56.35668131612963, 53.39145968037268, 54.599302584125155, 64.72854506584906, 61.29440015362155, 56.260971561554946, 60.13264509939379, 54.16145624652986, 53.80747018321868, 51.386638226047644, 55.77409951917587, 56.79574358847834, 64.10726124240507, 54.75967261099047, 58.36055747924313, 46.36617306740054, 29.565402538545673, 35.52991159500615, 21.05360431055869, 3.9279262096651144, 6.711074854097059, 66.48633172435146, 51.435805136157626, 56.15907622921852, 52.28390785955614, 57.46450378048805, 56.0804013283022, 66.89917687446841, 31.10931411866219, 53.073963426774554, 28.897171866509225, 34.33959384118357, 28.152092156871674, 46.46520506951117, 30.444046797290927, 0.08339027934257062, 0.050395397214038726, 0.026072002196263884, 0.08095244201080454, 0.0038966011291655203, 0.028100909454928293, 0.03332715744393007, 0.053863385316705516, 0.1166981122186107, 0.09944853943682487, 0.014049866754982262, 0.04141945144041412, 0.023581841059269446, 0.05601680484570323, 0.10831278193021014, 0.026986224712022854, 0.046925593482991385, 0.014213382476760496, 0.0597200662107958, 0.07973376466261764, 0.10362172679555032, 0.26386317346365223, 47.51804767116424, 63.700550679237615, 46.627042062820934, 36.58021642315772, 50.321267574064194, 50.1289027737033, 14.447099354959304, 71.63745495580858, 51.32258199876355, 60.37166257058421, 63.00824057671332, 69.71885112024123, 61.04814198709304, 65.50144810830393, 8.02934326471821, 0.2832811427933555, 0.32230275052209056, 28.420345014141454, 58.017385390497026, 38.101146836434644, 60.53335051382742, 58.88775148699361, 69.76249141077842, 61.02344674448813, 65.62810928590837, 61.413914772772024, 65.38190211019209, 60.35554162917599, 64.65191371979253, 60.983936709742395, 63.14098927282519, 62.52313360091179, 64.34379977564659, 61.800287846596014, 59.471521762109575, 60.73825513162921, 65.63979010428152, 58.93085441281719, 60.5124403584388, 58.646557100357555, 56.65626410515078, 59.18156839186146, 58.24811097114318, 56.76487845759238, 58.07202400699739, 56.20697229139267, 58.406821835425596, 53.42925563935311, 47.10679892570742, 48.4119362215842, 52.513801897725756, 62.24264490988947, 57.995631925521366, 59.311673410477184, 61.22832782806889, 58.6156213668085, 56.23744518526139, 53.111222021041385, 52.0027131419028, 51.06497641532652, 51.05475471865747, 53.291611825266195, 53.9596503011642, 58.28130598991149, 57.608603815878595, 59.71231606698806, 58.75231596731371, 60.711892881701075, 58.26320817393642, 62.50874242474956, 59.34815929782007, 61.4566215392082, 52.190935919361735, 58.498813183076926, 59.74859799108198, 59.06934545886133, 50.05077700461111, 55.07119117244598, 62.55574026415425, 57.47243873534664, 56.544445176278394, 60.42323389360982, 59.16368630624587, 61.36452428756222, 59.1516956206291, 56.01830628610427, 58.77815261963875, 55.116286662317094, 58.09833918848346, 51.67612483424526, 50.19558698900285, 50.4238179422194, 48.18436030418643, 46.52191861983269, 53.20326043713478, 55.38276072471373, 54.756691609659505, 55.72749391678841, 55.279374891711825, 57.220736319018954, 57.81778381716821, 55.563056392054406, 58.49527520518149, 52.21770217341762, 45.27602872540874, 47.16360661291307, 55.22097472221621, 51.135382959919596, 52.9708678491654, 54.91462192227764, 57.452677834418516, 54.12046747822916, 52.4703694928077, 43.46401922164425, 39.13980222517444, 61.67625857937721, 73.79234237055626, 55.850605349386896, 57.85972572142079, 58.129274922032515, 56.17747606769685, 58.345244546090406, 62.45848509573168, 63.02200809601815, 59.14513741770099, 62.405568399736964, 55.684037977649325, 54.961768811748875, 53.24364516042894, 60.573868597707445, 58.911215105364406, 68.34435847497755, 56.23467206954957, 63.494669391262924, 47.63655031881025, 36.12335443496704, 43.61586201575495, 23.189901651874667, 6.321029461199238, 8.789998216013755, 72.49091563686248, 57.213334806503795, 63.24555181687879, 56.93142229510892, 60.31376054210048, 60.548071169084125, 74.40254549826346, 38.3617098869816, 56.196401503778276, 36.69160781368133, 42.58156438027659, 27.205916450869655, 56.255111540517504, 36.56795901636924, 0.2569057467964388, 0.0537215824419212, 0.04092376957076692, 0.01818047686209602, 0.014854662229246912, 0.022183332231736953, 0.10070286285612853, 0.03309598275189919, 0.15782469973689126, 0.2217598085201556, 0.12381795718665085, 0.18424177091688881, 0.19083765004911732, 0.11155509585214239, 0.16763519105171004, 0.2034802764894501, 0.13556647474967665, 0.1617051189344737, 0.1149913908973817, 0.1457673491489503, 0.17153010463281987, 0.7858121755623049, 62.90598046395087, 73.41604586570494, 70.77580436583489, 34.60802908866636, 60.9827325420995, 62.21823992267732, 16.53016621066678, 79.21425819396973, 59.616374892573205, 65.89360667813209, 68.73013142616519, 74.31515509082426, 68.02639545932894, 72.61009293217813, 8.491071443403921, 0.9051601552674848, 0.4030784790314013, 39.72587100921139, 67.97007806839483, 45.738593839829974, 65.4460838533217, 63.280676641771876, 74.41825066843342, 66.38700162210773, 67.79165729399651, 62.53570087494389, 67.43014027995449, 63.29684465162216, 67.70763228016516, 64.27930816527336, 65.0370708588631, 65.40098836345058, 69.2142931107552, 65.20144170330417, 63.058290020112075, 60.478774655249815, 65.75597855352586, 60.750367410721324, 64.58147579623808, 62.721389801271506, 60.81418829579508, 61.00665507778045, 60.91708383252544, 59.17366089359407, 59.592593562218454, 58.565654293183364, 61.17821562674738, 56.1017115654484, 51.29362313978134, 52.84393602801908, 54.62768093232186, 64.72417946784728, 61.68818258470105, 61.83227085298108, 64.29902984249976, 64.04068293110018, 60.339087286303126, 57.48998349712741, 54.82364254613077, 53.528793627215975, 55.87224114325739, 55.384882726976954, 57.08768167803365, 62.07934487250544, 59.60192095848822, 62.7792682955342, 60.75959282536661, 63.73656980452999, 62.698373333100356, 63.27535790781822, 61.84710917934295, 64.36069734634893, 54.703457201680834, 62.627456880384884, 62.47633972475606, 62.64089099822506, 51.744291705469934, 58.277850381789676, 62.90587063758605, 61.488451573156546, 60.53748861435921, 63.08076912356962, 61.59079405569262, 65.03396041931646, 62.40805126005604, 60.498755208907596, 62.36568181745468, 58.591879260155466, 60.89580105197046, 55.87335117401616, 53.884838934867616, 54.02444393404069, 51.68535809363089, 50.57353873406687, 54.48133730119275, 56.55365097907282, 56.548685258434666, 59.02706230840376, 57.664199490701, 63.284336213142645, 61.73893805473082, 57.61858624796714, 62.567801552434126, 53.920512891584835, 47.037678918530865, 49.87371337029242, 56.224426838659475, 54.25409086288945, 53.7387228012085, 58.22161536062918, 59.665361373655266, 58.288017165276315, 55.89308854072325, 46.328812491509225, 43.7323328756517, 56.38239245260916, 67.48212737421836, 57.477208337476185, 60.074790139352125, 61.899159031529585, 58.909952102168916, 61.72928117936658, 64.83792428047427, 66.34816231266146, 61.3329452853049, 65.24672938931373, 58.90316640177081, 59.79075562569403, 56.23845323439568, 63.1335485366083, 61.77825981570829, 70.79618500125024, 60.266295940645286, 64.49577985271331, 49.652676043971894, 46.99813750482375, 52.741044413658884, 36.64411575563493, 7.120270729064942, 8.453786373138428, 80.18088709923529, 60.48971806803058, 68.14278787182224, 62.20772012587517, 69.66095693649785, 66.04260183149769, 78.86852479750111, 42.526211892404866, 64.21392225450086, 43.91210294538929, 48.49850293128721, 41.73252813277706, 66.79841902948195, 51.57150737700924, 0.6047868247955077, 0.10407188772073678, 0.15235388200850258, 0.13889115844522754, 0.11478752723985142, 0.10075841189151812, 0.1706663864634691, 0.12151811527268541, 0.22293019168559583], [0.0931980510452582, 0.0511947563368707, 0.017910607069009737, 0.06956710375004238, 0.04697995125165871, 0.04021876566712895, 0.03931598850495873, 0.057969631912607344, 0.023696309916915435, 0.03238850055382617, 0.18559049935110156, 0.09081505794799136, 0.13009850686836627, 20.74864591321638, 49.26243943552817, 44.70388827785369, 35.931746652049405, 32.39489251567472, 49.99309462885703, 11.814753586246121, 46.254577713627974, 68.39547480306318, 61.66700963051089, 59.7196783558015, 62.868121747047674, 59.25741134151336, 65.10493962995469, 21.077140492777673, 0.4187768769841041, 0.20341954103881316, 0.6183944462287811, 23.206885514720796, 40.85238748981107, 49.30030599717171, 60.08135618702058, 60.389011213856364, 60.64593430488341, 58.78174158834643, 61.12415359866235, 61.007200287234404, 64.28245390615156, 61.63141412119712, 59.871976144852184, 59.304683746830115, 61.067957801203576, 58.62884759902955, 59.23662277960009, 58.94968571201448, 61.697219725578066, 64.72365387024419, 65.21458164338144, 59.06457977910196, 58.601936217277284, 58.36300896060083, 54.45402976005308, 56.94572325675719, 54.22688138100409, 56.81655960698282, 53.81110229799825, 53.76246098549136, 53.586381866085915, 47.28435285629765, 46.174616275295136, 46.32354474836781, 56.883443863161155, 57.42535460379816, 56.895352179004306, 58.28456547952468, 55.7560879953446, 52.14364782456429, 46.937109347312685, 46.78019100619901, 45.58804542787614, 49.893191860568145, 50.47961758029077, 54.34631755275112, 54.393295780304946, 57.019185327714496, 55.287239243907315, 57.30355716520741, 55.308255303290586, 54.60289939757317, 61.97476271660098, 58.325919028251406, 54.51086882622012, 47.30147400209981, 52.26789674451275, 57.703595776711744, 56.82369047595609, 53.24229978745984, 55.3354843970268, 58.86759834904825, 52.623961664015255, 44.882042331080285, 54.58363663765692, 57.56827008339667, 57.041754645686, 55.06687656525643, 56.240241835194254, 54.694310234438994, 54.22568505810153, 55.86373352235364, 54.05105721565985, 48.22904002281928, 45.19865997375981, 46.49315980172927, 43.88304602715277, 47.91789800890031, 51.21052380531065, 52.08216467211324, 52.56982511089694, 51.137414747668856, 51.33032083511353, 52.790211323768865, 55.4030825245765, 53.75090960533389, 45.80605076205346, 41.738694098687944, 48.04371587691769, 50.29674883811705, 49.74558130387337, 46.87940735970774, 53.44884003362348, 53.896927679738695, 57.06535554701283, 36.16577094601047, 41.789073021181174, 67.30808396493235, 65.47289325344947, 51.85554189066733, 54.75424405067198, 49.38521354429184, 49.11277747923329, 52.431843972975216, 52.31861691321097, 50.91128226249449, 55.845223857510476, 56.37434767138574, 57.07085863236458, 54.96891144783267, 56.923416737587225, 55.411535232297844, 58.58082209863971, 62.1740230437248, 59.53023572121898, 59.15293508960355, 58.9114700594256, 36.598447599718654, 36.232878777288626, 19.361056473947343, 3.2080266456450186, 3.1826163059280765, 18.061828228735155, 55.011276968063854, 58.03580484082622, 57.976114211543916, 59.441405803926536, 50.4307879940156, 69.27994574269941, 36.95555586968699, 36.072571508346066, 52.85055306649978, 29.27245443867099, 55.952390855358495, 23.456169789837254, 52.35611869442848, 14.221210056735625, 0.13827723090446767, 0.04055737652966092, 0.037948490916601116, 0.12440567685952111, 0.03637305408295605, 0.041281578596681356, 0.11509066057060996, 0.04541543883181388, 0.0563197466544807, 0.04892713991144011, 0.03305272942769431, 0.043823986930111726, 0.055666553277161815, 0.033119536125131195, 0.008132778870452556, 0.06779591612998517, 0.04706365784870521, 0.01792211754007205, 0.0801628428481279, 0.131937041277847, 0.12333116959780456, 0.20202035805390728, 25.22326815512873, 61.52896965703657, 42.207342809246434, 36.21146263614778, 44.786324731765255, 52.5375557714893, 17.027342319488525, 48.48192699493901, 76.07990787875268, 63.70165286525604, 63.67276068656676, 67.68356461678782, 64.68720328423285, 69.14055255151564, 25.066543971338582, 0.250265970826149, 0.5542510687824219, 1.0319655412627806, 29.0117835229443, 48.86148298940351, 52.933624944379254, 61.25325056814379, 63.30239872778616, 65.06735547896355, 63.5609809813961, 63.14371924246512, 65.09076026178175, 65.99886740407636, 64.83597486249863, 61.05587297870267, 62.02045440673829, 61.63153179230229, 62.83109065025084, 62.19217577288228, 60.68861753709855, 63.57424251494869, 65.63261216686618, 67.19693968372961, 61.64091410175447, 58.20549441922096, 58.360647693757095, 57.106512977230935, 58.13583312496063, 55.10603750905683, 59.401150518848056, 57.339913614334606, 55.30417996068155, 55.2002763748169, 48.62998470183342, 45.95247284058602, 48.37432069163169, 60.08894989567419, 59.39103080380348, 58.79964328581288, 60.45166323261877, 59.83034803021339, 55.9599845640121, 51.6417452596849, 50.73736044668382, 51.810430711315526, 52.59591279491302, 55.38744795706965, 55.68225329922092, 59.90762656734836, 59.16580438613892, 59.03566798856182, 60.36692042504588, 59.294536575194336, 57.46807313734486, 64.24434415755734, 60.51586458759924, 57.56172364757907, 49.939169883728034, 55.00986099243165, 58.283667256755216, 58.65025981780022, 53.08794667643886, 58.90083651388846, 61.29408636400777, 57.3276444404356, 48.58626988626296, 55.66699135688044, 60.431741514513575, 59.84408809292702, 57.12763886297903, 59.749617807326786, 56.24700400137133, 58.74165888755553, 57.355481501548525, 55.84605147761684, 52.192434264767556, 46.64939565043296, 48.006633789308616, 47.51871055172336, 51.49730790045954, 53.815734617171756, 52.208641498319565, 56.17577768141224, 56.07194469821069, 55.74862372490668, 56.15663259260116, 57.12018635965163, 57.21281705364105, 48.67269931300994, 43.88601133900304, 50.714779361601806, 52.875197318292436, 51.1598232484633, 48.24218780763688, 55.27234600436304, 56.61647950449298, 61.33223141393354, 39.576460084607525, 48.71408816306822, 70.33798156246063, 65.22489355456445, 54.039396009137555, 58.2285265768728, 51.57296257634317, 52.33315713943974, 54.02247882658436, 54.57096345963017, 54.32010435288953, 57.583947796975416, 58.31475204037082, 58.89999712667158, 57.2489813066298, 60.40746988788728, 59.007936831443544, 61.05956000666465, 66.04304113695699, 62.907714151567035, 59.70611087737545, 60.882794472479056, 38.52126406085107, 42.881331520695845, 14.817908463939546, 5.095523634264547, 2.980814528080725, 24.20835683422704, 62.32700724755565, 62.964196282048384, 63.45282162389448, 67.21251933805405, 58.810523940670876, 74.55540026387861, 40.27263764412173, 37.94943348053963, 56.64714851687032, 36.61500000184582, 55.6142197885821, 23.12248983690816, 63.47455155464911, 15.68543476443137, 0.1570581981251317, 0.0814932924244673, 0.11255188349394069, 0.0724981944527357, 0.05319412324517485, 0.011734001154470588, 0.06293595776021962, 0.09928000009348316, 0.06281691152722606, 0.31206269838636924, 0.2610343784814881, 0.13319990657750638, 0.21110858167371443, 0.11453792047236236, 0.1801820105362323, 0.311897897552098, 0.14218625582514272, 0.09567034701185842, 0.2635563399282194, 0.19291028560649967, 0.2357984616631462, 0.3993583867146123, 38.48615884780884, 70.6670605751776, 66.08683047756072, 50.91523993399836, 47.158323180290964, 66.67429954774919, 17.32842541510059, 56.055470743486964, 81.8838547122094, 71.09055103794222, 69.945266016068, 74.00093401632002, 67.44749284559681, 78.60463557704803, 29.16388911585654, 0.905466590437197, 0.3335900754938203, 1.8120926089825171, 42.11170365733486, 55.60952863385601, 56.406970024108894, 65.77465295791626, 67.9398601285873, 66.40760975499308, 65.57576525595881, 65.93863548771029, 65.48947311216786, 67.81555237308626, 67.41035584480532, 64.03256362484348, 64.21464397061256, 66.97525516633065, 64.70803106984785, 64.30819642159247, 63.82724323580342, 65.92335393351894, 68.80924563254081, 70.07668895106163, 64.68008810474028, 61.391933810326364, 62.588288091844134, 59.51779004066222, 63.39839089301325, 57.21138538852815, 62.3774959964137, 58.164129103383715, 59.825284250320934, 58.166819849321925, 50.21025665344731, 48.797779775434925, 49.25948196841825, 62.45904599466632, 62.6651704695917, 60.700396414726015, 63.082698929694395, 62.10501286291308, 60.70842158409857, 53.97928960861699, 54.01239833524151, 53.98397291860273, 55.7573902222418, 57.14700752688993, 60.99851223730273, 61.52024630577334, 63.348584636565185, 60.9102471413151, 64.27800986074632, 62.07040186851256, 61.44115955598893, 70.63727409608903, 63.632391652753284, 61.04489818696053, 51.393835775313846, 58.12719998821136, 61.39051783469416, 61.80312764260077, 57.68966351785968, 57.9706621170044, 64.85710859298706, 59.28819802499587, 50.53531131436748, 57.264506047771825, 63.421073959719756, 61.30499055308681, 60.644149626455004, 62.506671413298584, 56.71043203723047, 60.14901315012286, 61.55690869977398, 61.33165874788838, 55.65808757658928, 49.62385446794572, 53.070323467254646, 51.663832126125214, 55.025860340364524, 56.182473167296386, 56.87953718246953, 58.397161037691184, 56.495858776953916, 59.287727340575195, 59.64091716274139, 60.52522728520056, 58.80654273494598, 49.964771193842736, 45.54289110245244, 50.551385187333636, 55.016411350619414, 53.45384105559319, 48.68849862006403, 56.41147290506671, 59.308441377455196, 62.04650678942281, 46.01957282712383, 49.78204365699522, 62.917167063682314, 63.72740714780746, 56.856116710170625, 58.368461055140344, 54.73910370180684, 56.19675451709379, 58.816317281415394, 56.28804376048427, 57.631212357551824, 60.587396852431766, 59.17253909572479, 63.45654395318801, 60.05660995360344, 62.42117943302278, 60.939649228126775, 64.934591093371, 67.66520792438139, 68.46030373727122, 58.19187594998268, 61.34118618503694, 44.75033698543426, 54.25165114864227, 25.35654244884368, 10.827552830019306, 4.823240541642712, 23.03040631355778, 71.45435087142452, 68.33581555274226, 69.57966973704677, 71.76818755365187, 63.83182456416469, 79.62340062664401, 45.57821989059449, 46.430896097613925, 66.72169746891146, 46.226513155045055, 68.12025777755245, 36.7628498231211, 80.11020598873016, 27.95853887834857, 0.3596732242693824, 0.14369175649218022, 0.26907355194130256, 0.17880604001543215, 0.12384008946678332, 0.10437768703747181, 0.1372029917735246, 0.2119102467211985, 0.10814379825587235], [0.017397025555011728, 0.050135023080773895, 0.025226369447585557, 0.025105771886545326, 0.044655039110371185, 0.03192065065846809, 0.03778309253374896, 0.013232856966374863, 0.03125970064091586, 0.03703072524419235, 0.0429372631403948, 0.0869178997292634, 0.21386268308326123, 5.03110017507307, 55.44181985239829, 41.367724172530636, 45.541784994063846, 26.70047198572467, 57.14163780212403, 17.338250952382243, 29.977276902044977, 67.49143908100744, 57.03236841386365, 70.03442149008475, 57.22269750410511, 65.01211673982682, 53.84564268973566, 60.700714126709975, 0.4201699312656157, 0.2253024289084058, 0.40919213645881225, 2.2836286742841048, 42.33281158631848, 50.77000241125784, 59.33694524149741, 59.648871729450846, 68.69493207623883, 60.2133047196173, 66.74370196557814, 61.463956371430434, 64.80911839392878, 61.73215235433271, 60.67496376652872, 61.042215285762666, 55.83939913780459, 58.303867463142645, 60.59404526987384, 56.74696891538559, 61.006917876581994, 60.54459987148162, 60.390062409062544, 59.82967730491393, 62.89502528405959, 58.74321606851394, 60.757533581026145, 55.100703085622484, 55.8054353344825, 51.686844671926195, 52.279201015349365, 52.27757323172785, 54.16420190565048, 49.73648924981394, 46.02756661753501, 45.34404654656687, 47.19593086550313, 57.42701768875123, 58.697030159734915, 57.22696504285259, 55.06875930293914, 46.46455787843274, 47.504558640141646, 46.50495044646725, 48.3249851196043, 49.770464820246545, 53.49701850645004, 55.11830668295584, 55.98462489343459, 55.61168593745078, 57.26146621088828, 54.864286145856305, 60.11318229859876, 58.11494650379304, 55.46934312389743, 55.343289913669715, 48.47476474700436, 43.97561396321943, 51.83303140824842, 58.061904291952814, 57.18513296496484, 54.435178849004934, 58.60315607440088, 56.65045899729575, 48.534902526486306, 45.362422850824174, 49.24618121116392, 58.90111500217069, 58.15436632402482, 56.66084935588222, 56.253864226802705, 55.73936693130001, 55.61293717353575, 55.08728465726299, 52.917037240920536, 52.095536032030665, 47.211149661771714, 47.55814213906565, 43.70338970615018, 41.30044767933507, 47.825824291475364, 51.96894545708933, 54.7271365504111, 52.657945079188195, 53.10707607576924, 55.26106134537728, 56.99582761333835, 50.7271348276446, 43.57446139858615, 45.48938605093187, 49.51813874706146, 53.0741830795042, 47.10795210253808, 48.40681752850933, 51.15608915205925, 55.07655697484171, 55.150105337942804, 43.6520694148156, 58.774759769439704, 57.09209826684768, 52.98421567486179, 58.95498091174711, 50.31672939177483, 49.59730786661948, 56.13852300951558, 57.76687145233155, 52.0960694743741, 57.224941099843676, 57.53587130577334, 57.58544222001107, 57.520566217360965, 56.62573237572947, 57.97978947239538, 60.17723852588285, 60.41061955113565, 58.88726903546242, 66.30980937711655, 61.170002183606556, 41.919382003045854, 39.42140094695553, 19.26732163275442, 0.4799878843609364, 1.2232963067869986, 4.941659348626291, 61.610841289643325, 53.62204013332244, 59.659697471126435, 52.548938489729366, 55.409966284228915, 46.395488862068426, 67.61150283198204, 29.667268453105805, 54.039482301281346, 34.6941682600206, 46.94569541561989, 50.64002290848763, 27.035562030730713, 40.74166290221676, 2.076145833538425, 0.011589092750763221, 0.05823482090847627, 0.04407458961190235, 0.047379178821199366, 0.026418668473319664, 0.04079478717739544, 0.05786860406759286, 0.006508982736587284, 0.015952762126201586, 0.06826246367587198, 0.034222997679945924, 0.025285411843909852, 0.05012124115901609, 0.02738945509096788, 0.019998079834265575, 0.027150879989588456, 0.05650110264879562, 0.039219794674746455, 0.09601979035763972, 0.0778253017474086, 0.1449229057517744, 0.2212968462657544, 7.884058183239353, 65.73286794847058, 48.184646637209006, 41.327002125401656, 39.595001128412065, 57.549678048779896, 17.585554430561682, 34.255494302318944, 72.74391635771721, 64.70241815813127, 74.31718687857352, 62.65825925334808, 70.62090996773013, 57.9950749489569, 62.94113666780534, 0.6480318139637671, 1.9037885531302423, 0.9373465733182047, 2.6443720008096387, 49.140438033688454, 54.18666139725716, 64.01138282591297, 63.801296757113555, 69.48798041189872, 62.95280964143815, 68.06080249048048, 64.60431968012165, 66.14728989139681, 61.96809076493787, 61.916703793310354, 62.810353079149806, 58.80441681031258, 63.05480303302888, 64.03816869181972, 60.316729776320926, 62.28125672186575, 64.07131664214596, 60.871705932001916, 62.972837263538, 64.36492566139468, 61.03081687804192, 61.33624792099, 57.75625751864526, 57.129560824363466, 54.71613430207776, 54.705218345888206, 52.46910256724204, 55.29407593511767, 51.221526053644, 47.51245437129852, 47.071783927179155, 49.80950417057161, 60.75731785066667, 58.801930027623335, 59.57080479591124, 58.68531011766004, 49.6901935146701, 50.73841164189001, 50.676155782515, 51.84368456563642, 55.054972171783454, 57.16472487295828, 57.155377864837654, 60.12767937875564, 59.03562484248992, 59.356329594889, 57.50205263014763, 63.65479230880738, 60.69454031605875, 58.263541575401064, 57.634009007484686, 49.961723512218846, 45.88221142368932, 54.49159429919336, 59.52842358619937, 59.756968329029704, 55.32587459010463, 60.63848572392618, 59.48095898474417, 53.127515546737186, 46.621648803834, 52.626656332323634, 61.3283129661314, 60.580466024337284, 58.43199952956169, 58.481060535677024, 57.77422197403447, 58.70170954735049, 58.992690578583755, 55.91486946229012, 55.07731791465513, 51.16705609906105, 49.20239579293036, 45.5113866252284, 44.786571841086115, 50.96694069523966, 52.86488148473924, 55.774872226099816, 54.447746123037035, 55.865173032206876, 56.557404687327725, 56.370848917192035, 50.79870631617885, 43.29386288119901, 47.55290185251544, 51.125843755660526, 55.585857129866085, 49.08093567817442, 50.82722979207193, 54.37944196885633, 58.084810933759144, 56.17053739486202, 46.08873598037228, 63.26527349410519, 57.35108452458536, 55.12129945139731, 60.116061318305235, 52.51960700558078, 54.029586161336596, 58.50534392941383, 59.97374203897292, 55.278806148036836, 61.14189840132191, 60.57904220396473, 60.98608224622665, 61.72848101585143, 61.16334984379431, 61.0837100398156, 62.421540291078635, 64.33030289988365, 61.25378793285739, 65.80605153114566, 64.49771750357844, 45.36368193164949, 45.477536570641306, 20.411210290847286, 0.9953314618718241, 2.0664284065846474, 9.007249474525452, 69.17235512887278, 56.97990671280892, 64.45509310691588, 59.64526314889232, 59.46839563308224, 52.410576881900916, 72.01450455573298, 34.367152414014264, 57.00081294582736, 36.25314174159881, 56.68504253510506, 50.42995645153908, 31.22991131198022, 51.01378556220762, 2.420176431055992, 0.0417337964679445, 0.08535809108927365, 0.06769114594546057, 0.027710290798436732, 0.006192906829152978, 0.022844433551654223, 0.059323133074588356, 0.07747061836022524, 0.06482902613859023, 0.15072543955137654, 0.21398663610940982, 0.18139460514630043, 0.298925485582121, 0.18739733304227554, 0.12617642014858224, 0.1511216755475729, 0.16182133447258704, 0.25154498525925223, 0.2775861064512884, 0.17104279610418505, 0.3824735637153349, 0.662746156655973, 11.93053214780746, 79.44691750311083, 60.02656067571333, 62.3056617090779, 41.770908524913175, 75.86002765163299, 24.698066711425785, 38.437188056207475, 80.04107813681327, 67.7625846862793, 82.71242403214978, 67.34129075081118, 75.72536483887704, 62.288062034114716, 74.88361635515767, 0.7365934779086422, 5.426782994501052, 0.3512530293195479, 4.258679584149392, 60.18798189778482, 57.72055218296667, 66.64362661300167, 63.92316479836742, 73.60497074742472, 64.88940146661574, 73.15391386708906, 66.02076991911858, 69.32349189635246, 65.00266775008171, 64.3775753052004, 65.6611866335715, 62.69401165746874, 63.438367689809496, 67.10543863234982, 62.835013020423155, 63.46563600724744, 65.43371269779821, 64.42853473847913, 63.01339457111975, 67.09211826324463, 65.52651205370503, 63.96396921527002, 61.07668507483698, 60.16092538833619, 56.05970298090289, 56.97573331094558, 56.04916749462005, 57.53287461496169, 54.35955947445285, 49.98774843831217, 49.204670767630304, 51.70352651226906, 62.393036427036414, 62.72422959727626, 61.96732982512444, 60.95128297805787, 51.81424325512302, 54.7876077313577, 53.03106446419993, 56.96178536261282, 56.567406731267134, 62.13015133334745, 62.58936282127135, 61.191614443256015, 61.26690041634345, 65.08353133355418, 61.60653844956429, 68.57889267706102, 64.30279924023536, 60.223330297777736, 60.67706223457091, 52.461532392809474, 47.70581545368318, 56.280426517609634, 62.53715999664799, 63.00366317072223, 57.05661650626891, 64.1121720498608, 62.828501885937115, 54.112485454928496, 48.13462857277163, 52.50502755565029, 64.03469739421722, 62.71089746106056, 60.6115351184722, 61.23522727720199, 63.93078596361222, 63.27751128904281, 61.063019537156634, 59.351073618858095, 59.7705985653785, 53.73229795886625, 54.143668297798406, 48.74714197651033, 47.58830516569076, 52.71965965147942, 54.31666051187823, 60.5557825488429, 58.00661848437402, 58.70119571685792, 59.20060757667788, 57.642030254487075, 53.42550977583855, 45.671093771534586, 48.5700979540425, 53.51208825265208, 55.9399647866526, 51.17405752981863, 53.44670234187957, 57.83453626017417, 60.99568813077865, 57.2497187122222, 48.926551188192065, 59.56467805370208, 60.43464406844109, 58.46778331264373, 63.107386327558956, 53.850169104914514, 57.84583268627044, 59.854466684402965, 63.264669449098655, 57.026943775915335, 63.566480144377685, 63.580851708689046, 64.35421759082426, 63.16436659905219, 65.0927371363486, 60.88593629098708, 65.58905424610262, 66.10186100006104, 64.46215729559621, 63.770541452592425, 64.4352106125124, 49.27799947800175, 53.45177004414221, 26.7039668175482, 0.8302568584199875, 2.529643653861938, 8.817856850162629, 75.02940300972232, 63.19944827787338, 68.94131968098303, 64.14387656796363, 67.32550713323778, 56.19365976702783, 77.65939927870228, 39.812167075372514, 65.19645244844499, 48.535365366166644, 60.973820917068, 61.010267580709154, 44.04973891473586, 70.05176621098673, 8.221605102862082, 0.18546596409813051, 0.41451368961603413, 0.2387887939450241, 0.16417884748549233, 0.15589771281567313, 0.10807276658353307, 0.12462254869000566, 0.22705937495395062, 0.20999891863715267], [0.025524505969857978, 0.07024266306431064, 0.026561415551470655, 0.016388639342039824, 0.051460849316490274, 0.059712949253979235, 0.028408051340750633, 0.06555055072831531, 0.010370198982737718, 0.06039447639317763, 0.036867954542920474, 0.06320827520422398, 0.04485475057135186, 0.43933509158030637, 30.19556268568962, 43.848364430089156, 44.24586919046218, 28.150429071918612, 40.95754231176069, 41.31624698638916, 17.538687990557765, 75.84650331927885, 57.875313220485566, 63.133807413039676, 57.1629794182316, 62.932123061149355, 52.61508141794513, 71.0626708307574, 23.06516831920993, 0.9424571152175627, 0.07209969083628348, 0.636498819916479, 18.024206815227387, 41.693677056220274, 53.88328567627938, 63.98922927917973, 62.325053907209835, 66.0230213595975, 61.591303963815015, 61.402128050404215, 59.12645124620008, 60.47231058920584, 57.6023554801941, 56.05297611605737, 58.54252799864739, 62.93065217233474, 58.081653425770426, 56.01638040234966, 52.387419208403564, 57.60657595049951, 63.96020766227477, 62.064941929232695, 61.406728990616344, 61.79243526151104, 58.293814428391, 58.59397380582748, 56.268659407092684, 53.99186080501926, 53.97440233538228, 52.269344099106334, 52.28610830922281, 53.71741648643248, 47.096863562060946, 46.76303848143547, 46.38986418324132, 48.991234994703724, 56.36058015208091, 58.92050720030262, 49.960315381326986, 47.52150327928605, 45.2776212076987, 48.791896220176454, 54.11337583295761, 53.22900687494586, 57.314210322595414, 57.90191865736439, 55.63184299776631, 55.15399240678357, 56.23137727860482, 56.47551344287012, 57.1306473209012, 57.58990979963734, 58.524559620888006, 51.521756033743586, 44.25654588207122, 44.53762685098956, 48.33748571334347, 53.86069282408684, 54.35296204782302, 56.08341763096472, 54.91697142201086, 53.610712328264796, 48.59729174644717, 44.41983415234474, 45.874405907046416, 55.62710085222798, 58.01017215175014, 57.82831538108088, 57.713487994286325, 54.9326922816615, 55.33610020914386, 53.58909614624516, 54.990810040504705, 54.979662664474986, 49.890677621287686, 50.05442480887137, 44.10818615267354, 39.39201847199471, 45.22590475697672, 49.34704103777486, 52.144604882886334, 51.71903164156022, 55.63860516394339, 54.567515696248705, 50.8188751436049, 44.28453591562087, 44.97550456754623, 44.38753343397572, 50.226989484602406, 49.17871644420009, 48.296861725468794, 49.17495489120484, 51.01188321267405, 56.32265083251461, 53.57236331509006, 49.225294589996345, 55.08535877350838, 55.06375435859927, 56.39829374128773, 54.41135437257829, 52.23843582214848, 55.26233611568328, 55.8897662931873, 55.18601463687036, 59.472608258647305, 60.5009360467234, 58.65640617186024, 60.61726570129395, 60.02286580301101, 59.69368873103973, 60.705122870783654, 59.69179030387633, 61.33795022964478, 72.9539514357044, 66.32679323996267, 55.562934798579064, 41.355031382653024, 31.388561379524972, 3.7391297855684837, 0.022152027963931044, 0.5433541728604225, 29.034833331261915, 68.12693365158574, 49.44795969993838, 62.136238851854884, 48.24385089258994, 55.29379352446526, 43.64145940349948, 60.933444038514175, 43.11599908336517, 56.239849598177024, 31.47396118410172, 38.07222327878399, 27.68115866568781, 30.76412004809226, 24.110627059013616, 0.12400664464240113, 0.0686351424683967, 0.0970151607367781, 0.06099582093978121, 0.02961698979620011, 0.0862768373542255, 0.07324617971936542, 0.04612814191909087, 0.04313927286514833, 0.017842769983314702, 0.019556872561694156, 0.011013942665510602, 0.07482393013854181, 0.03760162545668502, 0.052244377232366995, 0.02650726462654289, 0.01903174610267724, 0.042471175247262564, 0.03284738339003056, 0.0038429445703513925, 0.03310405731862111, 0.050401587204466906, 0.027757575660343134, 0.7784541768412437, 39.39186942192816, 52.04256834522371, 40.72993109303136, 39.86354227988951, 53.25816969717703, 39.13028263276623, 23.8237194092043, 81.3408810092557, 67.23330005522698, 69.9441599076794, 63.5531597752725, 69.87533015589561, 58.42352328761932, 76.71792845572196, 26.426708198362782, 0.689451430113085, 1.724470046258742, 0.19303799246347722, 22.88682403102998, 46.9677822820602, 57.74898936671596, 65.60249228631297, 64.41054674886888, 67.05454195699384, 65.39523032403761, 62.50709110690702, 62.05814446172407, 60.4375466223686, 59.99534253151187, 58.602524572803134, 65.10364917016798, 64.3051330504879, 61.276274881055286, 58.35269312704764, 53.34586604948967, 60.636712812608295, 65.68896485913184, 63.90495323365735, 62.04930343935567, 62.76251193015807, 62.72295482697026, 59.20269035523938, 59.061845887091856, 54.4525824054595, 52.95881440562587, 53.25486313912177, 53.00201931307393, 56.40756230200491, 48.04376686772993, 47.776155317983324, 47.97018320329728, 50.90548499937981, 59.39198001738518, 59.50007269459387, 54.416527978835575, 48.406291930906235, 48.56855646256478, 50.96294380003407, 55.64911711600519, 54.82228932842132, 59.10553324607111, 59.74547186205464, 58.68720070008309, 58.3321399073447, 59.253481126600704, 59.18820111982284, 60.08046580899147, 60.74668430512952, 60.73205386438678, 51.86089200358237, 47.79278224514377, 48.628945273737756, 51.815400354323856, 56.935128934921764, 56.661661286507886, 56.78817341404577, 58.875043007635306, 55.85519844485868, 51.958496262950284, 46.4618710548647, 46.92402824278801, 59.04267334168958, 60.35097599029542, 60.45380876910303, 59.28105538891208, 60.17775235637542, 56.971175516805346, 59.641336856349824, 54.93088014664189, 56.65469515708185, 52.86424606077133, 50.39037581413023, 47.06020509043048, 43.22859464153167, 48.043586438702, 52.478575091208185, 56.245431130932225, 55.86530247042256, 57.011968166597434, 56.929516023205174, 53.4441763354886, 46.68259066920127, 47.12006438163019, 46.56123253606981, 52.58330237480902, 51.81553371490971, 49.449736533626435, 53.32317121567265, 52.88073178260557, 57.67491540601177, 54.96059602306735, 51.64609909057618, 54.24197073905699, 55.92018035150344, 58.55450691715364, 57.67318956313595, 55.29779434204102, 56.57252934671218, 57.708067278708185, 57.88487988133585, 61.56157239790886, 61.591123534787094, 60.492318599454826, 62.18930067554597, 63.508680097518436, 62.38623111478744, 62.80297117848551, 63.91588095695742, 60.394604513722086, 71.56344767539733, 66.8108372534475, 57.08901136152206, 46.104805930968254, 34.003132927802305, 3.3433633706262036, 0.5955889280284605, 0.679555964325705, 35.25217640784479, 68.97691911266696, 55.172192204383116, 68.51212609198787, 53.67882036393689, 61.304594393699404, 47.88694266350039, 68.3161723229193, 49.31742714297388, 60.01979850953626, 40.40290740228469, 46.60756749491538, 31.270858895394113, 40.030847057219475, 34.024172521406605, 0.5231111268362691, 0.040438211553039095, 0.09392021914883968, 0.03610008929465567, 0.07852514604887656, 0.02717519562030512, 0.087486352290838, 0.038478842095261624, 0.013175989302145618, 0.025717083237043796, 0.1121623507670818, 0.30557028708919404, 0.23518922258048292, 0.11505477701223667, 0.15054933125934294, 0.1533064510553114, 0.13431608136142456, 0.1613476929525214, 0.16142497590232283, 0.1608486479568866, 0.13127299626508068, 0.14900718094600787, 0.1464310877265469, 0.9792645143405084, 57.032038934769176, 61.540850516288515, 61.72220130120555, 43.25157973074144, 58.528532981872566, 52.65405408797726, 25.395946579594767, 88.2991264712426, 69.22014528705229, 73.30989868410173, 67.60310111507293, 74.61492615361368, 63.30751742086103, 84.33301402676491, 27.978921474949008, 8.16500481097929, 3.0450004387286405, 0.9089028931433155, 29.87808800512745, 57.325377310476, 58.36077713197278, 66.64876491792741, 66.51571812168245, 69.36869329021823, 66.5934830327188, 63.76664653901131, 61.802998204385084, 63.822634450850956, 62.347521243556855, 62.72138195653116, 66.75640260019611, 66.64478763457268, 62.76011143961261, 61.319938705813506, 56.50817109692482, 62.247449813350556, 67.28309062219435, 65.60151561614006, 65.45972193441084, 67.3049617582752, 63.875017704502234, 64.79782981257286, 62.17890639458934, 56.177750633608916, 56.82918963893768, 57.85350091995732, 56.16272795584894, 59.53615850017917, 50.70024698011337, 50.86167604692521, 52.06991118769492, 53.57779187540854, 60.03047127877513, 63.669418827179946, 56.12368468315371, 51.898786021817116, 50.924261385394686, 55.183441562037316, 58.38162060706847, 59.821306966966205, 64.62767347212761, 63.41546497037334, 60.852972692058934, 61.63808607286023, 62.10979030978296, 62.57214361621488, 63.435535738545084, 63.680852536232244, 63.37328772391043, 54.211988141459805, 49.19898725325062, 49.71042117764873, 54.512339715034734, 57.032984225980705, 60.992028559407885, 58.9441708595522, 58.76516565199822, 58.20615729978008, 54.91665763239707, 48.29045257260723, 47.77672798402848, 61.671139886302335, 63.16006768134333, 63.72476347031132, 63.14411932422269, 61.63102188417989, 59.436596978095274, 61.95049893471503, 59.895118128868845, 61.793192278954294, 56.88130224904707, 56.896066050375666, 49.733986777644006, 45.06969636486423, 50.30781776674333, 55.50792355691233, 58.119076759584495, 58.584713089850645, 59.95092953405073, 59.1441725146386, 55.163692428219704, 48.79368089860486, 49.145839137415734, 47.164504835682536, 54.735761842420025, 54.469707473631836, 51.70429529682283, 54.93078600975775, 55.71155340440812, 60.262553999500895, 56.82405133401194, 50.653170693305235, 57.304188666805146, 59.366049228175996, 58.71881108130179, 61.413326417246175, 58.79293995518839, 60.02752950114589, 58.99975476726409, 63.20741853406353, 64.80369767835064, 66.97330967072519, 65.14238649798979, 66.70625901991322, 66.06149981098791, 66.05683219048285, 63.702974704004106, 68.34671974182129, 60.75080279381045, 70.72474295093168, 67.1635446240825, 63.76427350505706, 49.273072981065326, 43.61891361974901, 4.795273552017828, 0.4210384911106479, 2.8431055045896962, 36.94890745224492, 80.73321957742014, 58.793779342405266, 72.82233238220215, 59.351446244024466, 67.38039678142917, 58.277426765811065, 72.66069150740101, 54.19170556529876, 65.90962563791584, 46.35629653930665, 45.06664083849999, 42.85588318301786, 51.061967957404356, 51.288245570275095, 1.5495252272775097, 0.15374011810748808, 0.3441180541150032, 0.1571545106989722, 0.1119473864955287, 0.21562453209152146, 0.20739782030784315, 0.11942159309382401, 0.17769265379155838, 0.0938427446770572], [0.037671052174822944, 0.08613169433609133, 0.07893514864507221, 0.043384164361463445, 0.002621150920130012, 0.00472263423650856, 0.03315998939797282, 0.014982961846755878, 0.04153979619243934, 0.023731274169779593, 0.07691911932441496, 0.07540319220072801, 0.1547022938968674, 0.19448738485094041, 16.16833246523334, 55.959678619138664, 38.998114447439875, 27.08081637659381, 28.355976958428663, 62.02414535707044, 20.96039898933903, 44.639059343645656, 68.68416909248599, 58.83362277861565, 65.6354872642025, 61.01445274968302, 62.185084127610736, 54.036575824983665, 64.9379486422385, 2.6387326130943918, 2.3407207333272506, 0.17634691310025033, 5.78846033542387, 30.32864086089596, 53.8213945973304, 68.8763338519681, 61.212273566953606, 66.25925787033574, 65.20031598306471, 61.983364474388864, 57.703254530506754, 58.20582389831544, 58.64182672192974, 61.540838749178, 58.162771963304095, 60.52097935830394, 56.534654940328295, 56.2927859060226, 54.31288326940229, 54.058380280771566, 59.45123526357836, 62.79050980844806, 60.63486145388696, 60.33592585594424, 60.42588149347613, 60.317267141034534, 57.54887788526474, 56.61000367133849, 51.35114862072853, 52.34634807032924, 50.729296053609545, 53.7603154490071, 50.1807878863427, 44.62256185470089, 47.21395023407475, 44.95630064318257, 49.1226932310289, 51.7685947110576, 47.69356196926486, 43.751901580441384, 46.56588446709418, 52.504623551522535, 49.82336582676057, 54.0037416642712, 57.82392624885806, 58.11924149913173, 55.063566084830995, 56.05768296026415, 58.31571302106304, 57.38219676479217, 55.90854660157235, 56.6928872754497, 50.82718272362986, 45.25036465737128, 43.42011220993535, 43.37264760848015, 47.48256591058547, 54.422144812922326, 52.74220935760006, 52.44972213622063, 56.36030558616885, 49.99223955215947, 46.67777007625949, 42.859119138410016, 46.33133457553002, 45.845902043004195, 55.39686949022355, 56.216958645851385, 56.97974589563186, 56.62993323418402, 54.03591294442454, 56.44165554354268, 55.29739426028345, 55.41075860300372, 54.84667470378261, 53.39462503310173, 46.908283848916334, 39.51034069061279, 40.1365117872915, 46.91474791496031, 51.34282535122287, 50.92417117088072, 55.20894873526789, 54.45486914726996, 47.00703736274473, 44.38139884702621, 43.12793485579952, 45.24053912008963, 50.729652989295225, 45.49817216011786, 45.699750608013524, 47.22079869239561, 49.775191276304184, 51.8830337832051, 57.76372571145335, 50.73387345960064, 54.36261500081709, 58.56185351648639, 53.552484743056766, 57.12940785192675, 53.616329162351555, 53.10028645300096, 58.698975655340384, 55.34088942312426, 56.87825064505301, 57.03562790347684, 59.47974304999075, 57.69628840108072, 58.559362811426965, 58.76984503961379, 58.05051765134258, 60.01917093030868, 67.72140764421033, 57.384644323779696, 54.241405917752175, 50.30559770522579, 35.45480212857647, 12.216070890426638, 0.5213654269614528, 1.0486837861038025, 3.24851653748943, 57.79219427416402, 52.78355506158645, 60.436483660051906, 49.84329931197628, 54.04051388463667, 60.16297286556613, 59.71074711891913, 53.46749090379285, 39.12258694248815, 59.26824885029947, 34.03314298199069, 20.566995066981164, 30.49902077644102, 42.914459859171224, 13.246816819713963, 0.028328274774755684, 0.0387122001378767, 0.04426818003036803, 0.024567905385347626, 0.06458756288573628, 0.04967819719064621, 0.05962913157418371, 0.023954715204214858, 0.1008191013768796, 0.019254430625287276, 0.06071142228921095, 0.022259266866791635, 0.02516107385857932, 0.03905275686373634, 0.008389254573792701, 0.023809235107393998, 0.06363900047877143, 0.035918128090880574, 0.01789856991249948, 0.04379608217746981, 0.025586656767935045, 0.05876874588730355, 0.05332872489347093, 0.05381886411698596, 20.341941233604185, 67.2093657524355, 40.671679973602295, 30.653005184665805, 39.658896538519095, 67.04580291624993, 26.860171287290513, 50.43231771838281, 71.50755390044182, 64.52541335936516, 70.99181713596468, 65.88929991568288, 69.05375834434264, 58.017565819524954, 71.58619742239676, 3.355916180918294, 1.3236003825741431, 0.3512807617024068, 7.066867659168859, 40.16506271977579, 58.54860767241448, 69.4223120904738, 61.63748595022387, 66.86840980283677, 65.68796465473791, 60.09902646464687, 56.64052755601945, 59.60219552440029, 60.239235508826475, 61.85675428759668, 60.862076513228885, 62.2684423385128, 59.030753258735906, 58.844593647987615, 55.5881634835274, 54.88222706702448, 62.72393934188351, 65.64728183131065, 63.21126637920257, 63.66518266739384, 61.972915280249815, 63.596592180190555, 59.81026549493114, 58.137594269168, 53.41903786505423, 54.67221944562851, 52.126130519374726, 56.09507883748701, 53.189720415299945, 46.23724868220668, 49.05225922984462, 46.02752347146311, 50.19820320990778, 53.24098579345211, 50.146298485417525, 47.48118131391464, 50.85223490192045, 55.515081882476814, 55.24770567494055, 57.28166249490554, 61.64943348976874, 59.07749222170923, 57.930030284389375, 58.96532027952133, 59.82264057282479, 60.739977052134854, 59.904975045111875, 61.22453097374209, 57.16652524086737, 48.945845327069684, 46.771346061460434, 47.16680334460351, 49.05126294782085, 57.350755045490885, 57.25481779344621, 54.84630207861624, 56.77233096091979, 53.55978427394744, 50.134943223768666, 45.835119447400494, 48.12760360779301, 49.79498355619369, 57.89526631755214, 57.607391803495354, 59.33021445428172, 58.5936168701418, 59.00783092744889, 58.284879269138465, 58.02215499262656, 57.07915052290886, 58.841616569026826, 56.198343077013575, 50.41887967817245, 43.53570838128367, 44.8445366274926, 49.23377083193872, 53.098105615185155, 53.40102634122295, 57.62268120242704, 55.57921655716435, 48.57478910876859, 44.92882836249567, 45.06238114449286, 46.82264674094416, 52.31463570748606, 47.459776939884314, 48.50467281956827, 47.41594053083851, 52.125326433489406, 53.571833795116795, 59.035726824114406, 54.731874773579264, 56.420537502534934, 60.04303070806689, 56.4389608752343, 58.81991017249323, 55.047358851278986, 55.41013102377615, 58.07263589674427, 60.706919316322576, 59.47702092509116, 60.13229600844845, 60.691586771318995, 59.433545374101215, 61.65335978231123, 61.08740099014775, 61.20974363819246, 61.12209435432189, 64.90338079390988, 58.729068079302394, 58.3025848480963, 51.507870843333585, 40.65896757187382, 12.978635545699829, 0.6194911164141471, 1.8984509427701275, 6.090835852007713, 65.22013179717526, 56.32109757392638, 65.97469775907456, 55.94645630928778, 59.66117228231123, 66.27965419523179, 65.50515474811678, 58.86475463067332, 43.179525790675996, 64.42635390066332, 43.12929591824932, 24.68889032640765, 35.406282409544914, 53.11566998881679, 20.77914038012105, 0.016172533599479545, 0.05789182802301742, 0.0653398612273797, 0.025309039910714475, 0.05834759288136998, 0.10314985493858976, 0.011440554047904668, 0.03886593100164206, 0.07262187168723153, 0.04069563241735582, 0.22261706090742545, 0.16710913379586514, 0.20873695732124392, 0.12828031975415446, 0.0996526635642494, 0.13590467192472952, 0.08799674304863138, 0.13084414024506846, 0.09925577639331741, 0.1587883157715682, 0.13872369162497983, 0.1923965164009602, 0.34297636860320646, 0.41288523183714965, 32.07571944882793, 80.33869974074825, 59.42972498555338, 37.92567176203574, 43.50803605971798, 79.09025638334214, 28.54031462823191, 54.76131216172249, 83.86353769610005, 69.6681191844325, 76.42492740384995, 71.98002692191832, 76.17885358871953, 64.31577444076538, 79.21820409836309, 4.516932358664851, 8.184308265486072, 0.3601952672245041, 10.516075453450604, 49.510619563441125, 58.535310837530325, 70.91545643345003, 61.34847002644693, 67.5572721419796, 65.80796564778974, 61.72865752250918, 56.91829412214218, 61.53022089312154, 62.24928156022103, 63.80710186496858, 60.41522833608813, 64.68608540873375, 59.192754991592906, 59.963116338176114, 55.71564443649785, 55.39223717105005, 66.55212556162189, 70.27391356806602, 64.60498648305094, 65.26319157692694, 64.76443475292575, 65.87743082354146, 63.33973184708626, 61.10403183967837, 54.73752690899757, 58.116739026961795, 53.69437256167012, 57.719120517853774, 55.14169969866353, 49.40665714202389, 51.92098663699243, 47.33106828504994, 54.55627810570502, 56.07931483176447, 51.44994135825865, 49.43376856465494, 54.018987917131, 61.69556840773552, 57.15939044952393, 61.710269451141365, 65.7282042503357, 66.7984268742223, 60.369152253673924, 60.43238086085166, 64.10809278488159, 62.371694810928844, 62.683119235500214, 62.8402768411944, 58.70057598237069, 50.716391455742624, 51.080881626375266, 47.44314609035369, 53.12937867256903, 60.91719758126044, 61.61284562080138, 55.569049773677705, 60.211390602973204, 55.65234914902718, 51.6181835820598, 46.38283921826271, 50.93527932320872, 48.12222603828677, 58.910948384192686, 59.80127150012601, 64.04894344268307, 61.65552493064635, 61.14862526616743, 62.17719624119421, 61.18957481076641, 59.682655103745006, 60.30353100069108, 59.116904197200654, 53.82291647695727, 46.602080099044315, 47.626399224804295, 51.74414657777356, 55.04342471399615, 52.9514560391826, 59.32243247185985, 56.769702972904334, 52.62460101035334, 49.744792907468735, 49.50979194333477, 48.51056814193726, 55.3884324719829, 48.44390353848858, 50.646428138979026, 50.876396702181914, 54.58932407440678, 56.07574939727784, 60.24410709258049, 51.156599060181655, 58.48213918747441, 64.34919695700368, 59.05416980866463, 61.366991458400605, 59.18651057827858, 58.424707843411355, 62.354204962330485, 60.637764007814475, 63.092932393473966, 62.80908223121398, 63.65571406579787, 61.53796365184169, 63.1462295593754, 62.688073189027854, 63.6707720448894, 61.19192431049963, 65.42406366717431, 63.71480457244381, 65.55307826688214, 53.22503351396131, 47.96209135363179, 17.255636030627837, 0.9778378747643964, 2.3661778963381246, 5.927961391787376, 68.19973284198393, 61.75309781105288, 71.15602324085852, 60.04621175027663, 64.55567444524458, 70.20123204877301, 73.24333606227752, 63.74545397297029, 46.627257793180405, 71.06435744993149, 47.27386836082705, 33.73547038724346, 47.05567083051128, 62.88596853133171, 35.86891420425908, 0.13218335386726165, 0.18253437543828643, 0.15613397433152124, 0.12954517688241698, 0.10010087096522893, 0.2381519756970867, 0.1537400108551787, 0.08177066987921154, 0.26056890345869527, 0.07568593993182145], [0.07605235212512555, 0.044738052397846215, 0.03900029133224199, 0.022613391009790283, 0.06826922057136413, 0.025361536085725795, 0.060055478656243895, 0.020879312688785217, 0.09212731293612912, 0.029115378406018983, 0.0034793288373733845, 0.025615534452240796, 0.04406309829303815, 0.1380641205656913, 2.9097073501156223, 47.37387311074042, 44.77151386199459, 40.33650167526738, 24.65148268207427, 48.21590792748236, 33.86594018628521, 29.865985531960767, 82.42070951769429, 56.71881414228871, 70.13546959046396, 58.67457066812823, 66.84799778846003, 52.85547171869586, 69.64290618896484, 19.458635237909135, 1.734972192395118, 0.45422520548585926, 1.1848330545809962, 22.196294684563917, 50.66380423884238, 65.41502260392713, 61.817114814635254, 60.685079559203125, 54.692058793960086, 59.00430471666398, 58.74967228981757, 56.841851049853915, 58.31011579882715, 57.94461365669005, 56.10003671338482, 61.17616814951743, 62.57016281927786, 63.668371554343935, 56.69904147425006, 48.64141448851555, 57.951242462281265, 55.14211154753163, 63.55707822307464, 61.63662695115613, 60.743307144411155, 59.050043475243356, 59.19232353087395, 59.79694120345577, 56.1961426273469, 49.98487726334603, 51.04448987591652, 51.45630344267815, 54.95375148711666, 47.99432539170789, 46.94425198339647, 42.511134301462484, 44.178557395935066, 44.54455767908404, 46.662967051229174, 45.19798532609017, 51.041304911336596, 52.558003087197584, 51.253371777073035, 54.106284187686065, 58.279905703759965, 55.86541229678739, 56.29233091108261, 57.20844361089892, 56.93098298964962, 56.707835428176395, 56.25308367513842, 47.08578678869432, 43.46945170433291, 44.037061814338934, 42.12250586478941, 43.49588847929432, 49.24343162967313, 52.311560569270966, 50.75663105134041, 49.83381109852945, 50.21506940164874, 50.65802658757856, 45.99838810582315, 41.42770897957587, 42.30941857061079, 45.043957771793494, 50.83908319473267, 57.81578340838033, 57.69457432531542, 55.87780306416174, 55.58890481148997, 57.22140704431842, 54.333448256215746, 56.062436872913, 52.61720342020835, 53.828541155784364, 51.94495231874528, 45.597219851709184, 41.19390826071463, 41.2528104935923, 48.06581451046852, 49.669734431851296, 49.959656423138036, 43.80154309734222, 42.42711713237148, 44.21654555105394, 44.11556020859749, 46.57053247574837, 50.59784566202472, 45.38063833790441, 46.88959375504525, 46.41279043689851, 50.63027189623926, 52.76647706185618, 55.163704195330226, 55.82048546883368, 51.579163843585604, 58.095487625368186, 57.18242652954594, 55.60819502799742, 56.38443992983911, 50.476260031423266, 52.62500893685126, 58.316740682048184, 59.06688613276328, 56.21004350723759, 58.87077546888783, 59.073581618647424, 58.90797914997224, 55.799794966174716, 59.98413631992956, 60.84298633760022, 54.72588923669631, 55.85099758640413, 56.920349444112475, 39.66226193212694, 21.468973505881525, 0.9689386297137508, 0.1491168081279724, 1.6803335758947557, 13.603138654462754, 56.14690119220365, 51.758110215587, 58.69619861725838, 51.81170548162153, 64.60162893418344, 52.32624200082595, 65.00034962930988, 33.63483021336217, 47.2332835966541, 53.44661212736561, 23.486403419125466, 49.255155594118186, 43.934476144852184, 41.90222163354197, 5.637824650733702, 0.15100748248157964, 0.057668325701548215, 0.02048815968596647, 0.022193689740473227, 0.01622373125545921, 0.03655567029190641, 0.007745673205898775, 0.033505832130510005, 0.00930256640253168, 0.03279086525341676, 0.04602730559605745, 0.03963247474823748, 0.055836299208984266, 0.04408396652809555, 0.024129027020066016, 0.023717679939563238, 0.04716476613295175, 0.0489962563639687, 0.022467066301032904, 0.035377469199198874, 0.07038277288478229, 0.09817198414595858, 0.073231715979355, 0.108738282485114, 4.109963899658573, 60.392349150873, 48.9311364389235, 41.277246859765825, 36.36492536913964, 56.17282021430231, 35.281445134070616, 31.866688497604866, 89.34630517036685, 61.35511059914867, 76.13704112268265, 63.17471773393693, 73.89856015482258, 60.69012372724472, 75.43422299046671, 24.09004834390456, 1.0927381318423057, 1.6882929229928603, 1.1670964643839867, 26.899079238214803, 53.9027367099639, 64.6061122032904, 63.035222561128684, 63.631058046894694, 59.18778142621441, 61.342241302613296, 60.19030001855666, 58.0578681730455, 57.426543081960375, 58.435721858855224, 57.933717312351355, 62.98613409842215, 63.30011590834587, 64.17743636715797, 56.86022735411122, 50.22967630817045, 58.454729664710264, 56.848891704313225, 64.04495439221783, 65.01926329828078, 64.76417195412421, 60.499116066963445, 61.87087874258719, 61.00772196246732, 59.9880273111405, 51.06210916273056, 53.3564172252532, 52.17928647994996, 55.343395817664366, 48.761854787026685, 48.14372062683106, 45.221739199853715, 45.01037051600795, 47.22739611902545, 50.0890750269736, 48.30555369777065, 52.859613741597826, 57.160633840868556, 53.27102722660188, 56.398576151940134, 59.312956025523526, 58.04728954069076, 59.510525811103086, 60.75501541937552, 60.06324268156483, 58.25263738632203, 60.293309304022024, 51.85326299359722, 46.44392228895619, 46.15810701923986, 45.46274139035133, 45.98186708265736, 51.66393803011987, 55.30831806121334, 55.44329074121291, 53.73044267777474, 53.67773778976933, 53.005416085643155, 48.327311085116484, 43.05791662585351, 45.06288320787492, 46.35053457752351, 52.932867926936, 59.980425757746545, 58.652315139770515, 57.96668875601984, 59.17169578613774, 58.59390712553456, 56.2175234671562, 58.577009554832216, 57.166089857778246, 55.581311102836366, 53.41042434015582, 47.51515688434724, 43.90924353753367, 45.04937064263129, 50.47860168641614, 50.83530595225673, 52.10851907730103, 46.21844876197077, 43.782080296547186, 43.25039909731957, 45.42794212218254, 48.77509278635825, 51.54070108167587, 47.19430308188162, 47.02806126686835, 47.82021922449912, 52.04263110314646, 52.75624359807661, 56.0778517876902, 61.067475349672385, 53.55051571323026, 58.30150619629891, 60.569840323540475, 58.84346400537799, 58.20738500164401, 51.55878713054042, 56.40589921705185, 60.07451165106989, 61.497861339199936, 57.781164569239465, 59.032573238495864, 61.304700297694055, 60.519347652312256, 58.035534197284335, 62.5501940327306, 62.10468730618877, 58.485590873226045, 57.890806582666215, 59.33305817265665, 43.215093843398556, 23.930582423363965, 0.4096499199588453, 0.7647294971731402, 1.6688308576422355, 17.472954950025006, 61.39550708955335, 55.67370645461544, 63.84990276828889, 58.29522648165303, 68.9701569464899, 56.66069246107533, 67.95862474749165, 38.014517368808875, 51.83503966177664, 59.84094627441899, 31.777899765199233, 57.74784795699581, 47.05765554981847, 52.013723234976496, 10.006392867334428, 0.24067576043307784, 0.023148122296157866, 0.01001764627759375, 0.06613241748944407, 0.0793244821890708, 0.04738640303032533, 0.04903648747131229, 0.091323847582023, 0.03554970874721485, 0.04265541939305202, 0.1707505795263475, 0.1999456387373709, 0.1511495611480167, 0.13845502458993467, 0.1738349567618101, 0.16659049227112727, 0.15735845862617417, 0.14699019401544525, 0.14164696056996623, 0.15525812132944986, 0.18134986561152244, 0.24026049481284237, 0.26600288767968455, 0.5360058574907242, 8.318787217140198, 75.38741342483029, 59.953075070534986, 56.85929775238038, 38.67271854031471, 65.57040729830342, 42.99526852946128, 37.92746820757466, 97.90258699847807, 67.35963175373693, 81.3176998015373, 69.24164772033691, 79.54144662426364, 63.9256319692058, 82.35125218668293, 24.88912340133421, 6.699242043879725, 1.8309643576222083, 1.6721209907724013, 37.993889624072665, 56.7008065408276, 67.4266258362801, 64.49988265191355, 66.14426182162377, 58.42039323622181, 62.242672366480676, 62.28757566021335, 59.25639937000891, 56.920008197907485, 59.51809990790583, 57.999824939235566, 64.88107427473992, 64.73274592430361, 66.58380262313351, 56.83333950657999, 52.499183224093535, 57.75521416817942, 58.710844747481815, 70.52099150996055, 66.95852233517554, 66.82451848060855, 63.965334200089984, 64.39441404035016, 64.36671818456342, 63.223347279333304, 54.80653316743913, 57.258281246308364, 55.72647410054361, 59.142321155917266, 51.75613334102016, 51.550177528012185, 46.5701323939908, 47.25035767401419, 49.79559936831075, 51.90157874937981, 50.52867074166575, 56.13925257036763, 60.39496537177794, 57.54574391149706, 58.67962268091018, 60.82089947115991, 59.343495599685184, 63.14603344086678, 63.490680340797674, 61.595959817209554, 62.15169691270398, 61.41544449713923, 52.623055596505445, 48.628929584257065, 48.45730627736738, 49.07464027404786, 49.98406925509053, 56.263791745708836, 57.37021392391574, 58.60948285748882, 54.41007175753194, 55.71194171905518, 55.97084952938942, 51.570181615891, 46.105374674643244, 46.72403051007179, 46.49610942409885, 53.321347313542525, 63.12646081370693, 63.348498344421394, 60.52154810197892, 61.35079206958894, 62.42563524553853, 59.446771606322265, 63.9881859287139, 58.81712528967089, 58.967073578988355, 58.4346196728368, 50.822683765042214, 47.315492553095666, 45.73298877285373, 52.690426226585146, 51.83837759879328, 51.45553858049455, 46.115019782896965, 46.44578933715821, 46.25139274904805, 48.14881970805507, 49.145529270172126, 54.62218569171045, 50.154786494470414, 50.27841175756147, 50.06115559608706, 55.19876233993038, 55.92898999491046, 59.13206415791666, 58.560931759495894, 57.01131313077865, 60.31601198257939, 61.812941412771906, 60.66043530741046, 60.79196806876891, 54.96448309190812, 58.38249529561689, 62.5130452648286, 64.71120818968743, 59.55715887008175, 63.13305824033676, 63.946310704754254, 64.11126990472117, 59.207911029938735, 65.61501641427317, 64.93446557752549, 65.51605893719581, 59.01349482997772, 60.280577290442686, 48.04195081034015, 32.844696198740316, 1.814417961624361, 0.5845489268822055, 6.608994680066263, 19.475071930116226, 69.8782091756021, 60.904171389918176, 68.53353438838836, 64.24319490309685, 74.88504409790039, 64.0765098602541, 75.14865090770107, 42.51501352556291, 57.925574471873624, 68.84274267381238, 36.058627482383486, 64.6798292283089, 55.248462692383804, 68.8263471664921, 19.171802113133094, 0.42094922654571076, 0.3384025479035993, 0.13233500863275222, 0.1541658944540447, 0.179227281121477, 0.14944821776401612, 0.1294505190584929, 0.18616888041217483, 0.1690764475854174, 0.11675998914025484], [0.053402874543662035, 0.00751240469980985, 0.04156232300785281, 0.0833396792351719, 0.029965282094875173, 0.01870682140091254, 0.020186677274684754, 0.05591124942105624, 0.03717252045809742, 0.06828030586362847, 0.0710825405774578, 0.03853366334712313, 0.04769936526915239, 0.04916864529912991, 0.028886427284188332, 32.83121697364315, 56.283615404559725, 36.6164630459201, 22.25521456810736, 33.00683913692352, 57.73466094847649, 25.77633607772089, 54.894464861962106, 70.9945627950853, 60.49726863061229, 67.26754234683129, 59.49066292855048, 58.707475431503795, 58.305224603222264, 40.827264708857385, 1.4431424583158186, 0.36486441990540874, 0.11442648532289652, 8.998161342836196, 39.635581970214844, 61.41511894041493, 61.44549377502934, 62.63549381686796, 65.27424481607252, 62.22153471362207, 58.94051913292178, 58.777842752395145, 61.906156539917, 62.71247033149966, 61.979583309542754, 58.96868567312918, 61.181522184802645, 58.64771027718821, 61.84226505218014, 58.65677879702661, 54.989029284446474, 57.228867392386164, 53.10083950719526, 60.788073155187796, 61.29695361660373, 60.82379418034708, 59.483320251587905, 60.066196226304584, 57.32881722911712, 57.85447759013022, 54.18433935411515, 51.48561531497587, 52.35051362745224, 50.58272492501044, 46.07312886945663, 44.14945733162665, 44.49495146351476, 45.46113321858068, 42.61411613033664, 43.127719125440045, 53.22551204312233, 55.535297778344926, 51.648993799763346, 56.41270452930082, 56.73580192750501, 55.77049486098751, 58.89120317274525, 56.523421272154785, 57.86678598773096, 55.0904147086605, 44.60226751142933, 44.083412462665194, 43.703068071796054, 42.55600621623378, 41.65498287447038, 45.370816722992934, 46.71624460527974, 50.29661547753119, 47.90322442208567, 48.6354995542957, 49.69222530241936, 47.61900555702948, 45.270694301974395, 41.14759291371992, 43.326591137916814, 40.79448938369751, 44.3947192161314, 48.726733884503766, 55.612031106025945, 55.00067872385825, 54.91449248406195, 53.79683271531136, 54.81701374053956, 55.9230907501713, 56.564249223278416, 54.386486545685806, 54.72958018702846, 47.87270445977488, 42.824657194076046, 44.66964990861955, 42.66893517586493, 45.22455938400761, 43.50716529353973, 43.10208643636396, 45.28006876668623, 42.86821511483962, 45.57567034998248, 47.83449665192635, 47.22150079665646, 47.1945894149042, 49.393434832173014, 51.245703543386156, 50.752755749610166, 53.576379822146514, 55.22777218972483, 56.98626487485824, 54.871326800315614, 56.227956971814564, 57.61736639084355, 55.48603280898064, 52.720914809934555, 51.47136926651002, 49.215951504245886, 50.530086717297955, 50.90084483546596, 54.540667072419204, 56.79719878781227, 55.80727492609332, 56.22593695117582, 54.60693159411031, 58.07704464081795, 57.547434453041326, 62.40350523302632, 60.514217192126864, 52.503748862974106, 31.40356052306391, 2.596385233825253, 0.0716894354310728, 0.37130954825589735, 1.0383125490719274, 20.571321441281228, 57.81894483873921, 52.754109828702866, 57.92888102992889, 55.33732006626745, 56.174279336006414, 56.545261029274236, 54.85274261043918, 30.121837815930768, 59.788288454855646, 30.632391168225197, 25.523050985028668, 46.03971812032884, 39.08608928803475, 32.17026425946143, 1.1810176915699437, 0.04178405566621692, 0.017318593473323894, 0.04489618443673657, 0.07661992368558723, 0.059016196117285764, 0.06282726903596232, 0.044520100383388425, 0.10872993978761858, 0.061008438407894106, 0.11767698872473933, 0.05258691046507128, 0.10407163491172176, 0.04385314040607022, 0.05953567267786111, 0.08570696752999099, 0.04396843663867443, 0.02567014694514294, 0.03666698669774398, 0.033496409249041355, 0.0401433366501043, 0.057632024625256184, 0.027767720579680417, 0.08210697481709142, 0.07004375599565045, 0.30733219738448825, 39.83077087709981, 65.93349718278455, 35.55091196490873, 33.888889974163426, 43.39263600687827, 59.835855037935325, 31.46258827178709, 63.52874694332, 76.95027397524926, 66.56604213099327, 74.17809963226318, 64.51287746429443, 62.88866712201027, 64.07920452856249, 48.72952268969629, 2.4761604205254586, 4.016105994101494, 0.36314479766353486, 11.665838841469059, 43.66375415555893, 66.2151704295989, 64.20741504238498, 64.38204680719684, 65.76703179267146, 64.83390777341782, 58.96849347699074, 60.3862851665866, 61.7513955023981, 62.73787552310575, 63.33158900660854, 60.08235246904435, 63.468126712306855, 62.514551454974765, 64.54768457720357, 60.28815138724543, 56.219735683933386, 58.1606028925988, 55.11146606937532, 62.915096052231334, 62.618345214474594, 64.01931778077157, 60.4648070950662, 62.496724282541585, 58.63410357506045, 60.440154998533195, 56.91195949431389, 53.61268920283164, 53.4786343574524, 52.57095475350657, 47.19238896523753, 47.43155156412433, 45.675361310282064, 45.16095030692316, 43.477272910456506, 44.833581447601325, 57.10644629693801, 60.180811805109826, 55.280747721272135, 59.51092197049049, 59.843664476948405, 58.70323534934752, 61.359468352410104, 59.33789053270894, 59.527195884335434, 58.36061631479571, 48.88685680204823, 46.344003831186605, 45.64019726168725, 46.10577083403065, 44.7735809510754, 47.09387863835981, 49.599261206965295, 52.436217415717344, 52.184609136273785, 50.76192625107304, 51.73019078470046, 51.16456539400163, 47.78463548229587, 43.42775298703102, 44.18040483228622, 42.85092922949022, 46.09416061832059, 52.98395287606024, 59.31490936586934, 59.691856984169256, 58.49554192635321, 57.415344715118415, 57.608156665678955, 58.19503345797139, 57.47705928740963, 56.23380130337131, 57.73779884461434, 50.26176521855016, 45.73156495248118, 46.08983032165035, 44.45030312384329, 46.739166936566754, 46.02926892618979, 45.096533221583215, 46.15166648741692, 44.316193365281634, 46.04872388224448, 49.62180699071577, 49.48019373801447, 48.68862805827972, 49.8499987202306, 53.55388502920828, 53.631183178194114, 55.324356632847945, 55.8135820973304, 61.673760029577444, 58.50365338786956, 58.04529697664323, 59.57526845316733, 57.48718684719455, 56.865565699915734, 53.53228453666934, 51.88697576522828, 53.77169816724716, 53.67525885182043, 57.060766373911214, 59.03025119535385, 58.114691549731845, 58.36160082970896, 57.26424717134046, 61.87992765057472, 59.78528784167383, 64.05052023549234, 62.6694497754497, 55.811958236079064, 35.202185799998624, 2.2257467479475084, 0.19626006634244997, 1.3010043434558378, 2.570778285303424, 25.42228529530187, 61.085071102265395, 57.1348834806873, 62.78642662109868, 58.82640953986876, 61.82944282408684, 61.9967632908975, 58.7558029543969, 33.74349947898619, 65.0107595997472, 38.08507296346849, 27.51435987411007, 43.576218620423354, 46.30661972107426, 41.21461053048411, 0.8195228634342071, 0.09307216747754044, 0.1678497876010595, 0.02195666979758009, 0.07180461675048837, 0.024710566278607137, 0.02264495000183102, 0.0445262175954638, 0.058342804831843224, 0.03740915735702842, 0.02288736703415071, 0.234839886487011, 0.17629661176714206, 0.15687930127305372, 0.22250076876051966, 0.21773921055418832, 0.14367052053491916, 0.1910092997094316, 0.13111581034477682, 0.1467038609928662, 0.17919944148630867, 0.21243736117837891, 0.13468711306491207, 0.1773680929815577, 0.15504787615951032, 1.0331183503712378, 56.380996088827814, 77.53364809097783, 54.824560380751095, 32.80218751199784, 49.215206253913145, 70.02606684161772, 35.18545296884353, 67.61641363943777, 84.53259991061303, 72.40296040811847, 78.76866125291394, 69.05021252170687, 69.89683258918025, 69.9509063843758, 54.13008905226185, 4.259919053123844, 2.9411620622681034, 0.4548828460035786, 16.51480228670182, 50.88779510990266, 64.00483246772521, 65.21943753765476, 66.53278043193203, 70.0814820874122, 66.81461057355328, 62.251356494042184, 62.05069195839667, 65.81164483101138, 64.98369916792839, 63.765501206921, 60.13655178008541, 67.22241155562863, 64.0891791159107, 66.42948873581426, 61.73839676764704, 59.29542695322345, 59.260274671739154, 55.965468037513, 65.37588519434776, 66.67477807691021, 65.89559139743929, 62.35916676059846, 65.71166753768921, 61.87016094884565, 62.337197565263324, 61.868333124345355, 56.601707858424035, 57.471579736278905, 55.67073329802483, 51.00783140428605, 49.28205128638975, 49.010803699493415, 49.53690728833599, 47.2367548942566, 49.51186295478575, 59.90301778239589, 62.75298057063934, 57.23557072301065, 62.43239348934543, 61.84158648214033, 60.81621616117416, 65.31943836519795, 61.79031325924782, 61.85208666709162, 60.01866886692663, 48.70649445441462, 47.56557110817202, 49.56660747528077, 48.15875507170155, 46.759810370783654, 50.698901607144265, 50.32838667592695, 55.68734845807476, 55.28390130689068, 53.33199262619019, 54.729572342288115, 53.16480551996539, 52.05064842777868, 45.653764740113296, 47.048128112669914, 44.947581214289514, 46.9139555961855, 52.442242176302024, 59.02779186925581, 62.41688051531392, 61.227751239653564, 60.25343448885026, 60.95768820854926, 58.734167160526404, 61.56769521774785, 58.417145513719134, 62.272603973265625, 51.58336470204016, 46.568547756441184, 50.16122702629336, 47.01166968191824, 48.49002276697467, 49.365499711805775, 47.504060499129764, 47.39577562578263, 46.60273121249291, 49.06024909788563, 52.212308914430686, 51.005630954619384, 50.38215452624906, 52.84722297422348, 55.39410421925207, 55.84222716669883, 57.25431180769398, 58.290401966341086, 60.37140761652301, 57.25042473885321, 61.78007979546825, 61.97766919289867, 58.41018722903345, 59.65615949323101, 56.02920263044296, 53.396527382635306, 56.86323973440356, 56.90420104611305, 60.688578313396825, 59.94746608118857, 62.525412497981904, 61.36428894535188, 59.31275598464474, 65.59096051800636, 62.87427986821821, 65.93328537479525, 63.502553355309274, 60.964932826257524, 42.88349666903096, 6.332938267338661, 0.2405527113906799, 2.2415556157788923, 6.783352369262326, 27.40753608365213, 65.6005899367794, 63.570935956893436, 68.76563672096499, 64.94826839816186, 65.58483769816738, 68.65924635241109, 65.30221916014149, 39.22605906763385, 71.10140815857919, 43.71349765408424, 38.71178926960115, 55.02784505967171, 55.02965327232115, 60.83043475304881, 3.34154216512557, 0.3184840167241712, 0.2519617524118193, 0.13446586687237988, 0.14616825828148475, 0.20673037386469303, 0.1413571801517279, 0.12040554876289061, 0.18872422797064628, 0.18596827262832274, 0.1640880507447066], [0.06531779023428118, 0.01431961971966009, 0.012114793775723347, 0.04679980567626415, 0.06292807088503916, 0.05923476100208298, 0.00951961539084873, 0.013048447154071784, 0.0655145216132364, 0.03363203362471635, 0.05903177451522601, 0.03586344090440581, 0.10251512044980642, 0.04407828215569739, 0.20932307587035243, 11.507872246926832, 50.094684016320016, 36.976905330534905, 31.54633479733621, 25.357266126140473, 47.46142041298651, 45.04954714928904, 27.548368784689135, 72.8211635158908, 59.88752834258541, 65.6869605279738, 59.451090135881984, 67.2358182168776, 59.38755558383081, 46.95978064690867, 2.511361731636909, 2.3586033092391108, 0.13881307876398488, 3.085036316225606, 30.339158696513024, 60.26675878032562, 66.90646463824858, 64.27924148498043, 63.719056421710604, 64.09093633774789, 62.916578708156464, 63.94317673098657, 64.54783362727012, 61.996802514599224, 60.65133933098086, 60.274285808686294, 60.198709580206106, 62.8192097909989, 62.54263562540855, 67.0173578877603, 64.62381778224822, 62.543235748044914, 57.817066023426676, 54.503298651787546, 57.4068880850269, 61.752627126632206, 59.329983034441554, 57.01846753397296, 58.17377421163744, 55.39544959222117, 54.68745785374796, 50.143089986616566, 48.543335622356786, 50.6234783511008, 46.83685748807846, 45.06867654861943, 42.86066062988774, 41.86011106737199, 41.056731208678215, 42.63510081075853, 48.47867927243633, 55.22450485537129, 54.995885587507686, 53.822120235812285, 56.94687251121768, 58.020295789164884, 58.68200748197494, 58.43971875406081, 53.58974333732359, 46.05367783577212, 43.5483854816806, 40.925696588331654, 41.0065209481024, 41.104380161531516, 40.78557775866601, 43.893397162037516, 49.381954054678644, 49.106544833029474, 45.69178819656373, 49.412187683966856, 48.7504759911568, 46.21714653507356, 42.565294388801824, 41.25264575404506, 41.430317355740456, 42.36119385688536, 42.289614523610766, 43.432491210199174, 47.35197844043855, 57.18339535497851, 59.78731962942309, 56.0767456793016, 56.06603760873118, 53.65207764410204, 54.02561280035204, 55.19001545444612, 54.246716806965495, 52.64391083871165, 45.20563394792619, 44.779507652405776, 39.89316401943084, 41.54448578434606, 40.807346913122366, 42.163035715779955, 42.91165536449802, 43.42467000407558, 46.95137892999957, 47.42757035839943, 46.308239659955426, 47.789205043546616, 50.18242351470455, 55.14274697149954, 53.47767729913035, 54.60127161395166, 56.80547891124603, 57.76206654887046, 56.25404465583063, 54.509770562571866, 55.622546980457926, 51.63506546328145, 58.8148424702306, 56.59633421128797, 54.52495405750891, 52.678215888238725, 54.517368193595644, 53.89333871103103, 52.36700327165666, 52.88040622588127, 54.17653383747224, 54.55082208879533, 55.838006696393414, 60.61714803018878, 57.888096224877145, 58.91525906901206, 50.72895088503438, 15.63068534097364, 1.1297324564187758, 0.500132717913197, 3.764064047605761, 0.8679026641672658, 34.43971626220211, 58.97922115941202, 54.51864688627182, 54.53251638720113, 59.140218765504905, 58.37146166832217, 61.39338508729012, 52.37835461093534, 53.923956732596125, 50.315646817607266, 19.830483774985037, 41.37667894363403, 23.24518745945346, 45.48515773588612, 14.658153268598742, 0.0677689498350505, 0.08690774140338745, 0.022170477276367527, 0.06949164408950076, 0.0198169460054487, 0.06444610475051789, 0.07050972131471481, 0.07799653005936454, 0.009576681280328382, 0.07355763276498165, 0.06937004295327971, 0.02421198285094673, 0.022817216362924348, 0.01726870965813437, 0.06289936940095599, 0.07299638909077452, 0.09474003281924995, 0.028835018954029488, 0.05436704216164447, 0.05504710990334711, 0.007745448167571017, 0.018124133010485002, 0.027190534615769025, 0.05762866149926859, 0.05332264598579176, 0.1965445301104938, 14.25302440120328, 64.10880665625295, 38.85579909047773, 36.20180968315371, 36.54797846271146, 55.18301010131837, 48.62055924630935, 32.03762342852931, 80.50298429304554, 63.78554451850153, 70.70492713682114, 65.71765699694234, 71.81840958133822, 63.04902538176506, 54.68032306240451, 3.975437144117971, 1.9161549282650796, 0.18730310422758903, 3.6768121488632697, 34.22315828261837, 62.18891628326909, 69.34389606598886, 68.3386710382277, 66.11416939766177, 66.31916030760735, 66.73838323162448, 67.02732070799797, 66.345306827176, 64.17587134145921, 63.65017567911456, 62.31469100521457, 62.114756030421105, 65.30387047798403, 62.594826682921386, 68.89032886874291, 64.82431365597633, 63.33086336812666, 60.023426701945645, 59.16824017801593, 60.003689335238555, 63.09782358907885, 61.6009412273284, 61.14332222169446, 61.42276363988077, 56.244752560892415, 57.834963798522956, 53.37029457092286, 50.69599513084658, 53.850184794395204, 47.72808667152159, 46.5568277143663, 45.50196509207449, 43.92454078120571, 44.60841778785952, 46.100844337094216, 50.51328720584993, 58.41871838415823, 56.39647376152777, 58.086254365982555, 58.058142738957564, 60.40548516858009, 59.295164154421904, 61.09176266577936, 56.33273916859781, 49.46918364494078, 45.49406936091762, 42.34562204730126, 42.23116728567308, 42.879601755449855, 45.48228656091998, 47.09246658509778, 52.33937017379269, 51.28674722486927, 51.34182122445876, 52.36712094276182, 51.15073119440387, 49.33963168051935, 46.2436931363998, 45.432115524045884, 44.204680381282685, 44.04172159010365, 43.855750253123624, 44.73238429715557, 51.74873575087517, 59.456648134416156, 63.96983315867763, 58.37815715420631, 57.5068889125701, 57.7708448133161, 56.53376456229918, 55.95126121274887, 58.11231459340742, 55.31673938997331, 48.97929137752902, 46.70251630967664, 41.922233566161125, 43.02942845129198, 42.500308559786895, 42.711551727787146, 44.536858066435784, 45.399073477714296, 48.45785933156168, 50.25263001841884, 49.70498869496007, 49.04204537791591, 53.058473986964074, 56.01250117824924, 55.44340056757773, 56.957502134384654, 57.08202562024517, 59.85737316070065, 59.34016942977906, 57.04009156073294, 58.486014489204656, 52.83309851923297, 61.32108403790382, 58.30970002758888, 56.303835222798014, 57.77280207603209, 56.64508535015968, 55.81768489653065, 54.68597127545265, 54.90629080803164, 57.35593257411834, 58.17775933973251, 58.788307636014885, 61.46230897595806, 62.713211659462225, 63.3782652116591, 53.55775248619818, 17.10486012120401, 1.6770246889322036, 0.5107343941926956, 2.210097961848782, 2.399440085695636, 38.22253242615731, 62.6099278080848, 59.828884986139116, 58.363161933037546, 63.89624557187481, 65.22362662899879, 66.00263287944179, 59.45909569340368, 57.14639955951322, 56.787349716309585, 25.321670616826705, 44.92909900603756, 22.452521554885372, 55.2239949472489, 17.636578582948257, 0.12594804167747498, 0.026919138392493613, 0.019675466802812392, 0.03158825468422184, 0.01992784106292792, 0.025820334652258504, 0.008174978823761546, 0.05889425407193842, 0.017594118910511176, 0.04523904325680868, 0.0209354535270963, 0.115874245943081, 0.07687809531606975, 0.10272117511880013, 0.19473778834987074, 0.17902783779126985, 0.1551181570656838, 0.11709111532376659, 0.09366161084824032, 0.147303493332959, 0.16298630905728187, 0.11975106452741932, 0.2199902373456186, 0.2985696224195342, 0.1760922654742195, 0.4155238225094734, 26.34501503359887, 74.30590614195793, 61.834820393593084, 48.460663826234885, 38.888507735344675, 64.34007352398288, 56.354986852215184, 35.98100377667335, 88.54515321793096, 71.88060268279045, 78.55711214004025, 71.00429027311264, 78.76444862734887, 69.11999148707237, 61.535233682201756, 4.7560939769591055, 6.279782797059705, 0.22871692875219932, 5.3629498520205106, 42.60845222780782, 64.07000657050841, 70.52885193978587, 71.1309906744188, 69.87813857293898, 68.78978283174577, 68.85363117341073, 67.7101190628544, 69.40402600073045, 65.9168977122153, 66.57762096774194, 64.71118073309621, 64.13386275691371, 67.08557574979721, 66.73065616238502, 72.11912985770934, 69.11772435711276, 67.76904090758293, 61.163946044060495, 59.294163950027965, 61.120960789342085, 65.28385854536488, 64.0898145398786, 62.12401282402777, 62.99144106526529, 61.38254365613384, 60.4519142643098, 55.458725267840975, 52.0139350429658, 56.01807094389393, 49.99585989982852, 50.30851202626383, 46.48937863688315, 44.79999419181578, 45.98886851341494, 48.26531410217286, 51.655595148763354, 60.26529181388117, 61.52327829791654, 59.10563522769559, 61.77069748601606, 63.7223159113238, 63.18157795936831, 63.77664466058055, 57.22504308146816, 50.4296975751077, 49.565262102311664, 45.82735315445931, 44.490142637683505, 45.40713787078858, 46.10787714681318, 50.643011754558934, 55.73380893276584, 55.84875006829539, 53.31178457506242, 53.692905595225675, 53.95319800223074, 50.954251827732215, 47.89531300144811, 47.828248316241854, 47.06483348723381, 48.00539432033416, 47.08134666565926, 48.15855895319293, 52.08490248649351, 62.68448029795001, 67.0592252669796, 61.560387842116825, 60.13852865465226, 58.67225646972657, 58.57197323153096, 59.952843650694824, 58.797062366239494, 58.437765413715, 50.189303351986794, 50.2445028674218, 44.56501283953267, 47.44557795986053, 43.78105263556204, 45.870542372426684, 46.88698537888066, 49.15995967003607, 51.63353966128442, 53.29687564603744, 52.00455273351362, 51.41747590034239, 56.475089826891505, 60.59174283858269, 57.27473166681106, 58.28067841068391, 59.59944202053932, 61.4133381843567, 59.038350889759684, 58.61890046827255, 60.768002387016054, 55.44094908622004, 63.93478285881781, 62.14736661603374, 58.331606465001265, 60.35468655247843, 58.930132696705485, 60.117163504323656, 59.280741599298295, 57.690722557806204, 59.6505779604758, 59.31394446280695, 61.90668998226043, 63.38822803189678, 64.66099008437126, 63.3069133758545, 56.76320360552881, 24.17746032437971, 2.2259296284567927, 1.778711645353225, 9.278369584391195, 4.178138615623597, 42.0273530867792, 69.96510536439958, 63.799986685476, 65.34916993110411, 69.21887443911645, 67.510117407768, 72.68651639261554, 63.816197841398186, 65.56020129111506, 60.18357707608131, 31.928175572426092, 59.9280660383163, 35.51904662962883, 66.24749860455914, 29.577518740007957, 0.20400325407183942, 0.19675169560697772, 0.15249910163542918, 0.10948210789431488, 0.15155816180331094, 0.17713316445869787, 0.258468535518454, 0.1900641617154883, 0.19450472908154612, 0.1980176712236097, 0.2623960844451382], [0.05175717212560196, 0.07943672939173638, 0.04565479917331569, 0.051021693244336114, 0.03538448273414566, 0.09287434825373274, 0.061936611384754224, 0.07376677476831021, 0.08331882632187299, 0.0845598810983281, 0.03701978550863363, 0.07533053642198925, 0.10152253096983319, 0.06294358033506621, 0.4767716327501882, 1.9427717645322125, 39.99502012806554, 42.581964462034165, 33.63500672001993, 28.070255825596472, 28.08636696107926, 71.15045347521382, 35.18027936258624, 57.854312850582986, 69.80765358094247, 61.853447729541415, 64.18097826742357, 58.690632773983864, 64.19519685929822, 55.49786659979052, 13.84693749489323, 7.946269915949914, 0.3215696656655881, 0.31961969610664154, 17.81283813138162, 55.05708632930633, 68.76287537236368, 64.1014482898097, 66.17893557394704, 64.94376943957421, 61.70264436352638, 62.67373300367787, 62.611802701027166, 60.94691345768591, 62.21172878819128, 60.86290413333524, 62.3056617090779, 61.89697819371378, 60.10847545439198, 61.80482210651521, 62.23649463345928, 63.34343064215876, 62.610676980787716, 63.33015734149564, 61.36997638210174, 60.224636447045114, 60.65018223178003, 62.21695730763098, 58.44983062436504, 56.22916113945746, 55.319790993967366, 53.4149468329645, 50.29375999204574, 50.21649714439146, 47.709212226252404, 44.187386651192945, 43.25218377574798, 43.38632099090084, 40.40790842425439, 44.84183411444388, 46.42428690387357, 53.48139570605371, 56.28954602826027, 56.56594760956303, 56.231114479803274, 56.9906775413021, 56.89666617301203, 54.326976345431426, 45.20810896350492, 41.46160218023485, 41.25252416056972, 42.89516179792343, 43.00699249390633, 41.48895286744641, 41.8420877764302, 43.23874181316745, 48.79607354440997, 47.97321519544048, 45.17309788734683, 46.96710371202039, 49.23609287508073, 45.04345178604127, 42.72425628477528, 41.13534727404195, 41.060312332645545, 39.698936093238096, 39.82736625979024, 41.10015576885593, 42.08282324575609, 47.12894462770032, 55.563644747580256, 57.479565681949744, 53.59932568765456, 54.78609761884136, 55.80078732582831, 55.75869244913901, 56.12693632802656, 55.73967679854363, 48.06488883110785, 44.43313098722889, 40.700576074661754, 40.90308020191808, 38.466566608798125, 40.34662531268212, 41.44692859342022, 44.20502162748768, 47.50777498368294, 49.07369106046615, 43.304641554432536, 47.214922981877486, 51.96165769330917, 53.334577468133745, 56.07116806891657, 58.24429058259534, 57.43161470659318, 57.873151994520626, 58.90551590150403, 54.613191696905325, 54.333699287906775, 59.564901628801906, 57.45561568967758, 57.648737507481734, 56.595232025269546, 56.970143933450025, 55.380481827643614, 53.52722467914705, 55.67438894702543, 55.07989491185835, 56.8893313407898, 56.8711393879306, 61.242354223805094, 59.159830616366484, 61.53047584718274, 65.57329416275024, 46.59861272381198, 13.769703084422698, 3.377822128034407, 0.6357106073729454, 1.0080232098698616, 2.6069574923284593, 35.66415863652384, 56.05026183589813, 55.09996175765992, 59.20531834325483, 58.86752774638515, 53.27788745203326, 59.73181416911464, 51.71962391945624, 59.888932551107104, 27.37581587606861, 25.7797210831796, 29.699402470742505, 25.84471671811996, 42.97665296062347, 3.8594646703812385, 0.029057854779004574, 0.03684412537803573, 0.07687258714389417, 0.04503554732148205, 0.04756306673610403, 0.013185843108071676, 0.04532152411317633, 0.03591202237012406, 0.045329686780009544, 0.03692544561119811, 0.011785555998944949, 0.08824292540309892, 0.04520486807450653, 0.02392786765290845, 0.083221111807131, 0.08532586943117842, 0.015113866163207399, 0.040155548091617324, 0.016717796679586172, 0.0983543437154543, 0.05222370818016991, 0.0037331888292570633, 0.015478739477393609, 0.09232925371296945, 0.045933930969406525, 0.17159796470115263, 3.1107121513735865, 53.70644561706051, 46.860838859312, 35.5996121129682, 43.891545803316184, 32.59769082069397, 77.75863524406188, 39.356744597035075, 63.3181627335087, 73.46041571709418, 67.81141035018429, 68.38870479214576, 63.86716511941726, 69.36529651764901, 61.68921416805637, 14.044861274380839, 2.6774272851405607, 1.0118811673695043, 0.363676983622774, 22.800930007811516, 58.7074322854319, 71.45159736756356, 64.98623301905971, 69.9256149415047, 67.62161470228627, 65.86626775803106, 65.2305260781319, 65.39541075306555, 65.35325704082366, 65.49913783227244, 62.82790568567092, 64.57016368066111, 63.29266732738864, 62.813279167298354, 60.522701278809585, 65.05052066618397, 69.14442000850555, 64.67063127025482, 64.95343808204898, 64.57218370129986, 61.20948083939091, 62.483368612104854, 63.70037417257986, 58.639873381583925, 58.638159305818625, 58.98073127192836, 54.13355642749418, 51.54524318633541, 51.97932012619511, 48.89670979592108, 45.182072270301084, 44.48563975672568, 43.29591035842896, 43.18392276763917, 47.2387513806743, 49.530298094595636, 58.34326767152356, 59.597100365546446, 60.366347759000725, 57.53922885464084, 60.55485686948223, 60.548090780934984, 57.785957705590036, 48.34391447805589, 44.88951444625855, 44.237804797387895, 45.48225125958843, 44.03558700315414, 45.18728902263027, 45.48380451817667, 46.6280383448447, 50.19252754026844, 51.3589031465592, 45.799653376302416, 51.094739360194055, 51.177905374957675, 50.20589105544552, 46.53996544499552, 43.99971692792831, 43.65678018139255, 42.00074372753021, 43.79918183049848, 42.457719464455884, 44.501627337548044, 49.6059331586284, 57.7937985235645, 59.68820133516866, 57.36516975587415, 55.71621318017283, 58.422938854463645, 59.38193874974405, 58.75121378129529, 56.902859595514116, 50.2956231178776, 47.41768598556519, 43.53067990272276, 41.836549389746885, 41.69264547286495, 41.828151595207956, 45.50260836078275, 44.88176776516823, 48.1540011590527, 49.907433986663825, 46.294672181529386, 50.362609355680405, 54.532963537400775, 55.40024272857174, 56.677138959207845, 59.819989050588305, 57.60935691095168, 59.161540769761615, 59.737764404666045, 57.11881353009132, 57.8381173841415, 60.63711681673604, 58.20468248859529, 59.38420587970365, 58.90505698419387, 59.47184731883388, 59.38666128343152, 57.80145891251103, 58.58647423405802, 59.84728874698762, 60.90093935689619, 59.474514530551055, 63.70435537830476, 62.58545221820955, 64.44482041943458, 64.9519318919028, 52.29019934131254, 17.562714469048288, 5.649440749999016, 1.3089804832012424, 1.3319248778204764, 3.6720756417320626, 40.96854063772386, 58.69440217171946, 57.801466757251376, 64.22941561668151, 63.60594311068135, 58.43024623009467, 65.0052486696551, 57.744831654333304, 67.895921737917, 30.911660002123927, 31.315358184999038, 38.86320452536307, 28.200629526569, 53.923670399573545, 4.830122830406313, 0.06699049725167214, 0.033930195044846304, 0.03747186931451002, 0.061261006105210514, 0.08022200781852007, 0.04890834011377827, 0.048542881699939894, 0.059157922383277654, 0.06531288727156578, 0.006513704711030568, 0.10589028167868815, 0.17892113706517607, 0.13375496792216457, 0.1911332220920632, 0.18589351776867144, 0.15592624192997334, 0.10088850894281942, 0.14099786959348187, 0.23297748077780972, 0.37640090731363146, 0.3392267972230912, 0.14305063283010838, 0.2305108768444869, 0.21471057387609638, 0.3311518934224883, 0.7172324135899545, 6.129464334057224, 67.9470302212623, 63.23570666774627, 51.78210727630123, 44.04431819915772, 43.535394591669885, 85.99692267756309, 44.7298151446927, 69.03400528815486, 81.61961247844081, 73.6589974741782, 76.27129600894067, 68.27492467818722, 76.01356490965813, 69.03634302077755, 18.614015579223633, 13.044533325779824, 0.7530466563278629, 1.1815394893769295, 28.320240243788692, 63.21367471448837, 75.19185189277896, 69.26607624177011, 70.63221423856675, 71.29712658543741, 67.96823455441383, 68.15342533972957, 68.6931356306999, 67.55917056914299, 67.53046666422199, 63.99700733923144, 66.67598616692328, 67.05536565473004, 65.71833948935232, 64.6891370127278, 66.68878093842538, 70.61799172432193, 66.86240857647311, 68.98810571239841, 66.61764483298025, 63.56316966395225, 63.97875655081965, 66.16487779924947, 63.16234657841345, 60.30795543424545, 62.749077812317886, 58.911877985923525, 55.020620053814305, 53.950985785453554, 50.531655665366884, 47.37228455082063, 45.52132591124504, 47.68269308151738, 42.57112695324806, 50.986128930122625, 51.343974605683364, 58.8253269657012, 62.67223465827204, 62.11990218008719, 58.750692106062374, 61.52725558127127, 62.23975804544265, 61.42826672523253, 49.69620650814426, 46.38355701200424, 47.52781829526348, 49.720760545422955, 49.185184432614236, 47.854865520231186, 47.82841697815926, 49.57535043839486, 54.006110775855284, 54.33297757179507, 48.46314668655396, 52.57986637853807, 55.06675497178109, 50.98354408817907, 48.29330805809268, 46.10783792311146, 46.911029508036954, 44.24007192734749, 45.11531352996827, 43.629386348109094, 46.6524354873165, 48.11628756984588, 58.19211521456319, 62.31500871719853, 59.40427664787539, 56.80273325212541, 59.1756691471223, 61.07721851718042, 61.32583010581232, 62.28914460828228, 52.812282500728486, 49.56112792415004, 45.370530389970355, 44.187119930021225, 43.48409783455634, 44.00691839956468, 48.183795482881614, 46.90520478833107, 50.75381086718652, 54.10858269660704, 47.963048411953835, 53.51142537209296, 57.876576223681056, 59.24673072753414, 58.57149470236994, 62.03902290713403, 60.453032139808904, 62.40709812410417, 61.382516199542636, 59.48874881190639, 58.18968726742653, 63.46008977582378, 61.055284623176824, 63.7692706046566, 59.76944931091801, 60.71345398502966, 61.61828594823038, 59.90510840569774, 60.25960437713131, 61.19790984738258, 61.60354568112282, 62.30743069802562, 66.00100901819044, 65.30208187718546, 65.2991283324457, 66.44011051424089, 54.270141201634566, 20.75856754856725, 7.195789592881357, 3.0080970641105407, 3.5909544075689013, 3.811847096489322, 43.630237502436486, 65.64743480374737, 63.07230072636759, 69.13151541063863, 66.25952459150746, 64.31524099842196, 69.75917308561264, 63.97655610115298, 71.99031922125047, 40.01214911860805, 41.9900474240703, 48.567473888397224, 39.71889311267484, 67.35187330553609, 9.869785539565548, 0.23782883981062522, 0.1259279088868249, 0.15966887255349468, 0.16043166629970074, 0.13323422731651416, 0.11905931011443177, 0.19097891666235464, 0.11515128876893752, 0.17827855783604807, 0.10003129485994579, 0.343960699655356], [0.02463855592894458, 0.03093557267059242, 0.07687355241467876, 0.039919857311272816, 0.07797050605257673, 0.02885602125447364, 0.05005882797582496, 0.024606512386291742, 0.11737921800945075, 0.14935930559952415, 0.03320030477498809, 0.027533299590070403, 0.04343541947403743, 0.018483772986538468, 0.015087429426550386, 0.20427265655129187, 18.915730176433442, 49.60452502773654, 25.008585068487353, 22.42897556674096, 28.961585029479, 57.311284234446866, 50.06030051938949, 39.51708716730918, 71.7033350852228, 61.28901866174514, 67.01383559934555, 63.869345957233065, 59.15718301650017, 61.33569878916587, 21.318878127682595, 0.5975332591802843, 4.531093585875727, 0.5652127450992984, 10.856155733908377, 51.8404996010565, 67.77185716936665, 60.28076164184078, 62.09343794853457, 65.67036497977473, 62.97096237059563, 63.08261655992078, 64.21240429724416, 63.3340169537452, 64.92941748711371, 63.33622524815222, 62.41384460080055, 62.093841952662316, 60.9228418719384, 62.027020454406745, 61.184660080940496, 61.37564420700074, 60.25243820682649, 62.59767040129631, 63.82036732089136, 61.327677542163485, 60.492675535140506, 60.992491399088216, 59.08811400013586, 58.38824156791934, 54.774840416446814, 56.14217473614601, 49.99118051221294, 52.117254195674775, 48.51191351490636, 46.46307130013743, 42.31961281068864, 40.75361044176164, 42.87947623960434, 43.155097269242816, 44.12205957597302, 47.623029908826275, 52.98185048564788, 56.061013052540446, 53.64127543664748, 56.76054816092215, 52.79729512430007, 48.20630204293036, 44.030017237509455, 40.84855533415272, 41.377314367601954, 41.93893501835485, 41.665832150367, 39.74578880494641, 40.53296143008817, 41.258223364430094, 47.478372896871264, 41.986717331794004, 34.607487801582586, 46.884926134540194, 46.56743380331224, 44.68195046147993, 42.11344126732119, 40.033294616207, 40.014855554026944, 40.61460556522493, 41.401382030979285, 38.601633425681825, 40.62770628160046, 42.053374090502345, 47.48991643228839, 53.23862844897855, 55.04927296792307, 54.35351117964714, 54.84988320258356, 56.07319985666583, 55.1504034380759, 52.50421954739479, 49.03092153610722, 41.736336754214385, 40.595856635801255, 38.102888368791156, 39.75951317817935, 40.86426050432267, 41.26930013779671, 45.0232986480959, 45.105766480968846, 46.977690189115464, 45.50419692070254, 47.78787143768803, 51.595708400972434, 53.96910321327948, 55.18496736403435, 53.75531050466723, 53.31575793604697, 54.742676981033824, 53.924721594779726, 57.2409482925169, 57.21915952620968, 56.66947464789114, 56.43819209068053, 57.39513274162047, 57.57768377181023, 57.64744704769504, 57.57333386328913, 58.06414788769138, 56.63163162046864, 59.81924380025556, 58.60251672806279, 59.97086301926644, 58.967359912010934, 61.963109354819025, 62.48975030837521, 52.38650137378324, 47.133631860056234, 16.118675258851823, 1.7346041024692598, 0.9736345035414543, 1.0940586222756294, 4.657763098516773, 39.431089201281154, 62.31809170015397, 53.138466804258286, 57.07272175819644, 47.03729452625398, 58.56228105483517, 52.38838803383612, 52.33394945821455, 56.289926498166984, 26.94292349200095, 31.818692414991318, 24.154588983904933, 33.8903961643096, 35.41928114429597, 0.18186285340737912, 0.039502266614187154, 0.05641692107723606, 0.06935734887637439, 0.09061986640576394, 0.01699502857762479, 0.016127330581507376, 0.0328307286385567, 0.025227530070790843, 0.03652707606013264, 0.019795566406701843, 0.04750173756732576, 0.06921353885122845, 0.07457986984762453, 0.04227059044604821, 0.0816108945817236, 0.007394588516739708, 0.08110598901346808, 0.09454238213478558, 0.03627723946626629, 0.10942060635575365, 0.026882630472462025, 0.007156665068900874, 0.03020815303429, 0.025576136465514862, 0.025531977242339524, 0.030135229124777743, 0.1614819575221308, 26.779884292233376, 59.541543914425766, 25.286269264836466, 37.0574394349129, 35.151194987758515, 63.99755647105556, 56.02875940261349, 44.796432679699315, 81.22261370382002, 65.43125337170017, 73.89475545575543, 68.61373116893154, 67.16785923127206, 64.49608579758676, 22.840665578842167, 3.072184915504148, 4.18332104721377, 0.35872477677560627, 12.54844077171818, 56.25444081521804, 70.37453020772627, 65.31947758889967, 64.96859804276498, 67.96303349156534, 65.64359872571885, 66.11707979632963, 66.48295064126292, 66.22162665090254, 65.89894110156645, 63.90324308026222, 64.43760718068769, 62.33745251932452, 61.98376455614644, 65.23883365815686, 63.217746134727236, 63.22135471528577, 60.68187498277234, 63.860379419019154, 64.19331019924533, 63.37142852044875, 61.46958105025753, 62.282158867005386, 60.76697080366073, 59.938742729925345, 58.88500582787299, 58.4896779829456, 52.18463267049482, 53.677710333178126, 48.50664969413511, 49.192887967632664, 43.96400766987955, 42.36129583850984, 46.97501905502812, 46.80026569674092, 46.285438922143754, 50.76624085826259, 54.91453170776368, 59.38055415307323, 58.47019949266988, 59.26307916641236, 56.5621978236783, 51.99522533724385, 46.4887628247661, 43.89931209625737, 43.749081396287494, 44.554595024355, 43.175175882154896, 43.513033159317516, 43.49227205399544, 44.207300524557795, 50.120218646141794, 46.54747286150533, 38.596232321954545, 49.05839773916429, 50.319639790442686, 48.017902758813676, 45.46820917437154, 42.55907350970853, 44.44447448176723, 43.473174033626435, 43.649068801633774, 41.30142434950798, 43.48513334028183, 44.32898813678373, 49.342624448960834, 56.810632905652454, 57.654652441701586, 58.14447802882041, 57.2925353050232, 59.51121222588324, 57.72038744341943, 53.88138724911598, 53.798354594938225, 44.67269759024344, 43.08267854875134, 39.50006015839116, 41.89408663780459, 42.63248851222377, 42.12427485373713, 45.95579901049214, 46.60540626895043, 48.8067384689085, 46.77318565307125, 50.29643897087344, 54.394229304405954, 56.532297595854736, 55.46284767889208, 54.5813734300675, 54.73948024934339, 56.371915801878906, 57.49858133254513, 58.58802357027608, 59.93475760183027, 59.67736382638255, 59.97068259023852, 58.477047950990745, 59.037723310532115, 60.6649068094069, 59.58323870935748, 60.12541224879604, 61.02744363969373, 60.50183819186304, 61.72095790986092, 62.11718789992794, 60.58094063112813, 64.09472142496418, 62.208653649976185, 52.824390857450425, 49.27097843539331, 17.558086072244954, 2.4267971467587257, 1.5870967531396498, 0.24548558217863886, 4.115473358861862, 42.378813143699404, 66.89182635276549, 56.68459538490542, 62.88237564025387, 51.10285474408058, 65.80833435058594, 57.765612371506236, 57.081456876570186, 63.24009972233927, 30.409777049095403, 41.24782123873311, 28.454769695958785, 41.03065921414284, 45.717644460739635, 0.24282967791922633, 0.07195836293601221, 0.05282970671091349, 0.07581646599236035, 0.035204927046452804, 0.0018601866876481162, 0.03335799631332198, 0.016114646080701102, 0.0648278387023076, 0.004359886816312229, 0.04539152156681784, 0.005533746584513856, 0.16491600792975197, 0.2806269545708933, 0.1792132310689457, 0.1670222900687687, 0.1951856586721636, 0.24258240005902706, 0.18835549453093162, 0.24051281353158338, 0.26180662575267977, 0.17050374599714435, 0.21311833673427183, 0.09431820182550339, 0.18853883469297042, 0.15545361164596774, 0.10036478059426432, 0.40014255431390583, 42.68902163351736, 72.39929691437753, 42.47642524780766, 38.32150559271536, 42.551742599856475, 70.70615876105525, 63.71569495047293, 50.21193150551089, 84.81036647673577, 72.04571093282392, 80.21464301693825, 74.57493366733675, 71.22101691461378, 70.72653155173026, 26.39805332306893, 7.026226020628407, 13.074793431066698, 0.918620013661923, 16.687549352645874, 61.27853024390436, 71.36084941125685, 65.96427994389688, 69.13535933340751, 72.7615591787523, 68.18696160470286, 67.13305211836293, 70.59649713577764, 67.8017613195604, 71.5168656072309, 66.82140411869173, 67.82133394672026, 64.88812277393957, 65.8559754586989, 68.58443890848469, 67.07202788322203, 65.81297843686997, 62.64834350155246, 67.73639109826857, 69.63663039668914, 64.92196498378631, 63.8809444058326, 63.65534928537185, 62.45458233741022, 61.59835638538484, 63.08424042117212, 63.677494987364746, 55.84890696310229, 57.42981826105426, 51.7201259828383, 49.56312833293792, 46.3530998076162, 45.17679668241932, 49.879341971489694, 50.090867550142356, 48.9149841185539, 52.16818224999213, 57.69256607178719, 60.94614467313213, 58.682552691428896, 62.52363566429385, 58.241945005232296, 53.63406612027077, 50.46294750705842, 45.70941532811811, 45.63360767979776, 47.45229305759553, 45.40941284548852, 45.29586022899997, 47.949763344180205, 47.87489706470121, 52.64611128837832, 47.798975667645855, 39.494557073039395, 52.157168234548266, 52.936437283792806, 50.88794023759904, 47.292405482261415, 46.508088342605106, 48.10594035733131, 46.824058794206195, 46.81743391098515, 43.67157536168253, 43.422751965061316, 46.115180600074034, 49.327562547499134, 57.84599742581768, 58.15851619166713, 59.5829523763349, 59.761388840213904, 60.61696367879068, 59.535468163028845, 54.77783710725846, 56.47186956098003, 46.270800636660674, 44.31905669550742, 43.246057033538825, 44.693168440172755, 45.195780954053326, 43.35697773964175, 48.12832532390472, 48.39967881479571, 51.15914860079366, 50.48826248415055, 54.19670266489829, 57.127529036614206, 56.632725961746715, 58.508764236204094, 58.678202782907796, 57.2124561955852, 58.15413098181448, 59.76203603129233, 59.750688614383826, 62.66505279848653, 63.15904786509853, 64.1884974510439, 62.10925686743952, 62.690536437496064, 62.240193428531775, 62.39808451744818, 62.83994343972976, 64.67429868636593, 63.33366001805952, 64.32027339935303, 65.34100747877552, 62.73412965959119, 64.9779019048137, 65.26329355855142, 56.97184231973464, 51.36479454655802, 20.012450372019124, 4.031289243890393, 2.626190099024004, 2.5673641072165583, 7.515812833462992, 46.78385057756978, 75.6176487092049, 62.31170608151344, 69.24265184710103, 58.52576378853091, 72.15840062787457, 62.21154051442301, 64.02095340913343, 67.75430064047536, 42.167636655992084, 50.79509381325015, 35.67712206994334, 50.32765319270473, 60.54067750130931, 0.9836702553495285, 0.14473513760153325, 0.13784829827566303, 0.1686160593864418, 0.12555070251466768, 0.08519824684387253, 0.18498467702058055, 0.10225935433540614, 0.16855241280169259, 0.18837100015051905, 0.14682772208846387, 0.10771311128572111], [0.0290874257728818, 0.04697275385561009, 0.025617260065290238, 0.05005131648372739, 0.04520885173171278, 0.018637821776792407, 0.010326237984812789, 0.035709158457334966, 0.031190101552994984, 0.016457725151051438, 0.060270435266917756, 0.0445669160164412, 0.061101625343003584, 0.11491660539421344, 0.05900229928233932, 0.22521768426222188, 5.706231767131436, 41.937381759766616, 30.03032107507029, 28.964016898985836, 25.48702205381086, 41.8039741054658, 59.96124536760392, 59.916518580529, 65.47281480604603, 68.0660427770307, 62.56574623046383, 63.490303793261134, 57.26010514843849, 55.28508586268271, 22.914325729493175, 1.9693267008950635, 3.025623930077399, 0.6340485642994604, 9.839178304518423, 52.58665600130635, 68.66440034681752, 63.29873523404522, 62.169810418159734, 59.5019946559783, 63.60469579696656, 62.50343545790642, 61.739098871907885, 63.088743302129934, 63.62701800561721, 63.38665516145768, 61.49000090937461, 58.99996265288323, 61.023462433968824, 57.3129512417701, 54.483777015439934, 56.00361700980894, 56.460612358585486, 57.933077966013265, 58.27122157619846, 59.933965283055464, 64.1021700059214, 60.71879625320435, 60.368348167788604, 58.743059173707046, 59.34057735627698, 55.56075396076326, 50.620042354829856, 52.37110999322707, 49.67288409509967, 45.55461898926766, 44.88950267914803, 41.84699073914559, 42.888513380481356, 43.35696205016106, 43.57375144958497, 49.02058216833299, 52.35152167658652, 55.66853284835816, 59.61181709843298, 57.03013266286543, 52.37237691879273, 43.6106687976468, 41.576672753980084, 40.78860190606887, 42.13518296518634, 42.00661943804833, 41.6903155849826, 39.636166403370524, 41.245189328347486, 43.2563885565727, 48.39718810973629, 36.78124573922927, 26.498003159799886, 47.04775548750355, 47.26924388639389, 46.634353360822125, 41.82999510918894, 39.37072784669938, 37.34977368385562, 40.95060363892586, 40.434102012265114, 39.814873510791415, 41.305005473475305, 40.924319836401175, 43.63434030163673, 49.75399871026316, 52.77738909567557, 51.92842345083914, 54.82649803161622, 54.05626612324869, 52.777710730029696, 51.79292125086631, 46.57155621436335, 42.028419971466064, 40.463923792685236, 39.45203465800132, 40.0524789287198, 40.53865671157837, 39.72810676020961, 43.349854715408824, 44.58861766322967, 45.981239503429784, 47.80122710812477, 46.89459869938512, 49.8340307512591, 54.197079212434836, 56.470230010248, 53.24592405749906, 54.60171484178113, 55.75220092650383, 57.65577816194104, 56.82747556317238, 53.31961362592636, 54.454806389347205, 54.82518011523832, 52.359111462869954, 56.80374914600004, 56.53784382727839, 53.143973811980224, 54.253898666751006, 54.023063259740034, 53.881273500380985, 56.104641575967115, 59.40465711778211, 60.132962811377745, 58.14267373854115, 56.39983523276545, 63.14829664845621, 45.350565525793264, 15.647920235510796, 3.207894755947975, 0.7804851678590622, 0.6112371625438814, 2.0978076131113115, 37.403584680249615, 54.475469435414965, 59.72061972464285, 55.72066114794824, 58.03165497318391, 60.01116929515716, 61.03922251732119, 60.5828429806617, 47.11181955952799, 28.641013637665782, 34.635960286663426, 28.320785453242642, 45.67657724503548, 15.775380596037834, 0.061897674966002666, 0.07141640169485923, 0.06083359033049596, 0.018531862240765366, 0.022326408727695386, 0.024062080511582956, 0.008679962916029318, 0.05458643442139991, 0.03165153737720703, 0.05218033994277639, 0.042708919143244144, 0.025185500572045005, 0.060003108885740085, 0.04449478883837019, 0.026169069366709843, 0.08701334662374952, 0.045975621474245866, 0.061757990324328986, 0.060247839503591104, 0.08041631069875534, 0.03145104450654359, 0.08699137522208114, 0.04629381226315614, 0.1141854970445556, 0.04979469235085192, 0.08449444186783607, 0.0644340618483482, 0.12688130530859196, 8.415905102606743, 57.7350845644551, 31.595866487872218, 30.866331131227557, 37.60186441483037, 45.411927084768976, 69.57674364889823, 65.02792389162126, 70.92285402359502, 72.12274628300821, 69.45631903986778, 68.33929861745527, 64.26931004370412, 62.07212378901821, 26.963296282675962, 0.9107097574780065, 2.9188945216517297, 0.08720839260927132, 11.942148247072774, 55.48155346224385, 69.59902271147698, 66.69147952910393, 65.82920135990267, 62.972841185908166, 68.47653450504427, 66.12430480218703, 65.90215744510775, 65.8272558642972, 64.71911176558464, 64.76519569273918, 63.77251832715927, 62.85197334904825, 61.69399945966659, 58.768452598202614, 57.56953700896233, 59.33089302432153, 62.21872237420852, 61.415358204995435, 60.30383302319435, 64.05325412750244, 66.04728514148344, 62.00321166746078, 65.13044680318525, 61.64315377512286, 60.94064158778037, 59.76676248734998, 53.40854160247311, 55.086974790019376, 50.22382020950318, 45.8279218981343, 45.79376982104394, 43.961218864687034, 45.41621815773749, 45.30131624590966, 45.98566393698416, 51.98237173018917, 54.172497718564934, 58.468599165639574, 60.061148135892815, 60.54059120916552, 54.573293347512525, 48.258045950243556, 45.98707206787602, 42.5583125698951, 43.99816366934007, 44.9721509410489, 44.052429660674065, 41.10376434941446, 43.20746875578358, 46.55296417974657, 51.92416767920218, 40.74590690674321, 29.53734386351801, 52.51702216363723, 49.799168725167554, 48.084029997548754, 46.595592498779304, 43.979650082126746, 42.28411928299935, 42.51572739693427, 42.75337203856438, 42.740949892228656, 42.084933480908795, 42.255368309636275, 45.420309189827215, 51.14263542236821, 57.05927979561591, 53.52185887675132, 58.776242425364835, 57.82830361397036, 57.02058953623618, 53.7755891584581, 49.016848071928955, 44.44975006964899, 42.58211743447089, 41.054056152220696, 41.90264132715041, 42.826583077830655, 40.48989380559614, 45.076223188830966, 48.16670179367066, 49.473910100998424, 48.83976090338923, 49.31061006361439, 50.875200379279356, 56.28050496501308, 57.783961219172326, 56.35272756699593, 57.59768001494869, 58.09594654267835, 59.6957048293083, 59.856463170820675, 55.2283723123612, 56.85973705783967, 57.271209378396314, 56.64336735202421, 58.94347267766153, 58.26556159603981, 54.94861318219093, 57.21967335670226, 55.47381854826405, 55.742642110393895, 57.913517105963926, 62.351796627044685, 61.288332246964984, 59.62110134863085, 57.60783110895465, 63.86175617094963, 48.609247130732385, 16.723362553504206, 4.290378708993235, 1.0789723285744268, 0.7149132509385386, 1.3018642005420502, 38.45628215420631, 60.45988844287012, 62.70856757317821, 62.484384505979484, 62.757565821370775, 66.28674584050333, 67.43208577555995, 66.8701042667512, 53.459155867176676, 35.864372099599535, 44.57634848933066, 30.896407865708877, 54.64849302845617, 18.876147577839514, 0.04501909941374775, 0.07150292366502747, 0.06327388680449898, 0.02240778833267189, 0.016542655573556983, 0.03038203201046394, 0.04100846825167537, 0.049336250015203996, 0.07082405485092633, 0.0376203601368733, 0.01887745024906772, 0.05377474894386627, 0.1533213744480764, 0.10858184733097592, 0.22200762264190183, 0.19991367754916992, 0.16195094122761683, 0.11481848485287159, 0.15106446410138763, 0.1688606406171476, 0.13557266474010485, 0.23304445218415032, 0.24385355443002718, 0.14669456068546544, 0.09935408079576108, 0.32247337362458633, 0.3250302686806648, 0.4796011938202766, 14.838185156545332, 71.84722331262404, 51.535915790065644, 45.678514895900605, 42.218321523358746, 56.138264133084206, 75.2581948618735, 72.09541520764752, 79.30873240194013, 80.09785052268737, 75.70003417230423, 74.18234363678964, 69.10299193474555, 66.1963430527718, 29.925664394132554, 5.494727761514726, 11.90427678246652, 1.3069881643018415, 14.469734372631198, 61.064431590418664, 74.15739736249371, 70.54647907134026, 68.43318446989983, 64.90115681002217, 70.72056954906833, 68.97549136992424, 68.12120699113416, 68.76639766077842, 67.82730379412251, 67.39954579261043, 67.28905262485628, 64.33808488230552, 63.618255430652255, 60.336059216530096, 59.42947787623252, 61.49496270764259, 63.7349106419471, 62.90545486634778, 62.56751914178172, 64.83004031642791, 68.98457557924333, 64.80969498234411, 67.33580727731028, 64.19479285517048, 64.66294734708725, 62.37422866206016, 55.55614909818096, 57.36279672191989, 52.84520295358474, 48.180708577556, 50.27443055183657, 45.499039003925944, 49.06383414422312, 49.42098163789319, 49.13389552024103, 54.80663907143378, 57.32451438903809, 59.18098788107596, 62.490146467762614, 61.710767592153246, 57.97443151474, 49.45284697317308, 47.54580628487372, 44.40110091240176, 46.08539412098546, 48.314618295238866, 45.88898535697691, 44.13240286611742, 46.44515391319029, 50.92755617633943, 53.254470902104536, 40.12981630140736, 28.938984332546113, 53.36965914695494, 50.617939964417495, 51.5918448663527, 47.446762515652566, 44.56516581196939, 44.101561269452496, 44.72139773830291, 45.881968236738636, 44.84016710712064, 45.491104049067346, 43.28395105177357, 46.56241709186185, 51.69707029096542, 57.68812202638196, 56.503260289469075, 60.20719366688883, 60.34840683783255, 57.64061035648469, 56.34399244862219, 51.66655032865463, 45.58621368100567, 44.87523701883132, 44.1099629863616, 43.860492398661954, 44.77968415906353, 42.46591329574585, 46.33973237006895, 48.58887434005738, 50.8376476072496, 55.15285884180377, 51.75787879574684, 53.07255137351252, 59.285146421001805, 59.80830430984498, 59.733108551271506, 58.300407932650664, 58.18688277275332, 62.48200754965506, 62.09115905146446, 56.93584672866329, 59.219391807433105, 59.82358194166615, 57.141363236211966, 60.96288927139775, 58.78065116943852, 57.6535737899042, 59.32310319715931, 56.31279783864176, 57.51654578793434, 58.81443454373268, 64.85528469085693, 63.87496671368999, 59.96265742086596, 58.33721545434768, 63.79560147562335, 51.27861615150206, 19.392880624340428, 5.570537861316435, 2.17471769259822, 1.8237593313378675, 4.191235899925232, 44.8142873087237, 65.29431558424427, 69.19854871688351, 67.89213272833055, 68.29362653916883, 72.00727954987558, 71.71538460639216, 73.02015319947274, 60.26885724836781, 44.78792113642539, 46.91611289978028, 39.20605105738486, 67.59400121627316, 29.303095994457124, 0.090726796958235, 0.17921343025180603, 0.2581832750189689, 0.15683771802052376, 0.0677031582041133, 0.1016370228101169, 0.1548748781844493, 0.11400492245992346, 0.10914940356967912, 0.11716604638364046, 0.14948379488721972, 0.10674144366695996], [0.057042971959397684, 0.06480917680047213, 0.042150172915670185, 0.027699172947435614, 0.020518575291780215, 0.056586728296092445, 0.07126389657177272, 0.049453338893551024, 0.029829602177825668, 0.038680943750566056, 0.00417872904724772, 0.027887519494059588, 0.13205295038079062, 0.009015680839037223, 0.05130143791076638, 0.20145044992527655, 0.630808012379754, 33.1437926138601, 44.90477638859903, 30.06313562393189, 27.876641750335697, 32.09449387365772, 50.467972063249164, 55.30529391381049, 69.38173909341135, 66.46958320371567, 63.69437686858639, 67.50448488420056, 59.47431056730209, 61.47464483014999, 21.716484869680098, 0.8084700532978581, 0.3160144250479437, 0.04197409909759318, 14.114984427728961, 56.26511358445691, 64.78390539846113, 59.89205868013444, 60.70851179861254, 67.175688282136, 66.89839240043395, 63.107315724895855, 60.43866842023788, 64.65727559981808, 63.46811886756652, 64.82055210298108, 59.94600695948447, 60.47683700438469, 59.69615982424829, 56.247780630665446, 55.74093587936894, 53.78788578894831, 53.28097435735887, 55.08575493289579, 57.53851106089931, 58.87752979032455, 61.784421859248994, 62.19545487434634, 61.27711034590199, 59.96733680848153, 60.6596076873041, 58.117633327361084, 54.012845485441154, 49.05481661519697, 47.25596274099043, 46.414080896685206, 45.5078015788909, 42.03983406866751, 42.73304239396126, 40.216473225624334, 46.60605346002887, 49.30406362779679, 55.73348337604154, 60.35060336512905, 61.51607290390999, 55.15034460252332, 47.17020011717274, 43.50145432256883, 42.15657164973598, 41.18353359160885, 43.38465006120744, 40.86023615252587, 40.47825221092471, 39.12821554368542, 42.45954728895619, 43.283303860695135, 50.00298684643161, 37.13406293622909, 18.10089699683651, 45.03010788271504, 48.88830023427164, 47.43394028755927, 41.40828932485273, 39.8547169470018, 40.10542308130572, 39.673228879128736, 40.75481853177471, 41.119877446082334, 39.06700303477626, 39.23784186763149, 41.75501115860478, 41.10464296033306, 47.949335805831424, 55.47271243987545, 51.18844870598086, 51.8785426693578, 47.740461749415246, 44.0976506663907, 44.09905487491239, 41.00230832253733, 39.60034339658676, 39.38148298571187, 39.740889764601185, 40.05934307652135, 40.07591116812922, 42.771136453074796, 43.338770097301854, 46.00988849516838, 45.545142542931345, 48.02907366906443, 47.19343623807354, 51.44240648515763, 53.87911619678621, 53.562902558234434, 54.778692183956025, 55.6297759086855, 55.57697296142579, 53.07070785953153, 53.21561590317757, 50.53733133500623, 54.41882648775655, 53.453774375300256, 55.73505232411047, 58.32620928364416, 56.384455619319795, 47.591203797248106, 52.53645358547088, 57.408237380366174, 59.69219823037425, 58.22733417634041, 60.263840536917414, 60.8031193671688, 62.4282043980014, 63.59286200615668, 44.79123946159117, 11.45116359956803, 2.748186843049142, 0.39157916220926475, 0.3227724543502254, 1.7732155467233353, 27.990637594653716, 51.30439004590435, 53.81196521943616, 58.783922426162235, 57.35978826399773, 61.35284346918906, 53.94913050436205, 61.61659540668611, 42.948937492985884, 29.527643842081872, 27.201199800737445, 28.444447978850338, 40.42654752731323, 2.2512063624397403, 0.06345013682279857, 0.11879772939268621, 0.03765189614627631, 0.03518724573716041, 0.07608481893135656, 0.0642813805250391, 0.018529240304844517, 0.023634503858404297, 0.04316960228607059, 0.028535857789158344, 0.03536580168011208, 0.02798309853871263, 0.028481890725332405, 0.06228468343315106, 0.07827221445979611, 0.01698320592573333, 0.021172379624218713, 0.043758072725106636, 0.047599134155579155, 0.06907016549619936, 0.01663899304525506, 0.03887435796880915, 0.030161076931342966, 0.06391408350018245, 0.05944206056395366, 0.07875599898397923, 0.06595886027019832, 0.1427157757984054, 0.9550595067201123, 47.22112032674974, 51.182435712506695, 31.44182912765011, 44.0047493288594, 36.10012223643642, 58.14527034759522, 62.685574639228086, 76.65298969514909, 71.63462300454417, 71.85455030010593, 74.82729111948322, 64.44224734460154, 65.96448390714585, 24.58457293048982, 0.800249562148125, 0.28590759863295867, 0.6250708718453685, 16.45491357772581, 60.18620898646694, 68.30394237272202, 63.45097418754332, 63.41246827956169, 70.80596739246, 67.13718629652455, 65.19187896482407, 65.31517867119082, 67.5044221262778, 65.436121033084, 66.06578303921607, 61.91860614284393, 62.50113302661527, 60.32670436366912, 59.39323125347015, 57.78960158748012, 56.45662723049041, 55.33164047425794, 59.39617303109939, 59.29292448105351, 60.65677573603969, 63.50946064918273, 60.33895784808744, 61.63449318178239, 60.16387893307594, 62.25176834291028, 60.74939858528876, 56.917658698174264, 51.341083818866366, 50.05636638210666, 47.31520229770292, 47.728824077113984, 44.50755796124859, 46.558278991330056, 44.512943375495176, 48.8439578394736, 51.62473786261774, 56.243356197111076, 61.85913908866144, 62.640082989969564, 58.331500561006614, 50.97773505795387, 45.112081496946274, 45.21979762661842, 41.84700642862628, 43.54210968940489, 42.27396034425305, 42.129503373176824, 41.87873448095014, 44.807623201800936, 45.962019889585434, 53.032731471523164, 39.65717461801345, 21.170865528045162, 47.911433942856334, 49.3314221597487, 49.54394402042512, 45.261994484932195, 42.69476006107946, 43.36201798531317, 44.219726593263694, 42.49308747629966, 43.06598494129796, 43.47533525959138, 42.1412665613236, 43.805845937421246, 44.4163824665931, 50.524199239669315, 56.46591932542863, 54.30877262546171, 53.254094354568, 51.00192039243637, 46.57094824698664, 46.80852228595365, 44.89935959539106, 41.34804564137613, 40.88285646130962, 41.00878415569183, 41.25825474339147, 42.71475238184775, 44.70815973897135, 46.11689467583933, 47.08319802438059, 49.00931319882793, 50.81001058701546, 49.525414743731105, 53.61436405489522, 55.67320439123339, 55.86132910943801, 58.348096109205684, 56.97982826540547, 57.280603454959014, 56.225870270882886, 55.5146582664982, 52.373086867793916, 56.005393843497004, 55.83782234499532, 57.176217417563166, 60.326559235972745, 56.3903352522081, 50.21516746090305, 55.38019941699121, 57.74819312557098, 61.05355878030101, 61.68129490267847, 62.16498982521796, 63.28493633577901, 63.41250750326342, 64.3478202050732, 46.66995671487624, 13.061072980203937, 3.436311286303305, 0.8226709332196944, 0.5044606856761441, 1.8114387989044192, 30.05059776767608, 57.44650010139712, 59.074326868980165, 62.74993288901545, 62.79836239353303, 68.78577416942966, 59.57554694144957, 68.45584792475547, 47.20122606523576, 38.55635750678278, 30.748434489773167, 31.80359325101299, 49.75270825047647, 2.338023368389376, 0.10384558534790432, 0.19668809498750395, 0.07771084055064187, 0.077750094895882, 0.04587070956345528, 0.015366195415657376, 0.059877386196486415, 0.05653091879080861, 0.05558184693537413, 0.08341216647456731, 0.030587686398517222, 0.026807984780339945, 0.12607837621603282, 0.26648031367409614, 0.18192018742763227, 0.11029740930685114, 0.15422226320351326, 0.24688206853405123, 0.24195619978972022, 0.2028698729531419, 0.10524201807716202, 0.24091830386990504, 0.2237121376299089, 0.24510230839012132, 0.3980045254913069, 0.23023130071739997, 0.23668597452342513, 0.37715528941442894, 2.243133634328842, 62.01922670487435, 67.16820439984723, 47.30405492167319, 42.154516327765684, 45.977881954562285, 64.4361323695029, 66.23399780642602, 79.80107615070959, 78.71895697809036, 74.539475440979, 80.37298910079464, 68.56239518811627, 71.68100895420199, 27.9577269477229, 1.8179023746521243, 4.4205151065703365, 1.272716822643434, 19.115961290174916, 64.86145850150817, 69.00314407963907, 66.15193397768083, 65.48495061935918, 75.19124784777242, 71.00054048722791, 67.68719673156738, 66.97186623850178, 70.88825871867519, 67.60267749909433, 70.21809824051397, 64.06808460912397, 65.5120934209516, 63.39882235373221, 61.62585612266295, 61.05889712610553, 58.49285902515535, 58.42264859907089, 63.14724545325003, 63.022482702809, 62.392267642482636, 65.83853660091278, 64.24958052173739, 65.11632627056491, 63.950641001424486, 64.31493505354851, 63.31120837119318, 59.247079818479484, 55.2041438318068, 51.6816436090777, 49.35331290768039, 49.52486561190698, 47.10309228589458, 48.60515217627249, 47.17282810518819, 50.978233198965754, 55.32828292539043, 58.14668632322743, 65.4757801178963, 64.06373077823271, 60.22683297434161, 54.19639672002485, 46.63905236028856, 48.528340401188025, 44.4082357037452, 48.36571501147363, 45.81939858774985, 44.75263941672541, 44.506797021435155, 50.140203122169744, 47.77338612464167, 57.22085006775395, 40.56508956416961, 18.256730802597538, 50.39575730600665, 55.65982126420545, 53.603495167147734, 47.61451444318218, 43.94268174325266, 47.09736954781317, 45.15788693581858, 43.92443095484088, 45.85096190052648, 45.077454813065074, 43.28022480010987, 45.55470528141145, 44.04523603377804, 52.30119766727571, 58.19556690031483, 55.29922992952409, 56.14109216197845, 53.499058138939645, 48.97008949710477, 47.667242865408625, 45.91421404192525, 44.26086441163094, 45.00841717566214, 43.30529266788114, 43.828238748735004, 43.32377095376292, 47.329471880389804, 47.621727681929066, 50.25091986502371, 51.54614140910488, 53.664680219465694, 51.520438117365686, 56.169839212971354, 57.85191628240771, 58.73404556705106, 61.11004091078236, 60.23553671375398, 60.31563543504285, 58.097472344675374, 57.94606101128363, 56.18232803960001, 60.42683855179818, 58.77872528568391, 60.98267370654691, 63.63547071333855, 59.871670199978745, 53.72112704861549, 57.915246871209916, 59.599708741711034, 65.23535451581402, 63.21546331528695, 62.79335352682299, 64.45003717176377, 64.58455485682335, 65.76623162915631, 51.186424762971946, 14.22810068053584, 5.232357969207149, 1.7240023036156933, 1.0751429921196354, 4.035981134060891, 37.3857496630761, 62.92305454131096, 64.38844027057772, 68.99733897178405, 68.15351163187336, 72.68020922137846, 67.12700382355722, 72.70025253295898, 56.76454897849791, 39.8692532508604, 37.3055568049031, 41.611236679938536, 62.95761846726941, 6.03975139317974, 0.6134448440805559, 0.4273836909522934, 0.18389510080939342, 0.22829731175255394, 0.18764497862467844, 0.09301995858550073, 0.16898981836293975, 0.28728959060484366, 0.19917944356078104, 0.1206921728988809, 0.15711255972423863, 0.12951882345782173], [0.06578379385774175, 0.07879528397273633, 0.005948048849184547, 0.09372218542041318, 0.03862183240632858, 0.027741154565686182, 0.042241662966027375, 0.07251150906085968, 0.00845843997423447, 0.04067900830939893, 0.005888331337876979, 0.06437721812436659, 0.005827816616323206, 0.014725343714798651, 0.07938895614877825, 0.09498593938206473, 0.10858930902735842, 14.502630310673869, 50.70258471273607, 32.2760074369369, 22.69706956801876, 31.835197748676425, 55.28095168452109, 53.216514125947036, 43.57378675091652, 69.56377629310855, 58.32354207192698, 65.52098543413224, 57.77097425153179, 61.38040596438993, 21.476502495427287, 0.17725629010988822, 0.2986116959683357, 0.2157991082077065, 19.718158860360425, 57.86232233047486, 66.55600086335214, 59.81628633314564, 63.81629982302266, 66.17000825943487, 66.5276107480449, 65.4411259774239, 66.20217169484785, 59.06342267990113, 61.63292031134329, 62.0916768043272, 60.770371498600134, 60.132943199526885, 57.768342341146166, 57.48207207648986, 52.807077515509825, 51.78265640812536, 51.21170443873252, 53.064337930371686, 53.6659824463629, 57.664438755281516, 61.598560348633804, 64.88927202840006, 60.26475837153774, 58.5378368439213, 60.54327411036338, 62.413056204395915, 55.72923152677475, 48.487532061915246, 47.063084110136955, 45.228568046323716, 43.643036196308756, 41.91626764112904, 40.78416962777415, 41.099281080307506, 45.16611214606993, 52.663883547629084, 54.542467440328295, 60.64651481566891, 57.42018884228122, 49.059299884303925, 42.44202213902628, 42.45555823849094, 40.73888194176459, 41.35912241474275, 41.2667231405935, 39.8618438936049, 41.104721407736506, 40.01312971115112, 42.753576001813336, 46.54828871450117, 50.8959654069716, 40.6417836681489, 13.53037182361849, 46.36463549829299, 49.30690342380155, 47.394418485703014, 42.90242602748256, 37.31403696921564, 39.44187964162519, 40.502508148070305, 40.052933923659786, 39.90342101743145, 40.37167749097271, 41.30902198053176, 39.540574319901005, 37.64799541042697, 42.33196435436126, 51.19875669479371, 59.103254349001, 57.627541019070534, 52.26759079963931, 48.09993520859749, 44.33131017992574, 41.63212330110612, 39.59924121056834, 41.21994887628863, 38.448672756072014, 39.197217879756806, 41.11785742544359, 42.39224333916941, 43.96304276681716, 45.81165190665953, 47.23835914365707, 47.91249690517303, 47.9151641168902, 54.05423433549943, 54.65217613404798, 55.27483278705228, 51.91677793379753, 54.50526768161405, 55.338904703817065, 51.736462654605994, 48.66054388784593, 49.45416096718081, 48.99781673185287, 55.06972812837171, 56.901667194981734, 55.81804183221633, 57.203301383603005, 64.98896691106981, 63.9519706849129, 59.47064315119098, 58.68858921912409, 59.552710902306345, 63.08688802103843, 62.7840849661058, 62.849023726678666, 65.85602252714096, 34.6513085211477, 10.722961848781956, 3.1751473776755796, 0.8914451589507442, 0.16758740248699344, 0.39522941795087635, 14.431151978431211, 56.54302527827602, 55.063526861129276, 58.732080459594734, 51.31187392819313, 55.879399468821866, 59.863594039793945, 57.880914365091634, 33.60727164053148, 27.353476016752182, 22.687036145117975, 47.56200959605556, 23.39812655602732, 0.03729470382114092, 0.013905829776288762, 0.025365801280244224, 0.047813795822402166, 0.00815992423843953, 0.027147568574535753, 0.02628568710098344, 0.014842138606904736, 0.04820138268593339, 0.030149690949568347, 0.04707909835081908, 0.07295436916812774, 0.051032475931870366, 0.05027454684398348, 0.029411295188530803, 0.04527270899064118, 0.07502082239596114, 0.019971444872358156, 0.05171235981247118, 0.07642433377763919, 0.025908800570534605, 0.019436123698288878, 0.04824416869650445, 0.03066628510432859, 0.07361979313915776, 0.06313509465525709, 0.020220986522373655, 0.07348578137856338, 0.01692288990823492, 0.06806326549380057, 18.924269176298573, 63.503957563830966, 31.65540022234763, 35.432201431643584, 40.680626899965354, 56.51986760477866, 59.26843320169757, 47.36900544935658, 77.35114020685997, 64.06402103362545, 72.48185496176444, 61.718094579635135, 68.09253446517452, 23.15532791999079, 0.3585096899299853, 0.5475633663515891, 0.6405598826466069, 21.898129832360056, 64.75157330113073, 69.47826077861171, 65.44935903241559, 65.87827021075834, 69.64987231839088, 69.34597492218018, 66.12780355638074, 68.97908426100209, 64.35546098216888, 65.77488437775644, 67.67437058110391, 62.42974588947912, 60.462481129554014, 59.839938225284705, 59.25216713259297, 54.75705246771536, 55.90139219837805, 54.97092754610124, 55.06355824009065, 56.95043010096396, 62.42859271264846, 63.14611973301057, 66.2140250975086, 61.71614123928932, 61.03819093396587, 62.5429258808013, 62.65976544349425, 57.29561828797864, 50.39645548789732, 48.24873816582465, 47.06601412065568, 44.799566653467, 43.60159243306806, 44.50989961624146, 44.85889642469345, 48.64626646041871, 54.20270781363211, 55.6225077567562, 63.93237452353201, 60.553844897977775, 51.776255100004136, 45.57622340417678, 45.59200702175018, 42.92785867567986, 43.90807074885215, 43.93202074112431, 43.25040694205992, 42.384692776587706, 40.423280192959695, 46.59194469451905, 48.749342426177, 52.969220453693026, 43.60282797967234, 17.687816504509218, 48.77066835280388, 51.84167238973802, 50.06251273616668, 46.04828065441501, 38.24980466596542, 41.81234052104335, 42.81751848036244, 42.02300710062827, 41.36308400861679, 41.45125889009045, 43.43554673656341, 42.45098867724019, 40.078590146956905, 47.18800767775505, 54.07061415333902, 60.0188571406949, 58.00395911739719, 54.20773236982284, 49.94245682993243, 47.40512263390326, 45.07625064542217, 42.35614576647359, 41.784295574311294, 41.57035381563249, 41.85374506058232, 42.3723098539537, 42.43363611159786, 46.03962398344471, 48.486661295736994, 48.84759779899351, 49.31836458944505, 48.82009021697506, 53.82155933687764, 56.86982539392287, 56.98284064569781, 53.87571550184681, 55.91709344617782, 58.1914484116339, 54.241370616420625, 52.18146339539559, 51.46060236038701, 51.736348905871, 58.47880125045777, 57.983088185710294, 59.031753463129846, 58.83023385078677, 63.43067592190158, 64.29718632851878, 63.03635612610848, 61.40772527264011, 62.38849824474704, 64.82049326742849, 64.451704179087, 64.17099191296485, 67.25117037373205, 38.03006172180176, 11.952754336018717, 4.246461891358899, 1.2361572682857513, 0.28500156176667063, 0.42654868575834465, 16.906409763520767, 61.34912113989554, 60.63670889023812, 64.22942738379201, 59.193755195986846, 62.370694606534904, 65.39610109021588, 65.8901628371208, 39.17049084940265, 37.759806494559015, 22.099788688844253, 52.5406583662956, 29.376442355494348, 0.10253555967562622, 0.04265543088437088, 0.05202297399181032, 0.037508794752460335, 0.055789211614718365, 0.05124274408444763, 0.08144359630081924, 0.016938462560515732, 0.013165253537496733, 0.03850887657233304, 0.03264329373656261, 0.01742562553244493, 0.024068331789045085, 0.17387033470215338, 0.1743078015504345, 0.15945714117298204, 0.2771520103898741, 0.18955068362336006, 0.1477149131918146, 0.19233204244125277, 0.1582434280745445, 0.11551686592640416, 0.201402600073526, 0.11569789250291164, 0.2863547181890857, 0.16365190156765524, 0.1500074313052239, 0.2215667696849954, 0.23924691452374383, 0.18457799158509702, 28.190747114919848, 73.58740637379309, 52.67335214922505, 37.17297284833847, 46.97415613359021, 72.00287080580189, 65.4498807076485, 54.85091478593888, 81.94766383017264, 70.21568990522816, 77.96164143470027, 68.9631280591411, 75.81601865829961, 26.319511782738473, 1.968790439348067, 2.4257878718837618, 1.3472335208808224, 24.663820497451294, 67.29749356546711, 75.12689744272541, 67.91020701008459, 69.8479284778718, 72.82565070736793, 73.02614658109604, 68.89316082000732, 71.44201893960276, 65.80183890558058, 69.11602989319833, 68.91186268098893, 66.9913290392968, 64.63449839622744, 61.31198413910405, 61.66080051852811, 56.65951182765346, 60.28927318511471, 56.18302229912051, 58.58832167040918, 60.0700048477419, 64.73244782417052, 67.60492109483289, 69.88326903312438, 63.410181537751235, 61.95326028331634, 65.18585812660956, 68.0238223844959, 61.70216583436536, 51.93120833366148, 51.812909649264434, 47.85428893181586, 45.723869262203095, 45.4404584054024, 46.41459472717778, 46.597502693053215, 51.974287725264034, 57.50079354932232, 58.552816375609375, 65.33450418902983, 63.318602038968, 54.15332517316265, 47.34489856227752, 47.128901481628425, 45.470460614850445, 45.72008025261664, 45.79906502077657, 45.73288286885908, 46.25953558952578, 43.51124848088911, 50.15795576956965, 51.01453473491054, 56.28750247340049, 43.608382055836344, 12.8846182938545, 49.678312655418154, 53.77030572583599, 53.99613618850709, 49.29162579198038, 40.558613731015114, 45.26788588493101, 45.486240310053674, 43.49888909247614, 43.43616647105063, 43.71273671427081, 45.10673922877158, 44.7223626413653, 42.431757296285326, 49.08783512730753, 54.94175295675955, 60.10333714946624, 59.10257970133136, 57.02686925088206, 52.29677323372134, 48.903534720020915, 46.92542460656936, 45.38688667358891, 44.88093230032152, 43.69982819403372, 44.50087032010479, 44.11312049435031, 43.55443769885648, 48.31687365808795, 50.32233838112124, 53.502694176089385, 52.94629420003584, 50.050510283439394, 57.85037871330016, 60.44514033102221, 59.68521641146753, 56.88442053333406, 57.80192959693171, 58.96621065755045, 56.96484481134723, 54.32001021600539, 54.08773529914118, 53.51372388101394, 60.24658603052939, 61.20778637547647, 62.056104829234464, 62.52500457148399, 65.38502431684925, 65.56057391628143, 66.82149825557586, 64.73962183921569, 65.81142517828172, 67.28145891620268, 67.8009533113049, 67.67956379921206, 68.62579637958159, 40.486528411988296, 12.254489525671929, 7.0586851046931365, 2.2360858705735978, 0.8376329981030957, 2.4123226202303365, 20.600996132819883, 65.91577591434603, 67.88017734404534, 67.97408673071092, 64.2324201522335, 67.81050820504466, 71.64930835846933, 70.03533932470506, 46.60364120237289, 42.230908409241714, 36.346804018943544, 63.716487269247736, 44.45282128549392, 0.2791021638099225, 0.1506612873485973, 0.10954649758435066, 0.16340661553605912, 0.09917158333043899, 0.21698898064994046, 0.21094106888819128, 0.24935259483754638, 0.16923905740822517, 0.09484284181868839, 0.15992876022092758, 0.2020574979964764, 0.14423079127746244], [0.016782174878303083, 0.04280792451613853, 0.019845634082993193, 0.032406116745645, 0.082676783354292, 0.034781514081142606, 0.060862651875903534, 0.03474424773406598, 0.06550282345063264, 0.04176223748213342, 0.015374098570206234, 0.06623795376189294, 0.06477471050475875, 0.03030640381057897, 0.056811847063081886, 0.045637497077545816, 0.1369928232123775, 1.136558115963013, 41.77512899521859, 45.260531440857925, 31.864376260388283, 28.18028811485537, 38.67633104324341, 74.53534126281738, 54.30444625116164, 62.10861359873126, 62.15994565717636, 68.63288018011278, 58.856270543990604, 64.50535043593376, 19.92563851418034, 0.7635130108364168, 0.2501158942017825, 0.12174264798241279, 23.96400886197244, 64.06854352643414, 63.06018844727547, 63.03852911918395, 67.3172152426935, 65.51883205290764, 68.15723788353705, 63.86721218785932, 64.15358443414011, 65.12116255298739, 63.539772725874386, 64.14529254359584, 62.4371160230329, 61.070224931163175, 58.73135089874268, 55.89445744791339, 55.94318505256407, 54.51769767269012, 50.69648150474795, 50.012478982248616, 49.8977888784101, 56.007496233909364, 60.0150602863681, 58.95098009417134, 58.67489622485254, 59.19215879132671, 60.61454357639436, 59.99828038677093, 52.29439627739691, 48.62838437480312, 46.93718387234596, 43.581403993791156, 42.581658517160726, 43.8188172155811, 44.62633909717683, 45.10426029082268, 50.05215767891177, 49.57136531029978, 53.22204074551983, 56.61362009663736, 47.9617226508356, 44.02607133311611, 40.83180681351693, 41.14890690772764, 41.192100048065186, 39.140884799342004, 41.28456208013719, 41.59082858793197, 41.98850593259258, 40.77730155760243, 42.56610239705732, 46.521036086543916, 49.66893819070632, 44.60679784897835, 13.783209766111067, 43.22622160757742, 53.544337980208866, 47.63478917460288, 45.13408599361297, 37.84091718735234, 37.99648623312674, 38.1226610368298, 41.29871791408908, 40.505853929827296, 40.96460650044103, 39.744827824254195, 40.739246722190614, 38.435403377779075, 40.586423335536836, 43.96470192940005, 52.574633936728205, 56.75946558675459, 53.04265114568895, 49.87018323713734, 43.93317784032514, 42.82068775546166, 41.53128308634604, 40.23594779352988, 40.01546744377383, 39.822055370576926, 40.570106275620006, 43.13419103622437, 42.58250182674777, 44.323983192443855, 44.9846476124179, 49.54048448993314, 48.24523548926077, 50.21929379432432, 53.76358670573081, 54.72054304615144, 53.847952965767156, 55.683986986837084, 53.37270290620866, 51.652669060614805, 47.31466101061913, 44.46207415673041, 48.75311574628277, 53.633748408286806, 55.617667551963564, 60.16753850444671, 55.32084218917355, 56.63506761673958, 53.13702729440505, 56.122896286749075, 57.905248749640684, 58.51383193846672, 61.780315137678585, 63.33039268370598, 65.4383332498612, 64.29211862625615, 31.45164485900633, 11.109362379197153, 4.337269173514459, 0.8772377826033101, 0.14180514240457168, 0.17329042146523155, 19.257113664380967, 57.88353843073691, 52.955621596305605, 57.50845393826885, 51.812407585882376, 63.7634890310226, 56.019118216729936, 50.37395677258892, 30.676525677404097, 24.587742205589052, 34.00600018039827, 45.98346740968766, 4.1667220669408005, 0.12197241307266297, 0.1454539732226441, 0.08871618387920242, 0.013255737139843406, 0.08527005226501534, 0.05984950442648223, 0.0015651775996253317, 0.023816020731183312, 0.07521569218126035, 0.06417358812365322, 0.014271224987873388, 0.06707271380770592, 0.08216048605860242, 0.04083820904094366, 0.08433487341408769, 0.11228464138243469, 0.06909366141283704, 0.037784793248940865, 0.01009581788938733, 0.07314618992348833, 0.0143509057928778, 0.05527353868068707, 0.03718671606733434, 0.028199056809347485, 0.04794610686780465, 0.031853229175471974, 0.040901407464257175, 0.040388392855323134, 0.04838176191814485, 0.10060996703443029, 1.9671001429519348, 54.50993922448928, 48.27482977221089, 30.106540572258737, 45.65193299324282, 42.27356026249547, 81.26180602658181, 56.55711443193498, 69.04702755712694, 67.08523842596239, 74.67371463775635, 63.35563313576483, 68.80310320085096, 21.6303692325469, 0.5371525991828211, 0.19067505554806805, 0.7209963567795292, 25.35671111076109, 68.13043240577944, 67.94700668704125, 66.71007940846106, 69.15407688386979, 66.64596434562438, 72.1729055527718, 65.84358861369472, 65.74632167816162, 66.99047396259924, 65.18179455111104, 66.8414003618302, 65.64859974768855, 63.82437598320746, 60.74784532670052, 60.564333315818544, 56.422588902135054, 56.57436501595282, 54.317852912410615, 53.25050538586032, 53.516634279681796, 55.99358358690816, 62.63462697305987, 61.86930979451826, 60.15256289512881, 58.994083019994925, 62.2183419043018, 64.35202498589793, 55.77011831345097, 50.029596205680605, 48.501334882551625, 47.11254519800986, 45.26025295257569, 46.17205888994279, 46.30469775968983, 47.525221686209406, 50.34277392971901, 52.054817907271854, 53.231372064159764, 59.37125813576483, 51.85145085857761, 45.573022750116166, 43.72992846273607, 44.64654322593443, 42.886410990068995, 41.86219384593349, 42.84065261963875, 42.98342689391106, 42.984238824536725, 43.819001566979196, 45.18289989040744, 50.21203740950554, 50.381271992960286, 50.01070607093073, 20.713448524475098, 46.4388898880251, 55.3211755906382, 49.983884903692434, 48.50459829453499, 40.46644587670603, 41.5340522796877, 41.975699393979966, 42.36879933264948, 42.183643848665305, 42.90894108433878, 42.75650601233206, 42.729469114734286, 39.027873469937234, 41.759604254076564, 48.03547889955583, 57.18643911423222, 57.7109266865638, 54.772271263983946, 51.569910972349106, 45.729160539565555, 44.792957459726644, 44.01586924829791, 42.77941265413838, 43.510377714710856, 41.33992241274926, 41.857639974163426, 45.31056127240581, 44.80061784867318, 45.60994402054818, 46.293511159958385, 50.06945140900151, 48.786510805929865, 52.93447217633648, 58.244070929865686, 54.74364972883656, 55.73245179268622, 55.24908242687103, 56.04405272391535, 54.4102482641897, 51.32723000741775, 47.24593324045981, 53.29294150875461, 56.04808492045249, 58.136154759314756, 61.748853806526434, 58.20405490936772, 57.98457868637578, 57.0180086166628, 59.77718814726799, 59.99938257278935, 61.57020553465813, 64.24724671148485, 65.54288794917446, 67.60407386287567, 66.73973252696376, 35.84782361984253, 11.382043592391476, 5.69675483049885, 1.5167405864884778, 0.22140069714476987, 0.1812808410895448, 21.79471850395203, 64.80518425664594, 58.26388674397623, 63.49693652122252, 59.152056478684955, 69.37161153362644, 64.94049033811017, 52.063764833634906, 37.62525350816789, 30.261731109311505, 33.86074696817706, 56.77630432190434, 5.7105723600233755, 0.15662859133895368, 0.16495411314310568, 0.039618577913291035, 0.015564575798869615, 0.06566920242602788, 0.0380909871009569, 0.02917807887218172, 0.02518452955560098, 0.03502665455603311, 0.01909571827479428, 0.03844671619815692, 0.020171847727690494, 0.053368500178499576, 0.07008524731762948, 0.17161097287410693, 0.3154358448040101, 0.14006316571706726, 0.2523037647047351, 0.18455379852844825, 0.1419989779711731, 0.12055359525425781, 0.17191566136335173, 0.18642748105189494, 0.1306590840460793, 0.16456500176460515, 0.15817521560576656, 0.1624607420977085, 0.28147608642616584, 0.22137815883803755, 0.38358371704816824, 4.206343398940179, 67.38527620992353, 64.84081114492109, 48.27979157047887, 45.226481345392045, 51.6922418532833, 88.14572257380333, 66.84369102601083, 73.01008055287024, 74.17949599604454, 80.94354491080009, 71.96673793177452, 75.86870393445416, 26.089292187844556, 1.324465020049003, 1.2308409858134486, 1.760198425862097, 30.14726261938772, 71.40197938488376, 70.69341890273556, 70.56910330249418, 72.10386399299868, 71.84405403752481, 75.29382567251884, 68.1720801322691, 66.5238452726795, 69.25712539303687, 67.9310191062189, 70.06101515985304, 67.79183772302443, 64.6089166979636, 61.74317029214675, 60.77754943601547, 59.70948019335347, 58.79240651284495, 56.698868889962476, 56.70106933962915, 56.625544101961204, 59.67833657418529, 66.55003101594987, 64.67356912551388, 64.0517440149861, 62.065836229631984, 66.10309262429514, 67.09816655805035, 58.73368863136538, 51.546164943325905, 50.889089492059526, 49.06011573729977, 46.22233190844136, 48.006563186645515, 49.7045454671306, 49.058601702413256, 53.567605480071045, 53.89484882354737, 56.3394424992223, 59.19061337747882, 51.96685091141732, 46.23296545397851, 46.608002878004505, 45.503565419104795, 45.46339642617011, 44.23954240737423, 46.935414883398245, 46.46664065699424, 46.983695337849284, 45.187136050193544, 48.497181092539144, 53.053712229574884, 54.0102174974257, 49.1682594053207, 14.281742034419892, 45.9797215461731, 59.8851082401891, 52.75358423109978, 50.609475489585634, 42.663400711551795, 43.42119870647308, 43.85155331703925, 46.648383678928504, 44.64500173445671, 44.35133780202558, 45.528166524825565, 46.752267652942294, 43.08351009122787, 45.61470577793737, 49.978625005291356, 58.649353750290416, 58.816493788073146, 54.4780856563199, 54.75493831019248, 45.660487682588645, 47.50807308381604, 46.57820463180543, 44.164938926696784, 45.91353939425561, 42.20302035731655, 44.26739123559768, 48.17769227489349, 46.36444722452472, 47.46155377357237, 49.19603370851087, 54.6847592630694, 51.73855720027801, 53.55097463054042, 60.32870085008683, 58.502798311172, 57.505237594727554, 58.126152715375355, 58.68420008690127, 55.25315776948006, 55.17679706696541, 50.556472501447125, 54.705520368391475, 59.3112458721284, 62.27582031680692, 64.1119602418715, 60.228052831465206, 59.93443204510597, 57.57212185090589, 59.796023368835456, 64.26167318897863, 65.49527429765271, 67.45798126343759, 66.84490696076425, 68.67306878489833, 71.07999986217868, 39.3157793629554, 12.261643928866233, 6.553543152347689, 2.0868038938891504, 0.7333946624590505, 0.553604674435431, 22.123768098892707, 71.06594993222144, 62.65275616799632, 71.40765897689327, 64.43759933594735, 76.77273181176956, 69.62303546167189, 62.59860392539733, 44.111241679037775, 40.009811385985344, 47.20341867016208, 68.39274483342325, 11.571106737659825, 0.3672438889982239, 0.2982884068642893, 0.1914492640043459, 0.10361703833745373, 0.12192541357850838, 0.12812119563140217, 0.09712234409826417, 0.12873646382602955, 0.17280841426503274, 0.10826954392776375, 0.16302424573129223, 0.15699115010999865, 0.23330790982131036], [0.024381313180070252, 0.04396092514657686, 0.02346254201726087, 0.05831349430786026, 0.014032813637787777, 0.0225330532843908, 0.03221504675645021, 0.10808949794379935, 0.02476321950164293, 0.015512430109083654, 0.07599164731800556, 0.008994155683584752, 0.07773691052270514, 0.04947572015225888, 0.024739173916919578, 0.06432484069298353, 0.06536117379343317, 0.07111590370656022, 12.883186628741603, 51.371089950684585, 36.926181239466516, 27.67192932867235, 31.956285238265995, 60.10684767077046, 67.61546442585608, 67.64760432704803, 62.799178246528875, 68.62520017931539, 61.46562730112384, 65.50458600444179, 16.152202698492236, 0.2959773647448709, 0.5130405639929156, 0.1259102275775325, 32.0821286016895, 72.24879557086577, 69.8397542584327, 68.64329015055011, 64.16143309685492, 65.33186051153368, 64.95271636593726, 64.61333328677763, 65.57983667619767, 62.67430174735285, 62.539027044850016, 67.47690277714884, 61.55854825050601, 62.06862895719467, 65.29175035415157, 56.23889253985498, 54.39935584222117, 50.97126706953972, 51.01884934210008, 48.14160254693801, 46.94399702933527, 48.58409297081732, 54.53587001369846, 59.14604348521079, 59.41025041764783, 59.73447745846164, 60.585043430328376, 57.23917538119901, 49.42879499927644, 47.308271469608435, 46.029523880251, 42.73740406959288, 41.43140385227819, 42.92001393533523, 46.892131528546734, 46.22518739392681, 46.13253708808653, 50.13555511351555, 49.82563295672017, 47.709173002550685, 41.420817375183105, 41.96047667534121, 41.58599622787968, 43.993186181591405, 42.42895672398229, 39.67856722493326, 40.80847655573199, 41.97440108945293, 40.74298474096483, 42.28689632108135, 45.68442198538011, 49.60369348526002, 49.61882598938481, 49.25983890410393, 14.763597365348572, 43.06083879163189, 56.1185149992666, 47.52741429113573, 48.17644496117869, 38.31280185330299, 38.7810936281758, 39.119598096416844, 39.897792416234175, 38.5241783818891, 39.116209168587964, 40.07801355854158, 40.71875626041044, 37.94556602354973, 38.132235542420425, 40.094114888098936, 42.56910301023915, 52.26076587553948, 52.96460774637038, 47.48982229540425, 42.68629166387743, 41.27149666509321, 42.984917394576534, 42.315968928798554, 40.98380258006435, 38.676782115813225, 40.018362152961, 43.08597333969609, 42.84642242616223, 44.65823581141811, 44.50981724646784, 44.888867255180116, 49.562551744522594, 51.893863447250865, 53.41174225653372, 53.60861778259278, 52.42654092850224, 52.17825097422446, 51.91765262234596, 48.769232765320815, 43.98218001088789, 47.24030071689237, 49.7252595040106, 54.04473435494208, 55.92638946348622, 60.306751266602554, 58.4527410230329, 55.545013489261756, 55.80435668268512, 57.315904786509854, 59.380420792487364, 64.11570610538607, 63.18375487481395, 65.46156152602165, 65.67022377444853, 64.8421722073709, 26.4592364142018, 11.847039595726999, 4.688975359162977, 1.3792164046918194, 0.17415187201432644, 0.2293999574237293, 23.11551586274178, 58.84730792814686, 55.7461134079964, 48.66448979223929, 55.686391399752715, 58.106619311917214, 51.71257542025659, 40.78073755387337, 28.610901601852913, 27.117141446759625, 40.68219977040445, 31.065891519669567, 0.04796118730859411, 0.036562722131249406, 0.034551511503635876, 0.09777901934519892, 0.042558735266568205, 0.01840702629828405, 0.04781247432073278, 0.05248958665517069, 0.03510713209247878, 0.038053264931565335, 0.044344555165979176, 0.064515458690303, 0.007929356192283693, 0.05201421760683579, 0.055924491250827435, 0.03573036377107905, 0.03778590407643107, 0.03505576206671615, 0.011248853951392156, 0.032544928047085, 0.037568530458356106, 0.03831521337551456, 0.05475066068972792, 0.04016746458927951, 0.03420268868907325, 0.009322086322842347, 0.01804480843636538, 0.04276998784212817, 0.04414066086493192, 0.013351681991480293, 0.10962488370076304, 0.06641437614997549, 19.150917453150598, 60.917860461819565, 32.28788829618885, 41.46051568369712, 41.989886606893236, 68.20950738845333, 79.04773789067423, 71.98162724894863, 69.03111057896768, 71.70840278748544, 66.79350822202622, 69.05894371771043, 18.312514751188218, 0.5180396247775324, 0.31411161586161584, 0.2807078534556974, 36.0182741380507, 74.02877499980312, 72.04251812350365, 69.9769038538779, 66.84136113812848, 69.0248740103937, 68.00133935866818, 66.01122287011916, 66.80947226862754, 65.76531379453598, 67.0218764581988, 68.88474341361754, 67.37214411458662, 63.50004696076917, 65.6948797933517, 59.02996486233127, 57.72460399135467, 53.47047582749398, 54.214035618689756, 50.59330747973535, 50.288747202965524, 52.49084426510719, 56.63192187586139, 61.68850814142535, 60.79246620978079, 63.22273146721625, 62.75193329780333, 59.240466702368956, 51.38559879795198, 50.234708709101525, 47.533909736141084, 45.209277829816266, 43.76533569828157, 43.85502853701192, 49.56281454332414, 49.16315640172651, 48.26882854584725, 51.646856108019435, 53.52101556716427, 51.63880348205567, 43.750846462865034, 44.55843894712387, 44.080541287699056, 46.0514695413651, 43.69714137046568, 41.58086184532412, 43.44174800380584, 44.15980454414122, 43.851667065774244, 44.25371393080681, 46.888440578214585, 53.80619541291268, 52.318067781386844, 54.43670072863179, 25.265590529288016, 46.055093811404326, 56.365789059669744, 51.44703488196097, 49.66145038604737, 41.58015189632293, 40.50301021145236, 42.08774582032235, 41.64344326142342, 40.61503310357371, 42.178638904325425, 42.680980774664114, 41.2723203628294, 40.50346128402218, 40.324491377799745, 43.915378124483176, 47.60049196981615, 56.77850477157101, 55.43450070965675, 49.82074960585564, 46.98120071041969, 45.211556726886386, 45.54741751763129, 45.28883526402135, 41.807112001603656, 43.54192926037697, 41.12442739548222, 44.95045631162582, 45.55546622122488, 45.3035637640184, 47.73977533463509, 46.59136026136337, 50.12762015865695, 53.911797385061945, 55.6773111128038, 56.6871057018157, 54.857084674219934, 53.49294708621118, 54.28371652480095, 50.51389125085647, 45.627025942648615, 49.48528105212797, 52.936684393113666, 57.72350180533625, 59.256281698903734, 60.54252493766047, 63.043796862325365, 57.42018884228122, 57.07611853076566, 59.847037715296594, 64.14629667035996, 65.68664281598984, 66.00918323762956, 65.20537191821684, 66.59560111261183, 67.37207351192352, 31.737769995966268, 11.269739270210268, 5.758301231168932, 1.6411623358726504, 0.4306503205049423, 0.39340459651524023, 27.160012952743042, 65.5216718489124, 61.17561509532314, 56.51854576603059, 62.00833036053566, 63.063742114651596, 60.167691476883434, 45.59327002494566, 38.57342373940253, 26.51508115953015, 45.92883271555747, 37.6558832968435, 0.1476331256450184, 0.06210544184150715, 0.03653380231210782, 0.1101378331922235, 0.05367207400981457, 0.02973291422090223, 0.05069743886950517, 0.015046230175592487, 0.01579542777636239, 0.02520791438948964, 0.04872348692808901, 0.03398097518290724, 0.028571011648783763, 0.03464392468994183, 0.09297125837615422, 0.13937420752500335, 0.11684811223418483, 0.17171919045429077, 0.12067246145658916, 0.17459830209132166, 0.12316782433058947, 0.19096986150308964, 0.11012759825755512, 0.20985265713064902, 0.13232858881594675, 0.13041050383640876, 0.1387869704875254, 0.19903281433207376, 0.1455880232876347, 0.22388289862823105, 0.16829349040504427, 0.31154822437993945, 31.14328576672462, 75.3443536450786, 52.715066556007635, 44.01529658225275, 48.08095878170383, 74.66246528010215, 83.83202537413567, 77.29593676905479, 77.16340772567257, 81.18305267826204, 70.35288656911543, 77.37978919859856, 21.66662762241979, 0.6159032508730888, 1.028432343755999, 0.964858445429033, 41.321961879730225, 77.5967433375697, 75.80864460237565, 75.19451125975579, 71.89761792459797, 70.57291584630167, 72.08026701404204, 67.25921907732564, 69.42878400125812, 66.83239459991455, 70.25815348471366, 72.4805841138286, 67.93612603218325, 64.40871107962825, 67.74424368335356, 60.97089482891945, 59.06957687870149, 57.02915207032235, 56.702759881173414, 53.77530282543552, 54.484600713176114, 53.687073030779445, 59.90639494311426, 63.50477341682681, 65.51497636302825, 66.12700339286559, 65.8263772533786, 62.721248595945305, 54.95212762586532, 51.83991124553066, 49.3914814918272, 45.84568239027455, 46.04492702791768, 44.7613549232483, 52.7354746480142, 52.64973555841754, 50.753952072512725, 53.71094849801833, 53.99465745495212, 52.57508108692785, 46.20131977142827, 47.1119019293016, 46.872480453983435, 49.341781139373786, 47.56462581696049, 42.990243973270545, 46.79517053788709, 47.371915848024436, 47.36942906533518, 46.49751755499071, 50.62113669610793, 55.3751709384303, 53.81277322769166, 54.588104217283195, 16.18875232435042, 45.550935883675855, 61.11260614087505, 53.649849737844164, 52.74772028769217, 42.18139633055657, 41.900782123688735, 44.52256102715769, 45.37913999249859, 41.97010609411424, 43.176046648333156, 44.75686380940099, 45.05066110241798, 42.65987842313705, 42.15144118955059, 45.523494981950336, 49.05630711586245, 55.66185305195471, 57.0778835973432, 51.00587021919989, 47.537737969429266, 48.12380675346621, 48.512494025691865, 48.79544988755257, 45.62992457420596, 45.16551594580374, 42.26482514412173, 46.500318127293745, 47.243677877610736, 47.73111081892445, 49.949011110490375, 49.01564390428605, 52.08800115892964, 54.603189652965916, 57.80700122156451, 59.17501018893335, 56.9345288122854, 55.206654148717085, 55.58295849830874, 54.55056713473413, 49.46014258169359, 51.69556802318942, 54.443356990814216, 60.21767031761908, 61.95958706640429, 63.20569661355788, 64.50577405191237, 59.86593961715699, 58.777936889279275, 62.78140598727811, 66.17825308153706, 70.042234851468, 67.02899948243173, 66.95336049602878, 68.07340114347397, 68.4409115391393, 36.81388770380328, 12.225758164159714, 7.491319102625694, 2.1522187321416797, 0.3836321950920167, 0.3521873807955173, 29.27077958660741, 72.79657809965073, 66.43467410918205, 63.91748912872807, 69.23432073285504, 70.621521857477, 65.52425669085595, 55.909331075606815, 42.88818390138688, 41.01097283824798, 54.854801854779645, 54.6580518445661, 0.4117472541909064, 0.20717565480980182, 0.09918084533344354, 0.1842722152509997, 0.15170238551593598, 0.147269448385604, 0.13682057600348227, 0.17294940508661732, 0.1278114509618571, 0.20703800413156712, 0.18128396672827585, 0.2124396287986348, 0.09790511741753548, 0.11014806046601265], [0.04774829530487618, 0.04873860950371431, 0.043067321887299906, 0.01395953541261054, 0.035366177063194976, 0.05319247232569803, 0.07680526333710841, 0.05554564162007263, 0.01612630210846903, 0.04585482473034532, 0.08088344047146459, 0.04501877765681955, 0.09431712164153015, 0.08146611162491384, 0.04140221446211781, 0.09757759184726784, 0.13712321137709005, 0.1156854129306251, 0.4391804950371866, 33.64471458619641, 43.296530092916186, 30.29073899792087, 23.621474158379343, 44.29226298486033, 64.22672094837313, 66.54883861541748, 64.01766254055885, 72.69793833455732, 56.877634832935954, 65.10700279666533, 17.13030649769691, 0.14647883032598805, 0.23820488172913754, 1.8376886484123047, 60.6113507670741, 65.18407737055134, 66.03971496705087, 65.84764434445289, 67.49790314705142, 62.77052141004994, 68.88709683572093, 65.36937405986171, 65.34175665147843, 62.65629022352157, 64.73575438222578, 64.79355442908503, 65.5870734491656, 66.49486680184641, 62.32007249709099, 57.98464144429853, 56.500851954183275, 54.73653454934397, 51.732948210931596, 46.75115762218353, 47.40822915107974, 47.277429872943515, 45.48633444693781, 50.37406267658357, 53.1879553487224, 54.71859755054597, 52.4903892701672, 48.72075619236116, 45.917430385466545, 47.126673575370546, 44.84751762882356, 43.71540784835816, 42.517974915043006, 44.42505874941426, 46.99382682000437, 47.62470868326003, 45.05726637378816, 46.74390123736474, 46.65105481301585, 41.99304411488195, 41.88234698387885, 42.55568065950948, 40.03427128637991, 43.06532598310902, 41.560500821759625, 39.104653866060325, 39.4304733891641, 40.69018963844546, 40.58962398959745, 44.40316407911239, 43.93863777960501, 51.88705029026155, 51.28026354697443, 59.20406318479969, 20.392755539186542, 35.690940580060406, 57.18772172927857, 49.11036522157731, 53.27735400968983, 40.500013520640714, 40.279442956370694, 38.8221961452115, 39.77808952331543, 38.86085110325968, 41.092601283904045, 39.46755939914335, 41.79804740413543, 39.898219954582956, 38.8545713886138, 39.62216354185535, 38.63964903739191, 45.219883918762214, 49.01609497685587, 45.943686731400035, 45.18302932862313, 44.35460121400895, 43.8427475960024, 39.86453856191328, 41.67122540935394, 40.70208226480792, 40.053235946163056, 39.85695662037019, 44.186833596998646, 43.613587041055005, 43.044458973792295, 43.56893870138353, 44.60305590783396, 47.08953657457906, 47.718084627582186, 50.13133856558031, 48.896635270887806, 45.90465522581532, 45.56729608966459, 45.160875781889885, 46.090344152142926, 47.75007547870759, 49.68994248297907, 52.47309161770729, 56.88911953280049, 58.225812296713556, 62.97313928604127, 50.94194343013149, 55.15521226390716, 56.21335398766303, 57.092286540615945, 59.635504291903594, 60.56451374484647, 66.94896744143578, 65.20931782261019, 66.6091803581484, 24.91834113674779, 7.8152279411592795, 1.5328998935799447, 1.602141003935568, 0.4809312143873784, 0.5472819362917255, 30.769203439835582, 58.125458455854854, 50.64825204110915, 52.79292560392811, 63.967467969463726, 60.88581861988191, 54.196349651582786, 30.160149566588867, 26.244645503259477, 35.23404721290835, 48.09432229688091, 9.60221125233558, 0.2960568846714112, 0.11895408793803185, 0.08671575210868351, 0.07859392542271845, 0.014473385057382047, 0.04181730005169108, 0.02680154581133637, 0.03567407163040292, 0.09259294883738603, 0.049910739349621924, 0.039955656599974444, 0.005283513540146692, 0.05492328328170604, 0.006176969327498228, 0.07711831750648637, 0.03293465229592497, 0.05751069545024826, 0.08463754709209166, 0.061347041609546835, 0.043308574465974685, 0.07592499000771392, 0.09271232065774741, 0.05866952600979036, 0.013208545166097823, 0.009431649344943224, 0.03268898705080633, 0.09809971141118197, 0.13124854273853764, 0.06577713655367975, 0.04838985180662525, 0.0886910715170445, 0.06971862828058582, 1.5705512151602776, 48.55514980131581, 42.66831151900753, 29.767261435908658, 39.1615713796308, 50.15193885372531, 72.43937569279825, 68.92536347912204, 74.58917187106225, 77.15440196375694, 63.88057178066623, 71.00425889415126, 19.5557354727099, 0.15419895880885665, 0.1467115065503505, 2.8334243595600133, 62.86484656795379, 66.39849416671261, 69.83261554471909, 67.93640059809532, 70.91941018258372, 65.94367181101154, 72.75223178248253, 65.87281811621882, 67.65157376566242, 66.83040203586702, 66.98212715887254, 65.51243858952677, 68.33904758576425, 69.08170915419056, 65.57031708378946, 60.79967552615751, 58.46386094247141, 56.47210490319037, 52.04426280913815, 51.42353203988845, 50.50142203607867, 49.249793714092625, 47.7807641029358, 54.741374754136615, 56.53135230464321, 57.10554415179838, 56.48267961317494, 52.71106573843187, 48.46785353076074, 49.26329451222574, 46.585213907303356, 45.55749408660397, 44.071237425650324, 48.088858435230875, 48.97605149976669, 50.78343260672785, 48.16732937289823, 49.809382577096265, 50.04119857665032, 47.116142011457875, 43.07476320574361, 44.39560174942017, 42.96004172294371, 45.0691197764489, 44.303751607095045, 43.20298940904679, 42.1946382522583, 44.487518572038226, 42.95624879098708, 46.44659734541371, 48.617087948706846, 54.59922413672171, 53.19632568667012, 62.44221510425691, 35.491888138555716, 41.262381076812744, 59.00981172438591, 52.706382428446126, 54.24425355849728, 44.65603928412161, 43.11841918576149, 41.84834003448486, 42.9116867434594, 41.59703769991475, 43.13124925859513, 41.50327736331571, 43.50345865372689, 40.92718708899714, 40.90786941589848, 41.42610080780522, 42.69692520941458, 48.746361424846036, 52.29811468432027, 50.30071043199109, 48.07625978223739, 47.21689593407416, 47.209043348989184, 43.202420665371804, 43.837224898799775, 43.143993039284986, 41.55886519339777, 41.206232347796046, 45.41299396945585, 44.53943114126883, 45.37220131966376, 44.761205873181744, 46.73153400421143, 50.25331251082882, 50.005046090772076, 52.24506855010987, 51.00183017792241, 49.23256666429582, 47.78034833169753, 45.84897718121929, 48.51805986896638, 50.748566658266135, 53.764375102135446, 55.79329559879919, 60.18565200990247, 60.40442220626339, 64.3151782404992, 56.44991605512558, 58.57879815563079, 57.28378057479859, 58.75987829700593, 60.17753662601594, 61.6186232720652, 67.70372559947353, 66.92832792958906, 70.22287568738385, 30.112912462603663, 7.578990449828487, 2.1811572438286198, 2.167449050372647, 0.22035540081560615, 0.6769453818278929, 37.84560834207843, 64.54601756988033, 55.35955990514448, 59.45181185199369, 68.44422986430507, 72.3908559737667, 60.40395936658306, 37.54858293840962, 32.11241714416012, 33.776427776582786, 58.53825653752973, 10.114029569010581, 0.31440291313394425, 0.14489931024370656, 0.07489627948211086, 0.07906183660511049, 0.04806296591977439, 0.05059255377179192, 0.14027112794499244, 0.04734156773455682, 0.025200335864698695, 0.05322900705880696, 0.008237932098939294, 0.010836225588836018, 0.03699946502644209, 0.045075395384863506, 0.17222581972037593, 0.25295596599819203, 0.1022550335995132, 0.1523558891588642, 0.17629650451483267, 0.1936481814951666, 0.17990790427692477, 0.19353038781592924, 0.14366102104465808, 0.1156633802419228, 0.21854133525442695, 0.17739335856130048, 0.23938055090125532, 0.20939832102627526, 0.13502711820746624, 0.2093563240862662, 0.21263541022856391, 0.31938511998422686, 3.4291934101812305, 63.51805456223027, 62.485506303848766, 46.46477753116239, 39.80755436804987, 58.47079961530624, 77.25649341460198, 80.97835986844956, 76.23661441187706, 88.0093417629119, 66.76899340844923, 78.38932098880892, 20.896925234025527, 0.2544581112001212, 0.36746081445486317, 4.18646776868451, 65.30924804749029, 67.36817467597224, 74.33351962797104, 70.96050093250891, 71.96990720687374, 69.9167190059539, 76.68494916731312, 68.51593863579535, 67.74192164021154, 67.7875623395366, 68.5305533870574, 68.74753106024959, 73.32301508995795, 66.63641729662496, 68.61655527545561, 60.57607296974429, 60.60748331008419, 61.4261172663781, 57.1376605187693, 53.043721952746, 54.19502781283472, 52.182906827619, 49.91743210823306, 57.29213130089545, 59.591558056492964, 59.23720329038559, 59.12668266604024, 54.814060195799804, 52.25962054344916, 51.347771460010165, 49.80448353675104, 46.95054738752304, 46.68037453005391, 49.03065089256533, 51.99955955628426, 52.04207804895217, 49.80596619267618, 50.855517925754675, 51.84117032635597, 47.87905085471369, 44.78205719301778, 47.96384857546899, 45.57613318966281, 48.62339119757376, 48.180477157715835, 43.29259595563335, 44.74999966159944, 47.20628592275804, 45.37997153497512, 48.49873042875721, 50.140556135485255, 56.9227264004369, 54.49180610718266, 62.759256362915046, 24.38304155103622, 37.168234625170314, 64.62460617865285, 53.47806561377741, 61.851039394255615, 44.84270488062213, 44.9568066289348, 43.6159679197496, 45.105907686295055, 44.37602127751997, 45.33992805788594, 45.09310507005261, 47.824576977760564, 44.45086402277793, 43.941144174145116, 42.04133241407333, 42.52044208588139, 50.0172564291185, 54.05845480580484, 51.86321012435421, 51.17550488441221, 49.12883174034857, 52.175964232414, 44.3004999622222, 45.54694683321061, 45.397237808473655, 42.07071488903415, 44.822885144141416, 48.37117495075349, 46.321273696038034, 49.71104091213596, 46.001259280789284, 47.64228874637235, 52.179812077553045, 51.49471521377564, 55.47002561630742, 54.22088407701062, 51.55353899924986, 50.46228070412913, 48.566634501180346, 51.715175951680834, 53.39170286732336, 56.09452578329272, 57.85856469984978, 62.79699740871307, 61.874200990123136, 66.45831031184044, 57.285447582121826, 59.10987923222204, 59.860248258036954, 61.848062315294825, 64.56729642806515, 63.388145662123165, 67.57433445222917, 68.61965394789173, 72.80923951056697, 38.09091337265507, 7.771177762939085, 5.9556631311293575, 4.087386491798585, 1.3372657976804243, 1.1607939509614822, 42.95641745290449, 68.90325700083088, 65.93022592606084, 66.09869956970215, 74.34114471558603, 75.31044083256876, 69.00511310946557, 43.262409394787205, 41.919056446321555, 47.05779675514468, 67.73814047536543, 19.328808707575647, 0.42221786814831924, 0.17474574337322868, 0.1785630216040919, 0.1640586789336897, 0.1360501213780334, 0.09336394738526115, 0.19685358530090702, 0.11705733850718507, 0.2446139579819095, 0.2279486498164554, 0.07206497939243432, 0.17349884334591129, 0.15914517484845656, 0.10901826463880078], [0.0371529009463566, 0.05865282529304105, 0.06969802051542268, 0.035208002889468785, 0.02393160807719875, 0.07608114170932001, 0.011976802188362326, 0.06582777496547469, 0.0677173001871955, 0.038627903653128494, 0.10878276154999772, 0.06705796661516351, 0.021332903772652633, 0.05704232461510166, 0.030827628966841488, 0.03730037287178059, 0.029558987364233024, 0.03604062554997302, 0.24668942806461167, 13.93047417363813, 43.35459293857698, 31.40526871527395, 23.49017281686106, 35.22672807016681, 64.50915513500091, 74.6415747365644, 50.99808039203767, 63.91325296894197, 59.35145408876481, 65.10733619812997, 22.003502345854237, 0.3406602090164539, 0.17166489014221778, 11.797567721336119, 82.92495373756655, 64.37071900213918, 70.1179365957937, 60.84805796223303, 70.94691384223201, 63.87953235257057, 63.91317452153852, 61.725978543681485, 67.46558281683153, 60.850936981939505, 66.10761119473365, 62.00035618197534, 71.20106773991739, 62.49001310717676, 67.00268037857549, 58.13250303268433, 54.76698783136184, 51.93441291009226, 52.82100977436189, 44.17060282922561, 45.22313556363506, 46.54677075724448, 47.96513903525568, 45.14681800719231, 46.79315051724834, 45.28215154524773, 46.564911719291445, 44.81535419341057, 47.03546277938351, 48.70983631380143, 46.10129540966403, 42.705746619932114, 42.63349656135806, 45.491727705924745, 48.47569827110537, 47.59026635077692, 42.39342397259128, 45.96218855150285, 40.45635754062284, 42.09569254229146, 41.523614852659165, 41.5774650727549, 41.18684799440446, 44.291039205366566, 39.118311559000325, 40.08174765494562, 39.570380410840436, 45.479533057059015, 42.51138925552369, 46.93735253426337, 45.69574586806759, 56.40999809388192, 52.34438688524308, 61.57583805822558, 28.839167856401016, 29.997643809164728, 60.35329411106726, 50.245765870617284, 54.57740399145312, 45.970429451234885, 43.39853132924726, 39.797011037026685, 42.139611321110884, 38.965809806700676, 38.72223454137003, 39.939655873083304, 41.28979059957689, 38.06684178690757, 37.870307507053504, 38.284545098581624, 39.097613211601015, 39.64822376928022, 44.243115686601215, 45.487377797403646, 43.3577073004938, 44.157325606192316, 45.624421488854196, 42.17404188648347, 43.1667741652458, 40.74956647811398, 39.484288307928274, 39.665297846640314, 41.71616008204799, 42.98797292094077, 42.877981816568685, 41.45943703189973, 43.09464177777691, 44.250874134802054, 42.808952023906095, 45.9914808119497, 41.00077859817013, 43.3260694626839, 44.04739333737282, 44.24902277608072, 45.097188257401996, 46.97509750243157, 51.41059214068998, 54.15028925864927, 57.729283378970244, 58.605356524067545, 62.6728347809084, 66.32671479255923, 57.95255645628899, 58.03418490194506, 54.70228049062914, 60.99763362638412, 65.95795708317911, 67.29319464775824, 66.51640845883277, 69.7703439958634, 39.8703436697683, 6.9674743087061, 2.2282264213408194, 1.7158242843804823, 1.112678848928021, 0.82047367047879, 41.830187305327385, 53.958097042575965, 54.19949539246098, 59.44747763295328, 50.33534496061264, 42.21152405585013, 41.955032425542036, 27.133966453613777, 32.51981608329281, 44.00827161727413, 35.519164300734, 0.21302685051435427, 0.03706759322554835, 0.048292049191771984, 0.05112948181528238, 0.10021794452181748, 0.020846399636338317, 0.059194495420782804, 0.10143459939788427, 0.04501322351936852, 0.03931289350974464, 0.13586183228800375, 0.051091614089185194, 0.02566086195950066, 0.022565897388924516, 0.039571045988029054, 0.040758819349350474, 0.05043376672772631, 0.037621834856127544, 0.01972477988249833, 0.05455150847293196, 0.04622158549365498, 0.031038155674093196, 0.03996817064621756, 0.07487431574132174, 0.012146231151306102, 0.0624611939213449, 0.0435698410916713, 0.008614522727927374, 0.036851169556499495, 0.04396442616839082, 0.09249031603817018, 0.013982845552926584, 0.08484090513159191, 0.22541182626399303, 21.21119337697183, 54.49258665884695, 31.854650743546028, 35.47150750314036, 43.20982217788697, 72.92357660108998, 80.79916246475713, 58.79666620685209, 73.25768409236785, 64.29411119030368, 72.99643854941093, 23.688746729204734, 0.12572663460647868, 0.011991344452384981, 14.221371854505232, 84.78082318459788, 66.40468366684453, 72.31576611918788, 63.96808770395095, 73.29865717118787, 66.43902794007333, 65.80821667948078, 64.31568814862159, 69.19620313952046, 63.931927373332364, 69.49802952428018, 64.77850429473385, 71.72299400452646, 65.6095290184021, 67.98056648623559, 59.22558915230536, 57.88351881888605, 53.434468469312115, 53.798001581622714, 47.652714406290364, 48.467171038350756, 48.998044229322865, 47.92600554804648, 47.35470056533814, 49.07654262358143, 47.82114490385979, 49.0199585114756, 48.0748281171245, 50.355992317199714, 49.773030050339244, 47.768094847279215, 45.44074081605481, 46.278986623210294, 50.31725891174809, 50.37668281985868, 51.20142782888105, 45.40848324375768, 50.03797831073884, 43.751274001213815, 43.45159707530853, 43.133332037156634, 44.616168391320016, 44.06580494296166, 45.01521072080059, 41.52281861151419, 42.96856895569832, 42.30122473932082, 46.41655983463411, 43.94148542035011, 49.12705098429034, 48.22429395491078, 58.240223084726644, 53.901222675077385, 66.90404845822242, 46.815327598202614, 37.22057081037952, 62.06094111165693, 53.10274577909901, 58.30410672772316, 50.27554842733568, 46.49031608335434, 42.93477381429365, 44.173105301395545, 40.300866942251886, 41.75789017831126, 42.2501358678264, 42.47967689268051, 40.85378777596259, 42.60322370836812, 40.15341720273418, 41.96402642034715, 42.79903234974031, 47.232471666028424, 47.29275065083658, 46.005805307819, 48.24408623480028, 47.71176176686441, 46.03956514789213, 44.9464358821992, 43.43570755374047, 42.25993002614668, 41.273038156570934, 43.301562493847264, 45.03931368550947, 44.234094235204886, 44.24921104984899, 45.402995847886615, 44.58754293380245, 44.05247672911614, 47.56970136396347, 44.24035826037007, 44.39151463970062, 45.57642736742574, 45.46316500632994, 48.267138004302986, 50.46150015246484, 52.38987068976126, 57.33099414456276, 59.73989817403979, 61.076959640749045, 63.98798196546493, 66.94170321187666, 58.44814008282077, 58.35801578337147, 60.1260555175043, 64.27264798072078, 66.29942294090026, 68.74447945625552, 68.38825764194613, 74.63183156905636, 47.6118197748738, 7.6435668814566835, 2.877491943297848, 2.1272065129972275, 1.119609922170639, 1.4484610696954112, 49.54520702362061, 58.17726119872063, 62.5942147931745, 68.98656814329087, 58.142481542402706, 53.61153994837115, 49.071133675113806, 33.75046560841222, 36.151011067052046, 47.35695200581705, 41.90079781316942, 0.6935237696574581, 0.07819467870097968, 0.01917176399259798, 0.023123618973899755, 0.03390113732987835, 0.0638374402337978, 0.05274827922544172, 0.0642820623432917, 0.09436161602817236, 0.016396263832106225, 0.017709650715152105, 0.030186725555047877, 0.08598858911183574, 0.02520898308214401, 0.046754993363133365, 0.08352901020477857, 0.23024518223058796, 0.2595574835375432, 0.10030802880083362, 0.18075761835901968, 0.15278974007214272, 0.13019776121983606, 0.14421148586177057, 0.14688255866208386, 0.1562026004877783, 0.19858235463259682, 0.23504323686563203, 0.20314301394166487, 0.16625169754749344, 0.1592480604566874, 0.13425977389898994, 0.08985576264920736, 0.17049547224756212, 0.3272737112016447, 35.542235682087565, 69.06007336032006, 48.85021794226862, 39.256088733673096, 47.70804335994106, 79.57663812944966, 86.68018387209985, 62.1933211049726, 78.57277808650848, 69.45772324838947, 80.79838583546301, 28.279498584808845, 0.5441651841805828, 0.7956948323595909, 16.419681868245526, 88.40474021050238, 67.1850549021075, 75.36893121657833, 67.94885020102224, 74.83960736182429, 68.31458768536969, 69.0699577331543, 66.37496779041906, 72.39881054047616, 64.91803476887365, 72.72286107463222, 69.9122553486978, 73.95741924162834, 67.11296958308067, 73.01490506818219, 60.56118757494035, 60.19340261336296, 58.91633772080945, 59.08436029188095, 49.58791379005679, 52.05073471992247, 51.02759230521418, 52.53481795710903, 50.1119855911501, 51.02587038470853, 49.552212376748365, 51.63164123412102, 51.02729028271091, 53.97915624803113, 53.50227840485112, 50.543920916895715, 47.049355814533854, 47.147391534620716, 52.018747791167236, 51.09996395726358, 52.43323249201621, 48.740371965592914, 51.94272833485758, 44.66657869277462, 45.70223739070278, 45.159342135152514, 46.77659027038082, 47.70119882399037, 46.996760752893266, 43.895397570825395, 45.1671084280937, 43.815098808657744, 50.8671046072437, 46.64570077773064, 52.32998394197034, 51.013746338505904, 61.223134609960745, 53.7170164046749, 67.3257032517464, 31.780506180178737, 31.324924845849317, 67.56895296035275, 54.44499654154624, 62.58845675376154, 51.54102271603, 50.228699637997536, 44.31279267034223, 47.205454380281516, 40.234567119229226, 43.74609255021618, 46.48531898375481, 46.061785374918294, 41.981135799038796, 43.731626849020685, 43.778620766055205, 43.938645624345355, 43.16324010972054, 48.68252485029159, 49.65829680042882, 50.78635477250623, 50.8448176999246, 50.695191044961255, 47.49802789380474, 47.22283440251505, 46.72112795614427, 44.011707613545084, 43.64058471495106, 47.83574788801132, 48.150690678627264, 48.32429478245397, 45.80110465326617, 46.93525798859135, 46.661460861083, 46.4898963897459, 51.037237413467906, 46.14943465878887, 45.76758015540339, 47.806800796139626, 48.29356693452405, 50.5833956503099, 52.31019166208083, 54.160459964506096, 59.57482522533786, 62.90598046395087, 63.3759980816995, 64.12301348101708, 66.93290141320998, 61.311846856148016, 61.30448064496441, 61.71561171931606, 67.28026651567029, 72.29930785394484, 72.3902754629812, 71.00167012983754, 76.28683643956339, 54.98261620921474, 8.863992748721953, 3.939310153645854, 2.7973557143442096, 3.60766762687314, 2.0496074446747383, 56.16091582082934, 61.77513760905113, 67.74587538934523, 69.45779385105257, 67.4774048405309, 59.21581852820612, 55.323340738973315, 39.63114576954996, 49.14293658348822, 54.684665126185266, 59.85096793020926, 1.6966100637951207, 0.20887830054327367, 0.27543775076347016, 0.1245375972000822, 0.1306158307218744, 0.17976908914504514, 0.14739243614096798, 0.3172090319135497, 0.15989935776639372, 0.06826324508555474, 0.22618713788688186, 0.13810646990614553, 0.09829212205424424, 0.28949782372482363, 0.22038895546668963], [0.07114579645736564, 0.053948896050813704, 0.05077600884701937, 0.038679740992524934, 0.02869633980275643, 0.04606984645849274, 0.024425786499294545, 0.04030513825015195, 0.03228471479228428, 0.015604521538461409, 0.060490057353050485, 0.11013931174191738, 0.05312215311512832, 0.07015862321901707, 0.024926177894456253, 0.008919087685494414, 0.11902373299122819, 0.2900735541216789, 0.15385228870136125, 3.250885649073509, 41.28238908706173, 43.198031533148985, 35.085805154615834, 22.484790894293017, 40.52972547469601, 74.22686253824543, 64.28225778764295, 63.029535124378825, 57.61293019017866, 66.15682125091553, 27.62136213241085, 0.13055468158375833, 0.31375014493542336, 29.019543932330226, 85.4213462337371, 65.05403118748819, 72.17250547101422, 65.55503945196828, 69.3136545919603, 66.58850946734029, 69.19561478399461, 62.17296008140811, 66.2785323973625, 64.56429581488332, 64.27029455861738, 66.18859244931129, 68.54892576894453, 64.72521889594294, 63.08798236231651, 54.794769979292354, 48.72270168796663, 47.838446478689875, 48.79256694547592, 46.00083566481068, 46.46856261837868, 45.43393158143567, 45.845670623164025, 45.588198400312855, 46.08368396759034, 46.200594132946385, 46.052332462803015, 48.02957181007632, 47.012289416405466, 46.0135127652076, 45.75775461812174, 44.95575543372862, 44.65859666947396, 46.65079593658448, 48.69855165481568, 44.539258556981245, 41.19823855738486, 43.96494119398056, 41.359573487312566, 42.4153539442247, 43.92256390663886, 42.05488420301869, 41.938436877342966, 41.86565337642547, 40.80110249980804, 39.75904249375866, 41.20274536071285, 43.18990830452212, 43.338785786782545, 46.635741879863126, 49.579574831070445, 58.911983889918176, 50.45241202077558, 64.56483710196711, 35.78438712704566, 24.681163257168187, 63.43363731138168, 55.77384456511467, 58.69161728889712, 50.33119117060016, 46.97662722679877, 41.802762093082556, 41.67373180389404, 38.78035230021323, 40.546113137275945, 39.26122311622866, 41.2999338488425, 39.618300007235625, 37.11845190294328, 38.765368846154985, 38.935254543058335, 40.36893967659243, 41.24356938946632, 41.50294003948089, 40.722702164803785, 43.57451631176857, 45.28068457880328, 43.69376420974732, 41.08225407138948, 42.363257023596, 38.71740610368791, 40.17965001444663, 42.042254171063824, 42.933318614959724, 42.7952786414854, 43.10825240227484, 43.461991356265166, 41.9270267025117, 42.18626006957024, 42.025423280654415, 41.3073863521699, 41.679909536915446, 43.26258197907479, 45.1518347186427, 46.81355468688473, 49.42984227211245, 54.14584913561421, 55.819457807848536, 59.569322139986106, 61.66909633144256, 56.843474911105254, 57.288840432320875, 58.93104660895563, 55.53656862628076, 62.95834802812146, 62.32454399908743, 60.92633670376193, 63.21791479664465, 64.58759861607706, 65.23098107307189, 63.689654334898925, 20.017155255040816, 4.367947501520957, 2.6781867540651754, 0.7675848600845184, 3.6754263264517633, 46.277468665953606, 53.27318453019666, 42.02385825495566, 42.649707717280236, 50.517460607713275, 46.52400532076436, 31.999164588989753, 30.49771070480347, 35.784893112797896, 51.326198424062426, 17.133422820798813, 0.5621751758360094, 0.12066761978090772, 0.08635789711749361, 0.1093759434297681, 0.05197312848101701, 0.09159033892736321, 0.05743782133645108, 0.03714522857579493, 0.01355040041098912, 0.09416196585422563, 0.062386186252678597, 0.014172700335151486, 0.04450694665372853, 0.030058124290418722, 0.022114970375813787, 0.02371451216599634, 0.019212314941649957, 0.04220108328867824, 0.03354223662867181, 0.06816603618884279, 0.0351823580962035, 0.0343588863559548, 0.0075235704313062375, 0.059651800115863164, 0.04693771682439312, 0.03142785694029543, 0.040782621701157866, 0.018439952757269628, 0.05439764354377986, 0.021797327339769374, 0.0814517168328166, 0.03820274400735094, 0.08044767433837538, 0.14725535236779722, 5.2723607517057856, 57.841741654180716, 44.22517476543304, 40.25154313733501, 34.53773629280829, 44.63802383792016, 83.14949374045096, 63.894323610490375, 70.24189918271958, 63.52555805636991, 71.1214828491211, 29.625875680677353, 0.023931782362201524, 0.2690053701160416, 32.93582070258356, 89.97934433721727, 67.86886522846838, 74.66161804814493, 69.18766021728516, 73.3279808105961, 68.96142575048631, 69.67919595779912, 64.52575852794033, 67.34138488769531, 65.21966503512475, 68.52779988319644, 70.98031674661945, 70.66968856319305, 65.09942085512223, 63.51181014891594, 57.673640635705766, 54.18560627968081, 49.15036163022442, 50.027011363737046, 48.78819742510396, 49.23748139412173, 46.191251047195934, 47.54723010524627, 47.02796712998421, 47.25280131063154, 47.870319658710116, 48.930614763690585, 50.00220237239715, 49.162740630488244, 47.17102381490892, 46.79627664627568, 45.67998186234505, 46.30956542107367, 49.57462479991298, 52.78178607263873, 49.34974747319376, 45.28850970729705, 48.075506687164314, 45.3566530443007, 42.94839620590211, 44.39391905261625, 42.52801226031396, 44.27343168566304, 42.78197003949074, 40.55176135032408, 43.536143764372795, 43.18643308454945, 45.99383031168292, 44.159933982356904, 49.631977696572584, 51.207032895857296, 60.2137714816678, 57.61646032333375, 66.14743109672301, 53.926808295711396, 32.11743189442542, 64.2974687391712, 58.10416783055952, 58.09851177277104, 52.9171549120257, 49.37740802764893, 46.350652248628684, 43.565738047322924, 42.82840697996078, 43.23543133274202, 42.16975081351496, 42.48755301198652, 43.16541702516618, 41.16083483542166, 40.735998999687936, 41.91718939811953, 42.56181524645898, 44.7935732718437, 45.63842827273954, 43.528279412177305, 46.134576720576135, 49.604356365819136, 46.73997102245208, 42.59292356429562, 44.228638218295195, 41.01976286980414, 43.036951557282485, 43.32884257839572, 43.83115306977303, 44.238495134538226, 45.47003699887184, 45.63601993745374, 43.37749173564296, 43.020069676060835, 44.16480164374075, 43.507012321103005, 44.89791616316765, 44.75646765001359, 46.520181009846354, 48.39294018283967, 53.505816382746545, 57.15105149053759, 57.68128141280144, 60.839687624285304, 63.89338616401919, 57.88502108666205, 57.882012628739886, 60.3929728077304, 59.20586747507895, 65.51677280856718, 64.92462042839297, 63.270086242306625, 63.41269185466152, 66.78891120418426, 69.16930352487873, 67.04316708349413, 24.351333110563218, 5.023140705400898, 3.080923220803661, 0.8299495039447662, 5.5458455604891626, 54.74089230260542, 58.65321728491015, 50.61198972886609, 50.35373695435063, 58.37499572384743, 51.93461687334123, 35.46734194601736, 41.683890742640344, 39.73182516713297, 60.18687578939623, 20.7610543312565, 0.6244248452205813, 0.10236934923957433, 0.1295304679942708, 0.0763409910723567, 0.04993423143581999, 0.1265776893424411, 0.008178737442640048, 0.03583171720346136, 0.007646075551277928, 0.007423924417385171, 0.06422512285831956, 0.06142483017737828, 0.1083952283126212, 0.05194191039810258, 0.05161651455226445, 0.1898877316665265, 0.19930315143879385, 0.1358637781513314, 0.14184979000879874, 0.12709220931414636, 0.22604216340809102, 0.13296269511263217, 0.14925556197281808, 0.1831660762188896, 0.12891597354844694, 0.178871693750543, 0.2014135857743602, 0.14707098564793988, 0.27359166272705604, 0.1658304717632071, 0.24514177723998026, 0.26571738203206374, 0.4140745373743196, 0.36802961941688295, 7.819937727143688, 73.58528829390004, 59.18032500051684, 52.63264186920659, 35.26830127162319, 53.52092927502048, 89.20759447159307, 74.27047929456158, 78.36415506178334, 70.64561305507537, 76.0047003530687, 35.517563973703695, 0.23725848735099841, 0.3571954507741236, 36.5470370938701, 92.85029965062296, 70.87181614291283, 80.23309384622883, 70.8747971442438, 76.38782178201984, 72.22654788724839, 72.67784795453473, 65.70504265446817, 69.53474290909307, 69.83446690344041, 72.46172535804011, 71.64592727538079, 74.09718113560831, 68.49260837801042, 66.60219069450133, 57.746667323573945, 55.113184067510794, 52.38254762464955, 54.27790749457575, 50.90751286475889, 52.60282401115664, 50.01609148517732, 49.64065397939375, 50.862025137870546, 51.90202197720928, 51.769034016516905, 52.75276837810394, 55.218123159100934, 51.215932753778276, 51.51928494053503, 52.268402730264974, 50.613001700370546, 49.3307553568194, 51.36562216666437, 53.94097589677381, 49.861353981879454, 45.9950227122153, 49.249742723280384, 46.14235478062784, 47.48641375572451, 48.31313171694356, 47.67696249869562, 48.05280400860695, 46.82282324760191, 44.74219414495653, 44.690799328588675, 44.75411815028037, 46.917874043987645, 45.55883945957307, 52.55424545657251, 52.23519202201597, 64.83946577195199, 55.425534171442834, 69.60062303850728, 37.87668135858352, 25.51471006485724, 70.59597153817454, 60.809642268765366, 63.391177654266365, 55.37599463616648, 54.07420312204669, 48.80466353508734, 45.660487682588645, 44.37032991839994, 45.04179654582855, 44.39120869482718, 45.96165118678924, 45.41144071086761, 42.35903263092041, 43.59740334172403, 44.72539855587868, 44.28229624225248, 44.43909298989081, 46.43854079707977, 46.07487040181314, 49.158739812912486, 50.39340388390326, 48.30351406528104, 44.148535574636156, 46.700566891700994, 42.38391614729359, 44.85231860991448, 45.16910883688158, 46.62899932553692, 46.50986909866334, 47.51275247143161, 46.19842898461127, 46.41034680028116, 45.169646201595185, 46.29537820816041, 45.68843064769622, 45.69405140415315, 48.000789457751864, 50.127526021772816, 52.779228687286384, 56.21569956502607, 61.23676876867972, 62.39186756072506, 63.57831393518756, 65.61192166420722, 59.628177304421705, 56.322376266602554, 60.82942278154435, 60.653735899156146, 68.23362996501308, 68.70951544853949, 66.50901871342813, 66.99792646592664, 66.87980821055751, 72.86797308152723, 70.06884421071699, 27.690884182530066, 5.678689374077705, 4.812819784687412, 1.9566097639260756, 7.230078952927744, 59.08240695153514, 63.52549922081732, 54.23202753067017, 56.6049006677443, 66.01699659901281, 61.44461516411074, 43.129021352337254, 47.964025082126746, 49.32162800142842, 66.3114724620696, 30.646223406637873, 0.6774481806543566, 0.277976167778815, 0.258729342491396, 0.3218788281083107, 0.20324421415646232, 0.28760580105646966, 0.21797386328539542, 0.17154884314344776, 0.15947813198210734, 0.22137700970615112, 0.17715841471668214, 0.2165761205457872, 0.20401022547195036, 0.13935186840113134, 0.10449951033919089], [0.039940059049836094, 0.001532574573385289, 0.054913335630009254, 0.05399632838464553, 0.0348649142430194, 0.03795783335883771, 0.09568580666617041, 0.020668326328778942, 0.06371431458260744, 0.010878905304707589, 0.08491588215674124, 0.041484335257161054, 0.07487316660943531, 0.07125071985947509, 0.09095978727864643, 0.10932377284212459, 0.0791500209860744, 0.051445382001299056, 0.07222489258574863, 0.16005015451340907, 18.56400339834152, 54.29187897712954, 29.56809916803914, 34.42180279762515, 27.80711381666122, 65.53017554744598, 71.39313836251536, 60.10060717982631, 60.01267156293316, 62.34686620773808, 37.98885330077141, 0.19639244633576564, 0.5376088811505226, 47.844863476291785, 81.99525786984353, 65.35701859381892, 65.93756075828307, 63.71649511398808, 72.96326314249347, 66.76389432722523, 67.01104287178286, 67.0990373242286, 68.41367460066273, 67.46887760777628, 67.40721794866747, 63.40149741018973, 61.21014764232021, 57.099754733424035, 49.37812189902029, 49.966748068409586, 45.94099206309165, 44.269662287927446, 48.74846773762857, 45.27389103366483, 44.97221369897166, 44.63079883206276, 45.06983364782026, 44.41329556126749, 44.27742858086863, 47.65618570389287, 47.701222358211396, 46.16020548728205, 47.03366241147442, 44.25019948713241, 44.76242180793516, 44.538595676422126, 44.95934832480646, 46.94573463932161, 46.072211034836315, 46.38243521413496, 41.232567141132975, 42.21754489406463, 39.9981148781315, 39.787209033966064, 41.81594910160188, 43.17975328814599, 44.74512023310508, 42.956154654102946, 43.61846254717919, 43.248555583338586, 42.60513390264204, 45.02256516487368, 46.77514291578724, 50.9475524194779, 54.34410533597393, 57.736520151938166, 55.70798796992148, 64.00600525640672, 46.11839302124516, 22.81849830381332, 55.69308296326668, 59.85802035177908, 60.2919247073512, 55.21653459918115, 51.5543979983176, 46.11907551365514, 43.90676459958477, 44.16233055053219, 40.36696672439575, 40.22077998807354, 39.44295437105241, 38.248726014168035, 39.69528828897784, 39.95507078786051, 39.65709224823983, 38.80068978955669, 40.27822309924711, 39.3567681312561, 39.875901668302475, 44.12529945373536, 44.605244590390114, 42.74886523523639, 42.91288306636196, 42.37007018058531, 40.603254225946245, 39.52223331697526, 41.524128683151744, 43.65870606514716, 42.574790446989, 42.481536096142186, 41.667432477397305, 42.506247028227776, 42.46917278535905, 42.5302872350139, 42.990208671938994, 42.35063875875166, 41.490058975835005, 44.048322939103656, 44.79963333375993, 50.083489571848226, 50.77237936758226, 55.98879829529793, 59.684710425715295, 60.55019709371752, 55.28709019384077, 61.83294157828055, 59.84925385444396, 59.600116668208955, 61.659835615465724, 59.61652002026958, 61.65501110015377, 58.65524515028923, 61.327179401151604, 66.77287655491983, 67.54898809617566, 43.17259888495169, 8.059607292375258, 4.454171003833894, 0.40918214667227965, 5.751415510331431, 48.723650901548325, 50.96064136874292, 41.674759464879195, 53.008142132912916, 57.440432194740545, 53.86194013780164, 27.531220182295773, 29.263130964771396, 30.199347772905906, 53.59488164224933, 3.4505134532528543, 0.13296733760545332, 0.05162019560474062, 0.05236735732685174, 0.02236840183726482, 0.05500709330062232, 0.08857557610157998, 0.06527298941246926, 0.07786633341663307, 0.03465381871548391, 0.10918102001831417, 0.015070190533034265, 0.05170039351909392, 0.06052037528265388, 0.02380811853424436, 0.06280921234358704, 0.05821826191799295, 0.06509734843406947, 0.10418048068400353, 0.019044715971235308, 0.09992815644269991, 0.04292943755224828, 0.04872961563148326, 0.05994809994233712, 0.01181051227068829, 0.04688297218132404, 0.020838604691708763, 0.007504822823384236, 0.014598740024432061, 0.08211335632950068, 0.0168809887292164, 0.023790827929793347, 0.042833898727211266, 0.09892623601180893, 0.06164138025093464, 0.11053783068012808, 23.363848963091453, 65.02722570973059, 27.546311501533758, 46.839375649729085, 34.673469912621286, 75.31608120087655, 77.3098611831665, 67.82589958560082, 65.41836054094377, 68.4814453125, 41.17091532676451, 0.174157127377487, 0.46526876128008293, 49.85644317442372, 84.94937527564265, 69.04886322636759, 70.23707466740763, 67.2482285961028, 75.45291700670796, 71.21241123445573, 71.38289313162528, 69.92098654470136, 71.89138920076432, 70.63611307451802, 70.3513882237096, 67.04170011704969, 63.13712181583528, 58.883370199511134, 51.87990373180759, 49.35042996560374, 48.558401446188654, 47.81160569960072, 50.36833601613199, 48.33083337353122, 48.3090171506328, 47.18253597136467, 48.24331352787633, 47.317147793308386, 45.27908425177298, 49.670946444234545, 49.48455933601626, 48.23591986010152, 48.859961109776656, 47.87005685990857, 47.860478431947776, 46.31235422626619, 47.7459099215846, 49.442487993548, 50.57095781449349, 50.10020671352264, 46.17092924733316, 45.923796392256214, 44.02676951500678, 43.123027970713956, 43.41606040154734, 44.25252153027443, 45.32162235629174, 45.90060341742731, 45.54360889619397, 47.007582572198686, 47.873304582411244, 48.84047085239042, 49.88544910184799, 53.518042410573656, 56.2160211993802, 60.79163074493409, 61.13141390585131, 63.59323463132305, 62.9692090711286, 32.499623721645726, 56.155487260510846, 63.95989387266098, 60.78744557596023, 57.165328917964814, 54.23729527381159, 50.56380341129918, 46.24579552681216, 44.83120056890672, 42.10620841672344, 42.970279109093454, 40.90614357302266, 40.49997037456882, 42.407348386703, 42.332972403495546, 42.07554332671627, 42.65711707453574, 41.79061059028872, 42.702710705418745, 43.21344644792619, 45.90305489878501, 47.36051351793351, 43.99035815269717, 44.63054780037173, 44.546267832479174, 43.28748510729882, 41.95913914711245, 43.34641871913787, 43.95338589145292, 46.099863744551136, 43.89415810185094, 43.565773348654474, 43.35081177373087, 42.37064284663047, 45.551598764234974, 44.47010717084331, 44.66229546454645, 43.68803362692557, 45.70813663544194, 46.81865376810874, 51.66735049216978, 52.400312039159964, 59.25644643845097, 60.96797266314107, 62.882312882331114, 57.01126606233659, 60.161666716298754, 61.62287512133199, 62.22242509165118, 62.87349539418375, 63.66390789708784, 62.632171569332, 59.97692308118267, 63.612160067404474, 69.54931059191304, 73.57377221507411, 46.42256106099775, 8.653227129290181, 3.5390589987078025, 0.5158406459996777, 7.860169968297405, 54.18301359299691, 55.891790236196215, 45.732886791229255, 55.82535313021753, 67.4451708024548, 58.09936292709843, 35.326697518748624, 33.26408386230469, 35.97910534950995, 58.14219520938013, 3.201181619398056, 0.1042989025553388, 0.03031435197279338, 0.009182894850269923, 0.01666294095376807, 0.1138295189687802, 0.04914888023068348, 0.0787384555705132, 0.019915859447792172, 0.024709629736119704, 0.06906596733437431, 0.027384707261057153, 0.05615893330785537, 0.030210301910917607, 0.02690171180743604, 0.011300186630368475, 0.13457679640381567, 0.13980105639465396, 0.19589183852076533, 0.16675261179766349, 0.248280301569931, 0.1708927501233355, 0.15108044469548812, 0.1337539873296215, 0.2757829806256679, 0.12015218050369333, 0.13516935009148814, 0.11843895509598718, 0.18931835979944278, 0.21130732020303128, 0.24577346269882497, 0.20620465368753482, 0.16763281617914477, 0.3212847728883067, 0.17108923635415493, 0.24911621074763038, 37.39127628264889, 77.86918332499843, 49.22849524405695, 49.9157533337993, 39.16456414807228, 81.42024624732234, 82.49568954590829, 72.07305769766532, 73.76490931357108, 75.55196469829929, 45.738025096154985, 0.3070594087964104, 1.0084117083780229, 55.64370816753757, 89.2562867749122, 72.73102744933098, 74.19899017580094, 70.81423574878325, 77.64683984941053, 74.7428503344136, 75.04277829200991, 72.3098982534101, 76.02242162150722, 72.61515278970042, 72.16989317247945, 69.26222447426089, 67.53305542853572, 62.519991782403764, 52.76071510007305, 50.79703538648544, 47.78149366378785, 48.95372929111604, 54.828608266768924, 49.87200321689729, 51.027470711738836, 49.67027964130525, 51.27953790849256, 51.63110386940741, 49.529960770760816, 53.71291752784483, 52.382512323318, 49.702662729447894, 52.82280229753064, 51.079799052207704, 50.8773341486531, 49.39035577158774, 48.97891482999248, 53.68371548191194, 50.66056436108005, 52.87423241523005, 48.64110854364211, 48.30732268671836, 45.8872163680292, 44.35325584103985, 46.51036331730504, 48.21544508780203, 48.91482330137684, 48.33752101467502, 48.582896647914765, 48.40063587311776, 47.36288655188776, 50.19130768314485, 53.519062226818455, 54.63297220968432, 58.580861322341434, 62.78301415904876, 59.59318976248465, 66.6034693871775, 46.92225140909995, 23.865635818050755, 59.691056820654104, 64.86726360936319, 66.09993119393626, 57.522048873286096, 55.32272492685626, 51.59703416209067, 46.62457096961237, 48.158582487413966, 43.45326800500193, 45.48058032989503, 44.985479154894435, 43.24160906576341, 45.160750266044374, 46.156204669706284, 44.43857915939824, 43.90383458906605, 43.75605537045387, 45.57888277115361, 44.07996469928373, 48.550395888666955, 49.80566809254308, 47.441965456931825, 46.27684500909621, 48.10092364588092, 46.88514578726984, 44.463152808527795, 46.942102524542044, 49.36289525801136, 48.23832819538732, 46.821634769439704, 45.69792278351323, 45.01153545994913, 44.89300143334174, 48.245427685399214, 45.930797823013805, 46.47410100506198, 45.76315572184902, 49.222337122886415, 49.241215490525775, 54.675416177318944, 54.97676403291764, 62.73261954707485, 63.86400761142854, 64.73598580206594, 56.91403442813505, 65.0099241349005, 63.45112323760987, 65.03670607843708, 68.20054085023942, 67.72421606125371, 67.41161100326046, 62.677984852944654, 62.97861099243165, 72.5857271686677, 74.18123752840104, 48.91493705011184, 9.228632950013685, 7.425964570814564, 1.5660647591275554, 9.554601523184008, 59.10195604447396, 60.212543779803866, 53.02425522958079, 66.30634200188422, 70.05419808049356, 67.14853763580322, 39.88725300758116, 42.95902975143925, 41.514805209252145, 71.35164753083261, 7.324599739043944, 0.39926008231216864, 0.19650188965662835, 0.23760630659038023, 0.2760121328455787, 0.20706558329684122, 0.24713857009285883, 0.14688320217594025, 0.15979996551909756, 0.17132300042336987, 0.23898089815291668, 0.12772245452769343, 0.2010125847112748, 0.08020713039103054, 0.13759579569582017, 0.19626961179798652], [0.025931231624957536, 0.013319317649509157, 0.07951472480330737, 0.04109440033414191, 0.021706955777781627, 0.038083330052153724, 0.036786576853163784, 0.04768352640131789, 0.01760051765989873, 0.08919725645213358, 0.09409981314092876, 0.001948413921655306, 0.1408709288244286, 0.03476951714424837, 0.0634443260458929, 0.030548550796905355, 0.04936514302126823, 0.06578297414366277, 0.043952184083360823, 0.10529244198433815, 0.39090727245615375, 49.07934711825464, 39.736449641566125, 25.727386859155473, 22.82562525041642, 29.416234800892493, 67.76915073394775, 69.73214795512538, 63.836523563631125, 60.65476748251147, 53.85351096430133, 1.7658716440200808, 0.5666690475998387, 49.45459635026994, 79.95332687131821, 68.34849265313917, 59.792179446066584, 56.920345521742306, 62.47446875418387, 68.76186340085923, 69.25685082712482, 68.46783468800207, 67.33284196546002, 64.51007296962123, 59.96235147599251, 55.30413289223948, 51.668425221597, 48.2540294431871, 49.37711384988601, 52.46705116764192, 47.892622255509906, 45.70150390748055, 46.98833942413331, 49.40858694814867, 43.3484975753292, 43.77711457590903, 44.498344313713815, 45.386098277184274, 44.539329159644346, 45.9747911268665, 45.49465771644346, 46.75034961392803, 45.990127594240256, 44.87254627289311, 47.66770178271879, 46.77592346745153, 46.129030489152484, 44.338668546369, 45.23210210184897, 43.47524504507742, 40.87801233414681, 40.26901729645268, 43.42403065773749, 39.49358824760684, 43.33574202752883, 41.41968773257348, 44.34932170375701, 43.318087439383234, 46.22237505451326, 43.43587229328771, 41.00987065222956, 42.71400713151501, 49.50549302562591, 52.28046009617468, 58.853022821487926, 59.71223761958461, 59.7151009498104, 57.40059268090033, 52.75788314880864, 27.751869193969238, 45.6937611487604, 63.19388635696904, 62.19308184039209, 57.89969859584686, 51.457080071972264, 50.265499314954205, 47.77771249894173, 44.965192656363214, 42.725103516732496, 43.40912565108269, 41.36909700209095, 42.198588079021825, 38.32731854531073, 39.12445399069017, 39.43307784295852, 39.347385821803925, 40.08040228197652, 39.30894659411523, 40.026689344836825, 40.93155268699893, 41.18484758561657, 40.390116553152765, 41.016346485384055, 43.489789193676366, 40.2991646335971, 39.89816111903037, 41.38746938397808, 42.83261960552585, 41.81671788615566, 40.6299537997092, 42.31098359630954, 41.093221018391276, 40.3309593662139, 41.81083040852701, 43.07718330813993, 40.84632350552467, 42.27081068100468, 43.20526046137656, 44.46300768083142, 45.38828695974043, 51.088498869249904, 54.33893172971664, 61.239055510490175, 59.307802031117106, 59.65907381426904, 59.46018611231158, 63.72028020120437, 56.96564105249221, 60.507439336469105, 56.470041736479736, 53.22096993846279, 53.49350406277565, 62.48770675351543, 62.4752296939973, 71.55433208711686, 51.78748092343731, 11.802222594138115, 2.947104453079162, 0.0359923160454679, 5.0567573789627325, 50.281973269677934, 51.794705929294715, 61.59938404636999, 54.319829786977465, 73.25704866839995, 32.02496593998325, 28.75478198451381, 40.34894343345396, 52.566165539526175, 24.542244672775272, 0.241832920920945, 0.02188008590300958, 0.01911943252649038, 0.04305930860761193, 0.07956286576846916, 0.0687813809922626, 0.03343767711832639, 0.04662824028562154, 0.04563504942662774, 0.04122890622144745, 0.09939104453810763, 0.07223577103427342, 0.10105750793891569, 0.04907801709768753, 0.05349948206135342, 0.019521825954378135, 0.0402151765452037, 0.025901566785309586, 0.0811260375344465, 0.05748198630528585, 0.03730085167673327, 0.031217366622220126, 0.04779982237866329, 0.05023511246808114, 0.018760541401382898, 0.07565761000038156, 0.056011821443755785, 0.04230743544476648, 0.02968973559026997, 0.0478816137558991, 0.0955721038964487, 0.10270936970388699, 0.015563210247144585, 0.06252634586886534, 0.07324138400895942, 0.045886104100293694, 1.0068236387545064, 60.65614815681212, 42.895150030812914, 32.3352313041687, 30.914693955452215, 37.70354793917748, 82.26717225966915, 73.2867802343061, 72.22722253491803, 66.98348429895216, 62.341280752612704, 1.8397461767158203, 0.5783854737397164, 54.857845614033366, 86.31510534594136, 69.12933457282283, 65.53301142108056, 58.852689420023275, 66.65941807531541, 71.00724774022257, 71.4443096037834, 69.43205525798183, 68.14711816849248, 66.55460449957079, 61.40103370912614, 59.46528519353559, 54.26036665516516, 50.67724227905274, 49.79774882716518, 51.69425010681153, 50.87928748899891, 50.13095025093325, 48.4835155548588, 50.149934522567264, 47.683606993767526, 45.33780605562272, 47.420945475178385, 48.18985946716801, 45.95266503672446, 47.64471669350901, 49.23261765510806, 50.114440994877974, 49.21106423101118, 46.83207611883841, 48.54002906430153, 50.48111200332642, 49.30507559930125, 46.7576648342994, 47.35444168890677, 48.56207670704011, 44.127252794081166, 43.57644611789335, 45.92333355257588, 43.78149586339151, 44.65701987666469, 44.26659107208253, 44.555179457510675, 46.15059960273005, 49.417286765190866, 47.47591357077322, 44.38212448550809, 45.97393997253911, 53.85480142408802, 55.98244013324861, 58.39111274288547, 59.61946179789882, 65.38560482763475, 57.39668992257888, 71.415801817371, 38.029708708486254, 46.454340104133856, 68.01499705160818, 60.8533178606341, 62.15986328740274, 54.68544175547939, 53.38278731992168, 50.63778715748941, 48.57212189705142, 45.63607485063615, 45.7856858161188, 43.228123957110995, 44.35995132692399, 40.55744486470377, 42.16079604241156, 42.153339616713986, 41.41065843643681, 42.28909284837785, 42.884665535342315, 41.98258707600255, 45.993928370937226, 45.889259922888975, 44.46016788482667, 44.24775585051506, 45.73535788443781, 42.642631761489376, 42.35290981108143, 42.72724120847641, 44.835275911515765, 45.17830287256549, 43.97240938678865, 44.306940494045136, 42.97089099884034, 42.60344728346794, 45.56607623254099, 44.67336047080256, 44.52682856590518, 44.47524547576905, 43.407870492627545, 47.79743809853831, 49.107525425572554, 53.5379719734192, 57.84934712994484, 64.26104560975106, 61.70912019668087, 63.17350572155368, 61.21556835789835, 64.86368248539587, 59.702161050611934, 62.47567684419694, 61.460889077955684, 56.444644389613984, 55.78181482130482, 62.23708298898513, 67.59649584370275, 72.38287787283622, 54.08140851605324, 12.452334857756092, 2.541910376279585, 0.7972292758284077, 6.905912218555328, 56.81495535758234, 57.06486917311146, 65.40190227570073, 59.40703015173636, 77.26301239382836, 38.45746670999835, 36.96191403173631, 42.88460277741955, 58.255073178199034, 27.22834260232987, 0.20989661525574424, 0.11750197593843746, 0.025908490304925272, 0.012785227004168256, 0.01869516154270499, 0.055315095120139664, 0.03295243702708714, 0.055916746101912954, 0.05279122611447688, 0.06314905277723748, 0.05692694028238616, 0.17670806226951463, 0.03365837938843235, 0.04605266310635113, 0.08008428053149293, 0.034395218075763796, 0.09670065866122324, 0.23665093366176854, 0.2229423724835919, 0.152956057760504, 0.11125164076445565, 0.13157586146506572, 0.15972501147658597, 0.1823054990100284, 0.06615409011682195, 0.20125128238672213, 0.17183845502234277, 0.12134308716462505, 0.19082857956809385, 0.09597879699281148, 0.17374560026632202, 0.15951085925823258, 0.1186192921933628, 0.23691557107433198, 0.1947379109239386, 0.2788313364069308, 4.982510343674691, 74.28015970414685, 57.255998426868075, 46.18369656224405, 36.04800178158668, 40.43825972464777, 82.05069664985903, 81.6096967266452, 78.94370094422372, 72.01953303429389, 67.30272600727697, 2.342072480147885, 1.3091827304132524, 59.00612077405376, 86.25000969056161, 74.95476030534314, 66.06343746185303, 60.886324605634144, 69.66716212611045, 76.09387936130648, 76.03163134667182, 75.81672468493062, 69.37281962363951, 69.63395534023162, 65.80592993767031, 62.377327334496286, 58.43796153222361, 51.77875757217408, 53.50721666889807, 55.26634477799939, 51.072950593886844, 50.944394911489184, 54.19488268513834, 54.74455971871653, 48.12556397530341, 47.683963929453206, 51.43758589221586, 51.29549803272371, 49.50121764213809, 49.16154822995586, 52.026184605013945, 54.82216381257581, 52.246488448112245, 49.84946920025734, 53.54369078913043, 54.33080065634943, 51.96667048238939, 48.154095295936834, 49.81621534593644, 50.14497272429928, 45.705434122393214, 45.19825596963206, 50.68285911313949, 44.09647395533901, 46.86409050418485, 47.372166879715465, 47.69595853744015, 48.90912801988664, 52.14920974546864, 48.69801821247224, 43.85827233714443, 48.01024629223732, 57.24830273658999, 58.093314632292724, 61.70848085034279, 63.19716938080327, 66.91783951174828, 60.31888315754553, 59.61040504517094, 25.44390736087676, 46.88356114972023, 67.34911195693478, 65.80126231716525, 65.39843097809823, 54.63848706214659, 56.043240793289684, 52.469765447801166, 48.95039919883975, 47.72184225820726, 48.489759968173125, 46.294581967015425, 48.23553154545446, 43.22330336416922, 44.320739392311346, 44.15109688235868, 43.439229842155214, 46.43566569974346, 45.483188706059615, 44.94560826209284, 49.00002894863006, 48.26337252893756, 45.569425936668154, 45.040729661141675, 47.713699417729536, 45.031849415071555, 43.59991758100448, 45.536493716701386, 48.04340600967408, 46.67752296693864, 45.41626914854973, 48.628141187852435, 43.590448979408514, 42.91211035943801, 48.19110678088281, 47.619193830797755, 45.82307777097149, 46.7136440738555, 48.194083859843595, 49.66771833358273, 52.24360942840577, 58.029458445887414, 58.960240810148186, 67.66633756699102, 63.702778585495494, 65.58498282586375, 64.25413831587761, 68.95893896779707, 61.172304614897705, 65.58189984290831, 65.78908335778021, 60.10256836491247, 58.36751576392882, 65.40302799594018, 68.43123897429436, 75.8607493677447, 55.83029531663465, 12.855300538001522, 6.576805749247152, 0.7884248418192711, 8.279069296775326, 65.92922179929673, 61.94496054803172, 75.88970430435674, 67.67517074461907, 86.2886058130572, 45.51516779007451, 42.788645913524014, 54.465698811315725, 67.24538880009806, 42.950063213225334, 0.2001444079102047, 0.32092247458715595, 0.11383110477078347, 0.15156910153886965, 0.2212854621991996, 0.14443285462837066, 0.17499110601361723, 0.08798110719409682, 0.14042388587709398, 0.22778355786877297, 0.3017116247886612, 0.30553952099815496, 0.20616677830055838, 0.12551730108116904, 0.1796399880080454, 0.18213633147458877], [0.010298244174449675, 0.03801544700118323, 0.04491814051664645, 0.004259432100826094, 0.01975386824098326, 0.0850967248721469, 0.056574635598207676, 0.043978300020699544, 0.07021155989458484, 0.05237039103503189, 0.018352896440774202, 0.09684616940156107, 0.0408767853983708, 0.04067838394774064, 0.04435167212279574, 0.05219234454054987, 0.0469306611546105, 0.006037963152442489, 0.059716863963272304, 0.03716014813812029, 0.3631015596610885, 20.3511489975837, 52.29946397965955, 62.9149313126841, 40.292971211095015, 28.00313818839289, 57.8679980001142, 56.73580584987518, 74.58276271820068, 55.00338123690698, 72.40764371810421, 4.994944257120933, 0.09277072720109455, 47.84694233248311, 74.99532545766523, 70.16415780590427, 66.617935088373, 60.552185735394886, 52.729846046816924, 55.23502465217344, 52.029483318328865, 54.810318254655414, 49.0905023390247, 50.735571845885254, 48.436968788023925, 46.150995762117454, 47.86667577682003, 51.865771432076734, 50.127757441612985, 51.1926927105073, 45.86329775471842, 47.71960650720904, 44.92169357115223, 47.437897959063136, 46.368393128918065, 44.67818106374433, 44.76983900993101, 44.57013545497772, 44.56365569945305, 46.60907368506155, 47.32493369810043, 49.61802974823983, 45.79185178202968, 45.25198851862262, 45.83812006058232, 48.67168734150548, 46.671058900894664, 44.34864705608737, 45.66646929710142, 42.734787848687944, 43.124008563257036, 41.06727846207158, 42.67681521754111, 40.86421735825078, 43.13491667470625, 42.281185350110455, 45.911276186666186, 45.72482239815497, 46.47167305792532, 43.72249164888936, 43.67897295182751, 44.50503587722779, 51.8212446858806, 59.336560849220525, 60.05108725640082, 60.50639990837344, 60.50224219599078, 56.617322814080026, 57.28050931807488, 31.397482810481904, 36.5466134778915, 63.08971604993267, 57.66184606859761, 59.341538336969194, 55.00123177805255, 54.622978010485255, 54.22326103333504, 47.831794138877626, 44.02507112872216, 43.88127311583489, 42.78036971246043, 39.85243020519134, 38.92373061949207, 39.4950238350899, 40.55995518161405, 41.75759600054833, 42.44387349774761, 40.62014787427841, 40.29318301908432, 39.34036870156565, 42.04129319037161, 44.4376495576674, 42.4730755436805, 41.93969203579811, 41.34974010529057, 41.67705405143, 42.61998007374425, 44.502121556189756, 43.10383581346081, 40.88189940298758, 42.73140676559941, 41.00450092746366, 40.712590294499556, 42.60407486269551, 43.393232207144464, 42.31302715116932, 43.91044770517657, 45.59729437674246, 44.83937086597566, 42.797024096212084, 45.29449916655018, 48.02675162592242, 57.79515174127395, 61.09668524034562, 62.58802529304259, 63.08658207616499, 61.439653365842766, 58.41327413435906, 54.993214453420336, 49.89740840850338, 51.821860497997655, 52.33880927485805, 62.13468167089648, 64.35045211545884, 69.81816553300428, 58.200764040793146, 12.222624190392034, 0.5845740545661219, 0.6977994595804523, 9.568560258034738, 50.607212281996205, 54.481941346199285, 51.499700546264656, 54.010852921393614, 56.94254221454744, 30.756955838972527, 39.96663001275832, 38.017066909420876, 40.008116922070904, 1.6830661195901133, 0.05681950411188507, 0.11209731756318962, 0.029620471665815964, 0.016296488540847937, 0.025276272414973187, 0.03159135734031518, 0.03048856036677476, 0.06012882008367489, 0.03353955915137645, 0.0588533373159026, 0.025718887374105475, 0.06536966204763421, 0.036636496398357615, 0.02545349728015642, 0.04200403398323444, 0.145410428785028, 0.04367761434085908, 0.021703374316735614, 0.029641213496365858, 0.18023795027646328, 0.08674987366483097, 0.10376084070172041, 0.07699904527755515, 0.0815079323647003, 0.013562023880020266, 0.018706229597991033, 0.03781634074966273, 0.08215047328943208, 0.028797561084971796, 0.08025092763766166, 0.04347017305272241, 0.057335946964280265, 0.05915758530459097, 0.0783755673816608, 0.07237135327511257, 0.024584449054072463, 0.14533768107573833, 25.28940127741906, 63.497771986069225, 50.34931252079625, 52.571319533932595, 33.911161192001835, 68.17000127607777, 68.51822929997599, 78.64474573443013, 63.9087579327245, 76.85024569111486, 6.468495380493903, 0.1339588085970571, 51.80288407110399, 77.27074730780818, 74.88022742732879, 68.77961604825913, 64.47990602062595, 55.31177366933515, 58.91010115223547, 56.59214119757376, 59.12457635325771, 53.36592897292107, 53.243880502639286, 51.49750794133833, 49.10208902051372, 49.18940098054948, 52.55260590584048, 50.02826652219219, 49.73230015846991, 48.7913941567944, 49.76849186804987, 47.24199910317698, 49.29213570010278, 49.6439762269297, 47.94855525416713, 48.621116222873816, 47.78112888336182, 47.92522107401202, 50.85083461576893, 48.241128767690356, 50.73388130434098, 49.03360051493491, 48.79334357477004, 47.741316826112815, 48.22904002281928, 48.9275945386579, 47.043507560606926, 48.32723263771304, 47.52038540378694, 46.0944704855642, 45.925345728474284, 46.889397636536636, 44.878657325621575, 45.597215929339015, 42.832678441078436, 46.99056733039118, 46.53362689479705, 48.03596919582736, 46.538153309975904, 46.88931918913319, 48.10008818103422, 53.734423883499645, 60.1686877589072, 61.42605058608517, 60.985537036772705, 66.74127794081166, 56.934273858224195, 70.34755214568108, 46.541232370561175, 40.539656915972316, 68.66192140886861, 60.60354132806102, 63.7055830801687, 55.31245616174514, 57.83110810864357, 55.24097488772485, 49.51540093268118, 46.23975507674679, 45.30752535789244, 43.91788059665311, 43.78258235992924, 41.94502645923246, 42.20418137888755, 42.47181254048502, 42.66401652366885, 43.59981559938, 42.92364605011479, 43.01382526274651, 42.635445979333696, 44.72414339742353, 47.27809667587281, 45.985601179061405, 44.30903896208733, 43.85529918055381, 42.75614907664638, 44.671207089577955, 44.69702805242231, 45.74226910068143, 42.74695896333264, 43.698557346097886, 42.739867318061094, 43.26817920131069, 44.68496284177227, 45.25501658839565, 45.23032526816092, 46.54541753953504, 45.8051250826928, 45.27881360823109, 45.13796129534322, 47.329844505556174, 51.22118088506883, 58.722843277838926, 65.01389749588506, 64.7680119545229, 63.1801345271449, 63.291392557082645, 62.427957288680545, 57.32211389849263, 53.41475463682606, 54.70443387185374, 54.93018588712139, 63.70904261066068, 68.97083159415953, 70.7112813765003, 60.93166328245594, 11.572733540688793, 0.6812762300814352, 1.47602160371119, 12.435862864217452, 56.93923957886235, 58.4484617171749, 57.68625497817994, 62.72046412191084, 62.10021972656251, 37.37002095868511, 48.95213288645591, 41.433545466392275, 44.671811134584495, 2.545684922126032, 0.17498183634973344, 0.13048898188337205, 0.03075893769311088, 0.02805192196261018, 0.021733625213645642, 0.02152349304167494, 0.031165739957002864, 0.03128563463237257, 0.09462282902771428, 0.040124977352998914, 0.03743066144506297, 0.07079882757557977, 0.09983439494164721, 0.02835445199912835, 0.026383868929359223, 0.04616396419043022, 0.147343942775361, 0.09361232075119212, 0.18280930907255222, 0.17982892061193145, 0.14979228317256899, 0.21122199333002492, 0.17344642761013201, 0.26126687084474876, 0.1872911072906948, 0.21378792822360995, 0.11647233844644601, 0.18339355836712545, 0.07743387678337675, 0.19591446875804858, 0.1933931814686906, 0.18793532594798074, 0.14293861545382008, 0.17999554473546245, 0.15543697221625238, 0.1968649846892203, 0.36399009907918595, 42.470267126637125, 72.77578953773745, 71.51623802800333, 56.45874531038346, 40.279654764360004, 78.23080232066494, 74.36183914061516, 88.1130256960469, 65.26182659210698, 87.59440206712293, 7.876922901599639, 0.13658820621428952, 57.30051340595369, 80.69972253614857, 78.10683188899871, 72.69272158222815, 69.36549263615763, 59.86490803380167, 63.24847006028699, 59.38446083376485, 61.56119977274249, 55.783430837815814, 54.97619921161283, 55.206971860701046, 51.467184097536155, 53.26059372194352, 56.0140936605392, 54.89817934651529, 53.10122782184232, 50.49680540638585, 53.013166689103656, 49.582693115357436, 53.50563987608879, 53.03123704848751, 48.93738085223783, 51.960649644174886, 48.17325999659877, 49.94235484830795, 51.9099255531065, 50.596653261492335, 56.34035248910227, 51.7299162187884, 53.35658588717061, 50.19565366929578, 51.487866755454775, 50.59398604977516, 48.463040782559304, 48.89286587315221, 48.876293859174176, 50.04828629955169, 49.06497947631344, 48.54475159798899, 46.71442854788996, 47.35581451846708, 46.85818733707551, 50.65134679117511, 49.57575836489278, 50.550247699983665, 48.89614497461627, 48.943825306430945, 48.518522708646714, 56.30749087179861, 64.85362552827405, 63.08726456857497, 62.35076896605953, 66.42391112542921, 60.52388583460162, 64.50100837215301, 29.397195616076072, 35.82257140067316, 69.6677504816363, 59.49440486969487, 66.79474769100067, 57.17151841809673, 59.50523061137046, 56.43452075219924, 52.43782558748799, 48.28383945649671, 48.664121089443086, 47.197668475489465, 46.32033624956685, 43.98884411781065, 45.357802298761186, 44.158953389813824, 46.02640167359383, 46.400909577646566, 47.048767459008005, 46.44622079787716, 44.3183232122852, 47.48673539007864, 50.52714101729855, 48.1094979470776, 46.042048008211204, 45.19475329306818, 45.686963681251775, 47.52126401470554, 50.13504128302298, 47.81866596591088, 45.05685844729024, 45.27951571249193, 44.19834183108422, 44.06813483084402, 48.690667690769324, 49.46741857836324, 47.27606096575337, 48.708741972523356, 49.79557191171954, 48.08131179501934, 47.20242238813832, 49.84766883234824, 52.64258115522323, 63.078262729029504, 67.95430229556176, 67.78632287056216, 68.16556899778305, 64.89803852573519, 64.09780833028978, 61.84652474618728, 57.27456300489364, 58.717940315123535, 55.7039047825721, 66.01045408556539, 70.58650293657857, 74.43473246789749, 62.191881595119355, 13.992541759244858, 2.202526806823669, 2.0250931213940344, 14.101541484555892, 62.90358389577558, 66.54442202660346, 64.99156352012389, 68.39664366937453, 66.05349817583638, 44.61134387600807, 59.2005055950534, 48.6317301565601, 63.70004861585556, 5.344058246381822, 0.2899874764825067, 0.24365398852575212, 0.08744650039701693, 0.1536196737640327, 0.09855412412434818, 0.10773890546613163, 0.116391439561642, 0.132169135275387, 0.12965808292069744, 0.17082933336496356, 0.12131491811164927, 0.1491687795327556, 0.2030266145424497, 0.12429987245629873, 0.24844717084159776, 0.2261861266508218], [0.05813352876312791, 0.04084554816325826, 0.03070106549609092, 0.029107815202986522, 0.024614146452457197, 0.06076299149783389, 0.03690150536356434, 0.07315177470445633, 0.04829053999856115, 0.013919143426802852, 0.060035993209889824, 0.056862382053007046, 0.044783086876475045, 0.044684882065461534, 0.16197387790006978, 0.04257089691236616, 0.0610581919881365, 0.1012384502457515, 0.11661600291488633, 0.3304829760905235, 0.09554138377068505, 1.123383487424543, 41.67774046621015, 56.91419132294194, 31.503863373110374, 26.347172337193644, 47.75042456965293, 60.18404383813182, 71.69896556485084, 54.951194101764315, 75.03756153968074, 21.26129577236791, 0.5727018367859625, 26.533853623174853, 78.41342787588798, 72.30923145048081, 69.71423056817824, 67.71524952303979, 56.692381289697465, 53.17542729839202, 52.984447094701956, 50.04364221326767, 48.41347379069175, 50.640352387582105, 47.59319636129564, 48.947214234259825, 48.71630037984541, 48.65485645109608, 45.96678164697463, 50.10900851218931, 47.41566596492645, 44.44627484967632, 47.00605677020165, 49.051400230776885, 46.81595517743019, 46.04050259436331, 46.90834268446892, 46.58538649159093, 47.47766687024025, 49.40931258663055, 49.623560290182795, 48.61639761155652, 45.41313125241188, 45.68885034130466, 46.577137747118556, 48.25207218047112, 47.41983936678979, 47.069018656207675, 48.02138974589687, 44.94159567740656, 44.584189307305124, 40.588333529810754, 42.64330640915902, 42.94101038286763, 44.198922341869725, 43.0667733377026, 43.91657052501556, 46.978396215746486, 45.843246598397535, 43.923528809701246, 44.04612248943698, 47.10711271532121, 51.320440384649466, 58.57185163805562, 58.70365504295596, 62.95089160242389, 61.387152441086315, 59.73750552823467, 56.28351342293524, 38.15179248009959, 38.70376410022859, 62.54513809757849, 61.095273187083585, 60.76564112017232, 56.063582205003314, 59.26624059677125, 57.3522259343055, 54.707234444156775, 46.88886027182303, 44.16031052989345, 45.464733954398866, 44.655517608888694, 39.02215857659617, 39.61239291775612, 39.42952809795257, 41.554009299124445, 40.887594684477776, 43.40221443483907, 40.21658305198916, 43.02126992133356, 41.78895927244618, 42.84960739074215, 42.98066162293957, 42.50567043981245, 40.42355083650158, 40.51957830306023, 41.016774023732836, 43.22620591809673, 42.32091895995602, 41.530027927890906, 40.54129254433417, 40.657394701434725, 42.29798486155849, 42.82031905266547, 42.34470029031077, 41.65407680696057, 41.97777432780112, 42.234634660905414, 43.3349810877154, 44.935045319218794, 42.90528543533818, 42.266241119753936, 42.66968827093802, 50.16156435012818, 49.780306047008885, 51.15327289027553, 49.06144542078818, 47.72961247351862, 48.17107131404262, 49.09892366778467, 48.71806544642295, 58.34631535314745, 62.81112578607375, 65.20429718878962, 70.51568062074723, 57.79961147615987, 5.889981081408839, 1.2718797643338482, 1.907595213382475, 14.503201015533941, 47.375238095560384, 59.67314335607714, 51.29718072952763, 66.93786713384813, 38.247694430812714, 23.30605479978746, 29.635422729676772, 45.73818591333205, 17.661815112636937, 0.29530418796404717, 0.07254163163804239, 0.07884475027000712, 0.017138978413816904, 0.016563531469493624, 0.047781099189793876, 0.019278547073143627, 0.058863851872663346, 0.053387296145721796, 0.024188933180524938, 0.05189528245659125, 0.05385651350802472, 0.07003781881423728, 0.0395589379683858, 0.044007284957314693, 0.035761072405523835, 0.024625333251371503, 0.02176514207085054, 0.009515419144243484, 0.07811237021439499, 0.01827227909328236, 0.03239398957380364, 0.026920222406906467, 0.037211031698051004, 0.04601093429711558, 0.018392267614422787, 0.044549613920671326, 0.05664755184684069, 0.067057981936922, 0.03581329661932203, 0.04432382099630852, 0.08671752943266785, 0.041262656224951635, 0.06999487192520211, 0.021964886090567997, 0.0739337359705279, 0.09929082491585325, 0.2810035940379866, 1.2628068318290095, 54.25497339617822, 59.44594006384573, 37.373472644436745, 35.67381551188808, 49.9278263891897, 68.13950877035818, 79.78370789558657, 63.19856574458461, 81.09459538613596, 25.729253907357496, 0.5158290014632287, 28.248288285347726, 79.73729841170773, 76.29531660387593, 71.1804517622917, 70.70492713682114, 60.01535446413102, 56.02248361033779, 55.812244569101644, 52.629723625798384, 51.30168361048545, 52.74642982790547, 50.02423432565505, 53.173426889604144, 50.58045387268067, 52.24635900989656, 47.81732451531195, 51.567043719753144, 50.55105570823916, 48.382812623054754, 49.45661637090868, 49.90724963526572, 49.21832061582997, 48.460954081627634, 47.87442638028053, 49.14158728814895, 49.26031743326495, 50.66993490342171, 52.4698595846853, 51.72390714768441, 48.18266191790181, 47.138793699203006, 47.005374277791674, 49.221909584537634, 50.12043437650127, 47.932885385328724, 48.470485441146366, 47.13917809147989, 46.75280894002607, 45.74494023476878, 44.20673962562315, 46.24458743679909, 45.32388556388117, 46.02000428784279, 46.27539373213246, 47.04363699882261, 48.725682689297585, 46.466872076834406, 46.68845461260888, 50.74972375746697, 54.685343696225075, 61.63905882066297, 61.654273694561375, 63.22530846441946, 61.45949663654451, 63.67818532451507, 62.34364201945644, 54.50620120571506, 44.015398563877234, 63.51048831016787, 60.84533191496327, 61.84187281516291, 59.15058558987033, 61.49963425051782, 62.04185093602827, 57.48351550871327, 46.913575126278786, 45.412252641493275, 46.58491972954043, 45.875119778417776, 42.01813551687425, 42.64830350875855, 42.568361682276574, 43.7001851297194, 44.535904930483916, 45.98229854337631, 43.64930414384411, 44.505047644338305, 44.90949107754616, 46.39485343810051, 44.109562904604026, 44.33412644170946, 43.913420861767186, 43.51249579460391, 43.07786187817974, 44.97250787673458, 43.47828095959079, 46.59655347947152, 43.35729937399588, 43.756051448083696, 43.165993613581506, 45.191129023028964, 43.538053958646714, 43.91743736882364, 43.31622431355138, 44.51104887070195, 45.02698175368771, 46.32929886541059, 45.22937605457921, 45.052104534641394, 47.21700183806881, 53.98032119197231, 52.910930110562234, 52.96315646940663, 51.3249981787897, 51.834423849659586, 49.35740786214029, 53.54214537528254, 50.0708556175232, 59.81126569932508, 65.04861047191005, 69.59291950348886, 71.65727861465948, 59.394431498742875, 5.659449167789952, 0.7817386102772529, 0.9496495776599454, 16.9546902179718, 53.976834204889116, 66.13058843920308, 56.649254829652854, 74.77346051123835, 42.50422308521886, 35.67723974104851, 34.6266838812059, 50.646428138979026, 24.27137951697073, 0.3004466297645723, 0.07833114194293177, 0.0480778586690224, 0.0689402369842414, 0.04383426399961595, 0.03797200981587653, 0.08466759306048194, 0.07525952007140845, 0.09457029071786711, 0.004853741566260015, 0.016820299243854902, 0.027318302759780522, 0.024815771218028762, 0.05362635005205389, 0.05808881604142728, 0.042220476804481405, 0.05400354110245263, 0.14971408091725844, 0.1157240161011296, 0.1632232906957788, 0.08183978633174012, 0.1369469192239546, 0.15277392801738557, 0.18357259311502983, 0.23648375795493204, 0.2435065319220866, 0.15155278386608248, 0.1878122922273413, 0.12400986987256235, 0.1177517052799944, 0.13273643870507518, 0.27470451268938284, 0.18194194432468186, 0.11153275672827037, 0.130038644757963, 0.1985139429809586, 0.4050588469591833, 0.5895892338406655, 3.7387591215872, 72.88869888551774, 68.98452851080125, 43.992221278529016, 42.261557809768185, 62.26648115342664, 71.12618184858754, 88.03300934453165, 69.34477467690745, 87.94913338076684, 28.54672770346365, 0.5017252002031573, 35.09363420547978, 82.72554828274636, 79.88827828438052, 74.81247240497221, 72.27786033384263, 61.61545399696597, 59.104419292942175, 60.25186946315151, 54.9876799891072, 54.068095991688395, 55.8851339740138, 53.72302547577889, 55.721512302275634, 54.448424693076845, 53.29074890382829, 50.60562372207642, 54.44495731784452, 50.86817933667091, 50.4356203540679, 55.34758098663823, 54.51981575258317, 54.62867329197546, 51.24748429944439, 51.80979920971779, 50.019111710210005, 51.5154214059153, 53.71017186872421, 58.51973902794623, 54.28210050828996, 51.310940404092115, 50.40333532517957, 49.828209953923384, 54.2817396502341, 53.50485540205433, 51.50019868727654, 49.07542474808232, 49.121877378033055, 50.336415767669685, 47.16845466244606, 46.8504249665045, 46.958376438386985, 47.452555856397076, 49.18271726177585, 49.14630982183641, 52.17087691830051, 51.65137860082811, 49.23413168999457, 46.15501619154408, 52.393710690159956, 56.133090526826926, 62.91061278312438, 62.423697594673406, 65.31846953976539, 66.03643586558681, 62.94137985475602, 63.34250104042792, 37.13456107724098, 35.853518901332734, 66.9098614108178, 62.92110512333532, 66.28998571826567, 59.574782079265965, 64.08129515186434, 65.4561133538523, 60.345755315596065, 49.4570242974066, 47.37253558251166, 48.13265562057496, 49.52217486596877, 44.127519515252885, 45.379375334708925, 42.76226405174502, 46.049374995693086, 45.642840939183394, 49.18427836510443, 45.22195885258336, 49.495945976626494, 45.17477273941041, 48.65546441847279, 44.84674884426979, 47.76851454088765, 44.85780600578555, 45.516328811645515, 45.85197779440111, 49.32779788970948, 45.50911557289862, 47.50277003934307, 44.385564404149214, 47.625132299238636, 45.03378706593668, 48.786546107261415, 49.08850585260699, 46.073513261733524, 45.65315285036641, 46.67511070928266, 47.399180243092204, 49.13425637829689, 47.69480143823932, 49.371520550020286, 49.845252652322095, 56.877415180206306, 56.99672975847798, 57.38993560114215, 53.6420795225328, 54.324340512675626, 53.99925839516425, 57.77050748948128, 53.93226823499126, 64.6951303943511, 65.20640742394232, 71.50414928313225, 73.05177534780195, 62.528781813959924, 6.612433127818569, 1.9451044716181296, 3.798842723331144, 18.033849962296024, 60.535448981869614, 75.15345973353233, 61.98878911233718, 81.01835235472649, 50.632488035386615, 39.336477710354714, 45.01823879057362, 62.19165409764936, 40.54075910199074, 0.32100895059204876, 0.16467700381913494, 0.1838378127544157, 0.19752708383865897, 0.20957046098286108, 0.1764007077942933, 0.1473534269438636, 0.1126618477545919, 0.18841057625268737, 0.12319572525279177, 0.11293105871206331, 0.07594056457521454, 0.19692967315354656, 0.18225345099645276, 0.17562458411820475, 0.13217846622630475, 0.07661507434902654], [0.06873176147740695, 0.06339628850260089, 0.07647581488615082, 0.08940922531990275, 0.07846375176262471, 0.016959166086669412, 0.06022218321900695, 0.1450366085214961, 0.14736456586228264, 0.06751175113623181, 0.08408192650324876, 0.03607742841385546, 0.0183892090083851, 0.03040983525645589, 0.05573009644004126, 0.12247340393162544, 0.13171720468709547, 0.05110192946308563, 0.08827916902279662, 0.08459709764968965, 0.18201326711043236, 0.26115113028114845, 30.04372577513418, 43.47224835426577, 36.733938032580966, 43.31943673472251, 34.461909032637074, 74.06632777183287, 61.222079492384395, 69.7384080579204, 67.52327303732595, 34.90965151017712, 0.08264901266703684, 1.326487982465375, 47.53877739752493, 83.72502311583489, 68.84355852680822, 70.331752838627, 68.9865053853681, 65.73153826498216, 57.68036750055129, 59.18309811622866, 49.73239821772422, 51.87019978800128, 48.81570108475224, 47.438651054136216, 47.82893473102201, 49.202423249521566, 47.74881247551211, 48.98548480003111, 48.63658605083343, 48.225137264497825, 46.904090835202126, 47.58946618726177, 45.53779202122843, 47.464017022040586, 49.497742422165416, 46.478388155660326, 46.736507569589925, 46.533175822227236, 44.77764452657392, 47.99471762872512, 45.882862537137925, 45.5029692188386, 48.03504743883687, 47.45326972776844, 48.201908988337365, 46.67868398850965, 46.91168062148556, 42.6433652447116, 44.471652584691206, 43.00603935795446, 43.33283162886097, 41.70988821214245, 45.274204823278616, 44.02533784989388, 48.01483154296876, 48.02783812246015, 46.5990206503099, 47.751907225578066, 45.946757947244954, 47.59914267447687, 50.32489184410342, 57.01202700215002, 62.14633503267842, 64.18629700137724, 64.195851895117, 62.083855598203606, 60.18418504345802, 35.00964841535015, 35.63122249418689, 59.45127448728008, 60.835977062102295, 63.452578436943796, 58.9304425639491, 60.59087991714478, 62.777907233084406, 61.42906296637751, 53.5574386965844, 45.61505486888271, 46.20199834146808, 45.37340940967683, 42.46535239681121, 38.99628662293957, 42.61864646788567, 42.99412711974114, 41.91320819239463, 43.76133880307598, 43.17539945725472, 42.6990472116778, 42.948117717619866, 42.48157531984391, 43.67867092932425, 43.4430149293715, 40.995059782458895, 40.292578974077784, 42.02315222832465, 41.46608937171198, 44.38874544635896, 42.40557547538511, 43.31699309810516, 43.70894378231418, 42.078904797953946, 41.954699024077385, 41.53460925625217, 41.71255150148946, 43.25498434805101, 43.41129472178798, 45.897955817561, 43.610523669950425, 42.36429252932149, 42.17230427649714, 41.75385013703377, 43.13241420253631, 42.37593412399292, 44.010691719670454, 44.62919850503245, 46.28805122067852, 48.11744466904671, 50.73002169209143, 50.298478603363044, 57.935753022470784, 65.11339233767602, 67.13309134206465, 70.97750048483573, 57.47413319926108, 0.7639324592967188, 0.7631803448161771, 1.175351092411626, 16.828740950553648, 52.47956352849161, 51.02188917898363, 59.096276452464444, 58.495588994795284, 25.36593064185112, 32.70406746095227, 31.406988674594512, 50.66918180834863, 4.195881947394341, 0.17675637177401976, 0.05779464593938282, 0.08431226615944216, 0.03971366474645273, 0.12027718307029818, 0.022639378627401688, 0.03751538693904877, 0.07371228293425615, 0.021985668140733917, 0.016780920409327073, 0.03699234040874628, 0.09842439479525052, 0.059272379749604774, 0.0961989400187327, 0.03783191531716335, 0.014899174810477324, 0.025065194124416, 0.061853180579360456, 0.07023883262468923, 0.1325575571747557, 0.019006421151120338, 0.053744009665904514, 0.01806800940915221, 0.028973654055246906, 0.11786965217681662, 0.034898641263885845, 0.031138748764210654, 0.06969916198642985, 0.04761141454500537, 0.04105299711227417, 0.02057204439845537, 0.10146858305820536, 0.06429969002642939, 0.17710696425168745, 0.02091576506744229, 0.06859077831670161, 0.14564416221072599, 0.10872574162579353, 0.23413030520802547, 35.145346733831595, 51.78163266951039, 36.04692312978929, 51.89762107787594, 38.777885129374845, 79.09601442275509, 68.57784148185485, 73.72628181211411, 76.07230632535874, 38.391119818533625, 0.05321896747655926, 1.072525177751818, 48.74511803350141, 86.5569979144681, 71.43353877529022, 72.3866904166437, 70.0049017321679, 69.79541578600484, 62.102702586881584, 61.58547924410913, 53.20617868054298, 52.93894760070309, 51.87480072821341, 48.76674206026139, 49.72949958616688, 51.94641928518973, 51.08585519175376, 51.0017321186681, 50.485587427693034, 51.62643624890236, 49.85567438986994, 49.18549822222803, 47.927084199843875, 50.22323969871768, 50.784068030695764, 48.808530992077245, 47.52327619060394, 50.686561830582164, 48.30271390176589, 48.32270230016401, 47.944075907430346, 47.75773586765413, 49.29976078771776, 49.550482611502375, 50.53493868920111, 48.77579881298927, 49.53095313041441, 46.92307902920631, 48.73477866572719, 46.095980598080544, 46.93413619072207, 45.62952841481855, 46.12790084654286, 46.520890958847545, 48.0884583534733, 49.643952692708666, 49.24415334578484, 49.21981111649544, 49.12596841012278, 51.12453368402297, 54.33093009456512, 59.86244870770363, 64.793075899924, 65.36711869701263, 64.61132111087923, 67.81119854219499, 60.98361899775844, 49.48093114360687, 47.63184739697365, 60.74814734920379, 65.58702245835336, 62.096587611782944, 64.04902581245669, 62.305908818398755, 63.19158000330772, 63.966903148158906, 57.019436359405525, 48.783125800471154, 47.98650026321412, 47.45044562124437, 44.666782656023585, 44.17328965279364, 46.74204203390306, 46.117671305133456, 45.613403551040165, 44.15848270539315, 44.67955389330464, 45.61549809671218, 44.881046049056515, 45.050468906279534, 46.612992132863695, 46.844113872897246, 44.996767736250355, 45.061875158740634, 42.82916399740404, 42.95731959804412, 45.47610098315824, 42.70582114496539, 45.156612165512584, 44.823085185020204, 42.49046341065438, 44.08354974562123, 42.66780161088513, 45.29844507094353, 46.68396349876158, 45.137643583359264, 46.72454826293453, 46.03532114336568, 44.71055630714663, 45.1513954131834, 44.62429554231706, 46.29932019018358, 46.12119751591837, 45.35311898877544, 46.248819674215014, 48.173848352124615, 49.96887007067281, 52.863002669426706, 52.79406701364825, 61.89440904125091, 66.54985843166229, 70.56336879730225, 71.24844212685862, 57.84152200145107, 0.423327531184881, 0.9529284339758658, 1.9550935227063395, 19.46721346147599, 59.37994618569652, 58.61829642326602, 66.13601699952157, 63.53414412467711, 33.679003946242794, 41.26637797201834, 32.54331500299516, 60.13823055451917, 5.044994190815957, 0.3402453264401805, 0.03639165086731796, 0.02246451905868467, 0.0717214732280662, 0.06087194835286468, 0.03409699919903952, 0.014109632146785097, 0.004396707874782865, 0.03340099682851184, 0.050978635272551934, 0.00580666444992887, 0.013708015340530585, 0.051630288813143015, 0.029875879634111643, 0.0492473186985139, 0.040356297601735404, 0.06537135510194687, 0.15686008778791274, 0.17760896634670997, 0.25414640534548993, 0.19428748186797867, 0.12501410388898465, 0.12005573769490566, 0.13008105538545117, 0.2810687727985844, 0.1965112972163385, 0.25799806560239485, 0.13943109721426042, 0.17874026370625343, 0.20459766169228863, 0.12283750253939822, 0.15517558301648787, 0.197209770220422, 0.29357960147242396, 0.2051954247778462, 0.2844479559890686, 0.23407707741904646, 0.24976258977286278, 0.3458266753342844, 51.640203768207186, 59.335348836837284, 54.93313943186114, 61.457292264507664, 48.65802964856548, 88.29696132290749, 76.6792695753036, 81.480423250506, 81.10131832861131, 45.05951781426707, 0.19836014316928005, 2.9420316027056788, 53.36311271113735, 91.08615875244142, 75.65296573023643, 75.89527407000142, 72.72795231111589, 72.09011216317454, 63.92877378771382, 65.30984817012664, 55.281995034986934, 54.966761988978234, 55.37987778263708, 54.181468179149014, 53.63411318871283, 54.5082643724257, 53.191132468561975, 53.48836968022009, 52.75590235187162, 54.32092805062571, 54.40765949987597, 53.79527553435295, 51.88489298666678, 52.950232259688846, 53.913723268816554, 50.242161212428925, 49.80153391438146, 53.226665219952984, 49.0953190095963, 52.30875607459776, 49.81523475339336, 51.8277205190351, 52.759738429900146, 53.47970516450944, 52.53997195151545, 51.36336288144512, 52.68411513297789, 47.48643336757537, 50.8903250386638, 49.325118910881784, 49.185133441802, 45.9868759493674, 51.2471705098306, 50.75933356438914, 51.17053524140389, 53.285422325134284, 53.567268156236224, 52.11192761698077, 50.1547747273599, 52.17766654106879, 55.879348478009625, 63.186210278541814, 67.42085210738644, 67.82087110703992, 68.19611641668504, 68.34460166192824, 61.06898546218873, 35.823850093349336, 35.20210343022501, 61.558340364886874, 66.15594263999694, 66.73306449767082, 63.41325667596633, 63.927161693573005, 63.98248280248335, 65.99785543257191, 57.728965666986284, 50.553652317293235, 51.328857791039255, 49.56803129565332, 47.83540271943616, 45.6509720125506, 49.00008386181247, 49.9860853533591, 47.75399000413957, 49.11453862344065, 46.225607087535245, 48.13834305732481, 46.83688886703984, 46.80393703522221, 48.84727616463938, 49.41174837850755, 46.70158670794579, 46.180586122697406, 45.489535100998424, 44.69359205615136, 48.25016590856737, 46.09445479608352, 47.223461981742616, 48.37616420561268, 46.71704476879489, 47.792488067380845, 46.24135932614727, 48.728334211534076, 48.47231718801683, 48.14650943202358, 49.97735415735553, 48.706749408475815, 45.30978856548187, 48.99065056154805, 47.169960852592226, 49.629941986453154, 47.29958341967675, 47.347585385845555, 48.51136438308224, 52.629096046570815, 53.6077783953759, 57.39786663363057, 55.402909940288914, 65.06355470226657, 68.84744951801916, 72.91155061414166, 74.63253759568738, 60.73039470180389, 0.8794967001003604, 1.1349747041540763, 2.9990187383467153, 21.994698586002475, 65.2865336018224, 64.04982205360167, 70.87915097513508, 70.29458445887413, 35.77858986393098, 48.754370904737904, 46.908656474082704, 70.15464213586623, 14.085555864918618, 0.5101880202850988, 0.25002047028993407, 0.2501031771422394, 0.1626258646889079, 0.2035984685344081, 0.2282677407586767, 0.12997291441405975, 0.12498481634763942, 0.11756222109280287, 0.23033363474232538, 0.16299655931370874, 0.2198683374351071, 0.16591932264066514, 0.14490845733352248, 0.15364709971172197, 0.19706350871391837, 0.1302891708309612], [0.04447834093063589, 0.013975335018438919, 0.03222556514365058, 0.03678864146011972, 0.04213018951216533, 0.04808571107024628, 0.03125072592088292, 0.07887589940500837, 0.12571363409440364, 0.04933098316072457, 0.05833038654659064, 0.05259104350942278, 0.02518794056208384, 0.01632608060214308, 0.0765572423716226, 0.07363742082229546, 0.02759351218569904, 0.023232031906504306, 0.10420359355667907, 0.025181235377526572, 0.07846981151810578, 0.11935723404730521, 1.6022864993541472, 69.43208663694321, 36.842140536154474, 66.69969297224476, 37.49071621125744, 42.047008083712676, 82.22775243943738, 62.65153238850256, 66.45546267109533, 55.753797331163966, 4.590008566456457, 0.5299366025194046, 6.36056253986974, 67.89685526201802, 76.9554671933574, 72.70779917317053, 69.98981629648517, 63.36358378010412, 57.43789442123906, 55.80611390452231, 54.715004659468136, 54.828678869432025, 54.066527043619466, 54.38938909961332, 52.05826959302349, 49.846217555384484, 51.17874868454472, 49.12972211837769, 50.4388366976092, 48.08544597318096, 45.171838806521514, 48.34070990162511, 47.36211776733399, 46.097675061994984, 46.78951840246878, 47.88949220411239, 47.037729909343106, 46.293334653300626, 48.492917476161836, 47.238582718756895, 47.078432344621234, 47.127960112787065, 45.625441305099, 48.80004690539453, 48.27879921082528, 47.213157915299945, 46.240080633471095, 46.294193652368364, 42.57109949665685, 43.77323142943844, 41.48045701365317, 43.61233580497004, 42.58274109132829, 45.95177073632517, 46.64969375056606, 46.96678207766625, 48.74348240513956, 46.69842135521674, 46.58107580677156, 49.538997911637836, 51.05566078616727, 52.01984997718565, 56.23347182427683, 59.71459496405817, 63.26860750875166, 61.03548842091715, 65.10302943568077, 46.50189884247319, 21.825940570523663, 50.83424298994003, 64.04639390207106, 62.42367406045238, 59.141360175225046, 64.38496897297522, 62.89743754171557, 61.353243550946644, 59.841330666695875, 52.32403762878911, 44.95184483066682, 46.12090333815544, 44.48790688668528, 41.057496070861816, 41.44683837890625, 41.95442445816533, 43.4911737903472, 43.49872827529908, 43.37688769063642, 42.44449715460501, 44.60821382461056, 42.54570607216128, 42.31052467899938, 41.80665700666366, 41.502806678895034, 40.94689307674285, 43.64175750363258, 43.15562678921608, 42.668464491444254, 46.261775262894176, 42.92044539605418, 42.83174099460725, 41.57415459232946, 42.90771338247484, 42.00973772233532, 42.01309527120283, 43.463952541351325, 43.80280217816753, 45.224661365632095, 44.46989536285401, 46.51934554499965, 43.78289222717286, 42.89777409645819, 44.157345218043176, 46.22464610684303, 43.01622967566214, 45.87821452848373, 43.42030832844396, 47.85872121011057, 47.35857194469821, 55.0115672234566, 60.199725474080736, 67.70393740746283, 63.676624221186486, 74.522334683326, 44.050484165068596, 0.12161478024697113, 0.28653974374455793, 0.66835833292815, 22.69191949598251, 53.443772331360854, 52.62655435069915, 61.68811982677829, 38.99775358938402, 21.914250773768273, 33.897931037410615, 34.76602215920725, 44.41350736925679, 0.5510471665090131, 0.06266167530068947, 0.07651343746411224, 0.09115048954563756, 0.0659093173641351, 0.006905636250702365, 0.028211890697298993, 0.02171668317920018, 0.0403768249276665, 0.011542171780620853, 0.06372616979323568, 0.05834748562906058, 0.04532581803599193, 0.0194373092193517, 0.02337415845343663, 0.06781830888001189, 0.035707078528620546, 0.03296107083799378, 0.01253226955962037, 0.03472536366673247, 0.058058735599080404, 0.022554270089453748, 0.0816947965311908, 0.025860843466474645, 0.06869639119794292, 0.045728370427123965, 0.03369300656260983, 0.054342178778061946, 0.04252927918587962, 0.051160968028970306, 0.07951218139139876, 0.023278837963458032, 0.0930503416325777, 0.04844443557123023, 0.07040738728978942, 0.009760204345859107, 0.05019118881694252, 0.021249486373797543, 0.07431446634713681, 0.15940783575417536, 2.3063507195441955, 78.92831740840789, 41.852666408784934, 72.13760422122094, 44.14364437903128, 50.160901469569055, 89.96051696039017, 67.14337579665646, 74.64075103882821, 61.10143130825412, 6.034299788936493, 0.6323104640168529, 6.500828458416847, 67.56492860855596, 80.21006953331732, 76.30686406166323, 73.08698254246866, 68.34534691226098, 60.1836359116339, 57.87479154525265, 57.00627288510723, 57.07215693689162, 57.26466686494889, 58.017008842960486, 54.26337903545749, 52.72309172538019, 53.528687723221324, 51.19712891117219, 52.57900737947034, 51.67519523251442, 48.270938780999955, 49.722788410802046, 49.08086115314115, 48.64617232353457, 48.5383463674976, 50.2801925136197, 46.3538372132086, 48.479742234753026, 51.512628678352606, 49.97097246108517, 49.23435918746456, 49.164874399861986, 46.951551514287154, 48.67493506400816, 49.83194012795725, 49.494647672099454, 46.91965872241605, 47.682681314406864, 46.08559023949408, 47.07589457111974, 45.09577228176979, 46.82296053055794, 44.507561883618756, 48.110505996211884, 47.92553094125564, 48.82489904280632, 51.06241118523383, 50.85563167448967, 50.93368291854859, 52.77656539793938, 54.73359277171474, 55.09964404567596, 60.66169831060595, 61.047851731700284, 65.30356061074042, 64.41222160093247, 65.07418824780372, 53.040482074983665, 32.90407303840884, 55.918976183860536, 65.979169261071, 62.974821982845185, 62.07518323775261, 66.50520616962065, 65.87047253885578, 64.67534595920195, 61.56778543226181, 53.50353748567643, 46.490818146736395, 47.85274744033814, 45.60852804491597, 44.42019893277077, 43.65869822040681, 45.22037029266358, 44.10165540633663, 45.92803255204232, 45.010260689643125, 44.57640732488325, 46.397073499618045, 45.18360199466829, 45.17097196271343, 43.278224391321984, 43.630861159293886, 44.54565202036212, 45.694949626922615, 46.158201156123994, 44.92626705477315, 47.938196274542044, 45.40851854508924, 44.750952797551314, 43.654516973803126, 43.803727857528195, 44.41365249695317, 45.91344525737148, 45.12954388895343, 44.27005844731485, 47.15585208708241, 46.53633333021595, 48.58811340024395, 45.7245203756517, 46.75760599874681, 45.67778925741873, 48.60294780423565, 45.19547108680972, 48.80896637516637, 45.149610734754994, 50.01201222019811, 50.47816238095684, 54.81780213694419, 63.12844945538429, 69.35842452510711, 65.52494310563611, 75.32518109967633, 42.65992156920895, 0.08840044840208947, 0.574303818566184, 2.0562842993005632, 24.527290636493316, 63.2990921697309, 57.760070062452755, 68.30868059589018, 43.1206706262404, 34.47341334435248, 40.405539312670314, 38.318489290052845, 49.174397914640366, 0.243443819964605, 0.1307582924322736, 0.07440968341524563, 0.12303665475619417, 0.06342846419542067, 0.04678016701232522, 0.017540031187837164, 0.03227935217681431, 0.026529647800470554, 0.01564863479636129, 0.08397938563458382, 0.048133836713649576, 0.026547461259929885, 0.051741432849197626, 0.04527105424072474, 0.04589323254842912, 0.03693723187391316, 0.03904086334871189, 0.1576665332240443, 0.10173573323916044, 0.11292942694478458, 0.12930234233217855, 0.17881112683924938, 0.21889978779419778, 0.1275950387841271, 0.22677331772302428, 0.16366533874984712, 0.1263470279293195, 0.16661405713567812, 0.1152195625247494, 0.1636954000399959, 0.1876135996632999, 0.20353483727141736, 0.2527390711850697, 0.12565076125845795, 0.14006198594166389, 0.288242144329894, 0.09406965992022907, 0.2865020522186833, 0.45656352033538206, 5.1787308339149725, 93.59587946245748, 51.27820430263397, 85.71521805178735, 49.275571530865086, 55.50727244346373, 97.72633137241488, 75.86165935762467, 78.73564274080339, 70.60599711633498, 7.527325480215012, 0.6753479965752172, 9.6248423476373, 73.6068142614057, 81.1653470993042, 80.99122524261475, 75.33126077344342, 71.81193767055389, 63.940266332318714, 63.762645721435554, 59.76338140426144, 61.054974755933216, 59.21824255297261, 61.72337801225724, 58.16755725491432, 54.80856495518839, 55.474575565707305, 54.1368825974003, 55.559204624545195, 53.63896516061599, 49.90700252594487, 53.008318639570675, 53.18079310078775, 51.09034238323089, 51.55329188992901, 53.6916269025495, 48.769828965587, 51.29718857426798, 54.98489902865503, 51.3022994226025, 52.181416326953524, 54.069790455602835, 50.80817884014499, 52.121976729362245, 54.54766458080661, 51.96172829597227, 50.657500989975475, 51.29861239464053, 48.47267804607269, 51.62046247912992, 46.90148245903754, 50.017060310609885, 48.04346092285649, 50.40492388509935, 49.179728415704545, 50.57943797880604, 53.736828296415275, 55.044240566991995, 52.18887667502127, 54.59665498425884, 56.34336879176479, 56.89043744917839, 61.97482547452373, 63.003843599750155, 69.25881201221098, 63.78690165858116, 66.65260884069627, 45.76978452744023, 24.581791970037646, 54.48516161211076, 68.33927508323424, 65.12067225671584, 62.86114385051113, 70.4732091965214, 67.62708248630648, 66.25510800269343, 64.00345571579473, 55.675373461938676, 48.17020839260471, 49.04684243663665, 47.764062650742076, 45.47487720366448, 46.73170658849901, 47.538220420960464, 46.64702261647871, 47.28312907680389, 47.87244558334351, 45.35863384123772, 49.632973978596354, 47.90135737388365, 47.76459217071534, 47.26697675643429, 47.366463753484915, 46.417807148348906, 48.305651757024954, 47.41102187864242, 47.58520649325463, 51.977872771601525, 47.41355180740357, 47.31007968225787, 45.560416252382346, 46.841399592738, 49.92318230290567, 48.279065931996996, 48.23381354731899, 46.863980677820024, 50.5741310119629, 49.447022253467196, 52.59270429611207, 47.65186717433315, 49.10888648802235, 50.44916822064308, 51.90549327481178, 48.22293289246098, 51.85897004219794, 47.5753927230835, 52.40923543130198, 54.33204797006423, 60.9838229610074, 67.5435987595589, 70.933028651822, 68.54974162194037, 76.9497876013479, 46.74198319835048, 0.2522648934034571, 0.6167340579052126, 2.2972571945959523, 26.888828123769454, 68.77895709007018, 64.43579504566809, 75.43530556463426, 49.00452790721771, 34.68269924963675, 52.08458085213938, 48.744455152942294, 66.52793238239904, 1.2020549562669571, 0.33347405913856726, 0.31889516079137403, 0.19529346256486832, 0.2095686376936013, 0.2750344514366119, 0.1134517073871628, 0.07972033514130501, 0.18523226131594953, 0.1192297493558257, 0.17318748989172522, 0.16920993074534402, 0.10079146092457157, 0.14170127620379772, 0.08899782078280565, 0.21298701394229166, 0.09072539501733358, 0.21982514539793616], [0.019955408736883153, 0.024742761123625022, 0.05274432238131281, 0.054901265914762215, 0.013554435779130267, 0.02333130157973257, 0.021070555047762972, 0.05810883391888873, 0.0778599672259823, 0.14957980102589055, 0.05686897040915586, 0.06748961885609935, 0.027018432963579416, 0.040299645399734865, 0.02952409780494148, 0.019590879204652963, 0.03627938068201465, 0.0641147219275515, 0.04847928491090575, 0.12367708127825491, 0.010990266718210713, 0.06033847153547311, 0.2538999701820074, 15.66792138161198, 51.55435877461588, 30.322012055304747, 51.858283627417784, 23.93973135179089, 58.910489466882524, 72.9733200996153, 57.32363185574932, 66.99649872318392, 22.630687375222486, 0.11463936583529558, 0.0894335026462232, 18.013759582273423, 85.69376268694478, 67.13860619452693, 76.96753240400746, 67.09331850851736, 64.3093966668652, 57.658202186707534, 62.091719950399096, 58.45663985898418, 61.8579702223501, 56.964048570202245, 56.4235459604571, 55.27657039703862, 51.16231395352272, 49.20509046123874, 49.54091202828192, 46.36200358790737, 45.77561709188646, 48.149353150398504, 48.76976228529408, 46.584986409833355, 48.59113362527663, 47.71282080681094, 49.28332213432559, 48.01431771247618, 48.532749145261704, 48.47597283701743, 47.52058544466573, 46.754742668521025, 44.928306687262754, 48.06705397944297, 48.991497793505275, 47.10470830240558, 47.19414226470455, 45.17614164660054, 43.50263103362053, 44.09725842937347, 42.504446660318685, 42.967537372343, 44.74022511513003, 47.15021564114479, 48.12110031804731, 47.488351406589636, 51.89028624565371, 57.15766460664811, 54.92219994145056, 54.160499188207815, 53.87361703380462, 50.64845600435811, 51.06103051093317, 57.655264331448464, 60.097818374633796, 61.40867448622181, 56.85757190950456, 66.31592827458536, 30.362677228066232, 21.559601829897975, 60.427642637683505, 62.461081704785755, 64.70989811804988, 60.769033970371375, 62.742966759589414, 58.175629492728945, 59.371842568920506, 51.81154466444447, 46.99839638125512, 44.25541231709142, 45.70317483717396, 43.65643893518756, 41.20720509559878, 40.26930755184543, 42.531475713176114, 41.67502226368074, 42.14416911525112, 42.50592931624382, 44.9878208098873, 41.76152229309082, 44.42987934235604, 42.161988442943944, 41.66360424410912, 41.48591695293304, 42.13241377184468, 43.48554911152009, 43.9985284497661, 43.08480055101457, 44.08420085906983, 43.15591704460883, 43.55701469605969, 41.82915964434224, 40.82827275799167, 43.26605719904746, 43.89451111516645, 44.004239420736994, 46.604935584529755, 44.91212298793178, 45.92221567707677, 42.90665434252831, 48.130686590748454, 47.458133466782115, 50.94930571894492, 46.63713039890413, 46.7129772709262, 44.11148878835863, 48.09157663776029, 48.401957711865826, 57.94991670116302, 56.603935764681914, 69.93367148983863, 62.08256906078708, 77.25972544762396, 18.131367929520145, 0.47246441064823064, 0.38105391086109225, 2.3313303339865903, 25.916888329290575, 56.7056663574711, 54.08842563629151, 63.55177910097184, 21.090568727062596, 30.061745143705803, 37.35488453219014, 48.130502239350356, 16.913556321974724, 0.31591688673342433, 0.08559975352498793, 0.03154584022629405, 0.040949238163809625, 0.054923356060058846, 0.06588860234666256, 0.04417697343254282, 0.040696498096710255, 0.04209081259285731, 0.03535610683743031, 0.023792543966743736, 0.04136966338621513, 0.04400342770461594, 0.032073512012439395, 0.018764950237387133, 0.10400999547733415, 0.04994974088584704, 0.038028144908528176, 0.02062871575265402, 0.0055329905514935815, 0.038624260905048544, 0.0339496306954853, 0.053398224389961654, 0.013427682701618442, 0.03718328782387319, 0.07531018912672036, 0.022703797045734622, 0.07263396821555591, 0.024224368577462532, 0.09540554872083087, 0.0669354385125541, 0.04329273176770057, 0.038523753999822566, 0.015199083868684548, 0.015025508454850605, 0.04885433857599574, 0.07406465273590819, 0.08697667399481421, 0.052507302438419674, 0.11991127649502409, 0.384814759055453, 20.23000659481172, 58.95287459896457, 34.61960792541504, 63.56871981774608, 29.38762503285562, 72.87955976301625, 82.17999366021927, 64.66716781739267, 73.62073083077708, 26.287113005115142, 0.11465448075004163, 0.055292200582522544, 20.043501815488263, 87.17958004243913, 72.34021817484211, 79.46390921069731, 70.82683440177672, 67.38002023389264, 61.99304488397414, 65.74226986977362, 59.73970597790134, 64.50474639092722, 61.76893241943852, 61.554347392051454, 55.815413844200876, 54.035077479577836, 50.411886092155214, 53.074426266454886, 49.16486655512164, 49.62991845223212, 48.66811798464868, 51.538265289798865, 49.329092271866344, 50.315823324265025, 51.449890367446415, 51.07156991958619, 51.312203407287605, 49.656127729723536, 49.7999414320915, 50.65848942725889, 49.85814940544867, 48.3590744387719, 49.04046074036629, 49.87273277774934, 49.02363377232706, 50.0001548951672, 47.82986433275285, 47.076792793889204, 47.292495696775376, 46.58000499971452, 47.842121739541334, 46.18541063800935, 49.680501337974306, 49.08301845673592, 49.708134435838275, 50.77041426012593, 57.60916471481324, 58.04443797757549, 58.62661969277167, 55.989594536442915, 54.08072602364325, 54.0192703277834, 59.1686834058454, 62.6375569835786, 66.81564607927876, 59.781086983219275, 74.41184936031219, 36.13148943070443, 27.160371849613806, 67.53397326315603, 61.31818932871665, 67.18354871196132, 64.32290923210883, 65.42000009167579, 63.42651820951893, 62.21893025982765, 55.48809597569128, 49.27597945736301, 46.88380825904108, 47.458670831495716, 46.73312648650139, 43.51320966597527, 42.30566486235588, 45.394174437369074, 43.62796645010672, 44.62033787081319, 45.31871980236423, 46.880038861305486, 45.56291480218211, 46.01437176427534, 44.35558965129238, 45.56979463946435, 44.35984934529951, 46.23724475983651, 46.6718041512274, 46.81284081551337, 44.349764931586485, 46.18270812496063, 45.846757119701756, 44.96199592467278, 44.17415257423155, 43.98684763139294, 45.278111503970244, 46.7258701016826, 47.33041324923116, 48.67022429743121, 47.18449715645083, 49.19650831530171, 44.9758497361214, 50.75203795586863, 48.66150879090833, 55.01012379123319, 48.409637712663226, 48.576777750445956, 46.96213406901206, 51.387332485568145, 50.949847006028705, 60.32431171786401, 60.995448866198146, 72.94902493876796, 63.17782032874323, 78.19330446181759, 18.629373619633338, 0.8434452765410947, 1.6462365345608805, 1.9790594496073264, 29.225117314246397, 62.262566627994666, 58.4352433296942, 68.3233267261136, 26.323853846519228, 40.0841599126016, 38.01188545842325, 55.70620721386325, 18.766927219206288, 0.6404774515859543, 0.10842294537372167, 0.08858286925861913, 0.11976260947243822, 0.03337583467063885, 0.05633251734017845, 0.022259243884153908, 0.019355284185298992, 0.05779153562241024, 0.011977348026008377, 0.026628145640115106, 0.004061967671488322, 0.1190600838632353, 0.06796167457416173, 0.04039159893328625, 0.049246138923110507, 0.061006029061372244, 0.014103743803477096, 0.1049151206989923, 0.11011030765310412, 0.17281524776931734, 0.1611525243929317, 0.1274226536794055, 0.08118126481290787, 0.13903020340348446, 0.2937338302933401, 0.20052306984941806, 0.22427674443010362, 0.181105989181707, 0.13639075471268547, 0.11225818836640929, 0.17142420063816732, 0.126080559566617, 0.24678275289554752, 0.13248362969006264, 0.2365168069879855, 0.2281618061205072, 0.24419429501698864, 0.18748227687131977, 0.19332374325923382, 0.4607565340495879, 32.06464071427622, 71.02769113356068, 46.91906252214986, 69.25303828331732, 36.16248399980607, 74.84767175489857, 88.86210426207512, 72.12094199272894, 81.3946488595778, 29.773066543763687, 0.19235203733607648, 0.14645863624830402, 23.030586742585708, 91.50303609909551, 73.34021076079338, 83.78201515443864, 72.24635585661858, 71.68656303036597, 63.607202191506666, 69.00985917737408, 62.19066173799577, 67.98397894828551, 65.84355723473334, 65.97940460328134, 60.236560452368956, 56.15815054985785, 52.22366417607954, 56.22400714505104, 51.67393222931893, 54.18175843454177, 51.74169117404569, 55.10732796884353, 52.3768013523471, 53.65868683784239, 52.15492856117987, 54.48712279719692, 53.10152199960525, 52.0047684638731, 54.312055649295935, 53.765536123706454, 51.690159074721805, 50.929791927337654, 51.80003250798872, 53.628967039046756, 52.32473188830961, 53.05362985980127, 52.27692604064942, 50.8194281977992, 50.0379979225897, 48.792233544011275, 48.51607122728902, 49.60238341362246, 53.3593786147333, 51.32060904656687, 52.190935919361735, 54.06475413230158, 60.19398312414847, 61.427109626031694, 59.29302646267799, 57.990913314204064, 54.874248966093994, 55.86838937574818, 59.171025060838275, 63.85029500530612, 66.53030149398312, 61.01919097285117, 68.34590388882545, 27.84342515853144, 25.902612863048432, 68.28465215621456, 64.45153159479942, 70.7979892915295, 64.72146126531786, 66.84398128140357, 63.81578207015992, 63.73946451371717, 55.08089119388212, 49.94181748359434, 48.23919111682523, 50.34853196913197, 49.20066995005454, 46.344984423729684, 44.26013485077889, 48.8013687441426, 45.7931383194462, 47.1962328880064, 47.933163873610965, 50.704996970392045, 46.63056435123567, 48.61221636495283, 46.11588270433488, 49.44673199807444, 46.910401928809385, 47.97312498092652, 47.631761104829856, 49.784067600004136, 45.820673358055856, 48.085347913926654, 48.202501266233384, 48.377015359940074, 46.35437457792221, 45.64252714956961, 48.55523217108942, 50.32884559323711, 50.0903223406884, 51.94960032739947, 48.90717467954082, 51.287049247372536, 47.57250978100685, 53.48629474639893, 52.772203722307765, 58.338862849820046, 53.25248618279734, 50.835623664240686, 50.12564328409011, 55.706681820654104, 54.34664703184559, 65.14613628387451, 62.65667069342829, 75.67762959387996, 62.685523648415845, 78.08647478780439, 21.653320981610207, 0.8306642946216368, 3.6440203987783004, 5.302030540281727, 30.30899370870283, 70.47293463060933, 65.04226407697125, 74.85654415622835, 29.096883266202866, 46.255628908834154, 49.751476626242365, 66.39283026418379, 29.858044693546912, 0.47952372700937335, 0.16746793873608115, 0.2433211692879277, 0.19347147565455208, 0.29472110312311883, 0.18259704143049257, 0.13531961057695652, 0.14496323262010852, 0.11509003237851205, 0.15612878025539462, 0.14663745649158955, 0.12274061539961446, 0.2415964449004781, 0.12826854498275828, 0.12590349366467807, 0.1520962926048425, 0.18609892126292954, 0.09640180776196142], [0.054327933373109955, 0.023373430669908563, 0.035979158485368375, 0.0252198442936905, 0.029690426984621637, 0.022302035640384403, 0.06966366913289794, 0.12369266350663478, 0.0450770769478573, 0.09765614650302357, 0.03459148214108521, 0.03503124725313918, 0.07112583220605889, 0.030379706933613748, 0.0699834342324926, 0.07045627902111701, 0.13195328234184173, 0.02497557332859405, 0.06403580338003174, 0.05194626560795212, 0.0790065557004944, 0.012625232414011995, 0.1263886035209702, 0.04801457980647684, 57.77866209706953, 35.55626992256411, 26.526528596878055, 30.528203210523053, 27.083997418803555, 73.25818615574991, 64.90337294916954, 63.95911724336686, 44.872165802986395, 1.7371662682102573, 0.03971893160093216, 0.30259421936446623, 43.614763752106704, 84.02908525159283, 68.36938319667694, 73.26703502285865, 65.13836606856316, 61.59509297340148, 62.2363926518348, 65.87236312127882, 62.967722492833296, 60.865555655571725, 57.78953490718719, 50.72205535827145, 51.14541246045021, 51.04332493197534, 49.84701379652947, 48.75713617570939, 45.37920275042134, 47.37640303950156, 51.260518335526996, 48.194617302187034, 49.959260263750636, 49.28765243099582, 49.20268212595294, 47.87256325444868, 47.44092210646599, 47.55456101509833, 47.845573425292976, 45.44549865107383, 47.311589794774214, 44.33244374490554, 48.70525890781034, 46.32293285862092, 49.21179379186323, 48.483056637548636, 43.37398513670891, 42.760157738962484, 45.11342686991538, 45.05372447352256, 44.443740998545, 43.18174585219353, 48.35195925927932, 53.2445865292703, 59.97234175282141, 58.52096280743999, 60.59275873245732, 56.803251004988155, 56.4440481893478, 55.227980075343964, 53.194733204380164, 51.94887076654742, 56.464856363111934, 59.06603105606572, 62.100745324165594, 61.52397255743704, 64.12397053933913, 31.470019202078547, 39.5342279249622, 64.01026887278404, 60.391168517451135, 61.957759241903986, 59.37993049621583, 60.385402633297836, 56.75926162350563, 52.257843709761104, 45.677852015341486, 45.35388385095904, 45.90695373473629, 43.9182218428581, 42.06710238610545, 41.18585171238069, 41.21590491264097, 42.14527130126953, 44.10274974761471, 43.60546381242814, 44.3501885475651, 43.68524874410322, 42.365492774594216, 43.02418032000142, 41.33725912340226, 42.7111751802506, 43.275192399178785, 42.70651540448589, 44.409651679377404, 43.385477681313795, 44.374103238505704, 43.865587557515795, 43.077708905743016, 43.6266799126902, 43.14647982197423, 42.84465343721452, 44.33876268325314, 41.43076058356993, 44.46097197071199, 46.44484796831685, 47.31964242073798, 52.71644723030829, 57.23317807720554, 58.84922204479095, 59.93247478238998, 53.32294371820266, 54.70453585347822, 49.05251026153565, 48.86745675917595, 47.02223262479229, 54.568480599311094, 62.611747787844756, 68.34308762704173, 68.3604480374244, 68.44851309253325, 2.4779688783230323, 0.3835178334866801, 0.8762788243832127, 1.0794649537532561, 38.54825389000678, 55.83086406030963, 60.6662953284479, 42.030930288376354, 21.397007819144957, 32.830097136958955, 25.938328004652455, 52.46107347549931, 3.7103903341677884, 0.18208676558588782, 0.08195471484214067, 0.030753843208414414, 0.06073123332293284, 0.0319800895052932, 0.043641382212480234, 0.05367467487831751, 0.03225268082573049, 0.07684421890805807, 0.03603319066666788, 0.041925138418352416, 0.025037295117433515, 0.018957845431061524, 0.02680736999478071, 0.025166017040910742, 0.04231817599746489, 0.08056536842618259, 0.03334211914109127, 0.01697038735954031, 0.04024107797792362, 0.01606640743932897, 0.022006685762936552, 0.029969361513071967, 0.08478771564700911, 0.07338927728274176, 0.04540233106742944, 0.024938500418718305, 0.03361204256033225, 0.05957709888236658, 0.02922030946900768, 0.013681529765768398, 0.009753084516212826, 0.03579651929378029, 0.01221478644443015, 0.06497527232333537, 0.08592044559097098, 0.03555442784882842, 0.03669512127676318, 0.05098880508974676, 0.03133780905045569, 0.09971621055756846, 0.9589748901705589, 68.64399617718112, 39.22004607415969, 37.40944077891689, 41.78604887377831, 33.48610570353846, 86.01775830791843, 71.85581330330142, 70.64398919382404, 49.48974863175423, 1.9037944366855009, 0.0570158064816027, 0.3083955580669065, 46.4613180006704, 86.99183187177105, 71.39603307170253, 75.06636742622622, 66.87600351149037, 64.29137729829358, 63.21616541954779, 65.54920688752206, 64.76798057556152, 65.01346995753627, 61.173838261635076, 53.2231782328698, 53.21276826243247, 54.443039278830256, 50.64542008984474, 52.28856763532085, 49.03618927924864, 51.10566316112396, 52.458873025832645, 51.218356778544766, 50.52829811649938, 51.643561317074685, 51.75186972464285, 50.749633542953006, 49.56405401229859, 50.226401129076564, 50.51327936110958, 49.162042448597575, 49.489685873831476, 49.40196206492763, 49.789127457526426, 49.72936230321085, 51.92173580969534, 49.800470952064764, 47.33815600795131, 45.48488709234422, 47.92770001196092, 47.49722380791941, 48.12719960366526, 45.81640581930838, 48.66870634017452, 51.092331024908255, 59.76838242623114, 60.40180598535846, 62.29141173824188, 59.157135948058105, 58.42444504460981, 57.52189590084938, 56.9853784191993, 54.988793942236136, 58.17269555984005, 63.86343494538338, 65.52934792733961, 65.1368167323451, 74.46170268520233, 32.67594995037202, 42.336894773667865, 64.43524199147379, 61.399774628300825, 66.07157245759042, 60.82000909313079, 64.44538131836923, 58.80115732069939, 56.222395050910215, 47.81605758974629, 47.80525930466191, 47.537275129748934, 47.17865674726425, 44.98655780669182, 44.24257439951743, 44.22096998460832, 43.95841044764365, 46.012469414741766, 44.97046039950463, 47.311731000100416, 46.70456770927676, 46.083354488495864, 44.52040764593309, 44.57643870384463, 46.015113092237904, 44.98845623385522, 44.09536392458024, 44.891954160505726, 46.5321324717614, 47.34950342485982, 46.88076449978737, 47.314978722603094, 45.05026494303058, 44.54682480904364, 43.96685531062465, 46.05598026706327, 43.58651484212568, 46.57862432541386, 47.69677831280617, 49.64163064956666, 56.33710868896977, 60.51779439372402, 61.787434239541334, 61.04143865646855, 55.18515171543245, 57.34921355401316, 52.729983329772956, 51.705848555411066, 50.13772418422084, 56.50548427335678, 65.8918337668142, 71.01250371625348, 68.78035345385152, 70.28581403916883, 2.0384637458670527, 0.28290107125236147, 2.5927518933050098, 1.178044534979328, 42.760349935100926, 59.88368441981655, 67.66487844528692, 47.06477072931106, 29.441124200820926, 33.736588262742565, 27.516244572977868, 58.43986780412736, 3.5364886205042567, 0.1060356698449581, 0.08118000842871205, 0.03630281914205801, 0.10673914540318713, 0.01373866173033152, 0.05246811321065311, 0.005442546689957982, 0.04242299214726494, 0.04290074372904436, 0.04329746619107262, 0.044399161913221886, 0.0452197186889187, 0.03969952659381013, 0.02426713160539587, 0.11056343333855753, 0.034959323088368105, 0.006463363158306288, 0.04212511801010659, 0.12905042197915817, 0.198686511946782, 0.11995748691861668, 0.13746695502871467, 0.19954894308842, 0.19440282406585832, 0.14177580123707173, 0.13843193469989684, 0.2221933529982644, 0.16756003782633813, 0.09279351065596265, 0.16027300949058226, 0.14958018406985268, 0.1244650410127736, 0.18497902329169935, 0.12333632536953497, 0.4540880144603791, 0.15460664015864173, 0.20437762591867678, 0.1962392900379435, 0.1668615341787377, 0.08578859419832308, 0.4208626279667501, 4.642458500400667, 86.0574213151009, 50.55128712807932, 45.184245263376546, 46.461596488952644, 38.712526675193544, 92.51240314975863, 77.26393022844869, 77.8207891218124, 54.86074424559071, 2.4133390044012377, 0.117281541799105, 0.6914957204172689, 51.98906329370315, 87.33230144746842, 75.68163825619605, 76.00561034294867, 69.5110204142909, 69.70626815672844, 67.9529530002225, 71.27366296706661, 67.5357775534353, 67.524002598178, 65.6721967266452, 58.23975240030597, 58.760141095807484, 57.21498612434634, 53.30529697479741, 52.88960810630552, 50.35596878297868, 53.33198085907967, 55.98839429117019, 54.49526171530447, 54.26009601162326, 55.37062883377076, 53.65485468218404, 53.26245684777537, 52.079065999677105, 53.01719104090045, 53.770046849404615, 51.166495200126406, 52.67502700128863, 52.09861117024576, 55.79019300399288, 54.623385936983176, 54.16548452069683, 54.88878919232277, 49.364750539102864, 48.11938624228201, 49.053114306542184, 50.609244069745465, 48.462358290149325, 46.02265581007927, 52.90683123373216, 57.258316547639915, 64.20182958725961, 63.595309565144206, 66.51720077760758, 60.53126773526592, 59.85735747121996, 59.32240893763881, 59.45418488594794, 56.467531419569454, 59.63366077792261, 65.03383490347093, 66.38486785273399, 67.89437632406911, 60.57707317413823, 30.975551489860784, 42.47544465526458, 67.8662686194143, 63.61630601267662, 65.72150876445156, 64.3206460245194, 68.05917078448881, 61.518810718290275, 57.84986488280758, 49.2096874790807, 50.530302447657434, 50.09899470113939, 49.9031154571041, 45.75303992917461, 45.3721111051498, 45.903058821155184, 47.05161509975311, 47.56053870724094, 47.40867237890921, 49.56585438020768, 49.23480633766421, 48.14710955465994, 48.678222010212565, 46.57059523367113, 49.42376259834536, 46.754013107668975, 46.86117618314682, 47.34714608038626, 49.53449895305019, 49.91003451808807, 50.238129015891786, 49.37323854815576, 48.65204411168253, 46.34481968418245, 48.87226558500721, 50.960810030660326, 47.42737816226098, 49.96684612766389, 49.94282161035846, 52.04558072551605, 59.161650596126435, 62.7520509689085, 64.17261185184603, 64.37230756205898, 57.35600317678144, 60.79998539340112, 55.16058198867306, 56.79997974826444, 52.00511755481843, 61.842857330076164, 70.4465292346093, 74.96609595514114, 71.60102398164811, 70.12994689326133, 3.5891582071781163, 0.585520448944261, 8.788803854296285, 4.722495444359319, 45.81913578894831, 67.00159780440792, 70.8550048643543, 52.66382078970633, 31.965075269822155, 50.84389986530427, 38.15683272577102, 73.20260617040819, 9.795609597236881, 0.5924460676408584, 0.18826865080383517, 0.10772297849818584, 0.2416026348909063, 0.15518253909484034, 0.10896355063924867, 0.2015486777189278, 0.07727641507142013, 0.13335137748189513, 0.13579562696958744, 0.19083653156074787, 0.14508353906773752, 0.22568118277817006, 0.19753210937544224, 0.2402648155487353, 0.1355912500331479, 0.17479258198891917, 0.1270870612032952], [0.03449183325433443, 0.09743404995289542, 0.013092160131031228, 0.04393411589966666, 0.06089269784429382, 0.05896106459981492, 0.008080035632085657, 0.01754606221502106, 0.049106358520446286, 0.08151584605295813, 0.11393592858146276, 0.035634970502747644, 0.07980742401653722, 0.02858212183890564, 0.0320751591014766, 0.03135214064029917, 0.12349688973758491, 0.10332653013568732, 0.02096094318755692, 0.021935843697358525, 0.12958440058414014, 0.03076095633479136, 0.0665842408254262, 0.1364097843367246, 20.927205931755807, 55.94846848518618, 29.2995717448573, 29.422614535977765, 26.83381295973255, 65.77464511317592, 56.13891916890299, 55.454677381823146, 61.74293887230658, 3.800419761288551, 0.15596318268968215, 0.009599035725958887, 4.165198226128855, 72.21521223745039, 71.96814214029621, 78.58825575920844, 68.31775696046891, 65.97097150741085, 64.46944505937638, 67.46839907861525, 66.36801735047372, 65.30376849635955, 55.96473455429078, 49.49931921497468, 49.191546517033736, 52.17152803174911, 50.964253871671616, 53.039787815463164, 51.224652182671335, 48.40708817205122, 48.26438842281219, 54.62354675416024, 49.50957229060512, 50.020735571461344, 49.1197318415488, 48.92364863426455, 48.54037031050652, 46.24246543453586, 48.66960456294399, 48.6632973917069, 45.82567830239573, 47.399427352413056, 46.205210762639204, 46.46042762264129, 46.9221729616965, 47.07390985181255, 46.772001097279215, 45.25294949931484, 44.36044946793587, 45.387435805413034, 46.52235008055165, 45.42116818889495, 54.622071942975445, 65.2177313066298, 64.00569931153329, 64.3815408214446, 60.99337393237699, 60.70810387211462, 59.68669514502249, 56.85357501429897, 55.75441706565119, 54.04990011645902, 56.44857852689682, 59.10570975272887, 65.79557095804523, 62.25932675023233, 65.35362966599004, 60.97517413477744, 49.58455624118928, 60.86220987381474, 57.729444196147305, 60.39096455420218, 58.73033500486805, 57.213122998514486, 53.02253330907514, 50.42501818749213, 45.67871885914957, 44.60580941169493, 46.00443640062886, 45.64446480043473, 43.39741345374815, 42.20668777342766, 41.844017582554976, 42.913840124684, 43.93662560370661, 45.441576280901515, 43.215988143797844, 43.1881824616463, 43.00290538418678, 41.24052955258278, 42.52549017629316, 43.19728628281624, 42.47142030346779, 43.076995034371656, 43.6093940273408, 45.048801898956306, 43.610535437060946, 44.21119936050908, 43.59134720217797, 46.063617121788766, 43.728226154081284, 44.633014971210116, 44.727720599020685, 44.8527539930036, 45.82105775033274, 45.8535938109121, 52.739726497280984, 63.46655384186776, 60.8367693808771, 59.36588448862876, 57.71206809628395, 63.095799646069935, 54.631038481189364, 58.12160276597547, 51.4189624786377, 52.3551381018854, 53.183534837538204, 63.648402767796675, 63.83262865005001, 74.75820249126804, 50.164945433216715, 0.08247102745958874, 0.19804822281003, 1.395639858899578, 1.736529986223867, 38.58338263727004, 58.51147067162299, 50.74447954854658, 13.92292361105642, 23.62940715205285, 30.136919329243323, 43.93264832035188, 31.038005428929484, 0.09653664689751403, 0.021689050387771382, 0.037201340685808854, 0.0496065718001656, 0.04847631248975954, 0.09263584976114574, 0.07160975462606839, 0.023676650185558586, 0.02847428155702449, 0.05964547989048785, 0.029091078097060807, 0.030651336813706066, 0.0523769066128279, 0.05263692834564755, 0.02466414518083536, 0.021113057605802052, 0.05457842880259118, 0.029668197028278828, 0.05134507427893339, 0.010000276191520595, 0.08915958024801747, 0.008929979540557872, 0.03379815213021732, 0.030560564970777884, 0.04318582802830685, 0.02558952193677185, 0.03985709172763652, 0.053252866867208676, 0.01500377454043877, 0.01812186539022913, 0.028203392866998914, 0.07918267165340724, 0.0558575504880038, 0.035442571351004225, 0.030382476341460022, 0.012179112602626125, 0.06852806635922001, 0.020510157900712183, 0.02517791821681444, 0.09121532356666942, 0.05422089173788986, 0.024403085398878303, 0.1388082677318204, 24.303911655179917, 65.64692881799513, 28.88435748315627, 43.1372465625886, 35.994218241783884, 72.48353373619818, 70.90263028298655, 64.26240274983068, 67.69425699787756, 4.723040163516998, 0.04846047745236466, 0.010530267308856691, 4.642038806792229, 76.96640276139783, 76.75590484373032, 83.78640820903163, 69.90884288664788, 69.14498482981037, 66.81138638527163, 69.80966183447069, 68.91988785036149, 68.49656212714412, 60.53590789917977, 54.01512046014109, 53.37582119049565, 54.70170390221381, 53.36114760368101, 54.736044253072436, 53.72621436272898, 50.76907673189717, 50.372074034906205, 54.569853428871404, 50.984026539710264, 51.532220917363325, 50.977001574731645, 50.48090411770729, 49.63864964823569, 48.55118820744176, 50.827810302857436, 51.411431527906856, 50.25848611708611, 50.61432746148879, 48.346260055418945, 48.72223492591612, 49.385770520856305, 49.09198499494984, 51.30039707306893, 47.91689780450637, 45.63811056075558, 49.34895907678912, 48.667204072398526, 48.16587025119413, 53.9512485842551, 63.688995376709975, 64.779645704454, 63.96179622219455, 63.9927044991524, 63.69784816618889, 63.28364587599232, 58.83696463800246, 58.219858138791984, 56.05775356292725, 57.75537106298632, 60.513538622087054, 69.78207188267862, 63.15651793633739, 72.96069006766044, 74.82354917833882, 52.76097789887459, 63.76636020598873, 60.89075296155868, 62.109531433351584, 62.58064731474846, 59.91957018452307, 57.52579865917083, 53.18182860651324, 47.49820440046249, 47.73418203476937, 47.85310829839399, 47.702881520794286, 46.96103188299364, 45.00337300762054, 44.568033064565356, 47.01472520828248, 45.78392074954125, 48.43788270027407, 45.70601463317872, 45.910350507305516, 45.96560493592293, 44.35207520761798, 45.47943499780471, 45.16895978681503, 45.399414723919286, 45.36969100275348, 45.995481629525464, 45.89315091409991, 46.373472598291215, 46.29412304970526, 45.16107582276867, 46.02943758810721, 46.190054724293375, 46.646367580659934, 47.36631862578854, 47.11022707723802, 46.23398134785314, 48.35943137445758, 54.68816388037897, 66.56471636987501, 63.286348389041045, 61.62809579603134, 61.81992323167863, 66.02084052178168, 57.01379206872756, 59.65381783823813, 54.169018576222086, 56.005927285840436, 55.991983259877856, 67.5298547744751, 65.59221959883168, 75.89892187426167, 51.99992825908046, 0.042522112433347976, 0.5050334130083362, 2.8687634439237657, 1.3906122383571442, 44.15361504400931, 61.24250719624182, 57.70893804488644, 20.863471338825843, 31.778241011404226, 31.037997584189142, 48.907327651977546, 35.77338880108249, 0.10367546020255936, 0.027953648203683477, 0.04467573497564562, 0.020087564649480968, 0.018440052348699783, 0.12308481870399368, 0.036119701145517255, 0.08999820903784807, 0.030524710140701745, 0.0378439850324104, 0.06828778288176945, 0.03552656906146196, 0.04602612582065406, 0.018719368005892443, 0.022101201860594655, 0.027491651220066894, 0.021473094032356338, 0.05530014874473695, 0.1343978995517377, 0.06213216298830606, 0.2597638369808274, 0.07454527331696403, 0.15014816165691422, 0.13463826729885994, 0.17549828686300786, 0.12884301133453846, 0.14631975982939044, 0.12901256191394023, 0.1526867931768779, 0.18230629574146964, 0.09219649833657088, 0.20324067483025215, 0.1619936582902747, 0.10439641788722047, 0.13844517269922843, 0.16110190130289526, 0.20431667596342104, 0.17770809812411187, 0.11732010666521327, 0.22496588648326937, 0.13036801660012814, 0.1356186913025956, 0.2309809330730669, 40.744667437768754, 77.6662398922828, 45.789047287356475, 45.95385743725685, 41.157441985222604, 84.11365155250796, 72.12080078740274, 72.29729175567627, 74.40291420105966, 4.597512550892369, 0.25095192595354976, 0.19980109326781767, 6.179805994033814, 83.15184716255435, 75.93066169369605, 85.51849549816501, 73.56314259190714, 70.0101733976795, 71.1647544368621, 73.78236386083788, 71.55153935955417, 71.01102890506868, 63.21182335576704, 56.27317405516102, 57.59778591894335, 57.92184037546958, 55.503008827086425, 57.44042042763003, 54.70576355534216, 52.9173392634238, 51.80908141597625, 59.036778019320586, 54.336499860209805, 56.75281324694234, 52.96336827739593, 52.38638370267807, 53.557105295119754, 51.53034602442096, 53.46893433601626, 55.622425386982584, 52.222008935866825, 53.0250475483556, 50.578378938859515, 51.4252814169853, 53.015771142898075, 52.210492857040904, 53.5361716055101, 52.80430047742782, 48.14360687809606, 50.22528717594762, 51.560677712963475, 49.30092573165894, 57.12832135538901, 68.60778485575031, 67.34518174202212, 67.1641408243487, 68.16989929445329, 65.66106111772599, 64.6140314686683, 59.612880060749674, 59.74434614181519, 59.867069259766616, 60.654077145361136, 63.28986675508561, 71.34829782670545, 64.96143187246015, 72.38221106990692, 59.948725162013886, 47.09061130400627, 65.56015030030282, 60.67616008943128, 64.08572350778888, 62.66666489262735, 62.01893252711143, 57.59433031082154, 56.25349944637668, 48.353732170597205, 50.50111216883506, 50.948568313352524, 50.345986350890136, 49.3501946233934, 47.91734103233584, 45.98888028052546, 50.13771241711032, 48.467798617578325, 51.108306838620095, 49.34992397985151, 49.81151242409983, 48.90446824412192, 47.23559779505576, 47.19512285724763, 47.44480133056641, 47.194173643665934, 48.81706214720204, 47.916991941390506, 47.63802120762487, 47.977133643242624, 48.682218905418154, 48.503237232085205, 49.64481953651675, 46.91023326689198, 50.63098968998079, 50.74410300101004, 49.317274170537154, 49.03987630721062, 50.912000056236025, 57.22942829132081, 70.85855853173041, 65.48679805571034, 64.13705556623398, 64.50637025217857, 68.78562511936312, 59.937722913680545, 63.82006137601791, 56.69687632591494, 58.00759515454693, 58.674978594626154, 72.8503224157518, 72.44081912502166, 78.67277499168151, 55.51250880764377, 0.23951435581811015, 0.8658458713081576, 3.4266649523089012, 5.7529687689196685, 47.72511743730115, 69.2505907243298, 61.368289762927645, 20.44355219410312, 37.98049080756403, 45.235891111435436, 59.67839540973787, 51.54414100031699, 0.24048730280370484, 0.21963808204858537, 0.13056635676372436, 0.120858168830314, 0.11672334715483651, 0.3091724631526778, 0.13500211309761773, 0.16152703413559547, 0.12501274791335867, 0.1082038901926529, 0.13998634242002042, 0.12693728335321913, 0.13770130132475208, 0.11661996358945487, 0.15746686006745986, 0.13304967673555498, 0.18572416637213002, 0.12031711157291167, 0.1983576150791299], [0.023313085924112992, 0.07814646112702547, 0.05451426127805345, 0.04509508767495713, 0.031296356032872875, 0.030111020746370478, 0.0261495360398605, 0.0378414262987433, 0.08187102739729228, 0.04960166883745021, 0.04179126838402402, 0.023687436703532457, 0.04924213611370614, 0.010751989433511851, 0.02849560752961665, 0.07770068222476591, 0.07706588644894861, 0.02594093795895817, 0.051046709845503496, 0.02966545634872971, 0.04779679250092276, 0.11360847961998756, 0.12163215512109381, 0.11752348768735126, 1.3740425532863987, 49.40515879661807, 44.07324175680838, 33.12176850534255, 28.4503472235895, 45.63482753692135, 56.9192825594256, 59.045873995750185, 68.67805019501718, 12.737332313291489, 0.36235394977754165, 0.2920714807846854, 0.12493955587307293, 33.51106374494491, 75.90552714563186, 71.1844055114254, 73.4505391890003, 68.62411760514783, 69.75055171597388, 70.37659337443691, 65.88566780090332, 69.05529591345018, 59.275658207554976, 50.38925401626095, 52.3220685989626, 54.23583615210749, 55.214232167889996, 58.7037766364313, 53.99672454403293, 51.87517727574995, 50.9411903350584, 50.380562043959095, 48.46273876005604, 48.16016320259341, 46.710368894761615, 49.49827586450885, 48.08546558503182, 48.66505853591427, 46.99113999643634, 46.897140395256784, 50.336094133315555, 48.380204246890166, 44.81742128249138, 46.406557790694706, 47.42785669142201, 48.24091695970105, 47.573859076346125, 45.81331499161259, 44.86389352429298, 47.848628951657204, 48.09437721006332, 52.02736916080598, 62.848309855307306, 63.15034804805633, 64.52374635204193, 62.16853564785373, 62.31602461107316, 64.14713213520666, 63.07978460865637, 59.922837518876605, 58.23741859005344, 59.48632086476972, 58.438753850998424, 60.74217357943135, 62.73994653455673, 65.21004346109206, 64.70677591139271, 62.36683891665552, 57.98113484536448, 58.4526704203698, 58.164517418030776, 56.65803701646867, 56.28393311654368, 54.48530281743696, 53.53801511949109, 49.890195169756495, 46.71234184695829, 47.27158946375693, 45.52030609500024, 43.609951003905266, 44.30801914584252, 43.987016293310354, 41.930003781472486, 43.824583099734404, 43.395762135905606, 45.07683900094802, 43.304410134592366, 44.594634579074004, 42.53607273101807, 43.23148150597849, 44.559352859374016, 45.557015557442945, 44.598929574412686, 43.64864518565517, 42.778945892087876, 45.61309760616672, 44.16631960099743, 43.37147481979863, 43.99672808185701, 43.60885666262719, 43.73696519482521, 44.30869771588234, 45.78703903382825, 44.1599771284288, 46.61793431928081, 48.46545304021528, 56.10400222962903, 62.485047386538604, 62.21176408952283, 58.481040923826164, 62.16415043800109, 63.51889002707697, 62.25632613705051, 57.81552060957878, 56.17798989818942, 53.129241389613, 54.65230164989349, 63.99494025015063, 61.54948757540796, 74.27039300241779, 28.652072760366625, 1.0937541482910034, 1.0885372733877552, 0.34063511197605445, 2.5648175083821823, 42.67174359290831, 61.47643343094857, 28.596790875158003, 10.905769794218003, 38.71305619516681, 26.479815129310857, 49.39483511832453, 8.99648747136516, 0.08254245749764866, 0.033866115620419864, 0.036922312311587796, 0.07712136653642501, 0.03408670297733719, 0.06434789227862513, 0.01630106017053608, 0.02228158875368536, 0.05232048423720464, 0.033515787443086024, 0.044296701483788996, 0.04042317324708547, 0.06033153077887912, 0.017376009848028902, 0.033129499098586465, 0.058756653189418785, 0.01815666301896976, 0.0311543635513273, 0.026890641836930188, 0.010193654020587284, 0.07700664486976401, 0.09644857742973874, 0.07373865934148913, 0.027682985509595567, 0.027541655694104494, 0.011935018795362164, 0.026573468029739398, 0.037820692129072644, 0.09377138358691046, 0.03015128058201123, 0.0811387622548688, 0.01763196365397063, 0.022077573793790033, 0.020886485186976292, 0.04894287152696521, 0.03871912174227257, 0.054725544497130386, 0.07943302152618285, 0.03151103493667418, 0.0623710981510099, 0.10191947176691987, 0.053994325064723535, 0.09811834266950047, 1.137186308060923, 61.3836262303014, 47.6185074160176, 35.24979160678002, 36.298433349978545, 53.94350974790512, 66.37845085513207, 62.978814955680605, 78.18265130442958, 13.95516255209523, 0.3006617778972272, 0.20267560837730286, 0.037602042974603754, 35.57123376477149, 84.2347429644677, 73.20188445429649, 78.21918426021453, 72.02776216691541, 72.9647614878993, 71.58580518537953, 69.96013179902108, 71.11924709812288, 61.79336094087171, 52.723209396485366, 55.862694094257975, 57.017816420524355, 56.232110761827045, 58.92815974450881, 55.279359202231134, 54.422733168448175, 52.67522311979725, 51.480288736281864, 51.34954437132805, 50.584478224477465, 49.310178602895434, 50.75555239954303, 50.24085114079137, 51.20674264046454, 49.26617353193222, 49.025300779650294, 50.6862872646701, 51.00099079070553, 49.0144044353116, 47.91077106229721, 50.13296242683165, 51.00854527565741, 49.30902542606477, 48.692754391700994, 47.7982892528657, 49.38725317678144, 51.17000572143063, 54.22357090057866, 63.13642755631478, 65.99771422724571, 65.90166322646603, 66.66947503243723, 65.06925782849713, 65.65214949269449, 64.33138155168103, 63.557976445844105, 62.37309117471019, 61.78312747709213, 57.275986825266195, 63.091908654859, 64.60420593138664, 66.31995262638216, 63.02607167151667, 69.4048261642456, 69.21380673685383, 62.721715357995805, 61.35498116093298, 59.3517247323067, 60.40106465739589, 58.36596642771075, 57.20241885031424, 52.290364080859774, 48.71591990993869, 49.96543799677203, 47.22962010291315, 45.135505891615345, 46.93907445476901, 45.24142557574857, 45.24146872182047, 45.858559531550256, 46.113376309794766, 46.6019114371269, 46.76985556079496, 46.534195638472035, 45.45531634361514, 45.928891551110056, 46.740445629242934, 47.782623306397475, 45.89555532701554, 46.67886441753757, 46.61008565656601, 48.441408911058986, 44.55732107162476, 45.2176324782833, 46.78934189581102, 46.81927742496614, 47.98737102939237, 47.883424297455825, 46.10645332644063, 46.48624466311547, 48.869394410041075, 50.49971580505372, 59.35934197518134, 64.06233833682153, 64.70663078369634, 63.13083033407889, 65.52977938805857, 64.68693264069097, 64.35843413875949, 61.7416758691111, 58.22769503439627, 56.75013034574447, 58.181403221622595, 66.95263877991708, 65.02167163356658, 77.79882384884742, 29.09440628943905, 1.1795911745678995, 1.9869363043577442, 3.795471691316174, 2.580453056481577, 49.37098318530668, 65.9719285657329, 37.414120166532456, 15.869420401511656, 41.95750351875059, 28.849821013789025, 58.165109695926795, 10.555943404474567, 0.14287283914464136, 0.029324957079464392, 0.0269660095669209, 0.03390638120172005, 0.011494501959532501, 0.045104384151918274, 0.04350722872561986, 0.0273075066657076, 0.06762933031085037, 0.03679022726212298, 0.03480421709677866, 0.03232635167096892, 0.03563257647798427, 0.055584413329920465, 0.05758753406905359, 0.039455508437728694, 0.09690595490317191, 0.032770648193095005, 0.03572881244303238, 0.09318749435366162, 0.14560245638412816, 0.17745633098867633, 0.1905338195783477, 0.12830897144252254, 0.2059427435479818, 0.12424982393220549, 0.10323846066791205, 0.1456050610830707, 0.2320849423807475, 0.0729275331081402, 0.23430800696294155, 0.16901839344251543, 0.09695826338664179, 0.14980616468575694, 0.10470281475253644, 0.1469827936060967, 0.08865554801999562, 0.19364631224063136, 0.177646734481377, 0.24414990788265584, 0.3004069770536115, 0.22290855736261417, 0.3251203606205602, 5.815345241177467, 81.56630746779904, 62.82468149738928, 51.868462178014944, 45.67927191334386, 57.61643678911271, 78.5868593954271, 72.53218681581559, 85.00821867296773, 17.21772240054223, 0.7410154599816569, 0.9239818936874791, 0.14201894222247985, 42.282397362493704, 84.22490566007554, 75.22221888265302, 81.93213908903061, 75.17262443419426, 76.26660485421458, 75.73531196963403, 72.43788519213277, 73.95385772951188, 65.5280613899231, 54.93233534597582, 58.79927850538685, 61.30620648784023, 60.035260492755526, 64.82814188926451, 59.34140497638334, 57.27884623312182, 55.82651022941836, 53.600894635723485, 55.17700495258455, 51.557163269289084, 52.22015365477532, 53.3484548138034, 54.6685088834455, 54.198134330011186, 52.21290903706705, 51.10135639867475, 55.29131066414618, 55.41985065706315, 53.05705016659152, 49.7413412217171, 53.63582334210796, 53.69143470641106, 52.30017785103091, 52.01224057905136, 51.89766814631801, 51.30702980103032, 54.62804963511806, 57.948602707155295, 68.44471623820644, 67.17371140756916, 69.00423449854698, 67.55027463359218, 65.39820740299841, 69.52416035436815, 66.6219045269874, 64.83044432055566, 62.45444113208402, 65.28299954629713, 63.17605526216569, 64.22759171455138, 65.5461827401192, 67.28886435108801, 65.49863576889038, 67.65570794382404, 66.18005737181633, 64.8825922319966, 64.29918281493649, 62.312969084708925, 62.68999515041229, 61.25575304031373, 59.724000807731386, 53.103502796542266, 51.16009781437536, 52.44787862223964, 48.98723025475779, 47.53320763188024, 49.02126466074298, 47.80326674061437, 48.0122467010252, 48.58623458493141, 48.7773952176494, 51.09248399734498, 49.054502825583185, 49.175413808514996, 46.975172027464836, 47.22927885670816, 50.58831822487616, 48.974011867277085, 49.44626523602394, 48.4360509534036, 48.53769133167882, 50.438354246078006, 48.61948059451196, 48.267498862358835, 49.94890128412555, 48.33716407898934, 50.109840054665845, 50.183984618033136, 49.71042902238908, 49.115672188420454, 51.94208898851949, 54.84443110804404, 63.080396498403246, 66.4683594242219, 67.21782238252702, 63.57579577353693, 65.5226053730134, 67.94564954696163, 67.79590129852295, 64.70293198862385, 61.86379101968581, 59.31223038704165, 62.65255220474736, 68.8291242045741, 70.50247007800688, 79.59170787565171, 33.02698050775836, 1.5785540760524812, 2.5113200564538283, 5.996739172166394, 3.3042485146753253, 54.444623916379875, 72.67033269328456, 37.96331082620929, 16.403062785825423, 57.866664394255615, 37.91470873740412, 71.8075446159609, 18.82941253723637, 0.40758926601659873, 0.24318701197062773, 0.20040789619088176, 0.12354525286824473, 0.12273901427585272, 0.17328496691921066, 0.09077461616646859, 0.09117011671825763, 0.1288991042923543, 0.14862208386823056, 0.12114880726702752, 0.11989577087543665, 0.15266437744421346, 0.13814658226986087, 0.18081740386063055, 0.25404934200548357, 0.16885651906411495, 0.11876677944054527, 0.1263668925891961], [0.035321560102484884, 0.0241835035323616, 0.03716281795453641, 0.05622207427457456, 0.05695547705756561, 0.02891543137300159, 0.06161387386401335, 0.023846375049963116, 0.0411729320072599, 0.02744752264040853, 0.006458245212167141, 0.02592870353480741, 0.058516626351422844, 0.03824169574786098, 0.04990455702007298, 0.0405184286195905, 0.015160985358600176, 0.04901047112540372, 0.06726934559523098, 0.04105785027927449, 0.045175450298214154, 0.027417922918234142, 0.09794886869889113, 0.020859187559014367, 0.2876516131143416, 9.061577243189658, 56.38342403596448, 39.12356361266106, 36.979274442118985, 20.2678672729, 62.82580721762873, 72.02009001085835, 65.14475953194403, 31.588098233745946, 0.11934077081781243, 0.7468289028733008, 0.03018902956448015, 8.406705183367576, 66.85956093572801, 75.71221705405944, 75.22301904616818, 71.49420215237525, 70.39527954593783, 68.309017919725, 74.24293641121157, 63.748148641278675, 57.38339308769473, 54.15363111803609, 59.91074092926518, 65.48359740164973, 70.31001506313201, 69.90253571541079, 68.3301124265117, 59.043481349945075, 54.27550308166012, 52.3375972624748, 49.08137890600389, 50.92504193705898, 48.91197173826156, 48.83128858381703, 48.62643887919765, 48.087897454538655, 48.03465127944947, 49.88836734525619, 49.838835654720185, 47.54562977821597, 51.18322018654116, 46.366643751821215, 46.04503293191233, 47.748506530638664, 46.99506236660866, 46.38150169003395, 46.35392350535239, 48.01684764123733, 49.01032909270256, 52.83748372908562, 64.95242611054452, 64.56902619331115, 63.89083662340718, 65.4458563558517, 65.8324961508474, 63.722798362854995, 62.394495548740515, 63.93113113218739, 63.40973046518142, 62.21467056582051, 62.73232536931192, 61.72908898322814, 64.5176431440538, 65.52650028659453, 64.1576244754176, 63.97734449755762, 60.62889552885487, 59.33560771326865, 56.55122695430633, 56.24922798525903, 53.846776254715465, 52.012173898758434, 48.620978939917784, 48.3158891431747, 48.64323054590533, 47.459847542547415, 45.63252118326003, 46.879878044128425, 46.53988699759207, 47.40833113270421, 41.99594666880947, 42.748618125915534, 43.12435765420237, 43.13760742064446, 42.13234709155175, 45.103036511328916, 45.96575006361931, 46.69219655375327, 45.20726957628804, 45.300253283592966, 44.97260201361872, 45.54298523933657, 44.02867186454035, 45.004875275396536, 46.08526860513995, 45.9240395792069, 45.60379766648816, 44.36489743571128, 44.1642132882149, 43.86005309320266, 45.107723743684836, 44.684366641506074, 43.726084539967204, 46.26561526329287, 53.23289394378663, 62.11282230192616, 62.80445775678081, 66.94009504010602, 61.6257070725964, 64.59834198797903, 62.14715480804444, 64.84573371948736, 58.90329191761633, 59.22809554684547, 58.05351434215423, 65.26355635735297, 63.76967460878434, 76.79094729884979, 9.625962184321496, 0.678278313529107, 0.5605188324566811, 4.403986238664197, 3.7205311319520398, 51.1293189756332, 54.75937451085737, 12.12944338398595, 30.401761685648275, 32.99287549911007, 32.66119595496885, 42.73747467225598, 0.7423189126195446, 0.07923417574455661, 0.047170362405238614, 0.040771011638665394, 0.03939272370189428, 0.037005199194555326, 0.05495958052755845, 0.06026455171165928, 0.03967563997233107, 0.08406639024014435, 0.05260106776991198, 0.0841507288597284, 0.10824571093243938, 0.024343183068859003, 0.05831121902672514, 0.020379221983133786, 0.06161825588694023, 0.03467186774697996, 0.02322510264122919, 0.04340325527253651, 0.032392940033347375, 0.03381218686099014, 0.00910151045724389, 0.04082400194038788, 0.025515900887248498, 0.027815016932905685, 0.03543747303586814, 0.04977787289047434, 0.015259116433650978, 0.042352967880546086, 0.049819436990806175, 0.05836062020652237, 0.07724386399551746, 0.026273967870961756, 0.0008163064241319175, 0.04205545763515177, 0.03166561998847512, 0.03176184446220437, 0.09102616113640609, 0.04881449817349354, 0.044456810029523994, 0.047554057542114496, 0.1488958990141269, 0.07668976792164388, 0.41137429194584973, 14.330782448091815, 68.48878014472224, 36.244681189137125, 44.81211431564824, 30.382051775532386, 70.73678462736069, 78.14627524345153, 73.66384552371117, 35.752094253416985, 0.22868176531647483, 1.3034792364605012, 0.03523390049174909, 8.36479759985401, 73.19145879437848, 82.06520157475626, 78.76876323453843, 74.87290828458725, 73.38090927370133, 72.20903058205882, 74.85160981455158, 67.91483540688792, 61.73800453062981, 56.10272353695285, 60.266656798701135, 68.40670062649635, 70.81576547315045, 73.45448509339364, 69.86299822407385, 59.94743077985702, 56.54867741369433, 55.5038482143033, 51.66020393371583, 52.739153831235825, 51.31285844310638, 51.198607644727154, 51.45866863189205, 49.46119377689977, 50.63294695269678, 53.87462900530908, 50.85682799739223, 50.94375556515109, 51.18153748973724, 48.877792204580004, 49.07973543290169, 51.608969934525035, 49.13301298695226, 50.388724496287686, 49.882797579611506, 48.93649047420871, 51.09396665327011, 55.28845910103091, 67.010909511197, 65.55890298658802, 65.37748944374823, 65.24665094191029, 70.15977259605162, 67.47693415611022, 64.12854794533023, 65.15130204539146, 65.73862991025372, 63.59601559177522, 63.86674934817899, 64.43772485179286, 66.72401951205346, 67.61114981866652, 67.73826599121094, 66.50682218613164, 61.78854819267028, 61.05355878030101, 58.46683017669186, 59.35076375161449, 55.87192343127344, 55.005679745827955, 51.324076421799205, 50.05078484935146, 49.25774828080208, 48.6353152028976, 47.60171967168009, 47.21888849812169, 48.87161447155861, 48.98383740455874, 45.06684480174896, 45.70273160934449, 44.18655903108659, 45.53852550445065, 45.82087732130482, 45.92960934485159, 48.51942485378635, 47.35455151527159, 47.8392937106471, 47.772499668982725, 47.702705014136534, 47.41181027504706, 46.402819771920484, 46.33916754876414, 47.98612763804775, 47.71863768177648, 46.38882083277549, 47.089273775777514, 46.56775543766637, 45.70735216140748, 47.614486986590975, 47.49775725026285, 48.228510502846014, 48.869712122025035, 57.82056477762038, 61.894432575471946, 65.79507673940351, 68.16348229685138, 63.85304066442675, 68.0527380974062, 65.07807139427432, 65.7348487454076, 63.424019659719164, 61.53709288566344, 61.70478597764046, 66.72574535492929, 68.36868501478627, 78.280836074583, 10.703583378945629, 0.9604260445602479, 5.467989454346319, 4.215967424454228, 4.724286986935524, 56.64817617785547, 59.85091301702685, 19.2577039810919, 29.37903504217825, 40.156570788352724, 38.243626932944025, 52.1744345080468, 0.7406946836460022, 0.028010007377052983, 0.0491827106734197, 0.028346693443675196, 0.06363608168377992, 0.030729075585822427, 0.039076800533239885, 0.08099587919611125, 0.01904139114964393, 0.0590433884081581, 0.04654739885741184, 0.04620593048692231, 0.01619297282529935, 0.05453392292463011, 0.042659609893997835, 0.034351068428687515, 0.08351875228747245, 0.030754559500623616, 0.04088112911690147, 0.030221029057077346, 0.14335453990967045, 0.09383090095774782, 0.13974813504084466, 0.11255294069527619, 0.15046880009674257, 0.07865348109795202, 0.20896390320793276, 0.16933625864405788, 0.08852761899752003, 0.16336544597100827, 0.1346573735316915, 0.1301523628494432, 0.1714462946139036, 0.11778777269946954, 0.1232277324062682, 0.14429944807723646, 0.13169953869956155, 0.1978646681433724, 0.1663771980712491, 0.13266813430574634, 0.08910445256098624, 0.08575580563516387, 0.24724615948094478, 0.11100451612184126, 0.4172336081823995, 28.15045260613965, 83.31396656651651, 56.70848261925482, 59.61829293158747, 30.173499353470344, 80.06689517728745, 87.81375669663953, 80.2560083327755, 38.375983392038655, 0.7025240157400409, 3.155774791394511, 0.11590967750957898, 11.556997972150004, 77.02319083675262, 83.75801024898406, 82.54014568944132, 77.79533293939407, 77.54110059430523, 75.01150915699621, 81.76634834658715, 71.17447407014909, 64.79587254985687, 60.30594325834706, 65.58688125302716, 71.81269076562697, 74.79111902175411, 74.25942605541599, 74.8371127343947, 64.72340283855316, 61.34917213070778, 58.370080994021514, 53.736134036894775, 56.60940354870212, 54.6231702066237, 53.12636236990652, 54.26080596062445, 52.29992681933988, 54.38126194861628, 58.24906802946522, 54.36265422451881, 55.07764739374961, 54.73099616266067, 51.43627189820813, 51.097214375772786, 56.00065562032885, 52.45160487390334, 52.76026794987341, 51.59435126089281, 50.7782119320285, 54.86379584958477, 55.908676039788034, 69.3653278966104, 68.45217658627418, 67.77867424872615, 67.56002564584055, 73.13276444711994, 68.69504974734399, 65.20641526868268, 69.67193957298034, 67.1422226198258, 65.84317284245645, 65.14614805098503, 66.20501149085261, 70.34258642504292, 69.68654647950204, 69.01961018962245, 68.921401885248, 65.22999263578846, 64.91880355342742, 60.0660942446801, 61.21079875576881, 59.26899410063221, 54.95473992440009, 52.686025327251805, 51.77522351664882, 52.16519732629099, 51.08632979854461, 49.35477595175467, 50.50852937083091, 51.41228268223425, 50.59661403779061, 48.061033141228464, 49.50593625345538, 47.39205721885928, 49.21911685697494, 49.039864540100105, 50.54709411436512, 51.20571105710922, 50.645788792640936, 50.8540117356085, 49.533600730280725, 49.78284774288055, 49.88959504712013, 49.11507598815426, 50.30881012639692, 51.21274778919836, 50.293736457824714, 50.148722510184015, 49.146584387748476, 48.62237138132895, 47.40018436985631, 49.61081650949294, 49.86339361436906, 50.861632900853316, 50.797560984088534, 60.949404162745324, 66.96530803557366, 68.01316922710788, 70.13442623999812, 68.18673410723287, 69.2800320348432, 67.97351406466576, 70.38545793102634, 65.84190983926096, 65.80265083620625, 64.32469391053723, 70.42083770998063, 69.21994132380333, 79.84375153818439, 12.775623471506181, 1.6809843216211566, 4.489627269006545, 15.132898322997557, 4.824263789961416, 62.392569664985906, 68.31036721506428, 17.829925937037316, 43.608382055836344, 50.5099610359438, 47.0715368178583, 68.39017960333055, 2.571376201606566, 0.24916574599281435, 0.10646913005339523, 0.08271049122296034, 0.18748249137593856, 0.10446605527953756, 0.17190965523402538, 0.15334604247923822, 0.10206869803369047, 0.19759451489775412, 0.11265190393333474, 0.1564919672185375, 0.12427218603871523, 0.09306300506596604, 0.08907866604145497, 0.1789830676129749, 0.1548726258859519, 0.1319771842850793, 0.11053495785041202, 0.14325392192169545], [0.06515037704018817, 0.04070828052898569, 0.04058342734952608, 0.0038561914275745835, 0.030007047293287133, 0.07154417749974998, 0.08602780515267965, 0.03754390073159049, 0.04843250375180956, 0.018850817202380108, 0.03517813695174071, 0.03826001291013053, 0.02712554737715231, 0.026786210646312085, 0.022940640788405173, 0.030342132236147602, 0.023951936220269532, 0.06524858185120168, 0.09073281840931985, 0.16522163104626442, 0.029925319118305083, 0.01601858535826567, 0.0674548537860955, 0.059449878491220944, 0.08338989629860848, 0.7406588307311459, 51.54803199152793, 44.13506223309425, 32.6384638586352, 25.44192656393974, 27.516825083763372, 76.70869519633632, 64.83401759978264, 43.76692425820136, 0.707403382947368, 0.16694486922314092, 0.17246162158346948, 0.27749641287711363, 30.49121329861303, 74.52500189504316, 80.01231931870984, 73.68050775220318, 75.30998583762877, 76.54143748744842, 69.04462706658148, 66.29251956939697, 57.143018476424686, 59.89154092727169, 70.01157760620117, 73.39242535252725, 72.25170596953362, 72.2916356978878, 71.18941830050561, 63.20368443765948, 62.251427096705285, 52.190076920294, 51.39061943177254, 49.90260162661153, 47.98651203032463, 49.24107820756974, 50.605749237921934, 49.67798317632368, 50.35424686247303, 47.198574542999275, 47.86604035285212, 49.136390147670625, 49.82160076018303, 48.63091822593443, 49.12134001331945, 47.11086642357611, 46.944455946645434, 47.794092316781324, 47.17041976990239, 48.845393426956676, 48.04579081073884, 50.53434248893492, 63.77545226004816, 64.1895172672887, 62.553131887989665, 63.11369349879604, 64.1370241872726, 65.11895033621019, 64.37919132171139, 64.87480240483438, 63.67749106499457, 64.32732974329303, 61.92049280289681, 61.530597440658084, 62.94120334809827, 64.19917414265295, 63.327086125650716, 62.46255651597054, 60.67861549315914, 56.97967529296876, 56.90181232267811, 53.56949998486427, 55.4016508594636, 51.717988291094386, 50.32419366221274, 50.192096079549486, 52.58471442807106, 51.987929728723344, 48.6086077843943, 45.840144003591234, 45.928413021949034, 46.780489106332105, 44.02924060821534, 45.08023185114707, 43.763876576577466, 42.80237420912712, 44.39969670388007, 44.62160087400868, 44.72794417412051, 46.66459483485068, 44.48574958309051, 44.6704500721347, 46.01801956853559, 45.56199696756179, 44.34790572812481, 44.46588277816773, 47.25901826735466, 43.32885042313607, 45.72277492092502, 44.616741057365175, 44.53149226404006, 45.351526506485484, 45.48594220992058, 45.21596939333024, 47.786730027967884, 46.02409924230268, 52.78579865732501, 57.38431876705539, 60.86828562521166, 66.58210815921908, 62.52602831009896, 63.76511681464411, 66.63513075920844, 62.82425003667032, 63.659471696422955, 60.47954736217376, 62.60153001354587, 63.16923033806586, 71.92432142073109, 58.21365687154955, 0.4260832720225857, 0.17383020701667956, 2.1548383851205153, 2.8045392901666704, 8.600234927669648, 75.73415094806303, 37.596467233473255, 12.678624237737349, 46.68443418318226, 29.044317622338575, 49.57997883519819, 16.74310580376656, 0.11272018535002587, 0.09007548432677023, 0.03924056714881332, 0.0043606347096483075, 0.027827475437774297, 0.01623599823834675, 0.03607943173377745, 0.045807112774421135, 0.03032013976706132, 0.024313142846128153, 0.08503618094349101, 0.06786750704650918, 0.025943165359598015, 0.03296993064483808, 0.10888107361332064, 0.041155955498857845, 0.020469961267325188, 0.05420546655753448, 0.04803747817453358, 0.07306551320418235, 0.03553639796953048, 0.07818729361338962, 0.018181348287109888, 0.06392795735249115, 0.02737587235207039, 0.01628764214054231, 0.04881152958278695, 0.032378667815318035, 0.07456557464695747, 0.049316603690385825, 0.017488325998607664, 0.008551256314310576, 0.03652496165746162, 0.031805842806915605, 0.009328766609542072, 0.03677880489117196, 0.0480055361385307, 0.13932801242316925, 0.1407335999031221, 0.08075094556496029, 0.0589334816041012, 0.03698609679216339, 0.015118206051298448, 0.024501441512256864, 0.11094519027298498, 0.8243211478956285, 63.94854645575247, 48.85910211070892, 36.3429561738045, 31.696775344110307, 37.57931863107989, 90.02129800858037, 70.43838639413157, 52.77285483575637, 0.8937828915734446, 0.5326214649023548, 0.4107527188476055, 0.2739376280336611, 31.388180909618256, 78.89880549523139, 83.07489025977351, 76.34049446352067, 78.31881246259137, 79.67297154088175, 72.53537178039551, 69.23022577839514, 59.77647427589663, 62.30530085102205, 72.41396657882198, 75.49855770603304, 74.44664078374063, 71.86208909557712, 72.15354473360124, 66.19904948819068, 61.07029553382628, 53.89098921129781, 54.113065965714, 52.26624934904037, 50.75625450380387, 51.69227715461485, 55.63537705329157, 51.935993625271706, 52.445344771108324, 50.01527170981131, 50.50267719453382, 52.84580699859127, 52.222471775547156, 52.65028861261184, 51.09139750080725, 48.06709712551486, 50.773281512721894, 48.227227887799664, 49.204992401984434, 50.487403485082815, 50.97900198351953, 53.484470844268806, 65.50536263373591, 66.61871171766713, 66.56227665562784, 66.300874217864, 66.83492060630553, 65.00366403210548, 66.10789360538607, 65.92548770289268, 64.92783677193427, 65.73181283089423, 65.08457468402001, 63.69257257830713, 63.74876053102555, 65.72115182876587, 65.03680806006155, 64.1322349732922, 62.84501898673273, 58.54941568066997, 59.827527846059496, 57.581912086855986, 57.982087981316354, 53.453437051465436, 53.00014049776139, 52.11051948608891, 54.16732411230765, 51.70143588896721, 49.36233828144689, 47.96576269211308, 49.448697105530776, 47.834786907319106, 45.12369171265633, 47.728906446887606, 47.138354393743704, 44.63928291874547, 46.70202993577527, 47.118440520378854, 47.28212495003977, 47.27358595017464, 46.491955634086366, 46.69347524642945, 49.21282537521855, 46.60221738200034, 47.64157487500099, 46.67278082140031, 49.19549242142708, 45.01854081307688, 48.73893245573967, 46.03697246120822, 47.00335033478276, 48.78185103016515, 48.01443538358135, 45.59039492760935, 49.54571300937284, 49.09833923462899, 56.15428701523812, 59.33983602831441, 64.31158927179152, 67.86060471688548, 66.27384908737676, 66.70371732404156, 69.90166494923254, 65.22625853938442, 67.80913537548435, 62.854624871284734, 66.77555945611769, 66.21048711961316, 74.4068757949337, 59.03775076712332, 0.45976089553967603, 0.3131156096295003, 5.606854596445638, 3.0355524295760743, 12.8575353084072, 76.559433321799, 50.953934115748254, 17.093944165014452, 49.81013567216935, 31.132371771720152, 56.646901407549464, 19.00211645710853, 0.2948967824059148, 0.1920114040014244, 0.020784744880192225, 0.04007610860430906, 0.05594238706473863, 0.02937239707417546, 0.04689918643224144, 0.05230715430732216, 0.03791517758321378, 0.014865132735952016, 0.040809197291251154, 0.08103137971052239, 0.023594546627493638, 0.07120042618724608, 0.06752493550940868, 0.06010835404477774, 0.048216049439243736, 0.03538369749402327, 0.0585426235451333, 0.01728329788743248, 0.19559850345455831, 0.14910229842268652, 0.24049902394894632, 0.10430155321955682, 0.11510700888691411, 0.17846258747721874, 0.19618557195269293, 0.1431286665460756, 0.19823525551586382, 0.15147570009914138, 0.1553303634207095, 0.1581890971189545, 0.1010804369504894, 0.14763075077245313, 0.08549657680334584, 0.13758209804373403, 0.17503561572201792, 0.1808503609631331, 0.2564026721783223, 0.31214436335909757, 0.2128197309831458, 0.12036257123033847, 0.24335435621680754, 0.19235344693785716, 0.2509408789656816, 3.2943467363234493, 82.07075565092026, 60.9460073901761, 51.50861217129616, 40.70666359316918, 40.43079153183968, 92.5578163516137, 79.6996436580535, 56.132788504323656, 2.4057080332309972, 1.1688261070559103, 0.7029062016837059, 0.3397882783845548, 35.24351973687449, 82.98077690985896, 86.35839262316304, 80.89675103464435, 80.1813970073577, 84.48593939504316, 75.24785549409928, 73.20958798931491, 64.13771060205275, 66.23278971641295, 74.76850263534054, 79.19183008132443, 75.68209325113605, 77.09794336749663, 75.12992551249843, 69.93034531993251, 66.03761257663851, 57.16676058307771, 57.459989132419715, 55.07618434967534, 52.09327674681141, 54.31243611920265, 58.2139902730142, 56.260885269411155, 55.02524452824747, 52.50504716750115, 52.908643368751775, 55.46280061045001, 55.69779765221381, 55.00706042012861, 55.1855125734883, 53.465918033353745, 52.43194203222952, 50.45057635153494, 52.869564794724994, 54.30760768152053, 52.37616200600901, 54.29937854889901, 68.94311612652194, 68.84364481895201, 68.60764365042411, 69.50724709418513, 69.49795892161708, 69.05604116378292, 68.23879180415985, 69.3365063205842, 67.03498501931468, 67.69911289215088, 66.86553862787062, 65.90641713911488, 66.51009344285535, 66.47091680957426, 65.92400504696754, 67.8333991573703, 68.07259313521847, 62.04338458276565, 63.996940658938506, 58.52721114312449, 63.206104540055804, 56.765710000068914, 56.45155168348744, 55.31305236201133, 56.65391460541756, 56.26262287939749, 50.977338898566465, 50.52016704313217, 50.52725476603354, 50.01453430421891, 46.91965087767571, 49.82831978028821, 49.5398529883354, 47.43090829541607, 49.67650052039854, 50.45697765965616, 50.0575940839706, 50.70095300674439, 49.78589542450444, 49.42574339528238, 51.12776963941513, 49.21392756123697, 48.26389420417048, 49.92496698133407, 52.66491905335457, 48.81864678475165, 50.47615020505844, 48.989591521601525, 50.15830486051498, 51.842841256049375, 51.16571857083229, 47.59310614678168, 52.945474424669825, 50.76087897823703, 58.95150176940426, 62.04913477743826, 65.77706521557224, 70.3816375424785, 66.63048667292442, 70.00846324428436, 73.50550728459513, 69.61201360148769, 70.52265459491362, 64.39682629800612, 68.68864059448242, 68.28213399456394, 75.61316151772776, 61.02398803157192, 0.9491269831215182, 0.565350579638635, 9.445658672240473, 11.395995463094405, 11.155384529021479, 89.69667480837914, 48.43261495713265, 18.681733339063584, 68.70058028928696, 42.954997554902114, 67.97284726173648, 32.428858280181885, 0.22666289380961852, 0.2588265743707457, 0.08140761315101579, 0.16162242740392685, 0.16517263206262744, 0.20708553222638948, 0.18846832396041965, 0.25756537914276123, 0.08088643587524853, 0.13580929397815658, 0.14371130705600785, 0.2115501394315112, 0.08839639579697002, 0.17668036053017264, 0.1951297495754496, 0.16842409307437559, 0.08168861420164186, 0.1488567978864716, 0.16662763221369636, 0.14532936136088065], [0.009457808374727686, 0.022716998655889786, 0.017235149261391452, 0.07886561850506453, 0.01565160051423816, 0.032573575905013474, 0.05552164774628417, 0.06355345144026703, 0.052242653534537366, 0.024957300216380148, 0.022793528924305594, 0.02141028439866439, 0.05036625139895947, 0.07074851092071303, 0.051674660625717336, 0.019113813271565784, 0.033634102062111905, 0.030076022019549727, 0.07837699230519996, 0.1125729509118584, 0.042747913018590024, 0.04734652432342691, 0.042873513133775805, 0.03164125647726319, 0.0577650940977037, 0.19353040313768774, 13.622246480757191, 63.62904587099629, 33.345633860557314, 54.111222451733006, 16.460271535381196, 41.28349127308015, 77.93667947092365, 57.39517588769236, 5.528070849757041, 1.1895212675294569, 0.293272951798093, 0.1496521656912181, 3.5826174097676433, 44.987244221471975, 83.14844254524478, 76.099331455846, 82.2294076796501, 73.37544148968112, 75.82049800503638, 61.35485956745764, 63.58230690802298, 71.83283605883199, 74.75214635172199, 75.3503470267019, 79.08370602515437, 74.6178287075412, 71.46595324239424, 62.36191241971908, 55.86989948826452, 54.44946804354268, 49.72432205753942, 51.12963276524698, 50.717497564131214, 51.89030585750457, 51.1419137062565, 50.471094269906324, 49.498315088210575, 49.967571766145774, 52.03530803803475, 48.656346951761556, 49.19472755924348, 49.00029959217195, 49.23330799225838, 48.691361950289824, 49.098856987491736, 48.002907537644916, 46.227513359438994, 47.61347893745669, 49.84748448095014, 49.42174650007679, 61.423775611385224, 63.93833652619393, 65.10486902729158, 66.10963513774257, 63.369890951341205, 64.48000800225043, 62.73167817823349, 62.031797901276626, 63.33807660687355, 62.17547432068856, 63.18737522248299, 59.6846241335715, 61.65075140614664, 62.324061547556234, 64.12000502309492, 61.06082300986014, 57.54566154172344, 56.080232666384795, 53.973821824596776, 52.12177668848346, 52.83434191057759, 53.26418269065119, 53.107621285223196, 54.147269033616595, 56.575981032463815, 60.31475682412425, 62.67863204402309, 55.67208651573428, 48.82827620352469, 47.38189043537263, 44.888463251052364, 43.28593577108076, 44.837346922966745, 42.880652950656035, 46.26149677461194, 45.6822842936362, 45.74929406566005, 46.38644387645107, 46.765172250809215, 44.81342438728579, 45.42824414468581, 44.83510724959835, 46.47980413129253, 44.99413190349456, 45.33761778185445, 44.714474754948775, 46.49189287616361, 44.40186577458536, 46.64633620169855, 44.26222155171056, 47.23739031822451, 46.64687748878233, 47.88318503287531, 47.902447792791556, 48.851547625757036, 52.65638397585962, 59.185326022486535, 60.27503890375937, 67.9728158827751, 61.98684361673171, 64.71344394068565, 63.47290808154691, 67.92722225189209, 63.4462594985962, 68.93123918964018, 64.40906409294375, 79.82929368172923, 13.945714542942664, 0.3201789402913663, 0.2763157794552465, 6.018618643283845, 0.639144765032876, 21.012703795586866, 73.4619846651631, 9.622976280027821, 27.733357567940992, 38.270244136933364, 31.71099589717004, 59.38576306066206, 3.9757717713232967, 0.2859782625830943, 0.05968427841341304, 0.0149857398730913, 0.029053329114591884, 0.07455680294022446, 0.07524153998782558, 0.05962348550618176, 0.037618414273545626, 0.05060896337513001, 0.04032177001898808, 0.025946065002391418, 0.017238918413978913, 0.04737869618580707, 0.04891333117660496, 0.011728329231001198, 0.007710458059239412, 0.06309177238313902, 0.024722228052034497, 0.031072892015799883, 0.06050598432099628, 0.01979711390430889, 0.040184590484826796, 0.036591668763468345, 0.061322262495635986, 0.032719806768000126, 0.02789030805410397, 0.051340883777987574, 0.034368573537757324, 0.06050663549573191, 0.013265407084667636, 0.026861258534594413, 0.03384232859037096, 0.03733958891262451, 0.015978099526687255, 0.05038495543563078, 0.011732926716156786, 0.012725506620030972, 0.05212991603560025, 0.014427879434679786, 0.037205875926320596, 0.028264928879516742, 0.012810987668232092, 0.06569152622814141, 0.021997931293181835, 0.03529822123387168, 0.2521615787859886, 17.21146818130247, 77.63206820334159, 33.496547052937174, 57.4380160147144, 20.774294291773153, 53.96675371354627, 82.37434710225752, 67.5934128607473, 6.414729491356881, 1.2437442353656216, 0.9504202621117716, 0.07115587817444917, 3.5325865976272093, 49.486316557853456, 86.5625519906321, 78.0948765047135, 87.30901825812556, 78.77269344945108, 80.77547134891634, 64.2591707168087, 66.30286678191155, 75.26095621047482, 76.56861951274257, 76.0814925163023, 81.4145274316111, 78.10258788447227, 72.65857342750796, 64.7105021630564, 61.716086326106904, 56.1170558775625, 52.74569242231308, 53.458037991677564, 52.62618564790296, 53.51188036703295, 52.483336848597375, 51.90460681915284, 52.77109761391917, 51.62112535968904, 53.99872103045064, 53.191022642197154, 51.581603557832786, 51.30304467293524, 52.6755839778531, 50.22910756449546, 53.66582947392618, 50.3708424106721, 50.432866850206935, 49.355352540169996, 52.22531941629226, 50.04199089542512, 64.49217911689513, 64.4668209937311, 66.59789962153282, 66.17978280590427, 66.08487713721492, 65.53233677341093, 65.18018245697021, 65.77104045498756, 65.91070821208339, 65.90942167466687, 66.61774681460473, 62.21229360949609, 63.98625220021894, 63.89609652180826, 67.45061505225398, 65.35741083083614, 61.68305604688583, 57.795018380688084, 57.877219492389315, 56.03449783017559, 54.991057149825565, 54.31151043984198, 57.359831410069624, 55.769561336886504, 58.175001913501376, 61.81669904339699, 64.10135807529574, 55.22859196509085, 50.7782825346916, 49.13283648029451, 46.79803779048305, 45.07047691652852, 47.393402591828384, 45.45432790633171, 47.5459514125701, 46.4619416575278, 48.70313298317694, 48.121343504997995, 48.226172770223315, 46.49708217190158, 47.07385886100031, 46.67003123990951, 50.04300678929975, 47.95665102620279, 47.75769664395241, 46.32624726141653, 48.452587666050086, 47.007763001226614, 48.75039754375335, 45.94388677227882, 50.85175245038925, 49.69775584436233, 49.583230480071045, 51.17147661024525, 50.91888773825861, 56.16439104080201, 61.22486829757691, 63.21975438825546, 68.92217851454213, 65.03427420893024, 68.07963771204795, 66.45380743088262, 69.93450303231516, 66.59451069370394, 73.80916149385514, 66.46341723780479, 81.72639508401194, 14.185597877348624, 0.4622138477861882, 1.014070401508962, 6.551908994874647, 0.4619945321352252, 25.311380278679636, 80.3916125143728, 17.06315944271703, 24.287727955848943, 46.03281474882557, 31.749007586509954, 68.37005784434658, 5.084589046816673, 0.13443874735986033, 0.13087804729659713, 0.064843658417944, 0.05739379426344268, 0.09238025218608881, 0.039528987760986053, 0.11771905461266158, 0.02811248887390379, 0.052895919690209056, 0.03196344241469858, 0.015132105759074612, 0.004431798053349579, 0.023538334926049558, 0.038359048926541885, 0.07455134839420358, 0.0398532766097736, 0.052783925296558495, 0.014740619508008805, 0.035337808827358874, 0.04032037190852627, 0.12153465511097063, 0.24177635298861613, 0.17563212242337967, 0.20663589990187078, 0.10864301179085048, 0.1143563959387041, 0.12418585559052807, 0.2102685662647409, 0.11333572933630598, 0.10465406857791448, 0.10871949800921064, 0.09832156281317435, 0.14791141474439254, 0.20120577676401985, 0.15399571568254503, 0.10675852742767143, 0.07208462954769213, 0.1961777425341068, 0.08694018522698073, 0.21730742807830536, 0.1098315205965792, 0.14881478562470407, 0.16275671250637502, 0.1442422213092927, 0.09314383500285688, 0.2728188945160758, 28.740767355888124, 91.79314244178035, 46.20921550258514, 80.85061611667757, 25.31666175011666, 53.657047287110366, 95.62289760958765, 74.35517895606257, 6.57463618824559, 4.191818371895821, 1.3069783583764107, 0.15325526106021098, 4.888485247089017, 52.72217389075987, 91.69596964313139, 83.10056609492149, 91.20349253377607, 81.20661043351697, 82.2663014934909, 66.93443113757719, 70.32955631133049, 78.55190323245141, 80.85013758751654, 78.61814421992149, 84.18940036527573, 79.4129183984572, 77.74430290345224, 68.85457254225209, 64.865506387526, 59.4686427424031, 55.96913937599429, 55.84610639079925, 55.50200470032231, 56.95073996820758, 55.80930279147241, 54.191862460105654, 56.46871597536149, 54.51890968507337, 57.565634250640876, 55.02331472212269, 53.35036500807732, 55.41264918542678, 55.77740999960131, 53.90649826295915, 57.71091884182346, 53.62979073678294, 52.02109336853028, 52.21878866995535, 53.956779126198064, 53.33618563990439, 67.5222610658215, 66.62736446626725, 69.81180344858478, 70.50545107933783, 69.1380657688264, 68.60297602991905, 67.8930191839895, 67.4137604621149, 66.79797972402265, 66.73599058581938, 68.13419788114487, 62.89169126941312, 64.70950588103264, 65.52387622094923, 69.70196923901959, 66.38809988575598, 62.664378150816894, 61.445148606454175, 60.23767832786807, 56.925644643845104, 57.34750732298821, 57.82995100944274, 60.25336388618716, 59.314199416868156, 60.37337664634951, 65.08002865699031, 67.6208459177325, 59.366119830839104, 54.45393562316895, 52.654862096232755, 50.487740808917636, 48.104210592085316, 50.38901475168044, 47.70845520880915, 51.48090454839891, 48.56377117095455, 52.611268874137636, 51.44773698622181, 51.13886994700278, 48.07075669688564, 48.6628580862476, 48.91483114611719, 52.949969460887296, 49.113228551803104, 49.49493400512203, 49.182364248460345, 51.491039952924176, 49.88368011290028, 52.5808116697496, 47.65666423305389, 52.724535157603604, 52.64326757000339, 52.2435192138918, 53.029056210671705, 53.648225876592825, 58.147835577687914, 64.94972751986596, 65.10501023261779, 72.47093508320471, 66.68677268489715, 70.72072644387522, 67.81530134139523, 74.38995469001033, 69.018598218118, 76.68619648102792, 67.38904168528896, 83.06230729626071, 16.83145719189798, 0.8303612302387915, 0.439309933252873, 18.54782166019563, 5.721532933173641, 25.765624084780296, 88.72719041762814, 13.780798489047637, 41.50986302283503, 57.72021485913185, 44.20884201603551, 82.4368461485832, 9.77878753216036, 0.6470264001719414, 0.2971817775359077, 0.1499765732836339, 0.18499972298741343, 0.1977185904979706, 0.291741848472626, 0.22828687763502523, 0.2016356593418506, 0.12672298557816014, 0.1199797341119378, 0.13731920731163796, 0.11569264480063032, 0.14563803350733173, 0.2415529157846205, 0.11350247603390487, 0.08456268498013098, 0.15332834584818733, 0.18839073457544853, 0.15623531244214506, 0.17857425245306185], [0.06347593100320909, 0.030766728807300813, 0.057140487291279345, 0.08677159225748432, 0.003917746113485567, 0.011075250766870957, 0.014447767077194107, 0.044831568750763134, 0.09377355161573618, 0.07791536304378703, 0.024256069295769258, 0.024309645654753815, 0.0494634818976685, 0.023356174539414146, 0.045981934038741935, 0.06828595193163042, 0.04667256996336003, 0.04601914675966386, 0.08208128022811106, 0.07774687732660002, 0.04802912781615892, 0.03220750845127529, 0.06756006064073694, 0.013220059467599759, 0.020968630879877076, 0.020356224023646886, 0.04045525700935433, 47.669737492838216, 52.59440268239668, 38.96586864225326, 31.687098856895204, 18.197665791357718, 65.38014881072506, 81.45813634318691, 20.249543920640026, 1.1798125433344995, 1.430749852330454, 0.05035650676056262, 0.21373393434670665, 4.3614221484430375, 62.5877115034288, 86.86457449390043, 78.99755508668962, 79.86352028385286, 69.64147844622212, 69.20987652194115, 72.35330320173695, 74.94814718923261, 76.46325680517381, 76.22132501294537, 72.24021342492873, 76.23684975408739, 71.0240041055987, 63.10003972822621, 57.9974126815796, 51.043250406942065, 50.196948051452644, 52.40060229455271, 49.88744166589553, 51.03413089629143, 50.45474583102811, 54.383674206272254, 52.026400335373424, 50.357545575787945, 48.82914304733277, 51.350642634976296, 48.38470320547781, 48.984225719205796, 49.731723570054584, 49.434156879302, 49.3619264325788, 47.91979251369354, 46.90752290910291, 47.44201252537389, 47.23604886762558, 49.58692535277336, 54.221707774746804, 62.314949881645944, 63.77880196417532, 62.39972014581004, 63.33871987558181, 62.11476779753163, 62.830608198719645, 61.975515811674065, 58.66738488597255, 57.30499667506064, 60.041273486229684, 54.758637105264974, 57.751334944079005, 64.4229571280941, 62.24443351068805, 60.40722277856643, 58.22735378819128, 58.18803202721381, 56.452344002262244, 54.900113075010246, 54.51831348480717, 54.5229144250193, 57.06131158336517, 58.25034279977122, 62.450761948862386, 64.83333510737266, 62.71201533655967, 60.77179139660251, 54.592222705964126, 47.10958380852976, 44.168378845337905, 44.231634909106845, 43.28864220649966, 46.815970866910874, 46.21665231643185, 43.194018948462706, 45.585805754507746, 44.25966808872838, 48.26320386702015, 49.9838888260626, 51.82641044739754, 47.810719243941776, 44.60111433459867, 45.29494239437965, 45.76837247417819, 46.93508540430377, 45.81214612530124, 47.22696073593632, 45.790796664453325, 46.19807597129576, 48.30222360549435, 47.40628757784444, 50.23060198753111, 52.28687709377658, 52.02441561606623, 52.30213511374689, 60.228307785526404, 63.98573836972637, 65.77254272276356, 66.49894606682562, 61.71942426312355, 64.30197554249918, 65.91175156254923, 69.48877273067352, 67.64456056779431, 74.92455021027597, 42.26732761629167, 0.2206468513055194, 0.057798698544502265, 0.9693962599961989, 4.670719177492203, 0.4472969820903194, 50.22629522508191, 42.35530637925671, 12.336741628185397, 57.329738986107614, 21.98411407009248, 44.92569046635782, 35.61052806915776, 0.45898405174093865, 0.08194677817124514, 0.10901805013418199, 0.05232408485044876, 0.13193121900962246, 0.05757766302614924, 0.018484793798697573, 0.06582106403525799, 0.04921943692850971, 0.02644944414045782, 0.03844386252063898, 0.045866235609977477, 0.039552567947295406, 0.042788090499778914, 0.035692208762010263, 0.006026513489609164, 0.06785599274500724, 0.023464148886682048, 0.009868437247801452, 0.016248542928106843, 0.04214817725662743, 0.041581210905625936, 0.05390070145949722, 0.10075607532334906, 0.07120215754595495, 0.05093281938424034, 0.08329582070150683, 0.06425413077757244, 0.03161070680606269, 0.03312492172323889, 0.014710338925191713, 0.013839640737240835, 0.03973611495307377, 0.06720788236106597, 0.057308390781643896, 0.013880449283357351, 0.07901316703928095, 0.056243229792603565, 0.04211427020509878, 0.0420444566125591, 0.053716740766239744, 0.014817331722306629, 0.029479461692033276, 0.07840431100057979, 0.02067924116648013, 0.10414183920910282, 0.06873879416455185, 0.4414099028273937, 59.025901286832756, 56.99179149443104, 45.99315174164311, 38.548861857383486, 25.591188438477058, 77.61896748696604, 84.71966558887114, 24.55296451045621, 2.196741310819503, 2.699879422303169, 0.8427426206969446, 0.22532361890039138, 4.347592361511723, 68.8530114389235, 86.71151576503631, 80.76819927461686, 82.82907532107446, 72.8817484455724, 72.56595842299923, 74.03089307969617, 77.31065350194132, 78.83350587660267, 77.36522151577857, 73.06529183541575, 76.61327177478422, 73.9144535987608, 64.94972751986596, 59.86423338613203, 53.500289763173754, 52.83468707915276, 53.543788848384736, 52.78864629807011, 52.313702183385054, 52.7565142416185, 55.82496089320029, 53.461921138148156, 52.14061975479127, 51.13994075405983, 52.11080974148166, 52.96622376288138, 53.21090121423045, 53.28881517533333, 50.80636278275521, 50.763808988755756, 49.98943505748626, 50.18711466943064, 49.70361586539976, 50.013106561476185, 51.435738455864694, 57.00983047485352, 67.01031331093081, 67.87306216455275, 68.25831736287763, 65.2497809933078, 64.46401257668772, 64.6857088611972, 64.8241332269484, 61.461320538674634, 59.50676818047801, 60.73459948262861, 57.30617730848251, 58.490933141400745, 67.02739915540143, 64.88068596009286, 61.88812148186469, 61.90380704018378, 60.278102274863954, 57.057483350076986, 58.0437280285743, 55.38074854881533, 56.15176885358749, 60.06258372337588, 61.392290746012044, 64.1086889851478, 65.21546417667021, 63.46915437329201, 63.27777801021453, 54.91919540589856, 49.662799681386645, 46.1698466731656, 47.735166549682624, 45.92020350117838, 48.49846370758549, 48.20978118527321, 44.777448408065304, 47.9040991106341, 46.15028973548643, 51.00856880987845, 52.89464442960678, 53.7895449515312, 48.46524907696632, 48.24821649059173, 48.176452805919034, 47.784015747808645, 48.881573369426114, 48.60229276841687, 48.86319706516881, 49.10434046099263, 47.76907151745212, 51.45788023548742, 48.52418268880537, 53.01536713877032, 54.6792914790492, 53.77212570559595, 54.91606535450105, 61.40971391431747, 68.7541441763601, 67.84138510304113, 68.17641042893933, 64.15338439326133, 65.69080837311284, 68.86880290123725, 72.2227196539602, 68.1019873772898, 77.50151603452622, 42.31853023652108, 0.2811442784244015, 0.05325711865518844, 2.100022771666127, 3.7982840307297248, 0.8735929201206855, 49.867166934474824, 57.32154515481765, 14.468991083483543, 55.230047164424775, 29.468555296621016, 51.39547532604587, 41.1833845415423, 0.693579234423176, 0.13861083155197484, 0.1466043002062267, 0.06474732286146571, 0.09621818414739064, 0.03258950287295926, 0.03588364264296909, 0.027256533090445786, 0.034464932076873324, 0.08917687851334773, 0.1216972649337784, 0.032805267706393235, 0.04304532750299381, 0.05843042230774319, 0.04743823270884253, 0.030227556126192216, 0.06079696749727573, 0.011281268089078368, 0.02692050202899883, 0.05797514774566216, 0.04367034416645766, 0.15821669160598711, 0.15584149728378943, 0.15386897409635206, 0.20582930124815435, 0.12216660870058883, 0.2112747155009739, 0.10238038856656322, 0.10327984473758167, 0.20123091976969473, 0.2546052307251, 0.26869427713174976, 0.1048630956680544, 0.2518379219597386, 0.10624414535179254, 0.0919009645980212, 0.13773347701757185, 0.22358686693253058, 0.12750791160449867, 0.16344718755252902, 0.1244975614451593, 0.1693233424016545, 0.15882940872782664, 0.17859734234309968, 0.08151732460265199, 0.1466510468913663, 0.21012071129535476, 1.2706493658404197, 75.73600230678436, 67.5083758754115, 61.431687032022786, 48.69472734389767, 26.996148094054195, 80.90456439602761, 98.69790246409755, 26.431995553355065, 4.614993083861567, 4.164645171934559, 0.5137156406717917, 0.5698797527340151, 5.1811019066841375, 73.85799500250047, 91.14891667519846, 87.53518996700164, 85.76968408400013, 77.39563557409471, 75.22942819902974, 79.51919894064628, 76.74747959260019, 82.66220200446345, 79.34023687916418, 74.85836413598831, 80.59579541606288, 79.27404296013617, 69.65789748776344, 64.22968626022339, 57.178147223687944, 55.30261885735297, 56.34843649402742, 56.33570448044808, 56.822953070363695, 56.249137770745065, 59.642011504019464, 57.56473602787141, 54.21072513826432, 54.72702280167611, 55.158820844465694, 54.16305657356016, 55.83013057708741, 55.805878562311975, 53.8352523311492, 54.67334908823813, 52.08254906439012, 52.33383963184973, 51.90171603233584, 52.10228643109722, 54.119494730426425, 59.55669603040142, 69.9833522304412, 72.8935940034928, 69.58004628458332, 67.7622316729638, 65.75495089254072, 66.71630028755435, 66.85869016954976, 62.15552514599216, 62.83468354132868, 65.01187355287614, 59.56798068938717, 58.807421345864576, 68.14994227501654, 67.26782475748371, 66.49114839492306, 64.05771778475854, 64.35540999135664, 61.502375987268266, 61.241338329930464, 61.369117383034, 58.890622661959746, 62.52501241622433, 63.022082621051425, 68.07659395279424, 68.9556755558137, 66.62383433311217, 66.54888568385955, 57.35179839595672, 53.414480070913996, 47.77333513382943, 50.34038912865424, 47.64564629523985, 50.65385318571522, 51.05386434062835, 47.06633575500981, 50.64868742419828, 48.20942032721735, 55.43923893282491, 55.91401830796273, 57.506018146391845, 51.62534582999445, 50.232268994854344, 49.8029028215716, 49.20123477135935, 52.825457742137296, 50.85818121510168, 53.86854933154199, 50.314164161682136, 51.012510791901626, 55.1554476061175, 50.6079928336605, 56.264701735588815, 58.18968726742653, 56.64054324550014, 58.393544612392304, 65.18447745230891, 71.91209147053381, 71.66894374355194, 73.4432122015184, 65.69008665700113, 66.42553498668056, 69.51469959751253, 73.98137707864085, 71.418578855453, 77.57060466274139, 45.188877582550056, 0.47909765954940553, 0.24221921309588418, 1.2736830740205705, 14.929100794176902, 1.190379408578719, 59.74160832743491, 54.316746804022024, 18.71663655004194, 80.43891629865094, 35.698322480724705, 59.77581924007785, 54.57460341915008, 1.1244761126656686, 0.3177547929508071, 0.23386390579323615, 0.17066100852624064, 0.2689396704156553, 0.19547861069440844, 0.09432757108081734, 0.1841676748928524, 0.1308499471915345, 0.3037787751565057, 0.21437265249269627, 0.09964406039685973, 0.1862915617323691, 0.22757725039076424, 0.1517417471134855, 0.07445195614690743, 0.10069597572568925, 0.14882097561513224, 0.12180102388224295, 0.14770795711346213, 0.1300816682557906], [0.07918654039742486, 0.07644635880546224, 0.06159417008260085, 0.022498050727130427, 0.018857189138690313, 0.011285695119670803, 0.0932835464576079, 0.06788423074589622, 0.05445337644027126, 0.010113275117961871, 0.011475443607196214, 0.0530104881392852, 0.05829858240641414, 0.051435419027843786, 0.055404080062984466, 0.005902083573727719, 0.06089857756911267, 0.028233796981493794, 0.04159984982482368, 0.034870441567393086, 0.06684442726714958, 0.01731140182293471, 0.0629349541850388, 0.0672415902297343, 0.004809447798892977, 0.013209494157514025, 0.05843522950946804, 18.60219943907953, 71.59397156007829, 31.0354245093561, 43.69596073704381, 16.346969950583674, 33.52485087610061, 79.29865191059729, 42.69673301327614, 1.1709953003352689, 1.9673742185677252, 0.3864006529892645, 0.20677640042718382, 0.20755515944573188, 16.416095841315485, 86.31678412037512, 77.71705027549498, 79.27080308237385, 75.48693180084229, 74.92702914822486, 74.29882234142673, 80.50419238305862, 77.37359969846665, 65.6144476705982, 75.31025255880049, 78.39513394140428, 69.69272813489361, 55.59820867353871, 53.62881406661003, 53.13075150212934, 51.46293224826936, 52.073609982767415, 55.479639345599765, 51.972055896635986, 59.0922874019992, 59.80015754699708, 62.01567695986841, 59.88135845430436, 52.95824566195088, 48.93196405902986, 48.63838249637235, 48.793747578897786, 48.91837304638278, 48.45839669627529, 49.333995234581735, 47.59513401216077, 48.941063957829634, 47.03806331080776, 48.82178860325968, 48.61371471035866, 49.36249909862396, 58.46742637695805, 65.1320981210278, 64.4218510197055, 65.26763169996201, 65.54939516129033, 66.9070137700727, 65.86725619531447, 66.48141307215538, 63.22725396002493, 59.09639020119945, 56.46095752716065, 61.616638552758005, 65.20381473725843, 63.69542806379257, 60.6205173461668, 59.89405908892232, 57.8292332157012, 55.31454286267681, 54.93099781774706, 58.37167739868165, 59.39932269434775, 59.19998391982048, 63.26956064470353, 63.84647853912846, 62.905058706960375, 65.66809000507479, 64.75980243375226, 58.161148102052756, 51.27279143179617, 45.64859505622618, 44.54661300105434, 43.74011878044375, 44.50425924793367, 45.048197853949766, 43.92598029105894, 46.21882138713714, 51.500681138807735, 59.70703263436595, 64.97440315062, 63.01324944342337, 61.03074235300864, 49.31865876720798, 46.684642068801395, 48.42798263795915, 48.101982685827444, 45.984891230060214, 47.521820991270005, 47.41521489235663, 47.35265701047836, 49.281525688786665, 57.23725734218475, 64.78581951510522, 61.82708547961328, 57.7947045910743, 58.00311188543997, 62.07459488222676, 66.84493049498528, 63.52884500257431, 69.06127360559279, 63.5032868385315, 66.94081675621771, 62.98342766300325, 69.15293939651983, 66.28616532971783, 73.0493591677758, 9.121299251433342, 0.5018569366826166, 0.09129799211457854, 4.6760374211495925, 4.191110384079718, 1.360423471177778, 67.26262369463521, 16.96489034160491, 31.17925782357493, 38.65117296095818, 24.577187107455348, 57.79710900398993, 14.05582331841992, 0.35604828007278905, 0.09052081123715447, 0.11915533923574033, 0.052261686989016114, 0.026288437356631604, 0.04764578891016784, 0.043583121225838704, 0.15045392266925306, 0.037863535596238035, 0.03808080196200359, 0.020513704887801604, 0.07716162445684595, 0.005391420375916266, 0.06514874527290945, 0.0685282425594426, 0.08392612720208784, 0.04588649097469546, 0.07591071012880533, 0.06610021881398655, 0.05244741734537867, 0.03260158407952517, 0.05344112531372136, 0.018846929306164384, 0.05919597780091628, 0.03958434527439456, 0.04722398472949863, 0.03491275260345109, 0.04500875339633034, 0.043680904688493866, 0.0064066525421015205, 0.025414204630520076, 0.009752028272487223, 0.08594306816737499, 0.035024191583356554, 0.02293584507799918, 0.01982644166527016, 0.01596094586045271, 0.018106315720586047, 0.004740396942642908, 0.035908015730280074, 0.059499352449370976, 0.019824882676344247, 0.011829143529006792, 0.02248842291714203, 0.08138566473198515, 0.037568511306158, 0.026116354856640104, 0.1465580897826341, 21.43356627033603, 80.4654707447175, 32.5659921861464, 51.396957981971006, 22.687432304505382, 48.38529548337383, 86.6666752292264, 49.90227214751705, 1.528392599955682, 1.8443536133535448, 2.1792453335177515, 1.2356999444384729, 0.23769266002120512, 19.090720838116063, 94.93978546511744, 80.35465594260924, 82.67439273095901, 78.92742310800861, 77.69928193861439, 77.51419313492315, 84.28509050799956, 78.29323076432752, 68.67819140034338, 77.56909847259521, 80.11374396662559, 71.92730242206206, 58.75692475226618, 57.74774205300116, 55.16282166204145, 53.80186119387227, 55.351668096357784, 55.27984165376233, 54.58850822141094, 59.710021480437256, 61.79487105338805, 61.288830387976866, 60.61985838797785, 55.407224547478464, 51.6899747233237, 51.449909979297274, 51.14320416604319, 52.46580385392713, 52.15639552762432, 53.36514057651643, 51.85151753887054, 49.957197097039995, 48.93820454997402, 52.3569659263857, 51.52462328633955, 53.83311463940529, 60.4971823384685, 67.00810109415363, 65.35326488556402, 68.16546701615857, 68.7405570860832, 67.86957125509939, 66.69778670034101, 65.86291020916354, 65.45341868554392, 62.48710663087907, 58.75577942017586, 62.823920557575846, 66.9767221327751, 67.05600107869795, 64.44360056231099, 62.33743682984383, 59.214241735396854, 58.14135582216325, 56.66758798783826, 59.46084507050053, 61.25544709544028, 59.66566339615853, 66.9382829050864, 66.0673676767657, 65.74792200519194, 68.10358770432012, 65.10362955831712, 61.361837463994185, 53.97607718744586, 48.91126178926038, 46.1680619947372, 45.97885862473519, 47.45199887983261, 46.472006459389966, 47.048747847157145, 47.57880910750359, 52.688233621658824, 61.13204540744905, 67.09577391224524, 65.40930771058606, 61.59081758991365, 50.68212562991727, 48.52548099333241, 48.36375774875764, 49.63289945356308, 49.977377691576564, 50.505536602389434, 50.392717469123106, 50.73363419502012, 50.6735356392399, 61.26922638185563, 65.51637272680959, 64.91568526914044, 58.7527709622537, 61.763794114512784, 65.56940709390949, 68.8451353196175, 66.17587612521264, 71.7417743129115, 64.55958504830637, 68.3693047492735, 63.685680973914366, 69.71310092556861, 64.47754475378221, 74.83114288699242, 9.157507631086535, 0.6117046600387943, 0.5940492138747246, 5.416620623680854, 0.6385347751840469, 1.8357047871235879, 70.91953569842924, 23.802471929980864, 27.08054965542209, 38.929445512833134, 25.19831011372228, 68.09875534426781, 16.696055012364543, 0.542271843840999, 0.09082852577370021, 0.19097525476207658, 0.07582192053838123, 0.04279644851903281, 0.03304041839475113, 0.02651368635856817, 0.09342263738114027, 0.01530496775352907, 0.013468141720119505, 0.04929311543462738, 0.03168925380093917, 0.0404024543991733, 0.030689727394811572, 0.03205203090704257, 0.023553074457712715, 0.0420532436410506, 0.0484111950161957, 0.03465297218832759, 0.04156552908581592, 0.06544093120723002, 0.15105156318074273, 0.14875173658853577, 0.18468708250551455, 0.08522062427214078, 0.24060359495061062, 0.15374822331772697, 0.19688730849133385, 0.23558155152826543, 0.14541563818291312, 0.15385740616869542, 0.11365103580418134, 0.12551946910999476, 0.17574870568369666, 0.1631451344057437, 0.2546655831317748, 0.15445363707840443, 0.12875039130449295, 0.16525684044726435, 0.09886301077541806, 0.1514884324804429, 0.18612286917144255, 0.10826801941279443, 0.17270171353893896, 0.1095054122889715, 0.16077015458816485, 0.10399859608902086, 0.1809941863100375, 31.427453640968572, 97.62118831757577, 44.67331732473066, 66.79430838554137, 26.54908810892413, 48.169835767438336, 95.81165775176018, 55.670309682046216, 3.206940639403559, 6.941470955648731, 1.2838032793614174, 1.1139026284217834, 0.5117882247413359, 20.20496618363165, 94.44977160423034, 84.13356150350263, 86.34316598215412, 80.54234135535457, 81.89361356919812, 80.02629080126363, 88.86936849163425, 80.61531313004033, 69.54069706701463, 79.61631682611282, 84.75583768660023, 76.65085592577535, 61.00073229882025, 59.18687143633443, 58.7542300839578, 56.24030459311701, 57.573784935858946, 59.946501178126184, 56.935874185254505, 64.08234634707051, 64.8010971469264, 65.62333968377882, 64.28113598977366, 58.47254507003292, 53.71328623064103, 51.76080096152521, 53.904470397580056, 55.732208605735536, 55.65907209150253, 54.302912604424264, 53.52507522029262, 54.57185776002946, 51.146047884418124, 54.54475810450893, 54.18586123374201, 55.110563924235684, 63.74152375805763, 69.99560571485951, 68.1646276289417, 70.06368237157022, 72.20462183798514, 70.47896723593436, 70.55706947080552, 69.93852738411196, 67.29134328903692, 63.44956213428129, 61.479343829616425, 64.16108400590959, 68.04118279487857, 67.17290339931365, 65.91586220648982, 65.07460794141217, 62.877962973810014, 60.13947786823396, 59.049596325043716, 61.80403371011058, 64.62820691447105, 62.733851171308956, 70.34901126738518, 68.57715114470452, 68.96431261493315, 68.95359669962238, 68.70541264933925, 61.5007285917959, 58.039562471451305, 51.22125148773194, 49.48391998967817, 48.75219791166244, 49.8138266225015, 48.75667725839923, 47.81603405552526, 50.20417697968022, 57.886935203306145, 64.58464899370748, 70.2220755238687, 68.63135830048593, 66.07509474600515, 53.922603514886674, 50.96313991854268, 52.095587022842906, 52.76779105586391, 51.513605348525516, 53.89159325630435, 52.20097718700286, 52.32752853824247, 54.451491986551595, 64.94541683504659, 68.00625801086426, 68.4691055359379, 60.90280248272804, 64.89223734025033, 68.24810351094892, 72.11315216556673, 68.31068100467806, 75.23440176440825, 65.7681300563197, 69.82841076389437, 62.97393552718624, 69.8917256632159, 63.56620165609545, 76.25029563903809, 13.100385915848518, 0.6652721017599107, 0.28844883485186484, 13.711542179507594, 12.133636397700156, 1.5826959763803792, 82.12252309245449, 23.279002212709, 44.92624352055211, 60.05413493802471, 37.748415931578606, 75.9041621608119, 26.756267701425863, 0.6642689555883409, 0.30002184933231724, 0.35828902596427553, 0.1552306953817606, 0.13329235806820855, 0.09628516321461048, 0.29977470936794437, 0.4283482262924795, 0.19303730298434535, 0.16475566572720007, 0.07960941327074844, 0.1202638531404157, 0.16402196800035818, 0.16581591609264576, 0.21570281095562444, 0.3046741480788877, 0.16583644724901647, 0.19207011697994125, 0.1549941274307428, 0.12289387894974602, 0.12515525558903334], [0.03382548231691603, 0.007607857339955386, 0.054044860054648695, 0.047319515893656405, 0.027304888560226368, 0.0781672987185659, 0.03200428447716179, 0.06303518912905166, 0.046176409288760156, 0.030613233515572165, 0.08696424804868237, 0.034853185436898665, 0.08404172986986176, 0.05428218643271154, 0.025924991838814273, 0.02757524290392476, 0.06429699339693593, 0.028448684644254468, 0.02795419978698896, 0.03615228669537652, 0.019452565860363747, 0.05969660859855433, 0.01292814836732202, 0.02361484412704745, 0.04553036734221443, 0.08965651850186049, 0.019968330724945953, 0.34720033226955327, 49.63695126195108, 51.56924024704964, 34.96889498925979, 41.48720741271973, 17.31193773208126, 62.143546227485906, 70.57164499836584, 7.414624018053855, 2.670619276262099, 3.862427530750152, 0.8012927900398932, 0.3070278153304131, 0.6182398190421443, 36.88336072429534, 83.89471269422963, 84.51164660915252, 77.52649368778353, 83.13097230849728, 82.81428014078449, 81.78672898200251, 76.47471012607699, 75.42386008847144, 76.64782785600232, 73.69876246298514, 65.56555924877044, 55.05704710560461, 54.77439718861734, 52.24884971495598, 54.7683528161818, 52.49892827003233, 54.175651304183475, 62.54037634018929, 69.90975287652785, 68.17341373812768, 66.99346280867054, 65.87925080330142, 62.47841858094739, 58.494125950721006, 52.3107486386453, 49.808990340079035, 49.085218906402595, 48.357297605083836, 48.69506074536232, 48.8401609851468, 48.79711297250564, 50.26275757820376, 49.789429480029696, 48.605485577737134, 48.46148752397107, 53.18405651277112, 62.095465813913655, 63.046099293616514, 62.59947861394575, 61.33164698077787, 64.82203475890621, 64.39624578722062, 65.75434684753418, 64.55598823485836, 63.956583392235544, 58.236598814687426, 60.8947459343941, 65.25131464004517, 66.16729397927561, 63.42518852603052, 58.823899222958474, 58.375356581903276, 58.74913492510396, 61.53195065836753, 59.59614722959457, 62.07814462723271, 62.91893605263003, 63.46573014413158, 62.188453443588756, 59.37585907597696, 54.459171987348995, 64.28189692958709, 59.825084209442146, 52.32241768990794, 46.21067462428924, 44.33158866820797, 43.63079840137113, 43.56977416623024, 44.47601033795265, 43.68191080708658, 47.51871055172336, 54.51412831583331, 62.87808848965553, 62.96953462785291, 62.54483607507522, 62.06277678089758, 59.60756132679602, 48.42809638669414, 45.317425420207364, 48.232966315361764, 47.70502705727854, 46.931602339590754, 49.942931436723285, 48.71921862325361, 57.086077428633175, 64.47884305830925, 64.28605856433992, 65.76754170079386, 65.01187355287614, 63.64249960068734, 64.29109881001135, 67.31242995108327, 64.77706086251044, 67.03554199587914, 71.22344093938028, 61.88908246255691, 70.72113437037315, 65.48660978194206, 72.01168829394926, 27.445384994629894, 0.3053721154649412, 0.22185474213573242, 0.7427311904968754, 4.33445732439718, 3.6828702495944117, 11.626219960951037, 51.36933272884738, 16.905489967715358, 48.15322845212875, 58.07879401791481, 47.6296155683456, 56.26926345209922, 5.947932629815995, 0.423820524085914, 0.15181636407731042, 0.04032309918153671, 0.05672549363225699, 0.08414280751059133, 0.08231476850567326, 0.04507297071658316, 0.015017366855435315, 0.04499953735860125, 0.07738031957659029, 0.02467853805771278, 0.03636770678924457, 0.04341597233207957, 0.04135251833846973, 0.032598856806514726, 0.03535793778756934, 0.09299767308778341, 0.0613647535623562, 0.05166962359761519, 0.04156998388709561, 0.03595913294702768, 0.022457543828134096, 0.05957244106778695, 0.010339927018409776, 0.035556729943040884, 0.051315124071533644, 0.032700995479019425, 0.03156706277701644, 0.02337702553749325, 0.055484818069324385, 0.06055908570546777, 0.0639173508651795, 0.03853964266337214, 0.08814666645541307, 0.025295962789847005, 0.034815896107184316, 0.04149514858821227, 0.027060142620616866, 0.012896381573931826, 0.08408010321398897, 0.04767172864728397, 0.009764194706334703, 0.023293617714737213, 0.028283347548436255, 0.02926835850361855, 0.02936384753294049, 0.07180673115315937, 0.06420110217145374, 0.3193066112937466, 58.91205057021111, 54.30060625076295, 38.99340368086292, 44.258773788329094, 28.02872184784182, 78.35770668522005, 75.47140705970027, 8.94836881468373, 2.863449367784685, 5.397766770855074, 1.5984440474740922, 1.5353804249917309, 0.7127341904467153, 42.71690968544253, 84.98289585113525, 82.79440156875118, 81.97155106452205, 86.56860813017815, 81.95710889754757, 80.29319240200905, 76.58539941233974, 75.0428096709713, 77.84600211728004, 75.43482703547325, 69.28579791899651, 57.231185513158, 58.071047336824485, 53.75669902370822, 55.99742750967703, 55.482710561444684, 54.288003675399295, 63.81830807655089, 73.60974034955426, 71.83338519065612, 70.81659701562697, 68.27333219589727, 63.487699339466715, 59.45884073934248, 54.77923347103981, 52.155869930021225, 52.566432260697894, 50.56580382008707, 51.76307201385499, 51.392482557604396, 49.92162119957709, 50.761192767850815, 50.40226451812252, 51.829309078954886, 50.775297610990464, 56.1282346325536, 64.98626047565092, 65.9225929937055, 65.27562549037319, 65.95652149569604, 67.2221056107552, 66.70340353442778, 67.97693437145603, 66.12239068554294, 65.59038000722086, 62.21344286395658, 63.925792786382864, 65.37239820726457, 67.99630303536692, 65.41702693508518, 64.00880975107994, 59.868430322216405, 60.803903841203265, 61.7679714387463, 60.79569824280278, 62.74532802643315, 66.2010734311996, 66.24989125036424, 65.0454019731091, 61.78098194060787, 59.20198825097854, 67.3766234613234, 63.87325656029486, 55.286093911817, 47.15671108615014, 46.434551746614524, 47.30202313392393, 47.115961582429954, 47.88424015045167, 47.5047351467994, 50.74383235746815, 56.19715459885136, 65.29435088557582, 65.87698367334181, 64.37868925832933, 65.28405074150332, 60.86403377594487, 51.577398777008064, 48.53665974832351, 48.58190821063135, 51.72926510533979, 49.75256704515027, 52.1839697899357, 51.691857461006414, 59.51415400351248, 66.5997588249945, 68.42719893301687, 69.13413555391374, 68.08477601697369, 67.16189722861013, 66.06653613428917, 71.92306626227595, 68.93596172332764, 68.82907713613203, 74.63811520607241, 62.117325182883974, 71.48479630870204, 66.53143113659274, 71.59539930282101, 27.243328017573205, 0.5976398986193442, 0.7398691472987975, 1.3023631995724094, 3.9477530554417646, 2.0413142058157154, 11.392887965325388, 61.75617294926798, 18.13234656087814, 56.47386604739774, 69.2580275381765, 46.908138721219956, 65.61218446300876, 6.350091772694742, 0.4708103042456412, 0.14328505573493822, 0.0405144909276597, 0.020804437170285853, 0.07742662193073381, 0.023753241741008336, 0.06425714150311486, 0.006944127859652884, 0.1052429833479466, 0.013173072422373922, 0.015707925213651074, 0.041297375329680024, 0.030226705768596263, 0.03383910719064936, 0.09133032102498317, 0.022824076680286277, 0.09826701735296557, 0.10766623436563438, 0.04321836761289066, 0.03567634691153804, 0.07213201208580887, 0.186881005103069, 0.10134435424040403, 0.19779227283452788, 0.1276769718876289, 0.07981092503835117, 0.34028393727156425, 0.14536142980139102, 0.23523203157369169, 0.16451600278096815, 0.16035830572007165, 0.2722956871073092, 0.13520956970751286, 0.21856529848469844, 0.16881476727224168, 0.07275609795244471, 0.12358321252489284, 0.1922858933046941, 0.16684418994813197, 0.23468501415223847, 0.19090296670554147, 0.10834321094256257, 0.14570073014305485, 0.10542579490931765, 0.07698344006653755, 0.15174401473374138, 0.21955940481876174, 0.1952880539841229, 2.1737260683890316, 77.77446593007734, 68.77004546503868, 55.305674383717204, 60.94124563278691, 26.470015087435325, 77.46594798180365, 91.23098050394367, 8.92420897560735, 7.752365585296386, 11.135974680223773, 1.7569901722092784, 1.0154868674374398, 1.2767817464567002, 46.6269047798649, 86.74888026329779, 89.86390898304602, 84.22415256500244, 89.8097724299277, 86.64826362363755, 82.36607874593427, 76.06819568141815, 79.88989430089151, 82.55090867319416, 79.10595370877174, 71.74368842955559, 60.1535277981912, 60.27227755515807, 58.40274649281656, 60.62309826574018, 58.11086723881384, 58.618335646967736, 67.55656611534857, 76.70130545093168, 75.62197900587513, 72.07303416344428, 71.46192889059745, 67.98790131845783, 63.87376254604709, 58.41471756658247, 54.92492598872031, 54.60821420915666, 53.60099661734797, 54.08487981365573, 54.34721969789075, 52.91928475902927, 55.06386418496409, 52.8763504951231, 54.621660094107355, 53.39628027331445, 57.60227311042048, 67.30746423044513, 68.7838129843435, 67.14898478600287, 67.42542559100737, 67.83958081276187, 69.02867870946085, 71.73173304527037, 68.7308531422769, 69.25827072512719, 66.63800977891492, 64.66404168836533, 66.70821236025903, 71.65589009561847, 69.3775970705094, 66.29164095847838, 63.763104638745716, 63.974802801685954, 65.24208530302971, 65.31938345201554, 66.87520334797522, 68.33122637964064, 68.0292901685161, 66.18483481868621, 64.8521585618296, 62.98568302585233, 70.92378754769602, 64.79162854533043, 58.540766854440015, 51.6416040543587, 48.613612728734175, 48.33633645888298, 48.34882528551164, 49.95180383805306, 48.993031440242646, 52.53086420797533, 58.65363305614841, 67.72007403835174, 68.39505118708458, 67.5536714061614, 67.74561651291387, 64.73480909101426, 54.69816984668855, 49.05120803463844, 52.60358887334024, 54.819320094200876, 52.809124992739775, 55.69761722318588, 56.38665606898647, 62.0034077859694, 69.3881796252343, 70.58533407026722, 73.35388414321407, 70.46873769452496, 69.2722265182003, 68.7785020951302, 74.80225070830315, 71.91438213471444, 72.17943237673852, 76.1932094635502, 65.39346525746008, 71.62049462718349, 66.10139816038071, 70.99351159987911, 33.55248397396457, 0.3321868475646742, 0.43505783883794663, 1.1969949761706016, 14.500013109176392, 6.485298814312105, 14.423051303432835, 64.98560151746197, 24.72493298592106, 68.97909210574242, 72.76886263201314, 60.814729582878854, 74.67079639434814, 12.928273293279833, 0.8402505060357432, 0.3664000278278705, 0.24461132263944996, 0.2239672755522113, 0.33648153646819057, 0.18719980493187907, 0.229764937032615, 0.19666509702801707, 0.23363856869118832, 0.1579944035338779, 0.10505397413526812, 0.1665587149440281, 0.19594066896505896, 0.1273394335481909, 0.2046267883551698, 0.0953610773168264, 0.18263048882926666, 0.19568972920458164, 0.09659764281804524, 0.18307946231817046, 0.1063374548609699], [0.014916048854619507, 0.08879563485782954, 0.08015779432870689, 0.04574089213424633, 0.04699354165143544, 0.004481968672705754, 0.06045642609317457, 0.031467496244717515, 0.03040445348878782, 0.02503982320758364, 0.0062967782967814035, 0.04613915826344202, 0.019621367588819518, 0.05401915780478909, 0.04782946615089332, 0.05214406567956171, 0.079539607339088, 0.04862596393532811, 0.050426910240804, 0.022312341438185786, 0.017918988070901365, 0.08973068347381008, 0.059410907598512794, 0.052953602280467756, 0.07122472649620426, 0.020371928826094638, 0.07182898600735972, 0.08582352014679102, 20.293319532948157, 65.65571100481095, 30.78086856872805, 41.55095377276021, 23.111089468002323, 18.212460971647694, 81.18913235202913, 18.00434785504495, 1.4697775581190664, 4.488669230091957, 2.255813676503397, 0.5603916005742166, 0.1471095198705312, 1.3089537620544434, 57.468547744135705, 87.82324883245653, 79.27806731193297, 82.15951104317942, 83.40907619845483, 85.17498216321393, 80.01170742896296, 77.81768260463592, 75.83610119358187, 72.99279858989101, 56.48815131956532, 52.70918692311933, 53.01640264449581, 56.62592064949774, 54.44299221038819, 55.042193089762044, 62.87609984797817, 70.41900988548034, 72.07363036371046, 70.21339924104753, 69.58550622386318, 69.06019103142523, 69.57708097273304, 67.90401750995268, 63.528739098579656, 55.698229112932765, 50.69698356813001, 49.51234148394678, 48.8906850353364, 48.717104465730735, 48.624454159890455, 50.03637798370854, 47.36774244616109, 49.61155783745551, 49.894674516493275, 50.641689915810865, 55.69135712039087, 62.4888167842742, 63.5947290543587, 63.836915800648356, 65.49266592148813, 67.13048688827023, 65.36503199608096, 64.66732471219956, 61.58017227726599, 58.16392514013476, 58.96897592852193, 66.90586843798238, 65.38618533842026, 64.80383496130666, 64.82742801789315, 64.29619004649501, 63.0358854416878, 64.70774473682528, 64.81168754639165, 64.99378358164142, 64.05635279993858, 65.84696969678326, 62.80489313986994, 66.49205054006269, 64.96263211773288, 56.01297970741026, 61.84038231449743, 52.60114915909306, 46.895410630010794, 42.343045050098056, 41.76123203769807, 45.50279271218085, 45.239656586800855, 47.113855269647416, 48.44266406951412, 54.65496101687032, 61.430227910318685, 67.06094326511507, 65.01538799655053, 61.770226801595385, 64.0180940012778, 55.21053337281751, 47.21299709812288, 48.20476447382281, 45.617490660759714, 49.46703418608635, 49.9437080660174, 54.740806010461625, 62.82565816756218, 67.36614288822298, 66.62627404735935, 67.9587188843758, 64.501235869623, 66.23148748951574, 64.27338930868333, 66.09682467675978, 66.3407019645937, 71.09561874020484, 63.78116323101906, 67.80660936909338, 65.86231400889736, 64.51979652527841, 65.0154782110645, 2.918121324431512, 0.4554533057155148, 1.357558302340969, 2.4933080423262814, 3.33611041788132, 1.384106987426358, 24.168835032370783, 29.406770121666696, 19.953252000193444, 43.560474226551676, 50.91469864691458, 49.32758608172017, 44.93699865956461, 0.17006189712593633, 0.1741435982647442, 0.10870974570993455, 0.07928151997827715, 0.05220222324433346, 0.07339103162408837, 0.03402997416654422, 0.07737333285472087, 0.03405014909203014, 0.07654960447501752, 0.03618164318463495, 0.04738427713633545, 0.017300688083313646, 0.0464972967071639, 0.09811093459927267, 0.052591936001854564, 0.09391602098701463, 0.05208194360978181, 0.03001337900998131, 0.043981326068000454, 0.0692626374262956, 0.028733177140595454, 0.023720903254504648, 0.053567112303308906, 0.04262368037034908, 0.027016986972622337, 0.03824674426728199, 0.0234757378817566, 0.015138773596845569, 0.044947018200952205, 0.05821121773952919, 0.03053823733822473, 0.05649901122876233, 0.037023972179139816, 0.004130414275888113, 0.07768943605403747, 0.05755736935703505, 0.026499226448997378, 0.05145869660942305, 0.056641235451905005, 0.03531383793620813, 0.054257112374949845, 0.005464808247427667, 0.049271546229119265, 0.029474422748711322, 0.08146090988790797, 0.007124033553766148, 0.05890709753598898, 0.08842187588133159, 0.19098231809273844, 22.66577493759894, 75.15663685337191, 33.98766309984269, 47.90010613779868, 21.768717112079745, 35.055669584581935, 91.21813081925916, 22.211625268382413, 0.33717545891000383, 3.3539758334236764, 3.0058176767441536, 3.5872580639777647, 0.15409993428376415, 1.8594685893866325, 61.745531558990486, 87.90479490833899, 83.76360354884979, 82.76765884891634, 83.59895813849666, 87.0274862166374, 81.19719674510341, 80.43084406083631, 79.75729465484619, 75.69618240479501, 60.398475893082164, 54.10763348302534, 57.5928476548964, 57.526932224150634, 57.58328099404612, 57.15929239026962, 64.07849065719113, 71.50566331801876, 73.06694707562848, 72.62091082911338, 74.29464109482305, 72.91859519097113, 72.54224377293741, 69.57268007339971, 64.11742410352154, 57.72438826099519, 53.69002265314902, 52.291470189248365, 51.54499607701456, 51.42653265307027, 50.11957929980371, 49.95633809797226, 50.23322213080622, 50.76220081698511, 50.630887708356305, 53.23185451569096, 60.11855202336466, 65.4994123981845, 65.74192862356863, 67.25623807599469, 68.42054659320463, 68.77596039925852, 66.78684019273328, 65.35805802191457, 64.47998839039957, 60.46869416390697, 62.78401044107253, 68.87940114544284, 68.1997485314646, 67.00640663023918, 65.66303014755249, 64.23514619950326, 63.920548577462476, 67.8056993792134, 65.86958608319684, 66.86421286675238, 66.31081350388067, 68.62395286560059, 64.43966642502816, 65.42112973428542, 64.19552241602253, 60.80414702815395, 65.11600855858096, 56.58049960290232, 48.101480622445386, 46.61284308279715, 46.44388698762464, 47.892681091062485, 47.637754486453154, 48.82768784799884, 50.550926270023474, 56.377234535832564, 62.400324190816576, 68.51472270104193, 68.03823317250898, 65.3410663143281, 66.18184597261491, 57.95965594630088, 47.433053831900324, 50.05112609555645, 47.98624530915291, 53.028609060472064, 51.74966143023584, 56.39850554927703, 65.75904976937079, 69.00811764501756, 69.41101566437753, 68.97502068550357, 67.7633220918717, 67.65551967005577, 68.08962406650667, 68.79989470205, 70.1194663201609, 72.96724827058854, 68.97870771346554, 70.07148004347279, 68.37989514873874, 63.374417366520056, 71.11345767974854, 2.6317809474083687, 1.1185675522973462, 4.508577219901547, 3.5421873340683603, 2.140871315233169, 1.5663106427077325, 27.21022321331886, 36.28751347141881, 25.25614546191308, 56.15653061097669, 53.81388718082059, 55.48934721177625, 51.03127148843581, 0.37765131602364205, 0.07950643573196665, 0.04669387103809465, 0.08407159197715022, 0.034464614150384744, 0.03788789336179053, 0.033048764922686165, 0.08922486626092466, 0.030096725545703407, 0.07582640215273827, 0.005227523046590749, 0.07824467359891824, 0.04412081535725344, 0.036819606734019135, 0.05713456543162466, 0.05059440004368944, 0.023968692478393356, 0.05130640216051571, 0.017865668351371444, 0.02604253845469606, 0.016685521395336238, 0.0510747026982567, 0.1246928908832131, 0.21378042056195198, 0.1746257433607694, 0.12133408563151477, 0.12442819218361571, 0.10064879237043281, 0.16408395983519095, 0.1546610783665411, 0.2177862789962561, 0.1271340760192083, 0.14466159316080232, 0.11530141135857952, 0.10713293757890502, 0.23290703133229287, 0.1832553254620683, 0.10663937011192884, 0.19512775774684646, 0.16978324030435857, 0.16364306091300904, 0.17239604445715107, 0.153033264101513, 0.17371100373566153, 0.19850772234701342, 0.11210219754326729, 0.14931519425684406, 0.25712515437795275, 0.189733901211331, 0.2170673974098698, 35.95214297694545, 90.07427354012766, 49.33483462179861, 70.63670143004387, 35.74145678550967, 29.660825960097778, 102.37532846389279, 25.265525810180176, 5.777462990053239, 14.709018564993336, 7.332827400776648, 3.695993519598438, 0.1938733807013881, 1.9853186943838674, 66.82239255597516, 89.86690567385766, 84.95706312118038, 85.96858747543828, 84.3721200573829, 89.47767319217806, 85.83873348851358, 81.35140080605784, 81.65076394234934, 79.34177444827172, 61.934068126063195, 58.22446300137428, 59.558774886592744, 61.442901088345444, 62.4370454203698, 61.431792936017445, 69.16299635364165, 74.02395048449117, 76.70245862776234, 75.68449374168151, 76.66865564161732, 75.40711941257601, 73.33290730753254, 74.28430957178917, 70.44245781437044, 61.99000896946077, 56.63717392952212, 56.451681121703125, 56.15238858807472, 53.652022730919626, 52.61087271475023, 54.045452148683616, 51.44086107130974, 52.2791814034985, 53.37162817678144, 55.65946040614959, 60.855412406306115, 68.23457917859479, 68.01149045267414, 69.13415908813477, 72.27367908723893, 69.18741703033447, 69.07523724340624, 69.28808858317714, 68.01626005480367, 63.36543121645528, 65.69898651492211, 69.15177837494882, 69.60307844223516, 70.37663259813863, 68.46020175564674, 68.66750686399399, 67.28265131673506, 72.40438030612084, 69.45724471922844, 70.10151755425238, 67.1673728573707, 70.56996622393208, 65.88920577879875, 68.62505897398918, 65.11997799719533, 60.31723968444332, 66.84489127128356, 59.26659361008675, 51.970404578793435, 49.2024899298145, 47.66525814610143, 51.25021034671415, 50.489705916373964, 51.50896910698184, 53.4519269389491, 59.78851595232564, 66.1788728160243, 72.35859840146958, 67.50849354651668, 68.80270311909338, 70.81754622920867, 59.645078797494214, 50.13370375479422, 53.01362168404364, 50.34584514556393, 56.014376071191606, 55.409275947078584, 58.84098506742909, 67.95528288810485, 73.63796572531425, 70.92840809975901, 69.96538777505198, 69.1778935155561, 71.09843500198858, 69.84988181821763, 72.89878722160094, 71.65481536619126, 75.72861256137972, 69.86823851062407, 73.35907736132222, 68.19246861242479, 64.46727598867109, 72.23658915488951, 4.4971518458858615, 0.6202423728762135, 3.9788562251675517, 11.069745459864217, 12.454796145039221, 2.385917959674712, 31.12673140341236, 38.38630314796202, 33.272658163501376, 58.15110291204145, 59.353066182905636, 63.73468314447711, 67.88397419837214, 1.515283671117598, 0.5672741957729863, 0.33440568334152626, 0.21429918466075776, 0.20943167649449843, 0.3846822564880694, 0.18010342523695963, 0.23953726184704613, 0.1541946074294467, 0.24091358476829147, 0.15300913233189814, 0.17609202032608373, 0.1133876700975722, 0.11223289980402879, 0.17761439024921388, 0.17271613131367392, 0.14731929006595768, 0.1754299058548866, 0.15557218673488787, 0.1697909624706353, 0.13198470726849573, 0.1288859888670906], [0.03956040119632118, 0.016669695934040413, 0.014242299423072369, 0.06930725438700569, 0.047653840494252024, 0.025063767285657026, 0.07664329702815703, 0.08801818584963199, 0.03267771406700054, 0.022189945485743306, 0.04759536117255207, 0.04473479652416803, 0.05106529513854654, 0.014828830702050079, 0.0076507381539070805, 0.0808270640611168, 0.06240626158673437, 0.0076192078901635065, 0.07114340626304189, 0.006927963883255519, 0.019676794050141208, 0.045244988099101095, 0.062347249833927046, 0.06276390590374509, 0.052938671226823525, 0.06236536781333628, 0.07830683397309435, 0.04704528322984134, 1.0129679090553716, 57.23004802580803, 44.24993668833087, 38.897242853718424, 89.97150744161299, 9.261400430433213, 47.20842753687213, 48.10948225759691, 0.665128996535655, 2.551916587737299, 1.77804202322037, 3.5805417405020807, 1.1727197948963413, 0.22601132070825947, 11.546865509402368, 102.43089275975382, 73.14687713499993, 90.40125800717263, 78.5690204558834, 86.42188010677215, 78.86830514477145, 80.65343856811523, 66.64157913577172, 60.71855306625367, 55.92016073965258, 59.248436958559104, 54.02221995015299, 54.336001719197924, 52.58262380476921, 63.164139101582194, 69.50185775756836, 72.1023028896701, 72.27168652319139, 73.07137935392319, 72.51817610956007, 70.90946305182673, 68.78485633480933, 67.74866027216758, 69.75226971410936, 66.17924936356084, 60.221243596846065, 50.60909501967892, 49.39262290154734, 48.80835448541949, 48.917388531469534, 47.91035136868877, 50.65610070382395, 48.70941269782282, 48.985524023732836, 48.356583733712476, 50.265781725606615, 54.85948124239522, 61.60018420988514, 60.87217269405242, 65.62932522066178, 65.52098151176207, 65.04126779494747, 62.66684924402545, 62.16860232814666, 58.44544933688257, 55.9351049700091, 60.45257322249874, 68.70354560113722, 66.27579458298223, 62.6658647291122, 66.00497845680484, 66.89657242067399, 66.55771886148761, 68.35036754608154, 65.37439469368228, 66.06892878009428, 64.99343449069609, 69.36357851951354, 66.99325100068124, 69.00243020826771, 67.54275937234202, 58.06944700979418, 51.75552537364345, 44.9484480580976, 45.651987906425234, 45.737150407606556, 46.41981540187713, 43.90205383300782, 47.28915775975874, 49.364997648423724, 56.304953098297126, 59.315485954284675, 65.64290838856851, 62.89939872680172, 63.50377321243287, 64.55769054351315, 63.41750852523312, 49.595978183131066, 49.5568682301429, 48.5080970487287, 48.07721291818927, 51.09337437537409, 61.11586955285842, 63.77814692835655, 66.16905904585316, 64.79974785158711, 66.27149566527336, 67.2075379279352, 68.35233657590805, 66.22965966501545, 68.01450283296647, 66.62003747878536, 67.10790188081803, 63.97977636706445, 68.66588300274265, 58.00404148717081, 69.41369856557539, 34.28111522428451, 0.03318122535523388, 0.12015834751148378, 1.3880727488187052, 1.1789141979909714, 0.5740663925966909, 0.2782814384948823, 26.320751251712924, 20.996647573286488, 35.91135817189371, 28.000367033866148, 27.961419859240134, 54.6103048324585, 13.197213545922311, 0.3058115741418254, 0.10088110853347088, 0.020580383265511166, 0.0782012670571285, 0.025010610359811017, 0.012750160287044222, 0.03856743633326504, 0.037500218398148016, 0.03426729671416744, 0.07251075063381465, 0.04909696245205499, 0.0968829186392888, 0.04306210099809593, 0.03346471619161387, 0.07326969095776159, 0.06499730501203768, 0.0469409880198298, 0.03372113348074979, 0.025555789170245972, 0.06816325528967766, 0.09728878436069335, 0.02053787113137303, 0.0521011456036039, 0.03692722676562206, 0.038863736159738996, 0.016873220597664197, 0.08234293755864905, 0.04122650836624446, 0.05659005694812345, 0.12407433617139056, 0.05475398168087967, 0.020429852734049483, 0.022890031104907397, 0.03724814482754277, 0.05450126076597841, 0.0650554740681283, 0.06967054860245797, 0.07864398926857018, 0.018027611677685094, 0.05122231634994669, 0.061158246901487155, 0.05237009609118105, 0.05520799985876488, 0.0372519982498019, 0.03195021590668588, 0.015950326924212277, 0.08820033857538816, 0.026105874773835944, 0.05369717488065363, 0.11891453481850126, 0.7501757265098634, 66.76055246783842, 48.430520411460634, 44.41042830867153, 82.43919172594624, 16.13893920375455, 68.76500129699707, 52.35100784609395, 0.7300854690613285, 2.5332742977526883, 4.999674145252475, 5.680163694966224, 2.868924015952695, 0.6019576927346568, 15.368969113596025, 101.32454118421002, 74.37418676191761, 92.14760703425254, 80.99153903222854, 84.94980673636161, 83.50861026394753, 82.76153995144753, 72.43433152475666, 63.95635981713573, 59.713127997613725, 63.80188119026923, 56.97345049150529, 58.59676261102, 54.3579513026822, 65.21451888545867, 72.18952071282172, 75.00322511119228, 75.2113852962371, 74.19740553825133, 75.02236627763318, 73.08659815019178, 72.84642357980051, 70.4770217403289, 72.60269534203314, 66.47397625830867, 59.57122841188985, 52.11253950672766, 51.667248510545306, 49.343032375458755, 51.06917727378107, 50.54030841396701, 51.42927831219089, 51.55112674159389, 52.290081670207364, 53.12497385086552, 52.99203688098539, 59.722286731966086, 64.68466943310153, 65.20740370596609, 67.42816340538764, 68.41682034154093, 69.39878571418025, 66.22790244317824, 63.38700425240302, 63.18167601862262, 58.96634794050648, 63.590155570737785, 69.81048553220688, 67.52051953346499, 67.7148808202436, 68.66307458569928, 68.75787827276415, 68.40262136151715, 71.21732988665181, 68.56323457533314, 70.85787603932043, 71.01244095833071, 70.63646608783354, 68.6803565486785, 71.94281931846373, 71.6657901579334, 60.116057395935066, 53.91394684391638, 47.42249873376662, 48.58320651515838, 47.81708132836127, 48.04333540701097, 46.412692377644206, 50.72525601233206, 52.21507810777234, 59.13340560851559, 64.32520381865963, 69.06565881544545, 65.31269188850158, 64.56111869504376, 66.439953619434, 64.34641207418134, 51.9457564046306, 50.820291119237105, 50.64291369530463, 51.30745341700893, 54.48673056017969, 62.59264584510558, 65.04489990972704, 68.37451365686232, 66.23161300536125, 70.30131524608981, 70.15772511882167, 71.90783962126702, 69.3878972145819, 72.16167188459828, 68.59388397585961, 69.39991535678988, 67.6522562580724, 72.13376814319243, 57.33237874123358, 72.28818401213616, 34.46869081066501, 0.36995810787043265, 2.012762415312952, 5.735499022468444, 5.824896702843328, 0.5601327854298777, 0.30906171748234385, 31.31460705111104, 24.899048959055257, 41.31583513752107, 29.88084739254367, 27.855600195546305, 65.72974181944325, 14.789370279158316, 0.4223242317957263, 0.016741757994637858, 0.049755874675728624, 0.048833432036542126, 0.036956805420378526, 0.009456776071249718, 0.038709400086513454, 0.023816717871194406, 0.03014013017227333, 0.007950439410764844, 0.09132552531457717, 0.015723005654440535, 0.03020408319219226, 0.05151136515421733, 0.08169390020831939, 0.07139289045646306, 0.08752305556329028, 0.08472226875563783, 0.01663054309545025, 0.07223348809225906, 0.058874469851293874, 0.0901957294873653, 0.13172063676099624, 0.1975508938513456, 0.12709004128532064, 0.13399027948898656, 0.16368659002886665, 0.11923629174669904, 0.13097852738874574, 0.1784398346658676, 0.14295620483256158, 0.12582613410608423, 0.13823241476089726, 0.17357876163817224, 0.16335136527496, 0.10853855570237483, 0.27343970152639574, 0.2943930642739419, 0.07499236989045337, 0.1818362548346481, 0.272205441949829, 0.3030273961203714, 0.1263145074969338, 0.13200631094796042, 0.1954345606387623, 0.1265853272390462, 0.147664412675846, 0.16122879610667307, 0.15585772302602569, 0.6361695246831064, 3.6613305537931384, 85.99647552736344, 65.87971364298176, 56.06766931472286, 114.49169466572424, 16.283494234085083, 66.40354617949455, 66.51156825404014, 1.5868812679283082, 9.894252304107914, 9.267521289087112, 10.8159779156408, 2.892582036795155, 0.3218566422020236, 15.333201019994675, 104.10393268831315, 75.6432225627284, 95.04004124672183, 83.4209688248173, 90.77034519564722, 85.79666214604532, 88.53020898757443, 72.86168944451117, 66.40015725166568, 62.05992129541213, 66.94024409017256, 61.192983350446156, 61.19425812075215, 58.37554093330138, 70.35615782583915, 75.02598270293205, 77.12197965191257, 77.60348196952575, 75.59013720481627, 76.45302726376441, 75.75944239093413, 75.02410780998969, 72.57198318358391, 75.65076135819959, 70.5578225658786, 66.80262381030668, 55.455536380890884, 53.884748720353656, 53.338013464404696, 54.613583933922556, 52.270097194179414, 54.79818244134226, 55.1648691392714, 55.72552096459174, 54.578266912891024, 56.5088535893348, 61.651900660607126, 68.20426710190313, 66.54352772620418, 67.39324646611368, 70.21526628924956, 71.05881121850783, 70.60756606440391, 66.42499369959678, 66.96768499189808, 61.31760097319081, 64.2887100865764, 70.70215009873914, 71.61792939709079, 68.83282692201676, 68.75119455399053, 71.88284627852902, 69.59728902386081, 74.56154269556846, 70.15840761123165, 73.6462889948199, 71.93159349503057, 72.54645639850249, 72.8857021947061, 71.60114165275328, 69.79783981077134, 64.0625972132529, 57.09638933981619, 49.14635689027848, 50.571248069886245, 49.9836064154102, 50.86298219619259, 47.955756725803504, 52.818040540141446, 54.4319115146514, 61.427803885552194, 67.25762659503569, 72.19909129604217, 67.9142156724007, 65.01005357311618, 70.06580829620361, 66.32072141093593, 54.938607215881355, 53.1648604331478, 54.204892573818086, 51.70722530734155, 57.81847023194837, 65.18815271316036, 69.24669188837852, 70.89418934237573, 69.27979669263287, 72.1808522747409, 72.44329806297057, 72.82496037021761, 73.88042311514579, 74.40611485512026, 73.17345511528754, 73.41740300578456, 71.41972418754332, 76.1187001197569, 61.465972469699004, 70.86770549897226, 42.20028646530644, 0.5218015454949871, 1.41474511113859, 10.479836675428576, 12.039687787332843, 4.049117642064249, 1.017093078023003, 34.5970856758856, 32.13294682964202, 51.576096550110854, 43.212901238472234, 43.40365002232213, 74.06588062163323, 27.47943509009577, 0.7050812172312891, 0.1979934934887194, 0.241441649174498, 0.31395937886930286, 0.14439223664662532, 0.12437282700932796, 0.2547563798725605, 0.1638270752324212, 0.1413367409259081, 0.2014161138645103, 0.17645704590024489, 0.19706648113506456, 0.09549833729021973, 0.12692881042077658, 0.16231172267467747, 0.15352178304906816, 0.17320601389773432, 0.15022887668061644, 0.09122326789844422, 0.15899986329097904, 0.2030329883939797, 0.19632418790171224], [0.11562524438505212, 0.020924077121420734, 0.04098068607310134, 0.029080291579086936, 0.03244933559589329, 0.042386499548991846, 0.027746576552970276, 0.06497940919812649, 0.04344015389740948, 0.07224697890060564, 0.045367895415233034, 0.015560973270405686, 0.03525306801161459, 0.07837211232512228, 0.052956003966110374, 0.018995632717926658, 0.13413670953483353, 0.06793463933131388, 0.013703390084687742, 0.09301906992350856, 0.07487997713108217, 0.02843260828916344, 0.014973352231355685, 0.049770127741559866, 0.12110168519880503, 0.03885401067354026, 0.09028999660644801, 0.07588408091255734, 0.5958218800444758, 18.538066725577078, 57.387264467054806, 41.30802962087816, 50.80880249700239, 43.187582339009936, 13.65993457455789, 63.083357887883345, 3.4008025594295996, 1.453950059029364, 1.9126448972571282, 3.5938562260520075, 3.2425427677169925, 0.052421741908596414, 0.35241380574241765, 72.79402071429838, 92.91597581678822, 78.64572632697322, 84.03449812243062, 79.17005308212774, 70.11318268314486, 63.74853695592573, 58.73550861112533, 60.865590956903276, 57.0428176080027, 55.49531313680834, 55.58721819231587, 57.01562381559803, 61.029004743022305, 70.63123364602366, 72.71284334121212, 75.03021886271816, 73.36207405213388, 72.11891804972004, 75.75187221650155, 73.04111434567359, 70.60412222339262, 68.26645235861501, 66.30773836566557, 67.68369013263334, 63.78869810412007, 59.42870516930858, 50.544168026216575, 49.703698235173384, 49.68977774343183, 47.72460360680857, 47.94373073885518, 49.296324791446814, 50.764044330966094, 49.203243024887584, 50.71011566346692, 53.94956980982135, 60.074519495810236, 65.4233144944714, 64.86023864438458, 66.40495038801625, 65.50701002920827, 66.2119540860576, 66.2699737856465, 64.84856959312194, 58.23264506555373, 59.44453193295387, 66.20453296169158, 62.002007499817886, 65.29962255108741, 65.56764594970211, 68.715422538019, 66.54065655123803, 66.16678407115322, 65.10191548255183, 68.44095076284101, 66.16763130311044, 66.2761946647398, 65.37631273269653, 62.98192147285708, 61.39115325866207, 55.643531660879816, 49.02163728590935, 46.47576409001505, 45.50607965838525, 45.05990612891413, 46.5497439138351, 46.16587723455122, 48.336403139175914, 50.63178985349594, 54.12107936797604, 61.191881164427734, 65.7743352459323, 67.64738467431837, 63.67618491572719, 64.7525421265633, 64.98244008710309, 58.82679393214565, 47.924644485596694, 50.57580586402647, 48.54950158826767, 59.21144900783416, 63.395668768113666, 66.37737612570486, 68.04571705479776, 65.9007453918457, 67.82924928972798, 67.42666505998181, 68.5007433737478, 67.95707933364376, 63.43252728062292, 66.94486464223554, 66.94188364090459, 63.17594935817104, 60.66002345854237, 59.36120510101319, 60.226111258229906, 3.055292492912662, 0.18008695434658759, 6.086933093686258, 5.54285720471413, 1.2040923824233394, 1.550417321343576, 1.0279748973346527, 25.842912427840698, 29.99660634225415, 44.66902232939198, 35.45311550940237, 53.96598885136267, 44.173909387280865, 0.8306527113722217, 0.13612964130457372, 0.10843042239186265, 0.09017705226377135, 0.01677550608292222, 0.05461740735617857, 0.04902969993230316, 0.0018788281205718617, 0.0329031775735559, 0.05552663880911085, 0.025752589497114384, 0.012968371813786368, 0.01228066617547865, 0.014423227365759593, 0.09050546649603114, 0.024222277157429247, 0.051100320678444645, 0.10132537058164036, 0.029941818736974272, 0.04958157435119633, 0.010074911349933716, 0.006577858350224674, 0.06135721142674166, 0.09704372049459527, 0.059760358605173335, 0.0031573636290211714, 0.008946586411536462, 0.07222440228947709, 0.05319983826108998, 0.03710911902148397, 0.07196692779900567, 0.06290675448854605, 0.04314879533804713, 0.03285416709860006, 0.09190949115661845, 0.05243257439184574, 0.06339148130087603, 0.017831996871879505, 0.03412300405362922, 0.08700131138245906, 0.03824558747451633, 0.03331939314281748, 0.08147204114544777, 0.0779286393475148, 0.027159098197796175, 0.03587237348960292, 0.014494580795027077, 0.07582244147816974, 0.06379352807397805, 0.1561817935397548, 0.13758704697172489, 0.7524423048861566, 23.34088544691763, 69.48068480337821, 47.97380355096633, 72.61902024669033, 33.965431105706, 25.576861981422674, 75.89664689956173, 3.922697445077281, 1.2580095279601313, 3.148762574118953, 3.786592180690458, 6.501696773113744, 0.0813859788280341, 0.3840239418129767, 75.51134463279479, 93.00876340558453, 81.76490491436374, 86.14660816807901, 82.038176444269, 73.1332508210213, 68.60026174975981, 63.05581108216317, 62.38776083915465, 58.12638413521552, 59.52818039924868, 59.16747139346216, 59.24420472114318, 61.679961296819876, 75.46088726289811, 74.70746271071896, 80.6633072514688, 75.70620798295545, 75.82798973206552, 79.1654089958437, 74.47786285031226, 73.27064360341718, 70.37602855313209, 70.73825943854548, 71.77039977042907, 68.9215587800549, 61.85648756642496, 52.26817915516516, 52.24695521016275, 51.231155472417036, 51.09835186312276, 50.630185604095466, 51.13693229613766, 52.94328966448384, 52.05787735600626, 52.06078775467412, 56.13535373441635, 63.30512477505592, 68.82819068047309, 65.87541472527289, 69.02825509348224, 67.21832444590908, 68.46300232794978, 66.6134871205976, 65.47770207928073, 62.02278429462064, 61.150107922092566, 70.06274884746921, 65.00225590121362, 66.16653303946218, 66.85547382600846, 71.37236549008277, 68.27663483158236, 68.27559932585686, 69.39838563242267, 69.6829535884242, 69.12289404099988, 67.78214162395847, 67.93424329450055, 65.60789731241042, 66.81681494559011, 60.463457799726925, 52.21802380777175, 48.86231060950987, 47.08788525673651, 47.51505098035259, 47.605394932531546, 47.3704331920993, 49.13655096484769, 54.44217243502217, 56.13039193614837, 63.38902819541193, 66.10055092842349, 69.0496555451424, 65.73774345459478, 67.93653395868117, 66.76443561430901, 59.17059360011932, 48.95514526674825, 52.1711475618424, 49.83426217109927, 61.52324299658499, 65.09433354100874, 69.1117701991912, 69.1903901869251, 68.53052985283637, 69.30795146572974, 70.99045215114471, 69.71983955752465, 70.0285065558649, 67.36509953775715, 69.51703733013522, 71.02443556631766, 68.79966720458, 65.04227976645193, 60.9726010599444, 64.90428686141968, 2.6858603810110404, 1.684674168786695, 4.702973808011701, 5.265600056417528, 1.6299165328664165, 2.2764960892738837, 2.0475193954283193, 31.54127101744375, 36.816398020713564, 55.88054872328236, 35.97994081435665, 59.809555545929946, 52.23003018286921, 0.7897350973179265, 0.09890712977897737, 0.09325052806807142, 0.06065949301926359, 0.06023617964538355, 0.125225888895652, 0.030382891944158944, 0.041746639931995067, 0.02588668744260025, 0.03734569463338103, 0.04225769718628257, 0.017457320505092223, 0.05218503223131261, 0.03665726887242448, 0.05074527722993686, 0.024872969257675355, 0.007987170453904378, 0.08804339014234082, 0.06446729474250348, 0.008570105907687498, 0.014467647058829186, 0.08084261564597969, 0.01922283715928995, 0.222280549125806, 0.1500070942265372, 0.08703285888318094, 0.11796236413741305, 0.13686897743853832, 0.14964162432137998, 0.09631700948962281, 0.2275299980875946, 0.132360274212495, 0.16828943013904557, 0.11515840572575409, 0.23397524901215108, 0.2806927155583136, 0.11245351780446307, 0.1367499580186221, 0.10871349187988429, 0.34237710398531734, 0.23699011142936446, 0.14177376344319315, 0.25676953636350175, 0.2319407646333979, 0.12482504105015148, 0.13221442639347047, 0.09290944274154403, 0.23828090829474313, 0.1389046262709364, 0.36625655488141123, 0.17535361881938674, 0.8774292432973463, 35.97181366335961, 91.24345364109163, 60.562689842716345, 75.20647448878135, 63.80153602169406, 24.104710163608676, 81.5534342488935, 5.113765107047174, 7.63279801414859, 9.134808874899342, 11.055366050812507, 7.141884459603218, 0.150381037064137, 1.550069088416715, 75.82153351076188, 96.12041104224421, 86.38238968387728, 90.39954785377749, 83.78773397014987, 76.71823440059539, 68.89056421095326, 66.01425878463253, 66.80740125717656, 62.586609317410385, 62.14837466516803, 62.5601254740069, 62.49572015577748, 66.68754931419127, 77.27755654242732, 79.49925761069022, 83.49332870975618, 78.30994006126159, 77.53265965369441, 82.97647014740976, 76.10606224306169, 77.25424981886341, 73.53134785929035, 75.5200836735387, 75.76490233021399, 71.56862520402478, 66.45627852409118, 57.039691478975364, 56.65869989702779, 54.1621308941995, 53.87930839292465, 51.95388747799782, 53.62204013332244, 53.55630120923443, 54.92891896155573, 54.38843596366144, 59.02326937644713, 65.79482570771249, 71.71398824261081, 69.16547529159054, 70.3217194157262, 69.35790677224436, 70.4244698247602, 69.39173329261043, 68.63104451087214, 63.758684127561516, 64.3796580837619, 68.27673681320684, 67.48982306449645, 66.29392377791866, 68.50736433459868, 74.96653526060044, 68.7719125132407, 70.58222755309075, 72.51115506695163, 73.29304818184146, 70.58769533711096, 70.45406803008049, 70.68399736958166, 67.75863093714561, 66.39643884474232, 61.43879436677503, 55.35648868929956, 51.33242322552589, 51.10969143529093, 49.477706955325225, 49.82264803301904, 50.30868853292158, 52.41219682078208, 58.17571186250257, 60.02851401605914, 65.75360551957162, 70.20918661548247, 72.92564761254096, 67.61602140242054, 73.04535835020005, 71.29441230527817, 63.034151754071644, 52.65194777519473, 55.24925893352878, 52.773615775569795, 64.58765745162964, 66.40394626125213, 74.02751984134798, 72.87971665782314, 72.06296936158212, 70.6375329725204, 72.87703375662528, 72.62095789755546, 74.21586421228226, 67.9452729994251, 72.35470741025864, 73.35858314268052, 71.30627355267926, 71.06471830798735, 62.999564293892156, 67.51416529378584, 4.683503162476325, 1.050284603430379, 15.479094559146514, 14.761089990215918, 4.3456581427205, 4.390180476250188, 2.409920168499793, 34.65197532407699, 48.50353925458847, 64.06533895000335, 54.83964973880399, 68.37165817137688, 67.38970848821825, 2.67581862307364, 0.5137959266862562, 0.3025980804476046, 0.21037070110680597, 0.2124706093942927, 0.3299889106663966, 0.07794285793938945, 0.11926703485510043, 0.13483481481671333, 0.18708443209048242, 0.0927925683678158, 0.12371743112922677, 0.14955513299472872, 0.12673290641677956, 0.17409098334610465, 0.15578112955535614, 0.16554735630991, 0.24841720148199992, 0.15781063436260148, 0.21146507302839912, 0.126825901829908, 0.1642483776255, 0.16128277466181787], [0.03814955452276814, 0.03873384595217724, 0.07154739506903195, 0.073967436178317, 0.024724851903175155, 0.033857328591928366, 0.044794811852156155, 0.10496077187840017, 0.0334538224213306, 0.021981726618363492, 0.06597155434710365, 0.03743618110855741, 0.041202870723340786, 0.032657730663495685, 0.029039449516623735, 0.018603045215469696, 0.010692196271021762, 0.018006592140262647, 0.07803805202486054, 0.05632007990272776, 0.04608378925871465, 0.04950727914429961, 0.04483023192733527, 0.10798752398019838, 0.07953161704203776, 0.0956558985936065, 0.03638169938518155, 0.1517491934881095, 0.41325506844347526, 2.121335950589949, 50.833627177822976, 33.93548380944037, 15.750211727234626, 71.44707879712506, 15.026445196520898, 49.53239656263783, 22.605433194868027, 0.5993702154486411, 1.24373099736629, 2.913175705940493, 2.696648369873724, 0.10100451763719322, 0.2501087389405697, 33.77825952345325, 99.56941389268445, 80.41117729679232, 87.95219282950126, 68.7564113063197, 75.31777566479099, 66.71776725399879, 68.37268583236202, 59.715140173512125, 62.10367533468432, 63.59979283425116, 60.321707264069595, 59.506960376616455, 70.88944327446723, 72.04365561085363, 73.16681062021564, 73.25945700368574, 76.98066449934437, 77.53514643638366, 72.77088657502206, 74.08162501550491, 73.06392685059579, 72.56011409144249, 70.36900751052364, 67.51087050284109, 66.78246282762098, 62.16224024372717, 55.721249503474084, 53.38713722844278, 50.64185073298793, 51.61389643146146, 49.30810366907428, 51.04788664848574, 49.968697486385224, 52.86153178061209, 49.54018246742987, 51.60990345862604, 51.792262292677364, 59.63817934836111, 63.205516184529955, 65.58364137526482, 67.45818522668654, 63.979846969727554, 67.73188821731075, 65.21903745589718, 68.88986602906259, 47.90021204179334, 49.76546379827684, 70.65068860207835, 62.91271125116656, 68.22089795143374, 67.38369157237392, 69.5916643450337, 66.31919168656873, 68.23239049603863, 65.45996512136152, 66.31306494435957, 62.317781832910356, 62.72676344840758, 58.29321038338446, 56.034250720854736, 50.04248903643701, 48.09370256239369, 46.15426309647099, 47.438529460660874, 44.6894500332494, 45.916018332204516, 46.119565809926684, 49.385962716994754, 49.579755260098366, 56.077683125772786, 58.566544671212476, 62.264296393240656, 65.07288209853634, 65.5063118473176, 66.4764787304786, 64.76545456917056, 62.25734987566548, 50.66029371753816, 49.131644079762125, 49.99597757093368, 62.601071096235714, 67.39296405546128, 67.08239078521729, 62.59275174910023, 65.61112934543242, 68.76799014306837, 70.69669015945928, 67.55230642134144, 67.15413093566895, 66.8004665067119, 69.57107190162905, 62.078062257459095, 66.18336000750142, 48.34221216940111, 72.34177927817069, 17.966167503787627, 0.3285081239957964, 1.4496565345794925, 1.7666925225527057, 5.0941052071509825, 3.727991234871649, 0.8181523627811863, 3.4199219076864185, 22.607578731352284, 34.14760558835922, 29.297294808972268, 31.45290001746147, 53.007483174723966, 14.721981998412842, 0.31809505856325554, 0.13815179166774597, 0.05161831485888651, 0.03947879751062682, 0.012432420532399369, 0.03846775297255766, 0.04844010717445805, 0.044538137923565604, 0.04354943633980809, 0.01591832168595565, 0.04763487215724684, 0.05273874143078443, 0.0693165623552857, 0.03909977551008906, 0.06689433789541645, 0.03451825179640324, 0.06554762427244457, 0.09841108018712652, 0.04781877539390999, 0.06340800198696314, 0.02128656885977234, 0.07078194299772864, 0.04153365599772623, 0.010768688235041356, 0.04104490339335415, 0.034027078354190436, 0.0800241043250407, 0.01770901677739476, 0.06950053837030165, 0.035370164550840855, 0.013522455438731179, 0.03848624250461017, 0.02833389019924066, 0.03277511065525394, 0.004605909728730519, 0.0969584625695021, 0.034564783976924036, 0.020325731809040713, 0.02947102514876714, 0.01622990783934872, 0.037876222012264114, 0.039321370272626804, 0.058946765568708225, 0.06808724404583055, 0.022268360330452843, 0.01961708898776241, 0.08247807546849213, 0.06721701412912338, 0.05640868946248966, 0.11568676124537185, 0.05976558332481693, 0.3001009708931369, 4.829043688312654, 70.30308031266736, 38.37939585408857, 25.43986143604402, 76.92980704769012, 16.025302256307295, 67.37592527943274, 21.429808639710952, 0.48295987649790706, 3.509831947665061, 3.1709335263698333, 11.91147727351035, 1.4618184561690977, 0.32581964567784344, 38.977875017350726, 99.75074506575062, 85.5412530899048, 88.63628556651454, 68.8205812823388, 77.01209052916496, 67.56270854703843, 68.47870749811973, 60.14231766423872, 66.75774405079504, 65.1617669290112, 60.78880663841002, 60.386493052205736, 74.1663246770059, 73.15294896402668, 76.09701725744432, 76.97386310946557, 78.26811190574401, 78.07680222295946, 73.72399899267381, 76.397659086412, 75.17576233033212, 72.76283002668812, 73.64253920893516, 71.92897335175546, 68.48962737667945, 62.95906974423317, 58.511227484672304, 53.03821102265389, 53.75742858456027, 51.79109734873618, 53.19893014046454, 52.79323154880155, 54.533394998119725, 53.3299373042199, 54.22783059458579, 54.35736686952653, 56.48399360718266, 63.63874197006226, 66.19060070283952, 67.00286080760341, 69.72414631997385, 66.81992930750694, 69.00407760374009, 67.63236199655842, 68.99926093316847, 51.89464007654498, 54.81336985864947, 72.0184975285684, 64.3158999566109, 70.15402240137901, 68.75420693428286, 71.38255580779045, 68.78581339313139, 69.86881902140956, 68.42693221184516, 68.19108793812414, 65.31936384016468, 65.19054143659531, 63.16130715031778, 59.03327926512688, 54.656208330585116, 50.45006252104237, 49.571094666757894, 50.81236008674868, 48.57430665723739, 49.05577367351901, 49.42036582577614, 52.31748727060134, 52.70843775041642, 57.28627912459835, 63.319453193295395, 67.88903405589443, 68.41077204673522, 66.19140086635467, 66.72297616158762, 70.5198226436492, 62.6589221339072, 53.145044619037265, 52.65159083950905, 54.118533749734205, 63.7169461865579, 68.8229190149615, 70.16447159551805, 66.59878607719176, 68.45677360411614, 70.67907871738558, 73.11103451636531, 69.30098533630371, 69.94510127652076, 70.16964127940517, 72.59907107199393, 65.46081627568891, 71.21322708745157, 52.651084853756814, 78.1453730983119, 17.59665866051951, 0.6496857058617377, 1.9608355049164066, 4.280779198292763, 2.5188576261843405, 3.1598846998906907, 0.05607160311492701, 4.089167002708682, 29.361829565417384, 46.11631024268366, 39.558542697660386, 32.503944212390536, 64.69428316239389, 14.44368689290939, 0.3554545619314717, 0.06941402406101266, 0.01463071366156181, 0.04313392940187647, 0.04772457722274046, 0.03431423109084849, 0.0491230592371956, 0.050631283346803925, 0.018021140149944735, 0.04620581940417329, 0.04747336550105003, 0.046673546725463484, 0.03196324706227789, 0.03204919638172273, 0.04158520222371144, 0.0276487183967425, 0.07798312352068963, 0.029812859326240518, 0.02831387232177921, 0.02388372949715103, 0.025096103856940905, 0.06485255269874489, 0.05323590568056511, 0.10241362912159774, 0.23136327223431682, 0.15210167054207097, 0.17585727566432569, 0.0900094169041803, 0.15144876444772368, 0.16622526751410577, 0.22071049789026861, 0.08844040754821994, 0.1025936138185282, 0.10530831532612925, 0.14867298274991975, 0.26868839357649127, 0.11446010126101394, 0.10016891489466352, 0.22709718905389312, 0.14988016877924243, 0.11448000422528676, 0.3741923371149648, 0.18769307362456478, 0.25149376462063483, 0.10920289182855238, 0.18609452391824416, 0.3462406079615316, 0.23034388499875225, 0.2554951031361857, 0.500852411552783, 0.3282358257039901, 1.0959407470880018, 13.838220027185256, 86.82418192586591, 59.57614314171576, 35.57195940325337, 100.81163637099728, 26.168628008134906, 67.22978561155259, 28.58000901437575, 2.0990362955677897, 13.72063619475211, 6.395561358621044, 8.403689861297607, 1.2052082967373634, 0.32651221980490996, 40.55677806177447, 102.16489330414804, 87.53514289855958, 95.95246299620598, 74.28762005221459, 79.42932959525817, 73.66072331705402, 73.85346858732163, 63.52709170310729, 69.5819760907081, 70.61497149928924, 65.01469373703003, 66.14142202561902, 78.52106555815666, 76.1190531330724, 80.2676107037452, 78.70012175652289, 82.35127572090396, 81.59423474342593, 77.15062079891082, 79.87887244070731, 79.5354453979, 76.41538819959088, 79.41000015504899, 74.75514304253363, 75.0634805617794, 66.36294964821109, 62.28709713105233, 59.010235340364524, 57.316850077721384, 56.460828088944965, 56.44664479840187, 55.97049259370374, 58.532494575746604, 59.89285492127942, 58.107560680758574, 57.46365654853083, 58.6288829003611, 65.68802741266066, 68.89177230096632, 69.29738460048553, 72.04376543721845, 69.82648880250993, 73.0631737555227, 69.82122498173868, 73.56202079403785, 51.94789801874469, 54.85350355025261, 73.4169872345463, 65.63640117645264, 73.75563683048372, 71.60072588151502, 75.6166994956232, 71.8589198204779, 73.52251468166229, 69.38941909420875, 70.53987379997008, 66.80135296237084, 67.26569098810997, 64.39326870825984, 60.34637112771312, 55.78418785525907, 52.87559347767984, 51.80913240678849, 53.09475983342817, 51.00312848244944, 51.17574022662256, 50.214618329078924, 56.088042105397875, 54.293173359286406, 61.39720939820813, 64.85952085064304, 69.00544258856004, 70.19155948392807, 68.64414522724768, 69.44332814985707, 71.74055837815808, 65.50032238806448, 57.520974143858886, 55.92052159770843, 56.920059188719726, 66.95351739083567, 73.5234482057633, 72.72614802083662, 67.1137305228941, 69.49788047421363, 74.06599044799805, 75.27739878623717, 70.90241847499725, 70.26066380162393, 75.59871150601295, 76.48586534684705, 69.56219950029927, 77.72440864193824, 54.40892250307145, 78.7581963692942, 22.49428499129511, 0.31443135031769354, 3.9539783472015015, 10.26959567300735, 12.454899107256244, 9.98613186420933, 2.1990256011486053, 5.489561019405242, 36.265057902182306, 51.32558261194537, 46.58798702301518, 44.53268858694261, 74.83910529844223, 25.924346716173236, 0.697053412516271, 0.2941688456602635, 0.19524244110911124, 0.11822675640184073, 0.1500683506169627, 0.1415231607614025, 0.164862749497256, 0.09883982895482933, 0.15461578724845765, 0.16009529241390769, 0.13250363990664482, 0.1277690556561274, 0.09626266321227436, 0.11269227676694432, 0.2451836822494384, 0.10890685247197267, 0.11806303575154274, 0.18406658193036435, 0.1594615538394259, 0.1456113583258083, 0.1756422807492556, 0.17985804727481258, 0.17568315920089522], [0.018457957738710028, 0.0209159450981045, 0.048560731548575625, 0.04435864735334631, 0.011364084108912898, 0.0078111488255672165, 0.06262644291705181, 0.03355792227892145, 0.03989472962735642, 0.04983135731890798, 0.06509973096751398, 0.060318365557900364, 0.055525868890746954, 0.01490044843165144, 0.06660305594484653, 0.0469404862322394, 0.044087590123977394, 0.03815956729193849, 0.003615117443147146, 0.028049179367841254, 0.0182148722946764, 0.06543880914367976, 0.04344033009763207, 0.08570761104384739, 0.04931094996150463, 0.06399927247736244, 0.1120200882395429, 0.09251047947233723, 0.017662185822583495, 0.257621027769581, 25.272529202122843, 46.568673272286695, 30.86529366431698, 41.46966265093896, 47.737006141293435, 23.849950259731663, 51.94248122553672, 0.09026407219109037, 1.4017210035554826, 1.1743991822004318, 19.278843595135598, 2.7115707820461643, 0.3250936701172783, 3.70398142645436, 92.86704817125874, 81.21542792166434, 90.37128325431578, 85.39902794745662, 80.65799636225547, 80.5490799873106, 77.70181578974571, 69.45362044918922, 63.219738698774776, 60.37163903636318, 60.87036448140299, 68.66630661872126, 74.81120155703637, 77.41580440152076, 77.18113683885144, 74.3137038138605, 74.47702346309539, 75.71576287669521, 76.19369583745157, 76.82398934518137, 73.66594791412354, 74.69932771498158, 69.19128448732438, 69.82664569731682, 69.63160191812824, 64.9481075809848, 60.14665972801947, 54.04866849222491, 52.02632188796998, 50.15427266397784, 48.73256644895, 50.560587067757886, 50.04809802578342, 50.565227231671734, 52.510381590935495, 54.3236933215972, 54.806380195002404, 53.56009414119106, 57.57124323998728, 61.521344569421586, 65.18418719691616, 65.56829314078054, 70.25160312652588, 66.51751456722137, 70.00411725813343, 42.68342833365164, 53.05386127964143, 72.56431102752686, 63.3342013051433, 71.24271546640705, 64.93170422892418, 67.86715507507324, 60.92926279191048, 65.09837358228623, 58.71062509475216, 63.3367939918272, 56.73287976172663, 57.831100263903224, 52.35887219828945, 51.56205838726413, 49.55377740244712, 48.323745650629846, 47.98364870009884, 46.67206302765877, 47.26629426402431, 47.048465436504735, 47.38289063976657, 51.15328857975622, 52.378735080842056, 57.089270237953436, 58.78010595998457, 62.01904627584643, 67.83022988227107, 67.57425600482573, 65.2756529469644, 68.63647307119062, 65.37682656318911, 55.90069401648737, 49.72390236393098, 56.98709249496461, 62.284229878456365, 69.05513117390295, 68.54256368452504, 68.32353853410291, 67.73760703302199, 70.57302567266649, 68.21939960602792, 69.37904834747314, 64.97386970827657, 68.05036114108178, 62.47961882622012, 64.14110345225181, 47.24748649904805, 62.52668726828791, 43.558426749321725, 0.10625329244160846, 0.16320435300229058, 1.2813715324286492, 2.0846039345187526, 2.2597107964177288, 0.9968143629450953, 0.37939422733841405, 5.222746201099889, 38.78301166719006, 32.97087884718372, 22.10224605375721, 46.82777720112955, 41.188016860715805, 0.5861526859864112, 0.11401305065280008, 0.08632009833930962, 0.02517693570905155, 0.06816734619919332, 0.04472249315210408, 0.04395216110072309, 0.04422030719597975, 0.015406962784547961, 0.01759528144893627, 0.03864350503370647, 0.032053746943992954, 0.06501895465677784, 0.042898778713518576, 0.03336640029785133, 0.09609226227527666, 0.05325282473237284, 0.0386592060057146, 0.0591551031797163, 0.0434765430738128, 0.0663168914616108, 0.025343831793795672, 0.13363912010625487, 0.08699516735730634, 0.08755975117486331, 0.07169777046768896, 0.007710924415263318, 0.023309676832849943, 0.010768228582286788, 0.04300348761100923, 0.027120050696295597, 0.053796134288272554, 0.018031032260267005, 0.11056782302236366, 0.03789990562044325, 0.04499924624519003, 0.07706632311906546, 0.02340941956537145, 0.028823456772032286, 0.0032055124944646756, 0.008530876460304905, 0.08078935721348371, 0.029111036602708123, 0.011099245598269327, 0.009727569000284758, 0.031569071842597864, 0.05740158154719299, 0.03322183950653961, 0.037032931577414274, 0.04201517290165348, 0.1301575722473283, 0.055252467432329734, 0.0750519025830492, 0.4802693144208001, 40.77806641978603, 61.058810833961736, 31.82997511279199, 56.71278153696368, 46.48462472423431, 35.632301145984286, 63.090469145005756, 0.07224496408936477, 1.4929156197655586, 3.0274870559092495, 12.793654607188317, 3.3182999155213757, 0.30899111481924213, 4.899665963265204, 97.4894751271894, 79.54100731880435, 93.908900291689, 86.30515821518438, 82.79506837168049, 80.1891476108182, 81.13326995603501, 70.50972646282565, 67.33127301739108, 62.2240803318639, 64.38271361012613, 70.05814398488691, 78.53998707186791, 81.06445589373189, 79.7578045629686, 76.43830268613755, 75.91892596214049, 75.61986877072242, 79.7582438684279, 75.0482068523284, 77.01348689294632, 74.62649714562201, 72.97808970174482, 72.36578418362525, 72.22734020602319, 67.43236034147202, 63.07787441438245, 56.86744451522828, 54.3350838845776, 52.594292856031856, 51.260910572544226, 53.13086132849417, 53.93391170809346, 51.763754506264966, 56.148034757183446, 56.5656691212808, 58.557880155501834, 58.49995459279707, 61.494813657576046, 64.736487865448, 67.78149051050987, 65.41371645465975, 71.56497739976453, 67.88528427000969, 73.93412036280479, 45.340688997699374, 54.257291516950055, 73.63517299775155, 65.77784184486636, 72.71856215692335, 64.7602338944712, 68.1934727391889, 62.6882928417575, 66.1300628416, 62.97322557818506, 66.23211506874331, 59.824413484142674, 59.53463269818214, 54.85942632921281, 53.93130725429904, 51.377746212867, 50.17816382069742, 48.619123658826275, 48.67004386840328, 50.51495813554334, 49.711809696689734, 49.081229855937345, 54.048715560666984, 55.69465583370578, 59.51474235903833, 60.74411907503682, 67.28467525974398, 68.88675951188611, 70.30279790201496, 66.44510761384042, 70.05452755958804, 67.12997698014783, 58.56052775536814, 51.432616249207534, 59.10284642250308, 67.1316400651009, 72.45479060757545, 70.29260758430728, 70.31576525780463, 70.5988819368424, 73.16952490037488, 68.77749012362573, 72.18249182547294, 67.97057228703653, 71.70353120373142, 67.11470327069684, 70.54869128811744, 54.49170412555818, 71.61064163331064, 44.7803823409542, 0.05915532917565396, 0.46951515600085264, 5.085083265458384, 3.424958721283944, 2.4758167228391095, 0.6628455029379937, 0.3784732364358441, 8.366335168961557, 45.26381838706232, 47.88293400118428, 23.589302878226004, 51.596386971012244, 49.87676889665666, 0.44017260954264675, 0.07850056994826564, 0.06453462621016849, 0.058916907291859395, 0.04625930766304655, 0.03421223797504941, 0.031270523548066136, 0.051152717262025804, 0.028857790917578726, 0.10846323393765958, 0.049683107814240846, 0.05637675508736603, 0.029752847828692006, 0.060271802733862595, 0.01098499699090157, 0.027167956089420665, 0.0254282048873363, 0.030789893390911243, 0.0314552350074894, 0.06790118427166054, 0.08263208212391024, 0.0408505660391623, 0.04563359769001123, 0.06190763027857869, 0.09509497667632758, 0.15400058800174346, 0.1916015009966589, 0.07656141755080993, 0.08833342336959417, 0.1643302571028471, 0.21172555824441297, 0.1296419337872536, 0.18036184201557792, 0.1888086355381435, 0.20138286564859653, 0.17917252115664944, 0.13762184268524572, 0.1790744159370661, 0.13398499348230902, 0.12895058540086593, 0.10753797592535135, 0.12682161939841124, 0.23685961601234254, 0.1988273955160572, 0.1631424837415257, 0.1436181814079323, 0.17914674995887667, 0.1979924516091424, 0.22138781154588347, 0.17952565704622578, 0.25787022084959094, 0.155609862939004, 0.2179464373377062, 0.7831507861133545, 65.28749066014444, 75.46706107354935, 47.41639944814867, 63.43405700499012, 72.82597234172206, 35.79492653569868, 68.84400567700787, 0.213097928151969, 5.5144719923696215, 8.016750004983718, 47.09259994568364, 6.7733846460619285, 0.5520199143117475, 5.2874550127214, 98.79382794903171, 83.00936314367479, 97.7487830192812, 88.62426742430657, 84.12577952108076, 85.60168112477949, 83.97669807557138, 73.3770731956728, 69.82794792421403, 63.7486977731028, 68.24902919030959, 74.3492797113234, 80.58385572125836, 86.27314382983793, 84.31646946937808, 78.69197107130482, 76.65105204428397, 78.51500157387026, 83.65075695899226, 79.64679364235171, 80.52666756414598, 78.87538894530266, 75.11109813567131, 74.11486318034511, 78.97666454315186, 71.63796486393099, 68.83195615583851, 60.70329112391318, 60.71853737677298, 54.61095202353693, 54.8789518879306, 56.10972889008061, 56.75116585146997, 54.789404176896625, 58.3653074695218, 59.80635489186933, 62.56980980596235, 62.370019958865264, 62.02436108742992, 65.67726442890783, 68.62985211033975, 67.49139985730572, 73.55456829071045, 70.57286093311926, 75.71257006737494, 48.100684381300404, 56.77644160486037, 73.17985642340876, 68.95233369642689, 75.62153185567549, 69.33658476798766, 72.5315200128863, 62.6589221339072, 69.74945345232564, 64.70821542124595, 68.8452765249437, 60.492373512637236, 62.75249811910815, 57.74485911092451, 55.50276564013574, 53.081812089489354, 53.694541223587535, 52.10687560419883, 52.91385227634061, 53.71170943783176, 52.64518168664748, 52.62003537147276, 56.18674462841403, 59.76843341704338, 64.08824166943951, 65.30530214309692, 67.64125793210923, 72.5771136437693, 74.91565427472516, 68.58730223871046, 75.44739430950534, 68.55214211248583, 62.432079699731645, 55.28086931474748, 61.06934632024458, 67.7324922623173, 73.89372779477027, 72.38381139693722, 72.99277505566998, 72.63292112658101, 73.84381955669772, 70.66759401752104, 75.54459848711568, 70.07752049353816, 72.80286173666678, 68.57292282965876, 72.68246066185736, 59.18672238626788, 71.95847742019161, 49.46593200006793, 0.4326517711724005, 0.4271015867350563, 6.796947794575845, 13.607981801033022, 7.599466693016791, 3.850004158673748, 0.8196446407706508, 10.562857562495816, 60.257062681259654, 47.89833714885097, 37.559687168367454, 65.4188390701048, 64.67666779795002, 1.5104165000300256, 0.2982352403623443, 0.18849302263509846, 0.10505619579024854, 0.11140451360974582, 0.08968662575728471, 0.10945639032269679, 0.1514088053015932, 0.2042151386699369, 0.18486483022570613, 0.12881224524349938, 0.22247110583609153, 0.18537358921622077, 0.11946002772498517, 0.14620561272867266, 0.14125470823097613, 0.11687949119556336, 0.09932731368368673, 0.1314074446957919, 0.1534185756839091, 0.11244145958053489, 0.14645123583895547, 0.19862779896826516, 0.09032763450616792], [0.01756331643029567, 0.032645959722539114, 0.018430351760358583, 0.060952035184468956, 0.03356768223907679, 0.07658209426388626, 0.08120541956516043, 0.07746757699116584, 0.025130683150623116, 0.047086448964452556, 0.03431182940520587, 0.05891422215368479, 0.06101608779581805, 0.03768812061377591, 0.1451609752351238, 0.07991465334329875, 0.04197162463359776, 0.07351973439536749, 0.0971130591126219, 0.050339170190836155, 0.13606437061342502, 0.08149777403882436, 0.07557438220828772, 0.1416205918236125, 0.07395909348082158, 0.1048867371413977, 0.0953210951880582, 0.41213998150440956, 0.13650258822787192, 1.0038105843047942, 13.91690375343446, 41.536468459713845, 75.94537058184224, 61.36926643310055, 60.85691075171194, 29.54487677543394, 32.37170542440107, 6.003396905237629, 1.3881757110357287, 3.537217691060036, 8.044656197870932, 3.155919673942751, 0.06144613891299214, 0.1464132838431866, 23.45628549975734, 118.19070154620756, 79.8637399365825, 92.05720424652101, 83.5499991140058, 90.70746175704464, 79.79531026655629, 75.69956348788354, 65.72737663022934, 64.32614518750098, 64.79623340791272, 73.91257870581843, 78.30341323729485, 78.02512107356903, 76.36588788801625, 75.73335078454788, 81.41683378527242, 77.08694504153344, 73.97900796705677, 75.31801885174167, 75.29409239369055, 73.85314695296749, 73.76819625977548, 69.99733940247567, 71.28043297798403, 66.50024829372283, 61.877711511427364, 55.5315479924602, 54.46925640106202, 48.75217045507124, 52.90748234718077, 50.66664403484714, 51.436789651070875, 48.156036869172134, 51.26702162527269, 54.56680966961769, 57.589313599371145, 52.75352931791737, 53.75595377337549, 54.7484467875573, 59.90139784351472, 60.14213723521079, 67.04160598016554, 65.73528020612656, 72.95193533743583, 47.71187943796958, 57.16965136989471, 74.21246743971302, 65.77887342822167, 65.82805602781235, 63.87477451755155, 62.23087779937252, 59.31617236906483, 57.400620137491536, 56.5752044031697, 56.953277741709066, 53.81309486204579, 53.8808028159603, 51.379240635902654, 49.482092165177875, 49.36547225521457, 47.56426495890464, 48.48015016125095, 48.1222064264359, 46.60198596216018, 48.5500507200918, 49.68145447392618, 51.17361822435933, 54.10424063282629, 55.290373217675, 57.83371256243799, 61.808842535941835, 67.11583291330646, 67.28159227678853, 66.32805624315816, 67.75319453208678, 66.24236814437374, 59.141681809579175, 53.24823825590072, 58.967410902823175, 66.10965082722326, 69.44215143880537, 68.20176462973318, 68.27910592479091, 66.9908897338375, 70.17302236249371, 69.04846314461001, 68.57188732393327, 69.48209685664024, 66.09980567809075, 65.1582093392649, 55.13791461144724, 49.490619397932484, 60.82158588594007, 5.254900320883721, 0.09852542647070463, 0.174787970139615, 2.895683405860778, 2.4840728217555634, 0.6281084411086575, 1.046022457941886, 0.0698462508678917, 19.22510516258978, 45.75088262557984, 20.68555262780959, 35.6994717351852, 37.27786487148654, 4.5075951564696535, 0.12926351699617603, 0.07605008450486968, 0.06805470063080711, 0.04215969155812937, 0.043733056123939254, 0.011516114257486358, 0.01638867956165585, 0.0866089211476426, 0.03067724399208542, 0.0848077028809536, 0.034151728520350116, 0.0456326439105455, 0.025095548443195802, 0.06349563095418197, 0.06946111548571818, 0.03620900401485063, 0.017814486017150265, 0.035557059360848325, 0.04857827113160203, 0.03905648771192759, 0.039579656816297965, 0.028163075574763843, 0.035186521784071965, 0.018988988820403334, 0.07835107555072154, 0.029386822509789662, 0.0930913273365267, 0.018141569171641624, 0.12229285999051026, 0.017667270731180906, 0.0062618169167469595, 0.05321468504506254, 0.07774928284268226, 0.05545200652352745, 0.022169866321247914, 0.05465476946424573, 0.00828821715267916, 0.04191819383131881, 0.03378163910500946, 0.09240950142303783, 0.06879113329153869, 0.09059051757738476, 0.03734426587940224, 0.08194567500463418, 0.06942491783129592, 0.06967063287212964, 0.07713733180876702, 0.16311262163423723, 0.08518641844632165, 0.03510161242898434, 0.0634023750711593, 0.34933351941647073, 0.13577895689635508, 0.9115576023055662, 18.623613619035293, 61.153461548589895, 80.30284143263295, 74.46732736402943, 71.76539482608919, 29.809470061332952, 50.70509502964635, 6.879849049352831, 0.5096337403501234, 3.5668279086389854, 3.8910591169711086, 4.829290307337239, 0.34864664498356085, 0.38161297118471516, 30.049268084187663, 116.04022287553357, 79.41163970578101, 93.06674388147171, 84.73568454865487, 90.91282921452677, 79.40633666130805, 77.32370714987479, 68.06766663828205, 68.35479982437627, 65.16367712328511, 78.34036196431806, 81.2008680835847, 79.67156733236006, 79.15230043472783, 80.44492536975493, 80.868039284983, 79.06641621743479, 76.77083338460615, 79.69056729347476, 76.91508247006324, 77.56594488697668, 75.03491001744425, 72.3427677154541, 72.58065946640508, 66.69997538289716, 61.67400321652813, 57.16976904099988, 55.21554616189773, 53.16549585711572, 54.49958024486419, 53.34758404762515, 55.47857246091289, 51.24014946722215, 54.91638306648501, 59.04028854062481, 58.9906862474257, 54.71589503749725, 54.77784887436898, 57.241434666418264, 61.028271259800086, 62.996712730776885, 67.88144819198116, 68.40737527416599, 71.2047939915811, 48.45610995446482, 58.70791865933327, 73.47430875224453, 68.68205101259294, 68.06679587210378, 66.28338829163583, 65.43694080845003, 63.17013640557567, 61.08030150013586, 60.38497509494905, 59.31171655654908, 57.77282561025312, 55.913147541784475, 54.22245694744972, 52.18921792122626, 49.54861556330035, 49.299482299435525, 49.35701954749323, 51.53604522828133, 49.449485501935406, 50.79600380313013, 51.310508943373165, 54.052461424181544, 56.31559056620444, 58.920307159423835, 60.9269799724702, 63.444274779289, 70.31341968044158, 69.34613181698707, 69.24472285855201, 70.30886188630136, 67.38813954014933, 60.19212392068679, 54.461348902794626, 63.465914495529674, 67.31277511965844, 71.28970546107139, 72.40922051091349, 72.13443494612171, 69.44858412588798, 72.9895273331673, 73.47338307288386, 69.99267178197061, 70.96629035088324, 70.52608274644422, 69.80171511250158, 61.05145638988864, 59.1238271805548, 66.11875857076338, 4.682778994883261, 0.2885733701048359, 1.1909795312150833, 2.496274334769095, 2.676429532227978, 1.2419300165868576, 0.28004491160954204, 0.0778349084899791, 22.664933589196977, 63.18036594698506, 30.841457420779815, 31.724361373532204, 51.03004770894205, 6.7523372077172805, 0.10041410899570874, 0.12883941072129435, 0.014888790488663702, 0.031313615993806915, 0.03627542000744612, 0.04591815338860597, 0.019932232661953857, 0.045385660994197094, 0.0019950911800767626, 0.050049968168980656, 0.048052474345651366, 0.022640523928848487, 0.030406742176461606, 0.0311284123228923, 0.04206090835073302, 0.02341422102143688, 0.04487316732505157, 0.04261506188120093, 0.074853815228468, 0.029851299703061104, 0.030868474859744314, 0.08284762862228578, 0.06316690262587321, 0.028665908875184196, 0.15906904103054156, 0.15146765617593644, 0.22322417026565922, 0.13715374764175187, 0.2563313493925718, 0.14185167458509246, 0.16475022650293766, 0.237256235052501, 0.17192609548088045, 0.17398538578662182, 0.16440176374969945, 0.23566467206804986, 0.09461563546210529, 0.14018180209302133, 0.24140029574834534, 0.18928822190050157, 0.1690185313383418, 0.15200531200295495, 0.4068581117016654, 0.20818552723334682, 0.23523167917324653, 0.23361544815763352, 0.21213110986976855, 0.2767536753127652, 0.1420946929964327, 0.21530403154751948, 0.17625660665573614, 0.5937684579722343, 0.44344723705322514, 1.6434512840163324, 33.422167147359545, 77.68508295859061, 92.10273511948125, 81.32036701325448, 90.03593629406345, 45.34851020382297, 45.817162836751635, 8.183120767916403, 2.3037722514521692, 11.98174653514739, 18.818145528916393, 7.9400014781182815, 0.24363486697116207, 0.4162624231990307, 27.609016472293487, 118.9135943689654, 83.90177296053979, 98.68551561909338, 87.43727191801995, 97.5558259410243, 84.99358038748466, 79.9699341866278, 70.02361143788984, 71.24309985868393, 70.18322052494173, 79.293819550545, 83.8094795903852, 82.9967095774989, 82.49586997493621, 85.12032785723287, 84.68155584027691, 81.51219444890177, 78.99724914181617, 81.82158316335371, 79.22473092232981, 80.10405571229997, 79.30783810154085, 76.97691471345964, 76.28751108723303, 71.9522330068773, 67.21715557959773, 60.95273033265145, 58.405943224507, 55.051316522782855, 58.133675821365856, 57.018581282707956, 59.7898103344825, 53.904662593718506, 57.14614460545202, 61.68254221639326, 62.821465153847974, 58.92427267566804, 56.699833793024865, 59.67000545993928, 64.66617545773907, 65.21587210316812, 71.98114087504726, 71.49115839312154, 76.85645872546782, 52.061289818056174, 59.369900995685214, 76.4691246709516, 71.9949789970152, 71.44552553853681, 68.92818758564611, 69.00348140347388, 65.50596275637227, 63.971625681846376, 62.80767410032211, 61.01257785674065, 59.70138049894764, 58.20119157914193, 57.27891683578492, 54.92900133132935, 52.63632889716856, 50.32574692080098, 52.31940923198577, 53.555485356238584, 52.694815358807965, 53.55367322121897, 54.57325020144063, 57.31471238597747, 61.53531212960521, 60.38159793423068, 63.6600600519488, 68.74069044666906, 73.23304376294537, 70.50560797414472, 68.82060481655982, 72.9531983406313, 72.05714071950605, 64.47064530464911, 58.29361046514204, 64.67019588716569, 70.33596546419206, 76.22885596367621, 74.2843880191926, 74.74054398075228, 73.27177324602681, 76.02140965000277, 76.26180387312367, 72.54800181235038, 75.03632991544663, 72.2800882401005, 72.53518350662725, 68.66709109275573, 60.26462893332205, 65.717307905997, 8.038740283058535, 0.23304619886461767, 0.48817675140115524, 7.756388466204367, 7.755099967602761, 4.1751453568858485, 2.0946939866389, 0.19587316129717136, 33.731575473662346, 64.03059851738715, 32.06085170468977, 52.142243616042606, 64.3916448470085, 12.912067040320366, 0.4169687869087343, 0.3405696880673209, 0.1847699885406802, 0.13702964139801843, 0.13093437008079023, 0.1652576371787056, 0.17554788339522578, 0.1889705865253364, 0.11667158259379289, 0.14092147530567262, 0.14950210438861003, 0.1388948203455056, 0.15103215051274146, 0.07550486739003852, 0.1078738978192691, 0.08851801991582879, 0.09635990275250328, 0.18182237332146015, 0.13160529456311656, 0.18578640335509855, 0.11115782563724827, 0.16035458253275964, 0.13837221048531995, 0.1838109996770659], [0.02261655112247794, 0.0497225996467375, 0.02649027471160216, 0.06963507873156378, 0.042051194355853146, 0.010934961873347, 0.02986855391833571, 0.08358717926086918, 0.03779349600776069, 0.0630121605260478, 0.03844706859860209, 0.03187718282964441, 0.08194386703713287, 0.01183386263062036, 0.08813137534044443, 0.06114207478540559, 0.019651867464304935, 0.019498552203238494, 0.08138879037071621, 0.06257280910147295, 0.07153292366814229, 0.038314554539899674, 0.045387292761475816, 0.05515001466377609, 0.026866531134733272, 0.03847080583293592, 0.07762608058269947, 0.07108511463288339, 0.0818648220851056, 0.0848672125909117, 0.2437976453333132, 30.189839947608213, 59.10095584008002, 42.27071262175038, 39.7754301563386, 73.72612491730722, 18.45939378584585, 7.585710450526207, 0.276473838715784, 2.0402152067230594, 1.7005942112976506, 3.531597670047514, 0.11615956006872079, 0.041950296745785785, 0.19273716505737076, 34.41988868098105, 105.38951304651077, 91.86099944576141, 85.88860250288441, 83.37264522429436, 87.48903935955417, 82.33528029534125, 74.2414302210654, 59.21207658706173, 71.07573232343121, 78.50044958053097, 79.88249671074652, 79.33052509061753, 80.20095394503686, 81.7190916307511, 76.51756594257971, 76.5907181462934, 76.14283838579732, 75.97876564148935, 75.5611587339832, 73.8753475681428, 75.5494857603504, 72.76495595132151, 71.90429379863124, 67.34551906585693, 64.31493113117834, 55.50847661110663, 54.87661807767807, 52.03214660767586, 52.05350391326412, 50.234367462896536, 53.192862233807965, 47.964703652166556, 55.714099022649954, 55.9491313657453, 61.358844695552705, 57.68383095341345, 62.16684510630947, 58.73407302364227, 64.06209122750067, 61.63520313078358, 72.13471735677412, 63.497148329211825, 75.65411890706709, 36.40030122572376, 50.40552793010589, 75.46454291189872, 62.04762074255175, 67.98026054136216, 60.44875675632108, 62.07460272696711, 54.6313169694716, 55.55103432747626, 51.91692306149391, 54.63464313937772, 49.607000043315274, 52.02746722006029, 48.80196494440879, 50.18059176783408, 48.444476204533736, 48.82374194360549, 47.81430429027927, 48.6347621487033, 48.49167016244704, 46.17807188341695, 48.5748871680229, 51.641490305623705, 54.16360570538429, 57.19628034099456, 58.02584594295871, 62.20939890030892, 69.07403699813351, 68.4842929532451, 65.93090841847082, 67.43187396757065, 68.54490926188808, 61.84901937361687, 54.204927875149636, 59.97827237652194, 69.70034537776824, 70.33512607697519, 70.34279823303223, 69.44236324679467, 70.97415862544891, 68.14121107901296, 73.00670731452205, 68.81890250790504, 69.95690761073944, 61.61035491574196, 60.96982009949223, 48.01892649742865, 62.98105070667883, 24.680155208033902, 0.35535999603809854, 0.6570025809830236, 2.351047843694687, 6.592984055319141, 1.7815298683220342, 0.9229187475096796, 0.3202669178285907, 0.5276275522285893, 44.75490262431484, 26.870669511056718, 26.649400764896026, 44.924078372217, 28.106559322726344, 0.1751286800830595, 0.07679114433666391, 0.04346785180631184, 0.03352935869066465, 0.031570879810099164, 0.014725179963504836, 0.01825990868852504, 0.03369429359032262, 0.035110403287915454, 0.0370746718779687, 0.031445882989153746, 0.0384583454128475, 0.10466100933450846, 0.04309429967355344, 0.017420396982361714, 0.03427714094399445, 0.02078481957376484, 0.02015414343576037, 0.023862491624670166, 0.0618624234301669, 0.054150235448633476, 0.09051795372919691, 0.07739966329667838, 0.03928044968615136, 0.012004127587011505, 0.07133011721194753, 0.01885638857680944, 0.025355884272064415, 0.029927941054225932, 0.04398573490400468, 0.038773969807211435, 0.008039821761720365, 0.09105959321342169, 0.03909147111698985, 0.03368178720495874, 0.031078965177819617, 0.06284238778114801, 0.04150425354319234, 0.014867189682028709, 0.03346501879634396, 0.01735491944747346, 0.03345258518933289, 0.07448980855124612, 0.03412064833326205, 0.09260784924751328, 0.07159929752590195, 0.015365490614767037, 0.06422385498280488, 0.009360123545892779, 0.0659343531175006, 0.029212753926854462, 0.049053988749942476, 0.12153258667357507, 0.026651093803886926, 0.32399415008483395, 0.9165876743293578, 50.14809100858627, 73.59360371866535, 44.03825813724149, 61.81038794978973, 77.77051218094365, 24.202500735559774, 10.737395190423536, 0.6499851543095805, 2.773411115331035, 3.080467735567401, 5.49313380833595, 2.5066004645439888, 0.173781284641835, 0.4051212678032537, 44.17530182869204, 107.10300045628702, 88.93097323756065, 86.1203282879245, 85.62060263849075, 89.77334145576724, 84.6499336919477, 76.1039206289476, 60.74837876904396, 73.31961047264838, 82.70966268354847, 83.18447343764767, 83.26676476386287, 84.1062068939209, 82.77333844092585, 76.17323675463277, 79.84710124231155, 80.93202883197416, 77.80877882434477, 78.38004066098121, 75.52265674837174, 78.2571606482229, 74.22841579683366, 74.9196707817816, 71.27052507092877, 66.64684295654297, 57.81422230505175, 57.443193543341856, 53.47086414214104, 55.47811746597291, 52.836828693266845, 55.602864526933246, 52.683958238170995, 56.15142368501233, 59.78582128401726, 64.42085473768174, 59.47689933161582, 64.94135718191824, 58.4713722813514, 66.33123336299774, 62.119443262777025, 74.10090738727202, 65.59303937419769, 77.03145919307586, 40.80923357317525, 53.97229994496992, 78.7248876017909, 65.04447629374843, 70.2628211052187, 62.57635231940978, 65.99791034575432, 57.53824826209777, 57.705764847417036, 53.961642865211736, 56.14035475638605, 53.45214659167875, 55.61114857273718, 50.21052337461903, 50.46398693515409, 52.68763742139263, 52.46455261784216, 50.98070036980414, 50.00268090155817, 51.64779747686079, 50.151840794471006, 50.32961045542071, 54.89965808007025, 57.27172713125906, 58.368833680306714, 62.00087785720826, 62.73465133482411, 71.02677329894036, 71.13241057242118, 69.61764612505513, 69.04736488096177, 70.86805851228776, 63.84637655750398, 54.59105383965277, 61.59214727340206, 69.49125166862243, 72.62165607944613, 74.00598602910196, 71.25340784749677, 74.51184626548522, 70.26631201467207, 73.39151536264728, 72.15486264997914, 73.33925370247134, 68.36775149068525, 67.78990791689965, 56.35948581080283, 72.59146951859998, 25.853620498411118, 0.4175093691916235, 1.1164392987566611, 3.9812221498258658, 2.74368935535031, 0.19340882498410442, 0.9995526676216434, 0.6500113238730739, 1.3165109436358176, 54.748556613922126, 42.346822292574, 26.414460597499726, 48.34136885981406, 40.35508978751398, 0.9264618735159598, 0.011511729361729757, 0.039148422093280864, 0.04255367142538871, 0.06657017545113642, 0.01901019413414742, 0.02017222119555358, 0.030248692492023114, 0.017284872198116877, 0.03573646183095632, 0.04402442234418085, 0.051301909054839806, 0.08481118858100907, 0.04644322622146818, 0.009447228700493374, 0.07079177956667639, 0.05144348210324684, 0.026058241341923995, 0.036006515485144434, 0.04015518036941367, 0.06565823204695218, 0.048274410017315424, 0.036421857714172334, 0.017239056309805285, 0.0585339782429078, 0.1875255761608001, 0.1364737680001605, 0.1083434331080606, 0.131242843044381, 0.14905604203381848, 0.0946995757159687, 0.08787547899109703, 0.20853832604423647, 0.146408626028607, 0.1027393697070018, 0.14428797208013075, 0.11462226675282564, 0.19420040831450494, 0.12616915763506006, 0.21076405661240702, 0.10010323051603572, 0.099252765667775, 0.24605856998072517, 0.20661015934761495, 0.2068956649952358, 0.12837740607679854, 0.13430029995018436, 0.1465046474890363, 0.1789173525908301, 0.1931338147410462, 0.12157647585075711, 0.21200121200132757, 0.14864581727212475, 0.28696645471838217, 0.43136455959850745, 2.6506534314924672, 76.53921742593089, 83.01046925206339, 61.68526826366302, 61.14820557255899, 98.3481917842742, 29.54774795040008, 11.057839105206153, 0.7737556063840467, 7.071550478858333, 5.283106084792845, 12.423943761856327, 1.8533466275661223, 0.22735408897842133, 0.44978428571935625, 41.180258412514966, 107.40747836328323, 93.30403943215647, 88.59600282484486, 86.93611068110313, 91.87741848730272, 88.4452896733438, 80.16814724091562, 64.4233101414096, 77.40901870112266, 85.63216578575873, 86.29326558882191, 87.10627094391855, 86.63025994454661, 88.72121272548553, 79.21002203418364, 82.7860704545052, 84.20621164383428, 81.09190464019775, 82.55235210541757, 79.94908286679177, 82.18048003412063, 76.46609660117858, 79.38349277742448, 76.48444544884467, 74.21056901254963, 61.98055605734549, 61.91913174044702, 56.57505143073298, 58.444311849532596, 55.53328168007636, 58.26038798978252, 53.84527006456929, 60.327178970459975, 61.56558890496532, 67.42824185279109, 64.11783203001946, 69.02168120107343, 62.59116711155061, 69.8567695002402, 66.07737756544545, 77.34462122763358, 69.00095539708292, 80.79454975743448, 42.448286164191465, 55.36171720873926, 80.29505160547073, 66.7086830446797, 72.52403613059752, 66.13539726503434, 66.64789415174916, 59.65093097379131, 60.74069092350622, 57.611333785518525, 58.265945988316695, 55.051336134633715, 58.49920542009416, 53.57435195676742, 53.79510295006537, 55.744211058462824, 54.1466728333504, 54.6506699439018, 52.46950657136979, 54.4209014215777, 50.54408565644295, 52.48759262023434, 57.63302449257144, 59.71400660853232, 62.6272136934342, 64.34012451479512, 65.64679153503911, 75.4178039489254, 75.46681788659866, 70.90968270455637, 70.57213137226721, 74.28059116486581, 67.50068018513342, 57.811574705185436, 64.95987469150175, 75.22044597133514, 72.66953252976941, 76.83007686368882, 73.24346157812303, 78.29914569854736, 72.68689294015208, 75.98990517277872, 75.43380721922844, 75.69944581677838, 68.75095136703985, 71.99361401219522, 61.15605031290362, 71.69530991585025, 31.769282317930656, 0.6137691137771453, 1.5240322726388134, 11.385380548815574, 15.678154845391552, 5.716984944958841, 6.387489120806418, 1.952084206765698, 1.962645065880591, 67.91271732699487, 37.68348893811626, 40.94168809152419, 63.85760630330732, 54.28822332812894, 1.7116282063145793, 0.3256957232952118, 0.1904304283520868, 0.15192733957402169, 0.1259071862084731, 0.13037848136117383, 0.15550153810651074, 0.1488676763349964, 0.0831044212945046, 0.18036760299676852, 0.17393623358539997, 0.15775006745130787, 0.20398892822765535, 0.2208544917765164, 0.10776758779801669, 0.18131172975465176, 0.14813453019145997, 0.08756106118521384, 0.10117714022917133, 0.14344374318757366, 0.19552330426391096, 0.16387699352156732, 0.11440180196997621, 0.13934673561203864, 0.08446519263088705], [0.025994834159651113, 0.043791964454876806, 0.03267065839721792, 0.022491274679440166, 0.05966901411152175, 0.04044866099232628, 0.06444064254361777, 0.010918450763358945, 0.04992025799208111, 0.046816318701472015, 0.062466146679775375, 0.04969336190110734, 0.06845099025315816, 0.027722973384023197, 0.05260417042600532, 0.028070327224991018, 0.031413531096111384, 0.033415563990392035, 0.026790789936879472, 0.07328718074507291, 0.03796514183763535, 0.01836541623267676, 0.056052604134404854, 0.09273217765674477, 0.12659489567722046, 0.0917607015599647, 0.13857928405125297, 0.042748292232112545, 0.1255550921984738, 0.03606446237573701, 0.6722286704086489, 7.814068390477089, 64.88802079231509, 48.64165375309606, 24.603892564773563, 47.550560197522564, 58.21712816915205, 5.894604084953185, 0.18654073949062056, 0.31496528295740006, 2.2152911799569286, 1.3125665101312822, 3.4824381143816057, 0.0927653109594699, 0.09720973174778685, 0.12160104429048878, 14.570045067418008, 89.09617562447825, 88.69104185412007, 89.94587083016673, 89.35611894053798, 80.09523822415261, 73.61336461959347, 66.69066367610809, 74.25402887405889, 79.42087296516665, 76.78217687914449, 80.14734298952165, 73.45564611496465, 75.748718630883, 77.33730992963238, 80.91276214968774, 75.75007577096262, 77.29406187611242, 76.19741424437493, 74.46460523912984, 73.03587405912339, 77.00415949667655, 75.04816762862667, 67.78353798773982, 63.3565588151255, 58.449359939944365, 56.6092231196742, 56.21243223067253, 52.05787735600626, 50.706565918460974, 51.13984661717569, 51.38812088197278, 52.59988615589758, 58.06596002271099, 60.86814441988545, 58.863130769421986, 62.750183920706476, 61.233281781596524, 70.40621511397823, 63.29454222033101, 69.12920121223696, 62.78479099273682, 81.09276756163567, 40.908398935871745, 50.25986286901659, 79.07045625871228, 62.25376875169816, 68.03596604254939, 58.10814511391425, 61.98957750874182, 53.16316989160354, 58.64079513857442, 51.253724790388546, 52.81735804773147, 50.313850372068345, 51.74081256312709, 48.28381592227567, 51.39225113776423, 48.90171081789079, 51.22143976150021, 49.26860932380923, 49.30695833698396, 47.77135041452224, 49.884778376548525, 50.25781931415681, 50.647714676395545, 53.86119880983907, 58.33896090907436, 60.25995739044682, 63.12691580864691, 65.75027150492515, 71.42508998993905, 69.91405179423671, 71.24065229969641, 66.1709810072376, 63.687873578840694, 58.53900963260282, 60.76347989420737, 66.8648482907203, 75.20593320169758, 69.36441006199007, 69.46739581323439, 65.47268144546017, 71.60871182718586, 67.80804495657644, 74.32541601119503, 68.9762209307763, 70.81034475757231, 50.35276028417772, 54.64368812499508, 47.57021519445604, 0.3904929721067029, 0.03655718331555686, 0.4441835394790096, 5.107709457797389, 0.8502553078916766, 1.6922293891829832, 0.7448804654902028, 0.5328821186577121, 21.372704813557288, 49.67573173584477, 60.76593922030542, 50.61990507187382, 47.10383361385715, 26.98352198446951, 0.4888443204183733, 0.10156657336460007, 0.12139590126612496, 0.07386338611644122, 0.02819027744173523, 0.03549639285812455, 0.0769880825593587, 0.049463474236789255, 0.10694876238102875, 0.04711621148031085, 0.07579504617399747, 0.01619311455156534, 0.03724418415297424, 0.048920417489904555, 0.01121979144837467, 0.045253602757809624, 0.020066531705519846, 0.011025196497118282, 0.023670251436171033, 0.0671323997178866, 0.04758455167194048, 0.015856710979865206, 0.04099879256119171, 0.08726103051054863, 0.020715331568592982, 0.05279113801436559, 0.029253892848388325, 0.06835427165271775, 0.04507295922526429, 0.007562447478243662, 0.021557110895012176, 0.03879502573381028, 0.0013441623107815583, 0.02239691754502635, 0.04882434623376016, 0.04101782218523083, 0.016293313106401794, 0.12230710922590188, 0.024783658727462736, 0.11189700855362801, 0.034076238216291514, 0.07809461995718942, 0.005834601282502615, 0.06500191686134185, 0.031838355578422066, 0.07203766835793372, 0.07135402681606431, 0.06558428157962139, 0.020302299094656785, 0.11603071940161529, 0.014385629685655718, 0.05832230048854986, 0.04892232121839639, 0.05280003229516649, 0.06709150594448851, 0.6074521366146304, 12.945568984554662, 83.76922822767689, 43.51712419140724, 32.75325986646837, 72.15289362015264, 53.27423572540284, 8.294422434222314, 0.08336337433466989, 0.538686000772061, 1.7245057153124965, 4.881295542563162, 3.4539967631140067, 0.5453450208710087, 0.3034113593880208, 0.16359783108195952, 22.51777606625711, 93.30322357916063, 87.81032854510893, 89.95690053509128, 89.67090483634703, 84.58257090660834, 79.22018097292992, 70.7491087144421, 75.99179575520178, 82.4632986130253, 79.45961029298844, 80.02712234374016, 76.32300853729248, 78.98654107124575, 82.48139642900037, 81.15484299198275, 77.36136974826937, 77.86820273245536, 78.74074966676774, 77.28789591020154, 74.35823840479698, 77.80705298146894, 76.70138389833512, 69.4558640449278, 65.17217689944853, 59.7460876741717, 59.46963510205669, 58.316113102820616, 53.59505814890708, 54.48045476790398, 52.512754624889745, 54.34652936074042, 53.72797942930653, 61.27575320582236, 61.95046363338348, 61.2385848260695, 64.13622010138728, 61.87380090836556, 70.35636963382845, 65.35772462044993, 69.99668828902706, 65.89750551408338, 80.81603650123843, 41.2055302435352, 51.06966364768244, 81.1376080974456, 63.90632998558783, 71.65068118802964, 60.6624984741211, 65.61975463744133, 55.237833069216826, 61.48661198154573, 54.0185760682629, 56.64236714763027, 53.309489988511615, 56.48324443447975, 50.381126865263916, 54.19184677062496, 50.38602198323896, 53.13701552729453, 51.57369998193557, 54.97111581986951, 50.360306924389256, 53.221279805706395, 51.87625984991751, 54.47378673861104, 57.340039130180116, 59.8932118569651, 61.45524478727772, 66.59776626094695, 68.57777872393208, 73.07121461437595, 69.78640217934885, 73.27171048810406, 69.47366376076975, 66.79474769100067, 58.870320473947835, 65.11401207216325, 67.17768084618353, 77.22963302366196, 71.82071593499953, 73.42731091283983, 67.99832697837584, 74.9117083703318, 71.097807422761, 76.94865011399793, 70.60590297945085, 74.31606508070423, 55.75060059947353, 65.65464412012409, 50.70229053497315, 0.5061691230343235, 0.12918126979662528, 0.48375354358746164, 2.9930069706132336, 0.27414272509274945, 1.0631847886308547, 0.3653786181201858, 0.37701650492606625, 27.329120059167188, 62.579835384122795, 60.28047923118838, 40.58034758413992, 57.124999107853064, 32.623425491394535, 0.5291020569782103, 0.09961671105796292, 0.05260418191732419, 0.07568692818524377, 0.05148783859406268, 0.03138190698659709, 0.053129948059757875, 0.09416021917375827, 0.1127030096587635, 0.05162091572738944, 0.07759088650345802, 0.036872271448373795, 0.024863873878794334, 0.058877518881232514, 0.03586842430635326, 0.04242345946089875, 0.04703161239083256, 0.024026378899091677, 0.07897288613622228, 0.0439767180491359, 0.034446197396685044, 0.005072193453088403, 0.025937480987199855, 0.0314105088792501, 0.05793556015217497, 0.15489908656285656, 0.09671562801926367, 0.25169028149497125, 0.13749943715670418, 0.23848583681448815, 0.17209759192360988, 0.16346344393828224, 0.10962194192313379, 0.19960954064323058, 0.13583967702523356, 0.10390691068624297, 0.13555541244005004, 0.2150477444933307, 0.16820788774038517, 0.20272512830072836, 0.12738545244980243, 0.11864118698623874, 0.11719247641702814, 0.17317370030908816, 0.1564416199201538, 0.19584585792355, 0.08824524664950949, 0.13687968734771977, 0.12950993683790007, 0.3855147182701096, 0.22581924714388388, 0.2324785889997598, 0.2007914304492935, 0.3471961341077282, 0.27137478813529015, 1.2201311992060755, 24.29080309406404, 100.65694593614148, 70.37711897204, 39.39754116919733, 70.97216606140137, 83.30894593269595, 12.881486281271904, 0.4458224466971813, 4.200124481031972, 9.17824226040994, 12.503980705814978, 8.478900328759226, 0.20807274376913426, 0.26989387889062205, 0.23524153106395276, 18.30696459739439, 94.79981176314816, 93.85104533164733, 92.49230492499568, 96.83959330281904, 87.57486866366479, 82.615368904606, 72.86465475636145, 82.24975693610408, 86.43294119065808, 82.32654125459733, 83.37270013747677, 78.82525320976012, 83.52520973451676, 84.63931191352107, 85.10814497547766, 82.54271876427435, 79.14725626668623, 81.80894528665851, 81.78284583553192, 78.62932297491258, 80.54479675908243, 81.56567204383113, 72.75690724772792, 69.77508221903156, 63.676192760467536, 62.0228039064715, 63.48443984985352, 56.29823800056212, 57.51789900564379, 55.45368502216955, 59.30799030488538, 56.33770096686579, 64.27978277206421, 64.98301275314824, 65.01352487071868, 66.76580844386932, 65.84807580517185, 74.60802278211041, 69.88794449836978, 72.31155349362281, 69.73230484993228, 83.20028843418245, 43.807681606661895, 53.10162005885955, 85.34995125186059, 69.01634677763909, 75.10764644991967, 64.46711124912386, 70.08869924852925, 59.30187925215691, 65.89268099877143, 55.862980427280554, 59.85850280331027, 56.42237709414575, 58.79579151830366, 53.97018186507687, 57.82082365405176, 54.12874367929275, 56.01512524389452, 54.18446879233084, 56.36178431972381, 53.402340335230676, 56.283917427062995, 55.505738796726355, 58.44113472969302, 62.25351379763696, 63.548245045446585, 65.48217358127718, 71.59892159123575, 71.81020398293772, 75.78390229132869, 71.65982031053113, 74.43379894379648, 72.02637364787441, 69.85610269731092, 61.62293395688457, 67.88180120529668, 70.43172620957898, 81.56458946966356, 74.93597215221774, 73.0616283416748, 71.54796215795702, 78.49414240929389, 74.9521872305101, 80.90933399815714, 74.54400185615786, 78.98992999907463, 63.41769287663122, 67.14372096523162, 55.40611059434953, 1.4694190289705031, 0.11204572920236858, 1.7506666986211654, 14.782647336682967, 4.080122017091321, 3.9170019184389426, 1.2646083029047137, 0.9441298835219877, 35.690850365546446, 64.77530364067324, 68.94408102958434, 67.13520157721736, 69.02325799388271, 43.273231214092625, 0.7079995832135602, 0.3386875019679147, 0.22441726027717515, 0.2589298430229387, 0.15541527660623675, 0.2283450543519951, 0.15030968363486952, 0.2021328810482256, 0.24783702777518382, 0.12791256690698286, 0.15547872400812565, 0.11384613541585785, 0.09675375621525512, 0.2003914406222682, 0.10711813676020793, 0.11286063991006344, 0.1711768002039002, 0.13735646982827496, 0.09805723949665986, 0.16233613023594504, 0.18642601016308033, 0.18090780223569564, 0.18011189816940218, 0.21754177437434274, 0.10513787608473532], [0.07767989059850093, 0.04216659401032714, 0.03171429913040371, 0.05608995858159277, 0.032977671963312936, 0.025394096737727526, 0.03953339659699029, 0.07980332544614231, 0.016773385934591774, 0.03231724288554923, 0.018570463496050047, 0.0770706438549584, 0.06434260627194759, 0.020566869474526857, 0.029965264857896877, 0.028243941900831078, 0.024051230791355335, 0.03715391984329589, 0.036436064814728115, 0.05176380261658661, 0.011066328715382805, 0.02169882183924558, 0.006578798723151728, 0.06812192484616272, 0.06528372996516767, 0.05779649221128034, 0.04784180399691386, 0.0886936838768663, 0.027681989595294002, 0.03699183479071625, 0.023817428417744178, 0.21893112079030086, 38.46614691518968, 71.80035883380522, 48.45780049600909, 30.59972566943015, 72.76442250897809, 29.176321068117698, 0.022609242643680305, 0.6333924253140727, 1.7138997489406218, 1.4172288294761413, 4.816105750299269, 0.8020707676487585, 0.0477328701245208, 0.27965475835146447, 0.480569651530635, 9.825815769933886, 89.63088097110872, 92.44869601341986, 89.46405472293978, 86.96882324834024, 79.51568449697187, 65.94713918624386, 76.39682754393547, 80.09966265770697, 80.08269448434153, 76.42389189812445, 75.69104409986927, 76.42568049892303, 75.7404738087808, 79.39303198168355, 79.54140740056192, 79.01519006298435, 76.14634498473137, 72.39884976417788, 75.91615676879883, 73.80997734685099, 74.39990182076731, 67.53020778779062, 64.6616647320409, 59.30912779223535, 58.11522499207528, 54.489374237675825, 53.398527791423184, 53.30932524896438, 52.23492922321443, 50.77355607863396, 54.249391863423014, 60.447285867506466, 69.6934812299667, 65.39159820925805, 66.92524494663363, 62.77947225878316, 68.37563545473161, 65.9804008853051, 75.64816474914551, 63.663041053279755, 77.80655091808688, 34.95476268952893, 45.26985883712769, 81.85395056201567, 60.67729365441107, 68.80786495824015, 59.5413399511768, 61.66193408350791, 55.594027426935014, 55.576161030800115, 49.959315176933046, 53.239499215156805, 49.72332185314548, 52.44968683488908, 49.41390568210233, 51.32987760728406, 47.38443997598464, 48.85778419433102, 48.00175043844408, 50.64594176507766, 51.34801464696085, 49.63271117979481, 49.835034878023215, 51.135704594273726, 51.99724928025277, 54.65083468344904, 60.72922583549254, 62.857025361830196, 66.28176443038448, 71.37633492869716, 68.09910835758333, 68.78844922588718, 70.37916644926995, 69.89181195535969, 59.79986729160432, 63.41100915785759, 65.1334709505881, 71.05332774500694, 69.53122062067833, 73.27356184682539, 69.92376358278337, 72.1793931530368, 69.955440644295, 74.15498118246757, 68.94572058031636, 62.233862723073656, 43.75337246925601, 59.50375580018567, 3.209668157562133, 0.12145145030151452, 0.11029282810106394, 0.623225151531158, 1.3894546488600394, 1.0213473787711513, 0.12533691801851796, 0.5594011408186729, 3.504977769428684, 53.24448062527565, 54.54657808426888, 99.64446452356155, 43.351659005688084, 54.79349520898635, 4.844992045433291, 0.41137548704301163, 0.4062130656694213, 0.04429715730610394, 0.032113528615164186, 0.04645814961423317, 0.02329381881281734, 0.05607268329890025, 0.028545098724744977, 0.05886783552986961, 0.07312970371135781, 0.06072643761252684, 0.08575313198830813, 0.06252828024087415, 0.061660229844311555, 0.053115495811066324, 0.05199976535814424, 0.03209585113631141, 0.03408067003493348, 0.08431502407596958, 0.03007262441960554, 0.020274085991625345, 0.05235366733564485, 0.029642353052153226, 0.04307671029481196, 0.023061648206484896, 0.06232004988217547, 0.08423347401642993, 0.03762895564338373, 0.029117931394026648, 0.014650821554354362, 0.043321942700253385, 0.027652585225540306, 0.07145223162707783, 0.019433628166875532, 0.016844921309741277, 0.0029920691468437476, 0.027561518438761274, 0.013098676666437138, 0.053685947862123294, 0.03023087520212416, 0.0020942919053918412, 0.0733869024101765, 0.04490912749221729, 0.025784954796695424, 0.031914525785513466, 0.02164116223162461, 0.014972495170490397, 0.030979017516778364, 0.049314194343863964, 0.02447097611072804, 0.018969187362780495, 0.019205621248411558, 0.056040534419157816, 0.04991772990193098, 0.03187270504572699, 0.08244587679303463, 0.027829622399182092, 50.233728116558446, 84.32957803049396, 37.595365047454834, 45.58495460018035, 92.23555441825621, 34.03604945828838, 0.34511645054144247, 0.9553198540402997, 1.268209774167307, 1.9076541715091275, 4.843472126991519, 2.291856336016809, 0.48945072497571673, 0.3980181924998761, 0.9397873907319961, 14.863268713797293, 98.37437752754458, 89.2773106790358, 91.38616515744118, 87.14496904803862, 81.30929808462821, 66.7165905429471, 80.9569751062701, 82.02921775079544, 80.32152760413386, 79.92909446839364, 82.3841138039866, 76.94996018563548, 78.83634567260742, 81.79683300756639, 81.76956469012846, 81.8238816722747, 79.60280818323936, 75.24528241926625, 75.75930903034826, 77.09382487881568, 78.50514073525706, 71.35112977796986, 65.96395830954275, 61.75479619733749, 62.303680912140884, 55.563307423745435, 56.33061716633459, 54.67971117265763, 55.6905020436933, 52.83974693667505, 54.63368608105568, 61.51979915557369, 71.24895987972137, 67.72120368096137, 69.17739929691439, 66.24964021867322, 69.4908437421245, 67.28024298144926, 76.4218444208945, 66.53391007454165, 77.84074614124914, 37.74749417458811, 49.17495881357501, 83.76983227268343, 64.5108299870645, 71.2349727076869, 60.32695539536015, 65.03303081758561, 57.78105082050447, 60.14389445704799, 51.796933835552586, 57.15296952955185, 52.12156095812398, 53.93349985922537, 50.551247904377604, 53.790529466444454, 52.47755135259321, 53.00884423717376, 50.032306563469675, 52.60926846534976, 51.72112618723224, 52.32276678085328, 52.11630890446325, 53.88717274512015, 54.67652228570754, 57.878737449646, 63.77704081996795, 63.70270406046222, 68.24117660522461, 74.21409130096436, 70.14282011216687, 71.51116248100035, 74.0553451353504, 71.15022597774383, 60.580520937519694, 63.60855933158629, 67.2087146389869, 74.09812250444966, 71.6145561587426, 77.05235758135396, 75.08121751969861, 76.34137307443928, 72.28972942598405, 78.74879052562099, 74.3216662253103, 67.01308250427246, 53.69505505408011, 69.2373566473684, 3.5967901589409, 0.16467355642347567, 0.24560077115893367, 1.0479640311771825, 0.521514231879865, 0.6104480306948386, 0.1777866374581091, 0.883684688277783, 7.2298166444224705, 63.76835669240644, 59.03377740613876, 85.3785845541185, 44.62338555243708, 66.25474714463758, 6.398283483520632, 0.3338257241393289, 0.270165472381538, 0.047091949475748886, 0.023716396742290067, 0.055285370908677585, 0.08949167936319306, 0.03262063668620202, 0.07604879747715688, 0.0232210059860541, 0.028948627877980474, 0.05313236123671936, 0.06387184524247724, 0.039748077416011406, 0.011108226063961705, 0.028036925791492386, 0.0761749032103727, 0.09883094999578693, 0.04633432299259209, 0.08389621912952393, 0.06389697675683326, 0.02477659348158106, 0.036935366449817535, 0.015435130879913848, 0.02645075415080834, 0.07554828159270749, 0.13224073385279025, 0.29719982656740374, 0.1910575326051443, 0.1566904146344431, 0.0859794190393821, 0.08499273609730505, 0.12105726742095525, 0.1857728282770803, 0.1550025237543929, 0.0907465007396475, 0.0852409256021342, 0.14409586787223816, 0.11344454446507078, 0.07631519689194619, 0.10339445149105403, 0.09429107465210462, 0.22363883833731377, 0.09729837578150535, 0.10807798364229741, 0.2899217154950865, 0.19636840649670173, 0.12905075905784485, 0.1070335683142466, 0.13424724070054872, 0.12361587851398415, 0.1045942600936659, 0.11647995336041336, 0.18487664330149853, 0.18513057080488052, 0.20171531716421728, 0.18255253172209188, 0.35420283555023135, 71.38829815772273, 96.26470719614338, 75.41109669593074, 47.15287108575144, 96.1124486307944, 47.07448644022788, 0.45688659493480965, 4.213924850186994, 7.142349260468637, 6.799751308656509, 22.896800579563266, 3.5025824269940777, 0.25624442905668293, 0.3379458982136942, 0.5975408587724932, 11.160959197628884, 98.66612342096145, 93.32435730964907, 95.28021581711309, 90.29499315446424, 84.30658509654384, 71.26348049409928, 84.20930247153007, 88.53693193004978, 84.83153943092593, 82.7456465075093, 84.50078948851555, 81.99940773748583, 81.28735634588426, 84.71117757981824, 85.24521612351941, 85.79970590529904, 84.6171191430861, 75.72407045672017, 78.14793832840459, 81.20197419197329, 83.51523906953874, 76.25142528164771, 70.96381925767469, 68.35696497271138, 65.72275215579619, 58.73201770167197, 59.17996806483115, 58.44818715126284, 57.05984069455055, 56.06006383895875, 57.12909013994279, 65.09553378628146, 76.18498817566903, 72.93539862478934, 72.74285731777069, 68.7415219891456, 73.87623402380174, 72.6325132000831, 78.96589371465868, 70.94536058364376, 78.13224100297498, 38.33387674823884, 51.603266808294485, 87.14028573805287, 67.85170878133466, 74.64186499195715, 63.85962240157589, 66.99547106219877, 61.27676909969699, 62.566362042580884, 53.818468509181855, 59.28752337732623, 53.5139553008541, 58.18325065797376, 53.61599968325708, 57.278552055358894, 55.368765707938906, 55.35251140594483, 53.084585205201186, 56.67172608837005, 57.80638148707729, 56.4585413471345, 56.18952558886621, 56.60985069890177, 57.61804103851319, 62.8430264226852, 69.56740840788811, 66.77584971151045, 71.51850515796293, 77.51802921295166, 73.14505715523997, 74.22400705275997, 74.98488410826653, 75.38051005332701, 64.14861086876162, 67.30542459795552, 68.28448741666733, 74.6319413954212, 74.78421565025084, 80.73502386769941, 76.12248912934335, 80.06852688327913, 74.77021278873568, 82.75727241270005, 73.20197074644028, 73.38244684280889, 56.903432261559274, 73.15558479678246, 4.782541048142218, 0.1463433400156998, 0.9133014635693644, 8.373493494526032, 5.66784058847735, 2.6901794008670317, 0.272229926119889, 1.3417871873224936, 8.391541300281402, 74.47768242128434, 65.23952007293701, 107.9996935013802, 58.17656301682996, 79.83676971927767, 9.040343492261826, 0.7867442900615355, 0.5613378110912539, 0.16851973149084276, 0.1843475216939565, 0.17059108002051232, 0.22350124894611298, 0.13443749097566451, 0.13762542797673133, 0.14099524957278084, 0.15851920440552697, 0.19305262474283097, 0.1834720057705718, 0.24848435674944233, 0.2156464422061559, 0.1897219502397122, 0.12163063060612449, 0.2640225810389365, 0.1913286051562717, 0.17339889951530965, 0.16541994056634365, 0.13212487071512208, 0.22369753599407213, 0.1167235769812138, 0.15605261579396265, 0.11068832099197373], [0.0023910561726698952, 0.023755932624842373, 0.06719231545444458, 0.03466239123935661, 0.05496249932254996, 0.015001314440591922, 0.049090489009094816, 0.08707049678290084, 0.049362392765620065, 0.09634343186213125, 0.08024409413337708, 0.07624344509695807, 0.059074135346999096, 0.08431414307485666, 0.037673687517282464, 0.021863760569343166, 0.056924898658067956, 0.016410467102222385, 0.06482008589251388, 0.02728478641309325, 0.03127596851798796, 0.049068517607426455, 0.025380515914049842, 0.02206789235764694, 0.048254196787433284, 0.1195725200757865, 0.04123564779518112, 0.02227908556139277, 0.0960987663617538, 0.28426155147533266, 0.1369726750999689, 0.5245296765239008, 4.534012809876473, 67.48637922348516, 62.86277555650281, 33.5654434850139, 38.49075194328062, 69.60843639989054, 5.5787027651263825, 0.0962366315446073, 1.3687126650925607, 0.9191471434408619, 1.529268759392923, 5.632638787069629, 1.1623831237516096, 0.13020618818700314, 1.015613057440327, 0.18428729186134954, 4.63416317778249, 90.76904296875001, 88.86650516140847, 88.1821535479638, 79.80646548732635, 77.78824129412251, 77.1695109336607, 79.91295783750473, 78.10483932495117, 73.9949720136581, 72.38394475752308, 73.36916569740542, 81.37440942948865, 83.58912867884483, 81.91131914815595, 76.55328304536881, 77.49086287713821, 77.64044638602965, 78.26329523517241, 75.91654116107573, 74.80449430404171, 68.60515686773485, 63.77930402755738, 60.26574288645099, 62.02917775800152, 56.21471897248299, 55.837896870028594, 51.579254058099565, 57.048336382835146, 52.83338485225555, 54.04284377251902, 58.069337183429354, 70.81995456449448, 65.79117790345224, 68.41230961584276, 63.647033860606534, 71.11375577988164, 63.80317557242609, 72.16329574584961, 61.49563343294206, 79.81822475310295, 32.74329704623069, 43.817452230761134, 81.68198600892099, 61.66367169349425, 68.47555391250118, 57.65511528138192, 59.49001181510187, 51.937531194379254, 54.260605919745664, 52.76672024880686, 52.6344540042262, 49.484802522966945, 51.57647702001756, 47.99261131594258, 49.65482550282633, 48.99198416740664, 50.95370661827826, 50.47872720226165, 51.501398932549264, 50.92756794344995, 51.49109486610659, 50.795207561985144, 50.22394180297852, 52.06652618223622, 55.191392206376605, 56.67051407598681, 60.822197775686945, 65.87661497054562, 70.70087925080331, 72.31021988776423, 70.57674407958984, 71.2758908733245, 69.90955675801924, 67.01636945047687, 63.01029197631344, 65.18050016895418, 70.71623140765776, 72.85653545010474, 72.24981538711056, 71.86561922873221, 71.93051876560335, 73.37395098901564, 74.84937406355336, 69.43392230618385, 48.90377398460142, 63.257981807954856, 10.29613737137087, 0.6113978571468784, 0.9944214719918467, 0.8814925736477299, 1.4587825416557252, 0.6006038008678345, 0.08272251880337154, 0.19068849273025992, 1.4067768161335301, 38.95430549498528, 44.105522863326534, 31.899257898330692, 37.87010354380454, 47.49788668847854, 31.614756622622092, 0.0921224942430854, 0.13930362018366016, 0.0249862315268406, 0.06470790763776149, 0.031302136166261575, 0.010554591558062503, 0.09197256317542446, 0.03931416521569894, 0.05418977707684521, 0.021996634689369993, 0.04015927893980857, 0.026047809139615106, 0.0184325389413824, 0.07342641722531089, 0.014431387159763085, 0.02519386625217815, 0.03944489811997741, 0.060444555560787844, 0.060751848748975226, 0.04669131613486717, 0.023074077983056347, 0.06407347575370824, 0.05805616537409444, 0.04522432670778325, 0.016432103340423877, 0.02283022262065882, 0.04652974819163642, 0.02104202976390239, 0.01782728351592537, 0.02203896679284592, 0.026445200013357307, 0.07667027864485018, 0.08836078803024947, 0.06953969312411162, 0.05808918376363093, 0.06009482493203494, 0.04043634995938309, 0.029498740294647795, 0.07307426958915687, 0.038247629098834536, 0.02169772824873367, 0.05363266261654997, 0.03600713218592348, 0.02441752998669061, 0.0068434141106873516, 0.0032660176399193948, 0.038628554827864134, 0.011853870931982756, 0.05135573056196013, 0.026744056658278552, 0.07959294238037641, 0.10019090161809038, 0.01914949764707877, 0.04642609266504165, 0.018701228959065293, 0.1764050744954617, 0.1517951127982909, 0.5050834538715502, 6.773841111890732, 85.49724409657141, 60.90653657913209, 33.71222642160232, 61.8313334065099, 74.20765861388176, 10.33350088903981, 0.8291368378746895, 0.9686991812721376, 1.298673474980939, 0.17093591151698945, 3.5041450012114743, 1.930816747969197, 1.0396541222449274, 1.5505181998014452, 0.7340115777427151, 10.17826230295243, 97.22739804175593, 90.1609657656762, 90.46620461248583, 79.77821657734533, 81.3421832361529, 77.53740572160291, 83.12431212394469, 81.07657601756435, 76.70455317343436, 73.35790065027052, 76.5296389979701, 82.86585930855044, 85.2944810928837, 81.75655811063706, 79.72429967695668, 81.32796856664842, 79.27012058996385, 77.81555668000253, 77.64251739748063, 75.18339526268744, 70.6121866164669, 66.25607290575581, 62.89469580496512, 63.08541713222381, 60.411988458325794, 57.64689399350075, 54.819194578355365, 59.30900619876001, 55.442200322305005, 57.18447400677589, 62.67187772258636, 71.84795287347609, 67.5505962679463, 69.16779733473255, 64.24865876474689, 71.9380340268535, 65.62560289136826, 73.67130587177893, 64.83954421935543, 80.17692550536125, 34.990738668749415, 43.24331921915854, 84.41987883660101, 66.54511236375379, 71.98018381672522, 59.60989513704854, 64.34742012331563, 57.75213118522399, 58.83922392322172, 55.65124304063859, 55.128143987348004, 53.09810953755533, 53.05081752038772, 51.674257786043235, 52.5769010666878, 51.109409024638516, 53.65838089296895, 53.29165889370827, 55.983495250824966, 53.78196693235829, 52.944105517479684, 52.537336118759654, 53.81931966350925, 53.632034332521506, 58.40555883223011, 58.67724964695593, 63.56123201308712, 66.29186061120802, 72.27149040468278, 71.40174404267343, 72.08122407236408, 74.01724323149651, 73.16863844471594, 68.8150115166941, 64.85530430270781, 67.30869585467924, 75.69015764421033, 75.7588775696293, 74.39365740745299, 73.93583836094027, 76.3750897684405, 76.62406613749843, 77.42346871283748, 73.43139802255939, 56.85930559712072, 73.9270208727929, 11.07020829954455, 0.48758766043090057, 2.019541251563257, 1.372284473430726, 0.7493216916918756, 0.10379267931585351, 0.5728497223988657, 0.2049421254665621, 3.6132692617754785, 47.13394172729985, 67.7973839544481, 43.421367368390484, 43.10328668163669, 56.07995417810256, 41.40696748610466, 0.07374356230420452, 0.11270258831040514, 0.04611953492126158, 0.0016438882260943854, 0.021591414397041646, 0.034924596322760466, 0.013915469077596021, 0.08214400750735114, 0.02607852543493913, 0.029190663781557834, 0.02421024000091899, 0.03639909341150234, 0.04746685758413327, 0.0224672808056517, 0.04631181532937673, 0.018611428132581136, 0.04467210371888453, 0.05329788602407902, 0.050135011589455034, 0.03530507772079399, 0.03177283207825836, 0.0511621478043737, 0.03222981693163034, 0.0336806342426327, 0.029303610039454316, 0.11570366880586071, 0.08780040237451754, 0.1203854466157575, 0.08340255973199684, 0.08607345633208753, 0.100215784153871, 0.16353580860360978, 0.12534932098201207, 0.19294526518112232, 0.09312220834075444, 0.3349303309955905, 0.12157695082527016, 0.17938356305803024, 0.1969488100298951, 0.21609091109806494, 0.14980616468575694, 0.20280268704218252, 0.08902228197022792, 0.1643267637419124, 0.17642362914498777, 0.13930435562806745, 0.1844325727753101, 0.22865046296388875, 0.12179641203293878, 0.1412876500117202, 0.2130422335598738, 0.2226810905361368, 0.16135342329019503, 0.19640697136281, 0.314594833480735, 0.407398356905868, 0.5598159927514292, 0.9619149517628455, 10.290002784421368, 101.13165470861621, 80.53493592046922, 53.95392756308279, 56.19124358700168, 96.25762339561217, 11.602773993246018, 1.106473659315417, 1.8773473655023885, 3.421559987529632, 4.135649540731984, 16.703464369620047, 3.917977608019306, 0.5190192367280684, 1.7609701521935004, 0.38395214405271316, 7.040431864799992, 100.05928654824534, 95.35342293400919, 94.61247936371835, 84.98545323648761, 87.18889959396856, 81.71911516497212, 86.85802413571267, 85.5513963391704, 81.08648392461961, 75.86304787666568, 80.81746424398115, 86.6611054635817, 90.00804824213829, 85.99029387197187, 82.64979946997859, 82.99643501158684, 82.62905797650738, 82.85519830642208, 80.42290518360754, 80.20750430322464, 74.20943936994, 70.32167234728414, 66.07798945519232, 67.61129102399273, 65.42797034786594, 62.16227554505872, 59.98526204016901, 65.41008433988019, 59.75940412090671, 61.605173464744325, 65.29075014975764, 74.96011826299852, 71.424360429087, 74.18250053159653, 69.3329369637274, 74.88312213651596, 68.77241457662275, 77.0534715344829, 67.71235481385263, 81.69354915618896, 37.12157410960044, 47.843561249394575, 87.87867192299136, 70.63167295148297, 74.50949284338182, 64.62311960035755, 68.65595940620669, 61.23881624590967, 62.39635867457237, 62.76786204307311, 58.060190216187515, 55.80627472169938, 55.87860322767689, 54.275240282858576, 54.73376927837249, 53.96236458132344, 55.76532909947058, 55.7687258720398, 58.213209721349905, 59.730970859527595, 56.710153548948234, 54.92016030896095, 56.997420095628314, 59.98538363364435, 61.905293618479085, 63.48893488607099, 68.49210631462836, 71.78306902608564, 75.50646520430043, 74.3851537089194, 74.98611573250064, 77.00437130466585, 78.1569048666185, 71.82501485270839, 66.90662153305547, 70.70045563482469, 78.90849374955701, 78.35649859520697, 75.9874576137912, 77.3543643951416, 78.78359763853013, 81.39502540711435, 77.23346125695014, 79.99738293309366, 64.45264554792836, 75.1230299857355, 15.39018423326554, 0.6411421707560939, 2.6938338241269513, 4.002895206212997, 5.773550425806354, 1.4853992553487902, 1.4548278119294875, 0.45529852531129317, 2.7775222495678933, 61.90735678518973, 61.87832340117424, 44.60622910530337, 56.27384085809031, 65.62760722252631, 56.60791697040681, 0.18804542810445835, 0.22058888909316834, 0.1685223668333023, 0.11745601832385986, 0.11202768783175177, 0.16665470576094044, 0.13868722583978407, 0.20650439324878878, 0.10996773102951628, 0.15375165539162775, 0.12615562086143803, 0.12732363681519224, 0.18057041711384253, 0.10023711204168298, 0.11898331419234315, 0.13343440609112864, 0.19964775310889368, 0.13951221060368324, 0.19670618998427547, 0.10276910924022237, 0.0810545921746281, 0.19812192046834579, 0.13243205665100005, 0.2516632845565196, 0.09166148551289113, 0.24300883524119857], [0.041837256642118584, 0.07491894802379032, 0.08545831071152803, 0.03150548079922315, 0.06807081912073397, 0.019367313680930004, 0.07036935868522814, 0.03910534496929857, 0.0705718970106494, 0.057664292248626875, 0.03814393143740393, 0.06920700412123434, 0.07840262560714638, 0.029594143139078256, 0.032932760058751995, 0.040899204961474867, 0.038833130947163993, 0.04415686362453046, 0.04972233534640363, 0.08388758531861729, 0.06551811456560128, 0.022953489998115167, 0.04370479897085217, 0.10993122693992431, 0.014714124357147564, 0.10035209417823823, 0.011454653896151051, 0.03872077649218902, 0.034243406262248755, 0.10769338452167089, 0.09264232320410591, 0.14612172610096394, 0.2262324596484823, 27.19736960626418, 75.2001908517653, 53.5074951571803, 34.57433985125634, 79.75169351024013, 45.64047967233966, 2.4446473631166645, 0.22103449179520532, 0.4125363553964323, 0.5313616486326341, 1.1933628613910368, 4.052702198105474, 1.7494733174962385, 2.011040617381373, 1.1545234293706956, 0.3093295418206723, 16.705166678274832, 111.754115627658, 81.040466677758, 95.06464235244259, 67.80800573287472, 77.23054301354193, 73.73775082249796, 81.1097514244818, 72.99007646499142, 82.24941961226925, 75.75162902955087, 78.80164054132278, 79.25088528663882, 84.34540087176909, 81.40818103667229, 79.21740393484794, 74.76265045904344, 77.4186912659676, 73.90905641740369, 72.62661395534393, 67.84060062900667, 67.70880899121686, 59.86641814631801, 64.78264239526564, 58.24845221734817, 56.883483086862874, 52.34908588470952, 53.68649251999394, 53.43318585426577, 54.03623457877867, 57.81876833208146, 71.438245619497, 66.5492622313961, 71.810392256706, 64.72047282803443, 73.05477988335394, 68.66322363576582, 79.52848711321431, 55.34577277398879, 71.29339248903337, 28.60609473720674, 39.57709550857544, 82.05393652762137, 62.161087066896506, 72.947432456478, 61.931538197302054, 64.56964592779836, 56.33800298936906, 55.9166855196799, 51.000982945965184, 53.69669460481214, 52.043337129777484, 53.620431961551795, 50.11843789008356, 51.913993050975186, 49.56049250018213, 51.41370650260679, 50.33689037446053, 53.824512881617395, 53.32325358544627, 52.22950850763629, 52.12829566770985, 50.83304666703748, 48.75672824921147, 52.06557696865451, 56.210878972084295, 63.68488473276939, 65.50246792454874, 72.59131262379309, 73.05425428575086, 72.7667288626394, 71.62160073557209, 74.22814907566195, 68.3799579066615, 65.94515446693667, 65.56669673612042, 67.76673455392161, 72.89493545409172, 74.46910812008765, 73.41097816344231, 76.14352872294765, 80.40313643793907, 73.20995669211112, 49.314402995571015, 68.91354930016303, 19.521538288362567, 0.3463453168590223, 2.382131156421477, 2.804790321857699, 0.3340150704306941, 0.27676918093235264, 0.13493682708471053, 0.5446304753422737, 2.5302045527965795, 26.456539784708333, 55.982000827789314, 8.387525773817494, 16.804067280984697, 34.71867522885723, 53.10464028389224, 3.9490006143046967, 0.2260587721942894, 0.05102960310215431, 0.04408397418897479, 0.04623786103160632, 0.01295331722846435, 0.03200961836433459, 0.06368292412991006, 0.035235643341776826, 0.0534209618795543, 0.051162124821735974, 0.03521537648573999, 0.023940722608277877, 0.05751135045542352, 0.027595902380022793, 0.027964070829893314, 0.033448827528064294, 0.14364579121672338, 0.04414623415458106, 0.05634658271446825, 0.0133685426290838, 0.06228225493443109, 0.08019547819370225, 0.0027540786663115386, 0.0446840891644599, 0.028157925548692866, 0.04147159521498027, 0.008429822759822974, 0.03552374219702136, 0.04676824668422342, 0.05743883257251113, 0.09273816080343339, 0.015259404674232488, 0.042162859331696265, 0.014392459359500679, 0.015803053224038695, 0.018320971641749628, 0.02373112286741455, 0.01887198038128836, 0.04492414281553319, 0.030052506950713938, 0.07647648904352419, 0.05195777990945405, 0.05671346988228541, 0.09745145547053508, 0.031266168338216604, 0.07324277828898161, 0.035210350948956706, 0.019447323903741858, 0.07093684597601814, 0.027806907892227176, 0.02580370862908181, 0.04508122531396728, 0.06903976712736391, 0.03233485524692843, 0.008913130394273229, 0.02312057952006017, 0.09139458048007182, 0.013055570814157686, 0.08280429102840924, 35.900265709046394, 91.39229189965033, 41.132248601605816, 48.37064543078023, 113.03367907001127, 48.16175568488337, 5.377490078249286, 1.745579139359536, 0.9517835308947872, 1.057961049579805, 0.8744948201121823, 1.9234107002135248, 2.3516504178124094, 2.4650270179394753, 1.576892216840098, 0.8021903999390141, 24.394759631926014, 114.63837562068817, 87.30522140379875, 93.85379099076795, 68.94346129509711, 84.00253080552625, 78.02400712044009, 83.54367625328803, 79.0535508432696, 85.74632244725382, 75.21970856574275, 79.0307383383474, 81.12715890330654, 86.41852255790465, 83.0816210469892, 82.44372598586544, 75.3167558485462, 83.31168374707623, 76.8927877180038, 76.6113341239191, 68.33730605340773, 68.7523869545229, 61.07776764900454, 68.120861822559, 60.17623832148891, 59.15021688707414, 54.46142735019807, 57.59117280283282, 54.368981007606756, 57.932011081326394, 59.17363735937304, 74.84574979351413, 70.21747066128638, 72.43611228081488, 66.66923184548655, 76.85906317926224, 69.67115509894587, 81.4411211013794, 56.760340275303015, 74.8312448686169, 31.54013353009378, 41.71002941746866, 86.7144496979252, 67.55956280616023, 74.30482356779038, 64.1794446206862, 65.54650437447333, 59.266766194374334, 58.686973202613096, 52.05541018516787, 56.07550228795698, 52.099634908860736, 55.95864311341317, 52.826136312177105, 57.20499976988762, 52.99080133438111, 52.697039342695675, 52.04631813110844, 52.85213770404939, 54.640322731387236, 55.21771523260302, 53.28215499078074, 51.834729794533025, 52.524164799721014, 54.37869279615341, 58.20390585930117, 64.60254676880376, 68.42694005658551, 75.5752557323825, 77.08576833048176, 74.5591578945037, 74.91059441720286, 75.46000080723917, 67.80729186150336, 66.03980125919466, 67.34423252844041, 70.30295479682185, 76.08057468168198, 77.23044103191745, 78.38112323514878, 77.88252722832465, 80.06708345105572, 75.05684391144784, 56.91202617460682, 78.17397502160843, 21.638892542931345, 0.6069389802794303, 4.431145710329856, 2.898145183440178, 0.2872463219588803, 0.21211739689592393, 0.06801792841044164, 0.9798447799778754, 5.598685770265518, 28.212669241812925, 83.94026710141091, 21.84202817178542, 20.230642018779633, 43.02892638790993, 62.30130003344629, 7.508482413907205, 0.1894629205907545, 0.2568009766119142, 0.04645519634528507, 0.016348561452281092, 0.08056941337042278, 0.037737862702699444, 0.07791211483098807, 0.014094452114565479, 0.019046479888680964, 0.06349663069892315, 0.10273115724445352, 0.04444490502318067, 0.017306964258633314, 0.0016896636553874781, 0.02140866220748473, 0.04864758676699093, 0.01941444149481193, 0.022582312737922036, 0.0017389614133149266, 0.006288819122053082, 0.05170021731887133, 0.09137434043711232, 0.04729154602354092, 0.04687949414214781, 0.015238089235349288, 0.03413297851840335, 0.10007902213762845, 0.1280868365879982, 0.17106487475816282, 0.15950915854304068, 0.2087784026779475, 0.09005489188336557, 0.14176567355471273, 0.12994957937588617, 0.17800644340534366, 0.08709491200504765, 0.10005328158337264, 0.2347926341838414, 0.17003321479405129, 0.17266098830488422, 0.132301714451563, 0.09770159083869188, 0.13033386440046374, 0.1625529484402749, 0.20406687001307167, 0.31458986923098564, 0.07947839691393799, 0.09085267286507354, 0.14835833511765928, 0.25968670724861087, 0.19287751236509895, 0.1779957488179207, 0.1249915425996146, 0.15273741626691434, 0.21889450178752023, 0.2393833547830582, 0.20647295300037632, 0.3676008859709386, 0.5162623620802357, 48.68858491220782, 101.99400348048057, 77.70896234819966, 52.79300797370173, 96.94916079121252, 70.26779467059721, 4.675680485463912, 1.7372195879297874, 0.9553688223804198, 5.156776347467977, 3.3679306459042335, 15.498037645893714, 10.711550693358145, 3.548201308135064, 2.263924647723475, 0.5931519104107734, 21.759460318473078, 118.98168671515681, 90.05636399792087, 99.42943234597483, 73.29431902977728, 87.23759189728769, 81.24100177518784, 87.15047605576055, 81.8498634522961, 90.87424093677153, 80.4785636163527, 80.85289109137751, 80.97711255473476, 89.16738233258648, 88.26942628429782, 84.60332808956024, 79.17651714817171, 85.073439844193, 80.67836915293049, 81.4415054936563, 76.10378726836174, 75.73250355259066, 67.22036407839867, 72.08063571683823, 65.20063761741885, 65.70586635220435, 58.430124636619325, 59.4473325052569, 59.23474788665772, 60.383033521713756, 62.257487158621515, 78.2106178037582, 73.98671934681555, 75.36847622163835, 70.18402068845688, 78.47845292860463, 74.36470247084095, 85.45547085423624, 60.03533109541863, 72.7962407758159, 34.62261638333721, 44.9268828668902, 88.9782456428774, 68.8824684389176, 76.5872899947628, 69.09234662209788, 69.03131454221665, 61.9754530537513, 61.85771919065907, 55.68203364649127, 59.43371011364845, 58.00648512378816, 60.06440762550601, 55.053010986697295, 59.40806565746185, 56.61227080129809, 55.42090969700968, 57.08132351598432, 58.2907824362478, 59.205094768155014, 58.39535282504175, 57.710067687496064, 55.09549025566348, 56.01783952405376, 58.71529271525722, 62.78011552749142, 69.98505453909598, 72.61083033777052, 80.21454888005411, 83.50475065169796, 78.78237385903635, 75.49258001389043, 79.57299032518941, 71.49628885330694, 71.97852073177215, 70.37763672490274, 73.03165358881797, 81.0567052902714, 81.95345324854698, 80.0281500047253, 79.95444866918749, 81.24429656613259, 82.02007862829393, 64.1022837546564, 78.01349516837828, 23.437966069867535, 0.38018829279368926, 3.275242587251048, 6.225583976314915, 1.4586620513469943, 0.9748319296106216, 0.266802039958777, 0.7760437577962876, 4.089682304090069, 44.912460311766594, 73.05703132383286, 15.644856864406218, 30.746016348561934, 50.042775369459584, 81.14916339997323, 9.510334634011793, 0.4059116253929754, 0.4353804844281366, 0.1461300917810971, 0.2227714889112019, 0.22441119286081485, 0.14307766041207698, 0.2275602432388452, 0.07941339435356279, 0.11689491254547912, 0.11099700079930407, 0.17245448164401517, 0.12573869283040687, 0.14860086323272798, 0.16036532308545806, 0.17114856220301122, 0.2667516926603933, 0.35846767766821774, 0.11245262148159166, 0.1226768539016766, 0.07179215249996032, 0.15132487270860903, 0.2386836100730204, 0.1471625484766499, 0.14601329401616128, 0.09248739724317867, 0.10169283997627998], [0.03513771815285568, 0.038089408959832885, 0.029917572054170796, 0.03767605472896849, 0.07322174917546011, 0.042562967902349855, 0.06798022156280857, 0.03255228632159772, 0.045080206417027986, 0.033957720583965706, 0.06592633983781261, 0.027999272570014003, 0.0424257040985169, 0.01881326357233188, 0.009547362137856263, 0.021686742547899488, 0.06806953975390043, 0.039429921101057724, 0.15059992370586242, 0.004878309048381785, 0.05298424196699935, 0.04353615620564069, 0.038663649315675425, 0.01036677552732609, 0.03787063723129611, 0.08535284338699234, 0.03589557063195013, 0.01052180874056273, 0.026952277440878174, 0.11498334697417675, 0.08301900249094733, 0.04514765279788164, 0.2549882900089987, 1.1293717209369907, 62.063196474506015, 69.29032433417537, 41.01114150016539, 23.35879106675425, 94.2696406764369, 40.019295677062004, 4.263118236295639, 0.9634127455853647, 0.3690003753910142, 0.31340454735102197, 0.6522779022493671, 3.392755817021093, 3.0437229717931444, 1.572831583119208, 0.29792803910470783, 0.36006172277754356, 74.44235755551246, 105.08450954191147, 78.82537872560563, 94.37907480424451, 82.01909803575086, 78.6852010603874, 79.99108360659692, 78.8957146675356, 76.27193143290859, 82.89151945421773, 86.47508313578945, 88.57981912551388, 82.00306338648643, 77.71597554606777, 83.43676813187139, 82.05298731403967, 78.5949630122031, 76.7221018575853, 71.17714128186627, 64.24265361601307, 64.93210823305192, 62.98652241306921, 64.11144248900875, 61.30135843830725, 58.111326156123994, 54.29940208312004, 56.71092625587218, 53.17951833048175, 55.250259137922725, 53.2612056116904, 66.74993853415212, 66.98803424835205, 72.99589726232713, 68.65067989595475, 72.84276793079992, 68.13534321323519, 78.72351477223059, 63.2774289192692, 76.91819683198007, 30.007169285128196, 38.61772691049884, 80.31019979907622, 63.529633398978945, 74.50669227107879, 64.14737139978718, 68.6028269798525, 60.8469714656953, 59.17261754312823, 52.002513101024014, 55.17192156084123, 51.17932527296005, 54.16464513347995, 50.11245235320061, 53.019940622391246, 51.53704935504545, 57.69942629721857, 60.57118177413941, 67.16836129465412, 64.19467910643547, 65.71220098003265, 60.922355498037035, 58.16874181070636, 55.03110454928491, 53.604511061022365, 52.455931248203406, 60.64563228238014, 64.71841358369397, 73.61916188270816, 78.11822245197912, 75.96161703909598, 74.97838866326117, 77.69591654500654, 72.1586359700849, 69.40857595013034, 67.93090927985408, 74.99027344488329, 71.42148140938052, 74.054152734818, 78.35749487723075, 83.30372918036677, 72.76117478647541, 62.2039899518413, 79.15054321289062, 23.212053237422822, 0.1465228650598757, 0.6351474408180483, 3.8488725548790352, 0.464102836746362, 0.1491325742174541, 0.06954038260324348, 0.1272385244468047, 6.446950781729914, 26.17303675220859, 74.24655283651045, 7.701222290915828, 29.679284634128695, 49.52478324213336, 48.172047984215524, 14.77521542579897, 0.19734693060238517, 0.1925170526749665, 0.042428117275478384, 0.03393264269576438, 0.031192441951603662, 0.04261660171792873, 0.048441221832387873, 0.0009694668516467867, 0.06774774452130641, 0.048786053328865, 0.010181983628670776, 0.009280798971773157, 0.04132689269740255, 0.01068428545559366, 0.017841774069013137, 0.054927898961449825, 0.01424279546500334, 0.022122527833186814, 0.023413068059110836, 0.043031465142003955, 0.08199803711425874, 0.03708851508676045, 0.061135597512005806, 0.02787127459962522, 0.027838983993616798, 0.1552168904773651, 0.047580135175057, 0.03408109904417107, 0.07135653192357672, 0.012630459048875399, 0.034168207071601384, 0.04247866758716203, 0.08012214059671087, 0.06112604439559002, 0.04223689406869873, 0.06136722036547238, 0.05582577316090465, 0.03394277037812337, 0.039273665977581855, 0.018486689866310167, 0.06536144192420668, 0.031812802715707696, 0.011149385095303579, 0.06512567070463011, 0.12691402492383796, 0.06628803292950315, 0.02971507969402498, 0.04514152409448739, 0.10609495738941817, 0.057360500082253456, 0.059703147158988064, 0.051501995898903384, 0.06932844437899129, 0.051634827884094375, 0.03220966498878214, 0.03975563487338443, 0.09229707035927043, 0.06350539474477691, 0.040739985077732035, 0.29782599619319367, 1.637162376315363, 78.51124394324519, 74.70464644893524, 27.894710148534468, 54.54748807414886, 117.94141138753584, 42.78338209275277, 7.744450732584923, 1.6439474638431304, 0.4490571457051462, 0.4163460800003621, 0.5659552375155111, 0.1628624632834427, 2.119217380400627, 2.095885406578741, 0.5420231410572606, 0.6208196354489173, 86.0803593358686, 104.77328515821888, 87.31555292683264, 95.89256840367472, 83.30826344028597, 81.05060992702361, 84.27495510347428, 80.26179775114983, 79.87538153125395, 85.66776521744268, 90.13296004264586, 86.82193048538701, 85.32751529447495, 78.97133796445786, 85.25468472511538, 85.04271199626308, 79.32006020699778, 75.52678308179303, 70.23807094943139, 67.95596538051483, 65.94965734789449, 64.48678978027837, 65.23104383099464, 64.29562914756038, 60.2848252173393, 58.83643904039937, 58.19009911629462, 55.62104079031176, 57.58864679644185, 57.43744334866924, 69.8432530126264, 69.53894768991779, 74.74215215252292, 69.54061077487084, 75.6078427837741, 70.01093433749291, 79.85170610489385, 65.20274393020138, 74.57405505641815, 30.933658615235363, 40.9861324679467, 80.42886718626946, 65.45146142282795, 76.58774498970278, 68.61133852312642, 73.30140283030849, 62.84466597341723, 61.82151179159842, 55.15702439892677, 56.578565874407374, 54.85563339725618, 57.62532880229335, 53.5895158398536, 55.85818729092998, 53.67331335621496, 59.86046006602626, 60.91316930709347, 68.84728477847192, 64.44536170651837, 65.83273149305775, 62.763378773966146, 57.833308558310236, 55.2798455761325, 56.17881359592561, 53.596701622009284, 63.39031473282845, 68.25856839456867, 75.36778588448801, 76.434215576418, 75.25157390102264, 74.48354244232178, 76.13800602574503, 75.86933935842207, 74.43936870944115, 68.09793949127197, 74.67215353442778, 74.69189090113487, 77.16391763379498, 79.9183314846408, 83.41532061176916, 75.01791046511742, 63.83267179612191, 84.88029449216782, 25.67788458639576, 0.5210132103773856, 1.5104551108614093, 4.2276889374179225, 0.21567817356797958, 0.04378823743712518, 0.18306302207131542, 0.4190059679169809, 13.40854202547381, 30.300537078611313, 98.09481451588293, 27.473618215130223, 15.732210989921326, 42.79014425892984, 61.63570519416564, 22.426294626728183, 0.12048337563511827, 0.20058221183717254, 0.055726645213942376, 0.0912451167260447, 0.07200594465698927, 0.009410241975509112, 0.0759951253571818, 0.02600799555019025, 0.017926166314751874, 0.01572150507971885, 0.015631966638348756, 0.03873800964004571, 0.08613340271216247, 0.02894020091081339, 0.03975084299341806, 0.05129943459084438, 0.02960527822705767, 0.02221539301136809, 0.06777596720043691, 0.05632247775793076, 0.019566774248115478, 0.06689851307460377, 0.06349840419246786, 0.014989219827487346, 0.04317087016158527, 0.07906591219286765, 0.049872726066819126, 0.1716680770679828, 0.09140863053260312, 0.11621284914473373, 0.1353772203888624, 0.15163169092228337, 0.19414675151628835, 0.18050035071228782, 0.17860535562278765, 0.14484128674432156, 0.30562710016965866, 0.10969068299257949, 0.16157922004499745, 0.13235183192356942, 0.16798196841151486, 0.10036423667183808, 0.13762954952976397, 0.13918944243942538, 0.18712261391262855, 0.25190461757442645, 0.09669819185810705, 0.17740374671355372, 0.14666178744406472, 0.09405397810041906, 0.1435894837542888, 0.15285845815895066, 0.14478010696268853, 0.12389852665364744, 0.09825337332703414, 0.12741784264724101, 0.22209673398925414, 0.1218050764873624, 0.1864544779903466, 0.3264217907863279, 2.7973461535669144, 98.75700473785402, 86.82441726807626, 60.86615185583792, 39.36222807053597, 115.47861791426136, 63.094175784818596, 7.361316555930722, 1.8570443194720054, 0.9747083136631597, 3.276402137933239, 2.7199396491050725, 11.943386735454684, 18.311081124890237, 2.626573020412076, 0.6704295895272686, 0.7684493749853104, 83.22515626107493, 111.21300112816596, 89.60077285766603, 101.8153787428333, 89.77727951542025, 83.78760845430436, 87.06435649625718, 85.19859483165126, 83.28399181365967, 87.50441505062966, 94.59782538875457, 92.47226161341514, 88.8291249736663, 79.10735007255309, 89.47576692027431, 90.30331642396989, 84.82201591614755, 82.41920332754813, 74.5502305799915, 71.8387274588308, 71.62034557711694, 70.36729735712852, 70.2132345015003, 69.46508945957308, 64.48566798240908, 63.804669995461744, 63.791275101323286, 61.102580562714614, 61.45025553241853, 61.39285556731686, 71.80448516722649, 72.36062234447849, 76.96821489641744, 72.97151580933603, 80.6133205659928, 75.29829717451527, 83.9870374433456, 68.26191809869582, 77.94508118783274, 34.514107934890255, 43.94557253006966, 82.13502760856383, 70.26966956353957, 80.7418409470589, 74.7949472550423, 78.28117339841782, 69.30883792138869, 66.32860537498229, 59.076680291083555, 61.77718508628107, 59.23954102300829, 59.821004944462935, 56.44347552330264, 60.576880977999785, 58.231182021479455, 65.01880045860045, 66.18420723945864, 74.10213116676577, 72.32832554847964, 73.32746305773335, 67.28532637319258, 64.43954483155282, 60.86578315304172, 60.011553687434045, 58.960868389375754, 68.2544812848491, 73.53502704251197, 80.74948956889492, 81.89930885068833, 76.5907024568127, 80.00944814374371, 80.5036981644169, 79.26532745361328, 76.6366647904919, 76.39982423474713, 82.79520957700669, 77.14843996109502, 78.76906133467152, 83.58446105833977, 86.29765079867455, 80.73632609459662, 71.93851255601453, 85.71699096310525, 27.02247896502095, 0.47272417574159564, 1.0800736565743725, 7.992825017821405, 1.574909826440196, 0.21912929241455373, 0.2887599891231906, 0.5010309100391404, 10.211954482140081, 43.49665726384809, 93.9377297124555, 14.583258551935996, 45.63061098898611, 67.41122661098358, 76.49537317214474, 32.97515423067155, 0.28056680134707884, 0.3178569890799061, 0.2292882771261277, 0.2618645113562384, 0.09807080691379887, 0.19807411658187069, 0.20504513364886084, 0.09781701730624323, 0.12723080994140717, 0.25226791178987873, 0.19433294152540548, 0.07700504374600227, 0.19972848345435437, 0.08506592047671158, 0.13948613297074072, 0.14661738498797341, 0.07216059482626377, 0.18058656624728636, 0.12217561023369913, 0.14771540348808612, 0.20501683436093793, 0.12858123909081184, 0.20482313669016286, 0.12521665753616443, 0.18722220534278503, 0.24557469352599115, 0.13704720013324292], [0.056329698136617104, 0.080570524197913, 0.04173983324078783, 0.06326237633343666, 0.06751968014624811, 0.056022784161952235, 0.049572726035670894, 0.03460229930257605, 0.024637914330307997, 0.0165553477352425, 0.12636692323271306, 0.04537507365908354, 0.01586275062553825, 0.06395848978671335, 0.013709703606793718, 0.04166482557212153, 0.04723898473105604, 0.04353287734932477, 0.0195004329490926, 0.036549005326965166, 0.06314143786327013, 0.06360138939212888, 0.018747282334633412, 0.06488386271221024, 0.11347534119962685, 0.05845835387346245, 0.05619877754079719, 0.030325121253788955, 0.06457866860493537, 0.04254306110763743, 0.06285053895666234, 0.27755840471194637, 0.12136251515438481, 0.4667842976989285, 12.290696924732579, 79.80462197334536, 77.85825560169836, 41.41084278783491, 26.13739417445275, 104.98649735604565, 37.93963539984919, 6.608266099806755, 0.49319147102294436, 0.39318212458202917, 0.4747792832072704, 0.5576613244991149, 2.000693895163075, 3.8855673084335947, 0.13701067306101322, 0.3771493445721365, 5.101831295797902, 94.70677314266082, 101.19106292724611, 81.46219207394509, 79.9896558638542, 89.03184875365227, 85.73232743047899, 89.00692601357737, 91.53880027032669, 86.82091851388255, 83.40855844559209, 85.4769262190788, 85.55993141666536, 87.27844730500253, 85.84700184483683, 75.98869708276565, 77.88462177399667, 71.95627304815477, 76.17907324144917, 67.39921631351595, 67.45579258088144, 65.47885133374122, 64.8255648920613, 59.0614144263729, 59.749641341547814, 55.88101156296269, 58.53485976496051, 52.28878336568033, 57.71490789228871, 53.550778512031805, 66.44695112782141, 71.24913246400895, 73.59256036819951, 70.0224425715785, 76.4469083662956, 67.54230437740203, 76.90577076327416, 60.76504491990613, 83.57413738004624, 33.53951661817489, 28.387342191511586, 77.39447455252372, 63.378394649874785, 78.54896145482218, 66.43605478348272, 73.6121722190611, 65.57575741121846, 67.8423656955842, 57.11567955632364, 57.25507666987758, 53.57276731921781, 55.90580094245173, 51.849936823691095, 60.169134909106845, 62.19294063506588, 68.4024566219699, 72.00576551498906, 74.99593734741211, 70.92633708830803, 69.42669730032645, 68.75578372709214, 69.92808603471326, 66.49208191902407, 61.33086250674341, 56.25588816981162, 58.62947125588694, 67.42530007516184, 76.18052451841294, 78.46062183380127, 82.46617763273179, 75.00161693942162, 78.38329622822424, 75.10735619452693, 76.6217754733178, 74.87049994930145, 71.17168918732675, 73.9846718695856, 79.1714886696108, 79.9361547347038, 78.20107075475877, 80.95092681146438, 71.8331890721475, 13.636344459749038, 0.7281413217706065, 0.19323119983798076, 0.8853369254258372, 0.259647207755235, 0.2892090085773699, 0.15478302424232807, 0.1524899392238548, 11.964887207554234, 25.382314382060883, 81.66035805979084, 14.927265124936259, 25.952032766034527, 58.030721449082904, 54.42343919507919, 24.85076850460422, 0.17714693871957643, 0.07594768153203112, 0.015994629788873418, 0.059075035500310125, 0.004512462802531739, 0.04026645080997579, 0.03377129308759205, 0.05798633262935666, 0.06975963696717255, 0.07721215561633149, 0.05359500939507158, 0.05026870925400046, 0.08010083569153663, 0.05552565438612815, 0.004683486664772875, 0.01281110162381083, 0.07806596060794208, 0.02009975502357608, 0.010543971664212164, 0.11161522609331917, 0.07700305191739913, 0.026217834693529916, 0.153398979154806, 0.08483577234249923, 0.019504146560305552, 0.005760665179320401, 0.06404342595487833, 0.04582504306228892, 0.02867255851836695, 0.040956558133926124, 0.013749378342782299, 0.050946084196649255, 0.03326364109412797, 0.03982162185674233, 0.07504748991660534, 0.07899812107244808, 0.0397399147491782, 0.07716818983035703, 0.08147404829580938, 0.021448537083943526, 0.05749019110695489, 0.052547158162680366, 0.021519660686833725, 0.03721549416020994, 0.019148748796132785, 0.10305652244677467, 0.03775659738288772, 0.010539626030461683, 0.038896019104868174, 0.06090230075642467, 0.07587470399636416, 0.022947977995499972, 0.03545820337509917, 0.10891118086874486, 0.10365876714668928, 0.107449178674048, 0.04906884319479427, 0.04781612472969198, 0.017355716178914713, 0.24524037275583516, 0.10477965337134178, 0.5251484304185837, 18.613470369769683, 92.73915536942022, 65.10745386923513, 19.571634800203388, 64.41359050812261, 123.11437437611242, 41.30406802700412, 11.52806951153663, 0.651797779625462, 0.012210749161069193, 0.5920258837361491, 0.3028689691376302, 0.9260540695921068, 0.8176336293258976, 0.2795739820407283, 0.4787547585944976, 9.094775203735598, 106.90207312183996, 95.94913682629986, 82.97369310932775, 84.34306313914638, 95.46165681654408, 89.1892142449656, 92.90517360933366, 93.68527027868456, 87.61923851505404, 81.6059704749815, 87.79813781861337, 87.22891561446652, 85.37996522841915, 84.94202475393973, 79.12245904245685, 81.0029923531317, 74.23258135395666, 77.094036686805, 67.86197754644579, 71.47535908606746, 66.13637785757741, 68.79547026849562, 60.63804249609671, 62.184338877277995, 57.54876413652974, 60.994950725186264, 53.86427787042434, 59.03553070560579, 55.269427760954834, 69.64817000973609, 73.37364504414221, 77.61404099002962, 71.73256458774691, 78.67889388915032, 71.57519125169324, 80.59170046160298, 63.586609748102006, 86.92876800414055, 34.982038851707216, 32.20099406857645, 82.66118218821865, 68.17564164438556, 79.92292065774241, 68.86502173639113, 74.46158501409715, 70.25398792759066, 71.3379898378926, 57.242787884127715, 59.32692750807732, 56.01158726599909, 56.94147925223074, 53.86968289652179, 59.76382070972074, 64.55769446588332, 68.82793964878206, 73.00818997044718, 72.43702227069487, 73.54833172213647, 72.66038556252757, 72.45285295671033, 72.30737224701913, 64.80423896543442, 61.55119380643291, 57.55193733399915, 60.882433614423206, 68.13426063906762, 75.45864366715955, 79.76535904792048, 81.33544460419687, 75.93125789396225, 80.79949978859194, 73.73414224193942, 74.92090240601571, 77.57742174210088, 75.30360806372859, 75.54985446314659, 80.55296313378119, 80.1882533104189, 79.03230728641634, 80.33297308029668, 82.37244867509412, 16.599615696937807, 0.6589570857824818, 0.5623689654373354, 0.46546126385369613, 0.4028343421316916, 0.29650054151012056, 0.17440195375632855, 0.19243790047062984, 24.417374057154504, 26.537503388620195, 96.40187248106926, 39.778026765392674, 8.814190414644058, 47.05098359815536, 63.79128294606363, 38.13764841325822, 0.3352344066144959, 0.04322975934032471, 0.03900697161894172, 0.07650897883239292, 0.08706401567906143, 0.017061965510008797, 0.059371553661842505, 0.05835687403657264, 0.03439626761622006, 0.024183834865388852, 0.06034668016758177, 0.02556214195435807, 0.04856041362208705, 0.10442903025015708, 0.040720920979736314, 0.019688417519172354, 0.018411707095501405, 0.026319266649924462, 0.033869448102890484, 0.13387884433952071, 0.0504701137692938, 0.05501301516027701, 0.07933101691906491, 0.019801078409317042, 0.008079369135591532, 0.008405650770592113, 0.02873879064986062, 0.02312756241148999, 0.17635006938249836, 0.17459146858703706, 0.262822151905106, 0.12022823771281589, 0.14017452425774068, 0.2126168709007963, 0.17711548314940545, 0.14432201702748576, 0.12013004822356087, 0.1379971491593507, 0.22871666828230505, 0.10510003900215512, 0.1871928335317681, 0.3147009826235233, 0.09697146308157714, 0.27243508446601133, 0.08903306848820179, 0.24643819719072313, 0.08252193400215718, 0.09460236681925674, 0.1626194908373779, 0.17830049859419947, 0.16179776960803618, 0.1944192643127134, 0.219571371112139, 0.14741290601030474, 0.21330281070643858, 0.3490380852693512, 0.20391348388887223, 0.14092711371279534, 0.11648663364711309, 0.6451973499309632, 0.2946436056686986, 0.8391401688418082, 25.43845134396707, 112.2269573519307, 96.07203252853887, 65.4024592522652, 44.18133443401706, 126.63601952214395, 61.40960801032282, 10.886532529707878, 0.6373082377737569, 1.0419344902038574, 1.084663074824118, 1.684846753074277, 4.991460702111644, 13.649854083215038, 0.21194467471251566, 0.6510243372571084, 7.255887658365312, 101.29236205931633, 106.09991704263996, 85.9870304599885, 85.48885022440265, 99.59372474301247, 93.59736996312296, 97.16062361194243, 98.44109704417568, 95.13075782406716, 83.87557937252907, 90.14150296488117, 90.85014189443281, 91.54159299788937, 89.34948229020642, 83.34104661018618, 84.87263802559146, 79.18309888532086, 83.65262400719428, 74.81157810457292, 78.61200963297199, 71.11698781290363, 72.84509781868228, 64.74526220752348, 67.0238454880253, 61.87303212381179, 65.13161959186678, 56.84353766902801, 62.211760167152654, 60.08144247916437, 72.10364434026903, 78.7682847053774, 79.60336515980383, 76.25974070641303, 79.97052254215365, 74.4520850335398, 84.68379943601548, 66.58933316507648, 87.70512273234706, 40.62023024405203, 36.176706514050885, 79.7644333685598, 69.64459280813895, 83.31628076491818, 74.30933429348853, 81.05515203168316, 74.54491969077819, 73.39899924493605, 63.68144481412826, 63.096207572567856, 59.89585161209107, 62.709450106466974, 57.714488198680264, 65.67098863663213, 69.64228645447763, 76.20121109870173, 80.13821171176049, 79.24901039369645, 78.6449340081984, 76.02328454294513, 78.32811632464009, 77.03864497523155, 72.14620990137901, 65.99365849648753, 64.0091549196551, 65.4551798297513, 73.16200963912472, 82.89011524569604, 86.5003824234009, 86.43969551209481, 77.3526777759675, 84.76171339711836, 81.22397868863999, 80.11442645903557, 79.93716670620827, 77.1189437373992, 80.64877094761019, 83.57056017844909, 84.6953861175045, 84.48710041661417, 84.28996209175357, 78.52931038025888, 16.518051970389582, 0.5613683320341573, 0.6274991254172018, 1.6501938383425436, 1.3775796731633525, 1.1757145245229046, 0.22947932413268476, 0.2751401409266457, 19.455271805486372, 42.1463107293652, 98.34212779998781, 24.218456937420754, 37.49403453642322, 83.80103080503403, 73.58437045927971, 54.98275349217077, 0.361371947632682, 0.1472128804532751, 0.08497158440971568, 0.21555042074572658, 0.1504703629161081, 0.16157935794082381, 0.10736069551879361, 0.1352006984093497, 0.2324010609018226, 0.147626108279632, 0.10612226842391877, 0.13584491706663562, 0.10297346319402419, 0.25011961738909444, 0.09592886338190687, 0.1059561345966593, 0.08683851003767022, 0.18176689323398376, 0.12065613612292275, 0.2136373306594549, 0.2537451438125103, 0.14245483092963696, 0.2297714181364544, 0.09910687188347501, 0.07600005130253493, 0.15305918851687064, 0.1141543708921921, 0.1872488498807915], [0.10427728355411561, 0.03962525053911152, 0.03601297743678574, 0.07720428789334913, 0.06657897014050715, 0.05746500979688379, 0.04456424620002509, 0.0585936296791319, 0.03360908929138415, 0.018985384376719594, 0.027609067601001555, 0.04820553871292261, 0.09729354942758238, 0.008955736374182087, 0.015892471006560712, 0.10212638445438878, 0.05359313631009671, 0.04859638528057164, 0.043139866583289645, 0.038753917455793395, 0.01945146077853297, 0.025296146650948835, 0.05004298527755084, 0.039674107796482505, 0.037391832278620814, 0.023652233048191956, 0.11200844370309385, 0.023171899750107722, 0.011875663260598818, 0.03512103275786485, 0.10558785314881995, 0.060304499366470886, 0.16874886838899505, 0.11533393179096522, 0.4018500417230591, 32.93903704612486, 75.79513595950219, 71.94012072778517, 34.02454906894315, 33.42278688184677, 99.90681617490708, 45.281229788257235, 10.245510358964244, 0.3143131276292186, 0.3635424279397534, 0.015426282564388409, 0.23542223588353206, 0.9865701126475489, 1.761798752892402, 0.43862652153738085, 0.3186193691386331, 3.017724276550355, 72.21277252320321, 108.22436686485045, 95.39832622774186, 86.25764262291693, 82.04698608767602, 84.72069324985628, 82.8969950829783, 85.82997091354864, 97.86781910927066, 92.73281681922175, 84.24157573330788, 81.09206153500466, 87.26723717105004, 86.57871215574204, 77.69776005898753, 76.54935283045616, 72.86697679950346, 66.69527638343074, 64.44274156324326, 67.36352274494787, 63.708858259262584, 61.46815722988498, 59.46432813521355, 58.47755785911315, 60.57753209144839, 55.46916269486951, 55.00931970534786, 51.579944395249896, 56.185183525085456, 67.20844791781518, 75.26303506666615, 69.0311654921501, 76.72629094892933, 72.08612703507947, 74.15832304185437, 67.34511898409936, 77.4811589333319, 35.32884305523288, 36.97128849644815, 72.49730125550302, 62.85719794611778, 75.62952564608666, 65.19889216269216, 74.06989712868968, 65.52381738539665, 68.78316971563524, 62.49714005377985, 56.98566475222188, 51.22096907707953, 53.56915481628911, 55.21456556935465, 66.6157542505572, 69.78258179080102, 71.4652079920615, 68.9592606021512, 73.17035644285141, 67.74763261118244, 70.64446772298506, 69.39371801191761, 74.15651090683477, 72.55394028079125, 73.30665096159905, 68.54770198945077, 65.84897795031148, 65.08553174234206, 76.855666406693, 80.54158826028147, 82.44772680344121, 82.56176579383113, 78.47886085510254, 78.74325998367803, 75.48690042188092, 75.60625030148414, 79.9868082231091, 74.41546578561106, 69.5408147381198, 84.24010092212309, 79.63013925860005, 33.09808131187193, 0.6739738799871937, 0.205087544276349, 0.5867738300754178, 0.0649657728330743, 0.5160424642024503, 0.04574613600608803, 0.6260025573353614, 1.5189160310452985, 16.80032926221048, 28.394806461949504, 94.20957349961805, 22.138873146426295, 31.06491484949666, 62.81855867755029, 53.98842873111848, 38.300230656900716, 0.43390588774796457, 0.0314469114621921, 0.07223915714289873, 0.015805882961309005, 0.04598011074948215, 0.018079426034443805, 0.032583420134840474, 0.037498548326473084, 0.03423735799808656, 0.009151944898128992, 0.08660239407852774, 0.007550047866384229, 0.06988123044251435, 0.03409496523560055, 0.07142863611900999, 0.041199787219445554, 0.03941408989410247, 0.03260837161853429, 0.06636762946483589, 0.08113925255114034, 0.07231176695636204, 0.03377124329187697, 0.054011462451589685, 0.036703222656562444, 0.07618215806301563, 0.14255463686441222, 0.05017045847771149, 0.14989314630867975, 0.0047354015705716465, 0.046742149899082805, 0.011067619573535218, 0.10168686449047058, 0.08662985066973394, 0.06577548946464254, 0.039488856245072625, 0.030261158657770966, 0.04643173490260397, 0.06404716446394883, 0.08964800726502173, 0.042323875691621535, 0.09126963153962167, 0.06746938647401911, 0.04592008393017515, 0.04203740094277648, 0.03323954379846973, 0.03132583892663881, 0.02978937681614151, 0.0567509277513431, 0.02887361446365474, 0.03450923494153446, 0.03695504341815268, 0.09866216550430945, 0.02402388336767833, 0.03984352814093713, 0.014275597434701219, 0.07087490776734007, 0.033897310720696565, 0.05253170233880801, 0.05135111105177672, 0.0734286388802913, 0.19104427928405424, 0.20526477105675206, 0.08376256743025395, 0.269711917686847, 45.95214728386172, 88.58679309968026, 54.25526757394114, 15.968264129854019, 68.92562235555341, 123.10274062618133, 46.726007384638635, 17.03928593666323, 0.21410757074913672, 0.4324165515361294, 0.34738866732485835, 0.3452238560684266, 1.12169784884299, 0.7858198977285816, 0.24977906066323483, 0.5802047180552637, 5.713668090681876, 89.20968901726508, 115.01158914258404, 98.95899895698794, 87.40560270124867, 85.84948078278573, 83.95031621379238, 85.50333945981919, 91.02622493620842, 98.57270040819722, 88.84589702852311, 83.66485395739156, 83.53572168657857, 88.64924507756388, 86.69029574240409, 79.1083698887979, 76.82651535157235, 73.73796263048726, 69.4475172412011, 67.51334159604966, 67.64738467431837, 67.66982063170403, 65.3552496048712, 61.156277810373616, 60.393733747543834, 62.27129782399824, 57.56480663053451, 55.998223750822014, 54.402744770050056, 60.259184683522875, 70.3511764157203, 75.70717288601783, 73.83240545949629, 79.9310713429605, 72.8878124298588, 76.73973683388003, 68.38340174767279, 77.49691117194392, 36.87306450259301, 37.506080135222405, 74.92236152771981, 63.69012894168977, 80.28173908110588, 71.7747300670993, 78.37796964953023, 67.1069997356784, 74.49125382208055, 66.21330338139688, 60.71068871405817, 56.13658928102063, 56.82014857569049, 56.50487630598007, 67.54525399977162, 71.50076035530337, 76.12286567687988, 73.62845790001654, 78.93806057591593, 70.08712245571998, 70.26710433344688, 71.30790525867094, 76.01353353069675, 73.91527729649698, 74.47826293206985, 68.01609531525644, 64.35926568123602, 65.80753418707079, 77.64429030879852, 77.04950994060886, 81.50927620549356, 77.97637385706749, 76.09504038287749, 81.27286711046773, 80.31453009574645, 76.23033861960135, 81.4179712726224, 80.48945211595105, 70.86007256661692, 83.34440415905368, 84.56038598091372, 40.92847754878383, 1.374474504301625, 0.471186392129429, 0.30265265655133033, 0.018772770079874226, 0.4352287990191291, 0.4170592159273163, 0.7116891239439288, 2.6860712084078022, 32.08291895927922, 24.510483280304943, 109.45640687019595, 52.76495125985915, 9.723676270054234, 39.80135310080744, 60.018253095688365, 48.56830150850358, 0.6459086472468992, 0.03698086058120093, 0.09104344407997786, 0.047184309035900145, 0.05589728746863623, 0.04930880491531665, 0.08240019497010978, 0.062326684203599735, 0.023470758310248776, 0.006844200308419645, 0.07548630507963319, 0.04242875312845554, 0.09096123518482332, 0.040801582377283804, 0.05599685974659459, 0.07211692015370054, 0.08830748363247803, 0.019412171959336248, 0.015580315075273958, 0.03542086424966974, 0.06871364349799772, 0.034834029408352035, 0.027096250259708014, 0.05672210752363167, 0.013082224928263216, 0.1608354559228305, 0.04871846905218498, 0.10956948022207907, 0.023461080704545303, 0.10968991690465521, 0.10415205882201273, 0.21385051760702364, 0.17278576870599102, 0.10419007210481553, 0.18169904848740948, 0.19644408066186214, 0.11884266044944526, 0.28193059106988294, 0.18982460602156578, 0.1291557743905052, 0.20530344317516974, 0.2335225216924183, 0.152676573563968, 0.1965983094827783, 0.12972955892403282, 0.11777204491438405, 0.2148288272080883, 0.13554701611639994, 0.16398180967136738, 0.07815560821684138, 0.20900248339579952, 0.21925523726930543, 0.19876215546842546, 0.20493351463829318, 0.07813645601873437, 0.17587651979298363, 0.06814846979273904, 0.14313605163366566, 0.13551827249748094, 0.3456084322064154, 0.3388327215948413, 0.2963794383310503, 0.23699608691517385, 0.38312930433500203, 57.82691117255919, 101.79724170315652, 96.31757290132585, 51.985843027791674, 48.55858971995693, 114.9135063540551, 68.20131747953354, 17.223968775041644, 0.338406071908051, 0.4871275480235777, 0.37710662750947865, 0.888303401729753, 4.121465269596347, 6.012260971530792, 0.5177382151446035, 0.6205186548252261, 5.155511383087405, 80.04374534853044, 118.57535269952591, 101.54791232078307, 93.22611762631325, 87.46364593505861, 88.26108732531148, 86.91292947338474, 89.9158803878292, 101.40860542174309, 90.72464958313974, 85.05556952568793, 84.36265930052727, 90.61417994960662, 91.98384807955836, 83.85525365029612, 81.90121512259208, 80.84816071294969, 75.20430934044623, 71.31793868157172, 75.54626157206874, 70.51969712780368, 71.11196717908307, 66.98977578070857, 67.33057483550041, 68.86965013319447, 66.41444252383324, 62.375209254603234, 59.51397357448455, 63.399967685822524, 73.41428864386775, 79.22579780701669, 79.97250726146083, 84.18302259137555, 78.18653445090018, 77.67087613382648, 73.43550082175963, 79.48089307354343, 42.527769073363274, 47.60337098952263, 78.09716716889413, 68.35231304168701, 83.30408219368228, 77.05278904207292, 83.65620120879143, 72.2452340587493, 79.29934224774762, 71.99286091712214, 63.78270864486695, 60.17276702388641, 60.58783615789106, 61.30204877545757, 75.34365546318793, 75.01273293648997, 80.19157163558468, 76.62825522884246, 82.40460426576676, 75.25925390182003, 75.01419205819407, 74.73034581830426, 82.94933519055768, 79.44101041363132, 82.05709795798026, 74.96363270667293, 71.38044557263775, 72.55135936121788, 82.23835852838333, 81.51745042493268, 87.20023524376654, 84.83708566234958, 79.92033973816903, 82.16745776514854, 82.88212145528486, 84.65927677769815, 87.32194639021351, 82.91205698443999, 74.85992523931688, 89.39946897568242, 85.27779533017068, 35.535140114445845, 1.291800746994634, 0.4005357412801635, 0.8528392305297237, 0.3952129623822628, 2.31600514342708, 0.9740104994946911, 1.011594037615484, 2.452803441593724, 27.526560406531058, 46.417061898016165, 110.91613261930405, 34.09053510235202, 42.84602234440465, 90.74129612215104, 70.20133403039748, 68.18234889738022, 1.5074886958445273, 0.09425692245244019, 0.19618046980711723, 0.14196488705854263, 0.11667923581215645, 0.13539280261724226, 0.1606460330226729, 0.16725487436258024, 0.0924442358495247, 0.10319062613791997, 0.23735234844348124, 0.07310273741642315, 0.12219992586441579, 0.13457098945734963, 0.24056426399657804, 0.17087719853847258, 0.23391661264242666, 0.09894363386856933, 0.17431985977436268, 0.15287934171576656, 0.17972909935539771, 0.17924234241006837, 0.15219429057211648, 0.20950854575682074, 0.16646644731442775, 0.25592826457033235, 0.13147231702121998, 0.271942459287182, 0.11377925594006816], [0.030895437324239366, 0.09196214437965425, 0.04001559914960977, 0.028845006825342297, 0.09165141145668684, 0.03538226107916525, 0.037480782747509024, 0.04698106974002816, 0.09799862610957316, 0.012318777134491792, 0.010800842860443218, 0.013158488023515432, 0.11434076774504878, 0.07550808495932049, 0.019407362842391578, 0.0561429756963926, 0.01613806538854636, 0.040063111922673644, 0.09951405527610933, 0.06296869269722412, 0.056636133306329293, 0.06746724142783111, 0.03359584746161296, 0.018061941992791913, 0.10679801159928884, 0.038575545373943546, 0.04863268635686367, 0.04056995952381723, 0.06391543947580842, 0.016946071728823647, 0.025905694084001646, 0.07120936643332243, 0.027681867021226117, 0.04874745781923975, 0.041563311261275125, 0.25438419903718656, 53.10766050892492, 78.11729677261846, 67.4794444730205, 43.47097358395977, 23.001604349382465, 80.00388622283936, 65.78106995551818, 22.141328550154164, 6.508701145648957, 0.17154433854645298, 0.24976988292990193, 0.24093492797786192, 0.5728247172890172, 0.3227638128784395, 0.29487235952288876, 0.1531761241776328, 0.028881629658562523, 17.261415643076745, 52.847062157046416, 77.58809058896958, 81.08005908227737, 99.09024930769398, 103.20454105254143, 92.38303553673529, 81.91617504242929, 83.59521619735226, 90.9492366544662, 89.30071153948384, 90.10073384931012, 81.7887293907904, 81.82296383765437, 75.34443209248205, 73.30799241219798, 70.38642283408873, 70.64942559888287, 68.63974432791434, 66.21343674198275, 61.467411979552246, 60.973820917068, 66.04644575426656, 66.29918759868991, 61.913722791979396, 59.11653941677463, 56.593235538851836, 53.91250341169296, 65.12791687442412, 74.4066639869444, 71.0376617985387, 74.97552533303538, 71.10089825045678, 76.21875193811233, 70.05825381125175, 79.90355199383151, 40.03762883524741, 32.93895075398107, 66.19856311428931, 62.986208623455425, 70.53976397360526, 71.49070339818155, 72.10322072429042, 74.11923270071708, 71.2498777143417, 69.76398975618424, 62.480356231812515, 55.49920805038945, 54.55340300836871, 59.78478970066194, 71.99861111179476, 72.65337236465948, 74.45926297095515, 74.23804129323652, 74.91101803318148, 73.89805024670017, 72.71500064480689, 72.55202616414716, 73.25678194722822, 72.01467714002057, 74.73054193681287, 74.36995060213151, 70.79572216156991, 71.50638503413047, 74.26736493264475, 83.9317398686563, 85.77467333885932, 86.06408934439384, 80.79195314838041, 80.53093510289347, 87.14970727120676, 83.38981736090876, 69.68583260813068, 76.43545504539244, 83.61967609774682, 39.07150983810425, 1.511150596122588, 0.9370400155744246, 0.16072587470614141, 0.20114586868834114, 0.34369597031224164, 0.0827260734513402, 0.02426716799457227, 0.3438272471389463, 6.961142622655438, 20.994811904045847, 36.03797228105607, 89.24289580314391, 18.595392165645478, 23.53272072730526, 62.80790552016228, 54.25238070949432, 60.708135251075994, 1.9504281085345054, 0.12888586629302273, 0.0399702352531735, 0.02953592237205275, 0.0595639834571029, 0.12020712432962273, 0.009853546413773251, 0.030551272324256362, 0.004095377723476098, 0.09958228306664575, 0.08911351538113049, 0.01803839244999953, 0.0590656164492811, 0.054245452516742294, 0.07034095214499582, 0.017536185426457275, 0.04333988447944003, 0.07450362111652091, 0.056843045993798205, 0.06679309937622278, 0.12916125958004307, 0.055689076262135664, 0.1643225042930534, 0.03949803780884512, 0.059346912443758025, 0.02977280058867989, 0.014489161680572698, 0.08458220490044163, 0.01892853490707855, 0.051037964951847835, 0.017225102018264514, 0.07712303660809994, 0.009829161835143404, 0.023302684365321073, 0.017652671010563933, 0.08590811923626931, 0.08463268243377248, 0.09437047200457704, 0.06152787283363362, 0.04152488812143284, 0.07857891009940256, 0.021116282835963274, 0.03985818340292862, 0.019982782973637505, 0.01633393874902639, 0.06099413554634779, 0.024613162029474497, 0.03495641961513508, 0.046104209332336346, 0.06962436882238235, 0.10220818732294346, 0.07010075293721692, 0.04528279836860396, 0.028272739145904783, 0.11956201701034462, 0.02111987387310834, 0.01876534860310776, 0.03251312007646888, 0.07142177963208768, 0.017673271114847833, 0.019160837663577932, 0.08210332823857185, 0.021832569299506086, 0.030447270142875855, 0.009721626073212154, 0.317769808274123, 68.57380928531771, 83.9515164590651, 50.549251417959894, 27.47611676492999, 58.08814102603544, 114.195524338753, 64.04948080739668, 32.47092766146506, 7.888348275615324, 0.37834952855783127, 0.08738261632501118, 0.5472246329149892, 0.7601843894489351, 0.3851689061810894, 0.3913145860837352, 0.2430222111363565, 0.4001538311281512, 24.923310779756118, 66.56951735096594, 94.35751745777746, 95.32529953987368, 106.82225288883333, 101.99871032468735, 87.07463310610864, 79.94145777917679, 86.82806507233651, 88.9560293382214, 87.27589776439052, 87.72908841409992, 82.4718572247413, 82.53332861008184, 81.64836345180389, 78.39189406364196, 73.68919972450503, 71.50692632121425, 69.45733885611259, 68.14514913866597, 60.89449882507325, 62.86516427993775, 64.64169202312347, 67.17939099957867, 62.5020783178268, 59.85162296602803, 60.34792830867153, 58.569098134194654, 69.35305087797104, 77.98665046691895, 73.0567410684401, 78.21306536274572, 76.6868789734379, 79.8795392436366, 73.29187147078976, 83.26595675560736, 45.34558019330425, 40.2689153148282, 70.26952835821336, 67.10568966404085, 72.92142714223554, 74.55460794510381, 76.81656822081536, 76.29989008749686, 74.34968763782133, 71.32592462724256, 63.44686354360273, 58.93903647699664, 57.4151054505379, 62.21266231229229, 73.79591172741306, 74.82554174238636, 75.64615649561729, 75.33216291858305, 75.20700793112479, 75.48191901176207, 75.94373887585056, 75.28536904242732, 75.51262332547095, 73.2389743866459, 76.67333895160307, 74.94873554475846, 74.66484223642658, 69.3494579868932, 70.27818895155384, 82.73821753840294, 83.6206017771075, 85.0349300138412, 77.21839935548844, 77.71406927416402, 81.13960850623347, 82.81511168326102, 72.53264181075558, 75.27418244269587, 89.22541772165607, 51.72466416512766, 4.141986620041632, 1.119085305160092, 0.05864726349471077, 0.5027022993853015, 0.2727185676415121, 0.4229771532118321, 0.03321640794315646, 0.6046399197751476, 12.096351327434665, 41.260290453510905, 29.63002358713458, 110.17423199069117, 48.4218833523412, 8.406501220118615, 46.84137605851697, 57.21866530756797, 73.78379944832095, 3.834006281629686, 0.18481132664507438, 0.16472653906431892, 0.015194560119491673, 0.047646091514897924, 0.031108335073616718, 0.029753163839960774, 0.03064646066406802, 0.024724369267782858, 0.039026165951884566, 0.02404212009071583, 0.010971446810740857, 0.013956725785148241, 0.034213570968037656, 0.025779668790017887, 0.07745284512038193, 0.007109397922777721, 0.05399087000818503, 0.05845801296433615, 0.009324779121896193, 0.13655376290121388, 0.06599567845583924, 0.05352154156313308, 0.03885571138873216, 0.026957354688596342, 0.04812396567074522, 0.03822614799343771, 0.06602818356646646, 0.025457084486861865, 0.08906285398669782, 0.0874176801693055, 0.19509441760038176, 0.13291801686488813, 0.16792587545369903, 0.19694479572917187, 0.18031262852732213, 0.2124179944756531, 0.17273240302118564, 0.17522295486302147, 0.08193133383869164, 0.17130515057473414, 0.08696641607750809, 0.13464350734026204, 0.13196754689899184, 0.13639312958525074, 0.15129383082591719, 0.056549883297374176, 0.15068080726890795, 0.1793477101431739, 0.11798555361888102, 0.13958221571820398, 0.14318970843188225, 0.12949579485481785, 0.16189877063997332, 0.2039397147393996, 0.1294261268189838, 0.10736105558011802, 0.1719193385853883, 0.17755149443063045, 0.11433915129952854, 0.23345155130711295, 0.19440757381098886, 0.10950702873449172, 0.19476362083467746, 0.08778393148414551, 0.7325417308076736, 83.97036737011325, 99.20362933989495, 92.9887750071864, 58.04955667065036, 36.858488975032685, 97.50127361666773, 89.84626616201093, 37.86143510572372, 8.90601113919289, 0.2718861365029889, 0.3046515944503969, 0.6476467475295067, 2.968022453208124, 0.8664866885350597, 0.5758062702032828, 0.34766295744526776, 0.3692569535586142, 21.05928978612346, 63.31570732978083, 95.53004726286858, 97.45163994450724, 110.23325581704418, 109.45937218204622, 94.92504519800987, 79.98760838662425, 84.33170395512735, 91.4195837513093, 96.68286323547365, 92.19802518044749, 86.87573755941084, 87.00064935991841, 83.64998032969814, 83.33990127809587, 79.26945378703456, 76.62722756785732, 74.65698180660125, 73.03535630626064, 66.31583413770123, 68.73417931218302, 71.42621178780833, 73.11071288201117, 69.04629015153455, 64.4438398268915, 65.58295888285484, 62.83149073200842, 74.04224441897485, 82.3019636830976, 78.258392272457, 82.57961257811516, 80.08733072588521, 83.44811162640973, 75.78586347641485, 83.28649428582962, 52.17386576437181, 45.95188448506017, 71.81744467827582, 71.0708450501965, 75.34731111218854, 78.56450973018524, 79.96336029421899, 81.80911002620574, 77.11218157122212, 77.9553734871649, 68.38782618122717, 63.59321894184236, 60.69669369728335, 65.72552134913784, 77.3117752998106, 80.08413791656494, 83.4403217992475, 81.54058456420898, 80.68725724374094, 80.51330012659874, 80.26087207178917, 82.28680764475178, 81.5846327812441, 80.64578994627922, 82.54884550648352, 82.25725650787354, 80.29007804009223, 75.51595734011742, 77.41388244013633, 90.54504425294938, 91.45338673745432, 90.2153298162645, 81.8582102560228, 81.38481155518564, 86.67845802922403, 84.77533971109699, 74.02815526531589, 82.23446753717239, 93.69524878840294, 47.1568875928079, 2.822056595356234, 0.9418941938108014, 0.20173017926994832, 0.7446709864081875, 0.4127601756443901, 1.446441661927008, 0.1699234190727434, 0.7359224461740064, 10.176820831914103, 35.27764435737364, 53.00703210215415, 106.2760942212997, 32.44756798590384, 33.548745955190356, 90.8715815697947, 64.80202282628706, 91.37595915025281, 5.5011222054881435, 0.22520832266778718, 0.27384027358024354, 0.08093673720835678, 0.18349111200340334, 0.1715744611236357, 0.09630682818110912, 0.12140531648671436, 0.10602697474701751, 0.23347997316910377, 0.24088261949439205, 0.18265708740199768, 0.11593161060685113, 0.14766833504601834, 0.1425640291023639, 0.180863231240261, 0.12060169791502338, 0.19079045903298164, 0.17312759713780496, 0.15258795251288723, 0.21840164678231364, 0.15984459780156612, 0.24336822240823702, 0.14129356421049566, 0.08880521095688305, 0.2776967908345884, 0.20375648182967018, 0.13452657167949986, 0.1546567269871312, 0.16294805062634332], [0.0921766719810905, 0.07002697867010871, 0.24635688461844, 0.021104555945062352, 0.08294263884665505, 0.1438448668247269, 0.07315338348909732, 0.020775488622847105, 0.12136117450051731, 0.08470789694617833, 0.07082652165404252, 0.09919933103505643, 0.025384863463020133, 0.013013629415523142, 0.06733055602038099, 0.01326152397650144, 0.06335080203209674, 0.06619555079528401, 0.010794419213198127, 0.054497732931087096, 0.02596238075995878, 0.11049590268803221, 0.027012859673930273, 0.051886510749858235, 0.05018402972529012, 0.020414427553694096, 0.07617695632600978, 0.033516339026391506, 0.08568472033666988, 0.027673512832411838, 0.03459476865828037, 0.01755255672539915, 0.06887767058346542, 0.0659111253316364, 0.0560749126147599, 0.026832811774746067, 0.6674020713375461, 72.6406011273784, 67.51028214731525, 72.15977345743488, 49.82826878947597, 8.81855405146076, 57.66006923490956, 79.04081882969027, 34.441045945690526, 14.511985163534842, 1.356120876246883, 0.6701241962371335, 0.048208446016595255, 0.6250113621354103, 0.14203119962926836, 0.03838231884724191, 0.23324289960005593, 0.1971887794112967, 0.02832042620397143, 1.78001816234281, 10.855082965666249, 22.65781644851931, 43.97405285989085, 80.05148026251024, 112.1709772848314, 97.07922658612652, 88.28901460093837, 86.45207451235864, 88.51568837319651, 91.03457173993512, 89.55822298603674, 80.15751761774864, 74.15283956835347, 69.26015346280991, 71.97595550167945, 70.53115044870685, 67.81705071849208, 68.87771452626875, 69.67653659082228, 71.65739628576463, 70.54595347373717, 68.293061717864, 61.75675738242365, 61.31541621300482, 55.83604551130726, 54.811192943203835, 67.93829118051838, 71.55154720429452, 75.60827424449306, 74.42446370278635, 77.29370101805657, 73.23098844097507, 77.5436972033593, 50.75590933522871, 23.79413297099452, 66.52807358772525, 65.8410704520441, 72.85315436701622, 71.46530212894564, 72.57625856707173, 69.96860411859328, 70.07318235212757, 70.7417974164409, 66.08152743308776, 56.183508673021876, 54.17513355132073, 63.25127063259002, 69.09802621410739, 72.53901958465576, 75.07088599666473, 72.00960159301758, 71.76313554086994, 73.46473032428374, 72.60357395295175, 72.88381945702338, 77.3043384859639, 73.38606326810776, 75.91098708491172, 80.2736197748492, 80.30124895034298, 75.39335973801153, 77.81302282887121, 80.61480322191792, 92.72658025064777, 97.3952990193521, 88.48935357985958, 85.16224230489424, 74.0480338373492, 74.67097682337608, 84.30411400333529, 63.742002287218654, 11.194361121423784, 0.6950603581724629, 0.034100507881732724, 5.479355012216876, 1.2109193902823234, 0.11581478219839836, 0.5530774220824242, 0.12343709657509482, 0.11752257604272136, 13.962737629490515, 19.987602156977502, 41.68413392959103, 87.0020535684401, 12.809955977624464, 39.54213150085942, 66.50951293206984, 53.54705618273828, 58.102426298203014, 3.3109557676699857, 0.18031386958975948, 0.06417640349677493, 0.013431411634589876, 0.028373466301408988, 0.024289761842679114, 0.012001445321666618, 0.10554476836395842, 0.09468586274212408, 0.09441467527780803, 0.06130379211578158, 0.04125631684737821, 0.0652378106549863, 0.06428368644969118, 0.01951725815512961, 0.05956662263000204, 0.09054265240387571, 0.05230019056809045, 0.030221442744556456, 0.05046714517858721, 0.04839298893667517, 0.04045199730523652, 0.03646341032318531, 0.06326453287094351, 0.10387570792508703, 0.0568877702068177, 0.04191718642569838, 0.025702630988352244, 0.05043191662538917, 0.04114236509908111, 0.08539564471932189, 0.07487510481188375, 0.053097079057366624, 0.09183289768594889, 0.037920049902412205, 0.05292456754813752, 0.08091022290529744, 0.032191378470029564, 0.04911319202473087, 0.07210467806867055, 0.14087226181741686, 0.06735041301937834, 0.1049384940415621, 0.013270288979965112, 0.020048915513701016, 0.0522473841274698, 0.06091321750934567, 0.11543706254733187, 0.03943988024407337, 0.04960292905208565, 0.08266596619280116, 0.03730879983894768, 0.10308993920203179, 0.07518592200452283, 0.05375389220012773, 0.00658746317757534, 0.04554855043909723, 0.005979459890494905, 0.04828266844513917, 0.025280932144772623, 0.031195981277813836, 0.07124872036999272, 0.028238765061682755, 0.14515722140429482, 0.051365567130907896, 0.016703183552430525, 0.09811743868574982, 2.5732030455143224, 89.44236401588687, 74.1016604823451, 60.354690474848596, 20.49055591706307, 27.01991765729843, 104.36979878333308, 78.11924226822393, 45.758225302542414, 23.34899494724889, 1.0151519950839782, 1.0069622087382502, 0.15135234462157374, 0.5929928092706589, 0.12983950786292553, 0.03287041965391367, 0.16687224408791912, 0.12084538282285776, 0.16983999209778924, 4.241685425081561, 18.95786427682446, 34.45583328124016, 60.049588910995, 96.4690391479, 106.58254900286275, 86.58455648729878, 83.73293061410227, 85.83254398838167, 91.7620772700156, 92.29964594687186, 88.84956836700441, 77.2482015240577, 74.83388854611304, 73.49847839724633, 74.95017113224154, 71.99654010034376, 71.3423672030049, 69.30017732804822, 70.55663801008656, 72.15847907527801, 72.99063344155589, 67.5221747736777, 64.6645398293772, 62.27678914223949, 58.12469751604142, 56.88789183093656, 73.63518868723224, 73.69030583289363, 79.4453485550419, 77.04139063435217, 79.28901072471373, 74.08482566956552, 77.94782684695336, 53.01387663810484, 29.303949109969604, 69.40537529606974, 70.56362767373362, 75.89039464150706, 75.69572740985502, 76.83297941761633, 74.54604148864746, 73.04591532676451, 76.52603826215191, 68.25413611627394, 59.997342940299745, 56.59775410929034, 67.72815412090671, 70.55187625269737, 77.13484502607777, 77.82889273858841, 78.12940120697021, 77.87432162992417, 75.9462256585398, 73.83186417241251, 76.84797856115526, 79.55237434756371, 79.08242733247819, 77.43955043054397, 79.61245721386325, 76.90173856673702, 74.91596021959859, 78.33945981917843, 79.08660857908188, 85.29703063349571, 82.864619839576, 77.41734981536865, 81.7538595199585, 79.37337306237991, 76.18323879857218, 80.19633339297387, 74.91816459163543, 18.4849892124053, 0.7032076113166348, 0.21255019060786695, 7.7786327177478425, 2.146509232059602, 0.1886551268398762, 0.9505270241248993, 0.34720949468112766, 0.17711867007517046, 26.655572614362164, 35.665778575405, 27.593272078421812, 111.43033965941399, 35.926718173488496, 14.598059615781231, 51.38127634602209, 58.728193390753965, 71.57171603172057, 5.919983781153157, 0.31140131935957943, 0.08354463073755465, 0.05487562495193655, 0.024358763382019057, 0.03734854448045935, 0.04726487850289672, 0.07046557932851777, 0.056575175690194296, 0.0685750428707369, 0.010147191745589578, 0.020268325010434757, 0.018065613469169024, 0.13077038129971874, 0.019681618488844366, 0.019710484681831255, 0.08159179600977129, 0.0029538504567162525, 0.07080587558448315, 0.06228300187015726, 0.02761826831697216, 0.1043306875433172, 0.06778303053109877, 0.0816108026511727, 0.008583011616381907, 0.05972776922487444, 0.07251031396369781, 0.051750020694828806, 0.036529136836648955, 0.04191086620032307, 0.011316300332245809, 0.13152834869200183, 0.11889252511243667, 0.22977342528681602, 0.12027431790146137, 0.21106253978946518, 0.25259060334534417, 0.13746785901246533, 0.15605188034955533, 0.30982253472170523, 0.2441929773457589, 0.2112391383777703, 0.1522814560561411, 0.14637277311375066, 0.1436181814079323, 0.1458330335275781, 0.15124878485596951, 0.20572073126752533, 0.13863793574273586, 0.15769302454446593, 0.264220047862299, 0.22808732705250864, 0.21391312231219586, 0.23355531025557752, 0.2640824278275813, 0.07589708142463239, 0.09051280561834575, 0.1708101352015811, 0.1453785901708949, 0.10860110678139234, 0.16974191752172288, 0.1535540966377143, 0.09865186162172787, 0.2498667011217725, 0.23823917182462834, 0.16001230976994962, 0.16357585968029115, 3.3924819865534386, 106.50137947451685, 87.46230448445966, 96.86373941359982, 65.84653039132395, 20.711320638656616, 72.62359373031124, 97.17438328650691, 53.98709904763007, 21.409369168743012, 1.6426077292811487, 1.036977717472661, 0.17790639232243263, 1.2103961215865229, 0.1392820777912294, 0.16125692685525264, 0.48055638288778646, 0.13480651552879042, 0.257597585479098, 3.5442419205942466, 17.327066313835886, 29.168593998878237, 53.22275853926136, 88.72071850684382, 114.01683684318297, 97.85999005840671, 86.16823611720916, 86.4687838092927, 95.08213612341112, 95.75552863459434, 92.76450172547372, 85.35259492935674, 80.49768909331291, 77.04822340319234, 81.86745920488912, 78.86522216181602, 76.15245603745984, 77.59529206060594, 78.84811278312438, 81.22488083377962, 81.58642922678303, 77.24256115574991, 72.70386895825787, 69.42734841377505, 65.13822878560713, 60.30884973464474, 76.0416647695726, 76.81405005916473, 85.91539229116133, 80.26697527977728, 82.88116439696282, 81.29760157677435, 81.54591898764335, 58.4350158322242, 33.55636712043516, 75.18180278039749, 75.42950830151959, 78.24260865488361, 82.10046368260538, 82.96910393622615, 80.89714327166158, 79.67102604527628, 80.94026580933603, 75.23482538038685, 66.64186939116448, 60.21125724238735, 74.34769507377379, 76.84613504717427, 83.11673410477178, 83.9939957280313, 81.72351606430547, 81.11528196642476, 83.42557368739959, 78.09082077395531, 83.22710960142075, 87.48819212759696, 83.68465408202141, 84.56912502165764, 86.84930862918978, 84.32978199374291, 82.50682123245733, 84.41797256469727, 86.04847046636766, 94.49571824842884, 89.42277569924632, 83.68620734060966, 86.09015741655904, 84.72063833667387, 87.96080635439965, 88.73881632281889, 72.2951344520815, 15.108666900665531, 0.5123645986520475, 0.17222329163022582, 8.931331999840276, 2.834067383120137, 0.19042848248875913, 0.9430736014919897, 0.20031366737619524, 0.2512647962618259, 21.301666767366473, 32.517801946209325, 56.126210689544685, 104.20276857191517, 27.800461476848973, 52.17985522362494, 90.39910070357784, 69.78341333327755, 88.4332872206165, 9.080790973478749, 0.3475483506917954, 0.1683680920471107, 0.1266877531945225, 0.1667933829969937, 0.24907833536065396, 0.16278616092618436, 0.21374568613546513, 0.12665258209791877, 0.16678399075904202, 0.08358128038385222, 0.06310854587824115, 0.1639106707467187, 0.2023489025211142, 0.10585318004051525, 0.1459417107605165, 0.12139646817118892, 0.16292640098160313, 0.1560733154896767, 0.10576589198242273, 0.13566477915212033, 0.21416053806822147, 0.15481156867838677, 0.20183085854495728, 0.19972817701918466, 0.14078131185904627, 0.10463543731959597, 0.21923944053630676, 0.14225442232864519, 0.07537981119727896, 0.14180083699043722], [0.029785774287677584, 0.14573210910443338, 0.06296821006183183, 0.053005075728100155, 0.04547776774533334, 0.09543545679339478, 0.09235982062114824, 0.07955109865795221, 0.12030742822154877, 0.0961208526766108, 0.11480487913133637, 0.04974380113004197, 0.09596998698168224, 0.07654722960245225, 0.13937584695316133, 0.055922449626509226, 0.0695834290837088, 0.06053899504965352, 0.008993265106372775, 0.062481587181889245, 0.01758686597308805, 0.08660532819527773, 0.12985181123498948, 0.07422885602159847, 0.06493754249306456, 0.04154205998225559, 0.03367634415025673, 0.019671473569507082, 0.024426058460507664, 0.0950139782000934, 0.05783514517749991, 0.03136866324160609, 0.05086375655786646, 0.050358287914986574, 0.04653621780415697, 0.05433412719397776, 0.24488591919502906, 2.890997644393675, 72.53736434444305, 76.68720060779204, 69.375243648406, 54.37091473610171, 12.2072563440569, 45.26082954099102, 101.06291909371653, 48.9081984181558, 23.855876961062034, 8.75756609824396, 0.04580912758566199, 0.5445710882063836, 0.05097136892859013, 0.1367966893820032, 0.149237007323292, 0.6523863190124113, 0.2644792307288416, 3.5226750133499025, 5.007809631286129, 1.243430936048108, 0.05581063526352087, 1.173397261769541, 18.874270723712062, 63.00129013676798, 100.6925061441237, 107.60586400185863, 96.81194843784456, 83.40828387968003, 81.27431054269114, 94.64819646650746, 89.73590635484265, 85.80681324005128, 78.89156479989329, 76.0448968025946, 76.4178357585784, 74.29956759175947, 76.77310051456575, 75.50514728792253, 73.78304635324787, 68.99318910414173, 67.01796193276682, 63.07259490413051, 61.72536665393461, 56.567583237924886, 62.676015823118156, 66.06357866717924, 70.57072716374552, 72.8123224935224, 79.48368580110612, 73.48177694505262, 78.61747741699219, 53.191720824087824, 26.37573111441828, 70.10152539899273, 66.12499513933736, 73.43084889073526, 72.39263672982493, 73.02884517177459, 72.34307366032755, 73.58560992825416, 71.54424375103366, 70.84275922467633, 64.28307364063879, 55.348392917263894, 61.68878270733742, 70.44496813128072, 72.96400839282622, 75.85140628199424, 77.49687979298254, 76.69539051671183, 75.10082937056019, 79.63415576565652, 77.49748383798908, 74.17090600536716, 71.25765969676357, 78.68247109074747, 82.83586886621292, 79.63724659335229, 82.44330236988684, 93.75506493353075, 101.00880607481926, 103.62750591770296, 97.93551137370449, 91.38493353320708, 80.56596186853226, 64.06865335279896, 53.408349406334665, 21.46551593657463, 1.3681300705479038, 0.35123366261682204, 0.9724930325342763, 9.16807645751584, 3.595049607176935, 0.5283674093023424, 0.027622477970116084, 0.8836669150379397, 2.1022067964076996, 17.64772595897798, 24.233658083023567, 60.33403527352118, 86.99239669307586, 9.616827964782715, 32.74137312366117, 73.29607625161448, 58.951199746901, 39.18835332316738, 0.8879590298860305, 0.2424883551054424, 0.019829898637028474, 0.02329418461980118, 0.08005369830155566, 0.08208100443645831, 0.013144376683950186, 0.11042807326321641, 0.05188026713327535, 0.00631778538527508, 0.04099989189736305, 0.032704343283248526, 0.03576354686951926, 0.0705640752529425, 0.053696194288110545, 0.05315749275107538, 0.007582162272170067, 0.0555605803345961, 0.019520979427221804, 0.09744043146530468, 0.06496882952389217, 0.02156193341849552, 0.029507337716378035, 0.05764758387099832, 0.07592418561539344, 0.0538629524770283, 0.12710832014319398, 0.05410969790612018, 0.06034214875750965, 0.03190563150471257, 0.10493492407183494, 0.025835202503648978, 0.04495822989772405, 0.10696062908297586, 0.0669627495470547, 0.031199524434463635, 0.09075899563369252, 0.029897517787532944, 0.08857452656112372, 0.03481980698603777, 0.10138699469426948, 0.06243338492969352, 0.07243608770471427, 0.051389706561401974, 0.08539235054124748, 0.04192333811173036, 0.1060710171417844, 0.0295374890218579, 0.04877940751612187, 0.0560316363079173, 0.012483036919166485, 0.06381183374492873, 0.004185909206318039, 0.04507374446538668, 0.08115895633255282, 0.057108920638359366, 0.06292061301909628, 0.03907126171754734, 0.058510731304845506, 0.047612295546118295, 0.03637795704567144, 0.06586603339641325, 0.05246387291399222, 0.019771785122312365, 0.0825485325748882, 0.036421968796921354, 0.08202135683067384, 0.0804994005950228, 0.48156666899881057, 6.453798259458234, 87.16525554656984, 79.63110416166245, 56.99099917565623, 18.827796520725375, 18.46584020122405, 87.0556959029167, 99.60992413182413, 48.06316298823203, 43.11556762264621, 14.370644515560521, 0.24338404978475264, 0.78078345185326, 0.5295199119756299, 0.09466034435336629, 0.15398843784726438, 0.42160073836003586, 0.39023075553198017, 3.8791821800893356, 4.234733023951131, 0.8120762436620651, 0.3525226515146994, 4.322218058570739, 34.39904912825554, 83.57078767591908, 103.49027003011396, 99.40465081122615, 90.65002256824125, 82.32010072277438, 84.26023837058776, 97.57095060040875, 89.45619429311445, 80.78009190097933, 76.82667224637925, 74.15797002853887, 73.56384861853816, 70.58891127186438, 71.97001703323858, 73.6458339998799, 72.85855939311367, 70.60930759676042, 69.7497986209008, 67.75944679014145, 67.07365958921372, 62.51011525430987, 66.79569690458237, 71.13140644565706, 75.62426182531541, 77.4458654465214, 86.57562132804625, 77.25410076879686, 82.42467111156833, 60.620223168403875, 34.763896234573856, 74.63576962870937, 70.57150379303964, 76.13296185770344, 75.46109907088741, 78.49844917174309, 76.3155403444844, 76.73574386104461, 73.61905990108367, 73.44076464253088, 64.9147125213377, 58.590094581727065, 66.30389444289669, 73.79107936736077, 74.68213204414614, 76.34134954021823, 74.82788731974941, 75.74414514726209, 77.33215593522596, 80.0679934409357, 81.2615785291118, 76.85659208605367, 71.69757704580985, 80.41781394712388, 83.06513140278479, 83.51343477925947, 81.17279960263161, 83.92662509795159, 88.95972421092372, 94.45091693632065, 94.3994240606985, 89.75026222967333, 83.51225806820779, 72.26735622652116, 65.52572757967057, 32.543595452462476, 3.3257205495911264, 1.1897759764425218, 1.204863741032539, 11.02548739602489, 5.081905655322537, 0.5720330726715827, 0.1909565775384826, 1.0377224775091296, 5.947983130331963, 38.367887620002996, 30.349919719080773, 36.340669431994044, 114.89614594367244, 26.836072244951804, 11.42412179900754, 64.13358819100165, 61.97141301247382, 53.42612166558543, 2.5510887224828047, 0.22012391968840556, 0.1525295306477816, 0.05793036224560873, 0.09574457327084196, 0.0518723649363364, 0.025754914573964574, 0.1017041550949216, 0.029820250159490014, 0.024089150228387406, 0.05760297457116747, 0.014749327054878157, 0.04080073585012748, 0.05324283494584022, 0.05892900382018378, 0.054136445865996426, 0.02867373446333072, 0.013198352366265272, 0.025480028820194067, 0.023404353808972145, 0.07828447952746384, 0.08202923221453544, 0.07287209898593926, 0.028007521421738693, 0.038233153867505254, 0.08099695171920523, 0.10889143878293615, 0.0044301897475135426, 0.07536022998993436, 0.09128977965203025, 0.05848808191536416, 0.03243376102839266, 0.14505298748131723, 0.2717916012531327, 0.20908163560013618, 0.09032162837684156, 0.15121009741579333, 0.14734670069188843, 0.16615242787426518, 0.12050448135743219, 0.24089472368359569, 0.144335592105504, 0.20432304981495106, 0.14426904970840101, 0.11331245558516634, 0.10770633140759123, 0.20181841727706695, 0.11111130111760671, 0.17537883843385405, 0.14743788047663628, 0.13745218485353455, 0.16558642679404828, 0.11706175117362892, 0.23040630584282262, 0.2853415209439493, 0.17675238811681349, 0.1195743433650463, 0.06716932515583693, 0.10610880825908915, 0.1693992463931922, 0.13337085143693034, 0.25094498519695574, 0.14376422840981715, 0.10938217938547173, 0.20456711010586834, 0.20435053704967424, 0.1709368001789816, 0.2274125721305609, 0.49164008168924245, 7.240849291124652, 103.1738994967553, 94.82018455382317, 91.49628962239912, 76.53838588345435, 24.981359897121308, 61.31432971646709, 121.27340209099555, 70.01720228502828, 39.2114011702999, 12.526500013566787, 0.29068290045665157, 0.9021306758926761, 0.7383885138457822, 0.42067282202263034, 0.20340498536825183, 1.7507819182449773, 1.703240707997353, 6.948890609125938, 4.324749948516969, 0.8151471530718188, 0.25253072591318243, 2.6832877964742723, 23.6944753508414, 71.38740385732343, 104.66671436063706, 108.41270339104437, 101.34496888806744, 86.84628055941674, 88.34963875432169, 102.73224846009286, 100.2741696757655, 93.19824526386877, 85.46483747420773, 80.05034277516027, 84.13657388379498, 77.92113904030093, 81.21307449956095, 79.76798703593593, 80.23824784063524, 75.07542025658393, 77.80148321582426, 73.95880776066934, 74.91642305927893, 69.47638588566934, 73.24738394829535, 76.20575320336127, 80.05868173414662, 81.94119976412865, 90.90895391279652, 82.67735019806894, 82.6309956273725, 69.1033527928014, 44.22477860604563, 79.15808200836182, 76.08937648034866, 78.60493367718112, 78.3865047270252, 84.4071154440603, 81.41469217115834, 82.2706945480839, 80.68224445466073, 76.50542228452622, 72.43208792901808, 63.58002408858269, 70.33980938696092, 79.43662520377868, 81.87611195348924, 83.7967005083638, 84.65700180299821, 79.94480748330393, 81.79093376282724, 87.96406976638302, 86.45027022207938, 81.89330762432468, 76.40646872981903, 85.94623781019642, 90.60045949874386, 92.26570175540064, 88.9031400988179, 96.188534767397, 99.66765357602029, 104.12968697086458, 102.59893494267618, 96.57695924082111, 83.99596475785779, 75.26113663950275, 60.369505266989435, 23.38161926115713, 2.628796268855372, 0.857949527280946, 2.0824235869992167, 13.340555583277057, 6.182915943284189, 1.6575151874173073, 0.3119439854016227, 0.9962579992509658, 3.8406637695527848, 28.33176220616987, 37.097596660737075, 76.71816379793229, 101.39001338712632, 22.929326834217196, 48.5687525810734, 96.48865884350192, 74.18952941894531, 69.17540673286685, 5.512556895132988, 0.5344663271980902, 0.19741776309186415, 0.18732538206442712, 0.2705130005075086, 0.22504641764586975, 0.1649508955738237, 0.20395059318792438, 0.17731299593804345, 0.08488049655551873, 0.15924878057933625, 0.1429079412933319, 0.1651985411562266, 0.1519371148559355, 0.19609898869549075, 0.1218790652590894, 0.15783833610194345, 0.1693866059424416, 0.16644082933423981, 0.12712977060507383, 0.14378241533713956, 0.12751565675341314, 0.11583217239427952, 0.14971771217401952, 0.11902685096908001, 0.2034077739282962, 0.2008151791749462, 0.07716117246497063, 0.15909003183966683, 0.19125472363685408, 0.13682904893592482, 0.2001650769624018], [0.10293226298545638, 0.11403308385202002, 0.08785572924440907, 0.018271198909309123, 0.0916914931768852, 0.1378362860170103, 0.044150907290919174, 0.03480558839416312, 0.14531402428063656, 0.09439606700212726, 0.13968989703684084, 0.07924204346753898, 0.06661738178903057, 0.09524078619095588, 0.07351086309720432, 0.06719547939757187, 0.027102922885528496, 0.010420587458347362, 0.035251746509945205, 0.045169298612182184, 0.15714255972735344, 0.029029176277559132, 0.019327352619579723, 0.03598167125376002, 0.08613543284516181, 0.03448165194582074, 0.05986978660427755, 0.051035750957746664, 0.026456421286228205, 0.07769721950734816, 0.05710860271187079, 0.10480304203567006, 0.02662455077253042, 0.028841731799465996, 0.08513220240392032, 0.04779194699480169, 0.10128552634869853, 0.3540079121387774, 4.796184032194076, 62.36708602597637, 81.21179580688477, 80.8931738330472, 78.953381353809, 17.396596208695446, 39.179602515312936, 111.08059760062926, 67.68550226765295, 32.725589506087765, 16.676560832608132, 4.51157194952811, 0.8190078072009549, 0.03796672763963861, 0.04039121971976373, 0.2347856934272474, 0.8399256234688144, 9.40903256016393, 25.970840531010783, 25.00485489445348, 7.449817484424961, 0.16673275479866614, 0.026397131826548327, 0.2671607223249251, 6.361853980248974, 33.63694829325522, 68.92112731933594, 99.8567275078066, 105.73745081501623, 86.5563311115388, 82.65425528249433, 93.290052260122, 82.2752994106662, 85.6751157391456, 85.83714100622362, 84.2645529777773, 79.05285266137894, 80.51617914630522, 77.51546398285898, 76.21238200895249, 72.46938182461646, 67.72751085219845, 65.0577692062624, 60.636716734978464, 58.1631249766196, 62.89947717420517, 70.78605744146532, 70.25583144157164, 73.74043372369582, 76.43490591356831, 79.92736078077748, 48.044947501151796, 7.825383938127949, 70.85190619191816, 70.52725945749592, 75.55046635289347, 75.36838992949455, 73.53996138418876, 69.37848352616834, 70.40565029267343, 66.6989084982103, 68.29679581426805, 60.47439729013751, 56.164238068365286, 59.37795362164898, 67.12334032981627, 72.00191374747985, 77.11464481969034, 77.70875838495071, 75.56166079736526, 72.20945419803743, 73.35162485799482, 81.71718535884735, 82.05392868288102, 79.78211541329661, 78.67998430805822, 82.7435205828759, 89.54340427152573, 93.65182030585505, 99.97522231071227, 97.03922625510924, 77.27803507158833, 41.76901794249012, 20.578469960920273, 6.879538201516675, 3.176759962112673, 0.42445129023924955, 0.16674156480979535, 0.05732536729004595, 0.4313314952436955, 0.11678471845845062, 2.3475086400585794, 0.4722222042900901, 0.18193390040147692, 0.05750187011736055, 14.8779462229821, 16.979448218499464, 25.691516783929643, 78.67413997650146, 66.38575430839293, 7.287688764833636, 41.64252150443293, 60.17659525717459, 51.99913594030565, 49.77015103063276, 0.7094728009354684, 0.09258908009336841, 0.032679349664718874, 0.13016602985801237, 0.0995619051278599, 0.09224036453111518, 0.06135626147771555, 0.08392828757003432, 0.022466558767783067, 0.02813725266605616, 0.06867364604747103, 0.09119867647607481, 0.07057319936012069, 0.04172264988864622, 0.05156767261665195, 0.08040927801161044, 0.09023516003282801, 0.07707222965696166, 0.0829847430389735, 0.06415609067546264, 0.03555790588800465, 0.03871914855534992, 0.0386936952840657, 0.059165648379994024, 0.08506924529830295, 0.1125720392672285, 0.06157116063179509, 0.12489632553150579, 0.14138334971522132, 0.09187114845600822, 0.08646864278782761, 0.06675026740037626, 0.17018935883477812, 0.026717753029398383, 0.0675331709545947, 0.08149012848134003, 0.09803097800261552, 0.05727940201458912, 0.06900972881985289, 0.03724157179315244, 0.07844945656195765, 0.050166344585558104, 0.05009351643703638, 0.06339505127060317, 0.05248120182283944, 0.034890202805399895, 0.06794658264205342, 0.07243630987021231, 0.053622408529683474, 0.11029714117607764, 0.032214047011709025, 0.01741358071505543, 0.014685619183094993, 0.10770103774003445, 0.047838486836201725, 0.02650183114793993, 0.06706734353135671, 0.0817668317787109, 0.06455216196275528, 0.13836212876823642, 0.05838646035220835, 0.06500854352188688, 0.0257477957019282, 0.05017071511716612, 0.02141486943489121, 0.07649171121057964, 0.05627071319688713, 0.025806179262637615, 0.08623985829012049, 0.048542153916411826, 0.35350759543718835, 8.8429747281536, 82.30978488922119, 81.82144980276786, 71.0906530195667, 36.81084002217939, 12.604146272905412, 78.90335544463127, 120.72221494490101, 50.26409902880269, 40.29097080230713, 32.84248594314822, 5.691379712473962, 1.011055140726028, 0.09895651946745573, 0.2318311068079164, 0.28512447291324217, 0.8609238483252064, 10.646119675328656, 31.020590105364402, 28.608214778284875, 11.738211474111004, 1.0614091806834745, 0.0447498424910009, 1.1904946282025308, 17.690330743789673, 54.93526535649454, 84.63958647943313, 101.79499810741794, 99.03750127361667, 84.11505576102965, 84.23870455834174, 95.08190862594113, 82.82851834450999, 85.76241200970065, 82.96238883849114, 81.56578187019595, 82.13738103066721, 79.36193543095743, 76.50922698359336, 72.71132146158527, 71.33638951086229, 66.82800154532156, 67.00970142118393, 62.44654147855697, 61.91956320116597, 69.51149109871157, 75.57196094143775, 74.05338395026423, 77.00602654487857, 75.94826529102941, 79.80412775470366, 54.02923707039126, 14.215012711863364, 73.96648776146674, 75.03697318415489, 79.28558257318313, 78.45289476456182, 77.61391547418411, 74.16958808898926, 75.85384599624142, 73.15858148759412, 74.1354791579708, 64.95969034010365, 60.09782621937414, 64.45230430172336, 71.09734458308067, 77.15238586548837, 84.76642808606549, 82.53754908038725, 81.52136495036464, 75.39343818541496, 73.62760282331898, 84.59896641392862, 81.1278570851972, 83.02852784433674, 81.03925858774494, 82.89451614502939, 83.91267714961883, 88.48750222113826, 97.00667842741936, 100.66586540591334, 87.28353069674584, 59.82197769226567, 36.36771809670233, 16.37218588782895, 10.971279259650938, 2.5841606768869587, 0.29054209349616883, 0.11054900024206409, 0.8384528960431776, 0.36996448172196267, 2.497225264387746, 0.8255682164622892, 0.19434817135334018, 0.0966160519108657, 20.353743645452685, 30.38933365575729, 20.14438713750532, 59.53718616116432, 104.4839083763861, 18.92560278215716, 18.349469361766694, 54.57832574844361, 58.68159171073668, 64.28783932039815, 1.1708648815270395, 0.363770691497672, 0.07541008699204653, 0.1475871450478031, 0.07405935906835141, 0.0822437751377302, 0.014350616594686384, 0.025237514111664028, 0.026589393082465378, 0.08390332076458201, 0.079830797359107, 0.042606811114256425, 0.03512366426988475, 0.027242927368910565, 0.006564196608509989, 0.0864056626995725, 0.0508706551796246, 0.04460451944220451, 0.036265096972666444, 0.04332627109702557, 0.03314669011160731, 0.022830619071159634, 0.019391253928563768, 0.04387400098024838, 0.015478669571870518, 0.012136430971534743, 0.09626991806491729, 0.0767798675224185, 0.1175133293614753, 0.052417486290177034, 0.07075907527318887, 0.002268960430932742, 0.03252828478693001, 0.2588953997098631, 0.15052725260536517, 0.20248921918532542, 0.15783150259765888, 0.1638535971963598, 0.19693587846573324, 0.1003980671145743, 0.2365280071934385, 0.2700631536783711, 0.1394525170326233, 0.2540873399665279, 0.35003513338104375, 0.10484562120250157, 0.16965764785005202, 0.19329464723986967, 0.20983345896726657, 0.13392919163790443, 0.14050830876634968, 0.1941537995251917, 0.11465644959600703, 0.14469896292974874, 0.29252883527548085, 0.20937172245354424, 0.14663715005641983, 0.14538162387907505, 0.17418815393842038, 0.24770997975382114, 0.18580383951625518, 0.149198672283561, 0.2972237591541583, 0.15435464319682893, 0.1448467872556179, 0.133686893349213, 0.27615376718101964, 0.15909375502697884, 0.29308792624262076, 0.34143950429654896, 0.5313785025669683, 9.213003285469549, 93.5358593540807, 101.59835400119906, 101.80467067226287, 104.91753424367597, 29.382931916944443, 56.47971430132466, 125.77046225147863, 85.44181316129624, 47.990681509817804, 27.293520627483247, 6.67369564694743, 0.701048162675673, 0.15972640575660815, 0.35697972041464626, 0.817571300412378, 0.7547513551769719, 12.941249474402397, 36.56442103847381, 33.28392321063627, 11.5770608955814, 0.5231623627966451, 0.08091321064820213, 0.4982117677648222, 9.438119876769282, 41.16893060745732, 74.66146899807838, 104.60152456837316, 109.43747751174435, 91.93770531685122, 86.96910565899265, 102.5922041554605, 93.59641290480091, 95.0435870693576, 94.66853003348075, 90.70245681270477, 87.48499147353634, 85.87502325734785, 83.57674183384066, 84.37931368427893, 80.17599982600059, 75.9677359365648, 74.28771418909874, 69.17208056296073, 71.23017172659598, 76.9649907081358, 81.53025304117511, 79.71196774513491, 81.32544256025746, 83.29036174281951, 84.42920623287078, 58.17135410924112, 12.57253687227926, 78.9958998464769, 79.65496001705047, 84.57948007891255, 84.79068402321109, 84.57157258064517, 83.0231777314217, 82.9177365764495, 79.2393692078129, 80.71441573481407, 71.10543251037598, 66.72109342390492, 69.28504482392343, 77.21068013098933, 83.47338737980013, 89.14916684550624, 86.5069249368483, 87.61047594008907, 80.6461194253737, 76.24204297219553, 93.04843425750734, 89.50405505395706, 89.70487256203928, 84.02076982682752, 89.06354150464459, 93.53738123370756, 99.02280807495119, 108.59441111164709, 111.7811486028856, 87.08405463926255, 47.90966103153844, 24.497319806006647, 10.220547414595082, 5.7031752601746595, 1.2768704900818488, 0.3594166767452994, 0.20672943923742543, 0.9565952985036759, 2.145959609939206, 5.420567998963018, 1.3022336387826552, 0.4913981204792377, 0.16703915932486135, 20.960320541935584, 28.225293390212524, 35.89302109133813, 96.20591086726036, 79.1434907913208, 17.967909036144135, 59.772583284685695, 77.93349450634372, 66.5720590468376, 79.7637979445919, 2.3925425977476182, 0.5252625468757846, 0.14982171627061983, 0.27631528915897496, 0.17873482448199104, 0.1351687678646657, 0.1526873294384249, 0.157198959120339, 0.1614271056267523, 0.09240294371040599, 0.1672293789564602, 0.22369200483925883, 0.16630783647058472, 0.13855248629566164, 0.12109860552534943, 0.15359370338339962, 0.2030702509106167, 0.14270623034286883, 0.11106545841621776, 0.23359349207772365, 0.19945829956521913, 0.18482614278552995, 0.20755672226509742, 0.15336783001980475, 0.17000286239049128, 0.127616175149958, 0.21136748874860428, 0.1314559840266743, 0.20434532765178912, 0.13269110162171627, 0.14198957041146296, 0.10128682103729057, 0.19955262031045654], [0.16212197801759168, 0.22287134081125262, 0.17217072267686168, 0.055713974119674776, 0.08643266729890339, 0.08758684770474512, 0.05189649287551161, 0.07692476539241691, 0.08886982281241687, 0.10568136950173687, 0.29257608757865045, 0.09639309734226235, 0.14492302832584228, 0.09799275787607317, 0.10348254394146705, 0.02809084689004287, 0.0916090774379911, 0.10507762326949066, 0.022450758204344782, 0.1475620326856452, 0.03527965126258712, 0.018861889088105772, 0.06863132735053379, 0.039076777550602154, 0.029675187580587885, 0.0161530175096085, 0.042285896882775335, 0.03401798106008961, 0.023141645022758076, 0.08648649263646334, 0.08246951826637791, 0.06469705217187444, 0.029298488741680503, 0.06380045350881354, 0.07630614939356044, 0.04548854277198834, 0.06879946832815487, 0.05339179691227694, 0.16695783143081974, 0.6734596817724167, 37.763191500017726, 78.19524211268272, 68.44692061024328, 74.33061707404353, 27.350549928603638, 33.9328872003863, 96.43591080942463, 104.17965012211954, 38.847769998735004, 18.729684314420147, 16.962854631485477, 0.9162336804213063, 0.6588192512431453, 0.10132763820189623, 0.14451307935580132, 1.241242743788227, 2.7637449243376335, 9.03001981396829, 13.25768570746145, 4.576212119671607, 0.07203620512999835, 1.0134353452632505, 0.026766843943586274, 0.1275542369412799, 0.6140798390392335, 11.218236588662672, 51.24342464631604, 100.83252691453504, 104.81545063757129, 100.32470549306562, 95.46131949270926, 89.63196354527628, 89.41577819085892, 87.78025965536796, 84.95830259015484, 83.38788755478399, 81.25200010115101, 78.1817570040303, 74.76151297169348, 69.45991193094562, 65.7799324681682, 64.03645461605441, 59.90654791555097, 58.598637503962365, 62.09748975692257, 68.41784015778573, 78.33376453768823, 71.69165426684965, 80.99874834860526, 42.02281098211966, 0.23491969752696254, 51.22174178400348, 74.37854843754923, 69.76790428161621, 76.7351947292205, 68.55545259291127, 68.31496423290622, 67.83673317201676, 69.35097986652006, 69.68150231146043, 62.11751345665225, 57.39016309861214, 56.29793597805885, 67.74202362183603, 70.15993733559885, 74.4059108918713, 80.72140539846113, 75.86543267773044, 72.34097911465552, 86.28061202264603, 81.43952077434909, 75.78878171982305, 74.57855793737596, 84.54342565228863, 91.76787453313028, 91.94429489874071, 80.07789350325062, 49.2741398657522, 18.407926405629805, 1.9957913001698835, 0.06996952207578767, 0.10967658697477273, 0.03942795991597157, 0.3951511544085318, 0.12085410090343607, 0.7225838748197402, 0.5245757643734256, 0.5605372798538978, 0.38672513719047275, 0.19971285526069904, 1.1924059256430597, 2.2703504706582716, 13.85314464569092, 34.16634275067237, 54.101506740816184, 94.70128966915993, 50.48823110518917, 17.990221438869355, 50.5551585074394, 53.73273726432554, 61.79143897948727, 35.836527193746264, 0.28062395150623015, 0.11993265034811151, 0.05743542348124808, 0.07478051593587284, 0.0583047494142046, 0.0366196156509461, 0.044883482698952, 0.04955350872009032, 0.01623334565890893, 0.055804429951334195, 0.05063305300990901, 0.027931272690635056, 0.07324300045447965, 0.017721122881818204, 0.017336705707073692, 0.03981762670821721, 0.02823706817693047, 0.05155482532216176, 0.05412673187111655, 0.07384938969006462, 0.06465443470064672, 0.08777445497652216, 0.07704347071628417, 0.0882523712672053, 0.12816641780157245, 0.21958329144024083, 0.09626672347827304, 0.07247845236692699, 0.12118400900714821, 0.1356520467708188, 0.19168460621468483, 0.035910179928666165, 0.1724622344538089, 0.13149195951559853, 0.03969009988190186, 0.15072851922483216, 0.03667136105979162, 0.011152051081280074, 0.09741210153386479, 0.10326457660525076, 0.06863197086439018, 0.0856201314637738, 0.04921721144308967, 0.16976067135410924, 0.20422356563710398, 0.0869624094376641, 0.1367940387177852, 0.18174945707282714, 0.0332743663250679, 0.02509884645170983, 0.02539815317328659, 0.0762822857547191, 0.015461581023109537, 0.05192757306259967, 0.05241596943608696, 0.08330880589182339, 0.025795364016366583, 0.0657139496216851, 0.05426283505174422, 0.05978805651407569, 0.0747712922372645, 0.023134713842263146, 0.052903155390653885, 0.05817273331265296, 0.04058096820728914, 0.05710430112817595, 0.010610673982169359, 0.057425023837675976, 0.026526414909430092, 0.018739609964071743, 0.20893935775083883, 0.09297177165506348, 0.11909971359155833, 1.9016682669039697, 62.16393863001178, 91.9011958952873, 73.08611962103075, 46.15895425119708, 15.696174213963172, 59.01143558563725, 126.84035931864094, 80.87721763118621, 30.01589067520634, 41.462335663457075, 23.7883690480263, 1.2954925553452585, 1.0256179818703284, 0.13103530982569342, 0.44731509240884937, 0.9940879479531319, 5.128739245476262, 15.567136080034318, 20.1650188046117, 11.281082764748605, 1.7319784433610979, 1.471414412221601, 0.13396869113128032, 0.10946556805602967, 3.060904424036703, 25.58852122675988, 72.97443405274423, 109.11496454669584, 97.0470396164925, 93.12190025083481, 89.79439673885223, 90.36121060771328, 90.17854582878851, 87.13252728985202, 80.87842572119929, 81.87598643764373, 79.59887012358635, 81.5134496073569, 80.67268171618062, 77.2766230183263, 71.19546659531133, 70.66826866519067, 65.81013079612487, 67.9967580303069, 74.26457220508208, 77.67548884114912, 85.93880884109005, 78.5266431685417, 80.53572823924404, 48.502280173763154, 0.2118567737840837, 57.765133842345215, 76.98760709454938, 73.31038505800309, 80.32305732850106, 76.22423541161322, 74.45519939545663, 74.0389653175108, 73.65491820919898, 75.22446247839159, 69.1413527150308, 63.30041793084914, 61.532115397914765, 72.55170452979304, 70.61079025268555, 75.27999539529124, 75.60104923863565, 74.21099262852823, 72.99326927431169, 87.88210791926231, 86.8976636086741, 78.97137718815958, 73.52044367021131, 79.85269454217728, 86.22314145488124, 92.10771652960008, 90.23829921599358, 68.63269190634452, 38.4485903862984, 9.48226026950344, 0.9542853901943854, 0.900360154769113, 0.627466949724382, 0.549971885498493, 0.7581936640124168, 1.137216216133487, 0.5907352400883552, 1.2337705060358972, 0.9511779537124019, 0.17682789374263058, 1.5108457544157583, 3.0156277696932516, 31.217667633487334, 49.685957354883996, 33.37502418025848, 90.01121751723751, 87.8580794795867, 19.44928038504816, 22.183578360465265, 51.41733861738636, 70.46972613180839, 47.69783735275269, 1.4251245606330134, 0.08518367585155272, 0.08347818027100257, 0.04822882778582074, 0.038569259622524825, 0.0643830557143496, 0.06590600786430222, 0.029332309608317675, 0.015852371091774155, 0.016736765016591357, 0.05741475825949062, 0.01950697917040558, 0.05389595171436668, 0.04574844193074011, 0.0790266884911445, 0.027679099528599652, 0.04951145432348694, 0.03944356512698916, 0.07094187917368067, 0.0449736665693983, 0.08988034641069752, 0.012863567155305178, 0.06503109715037769, 0.06441453426715828, 0.04448588306625043, 0.03307963443559504, 0.09357556385258514, 0.03681369253524369, 0.00596370241950236, 0.08972106140948112, 0.08885777224936793, 0.07593267386959446, 0.09225398557440889, 0.05937780493930463, 0.18891708294470466, 0.3457531308935535, 0.21585667205433692, 0.14901710944550653, 0.19417911107020994, 0.18577924809388577, 0.1243115706189025, 0.11553847726674811, 0.2272740481120925, 0.3998789587809194, 0.24606531155445885, 0.15185932628810406, 0.3141342307771406, 0.2789031954542283, 0.16403655431443648, 0.07659057485720805, 0.13721698053902195, 0.18878510131710963, 0.09229996617162421, 0.13528913559932865, 0.11319948825985195, 0.16727816343547838, 0.17149373077817504, 0.20183874925057735, 0.2511342548795285, 0.22475550341750347, 0.20415771271913283, 0.1268184631161632, 0.12681728334075984, 0.19262271152148325, 0.2305809585678001, 0.21319644705903149, 0.11632740227205139, 0.2409097083633946, 0.19049359996232296, 0.11847673855241268, 0.3274919849730307, 0.22594782734109511, 0.31460917464667754, 2.5337670455055856, 69.47496598766696, 104.15008329576062, 89.19900448091569, 94.39772959678405, 42.33531405848842, 53.04947214741861, 116.18889639454504, 124.45873537371237, 54.976669896033506, 36.195761388348, 24.23178711245137, 1.5996020046934005, 1.365558589177747, 0.22272892506612887, 1.589666641046924, 2.6238660946969063, 8.883012321687515, 21.006833968623994, 36.594846863900464, 11.887100723481948, 0.7323655305850891, 1.8888749662906894, 0.15047946404064858, 0.11583973368209217, 1.0223407803043243, 14.324864572094334, 59.72889200333626, 114.81744750853508, 111.3900569177443, 103.14865512232628, 100.44145876361479, 99.0197878499185, 97.63119820625552, 97.24246778795796, 92.4878098887782, 92.84247844449936, 91.26170050713324, 91.60237404607958, 90.47768931235038, 87.16935834577008, 82.3581555581862, 81.35545653681602, 79.12485168826196, 76.44317426989156, 80.7442492823447, 86.57122042871292, 93.36368299299671, 80.00276442497008, 85.22922854269706, 51.96892584523847, 0.245999688462865, 58.44093468881423, 84.93551361945369, 79.6598865139869, 87.35819693534606, 83.30042654468168, 80.25473748483967, 79.49446447433965, 80.93295451133483, 82.4775681957122, 75.1556170371271, 68.90299027965915, 65.85104111702212, 81.90566309036748, 79.15522652287638, 85.67429988614975, 85.48658309444305, 81.59605472318589, 77.76488750211655, 97.65688973088419, 89.31396130592593, 81.77122777508151, 78.24590344582835, 86.0856310013802, 96.17216279429775, 103.80965294376497, 95.29050811644524, 57.32208251953126, 22.429503125529138, 2.8084734274495036, 0.24148439688067286, 0.725761178520418, 0.42203075883369295, 0.710770063582928, 0.7213211780594242, 1.4497194150763175, 1.1776395502590364, 2.8494063019752507, 1.318548247218132, 0.3601355736534442, 1.3482733166986898, 4.092476502541573, 21.91816333801516, 48.28634585103681, 67.11049848987211, 111.69934365057178, 67.02603417058145, 27.157708560266805, 72.13582346516272, 68.50738002407935, 83.64517150386688, 61.613602638244636, 3.098702834498498, 0.1958196577165396, 0.25005097591107894, 0.22561932883916364, 0.27073703526008513, 0.1776317498015781, 0.12529859063966622, 0.16441998132053884, 0.0834667502391723, 0.15595144622268217, 0.09752082473207867, 0.1031566961037536, 0.19189289019953823, 0.16956305131316188, 0.12566518669407215, 0.1229366496385586, 0.14861002564430237, 0.11669959842918382, 0.1400426958477305, 0.2167469121876263, 0.2003584222327317, 0.15973927603373606, 0.20231642039312472, 0.4001211651390599, 0.27401466583532674, 0.30026356539418625, 0.24494192022229397, 0.13809752199918995, 0.14841926975115655, 0.17327136119767544, 0.205404321633039, 0.14269075536679837, 0.21333619681817872, 0.1624738575229722], [0.22973230168704065, 0.33725111775340577, 0.1843696309914512, 0.10691558311302816, 0.09728388905885721, 0.04330046542529618, 0.05784930248234061, 0.06242399652218146, 0.17861885409201347, 0.09697192273433171, 0.2965737182286478, 0.293155801632712, 0.1483871706671292, 0.13016825151299277, 0.10608639252642471, 0.06205407181574453, 0.005098376423120499, 0.15937812686447175, 0.10257731912837875, 0.020651508783621174, 0.14118179198234312, 0.06618817336857319, 0.14998152221162475, 0.06168430032689245, 0.12051962691569522, 0.1422926501160668, 0.04596210002238232, 0.0470558169388002, 0.038205819850366925, 0.09150600030777917, 0.08049040672279174, 0.0924692562811317, 0.028056914940656676, 0.04880710159458461, 0.0621853792859662, 0.015304138463351036, 0.04727319438731478, 0.04607896290479168, 0.007512182055506856, 0.053319478212224866, 0.18105884413084677, 10.364445447921753, 84.55177245601531, 85.76317294951409, 80.5587133284538, 59.95982154723137, 20.62018632888794, 47.86890368307791, 108.65765540830552, 58.67664560194939, 44.19799666250906, 27.880444488217755, 6.643132048268472, 0.16628825526324012, 1.1815385087843866, 0.4909795606809278, 0.5779787116954404, 2.636627280904401, 3.466033781728437, 9.05803926529423, 1.665173002308415, 0.624913854464408, 0.31647291334886707, 0.2820775573772769, 0.07493394036446849, 0.4025269263694364, 0.3150381838842746, 5.972149833556145, 32.34887330762802, 74.73196967955559, 100.14509231813493, 105.96288511829992, 96.97904140718522, 94.99037619559996, 93.61852722783243, 93.32431808594735, 91.05792553194108, 83.0979851753481, 71.83973158559492, 67.72798938135948, 61.70913196379139, 56.38129418896091, 50.73799979302191, 49.11049073742282, 44.541243276288434, 51.655057784049745, 60.46808619653026, 77.23188446414086, 65.2112554734753, 7.065653195304256, 0.6745689770867748, 21.30892707455543, 80.55708162246212, 63.91157419450822, 74.5893366106095, 65.86939780942856, 63.186139675878714, 60.02527021592664, 61.27369788385207, 59.21240998852638, 59.05971604008829, 53.704351071388494, 56.881502289925855, 63.18391569199101, 70.03904988688808, 78.23331263757522, 78.81751045103996, 91.63931492836245, 83.50247567699802, 68.72450674733808, 78.08614530870992, 93.32193328488259, 91.57642364501955, 67.79553259572675, 40.25350432242117, 18.778117741307906, 7.473425249899588, 1.1852127890433035, 0.8493337347622841, 0.948581099510193, 0.18368326217657138, 0.1435636053042066, 1.2545237666176212, 0.7842047392360626, 0.31561596739676695, 0.19531163417043226, 0.6654216421227301, 0.2723102121343536, 0.6512423965238756, 0.5125389296200968, 10.21847346136647, 24.051877798572665, 22.615747067236132, 55.3878088151255, 70.41899419599964, 37.43384576612903, 15.320776912473864, 72.51637966402116, 67.03365925819644, 65.62147655794698, 25.43523696161086, 0.3774589666676137, 0.10727212809386755, 0.00530393026213372, 0.03619771570928636, 0.04819146184731395, 0.045235626504666386, 0.05249394952589947, 0.0697798693492528, 0.06819682526251963, 0.03369235921831381, 0.057746727139719074, 0.00741297654214225, 0.12348795715238779, 0.07365395299970143, 0.05457808406302526, 0.032627136942239544, 0.05913508147181523, 0.013935177647058043, 0.02768851857962868, 0.028152053484753258, 0.04930045455694199, 0.09990833008721953, 0.07039704510281164, 0.1407624201308335, 0.12520164987372776, 0.08822215675947168, 0.12273565881074437, 0.058710316361318675, 0.06361124894371437, 0.07052170292985055, 0.17637075375645392, 0.18322413036179158, 0.17122454280334135, 0.30067210476244655, 0.08192605549289335, 0.18440598952433757, 0.13741962611675262, 0.11569026992806505, 0.05365182630597584, 0.10699684205915659, 0.0870251750213004, 0.04361983598960985, 0.0014810915496538304, 0.21847056405198192, 0.10722511327795445, 0.20614123692916286, 0.11844856183855765, 0.14580528582296065, 0.10745137734639068, 0.01032846825828235, 0.028505815651207685, 0.0028999621563050295, 0.09581533681240775, 0.06735123273345732, 0.10916539182465886, 0.04461122654198159, 0.05739053455932487, 0.10887034072150147, 0.036206625311845736, 0.0952100967087092, 0.07516037297224806, 0.005343639472078893, 0.12968029947050158, 0.048935291086954456, 0.047170086613585877, 0.026848623829503215, 0.05534000829943726, 0.05595975044754244, 0.011953320635873224, 0.03897078545583833, 0.004672445422564183, 0.11266177880667871, 0.03300846869786901, 0.0758998240194013, 0.06115926962886607, 0.18767468751438204, 24.197939019049368, 100.86826755154519, 93.9251232147217, 64.3035327234576, 41.25396759279313, 34.276490749851355, 94.95818922596594, 113.27539905425041, 35.38001429650092, 51.11081323316021, 44.057505207677046, 13.82576846307324, 0.24769441284719976, 1.040667074341928, 0.5224241604728084, 0.24810437713899922, 2.8365352894029314, 4.156934282472057, 2.5691527080151344, 4.755200657152361, 2.616323131707407, 2.7297659218311314, 1.2537001914555028, 0.29199907015408244, 0.07555043429977472, 1.6234909550797556, 20.608403528890303, 58.28640899350567, 91.65084669666906, 100.83830064342868, 99.0430082813386, 92.61585958542364, 88.7181140530494, 88.07329208620133, 88.23002999828708, 84.49050503392374, 77.06155946177822, 71.81192982581355, 72.40438030612084, 66.9114617378481, 66.04827357876685, 67.14941624672183, 65.99111680061587, 68.82142066955566, 70.28764970840948, 70.31407863863053, 80.76251183786701, 77.81078707787299, 13.543555890360187, 0.5290550498231765, 31.93436311137292, 85.61171454768028, 73.83186417241251, 79.37039990578928, 71.23216429064351, 71.89302875149635, 70.3451987235777, 71.34564630446896, 68.71109224134877, 66.54471228199621, 61.902900972673976, 61.48882419832292, 71.52125081708355, 78.08547066104028, 84.19784130588656, 87.27448571112849, 92.69279295398344, 81.45901495410551, 74.22818045462333, 76.20714956714262, 87.34868126530802, 96.12644364756923, 80.89628819496401, 58.17868894146335, 38.82850331644858, 22.50824078436821, 6.795639684123378, 1.426614571002222, 0.12175162653288535, 0.028023505846278805, 0.6213923014940754, 3.651832779569011, 2.72676702468626, 0.8426839690054617, 0.6057389188678034, 0.5781172816791843, 0.4863161996247307, 0.9765411024132084, 0.6510420492099178, 15.509209536737012, 42.07765356186898, 20.531870242088072, 47.33541034883069, 104.91587115872292, 63.89689276295324, 13.530641486567836, 51.84779520957701, 70.73150511710875, 76.09627200711158, 36.92220003374162, 0.4127869580782229, 0.09641607997999077, 0.0542939726954266, 0.01866101317348019, 0.045042660447859, 0.02891004960533352, 0.08615068565573424, 0.01516436667917597, 0.03896867488360694, 0.018103017712072022, 0.05688100182000668, 0.053920723167398286, 0.06779748661022994, 0.04389280077791022, 0.12474324584247605, 0.02909778519683788, 0.0048946281575838165, 0.036079194246520924, 0.037848826708091844, 0.08419324673952595, 0.08033030200749636, 0.015692575684478207, 0.02621192432519409, 0.033162751144939856, 0.019820512144736225, 0.100831450714219, 0.11632251463109448, 0.10591740885208692, 0.05589941336262611, 0.050107072362856525, 0.09676959891352924, 0.20385424997056686, 0.05893569559820237, 0.2307994008785294, 0.05924174772395242, 0.19621322772675948, 0.3296906573157157, 0.23117504443132111, 0.16342316303522358, 0.19719290096432934, 0.18458552989027194, 0.17033629449865512, 0.18490566271207026, 0.3593210383288322, 0.1416368941746412, 0.3717000385926616, 0.3306766431177816, 0.16586010404411825, 0.23496719497826793, 0.1943504849388715, 0.11315703932796756, 0.14224922825251857, 0.2572032953462293, 0.1861773073793419, 0.11108380622200428, 0.1965229417527876, 0.1462711438897156, 0.19217753782868388, 0.24048048462117874, 0.1900755304602846, 0.2804799882634994, 0.08965244291410332, 0.2716287616039476, 0.15133916790927612, 0.19941610344234975, 0.14565024494884476, 0.14527812540050478, 0.1444256687236409, 0.10967877032535692, 0.1459701632660243, 0.11519880920288064, 0.17992909426891035, 0.12879176005240411, 0.15995329035626304, 0.14023352834966876, 0.28914269600664416, 31.531825950068814, 117.78872920620827, 106.04182674038796, 102.44915531527613, 76.79867436808925, 37.216781800793065, 65.47281480604603, 123.57633544552712, 73.98229491326117, 62.41484480519449, 46.85631636650332, 12.204879387732475, 0.31595804097671665, 1.456619231931625, 1.0075710954204684, 1.2085175514221191, 7.289276834457152, 14.472628101225823, 26.555373707125266, 10.939752228798406, 1.5556528275051427, 1.3275891878912527, 0.7996368143827686, 0.2576173811910614, 0.3172064578581241, 0.45404112987941314, 9.034896300685022, 38.998220351434526, 84.15729184304514, 108.13377580335064, 113.71611656681185, 108.27445553195093, 105.29840423214821, 101.47866679776101, 102.27276632862707, 97.2458645605272, 89.18432697173088, 83.33494340219806, 82.41172728999969, 76.842008713753, 76.59469542964813, 78.87044675888555, 80.09122171709615, 75.55835031693982, 78.54287393631475, 74.62877996506231, 89.68846136523833, 79.13406141342656, 8.946616495809248, 0.6348596981936886, 29.404606934516664, 92.13583207899525, 80.3813123703003, 87.24847255214569, 78.98218724035448, 82.38966788015058, 79.22579780701669, 80.34669353115945, 76.64090879501836, 76.63217759901478, 69.35736548516059, 72.05592478475263, 78.6627729477421, 87.33280351085048, 92.0862925437189, 91.41542603892665, 102.7182455985777, 89.66953200678672, 72.50704442301105, 83.31020109115109, 96.34975202621953, 100.59122270153415, 75.37206911271619, 46.214408720693285, 22.099439597898915, 10.580372906500294, 2.58509420098797, 0.7084100837669065, 1.4175849071433468, 0.20318635919642067, 0.45123914797459885, 2.8494158627525454, 5.053010534855628, 1.2290197803128151, 1.040219801568216, 1.84618168300198, 0.5805008570032736, 0.7923429218992111, 0.7683349520929399, 14.872873617756753, 41.85349402889129, 36.19520048941336, 72.29152587152296, 86.45581645350303, 52.51634751596759, 27.363121125005907, 91.8010420953074, 82.76026910351169, 86.74709166249922, 45.5955881457175, 0.650108034812635, 0.32288252586318605, 0.13645095390177545, 0.11285564501679714, 0.08152962031383669, 0.15006073570299536, 0.17667941058114653, 0.21732031367719176, 0.15662679869321086, 0.10684649730401655, 0.14931468863881406, 0.14489646039662823, 0.16069860197603703, 0.15629047077269326, 0.3128332602641275, 0.17953955388117224, 0.15318531723272416, 0.16867699401993907, 0.15515552683463021, 0.15456730920460918, 0.20764594086475913, 0.1308794722201363, 0.14441103644428716, 0.19431257890837808, 0.14215556634289606, 0.1886056069164507, 0.17333968091876278, 0.26856879192975264, 0.2322173989828556, 0.2933054952131164, 0.23695310938262173, 0.19578408059333602, 0.13201424761885597, 0.2828279558208681, 0.1938160007158595], [0.31123127848390614, 0.2505696480793338, 0.26652419519039894, 0.055174843573402015, 0.026767138887437123, 0.041473043121157155, 0.08337268230294989, 0.044829032999733766, 0.30101607824044846, 0.28812444258120756, 0.4868254948767924, 0.26835909834311855, 0.35986082388028023, 0.12882951286531266, 0.02370705621527328, 0.087732833419596, 0.05868085645019047, 0.1264186724719982, 0.06439070893271316, 0.01709384625897773, 0.0841985327462035, 0.0493238470517099, 0.08601360188256349, 0.11259785643027675, 0.02480052032267615, 0.1189408882430965, 0.05817116283240819, 0.10353433914602765, 0.030661341921997168, 0.07246917504216395, 0.002898987309421383, 0.0332191352161669, 0.025891722555482583, 0.06781279304695707, 0.0488520403122229, 0.02425704988831234, 0.01338374085589162, 0.11933746131797952, 0.040622800438394474, 0.07884967621536025, 0.17724645354094046, 0.05532911835959362, 3.8641268976273078, 54.29273797619728, 79.50974602853098, 78.68010982390373, 62.25788331800892, 34.52669874314339, 38.493674109059, 92.5162313830468, 75.45612550550892, 57.15145941703551, 34.61935297135384, 24.273344624427057, 8.196570084941003, 0.17609433391161505, 0.24738975500147192, 0.14553802838969618, 0.01796825135487222, 1.6179410464340642, 5.294837893978243, 5.509708273795344, 5.689723981964973, 1.7019361521928542, 0.3734311215098827, 0.3805034920092552, 0.29690371826291084, 0.4433764811725386, 0.9635714790032757, 1.6936351911675547, 13.677586220925855, 39.346671950432565, 63.23250209131549, 76.45021884672104, 84.38478146829914, 80.26788526965727, 71.40825517715948, 61.89799800995858, 53.14906112609371, 43.93348770756876, 42.61411613033664, 42.08504722964379, 39.086414844759055, 35.37721372419788, 23.121052288240005, 35.261429279081284, 41.291720405701675, 40.703502162810295, 6.182340335461402, 0.13606999369878925, 0.057770763148343375, 2.2098719352676026, 63.02212968949349, 53.005667117334184, 61.1118059773599, 54.83296209766019, 54.02187478157782, 50.99160455888318, 52.08900528569376, 49.8466686279543, 52.10612250912575, 54.204390510436035, 60.28271105981643, 63.811263499721406, 73.64807759561847, 80.28241372877552, 89.102474950975, 80.98588297444006, 85.20485493444627, 99.88928318023683, 84.24461164782124, 37.58631613946731, 9.575311637693837, 1.9594545854676155, 0.11060606613154374, 0.11982730559764371, 0.11505799458151865, 0.646825562561712, 0.3179484906215822, 0.434232302490742, 0.500205005969732, 0.6055739954594643, 4.470573865598248, 1.6643461176464636, 0.9250674709197014, 0.3544041021696983, 0.14209360515158023, 0.08091293485654939, 5.539876693679441, 13.88729868396636, 36.38017554436961, 50.714143937633885, 85.68371357456331, 54.31223607832386, 20.92110272376768, 28.600375921495502, 62.15640375691076, 57.112820148468025, 45.565503566495835, 12.659130057980938, 0.2610827339512687, 0.14604052078099022, 0.06536757828848017, 0.02833706180324718, 0.01757367202381213, 0.06429291780917876, 0.11120593595889308, 0.045236909701939554, 0.05212562211278466, 0.07520061557091053, 0.015652240197654935, 0.04719118850546018, 0.09425102357542324, 0.059344541401632374, 0.07687830982068855, 0.017707607175614086, 0.12445103692551776, 0.021414258479771596, 0.03923535392048859, 0.008764033404839857, 0.14211566848379953, 0.09999819220073762, 0.1745403245572121, 0.19997436703453142, 0.11745850044873454, 0.14633096003484342, 0.16735763739674323, 0.0527984235105255, 0.1698341851513232, 0.1744571733739107, 0.08499442915161771, 0.13116585120799082, 0.09996767891871353, 0.2049063798040152, 0.18243930392688323, 0.2339008312311865, 0.10198475011894781, 0.17354744396382765, 0.1713339401589286, 0.06510664108059099, 0.10006497974597639, 0.01779838667942151, 0.029326602253281785, 0.14853766097897483, 0.25214037347224455, 0.2550495004341487, 0.35270485786661027, 0.29058762976238806, 0.23391874236685617, 0.10867672732039806, 0.026745240264121565, 0.05780868450059526, 0.14022189913497818, 0.0896681706991888, 0.04208629650454368, 0.011025963542652468, 0.08221840996655726, 0.054960622407135465, 0.07056227494632045, 0.04369968916439722, 0.028669725908266924, 0.011915550585986387, 0.11848185601974688, 0.08819910517383008, 0.03650801579257654, 0.10647475313875945, 0.03285389513738694, 0.04521668115029893, 0.042623542474522706, 0.01692928099674323, 0.07380583759156928, 0.09126790784179203, 0.04916814351153951, 0.05457577430793355, 0.11540321678283716, 0.03294288774111098, 0.1267354728113259, 0.024506794551627773, 13.989548990803382, 74.20554837872906, 88.7440566093691, 80.97649282024753, 38.44895124435425, 18.71544218832447, 63.97898012591947, 113.0839873898414, 78.35132106657952, 50.74527578969156, 39.39878848291213, 35.13252450573829, 10.079274427506233, 0.715664507400605, 0.9989534642907881, 0.21197340300967618, 0.13004805231767316, 0.6395882380104835, 2.442401561044878, 3.9579818614067572, 3.67030885911757, 3.9620714226076683, 2.6761167232067358, 1.4496582506164428, 0.7883682125999082, 0.8771540032279107, 2.7426119292936018, 9.190988982877425, 33.0877576335784, 62.91457437699842, 78.62631059462025, 87.25288914095971, 94.22698097844278, 90.11116735396847, 84.07558887235581, 81.31384018928775, 77.93964478277391, 75.68508209720736, 68.12268964705929, 64.19858970949727, 56.42385190533054, 54.919050278202185, 46.82692604680216, 64.94089826460808, 69.24903746574157, 74.45324605511081, 17.25159206698018, 0.1258185421747546, 0.06718013465644852, 6.561891917259463, 76.4213345127721, 62.498697234738266, 75.30906015826811, 66.92773957406321, 71.15225776549309, 65.90005505469539, 66.96447649309712, 65.29776726999592, 70.34239815127465, 66.70356827397501, 70.19057104664465, 73.13856171023461, 76.01539273415843, 80.22240146513909, 83.92322048064202, 81.86418794816541, 83.44830774491834, 93.45579593412339, 96.17368467392461, 58.54703480197538, 24.89093945872399, 8.13964472663018, 1.982936344800457, 0.4348820063375658, 0.16928843943582428, 0.55066718689857, 0.6340071955515493, 0.27804980415009684, 0.3629164728185823, 1.4999082251902551, 2.6230772079959994, 0.6219711575296618, 0.23104945197701457, 0.42169962498930197, 0.3316349884675395, 0.2284087009367443, 9.736094494019786, 34.40325390908026, 44.304108542780725, 45.49013522363479, 89.38653299885412, 87.62010928123229, 29.34476725516781, 14.817136737608141, 49.75605795460363, 67.08494817056965, 56.66400686387093, 18.835235295757172, 0.2183553750716871, 0.09628575310231217, 0.11906102615138216, 0.04213495457905435, 0.04722049136856391, 0.08126111415725562, 0.06699967498500502, 0.09867744895839885, 0.058685525756088965, 0.10560162740969851, 0.07751998506606587, 0.050319179126452056, 0.015440905267643112, 0.13138479913675016, 0.04408253777411677, 0.0736314683191238, 0.032144570497856025, 0.021731533793612354, 0.058594100823205326, 0.08168581798071824, 0.07441377432476129, 0.05999589233749336, 0.0226290536774022, 0.08010395366938845, 0.008668507986341514, 0.127027896232903, 0.1316783027423005, 0.04959293543511341, 0.2029348218873624, 0.13145033029779313, 0.18663031049072745, 0.10783589985822478, 0.09810613122798743, 0.16313067066573328, 0.04005892525216745, 0.15960269787859532, 0.3284047940565694, 0.17804775086622085, 0.40833895965929956, 0.15382234998528035, 0.23252216408089285, 0.08117109882615267, 0.12594766629439208, 0.25430907645533163, 0.3979936470427821, 0.3021212060364985, 0.45363249858060195, 0.3361098306073297, 0.380333359203031, 0.144369162078346, 0.19268859508297137, 0.20273688008948682, 0.37387401226066774, 0.16693187637194512, 0.17598242378763615, 0.13279875229683616, 0.16914571725553082, 0.17253348063076698, 0.1456799078732729, 0.1804444722590908, 0.13090315965875504, 0.2148960437625647, 0.1701407275733448, 0.2628645931761111, 0.26209568604826927, 0.222819798415707, 0.1136223228287793, 0.16091515971047265, 0.1864711787070959, 0.12758360875229682, 0.3923804901780621, 0.24066132733658438, 0.2825421743815945, 0.29640196131602414, 0.22254552361705612, 0.1550952816802648, 0.44100574548206023, 0.14808649647860758, 15.29344975948334, 86.51105127026959, 106.89029032184233, 98.57026853869039, 82.93994503636515, 50.22496161922332, 55.0046677743235, 108.72346493505664, 92.57636131778841, 74.00455828635924, 58.45464337256647, 43.6765097033593, 12.851334041164769, 0.6614322852223151, 0.979121225255151, 0.2002763588942828, 0.28663290003615044, 4.125291541699441, 15.30490602216413, 17.39224826135943, 12.087156311158212, 4.661832067274279, 1.5774517674599926, 1.272561398725356, 0.4788742989542023, 2.2575674662666936, 1.6265435396663606, 2.8731805230340655, 16.149787499058633, 46.037788314204064, 69.79398804326212, 89.08727968892744, 96.29022613648446, 92.91122190413937, 85.67110707682949, 89.76495542833882, 89.31829160259616, 89.493605859818, 82.40400022076022, 80.89568414995748, 72.62593146293395, 68.064160039348, 62.29746787778793, 83.20324590129238, 79.40911369939005, 73.30516046093356, 10.20112285690923, 0.2857900194583401, 0.12457590159629622, 5.457462303100094, 82.36339584473642, 69.27829834722704, 85.1381903309976, 79.99286436265515, 83.56064442665347, 78.26671554196265, 78.26245584795552, 76.19745346807665, 81.19600434457102, 80.2261120273221, 86.55441699489471, 84.68063016091624, 88.19753708377962, 91.48752704743417, 91.48114142879363, 82.44768757973948, 85.05757777921616, 108.06535397806476, 93.40297729738298, 43.85488340931554, 12.974876934482207, 3.1173600785193907, 0.6150383069630593, 0.1453968077417343, 0.13254799639746068, 0.7460065534518612, 1.1247718838914749, 0.2639410079967591, 0.7882759756138249, 2.636868016373727, 16.565089033495997, 4.8235494282937825, 2.226104173929461, 0.43374697046895183, 0.5056917276834288, 0.20914235572901466, 7.843565594765448, 22.287750628686723, 56.85708161323302, 68.66262743549963, 104.37830248186665, 68.97900581359863, 31.45140951679599, 42.10969148143646, 77.97932347943707, 80.68472339260964, 73.44632656343522, 27.027126973675145, 0.41517568151316336, 0.2235043439413271, 0.2912411946923502, 0.204646767928235, 0.10421392042189838, 0.12759271753771653, 0.28874270617961884, 0.26493486918268666, 0.13012058552234404, 0.20114021495945994, 0.20224495971154785, 0.24428236448476393, 0.20726783050885125, 0.15099744672977156, 0.1739189659635867, 0.16768941475499063, 0.1913204233372404, 0.1294410502117488, 0.2209504979151872, 0.1491357458214606, 0.14005475407165868, 0.14954381021520785, 0.170517428327472, 0.24896952023188917, 0.19591915721614517, 0.19844370804006056, 0.24876788589021853, 0.16612703972045453, 0.31009219767105195, 0.25897295845131724, 0.32643512071621034, 0.4031762012070225, 0.2972365987877692, 0.1757612388821379, 0.15472647163175768, 0.1868645954997309], [0.18553132671983014, 0.11789612051460052, 0.05795668119624738, 0.027190722307310473, 0.03550018116291012, 0.08622605338572495, 0.11600668722343062, 0.11603465709354609, 0.16941121268656947, 0.1699310952737447, 0.22853377245126233, 0.2755727048122114, 0.317926335358812, 0.3098138013193685, 0.04618992691018409, 0.0719605616083549, 0.11976299251640037, 0.08826977678484495, 0.05562070674533325, 0.025055158372607925, 0.03757244516764918, 0.046992894307139425, 0.13771070888446224, 0.09841876404900705, 0.0700494020636524, 0.036357506328532775, 0.14403657266689887, 0.015040334171405243, 0.031459452321512565, 0.027400023273883328, 0.04985334787277445, 0.018838628743504806, 0.06070656529177101, 0.015384239659103897, 0.06849397544658954, 0.017522550976624893, 0.03253219566578346, 0.04414223900605594, 0.040034437251667825, 0.06281594242600184, 0.18187837434872506, 0.058959926959247365, 0.14881651698341294, 0.3934859550527988, 32.465171583237186, 75.50295860536637, 82.87455128085229, 90.89634741506269, 59.424790643876605, 29.436442852020267, 55.30049685508975, 76.16587054344916, 85.6734997226346, 60.37922882264661, 60.04620782790646, 29.563619821302353, 5.311304984554168, 0.28676402364527026, 0.323608685284853, 0.2074055577958784, 1.1949571822920155, 2.127210190219264, 3.184541944534548, 6.838540117586813, 6.463819915248502, 1.973345414284737, 3.1568470693403676, 40.83937306557932, 48.81439101311469, 4.518694973761036, 0.733570923968669, 0.31224508859938194, 1.5319081467966882, 3.697462202079835, 6.446788493664035, 8.915958269949883, 10.217478159935245, 10.7270783762778, 9.2473259856624, 9.364311656644269, 8.660051072797469, 10.265794896310377, 10.192740751850991, 14.018476470824211, 14.311035275459291, 10.51436726124056, 3.380224824913087, 0.1350484460952782, 0.20480450543184436, 0.3075487857624408, 1.2997430562973022, 0.25851459272446176, 22.292400598526005, 57.955007937646684, 46.1825551525239, 46.17346309846448, 39.413026686637636, 36.22499481324227, 34.17878058648879, 33.13376703569966, 34.928129796058904, 40.96756004518078, 47.38188651300246, 61.015809889762636, 78.77338378660141, 97.31450603854273, 102.49907139808901, 109.05508564364527, 83.82852661994197, 36.79253432058519, 2.6348857485478927, 0.16085224857013072, 0.2323380118656543, 0.6917294078776914, 0.1835894317276055, 0.5120755077129411, 0.4611894350138403, 0.1550381928081474, 0.07666721429315305, 0.9028788680030454, 1.7630681299394177, 0.7368176045917696, 0.6484789641634111, 0.634577164967214, 0.031506725692100106, 0.2666744709976258, 2.077923402670891, 20.184989552344046, 17.354793548583984, 43.82464585765716, 76.92058163304483, 57.306043947896654, 30.365103214017807, 21.6167389961981, 61.93240504111014, 71.23250945921868, 59.38382933216711, 37.052316819467855, 3.257638989917694, 0.12573455595561575, 0.1506123190084773, 0.021547925500800053, 0.09514529333119431, 0.0963832990777108, 0.11217598713213399, 0.038381721298660965, 0.11414782084043949, 0.12093331439480667, 0.03404712687516886, 0.05445307383554117, 0.0436221725577789, 0.10810101990618053, 0.10303275839936349, 0.07546265594541066, 0.12255750506395295, 0.03703424924864404, 0.08034949250999959, 0.02514116323342727, 0.032211894304641796, 0.05224083790615682, 0.13890232800716354, 0.13724106634336133, 0.14137116891722526, 0.05286392402805148, 0.18629487123220198, 0.23305900785471165, 0.22143458887454004, 0.07332795960528236, 0.15910078771412373, 0.11607691450344941, 0.030789521838267966, 0.052753013648813775, 0.019841286534022902, 0.1469998467232912, 0.145846440066253, 0.18766037699195648, 0.2178136589786699, 0.11756759903003132, 0.12982616261128457, 0.03325930120603692, 0.03893489806702541, 0.035569301445878325, 0.11084399005818753, 0.15155430072017256, 0.17461924693517147, 0.2017122221690032, 0.141975688898275, 0.27848261318379836, 0.2113783212318536, 0.1793397428287614, 0.18184486566291702, 0.12971629028118428, 0.09677189717730207, 0.09026482295725616, 0.06793788754411283, 0.018532800698472608, 0.053888087821823936, 0.10948950830366343, 0.0897415849049726, 0.031232931613621694, 0.05778874706236586, 0.023877332662983287, 0.09905606493233673, 0.07808859850610457, 0.08466071359092191, 0.06260498862473235, 0.022982566865281235, 0.09280488706163822, 0.030879812961023663, 0.03418528700187322, 0.07740849629044533, 0.03304188545312613, 0.07717443344693992, 0.039636910397319064, 0.03520146049859543, 0.12624663210684253, 0.14733280385694197, 0.20365820807074347, 0.3279160299608785, 1.0400371662070675, 48.393222593492084, 91.15638486800655, 89.72806161449802, 75.00740635779597, 35.519148611253314, 34.56547921703708, 69.22599746334937, 93.93969089754167, 80.05170775998025, 58.74045079754245, 61.12695809333556, 38.460777190423784, 8.37975065554342, 0.5579140109400595, 0.6313255813813979, 0.3005146583722484, 0.527664018013785, 1.1815932993927312, 1.4972859981559938, 7.442506676720035, 6.426545631500983, 3.675019870842657, 3.972367399161862, 26.81299105767281, 21.871834262724846, 0.695924750499187, 1.4149897689780881, 2.2937562340690247, 13.064861009197852, 15.739144759793437, 21.405285981393632, 23.60675154193755, 26.10015126966661, 28.734862227593702, 29.3162339733493, 31.178357639620383, 43.54575749366514, 44.463148886157626, 48.36646026180637, 44.34856468631376, 40.11913960979831, 30.77411032492115, 16.86316171000081, 3.5168980975304884, 0.4531513034336029, 0.354092488245618, 1.1416265536700527, 0.15601887728177732, 47.02522539323377, 74.49511343433012, 60.85487896396268, 60.144016050523334, 55.67768766034035, 55.20670121715915, 54.84223850311772, 55.33881056693293, 55.38266266545942, 60.28111857752646, 65.95216766480478, 77.60082260254892, 87.45338501468783, 95.12984783418717, 97.74608442860266, 100.03867841536, 94.4738628018287, 58.41383895566387, 10.555267776212386, 0.781370152629191, 0.05325866615279548, 0.8390103629039181, 0.7511305172116526, 0.34979320281455595, 0.0858594190269228, 0.1433234980269786, 0.0354162217568486, 2.347907986371748, 2.1601159341873664, 0.4848329614727728, 0.6175188383748454, 0.44493537816789847, 0.0498308057356025, 0.5171843642188657, 3.2588755171145163, 29.506543451739898, 27.245740275229178, 29.448690452883323, 73.65738930240755, 87.0008062547253, 50.75845887584072, 13.085385791717037, 33.040983369273526, 63.47159408753919, 68.83205029272264, 46.04125961180657, 5.904538468007119, 0.5147730258684005, 0.08182182923079499, 0.11664873019101159, 0.1077485275304606, 0.10787003673613073, 0.07806553159870448, 0.01931914398747106, 0.020155024436873295, 0.09592170812069409, 0.00816845750030611, 0.04746533689960357, 0.013134616723794852, 0.08409239126429444, 0.1926557605545367, 0.12304849081462431, 0.15133739058529178, 0.009544796700919829, 0.05837971111759544, 0.06661855390355473, 0.038429758841952974, 0.039128013510978034, 0.10965836174305409, 0.1023400616982291, 0.13558345125807872, 0.1500128705294863, 0.2081809766710766, 0.31905303619080977, 0.3095317890326823, 0.17587294982325646, 0.2756254729484358, 0.1992281207874898, 0.16793404195097186, 0.25619092547605116, 0.08543373461091712, 0.13085855801980342, 0.24416234915054616, 0.18713845661090267, 0.31575965484784496, 0.17585840947445364, 0.14937099610124865, 0.1936722519777475, 0.10752868327882983, 0.1572943370669119, 0.27920711785554886, 0.1891304077880998, 0.22719492655127282, 0.21149387793435206, 0.2833357495405982, 0.46300016043166964, 0.19611454028035366, 0.2245527352657049, 0.16162471034594122, 0.26363638079454826, 0.2033443265264073, 0.15123764593755046, 0.12163765563239014, 0.12113596763341658, 0.1602748787451175, 0.2516931160202911, 0.18671710825254842, 0.12798085598455322, 0.13053772039711475, 0.1369822818425394, 0.29984745707723404, 0.19532718575529515, 0.13878468754551104, 0.14177554076717747, 0.17632219910381303, 0.20097189012073702, 0.20791935764493483, 0.1311269952284713, 0.21391800995315277, 0.10415189028266938, 0.1141213678244141, 0.1492311544115505, 0.1957327833459262, 0.27888762854760696, 0.4141340470842777, 0.2661595679819584, 0.3856780175720492, 1.5468243076916666, 55.87843064338931, 110.08379782399824, 105.75558000995268, 110.06864963039276, 79.8894157717305, 49.28579714990432, 70.30036603250812, 93.08324921515681, 97.53859104648714, 78.28522128443565, 78.88601856846964, 48.12652495599563, 9.968336070737532, 0.4260415968395049, 0.8658900592596301, 0.5948776919995585, 2.571434792011015, 7.535060394194819, 14.045788914926591, 20.551646832496893, 18.327972812037316, 4.566543967493119, 5.105206985627452, 49.80644864420737, 62.90547840056881, 6.263486329586276, 1.1131030777769706, 0.5330512095843593, 4.509905922797419, 4.924064576625824, 8.096532485177441, 10.6080501310287, 12.953720650365277, 18.31063985824585, 20.50774766552833, 26.391046008756085, 43.55692448154573, 51.45736640499484, 60.13940726557086, 56.82081145624961, 51.8644731275497, 34.6223339726848, 12.492316557515053, 1.5016159271040272, 0.4888252907943341, 1.2435228665990214, 2.7387537879328576, 0.3999335655281621, 43.34780723817887, 90.85395443824031, 70.36359463968586, 71.39204794360747, 69.54998523958268, 69.91502454203945, 68.5583237678774, 70.58209419250488, 67.92028750142744, 76.19037751228579, 79.7378553882722, 92.38023496443226, 104.09284807020619, 114.23072368867936, 109.09634897785803, 119.23161229779645, 99.16157368690737, 38.30353721495598, 3.8118179238611654, 0.3160548744903457, 0.3496656951404387, 2.0391057888346333, 2.3455820208595646, 1.15330504313592, 0.6741310199422221, 0.17049481341194722, 0.1775153504023629, 4.1399901336239235, 5.949841353201098, 3.7142411210844597, 4.361998736858368, 1.1196061223745346, 0.13637206216733302, 0.5754892936637325, 2.8164726111196705, 29.502491643351895, 30.906721738076982, 58.565116928469756, 93.30666742017193, 72.53221035003662, 46.312640559288766, 29.913675669700872, 77.24290632432508, 84.73020107515397, 83.90960985614409, 57.46568049153974, 7.1970143529676625, 0.5851577522773898, 0.2083797764874274, 0.35724843341496687, 0.17792339947435165, 0.22716857312667757, 0.26671709612973277, 0.11205230989763815, 0.15828445974376895, 0.28373622966389506, 0.058748992310175975, 0.12483641745582705, 0.12033230309645015, 0.2889930637132737, 0.4115224227068886, 0.15040228834315655, 0.27470769961514785, 0.17734267418423008, 0.11695610764887064, 0.14570126640460185, 0.171907939197075, 0.30784483277989977, 0.14365285454738524, 0.20135332529823627, 0.14384299757019167, 0.1651693838498285, 0.23814094403097708, 0.42539290422874115, 0.5886289273058215, 0.32470137181301273, 0.26246742255264716, 0.35253166070868897, 0.29808833534198426, 0.4301573582474263, 0.16398073714827338, 0.22677563130855563, 0.28164189849649707, 0.47542000850362165], [0.021152298544503508, 0.05345762301717074, 0.04159350278637102, 0.051744612114083384, 0.06656777759593341, 0.11087991192095703, 0.023582555436258836, 0.025791920451146942, 0.09161332922597086, 0.23483230221656062, 0.30497586414698635, 0.4680413560521218, 0.5647765652787301, 0.2143626933496806, 0.05748011705075061, 0.0337112394552077, 0.05497144722950555, 0.07114194303510651, 0.049375577138796936, 0.012546819484522267, 0.026445952694742914, 0.11089036136024422, 0.08245136198257247, 0.1347130528020282, 0.08764821900835923, 0.10545085364532088, 0.04173132966482832, 0.10653109890559029, 0.08465398733894672, 0.07765237272026078, 0.07144051814271558, 0.05288070901447246, 0.048116515465681596, 0.09487527032052318, 0.029971786181352315, 0.03544828636691936, 0.08147159681445168, 0.020427778550994494, 0.06487430193491521, 0.17041763771445523, 0.12175885074201132, 0.08478433719926304, 0.05439461366603932, 0.09662363618131607, 0.3886577012317796, 8.084604557483427, 50.09583719315068, 73.7030456912133, 83.85377883911133, 78.0773905784853, 48.59693481076149, 41.31069683259533, 53.02021911067348, 75.21068711434641, 82.55555275947818, 71.7498073270244, 45.81215789241176, 23.897505075700824, 2.2998815053893678, 0.16071020054721064, 0.3594276777678921, 0.2149227495876051, 1.3275807302805687, 5.706163615949693, 3.988926175140566, 4.565514835619158, 8.239990722748542, 69.32330362258419, 85.53928406007829, 1.7234230185708694, 0.16501599772562905, 0.18346989136790076, 0.09284999431861986, 0.09804777831079499, 0.33705763458724947, 0.15487834090186706, 0.23156542751577594, 0.26978794425245256, 0.2745001817182187, 0.2480993975674914, 0.45653036405001923, 0.7782866180904451, 1.1996161000382517, 1.380383800114355, 0.5170459168091898, 0.18445797625087923, 0.7319444886619045, 0.18242491679566522, 0.25893471534213713, 0.5207577047328795, 0.18860669476130318, 0.17773411447002044, 0.19172586771028657, 17.22334315699916, 33.2670295623041, 27.910319220635202, 18.59502346284928, 13.239708504369183, 9.996925246331001, 12.100711041881192, 9.216577545289072, 16.185421251481582, 24.47742554449266, 43.958045667217625, 56.231094867952415, 70.68146351845034, 68.62703584855603, 41.25652105577531, 5.226429796987965, 0.5065459157190015, 1.186047028149328, 0.911888920011059, 0.3056550777006534, 0.08880048419439024, 0.0345315051174933, 0.11581587770413007, 0.04503810605514915, 0.1212943792943993, 0.04339451803976009, 0.9970421668502593, 2.1519240640824844, 0.3683092415092453, 0.3443165934614597, 0.16379180454438733, 0.5746384457715097, 15.824873062872118, 28.961443824152795, 47.57068195650655, 76.4244096509872, 87.69636800212245, 34.34740720256683, 20.192385181303948, 45.58900248619818, 78.14618895130774, 64.47791737894859, 44.22456287568615, 15.169633280846382, 0.35550625754460213, 0.05236490201505442, 0.07536956860173134, 0.0530026319076217, 0.11258998104641516, 0.12111802585422994, 0.08395674007554209, 0.012283746806544163, 0.026780888250458146, 0.09709676442247245, 0.03994036931544542, 0.018224228143451676, 0.058411457801177624, 0.03811534103606978, 0.07793432371991296, 0.04494810221536506, 0.05386342745154135, 0.04864772083237768, 0.04292498658140821, 0.1122641868348564, 0.030288661214252634, 0.09083067848076744, 0.03346431782589324, 0.03636257016971227, 0.029037264250819723, 0.0425518443056893, 0.06972637342950029, 0.058582203477741256, 0.07521167021965788, 0.05081239419298307, 0.07154003296407961, 0.029125645899424152, 0.06133400279307558, 0.013417993604596104, 0.07873434167835983, 0.01310782950191248, 0.044080009683966644, 0.09179022658856646, 0.04807033185516635, 0.037355282223753394, 0.08494526928951664, 0.04090756681116839, 0.016911561383054625, 0.029514161644563563, 0.16654538501414562, 0.04963865556243447, 0.098827671139471, 0.17105372051798529, 0.4516410070561594, 0.46722715780619656, 0.6423121402340551, 0.6362292182541663, 0.42891795056000837, 0.12295603166304289, 0.057585906132214496, 0.09606437667483285, 0.04800480835500264, 0.04668567006686523, 0.05216310296448008, 0.052618879314151504, 0.049594007958207405, 0.07470485709247089, 0.08776484823395168, 0.06867824257501672, 0.09391462670699244, 0.08830549946475415, 0.07726830986118124, 0.05694816474832835, 0.058786867697152405, 0.02602236352921013, 0.022666988436192758, 0.077526236343528, 0.0995278831631426, 0.023203249983189088, 0.06478876055729005, 0.013350987724298912, 0.03322315334732975, 0.012980460681231513, 0.11748516796937875, 0.12583819233001242, 0.02506612875168362, 0.15688565980282523, 0.062305586142165054, 0.26743868966737105, 16.739428581730014, 65.24529772420084, 87.82284875069895, 93.16909420874812, 62.13868641084241, 36.68497508571994, 45.07250478190761, 71.07015471304618, 88.18569937059956, 85.26622433816233, 66.5203857421875, 44.41013805327877, 25.609372546595914, 3.7410573853600413, 0.4577572078954789, 0.5108270601880166, 0.7838185083481574, 0.2020791169976996, 1.741313806945278, 2.302704631320892, 4.1473033928102065, 9.743976496881055, 77.54378349550309, 86.91164293596822, 6.142550831840885, 1.4353883002073535, 0.14078359480106062, 0.23232466661401335, 0.5491259405689856, 1.0807647291691074, 0.578463553420959, 0.6530291587114334, 0.6754954531788827, 2.0042871539631197, 0.8788780687797455, 3.72166175515421, 4.341634281219975, 6.757315676058493, 7.779200480830285, 4.739008132488498, 1.0725001726419696, 0.5321366844638702, 0.4668568921906333, 0.26308706510932217, 0.8114633120356068, 1.2830957818415858, 0.15097066429593872, 1.380118427257384, 40.65890873632124, 53.80041383927869, 55.24734089451452, 46.70061003777289, 43.14665632863199, 41.64105453798848, 44.258165820952385, 48.47052858721826, 56.83965060018725, 61.597701349566066, 71.12448738467309, 80.62176150660362, 89.69461948640885, 87.20674637825259, 68.59134227998796, 17.27585388768104, 1.5046854269120002, 0.757107473909855, 1.7546415304945362, 0.4185770506099348, 0.19472554626484073, 0.04082911557728245, 0.2108872741941483, 0.5658140321893077, 0.0748111671137233, 0.17919682146560761, 0.6979969264038148, 0.48494281848111465, 0.0329582286517947, 0.1785596048519496, 0.38113294049136104, 0.6071135870391323, 15.165615793197388, 35.21294486138129, 52.41905312384329, 55.25227131382112, 94.32425575871622, 64.45456358694261, 20.42654479703596, 22.58352283508547, 58.86922613266976, 70.89935902626284, 55.142684213576786, 21.63686663873734, 0.3253327814802047, 0.31286157487380895, 0.0768391780495163, 0.08552874483528637, 0.06956934072678128, 0.02321188953975516, 0.03403863479052821, 0.07659525565442539, 0.05589438782584283, 0.11416556343676583, 0.011772257670189345, 0.02297693420381796, 0.0556558663506181, 0.03576155504091613, 0.0932210107003489, 0.08775265977507637, 0.1508199288359573, 0.06113506891133805, 0.022533258212910547, 0.07573064882308245, 0.030662039062008265, 0.06365207376919928, 0.10410643828612182, 0.04634585644629213, 0.116448390537933, 0.07962025341487701, 0.04871699050249112, 0.005105212800234797, 0.046257572473898056, 0.07706413976848125, 0.05996941250839061, 0.1129347972211338, 0.07465110836370338, 0.06946946584409283, 0.02848679560326761, 0.07146795941216331, 0.04294622253866927, 0.06828345448499726, 0.028777047165579377, 0.1678561614525895, 0.31037031823108274, 0.11797494330112973, 0.27344993646106414, 0.14352183819057482, 0.18885386536919302, 0.2065115025447261, 0.17190839884982956, 0.28548125538133806, 0.6864730028375503, 0.5808955455018628, 0.6758110814036862, 0.6009026977323717, 0.5245775416974099, 0.1915216439914319, 0.19979738540226416, 0.14743398874998093, 0.129890130952962, 0.12174578894290233, 0.17464684142220407, 0.14127087268617847, 0.11744900095847347, 0.24163605164616342, 0.2501528656050082, 0.15172883087108213, 0.1705453139279158, 0.18750195000921527, 0.2511208789843706, 0.17266913948039855, 0.15608371896368844, 0.2003205468457553, 0.18000775617697548, 0.152060654194605, 0.21387909268659933, 0.18669873746412416, 0.1375214392018895, 0.2571761145466759, 0.15684540954328355, 0.22557141770037914, 0.27268348081458, 0.35412448007733593, 0.21615477218743295, 0.25826135470021155, 0.19100628132300992, 0.3840061992166504, 17.021635270887806, 74.47062999971452, 103.03985641848658, 108.1651939884309, 93.21207554109635, 66.97068952745008, 59.4736869104447, 71.75176066737022, 86.70655788913851, 96.71158282987534, 87.79716507081064, 63.0719869367538, 33.07078553784278, 4.194745440636912, 0.7885048826855998, 0.4888959547444698, 1.6225434575350055, 2.5968054177299624, 11.180045450887373, 16.626168181819303, 17.02872495497427, 17.76048037313646, 95.37188945278045, 88.50376436787268, 3.209761804149997, 1.2520754721856888, 0.8596411719918252, 0.49044372814316906, 0.9420839384678872, 0.5914579980796384, 0.17621860869469183, 0.22216552868485454, 0.20248394850040638, 0.8121395531681277, 0.2713936032547105, 1.5687477828994876, 2.224116267696504, 4.6001979035715905, 6.020963730350618, 3.067281217344346, 1.1229368275211704, 0.8536993327640718, 0.7194483688762112, 0.7977974679200881, 1.1701181603054847, 0.8452364513950964, 0.4370073793876556, 0.6401396374548636, 34.27230558087749, 67.1697655031758, 72.36873380599484, 61.525537583135794, 55.52810807381907, 56.87615609938099, 61.49950088993196, 67.21816755110218, 75.82476554378387, 82.0630285816808, 86.814054366081, 86.75688974318966, 85.88549598570793, 75.07392975591844, 47.29652789331252, 7.6676100300204375, 0.682471082095177, 1.001505824106355, 3.6603087763632502, 1.2534171679327566, 0.32146633572636113, 0.12773334063709746, 0.3207039250241172, 0.7285773177300731, 0.3133600836078967, 0.3076889185655502, 2.5354781794932584, 5.282194133727781, 1.315633190735694, 0.6525598838925362, 1.0434844392922618, 0.8086127295128761, 24.915683730956047, 43.4581042874244, 66.42277363807925, 87.6065065014747, 108.44037963498025, 51.59455914651194, 31.82919848349787, 56.79434722469699, 91.05888259026312, 84.46673547067951, 71.8935465043591, 26.481948898684596, 0.798107335163701, 0.5458603835394306, 0.16580128381329198, 0.30497880592461557, 0.21487488441409605, 0.13731577523773716, 0.1952499487707692, 0.2000982281301291, 0.22509379252310724, 0.17542517143151454, 0.13245122417086555, 0.07370840652935928, 0.16331215689499534, 0.2252408660828106, 0.15422184951603413, 0.2057670795869443, 0.18953960599197497, 0.17719451277967424, 0.151365352794528, 0.26810405235136714, 0.15282124160758911, 0.22766931883750424, 0.253168340892561, 0.26479948612470783, 0.21298398023411153, 0.10815564197518172, 0.2059836526431384, 0.23255124477849853, 0.3093494294631866, 0.15336733972353322, 0.18191087179847304, 0.3582642966460797, 0.27649458437677354, 0.13593424291860673, 0.16936480308011656, 0.19353233367925693, 0.12888526874444178, 0.1260283659963358, 0.12383773757685577], [0.04165677015759772, 0.004829122852008309, 0.03336645009356641, 0.059270924182548645, 0.016288887033419266, 0.024540312813534856, 0.11673457034292722, 0.04844524762442997, 0.08965651084098125, 0.04062600651635759, 0.03220271274086929, 0.057250574125998446, 0.07186931287569386, 0.0012477175867740787, 0.04527140664116991, 0.06918914661171936, 0.04829569960073118, 0.02296359278261662, 0.03550253305283766, 0.05256488543724822, 0.04016670999267409, 0.01614474376002627, 0.01419234474474985, 0.023692837623398633, 0.0839289464056492, 0.02711991854612866, 0.010583323685662642, 0.02584126992000928, 0.019599177852092732, 0.01997815580257485, 0.04089889086542591, 0.09757714751627176, 0.04782322636475006, 0.055131712823265025, 0.02564591558409795, 0.04015807618176745, 0.06092929386443669, 0.03358325680657741, 0.031940262509329666, 0.054941661731009526, 0.06822549993352545, 0.09523407526073918, 0.039469003076514894, 0.012714163730702093, 0.2504418033265299, 0.11899506598110161, 0.1608073558177679, 15.375856795618612, 42.29174437061433, 66.82551476263231, 78.48478363406274, 64.53492118466285, 50.53253035391531, 48.12079829554404, 58.2601918712739, 87.74184396190029, 84.41988668134137, 82.46945673419584, 40.53271432076731, 15.81924936463756, 1.0861646071557076, 0.5476307820889258, 0.17388896596047188, 0.6440378605358063, 0.7364085136402039, 1.927556522911595, 3.2354920621841186, 12.937145694609612, 10.841967540402567, 3.989708442841807, 0.5330415262329964, 0.9683016122829531, 0.5496259814789218, 1.4510622139899962, 0.5330042024293254, 0.13964506557151196, 0.46337483871367674, 0.6701409888844336, 0.18685477425254163, 0.24077196575460896, 0.23659962109260022, 0.1983943566559784, 0.40155620103882206, 0.12141745131943496, 0.27222925196251563, 0.6927933507869322, 0.19469854932638908, 0.050341924276923945, 0.11335236110514212, 0.30356525113025024, 0.6933979473767743, 0.9286158676109008, 0.2454755157833138, 0.09452668499321708, 1.0759882628917694, 4.721151051982757, 4.976874388033345, 4.67156493856061, 4.2769970528541075, 4.410776842025019, 4.524767783380324, 3.104063488783375, 1.928612498506423, 1.9906154875793767, 2.0552891204434056, 1.1547736030432487, 0.30381882623318707, 0.09529956045650667, 0.19373787506934137, 0.4377620066365888, 0.08396417878928684, 0.27592179575754755, 0.14851861603317723, 0.07032887093842992, 0.09260073229069672, 0.061338097533030864, 0.1326609330792581, 0.13290755210384247, 0.2417282579887298, 0.950802019046199, 0.3386972772498285, 0.12729539115342403, 0.5016692451411678, 10.311587587479623, 43.82544994354249, 63.2541927983684, 73.2070541381836, 72.27229056819793, 56.380101788428526, 29.61518329958762, 37.41924670434768, 61.62382825728386, 69.17357890836655, 49.04808975035145, 21.450071604021137, 1.7187843255458342, 0.46289413386294925, 0.0802595614485683, 0.023881902377451622, 0.06391407200886358, 0.08908172273227284, 0.07002700165274643, 0.08300689064086446, 0.03830558365030635, 0.07245812805429583, 0.02867379000470523, 0.03825333645387042, 0.09781231352638814, 0.05408211491040645, 0.05733937903818104, 0.0427300823221524, 0.056634581978282625, 0.02421993101316114, 0.04792480196263041, 0.03158202830461725, 0.05792889135679411, 0.027367474113200462, 0.05296980120962667, 0.04966299417578886, 0.015362975931155588, 0.04302283516153694, 0.04025089156423365, 0.08843935800776367, 0.05191001432737516, 0.020937916499772863, 0.019498613490272435, 0.00678660246663757, 0.026037834674840974, 0.02299749600370565, 0.03653030512073348, 0.028421339135797277, 0.036342242026641484, 0.03046711948099396, 0.05974614767417793, 0.01850756767746662, 0.04179961874239868, 0.014132196308984874, 0.02726085957199816, 0.03270088056583078, 0.048928403956515175, 0.02058670349088648, 0.05722854909817538, 0.06661973367895811, 0.046273112567442085, 0.12010138887431353, 0.1158241514537123, 0.21983715765658887, 0.3294403304255778, 0.11550320657871424, 0.12113561523297142, 0.07145901916608696, 0.018855666538940805, 0.09021988423961787, 0.018257828759810617, 0.07929933152251667, 0.061227271423464825, 0.04247219414420186, 0.019418034447176803, 0.050986962648288864, 0.028714252853645917, 0.07670529652386904, 0.039619049057364464, 0.04004045487231305, 0.03125604831673686, 0.010895019964194827, 0.030082229246956207, 0.06022256626296909, 0.060436584415935704, 0.036120934547075344, 0.006581855892774559, 0.010815250101469217, 0.06060347667024021, 0.13226523334460874, 0.044977661717923424, 0.022568929181884856, 0.07219526796571671, 0.0066171988803562865, 0.10923852257791067, 0.29827072555499695, 0.030847587472488804, 0.16332708028776033, 0.3978935653163541, 1.1298188711366346, 24.25609011803904, 59.10839265392673, 87.94972173629269, 84.07429449019894, 59.574621262088904, 40.71513199037121, 52.449514250601496, 78.4197272023847, 104.07384026435115, 89.5837027026761, 78.25757641946116, 45.26372032780802, 17.859094642823745, 2.1046619549874337, 0.7028952925916642, 0.1497486008391265, 0.3231619640944466, 0.32663788886800893, 1.8761059353428504, 1.594313178812304, 33.4213238377725, 30.753468851889338, 6.033896765401287, 1.9779392452009263, 2.290593577969459, 2.8435014188289647, 2.3457379350739145, 0.5553004253775843, 0.9090122904989028, 0.5856139116710233, 0.81152600867133, 0.14596247174326452, 0.22164766856979942, 0.5334200349546249, 0.43552052530069507, 0.5006628201132821, 0.44833561345454187, 0.45739074207602015, 0.7531941129315285, 0.7006346590576634, 0.046193657758375334, 0.1715564887009321, 0.6161058045202686, 2.204411505691467, 1.7189927014612383, 0.9378850411984229, 0.46988441038035583, 8.457786210121649, 15.077616437788933, 15.6909986465208, 9.56599110557187, 7.838539077389625, 11.683299272291123, 13.882841890858067, 12.747407901671625, 13.71084007524675, 11.679411222857814, 9.515390569163907, 5.834543281985868, 2.103118012028356, 0.502382442355156, 0.13495159725989067, 0.7398480645591213, 0.24082807403418327, 0.2787664334379858, 0.06923050003787203, 0.07281743095166261, 0.016174602036875103, 0.05340559798623285, 0.08982364824342151, 0.29438227775596804, 0.46168227469728845, 0.4778098351051731, 0.07245687933097925, 0.07978731420852485, 0.38065922236250294, 6.324110973265864, 33.597148003116736, 63.37114610979634, 71.63248923517042, 86.72857023054554, 76.70323525705646, 38.83437118222637, 17.567950833228327, 39.647058825339045, 71.490326850645, 64.54784539438063, 31.10618602844977, 4.244903729807946, 0.3297728125847155, 0.07624002068393654, 0.07214838338475074, 0.09027849762670456, 0.19987848346992848, 0.05681214966781198, 0.06639644203166808, 0.07245890180309934, 0.042944897206560265, 0.012677623251933726, 0.02246055455367652, 0.061328402690349094, 0.10076201250476223, 0.010177176426945916, 0.05691477480614859, 0.053304704206605116, 0.04382698233389566, 0.009884230150360494, 0.048447909779966845, 0.04032708666918259, 0.053584016033358155, 0.027202746057282054, 0.03947928014601912, 0.01417401992160106, 0.07628207891097954, 0.05279699858698634, 0.16514129906652436, 0.016274844641767202, 0.03753170461183594, 0.020973340405391592, 0.019160381841262984, 0.018166285083298723, 0.0389935995542234, 0.023342745018101508, 0.07681619541178789, 0.05850486307134552, 0.03122630686829648, 0.022719295004442818, 0.0261784041480672, 0.012255930154013538, 0.11888838057676632, 0.14410486174446924, 0.18540783334643612, 0.17757047808939413, 0.17595633083293516, 0.11395729477367095, 0.2898689167153451, 0.1832378586573947, 0.17177543662969144, 0.20880069583654406, 0.18996680726207074, 0.31597109511494637, 0.1609765233532075, 0.16840500216330254, 0.31293236139801245, 0.12526072291356902, 0.22719109611165142, 0.12097875873047499, 0.15631141561654308, 0.11251839012989115, 0.12715939522510575, 0.10375825898541559, 0.16099800445860432, 0.14089884506838937, 0.24150921812941953, 0.13978395731218402, 0.09131609477222928, 0.13737848719521878, 0.10007810283211932, 0.0803488873005394, 0.15655596620373188, 0.2866856681723749, 0.07092681022421007, 0.10684465103211904, 0.2505988360292489, 0.20132726298705225, 0.2655377803790954, 0.22147591165717573, 0.15102525572142295, 0.14451407527010288, 0.15862186018738056, 0.2995294386581067, 0.2831960457467264, 0.11622310706203985, 0.37944301181743223, 0.3409845400000772, 1.014329094079233, 26.38054386261971, 71.47484917794505, 101.05608632487636, 102.84679735860517, 85.6647293029293, 70.0151155840966, 68.27348909070416, 76.6553117382911, 106.19312040267452, 100.73411464691164, 100.88922869774603, 59.94959200582197, 27.411617309816425, 2.7297698442013036, 1.349170436301539, 0.3426245810283769, 2.652518763657539, 2.8848059379285385, 8.806615337248772, 26.01304719524999, 26.482864772119832, 16.481695521262385, 20.05151717893539, 1.443911978314, 2.6378620920642732, 2.8908772766590123, 1.7777696636415299, 0.8314906889873167, 0.7504719267449071, 1.1043286131274317, 1.0594597627078335, 0.4104062938882459, 0.41353573241541464, 0.8632045227193064, 0.9714538495867484, 0.78629432065833, 0.47062454324576164, 1.5240191572135495, 1.7585308056685234, 0.6972772940512627, 0.17040087571067197, 0.5584666361251186, 1.258599599522929, 5.435439665471354, 2.0803324734011004, 0.5397828548185287, 0.23404932971442902, 3.322131580883457, 9.933536802568744, 15.081024977468676, 10.761659952902026, 8.717873673285208, 12.954770864978915, 13.618544743907067, 9.519647321393414, 7.221015336052065, 4.147915772853359, 2.876638827785369, 1.4937774380368571, 0.2832115820098308, 0.1380078131032567, 0.45436300938167884, 1.7812132595046875, 0.34731141501857393, 0.4842771493619489, 0.5082509210032802, 0.3639113758840869, 0.2095438164448546, 0.3040063952005679, 0.4138788478749414, 0.3910853725767905, 0.8571098949159346, 2.0136912815993835, 0.5750885377487829, 0.6417588408916228, 0.9073091851126764, 15.25289539367922, 58.7052789042073, 82.90544386832946, 86.73157476609754, 87.9884433746338, 72.56796667652746, 46.461043434758345, 48.36248297845164, 74.76081478980281, 87.87412981833182, 78.62718920553885, 42.7385337122025, 5.904220756023161, 0.6340750402981236, 0.1319954937864696, 0.1077939335617327, 0.17058544161338962, 0.3204245174363736, 0.22384836338460448, 0.19548939721238232, 0.22296298024875505, 0.180494298617686, 0.15477418358768188, 0.12511310543143941, 0.2700602425442588, 0.21821948639567823, 0.16149266743131224, 0.1295894720861989, 0.15267470430943275, 0.11640579604934301, 0.1243120379325363, 0.09231447587691008, 0.12107802840370326, 0.11440259870141746, 0.245950183861198, 0.09334859498325856, 0.21526710610956917, 0.16868784182494687, 0.1595472790781529, 0.27193164212569115, 0.1005699159577489, 0.13420812425113496, 0.11642461882964258, 0.10472966613428247, 0.1154607653077091, 0.18657268535706306, 0.2991163334058177, 0.20623848413027104, 0.1622646389108512, 0.1333352283484513, 0.12093932818501227, 0.10344460726745668, 0.12396202768169104], [0.043465653133969155, 0.07246398096603733, 0.06165996554397768, 0.038329474102225036, 0.028149816508014357, 0.02848139085296181, 0.0062147891731001445, 0.017719899056359165, 0.03880375913614708, 0.015965536642338962, 0.020378363964658593, 0.010532371177818748, 0.03780778737798814, 0.08098136182994613, 0.11079065501689912, 0.026466466614135334, 0.01625634936405526, 0.055180684993824655, 0.049665468639784285, 0.04343344296719279, 0.14628588342137877, 0.022775472231930303, 0.008449495897718496, 0.022427356133477825, 0.024674885733533772, 0.09058519326631101, 0.0324771139440277, 0.0214031272222318, 0.0428594439290464, 0.0756224695472948, 0.0050274836042174895, 0.034870012558155486, 0.036764126646542744, 0.048998275005649176, 0.04925468080346623, 0.054444171893861026, 0.060061921455687096, 0.039947279428522435, 0.058556949389317346, 0.021800416589324034, 0.09053141389402652, 0.10252992126850352, 0.05260390995611107, 0.11695858977374532, 0.03995289102256779, 0.20765335659586615, 0.21021924552417573, 0.2581911504028305, 1.3316738461294484, 20.987322138201808, 42.91639751003635, 68.08265793708064, 78.27685879122826, 68.75360288927632, 58.39105390733289, 38.94076939552061, 45.9421334728118, 61.155548249521566, 77.16032474271714, 62.50887578533542, 41.202459027690274, 9.446274484357527, 0.45019141548583586, 0.19128152139244542, 0.412727264507163, 0.3659925609827042, 0.4638645527583938, 0.8992364570017785, 1.6096584715189475, 5.198349058628082, 4.615747159527195, 3.728375136852265, 3.054742380495995, 0.4496473398420119, 0.6909692035086694, 0.6341446623686822, 0.33419834930569897, 0.48852912120280734, 0.05754886195063592, 0.21736834739004413, 0.09798823795731991, 0.42739469197488605, 0.09795186410267508, 0.1502598879197913, 0.02265951141805178, 0.09773329921787786, 0.04520469570472356, 0.15586233487532986, 0.49133303364919084, 0.6821357807324779, 1.2317059910105121, 1.627522538746557, 2.291828389129331, 0.25460616535236763, 0.023518520061888044, 0.19571879458042885, 0.19091585230442787, 0.15404246236768462, 0.17422771471883022, 0.12785602195729173, 0.09883833508337699, 0.3534187292379718, 0.3050968141084717, 0.35165859626666196, 0.08818721548924524, 0.5596137455394191, 0.05166120812176697, 0.9924813083583309, 1.011996509567384, 0.1358960457747021, 0.022938082054738077, 0.06836265265460938, 0.029865363162131082, 0.15401359617469773, 0.20497934201792364, 0.0691576527371522, 1.0329773901931703, 0.09522608496368894, 0.16412014982873396, 0.3235800335964849, 1.192608908299477, 11.476967892339154, 40.48715206884569, 67.0858189367479, 73.15909139571652, 54.34642737911594, 39.993545316880756, 31.4722784872978, 51.10350193515901, 83.69074160052885, 78.6645144800986, 66.18044960883357, 32.87177820359507, 8.099663026871221, 0.1301941146413165, 0.45844319366639663, 0.07224065101435108, 0.12820430851030734, 0.04365582680029254, 0.06790797181066967, 0.06618649563601901, 0.13799468235623452, 0.11932407776194236, 0.08998286429672472, 0.052022318986635056, 0.009410713119582545, 0.008789109377821368, 0.017657229233713403, 0.011168001031863594, 0.06280579176100512, 0.020358133497798157, 0.06164228423468529, 0.06032287398533476, 0.049582949479020415, 0.04622647313461189, 0.027372105114702738, 0.0053566031161725765, 0.008135852798248732, 0.016423739575510545, 0.031502778424070246, 0.034185819432980595, 0.028956681377284473, 0.04871705561996468, 0.02204442516930642, 0.04480655214959576, 0.04196227070004229, 0.022560778006370512, 0.020243526744325797, 0.03438663789101186, 0.04263593394669794, 0.04616740775564986, 0.022517936454424937, 0.07905779166087028, 0.04983023883053853, 0.022569769963381753, 0.00582323014368153, 0.03820775422237573, 0.06982124575804319, 0.03678012639284134, 0.02107163523173621, 0.014455106199508714, 0.011712632089432691, 0.07192188182905798, 0.043624911322108204, 0.03628649763883122, 0.08938304809553009, 0.03072555349659055, 0.04852340008402544, 0.048710072728534864, 0.05602377241537456, 0.05013053763597723, 0.1008548240567888, 0.05176714275993648, 0.010287690355682807, 0.015902631247656483, 0.020510755449293122, 0.043364989180718704, 0.01782091924049441, 0.04044927003222608, 0.004795100408486061, 0.04016500161660295, 0.025104065425693992, 0.04265957158960162, 0.016169063221182556, 0.04783041993035905, 0.04337721977442984, 0.06935616910097099, 0.053418606159187136, 0.052324092511328, 0.05069704433422416, 0.021311437989014293, 0.02618583903137234, 0.10849603016169802, 0.054958848913590756, 0.060862540793154514, 0.04008319874804828, 0.06643765756199438, 0.12135536755405127, 0.13111685222435382, 0.09605271681662529, 0.072854011650047, 0.2319058769893262, 0.06889037232124998, 0.2137550630516583, 3.14694480069222, 29.124092748088223, 60.867461927475475, 87.91456161006805, 87.61314315180626, 65.21159279731013, 52.12644038661834, 50.98503066647438, 68.33554883157053, 91.54002404982045, 85.1198414833315, 70.65623483350201, 44.56724074579055, 10.168210248793326, 1.0324586567378815, 0.5002182746125806, 0.3105437298936229, 0.5839344017928647, 0.643457901333609, 0.7696688030996631, 2.8446291002535053, 4.86029762414194, 3.348246966638873, 3.1721283783835754, 6.54468693079487, 6.87307462576897, 1.6526325719971813, 1.0008771417121733, 0.6586994963788217, 0.3688915296187324, 0.32104078920618184, 0.17575261273211049, 0.07097600072982811, 0.6278592480286476, 0.25468884156115595, 0.3200106767396773, 0.04832277697841487, 0.13355022326352137, 0.0377327184222879, 0.20620393356488598, 0.6418595967754241, 0.6623262791864334, 2.4833915550862593, 2.4823285927695613, 2.4400986394574566, 0.20700216653846926, 0.09139633482141842, 0.41181623274760865, 1.0094238637435822, 0.44073154729220176, 0.8730860763499815, 0.6392376148892988, 0.6619312842526744, 0.8320700353191746, 0.9072704517072248, 0.3679785366740919, 0.07040859004783054, 0.0963919405494967, 0.11989366413364488, 0.2339315820004671, 1.176457200800219, 0.0678323053063885, 0.12367643776439852, 0.08202723272505306, 0.13109711779942437, 0.21046387272015696, 0.0881955122214652, 0.053760522691112374, 0.836312385095704, 0.15687338707427825, 0.100481700933268, 0.19171394738218478, 0.6909316345568627, 3.626296188562147, 26.08340863258608, 58.42262506484986, 84.45248942221366, 82.16880706048782, 60.26944952626383, 39.34619342127154, 40.012164808088734, 62.098693924565474, 77.52794496474728, 77.81299929465018, 44.014539564809496, 13.812142149094614, 0.6788234616960249, 0.41681278076383377, 0.08887945253762508, 0.10475677798592276, 0.11780033654142773, 0.03885710949919397, 0.10363789891163189, 0.17052858256764952, 0.17066813314393645, 0.06658029547261615, 0.06432828042776355, 0.028295532176871935, 0.10321672675350022, 0.009776254845482689, 0.054194706852637956, 0.012375093215415555, 0.08556784596294166, 0.046401554868826946, 0.07726321537648478, 0.09999055430413255, 0.03400456303009584, 0.02025535897231631, 0.047032186956775766, 0.041512458344861385, 0.029412268120194637, 0.03544616813380872, 0.036887252297733104, 0.06657670252025127, 0.009874106298441128, 0.059831240890367385, 0.024950932110509565, 0.017801110121992328, 0.03622266336254055, 0.050177759295629884, 0.03745333381718205, 0.09772365417091117, 0.008631506897208673, 0.06138264554582777, 0.07688149674645356, 0.05518058923283412, 0.054997352492665096, 0.019942270328981743, 0.22187813846093996, 0.3939714709356908, 0.1410389319062233, 0.10888282795466724, 0.09274386815846929, 0.09682716276015967, 0.10638040941088431, 0.10665397174776563, 0.2775054220711031, 0.18242024365932713, 0.1619921567579431, 0.0870979610349863, 0.15494197216485778, 0.19341965746735373, 0.1768144412386802, 0.1092521129776874, 0.10207252847331186, 0.12715443863623566, 0.11901139131476803, 0.1180218278820957, 0.2549596842859061, 0.15746263126211782, 0.10528281225912994, 0.09534695065550267, 0.10689561886172141, 0.23771308392526644, 0.11643419492869608, 0.13338523856814832, 0.16615749937632393, 0.19389199663794812, 0.12210663167699692, 0.13940347208371087, 0.12689744678115653, 0.20628408168352422, 0.14102175621496094, 0.1894793148723341, 0.18069666840376394, 0.22497883336918972, 0.15077497479656052, 0.15658739113038586, 0.08994034641692716, 0.2556998171513119, 0.18644415112512727, 0.25259722234501, 0.2102277950654107, 0.30932500658016054, 0.3159922084981396, 0.41058990984193744, 2.604127011952862, 33.19748593914893, 73.24106108757758, 104.083693258224, 107.0895859502977, 91.26636028289796, 83.96846894294985, 59.42805797823014, 65.64994904302782, 76.46515523233722, 95.87414895334553, 82.82948324757238, 64.35220149255568, 16.505319956810244, 1.2888867936788069, 0.8952059152145541, 1.2814380901475109, 1.185285598039627, 5.943280698791628, 8.783177214284098, 10.893171141224524, 23.101509078856438, 16.08037527530424, 11.834607643465842, 11.653334325359715, 8.98318769470338, 3.643520541729466, 2.9544539941895396, 0.9423616913057143, 1.2995104107164568, 0.8789108573429046, 0.5895642900178509, 0.1855770162036342, 1.233597308877976, 0.3495981874725511, 0.2699628268038073, 0.11544384242546175, 0.7682812646512063, 0.19325307930909819, 0.5146112893858265, 2.0157192695525388, 2.397631382749927, 5.6595236928232255, 5.3134902350364195, 4.452177949490086, 0.3659820196128661, 0.142132721600994, 0.1687990777915524, 0.3387150198461548, 0.2223342212457811, 0.40172510810436746, 0.398339826854006, 0.35135491901347715, 0.9563474537384127, 0.678490060231378, 0.3734071276360943, 0.14418588320334114, 0.4879036563779078, 0.1229761491319345, 1.3715209595618711, 1.4293684425853914, 0.3112102876747808, 0.247941721350916, 0.46251933300687426, 0.367769793036484, 0.544552518235099, 0.3623077087104321, 0.3429697189600237, 2.376361349898, 0.18319295058327337, 0.24987785536195004, 0.6366658883710062, 1.425226051961222, 16.622587057851977, 53.34004132978378, 85.69042082755797, 86.69856409872733, 69.22893139623827, 55.85939145857289, 47.60330038685953, 61.623855713875066, 92.4821852099511, 93.1788295315158, 90.66817529739873, 55.7829366191741, 15.541396506371038, 0.7577416721370913, 0.7521467788084861, 0.22407327147741474, 0.26098893414581975, 0.2905583039166466, 0.10846280492842199, 0.24309955537319186, 0.2843568834566301, 0.23878039762137399, 0.2015336470738534, 0.20617266185581687, 0.11001745013580208, 0.1984074567594836, 0.13208054486782322, 0.13406451340884934, 0.2140035819742949, 0.1346948505529473, 0.16917671317294722, 0.21326354103943995, 0.3252797681958445, 0.08308411996451118, 0.12775099130287287, 0.17805300622938142, 0.09572352883556197, 0.13870749652626055, 0.17605160152719868, 0.11909956037397347, 0.17602638191273137, 0.18953857943415645, 0.12626987521446523, 0.10205922918694635, 0.1562836219466502, 0.07182178478087149, 0.15480274334549904, 0.12450431067977222, 0.14375350317887722, 0.13612381903634918, 0.1825404734981637, 0.2898329412264209, 0.2115960587416926, 0.11174079556498798, 0.11678689414815557], [0.03330776009768729, 0.1102741355557115, 0.021684566858194528, 0.05672889123220117, 0.013839950045240263, 0.019467020024275108, 0.09130574492437225, 0.02922945655882359, 0.042986415341616645, 0.10330540143073567, 0.022437416783143437, 0.07631973213245792, 0.013400887818856826, 0.07421075336394772, 0.05387463531787357, 0.023640862388175823, 0.06486842604053598, 0.001635168948503692, 0.08247857342564291, 0.04906835289852274, 0.10466702312471406, 0.022487540000809297, 0.024428059865209847, 0.011121927546487461, 0.053480249424014366, 0.06268432852061046, 0.014669940236114688, 0.003856040843416967, 0.03592593069638937, 0.03885045985601122, 0.1516443160512755, 0.015041427761917154, 0.044045685114519256, 0.024979631679372925, 0.06114366058740885, 0.025353155083834164, 0.0668068123500674, 0.009757521122904315, 0.04737544797300812, 0.09087743282678629, 0.12119869491265667, 0.045427474073104324, 0.07879099388036036, 0.025711306934094718, 0.132215452951289, 0.06507671768626859, 0.0937126859301521, 0.3906012662956792, 0.11584287464258172, 0.0072410099129492965, 1.9876319121929908, 19.48366584316377, 39.51472590046544, 57.00671219056653, 69.18692281169277, 63.051527853935, 43.51773608115412, 27.845405955468458, 46.46745258761991, 57.4795146911375, 68.08854933707946, 64.14465711962792, 43.588534862764426, 12.649244704554159, 1.9447574644319474, 0.08189957949423021, 0.4285886859701526, 0.10245618530579152, 0.9532909467816354, 0.4787108770781948, 0.8485246233401761, 3.3879707705590034, 4.063631882590633, 2.425835430622101, 0.408509919840482, 0.10982545318021891, 0.10989105328917505, 0.11360910015120623, 0.12725884109855662, 0.26871909838049646, 0.054190757669388294, 0.047132199735290585, 0.09153914127138355, 0.15798396941634918, 0.07249293142869588, 0.1627821772689781, 0.12708461738281673, 0.6481105678023831, 0.349146869754599, 0.20890067031066265, 0.11241491463395858, 0.5330211789377275, 1.129740791455392, 0.6898106947060555, 0.23949532619407102, 0.0955948337251621, 0.04168236898558755, 0.08379316498194972, 0.04840382908080374, 0.07593029133614994, 0.018644237763158256, 0.15887304509599365, 0.08956915383497555, 0.10390993673354389, 0.34448914710552464, 0.36674823011121443, 0.23362309371511783, 0.18867202673948583, 0.2923074358653638, 0.03989330470381726, 0.07620276582817878, 0.1135597181236071, 0.2584115998639215, 0.2632195983202227, 0.5111000326371963, 2.7183846744798847, 0.08416640301865917, 0.4411068690880653, 3.4451630951896792, 15.888525286028463, 41.54102625385408, 55.41088411884924, 61.86306538120393, 64.58568842180314, 31.7888706345712, 25.4977556197874, 44.5813730455214, 56.027567002081106, 68.11806125025596, 68.13428417328866, 47.113161010126916, 15.400531445780109, 1.2215481554308247, 0.20147923950947103, 0.09161738949196954, 0.16488185573008754, 0.25718466408791085, 0.11140855855398601, 0.10244336099393907, 0.011883313606132664, 0.0370794867405728, 0.019120997261075724, 0.045410053233706185, 0.09240221592687792, 0.08813003468657694, 0.11294176862124475, 0.06527472843205737, 0.058783952732600515, 0.07561788834150761, 0.03426439707137404, 0.02562923018910712, 0.03643501144383223, 0.04512370488936863, 0.024962745186301972, 0.01673742002176662, 0.02720393349356469, 0.049387440010304415, 0.01864217124098251, 0.05759529453972655, 0.07451963235413836, 0.06012727641650747, 0.039189645284486395, 0.06422805697506954, 0.016783730036789374, 0.10833733504818333, 0.030159851190664118, 0.03496425669460047, 0.05633747009860893, 0.055515695243112506, 0.04190913101117458, 0.06903042085468769, 0.031194249919104963, 0.02819778318817337, 0.024251851981746095, 0.03610082473906298, 0.07025757879619637, 0.0034860646654476203, 0.037659871121568066, 0.004723190607863569, 0.025047949485240445, 0.052992883438785235, 0.022971376235927307, 0.06842552549055508, 0.006191443601217602, 0.036089118915579976, 0.133278016902266, 0.028179937169977257, 0.07200388388047296, 0.04109769834265594, 0.066149263762899, 0.041429249704965664, 0.08295493455783975, 0.014728269213059498, 0.04742130982659517, 0.014506189899909643, 0.035176903550182624, 0.09094211363023327, 0.01484764773669022, 0.02743274288912935, 0.028851805855670286, 0.005823824340627799, 0.031149267151411024, 0.06153446502022206, 0.04056226800105745, 0.060973106432826295, 0.05387915906706645, 0.06679247884500412, 0.06632911056400308, 0.0970609421511331, 0.02488213549968937, 0.056511663170831825, 0.011619764038421696, 0.04195525333465588, 0.03131804781244888, 0.041463309974079175, 0.036386119712504654, 0.06536044600990511, 0.07135390424199643, 0.07656144053344766, 0.03658081329758129, 0.12945566716934406, 0.07827815930208853, 0.05021488008600089, 0.426678185261065, 0.23527315517346706, 0.2670353290534789, 4.934845211044435, 32.18563602816674, 62.78517146264354, 81.65339977510514, 81.30917256878269, 58.10740378595168, 31.21553582529868, 30.214076272902954, 65.33451203377017, 74.02977912656723, 86.86769670055759, 64.51916110131049, 37.354857075598936, 11.233930972314651, 2.552626781886624, 0.1963115780944786, 0.3520682388015332, 0.21132192183886805, 0.9573062280974082, 0.5251876541203069, 0.5286251212800703, 1.1144594824121845, 1.7478738484844085, 2.065336516787929, 0.2443072163770276, 0.20303067480844839, 0.03257902279015511, 0.09380262465246263, 0.1407639369849236, 0.11539383220576471, 0.18091495749690842, 0.16612117148695454, 0.1316972557575472, 0.38530073459109954, 0.07451987750227414, 0.15596923478428396, 0.17422160133719447, 0.4518826005439605, 0.4126479590852415, 0.5752186501218427, 1.1842448216292167, 0.688905117492522, 1.5301890454946028, 1.7591032265655457, 0.35700481745504564, 0.12911422178149223, 0.0844609255211488, 0.06783701674712282, 0.09899459403729248, 0.05763336910956329, 0.02793393676139174, 0.071435546232087, 0.05881109139731815, 0.10144023014412773, 0.26497084467161086, 0.3695879648289373, 0.03343674249105877, 0.16024274901757318, 0.24269732856942763, 0.01019164016695633, 0.08650288691804295, 0.2437589732148955, 0.14022620454911264, 0.13360380345294554, 0.13236637227237225, 2.4467149424937467, 0.446861905436362, 0.39073033678916197, 0.41101092112160503, 4.167303068022575, 27.42915422685685, 55.96268707706083, 75.72577276537496, 87.05836311463388, 56.7685890197754, 30.848715766783688, 26.754526169069354, 40.203082253856046, 73.5712226744621, 84.72078738674041, 59.754736500401656, 23.819757815330263, 3.1194943381894022, 0.17666683141742984, 0.15462851962975918, 0.07917581516648493, 0.24773012786622972, 0.08240052438791722, 0.13844816044213312, 0.027500654668397004, 0.04800341407498045, 0.04319369575128921, 0.11036689348158338, 0.09647898345945344, 0.05950969846678838, 0.0660950017552222, 0.0626628244325759, 0.053104349231768044, 0.04998179017415932, 0.043853573245747436, 0.027358736880424044, 0.04076047792970654, 0.026730104281957594, 0.05997286373448949, 0.02002856438799251, 0.02684669711837365, 0.010502423843248718, 0.05654348263276681, 0.05904171450604355, 0.17262983916988298, 0.09089517542311261, 0.020765655884338964, 0.020137074996807405, 0.040162779961622534, 0.05436053807516733, 0.014866895695787766, 0.07372796475406616, 0.034020520641558596, 0.07576582758056541, 0.054048843711854956, 0.062358201060804634, 0.032756069539895946, 0.06559705992619838, 0.023896741500544934, 0.012090519322232615, 0.0677069733219762, 0.149252972595634, 0.18759715941644486, 0.10464865233628981, 0.2084301084640526, 0.11174196001863289, 0.12197828130616296, 0.15111930067500762, 0.1285242804536416, 0.1287487671980935, 0.23597741980225811, 0.1788912902796461, 0.14446087812464084, 0.12021552831415208, 0.2719484041294744, 0.16414080355917254, 0.09316274971370736, 0.12574094512890424, 0.15149279918161132, 0.23351669942419376, 0.06939399852267197, 0.2462219612132157, 0.09356290041919678, 0.12488307987129497, 0.1142005813157847, 0.09106910802544126, 0.0911921953722354, 0.18987981031738943, 0.14148076545567284, 0.21549570674617446, 0.1553530549450267, 0.29169343171581147, 0.12628092220233333, 0.190504738880742, 0.1030936623893438, 0.20364613452505684, 0.14828247709139702, 0.18279118343226372, 0.13384504454030147, 0.14893077133644014, 0.26400569646108535, 0.3007871405251565, 0.2073120491038407, 0.18164097902274903, 0.24582946372608988, 0.3662586079970483, 0.28302477913037427, 0.15307821814090977, 0.4053326161398042, 0.2798555040311429, 0.2715262283961619, 4.649629083371932, 35.688092939315304, 75.59209838990243, 97.30765758022186, 98.6813892856721, 88.34527707869007, 62.79222780658353, 45.26159048080445, 63.96325142152848, 72.73120003361856, 89.37119653148036, 83.57635744156377, 65.78201916909987, 20.618468330752467, 5.440368613889141, 0.2669771676582675, 0.7330540291243984, 0.33190480463447114, 2.403564703079962, 2.366602002613006, 4.168056653391931, 8.354983829682874, 7.033175479981208, 11.452640371937907, 3.378008685765728, 0.7317122108032628, 0.39748968376267346, 0.12245292640140942, 0.5727447989967562, 0.8616450741406411, 0.30894199326153726, 0.21914777045528736, 0.24844482661254946, 0.7617701301651617, 0.2387447285676195, 0.30383807036184496, 0.6802466079112023, 3.0149859718738066, 0.359490588908234, 1.2906203587209026, 1.2341888513295882, 1.4438444400025954, 9.320114389542612, 2.550666577393009, 1.7294919058199854, 0.38472727181450017, 0.11920080655404638, 0.27346053911793616, 0.20746374983460675, 0.08808760107645104, 0.2347727158978101, 0.41230367917206984, 0.14953123105149116, 0.13507271576071941, 0.5969906850687919, 0.6985651797825291, 0.2873352800886477, 0.1950460774523597, 0.7354796473537722, 0.16696402142124792, 0.1344655144719347, 0.539766675041568, 0.7710780371581355, 0.6896678959169696, 1.0006456605849727, 3.382223027367746, 0.27449800602851376, 0.8544121009688225, 4.1194496616240475, 24.065225624269058, 58.85325031895792, 76.79565414305657, 79.94765512404904, 78.4356834042457, 49.06070017045545, 41.81460765100295, 62.4598422358113, 68.25888218418245, 85.43261128087198, 90.11257940723051, 73.09020673075031, 28.59369416390696, 2.677958521150774, 0.5361015878377423, 0.2961496425972831, 0.35204617546931394, 0.6214971023221171, 0.26756206046669717, 0.20728422479043085, 0.1579787140531886, 0.20489700288782198, 0.2418906226634018, 0.1266303961916316, 0.18924723619655257, 0.19215481566084971, 0.231861382602684, 0.12609008203951583, 0.21942633534631423, 0.17148234671162021, 0.14323860016320983, 0.06285614672026808, 0.202322518453002, 0.09303226961844391, 0.12396315383093974, 0.12874231673777103, 0.22915531490598956, 0.16626833697720883, 0.19432647574332454, 0.1642408393203251, 0.3178298082803527, 0.16621769856541388, 0.10368895101090593, 0.14566519898512673, 0.08278824148639556, 0.15697167615496344, 0.11913453994859612, 0.1193599000332817, 0.15936563963130598, 0.10126687210774231, 0.18743859453787728, 0.22260480350063694, 0.16687733091173634, 0.15207867258258406, 0.10943104813416159, 0.13549266983905148, 0.26500259135519305], [0.030440164677378152, 0.020468942370385896, 0.023129653831523274, 0.04530227998451841, 0.05704762977397731, 0.041112468517836065, 0.050765915638616974, 0.01882131707163588, 0.016281297017309456, 0.0437017614322324, 0.04756449932052244, 0.08147745738707243, 0.06516970543851776, 0.02782950940121326, 0.05229152611366684, 0.032296163976312645, 0.030909330328746192, 0.052915420458321615, 0.04590796824965266, 0.03522070462725336, 0.10159600646265092, 0.07731403764938155, 0.0937338606003792, 0.007807245128788055, 0.02948591023713591, 0.02137665505400829, 0.04212601050253838, 0.03270614358987058, 0.06509080604319611, 0.02100450294693151, 0.08303640034770773, 0.0741235725581646, 0.03428479416235801, 0.04368370857029673, 0.035204900233375455, 0.04805761479562329, 0.0448869186032924, 0.061525402200077815, 0.03238633635544008, 0.042287203062686234, 0.04310151239136054, 0.05723635936456342, 0.034949517162937316, 0.06835758115255064, 0.07794177775541622, 0.038498082393479925, 0.1276178911869084, 0.11829817877902139, 0.05849554744218627, 0.222882112007468, 0.06667607944578895, 0.044994170912691665, 2.5308032045441293, 7.768154596128772, 32.83903817976675, 66.5821316934401, 81.95843465866582, 63.847612104108265, 46.101005154271284, 42.67815666814005, 39.797866113724254, 58.90389204025269, 70.5297540849255, 73.31258943003994, 55.192784647787775, 17.616184219237297, 6.438552496894714, 1.3203910257547133, 0.06678954472825413, 0.18811388572137203, 0.11208876802195465, 0.08364517977761646, 0.2706219075668243, 0.11798641929823546, 0.08028380047049254, 0.2007757869338797, 0.5930563026378232, 0.769619896046577, 0.39444322787946273, 0.8315680332241521, 0.33357732779076027, 0.24290313042940634, 0.38912253274071607, 0.43122062699929364, 0.24292991286323917, 0.05306791409008926, 0.6019545670959258, 0.6055059055647543, 0.21717507872850667, 0.9528182398888373, 0.7554932347228451, 1.712475928568071, 0.32245829701423645, 1.7064542323350909, 0.32508371097426264, 0.5411046935665993, 0.05736155728358896, 0.09394831925390229, 0.11526528265207045, 0.06432156949754685, 0.13846930446884326, 0.16609405197443503, 0.22701544747237237, 0.2583539900520156, 0.26983363373625663, 0.4729695383819842, 0.4289349577119274, 0.2060213288472545, 1.223129851202811, 0.7786932575606531, 1.5533081081605729, 0.5521667580450735, 0.3140500530360207, 0.256856027690153, 0.508527907753183, 0.6381856842387108, 3.3726205748896447, 15.388014181967705, 45.19013666337536, 53.624817171404445, 55.347035777184274, 55.78155202250327, 36.06789996547084, 31.55900993654805, 44.6838959570854, 66.3863818876205, 66.7046037797005, 68.68645191192627, 44.881434363703576, 24.70991619171635, 3.8787168889276447, 0.3012974163697612, 0.003981238762442504, 0.05825557039990541, 0.06337298027750465, 0.05039432086050511, 0.1358676392344698, 0.013688079817520996, 0.0177108132535772, 0.07127961669597896, 0.05387110365254264, 0.09616900130265182, 0.037560168608662584, 0.06701223882696322, 0.05698181516040237, 0.06504186834659308, 0.17720395098290137, 0.13065390529171114, 0.05680201432457375, 0.022899622525719386, 0.019770852410264557, 0.04721187287941576, 0.01701780054117403, 0.05892179876325592, 0.015323933217704538, 0.026882274241577235, 0.01741319384065367, 0.09171757847070695, 0.05841029717797234, 0.036708818928849314, 0.05020383309813277, 0.025237784157657338, 0.04868158574907049, 0.07527422129867539, 0.024823365064578194, 0.021756519751262762, 0.042545033784042445, 0.02403993674013163, 0.04384262201886985, 0.028980585235741832, 0.0018858927679473475, 0.06931434070030529, 0.03575801571470595, 0.07379011746736304, 0.03582777951153056, 0.04353566973980877, 0.007209481085620581, 0.058841056926476384, 0.03516506366131287, 0.07999947459827508, 0.07441482386521756, 0.03017097478732467, 0.01886994258740977, 0.0446873641903362, 0.03817302362632848, 0.032035527457933755, 0.03011164893846839, 0.045396581577557715, 0.024799610593266068, 0.052774065744973, 0.06028600217353913, 0.030919000273570422, 0.05900829392034681, 0.07511547255900598, 0.17363212732297761, 0.04933111339567169, 0.024089426020040147, 0.061846550088375814, 0.01788710349149281, 0.04471937134381264, 0.028362449957057837, 0.017701689146399018, 0.09843123596041434, 0.09832360060705293, 0.06789036711016971, 0.04781635072562964, 0.1291421839907285, 0.007818288765021511, 0.07058551805394311, 0.045818948832851265, 0.04175913482604008, 0.02549162164570824, 0.017564754760373506, 0.06894448111134191, 0.06054184106629222, 0.048551308667106975, 0.096853960515751, 0.04648823388701966, 0.018536472174849723, 0.04206707535852348, 0.06135503956747632, 0.11947851342659806, 0.16422605382338648, 0.15328429579254121, 0.0732551429480795, 0.11921374577908747, 0.030564508408368118, 0.22336313861512372, 5.235024200331781, 22.3148581289476, 61.40139064481182, 88.07600636636057, 79.12689132075157, 47.5438960905998, 33.60496528687016, 45.19400412036527, 56.444267842077444, 84.92725310787078, 92.88058034835323, 68.60281913511216, 47.46495839088194, 14.500250412571816, 5.542787582643571, 1.8711605619999672, 0.245547175647751, 0.02662881405182904, 0.19644359036559061, 0.09738050806786745, 0.3704902325426379, 0.08855352043023995, 0.10855485039252429, 0.10286869300949959, 0.46708736208177387, 0.6588149611507693, 0.42574371121102766, 0.2259251664602949, 0.023385291626196236, 0.12827799850774388, 0.4057949961673829, 0.5657489453592609, 0.3439796373488442, 0.1719763814922302, 0.6471440099900769, 0.8960803586148447, 1.0659303251774082, 1.7392637556599033, 1.7185931099999336, 3.1662127087193155, 1.6096281957241798, 3.96357516127248, 1.8970544564147152, 0.5832353618837173, 0.17416146343513844, 0.030826328532590024, 0.1246276738182191, 0.04389817488469905, 0.05993014284139199, 0.08216797073762264, 0.12929811352683654, 0.32302173936078626, 0.28680517788856263, 0.19973275822497186, 0.182833502129201, 0.18669553521660068, 0.8103953241821259, 0.3693022140331807, 0.5497032644287233, 0.6467351641866469, 0.1816130014917543, 0.1413479411313611, 0.4664697726407359, 0.8550336127800326, 0.5531993832799696, 8.686427051021207, 34.05968958331693, 52.97689653212025, 67.87676488199543, 72.74650512203094, 55.35747712658298, 42.26433092548002, 24.009020020884854, 45.83726890625493, 66.3625652559342, 82.87382956474059, 56.86227483134116, 30.542668911718554, 7.203149920509708, 0.4607635820584913, 0.11050463609036901, 0.043475198589505694, 0.0770710192380413, 0.06297187579254951, 0.12229662914309772, 0.05542745340555426, 0.015276036443068616, 0.08317253417185239, 0.05203517011156486, 0.06650256053093942, 0.04975131262213953, 0.05357725147698676, 0.05755807798836501, 0.10492518709431733, 0.13624936552538028, 0.026129117881458615, 0.08191173730958855, 0.034924129009126656, 0.0739006256504405, 0.06690867906135899, 0.039204331189994855, 0.03786038697486924, 0.023401865938438043, 0.02687893218300756, 0.028756596448440707, 0.09044296904316834, 0.022859379927056934, 0.03722816142403791, 0.0339566825348283, 0.05864021548580739, 0.05275004122766757, 0.1084531062553006, 0.009998711456935252, 0.029024235010447524, 0.07211845999042835, 0.02530296291825512, 0.0746786568854605, 0.05196490452714986, 0.038969835506812225, 0.010009303580098336, 0.043779258886652614, 0.05262279019300496, 0.039358839633003365, 0.028816650080825054, 0.10828699541067886, 0.13977435056961354, 0.1625411353644825, 0.13865523400806612, 0.1409586612135172, 0.13493719480691418, 0.15267099644387924, 0.1643083469882127, 0.08850514197782164, 0.1433988810787278, 0.2148210743982946, 0.17312919060068746, 0.21368965446468324, 0.12403501287823725, 0.24041335999725327, 0.12467346289345335, 0.11092578526586296, 0.19032601056800735, 0.249875235341249, 0.14400856449238716, 0.16624455760803916, 0.17635644323402838, 0.26609478758708127, 0.09714701979030525, 0.1387915670150711, 0.1058272556251576, 0.24538199176951764, 0.19891908091883506, 0.18685604595849592, 0.1949942132998859, 0.240770862587998, 0.15540655852565843, 0.16665020116394566, 0.3272736805581278, 0.08420792498415516, 0.13120893599285235, 0.14049586749845935, 0.09317349026640577, 0.22127924156525444, 0.1844375676685764, 0.16474601301935413, 0.14878830962604092, 0.11678148556741015, 0.22158851126028647, 0.14219992283371188, 0.24808326375580605, 0.23901468263037745, 0.23303441643234224, 0.1671531225644773, 0.4231689509845549, 0.22520112144129895, 0.3524238261724672, 4.56715585724, 30.309262391059633, 76.22373334823116, 102.0576007904545, 107.40077895502891, 88.35711479187013, 63.7317099878865, 60.64545185335221, 58.67616707278837, 76.68827533721924, 97.87358499342396, 95.88244868863015, 74.19355377074211, 29.103147291368057, 11.504456843099288, 3.826350060201461, 0.2499873599698467, 0.2435379415269821, 0.29127159306118566, 0.2968681717832243, 0.5583269629747637, 0.2047454706963993, 0.17381870037605687, 0.3311169598131411, 0.8787224610005656, 0.6930975796234223, 0.6925508992806558, 1.370446720430928, 0.5902711133803091, 0.3963010217393599, 1.3908544447152846, 1.624806542550364, 1.0802364349365234, 0.6374499946832657, 2.8516050356049694, 1.6133240490190446, 1.5251125178990828, 6.390831470489503, 8.472964802095968, 6.802174352830456, 1.280210265709508, 13.603977061087086, 5.532115793997242, 1.4161141409027962, 0.23426623984930978, 0.19334608238310586, 0.298732707216855, 0.14642333491675316, 0.2437808373642545, 0.30019912207799576, 0.3902033602278079, 0.29486040855127, 0.21781488471934873, 0.9842676200693654, 0.7908339125494804, 2.2569026245224864, 2.146611213684082, 1.3741527473734272, 2.404105009571199, 1.3919301547350422, 0.6418986366160455, 0.3332759488013483, 0.33396723590070204, 1.4089224751918548, 6.424464323828298, 31.01027034944104, 72.68952877290788, 79.56028969057145, 75.91651762685468, 73.02862551904494, 48.57953125430692, 51.654238008683734, 60.51512718200684, 82.72072376743441, 80.90885546899612, 93.97796538568313, 69.60427868750789, 38.81364145586568, 7.6016720456461755, 0.6530608441079817, 0.11615549980272209, 0.2835966790876081, 0.129291218735518, 0.15606727871683337, 0.21970356724435286, 0.19290245618791352, 0.12392618242771396, 0.17880308291604444, 0.1758711265339967, 0.40099514888659604, 0.17433453801899187, 0.1581311961936374, 0.1305361882212662, 0.1910127317833324, 0.2104939799755812, 0.21073462351435618, 0.22889329751412715, 0.1183685516157458, 0.15613791202345204, 0.11981753797660913, 0.08683824190689672, 0.1383168989371869, 0.20247156851955, 0.0816181264517288, 0.1420580739936521, 0.24520471902383914, 0.09867497449440342, 0.14281265527730988, 0.13817822170113364, 0.19894399409813268, 0.15613097126685804, 0.22005331702530387, 0.1131314902956928, 0.1614988880652574, 0.3261499521472762, 0.10963531781829174, 0.14528125103923584, 0.15020468362396763, 0.1086570311998648, 0.21459829602991382, 0.15485860647693758, 0.12836637441068888, 0.16623533390943082, 0.1561845667780407], [0.016995536110874628, 0.031542760552838445, 0.03324427822184178, 0.09153988437667009, 0.02433743549420709, 0.0027106850522555293, 0.034207089864198244, 0.029406193042955095, 0.04830146441236139, 0.043000798642395005, 0.04487592141113935, 0.1151569578195772, 0.06649860751725013, 0.014664536443418794, 0.055202997304619326, 0.05230961727999872, 0.026167659764929165, 0.05441041805991723, 0.021344900709546862, 0.007381166656306315, 0.05895853267922517, 0.13188310868797765, 0.017405285898055282, 0.026143851667462338, 0.08323104796750892, 0.04720459887457471, 0.05716987825449436, 0.018790257951965737, 0.01493918183710306, 0.11095645176547189, 0.04556011453631424, 0.058949653720182765, 0.03185164720390833, 0.06099672109309224, 0.1284411675747364, 0.06631483834597372, 0.0650439827492641, 0.05761251236582476, 0.07148899618656405, 0.04966042778124252, 0.10864992190392748, 0.045953454720156814, 0.049069168782162095, 0.05971517856983889, 0.16746516549779525, 0.041584642979526715, 0.07694609328022889, 0.13851603583222435, 0.06645551507150935, 0.05313602313699742, 0.1321876899249131, 0.38292601524341496, 0.18782859457836998, 0.4852014804078687, 2.3333358908853223, 27.526015197077108, 56.768753759322635, 60.67562664708784, 73.47025302148634, 53.97149193671442, 51.494601465040645, 28.89571862836038, 38.72221100714899, 52.72146001938851, 67.27554398198282, 77.99160834281676, 59.30717052951936, 41.61456677221483, 29.20872769048137, 17.317948764370335, 8.987848451060634, 3.8267550449217524, 2.8644463852528603, 1.4470563708774506, 0.43051656155336293, 0.12684889978939487, 0.11489965186844911, 0.18993449367342458, 0.5241311882292071, 0.6763096514248079, 0.1985579164278123, 0.29163275755220847, 0.3663115293508576, 0.46905847566743053, 0.27148415484736044, 0.15380315182189788, 0.2959915526932286, 0.5941522986658159, 0.4740467805775904, 1.0598632765393103, 0.5795604074674269, 2.64394715909035, 1.7877323613051446, 1.9939492570777095, 0.8613458708409341, 0.44820412212321836, 0.08509305531098958, 0.31062683511164885, 0.0684422645117006, 0.016435673310151024, 0.2476407100837077, 0.49442714020129175, 0.3156175608596494, 0.6177522194000983, 0.4483535092684531, 0.6537126930009934, 0.6823139421401486, 0.19582854433646127, 0.08838942439685907, 0.05539398685458207, 0.2954299489576971, 1.107283873904136, 2.1680371607503583, 3.2014841321975958, 6.475193808155676, 16.016614206375614, 33.10627906553207, 43.71438018737301, 50.8510503461284, 46.481294631958015, 43.93789645164244, 34.0923237031506, 46.59227417361352, 61.38972159354918, 70.97165615327897, 64.50987292874244, 46.32893800735474, 13.863748773451775, 2.022466971989601, 0.12807480900758697, 0.44834333562081863, 0.0934109009141403, 0.06823375836134919, 0.09754972922946177, 0.049882175761365125, 0.1492860982374799, 0.012938651432763907, 0.1837755451279302, 0.00924002777244295, 0.057162148427338376, 0.11889760427537466, 0.007714594455225574, 0.008847373237292613, 0.018008388616445086, 0.03836944857011399, 0.1864163268117174, 0.18670321141760196, 0.10399123398406852, 0.10043447927361536, 0.0462814016387828, 0.06175975615699446, 0.05181016242732445, 0.026269511154462254, 0.06935624570976343, 0.029866851287923997, 0.034311159078272126, 0.07214294416048835, 0.02938966469598874, 0.07659914738108074, 0.08038576677321427, 0.06697752738311406, 0.06311062580695556, 0.024623366320625912, 0.0467261501527842, 0.03966761903176385, 0.0510538689371559, 0.0421305074386539, 0.03605988883082906, 0.04582066486980166, 0.05535602719793397, 0.06498426619556642, 0.05882522188908151, 0.03017750568687916, 0.0220204217194189, 0.10666095080875582, 0.08488913036642537, 0.06076814343912467, 0.035655413559007074, 0.015316664958522927, 0.06176872704658778, 0.08129685981980256, 0.018522464257154255, 0.018783656189278252, 0.041848832230654456, 0.03168922124220239, 0.024567403597757224, 0.030998280797634396, 0.06554256809214432, 0.07432942804429801, 0.043250987636706525, 0.03289552818563196, 0.039725244165428227, 0.12089737721027867, 0.0535748957566196, 0.013086706542620256, 0.05853520781402627, 0.02735670483220489, 0.024521411509223046, 0.03864742740387878, 0.061215056151512175, 0.05710179219022394, 0.04517605550767434, 0.03888502574315475, 0.04463504421554747, 0.0317614384356045, 0.023214978789309823, 0.04439761058517522, 0.03814983031442089, 0.04386850046895204, 0.12516483168808684, 0.07771735995887749, 0.0698627677235392, 0.06057130863829967, 0.12344959146913984, 0.026121709811230822, 0.03441409831265769, 0.08593765192575033, 0.034394823540482795, 0.0855645594457465, 0.059690943378354275, 0.15136369804461158, 0.04439338944071243, 0.00896813263440685, 0.11893808436129363, 0.08820389322335682, 0.042704238346026796, 0.18822374272971384, 0.3137353747602432, 0.03649633678217088, 1.0478864417922114, 7.166939089375158, 46.437085597745835, 80.0308721296249, 83.57976990361368, 73.93332019928964, 49.665223706153135, 39.003299820807676, 29.292172193527225, 52.76927763415922, 82.323301376835, 90.30728586258428, 74.27752387139105, 53.227555597982104, 30.129839451082294, 13.81487702169726, 7.6723129518570445, 3.4112963705293597, 1.3565145841529294, 0.4599150324300413, 0.8927303480525172, 0.33325670467269036, 0.13653376800639017, 0.022218842322247166, 0.13939997872277615, 0.31954078905044064, 0.2322304837646023, 0.08147379548679437, 0.21813296442551, 0.06313419450194606, 0.3976641373047906, 0.12844441578753535, 0.12113875619346097, 0.4180584703722308, 0.281186290686169, 0.19126233855082145, 0.23092647954340906, 0.9724012245574306, 2.543443777868825, 2.5308392413200873, 0.8893920433136725, 0.1555472429120733, 0.39345898875786417, 0.10313479364999842, 0.1474944024436897, 0.06264069598288306, 0.03009160041748997, 0.07140544663754202, 0.4186264786028093, 0.2395680585816022, 0.43668249682072674, 0.2132116309216907, 0.2517897503510598, 0.41341135038002846, 0.2611966052603337, 0.3507116196617004, 0.14245743562857952, 0.8325434776563799, 0.6592811103309355, 0.39543154258881846, 1.3443401600083997, 0.615746662501366, 10.712595024416524, 32.66957413765692, 52.400437555005475, 81.04751909932783, 73.7249089825538, 65.28783190634944, 43.91737068853071, 28.63110573061051, 46.833331277293546, 68.55294227600098, 77.11280915044969, 60.422523944608635, 24.090140519603608, 4.178055755553707, 0.3090206245260854, 0.5041724833990298, 0.06289456602967074, 0.01611763956926523, 0.1343009128205238, 0.0478269035867866, 0.40436590510991316, 0.03990871073197454, 0.14955108805048853, 0.056896227817501754, 0.05973026284106797, 0.07617835060603197, 0.012773664822171052, 0.12480424176300726, 0.04091556476909788, 0.04952303757290206, 0.04715282282221222, 0.15335335095803584, 0.03544311527343046, 0.08096601708882278, 0.04556903563019249, 0.06752602335426115, 0.06296662809026819, 0.034579312834408016, 0.054807086895790794, 0.04218484605512312, 0.0077674109507502335, 0.023398596658221176, 0.04613096878353146, 0.08472309613059606, 0.060530050973137545, 0.020556801163982, 0.050299088470637805, 0.12111001257454196, 0.10148474751340766, 0.0775091602436958, 0.03975890606882111, 0.005519579224769147, 0.03569192147903866, 0.017037672861929865, 0.06496335199523358, 0.05955043519216199, 0.04805798251782695, 0.10134989305609658, 0.044582678275483276, 0.060864888852642435, 0.12186201980277417, 0.24528736458911052, 0.09115724644112973, 0.180188752109966, 0.12344239790353084, 0.27297508452207814, 0.2136770293356911, 0.19407605692263574, 0.14924486738539514, 0.15854394904548125, 0.20753061398863795, 0.24819045477817137, 0.19701048010779967, 0.21676471607098657, 0.0980568717744562, 0.17678716850857581, 0.15295709964008103, 0.13484275148760888, 0.20398618563288645, 0.12280185646828144, 0.25828783069887473, 0.1741192519905106, 0.30624766203184284, 0.18278847148101177, 0.11082739659374762, 0.1824090894191496, 0.12533845785524578, 0.10970825704956248, 0.19352303337185614, 0.23797539243054008, 0.25040762048334847, 0.12042230310579462, 0.2337253358094923, 0.1745009323161456, 0.18687127578643062, 0.21220563490304256, 0.14478983627932687, 0.1954005156914073, 0.2528285042893502, 0.12898913494521572, 0.12748903519804441, 0.1821106675291254, 0.2817358821630478, 0.2742930621870103, 0.13386546844436278, 0.2570479327151852, 0.21793589596786808, 0.19791909102951327, 0.2815943091146408, 0.15557733484573905, 0.2673958193871283, 0.2562677640948565, 0.5460224877442084, 0.3158519531209623, 0.7250595032688111, 7.936629220362633, 54.663056788905976, 93.24004204042497, 99.3479411832748, 103.37948660696708, 78.0681965428014, 73.7376880645752, 47.1969271475269, 57.99310984150056, 74.34081523649155, 89.84042183045419, 103.97635367608841, 81.40275247635381, 62.60233017706103, 40.0076933060923, 25.190996854535996, 13.469366219735916, 6.832958094535336, 4.472443365281628, 3.3123648791543903, 1.3851872326866275, 0.270570058736109, 0.2043349088560189, 0.1659092562453401, 0.5567702723126258, 1.125652333421092, 0.2763870562757215, 0.44673580736402546, 0.5174085521890271, 1.0717979458070572, 0.7916954856726431, 0.33027980957300435, 0.5690881081165806, 1.2118400441062067, 1.0172366735435303, 2.0103785948407267, 3.378396510116516, 10.376503794423996, 7.677876833946475, 4.521327864739203, 1.8025530370012408, 1.0762790085807925, 0.18319373199295613, 0.49851924481411136, 0.2954697242427257, 0.30443984774812577, 0.2689189553981827, 0.7053469578104635, 0.30058455623445973, 0.6583014983803995, 0.3834866077428864, 0.546330577663837, 0.5209517394823413, 0.36005298937520674, 0.3845190491166807, 0.2185222136998369, 0.8885074262657474, 1.6884940670382593, 4.10457922085639, 8.149691387530297, 17.624768326359412, 38.06792043870495, 69.05112251158684, 80.44826722914173, 77.86387243578511, 64.73832353468865, 62.84937281762401, 51.59228024944183, 66.51018757973948, 77.0357031976023, 86.59895158583119, 90.00204701577464, 74.83970149870842, 33.40326132312898, 4.6153039316977225, 0.4481756849394691, 0.6264148964997261, 0.24876532715655145, 0.14422916717106296, 0.5036787550535895, 0.20549275882301793, 0.43960990264050426, 0.18795640868765695, 0.2332539159444071, 0.10115943593724121, 0.21320735615107322, 0.2860325322516503, 0.05778312397700164, 0.19379067384908277, 0.16908766311262885, 0.10917791736222084, 0.3063204403846495, 0.378510590883032, 0.2571018653050546, 0.20910342314070274, 0.16932623821400827, 0.13429190362653426, 0.263589833292269, 0.1653443889752511, 0.10298945144900393, 0.1498680799117973, 0.18978100029691575, 0.16876962937174306, 0.10456750830335003, 0.21912518618327959, 0.22805915033865362, 0.24181516300286018, 0.20785993986552764, 0.18713724619198233, 0.26651880193141203, 0.17146844987667378, 0.29403671081508365, 0.13236074918700805, 0.13622823682042862, 0.16791095206093404, 0.1524921608788352, 0.22737131063495913, 0.12037123568476209, 0.12101450439302192, 0.11479360231709097, 0.31271408762662645, 0.22849415038381854], [0.03287618446554388, 0.07177319948471363, 0.06193489151736421, 0.05963352125798983, 0.048734614355189186, 0.04883496804283031, 0.017399563221260905, 0.028217716795963146, 0.047478111415740945, 0.10797440089405545, 0.06104794556214925, 0.0474076236658279, 0.03983986241021945, 0.04207629522669219, 0.0038054438482504342, 0.0008900623171000682, 0.022606944379907463, 0.02455655770796922, 0.013856671829407495, 0.0869884487662104, 0.05601238451838013, 0.026308627603876016, 0.06654524695008032, 0.06852469557235319, 0.05045735840535453, 0.043056818821858016, 0.04293984485669963, 0.09349520122932811, 0.06558488678908156, 0.02284020091587257, 0.11876163132969411, 0.051787873099167506, 0.11136471534207945, 0.052267873149004676, 0.10842869869403302, 0.01750265184279171, 0.05011687062740807, 0.03485545688759416, 0.03285660708863889, 0.06999093423327131, 0.05302445392214483, 0.024850362003029838, 0.0801352636828538, 0.09114554827852596, 0.01073411660223839, 0.07651010498164162, 0.1155283266017514, 0.08910842089643402, 0.0439295768287153, 0.2650464115844619, 0.04875144530688563, 0.10333820531565337, 0.007596782102595054, 0.32697083067990124, 0.11762240496013435, 0.638071506494476, 5.0505600340904735, 17.456610433516964, 59.40181732177735, 67.33601124055924, 65.6245634632726, 67.08480696524343, 47.05544333304129, 28.28793364186441, 23.04897089158335, 44.69879311899985, 56.97575292279644, 73.03765481518161, 74.52829668598791, 74.10440614146572, 56.518875245125066, 47.37892120115219, 40.0563463857097, 28.674171393917455, 24.074941335185883, 20.355414575146092, 22.154513597488407, 15.675882812469238, 12.934485347040239, 8.276054955297901, 4.266616500193074, 1.6155890952194891, 0.3446831205679525, 0.16632648305066172, 0.08037011559692123, 0.07673601664963269, 0.10187509995434554, 0.2452902757232228, 0.11831373036388429, 0.14026568872073006, 0.3485947348658116, 0.7547226728450868, 1.35984443128109, 0.34859626704166013, 0.16064522096947317, 0.11961451701579556, 0.09290863068834429, 0.22863380821241489, 0.11143007030289982, 0.3118105022416961, 0.2903965980775895, 0.39710523019875255, 0.6190185320954169, 1.0392090558044373, 1.8577426239367456, 3.5333115006646807, 5.651092558137832, 6.1211650890688745, 9.877119391195237, 10.421804228136617, 11.993162593533917, 12.757929659658863, 14.763152176334014, 13.197034097486927, 34.20391905692316, 32.35289177586956, 37.3109971323321, 67.51026645783456, 40.873619279553814, 55.20273570091494, 47.71984577178956, 52.545855506773925, 70.89679379617014, 76.86435837899485, 56.7597048513351, 17.589115942678145, 0.8038031069501754, 0.3518641223349879, 0.34264673629114706, 0.06564477954300181, 0.05138080845016146, 0.052807425043635794, 0.11390884737333945, 0.15885056807629525, 0.05614054336723301, 0.04299337525040873, 0.17795677026433332, 0.03208678065528793, 0.033062259561472365, 0.05001333001400194, 0.044927521263279264, 0.03197511759466462, 0.004364415832359585, 0.08508365541215866, 0.03220581156652301, 0.08887102557045799, 0.017153896060922456, 0.07491063596981187, 0.13890720032636197, 0.1211723031836652, 0.05717991017586282, 0.04575941230981581, 0.058389674091050704, 0.051077487427861466, 0.015217665331287971, 0.07039590363180445, 0.04755137623437951, 0.08570939602871096, 0.10427153023380427, 0.007684849655150526, 0.08320488606489475, 0.07967194136712821, 0.100047298436684, 0.04641311513560434, 0.03578632649394774, 0.057071635139084635, 0.1604854916372607, 0.025805045452509678, 0.1138561328632697, 0.09741256118661935, 0.09093791546840822, 0.08547478926277931, 0.10990302724343155, 0.06824366387821014, 0.018158756354222857, 0.028196672360683163, 0.023881961749265754, 0.09382461137588947, 0.01962899207888592, 0.042083450487904975, 0.05575937632050726, 0.06860478240395747, 0.033208011619506345, 0.04910471526184871, 0.0481814299259455, 0.032535489843857866, 0.07799569502352707, 0.08920466452236138, 0.06381992746384875, 0.07425940760801877, 0.03378995881986714, 0.0454102524165665, 0.0401039099350812, 0.08329440343884692, 0.03565753945299695, 0.024387863231822852, 0.1116564492845247, 0.05027082365667147, 0.09653391196362435, 0.092331322150365, 0.08663899009867061, 0.1431858167052269, 0.10181118523882282, 0.05489898297274786, 0.09304883243936686, 0.024382822373281085, 0.11100920457993785, 0.0894165721030966, 0.12328696632457357, 0.04493512851636737, 0.051657193821043744, 0.038702252486179915, 0.13948961100991697, 0.06233672761628705, 0.03927316802043108, 0.016471667951273344, 0.09863983404131667, 0.02337702745271306, 0.07134847267861329, 0.09401148320325921, 0.10176512803281508, 0.1936755767993389, 0.050226118595850085, 0.052354969685116125, 0.08661282819605644, 0.1919807604844532, 0.06344350633181392, 0.042374349394512754, 0.1097385788096055, 0.4083776011342003, 0.03972935039670237, 2.1589029412115774, 12.295832287880684, 31.424486367933213, 82.99792551225232, 80.18215010243078, 74.51568234351375, 52.286457400168146, 38.90687619486163, 33.608024735604566, 34.63676829491892, 74.08036201230942, 77.79537216309579, 85.49940140016618, 81.92874231646138, 62.46639259399907, 40.3395297450404, 29.004644809230683, 19.305001881814775, 14.489535477853591, 8.006148328704219, 4.103719976640517, 4.757004457135355, 3.503586063461919, 3.362006150907086, 1.6874865082002457, 0.47767819055626476, 0.5326798714457021, 0.285481347311889, 0.2350972307425353, 0.29893201265123587, 0.057387470207627744, 0.05171850383762391, 0.5032593985238384, 0.06684264994316524, 0.19661740039385137, 0.4297698709753252, 0.5284937218792978, 0.6435867879659899, 0.36009898529418055, 0.13103043750649498, 0.040646012902500174, 0.1049293852561424, 0.23340636744133889, 0.01554856934930168, 0.1805742628752224, 0.17655792435811413, 0.2793327562751309, 0.44155791101436465, 0.4712504677234158, 0.7737521743101459, 1.2372318751388982, 2.3859723825608534, 2.0748132082723805, 1.0571382098620938, 1.8343567175249902, 5.090497607184995, 8.476351768739763, 14.145601468701518, 19.134247379918254, 37.09911854036393, 61.188229437797304, 69.77794554925734, 83.34146238142445, 62.86268534198884, 49.20600045111872, 37.92914305963824, 37.588285169293805, 68.2676447591474, 87.36027579153739, 72.51979997081142, 26.510087982300792, 2.7306205082324246, 0.44085338591567935, 0.5811538703499303, 0.1727317135420538, 0.09138144973304965, 0.025506077724839413, 0.04247369184609383, 0.13489239398510228, 0.12687103206952735, 0.011779024141780552, 0.08338274869827494, 0.02882832526079109, 0.022074509442092913, 0.04240534148148952, 0.05533040155686679, 0.0383113369706177, 0.04547243960381997, 0.09828052348307065, 0.027056227911323793, 0.06781597231184283, 0.02908983320418385, 0.05470825389267937, 0.13516466163339155, 0.1073880218750527, 0.06631652373940715, 0.007563323212502105, 0.10855770790048185, 0.007292093613350223, 0.02842134871189633, 0.1797307847488311, 0.051375510952165054, 0.008446619237562823, 0.04689344460324896, 0.05350256173480904, 0.050809869933272564, 0.05146440396445894, 0.16720558426553206, 0.07266176954632805, 0.08489741177688684, 0.04176627093505475, 0.08398275642145066, 0.07471585811506357, 0.07700807745418242, 0.07839407606591141, 0.06083207347640588, 0.05444342878857448, 0.007646274255333289, 0.09581738226716557, 0.014816489025589921, 0.05079371313894949, 0.19034649575910262, 0.15470128266080735, 0.15362928050660318, 0.16748730543880694, 0.1995514711785701, 0.13072482971174101, 0.17233768387907938, 0.21056579305760323, 0.18827130146805318, 0.1282525184233823, 0.14628789057174038, 0.1907119350207429, 0.1044681543604501, 0.14333247657745116, 0.12002217538294294, 0.21720786729166586, 0.1226560392927739, 0.1774710705203395, 0.12968727087061252, 0.21839410847713872, 0.1912995397804245, 0.15897315746593862, 0.20552065974522024, 0.23830287969641148, 0.2219235368313328, 0.32341734716488474, 0.2769416120023497, 0.2237011825725917, 0.1812580269911597, 0.17039558970399443, 0.22699198986013092, 0.19843943326944308, 0.17782014614391714, 0.09737377415501303, 0.1719722599391976, 0.1458154594705951, 0.2749766577636042, 0.25069490345495365, 0.2728232152519688, 0.111234235246816, 0.16810506341918824, 0.1205385416265457, 0.19835680302593017, 0.15062393290140938, 0.11486703184463325, 0.22461713261661992, 0.16508053297237044, 0.18263085655147032, 0.16921279591418084, 0.423692709976627, 0.2270382002837235, 0.2233645328951459, 0.22545970675926055, 0.5816100297435638, 0.22006560507560932, 1.6255341422173286, 11.353194559774092, 39.455945261063114, 96.88685001865511, 100.42607522779896, 92.07140322654479, 92.33793612449401, 68.39246242277085, 48.996651787911695, 38.20252441590832, 61.43151837010538, 75.32393378596153, 95.15666900142547, 98.54547131446101, 102.08934845462923, 78.31346234967633, 67.97841702738117, 62.933817525063795, 47.804949437418294, 44.328462539180634, 35.71201155262609, 33.10631436686362, 23.254383456322458, 19.173031776182114, 10.071937634098916, 5.574639679924135, 1.4810525337534568, 0.4028521153715349, 0.28045957968119656, 0.27204091690721055, 0.20826910742588584, 0.17891402776923873, 0.46586039566224624, 0.27996070322490507, 0.5312127211401539, 0.927061015559781, 1.9378232042635641, 3.4776197277730514, 1.8515268929543036, 0.7469766046251021, 0.22506120314280834, 0.15391015898316138, 0.35779486860959764, 0.2319983897670623, 0.2794112343220942, 0.23879628628492358, 0.31569944033699654, 0.6215035987477149, 0.8578389654717139, 2.0883127806648134, 4.617431817516204, 8.41099331455846, 10.87772680867103, 14.56949789677897, 15.918908945975767, 24.621858981347856, 33.7255036446356, 45.79506028083063, 51.522077668097715, 75.61301246766122, 66.94652772718861, 66.10762688421434, 94.27974470200078, 66.85949033306491, 76.9655555294406, 68.91485152706024, 72.14509594825007, 90.22814812198763, 98.24413130360266, 84.16750569497385, 35.64053420097598, 3.6877609549030184, 0.48115233800584273, 0.5806370980797276, 0.20296736530238585, 0.20481561370674642, 0.3256675312595983, 0.1956976505537187, 0.26381095691073325, 0.22495845543040385, 0.21761012473894706, 0.35471216144580997, 0.11462228207458412, 0.1982725639977763, 0.14593262495773454, 0.1407398511805842, 0.15561116528847527, 0.07706955601010593, 0.16663881709739087, 0.11051169942103087, 0.1393355047630687, 0.08872408224570175, 0.14009555591450584, 0.24720310533960022, 0.21312261150488931, 0.20224428555417448, 0.1734568923711777, 0.2998647400208058, 0.1444049077408929, 0.11967223408001086, 0.19184277272753178, 0.15413653796478627, 0.14944758957191823, 0.3604552774660049, 0.18571583133551384, 0.16591647279358682, 0.19559772204487555, 0.4580675041483295, 0.0929798998479401, 0.2613512018034535, 0.12652347330003977, 0.33186836949279236, 0.21836807680947168, 0.17319392503028916, 0.22791008495034712, 0.28595573959812043, 0.1239324183834176, 0.28931607702566736, 0.14654474453099314, 0.15039612899624533, 0.10879982232807145], [0.0771055621425471, 0.21209749393165114, 0.15419682908442714, 0.07777771236555231, 0.037145021732055375, 0.03183428765154414, 0.07577869785769333, 0.004633587049019914, 0.13995769073165235, 0.11144629604513608, 0.11505349764540312, 0.09655349317096895, 0.16611125830921436, 0.009392630571739809, 0.040066015395906665, 0.2032433714597456, 0.13771823186787868, 0.17725581513537517, 0.16002196247779554, 0.16135175321852008, 0.11638477459670075, 0.05009783717292932, 0.08380723801711876, 0.12011008397225412, 0.037800195446658524, 0.17606099376515036, 0.05035425829250486, 0.05129619403892467, 0.10920346639449559, 0.12905799092785006, 0.19316799758422762, 0.1900498818365797, 0.05227404398723476, 0.037334149688362114, 0.029765695123182192, 0.0694757784085889, 0.054457099627583265, 0.01809728162873897, 0.026290697316008232, 0.05855974944068059, 0.045594971536869006, 0.02870902238834289, 0.06018169930264835, 0.06718339819100595, 0.11486126320256342, 0.09551604924302909, 0.03505490021780133, 0.26870546201544426, 0.04165898415169889, 0.032992116551125245, 0.04412744201779847, 0.15402547053752408, 0.11686292071376117, 0.04616716643795372, 0.11507972083505123, 0.13643969240928852, 0.08906065531435514, 0.3936068130837333, 8.836765616170823, 42.164781170506636, 73.24104539809689, 72.63222294469034, 67.99499296372937, 60.51757866336454, 52.24295047021682, 36.45528893316946, 22.32847659818588, 19.73277949517773, 35.95397472381592, 55.974265913809504, 73.57792208271643, 71.65472122930711, 79.79956211582308, 74.12944655264579, 60.70675065440517, 58.393505388690585, 55.659986003752685, 52.86782326236848, 46.59105431648993, 41.39108580927695, 34.452867969389885, 25.457280681979274, 18.46055284623177, 14.36738306476224, 10.5897444294345, 6.3803249116866825, 4.047896314051844, 2.4386152480879137, 1.4052334860447915, 0.7833390598816257, 0.6997073862341143, 0.4652766060204276, 0.3413939986738467, 0.28819130673523874, 0.4791606319767814, 0.9259986661134229, 1.565866066563514, 2.51764071083838, 2.8010042540488707, 4.376539943679687, 6.669693848779125, 11.379891191759418, 18.785021112811183, 29.501497322513213, 34.81098428849251, 43.332153058821156, 61.490216639734086, 67.66070504342356, 63.29731925841301, 46.04610766133955, 34.375993436382664, 28.391060598434944, 20.545667179169197, 20.64867646463456, 27.49783100620393, 25.30604193287511, 22.457028358213364, 50.26356950882943, 47.35044871607135, 59.882939169483805, 70.12782881336828, 80.12387152641051, 68.85713777234479, 31.750415717401815, 3.1055228556356127, 0.8647342470865097, 0.20091172157516404, 0.11419229224444398, 0.046959925713318015, 0.2544231622690155, 0.1316971331834793, 0.07927239587109897, 0.161844807406587, 0.06413130390067255, 0.023943059176446933, 0.06579317843481418, 0.08188351463045805, 0.027137948425426602, 0.07261156780464996, 0.036061145215024876, 0.09593237206460008, 0.02773871457564735, 0.09609574797533213, 0.07727907339651739, 0.07379268386190938, 0.04762488620115384, 0.08116519228825647, 0.04970875260750613, 0.07065852623312704, 0.058516848516920884, 0.03424258654816978, 0.08579745017472776, 0.02430169174687997, 0.08830525431661837, 0.04732370639460222, 0.032935870375724575, 0.06592321419908155, 0.07389217570063568, 0.04759010963983113, 0.053239617376558246, 0.048821933056798675, 0.026656050392757022, 0.0841480628737519, 0.03493498447501371, 0.04737121150678685, 0.05228459684839172, 0.01573130047144068, 0.07830844275773534, 0.010194317644251692, 0.034370243609432256, 0.0267319486386353, 0.052775391077082005, 0.05361863554665639, 0.11430468500381517, 0.07830120322685089, 0.054198966301496954, 0.06183037797229425, 0.0924861331981036, 0.09904014562527019, 0.10305838404043068, 0.16176865826691353, 0.06209036523115732, 0.04704973420068141, 0.055268038169390736, 0.037608669635148785, 0.09612357994962124, 0.04280776746811406, 0.04355667204025292, 0.110201993055882, 0.07982106804246865, 0.0705894710676324, 0.19330552568839443, 0.09785423385760478, 0.11107839764125886, 0.1124196260746929, 0.08523983009640249, 0.05524375318219105, 0.07418869769260769, 0.05576424097882644, 0.15650650756734033, 0.05040508439584125, 0.040215134410367864, 0.19240368698393145, 0.0666671775041088, 0.10295058014772593, 0.048238894181145776, 0.07607860595829065, 0.16288785143725334, 0.09433621255260322, 0.07577222441473315, 0.05369861512595127, 0.07377277323675734, 0.017517554168138775, 0.01551820832725254, 0.0054946535965427765, 0.03462808199166771, 0.0927978850180103, 0.08475600726782315, 0.06761858975815196, 0.08664958509466342, 0.10773662252411728, 0.1357203664919061, 0.020518178841279402, 0.11411989693559947, 0.0876110790657901, 0.09054252982980783, 0.09733436659218804, 0.06896559449453508, 0.09787065878270135, 0.07012019624873515, 0.08754493503440773, 0.1283610424387359, 0.14941352930280472, 0.8881076509433409, 17.376813734731368, 65.85589701129545, 92.70297542695077, 84.87223009909354, 68.16188196982107, 55.64653619643181, 36.97843897727228, 30.32365356722186, 35.48236070140716, 46.73562503630116, 55.447209189015055, 77.89349417532645, 79.82521441675003, 77.91831493377686, 68.9045435382474, 55.79311516977126, 41.5781161862035, 31.145947094886537, 28.375761393577825, 19.898281943413522, 12.07171590097489, 7.770998804799973, 3.557488254962429, 4.377302354381931, 1.6955586234408042, 1.8518948603060938, 0.8045024532944927, 1.0169551209095986, 1.2878496944904327, 1.076458457016176, 0.8363619050191295, 0.49232989789978154, 0.5264347839740016, 0.37040299044982083, 0.19297961656364704, 0.18409336436419718, 0.16027124748835642, 0.44270287538247727, 0.71338934883956, 1.7142526396820623, 0.5852115010061573, 1.1254927419847058, 2.813851732400156, 4.731566415679071, 7.339502294217387, 7.596263587474824, 5.011214738891971, 9.553891574182819, 20.932830610582908, 39.67086368991483, 48.06466525600803, 50.98485023744645, 50.9345458399865, 52.53157023460635, 61.4037597563959, 63.75016081717707, 71.59086504290181, 60.97555852705433, 41.795941091352894, 74.16487340004214, 38.496415845809445, 53.56039616369433, 69.02022992410969, 81.68826964593704, 84.33936042170372, 47.87680333660495, 7.465622675034308, 0.9887389382047038, 0.3077411351184691, 0.13737902345676578, 0.08922681978513157, 0.040528705689094724, 0.2094754507584918, 0.1016417112682135, 0.1693271575195174, 0.04633068407495176, 0.09702754071763448, 0.07937941069324171, 0.08037900221684287, 0.1340296410865361, 0.03189834600855266, 0.04412495606248418, 0.09870590146390662, 0.04655397955268141, 0.06774143961768958, 0.03155737559521391, 0.04327795776208082, 0.05091285896337321, 0.05155867108354165, 0.019088153156542012, 0.05322724888702074, 0.08990868400301665, 0.030136133108528394, 0.010568536273504217, 0.0318961511666496, 0.08186185732483864, 0.04528660199514801, 0.03206061492223413, 0.09697959893533299, 0.042420257213375265, 0.005885587306693197, 0.1361841867647825, 0.03325569676235318, 0.04445743439118228, 0.05647137077645429, 0.04644084368802367, 0.0681398896079871, 0.045735495044819774, 0.08200907644124762, 0.09993790874197599, 0.10393336370226838, 0.062022685193486755, 0.06723300238410312, 0.08421013897825634, 0.05585106172328515, 0.06974362572955509, 0.010049300073015114, 0.030966204696244774, 0.1585227743752541, 0.2571814158751119, 0.28778172548740144, 0.26028198820929377, 0.2527987034690957, 0.15750829010240494, 0.20825550170435062, 0.14222990751506823, 0.3462619358493436, 0.21643863840689584, 0.31801918521523476, 0.15946682452434496, 0.24781680305398282, 0.16095556318759918, 0.17238557969610538, 0.282757812810521, 0.1621133518675643, 0.2756560551783731, 0.2802004581016879, 0.28765780310476985, 0.2224729291253513, 0.22477234203007915, 0.1602600779264204, 0.3847023279916856, 0.2192279185739256, 0.2599870137149288, 0.23052106581387982, 0.17172081456069024, 0.14484306406830588, 0.1826872865879728, 0.2025225440100316, 0.20561839724259995, 0.20346100171727521, 0.23927780318885083, 0.18748302763748556, 0.1907070320580275, 0.13642040231535513, 0.13918236378700505, 0.11493270090150257, 0.16358557367517104, 0.22047702493446492, 0.256587176794006, 0.21396239708748557, 0.09880470382350107, 0.19797083260791917, 0.3007970077376212, 0.28807290018566195, 0.2081447713557751, 0.15787221250995515, 0.21036115565126945, 0.2091197254917314, 0.3354192176653493, 0.20474283535393978, 0.12259338096144701, 0.23750757317869897, 0.3262283995507225, 0.345489627291118, 0.6365459496455809, 18.84668469429016, 75.3473581806306, 107.55239425166961, 98.39391093100272, 94.37528579465805, 86.89740473224272, 80.95178973290228, 57.14426186776931, 41.50228108129194, 36.985354115886075, 49.82849628694596, 76.86469570282968, 91.36997361336985, 96.88358660667174, 106.46061820368614, 115.08289783231675, 102.91835708002891, 94.20037946393414, 92.80317629537275, 85.61416995140814, 74.97748651812154, 72.51246513858919, 57.14843134726248, 43.453742611792784, 29.80591639395683, 19.06207576874764, 15.560463147778666, 7.043804612851913, 4.449219011491345, 2.8690647309826267, 1.9732642702517973, 0.8473612115748468, 0.6729761883616449, 0.43898992300514256, 0.5190916780021884, 0.26593927173845233, 0.304740920302368, 0.9746561583972747, 2.0107729156171126, 4.487570476147437, 4.384727891414396, 6.681761020614255, 12.076025605201723, 20.378093719482422, 32.03793329577292, 49.882852492793916, 64.01974924149053, 79.23110869623001, 88.9617403091923, 86.94409662677397, 83.9504260401572, 68.27312038790795, 69.95526021526706, 67.42207588688021, 62.37773526099421, 59.537503873148275, 55.83175836070892, 58.474423885345466, 45.38795355827578, 81.71161559320267, 79.7542195166311, 78.33480004341372, 86.23763853503813, 99.57390108416158, 99.63393688201906, 55.778759294940585, 9.30079573585141, 1.0001475195730887, 0.5436079011809442, 0.19142959086645037, 0.20970676334634905, 0.45490267235905896, 0.2863817457710543, 0.3084937092517653, 0.24855995430581032, 0.2690376070958953, 0.19313951443520286, 0.2097321668219182, 0.22815262838717432, 0.3087393476838066, 0.20297383108446676, 0.1234529316124897, 0.3070073148175594, 0.22644887948709153, 0.21985221894518023, 0.1717758043518951, 0.1507723241323425, 0.08850240704393195, 0.15214821804435025, 0.10596410191107182, 0.13011628010820958, 0.13126417093219298, 0.17496991602163162, 0.29324690480866744, 0.11679846973669146, 0.22443877202608895, 0.2612007727786418, 0.21175804037240245, 0.2273329449517112, 0.20311894345908396, 0.10225339417135525, 0.18324289951593647, 0.13953510131086075, 0.09532692511716197, 0.18746340046486548, 0.15668226345892877, 0.26882058970870515, 0.17528237264242866, 0.12489413452004233, 0.29303828374512736, 0.18185890039368985, 0.20913426584053427, 0.15506045532322701, 0.20786332597415294, 0.17156578900833286, 0.21148975638131942, 0.2637182296283784, 0.1709762996723575], [0.03311339593041809, 0.030777681949398214, 0.05081802493922653, 0.024029023817650253, 0.03552893627314799, 0.05265305832689328, 0.05561957676564494, 0.05179641880996285, 0.07233031394500887, 0.03942314505336746, 0.1069384431766887, 0.12127739512511801, 0.08669866068709282, 0.07721591710803971, 0.05841248818943578, 0.07383166241549677, 0.040219378537468375, 0.17548393037530685, 0.062057423450413256, 0.0923223206172547, 0.032274694362234686, 0.061705708653936465, 0.04107084696090991, 0.09092102322967784, 0.03697093591214188, 0.027039793410128164, 0.028235871164548784, 0.045167762605894, 0.09374724415641639, 0.1757113052712333, 0.05138156687720649, 0.010841902300354936, 0.06484864565033106, 0.02202749462617982, 0.01754742393630647, 0.04036251440524094, 0.049038061781996684, 0.06847989475054127, 0.03556632902473211, 0.04561183313208242, 0.017981096734142592, 0.03189237818362252, 0.0423058458123236, 0.06290069856350461, 0.10606978374022631, 0.020144050227357976, 0.035717378580762495, 0.02591824068898155, 0.11050322648858833, 0.1298708408590286, 0.02838788216092414, 0.031067954579127893, 0.022653131820862333, 0.11067428626120092, 0.025239722360105767, 0.03616436024106318, 0.14530345226728147, 0.13901785406614506, 0.0588559688279225, 0.3204942314374832, 10.876888402046697, 65.59171361307945, 87.53243646314068, 69.49131442654517, 65.58681065036406, 67.28161581100957, 54.85433117035897, 51.8625747003863, 49.290602053365404, 39.289785815823464, 34.34934877580212, 38.10816395667292, 50.551585228212424, 45.13827116258683, 50.569255505838704, 41.447167858000725, 50.051863501148844, 55.20373198293871, 59.11301712835989, 48.3893237575408, 53.20952446229997, 49.96262173498831, 57.390033660396455, 62.87549188060146, 66.22965966501545, 62.4531271380763, 60.12229396450905, 45.22602242808188, 37.676891511486424, 32.76120658843748, 28.180050811459942, 27.003151485996863, 22.52017459561748, 22.22276479967179, 22.331653718025457, 17.13919262732229, 17.405276413886778, 14.052771714425857, 19.59701841877353, 20.08467101281689, 29.8121411954203, 37.57372925358434, 43.7973657731087, 59.235689255499075, 59.15460209692679, 56.43517971038819, 59.401028925372714, 74.41191996297529, 54.44932683821648, 34.28351963720014, 34.88841187569403, 20.702528645915372, 25.595548152923588, 34.528597170306796, 33.488451280901515, 46.013163674262266, 48.49840094966274, 52.749206865987475, 68.8179297601023, 75.5873130982922, 67.79538354566021, 56.14848975212344, 6.662422264775922, 0.6436024774466792, 0.1383525679909414, 0.03830045852209291, 0.006460823576837298, 0.13475321113101899, 0.0922337072270532, 0.048024255496960495, 0.019778645439674298, 0.09137971071346153, 0.05909000102791095, 0.03566528843235105, 0.0673852317155369, 0.12519159113928197, 0.11270087993433399, 0.1594214108321936, 0.024281129946992285, 0.03350431527641993, 0.037264225013073415, 0.08046019221505812, 0.015298511547547196, 0.10211172919239729, 0.06320068327289435, 0.05318614443944347, 0.09373122525791969, 0.048223174056939544, 0.04088730378557117, 0.09362379674829784, 0.04992285503014442, 0.0431094337404976, 0.06356401962318248, 0.017668879515821898, 0.05327417560282254, 0.009793437240014394, 0.06005987600092927, 0.011527995323582042, 0.020954755112348546, 0.06171932969723017, 0.06811577316013075, 0.04980109301545928, 0.01200671792180548, 0.153532063949012, 0.10773552701838555, 0.08865349490435855, 0.04604445447424247, 0.07572163196821367, 0.07390603423118591, 0.036880349845535336, 0.06650827554685455, 0.05682102096597514, 0.0147035178698359, 0.04573009795539322, 0.03295903304411519, 0.047674310363588795, 0.07990733720362186, 0.028753610620755824, 0.04481360781937838, 0.032067055806457516, 0.010398685962202088, 0.030772778986682816, 0.06638715704602581, 0.019939106385854465, 0.062187539653912674, 0.058489231047250574, 0.039687403252408396, 0.021508134894012924, 0.014661844601974854, 0.08195939563935803, 0.052429678579491955, 0.053335646497866804, 0.07774804178024493, 0.08378286876024739, 0.06352899025284475, 0.04714332333195114, 0.015322035234872133, 0.04261501591592547, 0.07288990286929954, 0.051646537538017, 0.06572455993943638, 0.018397092053125945, 0.03745825210165593, 0.029527958888079853, 0.06803195548033522, 0.0905080022470605, 0.03042269787270456, 0.02729524925891911, 0.10554887459523256, 0.07565181071479475, 0.027210290108116406, 0.06052381118699428, 0.03856835563877418, 0.07269087322657147, 0.0280468791888486, 0.01710288609648424, 0.05383213275983449, 0.027648454096408624, 0.015092013505167298, 0.035704332103412, 0.03574917889049938, 0.031066313235750122, 0.0884920342134372, 0.12278186923433697, 0.1178981736302376, 0.12269999741786912, 0.06162739914631652, 0.03368109772582689, 0.09462180246989574, 0.2846706730704154, 0.037673783278273004, 0.057729934492418845, 0.11726671799777016, 0.14186753260512508, 0.08952884994927915, 0.9310338862480657, 23.073036593775598, 87.39851890071746, 102.67660571682839, 80.93719851586127, 71.06502425286078, 53.78996856750981, 32.46552851892287, 21.53565968236616, 37.33721817693403, 47.90163193979571, 55.71711924768264, 58.957193128524295, 73.44122748221122, 70.97830064835088, 60.51689617095455, 44.70163291500461, 49.423331137626406, 47.08690466419343, 43.38358317652057, 37.44563641086702, 31.071222020733742, 30.775177209608017, 32.29046529339206, 35.31470291076168, 29.977057249315326, 24.196501470381214, 19.044864408431515, 18.098214095638646, 12.471565258118416, 8.690081719429262, 7.002897233732286, 7.091990440122544, 4.5525852326423895, 4.397759476015645, 4.31558140823918, 5.194068281881271, 8.176950879635351, 9.357839745859946, 4.836302524612797, 6.820571249531162, 14.029868994989704, 19.779392942305535, 31.14034398909538, 48.17403662589289, 52.93637452587005, 58.98547733983686, 74.47469357521304, 95.16849102512484, 87.58167005354359, 77.18655755442958, 69.61084473517634, 53.958810913947325, 53.12800584300872, 48.070819454808394, 36.14192685773296, 29.83028804102252, 30.651463693188084, 52.57052721515779, 66.17390709538614, 82.16086818325905, 83.82014843725389, 72.67747140699818, 13.75866847653543, 1.0055204925517882, 0.0750310879741465, 0.039852456895694624, 0.004599714950252806, 0.3219323623324594, 0.2355369805328308, 0.038065997312866875, 0.023912882973109523, 0.03737192165346877, 0.008314386716172581, 0.09919029119754992, 0.029759809652703906, 0.033807138341569135, 0.10284773284389127, 0.10440745721420935, 0.02974026866497532, 0.04854579666449178, 0.11718750450639956, 0.0987497983019679, 0.04467310346362572, 0.09255708826165046, 0.012287910494412626, 0.06479942450119604, 0.02814328752367968, 0.0166353483819553, 0.014752948735540193, 0.05726626743712733, 0.13619995285426417, 0.03376494987957901, 0.03968020585635978, 0.08327927320234238, 0.10616906873521306, 0.13451106605991242, 0.036640886082163746, 0.03873098078334043, 0.03466896427374694, 0.07582209673860381, 0.09114149567340651, 0.07335596777979406, 0.05931363358432728, 0.009396705201887076, 0.04681494740408756, 0.14491861565939843, 0.11691374298665794, 0.056895699216834, 0.11003621928994695, 0.0448881711570486, 0.0707998005072436, 0.10690582315287284, 0.05352306990854202, 0.026780371141109257, 0.01195537279390039, 0.001989344682735992, 0.1562030141752574, 0.20328711508022201, 0.09239522154412924, 0.24625186928577963, 0.14616481088582547, 0.14096293598413467, 0.1419428696915988, 0.16513420509234553, 0.12216204281656012, 0.11376299955431493, 0.19149086257863432, 0.19660580182267776, 0.1392887733996876, 0.18957541294155583, 0.1796604425556237, 0.1553287852795855, 0.1960368589648316, 0.3562281575174101, 0.2956073749209604, 0.14936325861321342, 0.11682977208927756, 0.1942528240502842, 0.12155379198731915, 0.13838284378570898, 0.28834608713946036, 0.16047701870481815, 0.09318643715232612, 0.12348277073714042, 0.21851596242237478, 0.2687074232005304, 0.2281719031593492, 0.09248139111385231, 0.2101036581781603, 0.12210964240253934, 0.0900290517376796, 0.1791281953093506, 0.10672162497235883, 0.12785697190631784, 0.12130815355527787, 0.1458014094180638, 0.1622653590335, 0.14887595008457863, 0.15964438838343467, 0.19520816633537894, 0.19951675207384173, 0.17552509994035767, 0.12986468151211739, 0.23224427334723935, 0.22812861919162736, 0.22600667821543835, 0.17266455827461136, 0.1191208806009062, 0.16033893901734583, 0.5270007697324599, 0.17771897657263666, 0.1107630528689873, 0.212932376551532, 0.4718863513440856, 0.20803463855578055, 0.8536761662652417, 24.565688679295203, 101.59956209121212, 120.41637205308484, 105.13213496054374, 99.19507072817896, 102.03318011376166, 79.17474423685383, 79.46298353133663, 77.24736213684082, 65.58771671787386, 61.4596535313514, 62.336232662200935, 75.61902938350555, 67.41542354706796, 70.44436408627418, 62.21935779817643, 73.02584848096295, 75.85277911155455, 80.26513961053665, 72.35796297750166, 75.69568818615329, 75.51420796302058, 83.98841811764626, 88.58539673589891, 86.92151161932176, 84.59458904881632, 79.81975447747016, 69.06530580212994, 54.912244965953214, 50.71586585813954, 41.58499994585591, 38.44500926233108, 36.89928162482477, 38.59704817495039, 40.01377297985939, 38.45538393143685, 39.69560207859163, 39.55056851910007, 49.15344069080968, 53.94001099371142, 65.50378584092664, 70.55149186042048, 81.75194540331441, 91.81691200502458, 89.80970967200496, 90.16972834064116, 80.24748894476122, 97.36465746356596, 71.59892159123575, 54.917124394447576, 62.994163190164876, 44.383709123057706, 63.643535106412834, 76.17938703106296, 62.664429141629135, 80.27694594475531, 79.27820851725917, 68.22334551042127, 82.62404518742716, 97.81225481340962, 101.85759129062777, 84.643430402202, 17.871640343819898, 1.5202274509975988, 0.12655728842101752, 0.26671896538426804, 0.20875004210299064, 0.5119187048365993, 0.22895153551813097, 0.11268114550940453, 0.1210071652707073, 0.1541993265310603, 0.16908387863828292, 0.18440208247592374, 0.27453211226290275, 0.2205741342397467, 0.3029833000994498, 0.16624593656630288, 0.11660338544677343, 0.16341349500561916, 0.2279388745345416, 0.2314364336310856, 0.32364607037555787, 0.29602238007130166, 0.1448092183038112, 0.16971226991905322, 0.14511641956144763, 0.15097443344852618, 0.16902902674290443, 0.24320974946022036, 0.17353638165420102, 0.16242196272698142, 0.18135754181252373, 0.12597320000490836, 0.3093656398836644, 0.17170281149446967, 0.09299367410881866, 0.11370254755620995, 0.13777886006620624, 0.2407706634051377, 0.1694414118725446, 0.19038637829644067, 0.08978296897464222, 0.30110754913860754, 0.21829568150062717, 0.15375654303258465, 0.1616964774626878, 0.1239904955089573, 0.2530232591614608, 0.17024568161897122, 0.25553463327307857, 0.2796599371058326, 0.18382128057700975, 0.13493310389739854, 0.17218181563000526, 0.17580789363672658], [0.07139292109998004, 0.12328729574238101, 0.09345020888553512, 0.0928143865518993, 0.028874418855975234, 0.062332069801707427, 0.06882176148675143, 0.016690403290633715, 0.11202745800537449, 0.12002697109334892, 0.06129639936731227, 0.08307983753301444, 0.13944926881982436, 0.0856543526113514, 0.05404654927852173, 0.05999798375752665, 0.120564044693545, 0.048704744587021495, 0.007452205031914938, 0.04703695202366479, 0.09520293378661718, 0.06833066848377067, 0.08512266460926303, 0.03767792781394336, 0.06314588117323096, 0.02456012767769637, 0.04785755093419745, 0.03669054390141561, 0.07427680546477919, 0.014342456800682891, 0.04871902063549046, 0.0745041037519132, 0.03349514903440591, 0.07435970383906558, 0.02375226497890488, 0.010128324915234362, 0.010933199871121155, 0.08702933487872924, 0.05546593400199087, 0.05823374455494266, 0.018881675223970128, 0.04289053943789294, 0.020985199446459452, 0.047317301899555235, 0.07412704293646159, 0.048329457265114596, 0.09726569447065554, 0.14331504041629453, 0.06666127862709184, 0.03382295039632628, 0.04889094608745748, 0.04019130907592274, 0.12550184142685708, 0.04067415514239862, 0.04804737603051528, 0.04600187913785058, 0.03285921944846069, 0.12978824125903268, 0.12371679527624962, 0.10079068717576804, 0.11553201148466719, 0.5631538684810362, 17.988881949455507, 50.732061324581025, 67.85851017121347, 67.00443760041269, 70.25649824450093, 72.01508506651848, 56.04282502205142, 64.38606723662346, 57.218347595584014, 60.12514160525415, 64.69476953629525, 57.62376769896477, 54.47761497189922, 55.81133457922167, 28.36790684730776, 39.92714743460379, 37.53798469420403, 39.74876196153703, 54.87256234691989, 40.66999727679838, 33.022928699370354, 38.37448112426266, 51.803617554326216, 46.55915760224866, 53.74333158616097, 65.1207781607105, 52.0113423562819, 53.08024314142043, 39.909790946591286, 42.99553132826283, 40.39636488883726, 56.41539527523903, 55.031634069258175, 42.731755856544744, 22.94573214746291, 27.91418471644002, 43.94221498120216, 41.85146224114203, 44.08076878516905, 56.647011233914284, 60.63996445748114, 51.644271266075876, 39.3698610028913, 36.625602168421594, 46.28632145543253, 35.2740946123677, 33.78302128084245, 53.37812754415697, 44.42055586845645, 51.61491624770626, 62.32030783930133, 58.9671951724637, 69.85899740649809, 65.58501028245496, 81.06335763008364, 71.50028182614234, 63.41888919953377, 38.275539336665986, 6.415121238077841, 0.9328476147305582, 0.2901208370683655, 0.04074203436292949, 0.09925590662826454, 0.14565796711512152, 0.01964911912387658, 0.014498683195861598, 0.024040143583871187, 0.07078939703323188, 0.09159056875374048, 0.020681985676468864, 0.05453366245473585, 0.044127051312957084, 0.08415217676590528, 0.07176848038310005, 0.08578199818129502, 0.08076203851810387, 0.13032712282673006, 0.0367838763932307, 0.07989326416845284, 0.04020797914915508, 0.050759886526652885, 0.07217542628847784, 0.032978683199372985, 0.06351841057861043, 0.04120417307281206, 0.030751738381842454, 0.04983281671640374, 0.024900496712014563, 0.05630786463077511, 0.06201493238369304, 0.02669999319609375, 0.03369203746138561, 0.04686105440581038, 0.03245836777252055, 0.04284719418313715, 0.1112896463863792, 0.0547734939403111, 0.0383007419746249, 0.048550148043901696, 0.03836136251207321, 0.14014541291661803, 0.05328299710527063, 0.08831069354088077, 0.06025507520403593, 0.04089955353148041, 0.10937873198981247, 0.06712971074927239, 0.013043847753696386, 0.04477206287124465, 0.017209860699010954, 0.0422383726183926, 0.17802956393889843, 0.09307611283035049, 0.05947777175254399, 0.03651078903086243, 0.051444263512929606, 0.13170208211147016, 0.1554966657873123, 0.03598980710751588, 0.0912151933317223, 0.02662564436304233, 0.041135167703032494, 0.013100958650841588, 0.07448513541490802, 0.05053275677886221, 0.02436492272893027, 0.12116042882083886, 0.0634462604179017, 0.05424062616281933, 0.10830861441190205, 0.1538353888017516, 0.06660681743655475, 0.07649784757485313, 0.11007479181693447, 0.04897776300147657, 0.06774855657450615, 0.01892369514661691, 0.07071971367563933, 0.05780320697193665, 0.07812400708996481, 0.021432106413187522, 0.015130400255833183, 0.007702893898597048, 0.06591936077682242, 0.014006551186133538, 0.0028836945186354102, 0.08165570306441478, 0.060439093353887724, 0.0677314728137947, 0.06452746328807647, 0.042482011560951514, 0.06592922032840791, 0.05180678781001799, 0.012849000951034889, 0.008605618871027424, 0.017813559050761887, 0.007081583185466908, 0.07288150654564943, 0.05579226447509662, 0.049101513014325214, 0.060344810913046526, 0.11337601790024389, 0.11381144695464643, 0.047052767908861565, 0.13903098481316722, 0.09541021419628974, 0.02552119455480528, 0.029859776465943264, 0.17165968074433266, 0.08620618106496912, 0.06336252700777785, 0.057772486846173005, 0.21080888807773593, 0.08686562955018975, 0.22602169353875423, 3.460878561581335, 34.03609652673045, 78.36175457123788, 93.98111897130167, 88.64260058249198, 76.38008686804002, 67.1538406802762, 51.129377811185776, 52.39746047604469, 54.050782649747795, 50.87644377062398, 68.54393651408535, 57.882012628739886, 58.54258683419997, 51.17272392396004, 43.91305215897099, 45.41098963829779, 48.16469354014243, 41.97618969025151, 57.94039318638464, 51.1186069826926, 58.329147138903224, 66.43352877709174, 75.79406907481533, 73.94056089462774, 76.27943100467806, 72.70394740566131, 70.66709195413898, 69.58372546780494, 74.13648328473492, 72.20421391148722, 63.158079039665964, 55.195510695057536, 53.96658897399903, 47.1545498601852, 40.883511497128396, 39.31741891368743, 37.94854310251052, 37.73953176313831, 45.88807536709694, 51.97572723511727, 63.8626543937191, 67.39028899900376, 66.58913704656786, 58.07856652044482, 74.99023422118157, 73.73008651118126, 49.47653808901387, 51.03338564595869, 40.42817531093475, 30.974245340593402, 37.59283119632352, 47.28956176388649, 51.175481350191184, 61.649441334509085, 77.19168801461497, 89.53416316739975, 90.04338879739085, 58.55086303526356, 15.233621847245002, 1.7154104743273029, 0.4993813082335457, 0.04275178942348688, 0.10166868522402742, 0.34877280434293134, 0.14045710344949078, 0.027372041912448984, 0.09279328082958538, 0.04357264497347417, 0.15472395886336604, 0.07471192042313277, 0.12438206602969479, 0.07866694892366087, 0.04136845679773439, 0.09628831183597927, 0.1050326002821807, 0.27776702577548645, 0.08285074660013761, 0.07435415736249379, 0.06098156404351035, 0.04663397445373478, 0.033793842885643244, 0.04919957226863311, 0.05721919516461992, 0.08721577769686138, 0.02917075890206522, 0.026428093270008123, 0.018200527298294248, 0.09332596474597532, 0.03366558827579983, 0.04047840818642609, 0.012119473615330795, 0.04118367639039794, 0.027688328972867424, 0.046674439217895276, 0.01744158314390769, 0.017664035924920635, 0.09015943990239213, 0.017666560184631138, 0.07660852429727394, 0.0804057080418833, 0.10740698255117863, 0.03451826711816173, 0.029796041781082753, 0.025136108968346834, 0.0375555184549622, 0.031133476164071795, 0.034209759680614356, 0.03452373698594109, 0.0353408923312541, 0.023956578713090673, 0.08077065700725203, 0.04006766631538349, 0.11424319112613318, 0.004718107614485968, 0.16047971533431163, 0.22234416506703825, 0.30467433193998955, 0.22047561533268423, 0.08264049376931884, 0.2914794173932845, 0.2797526337446705, 0.11507828058975358, 0.22344374638651648, 0.1539480496918963, 0.2051691173185264, 0.21369552269818323, 0.24974866229439938, 0.2746981081943358, 0.09982936940486394, 0.17273643264366736, 0.21695384785773295, 0.09969186428333483, 0.1967277630202232, 0.15541766680056052, 0.18277517219464626, 0.23107451837389703, 0.1573748222642368, 0.21077646723678037, 0.19767636373158426, 0.1327801823255516, 0.08440137750679448, 0.07459786525296588, 0.20703357614336476, 0.1603062730282545, 0.1044412033872739, 0.11620628377122265, 0.1533020996759015, 0.2236609476348085, 0.14501759421921548, 0.10624439816080755, 0.24380441755056384, 0.10784757503819083, 0.25272094554478125, 0.22971443651664644, 0.1944292694210045, 0.12933099402054665, 0.14496717031203932, 0.22629213789778374, 0.16988686135699674, 0.2269242983311415, 0.16322491480217827, 0.24651707360340705, 0.24363413152675478, 0.23767516257301455, 0.314807744636651, 0.19006885017358488, 0.3423104543359049, 0.15346644085741815, 0.2400433548515843, 0.34774557236702214, 0.19251594950835552, 0.2628646238196281, 0.373552224688953, 0.7183494923576232, 0.24322585262838872, 3.4918630796094097, 34.21279930299328, 89.60511884381695, 111.84898207264563, 118.37375071740921, 113.9366949758222, 113.08273223138626, 89.82073937692951, 95.66096813448014, 91.92935066838419, 84.12858793812414, 99.29282403761341, 84.85550511267878, 82.35302509800081, 79.0218424027966, 48.00483342139952, 55.52004368074479, 54.28167296994118, 56.05299572790823, 74.78239567049089, 58.07258490593203, 49.41263091179633, 50.2595216228116, 66.61099249316801, 58.46943070811611, 65.32102692511775, 83.10546121289654, 70.55951702979304, 76.9589973265125, 61.7186947022715, 69.34371563696092, 65.89148859823904, 85.86604102965325, 86.88359014449581, 72.26508909656157, 47.68889827112998, 50.00241025801628, 77.14166210543725, 85.1920993866459, 78.49944545376685, 87.11553558226555, 93.19011811287173, 72.99948230866464, 57.620421917207786, 48.60461873392905, 61.28035806840467, 54.4832004270246, 49.081512266589755, 87.32123251884215, 62.09759566091723, 84.65575448928341, 86.25304560507499, 88.1941952243928, 91.46042346954347, 87.87106252485707, 100.84618460747504, 110.97548592475154, 109.812848337235, 68.01309862444478, 19.816308329182288, 2.624023234651935, 0.3916094380040323, 0.14778566907250112, 0.27021171344864753, 0.6497103432493826, 0.22913927302485515, 0.15263178806391456, 0.20420686492035467, 0.2638184032853573, 0.3263647019142105, 0.10222507956167383, 0.1699319379704614, 0.26625937391673365, 0.19898007683936628, 0.19587116946856822, 0.24277767587092616, 0.268222366970393, 0.2348333900614131, 0.1532562876180295, 0.2669846446764085, 0.0960443587973714, 0.2061291787052347, 0.143124514349526, 0.17408097823781354, 0.2043056442973114, 0.09911478557173284, 0.16529578835733477, 0.14444754819475836, 0.21580417970976523, 0.18461856360156692, 0.08434472530479394, 0.10126466577452037, 0.1335481395043673, 0.1563622838547153, 0.09680273221625436, 0.11140663567329608, 0.14591292117632207, 0.12491783728041958, 0.1528312773593972, 0.21403546655370345, 0.22468140739346706, 0.3138279488250133, 0.21397810188993333, 0.12077962949631676, 0.07868251583028225, 0.15175864701309513, 0.14720650660174509, 0.20970944465408403, 0.06899691216887967, 0.1947466596480339, 0.14413846236082817, 0.2272988387173222, 0.3506821099548571, 0.25064912204059864, 0.19563625626746686], [0.10393557769636955, 0.02328186784119856, 0.06824924865917814, 0.030253838687654466, 0.029808251307375973, 0.046066789767674865, 0.021651724668880625, 0.043895891942684694, 0.15970467950307554, 0.18108879816868614, 0.12801976559022743, 0.1339793703969448, 0.0032947191240025628, 0.04245619439790326, 0.01707441826921798, 0.08946887292568723, 0.022653840452192292, 0.021338938630276152, 0.09149838539381182, 0.06710790788694736, 0.026693046693840337, 0.055485446261422294, 0.045428025656409805, 0.05483160553980739, 0.12182756882881927, 0.08932566044912224, 0.025990189751610163, 0.0056126340097116855, 0.03641808473114525, 0.032205968614547484, 0.07127665959659123, 0.09460631217206679, 0.0674406428551001, 0.07663878477028302, 0.012202590324675605, 0.0441522173012697, 0.11103000386708206, 0.036213370716019024, 0.017058458742535403, 0.06264795083552599, 0.06881354136332389, 0.06081385590556649, 0.03728509324813082, 0.050018784560022816, 0.050035588698641914, 0.01827440881771186, 0.058381886807300394, 0.1123614416968438, 0.11980720345051059, 0.13548632663103843, 0.014644194893809337, 0.04057005911524739, 0.01552805734512907, 0.09663204016584544, 0.025826754469063976, 0.06979389641914638, 0.12290302603956192, 0.16853128409674092, 0.03409996012886686, 0.174888051866043, 0.13113591249190992, 0.1487059245306638, 0.11047515702704269, 0.9173904731869699, 2.6923933336811685, 15.513949721090256, 35.74681474316505, 47.657436939977835, 61.01765340374362, 58.56514046269079, 69.01817460213938, 67.03732275193738, 67.29764261553365, 58.7713590745003, 56.40796630613266, 65.13619699785787, 63.063000786689024, 61.523184161032404, 65.01741978429979, 63.73716600479619, 63.42289393947971, 67.61217747965168, 58.211177933600645, 50.18267454639558, 50.70719742005872, 55.07565875207224, 36.22895640711631, 41.7348462535489, 38.182426191145375, 40.82267553575578, 37.30817302580803, 21.185413599014282, 19.449584368736513, 30.26422377555601, 51.70714293756793, 88.24295028563469, 40.15212674294749, 78.42266898001395, 78.61152325907062, 29.2967378324078, 51.807488933686294, 62.27226272706063, 60.84535937155447, 40.12252853762719, 63.53090424691478, 80.11311638739802, 70.3985272684405, 65.23620174777123, 78.32970880693006, 73.94780158996582, 80.32068037217664, 82.81443703559138, 79.79691059358659, 79.42055133081253, 84.37382236603769, 77.597410140499, 54.20357857981036, 20.94566264460164, 5.477992969174539, 0.4418983298443979, 0.4144421982909403, 0.0661269476216647, 0.06898056385257552, 0.10852881872485723, 0.0035940797111364987, 0.15523457178665748, 0.01249694045738227, 0.1389979051365968, 0.03404443407611501, 0.0452171063290969, 0.027822557153300415, 0.0238443678996015, 0.027381799957384507, 0.10454225804536574, 0.06724035682817621, 0.13328874213320593, 0.12829421658910092, 0.06053778080029353, 0.09784671853506759, 0.05188014072876784, 0.030037899569217718, 0.10012788322543907, 0.044588941044264266, 0.07701819747566216, 0.05858749331485841, 0.062130040924755804, 0.0608869138804655, 0.04649308705401998, 0.015359903918579223, 0.033911594430044774, 0.040681907952192335, 0.01600322625299375, 0.1273021327271577, 0.07405769665755572, 0.10657313414999556, 0.07769924964034751, 0.07113687919392701, 0.0573703519729597, 0.02231365910941555, 0.02108294843515802, 0.06978232083061049, 0.09135917189621157, 0.0361367121278759, 0.038349511131884596, 0.016154009593470443, 0.0256116159125081, 0.06747491762883241, 0.04902271704087335, 0.021852583346527912, 0.047029685679703, 0.025292072978411472, 0.0737316036717065, 0.015184113553034203, 0.04417891929587049, 0.05419223621908215, 0.05859190981174189, 0.1683524485316969, 0.08717816277977922, 0.1357501826339191, 0.03303106829163528, 0.12605445129015755, 0.03553546334226285, 0.037753816483722585, 0.019775956471060074, 0.11055508298018288, 0.09052933013487248, 0.0868198941011102, 0.04856253568563731, 0.01742973176371907, 0.03728156541323951, 0.08357410214000172, 0.11980030865919207, 0.0437250275224928, 0.04102460589380034, 0.04879910363665512, 0.03351548100791631, 0.0661630456846568, 0.017197689477113948, 0.03616866948563726, 0.060761593387372075, 0.04998953149263417, 0.03587266460301415, 0.027105067931716482, 0.10391893826665417, 0.04143941569172087, 0.06324396341017659, 0.0015670689988896373, 0.03584902312967085, 0.059380616481986746, 0.05901428472791469, 0.026318075383202206, 0.12244927982288985, 0.08195086141988155, 0.03445860419061876, 0.008301121903763664, 0.05757670924668351, 0.06641813764168371, 0.05009580320949036, 0.04470465862522683, 0.08475919419358816, 0.0546676857066491, 0.09255667457417135, 0.08622774644003761, 0.11312982022401788, 0.110388052830052, 0.1640916666797092, 0.07018532904405748, 0.08696584917244413, 0.08868528755321618, 0.16129567558246274, 0.12873542194645252, 0.033386862506308866, 0.19566578129606862, 0.210145486578826, 0.034425639427236976, 0.04894252678739929, 0.6006911348912024, 0.27156061042220364, 0.09405544132835443, 1.1742419196713356, 16.85141617251981, 43.272478119019546, 71.3806652253674, 84.61791930660125, 92.28865546564903, 84.85053154730028, 76.84261275875953, 71.39619781124976, 74.94444447178995, 60.78838302243141, 56.630800077992106, 49.55753111070203, 32.788896560668945, 40.436169101345925, 43.143298779764486, 47.96742185469597, 61.08035641331827, 40.52261813994377, 42.65379482699979, 43.86139062143142, 54.5863038493741, 49.884099806508715, 56.1863523913968, 57.30271385562036, 53.86676857548376, 63.67613000254478, 49.49818564999489, 45.675408378724136, 47.57213715584048, 66.3152850058771, 73.4800511021768, 86.88160542518862, 55.07769446219168, 75.22906734097388, 74.85735216448384, 53.39738245933287, 71.7637082069151, 76.45846366882324, 71.37448356997582, 53.040517376315215, 53.89265229625087, 35.02019959111368, 37.86149786364648, 30.656517667155114, 40.14653736545194, 46.81240543242424, 57.476980840006185, 71.25662419103807, 82.15420799870645, 81.39937923800561, 96.24971589734479, 93.00143641810264, 82.66306492590135, 39.69973233438308, 12.397589356668535, 1.2118938541220081, 0.5225032820336281, 0.19144071446311092, 0.1517510167773693, 0.2235787464005332, 0.09907909353534061, 0.011433852693787026, 0.09759955558805697, 0.1379809847041484, 0.06123832224177257, 0.09231497383406086, 0.023546976397835442, 0.022946317499924093, 0.0176479040284551, 0.10382409658162825, 0.0885946210473776, 0.06180846785765983, 0.12005335516146115, 0.004569375953231488, 0.02850047984881507, 0.08792601781146181, 0.007573800422476545, 0.11828716243467025, 0.0335209010799806, 0.025617447756831686, 0.007066686605779275, 0.04517050520066292, 0.004980708669585687, 0.039128159067683646, 0.021874907148641445, 0.03121046608524217, 0.06867815064446581, 0.01852343718881809, 0.0634321567392157, 0.09130607434217969, 0.17315784228905556, 0.031815778967293526, 0.1005325998149572, 0.08586957735279876, 0.039615172652467605, 0.04073112144044811, 0.08897741220050281, 0.0457570297763713, 0.035131757988804774, 0.06562895982736541, 0.01912153160740291, 0.03020689473487437, 0.06444771353515887, 0.05506344289789277, 0.016327352308097388, 0.06304703284836104, 0.0373802681814038, 0.1849964441310975, 0.06691565046146994, 0.12351807206869127, 0.10332162717297193, 0.11179355604033317, 0.2644216209169357, 0.2616003029529126, 0.4586475552810777, 0.2919376605460721, 0.2494491219160057, 0.1373914340811391, 0.09905107769994967, 0.14654888140578426, 0.1931344735766611, 0.18827759871079078, 0.29622379990835346, 0.16580444009554002, 0.10876339484727192, 0.2071919878043475, 0.14838381520202085, 0.2456923033441267, 0.14638394267568666, 0.1570133513380443, 0.14396384027936768, 0.11707691971452967, 0.09552281379940049, 0.12496391746906504, 0.2273355956159292, 0.16082845387920258, 0.17342851647446234, 0.15963829032355742, 0.12928306756000366, 0.1458078752001447, 0.08347676300834264, 0.14569362084711754, 0.1988613485328613, 0.12368745410874968, 0.14349314053693127, 0.27335530928065704, 0.14914708392273995, 0.22258726008717092, 0.16004866830283598, 0.13189357344902333, 0.1488819102486295, 0.1941231560082205, 0.08144803961078007, 0.19404896805363317, 0.15647071593951795, 0.16914027803126844, 0.14978780921909118, 0.21251046128811377, 0.14755794177612952, 0.23110821092080688, 0.2202007429854524, 0.26875308204081755, 0.19307545416297453, 0.23508581603246353, 0.20715973550273528, 0.3231362235401908, 0.2582569726772847, 0.1302406315000788, 0.3723529293652504, 0.24742450474971728, 0.1004689762128457, 0.24650876921030784, 0.8562169428313933, 0.25188617017720977, 0.14348791581728768, 1.0551744507205103, 17.101502572336507, 47.130921502267164, 79.03803394686791, 98.0764264445151, 119.15631063522832, 108.57510520565896, 108.50433780301003, 107.20827687171199, 103.52065270946872, 93.51089739030408, 81.19207412965837, 94.81150042626166, 96.06774145557036, 99.31682109832765, 102.26690630758964, 102.6268308393417, 106.14627945807673, 107.28499843228249, 94.44977160423034, 88.47662156628024, 83.95510150540261, 86.66761659806775, 62.53213544045726, 63.96956643750591, 62.349192173250266, 62.475986711440555, 58.20881666675691, 35.83313434354721, 34.59590896483391, 52.96035589710359, 76.21452362306657, 123.09990867491692, 82.26919620267807, 156.72214415765578, 113.53789191092216, 53.91839873406195, 86.44936807693975, 94.03343554466002, 92.52685316147344, 64.1906508322685, 99.34521121363487, 120.55880115878199, 111.66325784498646, 87.48868634623867, 99.9303190169796, 93.1004919544343, 96.16899351919852, 103.42997535582512, 101.44267512905984, 102.30471795605075, 111.3072713728874, 112.90779452170096, 95.14054806001725, 46.517556944201075, 13.241248034661817, 1.575856343392403, 0.5135551299298964, 0.1852137679534574, 0.23113886975953657, 0.2590811607097426, 0.2408490341997916, 0.342382803679474, 0.23077252651414565, 0.29384331957947823, 0.14008267031561944, 0.22968777665688148, 0.15022244154205247, 0.22825742921521588, 0.19733937697545176, 0.28506744532815875, 0.08879172014853648, 0.18835278257967966, 0.22309129997607202, 0.09864831463463845, 0.25738491947131775, 0.2091950319346882, 0.12627768165041364, 0.17585998761557764, 0.1911950760310696, 0.1840217811085524, 0.1561931929280681, 0.140934391548076, 0.10878075439963611, 0.12479304921843352, 0.0706347162204404, 0.09872601127191898, 0.19124931505610868, 0.11408156955674773, 0.16550612545782523, 0.1562238670885563, 0.26771147825544883, 0.1424835285832805, 0.2524338617560364, 0.20551987833553748, 0.0868116433341657, 0.1427050199239485, 0.29224320705379214, 0.16795129425102667, 0.1793684711259219, 0.14417921823839988, 0.0702424408988126, 0.11174359944679084, 0.18677307863629636, 0.10666440586529433, 0.057608946226537235, 0.13056595839800375, 0.15699136461461746, 0.26382732054879593, 0.08152500080365328, 0.23108809345191528, 0.12668457392963672, 0.18902674077018616], [0.014698765251875646, 0.020422232074422703, 0.04584359005093575, 0.10610774339687441, 0.06066176063951947, 0.011886231443514268, 0.022404930824714325, 0.08350704646398945, 0.12015568152550729, 0.0510682062726588, 0.06039873584203663, 0.012924520941000554, 0.042225939011381525, 0.02884163220803584, 0.02527212596408302, 0.04068559283510812, 0.0307470211954487, 0.11586069384770048, 0.0038370277381487073, 0.03487010831914602, 0.03651958372023317, 0.042926396183188886, 0.03385840494546198, 0.04991941912580402, 0.032936303215401794, 0.05340508087688396, 0.025221928052844542, 0.06522073455515408, 0.03260979654207345, 0.01781283701289325, 0.0628996413621691, 0.0729057532284529, 0.007266437807571024, 0.13608647991091977, 0.04606032781603356, 0.06814860768856541, 0.10073852424900379, 0.05277854735933004, 0.07974276619572794, 0.12543447165479585, 0.043476071929739374, 0.006106949848828898, 0.022248671870798837, 0.06814215722824297, 0.11889576566435638, 0.0550218366627251, 0.023407515836879614, 0.15216551630968048, 0.057234965084541234, 0.07817451526681263, 0.08733671999746755, 0.07947070539117822, 0.06710234608861708, 0.04336444142785284, 0.03779964003291342, 0.18960881437505447, 0.05612714065899772, 0.10414389998561914, 0.15523831029572796, 0.0344423784483825, 0.07061784696434775, 0.15247103217388355, 0.14054239967898016, 0.22487594776095884, 0.049168675942646886, 0.944350945853418, 2.2654445661652476, 2.3200407720381215, 6.57261420642176, 19.172653267460486, 51.840362318100475, 71.30254730101555, 69.71676441930956, 55.167575574690304, 55.455410865045366, 61.29165057213076, 66.37193187590569, 77.23337496480634, 71.39265198861399, 70.88846268192415, 63.78925115831437, 68.66327854894823, 75.52497094677341, 73.00997072650541, 73.45261020045128, 78.61487296319778, 84.38541689226705, 74.1911454354563, 81.79112988133585, 80.82484614464545, 92.72135565357824, 87.15497109197801, 80.37958652742448, 70.06707914413946, 35.205339385617165, 66.36438523569416, 76.55956668238487, 99.94819718022501, 59.48944699379706, 57.382259522714925, 80.11252803187217, 81.26420651712726, 88.13159419644265, 86.28076891745292, 84.399506045926, 76.44288401449882, 91.8302402188701, 84.00198167370212, 88.37283565152077, 95.92550062364148, 90.37699422528668, 70.2531877640755, 65.40161986504832, 53.777213019709436, 32.49068856239319, 14.942820264447121, 3.202873386683003, 0.20038534256239093, 0.2243203041894782, 0.08489940360548996, 0.08798604846120843, 0.07446053633165937, 0.08046773052023304, 0.0706547953849358, 0.017265691271712704, 0.05783414926319834, 0.036422708071768284, 0.055874707027068066, 0.05518517426906094, 0.035645190115657546, 0.08041467127059737, 0.11775593408533644, 0.05643225815748015, 0.07734024551727119, 0.009379899148048173, 0.1263897832963736, 0.04157628496027282, 0.13410476366839102, 0.03943607661752932, 0.01954525292310263, 0.05806873687693189, 0.09789266848876592, 0.05769978510215879, 0.035618078264017264, 0.04143232554798165, 0.036355525991248513, 0.0822488772833059, 0.06407621834847717, 0.1482917620770393, 0.03525342424249938, 0.05918980313224658, 0.08263652543387107, 0.06275655529011162, 0.054325868766154015, 0.0665420217199191, 0.07806087378412485, 0.02911209571926344, 0.04171911822331529, 0.08982559410674919, 0.041221509642538526, 0.09593738994050412, 0.043252527473434325, 0.20898880106547188, 0.133842884172355, 0.08840548926063123, 0.04309121616965821, 0.03719308225798511, 0.05395993154736296, 0.018594962987868537, 0.03008742140786302, 0.19110230278343926, 0.04243438387469899, 0.061010725180348085, 0.010987864074958189, 0.08121825153789214, 0.10114971428148209, 0.06926373293202731, 0.03023797683718224, 0.04940062055304166, 0.049247100363455476, 0.05178767008586757, 0.0018486551491678845, 0.08318623948481776, 0.11082853806475479, 0.04258334584113571, 0.07319285233895625, 0.06843226706428875, 0.018564631651726463, 0.0672987174062479, 0.02273138004144834, 0.05434026738869087, 0.04704821351615172, 0.037639730670038736, 0.06438638053594098, 0.043760524206464334, 0.05651014248630213, 0.04459005187175447, 0.017545633205783465, 0.014972573694502635, 0.03952379751529905, 0.027012798386896332, 0.06254114668756243, 0.02950224706212119, 0.08276319807215084, 0.07432862365197751, 0.050724642651696364, 0.04093762810131715, 0.04645651784695445, 0.03373450171502848, 0.14053050999439534, 0.026619324137667016, 0.07810117766982125, 0.07122021423833025, 0.023611450357542887, 0.0873042838347535, 0.03800692810346523, 0.027037246167779933, 0.03139016541442083, 0.02373314725475446, 0.027308548545284618, 0.06265413316507494, 0.07163888128894953, 0.039044950427787925, 0.0723078599079482, 0.04187661823966811, 0.008857898327762322, 0.04604202980596212, 0.052932531032110416, 0.004746415999702989, 0.021955126130412665, 0.05682832944477278, 0.1094873555965962, 0.05792651648422884, 0.1507989533485905, 0.13507780258453664, 0.061469577373035496, 0.09559540063022606, 0.1449668638768696, 0.3387515775619015, 0.1730480312459892, 0.08132730415391345, 1.135621159788101, 3.8838456330760835, 16.096335399535395, 27.067546998300863, 48.62102208598968, 85.58155152105516, 95.04109244192801, 97.73045770583614, 82.36213284154093, 70.3727965201101, 70.28161710308444, 65.15452231130293, 62.30782293504285, 60.795062818834865, 58.755555845076046, 59.12434493341754, 45.76301451652281, 42.353564846900206, 35.031229296038234, 45.78108879827684, 40.659928552566036, 39.48038947197699, 45.0195017937691, 39.989446440050685, 44.909942150115974, 39.054255331716234, 21.235417935156054, 17.842022526648737, 41.43747175893476, 45.58786892121839, 84.98094251078945, 45.90196055750693, 91.03104160678004, 70.42900408467939, 35.55162191390991, 60.605231869605284, 66.1725107316048, 59.781177197733236, 47.27030684871059, 58.95670283225275, 67.63709237498622, 70.72728464680334, 70.9301810110769, 87.43469099844657, 99.48898961467128, 102.80146260415356, 87.2302649098058, 86.55564861912882, 72.89529631214758, 52.34279048058295, 27.51268502204649, 7.696796386472641, 0.400518213188456, 0.18678060161971277, 0.11032230716439025, 0.11208021081984045, 0.011371054551413944, 0.1275470203930332, 0.0132828327121153, 0.13596055037792654, 0.026978115671344345, 0.08797540749994018, 0.0728868002132062, 0.09536332195444454, 0.09453330399288286, 0.09241295647957633, 0.024704244138012012, 0.01693100469457286, 0.08595730974188737, 0.026261729616371375, 0.15829155371794779, 0.08343867311674742, 0.14200970320211304, 0.06913283148840552, 0.07901171147222481, 0.054501842992800864, 0.08311097900713645, 0.034470578144875266, 0.04577733876724397, 0.06302163703367114, 0.03307259791801053, 0.06866434574007027, 0.06286126035716265, 0.01256007663605194, 0.018313247560253067, 0.030752098443166866, 0.03388554361017962, 0.1258374032594504, 0.029200632500672535, 0.02542945552587269, 0.045715147749550884, 0.08801709034390028, 0.09240212399632701, 0.07550582499994386, 0.14675799276559584, 0.043408732801195116, 0.11087118617949948, 0.07421469871675776, 0.07934645359073916, 0.029038444026223117, 0.03934648646522434, 0.05598752113479761, 0.03557182953602845, 0.07081392716856734, 0.06304082753617438, 0.09567203240529185, 0.06733455499934574, 0.05570858086068785, 0.14287070942021188, 0.0788080929628303, 0.07559007934985623, 0.22832464576969225, 0.12368626667246704, 0.14931504103925922, 0.18258354296126675, 0.17333376671998732, 0.12869310324951527, 0.11834046683244168, 0.23006714339698517, 0.24884083278236852, 0.15350495975825096, 0.12389127946188375, 0.10324089682751125, 0.23334393127551004, 0.17036801053872033, 0.1536024367857364, 0.1361209079022369, 0.12034566366984961, 0.2665167488157749, 0.09149407231879812, 0.20210954601005202, 0.12736949483833968, 0.12037901147719353, 0.1073383027687669, 0.16263447551717683, 0.18542281802623503, 0.1574669060327353, 0.19053297688163098, 0.15222419864468037, 0.14646805912977265, 0.11875340354538734, 0.11247445498743366, 0.14553815096376405, 0.08681699062787718, 0.22819963554220818, 0.18262144899176014, 0.23906358968346353, 0.21832143737664148, 0.16911069171563273, 0.2062200980200883, 0.38148108148767107, 0.1448943766374742, 0.1043585884655195, 0.177392806977995, 0.1878825578117563, 0.1719380770960162, 0.20873107376598543, 0.1772543748900775, 0.15450767692058318, 0.09462897305286701, 0.2654417435969076, 0.16210846422660738, 0.20451578221494154, 0.18527533077905256, 0.10520466362997409, 0.18007054474324952, 0.32414761281782584, 0.20835605840529167, 0.2095693578162501, 0.3379326295708457, 0.16106379608954155, 0.12526798542709122, 0.29208370754795693, 0.6020982851905208, 0.4954837286664594, 0.11976237964606094, 0.9794106226294272, 3.4451201942659195, 14.820408974924396, 20.876026845747425, 49.08496395234139, 88.2811620158534, 108.42930286161362, 115.00115563792568, 107.03236641422396, 99.82806282658731, 99.87648840873473, 101.7181824099633, 104.20145850027762, 95.22783648583197, 95.05398135031425, 80.21594524383545, 85.87579988664197, 93.43184594185122, 91.16306074203985, 97.70252258546891, 113.23439459646903, 116.28027193007932, 98.04685961815619, 103.17921823070895, 109.92350624453638, 124.8487444846861, 118.9149122853433, 112.40291487786078, 99.00983287442116, 61.45298157968829, 94.21875969056161, 131.08235559155864, 143.3037785560854, 74.85053508512436, 87.13491993565714, 116.5631454221664, 107.53067216565533, 118.14511576006491, 119.62505740504112, 103.78393004017492, 90.62450362790017, 111.99126212827622, 104.49212181952693, 114.21249251211844, 121.8191763662523, 123.09911635614212, 98.18020451453425, 97.18161613710465, 75.31581447970483, 54.48340831264373, 24.289544013238725, 7.053522775250097, 0.4836078949512974, 0.2240715094751889, 0.12617163975993473, 0.2523383765571541, 0.26757186639212793, 0.22798810334455585, 0.16891998178776235, 0.28683116359095423, 0.12475025554698323, 0.19544618985345288, 0.24959015870286574, 0.2381842586422159, 0.2671455537840243, 0.25632882130242163, 0.23905980520911757, 0.09806755104012067, 0.15621369344092187, 0.11243638807847617, 0.3536200571444727, 0.26019937328753934, 0.16559489972649083, 0.16410899558855643, 0.20051622102337502, 0.3123757831992642, 0.1787097427633501, 0.18727606132386193, 0.1579291941297631, 0.10062115191812478, 0.17638901729256878, 0.2562752411129975, 0.16069550698082294, 0.19293150624200223, 0.2809939719736576, 0.16232883707890589, 0.20242093010775505, 0.14535447372303856, 0.10777059852355912, 0.11922977999934267, 0.09527942000497734, 0.21993825061907693, 0.14381148071298677, 0.18956571426843444, 0.2620562171984104, 0.23869474899143944, 0.09946683361645668, 0.2668372800032939, 0.27992236818517413, 0.1465845044942633, 0.18612987121507046, 0.24066506584565486, 0.1983810573696129, 0.1466168487264264, 0.34453256896907286, 0.24060250710575815, 0.29120457568956964, 0.1751764992912931, 0.28289690373405335, 0.2002861648197136, 0.1850240079746131], [0.0991535802642184, 0.04772656522090397, 0.07125691751078253, 0.07669736751385274, 0.06130074691628257, 0.035708518773918195, 0.010332337002299968, 0.10658962802300531, 0.0813161269310982, 0.015693432745343495, 0.057237914523049715, 0.03493498064457409, 0.0707521728209911, 0.08290347643196583, 0.06538283109905259, 0.07121147317511421, 0.03880829820709844, 0.05009134457777104, 0.034046146282625776, 0.05269282595104268, 0.033714702172625455, 0.062340657647338614, 0.03906603316746412, 0.05146009855032448, 0.08368913024183243, 0.08572932963650073, 0.03979866603209127, 0.12237137634186976, 0.059191641743264856, 0.04815319575549615, 0.012850797427217326, 0.07570071010700158, 0.04584711022494782, 0.040938451645835754, 0.061847128484758644, 0.04755703379370032, 0.053931831442300356, 0.03520739384956899, 0.0699808371944293, 0.0026722303112863654, 0.057477087173010075, 0.016988018873117624, 0.06128660876363997, 0.01950755948200822, 0.061942763070786194, 0.04684592416930584, 0.0022488623536417204, 0.033282448552669056, 0.07061362581988496, 0.02983023803080282, 0.04185930848301899, 0.017820603229225646, 0.01720107750095908, 0.042000686179005334, 0.050695201892766266, 0.02732485855719255, 0.05209848344806702, 0.020233527381694125, 0.08716669444355273, 0.10200257698494582, 0.1772240531300345, 0.09901344746110902, 0.04989545972597215, 0.1314596152834354, 0.033134911509771506, 0.16991784195265464, 0.1698484803519903, 0.21079353567573333, 0.19586455046890244, 0.6731803354717071, 3.574419656107503, 6.575070100445902, 8.88454008486963, 6.290916444793825, 26.619186747458677, 36.17229384760703, 44.49897973768173, 53.01006409429735, 71.64163620241227, 82.51881584044426, 95.4148707851287, 84.53113294416859, 77.58933005794403, 97.77624745522776, 98.55978796558996, 92.95683122450306, 93.3859306766141, 87.25200268530077, 99.95096637356667, 101.6743616903982, 95.13903402513074, 97.9478511502666, 97.94296387703189, 102.48306028304562, 95.77945509264546, 84.94451153662898, 97.74956749331568, 87.29396420140421, 107.36819190363731, 117.18149139035134, 106.98893793167608, 101.84732252551665, 90.24723437524612, 88.69035151696976, 94.33438331850114, 80.46415282833962, 78.3226328511392, 75.73475499306956, 58.876682558367335, 35.107127158872544, 21.650310562502955, 11.134389062081615, 1.8081528332925614, 0.15775815733978826, 0.028802320406201388, 0.34050306906142547, 0.2510936981848171, 0.023092919915554025, 0.01666042818537643, 0.06179834783618009, 0.03909450865560963, 0.024566922877584736, 0.03726091168280091, 0.025199646385566845, 0.08787134977718515, 0.021022004225561698, 0.015991493616433396, 0.043343469770925666, 0.06217803633321197, 0.030837360198699662, 0.14596029605355956, 0.027973924635819374, 0.049960891295584946, 0.0533093543603055, 0.03720853808185747, 0.05847123564190923, 0.038837309956790945, 0.03910811437714485, 0.13144584102255683, 0.019604285743327874, 0.045786497348378745, 0.06211453147472874, 0.04877673386926613, 0.09020248638285745, 0.058462728235510096, 0.04616727369026311, 0.016152946646475506, 0.018555409868337938, 0.029545845125891992, 0.06678890887527697, 0.026679312652577798, 0.02532853684838741, 0.04372022032076794, 0.08975485354782113, 0.05512119060562504, 0.044181497181735696, 0.019721916628881328, 0.04459394359840982, 0.08247003920616643, 0.049868160182790416, 0.05842267332838909, 0.10146924189382023, 0.08052599916775381, 0.03887349995033395, 0.10860861444305028, 0.10044212483109967, 0.0533068492527931, 0.02514053121088974, 0.07155019895083482, 0.07833341722406688, 0.043349498882889755, 0.0391586646888285, 0.06893011696276165, 0.04365353236695932, 0.013331910219764518, 0.031800401667433406, 0.07451398628613642, 0.055886343902637886, 0.106804232233234, 0.033022993724913366, 0.13259762357319557, 0.019428194688272574, 0.02821255910901293, 0.12391564105787586, 0.039504568708399614, 0.07306227265226264, 0.05068849862342881, 0.07535784745648985, 0.07597411156541879, 0.05932973292205603, 0.021895790705457333, 0.08077380562862081, 0.041342892443701144, 0.03111122897075069, 0.04772454657922349, 0.10299758730275978, 0.051923918823200854, 0.028219729691984195, 0.04771970873398166, 0.038152699313697316, 0.09143944258891767, 0.19537681293103004, 0.0810696994284949, 0.08366800919776002, 0.04537067248395855, 0.023775061840311657, 0.02128480111188706, 0.05817464470202404, 0.08346596116861028, 0.05984560120850802, 0.03770416249491034, 0.03303130194845219, 0.07375480847493296, 0.04926792263323742, 0.010197843563923193, 0.0623472421730478, 0.060590146740357724, 0.007066789070039147, 0.057870653352790305, 0.07128822752424786, 0.03175726134119736, 0.05831965748521109, 0.022221349344979373, 0.029877147509626327, 0.059806109376011364, 0.036907354444866224, 0.04984502815791676, 0.09586114120940048, 0.02688351530401457, 0.08926955983042718, 0.060473004235856, 0.017041759941005902, 0.07009516049536967, 0.0764627990523173, 0.03397988733805476, 0.0950682248860117, 0.18502563208101258, 0.03740293672308326, 0.2579804762236534, 0.06628673058003187, 0.10333965322183025, 0.18359180660017077, 0.4153997775527739, 0.4958089789555919, 0.5680839200654338, 2.1828909314447835, 10.0392888053771, 21.554557661856375, 29.83011741792002, 26.66806732454608, 50.098233761325965, 64.27367956407609, 73.92528718517673, 86.04850184532904, 94.10858815716159, 96.3427858967935, 97.59729323848602, 99.20973254788308, 99.02887205923759, 100.4447300203385, 100.20990556286228, 98.09265721228816, 95.45122331188571, 88.49049106720956, 97.53040113756734, 92.36933862009357, 94.65729636530723, 86.25882717870897, 85.17349950728878, 89.09782301995062, 71.61658010175152, 74.17449105170466, 79.0949083143665, 88.0547078963249, 86.62367820739748, 83.80354896668466, 88.46893372074251, 92.42194544884467, 100.88364324262066, 98.64005534879624, 107.93941451657204, 102.3612157760128, 104.9903726577759, 97.48964771147698, 84.04755961510443, 61.75146218269103, 44.17427809007707, 24.706748877802205, 7.5834864666385045, 2.209775837198381, 0.21127751938277678, 0.11151848451024103, 0.11403502971534768, 0.032507726817481944, 0.07913102200555225, 0.033717850793994246, 0.03337517966546359, 0.05088850502826033, 0.006527609206856259, 0.049736350924978336, 0.07135998698011523, 0.0764017878100276, 0.023723521359985875, 0.05226916783759671, 0.10732204638301365, 0.07863226046244945, 0.06361949588021924, 0.04835134056667167, 0.03508233765680944, 0.03609555788458355, 0.04387770501536228, 0.04834956707312696, 0.0321132815518086, 0.04710744360401746, 0.016682209980283535, 0.07135287768417789, 0.07497589133920209, 0.013507912217098619, 0.046440525761535095, 0.060538416653270685, 0.0324215610781985, 0.020565479024944287, 0.0623836619929681, 0.026950099835953405, 0.019388367692309044, 0.022350632427861134, 0.03705984041575463, 0.04535857978607378, 0.020317243554839687, 0.09929478559042178, 0.018413668280587565, 0.0661958878739707, 0.06985293115459143, 0.05586300120358506, 0.06887827579292559, 0.07152358505634532, 0.009870259579451335, 0.07419846531364226, 0.1253081973822367, 0.041224095189282974, 0.11032285108681648, 0.0457233295685822, 0.016903134415887536, 0.046401282907613826, 0.05712488591070137, 0.029452357501272234, 0.09454001492309956, 0.036033677132499796, 0.0474867643788457, 0.08404612721454713, 0.040378870382424326, 0.07764243655988286, 0.21154742748025926, 0.08784284364552268, 0.17157772465819315, 0.12204565873910343, 0.17822531472531059, 0.13604279757747728, 0.10846356335546702, 0.14033460599039832, 0.15067069490830745, 0.23231216405908908, 0.1947519762982284, 0.2586837142946259, 0.22050288806278862, 0.21563271391055278, 0.11549703191004454, 0.17915893075687273, 0.16865879177085816, 0.08797579054390231, 0.17073786246680445, 0.1633229434129692, 0.17039070206303752, 0.14683254844238683, 0.1444666697493484, 0.18278952868234727, 0.2600649401785866, 0.2956664556216809, 0.2052102102747848, 0.29552868236937835, 0.1333021180283639, 0.1124301291401348, 0.12513997213494393, 0.1469077323112757, 0.2243564022524703, 0.1973956384726109, 0.1777024137517137, 0.15541377507390516, 0.12289769406760893, 0.14030505031827958, 0.23584266493637718, 0.15639568528821393, 0.17789156086021857, 0.08184204629111676, 0.20184141523655386, 0.15635439314909522, 0.1601218909866387, 0.1151000451476824, 0.09233939671708692, 0.1696951401930663, 0.16846783669485202, 0.08975785661248431, 0.11715355148959546, 0.22511441561002887, 0.12433970902836132, 0.16965476735945673, 0.18799535659772737, 0.1222518283212858, 0.11057882404495632, 0.2014806184677347, 0.16156230482362932, 0.23861034142394222, 0.32579096334595836, 0.25118608838848533, 0.24378417750760434, 0.18738144437872595, 0.1851742378165645, 0.6006205322281007, 0.5530336631401893, 0.3071896743870551, 0.508718510428744, 0.9918948527305358, 5.310537670889209, 11.81396617043403, 19.090928723735196, 19.057535625273182, 49.09444824341805, 63.9474795710656, 77.45371018686603, 86.76475801775533, 108.78626992625576, 113.92028377902125, 128.97618401435116, 124.89141202742054, 115.34389234358265, 130.14062589214694, 127.36554899523337, 121.61834316868936, 117.0596468833185, 113.30657405237999, 121.45074029122631, 124.6803100647465, 113.33109671069731, 119.03443474923412, 120.65220848206552, 132.55753547914568, 120.63207887834119, 106.88905085286787, 117.93613187728391, 106.03671196968325, 132.05942584622292, 137.95338323039394, 122.32720175097067, 122.24102727828489, 115.05449202752884, 114.26713897335915, 126.12413452517603, 122.05749173318188, 117.40438399776336, 108.87866527803483, 86.75266142814391, 58.76690326198455, 40.641905261624245, 21.87640774634577, 5.3149302351859316, 1.3480054923603613, 0.2546518088708962, 0.29616897865649194, 0.3360150502093377, 0.2601479228225447, 0.17922968663755925, 0.1840411784547952, 0.1184043815479644, 0.16513936852495517, 0.11561278013452408, 0.2219002324366762, 0.1820198401448227, 0.11171022099592995, 0.25485523585830966, 0.16501972091294106, 0.2365222308904894, 0.20027364694303085, 0.24317475456383922, 0.12781222471066062, 0.2595777082587442, 0.1949320222821928, 0.10580755950462435, 0.16804271918391028, 0.10672999831337122, 0.28943506580206657, 0.18006611675504716, 0.21191395458675202, 0.08418347911849137, 0.19568949937820437, 0.13671485586993157, 0.20496132362994457, 0.12028098286640261, 0.23336875252425673, 0.16456731535013647, 0.17866057524036977, 0.0783786317333579, 0.1425588197044788, 0.22735148427947877, 0.16545706518715428, 0.15244334575630006, 0.3180330360849058, 0.12130180268638557, 0.15902230966716044, 0.14648169549482484, 0.2219104673713446, 0.1843429404881693, 0.14350054094627981, 0.12584144820369061, 0.35062909667049685, 0.2972616651846517, 0.17143411381590754, 0.20565259540753983, 0.2865838091219625, 0.18717322168090653, 0.20230010272033755, 0.24428884558860334, 0.1183440521239273, 0.10539423974771654, 0.15934866312290394, 0.11305417670237441, 0.2143324635201885, 0.10081429034471513, 0.13689693964777455], [0.06572247618028233, 0.14739341673351106, 0.129744804073726, 0.1951466647968177, 0.08455204401886271, 0.09707562805664155, 0.08048213297320951, 0.08363731205463411, 0.026593403552748987, 0.03419140038350898, 0.026165798171273163, 0.024764460564080267, 0.05613057656333812, 0.11677331140925808, 0.1500811136417812, 0.06965421560791231, 0.050782114567775885, 0.08675826998848109, 0.05272777488214835, 0.0092666502854216, 0.06372751810798241, 0.12885415025295752, 0.04503575416522161, 0.1388646671248059, 0.1273368901362823, 0.06438533099548471, 0.07892470686666428, 0.06041786122706629, 0.05182533862910444, 0.040049429592345996, 0.017275546992858572, 0.03562397714103422, 0.037377131051353873, 0.0032989757000318463, 0.02696603254955863, 0.0191744701981905, 0.014591359724891523, 0.015731412511799606, 0.0269816339301366, 0.057681885457807974, 0.10467024835487528, 0.0593031496710835, 0.13148520262010638, 0.02648563604922064, 0.04974947401112126, 0.026659036220441905, 0.013606478047046452, 0.06047718707592257, 0.06417835702098186, 0.034977789637782884, 0.033057364259636214, 0.04046090307735628, 0.05694205136669259, 0.07734073581354273, 0.018702673034802563, 0.10005662938760174, 0.04546416202379812, 0.03544652053425389, 0.08000691331201985, 0.17128469602715585, 0.02166845219870729, 0.018839216715986692, 0.05693677685133392, 0.15529089457085057, 0.033098526163807804, 0.024644606108326587, 0.039171033178366, 0.14250848772785357, 0.19907563864704103, 0.14650503053299843, 0.4076702874754706, 0.2022869413297984, 0.2012195969901739, 0.26209660535377843, 0.24569406534635255, 1.4577258306164897, 4.797883399071233, 5.99547028541565, 7.974584035335049, 15.049260643220718, 23.14899721453267, 14.273637437051343, 12.49515635351981, 39.1344246556682, 28.890190047602502, 36.71743662126603, 38.48003210559968, 45.95328869358186, 52.908604145050056, 58.884401782866455, 68.00595206599083, 65.83823065603933, 55.907138470680486, 57.28825207679503, 66.44258160744944, 68.58547441421017, 68.741804399798, 73.56263268378474, 64.62092699543123, 75.10410847202425, 72.20131920230004, 57.09010570280014, 42.60315310570502, 40.16965581524757, 35.680711038651005, 22.45105262725584, 11.971098280722096, 5.194681152220696, 0.5721213872874937, 0.45637785126605346, 0.10838395149837579, 0.08130924746153817, 0.050614318329720735, 0.06841922058693825, 0.12972902266248582, 0.10076980361895216, 0.037700883638594425, 0.06946575031766007, 0.026272759367261204, 0.05596521648488218, 0.08296700044264717, 0.05063436685069915, 0.016298608689178384, 0.07912846327188515, 0.07332061282208852, 0.032008978680917816, 0.032165212736975764, 0.014530872295220053, 0.08925396994116808, 0.06306268785509371, 0.01053332016923495, 0.03625949303950033, 0.08281658673959394, 0.0808790737702962, 0.01730588024422046, 0.05897110801250224, 0.012596020523849274, 0.035565425040981466, 0.06322861483861363, 0.04385295271452877, 0.04744339231101256, 0.06738619698632149, 0.018509716554094228, 0.09359224924757596, 0.07641556973178541, 0.025886260348582463, 0.04898476121466487, 0.11893308180714808, 0.03139111919388656, 0.007629553907580915, 0.06502589541337182, 0.06508981012889455, 0.0694698718706927, 0.019668811413970207, 0.009166492907811076, 0.01128229943494643, 0.058260120962175636, 0.03613633291435338, 0.08534393378443296, 0.07393942034292607, 0.09120623776388746, 0.040789796114568753, 0.024840749514799927, 0.04933980083273304, 0.041282735389447024, 0.11239894936161657, 0.051424816370971745, 0.04256170385727479, 0.15114229863449452, 0.14869077131152153, 0.20149822316823468, 0.25109630288375967, 0.1166372235503889, 0.09486904968657801, 0.08024037860694432, 0.1367898865212356, 0.11145259328787366, 0.07028204764449789, 0.029275205414441806, 0.10839795558563164, 0.08023091742107946, 0.05609175505777521, 0.09376471862196924, 0.08050964319057043, 0.06674184043320917, 0.058821962184963696, 0.0077510358213687385, 0.03132151052986663, 0.03480919666828648, 0.14585243087382088, 0.06866069150067146, 0.04524655857934587, 0.087123287901763, 0.09180311218745286, 0.05645429084618246, 0.08984312985933597, 0.11324907713119062, 0.037873379826065035, 0.04457684068550025, 0.07013836019341985, 0.039629701509951584, 0.08402810882656805, 0.0189304941769449, 0.03878370678472904, 0.010093766688970069, 0.054066980843462294, 0.05234495308550616, 0.055829289504477096, 0.09797512253205623, 0.066115977242589, 0.01796333690083796, 0.026146195896510637, 0.10922617324057127, 0.03662716544743988, 0.038650215963923165, 0.037537752875998136, 0.062082520490812684, 0.0630882790222043, 0.08036489087727763, 0.07228831700499981, 0.05488501718988823, 0.025933229199220097, 0.05302100269604595, 0.02240590375637816, 0.07634169587324705, 0.10874327737838031, 0.05686168874343557, 0.04001822683119005, 0.03858224098240176, 0.10459544752994854, 0.075314027227221, 0.037271453052639, 0.020442602352329323, 0.05304334948079721, 0.10578629290384632, 0.08172121124281999, 0.017701105004356756, 0.03277155600728528, 0.10952509308774626, 0.07654271734457824, 0.024812691544573155, 0.13138706675700604, 0.09261140389548195, 0.21149095147848132, 0.22628047803957618, 0.05827551932945367, 0.2894992026830873, 0.26355388844686173, 0.6496177385410955, 0.7191977049073865, 3.1224537664844147, 7.99675032977135, 15.085795560190755, 18.540886909730975, 28.61026421669991, 41.31460351328696, 52.76609659194947, 40.65481378186134, 40.09353829968361, 72.14310338420253, 65.96997522538709, 74.30999325167748, 77.66795004567793, 80.43188741130214, 86.13496657340758, 90.67720459353541, 94.50073888224941, 96.39201948719641, 86.70625978900541, 88.23771784382483, 100.70679141629128, 98.02361565251505, 105.12395289636429, 105.22887629847374, 102.79140564703174, 109.83543334468719, 113.74926059476792, 96.91170215606691, 70.62329476879489, 67.47840896729501, 64.85290773453252, 44.072057201016335, 32.80751016832168, 21.625640815304173, 7.801336376897751, 2.3699352818150676, 0.11808382737780772, 0.05048036402572067, 0.4170503905944286, 0.11353387031704189, 0.03583543272989412, 0.08946888824744571, 0.09691059739599306, 0.0630255479125246, 0.045629958772370895, 0.04917354443140569, 0.07094351860183863, 0.07030697614555398, 0.023153094206786445, 0.04833750884919878, 0.03317988470136639, 0.02549006648722195, 0.05746626235063999, 0.06327624252486615, 0.030041745330597606, 0.07265472919830392, 0.031090985097351576, 0.07445156544206605, 0.057087983455388784, 0.04331852977855071, 0.035037391278291904, 0.038679162596142104, 0.03800415103473971, 0.05861399612659889, 0.01636671582086673, 0.10215335841020269, 0.055462540232486306, 0.055548495297590574, 0.028827440429238543, 0.03352227620780468, 0.06619728981487213, 0.01148294743841454, 0.0729488303524352, 0.14579912647604942, 0.04407088940722808, 0.07184633789884468, 0.016708461898228815, 0.12340776306847412, 0.033101736072210536, 0.061698166518321926, 0.02726622027224831, 0.03794138928154304, 0.0683120602080899, 0.05438575385919502, 0.07641583786255891, 0.061864089671402216, 0.056258873308017376, 0.0698891671134099, 0.03729300693638864, 0.12438893017749633, 0.04003907974448897, 0.10415118548177904, 0.11653560964811234, 0.07761811326828695, 0.09941173657294243, 0.11840481055720199, 0.14890092455091017, 0.18960149057449835, 0.06254707237765675, 0.10020515851436124, 0.08195037112361, 0.10732462043843924, 0.37917095867376177, 0.282410713693788, 0.18510009582725265, 0.2453484984054681, 0.22255595773458484, 0.2307531138461444, 0.1987426202263563, 0.16637204996039792, 0.15027959170120378, 0.2236626330282419, 0.16531924596957623, 0.1990675947238361, 0.18423343588027263, 0.4611009671803444, 0.33998078095816797, 0.23348596397667165, 0.32033326104283333, 0.13964056097451719, 0.3044176924853556, 0.20835425043779038, 0.20192265120004455, 0.20930461315137727, 0.15442500071179482, 0.30028452555979457, 0.21150765219523063, 0.15579707950593966, 0.10220352184748459, 0.325773251393149, 0.11673470823875359, 0.14574404475429367, 0.19690670583757663, 0.08752273380636208, 0.1641414011077535, 0.10534838172456912, 0.16702190702480657, 0.12408667018697148, 0.1858749477973869, 0.0729308272862146, 0.11761033907532693, 0.09645534964698939, 0.32926247545307685, 0.20502048093945752, 0.19597236968336568, 0.209114316910986, 0.14373677181861094, 0.13857393675754148, 0.14570531134884204, 0.12008314832083641, 0.1828351875226344, 0.2498478860023522, 0.13124937011349586, 0.19892795221699824, 0.1388167866295384, 0.4857263425665517, 0.21994588085480277, 0.33883817614086215, 0.17052888900281923, 0.1395523842544325, 0.20191275334406286, 0.39300641465571623, 0.15034527607983159, 0.08167853248455832, 0.23912234862725582, 0.25755168149067514, 0.1829556931531237, 0.2166281072723289, 0.15979135469082864, 0.24583407557539402, 0.3270122607148463, 0.3641383217707757, 0.5395969099575474, 0.3372226499261395, 0.4310592582389232, 0.2605221414517972, 0.7514418553440803, 3.2653072236045717, 7.99429786782111, 11.02189842731722, 17.901089499073645, 28.161878470451605, 36.18871288914835, 28.81483739422214, 31.499946886493316, 61.295910266137895, 54.98931561746905, 67.40824560965261, 73.04929640985304, 75.07862091064453, 75.77266077841483, 84.85435193584811, 97.0956220934468, 97.97903399313651, 91.58668456539031, 90.56267922924411, 102.9806443183653, 108.95572416244015, 110.88803275938957, 113.67224877880467, 96.99971229799333, 96.42458300436698, 102.27896367349933, 87.84012286893784, 68.90459060668945, 65.5656376961739, 59.52145353440316, 37.76730214395831, 24.893032043210923, 14.604471710420425, 4.408957842857608, 1.5564299470955327, 0.14742076607240787, 0.407698571441635, 0.5576787300167546, 0.24226485661441283, 0.3037412368482159, 0.18096076955478038, 0.1729519944638014, 0.11597047424724988, 0.23577665880082116, 0.13394364005615636, 0.3136832501378752, 0.1296238541122406, 0.10817038150684488, 0.15164440798182643, 0.2394567000409288, 0.21298840822231388, 0.12326999747705077, 0.3158200532197952, 0.1356878077551242, 0.16107429149410418, 0.10210865717982093, 0.15405773816089477, 0.16662187123250577, 0.18529629094466088, 0.12948782754040536, 0.15214593510233587, 0.20039246718008674, 0.17072938953436192, 0.1142719041015352, 0.20940546096572954, 0.14987920350845785, 0.13146601977848238, 0.08908210577623499, 0.178486795855626, 0.17688303675142028, 0.10471710229232427, 0.08841809140698564, 0.25650791733735995, 0.25194975547492504, 0.19476631746417095, 0.14638394267568666, 0.12443060536057719, 0.14318463692982353, 0.13788071911661856, 0.10493171416343221, 0.30911470012318704, 0.25936338750104754, 0.11412209560794216, 0.1594316304451035, 0.16905128925798402, 0.14905883059386285, 0.14926290109513268, 0.13192447743588878, 0.15367181370815924, 0.14820822784977575, 0.2651288120015975, 0.25922144673043684, 0.1546906953256938, 0.4270716786624924, 0.1853105401800525, 0.38347009088723893, 0.3604791487657255, 0.35170787104195167, 0.1418365213659502, 0.2778078735836091, 0.19501711932882188], [0.05442669742830819, 0.057205141281649, 0.06035544804387516, 0.053509330121620055, 0.004427508918583513, 0.02241488996772997, 0.038509952925866654, 0.05759355552013844, 0.021805863474465666, 0.08169262850236508, 0.04489155726567392, 0.05305595928803087, 0.05304578947083605, 0.04714928732644166, 0.02991168849891232, 0.0722980693042759, 0.04144210849077471, 0.006617858673581073, 0.06192815377407017, 0.0009785097415348696, 0.02205161298925598, 0.040854526713730833, 0.09374774977444641, 0.01960916189296592, 0.03971906566631891, 0.05210109580788882, 0.05241862393074459, 0.021860192514835827, 0.04191630542458546, 0.06324446136732736, 0.06885702451390606, 0.05818070062706548, 0.059235902473090164, 0.02322609089465151, 0.03741232896103494, 0.02421002166586057, 0.07417428757875197, 0.073714044936482, 0.056100296938130935, 0.04248970308371129, 0.07635377707981295, 0.052722864258553714, 0.05807157906313097, 0.03338774350742179, 0.034504787801134015, 0.041375884020160285, 0.04631676425736758, 0.04317292710766197, 0.027495761281780662, 0.06309952902337236, 0.040525078262773254, 0.02081770389791458, 0.011959624581880147, 0.03041150915857044, 0.07475029376725997, 0.011003362991276288, 0.04696658301738001, 0.044518108554785295, 0.04478232078855077, 0.04405484752609365, 0.028692582141487833, 0.025828324949308753, 0.040103534551998304, 0.09771008675377216, 0.02251975399802529, 0.1465792797746197, 0.04528633769481413, 0.059433825118767644, 0.020770683336342056, 0.19244755317847576, 0.06471260375673733, 0.0371602209164731, 0.06951719312177551, 0.02739385243565325, 0.010026100057838185, 0.05741429860673605, 0.04571437783118698, 0.03637083625841526, 0.05232980752724314, 0.07363771193570669, 0.033599141639687365, 0.20670195200270225, 0.18762403378082862, 0.13435250118134484, 0.20397382097378855, 0.404258560869963, 0.11695362552399598, 0.2571690665377725, 0.03915062459606317, 0.3151188069774259, 1.0029185515257621, 1.0414733665604745, 1.4893461403346833, 4.410570427294701, 4.952731709326468, 3.470638644310736, 2.48678685676667, 1.974787007897131, 0.9987498074769975, 0.4529803126089035, 0.6524928971644371, 0.628588196010359, 0.674259967861637, 0.5075236277714853, 0.2423436564183043, 0.12386605218653718, 0.3262521482763752, 0.0992976354375001, 0.06689916424933942, 0.0656085895494588, 0.012908673454676906, 0.04905154492946402, 0.08782957500267415, 0.11647711883509353, 0.12090571990777409, 0.05262316557608786, 0.05864823642637461, 0.05857637354863748, 0.04724906261769995, 0.0464724907801757, 0.05959343953779148, 0.03346141818309984, 0.019314614492618752, 0.1173448283225298, 0.04656878803225775, 0.00930747032285698, 0.009747801382365006, 0.08257166076932224, 0.03836859438207842, 0.009155578070109891, 0.07538483673406225, 0.06223011499030456, 0.0343928738467155, 0.024920748246292916, 0.0833428125347822, 0.04107101933069287, 0.052323031479552876, 0.050861351041784214, 0.09599273213215413, 0.04813240412923117, 0.016525533508449312, 0.01899902648743122, 0.0722504799224196, 0.04179936593338367, 0.08199790687931162, 0.04129080995616894, 0.00975814835739232, 0.055235207471395695, 0.051237795156456774, 0.012812244052427911, 0.011628842180324419, 0.02688381216308523, 0.04557411096269085, 0.04127925735027079, 0.04091095291979371, 0.01598609844222665, 0.05761082697239134, 0.04371080510017853, 0.014153212015967698, 0.044551165248717994, 0.0877590719310026, 0.0540555278289943, 0.038727395491854805, 0.018424087076357776, 0.01786973244780975, 0.019714801587284576, 0.010859214929833768, 0.04640776401145324, 0.05696959988844972, 0.02235592034975848, 0.015125250229762207, 0.0626106538449324, 0.02927196294730229, 0.08640691142288909, 0.03602621926655693, 0.04195772396821169, 0.1421159136319353, 0.13958618405365175, 0.09217219036673346, 0.11138262647774913, 0.073148135786816, 0.03871474738022493, 0.034155830921184634, 0.05709052303685777, 0.11167169443421787, 0.02142486305186345, 0.05932880978610727, 0.16294576768432895, 0.12780847087983163, 0.06853083959750592, 0.0368985635859351, 0.07290441257458541, 0.009705070913168452, 0.12599530164152384, 0.08279558826958941, 0.09374609502452998, 0.1380255863431, 0.014658496797745748, 0.07982325139305285, 0.03246700158342719, 0.04933058096456432, 0.08139470456949166, 0.0832932006808058, 0.014218054655488702, 0.05004990305150709, 0.02588458644646791, 0.020847983523121765, 0.06995982340266628, 0.06520771872132056, 0.05886919916637483, 0.015208132324680207, 0.02909806098849062, 0.018827639212231004, 0.04267368675960649, 0.08503468707203866, 0.019564878180502884, 0.05005923783286445, 0.031237246603855205, 0.05820135435750408, 0.048293389845639474, 0.049648752601276484, 0.035453212312272483, 0.07453336831062071, 0.047214672930779, 0.011797009971022848, 0.05009804018622926, 0.04115921520297566, 0.024127891294718273, 0.028793470175456137, 0.06054027058604745, 0.032964265424638026, 0.026587803450022495, 0.07213563568169071, 0.018448716803123395, 0.059579355011303584, 0.014455073640771933, 0.08988911811743053, 0.014547982869008857, 0.03326397434237503, 0.0735479417527395, 0.06027252285651142, 0.10914331317068109, 0.05297604865664917, 0.09789860567017909, 0.06578781581934422, 0.0768521172745574, 0.0736829953929109, 0.1011942086681243, 0.07108224180316733, 0.01350096284201549, 0.05013008947454153, 0.036920381770018613, 0.513541677425946, 0.1453511335796887, 0.232030121128886, 0.42846856338362543, 0.4862811434413157, 0.7149269179471078, 0.9240710663218653, 1.6751250360281238, 1.0412819058664384, 1.6851954762974095, 1.5013485930619703, 1.3800915835365173, 1.2365659302280796, 1.8934234448017615, 3.6761021998620804, 4.1735406171891, 5.356716715520428, 10.659373364140912, 12.987270643634181, 10.584636522877602, 8.307955591909348, 6.810921728610993, 5.942523191052099, 4.156644517375577, 4.0347686313813735, 4.464151474737353, 4.757657531769046, 4.419491858251633, 3.2550151694205502, 1.3655682725291098, 0.3617614267333862, 0.10740675272480135, 0.2480318898996038, 0.12727574099816624, 0.021222297913364826, 0.037840116288392775, 0.0462172226229262, 0.03191606753746108, 0.044349699446390715, 0.021393606664552804, 0.014841569786620958, 0.02787375672449989, 0.07543193581964701, 0.037712570309879324, 0.017596790642147104, 0.0368893628699645, 0.07668144054590695, 0.081319275552467, 0.03248552558943629, 0.03371856325576383, 0.034370419809654836, 0.0828955780654665, 0.015902071045861853, 0.03172377946846668, 0.03469158301971132, 0.024279293251193823, 0.010882863106446402, 0.01719250306186657, 0.04576225832645451, 0.05604515392934123, 0.07283245393585774, 0.016819481444995732, 0.014001970937956246, 0.037004513545863094, 0.03472390043879709, 0.025777121547669656, 0.04741813056170941, 0.043671998916374105, 0.05096327520967011, 0.022574155816748258, 0.025393960757120967, 0.0896873765234505, 0.040552469736505906, 0.03822087730851866, 0.03559100854721281, 0.0024711645504970465, 0.022541056987979723, 0.05543844676726768, 0.024070459598254774, 0.03879561562151198, 0.04111095166374599, 0.015780705481677527, 0.028053984654346303, 0.0427205445274951, 0.02737861111639969, 0.05957335654285647, 0.009047096189592154, 0.028152266074152246, 0.019663590524766236, 0.02024399788839923, 0.09373506335842033, 0.039728680069768624, 0.07005105681356884, 0.05140436182339346, 0.014762287347337172, 0.06243921102835767, 0.07726357543780919, 0.0046070339627594, 0.10442692350836531, 0.12404385353288344, 0.152994392800235, 0.21879443538285073, 0.21890746399519906, 0.1868267967215469, 0.18302346129090558, 0.08108640780612346, 0.12476447413885787, 0.15156167048600414, 0.2335031243461755, 0.17571973223840037, 0.16806246893059823, 0.30473537382579624, 0.276676177858345, 0.141986322198664, 0.20825225349155166, 0.2732511519664719, 0.06625551249711745, 0.21787692251945698, 0.38403491219205244, 0.23649641372744115, 0.27950619858118797, 0.09075032351838966, 0.14593466275161313, 0.19911169074475768, 0.1435388759860108, 0.19178455004528647, 0.1745415962631664, 0.10369267419821794, 0.13835622989121946, 0.14142848761571994, 0.1583058029533394, 0.17840012066787292, 0.16143778489241678, 0.11367953427496458, 0.1444721089736108, 0.12894290919986465, 0.08872470277692042, 0.0936394326028324, 0.18807469266316584, 0.15747919408304079, 0.15901285614217484, 0.11721628642971478, 0.12189605708924994, 0.12333813333703626, 0.17244956335954129, 0.08994780045243041, 0.1377252492332651, 0.12956629026561015, 0.09552295169522686, 0.12884368549191183, 0.17216159090880426, 0.12203232880922095, 0.20986932720388138, 0.17896524840785613, 0.14085104118191427, 0.10621145638006349, 0.16512875054632464, 0.1396692892716777, 0.17544371075928214, 0.11348832638994341, 0.19802369267469455, 0.13502730206856806, 0.20071221695792293, 0.1146694194645651, 0.1879327059272797, 0.36475578863774577, 0.1962633298770074, 0.2426835236650321, 0.19953354472114196, 0.2863220521999944, 0.16607712143130843, 0.18878677138878455, 0.1445941161364317, 0.10506125197054879, 0.23688911039742733, 0.13953914625510094, 0.29754839657295135, 0.17643271494776974, 0.19393756354768432, 0.161278928900438, 0.2112813191788812, 0.2815364847981161, 0.37146013049829396, 0.47494150998611606, 0.37625492159878055, 0.4993904706451201, 0.3653924077028229, 0.43383743013105086, 0.3469381156948305, 0.5321304331864081, 1.0228867864897175, 1.3275492287451223, 2.609674469117196, 6.2536490251941075, 7.16082803664669, 4.9619679104897285, 3.5227389970133385, 2.376893811648892, 2.21191254834975, 1.3090199520511012, 1.1396874319161139, 1.6382274223912148, 1.5188386868084631, 1.3948110130525406, 1.0949867531176538, 0.6376647444502, 0.32322662191525586, 0.22331487507589404, 0.2507420178622969, 0.25672735556239085, 0.08782426601335888, 0.15736444943374203, 0.18035796561068107, 0.12151312037941911, 0.32097349604291303, 0.19635348310393674, 0.10743143607772167, 0.2545961602440765, 0.17810641787946227, 0.18675230233178985, 0.14261368692161577, 0.19504915712581528, 0.1818602487084366, 0.21243480244471183, 0.1949899385292684, 0.1361773685822564, 0.07311222924580497, 0.2795616327033889, 0.14899804917795045, 0.11537557633052911, 0.2019653989062194, 0.1456966392335392, 0.19410420299297382, 0.08559585413745335, 0.14852777844475162, 0.14674288551172904, 0.20406676276076227, 0.08100119584630575, 0.14997036797144722, 0.12240375121754986, 0.08444813185281332, 0.16592047177255154, 0.12248523232917632, 0.12190252287133087, 0.1346489618862829, 0.20534550140221275, 0.08829964655301265, 0.258267299542504, 0.1439645604020165, 0.12427772485440779, 0.09784756123178429, 0.12447713754109799, 0.15862291738871606, 0.20581788653808258, 0.1306156315390141, 0.06450764459347533, 0.20214261036486397, 0.24171256850804054, 0.1318126745642193, 0.19841920854824208, 0.21198766756682627, 0.17049470615963783, 0.10395744950660776, 0.09840369509953646, 0.14264330388076846, 0.08564557324373916, 0.19145099536305477, 0.16014662030483448, 0.1948936872424618, 0.14088681748797818, 0.13320940606776746, 0.14573831441662005, 0.13634783846716728, 0.19231811496278933, 0.2623914879175925, 0.27257123361191443], [0.024149014254010493, 0.005284704328063996, 0.018237667240863367, 0.06373066672935121, 0.007228362758929331, 0.07938890252262354, 0.10205968117882168, 0.04098023025078639, 0.05085029639303685, 0.015013086339158398, 0.021110805307304668, 0.08664921737245976, 0.06531849503517151, 0.014461653378431596, 0.12288396577200583, 0.018828140999821406, 0.0819857873683495, 0.032503061342023076, 0.1075363364971934, 0.008560341159482638, 0.014334795921440087, 0.05438796785329619, 0.02335997625073839, 0.03039817539824834, 0.024299652037781574, 0.016150351523632006, 0.04984962851590207, 0.015709792552966506, 0.04062483440183344, 0.029120467145056016, 0.013575853682273339, 0.03657258551327452, 0.009853277325389848, 0.027544825382891203, 0.04238187237792919, 0.05947639662471991, 0.07481583258918217, 0.026954370776131272, 0.04288531471824935, 0.029865368907790513, 0.025578902042921514, 0.032770491145070524, 0.06151707099390127, 0.02360066575478883, 0.0726534728141081, 0.02041173666986006, 0.018290540714177395, 0.04365299993585195, 0.02036134149098108, 0.1419247746948273, 0.014121061221005456, 0.031406544374241945, 0.03493153707935445, 0.058327092368516235, 0.06539061455236328, 0.01685455103494948, 0.12574788588549823, 0.053700672072027965, 0.02836732036103645, 0.042949057063989104, 0.055919967501634554, 0.03838791128908915, 0.03599935256305241, 0.002665234013317874, 0.004308373149063799, 0.02928373771869848, 0.065620364320855, 0.037576206659357396, 0.09977733671304681, 0.1036680751149693, 0.09877830443363037, 0.11835404957133917, 0.11831658787184185, 0.09412361549273615, 0.0597568460920405, 0.031137411940782785, 0.04593610665911148, 0.027261217718102762, 0.02078809651486095, 0.1002007305261589, 0.0520311136760058, 0.02266128491159649, 0.03741241706114623, 0.032549735248809865, 0.010132441680217463, 0.06542736379009101, 0.025230287987318252, 0.05981495386109718, 0.10084766879557602, 0.02891094784342474, 0.0967625585655051, 0.04689120379607043, 0.02830448008382753, 0.18007814433545838, 0.18991676639885674, 0.1450775022948942, 0.12639738288858246, 0.15655774352771623, 0.0522885115576848, 0.07980672687652611, 0.017513221940926967, 0.0486676621010467, 0.031947076861416145, 0.11492598231040663, 0.07264584257838226, 0.07801528389175093, 0.13243271548661495, 0.034641695374082175, 0.04796657673714142, 0.09000290515682391, 0.06694971839146269, 0.10418098630203355, 0.05963412646745002, 0.010877714995595237, 0.050277906139531446, 0.025174654682257006, 0.14517730822966946, 0.04405824129559821, 0.03119683163540979, 0.016124543936682806, 0.04483292855682873, 0.05440720049063525, 0.10479325143199776, 0.03936645837741033, 0.017862753386819558, 0.020401676020194447, 0.012694762554019691, 0.05463175235256072, 0.05902719713987843, 0.06171516217892209, 0.03948648520294697, 0.01651659134715315, 0.0302611107772757, 0.07072207322644611, 0.022531080607985778, 0.03323653690336693, 0.07034844448489529, 0.11007132143863749, 0.01367533594490059, 0.056664068702488184, 0.04916334014025427, 0.10573641291909641, 0.051126103367536306, 0.031170215825700474, 0.07703526591461513, 0.0806439384036968, 0.027188113777928298, 0.06467562469263231, 0.1310828072769988, 0.011338807037851263, 0.006422713575434061, 0.0660351166621812, 0.051491676694563324, 0.02922995260075456, 0.031240305209892894, 0.03743989663499017, 0.04428368564995547, 0.028453731248455665, 0.030232020503570958, 0.03386192511947405, 0.057488141821757446, 0.060336261371811556, 0.01619117060345748, 0.028825151741564758, 0.035323785587904916, 0.06114512764578385, 0.07163335013413621, 0.08052539395829363, 0.029583663056274096, 0.09461399603394732, 0.024349453498519236, 0.020613487839939135, 0.07143375358634418, 0.032174375148550156, 0.020186652376827215, 0.019156608858235905, 0.048440459574903214, 0.0687211741422934, 0.016884531885866198, 0.01564064162648133, 0.059955822108613874, 0.019479930521019047, 0.04030590433807623, 0.00878386071793014, 0.00206349229800605, 0.04873401297616863, 0.08264133646603554, 0.034344204280885963, 0.028550610727360173, 0.04689887999707172, 0.09163845690988726, 0.0162586112386517, 0.0269465011379291, 0.0228029077557186, 0.023212996536805745, 0.04458299237153223, 0.03626731479720723, 0.029861475265915358, 0.002652581113638477, 0.046186092640123064, 0.027796253524420243, 0.05011368370164306, 0.03008305470669462, 0.02373540529891128, 0.05696656234982995, 0.04346194526841564, 0.018647294453976136, 0.038243166636675596, 0.05094474737322138, 0.03301485787115751, 0.05946924902438637, 0.06660759884623751, 0.07792121595552853, 0.04875296216097571, 0.01850789901049387, 0.012017468050602945, 0.025727908059413877, 0.043902863342795646, 0.08541845881770696, 0.031500688919256774, 0.036651132508150996, 0.014455509353278866, 0.10112181335927979, 0.035188957943671176, 0.02379569641855215, 0.026330618157742486, 0.029993669482909387, 0.01823778981493125, 0.09838198416776235, 0.04209169742440985, 0.030469262611962138, 0.0317996317490695, 0.0745754954855769, 0.03941954060968372, 0.02408667384917217, 0.03633610949280762, 0.026480886304090102, 0.05029007927664826, 0.07289598560741833, 0.03215158403280281, 0.04973222171106646, 0.056347869742181034, 0.020592678976695866, 0.05067016613940078, 0.06954417473846866, 0.0868999119848013, 0.08161817241700427, 0.08843527475912726, 0.10789632121281278, 0.03400470858680145, 0.03694306946389618, 0.09893150669672797, 0.036301727466765916, 0.043053225869493145, 0.04415291444128079, 0.06040785228833557, 0.1359610253524396, 0.0744415526728957, 0.09977857777548414, 0.08321162763862841, 0.036190805596209345, 0.07132307686392339, 0.14223159290850163, 0.28879446307978324, 0.18811918704980807, 0.019373457706082734, 0.07391882023864216, 0.06028936529952673, 0.10779242436852186, 0.32397478338210817, 0.21295764213127477, 0.24442925418336547, 0.03771658461060255, 0.09299598769434998, 0.1749868772082752, 0.05736142704864183, 0.04653556662942133, 0.030192406097006415, 0.13631975368386315, 0.2061982645142463, 0.1249836135895983, 0.07321150657991249, 0.15434800887540465, 0.022692391911761898, 0.04641216518657823, 0.010742341513715444, 0.022759796157779715, 0.0396500526356601, 0.07946689793419454, 0.02991203323847825, 0.009685571102665798, 0.014059635333626742, 0.0416314777647776, 0.009273605406164162, 0.0017671927109345674, 0.02151390928174219, 0.04883087330287503, 0.03764075722785727, 0.028685018938455372, 0.04244034786918952, 0.059411463012257894, 0.031134462502274304, 0.016185911409857295, 0.047026786036909594, 0.03485439968625865, 0.04328351956041109, 0.07119972138635575, 0.05897485418245197, 0.0577557516554671, 0.045681033854282675, 0.04387646012248532, 0.012395872392751759, 0.04785930527554405, 0.0209120974215048, 0.027556435445383675, 0.0559353850211107, 0.07254212193431393, 0.062255591244226506, 0.044866479377472596, 0.04271659534424544, 0.07483313085451242, 0.08910281313282829, 0.05628054976583489, 0.03190325088648787, 0.06391243258070561, 0.02271742191946795, 0.061048194540724646, 0.03036446752958, 0.0606342772352359, 0.012780367133898601, 0.052949028735559796, 0.03256930496483561, 0.00900134637636403, 0.01887046161197847, 0.03837516741646874, 0.05830047847402673, 0.03853262146754611, 0.03743924929069416, 0.11821717264190798, 0.04170979110283717, 0.031277952685711846, 0.02155373436248591, 0.012883973822388197, 0.056882323321676066, 0.032033830573181474, 0.013412063126452269, 0.04856461561435173, 0.006336984506267454, 0.023159761086947495, 0.022717623017548073, 0.04965182078341323, 0.04647780359993058, 0.14251530591037967, 0.14802373855585052, 0.15534182409605674, 0.16839787754560673, 0.15226457147828995, 0.21908859782401593, 0.18055218422124464, 0.131305125992625, 0.1154874328283533, 0.16105869394396582, 0.20354369324782204, 0.2466203882208755, 0.13420449299437387, 0.1350059588589976, 0.27486290902860705, 0.10978711047960867, 0.14299368185381736, 0.14398677695182063, 0.2590283925735182, 0.13660579559303102, 0.14799528605034276, 0.258794306747375, 0.11727204230884392, 0.09129363307428938, 0.08507645418567043, 0.1122546107358029, 0.1028996199790028, 0.09790374612015101, 0.16995363358047702, 0.12486008957268731, 0.15105547022915658, 0.11999252011939404, 0.14216702701824327, 0.14242682275512528, 0.18277964614812406, 0.15331821816582836, 0.2164888171659362, 0.1331641302714425, 0.16834771410832483, 0.08889675846383457, 0.11544202679708121, 0.10997692408460764, 0.18813933516221662, 0.085387539509083, 0.13300032535147283, 0.0779787874630382, 0.23993078589199052, 0.17433256151214724, 0.10539165803141172, 0.18363067790144877, 0.10213277362767728, 0.08943433002118142, 0.23165384938399639, 0.15490486286580563, 0.14494351351693754, 0.10675724806083788, 0.2169657988293517, 0.12836812109115625, 0.1698749869941704, 0.12985685209353126, 0.22325311306743856, 0.20407860648007164, 0.15279956131933198, 0.2831039313347109, 0.08714300700493398, 0.16723696322691056, 0.16284859709201321, 0.16975792875934034, 0.22203273500405976, 0.21952565098481797, 0.19712009196800573, 0.29651025550500043, 0.23558317563466488, 0.20564588447732313, 0.20303612935446924, 0.18015450797975066, 0.0821041785961678, 0.12396285505664927, 0.11285114808068161, 0.2658925403750712, 0.16665478236973288, 0.1767590990470302, 0.2699779647011911, 0.20607078748364605, 0.2051084278331649, 0.19327111301883576, 0.15867381627040525, 0.22320400683149216, 0.1772263973590828, 0.10536454617977144, 0.17430190267341752, 0.14603010198522, 0.0891141435732284, 0.3589722538186658, 0.28018657658849994, 0.27129214257001877, 0.3080392965385991, 0.3284227818010315, 0.15559970461312803, 0.13847238414229887, 0.22014962959914441, 0.21409134500690047, 0.21483687113129327, 0.3073652923828171, 0.18925449871007474, 0.16790384276499673, 0.259603510100034, 0.11998049253898284, 0.12159651671085628, 0.19674366700553125, 0.08571511104462609, 0.19169713941312608, 0.19179308426476296, 0.16694673847767616, 0.16408929180714393, 0.07749161683022976, 0.2217281690888828, 0.1071291224610421, 0.0968065320123588, 0.14025899311227186, 0.1736697115965428, 0.10607028935825634, 0.1640946544226139, 0.19120417715561008, 0.1292401206709685, 0.125452145303209, 0.08808377829770889, 0.1955120580931825, 0.25009660410784906, 0.13834173550769208, 0.12726195907640842, 0.12892311348790123, 0.1423886715764961, 0.1436387585295785, 0.1211023593561784, 0.14439701703527283, 0.2586401085699758, 0.2768376998363003, 0.07899891780388933, 0.27662638214326674, 0.15663183955175264, 0.18809318602565797, 0.11217037936852825, 0.11759867155624014, 0.22933821073703228, 0.16275590045317528, 0.15055984198566408, 0.14690990800098067, 0.20539587934411344, 0.09099292058137157, 0.1408684926648294, 0.09875928247047049, 0.18877115851688772, 0.10927492707607248, 0.19766133308650988, 0.18605698560995443, 0.1388186865275906, 0.08325733244419099, 0.0900406503088532, 0.11988066362156985, 0.1818687216408791, 0.1649760232577401, 0.1644652877603808, 0.1282653657178725, 0.2527207770054379, 0.17611357804027297, 0.1404023434846632, 0.19737423397600654, 0.11292079313387794, 0.17081303101393486, 0.1193276477316695, 0.08904502712069981, 0.1764638181174955, 0.14381601595349852, 0.21444305597293764, 0.2262968416776388], [0.02335937870215745, 0.013415711620191654, 0.05473955241482585, 0.012801611709648804, 0.05794281883525753, 0.05301250295052606, 0.015613405285553347, 0.03128663629233357, 0.033883911842900905, 0.03112360512116744, 0.05239359200781873, 0.030610996538833268, 0.05798770392674112, 0.08927570385557991, 0.006636050388953018, 0.013589160629518092, 0.01837814286831887, 0.04944650155882682, 0.03046976248433273, 0.006874984115241997, 0.046045484862500624, 0.12713940799116127, 0.028122681673736345, 0.04097153515284581, 0.10212728843813944, 0.05873850456649258, 0.024980284769328374, 0.04827831323528963, 0.05500425111442324, 0.027338935422801205, 0.032866750092756365, 0.012242872185344178, 0.016010882344187027, 0.029728013173406644, 0.0274815580116645, 0.08441805524090606, 0.03789970643758293, 0.05576397284805294, 0.06288972435398929, 0.1145994756370783, 0.03522562291172724, 0.036646999463799505, 0.06029456703653259, 0.08555237098687118, 0.06683120458957649, 0.020624463964674263, 0.0424709837252815, 0.04987792780382499, 0.03273191478764338, 0.06087389038575273, 0.020267941966472615, 0.03998333152623908, 0.022653045635970852, 0.04697546963730166, 0.039434042654090354, 0.0244544496789815, 0.029661558876414935, 0.10043424944723807, 0.03228742291309661, 0.03806539976428594, 0.033515255011978655, 0.035614807068580584, 0.07218176949649088, 0.009236977784894407, 0.0449238402108031, 0.04587540951287074, 0.05575960614688455, 0.0046989501495244765, 0.03305907646614698, 0.03322020390882127, 0.055930619954221675, 0.03672055539584929, 0.11012004463062172, 0.09836644790465794, 0.05202059145836581, 0.02667784367898299, 0.05907051558155687, 0.10101009475728197, 0.06388920096440182, 0.03010500887138469, 0.055729142660575534, 0.06864747648397762, 0.07195744363050308, 0.06732852588738165, 0.04317365106075041, 0.015107674257559402, 0.10056353444533964, 0.046710092949891285, 0.030793204805963946, 0.055761460079661304, 0.09608126891356322, 0.12162814082037057, 0.021812850196335106, 0.05518230910022413, 0.045783701127455126, 0.0936814908298754, 0.07878246732176312, 0.03164049805021815, 0.08566364525787293, 0.10486066716933444, 0.12442161148834614, 0.10435909408354953, 0.05136459802968368, 0.03352540184653575, 0.05662318258996933, 0.05919176048689312, 0.07687523014723294, 0.030190603875164545, 0.036166781078903906, 0.053797448129062696, 0.10246937733984764, 0.04383745475582058, 0.03516602127121822, 0.03629838732341605, 0.04066471693917148, 0.017597780810789238, 0.053462142935923995, 0.05506559943539962, 0.05079945496794197, 0.028833532743456385, 0.03342468426713059, 0.05488819645477399, 0.018944597855630903, 0.0337607785308313, 0.04224696046402378, 0.02282072696083736, 0.04274350035214617, 0.15585427563036644, 0.04883537023899056, 0.027532918461328073, 0.008543531275204113, 0.036051883212020325, 0.05985960529576387, 0.0175659172987986, 0.06925662363608999, 0.05024301466502009, 0.08535484287647471, 0.05357628620620217, 0.04449751994182025, 0.01851234423567451, 0.017842151367315845, 0.028877605781740243, 0.008851851978819937, 0.026120844131876386, 0.05502338799077177, 0.07211246918286048, 0.09252163371251476, 0.023514182089016806, 0.031970957737235774, 0.01139797488107316, 0.008468350279144943, 0.04620875352092328, 0.012493353250676827, 0.06899083709164013, 0.012176325000191649, 0.013252023528630455, 0.06113867335502179, 0.05911301430915633, 0.033706459066560196, 0.016458048823199446, 0.1213245171933405, 0.03225515528972591, 0.013792836595506919, 0.01713820083457376, 0.057113509505025806, 0.027377567321602857, 0.09850782177020466, 0.025270798716754205, 0.06976171306544734, 0.027618308536588188, 0.0068535666909038786, 0.021214646610221075, 0.04132115852928931, 0.06493772635416639, 0.019305928970777222, 0.02978540656547393, 0.014134082800498413, 0.01929912227956999, 0.06624497878815859, 0.07596832760159047, 0.050660375535728476, 0.017114509565515384, 0.007217750047153283, 0.022429953171541134, 0.020385582428125125, 0.04236123779968869, 0.023322819071190975, 0.013841587558178412, 0.06088329028458365, 0.04178948722960007, 0.006510155808721339, 0.03688925178721547, 0.05997493983276429, 0.02608976969044776, 0.06024602387521056, 0.034983006696547234, 0.0415048357700148, 0.01723729813801906, 0.029523946502576434, 0.011980816489085557, 0.04614170933622987, 0.06269914466106603, 0.021424089303059925, 0.02448859421776668, 0.029849800085949323, 0.015512036531412554, 0.03083271770587852, 0.0653139827772975, 0.01772857500210164, 0.05705533661849557, 0.010015457181350119, 0.036298061736048236, 0.05433578960477345, 0.03473932561915248, 0.010677549627519423, 0.04125502981966542, 0.10896017985238184, 0.027293366597845193, 0.074869244239263, 0.05146156560869948, 0.07794399174951738, 0.09681851362749454, 0.05609784162633362, 0.03761172632596666, 0.014320934518060137, 0.06124581458167203, 0.018828633211312756, 0.02608800385778229, 0.01855703780517703, 0.021746371001485857, 0.027394141633844665, 0.0908762913557791, 0.04773390434321858, 0.028752911565524918, 0.03232490376479203, 0.04423043104789911, 0.06927752251466436, 0.016298702534949108, 0.027814631973723733, 0.029297598164468527, 0.004519744947056977, 0.05505499677852758, 0.021367546268588593, 0.05997441889297578, 0.08233048096900025, 0.0236510954076244, 0.0776681081662255, 0.03378710131190958, 0.02158979029064217, 0.048636949636162295, 0.061790453300120375, 0.057742544299652504, 0.058892082212673086, 0.061831393038793925, 0.013832791911197767, 0.04283183795069495, 0.06898241778535229, 0.08118036849003646, 0.07846175227314234, 0.053043085180463335, 0.040692292274005955, 0.043087485321466966, 0.14173979510463056, 0.12470920089512103, 0.06852332427496872, 0.08695562189865498, 0.04532123683020473, 0.0018849115768980777, 0.0731842338498081, 0.03961365196793791, 0.03453238611860621, 0.025403492806118824, 0.036369365369600636, 0.11459919984542555, 0.057633047352635094, 0.055122672985758514, 0.07453468598185048, 0.08673856620706859, 0.14976733934975442, 0.08127643591574124, 0.060682307117648666, 0.02311207977454028, 0.019616811280889858, 0.06021865538411564, 0.04717529984191061, 0.06866940192037052, 0.04437859245245496, 0.06769490743716879, 0.056117851842915824, 0.008845917670236481, 0.040511729180692665, 0.0515812132207136, 0.08414100720396928, 0.03775327256129634, 0.07467009202246705, 0.028902940309396195, 0.06263478944498686, 0.06981797456260651, 0.03725559886304602, 0.07798977316387239, 0.04359347107369573, 0.014290290043479013, 0.059475599893278656, 0.08442880345448371, 0.03130350937886584, 0.018285266198818723, 0.030550297477372715, 0.07944029170058428, 0.05999449039659193, 0.012968520243321697, 0.02071344124663982, 0.030878091178413843, 0.07258918271550248, 0.0141020440458951, 0.029263281255900383, 0.09364243566749558, 0.03844786149960372, 0.03133878389733934, 0.04520016812509106, 0.024423922990418734, 0.08957669214015046, 0.009841149195938582, 0.05405504136316238, 0.026475588806093703, 0.038015389544588905, 0.047475399464489, 0.02521596405835402, 0.018491102532754024, 0.041309946832517465, 0.10837034577684057, 0.014193526435373052, 0.028677321670036164, 0.03856681580204637, 0.051098551015339555, 0.06041301572094522, 0.017082006370107976, 0.0455290726536224, 0.02221355631556963, 0.04772905500665788, 0.09424681775271894, 0.04698977249884798, 0.03415071728429006, 0.02879913156521657, 0.021542580122308388, 0.020667652171405575, 0.03575497051520694, 0.03928909498837687, 0.03871163323281273, 0.03937355618202879, 0.06125532556325198, 0.029628509843361475, 0.021714271917458505, 0.11489217485030813, 0.07435550567724052, 0.15072629756985173, 0.19716912159515967, 0.11293416902903589, 0.19035156726116137, 0.13206482474361697, 0.07220875877406328, 0.11201001418333863, 0.19603849839298956, 0.08328672723784562, 0.07761277363545473, 0.1823002589686263, 0.13864582644835596, 0.11133388796400641, 0.21967410350278502, 0.1300277969529552, 0.085821942005667, 0.10847430390816544, 0.19091520879057147, 0.20429493438812996, 0.1885959082433293, 0.21651869459498316, 0.11624124036320757, 0.2238005135328539, 0.1517329217805978, 0.11622835476432117, 0.12367426973557281, 0.11342920738482669, 0.18203822625500543, 0.10450915538615758, 0.12298331971490577, 0.14151359998410748, 0.07974011553150993, 0.04704567776512235, 0.22787780200521793, 0.12817563383930153, 0.20940676331520083, 0.12135752792199775, 0.22564491617583463, 0.18864041795173, 0.16041001665496057, 0.21878197879320194, 0.10646556008366809, 0.18620939114161078, 0.2644443277630114, 0.12153318422215602, 0.12816795763830025, 0.10734463065502145, 0.22976948759488522, 0.12039617950757665, 0.132207470315118, 0.2220551507367242, 0.15039939253080278, 0.10027707118781344, 0.12882163748145103, 0.17379283724773317, 0.14080414127918983, 0.09295360004949955, 0.13548122448546274, 0.26134501181302533, 0.12883898171205677, 0.20420914786236904, 0.10006846544603187, 0.12558830210999136, 0.20601668635443335, 0.09971504610392357, 0.12532891239970922, 0.24732122077576577, 0.12687539877069573, 0.20095109849447207, 0.10008870548899136, 0.2767951359912273, 0.20055824860690102, 0.16033319335791374, 0.1315603405237198, 0.17649948717125002, 0.25239065439710695, 0.1497245456783041, 0.08487185508373284, 0.16278711087521047, 0.20455229396541275, 0.16034839254233146, 0.31252765246937353, 0.1301860094310776, 0.21306348483889334, 0.37775256220371495, 0.263408791394003, 0.1992089532676243, 0.20364898437213516, 0.2098201290373841, 0.4168790626910425, 0.09887929014380901, 0.10915029223167128, 0.07269118732262043, 0.15034754370008746, 0.1816438748351028, 0.19527487727182527, 0.24942984714383082, 0.17626328694243587, 0.28514825228241186, 0.38794484109647814, 0.2852835127663228, 0.18165939577644874, 0.20327654306686696, 0.10998746545444574, 0.12291034984011805, 0.157376722162289, 0.14113665408184453, 0.22301869016260872, 0.25994956733719, 0.19931061313517634, 0.1333960097643637, 0.10495465083588516, 0.14116270107127007, 0.15200888197268211, 0.20688080288950475, 0.1293383791081367, 0.14263820173519273, 0.062414677062582594, 0.1952098210852954, 0.1325623528851617, 0.15809983255401736, 0.17511349622040026, 0.1896662709693755, 0.20224761037576586, 0.2102972945619014, 0.2618450220794447, 0.09444064565844114, 0.20047399425698867, 0.12108239510487165, 0.14561457589509028, 0.13722249637207679, 0.06430760371468722, 0.11290947801523632, 0.08586190115179747, 0.20302367276482045, 0.13917799708583664, 0.2012532282500498, 0.23844367133513575, 0.15126482673710392, 0.10352359093244999, 0.2070115894199379, 0.17589533491240394, 0.11433741227994043, 0.14581521432245934, 0.2366368989309957, 0.07301043914330584, 0.16258634987377352, 0.09352019867829739, 0.10141351665820807, 0.10252890237156423, 0.10833615527277994, 0.16535906721988033, 0.16057838745895894, 0.1220476582285858, 0.15927956199213383, 0.13517842057251162, 0.10255523281352175, 0.09746584260175306, 0.18317231217459326, 0.09770874609990467, 0.23309617844079775, 0.19740041886125842, 0.1676200378325678, 0.19311193526992876, 0.16144258060282277, 0.0702392922774438, 0.10485966359415363, 0.20406674743900377, 0.14628271181737224, 0.10621553196782067, 0.11723715466477218, 0.19799559256963192, 0.09777657552472047, 0.1777435373514891], [0.05510481164580392, 0.025448172969082673, 0.02882445268633385, 0.05655731051980008, 0.007850904958397752, 0.020890895938200336, 0.04395537867000507, 0.027898767580007835, 0.02995779933107476, 0.019429045045868527, 0.128595978622475, 0.0030912150489917447, 0.030377263113135294, 0.023581274154205478, 0.03698525026500706, 0.035235064945393996, 0.08285087683508474, 0.10261810564946744, 0.027875106954466433, 0.05262518421776834, 0.024361044408813603, 0.06634414120907746, 0.006532982834840134, 0.024902310425175295, 0.024339879314685543, 0.0155396779413305, 0.06980975443917899, 0.035515395669086326, 0.03865639829347211, 0.05955787773634638, 0.028653639977076845, 0.045214394377844955, 0.008371396106667817, 0.002610286356948857, 0.04708608507268852, 0.05405771884045774, 0.15962655385655744, 0.057979939625628536, 0.041682859281859094, 0.008074288057433742, 0.02266651154645989, 0.04166066188425307, 0.05575448484911073, 0.030598587829679735, 0.02029960821082275, 0.047964293795127066, 0.12255752804659067, 0.055533311434931336, 0.0744607738189159, 0.048641465724475925, 0.041178229505256306, 0.028802632587030533, 0.0013546062438117882, 0.03526905626659432, 0.013977551885369807, 0.020568125858722676, 0.04476906363702109, 0.039028456554778164, 0.08705528227672463, 0.048756624061253764, 0.05614201425604763, 0.048143198308084285, 0.03636667640098641, 0.02296193611748036, 0.0329056826810683, 0.03202424106758929, 0.025520175657865983, 0.058577457563050335, 0.026893208231476527, 0.10525461256263718, 0.08821539986397951, 0.03723458507128301, 0.024516138909084183, 0.012428862053991086, 0.054128926713019616, 0.02116868708042368, 0.049411257683870294, 0.14388922331554277, 0.09380876101673612, 0.041453504048648386, 0.06771692480411261, 0.015367019917785883, 0.14652819703182868, 0.07661606260244885, 0.02311915651174082, 0.1162322464909765, 0.06887334984757247, 0.07541925706450017, 0.033835801521256086, 0.024600764811639825, 0.058115157974703666, 0.06224521841373175, 0.05232588898751044, 0.01663578505207214, 0.0036847751846747294, 0.020089931861166994, 0.05629133628380876, 0.025362947602726282, 0.04272498400701631, 0.03162647864120382, 0.04596574277046227, 0.07983944649177213, 0.07635023009272353, 0.050574657957880735, 0.03309918116898306, 0.023623928014609604, 0.007518603308727184, 0.0299978963730316, 0.11684006065010064, 0.08214556266583743, 0.016618975167793613, 0.021760072484011614, 0.018685127706116727, 0.06519146233556733, 0.059674568248972784, 0.01891334529875988, 0.0498209270318189, 0.01659957399111121, 0.004967915958860108, 0.0700820833745022, 0.015529261060780095, 0.04164286183133241, 0.017234107381814433, 0.08861392646306947, 0.015763458927282165, 0.0720785774530903, 0.007752383178505566, 0.031874191256300095, 0.027880155473887443, 0.1419348870554278, 0.03037683793433732, 0.016062592321466056, 0.05737651131987091, 0.03370998690145151, 0.038699705243831685, 0.047239593770955844, 0.075594583946851, 0.0764643925151998, 0.06414550334034909, 0.02724717724167051, 0.07008463444729006, 0.05608438146150401, 0.04193799720416146, 0.03460788791398368, 0.03240697859455982, 0.0028946239598876527, 0.01727979495039871, 0.07555206606705343, 0.0281596492465225, 0.024319884419861822, 0.035893019559162284, 0.048125620420661666, 0.03128988258991271, 0.027967759543248726, 0.04596160206523153, 0.029082032513894865, 0.09055755281400296, 0.057312734500174566, 0.028533653371156226, 0.05677300257488124, 0.010693883579674988, 0.04918358401365338, 0.04946589124419036, 0.027455543580975746, 0.016814549753983176, 0.0295289337349635, 0.04303352591852027, 0.031827961680509394, 0.03352495751553967, 0.039505794449078466, 0.10204639721421466, 0.058991459138210744, 0.05564404561394646, 0.014549686457030477, 0.024232699783639084, 0.02918109151294395, 0.023163815607286753, 0.04787999731037886, 0.02433571371159727, 0.024058089193497455, 0.05449768696581164, 0.01222009639135532, 0.04397804338124491, 0.06636369177290509, 0.02206800152517615, 0.04115948333374916, 0.08328553980156299, 0.019877924689001614, 0.04665008145234278, 0.045784723854834036, 0.016983079521225828, 0.020654460137349465, 0.05314598228001306, 0.147742691539949, 0.04350670012495211, 0.07741675471826907, 0.08383863230025576, 0.02336811976537349, 0.0749928601867249, 0.031006552631996816, 0.009872272475472382, 0.007583090674973304, 0.05035223582038476, 0.15662715109365602, 0.04128319504220159, 0.010573894100924654, 0.006615033724360289, 0.05838960514313752, 0.0187396559293472, 0.02529665226897886, 0.0179630400417673, 0.06214222555319148, 0.06193933482732504, 0.030229191723910552, 0.057429467147636803, 0.05643339196760809, 0.050787638061709946, 0.016905063042236913, 0.08578375252264162, 0.02932178547545787, 0.04688130210964911, 0.062634383418387, 0.06271886376423702, 0.07125409064634193, 0.01862047946140651, 0.06718751208315935, 0.04792764797926911, 0.03958976534645885, 0.03726928885425291, 0.04110040263302865, 0.014350053520062038, 0.028811572833106886, 0.07703120564861644, 0.049668188251915484, 0.03818700090050697, 0.0015715332565671436, 0.05115331481060675, 0.006947413419238142, 0.030723056049957394, 0.021417123648608406, 0.01190750474756163, 0.03566456064882298, 0.05556207803648807, 0.11729119450695093, 0.02499562376479228, 0.07251783694711424, 0.07607142771444014, 0.03837103820255688, 0.05506899320490419, 0.021911803858294603, 0.04601512862850101, 0.07428390709983726, 0.0836075495387758, 0.051544632522329215, 0.07466518905975165, 0.047851157930469325, 0.08745626035717227, 0.04786360302879926, 0.02936415205289039, 0.054910378530621536, 0.044492482913718115, 0.05594041821877322, 0.028559709936680815, 0.12170066636416221, 0.08062896138477711, 0.018509023244522752, 0.12632015356493573, 0.05369489959951851, 0.029255562920063257, 0.05447848497198955, 0.04227496480809585, 0.003690644854589576, 0.03841930557222616, 0.07141011977388013, 0.02665199970285739, 0.03579673379839909, 0.03790051466034305, 0.009116361071656068, 0.03241299238476542, 0.11168133182030533, 0.09258756323927834, 0.07168739763719421, 0.013197619794687677, 0.051120311742828745, 0.07680974495146545, 0.026099615835494576, 0.0467694073074287, 0.03734543799392639, 0.09297335745706674, 0.0045677475375874394, 0.06745395746322409, 0.09329145248498648, 0.055858358710763924, 0.033767160043240554, 0.07103273720150033, 0.03849178515074234, 0.02688048351105423, 0.07557674941997375, 0.041930504864262, 0.026027396726872654, 0.03476546070868931, 0.03721802608079968, 0.02118927952382834, 0.046853236478543094, 0.06310691794140205, 0.10550811871766083, 0.0372075421675559, 0.016340245567863027, 0.06805159797471377, 0.012060765424863467, 0.043712643711196805, 0.08926715431434494, 0.14513109780607686, 0.04082240847750537, 0.020227124801866954, 0.02127335767351812, 0.043589801512538426, 0.041705037527267015, 0.020676127019067927, 0.04247138975188137, 0.008528452749634463, 0.006129213321518394, 0.020779640819396705, 0.00570399861317128, 0.08182886191793988, 0.017696958553466587, 0.03449658682990459, 0.05614268075254175, 0.014341940648943908, 0.056525540853580164, 0.02848671133359594, 0.031443362559882865, 0.03143802484227044, 0.08155805749758598, 0.06384566035722533, 0.05770597509258698, 0.030148620341694167, 0.030460826068695997, 0.025215852975604996, 0.0387891230263537, 0.03562483515950941, 0.058936557447117184, 0.04908026173530568, 0.0427415200148619, 0.05476469925094036, 0.036567433571983735, 0.08508885714916453, 0.08877177887986745, 0.03552373836658174, 0.04667337435568052, 0.03174677934317339, 0.04260721331041667, 0.2711249515414238, 0.11663874806535822, 0.1280619234087006, 0.10712757496343506, 0.15761515936784207, 0.14114699626882232, 0.17987672449840655, 0.15147710970092207, 0.09858913434248778, 0.13518972803027401, 0.4727889561364728, 0.09961714006720052, 0.15231571550811493, 0.16091954173339953, 0.14729298260663787, 0.1341340588706155, 0.17752906337620752, 0.25838518515229225, 0.11010921980825164, 0.16721182022123568, 0.15667346876955804, 0.11865028811077918, 0.14814657309362966, 0.12722989829677728, 0.09062915905228547, 0.11867209863398345, 0.15029011774928341, 0.371693235731894, 0.08981992505610951, 0.13246861436674673, 0.08183004169334328, 0.21960725467051231, 0.09512670037727203, 0.085435971587656, 0.18781054554687393, 0.1888945906032478, 0.20580034312461654, 0.10906532541998934, 0.15501269740202736, 0.1065831469191659, 0.08517485817954426, 0.0962200380801674, 0.18610937070221673, 0.10787631099623059, 0.14324059199181297, 0.1243606462113319, 0.17373652978529855, 0.1692955334100031, 0.17312657057998643, 0.2147973103508834, 0.1754650539688526, 0.10589280210795904, 0.07445541120344594, 0.2234081999068299, 0.11578352581108771, 0.11808591113696176, 0.19196502503848847, 0.22793680609714603, 0.1369111582396492, 0.18882807884966174, 0.18849570394283344, 0.07632110342984239, 0.15708349434839142, 0.08121698749281707, 0.17889898180240588, 0.08521215133969823, 0.10770842282762451, 0.1973405107855797, 0.2458285750640977, 0.22922138232857953, 0.15526690069706212, 0.18821260381129482, 0.11758095194255153, 0.2975641473406746, 0.13830765991682006, 0.1277560398222939, 0.1620140975160945, 0.18471602530729386, 0.20662848417076374, 0.12234246418360742, 0.2638671571208585, 0.12781677527293084, 0.19472180775577025, 0.22946997786000853, 0.130835069764045, 0.32974498827130566, 0.17038097274639916, 0.2336679864674807, 0.16866274478454746, 0.11432218245200573, 0.22366868512284374, 0.12141587317831094, 0.13871845158357776, 0.11652605653169656, 0.26236369424769956, 0.09295143202067384, 0.20527106829948966, 0.1882697999357216, 0.1339765971586589, 0.13772275178663193, 0.18302128560120062, 0.29989146116760473, 0.23500986607565036, 0.268345860343787, 0.19166009140110787, 0.10504604512525183, 0.10630406874922976, 0.10044360338079353, 0.2694647470789571, 0.21263646742989942, 0.09967073557838317, 0.12276849333917904, 0.0912688501299389, 0.16799658536911014, 0.2346899784019878, 0.22646979368742437, 0.24158688412318308, 0.13357273092673672, 0.2355774299752328, 0.1393839521634002, 0.14463415189135462, 0.15669248307183867, 0.1133440184076467, 0.17467268922876927, 0.13100613719753681, 0.1815737165029972, 0.07797390748296054, 0.16173499636352062, 0.1437352089992454, 0.29536363638697133, 0.15435312634273884, 0.1079670158064654, 0.17480581998825076, 0.08613090526552931, 0.1785982922921258, 0.2880864752636802, 0.27113656543435594, 0.13690729715651082, 0.1278384785438257, 0.10055375150254658, 0.1303641555169898, 0.12544327400504582, 0.17676288352137615, 0.14245964196180144, 0.1668070040402874, 0.12196439213209576, 0.0708777959188146, 0.10888524879250797, 0.23979652132238113, 0.1188701936494439, 0.11089780007398899, 0.1747673317309349, 0.11236040747814602, 0.22051221901370635, 0.14264927936657784, 0.13100961523671306, 0.18864994808550806, 0.14604379963730613, 0.11852888615741847, 0.21336392920103767, 0.12066319945358461, 0.27654704607782826, 0.14796772220682713, 0.16368980759814863, 0.08435708996389182, 0.13135608616134814, 0.12231222669323608, 0.0897159745856639, 0.12713974506984796, 0.12157335021202603, 0.15088506163127963, 0.17343421616861898, 0.12796102196819362, 0.21317709567806414, 0.09406883254527085, 0.11163804785258348], [0.05151411924030512, 0.04341604511043237, 0.010178790957246338, 0.09448848018843321, 0.07144189710097928, 0.04788275522690627, 0.04547795543687479, 0.02875552967100615, 0.05103571265335045, 0.05719548091292382, 0.05482432387408711, 0.035393668128357786, 0.03144033842780177, 0.0081073725220537, 0.030814793163670168, 0.05728680625437729, 0.010529952255197832, 0.043280439886955485, 0.03523040713081437, 0.058689792865827206, 0.07014192250226775, 0.021880373185981187, 0.039498501292039315, 0.038760781603594946, 0.008419584952324869, 0.012355858662856684, 0.03790504607041517, 0.07683516374879307, 0.013580710679713278, 0.027033894533111204, 0.01940619647352686, 0.02868880915846075, 0.07776105761407845, 0.0336031750926087, 0.03485626511035427, 0.10018350886962107, 0.024751770317614562, 0.0510993094423846, 0.05713487186679437, 0.014905519933710176, 0.08065313145878815, 0.028636345542186213, 0.05190557484785396, 0.04742359659904915, 0.03983292165362547, 0.08338490140534217, 0.029189985793744846, 0.053091210823866634, 0.013443275463707266, 0.045930437608471805, 0.1288093341093871, 0.0741104188285047, 0.02739770394269257, 0.01775426384542258, 0.0699932401579234, 0.04670163150876761, 0.08132496758574441, 0.034551622586384896, 0.025258696442770383, 0.02803871077635596, 0.056447089619694225, 0.06587420755456533, 0.030242328216592153, 0.02309653585055663, 0.058072670738423066, 0.02556717132158097, 0.041634626386146394, 0.03495747298603097, 0.06877672317768298, 0.07930113949001798, 0.05495035682895011, 0.059019995913390196, 0.05230901207053854, 0.04033357926434086, 0.0396580352718311, 0.021979822889871655, 0.01779445090271052, 0.05399437869087823, 0.05309300346960945, 0.0360815882712843, 0.02526352088147354, 0.04242404934860045, 0.036615348541207855, 0.0916073230966445, 0.030096200775475274, 0.03685267874971032, 0.04092329842669349, 0.04351257984977096, 0.02138588832871568, 0.01538329545573722, 0.05847756352816379, 0.05812843044799182, 0.021434670892514048, 0.06354871701689498, 0.008158690836881439, 0.10759406122228793, 0.051514249475252245, 0.054898741655051715, 0.0912682602422372, 0.05251678660692227, 0.06085046341702823, 0.07274538804326328, 0.08190383128220997, 0.048123935027228254, 0.015493328664301625, 0.050167179621395566, 0.023195376514547297, 0.03292202716693282, 0.04529687140377299, 0.03348779842077244, 0.01802520616160285, 0.04259592883529202, 0.019742964894600937, 0.04475266169456225, 0.036395875842220364, 0.04678619612428931, 0.020735548628914743, 0.0433216056215667, 0.03411661871078034, 0.012016311257837281, 0.03644177600020363, 0.026082583785718007, 0.12384365177563122, 0.011046480334874605, 0.06936706287125427, 0.01692681993928648, 0.06285262654625601, 0.04237194004799089, 0.012105719464260244, 0.04231227712044793, 0.05317666793182012, 0.04725323779688728, 0.038628945532705516, 0.06246808105178418, 0.013974680013263659, 0.01951097240371089, 0.04316610509469625, 0.0892766155002098, 0.01403325605356405, 0.01776631632369132, 0.029076371124134432, 0.02911164947304755, 0.04621279080428424, 0.05027142886613166, 0.04073991996025847, 0.049551015103896784, 0.04133302906167604, 0.025215004533228856, 0.010371080941460546, 0.046438484137216886, 0.04113621341304914, 0.06038232240825892, 0.02695633579165705, 0.03604877672548737, 0.04329674223798417, 0.07233903202558718, 0.025612933583737865, 0.0242120498836401, 0.038108327501122995, 0.029154573379444982, 0.05282287703706853, 0.05227251947226544, 0.05240168189629913, 0.03852931196771322, 0.03719469870350534, 0.046146688907737696, 0.06020436018344857, 0.06056502671732057, 0.04745204910455693, 0.03335919141048386, 0.03410097902580615, 0.03249395255660338, 0.038394809910847295, 0.12059322498258084, 0.003549173552234988, 0.027074650410682927, 0.02464466739536053, 0.07684804168680022, 0.02146076001677542, 0.039127507892948006, 0.034637263555440216, 0.044862357824439966, 0.027911624450597073, 0.009598448711086907, 0.027774262970553774, 0.06476715687782535, 0.006055887215845888, 0.028347365685828754, 0.019651687433642727, 0.014783004280029526, 0.04214655315022796, 0.05055490055031354, 0.02692779518603798, 0.06047579279590038, 0.0290028611573601, 0.00874985407497133, 0.03186513992747472, 0.0507088459186977, 0.008559726373923403, 0.04344823229457102, 0.003584960392007845, 0.04857294299008866, 0.10892841018616192, 0.020629114118374644, 0.07018385049436363, 0.009044278901250613, 0.03215374057030967, 0.06331200350917156, 0.047622702850569645, 0.011871333906216728, 0.07560777598090711, 0.08266814954338536, 0.020114659264142958, 0.025899086575654727, 0.027116005752055396, 0.022728049474197532, 0.0433429028658617, 0.06222725365190737, 0.03709317673177969, 0.02866649493244627, 0.053263484845839204, 0.05478551769028268, 0.00314897759967754, 0.038226569341796066, 0.016613329099791668, 0.009084348172520199, 0.04167213788135879, 0.05184785012275942, 0.02217701775202107, 0.039608526839724476, 0.07087763504035051, 0.0545168468247979, 0.053390214940713304, 0.019156972749999935, 0.048145278236798705, 0.02462869446213928, 0.06241344749146412, 0.05565739469602705, 0.03797037038771856, 0.08598338737482987, 0.1272579984018399, 0.031284709581204, 0.06890711900327476, 0.01622902300779618, 0.10578245480334568, 0.08934013951089113, 0.049391496445863485, 0.05482951795021373, 0.051337474686724525, 0.025423045285166274, 0.011632277127054912, 0.05345288476335907, 0.04794652438572338, 0.022093473948658477, 0.07400774772489264, 0.045958633474524946, 0.04626606838897832, 0.06613909777614378, 0.024486282547455163, 0.04721819693523069, 0.06807762198150158, 0.08255881347483204, 0.09501047717827944, 0.04396215471769533, 0.051495920821663835, 0.021781877261556445, 0.040072485008427215, 0.05023080705394668, 0.03373182423773312, 0.053462169749001344, 0.05760225827895826, 0.09164725926013724, 0.14155218017197427, 0.043702765007413207, 0.010522991388795838, 0.04024219263585345, 0.014154981679072785, 0.12391747966889413, 0.06164261748293235, 0.05668042467967157, 0.012951380941235732, 0.11344573956223265, 0.013995742643131845, 0.011492478529802494, 0.025037454080677805, 0.020559737195951805, 0.06165604317380537, 0.00959935652527718, 0.023921298448957747, 0.019150166058792703, 0.0464864335803976, 0.012531394304166879, 0.04822593580390658, 0.08717810149274527, 0.03752207105618812, 0.00879746260902574, 0.14593343701093428, 0.05587666055127498, 0.09142908508018141, 0.011195872268158824, 0.05898007124121632, 0.08267302186258378, 0.044164758160590165, 0.049423089911860806, 0.01400205041957839, 0.05072707115041633, 0.13727141874692134, 0.055895238183438785, 0.042557900230730736, 0.0409536546606931, 0.049003024750779715, 0.0478741520595166, 0.021133983297453775, 0.025324355923540653, 0.046823822532690344, 0.021286396489989375, 0.07707088900309417, 0.05048723966484109, 0.06139790984771906, 0.1281267650906117, 0.005722772076560726, 0.08807617104462079, 0.042129385119844834, 0.06280207623457236, 0.08762568070162689, 0.01809676068895046, 0.019536412268456434, 0.041598309988095876, 0.04693735676306871, 0.028215092944822488, 0.0509712195414449, 0.053233553790637565, 0.01115139703371472, 0.04574947614943789, 0.03879756148483965, 0.0126304236173089, 0.016332645975654165, 0.09912378710484314, 0.07262980069724784, 0.050643314757654746, 0.019584591538014434, 0.012200438575218282, 0.02056729082288521, 0.05661010929954149, 0.010378905571997167, 0.023995689416845, 0.05894749718267591, 0.0792314867759424, 0.06037655376618909, 0.07545672642487673, 0.024710616074322213, 0.021657874439692786, 0.19734867728285252, 0.10061056458301122, 0.12098168518634574, 0.19801705835327027, 0.10682228126473005, 0.22237240306792722, 0.14434277801023376, 0.07390304648828122, 0.140273196382388, 0.13255970222094368, 0.1362679508184233, 0.10838173750427463, 0.1378762298413823, 0.09087012434798865, 0.17485180058546607, 0.13315461545942292, 0.09987702007375418, 0.14972385619917225, 0.1421296112840214, 0.07841023286023448, 0.1827158310240315, 0.13390945721297495, 0.1232898161716519, 0.20579756988633066, 0.13155145390379813, 0.13414424784000845, 0.2343045595672823, 0.1607102311907276, 0.11108962082934958, 0.0877141485351228, 0.14154228231599256, 0.1407361279932722, 0.17942134651445574, 0.16301185042867739, 0.15108810557473093, 0.544600322121574, 0.08375705925807839, 0.17680601427151313, 0.14520736951981822, 0.10819774616750018, 0.18204571859490487, 0.13319607613788498, 0.1310449165682639, 0.14199445805241986, 0.12803507968783379, 0.1177006072154449, 0.08034868045679985, 0.09501728769992629, 0.19410660850905603, 0.16331799448497836, 0.11987472644015668, 0.11115646966162229, 0.1267589304235674, 0.12851616758252346, 0.17323704045866767, 0.17846937501622787, 0.19964724749086366, 0.1383867508341228, 0.16158550196597654, 0.1660913093796661, 0.12922666816701814, 0.22542138704128806, 0.18217543260224406, 0.21588509391632774, 0.21156020582683627, 0.10396511038585056, 0.10195517912507059, 0.16239986875124518, 0.19411267592541634, 0.22991254685386536, 0.17820737294612393, 0.17089351621125975, 0.1629651190652963, 0.11491861254457506, 0.1499481360998846, 0.08980643424776294, 0.08054040928160952, 0.1563050877302885, 0.15503610904899337, 0.17943201045836174, 0.20724311651241398, 0.24487494881595337, 0.12879476311706728, 0.12922659155822572, 0.21893856716492485, 0.17719276609920687, 0.13520777706177006, 0.1771169233947031, 0.17209322522244147, 0.12934101445059623, 0.11385729731691462, 0.13078496761379704, 0.17802712777929922, 0.15813467423281363, 0.13403457469276844, 0.20113209442746258, 0.3052762319003382, 0.17106790846634298, 0.23651401842794112, 0.18399499867471958, 0.16999737720095343, 0.24197360530735987, 0.12870198986943693, 0.2741690172303108, 0.08443985044235185, 0.3235867751702186, 0.10019988782944218, 0.11234854843707816, 0.1855945902606172, 0.07199636089705652, 0.14022989709290767, 0.10389351946932655, 0.11131692677736284, 0.19335910587781863, 0.11061535111718601, 0.10992066258744848, 0.10168710963860636, 0.1595869930761476, 0.09509070190571009, 0.14467170552140282, 0.2295292271000724, 0.09719116943738154, 0.21644398570060733, 0.09773736714475578, 0.11658886041972907, 0.21318296391156413, 0.2806403764313267, 0.12833358584752969, 0.11692655963763116, 0.1504609093911225, 0.2968720328663626, 0.12667711223325423, 0.18829200116376724, 0.1779747733305539, 0.21299387809009324, 0.11994140673308604, 0.17543739819478604, 0.15680067000850556, 0.2037152816211024, 0.10235125424280282, 0.10042032196877465, 0.1030302532918511, 0.15610895389991422, 0.1729549668849476, 0.14940219120152537, 0.16377367890409886, 0.14072399316055162, 0.1386154587230375, 0.17814533514601572, 0.1620917022228241, 0.13618659228086472, 0.15652163014296563, 0.2253601153291041, 0.09050546649603114, 0.14899348329392173, 0.2398059288820913, 0.11204902338044298, 0.15864228409144188, 0.15210262049109707, 0.07148950946547332, 0.18562831345104402, 0.20344001090814992, 0.14386976468226603, 0.22743092759722666, 0.1027037006532473, 0.14679067407644567, 0.15437535821430146, 0.20119388707943503, 0.11219890848282846, 0.14883038317484243, 0.11027810389115927, 0.17180428750091986, 0.12231505355767666, 0.22675865480015356, 0.09827637128652104, 0.12437321771416934], [0.07310707347407457, 0.03567701723847178, 0.02492589635714408, 0.0007021317322787289, 0.04920206205438703, 0.024399046200297536, 0.06440529524679146, 0.03594751905409559, 0.022730552666490118, 0.06134795708461635, 0.025661254579561855, 0.03017947453284456, 0.014962708397257714, 0.0781551102596906, 0.07044705532250867, 0.06346926220782823, 0.03293949397160642, 0.008776426792234905, 0.056758400939044454, 0.03399871011835433, 0.04873176450811086, 0.01857710930879318, 0.032557189284313115, 0.025185393319735606, 0.08365759806286904, 0.011062573926943925, 0.017447114298720996, 0.014074778019060052, 0.042250603212103735, 0.06037656908794757, 0.04169795504440704, 0.02540550187170025, 0.052013436197153026, 0.009394684644986787, 0.06946968800959087, 0.01674635260696373, 0.013174219639040531, 0.015330711180614609, 0.021238494927303928, 0.0764472474674544, 0.03486044795042084, 0.0399200871376501, 0.09043847976793205, 0.06986550265742887, 0.10518433931734293, 0.051503558718268914, 0.04101278132668907, 0.03934649029566396, 0.08439346381853666, 0.03567283056796559, 0.03575696234381007, 0.04666099054438453, 0.021332721826770616, 0.08699776439536965, 0.022418963640267332, 0.07503888674921567, 0.0263903615245175, 0.0313430720744955, 0.03335136965277695, 0.04633616543404999, 0.026769033039829908, 0.07923555470282033, 0.05123191543163792, 0.029254124589985418, 0.044400579175881805, 0.013705057283532957, 0.0835164693454581, 0.04953208507128781, 0.016719003268066916, 0.022676865224756544, 0.07660118517495933, 0.02764866094014818, 0.026109061699600953, 0.054042301320981596, 0.05026073044826908, 0.08548652572977929, 0.013782149668963206, 0.023383288306274244, 0.046593643754961035, 0.029942506300886313, 0.05657666956164664, 0.05331667816086162, 0.03990600261116221, 0.05048524400579834, 0.06166337463524073, 0.06632664376088689, 0.09247865617996262, 0.051729799804067424, 0.04714218186094396, 0.04575201190046726, 0.05556660561612057, 0.06097711307267028, 0.04574807037809684, 0.07561705330567015, 0.026787246780229673, 0.06580762685306611, 0.002777452727088765, 0.050526585940632134, 0.060195431428691076, 0.011572627606050623, 0.02561525099970881, 0.0802969312175147, 0.053222211858918594, 0.02186890868019433, 0.020179711620233232, 0.029205954896526474, 0.0888368963534313, 0.05739927179210129, 0.0532283329014336, 0.05257103329284057, 0.06472289231756041, 0.07221990535336156, 0.05983406775480798, 0.058944746927027745, 0.1444631763884137, 0.057900963621514465, 0.019543017861583543, 0.034992130803725416, 0.016074284738410386, 0.019131509902616663, 0.029297326203255408, 0.01158717753095252, 0.019472585653045008, 0.08243449272647982, 0.03500772452342414, 0.024438296715098045, 0.034835657345191125, 0.016955818282440305, 0.09592105694595845, 0.04376554208236837, 0.014091880931969614, 0.042905903331214384, 0.03407967029019229, 0.03132824635794086, 0.031005210062909513, 0.0333421076497724, 0.06606507836089981, 0.02956788739069335, 0.014266365117603734, 0.023763658621558742, 0.04723545689616473, 0.07707587623548123, 0.07374434371388729, 0.0485711963096213, 0.06512505783429069, 0.05885915575368751, 0.03542112088912437, 0.03530949804811709, 0.021243974371182344, 0.03325735917314887, 0.05323009490365944, 0.02606775040828413, 0.07286982370480415, 0.030765974210695397, 0.013124249638959527, 0.045344851490470676, 0.04010959047703974, 0.009826851122441792, 0.022480340689540874, 0.07142264531144212, 0.06423938358503004, 0.033941422063376636, 0.02223221247174567, 0.07174506873613404, 0.07470157057527574, 0.04689949669785077, 0.03687162410407778, 0.009137989648978316, 0.03701994638709772, 0.07669804933210535, 0.07803356274962425, 0.025763054258160056, 0.046423694809838656, 0.061676061051266814, 0.050207858890174865, 0.0193846732332942, 0.018584473328965328, 0.06465277228985103, 0.057325049363557375, 0.0060011416151669, 0.019090472487732768, 0.037807438807982596, 0.005144557639610984, 0.02284781966027954, 0.011491073716071346, 0.08699135223944342, 0.0019186578696638707, 0.029350527179157062, 0.010566870032268907, 0.08489341279792209, 0.01960447535008913, 0.017995554728493575, 0.03024157553520655, 0.013360018943316274, 0.0556124291653114, 0.02533022415704064, 0.06507089541804406, 0.05813221492233777, 0.008176147107846074, 0.007111184344056153, 0.04868523998846931, 0.003319067313456007, 0.014930286598692258, 0.046720082736423904, 0.029044911723523855, 0.055445690128591754, 0.03299042732725221, 0.01774670447282974, 0.08618987105306118, 0.056828011518284205, 0.04268833053027911, 0.024894117114825115, 0.06202560398847826, 0.04676487589735658, 0.023227711170611363, 0.05603505689049921, 0.01313331533193348, 0.07205413924830575, 0.11662672048494702, 0.03852146339692897, 0.10688179863556739, 0.05358063758561208, 0.022387125026134234, 0.02883980125789681, 0.031460015396136916, 0.02605021848613697, 0.05019616455801072, 0.055007652544807044, 0.029314185883249008, 0.067920129626028, 0.02769422784988438, 0.040065410186446486, 0.09203255552077487, 0.0551816770776866, 0.032755985270224275, 0.08793329564674247, 0.01991645699637311, 0.04076145852224962, 0.09330401632694468, 0.016424614830964034, 0.02549746306613088, 0.016459454594540502, 0.015651885881989954, 0.04358477597575515, 0.07344596778913852, 0.029181371135036313, 0.08083475558387657, 0.05620036334280045, 0.03814864287813825, 0.1190133908042504, 0.05229564766669947, 0.013232462431093859, 0.052394836900695685, 0.06472591836486133, 0.03627508675919906, 0.03999800594042867, 0.07756219651069372, 0.021053465541392084, 0.04103661049157381, 0.02598993119693572, 0.029016641163898092, 0.06401099362260392, 0.0372554341541423, 0.021868169405347398, 0.07760968630111988, 0.05092937198858108, 0.06236230729207878, 0.025764640060163317, 0.03408125992263517, 0.03808357903072911, 0.02592720391769563, 0.08741159743118672, 0.024149918237761147, 0.03865539854873092, 0.09911376667479355, 0.011606370906285461, 0.057113398422276786, 0.04602640544274642, 0.03498580291747086, 0.050086568019563155, 0.017078595363625118, 0.022908773445974917, 0.05361336869217696, 0.06400027222210361, 0.04884673898378688, 0.02846073137686378, 0.023010372026492993, 0.07541156554174039, 0.09637232103775586, 0.050032512855625925, 0.11611580112648588, 0.006319015435198503, 0.02691602041464179, 0.04571632369451466, 0.035776041763564276, 0.04040439260162173, 0.042027625660862655, 0.04329141792691043, 0.09604055900126697, 0.03107547373210471, 0.03209493566124189, 0.022588395476040822, 0.03321014900481509, 0.023766839801664316, 0.011332713766023518, 0.043395877845825694, 0.012568227811566284, 0.04274674856494512, 0.038735822459021886, 0.04953863129260079, 0.027039990677768667, 0.05285450497702245, 0.027003331455372037, 0.05537856167422668, 0.033088176315950776, 0.08994672026845718, 0.04233114969646258, 0.06041207343279835, 0.12204033442802968, 0.054236025804834026, 0.04770516455473919, 0.006962017927904644, 0.02489570483204819, 0.020139827167675383, 0.04379471854096459, 0.042195322307487654, 0.024334974436750336, 0.06896786211479096, 0.03534389156547766, 0.009954296551915187, 0.005612159514003584, 0.014149771323577772, 0.09264687376637613, 0.05361770858026801, 0.02124579383000251, 0.058412526493831995, 0.027154354198325067, 0.014379158157915359, 0.041994952010892095, 0.03594991307885897, 0.006095911000644969, 0.029230473540543072, 0.019115199890708732, 0.03618818174506869, 0.013257110352447678, 0.0442430638377705, 0.012444583135807227, 0.03364085129672482, 0.01572050437736776, 0.04508874829738371, 0.00884416907454931, 0.03847983417912357, 0.1870436762129107, 0.14397736939211048, 0.12639929810839315, 0.08901552507473577, 0.1705902373237956, 0.1312074957475547, 0.23395721530241353, 0.20111052139151483, 0.1271272578366822, 0.22701049854438152, 0.08531767229038863, 0.11174287166326277, 0.10171654273665721, 0.23519513677925835, 0.1345177923118876, 0.29903062348884923, 0.1281123779593937, 0.10588095072777041, 0.18737084172185392, 0.13071096352031156, 0.2741552582911907, 0.16940508398317522, 0.13475503442027878, 0.16359173302208224, 0.10380145102258652, 0.13542009066910515, 0.09963194088589761, 0.09822431561206618, 0.18252176563105277, 0.14165813013190223, 0.09828185647605889, 0.1373726189617188, 0.2092318501203291, 0.13364776157804076, 0.14560928988841274, 0.05559901113531763, 0.1342965461193554, 0.11526039501111354, 0.12728728594318514, 0.15308718136962385, 0.0790830112753376, 0.13131902282757144, 0.15279318746780196, 0.2031633305934168, 0.21087849482653603, 0.12718197949711355, 0.08124873417639926, 0.08229677310033191, 0.21210045103103886, 0.1780184096987209, 0.1680187559536388, 0.14449737455335357, 0.09863701483775532, 0.1817734662683741, 0.09992048790257785, 0.11218274402762614, 0.2043181008869602, 0.19321750218589462, 0.11502457016538228, 0.28441924301366656, 0.14543989252659584, 0.1459400253670831, 0.15219559292158774, 0.11622158254707053, 0.16262652352452278, 0.17902273564569413, 0.11435978970820866, 0.16137286660171327, 0.14973329440239938, 0.10840661237917601, 0.24469326340383102, 0.10506801652692019, 0.0961392158041558, 0.17434359317825687, 0.18063627003181368, 0.11455023916618479, 0.15539001102649397, 0.1830572764118833, 0.09802209138269387, 0.0874028793506084, 0.15627174758382384, 0.15074449981893265, 0.16642549225399572, 0.16736799490547952, 0.2559766966489054, 0.16537639612872757, 0.22817786332340012, 0.1898551422862276, 0.1516686010384752, 0.11115356618838926, 0.22046208621994143, 0.1400250145384381, 0.11693942991475906, 0.21416726432019667, 0.0923133344059029, 0.15006851915630604, 0.08028514878523928, 0.25569427067474015, 0.2590181882823667, 0.11367630138392411, 0.18065677054466742, 0.19222281362500884, 0.1357676494385927, 0.15373466356146723, 0.08014457165113381, 0.13056434961336275, 0.14764674668831212, 0.2099713088283616, 0.08756486864219751, 0.19165341111440815, 0.1537828964571799, 0.21615432785643687, 0.16974703498905705, 0.10017110590612698, 0.20817316257424895, 0.1867786710781436, 0.12431681066030457, 0.0806102381959077, 0.09819878956242915, 0.10200055451282572, 0.10097311569317695, 0.13320891577149593, 0.1855864084415859, 0.2678521626418637, 0.18281929885908482, 0.16309066555432736, 0.11858846481528976, 0.120566442548748, 0.2920726145948133, 0.20978576233310087, 0.09701290843828071, 0.16052024138550605, 0.11357906950457443, 0.13525918156148928, 0.12908740870414243, 0.1464987639337778, 0.10918133411436312, 0.15209983193105267, 0.07302437428264849, 0.1011864788409683, 0.16819927691211625, 0.20829143122799937, 0.20171064402787917, 0.113632756946308, 0.17320042145588707, 0.12464539343190771, 0.10431934944203786, 0.23504728180987222, 0.10875418647042207, 0.16199984828070288, 0.1381995802324626, 0.11878983102618687, 0.0818089283101501, 0.12735565162954793, 0.17587791407300582, 0.11197881142218268, 0.15202317717334918, 0.09694996665442183, 0.10133063360568016, 0.23316717946962004, 0.10774136460836857, 0.13090584096649002, 0.19551098557008853, 0.21453578325529254, 0.1357935278886749, 0.24051978493169432, 0.20407681383432882, 0.16925194300711158, 0.18478710294490863, 0.13174420162554712, 0.14126569393181032, 0.12676180325328343, 0.15557240123950666, 0.1480357201709863, 0.10917192655465296, 0.13530309372130903], [0.023187619874313958, 0.01993310983262716, 0.05359265750514404, 0.04854548639888245, 0.06251380883998449, 0.009342216240662721, 0.019187972497855945, 0.011150064040726472, 0.02504610512856274, 0.015274597155380876, 0.024936184917967168, 0.03551183719067805, 0.01554691747221495, 0.03360271160941451, 0.10493213551179056, 0.04230279678238496, 0.01904778415337205, 0.06934941986635809, 0.0564860298688854, 0.035441502658349854, 0.04949508685498469, 0.009371056578182166, 0.08333659956171628, 0.01493513689286286, 0.010600372014807598, 0.033017136982732245, 0.008040774583576188, 0.02704019177584879, 0.008741628205884368, 0.030087775723528, 0.040506255482473684, 0.07827430587982939, 0.07390537539557104, 0.06217926207389082, 0.0351749308737776, 0.10307396626881055, 0.03200698302187507, 0.012222914637306766, 0.015458071382806427, 0.04536304607867234, 0.07275651930080307, 0.0958503700131851, 0.011532604300056495, 0.016668994963589697, 0.1173394963505768, 0.036067074735558806, 0.022524189647106875, 0.0572708065080787, 0.007700962399417956, 0.050370794300350456, 0.08161673983258587, 0.017439895835254463, 0.02755795996035299, 0.013040583261529045, 0.01717204276862885, 0.040619368364493695, 0.05876746269003038, 0.03775324957865862, 0.05611472237374514, 0.009391161598145, 0.029067760295865518, 0.023324898999905395, 0.07733328177803948, 0.04559196464176621, 0.04627092155597864, 0.08263343809953622, 0.07052834491215407, 0.03994469388177799, 0.01414312551083464, 0.033956445047571775, 0.07283518120886819, 0.03859243761267393, 0.03535491557070806, 0.05741409559343612, 0.028381650035660115, 0.019999194492195404, 0.01899083126186123, 0.0641318669752969, 0.0740206256628998, 0.1404064956812128, 0.048344809667117176, 0.08964894189228935, 0.035759877308361956, 0.06792170010627278, 0.037277179559873, 0.04905937051761055, 0.04068178154768483, 0.030207182017845974, 0.05844328492399185, 0.0555924381009273, 0.0326013580835875, 0.06479053022039515, 0.026152918318046198, 0.017185288428839658, 0.04872549024801101, 0.03812784742143366, 0.026775360926084464, 0.025813261745497588, 0.03855763806871349, 0.04274629657306979, 0.09971074835066834, 0.004406481241476873, 0.11851396276465348, 0.0928508063718196, 0.026057065396960226, 0.09488649350861389, 0.0210968874049403, 0.09588728779025617, 0.04835850731920331, 0.04242601819456585, 0.029150329252344467, 0.07981426518170104, 0.12424160380877795, 0.01696082658224529, 0.062429462559521205, 0.013212788335588432, 0.017121151547818896, 0.05069816282259361, 0.064984978657336, 0.08276119092178923, 0.03590021312477128, 0.0683435770652948, 0.029926728720085758, 0.01184903787479045, 0.048779870999316056, 0.049281129989052014, 0.04858910744529098, 0.02186970158119596, 0.024538780637686292, 0.03756356620860677, 0.014453254181951767, 0.013501637956998764, 0.02877190671560745, 0.12806263587047018, 0.040059074639312686, 0.08787089012443058, 0.025774080178610263, 0.058326598241805076, 0.016840139005873955, 0.03365900758053026, 0.043787130440074595, 0.025471259028680866, 0.09599781129509212, 0.03243007231503725, 0.05672230287605236, 0.07135444816442267, 0.0677422823144063, 0.027189100116130807, 0.040853392903602896, 0.027892707824526776, 0.015029168439908855, 0.05805150755951482, 0.04590431401025384, 0.01733092748890481, 0.08790696520478496, 0.022077299917357105, 0.03608398229604767, 0.049155135338585225, 0.055525229207330176, 0.009048620704561472, 0.01415709991218342, 0.06316694859114867, 0.03556675037309047, 0.02895695333849759, 0.038282470777630806, 0.02841942966164601, 0.061518599339310205, 0.02887115723663761, 0.0424740097725824, 0.026304142159079353, 0.025568952476004922, 0.056910090178491614, 0.015061911995402508, 0.05579657755011032, 0.01793629591233067, 0.04611140289794534, 0.010859145981920584, 0.05083190262197487, 0.018879677649707566, 0.05711784939311686, 0.022092633167161577, 0.03586147205844041, 0.05566413243932109, 0.016704803828390378, 0.039833534523964896, 0.020909898749162114, 0.030003278140699672, 0.020212143952507648, 0.024571483015954017, 0.05134233934504371, 0.07705641760220451, 0.025185031343191385, 0.03625185514289526, 0.05396767286583782, 0.06009235046803952, 0.07253596258740272, 0.0386702491631431, 0.03608026676961491, 0.04144992258760237, 0.00572100815911507, 0.019445688306023518, 0.019987117116069122, 0.034077199656636484, 0.038693764231978886, 0.03105405774418145, 0.03390027165052391, 0.043681092380035313, 0.057253810847478534, 0.05297110355909794, 0.0675453440917115, 0.027833479651880842, 0.019784996308566585, 0.010274955101551549, 0.015468350367530461, 0.007352092183165013, 0.016687103366899877, 0.025620646173915556, 0.04155425227157051, 0.028151421462215727, 0.017936724921568267, 0.019191136440983223, 0.06739749678320463, 0.009750756566532919, 0.027537296653815338, 0.07046023969568553, 0.02978934234218492, 0.0671885233192194, 0.019912959804998773, 0.06532060177696329, 0.04203303041116845, 0.027089596786085638, 0.03126590403788273, 0.07100411615664921, 0.029101759277945085, 0.019307083848323074, 0.03334232598483082, 0.057889460811331395, 0.045592240433418946, 0.022454004501923922, 0.09053751961478303, 0.08692692424501143, 0.09444485914202468, 0.05947324800335112, 0.060440985591060696, 0.06386436439389664, 0.02309020030342283, 0.029926347591343428, 0.04505570692520949, 0.01633047411638883, 0.07675811062536894, 0.03385401526165586, 0.049908253394307635, 0.039877404548948815, 0.019311889134828123, 0.01562363064412268, 0.11595916678948749, 0.017938737817589315, 0.004987267339827433, 0.05894082072641581, 0.0651019526224944, 0.02377460793321652, 0.012865536001270578, 0.08556805280668121, 0.03629513144973786, 0.06533753232008989, 0.052234437241549456, 0.054294807731264064, 0.019732007922063914, 0.03748717575123714, 0.03538369749402327, 0.03684483017892607, 0.049968050387237346, 0.03191995734889661, 0.033809302539955226, 0.022311182730200312, 0.018204208350770416, 0.050674452401337125, 0.08306333599912544, 0.03635021700193325, 0.13742592335949022, 0.10695938802053852, 0.05257212496813267, 0.028030944560023568, 0.022325864805269147, 0.05469442600564611, 0.05468710220508999, 0.09598736951668417, 0.026602192496460293, 0.06206051844562735, 0.013279613227613512, 0.042624944415424144, 0.03909177755215957, 0.04312595825702433, 0.0837471307585797, 0.03732384580578055, 0.084511288141291, 0.04882919940076048, 0.06133159344655372, 0.030682604692335573, 0.05526771258202292, 0.0627186454291786, 0.022047545062378052, 0.03924704825265273, 0.04838926191892355, 0.03408957963749286, 0.037031590923546784, 0.04756426183326591, 0.07608000023831284, 0.024613650410526225, 0.10138661931118659, 0.02805810429215912, 0.03247661981731653, 0.05300412960951367, 0.054465197176942905, 0.0363167044856856, 0.01980228116735816, 0.04440627120915921, 0.03360462299878559, 0.09678263006912124, 0.06054873968805037, 0.027077982893153548, 0.04282188646855854, 0.0789534887899795, 0.029071027660862576, 0.06261929148627866, 0.04612577853784446, 0.047802024881445596, 0.013059359118943254, 0.014323704883516317, 0.06590241491193734, 0.041337208071302985, 0.053905887874744596, 0.04194620583627013, 0.04042180961058025, 0.027364208663423217, 0.005568449409873856, 0.030608635072806673, 0.0465836156640322, 0.02494678757483921, 0.09841268131088826, 0.04442783275378808, 0.018400342181144703, 0.07393552861627072, 0.05192707893588851, 0.047506368568828033, 0.031230558656276237, 0.03956587872497978, 0.027457592866173195, 0.03583625627441272, 0.03759252816258419, 0.06507217478487762, 0.03654185006575238, 0.08636240171448839, 0.13883822176965976, 0.14117056113337317, 0.15745103269094424, 0.15033545483264232, 0.11100158200509126, 0.2052867577801789, 0.11602646761363554, 0.15136161428545752, 0.09508191487721859, 0.1355489773014861, 0.1814466071946006, 0.08745593093936482, 0.16927187661490134, 0.1809162445246212, 0.1606680657113752, 0.13688033086157617, 0.12402809510428099, 0.13904051494694528, 0.13425795060973014, 0.18094757752072427, 0.09230571949193556, 0.14182697591041366, 0.07521206092449927, 0.15612234511683065, 0.11697977976573092, 0.08902029780250403, 0.09607142468373622, 0.10744616794850557, 0.1206293536890899, 0.10218500550235472, 0.1840703510829518, 0.12992253647215907, 0.1577796078016681, 0.19575676189795618, 0.18889728723274124, 0.095775400648915, 0.08655891092794557, 0.2712633683075828, 0.23268249096168628, 0.11367935807474198, 0.23614134729629566, 0.10235371338503976, 0.14174128131520364, 0.1343487013852404, 0.10573671935426612, 0.1120661531064299, 0.12138634814970917, 0.16262152863125648, 0.17565250036216554, 0.30121857060059426, 0.09158029551467589, 0.1558856086264695, 0.12183080171985973, 0.09595259678580108, 0.29096338056748916, 0.18991540276235153, 0.12714661687852877, 0.24293548998332795, 0.12064344970689667, 0.1580257824952564, 0.13897280809619736, 0.1494347346165488, 0.1503556029450509, 0.11037855333979092, 0.19918092977135413, 0.13519639299521524, 0.10740454639157943, 0.10084084295217069, 0.18010166323473378, 0.17466807737946513, 0.13206894629664961, 0.1391308520349764, 0.17658921138894174, 0.20930631386656917, 0.2140312377483614, 0.10616672450616475, 0.1660025963980344, 0.18812952923678583, 0.17279871559191137, 0.17479314889398315, 0.19549063827481963, 0.09704270925853523, 0.18987801767164664, 0.12510207376532978, 0.10782493714002833, 0.15594654325996676, 0.153351052694263, 0.23208656648714698, 0.1360750498790895, 0.10615245228813541, 0.23578571396008616, 0.15820376004182524, 0.10940871667116882, 0.1497679981853693, 0.13881782850911542, 0.11768077319908528, 0.15651318785404006, 0.11233724097931579, 0.1404062045678016, 0.19652243613475756, 0.19230981056969013, 0.1761203655792821, 0.31644153438748857, 0.2562568703245732, 0.16384110996319404, 0.13991506559954536, 0.12388960939020881, 0.23366766471055248, 0.10154945896037164, 0.19953043440416937, 0.1024388027707896, 0.264932387057812, 0.1183629668347778, 0.18917111770039607, 0.1092111808998931, 0.16275165632607477, 0.16878443019044015, 0.13577236854020627, 0.17309906802350478, 0.1324439463355849, 0.1771235423943689, 0.14462145015357003, 0.10065559523120042, 0.16084714642455503, 0.15883949044491016, 0.1695251146391515, 0.11523485363971804, 0.08359236567611657, 0.11898257108705661, 0.1203917668411328, 0.1764737619387527, 0.07936698474710988, 0.19542144521349863, 0.14989765090567453, 0.10375367777962839, 0.14465131226085848, 0.1275071148730574, 0.1584959766196628, 0.12152026797975264, 0.16197562458053713, 0.10077417032012057, 0.15623350447464376, 0.12709447693440223, 0.14993785519994077, 0.15317702816138346, 0.1376238651573658, 0.23245424272552614, 0.11677144215472283, 0.17290679527626884, 0.08318274612388304, 0.1225818360164281, 0.1194119633686158, 0.21153662564052692, 0.221987214059599, 0.10962265438490337, 0.16904912889003756, 0.11897441225066302, 0.23358615295540905, 0.0997700512168869, 0.09703860302726108, 0.12207729817037621, 0.0973773288029817, 0.1573156189894484, 0.12744272518302166, 0.13006354261550213, 0.4095377033996967, 0.19737535246437599, 0.14871430553255544, 0.11338796887186267, 0.19347024991387324, 0.16880422590240357, 0.11069769790816693, 0.13657833900182478, 0.18725294079030716, 0.09864820738232906], [0.09543208600652796, 0.05470715838694765, 0.03394232987756691, 0.020579919782316974, 0.06374548286980679, 0.04198500818963494, 0.05986010325291465, 0.0630374146144717, 0.0741419893118643, 0.04456989226802703, 0.03309590997354638, 0.044869532237850854, 0.09601761466793476, 0.03371014777991561, 0.031021441550805207, 0.01802519467028399, 0.06840482579484101, 0.02311218894206949, 0.0483910966995022, 0.04199211365513263, 0.039773063373661814, 0.019851260998797034, 0.0351843269421689, 0.019275047966549476, 0.12362296482728374, 0.029861094137173028, 0.03526829783954928, 0.06052076598749526, 0.02663887278627484, 0.0533788308741585, 0.017648559033630357, 0.014949129488799843, 0.03473262234981503, 0.026351294870818817, 0.037397244689805854, 0.02019453733678787, 0.0744246757559238, 0.02868873063444851, 0.023844957787303195, 0.017405575096246698, 0.015178189778159705, 0.005378856055153113, 0.03459486441927091, 0.08804495296170635, 0.02674380193404373, 0.06172263919706307, 0.07705464027822018, 0.017631107550715248, 0.05466736778016052, 0.04099256809680693, 0.03740790480327222, 0.03964638307450279, 0.06066289828008702, 0.007299706133292809, 0.038299508573066805, 0.07912310065641519, 0.042660973530503056, 0.05320865976353807, 0.017582945518135544, 0.07920389994978905, 0.021697686113897833, 0.013995116366253746, 0.021439627481384144, 0.04702636085811162, 0.04285494699293087, 0.04989772734622802, 0.02371620713552881, 0.04026853839956945, 0.035947764202231364, 0.01295430835471639, 0.015281892227639836, 0.026981103414249037, 0.0439419070138566, 0.02328697764765351, 0.03221865120013395, 0.010046531622778746, 0.011123814038001003, 0.08513191895138833, 0.053964125878748395, 0.055072946218593474, 0.0591251070070411, 0.06447313999336574, 0.017889840340602304, 0.0515687374788667, 0.030309297707712943, 0.01664707527285622, 0.005706855642323893, 0.029134318014727007, 0.07212896305587023, 0.011730043352731775, 0.0194986249815913, 0.010120129689664371, 0.035158069278564186, 0.01304640074170405, 0.026667348274420348, 0.03208426405645667, 0.010364630481138105, 0.04654222010304371, 0.028877349142285607, 0.01836670134516974, 0.02417405000737598, 0.0874280606606795, 0.08970588520770112, 0.01953101709424969, 0.029159171822210474, 0.101783046829364, 0.025946403996297912, 0.07405598828148457, 0.017434031432194096, 0.041898076362427206, 0.025926031803171483, 0.06094657680800846, 0.03844632932375516, 0.052664534323999, 0.01769267612196986, 0.025172408129419052, 0.04523894366537852, 0.048573904430433634, 0.026277871088935967, 0.07233575316927127, 0.047276523039345784, 0.056164778558717626, 0.02282001449906778, 0.07584252064266513, 0.03265325671001788, 0.03575640309962534, 0.021652546298179417, 0.07654107025554104, 0.004385079138897239, 0.021259933897864916, 0.02189944877529577, 0.026471411711686564, 0.035534095875318014, 0.058861266325918905, 0.04029638186517743, 0.035904606639017025, 0.032258863155279434, 0.0392412796105829, 0.07565229335018704, 0.0485519751636011, 0.020363515265466228, 0.045706460312489545, 0.028950386049766696, 0.0655215543003813, 0.03371258010907519, 0.006147934116363045, 0.0377511351759876, 0.05105543941740067, 0.03774135989407378, 0.005887028988405702, 0.04743616810188659, 0.04992993368256477, 0.05195584553744524, 0.007149737240040616, 0.05462276231076929, 0.05660448621417727, 0.07511074579651318, 0.014147856103767072, 0.010690036860685195, 0.018221445329066728, 0.09765923383735842, 0.07442554909615748, 0.008155791194088036, 0.021765117172993, 0.036938687440969294, 0.00806837768909792, 0.07260607495423287, 0.007897736392013969, 0.01754979689365193, 0.03504653453766819, 0.03867827393414994, 0.04898508680203269, 0.03819642378197562, 0.016892878413801233, 0.05407376072159218, 0.08397520279451724, 0.015000529200469535, 0.017312566276579615, 0.03029055919708504, 0.010464309053795954, 0.017947130310799808, 0.07432899137418117, 0.02325159396165081, 0.03823319983278071, 0.056353550284139575, 0.014410765030451361, 0.048699994841890956, 0.023937326923553503, 0.029075934454017592, 0.019340851088805545, 0.01636906579557446, 0.07957063390002136, 0.044969257733394066, 0.06201407819565746, 0.017098138266573512, 0.010123704447441045, 0.08486473812691628, 0.07188072758576564, 0.03774885223397324, 0.10348281973311979, 0.03493728656922618, 0.0571618841270045, 0.048341442710689964, 0.028539628856965614, 0.033737635014638785, 0.09215817861859837, 0.05613971599227479, 0.011949916332659703, 0.026998388273040616, 0.054580841979552666, 0.030944081992211363, 0.03275178327795959, 0.06362781942551655, 0.07235358003526926, 0.02099093361457269, 0.03446694688811418, 0.017567778892454602, 0.04655025253492979, 0.00401665500718199, 0.052917094360436165, 0.030366698760659467, 0.08590472546676475, 0.007614121066346284, 0.01685171267919002, 0.07405704548282009, 0.03514393112592159, 0.07427090658776223, 0.06765585993566821, 0.010930721576686108, 0.014734743613629572, 0.016555581392059406, 0.028751796907595092, 0.01922079170453212, 0.013650938917341973, 0.03142184123487002, 0.038212461832670436, 0.017120557829677578, 0.052952127561213515, 0.015608449654293158, 0.02546163121869247, 0.05054263548264581, 0.09051784647688751, 0.009070513582217598, 0.02655244849231695, 0.07097801554106897, 0.022416351280445536, 0.03665431177303676, 0.025477073636026155, 0.055887462391007336, 0.06250995541772535, 0.020743671076131925, 0.015823207082106702, 0.0590474333523983, 0.03145630944580321, 0.03998196405929424, 0.05878476861623987, 0.07758818221308532, 0.01359070333907561, 0.0065640553610489495, 0.043889395517086795, 0.045124137729045846, 0.05666645889681193, 0.03611472540444905, 0.08604429902568941, 0.03894269684209459, 0.051329315850330945, 0.038151814482144775, 0.04118545754482189, 0.007339572870067411, 0.04960233916438395, 0.015491604008862089, 0.040594554776626254, 0.01719933273571153, 0.04418964835725004, 0.03486355826739342, 0.06433538972370087, 0.020087355890521602, 0.10810505718954148, 0.0310807156887266, 0.0780999519291424, 0.01150453866895048, 0.06748348249182587, 0.02195986821466396, 0.03395985413883482, 0.0736168283788908, 0.07897268695336196, 0.015781294411769318, 0.04582790823112573, 0.06115997442975641, 0.05104437710777406, 0.02171685363376333, 0.03790165613135023, 0.07441751283383177, 0.050896261668493675, 0.03132833254283234, 0.03985163718161564, 0.05396065167001179, 0.07554632806850058, 0.040203152795232115, 0.043317124007209655, 0.035798629866011684, 0.02504706273846809, 0.09117232305147956, 0.05060513293550861, 0.009783779744118934, 0.03750068954222145, 0.04369454488398568, 0.030646094857084177, 0.038549785667489615, 0.06217489537272242, 0.06144389427537399, 0.06768409793655719, 0.029537985063788873, 0.029920339546797257, 0.07772766384145907, 0.059033762513389515, 0.03960078552124962, 0.023565040751089974, 0.07945014359129053, 0.06371794200892891, 0.04310989339325217, 0.057302108860664794, 0.017584470033104864, 0.020645759293749448, 0.0725678165232943, 0.036046999401503035, 0.026140452152298346, 0.06958617167847772, 0.02443268129061307, 0.029924706247965657, 0.04165728726694661, 0.0509525882831264, 0.012134577038757985, 0.04719058712643962, 0.027183162934717633, 0.0723541929056087, 0.032793810861485626, 0.03146011881800669, 0.03012200836242447, 0.019225987695878553, 0.031206026605720964, 0.029972849128347252, 0.02474635790642952, 0.019865341694845308, 0.08557782808859503, 0.04669121654343702, 0.04185145991223474, 0.04162434548620255, 0.02889751257645267, 0.011271621126891866, 0.0834952793534725, 0.05352156837621043, 0.14438451448034856, 0.19852646085764133, 0.1504734885548392, 0.11252089523740354, 0.09558807682966995, 0.1877523688299041, 0.13182733748709002, 0.18787420745338165, 0.18319402310636737, 0.20555485791016012, 0.11425638316018928, 0.10854666091261372, 0.1986650001978682, 0.14326158280093826, 0.127336660309905, 0.17711721450811435, 0.15837723299139933, 0.10276127216075698, 0.16155577775451446, 0.10213819753018119, 0.16161012403186292, 0.13764078037873392, 0.10305669098611801, 0.21932150387475569, 0.2579221922543741, 0.19199315578706805, 0.18362909976032474, 0.25157743674372474, 0.10711817506460414, 0.16925730562258154, 0.1751047321745465, 0.1384658417514255, 0.1530137595029608, 0.14095809430845324, 0.2173723310472504, 0.11002995269072634, 0.13943906452867294, 0.1307960912104576, 0.16950533424894657, 0.16360673302363965, 0.18037993701234942, 0.11806348774341807, 0.13550134195435432, 0.19495849828085593, 0.15090399932476783, 0.20762954658317953, 0.1282953427383496, 0.14459669019185728, 0.1608085202714128, 0.13828415633930316, 0.17243010472626458, 0.13472325709317962, 0.11026355588147718, 0.11360945255165139, 0.10273193865413628, 0.2158196546858357, 0.13828812467475093, 0.11203647486024326, 0.09513691999018194, 0.11603695535731894, 0.16882530864207976, 0.1260498087973364, 0.14741152705204102, 0.11609147017401074, 0.15738095096763105, 0.2202559013160006, 0.11687134768092826, 0.08606533580009015, 0.10855598420265222, 0.0945193688535402, 0.13369898221665813, 0.11306286413943577, 0.20382820298114132, 0.162074787001456, 0.09036046137372333, 0.15434269222521013, 0.13529466675414195, 0.2197190728639403, 0.1008866626709219, 0.2581837040282065, 0.19730543928040614, 0.14547433583967148, 0.1784461319086052, 0.08690218726593642, 0.1894878184482936, 0.11627650339036219, 0.11964911354645608, 0.28064619869955126, 0.14474039296469382, 0.1759464942639874, 0.11956200934946538, 0.1649999711662531, 0.07946623909857967, 0.13605412035699815, 0.12922577950502598, 0.19458668516768565, 0.14017752732240385, 0.3005010220071962, 0.1539438821735882, 0.14108449881595952, 0.16673732068269484, 0.23413338488148105, 0.21001416378684584, 0.24101018845554323, 0.1626798738875697, 0.21958555906049668, 0.18663686820335929, 0.19660186413074696, 0.20215990863019423, 0.15207562355264542, 0.056692486734039364, 0.12946256196066258, 0.18764245053452833, 0.24961835073847927, 0.2125768811111489, 0.10599131335414226, 0.19263381979638533, 0.16507273419730126, 0.12374751540201327, 0.1229433988731715, 0.11465192201637453, 0.14968501554141123, 0.09863765069073248, 0.1546939895037682, 0.1424456531963041, 0.10655412750859415, 0.21544160561696177, 0.17879710743023505, 0.08693942679993569, 0.15115510762458848, 0.2530313337281827, 0.08863829571994082, 0.12847649188892496, 0.16693440446209523, 0.1687943127246634, 0.19029607185192648, 0.13226264396742468, 0.1386748458589277, 0.2174979694668324, 0.18153018738713958, 0.1849511070477386, 0.1092140460687299, 0.13188772053728182, 0.2625755328805216, 0.2418856277701355, 0.16575930219504142, 0.12670643807899568, 0.09527616413129915, 0.16010843848268833, 0.1100789133699671, 0.14366877385445181, 0.22036323023419227, 0.20882622188618108, 0.10664144621020365, 0.10830780235870231, 0.12493320500418065, 0.1377782625176253, 0.19913254365805658, 0.11439380401204671, 0.1733794868473084, 0.11581157228999561, 0.12440834284549761, 0.1147095088456427, 0.13511759319132374, 0.17230556947329354, 0.11498935310350311, 0.1181242002114173, 0.07516207368743998, 0.20767402564806325, 0.1137607395949383, 0.16524340326507247, 0.12814778654325393, 0.1114830069784676, 0.09555192514052314, 0.20015594519434438, 0.13281379826366901], [0.032235267647211595, 0.025298954363191323, 0.037120736744855685, 0.011737010922403106, 0.019677144535366568, 0.06059673126606692, 0.11459051240836421, 0.07811505918300922, 0.015657331809521686, 0.025054499536993045, 0.029913737784109773, 0.05357292308021457, 0.04762300545529974, 0.030309000848642284, 0.06678969794583899, 0.021021058106975212, 0.01277899966695376, 0.04670928472713117, 0.014427786546518967, 0.05383472596745818, 0.046866386377763365, 0.08657026435098342, 0.07406525794536838, 0.019495066503183018, 0.014240017438667917, 0.06346961843871302, 0.11980726473754454, 0.043055282815569834, 0.03431888124454887, 0.01644686010906533, 0.022295205966539444, 0.052197124929197376, 0.03777650800803977, 0.07703124395301265, 0.03417091519241372, 0.02222653576022675, 0.05140588633836277, 0.03347253028844153, 0.023211671204696742, 0.022829895118071188, 0.05610245347563779, 0.04507524599771827, 0.0489880055970242, 0.03338941357909672, 0.05140918817731643, 0.07154295941995037, 0.027677410304726615, 0.07509078920608567, 0.023047760947637504, 0.050413668411032814, 0.02001851906008538, 0.039027223153220075, 0.01806149574657602, 0.06183810779945024, 0.03324892071466292, 0.01087910640278771, 0.01814742399860294, 0.009858569077726816, 0.04061227439031486, 0.03795826619851493, 0.030465916722952843, 0.010886400517436766, 0.033170320093631744, 0.023524639189183235, 0.044861672175747734, 0.06654644970812144, 0.017227459653851487, 0.021712940839690067, 0.027194974095290227, 0.05921404981505006, 0.012891317732752332, 0.07727181088299521, 0.07239999730260142, 0.03811906039294216, 0.04123908369952152, 0.044890182137849836, 0.024770815263412176, 0.05647861030733874, 0.07320386102242817, 0.026067769560482235, 0.030028578194399035, 0.07345177473560457, 0.019140804464357997, 0.02599108224404195, 0.034075203997593735, 0.001967276801869664, 0.024669779757518443, 0.025696002412587408, 0.014089176641596902, 0.09003186328036171, 0.04346736917091955, 0.10462424477502223, 0.047642571340885856, 0.10361080238175008, 0.04321146899113252, 0.011880970334694272, 0.06491944749629305, 0.04067736122036173, 0.05353115979702242, 0.028381563850768635, 0.06507965946389783, 0.06390614299884727, 0.030048919744008494, 0.03895432222634554, 0.022098878698964274, 0.051940991092593446, 0.01427340546562787, 0.02645774278789759, 0.06174474466411818, 0.04338018836513643, 0.02484233914724281, 0.030312551666171323, 0.008848509920250264, 0.008912347069370651, 0.040317889783651605, 0.08122233478652854, 0.04127583676768888, 0.04280610888775799, 0.08369915833276126, 0.07207190482726983, 0.01731418463731966, 0.027431806346641916, 0.023360757660421155, 0.05991925673198797, 0.01701231343641637, 0.05182544205097422, 0.03440690857748832, 0.03047241506377055, 0.09754632779907796, 0.012590510436453888, 0.031416731428415064, 0.08022392303833077, 0.027332184272968484, 0.024286869860764955, 0.050919585215348395, 0.019912908094063885, 0.024641838615700126, 0.03867857653888003, 0.030504759295933673, 0.038453844646292354, 0.05494319390685809, 0.02634774979894921, 0.11899603891276544, 0.047613394882289634, 0.03409936641072554, 0.04205720431561913, 0.09610119486047376, 0.03087583887991646, 0.009821661834364698, 0.033536981265511245, 0.06164204291698914, 0.059523453575468836, 0.05956558075042502, 0.03344003666913317, 0.03080304903579095, 0.03199035125303894, 0.06351751808617866, 0.02213030745605788, 0.11326404648923105, 0.04299498786548934, 0.0504626329207132, 0.009532651334490267, 0.07479243626397464, 0.013491692220521791, 0.035392254696137486, 0.032207378216328165, 0.054354987768155914, 0.02024375657070308, 0.03377495881830973, 0.016397849634109486, 0.0435404003327412, 0.05150842337658809, 0.05102422899536548, 0.0483693857677281, 0.03390714345920471, 0.056083538764787305, 0.08243551928429835, 0.018069206421533902, 0.020691037005294236, 0.006962098367136693, 0.019210591243820328, 0.06380315779918624, 0.05584294119128778, 0.015005866918081959, 0.007962219927820468, 0.025802929134618853, 0.009108043272018192, 0.03147639435595803, 0.06220255114678895, 0.014883594497317269, 0.0886367712049715, 0.022096693433160265, 0.05755624320778636, 0.06747379147958371, 0.02315436016708132, 0.039556183882298014, 0.03535195464088071, 0.07390180542584389, 0.019749850109820406, 0.015531475054881266, 0.05305394064635039, 0.07836177779902374, 0.06781225678541007, 0.019094670649557825, 0.024885150055671414, 0.035240810604826096, 0.04911081332172598, 0.017298468343553045, 0.041739335283637054, 0.04999628072724708, 0.06567791284572694, 0.0525360307355802, 0.024711927999892545, 0.0657608418635303, 0.0362636758795669, 0.0682852164872231, 0.1263798318142372, 0.0269978845702304, 0.0713654415261361, 0.05323380659965258, 0.04158107300979957, 0.08855839274943837, 0.03160724791908457, 0.04479811369110981, 0.029422681170305418, 0.045830524421387145, 0.06269034614125568, 0.04486737186990438, 0.005941101868126181, 0.016936231329436266, 0.013929151407923671, 0.02776032783121111, 0.05576964189869262, 0.0358905527560461, 0.029826399930302176, 0.017285559762028918, 0.0487975791216858, 0.03786458896713392, 0.03790195107520108, 0.015388366000186053, 0.08119088687723683, 0.027032505998748447, 0.03996378096241144, 0.041407262981538816, 0.048334674323878946, 0.03575582853368214, 0.039983212782610814, 0.1272768824691734, 0.05542714697038455, 0.03995813489440949, 0.012571839916129268, 0.007326245813014647, 0.01598316528308656, 0.025488861813961018, 0.0890951752362232, 0.03729228681373981, 0.0300551135648763, 0.040316694686489726, 0.03588859157095994, 0.04768631879180189, 0.029170251368815382, 0.06260838622467653, 0.014589907988275011, 0.0066440392495884055, 0.07179854933412806, 0.01115123424003081, 0.048567067095709425, 0.07410671862383043, 0.02804346435192612, 0.045790952149658434, 0.05630268587640697, 0.0634205964724383, 0.01568154784880819, 0.004861657648542596, 0.0610703612948137, 0.02089557290497807, 0.09459005578631356, 0.016079386883986094, 0.049775310326367624, 0.02631544195596249, 0.06091756122787634, 0.027238227419495106, 0.05898940602257367, 0.047103869803850694, 0.015710609394215768, 0.03069463993362602, 0.03376052572181629, 0.028236960924621073, 0.005347840985538619, 0.01803246675990522, 0.03070537857110462, 0.03869889702107157, 0.07902250565107792, 0.05864145654824473, 0.038602967491193164, 0.03955965809103462, 0.0643343018788484, 0.04460867163875411, 0.012331276816586334, 0.05968736574774789, 0.03972823956921216, 0.04944480467407454, 0.036417402912892645, 0.01307885031095676, 0.06764189415280858, 0.04401365114796547, 0.06888749183065469, 0.046264758378627806, 0.04189775460549901, 0.02710822421396452, 0.03448192773747348, 0.0059982726158904695, 0.02697403433792774, 0.05708715991087018, 0.07158940733079949, 0.022219464768685644, 0.01617604419739256, 0.009815574308196384, 0.0822521867831388, 0.006618532352149487, 0.04838296850662559, 0.07166681285466879, 0.0717279160275094, 0.01738853347037108, 0.07370135852045591, 0.03170278482890177, 0.037152697933056665, 0.001983444249602936, 0.052666395917655005, 0.015125643807433307, 0.03635532297794858, 0.0351285595717209, 0.04746283562253079, 0.08368880848490423, 0.06675929191612429, 0.020522625981679848, 0.0311639741243374, 0.026992761357236775, 0.03328078997231299, 0.0436475875246669, 0.03570618986662838, 0.05677654573153104, 0.01974988266855719, 0.01098155534090174, 0.025525229922946424, 0.02786996650449451, 0.04358329742606129, 0.03948977172014214, 0.02484299032197845, 0.030023857177565658, 0.03451513764899104, 0.009325239732260666, 0.1752468721280175, 0.12159263264508018, 0.10209271489011665, 0.11354603579327946, 0.08682276693082626, 0.2595561045792795, 0.261126033240749, 0.10558766928771812, 0.10005813091993333, 0.1008830467359193, 0.14392124579077767, 0.12090404217521991, 0.16202375022394044, 0.11323683504616061, 0.22792609618796458, 0.1308246203247578, 0.22431219897923932, 0.1232199106485613, 0.10293653009519463, 0.1348777617057485, 0.20792213088322073, 0.2868024199720352, 0.16102653357290453, 0.07507336070580829, 0.0945885082887065, 0.16564069646260432, 0.1970434525320607, 0.09569142209065538, 0.20080446926576478, 0.1305582515534855, 0.11485613807434998, 0.0577844952743861, 0.20382117029399643, 0.238585566140471, 0.1451100916751931, 0.2863899582336026, 0.16877848534814774, 0.12532384855852974, 0.1139827365536363, 0.1183073258688373, 0.2496828246981867, 0.12619620053878716, 0.10244393555988228, 0.1515984273846111, 0.14696967818083304, 0.208729955277616, 0.10863162006341642, 0.1900158215674662, 0.13859098987473598, 0.18623294068440316, 0.1116205120999967, 0.13708380381426505, 0.06803230021990116, 0.13289639786366494, 0.17452901709944973, 0.17057819442162592, 0.14734446371514953, 0.10105733939957234, 0.1717348186479461, 0.1513969922258008, 0.18903593382527753, 0.11476964674769871, 0.1272303656104111, 0.17407195372206552, 0.18171323643576714, 0.12507718356866993, 0.15099782977373372, 0.2044940866049259, 0.11145578021363867, 0.09746607242813034, 0.10753884926558503, 0.24489877415039848, 0.18612256273627284, 0.11990510948723364, 0.18656563734815967, 0.14681837581578763, 0.09698810251129251, 0.19900701249078398, 0.22228719876898875, 0.08015275347016512, 0.14702204795133683, 0.1904128696168623, 0.18226325692188355, 0.12300076353694163, 0.12815501841325916, 0.19094527008072024, 0.12421716560399342, 0.07938639741511115, 0.13981274689637846, 0.12786874667771403, 0.20186629777233447, 0.21546184565992127, 0.10234223738793405, 0.23252604048578973, 0.1327575827317853, 0.19354983112744747, 0.11037512126589015, 0.12231211178004743, 0.13982520348602726, 0.15817671713809814, 0.21955313821954114, 0.23220573912464806, 0.22988852233655993, 0.20542473021534183, 0.1941184675501239, 0.13457308853826216, 0.2065972124616946, 0.07004701186932864, 0.16333429683600703, 0.09724734666486902, 0.07679453044528924, 0.07364730335651867, 0.16573173835152583, 0.09127601305203092, 0.10445646385872558, 0.14816917268739593, 0.12638813620733638, 0.09744118223147047, 0.19101136814682715, 0.14961260491080824, 0.11433793321972895, 0.08341321601502358, 0.1540818852522681, 0.16399492509663105, 0.08220586144635755, 0.15732632889862985, 0.14458610285674373, 0.12177411121346297, 0.2110304560271963, 0.0994979061426655, 0.14878703792008663, 0.1953825892339791, 0.18119390543189742, 0.11827983097323488, 0.19440133785528524, 0.08520331834593127, 0.1569118906533526, 0.19619416745920337, 0.19088746108595403, 0.123166989294752, 0.19237802303846807, 0.04531634918924782, 0.2596708645503367, 0.0969336030163592, 0.1785103300766599, 0.16537160041832155, 0.1315154018060815, 0.07452906289648625, 0.0989599132369603, 0.22484666788049285, 0.16497697320676621, 0.11274018024484958, 0.0978901250768573, 0.08358468181423603, 0.20182215578613744, 0.07556001039882822, 0.16489143182914104, 0.14768973954262274, 0.17660283243223546, 0.11908171052533774, 0.12991853749319432, 0.06858668740718596, 0.12927304712995408, 0.21419698853165875, 0.14328458076042516, 0.10512291438757412, 0.17199067669289728, 0.1466477527132919, 0.11687762194102812, 0.04755183205669446, 0.1621060740322836, 0.20169755924613247, 0.11616516783232651, 0.1561040969024743, 0.11910623299979395, 0.13584372196947375], [0.015272826534665883, 0.07168195075205258, 0.015674264267868093, 0.03423060110259441, 0.13893833413960474, 0.034021738721358205, 0.05058025039972798, 0.06449641374450538, 0.02176334176422848, 0.03348060868560307, 0.02300115407354409, 0.0053122404008923525, 0.04781882518962507, 0.00864656148253069, 0.07573319223499106, 0.010851961034800737, 0.06602938632450758, 0.02174634993406794, 0.040604238127989155, 0.01974363330631487, 0.037270767403946775, 0.014963058882483072, 0.03293418115185153, 0.014496237460163333, 0.019220667215244427, 0.015744599757806187, 0.04434279316375333, 0.061953243153590354, 0.049823248278229475, 0.022124523492229563, 0.034718828936738354, 0.02288031711002752, 0.07405490809751135, 0.034417446116886796, 0.02878465250344767, 0.0564813222585907, 0.039067573004191926, 0.043976465240120895, 0.07390251022673423, 0.030207890649175936, 0.024112165424852602, 0.07163576331109771, 0.07149900129485516, 0.03278482465013381, 0.012947163627212568, 0.04177969279548815, 0.03303723146898612, 0.08454105831802854, 0.04637542744016936, 0.019491986829727408, 0.051019498402433056, 0.06926659043998488, 0.06179667010362591, 0.045429170957856604, 0.03810690257758383, 0.042722321851479436, 0.0343325597444369, 0.03673741316062309, 0.032946438558640025, 0.017157033190972382, 0.09879983150430265, 0.040601936033776695, 0.0182317492116483, 0.05724370614775727, 0.07384769663575196, 0.04278910556627859, 0.03658629848711914, 0.026234493275443395, 0.008215372724789045, 0.035346948256295536, 0.03009720052021646, 0.09889117216751461, 0.009196531215322115, 0.011556533056371396, 0.008748044192250217, 0.052531227364294955, 0.05804817124660458, 0.024324013633773695, 0.035107473001605084, 0.020522581931624203, 0.09901465788002937, 0.07055776268844643, 0.02450713737597389, 0.03461110548326566, 0.03914482148003675, 0.021921695968616876, 0.07466788568924512, 0.0592193894478823, 0.05124216568806479, 0.05880571729052932, 0.03896521982706843, 0.020757845617950927, 0.11168368371023286, 0.010704614556274347, 0.008273418249201872, 0.024748998994548476, 0.05066959923433681, 0.049834394857527754, 0.00890023043123825, 0.017303704554515503, 0.02327020223733158, 0.04911508426190384, 0.023027084234561172, 0.04046582136183016, 0.0032692239572849847, 0.0652537759273283, 0.03174464770352408, 0.025470322486193433, 0.031298646635766474, 0.037442995460643884, 0.08139703347678147, 0.10269240085636416, 0.013661903550758237, 0.031079943855142886, 0.047772216400311845, 0.029212485796080965, 0.05001671229218764, 0.025990283597380887, 0.08784823690450962, 0.03302353764733961, 0.06580869171528086, 0.051586840136517445, 0.029686303516369195, 0.04969647987895916, 0.03618058981373906, 0.00573070491701665, 0.048766449138882666, 0.030894422257739692, 0.03311010175234368, 0.03903368127442176, 0.051846379233944806, 0.016156497464004545, 0.034389572007761854, 0.0711730308830738, 0.05273863034803541, 0.03512051564851596, 0.008579546026134444, 0.09389342905412759, 0.03204093412345937, 0.01022119009341564, 0.024607397217844284, 0.15413093020118054, 0.042610526640689185, 0.04435449132635709, 0.018204317518299627, 0.022171942419522715, 0.032248294972363985, 0.006180879727546727, 0.045219645910565896, 0.041841343721194614, 0.03635148104700831, 0.027501242640878887, 0.04228058023258083, 0.0058417302094429975, 0.02897676054177986, 0.014016052591614427, 0.026940345621457504, 0.03580669677185436, 0.08107670147212283, 0.04080850398167968, 0.02171680000760863, 0.01977676086338057, 0.06010658438167265, 0.008552218712265454, 0.053496636044714725, 0.0244304672965119, 0.07336704541117915, 0.06565794859442019, 0.06766320671886206, 0.03591519014369096, 0.009308865560489077, 0.06851524970824681, 0.06211612110717162, 0.005960891355625204, 0.05694458711772196, 0.0415254014003421, 0.025288062508127866, 0.0760437872621321, 0.05329708546219815, 0.05663441726937891, 0.08973600778488383, 0.06408321656166546, 0.030982671756177183, 0.018140469835470283, 0.030114807135936235, 0.036807709388555064, 0.08436131110835461, 0.036791721133575324, 0.01868300755778628, 0.043745355665563576, 0.08025881834328175, 0.03588242073272986, 0.04541722764711707, 0.07168924390909172, 0.013363789053513639, 0.01636335652531876, 0.014879649144507226, 0.010965799785129005, 0.04278304964123715, 0.029948792052305037, 0.013632770184607757, 0.028769778906397765, 0.01631094461997911, 0.0432737136349803, 0.024696382160689083, 0.015487211452226247, 0.004082737272725471, 0.020356873283162713, 0.01272103553938289, 0.015955006763819727, 0.002005807074320112, 0.05240807106958763, 0.014977046690370529, 0.09649324035572429, 0.01716224067363768, 0.02361348240576204, 0.019149871114941857, 0.05599451551754629, 0.05790638752401837, 0.0445935107587326, 0.014585426373917972, 0.006341448883646198, 0.0408994960748861, 0.09663676692833824, 0.026144983562370463, 0.071187992580235, 0.01947761502026791, 0.0694545501122071, 0.01729482176503347, 0.13866078048463792, 0.06089971904011984, 0.011177634587511422, 0.05896055898178489, 0.028363068573056694, 0.07044307932618164, 0.029776521860772086, 0.05944641577380319, 0.06698362544299134, 0.024568550814423832, 0.03305703484182877, 0.06445058636487493, 0.02790828813768683, 0.02541024587117136, 0.043718550249093005, 0.06593300480275385, 0.03709960803990403, 0.018578074579577775, 0.07556846034863303, 0.046644255353678624, 0.007571459066257963, 0.04915503957759469, 0.027072947780271212, 0.017788808665148193, 0.030425258521591465, 0.009754868543466494, 0.0928866209822797, 0.04619307170111326, 0.014589003046914456, 0.04599909823868544, 0.03830760229198683, 0.0336940216291095, 0.04548327591750891, 0.028471456607803706, 0.060007981204938506, 0.028986556891111598, 0.029904408748411847, 0.09365070175619856, 0.04712756873378831, 0.06889179724478914, 0.05137571779590461, 0.036839977011925755, 0.06122020426236334, 0.03720140963372204, 0.08615822396090916, 0.01991651253774762, 0.1264686214046613, 0.018285632005802566, 0.01165043915651979, 0.03196136248598416, 0.034735679040632905, 0.07958788620007616, 0.032503888716981295, 0.01954795721347534, 0.01703596448585872, 0.0017665325586060665, 0.03624636612291779, 0.0779108124815168, 0.0742902503078503, 0.03268460502787944, 0.01434570309826203, 0.052930355342405463, 0.03413855563849211, 0.036425236161918416, 0.017031728019637447, 0.0864252056025209, 0.041835448674617276, 0.040240331042197444, 0.016984703627625303, 0.03262922070139358, 0.03664812561304819, 0.049141801578263124, 0.024866698828015118, 0.04864816899381338, 0.03434996526207655, 0.028069505595692226, 0.06998637601012184, 0.014833413823057088, 0.006992593933377536, 0.028545893540966417, 0.046999333276143, 0.043348602560018344, 0.0485107213288786, 0.02579775995634977, 0.07636930568203812, 0.05462886037064656, 0.05888300790120998, 0.028045023340852033, 0.04172026352476209, 0.031066615840480215, 0.009618280812226718, 0.03777461194042717, 0.035403156127299995, 0.03470372551331117, 0.07454292908791574, 0.011864681390204258, 0.051338911101582556, 0.055542967973216895, 0.0434281301474379, 0.01815004593452379, 0.019038020362777096, 0.04127882451059357, 0.016363318220922546, 0.0067363437471701015, 0.007609478094720192, 0.051316820956285925, 0.05686132485167154, 0.07569740826804792, 0.01771660104784514, 0.020030259357524977, 0.03790308105488939, 0.019924935674475088, 0.026884208613586043, 0.046857109053000334, 0.023367840143281127, 0.10384396124150484, 0.06437659759314791, 0.020917076993012623, 0.014587300416502743, 0.07807932118134153, 0.05522843525414506, 0.05496491632995106, 0.017912867028386365, 0.07428907819332616, 0.21317826013170907, 0.1401789675677015, 0.2057841939911727, 0.25657433716039507, 0.18217766957898296, 0.14393405478087165, 0.1992249338617248, 0.09385718543442989, 0.1726976073076648, 0.1418236204453053, 0.11629378633393396, 0.1407040901962788, 0.14783970891467987, 0.2162669581030646, 0.2042252663522959, 0.1325530832212779, 0.19045005552470687, 0.12917886428054304, 0.051740536526326215, 0.09918777842915828, 0.1369047537446022, 0.11689478231053199, 0.09674493854324664, 0.12410436681802235, 0.2282726283996336, 0.1263026944211414, 0.17335366968426014, 0.10682314694408448, 0.10160935171429189, 0.17022787773561093, 0.12640974754768033, 0.09787133294007472, 0.10629925771706528, 0.07203478786733843, 0.16771717778136655, 0.1759236035568099, 0.18504407947822926, 0.1528986624532169, 0.09197096205166272, 0.15954462841393488, 0.15919869375084678, 0.14098734354540227, 0.0855102055075188, 0.11322475383959471, 0.10101268413446604, 0.08628534859106426, 0.24463764542052824, 0.0811889486747884, 0.15276274313369106, 0.08570434750928994, 0.17853346593197317, 0.14968093995365406, 0.21870127909125822, 0.11032040726633803, 0.1505406438222816, 0.1282862722573261, 0.1743515604926694, 0.20242001080224592, 0.07824085082017607, 0.14864330450373311, 0.1391555813531722, 0.09759846774320449, 0.12810820278020638, 0.2333437627361667, 0.1400632270041012, 0.18386051960049138, 0.15119901978440825, 0.1533365889542526, 0.12777052654494203, 0.1332265051502374, 0.23142512617332323, 0.15379754405829216, 0.13231554999947548, 0.09411414664599205, 0.26103719768504946, 0.1246792698399194, 0.21114638045189843, 0.10668463824737458, 0.18055376236236867, 0.17750031975728853, 0.1392944884156027, 0.17107291868136776, 0.1915751016067882, 0.19018036193184315, 0.15024015349486183, 0.20736987342036542, 0.14506414172149476, 0.1487799286241493, 0.08943600009285635, 0.1875874300998065, 0.09518095472406957, 0.2547347915148543, 0.13748714910639873, 0.18864427903486838, 0.1670759468669853, 0.16305413848209768, 0.13061737821948144, 0.10290449995908046, 0.30060821302956153, 0.1524163334960899, 0.12110550031666795, 0.17664725021008523, 0.11047832097016996, 0.15420626728765427, 0.15145421899374456, 0.14329757361162093, 0.1461974768749168, 0.13040868054714896, 0.13395398224313415, 0.22567673946820924, 0.26291990472424415, 0.13516551965186674, 0.11897289539657294, 0.16038375516091624, 0.13986804312275303, 0.09300128136190677, 0.14251064809580005, 0.17452218359516514, 0.13003027907782985, 0.12731960719271054, 0.09153057640839009, 0.254163381853892, 0.1760593390152339, 0.12098087313314601, 0.13335009045418234, 0.14876053127790653, 0.20361642563535323, 0.2470896017527388, 0.11555246603224548, 0.09303231558371937, 0.08800930689058958, 0.18153311384301032, 0.15661489368686754, 0.11715560460523253, 0.14911507676926353, 0.1025300438425714, 0.16886133009627943, 0.10485603999827178, 0.18671047393112414, 0.15677672209999255, 0.18656583653102, 0.114012859130819, 0.10147255905453237, 0.09414989230853897, 0.13425957471612962, 0.20556771286552955, 0.11059757787734271, 0.13934184797108173, 0.15682379054206033, 0.13100917090571698, 0.15459963811501382, 0.12546674693904578, 0.169509670306598, 0.09865394538088192, 0.09710431038852661, 0.1787836242827677, 0.159181977712339, 0.17448302118047593, 0.08967374015839831, 0.14236901376035907, 0.17374512529180897, 0.0936216976673853, 0.20751253431362493, 0.14887686939008776, 0.1931496880828373, 0.17551779146156005, 0.1367115463700987, 0.29356571995923597, 0.10354526355982789, 0.15729658936540927, 0.09921239283416541, 0.14208237430261028, 0.11115404882378156, 0.19366514268181018, 0.1390006630531242], [0.03955775053210316, 0.03339695188427164, 0.04282303560044497, 0.021176631412198468, 0.061083786985686714, 0.03484073267768949, 0.0078757640327357, 0.12413881779197725, 0.05222586471767676, 0.02496508941535027, 0.012526063289823792, 0.0269616064765761, 0.06343257808757406, 0.03431040448166671, 0.019999499012145306, 0.05583320804420979, 0.05745690841708453, 0.02768332258828225, 0.015593943779446907, 0.010756779398258415, 0.014526781385704396, 0.03627120652386258, 0.008097494775880008, 0.021475185452389623, 0.04469809325171575, 0.027188822409258257, 0.028525391112892862, 0.013573593722896711, 0.03384242052092187, 0.031690194173866225, 0.06947872784709738, 0.0037639786211413244, 0.04770924014249637, 0.026422108208099683, 0.06608563249990826, 0.06829140647765129, 0.028458674430787086, 0.060452044070247686, 0.04956500386939414, 0.0356541303617339, 0.016645546927447283, 0.008462492579353914, 0.07091884290979755, 0.02459305030624232, 0.004481989740123672, 0.04329447078728869, 0.04961308737796161, 0.018475493491296808, 0.0936801118716117, 0.033568927131953745, 0.036032175600168206, 0.04609521546010529, 0.04370267307686229, 0.01833644087216066, 0.09173284660303786, 0.03369262734908731, 0.008338642975075111, 0.04441177555089516, 0.059748131841901815, 0.045658005251278805, 0.09126563256065692, 0.023067345985421733, 0.019517838466732253, 0.021056543299627882, 0.023633984833835595, 0.04480312007569498, 0.042395570030015324, 0.047439726580294876, 0.10307588148862125, 0.03381209493043923, 0.03521028200104352, 0.009598668961365138, 0.044520778371201414, 0.021819005712806698, 0.0527956847461962, 0.027608194260767875, 0.036598015801921006, 0.07824573846113297, 0.022077709774396593, 0.011905931394487139, 0.05700108227169803, 0.041533809215311086, 0.017330506140546455, 0.024173973398583553, 0.014571332271331021, 0.017249224211780295, 0.07987869317613303, 0.042944529484356606, 0.022331821138880426, 0.007736767912583967, 0.034510510477928386, 0.05075334030533991, 0.0377463739395382, 0.020168814019510345, 0.05401027118486743, 0.04845259440762382, 0.09767257142812015, 0.11575551763657602, 0.022567203568835414, 0.04650843945602256, 0.03088761173609284, 0.020931479445989096, 0.02321426824276005, 0.03592841665170366, 0.06021040844761076, 0.028949694655415033, 0.05923826968477619, 0.018287694697538694, 0.05757506598808593, 0.02875848102473444, 0.00920519471213582, 0.004612427700551287, 0.03727263282804239, 0.02506167203518412, 0.12491725505359712, 0.06004034075886012, 0.04235296021966685, 0.09004839545776767, 0.011949716192189486, 0.04189816829297812, 0.04515986806983429, 0.05748575545787331, 0.06801912350760353, 0.04424080004795425, 0.043890356957431764, 0.06275168297091319, 0.048401040520759366, 0.02423255614215328, 0.049066659844210075, 0.04120115851683002, 0.0513723163655208, 0.04186207789086527, 0.026270987788936304, 0.026675865256918535, 0.031216087255386576, 0.03456656513134799, 0.05003040611383416, 0.022973917732616107, 0.0659613806994692, 0.03144064486297148, 0.019731134581830234, 0.050888891902662096, 0.04301442351612834, 0.0345723299429782, 0.0397144653083336, 0.03197309703776433, 0.0024750399977840004, 0.06877317619059356, 0.033780873017085176, 0.02451539197335801, 0.0727831025517756, 0.04848779997818413, 0.013874446984470613, 0.059135828407541405, 0.04331168095250765, 0.06535620954368385, 0.03480259682081881, 0.036426197602263385, 0.04919501021504403, 0.0764235140635602, 0.08446165330467686, 0.06554094398574484, 0.02208543002545353, 0.055857056361292644, 0.024600613509274782, 0.043456168965466564, 0.0307094733110599, 0.02815096755512059, 0.04042275189872711, 0.06546069627567645, 0.010204608120294589, 0.017449347445020275, 0.04344635537915653, 0.03173039272247303, 0.062058706647686424, 0.03544787650987987, 0.03963320636220517, 0.01171909116824428, 0.0401870955923392, 0.035358144631308895, 0.043686543095616565, 0.06823362046552282, 0.10608196453822237, 0.06010153969269126, 0.02111094511835085, 0.007607643792946493, 0.06532301495392477, 0.0072303071858421455, 0.013792715936658845, 0.04721378809922645, 0.028281736848575455, 0.06364163199079133, 0.04442678704377144, 0.039559160133883844, 0.05521654939999985, 0.026236841334931316, 0.044232193050124956, 0.031382565822211966, 0.01950335557452373, 0.05577911840631597, 0.08931238414539446, 0.010647878084602136, 0.06130503700865854, 0.03942573443055153, 0.005595163374598469, 0.028633353968841896, 0.08620624235200305, 0.008254234449967982, 0.03428570580698791, 0.004978174833776129, 0.03674136234387275, 0.018404477140716007, 0.050863407987860904, 0.029680950476998286, 0.02785821854617567, 0.04671643232746471, 0.027207359821806033, 0.04125701781782893, 0.06608030052795526, 0.01241635088057768, 0.04638874204829336, 0.008361666790029455, 0.012537602489183267, 0.04129841337881742, 0.038177746558381666, 0.07158478015973684, 0.014510158235357415, 0.049117183342816374, 0.07779439776054314, 0.015232576275124185, 0.032060794952896335, 0.02801958730654611, 0.01981265208263311, 0.037402350665821184, 0.06257443703831204, 0.031547533280606714, 0.05212487134661886, 0.06216167652558896, 0.04488417217808385, 0.030921693072624268, 0.03576122945354831, 0.04122543967359009, 0.046272166448855595, 0.03739624111462505, 0.044686126958338485, 0.03387818916610653, 0.009644638067261587, 0.014018862219076726, 0.058626295668223215, 0.04294151875881418, 0.09516642203614598, 0.04811901674275437, 0.08348502143616639, 0.058572891679021626, 0.029282816497969533, 0.027306711849486156, 0.07001080655402715, 0.03029658830904913, 0.015106749206390834, 0.024616938842941197, 0.07866512563440108, 0.05749101465147349, 0.10323572573402237, 0.04573147691365692, 0.05853961281959088, 0.045242145912902015, 0.025930837089676532, 0.056189557672628475, 0.12900646385406295, 0.022826560720380758, 0.03996585706068624, 0.040556223567334876, 0.02190800406219017, 0.012715434479046495, 0.05385592745076265, 0.07468443318840957, 0.0177144464255581, 0.019912151582238656, 0.05243183511699881, 0.025009978337273486, 0.11300956740254357, 0.025147397273911104, 0.043521405182658665, 0.052694702866457166, 0.006884828823873954, 0.02862798369249269, 0.04983147606253625, 0.038566172288189975, 0.032235512795347365, 0.038524627340056246, 0.03615352775781386, 0.04814988625566325, 0.022764743170550755, 0.06795290286742872, 0.06783760663482451, 0.03746116706620782, 0.029688538577888283, 0.016703195043749387, 0.07135440219914721, 0.03161770310403118, 0.07902002352620326, 0.0384600997541941, 0.04142788989890007, 0.05579858853091156, 0.05078834669303991, 0.022421916909215432, 0.027567400078799938, 0.02542637202197746, 0.01379323783405726, 0.07360332990966498, 0.03989011777805225, 0.04450531488644981, 0.041310624820330454, 0.07523352670813761, 0.05416761032275615, 0.07521676470435436, 0.02517923014238477, 0.06417529649972435, 0.01183161128973288, 0.03979794207900282, 0.04265146254892311, 0.05166868513990795, 0.03771928507053564, 0.05230896993570271, 0.04649943026203302, 0.028861996740283027, 0.027359391885599302, 0.050800960330713185, 0.015833237088255344, 0.03774281163069029, 0.024194330269951495, 0.032605682649920066, 0.027673509001972216, 0.07211140432064572, 0.02424088543311002, 0.052841312942966345, 0.02825151084952297, 0.007198990469107465, 0.030312785322988228, 0.07122661873337723, 0.030593093064042832, 0.008998080926586785, 0.05532331907400682, 0.03223018465383399, 0.055336683477845885, 0.007399148176304035, 0.026201256550848488, 0.03145562954277041, 0.011668965077748703, 0.05828106963646509, 0.05915615655061218, 0.03057036706576905, 0.12751732682508807, 0.17148092178808105, 0.16933999715312836, 0.19002869184459412, 0.17374302621089643, 0.1471114197685834, 0.1361248609159262, 0.29877698709887845, 0.1696745937149371, 0.1351637576496409, 0.12649954071328526, 0.19434322242534932, 0.13549377300566243, 0.09164129909608634, 0.1323121179255747, 0.10998587965244248, 0.19148102600968656, 0.1032144361506066, 0.15518348904386645, 0.12685941817659524, 0.1652408292096469, 0.091332366479741, 0.1118774809724381, 0.15116400956626863, 0.10948717939637362, 0.13650810406092675, 0.09995767381042243, 0.15952985823875473, 0.09914847045776345, 0.09611012744567088, 0.20446509783787115, 0.05941386852834014, 0.14661775271017707, 0.07707765355946557, 0.15059163463452171, 0.19992334557877434, 0.11516841083404519, 0.1793900901271451, 0.1224057813505492, 0.21270567581297892, 0.165150216329963, 0.11519832656748834, 0.27256044709394056, 0.1637449965722138, 0.1350075523218801, 0.1409534518156321, 0.13722828799678435, 0.1513493109133936, 0.2806870771511909, 0.11769860772596252, 0.11837418236198927, 0.1518528145407477, 0.22636390501453033, 0.08628382407609494, 0.12930511557046445, 0.12231819451816621, 0.1651460488116549, 0.08496203129329989, 0.17649965571059337, 0.08867145200530369, 0.24542840137597055, 0.17707014606604654, 0.21314294347839974, 0.1725677400827408, 0.12431838114054934, 0.06549926880266398, 0.20790739135155756, 0.14787755365813934, 0.14811421353970805, 0.0819263159627876, 0.16159319348873633, 0.10900104298226296, 0.13909787961071537, 0.17205257659717915, 0.15248089938634826, 0.16277235602178883, 0.15405859617936998, 0.12075669282386381, 0.10355799594112944, 0.08626349210258454, 0.17877102979729254, 0.17846274069480358, 0.10836176559208863, 0.07485976773163966, 0.14245840089936412, 0.11506581633922555, 0.22534217354991745, 0.10990737862284146, 0.12222920574488179, 0.1154054077943006, 0.13567711316770123, 0.16271091577026153, 0.19035487676099425, 0.16284161037014377, 0.15384836633118892, 0.11050009318897802, 0.1349200344374103, 0.16688551273076765, 0.25067052653720306, 0.12027023465282495, 0.13652719497199983, 0.08617638790559384, 0.1445832683314239, 0.09966957878561751, 0.15558677304896618, 0.14964433627263193, 0.1252879037131225, 0.16820460888406924, 0.15108285021157036, 0.11470685052054544, 0.1648066105741647, 0.13798188868789904, 0.09816354185703302, 0.10724428845869918, 0.21249965944838142, 0.25741724838172236, 0.21607076298565636, 0.16796580395631253, 0.15443831531991883, 0.16455069124217958, 0.09791663171903742, 0.1521162262126323, 0.16592424092513902, 0.12175548761602371, 0.13445436023175716, 0.11732579103761143, 0.14434489241290477, 0.18767415125283504, 0.14213989218396528, 0.12197869499364208, 0.16585679454428537, 0.12714790390624156, 0.11680673582539444, 0.13116185222902607, 0.10516347108228553, 0.1145236099499368, 0.3218106462830498, 0.2124823305395342, 0.16107421488531176, 0.13233913018578483, 0.1089967911942832, 0.15840268243224392, 0.2775482310643119, 0.09767456325672327, 0.12509013045459025, 0.12198618733354154, 0.15250893820437694, 0.25950673787343886, 0.11951813549404183, 0.10449918858226269, 0.18840538217656075, 0.19620536766465635, 0.2772663413516937, 0.16885097258754317, 0.12266592948787636, 0.14954433115499635, 0.11316824719429978, 0.27355590174275063, 0.13009067744978015, 0.172250778864949, 0.17908055996221883, 0.10646614997136979, 0.17707340960060397, 0.19570050040079703, 0.19112838041638175, 0.09352957559449059, 0.28942467764981333, 0.11451992506702101, 0.15192992895120574, 0.2446672930231979, 0.1235195276357474, 0.1068652971016784, 0.14842936678999855, 0.10615879549614846, 0.25941667657706047, 0.18454762385977855], [0.05483335222027475, 0.04939698163540133, 0.01654756811237143, 0.07519527593807829, 0.00718463781184607, 0.024680715662637548, 0.03511970359531622, 0.03783759968956152, 0.0568583294478876, 0.039719724501933784, 0.03222168873875372, 0.03238292726417703, 0.07587804413971401, 0.05370194377798227, 0.02794884291717843, 0.028255739654864998, 0.029483998847764828, 0.08838096678617502, 0.05439003629069175, 0.1276284555393842, 0.015200800863244842, 0.07649310549060184, 0.02012414151742574, 0.04579705403997533, 0.026180598989970265, 0.06134784983230695, 0.059529432891717846, 0.06899751737833985, 0.027354458279366937, 0.020349055355895432, 0.06145787154955249, 0.03661506891911549, 0.052070934926309896, 0.04816203641014234, 0.04154592106539396, 0.014039061084810286, 0.035848942690438805, 0.04550723148690117, 0.024429971254580927, 0.024647907947280237, 0.027763070425980037, 0.10431566455912206, 0.010438155769670924, 0.026979073281249693, 0.10152244670016151, 0.03767882030637514, 0.06095288937250453, 0.034579178769021265, 0.011822333007359938, 0.06041779610959273, 0.04386290419666518, 0.040786877319577246, 0.023340013914651448, 0.020024573069907004, 0.03241393084247266, 0.03451073647386605, 0.036480857975660794, 0.10145011267835095, 0.0223580175154512, 0.055935465460342754, 0.02381880354556826, 0.025882313080552607, 0.06251920975985066, 0.06727269339946008, 0.09433578354336562, 0.05419781333917091, 0.0312000549503512, 0.0279283634717426, 0.009740800296346988, 0.052017496463151715, 0.037556698230365594, 0.03341809591098178, 0.05176937590623575, 0.02808454581686566, 0.021558955251689882, 0.03249345076901298, 0.1038869770784532, 0.05241151846524689, 0.03524220488484829, 0.1048751385702241, 0.028736205103116173, 0.015318162660414894, 0.08934824472113002, 0.044409890974601435, 0.08485668654283209, 0.04528839847133045, 0.03705682202933296, 0.03667998720981902, 0.004449365407063236, 0.05841139268370406, 0.04888107887499275, 0.09188498400392071, 0.05397871985370594, 0.03761685528461972, 0.06085018379493587, 0.011994970921096543, 0.02117419908303888, 0.024323931279321833, 0.015980395875240288, 0.04840372948937359, 0.03208476392882726, 0.07190364127558085, 0.04004244670091618, 0.03971541142692009, 0.07463267628824519, 0.019541493346614223, 0.1237886313409094, 0.019019737674464143, 0.11649014999068553, 0.04181212129732294, 0.08101106305877048, 0.013732614423779231, 0.010295822378999044, 0.06562533623148357, 0.01627352888575725, 0.045657932472925995, 0.04023248247141319, 0.04493417090646202, 0.06616411820775078, 0.033059907671544826, 0.04708250361164251, 0.03084287603175448, 0.01807212521652541, 0.007588481061130523, 0.06667638588095866, 0.0589225993251368, 0.05003991326497448, 0.05986053992303149, 0.023910571302798007, 0.07996591228631236, 0.04580666461298543, 0.0387224733769413, 0.037764020774874, 0.044924410946306684, 0.07105597264824376, 0.05100695371267296, 0.05122958652434811, 0.04082268426915811, 0.07185716272121476, 0.04388467641547323, 0.011248394298637587, 0.04808776418588335, 0.025713702874077905, 0.08225535072626607, 0.012027010633309763, 0.03294088442118899, 0.11982046443247989, 0.08392670176803105, 0.029134400369178866, 0.02865436967582472, 0.013490805473749437, 0.05861878800656527, 0.04118630407197822, 0.046588131752345836, 0.04801594727342168, 0.05548233977488934, 0.05488178812928739, 0.04932313075950069, 0.052764378563170476, 0.02682408220284889, 0.01176523934719303, 0.010523168546628329, 0.0456055473806637, 0.05220602687087752, 0.005542174988095799, 0.02720418438735989, 0.007361054933074141, 0.025777642487458167, 0.03395017461791154, 0.025324321449584058, 0.03993322554555151, 0.0216877116491237, 0.012250206519609258, 0.04202277249386234, 0.03342270776028595, 0.04537061885780385, 0.030999278627155773, 0.015339832414963074, 0.029608988007831, 0.015679768609604048, 0.02433823605608796, 0.052519651775759076, 0.022166798139111172, 0.02916013709299507, 0.0202967717702831, 0.09644197375183144, 0.013744311628773088, 0.05072306451057235, 0.09746232625818062, 0.049113935130017425, 0.040582868105341355, 0.09490111046620915, 0.03675977526713283, 0.046141410561939405, 0.11891314053847907, 0.10214683134108783, 0.05240974497170218, 0.0505850690927717, 0.0633918337013212, 0.032245452786164905, 0.024386191244928107, 0.003788700278457855, 0.029879995441484838, 0.08391016192974583, 0.03721847807267501, 0.01489444230232508, 0.02992263589535029, 0.0208545757097102, 0.06860967770579361, 0.10474831271435946, 0.02714980363605484, 0.04610095728909777, 0.019802867224620237, 0.030611641967909473, 0.039766099634430105, 0.013047888867496964, 0.07664790887746119, 0.07541548791191272, 0.07802660667127179, 0.04153888837824907, 0.05807508774582417, 0.006263145600490633, 0.06009443422719356, 0.0327854490117921, 0.036947922630896496, 0.033587788216649525, 0.08336118332320645, 0.020942675821002454, 0.004107876447960734, 0.07337176451279272, 0.010420038747871596, 0.0036408465060841053, 0.02716042161468537, 0.060800208049195434, 0.011901857721949778, 0.0188649362028246, 0.025271823359352928, 0.03622996418045894, 0.07038244346697485, 0.013287119931661555, 0.06846882478003541, 0.028710598614247098, 0.07051604920096936, 0.020557000346842314, 0.02463781665409765, 0.030021989838250225, 0.05672490374455529, 0.03937539096260744, 0.07758052899472176, 0.047415640775955496, 0.014604670502575896, 0.07588105486525644, 0.02762591578967629, 0.035009452051693396, 0.031552893980856866, 0.016998836034608465, 0.00853229659579454, 0.07397061544320277, 0.06059125373740831, 0.055222413803060214, 0.027223010998099085, 0.04624689320823358, 0.0465817540703762, 0.04720046583022322, 0.10164530422057837, 0.00871815431427451, 0.019088405965557022, 0.03289006980917147, 0.023713541149552313, 0.046656765569482124, 0.09774995396935171, 0.05082960435820203, 0.054055229054703835, 0.04015505779534578, 0.013658071195917025, 0.028938055864625403, 0.038465125290977384, 0.06683798446770638, 0.053725102615933266, 0.025410845334972107, 0.08193670411504085, 0.03297738468034133, 0.06715506059868682, 0.07353293409030284, 0.01667910923941001, 0.04793725089139996, 0.009658851871086706, 0.05704183431883013, 0.012543040755835753, 0.011392092283424592, 0.03972100769920696, 0.03388419146499327, 0.034980298575734904, 0.031198484470106425, 0.039550081991981116, 0.0268373278630597, 0.03811851647051592, 0.12421576366309198, 0.05428676763849874, 0.019040299474351832, 0.024696634969704097, 0.04686682304788021, 0.019457989762867653, 0.056700159104601036, 0.01216501945764908, 0.011404456942522479, 0.021486060070474784, 0.08842353063124804, 0.1348091968365254, 0.0412335678664667, 0.028856113185024554, 0.03238001613006477, 0.06687896251077614, 0.05955390940089861, 0.00761620338908547, 0.00626590303821309, 0.021538320673449386, 0.06019235175523547, 0.05696788385149933, 0.06895399592336147, 0.02788566556128283, 0.05219680317226918, 0.042226984721398166, 0.01647750937169598, 0.05326150067811532, 0.02443940562736844, 0.040356404854044806, 0.026752556403798443, 0.04325778666703452, 0.011200947600657181, 0.03382947363500153, 0.06235982133676449, 0.0439545781081242, 0.008184059838493987, 0.03168100686443429, 0.040194518984325474, 0.055456633694590106, 0.028430221925279307, 0.025859521964805263, 0.04807091791242842, 0.030560001896153537, 0.028858957286443443, 0.02247426944274095, 0.029728392386929165, 0.022811037863815026, 0.03081200460362579, 0.016781765021263592, 0.004215283890164668, 0.04673205669068041, 0.10509608598846583, 0.026947769013443784, 0.04237776231621543, 0.11992691234955866, 0.11440431473836785, 0.07011853383793946, 0.12397269928647627, 0.12013174893875277, 0.13880725649576034, 0.13784782330114997, 0.10701862193884389, 0.1611410330740675, 0.13617168420985823, 0.07571106761573784, 0.15913141590933647, 0.22548432882514693, 0.23061071342277914, 0.14404098533334272, 0.1595048990941817, 0.17198261744793386, 0.1495273546465943, 0.20469248805555607, 0.24422126131192332, 0.16381956757076327, 0.0784093212156046, 0.12771791162630244, 0.12307063841651525, 0.10622275617694664, 0.1844816483677395, 0.14480425405406183, 0.2123453846621898, 0.0999602095614518, 0.15495479647671023, 0.09431282388827494, 0.13267984012922934, 0.10610867036326278, 0.32700006459509173, 0.14546065350934384, 0.0973652322746573, 0.1405012607574463, 0.07710422148867961, 0.17124913422571075, 0.16459717745742491, 0.11958299249771143, 0.2210565704491831, 0.1233262206698137, 0.11187745032892113, 0.201116175120396, 0.17150309237260974, 0.20818368862232856, 0.10423730142534741, 0.13277688814747718, 0.13477411000959336, 0.3223409017007197, 0.19089924351822948, 0.06150159984827042, 0.19398245630004715, 0.1339303867350663, 0.08937077536698311, 0.11071336440621846, 0.22060562045343463, 0.14217851833710748, 0.14951013299005647, 0.15059499009963007, 0.10345885650284829, 0.18944084193677674, 0.12834508482727314, 0.26224620700363194, 0.13022557021148745, 0.19729377942219858, 0.1551996075337933, 0.1598509256878207, 0.11242379359300099, 0.12480508445972398, 0.14830633306935911, 0.14523882508998917, 0.1423511945552403, 0.18605107141117896, 0.0899673433553788, 0.10457532240017768, 0.17595645340700306, 0.13609912036167038, 0.2859780480784755, 0.15868446489255275, 0.16759630442867357, 0.2995570791104148, 0.15963907173324018, 0.15740776404498086, 0.16504699364304543, 0.14551288538402127, 0.19840952519687916, 0.14640511734591377, 0.1091691762990048, 0.15754268745020514, 0.12470605227375224, 0.2314263212704851, 0.1670738171425558, 0.18778157210157764, 0.10915763901486512, 0.12584887925655613, 0.15978781536461847, 0.15242747241450896, 0.11964752774445281, 0.1108030886239102, 0.14626372815860858, 0.22747126978731927, 0.17096316892533533, 0.23153420177198228, 0.10625037364661695, 0.18404373718846231, 0.17952017185668792, 0.14104573476699092, 0.14893211965118686, 0.16495786697393464, 0.13887430451089336, 0.09418386064710156, 0.14851051082293834, 0.16949401146942572, 0.11012443431442785, 0.16343854608074312, 0.10177658104728307, 0.09930872072976443, 0.12112089868394599, 0.19352379945978043, 0.24618528092340117, 0.16666057399444043, 0.14223271139687108, 0.1723237104353405, 0.12806216855683636, 0.15482327450186978, 0.14901744652419321, 0.11753496368445697, 0.1564593931599971, 0.17652859851237268, 0.11320026200865546, 0.17507755137499303, 0.17059169289085174, 0.17798287854079278, 0.18002825668982922, 0.15840179377025174, 0.21797256093592415, 0.18971592878862736, 0.1987882943884019, 0.06949831671532124, 0.17581028383105032, 0.14465931021878797, 0.26314513457398264, 0.15975119636183785, 0.09438839080112596, 0.1618726930070308, 0.19028862547730246, 0.1344212039463943, 0.12915988062177935, 0.1749148036563589, 0.16274413334265833, 0.10775847135171776, 0.09396220076709025, 0.11631926641829553, 0.21127773388739557, 0.07434448933288937, 0.14663999990349816, 0.11882625850698642, 0.18008698499010456, 0.17956817492602334, 0.09940752308935889, 0.11229090032077606, 0.11495032092376102, 0.09455113085888087, 0.11883545156207778, 0.12873096331473322, 0.08911687084623883, 0.10550781228249112, 0.16497979241032756, 0.2289147632977655, 0.11742044886153553, 0.09301790546986366, 0.16679139116839056, 0.21353380153736762, 0.12507202013606025], [0.08605611210148181, 0.04117065672612479, 0.03716084910857101, 0.020601017843751658, 0.04343135920803874, 0.05822552443151513, 0.021797403948561802, 0.027430134359747175, 0.025467681398074475, 0.05782865641278125, 0.023967822968599298, 0.04046368780696104, 0.06727465458454625, 0.017799380678503264, 0.02430105397868301, 0.02086970211577512, 0.0905043863120579, 0.043557258097515, 0.04755968062747871, 0.05413805465063742, 0.05686430493369699, 0.028844889996933843, 0.06315205584190066, 0.058327793338966955, 0.05374189143279388, 0.06658885267473037, 0.01977428639938514, 0.0072245380649673605, 0.05347043200726471, 0.054360545736046574, 0.043914933058042685, 0.04351834849184079, 0.057567332330490315, 0.065242376539015, 0.05076847437228407, 0.047175242385316285, 0.022743045645315322, 0.03756705190866225, 0.029736669966951016, 0.04076962501952245, 0.017984657127770688, 0.054226051340059894, 0.043413222076431404, 0.040679192170500755, 0.03768006136881248, 0.04619743840228166, 0.022110626657283115, 0.029871216073872584, 0.01691456253249799, 0.005162088604148237, 0.059231807733134884, 0.025303872647665204, 0.025892559506539858, 0.03211695877384515, 0.018594376930606463, 0.05876849690872816, 0.04925408325488529, 0.045527866065141656, 0.08383759808155798, 0.03036782874034778, 0.024256708979186033, 0.014552570778065392, 0.07498586580397622, 0.004510526994108073, 0.06559414879208611, 0.06637886031380584, 0.04528185991089671, 0.07082420040763195, 0.02731692954717625, 0.011921983809330532, 0.02197300279212575, 0.022320444733204863, 0.056790603444941586, 0.02795135760078988, 0.030675809492447206, 0.02886181862484063, 0.006687900177278226, 0.02406918980752028, 0.048384362786647775, 0.04258677791503649, 0.03304559331867964, 0.03834417532949198, 0.019302772688529184, 0.0408726332018212, 0.02601990247175338, 0.02018804091118997, 0.020493081800879973, 0.04127874407136152, 0.018868699609752626, 0.02847117507049153, 0.06531825754791498, 0.026767113989579584, 0.015037563805949065, 0.05691924875962639, 0.010528041823436658, 0.06100615546587975, 0.05024818958894861, 0.0440863375702212, 0.035775712345756834, 0.07940517423013527, 0.02915254516166545, 0.030717896447787364, 0.05143861361448804, 0.1203361948231055, 0.05104630381890363, 0.05450572322813734, 0.04171316572014363, 0.05420083172559258, 0.029525367595675974, 0.0624291216503949, 0.0323638784879398, 0.05457637951739373, 0.03836263421802752, 0.022647527887696223, 0.06298804790863106, 0.015610384026301966, 0.07206379961703094, 0.015748442646356362, 0.04442925767732724, 0.049121048256394365, 0.05732384660551625, 0.085153583917887, 0.033038874727583704, 0.0432077074994243, 0.00946363638861165, 0.04009567832033481, 0.04043794725270521, 0.05781947101856913, 0.019856144809314323, 0.025172358333703973, 0.05217492753159135, 0.027640341225290493, 0.05133135364420953, 0.0557260591566803, 0.03391483498196449, 0.08148602225006589, 0.10009516361019305, 0.03605005609232091, 0.04167432889282223, 0.057047794482881026, 0.03076548582964367, 0.033677772904235515, 0.022053133673785676, 0.015599173287140026, 0.019088118682585416, 0.06651096451546877, 0.02180453431191704, 0.06477546127092454, 0.01628152109802731, 0.04755935887055052, 0.08445296586761553, 0.04290267044017392, 0.050637718485367876, 0.009769301639959939, 0.06358338249546867, 0.03979536802357724, 0.013925204139893815, 0.0526409273246123, 0.034422000509596644, 0.025680732365036686, 0.010065520069591943, 0.0494743641766329, 0.024573313966093045, 0.1289897018502797, 0.06906295660883188, 0.03888206098288779, 0.017447296244603012, 0.10004195880385176, 0.13132623937581817, 0.02583654507273628, 0.019305683822641452, 0.05898672471483869, 0.03630478415758379, 0.13191591257289534, 0.03728845254367879, 0.025103393183540434, 0.01071176311421779, 0.10895814205850325, 0.023063500224041845, 0.021682291577059417, 0.0482809026124737, 0.04048929429583011, 0.02735615516411922, 0.025273405330916567, 0.050609216184145024, 0.01731766267649589, 0.07567574330154928, 0.07321097797924474, 0.033829638343905254, 0.05177896349660812, 0.011466396108810461, 0.017664041670580066, 0.047303585095270995, 0.049184415219051224, 0.05231271610565243, 0.05893619355535316, 0.05239718112974398, 0.05159011516239374, 0.008311239052413693, 0.052266555477774916, 0.02880098932843295, 0.05554800883175866, 0.03183665294801036, 0.018357286124580333, 0.01464561119885935, 0.02746047144154868, 0.05754221230745316, 0.07564908344178431, 0.08088268204441956, 0.051187022679275086, 0.01698057632893324, 0.007782160537317396, 0.01847919178075127, 0.04688504444915922, 0.036961026564841314, 0.020754953636036768, 0.05316595036175944, 0.05675048725078664, 0.014898887527505717, 0.033094538676161925, 0.04724902048286411, 0.09839298519035501, 0.015305335475732724, 0.037527525602209, 0.044631455093622215, 0.0581266722762056, 0.02806178342941548, 0.0611485367370469, 0.015901980072920843, 0.036243899319801605, 0.05495659278465375, 0.1122119626210582, 0.039003497410205104, 0.04416596857951053, 0.021092290877394622, 0.0020298847389752946, 0.04085161557961856, 0.04740459761852699, 0.04519631470283193, 0.0382383517740715, 0.038897761954895915, 0.04009278633842065, 0.045343625749791824, 0.08134054981412427, 0.023379442544894356, 0.04631750736265414, 0.012579057421985895, 0.07292714240329881, 0.09085907736012051, 0.04213558660159188, 0.040429255985204256, 0.060111560122740854, 0.08050510028917944, 0.008464426951362722, 0.021829776909022082, 0.04650964221406368, 0.0984038100127251, 0.06391347829072226, 0.02923026095114408, 0.021524067607618148, 0.09051596956147302, 0.0435291426706939, 0.027363118903350928, 0.04271409789761228, 0.056034922825112465, 0.0735946194899659, 0.02946750688997488, 0.029361505219112002, 0.016593587013982957, 0.04797252540987346, 0.053393964941102656, 0.051067597232759006, 0.03039664513761959, 0.028005579388850642, 0.04107816693102641, 0.06559173561512463, 0.07250803102168345, 0.049479749774740595, 0.027573561340930964, 0.007695583504579602, 0.05185174951029401, 0.07882637182070364, 0.04822285613045097, 0.08893139329889128, 0.04075477440511027, 0.018215845226340236, 0.029507132787858287, 0.09829104187027102, 0.05886556790961374, 0.06244362752524115, 0.060598359202906016, 0.03285299115363629, 0.0198537067344953, 0.030222394608802376, 0.13523708758575304, 0.12420103179230807, 0.027183871566047593, 0.038200185273683844, 0.034976828197437915, 0.05131563352000329, 0.06808493812117847, 0.06579019835278874, 0.034592956860339454, 0.04311283900132103, 0.038750941204207565, 0.03418378546954163, 0.024232864492542805, 0.06402627324625369, 0.045106582824260964, 0.03813338240668659, 0.08352426045964803, 0.06365325354460268, 0.08192879808766228, 0.10471672690924137, 0.0349472418818022, 0.05933806412823259, 0.10978343325757212, 0.04025959049261386, 0.053676892702858296, 0.02614893466083994, 0.03543484918472748, 0.024055059315756928, 0.04303960482619944, 0.013858814002765764, 0.031252687105969075, 0.11124596405293673, 0.022476966072234417, 0.013152821845705471, 0.015705096433990668, 0.02052937713151257, 0.04963177226243481, 0.12489560540885696, 0.08986985100613487, 0.05032722688009662, 0.018813598735798753, 0.015127050536384266, 0.030447034570839138, 0.05333984849013148, 0.04562625856769662, 0.05649197471117782, 0.042756079515862855, 0.026218459055188204, 0.00828982976775977, 0.056869518162021716, 0.12404599091819218, 0.03749290608891076, 0.05200147756465501, 0.08217086654997642, 0.05110479463192244, 0.04870900020544087, 0.01114083938450823, 0.021940319566056136, 0.20208821812224007, 0.16282592088945452, 0.14770700716443602, 0.10077559524365973, 0.13511843588804046, 0.18333833874954333, 0.30279671172461203, 0.1514530238965827, 0.1258634655706344, 0.09326729007185468, 0.11528025967099013, 0.2372311226903431, 0.12938785306628675, 0.17301660631933521, 0.07427848319733336, 0.08788520830773539, 0.13795700615211842, 0.11594330110857565, 0.12517214782776373, 0.22306142254702507, 0.1648599609372116, 0.1403082372440446, 0.16142437835374188, 0.1597342351751943, 0.08036042458467907, 0.14625758413345585, 0.186787297228171, 0.13614917654664288, 0.13509753700946608, 0.15767086928169574, 0.08907963897311881, 0.24016652646805012, 0.14943455075544698, 0.10106073316907692, 0.07962563135210546, 0.23144861442908166, 0.17057508410465333, 0.13905222077042828, 0.23304898742466207, 0.15323667576716793, 0.1643186891751905, 0.16313234073740823, 0.12953635154952928, 0.179198001241011, 0.13276319049539106, 0.20353773308377113, 0.1158677112130869, 0.13227350709419097, 0.15866840768965984, 0.16853894497598373, 0.15667576703333086, 0.15377146642534964, 0.08186672964403707, 0.13597377305549962, 0.14874311043850838, 0.28892408515657153, 0.094386215111421, 0.12731912455731823, 0.27953111176048556, 0.10240782983601095, 0.14932844757793412, 0.10874191374187508, 0.19263294645615164, 0.11451390361593616, 0.20624139526438331, 0.16532195792082818, 0.23134793515407273, 0.14408443784040792, 0.13681541257087262, 0.16045235067365632, 0.08861067058939127, 0.12379264564163263, 0.1658745371406117, 0.08157318007321128, 0.08567270807801716, 0.17571346563917978, 0.17165021189758856, 0.09186893446190704, 0.2127506298523757, 0.12148526542249227, 0.2548787241140681, 0.11387562980094265, 0.08147612439408418, 0.09307962917392293, 0.18486790989916171, 0.14306437644746997, 0.14082298704212712, 0.10739405864789602, 0.08989879380791418, 0.10755934977843877, 0.1851387985891873, 0.13237818534816467, 0.13197127008630385, 0.13083186751652148, 0.15626321336434734, 0.1387678182894184, 0.1232615934925214, 0.12120480063341318, 0.13746442693856456, 0.1522221455290433, 0.1294395333576587, 0.2050676566338347, 0.14103929962842696, 0.2878896213106571, 0.1559730039368714, 0.18070207698450935, 0.15442444912848935, 0.21170458275704615, 0.18574446770212344, 0.12445852160453798, 0.11153577511469204, 0.11975249711183772, 0.12164842682860552, 0.20164364197802162, 0.21639510929103822, 0.1272069922678413, 0.23213555014902548, 0.17725871094772894, 0.12564726789752323, 0.2892977828460355, 0.16164629870364744, 0.12521260493104497, 0.12382597812721807, 0.20668514403364352, 0.09510952468600967, 0.07722861118494503, 0.14941158343947705, 0.14407313038264552, 0.12139901158309753, 0.09939726517205277, 0.11887329630553724, 0.25822219228552235, 0.16629974658210434, 0.16481540526353544, 0.3143022491806938, 0.13354106085194697, 0.2329187065122589, 0.14223700148924706, 0.15709359138723344, 0.20987467449759284, 0.1917473794592004, 0.10238127722855538, 0.2219728422501395, 0.09737244882290402, 0.09629057945623513, 0.14695380483904194, 0.12839389228892903, 0.11720845701112864, 0.10469405836756192, 0.14089997887851732, 0.10819408426722212, 0.13209329257088323, 0.07107015293572219, 0.14591590891922676, 0.13536853295180107, 0.20545292225095535, 0.11123087978170765, 0.17713573851412345, 0.10355146121113531, 0.073233041311464, 0.11743182526721109, 0.19480492829555468, 0.14497077092528343, 0.18591673023277716, 0.2140340263084058, 0.07984232698236743, 0.17342070237763468, 0.18802835966550535, 0.23645423292633028, 0.12453938218494578, 0.17463443079783073, 0.1630791435919462, 0.16070313721654877, 0.2774820410676541, 0.09405150363642363, 0.11229078540758741], [0.04516070693611138, 0.022154923776284825, 0.033307924806591005, 0.020713079270095597, 0.04530294648101253, 0.06428402352837786, 0.08749203666323617, 0.016957409830103, 0.06287568962321648, 0.05111339013843287, 0.02270731530452688, 0.029931668071977557, 0.023406477787742214, 0.013197313359517966, 0.0161567579338988, 0.04053249399388029, 0.030336411474573038, 0.027750636818968964, 0.04842398868453118, 0.03533695846976292, 0.026549991265299822, 0.09757494118304984, 0.018904203954603405, 0.03474293389327584, 0.03648086563654004, 0.08947438875874204, 0.009009232293934593, 0.06312900042581944, 0.01712250369300525, 0.08204764130735591, 0.03248260296400517, 0.04881377805084471, 0.032261789611150185, 0.09605336799136094, 0.009499200105276561, 0.020686654982367353, 0.04247633101899297, 0.02962265310118035, 0.02525988770949264, 0.020260164258821357, 0.17553211730574408, 0.0047409691145613555, 0.07788480379648748, 0.08754213115260487, 0.03561840385138508, 0.048977537005538904, 0.11565810955700376, 0.012836117267368302, 0.010089370301894603, 0.017318739030029506, 0.026515113197327144, 0.03025663873901771, 0.034015935605331775, 0.08532155635616473, 0.05165744279961913, 0.0503145328031913, 0.051016993294920654, 0.016454959573644786, 0.026225005276501182, 0.09649491808827847, 0.06056865031320242, 0.04296671539064377, 0.055155725849251595, 0.029525141599738312, 0.031838407289356954, 0.03814786912933473, 0.03276584865224939, 0.1041698090792183, 0.053845340115649086, 0.055501760103769844, 0.08166874954176527, 0.0570875391243927, 0.046181204999166156, 0.09518869987298405, 0.04095111124878449, 0.033888956531882286, 0.04951234681591873, 0.03299631854338992, 0.031924640061333776, 0.041895333767658284, 0.0683328748169926, 0.03629496291039452, 0.06324705457495106, 0.01586779052647011, 0.04716473165899516, 0.041422714974971554, 0.06995113596560494, 0.00968042969508397, 0.07752744676244837, 0.03292899090616453, 0.004783062294365898, 0.029195817638068434, 0.05421721451585332, 0.03897926604916011, 0.040640749878460364, 0.06302977671786662, 0.016213076887652278, 0.04536171308568409, 0.02784882247778437, 0.05240024165100148, 0.022475351541933995, 0.03506358382442305, 0.03539762497248669, 0.05416855644134264, 0.014016569700963316, 0.036851590904857845, 0.033778191709350196, 0.0358826428982279, 0.10642173985439925, 0.006710384857855858, 0.02458429966692723, 0.04686887616351728, 0.07404271963863604, 0.029607858028142687, 0.08043488067003988, 0.019123908395187992, 0.008635792201535116, 0.009884880367486228, 0.03710845635542947, 0.03071076033877269, 0.04203245584522525, 0.058660505324481964, 0.08239342275285914, 0.03473542623161789, 0.06745493039488792, 0.024842754749941732, 0.05487087137636639, 0.0433309480638033, 0.12430396336581438, 0.047081863928225734, 0.03381578747423426, 0.04445193387988595, 0.022533062860489856, 0.07634076890685866, 0.05846607220929958, 0.05013757415356175, 0.10595513868235773, 0.04212258608951684, 0.02152076193822488, 0.040212774859561075, 0.007631326443515719, 0.01916236409376706, 0.029177416206127214, 0.040101113714157574, 0.04397390267601417, 0.012916578524445575, 0.014187243556784046, 0.04816661761592954, 0.01729547677020873, 0.02902236384069247, 0.040389216399841735, 0.06517486121024817, 0.068444769619213, 0.037160335829661745, 0.03729451612959947, 0.07012991024361503, 0.027079061161906972, 0.018562387014108322, 0.05465618289646603, 0.06006353790120733, 0.02298542054279918, 0.08759486098443309, 0.0460340088653949, 0.0787257461718494, 0.024452637881040577, 0.027499513197389823, 0.028355840533491106, 0.08239372918802886, 0.012627926170675745, 0.032031739153148185, 0.04827116563495609, 0.029353089743263783, 0.02424459521388335, 0.04564695060253144, 0.037942760578927495, 0.024711083387956027, 0.06517121463172859, 0.09193758360080181, 0.029871518678602674, 0.0533640300554614, 0.024224809078018994, 0.0320045200491985, 0.05746746893912073, 0.024510523484599207, 0.0564804106139608, 0.03400505332636737, 0.04225029677693402, 0.0114856785418646, 0.07526777083835295, 0.06844989474742644, 0.03170884075394321, 0.026692276775476434, 0.03373830534157253, 0.028034355566506425, 0.040288586920547875, 0.04878949306364502, 0.037879136976816004, 0.09565038276055167, 0.09208025981581981, 0.03414765293259294, 0.05413030567128332, 0.020836505610796235, 0.027638226822619478, 0.037728033794630925, 0.029750059268647627, 0.02110917162480614, 0.07405790350129528, 0.04279901108313953, 0.042066067952903054, 0.060665024174076904, 0.029235460772930138, 0.024948848351355524, 0.021240555703820243, 0.03088917072501875, 0.035445080288956245, 0.03651719352590942, 0.05100606122024117, 0.03919457889071876, 0.02998778592765091, 0.0452295973927023, 0.05434176892102246, 0.03094478104744227, 0.03781575086196104, 0.06803718786085806, 0.02109259539734452, 0.07216788798330293, 0.05824204894804186, 0.03945450869298751, 0.012973792843460556, 0.059145534741542036, 0.01794151297109502, 0.06525215182092882, 0.05194167291084605, 0.006759469547579366, 0.027975521929141496, 0.04829849199121518, 0.10037231123856, 0.011758008434797728, 0.06365688863180338, 0.02297658180337279, 0.03558810890441941, 0.02831835010569663, 0.03822523251836819, 0.11410901848707469, 0.02556468536626668, 0.02802341200050808, 0.031333153151095874, 0.018858755788495465, 0.07333640189420793, 0.1045970869581065, 0.023811629132157373, 0.045656319857845386, 0.03135143775462864, 0.04939461825415493, 0.017988776765583504, 0.005337354678270077, 0.04698575819812475, 0.02518169119984152, 0.047953311924732504, 0.04843737990144761, 0.0555236587270854, 0.04314388088401287, 0.0609970007151846, 0.007935388655882449, 0.01650015684595752, 0.04881951221895795, 0.012082375807597513, 0.010950282674222704, 0.06060695087897682, 0.060418412810371774, 0.06595174331338176, 0.04598949149611496, 0.04959312695709448, 0.04054553664079116, 0.020028510761837807, 0.06466383459947764, 0.050641150559268655, 0.03532859278962978, 0.032223090679655154, 0.03563566381231912, 0.061688486997398644, 0.026272293968847202, 0.07153254062418016, 0.04014082388171265, 0.014148850102848826, 0.027489444886844967, 0.018122642969472275, 0.05042507929066497, 0.02365808595993346, 0.014519591650535024, 0.004173192625579935, 0.029239092029691226, 0.03927237894986907, 0.011206967136522215, 0.07477785761077559, 0.024207213953618082, 0.09331577577658239, 0.05410595556661006, 0.029423046977289265, 0.043361986116055524, 0.07912794999297589, 0.02385054639871082, 0.022172252685132048, 0.04938619511742746, 0.047702674768985286, 0.04262094926689902, 0.009623869423634343, 0.03652086691750634, 0.06068510716901191, 0.06156709653535678, 0.046664587327189026, 0.05516430220356392, 0.04940325206506157, 0.06086543277506867, 0.0133646767578959, 0.010387624610185383, 0.11880679987370969, 0.05103911408373425, 0.048136690391167525, 0.06641250689544025, 0.05601186357859162, 0.03430029595150583, 0.05805027798839635, 0.047254566959435904, 0.024195921817614187, 0.0254690277976014, 0.05946841015810928, 0.010565092708284577, 0.054537247746221484, 0.022620140244403196, 0.00988152490237788, 0.03659079925367429, 0.01651033240881178, 0.02257450821719343, 0.02219515105318879, 0.034092349045339136, 0.0072528296920110384, 0.10565569023451499, 0.02893138706924454, 0.07861180591487116, 0.036563534184449145, 0.027922537373078447, 0.018396687941745888, 0.03973112389024708, 0.03854989291979902, 0.011162361667130985, 0.08324164296350173, 0.023557582885147105, 0.031150626957476623, 0.02366153144037291, 0.0036896771897802195, 0.06656289761585575, 0.1139151905813525, 0.21284959309043425, 0.13672585689252423, 0.1691715190968206, 0.11821073750334403, 0.21621995094803073, 0.13295535599031758, 0.08568829030639703, 0.24214407519227077, 0.1156366054689692, 0.17044397581729198, 0.07477234177772077, 0.1337785787519909, 0.15467805487494315, 0.12827864968247954, 0.17945689299414236, 0.14949015341699123, 0.0847808208556906, 0.08117198748814483, 0.12727165008865057, 0.16552310196622727, 0.23068660209255837, 0.20811405123001148, 0.13928901854782336, 0.14482866161532942, 0.2248304421382566, 0.11814020378815553, 0.13330118340109626, 0.07953725544916046, 0.21954642728932444, 0.2508794387141543, 0.14644709896416436, 0.12801373647826333, 0.08321859903873936, 0.10870288922301224, 0.10227455351982387, 0.11406977946359305, 0.13113696969324543, 0.09813790089420735, 0.11368010118002854, 0.2512305214880936, 0.17224915475854952, 0.14129981548795778, 0.1995828041746732, 0.23890488690906958, 0.15361771257894655, 0.1650764267410963, 0.2239641652352387, 0.06436634733672104, 0.1534075899830749, 0.23298521826584495, 0.09515169016536205, 0.09251446312954349, 0.16490974133053135, 0.2539482030777201, 0.13815114815388957, 0.12241873589734878, 0.09272095446865405, 0.171739170027356, 0.17152180023972066, 0.17637487530948656, 0.1351109588698995, 0.12633339922514655, 0.09417905727581632, 0.09452964975348405, 0.10910776669099446, 0.21340024176864855, 0.20278109868447627, 0.09364052044768488, 0.2230603500239311, 0.2809551466376551, 0.19087256833670602, 0.20611808575209112, 0.19801610840424416, 0.1854007240504988, 0.10421700775623323, 0.13850563235821264, 0.1409928440566986, 0.17505677507048653, 0.11618017549476317, 0.1505443976531106, 0.1220271653766113, 0.1499452556092893, 0.12370284481514847, 0.11701651368170016, 0.16232575740545027, 0.1738660599315359, 0.1409140595745656, 0.126412513125087, 0.1992713434681777, 0.1334204786126652, 0.14878423403828375, 0.14941798793452402, 0.1638264317185648, 0.17468487002676533, 0.1651551039709199, 0.13996647009926458, 0.144713610530861, 0.0880694447926456, 0.23128548366648538, 0.11487742765776573, 0.18155811895285884, 0.10078061311956375, 0.18848513192947836, 0.1678833269303845, 0.11806036210468701, 0.11384155421007065, 0.1453538148874237, 0.1379442584490584, 0.10878702865973597, 0.11787195044058947, 0.18005582053334485, 0.1740022243991975, 0.11022691389605885, 0.1384104995597755, 0.10704885942921524, 0.11123571379650986, 0.10439689286173352, 0.13161971233785152, 0.13707111739823896, 0.14230720578662812, 0.1458145861303614, 0.12668030681989847, 0.0828654401665253, 0.2294067756062554, 0.12881564667388318, 0.09827528344166857, 0.1939567617110668, 0.2879171698324142, 0.11927079634680865, 0.07515491076534794, 0.09809627933728118, 0.16638947079979605, 0.22951582056139747, 0.2481021861275358, 0.14497512230469337, 0.20870266722575312, 0.12844545766711235, 0.11422240716074744, 0.10912206189166154, 0.19312906499591567, 0.1721697574060771, 0.14365725189207063, 0.20528033796337344, 0.10696123429243604, 0.07671609070272216, 0.22924683176942412, 0.14242539783158611, 0.08835903368890287, 0.11365524162688564, 0.13074330775247467, 0.16990866421932177, 0.14451127138830003, 0.12421726519542357, 0.07867359856684362, 0.23004894114790425, 0.0786926741561582, 0.12492644044780925, 0.15161073075667506, 0.14307677175008482, 0.1282725975878777, 0.1550608996542231, 0.08830520835134291, 0.2840361377644924, 0.23728251186830385, 0.204947013107519, 0.11611725669354202, 0.09868827378076893, 0.16156858674460844, 0.13143497789579053, 0.13857407465336785, 0.0947299127977702, 0.16084988901932395, 0.15621827464670907, 0.15025458659135527, 0.22760893578731248], [0.02681643281492495, 0.008918649100157763, 0.06804978234633323, 0.07254305656158155, 0.05394028522254479, 0.0601031752904096, 0.03523839359742499, 0.031577299626904635, 0.004648197303345848, 0.033420903623224266, 0.0277961386112316, 0.05906581180170179, 0.0965808654925035, 0.07389433606858216, 0.017031990404751514, 0.059941404333878914, 0.03214407254070525, 0.07153149108372389, 0.07935989843381029, 0.044021798493040186, 0.04185224515235713, 0.016718239095362446, 0.0731230770508128, 0.03704356487780329, 0.03610442152186748, 0.025641294158694726, 0.0382299401286629, 0.007293788104077742, 0.04389962279087594, 0.04359805610992255, 0.031038408483108206, 0.016961935494515686, 0.033875423588699875, 0.05613688529739457, 0.017054611065935706, 0.0212597519519829, 0.0698315189971078, 0.05125682095005628, 0.02098942059092224, 0.013776192377742021, 0.07407520176662553, 0.06763162857462322, 0.06699057386046456, 0.03722107511073832, 0.06832842384615252, 0.0393312489764104, 0.03229438282188869, 0.0920708445952304, 0.02004129676929405, 0.03225548470753335, 0.030191691720017025, 0.05360017282768123, 0.08436205421364115, 0.015821179821937075, 0.04007428531504927, 0.06481888313447276, 0.06425858940929174, 0.04197866881206151, 0.015189896559252616, 0.027912281370992144, 0.05687190069546623, 0.048093712858615384, 0.0620616369339968, 0.03300092273181485, 0.05253829069495682, 0.04311168986943461, 0.04985681442063182, 0.011061331906896687, 0.012404469814481995, 0.05755815076671782, 0.09097641138660331, 0.06822522414187271, 0.022249730987354152, 0.01983592391855294, 0.026569765909845312, 0.030241215473882137, 0.06039151546335029, 0.038732317606768304, 0.06160976380229958, 0.03688357124525694, 0.033469481258502895, 0.011241861483863285, 0.06069060384986862, 0.09973502567698879, 0.05073572411352108, 0.025354478500723362, 0.05712928708582636, 0.04343085742044834, 0.01130618318359578, 0.01973957112509637, 0.10166132311907508, 0.07426072527924854, 0.050476246303127664, 0.01320097430218612, 0.019952597194201043, 0.034770187471182115, 0.04121103722061362, 0.0480022419604563, 0.05121922135473259, 0.04777338468439637, 0.05304101291262815, 0.06283697536996295, 0.04588469449851302, 0.06977628405776716, 0.03066557838821844, 0.03675761106874674, 0.05626468025448342, 0.030021859603303096, 0.018598404637868368, 0.05530620850021801, 0.04879347289041166, 0.01758276548747334, 0.03281968931156782, 0.054017598815863176, 0.04471481695110279, 0.08400796837503872, 0.005131499670941624, 0.0469352078864411, 0.041434547202962066, 0.034564454559116595, 0.05082655149782377, 0.021031633950769905, 0.02963630287277122, 0.0702624511153948, 0.018933428293694893, 0.01638425348867332, 0.015532732396686991, 0.021390904289399906, 0.08002210483555833, 0.001389784522489795, 0.0839489029960767, 0.008702348005176793, 0.007883374158653521, 0.008641485192422426, 0.019285870873699748, 0.03068947458579656, 0.026225085715733232, 0.03560204021332245, 0.04664641189118547, 0.07461468088290385, 0.0762603986227224, 0.0280376976250761, 0.03994621456630769, 0.06852949894363843, 0.030804631007354588, 0.00960543639056625, 0.06177171478949248, 0.027209386124365756, 0.03551203254309874, 0.02320032544253815, 0.024369980824450334, 0.08258744984144166, 0.0348657914136927, 0.028692890491877353, 0.015174522132222212, 0.025647263898844683, 0.09779554386172565, 0.015345444966618334, 0.05703751358293718, 0.008711479773234216, 0.045878872230288484, 0.046196522927212144, 0.03558955298015668, 0.008476569444962568, 0.038813534418060895, 0.07665488793845139, 0.01891019476217128, 0.007372288176068857, 0.017317446256657282, 0.0393388370773004, 0.05794479534210217, 0.03240367675560617, 0.060802640378355026, 0.024643872579139088, 0.03504930777595409, 0.03416658679564153, 0.046104791559158795, 0.06171940247558298, 0.008406621787036139, 0.01721605068943914, 0.0488282724343721, 0.03653133933943126, 0.052139848365538546, 0.03353856323707489, 0.010561110008688224, 0.047861366052060365, 0.027160473325620257, 0.033805970057484605, 0.04743210400544828, 0.02569715729013326, 0.016155325349480394, 0.05276810941136172, 0.02825517274980103, 0.045432836688574285, 0.026581601968275446, 0.02229640106370132, 0.0730239988995656, 0.05825298102272134, 0.0628761607672899, 0.0511397933587432, 0.06486631163786497, 0.01751461622094916, 0.04484843800685579, 0.02019185028339346, 0.05362726552712341, 0.039473136120866385, 0.029570289076335972, 0.03513884430210437, 0.05021802487693006, 0.045368339746229114, 0.020467147809423266, 0.04938499618982596, 0.010708295608750515, 0.02809080092476741, 0.01976054469724336, 0.029376846129795717, 0.02830119356663237, 0.05279380783078171, 0.04349144731437968, 0.052750883924384276, 0.04196133607277467, 0.014131336375289868, 0.05437705876125444, 0.024949066686413945, 0.05876507249570662, 0.050619033600894675, 0.025294834725378502, 0.0327133409859192, 0.08330930384897417, 0.04797750498138128, 0.03982470919107718, 0.037269216075900106, 0.05290291790339736, 0.0570948054683545, 0.035481331569533196, 0.050681611492989526, 0.048732741270214326, 0.01044086101765354, 0.06729911577196852, 0.04268027128531568, 0.07649060038308944, 0.01790728416263817, 0.06645821170100281, 0.009992438154445301, 0.03782654504081415, 0.028703299711548516, 0.038379062973563714, 0.009979690451385274, 0.041239531860957225, 0.020902659218277664, 0.031851482495004614, 0.05657289657861956, 0.022409682485064673, 0.056664264054908875, 0.029583864154354222, 0.06251308105645642, 0.02552049741479418, 0.08476029736019912, 0.02860874913993382, 0.02932910161513475, 0.023040040696580565, 0.015019756092149165, 0.02737776458924336, 0.09727778333810069, 0.08909841578814293, 0.050547729967342275, 0.020091107806130763, 0.0495659806314976, 0.02711481831577276, 0.016649595702127103, 0.01625413153951447, 0.03553763137108857, 0.03664352525506289, 0.06148118743552797, 0.020970101768691695, 0.04800425677169715, 0.02535273373547581, 0.027107099979935635, 0.02717219447086175, 0.019790504480742162, 0.02766682488483287, 0.05603751220229653, 0.0188101704923376, 0.02370943491827817, 0.022685744183798952, 0.04685512488527645, 0.08480368858023037, 0.07657620304774854, 0.005152338220091958, 0.036059498125987674, 0.02632450477610673, 0.0014491644763057272, 0.03395885822453326, 0.033242949059293155, 0.03398858243599534, 0.03498789433750414, 0.03231218670524898, 0.017356036020623102, 0.0021265798779730237, 0.09110523673195033, 0.05711838565466385, 0.05237411422234389, 0.022700487545901732, 0.024590181306965893, 0.08498193425757271, 0.042315215067637545, 0.020388100942176197, 0.029430006886081352, 0.02164045551551446, 0.06287332624197006, 0.04728711803533858, 0.14250033655233924, 0.07463768650326999, 0.05232304297087174, 0.036516975190851, 0.04556870238194543, 0.04864703135324582, 0.05456668084427234, 0.03772963491839267, 0.049172414451717376, 0.07082557936589565, 0.04471508891231591, 0.011661135659162557, 0.02110851470441107, 0.023890300616321546, 0.0758151866255268, 0.03393096496321021, 0.020240648168950312, 0.060255649769979144, 0.02203145721596816, 0.06979958845242377, 0.008459307568808718, 0.00986113642988306, 0.06276110968282146, 0.06564972081011342, 0.013018317873619739, 0.07702657081667455, 0.055760632704703085, 0.034257134557851864, 0.03646277830064778, 0.01581074666201828, 0.03790632926768834, 0.02785469071128436, 0.02430509892292321, 0.00906145076207336, 0.016239010879108985, 0.0312942837650377, 0.00831822194384351, 0.047536663515793706, 0.033734275719090816, 0.04598382244547529, 0.05677206028673438, 0.1161426142038357, 0.2126786635527688, 0.11453359973646941, 0.14981328930345275, 0.15956949562795703, 0.09788180536199963, 0.17625311329480142, 0.10296322059847655, 0.07368846526069027, 0.12551734704644452, 0.20329146645963195, 0.11974010947010211, 0.21977990024512817, 0.1503257868030379, 0.1068370207963932, 0.1102053025557149, 0.17928806253738944, 0.14854107773111713, 0.1362766688990016, 0.13143019750714302, 0.26602556388224324, 0.13392438060573994, 0.20164506690156078, 0.16272536418851347, 0.12253773233462727, 0.06750261170729514, 0.15734335137230737, 0.1522443927223644, 0.11693019855527148, 0.14293175130601854, 0.14849920336517597, 0.12400135097484435, 0.14136663367671354, 0.17910004923901252, 0.09534271418928139, 0.12802469153558055, 0.10429075137982446, 0.1511012209999946, 0.07572802114150218, 0.05724390150017797, 0.13922019320870602, 0.12853763336616178, 0.11757657758050388, 0.19872179795657435, 0.19004459582990219, 0.16703244839464465, 0.1603380197118367, 0.13872592860171873, 0.14049459579250506, 0.14258174105517327, 0.2522321508055733, 0.2694748287960407, 0.3108921773251026, 0.17807759765175082, 0.11180230476442846, 0.22187898115765667, 0.1709707685175442, 0.12013691237136243, 0.07907823088669008, 0.28747881432214095, 0.16685436359576641, 0.10538945935906903, 0.17496751050554937, 0.17205300560641676, 0.1426539984681914, 0.138535617039569, 0.2047814768288405, 0.17918926783867423, 0.17081194316908238, 0.1287005189806223, 0.2389498869137418, 0.11720718530517434, 0.1237023315362392, 0.07353809752291249, 0.1296427918057288, 0.1495455722174337, 0.18731361495391016, 0.14990174181519017, 0.23874436084541584, 0.17271521200816478, 0.1105462270037782, 0.15576300391506764, 0.16222797394279512, 0.13424964621663094, 0.12353782181537921, 0.094655066007568, 0.23272992712595772, 0.17584838904440406, 0.27317276585005945, 0.12306956589342126, 0.1629357166107624, 0.1414223282688087, 0.1281157793897775, 0.1896674660665374, 0.14431035716927823, 0.11013237864620264, 0.09563371268731934, 0.3786763723098463, 0.13882608693693915, 0.15928084901984663, 0.2081062371331838, 0.11112619386685473, 0.14227893714222217, 0.11063722292742423, 0.10615733992909232, 0.11467077544019108, 0.1859032470853098, 0.3521556034684182, 0.15991380618464562, 0.14957906558148323, 0.20275119061191238, 0.10360135651764371, 0.0731533068803049, 0.22817237813386226, 0.12355216298132174, 0.1753295943020813, 0.14458699151873589, 0.1305683485923275, 0.11414022890910988, 0.14193785947657403, 0.17165290852708204, 0.11414026721350609, 0.1064057132950233, 0.1852817965611335, 0.16216029773556417, 0.1321880882906337, 0.10548211769351076, 0.09226268833322872, 0.1698893588036299, 0.17316348069617826, 0.22179613640952497, 0.08644400540018275, 0.16534242779016495, 0.1183895271031126, 0.10227750295833235, 0.26454223379973446, 0.13178996771814364, 0.24801685925452943, 0.14010407481222384, 0.2252956107258797, 0.10983374991243887, 0.14493242056379396, 0.09647489254993778, 0.23596015218044483, 0.17064547226313623, 0.16637267815249582, 0.06909356948228614, 0.12009640164192646, 0.10955339237566918, 0.11114987364459424, 0.16892577341246992, 0.12602833535281882, 0.13021535059857753, 0.0828940382287387, 0.12433780146942985, 0.10906121152783595, 0.126080843019149, 0.13934607677642377, 0.16280065530971174, 0.17729896120727065, 0.20263189540034343, 0.1296441707639925, 0.11398291275385888, 0.06738435837530321, 0.09843724975061995, 0.1631294908903299, 0.0991860087660532, 0.15306914765988627, 0.12135621791164722, 0.14107699115430156, 0.14825806953012943, 0.11942593681235468, 0.14247019865339802, 0.1456740396397729, 0.11204227414583007, 0.11632740227205139], [0.05922423495400337, 0.023424863897924943, 0.04584473535238255, 0.015581272685179308, 0.04692467800792187, 0.01522953777889451, 0.008314461409745198, 0.00622578636525319, 0.09889465786757008, 0.05582366258867326, 0.04613057807869008, 0.0639927339169287, 0.055887933535080765, 0.11407452920872359, 0.06774882470527965, 0.0513275538481051, 0.08457711807662442, 0.019002516017926317, 0.016085722431119893, 0.027443117634843917, 0.03762682591895423, 0.07557261254518263, 0.031240094535713716, 0.10411815943136331, 0.03194466176923485, 0.09031829589437093, 0.02374207983995157, 0.011563676826265312, 0.06775154431741084, 0.051453625107364315, 0.05347408241622391, 0.047905680408040364, 0.04962421097462216, 0.014618203445758312, 0.05012849984209865, 0.039170933586935845, 0.044006618460820573, 0.04216618798372727, 0.033386801219274925, 0.06105206711518188, 0.06435710065547498, 0.03567406013908406, 0.020178537590489275, 0.009481711275575143, 0.04176270479576723, 0.017530874521922202, 0.013255062024860133, 0.010231796580727303, 0.022240922891444737, 0.04932747447803136, 0.029224289295774315, 0.033164524638484565, 0.08644107128343276, 0.01427609347663219, 0.06757761937596145, 0.09953057213175683, 0.01998632038462787, 0.032035885604038354, 0.022243554403464642, 0.05187729088168952, 0.056725627697643735, 0.001654605676453831, 0.026086755134465716, 0.026240118276027423, 0.03564150906318138, 0.04520324013766743, 0.030369885686424472, 0.03561821999028325, 0.04623905229832857, 0.02864408877588088, 0.01728128116097181, 0.022239517120103684, 0.08716079556653578, 0.008190332183374033, 0.009030171392124989, 0.024966175344982938, 0.023824826911872914, 0.08948119161950965, 0.041913972686856024, 0.04341566589690986, 0.020523022432180665, 0.02880240467587306, 0.02771036740722916, 0.021711515916150906, 0.02670018280285501, 0.02011874059755956, 0.0512142111397078, 0.027611992141652494, 0.015440159289526845, 0.025365288001334956, 0.018539860198694854, 0.04240986906112202, 0.06652221068619721, 0.07195110042249003, 0.057309785061666084, 0.04093595802964222, 0.048611446569163, 0.047611782267209024, 0.022355345783815272, 0.020422299107116078, 0.03511761983616218, 0.008250639582383297, 0.09083221065661601, 0.024409597146234686, 0.006628733291666234, 0.057766067029367534, 0.03465487591681942, 0.057393740637287985, 0.02162021547255497, 0.044149735176395026, 0.06202209913622468, 0.06050742456629392, 0.024755639061632178, 0.0201131098513161, 0.06051058467898158, 0.02792413083596095, 0.03621050554718222, 0.03238666960368714, 0.028724144963968187, 0.06816351575957191, 0.060718263454374775, 0.040208025114430536, 0.041418432543474826, 0.04123192460786912, 0.03933676480946522, 0.058221678670135245, 0.01985027466059452, 0.1166577164023634, 0.0038649593038679736, 0.0431870537689857, 0.06992744086610694, 0.02782379438529813, 0.011559798506148642, 0.03872790877076407, 0.03320567888177691, 0.030505866292984258, 0.027540184805289875, 0.08485382903487453, 0.06952788770919846, 0.029055652276222265, 0.08311641823139884, 0.07547525809176507, 0.049876207936434984, 0.016452797290478504, 0.032550654554319, 0.03220365885945578, 0.003751703019764635, 0.05413975919626894, 0.06457185042240927, 0.038308069605620644, 0.01743103219797054, 0.04005068214610219, 0.0668653874327579, 0.04444901508489444, 0.060997858733659795, 0.014122974525596348, 0.04823113371047282, 0.011222512975725676, 0.054873119844424154, 0.04061413598397086, 0.06254638672896451, 0.06861586003534256, 0.015131344459199858, 0.024377724058145, 0.05854651527178865, 0.03011405253933082, 0.030796746047393932, 0.017013094846099135, 0.010054141748696566, 0.024387863231822852, 0.02042462801440589, 0.06333063093705044, 0.06770633746899905, 0.026265711358357823, 0.05513340587757769, 0.04177320020032987, 0.0648221313472717, 0.02437256637119478, 0.04542115767816863, 0.01974425383753354, 0.013310157153154574, 0.05238158357960563, 0.12380266607168222, 0.0473519099215346, 0.06268274271860719, 0.015478533591263959, 0.033957942749463746, 0.04234451026986203, 0.007023397850007901, 0.06624641903345624, 0.06185173267318357, 0.021130714017236908, 0.0977280438547173, 0.027081200462435524, 0.03289445566253797, 0.030400889264720104, 0.0474156599281536, 0.03221227351816432, 0.08210654580785383, 0.016731940577888203, 0.04789884690375579, 0.014435977941649336, 0.06105556813699584, 0.05401244687457239, 0.08632643388644343, 0.09586098033093637, 0.05657879545563652, 0.05161538457257613, 0.05488197965126845, 0.05341452674099034, 0.02367655059412843, 0.03721681566187932, 0.01984734628950396, 0.09113849260874334, 0.054083424920756976, 0.04143350915382466, 0.030019938637832963, 0.04394516671797441, 0.018865037709474564, 0.06515764721458958, 0.031326716097312114, 0.06619859216434341, 0.03469209246818097, 0.05159954187430201, 0.03411626247989555, 0.020519778049821337, 0.03802507672639143, 0.028091390812469107, 0.005636307084181857, 0.06667924338891622, 0.036033343884252736, 0.034287816379219294, 0.04086463141345209, 0.06118521702686145, 0.03856257550538548, 0.06415222576188465, 0.041049641647165826, 0.09550990521787636, 0.019479930521019047, 0.034851917561383984, 0.0566871049663713, 0.031691632503944064, 0.04800661249206432, 0.044964879540906805, 0.02632718033818228, 0.05684682663770453, 0.042773829773068435, 0.019789625394849047, 0.047841735049000675, 0.01115715801490531, 0.06043304508972553, 0.03279681009570918, 0.02317121793185511, 0.07380765321994982, 0.04245047938198813, 0.04011520207108509, 0.051181081667422294, 0.01098386413838354, 0.023764652620640495, 0.02391768442917495, 0.025904349599694534, 0.07848024563563448, 0.057867320870319684, 0.0882817967043769, 0.050511919187321785, 0.024012068376666116, 0.04008730497932242, 0.05337463654277306, 0.025990953924314632, 0.05803006092807459, 0.015798620447786828, 0.045845853840751995, 0.05931532663863994, 0.08096109114346967, 0.03272662495052622, 0.007117061196045289, 0.02173215240961121, 0.05526740614685321, 0.03055599908674917, 0.027647741634639043, 0.015478121819004658, 0.0388918171126035, 0.08159154320075628, 0.03371273715709967, 0.018914584445977406, 0.028376272098431667, 0.0356024615616808, 0.060688002981365695, 0.029564206338217183, 0.0640202058298934, 0.08882575743501225, 0.029092244465925524, 0.011156376605222543, 0.049262824318101334, 0.02340598366103105, 0.07803448971601264, 0.021232837367983117, 0.07517792404659333, 0.03750189613070219, 0.057188046029618675, 0.024838962614716544, 0.044411269932865136, 0.027547866751950596, 0.012857012315503052, 0.0023259566542917806, 0.02743127391553454, 0.08942653124611225, 0.028434337732652505, 0.03522216402474911, 0.010483290797339813, 0.04734752023772848, 0.031952020043747566, 0.028458705074304057, 0.05860076961858619, 0.03357652289372298, 0.057608306543120456, 0.055421454937107144, 0.01791420193659442, 0.06820339829690995, 0.0316135892118778, 0.054350283988300836, 0.05078589904212183, 0.020269131317975062, 0.04513865892565058, 0.04650573133521023, 0.029962148795264865, 0.025969444090620648, 0.02622333712004606, 0.050520863263837756, 0.038405914355309746, 0.022630453703083822, 0.021078505125197194, 0.037379268436662616, 0.01730962066851076, 0.06134052220131121, 0.04020947302060743, 0.06760159026711218, 0.06549305582959807, 0.08124503397172497, 0.018899779796840686, 0.015226187101835686, 0.03907034624247782, 0.033893422824480844, 0.09233073992354256, 0.013842645717123825, 0.015605950292440192, 0.04759859023315292, 0.1027264841081154, 0.014093380549081392, 0.019547731217537678, 0.049673573850023175, 0.03856104715997654, 0.16679963427445582, 0.08063775607414785, 0.10664472506651956, 0.14399408543061826, 0.1423669453229635, 0.24425018879194416, 0.20517011323282797, 0.16423097210786036, 0.13943318097341445, 0.13022373160046916, 0.15285536316373657, 0.22161910881198224, 0.19037458054240675, 0.19929683887429778, 0.2691445836136418, 0.10704887475097373, 0.1453830488026142, 0.06371771601299125, 0.12767238302096245, 0.07427686675181312, 0.10083447676151992, 0.1942782888128873, 0.18697868131341475, 0.17861992661510745, 0.0907381427203936, 0.14020337512896908, 0.11950602364395896, 0.153523545051294, 0.22536275067156364, 0.18658170987281109, 0.15177186969066822, 0.16605337270565573, 0.15787383661635462, 0.06688742012146019, 0.09402551027315278, 0.25877199826701996, 0.11448353589061769, 0.16120919957756996, 0.1530423805478119, 0.22252402718990083, 0.13467150019301524, 0.06117392872129718, 0.1523493774115078, 0.14961078162154845, 0.18994174086518828, 0.1616084386384295, 0.12149045949861889, 0.2827625625556515, 0.11047002423795, 0.11064631639108544, 0.08688091300427915, 0.05207697169915323, 0.19642601630860762, 0.13730111231486644, 0.17030591145157817, 0.19645641467744307, 0.09541921572940004, 0.18592622972303824, 0.12248039065349488, 0.15544264126689206, 0.15718288659568758, 0.17134348561446514, 0.08424291221965706, 0.11494945524440658, 0.11979362071161309, 0.09667454272388451, 0.14266588815277623, 0.16318287189689376, 0.08356036618351938, 0.13019999819657496, 0.070103058861869, 0.11793838558538307, 0.11121253963680038, 0.06491230755683876, 0.14019556103214142, 0.13773444228835646, 0.10057281943098192, 0.1808510964075404, 0.10020948691113342, 0.16870641179623144, 0.1209320120453354, 0.09106925358214686, 0.13520431434435232, 0.08247790692914879, 0.08573780256894328, 0.26862042625584914, 0.24564771702693355, 0.17280413949441525, 0.06264320109039545, 0.07792268684434314, 0.14630241559878474, 0.22203298015219552, 0.14142571437743404, 0.14695781913976516, 0.13170064186617253, 0.20292852464462482, 0.2560838570277537, 0.1704607684645922, 0.14097441198124042, 0.1790180012223221, 0.11593013205715727, 0.11971033163248532, 0.2632674022066978, 0.1902665774668417, 0.07036126113586849, 0.14481536232896391, 0.10533493688149799, 0.16115736606861317, 0.13507087714970112, 0.08889491219193706, 0.1851786198394914, 0.1366124145926968, 0.14966978571347653, 0.15909683470043445, 0.20993885734388906, 0.12335756898767526, 0.0874512194986305, 0.19540578637632633, 0.100391999698214, 0.20254638466623523, 0.17656365469578775, 0.1292808918702987, 0.11616689919103539, 0.14299925897390614, 0.28082953886159007, 0.17108347537296434, 0.1593987499513934, 0.16099254991258347, 0.12086424390755354, 0.1373033952568808, 0.10958916868173307, 0.09500247155947071, 0.13543735829091844, 0.0686733166296636, 0.10818674514490752, 0.1852606831779403, 0.09699042375770309, 0.1203954517240486, 0.24078799231398493, 0.18081771029580027, 0.22049818428293352, 0.22791780711662388, 0.1904198716604902, 0.13449719986848294, 0.14569115404400135, 0.10952783568251519, 0.10701197229566113, 0.12722422158525837, 0.232355923001324, 0.11686647536172984, 0.11617320409465222, 0.17868524327153162, 0.16357867888385252, 0.14575475466347512, 0.13709046877920628, 0.0695128953685203, 0.11876339333191996, 0.13201455405402568, 0.17676916544235524, 0.1926258371602143, 0.12713036815365478, 0.140243380240375, 0.15181950503779998, 0.10290661436175147, 0.15248520480048272, 0.10806880590896453, 0.137852557724522, 0.1476282380040615, 0.11222628846524224, 0.12677858057882518, 0.14052591346684964, 0.14197172056282722, 0.17863483468611396, 0.07786133852336677, 0.12992253647215907, 0.12633407338251992], [0.13139135684938202, 0.04014195386140097, 0.030935526705316962, 0.033570382699009874, 0.04451810472434567, 0.02475425435770904, 0.011654115420946432, 0.01385411884139983, 0.07275247435656286, 0.03381012225403421, 0.03993072426847873, 0.023511676981504408, 0.0038546805585464167, 0.06349836205763203, 0.02252551306399607, 0.012365761306887914, 0.05950370765922051, 0.010109129624681608, 0.0650292202349632, 0.0285772284522893, 0.028266030130907897, 0.05471321814242871, 0.02841856015185195, 0.04002481901777848, 0.01523409121399445, 0.019501915329226086, 0.03359592790084501, 0.04435306257237831, 0.05270864949711869, 0.02797807300192935, 0.05701753017943233, 0.01700163991641133, 0.020508983870968223, 0.03411489501295071, 0.005949428765058157, 0.009524940659532384, 0.035753591556943236, 0.03165168676435227, 0.03152482834975085, 0.055408645947013176, 0.05622526120033957, 0.048535351055644216, 0.024867568337809176, 0.05794207189953136, 0.024651315123323473, 0.03186676211865439, 0.04455037234771637, 0.01757391334150828, 0.0384987220768967, 0.04081360612725539, 0.019383558575364373, 0.1610236990475847, 0.05662705899486619, 0.04122757705889883, 0.02162010247458614, 0.0521139239501809, 0.009317972430688961, 0.022541976293488857, 0.009793446816113448, 0.03601334515898939, 0.10999075963252014, 0.05028439873468973, 0.015367636618564929, 0.04448952964477001, 0.045802945256113045, 0.0325556111431891, 0.11488399303127682, 0.020326614725373445, 0.04450694665372853, 0.08785418174680203, 0.019240951308259563, 0.010019414983088932, 0.031095053024229505, 0.06898522166715515, 0.01840374552674832, 0.012795267544025856, 0.08264519754917392, 0.015838227193472127, 0.04239342881426696, 0.02770173168110271, 0.05620743050390194, 0.03846718989793332, 0.08769023127012676, 0.02948967938972337, 0.011423225139057445, 0.012715128043876782, 0.11935800779610874, 0.03963401458496529, 0.038563130919130585, 0.05313459438301864, 0.024655476895972125, 0.053037427621142524, 0.029918470292262016, 0.026256127598425074, 0.06330706990293919, 0.005908018839921082, 0.005515834491234274, 0.10953634691935395, 0.0817827434248982, 0.01853911326296868, 0.04115955228166234, 0.03828678385264451, 0.02997945280625455, 0.03985485475089762, 0.05408969535041721, 0.017301927230531172, 0.07537255634463604, 0.013965120193578545, 0.06892997140605604, 0.0062793114921078095, 0.0508387974132934, 0.027024282044881297, 0.004143637432266147, 0.06528238165042093, 0.03823456346928593, 0.026447454227074504, 0.016184329438293656, 0.04156553674669516, 0.06672321683576991, 0.05004221152874732, 0.0926312608944793, 0.03676296219289784, 0.07127618462207817, 0.009211210417561233, 0.08859119663435606, 0.010873973613695033, 0.0532622131398849, 0.04884877677766546, 0.055064189833618944, 0.06869217005348013, 0.03134772222819588, 0.002645293941661235, 0.018608394424400983, 0.017411171368533568, 0.018076691100554123, 0.03015060067897843, 0.03939360853344683, 0.0504827848635614, 0.020172742135342092, 0.023101348797940922, 0.02762957002907511, 0.04360133113579885, 0.05972071738553144, 0.03876045601622712, 0.031411437760858286, 0.012676346757929894, 0.044349304911109715, 0.049343753846422325, 0.03326361811149024, 0.05005046995657106, 0.030467079261377938, 0.023984828205298514, 0.03620316259442799, 0.010373219284379195, 0.05691574007693318, 0.03533073017493852, 0.014092421981566136, 0.017655358063958345, 0.0329981763066063, 0.07887478091663892, 0.043935123305287094, 0.047120279407188784, 0.029563689228868293, 0.07213008920511893, 0.017892058165143096, 0.12868820028679986, 0.062339883898535085, 0.027698215337530262, 0.04368723640518804, 0.04662387358445314, 0.026871464740965637, 0.09665372045410257, 0.03897901707058472, 0.09737998712807895, 0.08569577498541725, 0.06595441696023749, 0.06576602827877769, 0.021005066021555857, 0.02636496379460779, 0.06049527058137521, 0.059115469620953646, 0.036280717505442525, 0.022918922195751822, 0.05179242366143773, 0.03362921059071537, 0.04497921304597009, 0.009454469188987728, 0.028450013806803093, 0.03568218833196067, 0.06390584422455681, 0.04295752999643165, 0.03218334603814348, 0.013723542985145845, 0.018640920602446123, 0.007025490227651092, 0.00857034626777374, 0.026997248717253248, 0.029235433959852786, 0.07089369990412267, 0.013247212496465974, 0.02226283300607916, 0.04366926398248442, 0.03718324951947697, 0.035237190839383876, 0.009685458104696967, 0.021281478205515493, 0.05849987200851883, 0.009116198277972158, 0.013725395960312699, 0.058433023176246116, 0.04536866150315731, 0.016148849991300417, 0.05364179821504701, 0.03525161627499807, 0.09607756104800971, 0.08168306006419082, 0.03792712089395331, 0.013643783656129194, 0.058751390165378975, 0.054521550604652975, 0.024034185335040096, 0.03360241666556366, 0.07121431536131329, 0.03798109944909811, 0.08640385473207121, 0.017127397079621593, 0.011201086454093458, 0.1479696833919133, 0.020177961109326254, 0.022283682088938453, 0.00542779901861063, 0.05910624592234531, 0.0325661180390706, 0.04110909007008999, 0.02814828241694599, 0.04685759551883225, 0.09189148042951861, 0.018936580745503306, 0.025488135945652763, 0.08604169432674685, 0.04061992760867842, 0.11863197860938889, 0.03967107791874198, 0.06232497199708897, 0.059159040871647105, 0.02307400711992335, 0.03174511118671827, 0.030572812801467317, 0.04189645608646735, 0.016411675605922937, 0.08729683746012949, 0.031543631977852316, 0.13933875297586765, 0.055299298387141003, 0.0924064906974954, 0.025203553433980674, 0.04443441344905765, 0.020756830551451253, 0.04764979555001182, 0.0475080271491841, 0.03450482993596985, 0.038360929672395995, 0.01567439641803503, 0.014473694365381476, 0.034406782172980814, 0.11603031337501542, 0.01180664639950039, 0.03147838043890173, 0.006161475199229655, 0.010983694641430293, 0.04660116673837747, 0.006883186522886278, 0.035496021305481275, 0.08236617300539248, 0.02806304555927073, 0.06343928518735113, 0.048077264950881084, 0.07161499466747046, 0.062186777396428014, 0.041185710353836905, 0.04639378290683512, 0.039882215581113295, 0.06862672316210885, 0.04090724505424019, 0.03024141657196226, 0.0643516997356088, 0.06626279033239811, 0.05022714515366862, 0.020187338025519447, 0.06522369931542105, 0.06225931443153851, 0.03073250382928358, 0.01462299245289497, 0.0514297652989626, 0.05532238061629957, 0.03823137654352092, 0.04630628417456343, 0.06488861245734077, 0.058402992529614325, 0.023898978477283835, 0.024746832880942572, 0.06487597966746939, 0.09156915659625685, 0.042622523577583414, 0.03461679751654306, 0.06958390405822186, 0.02512045396161416, 0.03283704886393201, 0.042780253420313524, 0.057982180432807055, 0.07425333253077923, 0.05878466136393048, 0.07618413456986028, 0.05712197860702873, 0.013318880979392319, 0.061946317718754855, 0.03336938804075603, 0.046645412146444284, 0.06776898047856747, 0.03555951467264564, 0.06564737658106512, 0.06161475869556589, 0.021336136663693096, 0.04291332672320066, 0.072194425269, 0.024707948173125906, 0.04477010168615849, 0.008934840368437431, 0.05303876061413077, 0.03647500506391929, 0.038596520861310345, 0.03221924874871489, 0.03340698380564009, 0.017639434926452178, 0.06534452670283857, 0.029821393545717004, 0.038761789009215376, 0.08802984570783955, 0.02831643871632555, 0.07970580245338141, 0.017974100436174104, 0.03615988628758538, 0.06285496311442507, 0.1344114286644805, 0.03385338323911832, 0.020918013535500057, 0.04237510399111817, 0.030868509333700906, 0.025813397726104147, 0.02588721221282838, 0.026223003871799, 0.015373893641686488, 0.18302922227209617, 0.11942237450350678, 0.2725974644624418, 0.14249262970782098, 0.09466127131975467, 0.11870534684989723, 0.12100001767037377, 0.19591512759366345, 0.2346529457117281, 0.12874744952686373, 0.1465703318676641, 0.17789649446645092, 0.2101808338756523, 0.15241014350566173, 0.0859614695993162, 0.13078659172019652, 0.09330547955488006, 0.12143287266935072, 0.12365040609673147, 0.10873167114632745, 0.13852464666049327, 0.12839200771263531, 0.14148458057353575, 0.171970222145319, 0.13192824658847627, 0.07192552074669831, 0.11102083379462843, 0.10186020720509753, 0.1551763950696876, 0.09186858972234112, 0.22098815879754483, 0.08014267941396083, 0.14137484613926182, 0.10352248010495979, 0.20395359625258755, 0.22584196931171804, 0.10773667615027198, 0.11234133188883144, 0.19330201700570124, 0.21392567083239558, 0.13644579046916577, 0.12420153741033808, 0.17326567682527727, 0.12193883543894177, 0.22761405325464665, 0.14207860515002282, 0.14952942308398987, 0.13097540175001468, 0.3544974729659096, 0.1339940639633325, 0.19247240507073943, 0.29171325807129184, 0.16863453742717543, 0.07275506373374693, 0.1296210961957132, 0.10752157398289251, 0.12424881269614543, 0.12011298744548714, 0.10156419083115556, 0.12386185402471213, 0.19486361063055455, 0.19254158281030195, 0.11426386017833026, 0.30227797826932323, 0.08562279744975029, 0.22829780204882547, 0.19488365149065373, 0.14980446397056504, 0.148709969474904, 0.15238719151145028, 0.09836349846614946, 0.07382210929908099, 0.1056698858437519, 0.22293990568047573, 0.1837375471668859, 0.10461096847129446, 0.236894779448067, 0.13609317551937797, 0.18644396726402546, 0.08918994797333595, 0.15904498586971916, 0.11017760847725215, 0.17570333795682078, 0.16881413908014375, 0.13819548932294692, 0.1426861588392527, 0.16929240777127205, 0.12716812862744256, 0.20495108869527617, 0.15529354523506858, 0.13092801155101869, 0.23971726186573508, 0.06748365869204845, 0.13894510635685536, 0.15231885646860446, 0.10787531508192902, 0.1334557646224576, 0.22125046730281847, 0.16962010954176227, 0.16663893967145876, 0.13440266461862674, 0.20424352988841074, 0.17439282198827114, 0.09443769621993266, 0.14885961709003295, 0.07241306676258964, 0.2160427088458692, 0.17709269969453736, 0.16608698864377316, 0.16306100262989923, 0.197326353480739, 0.1755553297698498, 0.07783126957233875, 0.14186687376951018, 0.14045315043580148, 0.20931541499110962, 0.1160269808925448, 0.12239109544504075, 0.2559118243234773, 0.2388572822054548, 0.30263889761221024, 0.12246004335822598, 0.18691943207335088, 0.1143682090144965, 0.1312555141386486, 0.18450409474392093, 0.1383407395933905, 0.17124800041558283, 0.2605167175492933, 0.13340319566909345, 0.16252691677260786, 0.19323311505779145, 0.11471861763106239, 0.15793592038173832, 0.14383130706846714, 0.1697515702295688, 0.1996987592428923, 0.18172966136086374, 0.09410878403052207, 0.14956801859361513, 0.14247931509969697, 0.17702712256821895, 0.24901223729454705, 0.14917682345596053, 0.14779726764367473, 0.07649527351942755, 0.1430172926836437, 0.10836666089392478, 0.11748652394500472, 0.14476271676680735, 0.18634789983832067, 0.10880631875366935, 0.2973843924701214, 0.10058931330399168, 0.16789063540918214, 0.11827609246416439, 0.14732590906562346, 0.10030383063900856, 0.12682767149301308, 0.23422387518709709, 0.09149859223755137, 0.15469559828840918, 0.1413918073259054, 0.22909081030276515, 0.17345128460757195, 0.20007804937420354, 0.16254266754033106, 0.11741453466276008, 0.1561589181543358, 0.16191898003941582, 0.10689359638960132, 0.2039668342519191, 0.17112726495871622, 0.2126622692711892, 0.2366621338672215, 0.12194376138429489], [0.059956867818630515, 0.014211342767662099, 0.060317105343264926, 0.02024460501307922, 0.060142364518176165, 0.05589598128872533, 0.013835004947689033, 0.020421081027316473, 0.029562543927421494, 0.04574213319668367, 0.03274885682208884, 0.006850237081262975, 0.06605982299773924, 0.05682783914850124, 0.05280146487958489, 0.05540990999208824, 0.0360779914884798, 0.019574142098727248, 0.019462314329200217, 0.09636776281460639, 0.08502625244399233, 0.03983430444232879, 0.013365139283480184, 0.0013977166447382901, 0.05821960640230006, 0.058218606657558875, 0.02262736828396878, 0.04587825552950944, 0.021687594820715247, 0.04650861948668476, 0.05529510788619519, 0.048607156476787025, 0.043339375030970385, 0.029767020455291195, 0.01281062569168787, 0.03884159621872729, 0.01534667932578633, 0.007531890146163924, 0.009872285882011056, 0.05113393278612245, 0.04701054114247522, 0.028690695649974292, 0.044776885394727996, 0.0276415593050901, 0.07300260972471968, 0.09637323268238576, 0.050808280300829685, 0.06485640612100402, 0.03241256720596745, 0.04585752135983879, 0.04646923490649751, 0.025566146678982243, 0.04726848294658046, 0.043462255534024975, 0.04942733786940094, 0.01102474354763305, 0.002741733398814235, 0.04687199797180872, 0.012303904495051792, 0.040681149525147293, 0.023027139775935682, 0.033947535445012396, 0.027921160330034556, 0.059509441827333746, 0.059438988551377296, 0.00692764547796199, 0.019195426533359195, 0.005062480415818432, 0.03571962704882026, 0.060844790535948934, 0.027322824593753587, 0.05423817085102201, 0.06549282600322077, 0.06185463231597697, 0.03320993066975667, 0.030433200938146443, 0.006480337751488532, 0.01517584650672131, 0.036425818388740865, 0.07729942069178627, 0.01881498727016151, 0.10296051630810385, 0.026074426864544233, 0.029374645542233225, 0.017843520749480497, 0.02217768999417463, 0.03562866559913082, 0.04303187882948307, 0.020608473794474717, 0.008089778355262693, 0.00849047968644769, 0.05907731844232448, 0.08787934773511465, 0.06613203444548192, 0.009142496161192898, 0.0073900925382340875, 0.015498244075945791, 0.02813457901920042, 0.07665805954245791, 0.040788662304440816, 0.03587037400012055, 0.05803479918188626, 0.010319858387623344, 0.02371375948461073, 0.03418728266091597, 0.06164784986345519, 0.005877336539748696, 0.020327702570225925, 0.01247736978374662, 0.020902195735083475, 0.07753589671225318, 0.018402318687989347, 0.07320479564969579, 0.024158689944494157, 0.05066765720144876, 0.048344591332058755, 0.03534990918612288, 0.047241428551534494, 0.009783890826867954, 0.06874391163188605, 0.013922752658536118, 0.043657450906692014, 0.019359373179594838, 0.08131438791151009, 0.03272390150795541, 0.07270454789601988, 0.03899547263919827, 0.030308866783255534, 0.03664327244604788, 0.06030667122573622, 0.01967439236449859, 0.018196681536914363, 0.04916786388944715, 0.013500930283278709, 0.023095610799388062, 0.05587131708800312, 0.011809669573971582, 0.017750730264871832, 0.04017019952316919, 0.010617316922082776, 0.013963937545345436, 0.052382659933139245, 0.05574015517448706, 0.02855969653014214, 0.01950092516058395, 0.031006926099859902, 0.062255392061366197, 0.03525272710248828, 0.023924569644394423, 0.04708010958687914, 0.0631985612093441, 0.019781407186641328, 0.013714320244147413, 0.03189840538036679, 0.08177598652940604, 0.02462138981378127, 0.07664485218664331, 0.02877485423889612, 0.02975527824263179, 0.1056934200647858, 0.06823973384715858, 0.0031031425591678393, 0.03793468218176596, 0.05977802842314686, 0.044260871551570394, 0.047548622148291725, 0.007529991205721613, 0.04985320231606884, 0.008295990072280891, 0.03825607904863935, 0.07345535236621097, 0.026787083986545765, 0.09522167995812432, 0.049471261520539565, 0.026434677795717315, 0.05579023434209728, 0.022984949398725744, 0.03788806956201311, 0.0921932807672889, 0.032628515900503245, 0.03177123286971643, 0.022597299332940773, 0.027854240634628845, 0.033840796414522395, 0.06115625124244441, 0.04758914819948616, 0.06916110013281146, 0.05675210752674649, 0.03985198958206081, 0.07328156532058794, 0.05797778691856131, 0.03797678254364479, 0.04243990736863306, 0.0195665271847599, 0.06677776995685793, 0.06227600748740858, 0.03315807417816213, 0.018836163855608434, 0.052742912779532136, 0.004839733169759594, 0.05019813340397612, 0.03694625638966118, 0.09949402973776865, 0.019056530962247523, 0.028582845791994084, 0.07528557472171322, 0.03250538258843365, 0.050322806552773526, 0.04276002103823327, 0.05019642502790497, 0.028675735868032903, 0.030141855785322767, 0.027444697691187746, 0.08028616002129932, 0.08612895940220164, 0.023230762115769812, 0.05552454738907757, 0.03698927605704915, 0.020605348155743653, 0.032925478393031705, 0.009000042111672943, 0.04253080753128856, 0.0337860670932118, 0.037482433666985844, 0.03320298991316269, 0.03212138484682768, 0.027310881283014055, 0.044132747176674106, 0.04983701104778917, 0.04010223986340627, 0.03920923415271025, 0.07885930594056845, 0.016267972833086407, 0.030946271088454994, 0.047868391078326016, 0.02128086533517607, 0.03941135112977317, 0.04228785806786149, 0.030102999805803263, 0.03426839605033879, 0.0503198494533858, 0.028502163327028675, 0.008430637685852426, 0.07803954589631289, 0.00580764695769176, 0.04103040900982676, 0.046541806415564595, 0.004026738160680379, 0.04850675682387045, 0.06623770861375718, 0.04408723772353223, 0.009009077161129926, 0.011870329373426015, 0.04183775076882974, 0.01949083386740137, 0.048433492005231886, 0.03957716320010443, 0.04571663012968437, 0.0421550797088252, 0.027668188521338087, 0.02821084690250216, 0.028700022770452405, 0.0624709653728191, 0.03909267387503097, 0.030877736862748865, 0.08553062941158011, 0.03131967191884835, 0.08861659244904596, 0.12686379253864288, 0.06312137402053322, 0.027171363265463905, 0.022421847961302248, 0.06917907255551509, 0.07528653233161858, 0.06656243030222193, 0.026878568291243528, 0.04894676325362056, 0.030470792872590885, 0.04612721878314211, 0.042520258500571215, 0.04207184425585213, 0.04169770223539203, 0.01616031258186746, 0.06265261631098486, 0.01656816055577609, 0.0200582368885197, 0.015384143898113361, 0.03420446601305758, 0.07476203789513919, 0.06896165680260428, 0.028273976377902493, 0.005490760433472573, 0.0335449370886049, 0.04725517216889609, 0.06421875283722916, 0.010368281847707207, 0.022018983389341065, 0.05390412204207913, 0.04748896305118838, 0.04370829233178689, 0.08729054021739191, 0.04947035753678891, 0.04658561515351457, 0.0225178406934344, 0.06882592900505952, 0.032554446689544186, 0.04055830732648892, 0.02436201542525763, 0.07070076066039263, 0.07262485176925698, 0.008833067502916582, 0.03879682987087196, 0.019693310905788696, 0.022149582228232777, 0.009060298757357223, 0.03321250089474263, 0.021409836237228686, 0.08779579818609261, 0.01833337652046354, 0.02538512393291439, 0.05745215484151437, 0.07538036278058445, 0.049613899431161346, 0.01958723645657301, 0.045000211515974615, 0.03479281004758612, 0.09590525255208054, 0.023105535468447114, 0.024905330726816773, 0.03356475195276641, 0.0809042014542126, 0.06952484634013907, 0.02952666419948782, 0.03667680028405401, 0.048726497653631434, 0.07586402473069968, 0.037453203582234924, 0.03136222618782232, 0.04067226673566526, 0.04583723152116422, 0.015099669596360577, 0.04670049003776043, 0.05987431418391005, 0.010970994818865532, 0.019979925465679938, 0.0812446279451251, 0.05028572406679873, 0.055095852247529456, 0.05710267702177648, 0.025348499184474352, 0.015665271353246947, 0.030878933875130552, 0.12112240787715682, 0.08817358678507228, 0.16488243795691, 0.07233373069715116, 0.1825591047564822, 0.12575189252534222, 0.10145889970684245, 0.07586156558846274, 0.1907258778209648, 0.09541659570869901, 0.1696439195544489, 0.1660182858787237, 0.20300614467311293, 0.1576484688707898, 0.14593120003419538, 0.15314751845454017, 0.07520701240507827, 0.09074845426385442, 0.13491805793056566, 0.28875710863259535, 0.1019306643114936, 0.14927282959463137, 0.08493239901238873, 0.0760504445661941, 0.1812107440444731, 0.1465989682342737, 0.12952101446928518, 0.11402186832480854, 0.0938690368146185, 0.1032740301302364, 0.1714052935881961, 0.11574306870780646, 0.10889809608699814, 0.14096987674072867, 0.08533923766545712, 0.08414260832773102, 0.15238955106225707, 0.18555273121643454, 0.1601776775092848, 0.112324500937135, 0.10045512534317472, 0.17037927203120726, 0.1334711629897356, 0.07501591943324575, 0.11279221293666672, 0.1265252812675411, 0.15045505647938098, 0.17313228559590157, 0.1613950678297589, 0.1459955054545595, 0.11059839759142169, 0.17892965596289406, 0.19950461724112112, 0.1362135585757994, 0.10636488080865915, 0.1848732418711147, 0.09725702235535269, 0.1460636566363035, 0.09983383569746249, 0.19835824327122784, 0.1148960895596012, 0.08598909472986575, 0.13264820069795655, 0.23037825170303547, 0.15952019020915031, 0.08638616576189957, 0.12897508489268442, 0.09364575282820771, 0.13346077483748237, 0.19127998921659686, 0.1011877658686811, 0.1307358307343337, 0.16844025752957792, 0.17055216275395887, 0.11011884953345984, 0.07098293382554285, 0.15391618043424624, 0.17993186750719625, 0.09829655770332583, 0.17997778681737764, 0.13991868153454798, 0.17398141745117404, 0.10271636408663566, 0.10466947460607176, 0.14571559224878589, 0.11041029236249386, 0.14298042853272733, 0.22623864963891047, 0.13745082121702934, 0.19174572470928394, 0.12635002333310344, 0.20447153297643508, 0.18982638334555013, 0.15790369872364307, 0.10327920122372528, 0.09817537791546314, 0.1589236681860301, 0.1525059964267477, 0.19564598558410523, 0.13523357890305981, 0.16087664080963981, 0.17854347104026427, 0.12369693827725227, 0.10992831580581204, 0.20153268180306882, 0.19078478998234197, 0.08554438835070019, 0.13860157720984953, 0.13293769000278366, 0.09677395795381839, 0.13552807842291173, 0.13230824152067786, 0.18682586209427926, 0.11656638340003068, 0.17498534503242663, 0.10145052636583006, 0.13339806288000078, 0.2869146058876669, 0.157878203317523, 0.1136268504084118, 0.12441887655445646, 0.2528430293163946, 0.12146779861781867, 0.12101819693681695, 0.19906754875856064, 0.17500405289953755, 0.09833932073125917, 0.1253053015698829, 0.18408243995039694, 0.14084684302008924, 0.12563388434148606, 0.09115870200818585, 0.13440416615095832, 0.15695974050510317, 0.07282160613084994, 0.1298824700737192, 0.19762131265334545, 0.18020516171330409, 0.14939330458160371, 0.12632923170683846, 0.10754795805100473, 0.16360610483154175, 0.169516074801645, 0.1604738777443286, 0.24962880017776645, 0.19131144478676781, 0.16321927639505557, 0.08195440840697096, 0.1111648659852724, 0.14083136804401875, 0.2436947750468408, 0.14225206277783842, 0.10300083551555873, 0.16437943994758591, 0.22094265317484257, 0.10282959188184432, 0.21808018096752707, 0.17817797049159007, 0.12881993676625914, 0.2018713845961517, 0.19348917228560295, 0.09702557953254831, 0.14275708325928257, 0.18537746562111765, 0.08631516473307725, 0.11014215392811645, 0.13526166368636394, 0.17496380263999586, 0.08944242757054106, 0.12498783473406108, 0.3269126692846898, 0.1809727818134331, 0.20063084309860585, 0.1402754333591269, 0.13718806838075961, 0.1855374401014659], [0.0462477014309937, 0.026836764788435354, 0.08451835913283211, 0.04060574732119999, 0.010078878727771584, 0.024897539612626838, 0.013048159871100178, 0.0670256760091551, 0.013751783858864539, 0.04167772266232679, 0.013936003106796454, 0.01527956619317974, 0.03739706082870403, 0.06884378651457448, 0.029909987783720417, 0.050170328242764364, 0.037641481180945714, 0.03803109434703666, 0.06402552631052752, 0.0456147825705909, 0.010443932072619998, 0.06439365837122164, 0.029578790737075672, 0.04197207662547308, 0.05529095185920597, 0.022372672777442683, 0.049160869506698464, 0.06416948955325831, 0.038114429391439886, 0.04990258051322834, 0.02467977145927087, 0.03282971357205703, 0.0402607434549399, 0.04002837749618677, 0.08402600974565552, 0.06726078839311678, 0.03403449025485785, 0.018256371277534676, 0.018380105968624837, 0.016462407863488602, 0.01762508226919078, 0.14161193503006814, 0.037774385944489515, 0.031467028931083704, 0.02229137361169823, 0.02341496987238286, 0.043761569916480975, 0.013733812393770825, 0.012501180754043164, 0.0603713481987436, 0.043149706982677026, 0.008284236368302616, 0.07980686477235249, 0.005194295898094894, 0.01738838025278622, 0.015739714989678997, 0.030899920853816217, 0.010283913542216104, 0.019722837849610278, 0.043808990758993936, 0.052542458213264906, 0.02228607611370183, 0.045950712125387885, 0.007945280766204722, 0.03564146692834554, 0.013565415734305017, 0.038424357922086795, 0.020323701676041372, 0.0443322632852341, 0.07032018350136858, 0.03428699666514032, 0.009615565030535143, 0.07366391214271707, 0.014980175201931309, 0.014006281140140228, 0.04252116248432187, 0.06174948291792985, 0.027016870144213882, 0.05438461238818784, 0.04915225101755031, 0.07242584510916665, 0.032271350388445204, 0.025369455519643043, 0.06005901032157483, 0.027649107186364073, 0.04974051078240718, 0.022442076512942874, 0.02763426997849057, 0.031730408044231516, 0.03843890593176888, 0.024960188367854685, 0.055060941620819995, 0.03166445170439059, 0.043584534658059, 0.019076330504650553, 0.019612046214000835, 0.035045128766327135, 0.050618390087038286, 0.008464309165344365, 0.048084891356167295, 0.08825470783537434, 0.031462662229915304, 0.024380495381211082, 0.0661916820512664, 0.002963302305884539, 0.025151003632814656, 0.12954286329688566, 0.10220075627007794, 0.03142993495379004, 0.013568527966497407, 0.016011206016335038, 0.015363830119191159, 0.02657473207481446, 0.04172002603750556, 0.06483330090920772, 0.0565371087812368, 0.052664281514983986, 0.06290835944274742, 0.02445500700794641, 0.025294593407682357, 0.02915783691400242, 0.04359501857130278, 0.02556249627002305, 0.014140903855854226, 0.02391535360666533, 0.01839863188985375, 0.007711928948054031, 0.05991847149186558, 0.07886305211051818, 0.04889112994855931, 0.035473973295020486, 0.02696709741177338, 0.0729293410756415, 0.01875700207517272, 0.03731728043226946, 0.015888403079682784, 0.07649822295793603, 0.028674542686090838, 0.12147600341948772, 0.04048447177234677, 0.04623097390116704, 0.010793443408704573, 0.06113151426336939, 0.01178722415540007, 0.07500668807375817, 0.014999388687072263, 0.05229331492897003, 0.04369537991982314, 0.056408884814910354, 0.022668336750939492, 0.045607726900808276, 0.029109242041745496, 0.01700373899732386, 0.03133016732341099, 0.0238287435363858, 0.01611947243462407, 0.03651156661010558, 0.02832973608747125, 0.05147912434392399, 0.020714136471431104, 0.04056555451825261, 0.015129227183699129, 0.022021388905423305, 0.04125374279195263, 0.04262530447674855, 0.01195235344986882, 0.04433360393910159, 0.03383787761953089, 0.03736212721935684, 0.053508962399416396, 0.04086875296648472, 0.05976383281390994, 0.025290132860743234, 0.02917248451511466, 0.039901172426799615, 0.09507060741945621, 0.0538754818450299, 0.023381359679924867, 0.040774428390807686, 0.04215425999474622, 0.012175617326471594, 0.027110175822951624, 0.04726692012721493, 0.012503720335512152, 0.009214852208031282, 0.059881346871054945, 0.016988666217413642, 0.042017601400373444, 0.028398090282515175, 0.08400986061221169, 0.06339315520299059, 0.04746297351835717, 0.029520476124279445, 0.022750503511258194, 0.05414514096393701, 0.06304734311397038, 0.06468933000559769, 0.03831768017863074, 0.014546290772306103, 0.012130535924957405, 0.026334201534008308, 0.039689103967600295, 0.06722822965633485, 0.04432741777911302, 0.032029980981361963, 0.061344850598083395, 0.007148917525961635, 0.005182164895813912, 0.01828894725129489, 0.006579410635881247, 0.06573685565062108, 0.016034671289455748, 0.03593701598865371, 0.028321090785245744, 0.02499846595099136, 0.0044547117431648076, 0.025876259070730982, 0.04152746600729804, 0.03186976518331757, 0.053953764539572506, 0.07997839951947813, 0.019238070817664266, 0.06927683303553252, 0.08378949542079242, 0.01618037642460437, 0.051740042399615056, 0.023588527091628602, 0.0023342397405705867, 0.07742294470869726, 0.025408345973119143, 0.013222793443879534, 0.024623839379919153, 0.020446653042228955, 0.004157467234519221, 0.06334296112219173, 0.01570172181668421, 0.04132455229879387, 0.02160163784039117, 0.030855738648003152, 0.030893468478273962, 0.013568695548230843, 0.04814022588693807, 0.022972494724296758, 0.03225695942678759, 0.030731605591192365, 0.017878057908326868, 0.04374366261125092, 0.040020942612881624, 0.10870288922301224, 0.03375006479121024, 0.04645192514984839, 0.060728191953873446, 0.09701588852030617, 0.034973951537282236, 0.06507659511220071, 0.05138360084064546, 0.02920326018225282, 0.013700455967937748, 0.03774022225350623, 0.01472251206230853, 0.047679979414228475, 0.0150244694481033, 0.03225918491220763, 0.02368425360820707, 0.018857173816931826, 0.051223756595244335, 0.0825075468709392, 0.05402685698842811, 0.06541206501424313, 0.01911456212251177, 0.03678621296139975, 0.04283465332381668, 0.07895246223216096, 0.0069548272351253665, 0.02908631111495197, 0.013028028995669898, 0.07414005877029511, 0.037078835565837166, 0.032229943336137844, 0.02617152276328735, 0.05418274822013994, 0.06519910789305164, 0.0711261386412286, 0.02728923929915313, 0.048411045629050464, 0.052643022575085206, 0.06032624477220159, 0.054436323323076775, 0.058111208791454, 0.028426039085212736, 0.05498863441208678, 0.048921083986398675, 0.05248215177186555, 0.05945418007491578, 0.02333834958863595, 0.07941245206541593, 0.047151206376691984, 0.023219734280099793, 0.001196742215993694, 0.028407947918880853, 0.023440597428669854, 0.01758634311807973, 0.016077155652906627, 0.030470645400665464, 0.010485208889980231, 0.08084142820969706, 0.011233224800126928, 0.019296624832936836, 0.019972555699848363, 0.012635961475391543, 0.05785980554778249, 0.07176230571443035, 0.021167773520573977, 0.046279781362822944, 0.013933157090157753, 0.023629644945744547, 0.03123851830980951, 0.016814902154428345, 0.011677201480544623, 0.009009285920089292, 0.04945174926110814, 0.029777467979358572, 0.02669053584066851, 0.053795456300459565, 0.015537464904839234, 0.017470876430912365, 0.014046035357750954, 0.07696391248534765, 0.018881916541666276, 0.05631393204713541, 0.0664233623613273, 0.05728961396661978, 0.05936986060752984, 0.049135354948380304, 0.026299480514060107, 0.10808831816839595, 0.030813981110470432, 0.04156960467357309, 0.09320601835967073, 0.02908120130849702, 0.04683992953129834, 0.009825951926740668, 0.047733494486179084, 0.01019783590304395, 0.05998117961890756, 0.04297244955875701, 0.041521302829947204, 0.053821327089662516, 0.05163961976406075, 0.04450081795033428, 0.021024145441310062, 0.013484357886256711, 0.1247327657596719, 0.1788936345086944, 0.22553613169058678, 0.11894258895828841, 0.08994305070729987, 0.07875242135337285, 0.16545263719895195, 0.08435879833996297, 0.11079931181044349, 0.1716256970840116, 0.14444534186153643, 0.1550935809650729, 0.11986875095434728, 0.20150637434374905, 0.13222904335106575, 0.12287156280851173, 0.1117679840254207, 0.08890857153962697, 0.14466914678773574, 0.10490015134095185, 0.1547610681624182, 0.13538316523115482, 0.1569279478562455, 0.10275679054639994, 0.10004041896712396, 0.14076143953829043, 0.10665495234030871, 0.1613507879477355, 0.1481052349892355, 0.11006541490074127, 0.12449260485628921, 0.1694262892969193, 0.09868854957242167, 0.11486538475559604, 0.17644917051638329, 0.10895593572528132, 0.12243902956646298, 0.09669066887469062, 0.12378733665231736, 0.07983545517368663, 0.08023203590944891, 0.1825863621648281, 0.11853066348140279, 0.16777524724602702, 0.16941185620042587, 0.19935095532526895, 0.10378154039743448, 0.2701599259049662, 0.08564650021012753, 0.17564137676550498, 0.21992426185357958, 0.09776576602410886, 0.2473653780837213, 0.09520320191739068, 0.14338351335496674, 0.14545521428508146, 0.09910180804229553, 0.08718158719280074, 0.1757085320329474, 0.1427530076715254, 0.17115318937407387, 0.1321318880805085, 0.17584708669493276, 0.10261414497489892, 0.11740931760399573, 0.21325736637077025, 0.2678105793893337, 0.11703423329538877, 0.12342044182362095, 0.15978931689695006, 0.18452670965944568, 0.19268870233528076, 0.11989698895523626, 0.14263000459440295, 0.0838590945087133, 0.11912658029506284, 0.2376268990337849, 0.14924920344304654, 0.1377152288032155, 0.15538421940178643, 0.1561754350099833, 0.17095170824998812, 0.12435034232875034, 0.10032142767862928, 0.12656982161945876, 0.18440056562183366, 0.12993491645301544, 0.12275906279683114, 0.09816609292982087, 0.15908382652748018, 0.11605591603344488, 0.12529802373460225, 0.1424267921116083, 0.16344324986059822, 0.13131935990625812, 0.21949702993996684, 0.12303431052714588, 0.16825239744878587, 0.08609554264694454, 0.14583508664321515, 0.17358420086243462, 0.10984234541894929, 0.14138310456708555, 0.1539702968852174, 0.16558081903044256, 0.13994221575558186, 0.3235310958998819, 0.1015274569151863, 0.10095933377141915, 0.10239879765938367, 0.20864963861963443, 0.16448149818085855, 0.11946127644830173, 0.1976059449295844, 0.1018203629721557, 0.18861596442518697, 0.1654147005249416, 0.28313411519892756, 0.1343035941282588, 0.14367361553013325, 0.07421507409984067, 0.2109044039201352, 0.07657615708247309, 0.17848144856191453, 0.14650849325041618, 0.11785793103157513, 0.08648879090023619, 0.1483399030422011, 0.16641130430563805, 0.1945481662668528, 0.06382286158059874, 0.1469864401846163, 0.16492812744071408, 0.11113417650302572, 0.1650643991606851, 0.10476597104101412, 0.166208551475598, 0.11446023915684032, 0.19523422864656295, 0.1166631020004711, 0.08391639022457023, 0.1696879083230611, 0.18478043797996738, 0.08262851981506233, 0.16144221288061913, 0.07425988258253183, 0.12852539894201104, 0.12714686202666453, 0.17471799566861124, 0.18470594359021034, 0.14048190937647898, 0.12982823104868013, 0.09932773503204508, 0.1422351628782288, 0.0947332759237578, 0.13647753715274796, 0.12557994409073747, 0.22550561074768344, 0.09747518887442928, 0.22492926748048878, 0.1334961987431011, 0.07754651469088371, 0.16806093675474967, 0.2245390222918603, 0.14218653161679545, 0.13986687866910813, 0.12097511981283465, 0.16273334682468446, 0.10274510770555466, 0.12128225212255794, 0.10352314660145391, 0.203600705511147, 0.10312126453725562, 0.14005391137494197, 0.12884903278562332, 0.20500598655593014], [0.038593705488188614, 0.050005228634202675, 0.08639414839807057, 0.013903882955351185, 0.032469786313031955, 0.03095889813266695, 0.04048749781964768, 0.012885506955846664, 0.01745553935066827, 0.05335545370114907, 0.03778928252417715, 0.10385762825007401, 0.04920656282094218, 0.0420871238795019, 0.038582781074388374, 0.06016430527632756, 0.03412468944706264, 0.031853020416512605, 0.041310781868354934, 0.03160271459379264, 0.04945240809672302, 0.026814592288686868, 0.025253596212414485, 0.05219626691072218, 0.014457951258537511, 0.06113364015735927, 0.0476007889054956, 0.06178872577185112, 0.05121132298823326, 0.025154876207271894, 0.028661207010548924, 0.06325632806927448, 0.016326831368308876, 0.04074992123810996, 0.05111843482741425, 0.005586777584657314, 0.026352267802482652, 0.01171156339677832, 0.0596668575740149, 0.03528751898556948, 0.04292998530511414, 0.055323679135331226, 0.015093025698837255, 0.02827248825210958, 0.1028850719693207, 0.030079055727729877, 0.04736137110739947, 0.05177381155531734, 0.026353428425687938, 0.08950916148962514, 0.01366225307837369, 0.018179021295039885, 0.026440856294826637, 0.0396460076914199, 0.03133028798225907, 0.04691566881393233, 0.09553018356523207, 0.098773370827398, 0.05208393543838494, 0.009360298788505457, 0.017826630425969922, 0.014373198951474361, 0.029679535129558177, 0.14086619440105655, 0.03810030273011616, 0.05772660967082747, 0.07467362368779798, 0.07353984420337985, 0.08496711045623788, 0.06541162068324705, 0.017445769814413883, 0.010155338133054395, 0.018487367854123155, 0.023224464873032227, 0.05589919119712807, 0.033024211804712975, 0.060319484046269814, 0.023972612933345863, 0.023250140309814486, 0.019560505733675054, 0.03270943010706575, 0.023177176180686203, 0.02218252783941646, 0.033381388808089885, 0.006560922540243596, 0.04353686100653103, 0.011729447719370647, 0.05225000797861046, 0.07317917766950785, 0.03870818966759309, 0.05621016926823124, 0.0337760811371188, 0.027576100922399954, 0.030748898110863183, 0.023018050142714096, 0.01634308966928192, 0.0861901621664724, 0.03139132986806574, 0.037521327950901566, 0.05330964930415635, 0.038034101242139455, 0.04743669287211472, 0.057204428819879416, 0.029692909109496304, 0.02056649409144396, 0.031159929180097197, 0.15705027677599462, 0.04898877168494848, 0.08090754925844171, 0.003638313627884453, 0.0386493464541291, 0.05837262863473547, 0.01313058231326361, 0.02103839659192149, 0.020937627301581448, 0.02124347066837213, 0.017713728218129086, 0.025201797177414262, 0.04862131761206735, 0.054636383354063, 0.029327092549553322, 0.03255800133751285, 0.03502508024534872, 0.10436261808800121, 0.03245749060184725, 0.06978104912465619, 0.03710835293355969, 0.022639100920529138, 0.0819256724489312, 0.10507878772313557, 0.04266385785153797, 0.0932042257139279, 0.043043385470105756, 0.02506614981910154, 0.03974188742558322, 0.07297307703523867, 0.013575613322187097, 0.02487438268989565, 0.012930917775168294, 0.044262564605883056, 0.06302223075181246, 0.01309824382675992, 0.035855856633955435, 0.040876459811002984, 0.05332522004121735, 0.0244980477427523, 0.008070306315447294, 0.022476816685089183, 0.07459660886877006, 0.04558277541711446, 0.09224462397997418, 0.05527734230723112, 0.05445546786030454, 0.010994332729868833, 0.026834460779003082, 0.009503291972402123, 0.019778907824788364, 0.02690336655735249, 0.05221253095735466, 0.04630946726988881, 0.0922345346020114, 0.010242853144694482, 0.0865897000016224, 0.021249532339072997, 0.02849455032828114, 0.0666889037576414, 0.05425526610305233, 0.0255399368958728, 0.025108058658999302, 0.01821524384731968, 0.016572487037328464, 0.05564346721756363, 0.02584426723901303, 0.027577466474124984, 0.04712583354463981, 0.10735465108507103, 0.01901082615668495, 0.06225979323649119, 0.08217006215765592, 0.04749916351190017, 0.07897025845464199, 0.06440505009865569, 0.01971050000358974, 0.0371940283765716, 0.026457943885977712, 0.04491737442872217, 0.005722054826741618, 0.12237760463669417, 0.036750222150717056, 0.046388404969606674, 0.04332981042323574, 0.0660465160504945, 0.01359752918248095, 0.02480749363800691, 0.039231619241857724, 0.05042786785070935, 0.045049176025655, 0.036078504767389066, 0.024642880495277145, 0.049478236751090136, 0.02724971299269988, 0.06108019403332184, 0.017813827181535385, 0.045358043524526784, 0.05875164680483361, 0.03691170199383651, 0.042999174535995534, 0.0361468244884764, 0.03310883004638938, 0.005418424017637247, 0.02275634493168083, 0.04306220825040533, 0.06090847542509437, 0.08141427811595701, 0.060196343073320974, 0.038767450398975806, 0.059026197395137245, 0.05612893713518016, 0.02873398919379519, 0.07979941839772849, 0.04689129955706097, 0.013023084855728574, 0.01875443568062638, 0.021877241801590692, 0.054205275035553405, 0.01689221383252692, 0.05699677685756357, 0.02132454383817892, 0.025112735625777035, 0.03004511228702482, 0.07053530865138577, 0.03771885223085842, 0.06155771578872397, 0.019420516572051474, 0.015196951271425334, 0.040102262846044, 0.015224524691039997, 0.0591773503730374, 0.07619386388649864, 0.050863810184021155, 0.008943346817226661, 0.013743722698681298, 0.05431538868334986, 0.053010177873675866, 0.027786775101577083, 0.015116263060800493, 0.029704434902317105, 0.025045413734211076, 0.05241376310286503, 0.034779415000230074, 0.027297424948624065, 0.030755733530367577, 0.05774813291106013, 0.06818937888789563, 0.020622577473160722, 0.038667698090355244, 0.0651480940981738, 0.006219743367945475, 0.022116630871389664, 0.06141777833803527, 0.010151702088243779, 0.0861844854549535, 0.06415519052215161, 0.08559554770228364, 0.07375359805601259, 0.03574668910474547, 0.027670969420503226, 0.05130416901421644, 0.02279394644222433, 0.022049990798076315, 0.02465496170184305, 0.01492549567633579, 0.02787242756195126, 0.016288883202979644, 0.02591856819156918, 0.032018907180416493, 0.04409410187133378, 0.026872219337571054, 0.06562709823370942, 0.020026850266261928, 0.12647458922959146, 0.008627633365141529, 0.03597638524708248, 0.04061468373683672, 0.024241825806037075, 0.05240247096686114, 0.025401282642457276, 0.018769732541254452, 0.057626983766714414, 0.020638669150010235, 0.01949840664653288, 0.03873382679997914, 0.02675085377338673, 0.031319679579727595, 0.026512274841567682, 0.06758954736494249, 0.048068627309534824, 0.05811987324587761, 0.02278840762653178, 0.029504277195120533, 0.042521016927616256, 0.05148230743924937, 0.02338926187686382, 0.014793379025744095, 0.07497000778394361, 0.04343597105734291, 0.054179427228988185, 0.06784511429648246, 0.03394851603755548, 0.08329750609494026, 0.031059066043986432, 0.0333363619903403, 0.022952442372878714, 0.024370430901105848, 0.05964285986978681, 0.05090264318090293, 0.017979240886146025, 0.0733344636917595, 0.06244155525740597, 0.0370625561974462, 0.0557289396472756, 0.05078767636610616, 0.04027369417129986, 0.02407364077836035, 0.055048098156769434, 0.05164878600607476, 0.0715190344940751, 0.007762955191860637, 0.06852785185460122, 0.04459800386440851, 0.03653114015657095, 0.0472493767137489, 0.021781030734400117, 0.020300979508207213, 0.06982469315370245, 0.045575129859630144, 0.014802415990420889, 0.020000498756886493, 0.07139872804644608, 0.04248579986573708, 0.06394260112316379, 0.08018815439314612, 0.028892588546319358, 0.09138194769020043, 0.04531814949586988, 0.02315507837451033, 0.021781756602708372, 0.08456552716633005, 0.035587151294514056, 0.03008370205099064, 0.03286750851980141, 0.02833837755925713, 0.14050502991003377, 0.132159007593028, 0.23301713348877048, 0.10139022758530994, 0.1390667611192311, 0.10657929349690677, 0.15805480190582816, 0.1113780759154789, 0.17142812300833965, 0.1066109252673003, 0.14044306871871795, 0.2647809774404572, 0.10691462550312282, 0.13730897237696957, 0.1845234001596128, 0.15197888196956727, 0.0880714672647657, 0.11940028818864977, 0.1028947170162874, 0.1167400248889481, 0.19104161329807776, 0.18273191887044138, 0.11023609929027096, 0.2259061215144973, 0.09665088592878274, 0.14822520435817782, 0.07797847336698925, 0.15185005662422027, 0.21420792826721746, 0.2017699085897015, 0.14646041357228834, 0.23724727182378694, 0.11290695758596545, 0.10194358055389698, 0.057111567472137754, 0.11342426611771507, 0.14760946884991663, 0.1001138561555455, 0.13008237305668094, 0.1320518165706627, 0.2020418544810626, 0.17235430798703627, 0.09439871000546603, 0.15279274313680588, 0.21693127890748365, 0.0859258541717164, 0.16096687064536158, 0.125194463968998, 0.1723134755006721, 0.16203202397352265, 0.14363990766146492, 0.10623214841489831, 0.0796966553635655, 0.11655987931355355, 0.2171277651383031, 0.17384085563882706, 0.27338773012161255, 0.20792856602178467, 0.06445014969475808, 0.10316390499112107, 0.11619385782509081, 0.10249279664769288, 0.1185397033189093, 0.19411267592541634, 0.1255221810612467, 0.08309027931142239, 0.22217910376287278, 0.1689076784156984, 0.16843233618044084, 0.13211457449341976, 0.1368180938786076, 0.08661778478492653, 0.2231287923190863, 0.1856193042570545, 0.18761418189012236, 0.1470899233414281, 0.11213664851722219, 0.12880332798006075, 0.11823296937490664, 0.0751647473342957, 0.1842857443637425, 0.12746778391902486, 0.09082479492550896, 0.17398535514310484, 0.07375637129429849, 0.14323567370733908, 0.12273741315209097, 0.21591783651421148, 0.17276984939892448, 0.1358740284077583, 0.1372091664421943, 0.18948605644606775, 0.08147328986876434, 0.2220074234590415, 0.13820066807731507, 0.19596976498442312, 0.22644710216310718, 0.11483952928815158, 0.1344834102858459, 0.19851516872163744, 0.1430465419205927, 0.24995017406200212, 0.16245017008435342, 0.1067565355990683, 0.14864203279777882, 0.11267214397629423, 0.24139238972096677, 0.10939094343132551, 0.23366596399536058, 0.15862880094397455, 0.16467038481946916, 0.1796351922976394, 0.1867032727046359, 0.130745621338006, 0.16041960807577257, 0.17948353753214885, 0.10209950242912579, 0.095448273444368, 0.10392288361946422, 0.1267075489064859, 0.1093758208557002, 0.12559941038489342, 0.1931044582517878, 0.303016119306126, 0.11832326815854158, 0.19094454995807142, 0.10700637219293464, 0.11937551290517855, 0.1377838089941971, 0.2292532209427126, 0.15893096134306925, 0.1609916459288328, 0.1056040788910562, 0.16451911309794073, 0.1357860968358094, 0.14414647564051614, 0.1688387151807547, 0.14890732904595716, 0.13890347713904996, 0.17027203504356647, 0.09737287017126238, 0.15853186017803608, 0.17872524838293755, 0.16995954777925246, 0.14876169573155143, 0.11781875329512743, 0.12238191005082862, 0.06924425131611286, 0.16842867428016278, 0.08605547624850467, 0.2098722843032691, 0.15205539883144442, 0.16094004224625327, 0.11197657444544377, 0.14311334478758997, 0.22274397103296173, 0.09799789066516584, 0.12012963453608176, 0.4274530678747162, 0.13545577504461812, 0.21526880682476107, 0.12781240857176243, 0.2487885855859326, 0.1756579702299449, 0.1210155769161159, 0.16415621724820909, 0.2232159884466279, 0.15711234521961984, 0.14898379994255884, 0.09402972375673634, 0.11735540799676411, 0.21230606902991572, 0.17168038044004671, 0.12920022281187196, 0.10572623161058273, 0.156251339001521], [0.04533244469653695, 0.06167334910001486, 0.016039808866597952, 0.029669372973242597, 0.05509326670078501, 0.0323795028511555, 0.04259210605654986, 0.11697092378932623, 0.03253993698425832, 0.06248053381099336, 0.0865389619983973, 0.02526707744466201, 0.004950057491735225, 0.009431105422516985, 0.05985043139287061, 0.015241321168779848, 0.047574243958919286, 0.05888774615502166, 0.029665373994277853, 0.02804392208946088, 0.062451510569981994, 0.023018651521734657, 0.03679154876379236, 0.06814254793308436, 0.09286008369658263, 0.05192732408402428, 0.07115837562108232, 0.024523539318432732, 0.07598994660281366, 0.010419892233556077, 0.029393979686222253, 0.0724835545125027, 0.033955238459091035, 0.029796689125378768, 0.04665468947120732, 0.016932508142124263, 0.07177728273335003, 0.04061724630094344, 0.051668842187932426, 0.06139551582295568, 0.049392657069068764, 0.040529946751532056, 0.03274712546337997, 0.03451875741443327, 0.033276469236420046, 0.06042444192233586, 0.06639933018314262, 0.017285460170598763, 0.028603365457045938, 0.04602109262299153, 0.02567673147085213, 0.0344302436156619, 0.027730594043649977, 0.06831753773674851, 0.1011889456440845, 0.06053302339428376, 0.03520971892641918, 0.040542728928548676, 0.08437907668731867, 0.043931518861603354, 0.033616524174689286, 0.01688363556299479, 0.0009687545694290631, 0.07285750501098172, 0.02348447702975283, 0.015197270155523815, 0.14590945845890432, 0.06359664347743796, 0.023135748060960925, 0.03659629210409138, 0.06735958309183199, 0.04538824654094154, 0.020502592782459913, 0.049773081010507966, 0.05730315840112106, 0.11006179130485944, 0.05855517206533302, 0.10507633624177788, 0.05774184715964141, 0.08247879559114095, 0.06464282080771462, 0.04873351118857822, 0.030971756918475996, 0.047215186209688266, 0.05867655103605601, 0.07195971125075895, 0.03744281542998168, 0.05403664759210041, 0.050942495074724, 0.021255390996473934, 0.05422692084985395, 0.044468868253452164, 0.04981100236275985, 0.024250216384027756, 0.06539545622804473, 0.012446080837699195, 0.013995649754971027, 0.061890060052035324, 0.00929336185612145, 0.013320451459637093, 0.02877534453516766, 0.014476017527011855, 0.03486825821680888, 0.053909293135568026, 0.05606214958994139, 0.023845112920107863, 0.04345863576858275, 0.06282083389739837, 0.051321961406257846, 0.08328728648203035, 0.024551490036350106, 0.045343514667042804, 0.014736135020822048, 0.05062241970952, 0.02876228082083887, 0.033534717475694996, 0.004309618041940755, 0.05959082717796969, 0.04267147276550532, 0.057794025408164154, 0.060236926581109726, 0.015937730523517296, 0.03207621247237248, 0.044632860864963264, 0.04416234115318906, 0.05510041430111855, 0.10788676043551777, 0.030591449805445252, 0.012254820284133237, 0.060344293803697636, 0.05942248318704867, 0.07026812016603447, 0.01721430400897178, 0.059281124643260436, 0.04403034420383554, 0.006382176990530664, 0.037660545278941436, 0.04179538610661703, 0.025662524370296348, 0.015879881309135067, 0.04906174539017582, 0.03274879170461528, 0.07874961747156997, 0.04021268292901017, 0.07377082737342966, 0.061286467037373976, 0.10323490601994338, 0.02221846885438408, 0.003262084975440596, 0.024035307653849165, 0.02895140303148618, 0.03994229219613537, 0.04084873508902327, 0.052302982958574454, 0.07201337570985479, 0.04691592928382659, 0.08913514970411217, 0.012822508673003365, 0.04203937744962112, 0.04117452163970278, 0.02080513622551676, 0.02873439522039506, 0.025478056143789042, 0.04794395799117704, 0.06465949088094697, 0.0023047858145042897, 0.012225906210651082, 0.023484574705963174, 0.03971438486910155, 0.03536913799302232, 0.046625899887012864, 0.052871010341351075, 0.12250412405738909, 0.037791301165857626, 0.03826010484068144, 0.04794568168900667, 0.012300583503900037, 0.003033910235840707, 0.0242430649532546, 0.03685502680919824, 0.050510544059497696, 0.055679186067033204, 0.05613772799411128, 0.041560580157825065, 0.02383306235705893, 0.029667589903598832, 0.0383471860550344, 0.010801260378361951, 0.018101893478043137, 0.00572558984370722, 0.04377343278798846, 0.011252466055955137, 0.06815439931327297, 0.03605711559254316, 0.01476283988825256, 0.06128753189958873, 0.02951090577088537, 0.03682923262878772, 0.008266190209636285, 0.01653817012876032, 0.01634536111997741, 0.03159183423004804, 0.02268764791229079, 0.048197410520045995, 0.041386046176475864, 0.023111313686615998, 0.05098301729547882, 0.010079667798333592, 0.028215491310543114, 0.06236480090827231, 0.017494263180020838, 0.02513601895301573, 0.0746795685300904, 0.05392001453606833, 0.014182978362265616, 0.03613785359888308, 0.05200989304050323, 0.09747410869045604, 0.09751147845940245, 0.12275696371591861, 0.024203105807124127, 0.038760268324685675, 0.06417484450784904, 0.027330113920353116, 0.04133541542556017, 0.041698372562325774, 0.040981448330586, 0.0015411053215258666, 0.0487413099636474, 0.04144511155543789, 0.07321463987952279, 0.07678847068980818, 0.07789963525870154, 0.0568395909372597, 0.058372437112754395, 0.03795964898721826, 0.12733754897189717, 0.030448689320755583, 0.01793023232640999, 0.08049203082919121, 0.014197598192690602, 0.01827734101924204, 0.04248678045828016, 0.027830951561730717, 0.1124030172884945, 0.03445396935867687, 0.0211770661670955, 0.04171071040834631, 0.0697688070396262, 0.029717383703457254, 0.01948655143590464, 0.040137165811874216, 0.04047518678670449, 0.030137584845144904, 0.05700868952478613, 0.020408009652108438, 0.04963061546966915, 0.028798470814381878, 0.023624383836924553, 0.017981956667837598, 0.06976752767279264, 0.0696271880259437, 0.00813766555379956, 0.054761408903305574, 0.014799858214363698, 0.028477531685043248, 0.01640075502256232, 0.03745356747399896, 0.07452453531685375, 0.042642093293609164, 0.06362079056881129, 0.005337212952004085, 0.10799706943573491, 0.019871456991700877, 0.0706005486990175, 0.020126112278610952, 0.006269266643005634, 0.05063510612554608, 0.048488730775012125, 0.03134404500615934, 0.013527786453074266, 0.03993201512663115, 0.04016247735689244, 0.04788495772968858, 0.09564946345504254, 0.09110980261597904, 0.01970978945703997, 0.030353677181166508, 0.02366854880575932, 0.028297736594874053, 0.07067568660263093, 0.025307925252784646, 0.015940830306780916, 0.014604711679801827, 0.006143685680017957, 0.019103291053925792, 0.07435884582059038, 0.04092177008128455, 0.022658710856170907, 0.026430301518449863, 0.06841415674575875, 0.03467047346695777, 0.06393888559673103, 0.057000668584218914, 0.0206765521978659, 0.04131894453518814, 0.07269392991738935, 0.02940992580636615, 0.02815012677362369, 0.04331024836808924, 0.039528957117469087, 0.0027028824467467327, 0.02700708145576139, 0.08043728618612213, 0.05852330280768295, 0.045128872152417905, 0.03340822486807743, 0.09695913672687546, 0.05570046032869047, 0.029049481437992186, 0.003549767030973829, 0.05268607671642977, 0.0321096847690041, 0.035874874766675696, 0.032376047794616995, 0.054571691059297135, 0.009763284019314715, 0.02632745804505483, 0.05632769864713473, 0.0733688610395597, 0.020008109840414217, 0.05892739503554279, 0.03166338684217584, 0.03453663407614635, 0.09609147320471464, 0.004632986148804306, 0.04128794478733213, 0.022937834991382498, 0.02743886393164435, 0.03790241838883489, 0.09470789543082637, 0.027747311997377587, 0.07138241803453815, 0.007810914689945358, 0.05383016391386909, 0.059665367533002174, 0.014497093563418717, 0.07182245127736561, 0.0757453500503494, 0.01702791098655472, 0.04658786745201196, 0.029733967591798114, 0.12280442286282779, 0.0818706903186056, 0.1274986649232526, 0.07340507401574044, 0.16506231540153105, 0.10666314182021927, 0.11591068874563902, 0.2821313061060444, 0.16054752943736894, 0.14187874813233653, 0.18383007526638048, 0.087677460584429, 0.17408799560319993, 0.2032026002604154, 0.13521678625575959, 0.08985321923729875, 0.16245321911429206, 0.133469155839374, 0.100974663190784, 0.23965727718126392, 0.16559709073795428, 0.08923666401495857, 0.10121244922160141, 0.11040339757117534, 0.31390713167286693, 0.17455621322076167, 0.09535817384359338, 0.1762043901028172, 0.20928598189305878, 0.17177819454621884, 0.1010460549244477, 0.14130196053414576, 0.16952837817370894, 0.10325150714526254, 0.08169891042334419, 0.09551444045838811, 0.134618517552172, 0.07490765588778643, 0.1084462880727745, 0.15223878495875867, 0.10705453614073415, 0.1279725975567295, 0.1700164681120265, 0.24221308439248995, 0.16511309170915237, 0.14056245586083782, 0.2088440717348168, 0.12459022744048028, 0.12958630048219236, 0.11774559955923788, 0.12231457092228437, 0.07640023265154132, 0.11750813528534867, 0.24744912681560366, 0.18472434502215157, 0.16025330570916976, 0.2760898754481347, 0.24763574583395837, 0.13614088747530215, 0.18602065772058504, 0.20459079754448709, 0.0809521125929971, 0.09593221884701522, 0.1555433052201425, 0.06604421012584241, 0.0937441491612023, 0.2697997420064865, 0.1187009035399364, 0.28171317531697215, 0.15110662958074003, 0.14056170509467203, 0.08251271030354886, 0.20199910677488775, 0.12962284287618053, 0.12613024802938586, 0.24905735987328717, 0.34916651224897755, 0.17188878699896798, 0.11879703991355435, 0.13651821642152726, 0.11523942718462599, 0.12346816144042438, 0.10822063687467769, 0.12098580673937837, 0.13912294600759784, 0.13805057613119004, 0.11249275682794471, 0.1813546000348945, 0.10190729862980305, 0.0978756613368469, 0.10443846079250498, 0.09296937379986049, 0.1785780369274078, 0.1805074140429497, 0.15518361161793434, 0.15497512845022066, 0.13870152104045116, 0.15118492376660148, 0.14336429986982577, 0.1437414909202245, 0.12483514574987274, 0.13508874232009535, 0.1912050045305683, 0.07797326396910415, 0.12834410423473006, 0.12801234985912038, 0.04759005984411605, 0.12585815658131916, 0.2762488846576983, 0.21937491552483654, 0.11481380405565424, 0.10205725268010171, 0.10218225524670656, 0.10495763091791062, 0.20011840688605464, 0.1326436961009618, 0.14653515311018114, 0.16089162548943875, 0.11077541752808517, 0.0783995152901738, 0.14301625080406666, 0.1659715391935841, 0.1210948976597959, 0.1170794478046798, 0.15605776390481382, 0.14648862092966033, 0.2237297116868919, 0.13303031003282917, 0.10750642076375024, 0.14896175193209804, 0.19631228289536892, 0.1345429046740455, 0.15202159903222515, 0.14650535228992664, 0.18071073377805372, 0.08468443933393686, 0.10899725850791701, 0.18258106083639208, 0.13126328227020082, 0.31255498648651187, 0.15473108348106185, 0.13055987565988494, 0.21775362832892328, 0.10679751364213806, 0.14153835994582023, 0.1766700796302288, 0.26554945555906145, 0.16648550758198385, 0.12160136604741698, 0.1499518592871966, 0.15590076184561177, 0.08940523400181725, 0.16083268268454462, 0.16004341293967542, 0.1726222395776741, 0.15337775851930344, 0.13309008021268154, 0.09836798774138575, 0.16193761129773435, 0.12830527889872753, 0.14763902452203537, 0.06967825544697624, 0.1714666112656555, 0.1597139798104763, 0.19863251806987872, 0.1666746546904887, 0.15974517491075302, 0.0885238192014156, 0.15369194649880932, 0.09707949680065918, 0.12692674198338103, 0.1765390939169353, 0.18625000912335613, 0.15175395855499854, 0.1979852810261711, 0.19211677173452993], [0.11391702919237076, 0.05177737769460486, 0.035663534091004444, 0.04310963292335791, 0.04688759935238669, 0.04156578572527055, 0.13540556564206077, 0.0645056527648722, 0.010311797227440102, 0.03239978502895082, 0.03036340458258506, 0.07949089180798301, 0.028848421662264777, 0.020718980062332366, 0.03156985325228063, 0.01967671361090916, 0.06402426226545246, 0.03345289545494222, 0.06214951871023063, 0.017394369145134286, 0.013479513337745542, 0.026324050869011593, 0.0506675920839752, 0.009003290324471891, 0.08468929633137681, 0.09415903939835488, 0.0786192752721329, 0.09170776488439691, 0.05723493444102426, 0.014510528830390786, 0.023289300809283892, 0.04022187215366191, 0.05690362439641068, 0.019299195057922797, 0.021448632844934062, 0.05541592761273346, 0.05028828663090545, 0.05500947200362721, 0.052814852266061696, 0.0635600857616913, 0.007897028718293916, 0.017629717101132678, 0.11842309707595457, 0.046633882523183866, 0.03769531800982453, 0.014666505289384195, 0.06127800176581068, 0.049815054967879295, 0.012086760703354113, 0.0804974164272989, 0.017209634703073292, 0.023859205107475003, 0.09878997195271716, 0.03033381826694935, 0.04328766792652108, 0.060458345143424894, 0.031961667005934065, 0.02358351879182362, 0.03678361592333644, 0.024002038370517474, 0.017901233983256163, 0.06794242278462456, 0.027288019304133715, 0.07102666212426079, 0.0370238802485889, 0.056241663142798416, 0.025263735386092338, 0.041868317677008535, 0.06110594990933615, 0.03216306769078778, 0.01958767695712947, 0.02102705849064214, 0.06512643679255439, 0.04200510267588881, 0.031082372353862853, 0.04105795753158389, 0.0390572231563349, 0.011309704315217753, 0.004015875273316558, 0.014753252297880189, 0.0537054754433132, 0.07157262234437851, 0.018138887863906644, 0.04201947448534831, 0.03194442236675851, 0.05890890550349028, 0.06330155406988437, 0.06595549714421073, 0.09996950220797332, 0.07315513783044393, 0.011582271695407409, 0.04733288795837472, 0.01288990334292213, 0.033996863846456817, 0.050951523420911644, 0.023497873992328683, 0.0352246308278653, 0.026445738190124114, 0.032780266426984346, 0.011843523956955442, 0.06842383243624242, 0.03920838762555392, 0.04275660428609099, 0.01825605718148572, 0.04675760189251554, 0.01857877171958887, 0.032466748774412184, 0.035219272042834954, 0.04210293210381943, 0.0244707003190753, 0.06302082498047142, 0.04067842608257648, 0.03700933606934644, 0.006177119672253368, 0.06188514559800106, 0.03893496701493859, 0.13012899716775264, 0.0908017126963504, 0.01423084545099447, 0.03513851488429693, 0.04863986077027456, 0.02305756304262867, 0.03483702481213597, 0.030010416164934158, 0.04440139505952116, 0.041687555400834936, 0.06139803625222656, 0.11639318624210936, 0.05774951569976346, 0.035098172694204316, 0.07242001518006287, 0.0367493181669664, 0.07571779386771303, 0.023347540728507504, 0.06089703773238486, 0.030762909858998273, 0.10645406876480389, 0.01694804249000886, 0.05647563788619253, 0.037354987279902545, 0.021286425218286536, 0.035618246803360606, 0.03798919699845776, 0.03562924399551365, 0.020809001139094754, 0.0706714577972889, 0.05254283359634781, 0.038306855356260654, 0.021564425119469245, 0.022913138231923504, 0.04076994294601102, 0.06154807074175728, 0.043533141649658644, 0.035021705628042264, 0.03030623718645544, 0.012621486244062263, 0.04937579164341573, 0.04618452599031791, 0.024568483781730457, 0.014518845672418755, 0.030997325102948857, 0.059024385597196326, 0.006400790533065917, 0.10501134134228192, 0.048502922553809426, 0.08285921187170091, 0.04641787254161412, 0.012846412531460726, 0.024569655896254608, 0.1402534926009755, 0.04455704497353685, 0.05064982650501113, 0.004925645142418123, 0.070528406199188, 0.0513967813833827, 0.02914353979811553, 0.0341966480857903, 0.12851550874690856, 0.010612052940433065, 0.058575316347301974, 0.029603211704881924, 0.031111583286415667, 0.03330471106774865, 0.03786139438048967, 0.028741071676655162, 0.027104575720225132, 0.051533462960393205, 0.05490248782500144, 0.03444987844916121, 0.01627778833461625, 0.05478772785394423, 0.045337286372218406, 0.029495917260646824, 0.04183220046181833, 0.02180070770273526, 0.03319058311922896, 0.027722676524952538, 0.026325221068315932, 0.08312470730273955, 0.10238674709633475, 0.038369843105395, 0.06033100600865099, 0.05183872218514162, 0.06507886273245658, 0.006745214087723364, 0.055194742707235206, 0.044796202301738725, 0.007933306811948218, 0.07104210645681427, 0.03304797202168453, 0.01917402969763404, 0.03346233748860898, 0.03443850587392527, 0.028339630113013332, 0.047829347407265056, 0.07884482687879955, 0.010735462044155406, 0.04641513377728482, 0.04275458947485013, 0.06865198108097238, 0.0087085954521993, 0.02422458116686152, 0.014973997660431893, 0.03381367690200287, 0.027273281687690366, 0.05486104629873749, 0.030512257381492568, 0.06541214162303556, 0.0806927458653527, 0.053290163857802275, 0.05354728594782853, 0.10221532726239774, 0.01830118167544565, 0.027836113079120556, 0.06869979262832673, 0.02794871076701149, 0.017620397641533808, 0.026217867252266696, 0.049035637113716335, 0.041353962414207, 0.018621969502419233, 0.006309817113252658, 0.03378360029009562, 0.04658762613431581, 0.026872204015812567, 0.017245667648591825, 0.07013747153142769, 0.08246277669264425, 0.046042213667063944, 0.03646965777020782, 0.0629689033714033, 0.07712023272629707, 0.053019160254588055, 0.022607323593429984, 0.039936416301756136, 0.05330870701600948, 0.03638924918167534, 0.012529995236095163, 0.026247522515815594, 0.023357181945034576, 0.09125419486794742, 0.01728124860223503, 0.053212762164372596, 0.041346569665737694, 0.015087301106823069, 0.08026587401306437, 0.04234027380364076, 0.043252106125075976, 0.028913822588360602, 0.012725759429045984, 0.06923141934338116, 0.02886997746123422, 0.06999163903416165, 0.02775209430124491, 0.05546352848590863, 0.007803783847785165, 0.09138731030567039, 0.034100435103379914, 0.05398695912933158, 0.010972798955927213, 0.0724500688093324, 0.013676564558409156, 0.07973694392750341, 0.007262637053856687, 0.03989894694137958, 0.10161273016203796, 0.0168660442690335, 0.057700520546566096, 0.01980479010531018, 0.019949080850628596, 0.05936475463151451, 0.08634262132428347, 0.09847686415718448, 0.035202847117738384, 0.04361529308821886, 0.019864123615045703, 0.05313192456660252, 0.033887355408120545, 0.03403937406537514, 0.039277898613363504, 0.054824392822000294, 0.06349570373253477, 0.0696138734178197, 0.03184862498704705, 0.07695087366887639, 0.045051558559099515, 0.03885080076513752, 0.0372961325751197, 0.029509611082293337, 0.06148892109312358, 0.05279073581820535, 0.06258783208566808, 0.043595336497791355, 0.06508702156885017, 0.052923341807458675, 0.022301556835431727, 0.09012826778475316, 0.03499174775976328, 0.04153649818392531, 0.06143798390703817, 0.009754906847862708, 0.05707936496624062, 0.03261287238508944, 0.024139204498140082, 0.03657307963998568, 0.027351338386295304, 0.04566618707031012, 0.06781791051429126, 0.05027517120564177, 0.007270375499501825, 0.012971566400430616, 0.01086450380934102, 0.024863799185221715, 0.03971730749453268, 0.02929744686210348, 0.04399041570122204, 0.06949208842049684, 0.050713362007011334, 0.059842161473728, 0.022949324395026893, 0.048379819885256796, 0.054492619294192524, 0.04781369623097201, 0.027937474172382105, 0.05381818229873335, 0.042535415550153104, 0.033194095632361795, 0.06585387558105492, 0.030090748144674207, 0.024542693431759556, 0.03959959042408774, 0.013545087591234236, 0.21259552769122586, 0.19491075568141478, 0.10256925222253609, 0.3002614816350322, 0.11392726412703914, 0.15167698204036684, 0.20650600203342978, 0.13891797152257737, 0.1036308509027285, 0.14511165449455862, 0.10626502124772919, 0.1925817871045682, 0.08172337161076647, 0.1352341458081238, 0.10588196196383047, 0.10969896440304096, 0.25890842320457585, 0.19278435607350644, 0.07548484185169782, 0.16752550258271157, 0.0634400129708792, 0.17465793437534766, 0.16356211606292956, 0.12152211425165016, 0.1261540197376763, 0.19777886629585298, 0.20659770275796616, 0.18413707734115664, 0.16233614555770354, 0.13669124504010524, 0.17232027836143973, 0.17990110141615714, 0.23676374776949807, 0.09710579659909972, 0.08430376258348266, 0.143873012895065, 0.12739730382999107, 0.1426369913162724, 0.14391309461526333, 0.17560275061236275, 0.20833831580896534, 0.09096226174264185, 0.21207299443983266, 0.28895855911316415, 0.0925195116489645, 0.1185370373329328, 0.1038304244678828, 0.16796462418090913, 0.10706553716332683, 0.230440488686004, 0.128667852991531, 0.21947648346183762, 0.21035038445505405, 0.17111018119800478, 0.21569534925924194, 0.18818462628030008, 0.10415218905695986, 0.09941030398852403, 0.1557623144359358, 0.1462472879117535, 0.08493793016720204, 0.14787128705891872, 0.09037112531762931, 0.18641553008027617, 0.116464355810275, 0.19427288023214187, 0.1569130551069975, 0.1986470124534061, 0.2377478336735118, 0.12450647870859793, 0.1228257047853643, 0.169990926740631, 0.1918948360628659, 0.15141599120632296, 0.1358553052188889, 0.14267980030948116, 0.14910649658451158, 0.13891072433081367, 0.1434804234773882, 0.10333860368137399, 0.12217418531015997, 0.15034447934839035, 0.1489251788945929, 0.11437797663553108, 0.1999702301597403, 0.15248863687438352, 0.16744587540386185, 0.16687965981902617, 0.20020817706902183, 0.3700968004282444, 0.1239901201258744, 0.1747674389832443, 0.09957128970493233, 0.12186132266276306, 0.17806659662915816, 0.07471041889080117, 0.29351880473475306, 0.13672999376731534, 0.10860078502446414, 0.08055583829240454, 0.13226716388617793, 0.15567525620422057, 0.1165920703281318, 0.0718670682380757, 0.14937150171927868, 0.10441801390580593, 0.1424697083571265, 0.11340973342979148, 0.1957384370748074, 0.12883590203860115, 0.15835945975155602, 0.10365671403105221, 0.14149765003352396, 0.13443042764500265, 0.23984705248186666, 0.1618097665449304, 0.24099555617618948, 0.14392014262416672, 0.18424065242851936, 0.13721941669862117, 0.13411196489487925, 0.12471187454197677, 0.12196091409291952, 0.0842877360241067, 0.19214868695745546, 0.12303028090466415, 0.21222233561979187, 0.2083016968061847, 0.16469437869325762, 0.11679004276952437, 0.20727967422816063, 0.12911722484615543, 0.1549197249715367, 0.1136522998492564, 0.14551070969431631, 0.10378772272698342, 0.2843345136892411, 0.22637570276856425, 0.28965857961485464, 0.11560025459696209, 0.22389575358360048, 0.13423265438647042, 0.1396451115367874, 0.11451311454537416, 0.1213827551973443, 0.15318024573066544, 0.16103581855854682, 0.08788746826711201, 0.13786798673531703, 0.08384408684627664, 0.09583366163555654, 0.11923989235994317, 0.1267349135671412, 0.10233180327040535, 0.12701940797870198, 0.10295888454082514, 0.1477309703947075, 0.0955799792803103, 0.13161335380808, 0.09778582986684577, 0.14094658766783055, 0.19260910579994803, 0.1308785069493517, 0.17981447219367952, 0.1364888905757858, 0.17499642266381174, 0.10687484255721492, 0.12797241369562765, 0.14786603169575815, 0.2606766460643661, 0.09295839575990554, 0.1540429220204392, 0.10412293982001082, 0.07759738292905592, 0.17754459963931193, 0.07425227532944373], [0.023558463886260025, 0.04589122539806751, 0.05392623900045311, 0.0074880182059601915, 0.061574156035579024, 0.009133199684231753, 0.07098271166004481, 0.018734166909369732, 0.036607695322844296, 0.0235944144773267, 0.03072283388445935, 0.042909825701386704, 0.04163696295431545, 0.04200905952001772, 0.062483494740820704, 0.0037134831326247585, 0.06429769053694702, 0.04995681187738815, 0.019571648482533715, 0.06160716293379665, 0.028149374092238087, 0.0861936861709241, 0.047120022767734145, 0.022897707305908687, 0.026405644978606896, 0.01529352431516013, 0.024949499526091164, 0.02533076999468669, 0.028242903851693677, 0.01027308680462621, 0.007256559582592379, 0.07083274228798767, 0.03409248311072588, 0.04387190189933585, 0.04784625879819355, 0.041428422330007444, 0.014444906696406825, 0.009153272145457808, 0.01587016348381557, 0.018593752568948175, 0.018860040900988445, 0.01360647421660683, 0.06815276754599425, 0.059971618841612534, 0.037155812080468864, 0.016407015876123504, 0.015830043459221, 0.029109297583120006, 0.07625642262639538, 0.06887055362664884, 0.040905145973327665, 0.08049601448639747, 0.0609063686833026, 0.01353782412010215, 0.04318064161305947, 0.017657501194926522, 0.07065542357703371, 0.06513919215649366, 0.024408281390224735, 0.058803966779622345, 0.04621142716777902, 0.03243572987435806, 0.035784618117876595, 0.013242865905105589, 0.01250982988670829, 0.021824889268065174, 0.036959207106021144, 0.034741930318095034, 0.09487059718418507, 0.05971877152220376, 0.05095521596470668, 0.05101375657344057, 0.10054966825391017, 0.03426372291400068, 0.0429622644198037, 0.021608233857419223, 0.05386583679806321, 0.06047480071203844, 0.017686604875169935, 0.05289499272382068, 0.01862774772058812, 0.0717123644426465, 0.045124643347075874, 0.045997087257884206, 0.026037516748352398, 0.00800781556585383, 0.06272076366228924, 0.03833738779048285, 0.036911238510642326, 0.049717171913793975, 0.01668317716628794, 0.0888131476277786, 0.015676485922848506, 0.11094201100809921, 0.0020505449332807574, 0.0654879077187469, 0.020137412075494087, 0.015904237159467753, 0.04165854365114243, 0.0617814555974497, 0.02857129893175537, 0.02636499060768514, 0.07707614436625473, 0.03857995037950816, 0.018833430836938562, 0.10910247302343769, 0.05312170495369262, 0.022167209911370472, 0.013234876565665249, 0.04388146267663087, 0.025458882878264113, 0.023559116976215475, 0.05016278610714982, 0.07404130237597613, 0.0719028445441396, 0.04338126854910966, 0.023113192517250296, 0.0516366052080787, 0.023320392487690817, 0.07384639428628069, 0.05473733075984544, 0.05875798618240703, 0.026521316594294003, 0.04966629984518213, 0.04839162913060958, 0.017613702033075596, 0.07731668065272032, 0.004741021304301197, 0.05403755157585106, 0.055989581911313924, 0.028378262011814984, 0.05792042991567043, 0.032160508957120686, 0.019746188209542347, 0.024687756010661685, 0.03221488204754649, 0.07477385863181084, 0.08583383935113108, 0.05399694125498495, 0.06408885113834854, 0.029910661941093784, 0.003993643162351463, 0.02686115128228501, 0.018570949961881966, 0.028678576139012174, 0.055293219479461836, 0.026981022975016988, 0.05347079972946837, 0.017754202558388634, 0.05152398262233023, 0.04359859237146955, 0.021118012279452338, 0.034075621515512466, 0.07620416776908022, 0.02171485797472058, 0.05355427650013759, 0.05699433686752474, 0.0520399734828501, 0.01933845323360255, 0.05456529805556901, 0.02861675858918217, 0.0461880499947696, 0.018162040956198208, 0.026248566310612426, 0.003640022243358075, 0.03505009301607648, 0.02228244294172093, 0.03611800809120459, 0.051087787480003415, 0.076690970679685, 0.01396784172092955, 0.012024895273028843, 0.0907330942009726, 0.025110958301792705, 0.018216391063986287, 0.019717965530411854, 0.11185279761951779, 0.030307280981252273, 0.10679628790145922, 0.01818889233794424, 0.010182019060237274, 0.0694723233520504, 0.08941369927338055, 0.046813388415161646, 0.0641924147343924, 0.02586704877866132, 0.023371900409279812, 0.012854002547570536, 0.018283080933014714, 0.05111292665523868, 0.08533651805332593, 0.03200646208208655, 0.02349488624942399, 0.047884409976822716, 0.011130371750632842, 0.030608696359840613, 0.11645411321472739, 0.026532825150136507, 0.01785855714021431, 0.03635946368317931, 0.03522764538384734, 0.024621010600258748, 0.06401983810768974, 0.018978660039964224, 0.0427335910048456, 0.051286606448552305, 0.0102242611483821, 0.005930763511588016, 0.02957738305051481, 0.05763549883399279, 0.09889621302605638, 0.04288501211351926, 0.07846971958755486, 0.024055628136040706, 0.021398300868308833, 0.02739098343637682, 0.04162316571079916, 0.019953148777506525, 0.027258521088609294, 0.017187157683374903, 0.09899919056483815, 0.08063531991454863, 0.10954318808451777, 0.07315509186516847, 0.03920454952505328, 0.03817891101202658, 0.055115337693883534, 0.05435780697171727, 0.05383802397597221, 0.0649472488270652, 0.06269167147336469, 0.03432613992763143, 0.06030496284966508, 0.0019500335991089685, 0.010206049323202142, 0.06499997099801418, 0.010849828437541523, 0.057231655584708344, 0.009419120934551523, 0.01998352799414387, 0.020609820194001642, 0.03888755000286526, 0.017671666160646467, 0.03859722949264031, 0.04592602877246757, 0.01916242155036138, 0.01131033729536519, 0.0828930193317994, 0.03907504619189328, 0.020230141273068807, 0.03276668368808685, 0.04661182302140421, 0.02529227982215103, 0.007256453287892885, 0.07535982396333449, 0.07931020997104146, 0.04659505335674171, 0.11494105125987723, 0.020718625746667385, 0.060658075756603674, 0.016539989587580486, 0.06391898263245821, 0.06153456844209183, 0.08095640268537306, 0.05461302916369131, 0.027962159440522234, 0.039241471132563974, 0.05657281613938751, 0.06481515228628151, 0.038125024387432684, 0.031367044880866043, 0.0479092120733713, 0.050158335136309753, 0.03856965798824545, 0.0737118079597431, 0.04616088834741423, 0.03736815633132093, 0.040017204103811134, 0.030368661860965436, 0.015517680684194691, 0.026103411801159385, 0.06423642648564232, 0.03654257018840121, 0.02018548409274269, 0.013164596617101662, 0.01690677716396749, 0.023547346035258907, 0.05220827533893528, 0.05621794123022307, 0.04795559103630724, 0.03332492429763079, 0.06001573401473223, 0.05827057423190244, 0.036951530905019854, 0.03355781502661205, 0.047750283303039695, 0.03542492451566843, 0.08647450336044835, 0.009270281542182691, 0.026774583346841317, 0.03588793273534506, 0.13345826206909073, 0.05042098455070969, 0.015409698676047547, 0.027861750211506605, 0.026753276526447267, 0.06118070476898744, 0.05636830513756122, 0.01744120201516536, 0.014682067407956047, 0.024793799816360398, 0.05438147908857754, 0.007373567064097452, 0.026782474052461407, 0.008022378897294402, 0.060760252733504584, 0.047708669406992775, 0.05260290638093026, 0.038485507060202866, 0.08539281019400205, 0.028223933599468683, 0.04208466473726496, 0.034444508172812006, 0.026319739709217704, 0.047439446958202514, 0.0670713501712007, 0.06948099546735326, 0.032985290707719904, 0.026924767223517262, 0.07111517592303215, 0.037923087441031976, 0.04695444818465941, 0.05401258477039876, 0.03083979061263944, 0.006570278389018871, 0.04110493404310077, 0.039079952985048294, 0.04768815357238055, 0.036931869258443197, 0.050322021312651136, 0.04507076821380085, 0.018370020421101682, 0.04451495610297688, 0.038374290245795445, 0.045848879888052904, 0.08159256209769557, 0.03533329273904524, 0.0353757914666447, 0.016408136279712764, 0.07128325561361928, 0.07353494124066445, 0.07968374678204138, 0.16394276983074604, 0.16495711620776884, 0.19460595993986055, 0.08511450577286944, 0.1467419662062199, 0.1213067286317387, 0.1858606832402368, 0.11056321117305949, 0.14865556191052162, 0.11015756761715298, 0.22838401758382398, 0.09421218291766222, 0.15660436763878793, 0.1978802044064768, 0.17771065685777895, 0.07949895105294644, 0.12319061544633682, 0.1706203752227368, 0.19668617976769326, 0.09113047166817612, 0.16574278533939393, 0.1697919124196614, 0.11703139877006893, 0.23086666339828124, 0.22165676969433987, 0.08913482028630473, 0.12326691780359515, 0.09030258343104394, 0.13093093800688946, 0.16286100771638656, 0.15035607791956396, 0.12403444597317327, 0.16288736114098182, 0.15628592021042303, 0.17405565137103682, 0.12094547987104425, 0.11387996585859407, 0.06464377841761997, 0.20184899950700425, 0.1557903226104475, 0.17178916492529456, 0.2019175950197443, 0.17709489070600082, 0.18749641885440196, 0.19520625111556825, 0.14543845228129818, 0.1704586540619212, 0.12797091216329606, 0.2143982704728842, 0.18349170955198427, 0.1446567514851209, 0.16633901624910294, 0.182485866750921, 0.23846810953992031, 0.16766968033006116, 0.17595441561312447, 0.14759665985982265, 0.11996889396780923, 0.12099814841583853, 0.13825135245438547, 0.2344277311837481, 0.27535191827243377, 0.08571832095302882, 0.1283058151602745, 0.18798205731136186, 0.13769645964907062, 0.13725146981737307, 0.12770073593504008, 0.22853017183801821, 0.13703048409473512, 0.1594117121590722, 0.15654044526238597, 0.11940470851597287, 0.14256124054231953, 0.10803342030774202, 0.1538401845121576, 0.07123370504667682, 0.11892961908973033, 0.14427781375425477, 0.1870491154371731, 0.12943461507318482, 0.19480126639527662, 0.1387696262569197, 0.23764415133383968, 0.10314590192490047, 0.16325610990245498, 0.11491898792765795, 0.15893258544946873, 0.15429969937089952, 0.14880326366232288, 0.11632082157678182, 0.15873165590868843, 0.13234484520169998, 0.2173174791518719, 0.1914399790187036, 0.16768921557213032, 0.12263596012827852, 0.1287764382939185, 0.1725963917711089, 0.16219933757618551, 0.11434428408862123, 0.19009547938983287, 0.12309814863387616, 0.13792126048957148, 0.09438754810440926, 0.18194631102585024, 0.22039330684609953, 0.25449496002927907, 0.08282466130631586, 0.0960712408226344, 0.12463484440119037, 0.105319224418171, 0.18587436557056444, 0.14586721637075947, 0.18609536661496087, 0.12655410915613174, 0.13300979419821693, 0.08219693652203969, 0.09582945581285224, 0.19211249696391244, 0.11650824498745704, 0.3128101244088142, 0.11988591132385117, 0.14150650600992865, 0.12436295213598399, 0.13929456502439516, 0.16875131987035277, 0.10795988352789034, 0.114499447536805, 0.3290731904487456, 0.1424652497254072, 0.17745233200971158, 0.10504638986481775, 0.16425338784052482, 0.2090074170020319, 0.08198903558114845, 0.14138616891878267, 0.2535510324542561, 0.1970669714313361, 0.202696752404013, 0.1035027226973926, 0.1267280417584604, 0.11551835213697727, 0.21358278519924612, 0.10479696695843052, 0.18640468227526835, 0.13392736834864463, 0.15881146694863998, 0.1796615916875101, 0.16877755072088013, 0.127203858968231, 0.11566689658549525, 0.09609376380760824, 0.1810104886610662, 0.11380025441007269, 0.13173948252393355, 0.16881162631175212, 0.16627579867359132, 0.11266082119677337, 0.12384444084619323, 0.10934049654151164, 0.16398890364554622, 0.06652558913394328, 0.0985369484330858, 0.15133870825652154, 0.08143811877216063, 0.21188988410417112, 0.10600944665530998, 0.24747989290664274, 0.1330692579428996, 0.1054966044161589, 0.13088622911562844, 0.1778489050845946, 0.13913455990052995, 0.1293005803299527, 0.15537248293478645], [0.03931229979160332, 0.03915337102127172, 0.04725182436466698, 0.05865019378102115, 0.03473339992905817, 0.017928100686760682, 0.07127629187438758, 0.038796013987232605, 0.05048552745833032, 0.037197069745630994, 0.04227376588049435, 0.03519898986503963, 0.02251780621947781, 0.050553241969957474, 0.04104824353670401, 0.03897856890914902, 0.01146605424207425, 0.05127960440492438, 0.07628115194459116, 0.07099575813739531, 0.012509814564949803, 0.02719200550458364, 0.043545808913486625, 0.05804509157314897, 0.06095824049665563, 0.027235438859450723, 0.04782199679363159, 0.02824869547640124, 0.022175853298376166, 0.02648497338316614, 0.06123605079107708, 0.018991009377303626, 0.04313723890170936, 0.013925317137862646, 0.04156603853428557, 0.04076805070883805, 0.06983761705698506, 0.06374460186869388, 0.01941805551459472, 0.02628467969536301, 0.03995090302440428, 0.014249399142910638, 0.026120832640557524, 0.055319657173728755, 0.09237596209371284, 0.03955310420884241, 0.11635110503242863, 0.04677403447849136, 0.014181157945835543, 0.07713490331004705, 0.1095512473294812, 0.04935924797469089, 0.022291775807858478, 0.07007499706120261, 0.0332056405773807, 0.050567609948977355, 0.03146566529457848, 0.04002684915077783, 0.02784507822305445, 0.027937175398091638, 0.04211291039903318, 0.01976699132712618, 0.02787810427347018, 0.03963268925285628, 0.0067645453588826765, 0.04246613821916042, 0.058549851584698887, 0.0460168446654514, 0.03957425206599217, 0.03609489904896867, 0.08182510808711091, 0.05043316534870575, 0.03678076607625812, 0.03771685657181567, 0.052887213100949605, 0.05686793619045808, 0.017958460751199917, 0.01464767484820538, 0.06423053909994422, 0.09000675857908304, 0.025082335341721777, 0.010152022887562073, 0.06677321173370847, 0.026027703162042365, 0.058297866114204934, 0.023410875132427584, 0.013832413655285154, 0.032641286586201, 0.01387749792962906, 0.07068697873863482, 0.05450826664004595, 0.06737685071364527, 0.027168965410260905, 0.013926157919359545, 0.013009164080534492, 0.03423242822229382, 0.004549662595719941, 0.02233739825896919, 0.012011070258825297, 0.041239359491174264, 0.021058956476589365, 0.03283931265374826, 0.03906944991960641, 0.023081809725432147, 0.04708031643061869, 0.040245272309309056, 0.028694386278549512, 0.04417868563905359, 0.06644676634741407, 0.03258330139121221, 0.061956613940457185, 0.03279606699042263, 0.021040242863819007, 0.0631061748361155, 0.048720591115735234, 0.05078452008385813, 0.015758660344046452, 0.04358137837581096, 0.0445907719944033, 0.029135811886179353, 0.056087097243195584, 0.013163135304386097, 0.031557718419560024, 0.020386566851107825, 0.00976369100352449, 0.06402489045755037, 0.019342004051131588, 0.11280714399031094, 0.10653782515756546, 0.026258563758024288, 0.05275305195320999, 0.0394864890333866, 0.0502923775404211, 0.07830189270598274, 0.06488096689985645, 0.005013790740180882, 0.051291930759626056, 0.022396549822822697, 0.0835712369711649, 0.019497680778224624, 0.010324776672097224, 0.009317537675791932, 0.028856364078819755, 0.016810663772987264, 0.04328719678244764, 0.08207065458860129, 0.032854301163986806, 0.01634334056307712, 0.027903685864481716, 0.020450012337776925, 0.020069370061279308, 0.02323662268839056, 0.02176057618682183, 0.024244702466192748, 0.05599884008387885, 0.03541210020381597, 0.14695089370492967, 0.07959380805973085, 0.028261900916996024, 0.046120423583253745, 0.006197822719602095, 0.04305542454183583, 0.05599999687664452, 0.05658362180955949, 0.05761779454206267, 0.09776638655532753, 0.004685677676236317, 0.03062706714826486, 0.13066509017540565, 0.06881727221151514, 0.03761355727610569, 0.02507420714884516, 0.02517920715974704, 0.12442770954822341, 0.015722424385227984, 0.017362080454345674, 0.05518802411613926, 0.04038597584792203, 0.02121249773359347, 0.0705672238743113, 0.033511700364009994, 0.008800871700288789, 0.039264993862279, 0.045023672958655704, 0.025731173509191123, 0.018789505270580133, 0.047080864183484554, 0.029971814909649473, 0.03825392634157212, 0.043984168254199534, 0.040958955989129124, 0.039676053659810175, 0.04510503915709354, 0.028745888454479077, 0.07303379716411715, 0.04543900752680437, 0.09426629170775415, 0.03315481064360469, 0.05032522739061425, 0.026782638761365128, 0.028640166405708562, 0.05146602807085841, 0.013835481837421898, 0.056891037571814754, 0.011530157606748324, 0.02250534962982901, 0.036176609986972426, 0.04203724006431238, 0.060160693171764576, 0.030062615480874817, 0.05223534888617935, 0.011071427988128798, 0.03130284096715191, 0.02001093287441519, 0.008069488516588124, 0.04934408326422976, 0.00912035430496138, 0.02026315008650624, 0.04755547097433479, 0.07253262244405285, 0.05629343919516091, 0.03955835574156335, 0.009327727602794766, 0.07545507933583952, 0.04480330776723643, 0.06047080939395293, 0.09644113105511475, 0.013050137335554728, 0.054893172195842194, 0.052814928874854124, 0.05423969919643095, 0.06606651860619746, 0.011741036714445199, 0.007276050295800932, 0.14947481633674714, 0.06329918685819834, 0.005936101708005393, 0.06420553015965609, 0.07398491830474908, 0.002626420168634204, 0.06260202003402576, 0.05564039520498726, 0.01525847770784411, 0.05176764454752688, 0.034067010687243555, 0.057177527642418305, 0.06885890142932054, 0.048070324194287105, 0.008802646151443404, 0.13448154103131066, 0.02426710670753833, 0.07414771198865867, 0.051290130453004, 0.045758447039031216, 0.030896318325352286, 0.06102602012575634, 0.012140504644072105, 0.058491705511246, 0.05137099869429104, 0.015454148055024207, 0.05641847240528273, 0.0276976848216427, 0.012190252478655067, 0.014721854184303555, 0.00995900224699008, 0.04998127306481043, 0.012589872668256924, 0.062086753126594334, 0.027515848107155294, 0.0537388002680194, 0.012521193843455085, 0.02559863646785098, 0.04872465138173392, 0.018401299791050055, 0.053976892734006535, 0.010923385327201217, 0.10822145658875666, 0.07358890447405077, 0.044809225796451496, 0.021507522023673502, 0.044004032914076126, 0.03906559649734728, 0.03148528097587968, 0.008492247434332967, 0.035738304272414215, 0.08587072648468518, 0.04463127506296, 0.07509920851237352, 0.007440349821286697, 0.012977033395380264, 0.05108097695835656, 0.03531215637321434, 0.03697550179617059, 0.06730796408749397, 0.08114404826154632, 0.04943111851330727, 0.03752275287444073, 0.06875969304312622, 0.02800986182034737, 0.02028598333708942, 0.0672160335365803, 0.018622658981551087, 0.013810719002879435, 0.012187696617817687, 0.013441257779636692, 0.06018918781210819, 0.034855292178690434, 0.0320271770995591, 0.036461897299534855, 0.05555449759647731, 0.03032836372092847, 0.0221185345998815, 0.0232384555537494, 0.017431099230663914, 0.067517404865113, 0.02072568141645001, 0.04271272660022782, 0.02416489334146102, 0.03317153051255211, 0.01822216162127593, 0.011888957758914801, 0.03632623078902403, 0.087245992204595, 0.07685740328123493, 0.1085746844088839, 0.015402934119676151, 0.014161967443332318, 0.03997347580509321, 0.03425102883709535, 0.0894330353325894, 0.08958365587938218, 0.04962879601084898, 0.09613219077789015, 0.10901929119661932, 0.01842237678506682, 0.05989463083566197, 0.056025293099904255, 0.03272958204991395, 0.04179871092820841, 0.04986783459542259, 0.056893247735476306, 0.11400443982453116, 0.05132628597259041, 0.029617805679839466, 0.023426171993055654, 0.020225621354315552, 0.08130659679732016, 0.044082369234773426, 0.014457116222700045, 0.021453147018027884, 0.017718883989859494, 0.06418987132248379, 0.1197888250012071, 0.1695795222035339, 0.18834437093427106, 0.23865292059077373, 0.1060624446179117, 0.1281201307691874, 0.12506460440495323, 0.19870007170304177, 0.2302565203318673, 0.11353022373852231, 0.159883086058882, 0.12930549861442658, 0.2932369150221348, 0.20203566449063443, 0.12993721471678826, 0.21807431273402708, 0.19750791631879347, 0.08933886780493683, 0.17100254584464336, 0.12914393067119584, 0.23591031050009115, 0.15499394356964097, 0.1037913156793483, 0.13130209228444484, 0.15999531793978908, 0.07297513015087574, 0.11354271097168808, 0.14102733333504971, 0.1294026998502593, 0.11352375029556214, 0.16757442495755612, 0.08296483241382145, 0.20523498555825603, 0.10108782203807946, 0.1969198365845988, 0.09861940247637611, 0.16997205033417673, 0.1603493271695991, 0.17166842946842795, 0.13614419697513505, 0.1307842781346652, 0.13867642400005173, 0.12257988249222118, 0.15747540960869483, 0.20296117531195765, 0.1691730053073937, 0.1930526094210725, 0.24552440751464139, 0.22874947216722274, 0.0993487871282043, 0.19738175695942295, 0.2175490675313819, 0.13377082594219716, 0.17092947637842548, 0.12346472170564438, 0.08773089521714757, 0.07400446120769748, 0.08378489123236749, 0.23444545845831596, 0.10907662521687247, 0.1613077644499079, 0.19995950492880038, 0.16443904158809494, 0.1019890631939615, 0.1751081489266888, 0.19724743110277962, 0.21214462366075287, 0.14305447859148826, 0.10723327977522727, 0.17537629502194543, 0.22415919589900205, 0.1408334518031728, 0.07575686435185133, 0.27650310327449157, 0.17840871617438334, 0.14771365680761878, 0.1216310442936036, 0.12217865160275852, 0.1319279707968235, 0.18456412539366754, 0.11514313759342318, 0.15217591978369222, 0.11672580629707345, 0.11144847173484103, 0.1940237331174074, 0.13543296094623306, 0.07706305192362878, 0.1099835201016357, 0.09850350103431171, 0.1663498180888353, 0.10878319822011456, 0.19907496448966766, 0.15292950515304843, 0.08803333906877427, 0.08712188596086157, 0.1285843494077844, 0.11948098022971423, 0.12037502781998728, 0.09222037729717071, 0.08239261836053864, 0.12867759762992784, 0.1585052462835466, 0.16748603373285265, 0.05531732826643894, 0.12934260791347874, 0.15971776428482226, 0.1618741026088115, 0.13177144371213453, 0.13413517735898495, 0.10622334606464832, 0.1416506990790367, 0.1769219846614907, 0.07009206550015558, 0.2039373705103513, 0.10085490832646048, 0.11228041257709266, 0.15561110400144132, 0.1831638392421507, 0.2231753398213656, 0.16001284603149662, 0.14224838555580185, 0.11870160834082674, 0.157012615893637, 0.18781241480140917, 0.1579618907623714, 0.0886585510846588, 0.20388394353851197, 0.13191079510556114, 0.162410180294706, 0.17795772021335943, 0.21859896038809132, 0.13127074396658328, 0.1481537896418764, 0.1477520531343837, 0.13856406954507675, 0.08933479221717966, 0.13103509532107463, 0.0915619170653724, 0.203948846507457, 0.1177636945560094, 0.1820350699727574, 0.1621341894591047, 0.10322289376129067, 0.1697926631858272, 0.1285486956757884, 0.14563280878768814, 0.22876022804167964, 0.1285769030331604, 0.1723589504798574, 0.11997778058773088, 0.0940242768715947, 0.1179020576960137, 0.17850090719519124, 0.18950217493599464, 0.303461124459582, 0.09722277056425811, 0.20067228845530943, 0.188000014412307, 0.08761341563395916, 0.08897872987173258, 0.2289119900594796, 0.14590077102184296, 0.09535866413986492, 0.13577466680397912, 0.2907688248782389, 0.2616612835516853, 0.1770961624119551, 0.09865279624899549, 0.16584678943599426, 0.22536412962982733, 0.18401608141439577, 0.08395775131160214, 0.12748693611713188, 0.15141858058350702, 0.22646649950934997, 0.22565850657561135], [0.04342745982050415, 0.02449791559258536, 0.10174444365885951, 0.03894935031571696, 0.060535731515096086, 0.06521639849750266, 0.0773133481702497, 0.0581419748824931, 0.05304358696805374, 0.028816433660986445, 0.06323615314378854, 0.004056958892878386, 0.026019061690256483, 0.039799512559247595, 0.06247656547554559, 0.03591942660991223, 0.04222818747943929, 0.03174698427169314, 0.022641257458035986, 0.07461749242558595, 0.013289824222034265, 0.024360713075786352, 0.027014275021370382, 0.03489191501191066, 0.053345326018790086, 0.12477717587664244, 0.03496947375336482, 0.008802448883802902, 0.0032056180709567404, 0.019959513052937486, 0.03386421572236765, 0.027728462404000665, 0.0372063240877563, 0.0071187590384074765, 0.03316902923547933, 0.06273702770892171, 0.002543285025298716, 0.046708579926240834, 0.031876525909249345, 0.014511180962736328, 0.07922841476336603, 0.09569024997613124, 0.03525026796025134, 0.049088386097742666, 0.03781071000341927, 0.025836604444550413, 0.05167144305643536, 0.00326969558016337, 0.04852009441463217, 0.04621676680061125, 0.021140948951905294, 0.036168577555086345, 0.03913259088632561, 0.05136643664070195, 0.009535218686646512, 0.0012880050734008454, 0.09682051311697691, 0.030784942547700582, 0.04115222848110622, 0.055926054070192965, 0.09002951139043416, 0.04226156976073981, 0.051360081941370046, 0.014070000503242258, 0.04030538339828772, 0.04505963312582143, 0.00509017976113565, 0.1154554486575146, 0.00940436225069026, 0.05473749546874916, 0.08803746828268613, 0.030579228787833167, 0.058957222668874654, 0.06136592567688035, 0.07499554915533913, 0.024509560129034425, 0.03713265707295749, 0.052831300173795996, 0.06421958021218739, 0.01979627120759218, 0.044468979336201184, 0.058025272878547834, 0.01673305906625765, 0.04015567449612483, 0.07651575871052281, 0.008840707314741469, 0.05771546309152919, 0.07115197878691458, 0.07974811348943942, 0.04998385095067563, 0.08113868564607636, 0.06492133207258678, 0.03219517060525475, 0.014663675552113883, 0.04629123054685132, 0.05481497377097126, 0.022745977846845504, 0.006388192217151124, 0.025434992426345428, 0.02396089370332418, 0.07025024733476101, 0.01084244526517127, 0.10494818505380424, 0.007518758441531851, 0.1548791529550668, 0.03346002773351727, 0.06479584687058965, 0.00914054072176617, 0.029524603422971505, 0.048463928678463546, 0.0382530108665026, 0.046034560448700385, 0.031075772506395177, 0.04005161677336982, 0.0631641638615439, 0.05001406928884888, 0.04107286560259039, 0.024575899512837493, 0.026518120092429945, 0.020792943936201836, 0.0145266568964167, 0.021525743424952514, 0.015486815959335336, 0.044823593775471376, 0.0859125012591962, 0.01198096396101098, 0.03599488244001423, 0.01571135058428251, 0.06714285681805304, 0.0778908022649346, 0.08940392399146672, 0.04402262203755879, 0.061949887688482, 0.03890374893202417, 0.04837621161113343, 0.016413935565299565, 0.054729102975538665, 0.01871905774028311, 0.017168650914344098, 0.045072323372287136, 0.037057886891547716, 0.04503339461441483, 0.07937340456391535, 0.06336488655858463, 0.026070743896848252, 0.016116607265787262, 0.05124550966185428, 0.03268737443572572, 0.010912924396595167, 0.050792165641342445, 0.01985983352266973, 0.01736164186900902, 0.028583282462110924, 0.029415050934579585, 0.09146580367439217, 0.038778865109047586, 0.03609679128614164, 0.05505629529755923, 0.04752634814189327, 0.11808395761275485, 0.025912673144991842, 0.029196183445052277, 0.022152658071248763, 0.05825517203418478, 0.07270093962189651, 0.06806773944727837, 0.03402038274573223, 0.00929429935621879, 0.0458820783082516, 0.0376712781707606, 0.03276230549559959, 0.013558203016497917, 0.046817866199079065, 0.03684487997464115, 0.07077843431503543, 0.041533564067175316, 0.006257656580513164, 0.008617184883464248, 0.06488248375394652, 0.08586891085630463, 0.02248549837649109, 0.04794398480425439, 0.04639646804500972, 0.012750683142052544, 0.11823486927295886, 0.03451897957993131, 0.11800695045460617, 0.026837640043888843, 0.033464758326449705, 0.013760476083975407, 0.01816750699353795, 0.051588537021269726, 0.047448214834495905, 0.030166820675555258, 0.0691518917559616, 0.03671682837809767, 0.017337983158687433, 0.019959461342002598, 0.038586852831705924, 0.04889552729324468, 0.04946631259254871, 0.03764449956736738, 0.020185478347083254, 0.03320561376430335, 0.06685932001639759, 0.04828664061102656, 0.016398280558566895, 0.00752762638806035, 0.0700697340371628, 0.03225757612756664, 0.04319994319831172, 0.02440839821863319, 0.03896769429106386, 0.01900577189160451, 0.04571399095678522, 0.12250521956312081, 0.04322418988111519, 0.07529227033017144, 0.03450788662678773, 0.02432766404273289, 0.022508693603618492, 0.025129723625497955, 0.0277298107187474, 0.09614803347616427, 0.04419339835763939, 0.06960160068927274, 0.035782070875528364, 0.05495529809606172, 0.054905594311534404, 0.08276023331188387, 0.02726834425101838, 0.0313391707717411, 0.005394589107093071, 0.06151301838878182, 0.03568685380741954, 0.013283078817860975, 0.03775783078444581, 0.06517768807468877, 0.0488745901102741, 0.05907783172123375, 0.0213076630907674, 0.04441844817671565, 0.05518039771085305, 0.10575127502482747, 0.02509188079725831, 0.0432532207830058, 0.04125541669406718, 0.03929765219049108, 0.0517520240147508, 0.06869446831725298, 0.04614537889738718, 0.0393916703309984, 0.06077977648425487, 0.08786643149271127, 0.03574509564186296, 0.059643062883086746, 0.01252078302880569, 0.037578029948617184, 0.027928503282788782, 0.05228573065851966, 0.03218412361738663, 0.05638361923516758, 0.05293091458659019, 0.04683869996017987, 0.08643632153830222, 0.05132276196813872, 0.03503565991958303, 0.018278980447400003, 0.032998429115621314, 0.0366870888448771, 0.030481198261822426, 0.07344359291657325, 0.034499363898630106, 0.04322045903292395, 0.09469357724752157, 0.022780040031178825, 0.08149592776692684, 0.03447084244520914, 0.06816753772117438, 0.09112646502833213, 0.03437621909524164, 0.04312470187282851, 0.06612823464937749, 0.03427397700086717, 0.05052344114970296, 0.054892356312202836, 0.05383468000218273, 0.02132143160598653, 0.05444638205752258, 0.034473826357674216, 0.0378113228737587, 0.04887076350109232, 0.015221893179020094, 0.0530055851765698, 0.06962222377619437, 0.06950652151699029, 0.0036589405452457048, 0.020900544815606648, 0.0360457583390657, 0.09617059476553433, 0.059549090707854885, 0.027600305470367594, 0.05990421459559472, 0.055425231750573845, 0.01288007060441399, 0.008580912535469378, 0.012451593797924298, 0.05341338526998317, 0.004100508597348967, 0.05258455857514374, 0.03069458630747132, 0.027615606161435286, 0.06959745615360237, 0.016058687188272035, 0.04853674916610603, 0.009420527663502482, 0.09709818168513237, 0.036732720872086864, 0.062180503136328155, 0.04705247679545034, 0.05155178778354199, 0.03520929757806082, 0.023765087375537525, 0.04185263202675889, 0.0200319275139801, 0.022830900608471805, 0.04337818121477481, 0.012631528699139674, 0.01570769921771341, 0.060390266740033706, 0.06053522206662644, 0.047852004457625656, 0.0465118830212422, 0.10285753876932206, 0.05517143065169935, 0.08981930452489084, 0.018356770930451252, 0.029605707236295267, 0.043415018552613836, 0.027285033476448832, 0.07851399946957827, 0.060809554321871656, 0.04110733572874339, 0.019859126806559584, 0.012514970336680212, 0.02691542669650047, 0.03163904056794221, 0.020209537338345282, 0.062113715591089386, 0.09966819982735381, 0.06059389291030746, 0.01932630882478289, 0.09441622277541507, 0.0877418196309478, 0.21234624268066501, 0.15712775890865635, 0.1827779301111737, 0.18615766488496335, 0.2132710487010979, 0.1237099387893273, 0.2235745942039836, 0.13794632688645395, 0.17642437991115356, 0.14132570925979845, 0.10256999532782263, 0.15707903571667212, 0.15087464283550941, 0.11260227675759986, 0.11785850559751834, 0.1289055853961937, 0.296596976658029, 0.13095569796860218, 0.0887436711139256, 0.11669723887837703, 0.11510240469848919, 0.17012978783778607, 0.1450294839038003, 0.17805619315514642, 0.15803934225151617, 0.07341926962497734, 0.14158942736685276, 0.10097228831821874, 0.07724410914365323, 0.13906905938300396, 0.14619755348370922, 0.10009402980006511, 0.17450532966083096, 0.12181773225987151, 0.12273997188575807, 0.1276611521719925, 0.11091191907443347, 0.1834321845202677, 0.2235625666235724, 0.19802534742461098, 0.11919525241659534, 0.09618228526725885, 0.17306854708060143, 0.11249873231375411, 0.21750376109153996, 0.1805568113923073, 0.10591920149782974, 0.1574638570027967, 0.25725719729258173, 0.13821925337035812, 0.1421529616439535, 0.17289461447827278, 0.17842809819886762, 0.15291044488549232, 0.13418671975453056, 0.12096792624722566, 0.1616101546753799, 0.08045727342006662, 0.2646365851884888, 0.21491597737035445, 0.16253750410772141, 0.15794453121000723, 0.18981308405918462, 0.2096288828479667, 0.13299487080545197, 0.28159357367023347, 0.1101769343198788, 0.11051822649014574, 0.1346953868144943, 0.10185083028890433, 0.14573316630576888, 0.14873345773066246, 0.1078390178360766, 0.10795221498776829, 0.1851536147296429, 0.1215649309057382, 0.1067528124117563, 0.18920998900167404, 0.11985185105473765, 0.19692342187608444, 0.12374173143818495, 0.17377723969759482, 0.15189343252249304, 0.19596584261425082, 0.09422644747481232, 0.1535046073578058, 0.18797124014987102, 0.14188904435403887, 0.22748015640724092, 0.15545606312732543, 0.08961006293013211, 0.202874576732997, 0.07631703550296445, 0.12323222934238373, 0.13185873177022706, 0.08786248613990123, 0.14630439210562937, 0.16526709070369122, 0.11209925576563805, 0.10159333281579519, 0.2510993212701813, 0.14183880430796456, 0.16859655478788962, 0.09772395294520164, 0.14665970368491066, 0.12360243367091303, 0.09782668533584765, 0.2037549802973386, 0.13635821129766204, 0.11551834447609803, 0.17561202027624653, 0.10306026095584517, 0.21394770352109788, 0.1992166601121426, 0.10575834601636856, 0.19630118994222534, 0.22100040088257483, 0.12453623356357699, 0.12075893746148195, 0.12498752063801213, 0.1503740196987506, 0.20820922999372407, 0.12440709412218103, 0.11953665950005093, 0.15107200240656254, 0.15756069051642574, 0.20165254391970175, 0.10162150952965023, 0.23230064209670792, 0.14542999467061413, 0.16059364793041062, 0.1838857238932002, 0.10282868023721442, 0.10289012814962095, 0.18176448771790152, 0.1890483138061339, 0.1289700133906257, 0.08240348914818418, 0.18739508074377814, 0.15630816740374412, 0.18701272626076976, 0.21512004787162428, 0.10525196955929841, 0.0719978777511466, 0.14860044954524887, 0.15297231414625723, 0.1519929167003401, 0.10111670355282484, 0.2689312740920052, 0.10258289624846752, 0.13360345105250038, 0.19809457112944898, 0.17166415469781046, 0.14210966235447314, 0.1782181594640978, 0.3415430180968777, 0.2051994544003279, 0.2389694834428449, 0.15482592516608779, 0.09590016572826332, 0.10642747019207287, 0.12994669888529087, 0.15845776415399968, 0.20685103271276722, 0.1298775671110038, 0.17416218355778726, 0.17514982410976965, 0.13167367557123785, 0.1171092103205381, 0.06520086989527749, 0.10334872370285374, 0.18508998346665215, 0.1689689041626069, 0.23393938077553628]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.05340062607560427, 0.006126864304420569, 0.0054205819915589554, 0.050283873964461594, 0.07183630980791585, 0.06460394950643664, 0.03672486847086299, 0.044182887631318266, 0.06653770864490541, 0.011476647322847238, 0.058655621513964674, 0.041771863376902, 0.03847510741663076, 0.04237996098855811, 0.024350152553750143, 0.05771144879080596, 0.08824079567866941, 0.04226791296875285, 0.1132852441420959, 0.0731068819520935, 0.07193353402638628, 0.03148718853481114, 0.024844574208761898, 0.018038612700277762, 0.06837956021509825, 0.032800835887751276, 0.010695742300501274, 0.04280061986778052, 0.028214989522952708, 0.016635777391192895, 0.04006983051376958, 0.01960814874168606, 0.11452103589451122, 0.0433659544515033, 0.07671186955825937, 0.008582002295541668, 0.03307967273999126, 0.08929965176409291, 0.028582206108577313, 0.025623668390776844, 0.013919536046864045, 0.019117471341404225, 0.008512302658580726, 0.05105353568890884, 0.018821474119660356, 0.05799259156769803, 0.05523841354935881, 0.04564700422868614, 0.05955153452833334, 0.0377394829786593, 0.04531590485825174, 0.08700488135218622, 0.019758256009569573, 0.03129247771275621, 0.06780150857183241, 0.024629732511276682, 0.012036761017366043, 0.025407744594098582, 0.04407057914161875, 0.028728000301447128, 0.026231869424302733, 0.02274585910321724, 0.01805085095486814, 0.09148559938635557, 0.013979727575074763, 0.022749252872721806, 0.010453221846311804, 0.053514708058848504, 0.01029463877315603, 0.07242844214722996, 0.043413160789397456, 0.02717684270934232, 0.08389673240843319, 0.030306352099644083, 0.028378662292755423, 0.031205122621970314, 0.012360756837522552, 0.01859164199671678, 0.05163396986561918, 0.023812060056614782, 0.04071923941674252, 0.04575916716168004, 0.05344740723470046, 0.07487322789646926, 0.051847884596716014, 0.021426981284974084, 0.039363405517032074, 0.020617157401096438, 0.05142446397052658, 0.017524113795990427, 0.012180482942400681, 0.030921168302396135, 0.01009558902061995, 0.05985029349704424, 0.06624909268031198, 0.006781750257247158, 0.03877529513932044, 0.04953517240562266, 0.044226688708389, 0.053349914885456526, 0.06304443197985811, 0.05312840822303007, 0.009071726873967676, 0.03597783315325937, 0.029859789872481942, 0.009290526373191707, 0.043657830120214534, 0.0109647607783817, 0.010093785841168176, 0.026875607361416184, 0.037502125957079475, 0.09458502258865104, 0.029327425797800385, 0.038106358655157595, 0.024307146292900848, 0.03929674820674043, 0.05323919602819989, 0.03737578656704676, 0.02333977642739492, 0.020124218126218167, 0.012970229577002747, 0.049126395550105846, 0.0803892448123905, 0.046256614863992705, 0.014871707685562152, 0.046847724475927895, 0.051979559789141344, 0.047374938524538474, 0.03035351630270241, 0.04928817033707615, 0.08167470970581617, 0.08740548404955095, 0.04045069495576524, 0.038561499151851863, 0.04909208247197732, 0.010785721242427828, 0.039778793711335435, 0.03611202877495558, 0.05927086672595432, 0.0440983115244777, 0.0031994359808102733, 0.021388774564970407, 0.03804267759645178, 0.029856313748525518, 0.041491260691996545, 0.04135772390591522, 0.021350761282167608, 0.04047474245570841, 0.03307385047176673, 0.02642813923528358, 0.006495234331176166, 0.006512559409583769, 0.030747201226110903, 0.059876290690754695, 0.06702912340481436, 0.03889967334426699, 0.058646198632496024, 0.15736022062840002, 0.020670203244193427, 0.04894747571539014, 0.034758941300453684, 0.05926903577581529, 0.03333640795561575, 0.02816784830253211, 0.06643761925759815, 0.011470259107168645, 0.05306346311924919, 0.044636239312709346, 0.048173906942529064, 0.05146267260575006, 0.037632008503761985, 0.038430850517245076, 0.01642181477960079, 0.018906255155020667, 0.09270276754133164, 0.05515055092532308, 0.027884552818572814, 0.01987922512325308, 0.07715814641766972, 0.09916178506588745, 0.0720041596721257, 0.07405210421570847, 0.03461804240942001, 0.037645859373432976, 0.027349536164453434, 0.03877099738606522, 0.0303898461072916, 0.008978435559378517, 0.04645936386359315, 0.06619198082555687, 0.027421312857299086, 0.0665724813757885, 0.02609503654492719, 0.039854881563974966, 0.035213449774610425, 0.034799440538570765, 0.07372331460036578, 0.04500614486694817, 0.04289552667028001, 0.009757077749518138, 0.0538815837353468, 0.051038325013172244, 0.008748324771952486, 0.02642300261575128, 0.023310090520329053, 0.03568836300063037, 0.10202640998027018, 0.05447798701483877, 0.05053436173306358, 0.043038551455303546, 0.07437219873311059, 0.016491494306753722, 0.045312821354356506, 0.0534386623410448, 0.048183513685099544, 0.03673337587726213, 0.05810733238655714, 0.14667986711907774, 0.0927777522273602, 0.004376356270269401, 0.05198553527495073, 0.01726510712967044, 0.03729834656922087, 0.05709588948276736, 0.05742307414390868, 0.0659288602670835, 0.0663934389670049, 0.04306844803654859, 0.024677649395720615, 0.03777265075534102, 0.043953451958875504, 0.024475363879314354, 0.02197215434974961, 0.030706420450681643, 0.05820997667709186, 0.02671433436203628, 0.029444282934550318, 0.0020750765050310763, 0.021024790870386268, 0.027519772392547423, 0.03806306319611688, 0.02798970604705955, 0.013527767300876159, 0.013749914604329295, 0.05336040262913993, 0.05204619794723488, 0.033949393208228776, 0.0697759852834767, 0.047953200841983484, 0.012580079191754903, 0.029453989268550952, 0.040508419680859775, 0.07360937434338755, 0.03251382104691959, 0.012982411332608712, 0.03129003772271737, 0.025907210938091722, 0.015602141877846613, 0.05241437980364408, 0.04038582646077679, 0.0335889105354586, 0.007001686918233792, 0.014212508178916911, 0.04702936009233517, 0.047874175042154334, 0.021793922078945947, 0.018042617424901937, 0.05890699794455882, 0.03079438841180696, 0.08138871376192378, 0.020487393598042188, 0.08351270019287065, 0.03908040880736324, 0.03226977990820043, 0.08468391073326911, 0.05197884732737176, 0.02709244280272434, 0.08071298590831219, 0.03273270002776577, 0.08209121638848897, 0.0478439950083773, 0.04118300606346419, 0.06421879114162538, 0.04549432290537704, 0.027904009536629724, 0.031153045880097537, 0.02026492549527076, 0.012271752742479646, 0.02874439266780692, 0.020062622741886207, 0.09332581152839046, 0.09005491486600331, 0.02012569859113184, 0.03909530538705088, 0.05445169487727746, 0.024919704451496084, 0.03783354325400245, 0.049615584824594765, 0.09273678950604894, 0.007692035559880277, 0.04216890376541884, 0.04343133622540101, 0.011447545557823634, 0.06274208771966158, 0.03181511055557959, 0.019736384199331367, 0.06324235845597521, 0.10090501047670843, 0.08262079764878558, 0.031665305892426165, 0.024045680484343922, 0.06999537754323214, 0.044200454027422016, 0.04660831050827138, 0.012521679351677098, 0.032365567711812836, 0.04983125006659858, 0.057189447970520106, 0.06604844659206367, 0.06105572901545994, 0.03266698500562099, 0.03507134812553564, 0.0191754182319968, 0.03203493948545187, 0.04812565106417864, 0.02144117114855157, 0.015026781118414817, 0.03628199687227607, 0.025500653822335507, 0.055170415585199674, 0.06479486627804656, 0.011381619861499678, 0.014932130955369964, 0.04199433914055267, 0.011436056154179237, 0.06817292331928207, 0.023880351049404953, 0.06212025415152312, 0.006572650388754424, 0.023430280139549606, 0.015002716381493357, 0.0267776228006809, 0.021739188927195726, 0.01772743161587465, 0.0312116171323484, 0.07938137953920711, 0.12339486214782923, 0.01709228918527163, 0.005090235302510161, 0.02106251687021746, 0.034635581992446415, 0.05957139918820993, 0.11184736605613463, 0.07547877443533751, 0.15215158883121707, 0.13967167946600145, 0.12579143032311432, 0.22813828722123178, 0.1329381649772967, 0.17667971701631624, 0.13425249606370926, 0.08006918093850536, 0.2208949412189184, 0.15581951056036258, 0.1347197790540034, 0.18427624487348143, 0.15198723232794195, 0.10245651472359897, 0.22418663716844975, 0.1531903887347829, 0.15609352488911923, 0.13995959062970456, 0.1337709944815405, 0.14775510216432233, 0.10034644811023628, 0.10468922435275971, 0.1265900923059352, 0.16769899085404413, 0.09504714980721475, 0.10748344578690107, 0.1261589456830294, 0.11030763658064027, 0.28217249099285374, 0.0976540933873865, 0.18743690914444386, 0.27210284745500934, 0.22435870051624315, 0.1505122219602908, 0.1467724105403308, 0.2479002759942124, 0.12053602119727481, 0.10421636424237683, 0.14692613374321692, 0.25138217625358417, 0.24036229257622074, 0.1352710712460741, 0.14775894792570224, 0.1072920233972611, 0.20948852021848002, 0.08837804033030426, 0.17745314406291132, 0.21049600244770128, 0.1326897839504865, 0.2885227776583164, 0.10853558328122863, 0.13158225063835421, 0.10987793020303212, 0.1356919599516738, 0.09202686348749746, 0.19736543928663577, 0.11265070117529362, 0.1257453577953481, 0.12916721974409398, 0.14681227775591035, 0.09115214429555402, 0.10483468912782208, 0.11046819328781098, 0.06710465201326916, 0.0891573662539163, 0.14886784487433974, 0.11639434303487502, 0.12121310502651239, 0.16861788267570157, 0.09808041365636934, 0.14169568376195046, 0.08866539224982263, 0.0687057451314984, 0.11272397748525105, 0.17306853175884293, 0.10207077413196526, 0.17751879779802215, 0.13013397673926047, 0.09106894714697715, 0.16473898033220924, 0.16512069130136123, 0.21326657474762012, 0.11854475183833031, 0.16202424052021197, 0.14162238446935532, 0.17385228567065733, 0.1703512025696616, 0.1398273944974907, 0.08004367021062682, 0.09247286455525507, 0.15101094519899738, 0.1348860814206062, 0.208019791771808, 0.18130975324780713, 0.10041992360305402, 0.08115426021357698, 0.16789906237634922, 0.13966126067023124, 0.1443518944565327, 0.12553720404544186, 0.11639094926537046, 0.2104758543352927, 0.159933126922096, 0.17049286754861956, 0.16691214194701565, 0.11477274174291281, 0.08963065537353677, 0.13956520856628496, 0.11675615870063344, 0.1596619471186592, 0.11679683796941273, 0.16984596758359866, 0.2176160389377225, 0.15218312101018044, 0.11989029334677805, 0.18269885451562945, 0.17181429260921094, 0.1229554954014959, 0.1703992516042725, 0.14921206350047744, 0.2092409052795941, 0.1363686760587077, 0.16256575743036886, 0.08671199827785454, 0.13888826263287377, 0.1599895263150815, 0.054883550131513234, 0.13709527981137076, 0.15103706879721535, 0.20453885678322087, 0.24305735925032249, 0.11492156964396277, 0.13411758798024348, 0.184074396027192, 0.19840880507423034, 0.14795164968217575, 0.15864645160974997, 0.12383358538030617, 0.10819217670829066, 0.1354923327603648, 0.16314018547775286, 0.15875189595164793, 0.15619521540018821, 0.18736203171072469, 0.07952604758282823, 0.13307655109993874, 0.11422494291177682, 0.1215327169085222, 0.10064919073615344, 0.24702462217500135, 0.15645079765348666, 0.07970908897057657, 0.1435208729197902, 0.08513578769540595, 0.20473073116473614, 0.21259918959150392, 0.09961375395857519, 0.13301210778374828, 0.08692862496020333, 0.1715236848160144, 0.1289016477042629, 0.1088355373471014, 0.2030804705235266, 0.07407893261481678, 0.17278861855306935, 0.09298056634443422, 0.1566142961382866, 0.15569987827010695, 0.15885821363377958, 0.09198104376874625, 0.08391119614844361, 0.1265898394969202, 0.15157253361277043, 0.20077951012119172], [0.051160412615225206, 0.07538354204547021, 0.07419616704986942, 0.008306360029945932, 0.07092181533094376, 0.04946550053934898, 0.10709106321296386, 0.07911084324962671, 0.0016139620786435123, 0.03292441736125658, 0.054708977845767816, 0.010726657778685613, 0.035911654647920406, 0.04260742398459585, 0.09317640140051804, 0.022421779013389063, 0.09374162107105218, 0.00933688426870973, 0.08043796800437474, 0.05741933180439857, 0.010859325054972883, 0.014058626970396408, 0.015193295116806704, 0.0368913317159299, 0.07258296974243657, 0.07032828105072822, 0.04794730196496652, 0.048737234375890226, 0.03458951329511981, 0.03368214343584353, 0.05008283717137191, 0.018059007876041918, 0.02373208813819914, 0.07827312610442601, 0.0744693463427886, 0.06122774639797788, 0.04524168626014744, 0.01998864354625825, 0.022593595297826875, 0.0051225579884504125, 0.05187224619270814, 0.025790769404040712, 0.03809394420034463, 0.049087045443875175, 0.05379469021253529, 0.05875274997144457, 0.02993572450753662, 0.0650737299433639, 0.06945615123596884, 0.03925586209422158, 0.05069351649933285, 0.029631457366650144, 0.07089223667618728, 0.028973866644645893, 0.0518571351084017, 0.012282694393258181, 0.03985236496514371, 0.08611068054432831, 0.09823577628741342, 0.04170479620957086, 0.011098468019026182, 0.04747984660488944, 0.018241784963456374, 0.08996424069928546, 0.03465999721459324, 0.01631771875244956, 0.045961575252154184, 0.03483041730378905, 0.02159967665530501, 0.04601923869021478, 0.05276065920629809, 0.0427231568873169, 0.04844579154685621, 0.05488099522828575, 0.07521546235488308, 0.042883744238004576, 0.02311565740514667, 0.02581458133194716, 0.05821328234648513, 0.01553412284626956, 0.033765754271899505, 0.017600952414795756, 0.10180468881322492, 0.044679791411204685, 0.045309990659476294, 0.00847484287430322, 0.043692273433290185, 0.028941332805721514, 0.02651122721633123, 0.056253663910132264, 0.01881828910911516, 0.038175222298671166, 0.01741339302351398, 0.0472831113954946, 0.01634480762145212, 0.016562977970968333, 0.07562856760717208, 0.02109354534637063, 0.04932628321130911, 0.049689336109065244, 0.05409269841508039, 0.028901659027342836, 0.0511803500534546, 0.07768808773929074, 0.034403729312602556, 0.04646416340443877, 0.026182031574388667, 0.025946055426292365, 0.03484737082955337, 0.024678720003594796, 0.02603825602319933, 0.027733756071557442, 0.015099882185759564, 0.03175237561546026, 0.010114990197302354, 0.026984183087704644, 0.04100246978322825, 0.020567827084432208, 0.0066565145126303606, 0.026055881791117213, 0.043616974651212656, 0.015003786031757633, 0.08075247774080885, 0.07549387402832508, 0.009303336320895582, 0.04573460638282761, 0.023604955847164797, 0.04256688644208255, 0.024252127773398836, 0.0397617137810636, 0.03038416173489344, 0.08778105865442946, 0.064167287050476, 0.08776298664029568, 0.01699803164228797, 0.051834535514635426, 0.08946968497888697, 0.037088679795664166, 0.025111310702237873, 0.03790816404826699, 0.021456106032635418, 0.05524687116004287, 0.03445109652896081, 0.06120110952085065, 0.059471604744753534, 0.015560054922506455, 0.07214126642793417, 0.04853110309810408, 0.017362568835397402, 0.03402109903794143, 0.019677219228939186, 0.03661752423091281, 0.039814152499480594, 0.014379556523635985, 0.039625442061092586, 0.015635762604013566, 0.03337054100308207, 0.038664806108441085, 0.060997096476175135, 0.08085851197040851, 0.05097493889831728, 0.06493270081738312, 0.025925248478268905, 0.030962824333278887, 0.06036572128293976, 0.02838209819709582, 0.046128900346135905, 0.04763678354661792, 0.02393534467104943, 0.03718576228786861, 0.01973267824899766, 0.026372873652425986, 0.043544629138083234, 0.06257974219718768, 0.04339341870358875, 0.0668307219541842, 0.05554237425507558, 0.06991573504262394, 0.038627371222021124, 0.0026602343320020387, 0.04499445819566327, 0.04805561913658054, 0.16756985907352742, 0.02566118563164867, 0.0484496028342795, 0.09130379140016534, 0.032744432664326126, 0.018098166460291516, 0.03983112134700341, 0.024364957202886863, 0.03087111403264346, 0.03990918953692721, 0.09954272228623591, 0.05868607350895482, 0.07471624115902571, 0.04139821165271344, 0.007549039024348943, 0.025092989709528706, 0.03544833616263444, 0.04298934945836664, 0.07390870021716242, 0.0317704227317365, 0.045094907644294926, 0.04517187649804739, 0.0037868937473714117, 0.021602635669912544, 0.059441091462729446, 0.015997416433697988, 0.05026785889640451, 0.02907697058793518, 0.04222470177938381, 0.03664474716530212, 0.09117639097835749, 0.022034113625845602, 0.028637835583198937, 0.049282493625557235, 0.015504285636838647, 0.0590596754374283, 0.030150552798483162, 0.13243407912312016, 0.1458564451745441, 0.06599678928332944, 0.01244575429272147, 0.05380383730235119, 0.03966368133983305, 0.019390801936688445, 0.02864898407771703, 0.04557233746914614, 0.05217813743999408, 0.02701443589983448, 0.06791374045273951, 0.02471352720843448, 0.03207700154293449, 0.0859391151536857, 0.04133200633429712, 0.06435983558936466, 0.022619048569111094, 0.08970190921137411, 0.08849997854521198, 0.04101727060192535, 0.03183358476587361, 0.0569830370706416, 0.01788103224469289, 0.027951434209582307, 0.02645468226664009, 0.04242763464008609, 0.04121839166468671, 0.04944927096667309, 0.03130683420045722, 0.08082693382616966, 0.019371745499571966, 0.007091558607850945, 0.0028501587803475563, 0.06585497874766588, 0.015487969879271283, 0.017157728415763667, 0.04910360826479812, 0.03155926400194726, 0.04253351182166127, 0.020633580410973202, 0.01828346014653723, 0.00852988054600334, 0.007061538973733062, 0.032754326689868205, 0.028331781542229078, 0.02577442491817619, 0.012453296428336012, 0.04804259181142815, 0.02504997961823979, 0.09050963401433923, 0.03337591894031052, 0.049402286794276974, 0.11485643684864046, 0.013235936639830472, 0.07034566358573015, 0.044237410108889305, 0.10391739076904713, 0.02730769818768867, 0.03321930758594986, 0.08113169126332768, 0.05772921436977002, 0.03740998473198664, 0.0343165599981383, 0.029947476296295083, 0.04136669096506892, 0.009567619417794049, 0.03262993699360279, 0.019766539335250854, 0.014916828349082461, 0.038338123234890165, 0.030497374208343607, 0.009697366941479907, 0.026944089876187426, 0.01639671390876174, 0.030173117918292844, 0.04901710544682799, 0.03484524876600312, 0.016910628671006813, 0.06034219472278511, 0.03151781864524369, 0.07022744855813443, 0.013233964921035355, 0.08874955466918408, 0.07607957122907524, 0.13194281758079607, 0.02108904457981548, 0.04474130444108479, 0.020986109175869537, 0.03394148335041058, 0.02267207526000998, 0.025952638036781744, 0.02348617774494473, 0.061557769414878664, 0.018410615420209307, 0.039206878432343086, 0.03892778877108809, 0.041655031138009606, 0.05780279328445754, 0.04090161813843635, 0.037315621851913394, 0.015574900748869105, 0.02905068994169274, 0.04967889816109693, 0.043123407184236476, 0.01662388004572882, 0.02709049310895705, 0.004402203598029671, 0.012577525246137334, 0.07011916969091662, 0.0348348644441895, 0.04964026434707546, 0.04243101691827179, 0.02525025032340519, 0.010790748694430917, 0.044464830970091206, 0.01859297882014465, 0.04990059634550445, 0.01076180206221198, 0.01305058166655081, 0.0646324709598576, 0.023311122823807023, 0.02306996409090296, 0.03763196636892615, 0.018236682817880667, 0.035917116854820526, 0.019276896153666803, 0.033493789228340315, 0.048260976665563164, 0.05956751512243383, 0.01732997370943908, 0.037716101975210255, 0.0572237380660109, 0.1640199914935135, 0.11660496358789744, 0.16555679451313712, 0.1450965625624503, 0.13706036152378206, 0.18181298108350846, 0.2544033665570521, 0.19139735388659662, 0.09258326548602312, 0.17234911391090962, 0.15922650274249817, 0.05957890301942826, 0.2325613264955821, 0.09859491064543686, 0.18298578508678945, 0.13483052472433738, 0.2000891882926226, 0.11486648026132777, 0.13740117871953597, 0.17775634634158305, 0.06390651838193018, 0.1285080317287676, 0.14253994329802452, 0.10128768671664501, 0.24777829947490848, 0.11955195827589882, 0.22253763291143605, 0.16898235666655725, 0.08569212840689767, 0.15420740109778222, 0.17960525358155852, 0.08399458481900154, 0.0992725077535837, 0.21181479216583315, 0.23562696522041676, 0.10207838904593261, 0.15685955152636574, 0.0776559197073502, 0.12195778845418846, 0.14327365634662492, 0.11668525726324129, 0.12716900962855548, 0.11810268080162427, 0.20315173202224318, 0.27274320502915694, 0.20978757030060216, 0.1959697036973892, 0.21960382259661154, 0.17597617251017403, 0.13410960534407249, 0.12244827624770904, 0.14114210862786541, 0.18008943647146228, 0.09578963456254813, 0.1521892497135747, 0.12446694091082582, 0.14575311523531714, 0.31652736687852495, 0.17256004855998103, 0.14030687360753938, 0.08365486312897936, 0.13461914574426992, 0.18913045375337525, 0.12703978591748785, 0.10459082801976513, 0.14923481631182856, 0.09163915404989835, 0.31930786767794245, 0.07806645090421362, 0.12066723673694557, 0.16275669718461652, 0.14646344728046848, 0.13305883914712938, 0.17064936398979158, 0.107921916210363, 0.1697136641990754, 0.084165514356667, 0.17107707087791738, 0.23876533633278263, 0.1458787230113822, 0.1545835655903624, 0.13558700590604736, 0.1794968674620313, 0.13084809325875776, 0.15163435690825985, 0.0624168450914083, 0.12696447181365184, 0.11061281536615665, 0.09635418773658815, 0.14504644509044387, 0.20573902544715714, 0.14116706777243845, 0.09722345238251072, 0.5128303494664931, 0.11157162036866912, 0.18010529449149487, 0.24196545413184553, 0.1394361380728022, 0.15052334555695135, 0.17385266871461946, 0.19071325269197265, 0.19437841650459076, 0.1453379262238741, 0.20809215643713552, 0.16048638029925286, 0.1112632469965085, 0.12434404508601274, 0.09723456831829203, 0.11074484295902715, 0.15106279402971268, 0.1952164094414442, 0.1269595075639025, 0.10208457137548155, 0.12809707152266658, 0.09956366713008574, 0.16561746867674013, 0.13897794088529003, 0.07231961935758591, 0.08969245568638848, 0.09827133808885852, 0.1538880037203912, 0.14837803889907178, 0.20433031232847323, 0.2482102045248593, 0.13911962118600646, 0.12374033715816275, 0.24155241016659046, 0.13207398715519136, 0.16215476658075087, 0.12485924687597061, 0.1151730303442286, 0.19878219632852465, 0.1535261191067196, 0.17712495199614958, 0.1192060542563277, 0.11334500666106902, 0.177644620078706, 0.13955906454113223, 0.08836037434277036, 0.13060588690061725, 0.1756012950453066, 0.12447617227031339, 0.13106383893999363, 0.08938644186503465, 0.10344156589839729, 0.07369000509741806, 0.14504707328254177, 0.18402017232391144, 0.10365096071074087, 0.15097018932142567, 0.11071295071873935, 0.0965906024700211, 0.17111934360957917, 0.13943796136206196, 0.10722033288930694, 0.15069341707614162, 0.2156088272890737, 0.11323180950937733, 0.16320974626127752, 0.1887981094900639, 0.10130739815893675, 0.10540796038244041, 0.07939075645540031, 0.16214755003250417, 0.13796083659173983, 0.11998954003736859, 0.16364411811434454, 0.14748972930735157, 0.1744009731637855, 0.1255009910692611, 0.0945335261583809, 0.14084359480729028, 0.1354285482797892, 0.14848427997241098, 0.13103653556637226, 0.19499923883666917], [0.028589399674186305, 0.05206233175892023, 0.012342169629259696, 0.02442854058538233, 0.020023314770491376, 0.0608880591819123, 0.08095402015192855, 0.05282302642421377, 0.05393202679472105, 0.04914487742127911, 0.02689335187296233, 0.030133440309474548, 0.02823181472898972, 0.06627880157001557, 0.03596798126255313, 0.03567086938287943, 0.033635798946864186, 0.06935920280915114, 0.023687086218307098, 0.05287827668531288, 0.05952130852928085, 0.020251767935171243, 0.03476076458971347, 0.06364108423792547, 0.01881091551284396, 0.021397391138898752, 0.0463075865240347, 0.0665640161042252, 0.01845140385651781, 0.0411370292966885, 0.024255513882024154, 0.08381785599574929, 0.06625118410034526, 0.024671164461441582, 0.013578148115606559, 0.053966163672626986, 0.07915890760599606, 0.036147245836834756, 0.05556852849681051, 0.02165140482717224, 0.010731080978838427, 0.0705426324519419, 0.03310444036258325, 0.03430506101839485, 0.050199975845434015, 0.029034695941053575, 0.05303002338135435, 0.019136512456762216, 0.019403151274027846, 0.03193304787630276, 0.028181003947411815, 0.06030775140970946, 0.020656566879141237, 0.04452783404098404, 0.03267621253466895, 0.07797857295841941, 0.10054837356531814, 0.07146415961605888, 0.05147870299556563, 0.04158982556433447, 0.0771447015745986, 0.04089377722853134, 0.022202300568742138, 0.057610938055140365, 0.06323432219364951, 0.03027835158601163, 0.07763167302454672, 0.045012143335395285, 0.04691183837431093, 0.021055679535493258, 0.05830486049695362, 0.00374447426199162, 0.019341724429039225, 0.04132262558766431, 0.06316979077734775, 0.05233556084755448, 0.08250501878078907, 0.030103574371746475, 0.08027486788529543, 0.08859008580686585, 0.028921207675950664, 0.08475072126114562, 0.02496058864879512, 0.006592329751114331, 0.02543917718163181, 0.04180177144946591, 0.03427185110687729, 0.05280646743373044, 0.04714172603862901, 0.011059379340299677, 0.0280931432385959, 0.02471571055901868, 0.009477447038666617, 0.015419811994257956, 0.033578227439354506, 0.08720718219035095, 0.008199969569461481, 0.029809727941850023, 0.009347626736627953, 0.11641799216909755, 0.02088951314949701, 0.07280909591504643, 0.02822046130595188, 0.030335660708407243, 0.047822567529135177, 0.023045612071009896, 0.0340146332558605, 0.006812446442763171, 0.037071852674407345, 0.035437848418951035, 0.04796548506184932, 0.050675337232889674, 0.06457311446748434, 0.05946307435571667, 0.06108211691401178, 0.03263030088536682, 0.06357963249507932, 0.03590776675170468, 0.06458288974939816, 0.03934542926388883, 0.11723936865887336, 0.027136870156673175, 0.01759653400269247, 0.019368688808754086, 0.07152917749819256, 0.0709618587467459, 0.06264511247976653, 0.01739189851157848, 0.04547132494589014, 0.08901314254129127, 0.04844556555091854, 0.0696539091727426, 0.07168958864865765, 0.040763124763484926, 0.019665965397331505, 0.0418540301372207, 0.0012043461174471304, 0.015689290124892948, 0.02582802042935885, 0.04533653560605261, 0.04169128241858656, 0.07693752841723543, 0.018418262892913435, 0.03395502012403261, 0.04102828311583689, 0.045690027726513725, 0.037764200805536205, 0.03670674666101414, 0.0045407060702751965, 0.05333560436303097, 0.055793578315886765, 0.0241021239273851, 0.01952703343704343, 0.020315945035808032, 0.05306355504980011, 0.15291619054492445, 0.08308768227335908, 0.02716362386220886, 0.0078018671915596055, 0.03523888772413616, 0.025457486683022112, 0.03047946498789374, 0.17223708121286285, 0.061908377214304866, 0.03966711724417345, 0.02503309504038865, 0.020345669247270114, 0.03811503843133969, 0.006304424811875629, 0.060013221246340585, 0.0947769659180795, 0.02021021149571865, 0.008128032955761639, 0.024837053140565276, 0.05030670338460515, 0.057854201614616386, 0.045671722055563045, 0.05690152531549816, 0.02932219150205774, 0.08831941928233832, 0.059299709936303485, 0.02957998391901774, 0.04391097621391377, 0.049119948920223026, 0.0373414122018843, 0.02995041998914413, 0.005388541800540782, 0.03275914538291193, 0.05988293650349783, 0.03908850635672289, 0.05352129258455769, 0.03288460377183172, 0.03969065912608658, 0.012985121368640854, 0.09674345233267355, 0.04757494109893038, 0.01675394836873297, 0.07352369506993602, 0.07395756896585226, 0.041774173131993705, 0.017377059388485168, 0.05852475837473908, 0.030038217495706294, 0.051607336818931565, 0.0234049187988163, 0.033976482077231335, 0.05695837670035901, 0.057345457945860205, 0.022124446883437135, 0.01658250555215824, 0.030484666724899606, 0.0324614551068554, 0.019095538244132074, 0.01691796970854123, 0.012422285189161138, 0.0803554909784467, 0.0279961220334254, 0.06138490933564402, 0.02431387254487603, 0.051261988213105555, 0.018647235082162004, 0.07363431816620213, 0.014649189787075646, 0.07152553858055223, 0.06793428693086871, 0.012586890671011663, 0.03769931315834965, 0.011934952720278695, 0.043903568143685984, 0.037687228121344125, 0.03016308025126496, 0.016205640089127327, 0.06737357185732934, 0.00688089783521249, 0.035590851499188336, 0.08299504692155509, 0.04855410105759098, 0.030267218413252025, 0.03637971521745767, 0.03150956404785956, 0.021380943231164448, 0.04569680377420399, 0.11079944204539062, 0.0341141787207415, 0.02969447767452127, 0.0431815417663705, 0.04394366518564282, 0.042002540111782095, 0.006647262085724863, 0.009286813719588663, 0.060759107432057785, 0.008136291383585383, 0.0290384593479816, 0.030904254996247833, 0.07144182049218686, 0.06988825546878, 0.017766942600569418, 0.03314716125568075, 0.008999720354744745, 0.009594873953310233, 0.059056595763972694, 0.038400207000273856, 0.04386749306333162, 0.019764710300331636, 0.03157608154710503, 0.02949571424734689, 0.028692225910603043, 0.038601381689189904, 0.03232125335583284, 0.023637581616640094, 0.021026077898099058, 0.021396468002949993, 0.13327509044639527, 0.0421275541697058, 0.04229935321716532, 0.01758350859275989, 0.026716375986354488, 0.019404151018769033, 0.02340166484035792, 0.10069674181361353, 0.04014065534236931, 0.01928825149192445, 0.045370120900653066, 0.008727026570047583, 0.04998278608846088, 0.10858286622791521, 0.032635881835895206, 0.053800451193725875, 0.03807125267602744, 0.03795315256162036, 0.022640579470222997, 0.05183267392097943, 0.017313334279723706, 0.07479744647899944, 0.04195637948390457, 0.06039552210319427, 0.12550780159090796, 0.026970167509129932, 0.06710285170664711, 0.055358934501606616, 0.04479389254664702, 0.0338774690434577, 0.051368742565354036, 0.026035651324256778, 0.006176088326385306, 0.02105924375956097, 0.061160729026361826, 0.04038889081247392, 0.07145801559090614, 0.03636224075190483, 0.024812722188090126, 0.0491757124602314, 0.03130145051756934, 0.03680194840736447, 0.045242149743341634, 0.05344787837877389, 0.0768814507811781, 0.026129286420801957, 0.10369523293188504, 0.008452909777031071, 0.03548272967999501, 0.017997621250669324, 0.019946133327339927, 0.01856270877103652, 0.010022314625882335, 0.009052392729978648, 0.028910176009841027, 0.09991778361220514, 0.011033302664967074, 0.018722160396376447, 0.012152730449733716, 0.027881913645673665, 0.004822953450193088, 0.0439664448100713, 0.019696961314747893, 0.027899524091833064, 0.040535470245466124, 0.007503893462971094, 0.09248614085898285, 0.08120689811485429, 0.05088900681585074, 0.034905811846857114, 0.0637950602498266, 0.10644095333954019, 0.0327048757143559, 0.07380920071755687, 0.048804584995753346, 0.038666468519236774, 0.029058888997702353, 0.04043718882566018, 0.026045344251718734, 0.023424810271770246, 0.19143313019266053, 0.2647590060387888, 0.12040806153128225, 0.12136379452121836, 0.14327321201562881, 0.15643080275866295, 0.16959859779284847, 0.09271411330349023, 0.2949511133615048, 0.1117778129334892, 0.1238271808852592, 0.07703980115512687, 0.1077145055657433, 0.22645257203088653, 0.16132867865024075, 0.12754860619503644, 0.1171531301412371, 0.1507804293425814, 0.10935786375475508, 0.25274311612930994, 0.2314306879716535, 0.1684466467028664, 0.10906544799405722, 0.2107738778595963, 0.11159478686749937, 0.10149492116104211, 0.09536707578527351, 0.1699352627920528, 0.05681056003536909, 0.1357304022437142, 0.12301430031056367, 0.15704810108628967, 0.15710774869207414, 0.09470951187634662, 0.13244485031933556, 0.12881645872708292, 0.13776487130070889, 0.17005195330467918, 0.11197524145245553, 0.09747832217403958, 0.13386450317357818, 0.1374363727987774, 0.10530287610186685, 0.18237452353200606, 0.10843843567155062, 0.18117565721754106, 0.1447873541544522, 0.21235267781922895, 0.12252073284358748, 0.12630855499376215, 0.14157286454592982, 0.13201331299158836, 0.08840660774900068, 0.19291359510633255, 0.1184397288447907, 0.1884731809578596, 0.25617327481027574, 0.1496505262630601, 0.23366674540504334, 0.11293531816092231, 0.19361808956150087, 0.08764142380847086, 0.2161118099766393, 0.212729531790941, 0.14130644980938206, 0.12789531460692807, 0.2878904793291323, 0.08746072664977082, 0.13987614833299192, 0.2253869284064539, 0.12277249231814377, 0.18468303756127435, 0.0772042112845567, 0.13069630059744083, 0.12084869232269065, 0.14114655193782624, 0.20998014948300778, 0.13424198533738815, 0.16215366341413992, 0.14137567351422003, 0.09762902699050405, 0.13434931425557983, 0.09346661848887321, 0.06303401701452752, 0.15798727891618208, 0.13569102532440616, 0.1395195803695148, 0.2833339415730969, 0.07842105768260457, 0.1283951563340041, 0.18292679631661984, 0.11808516803167521, 0.10399723245251564, 0.11409100009909562, 0.11821356436778462, 0.1758141602359472, 0.23954863059184245, 0.16281616092929918, 0.08115055234802347, 0.22615680080508033, 0.09044293839965137, 0.23921994822880915, 0.12091095228829693, 0.20574431145383468, 0.21509249934986716, 0.12047344713561958, 0.11032627549983802, 0.07928058535100953, 0.08280611431766903, 0.26673352105482934, 0.1121182011200055, 0.13820848217414272, 0.22969761322582924, 0.16268371964894957, 0.08963804812200608, 0.1063449701835071, 0.11481705992933243, 0.11769812509057023, 0.1116256295673309, 0.10998338220580933, 0.3632727343468897, 0.22149327120953993, 0.14755141470701466, 0.13462764932022941, 0.11542278266842328, 0.14247824257660296, 0.14993581740606218, 0.14907415235234847, 0.14193802801591737, 0.23292676575722235, 0.15910339241306629, 0.41443554864775756, 0.22708221969585266, 0.0915737837673195, 0.11005051449061402, 0.1418067971544881, 0.1143195624313047, 0.1349201416897197, 0.14891885100833832, 0.10814927578453096, 0.26333552274492483, 0.2065189642411086, 0.16423080356851702, 0.10237699479705865, 0.13347868597315204, 0.10479920393516941, 0.14882597050839855, 0.17031839868474394, 0.03732217190366599, 0.19723396327707077, 0.15362131319219066, 0.19544153203887327, 0.08900626307173122, 0.10602886698419049, 0.09058321675946636, 0.2743750029513913, 0.2036974624159836, 0.09395189688450868, 0.1355931499312001, 0.16804025238079412, 0.10700985789299013, 0.1661861663864505, 0.21735520132126349, 0.20663366292513188, 0.19698795712282582, 0.16094431701687076, 0.14939612378516506, 0.1444461232712192, 0.1362486913680069, 0.12904723505339316, 0.18417006508717615, 0.15517604266924245, 0.057176604506469546, 0.1317797787487507, 0.1860854381154622, 0.1661791490210641], [0.022434871456015016, 0.049886787610669295, 0.0486854161886919, 0.07034850577192922, 0.07623264325722572, 0.04037047405877421, 0.0513808888893935, 0.017104192276395137, 0.01317086034349256, 0.02216827285836541, 0.04424523186659621, 0.04354297055772716, 0.06798594423960294, 0.04686873826769091, 0.015203618151586384, 0.027160076875119444, 0.03863238909792516, 0.04387320424880713, 0.06169111467897893, 0.023205266709649758, 0.015300019783148123, 0.02095325549523677, 0.07799631555474575, 0.021336810821066463, 0.0682997108707505, 0.06392256409350423, 0.06265721666897017, 0.014210642754821288, 0.0486533439177419, 0.09770262505738966, 0.024819448440065308, 0.04046617376227533, 0.08513764928906195, 0.05782510559525221, 0.021983224320255464, 0.05513195031052155, 0.03163065765083077, 0.0795719285886134, 0.014982054032565606, 0.03221898444838101, 0.03596455684953159, 0.009247178245606202, 0.03226845457609142, 0.02738243006470223, 0.009896745154213522, 0.06075059236477941, 0.04976736982503245, 0.055100919919148575, 0.05275143167725014, 0.031237951404745543, 0.06822233599039816, 0.03528629324489063, 0.02163875863076218, 0.013768158988246034, 0.058041881664746234, 0.02285944695975031, 0.020594509926834897, 0.08175557028622397, 0.013994260262998362, 0.03148586128748233, 0.029200216897973613, 0.04765720362023962, 0.017558449856756676, 0.07409425437330239, 0.03591182701770337, 0.07830527115372882, 0.02137575298547745, 0.05464882845239294, 0.10851698266642709, 0.019102611150892995, 0.034787160149144555, 0.008579282683410473, 0.06758102080634526, 0.04293807519359454, 0.011696162156670565, 0.058497926145191156, 0.032648238834113844, 0.03729583763126885, 0.03264252381819872, 0.023237275778346007, 0.0745376430812382, 0.07180231082583628, 0.04159440293968205, 0.10027270448664505, 0.035472636471592614, 0.07413438971965544, 0.027423580477554953, 0.05633206151786351, 0.034552040104303634, 0.04958787925481316, 0.0055937628701118935, 0.015901064597851327, 0.005747759470625991, 0.04885317029191121, 0.04204631437577548, 0.05575428949669004, 0.0546219579184488, 0.05674857586141556, 0.0295081191260608, 0.026818055006104614, 0.037575360132201065, 0.0504063101365201, 0.07831729107326077, 0.055361248087137944, 0.026909186910357208, 0.12786446424621728, 0.038088558602236935, 0.09232956014813916, 0.059442704077810056, 0.07393008939200833, 0.07822536818322637, 0.0317845072582244, 0.04713866168693189, 0.051910301610346765, 0.041813170837779204, 0.05565959336836973, 0.025976725756340933, 0.03755324317382709, 0.032705044253699245, 0.012662781256010697, 0.05785909308601291, 0.10127333022894398, 0.029055590989188324, 0.034930364964830304, 0.014208338745389015, 0.12258839372905994, 0.012630827728688959, 0.028450099991694577, 0.016527349136829857, 0.030119365359085704, 0.024121348903844916, 0.055963416178260124, 0.03886883064443546, 0.03850486227160981, 0.006890831122760691, 0.01941747328777227, 0.05911798621978491, 0.017211074948370937, 0.026020651322699366, 0.04954601254975123, 0.014895602925530365, 0.011502372555344576, 0.032437901733623396, 0.10535101706702864, 0.08288730431588427, 0.09393919514672411, 0.06215025032419832, 0.025534631736997156, 0.028850352203833963, 0.04890601120648846, 0.021453097222312804, 0.070664708562676, 0.015733295172873526, 0.03501923882492608, 0.016888262734057444, 0.029155864237597393, 0.046115432520427053, 0.06600701655711859, 0.008463228981371128, 0.026849112210554943, 0.05331766258384432, 0.03923982021308715, 0.013862564960765022, 0.03300021410048489, 0.04251010017469526, 0.04084192456737642, 0.06340237890159892, 0.05812835383919939, 0.022165526433156866, 0.031006600512492082, 0.016826613723570784, 0.012863326795218934, 0.07464530907811658, 0.027905183566373684, 0.074957083880661, 0.03203425766719926, 0.038345171243793545, 0.009492529394675889, 0.031108683643622265, 0.012193451853348844, 0.09223722357062564, 0.0817478634417057, 0.05872889399348248, 0.06259010736680319, 0.009221300753133913, 0.021343493022986, 0.060558959300960266, 0.043472034646378416, 0.07392746171042805, 0.05850866286744995, 0.04604196851892818, 0.04888013658684589, 0.01135435191944482, 0.04834271058620465, 0.05281735354313447, 0.11372755266605847, 0.02841719460012692, 0.059963866031818816, 0.076266948674475, 0.046546617447729075, 0.042659020006296136, 0.05481318112522845, 0.017440332505371303, 0.03625185514289526, 0.053790461407193256, 0.11691876852344121, 0.07883250818497713, 0.0233180808173793, 0.024155411088178237, 0.03429856076235733, 0.04829312554530559, 0.0056204768348365065, 0.02300071357298763, 0.021350385899084712, 0.026632726845902302, 0.027321616090053034, 0.07280390183891981, 0.010485433928307988, 0.024305953110958782, 0.019210342265244935, 0.038086949817595944, 0.04866835924105779, 0.03239711904297433, 0.06806495854811323, 0.05328227698262181, 0.012020471115266124, 0.048892639141770146, 0.11979056402079521, 0.014167678628807828, 0.04578457063724918, 0.07937214817971953, 0.052772510586486715, 0.07565281428997556, 0.02717940910388866, 0.004201092590172325, 0.04326968018205897, 0.030710356227392634, 0.06887643718190732, 0.05927276279356691, 0.04931591804169359, 0.044326586573715174, 0.014632558975849422, 0.04108132321327444, 0.00480039599126265, 0.0349236348824155, 0.05318025322330575, 0.043715899584875, 0.062481636977604324, 0.055164815482473185, 0.040987887299589576, 0.02519354258003014, 0.033365557601134625, 0.047405605024147424, 0.010294416607657989, 0.03749178760054131, 0.05853356838586831, 0.08268606067905504, 0.0639813153764173, 0.02100324273229607, 0.012417206983833064, 0.0251515839444173, 0.04156559037284986, 0.08073338682973578, 0.06396472957285662, 0.1095423530486803, 0.1268019922257912, 0.009643522451721854, 0.00993554080430899, 0.04828602774068714, 0.07636453295426984, 0.010991028975695373, 0.0713760365221289, 0.025740056298673156, 0.07811430841684341, 0.026821550282259143, 0.04749849318496643, 0.07001964720867335, 0.03907355998132018, 0.12080147066303801, 0.09941986476581904, 0.0525078080564497, 0.08299736816796564, 0.04566864621254706, 0.03189158911306051, 0.052281907879777496, 0.08465257773716604, 0.07295276038348675, 0.0812909992471818, 0.034545271717492616, 0.026403536321595315, 0.014976390727585363, 0.020904687436057195, 0.02999968710355461, 0.07427642242081704, 0.028483995551904364, 0.018150453876343467, 0.021974264921981002, 0.1061602357414461, 0.034358533955509626, 0.03195541189803231, 0.03884430433953962, 0.05634832556449598, 0.07143814327015031, 0.07416080443128463, 0.03768325212501711, 0.012046912639972665, 0.030804374367899956, 0.04011499139690592, 0.05151917159016575, 0.04101851549480231, 0.05309414494061663, 0.0402720011169872, 0.022759194778759154, 0.06451571916019724, 0.017340813853567647, 0.14053499926963162, 0.01342807053363011, 0.030585771178706523, 0.05883802321829623, 0.04609373691041143, 0.061297452738208164, 0.06863564042554748, 0.06664257842086016, 0.04062756933572312, 0.03325034563820208, 0.019291277539225358, 0.025099543591720924, 0.0637329190278486, 0.03302895005852465, 0.05273168959144143, 0.016902609645659407, 0.07217763262169977, 0.06079501014262919, 0.024943922406002402, 0.04800739390174708, 0.024443678482766115, 0.03834054790317051, 0.02996360244710119, 0.05542805478457482, 0.027746268202580755, 0.062342220466704144, 0.030457798106175278, 0.030902768785674727, 0.016511665401800026, 0.05548538497438835, 0.061607147612038164, 0.02296641581661759, 0.042185064390181534, 0.027933300908414588, 0.07729506931237637, 0.03585683722649852, 0.05808555633730947, 0.157705205342462, 0.14489428470692328, 0.1408439931730109, 0.1834594266068551, 0.20306658901033864, 0.26330858709350713, 0.08331217667869023, 0.1697346550082007, 0.09288516541522357, 0.11386319619393158, 0.15328477076705427, 0.14111244570343726, 0.2236244205625788, 0.15314382591074513, 0.05470968264665815, 0.0984766879569619, 0.1238313867079635, 0.09626940478600803, 0.1398942433297634, 0.14467256353987804, 0.10899989385037653, 0.13490337968593644, 0.15270943873591963, 0.1283504091383469, 0.12692317201365388, 0.20837922490412192, 0.21400148289338236, 0.10970905378100373, 0.14772839633928192, 0.21503194776033202, 0.12885136169291314, 0.1602490156167938, 0.24277238986424862, 0.1124730836900492, 0.1630424939456486, 0.1479182482486771, 0.11004275401994107, 0.12285084779103919, 0.18552052488009776, 0.11439708286836264, 0.1769674443189175, 0.11709011940946502, 0.11255980484307775, 0.10808412766745014, 0.19654632275623662, 0.2048160580377425, 0.15546018468035808, 0.1922968483620113, 0.18391488119959834, 0.07826457656319104, 0.17199666750046516, 0.19952824339270595, 0.06482703430998711, 0.10744763117644096, 0.18075797075946487, 0.09234212399009736, 0.20434468413793272, 0.23425321635459703, 0.14079280317791049, 0.09244529305086022, 0.09009506553411485, 0.22327332246688106, 0.13462262378344614, 0.1625324172839042, 0.1214946116951685, 0.2243977403568645, 0.11025424791319717, 0.15134880529536357, 0.15887440873249886, 0.28626471817974125, 0.1541848474692914, 0.1848651826261513, 0.24591883554333643, 0.11198546106536543, 0.09147463666815912, 0.09588737205992784, 0.14648551061268777, 0.08214760812059527, 0.0974127680303589, 0.19163766034668495, 0.20416109882775815, 0.1710591597422477, 0.10224063880741598, 0.20078200756782488, 0.12027089348843983, 0.15119943347188736, 0.15706680895340058, 0.2159144044403107, 0.2692385979237095, 0.2518325593442686, 0.08050424993158349, 0.10854798624472273, 0.1320487368972071, 0.3438553472440089, 0.08475875752347131, 0.12793332788973086, 0.20083384107678168, 0.1653398384129809, 0.16966186133363556, 0.10190568218428282, 0.15767148215203516, 0.16453120196538587, 0.1568524728739454, 0.26286676886581606, 0.14700805918583948, 0.22476161679913922, 0.21813045165711836, 0.14340272684010769, 0.1577115945157505, 0.22560632066620936, 0.23527245037257674, 0.18777302256034267, 0.11996365392640715, 0.2189706662489522, 0.18310154097214823, 0.20139474001142288, 0.107012914583808, 0.21907224950771179, 0.10826850970906597, 0.09292130178261189, 0.18422954415361728, 0.2621965032191046, 0.15016063356832152, 0.14222189423538026, 0.07976447712750205, 0.19199834986319467, 0.1673552165589025, 0.19048586247428773, 0.1786075313124926, 0.1279005086830547, 0.16943892974766994, 0.21569957806458398, 0.11439523659646512, 0.07882131564040339, 0.13619161781764802, 0.10651395385784489, 0.11521665905151637, 0.16349856140873126, 0.07553211713750517, 0.28058092800840256, 0.14167443248293093, 0.09061445782501852, 0.2125441844785406, 0.16746044639618168, 0.13678608672513118, 0.17494710192324656, 0.2044762214345317, 0.19057541815263612, 0.10136496200556717, 0.14797676204433366, 0.10534896395139157, 0.12070061518780648, 0.12589648396017092, 0.11169050955363821, 0.06805650093742917, 0.18205443667548318, 0.16581210097478283, 0.2047611295335716, 0.08097786080813216, 0.13394307315109238, 0.14030126584393365, 0.12857543214434577, 0.09905283204129628, 0.18853722590832941, 0.12719613680195424, 0.16473288227233196, 0.13223149483242344, 0.18745319617371406, 0.11553679953419393, 0.15285917828159948, 0.07955649191693914, 0.1227458631018958, 0.12920215335344115, 0.155638070296376, 0.16092387779105097, 0.17636968123335994], [0.024440504963539784, 0.048367309669453296, 0.02421668854602162, 0.009837156920243176, 0.023577275175240733, 0.02258320523035382, 0.03428692388678751, 0.00550064631933046, 0.06531381423795415, 0.04027331495777734, 0.032895041719800046, 0.03279757235319384, 0.04927658325722141, 0.0972810238900204, 0.019187041701027946, 0.049809297817128326, 0.036505667733088616, 0.027759439169218945, 0.03419388250838365, 0.02033224738683672, 0.09668816376717822, 0.06449619923988659, 0.03573688317931468, 0.019289458080405192, 0.03900288453986568, 0.03743992344806752, 0.028893752999964262, 0.04116734339585228, 0.02117572934366763, 0.05158633451848742, 0.056022512200739116, 0.02474176712454327, 0.010750110602877554, 0.028345086574254018, 0.026478505685865402, 0.048048168931516914, 0.04335427161065802, 0.06067791743384254, 0.016740794639073072, 0.03513845359726298, 0.11253140596372467, 0.029707529897531195, 0.02303797608962463, 0.02409667321180384, 0.026339792060635747, 0.008952781190014174, 0.0054550190801702205, 0.09201528789896159, 0.034220718568371195, 0.011597101242401668, 0.06454012672146482, 0.04272421791909203, 0.05575398689195995, 0.03398443406988536, 0.07239254326709817, 0.02617524020493992, 0.054266539086858114, 0.06431291270400248, 0.045688108676263404, 0.04236520996557609, 0.009205533706042315, 0.04990782821550966, 0.05620733857335103, 0.08851602042634642, 0.07835865216029268, 0.06068004332783242, 0.06994630195080273, 0.019064239721985596, 0.03848035128847246, 0.0589222775682086, 0.07140576839447021, 0.02503683929511857, 0.048764886319517135, 0.04198338025279584, 0.037530011557523286, 0.0872499835226805, 0.03554779352740415, 0.021570892816769983, 0.0147948298047507, 0.07165687669429087, 0.04291308157506489, 0.07042459362456877, 0.012666249719087877, 0.021046273891002904, 0.05227052764366231, 0.05234203046007503, 0.00867752771404001, 0.025232040413445043, 0.01391740536482464, 0.0485067836369478, 0.04836055277396114, 0.05964738361897969, 0.024629257536763628, 0.028956987812454184, 0.04998992985835479, 0.07001834485920207, 0.09917254094034435, 0.08087457683418067, 0.02455467121645568, 0.03147065252696555, 0.050512501414144234, 0.0395353501211972, 0.03105737298967377, 0.0271584585143794, 0.02561693639314223, 0.04824490031047214, 0.01780778657825243, 0.03168586194665442, 0.018983499800425865, 0.014645318170228313, 0.03422222776158202, 0.06679316832413597, 0.05241548297025504, 0.06584367128990351, 0.036944283713256164, 0.05943382894920726, 0.03596865158948687, 0.041539049256713166, 0.03751979960549263, 0.01650198396565693, 0.08784156427868912, 0.03648286512602241, 0.03748398882547214, 0.04111971954003938, 0.03421012357237839, 0.029206933573849743, 0.11578573980518889, 0.03518231979180728, 0.06284674299099753, 0.04913314861515838, 0.054560839423849705, 0.029753847573433193, 0.02580313023269898, 0.0026300820689122645, 0.030454258779965104, 0.06080182449471566, 0.07829231660692923, 0.00839875406405378, 0.03894030281733121, 0.009361095519946709, 0.06873439681986648, 0.09038573461434535, 0.04239725925388836, 0.06078409722014781, 0.03632193686620843, 0.06403334806823442, 0.041083694255400094, 0.02618521083927443, 0.10438540154286932, 0.035008812368276625, 0.021316137938429753, 0.047687977372157964, 0.0660757423048058, 0.010986626842960475, 0.0317622619801231, 0.10735429102374662, 0.05369986767970747, 0.049604637428156795, 0.03926294074664193, 0.024098157507157134, 0.07026497154466568, 0.036035707265499144, 0.06262322917820946, 0.02764948256944697, 0.03478583098659593, 0.006805733118521711, 0.09915318955937702, 0.0033108421625764745, 0.025440098402360757, 0.04149602575888557, 0.0113557442842472, 0.030149189161977945, 0.02662144237077765, 0.03255633509627754, 0.03349720215004298, 0.005631619104890214, 0.027915010559222395, 0.09527282398794928, 0.07109865140650543, 0.030489194304532105, 0.051310535204867204, 0.005317333927978912, 0.040243675015986934, 0.08612335929947515, 0.07246942019029971, 0.049540803151866125, 0.018985110500286666, 0.039261584771015955, 0.031125447562625332, 0.027365769567568938, 0.030415042739121184, 0.06526381934001561, 0.05360971828321776, 0.06084345754296069, 0.06462710068350838, 0.003934136564625547, 0.10092644561682979, 0.01140750884529083, 0.05586117791432527, 0.049309705068627675, 0.03237321326929716, 0.014508986120833265, 0.02409500505534872, 0.024669182208937504, 0.04472642701359526, 0.1212924640745886, 0.028262195860846873, 0.01726630605727194, 0.026833782791190093, 0.004355285021912066, 0.07854574615316046, 0.05578871365756758, 0.05004216556347186, 0.05720731314091433, 0.06834703978271255, 0.07359895554761733, 0.013650920722753772, 0.04404300380678427, 0.11809126609155249, 0.0976731000287879, 0.06247779887710368, 0.033293821127905, 0.03359247667474612, 0.04798591279635026, 0.052553727366631074, 0.017531627203307806, 0.026289896754127358, 0.02515345319895254, 0.03013882973802186, 0.03291660326442892, 0.055519767000430056, 0.031639142074592175, 0.05577367152117434, 0.024637175055461067, 0.021061597564708323, 0.059436866487827034, 0.034757723220654076, 0.03463970737591867, 0.10705292735609317, 0.03764366070109029, 0.01725786568356618, 0.04448654956274456, 0.022143708249073357, 0.02991097795236255, 0.0076813907681724004, 0.06203271711485521, 0.026877258280893008, 0.042576416575860594, 0.015361824884049356, 0.09009845164274016, 0.01888634836030824, 0.06584939396669788, 0.08603948799352493, 0.0035361021770269523, 0.03431527297042551, 0.02143915250687109, 0.029729011002928022, 0.03385637864290226, 0.05947412900446404, 0.08373656640610389, 0.0644835128238605, 0.046645101880834955, 0.05041706984141662, 0.03722708890094392, 0.019453048495756044, 0.019918521603329048, 0.04209939660804887, 0.019860224227511117, 0.04481836522538816, 0.03754533714644852, 0.017794067858748378, 0.019986778122162627, 0.012213464942760767, 0.15496264121705486, 0.05410473748681046, 0.03754401947521875, 0.0707766569910511, 0.03893620041649669, 0.038268987630163474, 0.027322598597815922, 0.024150023574850733, 0.054139448930659605, 0.06350751297788755, 0.030678207347650203, 0.03444353524114817, 0.01901034160607284, 0.0057103777315557725, 0.0607152795419097, 0.1127202466370598, 0.056891581494241, 0.01853864594933487, 0.07099171319315511, 0.07820310566814677, 0.06303640720885127, 0.015009068207995547, 0.016866381347720182, 0.05294242888809212, 0.031386875066786044, 0.08224187523967798, 0.05606848896751481, 0.024980723354665023, 0.034772968370347254, 0.050683047907847556, 0.0491217530572847, 0.05339606785245481, 0.04057602310973791, 0.0763184757482621, 0.018748864306197054, 0.023641597832583135, 0.03490803350183753, 0.025555777678927107, 0.0347125546766385, 0.03079425434642021, 0.002931180718024412, 0.01376327422011884, 0.025107784782566374, 0.05122860593180503, 0.0819414921645676, 0.10507613705891757, 0.02302666288620282, 0.02080472636847727, 0.12122813567158677, 0.029817141757737246, 0.05340984211333337, 0.06924897041772643, 0.0604482519350225, 0.040819355617127115, 0.031036523906814478, 0.03540145158166847, 0.023631441421926986, 0.01488839116533317, 0.0679549406613073, 0.05895096373053328, 0.03171909675602952, 0.012186812743875048, 0.03590045827290705, 0.10392024061612545, 0.023284575962010893, 0.026520389627905625, 0.06580444758818035, 0.05309723227495148, 0.026679779966211608, 0.029220192640599225, 0.03639745015290476, 0.06292706347941872, 0.05325037325101514, 0.012892550176700518, 0.041780129465604984, 0.02279487915427214, 0.07436772477963279, 0.03253901384830956, 0.030966702653395555, 0.09114174848242153, 0.250563029079668, 0.15978275918431822, 0.12435454815145462, 0.09059178928333907, 0.16228553778942556, 0.25472258007334125, 0.24772033726255743, 0.20992070106008362, 0.16626715720180543, 0.09094903140418953, 0.13927095419456884, 0.11283607147033177, 0.15733337690753324, 0.09532078109200924, 0.18155309341607556, 0.1253639302787281, 0.21062988397334853, 0.19330359514682524, 0.0868662654031669, 0.2164651910143514, 0.10564610647458224, 0.1151586585347691, 0.20728178863083163, 0.18529379349802771, 0.1044279424053046, 0.1407512505688975, 0.10528300378111102, 0.13647166891924797, 0.1581050113083855, 0.17710144841863265, 0.08572060389504318, 0.11734475937461662, 0.06621848746773697, 0.23721636783692146, 0.12949838423200194, 0.1762595177898484, 0.1502672270421059, 0.15110135889582096, 0.17376519679542513, 0.16202813224686732, 0.14823550057988014, 0.20111335591683466, 0.2781692219357337, 0.20222782998556094, 0.11206203155339726, 0.08425259557101997, 0.13661552490966936, 0.2089900574496677, 0.13720953416439796, 0.10320860622150284, 0.18862474379279923, 0.16122576239849293, 0.12366110834503367, 0.21297909259315462, 0.14223635797539066, 0.09235032879176641, 0.11903914668026472, 0.11192742990510118, 0.22660002863455206, 0.072465926829365, 0.09523084236969871, 0.17944674999002488, 0.25051547034132865, 0.12824475795270937, 0.19101035691076712, 0.18314113239607505, 0.11940737450194937, 0.13383854811470355, 0.2060152307873772, 0.21359933269841058, 0.12858186728290974, 0.11372181466750561, 0.13044071834414236, 0.26971427723765373, 0.17895570295231958, 0.15031549058133556, 0.11893606188917354, 0.12476621315844598, 0.23100975330077836, 0.11290521856637732, 0.20229965838934147, 0.09617017341717597, 0.1868870725194293, 0.2686804569055957, 0.15283660933135018, 0.15526576688693416, 0.11615424341852627, 0.12506502575331158, 0.1301250135105464, 0.17626691819919696, 0.1926768739377299, 0.10022929028397608, 0.20378311104591817, 0.13859770080495265, 0.14499862588221027, 0.15944535874070662, 0.24784317180033655, 0.1347087933531692, 0.1029597195766626, 0.14242237944516445, 0.14873217070294967, 0.13201887478991864, 0.13020931382573422, 0.15043959682506902, 0.11435867888071846, 0.12041275765025809, 0.22025564084610633, 0.2533455829947226, 0.15347272277839724, 0.12248354693574291, 0.2412999229085061, 0.17176480332930244, 0.16194320373958157, 0.14272581155021347, 0.15895717687183814, 0.1377523993893016, 0.1269929779453143, 0.1285990429741721, 0.09658559991587555, 0.1981235905400207, 0.1390284260795001, 0.1499282331356118, 0.10511839446882087, 0.11222096415416849, 0.1879490082783084, 0.23352984549297442, 0.17209218334286444, 0.14949078160908916, 0.16952773465985255, 0.18885691439913166, 0.10199295492061686, 0.18206531512400798, 0.11062519534701303, 0.16043304525796445, 0.10985680149808047, 0.2621116206770943, 0.1001304113155892, 0.12441957369446756, 0.12107784454260143, 0.16606443501528234, 0.20654989887149106, 0.2673154720856298, 0.2941059345199216, 0.11627572198067943, 0.23835295120314245, 0.09522867434087301, 0.16962004825472835, 0.1824552998427422, 0.15590394877137678, 0.1313098297724801, 0.1611760586139656, 0.21958866937746926, 0.10568954365988893, 0.20393770758903798, 0.2226168770463236, 0.16770409299961983, 0.14847114922538882, 0.14227671548724174, 0.11799666189378309, 0.22374219892005767, 0.11002179385433275, 0.14796995918356604, 0.1481726200830552, 0.23351530514417157, 0.10414481929112827, 0.20635708986270815, 0.1077763595047497, 0.16900633521858724, 0.18279363491362144, 0.15596284561099547, 0.12109311267493233, 0.28991157249096905, 0.1417022567963408, 0.15292317726679389, 0.15058331491966404], [0.07614471934615605, 0.023383439608639287, 0.02671400685944865, 0.08082309572566902, 0.049228538053050164, 0.012115603913703274, 0.038926030599301865, 0.08847498109624272, 0.06896925639481315, 0.0494671514588258, 0.04853235565186028, 0.03459962948615994, 0.026404664386063818, 0.05664996502380218, 0.0422655227744291, 0.06197204678169182, 0.04008055574470951, 0.017806239080645384, 0.046419488987134355, 0.03818271846901025, 0.02455827566013942, 0.023781263322058706, 0.03336894370975994, 0.017458642006761605, 0.03513509813215464, 0.01653010705335727, 0.053878565348925135, 0.021528782878792094, 0.05734321330824206, 0.025461125600662445, 0.013443757141489657, 0.08565010082337164, 0.039562224485580964, 0.09303183294832708, 0.0937442564135117, 0.01313540579435686, 0.04896888787287378, 0.04624717666076557, 0.05124657069362941, 0.003682886538538902, 0.08148128016581459, 0.07142092161361249, 0.020185641140767166, 0.04674257507788078, 0.05131858295851177, 0.019664442797581998, 0.004250530159145955, 0.0625856334133254, 0.03859121187199508, 0.05860966772982671, 0.027763371115490317, 0.019463515172021526, 0.04030354095682983, 0.026333569511470777, 0.03930830081263858, 0.04555719957176236, 0.015921724073949362, 0.03581789697730734, 0.02400989268696116, 0.0658410742518402, 0.029575559761255022, 0.0523161635013117, 0.04678908810620347, 0.025441833591509252, 0.04196205236498387, 0.04540113980070718, 0.08581366825608477, 0.06378438098416214, 0.01930494646301433, 0.0423547413740908, 0.0316915501494922, 0.06111877805162823, 0.025771475479667707, 0.023185055394987428, 0.02866332141321994, 0.03217371631293528, 0.05146038966373571, 0.02281277496818333, 0.0667031683147915, 0.04901926581477446, 0.04941601125944046, 0.04442498290670976, 0.04353485768660904, 0.06963497914013363, 0.019840597054891048, 0.03227784298360348, 0.05571514623419893, 0.010916446485827047, 0.026092234578344132, 0.041614351869230314, 0.03781417272083702, 0.009022299838703006, 0.052444586650498455, 0.030531501510150494, 0.04153711105426473, 0.018117203745209885, 0.021614023566906972, 0.08350838711785694, 0.051239515023846785, 0.02699209103030303, 0.02693178075846405, 0.053977961426660906, 0.06576775197660731, 0.0625370442867279, 0.016816627767477787, 0.022033251776930787, 0.0446594096419792, 0.06132800432462847, 0.0912558189743469, 0.01925416824017321, 0.03640567410677191, 0.01228984582403134, 0.03523675416926703, 0.017832464185513316, 0.024420180650908622, 0.048406230766446366, 0.07491885609323941, 0.07066491540641555, 0.024160055496219187, 0.07618241087203065, 0.025139778529504136, 0.008162565326558487, 0.06433679932548154, 0.003394433607031862, 0.03199838560014483, 0.024741184897720817, 0.05289577030306382, 0.08319123437808407, 0.04249092116351089, 0.026354161954875437, 0.05474586497932192, 0.06331408726832559, 0.06854973132571868, 0.1047314587800253, 0.03516108000410661, 0.02169349752817183, 0.025421796561849695, 0.025858296224126415, 0.01132616179905111, 0.013537075269156167, 0.007591364903360486, 0.07434330955748597, 0.046410598536773075, 0.04497560094140711, 0.014503866738279261, 0.060352919953725034, 0.04885901554277347, 0.01418439466731563, 0.05374193739806933, 0.0385337476167948, 0.031885102263561664, 0.04640877524751329, 0.05505825265220577, 0.0334568293164334, 0.01961145632629914, 0.056755087608771945, 0.04665159064555361, 0.06742434050407141, 0.005454844316362494, 0.0261217059807912, 0.0936690342402266, 0.016947134675818588, 0.06462280293025317, 0.04650479670794261, 0.033007947758080504, 0.039840980898588896, 0.061382400397692, 0.02351151993347993, 0.02471723890442762, 0.0540410487672254, 0.06621823465872197, 0.013658255057018853, 0.09322617413295854, 0.0487268309018785, 0.03783065893296753, 0.0645826829056586, 0.07601762535951792, 0.07578387661206146, 0.09015820650083405, 0.06820390391493998, 0.027860566605663592, 0.08044062632947199, 0.04150937867140578, 0.03296000214533941, 0.05074615440061016, 0.02181251311764842, 0.04916568053886295, 0.03178398440321607, 0.022524245188481385, 0.030031056488834085, 0.017403137021427675, 0.06632412333161601, 0.023607516496051705, 0.030016311211511496, 0.018825107291641257, 0.05130235721627551, 0.024520871417236426, 0.0036217338093856894, 0.08208566225103794, 0.023421337978253444, 0.06291134718565211, 0.05590661458911435, 0.022543366743071426, 0.045067784301335775, 0.008723232519602584, 0.06490854606513055, 0.011109222935873174, 0.0563834966610997, 0.02958435253540595, 0.0123433513198829, 0.07340757912325283, 0.08893820382053814, 0.05391156458626351, 0.04101912070426249, 0.05036037933501986, 0.025091534142472574, 0.02593739480230837, 0.04125109978861386, 0.05768640154612161, 0.022466263823932218, 0.03996197299491014, 0.021323264471345374, 0.03271036473433337, 0.08311325428827156, 0.07486080195033744, 0.07349921089987602, 0.054207600112403595, 0.04101211483019494, 0.06206186292993446, 0.05428695916047981, 0.06881361031123708, 0.03603047488497631, 0.015056870179250838, 0.014426377902348197, 0.00961601893763028, 0.07457451489303382, 0.03845087605558577, 0.05366452038288117, 0.16414952163975086, 0.017600205479069583, 0.031070668445599657, 0.04312161070805404, 0.09364883250166332, 0.0377884513187793, 0.044522230107817924, 0.009843823800404227, 0.06601420246184835, 0.015813969019349786, 0.023201294543762362, 0.020202414635869286, 0.039191955039578105, 0.1178469376698617, 0.026609843799604044, 0.013454367459240942, 0.07185231338465406, 0.02695289605687703, 0.04650502270388027, 0.020649792746670788, 0.08640618363936102, 0.029548664329453345, 0.016882028693573612, 0.031720776403803504, 0.008640303501799222, 0.025486360536888245, 0.020250957797191316, 0.06745452436828805, 0.03093712974429852, 0.06510887805732989, 0.04330148049179585, 0.020513773835714788, 0.08028961507783783, 0.04968455572041774, 0.07480428764416326, 0.06350559775807685, 0.008106988520481655, 0.025688569444502075, 0.019820866460401206, 0.06537048176171319, 0.05257107925811603, 0.019719271710322752, 0.07833911691822353, 0.031088960710011666, 0.009718233261317497, 0.01666726168966101, 0.12248648105249291, 0.044215672364037846, 0.069919396942902, 0.07096507631602787, 0.04006301999212273, 0.05512893575453951, 0.04293674986148554, 0.06104191645018517, 0.01846893960910459, 0.06849689424158105, 0.010605760485745006, 0.04392726324318398, 0.025040129642753352, 0.02556299997283326, 0.05054912807780409, 0.05829198638938608, 0.04382836895303861, 0.0370217505241594, 0.05137510109512557, 0.02768114306813767, 0.0520422640857437, 0.06105800812703468, 0.03717319078503117, 0.03736188973210031, 0.014933175707776702, 0.0384780683464581, 0.028414262398596735, 0.023238671973588008, 0.030875907827829643, 0.035287898199092, 0.060022188305494294, 0.02382740862817774, 0.07163976229006244, 0.026831771810388854, 0.022230952257110227, 0.029884007826988256, 0.021719372147814404, 0.02232740081155733, 0.026476015900111487, 0.05483625569350777, 0.04572349427748592, 0.052032653512733604, 0.025646827228727843, 0.04694126764192216, 0.044359394289072485, 0.05340427265412385, 0.051437950948433536, 0.021880725586426356, 0.0196498392465254, 0.03743807717617001, 0.05070383570367291, 0.027828727991530494, 0.05175543693645347, 0.04099992637131964, 0.09622843440381751, 0.01744573151001767, 0.020779499093130715, 0.07340158831568495, 0.056582928499988014, 0.043089197527977734, 0.021743166838742552, 0.0325427791704574, 0.025359295278547273, 0.027179723199937614, 0.04115097592735002, 0.010577497586998488, 0.036208950388695926, 0.06805875323592656, 0.165971125506105, 0.08549319835559976, 0.28286776174941375, 0.19684034730157546, 0.15066626692010512, 0.24950391252435025, 0.20014908104654283, 0.16955304620487077, 0.18972181234388583, 0.3330011070976335, 0.10190307748534026, 0.1474066700546011, 0.11328872984215138, 0.12114666988171878, 0.07254569956492032, 0.13073940070406084, 0.09104820914686688, 0.16452698848180233, 0.13572451868845573, 0.12839203069527305, 0.1035383381249924, 0.07753268680385045, 0.13952089804074458, 0.0933865086746312, 0.09195018574715623, 0.12285101633038252, 0.10125988538587287, 0.06735176133412508, 0.11163091557400842, 0.24174664409891253, 0.17733345048562174, 0.15939081328049784, 0.09780910361798541, 0.16146004740749637, 0.17147862352430823, 0.15723283552835066, 0.20202806489842556, 0.12809168592455888, 0.25288530204805637, 0.14180451421247375, 0.163313030235229, 0.19666125126663717, 0.17962184704599843, 0.19746585809175046, 0.13326488615524384, 0.07285706067998564, 0.08443799650957508, 0.24711534230699464, 0.15325103225486894, 0.23433878837573915, 0.11008160233858133, 0.09838926200304302, 0.20955356108325146, 0.25822102783187745, 0.15137266127332566, 0.20796978155211096, 0.12329666499769497, 0.07495054915066689, 0.11238363526401021, 0.20625674766638588, 0.14799294182129447, 0.17239540094329467, 0.19695944333028412, 0.19125001985699902, 0.09834589376564949, 0.14841881009840197, 0.14391657265443958, 0.18236100974102176, 0.16305490457002195, 0.13169546311180438, 0.1297968520873016, 0.11242652852689067, 0.16655600299277615, 0.19488712952982998, 0.13501263914569733, 0.15681677317667395, 0.24344847777918463, 0.10509881326147627, 0.1984514302063373, 0.13037046808148586, 0.08122578218218782, 0.18365301702532077, 0.13990133730394227, 0.18496573932709234, 0.07817180331556067, 0.1542238107011203, 0.1652738169556664, 0.13377860939550784, 0.14957013299628613, 0.14571747682507963, 0.15500793233513832, 0.1524938769157856, 0.22575881812841664, 0.1813675775643318, 0.19823353947891345, 0.21552123279581148, 0.12830566194268966, 0.1993058480682873, 0.2866232166847875, 0.18641013682128924, 0.09501761711773374, 0.13268192388838337, 0.10727375986114626, 0.1599427796299419, 0.14672028591796277, 0.18601192431824823, 0.11550453191082324, 0.09961190768667769, 0.24238257368485777, 0.09466244343427882, 0.17787997761080343, 0.15340858589737646, 0.10920103789577562, 0.14892830453332395, 0.08075695169428665, 0.11650902639713981, 0.19114796162372638, 0.1661603951886777, 0.17886047822333154, 0.10336123391865723, 0.11048661004151068, 0.10187267911650481, 0.11721070930962602, 0.19683355976256633, 0.17100950192299583, 0.10703544522966109, 0.13516411005008605, 0.102293583143863, 0.17417520705250003, 0.1860341255462939, 0.10592589710628796, 0.17387752060688313, 0.11473155685610349, 0.14060275208565498, 0.09880484171932745, 0.1849940232932568, 0.11967385818641033, 0.10584802426878484, 0.19263388108341925, 0.1128902875127331, 0.18408423259613976, 0.15117599118140437, 0.06847870731425863, 0.25308866774843586, 0.10780267462494875, 0.1898408011202851, 0.0859616304777803, 0.1391359695023106, 0.14786975488307016, 0.15971537409049852, 0.1370975014663512, 0.14386051034014072, 0.08096119839577906, 0.07860094278810487, 0.1512616704548559, 0.1395725017233241, 0.09945933361567798, 0.1489756181235275, 0.11835899083845078, 0.14603957083196412, 0.1676254617350717, 0.08715966941728708, 0.19851683879331236, 0.2392782628416054, 0.09093539503913733, 0.30633187041647975, 0.1804850442755607, 0.1730821068368612, 0.13831573448354198, 0.13850262929354945, 0.17294122326758601, 0.06201426588719892, 0.21434776995691562, 0.08860343871938606, 0.14090577050322486, 0.1868082727155378], [0.03103346530077679, 0.023457403482508757, 0.03228369206490536, 0.014663536698677608, 0.040900373245559396, 0.007155095067461052, 0.06249684382290129, 0.040476017992102334, 0.012796139926649632, 0.008706711833515476, 0.09903424674825323, 0.036196574238279176, 0.03480260831213767, 0.026962654101812554, 0.0293038571028099, 0.049873086128143534, 0.05523431497896391, 0.024370105313738028, 0.046300327840952143, 0.02131410014455117, 0.034161928981061906, 0.042960004460427074, 0.09701748198318867, 0.046672857246331634, 0.011576038612533483, 0.030815486473241643, 0.05589451806078996, 0.03193571577749906, 0.021094644682541974, 0.03947590552871266, 0.075961907784785, 0.10313045759234699, 0.014829632221540857, 0.03223282765717276, 0.038391745559150176, 0.022839507606301098, 0.03325362066407839, 0.03358948127096219, 0.050598487122765476, 0.01127672614529729, 0.025282822466725786, 0.06984442757863192, 0.06367556585539734, 0.04554465105156264, 0.05226939000309475, 0.026486329358792114, 0.02935133348669737, 0.08569426579220642, 0.021096563732792294, 0.05132052882183945, 0.06934632487114399, 0.010481460804810688, 0.023062138502756437, 0.017881346340741844, 0.03812543424447218, 0.027188864544094093, 0.02897536051609824, 0.04540340359052343, 0.04809858900825343, 0.04282533386421781, 0.03256381594485814, 0.047357739850638375, 0.05411300740595307, 0.020655492440827435, 0.09149666169598218, 0.035249436754853494, 0.041543392975243836, 0.049437714530335325, 0.05978996024256753, 0.06047171337770359, 0.03445647063574964, 0.027858994210199006, 0.012011610350811915, 0.055764608701030095, 0.030025029292089805, 0.059697570038899306, 0.12491608293907297, 0.02206755910939988, 0.06635350280351217, 0.06281728307986933, 0.06996536987923807, 0.03227119334042072, 0.025520294401494246, 0.07077306403868622, 0.025987596543986472, 0.02378287785235913, 0.030201306123466744, 0.007709256258808197, 0.027677875703140616, 0.06723447327291773, 0.019485473167151213, 0.04473513743329433, 0.06106121803543741, 0.014303257039207366, 0.008517920955895417, 0.05011296740943386, 0.04535229403465506, 0.07268580172451274, 0.035681874235911716, 0.025230948738152945, 0.02245883085584689, 0.05256578559055925, 0.05242611244020443, 0.052271734232143055, 0.06431004753516567, 0.059183007932358214, 0.03603005353661795, 0.030900790363610275, 0.06584037711182911, 0.05933685753975184, 0.04372205893178621, 0.020519069418491378, 0.10937320849587841, 0.03604027697996747, 0.02717441421062235, 0.07823397901149527, 0.042213172156123385, 0.04058350012787888, 0.027476699099004753, 0.0012959306120812414, 0.09892995919912093, 0.040807423797706445, 0.06131659727543593, 0.03164181572144791, 0.044593912954892845, 0.03844039214234199, 0.0666204308189692, 0.08173913003936892, 0.010585141229262997, 0.024417755982628273, 0.06520119931308493, 0.03038678941647372, 0.0558270180537816, 0.0518936621806314, 0.07772485229877696, 0.0409234439833991, 0.023415337594586517, 0.11126916885616318, 0.04415247394072433, 0.02670126873248768, 0.06927334733547703, 0.004285853994529574, 0.03016007144094235, 0.08557663299143316, 0.042305815168806625, 0.08552408702070675, 0.06925586520904495, 0.06891726200739223, 0.042857838974845026, 0.009593464351529557, 0.07475693574956349, 0.0418154422884747, 0.03294635428896835, 0.0548236956819892, 0.009937842898521452, 0.07392881768605403, 0.02208157468797459, 0.08900715939460263, 0.05601800377330473, 0.033979500463653, 0.01999489290850057, 0.015283688703822273, 0.0682741005514418, 0.007165946224103532, 0.07257984410370551, 0.012650990205246114, 0.041229614852777416, 0.016701013608385, 0.03720232893923118, 0.026967823280081637, 0.05340809926330563, 0.03039612036739146, 0.027259409750601458, 0.08385101994199139, 0.029178278055042032, 0.06213306314161709, 0.01424290463253255, 0.04785971130214391, 0.06638041547229213, 0.026206933262367404, 0.005594038182959682, 0.04286081139599124, 0.036294928436437925, 0.05373000557864866, 0.05219139076108414, 0.03532367067471628, 0.04673341266630639, 0.031957645044331594, 0.04259514359516963, 0.01930352345469498, 0.0338460939125188, 0.06585871725673638, 0.0378407636326888, 0.04137032222183001, 0.04466850310564042, 0.024787236358069127, 0.022807000580454068, 0.010042835248544092, 0.009073257134596427, 0.041248303567690235, 0.03048437369626857, 0.05034934000803098, 0.031627235153029044, 0.040590816267555764, 0.007273809009817459, 0.06586324483636888, 0.011544561017334703, 0.010407351374235606, 0.042017352421798056, 0.04836143377507406, 0.05991965892814821, 0.035066088931935455, 0.018891444760224512, 0.06001840383114834, 0.04845208495915417, 0.0641143465444686, 0.018131962429071148, 0.07398319460691945, 0.03744067421423332, 0.015561266299036723, 0.07443324061891726, 0.01895608917449511, 0.04792743730508993, 0.04072509232848402, 0.026051417413738467, 0.0226290536774022, 0.018966567342079455, 0.05325102442575078, 0.085476451673575, 0.02293951272393667, 0.04373396010768991, 0.04024545233997126, 0.09320565063746707, 0.03517692270238073, 0.032456291674245755, 0.02686163391767731, 0.03434821092072995, 0.060493416648598454, 0.051863531942569444, 0.01615842800557373, 0.03806990819172033, 0.05008163058289117, 0.026117435040613337, 0.01094650011509657, 0.036831289574864416, 0.0693300225201153, 0.07568670601974573, 0.03325359768144066, 0.015304691961876329, 0.027169539976204117, 0.04192551380143531, 0.05836522056450767, 0.05100308113821572, 0.028565421122156327, 0.04959280903060591, 0.008845327782534785, 0.08196496509856756, 0.05279732800479378, 0.08552248589694501, 0.04908284728205012, 0.01592463616567153, 0.06336328543482289, 0.05124992615873775, 0.0632802261820724, 0.03239564049328047, 0.11333814251326746, 0.0455292871582412, 0.060895792839507905, 0.04742134047011214, 0.07001547969036526, 0.03284569416615752, 0.08218015919649795, 0.08685840534106379, 0.044631776850550406, 0.02990816832490025, 0.04912643002406244, 0.027251130255359798, 0.03661939348544806, 0.07045702212640355, 0.010423374103171932, 0.07359244380026095, 0.057199215591554685, 0.053481237677436684, 0.030570286626537, 0.10677988595900037, 0.043058170967044375, 0.05555479637076778, 0.05722511702427461, 0.06944466757798387, 0.03790356369028169, 0.02920113620348275, 0.040792699587801774, 0.04476740888710465, 0.01339625298691493, 0.02965794102619252, 0.015241591214773156, 0.06712892933958961, 0.07170285729150619, 0.09332593410245835, 0.03492071608742399, 0.08346838966733025, 0.018476905008297295, 0.034480395561624924, 0.02107715872567027, 0.03555209894153861, 0.03450643489017122, 0.0404967368400145, 0.02388504716838079, 0.05594421418443803, 0.04783558719340832, 0.026070063993815455, 0.05329991232663874, 0.026649542475840258, 0.04653765421901499, 0.052711028200123584, 0.02910846829294197, 0.03879311051399958, 0.01958955578776377, 0.025403931391455477, 0.09010718504507696, 0.05035236605533189, 0.033510053274972786, 0.006842894128508747, 0.022703875569746863, 0.033258385730967406, 0.055915895744317004, 0.015808678224622723, 0.01659350274431129, 0.010625005572012836, 0.05026250394181379, 0.03507145920828466, 0.04269404554619424, 0.03549627411449629, 0.06950937136406861, 0.06881190959604518, 0.004511691447752979, 0.00789539551460034, 0.055099533300005624, 0.04819553743507113, 0.005445200705810661, 0.08302231199078022, 0.004651297086609467, 0.07765109335342724, 0.05737428583445088, 0.04113236382122963, 0.03369583725749004, 0.042440516408532865, 0.039291883548421246, 0.026805035341831467, 0.04575257880553123, 0.026688304609589042, 0.06502270848760683, 0.09794853162020446, 0.10637631850136865, 0.0991283989541473, 0.14895658849948837, 0.17312424167269663, 0.0840355092359166, 0.09847826609808592, 0.1996978705809001, 0.1383458723824832, 0.1506612720268388, 0.18971479497849944, 0.08291869093814204, 0.1578291277250936, 0.2376242330478084, 0.15245814657499715, 0.2011969054658567, 0.1638118454044865, 0.10495442100950789, 0.14673075067900843, 0.12114338336452363, 0.1628041180271295, 0.1473020990529368, 0.1872646006485147, 0.11689441458832835, 0.1523376715880248, 0.07860675739545016, 0.1532976257224237, 0.15941200327248345, 0.05050312832839066, 0.16865977236340124, 0.2300876592315974, 0.1522407001785694, 0.13952604615159575, 0.05737619339338234, 0.22681200516320046, 0.09466802821524682, 0.08190475824859836, 0.12696703820819819, 0.12538796245691278, 0.09177932515740396, 0.0959367770701647, 0.1516921505812676, 0.1474129213320632, 0.10440034791827203, 0.21899415450471066, 0.11720553055525788, 0.12053119484335185, 0.15580768216281168, 0.17987407383418855, 0.1303819134350746, 0.17108462450485076, 0.12765364451033454, 0.2880434517658526, 0.09339539529455286, 0.1459034063643025, 0.09137192726015084, 0.17576427259031804, 0.15461048592002163, 0.11592445534563835, 0.10016906045136914, 0.15078539359233073, 0.1503525232715953, 0.21273942964692272, 0.13194306272893183, 0.16647130431186768, 0.16903009926599843, 0.1078192221241132, 0.16363734589709392, 0.27349688232906405, 0.1492515017068194, 0.22998051417450752, 0.16462575253700057, 0.09478111045374986, 0.21020619138594598, 0.12804274822795583, 0.2041884328448965, 0.23394008557642662, 0.1330895745946515, 0.15205532222265197, 0.14195013220512098, 0.21989757135029764, 0.11307905923815505, 0.18435731229762878, 0.21308095164356694, 0.09527198129123259, 0.14775946886549074, 0.10540039143374852, 0.12084947373237341, 0.11181776441874043, 0.1918934264610852, 0.19907136387642355, 0.18069182672808248, 0.1362262143483085, 0.0880981347854099, 0.14788988767372024, 0.2341382572006795, 0.1641815287932273, 0.144850924130409, 0.0850072917678664, 0.15181650197313679, 0.12784132073002477, 0.13546360446320427, 0.17351462475715146, 0.13589432973775173, 0.1902995652128612, 0.22119449691907053, 0.19660187945250543, 0.11899848273324391, 0.17928147418124063, 0.13282237844842096, 0.13331546328000485, 0.23687463133565842, 0.23907362543527158, 0.2443686566285549, 0.10120837363384425, 0.14687330431995854, 0.19258817627785668, 0.12651134612819842, 0.143105331507902, 0.09564520400618354, 0.23591424819202195, 0.16454943485798376, 0.24888710449299506, 0.15045746199546323, 0.15166113934209272, 0.13839741477802878, 0.14024282865706952, 0.16494542570604434, 0.16106086963367078, 0.08866524669311701, 0.2192561412530561, 0.1425050403321943, 0.14803853937454764, 0.18119421186706713, 0.1643914828497556, 0.16099012907474272, 0.10235802646005347, 0.23272651037381542, 0.1780812442302704, 0.1162210386246443, 0.17628738806853372, 0.10065371065490669, 0.14314593416788887, 0.15345580755702912, 0.20737183460545158, 0.20060030683394403, 0.14664534719720965, 0.14159475933880578, 0.15027219129185523, 0.13257077985232876, 0.19122951934414525, 0.16309835707708714, 0.07815891005579503, 0.15309410680445934, 0.217726233024751, 0.1338794112445847, 0.11462607420980932, 0.18427025406591355, 0.17487536545001692, 0.17753335346858348, 0.08587296346142408, 0.11096587464694055, 0.15311195665309507, 0.12786678549262787, 0.1418712404706786, 0.13657273123821906, 0.17939805744155762, 0.10138893289671791, 0.19558796208472023, 0.1984457917992146, 0.13998321678128936, 0.12190682828546533, 0.1910159033873389, 0.13956105636973537, 0.19142191466544906, 0.17740894078968034], [0.01058035222212634, 0.08181303454142425, 0.04515860402475923, 0.01941196511559669, 0.026075748366213618, 0.1166934927084273, 0.016660537352905642, 0.07739731906763009, 0.04636097519147781, 0.03182669572021452, 0.03551868601672111, 0.03279564181162465, 0.03179794060997665, 0.015491676787214895, 0.010160497735224424, 0.041661366685143406, 0.06722569390530549, 0.04748334379626378, 0.0422107398269638, 0.05037468985744542, 0.025628994617070404, 0.03836115949877328, 0.045900828310198365, 0.018840475015402324, 0.050681917928159244, 0.07512593732005166, 0.04772154351456031, 0.07876358325442961, 0.02075182225164627, 0.041189686350163915, 0.10060095784044075, 0.06419626049577229, 0.03351923866918491, 0.08845342338205346, 0.016733729393191395, 0.01990871567789826, 0.0239864006007631, 0.019568348558799877, 0.05492021509956929, 0.030388061122428027, 0.07936468648333704, 0.048593772920749845, 0.00735556208265705, 0.07091975455442745, 0.04320800244327515, 0.05540621744829321, 0.007474271236963931, 0.04840436534235074, 0.08055646648450245, 0.01639016002656952, 0.05242067321594204, 0.04302377361924418, 0.020749179248307503, 0.03318788265929588, 0.010839138638168093, 0.034180790065757694, 0.03221801917759642, 0.057277555742691603, 0.034929085597996755, 0.06457155930899805, 0.022382599361721548, 0.06644514990189383, 0.015584688479711693, 0.04534184459536787, 0.03235532511626521, 0.07193577866400443, 0.047493341243675644, 0.04291139618163148, 0.00498094184759764, 0.046819172378989964, 0.05119798156703192, 0.055112338459659974, 0.043012596396428925, 0.0532183469453406, 0.03693811670546571, 0.052988972559931784, 0.016047939932304287, 0.04203498776581499, 0.02391310896904719, 0.009742844793494913, 0.03363157397196178, 0.04087842099608914, 0.05555612936375603, 0.025699603025831526, 0.0581635402575616, 0.025305651886869344, 0.07517365693685508, 0.0787225439243259, 0.004867271157807761, 0.02698558502860608, 0.04156616876923269, 0.06706866886346571, 0.04823275781687229, 0.06410653244764095, 0.028749508219921303, 0.03475004318921316, 0.011248231504953677, 0.03091869766884033, 0.05138771473279884, 0.027239248231654207, 0.0807171381048618, 0.03751620665312775, 0.046986340424947204, 0.11919711401025135, 0.013180762029913886, 0.03258108356667142, 0.045353822380063996, 0.038124281282146136, 0.037083757680750666, 0.05462395740793117, 0.010729607217194093, 0.06539032343895206, 0.04300103612965153, 0.04153545247390867, 0.012695593759417536, 0.06467406187326678, 0.03872860591077516, 0.019674539836424015, 0.013066308494026383, 0.02228388318701858, 0.041165650341539614, 0.04573642201120815, 0.01992736991885449, 0.037902165579819874, 0.026223427135377165, 0.05103128849558773, 0.028975124944061525, 0.08744017251076237, 0.03168730985283131, 0.044378718856962464, 0.027281053649682193, 0.060219582350504015, 0.010492735703836286, 0.023208465126733628, 0.03429383783030414, 0.05922277172606799, 0.014028282227715658, 0.06059659720068017, 0.04115693226096131, 0.05595194401159402, 0.05902168896770286, 0.042568786340134765, 0.05711778427564329, 0.004525079791839685, 0.022350691799675266, 0.04103835334160155, 0.050419375766068704, 0.047235311339459116, 0.013801805569880433, 0.011858210820073803, 0.028433167533348166, 0.04217106413336531, 0.06157525920218999, 0.051446014023836584, 0.03891460439791122, 0.001110652486996485, 0.036632313558291045, 0.008450645987214822, 0.08027841487238485, 0.06253518269307191, 0.02576733094399735, 0.02122167546692635, 0.037187830725264166, 0.04068262807484116, 0.010103942251824325, 0.019671973441877676, 0.027147652844207424, 0.07142652937721822, 0.030980963380106037, 0.08732049425523128, 0.026481570037562522, 0.003073419305315662, 0.05256561705121591, 0.03636822389859346, 0.052056199225086364, 0.055137247808517954, 0.014522346694232717, 0.04613108752715973, 0.04965119642175494, 0.07347665727138519, 0.049462895840406425, 0.057381169134450544, 0.03614782806365721, 0.03457122294592761, 0.043717297695336804, 0.02712273966490982, 0.028012190727637182, 0.03971483303053726, 0.05570318760170091, 0.053858528319265575, 0.031166912071527015, 0.012302378064862663, 0.05116105995952122, 0.02974902888038947, 0.0717569967251151, 0.06188529115470667, 0.026460322588982604, 0.052480799626679196, 0.03267997019593755, 0.07422208380434783, 0.07983257468309134, 0.0027031773905975805, 0.036763881498406974, 0.03534317910370808, 0.05604725684069338, 0.06105900404133624, 0.023864556231626102, 0.02067296499116046, 0.04169196806727879, 0.022176967956305995, 0.03991246839324313, 0.009086440550163388, 0.003566902263217696, 0.11148589512994213, 0.049759697454470786, 0.049365457117317185, 0.0587441468040549, 0.04977905649631735, 0.014842473770371609, 0.0174175662874815, 0.0147565292389763, 0.08414936522322317, 0.029514523621107784, 0.07950567730492161, 0.052148248519628286, 0.030593230959869204, 0.012368488579898352, 0.035049139236610745, 0.00262953718887612, 0.02595123609588031, 0.06530615335871136, 0.017559321281770547, 0.03528938057922548, 0.03189782698398396, 0.050882851299379146, 0.02914547225490453, 0.016559153277006362, 0.03354044398292899, 0.039227719854323134, 0.005441124639248536, 0.08031111916587239, 0.04738181799409851, 0.00901206873447424, 0.011400944429389652, 0.062335295031868646, 0.05835136586439706, 0.03659248847754733, 0.032601844549419425, 0.053653312516548944, 0.0300018513019407, 0.09389072476375489, 0.07072147567786517, 0.02431476886774744, 0.05959396047757999, 0.037691855292406776, 0.03368845983077923, 0.04605719834686287, 0.04493627381781417, 0.01799114397726953, 0.05355962762428869, 0.12233766081232218, 0.022282314621993614, 0.037635528677774054, 0.057134642040417086, 0.03462659578109461, 0.03295490383020332, 0.06625068614319449, 0.021539239978958524, 0.027086225999218803, 0.04228087134599205, 0.0252481761403502, 0.02037751743750226, 0.04621454131519122, 0.041110794615721515, 0.08010904049320568, 0.05180159373389137, 0.02917568101697872, 0.005786225702914019, 0.04822726113601558, 0.07513420340875465, 0.06895598009108536, 0.05631336514207144, 0.018630978696408774, 0.01234224528044222, 0.09823286515330115, 0.01673373896929045, 0.04798770161165346, 0.039171067652322596, 0.025731366946392005, 0.019765589386224747, 0.03258594439455098, 0.030287535065003944, 0.016914118201501908, 0.025513543251661525, 0.02456272471575968, 0.012869777255541375, 0.03406290828640904, 0.05043058746284054, 0.03180553637174589, 0.0355022725829434, 0.015025784246503346, 0.01729108134074317, 0.08362064198140176, 0.07196482871809314, 0.004985077764778849, 0.015502155912409147, 0.09669016325666059, 0.023014259922708717, 0.08366912002525023, 0.013361011027178217, 0.0037637205452718324, 0.08943564769241119, 0.042680746259828733, 0.005475723563933806, 0.030318113464501598, 0.04027576260869542, 0.02622666768729687, 0.04420504672452808, 0.05135499894799245, 0.010387023231164824, 0.01849819459171305, 0.028531824336237008, 0.018234026408003225, 0.03867718608929746, 0.025182051261165933, 0.018379140697840243, 0.03743595128218013, 0.03118855214016813, 0.030954161794075084, 0.041523378928222006, 0.04222652123820397, 0.019046209842687654, 0.024202286093045148, 0.1077353738008007, 0.06562161304417156, 0.019351026651659803, 0.024102493564808564, 0.03385269759042609, 0.04217280698339305, 0.04147728341781805, 0.05998384177444443, 0.018500952508240458, 0.006927652181231327, 0.05145300074570602, 0.033898456022143364, 0.048358599249754226, 0.056593898879063714, 0.014645006947009074, 0.07463617731005916, 0.006283098360478518, 0.06486110223997986, 0.038149799670903914, 0.12959279690779027, 0.23514740950157567, 0.1412485642058234, 0.1683930205481668, 0.10410009507810879, 0.16145551216698464, 0.085914041095924, 0.17679352703834736, 0.10715193655942717, 0.0993441139918662, 0.16342350011391027, 0.11948645009749359, 0.2911025634215724, 0.19122636306189722, 0.12980776117934337, 0.12929031475176736, 0.13186700551980926, 0.1180761818203234, 0.2726999057396766, 0.11728277520066309, 0.20411042977244626, 0.1266735422635271, 0.15375306499340843, 0.2451170172782675, 0.16250191166275935, 0.14233006585028865, 0.11327498622478978, 0.2418506022302374, 0.06504811962405521, 0.10539899715372633, 0.211681324327665, 0.12088810754639488, 0.11354883201420309, 0.13408332852826965, 0.18626657194427906, 0.15559854015948313, 0.14162691970986707, 0.1463024462423017, 0.12320517111689815, 0.20693763129172787, 0.19610356990127795, 0.15041909631221526, 0.06309117866499771, 0.14057638333930125, 0.2712999873103634, 0.1281187135065275, 0.1437497187045313, 0.15410335103590644, 0.11208283850142073, 0.10003820497302279, 0.07810441056086172, 0.12718328950746408, 0.16400588015394826, 0.10391972733721619, 0.15238598109252993, 0.1375448508488555, 0.10453200012805963, 0.1324309534843891, 0.12204758928067262, 0.14683051064850824, 0.1583491482080952, 0.15130458670037408, 0.15414410691347816, 0.1412124661428313, 0.1841720262722623, 0.16194827524164032, 0.1260620355606079, 0.102253922772023, 0.17942903803721552, 0.14442698639487067, 0.15515986289228165, 0.16718326046341853, 0.12448289086140933, 0.22364884344560487, 0.2572218653175139, 0.11897848017754094, 0.13129676031249185, 0.09769703261554243, 0.11777805870458966, 0.11529976426954232, 0.13230081046781234, 0.2510577226958929, 0.10168277358095493, 0.16644508878309883, 0.2028286727445741, 0.08618015705818131, 0.09995992610891981, 0.3592241128846523, 0.19488087825236783, 0.12569735472601268, 0.10838051176359577, 0.09329321448721233, 0.1689455997679503, 0.10987132652512482, 0.10971777186158205, 0.13451348689775314, 0.09447031624374852, 0.16250561952831286, 0.16652269348982843, 0.11653625316196874, 0.1755534298717976, 0.08992939902048919, 0.11177818065569287, 0.16671272926032546, 0.10566926531253323, 0.11013835413201202, 0.09262137069937684, 0.13405061657390288, 0.2624679434924357, 0.23242902311105884, 0.16718725944238325, 0.11031571114736219, 0.1172099355608225, 0.16509596198316545, 0.10085378983809103, 0.1483232789342442, 0.18628137276297618, 0.09346841113461603, 0.14217937635558267, 0.15489298850297928, 0.1517478298516043, 0.1641476830287326, 0.11038051452487709, 0.08073312635984152, 0.07118386336632314, 0.10689518985248382, 0.0903685819057207, 0.20755538927210918, 0.14791535243632334, 0.17303289334860542, 0.15566483740845036, 0.11834316346193514, 0.1911820831798738, 0.1513928400292512, 0.14161481552066343, 0.18167120885224114, 0.1354512398041064, 0.09474566356549341, 0.13100207693153812, 0.22460634609864605, 0.14855759458676462, 0.12739655306382527, 0.16673368942593375, 0.1462341111994559, 0.09892315633835332, 0.12761116493493319, 0.07762733696689529, 0.17362871057083532, 0.10823150766232323, 0.13601785375466272, 0.13405567275420313, 0.13594317550380386, 0.22059950707179887, 0.10824623953310714, 0.14573296712290856, 0.10819502655536899, 0.11071776941178307, 0.11505561970895338, 0.22114526810905627, 0.14943822797748352, 0.10228446669756405, 0.12945948228720697, 0.1941627933974228, 0.13190291972169954, 0.11156175315620438, 0.1449364195427587, 0.09538819682934592, 0.16889528311308355, 0.16225463380256008, 0.1954673798454385, 0.1467066189093936, 0.11452443732489502, 0.1740639710858945, 0.09142365351679826, 0.14915966308645665, 0.140748584582921], [0.004310602464923455, 0.0544399967146737, 0.04762683206448152, 0.053010400039173906, 0.030577336550660195, 0.009952937703459494, 0.027568286825572292, 0.029968560951191093, 0.01206279747308262, 0.005486696815839218, 0.027922554610056743, 0.048877731070763646, 0.04359873409773554, 0.05416207533750323, 0.04851623716193342, 0.02485225807064243, 0.033833844166609554, 0.08451523349410103, 0.06076714369438349, 0.06515438368003215, 0.00673115685311777, 0.09902278607290599, 0.02048239104389664, 0.013530777068808677, 0.0394312770766837, 0.09252426139409504, 0.008215671499079515, 0.009409515149590951, 0.029576789332373492, 0.035135224536662145, 0.03795318320513733, 0.0534887032042588, 0.015655399352732687, 0.07620029136418335, 0.034179794151456125, 0.050526130118317185, 0.04254302280324121, 0.03181823619431065, 0.07005039797795397, 0.02178967029096619, 0.05165301864185641, 0.05098684773510022, 0.012055895020884853, 0.03206757674624603, 0.030118685456052906, 0.041763252548633084, 0.03176801913087407, 0.010183594328531576, 0.026509823360209985, 0.03226656616935807, 0.05005363389969834, 0.06053194321031052, 0.03756108025329248, 0.053920539306296464, 0.033095400525076736, 0.022725019596457, 0.023376577376057545, 0.03840686047389623, 0.008333728521040851, 0.031054626564465226, 0.024602423391995892, 0.03388518354885521, 0.11575541804514586, 0.04445551534093196, 0.05875653444579052, 0.03695850230513081, 0.015700682809936906, 0.05801292737164806, 0.027763943766213717, 0.020057032215258768, 0.0624944114937417, 0.022450265992853432, 0.020035585583818537, 0.022528031578047142, 0.014276149975616607, 0.058829799264429085, 0.02241945202131906, 0.04384316211085647, 0.03691431818409793, 0.0706731738342393, 0.05632108347790857, 0.04230479627186733, 0.03046291174306985, 0.041637311524321, 0.011414054108993902, 0.02371104944857859, 0.02429248337003012, 0.032403542690219424, 0.017224002682093172, 0.051799192048248746, 0.07284908570469388, 0.08195568777380452, 0.031110978076955488, 0.041033032860967426, 0.10378693365642142, 0.0518765362850841, 0.06127083501327903, 0.052413426024178346, 0.02068941289889476, 0.0026206127433632052, 0.02148350708246712, 0.058692539291035746, 0.015518108735822383, 0.0516806322810871, 0.01000258211617268, 0.034244390685231454, 0.027675713419974334, 0.06712105395572801, 0.08953045107304089, 0.04761380473932913, 0.05375422161793517, 0.0394431782525874, 0.013575298268528236, 0.0352591201062164, 0.02762554806747264, 0.030090828583906257, 0.021165030925805052, 0.050249105064018126, 0.052200005419792674, 0.028428433109976115, 0.04687163024960507, 0.031031603707120787, 0.08905081874540738, 0.04568749580592398, 0.01754979689365193, 0.06175927352160216, 0.02556220324139201, 0.06078664446249605, 0.09551420297113158, 0.003178344143839974, 0.01832560647369152, 0.026826608377779206, 0.030281643848866228, 0.06525507061592033, 0.0899525578584402, 0.010076178267838494, 0.018324660355105035, 0.025905552357735655, 0.04688075818722287, 0.0026164325367238734, 0.06001008028585104, 0.017951654059992685, 0.02961854686990621, 0.009660753684358732, 0.03382820958992647, 0.06708138592300877, 0.05121870807582333, 0.08951941940693126, 0.002973110864742569, 0.025976564877876834, 0.040609194716859254, 0.06615627346740616, 0.005827713673258381, 0.019693301329689644, 0.029510538048681714, 0.07047902417158888, 0.06989403943260832, 0.030120380425585375, 0.06325813603677577, 0.03233897679996106, 0.04704764661108775, 0.046409303848181045, 0.017426659751142708, 0.059616073605514346, 0.015921908892661093, 0.030720198541999828, 0.04781302973447789, 0.09078630666819312, 0.04279469034724659, 0.03164159164073006, 0.009217601506069545, 0.047957962078432885, 0.04890436794789088, 0.07783907600828717, 0.06080413041936775, 0.019373859902242982, 0.02327175739581787, 0.04048764337635329, 0.018401401297700022, 0.049327026316595655, 0.0440732910928707, 0.014125262255660229, 0.049328366970463146, 0.03379656249777444, 0.039643280418409456, 0.03234289150925414, 0.03272680881162805, 0.06639862538225229, 0.004950140324992038, 0.017160298640749628, 0.07289328131704562, 0.03537134815668387, 0.03629400913092879, 0.03247524468949245, 0.051591842690663, 0.0216184668768678, 0.03409914041478788, 0.03730809886849696, 0.06679611776264445, 0.03261529705336979, 0.047205885902287505, 0.07715433896068605, 0.10872458483302787, 0.0695705971109771, 0.02893594529239401, 0.08613432201767161, 0.05373682376117476, 0.08260561378612634, 0.023913970817962003, 0.0899013908459775, 0.019880267002830104, 0.035877950609691685, 0.03975063231923888, 0.029207862455457933, 0.025459622153111046, 0.018887937992751118, 0.03138312889683632, 0.03444611695745299, 0.07310057704847667, 0.03758819976581201, 0.05376393178237542, 0.07608816673558566, 0.04303038495803072, 0.016244496068646832, 0.021226656953653982, 0.04822903845999991, 0.0474875879233643, 0.022759497383489244, 0.09384869718022885, 0.04010558000675613, 0.009205735761732345, 0.033033435503321315, 0.023370297370298256, 0.004634458474033783, 0.04104606784699906, 0.02370414508116101, 0.09319864859383914, 0.026132576768436742, 0.06695210858578644, 0.04425422190838764, 0.04389528673322451, 0.04145477192416307, 0.026550403037559123, 0.14412156246121854, 0.040118097883438876, 0.04855069962720718, 0.04087870444862112, 0.030865833771625356, 0.058370112035904205, 0.04342746365094378, 0.01644691373522003, 0.06699493290075371, 0.05510681496572591, 0.04366742920190577, 0.04733279602782381, 0.04871131762141182, 0.031309864078197754, 0.023478183617454865, 0.027811500589333238, 0.029926975783441338, 0.01988869396999719, 0.020839805534530072, 0.06004885199569887, 0.029821265225989685, 0.01925323361290559, 0.03980654141595287, 0.058108527483719016, 0.08428256493061782, 0.008275875476219, 0.04610825044613692, 0.07272659590648067, 0.08044081785145306, 0.0661591462971222, 0.019781826619779872, 0.022169259196567922, 0.03401205153955567, 0.026556575791009014, 0.06689661317655156, 0.020619137738380703, 0.06351214014895021, 0.08146013613910445, 0.07840984981627235, 0.04808091152940066, 0.03871412684900626, 0.051097049483007966, 0.0392038025893271, 0.07834506942139519, 0.04961044820506246, 0.011306150624858997, 0.033039207975830764, 0.0393005020375694, 0.016545867397179528, 0.049099494372644735, 0.02960063381901672, 0.05212379499308525, 0.026656462165016322, 0.026072823825562676, 0.036273152387190255, 0.04854888782926625, 0.0404003783008985, 0.038857879417557875, 0.034188171322908134, 0.06625679952483024, 0.0031461476230047526, 0.022893309961223317, 0.06679087006036313, 0.00856007494392895, 0.04640675277539319, 0.031071290892038136, 0.06812860513286245, 0.05954775771486664, 0.03537308717627199, 0.08571642871585586, 0.05839009926984868, 0.030810600747504545, 0.023422594362449263, 0.038480010379346154, 0.039885574876661264, 0.0956943791900431, 0.022870434575804302, 0.08338303215080693, 0.005243292966512062, 0.062073564922977845, 0.05156145581314641, 0.030457667871228153, 0.08947755270186933, 0.03330867940319642, 0.0456582197558976, 0.01940862880268645, 0.04924127809523095, 0.04652762995852579, 0.03250635552009748, 0.053607278293178934, 0.0061654258188941794, 0.038964373299912106, 0.07789508469643132, 0.04620062915848629, 0.0301687071670688, 0.1093744418974365, 0.05885576964506219, 0.01978965412314621, 0.026867498320737676, 0.049837976318573764, 0.11359783865871931, 0.016689344174078396, 0.01034482806590536, 0.055467692173777096, 0.02930449487100686, 0.06394177374820556, 0.030380572612968185, 0.013980180524559993, 0.03765847684154588, 0.14182590338731968, 0.09949298785819162, 0.07125142466036544, 0.13026689299412314, 0.09455723657963738, 0.14499421321576642, 0.10366554702481917, 0.17645048818761305, 0.09284171290815839, 0.12078811775051779, 0.1281186445586143, 0.14914048024483267, 0.08730353306858771, 0.08772295854625203, 0.17536981391810602, 0.11631492269976486, 0.2593606602280371, 0.14376196078956127, 0.1607281576481558, 0.164338898574633, 0.13276939580757774, 0.21456017549480164, 0.17342459410429004, 0.1436994326931815, 0.15056558764509617, 0.1941750201606943, 0.1588439950419049, 0.1747643439880302, 0.0753597013892666, 0.2078809459964114, 0.17901070806528294, 0.15659701319471483, 0.15120741610805835, 0.13023646398177072, 0.2158201909473827, 0.07181243850819527, 0.11711795904463339, 0.11537619686174778, 0.2860314903720733, 0.10229351419594981, 0.11534056611238949, 0.0796033381935089, 0.084071553672754, 0.08026669372714336, 0.07379315117554319, 0.15944618611566483, 0.05472092115650735, 0.07923814408000439, 0.23118727119459262, 0.20914842314537496, 0.16192133959022262, 0.11920685864864819, 0.2366609847353351, 0.08212110147841516, 0.1507638971651754, 0.10545707427926602, 0.17133796978141033, 0.08383547601800773, 0.084825100737714, 0.1185451808475679, 0.22963597379144163, 0.1363532776914297, 0.18251793519143136, 0.15961659471354178, 0.15989693692855297, 0.16435961359210555, 0.10006498740685564, 0.20461967905923245, 0.10184768932841479, 0.0946158193232071, 0.1698857122251103, 0.11879707055707132, 0.17489220406259262, 0.15328743675303075, 0.1483018897593983, 0.19614141464473742, 0.17347373098375338, 0.17138007397372879, 0.1477402553803498, 0.20348139497781956, 0.1902559288446942, 0.1853939824767651, 0.19388389142770923, 0.0944959955109704, 0.11271880639176216, 0.09690620005130769, 0.12437418298495394, 0.13021058553168852, 0.0782750566459952, 0.17580076901903077, 0.21994790332692288, 0.2512809760387867, 0.1551368036457608, 0.12224321749301688, 0.16980924132850864, 0.16276000668444943, 0.17112338855381937, 0.12482278875165409, 0.09771140442500192, 0.07948122377837859, 0.06951583714614953, 0.15673444936833075, 0.13511823670518014, 0.13942070906200718, 0.15617407137347808, 0.13617286398526163, 0.18718298164106187, 0.12462916768967144, 0.20689420942817965, 0.14642846770584583, 0.2808685787022114, 0.15709751375740574, 0.08685522607617802, 0.07884563127112004, 0.19770287037376436, 0.1815439003609842, 0.11740640646988347, 0.18290338466965383, 0.10971612477254485, 0.13291637743673018, 0.12398543932865705, 0.15420475043356419, 0.14638489262471277, 0.16406531325511395, 0.1210558808018123, 0.15650264648420198, 0.08775999889739099, 0.12419651953443406, 0.13166589211792717, 0.15341422430449916, 0.18961316575446438, 0.17234254087651932, 0.22749558541803594, 0.1839810252309807, 0.12931072333407018, 0.11532866110604618, 0.2693879237819103, 0.12038531638081036, 0.08494383670509824, 0.14938760488744707, 0.11512935567166536, 0.13284381358854233, 0.23126185751490055, 0.14531289047050863, 0.11555050484715931, 0.12820148164586675, 0.233553211174665, 0.1457403828540156, 0.09626868466335921, 0.17369286277361456, 0.1288050746605281, 0.1905270933263725, 0.15575768726487316, 0.10712601214406953, 0.1041561880359246, 0.14100047429242443, 0.20687836672990553, 0.1209284880408837, 0.1345714337883457, 0.1400812147485633, 0.13477381889618215, 0.10679620363178755, 0.19993912699001454, 0.13822487645572232, 0.10870971506641758, 0.08403794539551582, 0.1427324765151547, 0.24569820222114366, 0.09589544662664976, 0.1381192788962395, 0.09226563011085795, 0.18891786435438743, 0.14961933116278342, 0.12194759948479554, 0.1656321009560939, 0.07966523043691151], [0.08976009358922321, 0.013926608953624965, 0.019829285766689048, 0.027218837734131564, 0.009363734692845856, 0.007275327779127346, 0.0848920721440546, 0.10076452527315387, 0.012109487659237798, 0.02663875595786639, 0.04249207795627656, 0.0033397344504332836, 0.043521918461567936, 0.05305549580483668, 0.07068923869801146, 0.04105801498817821, 0.045954155690607526, 0.03776096408405612, 0.02942448722258691, 0.09043264983882827, 0.012152034267332527, 0.02656956098132557, 0.0450124689227631, 0.03361172080340405, 0.020461605163291097, 0.022553938756426497, 0.04661029467599527, 0.05132876809746508, 0.0574991581661086, 0.0248826775068958, 0.05371248514782037, 0.04469689815455387, 0.05769271028017806, 0.06298938473205894, 0.0484664797512514, 0.03083656729769803, 0.0333866365103712, 0.027828888869994593, 0.004603547305094018, 0.033090666101704684, 0.001122377702080074, 0.0468174793246773, 0.01601401851662705, 0.010180717668375902, 0.035742743751935424, 0.00782730514108534, 0.013142603190405475, 0.030729866571604248, 0.11396116351768856, 0.02065160071417209, 0.04143481533373556, 0.04265145871848349, 0.065883346983502, 0.02855699607020905, 0.011366239688809843, 0.05535289006788404, 0.039176912903184855, 0.06751880680601444, 0.08033503643086842, 0.03869223588656995, 0.04977059505519368, 0.009973736032993804, 0.02275289753602157, 0.0232175700817137, 0.05276801748081081, 0.01758205877136319, 0.037841797851386576, 0.016495926125395684, 0.027832014508725657, 0.02818858247220276, 0.056072568385711605, 0.05523985762509608, 0.011788854965068882, 0.08954054045100367, 0.011189120160716196, 0.015975297560104202, 0.03689807328966357, 0.027932657394558195, 0.06177186034619809, 0.02501599595791871, 0.040499720752479575, 0.07282593452762212, 0.07737219904459293, 0.03148894479137755, 0.04329281603737224, 0.024461777309977242, 0.08526635206034107, 0.02648309263731203, 0.10996634441037333, 0.03258977100373276, 0.02499147156824268, 0.00641018181340769, 0.026534290293291695, 0.04296605272458927, 0.03190068257672172, 0.023417869515176264, 0.05850893099822345, 0.03114276306493388, 0.05401048568948623, 0.03681152067597836, 0.09117262948664928, 0.018589062195631768, 0.06658127606515923, 0.06034262756246233, 0.03930251684881026, 0.02294306545668552, 0.012845674214223701, 0.030380781371927554, 0.0430646367491253, 0.04096865083181089, 0.03468614379544893, 0.02794131035766294, 0.017244168031480045, 0.06461584685190071, 0.021570279946430557, 0.045116044010125825, 0.0507568643097916, 0.04179968002943262, 0.04984351896470593, 0.030881758824351336, 0.08530712325967128, 0.025625958993670442, 0.03466064072844963, 0.11044392362236978, 0.0658018428892378, 0.02557899397347243, 0.03102325526396594, 0.01638146492862894, 0.020886554134889476, 0.06047634820964548, 0.03875237378862597, 0.035613171470862244, 0.03984673038846062, 0.035991247352813525, 0.018842968631595857, 0.04972544566337621, 0.01038706536600066, 0.028773638074316328, 0.017351349477746317, 0.04531002513343289, 0.027498477063472235, 0.026124145970830036, 0.022679502482435877, 0.025820579800394275, 0.05853294785464964, 0.08607536389101898, 0.01707216597072059, 0.031226237920383294, 0.07112790830433369, 0.03314286350242553, 0.03293087165201864, 0.057818996044056076, 0.09078390881299012, 0.02030242166872467, 0.009015394513675523, 0.037219864691817955, 0.05377815420468969, 0.05415289760417035, 0.07757661428542868, 0.025182334713697917, 0.010272956569679081, 0.05565061481789716, 0.008676976130734529, 0.07518591434364358, 0.020662421706102548, 0.060191658445663994, 0.008057623729860831, 0.017593048302636995, 0.01707900713588442, 0.04861422363788851, 0.07619802374392748, 0.053969170567729784, 0.06423454190934859, 0.030347282262218576, 0.019078691970677148, 0.07308225988620713, 0.028512291009387666, 0.018641472185751604, 0.01236837366670971, 0.07147047984143419, 0.04904426709418336, 0.06783640387678339, 0.07048783418271812, 0.042861493214243845, 0.04280884382164767, 0.039682569237606186, 0.0365670696802197, 0.012026652487205162, 0.0337582197971642, 0.013466444835367223, 0.08579469225820034, 0.07580614678802029, 0.035069042200883555, 0.06019934613798415, 0.09108800741453325, 0.027244844503941077, 0.020440646912902594, 0.031250358198679266, 0.030485802450247353, 0.02820193346950316, 0.03221569027030661, 0.05189681463243981, 0.03933081230629356, 0.028729088146299608, 0.043986439704895026, 0.013333795753668153, 0.06599472850681314, 0.0195356902305878, 0.02969723367582887, 0.03954328296165313, 0.07074857986862622, 0.05300000422604142, 0.03775948170392263, 0.034494958893065496, 0.03848227799960202, 0.030541692394763235, 0.05425690170077067, 0.07500708643947879, 0.0388270826830018, 0.024094277271820654, 0.08873109195020892, 0.04559164671527763, 0.017883460743412856, 0.06689249162351893, 0.043154617606271664, 0.047157515110748435, 0.08458690101941747, 0.05013470898472494, 0.060485801734631105, 0.002066504699365807, 0.045307677073944966, 0.020764776798445853, 0.05824546570018415, 0.012292978166031742, 0.06148967185928937, 0.04468940198421479, 0.05728001871536817, 0.04390368688731425, 0.06488269825856532, 0.003763416504126884, 0.00998566210675504, 0.027354264842166055, 0.010779807043652381, 0.058864334508055643, 0.03635022849325211, 0.04865966414311721, 0.0699103954097917, 0.04268180346116424, 0.00435022261714743, 0.08535145676784939, 0.09167861523887805, 0.010840607611762901, 0.05220674699352634, 0.04083412579230724, 0.07816528390732505, 0.05562528412068083, 0.027042066776043466, 0.02978721836341485, 0.03462582203229109, 0.023773315159844297, 0.08329726860768373, 0.010767369606201688, 0.08500433466847866, 0.020390602219248974, 0.04561071464371297, 0.04748269262152815, 0.053889711928223415, 0.04775226364032396, 0.026756086153909567, 0.035401210263972326, 0.060233984803480495, 0.061161422335933295, 0.11461106654737266, 0.03393843815091156, 0.029809044208377603, 0.019885620042201013, 0.03166647417651069, 0.035056409411012165, 0.06532258594468718, 0.03381788655514679, 0.05341723486180267, 0.07068995115978104, 0.021291065795887864, 0.03761845640838146, 0.05328151472513715, 0.05961439204252055, 0.10601883123238241, 0.03117957167447575, 0.023064725964720693, 0.10588920149471491, 0.020008341582011313, 0.0960799589032127, 0.10809893614702648, 0.031510751484142195, 0.052116107300765095, 0.08987341331498278, 0.024584694202208233, 0.028805514992845636, 0.06201366450817836, 0.06420683633956699, 0.03709344486255319, 0.049903124435654575, 0.03436667747014473, 0.034854870830332084, 0.02029177496179698, 0.027311001941862128, 0.023404275284959905, 0.033027777944000504, 0.023581385236954498, 0.029588847556301666, 0.03869223205613033, 0.05107697031851258, 0.08520789955171847, 0.007830822442267692, 0.02931065996357751, 0.08002225039226395, 0.0366714644816614, 0.05580993429307015, 0.02779425211971806, 0.01866612297993514, 0.008082199830471749, 0.1091107774165369, 0.06004293779692343, 0.06463008842641307, 0.0792980827992001, 0.09081871984826942, 0.028185202109236872, 0.011519614321690415, 0.04933112871743018, 0.034676900944642486, 0.01977412169048142, 0.028947750707307172, 0.05372231405588889, 0.10890815482144395, 0.02239415579805932, 0.01873902199158986, 0.01713266584932083, 0.05022559382562196, 0.06510320900669021, 0.11800613840140643, 0.008184990635321987, 0.045577895437036796, 0.07199791605554282, 0.0015038782364553624, 0.013329724953960509, 0.022323018788630446, 0.16725032380031002, 0.015508893655703194, 0.029993476045708505, 0.03253340608470383, 0.02264883598282693, 0.04622674126538538, 0.1625987451763884, 0.09868122577186554, 0.06513486375972148, 0.1600781320444038, 0.1545104195153521, 0.14198071443505828, 0.2638108036931484, 0.19267924881029516, 0.11165854070455798, 0.1019820994547298, 0.14172012196673503, 0.09375543363632695, 0.13483182707380864, 0.08820073694110879, 0.17716927784344844, 0.12873621867789378, 0.25390380062162876, 0.19906987766585044, 0.1527241476240658, 0.12721064650724012, 0.07088924127240336, 0.12874656086487155, 0.11400296893571654, 0.12503373872248397, 0.17077440486079262, 0.12914063649312144, 0.15298239586334075, 0.1610639646288849, 0.17195768894687777, 0.10254451524346106, 0.13959940673122484, 0.10430165281098697, 0.1251483224933186, 0.1383185996523788, 0.1758372654477435, 0.15876219217335025, 0.14921483673876332, 0.14626340640168037, 0.14449864625930786, 0.13231401782362692, 0.11741160820688933, 0.1528899596943971, 0.08610564734666579, 0.07627600383373999, 0.18291688313887966, 0.09406730803030153, 0.1473904596341233, 0.11819006845114693, 0.16022466934256016, 0.15478627245512702, 0.15739683963118062, 0.15635093043167747, 0.1754538537633996, 0.09864685906758232, 0.17631216335200495, 0.18352230710368003, 0.15724958221037544, 0.12165925931185485, 0.2799407849388738, 0.12280443818458628, 0.09301668739006405, 0.18303421716536247, 0.20014036296596452, 0.21689904192762993, 0.11481581120601586, 0.09089936592405842, 0.1465467976466302, 0.17979262336607904, 0.0825250673017675, 0.11017748590318427, 0.2609419576343029, 0.17863796032484502, 0.16459434293210506, 0.25587492952904395, 0.14296879931803674, 0.11226587222828982, 0.117000985079475, 0.30630729431586884, 0.17774764358276324, 0.13957873767902776, 0.1807184253008135, 0.13626438084869616, 0.34797478587396685, 0.16155173281027427, 0.18236301689138337, 0.08400769258338599, 0.21449116629458245, 0.09489342660432863, 0.12348830955283296, 0.14605956572678783, 0.15715567515261714, 0.11997763503102526, 0.1766011930040775, 0.12495920602833072, 0.13358239895634114, 0.19903030156368212, 0.22157675947152802, 0.12852519975915072, 0.17422370041810697, 0.2266951614329892, 0.18511275159976176, 0.14416214979944691, 0.22025645289930607, 0.15767600207078844, 0.2205614784672376, 0.13261289936640572, 0.09772800555032107, 0.10547975048182473, 0.17477844000583695, 0.17608679560644014, 0.15362549603225725, 0.13163624451525752, 0.13932739955282983, 0.17908495730690419, 0.13838353326484082, 0.1562725289935066, 0.316139726388839, 0.15623879048132128, 0.13649845135308084, 0.20350644605294352, 0.10858680391984601, 0.18575556065526702, 0.19244358484302798, 0.20711410730596513, 0.15204160924880736, 0.23543469247318086, 0.10096468872600987, 0.1793768061625381, 0.05824784823362866, 0.17786798067390922, 0.10369117266588634, 0.1948200049059045, 0.1543852254267662, 0.11695424605521465, 0.23055535590937062, 0.19587576599611392, 0.11432518551666891, 0.1336455705665773, 0.12978989600894913, 0.15883713089410337, 0.16041597681901149, 0.14654601623694744, 0.1360599119817057, 0.09717946361389854, 0.14519498953896184, 0.1596496897118707, 0.13678538192424083, 0.1755448956523211, 0.15789724826332063, 0.14072957028064037, 0.09770758164625976, 0.11537140881222104, 0.1302585426357485, 0.15975482761859894, 0.170553618321015, 0.13957529028336849, 0.12364775543251347, 0.21038075218037253, 0.20787973557749104, 0.11515951655324429, 0.11169289208708272, 0.22216986474250594, 0.1274087645053383, 0.25683655373511777, 0.06523042556739624, 0.18167404337756096, 0.16992919537569248, 0.11810203728776787, 0.10466915284914356, 0.10579805235348402, 0.2146855228009724, 0.19830187452175926, 0.15053471430174767, 0.1404436509455404, 0.11272305051886267, 0.13614739922265853], [0.004063352375411459, 0.02468468782852494, 0.028869523554139083, 0.03682215014592775, 0.05992851873499252, 0.06915672577076382, 0.011967266308924845, 0.020740426693772598, 0.04650837433854899, 0.07140379188762558, 0.025733333877137592, 0.03700407687574625, 0.0912923843509728, 0.01584015007416207, 0.031119527618190458, 0.04013724625110626, 0.04336438397125852, 0.044364278099589774, 0.022703120973141446, 0.023379779623581037, 0.049021223169421, 0.0431192588181265, 0.03820287807273769, 0.026886556673073964, 0.03312471104905971, 0.06668284400216033, 0.060126996794415105, 0.03150463235684701, 0.025167284916425427, 0.014284512782920034, 0.001990330063328598, 0.049189628447375955, 0.0031290040116742136, 0.049403037560442765, 0.021659262974055547, 0.019284206547684247, 0.025067425355495467, 0.028297112233215765, 0.0439616835736219, 0.012125431864161887, 0.07211226233912092, 0.05334270982852867, 0.035744245284267014, 0.046702033704927856, 0.07191569949950903, 0.015639097001704, 0.03482068032627145, 0.04331335102418258, 0.04644332198245872, 0.014877381524251354, 0.02276603785914279, 0.010845362144942966, 0.05214202022480388, 0.048157409239079685, 0.03830456092292744, 0.04089445521634433, 0.0519779050392249, 0.0356091724918975, 0.027689974146684813, 0.03354942253340156, 0.02921443740506807, 0.03094936991410871, 0.057418443142406406, 0.02904897198952254, 0.08439960018281015, 0.040477086684756705, 0.03866996954105074, 0.022826987814398545, 0.07939827943881674, 0.06557813755446865, 0.007107722105443358, 0.04911257915439145, 0.03360754945465634, 0.0366412729565655, 0.043764385289602706, 0.02384944897775929, 0.017160936408946594, 0.03034029170990952, 0.040547095629717075, 0.04539354786937756, 0.04692392724175607, 0.026895336040686217, 0.031505570814554254, 0.023233334255975582, 0.050336105839139035, 0.06062921722449603, 0.02347803997596906, 0.04298158515725405, 0.027625057771201098, 0.03066962333245864, 0.06482462113302562, 0.01947543550012333, 0.07011602873042708, 0.04880944199319329, 0.04664378420960519, 0.08185062647586869, 0.055155932692991155, 0.02907656456133531, 0.04282526874674424, 0.056148273194389, 0.07631501303084436, 0.022113622061067054, 0.051021616635543686, 0.07961740356779869, 0.07343614654194924, 0.05694538767960283, 0.004410104358553766, 0.019556550804765958, 0.012859682131919169, 0.07275885586897213, 0.03986585960392991, 0.130741361889147, 0.005669458102690237, 0.06330913834033475, 0.08084888990607955, 0.055541665623745615, 0.0462975277895889, 0.05010757415044693, 0.007926041425596322, 0.03343086276623992, 0.07060100069089283, 0.014226568765157174, 0.07869344790496173, 0.08977402106768663, 0.034425754340425614, 0.02971804828473157, 0.0632070264809074, 0.05166113917385379, 0.01212974589678549, 0.04289071946855515, 0.031865197384069045, 0.03580801827352374, 0.01999861226537295, 0.06262317938249438, 0.025493736048379255, 0.01637327736393819, 0.06554141129937864, 0.03398824918774828, 0.07098123311035096, 0.06303812707624128, 0.05222309147939087, 0.01360823909166239, 0.0754521758626065, 0.04454574517665371, 0.05100266362029699, 0.06095778467434068, 0.028788800869557648, 0.06805646263303296, 0.04002005012044984, 0.028198555021757082, 0.10060153240638395, 0.029315467165302367, 0.026929028587596073, 0.03259359378247492, 0.01949987562012769, 0.023533627315754854, 0.06964195054024458, 0.07302400656044483, 0.01693129963842371, 0.08449032797568268, 0.061135842660141576, 0.034960613946520516, 0.05159517900357324, 0.05948728273412394, 0.029796172016029878, 0.03704721528676249, 0.058075007306592125, 0.045710781048382484, 0.04033583156283825, 0.05351024942712919, 0.061087391429370454, 0.05433811468162364, 0.0419066297341018, 0.025702142607300513, 0.08079802932878656, 0.04644632887756152, 0.022512114186200406, 0.03798297253407298, 0.07072954258370785, 0.024148330520538074, 0.0152596574832475, 0.035893682225216786, 0.03756011115206826, 0.025254270369787852, 0.06443002456498724, 0.016081805806607008, 0.04909917261571654, 0.013445467432780613, 0.02464239977510466, 0.026579474159065756, 0.017229062692833044, 0.04660675151934547, 0.03285550775246755, 0.0595982046046805, 0.05122318202930112, 0.020709327354486433, 0.0419839280056617, 0.001488684318892117, 0.03448373187453516, 0.10475203590167147, 0.031172648154860063, 0.038656601306772044, 0.0778169590499132, 0.022754196055053223, 0.02349089493133849, 0.04835775655303751, 0.03131980215379548, 0.04187941063015212, 0.025642519899373575, 0.015386956398405377, 0.06614810697013332, 0.04041940026405839, 0.006761553785538362, 0.052432639509319305, 0.03111879408900296, 0.04803020416969254, 0.08793077521747159, 0.0169298842909836, 0.0670035896942981, 0.0425901448714637, 0.01989411021162185, 0.02174307490819164, 0.0214154765595712, 0.05481619568121049, 0.07353068179180546, 0.04006080599802156, 0.00841732978099777, 0.04906313967019801, 0.07216077102648635, 0.010288757133117367, 0.05920380338906281, 0.050993999165873376, 0.06133153215951978, 0.03771037929841588, 0.033801109229605046, 0.12361685144564799, 0.032995119615788424, 0.06705717754460151, 0.05405227578575573, 0.04714795050301379, 0.034379892486838565, 0.03427260953392233, 0.040429305780919335, 0.027662515640258793, 0.065508293318412, 0.029744503215976784, 0.02552128073969676, 0.034714680570628376, 0.039990004152059555, 0.0717695988714695, 0.053002834920921636, 0.047691263889353123, 0.0656340389903034, 0.012508061181213106, 0.030178955508275863, 0.016995208608287, 0.06574425605996963, 0.08182899981376626, 0.0651024888840414, 0.022589743790787556, 0.03736996812926185, 0.039839540653291254, 0.03561007264520853, 0.03642795960448923, 0.010038573884465283, 0.08067157119512558, 0.06918422066636624, 0.04643799767138497, 0.06590011664816449, 0.026998595116780173, 0.032474846323771824, 0.05163556332850168, 0.07282697640719914, 0.03995752968494931, 0.0266956533080027, 0.06574909007477184, 0.06337236740716523, 0.03365329639505475, 0.05813905608750159, 0.0499798902761071, 0.03557290205912244, 0.05353397517014415, 0.049448566165782755, 0.025562825687830488, 0.029189489751813874, 0.048406100531499234, 0.041209294370585875, 0.06383325739373123, 0.039427458128381165, 0.03254657130568259, 0.013272471372939408, 0.03519441248969205, 0.0892493580918639, 0.016527502354414716, 0.025137053171713507, 0.02367100411755664, 0.04522050775948071, 0.053950420565783024, 0.046589656267315156, 0.0678478951956476, 0.006805810684924044, 0.06418849236422008, 0.043314021351116325, 0.03163164590425309, 0.04693014404526161, 0.0440768534017186, 0.026681545798877077, 0.034611974993059715, 0.06411270711631065, 0.02456595569158033, 0.025167516658022523, 0.02481234680500723, 0.015581349293971735, 0.02254930775492422, 0.06855108730134464, 0.030780506898618998, 0.020102371213837497, 0.03574268246490148, 0.02703921118330571, 0.043879382747916446, 0.021097188094450582, 0.016659564421241804, 0.045234312663876244, 0.02429819838594525, 0.037370695912789915, 0.048813245619737336, 0.030255118054488016, 0.062208760289415244, 0.04636848668357538, 0.05014280653408459, 0.041431620747091315, 0.052249755169595444, 0.0069971842364588335, 0.02203382825809381, 0.030552894515436024, 0.05935326331265031, 0.04052475267540544, 0.01249892175227644, 0.019417770146842928, 0.0030509262456513584, 0.031658786484190536, 0.04241402125767162, 0.01588415033409312, 0.024334284957618486, 0.01679235618681677, 0.09204676645177026, 0.024096989223072608, 0.045678141872368516, 0.016758880059745525, 0.04613917741564013, 0.021222024036931898, 0.06661376585402796, 0.06066674021102729, 0.11044499614546377, 0.13630752692059164, 0.07935087391806227, 0.10060370809608891, 0.2032806339763826, 0.15559530726844267, 0.1389713831726582, 0.2003828144722408, 0.14041009629445692, 0.13845192959472058, 0.10548731176963738, 0.22180585040440484, 0.1599342913757409, 0.11015267997619607, 0.18073229149224299, 0.1434770220470044, 0.09705543397895752, 0.1482479878130459, 0.11105810397214468, 0.12051496910111559, 0.13642481498179898, 0.1918836511791714, 0.1326141863941185, 0.1428702497674573, 0.14795086827249299, 0.17090523735650126, 0.10236761021998622, 0.08253605300260168, 0.15913861713582472, 0.13769912563504713, 0.12171256370962628, 0.13182284821185375, 0.12323927735128712, 0.15573242168513038, 0.11970061763760545, 0.09379078859403249, 0.1775808355981304, 0.09617465503153302, 0.13691964649385022, 0.20008995438054686, 0.14830906034236954, 0.15429061356811755, 0.14933590927431661, 0.09379353118880142, 0.0854376339984517, 0.127051085714371, 0.12027298490847312, 0.2165188631343265, 0.0987329596893922, 0.09036452930060127, 0.07308663424825476, 0.24064127115472672, 0.08202840483957723, 0.12510108551190746, 0.11531743025707623, 0.24462606217111313, 0.09697633540077556, 0.16150552238668167, 0.22472675979858447, 0.12726602700328635, 0.1214696831941124, 0.1582136119325315, 0.11737452955135416, 0.17153223435724937, 0.15572748807889802, 0.22181911904725338, 0.12712515875576966, 0.19229929984336902, 0.11105865555545015, 0.13065333838664717, 0.09818543664990895, 0.19638273234088577, 0.1633206145056794, 0.13736883448737283, 0.09765273741176052, 0.1563377996846553, 0.09508290313064091, 0.09935230347177676, 0.14813540353169366, 0.255232886561463, 0.1803070054419579, 0.17443219890757916, 0.11084270303047473, 0.1946836412553826, 0.13919855888572433, 0.1682999408653667, 0.14551156771279153, 0.063760697375983, 0.25409664027392864, 0.15526441857218742, 0.09395502252323974, 0.2519135808031405, 0.18709610727044845, 0.20241441836039867, 0.198197839781642, 0.11561771374075644, 0.1402599737048149, 0.1305903966027883, 0.13960745065442978, 0.1281784913472591, 0.11851302047650661, 0.14142215972946537, 0.1898582526032002, 0.2114541179710819, 0.21821006351420957, 0.13217952342764025, 0.16138415873771714, 0.1714296705059467, 0.18097722512339393, 0.1953509957679818, 0.3208090629308455, 0.10865034325228584, 0.1731668668048036, 0.16035700337060038, 0.19605236458441905, 0.18054204121712716, 0.1716382609259698, 0.06158722549556725, 0.10979086431043764, 0.2005507103017261, 0.1397812147174151, 0.13724581608849187, 0.15478242669374714, 0.08413561394498234, 0.12313040093548837, 0.24824509216893106, 0.13644070364534855, 0.2804056164478102, 0.060585328047314, 0.15113759485463943, 0.21833731071843257, 0.1433262406217475, 0.160583121882331, 0.11318201379429911, 0.08587748338017734, 0.12415833005140867, 0.08774990951942821, 0.2469816599642077, 0.10680683693217655, 0.12649667554444846, 0.22865352731558586, 0.1521595408238711, 0.13772679673087213, 0.11864753785513102, 0.08810502191584918, 0.2103963190869939, 0.0805756263434887, 0.11865000465824721, 0.10550189808371568, 0.11262296879243468, 0.14118062752869823, 0.15884191128275088, 0.12193593962658798, 0.13243090751911366, 0.15549168621580448, 0.11436644701227067, 0.21303751445826025, 0.14393079124631422, 0.18302369111728284, 0.13372412522233304, 0.06421907842459698, 0.18510084659341844, 0.1564666250300023, 0.1347230732320778, 0.14725605716868756, 0.15181043455677648, 0.11366333151536603, 0.09926048783405174, 0.18430045325188868, 0.2439264860004187, 0.19257925901441805, 0.14426869730795586, 0.13016224538366641, 0.17130027825553573, 0.1231506486393271], [0.015040731579515965, 0.014685807832246347, 0.016079601388604894, 0.03950112514317997, 0.03580792634297283, 0.07049390925995766, 0.03156415355812398, 0.01096610813551853, 0.02675953929522826, 0.012072588076754924, 0.028531935418986028, 0.03657754210214462, 0.05420067850800772, 0.0401985332850487, 0.04813763650975401, 0.039858091472377705, 0.06816479512640546, 0.08648335933685304, 0.07231895286109179, 0.03912475763729984, 0.02662526706473962, 0.04787874475662266, 0.04684769383241092, 0.022092951093650153, 0.02349450703590147, 0.03659821881522094, 0.026521730281773116, 0.008703592898053749, 0.07873047293434221, 0.020819550169812098, 0.10365724263171996, 0.03618083879231446, 0.04839075195993628, 0.012622554936716634, 0.0939290981078821, 0.07692903250215516, 0.04416085877305558, 0.028952598128648057, 0.01210412217093812, 0.03197429979580545, 0.02048034558913881, 0.011437189006697268, 0.023968296027892542, 0.021769960763894265, 0.023059646801782713, 0.027013959010101618, 0.1380961890062017, 0.019416174768740614, 0.07343948668529911, 0.04682254699629642, 0.05875885569220109, 0.007787546135425087, 0.07078428722677693, 0.014938640787506537, 0.05523072585703866, 0.04318880044945306, 0.048201375025054144, 0.030779269666621284, 0.011454500678566196, 0.03693137130129241, 0.04007095666301828, 0.017740167827615817, 0.05295796898163615, 0.02572543168019864, 0.010524714129015563, 0.010731500411976971, 0.04089197692190928, 0.0503863726982907, 0.05121228825901786, 0.07579025812447071, 0.057981310923013, 0.05650109115747675, 0.035013022021420544, 0.03682481613190424, 0.048990759683111985, 0.03596091793189126, 0.016577100801852443, 0.057635200059702324, 0.021107574331484014, 0.05278543832020895, 0.04877952242931051, 0.07158580671755538, 0.03308224679541684, 0.05687674620158731, 0.03287944033922207, 0.032012177098001686, 0.005868131514533513, 0.05349850529924997, 0.030848566149812073, 0.06656137310088643, 0.06087794299087217, 0.013032151506312433, 0.06241843472385119, 0.10493281733004317, 0.054354271475946715, 0.05554094167065717, 0.05447419104917396, 0.010395977841389757, 0.07965999039550943, 0.05774718296203402, 0.07119895529843147, 0.013732677626032985, 0.03515507004434063, 0.024580819712531184, 0.03985070255434802, 0.053178180955470576, 0.04029417170151588, 0.06169615553752069, 0.08461752155375096, 0.026651965228900797, 0.030639634820662683, 0.039113323775029955, 0.005417724962406342, 0.029348376387309645, 0.0101130299698261, 0.07253334256670169, 0.08380405875223298, 0.026995404360575542, 0.03583867711225345, 0.03297003023626824, 0.012679275129020456, 0.0554964013187395, 0.05994713850199215, 0.010061425329636662, 0.054226445875340895, 0.04312256831795939, 0.04694165451632393, 0.03629523104116802, 0.04908737869212224, 0.004318784762759723, 0.01315538249459238, 0.019978328172357816, 0.05096150554656502, 0.03994727176764319, 0.04090876956920951, 0.048265833663003105, 0.06324618889559662, 0.007309352137869405, 0.04945547627885977, 0.03047574946146098, 0.09177406213336414, 0.0305651136178283, 0.042775185748694405, 0.03661819455784656, 0.017660984979762186, 0.1002396401318331, 0.050540007801065524, 0.02087467977206313, 0.039573206355975526, 0.04420426531484531, 0.03415377014466832, 0.0339204925412853, 0.03892234571638607, 0.06609493280730902, 0.019159380181301987, 0.054971320824998046, 0.06818630687531925, 0.05466484735088964, 0.05213403758863288, 0.049382985209024725, 0.02336757201250763, 0.0501723392235656, 0.048448170249861096, 0.07044903949023255, 0.004445429151547292, 0.03284796178641339, 0.0345608577763121, 0.020434535446486646, 0.042492196699904825, 0.030301355291157964, 0.045269116038276304, 0.03954878730338909, 0.06100953391362583, 0.023033107600865826, 0.04318370213431697, 0.0612819432881811, 0.03550676568861931, 0.014818281671332737, 0.051006731547174916, 0.02384562428379732, 0.008972880464317578, 0.05035523888504794, 0.01715634562706034, 0.017426270961521134, 0.06117284470688432, 0.013357719721933527, 0.03343212681131498, 0.1353912704413937, 0.026274511793387995, 0.036877044176142064, 0.07169439968082213, 0.01688958998138626, 0.0076626675793029855, 0.057622318291255546, 0.096732045283481, 0.010728501177753412, 0.04307679839492325, 0.02565403037043589, 0.04452149466341061, 0.044878817223493135, 0.02134229984104393, 0.026119470919272112, 0.04779329913998804, 0.01907848512693759, 0.06314686942665328, 0.041338242290000764, 0.048445182506956404, 0.07196089868704159, 0.024040059314199516, 0.03365325042977929, 0.029905490847604892, 0.015586312586111168, 0.027285987255914558, 0.050416928115150625, 0.0488835035432731, 0.04556152413809492, 0.0472732863178657, 0.02106961659005573, 0.024834193717387897, 0.04092554689475125, 0.047358191842513706, 0.025349855160100326, 0.06345106761962657, 0.059172891741318095, 0.04779274372624294, 0.03805498096851572, 0.009790831583461935, 0.10919854044914247, 0.05142123107948611, 0.07909487031640546, 0.04639860926075809, 0.02896809417213644, 0.07007732596849242, 0.06387753727575464, 0.003130759310630721, 0.020158056229833635, 0.009940454300733344, 0.015511772231078677, 0.08523344092311398, 0.015525672896464747, 0.0471536080623346, 0.02317705552183813, 0.033421677372027794, 0.0270843280163864, 0.040630315760931665, 0.03847412299364805, 0.02244192712579764, 0.07733829965394351, 0.040691985838836243, 0.0651525833734101, 0.048288701387542876, 0.05998455040577439, 0.031893368352264646, 0.02103902861445902, 0.018245368339722196, 0.03477302199650196, 0.032442996218319864, 0.039874918593634526, 0.030908299940488035, 0.019321783160370205, 0.0722916265048327, 0.026384891656738137, 0.033992006849016876, 0.0408734567463398, 0.05016712599524087, 0.027747030460065412, 0.014579563886077415, 0.010703682801836442, 0.047013390989553545, 0.06856837024491641, 0.03207835368812084, 0.09192495847180968, 0.06913618695351385, 0.02784332771214747, 0.08339577219298772, 0.05530114848947814, 0.0422815608251239, 0.05942031132778334, 0.04044511017479724, 0.07787162708418985, 0.04463489099796261, 0.027814616651965246, 0.032352210968853004, 0.058028643665414666, 0.01990366907369706, 0.0488844879662558, 0.003434798061554771, 0.005628824320381448, 0.05710340480530455, 0.04257667704575485, 0.018945047932286418, 0.030023654164265723, 0.037478174218126846, 0.027270860849849643, 0.0038920922229261773, 0.006253851517554253, 0.02009915172933571, 0.01795388146063253, 0.00506198437388746, 0.09022347719198273, 0.0701486793977599, 0.019731632538981015, 0.039726121336101525, 0.029449821750242865, 0.10608872143371452, 0.049323743629840114, 0.044218303876057755, 0.013243697110503433, 0.05157974999277823, 0.0664433189517548, 0.09357393208530643, 0.01218740167396684, 0.05310945137734375, 0.04177165653316244, 0.09918119773388871, 0.058326146249929746, 0.02753689062721547, 0.08979164875082432, 0.02830707137623141, 0.03913488531965883, 0.020639375866120382, 0.06444589790677832, 0.02718137028897482, 0.10586007483183377, 0.030907122080304453, 0.09419234124042335, 0.010775741031994263, 0.06311466309031652, 0.035433531513497714, 0.045456543279391144, 0.029090210502486558, 0.04589053974937528, 0.05163478574925854, 0.05207153247489084, 0.023709118907009403, 0.04624589729393202, 0.03850972309948937, 0.10079150688984703, 0.015781336546605153, 0.015067358880544142, 0.05553510408067415, 0.04947148751647723, 0.02440703266690816, 0.0717955845738611, 0.029433705175535816, 0.07261254839719304, 0.006559880660666574, 0.06730267808081643, 0.09583455795842795, 0.07985005680952342, 0.08090128265922109, 0.09736629713687206, 0.1017516372244685, 0.22817110642790797, 0.1373653870917136, 0.15760546069472067, 0.16812642195051716, 0.1498585804215362, 0.14560423370811248, 0.09755401932183774, 0.06047106220296795, 0.055359072397432985, 0.13425422742241813, 0.17985504421014942, 0.13437007523832784, 0.1532891068247057, 0.20456914789974692, 0.11502224125809248, 0.16270308635167538, 0.18322336427386732, 0.25829834142519587, 0.13480001910319253, 0.23508129611371026, 0.09649165455372104, 0.12892905833019366, 0.19898948439907646, 0.1396355354377339, 0.16975874081254008, 0.13035074897831486, 0.1343976084383265, 0.1892748613271021, 0.15636896414141502, 0.19397885568680304, 0.19645970885551747, 0.14682058214900956, 0.2866207958469468, 0.18024115252398676, 0.1832102794921206, 0.21259701390179897, 0.11175545082697946, 0.09091276480185409, 0.10134351920456657, 0.10328411184731992, 0.14623283949350158, 0.15719240140770713, 0.12865300620755843, 0.07952882082111414, 0.08582201095358019, 0.22108108526276005, 0.10232798049166318, 0.1945370120266753, 0.15373935201956382, 0.12809851176796422, 0.18170929874383634, 0.17598602440088026, 0.15628225831014497, 0.2737650437460792, 0.14727435134831937, 0.23391630620725695, 0.13943457525343667, 0.07998233721140893, 0.11588905442265734, 0.12364454552411072, 0.1483557610622337, 0.29972702805553714, 0.15848364260408188, 0.22241116711689582, 0.12418841432419517, 0.11157186551680488, 0.17961662232635484, 0.10254675988107921, 0.20368427038192752, 0.1936601171450269, 0.22575233702457723, 0.11962981579164345, 0.17473363918402504, 0.1788162136630666, 0.25100916804325196, 0.11904097763040375, 0.07854619048415654, 0.18173188301584414, 0.11851131210043547, 0.09590145275597611, 0.1495606794713005, 0.09124471836032406, 0.198567814283794, 0.14211307910661544, 0.1488552044235891, 0.07766279151603099, 0.14590385069529857, 0.13547886493465594, 0.14644115412187192, 0.15898768249298298, 0.10742601983609701, 0.19102359491009868, 0.3138493073563422, 0.1585802922566091, 0.16800478250989992, 0.09653440225989589, 0.13404301698169402, 0.18651196522818458, 0.21553871492224358, 0.13463048384554926, 0.09757372310325023, 0.12217960921266388, 0.17822332289670745, 0.18430966162873855, 0.1961044892067871, 0.1190324510718065, 0.1564700264603861, 0.13307641320411237, 0.16369711607694626, 0.14993872854017443, 0.13652960048808208, 0.13448313449419316, 0.15704279975785365, 0.2041829936206341, 0.146468763930663, 0.19406424384684334, 0.17170494121889915, 0.10092040118310722, 0.12662732417905523, 0.09174864333603652, 0.13526451353344227, 0.15900115031869183, 0.22881952324701896, 0.18421679645055727, 0.13634131139805242, 0.16098859689889417, 0.13618078533439867, 0.18856402366392075, 0.17906013605815752, 0.11315458784660987, 0.08129209475291353, 0.18420179644899984, 0.09989782702177764, 0.23448232260923232, 0.13856596944312896, 0.15374445416513952, 0.0836817145107254, 0.21127603317220367, 0.14432183316638394, 0.19945189507017214, 0.172738409150512, 0.1628128514294663, 0.15304156849461217, 0.17710651992069137, 0.2207985826798024, 0.14344841632391178, 0.1982634015862019, 0.2165165035835197, 0.23018308314344577, 0.23442011626978076, 0.1594410992918476, 0.14989300841285338, 0.1269350770199972, 0.10171606010126491, 0.1787997121291776, 0.20559829509546682, 0.13943555584597972, 0.10984981477621103, 0.19632840138529578, 0.09189220055216744, 0.2460704749870685, 0.09665673117964499, 0.21076096161719293, 0.12391774779966763, 0.11478198842415888, 0.08952840561828307, 0.15820683971528085, 0.1722778217686761, 0.16465965958852924, 0.11480090313500936, 0.14501892721220372, 0.20564807548878655, 0.12293268130311083, 0.2331686043931592, 0.18085181653018922], [0.009623271875053404, 0.011227047258627512, 0.01355634046523201, 0.024719108158962864, 0.02907986831550877, 0.030948693841515534, 0.05415436083210572, 0.015500282827434281, 0.041184691456897606, 0.057170625190220536, 0.061667729845090266, 0.07545787555676314, 0.05897650510192879, 0.05016876159295921, 0.04746893751284769, 0.05654062895524887, 0.03647051961912263, 0.0338746766529737, 0.048596592124311194, 0.031126491357422167, 0.06270351519267406, 0.016096300190134395, 0.03693381895221049, 0.05594477725906238, 0.022967271919872974, 0.06603512432306044, 0.03242727609411363, 0.014494887230196788, 0.06134306944365944, 0.03825617480962988, 0.041484051804629066, 0.08969777999746223, 0.014533190668800907, 0.01059970839114319, 0.02919813505403938, 0.03540535479964268, 0.07585555179825715, 0.021074678516015414, 0.05567193887526951, 0.06750121742727296, 0.038943941734971545, 0.04358071187931684, 0.02211437857289228, 0.01383394487352381, 0.03381690979304333, 0.04620347900556461, 0.026953068426659992, 0.022170308737024184, 0.03532755474049238, 0.052604323643590176, 0.04493628147869341, 0.03601657038915061, 0.044015007123591444, 0.08018766409687458, 0.03292198886253661, 0.09039843635212991, 0.06213159225280247, 0.04906720759707594, 0.033006128299260334, 0.030113924219603502, 0.021437200897883986, 0.0994789531274188, 0.03827692813149864, 0.038451163338557366, 0.023072047850057002, 0.03283551668808345, 0.03852775297878731, 0.025744128055990707, 0.046667701474601225, 0.05454661700153544, 0.07287245138638443, 0.02908724191177997, 0.03396635439487235, 0.04404026121201535, 0.07615021219657314, 0.06312868632977048, 0.05079663576438062, 0.021790564698617787, 0.04863246036092601, 0.0741082891040752, 0.04184245454868482, 0.0741610649011789, 0.039928506443937944, 0.022415721173127814, 0.052292659923794775, 0.09014478464040065, 0.02052345144141826, 0.02490960549743426, 0.029071247911140807, 0.04882718075908, 0.07668201511185016, 0.01144065268172492, 0.03206291510122678, 0.011456105632767563, 0.08970724884420635, 0.021719464078365315, 0.028493290113645698, 0.0504423737255556, 0.03256030726216493, 0.03247118059305414, 0.03230837158738606, 0.030957061436868487, 0.026872305522462534, 0.003987686110532753, 0.010706794076418925, 0.04667383017799547, 0.034322872562634374, 0.031005872728964014, 0.013100667537430362, 0.04380812124919988, 0.02799718881085996, 0.0573194875652271, 0.048948440986174735, 0.029359716403808807, 0.05834045677235531, 0.026846216398201166, 0.04761312675151614, 0.05635848005993232, 0.044026287768276474, 0.04270570157396217, 0.04091919219541935, 0.02482737361964199, 0.018893725787019058, 0.06315049685297475, 0.029462983140782006, 0.0345481866820445, 0.027836568901435505, 0.019140203085337437, 0.02361197512777102, 0.033608782856214436, 0.03507395665491781, 0.04314596464316692, 0.021134123108499957, 0.018116113985137596, 0.009683338913976425, 0.043944837300166975, 0.04929760854030329, 0.08294740391354408, 0.03546131752251137, 0.013347051947587922, 0.016795757617200577, 0.04238827687297617, 0.04882838734756074, 0.022582835592930357, 0.05947240530663441, 0.04077954585814188, 0.03440357992545732, 0.002968565808729299, 0.07709592475645966, 0.03805972688320664, 0.031486085368200176, 0.04004194491332577, 0.06072825707134701, 0.00630665317012538, 0.07349333500549679, 0.09240660561068405, 0.050684108939622684, 0.06506206242427712, 0.020720429883729068, 0.03572991944008297, 0.12628205601246129, 0.027825541065765486, 0.03677836822105512, 0.0525128182714745, 0.036096599764160575, 0.05286191304725024, 0.033421321141143004, 0.02825876953260553, 0.02649868827223057, 0.024304382630714008, 0.010500350617803635, 0.025675455934458205, 0.021691024979396213, 0.026123412441642537, 0.046678242844439326, 0.02613300960811396, 0.027815302300657478, 0.028386321256778417, 0.05063538957807807, 0.06538077032253628, 0.0474294226977133, 0.04595527034853736, 0.012353643711145607, 0.028231778339813315, 0.04905080182417747, 0.029304648088591716, 0.0362318717393904, 0.015359439477775128, 0.017048223807867018, 0.015450152906499084, 0.04392426400896042, 0.061733180566901164, 0.05652388993410334, 0.034723597834067005, 0.01158979946687337, 0.014996205591746877, 0.03658987994816515, 0.014487812408216059, 0.03893966696435406, 0.02945070275135579, 0.03366496008370192, 0.09357900358736516, 0.00907039388097943, 0.00999645053994872, 0.08224028943767471, 0.029728915241937486, 0.026352526357157097, 0.019907338634854364, 0.0427056709304452, 0.04477929091081024, 0.09487334743983324, 0.03379087429493666, 0.023843919738165797, 0.03037099651391468, 0.025503107218913017, 0.060174042253845164, 0.07896454343872686, 0.018357297615899194, 0.03629867460638766, 0.016553861524669394, 0.07749554686128132, 0.08043526371400203, 0.06366807351549787, 0.04147538735020546, 0.03692297880808192, 0.04116971443797793, 0.11740148052453034, 0.06424530544468472, 0.019561813828805764, 0.0507702516962684, 0.025247094041157155, 0.02587008057162166, 0.018312263137270367, 0.02861481655629412, 0.014704520487406803, 0.024122900231891585, 0.02703702208706208, 0.03188265844308321, 0.019187170020755262, 0.06473322684365897, 0.062020984478294856, 0.027464635129417145, 0.024905388183411092, 0.09263493811651584, 0.0685235004751913, 0.040651620666105906, 0.07211602383082913, 0.020746963338986523, 0.03994163336052049, 0.047442411718469475, 0.07525744397313365, 0.06493698324887984, 0.054521133086734244, 0.02043588184601357, 0.03997668188305632, 0.07972626466183894, 0.07820202548417353, 0.04104331376091127, 0.09442089591175319, 0.030851406420791344, 0.03969564252803403, 0.025251924225519744, 0.049483576383922374, 0.044601635121169596, 0.0368892019915004, 0.048858651651009444, 0.01332092164610062, 0.044220517870158925, 0.01667843316681683, 0.05424537973838949, 0.0011305278002832746, 0.03941426226388543, 0.04717463334541648, 0.02992900400122087, 0.05003941147738407, 0.029511302221386187, 0.043016568562316324, 0.017214497446172664, 0.07022089084550258, 0.035968735859158545, 0.0441490150537462, 0.020396018460873636, 0.04508689053416733, 0.05137685543647216, 0.0013860681581483675, 0.043552527504582564, 0.029698317690241723, 0.05754872405480954, 0.016775571200395786, 0.04407327194067259, 0.07668003860500551, 0.06621597469934533, 0.040246256732291756, 0.04629797978146423, 0.015907077430447024, 0.03257964715181339, 0.026349435192382625, 0.013760353509907522, 0.030794083891857057, 0.054464936707048654, 0.0574922863574278, 0.05120716313080442, 0.01333862019237131, 0.049682188508731705, 0.007181250266805893, 0.009087147266273538, 0.014930593033861971, 0.025455358873812423, 0.0632591434423962, 0.02194366162462581, 0.054341600381679116, 0.042399193625897176, 0.05095800069431144, 0.07081509162221225, 0.022600371345517137, 0.04136148539762344, 0.0330844224851218, 0.07060571213162715, 0.01955950981937349, 0.044505720913049676, 0.045327472785908374, 0.07435070996683452, 0.035242718163757555, 0.0029077669164361136, 0.017227509449566566, 0.041147245079158776, 0.01614131934700474, 0.025657671203296033, 0.06880121500862223, 0.04542355170293201, 0.04212099262663434, 0.04500959992348667, 0.0945100991896564, 0.029730462739544532, 0.04320780326041483, 0.024883767266968088, 0.0699111998021122, 0.015071423934592355, 0.031532426026739904, 0.05280516508425917, 0.012985331085210126, 0.015986006511675737, 0.03217766932662457, 0.06492626567881915, 0.023142384297605005, 0.04893964246636437, 0.0894288678142813, 0.04926370148877463, 0.06958096994147187, 0.05237827791021236, 0.056522564601994334, 0.03422537638295082, 0.07675624903171294, 0.06504327794837375, 0.19020322199550369, 0.1557666045283118, 0.11265598718197116, 0.11893318139857824, 0.10333038355794646, 0.14127652641505967, 0.13108505957549618, 0.18228178092789266, 0.14810272222084386, 0.15795596124183747, 0.10570553191486867, 0.17024511471390727, 0.0984658784563503, 0.15619742173341014, 0.18613180175663965, 0.09110325256422644, 0.16709762715524243, 0.14583660349730523, 0.16763574263501554, 0.16131229969041963, 0.11238932729728761, 0.11911056139656614, 0.129801755050017, 0.12489120040329234, 0.1139553182668263, 0.16564291811758475, 0.2210165193725017, 0.14651906526377126, 0.11703477721781501, 0.18315450829123298, 0.06358493382351534, 0.11354050463846616, 0.22392959934809517, 0.12499546496978692, 0.19258488209978228, 0.1493624312382552, 0.20003974497798951, 0.1391651421304672, 0.12729313885492663, 0.08573425558185385, 0.09837899642485766, 0.15948320348416606, 0.22603284777893176, 0.17693589681819563, 0.12682224759050917, 0.1780221328860329, 0.07208116683027438, 0.19004317090636302, 0.19176985647889877, 0.12551465807783027, 0.07849211999846083, 0.11880031876987028, 0.13101983484962296, 0.19806699196417488, 0.10157567448914052, 0.11920162626812536, 0.13658187832803498, 0.09866931310464298, 0.12373559507391146, 0.1466602093029407, 0.17823993168290586, 0.14117465204288884, 0.11602521889031896, 0.07740182366462485, 0.13839425849578074, 0.2003744028268322, 0.20326289138005627, 0.18978950387287527, 0.21565463934694568, 0.12255512253050843, 0.09433006852745049, 0.1013791959192003, 0.0854038954862664, 0.13587333892862644, 0.17200851121977453, 0.11787786463936491, 0.12449769168010644, 0.27091770943614746, 0.18821660279025956, 0.15928648742696933, 0.2323869035969819, 0.07932427534533125, 0.11279311692041737, 0.13013290421616647, 0.09298753008366593, 0.18115512606117035, 0.114101771295311, 0.11102012133285885, 0.20046881550262052, 0.11710014750039387, 0.1406905764052945, 0.11708858723361647, 0.06738905449427905, 0.1768307282679504, 0.1648129997474532, 0.10194789362891067, 0.17701857302698398, 0.15893080812548438, 0.17701751582564848, 0.10776847646000887, 0.11557267543168799, 0.1859211275774625, 0.10001730609444842, 0.13885248632680985, 0.17463046246238295, 0.08403003936813724, 0.1009328730945145, 0.15723456688705953, 0.1258078016220562, 0.20380528163044684, 0.09772993609189026, 0.12396162931597042, 0.10884074674498652, 0.1514349135780527, 0.09616773725757677, 0.15835320847409387, 0.22316417025942958, 0.12112256875562093, 0.13992882453866545, 0.09406259658956721, 0.15177545498215383, 0.1485486926450845, 0.09485590361779737, 0.13971002982749095, 0.11877664665301, 0.1141759362672606, 0.13884223607038298, 0.14154505555427846, 0.13980968254468135, 0.07335707860728426, 0.1819856726233998, 0.06722751719456527, 0.10601300130327863, 0.1440804082179262, 0.18910543332176824, 0.27756165292474533, 0.14641265565108869, 0.11398278251891175, 0.13307279726910975, 0.18203652553981353, 0.09782422619361071, 0.13137543754231545, 0.17295325084799723, 0.14261607711593952, 0.09923990305152633, 0.12884992144761548, 0.11577653908921827, 0.1262343976826918, 0.08118429852108802, 0.18096835382523077, 0.1008752786043671, 0.08522136737742732, 0.12070888127650946, 0.22370259217437238, 0.19870295219363707, 0.16072348451181767, 0.09463747662882652, 0.11304056331995996, 0.22977998299944788, 0.09405492804944517, 0.11060647981902284, 0.14120020873604283, 0.10363579983071936, 0.16167046111677924, 0.08531347412856356, 0.13104605037839184, 0.07653049058130673, 0.10717359386504659, 0.15340354503883472, 0.10359461494391003, 0.19112589829150708, 0.20298374426220694, 0.29168730301241724, 0.15253956639958968], [0.013423087131682665, 0.007364554518473245, 0.05954505342449393, 0.023202874600106192, 0.03366837300540459, 0.02744711278336904, 0.06588998130492627, 0.07412422373290024, 0.05596460361454276, 0.03662538429301593, 0.086490047284432, 0.0635070035294179, 0.03280627128157405, 0.035907759090825435, 0.04996287929374845, 0.02029324968105122, 0.06833027777892929, 0.04183040015519627, 0.036170741753472437, 0.042489553696566054, 0.07030117685996717, 0.024780923793573054, 0.027463652621654254, 0.03826686939705284, 0.016135502824439638, 0.02181097136570081, 0.05314227058401993, 0.047174430332116546, 0.02441626594161555, 0.024811341314606612, 0.005240592985383926, 0.03786483411526969, 0.03945314122604267, 0.03376550146288449, 0.04209687617877799, 0.0870418910598082, 0.032597700013749065, 0.06568185819853699, 0.0218097168967248, 0.07116955284389757, 0.04308119573960862, 0.01737539506246967, 0.10637943647922048, 0.019543464107799436, 0.08699246306693362, 0.038242760610075734, 0.05082391232492463, 0.11238931963640837, 0.010955416420925288, 0.06236896842658039, 0.016097930042193304, 0.038535329588358445, 0.06869938660172686, 0.04973757283521756, 0.007986789325162048, 0.052230622123686545, 0.018277951974361654, 0.06162709654158643, 0.023509926470597426, 0.04974413437828903, 0.055930949372029116, 0.08795202649649113, 0.021401817211881283, 0.056248875860605514, 0.0867065130883167, 0.0073377409623184755, 0.04696910727709051, 0.035251068522132216, 0.02508781095516057, 0.055319496295264656, 0.019480390173773614, 0.008087887075699626, 0.01817209011454496, 0.021055947666266756, 0.058587730802114935, 0.05616003647446633, 0.0664632372377861, 0.055152638514916745, 0.02079333847148284, 0.018737809657449686, 0.01750608966235192, 0.04038402998459436, 0.017046164946570512, 0.05191601279582228, 0.05372600659968392, 0.0363165972333762, 0.0553699393546389, 0.040336800664062464, 0.09167693750632387, 0.04159458680078388, 0.01786680407671919, 0.03890395577576372, 0.03920817695137474, 0.04313736530621687, 0.03716700845548222, 0.043360055574486335, 0.015762485995618327, 0.06779691204428673, 0.03632989651974171, 0.05916298239401752, 0.02839848481779618, 0.03640599586370011, 0.021057661787997332, 0.03936969509889041, 0.043065931437717336, 0.08491647204444294, 0.04899659344265538, 0.03228441984843343, 0.016558973246344155, 0.044063772450411515, 0.046870592200467666, 0.033438232532071496, 0.02384969412589506, 0.10369972220712131, 0.04725769642860659, 0.04371416822616612, 0.05826803465043345, 0.039231791611640685, 0.024253464596826705, 0.08547852011097055, 0.13521457992253766, 0.05292557495375795, 0.040951904149786125, 0.0730419866440277, 0.008914341770803497, 0.023943662470687303, 0.06838365878549314, 0.037920000106697126, 0.057837956720182014, 0.006115228865265606, 0.055200407927435254, 0.0704025685967457, 0.0422592600056481, 0.038214197021818934, 0.0586697481752884, 0.0075666274454805164, 0.00708285249739645, 0.04470686878888838, 0.033506977431956804, 0.12836203835303747, 0.039284797235121655, 0.06842868943368235, 0.0650485103288966, 0.09524591898004856, 0.043616495846259984, 0.06586985617515541, 0.04519137343572033, 0.015379789645873733, 0.04208888205128812, 0.020801786506067843, 0.023643371326127843, 0.03524466402708523, 0.03327745748984237, 0.021477359226874767, 0.0693666568446544, 0.029894683262213107, 0.03441311005923537, 0.01733232368414681, 0.044439021467922196, 0.11102658711493978, 0.026557284422338973, 0.037416312618241195, 0.0659575502598478, 0.062232034040554884, 0.027642794621868, 0.05119695500921338, 0.029056740121074745, 0.06830786204626484, 0.018524969364666653, 0.05800535076207692, 0.03209328474176507, 0.061320469849893165, 0.04024739054241969, 0.0403749633340105, 0.0203465081135472, 0.06479039998544801, 0.025529357221638484, 0.03259032258703824, 0.026621919260510517, 0.017843526495139928, 0.09578478522598745, 0.07673817701757916, 0.015430735450448289, 0.05620134393534353, 0.031079070514909206, 0.011687041879932006, 0.04894877040398218, 0.04420398186231333, 0.008953866162036937, 0.06984745362593282, 0.019207258761349707, 0.018869109466792117, 0.03111499429289853, 0.023386456079841144, 0.06339631914611786, 0.03741545843020563, 0.012874421663582327, 0.023967784664203084, 0.018710184526900132, 0.004677126219781537, 0.06737642170440766, 0.036177510140283455, 0.05473619311927788, 0.06752026237307057, 0.022616351939617627, 0.0625817301953512, 0.02411101054730675, 0.018244334121024417, 0.07771708416722475, 0.03597708238709358, 0.034529134075367646, 0.06814453210080824, 0.07241489771272867, 0.07403055416239847, 0.009144516718093186, 0.04240802661966413, 0.08959991992601464, 0.11056678114278663, 0.05978343317345266, 0.056072208324387196, 0.1327801670037931, 0.03647849076397477, 0.039437643267334475, 0.11688198098131727, 0.01375514315441251, 0.04962293926866786, 0.1089834229600045, 0.03876186944844742, 0.04193522396587557, 0.04118253491939076, 0.030973582122955593, 0.01939157760071178, 0.005641363264482108, 0.042914314976622986, 0.005502021925959496, 0.027080882535946947, 0.0014205035709422985, 0.041356999952826774, 0.02534183613475292, 0.053183018800712405, 0.02103714212294548, 0.04279181368709092, 0.04052358822176053, 0.03708183480006072, 0.03792671486735344, 0.05939492317397268, 0.03245700030557571, 0.04062278511663599, 0.042826594078853246, 0.0486966930029373, 0.09297580893842444, 0.05326284516242243, 0.022689921278206092, 0.030264998673491424, 0.053461602843937375, 0.0933130561644512, 0.03031885273934853, 0.061181482348230586, 0.025611347781734604, 0.015368255234563784, 0.04110205355250547, 0.05113578671889921, 0.02086757813700505, 0.03999613668589343, 0.04542013878122934, 0.07873859346633957, 0.00813084832888337, 0.02282880344277909, 0.08702135990343748, 0.017194651938494177, 0.019980053785407258, 0.01866541626382499, 0.04007267269996866, 0.01317077415860108, 0.02226786045808225, 0.060966280589420954, 0.02959238113685241, 0.008180646916791316, 0.04875092436709712, 0.025952046233860236, 0.036908844485878944, 0.03797811553663304, 0.10706623430333792, 0.023942633997648958, 0.032028540736064315, 0.02805102563973877, 0.055582616853738026, 0.004904852079738293, 0.03287648707027397, 0.10287301374539252, 0.057818662795809016, 0.05673094434783824, 0.04943266601091431, 0.03926632685526725, 0.06450494796398186, 0.112904766574502, 0.04319415157360416, 0.07366773492145924, 0.07594316161327785, 0.06175977147875294, 0.025547387100936427, 0.06588868661633422, 0.0689354948999901, 0.012230397401107176, 0.06262250905556065, 0.07397885854926801, 0.08937889589898049, 0.10878700567709823, 0.038731210609717716, 0.08403098931716335, 0.06882456536855429, 0.01930289334737726, 0.032181300583385655, 0.06106132911818643, 0.020880371805340536, 0.12684370571326825, 0.04047979863600866, 0.06061211814202609, 0.030461756865524, 0.057172766405968904, 0.05295805325130782, 0.06854311998693213, 0.0605932915312869, 0.026191946667348667, 0.03960404522536744, 0.056576910879342794, 0.03090602274413311, 0.028825835475037177, 0.03935008707846846, 0.037541679076610074, 0.05118129617204109, 0.058971628952290744, 0.02192220541708652, 0.031504919639818614, 0.039883655826410944, 0.022401600257463516, 0.07514439237814757, 0.10508676269842733, 0.04886786002785929, 0.008504429189938932, 0.052694909710196726, 0.032553489079638835, 0.03863266872001752, 0.030898587860827966, 0.10375743927133661, 0.035299734257522135, 0.02050004362489187, 0.06645952171135334, 0.05759205015736723, 0.0327742449758995, 0.021651402911952427, 0.06991266303004758, 0.166729690446969, 0.09062307631416668, 0.1073058206407774, 0.13288501379711012, 0.1724252783723416, 0.24159718034488542, 0.18282257771540075, 0.1938284573055083, 0.12114852381449555, 0.16921051297216647, 0.1811126081813728, 0.10060629747327297, 0.12569072040458842, 0.15656060869655303, 0.14557267088563214, 0.06829615622278183, 0.1153127724424966, 0.09774642996490003, 0.1352557494875885, 0.08094548593245207, 0.15668439318335828, 0.13715365571120094, 0.13242422723241393, 0.0921405739180984, 0.14414454509894695, 0.10555616009139246, 0.10389987033821883, 0.24318155742460684, 0.0751519306833225, 0.09868525539434726, 0.0976120887864982, 0.12324098572735825, 0.2527811600556297, 0.10611478374489855, 0.12129705294125503, 0.15827937291995173, 0.13233554489429922, 0.19859116464372606, 0.12939306246417184, 0.12208782421845583, 0.13795400308745523, 0.19427649616714449, 0.20740834635592278, 0.09354836773127319, 0.18536431955233698, 0.15260305976675403, 0.08025327186670997, 0.3018791835394598, 0.14100808920639177, 0.12007769377481554, 0.20848021061430055, 0.15436184442331716, 0.15129580733276185, 0.16608711121784103, 0.14267842135121747, 0.11954965235124673, 0.15248446935607543, 0.16158220778790214, 0.16100557340729624, 0.15693154846948965, 0.09466483362860258, 0.144680576819566, 0.16604601826158263, 0.19269414155954318, 0.16551634507073512, 0.10944784078146182, 0.18788526976300826, 0.2208028114851444, 0.2659752778708935, 0.1995188971200297, 0.1350094828634493, 0.15129911683259473, 0.08486186529720023, 0.0722327066825763, 0.16029199314934595, 0.1678772288705072, 0.11112023370280383, 0.1484904239975637, 0.15561174751529772, 0.2030607973856311, 0.1303530472420877, 0.21322045625457842, 0.14817563846947687, 0.11673535941348923, 0.14994870300494856, 0.07136827605145593, 0.11816315578236697, 0.15770431668046983, 0.20216606797710543, 0.20108551628166632, 0.1373982675854237, 0.11023171726734408, 0.1739039506402708, 0.10365371862726827, 0.10355535293779067, 0.11552511669334867, 0.17373550322748002, 0.20871146191512385, 0.13774651583404313, 0.26527164143420034, 0.11159523119849545, 0.06779282113477107, 0.14901016868891256, 0.07895933404084175, 0.20541207444283271, 0.2755911215659111, 0.2023671200919536, 0.10026300581352365, 0.10573926276617474, 0.07331478289298474, 0.17453965039983874, 0.15428217127919197, 0.17831790411183912, 0.38741921284987085, 0.17074727002651463, 0.1424501118280234, 0.17123735179343533, 0.1639159107881208, 0.07996306243923404, 0.20137359598471274, 0.18729766500332665, 0.22249413443909538, 0.2305876541762583, 0.11362042293072709, 0.11824540298191771, 0.10793732223852028, 0.2274349112544329, 0.06845989985571754, 0.2338441713683067, 0.1166271111897884, 0.19156079108436264, 0.18711208786454894, 0.130990493682123, 0.1588160021891517, 0.20842583369343512, 0.13394154097524383, 0.11729584466065131, 0.17957298595818783, 0.13555250130593777, 0.23411895178498762, 0.13310930901958098, 0.13049622907513572, 0.1509013793040668, 0.328991831911187, 0.14102426898335257, 0.225262806840962, 0.1444940497317622, 0.13569508559040486, 0.1200019276791042, 0.08754947793579872, 0.1508218287340095, 0.19603852903650654, 0.2287985171161352, 0.09618651407260088, 0.3258725976751697, 0.12678450243847986, 0.11963435103215518, 0.11482506554814116, 0.12914633618727808, 0.2062807721836913, 0.09926925187990551, 0.19374470857362594, 0.24441330423278196, 0.13033098390986844, 0.11931727490117473, 0.12019040829111492, 0.1256464558443235, 0.11306244279107741, 0.21706237187308652, 0.07079364116033239, 0.09485435612019032, 0.14633287525465413, 0.09928484176916462, 0.09172589818556463, 0.12174367454023131, 0.13527067288035347], [0.029843573706344734, 0.02704033158689497, 0.06269835176006441, 0.06005386221072367, 0.03204638292382081, 0.02180302894914583, 0.047230343259270155, 0.05414159397684759, 0.0128941934352981, 0.06481887547359352, 0.05429262055024024, 0.08775383188960054, 0.03420487587009707, 0.01291144094730337, 0.0747183708834552, 0.015374057392980305, 0.15195684928086498, 0.015550929857718368, 0.08222044776043586, 0.05523012830845772, 0.0678492205277566, 0.00712846537240811, 0.06518902617596811, 0.023824985875117204, 0.026752200172913652, 0.07509368501843945, 0.026977493224905866, 0.044758380540917, 0.05721446074124786, 0.08503320086146555, 0.012158147648968285, 0.07328971649610228, 0.1235060521491593, 0.020432832816074935, 0.03568074808666303, 0.02869563117142647, 0.07747332265059795, 0.04253463031003072, 0.044799875693335656, 0.1335701875148281, 0.05457343390932488, 0.015171537262147233, 0.03194266802541191, 0.030730824181509596, 0.025641093060614604, 0.042495778160950834, 0.02111678653877349, 0.03062453139723549, 0.03366055507813731, 0.0075360284573698965, 0.01488967436260634, 0.0034799790544991173, 0.05038266100229756, 0.028583791910580574, 0.06618601300062672, 0.07395454291855136, 0.0626976354678552, 0.0940181558290797, 0.03821545340601475, 0.020673499337487647, 0.06783242788045638, 0.0007846316809938741, 0.0277910728548323, 0.0431198678580263, 0.00813271854102852, 0.012629051362314533, 0.04033318855949948, 0.05087540492475514, 0.04832808979816976, 0.06081977010434193, 0.05782704762814026, 0.04966405903800361, 0.04019336602199943, 0.07133826838746186, 0.038691983077554934, 0.052192501588574344, 0.02760960194732874, 0.0349204671088486, 0.014280103946915798, 0.02497276561635156, 0.02281097657678108, 0.08755271848771842, 0.03731853298602566, 0.018414961053959785, 0.052034289110451944, 0.06201450720489506, 0.04436782125623957, 0.030304082564168403, 0.02071211016887138, 0.012864661703426993, 0.056771769173323154, 0.030783617215591575, 0.005932078788793016, 0.030355875853509195, 0.05455335091438986, 0.03586878436767767, 0.05953709377096065, 0.053871467544306675, 0.051664080951483025, 0.011645911576887293, 0.057424889772289225, 0.030976914605426214, 0.027794947344509345, 0.031197291288164355, 0.05417234474612821, 0.019625561920204954, 0.05563931119057441, 0.0451173999857518, 0.06365797264621624, 0.033469592341251915, 0.05116124382062305, 0.05680760676642099, 0.0838464770406004, 0.05840306913840675, 0.005475372599903495, 0.04273055729666545, 0.04738950568641867, 0.09544887865382819, 0.023604049948194337, 0.01244128895773282, 0.05115956991850849, 0.008027588773984462, 0.05017276057192395, 0.053324499918568524, 0.061896973995551954, 0.012386746370353767, 0.04331177671349818, 0.007251327680874497, 0.019484496405047756, 0.06651717748853468, 0.029945725785388105, 0.024946906318467472, 0.0037203245371910595, 0.035142827959310625, 0.011689314288237404, 0.0014785212049666313, 0.05706734504670866, 0.09057937099808648, 0.01629535281550019, 0.04248137570797436, 0.05948737849511447, 0.03326226979674351, 0.04490931135331912, 0.017035499087444717, 0.043247927115449024, 0.04114267153425082, 0.03691122701932346, 0.09455549756004926, 0.08460180909042397, 0.03663615931967094, 0.019013524701398228, 0.008338170873391773, 0.020135222979250456, 0.04944226126216593, 0.06863172571625441, 0.056590359552853534, 0.05301292812932403, 0.021855460006683584, 0.05723025747424653, 0.03782927614426421, 0.05332339675195756, 0.0319155695803103, 0.016805427562024806, 0.02207039938037915, 0.06698423065245152, 0.0380614199375193, 0.0499029329136735, 0.06052028718254259, 0.04079382573705047, 0.0178756830357616, 0.03463093949962528, 0.09260068632542126, 0.01215750796555151, 0.040108234501413764, 0.019909227041587717, 0.047316895872955365, 0.060577988924999396, 0.048663046421302904, 0.016063354578950716, 0.015897282038725192, 0.014047954408001277, 0.029882006422286073, 0.029075336905436653, 0.025388058049664385, 0.044934530967786435, 0.03129706657942265, 0.01332554785955337, 0.017440910901754134, 0.011038134764549474, 0.04849970881496707, 0.02887260897325412, 0.04614414932626871, 0.02522279947785841, 0.020260727333445704, 0.04426831026531516, 0.11407343370299186, 0.11909551542973328, 0.039700851925919135, 0.04337512835439655, 0.055905733588001424, 0.055537593866428064, 0.07119629697333421, 0.032846119344955495, 0.09857993362651718, 0.015643139073114484, 0.06571383470849645, 0.01612389467716698, 0.03920883961742924, 0.06291250780885739, 0.033795317604897485, 0.027979702853988257, 0.025679518115676703, 0.00563397195242766, 0.05294275064502032, 0.01000554783404955, 0.03808597305549249, 0.05293055452526577, 0.09837439223643273, 0.03719100615971031, 0.04501480932137178, 0.047437416825203166, 0.04461203859518132, 0.019266804860484217, 0.025114311851681243, 0.06042076853073894, 0.01154235181128306, 0.055717072945328495, 0.06437085959459506, 0.03618223690277627, 0.04841410998074759, 0.024981269192311074, 0.01041862914609092, 0.05852860030567935, 0.02313564846953077, 0.03468505595059645, 0.011695596209216503, 0.0433497938267406, 0.005230348953421438, 0.04265662215109314, 0.04941406922655241, 0.09731588089057515, 0.05633416059877604, 0.05683759144777733, 0.08415023856345685, 0.03154009648208176, 0.033767045130051916, 0.0430137723413927, 0.016597566840749596, 0.05245469518065934, 0.03297504428173265, 0.07449443572230878, 0.05709002891014661, 0.03891079694092755, 0.03696752299043921, 0.03902987764787771, 0.03861920855518791, 0.0371736619291046, 0.026396580243242845, 0.02812736438617351, 0.0771136520310275, 0.028503513556995222, 0.06244462726998234, 0.06961301539934452, 0.04511916964885689, 0.05981183971368498, 0.08021285306782493, 0.029528968208920092, 0.02171550914945622, 0.030818987495055607, 0.06668833685257743, 0.03345936506746277, 0.024877236367413597, 0.05835662505799725, 0.06780674861323449, 0.014064664700849643, 0.053397684297975034, 0.03940491982164883, 0.02835849311292893, 0.0426637735818663, 0.028275615806060455, 0.01709955552923343, 0.05486139486874304, 0.057200629023774985, 0.09772323282255281, 0.13965347721692056, 0.020055274043472546, 0.05279129123195045, 0.05086964777400417, 0.014601368663622247, 0.11327248877815663, 0.030439490520004785, 0.039280924660664414, 0.023691416530299093, 0.09407177432290009, 0.02160792933746932, 0.0186698921325226, 0.041985280150848056, 0.03682522215850411, 0.041324341624614694, 0.03171977665906232, 0.032652218660880486, 0.010702251175027943, 0.027395286935291467, 0.01942867732366487, 0.076453544710192, 0.05310182114161792, 0.016986266446990833, 0.06836963937647882, 0.013801997091861503, 0.051566852902572964, 0.0382179317004498, 0.09240501214780154, 0.11464712630596854, 0.0316998353903933, 0.0651336303581634, 0.01926790802709518, 0.08893960576143958, 0.057483384415747664, 0.05252800979501298, 0.015442874113608514, 0.03207548660406422, 0.0655694654391658, 0.04820003820162627, 0.023846848109256358, 0.02717697485950926, 0.04689436390875809, 0.05604619580891825, 0.03494785475214163, 0.04108866233558905, 0.044167523737996824, 0.06702632718389073, 0.024834659115801898, 0.005740575959921004, 0.0032886555380818826, 0.021923544155734203, 0.011403376758549244, 0.02266161815984355, 0.01976476775692596, 0.059442742382206266, 0.09761782678505106, 0.02539637584930226, 0.015462333704495143, 0.06134277449980859, 0.032703247777516806, 0.02485083697754289, 0.05125942564899883, 0.034773470157937664, 0.09316389118471453, 0.05082108163004441, 0.05299098737117264, 0.023038857090737552, 0.034441263790452675, 0.15206655307162195, 0.145203355219095, 0.12509274281441204, 0.16199687585955666, 0.1284093979085165, 0.12573993389284419, 0.1715945785925273, 0.23706485096725727, 0.1548898935077652, 0.16893023204418922, 0.12035756101531368, 0.21375599767892592, 0.1646124379288766, 0.07172944054247872, 0.21912751509056938, 0.14608818677163896, 0.2080012830875574, 0.10389780190082328, 0.11803888866016943, 0.13893723097299376, 0.13258057045600108, 0.07432434122048079, 0.1803996714372789, 0.18013940072588383, 0.14188438653945923, 0.15404690567764545, 0.12524714783555077, 0.1963536209997631, 0.13294576456950558, 0.15461388735040543, 0.08868570890157454, 0.15830201847899347, 0.20722650772621556, 0.09999367228198437, 0.12526508961473742, 0.12990750582708468, 0.19489051563845528, 0.13562161775846637, 0.15134849886019386, 0.17397487506030068, 0.13000343535696307, 0.29333555650326515, 0.17908829745025406, 0.12006649356936255, 0.134252266237332, 0.144993600345427, 0.11335652096257096, 0.1085454045284179, 0.17559628483028183, 0.11557023927208879, 0.07374939223330829, 0.11393619671223626, 0.13394564720651797, 0.1639686023155528, 0.1915275122249319, 0.17841977848400994, 0.15103193600812267, 0.2199814120127309, 0.16619041051355102, 0.15262944383486626, 0.1520989432690605, 0.12715379512237926, 0.13584994260341893, 0.07699715304038218, 0.26969337835907936, 0.10083623110286652, 0.09713448659186402, 0.1568771562268657, 0.1493112105996378, 0.20668368846658738, 0.09678932567757946, 0.1270896582413585, 0.1636304357840169, 0.14166024453457327, 0.10369953068514025, 0.12573910651788597, 0.11787832429211949, 0.13678694474360636, 0.1381780684835488, 0.18896169990541475, 0.07704704068601131, 0.14209712915603193, 0.11972836534222288, 0.14855593983684817, 0.1047400159821395, 0.12218910870292496, 0.16170335693224785, 0.24158322222290501, 0.10656094569112025, 0.20553179866363927, 0.27166703535664466, 0.18151627523043465, 0.15652838703845778, 0.1278070689389302, 0.15178285539150238, 0.12664075370036787, 0.20607230433773613, 0.19589715517095982, 0.13900251698590096, 0.19320630198044164, 0.09265947591273055, 0.11866559454750632, 0.13241409955005493, 0.15290319769372865, 0.14508280362333023, 0.1611306908870897, 0.15076950492878116, 0.2834033491390367, 0.25292368305306284, 0.18563110201108843, 0.17973950282940943, 0.10582286594135147, 0.20371970960930472, 0.23344487102041322, 0.12470995932216607, 0.07908868032597727, 0.1295687877122433, 0.25103143055833155, 0.19367474942438065, 0.12355453019300777, 0.1040190429757199, 0.1056576973848766, 0.11480265747635596, 0.1798635937513844, 0.1682155026543525, 0.09394721608729133, 0.18603616334017248, 0.06841626348755053, 0.110738086063535, 0.14881205835169362, 0.1347013623003037, 0.17752406848294122, 0.1481342850433242, 0.11774296421677836, 0.11780805104682524, 0.1714915091231946, 0.18916007071252794, 0.16854374068638972, 0.14956310030914124, 0.18171771038924495, 0.15095754887067503, 0.16967615653430262, 0.14552497425146643, 0.04920356358671862, 0.21833112072800437, 0.18521672505284512, 0.11447360739111902, 0.19555307444064848, 0.16594593653515463, 0.20966426078830996, 0.10929246282865925, 0.12767215319458516, 0.15084927000345724, 0.1317172966176464, 0.16979439454453607, 0.07473092706453416, 0.1580081165077225, 0.12244495142611767, 0.11881699650398186, 0.14699901934833298, 0.31226473109376046, 0.09721414441423071, 0.16834988979802978, 0.14090875824612958, 0.17246886877523315, 0.11050237613099237, 0.176576693512259, 0.19183667466765453, 0.12408321513043297, 0.09549972390936268, 0.10729709489931984, 0.18882211868561086, 0.1698693485870477, 0.12460285256947241, 0.1145105634725863, 0.2628629077826777], [0.05566705889519184, 0.04081041920149038, 0.011459583671943796, 0.0392621823195969, 0.047038668060615185, 0.041403436372357036, 0.01831715077822728, 0.02202449347673645, 0.047937258552279205, 0.05706741016418223, 0.037942132386829586, 0.04369736791798665, 0.059007734676162084, 0.059083803376603516, 0.015933875186038355, 0.054446975775663896, 0.03708075078564786, 0.018749689765935464, 0.06406173928670826, 0.022964621255654964, 0.08596362230638344, 0.10832815731485045, 0.03296176414756525, 0.023090299894852985, 0.06864834216333206, 0.04956099722955016, 0.04016258843964146, 0.019570905377247164, 0.0100180130421875, 0.026051300585330017, 0.07701126437994742, 0.04381416185248283, 0.05400485111280315, 0.07667626945241805, 0.06811076294510596, 0.0284898542093053, 0.05099739293537794, 0.04880839628317664, 0.034971025081411485, 0.017907199892966498, 0.07978344546450723, 0.09429067628638399, 0.06924038257209525, 0.05425616242592374, 0.03535361322123678, 0.06334963757845183, 0.12174076340611904, 0.03644071879886812, 0.012626527102604028, 0.020304624171506976, 0.0157551430428641, 0.08304484263663331, 0.09301569147576248, 0.03275383639359667, 0.11970118454266941, 0.03513464230983969, 0.006619368345596858, 0.0776515530061818, 0.0252692052538717, 0.07397383301248474, 0.023847857430096597, 0.06086551321430072, 0.016183459928499597, 0.06431873497222701, 0.018789357798654708, 0.05833965621047443, 0.036771998199964726, 0.028254391340118264, 0.07554092714863439, 0.04131211486134318, 0.06078237352231818, 0.053109627577566335, 0.048935551556848714, 0.10151519184751857, 0.05567861150108999, 0.05961123576027252, 0.09810156534395872, 0.03883537175434251, 0.05395144712360156, 0.03986468365896614, 0.07042659311405114, 0.04852650274011878, 0.032281508714321165, 0.07804316949219474, 0.08393711290292202, 0.022994596360912247, 0.06606680971960868, 0.08430213847708318, 0.02582662040367723, 0.019593340262109717, 0.014559602507600381, 0.0278059636888605, 0.05442123139096845, 0.036935194080034574, 0.05705001613786144, 0.0681750760263493, 0.02551696957990287, 0.018595635230022094, 0.04034571792750109, 0.09683673119833393, 0.01625341907774489, 0.07707357031082915, 0.05178113918631308, 0.04018932107775923, 0.005769493863842781, 0.020608602114202037, 0.08582776427389154, 0.02535068253505855, 0.024115637718369404, 0.09734532164950525, 0.029669604714839693, 0.06959989231320159, 0.040407215635622704, 0.0168894540007797, 0.07736702029022478, 0.008694033078368633, 0.07011734640165683, 0.0467125827356452, 0.015214641199206874, 0.03687663048866295, 0.02514358215604819, 0.012490920921517237, 0.047241941830443765, 0.0660398051202778, 0.03213584092595885, 0.023161971250609047, 0.04496067754864212, 0.07905540146654652, 0.010224622167316417, 0.025459897944763787, 0.017792518445921522, 0.015448694466613235, 0.044972211002342166, 0.02683221805660475, 0.035724227406805566, 0.03924145581080549, 0.03960155543961352, 0.022766733083934076, 0.031280769974053386, 0.02516513412457801, 0.028964221597679203, 0.04393070680840362, 0.058124868139143915, 0.06775068629893564, 0.024708063086314548, 0.024805480741985866, 0.058337771634180705, 0.04232069259629615, 0.019916663840112668, 0.021003173784382885, 0.031110037704028433, 0.04503603761775359, 0.031141209821667404, 0.015319044619137722, 0.07400659093212697, 0.08491492454683588, 0.049308843219712864, 0.01633527365723445, 0.06893137334695748, 0.04434667722952943, 0.041616623319925806, 0.025581504826644258, 0.031071449855282426, 0.04313949120020674, 0.06786462655591388, 0.044032623315410274, 0.04462197092511962, 0.055199764413578864, 0.028816726689617482, 0.038648814023021734, 0.04618634161869845, 0.02031042345709378, 0.06794755557371725, 0.039181563056885235, 0.05308077287589831, 0.11149430677535073, 0.021944508151782137, 0.04267501975259474, 0.03651327498617672, 0.009868774326488135, 0.053862500485152974, 0.02055733934074881, 0.028475011255772367, 0.018129530099911556, 0.026244538603350524, 0.04361065825627696, 0.08362595863159626, 0.04555015922373822, 0.06854405461419975, 0.05058377823461929, 0.021193414483399644, 0.07662332511597103, 0.02172865330301706, 0.023345543154244943, 0.06625570401909851, 0.03744967957778323, 0.08979684282695094, 0.011192201749391614, 0.01576930705097414, 0.0444441044612998, 0.04846012122147987, 0.0256811288155375, 0.018628990698245265, 0.009167787596403111, 0.01603966905555177, 0.04424836133576689, 0.06066408188593003, 0.03534646562090324, 0.019350950042867375, 0.03187027463178722, 0.012033450559923246, 0.06534191434301677, 0.03352201956835005, 0.050086357345383976, 0.03412221881350683, 0.047775119873544866, 0.022982578356600097, 0.06002749346436993, 0.03655840139535647, 0.04388250072576827, 0.05582879154732632, 0.0222472163037427, 0.014524722524407892, 0.027658777131188302, 0.015092383142590765, 0.015551328223438994, 0.019580391460969564, 0.047410477343345844, 0.005711017414972547, 0.028886657110565615, 0.030513670813712864, 0.06374255641393604, 0.013848089729435744, 0.015274031207926813, 0.03158500455620308, 0.025563329390640703, 0.038889124313549656, 0.0303622841789958, 0.03445103524192687, 0.046588097278389244, 0.008052267817660205, 0.07251635073654114, 0.06562219527099403, 0.06888656486426631, 0.06273442684041877, 0.05010596153536632, 0.07158163153836805, 0.03756014562602486, 0.044282283709054036, 0.10632949520743663, 0.019238959479656433, 0.03919295478431929, 0.05779172714439131, 0.0857661018568662, 0.05212219003888388, 0.09522476729245917, 0.07177568160958829, 0.0539126715833141, 0.03366422080885499, 0.02376512567993374, 0.0653583852333888, 0.0096680679088158, 0.029458779233297514, 0.04280416302443032, 0.02724528500449754, 0.046544315353516615, 0.006618928802650303, 0.04633981967344881, 0.03259813285342628, 0.024029678822825515, 0.03372644630050467, 0.03180237817427805, 0.03303116405262582, 0.10358264098965353, 0.0708046498438043, 0.0647509004920721, 0.030746161261753693, 0.0457618982651301, 0.020358070295544404, 0.033592779279476216, 0.04565296822317666, 0.052793413295500705, 0.088570244129627, 0.06264868244949369, 0.030824807848060326, 0.063916010211312, 0.048493277506842736, 0.06418716703211108, 0.06324746060155093, 0.052370724283278956, 0.019211619716858672, 0.0356960277103128, 0.053514968528742754, 0.04027747481520619, 0.06654238944212276, 0.042680853512138135, 0.07774584310790224, 0.027715412096210548, 0.024896068723812222, 0.05733159941530997, 0.023810162073782375, 0.07194797478375897, 0.07761995187930523, 0.10858621403214433, 0.07536562324892129, 0.08100932403918236, 0.011938250728792722, 0.015289923701916012, 0.07201702228837437, 0.055646657973768256, 0.012431168936253076, 0.012603814510868923, 0.03227338818232379, 0.05941756873301441, 0.06562431733454428, 0.06575605381400355, 0.019839164470472646, 0.07860701020446517, 0.05674676406347463, 0.05408863814908171, 0.056441064338169755, 0.037945909200296286, 0.07783533749921669, 0.06145722037481685, 0.008281330979849783, 0.08971216712868021, 0.010682770516723396, 0.03285607465753152, 0.021796871517454425, 0.01335005118181148, 0.05556765132613721, 0.019502283051429738, 0.05647632736532439, 0.03441011082501181, 0.05920855313419335, 0.012446775104880575, 0.020487952842226913, 0.09977577389368128, 0.026575080644820007, 0.04947810651614301, 0.10527522032780033, 0.04818796848637923, 0.036381653419906096, 0.03469536366361765, 0.013861467539813491, 0.008302559276231596, 0.04311525983916175, 0.1086183360988094, 0.01677430524010091, 0.048082305809422854, 0.028456948817737644, 0.0969070274262659, 0.09617911366325232, 0.16846287244510266, 0.13564763410437491, 0.13740484061981403, 0.16389560945812734, 0.18946489709759914, 0.11157040228886951, 0.0840158207762626, 0.07563827394117272, 0.148327216626175, 0.15542814688336465, 0.11030952115693402, 0.25930449066142885, 0.12673009487409748, 0.07483925955790667, 0.2435007862626545, 0.1158901192848721, 0.1282027227083041, 0.2318423070133694, 0.1171155458676719, 0.18830841076710533, 0.18100550908955837, 0.1479411695993716, 0.10814932941068565, 0.16413465953401982, 0.16975809729868369, 0.1208715370645927, 0.13700986100781348, 0.17473684143154852, 0.16385214162930367, 0.20629699792592757, 0.12486043431225324, 0.16593102846414814, 0.13633469239838664, 0.1648135360090002, 0.21773875090143374, 0.1305549420536526, 0.13123426285962905, 0.07295081452015909, 0.11059084396448829, 0.1405801524918887, 0.19817232905376345, 0.09201893447748116, 0.1464220325672819, 0.13736638300601514, 0.15395512834431666, 0.17150183598841393, 0.20795551699496087, 0.0683987737002392, 0.09920387393644742, 0.11033902320289805, 0.1924599791246076, 0.15573441351373352, 0.11733160564495672, 0.2487781361466454, 0.2862945343217542, 0.16179279003652836, 0.17331787805643775, 0.134069646197942, 0.18807970287819065, 0.12648605756581793, 0.12009333729022935, 0.15947505230865172, 0.13255289936017606, 0.13098963566364782, 0.2048269364862673, 0.17148752546598836, 0.14490366162311646, 0.15893928105792693, 0.11094380365384203, 0.17777582029661826, 0.141729713387547, 0.12444011251171752, 0.2836967608140361, 0.14247839579418783, 0.2690392312022948, 0.17107443553545784, 0.1582991992754321, 0.15517614992155185, 0.3533491990979641, 0.1353990692164629, 0.15976673262494226, 0.14209784927868074, 0.18741317574054966, 0.17965144868339264, 0.1250307356578208, 0.15995211058085965, 0.12122605191243273, 0.11066070352230342, 0.14313235908987063, 0.14796491832502429, 0.12529696653326675, 0.0916220166630322, 0.12212077366007913, 0.17092345492734065, 0.1702207837614321, 0.09171663618256008, 0.21013065511661194, 0.15758099184641916, 0.19369964728191977, 0.12341451996396627, 0.1652101397274002, 0.09975132036713824, 0.10149223985330713, 0.13440730711144788, 0.12718704333829303, 0.22823384902890653, 0.11973038015346374, 0.18923254263016487, 0.1298958612906356, 0.22425933891246397, 0.18246432435849022, 0.1445163888556342, 0.22977157135403928, 0.16071303507253049, 0.1522445152964323, 0.22464141760381962, 0.13633518269465816, 0.15758494486010846, 0.1204177525435244, 0.22275705581470845, 0.08141910446987999, 0.11491236892799217, 0.24651822273529347, 0.15406173713985952, 0.16172306071366035, 0.19500742065570048, 0.2674131023307001, 0.1661523053001973, 0.18186890550198095, 0.08618331334042935, 0.10294986768595635, 0.11574299975989327, 0.22486338391900065, 0.11231372208004037, 0.23451465151963696, 0.11406778763498991, 0.08724136503353234, 0.1358997689620141, 0.14648161888603242, 0.09047054820844243, 0.12017545425483298, 0.15503091497286675, 0.15411649710468708, 0.07532173407173927, 0.13071574390895907, 0.1499071503959356, 0.17335719368871183, 0.09955348582157206, 0.10745290952223925, 0.08407487083346614, 0.15809970997994946, 0.2112109616639153, 0.11818177937980621, 0.14161997895327308, 0.16560426132092554, 0.17569023785331558, 0.0912529384837516, 0.15421562888208898, 0.08291291463519297, 0.11605815301018378, 0.15918485820293427, 0.16789700926071213, 0.15058118519523453, 0.27541807762557463, 0.1774670102543408, 0.12395195362548675, 0.11723199889304177, 0.1372397333503731, 0.06889974157656394, 0.1532645154023363, 0.1372118324281708, 0.08618707483213756, 0.12417653996136882, 0.17258033456821598, 0.267025615058599], [0.04222179064527155, 0.02560814553421111, 0.04303765130199252, 0.013201438742990216, 0.004183458203765294, 0.03206995353403111, 0.03105928246382504, 0.006847210076352161, 0.026330627733841542, 0.04733584888820206, 0.07878322574880817, 0.07287791359328455, 0.029548876918852333, 0.04466288385071582, 0.054455096307661266, 0.015543829180270195, 0.008452916480300408, 0.01619999019068576, 0.05920612463547338, 0.022879428448035352, 0.05980472658730804, 0.04572327977286712, 0.041133367396410436, 0.04369511944992889, 0.04964650796365835, 0.02106697550193677, 0.018778444876173334, 0.03970652480699843, 0.04042988034686254, 0.047713503421794985, 0.042374678812320196, 0.05311142788418839, 0.04348691207386794, 0.07364846014928433, 0.03523495003220535, 0.020119267283007503, 0.03239796940057028, 0.0705634470608446, 0.007155588236562307, 0.033526290508527914, 0.01302907087524692, 0.050735011651751497, 0.027736330126983025, 0.043932281119088014, 0.015838406266524427, 0.020367148437447125, 0.022436650695219156, 0.09951376416269811, 0.07384149898444453, 0.03536063824750243, 0.020395256203388976, 0.03633431301662519, 0.02984623777710142, 0.03579615157157664, 0.03758322785518343, 0.010214658236251244, 0.08350666342002731, 0.05947689075143107, 0.07903696939108834, 0.00922894248017861, 0.023751650193345644, 0.06677370969085925, 0.032427812355660626, 0.04637776783877804, 0.03022798130499019, 0.030449131736531857, 0.07407223700635857, 0.006356252575173013, 0.01264807715591404, 0.037453042703770825, 0.01649291156941364, 0.008062860898433194, 0.04317003895618743, 0.04725889918664771, 0.02511717510529824, 0.06875675126549698, 0.06111690496665336, 0.05115850122585412, 0.011868673665899665, 0.08182262596223625, 0.04067900064851969, 0.05253969646629788, 0.019994417933987516, 0.0179077189175352, 0.08697610708975023, 0.023335415471885956, 0.009593291981746594, 0.008530946365827996, 0.01630868274538267, 0.07005182290149313, 0.023052962684643366, 0.04516964335174811, 0.016414617383552176, 0.032590035304066636, 0.15163478591749746, 0.042330483199968454, 0.015909229179904345, 0.028931745215349143, 0.01824991315633299, 0.08607163304282774, 0.0718372674178212, 0.05674846477866654, 0.04344984874009125, 0.037842230691063794, 0.13404085661374754, 0.02399421852803038, 0.03926840295354205, 0.05969550160150375, 0.017001402429154804, 0.0382554087217056, 0.06907303832591542, 0.010937846194381916, 0.09752218070770464, 0.009843814224305173, 0.01974079495055541, 0.02227799388610067, 0.05952479422933633, 0.07341972161685267, 0.04532428202970375, 0.04609813808553642, 0.0485903102033321, 0.03563352642701038, 0.011351930123994188, 0.02608641039489979, 0.057346599416867386, 0.05447005034394322, 0.05085828285964747, 0.05778773199586619, 0.011203303321024344, 0.02029349099874737, 0.028329483278456236, 0.07309744374886637, 0.01610627848534815, 0.03071528217274576, 0.010418757465818237, 0.046800449190120545, 0.045693812200859676, 0.05474375823753015, 0.043961400121089914, 0.07450201999275916, 0.0564597032573675, 0.06371501938349779, 0.052360186743880474, 0.04391275353789811, 0.021904370890209274, 0.09208685583284787, 0.026300204467148553, 0.03829417660111382, 0.01700229300636678, 0.029360103278210568, 0.06642904673372546, 0.02097582636070588, 0.055642701129639344, 0.035643972035857945, 0.04155486897234956, 0.053686055114432696, 0.0680103824443875, 0.018374287530839927, 0.04947503067312702, 0.032227495685219765, 0.04995762393058789, 0.06805102340877056, 0.014119265702432923, 0.06084810386622145, 0.05429382713872099, 0.054204620030378146, 0.014336624956359307, 0.05915341395584326, 0.06060895802933843, 0.10506423205257424, 0.10249815926316286, 0.034209744358855876, 0.04784404097365276, 0.016892933955175743, 0.018165490267077283, 0.05328462504210973, 0.04384068381642142, 0.059190768403031176, 0.02073773006427913, 0.019577545444330862, 0.031194198208170074, 0.03959129752230741, 0.07499290615200035, 0.05051450090362661, 0.03412221498306721, 0.008398929306666457, 0.015996676201241154, 0.050901662588359854, 0.0653599250701166, 0.016789006467367855, 0.05884874078835692, 0.008758213051835136, 0.013675932535871625, 0.02293794990457114, 0.03115853490007501, 0.008226750088074516, 0.07184438437463776, 0.042292615473871274, 0.060136530758632775, 0.022989538265392188, 0.06662919486482298, 0.02651608804421079, 0.02149371711927797, 0.02144718110831755, 0.06551315031585193, 0.045199302445736625, 0.012810337451106359, 0.03542358386180094, 0.06322645830110678, 0.07168155238633195, 0.05635003777100675, 0.03676042644186847, 0.017815694520850817, 0.02785136014403355, 0.017164086945535197, 0.02805340242752385, 0.05636226836471789, 0.07676350388435588, 0.016374926368195205, 0.06365706866246558, 0.07200468061191422, 0.004576520201930356, 0.011601263015050323, 0.058327559682150046, 0.06879795147406478, 0.02187437088709445, 0.00938955951677335, 0.07541872846383242, 0.03052379466563223, 0.03926861362772123, 0.019090922564388286, 0.03432732736391406, 0.026008876551303173, 0.05854744606861665, 0.032209251301303025, 0.01661334442155015, 0.01520642203338925, 0.04346245088644567, 0.01502310006593865, 0.033553662830062454, 0.009825249998680046, 0.03930235980078578, 0.01077678195396138, 0.02948116049200537, 0.04320120724338678, 0.01892085296041783, 0.07603901453436383, 0.03327274987954767, 0.060928991259706605, 0.03466572372182723, 0.012394874563230383, 0.04365059058933009, 0.006723295354599795, 0.09321165676679342, 0.02313095426577474, 0.04600865901598046, 0.08340499589159604, 0.05920440476808337, 0.022636772013239326, 0.03247033023545819, 0.05013234943391816, 0.01898260922321389, 0.036543435867755644, 0.033753772656763756, 0.030903395062552828, 0.07006755834745784, 0.0765748700547603, 0.04071388829259142, 0.04504470207217721, 0.028229537532634796, 0.07148509679902947, 0.018099608620808973, 0.04911131127887676, 0.032597860892213164, 0.018277810248095664, 0.04185722089342533, 0.07392419051499137, 0.07911367777494654, 0.03019433089291617, 0.041418838570074695, 0.10153854986832989, 0.1413866898585712, 0.009127661826149111, 0.05043262142627951, 0.02126527353069715, 0.07347812816019982, 0.07674388437261505, 0.03437794279307127, 0.08546215647290792, 0.03148529629763817, 0.05530909665169255, 0.02045043560135509, 0.0843086732070773, 0.03335762859111832, 0.06620599257369196, 0.009015526663842461, 0.04112381811043428, 0.037762136198580265, 0.009370231118443753, 0.024247255454200412, 0.017070258411789135, 0.056011599278257745, 0.06502115332912053, 0.07426475490173025, 0.01048082782466325, 0.040825641368545836, 0.03154984878135785, 0.040812525943282156, 0.04661835009051908, 0.011432137614446542, 0.02252722718572665, 0.056323546450585134, 0.08099141290351268, 0.011880127637977562, 0.06272405400992402, 0.018129798230685053, 0.03847298152264088, 0.03667376274543424, 0.03351354280546789, 0.02783841517333302, 0.061353377156680634, 0.023605664478494756, 0.05756737446532615, 0.02347078895376575, 0.01706519457060964, 0.028460850120492043, 0.038046297361894, 0.06879264248474952, 0.010749659568612135, 0.04625253927623553, 0.025905270820423484, 0.09391515530766019, 0.08489885968306372, 0.01830214120057081, 0.01496105747778089, 0.031075052383746353, 0.07427387900890843, 0.04757937291757234, 0.05045382674002359, 0.04464017317420052, 0.0637379675472696, 0.026115209555193305, 0.06459745308083874, 0.07691471431885036, 0.07626182354626156, 0.038726755808438026, 0.07044753029702172, 0.039344203523209983, 0.013091386382227704, 0.028776660291177612, 0.02987972348027172, 0.057181771769518816, 0.18822856908363683, 0.11951805888524941, 0.17821278152686937, 0.1745810038259914, 0.08940537189764362, 0.06603273412873668, 0.14142156218088445, 0.1238331257275516, 0.0974931076709782, 0.17647026857781797, 0.15233578701173106, 0.14517441241731568, 0.24488267098223013, 0.14675264547188438, 0.23305758293117249, 0.07386487232701433, 0.10528138733559078, 0.1283512518350636, 0.10443122892249977, 0.05553941715568785, 0.16666481812154094, 0.1830808259546757, 0.20991909227544264, 0.11353510371859997, 0.1799873935599481, 0.09787894019316282, 0.14206322210450328, 0.08026555991701542, 0.24142759912196668, 0.14668740542425265, 0.11158655142231334, 0.15264223750320174, 0.10559147674470179, 0.16816702461050403, 0.14110487675474537, 0.11337635497893057, 0.1501108072097263, 0.16706686106420335, 0.19383115393500175, 0.17855900730336868, 0.1786809072138802, 0.21976863875264124, 0.15164917304871545, 0.21728911857691505, 0.12592417803863365, 0.08576797877228068, 0.13038787359912551, 0.24088019865655133, 0.11871105420493311, 0.17305224472957273, 0.09534225453652682, 0.1314360810624015, 0.11969369220276994, 0.13852187342220737, 0.14076801257268076, 0.10727482472336101, 0.16441950634602578, 0.17354246439231982, 0.1606755274077577, 0.15276199236752527, 0.1012102811927757, 0.18854903898412184, 0.08425546073985678, 0.17577466074257128, 0.11562214938983803, 0.15078680319411142, 0.10973669423331177, 0.0712454415136768, 0.11509446036671439, 0.17267333764222362, 0.16078834151548727, 0.07423437185465329, 0.19237967778838452, 0.1708954007875535, 0.145375280671062, 0.16444287202771635, 0.15490985775907196, 0.1908249942766082, 0.06391254749389426, 0.16827266813526232, 0.18296772073353493, 0.13551462591896135, 0.17371227544161583, 0.13160791458381763, 0.13380162267675325, 0.11236248357642083, 0.15535967394469247, 0.14483492821455002, 0.14830352918755624, 0.14734668537012993, 0.10953353537667183, 0.1557272888960377, 0.09933088365341387, 0.18993343647208907, 0.1828839413581356, 0.1743425053334044, 0.1803466428311602, 0.16551087520295577, 0.08050322337376495, 0.21030820365394318, 0.1661171725079898, 0.16713645249124498, 0.15614661478227185, 0.2525402866904774, 0.2105489084797521, 0.27187636122107506, 0.14137715972479314, 0.1660857782248528, 0.09595580669420381, 0.23548278747306717, 0.21283845417201522, 0.19020709840040054, 0.17020687160472717, 0.10109591192655987, 0.2758425822661769, 0.15677267715575235, 0.2277935170117886, 0.13056232714124266, 0.22317584543939561, 0.23887318619076284, 0.23124825179336533, 0.14199405968669923, 0.10399087392274411, 0.15030522500315022, 0.15995727401346932, 0.19252710374853305, 0.16893223919455083, 0.12896034536102127, 0.11137149522020934, 0.11164198554451428, 0.15931222798122516, 0.13122254171438757, 0.17373033979487035, 0.09090197828388022, 0.0921288144684607, 0.23318492206594638, 0.132632817652437, 0.16304581876723998, 0.1575354709019584, 0.14706965265495164, 0.12333922118188874, 0.17030762748852854, 0.12880616250538057, 0.16039782053520604, 0.10270610616932954, 0.18033380319754924, 0.18402950327482917, 0.10057013812324694, 0.1254538460184009, 0.1071962547458468, 0.1636654766456735, 0.1321502895124497, 0.13281108631241706, 0.11747260412742054, 0.13591945742166814, 0.1114768323097979, 0.18952687361067344, 0.19125852343295852, 0.15963088991420885, 0.16409877597564654, 0.25672139539833994, 0.09242998661413308, 0.10843174772397166, 0.20039862652699794, 0.12046629953528605, 0.10367633354279304, 0.18218819562706257, 0.20871818816709906, 0.3009595715951535, 0.23400981489929462, 0.18992752227331364, 0.12032728522054612, 0.09285398563670536, 0.0785098166295117, 0.1166040596041468, 0.18824888573538875], [0.04901502168767395, 0.07427531925420608, 0.019152544761797594, 0.06110657810143406, 0.04868214882369484, 0.046564134048117746, 0.04370261178982835, 0.06591243534198692, 0.028442917917404446, 0.06382984830246818, 0.029745918563416893, 0.05851180765837912, 0.029877233694517807, 0.10627537875646546, 0.035152415549683, 0.022685183024394418, 0.006683700579038311, 0.017819953969709815, 0.045046931388036865, 0.01752059745241798, 0.02372842815314089, 0.01118439052539367, 0.05712141553240438, 0.07217823783115995, 0.029441680150827574, 0.04112094528071823, 0.023742855503974904, 0.029371433718610677, 0.021557756324088382, 0.010426736271549619, 0.047038683382373665, 0.030515934603529114, 0.03371028184530235, 0.0640444946475327, 0.03348279969706651, 0.008882523266478412, 0.04864725351874386, 0.07046811507954713, 0.06657084194763054, 0.038949921051220554, 0.04241148167620263, 0.08255628538468192, 0.027805358479400317, 0.0034202794983772744, 0.03737181823159899, 0.029086895256994233, 0.04833243351670043, 0.056651481877892255, 0.04551806780059011, 0.012592481197639099, 0.02456977463988287, 0.08894502966394348, 0.03018943559108002, 0.024404291987359047, 0.02992296914359735, 0.021374025457208196, 0.10246162453005392, 0.03407649102530653, 0.006278479807905012, 0.07072646291025224, 0.004816303807010334, 0.018815387551101948, 0.037303035027317466, 0.024411150389501167, 0.017322969750591347, 0.04025366863295917, 0.02844634041520617, 0.020255561985616243, 0.03398434596977407, 0.04510620361073844, 0.0810582617357854, 0.03164055359159266, 0.11363124775309717, 0.08225306012337247, 0.12928669881676474, 0.028292224592258854, 0.03482330034697249, 0.03194840410874496, 0.016327970924096245, 0.03240777149556145, 0.04996812316559015, 0.05631855538775844, 0.03718133813010589, 0.041274603366130785, 0.06433890606727331, 0.026227447181759823, 0.05543704099592663, 0.02716463509826891, 0.1286179040588679, 0.015491490053283352, 0.0292263443266312, 0.023755723865883007, 0.07697635375323796, 0.03711416754090498, 0.05859791977150787, 0.03191467708787851, 0.07350837331145041, 0.0159517805760486, 0.018447841547669905, 0.07982262320095494, 0.04929492340212868, 0.04251794108460027, 0.05214691552664003, 0.0314821170327524, 0.06792589826809783, 0.0396371670367737, 0.01693356534345977, 0.047233097345357945, 0.06530685049872245, 0.022017868731411237, 0.029065385423300248, 0.022545553924095248, 0.023262476240615212, 0.02791652549809266, 0.04444875461500018, 0.05178007432409833, 0.07546113143044134, 0.022891563280755957, 0.07862317465966748, 0.05955342676550631, 0.03719498598647695, 0.051815417790485006, 0.07076194044202566, 0.00846532135901432, 0.04392518714490918, 0.01690964041758449, 0.04610620882181872, 0.025744355967148178, 0.05729446330318048, 0.025143603223466107, 0.0156217728809063, 0.12550003345935576, 0.015191991809725523, 0.01966614542799371, 0.03642621675446149, 0.08671936038280688, 0.014550131745636465, 0.010667088696913374, 0.07564939753783327, 0.0832212880073536, 0.006780075876327653, 0.03716536136644502, 0.008644434630930906, 0.041008184799143386, 0.021196789100706097, 0.02330300612224927, 0.0542203976111787, 0.03327251239229114, 0.04749487341952421, 0.012332886558837228, 0.08593919942335737, 0.07023900882491181, 0.03303747278668227, 0.07055602366885833, 0.06364020706725217, 0.0026595953667926933, 0.12698629765861458, 0.1030845536039241, 0.026435602846885883, 0.01625782025286988, 0.028925166435299382, 0.04534264515724875, 0.06224826361323076, 0.03456545813429741, 0.04926425690251974, 0.04938303883517942, 0.02614543938468541, 0.0485714644403948, 0.04211974773375739, 0.0549922886514856, 0.00989894095372649, 0.07975826415443614, 0.042219492381498705, 0.02285732298098024, 0.04539742810471405, 0.08643161009756789, 0.027958457320628148, 0.05302066944779889, 0.04261700391408898, 0.02731886774962468, 0.013065155531700342, 0.032486578960332184, 0.10387129525864318, 0.0506170685853689, 0.0434081927092085, 0.05408576531936565, 0.028186155888702602, 0.03291504810594263, 0.03313387729107373, 0.06346504872424469, 0.07109411616599368, 0.031018465299219377, 0.045570713362746665, 0.054805102728066914, 0.018940639096282182, 0.005609308709315355, 0.025510153312596585, 0.02487975871190429, 0.004674206467180123, 0.045749541266911456, 0.06708406723074375, 0.03368120880857591, 0.040994690160357186, 0.07790045497278053, 0.029644429150428024, 0.014410760242401835, 0.03547121154805345, 0.018808111631041093, 0.03997187468133146, 0.028588830853902528, 0.07011092658485137, 0.03183508821342501, 0.02175700813231449, 0.07616801607993341, 0.02693311566667211, 0.0443064920874613, 0.1057303608244946, 0.021957575696550553, 0.03969209171050499, 0.015433630305192163, 0.08168968672473585, 0.03633673385446591, 0.06101436792842804, 0.03112413180661538, 0.020685978909774173, 0.05678119971567104, 0.04430770250638166, 0.054639014866082906, 0.03769711065556734, 0.020108666541355274, 0.04170159013160775, 0.060993859754695054, 0.027128764946434288, 0.040520217434893695, 0.06403528627068286, 0.07978230399350006, 0.016696191084901654, 0.03250657002471628, 0.05284452285136908, 0.07762731398425757, 0.08593326990282343, 0.055309789961264025, 0.057514583346463984, 0.06159010598616255, 0.026008114293818514, 0.022251069726001833, 0.05863494863132796, 0.053772194040638786, 0.010646410068617234, 0.019337646926062244, 0.09082216724392869, 0.07071377649422615, 0.08557179897663095, 0.021810697489267877, 0.06410248750340074, 0.004103280878024957, 0.055810960850888686, 0.03182831216573475, 0.021790313804822586, 0.048441612537229256, 0.061831975265616373, 0.0672936152606722, 0.057899328023796125, 0.047925840011767806, 0.020567899862785014, 0.027525918332919962, 0.016553311856583725, 0.10158427765653019, 0.07719344008834132, 0.0332878073376994, 0.07305248970946959, 0.023173430010736473, 0.008153749569769829, 0.029621952130729635, 0.11323715680308881, 0.04714187542577425, 0.04606909569232695, 0.0720058067611629, 0.05895443027839065, 0.02172460835877686, 0.014441549316078666, 0.026294619686180548, 0.03913259088632561, 0.03289632874751284, 0.10922683973706539, 0.0484638482392315, 0.02374660933480388, 0.013168410777354674, 0.03712513791998068, 0.04693774363747047, 0.08085727856885042, 0.032826266176397764, 0.05139718740998257, 0.050934975921747186, 0.01309659194967319, 0.06645569893261118, 0.020411154443037607, 0.032504551383035804, 0.04335591103881598, 0.07762862399460808, 0.025483581552942915, 0.02701904391869903, 0.033921603368775505, 0.0034692162373704057, 0.0853190818921693, 0.06866114349254678, 0.0033397100313806967, 0.01689546587576549, 0.05295025447623865, 0.05464610884026174, 0.04349239343296617, 0.05761468805552972, 0.07202633025665438, 0.039118356972692475, 0.052965265969114925, 0.031066115968109622, 0.016535448601409312, 0.045384094344391945, 0.041762042129712726, 0.025934315128852765, 0.07974026874909479, 0.06002450572146524, 0.03849751165797634, 0.053644035191785906, 0.039729465309891014, 0.05716191094008185, 0.06194282052738052, 0.026894516326607238, 0.07789234210166239, 0.06577003491862167, 0.020720154092076327, 0.0265951961984918, 0.0875966689519344, 0.01174675843362967, 0.032587648940182505, 0.03864288833292742, 0.025779984801286654, 0.060251528216946515, 0.06853515267251961, 0.030095137828480334, 0.08114816215369972, 0.0095088537707324, 0.06551182498374293, 0.043308176100254066, 0.03449196731972118, 0.04522035454189585, 0.03237120611893554, 0.06893822983387979, 0.012723403708678822, 0.023269696619301554, 0.03729301459726788, 0.04449631718377914, 0.14473696089079305, 0.19331943784509936, 0.18038886959754652, 0.09902699955648954, 0.18842635766392757, 0.15757026661547924, 0.17604953308980312, 0.199801261807161, 0.1918360464755566, 0.0906915186093219, 0.16097842325125972, 0.17535167295605908, 0.09883734682995467, 0.17419926221332244, 0.22141405771816933, 0.109765192704095, 0.11817971094241066, 0.14790998982085338, 0.14468437661567043, 0.08922421508618901, 0.07856933400034904, 0.17820447713377016, 0.13481806813468858, 0.15593828483214303, 0.13146096359818213, 0.12012805639495773, 0.13042662232633562, 0.17051856213759992, 0.12426287040955598, 0.055045696471126816, 0.0905408061319782, 0.07848978343029177, 0.16400667688538953, 0.13839821150947001, 0.15008863662519764, 0.13540193438529968, 0.1557779732731081, 0.17665088146684632, 0.12798929061259956, 0.16122170213249423, 0.19192944791528488, 0.21479502740886905, 0.12193764034177988, 0.10816468947356749, 0.2259297476660821, 0.14201429972965873, 0.10797507505142882, 0.12938144857123976, 0.19829933110985065, 0.1259392240054665, 0.24717036274171647, 0.17216045709867633, 0.15734086924743268, 0.12791019969529685, 0.08269690848406284, 0.11874882233960014, 0.20176393310389212, 0.1324093344831659, 0.14076838029488442, 0.16517684554621098, 0.102155166377704, 0.10563942618788251, 0.20230667575472788, 0.21846230562415817, 0.2931192439169653, 0.17179147851082588, 0.15574680881634836, 0.09368242545714302, 0.17488625922030018, 0.16658111535493406, 0.20667063432835764, 0.10707609385492341, 0.18403232247839052, 0.15507809066724393, 0.2590556959471395, 0.22691173448918328, 0.163960910792793, 0.22467469646325036, 0.14927554154588332, 0.19709206847173555, 0.17134478796393643, 0.1315501362325684, 0.18318608643547182, 0.10843458224929149, 0.22726258743674527, 0.10607879293421585, 0.16913986434378933, 0.17106576342015498, 0.21340364319903238, 0.14661838090227497, 0.1379327518084357, 0.26074749387560353, 0.24265857984221753, 0.09212371232288499, 0.18335387501264774, 0.1060383894570893, 0.17490643797622574, 0.13681994781138437, 0.15051439764999575, 0.20643457199536985, 0.15374483720910165, 0.17107146311431162, 0.1408481453695605, 0.08497456449174112, 0.14129658259691733, 0.15776347398998278, 0.15551261573789582, 0.13550440630605146, 0.23332480972091998, 0.15100247226655483, 0.06907341370899832, 0.1572497047844433, 0.10713245494351273, 0.15996639045976824, 0.21120057351166205, 0.15736616547069243, 0.14934680304459988, 0.09865451994682513, 0.20364470960151768, 0.15006304928852668, 0.21082010360494738, 0.19357593940390697, 0.1604678103279683, 0.2834897945004125, 0.06980384790128277, 0.08336145911485919, 0.24433484150757714, 0.09367104139058821, 0.3096692864933322, 0.15440862175197373, 0.0809606851168698, 0.15424679333884872, 0.1550018036317441, 0.17686089681040856, 0.1231288304552436, 0.09533320703814108, 0.11421830859035255, 0.09577886336633275, 0.13170350703500933, 0.18498309887945655, 0.09070843383069001, 0.1283057921776368, 0.10103913715049144, 0.08462912012492457, 0.16612242787115036, 0.14257476965506233, 0.13645392632292164, 0.1368737884707028, 0.12946853744647197, 0.11186598199269465, 0.1788737162226631, 0.26872259174143115, 0.20160578191280368, 0.23485663316903577, 0.24848287053886922, 0.12832107563172618, 0.21060653361341647, 0.21872868971718898, 0.12256872059116442, 0.10430692349590602, 0.1690589654589853, 0.23101822623322088, 0.1567285504913138, 0.1402730891300786, 0.22854204620084456, 0.09630956311499882, 0.18520123475501615, 0.13561101510159432, 0.12383164717785775, 0.13246722008672454, 0.07831278647626601, 0.14169418222961888, 0.08153325157059778, 0.08763953157129788, 0.22991459996950245, 0.1908538451478366], [0.028831966093651233, 0.03463578117530673, 0.02116966767296676, 0.03726303374635116, 0.07615520708983944, 0.05904407022641071, 0.039465728050638596, 0.01817534407300334, 0.02095080401387907, 0.029881261401779713, 0.014751994956074464, 0.018086150371199174, 0.014719198732036016, 0.0167398504357064, 0.04157460722771864, 0.05396863430618279, 0.04534803458579606, 0.018305490920019728, 0.02611833902436399, 0.00364661299353165, 0.06953593163240342, 0.05245042041004185, 0.028436737503075314, 0.030836113390602896, 0.03540525520821253, 0.02458903025985966, 0.06806537989647159, 0.03795797125466409, 0.05568726446419474, 0.02156260757586889, 0.09174771636964814, 0.04101753873269885, 0.0857743909282069, 0.04452147551121251, 0.049063656779546896, 0.046274181260096456, 0.02507557078535038, 0.026476362554897225, 0.06358930052468373, 0.028172069446994897, 0.043470448844375155, 0.03629281403376691, 0.06747725419700146, 0.030048760780764204, 0.05910670174466026, 0.01983728947027797, 0.012025665191392745, 0.0291568141866235, 0.0473941098748436, 0.04486076819199709, 0.0252563905181183, 0.008503645865036356, 0.04290956140105282, 0.0566318393835137, 0.0336324549730747, 0.022126078650715853, 0.041566731843857035, 0.09373578348106916, 0.055893441707256346, 0.12800455874493047, 0.036227673577565345, 0.01529714120777264, 0.04738271814740954, 0.03203876609463365, 0.01190112610798209, 0.041225520112822135, 0.040435346384202285, 0.03163396715066366, 0.02324849130555747, 0.039814692591467214, 0.05974555395603661, 0.025728361966509013, 0.04145763709299988, 0.07222932057395097, 0.018910955104436127, 0.02519104896383661, 0.04282953968692211, 0.12839389228892903, 0.07006706039030706, 0.06885386057077877, 0.0641710447117446, 0.07998008491291154, 0.06795134004806319, 0.03222509783001677, 0.03894795220525515, 0.034528559509424434, 0.04358903159417453, 0.04326144856731257, 0.07747924451025263, 0.038618204980007106, 0.04559738471383049, 0.028598847453512495, 0.057886496051064426, 0.03925382813078262, 0.02124429421289073, 0.146632201128429, 0.034834944883421544, 0.09373315579948888, 0.03482117062254298, 0.10325181358043226, 0.06716750952745638, 0.08363236312664325, 0.08819991722702981, 0.005138041104205074, 0.04166798951524881, 0.019609786254624208, 0.02933536629913555, 0.024460750752158707, 0.06064817790062197, 0.04798758669846481, 0.04191406461740694, 0.019568593706935644, 0.015404719104539725, 0.03996528632518265, 0.04980196635569296, 0.029657716945474668, 0.02236387234241251, 0.02487688779740805, 0.03463183965293631, 0.023550159493160826, 0.006939714235599123, 0.10216110355911717, 0.04304819650227024, 0.05897715244622481, 0.009973515782715573, 0.051392008655614434, 0.06366873618155237, 0.04522793498190661, 0.02174771357057316, 0.03860964011701365, 0.014814521137234426, 0.016871144499389396, 0.03282048987344869, 0.030154170648705576, 0.04475839203223587, 0.042555893080369125, 0.024699371818813588, 0.028491020578170018, 0.044926130813696695, 0.03715738256071364, 0.08146869334121866, 0.04682343182784896, 0.011432262103734239, 0.045577428123402985, 0.05192951892592734, 0.02309039374062371, 0.03338699657169562, 0.03844297768908643, 0.061797168060776696, 0.04235376844242696, 0.010791624907494314, 0.059792269997659235, 0.057228384389271664, 0.05981652051090233, 0.019537243473854278, 0.06865027270490123, 0.02980477326819974, 0.0637034437949619, 0.029571777202128887, 0.01839539325315385, 0.02659829693936533, 0.019335392712345047, 0.05251812726078976, 0.06340019555101473, 0.032997551944948016, 0.07060903695321853, 0.06627999666717745, 0.06123921090376474, 0.028610072556823015, 0.04393603878035661, 0.06044624478466088, 0.0046845357264241865, 0.0466874014255741, 0.00854351978388525, 0.04044034510790821, 0.04809970749662288, 0.02298868024691699, 0.015517114736740629, 0.041421067885934346, 0.07097740267072955, 0.08195074650669291, 0.03169497264729392, 0.017644807118021192, 0.10535323872200905, 0.03892339525684234, 0.06407288203556692, 0.006415869058635567, 0.06998497406922041, 0.08177139000186036, 0.10539509010531249, 0.06039093323652783, 0.05852664295103281, 0.055582823697477586, 0.014573354743451122, 0.04054884614062406, 0.009165418469497274, 0.02072119597165335, 0.044303971658190416, 0.03752048525418486, 0.02217502400819813, 0.019679574949306347, 0.02646025555628923, 0.08578855589392685, 0.049538282722595244, 0.07000239490861855, 0.051573356989050106, 0.06654929955519977, 0.046547892984123006, 0.05640064553928472, 0.02770304169145323, 0.016148510997393922, 0.08822230997705653, 0.04440586518255934, 0.048590145494428374, 0.02898084953607571, 0.02593698303004907, 0.06374050329829897, 0.017070174142117464, 0.044098594977009686, 0.050301903843759536, 0.04761062164400374, 0.05571816079018097, 0.04265048961725928, 0.05041705068921851, 0.03207019676694707, 0.04794572765428213, 0.05312641256398732, 0.03016870908228861, 0.026234336227418917, 0.1354241969003793, 0.023760360613044713, 0.036196018824534076, 0.053475197074153734, 0.03880597696068787, 0.05877311641891157, 0.01963582175273088, 0.02830617122292038, 0.057566604546962254, 0.007463074861950572, 0.018310227258611592, 0.06749609995993876, 0.05350689013158122, 0.086775652523483, 0.015309256888295134, 0.0115970533619064, 0.021772182418874676, 0.08431670180852376, 0.03964942827400181, 0.04151721192043155, 0.03788937191148439, 0.027351039612004836, 0.022379123237765124, 0.05474612161877656, 0.04520259279337141, 0.021477870590564226, 0.06407597703078101, 0.06918199901138583, 0.06617964680997596, 0.07678772758452163, 0.03219068516045809, 0.014926053005300704, 0.07673199468803021, 0.02118418120869225, 0.04731347912081307, 0.06630750688453836, 0.058027080846049135, 0.08954203432245601, 0.03897850762211508, 0.11404543318935942, 0.02451735315844417, 0.033210309883279186, 0.05671250461150081, 0.10475430352192734, 0.01906725810840726, 0.1784460246562958, 0.10961616562018472, 0.05806692124855134, 0.019137341746940248, 0.051589927470852295, 0.04612380969187906, 0.04442058939246401, 0.0053684190647946975, 0.043556783123001944, 0.02296242449853209, 0.03756007284767205, 0.03751674674511437, 0.036085763450471625, 0.032041135221539487, 0.043199422258523204, 0.05466968902657109, 0.027996482094749812, 0.010470231871060547, 0.0622504890986508, 0.033545113288827484, 0.019506450569737824, 0.03619277061173513, 0.02058982529917792, 0.06800844424193905, 0.0518188345426273, 0.05700022808366245, 0.034801899680807706, 0.02935105961026444, 0.04138993407269159, 0.030775339635569724, 0.034209131488516446, 0.06174417009817497, 0.02871543837470874, 0.023560834928385677, 0.02881038348160444, 0.09035457781846486, 0.043847027024434465, 0.08838154135211822, 0.0341883973188458, 0.020514725699960705, 0.030509501380184968, 0.016844074782584945, 0.05800510178350153, 0.041137094414162065, 0.06355151706825822, 0.030087950008530772, 0.06883525995597725, 0.07737517912661837, 0.07063195064303375, 0.053057407194207755, 0.03826429534162726, 0.022047560384136536, 0.0798135603808107, 0.055089945709633256, 0.07830430588294422, 0.021458749035974185, 0.04025330091075551, 0.0294891124846594, 0.03992621201060472, 0.010846115783938478, 0.03104120278881202, 0.03374452980595731, 0.036861147851713245, 0.06540617379810541, 0.03344950551587728, 0.026670571589361758, 0.05116476399463512, 0.050949933788468765, 0.009088757008524432, 0.01789300236850977, 0.06128523363581589, 0.027233002699851513, 0.06099316261468395, 0.023815754515629624, 0.015857618794055478, 0.05171176992476948, 0.06791621491673493, 0.04146586487730665, 0.07695443597772429, 0.11345009094164257, 0.15728946474771346, 0.16567061985692672, 0.17020982870411488, 0.11571276226952193, 0.12862591733855586, 0.19924983171926391, 0.12020711666874348, 0.13352371662134124, 0.05421379393327141, 0.17264048779203048, 0.14270701175255163, 0.1469423594854532, 0.11235976396428962, 0.19394925404940883, 0.10772004438143586, 0.06825010667765333, 0.12158626645442941, 0.10850723802803025, 0.1335597687190579, 0.11152953149810915, 0.1602788317588068, 0.11057831076604706, 0.13238491160013985, 0.2139373306906031, 0.17828798071751673, 0.14691300299619475, 0.15856579787308173, 0.11157695234062211, 0.14057518824213935, 0.12731701015464722, 0.1754862133173212, 0.19944434144323875, 0.11044748593121768, 0.14082977458113624, 0.1468013533421101, 0.11864831926481378, 0.09524355942924177, 0.15628791203902614, 0.17780465584608818, 0.1573242451394758, 0.13541177095424745, 0.20942942419600105, 0.22023797485857244, 0.09433906239968154, 0.12365612877352584, 0.1273550004548123, 0.09173067857421215, 0.1868213574972845, 0.13573194974132125, 0.07513492353140347, 0.12836096582994347, 0.18968471836659218, 0.20048317199032153, 0.11660642681583283, 0.14599374345233365, 0.23226742452431112, 0.17863785307253563, 0.1789137366558275, 0.09602462437244193, 0.132164875826528, 0.13027133630408397, 0.09085360749234116, 0.11559471578126955, 0.146307977397115, 0.22506005401092194, 0.07379797752946615, 0.21847062533901584, 0.10431557262857115, 0.2814026339159858, 0.15990897983072266, 0.15541205903695476, 0.20434370354538967, 0.15156455097659943, 0.19176838559008416, 0.12211918785807588, 0.2584937857764383, 0.1917780229761716, 0.2646753798809744, 0.20519410710661642, 0.16560449114730283, 0.23927204220766024, 0.0919201857440414, 0.21200859708891762, 0.12343220127325867, 0.12790979366869698, 0.14304372271703136, 0.22541242381257398, 0.2152179692301058, 0.17170480332307278, 0.16942638122747022, 0.18398548386270003, 0.17552768931754176, 0.1110308159202818, 0.23168236317653812, 0.21804497156652713, 0.24203651644770177, 0.29200774226938525, 0.29253824283519103, 0.20543974553865774, 0.1130061889547975, 0.26583603372977627, 0.09628725463464376, 0.15916210539158315, 0.17424227038939155, 0.15870139543567935, 0.10114883328036917, 0.14670485690716775, 0.17853420137638049, 0.16802710631201345, 0.13053016677018137, 0.26132009863372774, 0.18174714348729581, 0.13269932940602303, 0.11862338310287845, 0.1900897184086423, 0.07594353699636075, 0.12166760200935027, 0.2559117477146849, 0.09939327385396728, 0.2424424511170195, 0.16603428179458266, 0.1934667871964555, 0.12506618254607724, 0.17137083495336194, 0.18220414557764608, 0.1735440731769608, 0.08473192912436302, 0.20111150198405792, 0.13351734276981125, 0.09729797741578472, 0.12846850159187473, 0.19019179196367342, 0.1979046885765368, 0.15024121069619734, 0.13284730694947705, 0.17544968624509152, 0.1034264969489267, 0.2103594855795945, 0.2014475234694058, 0.12556828423252991, 0.13268898721904526, 0.15735551684854493, 0.20072429050360957, 0.14997577655219263, 0.12190505096148099, 0.11681387576484874, 0.12379024778642964, 0.12062002273817217, 0.14283421299149915, 0.17445384855231932, 0.24294100581638275, 0.14002613302680755, 0.05969943929343455, 0.12486434136066707, 0.12382482133445241, 0.17229703525381704, 0.15796866297962206, 0.11343935038894416, 0.1471271705363066, 0.17180542131104778, 0.1629683059910613, 0.09503194296191778, 0.0953380257311848, 0.1714125407799598, 0.10974062426436333, 0.12672327669157138, 0.18580031551180348, 0.14313934581174007, 0.21313289240483316, 0.09221730528459435, 0.1085735046334805, 0.14825819210419733, 0.13093607079598213, 0.14247455003280796], [0.029633058490411892, 0.022262419318600048, 0.060232165344660325, 0.08749291000346984, 0.03067458949742779, 0.07242398351551065, 0.07790971697578508, 0.0785562951838778, 0.03418624844221819, 0.014813168034438166, 0.0284996792869342, 0.04970070485386157, 0.06418800589838816, 0.010147954003074238, 0.04616946853216618, 0.04895096907632486, 0.06198587466872508, 0.049213779369188894, 0.13459196494471642, 0.051254449907930634, 0.05826228899100135, 0.06700737416864404, 0.07387921349295686, 0.10081728574849906, 0.046269508123758345, 0.05027103433085065, 0.015514010165427482, 0.08849030285472832, 0.06376044839740762, 0.06796436354277596, 0.03043591671983802, 0.03138265009188364, 0.023201076208703944, 0.026937658568063093, 0.019386157528647495, 0.010422474907470808, 0.029926058393152013, 0.092579948325311, 0.06625991750268206, 0.0762129701193302, 0.12968638220862036, 0.046162964445689035, 0.028542886645863616, 0.013122769174045854, 0.009018273089051006, 0.0381638995191503, 0.030052250311259302, 0.011510844530177214, 0.0331868675927962, 0.055765911050501375, 0.07944581519451835, 0.000570001375895264, 0.04309642939798294, 0.024914052637834704, 0.04231713411788787, 0.06233185529708863, 0.020736914180639773, 0.03762965278339483, 0.049619484212129354, 0.11051507786877694, 0.07262178741755985, 0.024750467968143286, 0.05001251413036258, 0.07010804609425607, 0.07391364148427403, 0.09739931552640854, 0.06378132046290463, 0.026875233893553098, 0.06208242856026177, 0.028794182637225718, 0.029043492545644124, 0.037977931675531214, 0.012868442347333317, 0.017965698366864555, 0.09324652908910668, 0.035238830267541835, 0.04181756818246457, 0.04192856283137395, 0.0031880725028684306, 0.11898414156730137, 0.07261879201377593, 0.04500284685843414, 0.16318300979272013, 0.0267534259135925, 0.05155500535282397, 0.06962978506400701, 0.057879398246445966, 0.036752413162180496, 0.0786835270663423, 0.054235056703609806, 0.05190203552164378, 0.06184185396939997, 0.007879607878895778, 0.06801196058551151, 0.048550998401497646, 0.03288967527389046, 0.0641107497616641, 0.02857900577627363, 0.004852089689173286, 0.019178055489676136, 0.06712721330263922, 0.022263857648677887, 0.008605728038556634, 0.012720975209958853, 0.05991363747706337, 0.05350761791510929, 0.03160445552860056, 0.010730072615608093, 0.034319723941265576, 0.0765904063178647, 0.08081591748181852, 0.04346595190825962, 0.008544263846781707, 0.056272038528996135, 0.02826557813903257, 0.04657224691923588, 0.05448875438061453, 0.04019132822812085, 0.044849035555436734, 0.09074212637759986, 0.078919681329881, 0.05762765409364816, 0.05902959499508143, 0.02101303333596837, 0.029430094986192645, 0.024237020519532027, 0.07285553616501632, 0.1234611823794342, 0.026671496640530326, 0.09642636854081385, 0.06864929211235817, 0.0444002382667555, 0.03566805784019732, 0.047926544812658144, 0.04839375502459946, 0.03880690392707625, 0.044421750015669295, 0.049058248198801474, 0.05494334329400332, 0.014955109762658757, 0.03218525359707494, 0.034128922082844286, 0.06300497845175766, 0.053137195251521566, 0.050220518493123596, 0.04456837924437658, 0.08923345410655584, 0.030794053248340086, 0.13331201588434557, 0.010679617107305075, 0.01707598683424294, 0.054953275623941616, 0.018202827477286902, 0.03028738184741909, 0.030326484890294172, 0.05917840374393329, 0.08016547052970818, 0.07506002311504657, 0.009920613581104385, 0.03153200850882117, 0.009757851498321661, 0.02188958347805085, 0.07615020453569389, 0.08603618615457127, 0.024342202476315924, 0.12106329653291933, 0.04487085373952024, 0.05293147766121453, 0.032602055223598596, 0.05208757052558565, 0.035436848674209855, 0.05506198733083664, 0.04285019341736071, 0.14111359483532368, 0.02050064500391243, 0.02545660568190919, 0.021455510399274288, 0.08472206957277753, 0.027654919878489552, 0.017896819401592497, 0.024291780484359593, 0.029901966843153202, 0.028129835019729314, 0.03861743889208283, 0.0586099703345568, 0.080925322498285, 0.0656519194824561, 0.07474178253042121, 0.06685997885201247, 0.016624443120353164, 0.039732479865873055, 0.06945301793635854, 0.06925745867192745, 0.03929598977969539, 0.07873044229082524, 0.05728482974753265, 0.07782949224835442, 0.08872330083601898, 0.03731182205580896, 0.0660579001170493, 0.019125082424931952, 0.011508100977798384, 0.04735157284284792, 0.028011053087069627, 0.07072023461542784, 0.10027852675486958, 0.08587662536170214, 0.055851410293290694, 0.04310121744750969, 0.022823708958082625, 0.03137654820156675, 0.02768187659732517, 0.06756903153033027, 0.029238601733419686, 0.008835919265214716, 0.017571138188002572, 0.05132550839334727, 0.0405710818426263, 0.03266629169604952, 0.011391761908007246, 0.060713800992215836, 0.028366232516183972, 0.029730573822293552, 0.0013122944895463486, 0.01730086045309661, 0.028741489194573897, 0.014483502206032076, 0.06106450455263258, 0.01620873891478104, 0.017312269417508956, 0.04689535216218041, 0.016919377395102096, 0.04591522693273522, 0.03977263819486384, 0.004088539909946943, 0.023993159411475066, 0.02007776830014923, 0.0689214984736135, 0.06001692528145448, 0.08823959292062829, 0.06744167707379788, 0.15087093496995588, 0.04864674790071384, 0.05256114692817773, 0.08030075399625687, 0.09641999468928385, 0.0495278409441873, 0.04335066333653466, 0.05142376300007586, 0.0387637808378185, 0.055721711607710014, 0.007817179373946161, 0.05014010990459112, 0.06742359739878485, 0.04052392147000759, 0.057903706216283386, 0.03020781404038351, 0.03032431686146846, 0.08849828549089933, 0.024777616208959973, 0.05150347444859724, 0.04010569491994478, 0.01984633696866372, 0.08691586959626406, 0.02925647073425353, 0.07560390723688949, 0.042778629313914046, 0.057309041956379536, 0.04624261077673686, 0.026006641489784085, 0.04332455506007518, 0.01688672481254945, 0.038769380940544995, 0.07388649898911677, 0.15260039378077755, 0.10926279990423111, 0.09323599538014782, 0.040381329524661266, 0.036734295182771264, 0.02234616613526258, 0.004347944463182602, 0.018794015613234332, 0.03356150757040709, 0.012601326640334823, 0.015448082553883715, 0.0425274865401368, 0.06056496926072625, 0.06007848810704966, 0.05468063642300906, 0.020338703592818592, 0.03649179005034028, 0.02036208076582801, 0.008116839453577995, 0.029773788842102213, 0.00964477979352758, 0.00482314162053949, 0.06207002942720729, 0.06514453945020515, 0.04922560393630017, 0.071242292892308, 0.10607464073766625, 0.07843258730586498, 0.0090323748525172, 0.024056449765339497, 0.03066981485443971, 0.0741284065729668, 0.0073209463997984375, 0.018081534691455386, 0.03846560792636968, 0.0647731247027555, 0.05653081153849921, 0.02990395484131671, 0.04723339995008804, 0.020831558598025192, 0.008666365812983244, 0.027605007335002867, 0.0419854142162348, 0.04859761868212973, 0.09233109232398773, 0.035615814474201014, 0.04608128415120225, 0.022178795076005405, 0.011332047269529393, 0.06340384595997392, 0.028429773763843605, 0.019064241637205406, 0.06628958808798945, 0.05245385248394263, 0.026580081283745748, 0.010664075098541236, 0.022450139588345925, 0.040667455703500784, 0.09371521402030222, 0.04059680324468402, 0.007225337669238329, 0.046912861101689844, 0.029324610424678654, 0.02657185924509841, 0.047560469698040723, 0.01326469366528815, 0.030887676853566404, 0.15937140061249658, 0.03401002140655633, 0.05852488860968621, 0.048096390335910746, 0.041319086261454134, 0.03940538330484302, 0.0252669855141111, 0.07892069256594104, 0.03346438677380643, 0.035378392335147626, 0.039141837567571676, 0.09199328585377625, 0.14935538322935182, 0.13453136738990584, 0.12999857835952314, 0.08761194474514454, 0.17331829174391686, 0.18982483584794307, 0.13450201090064742, 0.13445921722919713, 0.1624190056275937, 0.13451143378211608, 0.13017949768372122, 0.15978262128849186, 0.11106416372762573, 0.17518040633970694, 0.16871883774236326, 0.18507096916437152, 0.23806598998846548, 0.22279732139600864, 0.18973328834099157, 0.13825179678538155, 0.174957811832428, 0.16800122786193125, 0.2262159274710763, 0.14622353918610081, 0.10400162213632178, 0.1398550809150742, 0.22888094817678775, 0.15204747748230735, 0.19066535687494665, 0.20064873891251706, 0.1527448166762629, 0.1210266009213463, 0.11525474128223236, 0.13364710274242586, 0.08802569351128994, 0.10194500547743614, 0.09657193290730638, 0.17705825638146172, 0.14933704308444454, 0.20764632390872126, 0.11150877817624039, 0.10149989307167069, 0.14656345239810406, 0.13762299181713214, 0.14297578603990618, 0.12302301839114198, 0.06398368641854295, 0.2012729167097038, 0.13090600950583337, 0.1956480540215008, 0.07714280167654639, 0.1790354373834787, 0.08232499577946241, 0.08234535839648978, 0.1733924643767457, 0.17714016650232578, 0.11306550714277452, 0.10526577446369395, 0.2400973487284876, 0.12142807695894473, 0.1483744842511031, 0.20095949481812217, 0.17058207082652277, 0.19606215518809136, 0.24322232862393706, 0.11265571139031842, 0.12594270204464275, 0.17942520759759412, 0.13895253740972088, 0.2322250751838569, 0.11531994302546787, 0.12230317919485031, 0.12468935921788217, 0.125272995642116, 0.1126551521461337, 0.15291035295494143, 0.1213144584588947, 0.2360471797686431, 0.214115246950138, 0.22630978856355916, 0.17081499219902102, 0.31486556895317575, 0.1688339041485902, 0.17903791950835338, 0.12587619029105673, 0.12065876380450304, 0.21077726396822163, 0.15297720178721413, 0.1747740273393931, 0.375991479283379, 0.18892423820591744, 0.12760233194116624, 0.10124116985788269, 0.11548190933441925, 0.17913806252181533, 0.16940100839541805, 0.1384635128441357, 0.30045582281966365, 0.2650891286471198, 0.22024778078400323, 0.13695540747815563, 0.12700344270636, 0.15886359157100802, 0.17196781662923677, 0.11361863794586352, 0.13704926857063848, 0.11008666617976082, 0.1957636566892747, 0.15863281524469777, 0.1639727391903439, 0.16355594139425986, 0.13151803714854102, 0.20568685485951363, 0.10166783486643147, 0.13888974884344688, 0.10893103020686297, 0.1392460869805467, 0.11696214442171397, 0.23013124963448894, 0.21083945498591472, 0.14850519417274385, 0.15585329503782336, 0.1550683460288471, 0.20302986275524865, 0.11389636780105292, 0.21365991493146266, 0.2994225540709111, 0.15401471466306718, 0.2129277953457448, 0.09416288515973477, 0.1429659647927169, 0.11102834911716562, 0.22201056441953107, 0.13422347665313752, 0.16281407717014515, 0.10195730884950008, 0.13686091819357488, 0.13911424324877802, 0.17036370512458587, 0.12332737746257937, 0.19144227728247645, 0.20010104733369044, 0.11441597459657539, 0.14636498966043995, 0.14189564803194615, 0.16688353622392302, 0.11339025181387702, 0.21070601779126355, 0.1315781137635631, 0.18433927858789123, 0.26095801483719583, 0.09340849539805805, 0.21024232009245505, 0.0921066209012943, 0.21556319909230356, 0.14129351824522018, 0.12314505619747985, 0.16103897484079485, 0.16643096212177508, 0.07864362154636653, 0.12676628486764047, 0.11967235665407874, 0.16903319426121252, 0.10307919864933338, 0.25554476095543754, 0.16162875529018142, 0.157380475993118, 0.12215560767799617, 0.21192946020633946, 0.4156263863607761, 0.10092784755773122, 0.22216995667305686, 0.2472761594840596, 0.20649605821217262, 0.1648537862685419], [0.04901094226947716, 0.028809161571365212, 0.016781876104012612, 0.05601833702155179, 0.13106857336336566, 0.020702591526412198, 0.06582359212540811, 0.0470616698505417, 0.025789989909577756, 0.044833721457830364, 0.020375314934719956, 0.046007728219152465, 0.12339187440492454, 0.0286281637231549, 0.02382497821423796, 0.0504083326086402, 0.013585312952918392, 0.031644447233467814, 0.014987562204741183, 0.0257784181514815, 0.02680954568448567, 0.040634391348688834, 0.013827291399901433, 0.035639865804583795, 0.042190683645106135, 0.030478549512824228, 0.05658828345457873, 0.032557905576522314, 0.00990919216776327, 0.07988171156255469, 0.06360849102718696, 0.035659435520609545, 0.0264526444727615, 0.010183790638562172, 0.08153964840476552, 0.039728936709223256, 0.09642823013446986, 0.022865981689744422, 0.0505354572387953, 0.022854166698732206, 0.022516726035504572, 0.04043654531180378, 0.0400628361310209, 0.03992029398138966, 0.028711062097441287, 0.051064843146671215, 0.09284915162190314, 0.033719107178190065, 0.04960282179977625, 0.037355833807058876, 0.058625939437338424, 0.04874844607266207, 0.053810073258054834, 0.040784946778008056, 0.03193817683495581, 0.04807831832177697, 0.027779259779039892, 0.03423352372802554, 0.04596744348565417, 0.015058637927136114, 0.01769074366518086, 0.03628513783276562, 0.03330712041427051, 0.04347622514732423, 0.06304069730122724, 0.0322203251022485, 0.08791246571608129, 0.013828736433248608, 0.04524977997906747, 0.05461395613007969, 0.05512079223990441, 0.12185998200889557, 0.028470052751682462, 0.09057413861756364, 0.06666711621707486, 0.048556950904669306, 0.06016510583820844, 0.058531377374404864, 0.05861083601391124, 0.03142285055571026, 0.16164735590498294, 0.019537366047922163, 0.05533126723622123, 0.03765263925156286, 0.04489230037096047, 0.033674834957045895, 0.012210118096141566, 0.05730278684847778, 0.06727200392032824, 0.021090163068184932, 0.03186856242527645, 0.030261539786513296, 0.03799710302583633, 0.05077934132948999, 0.06837064295165962, 0.041097223368142886, 0.01809993229295698, 0.02668114743315645, 0.08219194162877337, 0.1284040352930465, 0.05318526343833055, 0.050498079808969656, 0.09420279834058978, 0.011084748341912224, 0.046843468857508515, 0.12848632845787272, 0.015593780985762997, 0.054355317185963356, 0.09536042614209075, 0.029621565256327875, 0.07934101436647677, 0.01935850941546021, 0.022405062974881262, 0.04408318128797316, 0.08050064931833938, 0.026107780417547594, 0.04305533261128491, 0.021470665533636368, 0.05313265235013059, 0.057477788143460794, 0.023391768899596026, 0.03736281669848869, 0.06684082665390546, 0.009913465980770848, 0.06471698577966421, 0.020792070595968156, 0.0228171723128687, 0.060637479482759396, 0.08110137716416391, 0.08409931669912993, 0.058514741775129116, 0.05293821540450858, 0.026516179974761703, 0.029546668670410593, 0.03729619003171402, 0.04192804572202506, 0.018498506772542195, 0.08216879811258086, 0.03940705337651795, 0.03371427699382748, 0.029446920192229654, 0.03864134083532038, 0.04028915765605146, 0.032394797796563755, 0.05555121107928215, 0.03191013993214696, 0.04436898187944486, 0.07187154985243274, 0.05808100577503924, 0.039939047813776045, 0.035333281247726375, 0.059358970667686195, 0.099140694665332, 0.02894970997717352, 0.0072093020125682805, 0.03864313348106319, 0.02667850251459787, 0.08190532515366232, 0.043108265456413074, 0.02474196822262339, 0.057384938287038, 0.02892313438708023, 0.07265731857548799, 0.031819289565206535, 0.013733225378898845, 0.007255939530178665, 0.017783765891386617, 0.05754682032631771, 0.0794443749492207, 0.04125434800141281, 0.0718698414763616, 0.03791084152556235, 0.029877802514801585, 0.015242536375749738, 0.009014447437479131, 0.016335294724652366, 0.04870295960215792, 0.06000497430983571, 0.04557519880754333, 0.11511760388290691, 0.06732300239344759, 0.006504763986149262, 0.014669839687074625, 0.04017849625538915, 0.037525376725581386, 0.016368261403253963, 0.03198321322880445, 0.057336418108353694, 0.08665617345081222, 0.01785087519355359, 0.030966288965916446, 0.041600512490878185, 0.015167310372025017, 0.018546776057431297, 0.07357931305323878, 0.021830851347335888, 0.0031814937228186718, 0.0656780660633118, 0.02325271245002026, 0.05542591356882646, 0.03406215368980362, 0.07737101926918953, 0.03889932094382183, 0.10966812170320943, 0.03282217526688211, 0.08624531283614137, 0.04020123757542141, 0.03644159596954142, 0.02531817933965114, 0.026681040180847052, 0.11155667399326641, 0.025634292115066803, 0.020104031709413377, 0.019112413245884162, 0.08765930430062356, 0.025535503162011027, 0.04665617185134081, 0.026384033638262944, 0.030338313287845066, 0.06752130425264759, 0.09123297423244485, 0.05966615660356418, 0.07877472217284864, 0.04850114906026472, 0.045717423030685995, 0.042191851929190664, 0.022347964526664828, 0.07242729301534354, 0.03126613386426001, 0.03787452895795146, 0.02875963207184067, 0.05824825809066815, 0.04098065159914475, 0.044247066647174864, 0.047577829250404914, 0.056050167974805644, 0.026084441548934387, 0.07016681269892762, 0.009804889296872482, 0.02850039174870378, 0.030705907171772375, 0.05967408561358049, 0.04520186500984334, 0.01567314865232836, 0.028067188179721276, 0.02555198937414154, 0.07895946427578888, 0.058996940497308976, 0.06856399588286877, 0.020991270693259376, 0.01908441656269133, 0.012039650126450486, 0.039076111054108034, 0.07876350664563718, 0.005002429656263802, 0.03666810135567381, 0.0947999791993249, 0.0549660156661224, 0.04702880084815045, 0.05786566612040324, 0.057294183681088115, 0.07130447624912185, 0.016898233368391954, 0.0606232877039621, 0.011771678316196608, 0.09398869208751187, 0.0745444076376096, 0.0027654330469592805, 0.04433971349029772, 0.042616383382870306, 0.03501763004028509, 0.06666399823922305, 0.06948081160625143, 0.05629515906255092, 0.13092070307222106, 0.14271648059929573, 0.017177849715094895, 0.052547031758172866, 0.03478473548086421, 0.0368289070414199, 0.026981555406124364, 0.06129621550621045, 0.03195125587104309, 0.046567232873771465, 0.05325879255730299, 0.03388079386504908, 0.03466143362945126, 0.037978816507083756, 0.0375136019541852, 0.03547208488828713, 0.051007137573774786, 0.03899769429417868, 0.0307703600640619, 0.03856889190032117, 0.030671643889358932, 0.07038772181277314, 0.03674408195600395, 0.04406212153093469, 0.050543190896390915, 0.009681509879057207, 0.017491509093933048, 0.00547650641003143, 0.03959906565385961, 0.0432098908500085, 0.028604801871903965, 0.06497535659300704, 0.0670151729437132, 0.017288221917565794, 0.04911599973697336, 0.04768919928239719, 0.005471761452950417, 0.012890597610103508, 0.011722171799309794, 0.05643968921034567, 0.03438740397893614, 0.029666967457160357, 0.04672688942763113, 0.03994313489285208, 0.05554392175268262, 0.021027782443730582, 0.02283719402076977, 0.02845177772424875, 0.05098589012519487, 0.046711077372873985, 0.09737660101945363, 0.11361879882432761, 0.04796828894365219, 0.026620881211373116, 0.040615702633776014, 0.051796089392155416, 0.0423951716642947, 0.037384803421915545, 0.016336033999499296, 0.09908875390406578, 0.032920544786799344, 0.02247560626616882, 0.012661385060768696, 0.046807684890565374, 0.08175015404459932, 0.01989344754556735, 0.007563747912495127, 0.03755493239770013, 0.023331893382654078, 0.012096604933181118, 0.058418456014365926, 0.04251322964386594, 0.033165076221790046, 0.049729980903887944, 0.012039314962983614, 0.038544055329816, 0.055743142917391755, 0.07413082741080754, 0.148227134899747, 0.10611406362224972, 0.10365194130328395, 0.26303494048695414, 0.15141248252362977, 0.10850293261389579, 0.12389900928903973, 0.14409660331664548, 0.10679167605215505, 0.11023319581703794, 0.151166798126313, 0.14157671030730973, 0.2206351454820364, 0.1127610331581485, 0.09976545468934121, 0.1304962750404112, 0.0894887146029261, 0.14378385558243723, 0.20876142616954543, 0.12118622300124939, 0.15545390275937898, 0.16604759640270667, 0.13263130079834692, 0.22079412404808307, 0.0885304611837191, 0.125623281684614, 0.14163084208003937, 0.1262244691831931, 0.17260771455062976, 0.15450410695085603, 0.1285139382666638, 0.13132118319551792, 0.13074179089838459, 0.09402285960893478, 0.18946521885452733, 0.1354427209063884, 0.13925406961671769, 0.10218876699406294, 0.1921186256673067, 0.11080724082045978, 0.20666680388873626, 0.09811808986048545, 0.12040328114263474, 0.16261281055067817, 0.17698987537334043, 0.1293864281427476, 0.23071958983857788, 0.1454250150991063, 0.08743182981326696, 0.08202052945571561, 0.17354773507723886, 0.12409945619442772, 0.2688500994155484, 0.14325666451646438, 0.1590467325501865, 0.16479136542447154, 0.21686251485540023, 0.09190023681449314, 0.1581008284683189, 0.20213744693225433, 0.10304999537765981, 0.23404623471921493, 0.15977580310596576, 0.14443682296381843, 0.2038667525254911, 0.1177768482856693, 0.28213584134655617, 0.13916235357042284, 0.20343444910981964, 0.20035963265165208, 0.1786902534865564, 0.25328630311114175, 0.13101361421567778, 0.15860771820429834, 0.11009953645688873, 0.14217441210583334, 0.19823651190005964, 0.15874526163022365, 0.19719440249666093, 0.2857553003536117, 0.41470637605074917, 0.10571520760535233, 0.18566346156501, 0.12720990340195357, 0.09555182554909299, 0.13172966127674426, 0.12659956881355855, 0.17919237815564681, 0.17281584531789826, 0.28852329859810494, 0.1943587893319707, 0.09756864394031226, 0.12837613437084422, 0.22716613696707835, 0.1093074321866997, 0.14719539832684303, 0.15710898975451149, 0.17125382268380734, 0.27798128524614923, 0.3331185943417011, 0.21577653925745718, 0.1692018715003806, 0.12748811589253525, 0.20283276365408975, 0.12573353705867646, 0.18264829271262695, 0.09592320199214643, 0.2542654400871646, 0.23113721500962014, 0.16106368883723216, 0.14253853369624386, 0.13632093345926655, 0.06961530600223811, 0.16987474184603463, 0.11727077826376885, 0.08285245497620876, 0.14368824780948702, 0.1736630159880846, 0.15778896939610282, 0.21729808180562912, 0.11945031373010528, 0.14918797769613806, 0.1689907223466904, 0.127443399340395, 0.11949658544073183, 0.11203181704566365, 0.10911451592560738, 0.1515483865213971, 0.19923883069667125, 0.12269119506761914, 0.23990913624725035, 0.16290265225595044, 0.2123890363521153, 0.13305425794134218, 0.11959741793332562, 0.11651626592802426, 0.09133139354807716, 0.16530548703045617, 0.13042443131487216, 0.09142826536610242, 0.11619937365814564, 0.22861300126439144, 0.1623129637371148, 0.1892373996276048, 0.17582563623305292, 0.1192733474195965, 0.1901019298501553, 0.21754376620294588, 0.20143054696100376, 0.181030927886886, 0.1894934721771748, 0.058130847455392924, 0.1551391478748091, 0.20698823906000585, 0.09123462898236129, 0.1769176332820808, 0.125381596266262, 0.1525827431150021, 0.11155283589276577, 0.10986215645267118, 0.1298380676176279, 0.15618485789145195, 0.256451441335582, 0.06246630372779985, 0.0968787128165845, 0.09293308421488732, 0.12073533429253487, 0.09776773487007427, 0.14171027007602877, 0.19842605737428512, 0.1646762990182446, 0.1681495884493474, 0.12051281639404836, 0.1745118107646704, 0.1445424818103352, 0.14858025546756484], [0.013512627488272566, 0.02479541243144101, 0.03179773951189653, 0.01670394580991518, 0.06874863073349961, 0.07148347269262999, 0.036383154952237685, 0.04824833621481254, 0.043787413892606576, 0.027895096103630723, 0.0093894072567984, 0.028380114029371933, 0.025977373100636948, 0.03872060029196643, 0.023924489205162373, 0.045075039153978716, 0.024641478554375713, 0.03941611236622257, 0.05249376183435802, 0.05163922905921937, 0.03146334596338772, 0.061204131737711935, 0.05122051604332463, 0.03245303580056756, 0.034243996149950454, 0.042527735518712195, 0.06796946568835167, 0.031515842138399044, 0.03605136227223181, 0.03285308691462682, 0.09454730808013871, 0.030656573024668524, 0.02225638637619634, 0.03014033127035345, 0.09655926947391803, 0.04732023984674485, 0.022247624245562383, 0.005688684036759961, 0.04316873277627653, 0.04084236506793288, 0.036543409054678296, 0.05061685791118972, 0.03529289309235831, 0.046929025556892164, 0.04652385314505908, 0.007020758677108755, 0.02862311328851408, 0.03542101363681498, 0.04798408567665085, 0.015962749039904488, 0.04184843386493383, 0.00895132179251842, 0.02014829052401887, 0.03546792886129791, 0.039782965060083136, 0.04682145915144394, 0.08259715617544229, 0.058106834429406354, 0.06685231031189043, 0.020186577683254596, 0.08626093336891744, 0.01417526385686811, 0.020206540019341537, 0.07033460127610354, 0.04331147027832847, 0.017016346889337706, 0.04147327294753444, 0.03982858176553442, 0.013735369467476924, 0.04534267580076572, 0.04628597135325113, 0.06341502701322879, 0.06230090917538732, 0.040722257803164186, 0.0062728758747389, 0.11352095407463851, 0.11981864114322009, 0.1559879426513949, 0.08347736821780283, 0.09113129904313434, 0.10037750531468662, 0.10918059100907658, 0.05920915834365353, 0.12296980592392145, 0.09701370516972196, 0.04823276547775154, 0.07405122321459555, 0.06554816053399155, 0.09664401412010194, 0.08540934237140803, 0.05859570960784632, 0.052189586624022455, 0.09784335540907999, 0.06668108966081374, 0.028441573433097334, 0.05962014919327152, 0.03371977750512381, 0.11559617900920492, 0.12244824560419207, 0.1236969459381315, 0.08430685757869676, 0.013237344326391337, 0.02855098228000345, 0.09361107968875478, 0.017220459525443373, 0.04472229013880415, 0.021034018399434227, 0.012162770989591317, 0.008458752155063615, 0.02270591719406507, 0.02008664342875202, 0.014789194270457714, 0.04166561847312316, 0.05760691992397751, 0.0249366196728642, 0.05915432177003353, 0.02209933260605941, 0.0286863308640257, 0.017553330474202673, 0.03956661033894747, 0.028979985771941084, 0.04290981037962822, 0.011669714886304593, 0.07287889418582763, 0.03096103168753607, 0.02832318412049884, 0.04531308565469039, 0.032759011317525184, 0.059351233179650964, 0.025247256834841064, 0.03876887149207535, 0.026202147128060464, 0.021769981831312183, 0.062454559599920634, 0.02249084567020257, 0.1357457240021998, 0.011162695872987951, 0.05287823838091666, 0.03483839227908081, 0.028003468816619248, 0.05099359696971313, 0.03302871640170774, 0.00804718578189251, 0.00969390422406216, 0.07932478096336126, 0.05913156895868241, 0.045765226917161096, 0.02312519328458415, 0.02512711126567616, 0.06592483064460178, 0.035507991429298155, 0.04031522762811473, 0.04161157480050479, 0.05984780754172995, 0.057681513905164704, 0.024220093806845047, 0.0626241676359167, 0.04828502799594595, 0.06479148016942125, 0.026551073364492868, 0.04190635777288868, 0.03191282315510175, 0.02635114356845377, 0.010335914632906357, 0.10901227383123291, 0.08658449826461655, 0.07360180539469566, 0.011207925704037471, 0.09522951703758971, 0.04806347919868366, 0.04482059837168744, 0.07431232130094882, 0.03698862488231352, 0.09274993557482959, 0.04820116052043535, 0.08440261090835256, 0.003295650878440469, 0.08464722278257532, 0.07412023241481475, 0.07339267871312558, 0.03364324149104857, 0.03510108382831659, 0.057564696988030795, 0.038129881384872624, 0.007161184987654129, 0.0386457305191265, 0.03341058058844459, 0.03124802354573002, 0.05015022992607086, 0.029202536229164373, 0.004047964063037428, 0.07675804167745576, 0.011471073075588192, 0.05275275700935914, 0.044738282224223505, 0.05211423038535061, 0.05274204326973808, 0.04457330902016932, 0.019616041362525958, 0.08491633414861657, 0.03156666632651562, 0.024286812404170636, 0.04216675105835161, 0.021996217171451258, 0.07527602160529745, 0.035190926789636576, 0.02117437145282184, 0.07311792127908238, 0.045132407648188454, 0.0249852471038579, 0.028439713754661144, 0.029113200801094214, 0.06301453922905269, 0.0017257122817682104, 0.05124036921188236, 0.018344289442944913, 0.05115704948923761, 0.05633094685993368, 0.011677356613349291, 0.03758920717143244, 0.0629703704297783, 0.010729593810655419, 0.004480639510157128, 0.021454797937504707, 0.019504698143611034, 0.05128473719401706, 0.04809550933479782, 0.09995974990869723, 0.05188708531580145, 0.038031174786268704, 0.01175880516623898, 0.026607413385664264, 0.009395940071572701, 0.06551397002993092, 0.05035778612739617, 0.006224863708109385, 0.039191108512421774, 0.027074489532218828, 0.026711499836716442, 0.030018655440559792, 0.030667750247483774, 0.048152349228339816, 0.021059418044563745, 0.07245798249759021, 0.04891223184043362, 0.06054240414091657, 0.09870153476273823, 0.09180960095217151, 0.07753598864280409, 0.05130426094476735, 0.041145954221006364, 0.03615482627684551, 0.08174535067331407, 0.059811571582911484, 0.004680161364376545, 0.09800152192192693, 0.05443935703125693, 0.02657213886719077, 0.1074550315857895, 0.07510452516256802, 0.08003976316221299, 0.022663127353054383, 0.01789883995849279, 0.04364712021103309, 0.03997412697982885, 0.04840508163455994, 0.09262206017850869, 0.022394847192410982, 0.11528787458495748, 0.03711179266833971, 0.022442465302564447, 0.021357899306402094, 0.03456164684687411, 0.10528731685612472, 0.035503513645380735, 0.13337523345985722, 0.11750995091372922, 0.007530535128147852, 0.07149735420581795, 0.0616101966419768, 0.03099055671613784, 0.0526557281433094, 0.01791449305000565, 0.03163983729938346, 0.031508095074264754, 0.03085457227913843, 0.04445808939635754, 0.010571540295777303, 0.06023604941043643, 0.05939587695343841, 0.012169582468848075, 0.020488422071080536, 0.032045084404789155, 0.03602868606967311, 0.06669621223643904, 0.045199425019804514, 0.0758954726399914, 0.10798361693178454, 0.004761719084795444, 0.043914201444075, 0.024702043550449516, 0.0529112299573758, 0.08251736045724924, 0.05807064443586334, 0.08881828041687127, 0.03506343443727782, 0.04455200411499508, 0.020791714365083366, 0.013649753396279149, 0.05554856807594338, 0.04746422990255299, 0.037607562638098196, 0.03198943769318923, 0.03202133567913646, 0.1151574787593657, 0.019766893650915836, 0.10005197157302212, 0.031032423421199766, 0.06547403386643817, 0.04027425341548459, 0.05560613958345306, 0.020691165325021552, 0.04662234906948382, 0.011082261428988029, 0.05973073015470178, 0.029416253692620707, 0.03962373751546106, 0.018490278988235423, 0.026785253036406734, 0.011152734814752496, 0.03242608099695175, 0.04764480448718514, 0.06557024684884856, 0.033379190135747194, 0.02058818587101996, 0.035621609929348194, 0.02986134694618804, 0.02723319230661277, 0.09627257639001455, 0.015324773999201435, 0.07102008908987045, 0.11931818654580463, 0.024468574425085418, 0.006241328374017031, 0.03515450696971628, 0.049373401449091976, 0.04107577290626303, 0.03206268144440988, 0.04606942127969477, 0.027864211268963355, 0.056137321967511415, 0.037241652232384494, 0.08388537132451612, 0.12132219594692993, 0.12808301380925602, 0.09409743060748424, 0.15072493393334652, 0.21471509379484963, 0.15875486837279412, 0.1575798886798082, 0.14997013814506993, 0.13814840555912064, 0.0877096209554903, 0.15027729343743096, 0.1437783550711409, 0.15307797299277398, 0.05382811079823202, 0.19583867201882024, 0.1760435882475107, 0.09468557928959209, 0.1338458565935012, 0.1591688622870753, 0.15129737015212738, 0.14150140386435295, 0.1129410255159582, 0.15406382089901358, 0.1517416705046931, 0.10434340460286026, 0.16867477236495865, 0.1267462440075413, 0.11017155638265033, 0.11694549733111936, 0.15494425510687215, 0.11007446239912703, 0.21810949149151004, 0.14791193568418104, 0.2948388968023562, 0.19286033667383656, 0.2028187748885924, 0.06336666005212935, 0.10009530916689865, 0.11321540756691849, 0.1349015104314012, 0.13085192369837917, 0.13353093316958797, 0.16246815782881555, 0.1809372353337465, 0.07328297492236861, 0.13012708194794195, 0.10892452612038582, 0.13553891090616105, 0.06783451163961042, 0.13108299113810062, 0.1645041284181418, 0.14895436684450797, 0.1784435884966966, 0.2004332843446924, 0.20199602710143214, 0.24182101591460167, 0.13766426863449235, 0.13503831841291922, 0.195956603593884, 0.2206340576371839, 0.10156953812486703, 0.19228359504092127, 0.19428737461566928, 0.1463088507373487, 0.09978594754131571, 0.12486445627385571, 0.18072507494399626, 0.1617872129164396, 0.12264175175298607, 0.14414687400623677, 0.16787580394696805, 0.18087539671649858, 0.1407342434169785, 0.16010828526510348, 0.19199428959719597, 0.2169722033243987, 0.24949897891811787, 0.21187381157951973, 0.26871284710303434, 0.28323208252268456, 0.20677016447148017, 0.21357409776218478, 0.15992329035314823, 0.2305164233210587, 0.14791182843187164, 0.2876867612283076, 0.2643858905761473, 0.22858905335587842, 0.12535990831712562, 0.1649179691148381, 0.17184507402200855, 0.2560305526299823, 0.16489376073643086, 0.14576652177399205, 0.1580985302045461, 0.2027996073687269, 0.18587479457980205, 0.2641866770723174, 0.26636972122134706, 0.29670723203209143, 0.06783828079219788, 0.2558698427052267, 0.16196391875705413, 0.12951333826828387, 0.17156761229759263, 0.1347300905974642, 0.1371239774650143, 0.0870895340678192, 0.10575685980579547, 0.11379814766828092, 0.09933907313332443, 0.24846030158861993, 0.2259052481742636, 0.10347366498242463, 0.339690127199696, 0.08973694241215145, 0.19694217570847083, 0.1297375262384453, 0.1553203583124184, 0.20785382648389186, 0.21324278005669195, 0.169871692816096, 0.1996210319620948, 0.10853016703960397, 0.2121906808667606, 0.2719356564264144, 0.1197119557388848, 0.13388511093874134, 0.13278621909839491, 0.1318686755914842, 0.16092458259194128, 0.0788184198280496, 0.12265650660640771, 0.14969010236522845, 0.19445516319284517, 0.21218588515635461, 0.15313755931152453, 0.1409571596811856, 0.11740479002436323, 0.1629271977130444, 0.19772171613670167, 0.16631417967859777, 0.10709327720706502, 0.21708831161020264, 0.1869271082743522, 0.15297038360468804, 0.14207837532364553, 0.10269859084679235, 0.10453179328432007, 0.19939137412415397, 0.13570564228200144, 0.14975066927652206, 0.10811710775259042, 0.160987171975355, 0.11826794894952929, 0.11270450353021584, 0.12907518194087092, 0.1256984655535029, 0.17908457426294205, 0.1752401611978008, 0.12337433865233777, 0.09713668526420671, 0.06254788443085647, 0.2621635001513266, 0.16145293811155906, 0.1876113780083195, 0.11289186565385712, 0.26225448075321417, 0.12092102634450122, 0.15134057751105678, 0.07603018920147613, 0.18178668894594718, 0.1711487920293885, 0.12654994163782368, 0.23415466680401759], [0.02836611760299533, 0.021018014822696007, 0.033217829036256, 0.031010432867333296, 0.06333847567739506, 0.08525904358154343, 0.021030032827008157, 0.05898102885112167, 0.0049757166491490945, 0.054105913431774226, 0.03255206415609967, 0.028312876407477646, 0.02360452300748758, 0.03431750611672479, 0.015227625431913524, 0.05179947167034111, 0.023529779639155157, 0.022781016793282285, 0.00944225104420536, 0.026874121150843082, 0.06586845423425398, 0.045592585172984874, 0.008011307490373692, 0.058131877843651085, 0.06598913606496588, 0.011968481515894734, 0.060699505791548765, 0.05320110613660467, 0.03960663843299112, 0.006253698299969397, 0.015998482253522645, 0.03339966000508397, 0.08655440633095081, 0.05463070281210446, 0.042960693939558925, 0.0162471390719856, 0.0312245391204112, 0.02470360828503486, 0.03850073305769794, 0.04494145257218231, 0.012935067098888179, 0.07537032702877637, 0.0616172293291217, 0.06432028246983405, 0.05551835739864938, 0.009501349939514072, 0.08838456739941913, 0.03684627808510296, 0.04202159271845895, 0.06306521977568347, 0.025965994779741573, 0.02262223166443648, 0.027515007325658397, 0.06210239664200814, 0.02123494985543432, 0.003487276999587794, 0.039266935895167054, 0.021037327899267117, 0.05343587378100042, 0.12347684121660649, 0.004425761759311202, 0.014797790734578046, 0.032443570784263076, 0.0365074182439956, 0.029888916535363085, 0.007365830533672125, 0.04854185514212136, 0.05691723394838553, 0.020359751858538198, 0.031099532723366737, 0.06381813098766631, 0.046938164985828826, 0.0753049184418013, 0.020335041692540533, 0.04688748826963767, 0.0445601323078717, 0.0762713690017981, 0.21722234635343476, 0.04857652062069505, 0.1511081617565886, 0.13117361933954302, 0.07896547806599448, 0.05068709285208776, 0.05392458042009704, 0.044366243115115556, 0.04257928940557665, 0.01837039197374496, 0.043234026450062954, 0.058562373291821256, 0.11294134727288639, 0.1324279504197259, 0.05030853433474418, 0.014661057446632656, 0.03470710013061762, 0.052240979632422815, 0.04276669366405376, 0.012880814667310447, 0.0655854307115078, 0.09144373268129365, 0.06876615116432791, 0.026331033760441408, 0.022939692754598878, 0.04556271157437756, 0.07169708864943636, 0.03350968555276913, 0.011967103515240935, 0.055512584926139925, 0.07220564845709071, 0.048051417144315864, 0.03668449180681379, 0.04332059438550665, 0.028976515393644094, 0.07198829399121386, 0.038554435821189996, 0.0381549324599966, 0.03238365887814472, 0.027622050876098297, 0.04755689589787395, 0.007027544300898069, 0.03145776118241972, 0.0930034876951287, 0.04917251021270791, 0.009964979648019278, 0.01591867600162063, 0.029149224170513695, 0.058899022969267065, 0.07313021699026709, 0.016723781741494616, 0.04150083679105005, 0.07018129176069653, 0.017560388059205106, 0.0155183443078591, 0.03460885701520789, 0.03818463751926057, 0.015814745640983025, 0.02813187664404752, 0.036927763027169054, 0.038897355928296046, 0.04283683284396126, 0.050458067036684484, 0.020452459988695, 0.07357287791467483, 0.030838304402066335, 0.01346688437831378, 0.016998993082632943, 0.010440108336267934, 0.0691124075843442, 0.046690806686397524, 0.017655329335661187, 0.048171972570520256, 0.030205898820572806, 0.05495604886222751, 0.054105492083415876, 0.03255268085687872, 0.043734281864618106, 0.039922699497471896, 0.03998675593926061, 0.03551078381978216, 0.06072996161697854, 0.05543054073988911, 0.04194845813476751, 0.008312016631656838, 0.04551435227415735, 0.03470268363373415, 0.05302323584234523, 0.0036898325619873626, 0.03289763492742374, 0.02641765340681999, 0.017912650608547756, 0.010692653050946613, 0.03062050368997359, 0.030855363264920253, 0.010087057673973183, 0.09394073498345192, 0.02802125546300123, 0.020062187986989177, 0.04176671143561121, 0.03981152481790032, 0.05003274268200321, 0.03981949596275245, 0.06820485386396609, 0.07536674939816998, 0.05462403784716322, 0.04397982836610848, 0.029791849364917126, 0.025934092963354725, 0.010325952617060995, 0.047510241143285274, 0.05214917165557704, 0.020432405722057147, 0.01321044697936985, 0.016868518733028925, 0.025226989978804223, 0.033644080357325655, 0.03135772159082755, 0.03654889041377652, 0.08535997566556738, 0.043799173342244285, 0.04138817973134499, 0.04483105930229349, 0.0717988787519355, 0.05111832374466523, 0.03781568574448747, 0.05888821729909509, 0.020547989237632965, 0.043993051043681564, 0.027064568693599394, 0.03744853810677606, 0.03982305061072111, 0.03335153053124105, 0.04855306300845358, 0.013681930046708835, 0.02844685560933525, 0.030256554469346043, 0.03473643363723832, 0.06629689656678708, 0.0271916933237545, 0.01843649961595093, 0.051354313299300215, 0.05300135254078815, 0.07536750782521502, 0.04878247186781899, 0.020083709312002027, 0.029278505338175647, 0.014863777717935943, 0.030352798095273397, 0.030912046110437765, 0.047990413562905405, 0.04338701803898139, 0.031922043023270466, 0.0157828304180575, 0.025512204513013847, 0.021526134129793897, 0.04344419501121006, 0.03204070238186227, 0.08829039221088733, 0.02781762546228786, 0.012135351745171413, 0.014912408021759364, 0.03597573024190722, 0.025065868281789368, 0.005832893385236422, 0.12059009168297054, 0.04273195923756688, 0.013838880394975987, 0.07156638638867487, 0.067524851239737, 0.07307751780195583, 0.03726227531930612, 0.033495302251990766, 0.006562846857348398, 0.07304495906517391, 0.013228264269268802, 0.1362981959696739, 0.010777413018889005, 0.05859759035370043, 0.06401671246895868, 0.09884346787246967, 0.04526863723332363, 0.07004375599565045, 0.07994356550156109, 0.025947616330438086, 0.07020433568545888, 0.00447639634066652, 0.08293655610853627, 0.056105284170518, 0.0896661482270687, 0.05159496449895444, 0.07720180576847446, 0.020094876958718224, 0.05570043351561312, 0.022964046689711755, 0.03994948576174436, 0.1597042964591134, 0.12223394016825384, 0.2094969778291641, 0.07355152704422513, 0.08443407413940276, 0.0577035810678236, 0.0389703143117649, 0.04251053301437248, 0.07185838080101437, 0.05942706822327549, 0.07729485480775757, 0.06960853378498746, 0.04497981825543027, 0.03996460833736966, 0.02251846888553231, 0.0782092496932995, 0.03697737105070584, 0.027054056052058458, 0.04824963473384419, 0.010179182619697625, 0.048599652645568696, 0.04290876083917195, 0.018773821535550298, 0.015704410785298436, 0.07124561005302014, 0.046607816381560224, 0.030724818052183238, 0.030107230526365103, 0.023505033083981084, 0.047501013614237315, 0.0291213596374878, 0.013601136498994405, 0.05708634402723082, 0.039648754116628444, 0.015582462036681753, 0.03598793019210139, 0.022616928420780648, 0.04111031198032922, 0.07253392479352413, 0.04838918531013112, 0.06420494793283363, 0.03919640217997855, 0.08101424232365624, 0.04139865981414914, 0.030575157030515616, 0.030315694541880683, 0.0577507759143989, 0.026811740526388732, 0.050892657224809935, 0.08468729684189444, 0.06473319620014199, 0.022025757521811514, 0.04571146669707472, 0.03910400431543108, 0.062432488606822115, 0.02977415464908606, 0.02918479554805785, 0.06141607379240375, 0.020141464680613532, 0.037335919351467205, 0.031911934493109584, 0.016476477068218014, 0.033371253464851654, 0.017185163939551964, 0.04810695085794695, 0.07733253867275293, 0.013188217980636945, 0.05548699375902934, 0.00996973705402906, 0.018415803750676495, 0.07461513287477917, 0.025624516833152984, 0.021432692470449596, 0.02328604302038589, 0.05090877954517642, 0.013625681956088351, 0.03758247325857801, 0.053187496584629824, 0.015062681913766411, 0.1817281904720491, 0.10800009548303582, 0.10717756220049436, 0.11053269023015616, 0.19060046922776008, 0.25442287115560425, 0.12943486022132059, 0.2534247658425762, 0.07748469905627352, 0.18183006484421993, 0.1517739994150977, 0.09479174375413887, 0.13649912551045418, 0.09135564789175989, 0.10469716102365526, 0.11828610523333473, 0.16781952712805043, 0.14473564321956328, 0.11397483052625773, 0.22103245400132673, 0.23340478930021488, 0.15913097157834039, 0.1637199914623653, 0.1800305396318436, 0.1614053027644273, 0.16390250424944586, 0.17763032487803893, 0.1680308907863594, 0.18138331301029653, 0.1005240809172392, 0.06859994838915526, 0.19871295730192817, 0.21875957838229595, 0.1671263094871275, 0.12170939976649901, 0.10707798609209639, 0.11583945789043942, 0.15625120110569463, 0.13057139762226613, 0.1427416542484876, 0.17459485469566238, 0.17239743873717325, 0.17609825628178735, 0.11797379416924332, 0.21376056356295464, 0.14674607243749405, 0.17178675940921231, 0.19222992292094618, 0.11324216701811361, 0.1848957188908131, 0.19184557660933466, 0.10286189780961122, 0.15968094609918135, 0.16598189670232036, 0.09589009167205903, 0.05918884169190161, 0.15137849886330867, 0.2100197409069346, 0.1278438105157787, 0.22456280166102996, 0.11909652666579332, 0.06449354091478933, 0.13544360956838056, 0.16209911795393114, 0.18447965653913637, 0.10231209182811361, 0.17952746501372707, 0.09718866432986914, 0.1332129760374946, 0.15476368818311922, 0.30352575163687434, 0.1380476496753193, 0.13544725614690012, 0.13466213859858053, 0.15435638987729627, 0.22414332255721095, 0.25836094613036803, 0.3800591916566895, 0.21872879696949837, 0.26399748399853706, 0.27682731168404706, 0.13037057533379526, 0.16704214706776604, 0.19770291633903983, 0.20543193144183006, 0.09391636572658055, 0.13959280305331753, 0.11920809205020629, 0.24324776274302315, 0.131110294511722, 0.27435474758667333, 0.20125062355110723, 0.3393107604595923, 0.10421726822612748, 0.131717189365337, 0.13766872726621168, 0.10248685946627971, 0.2513169668494694, 0.4424306996647389, 0.42594408916850246, 0.18192538150375892, 0.19309707316419772, 0.11228801216930152, 0.15410417841086466, 0.11089088996091198, 0.1674181583427614, 0.20744755473588744, 0.20789753946085132, 0.12431222945451738, 0.127724775774104, 0.19969983176598627, 0.10142072554557555, 0.17557538595170746, 0.0948636947319873, 0.09583021423989728, 0.13264225585566414, 0.09369951687873372, 0.19674962716958216, 0.17445014068676581, 0.12833211495871508, 0.14573459122930804, 0.1414013834249589, 0.0835701261436747, 0.07295511993429354, 0.12785320275373038, 0.11067113763983212, 0.1260314992959461, 0.11775003520831948, 0.20370513861698492, 0.16417287199968295, 0.21134177883786542, 0.15246458171356111, 0.11446862015873195, 0.13653076494172697, 0.09924902715870451, 0.19666843717136692, 0.1986442545368787, 0.13835848218971683, 0.13062131591141224, 0.20427368310911043, 0.1264163052603122, 0.12793582533636402, 0.13018234753079955, 0.1313880779930661, 0.12013223157414507, 0.12340859810431158, 0.20515690587701338, 0.18714988664273294, 0.12081704523053863, 0.17498620305090182, 0.09811392234217736, 0.18174795554049555, 0.19692565885282334, 0.16461248389415203, 0.22904703603877177, 0.07505677490224762, 0.13581349213998165, 0.09754474965795394, 0.22620982941119905, 0.16314891888008964, 0.13814489687642745, 0.10745375221895595, 0.11012737609205708, 0.13629073427329141, 0.11550320657871424, 0.06864469558481248, 0.1634898892934284, 0.15516190068616023, 0.15192292690757783, 0.15123700242369406, 0.16314807618337293, 0.1783124036005428, 0.205024219448528, 0.16243267263616287, 0.17444752066606478, 0.13289319561614146], [0.10981039189162756, 0.06078497439082112, 0.012168768500428528, 0.07702068726141607, 0.08281814955895947, 0.026000549175566243, 0.07279067150046749, 0.03527164947421801, 0.0430060769881933, 0.04253281085121055, 0.0807636549636241, 0.027296252834099918, 0.066943260270261, 0.008588364655752818, 0.07860078957052001, 0.06481438619835724, 0.041498848792886546, 0.01167092434761505, 0.02893239447486497, 0.09214765257051877, 0.09199862548660848, 0.01035339197128891, 0.031940545961861654, 0.07348044940661039, 0.06628319891470094, 0.018082689569001238, 0.011330886646324109, 0.051214628657626535, 0.07500376161788741, 0.04706491040246141, 0.04706311009583935, 0.03779551847988079, 0.034354611585337314, 0.0637517111646312, 0.014466986307994494, 0.04753081443449182, 0.01555203781237886, 0.03151143713283443, 0.07945372888277616, 0.030539758022754427, 0.02297734406085745, 0.02304541097292977, 0.026777827729200645, 0.04173190423077153, 0.037309914496877504, 0.020331362555284175, 0.02922167693595252, 0.012106270089955821, 0.06337232910276902, 0.012467191348062649, 0.05338190288673486, 0.04302886427350102, 0.03406512611094983, 0.03494946353678261, 0.06324554538174022, 0.016869290566612637, 0.04391877115854333, 0.006042830683591386, 0.05387715957758408, 0.09864420074248507, 0.040627450592094855, 0.02135974940873923, 0.027951740644752022, 0.022403289481336554, 0.055942329608144305, 0.08261066230554735, 0.07867873135593631, 0.0031230996284002982, 0.016968349565661723, 0.022405160651091608, 0.06381980105934125, 0.08186037111426554, 0.029807738028466705, 0.03703208505025795, 0.10725052441440283, 0.09968818706129828, 0.17263806695418973, 0.0803427662580244, 0.16762860269556124, 0.19780284484788296, 0.08552516720468, 0.3106215644267298, 0.11196102286058088, 0.16530380163702274, 0.09972365693219247, 0.0864257954902226, 0.04893533705222992, 0.09072937101366059, 0.25858069079056867, 0.17453580463845886, 0.28727607681385936, 0.03597643887323718, 0.13870669979481928, 0.04728995256065842, 0.022494840818727692, 0.012127634366944194, 0.026667888366406965, 0.010262781964434732, 0.19565977516674227, 0.16779511956678284, 0.07166707332456304, 0.016686260670183167, 0.05705841629195118, 0.05205788461851978, 0.037469096076224125, 0.09673513261781586, 0.043166917147895986, 0.06192312057640764, 0.0476423453449482, 0.014750942542788484, 0.012587559082725597, 0.02227269447288446, 0.04218198471672593, 0.03526968062825261, 0.05661238075023698, 0.07570595014840364, 0.04808858773040195, 0.07560850376443518, 0.06870857965681823, 0.026817401916149165, 0.04193715067700513, 0.03638254591233788, 0.06767359487111531, 0.028638375675185557, 0.0054491518042801374, 0.08373570838762869, 0.03324248557609897, 0.08051560335462132, 0.014200058292537449, 0.023791885131128857, 0.00995445838798919, 0.039937695668589686, 0.05153315269478387, 0.014287618311843085, 0.018013883382081985, 0.05754860531118128, 0.05256212369028119, 0.027663996105172464, 0.015991096208322675, 0.04832568811252714, 0.0386859271525135, 0.0318764473852371, 0.034191906001539, 0.02064539923242504, 0.029045076432427572, 0.019934170864402287, 0.02435082671112351, 0.03224307408316001, 0.033073785354293166, 0.0500669063729865, 0.009738829535161777, 0.014664315235530658, 0.024406151665795236, 0.012048131677382177, 0.07035600577270792, 0.012955563781302304, 0.07200003045821382, 0.025568636464736155, 0.05161171884185845, 0.05011930295656766, 0.045407889035320094, 0.038308510106177106, 0.0845740920293235, 0.05617572212471597, 0.04787975599268272, 0.014566038603774242, 0.042348513079266396, 0.04442269230381616, 0.020623358882843487, 0.029977736769304163, 0.04869544427962073, 0.04960785116699915, 0.0472768486267136, 0.023530024787290924, 0.044735723490556406, 0.016185539857214017, 0.049011696866082574, 0.05344556862368219, 0.038160302736345804, 0.06915720074527687, 0.07047071977848969, 0.030744941266734275, 0.049468369538625406, 0.04992832489792378, 0.029426948280043663, 0.021106417538718353, 0.01575674991228528, 0.007750356397140892, 0.030315072095442205, 0.03158283269693775, 0.07635114173735343, 0.058126258588726484, 0.05096558496476181, 0.08185446457636934, 0.030171354000847188, 0.03469303092588821, 0.014166249874829045, 0.062228245735769315, 0.03230336137236126, 0.048869541590853084, 0.03786085045806343, 0.005278205029636381, 0.008669504858252984, 0.09245723636159975, 0.05284318219750159, 0.033744966476074154, 0.050023840740323074, 0.06723183793045821, 0.02661529259996549, 0.040653122198437495, 0.041211152133802255, 0.07307993097891731, 0.06377102041076269, 0.042598951052153305, 0.07255819445896534, 0.06155176711599193, 0.0018780312694293719, 0.05691869334588128, 0.13829062212138407, 0.05668823877649923, 0.024606799669263345, 0.0046377244026159815, 0.027999992692662824, 0.032270760500743505, 0.043308352300476645, 0.037155478832221804, 0.05438665018206643, 0.03529945463542977, 0.025310303955789537, 0.02521149393531584, 0.02227419600521605, 0.07992915538770538, 0.028114465380748434, 0.049734163743954514, 0.024930402869358662, 0.07665016117595858, 0.007835016294848174, 0.04076131296554401, 0.05936531004525962, 0.07996605018213873, 0.08078985517063449, 0.11674253765733973, 0.09503157523971412, 0.13636597942921425, 0.005255782593702597, 0.08431276411659296, 0.12428020697928245, 0.09881175949328369, 0.019301866789558725, 0.05843491158297947, 0.019656908322846698, 0.05738922071853473, 0.13650704685959125, 0.10069553905557241, 0.07112434599548578, 0.191624820713074, 0.04723243850974306, 0.13198991666638082, 0.12781667568150068, 0.035110583318577665, 0.09419050262940508, 0.042548304979479125, 0.07150068668828857, 0.06819709339329312, 0.12878330244172004, 0.1775698498972962, 0.25236768708113705, 0.034718714023549715, 0.0952558244969095, 0.045323596381011515, 0.028329316654332706, 0.019462427327169046, 0.05997914182502897, 0.023772598867635095, 0.17017111062042176, 0.12885626465562852, 0.09489684335647092, 0.04200981794706276, 0.04742168904011769, 0.0619447855429063, 0.022980582697557348, 0.14200755815592506, 0.04965498472654051, 0.03813986734096562, 0.081596898155347, 0.05140775559289802, 0.00255069884118594, 0.09478274222102859, 0.034349873331525636, 0.03851343862592213, 0.00781737951441638, 0.024366397448184512, 0.02232024171990493, 0.05516413366422058, 0.05506741506378016, 0.06167157177603053, 0.04873303621406517, 0.06173765068993934, 0.045347881368211204, 0.03672451990085744, 0.05816769245411119, 0.037991449296955145, 0.03794277973112561, 0.0307593705327881, 0.016675447339131948, 0.056803519687344955, 0.060618166406188285, 0.0657205379778339, 0.0648447692454342, 0.013963719210287016, 0.06365980742679489, 0.03489824289816522, 0.021463803301054626, 0.09383820943654546, 0.03554777820564566, 0.024816374512269132, 0.044134195082851, 0.02858328820777036, 0.008761809834639632, 0.0563426909878129, 0.03639781404466879, 0.009959239734246606, 0.04745716657189112, 0.03162502498936749, 0.08211684202955616, 0.09762694323135, 0.08557169938520079, 0.02150543826451946, 0.04687281385544808, 0.018845893172246796, 0.12309526048240163, 0.05132605614621313, 0.02639798409936409, 0.06636893181430717, 0.0357252539646241, 0.04764650137193742, 0.04657184089263601, 0.08102967133445126, 0.09467768092309276, 0.06447188360916992, 0.057772425559139064, 0.053153593363540794, 0.02168850646534514, 0.05330712121400622, 0.03215670533057663, 0.043296926099086, 0.037494587651904554, 0.08105695172543488, 0.05336742382496596, 0.015505706729938187, 0.048216122217596545, 0.05668627376097345, 0.20293842250060654, 0.1476966802992167, 0.05762418371535117, 0.1581722738281373, 0.18096772563313285, 0.07107102627595586, 0.16417612021248187, 0.2820481702445015, 0.20449681387793636, 0.1014655493500252, 0.14753102144647032, 0.1053861958245116, 0.1318893293219228, 0.12787159652479235, 0.18928060698653423, 0.2023162212102644, 0.1648751907651463, 0.1392952698252855, 0.12241073027854005, 0.19763949958066787, 0.2070065025961207, 0.17089245900992425, 0.18264631620578228, 0.20750781521201137, 0.16497498137816308, 0.09527486178182787, 0.11555439657381467, 0.18025642831719693, 0.24345664427645747, 0.1300824343437149, 0.1249900027628868, 0.12044365397624432, 0.16158095140370632, 0.11650048451678408, 0.12406813085920389, 0.17607046261189446, 0.11791668997536744, 0.08827738403793305, 0.299054341570985, 0.15211207401608268, 0.12314889429798051, 0.1026980086199699, 0.18836969780104776, 0.1604924936808886, 0.1096434536720476, 0.1721338738477038, 0.07942476309835911, 0.0971702782196864, 0.1690015854734567, 0.1976821859998088, 0.1996236826263128, 0.20301595059854372, 0.09719253307388676, 0.13596232770191086, 0.15699548616765008, 0.1648297311077195, 0.17236078909087568, 0.14952312584125227, 0.0890483366205327, 0.2680857275282183, 0.1297551002954283, 0.16183506276819015, 0.21116092080070129, 0.16237722319220343, 0.24397744616914183, 0.28189697513176554, 0.25603563945379954, 0.215554756803378, 0.19081304330498944, 0.18136233752292974, 0.32203072802193705, 0.1506952403654014, 0.2366428897385636, 0.11401449855897697, 0.23484236861188568, 0.23189152050162518, 0.3607056349996598, 0.2804310199233794, 0.4343743351919036, 0.5009492757099291, 0.23522027978493323, 0.4183280720345436, 0.30618208490552445, 0.2841027261268708, 0.20162101174073838, 0.16257681973999547, 0.18680136260246077, 0.19324895775606557, 0.37665432919898345, 0.2242776330920958, 0.48610141921427946, 0.15059151206045382, 0.209155302614935, 0.14017385010036731, 0.13676950858244974, 0.11950933314379185, 0.12136794671776796, 0.18437914580347078, 0.26604931260789594, 0.29008795657465536, 0.23117545811880022, 0.17724593260115196, 0.16675423590406296, 0.15619968935366602, 0.12810046529217115, 0.26059994534138714, 0.19359765033568108, 0.11801705515432744, 0.1693497571132837, 0.12241066133062686, 0.1835062652225456, 0.2154643431065544, 0.17717761288006462, 0.08270152799424627, 0.12265754848598473, 0.15017998494928883, 0.12091194820259848, 0.14212544376571334, 0.16465156970004882, 0.10338571808871724, 0.12205346517505185, 0.16207576759399908, 0.21566859746892608, 0.12205978540042717, 0.13971352318842567, 0.13384470746161478, 0.2361560868279588, 0.25856288690720836, 0.08654392624814665, 0.1923744683904994, 0.11456863293724676, 0.20296004150182972, 0.16578249933738864, 0.1582600521825014, 0.19750131264088616, 0.17839955376280894, 0.17156741311473234, 0.18615381912358347, 0.19312469829474727, 0.1643495471967805, 0.12952299097612982, 0.14610071997008017, 0.13819665377659185, 0.10971558851099784, 0.18947657227756518, 0.1578625751238677, 0.2099261556061045, 0.11297196014634064, 0.09849254597699451, 0.1365263829188001, 0.19823695623105575, 0.0888428411957237, 0.11117071123613466, 0.09828045453515746, 0.22165942035855787, 0.16742508377759688, 0.2894566694815313, 0.1829742478026498, 0.1021380749561133, 0.10912395412883452, 0.16177055816496574, 0.2050785044388425, 0.22588497748778713, 0.2663223769876265, 0.13840162826161231, 0.2202532046865071, 0.18067333336559036, 0.12333048777955195, 0.11410417681139325, 0.14727024511704523, 0.15134287577482963, 0.23027240899541687, 0.0914973435142348, 0.1321397634643701, 0.17119006884674873, 0.14965509214708883], [0.01639313819337516, 0.03489301051764238, 0.06353528749558233, 0.0404364763638906, 0.03490954269504836, 0.03013175683126094, 0.028096192268534537, 0.018253375873750737, 0.02396634441890544, 0.009682123707006536, 0.10398361907010117, 0.031802288158946944, 0.06825676398171533, 0.03483058201269277, 0.005789675971402997, 0.015337603099103418, 0.042807932177017775, 0.022389157074353388, 0.017368936941267985, 0.08601461311862355, 0.03908567566184267, 0.013168146477020798, 0.024583194585096453, 0.041147857949498205, 0.04365550887380396, 0.005691831221713895, 0.016286178912606933, 0.06852682529678268, 0.037741405859349236, 0.022909074135485197, 0.011364437466967973, 0.024038609492802815, 0.0557787123797161, 0.0343172226641928, 0.0342303674457775, 0.036963278863338694, 0.059893167607726595, 0.0581993357158236, 0.031101135762348294, 0.015316049215353787, 0.10082431077476471, 0.01941493370630328, 0.023318180408809456, 0.02095241662895968, 0.06713599267025148, 0.04208529292936287, 0.05819238729835038, 0.030936683498082623, 0.09030870447355895, 0.010457713994377804, 0.03551043141933699, 0.08161537619608064, 0.01984229010920371, 0.03490670050884928, 0.057734385463258917, 0.04190169612786943, 0.05392690166650761, 0.03836133952943548, 0.05454549468272636, 0.12492182093762583, 0.016224895709104115, 0.030438180509654265, 0.017532159634415182, 0.08409668901754964, 0.1116190795155783, 0.08958030041427383, 0.042672231192550356, 0.012109667689900004, 0.05596343150001861, 0.15474269737399396, 0.12414293934500988, 0.05433879266943663, 0.022911500718985355, 0.054572292438317696, 0.07718576388734003, 0.06960360783963435, 0.1666050326199301, 0.25615784579948075, 0.11952500730272263, 0.14740870784847968, 0.21751067120461695, 0.2643018660526122, 0.2194923874471457, 0.17956771527326879, 0.13745337995069642, 0.11612231287384227, 0.04760928482057587, 0.10445280195844751, 0.08527581324620594, 0.16947970094700016, 0.18475724083762016, 0.016350336861045613, 0.18837706756687936, 0.04787231344849833, 0.054214671103944706, 0.03731927226087259, 0.029716025812611468, 0.05314731144256169, 0.08435007259850541, 0.11798149335288233, 0.12545360087026514, 0.0579828507597408, 0.06960682540891633, 0.04331270751032618, 0.08546925044708675, 0.021529792199632334, 0.06764195543984253, 0.023897007716098623, 0.032121204816165476, 0.05982388644629429, 0.04225320791104629, 0.08758133953256954, 0.04165808016794824, 0.03159266543544589, 0.02488727211922167, 0.05332014087827937, 0.08898966194641206, 0.02429612037245064, 0.06956689690630283, 0.04199767162302329, 0.06267446130814572, 0.02055434393696487, 0.10872045561911599, 0.040718074963097615, 0.02990365032136681, 0.06648583683155238, 0.07929467370793705, 0.023701375673314738, 0.0911051064970032, 0.019313637730515292, 0.050259359150884614, 0.021561695931238994, 0.06992410072275708, 0.03993151716948037, 0.011500603849849394, 0.054892245229453816, 0.05460601562874452, 0.019000189025856314, 0.04973861854523421, 0.025261969553426872, 0.1178451986502736, 0.02626198242538639, 0.010338888969272375, 0.028972087405441754, 0.06207646456577125, 0.0474032569646595, 0.0402746326290071, 0.009388675642830711, 0.04550426289619458, 0.053038044321921565, 0.03862954308128646, 0.054138376407565615, 0.007404628098987404, 0.07081702982466068, 0.052218640508550795, 0.099162780980189, 0.01772651997124476, 0.015406582613415537, 0.03422683195000695, 0.053204928915346825, 0.008529381631242653, 0.06731646000257424, 0.025174133742468494, 0.019986094388690208, 0.049153373336359385, 0.02504457295271418, 0.015132455286690065, 0.057987259595745036, 0.08486113751367216, 0.03418609522463333, 0.03844834796543564, 0.03307344827560648, 0.03342458850614006, 0.03062184434384108, 0.03512530369804271, 0.06691287722318404, 0.0652907320087956, 0.07865082277285476, 0.020063909769598997, 0.04370903160663382, 0.057496545806286804, 0.05515740358180577, 0.0329333690986518, 0.02498726574553838, 0.03371155355125666, 0.023565293560104988, 0.08700324958490749, 0.013463806620077982, 0.02344479176005529, 0.009883091552183032, 0.06689752482118146, 0.061620282189499956, 0.03324120620926542, 0.051493335274919394, 0.05561290797026408, 0.019868199202802875, 0.04396521906939246, 0.03052073031393511, 0.016461687740839778, 0.013587350746796978, 0.028155795824263367, 0.016730747395946134, 0.029872003229214784, 0.05951765428988203, 0.015078967985426708, 0.07501320748199379, 0.03821731116923113, 0.030396283161075368, 0.0576900328028827, 0.037806937020392194, 0.03790694596846739, 0.045614472304981564, 0.030936819478689186, 0.03647843330738045, 0.05051813982126694, 0.03537547354015612, 0.018091177823202267, 0.06275066024353428, 0.12056533938213704, 0.05672762335668649, 0.06171582484497659, 0.03323469829234866, 0.033345149018831795, 0.009914803761808623, 0.03530007133620881, 0.029789003348278425, 0.04532939566659831, 0.03220109629534906, 0.040991629639099685, 0.0383411722648288, 0.06597037457170025, 0.02295430588175453, 0.009583214095102684, 0.007328936696848682, 0.06896491267628248, 0.06191395816483325, 0.08003036326338207, 0.049698437233605695, 0.026895608001899336, 0.11821430747307117, 0.09569160595175721, 0.057309179852205905, 0.09917106239065047, 0.03449634168176882, 0.03463616421926887, 0.09213054582716958, 0.20249991377274837, 0.13154570824436604, 0.052216181366313855, 0.04757731980193527, 0.04411394354857264, 0.03502773857044597, 0.16497119690381712, 0.14713100097592802, 0.03824556832231822, 0.16009541498797555, 0.016635210486128926, 0.16958352118249864, 0.15030136392001184, 0.096160298543832, 0.14830570487726122, 0.055668533614446084, 0.03786482262395082, 0.1469549233274114, 0.0838813417020344, 0.1123056551741977, 0.24421772198571315, 0.05091816795268848, 0.13881845670121332, 0.06557735614478588, 0.008527757524843178, 0.108167861077574, 0.04681805389062051, 0.22246866967649231, 0.2564998887359135, 0.3073978357978406, 0.22319136638074155, 0.09503119985663122, 0.041477271926499186, 0.04894757147638067, 0.04020074727914987, 0.057671267479177446, 0.037238442323981755, 0.05537694139826683, 0.02594691152954775, 0.09031133981601847, 0.061103230297204957, 0.052226450774938836, 0.08237077719381741, 0.012240165979751657, 0.009842148940679769, 0.033183121422846476, 0.04534940971362014, 0.04413930871974557, 0.04450431514170863, 0.041989305942890146, 0.05878405615447029, 0.05402163992966375, 0.0875980862145943, 0.007342280990879743, 0.040175845591171135, 0.06535999401802979, 0.045862175343978795, 0.045486447521515434, 0.014777307458702597, 0.06530216204062586, 0.028557683634121093, 0.03397428340488865, 0.04403469558324545, 0.04174840576466053, 0.01015628233642107, 0.026459401368253657, 0.08188587418126483, 0.02824998441933384, 0.07849847852823236, 0.052228875443219185, 0.004605212588719423, 0.03122354703654926, 0.029220979795941425, 0.038064905637574774, 0.12993788887416163, 0.0410440530357582, 0.05879223797350161, 0.051376395783717596, 0.06588527752507119, 0.0233916386646489, 0.04686396170948302, 0.06505361247447229, 0.056427374346962864, 0.033269689358290166, 0.042859884429602854, 0.03222665681894268, 0.030185201040078557, 0.04037400572410515, 0.039322822009243315, 0.06745388851531091, 0.1007268414081585, 0.056909917808708646, 0.01204295483823385, 0.0054270228757823434, 0.027182919701801676, 0.048891187405153635, 0.06461600006948556, 0.04471745995444156, 0.03391722134584862, 0.05425182636827231, 0.04716965377390866, 0.034756631545361974, 0.05296621208770141, 0.020542381474027233, 0.04151820017385387, 0.08230785073171701, 0.16839711145768244, 0.1967440500494934, 0.16981457330046162, 0.1552098424684617, 0.08779924558175188, 0.11937661607178951, 0.20697467930374608, 0.1326136501325715, 0.12915102464537467, 0.1220617236028756, 0.205881318618213, 0.13658457495752843, 0.10905713594007878, 0.1651120804730923, 0.1221962026771038, 0.09864362617654186, 0.1202360594705228, 0.1397457295247624, 0.13835345665293355, 0.3129190927551639, 0.09259356170772545, 0.11759441210738114, 0.10745629563086456, 0.11631496866504032, 0.11787789528288188, 0.08049409926658677, 0.13815402864448487, 0.20245851438132026, 0.07294822514297501, 0.2068496537545035, 0.06359066033074934, 0.058364515763617335, 0.12468048025883975, 0.10159180830082587, 0.10733266436164418, 0.10760284058990018, 0.13943909517218991, 0.08654581082444038, 0.13740222059911297, 0.10971325960370804, 0.16539387825515964, 0.09003405429182515, 0.1763856771492189, 0.16906264268102186, 0.15355097099898324, 0.12018246395934014, 0.1836790793365048, 0.10777999076151079, 0.14705497441032242, 0.10011967076289077, 0.12672834053275087, 0.16155401575228862, 0.1267427506466066, 0.12361155011721196, 0.17293589129563303, 0.233722485962414, 0.1517171556911161, 0.19431982610014178, 0.14346847250576944, 0.21423518567556338, 0.2158404156685837, 0.08035729128506877, 0.14584224190442793, 0.3100407778495743, 0.21844433320145454, 0.21131162561716574, 0.1603105631206305, 0.12679905810904119, 0.1371774504021291, 0.3340762042470517, 0.2655343483051946, 0.2593186173227526, 0.14843472940546854, 0.15092051618041533, 0.15781483252442655, 0.1718257226410412, 0.3359988397888599, 0.3123815748239717, 0.281936903634379, 0.33530810427281166, 0.30934605867631976, 0.33644504003947784, 0.317987040165932, 0.24845470914677267, 0.2269708151899038, 0.18733639840877828, 0.10219873379795782, 0.1660569273536244, 0.299981614394534, 0.27677610636718813, 0.39285187939963034, 0.19300452974294463, 0.2175672544587043, 0.1628640414245667, 0.1514013436052107, 0.2359299376727112, 0.28728382962365306, 0.29944838655571787, 0.38249648506602935, 0.4398973694732113, 0.43993325303158454, 0.26525941467092884, 0.129377449592275, 0.13842926871392036, 0.1497276253517597, 0.12562807739502, 0.17592246974668196, 0.11555793590002483, 0.21529831653160436, 0.3057656088663686, 0.08604847420487674, 0.20306338676281516, 0.1714659830735576, 0.17450542159138188, 0.11398378609409256, 0.1989800461958493, 0.2605581475842384, 0.1284916757515842, 0.17892933420596585, 0.08832347954833701, 0.2062447966947671, 0.1672314014285803, 0.2853015005107849, 0.12961671417278628, 0.11636222862908918, 0.21928566628165785, 0.18831257828541342, 0.1508086520217119, 0.14808101128906975, 0.129637781590704, 0.19643755359274728, 0.1953093818719349, 0.12222625630637332, 0.1386033085685584, 0.25471046056237917, 0.1631125450254448, 0.19521063313849513, 0.13647384460895293, 0.1789956161331746, 0.11947505837005955, 0.14021790015601343, 0.12757987024322634, 0.07717040382445821, 0.09883836572689396, 0.31567654962981906, 0.2125817534303473, 0.1695697162781031, 0.1183400608058418, 0.1537923806256825, 0.11352035652605758, 0.14917997973820857, 0.1534220843666023, 0.19121272669684505, 0.1463581255126384, 0.16312752970524375, 0.18062844061322753, 0.14990593997701523, 0.14415825807279156, 0.09144937108841636, 0.22323540111462917, 0.15978121168671117, 0.13512473313077805, 0.05862205537156232, 0.1412731862717098, 0.15352486272252377, 0.1467346117621468, 0.10245156579560812, 0.11588543848765474, 0.10342370072800307, 0.11414130909308312, 0.13318642343003906, 0.08151072092474469, 0.09779138400429681, 0.12797519459479278, 0.17326900164686865, 0.24354005592965314], [0.010873527367479138, 0.018598854714523883, 0.038226768524656375, 0.012993844237268693, 0.03931045351970581, 0.015202220041124571, 0.030796498984038353, 0.03441781383909045, 0.08808071394601176, 0.06035013139368065, 0.031736523341087085, 0.035815495291664716, 0.026092924057475986, 0.024147083712441307, 0.049260204297400294, 0.04322602083125422, 0.03991012033375521, 0.13714435540380018, 0.06472275442173404, 0.04423393206971307, 0.027307110215206782, 0.023257163420860327, 0.05826967024815179, 0.040080482966356704, 0.025573294279315782, 0.031202205742198615, 0.010456279494739588, 0.009197096205166271, 0.012824444002622079, 0.06189870535426083, 0.050749777996492, 0.025047104873303926, 0.03687350868037151, 0.012827485371681472, 0.039631605238443425, 0.06959492040257301, 0.024227511453171893, 0.051495392220996083, 0.04573695827275515, 0.05084445497261421, 0.029087215098702622, 0.06859509905259456, 0.04696506616328994, 0.020664273723659497, 0.0372967224628214, 0.033762349011076075, 0.02314414246939123, 0.04707943925994539, 0.024563569327696197, 0.10643415813965183, 0.0610246335066134, 0.024970093884715633, 0.05657862691629318, 0.06662378628407756, 0.03362260308236845, 0.053733345721998525, 0.023341825712592374, 0.03182776441286889, 0.05744021536121446, 0.09936196384050193, 0.05795730172746605, 0.059749790422257885, 0.03146401437510166, 0.06908170278033904, 0.13800416652473713, 0.07595223209430134, 0.04358992791704593, 0.08295540953235281, 0.04103431988868021, 0.1279955955162164, 0.16279308636101986, 0.02462196629494429, 0.1262417521267649, 0.15895045061986293, 0.3380346724823598, 0.48370745573793694, 0.7357371141833644, 0.8361725893712814, 0.6239764692802584, 0.7088230358016107, 0.6691804372014538, 0.903460604529227, 0.585761061839519, 0.4703797321886786, 0.18959753756080905, 0.07142659066425217, 0.11697823226812387, 0.018593229713939854, 0.018030861805703853, 0.14899354458095568, 0.5730189971866146, 0.07581675710577158, 0.10552099665566798, 0.19467227251058628, 0.26472480787384894, 0.06835922824158784, 0.05976698526571836, 0.01587003516408825, 0.1610194549204842, 0.3130448231052968, 0.1950488200471286, 0.04586091512934335, 0.017931412101813385, 0.07599416008639721, 0.08487734793414993, 0.1201293740661875, 0.06183537286556056, 0.041810749999938474, 0.03935702783506244, 0.07275993605294535, 0.02865690542685409, 0.014814957807351266, 0.055712127847777265, 0.03292517578830162, 0.0827684534353114, 0.033412966952328725, 0.02488047117367387, 0.07563079692303173, 0.06913355927193357, 0.03225405595355457, 0.05607482451464861, 0.028531747727444576, 0.0684930025149257, 0.08046748537209727, 0.02334833937516857, 0.11956537247545297, 0.06914161851689701, 0.04531896920994886, 0.028123553098750212, 0.02866140810862905, 0.10654176284949626, 0.02639921750092218, 0.06279645314920815, 0.0087501528492618, 0.0568937839970233, 0.07524326368565522, 0.025441921691620545, 0.04102292816124616, 0.036852598310478275, 0.04856803236649402, 0.013949735232839182, 0.028994280972608158, 0.026188654404494072, 0.03744869132436091, 0.03163203660909447, 0.021805141436597033, 0.029303523854562835, 0.04082744550560752, 0.035578785614380916, 0.06486482542729186, 0.03085221464355146, 0.03602370649816529, 0.06315274149059288, 0.02145008075111095, 0.03706187820963321, 0.021709859251014648, 0.04765713084188681, 0.02625049110652218, 0.05058599605916008, 0.04295620466432264, 0.05091591182375147, 0.05156394942933994, 0.055157484021037824, 0.0069053293367276995, 0.013168091893256193, 0.025310033909796227, 0.007942655478649202, 0.00633696056601982, 0.01263013537672739, 0.0417830137866399, 0.052248326415616664, 0.019412263889887163, 0.010495939866579589, 0.014797807971556342, 0.036811926702578227, 0.058907017096756935, 0.05924936263791977, 0.08093722750462833, 0.061214221115674705, 0.042098067445500244, 0.08391948521978433, 0.024627602786847183, 0.056787722954346295, 0.02516724278158959, 0.07584285006047257, 0.018844261404968077, 0.018638829182412837, 0.014625555017001688, 0.030739145811587095, 0.005647300924700235, 0.060176639291908474, 0.0184230356206817, 0.012119591401349153, 0.0744629035433454, 0.040002859107428984, 0.08526960793401926, 0.030631422358114394, 0.09770604180953196, 0.033196665857347755, 0.09928520949136826, 0.08346856586755284, 0.017419121445967786, 0.023371308606358308, 0.01763884120831086, 0.05858367053611625, 0.046160183546523896, 0.036138056612183014, 0.09042345678373691, 0.05110156174088198, 0.07039316103703554, 0.04724948779649792, 0.06529757317395941, 0.04365289268354255, 0.060650740464728695, 0.10230585587240996, 0.07850600151164878, 0.04328875960181317, 0.04102192458606536, 0.03417188429363793, 0.057526511335445035, 0.06622637051247782, 0.028483262022716865, 0.04972940633794473, 0.06631333681364214, 0.06283947281659612, 0.0818671663141539, 0.06621933782533293, 0.061487917517942775, 0.08392337694643967, 0.01143249480294124, 0.06358813607103883, 0.024855295609262203, 0.018844236507110538, 0.013080438028179832, 0.00140559095128875, 0.08924086983766287, 0.06690082666013511, 0.07328326603577984, 0.09744280633786995, 0.13225086153514926, 0.06098115418647086, 0.02985910805422933, 0.18804210328286697, 0.08074489347035847, 0.057220669883874156, 0.17979076943330227, 0.24418094976534768, 0.18015490634547127, 0.0556081505642543, 0.03463136850886288, 0.06076107244758357, 0.19657730335189452, 0.5462768902221035, 0.6311346109836333, 0.3974344335015743, 0.6911538613419379, 0.2582130911609819, 0.6506507927852293, 0.5380287586200623, 0.3893366696373109, 0.18063044776358914, 0.06083542128063499, 0.05627631713005324, 0.0478919942472731, 0.0549693979443081, 0.014546633596652219, 0.4934521554218185, 0.03600614776294078, 0.14883833516749645, 0.04964278860678596, 0.061171764522911086, 0.10267851168229696, 0.020336167841789224, 0.07259105963091697, 0.24394081184460273, 0.32373980889397286, 0.1485953167561562, 0.03747879857978514, 0.015781818224387546, 0.1227660878230968, 0.12355933356429301, 0.07534605736333518, 0.08870233300953143, 0.07843585084042243, 0.08618194204304488, 0.008841045351038057, 0.015577588759873424, 0.048487746352029425, 0.04756875110850219, 0.022553109466248465, 0.05846889141286093, 0.033319718730185306, 0.007053304007352, 0.13377050418526898, 0.05981493087845945, 0.03326813419980388, 0.015353546346417599, 0.02424855780367169, 0.025842997448278532, 0.024261286354533607, 0.08785328542393062, 0.004334944429912515, 0.03545235429379729, 0.005825370401819988, 0.056295745119812994, 0.03523856979764758, 0.049984977099924326, 0.04901177730531462, 0.030988775561713887, 0.03394713324885215, 0.10941224833649975, 0.0525132128067555, 0.006964399024934298, 0.042365244439532684, 0.0605265882557198, 0.014833613963527306, 0.01000511978242186, 0.020873731738256834, 0.04181118283961569, 0.01778611969653397, 0.03687941138782809, 0.009044919542277293, 0.015777075182526343, 0.03693433606155938, 0.019396204771774433, 0.034504075339364434, 0.017237177479170987, 0.051873533220420924, 0.06667318363343516, 0.0029441323919942785, 0.01964186618645345, 0.033014122426750205, 0.006109710159381071, 0.035434600206152085, 0.09851489276174577, 0.04117967741143319, 0.049010700951781005, 0.0550878964244358, 0.03500935246026324, 0.025144371226610198, 0.024050740495083794, 0.09024424583560998, 0.007528872238547211, 0.06187063972315481, 0.057590360933494185, 0.060737381178525195, 0.023057363859768358, 0.03666474972100508, 0.017745409784237706, 0.05574185588967897, 0.06946001231910721, 0.07309600350356872, 0.10284509750143175, 0.1452515881148077, 0.1326078125425885, 0.0941476629926793, 0.18902963658253993, 0.16440337253434045, 0.1220299386148972, 0.1357191101077103, 0.18592823687339985, 0.13527274131774902, 0.11562581895099533, 0.10938710533082487, 0.1431203468312179, 0.10248738806694747, 0.08593939860621769, 0.1700514017213737, 0.12958496748920412, 0.2992942190218357, 0.24701106241874157, 0.1227510188736262, 0.16282601282000542, 0.22231614157076807, 0.1097656753394873, 0.13889616866025234, 0.10567997522171467, 0.09681525009293711, 0.08035703081517451, 0.07250219343170043, 0.0838728228043164, 0.1632332958040699, 0.12352175695160705, 0.2929644941562607, 0.15983627808670844, 0.1701380615873683, 0.09969664467198235, 0.17479475767862412, 0.16184712099211832, 0.16762422067263436, 0.1845041100656794, 0.20467607845221797, 0.13493927856606824, 0.22637971706928747, 0.21088548154840547, 0.09067614322468158, 0.14930255380609345, 0.11293169456504046, 0.19515123068084642, 0.13382622942088113, 0.1660257169315892, 0.33730011673704274, 0.21057385230256667, 0.13730331864808837, 0.13508797623217106, 0.15245549591077914, 0.13469043788650345, 0.2038816912400146, 0.06434288206360032, 0.12715757959672522, 0.1384163371497585, 0.3025302050575134, 0.17731897142385283, 0.11762245092540981, 0.25128508227006086, 0.4448090655909431, 0.3635424585832704, 0.15587693651116666, 0.20336373919440856, 0.2144505483128371, 0.1600933618723385, 0.28328552481628233, 0.48630329870408584, 0.3061316763201068, 0.18230185243150882, 0.29511848825120157, 0.4469371965575603, 0.5068210025708522, 0.8074626783209463, 0.9443378917151882, 0.6798715925505084, 0.9907896023604178, 0.7674082921397302, 0.944423325840504, 0.7892021452707629, 0.6612703035916052, 0.21670451688189662, 0.16728072216914547, 0.2850336148854225, 0.23580837484088638, 0.15255107304021237, 0.28099676053370204, 0.7682007947756399, 0.21347236128584032, 0.40989715185376907, 0.43554461110503445, 0.47697740396664995, 0.17029866425981446, 0.2745900285099783, 0.15822000110582, 0.3726535116232211, 0.6709579450468863, 0.3593071261721273, 0.2019498779648735, 0.20531772305407833, 0.14546633788174199, 0.21385736643306671, 0.21898957329892346, 0.1981839735902125, 0.12945142304224352, 0.14174299735215404, 0.2503957614422806, 0.15355083310315687, 0.1715259217927533, 0.13263692388371115, 0.15429304972771676, 0.17331970134569755, 0.13720568840301808, 0.14413515286099526, 0.23015558058696411, 0.22577260771105367, 0.13838417677869722, 0.12160751773344895, 0.09339979263923823, 0.18354286890356772, 0.1965526199989742, 0.21709471610524964, 0.21550093146581806, 0.20090151728401262, 0.10432087395700718, 0.18757123500108722, 0.1458370937935768, 0.16985997167085448, 0.19188104648022883, 0.19132181761726258, 0.09302732069045307, 0.16836352616308198, 0.1438334980799306, 0.09315026248054159, 0.13794727683548005, 0.12625359584607426, 0.15414494961019487, 0.09462758643372406, 0.18385713349186605, 0.15402464316256587, 0.10825824413088062, 0.1827844112150131, 0.13071592777006089, 0.09181543854215453, 0.18598048406983578, 0.1560387189590162, 0.25092751839228217, 0.11572752478382281, 0.18599336966872218, 0.22139518131171504, 0.08280648203987269, 0.20530997024428463, 0.07703425467855508, 0.13220498819024334, 0.10378175490205327, 0.1786573883146048, 0.10722847640394204, 0.11612025209732595, 0.13227468686959437, 0.12766370324478035, 0.1261159758113565, 0.07313757143434017, 0.1710115550386329, 0.059937910972944194, 0.17524386906335432, 0.11312225127532599, 0.1264114559237515, 0.12449455071961689, 0.11135484046873548, 0.12543477808996556, 0.08746135484186873, 0.1484534985596134, 0.12234968839273339], [0.03421711795512707, 0.07678785015858951, 0.04147598872922602, 0.025901570615749207, 0.017010576332048062, 0.012510240701357684, 0.00324922475321669, 0.055296394913907976, 0.008748403295964725, 0.015165440159879867, 0.055154369873625625, 0.10609507230260681, 0.030374284946329655, 0.035685539966629404, 0.07151544920258945, 0.03793049934169939, 0.0357835800687392, 0.07060195830079817, 0.07238659842480576, 0.014966839526389396, 0.04384929464469033, 0.01125998137849233, 0.05490394339205758, 0.05933477761103742, 0.010012104589071487, 0.014786329101620903, 0.03171149716382066, 0.06479094390787425, 0.01989904764829384, 0.020887308731494893, 0.07628544203696713, 0.0983870939742173, 0.02628743952711023, 0.02050107784358965, 0.06639730005014328, 0.034159159573215636, 0.028743343127350655, 0.024403717421415835, 0.018634179028712453, 0.05325466717383074, 0.03782764437698549, 0.029037840731982744, 0.09817143256265311, 0.027423526851400256, 0.10555972240024036, 0.03646065623709752, 0.054902223524667566, 0.04125566184220295, 0.09615650640860682, 0.0553752177004372, 0.05279705987402028, 0.0208431571691988, 0.12214985435768483, 0.010536536780907022, 0.054009432318590345, 0.04668980311121672, 0.09114895736978901, 0.05223997988768163, 0.14683846264116227, 0.2047018190064738, 0.04923984551081254, 0.04472235142583809, 0.02344263330732863, 0.07742130528053931, 0.10451891534631291, 0.04735236574384955, 0.04129231531894015, 0.048092211326283794, 0.04270179069510872, 0.5168320250607307, 0.6290115055537994, 0.06226705191957374, 1.6982352733612063, 4.769833059080185, 5.130804863668257, 7.41399153586357, 19.21819394634616, 24.827773609469016, 31.252200180484405, 30.77223150960861, 27.08076342459648, 29.88169070213072, 33.66761730563256, 44.09534823509955, 66.0198050160562, 70.85982937966624, 72.89432356434484, 80.79133341389318, 79.73027736909928, 79.39591884613037, 55.191380439266084, 16.68587253939721, 5.68027057955342, 7.429129433247351, 6.698290378816667, 2.0850763349763812, 1.5335675545277134, 0.7682026333866582, 0.23707730755690606, 0.6242975520510828, 0.7890271707888573, 0.212647560383043, 0.10124458661002499, 0.11522192207555618, 0.11295056331061548, 0.1738490068143414, 0.06856319915142751, 0.03160179337306369, 0.05111330969920082, 0.024205614745076147, 0.03607118479727257, 0.09341782634897579, 0.03814190896528383, 0.05544660177322165, 0.025009698715181123, 0.0230590358466631, 0.00861936153077911, 0.017195395043780728, 0.05022956599150935, 0.030370081038845163, 0.05881867566776853, 0.06600028264426416, 0.06193153605225587, 0.062161791438777605, 0.03629553747633773, 0.05575129026246648, 0.08075746497319591, 0.03005150720597275, 0.024500003182179025, 0.0318242231714389, 0.1040346481867375, 0.03483825821369406, 0.01121472090392584, 0.04507688542587623, 0.0687143559597673, 0.028762353599191676, 0.028937192100490776, 0.030912737504789428, 0.01995938664842998, 0.07707369288489704, 0.04757614002653188, 0.022919236291800777, 0.013480739078424392, 0.029579386370436802, 0.03166269161738455, 0.0160822156636465, 0.09796124867974751, 0.028774040270476576, 0.039258719602179144, 0.04557837807242909, 0.05664985394105316, 0.018780835070497087, 0.03626688961840926, 0.030724237740580595, 0.05438257459430926, 0.06283356244826029, 0.0406509043738967, 0.026147337367517814, 0.010989813768725482, 0.002880955275501155, 0.04682569944810483, 0.07649429292688448, 0.03511421840577837, 0.00845307257071498, 0.07497242862178434, 0.08182540686140138, 0.013532855082303287, 0.04731413412598833, 0.034269863108713786, 0.01019946096705333, 0.017371156681028586, 0.047929900277766495, 0.003087277117658467, 0.02687291456236234, 0.03863300196826458, 0.014180269283843378, 0.010224968822102153, 0.02888721826997015, 0.053223774678284125, 0.056797701249560045, 0.0841601440803178, 0.011398154911735367, 0.05750624064896857, 0.07076459110624368, 0.055083610162499456, 0.02955228217967576, 0.07729814898583197, 0.11020162533367835, 0.03872098333592858, 0.04957210550445223, 0.03181671167934134, 0.08003474528630895, 0.04688283428549767, 0.09073106406797325, 0.05590641157581441, 0.04815799146590214, 0.01947514247149229, 0.016577070158335473, 0.042310810062072934, 0.10757533037253927, 0.03824980095809987, 0.01870895304056185, 0.01728589492549579, 0.0400352378135487, 0.03642760337360444, 0.012701329842750585, 0.0738143258457703, 0.07192149878509584, 0.03084599209438649, 0.04231945919473806, 0.029150346489322763, 0.035372673488792875, 0.0276198502885358, 0.04031975520774722, 0.05808122794053728, 0.06527722587869053, 0.07816817971967882, 0.07010959359186311, 0.024166791324293422, 0.021470688516274098, 0.09754068939195526, 0.04299561988802687, 0.03016133740123722, 0.06507739950452121, 0.059697573869338924, 0.05397873517546443, 0.06974053839522024, 0.03654075839046029, 0.03540767221561363, 0.03669907812089209, 0.02672162560385562, 0.08340256739287608, 0.11632844415162841, 0.04161286948909683, 0.10177666531695474, 0.009668147390437944, 0.02852950500504625, 0.021734944800095215, 0.10482188779860736, 0.07077051296589837, 0.1504093823173354, 0.010420901554396317, 0.1830551773309708, 0.057964276958016626, 0.020600958471937526, 0.5888900713574502, 0.6029623097950413, 0.11705152389983978, 0.8716102232856136, 3.2702709830576375, 2.9548077429494555, 5.372389526136461, 16.8729676354316, 23.216611031563055, 32.1727628092612, 33.923975575354795, 26.90624344733454, 29.215066240679835, 34.78405329488939, 43.62477364078645, 69.48331279139366, 77.49804865929389, 79.98059518875615, 88.0658317381336, 86.86470785448628, 84.54119774603075, 61.422151750133885, 20.43737446108172, 4.052091534099271, 7.85154075391831, 6.340642782949633, 1.8976558047917582, 1.3268846321490504, 0.5393431816370257, 0.2709028473304164, 0.4994540865863524, 0.6161488893051302, 0.2079952922799895, 0.042861627279630596, 0.04715004958392632, 0.1656656249636604, 0.13899592862975213, 0.06263256779000645, 0.06938041578377448, 0.05568261431049436, 0.0440114563060624, 0.04413865371457031, 0.035573679638365586, 0.027530616367115613, 0.05037649016406748, 0.01745777441218736, 0.028870617144650994, 0.005173026903292104, 0.025577513508558757, 0.08817662049325244, 0.07534981885504338, 0.017833766534984592, 0.054521623383005785, 0.07574800837544665, 0.07213909073822922, 0.031912093456353874, 0.05084419450271995, 0.07138867697287953, 0.0748287411707063, 0.06778090846754851, 0.019715324442292896, 0.013012290676875461, 0.030516532152110053, 0.020669513765061577, 0.070300824459522, 0.03492987083811914, 0.01278917618741792, 0.009590752400277604, 0.014051288805691706, 0.04488299623312009, 0.027878768854744496, 0.042992409979624134, 0.0475998925826242, 0.05569335869363239, 0.018386066132675738, 0.028821566450079123, 0.009473969957100288, 0.04028761398888404, 0.023414192293139718, 0.018854312478534637, 0.05885533680538497, 0.009146477903179344, 0.016025038691417828, 0.05895423492596996, 0.02545771842461921, 0.020109664370876648, 0.024374933582880808, 0.017260347808440848, 0.04679802069140058, 0.030916165748250582, 0.02070910135854877, 0.05844961281024641, 0.017272220256047386, 0.058186607164961685, 0.030935448181304722, 0.0374827477630348, 0.050087414546719486, 0.013922645406226718, 0.030558410348490845, 0.020444749313737118, 0.05603923206968654, 0.0217417074412468, 0.015458303124403522, 0.03297373427138214, 0.049355923153099515, 0.07515083517759077, 0.014975759662657738, 0.12629085070183202, 0.18197857864922096, 0.11880013490876845, 0.1638401753359264, 0.15003888687539488, 0.08784743251218911, 0.12407168550717255, 0.17693180590868, 0.09601609015296544, 0.17361504356226615, 0.3070145160440476, 0.22155465017403328, 0.18397578518957863, 0.10563594814870628, 0.11125666630123893, 0.23126671451234052, 0.13477996292133487, 0.22058107499634066, 0.18287870131673353, 0.07962169366017466, 0.14450259927299716, 0.08093739604397167, 0.17498479344912116, 0.24150215479875767, 0.10761276908939886, 0.0897290593674106, 0.20914842314537496, 0.15636593043323488, 0.1466452859101757, 0.1208149461496261, 0.16885065083061496, 0.23031126497493637, 0.1359254635509945, 0.16404804563330067, 0.1844644113894432, 0.26833136596025964, 0.1047698857503072, 0.1521360985333881, 0.15902876012748288, 0.16618058926636176, 0.1251663255595392, 0.11872693520760345, 0.2298191607358956, 0.09351727988330588, 0.18710243515670302, 0.1284783381608225, 0.18206332329540484, 0.14240000967777547, 0.2001959656275088, 0.1775903044448745, 0.16408097209228625, 0.26040707504557026, 0.2536026208150772, 0.11222929152990542, 0.18660283857776275, 0.2075068039759513, 0.32187922647403133, 0.27218166258065934, 0.39533136893183957, 0.4182081639526352, 0.16087526185137613, 0.1250276406626067, 0.2644338476802072, 0.19494100083266536, 0.3145733830188552, 0.17909978876911825, 0.16852852618021352, 0.19590604179088147, 0.13744602550662335, 0.8447105473568364, 0.8879253220173621, 0.19071381959703662, 3.0755981129984704, 7.483729806638534, 8.178546793999212, 11.666944949857651, 27.29571323240957, 35.32051978572723, 50.58532153406451, 52.69895738170993, 47.26081863526375, 42.074790231643185, 50.20540075917398, 62.970558366467884, 93.85730543444234, 104.83169709482502, 110.20062169721051, 114.12159550574519, 113.48628136419482, 111.4089313630135, 81.78563856309461, 35.773859485503166, 9.616306289549797, 15.032621948949753, 12.083500662157613, 4.137186129246989, 3.0370895083873504, 1.763767414996701, 0.4388945910238451, 0.7117595427459287, 0.9293378901577766, 0.7550506197637128, 0.3107646390074684, 0.15659624710679054, 0.26712961915519934, 0.24499517865478995, 0.16464262179309325, 0.12281230590756863, 0.32274153504160147, 0.21223154399664174, 0.16776649852193173, 0.23083989628620688, 0.12708009746406349, 0.25498366283793605, 0.12702661686606947, 0.20029685940713654, 0.07213430268870247, 0.08680240431379888, 0.1894825017980991, 0.2897611741096743, 0.23627588765755778, 0.1733812794930512, 0.21379869941982532, 0.160278617254188, 0.11883070181694724, 0.12235924917002841, 0.2172362585101397, 0.1421019708317134, 0.22070918021903885, 0.19745312571044893, 0.20293203332731802, 0.1745191345652265, 0.18828242506471374, 0.17797357823339202, 0.1351510865553733, 0.06821105151527351, 0.059999665320520444, 0.1021437286849945, 0.13903306857232126, 0.1595618653922312, 0.15192714039116137, 0.17782782234491842, 0.12175457597139383, 0.154544587036775, 0.200453938075131, 0.08228982468285868, 0.17113362348848776, 0.1682842820281944, 0.1387453565914785, 0.15127553664628537, 0.16165428133981843, 0.1615245520107208, 0.08259509539892597, 0.09905188975314941, 0.08820356380554938, 0.08868139582656084, 0.160613979903921, 0.1063949037944117, 0.1209145988668165, 0.1818995949842276, 0.13109264384594657, 0.15324968394012223, 0.15824401030136695, 0.10039522492837522, 0.16967880719852063, 0.18019414536895292, 0.18347931424936942, 0.15646038907429866, 0.13057513613133662, 0.10963179381384004, 0.080658900100858, 0.15291364713301583, 0.14023898289568965, 0.12473043685238208, 0.18658589271287765, 0.11100049416023879], [0.06363296753636773, 0.05267057109684233, 0.021860644506711154, 0.029860075240233735, 0.079231632332648, 0.030655787784546137, 0.037197391502559185, 0.05304834820450314, 0.042599134913255135, 0.04185991369247918, 0.044335270180336894, 0.051249638875766154, 0.02879623000720336, 0.014045242456749324, 0.07968599141965951, 0.03094283709933441, 0.04555621514877966, 0.033924974155642336, 0.023408766475416, 0.06708412085689845, 0.05246213772484372, 0.02729243005535776, 0.06262046743124243, 0.09559009930179005, 0.021210195639381008, 0.02911960338092139, 0.023522565006128242, 0.056453425166828025, 0.013284016317958313, 0.03877192052201398, 0.027711332678013754, 0.014308498038219349, 0.10370208941880735, 0.0385069728438412, 0.009395208457605013, 0.07464673400165574, 0.02443960097978913, 0.0437395065842617, 0.02030181454404468, 0.027328698572913007, 0.05014186424593772, 0.027868060860782865, 0.00791319987676557, 0.014559309478969345, 0.012856051832767985, 0.06389555566373371, 0.009218540921386693, 0.053578982835695635, 0.05731675646177704, 0.04840846774318526, 0.05256832134158862, 0.027310910011311213, 0.03763321509224273, 0.03643036512057147, 0.11741009901367849, 0.10590995481658368, 0.06036418527665158, 0.02685249257352083, 0.12210873841878869, 0.2614902314399519, 0.06900509398791098, 0.019847087734829516, 0.2323457187101726, 0.4067739339605455, 0.3536595566378486, 0.03761480216898265, 0.028410797765959176, 0.1436581558758213, 0.5241212597297085, 10.670151056781894, 30.939940291066325, 50.3288612827178, 89.45477439511208, 105.30464864546254, 94.15961034836309, 109.20210392244401, 116.4585279649304, 122.46931706705402, 126.47040136398809, 123.72823315282022, 124.6707316367857, 128.31982243445614, 133.47331477749734, 151.2781140112108, 130.07222760108212, 131.4565340165169, 141.0283959296442, 138.06018152544576, 130.86202036949896, 132.6060159744755, 142.80902647203015, 99.5358854724515, 56.22689400949786, 113.82023196066581, 127.3313694615518, 109.72159831754624, 105.8110737031506, 99.62540964926444, 74.92201635914465, 56.657562409677816, 31.48624408629633, 7.52519416232263, 2.0607355765758024, 0.5553314366167592, 0.2949717977354604, 0.46314400110033255, 0.13664322664901135, 0.11914678969450536, 0.10388556747667252, 0.15089115969115688, 0.07466807721122619, 0.09099225408487743, 0.060701612533340533, 0.06123258807365933, 0.060338191913380745, 0.02988612031443946, 0.016820575035507643, 0.04543229659658767, 0.040137204116270433, 0.032894317766711596, 0.027475119042660923, 0.05234443214571765, 0.04056817453895365, 0.007586660644700451, 0.05129889066841814, 0.052042654790585084, 0.028756952679325497, 0.057157804708807707, 0.01788529935443113, 0.02831870825180123, 0.0271558633915359, 0.05403606153483834, 0.040199904582433166, 0.037361211744287325, 0.048477630160989306, 0.06091851883778169, 0.06062004332160277, 0.06836172568822099, 0.02745203298306273, 0.019274693650884495, 0.0599872010699924, 0.06698352585156118, 0.07053065083680615, 0.02435822520525225, 0.008290446468538815, 0.03938838764424286, 0.005752262631205903, 0.024620098955628854, 0.0015895583478155576, 0.030449832706982573, 0.020653828114811933, 0.04325378385763015, 0.07035636583403235, 0.0146141029601436, 0.03373540186833951, 0.030426725579966462, 0.006054357912827043, 0.058013613020340284, 0.0283561431382212, 0.04122993277926599, 0.07592584036530987, 0.05151444099723332, 0.05212705086676344, 0.031448221472542615, 0.025032953314122655, 0.037024588879918864, 0.028246462330101963, 0.009825539196871463, 0.0050886174205750714, 0.016066392117570487, 0.03145372389905876, 0.05943526919450491, 0.049570546515526316, 0.05976125492804474, 0.03932944866978834, 0.020956365812209346, 0.025165733588378758, 0.08014031986315405, 0.11610928171825026, 0.04144688121854298, 0.02605339009014349, 0.0005227320751498243, 0.010779753417497682, 0.03596458366260894, 0.05455400975000474, 0.025658636474080627, 0.025429807926317858, 0.03528941888362169, 0.0319099330884074, 0.06119698796781802, 0.05033462345900555, 0.011012535936559641, 0.02375098178163171, 0.08050746750086546, 0.054342852935435317, 0.05589066846897045, 0.050433720762450854, 0.032301783231237245, 0.030777116959554054, 0.0823229196811876, 0.024856096171143077, 0.04465279447275304, 0.02613385996570991, 0.027174236095179955, 0.03550168269524171, 0.019633866313304153, 0.022202587851713744, 0.029277325562772252, 0.05184430696610963, 0.052183323855241465, 0.030149957165122036, 0.06514280043061703, 0.06894515526871528, 0.11522129388345827, 0.013060402913740086, 0.022009836299525156, 0.016191605358354507, 0.052689757768905936, 0.04300322714111498, 0.03908553393557668, 0.08559873462804864, 0.01996727735405007, 0.06637390372493575, 0.050578545854096456, 0.03888337865411755, 0.025669204656996077, 0.04408320044017127, 0.02840367123304356, 0.03807686810051242, 0.05957441374419197, 0.07362229058579092, 0.04378925250362485, 0.06127950712858189, 0.053151095916907636, 0.06819455764226376, 0.16822619724177545, 0.04691135190847901, 0.06560332652541899, 0.029422403463432868, 0.3130329640642289, 0.2992256081873371, 0.11832498419549196, 0.060324130369530576, 0.17137661125631104, 0.22959995233724195, 10.798415503194256, 34.02270163259199, 62.93724175422423, 104.30521303607573, 122.29397927561115, 112.96182909319478, 130.31098227347098, 138.174683355516, 146.53502710403936, 152.73055199653874, 147.56841474963772, 154.9609842608052, 154.88093653032857, 160.81267418399935, 177.87307031692998, 158.40874764227098, 159.43863653367566, 170.77977764991024, 161.39301238521455, 157.09305917063068, 160.82608868998867, 168.23328079715853, 127.79703324840916, 75.31029962724256, 144.05532037058185, 153.6445426940918, 129.30064247500513, 124.16100394341254, 119.00481300969278, 89.08105096509381, 63.80643898440946, 32.026166185255974, 7.803073006291544, 1.4417278309983592, 0.5714022452312132, 0.1946226146913344, 0.3657632249016916, 0.15768980697518395, 0.050058839467143824, 0.10673360658749458, 0.042912867070446094, 0.06727493037619899, 0.07428975235069953, 0.10848106846453683, 0.06890790807383676, 0.01024111699793608, 0.0447918126179326, 0.05318586864779073, 0.009889342829645162, 0.044949182399338296, 0.0409430060385456, 0.03450081946568624, 0.03128238833479343, 0.0404663652842564, 0.03932448825047862, 0.033925870478513746, 0.059896906116797086, 0.03359843683879703, 0.07852804952210958, 0.021575604257504308, 0.08214987574085113, 0.028963880688552896, 0.04757862215140655, 0.013060720840228662, 0.030023985497292974, 0.0352523363976469, 0.04102189394254838, 0.01865565630366966, 0.017217157686489726, 0.039855854495638804, 0.036558206042935776, 0.04528069162681218, 0.021409564276015567, 0.04890153342257104, 0.011730090275617137, 0.09190553048204991, 0.08670982258814959, 0.027376280293890068, 0.015551832883859114, 0.0220357415626847, 0.011868872848759976, 0.024502540848428206, 0.0580614552112116, 0.027411943601985133, 0.043319054548778844, 0.038124618360832814, 0.013276458860585287, 0.04348535691538165, 0.019811299937446753, 0.01615555326063787, 0.02580794509530308, 0.05364307758188056, 0.0175172898678049, 0.04018164487675794, 0.07785750808374536, 0.05804105045934839, 0.03281613083315953, 0.09272951933164751, 0.040318778445643765, 0.04129720679033668, 0.009399121251678275, 0.08087661462805926, 0.04887792642318434, 0.048383650324878194, 0.027998293892690734, 0.025864311929551825, 0.03882306455183895, 0.09488322997405645, 0.21550934311122666, 0.34710248751986417, 0.1473294790353506, 0.1904006888188662, 0.10070504620671274, 0.14042026994209136, 0.14368446333514107, 0.1411477317132296, 0.1568517374295381, 0.09368166703009799, 0.1056146892088075, 0.12537036541729205, 0.11235683750841888, 0.17997095331309304, 0.07948121611749934, 0.12496531174908723, 0.2596752772167806, 0.10682756727140759, 0.10817647956672216, 0.1105919930963747, 0.11608510398335996, 0.20507323375392347, 0.18062991150204213, 0.12211706579452562, 0.07083338580184406, 0.08868696528577036, 0.16034788692430144, 0.09081834446518652, 0.14378650624665523, 0.22427980878180076, 0.1042181492272404, 0.11927204507012522, 0.14758682329087489, 0.09440948120168141, 0.25477740132520277, 0.1380853412011939, 0.27616930344412405, 0.061292879193300204, 0.11053190115959415, 0.13326157665541097, 0.14846088364720345, 0.1824752181287735, 0.0829706010558913, 0.16598574246370024, 0.15316899955993699, 0.13176624963600791, 0.16827495107727666, 0.15544660960233983, 0.16178212609262238, 0.1778212493105281, 0.12963067229476669, 0.10237240593039221, 0.17844227082546682, 0.2514807258041636, 0.2566048734250569, 0.18396636230810998, 0.14928781427443027, 0.3234235065117959, 0.3560581166417368, 0.1321821281265828, 0.24277321723920686, 0.33124964624162645, 0.6353876247040687, 0.6287898303520295, 0.2514776920959834, 0.1288061471836221, 0.2706909167670435, 1.8484773727193957, 17.104581632921775, 47.7876635520689, 80.26477090774044, 125.79074875000985, 146.50730379166143, 136.67459641733478, 151.4467602391397, 159.22764439736645, 165.90103949269943, 168.08686656336633, 166.045163062311, 170.11292765217445, 173.80718846474926, 181.27218061877838, 192.86096449821227, 173.8612073467624, 169.3574791569864, 180.15863541633854, 173.4483229729437, 169.34081692849438, 169.3520192177065, 185.36702525231146, 156.8736731621527, 106.81552994635798, 167.90038139589373, 176.02558689732706, 154.98975876838932, 153.27621644543063, 144.06765230240362, 113.86504111751434, 84.21972028670773, 49.186463125290416, 13.749239098641182, 4.296057320410206, 0.9658910093768951, 0.3566874119062578, 0.5364196675439035, 0.38665294106448855, 0.23792210335452713, 0.17420680051849735, 0.31816933844839373, 0.2598125295292947, 0.2313988493575204, 0.43570922807820384, 0.18814911044413046, 0.1896222975225218, 0.10997061918099081, 0.11206740182974648, 0.1617075857375899, 0.2637900580321589, 0.18322272076001092, 0.13864794085102697, 0.10295328443809863, 0.11147649523111121, 0.11984597516035843, 0.1012126790479787, 0.10753783036864574, 0.2177140828702719, 0.14081330369076422, 0.06762255809359974, 0.15456352473026322, 0.12834549851475224, 0.09745019908633926, 0.13315585652186027, 0.10516448231834559, 0.11548136541199301, 0.22679423192335715, 0.1211049180898455, 0.1718464836237892, 0.13207300656264828, 0.13170189825036835, 0.19363944809282982, 0.14218401884840381, 0.15652366793684422, 0.0804525466575738, 0.16120294830010784, 0.13951829334180202, 0.12171300804062236, 0.12899632084994547, 0.17788432899021334, 0.16481151353688012, 0.2378337580950991, 0.14385983618276735, 0.14253813533052323, 0.20346873920531044, 0.1563515279802584, 0.17681033500740606, 0.16780173856644862, 0.15133201264806334, 0.19880271216313686, 0.12698998254153038, 0.25194411706780234, 0.26690077337045826, 0.12522641749631974, 0.15610310098817273, 0.19655013787409953, 0.09804245399972124, 0.1446717514866783, 0.15149186455434369, 0.16788274470356204, 0.13483171982149925, 0.16728418488656321, 0.18738018799453013, 0.1319777052248678, 0.13456021826113426, 0.21340506812257154, 0.09951567172162956], [0.0687180944688378, 0.04023658487224772, 0.07097076068842603, 0.02424060389579785, 0.05652003268140459, 0.03378378032075782, 0.039946157109713366, 0.02618263869906866, 0.031389133110942866, 0.04587755838949834, 0.018791296001103137, 0.021426207536170562, 0.0743993335673886, 0.017423258320758903, 0.02425602141527399, 0.03386947491596784, 0.03398762099565037, 0.04377589576066502, 0.03980588641077761, 0.01849538687947056, 0.020373376732271527, 0.07557684901140391, 0.0170439969177448, 0.07699932106920788, 0.06559798689258677, 0.0833765127425713, 0.03469723291815289, 0.024149866526826255, 0.0221114118974055, 0.05356308268082719, 0.06761493551875315, 0.004113336260836091, 0.059483509751096855, 0.06369839910598052, 0.01937793357478034, 0.04690711544225774, 0.035226009786129, 0.04231746736613493, 0.045880232036354086, 0.05220567830087197, 0.03446786619362331, 0.038851743053284385, 0.03531012240977537, 0.02275721827191451, 0.038705795642829714, 0.04460500207759681, 0.019011082796139583, 0.06335059135791755, 0.02624979779695071, 0.024707800701200485, 0.042579833328002886, 0.013566139687393463, 0.03892714525723169, 0.08930533613649108, 0.047985541243706985, 0.05711591885154767, 0.08440596637346091, 0.12115435374359931, 0.6088556709789461, 0.24654526563902057, 0.4587692406869704, 2.1273854711363396, 4.337423126543722, 16.10224739197762, 28.742130379523005, 44.96103494398056, 59.24386739730836, 68.63584549196305, 88.07435897088821, 98.43903387746504, 111.45393663837065, 114.65983883027108, 116.10975080920805, 104.14600403078141, 110.94213008880617, 113.98400660484069, 109.16672414348973, 99.89059325187438, 87.45525206288984, 94.08385369085497, 104.54967083469515, 104.3485160027781, 114.86300191571637, 88.74308386156636, 109.8013714821108, 102.60772105186217, 75.28827159635483, 95.37272883999734, 104.50084517079016, 96.40105662807342, 103.56254362290906, 105.51156151679255, 120.1848816102551, 113.00367293819305, 109.1044996630761, 91.64127611344861, 107.67532133287, 106.93626834500222, 122.38068719064037, 120.57511037395848, 131.3539718812512, 114.02690948978548, 113.20845988488968, 84.29291171412315, 51.45801359607328, 21.05661669085103, 5.7514792488467315, 1.7983955697667215, 0.06401710317380006, 0.40377638513042086, 0.07591015088462061, 0.04662447113303408, 0.04857140315336086, 0.09367069665102229, 0.011891363274997041, 0.05317454969870949, 0.07739770977247147, 0.10644327458595076, 0.03770035503792667, 0.1151260844762287, 0.03337566613129551, 0.040139567497516834, 0.05014931062056173, 0.019033747507379423, 0.019936947933127804, 0.07425252047757949, 0.03115384261153879, 0.07799492127472356, 0.008278498369749756, 0.03712038434441051, 0.016745883378110105, 0.06071170191130331, 0.031107969266632875, 0.055602853066257896, 0.05228123755284375, 0.11309958273364652, 0.06548207012876388, 0.019688716293462825, 0.007444725140944244, 0.053664654448267915, 0.0429344515977127, 0.018436352144025506, 0.10078399156730983, 0.049042562548551834, 0.032139215543265306, 0.017766115225611195, 0.08499092046892451, 0.06324615442164003, 0.07819783498322772, 0.016600749936074983, 0.07020584487866971, 0.028203724200026165, 0.031365493552819375, 0.02687125215156665, 0.038423791017022826, 0.020716905879277377, 0.0741312487591659, 0.08756665362706108, 0.09730881755991329, 0.039549170347351226, 0.04955133303038536, 0.04662112332880498, 0.04909391725255598, 0.023227439209398244, 0.08411053988722064, 0.012968213808151984, 0.05199850897394842, 0.06160607508894417, 0.060466523132016586, 0.052047032983072346, 0.055766539242599285, 0.030504223034386675, 0.018572581729160684, 0.044189407039553895, 0.015286368096337445, 0.02037802880119172, 0.05943979677413741, 0.04629488095581051, 0.0751557611229439, 0.03299901517288339, 0.01907547440139517, 0.02374445471251684, 0.06607236385705971, 0.016236371706209837, 0.007465564168899531, 0.038589116621522174, 0.03159810465970828, 0.04198525333777071, 0.029080942753822576, 0.04704379318882862, 0.08189752637859314, 0.036207575260871844, 0.017888168353707563, 0.03058303241437722, 0.06738203712889264, 0.003855043253298068, 0.05410575638374975, 0.0601688405168393, 0.020037663597313148, 0.03233201689116898, 0.07219354426788707, 0.017824207672909383, 0.04571739238716903, 0.04063148787545581, 0.04996284481979186, 0.018517731749002012, 0.0523823113631337, 0.019574469601314877, 0.04128067461293071, 0.04132571292199916, 0.05614065061954241, 0.06715334456173644, 0.030287485269288865, 0.01024368530770223, 0.04178034013978416, 0.0417375005030584, 0.026965413933559775, 0.04778460021160784, 0.006120655640599228, 0.019751533588034012, 0.03809851774525258, 0.03650337713019502, 0.040926883718179125, 0.05913091395350714, 0.034999795513407844, 0.01667850977560926, 0.02108603385427306, 0.026223817840218547, 0.056668508182009386, 0.07467532440298989, 0.06819447337259209, 0.09228245340167515, 0.040696881140672395, 0.04568807803274644, 0.18046727103571739, 0.14395388113635202, 0.3518229068046616, 1.5569772403086386, 2.6303340831110558, 14.317018851157158, 28.840060195615216, 49.16020285698676, 66.24210142320203, 74.03709042456843, 96.93710342530282, 113.81459159235801, 128.68181797765916, 130.84597003075385, 135.0404428666638, 120.36560873831473, 127.36733759603194, 128.64046050656228, 130.88037706190542, 113.98197481709143, 105.1540296308456, 133.9185194815359, 116.04541609364172, 119.49608987377538, 140.9896899807838, 119.04245991860668, 126.72288433198007, 129.51656110825078, 111.02853990370228, 127.25398894279235, 135.03686566506664, 127.05529735934351, 151.93231828751104, 137.64571251407747, 162.6428834853634, 145.1367021376087, 122.59477015464537, 123.75692136826055, 139.7311269083331, 122.2097267643098, 148.64926307432114, 143.9083883839269, 157.48242501289616, 136.23889953859393, 128.032304856085, 96.13315090056389, 53.609676822539306, 20.776528081586285, 7.022436520745678, 1.7165213631045435, 0.08093722750462833, 0.35953162057745847, 0.03612264675358611, 0.050621776195663604, 0.027718717765603817, 0.15630337169333813, 0.06543416665085862, 0.09253561481713288, 0.008010677861860924, 0.08472261349520377, 0.05083640338853002, 0.01788013783704129, 0.044143250242115996, 0.0405752876653306, 0.03179890013510182, 0.02756432040534433, 0.01751742967885108, 0.03469174772861504, 0.009808785811577354, 0.042036090932425954, 0.11608733329921962, 0.025018993276922454, 0.023254895800604455, 0.04549051161795374, 0.009737877670915858, 0.10020322797279205, 0.04500479272176181, 0.024921317066576694, 0.009088989707731433, 0.017245073930450508, 0.02799399996987514, 0.015439734110728869, 0.008035498152997705, 0.024398724443369338, 0.1096226926892996, 0.04052419726166033, 0.01584640326684401, 0.06060191002043505, 0.039250894014032624, 0.04027185556028159, 0.018580951239733447, 0.01609401916333985, 0.045687051474927895, 0.03098499491780756, 0.07431827380412048, 0.042840299391818625, 0.004126233351041353, 0.05740221356973053, 0.013877996844389747, 0.0019573462674499402, 0.09483647562803761, 0.043322904140598355, 0.04111626448350088, 0.1190747238034683, 0.04477277916345385, 0.015472047699375019, 0.07152593694627285, 0.06601739704849259, 0.04868156659687239, 0.027397889719014207, 0.01584503579989917, 0.029030769740441636, 0.02734545674625664, 0.030925602036257906, 0.02146485284151089, 0.006663628117812257, 0.025119682128030448, 0.05378353214191814, 0.2004738563611623, 0.1338906880588301, 0.17576957391875406, 0.14755426455409298, 0.13548301713120553, 0.11458692711687858, 0.1536857105431057, 0.1247915936513774, 0.19464110805382653, 0.12932655071058582, 0.12479438221142178, 0.09786708881297419, 0.16609369957398984, 0.14569912135841387, 0.2392717664160075, 0.2177941543801177, 0.11857668238301432, 0.151958933040019, 0.1056467270058009, 0.19812447920201287, 0.11124115302077225, 0.2102254508363624, 0.1286070562538601, 0.17783483971030484, 0.16442148285287042, 0.19810137399021657, 0.1397250911160823, 0.12764357045413027, 0.14090800747996376, 0.1497969409871486, 0.24283551550920934, 0.1915978850616563, 0.22256890462050516, 0.2104118859936153, 0.14681581708212055, 0.16740862820898333, 0.17892102981286664, 0.22935537110653617, 0.1276008916958686, 0.10630309581756593, 0.17800610632665698, 0.12543309269653213, 0.10476960229777521, 0.17447309268097724, 0.19055409026482414, 0.13878355373538312, 0.10586591242181678, 0.2004152966002303, 0.17310276056729978, 0.15998960292387396, 0.12193969345741695, 0.15513485778243313, 0.25424313160680956, 0.14557964228574308, 0.22395265859461602, 0.3437035699044505, 0.19594546467546495, 0.35096461253781475, 0.872949222403188, 0.27630986525647105, 0.8577915905944763, 5.83277968629714, 9.23408014159049, 26.793626316132087, 49.756344287626206, 69.00713705247449, 84.83027642773044, 96.99586837522446, 123.13886565546836, 137.5110653908022, 144.99270408384263, 148.1967470722814, 143.58212563299364, 128.3276593300604, 136.51757609459662, 136.4489189271004, 130.7443492643295, 123.29681950230753, 114.60955404466199, 122.07659367592105, 132.5252308384065, 128.50693518115628, 140.8236482066493, 116.26904610664614, 138.23237357601045, 130.6162917229437, 104.26449883368709, 123.75081031553208, 136.08787259747905, 125.85145919553696, 134.4789634212371, 137.55573334232454, 162.06900935019218, 143.8936245825983, 133.62967614204655, 120.72929090069188, 138.61651482120638, 132.89842082608132, 154.93611643391273, 155.87572805343137, 174.0517874686949, 158.80227119691912, 153.62008279369724, 124.98245808386035, 75.61323212039086, 32.733269506885165, 12.745924265153947, 4.003432570926605, 0.16154321391255627, 0.6688103860905094, 0.16545064537034881, 0.18685195504898028, 0.18623776703832612, 0.30609432187291885, 0.2595544191858461, 0.21566331146224854, 0.15157000552262032, 0.18214140297664752, 0.18609270062898436, 0.15246962257210286, 0.11770142692952387, 0.14317558177055853, 0.1679260286712839, 0.0824331137682161, 0.1860751112502429, 0.1496295814192103, 0.14448321724851287, 0.18863525451912036, 0.30406829510484973, 0.11549512435111309, 0.09215615614647828, 0.23380762897431853, 0.10684095082744476, 0.28027715882466686, 0.10123230622059877, 0.21652113075458237, 0.3710702836753861, 0.13852242500551287, 0.08427193929110804, 0.11277265471195984, 0.10997577495272122, 0.1441059649110802, 0.16236795352831965, 0.12786039631933938, 0.10324600663396621, 0.1554403276813607, 0.11655729759724871, 0.19193173085729923, 0.12693175219840583, 0.07395248214203505, 0.1638621160940778, 0.1277503171454995, 0.17770681109639908, 0.1332950700194605, 0.14413732855070022, 0.14059072450524376, 0.18270579527222341, 0.12405794188981095, 0.23043791463057842, 0.1946769150034074, 0.10299165778222585, 0.167312101130524, 0.1737903398011, 0.10896153582800781, 0.20492193138887807, 0.12469891999517718, 0.1230089376950937, 0.11819071196500333, 0.09288203211561327, 0.09964448940609733, 0.10257011024101127, 0.12735384366204663, 0.1061389384971511, 0.14085332412392865, 0.19872403493331325, 0.23583630640660566], [0.02154504692542457, 0.09041365851918537, 0.053442450645830364, 0.07785429051446338, 0.003935211242341827, 0.015107921320914984, 0.02422711500267108, 0.053613786210095694, 0.03148071126141135, 0.010386003376615625, 0.043076649007778016, 0.04218501076402684, 0.035155525866655574, 0.024770776959015958, 0.044816457666456706, 0.02428031980901236, 0.03507043648090574, 0.03246062773189718, 0.02289911116202993, 0.024858741089701656, 0.003549331079064418, 0.06415088510801716, 0.06413809910056091, 0.06866663634296387, 0.015149852185840569, 0.025868429652144833, 0.06575258343570656, 0.025076731408555663, 0.029598216811615615, 0.04039993396990242, 0.03428111694032147, 0.055502411278505484, 0.03290847124111268, 0.043060338995870084, 0.026146950493116054, 0.007849095554481591, 0.04884529107760999, 0.08337177065832001, 0.016860076444103353, 0.06010959510721507, 0.038627876840051145, 0.08021265388496461, 0.1069078379641137, 0.06512323454503091, 0.08194875467808978, 0.04060400447117225, 0.02272334186390283, 0.007003330176831374, 0.007769134169774912, 0.11582153143301127, 0.07468990305618894, 0.08984426366946391, 0.03577000882116056, 0.06473448322785479, 0.10602641550283279, 0.13232031506636452, 0.04217704344961432, 2.39932511121996, 13.7094799933895, 44.01795594922958, 61.77285871198101, 83.30905575906077, 89.17605861540764, 90.86692179402998, 105.45045883424821, 104.75808989617133, 94.84214198204779, 96.66840537901848, 96.25876088296214, 95.05793509944793, 81.19625537626206, 75.57869957339379, 57.60020994370984, 50.95039613785283, 48.72956191339801, 66.98158587178877, 44.04376906733359, 63.39878705240066, 50.69408101420249, 36.66600650356662, 63.97714053430865, 48.9798758106847, 57.2638863132846, 44.91834386702507, 52.93286400456583, 43.09312382052022, 41.22468709945679, 35.394887924194336, 41.590032346787, 43.05663008843699, 20.654185433541578, 43.081560673252234, 32.72925299982871, 60.516194066693714, 73.33566865613385, 45.00647560242684, 40.054075333379934, 81.41083255890878, 79.92427779782204, 90.86117944409771, 98.3631830830728, 114.15862268017186, 104.83765909748693, 116.50455305653234, 121.75208030208465, 114.3661552859891, 112.4663160693261, 100.05776466861849, 56.86947238060736, 21.026073194319203, 2.146084390340313, 0.1366825576030439, 0.19762975494227103, 0.009061017922396141, 0.055378006260481574, 0.10030330969922005, 0.02860422347552113, 0.056360514023371285, 0.10215653001420921, 0.11242992995727448, 0.026525725430298238, 0.033192655387064146, 0.02953363176915915, 0.016183536537292025, 0.08338375993433499, 0.03890159622495694, 0.035346775886512576, 0.011477540772888931, 0.024434169416405985, 0.06749259127724556, 0.09400579116998181, 0.013615708448924126, 0.028872428942591916, 0.049698732177456545, 0.06235888287905724, 0.045715454184720596, 0.027279601913065683, 0.0723877705393299, 0.06219315890883727, 0.05282032596428068, 0.04807372562467091, 0.04237203197854181, 0.04612810361469465, 0.04467674621170567, 0.09681997685542992, 0.08235903306593818, 0.015085250864015713, 0.052360282504871014, 0.05011580959563294, 0.04057880017846342, 0.018744698703108777, 0.03883577012006314, 0.011061083885931201, 0.062002655824706446, 0.05948071353017323, 0.030243873798979387, 0.058131272634190906, 0.022978521921041033, 0.046787965787394394, 0.03315975574115592, 0.09918899650895789, 0.019493522836015593, 0.061970893819365776, 0.030306547452064774, 0.06264729966079036, 0.03747124112241211, 0.028344274521054282, 0.06852785951548046, 0.03185501799077517, 0.0417334019326635, 0.042157753355680935, 0.01923537227295099, 0.03575950575571868, 0.019499712826443777, 0.12856176513577663, 0.09105549464302679, 0.044803231158444, 0.04663597011277753, 0.03125406797945259, 0.030404261966806748, 0.04607931530523685, 0.009175191836191282, 0.007636915054923345, 0.007999085993956654, 0.033311150036752224, 0.03448735547041701, 0.0383558658312165, 0.0656360078362688, 0.009793349139903103, 0.03355252135905527, 0.0209117929015549, 0.04937985573985404, 0.08150829242602473, 0.07452484941290272, 0.013074918364685391, 0.02626554281901448, 0.02072019814213197, 0.08891158992604864, 0.01845140768695743, 0.06036814595122011, 0.026646579630793105, 0.010472127938673142, 0.045268755976951895, 0.07398403730363616, 0.07798695396031104, 0.03007960922625517, 0.10377748779231503, 0.07687935936114482, 0.061301106977606976, 0.02271684352308512, 0.021028805171109496, 0.050618968483421116, 0.008802591567678798, 0.06493890612956978, 0.0449418088030671, 0.046740108274764595, 0.043524431229959575, 0.011871262085473826, 0.04590036482700417, 0.032050437444160064, 0.1166215800349751, 0.01880244832606085, 0.06651995838769982, 0.06230965406904298, 0.03855020318540835, 0.15402113447987265, 0.053479425879495765, 0.07445410885397466, 0.06172208378331796, 0.0882490617673724, 0.10432282748121409, 0.0686402982401271, 0.12736695142643106, 1.0503283623726138, 8.359040541033592, 39.67730814410795, 65.01239522810906, 93.52260958763861, 105.94473238914244, 112.12309298976776, 121.07915063058178, 120.91754897948235, 105.80173061740015, 114.39142319463916, 109.68399847707441, 122.98081767174506, 111.73877916028424, 123.90230009632727, 108.50060370660599, 90.0256989079137, 102.91939258575441, 108.38638428718814, 82.7712360505135, 92.70603487568518, 92.16633242945518, 68.17357063293457, 124.0595792954968, 92.22306559162756, 103.73086821648383, 98.12864888098933, 102.70353671043151, 95.58597241678547, 74.38366320825394, 77.04823909267303, 91.45668937313943, 83.76130503992881, 62.97505732505553, 78.51260892806515, 70.90113978232108, 113.31083374638712, 130.12539140639768, 81.08947277069092, 75.81813673819266, 132.82686110465758, 121.99085066395422, 125.66319327200614, 124.64382417740362, 139.19214617821478, 128.54801808634113, 139.876646841726, 145.68354329755232, 136.88133670437722, 130.50142903481762, 114.43031741726784, 63.195816163093816, 23.351754334665117, 2.4077415370172073, 0.18530804273341933, 0.08167907640698456, 0.11916364362883954, 0.05051593731848463, 0.08018564162475449, 0.018921896755214662, 0.05638767567072665, 0.07460281418095674, 0.09178982822284584, 0.04641549766904885, 0.13335290965774368, 0.018885492257052855, 0.05495859610457575, 0.018742184019497326, 0.04911707609050697, 0.0630188369823079, 0.02362973304585584, 0.040787176093867714, 0.019537482876330614, 0.06257865052189558, 0.014583198973278125, 0.051690101127831206, 0.07619831485733872, 0.10735168632480407, 0.03750281160577171, 0.03308653305735319, 0.08057761051121258, 0.007753663981753973, 0.06709809430063733, 0.04996692806842828, 0.003094482892793754, 0.04264537214992508, 0.030159349403073712, 0.02455056881562116, 0.03709385088915306, 0.03962069997684129, 0.013760072930205255, 0.08362130847789588, 0.038765692227189584, 0.019896414221054124, 0.10350614711041413, 0.04262744569249692, 0.017162313451990485, 0.022327251424412095, 0.11776147290102898, 0.007446629348241034, 0.03768025672123317, 0.04596625221893192, 0.07233364642747948, 0.07449472683572, 0.0061917802010993325, 0.02764721686441091, 0.024140552812886816, 0.04266515254013, 0.03147641350815614, 0.020368891287474863, 0.04882852907382673, 0.03322089338795312, 0.005691804887441498, 0.08006449248040877, 0.02000559707202258, 0.039533856249744856, 0.025047926502602718, 0.023960625572550683, 0.09974768911037715, 0.13495790982438674, 0.23422188335849395, 0.1765674391701337, 0.1437816339274568, 0.13517292006121528, 0.1607274988125409, 0.10138547017930016, 0.1534002355390018, 0.10213415258594098, 0.10996039956808092, 0.1269049927472107, 0.15892932191491127, 0.12404645823182599, 0.16907499201836126, 0.09806320732159, 0.13265025381359363, 0.17007090631992589, 0.1538356339498874, 0.11502871470105265, 0.11296909497750383, 0.10137460705253387, 0.15373322331616956, 0.12319331207583029, 0.1513683558591912, 0.16631748917843067, 0.13307633659531995, 0.2009608431328689, 0.12550787053882115, 0.13097754679620266, 0.10885464357993296, 0.19166749181045642, 0.18674951377174548, 0.18741890607822329, 0.19338441742283685, 0.1262389099405658, 0.22545645854646162, 0.18516427867354887, 0.1918769249271962, 0.1239241676164731, 0.19375252267045362, 0.10984867330520384, 0.3281503915786743, 0.18171558066481547, 0.18251058074735826, 0.18961146503927248, 0.16857458338622125, 0.14230486155757982, 0.13498456968415168, 0.08369293003793686, 0.281873011901494, 0.12735601169087235, 0.19502608255753595, 0.13700961585967772, 0.13019045274103844, 0.3798156063402853, 0.41766329157737, 0.12221345497715859, 7.424869248943945, 29.64668581562658, 73.74731356097807, 100.58979495879143, 123.14859313349571, 130.65346010269658, 131.15941447596398, 135.9238233873921, 133.27674127394155, 119.14784616039647, 122.85431338894753, 120.26267005551247, 119.47086118882703, 108.90046581145256, 101.29559409233832, 79.68229893715151, 77.48360649231942, 68.64562003843247, 92.00873159593152, 66.00147185787078, 90.44781654111802, 76.92506097978162, 48.978699099633005, 87.93982167397776, 72.98758968230217, 80.76076246077015, 66.15012184266122, 74.96495846779116, 65.20948648452759, 59.78284420505647, 50.96718780456051, 59.437608949599735, 59.864629545519435, 33.885042129024384, 67.25703823950984, 48.36606410241897, 86.33338359094436, 103.47822835368495, 68.4172910259616, 62.24123285662744, 119.17333372177617, 109.365494174342, 121.55819754446708, 127.72632075894265, 139.8101705120456, 131.55028650837562, 146.9951525042134, 160.19336331275204, 156.4459308501213, 154.5452287120204, 138.5941259322628, 84.13827619244977, 34.388756828923384, 4.81485745599193, 0.25848633940181426, 0.3829540234179266, 0.12960402775676022, 0.14444597005363435, 0.3528304656426753, 0.08514560894259522, 0.22207863899248265, 0.2417915062077584, 0.218498679478803, 0.19176178191217685, 0.15669842791413108, 0.17433718868320988, 0.13325857359074778, 0.19523943804444807, 0.15774400003494757, 0.18201671450609164, 0.10154911422080572, 0.15136210458172908, 0.2655652369703016, 0.20761068549848374, 0.06842886563390493, 0.0959827040412253, 0.17634317459117982, 0.2672138888268702, 0.1845150957665136, 0.09875208890486149, 0.14391934589272545, 0.10913277180084299, 0.20110321291271718, 0.12095497170042609, 0.1526058483267984, 0.089340545537491, 0.11864880190020609, 0.177604139992787, 0.32916536614779507, 0.12603344515927378, 0.14703399892295563, 0.12613138950039304, 0.08055957680147502, 0.1317069544306686, 0.2497965581114254, 0.12847104500378334, 0.09878537542517148, 0.09742525526352468, 0.21493188135566252, 0.12385744135826827, 0.17720632585546664, 0.15739691623997304, 0.22091533447946274, 0.22046963984687484, 0.1414449125408165, 0.140621368022215, 0.1626521721482277, 0.08486842300983206, 0.10172343752797573, 0.08180306773752936, 0.170403495731373, 0.17658135132683864, 0.11785877372829184, 0.21232142143191832, 0.12114640941182453, 0.1194204975880923, 0.09377559707049402, 0.27941610664129257, 0.231935876992441], [0.06742560454914648, 0.026674304352772814, 0.0788568084939353, 0.038456832389197046, 0.019282454121557456, 0.04923301583696758, 0.048487390121144634, 0.016637983724414822, 0.009235734807237262, 0.03815227796533897, 0.04311339824550575, 0.048674507096650145, 0.04224877992284395, 0.051190048726575996, 0.04592387606540034, 0.024124441983839198, 0.06008099704500168, 0.036238391147626024, 0.06632570913361927, 0.04692948520964673, 0.019556410993719776, 0.08981445518833014, 0.03230622654119807, 0.01335742669330249, 0.03156408077977117, 0.0564380114777915, 0.044078458355919975, 0.02790352690123743, 0.041294705513263905, 0.06797367917193521, 0.03347911864459034, 0.034881948208015774, 0.037455122632485245, 0.0633662578559691, 0.05721338055727463, 0.07036470087064851, 0.013510993805774038, 0.03386457961413168, 0.03608580558530746, 0.04739710527862753, 0.030405619857652538, 0.1149240441079582, 0.041782661386194735, 0.046903817433743715, 0.020605754182343523, 0.04618296317095238, 0.04167641648241589, 0.11358169718615471, 0.06043400269963088, 0.05632113710406327, 0.034017655472721786, 0.0689715393368275, 0.29679674174516435, 0.1069434916961097, 0.7534930097960657, 8.797457583488958, 35.07644637938469, 74.63553428649902, 88.48268555056664, 78.44985885004844, 82.93455569974839, 84.80576945889382, 85.19965387159779, 88.74251904026156, 89.84885492632466, 65.4979258198892, 73.86856971248504, 84.81619511881183, 95.53273016406645, 37.639021027472715, 36.68205291994157, 35.635282147315245, 37.64413187580724, 40.05461269809354, 37.310930452039166, 52.40228499135664, 83.0176942579208, 55.86416890544277, 60.764323203794426, 81.74172370664536, 38.58157050225043, 46.70561498211276, 52.85254563054731, 56.391241319717906, 39.71836751507175, 51.0407087110704, 70.33566736405896, 75.75770870331796, 65.33233119595435, 72.70756383096018, 98.07506145969515, 71.43551564985707, 78.29370929348853, 64.0549760480081, 42.14957021897839, 56.655103083579775, 55.7892124114498, 30.970644604775217, 29.230387018572902, 33.44456780341364, 30.768585666533443, 50.200423271425315, 53.38113992444931, 78.40012319626348, 106.814392459008, 93.72731024219145, 105.05407979411464, 104.2331277170489, 121.91654528340986, 116.22822992263303, 91.56799839388941, 41.28953172314552, 8.982744466873909, 0.2437122418515144, 0.11743318124283707, 0.01687260389688515, 0.04984140456203492, 0.020541973532207554, 0.013128337675645469, 0.014578929948320073, 0.04887914067254432, 0.021569471723670443, 0.08781128082304232, 0.006592142538377836, 0.07850896627191575, 0.010087986555581373, 0.06238040228885028, 0.04514200672987969, 0.025845167392324057, 0.0594123401829312, 0.07155471120870883, 0.05715268724147351, 0.04702318542366547, 0.013480388593199033, 0.0349734612410107, 0.03389431148647301, 0.08095483986600753, 0.02676568332038099, 0.03266256467829789, 0.006764301647161765, 0.035216000847398274, 0.027892813161616365, 0.03213428959791218, 0.03470529599355594, 0.021636762971719428, 0.04091203310376695, 0.06743739464230115, 0.006416886519160002, 0.08891810167340503, 0.011546761604897197, 0.06601368918293907, 0.06759703970484196, 0.02264634619707302, 0.05054940003901721, 0.04340107575239193, 0.006853029471746977, 0.0327823884905346, 0.0542601116091734, 0.035140993178731976, 0.10244629511068906, 0.02381551894359291, 0.06335857399408856, 0.04426710367683442, 0.07028167992229424, 0.01885759325007037, 0.037819301679490075, 0.06298949581480796, 0.09532074278761303, 0.048521906212573095, 0.1169121418628962, 0.03185863392577777, 0.0443887124739347, 0.06218390073627234, 0.018060394495184866, 0.01870411328010021, 0.01659547733593612, 0.061820418829278606, 0.02481587272467873, 0.019844620931713332, 0.07163061520024654, 0.025386832308985537, 0.06124999742173861, 0.008217693013589709, 0.02240402109530424, 0.024162748295273033, 0.017499800080493573, 0.029440644016909986, 0.0819591045259468, 0.06777071949815558, 0.03596676318275352, 0.07748099119072, 0.06188582358581405, 0.05672008122107195, 0.06022828127888422, 0.12752077422074734, 0.047600942123080456, 0.04229517420753837, 0.03967673547806279, 0.04538270006436975, 0.05457043084466169, 0.03205719817009184, 0.059440283239969326, 0.047485837412457314, 0.07119437409264427, 0.07171395790552901, 0.05313771619131008, 0.1341371385440711, 0.05000914717393537, 0.04249180216462382, 0.04447144230887775, 0.030938780663775343, 0.022155283837609237, 0.024006872385319684, 0.04578828233324232, 0.044683269450380925, 0.019979458152046128, 0.05372638964364606, 0.03980623498078316, 0.02248331502590689, 0.01887936546887842, 0.06144751404081622, 0.06670417955085155, 0.005095741559465927, 0.02974230645885391, 0.04595099940835949, 0.20014120566268123, 0.03119265645622246, 0.06279757546801722, 0.1651564676074251, 0.09910694849226745, 0.9882625540898693, 4.7095197535330255, 29.51517462730408, 78.58433338903612, 102.63715451763522, 100.19550261958953, 102.3542025781447, 106.2286021632533, 98.98759303554412, 98.01708098380797, 110.55722005905645, 102.49016761779787, 119.21651901737337, 122.96405346162858, 120.75120910521477, 64.9054753395819, 62.26239404370708, 41.47461268209642, 32.81708075154212, 36.276432775682025, 26.850488916520153, 46.21924892548592, 54.76659559434461, 50.19216668221259, 49.22418455923758, 29.203422684823316, 29.62583253460546, 33.72463680082752, 35.33149849983954, 35.53777202483147, 22.038499693716727, 30.128982413199644, 41.9628300974446, 36.323662034926876, 34.15988260699857, 29.947757144128126, 32.48660733622889, 47.86707193620744, 39.60496002627958, 46.894712448120124, 39.034392449163626, 41.772191139959524, 36.93752473400485, 42.674238220337905, 41.70428706753639, 64.3198262491534, 67.86349942607265, 96.45965683844783, 99.69833435550814, 121.0561498518913, 130.15464444314281, 112.839553125443, 120.88970015125891, 121.2257766723633, 143.0510994695848, 136.04651512638216, 107.55011927696967, 49.41610220939883, 11.808980837945017, 0.13382658182132628, 0.0701720527403297, 0.11686333440124028, 0.07637635369094149, 0.12878307261534278, 0.04221726306563905, 0.04909523109334612, 0.0439102292781876, 0.023249044804082766, 0.11962243836493262, 0.05932893619061478, 0.06714258868727954, 0.07668280418241218, 0.07184833738832705, 0.10355868542026128, 0.02800161871428211, 0.07313715774686107, 0.035289660201317845, 0.08756765720224188, 0.05934379063546658, 0.006908524880981854, 0.06702298704054087, 0.06728887317642089, 0.023802102828818946, 0.06528714671730995, 0.013097865570847307, 0.009363993247520299, 0.029480323540948095, 0.054265232906947215, 0.03183114477583478, 0.03101110127904723, 0.044100529349018494, 0.029208134416671052, 0.03658583883436457, 0.02619968032494428, 0.07203186907234692, 0.08247736300672255, 0.07912294743883033, 0.002457462110361385, 0.011275441990414215, 0.025908520948442242, 0.05458744182702034, 0.022419051740378625, 0.048154858166291836, 0.05754778176666268, 0.018672008450413426, 0.10814046577340174, 0.11739254027845399, 0.005485655893872102, 0.09862148623553016, 0.06034597536669143, 0.01746135587323337, 0.040760600503774426, 0.047232273800839344, 0.03220057535556055, 0.01835812690607723, 0.03655567795278565, 0.039631000028983246, 0.04433823111016424, 0.010955452810101693, 0.017005386086361065, 0.025711925550093575, 0.035116171929985285, 0.12604099112532793, 0.14567261471623374, 0.11969603643181825, 0.1306094568703444, 0.10357417571809023, 0.1269779243176022, 0.15962845375460966, 0.15400743682778653, 0.25877500133168313, 0.06829571189178575, 0.17676881304191006, 0.17644445141476972, 0.21445656976392194, 0.11483859466088396, 0.1290828428201137, 0.22360243383915196, 0.13273892082994984, 0.1742097422961266, 0.17122210664374216, 0.20384075150134104, 0.15604005195200443, 0.18624400299402977, 0.17516462492846674, 0.16948759165262023, 0.12344550822050342, 0.1464497036631069, 0.14110703712269185, 0.13637451364869072, 0.1627923815601295, 0.22202184123377647, 0.1689205640145848, 0.14498889656557193, 0.21094154386270433, 0.17564246461035746, 0.11529024179664352, 0.16670391924919623, 0.13320471760967087, 0.12540963508429068, 0.12616055446767038, 0.10923722022843939, 0.2142933011054993, 0.12186149886298565, 0.1425744785416511, 0.13842281825359792, 0.13495190369506038, 0.12074021427261254, 0.06411394051786873, 0.1779004628018987, 0.24251483110410554, 0.29090233868168247, 0.19175563788702413, 0.2220719740275414, 0.49651803929478894, 0.18098612706507408, 2.332611232995987, 20.029663693520334, 59.7859154209014, 113.64740448613321, 124.1285502526068, 106.21721160027289, 109.09754137839042, 109.56466428695187, 106.2689947312878, 106.73654125582789, 115.68928057147612, 86.58695697784425, 98.37759387108588, 107.42338749670215, 121.26969937355288, 54.55952975057787, 52.38228090347783, 47.38926841366676, 50.94094714810772, 55.64910927126485, 48.17158122216502, 69.27976531367149, 106.22089078349453, 79.09008379905455, 83.83072314723846, 113.58295209946172, 54.555995695052616, 66.4654411808137, 82.76718816449566, 78.76357786117062, 58.653009399291015, 69.33470203030494, 103.99955057328748, 104.34072617561587, 89.35811934932586, 93.3736458132344, 124.62136468579693, 99.08398136015862, 106.44801955069266, 82.24905090947306, 57.04233907884168, 72.87195036488195, 73.51260677460702, 46.01989446147796, 38.3698997959014, 50.343727065670876, 51.75230903010215, 73.47589338979414, 78.25501903410881, 105.91121181364983, 135.99833273118543, 119.58453147642075, 129.65248692420224, 133.30953228858212, 151.82431190244614, 154.14178940557665, 129.6873332608131, 68.84037356222831, 18.42011909331045, 0.36709260195493704, 0.27490795499855475, 0.40690024653750084, 0.16443390879900227, 0.20336916309691247, 0.1996723445312631, 0.2203435111310213, 0.10527276118556339, 0.0865939058243267, 0.29957194121614583, 0.15097774294835908, 0.1999083762207339, 0.15223173694985528, 0.2268062135384929, 0.3026026769751503, 0.1647986432597522, 0.12999316977877773, 0.18456973315727326, 0.129061269784166, 0.2909522569708286, 0.13460557066625164, 0.11073039454077521, 0.2588105171678528, 0.16015774390149504, 0.1310937776560745, 0.11921534690284923, 0.1015254880692209, 0.12845848882270436, 0.1102726340233799, 0.1291187417002455, 0.08122082559331771, 0.10009557729767216, 0.13229561639168572, 0.22730309816618122, 0.15447468917456367, 0.20600786102154564, 0.16444147774769416, 0.1489766906466215, 0.1604362781490049, 0.09880252047291688, 0.18391354820661007, 0.1226247905663425, 0.13468433982662617, 0.17534137673435674, 0.1339237983789175, 0.08236905349598778, 0.15726563941326835, 0.17846438012296156, 0.14910429025128966, 0.2242911468830801, 0.2151980815875915, 0.1198939169426599, 0.16804561499626408, 0.12837834836494538, 0.12652905042012855, 0.12414644036682383, 0.18346728666895823, 0.07616592465990013, 0.1404912403273967, 0.10798790702416051, 0.11946847767478998, 0.09524451703914712, 0.1936309598386288], [0.02147389650945702, 0.03949948954546163, 0.03631405382146759, 0.01205565083035899, 0.06828793609935431, 0.07174461674425872, 0.05652315832013565, 0.04624669785581289, 0.10477154816110289, 0.08936196535585389, 0.03455787769428665, 0.03632159978752175, 0.05522311094307131, 0.06842404694086121, 0.037970489131346825, 0.09481113343950241, 0.08399834631070976, 0.06444822681406814, 0.02624493888429096, 0.04594748306478705, 0.041765512508009715, 0.09523435105239192, 0.03091779560030949, 0.03782752946379685, 0.038489643934993975, 0.021168474491024693, 0.04021404273507576, 0.007549940135269877, 0.047074317962171576, 0.11111366832929273, 0.03447806282389549, 0.06932830648316492, 0.03358431017747329, 0.07767720162988671, 0.030464535849469326, 0.030858787677941785, 0.10562424998610251, 0.0045464277894596665, 0.053659242037082874, 0.06481256290909744, 0.01508708468698446, 0.036052656960823846, 0.00823480646020823, 0.029214445065947312, 0.06794990746364479, 0.04741102126577208, 0.06574463910393177, 0.08808707247578329, 0.1359672766299017, 0.26327956768293537, 0.6817884058240922, 2.5360738894631787, 14.833590099888465, 34.801354869719475, 60.855765419621626, 95.11978303232502, 102.52322535361014, 96.28406017057358, 75.26971878543978, 81.52824478764688, 78.9706240930865, 73.54358565422797, 66.23327609031432, 49.052078800816695, 34.83637771298809, 27.028342908428563, 21.10848415282465, 18.555399679368545, 35.62372292241743, 62.82767818820093, 69.25320302286457, 110.04453489857336, 116.73276439789804, 115.57384521730485, 144.83071019572597, 109.34407803320117, 121.29222162308233, 85.7208505753548, 110.63805226356753, 109.96509905784362, 156.35915233242898, 109.75318124217372, 121.37517975222681, 166.53279212213334, 121.33683466142224, 158.42059320019138, 107.37893919790946, 117.50681277244323, 127.50749957176947, 121.45034020946873, 154.16251520956718, 101.04133036828811, 120.90364809959166, 151.74564484627018, 147.798642189272, 124.2568745151643, 120.3554968680105, 147.9193570536952, 132.86550429559523, 99.41499802374072, 60.220961186193655, 35.73482797991845, 30.54073714440869, 31.14103040387554, 47.217264636870354, 57.74389420786212, 78.81325860177317, 75.55206667992377, 87.81785949583977, 98.94627478814895, 92.44130626801523, 113.3773728339903, 105.77963198384931, 67.14808264086324, 22.20052888316493, 2.8007542029503854, 0.5344399737734948, 0.25681927079154604, 0.2268031032215203, 0.20802071107731712, 0.12305868744489648, 0.08901628350178081, 0.11667434051032029, 0.07406168031476199, 0.021787144116035873, 0.024156089075991226, 0.033716536953204104, 0.03973407332875556, 0.02542849600074753, 0.04886004593103163, 0.0327882950284308, 0.03802180170051513, 0.02255552838886938, 0.03635090265062548, 0.031088788340228702, 0.04647606074990285, 0.025313421933641358, 0.042875550927654396, 0.09150483585413426, 0.06589860745495366, 0.04389667718280708, 0.06498328560302336, 0.055612927122462186, 0.033610173305797006, 0.04834433469260412, 0.06266577387108438, 0.035069754662653135, 0.032138246442041093, 0.01589595670661619, 0.017188237867348136, 0.05435001202708772, 0.03272575544073217, 0.030728822776807413, 0.023578487509380908, 0.08244325677233358, 0.09813307454028437, 0.07270565872351009, 0.03263917984440923, 0.032109225116249536, 0.09377263231022705, 0.01756054127678996, 0.02869591079351883, 0.025779933090351766, 0.06591628876424606, 0.08669566528330888, 0.03088384449872519, 0.05258222583741431, 0.0537856197315118, 0.02366887822356676, 0.030940996573096326, 0.05674450793453763, 0.034689093233957406, 0.024595838866286704, 0.07092718560729297, 0.015194517027045933, 0.03795816660708478, 0.018242738742922104, 0.06540195265364263, 0.08092585109895276, 0.08872272627007577, 0.014687219349246834, 0.033839773687143485, 0.06488775443886557, 0.036398484371602535, 0.09111148800941245, 0.03376904461953429, 0.032065320617309025, 0.07065143225894821, 0.00978820868993118, 0.018633229079686345, 0.02067809778025314, 0.07674359325920382, 0.017363779254317764, 0.07062402929389669, 0.022336126553014885, 0.02634804857323968, 0.08161682410225754, 0.02683090804625423, 0.016491961620387532, 0.03250931644992482, 0.04858329666838531, 0.04497986039026611, 0.02773661932517444, 0.02346120136339338, 0.025855264431166074, 0.05211890735212834, 0.009163938004583603, 0.042502703595786326, 0.05369095041626885, 0.025100663995310187, 0.04213635651995579, 0.08326615011619945, 0.022670225157672842, 0.03936456997067698, 0.013130131278998189, 0.028561504497643442, 0.061757657076081926, 0.05935529727608927, 0.06788177926453852, 0.020186650461607406, 0.04840479052114872, 0.08466175547049892, 0.11384074215687091, 0.06366259981727888, 0.13545427351228653, 0.3907563531350705, 0.18070750088701326, 0.6283857036502131, 6.166704297065736, 27.217326625700924, 54.93225689857237, 94.16219126793646, 115.76841046733242, 108.64236600937383, 94.2263690886959, 90.38203054858793, 97.59853270746048, 96.00569740418466, 103.84842949528849, 87.00488551970452, 75.53665176514657, 46.0751881137971, 38.892539931881814, 42.6761091909101, 53.425462707396484, 37.70196722399804, 39.637394105234456, 68.73403810685681, 73.42538110671505, 89.34501078820999, 90.0493194210914, 81.56776658950314, 101.59420413355674, 81.47608510909542, 81.14318570783063, 94.28256880852484, 92.71527597981115, 83.18754857586276, 92.49392878624701, 105.65738739505892, 90.73156079938336, 90.62278562976469, 81.44824412561233, 83.9751918854252, 78.6888723988687, 86.80994372214042, 101.34063074665686, 88.01016546064808, 95.62772212489959, 88.69630567489132, 89.53758347419001, 86.20376494623001, 93.96461363761657, 90.01987026583764, 64.12045217329457, 51.42690135586647, 32.89750895192547, 26.35659387034755, 29.982444624747004, 50.6859617079458, 83.26288946213262, 93.58630103449669, 117.14680979328772, 110.77818286034369, 110.54938316345216, 113.4263083242601, 107.99511217301892, 130.19589208787488, 124.34527689410795, 77.53651142120361, 26.140328107341645, 2.728392847122685, 0.14217982068657875, 0.24009943248764162, 0.3007703172343393, 0.09501114367477356, 0.05601349151543072, 0.057703485306833065, 0.057419167095494855, 0.1476839325961567, 0.1167402393935669, 0.03865454819113497, 0.03923338124408357, 0.08805640597617434, 0.04667349309930879, 0.030227807019987417, 0.05118477804165694, 0.0601086336668701, 0.0300732966617591, 0.08305691618231997, 0.0034604859472658006, 0.02939501007448041, 0.014704513784137466, 0.04662796832440842, 0.05277886528581862, 0.02856215758759889, 0.03704847550139793, 0.042711523842186704, 0.025056502856915037, 0.02625857141890353, 0.046345362319580974, 0.05220083279475089, 0.04430160444650439, 0.029497746295566042, 0.041125702686728015, 0.056288042105734355, 0.047395013858594244, 0.03423494482112508, 0.05892396679208164, 0.03174339131932826, 0.04478908534492216, 0.09220632724463941, 0.022669008993093046, 0.04353227213986459, 0.015772903833778638, 0.09929778099420572, 0.05074079944601944, 0.03751655139269368, 0.0461293638293301, 0.036425864354016325, 0.07644000793656996, 0.03412982606659493, 0.03069013533663125, 0.008611170135648742, 0.10290848361628671, 0.042972491693592844, 0.0224801664045381, 0.021703016170631015, 0.022662125693093386, 0.03948224490628608, 0.02650412175083353, 0.03977584427282695, 0.10890070844681994, 0.11410006291923985, 0.14578107744455338, 0.18868924839602363, 0.15773621658163686, 0.11298691418262259, 0.36806029357737113, 0.152240056664713, 0.2737608455842541, 0.10186357799196437, 0.1318509023516409, 0.14426102110695455, 0.2046291019407011, 0.1553795462654483, 0.1828454990660952, 0.283028211204275, 0.15266232432857638, 0.2156336332160619, 0.09685308717551733, 0.20588625222444537, 0.22941386958043422, 0.18967528016336505, 0.11556582660564493, 0.22531471695871125, 0.2300701004963729, 0.11107014687431437, 0.09747974709757874, 0.08366550409024762, 0.14149501469106446, 0.2744357077585113, 0.11420451134683625, 0.2191995886424857, 0.17457148901397185, 0.1454553828244248, 0.16727922063681389, 0.1283479576569892, 0.1642823459640626, 0.10945389287606364, 0.1187470067112196, 0.1322804938160604, 0.14173688397051828, 0.12998437508940697, 0.3016195410201627, 0.16086000137992446, 0.18070834358372997, 0.2512022988089631, 0.18547596920642162, 0.23050775120575584, 0.1849956167561393, 0.49464106259326784, 1.0043853341091065, 7.379786016479616, 29.864806859723984, 61.79706365831437, 94.75335521082725, 127.53630545831497, 130.59434213945943, 117.62357388773273, 99.62835142689367, 103.90143640579717, 101.87106855453985, 95.41004626981675, 88.52781634176932, 69.27154402579032, 50.05373839409121, 35.54771523321829, 33.34154675083776, 29.501511050808816, 50.55305219465687, 95.17426475401848, 99.34162616729738, 164.75407569639145, 172.22622225361488, 169.61783039954403, 213.36300511513988, 157.944025224255, 166.26574147132138, 120.53133672283543, 159.17064451402234, 158.1722600998417, 224.900327497913, 163.75700919858872, 181.50276891646848, 247.95769814522038, 181.41572367760443, 232.26572282852666, 163.11543495424334, 171.91633932052122, 194.47409414475965, 180.77797766654723, 231.76069413461994, 150.44056246357582, 173.88813049562518, 209.96731512008176, 211.5829864625008, 181.73607149431783, 172.3338677806239, 208.6420717547017, 187.08119515449772, 137.24280664997718, 86.66745970326086, 51.96215975669123, 42.96077128379576, 43.06584373597176, 67.90026772406794, 78.89722870242211, 106.39071372247513, 100.94305146125056, 112.06337098152407, 122.82185969814178, 116.7136859893799, 141.01810363031203, 141.266876036121, 100.98808027082875, 40.484731966449374, 7.052731437067832, 0.6811526141339733, 0.37549949761840606, 0.6084195524454117, 0.5071860281450133, 0.3418660620527883, 0.3385161434210116, 0.18866505533937486, 0.20890889809496943, 0.25547484777146773, 0.08324465368904414, 0.21756627386616123, 0.16573403661529865, 0.1660930254166165, 0.1347266891670804, 0.12800366242205904, 0.21187750412331474, 0.1684861461962423, 0.28185698534211806, 0.16215914860367775, 0.17872319526730046, 0.13631091302921697, 0.22269691791265245, 0.17771747504030505, 0.14132472866725537, 0.14179455506945812, 0.22019685125879704, 0.17252595764735054, 0.12335072016163219, 0.07320618992971797, 0.08385187796046657, 0.10519727854238403, 0.15130271744583884, 0.12165764286633461, 0.18834708288552302, 0.18621369655574524, 0.1039150925052743, 0.10872857615111337, 0.11617936344156343, 0.23766742508497932, 0.12925015642277657, 0.09510687402179165, 0.11606602839404538, 0.13066936494602313, 0.3411153265305104, 0.08488307827182355, 0.14122230271177907, 0.1367405964241874, 0.10209206371538102, 0.16985267851381533, 0.13410646438358292, 0.14457844197750092, 0.14342172582062984, 0.21593196317553523, 0.14346704758223028, 0.13277500357118346, 0.06978397558052694, 0.06211085808313182, 0.12049640679071028, 0.10664772047030349, 0.13174950295398313], [0.121842768013237, 0.043605410553995645, 0.062488340246941776, 0.021934997170202194, 0.025161410937266006, 0.10163536806020046, 0.04028145464197282, 0.02303051439324214, 0.02181608308737557, 0.010038107528441377, 0.059946510309894244, 0.019395639781930277, 0.030985356894351786, 0.027600246098553462, 0.05311829969286919, 0.06417392137190027, 0.07090260950668205, 0.04465703859985356, 0.0678853722169034, 0.013064150041299722, 0.016664971086767413, 0.05415156078074248, 0.07708401975011633, 0.03795285378732989, 0.06896695047016106, 0.027929460892694134, 0.05979991172470393, 0.015524024849817639, 0.11035129593144502, 0.028642278893159765, 0.030954843612327695, 0.01764204537105416, 0.02366390056727875, 0.04182254775397239, 0.010851620125674434, 0.06967885299555718, 0.037092912431445815, 0.03072400216854388, 0.019758583512157202, 0.05107371061439476, 0.025688019776416403, 0.03287974294395216, 0.06531598226677987, 0.040140774085997574, 0.05563872896375195, 0.032245418312208306, 0.14727818178794078, 0.33010425286427625, 0.8625752887418194, 3.31367225416245, 33.126079190161924, 64.4501038520567, 63.01212372318391, 80.29823657005065, 87.31244640965616, 83.92616225827126, 71.73582015498992, 86.52706238531297, 53.91686900969475, 25.871422175438177, 31.63978134432147, 28.03836499491046, 25.61578169945748, 21.343591020953273, 40.12776490180723, 106.27239934859738, 129.42928052717642, 97.06692603326614, 86.43924836189517, 71.98740882258262, 61.50805165690761, 24.977867026482862, 17.591745891878684, 8.054505269373617, 4.952773384509548, 1.2037795734020973, 0.7799750145885253, 0.397773350799276, 0.688200194028116, 0.8203462547352238, 1.8974861622818056, 1.1356676153598295, 1.5728259447120851, 1.7548692731126663, 1.545804736595, 1.9130068584795923, 1.131913907104923, 1.2654282008447957, 0.6745266277463206, 1.0720582931272447, 1.3493639807547293, 1.5596529096364977, 2.483562178188755, 2.33427137617142, 2.0983751310456187, 5.09533339931119, 6.320358735899772, 15.838308161304845, 41.354694058818204, 86.7331672483875, 129.38075296340452, 143.8937971668859, 154.28075113604146, 103.9192831900812, 54.000168385044226, 34.87549158834642, 24.120719317466985, 19.253326615979596, 46.053673913401944, 74.49238346469018, 86.9457204880253, 90.99305737403132, 87.96138686518516, 91.0726422648276, 108.17690618576543, 87.82719473684989, 48.38930806806011, 27.3286081898597, 19.804001892766646, 7.782232472973486, 3.7596033321272944, 0.463621610955846, 0.2840245238715603, 0.0584245540742432, 0.027541856792184616, 0.02015443837961122, 0.023527090670540932, 0.04051067580979678, 0.008895852238750987, 0.0167922182909904, 0.04099655175401319, 0.030649592048458518, 0.023599926479941895, 0.02308962956791924, 0.04362586510157393, 0.02000843925822166, 0.04700533940546936, 0.07457055421846528, 0.0643591461102328, 0.044959750582253745, 0.0688045398302136, 0.0635584041986975, 0.007991667868824857, 0.06834007604348083, 0.03396286869481687, 0.11214495291032138, 0.023802667818663102, 0.026468885536756248, 0.027542550101756092, 0.07253653715334593, 0.03785888927297727, 0.017078760072528835, 0.005681695399670712, 0.01115326533064006, 0.01362794383068479, 0.05439443746581674, 0.03338752517236337, 0.01827566328668787, 0.004237203580898143, 0.02005236099414047, 0.06143382788004895, 0.05942416091960284, 0.05863044403433319, 0.018220535599656643, 0.05394256433411952, 0.01887666500894533, 0.06612190676312293, 0.07250058464705944, 0.03986284504794786, 0.04708239635933311, 0.05442819129976054, 0.02509857066005709, 0.014078056875375972, 0.02983484604966737, 0.12739289882442645, 0.03831307982064543, 0.008741123545464248, 0.03387445448747566, 0.05777602234194356, 0.04457233991894511, 0.07850594788549409, 0.06312736865854071, 0.03848218989949073, 0.022049035103390777, 0.024043196444249442, 0.048680218282125653, 0.02394559684269611, 0.008178437710739672, 0.023515417405794707, 0.03510501768980776, 0.0841642273289542, 0.09433835759879121, 0.006243483475109022, 0.0062723420072166676, 0.04574457701716212, 0.10059348082229977, 0.0681434136124388, 0.015834862152264727, 0.03965243899954423, 0.04405706535063444, 0.04840609287061999, 0.04630454132453569, 0.050362984033962416, 0.014713128442846, 0.045970588276583346, 0.02015609504474748, 0.05678689174894845, 0.05499888849895328, 0.06433570381974982, 0.018742153375980355, 0.020071532344445586, 0.10261422924457059, 0.03696866829188601, 0.011498553607042038, 0.026987454283141324, 0.03316777668172314, 0.02297657031205393, 0.08309199534837278, 0.02044421305219012, 0.01595877495879728, 0.1375356118284887, 0.011759006264319104, 0.10763191362662662, 0.14057308916122685, 0.38643307383022, 2.233484603704945, 17.559213753669493, 55.732510628238806, 72.47490452181908, 90.34954547882081, 101.41870944730698, 100.7198529089651, 86.51575026973602, 103.00272726243543, 85.46537091655117, 58.31103755581764, 61.41910799088017, 61.74706912809803, 44.43738283649568, 35.2237392240955, 27.76771753065048, 66.17696654412055, 56.3421763912324, 32.99693907460859, 60.323774353150405, 72.911558458882, 63.18266053353587, 36.93570867661507, 25.148543080975934, 12.57971186791697, 7.545132550501055, 2.6574450154458327, 1.0871748626232147, 0.6572418455635348, 1.1385226105490038, 0.9905713592325488, 3.3606056196074334, 1.4399833568642217, 2.116116746779411, 2.478196130644891, 1.8183492797036327, 2.7783572241183254, 1.496984465948997, 0.4336544883347327, 0.7157047729819053, 0.5139793894223629, 0.46116835227416414, 1.580189826988405, 2.2063724456294893, 3.505790680646897, 4.135117569277364, 7.243297340408449, 8.528671283875743, 20.319205214900357, 42.294301755966686, 72.02047440313524, 91.96275357277163, 80.33992352024202, 80.05839147875386, 49.847107933413604, 38.97516073719148, 30.645903733468828, 42.86251198860907, 40.177198533088934, 85.4591186584965, 112.6441014197565, 107.47184445781093, 102.67695088540356, 99.75884083778628, 108.55819979021626, 128.70030018591112, 104.97065098054948, 56.63744849543418, 31.16380564628109, 20.70397403932387, 7.929761640487179, 2.1784971414073824, 0.38504262424765096, 0.15566911217906784, 0.07512304916857712, 0.043728107195948406, 0.021231965942969246, 0.0352976888027643, 0.03204901443584071, 0.022567458293070237, 0.03919149155638391, 0.011910578675357806, 0.038442981519526055, 0.11699353104397175, 0.022608987919445482, 0.026267812354490164, 0.04369988068637829, 0.07127874335574527, 0.033996396532823006, 0.03737647221573899, 0.06564345421089281, 0.02555514757160939, 0.06040446617971025, 0.06308638295459171, 0.04721024877301628, 0.07608527858411113, 0.03513070461790889, 0.02170314449035833, 0.03351658034408766, 0.025852648240904656, 0.02127780672913838, 0.06231129349720094, 0.03441107226535678, 0.04285237293750529, 0.06647282865859809, 0.02247110741483348, 0.028984632095201846, 0.042916034844013, 0.057612343826481414, 0.014871339963358498, 0.019612620779944044, 0.022391175716033867, 0.04636005588596867, 0.060753633733838804, 0.007196372842431189, 0.06164791881136837, 0.049436140219650926, 0.048002594360901464, 0.022729154556028308, 0.02804395656341747, 0.06060141972416352, 0.0687847977444049, 0.023796083292953914, 0.06449706491924102, 0.09155575771846118, 0.033541616097453146, 0.02183190088779215, 0.2587214671075344, 0.17550968625132116, 0.24031557653459812, 0.14872141482849277, 0.17454314376077346, 0.19326483109785667, 0.15673362199337254, 0.12065612080116427, 0.15697754438846342, 0.11372168443255848, 0.14383619470942405, 0.09479292352954227, 0.13991336488435346, 0.16876716256862687, 0.22120073287477418, 0.20591370881565157, 0.10263573333260514, 0.1506745713132043, 0.17014932307985522, 0.2502220739880877, 0.15236923441050515, 0.17248118746905558, 0.23032251114566482, 0.13964253748136182, 0.15460463300828012, 0.16233625281001293, 0.15595138493564822, 0.1883580685863572, 0.2019190965520759, 0.069391033762405, 0.1368387476090462, 0.3242819846397446, 0.12813164507068936, 0.2483636672578512, 0.0847750062483453, 0.19966672144589886, 0.11530132708890785, 0.09616111059703174, 0.07002094955814463, 0.23779793582375974, 0.13169285841286182, 0.15247322318534698, 0.09439182287502675, 0.2035835604634016, 0.30112084842497305, 0.10560423210864106, 0.335442966391002, 0.30102772277689754, 1.9165892081875957, 19.812040790434807, 58.59737450076688, 104.75754076434721, 96.0212770585091, 109.91547323042347, 109.1411110662645, 108.4742061553463, 95.39210534864857, 108.9473302902714, 71.62597025594404, 43.85591891504104, 46.10945001725228, 43.00806722333355, 34.53320987762944, 29.66848634904431, 56.839693746259144, 131.23204108207457, 168.13500189012098, 132.9754561762656, 123.70278481514224, 106.6135435719644, 95.95385935998733, 39.01322341734363, 28.359407071144354, 13.073043073377303, 7.3677203155333, 1.8739926358384473, 1.877712881372821, 0.7268827925285986, 1.7046831596282221, 0.9606240629669159, 2.899272864864719, 1.8818638521817423, 2.889168349004561, 3.944583780342533, 2.3463672303384353, 3.7103650839098044, 2.019408136125534, 1.950392439480751, 1.3520300893052932, 1.522923099898523, 1.6557220513782196, 2.8663945774878226, 2.7823774083968136, 3.9907780241581703, 3.5724020869501176, 7.4763464350854205, 10.49074870924796, 24.204854157663164, 61.201792993853175, 120.01357601534937, 184.985535529352, 205.9080699182326, 212.2951633699479, 147.87442238100115, 77.84104424138224, 50.718780179177564, 36.03688970688851, 29.684644552969164, 62.461442562841604, 96.60476100060248, 112.66313275983258, 114.77434066034134, 110.03715299790906, 115.56869906763878, 143.72486852830457, 125.28354706302767, 82.37591605032645, 47.149654742210146, 36.48591087710473, 17.379902601242065, 9.17124475202253, 1.0246328540867375, 0.5917562207868022, 0.17452411413673433, 0.145930525876822, 0.0922357143774148, 0.13920929943842275, 0.14011936592719249, 0.13672424810788325, 0.2105820187998395, 0.15575672199408855, 0.08772947795448766, 0.27706495215815885, 0.06657473367428587, 0.07260788292173417, 0.14953431072494677, 0.17401566158138937, 0.1663025198203902, 0.1803281188251511, 0.20740944952253373, 0.11767527268778895, 0.19063961632069082, 0.16038957742914078, 0.1855935330592817, 0.15609038392862967, 0.13414092301841707, 0.11753554591127943, 0.12702895343423853, 0.22345198949258174, 0.19993157336308112, 0.13539473315881145, 0.16264150820432172, 0.1850511734524081, 0.11973057933632406, 0.12387280142115009, 0.12544764836709346, 0.1396065773141961, 0.19151775226477655, 0.15840776925606115, 0.12143409841002957, 0.1842776544752621, 0.138499396402509, 0.12382348068058492, 0.12737611383800546, 0.17408883829991664, 0.17860546287509704, 0.1740111876279116, 0.14129451415952177, 0.12774796525557197, 0.20109069503603444, 0.16320268293061566, 0.18023905344307425, 0.19460577607875873, 0.10343583556072367, 0.16403828567314535, 0.09946778356548279], [0.025393476206508857, 0.027565209067336498, 0.0036080000075256274, 0.024974726801437717, 0.08117315194178974, 0.0836043089868561, 0.0404686022609953, 0.03379846239582666, 0.043321563486730864, 0.05160184013807485, 0.016342540001196247, 0.018000084223345886, 0.011468694372583303, 0.0656529383793954, 0.056559344483239044, 0.022369311566674904, 0.04126111638822383, 0.07909782741579317, 0.08978326008805344, 0.026876982489240267, 0.05039260482355472, 0.010613379230151975, 0.03706628321519783, 0.08928580855530116, 0.0334964896882734, 0.07690221942480534, 0.035354118839266806, 0.0453259559318183, 0.022702238056808714, 0.015362570862165623, 0.1354777464462865, 0.05047430043979999, 0.025292145756764278, 0.056853403502534476, 0.06724364334537138, 0.0512920992989694, 0.04561230810659547, 0.07179664943607585, 0.02758289037662889, 0.04519132747044487, 0.07892169614112185, 0.10207873378549853, 0.07802992383198393, 0.046679188963025815, 0.07731290383925361, 0.12359633561103575, 1.8075193705097323, 16.088001343511767, 43.560140825087025, 69.66784461852043, 81.88679648983864, 84.48742989570864, 60.22849998166485, 73.81917922727524, 78.32939501731627, 89.08694236509263, 99.73241190756522, 58.84625673294068, 33.65624243213285, 54.037234783172615, 57.243788088521654, 29.263656562374486, 61.439978922567065, 80.44580398067352, 98.85373823104366, 96.17637541986282, 75.27534346426688, 65.98437032391949, 20.29422167808779, 1.7421448591255373, 0.40252052187438936, 0.4092620649645406, 0.41350845968531025, 0.235845499461697, 0.09635302328294325, 0.03648476502407463, 0.24440385070779633, 0.1709452118243902, 0.17235381769076472, 0.19133507093835264, 0.05864610670194511, 0.19772712471744708, 0.09911660886099262, 0.23851808911610037, 0.04676438560108504, 0.0521573611354876, 0.07135250996197424, 0.5440253271691261, 0.2844525218730973, 0.4361236510017226, 0.542591271861907, 0.08850890346952985, 0.2320638902845883, 0.0303965934266847, 0.011908370426916068, 0.2211741955890771, 0.145016506374363, 0.7374789529750425, 1.6630571287485862, 1.3792510931530308, 1.0857219921965753, 9.01190140554982, 27.426239905818818, 77.98006088502946, 112.67350350656818, 117.62620972048853, 96.81605908178516, 63.3732485002087, 42.176034450531006, 31.481095975445164, 40.11592718862718, 76.41562354180121, 73.41459458874118, 81.41627680870795, 82.22009597286102, 81.16510391235352, 101.10860686148368, 97.00934563913654, 106.19315962637626, 100.39956785017445, 84.18191648298695, 56.49591369013633, 12.078274103903002, 0.38272585179055896, 0.059139222177045966, 0.008542980649508536, 0.03944063101023917, 0.04109942970136481, 0.03807124884558782, 0.05419108708719573, 0.0319427388885449, 0.0785907461578327, 0.019413524104522604, 0.11562529035032758, 0.12139749472900746, 0.04545582315674232, 0.04560462041427532, 0.05268783105777637, 0.061652710691334746, 0.03647818049836544, 0.026102645713235104, 0.030175494706077926, 0.02867094590328634, 0.01610059985860942, 0.052805479180308125, 0.028334506900019707, 0.053406394717674104, 0.043449132447882045, 0.008624672435314186, 0.008388991231068729, 0.03899883959562548, 0.015468601261325663, 0.053255080861309846, 0.05456473498094467, 0.008265162694207843, 0.04877657682124165, 0.010722953743571717, 0.03019861715485252, 0.011785893077631632, 0.07231274754890511, 0.051646575842413216, 0.013237856647690699, 0.043328944743881305, 0.03716512770962812, 0.06079770677212266, 0.006946732079790485, 0.04099484720838167, 0.012531692120847444, 0.022020260840954802, 0.01063358767198459, 0.043606349011702884, 0.012644280232639324, 0.02943157928154594, 0.09317411079762444, 0.09193825775817518, 0.019283160837667606, 0.015584737317816866, 0.01656113744473025, 0.014079175363745422, 0.0558875275084809, 0.051615637381591147, 0.04708489763640589, 0.03587840643200663, 0.061496099336974086, 0.008577997570917493, 0.02727642647861954, 0.04139378749495072, 0.03951767647278406, 0.05093825094762349, 0.02405088222134979, 0.03459127912778528, 0.012892758935659885, 0.034057365640276865, 0.04916389555399937, 0.04247503249996132, 0.04847121417462345, 0.021939149366751797, 0.0985602681495009, 0.04892224460960396, 0.042379562622837486, 0.06207439612837569, 0.03067860762859064, 0.058736911103610075, 0.07188366936339487, 0.04324082164995132, 0.06452990710855493, 0.03348298738860796, 0.069344716086503, 0.10430728355723043, 0.06416704956321947, 0.04870528084856849, 0.07927346839419297, 0.07316291362287537, 0.0008655679724348199, 0.04486286727290961, 0.04484067370574321, 0.03594217176038412, 0.04544002259330404, 0.06656447575697977, 0.0780767547867952, 0.17487717341751824, 0.0885436685395337, 0.3403824255351098, 1.0750207857739542, 25.58494402516273, 61.326528287703, 92.6924164064469, 97.08119561595302, 70.03516674041748, 88.06376857142295, 85.37240289872693, 101.98841018061485, 114.34311528359692, 90.7376326284101, 50.83352911856867, 31.588241400257235, 39.54792091923375, 27.816352959602114, 33.9526520236846, 37.886299010246034, 59.29204979250508, 84.01653366704141, 89.75617716389318, 64.48916281423261, 26.712780383325395, 3.4691758453845982, 0.3061242912325167, 0.6667808659615055, 0.6521664211346258, 0.4503217117199975, 0.1427770781541063, 0.2280397683141693, 0.18203404341493884, 0.20372295782210367, 0.122023495815454, 0.14171020878899482, 0.07745095288320895, 0.16031724340733022, 0.09512470088778965, 0.18141936510801318, 0.10405890253042022, 0.1074095719283627, 0.054130343975679535, 0.3080836683511734, 0.07480532952374028, 0.4683076788581187, 0.28222850734187716, 0.06099241184851816, 0.08110753651107512, 0.08254524605769305, 0.10346292442972622, 0.5152704927229113, 0.3076619522706155, 1.45328558500736, 1.5513729087768064, 0.669008833506415, 1.018237919817048, 10.71846289019431, 33.10389034209713, 74.91930207898541, 84.15544048432382, 77.54150067606281, 46.49769406164847, 27.381693547771825, 32.6412408967172, 44.11303027983635, 71.92712983777447, 107.52069365593695, 110.54469985346641, 103.48695954968854, 96.06616466276108, 91.53392868657266, 117.9250237249559, 111.954313401253, 123.81782793229627, 113.31711738340317, 93.54117024329402, 61.45589197835615, 10.288231834288567, 0.51354912380057, 0.024026189292330417, 0.09265317866999297, 0.10122888180757723, 0.06510598990585535, 0.07647646606088647, 0.03569098685177104, 0.0376320468081582, 0.10826319305887146, 0.1140018351255886, 0.018545847175823107, 0.05915632892039515, 0.08603284601122142, 0.0707228239926119, 0.061201760695586284, 0.01988427747311371, 0.07401653475338414, 0.03249930368075448, 0.03150627944588421, 0.023163064841120955, 0.03125542587029838, 0.031081857159733776, 0.07504087091693956, 0.06425622219760573, 0.005596822433759489, 0.04551463955712896, 0.031254590834460916, 0.027065572268780203, 0.019667679519062082, 0.02429040535653551, 0.03902825354147823, 0.06047105837252833, 0.013709444094509369, 0.04386268203116713, 0.09474528052153126, 0.031362942480031526, 0.08391385447354087, 0.06597428162011408, 0.009564162446035734, 0.02524164524079571, 0.0688937584298753, 0.009950616457048925, 0.019468322373746384, 0.05806715873580787, 0.04613432041820019, 0.019936641497958093, 0.06629905693473355, 0.025692781012865807, 0.05197198701000983, 0.013809386009891188, 0.04620158676839164, 0.007276918369180133, 0.06316047131774888, 0.10346953576851277, 0.13950657219656054, 0.1052567269653082, 0.13838794593128467, 0.21081490952882076, 0.12938264366840163, 0.12901107570336712, 0.10334349898321014, 0.07739109843368493, 0.1386746313543089, 0.09100529290134869, 0.12948090210556984, 0.2146508190180025, 0.21514428689354853, 0.19736876410822715, 0.0667986688354323, 0.15357298836592706, 0.16203003214491954, 0.15756931666645313, 0.1302024037126572, 0.08575644148814102, 0.17699350663010152, 0.14186223127668904, 0.13480691389451105, 0.1309744211574716, 0.1520777839205919, 0.15616290181154208, 0.2197847419208096, 0.13229486562551993, 0.14000730258562874, 0.2339917352242816, 0.13763924820288537, 0.14300981566550272, 0.237401592575254, 0.29771577146264816, 0.15264596069051375, 0.16745836263702762, 0.21846126374458114, 0.1487734168767929, 0.21901732100354088, 0.23806410541217174, 0.21319371978602103, 0.22928622401049062, 0.20646314707494554, 0.3062722994194877, 0.19159930998519545, 3.685825755519252, 28.64460260637345, 79.22546832792221, 112.32484402195101, 112.44378597505631, 109.458524950089, 81.6159019162578, 96.98166155046033, 101.79016574736565, 110.56358214347594, 120.70475255289386, 78.45062763460221, 48.433277837691776, 70.18991993319604, 81.18899899144327, 43.70664135102303, 95.74501668253254, 122.91946395750969, 146.97138294096916, 136.83139708734328, 106.94880424007293, 103.90237777463852, 33.95067907148792, 4.435838826241032, 0.2999852609730536, 0.9057897569671755, 0.9034782551950025, 0.40238777415887006, 0.15696910209953785, 0.2518374010199501, 0.454229740726371, 0.383073962143352, 0.21628609497941312, 0.2034290711725912, 0.1936062458421915, 0.4340014342338808, 0.16277422527632407, 0.25884109939779004, 0.15178732934498018, 0.14880108797261793, 0.16550482310835393, 0.6537223763523564, 0.46906901703726867, 1.1865407564947683, 0.8289706274386376, 0.1727532252909676, 0.2190078368350383, 0.15240635903131577, 0.1609189288630601, 0.4096646901340254, 0.3303423529911426, 1.181886251414976, 2.081570471486738, 1.4983097367709683, 1.4673340440757814, 14.43743561544726, 43.11535973702708, 119.8796662976665, 166.01103844181185, 166.69600978974375, 134.93207562354306, 91.31211080858785, 57.09860547896355, 42.35254110828523, 55.5619816626272, 94.76859754131686, 98.1111551100208, 107.79065470541678, 103.44328003544962, 100.13588259297033, 127.14267207730202, 127.30203013266288, 141.91607536808138, 138.2367980095648, 119.26066137129261, 87.31316028102752, 26.78303395548175, 0.6649429291006058, 0.20686135957798651, 0.182833502129201, 0.19198512718562158, 0.21281228460852178, 0.14720662917581298, 0.17272310271378488, 0.1152381248351547, 0.168553025672032, 0.1693889042062144, 0.15938342819290777, 0.2426949383751039, 0.23946077562868598, 0.16879273458353936, 0.20930848955627412, 0.1499497448845256, 0.1549826207901201, 0.09688445081513736, 0.16973719842010931, 0.10809899743406043, 0.10635739612963893, 0.11564487921855143, 0.1565724524158624, 0.21509496615298335, 0.12684107037080875, 0.12876048834333498, 0.1524868442286407, 0.13509926836817496, 0.1854474400921214, 0.1465144380927086, 0.1427329055243923, 0.18597458519281881, 0.1500843005675462, 0.07111755845647666, 0.17769895103429595, 0.11919309204864888, 0.21849224434023906, 0.1603381422859046, 0.09537117435566841, 0.17878753133118155, 0.16539369439405782, 0.1821836910300678, 0.17817723504718275, 0.14804863641338964, 0.09481139390939668, 0.1153062760168987, 0.16730799489924986, 0.14823782948716996, 0.17957635674505465, 0.10396110374600658, 0.14513843692839146, 0.1620503181531545, 0.09007857932198433], [0.03415554363821303, 0.025952105605674368, 0.01980310279665695, 0.10992464624465474, 0.057261077191440336, 0.022400462616895957, 0.011262371572816085, 0.03994439510748752, 0.04202335089024517, 0.01869422691543737, 0.041717662656259154, 0.050962899826587214, 0.03789179657976474, 0.04915622318343771, 0.02679542859926099, 0.013666117034341781, 0.056651765330424236, 0.022437799827105576, 0.029287880339149027, 0.02221112590162985, 0.07408201994915163, 0.02495823484364777, 0.018006080776573192, 0.03999966452078473, 0.025842622065195636, 0.08778458265888114, 0.06659817596476886, 0.026246545753712137, 0.037520343527918866, 0.05345440161744914, 0.04740890303266145, 0.043072738128924565, 0.044692374405360995, 0.05643458706476996, 0.03633062047283015, 0.04732323525052878, 0.05812993198032341, 0.04612369860913004, 0.06759321692609979, 0.03578714620802672, 0.07020418246787402, 0.049254382029175765, 0.03640808345329377, 0.1584007672124332, 1.3582513361207902, 22.745304915212817, 54.783363726831254, 74.10433553880262, 81.66477464860486, 88.89535027165567, 80.84160251002159, 86.89186634555941, 57.329715451886585, 58.59422483751851, 82.67818174054547, 49.977483595571215, 22.1621367239183, 24.208998141750214, 36.918391412304295, 122.26530674965151, 83.49235596195345, 101.04511153313422, 98.2054018205212, 77.09594295870873, 43.645197422273704, 20.491909134772516, 1.9650817157760745, 0.8773216232657434, 0.6813783342799833, 0.08869483300875272, 0.10658626489701772, 0.13102397172441407, 0.057627374471555796, 0.09627440734015358, 0.13092188284762446, 0.025492669270944693, 0.28684375807642937, 0.22614851173373962, 0.31519667215404973, 0.40003153285191906, 0.1652043787462096, 0.08984051749951417, 0.27084447143058626, 0.35499169160762145, 0.17429474741220477, 0.031765885576004946, 0.2667079643616753, 0.40470610943532764, 0.10120965300067779, 0.12427495927700113, 0.19441266063480608, 0.17196867464771196, 0.7173790734621787, 0.21690748421655548, 0.024848998366524617, 0.1550330906625717, 0.023954948861031763, 0.20804922486985886, 0.6665889149711979, 0.5398912715815729, 0.09765165722778729, 0.27613191835341916, 0.494745219907453, 0.4252080318908538, 6.601164648609777, 30.033433475802024, 95.14161494470413, 127.9937558020315, 126.10263993663173, 96.96288124207528, 36.249748891399754, 20.993066449319166, 22.008709292257986, 30.300593952978815, 51.53793973307456, 72.40952645578693, 78.34920298668646, 78.64206283323227, 71.35884115772863, 83.32196035692769, 83.89687784256475, 89.6403495727047, 88.99675923009073, 31.89529630445665, 1.2047004723741164, 0.09628088844399299, 0.01853484615323044, 0.04753651029820885, 0.05323061584344795, 0.03633561536609646, 0.011677686031156731, 0.03009914638354413, 0.03135292971086118, 0.049099218580992, 0.0036816732467888228, 0.013316856592052407, 0.06285070749600569, 0.028421205070410526, 0.06821592383447193, 0.03951458530800958, 0.06618698593229055, 0.023171413284275803, 0.036106895985862905, 0.02202169725581283, 0.10269220167350385, 0.011245526256971063, 0.007559993124056248, 0.020770800164750507, 0.029096883128307043, 0.02451951735683026, 0.010522151564908846, 0.03651783703976581, 0.05532530707217032, 0.0475328330761723, 0.02923211871436046, 0.017318947788988872, 0.02239214290203827, 0.06782116638796945, 0.014876625012426127, 0.032427973234124725, 0.03293115893499025, 0.029714464908465747, 0.05059262655014473, 0.042051428012670054, 0.025760355713446776, 0.01952340601072196, 0.035461122170090675, 0.19211504037582106, 0.043665640386602575, 0.06765226698330334, 0.06811522157682527, 0.05765852743699666, 0.07029563804427463, 0.007280531431353021, 0.03371360283645411, 0.07713918574154377, 0.03728344232865399, 0.00041805531744161745, 0.039181746917987065, 0.008535463411751534, 0.02899663477775551, 0.05070028105570425, 0.030169164904603557, 0.025084191189718344, 0.035289966636487556, 0.010487436290620076, 0.012268490165532117, 0.02239822755537687, 0.02022310284026448, 0.027639523426431323, 0.05649688150433283, 0.04086243274110941, 0.025794032938598145, 0.06278294318866345, 0.0462796128234796, 0.02219525639027838, 0.0411074276592943, 0.03356092534358463, 0.023409136112839467, 0.022430644565892797, 0.011201361288136293, 0.05062457241658723, 0.007966113569695623, 0.02175383844352778, 0.03985366731461498, 0.07144330670275996, 0.0778084401521952, 0.0495698646972737, 0.020739679758046425, 0.038783637836815855, 0.06730921281081054, 0.06781136046253866, 0.09796508678024816, 0.036831565366517154, 0.07439182590573065, 0.0641116269323374, 0.09738759438116705, 0.0332501158118248, 0.02232289238412294, 0.08968687090542048, 0.6599323463536079, 4.799630324686728, 36.979235218417266, 74.90644454956055, 94.33847827296104, 98.62442078128939, 89.13348520955732, 93.73068348053964, 69.66136486299577, 82.23875076540055, 91.05215964778778, 78.36541022023847, 58.35916111546179, 40.31405395077121, 32.845011949539185, 118.16867351531984, 70.66485620314076, 40.544136262709095, 73.5123243639546, 65.02334256325999, 49.85800427775229, 21.278328664841194, 2.412609443549187, 0.16686496625263847, 1.0436211093779535, 0.20857283064434606, 0.0541442982672203, 0.14688727776369742, 0.08554295576628178, 0.18613543301340074, 0.12045270913550932, 0.07814773283297978, 0.3710960548731589, 0.41790785748631726, 0.4987827484165469, 0.39239011224239106, 0.3678915090858937, 0.31861789824981845, 0.9543899458742912, 1.4622126543714156, 0.8015978768948586, 0.5750001618458379, 0.8929809507343077, 1.164492991182112, 0.46823824064866193, 0.43662019855072426, 0.6685571480662592, 0.33336208772755443, 0.5744536040771393, 0.29281342161759255, 0.13395834894430253, 0.18910414629405548, 0.05972105829465774, 0.13405257775898904, 0.5377541314209662, 0.15376798838617342, 0.03572105963323866, 0.5812852697507028, 1.0470257266875238, 0.08901176358302755, 6.957339884773378, 30.41159506767027, 81.56177320787984, 94.39094389638593, 78.87274526780652, 59.02457552571451, 31.175068732230898, 40.80635455346877, 43.902489216096946, 60.067941681031265, 87.27219504694786, 94.61029852590254, 92.49625867412936, 89.36789389579528, 84.39639952874954, 96.41025066375734, 96.30074593328662, 105.12737320315455, 101.3133232055172, 30.762284378851618, 0.31699020655885823, 0.07815747747137662, 0.1141875348384342, 0.03703870021948411, 0.057148435453493754, 0.04480402788988525, 0.04203845431367236, 0.061157706809500535, 0.03349211532622576, 0.029511677604469082, 0.03317587040064316, 0.0349603611375055, 0.07753329967418987, 0.05923957586468709, 0.04928564990780527, 0.054308754361925594, 0.07618573569362203, 0.016887642202838775, 0.0318588350238579, 0.053543382729854316, 0.04970021838802965, 0.047481210241394664, 0.0361913878230318, 0.023579452780165502, 0.039624936443062565, 0.037053876421264106, 0.06535607930873671, 0.017199608527364272, 0.030856707749227365, 0.05483634762405869, 0.08967515742105824, 0.02423673515178023, 0.030781020177528266, 0.0604628382491008, 0.007183884172850559, 0.017636339931238084, 0.06624183016678979, 0.03813235967930767, 0.029529908581847147, 0.06259491456852806, 0.05107908472118359, 0.028203452238813046, 0.03849655787851061, 0.04719436777034595, 0.06157808223619096, 0.006482884515031812, 0.0142039691713909, 0.017711343769464764, 0.07591627958801485, 0.019820159744291056, 0.03293725699486752, 0.061207391441829746, 0.10194199475189371, 0.06534514723405724, 0.08325933193367335, 0.10866866041455539, 0.18562403868042654, 0.10435989847587002, 0.08562966925843109, 0.20407499054506903, 0.1321991506002603, 0.1967914402484894, 0.16736856181054346, 0.12857567729248157, 0.12395965280912577, 0.1959478855133057, 0.14136301774171092, 0.15388987297492643, 0.1362030018842028, 0.15157110868923127, 0.12816179829138902, 0.26809718820356554, 0.1704204262744996, 0.14260017313063145, 0.16984224439628665, 0.10771584621961079, 0.1906839268462312, 0.15806184991473154, 0.13210820064188974, 0.13814745561009453, 0.16456933782225655, 0.12330175948239143, 0.1751689456643597, 0.19140496880056398, 0.16408950631176272, 0.14229487177104722, 0.12482009212216064, 0.1669146393936488, 0.11433042555807099, 0.1936541723027345, 0.25969832114154295, 0.1610668451194802, 0.2802648707743614, 0.13645003459626628, 0.148467778438522, 0.3551509459653209, 2.746934381223494, 40.54299877535912, 89.1295785288657, 111.12798767705118, 110.13365899362873, 113.19778319328063, 101.0466020337997, 111.46421324822211, 84.18175174343972, 89.57167671572778, 110.4648482414984, 70.4711695640318, 33.28031855244791, 34.69358774923509, 54.621334537383056, 138.12888576138405, 112.26887179959206, 150.97538548131143, 138.11239611717963, 113.64796930743803, 61.75922063089187, 32.77532712105782, 4.4551128629715215, 0.8692720003666417, 1.4504710392605875, 0.2775128071586932, 0.23247727132853002, 0.31183621215243496, 0.2019450822544675, 0.4121627189940022, 0.24414298244782034, 0.4370270831690681, 0.4321676955348061, 0.691604198467347, 0.6760239925596022, 0.42480773562865876, 0.5508574831389612, 0.46739122319606047, 0.6245215561601424, 0.628202639279827, 0.5859183243686154, 0.41926141227445296, 0.6162316268009524, 0.6900155159734911, 0.3069708490323636, 0.5385450405939933, 0.5228806263016117, 0.3696551354181382, 0.8383949185090681, 0.7954061704297221, 0.3565116100493939, 0.42191618272373754, 0.2561175342529051, 0.3203992058913554, 0.9679944416688335, 0.5625500686226353, 0.1511485958772321, 0.584498426366237, 1.076774452963183, 0.7706976285384548, 10.904993164923884, 46.64848173818281, 141.27985123665104, 177.68065452575686, 178.00712123993907, 132.4486504831622, 52.614873532325994, 33.67767034038421, 32.59742998307751, 42.007984422868304, 70.6099743996897, 98.14573472545993, 99.76612860156645, 97.2425776143228, 89.90019875188028, 103.10059824297505, 103.62019461970176, 113.22416505505963, 120.06438639856155, 58.63711987772296, 2.371845966385257, 0.3622632143237899, 0.2768648193488198, 0.14140101570275523, 0.15864400012839228, 0.13568287414889182, 0.2162869529978883, 0.1740372346173371, 0.10491730404957648, 0.15549812135436844, 0.11723061993477807, 0.18708060165086102, 0.2152020346012808, 0.15354301900632922, 0.20791751903391656, 0.17157875121601168, 0.3646822135534979, 0.13785741472196195, 0.11144757541196962, 0.10965509820849666, 0.2368034158022173, 0.11505011919765704, 0.1102237729355693, 0.11222007549217633, 0.1670383932369371, 0.09971529125205933, 0.190677231237773, 0.18595906425147288, 0.14545663920862062, 0.07426657053011079, 0.1325003763720874, 0.11904818651777123, 0.12754263070922706, 0.14904700219631195, 0.14516128167029352, 0.11412080091935013, 0.13261945707903755, 0.1714561771481268, 0.11137954680429352, 0.1542007974198749, 0.08078933423084599, 0.11194845135774344, 0.09759083750747866, 0.19064572970232657, 0.2701947675837625, 0.09718677975357541, 0.1374053922031195, 0.1548810375313605, 0.1394168633006273, 0.1029557818847318, 0.17943807787472205, 0.21644887334156424], [0.03700116191119437, 0.03551991941827921, 0.07925647656403242, 0.06567569119074652, 0.0320652995498911, 0.05512021384352157, 0.032767622145794095, 0.050583812708575884, 0.03289957696031178, 0.08926509353782862, 0.0183865430224086, 0.005879890006561314, 0.03257857845915902, 0.061480145555950945, 0.020818584899027503, 0.011185208324252838, 0.012299237104373114, 0.042576822602460464, 0.04092263193019936, 0.08766264444397343, 0.033828983338729995, 0.0184588291637239, 0.023165483763741872, 0.02237769448378634, 0.025573771169048645, 0.031390107957826506, 0.049694426763322086, 0.10125674442538332, 0.04915809243797295, 0.0770639865508964, 0.05447957281684203, 0.04562605555439669, 0.051710521201452905, 0.08950112522729943, 0.04030540638092545, 0.012807501010566711, 0.03634615673593456, 0.05475929450063456, 0.09609511978323422, 0.08463564719403945, 0.1107776238613071, 0.10966168656464546, 0.14663108264005956, 7.714082762118309, 61.1436281665679, 94.54990971472957, 83.3502249563894, 82.52502103005686, 79.1055928507159, 78.7099825951361, 67.91036390489148, 77.03320072543237, 54.236910881534705, 30.06183143584959, 31.291012033339474, 30.074273194036177, 39.86242832676057, 59.30182826134467, 71.82209660930019, 41.614319662893976, 50.886649777812345, 61.99532770341443, 25.912846326828006, 5.1242795105903385, 0.13394547866717463, 0.21732472634363562, 0.03158183486741637, 0.47342508490527835, 0.1406513986688468, 0.0662130329217161, 0.30644194192944035, 0.16477877093899637, 0.21500027768554228, 0.1847190743372325, 0.15894145674763188, 0.08628600742667915, 0.25476240132364536, 0.27310176482123716, 0.21765334741963496, 0.21518599272014635, 0.16616707547537743, 0.08302106326746364, 0.25511867817371126, 0.7110346397084575, 0.37673489100510077, 0.3669149308435379, 0.3438964708437843, 0.7721030628008227, 0.2809935123209031, 0.25493864751150536, 0.1366442225633129, 0.11486594399978077, 0.15462802933348765, 0.07043765542367775, 0.04515106955002393, 0.110989079450167, 0.2000197500831658, 0.23202529477496303, 0.6754893857625224, 0.4059317275401085, 0.37240290894143047, 0.2459812563874068, 0.11566784653452136, 0.11934384283038879, 0.592179162608039, 0.30381199272890247, 0.594170255766761, 17.795771898761874, 56.04925770913401, 89.72191133806783, 111.18008459767988, 77.36486065772273, 66.27287633957403, 37.70807827672651, 14.968093076059896, 23.585729598999027, 40.033643707152336, 37.65707569737589, 53.052657111998535, 68.18114080736714, 75.56850925568612, 81.09490917574975, 87.15085260329708, 93.6212101290303, 49.77280647523942, 5.448796806796905, 0.28849409532643133, 0.14633819190484865, 0.13395356855565502, 0.02262015556616168, 0.08342715115436623, 0.08249451571534719, 0.03158234240066621, 0.04682015297153304, 0.03964039226693492, 0.12329077378155724, 0.023146957842512958, 0.030654033443199533, 0.028215309364661097, 0.05775709230933459, 0.018786316429595315, 0.01888408457049199, 0.0104590019797005, 0.06068422999833861, 0.06221595002458461, 0.03993224878344805, 0.01096610813551853, 0.015665671634187382, 0.027426403511555928, 0.09135297424490414, 0.03287947864361829, 0.03152867028069112, 0.08874631411726437, 0.06691055597677346, 0.010204620569223359, 0.009144920829473244, 0.04452907893386099, 0.06046763395950679, 0.018755261140364795, 0.023341011744172826, 0.050668507559044715, 0.07696496968668315, 0.032258656311539874, 0.02758581874771945, 0.06198422757968788, 0.06483017527047666, 0.0443990929653087, 0.03958309655107799, 0.03403525634278213, 0.03013643188281886, 0.00611575746593336, 0.05052415361147254, 0.04741663669025706, 0.037166847577018124, 0.03841238396783029, 0.01601024936403959, 0.01663376832561147, 0.04315415412307747, 0.06197578912120193, 0.09792132017713401, 0.02353388970086892, 0.013688210052468125, 0.05087535512904006, 0.051495281138247063, 0.04997375008139399, 0.03381455790311579, 0.017004072245570923, 0.028218846775651462, 0.07044592151238073, 0.01950876224004934, 0.05659636951261952, 0.021588890137331142, 0.07261751264694237, 0.015553608292623635, 0.0514111531928422, 0.011915720082939634, 0.07433806951608389, 0.007474181221632828, 0.0477444495434963, 0.030459018101194696, 0.10677093805204477, 0.06660852581262589, 0.021679085499096303, 0.053689008383380796, 0.05920517468644727, 0.08313336409628393, 0.04279155321719666, 0.10379591220689398, 0.07571227037377896, 0.061953499793044986, 0.03832667405086179, 0.0656828464519593, 0.0960574435791181, 0.06620071422789367, 0.052408358352559234, 0.038806593661466916, 0.0924031428932663, 0.03450564965004883, 0.10435711757670488, 0.4060346897571318, 39.91251307149088, 96.48831367492677, 95.94142544654109, 92.07523930457332, 88.21980045687768, 93.34932711816604, 89.75712637747489, 100.54762163469869, 66.13447943041402, 40.77147291552636, 62.38925918456047, 34.0212542779984, 22.742233699367894, 24.5943513993294, 23.911556966843147, 40.21533966064453, 52.24707288126792, 63.20046024937784, 33.42377531913019, 7.582308774994266, 0.500857651594185, 0.3324012602529218, 0.041712801828379595, 0.35866465419530874, 0.6254189821981615, 0.09138355647484142, 0.2636872183892035, 0.4402986156844324, 0.8054536280612793, 0.7432487594985193, 0.7485883923307542, 0.8493281576421954, 0.9005839137300369, 0.9015207473308811, 0.9512381375797334, 0.903860992721973, 0.8662823575638956, 0.8484581269083485, 0.8239592479601984, 2.4791889805947585, 1.8024823117640711, 2.767437590706733, 2.7808082151797513, 2.8758773976756684, 2.4960931702967617, 2.0935155595502546, 1.6227220479519138, 1.4358463594990394, 0.8331078086649218, 0.8163348345025894, 1.0220360611715624, 0.9250919244462444, 1.0331238662042925, 1.0348699338013128, 0.81226690762466, 0.7104674282093203, 0.14352718548428628, 0.33085029992845755, 0.3595509259931503, 0.028124945463552594, 0.5582028567310303, 0.33412881916569126, 0.44872193627299806, 18.81398585534865, 58.99674630934193, 76.7175675976661, 69.22877450143137, 36.290110080472886, 36.8102006758413, 31.29751728427026, 24.41016866314796, 44.59628589691655, 74.26785130654612, 69.42108831098004, 78.86598310162945, 92.41449294551727, 87.45172192973476, 94.12749398139216, 96.2391725663216, 106.34370803833009, 51.03074589083272, 3.380330974055875, 0.19376059723717554, 0.06728107440135173, 0.030366175905651147, 0.015247625114786771, 0.07590071268139348, 0.039125745890722166, 0.028493190522215543, 0.0361499922620433, 0.026444227081693472, 0.04650716775006825, 0.07460244645875308, 0.0676681709686114, 0.005440797615465859, 0.08173407385906867, 0.01584248568472122, 0.028844315430990634, 0.030532581694123727, 0.03678363124509493, 0.009112538292913908, 0.009919015330172355, 0.04347977979529289, 0.0028549037374285685, 0.026101644053274108, 0.05492460478337542, 0.0649052442261769, 0.050447054522772955, 0.05934610805143753, 0.05407745326538721, 0.025687780373940067, 0.04937557330835731, 0.04422172062820004, 0.06086257143667149, 0.04604686765120395, 0.04647051044289143, 0.016408513578015472, 0.015756196413759985, 0.07259021693420026, 0.017435036922594713, 0.007102822015557679, 0.05899311005768757, 0.054594857558127374, 0.0362685443683257, 0.02990679319707617, 0.008903364688458463, 0.09031792817216727, 0.07766525831914718, 0.018631306198996403, 0.07703865968411969, 0.01851657304101654, 0.046293965480740995, 0.12519441034284332, 0.09923707618708573, 0.13424364008730458, 0.14774463740327667, 0.16352229481262548, 0.16605462908985155, 0.15116100650160544, 0.19146366645732235, 0.10299339680181396, 0.12120123066368604, 0.11462538473067746, 0.10682618065226464, 0.19330351853803282, 0.10771984519857554, 0.16292952662033422, 0.05520179837701782, 0.1427405664036351, 0.22791324123259515, 0.2237750640920093, 0.19999007183697917, 0.11071393131128243, 0.12634495949192395, 0.13988508091818902, 0.10929618601597126, 0.1678047416311118, 0.2110258901431676, 0.14109883998190204, 0.15708891825089533, 0.26299893435451294, 0.1420201986066757, 0.10770993202083534, 0.15573006213432358, 0.2295783793012942, 0.14879155783883988, 0.23332936028319023, 0.15666380073995362, 0.17033178990166034, 0.11147569083879072, 0.1120871822199514, 0.22248503331455494, 0.19051639873894954, 0.19310473404344053, 0.21222253480265219, 19.062454277469268, 89.25446679515224, 123.32006346794867, 106.81789121320172, 107.88308928089758, 102.07138399924003, 104.88456280000749, 91.85386073204779, 97.16987256080874, 77.73397922515869, 49.98170406587663, 54.751266971711196, 48.273578536125925, 55.74003373422931, 81.6769967540618, 105.97075339286559, 57.2822626175419, 76.51211384804019, 89.86375208823912, 45.1008713629938, 8.99215619410238, 0.8418351435853589, 0.5929143618672126, 0.1823829045338977, 0.8985041382332003, 1.0811885902958533, 0.28443864035990934, 0.4244047733804872, 0.5115800633305504, 0.6365101580177585, 0.5253080831420037, 0.5919150767787811, 0.4503671866991828, 0.6097838631080044, 0.4511487802430507, 0.3241028426395309, 0.2772696508515266, 0.37008727029446636, 0.3292035173264242, 0.3444895148277283, 0.7807199584860957, 0.5453661648977188, 0.9240003410846958, 0.789317119746439, 1.2503600481056398, 1.1685982418637122, 1.162843879672789, 0.8077740777404079, 0.49790389234981236, 0.30905699838073025, 0.29018604647248025, 0.29605703788899607, 0.4106160794054309, 0.4017328302706442, 0.5182532713778558, 0.6246644775232961, 0.5239225671656671, 0.4929921962320805, 0.9731223277987974, 0.5333884721321445, 0.2266776946283156, 0.6094016158773053, 0.4360335590618272, 1.0245806375338187, 27.096464672396262, 79.71993800132506, 127.97494411468507, 153.44603938441125, 107.14796650794246, 89.86672524482974, 57.40833543962049, 25.719336194376794, 34.42773734369586, 60.53697086149647, 58.514271243926025, 74.53557660502773, 93.27654361724855, 100.37310754099201, 103.52434758217105, 105.30952022921656, 117.54914299134286, 81.75229057188957, 13.053663622948433, 0.4534515486128869, 0.4331499121842846, 0.11638340329931629, 0.14028687871271564, 0.1833233693915029, 0.1918676859068294, 0.13320868594511864, 0.2590236734719046, 0.10969497308495546, 0.16911505841680113, 0.18745478963659656, 0.13083434964139617, 0.09949465792986656, 0.1926368228610485, 0.1345052131481709, 0.1186072646129516, 0.0791283100543003, 0.12574332766234875, 0.157062656756851, 0.16015942929492843, 0.0945397544532053, 0.09150841348474065, 0.09651778581281824, 0.1774685117866724, 0.15509551150664208, 0.09285085233709506, 0.13594778735310803, 0.18677445759456004, 0.13591179654242533, 0.1531698575784122, 0.2043900825083256, 0.137918058242048, 0.1253684578583606, 0.16280258585128093, 0.09682310249416098, 0.14887481627445068, 0.13661180172235737, 0.14314383508697634, 0.10227877466428666, 0.16934277039141427, 0.16747690196479523, 0.1621898687294414, 0.1130234795592485, 0.10294485747093156, 0.17299933869752193, 0.19871957630159395, 0.16983617697992634, 0.15706906125189798, 0.14131968780871362, 0.12063273979771523], [0.036807092687776016, 0.01668279986798523, 0.031576612062992594, 0.012886417642866653, 0.0713299333508457, 0.007843812420633773, 0.03997777738878804, 0.057379211779804005, 0.019883720144148798, 0.031098709178848133, 0.044876507468401425, 0.04788489644265464, 0.04627719964651812, 0.02673058691734989, 0.008870718809175155, 0.047843324681443554, 0.05936295815533208, 0.06018847535033861, 0.07489037294421466, 0.05888559344795443, 0.053162499135660554, 0.06688792573949022, 0.05709823371181565, 0.03650094480103543, 0.04133130919428603, 0.03594100730673921, 0.057893130372488694, 0.05209012925925274, 0.011164786335411332, 0.031963216418760924, 0.007224818165864676, 0.03796652462633868, 0.02041026003538601, 0.060757142416532, 0.05760987702336523, 0.05358604233591788, 0.039141174901517174, 0.07722469647565196, 0.042012234954463865, 0.1443495655492429, 0.07867444126356034, 0.2832190283844548, 32.5912836290175, 85.11635057387814, 93.69076159692581, 75.13154937374976, 67.8050482657648, 78.07061272282755, 84.02960300445557, 61.880221828337646, 16.33680610887466, 10.249269950774408, 23.48163381699593, 45.72386141746275, 24.993868335600823, 59.65809322172596, 99.17883211566557, 87.26274213483258, 76.26797768377489, 62.293035599493216, 26.226486890546738, 3.1271363410257527, 0.11029623719232698, 0.26473461379927976, 0.10887395665650407, 0.26203277490792737, 0.16418470039723382, 0.08326693918676147, 0.08577767744540207, 0.15784909197640035, 0.13813424825427995, 0.08837204186185714, 0.15167566436913707, 0.31136335204205207, 0.1258517597471514, 0.43896182290007996, 0.8273356119471212, 0.9329538251603804, 1.035081496642482, 1.850782378065971, 1.7198580743805056, 0.5723200798515351, 2.8728694300497732, 10.110001294843613, 4.219767220558659, 3.216162131678674, 5.653340566542841, 5.71563417873075, 3.3562682136412594, 1.898457929491997, 2.5569830642592524, 1.9088480429303263, 1.3779308478678427, 0.6240281955369058, 0.6072404511993932, 0.1284768749328871, 0.4579425705296378, 0.2551351950293587, 0.4384844275491853, 0.2718408147413885, 0.1562953124483747, 0.07110909318491336, 0.03390522823939401, 0.08916771610177333, 0.3324328230754022, 0.18680128599366835, 0.13426009565591812, 0.4129277343951887, 0.2808181701167938, 9.308349240210749, 50.45401627017606, 94.51926815894343, 89.52737746700164, 91.06372279505577, 109.60403703874158, 55.93070014830559, 14.06171569901128, 18.923057163915328, 13.613984007989208, 17.93432374154368, 39.72642014103551, 50.43862096724972, 87.17346114497032, 83.55682403810563, 88.132535565284, 70.68037309954244, 27.328113971217988, 4.704789865401484, 0.4279528329929998, 0.23686867117160754, 0.017418382171120857, 0.02222065795062771, 0.1027345203704411, 0.06259105348538968, 0.034590532192059105, 0.050763724627153534, 0.03949078295620219, 0.08871068336790608, 0.027163032059287353, 0.0213775877660561, 0.10725401011445831, 0.06869526504869423, 0.08386107101555794, 0.08509487093937013, 0.08269863218189248, 0.023336932325976032, 0.06097892104017158, 0.029322099571506825, 0.015149919218533944, 0.07641695635092836, 0.012885564412440986, 0.052492953611597906, 0.04038875291664754, 0.02716903052773447, 0.0423666425499945, 0.037328365724533796, 0.02992706196833282, 0.05936480825766922, 0.035215238589913614, 0.023703449856369727, 0.032834926800381754, 0.04100767535067374, 0.060796270357264634, 0.015341226694985263, 0.03181236796081066, 0.010251763704863769, 0.017340426979165886, 0.06083207347640588, 0.05236125160609523, 0.016524259887275197, 0.04347174736340681, 0.02763343111221348, 0.06473491989797162, 0.06302214648214079, 0.03424478522051246, 0.035766641864733356, 0.06465893929764148, 0.034272153711607384, 0.019776584663157983, 0.011458067775463626, 0.053759132241529804, 0.009908838809708194, 0.05034991457397419, 0.04148779414413918, 0.02625575796100161, 0.012952871939858362, 0.03015770231403651, 0.033994921813568765, 0.026090062719078797, 0.010841862080738911, 0.028579235602650913, 0.020957189356727947, 0.019422627144282865, 0.04251806365866815, 0.055622304038655375, 0.02062043817263217, 0.029469098437637575, 0.025139862799175808, 0.041510474177137505, 0.03541906011260806, 0.04237444132506367, 0.01099298824556172, 0.03222535063903178, 0.03547716022078549, 0.06816515518772988, 0.023715352947493235, 0.02573182276870695, 0.10046542922575628, 0.013407489581544314, 0.0325502791712361, 0.06043207215806169, 0.13149781242734002, 0.009252203782389482, 0.08376992187432705, 0.046254217008789705, 0.08784915621001875, 0.15063315660001772, 0.1347000599508324, 13.835795021826222, 73.07989089719712, 110.25794321490874, 91.19895827385687, 90.00412587196597, 92.66855270631852, 97.17161409316525, 73.03535630626064, 40.81524264427924, 35.014135606827274, 45.47817199460922, 38.97402324984151, 24.666707361898116, 41.84416663262152, 50.87163102242255, 53.99412009023852, 68.91107820695447, 68.93817394010483, 32.24387734167038, 5.75663814621587, 0.21126647239490864, 0.34103096492828866, 0.19434084755278405, 0.5256476745970788, 0.34986892294499183, 0.2766674444560082, 0.6472488721051525, 0.4234126282315101, 0.37927245000197046, 0.17196300559707228, 0.6794553310159714, 1.215866479662157, 1.1924906243239681, 1.8341878104594447, 3.0766122908361497, 2.7574916856904186, 5.3941949625169086, 6.821064977876603, 6.439176153752112, 5.74901060711953, 7.028626020877593, 8.397854355073745, 9.661194874394326, 12.064370282234686, 12.238281311527377, 10.000818198727025, 8.312797757887072, 5.504449846283083, 6.390481398951623, 6.690499080765632, 5.421319623147288, 4.961418288369333, 4.035841399623502, 1.446475614943812, 1.567975566271813, 0.7654917240142823, 0.8207253150401578, 0.5104563655632158, 0.6484447659984712, 0.30574480191834513, 0.8675834200074597, 0.44367574575927954, 0.39712395338762196, 0.16675723896872613, 0.07140856461539384, 0.40530644657631076, 0.21058155914708493, 9.922807158962373, 47.25738656136298, 76.97108607138358, 62.417170770706676, 60.10219966211627, 58.811704574092744, 42.561870159641394, 22.242264862983458, 27.76763516087686, 27.286762383676347, 37.50081631445116, 64.05471324920654, 65.42205933601626, 97.28126002896218, 93.1628341059531, 104.273465371901, 77.10386614645682, 23.75007494803398, 2.723599220475843, 0.2672070246790686, 0.07470300315969414, 0.010449799348510081, 0.0384073737528055, 0.0826960964308631, 0.0628812054562713, 0.026156258461396062, 0.05007629861093817, 0.028654902106932098, 0.04351647923730555, 0.046259840094153924, 0.03210005887423552, 0.02009465287800037, 0.07094033167607362, 0.009683337956366521, 0.05288093117997051, 0.04268289513645634, 0.02106358173243221, 0.03703970379466492, 0.03169304976660398, 0.08966771104643423, 0.15205834060907364, 0.023557504361134865, 0.0404043159928293, 0.06521859716984534, 0.011066824757313777, 0.04636054235180059, 0.012280144278080234, 0.02369037465072207, 0.03917403624302918, 0.062083367017969016, 0.030961271090012406, 0.04561040820854326, 0.04183971961479514, 0.0034755560937487794, 0.02852260255284848, 0.013311019959679295, 0.03729533967411807, 0.03471494487096225, 0.017725116115123514, 0.0323518700597267, 0.034341178233585054, 0.06380217337620354, 0.0503958223928367, 0.03901569352995965, 0.07354832479670163, 0.03379231070979469, 0.028377775545983065, 0.1426015367671367, 0.09139337006115145, 0.1303061013740878, 0.13617790484380338, 0.19813794702772172, 0.11536802270359571, 0.1288283024463923, 0.12375805677185137, 0.1319568523115689, 0.15250987283164455, 0.14428625604318035, 0.14115314029397505, 0.1983125844309407, 0.19757723195418236, 0.14705623079451824, 0.1072323528088389, 0.13211906376865604, 0.17249465529476443, 0.22378980362367248, 0.1303167653179938, 0.11715065567724167, 0.14315891169732617, 0.17033229551969037, 0.11031262381302734, 0.1464503318552048, 0.16528728478137525, 0.1141638933650909, 0.1283855112870374, 0.14978410135353767, 0.08980180707670028, 0.0713972648185107, 0.15668304486861154, 0.128189247221716, 0.18445082098966648, 0.1621742252140276, 0.29567515838050074, 0.1602263240924766, 0.17136600859943898, 0.24879557230780203, 0.28471084672116465, 0.3521018853831676, 2.8790027912585967, 61.327018583974535, 116.63312050604053, 117.71249401953914, 97.5320642225204, 93.99898928980674, 102.90027495353453, 114.49007864921325, 82.66012314827212, 30.257518483746438, 19.455387515406457, 43.91010645897158, 72.40215239986297, 45.08518580467471, 86.4781661187449, 149.0192053394933, 134.415248440158, 109.28445800658196, 96.99819041836648, 43.768528507601836, 6.19927958134682, 0.400166854622864, 0.8463597201531934, 0.3312941099847517, 0.7898450462568192, 0.31176141132750823, 0.3619452571916965, 0.5096258649662618, 0.548665491082976, 0.205679546380716, 0.15645996006506105, 0.4402682479591139, 0.7268947435002173, 0.6819924916471205, 1.768556383828963, 2.9329660246449136, 2.5601572423211993, 4.886254889349784, 5.248716704307064, 4.6980556461118885, 7.310523333088045, 11.214871195054824, 18.908087438152684, 11.432975569079, 12.745445735992925, 14.610744560918501, 9.520239599289434, 9.371343485770687, 5.319910174415958, 5.473965185303842, 5.391723869308349, 5.836268144269144, 4.8092626852373925, 1.5091620770192917, 0.7298327826203839, 0.7936491324536262, 0.3445999234193756, 0.511857295228589, 0.25116871351436265, 0.2601906705287195, 0.1597462627556055, 0.42536183170253233, 0.4351942024884686, 0.704407427580126, 0.36418906743488005, 0.20674165067893846, 0.5639553803109354, 1.2728906326716947, 16.648886549857355, 79.3427001276324, 144.95128385482298, 131.54543845884263, 119.46454617284961, 133.74565278330158, 80.80668557074763, 22.148581012602776, 28.30241111017043, 26.127356829181796, 32.381091656223425, 57.45618835572274, 69.79023825737738, 111.24058323521768, 103.08537944670647, 111.22663528688493, 102.54399822604273, 51.52780825091947, 11.294350181856464, 0.7879337488162903, 0.32382521237577166, 0.06852041314085645, 0.09737714494187986, 0.3138500734442665, 0.2794498145099609, 0.11360315530891381, 0.20564164035022262, 0.082731872736927, 0.2017257359599875, 0.1170732195098554, 0.08257713063710159, 0.14791210422352438, 0.24907787570789938, 0.14649424401502456, 0.19207246120898955, 0.19751050569597753, 0.0910969476606096, 0.2377969245876997, 0.0985815117676412, 0.12879202052229835, 0.24357184857851077, 0.08768398765354388, 0.17124588601291182, 0.165416922179922, 0.12310089122864509, 0.13370973809111503, 0.12197593707711467, 0.2393128593722659, 0.1563468548439203, 0.1229261618948752, 0.08538407679166525, 0.1519476562257736, 0.1359526903158234, 0.11553896756301965, 0.1295825313296049, 0.07187891961826433, 0.12122984404765791, 0.10190877717949691, 0.23233620389815302, 0.11732569910706052, 0.13216501372235437, 0.1202288122787591, 0.12220854435356394, 0.19993174190242446, 0.16291581364648958, 0.09903366452143078, 0.12448155020754184], [0.02463432329316293, 0.0207295808039846, 0.05124924051004553, 0.1127260076182504, 0.018000825413412625, 0.04349969425088456, 0.04537968550838771, 0.0537758827539942, 0.040041174994961876, 0.03379929743166413, 0.029853764590957475, 0.010427757083708722, 0.03728118236927736, 0.09494690720232264, 0.02617857077219073, 0.0339177193029994, 0.0338583359975488, 0.028162068169143413, 0.025500456554695003, 0.032862234004442735, 0.046190593406678214, 0.013191786992754187, 0.037052757932894656, 0.012526470274033566, 0.039138160345535127, 0.056123252762782, 0.03293100571740539, 0.03867352035857978, 0.10614328221568178, 0.04641986820065687, 0.10294435185290153, 0.04060860865959718, 0.06263360966958346, 0.040467931934061556, 0.09924649906855437, 0.06413061059110108, 0.03496849699126136, 0.06028617837376172, 0.09458683821703158, 0.09307131711994449, 3.3471016345485567, 58.94785788751418, 107.06105462966427, 102.19153404235841, 75.81435557334655, 93.31757160925096, 62.52998205923266, 32.28800204492385, 29.238008183817712, 37.24267336630052, 29.384145890512777, 45.92633416575771, 36.664539537122174, 38.68575649876749, 71.85153007507324, 47.04335458817021, 48.78331015186925, 40.75383793923163, 19.71806864584646, 3.1144303131488065, 0.2805060352529249, 0.15890094601819593, 0.19893527601755437, 0.12875840458418095, 0.10270622108251819, 0.056187282391493364, 0.043291414096470804, 0.03508536370411035, 0.3727799774177613, 0.4403311897429728, 0.8837494686726601, 1.3989920145080936, 2.0244944696464846, 2.0014328942183526, 2.158688436592779, 2.90047874854457, 1.9737014919519427, 2.4749089392923542, 5.558028932540648, 6.503588336129343, 2.228519128214929, 5.083948229589771, 3.5746998604266875, 10.403399486695568, 8.530937433242798, 13.690425119092389, 18.668132520491078, 9.95258383212551, 6.736739412430794, 5.043900830130424, 6.0730062280931785, 8.566330940492692, 5.527738428884938, 4.370926051370559, 8.0908568155381, 2.7920151622064653, 4.61665028525937, 3.468642403041163, 3.0896973177309963, 2.5616953017250186, 0.9524464114539085, 0.8108075407724228, 0.3721155033957574, 0.12940626981998646, 0.08383885446575381, 0.09740299274844509, 0.09946944597627848, 0.2269579295910174, 0.03475077480318085, 0.2454956638957224, 0.33159377293721326, 9.539729856675672, 41.42674799888365, 69.15264129638672, 75.14829004964521, 89.92998523096885, 116.43392685920962, 57.60283793172529, 76.93700067458614, 79.52265847113826, 18.11706696787188, 30.047444182057536, 67.97772669023084, 67.75819947642665, 69.76716687602382, 82.17530250549316, 96.07926537913661, 72.8288435166882, 29.00680015164037, 7.39975578361942, 0.3364769092971279, 0.02038936498725126, 0.08096993179811586, 0.015064857603471368, 0.022064577112154617, 0.045577849471761335, 0.08832809905852042, 0.03625697261022945, 0.051638225484038555, 0.05963626385275876, 0.026053104722391696, 0.03586999478659803, 0.07400541881760282, 0.05558436736464501, 0.03776000264371115, 0.06269826365995311, 0.07114917490511172, 0.07479114923626184, 0.08005377491034808, 0.03174390076779791, 0.053496046157013026, 0.08857896987108455, 0.017969634143575546, 0.021612311360396205, 0.00554998908492346, 0.040107395635136676, 0.04219681234850038, 0.019854794579347777, 0.05384648158665627, 0.1049431671779002, 0.01714907545265892, 0.05472010527286799, 0.0435709136147653, 0.057849210551789695, 0.07278891715912089, 0.042671591509133584, 0.030689024509141044, 0.021096536919714946, 0.035913757559272556, 0.028358452893312902, 0.003214195861683918, 0.03788641098165705, 0.06348312839925771, 0.020389809318247343, 0.014115396000805401, 0.031470462920204285, 0.024146173983031226, 0.03557298249835449, 0.010279001961011561, 0.09006255276260838, 0.025041941440694278, 0.023373543667877396, 0.023179637238142953, 0.050414269790053375, 0.15354327947622345, 0.03558161247882151, 0.019261551412543463, 0.03207293936171599, 0.03445720991059657, 0.031918697134261174, 0.06580758088779065, 0.030199438784151312, 0.06907382739647742, 0.05249363926029014, 0.019401923618129185, 0.06799478489424914, 0.08646037669912462, 0.041018752982058836, 0.03404988096125665, 0.020075000807522766, 0.041622847784310586, 0.007947319517693213, 0.05203103323677375, 0.039576948695485635, 0.07864718385521444, 0.07339051068429986, 0.03161073170392023, 0.015590500214227266, 0.08362138508668832, 0.037025707368288314, 0.009526440276644163, 0.148209055224734, 0.10627704116726115, 0.0411569667349179, 0.061901156835618525, 0.0690126476148444, 0.8837915728649787, 39.95188974565075, 110.40263160582512, 113.35212061482092, 87.23570915960497, 89.61738801771595, 77.84693564138105, 61.04927947444301, 62.8229360426626, 62.163726822022475, 23.38844810762713, 21.694407809165217, 32.64242153013907, 48.02420993005076, 47.49349363388554, 36.76227323470577, 49.00502604822959, 51.615100599104366, 28.085492272530836, 4.350156120715603, 0.08094167081458915, 0.2842839518862386, 0.17347924681680818, 0.1767090428620577, 0.1461633093534939, 0.11985471622357446, 0.38529371722571315, 1.187360899582986, 1.9895255589677443, 2.760985536921409, 1.1593711111814746, 1.9346584644048446, 2.3204352153885752, 3.6325533495795344, 3.7201587519338055, 2.3506239825679414, 2.2160195150683006, 5.0889065957838495, 8.672184924925528, 12.034617143292582, 10.498952346463359, 12.006537875821515, 20.51894799355538, 10.399095666023994, 13.200053341927068, 20.085088745240245, 19.369881806835053, 18.41395312739957, 11.66527892312696, 9.569936029372677, 14.006205335740121, 10.336810388872701, 5.179897248744965, 4.043817539368907, 7.208547101866815, 3.607853449160053, 4.179154999794499, 2.606369381950748, 2.2725492042879907, 1.9124985438200737, 3.4774787675949836, 2.573029970930469, 1.2946347820182003, 0.7338729464719373, 0.14712831966819304, 0.5051118910552994, 0.4360140084979996, 0.18918424844741824, 0.03974541526047453, 0.19065617914161376, 0.2916505001485348, 9.559270124281607, 38.878450778222856, 60.5213245268791, 66.03765180034023, 67.70658108495897, 56.59863272020894, 40.473765019447576, 36.88440799713135, 52.12855454414122, 38.11816600061233, 46.46729961518319, 82.98558573569022, 82.40198412249165, 77.09908869958694, 95.62842815153061, 107.91412307370095, 79.28871262458064, 27.26366158454649, 5.311846761934219, 0.3138432399399819, 0.17989386954615194, 0.06290831347747196, 0.08006092251068161, 0.03656009828010875, 0.009987535191729907, 0.022322118635319417, 0.0440087175417331, 0.06698532615818324, 0.0508718541072261, 0.009634455801137995, 0.034299671589847536, 0.10849635957950547, 0.03502366681312842, 0.07762928283022297, 0.05292482418759216, 0.014296638039541582, 0.0604109894183855, 0.02025402406410825, 0.024357891957005186, 0.042071752325301214, 0.034305612601700335, 0.013357207400634164, 0.02984618606616653, 0.013060832880587589, 0.056999032986500574, 0.028993539782541416, 0.01853774771124365, 0.03473157663979838, 0.03081348123809984, 0.06620921014297394, 0.05084542790427805, 0.008688894543616522, 0.02099013879835125, 0.005359324164718631, 0.044210777062201695, 0.07067430764436722, 0.04943013409032457, 0.04984681697321996, 0.03760550569202151, 0.046863187960679495, 0.009652726998132084, 0.07731884102066679, 0.043912198124153, 0.041418926670185985, 0.08853531818115905, 0.08261351981350491, 0.19327002517398328, 0.13198190338669286, 0.17402886893720398, 0.08688408460828566, 0.08581494762291832, 0.14796029115396162, 0.1453297137613258, 0.2758153708231065, 0.10977507523831823, 0.1202399435362989, 0.10398214052040732, 0.13182180633227672, 0.22954267960402275, 0.15505167595561475, 0.09801349587618344, 0.15294331005744397, 0.21808270905767718, 0.11855188411690536, 0.22443864945202108, 0.1390687989131097, 0.16949555896703275, 0.17880938015878203, 0.13987529031451673, 0.10902826208621265, 0.09249170265731313, 0.16248936314255963, 0.10426861143881276, 0.15069861115226824, 0.1451519200758588, 0.18505411523003734, 0.1051405573924703, 0.19609699686688764, 0.20156110366505964, 0.194325985447053, 0.25528432170469917, 0.2440450917328558, 0.1661111050916295, 0.16859713701471207, 0.27208473713647935, 12.979572992171011, 94.03354537102484, 131.59286775896626, 121.54499484646706, 98.9076159077306, 111.84763277730634, 85.02227644766532, 54.132454241475756, 47.31357843645158, 56.8078205662389, 46.56162477308705, 68.87351759018438, 59.7076053004111, 56.31315085195727, 104.34438182461648, 68.57057725229572, 65.2329893266001, 57.93430174550703, 32.4126902703316, 3.833148753450763, 0.5175925971519563, 0.45343573655812974, 0.31856923634486817, 0.5357890852516698, 0.3479945815859303, 0.2944263737768896, 0.7229224856822722, 1.1166748861151359, 3.2024936522206957, 2.3204658589055462, 3.1337048401755676, 5.214211123604929, 6.578871367439148, 8.65003235878483, 9.932339499073645, 12.99839154366524, 9.831547333348183, 13.232707073611598, 14.370421921053241, 24.258814204123713, 14.356628906342292, 14.21252396798903, 20.54986999880883, 29.51042659821049, 24.95987511450245, 36.564664225424494, 41.92582645723897, 34.11933314415717, 24.948641446328935, 21.211671906132853, 28.669109575210083, 23.22681115519616, 18.553791507597893, 19.380515352372203, 23.948907736809026, 16.510979936968898, 14.538811233735855, 11.802802124331075, 7.961479396589342, 6.427816969733085, 3.2865037120157674, 2.324466676481309, 0.9916094390134659, 0.46777316399158975, 0.17313568702628537, 0.2921074562736096, 0.2314565664217357, 0.3627905586073476, 0.1656461356868667, 0.6002597354592816, 1.9978865812863074, 14.983810013340367, 64.70528541072723, 97.05300946389475, 109.3546841221471, 115.40562260535457, 146.03054754195676, 81.77609935883554, 94.21901072225263, 96.62816970579087, 30.971880151379494, 44.24927773014192, 87.89297288463962, 91.0117906139743, 90.81433065475957, 100.84163465807515, 118.45715599675333, 105.27556034826465, 54.21445138992802, 16.215890222980132, 0.7901708481292572, 0.21665406233120352, 0.18711145967245105, 0.1653217280944509, 0.16374954713448403, 0.18378371162520302, 0.1798404885395881, 0.1348791559857707, 0.08486499093593129, 0.14306161853094257, 0.14746432583178246, 0.12866383869080775, 0.18546976389423495, 0.24237986173360582, 0.14725075584025155, 0.14032061722490097, 0.1838099271539719, 0.17533848092200296, 0.14799026051355949, 0.13493247570530062, 0.14340329374517166, 0.10493712274417763, 0.12641901721156415, 0.08363144382113412, 0.11965629945118582, 0.1752176994998609, 0.259456574436157, 0.0918013655069855, 0.20376323872516233, 0.2153619324728366, 0.1723437359736812, 0.17922265395041437, 0.13507289962182123, 0.14693774763614903, 0.15027376943297927, 0.14655091919966284, 0.17384634082836492, 0.09161132207560925, 0.13074883890728797, 0.13134294009256747, 0.0815736320650866, 0.12192588089214218, 0.25671286117886344, 0.10582960751508513, 0.09277644221700969, 0.0920956505222186], [0.024783664473122167, 0.04492422708520486, 0.02226044855741484, 0.015584453865284882, 0.05664551022252249, 0.014552446288777696, 0.0786045663839867, 0.08988034641069752, 0.10029076883989958, 0.08513119116786026, 0.06085837327484643, 0.05853540316644696, 0.05327923178312279, 0.04750182566743705, 0.015112851096707729, 0.03628297363437953, 0.03436241802128573, 0.035222504933875416, 0.029113097379224438, 0.04186122753326932, 0.02588426085910009, 0.03997400057532134, 0.043185701623799345, 0.05302436199159392, 0.04328120980531939, 0.06136440116191103, 0.05030962601003628, 0.04338088550514752, 0.026394942730304696, 0.06423885498436228, 0.027488236383144415, 0.08017272538235111, 0.017294781545417446, 0.04389214577273496, 0.09344896782309779, 0.046045075005461136, 0.04065335968569402, 0.15441271266148937, 0.14080954985993524, 18.289284513842677, 85.80920588585639, 102.41558767134144, 95.93370622204196, 71.37293815612793, 74.04944589061122, 102.91493677323865, 119.49075545034101, 43.49402927583264, 14.39235189268666, 26.68956583546054, 104.21009555939706, 86.11717470230596, 61.76358230652348, 39.62489351149529, 37.117973373782256, 43.781331123844275, 26.03094889271644, 7.611661832178793, 0.20813024632873076, 0.25653397964854396, 0.14728754338237549, 0.061668492102574926, 0.09749653974487897, 0.027077630492708376, 0.23625878857508784, 0.5057590821337316, 0.15218004133672486, 0.5087112172717049, 1.2369155114696873, 0.8925647504868046, 2.9398267403725655, 4.10166833189226, 4.261004569069032, 4.298496054064843, 4.551370278481515, 5.355164927821006, 4.022982644457971, 4.808971449252098, 11.200296648087042, 14.075252779068487, 15.620007668772052, 5.57245982270087, 12.447323049268416, 13.098620849270976, 13.84292491020695, 13.668664789968922, 10.758496561358053, 16.03379124595273, 8.456135872871645, 6.382810713783388, 7.286236507277335, 11.033396855477365, 6.674903736960504, 8.766446344314083, 11.15231135199147, 7.862296383227072, 7.500891647031231, 7.042885307342776, 3.50728853575645, 6.312592442958586, 7.623913845708294, 6.688948273658753, 2.8025246627869147, 1.2079164481932119, 1.2440580249794069, 0.6146551404268511, 0.19985513310999642, 0.21960161626338962, 0.04377905587335268, 0.36390920019438194, 0.03546407543903878, 0.17995316475149126, 0.4392618535747452, 14.861829203944053, 54.96492631973759, 70.20395417367259, 91.71700923673569, 72.79511113320628, 111.36467133798908, 130.53693432961742, 44.7055866641383, 25.545528127301125, 25.912528614844046, 39.72310573823991, 51.191476775753884, 66.70320741591915, 83.75037731662874, 86.40073853154337, 92.12015828778668, 82.40600062954812, 25.18873560813166, 2.2682289586913202, 0.24785878467223338, 0.012522806458535695, 0.01758468262250385, 0.04742562673204849, 0.023765663856700547, 0.015223252985085693, 0.048183831611588124, 0.04020036423518773, 0.07536101906049637, 0.05435029164918008, 0.052588772058727286, 0.07470835811428486, 0.08432163541475612, 0.03858028745819484, 0.06580373512641077, 0.03430516444026463, 0.030542667241646882, 0.022260936938466567, 0.01914322338697891, 0.08133846605497022, 0.07389172370876036, 0.01103827553320556, 0.044290465528085354, 0.056470206322809385, 0.012885843076923443, 0.04247439281654455, 0.02344082342460752, 0.031055610987447926, 0.03537019519435783, 0.06688308406380877, 0.009548169403006474, 0.042505511308028814, 0.026415096588372707, 0.010694357596578137, 0.007524401636704082, 0.025824322139904387, 0.017874102979417772, 0.019789311298800093, 0.030645593069493774, 0.04617308063672916, 0.0450212559512546, 0.08606346654555491, 0.006276507610304943, 0.015554707628794977, 0.021161514582232605, 0.04963286010728729, 0.03943637156138017, 0.023155107102807493, 0.03403147569887581, 0.03949035394696459, 0.05788081933954551, 0.06770542582436916, 0.1475237742547066, 0.02983467942554384, 0.014555810372375194, 0.024506721773274967, 0.053959966021319555, 0.11581041549722995, 0.033764451922428225, 0.01598867249765223, 0.08758189111587503, 0.018700683121419242, 0.06612191442400217, 0.05221202150888501, 0.012470314113963998, 0.05175623749833434, 0.056514639422417655, 0.05074866333856218, 0.019377332195759784, 0.0984620633384874, 0.017787720820295717, 0.04716779218025265, 0.0462775367252048, 0.0811083562251541, 0.051632024002291506, 0.053240345160086314, 0.008299764012917876, 0.013847487392805278, 0.02823384103154944, 0.035871810414978576, 0.07190638387034978, 0.09180649063519894, 0.08385963077026029, 9.057175363263777, 72.09288920125654, 116.97142493340277, 105.83767521765925, 91.9661581900812, 81.27428700847011, 123.58858108520509, 102.25189931931035, 34.55340223927652, 24.32433347548208, 41.54503491617019, 61.08462002969558, 63.06942562903128, 49.956749946840354, 39.32891930303266, 47.83867397615987, 54.52678580437937, 36.62863808293497, 10.930038479066665, 0.3690965041037529, 0.06338153747961887, 0.006727893318560336, 0.09784152445894095, 0.29250082710096914, 0.30785433227016085, 0.6979032798159508, 1.9351330711956949, 1.5824174880981448, 0.8003094395802868, 1.4212781863827861, 1.3000448336524348, 2.025480455448551, 1.6135460306559841, 0.9168135783364697, 2.449405933580091, 2.1495802027563897, 1.5056636905477894, 0.6694235628651035, 0.6915226254251696, 0.5780351570537013, 7.800276356358682, 11.57859944528149, 14.471508264541628, 19.844057136966338, 29.5479009228368, 10.947348879229638, 12.14854532672513, 8.712732426581844, 9.647776446034833, 10.922134903169448, 7.53221030196836, 5.541896714318184, 1.8163412713235425, 3.4663017286408335, 1.8938840781488728, 5.057820831575702, 1.2170491968431782, 2.21223589874083, 2.1240122327881474, 1.1733307040506795, 1.8545125520998433, 3.1052975644988403, 4.691281222528027, 1.1253166030491553, 1.108924527802775, 1.4360001899542347, 0.8208995540776561, 0.5086708904033708, 0.4422738048578463, 0.5127537406740651, 0.677186852741626, 0.08750286914648549, 0.21145189631610148, 0.5018541481225721, 16.74243311728201, 49.63053426434917, 64.04966123642461, 78.54204239383822, 53.59113577873477, 100.46121181980257, 118.56998689713018, 37.53059887116955, 30.03648704098117, 49.00534768258372, 60.83673407954555, 61.6894220536755, 79.68771180798932, 91.6990134023851, 100.33211092795096, 103.58814885539394, 89.92148937717562, 24.491744156806703, 2.0921787667659024, 0.02934522010506161, 0.09928886373076709, 0.05307243400884252, 0.09611858505635493, 0.02681419583818605, 0.06230473961500872, 0.06565542816514931, 0.03694859295783024, 0.027628269594823642, 0.06856280844658613, 0.0627062233134864, 0.02020917344658125, 0.07354409599135961, 0.04749237597289105, 0.11088336697749554, 0.013071564814796852, 0.04288493550472683, 0.028697151855956164, 0.03649938581210952, 0.0352021882821235, 0.015809477828893692, 0.007983524832994708, 0.11318648008689766, 0.013351204144137522, 0.03938956358920663, 0.04361289906345549, 0.04544342019324822, 0.05150701760524704, 0.031162865212067004, 0.001663381931833893, 0.034128937404602766, 0.019155586130856987, 0.05416267671652379, 0.013852632630826726, 0.05011517757309541, 0.007407533008635285, 0.057471804996772166, 0.017029312927456155, 0.037146029137675805, 0.0466125201614153, 0.04096121211806613, 0.04936267238771243, 0.021659826048679894, 0.032149944604644855, 0.13467647976452304, 0.15488125203597933, 0.11924459613979825, 0.1545144797813508, 0.15896949556566056, 0.07875865730907648, 0.17756186726112522, 0.21702279577091818, 0.2579863904224288, 0.1939922162602025, 0.172174645047034, 0.1775548345739803, 0.12342857767737682, 0.13817379371293131, 0.09446548222894631, 0.18627176602040568, 0.1344661579857911, 0.09850858785812894, 0.1461010110834914, 0.20555533288467318, 0.08362840245207472, 0.10368142036661025, 0.1872436404829064, 0.12347691782539892, 0.08008847869331799, 0.14628527055103935, 0.15073199726400838, 0.2445164349891486, 0.1545127790661589, 0.15188053160184814, 0.16406716718789072, 0.20337674736736283, 0.08914173039938174, 0.1194906022940432, 0.2490911749942649, 0.2823299986700858, 0.1286842319513521, 0.20817236584280768, 0.14092719032158776, 36.31308340257214, 124.517272826164, 124.91817828147643, 115.77889104043285, 95.51212987592145, 92.93503853582567, 123.35953035662253, 135.6283433975712, 65.80461594366258, 28.510537955068774, 45.10766883050242, 145.70470840700213, 127.05255954496323, 88.63184544347948, 62.98365908284342, 55.67844860015377, 66.87896097860029, 44.82323423508675, 14.998756204881976, 1.1087559884594334, 0.21695629933909064, 0.3385307297350899, 0.3172849359050874, 0.2704304775163051, 0.29546466806242544, 0.438124917808079, 2.063161807675516, 1.4768495915397521, 2.431971733608554, 7.251578934731023, 7.306871116161347, 11.527565486969488, 15.883551720649967, 17.71745393353124, 17.158892731512747, 14.17554876496715, 13.5789748930162, 13.328393293965249, 18.45910745282327, 29.47688444968193, 34.37314187326739, 36.653717717816754, 22.0488606345269, 26.527873969847157, 27.39140533631848, 30.899843861979825, 32.1555200699837, 30.560605910516557, 36.89663010258829, 25.60660923680952, 26.416692426127774, 26.501192046749978, 36.796841083034394, 27.308307963032878, 23.49971398230522, 38.769075485967825, 24.394581164083174, 23.549875213253884, 24.76925184649806, 15.896361201040207, 23.241076815512873, 21.812565288236065, 23.10785939616542, 10.788897871971132, 8.233182468721944, 4.172162394369803, 1.3535075971195776, 0.3621591795836726, 0.28061089736800043, 0.6147770403373627, 0.6124972239617379, 0.15258933147115095, 0.2798262394724354, 1.2330411903319822, 25.847976207733158, 74.72997711550805, 105.4393114582185, 130.89132831942652, 102.71120102174821, 127.75918237624632, 141.93425947620022, 62.8262504454582, 38.395097101888354, 41.53681362828901, 58.81687818035003, 70.10079583814068, 90.30062567803168, 102.41226934617566, 105.73972578971618, 115.02820430263397, 111.80112131180303, 50.56570968320293, 7.97497921412991, 0.41317223901710204, 0.18247834376750455, 0.19322275754905519, 0.39494424938194217, 0.13515939094847249, 0.13371195974609545, 0.11378846431691801, 0.09677906776027334, 0.1292964587769201, 0.27418764848862925, 0.20142850916712515, 0.17934417081696374, 0.1510640504139085, 0.13184149479193072, 0.2586366764960751, 0.16637444015472166, 0.1720136440088672, 0.11211609437821374, 0.15325008230584283, 0.1964160418438335, 0.129222561935744, 0.037855307811931256, 0.165288633096122, 0.17732704599057475, 0.24352341649993775, 0.10440012575277399, 0.1516234784597351, 0.14240842132318404, 0.11482591590573711, 0.2167757630588547, 0.09765950962901117, 0.10195491865517632, 0.15693131864311236, 0.10001308494998563, 0.1615198329091072, 0.13359168394198342, 0.14498647572773118, 0.11141821126183195, 0.13322655111551285, 0.10818738865876391, 0.11527901094767357, 0.15717078240648394, 0.11730661585686669, 0.16142866844611783], [0.06204325848469331, 0.0350965945530803, 0.040424582848866145, 0.018367281656772382, 0.04196437361139444, 0.0659716539385338, 0.021316607167283376, 0.025898205574541807, 0.08276432422139952, 0.012981793674219762, 0.017064277180320313, 0.06470818342941423, 0.08916023908363235, 0.07434850363361259, 0.009936368179267213, 0.041894839640947125, 0.03981660015039867, 0.04463880187681606, 0.038423067063934384, 0.023013984131055976, 0.05613523054747813, 0.033303136757064256, 0.008860369918928033, 0.04912278344554286, 0.05867161742982365, 0.047774763642660076, 0.040332774872020374, 0.0509375729598105, 0.022631281078042045, 0.03814591177468819, 0.04848067536048832, 0.017155037531929634, 0.06133643129179555, 0.04556694037971958, 0.10491727340605952, 0.10514189804633779, 0.15130622612853206, 0.8093551606420548, 25.97357834539106, 95.70522031476422, 103.21681807118078, 86.59957132031842, 87.35239967223137, 57.58444986035747, 38.40883716460198, 22.47128813497482, 104.90892071877758, 88.16393021614321, 80.34247306085403, 70.8806493205409, 60.71809414894351, 44.3341774325217, 57.013321384306884, 54.05798019901399, 27.873823527366888, 7.2661490690323625, 0.7285925782015248, 0.41267857195869573, 0.029975340829320976, 0.25548600201164523, 0.0927999074901304, 0.034335704535366066, 0.0831852971966709, 0.14865911655849026, 1.0267438859708848, 1.5171827111513385, 2.482088347596507, 13.0979726776, 32.96148084825085, 62.45455095844885, 60.905418703632975, 70.69916125266784, 72.28757996712962, 47.25797099451865, 20.033358566222653, 7.457226841680466, 4.99099099828351, 3.988598902379313, 5.200536760591692, 6.527086275239145, 5.3435699112953685, 14.25527976405236, 23.092307198432184, 3.6538569677260617, 6.434940974558554, 13.729350720682453, 10.560632598015571, 10.821559448396007, 7.194491778650592, 6.583867976742407, 8.780117765549692, 6.531226336956025, 2.4198150827038676, 0.43001229183808454, 6.623637868512062, 13.742887800739659, 32.35118946721477, 35.53631290312737, 43.867670336077296, 33.08296057485765, 42.24457002455189, 24.848315062061435, 13.59977129966982, 5.446673333644868, 9.591273723110076, 2.2190350822864042, 0.7002499603456067, 0.7712881903975242, 0.008952966008725907, 0.26529882223375384, 0.288162287324667, 0.03795911272567126, 0.00938106551691289, 0.13582614791249076, 0.5424878193486122, 19.15887398104514, 43.50245452696278, 66.69856332963514, 43.53365305931338, 49.77355957031251, 83.38336113960513, 52.65843145308956, 21.091743476929206, 13.162520181748176, 27.47280432331947, 41.41407089848673, 63.42005022110478, 81.25534980527817, 73.36616116185343, 80.1627500595585, 78.43850751076975, 58.74250219714258, 15.610078188680834, 1.118023813732209, 0.14211923845352667, 0.12144012752199367, 0.04880333627243677, 0.04429489734672731, 0.010062746831306047, 0.06479672021082332, 0.0875506040850474, 0.06000208615836117, 0.01972669701752884, 0.0033346947889038997, 0.051441754574977586, 0.09963109052830166, 0.011072347293637935, 0.06785829866965933, 0.04539056395691249, 0.08610180924616515, 0.027165274781685685, 0.002883239893332845, 0.06326413450522289, 0.05589390136001091, 0.04525164923360271, 0.046633480327023615, 0.053656396020444176, 0.09041582654801109, 0.004610238125502703, 0.061932129770397186, 0.009244503641140558, 0.03574378180107282, 0.02566984242519304, 0.022395783734898415, 0.022222969620939226, 0.014506511656837839, 0.031003497856398745, 0.07129247165134839, 0.02694618129622071, 0.03396366542625812, 0.011398847263696934, 0.024096236541687, 0.025880367217224934, 0.030832719621098334, 0.09119363561753305, 0.054893773574862754, 0.02775303275895215, 0.04407002372787364, 0.0462405423393413, 0.04003221559668741, 0.04689296579829628, 0.042226444629411546, 0.0377608530013071, 0.012487620997783399, 0.05678826304633291, 0.018060752641289465, 0.004315629916926546, 0.053899062031339255, 0.02285018878718538, 0.024442785990334327, 0.030511347652082483, 0.05045218731186563, 0.058517250713081136, 0.04466878272773278, 0.03466449415070876, 0.013728352102090516, 0.048102848457112435, 0.04923847421342808, 0.05513108846160674, 0.06811670778739838, 0.04285410812665378, 0.10384884122158251, 0.025604489379592484, 0.02211082775536324, 0.02366586366758472, 0.08164326179652445, 0.09350084729733006, 0.033597984846921704, 0.0418411790122909, 0.031226948466933066, 0.23018581041645622, 0.12589693595204623, 0.2119434489718368, 0.3209530874606102, 15.312733111842988, 97.9977515435988, 117.28739538500386, 103.21746133988904, 97.70228724325858, 79.61380650920253, 68.18187821295955, 54.31226745728524, 105.4873683375697, 69.2070367259364, 28.047888509688843, 40.093655970788774, 57.51029352987967, 41.85447854380454, 50.8465592322811, 58.337470408408876, 35.41844960181944, 10.227551787130295, 0.7551735002667673, 0.16132133952792616, 0.1993913588023955, 0.12112702738734023, 0.5324289010417077, 0.34717627710873084, 1.6705775381095949, 1.0285201067886045, 0.9149367242090164, 0.9116433428660516, 3.1401470880354605, 17.97511443015068, 40.16440768395701, 63.641699437172186, 70.31906789348972, 81.27538527211836, 85.60492884728217, 57.05553000973117, 27.740859100895545, 11.947182609188943, 9.2829381650494, 6.044704366114832, 3.566608746205607, 3.0857913724837767, 3.3020806697107132, 1.922725878896252, 16.06787468156507, 7.284603820693109, 5.923027050110602, 5.042032801335858, 2.3440280268269205, 1.8315294240751576, 2.7552917263200207, 2.520795277049465, 0.4157415446975539, 1.304706202880029, 0.4938426764020997, 1.877803586183056, 13.754801019545525, 22.132624810741795, 42.76171491992089, 50.17360602655719, 55.60459036980906, 46.01101813777801, 49.30189847946168, 34.05831675375662, 18.194094473315825, 6.381315800451464, 1.7054264487758761, 1.734443162718127, 1.2310201891006962, 0.17627215824059903, 0.5124445782313424, 0.8469394954942888, 0.5671068208832895, 0.07067651397758914, 0.04056622101474674, 0.23836828828338655, 1.4246994737655887, 22.98084128287531, 48.689024217667125, 65.13708345351681, 48.88712352321994, 49.192189785741995, 51.58916980989518, 40.11717057997181, 32.72840576787149, 28.950927949720814, 42.91191424092939, 64.50391877082087, 77.30520925214215, 87.54873783357682, 83.49437206022202, 91.36434893454276, 89.48077970935454, 56.2434660234759, 13.712862057070579, 0.9863402249832308, 0.08735620927426123, 0.07749649681030743, 0.014424852429768972, 0.0386803615237436, 0.023906053299264565, 0.047093496973355936, 0.03368752137307198, 0.12810356794826447, 0.02301278711867429, 0.054990534310139, 0.056830401712607954, 0.017588606907895977, 0.05997130474556358, 0.04659018486798291, 0.02083543308770224, 0.05593950657414333, 0.0287916736992737, 0.04261042704925903, 0.09160821941951591, 0.0071573914160140825, 0.05320299837377764, 0.06191079039126635, 0.03299082569297283, 0.02212300663813949, 0.05975073654084437, 0.015493700216944902, 0.015878908377471232, 0.06653179444612996, 0.02027824967949381, 0.026158016633182287, 0.015258691254853001, 0.061420429002253286, 0.016613082036436085, 0.09242998661413308, 0.03521320079603503, 0.039721900191638744, 0.0280228604172026, 0.038651483839437846, 0.0433316643560125, 0.09062425608957007, 0.04348202060247141, 0.05590263476234771, 0.16383387809318883, 0.12989265904311212, 0.14350345208039209, 0.19875374382301686, 0.2552066557109356, 0.19228042343691473, 0.1612340821133506, 0.08881117112093395, 0.1578943830944838, 0.08285180380147311, 0.12669754379819478, 0.1681381277740002, 0.13218281760571465, 0.11415172022797408, 0.1245449516441553, 0.1805531954573047, 0.14438163398975326, 0.13266339988237427, 0.1226316087488686, 0.10536302166480212, 0.1056986294626709, 0.24953587371255123, 0.1748150283651006, 0.12628704324484835, 0.17721476814439222, 0.17165897594344232, 0.12595201001292275, 0.11699095698854617, 0.1764198599924003, 0.23531240951870722, 0.15171304945984196, 0.12470512530736386, 0.1337643908036332, 0.0859662653097222, 0.4859233803806767, 0.3023226565170673, 0.8224672151188698, 3.0457074459522, 53.56287117927305, 134.21756098347328, 118.91936025311871, 110.59260768275108, 107.1613339454897, 75.80444766629127, 55.83799100691273, 34.307336268886445, 118.1552040961481, 108.4435724443005, 108.8271253339706, 104.17502172531621, 85.52936046354233, 67.34966893349925, 82.35564524127592, 84.42349526189989, 46.83164073574928, 14.212397471550974, 1.345103306155051, 0.9313392182511668, 0.33292026949986336, 0.3794590383768082, 0.5131522596122757, 0.20780612984972618, 1.3218534569586478, 1.3602133792254234, 2.988313854702058, 4.590824419452298, 8.999365510479096, 23.194343736094815, 42.28423695410452, 73.25322043511176, 69.66789953170284, 79.64396953582764, 84.79105272600728, 54.19540043800108, 27.784469973656442, 12.660025338972769, 12.281914737916763, 12.521599012036479, 16.091516767778707, 23.794889988437777, 25.712134722740423, 40.88699063947124, 45.60484886169434, 9.820111663110795, 25.702807326470655, 42.84865033242011, 34.75207028850433, 31.10476613044739, 26.174670419385357, 26.825938801611624, 23.48755659595613, 18.37735349132169, 10.225618058635343, 3.4430582532959604, 17.38062627853886, 21.708493040454005, 39.57143945078696, 44.78697192284369, 50.16611037715789, 38.292315313892985, 51.18922925764515, 38.9208084537137, 26.17379180846676, 19.991336253381547, 20.98805169905386, 9.459382064880865, 3.166454915077456, 1.9738314204639005, 0.17073895031165692, 0.3718961877447944, 0.8740431346720265, 0.13583794566652468, 0.10202587371872318, 0.27108986471449176, 2.260630347075001, 33.78887345713954, 65.64110802065942, 102.85501864648636, 60.66801724895355, 75.26035216546829, 119.05296402592813, 73.69752299401068, 31.60701582508703, 21.649914403115552, 44.207728062906575, 59.72871157430834, 81.22122518477902, 102.24774945166804, 93.75774783472862, 98.60033742843136, 104.66527092841365, 92.1346789021646, 37.81071885939568, 2.00549021843941, 0.2956262513274147, 0.2584758286754931, 0.15092856010362027, 0.13939441692444587, 0.05839965621670408, 0.1440696523434693, 0.16737030849101084, 0.1929222518998769, 0.2421492692683974, 0.10699100446917358, 0.1846449783131961, 0.1639766615605162, 0.22244202513848582, 0.10341633862305073, 0.13105066222769599, 0.21635674360779025, 0.1209488889623073, 0.08635023623825082, 0.19057264491435022, 0.11504086485553174, 0.1804316019819629, 0.1562630601467625, 0.12432048788234112, 0.14178969807201816, 0.09786289831202838, 0.12744074101529776, 0.16191749382884274, 0.17248313333238327, 0.1606843527406454, 0.15113100649849062, 0.1257456259261216, 0.1464473747558171, 0.10289050353270385, 0.17799642297529406, 0.12827927787457744, 0.09673240534480541, 0.16072441913908528, 0.24967317199034078, 0.10518525862285208, 0.22461402229964736, 0.2031126308945879, 0.175106325637429], [0.045738544074758414, 0.07115803854239565, 0.008526268441440358, 0.02541604132631854, 0.0157458369898039, 0.035930787693829305, 0.02376538231938837, 0.046414199150017196, 0.01907322976377703, 0.019732936803672104, 0.07390703780636673, 0.04284845822821221, 0.03056819712172353, 0.03455714224987934, 0.07125815091234061, 0.03551878560815127, 0.0290169820730244, 0.042877964104615876, 0.03819083134012838, 0.05470667192111573, 0.04742738490383472, 0.04302653919665083, 0.060937356939839746, 0.06498781318265585, 0.1044042090014104, 0.030691619631984544, 0.019216028552862908, 0.06325692178741579, 0.025121786954602408, 0.053703993063179724, 0.06191316526383162, 0.09145088028162719, 0.04262758358832329, 0.01692990918884114, 0.02194211029657914, 0.07657300846110429, 1.434446686217862, 65.67975905633742, 114.64659690856935, 96.89589500427248, 86.8795971716604, 84.75335090391098, 53.10438140746086, 22.873131036758426, 26.216943763917495, 36.159773642017, 71.6635936306369, 85.57897060148179, 78.11197019392445, 86.0085250485328, 41.409799437369074, 49.550925839331846, 32.82831834208581, 9.186411576886332, 1.235110976042286, 0.09642259172734716, 0.05364961614231429, 0.13701015212122472, 0.0712551938129529, 0.2807225929873605, 0.03842707370377837, 0.09547236690958662, 0.6964054859934316, 2.1497010607873244, 6.126731422639662, 28.274183773225356, 88.97397810412993, 118.10803367245583, 130.30527914724044, 125.67310902380176, 132.18669891357422, 127.30986702826716, 129.1058575722479, 139.12337918435375, 141.36573545394407, 126.75318856393139, 123.57511166603335, 106.6674526276127, 88.50221110928445, 50.126702324036636, 13.809680861811485, 12.49035733361398, 16.541456753207793, 23.76856892339645, 5.599777660062236, 3.708918955056898, 7.0003565184531675, 8.804759075564723, 9.051702676280852, 3.242319682913442, 2.1101049790459294, 2.3311670653281675, 27.209244581960863, 76.34658982676845, 112.80473816779353, 130.7847261428833, 148.30218038251326, 147.7255605882214, 142.9102550014373, 153.66493901898787, 142.99640593990205, 136.49940767595845, 116.67425832440777, 77.6873657780309, 30.225041258719664, 7.305782168142258, 4.413517107886653, 4.564791648618637, 3.145619284722113, 20.824669291896207, 7.931475716252481, 0.4245492882065235, 0.2361727875447081, 0.16783578351380365, 0.16998266831280726, 0.3814823072283499, 4.176520637927517, 25.800670462269938, 47.49282290858608, 60.548749739123934, 75.91422696267405, 65.19543263220018, 57.339591979980476, 41.91822882621519, 19.873620040955085, 14.598566582126004, 27.720037198835804, 52.36401050321518, 69.62801687179073, 66.47719260184996, 78.93413820574361, 91.04499739985313, 91.58571966232793, 49.49409461790516, 5.421627529205815, 0.5603718661492871, 0.05263980883624285, 0.05582346340581294, 0.10603247525831384, 0.023295232245037635, 0.016428192461570425, 0.03617908828140747, 0.010294186781280705, 0.0841877232455919, 0.018948868795808767, 0.046978610597791216, 0.07319394018380873, 0.03482120509649958, 0.028730047671424768, 0.0244427093815419, 0.04189683913042949, 0.026496428312853943, 0.036193057894706726, 0.028904009002050566, 0.04411459089286866, 0.0738962589492721, 0.05131303265150036, 0.00605789915425703, 0.08890418185582084, 0.03355631349428046, 0.06056042635933526, 0.007095900411161805, 0.03341695060953498, 0.03447278830853682, 0.050820679433884165, 0.020812182319200328, 0.06441441935396965, 0.052619752654385184, 0.03135908139689315, 0.041073459320731705, 0.029922783367275715, 0.06794547947544245, 0.05560298330120503, 0.03228209477158324, 0.101999175554562, 0.0335375634923337, 0.0396146517126791, 0.04161381560768332, 0.00809998647685373, 0.0715603419549523, 0.032901404080011194, 0.038894981055730776, 0.10430422686641255, 0.060777275207182097, 0.031580229913215005, 0.031582124065607786, 0.045485685264030774, 0.0399169729902379, 0.05209562977054908, 0.01691529989212511, 0.02513094170529756, 0.040706817301050316, 0.05211252200927946, 0.014019391777354383, 0.026539582045628663, 0.09825580948663336, 0.04949789073678756, 0.044811137185822573, 0.04739643112125416, 0.0370342415877648, 0.0864721667922793, 0.03293957058039885, 0.090136687091041, 0.04969010602742915, 0.040030683420838854, 0.07424813845465261, 0.0926817843930856, 0.08293084875350037, 0.06628493793428906, 0.05909938177454376, 0.04313348890132001, 0.02640128402309793, 0.8890929625880335, 53.09978438961891, 118.80783942437942, 109.85595518542875, 100.597592630694, 91.8357942950341, 80.23559631839876, 44.34401473691387, 41.89736573926864, 22.02868592354559, 69.0074194631269, 84.45098323206749, 61.211394956035, 64.7483765694403, 42.434757909467145, 54.669775809011156, 42.64783282433787, 13.500506897126476, 1.3827529116984338, 0.25567737077513053, 0.15979944457930906, 0.14434012734601576, 0.3046138109939714, 0.5075109719989762, 0.64734723779463, 1.6372068707020053, 1.4255589631295975, 0.060618499654435345, 8.040610273038189, 34.87557003574987, 94.3153755126461, 124.55308406583725, 131.9790800156132, 135.08137672178208, 140.42033441605108, 135.28154311641572, 134.34955658451204, 147.8783133722121, 147.69292646838772, 136.67307453770792, 136.4984663071171, 118.06346770255797, 101.48891987339144, 60.543721260563025, 19.05168737134626, 2.180484312195932, 1.9705971811086902, 2.764474975485956, 1.205692096583305, 1.6242118131729866, 4.642866426898587, 4.635159459806258, 4.1189868219437145, 2.095817255396997, 0.9985069269614836, 3.97735886035427, 35.76253168044552, 91.50563270814958, 130.23617482954458, 148.21408394844303, 153.70144844055176, 157.40716257402974, 151.7139207163165, 162.52204310509467, 152.5249727310673, 150.6242549034857, 128.04142044436549, 90.03536362801829, 41.27770185470581, 12.472811591240669, 2.9777989608626214, 1.642286952945494, 4.2406562932076, 16.00840762738259, 10.856818614467498, 0.607616508439664, 0.4369510566034625, 0.04617578492710187, 0.13503268000579652, 0.3763633996488587, 5.898576465345198, 30.757705011675437, 56.95297964157597, 63.37050676345826, 58.462539103723344, 46.19063915744905, 29.990661990258005, 24.59430825325751, 38.4674334526062, 32.23959803581238, 53.04617735647386, 77.75611708241125, 87.94705452457552, 80.03311572536346, 88.22242060015279, 103.18364266426333, 101.1397740148729, 48.55153337601693, 4.2762998515559785, 0.30655440363672476, 0.0934087022417976, 0.05701961776902599, 0.05870767718841953, 0.01565046957693994, 0.08780296110818464, 0.056768386895137454, 0.0869426520300969, 0.07056071212695492, 0.0193536390114816, 0.044634764593455105, 0.012532964784411654, 0.05221233560493396, 0.018927920121519316, 0.10871007512774199, 0.04689569307130672, 0.04339502748822974, 0.03664066008622608, 0.04184323212792797, 0.04419487307689363, 0.022697819644705425, 0.05086198689476137, 0.0282799729311298, 0.06115979056865458, 0.022779856170077, 0.06622062485304571, 0.03160767884354197, 0.08220391558302988, 0.046069704732226754, 0.08165776384093108, 0.022089785235303066, 0.06656122754418081, 0.0458472864251704, 0.07007270645830901, 0.013703731951423952, 0.02306304631694671, 0.08615971783236151, 0.048663904439778104, 0.05267150572410995, 0.04264161831909611, 0.05812838831315598, 0.1398178183984372, 0.15221620068675087, 0.12112101359713463, 0.20471827457508734, 0.16219141622704847, 0.14004787460209864, 0.16126483288263121, 0.13593796610591874, 0.11500714166510491, 0.10027447414975013, 0.14174598509505873, 0.059964383141167706, 0.10236277620518401, 0.10441975292539406, 0.1606302975767082, 0.10168714028212333, 0.10124561316784352, 0.08893464151169024, 0.17114799529794725, 0.15228277372737087, 0.08865871962400214, 0.1121837016375315, 0.1507716959402446, 0.11837986673438743, 0.18457549413846386, 0.1340791456882031, 0.11090200589669329, 0.1766949621660094, 0.13618893650991304, 0.1651450988626288, 0.15798252917105154, 0.17560512548492802, 0.23557382936198867, 0.1842164593718706, 0.2047876514975102, 0.3890481609250269, 8.900375673847815, 104.64189360218664, 149.0219823775753, 112.71237419497584, 110.25400515525573, 104.09879438338741, 71.1370389692245, 36.432174405744, 37.53996156877087, 57.21111866735644, 87.89332589795514, 92.92276151718633, 109.51568957298034, 127.08524857797931, 67.10234780465403, 81.99459891165458, 54.97259847579464, 18.286972276626095, 2.3035185231316477, 0.7181937007173416, 0.15352847865752636, 0.5950109912983833, 0.2648613860289897, 0.49762289129918624, 0.5220009122164019, 1.6455482811697069, 5.343668951142219, 9.865517020225525, 16.63349909167136, 36.91642630484797, 102.42824908225768, 125.05060534323417, 137.12400590219806, 139.41404250360304, 149.03365535120813, 143.2213617140247, 143.33173721067368, 153.13108874905495, 148.9887991259175, 140.5413316911267, 138.2441249970467, 119.65028608998945, 99.26275514787244, 56.79748904320502, 22.4731041923646, 30.20241310519557, 44.02325507133238, 53.61024556621429, 24.844628034099458, 22.083248053827596, 15.325819119330376, 18.38631218479526, 19.242948024503647, 11.722297437729376, 6.877285780445223, 3.2037600874900822, 35.34709384364467, 91.77032209211781, 136.51098651270715, 153.1130772252237, 165.40525190291868, 171.47394303352604, 160.9489373237856, 175.64348528462074, 158.7935321561752, 148.55321207354146, 130.7827178893551, 85.21215054296678, 38.03954209050825, 11.39021683123804, 11.829599757348339, 10.198795910804503, 9.564405487429712, 30.79733075634126, 12.215372708535964, 0.5609297007322311, 0.776801449396918, 0.29509449437741314, 0.4176463763560019, 0.7280937630322672, 9.307592222767493, 40.953557183665616, 78.89679724170317, 95.13787300355973, 111.96311519991968, 93.12732096641295, 83.95959654162007, 57.90718640050581, 32.594953006313695, 23.801157935973137, 44.160589018175685, 70.10285900485131, 92.10946590669694, 85.97607135772706, 98.53435531739267, 109.10700213524603, 117.2274301898095, 80.1763528393161, 13.687988346622838, 0.7256253664532016, 0.2254694667194159, 0.189211659073349, 0.20239655319000446, 0.141428426328686, 0.2171980460444766, 0.1655908854257676, 0.2168396547917397, 0.23981932009900772, 0.12859354246287577, 0.11241464650318508, 0.18248108636227348, 0.18848441180682954, 0.13031443641070398, 0.13707194477319717, 0.1789500339016799, 0.12467715543724837, 0.18356534592326612, 0.13769788457260979, 0.10020022490812887, 0.1122312373932331, 0.23001958465864583, 0.136179406376135, 0.254055256204259, 0.18530621944415956, 0.1576696435410169, 0.10102318719990792, 0.16390304051099286, 0.08020801139214347, 0.17059475724254886, 0.10003542407385765, 0.23377350741817107, 0.09284414906775759, 0.12810424976651708, 0.13371719978749752, 0.2445237741114632, 0.2491456898109567, 0.07781001063243997, 0.1714367031930916, 0.18811596948052609, 0.12440369269179723], [0.008352196028065539, 0.0414102315722454, 0.0833669366435178, 0.04779791098929221, 0.06946448627258502, 0.0547211624742035, 0.05455692471455663, 0.02444396385051791, 0.02950796016281651, 0.0617555579951694, 0.013733010874280046, 0.035441954650225184, 0.052538413269024704, 0.036589010438371095, 0.03698140067318755, 0.021203312339381348, 0.0027855761319158542, 0.07367189477888808, 0.024504670572857705, 0.04068517531718939, 0.03381849559504659, 0.048531984099217, 0.0589538480515682, 0.007055119635732545, 0.035639988378651684, 0.016465426249910268, 0.02264283176872038, 0.021880359779442513, 0.035865624254990014, 0.017495730238395835, 0.04841435512888336, 0.027941997921574983, 0.05506734611586698, 0.07301665211637175, 0.15047423932100498, 10.54805257628041, 83.81933258425805, 103.05645588905581, 99.66611600691273, 86.33833362210183, 74.82365900470366, 48.893497374749955, 25.604028317236132, 38.88935104493172, 70.40212015951835, 64.8742768072313, 46.77428783908967, 41.13622980733072, 49.13888085273005, 42.19729761923514, 35.94770677628056, 13.272534820341296, 1.6471348799044088, 0.19653126146764527, 0.17848515642746804, 0.053635251993734034, 0.14130298709196432, 0.11065208503315527, 0.0036418733033051175, 0.34646779899635627, 0.623935345680483, 2.602808605278692, 9.149523646600786, 36.50586005180113, 99.53349282664638, 124.81683208096413, 123.27110444345783, 111.33231178406747, 111.25191888501568, 111.9489005304152, 108.07374000549318, 95.80085554430562, 100.61159549220916, 103.65399760584678, 112.56923906264768, 106.98529012741582, 110.0186158764747, 119.57449805351996, 134.66665667872277, 145.27633851574313, 137.49248904566613, 39.68663161800754, 5.955758738902308, 2.1454526435944343, 2.866349470230841, 8.120086318062198, 37.847824481225786, 55.49037095039122, 36.44224312997634, 24.78105033597639, 31.015508674806167, 81.36610969420403, 115.4182291030884, 121.32958612134381, 123.72974718770675, 117.33123179404967, 114.66136070989795, 108.52121968423168, 110.31693566230037, 112.01840492986865, 116.69231691668111, 123.4050141611407, 119.00344802487282, 125.99679869990196, 130.55897804998583, 110.58573569020918, 76.57948447811988, 26.959079734740723, 9.955957070473703, 16.10289752483368, 0.7049086942307411, 0.9756964445114137, 0.25750001652106164, 0.1369946158581203, 0.12639112395024107, 0.10477334080684571, 0.05673930236709215, 0.5298565003660418, 11.775432805861197, 35.3019905090332, 50.65617130648706, 68.0574135626516, 81.28792116718908, 80.05670485957977, 39.41091252911476, 38.407060330913914, 14.297050064609898, 12.923194804499227, 11.942628737418882, 37.15410232543945, 79.85446745349516, 63.82928286829303, 75.75206049026983, 89.65907496790733, 74.00474656012751, 14.087590594445507, 0.47218509499103795, 0.21904143745139723, 0.05089584032013532, 0.042752946216252544, 0.05598695422973364, 0.0943643969273375, 0.03941929546154795, 0.04449777275083527, 0.06242796868806886, 0.01725696361503534, 0.046683080689681154, 0.038183392626383615, 0.04782476237103824, 0.05548068885541251, 0.061974697445909825, 0.01713886541584807, 0.08628666626229402, 0.07452039844206265, 0.058605346993933764, 0.01819708564829442, 0.0823853635078957, 0.05334636406792749, 0.023451904886432236, 0.012551168948712369, 0.026522103749636202, 0.029144631473407633, 0.036122447570725795, 0.05958656772911068, 0.03797509715021138, 0.02707946335806722, 0.05392586361737021, 0.03087889940117396, 0.02245482038556328, 0.03776513926324345, 0.05015273120314364, 0.07766490591870201, 0.021240274166508068, 0.03222584093530332, 0.085235019064238, 0.04486187135860805, 0.02181679937958477, 0.049467829446638786, 0.025829924157850688, 0.04476573115455047, 0.08817053775513366, 0.035586760589672674, 0.09622697117588214, 0.019465991551236763, 0.0542961751982089, 0.02270644387951301, 0.00626267972327168, 0.03141883817020684, 0.01586702826898545, 0.039616854215461406, 0.06322750784156304, 0.04086949224133165, 0.06273523123273927, 0.07408249492366469, 0.00795610846140452, 0.03188609626264342, 0.03506102892119558, 0.04134474254603829, 0.043630997890666615, 0.017012543262793653, 0.0354309153232363, 0.015856544355741672, 0.07280136608789045, 0.06821565570369845, 0.017622441181071827, 0.045182793250968384, 0.04597865901286564, 0.1158853235744661, 0.04247170384793032, 0.059430098101016016, 0.05567021134700026, 6.446710046260588, 80.03230771710797, 119.44308296326669, 113.62439586270241, 101.25631547743275, 95.46749330336048, 85.27016239781534, 41.60633763959331, 21.282825662243752, 29.127199265264696, 41.00850174503942, 56.88391454758183, 58.70060736133207, 50.63721056907408, 50.23484206968739, 45.452558917383996, 20.062960693913123, 1.8477342061458097, 0.27104402201310285, 0.16188252957597857, 0.03083663816083103, 0.37717882363546285, 0.5443207919597626, 0.9315965625066912, 1.2959014624357224, 1.4222313223346588, 1.162007924529814, 13.004291768996948, 48.00703779343636, 109.35355447953748, 134.4515068300309, 125.28622211948519, 117.23690663614582, 115.91792337356077, 117.00921304764287, 113.43431780415197, 102.72642766275715, 106.34757549531999, 111.53584357230895, 114.85153290533252, 116.46824759821739, 115.27962038593908, 125.62711531116118, 139.9447548773981, 152.17991398226832, 149.83827467887633, 56.38596180946597, 6.53230449845714, 1.0633321226604524, 3.10978181419834, 10.503589568599578, 44.738134491828184, 63.51703474598547, 46.008978505288404, 34.120976617259366, 40.244996701517415, 95.55340105487456, 129.41796841159945, 125.29005819751372, 124.47725680566604, 121.41852978737124, 120.06024437565958, 114.37898928119291, 115.30596302401636, 114.84356264914237, 120.84997438615369, 125.73883225840908, 124.7156741542201, 134.56418868034118, 144.39556244880924, 126.6806717841856, 88.91139276566045, 36.85047165040047, 13.360647924484747, 8.836288067602343, 0.44354345769651476, 0.2656911818250533, 0.21260867376000653, 0.15666928592949145, 0.0982917543320406, 0.019472457333317688, 0.15490461771766986, 0.3416269813333789, 13.578999407829778, 42.00863945868708, 51.12974651398198, 55.0923131358239, 57.12278296870571, 56.77138959207843, 31.001717621280303, 28.696617157228534, 18.996809490265388, 18.40181339171625, 28.451690635373517, 51.99895551127773, 90.1425620048277, 75.87060236161756, 87.79176004471319, 101.95626243468254, 79.44328538833126, 14.759936813385258, 0.39806823336309005, 0.04973753836126097, 0.05268630271236743, 0.030780775029392495, 0.057045936719664646, 0.009850065501767301, 0.04579786609317507, 0.07354194328429238, 0.041041582402202396, 0.013880885953474191, 0.01541968750497026, 0.08612979443803911, 0.07364912664577847, 0.023797728466771306, 0.042217994679606734, 0.023204111832103903, 0.07436202508547614, 0.08268417610276131, 0.024763692560936176, 0.03241789534748082, 0.05090700988207133, 0.049339747206578334, 0.02013274851525503, 0.08751195494926746, 0.02642472056792148, 0.07728191558271646, 0.057723422745062467, 0.018915024946533868, 0.04705127786784884, 0.006121543344981488, 0.02885745192367223, 0.04745106851201385, 0.05482274956340271, 0.05043165998593454, 0.006674113467470893, 0.050516757032563614, 0.017487427760516445, 0.008335420617743606, 0.018787739437914664, 0.020359541184359023, 0.11096163051984004, 0.15211020476154744, 0.13192642329921647, 0.166402310433407, 0.20378036845114925, 0.14881236478686333, 0.25514284058684306, 0.1253848521399402, 0.14281889123301353, 0.17246503833561175, 0.11214754228750545, 0.1627444857431035, 0.18666237893123783, 0.1362096208838686, 0.1715087767450079, 0.2257428834995916, 0.148532175789437, 0.20420876481840688, 0.15887204918169207, 0.1465456331929853, 0.08737248098177296, 0.11850883763644005, 0.12659727054978573, 0.10659163517336692, 0.13616803763133867, 0.24342247675503456, 0.2360650755825543, 0.13817675081231903, 0.13037253651888142, 0.18166961538935864, 0.20009868778288367, 0.20179063892893254, 0.3310546308996216, 0.2146590927675847, 0.17939500841161898, 29.79582609668855, 126.72071133890461, 129.7114872163342, 118.05325385062926, 115.18915484028479, 94.33651708787488, 67.85555270410353, 39.62529359325286, 58.86779446755686, 105.38769306675081, 90.77583651388846, 68.13819085398029, 66.99762836579355, 71.21219942646643, 64.40896211131927, 55.866808660568736, 23.864482641220096, 2.5405184251646844, 0.6645206614367424, 0.35220573626218304, 0.24918261524890703, 0.4730691604556576, 0.4273243651034371, 0.608475691368503, 1.446724808023822, 6.165919332735001, 10.794297014513324, 22.472674692830733, 44.880343944795676, 112.01907957753828, 137.24457956129507, 132.0894398227815, 124.97544488599225, 123.13583758569534, 123.76791184948338, 119.39274326447519, 107.30006817848452, 112.36837448612337, 116.06500441028227, 118.67987601987778, 122.03891538804578, 121.51772652902912, 130.68577258817612, 147.25161275556013, 161.10294526623142, 154.7840069186303, 51.68030608084894, 19.09311740629135, 11.734597009997215, 6.766416065154537, 11.908324668484351, 51.54794177701397, 72.5163169060984, 53.83879815378497, 37.07564315488262, 44.451923062724454, 103.04621850290607, 139.6745192620062, 134.13949012756348, 134.62269475383144, 125.62637790556877, 124.52979303175404, 117.69453740889027, 119.60151533926688, 119.11879708690029, 126.01459841574393, 135.0607607441564, 129.79911296598374, 142.18268671343404, 152.20282062407463, 129.04654349050216, 87.4773899201424, 32.47480884675057, 14.958701941274828, 28.445393270061864, 2.391513220725521, 2.045797107200469, 0.19021937112894752, 0.417515283390399, 0.3049899908083101, 0.1870276036882593, 0.2413363427284264, 1.5294039585898, 17.941456571702037, 55.02720179096345, 78.23055913371425, 101.06704542713781, 121.82378907357494, 115.76850460421656, 57.11147477549892, 57.269067764282234, 24.64036080145067, 24.93094567329653, 23.838887214660648, 52.33747566899946, 104.882138775241, 85.38699411576795, 96.23268496605658, 107.6399572433964, 106.83748737458261, 33.85436134953653, 1.0946660993560668, 0.3463936110417689, 0.10766257246535633, 0.22766155070595204, 0.2066930653827806, 0.16384463396764573, 0.25234257471897914, 0.1491683352017595, 0.21786334744143873, 0.13092913003938814, 0.1022933686392442, 0.15861934741898892, 0.1830316431099369, 0.11304997087967013, 0.1036982513183067, 0.1053814001141056, 0.246769989870729, 0.274637280813148, 0.19102604639145637, 0.15107837625809256, 0.24995516895526843, 0.15216513326571834, 0.0849121896129462, 0.16187402600001904, 0.14302300769955884, 0.13205460513070708, 0.1808561985531161, 0.11193522101929111, 0.2001140708284032, 0.12994204107071125, 0.09656401155816932, 0.10873836675478567, 0.15156605250893102, 0.08983968246367671, 0.11099483277047835, 0.0961104185590821, 0.17741647909485525, 0.06487728201694067, 0.191431031111748, 0.08116700025575777], [0.05470174980620223, 0.039949704096802784, 0.10875833100609242, 0.05085926728263017, 0.16209525687079276, 0.14220217513220926, 0.052212308791856614, 0.08619644408745152, 0.07503455835244349, 0.11605206261118574, 0.039767168327084476, 0.04990465278106351, 0.080537237677603, 0.04916927349122782, 0.0343669226182805, 0.03106091614632357, 0.018160932043927814, 0.027082765197020867, 0.05659869458946971, 0.005934129031600371, 0.10722603258346358, 0.23601281306435987, 0.17757023294125834, 0.2548933257499049, 0.22385862896278982, 0.12345170587181084, 0.06957297964442162, 0.02503856682338782, 0.05433630671412234, 0.08076060593368546, 0.11450190667904193, 0.08153640019196658, 0.05229746712551964, 0.539903896710565, 36.94086267102149, 114.4528082878359, 95.04660729439028, 101.60686554447298, 116.38452068451913, 86.2873584993424, 37.13007388576385, 17.865662651677287, 45.91928566655805, 73.07133228548112, 63.36485462803995, 63.193070503973196, 41.697846535713445, 42.16430656371578, 34.457484599082704, 22.109210221998154, 3.0999584832499107, 0.1871884821523582, 0.19136710873534604, 0.0681805535550079, 0.36980571766053477, 0.18948501456649075, 0.1483414811833251, 0.2873327673202561, 1.6338523861862, 2.4374571682945376, 5.081224143505096, 47.06168774635562, 107.19436030234061, 125.70992439023911, 113.14106572058894, 101.0464608284735, 102.24654920639531, 107.3636733331988, 118.34835729291363, 114.40021714856549, 107.27697326290993, 96.06882402973791, 103.79386932619157, 121.39117517778952, 123.74108283750473, 116.35308680995819, 109.4273970204015, 102.5504073789043, 97.1580348476287, 97.7514345415177, 111.19134180007443, 146.50490330111597, 54.2154319824711, 28.723916853627852, 60.65289651193927, 132.72287122664915, 143.19705870843703, 161.5991094035487, 156.02948496418617, 115.03965762353714, 69.61657139562791, 97.43315773625528, 104.32140458014705, 110.72483078125985, 115.9564410486529, 118.9960975031699, 123.21550092389508, 119.26712543733659, 125.66435429357715, 133.18966465611612, 130.52171553334884, 125.33292970349713, 115.71206954217728, 110.08087958059004, 99.72530457281299, 110.68220246222712, 121.64659992341073, 136.72765824102586, 115.95855912854596, 77.89933066214286, 74.18601497527092, 35.615364351580226, 9.099284948841218, 0.2602345826885393, 0.33309585685210846, 0.022545075119142572, 0.1800459379991216, 0.15296161955883428, 0.057238960233066356, 2.0679390093972607, 17.47875613550986, 40.47462794088548, 47.501546259849306, 54.91050735596688, 81.69724402889129, 87.04002995644846, 90.76829771841727, 158.1125302468577, 86.53547194696243, 33.018272845975815, 32.3583830941108, 62.818966604048214, 74.76829082735124, 74.59704014562791, 88.44977686482092, 91.97667798688336, 40.80866090713009, 1.9672836363315584, 0.07478607007332387, 0.10209940283769563, 0.05972929373984376, 0.05384254389472547, 0.02380639675163454, 0.057000197440145485, 0.22671247502007794, 0.07943622377370635, 0.02357622180434485, 0.08861335955800549, 0.12329298777565842, 0.16349336733260464, 0.13341320077738456, 0.3165619634091854, 0.144409611520748, 0.030658819577506477, 0.04880626272830752, 0.01806388211046015, 0.046744268132193435, 0.04163245069644144, 0.06794299735056777, 0.1256306208069286, 0.18099426291882995, 0.06672379906259238, 0.08410182180664233, 0.014242462216756277, 0.09434087036718285, 0.039406107257931464, 0.0728377246207768, 0.02113877709263996, 0.08318000352911412, 0.0443209175230755, 0.15386747256402047, 0.05439254522864377, 0.09682504069660941, 0.03128956657864394, 0.03899742616340518, 0.05141773388811177, 0.13683430429908539, 0.062485965374376506, 0.03706642877190344, 0.09440594187547123, 0.0783462338750401, 0.04414102092625634, 0.06746531088626193, 0.016692153801540696, 0.02970789761973485, 0.13025538635350045, 0.03716193312298387, 0.046862471668470296, 0.06970855422438153, 0.05481993419028098, 0.0380135624248895, 0.10112846300246255, 0.05671958326392117, 0.05917692519423943, 0.042198015106541496, 0.14589076591355188, 0.06837396011237176, 0.2022995051717566, 0.11886610273992824, 0.28177832343405296, 0.1858395851788021, 0.1528826971808749, 0.04226501332595945, 0.04847259313288716, 0.0456729477962419, 0.06295078156155444, 0.10953722792046686, 0.07611658859757647, 0.016513712771777666, 0.2791562802608936, 27.178820717719297, 114.88593993648406, 109.82436441606092, 114.85857748216199, 119.39099388737833, 103.20129333003875, 60.62018002233198, 21.148445260140207, 24.417450543372865, 39.576832709773896, 47.75116981998567, 49.117209757528, 46.35171521094538, 46.4165049214517, 44.592759686131636, 29.341623475474698, 5.1186450258378065, 0.34121258905337704, 0.2310594264417887, 0.03922811438960414, 0.35285277412303034, 0.3517791478624267, 0.7734825113607992, 0.8939899804611361, 1.2286502194981421, 0.6585451756273547, 8.411756215556975, 53.985926258948545, 115.40228074596776, 129.33563786168253, 115.66986483912315, 104.94412791344428, 106.05472349351453, 112.3054910475208, 122.40895179010208, 123.11029511113321, 115.72153814377324, 102.30168988627773, 107.4349114202684, 127.05293609249978, 127.46310618615921, 122.30860187161355, 112.88471529560705, 107.85801749075614, 102.00139322588521, 103.90039305533134, 111.35585384984171, 148.7700406966671, 66.00872824268957, 38.330950660090295, 72.48700895617085, 147.27230718058925, 158.96591248050814, 175.276147473243, 168.9520472864951, 132.29437581954465, 80.03506122096893, 103.40615872413882, 106.67313221962222, 117.98518503865888, 124.85636172756072, 127.54840204792639, 128.27145961023146, 125.93619023599933, 131.52023330811534, 141.78911609034387, 137.10858314268052, 131.8560274185673, 124.9455564252792, 112.73814416700795, 106.0609051489061, 116.29633795830512, 128.3329623745334, 145.03155123802924, 131.84791595705096, 97.5140997671312, 92.05135207022391, 50.42033095513621, 17.826576232910156, 0.15521215605399302, 0.4185287564271881, 0.034617544452269236, 0.16940669276781622, 0.1485005516799227, 0.2310420668894245, 2.780445395938812, 22.96228454959008, 49.566999712298, 49.596460634662265, 48.765918362525206, 54.17639263214604, 44.91571587900962, 35.235165088407456, 104.9546398655061, 53.83193792835359, 41.80884961158999, 53.12939043967955, 69.78610407921576, 82.9447695516771, 82.4608196750764, 103.46451574756254, 102.01382713933145, 46.615063144314675, 2.195308174817793, 0.07641603704541922, 0.16086426082878344, 0.07761633594430263, 0.05247496969757542, 0.025855013537370873, 0.04724826971669832, 0.11686826034659341, 0.040157049623948914, 0.108966400486327, 0.08147117546609334, 0.12812226815449615, 0.17407841950414643, 0.18532610708667388, 0.2178318612277508, 0.18585787935843393, 0.020715743340852282, 0.0040661423718706975, 0.016555081519688812, 0.07464073553320862, 0.04999831852112567, 0.04408956280038242, 0.07320193048085898, 0.03917081867374721, 0.03924510621976468, 0.06582847210548579, 0.1286601461470127, 0.07852405820402407, 0.0286957441693953, 0.08257287884912184, 0.023768260894763856, 0.02011647680774331, 0.15500718156897253, 0.25454838700111837, 0.036295667711284854, 0.05900633656570028, 0.06445783355663862, 0.028142236068003604, 0.06301416384596979, 0.159932054399002, 0.16684923080667374, 0.24038253261918024, 0.21789494090743605, 0.1666222849199849, 0.26308164120681826, 0.17816624934634856, 0.14022355388489463, 0.18338666357580694, 0.27628032490611076, 0.12190192532274993, 0.1634741385257052, 0.2082013239663455, 0.1446317157317554, 0.19942056207406908, 0.2155182603746653, 0.10422963288522537, 0.22949931902750847, 0.13883436068652139, 0.256103805957302, 0.11069444969536797, 0.3771194671430896, 0.253189668780373, 0.3984737696666872, 0.3587784948608568, 0.23039288398238922, 0.26357227455704446, 0.09587919024089653, 0.21143003216674253, 0.22425448191502403, 0.23625151073980719, 0.2317095286543331, 0.11233164853746853, 0.6279103614149556, 69.08265052303192, 153.63873758623677, 119.71883343112086, 122.59358559885334, 139.91095973599343, 100.59375655266547, 54.22991337314729, 25.700355845112956, 73.21592653951338, 110.98693140091436, 92.83228028205134, 99.92400400100216, 62.55071178559334, 66.8428594835343, 58.17228371097196, 43.700549910145426, 6.558843255043031, 0.5473028964573338, 0.3765468010979314, 0.14904363140944513, 0.6852824409161845, 0.3356217100254951, 0.6656131641038003, 0.8016800628073755, 3.4178312843845737, 6.109942697709607, 9.99872757542518, 53.561294386463786, 122.49125096105762, 138.1243201225035, 123.74436978370913, 111.37606190096949, 112.6145738170993, 116.9817799906577, 126.69787529976138, 129.2770141170871, 120.84198844048285, 108.81320091985889, 114.57608053761145, 130.78779343635807, 130.87863552954892, 127.20149978514641, 117.06221995815154, 108.1504301871023, 103.92322909447455, 104.10623904197448, 120.68571336807744, 157.32548313756143, 68.2602628584831, 39.11774281532534, 87.57950490520847, 152.3365734469506, 155.8623919948455, 167.93778511785692, 166.896144805416, 147.50071464046357, 96.43490668266051, 112.49556910607123, 108.32929811170025, 122.64312513412969, 125.57622648054554, 131.60077525723366, 135.16856316597233, 131.5437989081106, 137.12668880339592, 148.20934572527486, 141.832481814969, 136.81360521624165, 129.2867180608934, 117.01965439704158, 108.61811007222822, 120.2949276278096, 135.26340607673893, 153.78152754998976, 132.89922098959647, 90.04200027834985, 83.93203796878939, 43.203769960711085, 14.814155736277181, 0.29048500462405147, 0.4158282964940994, 0.09737275525807373, 0.3962712668843808, 0.3699286594506233, 0.6205619847582233, 4.703548435241946, 33.030408659288966, 65.12612435125536, 70.04399991804554, 77.5081213058964, 124.02763551281346, 121.17922598315825, 120.21850416737219, 172.74444580078128, 96.93415380293324, 49.89061486336493, 48.9231034248106, 81.6669947101224, 95.59554300000592, 95.14459594603508, 107.93597067556074, 117.88966748022266, 76.9057942974952, 4.951328481397321, 0.157423576099738, 0.19131446317318948, 0.24669833000629182, 0.19687679776501274, 0.2266401103547504, 0.17491678016320353, 0.26280548183187363, 0.12161671844941956, 0.13957748129483194, 0.11218308110631282, 0.22867344560161715, 0.2719519587774431, 0.2968665170333078, 0.45636069089654957, 0.3677865856837842, 0.1690405793488026, 0.08622400793096713, 0.09760587581343229, 0.1841479557896814, 0.2068850163730883, 0.20493495488359084, 0.24806238019899016, 0.22631603984102128, 0.11935452209605325, 0.17957508503910036, 0.30688964371238986, 0.1612194957992723, 0.15582456674066283, 0.16359583925335638, 0.10541208193547304, 0.12701190031704404, 0.27220611610720236, 0.3307828229040869, 0.20679440349340442, 0.15640501623913167, 0.2576156038670771, 0.08997133467346431, 0.179192699912575], [0.053319367129475846, 0.04697757637909344, 0.03716889303177595, 0.044271347803934935, 0.031241174719686952, 0.00843575706840643, 0.04323139493804305, 0.09140895228953132, 0.07368350101094093, 0.04182761159515189, 0.06792437375312851, 0.09722080171829271, 0.03684191521437418, 0.025252002749531984, 0.05826135819417335, 0.05261808641314988, 0.09373338562586615, 0.015183732424291874, 0.054431217347061446, 0.058750961156141375, 0.20697785090775261, 0.23291057065850307, 0.2586298736353075, 0.16657549226956983, 0.21844361307880572, 0.05404487154596756, 0.0697104464615545, 0.05818939189456644, 0.02199438622131223, 0.0878791408913751, 0.11773699639184822, 0.057782534089299946, 0.2499914049140869, 46.91267298113915, 129.2290121509183, 102.41402656801286, 104.91449832916261, 90.58297357251568, 67.75061361251339, 32.80815932058519, 26.355972174675237, 77.85530597932878, 56.51111287455405, 45.314283601699344, 50.12857329460883, 49.03329457006147, 46.00910402113392, 29.357536531263783, 11.401867251242361, 0.7278826292003355, 0.4234149264952829, 0.027429573200342637, 0.3347692073833558, 0.15599189566508417, 0.11314273646642124, 0.18891293074815504, 0.43519512179397773, 3.2547472225081537, 4.421270653124779, 43.87250661849976, 84.8842639307822, 121.36720949603666, 103.83390888091057, 93.1507061373803, 96.38109176389634, 108.72527707007625, 94.33442254220286, 93.65876290106004, 106.95745698867306, 107.58669145645635, 98.3636773017145, 83.17571870742306, 93.262736874242, 111.39871751108478, 110.17130590254261, 106.53636701645391, 84.89046912039481, 87.42353577767649, 86.40472365963845, 110.34630637015067, 104.00775617168796, 118.37578250515847, 89.6601261631135, 53.95191146481422, 95.4318703374555, 120.16478338549216, 86.09346789698448, 82.58985780900525, 100.57126568209742, 100.99135152755245, 62.99765409961824, 96.46617581767421, 110.02497796089419, 111.64843128573511, 111.34764040670088, 106.18063157604587, 108.5678017523981, 104.63694357102918, 103.62475241384199, 102.72303873492827, 106.49700995414489, 102.74976576528242, 100.23878205207087, 101.49412093623992, 106.72039678019863, 107.40944739310973, 100.22928207151352, 102.90324026538481, 112.57067465013074, 134.4754489775627, 131.91972671016572, 142.96494853112006, 124.28958708240141, 66.31752075687533, 6.412512371616979, 0.5530506396485914, 0.06219463362809151, 0.19080113829864612, 0.1016629548863538, 0.15200880536388967, 0.3124808598189585, 5.928170257999051, 33.21893738162133, 51.15520269640031, 59.532079235199966, 63.80317165005592, 74.98258559934555, 133.78749662829983, 126.27410242634436, 26.313283058904833, 21.889651629232592, 24.00247750743743, 73.36856949713923, 70.91344033518146, 73.34569423429429, 82.16395901095483, 96.75749025037213, 55.809922525959635, 2.1993805756492, 0.16239393923071124, 0.17140961432408902, 0.18283665841144903, 0.09236032623917827, 0.1392122258942935, 0.12726631811669759, 0.020936742470028902, 0.08915493009431709, 0.12177183593232786, 0.17223306691213963, 0.13727672007535735, 0.2527322836460606, 0.21048919958693368, 0.25752036381633053, 0.03903120297998671, 0.054267056196207, 0.025205189031699014, 0.20249162470140766, 0.07968847354453418, 0.022148542263875567, 0.05231512162173468, 0.042648689310637214, 0.092144473305633, 0.031411108343050845, 0.09551332197001866, 0.06974846740523655, 0.06928632486491434, 0.03379908675748495, 0.09375983864189157, 0.027634310198106596, 0.09009753233723103, 0.05903091649675082, 0.010513383688615456, 0.08349111949604365, 0.06411032075242651, 0.054045304385644775, 0.03889231123931466, 0.10657616019729646, 0.018981919744082035, 0.049302764312033696, 0.022131469994482976, 0.022075821367663243, 0.017881003516395728, 0.0512329304981376, 0.08595335672819808, 0.06510223607502638, 0.03867400299397208, 0.10242166538392344, 0.0731716163816952, 0.07796048562252715, 0.06366484062445742, 0.05265678534464491, 0.0381970634653924, 0.059872747534104896, 0.0508334654413404, 0.03510615533037532, 0.01796655447011994, 0.07004156498418701, 0.06718191198043286, 0.312805068228514, 0.1325696000769254, 0.19701089379527878, 0.02972843069132538, 0.031203013964958733, 0.10738997539925961, 0.030564224955836133, 0.07354303112914486, 0.08381059348222711, 0.015631699465185164, 0.318147765412446, 39.623132367287916, 144.91042844710813, 116.98671433233447, 118.98253394711404, 101.47185756314187, 103.03926021822038, 62.39905334288075, 21.722637107295377, 23.56867121111962, 48.33142172905707, 45.72027244875508, 45.15720836577877, 52.9932959618107, 53.45164452829669, 42.575469017028816, 16.01382932355327, 1.142140261588558, 0.4760097429877328, 0.0356959204580034, 0.5577310078567075, 1.1805807150179342, 0.443045960198487, 1.5752130746841433, 1.9271292297109481, 1.784682841070237, 7.187831103801728, 47.95288947320754, 95.06095532448062, 124.72696273557602, 109.60598253434705, 96.56896545040993, 101.17123142365487, 112.8368466900241, 99.96321985798498, 98.87017296206568, 113.70887587147375, 112.25613194127237, 103.44655129217334, 87.71759586949503, 98.40991420130577, 116.20731584487424, 114.39262343991189, 108.45766944269981, 88.47507615243235, 90.6062646065989, 89.49797538018997, 115.27873393028014, 110.29134611929618, 128.0268370720648, 94.34371855951126, 59.59390363385601, 111.76006978557957, 125.03252321673979, 92.07651799724948, 88.03433510564989, 108.6128854751587, 106.2046286367601, 74.1193268376012, 101.97217941284181, 113.90968553481565, 112.97055244445802, 115.83022702124812, 112.1115690662015, 117.68475501768052, 108.97146071157148, 109.62203287309217, 104.91158008575441, 109.55077125180154, 104.12041448777723, 102.14600316939816, 106.9036263804282, 114.87831484886908, 113.34092617034914, 105.01365584711876, 106.4548993879749, 114.97670358227147, 133.88875653666835, 133.39656183796546, 145.27440870961837, 135.50508683727634, 81.83982218465498, 13.25425853652339, 0.30666680405697516, 0.12811567979834734, 0.2730163306959214, 0.10823890041079252, 0.16750232076212285, 0.17718037079659202, 6.412516784283423, 39.44140503483434, 55.05145380573889, 48.34171010601906, 56.19546797967727, 75.9157096185992, 155.45923509905415, 130.91065775963568, 39.7820040487474, 39.60506200790405, 44.99328467153734, 87.91936259115897, 79.06198393914008, 85.66345061025312, 92.70949440617716, 107.92422709926483, 63.460313350923606, 1.711499626117368, 0.08032837912680642, 0.08648710550680276, 0.17540617245099238, 0.04221720943948434, 0.12155419035303978, 0.2337115002615798, 0.0625506078734273, 0.11127845384180547, 0.13488925302461272, 0.3112511967699374, 0.15495798340247524, 0.3717633174552072, 0.31299570154759193, 0.18553189362489408, 0.0521126905486228, 0.035338314445388895, 0.04885261870860573, 0.21738656496088352, 0.09849790859246448, 0.034820887170011, 0.07220842935625585, 0.033420152857058474, 0.0809298500779175, 0.0036395601965787433, 0.071796749027506, 0.06345325480065038, 0.060358811169862754, 0.03736417650455429, 0.05478708434008783, 0.013289679622938557, 0.16569760147361987, 0.043241514959522796, 0.02542197084685247, 0.07825866236441559, 0.029911518044349168, 0.054558552651395725, 0.04379910822477072, 0.20251623144553554, 0.1926673897692273, 0.11288742234389629, 0.10017978568230906, 0.167886529177908, 0.1153481733654776, 0.12156472406199864, 0.17017232103934213, 0.2611674326321771, 0.10551875201804985, 0.25174953073503514, 0.22373757174899503, 0.13727328800145658, 0.1538563949326354, 0.21388258604753405, 0.16304969517213685, 0.21577378134092978, 0.3077000728057277, 0.15764457714413443, 0.2854040643620876, 0.3767856366692051, 0.3524502715276134, 0.4091211660735069, 0.25125977072504263, 0.3075119522550414, 0.13480024892956982, 0.1371718886037988, 0.23773294092426378, 0.14982758450411982, 0.29553346275802583, 0.3526755013773519, 0.14834708894693083, 0.7661083328627771, 88.6782157036566, 163.21951896913592, 121.39356782359462, 129.76397637398014, 117.11561910567747, 87.64481236857753, 51.98820037226523, 43.087475607472086, 123.78670000260877, 89.25647504868047, 64.77564880924841, 74.95515254236038, 79.79565543513145, 78.56855761620307, 53.619823994175086, 21.390071107495217, 1.5999058658076872, 1.3301193618005323, 0.18568823684848126, 1.0030949968964824, 0.6054215746060495, 0.2165125658915889, 0.7407264916166183, 2.711435215127084, 8.631154971738017, 12.814992300925717, 54.449048349934245, 91.21272579316171, 131.05100016440116, 114.83200734661473, 99.81434237572455, 104.88737121705087, 119.10974425654258, 104.63841053747363, 105.47197695701354, 122.45155657491377, 118.56668426144509, 107.43052621041576, 93.81693640062886, 104.63226810578378, 120.58900340910881, 122.6257804132277, 113.07461292512956, 91.84761631873347, 94.14859633291923, 92.74660002800726, 118.72284166274534, 116.08912698684202, 130.27692825563494, 104.5698396621212, 81.31834307024556, 124.2004551426057, 125.4050777804467, 102.1168521142775, 97.99414296304026, 117.67974222860029, 112.25329999000796, 84.18497593172135, 106.12684803624308, 118.30860014884703, 117.23073282549458, 118.04349499364054, 114.59399007981824, 119.84193309660881, 111.87510505799325, 113.63847717162102, 108.83719013583277, 115.54236427430185, 110.40966049317392, 108.33598967521422, 112.3055773396646, 120.81111938722673, 117.53090397004159, 106.6987923652895, 106.7949688819147, 120.4192981412334, 148.18932594791536, 146.66774442118984, 156.62954484262775, 136.4749634650446, 75.44486045837402, 9.772671576469175, 0.37351116237621157, 0.2340186708756993, 0.6657974542148652, 0.23017298610460377, 0.3599640618889563, 0.7020910228452375, 10.002062570664192, 56.99831831839777, 80.64737458382884, 86.9021821791126, 89.15511315868747, 93.52668885261782, 133.13763833815054, 140.5588725305373, 39.68613347699566, 37.31027933859056, 40.126223410329516, 89.9023639002154, 92.90476568283574, 96.38371190717145, 101.67857431596326, 116.2219855093187, 91.56027916939028, 3.253971083510307, 0.35243157898226096, 0.28413404380121543, 0.4725894361974732, 0.21483771382800995, 0.2920585185770066, 0.38816899842312264, 0.18474386494246223, 0.2209198390764575, 0.3432686771115949, 0.4099522795408003, 0.3448844484744534, 0.5198148650027091, 0.47182460465738857, 0.45867580860372514, 0.11117074954053087, 0.16831233616798155, 0.15121593500577635, 0.3656819582946839, 0.2300599728140139, 0.11140535630646253, 0.22115879722179907, 0.3190940065730003, 0.18521893138606704, 0.11871080139591811, 0.22550820012486752, 0.21906952223470136, 0.1906258880250877, 0.14970041390868927, 0.18284208231395294, 0.16891019118409004, 0.27258057988459067, 0.204046277569667, 0.14584607234404934, 0.17352056959944387, 0.18035683180055312, 0.1667917742123527, 0.18503628070316008], [0.1004069613953752, 0.04344598765695288, 0.10178925214155067, 0.0518159885259886, 0.021835137609272234, 0.017949591368256558, 0.049408806202512597, 0.14506650127230153, 0.13923623508984043, 0.07316457603367106, 0.06550942712853994, 0.010008252124422261, 0.04835675297785671, 0.05868374077122539, 0.0663483010665063, 0.05498022276667818, 0.030315240634785547, 0.048560961374952916, 0.02686642196720406, 0.09548396548076023, 0.1798073322542252, 0.15799314714968204, 0.11064532047678387, 0.2778191503978545, 0.18664800712177831, 0.10211585840630917, 0.02216879379815392, 0.08753635484965579, 0.06603078826540901, 0.027050365423483234, 0.21936471123368512, 0.4130012175488857, 39.50346085333055, 134.16638189746487, 99.26418289061516, 115.85440451099028, 86.64236437889838, 74.13931523599933, 26.682495763224942, 17.39500960996074, 55.30093223817887, 46.15705974640385, 40.31068855716337, 34.02051295003584, 35.282068790928015, 36.9572267993804, 23.73327151421578, 4.108071846346702, 0.36788629968800857, 0.07624960444386929, 0.23638634221448054, 0.09703818933978196, 0.17820726569381454, 0.3244967650501959, 1.1189228945201444, 1.4246688302486175, 3.64698693636925, 13.64830376640443, 66.13849593747047, 106.86728169841152, 103.54325340640162, 102.24562352703464, 106.7718896558208, 111.44300107033023, 115.75820446014406, 107.5375049344955, 100.67562426290205, 95.26882525413268, 108.75857014809887, 114.34131099331765, 107.09472425522344, 83.47764707380726, 89.30522226518201, 109.72343398678689, 108.73276095236503, 89.83971580382317, 90.73568713280463, 103.63791588814028, 105.33658458340554, 102.18116329562281, 109.30659586383452, 130.4407342787712, 98.05704993586387, 32.690645110222604, 88.90034737125521, 103.3331241915303, 96.66831908687469, 87.58964815447408, 108.52543230979674, 88.54407064376339, 65.31060910994007, 105.85511407544537, 104.20573388376545, 104.53362834069037, 110.45517567665347, 115.28505679099791, 123.79245019728138, 124.60187835078086, 121.27213124305972, 112.8556505326302, 106.79693791174121, 98.91500565313525, 94.68923230325022, 84.82760921601327, 86.21739126020863, 94.41618042607462, 102.3996393142208, 113.94402980804445, 115.99001653732793, 102.51453338130828, 99.57018267723822, 99.13818851594003, 99.10251063685264, 120.88213782156669, 116.1134692161314, 35.59530142814883, 0.1858642991752394, 0.22090551323227345, 0.10862140045050653, 0.16825920030955346, 0.13049448239466838, 0.25899771841303, 2.20607336490385, 19.763189631123698, 35.27147054672241, 44.08586786639306, 39.89056348800659, 40.1161939097989, 32.39691057512837, 38.55308625005907, 31.604774190533547, 25.340174398114605, 19.404812474404615, 48.47600813834898, 64.00075712511617, 81.80987881075951, 76.34898247257357, 88.23593708776659, 49.44812443948562, 2.008127767232157, 0.3504131518064007, 0.04270676643617692, 0.11483365339377236, 0.08825690650771703, 0.056736192050119566, 0.037696543750503374, 0.09287754284037698, 0.09875907562673093, 0.0840764030093147, 0.10987611457465157, 0.06278447536451202, 0.1249697780416858, 0.07578682605056994, 0.060781385268895864, 0.053612529825899875, 0.0378800141474893, 0.18772086729445767, 0.020787025906986768, 0.015024250155434975, 0.06982812522760323, 0.020508953227451252, 0.033780026489928845, 0.058064799185001084, 0.08698896970599891, 0.03551755220659318, 0.07710455090648706, 0.04482765787190968, 0.006045513906546178, 0.011564891075625295, 0.023562794198252024, 0.10439070287130534, 0.06882536976087479, 0.05344443481355425, 0.07174172093190494, 0.04447027402479322, 0.06960895513334582, 0.0442705549029333, 0.07384858529774413, 0.029624102922577052, 0.049286527078478574, 0.07165112337397953, 0.07309500758926715, 0.07946255421566387, 0.10349319256361454, 0.10912390050267982, 0.043554507841866826, 0.036450593672212095, 0.049354387146811333, 0.007999891822692007, 0.03496383534624212, 0.09712840385374524, 0.14241790549168665, 0.018716590937166926, 0.037596603750341365, 0.04904236336569152, 0.07628140475360617, 0.09249806118708465, 0.1505032893750937, 0.08954447814293447, 0.2864419602819028, 0.05105071265490786, 0.1567392757222537, 0.04395769991641564, 0.041635756365834706, 0.08006296796543945, 0.052666533813481374, 0.2711042978109852, 0.3972166500264599, 40.8077391501396, 147.42997077203566, 112.50559468423168, 126.15665881864487, 106.4573077232607, 97.62409871624362, 40.55158092129616, 17.444619747900195, 24.276364849459743, 57.00165625541442, 44.97699114584154, 42.53577855325515, 43.799299501603656, 48.528858154050766, 32.962131961699455, 5.410677742573523, 0.43399705221095397, 0.24351630720400044, 0.22241250010988406, 0.5481834072739847, 1.031232670910897, 0.9897095409612503, 0.6164154266157459, 1.4188726703005454, 2.425176227285016, 20.507427992359286, 75.0695445460658, 112.84193008176743, 107.66285604046239, 105.77239128851123, 111.26920084799491, 114.36353514271399, 114.99487200090962, 114.6389247525123, 104.54151230473673, 99.15914181740054, 114.05136939018004, 118.98325566322573, 112.16304625234297, 87.30255419208159, 93.23570389901438, 112.86517404740857, 110.76165399243756, 93.88394617265271, 93.35647367662, 110.93175934207056, 106.83840520920293, 106.37704818479477, 112.0329490784676, 130.00145235369283, 100.99349314166655, 41.901311643662, 95.08113199664702, 111.50269954435288, 108.08621314264114, 94.76086262733706, 119.30882023226832, 96.67356721816525, 72.44261557056059, 112.85066912251135, 109.53206939081993, 110.37205280796175, 113.02573234804215, 120.17453439774053, 126.56421661376955, 127.07773331672915, 127.86431758634507, 118.22186869959678, 112.77870931933003, 104.00922313813241, 98.71009319059311, 86.80625669417843, 88.70983000724547, 98.24157391825031, 105.62954641157582, 119.75022808198007, 122.22150171956709, 110.33284479571928, 106.94346981663858, 103.52841115766957, 102.62075901031496, 125.76285285334434, 128.33139342646447, 49.929862099309126, 2.860924832282528, 0.1722425510806422, 0.10290786308506805, 0.30428154333945245, 0.09694976747156152, 0.34655948439913414, 2.2621372726655777, 23.60191329833, 40.97642067940005, 45.71372993530766, 42.89096486183905, 43.373318333779615, 29.71669423964716, 28.78799073157772, 32.17683619068515, 34.51604558575538, 42.25479172122094, 60.638191546163256, 68.3236954289098, 95.66728315045758, 85.30815447530439, 105.05760208252939, 57.90688045563237, 1.306781259275252, 0.2983810728596103, 0.061870490336009575, 0.14811082743108273, 0.10757924508183234, 0.009947312702875464, 0.08274148714037673, 0.06923233864889031, 0.03900402984131248, 0.050119176552060156, 0.1261576050291619, 0.10994302469395822, 0.175294783266802, 0.06646876073172016, 0.01944970643718637, 0.08994796899177375, 0.06108215904884762, 0.10323728089250865, 0.07117314579626245, 0.02253608316213133, 0.10473509003678638, 0.03419230819769925, 0.06377529518138017, 0.05551566459959554, 0.08224077207306701, 0.023572379873404582, 0.08377351482669193, 0.07093676170634647, 0.03876342460693371, 0.06295128717958447, 0.017701078191279404, 0.033094894907046715, 0.005714279513115124, 0.01564252811799487, 0.02562518524486692, 0.008474555591331616, 0.05019333769357012, 0.22886496758268726, 0.21042297894675888, 0.1927174459541998, 0.1413343966968598, 0.16996219844347046, 0.19646514807977986, 0.24517911636540968, 0.2846337169889481, 0.22111024256915818, 0.2166270500709934, 0.11481131426990034, 0.1785979552134391, 0.16542467498971572, 0.1332139259865207, 0.36394750459059594, 0.3221859067918793, 0.14297134272994536, 0.2455936925065133, 0.16529558917447446, 0.19982706364845076, 0.22492886911476814, 0.2741198956726059, 0.17156163681178324, 0.4033804402476357, 0.2773931135814036, 0.19157900865520203, 0.16152617611712025, 0.11695813012099075, 0.19027621485292914, 0.1614368042998737, 0.31561841887812464, 0.4521306904573595, 81.08587987961309, 164.01707803049396, 121.24649463161346, 147.55435697494016, 110.3542923158215, 100.6738905752859, 45.81212651345038, 26.233056860585368, 86.59360147291615, 66.08721486983761, 61.5721510302636, 56.750463747209125, 63.28099043138566, 61.08196066271875, 39.74458463730351, 7.016826550806723, 0.6349172467185605, 0.4169902680141311, 0.4571160842334071, 0.42452210740697005, 0.2713668821079116, 0.7993032290570198, 3.456596313945709, 5.377761212087447, 12.67774856859638, 22.257030625497144, 74.99796913516137, 119.16586552896808, 113.00099003699519, 109.99955315743725, 116.35923708638838, 119.32596883466168, 121.23026386384042, 120.76290561306863, 108.99246108147406, 104.69183321922057, 120.66773322320755, 125.74987765281432, 115.80729684522076, 93.59650704168504, 96.98975732249599, 119.58917556270477, 114.45112951340215, 97.82102523311492, 96.45074521341633, 111.13213754469349, 110.30993815391295, 108.5824792615829, 117.04418490009924, 134.79003875486313, 99.7233747666882, 49.38287188929897, 103.53503211852043, 125.54444743740945, 114.86478267177459, 99.17248572072675, 129.13016842257593, 106.28852029000561, 81.32480713628954, 118.55305794746646, 112.64793749778502, 114.43831120767902, 116.25021088507869, 122.58753730404763, 131.59850812727407, 131.4545649866904, 132.58718859764838, 123.90870924918883, 115.79063461672877, 108.05597951335292, 102.70272085743566, 89.69212485897927, 93.57149800946637, 103.04896416202669, 112.27624585551601, 126.44352528356738, 124.78737508097004, 110.31570403806626, 107.87101622550719, 110.16400244928177, 110.74750992559619, 137.49476402036606, 131.7579681642594, 43.31519273019607, 2.509910209525016, 0.20410158911780005, 0.45600623733574347, 0.6769058516909999, 0.2928279466446369, 0.6361887075247303, 3.797821681345663, 31.914359023494107, 59.16190947255781, 64.02677812883931, 55.97343829370315, 57.8114374222294, 42.12025834668068, 54.170356104450846, 44.278005169283965, 37.78356036832256, 33.927631224355395, 62.4837020135695, 81.46729899990945, 104.81927102611911, 94.92696715939431, 110.26771776137814, 84.06504554133262, 3.772097061718664, 0.5934293568134308, 0.25965480734744384, 0.22482995184198504, 0.2101688062952411, 0.08840789477671347, 0.2578374629299487, 0.19844798281067805, 0.19259652663623134, 0.19182480030482818, 0.3111163040082301, 0.1531329934274958, 0.3591949096129787, 0.17734982944544286, 0.137273900871796, 0.24535896316651376, 0.16672680995637373, 0.3517638567474581, 0.30961621192193806, 0.10972003948183791, 0.23371594357154063, 0.13127779197548667, 0.20036959179466773, 0.1542164562570472, 0.30921573179864115, 0.08948090816697768, 0.20138773796779497, 0.14919527085317721, 0.1247074771972914, 0.2646036127642278, 0.1399135334236968, 0.21233711091260757, 0.15266797805745758, 0.1824049372226, 0.15765406131263704, 0.17545461985132388, 0.28067337949910476], [0.08237827719459612, 0.024624253067398266, 0.07708967347899753, 0.07650861877106852, 0.09578830923043913, 0.019567668655767076, 0.053318930459359, 0.10803082326967871, 0.08019063651802079, 0.04402232326326832, 0.035998862266780875, 0.023095877014941747, 0.027089920458233645, 0.02197266954387869, 0.025926363136198734, 0.041466719065342224, 0.07912327685663778, 0.038774770369092305, 0.03408739628690866, 0.009611255785961066, 0.08864161288065296, 0.12244997696290094, 0.16056925569090152, 0.17370662171273463, 0.0827511628308604, 0.04036042298520765, 0.13835914102533173, 0.08459703636265571, 0.08703858922085456, 0.14006701147844716, 0.37535838422275364, 35.71551815156014, 117.5093387788342, 103.58419510626025, 111.98230343480265, 76.45101116549584, 51.11516314168131, 16.834102830579205, 53.3560210658658, 88.82793257313391, 59.10956936497843, 39.076950165533255, 38.77818322950794, 31.281494402116348, 32.78962416033591, 10.512248200754966, 0.5893080489289376, 0.44231091415689844, 0.10729419908696607, 0.1440006584650086, 0.0784982563627343, 0.24482607240638427, 1.971897446820813, 8.230220098649303, 5.013409795299654, 11.548689411532495, 48.1540717617158, 100.80896131453976, 106.85742870453866, 101.1874778809086, 102.92046731518161, 112.71393529830442, 111.63972362395256, 106.56897760206654, 104.57652338089483, 104.69235097208332, 108.67759673826157, 95.4231156072309, 98.40545054404967, 103.3617574937882, 110.16148428763114, 83.35597515106201, 82.41277064046552, 80.68275436278313, 78.82410003292945, 83.40376530924152, 106.01244034305697, 108.82385407724689, 113.59257759586458, 108.9775796090403, 121.00036590330063, 98.0673893036381, 133.3566164201306, 67.82396977947604, 63.09532896164925, 99.50613821706465, 80.20534699962985, 87.25878838569888, 100.73294578060028, 58.60150475655833, 63.36410937770721, 120.38445180462254, 100.4702175817182, 110.69114546622001, 104.89468251505207, 105.05768837467318, 98.04377663520076, 116.25231327549105, 112.86856297523745, 114.4650225485525, 104.2054985415551, 101.3314288662326, 92.82934634916245, 89.93805746878348, 80.33783681931035, 84.90195382025935, 85.97516136784708, 98.8398059721916, 99.8399240739884, 102.69401319565313, 95.43105448445966, 102.99801257348831, 100.5915992490707, 95.43353342240857, 98.94539617723035, 133.3703447157337, 80.05884647369385, 11.434982842014684, 0.10158209430594599, 0.2601749810480303, 0.010429258616040311, 0.08871895711748831, 0.19460485677324957, 0.24871304931659854, 8.675713096895526, 29.034203790849258, 36.002682716615745, 50.52373247761881, 73.14197417228453, 78.766386278214, 74.52493913712041, 37.99275213672269, 24.298410531013246, 20.15334583097889, 43.38737218610702, 41.26504436615975, 66.57824070222917, 78.3360944255706, 87.37130549646194, 63.09037500812162, 6.3305539565701645, 0.6899181308765566, 0.1201061616020818, 0.036426381463365215, 0.11684217505277165, 0.08234777157345126, 0.10451709971793237, 0.0487436541926957, 0.14462164933643035, 0.09320267821632086, 0.09236305351218871, 0.049510653761606065, 0.09344319918102796, 0.055457323173721956, 0.09864293669741, 0.06762219803227533, 0.15901314725558605, 0.020905809754866268, 0.007799485615724999, 0.04625961409821626, 0.06131272087053907, 0.028994242668211944, 0.053534243300917654, 0.03923772879305386, 0.04874349714467122, 0.06390989299923663, 0.04156608449956102, 0.031204494429872404, 0.11935882751018771, 0.09075618409101041, 0.09720307444372485, 0.026323562487959865, 0.06824829104927278, 0.010740156247911435, 0.04371647798125783, 0.013569171480353803, 0.10615175514812432, 0.07927900720988551, 0.06600769071449196, 0.07847931100836686, 0.09152349775596973, 0.08246518220872649, 0.020193543337706118, 0.03486251255737678, 0.05614585235654827, 0.014982371001444278, 0.07529170342510746, 0.04151087254285813, 0.04613557297195639, 0.05910161492084304, 0.0874845443233367, 0.007024173514031235, 0.08394167878695073, 0.015056425848254755, 0.015758680453854465, 0.06092939345586685, 0.10408492653720802, 0.11869096737955848, 0.21550747385669142, 0.21291547665192237, 0.0670759160552294, 0.04705061903223396, 0.12141391199322478, 0.04927328524870738, 0.07916233967989683, 0.10749408674816932, 0.4246705752466956, 37.71247917605985, 134.95222091674805, 119.06060480302381, 125.14839003163, 99.95774422922443, 82.36846354699905, 51.646836496168575, 45.180738664442494, 23.996670438397317, 51.12896988468786, 42.94737246728713, 45.76962763263334, 39.49976598062823, 40.85724730645457, 15.243186546910195, 0.8303987379035642, 0.5431175436223707, 0.09333896525805035, 0.08211780730034075, 0.37634053958519814, 0.9445906394431669, 3.8042308342072273, 3.4184608247972306, 1.3673731756787146, 11.760601343647128, 52.651524159216116, 102.0448217084331, 110.76643928404778, 100.58347209807366, 107.29354919925814, 114.72335769284157, 115.40351237020185, 108.54553837930004, 112.00361759431901, 110.3050430359379, 113.94136259632727, 100.56585281125962, 103.9557533879434, 108.69258803706016, 114.68141971095916, 89.31178831285047, 88.76586498752718, 86.82870834104477, 82.35439792756112, 85.44309969871276, 112.75154298351659, 113.95953101496544, 117.65408992767335, 111.28360379126765, 128.09291331998764, 103.35515222241803, 133.35697727818643, 70.17416769458403, 69.48816868566698, 108.85443287511026, 86.93977417484408, 95.54565045141405, 111.80021132192304, 67.4943337901946, 72.60966147145918, 127.29612304318337, 107.36460685729982, 116.07743047898816, 110.75363666780534, 110.16697560587238, 101.50446030401416, 119.83251940819525, 117.35927674078174, 116.38707806987148, 108.18245241718908, 105.6145315785562, 96.03005532295474, 94.7584072236092, 86.06081808767011, 88.09290393706291, 91.20530466879569, 100.35715133913102, 101.6312469974641, 106.92501898734801, 99.81567598158314, 106.80976406220468, 107.13175927439045, 102.67436996583017, 101.73848459797522, 136.98449503990912, 99.31311838088497, 20.444417076726115, 0.2122343325566861, 0.22029936914482426, 0.1012934323760771, 0.012208516014769915, 0.2812925317595082, 0.2890535540157749, 10.142517743572112, 36.38362330775107, 43.462850355332904, 49.350218157614435, 55.99758048211375, 47.040973709475615, 38.55111722023257, 39.89903972994897, 35.15563903316375, 33.555861134682935, 69.84336283899123, 55.582491736258234, 76.65365649807838, 87.99982609287386, 100.8446470383675, 74.65908419701361, 7.78431966420143, 0.6719313057199602, 0.06342015214144223, 0.1653917791742471, 0.15810729425039985, 0.09532440468789109, 0.06757382724073625, 0.020281997764663353, 0.08435862213974038, 0.04551756218256009, 0.11023871165009276, 0.0805670001934613, 0.09298631200386633, 0.0383753742602083, 0.019876279515184222, 0.07065029844882027, 0.23465280781590173, 0.044183577110450116, 0.0035336475834370626, 0.05003649268239256, 0.08882988664892413, 0.01893514241542547, 0.024286555764716, 0.06061153974564326, 0.05546175499236392, 0.08230199015909627, 0.011339546312698194, 0.01015519927961812, 0.09736324044605417, 0.02374294551930601, 0.10740080022162969, 0.0399781987371464, 0.03166202512089043, 0.12992745475663295, 0.010026932220845934, 0.02832460329837857, 0.3285561117433733, 0.25712068042447495, 0.190430213847468, 0.16928718305162846, 0.2195663608971142, 0.24237238471546482, 0.15413304460385155, 0.2657029182920533, 0.24120834475803762, 0.12478858292583497, 0.20750513390427638, 0.09679326336951026, 0.12923477337725703, 0.13593159225438872, 0.10229638702566586, 0.15907342305346844, 0.16499577300442805, 0.10437779428978121, 0.15417436738648724, 0.14029685317748977, 0.15408076676389865, 0.22050236712300011, 0.4208128628951888, 0.3054642911639906, 0.14320057155864854, 0.11437973863775693, 0.23120064708975055, 0.18296577487020724, 0.1366359334919722, 0.2643245728986879, 0.47058672914581917, 79.98825950007286, 161.2460647090789, 124.27541163659866, 143.99868134529362, 101.23836671152424, 70.83809160417127, 33.91901377708682, 82.69182374400478, 130.77028397590885, 83.25127924642256, 67.28230614815989, 63.33910819022887, 53.44763586598059, 52.51253104978993, 19.878199408131263, 1.4885559053190294, 0.7934373244643212, 0.32704149463003684, 0.5126246395370653, 0.31899597796220935, 0.4834932269107911, 6.208653555762384, 18.80131659969207, 13.759942266248888, 21.430245983985163, 55.108065374435924, 107.50907559548656, 113.23931324866511, 104.34957504272462, 107.7475949256651, 117.95033085730769, 116.90330905299034, 112.53599305306713, 114.71494028645178, 115.387877802695, 119.06364856227752, 107.16383641765965, 110.77400945848035, 115.28286026370142, 119.27432690897297, 93.18577997146114, 92.25354240786646, 89.86236356919812, 87.16964860116282, 89.38854909712269, 116.48931857078307, 117.79582869622016, 120.29393134578582, 113.94053889859109, 131.94920724438083, 108.99765429958221, 140.22773035110967, 77.43170569019934, 80.72325675718247, 119.68318693099485, 97.49922613943778, 107.35150614092427, 119.76491343590521, 77.17369218026438, 76.7759560000512, 132.11316231758366, 113.56784312955796, 123.6898253040929, 112.62259114173152, 113.05602873525312, 104.91440419227847, 123.30318943146737, 119.47131618376702, 122.07428732225974, 111.61159238507672, 110.85850515673238, 104.97602462768556, 103.02458270903557, 90.66050314134168, 94.23648095900013, 94.9827197290236, 106.5626076729067, 109.29022389073526, 115.30505303413638, 105.99099282295474, 112.9819743863998, 109.96445578913536, 104.76027857872748, 107.15031993004584, 150.73602676391602, 94.25188802903699, 17.095787678995443, 0.2320132978380688, 0.3554742657128842, 0.245247466730014, 0.2374841921752499, 0.41795517107652086, 1.1804909908002423, 14.640511428156207, 50.85251731257285, 60.34087980947187, 78.78743371655865, 109.20677154294907, 113.06270460928641, 106.40184540902416, 56.81707735984557, 36.11246201299852, 35.356860545373735, 59.67227258989888, 59.310371183579974, 88.24786893783077, 99.68775180078323, 107.44188539443478, 102.01106579073014, 15.92838146994191, 1.3307813843411784, 0.14549033175553047, 0.22751058541959335, 0.4622017742405015, 0.17014016066828083, 0.14174161839389032, 0.18272012111640748, 0.25704111453265915, 0.1986623648554087, 0.3174516979244448, 0.23549567307195357, 0.38063035616951607, 0.13215853261851496, 0.1940289118717755, 0.17963320046903627, 0.3035213389704305, 0.12413697152007973, 0.13808440657392626, 0.10298491620849218, 0.18873585718533686, 0.11574975665538542, 0.13221160718990912, 0.20768179377961546, 0.12003653187064395, 0.15838751389134317, 0.18095693911515898, 0.1070756265412896, 0.22769236276226662, 0.15831695719351693, 0.1972633350880877, 0.2836032674437569, 0.15951810644999628, 0.20185111390967525, 0.21331120703008868, 0.11863262978412452], [0.01862479636685983, 0.07678860858563455, 0.04308779941751592, 0.11448692199924301, 0.020877970119697914, 0.06683586240415612, 0.011845175834042172, 0.07029097256881577, 0.011776157057723932, 0.03347118963457404, 0.04765156521311691, 0.018541135735088782, 0.041543209114142006, 0.09136567598268872, 0.08141237055702556, 0.02432820413471951, 0.056822204571818156, 0.02415324114413271, 0.014245092771166276, 0.047116268936905174, 0.05887062408991399, 0.06777733083694212, 0.05102323308106392, 0.23472236859942638, 0.014020691253995944, 0.14199433547835197, 0.023426265838826378, 0.1013130825313349, 0.09719738241044745, 0.18576999375176045, 51.94670169584213, 117.42401153810563, 109.02940196375694, 91.45781901574905, 69.36829320846066, 53.67240728870515, 28.92601109320118, 22.951919686409738, 44.17925165545556, 58.2142020810035, 39.14080242956839, 41.065144692697835, 29.96105201782719, 24.29958331969477, 4.3040138483047485, 0.29903295239613903, 0.022975143473294955, 0.14869086324207245, 0.1071924779323801, 0.12855588158051814, 0.31685368969075145, 2.2052947744246456, 11.265028503633316, 1.1255045090952227, 28.240186629756806, 84.87297534942627, 103.87695297118157, 98.23078740027644, 105.2772940358808, 104.75681120349516, 103.62776479413434, 104.47973497452276, 106.294811771762, 112.52853270499938, 109.73280845149871, 100.3173000581803, 108.06798981082056, 98.55299442045151, 97.53427643929759, 93.9720739856843, 99.54095317471413, 79.64155335580149, 82.3692793999949, 81.37533510884931, 96.04112425158101, 109.88633002004316, 112.79457138430689, 104.09098102200417, 110.48970822365054, 108.82528966472997, 108.53522254574685, 109.79550361633302, 113.05265549690493, 93.80122338571857, 37.08346828337639, 101.95927481497489, 91.49748202293151, 100.93719144021311, 98.55926236798688, 52.4710206062563, 99.46238025542229, 116.61258297581827, 92.32467851331158, 98.78505752932642, 106.16629923543623, 115.98298764997914, 103.74442392779936, 107.95159739832725, 118.10192261972736, 114.69309268459197, 107.89454260180074, 96.9979472314158, 91.905377141891, 86.22718934089907, 81.165205893978, 83.4447697670229, 87.4051869300104, 85.4968204805928, 82.27481303676483, 78.41510665032172, 80.31838186325567, 77.94378680567588, 78.47467960849886, 90.67564349020682, 100.54794326905282, 96.96059842263499, 115.35140760483281, 115.82999167903778, 34.819856689822295, 0.467793112921138, 0.04174666291463279, 0.015233292567333388, 0.11341262924214525, 0.0281226203867024, 0.23548278747306717, 4.5604515460229695, 21.512235287697088, 28.118979507876983, 32.419626981981345, 54.10602138888452, 67.91140725535732, 65.38208253922002, 40.7231963834455, 20.533988321981123, 11.995275770464252, 30.214952922636467, 47.499534083950905, 70.43633107216128, 80.51203712340325, 88.03898703667426, 91.48696222612935, 11.085743827204551, 0.6979479580636948, 0.08137614991996558, 0.012484216694569877, 0.05105033344138534, 0.050518515204349836, 0.03995619286152144, 0.08786967970551023, 0.09835550816909922, 0.0762956003628431, 0.044353242603040514, 0.1562758078498225, 0.08008753640517112, 0.1107341483716042, 0.06948027534470444, 0.02717020647269824, 0.032497281208634377, 0.0425313514537148, 0.023397386239300814, 0.03118255367172101, 0.03412703750655055, 0.03313280093754011, 0.025919613901585824, 0.09423141172456165, 0.05169311951425287, 0.12207202748545717, 0.0910186458138689, 0.04264536065860622, 0.04633665573032153, 0.09182383486580464, 0.03181342516214617, 0.03891483039384888, 0.05149670989222584, 0.04813166868482386, 0.024702777079637014, 0.04887314986497645, 0.04845960794257061, 0.12627786551151546, 0.10396267422625136, 0.008614242148225107, 0.028685298560547735, 0.038451619160872315, 0.17507419590988468, 0.0398740912186763, 0.11343687592494874, 0.016316694109850836, 0.030362100317893975, 0.021882702093271, 0.07062946085727985, 0.02883179755430789, 0.03264740379827638, 0.025619299774388635, 0.007201788126445947, 0.03604676191424651, 0.04115989319078865, 0.05817838321109453, 0.09833094739024678, 0.019394421702130668, 0.14072034658203203, 0.049145517104695884, 0.13394740920874382, 0.02901156966183936, 0.08475101237455684, 0.06225064231623566, 0.16974066113752706, 57.78159602995842, 136.6896269398351, 121.06659120129002, 109.12521762232628, 88.11321396981516, 76.4236016427317, 47.68962390961186, 35.86554096591088, 50.13222502123926, 71.32446550553846, 45.01508912732525, 49.97458888638405, 40.339804310952466, 33.263907355646936, 6.555154265895967, 0.08506059616563783, 0.1391981605200037, 0.2027214510786918, 0.26948239774473254, 0.4536411706959048, 0.8862634628049789, 0.23796763962074635, 2.649547323103874, 3.715240835182129, 32.488419471248505, 92.04156967901415, 108.44299977825536, 102.4813344401698, 105.84097785334434, 110.11272138164891, 105.80016166933122, 107.21095192816951, 109.2116274372224, 114.21879183861518, 110.11742822585568, 105.99842179206111, 113.48057823796427, 104.84363678962954, 101.285184121901, 101.46687615302302, 106.05093448392807, 84.89835308444115, 88.48069298651912, 85.38023979433122, 98.7981504009616, 115.33685561149352, 117.67003828479399, 108.62164020538331, 109.3247329035113, 108.71400417820101, 111.41007669510381, 112.22210145765736, 116.58533819260137, 96.85397271187075, 46.1489482848875, 109.19326290007561, 100.63996207329535, 109.33442900257727, 106.72940254211427, 61.210281002906065, 104.76071788418679, 118.45677160447644, 96.38615946615897, 103.70831458799302, 112.4087356751965, 122.73904277432351, 105.82102867864795, 110.95750577988164, 120.71258160375781, 120.58461819925617, 112.99723240637012, 100.44240013245614, 95.42534351348878, 90.78714862946542, 84.75234677714687, 88.16066680415985, 91.21575386293473, 89.97484145625945, 85.72930720544632, 84.69982624053955, 84.56108416280439, 82.85652406754033, 83.20002955775108, 97.13443786867204, 104.25963509467341, 102.58791308249198, 118.97137872634397, 131.87132466223935, 49.9051982356656, 1.8988072655854689, 0.10450097356712627, 0.2395865059788189, 0.052508286861402374, 0.018238366296094273, 0.23317667895988112, 4.565557491394782, 25.477227895490586, 34.57285719533121, 35.57953742242629, 48.75558291712115, 53.93053062500493, 31.762206362139796, 25.757081162544992, 30.19895749707376, 22.503930099548835, 46.193447574492424, 57.365197212465354, 81.61369754422097, 86.51989229263799, 100.1834374089395, 106.43036104017689, 16.699861672616777, 0.6499324474603899, 0.09922282695169411, 0.08334219200356353, 0.041271209596626224, 0.04285839821902975, 0.05841642205092696, 0.019036179836539012, 0.10886364511304325, 0.05614422441970918, 0.04124150453736225, 0.132716397844976, 0.06830836000341563, 0.0825041990667101, 0.056729255123965205, 0.040537695730886156, 0.028662549579636227, 0.08055221469652268, 0.07877970940523571, 0.039441508180912466, 0.03696846144814645, 0.07269096515712238, 0.06652240220817827, 0.018911690548843434, 0.014206468533243866, 0.09311206533663696, 0.045370032800541776, 0.08165013360520525, 0.048318693729778456, 0.08546412531887332, 0.06457773397766775, 0.08833579824215944, 0.036554490516503016, 0.04124395218828032, 0.04187859474651275, 0.16988853142867166, 0.1903684518390125, 0.2824312448501587, 0.20027488800546817, 0.09375757102163569, 0.17778649956228273, 0.19860256403203935, 0.4152640574161084, 0.09765363373463193, 0.1726897625673202, 0.2025007258259481, 0.18609504485803266, 0.08850175586919631, 0.20330680353987604, 0.2174359010232072, 0.08021877492747961, 0.20862029745213448, 0.12000212686196451, 0.13766584677561639, 0.16191108933379575, 0.15189871852917058, 0.328341331332922, 0.18396521317622355, 0.4321320877680856, 0.11040800175960026, 0.40240395393583084, 0.06608824485973006, 0.213543530854006, 0.10292183652880693, 0.12643167298407326, 99.85992816186722, 158.33411278263216, 132.80662167456845, 124.18128259720342, 90.72445346463113, 78.37788335738644, 43.06753427751603, 36.91565359792402, 72.9106798479634, 89.90607446239841, 60.01694694642098, 66.01945984748103, 51.22599363327027, 42.57380985444592, 9.305582988646723, 0.7835020221048786, 0.3257428223807966, 0.5750683743146159, 0.3757218163340323, 0.554178504934234, 1.139665981454234, 7.100545129468364, 30.759805440902714, 6.961096044509643, 29.727268949631725, 92.86859358510664, 110.96453466723042, 104.95210601437478, 110.00599368926018, 116.13279081160023, 111.66411292168402, 111.74546287905787, 114.96227710477768, 120.61456157315163, 115.35103890203662, 107.28980725811375, 119.59137993474161, 110.85163316419049, 107.44292090016027, 107.23629828422301, 111.97823985930413, 89.66615092369818, 92.29660218761813, 88.33389436045002, 104.62089323228406, 119.77519789049704, 120.58668921070715, 107.7384558031636, 111.960801001518, 114.42583807053106, 117.74818758810721, 117.71528674710183, 123.72868814776022, 100.86831461998725, 51.619458352365804, 120.61954298327048, 110.16102929269115, 117.95739112361785, 120.86372621597783, 73.0745800079838, 106.60353368328464, 126.52067046011649, 101.22991008143272, 110.10002074703094, 116.34132754418158, 126.48547111019012, 105.7286568610899, 112.44679835534866, 125.63644270743094, 125.89202434785905, 117.46401971386327, 105.16880127691455, 99.63257189719909, 94.64993799886396, 88.27891842011483, 91.9253969192505, 96.79567060162945, 96.65286494839577, 88.15397524064588, 87.05151465631302, 86.78073775383734, 87.7518460058397, 89.70511574898997, 105.45467930455362, 109.33952808380128, 106.36862293366464, 127.7703768207181, 135.79096486491542, 44.34489334783247, 2.0231054603092136, 0.3006828606369034, 0.2796987624418351, 0.24964904022072595, 0.30544507767884965, 0.45912917943731435, 8.88675622401699, 33.82008375660066, 46.68694057772237, 48.3196859975015, 79.91746071846255, 94.4935844790551, 95.64472167722641, 57.9054880142212, 33.14913880440497, 20.78079954270394, 45.05537186899493, 65.4480097370763, 91.85294289742747, 100.29414238468294, 104.98528926603257, 127.29352643412929, 35.43115808117774, 1.0041950378687152, 0.3885799279857067, 0.1615395520122782, 0.19386881481735938, 0.18732312976592974, 0.11163791761763635, 0.24464817146860787, 0.23674612774723963, 0.14408325806500452, 0.15060361624965746, 0.35379196727468126, 0.1382403514317928, 0.22781614724907184, 0.18375443174473702, 0.11922401135727284, 0.17018560500394914, 0.21933515556156638, 0.16289479219384734, 0.11263320372710306, 0.1650598026331394, 0.23847468257431062, 0.2359270571821159, 0.16136586455808533, 0.15511608862828824, 0.15407721211592998, 0.20112530688845343, 0.24313566875794243, 0.18871422286235517, 0.28676108186764104, 0.14105710351178724, 0.140031510964036, 0.1562036423673553, 0.10654150237960201, 0.12632351669092334], [0.06260371308833843, 0.07805148154617318, 0.02449575139419927, 0.04786128561282831, 0.066039054354112, 0.059981064705718914, 0.021623689681291584, 0.033775276744798306, 0.02911616364614137, 0.07565695882564591, 0.03173817426056391, 0.06550383468669269, 0.07940629271850472, 0.05397693869928199, 0.04851522975631299, 0.0797109199207156, 0.06255610838472363, 0.059716415801836606, 0.06661711365825708, 0.05074199071274169, 0.0809734481416883, 0.056515574049685276, 0.054829533271972215, 0.10802532275838238, 0.11109292266830323, 0.067194000847878, 0.13818914611493388, 0.056125233100066264, 0.5614493534930292, 61.618705641838815, 115.51564508868803, 103.63455833927279, 99.63141087562808, 84.39622694446196, 45.077631319722826, 37.29544885696904, 43.47038522843392, 74.391813893472, 69.88188051408338, 31.203988367511382, 39.186662781623106, 27.259778438075898, 18.188059906805716, 0.38557548436426353, 0.13225369606046908, 0.033616106656770554, 0.2896777011694447, 0.35906519560563954, 0.04748335528758265, 0.46974899667886, 3.026233123194787, 5.720972034239001, 32.328957473078084, 101.82610250288441, 132.64776568258964, 114.21519894753735, 106.7416246475712, 102.96278184460056, 101.19492253949566, 104.08155164410992, 104.69415526236259, 104.84179327564856, 97.8816415417579, 100.01112768726965, 104.11031046221333, 109.40276453571936, 105.75678809996575, 101.87619116998489, 90.29824087696691, 87.65299443275698, 85.15930837200534, 79.88189266573998, 77.1345155469833, 91.21523611007198, 103.91214447636759, 103.2946300506592, 105.33973816902407, 104.62894193587765, 101.13668318717711, 108.67164258033999, 98.78864257566391, 100.19782466273155, 96.88663821066581, 118.19828741012083, 71.824049949646, 60.09888133695049, 81.93332364482265, 82.1430370884557, 72.02897810166883, 46.16160969580374, 116.99899135097381, 101.40855050856068, 102.90741366724815, 85.98425342190652, 101.18430860580938, 100.2414414190477, 112.84920215606691, 95.87800072085474, 106.40447339703961, 111.43710182559107, 103.23621811405306, 93.26322324814336, 90.28005676884806, 87.93418130566998, 85.9081986642653, 80.88659994063839, 86.07813927435106, 78.88718743478098, 86.85382719962828, 98.3001741286247, 99.21454137371433, 93.99463545891547, 87.30072636758128, 76.82869618938815, 79.93092229289394, 93.30949937143635, 96.1775678203952, 100.89636741145965, 116.09013111360612, 41.84780659214143, 0.9241517813455675, 0.017766220562700785, 0.06126717311300098, 0.0444921228523937, 0.06959765533646269, 0.4133869274970024, 0.9710842887720755, 14.40887781881517, 30.646578381138465, 30.503441287625222, 45.335021172800374, 90.83840616287725, 85.51074489470452, 39.723470518665934, 41.73001389349661, 20.68942008479949, 37.63818948499618, 50.54465440011794, 59.037032973381784, 83.68296746284732, 92.67627977555799, 102.32131742662, 39.91459585005238, 2.5785793892798887, 0.12894790409313095, 0.058453638602288506, 0.04499166963561889, 0.03178704875491319, 0.04322095315963511, 0.07095070450656837, 0.06715959583919856, 0.047606208977559884, 0.022100324689921354, 0.021704347248399453, 0.025475282905503147, 0.057421051671788584, 0.07145638382362743, 0.042622113720543926, 0.009784229820774449, 0.050671116088426886, 0.02410822007204256, 0.04264269850306934, 0.010878413093216237, 0.08175894107309081, 0.09284516030381765, 0.018465790987735795, 0.04468952455828267, 0.06418209936049196, 0.0535702609246777, 0.01933935913257301, 0.0763297142581113, 0.04888672877343432, 0.06602342616045667, 0.0477288979586334, 0.05054845775087034, 0.04022482542261001, 0.04483865889450235, 0.1016524671426704, 0.02177666977889115, 0.0026112705405290813, 0.016058126986477406, 0.032927814961200765, 0.06648885521797404, 0.04435354137733098, 0.011305778114605817, 0.03878597440498491, 0.04114004002223092, 0.031087478329878182, 0.050152466902809764, 0.03193233732975299, 0.04943199185354095, 0.06738533130696706, 0.1037542140411754, 0.07079584749355432, 0.0719648210572139, 0.031120286045235493, 0.09360960879994017, 0.03330183057715336, 0.20970359174234254, 0.03801035251648676, 0.18547550955366704, 0.04411698108719241, 0.15175486253874917, 0.025098068872466687, 0.2894597951202624, 72.48238840410787, 135.4165981661889, 117.8030066336355, 114.73685849097468, 97.08309404311642, 67.5303803720782, 62.109515743870894, 44.368502093899636, 37.095302074186264, 63.37198941938339, 39.899949719828946, 45.47634809247909, 36.09368562698364, 23.027146823944587, 0.7840530538270551, 0.27278598337884874, 0.033382645192285704, 0.06457751947304895, 0.2708523774579648, 0.2224730516994192, 0.4146027090328355, 0.9194468983238744, 8.690184681646286, 43.274709947647594, 112.61285581896382, 138.1586330167709, 118.35355835576212, 106.1355007848432, 108.07402241614558, 105.0351582804034, 107.43710010282456, 110.40458494617094, 109.44967608298026, 103.46963051826724, 104.3847430136896, 109.75223202859203, 112.88852783941455, 109.23306711258428, 104.99389494619062, 95.27816049514279, 93.29945810379522, 90.33012974646785, 84.23118929709159, 82.86434527366393, 97.12669510995188, 108.34693308799498, 108.75169815555697, 107.71023827214395, 109.56392688135948, 105.79633343604304, 111.9888694824711, 102.74990697060863, 105.17014272751348, 101.08897147640106, 120.53183094147714, 79.07990132608722, 67.335619003542, 90.9558968390188, 88.94264621119346, 78.38703032462828, 54.53757232235324, 120.60121766982542, 105.4786136073451, 109.31397776449882, 92.23178109815045, 106.23011619813981, 104.20121531332694, 117.23325883188556, 96.99342866097727, 106.47029861327141, 112.89388579706993, 107.75855402792655, 97.90555231032833, 95.69521042608446, 93.16965118531259, 91.90289035920175, 85.27641465587001, 89.6133715106595, 81.37459770325692, 89.91853975480603, 102.4690809557515, 104.02852904412055, 98.42412887081024, 90.99311228721373, 79.26459789276123, 82.10304460217877, 99.72391605377199, 102.03955788766186, 105.05466030490015, 124.45251449461907, 55.377289018323346, 2.3499463931206734, 0.28155453382961215, 0.16350623760973254, 0.12686631296791379, 0.02940126518238216, 0.3661585262706203, 1.3568232256558634, 17.118119693571522, 38.59900936003655, 32.78155780607654, 41.05251466074298, 76.61045551300049, 50.822056185814645, 13.997875202086664, 37.04234615448983, 35.389628025793264, 53.64970853251796, 58.85658041123421, 70.23857301281345, 93.98854009566769, 103.27260201977145, 120.75729662372221, 52.1187956871525, 2.225171140124721, 0.2434850201731728, 0.07092252779271334, 0.05243034124554646, 0.04367061612767078, 0.025889276819784316, 0.05111560413253404, 0.04068619421412868, 0.08106670402471097, 0.08400193926307463, 0.03258307156483493, 0.0720898159629395, 0.024844403754198746, 0.02537092257801804, 0.010187945707941489, 0.025059751069713986, 0.052082047031651584, 0.03854792407383362, 0.0994868285112804, 0.026460295775905255, 0.020520272176532496, 0.10358531463650927, 0.035768208514538505, 0.022039776930825847, 0.024433550800407128, 0.07937545001867317, 0.008324796893453647, 0.08966781063786439, 0.03162689232868293, 0.02249033430651311, 0.03984879499541656, 0.024014766921379396, 0.010354488434630537, 0.16800413899604352, 0.18800929939794928, 0.14823611345021956, 0.14746374360495998, 0.18180449282930744, 0.12492658600451485, 0.17823882851629488, 0.1803969901295439, 0.20483666580290566, 0.1927999383018863, 0.15992675307056597, 0.11454961863496613, 0.12416172382091323, 0.17381505379753728, 0.1536493060449439, 0.15897622181763574, 0.15872802465192734, 0.13098009020811127, 0.2322518116524143, 0.1769968467734514, 0.2791214692256143, 0.11563589300719962, 0.2931853113395553, 0.30072076666739683, 0.3181476734818951, 0.20599301423757307, 0.23466284356770978, 0.17682251580540212, 0.8807357400655748, 116.0968226771201, 152.35494582883774, 130.29930929983817, 129.41721531652635, 108.14904951280164, 65.79171919053601, 55.11009323981501, 60.73680385466545, 118.17005418962049, 96.59259380832796, 52.63759190036405, 63.69629098523048, 47.94680979944045, 31.878030030958115, 1.3674458621009704, 0.4169008195880921, 0.21757011962754114, 0.7485510072400494, 0.390607854651828, 0.4049990308140555, 1.0031799407255266, 5.88124204066492, 11.71741016449467, 39.67814753132482, 113.53229861105643, 145.47168823980516, 121.33386150483163, 111.53465901651691, 112.78289056593373, 111.02009111835112, 108.83669591719105, 115.05380953511884, 114.19219032410653, 107.3427906344014, 109.75671922006916, 116.78858757019044, 114.24411466044765, 114.34962641808295, 114.05397384397446, 101.35965424199259, 97.55674377564462, 96.22984517005183, 88.3415900507281, 87.0300514467301, 99.08967664164882, 113.68537302940123, 110.91971766564154, 111.96633938820132, 111.8280601501465, 109.73869200675719, 116.11886639748852, 109.6094891332811, 112.00872452028337, 108.4641021297824, 125.69264242725988, 83.79374304125386, 73.7887651689591, 102.41683498505624, 100.49715642006167, 89.55605783770162, 57.07940155459989, 126.55818400844451, 111.1039984610773, 113.41310562626009, 95.94602246438303, 111.04293500223469, 108.22398247257357, 121.47119152930476, 97.08041114191856, 108.47097412232431, 118.62540998766501, 112.48843823709797, 102.36522443832891, 101.0601185214135, 99.00188615245204, 98.2075434346353, 91.13221522300475, 93.68270504859187, 85.06004102768438, 95.90166830247449, 107.38390491854761, 108.53913707117881, 102.00176977342176, 94.08708572387697, 82.8654670715332, 87.19290041154431, 104.51025101446338, 108.12226756926506, 113.86601386531707, 130.60839991415702, 49.12557617310555, 2.3687884788359366, 0.19944509220940454, 0.2337460048616894, 0.17252182077255943, 0.15741139530174195, 0.5670196707210233, 2.965026988137153, 26.326377891725112, 54.18033069179904, 51.821770283483694, 64.95186913398005, 126.63642744864188, 126.56035700151999, 58.13490352322979, 58.80448741297568, 30.495161164191465, 55.41387688729071, 68.62624352978122, 83.17681697107132, 102.73974018712198, 108.23412572183918, 134.51326062602382, 75.70044209880214, 4.7578624756105485, 0.6635994560295536, 0.1813259483465264, 0.22133101378717732, 0.10153402994957664, 0.21885837308101116, 0.1247278091708018, 0.12211245394522145, 0.40512145166435554, 0.21629168742126037, 0.12056158555130805, 0.18698648008848393, 0.2150187863697929, 0.17308535504966013, 0.06450454959826124, 0.12670836095968563, 0.1415667358425356, 0.12729264089777587, 0.23133984526559231, 0.13617503967496658, 0.17492830212558472, 0.20002096050208618, 0.16044027712796965, 0.17007988487039843, 0.10501925503053974, 0.1513860371684836, 0.202369372390451, 0.2041432796226394, 0.18618322157811734, 0.126198215350028, 0.09395386573047408, 0.16967706051805329, 0.14537989252036618], [0.0549358586149831, 0.0338813339570357, 0.03881471036302467, 0.03567330554247864, 0.07771107037701915, 0.060929519860374357, 0.04562347766853148, 0.03180549423691006, 0.009953303510443339, 0.017559888186834512, 0.033192004212328506, 0.027489592358770392, 0.02574681510938512, 0.040057377754560405, 0.034042258386410056, 0.05415371731824933, 0.03610974966338085, 0.02498033264982364, 0.06439129115953561, 0.0501231219048702, 0.05482548066685277, 0.1263003731747308, 0.10143729602737774, 0.033040433716509617, 0.04065444370010688, 0.17068077359468709, 0.03229247909339686, 0.1951299487583099, 67.64808285620906, 126.29904085589995, 121.57933911969586, 105.40205678632184, 73.26364609502977, 58.802996912310206, 34.811356913658884, 28.375624110621793, 63.13934579972298, 103.4476887795233, 50.1792581619755, 46.09740834082327, 34.699181049100815, 12.127574374598842, 0.7883623290446498, 0.03481083992688406, 0.11788642184147913, 0.11847381975742118, 0.17799504401703037, 0.24863873878794335, 0.3497238871791671, 2.1376929696529143, 33.867850380559126, 103.28972708794379, 132.5605949278801, 108.84367773609777, 101.26490546811013, 110.69520119697818, 108.99940367667907, 103.13273814416702, 100.514508985704, 103.20939694681476, 95.37956945357784, 89.1439736273981, 89.24696722338277, 90.63521169847058, 93.2839882758356, 98.44964781115132, 109.17604369501915, 105.15493177598523, 98.59178666145571, 85.89712189089867, 82.17325502826323, 74.41063342555877, 79.9937508183141, 105.01469919758459, 107.46731019789173, 109.73852726720996, 103.86023582950716, 102.44739024869858, 98.13782722719255, 87.48022971614715, 90.96997814793741, 82.6244217349637, 88.54065033697313, 97.29108164387365, 103.84275774801932, 51.11111525566348, 75.60294766579905, 92.29410756018855, 41.84392736804101, 97.58682051012593, 113.61772783340948, 101.97721573614307, 97.9880319103118, 88.83811504610124, 91.74269291662401, 104.0467994443832, 106.23880817044167, 107.88175567503899, 96.54806706213184, 107.55597145326676, 101.0387808276761, 95.62678075605824, 88.1645970190725, 88.90650549242574, 84.94193846179594, 80.6518147068639, 82.02296549274077, 84.61561295293993, 96.1741396688646, 104.53907259048955, 106.9730366429975, 97.85025473563903, 92.3391285250264, 91.8678165251209, 83.54072663091844, 80.030942732288, 89.84615633564611, 101.01597616749426, 98.67858086862873, 91.42373361895162, 30.790325403213505, 1.2813923700201897, 0.12249368993986039, 0.02434142298185297, 0.12526493639715258, 0.05404809294568916, 0.3198083069535994, 0.09130725411758309, 5.089558199528725, 24.88077659760752, 28.849366018849036, 40.99832319444226, 56.991446325855875, 86.59576662125127, 47.440235691685835, 32.278590317695375, 19.350544521885535, 38.17032960153396, 52.13938420818698, 68.66997011246221, 76.58667026027557, 77.99897455400037, 94.36494642688383, 66.86975909817603, 7.212157643610432, 0.4718214483751405, 0.1219261183793987, 0.017120879586605776, 0.0239571207202971, 0.0766835089833025, 0.035785219496897155, 0.04553081550365014, 0.07808948716809673, 0.020732689205737367, 0.047389884899941184, 0.036188947832992965, 0.04232170000191658, 0.036033811197886546, 0.032592030963109385, 0.02754514522459959, 0.05400127731263638, 0.04461417981092969, 0.03619687684300927, 0.020726732872126084, 0.04468589330152158, 0.04318017812986528, 0.07311786765292769, 0.06786650347132837, 0.06013239771428128, 0.03419516187521719, 0.018805298173139175, 0.0777742036828591, 0.029003361029730692, 0.00978905904752713, 0.03592943554864295, 0.016893428081886906, 0.03877759340309328, 0.04129557119261834, 0.021920192521065477, 0.015590273260679698, 0.1201313429121529, 0.0420331644765552, 0.01888367854389212, 0.02493207294103359, 0.06470593879179609, 0.035530759562407775, 0.005995781393721701, 0.036570398332250696, 0.01808182005920718, 0.05961025133728982, 0.07619197931020491, 0.0040159188445672515, 0.02091188100166619, 0.0428383075632155, 0.024225035073956656, 0.013464792000670588, 0.027297120428674167, 0.11453087246345897, 0.021655166318880457, 0.11558219024370756, 0.024057166057548696, 0.17732111647004084, 0.057146661959949045, 0.2543824830002362, 80.16023189790788, 145.24500662280667, 130.44082841565532, 120.53819302589663, 85.33803509127709, 84.06854429552632, 52.48908312089982, 35.46737332497874, 38.90336567355741, 76.12509358313777, 53.98363167239774, 49.731774560866825, 47.357975744432025, 15.274741034353934, 0.4372285949366708, 0.09307547697737333, 0.08451510325915391, 0.1829424091885167, 0.4981092345570365, 0.34253761472721256, 0.22983624449660703, 2.3924369389011018, 43.877762594530665, 117.67785949091758, 139.1646738975279, 113.78147109862297, 102.55876202737133, 115.83600075014176, 113.31412853733187, 109.1911683544036, 106.32069941489928, 109.14718289529125, 98.28709694647021, 95.55914340480682, 92.98115776431177, 95.96584612323393, 97.20951203377017, 102.28030512409826, 110.32093647987612, 108.60076535132625, 103.60723510865243, 89.8348363753288, 87.51718628791072, 78.84428454983619, 85.8458015995641, 107.01600228586506, 111.41887064903014, 111.10243735774871, 107.29889931217318, 103.60022975552468, 99.85306401406565, 89.47253488725232, 93.8291585060858, 85.68474123554846, 92.03564690005396, 103.1695064421623, 106.3275557179605, 58.946390921069735, 81.71349833088537, 100.13034420628702, 51.79077179201188, 99.96169013361778, 114.61030713973508, 105.9657641380064, 101.66428904379569, 94.40071059811501, 96.9401393398162, 108.8580963688512, 111.22671373428838, 109.81038508876678, 98.88499167657669, 111.348189538525, 106.20597008735903, 98.76422189897107, 91.46844863891603, 91.61349004314792, 89.28822271285519, 85.79854488372804, 85.01114476111628, 88.96618043222736, 102.59544403322282, 108.27850341796876, 110.80973440600981, 105.95092973401471, 96.42121761075913, 97.66965312342491, 87.73620359359249, 82.472578940853, 91.82825549956291, 105.59044822569817, 104.40861455855831, 101.63771106350808, 40.27512050444081, 2.079401645929583, 0.5282687371776951, 0.16299527228599595, 0.15143791664271586, 0.0235534479255758, 0.5296969089296557, 0.14136588291054772, 5.520609521096753, 32.44157852665071, 36.09331300181728, 41.289798444317235, 56.45603887496456, 59.49491477781727, 25.76181938571315, 28.016280089655233, 30.915127377356256, 53.90074022354619, 65.5474731999059, 80.00205839833906, 89.66015754207488, 88.89094152758199, 110.03611749218358, 83.38136073081725, 11.293382337016444, 0.520290942682374, 0.059526946936403556, 0.03270186498881348, 0.05873474307478436, 0.03163783206424165, 0.04253358460001407, 0.0049002517217529885, 0.06462276462585696, 0.016202619787485852, 0.07816444887148757, 0.0455509789378172, 0.05152396347013213, 0.05742987317423667, 0.018806502846400105, 0.02902805204353025, 0.04392518714490918, 0.07247971641200204, 0.02746625349015719, 0.05041680937152236, 0.03377272184157083, 0.03657067412390344, 0.04237046532873665, 0.043856733358435096, 0.04918728804876728, 0.0518205697317758, 0.007115882378251803, 0.07167229804420663, 0.1303684915746412, 0.029748310672960458, 0.03387805510071978, 0.012372995092112933, 0.20558812144783237, 0.1327118166391888, 0.10032245423644783, 0.10673706164403308, 0.2539042296308664, 0.13658622970744488, 0.12492203544224463, 0.14718344735522426, 0.14436631223126767, 0.19858581735001457, 0.1799370309398059, 0.10330940807057966, 0.12919585611070358, 0.10743030992847298, 0.15502484755650645, 0.1549049088310811, 0.15830876005272712, 0.19374905995303587, 0.20778572126742334, 0.12333663946558392, 0.09272238705307247, 0.20185184935408257, 0.2296551566330656, 0.22646982433094134, 0.13537887513877886, 0.42016646854819795, 0.17012255596778086, 1.152811069642344, 121.98022104078724, 156.07889113887666, 149.25567719244188, 135.70409221033898, 98.98438453674318, 83.60017407325007, 52.15606997090002, 44.67914204443655, 96.60286257343908, 143.3580327803089, 75.12426945470995, 75.06964652769028, 59.68842098789831, 19.694712892655406, 1.3215022822541576, 0.12465205839684895, 0.3209077044119758, 0.2999969055095027, 0.6634945326274442, 0.9677442067092465, 1.0911569263665908, 6.779222113470878, 40.39775733024844, 123.75674878397297, 149.5874312616164, 118.10444862611833, 106.09026801201605, 120.4492493598692, 116.18679400413268, 116.4817483963505, 110.24614472543041, 116.68691189058366, 104.77103371773998, 102.42557402580016, 98.40319125883042, 101.13462002046647, 101.5664259079964, 110.61895032082836, 112.82860971266224, 112.46729666186918, 108.1215693873744, 96.19651286832749, 94.729107118422, 83.0640802075786, 88.99223281491189, 112.97901691928988, 114.4414883275186, 115.72751583591585, 112.73521023411905, 109.42745193358391, 103.90646488435807, 93.30190566278274, 101.32810269632648, 91.47637967140444, 94.32103941517492, 110.75317382812501, 106.85578130906629, 65.95156361979824, 89.06945643886444, 107.79446724922427, 59.48427338753978, 101.0521561099637, 122.72500853384696, 109.47061369496008, 107.05788535456504, 98.68197764119795, 103.38978675103958, 111.95179523960238, 117.47634380094468, 115.07977562565958, 101.358775631074, 117.41846530668198, 110.0165762439851, 103.7879857709331, 95.93917400606217, 96.96629370412519, 94.15391506687288, 89.54305125821023, 90.83702548857659, 95.5164993962934, 106.77574142333, 112.36341661022557, 115.67421867001443, 109.83243665387555, 102.08151940376528, 104.34402096656062, 92.54608846479847, 86.55243227558752, 98.87243224728493, 111.55909538269044, 109.76625842432823, 105.97382853108068, 38.66887853991601, 4.12380398281159, 0.9041121469870691, 0.17001429242232155, 0.4031961501365708, 0.18355497309277136, 0.7602480053901673, 0.3604884031078508, 8.962400113382648, 41.786915717586396, 52.55744218826295, 57.61724871973838, 83.0689125676309, 117.94033665810863, 70.84968613040063, 45.68541042266354, 28.85537312876794, 55.851283919426706, 71.95254679649108, 89.80594419663953, 99.8098865632088, 94.56887045214253, 117.80776054628434, 108.0103466587682, 19.065905963220906, 0.6393839070393194, 0.13023608093780856, 0.22048077876529387, 0.20435016932747058, 0.2493981157820071, 0.08877746325226561, 0.13448822131801036, 0.1937378444258244, 0.12083078118702098, 0.22902106565813865, 0.15112458668168516, 0.13662071898579597, 0.11427381166046667, 0.14671742074912594, 0.08837848466130034, 0.21455557896725594, 0.16291224367676244, 0.17424865956268004, 0.16792912366649798, 0.2449420734398788, 0.14173516793356788, 0.126813912553893, 0.14371481573870107, 0.14559387619937622, 0.17072313825689978, 0.139394799968408, 0.16656715723295368, 0.24023187376799124, 0.17952269994683806, 0.1945491621811544, 0.15351413749158382], [0.040405626003179825, 0.047827746283503315, 0.09079987408533212, 0.039082163148709846, 0.04523120617734329, 0.04998807209513841, 0.05669012335279296, 0.038813890648945686, 0.03927440525242879, 0.07650203807579894, 0.027880346995868513, 0.053945241811414885, 0.013789528053283933, 0.01236580535694356, 0.0696554107050742, 0.03669676453536076, 0.04458892189206616, 0.013449588028203337, 0.025309748542044434, 0.04333119704237869, 0.06611253750780899, 0.01438020003749238, 0.17727993158323152, 0.0847384408717194, 0.12310444587661375, 0.30821473067325933, 0.45544230469292213, 51.22870399105934, 123.76409146093555, 113.41662006993448, 103.70342731475831, 82.13013249058878, 72.05613659274194, 26.007389176276426, 39.81867820985856, 76.98851708442935, 82.31987322530439, 53.21833018333682, 40.9841908947114, 29.69344242926567, 7.723157165511963, 0.6516604966694309, 0.1402863884164441, 0.0954623234968993, 0.028750216851251263, 0.0342181062085494, 0.9133732919731449, 0.27247774024163524, 0.6713210707229953, 73.50242430163969, 130.81965092689762, 107.43290316674018, 94.4313286196801, 100.70745821922057, 108.53237490500175, 101.38405922920474, 104.33845120091593, 104.00894857222035, 102.23497036964663, 92.98320524154171, 88.9719698506017, 80.74418652442195, 80.9595246468821, 74.92604071094145, 85.55611887285787, 93.23019689129245, 106.7471238105528, 102.95506262010144, 97.26033810646304, 79.70877493581465, 77.2244005818521, 73.28022203137799, 85.00332355499269, 99.17889487358832, 103.74513779917072, 98.50059939968972, 97.1085423807944, 85.0136080095845, 88.39045493833481, 85.94158587917205, 88.77808709298411, 76.36323636577976, 84.22788666140649, 91.897979551746, 109.62459025844451, 73.8271337939847, 38.67253026654644, 56.11671855372768, 58.30039224316997, 107.15128483310824, 88.19896482652234, 104.04435188539567, 92.22522289522233, 93.61919403076173, 83.57644373370756, 95.85066964549404, 98.23346245673396, 102.38038047667473, 96.84470807352375, 96.72519345437327, 102.60465375838741, 96.22896655913323, 87.84863441221177, 85.90202485361408, 85.9827236975393, 80.65034774041946, 77.0278113888156, 88.76155038033762, 99.8666589490829, 105.40531235356485, 99.51419476539859, 108.766995399229, 104.29084147176435, 95.61408012144028, 92.52711203790481, 97.02783569212883, 89.0538610950593, 90.28856831212198, 101.04413094059115, 98.2831745762979, 68.44264522675546, 15.377675794786024, 0.9963474170334878, 0.4205748240553564, 0.03305000215468388, 0.1764279498808807, 0.15779172731263025, 0.0037670286086898663, 0.1196169761580325, 1.873659724670072, 21.835991644090225, 28.162515855604603, 52.88263805450932, 82.315197760059, 131.72806401406567, 75.38845677529612, 32.76285202272477, 13.280190306325114, 21.657512034139327, 35.234466906516786, 63.82346207095731, 81.6856102789602, 76.24343933597689, 86.01480868554886, 90.12353850949196, 18.724393037057695, 1.1218806067782066, 0.06188298523005459, 0.10457572076589831, 0.030128899323303374, 0.05299353844396049, 0.07945067985283752, 0.05233404782390403, 0.02394863438131588, 0.07432915225264526, 0.055525401577113144, 0.06551062222570181, 0.025448352999744878, 0.02760302316727898, 0.021115158601934393, 0.0016522357116393266, 0.05498514105115206, 0.022557979870227077, 0.02218043067372374, 0.017547492884219657, 0.08301079002839905, 0.025471498431157202, 0.04113119170670548, 0.036767926442647175, 0.03610579664969156, 0.060057160219237696, 0.018502488514528643, 0.02530397606953498, 0.024152735526102687, 0.03582484539478056, 0.013223390034850568, 0.06170561672338556, 0.038965901645321044, 0.02127579191789752, 0.03219489098316239, 0.06419701126193808, 0.03263826436933971, 0.03643151425245789, 0.036106673820364865, 0.029333426181467313, 0.08270886711656086, 0.04601605942532901, 0.0045995133733677295, 0.04716075566266814, 0.06052114903145741, 0.03876359697671668, 0.030488705923480373, 0.12409020951318166, 0.0516572589385173, 0.025812198798502647, 0.04007063490609008, 0.02316116302784893, 0.03369694425454063, 0.031369142046558766, 0.11241669961882216, 0.12446831986908952, 0.2334023378188572, 0.44128205807458976, 69.96487786692958, 150.69870148935627, 121.1629089232414, 128.91877620450913, 91.84996974083685, 96.29576452316778, 42.53941851277506, 28.905471601793845, 19.630825327288722, 56.13387892323156, 53.24814019664642, 43.62423627607284, 41.99651541248445, 11.052128134235259, 0.5719077406871704, 0.09708190231674141, 0.11120998856401253, 0.1789362136755259, 0.5644032046679528, 2.7857057846361593, 0.3310804940279453, 2.9179448177737575, 83.54360565062493, 139.25501392733668, 111.53409419521209, 100.88933067937052, 106.64410668034708, 113.88359392842939, 104.12110482492756, 109.88713018355831, 107.21103037557295, 107.21559601445352, 94.47984833871165, 93.41730963799262, 83.26550176066738, 86.13901445942541, 79.63363801279377, 93.33283747396162, 97.94591349940147, 108.67547081362818, 105.46577176740094, 103.21006374974405, 83.88796621753325, 80.35251432849516, 75.93463897705078, 89.97311561338364, 104.92306478561895, 108.12637036846532, 100.85024033823322, 103.5512471968128, 85.52343768458213, 91.11597661049136, 90.57578779036, 94.06177074678483, 79.74651598161267, 88.01462911790418, 95.79932581993842, 114.1272201845723, 78.95559357058617, 47.74358003370224, 63.82938877228768, 64.16831293413716, 111.98829681642594, 93.77135845922655, 107.09018215056389, 96.67461056863108, 98.13474424423711, 86.71386134239935, 98.0884288972424, 103.46391954729634, 105.8908547124555, 99.5487508466167, 96.87914648363667, 105.05360126495363, 97.98324661870157, 91.2614808544036, 91.3970850360009, 90.78261436954622, 84.69943400352233, 79.82504967720278, 92.06948126516035, 104.83863184528967, 110.27324830332111, 102.84959793090822, 108.96093307002899, 109.42731072825771, 99.63386627935596, 98.0315702192245, 100.86276054382326, 94.2141862069407, 94.8976121410247, 105.47237703877111, 104.36764932447865, 77.62667102198448, 20.55479257337509, 1.1258645091326007, 1.126387042383994, 0.07857157097708795, 0.2773452484078946, 0.08811311946520883, 0.043486958039143396, 0.15838873963202202, 1.7658718891682166, 25.333457339194513, 35.141122341156006, 40.45925224981001, 94.3909203621649, 121.87463868048884, 32.664275015554125, 26.81523661459646, 31.275601040932443, 46.59599650290705, 49.39749448530136, 72.75797413241479, 94.22151319442257, 85.87313267492479, 98.46001071314659, 109.44833463238133, 25.747006554757398, 1.0276760617571494, 0.09362843158023973, 0.11142816274396836, 0.06462952918222835, 0.06156984679100495, 0.08274798356597463, 0.03303176160120676, 0.06235820489124425, 0.09014869168881448, 0.052398552427128445, 0.014316344693783793, 0.05353295244276524, 0.027145795080991044, 0.0631564302039483, 0.012703670241359263, 0.06489235096641126, 0.0272230856916717, 0.052030144574781584, 0.03662123209646633, 0.14633252285420895, 0.0661470650905563, 0.04775441251695157, 0.04553057035551437, 0.09083696806262578, 0.06357713121800654, 0.006765302349512856, 0.01047959442310516, 0.0074319357818533344, 0.0277069027745916, 0.04791920952078316, 0.17942450279670377, 0.17926943127907094, 0.19530098554828476, 0.1820069392241778, 0.2662961154935822, 0.10684626747763927, 0.13439894143131473, 0.07557515595709124, 0.13269356842483246, 0.23066636204959887, 0.19002268571526776, 0.15969108910329882, 0.11831784425603768, 0.10274055714328444, 0.16601768833014274, 0.13725641874536393, 0.20341770242779486, 0.1286280164194684, 0.23607278242707255, 0.14767951992971284, 0.21148324463396304, 0.1776535679856616, 0.2413964959522409, 0.25841258045646454, 0.30239797828178255, 0.38184678121920557, 0.43202308877821893, 100.35504894871866, 167.66254455812518, 133.97139303145872, 136.66504152359502, 104.15391937378915, 101.47203799216979, 39.68716898272115, 64.14866185957386, 110.31996373207339, 118.69609894291048, 81.15287396215624, 62.45681808840845, 50.6627961897081, 14.479099031417602, 0.8283846621071139, 0.2958894178511635, 0.29433539317500207, 0.5800611225347365, 0.20675187029184836, 2.534072990379026, 1.5958502576235802, 3.0441463426236184, 82.26614459868401, 147.44300873048846, 119.76825529529204, 102.7234152824648, 109.0390980628229, 120.2213361186366, 108.82117902078937, 115.43016095315258, 112.7462556285243, 111.36602063332836, 100.27072583475422, 98.08924475023824, 88.07538663187336, 89.77881708452779, 85.24955426493, 98.4018341187508, 102.35074304765271, 115.11666943950038, 110.63145483693769, 109.70721890849453, 89.40936903799735, 85.38332277728666, 82.28130848177018, 93.31047211923908, 110.01348541628931, 110.87217069441273, 105.33857714745307, 109.69130977507561, 92.16279445155975, 97.2129794090025, 94.61021223375874, 98.93505680945613, 84.53530634603193, 95.18004632765248, 98.5397917224515, 121.63916310956402, 81.2949892782396, 55.30223446507608, 74.51539993286133, 65.77826938321515, 119.1716863263038, 97.91376575346916, 114.24268691770493, 102.30438063221594, 102.93383475272887, 90.01496730312225, 105.74507590263121, 108.4993956165929, 110.82941685953449, 101.22958844707858, 101.62085271650746, 109.14337035148375, 103.42374663199149, 97.78439029570549, 96.29760019240841, 96.07181287580921, 90.43291153446322, 84.26171318177255, 94.27300607004474, 109.92829938088695, 117.3325732446486, 108.77589133477981, 113.26254936956592, 113.05422444497387, 101.6566090429983, 102.17331071053783, 106.76656307712679, 97.72078514099123, 101.06944591768327, 111.74458426813926, 107.57539503036007, 80.17349735383065, 20.77265670222621, 3.2811533539525928, 1.2607978428563764, 0.10288695654561443, 0.5785504584350895, 0.27279015089715686, 0.19043946818959331, 0.2356890949510759, 3.3060103943271026, 34.38329296727335, 50.49573852169899, 73.72173970745456, 94.17111073770832, 155.31606858776462, 103.48785385008782, 48.9217423623608, 23.29775702568793, 37.73040048537716, 52.37557365048317, 83.20785860861503, 105.63131147815336, 96.98597615764987, 103.0550830594955, 123.29212834758144, 35.545267674230764, 1.3487653290071797, 0.2279691043640337, 0.1555889793821881, 0.22274056960257793, 0.15567950033132108, 0.1307910809954328, 0.17133004843227326, 0.15882882650100416, 0.22648421146215933, 0.2722185267315757, 0.11978649609391728, 0.22140009959618892, 0.16474216725797425, 0.22186546736667234, 0.09979577644938424, 0.14673268122057762, 0.07626350127881573, 0.06539817584017593, 0.1457768946044868, 0.22274778615082466, 0.14016690934377332, 0.12494766108331182, 0.1759062440044457, 0.1800247633288945, 0.16722208579942105, 0.09310332427342093, 0.12528785774784704, 0.08455984279393189, 0.13522090780879223, 0.1195764577677173], [0.02421772084949959, 0.04332797947309671, 0.018666904389617905, 0.050941411060311144, 0.06750196819343875, 0.03979512287544147, 0.022599373515995762, 0.09472398327723627, 0.037739977105370456, 0.06706607948628164, 0.05427167187595079, 0.03840940005536522, 0.05384258219912168, 0.04447091370821, 0.1018283992344814, 0.14476205793119248, 0.023325337585242047, 0.03690653473078724, 0.06205614791401933, 0.11942802823238796, 0.04623254438141181, 0.02396299661467633, 0.13293289429237767, 0.21066244271013046, 0.06931060985211404, 0.5028223913283117, 40.09255770714053, 119.41208839416505, 111.76216433125158, 93.34826023347917, 56.358336556342344, 70.57986628624701, 30.41268352539309, 35.69352149963379, 59.4399506045926, 91.70736805085214, 57.300627154688684, 48.361631824124245, 30.668129844050256, 5.319135016010654, 0.5213399315553328, 0.2959089377714742, 0.21503285174408268, 0.011503907604022853, 0.07808168839302757, 3.5779230681157883, 1.2438925499877622, 0.9231144982960917, 87.05611951889531, 126.67896947553082, 93.87129260647683, 101.50435832238968, 101.59580446058705, 95.15928914470058, 88.62353786345452, 97.95582140645674, 94.03774230710923, 94.1430030330535, 91.06839826030117, 87.35570230791646, 78.58736145880916, 76.86241288338938, 77.97111788103658, 77.18890313179263, 74.97649808083811, 87.47901378139373, 101.2262858113935, 104.2186463263727, 98.19904758084206, 81.87262104403588, 72.96058808603595, 73.87435128611904, 90.32196337176909, 103.97199984519713, 101.61075653568392, 102.98628468667309, 89.7704702808011, 77.7427339553833, 83.46276560137349, 95.55973960507302, 95.68600070091986, 90.10446794571416, 77.98763890420237, 89.24070712058776, 92.79134642693305, 114.74513469203826, 45.36861235095609, 25.063662990447014, 95.68203910704582, 96.66185502083071, 99.95537511764034, 85.21708488464357, 85.89525484269666, 81.91846570660992, 85.72814618387531, 83.61756586259412, 95.71359849745228, 100.35080494419222, 101.81627304323258, 92.0665002638294, 95.05539340357628, 94.00030720618464, 90.36932206922963, 85.88423298251244, 84.84794278298655, 79.28602972338277, 76.1430109700849, 91.3494517726283, 100.82979694489511, 100.34740817162299, 98.47144049982872, 98.0890957001717, 100.98000803301412, 102.94986155725296, 104.60296800059658, 98.41871599997245, 99.9789877860777, 98.82026472399312, 95.06377943100469, 105.6045138451361, 89.00693385831772, 40.124211234431115, 3.0901687375960813, 0.6942356798437335, 0.6577546954635651, 0.056742198179445924, 0.2616567176676566, 0.018895053034347874, 0.04136220168983264, 0.15845181931170726, 0.6521325294048556, 18.431268430525257, 26.386154813151208, 39.460522667054214, 27.67632434445043, 72.33243619242023, 70.2952669512841, 30.412277560080256, 18.83769069948504, 16.689434051513672, 38.72764348983765, 55.05706671745547, 89.24294287158598, 83.41881152122252, 86.671264402328, 90.86867901586717, 11.010027373990706, 0.46768028349165, 0.08495731985256558, 0.0896124914288521, 0.08400252148989709, 0.10070525305045229, 0.013103003147989513, 0.05824546186974453, 0.030177812122048873, 0.026372270358185616, 0.01809632976449305, 0.015924615098253613, 0.019381128161424593, 0.02141336790255962, 0.017871438908661087, 0.027936464851541866, 0.06029722536162985, 0.06258544955222357, 0.07005232851952314, 0.03394896036855156, 0.05425792059770996, 0.023641994283083948, 0.09762757908432715, 0.05877969328374152, 0.06035965386657946, 0.07499308235222295, 0.11466776471464865, 0.061043138360424395, 0.025676585914146517, 0.059939029461313645, 0.02797596051447815, 0.013778570123137006, 0.030426375094741106, 0.07483123861733945, 0.04922129469172609, 0.025531542487442497, 0.019360600835493496, 0.03333610152044604, 0.07857845810752723, 0.10536759520971006, 0.05883370248240329, 0.05070282829805248, 0.03022839307724949, 0.02180816939911775, 0.01996662809453424, 0.07097678213951088, 0.006666303679887807, 0.02380481669529071, 0.04613097644441071, 0.07739670619729065, 0.05585131453230016, 0.062178204872555314, 0.10941143628330001, 0.06688719795596215, 0.17342828664808504, 0.3544398631540037, 51.1559832480646, 142.1607057509884, 119.02549174524124, 116.3643910807948, 79.99268393362723, 103.8349522313764, 52.402555634898526, 38.119028922050234, 29.408040969602524, 86.25357904741841, 49.963221857624674, 52.14188275798675, 42.403249509872936, 8.812600874131727, 0.7063891438226546, 0.07984931370423687, 0.10015291897880454, 0.20151516903311978, 0.16076842322945595, 8.878549645023963, 0.9869901739781903, 2.7110402814803587, 98.22167965673633, 133.57925015111124, 96.74702536675238, 106.65406165584442, 106.06921272893106, 99.07778401528635, 92.5802287747783, 101.93980416943951, 97.76144443019744, 100.36753777534732, 94.05169810018232, 90.31307528095861, 81.45255088806152, 82.44368676216372, 81.48807187234202, 81.44840102041923, 77.97576981206095, 95.84338188171388, 104.22617727710356, 109.2262343437441, 101.90280837397422, 86.15388024237849, 77.3868808438701, 76.07545206623693, 96.35890683820172, 109.44229418231596, 103.95821663641162, 106.47956325161843, 94.90333880147627, 80.49757142220774, 85.23128386466735, 99.81644476613691, 99.16179333963703, 93.23439382737683, 80.02666734880017, 92.60357472204393, 95.14196011327928, 117.10384415042017, 51.705511231576246, 29.75787324290122, 100.08300119830717, 99.15367403338033, 104.64974618727162, 89.08362403992685, 89.20059696320565, 85.43027354824929, 87.5782262125323, 87.15503384990078, 100.10992434716995, 104.4981622695923, 104.78043171667285, 95.09368358119842, 101.47486209869386, 101.28581954586892, 94.14292458565005, 91.20409657878261, 87.73391292941186, 84.43044570184524, 81.33003957809942, 95.69153908760318, 103.94455109873127, 104.47032913084954, 101.79358605415591, 100.86986787857549, 99.50881327352216, 107.72672007160803, 107.93233856078118, 102.08655572706654, 103.19133835454141, 104.00190399539088, 98.31244330252372, 107.20334253003521, 92.57262722138437, 46.366608450489665, 4.359213854036024, 1.619881148780546, 1.6116813113612514, 0.23688299701579157, 0.4880987942939805, 0.14898933109737214, 0.11985558956380814, 0.21521847484813583, 0.5877835339596195, 21.22170336784855, 34.77667531659527, 42.30213865157097, 45.34962415695191, 73.46950777115362, 45.646029826133486, 17.755997104029504, 26.36171648579259, 36.161158238687825, 66.16016311030235, 70.51247996668663, 95.98803889366889, 95.78857068092593, 92.38209416789394, 114.29484659625639, 18.431095846237675, 0.5603952165092192, 0.12098030622808204, 0.01592655042787233, 0.0969427501061751, 0.04051564388998574, 0.06559955737283153, 0.05859721114017791, 0.025014864063010584, 0.027162218090867805, 0.07622950229673617, 0.07929697963258914, 0.031892594603461125, 0.12829110627212834, 0.0033718569959033163, 0.02617294385638689, 0.04901493741800228, 0.019328934591143362, 0.04617603007523764, 0.0419816910289228, 0.02887044477486803, 0.01316473738575775, 0.0342091238276372, 0.060649821159219554, 0.018312358898260904, 0.034015307413233865, 0.09963891994688781, 0.07071742307274573, 0.04021149166228791, 0.05016205066274251, 0.14817425951121316, 0.1306697939552607, 0.14295376867296236, 0.19739911651178715, 0.182779707435158, 0.12309248724411573, 0.11060847930850522, 0.19635271701601245, 0.2911724306402668, 0.2715291701737912, 0.16763422578092546, 0.21011127309212763, 0.0968535851326681, 0.15636076700062523, 0.1800143445331243, 0.30094305473950606, 0.17642119298538855, 0.13141821589200728, 0.1612743476946508, 0.24622960677070005, 0.09723203256726266, 0.18374217433794854, 0.3106563754620091, 0.26486947591747007, 0.3084561096564416, 0.32029939995658013, 75.05481212369858, 162.9278358336418, 132.99054945668868, 129.28348602787142, 74.70773727663102, 103.2298638743739, 47.622210133460264, 59.03112588390228, 91.4907512357158, 130.8128652264995, 84.18552506354548, 73.50262826488864, 54.37520580907022, 11.192545064034002, 0.9352251839253211, 0.7719109892364472, 0.4069074171204721, 0.20626509802476053, 0.22133132022234703, 5.379300742380081, 3.4387733090308408, 2.6647913696304446, 99.32702710551601, 140.1100435564595, 101.76633342619866, 108.15584305794009, 111.28569833693966, 105.37962082893618, 98.19041836646296, 107.99200565584245, 103.05303558226555, 103.52121753077354, 99.28106477183681, 96.30282478947794, 86.30634277097641, 87.0022653764294, 87.0858040163594, 89.00985994646626, 83.09990713673254, 98.42073209824102, 109.60126784539993, 111.27179745704898, 107.22632761924498, 91.28477973322715, 82.11074029245685, 81.71193722755679, 100.95046474087624, 113.21399827157299, 107.97443343747048, 114.56158345745457, 97.1043925131521, 88.03602956956433, 88.60110975080921, 102.77227232533117, 103.55519310120614, 98.17582714942195, 85.46016200896233, 98.27911100079938, 101.30763576876734, 122.37670206254529, 55.83626516403691, 39.92773579012963, 103.40200885649651, 107.1188154528218, 108.58669188714798, 94.50714019037063, 95.03903711995771, 91.04493464193037, 92.80350577446723, 91.94905665612991, 105.84781062218451, 113.40766922120126, 109.8072079689272, 99.40429779791064, 105.2638481509301, 107.65182633553783, 99.15052044776179, 96.25098674528061, 91.68451632222822, 89.7783620895878, 86.3013848950786, 103.26244308102517, 108.07051581721153, 109.75004334603588, 104.80023968604304, 105.29186171870079, 105.88305704055294, 113.40810852666056, 113.5019394659227, 107.18704900433941, 107.59929795419018, 106.98259153673726, 102.44858264923097, 116.60222791856336, 98.45840254137593, 48.12678775479717, 5.496458017056988, 3.6311552697612397, 2.5420079452376214, 0.1770177150085088, 0.532076255448403, 0.3060826160494359, 0.3170748439527327, 0.48455036695926423, 1.4619436042924083, 30.503696241686423, 46.457799634625836, 57.84837045977193, 42.16897418422084, 94.76208640683083, 98.72558655277376, 44.233631395524554, 27.072987325729866, 27.817068792158558, 56.348275676850356, 72.7711925198955, 110.81659855381136, 110.04103614437966, 101.5331014510124, 127.83371525426065, 26.751678528324252, 0.7892647806194522, 0.2094719267540401, 0.2096041688515294, 0.2899815622837313, 0.14506357481643078, 0.14521150639460934, 0.17557739310206907, 0.10322527629473519, 0.11587354880306991, 0.1074723911381537, 0.14087069899805132, 0.16294204449701696, 0.24212818652872117, 0.10967375244945289, 0.15465456661918472, 0.20606185489844894, 0.1726216267073347, 0.29541940758785895, 0.11782769354120379, 0.1991838562272249, 0.11094660753564489, 0.17669280179806296, 0.12048762742309801, 0.12683493400653525, 0.23392986596351673, 0.15081430575059307, 0.2942678855071145, 0.10189498759685986, 0.177591897907757], [0.023916351436186704, 0.08581766723504952, 0.05327772258991196, 0.061854505911469466, 0.05737633128920871, 0.022581600276152455, 0.07352883551990794, 0.02781994862391824, 0.0660950017552222, 0.012102181095659975, 0.005876851989136588, 0.07288323024347906, 0.05592285182266947, 0.0489653485466636, 0.03360914674797847, 0.020502378277841116, 0.07140748443142061, 0.11780239731794405, 0.06571352827332674, 0.04835516334541383, 0.11488555585064235, 0.0037218011716651104, 0.20086695139686908, 0.17993093287992865, 0.35575784081893586, 33.73429367619176, 116.63663494971492, 109.37623362387382, 98.23773784022178, 88.24538999988188, 60.50900436216786, 17.167290526051676, 32.2033808308263, 58.1849019758163, 62.4093181856217, 35.27179610344672, 43.44452504188784, 28.149089582504768, 3.773805008780572, 0.5641566469304024, 0.20212178809508202, 0.30664446493310316, 0.07929401487232217, 0.2802707236861029, 1.3521796296681128, 11.346753047358606, 1.2054756307794203, 76.476804671749, 126.47717921964585, 94.81182990535613, 109.08833949796616, 88.93814333023565, 88.9635524442119, 89.1241656580279, 93.31816780951716, 88.76870478353193, 91.9007016766456, 86.53920604336648, 82.05767846876576, 78.29241491133168, 80.09229644652336, 80.0510331123106, 74.83532413359612, 73.58639440228863, 70.59525766680318, 81.24042126440233, 96.29960844593664, 98.32389662342688, 94.07110598779495, 78.07161684959166, 70.80133899565666, 74.54859102925947, 93.45959278845018, 97.09115059145036, 94.10745851455196, 98.0527667076357, 77.67269611358643, 77.03641706897368, 93.93304640246977, 97.56871484941053, 101.80042666773643, 85.6352723029352, 77.11428396163448, 89.34734852083268, 88.04624342149305, 100.3921231915874, 76.50357092580488, 22.710070263954904, 103.48238606606762, 81.87664539583268, 94.76638532453968, 88.72731593347366, 100.48859780834567, 89.42651764039071, 90.19829104023596, 78.4860231030372, 84.54591243497788, 92.52013021899809, 101.22434031578803, 94.92510795593263, 91.92079205666819, 92.97725892836048, 93.38447155491, 85.0334159789547, 83.09782828054121, 75.70690616484612, 76.30069809575235, 83.88003518504482, 95.45828357819589, 97.21938071712371, 99.10680170982116, 101.00318139599216, 99.8078312412385, 92.57559253323464, 97.82358261846728, 101.01574867002427, 97.60275317776589, 95.427579264487, 102.44007110595705, 90.83643713305074, 94.70057579778856, 70.65945117704331, 16.882314643552228, 0.9434461653713258, 1.4293203935507806, 0.2710369127171655, 0.1940554338357141, 0.03126837275621872, 0.22379898135700535, 0.03717928884490844, 0.11113141858649832, 0.5929286417461211, 15.563201942751485, 38.44813539135841, 65.54410780629804, 21.911838516112297, 80.27212142944336, 96.39909544298726, 56.43667413342384, 26.15245999828462, 13.265636351800735, 20.881790768715646, 46.12957177623626, 68.18817753945628, 88.72735515717538, 81.0754777539161, 87.80641401967695, 6.014993882948353, 0.3589492711809374, 0.07409492853067576, 0.061013912106113094, 0.07768943605403747, 0.030121328459391673, 0.044908537604515596, 0.03520642857878439, 0.05382049588426467, 0.018292804503993645, 0.008307490009634245, 0.03143328084279934, 0.0510572703675397, 0.0833582568673357, 0.03245269489144126, 0.016539704219828692, 0.05635358092765655, 0.05284469905159166, 0.0901224225338909, 0.024685415612053008, 0.0311558669988787, 0.06079964880501071, 0.014174869321587106, 0.03351889009917936, 0.09009678923194447, 0.031143266767744097, 0.04311075524216698, 0.03862527597154822, 0.09868759196251632, 0.035421779724739255, 0.06433391883488625, 0.04037461093356533, 0.0399923560419871, 0.037521527133761876, 0.05704903171487874, 0.038647465708275, 0.027402038085124186, 0.008848255196015441, 0.05563560715546051, 0.022754115615821174, 0.012617592602187108, 0.07444317677929517, 0.027524340191795945, 0.02884678797976625, 0.030184699252488154, 0.0655936968002108, 0.06716473628917048, 0.03435270785684547, 0.04986151053960766, 0.026834140937294693, 0.013896288151191849, 0.22715605524999483, 0.28416499375335635, 0.41427935864175525, 44.89690419166319, 142.3836689610635, 117.12683708437028, 119.39753640082576, 94.71561416502922, 73.44133730857604, 45.14474307337115, 35.05324948218561, 33.3934397082175, 69.64043509575629, 42.92630933946179, 51.21428928067608, 40.682501792907715, 5.313690766211479, 0.6944457105090541, 0.10501107321150842, 0.2737382613122463, 0.0683990954571674, 2.0709026052105814, 4.300494501667639, 1.9945031692904813, 2.1646867211787932, 87.86749316800027, 128.70280265808105, 100.6103717127154, 116.3433671766712, 93.48631981880435, 93.88342057504963, 93.51170539855958, 99.12162042433216, 92.32161121983683, 95.44723033905031, 90.27436148735785, 84.97587480852681, 83.25336594735423, 84.50062474896832, 84.2810583114624, 81.79035325204173, 77.86197400862171, 74.38007031717609, 85.23778715441304, 101.79277804590042, 100.65607516996323, 99.53376739255845, 81.90252519422963, 73.19493401435115, 77.78876689172561, 98.12793500961797, 103.90838684574251, 101.4311747397146, 101.44647198338663, 79.3968915939331, 79.93913573603477, 97.54984824888169, 99.83433861886301, 106.74462133838286, 91.48866453478414, 82.9667034456807, 92.31431561131632, 94.9617507380824, 104.98572857149186, 80.96411381998371, 25.257579088211063, 105.08317593605288, 89.50778130562075, 96.37749887281849, 93.95939688528739, 105.88434357796947, 95.65928151530605, 94.76694230110415, 81.90342733936926, 86.18446688498221, 95.8619660715903, 104.24611860705961, 95.89275667744299, 95.40597484957789, 96.05897103586506, 96.51890031753048, 89.17925926946825, 86.11300914518296, 80.23274083291331, 80.54341608478178, 87.82242513472035, 97.95912404214182, 98.47425676161244, 100.18826976899179, 103.79996468943935, 103.18816907944219, 95.85447434456118, 98.54944859781574, 103.58570914114676, 100.74159068446006, 96.44500286348405, 105.24358518661992, 93.41813333572881, 95.03482449439265, 77.60575694422569, 21.361337784797918, 0.8742945953722924, 1.4121122201604228, 1.1125089612699326, 0.6358663990132271, 0.09010176114257305, 0.20306807522091175, 0.04519922200650458, 0.1367676393279145, 0.4537545210651813, 17.8610558279099, 39.99540059797226, 29.94023599932271, 27.85413322910186, 66.45175210891232, 59.43382386238345, 37.77286406486265, 21.745781052497126, 26.3971786345205, 42.297996628669004, 69.31075988277313, 76.61847283763271, 100.83218959070022, 86.84418601374473, 113.9524942828763, 10.775132313851389, 0.4944125232436965, 0.08494498583698466, 0.05368205996590757, 0.06676001969965235, 0.052806858138571826, 0.06411711595231487, 0.013993161884436925, 0.037107514067282604, 0.014497751441423692, 0.03187115754811995, 0.03989518928011099, 0.026520768841428143, 0.0231948402530003, 0.015007577209372916, 0.03811251417162918, 0.01951176338949271, 0.07973948733941202, 0.028136392732361154, 0.06377595018655544, 0.019190927682023858, 0.02474884577696362, 0.053560654182107224, 0.026193090053575657, 0.03937562461942434, 0.038450412572391575, 0.013976365406697076, 0.08203258001876455, 0.020287590206510598, 0.08842595912996801, 0.2300149574875832, 0.1588765997439623, 0.3099861098152976, 0.1274674698229759, 0.15733847905310894, 0.21723406749867627, 0.11721529817629246, 0.2036387187939498, 0.16876578361036318, 0.07908103476849296, 0.24892916272003807, 0.11300873236670611, 0.18336962578037094, 0.17413261256391005, 0.20978792270104732, 0.15392774836190287, 0.2137894603994585, 0.16508209579173597, 0.2202558859942421, 0.2741017547105589, 0.11272555562637507, 0.462215134813901, 0.39657377968392066, 0.6150655184061297, 60.34294689855268, 159.56044966174713, 134.89523672288465, 129.75042850740496, 110.19851930679815, 80.79283960403936, 26.21386666451731, 55.47445004986179, 92.4619536246023, 89.80320638225925, 54.41925402610533, 67.94867761673467, 51.74377395260719, 8.367116701218391, 1.257218680074138, 0.5346981760474944, 0.49090650653646845, 0.3342304637114848, 0.9673433895072631, 3.003205868505663, 22.71895835476537, 4.945269400073636, 86.11915942161315, 136.8351782521894, 104.21863063689202, 119.71976695522186, 99.02377297801357, 96.95895887190296, 96.22905285127702, 105.45709548457977, 99.46849130815076, 101.45661523265224, 95.40412349085655, 91.11667479238203, 86.5270466958323, 90.95435142517091, 88.98274067909487, 84.79378269564721, 83.16275919637373, 79.22305999263641, 90.45733221115606, 108.52112554734754, 106.73404662839829, 105.8417623273788, 87.53955164263326, 78.57287222339262, 82.39676737016248, 100.91395531931232, 105.0719814915811, 105.6586660877351, 107.96290166916387, 86.11385637714018, 86.8326150217364, 104.37245030556957, 103.45441172199865, 108.27777385711671, 94.40377789158975, 86.12190508073377, 97.39398894771453, 101.87196285493913, 107.68524492940595, 84.27404511359431, 30.764729976654056, 110.88793862250544, 92.01663909419891, 104.74363988445651, 99.45997976487683, 111.54042490067022, 99.58220866418655, 100.90923278562485, 85.88570779369724, 90.57006112990841, 100.59439197663339, 108.24801091224917, 99.13906712685862, 98.45068331687682, 100.31358165125694, 103.68631009132632, 94.70559643160914, 93.11812693072905, 86.43560055763491, 84.78699699524911, 93.5286892614057, 103.62053978827693, 106.73729435090097, 110.4466719781199, 109.94178448953937, 108.79104737312564, 97.40511278952323, 102.55846392723822, 109.76423448131932, 102.3783173099641, 100.71753086582308, 109.0774666878485, 97.18715452378797, 101.11013658585088, 82.82908316581481, 21.369296273877545, 3.525463328246148, 4.996143031504847, 2.298755785149913, 0.6143958349862407, 0.16883822488448313, 0.44315805418356774, 0.18700466701580634, 0.3058010940590213, 1.4188235180993236, 27.470348919591597, 61.92841991301506, 92.30001464966806, 34.11508521726055, 100.01724658473846, 131.01253740249143, 83.37828559260215, 35.91143269692698, 23.42671278984316, 34.05511217732584, 66.44442512143043, 81.78779586668938, 113.21519851684572, 95.40919119311918, 125.81964877343948, 13.518848880644768, 0.7404302913815745, 0.2128856298663924, 0.3835419192910195, 0.20065382573633425, 0.14315031619081575, 0.15665849941151758, 0.11249042025977567, 0.12809667315694595, 0.0760379190286321, 0.20929768771654178, 0.16113842837512493, 0.19697864149366656, 0.10663114998850132, 0.12388134330150583, 0.12576761264954844, 0.13629963621497154, 0.14644663931140978, 0.18140294018291658, 0.09241606679654892, 0.14573630726625844, 0.16558219798870627, 0.12851512570294643, 0.17327752054458664, 0.11165418166426883, 0.17184135083469654, 0.13989707785508326, 0.17754331261159914, 0.17397999252763488], [0.062380329510497476, 0.0004329996279979711, 0.03526850468328884, 0.17171350608189262, 0.09684715765498339, 0.035239864486239614, 0.02889704909325848, 0.035536110686558875, 0.055917282363459955, 0.04515033410561662, 0.048654604132377335, 0.02333146245819667, 0.01720172867569472, 0.035556151546658046, 0.049672405565938646, 0.03865192817043393, 0.04079814264250379, 0.022758783006499854, 0.04628007247623417, 0.02462566266917894, 0.04109559926174341, 0.047436011053862116, 0.17799700520211653, 0.3626609671740763, 16.384554101574807, 120.96246796269571, 103.27298641204835, 121.94833217128631, 71.35531102457355, 77.4149493248232, 90.44306262846916, 41.88740291903096, 61.60730331174789, 94.73131933519917, 49.387123738565755, 51.803852896536554, 28.500610436162642, 1.5114190333312558, 0.7159545176452207, 0.1735528985098485, 0.324067602595014, 0.058233598998237046, 0.4658322342701497, 0.12253852140518928, 13.658042030949748, 1.050679537077104, 47.8439966324837, 132.68264339816187, 95.43852267726776, 113.27579913600799, 79.5605093433011, 93.18224983830606, 93.12481849424302, 96.0377980816749, 79.00068513808712, 86.97994709014894, 82.03557983521493, 81.6633233716411, 75.52240571668072, 79.58118023410921, 78.83277631575062, 80.09381048140988, 75.81662270330614, 74.61221187345444, 68.55782170449534, 73.27965721007317, 86.79192435356879, 100.53200275667253, 89.21529800661149, 72.10357373760593, 68.08363068488337, 78.40260997895273, 95.47556554117511, 97.84191577665268, 97.9173037313646, 91.68047628095074, 72.66669273376465, 78.618269735767, 94.07895072813957, 93.14603851687525, 93.28256837783321, 91.00935089972712, 82.2276504578129, 79.46087329618393, 92.72174789059548, 94.1222615395823, 98.14715462346231, 35.65576476435508, 82.66938778661913, 99.69681247588127, 92.09909515996134, 97.27722783242503, 95.00015858680972, 94.48544163857737, 90.4521546825286, 86.31524655126756, 75.34250228635727, 88.80910519630679, 92.75902609671317, 99.9748771421371, 89.3851052561114, 94.20879687032392, 91.20209616999473, 87.86379045055759, 79.57482599443006, 72.18322138632499, 77.77670168107556, 84.83014306714459, 87.46256336089104, 83.27618629701676, 86.37610604686122, 90.03031161523636, 97.6330417202365, 99.34332847595216, 96.54508606080087, 88.96091661145611, 91.54065947378837, 93.12994110968806, 88.56517299529045, 90.800978906693, 89.8728519870389, 83.8820355938327, 53.53718357701456, 6.183894574642182, 1.0850955161356157, 0.8264593912228462, 0.4530911195662714, 0.13837483050602098, 0.024059343662473465, 0.22759649451942215, 0.022154684373808485, 0.2155199151245817, 0.26844480826008704, 9.34834368767277, 44.59826669385357, 65.58274707486554, 35.832338102402225, 76.248381522394, 115.75283081300798, 96.60800087836482, 40.38652366207492, 18.767178250897317, 18.16723604356089, 55.24543462261077, 72.18300957833567, 83.39145691164079, 91.35332707435855, 58.01875037531699, 1.0062835774114056, 0.03961482408246206, 0.056673786527807676, 0.04723450694713862, 0.06770652133010088, 0.0118705773943915, 0.0823911244890863, 0.07575271215530173, 0.041156556877878406, 0.048330441688097296, 0.03954178525976116, 0.08420752661843454, 0.024283240519223676, 0.04538805501896047, 0.02540284546182281, 0.005171618259121334, 0.13522948799354417, 0.04813122435382778, 0.08815512406609713, 0.013900541854391416, 0.06387137792884343, 0.020777652821233197, 0.04752129962247226, 0.0409685091055449, 0.06489205985300003, 0.03546561910620621, 0.04480107079049753, 0.038397541014297355, 0.050197378807370706, 0.030438657399387132, 0.01324867380918154, 0.03438756485740024, 0.11228159235249605, 0.053551380687783805, 0.05373641390413527, 0.04321757088144941, 0.027091927608595263, 0.03185471155560546, 0.060868933796882636, 0.02323610940948129, 0.04157149691074606, 0.015783232614217747, 0.03744452380605283, 0.04190512054089097, 0.019154586386115804, 0.05370723361509943, 0.07224242067745618, 0.05185919205447839, 0.03720853808185747, 0.12986357834550644, 0.2734862183851581, 0.27055553370906466, 26.2336471772963, 149.32031785288166, 110.73762555276195, 137.6161535324589, 81.64962645499938, 110.66474007021998, 100.0364975775442, 30.458916502614176, 32.27479934692383, 85.76399664725028, 56.13331802429692, 49.72056050454417, 40.50873687190395, 1.2541187818973296, 0.8734572919145708, 0.0877453972615542, 0.2892318073539965, 0.09901258178175458, 0.5908013687979791, 6.784406506246136, 15.754940144477354, 2.5278354412125004, 61.768195013846125, 133.68341261340726, 103.20883212550994, 118.79881797298309, 84.18648212186753, 96.83230553903888, 97.95131068075858, 97.48417992745676, 83.49300707540205, 89.53657150268556, 86.30926885912496, 85.37472494186895, 80.1227261943202, 83.43151215584048, 83.62774049082111, 84.7535313329389, 80.73952674865723, 80.31812298682429, 71.98852277571156, 76.38536637829196, 93.92779042643886, 103.68917342155211, 93.46498996980729, 76.29941155833583, 71.93407243297946, 81.60124794129403, 97.35546342788204, 100.1777264379686, 101.69983356229721, 94.92085610666584, 75.83643851741668, 83.11346284804806, 98.62657808488416, 97.8709883843699, 94.55177676293158, 95.23459865200905, 85.11969243326496, 83.29275438862463, 95.54737629428988, 97.69326579186225, 102.40353815017208, 39.52207642216837, 83.94149088090467, 103.25386877982848, 96.40617139877813, 103.28430637236565, 98.4237523232737, 96.7897399779289, 95.52654066393453, 89.49329207020422, 79.14585205816454, 89.75126635643744, 96.822201513475, 103.39732554651077, 93.4524932984383, 97.99757111457087, 96.64236868581465, 91.66154692249914, 82.42627928333899, 76.0011859093943, 81.75945281982422, 88.33667924327236, 89.23563941832512, 86.79579965529904, 90.5221611453641, 92.07156796609202, 100.39633581715246, 100.20076644036078, 98.85165937485235, 88.94858467963435, 94.20816144635602, 94.44191901914536, 91.7609868511077, 90.68485321537142, 91.79303261541551, 86.78809612028061, 62.84569755677254, 10.489451385313465, 0.398301491814275, 1.1097634247233792, 1.5305046737194063, 0.3739398651786389, 0.2543753124172649, 0.16150509337744406, 0.09445587548637584, 0.06343826629041184, 0.8532969833862397, 12.284835923102595, 42.512879756189164, 38.81713628768921, 43.143538044345, 67.05886440892374, 70.87041193439116, 57.24805562726913, 35.67602772866526, 27.106082324058782, 39.253574494392645, 70.63166510674262, 84.326597029163, 94.28346310892414, 100.02928041642713, 82.72938436077487, 1.0867119003688137, 0.01815592948978226, 0.08685894160261078, 0.07183410347469392, 0.05597015392155417, 0.03577088216139424, 0.020972995665825663, 0.01973080133358317, 0.05440114456559381, 0.057574786365993565, 0.028548488663809917, 0.04461180876880404, 0.03547915587982824, 0.05424660930950796, 0.004047683004530207, 0.022559609722285982, 0.06453693213482058, 0.02598081283541697, 0.027986450173381357, 0.045795782334021026, 0.02051915943382248, 0.025020335846009756, 0.037509422944558245, 0.05860896675937599, 0.062283308305326975, 0.014152011173146387, 0.04208675232685862, 0.02139763820225433, 0.1927241262408995, 0.1364873890434542, 0.10147991349860545, 0.26530084470587395, 0.27525781203181515, 0.12329952250565253, 0.16776619208676202, 0.22209566146616014, 0.14051955493707813, 0.1063050416808936, 0.241616792195747, 0.13657988649943184, 0.1270726510894395, 0.07552984185637006, 0.2605296797569721, 0.160773188296345, 0.13001642820815887, 0.13546193439152934, 0.16163522107226236, 0.1647832142489572, 0.20288838163739253, 0.21828556914002667, 0.45299652302938126, 0.6853028494984873, 34.958885100580034, 166.45668245130972, 130.22037552249049, 152.19933755936162, 99.9257847570604, 100.60755545093168, 110.51595672484368, 60.464956145132746, 95.36491547861408, 126.45493153602847, 69.86630085975894, 85.09104344152635, 49.44752039447908, 3.7436682130059893, 1.5322001182263898, 0.5133642514626826, 0.7506494139952045, 0.22147729061543944, 0.9459792810582346, 3.8086405588734538, 25.727139749834617, 7.895481596069952, 57.27512782619846, 143.44299131824124, 103.79530491367464, 126.84854922756072, 87.29145388449393, 101.54522941958521, 102.8632164001465, 107.35377327088388, 86.65403735253119, 96.7328420762093, 91.77160862953433, 92.45094745389878, 85.72700869652533, 90.19544339949086, 88.81997800642445, 89.96464329381143, 86.20677732652234, 84.90062021440076, 76.68894998488888, 81.44605544305618, 95.73144528173631, 108.77092561414166, 98.42103804311445, 81.44461985557311, 77.6810036936114, 88.19297928963938, 105.58568646830898, 104.13767291653542, 106.1429689776513, 101.59710668748426, 79.55415510362195, 85.55400863770517, 100.10695119057932, 102.68012800524312, 96.62441991990613, 99.82757645268595, 87.94511687371039, 88.41221624805083, 100.25555410692769, 104.10973779616818, 105.12598468411355, 45.15313302316974, 89.82742309570314, 106.25102243115826, 100.30252841211136, 107.68976349984447, 104.66847158247425, 103.69895581276187, 100.74464228845413, 94.39696081223028, 83.06772016709851, 97.19637993843325, 101.68519527681413, 109.02181609984368, 95.0950328765377, 102.20354433982604, 101.71863740490329, 96.69506965144988, 89.44334460842995, 81.35865719087663, 89.54203144196542, 92.9488060551305, 94.02746569725775, 92.10426484384845, 94.87492515194802, 95.31004151990338, 105.16671457598287, 104.27679938654747, 103.0613588517712, 91.50844112519296, 96.94176320106753, 97.36444565557666, 96.86547310121598, 97.12806009477185, 95.33255592469247, 90.77887242840183, 64.41661857789563, 11.056230933435502, 4.640650287751229, 3.7145938892518324, 2.175729173806406, 0.40533126782505746, 0.42429356805739865, 0.4887696421675144, 0.31362750958050456, 0.39772018429733097, 2.730132173145971, 18.288519651659076, 72.29328309336017, 95.96014299700337, 53.297652275331565, 91.49161415715372, 143.6005921517649, 133.9504946431806, 54.640589452558956, 27.0495197849889, 30.01427858106552, 71.57843112945557, 94.08171207674089, 106.83311785421064, 107.67195593926215, 96.25636823715703, 2.2326256046372075, 0.12903071819774567, 0.19685370787497491, 0.19975318212903317, 0.11624643443933419, 0.11683863572656147, 0.16648820421147734, 0.21655543617183165, 0.20603914805237325, 0.09051639857071062, 0.1650180508412661, 0.21397321424897642, 0.23052722516079105, 0.11269713376438427, 0.253725225526479, 0.1241602146277024, 0.25218791688882536, 0.13118613721622577, 0.1723865296451315, 0.11796274718137519, 0.1327617502500934, 0.11620508101318153, 0.11536202423514859, 0.17104831193723988, 0.17097904226712643, 0.10784484776518038, 0.14069489714118744, 0.17214179519684086], [0.07689311830026489, 0.03099914264654921, 0.1082449448445151, 0.09504556400521148, 0.06898920532436141, 0.03812328536784457, 0.04969798907216999, 0.03113726638407717, 0.012424256907956255, 0.04237105904687797, 0.012694153514119887, 0.04850769145113807, 0.0608013303680045, 0.08577046089715536, 0.00931202663078664, 0.018041629171479615, 0.04186210853438224, 0.018765149420247446, 0.07696312341478563, 0.08784894170539995, 0.011331801163783718, 0.046962005642032435, 0.37649357330895245, 14.550410662927936, 124.97523307800294, 107.36740742960285, 120.5266926365514, 85.15071053658762, 88.06725948087632, 36.7805318678579, 14.501163344229422, 118.43413952858218, 155.73814699726722, 58.1777044265501, 48.00748494363601, 27.09428579576554, 0.60788476178723, 0.16596859741595485, 0.17807065689515683, 0.313107397166952, 0.04496617805993846, 0.33033487597300165, 0.09568871013940343, 18.81970467105989, 3.4265519390183115, 11.476508975028993, 133.36661061932963, 95.83865934802641, 120.10896805794009, 84.13050205476823, 91.6357377267653, 83.90105908916843, 92.82078773744645, 87.67954103408321, 91.03440700038787, 76.73324923361503, 79.58317279815674, 74.20489726528045, 79.03454303741455, 77.98473635027486, 83.79724179544758, 78.41865247295749, 79.40936473108108, 66.19688433985557, 69.46947466942572, 68.4996529548399, 75.831802275873, 76.54338298305389, 76.0328237472042, 68.14705541056972, 70.04797720140027, 77.77027683873331, 97.5199362539476, 94.66787892003214, 91.47175911934146, 75.58957238351145, 70.5780698407081, 81.04016857762491, 98.10568732600059, 87.4480035228114, 95.12041845629292, 89.03388054140153, 82.5330069757277, 78.34906178136026, 94.45478439331056, 85.74311394845286, 105.86354717131584, 40.94308445530553, 60.40731299308039, 99.87609617171749, 82.33622950892295, 99.46425514836466, 94.89837308083811, 96.49871580062374, 87.763393463627, 90.0262245055168, 81.66971683502197, 76.58158686853226, 86.87696133890461, 94.24926004102154, 94.50605761620307, 95.03869195138255, 89.44339167687201, 83.91485798743464, 74.45546611662834, 72.96414959815242, 73.38798522949219, 80.17514474930303, 78.39291387988676, 79.27598845574164, 82.49634065935689, 92.25276577857234, 97.80654384243874, 90.44845980982628, 85.18370551447715, 93.6334793029293, 87.85716164496638, 88.12982128512475, 90.43743010490172, 91.19692648610761, 88.6497236067249, 89.19456435788064, 85.87989484110187, 48.13234967570151, 0.38508261403729843, 0.8553424994311026, 1.2349915889001664, 0.5917434117967083, 0.16014830569826788, 0.11044025406121247, 0.055989715976700674, 0.08295158675361065, 0.22030797997309318, 0.03828177746805934, 6.424709471964068, 24.974695790198542, 37.827126133826475, 36.12923406785534, 110.93344596124466, 109.34099505024572, 65.47669795251662, 64.4295153310222, 23.54930058602364, 18.863084123980617, 60.244530708559104, 73.92240816547026, 82.72786248114802, 94.83428155222248, 14.157326413739113, 0.739500260641498, 0.11613699111847148, 0.11815705006161045, 0.018992150848310803, 0.08705644673036952, 0.011890816479741086, 0.02103280798051386, 0.005789093744580544, 0.03760403863364651, 0.007609792190769147, 0.010623231120858221, 0.05002427358000029, 0.023017138498084202, 0.05891582327744654, 0.0030833688722322547, 0.06418861493828797, 0.03304176670949786, 0.047396170651359905, 0.050287489899464195, 0.019092943121288574, 0.09390510423409362, 0.04020956112071872, 0.024905803786110015, 0.03925078676172322, 0.02299064334722296, 0.04372554080140206, 0.044648320519275246, 0.05867136079036902, 0.04210804957115362, 0.06962520385821981, 0.04611848538080531, 0.008214287752766282, 0.018495114918257442, 0.06049679126590491, 0.06018284843453477, 0.019666346526073835, 0.06940729014815823, 0.023905220178646908, 0.10714002389220462, 0.03653745272106702, 0.08194708460641485, 0.07788625936354361, 0.025859935652284373, 0.04361942996300998, 0.0312316081967325, 0.04715569182148865, 0.0741837947298923, 0.11032201605097902, 0.13312715886821672, 0.4268060606573859, 24.004864269687285, 152.85474992567495, 119.84853052323865, 135.26924256355534, 98.96580819160708, 108.2357652725712, 59.14218779533141, 33.52050096757951, 68.46737184832173, 131.32023949776928, 67.09254972396359, 54.512249500520774, 39.3953211076798, 1.3987174485960316, 0.33450876813261743, 0.10431534280219387, 0.3446198417054069, 0.024311666211654103, 0.4283147329284299, 0.08077362176751898, 5.054648614698841, 2.7271666161475645, 15.5132564421623, 140.42606107650266, 98.7459828776698, 125.09295909635483, 86.5852076007474, 95.96614422336702, 88.89465993450534, 96.31287390185942, 91.71960584578976, 96.42976053299444, 80.47602976522138, 83.38909564479705, 79.59894072624945, 82.27495424209103, 79.15996474604454, 87.53056941493865, 82.63997001032676, 83.85719130116125, 73.25107097625732, 75.95769466892366, 71.06823275166174, 80.12705649099043, 82.50398928119291, 80.24577879136609, 70.33765208336615, 74.54556295948645, 80.93669645247921, 100.46543229010798, 98.09040577180924, 97.27048135572865, 79.60388291266658, 73.30435245267807, 84.78108206102925, 106.13348468657463, 91.54854343783472, 101.80137588131814, 93.11911536801247, 86.86031479989329, 82.48960202740085, 100.30660767709055, 89.31973503481957, 111.29504142269012, 44.98958587646485, 61.92063400822302, 102.8070245250579, 87.49275776647752, 103.15427980115338, 97.09863447373914, 102.11754245142784, 91.69851133900305, 92.34405502196282, 84.30387866112494, 80.0634434915358, 89.89120867944534, 96.94048450839136, 94.61865317436957, 99.08871958332678, 92.68829791776596, 86.29680356671734, 78.81302325956284, 77.6715664709768, 76.51225505336639, 84.70508221657046, 81.66249967390492, 84.3223451798962, 86.82818274344169, 96.5649175643921, 100.31320510372039, 95.15753976760372, 87.05333463607296, 95.63565315738802, 91.14295467253655, 91.64502589933335, 93.02500986283826, 92.92873920932894, 89.78492029251592, 93.37532458766815, 90.11108106182468, 55.81233478361561, 1.7847066204394064, 0.40093459729706094, 1.22881434617504, 1.3268629365390348, 0.5723411013041774, 0.19823378462704921, 0.16324449600952287, 0.05439595431990681, 0.27980138758017176, 0.09590411874195261, 7.683892769198264, 29.12167460687699, 33.60145476556594, 44.81118863628757, 107.5805333352858, 98.60596995199882, 26.7955227821104, 25.074549528860278, 24.396750234788467, 36.219275997531035, 74.7299143575853, 81.381359869434, 90.47796387826243, 111.74440383911134, 24.94745885172198, 1.0065311157414991, 0.1897710411539001, 0.14342246126503716, 0.06271879481632384, 0.07611065907704254, 0.03609328643388806, 0.057658289949740135, 0.011097625322309474, 0.07143940731522537, 0.04435607329792073, 0.0464549703493474, 0.008507566319988861, 0.07065618966495799, 0.07184415454826049, 0.03031270488375618, 0.03983831874305203, 0.034002954245454846, 0.05871947111201383, 0.05711481951537633, 0.07359500253392805, 0.0536087223689162, 0.02615669130107328, 0.06042831832723272, 0.018923593639966943, 0.047799270795357805, 0.03592648611013447, 0.042072981896419684, 0.16427007323551565, 0.15039784503319573, 0.22044354689217385, 0.19361464216584162, 0.12290090397601167, 0.2097522842908098, 0.1798703046816011, 0.12980013094361753, 0.08235285073638925, 0.1829641047985323, 0.05823146544336792, 0.18995488693396892, 0.12951392049510635, 0.20577179868855786, 0.21558037478356593, 0.07595338122618776, 0.15798305011084005, 0.18298719468857014, 0.1439208014597816, 0.28444201114677614, 0.19655173133698203, 0.4528440408889325, 0.8009302159470897, 27.59593144539864, 177.71394760377947, 133.3426998507592, 154.45112320684618, 109.04179665350146, 115.03061263791977, 53.68824189709079, 24.522850513458256, 168.7684960519114, 182.20953295307777, 75.90492310062533, 77.79787463526573, 45.30164964737431, 1.8340424376149334, 0.8758704688760542, 0.41356128910856865, 0.8045791233739545, 0.18517449828645877, 0.7894894588858851, 0.20970457233488562, 45.94195304378387, 9.042910683539606, 12.842381231246456, 152.3556204765074, 98.7501641242735, 134.41192227025186, 89.49018555302774, 102.19746466605895, 92.26529382890271, 101.76885158784928, 95.08307749225249, 101.56662987124537, 83.28507438782724, 89.98549461364748, 83.58342555261429, 89.59674066112888, 84.41260676230155, 95.00345337775447, 88.35032124673167, 88.2441113072057, 76.32468731172624, 80.56196889569684, 76.33748992796868, 86.20936609083607, 87.69102573394777, 84.47923998678885, 73.34891842257592, 80.50030139184769, 86.57338557704803, 106.13329641280636, 103.62210873634585, 100.9877037232922, 85.56911760760893, 77.5814853175994, 89.92401538356658, 110.5672848609186, 97.36747372534968, 102.0057156778151, 98.26459038642146, 92.22758416206607, 87.49332258778234, 105.91708752416797, 94.67125215838033, 113.1101574436311, 50.46775241051951, 68.36311524914157, 103.27826592230029, 90.62251106385263, 105.40814430482926, 102.3979683845274, 104.77061010176136, 97.57266075380387, 97.75161497054562, 89.87186354975547, 83.51567837499803, 95.61052645406416, 102.30772249160275, 96.98148112143241, 103.12719191274336, 98.22772010680168, 91.7638344918528, 82.79585284571495, 81.54410685262373, 80.84439523758428, 88.66002375079741, 88.83424758911134, 88.22860225554436, 91.00362423927554, 101.23068671072684, 103.86306778077157, 97.83496533670734, 88.51728870022683, 98.09337892839986, 94.89679628802885, 95.4415507470408, 94.95454926644602, 94.96555543714955, 94.57837043269988, 95.21048392018965, 91.58373494302073, 54.87181709658716, 1.972958815674628, 4.061559400250835, 4.851508082882051, 1.5524703144065797, 0.607840022252452, 0.33257448805436013, 0.4177148952599495, 0.25427251873958495, 0.6909964762387738, 0.35560909718755757, 14.38898551848627, 43.990240481592, 54.50514608813871, 58.31197107991865, 124.51324847436722, 131.66938535628782, 97.62526758255498, 91.8594148082118, 36.0458876240638, 32.29312466036889, 78.79462734345468, 96.36228007654991, 100.57845146425309, 125.32536737380491, 31.92154480564979, 1.5547896609190972, 0.40757452648493553, 0.3282793701416062, 0.12766647648306625, 0.32175135107771047, 0.3325888292203027, 0.13583607641198944, 0.15962335160903393, 0.1396717560747939, 0.23054070830825837, 0.16944487458996235, 0.11359277481753981, 0.2693875560597066, 0.09867155008138188, 0.06630532353395416, 0.23049871136824931, 0.18093838446563293, 0.1836956728009447, 0.1829023581118353, 0.16253742749892897, 0.21915451202902103, 0.12701540899973723, 0.15591104274555562, 0.1744152377209356, 0.17186857759952548, 0.11020343330117965, 0.10518462276987492], [0.1459463072880622, 0.03453368080719825, 0.026082304163625645, 0.026806050408331138, 0.02659638938043387, 0.08113950536015534, 0.022660290912514734, 0.02666338568463201, 0.017454738788787397, 0.06024170313931762, 0.06300039341553085, 0.03309570312980683, 0.04279940178798091, 0.023199806417969447, 0.02205169534370784, 0.04043367248208773, 0.012199742392817093, 0.007403161040612407, 0.03660722034833124, 0.07016111300477097, 0.03367166335303937, 0.09985031424871377, 3.451253800622879, 104.7415453387845, 120.17953149734007, 117.4969127101283, 97.21519947052003, 68.4792644746842, 22.57585264021351, 42.71031225881269, 70.03650819101642, 62.94656522812382, 68.81672167008924, 69.74896707842427, 33.12928376659271, 2.749404984135782, 0.14357494340548593, 0.04481434709422531, 0.30944071650024385, 0.08355587690828309, 0.22768585101491023, 0.12965488067317393, 1.1067266521915313, 4.035930143248651, 0.1954185800446618, 80.38982391357422, 117.548782133287, 102.6571507607737, 101.19278092538157, 84.01149734374016, 81.99754853402415, 87.72740179492583, 92.69347544639342, 88.61649328662504, 85.05342791157385, 80.33828396950999, 79.08778529013358, 75.0539021338186, 77.58456830055484, 80.95073069295576, 81.47752854131883, 79.74406057788481, 76.53200810955417, 69.06478020452684, 70.60089803511097, 69.28506835814446, 70.13304556569746, 69.8085008128997, 70.5246393142208, 67.93904427559146, 69.17469286149549, 78.4304666519165, 94.05693838673254, 91.57531753663095, 86.64026983322637, 69.628432643029, 70.71179912936303, 82.01059433721727, 96.1264907160113, 88.74058138939643, 92.99657267908897, 93.4318773208126, 85.56582281666418, 76.39303068960868, 86.55693515654534, 82.25050218643682, 103.85911403163787, 54.438583466314505, 48.077091324713926, 97.28432732243692, 78.42943114619102, 86.6598032366845, 87.5253212836481, 98.03976012814431, 84.55873074070101, 91.92081559088923, 86.69263347502678, 84.1169620329334, 72.99190428949171, 91.8397480441678, 90.30118265459615, 96.43708752047633, 87.88380238317674, 81.46788735543528, 68.74724864959717, 72.8489495861915, 71.01251940573417, 73.13946385537425, 69.46160639486006, 80.55168444110502, 85.55057264143421, 93.5417115303778, 94.31731316351122, 85.9303286767775, 86.537715542701, 89.15266559969994, 92.07983632241526, 92.73491920963411, 84.60398704774919, 91.10267193086686, 87.58319977791079, 89.65862781770768, 88.41977857774305, 97.43214576475083, 38.78648688716274, 0.6535476470185865, 1.2081118312574204, 0.7034898381079397, 0.18966077045807916, 0.16672540035459305, 0.035068479126259204, 0.10808563686066097, 0.0625674120120464, 0.057101049084937384, 0.10437092248110041, 3.7680754065513615, 23.71598170649621, 47.032489622792895, 23.77850232585784, 50.24499316369334, 149.33410890640752, 149.12140661670318, 91.16243316281228, 33.90440687056511, 24.90172793788295, 58.941703688713815, 79.97580989714592, 92.9992320460658, 51.067067038628366, 0.8413388411844931, 0.1966634729216176, 0.049559917045576926, 0.00936224465183313, 0.07131132507516492, 0.04306492020165728, 0.06780537731585003, 0.03346111557836975, 0.06105974331618317, 0.051378441238475424, 0.07442371048513921, 0.035847218992609176, 0.08511248330074934, 0.03321478000631736, 0.04735415072871312, 0.04503322224463186, 0.031261152377532374, 0.06155627554342632, 0.007429571921801976, 0.03313781115256491, 0.04385160056934242, 0.027306868897510633, 0.05508806879421877, 0.02511340403749097, 0.03145326807674381, 0.010181059535112112, 0.1005203041037725, 0.03837466562887834, 0.014924007550542875, 0.023419420843222932, 0.07120339094751305, 0.05902764530131414, 0.028939099659422235, 0.029502886745537964, 0.041744318685584494, 0.04667359652117856, 0.059991851223692785, 0.07535927238002901, 0.061694768918377746, 0.06909867162786185, 0.07638061313980049, 0.03327705529368213, 0.03537729299897629, 0.013064741844221229, 0.07890563893822894, 0.052497569291341695, 0.10460860892048768, 0.09077655436891703, 0.28291032559448676, 6.974463482056895, 131.8709481147028, 130.43372892564344, 130.910414572685, 108.67216033320274, 85.52033901214601, 46.47692511158605, 48.65803749330583, 30.411981421132243, 81.21539654270296, 90.36675683913693, 64.03933755813107, 43.03848912639003, 3.3360121134788763, 0.4590088117026514, 0.08880492750435107, 0.24136798215969918, 0.09670731596528523, 0.30115872381194947, 0.07219333742414752, 0.5236663260767537, 1.1915354046129412, 1.7076704122366446, 93.49578842040032, 119.45332819415678, 110.42197673551499, 103.96634378740865, 90.6651472276257, 84.3879742776194, 91.35422137475784, 97.19597201193534, 93.36664046010664, 89.39343637035739, 88.0656748433267, 83.23854723284322, 79.6184584402269, 83.1187423583, 86.50374781700873, 85.46114260150541, 84.66958476651101, 81.04291423674553, 72.57592124323692, 73.0728933888097, 72.27738964942195, 76.17126772480627, 73.69429880572905, 74.2126557134813, 71.95224869635798, 71.89309935415946, 81.94284715960103, 96.24940995247134, 93.5833514121271, 88.28874787976666, 73.25715065002441, 75.45470560750654, 85.47967972293978, 102.98517073354414, 91.92979781858384, 93.800823303961, 97.08402756721743, 88.81782070282968, 80.75583596383372, 90.26825827936973, 86.77736451548915, 110.53640796292214, 61.342206001281745, 50.76948858076527, 96.18396912851642, 79.34831696171915, 88.95438978748938, 86.36275429879466, 100.63811855931436, 89.58705240680327, 96.61205660912299, 88.58316882964104, 86.8801776824459, 78.45174158773115, 95.77870984231272, 95.68436899492818, 98.21115985993417, 93.8516572213942, 85.39353662921538, 71.10801342994937, 76.86140091188493, 74.32920502078149, 75.51824800429806, 73.01596410812871, 83.42552661895752, 90.46825208971578, 95.76723298718854, 96.53622934895178, 87.69349682715632, 90.16083240509035, 91.67599693421396, 94.42932821089222, 95.65437855259066, 90.02030957129695, 93.28592592670073, 91.7484901797387, 92.60672046292214, 91.1865008261896, 101.2108002939532, 49.42921077051471, 0.7693551360599457, 0.835263763944949, 1.2427040718255506, 0.6651049720183496, 0.2968134118183967, 0.10772337686390647, 0.25710054763382484, 0.02044898961039801, 0.05162067824013291, 0.12186673124350848, 4.582674714826769, 30.390806505756995, 46.26410122840635, 39.57757403773647, 63.895802344045336, 114.07677065941596, 113.45332561000701, 39.47407837836973, 40.672727246438306, 43.99044444484096, 69.22686038478729, 87.29840432443928, 103.71433150383734, 75.39019830765264, 1.4830799088362725, 0.07753113930624339, 0.05314618912375262, 0.023631880007263635, 0.056937891509263754, 0.03890115189396086, 0.06056829408231763, 0.05054567302126558, 0.009922343024593449, 0.0193843687133443, 0.05237612903358475, 0.016824263748863054, 0.1330510556938187, 0.0010546493051092952, 0.00998079744843586, 0.02764967217620823, 0.02051120744116845, 0.05134816544370786, 0.06193182716566709, 0.05738814819544073, 0.02880519706635706, 0.03557721130369652, 0.03419329645112157, 0.06231926464205308, 0.027262188734546788, 0.053766766307695266, 0.05803320188856414, 0.16734476711961532, 0.08232408413483251, 0.1522107614624885, 0.138919948029422, 0.10443122892249977, 0.24102322727201447, 0.08619120404604944, 0.13078455392631794, 0.19867328926920894, 0.17068495643475365, 0.19514180779937776, 0.11523198847088123, 0.22998016177406236, 0.1382607906576126, 0.07506448174676589, 0.18518582106597964, 0.0993656640451762, 0.1085070848104454, 0.16138539980015448, 0.19452708352717663, 0.1359692071714709, 0.49105828387602685, 8.61321012819967, 154.39589623482, 144.09776041584632, 149.261074373799, 122.0382328956358, 96.63362964507073, 38.53145045618857, 62.121188717503706, 94.8478215740573, 89.50585934423631, 87.32645711591168, 99.31255355958017, 56.92729203931747, 5.6024169248919335, 0.57484676039988, 0.5443369104496895, 0.5868894787084672, 0.27876989615540354, 0.58683542354453, 0.5653310903618413, 3.4637710644352824, 16.37334494821487, 2.790595509352223, 95.42338232840262, 124.02335228458529, 114.20421631105485, 107.46548237339144, 93.31150762496456, 89.81265929437454, 97.9806656991282, 103.43394479443951, 98.09581864264705, 93.77008761129072, 91.41738722401281, 88.39888803420529, 82.89090756447085, 86.1137543955157, 91.82289754190754, 90.78404211228894, 90.6669907416067, 85.3271387469384, 77.10148134539205, 79.0465376454015, 77.13181695630475, 78.19706993718302, 78.2154187848491, 78.77972233679988, 76.41996952795213, 77.01143941571637, 86.29245758056642, 103.29011148022067, 98.55720704601657, 94.7644712078956, 78.07481750365227, 77.51741732320478, 88.30750465393068, 106.72213831255513, 96.25483851278983, 95.33592916304066, 100.30539958707749, 92.74059095690328, 85.928587144421, 94.20529027138987, 93.17414622153007, 115.12866404748733, 67.01366301505797, 55.98576630315473, 95.94817192323747, 81.3518871799592, 91.9175757131269, 91.54377383570518, 105.4143887181436, 91.03493259799097, 100.83854383037936, 93.00614326230942, 92.13915824890138, 81.1931880827873, 101.7608577974381, 98.7358945415866, 100.71241609511837, 96.93493043222736, 90.74985473386704, 75.4905011576991, 80.1772314502347, 79.14939003605997, 81.70311189466908, 76.82305582108037, 86.32060450892295, 93.6657133410054, 101.97207743121733, 100.73126700616653, 90.71091344279628, 89.7650574099633, 95.2224628386959, 100.1007773799281, 99.819519904352, 94.77736796102216, 99.16377805894422, 95.81166559650053, 94.90148744275494, 93.36118052082678, 101.88497727917087, 48.6690632758602, 2.129428290551709, 6.162364194470068, 4.757440330520754, 1.9409158705703675, 0.8557042155054309, 0.38716260403875385, 0.465825523339933, 0.28059257254485165, 0.13891801748785282, 0.5252027307306567, 10.757908205832205, 39.63002789405085, 67.17584517694289, 36.46210993489912, 66.99919731386247, 171.75351388992803, 181.82832564077071, 117.44015601373489, 48.33611288378316, 41.91337685431204, 77.36853984094436, 101.29176585905014, 114.69444982467161, 86.13200910629766, 2.0225986165385095, 0.3200306256692256, 0.15392256960753473, 0.21630374564518853, 0.12881293472263122, 0.18415972290019836, 0.1437204235023068, 0.11398852051746462, 0.10658371382422986, 0.10297090446035709, 0.22905506464021824, 0.2386566744216027, 0.26993785233747575, 0.15236203318401692, 0.15033315656886947, 0.08972292300313713, 0.15030951509552617, 0.16106318321920213, 0.18566142377113143, 0.18925066827045334, 0.2755391808046449, 0.13324823140376998, 0.14978684394830658, 0.13685693453636863, 0.12978560591657318, 0.18177945707594195, 0.18771271611894333], [0.03243404831136427, 0.023927792959335833, 0.041828818183632634, 0.041336185343924074, 0.04486559837635967, 0.03251187901403154, 0.031109984077873732, 0.035922579061720646, 0.03484185116605894, 0.0474863353696081, 0.09039597720989297, 0.04825187554102271, 0.022506408746384328, 0.005504075999206473, 0.025351190068308386, 0.09050531327844628, 0.07195664689906182, 0.08171479142601452, 0.04495640660846426, 0.09681741046088357, 0.15089336602437883, 0.3508357565489508, 40.858404405655406, 124.96982020716514, 127.12233851032873, 93.53461988510625, 82.2895376143917, 60.774862612447436, 28.24206348388426, 50.13764181444722, 93.19459745960852, 37.53395642003706, 48.9149566619627, 34.38075911614203, 3.927094912336719, 0.16842763240058578, 0.09506925144383023, 0.11793583451259522, 0.0348399474375671, 0.07264098558094233, 0.07549224226104637, 0.1562926311406397, 0.4822690184077909, 1.7682805921762221, 24.178584083434075, 121.48558662783716, 102.90880218628915, 104.66395301203575, 85.07809961995771, 83.02983791597428, 79.2486495356406, 85.50705002200219, 83.58475915847286, 89.89949272524926, 84.97621997710198, 82.59875374455606, 79.02166981850901, 83.508484748102, 77.99236143788984, 84.55951521473547, 81.22589280528408, 82.36075216724028, 73.52718230216735, 68.47206300304782, 68.61406849276635, 67.91733003431752, 68.55451122406991, 69.86126453645768, 69.06955765139672, 69.39829934027888, 69.98404256759152, 78.23992575368574, 86.40219765324747, 82.59503533763271, 76.06422624280377, 68.50038251569195, 69.93982176626884, 86.61493916665354, 90.84707460095807, 90.34850212835497, 88.32862269493842, 88.65830575266193, 84.16922369310933, 75.7974736921249, 80.23564338684082, 73.33892422337686, 93.38174158527006, 71.96937376453032, 46.524656434212964, 87.5316676785869, 78.6049650561425, 83.30701612657117, 78.32176992970129, 90.05477936037126, 87.77678443539529, 91.61882446658228, 87.72630353127757, 88.38193555032053, 78.84128785902455, 80.14912374557989, 89.75534562141665, 91.64944248814737, 89.23287022498347, 78.98511332850303, 68.42986614473405, 70.32400223516649, 68.6131977265881, 71.40344635132821, 70.58715405002718, 83.95585460047569, 87.13846575829291, 95.8502068058137, 91.52408353744015, 78.96648207018453, 87.89909962684878, 90.86614516473587, 88.60202758542954, 88.65796058408677, 91.6982053941296, 89.12995507640224, 91.44460062826835, 94.66970674453243, 93.97373707063737, 92.78358797873221, 94.80386749390634, 38.607160045254616, 0.9391134172197312, 1.449116350662324, 0.3469515375552639, 0.18494741450394356, 0.45568377560665535, 0.093875425987907, 0.26994572772133735, 0.10343634883963293, 0.18755223602056506, 0.1811476183995124, 0.9645265761402346, 28.63659901003684, 30.867092071040986, 66.57212180476036, 120.02463709923529, 125.20135771843695, 146.71564440573417, 42.00166940689087, 32.600852251052856, 46.92745639431862, 76.21429612559658, 81.23944067185926, 91.20873282032629, 8.32016004670051, 1.0237853156943475, 0.2601093426346779, 0.1446997443394315, 0.12564418822406762, 0.02824291151257292, 0.11591847219894971, 0.03997096686714119, 0.0443010873371555, 0.07570134595997872, 0.05687688026697405, 0.093702144560314, 0.06325481504562401, 0.015435862493881536, 0.037466376464092926, 0.04416702961128566, 0.03673791494821349, 0.072691646975375, 0.05531274706065174, 0.06537133211930914, 0.06681078834639442, 0.06141853293464069, 0.06353406558534311, 0.03593122819438577, 0.02021990825362023, 0.024322452729627974, 0.08372016446364504, 0.01814475992784625, 0.04043661042927735, 0.03940438739054146, 0.012331721147582417, 0.07036021925629148, 0.0383582292124629, 0.056124432538185394, 0.01236950460400793, 0.030855413060635332, 0.07611401454215089, 0.09677172097707949, 0.030813904501678004, 0.03997901079034613, 0.10678272814519944, 0.05919276789251355, 0.1177828467541164, 0.15081245181781633, 0.11433306856140976, 0.11512243023682987, 0.22823230153129948, 0.20984423016348194, 0.3979191526530251, 65.18414012847408, 139.84540908567368, 139.96585722892516, 110.2395708330216, 99.78024128944644, 84.34093721451299, 40.56847849199849, 32.75784707838489, 75.12988628879671, 38.50335451864427, 40.81656448302731, 49.28613447373914, 4.496849333086322, 0.10268099380717163, 0.058878170055968154, 0.11603291807395798, 0.15637662502065783, 0.14380950420614214, 0.07320711689610636, 0.27894759791031964, 0.8935795411948235, 0.7024934947971375, 30.819578439958637, 126.2288853429979, 106.37426330197243, 108.42625125761955, 88.50636097692674, 86.52063754297073, 82.77125958473452, 89.68744154899352, 86.73308095624371, 93.73162484938099, 90.73429861376363, 88.23886317591514, 81.44014050883632, 87.28253441472208, 82.18392387513192, 88.06980902148833, 87.09001664192446, 86.88351954183271, 77.86865772739534, 74.25338560535063, 71.06671087203488, 73.16711656508907, 72.60775519955543, 73.31820626412669, 74.11745978939918, 73.2976608891641, 72.81951612041843, 84.53293723444786, 90.0026196818198, 86.26900180693596, 78.49503670969318, 71.25303129996024, 73.92741310981013, 92.70998862481888, 95.06985126003143, 95.03081583207654, 91.240935479441, 91.84149742126466, 86.89790679562478, 81.13127739198747, 82.33950861038701, 79.84674822899603, 98.0477225395941, 75.21111857506537, 48.08587743389992, 87.75442692541307, 81.78807043260144, 85.8285431708059, 83.32239181764665, 94.5337652391003, 91.73076891130017, 93.73601790397399, 90.49012322579661, 90.45326863565754, 82.88738527605611, 84.00093047849595, 92.82574561334427, 95.23600286053073, 91.14717514284196, 82.73892356503396, 71.238981370003, 72.06166713468491, 72.43299007415771, 73.30207747797813, 74.42623661410424, 87.37138394386538, 90.15863587779384, 100.57560382350799, 92.3651259945285, 79.97136977411087, 89.34106488381663, 94.58826265027447, 92.50931232206284, 90.40896938693139, 96.10432147979738, 92.69186727462277, 94.92535114288331, 97.26528029288016, 96.6721159412015, 94.83978855994441, 100.40195265123921, 49.63617071028679, 0.26005966949366754, 0.11055506765842439, 1.0435175342905907, 0.051949134607228546, 0.6019944036679884, 0.047315838671619856, 0.32446124921402625, 0.05904058452635523, 0.1906691107057756, 0.13774970275980813, 0.7136669791033192, 33.43977858943324, 26.381873546108125, 62.15721568753643, 121.68057549384334, 123.25174362428727, 123.74294988570676, 31.30891961436118, 35.78770545221145, 53.14601736684, 87.30170696012436, 88.26714346485754, 111.20095945173695, 17.10932573964519, 1.1852908687245463, 0.3746081696402642, 0.12405777335046761, 0.18004111164519865, 0.029855517017084266, 0.006995723881353174, 0.13705283854036562, 0.034599962734407, 0.043573269335132454, 0.020542059717099034, 0.04592952596384191, 0.05959617830212078, 0.05687707561939474, 0.03511034583132114, 0.017796643829393773, 0.02354931871166393, 0.0779109733599809, 0.12297823289108854, 0.09875001280658668, 0.09870551841994447, 0.06566887300822043, 0.011681665857923369, 0.04291380935859296, 0.00921737359491207, 0.006345147173100662, 0.008467713468557885, 0.17060485428139088, 0.23033979408923658, 0.10302852193314223, 0.20455908150442187, 0.12769452296197414, 0.18309335915311692, 0.1457118690614739, 0.14000449870382586, 0.17489474747450123, 0.18113309337246805, 0.18187511081416763, 0.10166837112797845, 0.21595398054247905, 0.136588757797595, 0.15510652785099324, 0.2052349242712221, 0.2409096164328437, 0.18248376767000846, 0.3315659486238034, 0.41913264821613994, 0.5029068142175674, 0.5470611191084308, 81.83863762886294, 161.52598073405605, 152.7989738218246, 124.52118735159598, 104.55567990579914, 84.60438712950676, 41.133209582298036, 74.36344731238582, 131.00357870901786, 62.48726744805614, 71.64776294462143, 56.16397526956374, 7.924346808464297, 0.5818718479525659, 0.24854830976936126, 0.3156805639305423, 0.5015266302131838, 0.4942583557098143, 0.23105029467373128, 0.9763874558191147, 3.2497692444632134, 3.57570227115385, 29.03338205429816, 129.39848207658338, 112.27468475218743, 112.26480822409354, 93.39705451842278, 92.60310403762325, 88.20022782971783, 94.61473080419725, 91.62167210732737, 99.30065308847736, 95.34072229939123, 91.43662252733785, 86.14854581894414, 93.9773613406766, 87.80562170090215, 92.00733523215018, 91.96718585106635, 90.38669816909298, 83.32174070419805, 77.05382454779841, 77.62201909096011, 78.04630187249954, 75.43976137715002, 78.20002740429294, 78.69349295093168, 76.2119976166756, 78.55610801327613, 87.65499484154486, 94.60149672723587, 91.7330046622984, 82.45550878586309, 74.54094240742346, 78.36794407136979, 96.36265662408645, 99.73388671875001, 95.60866725060248, 92.7540917550364, 96.10491768006356, 90.82827860309233, 84.17436199803507, 87.01794701237833, 84.74592193480461, 102.33825422102406, 82.01082183468728, 52.709292827113984, 86.9808884589903, 84.30900127656999, 86.29382256538638, 86.97664445446384, 98.40834525323685, 98.2564240117227, 96.62074858142485, 94.16383866340884, 94.59186338609265, 86.72707972988006, 87.11350379451629, 96.66394172176238, 99.22224490873276, 97.00966727349066, 86.92020939242455, 75.35230036704772, 75.5604919310539, 75.4961415260069, 77.78054560384443, 78.70934717116818, 91.54211075075212, 95.60468996724775, 103.94952466410976, 94.3718654878678, 79.20726068558233, 93.55910331972184, 98.22057354834773, 96.19415160148375, 95.95364755199802, 100.48793100541639, 96.4813789244621, 100.0103981264176, 101.68276340730729, 101.66067261849682, 98.71437641882129, 101.25577419034897, 48.109466568116225, 1.804584334454229, 4.25073629425418, 2.594444150886228, 0.6336680943927457, 1.0061252730027324, 0.40036484238601505, 0.4246688592097452, 0.21495658003034132, 0.47235761799158593, 0.5479597708871288, 2.7649851287564924, 44.218208636007006, 52.866301382741625, 76.85722751002159, 119.08825751273864, 126.55488137275943, 179.8412686009561, 60.55920285563315, 47.86254159865841, 61.48586673121299, 103.67524116270005, 95.54369711106824, 129.6432771990376, 18.166561395891254, 1.338575501595774, 0.40737849990687064, 0.33513597963798436, 0.1972171093427366, 0.12404884076527051, 0.1964624514502864, 0.21807017585923597, 0.09132274441541204, 0.1570138875995913, 0.2864961993069418, 0.12717023536923433, 0.15701266185891244, 0.20784679379674698, 0.20063363165865022, 0.10869633917125965, 0.15598987319296406, 0.15018591446982277, 0.198848340359907, 0.14271068897458816, 0.19683271706584962, 0.1929727524158455, 0.17596858823972364, 0.1417474100185979, 0.168878291282923, 0.08788931453900953, 0.10006671110468526], [0.013885175088240255, 0.06210422759214717, 0.04273259126010441, 0.043756732071239146, 0.09027536432709425, 0.09998432600930815, 0.02202285404857849, 0.0680217665109423, 0.06724673067970623, 0.014426207447785043, 0.011334681654379014, 0.0527138052688491, 0.06456907718412339, 0.016736173213669853, 0.057184357316263264, 0.0879995928957097, 0.0026894768656817295, 0.07149094204989172, 0.08500362986758833, 0.036762230578930154, 0.24582491316381963, 6.815795763846367, 100.9484721768287, 114.90610091916977, 108.78858412465742, 86.21942304795789, 142.7829348656439, 83.49381508365755, 58.11724893508419, 89.75215281209638, 32.58328787742123, 85.59652713037308, 54.434519890815984, 8.133116922070904, 0.24303408549918284, 0.05479256569918606, 0.036016332901894085, 0.014138451416886622, 0.3157217181738346, 0.04187505542030258, 0.11183979710744274, 0.2396333292727509, 0.2272034760925078, 3.885387859998211, 94.69237804412843, 114.84743795087262, 108.30610905924152, 98.05301773932673, 92.3627333487234, 80.46984026508947, 74.30970299628474, 78.14804031002906, 85.77009201049806, 86.43105845297538, 87.45976278858801, 86.3354310681743, 84.89131635235202, 81.88299963551184, 85.47333332800096, 83.22604271673387, 83.69172219307193, 76.57318515162315, 72.31964142091813, 68.3083511167957, 67.63231492811634, 66.1447403507848, 71.89775912992417, 70.3364283038724, 71.98190965960103, 69.48110841935681, 69.91373015988258, 75.71879094646823, 81.47914455782983, 74.95853362544891, 71.77218837122764, 66.04846969727548, 80.1118298499815, 84.88011406313989, 96.4149731974448, 89.92364668077039, 83.32760856997582, 91.54209506127143, 82.81570788352721, 74.33364514381655, 71.01858339002057, 75.06189592422979, 91.38459620937225, 80.30958790932932, 47.39773681086879, 84.14358708166307, 78.53450359836702, 86.52088072992142, 81.29712304761334, 81.11263828892862, 80.39464058414583, 87.60363532650857, 89.71877344192998, 89.22415471846058, 85.85609389889626, 77.08800408147997, 75.45271304345901, 84.37105317269602, 85.12461893020138, 73.62356278204149, 69.75975359639814, 69.30248368170955, 68.6433764426939, 68.74546789353894, 71.26203706187587, 82.81230326621764, 86.87076399403234, 90.07840771828928, 82.39285284473051, 88.538940183578, 90.75793481642201, 86.81323066834481, 90.03748955265169, 89.8052538594892, 86.30146334248205, 87.22809976147067, 87.26594278889318, 91.74568960743566, 89.88954559449228, 89.29274912803405, 88.52348604509908, 100.60369583868213, 36.366164838114095, 0.21061713627028852, 0.9569381994585838, 0.34811991357034255, 0.19488472401374773, 0.16245629878774767, 0.054301239039388396, 0.03816125651581153, 0.32658579488915784, 0.06833173334598541, 0.42111191297731093, 0.20479047070107154, 26.042874859225368, 68.75090429859777, 89.91292292071928, 103.33578355850713, 83.31309580033826, 97.48118323664512, 57.256323983592374, 54.02489500661051, 77.6411053442186, 82.09388979019658, 85.13579768519249, 46.59900496082921, 0.794097630968017, 0.11092018516313647, 0.05260171894464762, 0.049100995904976324, 0.059930001115126, 0.1261442138122455, 0.0389775806557267, 0.06971702715682407, 0.031319817475553964, 0.036676723675261584, 0.024145576434450287, 0.06041741306563059, 0.05719906237396983, 0.038448665891924215, 0.025562325815459894, 0.03821239288475725, 0.01423565265271933, 0.05289955860784939, 0.015761119486283393, 0.07786212759392877, 0.01938972749837464, 0.02681014514828642, 0.04119601423641847, 0.00932406091446718, 0.007257152821928744, 0.020543189696787346, 0.02007940389786757, 0.04251488439378239, 0.06779922562981806, 0.04805581065856161, 0.10473058543979161, 0.07046420037025405, 0.02553799294776494, 0.03998482922813104, 0.053396427913779215, 0.02690378407527122, 0.011587518440078826, 0.05729261320084334, 0.06465293316831512, 0.09406194541483157, 0.011593575322730167, 0.05492440943095473, 0.047527796048070156, 0.043580033891503854, 0.07062616667920543, 0.1325529759689685, 0.36603138631870674, 12.577395708330217, 126.25648313953032, 127.39062078537481, 124.17683462942801, 94.6509813493298, 134.6023141184161, 88.3491131567186, 48.10578346252442, 63.200919166688, 42.67110816894039, 56.593466958692005, 67.36863751565257, 9.372154435803814, 0.23253698022134844, 0.10657737827709607, 0.10965754202897511, 0.06461613796531193, 0.243194688171629, 0.06308552110567689, 0.15642347895810682, 0.3858504792855632, 0.35755192680704984, 8.003013374343995, 102.9747058499244, 115.59157433048372, 114.64482399725146, 103.42511161681145, 95.62752600639098, 82.9330651990829, 77.20259220369401, 84.18205768831315, 89.90172063150715, 91.37375477821597, 91.98414617969145, 91.41412381202944, 90.1359724229382, 86.05030613560831, 89.12413427906652, 87.77523117680704, 88.44910221715128, 81.80050434604769, 76.37943575459143, 71.37625648129371, 72.74739942243023, 69.75591751836961, 76.51984091727965, 72.0839697314847, 73.96732714868361, 73.1658535618936, 73.77937501476657, 77.24941745881112, 83.12814820197322, 79.01919088056012, 74.77298198207733, 67.90868513045773, 83.96191858476209, 89.02933059200164, 98.95419797589703, 91.06021619612171, 85.03776196510562, 93.29058570246544, 86.21953287432271, 76.86617835875481, 74.70668608142485, 78.91261223823794, 95.85685130088561, 85.50357480202952, 50.439589792682284, 83.77287603193714, 81.20734783910936, 86.71129611230667, 86.10895341442478, 85.29240223669237, 84.63997871645036, 89.16036913471838, 91.04333431490006, 92.87963897951188, 90.77219655436855, 81.21924831021218, 77.86304089330858, 84.86985314276912, 86.96458708855414, 74.68451684521091, 72.37147946511546, 71.52769134890649, 73.02308713236164, 71.28113900461506, 75.25751236946353, 87.84322938611432, 92.64345738195604, 91.59648264608076, 85.12974154564643, 90.7585310166882, 92.55778497265231, 90.88522357325401, 92.94809218375914, 94.21376259096208, 89.12609546415268, 91.4162968051049, 91.10370743659236, 93.4420362595589, 90.15310533585088, 95.12424668958111, 92.69631524239817, 105.11269569396974, 48.06924266199912, 0.6541323866094313, 1.156200978063768, 0.3195674489102056, 0.09972061556313308, 0.4167630463357895, 0.10739159184477984, 0.08632228935077306, 0.0239986062966167, 0.02301448591864638, 0.4280791455699552, 0.07183585015516128, 24.57238808754952, 62.173803390995154, 94.24795781412433, 108.16467623556815, 92.25502506379159, 69.354643360261, 60.79824778341479, 61.5417879627597, 87.4484428282707, 88.93982210466939, 94.29003700133293, 70.29357248736967, 0.9501293938486808, 0.05558440566904122, 0.009328870989021756, 0.050530201875634735, 0.01663171712519421, 0.12820068491442552, 0.020446932664321318, 0.03258717396566945, 0.022627354877430107, 0.03711063204513442, 0.029434854307422237, 0.03914129364514544, 0.027218967969078692, 0.011626016273493729, 0.022833955384069876, 0.032376603208362095, 0.17099585023618516, 0.04998291632340801, 0.017760926895144007, 0.052883953396831794, 0.012692857867917948, 0.04421655336515077, 0.05862043509560247, 0.02777723347648017, 0.07265837577682349, 0.014886758440444547, 0.07405777326634816, 0.1689817744397348, 0.1382872972997927, 0.11576608198905185, 0.23065185234431299, 0.33542332389662344, 0.17687061080528846, 0.1386630327831353, 0.22609143818338073, 0.13529405388380253, 0.11356596940106924, 0.19644162918050445, 0.16304617116768516, 0.13849571918047246, 0.18602344628062942, 0.2755174239075953, 0.1297731033616489, 0.21096815775719382, 0.21335234595162256, 0.3409754695190538, 0.4708783328533173, 15.570723087556901, 142.86999579398864, 138.90041597427862, 141.70363979954874, 107.04526316735053, 159.1207676549112, 96.86850117098902, 87.32587660512617, 118.8457844334264, 54.46813068082256, 112.8532971105268, 82.97746642943352, 15.448393187215252, 0.5709929091315116, 0.277379936869106, 0.2949883452346248, 0.21257374015065933, 0.8805966184985254, 0.22157986978850058, 0.6518218041427675, 1.0752474252254733, 0.7524347665809816, 8.707315633373877, 107.34946650843467, 123.67627743751773, 117.39673537592735, 110.0158388383927, 100.63965612842192, 90.58967298076999, 80.98036027723744, 89.16952394670056, 94.79794471494614, 96.84244094356414, 98.60240843988235, 96.80237785462411, 92.10304890909504, 91.03860393647226, 93.93775324667655, 93.55163512691375, 94.60460324441233, 84.89995341147147, 81.98342015666347, 74.33059353982249, 75.31174305946597, 75.15981397321148, 78.87172545156172, 78.23339108497866, 79.51326047220539, 77.76449526509931, 78.81904802014752, 82.3593165797572, 88.65723102323471, 82.74517582308862, 77.39496092642509, 72.17951866888231, 86.6093772457492, 92.87952130840671, 102.74833017779936, 92.59130554814493, 89.9497853555987, 96.97960622849004, 88.1772505852484, 80.5792587034164, 77.22833864150509, 83.16316712287166, 99.85814740580898, 91.75700956775297, 57.23006371528872, 85.69038944859659, 82.98624469387917, 90.04712289379489, 88.69528585864653, 88.25430946965372, 92.0553058193576, 93.42597807607343, 93.81338273325275, 96.7792280258671, 97.04330552008845, 85.81485409890452, 84.13754663159771, 89.58054127231722, 91.08833959025722, 78.58999729156494, 76.77907820670836, 75.83285347107919, 77.11448792488345, 75.787369666561, 79.40506581337222, 89.62531905020438, 96.37699680943643, 94.25889338216474, 86.04341845358573, 92.52824952525478, 98.5681975272394, 94.22926379788308, 98.92345443848642, 97.63000580572314, 93.70696098573747, 94.54198652698149, 95.17766937132805, 97.10807954111408, 94.63875139913252, 96.79130892599784, 98.72590034238755, 108.58065143708261, 47.74298383343605, 0.5161293079295467, 3.0797813207872453, 0.5996603482673245, 0.9339873084137518, 0.6532697716066915, 0.41726446620398955, 0.21472189665561725, 0.8648863615047547, 0.21242381674387764, 0.6699079142943506, 0.2891676704729757, 46.361046529585316, 89.24842634508687, 99.47333935768374, 110.43434789103847, 95.5097136958953, 115.57108386870354, 74.25782572838568, 69.66373397457984, 100.94746805006459, 102.35876037228493, 110.27077721011256, 75.71700234566966, 1.3990275609877802, 0.18375749609643416, 0.10919402053038921, 0.2163576782350579, 0.19353720599845534, 0.24149429473665454, 0.10041444607439542, 0.15274377479668588, 0.12586014074904303, 0.1932048464133855, 0.11238142893078829, 0.19679638917648024, 0.18287603533075703, 0.15900401548752863, 0.19488464740495529, 0.13405285355064178, 0.2013303886257833, 0.19524276286603945, 0.09081904926607687, 0.23533395191113796, 0.08614559883191701, 0.12293064350923225, 0.16041173269191097, 0.11663175368260954, 0.1833041865498789, 0.08892624518804013], [0.06265151697481353, 0.062424467666254896, 0.05100806837060279, 0.15648773841319547, 0.030231214196030653, 0.015048165505211201, 0.018006065454814705, 0.02802123056514369, 0.06394460061264616, 0.05311899300244066, 0.07520012527463898, 0.08855915883736265, 0.04531941737138456, 0.033556616099010554, 0.03997684276152042, 0.012373904821523016, 0.04611121520640389, 0.11705217507457542, 0.05783308823142321, 0.08526352519590048, 0.07636193591620653, 40.01514188704952, 127.64140928945235, 107.38170839125111, 110.69877839857533, 88.28417439614573, 127.77651925240795, 95.63268000079741, 105.24367147876372, 80.9278711195915, 62.89377797034479, 58.808064614572835, 8.410601077541228, 0.09116176635988298, 0.1285779449127374, 0.1587609817544299, 0.1572319468663585, 0.09501511201022134, 0.09799317922443153, 0.17468327656388286, 0.365424185029922, 0.17718685190043143, 0.6148910342204956, 49.68725173704086, 114.51369916239094, 99.63792985485446, 105.9572212157711, 96.7244952724826, 92.12935232347058, 77.52967865236344, 78.02006906078708, 72.83785712334418, 78.54063818531652, 83.90577377811556, 88.04525498420962, 88.64653079740464, 88.61079800513484, 89.66112244513728, 85.56149251999395, 84.6474547539988, 82.06493485358455, 78.84224491734659, 69.87051348532401, 65.04208364794331, 67.87928304364605, 65.54915589670982, 67.860957730201, 68.16576511629167, 71.4402146493235, 69.54582752720003, 70.70757081431728, 72.55941590955182, 70.92694113331457, 71.57368506154707, 65.79905010038807, 71.57632089430287, 83.07231718494047, 93.67904939959126, 90.64180912510042, 81.46630271788567, 86.69572430272257, 84.16290867713191, 85.66176399107903, 77.81060664884507, 71.55772101494574, 73.63819322278424, 85.59789995993339, 88.80634384770548, 45.529237331882605, 76.82467183759137, 78.46991000636932, 78.98112820040795, 85.06472433767011, 83.69398147829118, 79.12998214844735, 77.39811451204362, 80.33857422490274, 84.54219402805452, 86.49329862286969, 82.71853508487825, 75.94837511739424, 71.06292186244842, 72.52358113565754, 68.94832503411078, 70.76056203534527, 68.95923706793016, 69.74218922276651, 64.9460679484952, 74.62616766652754, 84.24369381320092, 90.88593744462537, 82.62191141805341, 91.29049070419805, 90.61750611951275, 87.13244884244858, 86.13488812600413, 86.10827876675515, 85.7311507194273, 88.5712605137979, 87.34728490152668, 86.91685968829741, 88.85843292359384, 87.48372062560051, 87.91322015946912, 90.73722470191218, 86.0994298996464, 92.48950435269265, 39.87705092276297, 0.1969832839864877, 0.0782163206848406, 0.09479924375491758, 0.010862944820415108, 0.18577809896199934, 0.08396574926953163, 0.19626830944851523, 0.32488636672496796, 0.08799494274200932, 0.11703427926066423, 0.12554296502663245, 13.45330019151011, 45.05142204223141, 63.832440376281745, 47.988449681189756, 56.742105176371915, 29.27176214033558, 28.369762128399266, 60.70311069488526, 75.5779778572821, 79.27770645387712, 85.88205998943698, 8.475584945371075, 0.7957239437007135, 0.115459531906151, 0.04146131431503643, 0.07068409824803953, 0.0217836948051568, 0.04545234894800571, 0.03134386880593675, 0.04468381337280716, 0.03636159340760881, 0.08305091771387285, 0.031050711855172154, 0.048959698648222034, 0.030348048350142858, 0.04586862580430123, 0.03006377801929991, 0.014183628579391348, 0.036394703727696216, 0.06576546137371371, 0.04322571439608451, 0.022592335083191434, 0.03460486186668277, 0.11272677370617468, 0.07205467550985276, 0.05223203172546722, 0.06961612571631709, 0.029698235335789865, 0.034095218044615565, 0.06130042898979399, 0.06271758056696385, 0.037932043008866816, 0.045641817813438755, 0.015285160550246797, 0.11118703656980108, 0.04027090561125548, 0.041853164457866264, 0.058411285431394656, 0.043273525943438855, 0.0508876929750606, 0.034711861367067026, 0.015719924065765115, 0.07044559975545253, 0.08311258779177744, 0.05965346252665885, 0.028828482308815566, 0.061904493148528764, 0.08724007800581955, 56.42073754341372, 143.26581001281738, 117.01846984124954, 123.58785936909338, 100.4812002182007, 142.33291349103376, 77.38360174240606, 63.64939512745027, 93.0858144452495, 61.82393973873508, 62.39367185100433, 11.974147923531072, 0.09161817090165231, 0.07117443282397524, 0.18471882918909674, 0.05236530804165429, 0.11610843902153355, 0.16672092640111524, 0.1457663532346487, 0.7227731291805545, 0.09018024685041559, 0.5415402605168281, 59.77379921943911, 118.29387557122016, 103.68997358506726, 108.47901498117756, 102.62356742735832, 96.01793519912228, 80.42634902461883, 81.533414471534, 76.76764057528588, 81.42128175304782, 88.61871334814256, 91.91263352670978, 91.11895761182232, 93.51290564383231, 94.75412399538102, 88.97542938109368, 90.13086549697384, 86.56969854908606, 82.63116036691974, 72.87453128445533, 69.01689590946322, 72.08505230565225, 70.05822243229036, 69.54407815010318, 70.93989279962355, 73.25154166067801, 73.04158503009428, 72.49871330876505, 76.93720463783511, 73.17340804684547, 74.08914812149541, 68.78891206556752, 76.17505673439273, 87.94008839514949, 97.614865456858, 95.59692367430657, 84.46014588879001, 90.70815209419497, 89.20566466546829, 87.32277793269004, 81.92625553377214, 75.5323528474377, 76.92253497339065, 89.12111405403384, 91.21831124828708, 50.820773570768296, 76.06503425105926, 79.02758475272887, 84.10709334957986, 88.49115002539851, 87.722898913968, 84.26262317165252, 81.88742406906621, 81.01378671584591, 85.03454562156432, 91.98240464733493, 87.0326872794859, 78.63358266891973, 73.29128311526391, 75.55125082692793, 71.0144413671186, 72.72220211644327, 70.28546102585332, 72.5777647572179, 69.02284222264444, 77.33439953096452, 88.91085932331701, 92.6729065372098, 83.14756393432617, 91.1906663833126, 93.92851998729091, 88.5460396735899, 90.40623157255112, 89.43640985796529, 90.4709820593557, 91.47896843571817, 91.17595749516641, 90.61957713096373, 91.58959496405818, 90.78568166302097, 91.15056407067084, 94.61258134534283, 90.30691715978807, 98.7020601764802, 52.05541018516787, 0.8165803503605628, 0.1475213534168659, 0.1656324227130221, 0.2680357479520383, 0.3668121831311334, 0.19036465204290806, 0.022898965605324315, 0.27382982414095636, 0.06208526691602123, 0.19880307988534052, 0.07616401710096868, 14.001518103384203, 48.59943336056125, 71.32969794734832, 60.69661132750973, 52.085392782765055, 33.59667731869605, 38.432340006674494, 69.29327395654494, 84.19668028431555, 85.77557548399895, 104.27157478947794, 23.990363267160234, 1.1545551760542778, 0.1217351326598756, 0.021166944230395942, 0.07047046696947468, 0.044530591957511446, 0.06172642750184863, 0.017604304049464486, 0.07108413404034031, 0.06750893193267046, 0.05975134558074417, 0.03177272099550934, 0.03292512982302616, 0.02117938932872588, 0.101659017194423, 0.04615238860189434, 0.041641429246914004, 0.04997504860042565, 0.04252472479316977, 0.027132532183801936, 0.12312735956642898, 0.04526044392297345, 0.07351113888885706, 0.015870506308161687, 0.04360801142249857, 0.07778772513472265, 0.12031402423857682, 0.11129442677502671, 0.13235976859446497, 0.15891403079994265, 0.130879242393759, 0.1183567921661081, 0.07768773533884557, 0.16382088524199304, 0.23878885523205806, 0.12396794954134573, 0.17882085615588775, 0.13098275619408778, 0.08401049646518885, 0.10391501589648186, 0.09611539813058992, 0.12694523534587315, 0.2223837258474481, 0.22433544208686199, 0.19551018883864726, 0.18145226092348177, 0.11724060972131069, 66.47644735151722, 166.493678246775, 132.7508455707181, 141.85601603600287, 107.10965279609927, 136.9988509147398, 110.25011416404479, 138.6460267343829, 106.00414060777234, 91.23592269036078, 81.59920046406408, 16.17109577501974, 0.651845644798971, 0.1732832355605018, 0.5454755622533061, 0.24844081231182624, 0.35830621697729637, 0.4221560295310713, 0.6095124841217072, 1.2890834024836941, 0.8057241490291012, 1.0724653616066904, 60.40958796778033, 121.05290212938864, 109.22195896025627, 113.40951273518225, 106.2614167121149, 101.39086846382388, 84.38062375591647, 86.23632846340057, 81.41777515411377, 87.52067719736408, 94.61827662683304, 97.38682669977989, 97.32582599886003, 97.8713413976854, 100.42449059024935, 95.96853686917214, 94.4383575070289, 89.591735716789, 87.5637605113368, 77.8804797510947, 72.51318685470089, 75.2686519007529, 73.29789623137444, 73.56985768964215, 75.6182135305097, 79.05383325392201, 77.25557557998165, 77.09921421543245, 81.6692304611206, 78.00164961045789, 77.42521024519398, 72.55270865655714, 80.01184863428917, 92.12433953439036, 100.1902937120007, 97.74315049571376, 90.15276016727572, 91.91739528409897, 94.30247091477918, 94.40374651262837, 86.2239259289157, 79.08902475910803, 83.08307232395296, 94.54718758982997, 97.46317171281385, 55.64626555288992, 78.06625889193627, 80.74798337874874, 86.12584314038678, 92.22843923876363, 92.10570827607187, 87.86060548597767, 85.60789415913244, 87.61376288629349, 89.99440623867898, 95.44624190176688, 90.60164405453591, 81.70070355938327, 77.82922221768287, 78.12112500590663, 75.65284805913126, 75.84087864045175, 74.07243882456135, 76.15378179857808, 71.88893379703646, 82.01210052736344, 94.60960034401187, 99.31312622562533, 85.44826938259988, 96.24400492637389, 97.11230785615983, 93.21509576612904, 96.48747428770989, 92.49508980781802, 94.79045298791702, 95.04066098120906, 94.57846456958403, 93.70512531649683, 94.87520756260042, 95.67279800291985, 94.77690512134184, 96.37680853566816, 93.37487743746851, 102.87291249921246, 50.91687556236021, 1.0194585123850455, 0.9639441654566796, 0.7881008172708174, 0.6981995413380285, 0.9539524177389761, 0.4048130246660402, 0.5405020581618433, 0.6952387034412354, 0.38083116313622845, 0.2314498401697605, 0.2387640799485868, 23.67120981216431, 59.502057413901056, 77.32568402444163, 67.37826301205543, 73.24646611367503, 39.832814431959584, 42.30042849817584, 77.75386564193234, 98.33161584792599, 94.85212833650651, 120.78191341892366, 23.92474397536247, 1.2286860111259645, 0.2953283350554205, 0.16402944501849914, 0.19339477493157312, 0.15956948030619852, 0.23042562658027296, 0.18722036673176676, 0.13848632694252078, 0.2249395790239496, 0.2520486267824327, 0.14597138900670314, 0.09248195035803704, 0.12329318695851874, 0.18665396728582923, 0.1584214515863888, 0.1349235737636205, 0.155650848642953, 0.1341277922713949, 0.12037188685949772, 0.2423927626542507, 0.14336667474239104, 0.2590789237330037, 0.1466908528199119, 0.21610984879155315, 0.16928833218351488], [0.050804959309677926, 0.0015802027384427587, 0.011853269552962195, 0.038941386831744064, 0.03678835417714812, 0.0023114009837304516, 0.04795572893213361, 0.03997169465066926, 0.06729584457653184, 0.06268624374042116, 0.011119461700981183, 0.03868745932836206, 0.01504679803826636, 0.024574928496393467, 0.004346398401990413, 0.07232910352608851, 0.08429339741386714, 0.05893957200309923, 0.02804575878525934, 0.05024974091699527, 1.422080923953364, 87.9965469914098, 107.28687332522486, 91.62690454913725, 61.604836140909505, 48.4713012941422, 28.963399125683694, 34.53208415738998, 97.78364504537275, 66.39716840559437, 55.65580475714899, 23.695110774809315, 0.10805255718409054, 0.02318700700397453, 0.16143185537188284, 0.11565197319273027, 0.1268377149057004, 0.08805131149147788, 0.1972581103684441, 0.2590706193399045, 0.6097782247008816, 0.8441629477085606, 23.95829789100155, 117.26936817169191, 101.96098496837001, 107.45741798031716, 92.98300127829276, 98.02745957528391, 87.65236685352941, 85.10878824418592, 71.64011432278541, 72.97794849641862, 72.32627022650935, 76.37475244460568, 82.14420595476705, 85.59353043956142, 87.2893044256395, 87.4202488314721, 88.18105528431555, 85.9949536477366, 79.39384783467939, 72.56996708531534, 64.31918298044513, 67.87083425829488, 67.07781730159637, 66.59502844656667, 64.26937280162689, 68.64603580967074, 70.03662586212158, 67.21100530316754, 68.24028230482533, 69.01105157790646, 69.8582286219443, 64.72774097996374, 69.22707219277659, 83.97579593043174, 93.65233021397745, 88.30807731997582, 76.20767516474571, 83.82054067427113, 85.40218153307515, 87.43622856755411, 78.50569771182153, 77.69699127443376, 67.18529024431783, 76.5345262712048, 79.86351243911251, 88.862716151822, 46.88746783041185, 74.95017897698187, 81.77439705018075, 81.28034314801617, 80.65579199021863, 79.92596441699614, 81.89463338544293, 80.1816951074908, 76.34110635326755, 76.97420827804073, 83.93963167744299, 83.17506759397446, 75.45501155237999, 69.93948444243401, 66.94407232346074, 70.6113080055483, 70.57562228172057, 68.9805120037448, 65.87121778918852, 67.15088321316627, 73.5573688630135, 82.70229647236486, 84.48756325629451, 82.76248916502922, 88.50518426587506, 89.85733509063722, 84.40447961130451, 83.48779032307287, 85.52953304782991, 86.50266524284118, 83.36919353854272, 83.63509885726437, 83.82953074670608, 84.95279558243291, 89.93644929701283, 85.10601905084427, 84.51463545522383, 89.97557886185186, 86.54359125321912, 88.73414870231383, 30.16838262158056, 0.14023452426397032, 0.23983407495242937, 0.609408296164005, 0.13206104026927104, 0.28471449329968423, 0.12016531891159474, 0.05028044572100044, 0.2689013353759243, 0.07727754122066884, 0.01251199216987457, 0.15072594516940657, 20.76420987806013, 27.88545531611289, 40.912517424552675, 41.716548396695046, 53.39441322511243, 29.521925026370635, 39.812951549406975, 70.50097173260104, 78.7428520571801, 81.67275274953535, 70.721040233489, 2.8529356996859274, 0.2624369016097438, 0.0888400832791963, 0.03853705711662769, 0.0651783928755791, 0.0903390492162397, 0.05821970599373022, 0.10084700995996114, 0.04137201527614267, 0.04147765114002171, 0.07051607984448634, 0.046286316092817054, 0.028663332904538805, 0.045821396483769344, 0.02963676827118522, 0.006882915040478111, 0.08780434772732758, 0.046530498957802216, 0.030337064564528487, 0.036052844652365294, 0.05266906956451074, 0.040522561663942, 0.024929209687416593, 0.006171278730635682, 0.0601232736071031, 0.09589732354206425, 0.02488596210887115, 0.04281252487412384, 0.02034333267910106, 0.025258612173098712, 0.04142079209428161, 0.026442616381832672, 0.053592971601192994, 0.05437756054884484, 0.07993635661419361, 0.05924067137041881, 0.03223301534871421, 0.03144194912766257, 0.05835745626339509, 0.023294602137719913, 0.11783041315333498, 0.09565048235198183, 0.04957366449337813, 0.06140596909268249, 0.06678185320549435, 3.0611368244694126, 112.61060437848492, 118.9325394168977, 104.28370275805074, 74.29603745860439, 71.57880767699211, 59.3296221763857, 42.72604488557385, 83.74493306682956, 68.55052609597483, 54.32630562013196, 29.342121616486583, 0.17517508968951243, 0.07288156783268337, 0.1475061235889312, 0.290018058712444, 0.3832766996516336, 0.11530832913253578, 0.3458625282491407, 0.38380269562044456, 0.5581264317997041, 0.70269531299991, 31.107056794628022, 127.28274776089577, 106.0432937068324, 109.99291650710568, 97.42737616262129, 103.14448956520327, 90.60537815093996, 90.33735475232525, 74.37133127643217, 76.11242432748118, 75.33827397131151, 79.6278799733808, 84.79066048899006, 90.21848340188303, 91.13165824644028, 91.66279423621394, 91.41253132973948, 90.29038044714159, 83.81261748652305, 76.90276622772217, 67.6144681438323, 72.32613686592349, 69.93953935561642, 70.45696273926767, 70.31341183570125, 72.53275163712041, 73.45275925051781, 72.49332397214829, 70.32188415527344, 71.80651695497575, 70.92228135754986, 68.20578113678964, 71.17668628692627, 89.63124967390492, 94.90475085473831, 93.6724833519228, 77.70932320625552, 84.99711836538008, 88.0045800055227, 89.84600728557956, 80.90624317046135, 79.25716107891452, 71.06180790931948, 80.95456677098429, 85.50621847952567, 92.999373251392, 50.60360370143768, 74.5418994657455, 83.52606481121433, 83.60337472731068, 86.15511971135294, 84.97035211132419, 85.11675065563571, 83.28228166026454, 81.79402459052302, 80.31484388536023, 88.75241910257648, 85.8379254802581, 79.5116993688768, 72.7070931465395, 70.01444878116732, 73.68217868189659, 74.50607253659156, 70.75890679513255, 67.35049263123544, 70.39926467403289, 78.55437432565998, 87.71052775844451, 87.06856912182224, 86.11296992148124, 90.38884762794741, 92.98655494566887, 89.86408941207394, 86.95744837484052, 87.65507328894832, 87.6462479560606, 86.77747434185397, 88.21015927099413, 87.85235281913512, 89.30652449207922, 93.81924275429019, 87.69242209772911, 86.4740554748043, 91.68838377921813, 89.47187592906337, 96.5998266589257, 42.99699044996693, 0.33955909552112706, 0.4690947269480075, 0.998259511205458, 0.08589874232007612, 0.5343732934805655, 0.13185862451791763, 0.08968723096674489, 0.12672717607910597, 0.17596540131395863, 0.0335919710567161, 0.3555049092298554, 25.74249190668906, 28.102999771794966, 41.56381130218506, 39.905546942064845, 44.466894749672186, 39.999287666813025, 56.83326890391689, 81.62088332637664, 84.83563438538583, 89.38236744173112, 96.93551094301286, 7.22966367198575, 0.35868665624049406, 0.09853690246781034, 0.09100966726339633, 0.031683117436665686, 0.04723081440334359, 0.03479090631909428, 0.08147368823448498, 0.11195523889675257, 0.03837815132893382, 0.08986505529572887, 0.014971437011544984, 0.08482553740783084, 0.021606458448654702, 0.02077812205008682, 0.058131533104085156, 0.04601438935365408, 0.042486749814763185, 0.03176467515708458, 0.02965796017839063, 0.08828368128067063, 0.04333370214989109, 0.05274974628381672, 0.03429093435707112, 0.06389031562233163, 0.33265952381395525, 0.14924302877437684, 0.08548240417674666, 0.12698262043657804, 0.09351705005692859, 0.11710700398731617, 0.11423861758122522, 0.2146409058402623, 0.1349279098212719, 0.1835987167132478, 0.18752413591550243, 0.11268974101591496, 0.22599558526229477, 0.16825091123821276, 0.17698316444312373, 0.24027316590710995, 0.31202859215198026, 0.1370457445661868, 0.19231906491181544, 0.20774905629936727, 3.606159475541884, 132.20289045764554, 132.48346544081167, 120.3043334714828, 88.9534797976094, 75.61593855580976, 42.50275611877442, 48.294826015349365, 125.23356037755167, 83.98697468542284, 78.46710943406629, 41.25835672501595, 0.6280944676649186, 0.2132409261239152, 0.5425855108807164, 0.5447884120287434, 0.8461201491375124, 0.19014460094753774, 0.766008434997451, 0.44925813653296043, 2.632508792223469, 1.1763546063053993, 31.33601534751154, 130.76276086991834, 111.7439566889117, 113.32599762947329, 101.92751146131947, 107.63210465831142, 95.767789963753, 95.29358325466033, 79.7433231722924, 80.41393080065328, 79.8865681309854, 82.9514846494121, 89.64168317856328, 95.68527114006781, 95.88568072165214, 95.30998660672097, 98.03357062801238, 95.06483062621086, 90.4338607480449, 81.80969053699125, 70.35385931691816, 75.91864355148809, 75.24960487119614, 73.6831828086607, 73.01875683569139, 75.39999638834308, 76.85083404664071, 75.57103526207709, 74.27488803863525, 74.84101157034598, 74.82440425503638, 71.52510258459276, 73.89265306534307, 93.19218127958237, 96.62041125759002, 96.07947718712592, 81.74541857934769, 86.96545785473239, 91.18854830341955, 96.07464482707363, 86.50717596853934, 84.64836474387877, 74.32314888123544, 84.28619661638814, 91.30822766211726, 97.737761159097, 57.817066023426676, 74.9353837966919, 84.03894609020603, 87.54028904822566, 89.66494283368512, 89.28229993389499, 87.69341837975287, 86.47016448359336, 84.95780052677279, 84.51678491407826, 91.11036762114495, 91.7628852782711, 81.75471459665607, 77.5736641114758, 70.74164052163401, 76.69775178355556, 76.33165344115227, 73.16886594218593, 71.37336961684689, 73.78107732342136, 83.72752558800482, 91.69028220638153, 91.96596207157259, 89.43248748779298, 99.64450374726327, 96.77924371534779, 92.46233017213883, 90.05542262907952, 91.46105889351138, 91.33067930898359, 90.70247250218546, 91.16831671807074, 90.33718216803767, 94.89448993436753, 95.86711222125639, 91.87910510647683, 90.87503325554633, 96.42998803046443, 93.08881113606115, 97.45077702306934, 41.21968999985726, 0.456940496881162, 0.9742294167799335, 2.0305145724165827, 0.24210937140930086, 0.5695028374752691, 0.5021776517312373, 0.23893799722915698, 0.5631495783886602, 0.23950410556168328, 0.15105980628680798, 0.6557824787112975, 37.65816219391362, 41.00596004916776, 57.650533953020656, 62.22077377380864, 72.15796132241526, 43.58341224731938, 60.47470323501095, 92.34301951623733, 100.69786410177909, 101.13350606733754, 106.58261960552585, 6.086628619701632, 0.5233649777308588, 0.23947344672295356, 0.1447819302519483, 0.2982827684571666, 0.15535970458820944, 0.18589803768742472, 0.23065522313117984, 0.1441238454032329, 0.16639880175071378, 0.22734918601570592, 0.0732800561273771, 0.3007363335740182, 0.23922603096692796, 0.12537577399803748, 0.167081079656078, 0.2620979536685252, 0.12232291361977979, 0.103913537346788, 0.134821331669246, 0.15387805989913403, 0.11197431448606715, 0.09226307137719086, 0.16999088077535554, 0.16616952695673512], [0.010775011333246386, 0.010638911983058339, 0.03883399662651843, 0.03946786926638696, 0.06863538761653247, 0.0494110623314496, 0.06922754293848431, 0.027665905579323732, 0.017955011440320842, 0.02739395585752303, 0.026139532846789208, 0.04308575396275809, 0.05259996460330102, 0.13096705139164003, 0.02785614627834049, 0.023905631950906208, 0.05892781638390115, 0.04709467291831971, 0.20524411732631348, 0.45326253940020844, 11.984505922563615, 110.41266502872591, 100.75966496621409, 91.59321923409739, 61.308995293032744, 34.322849242917954, 25.761413420400313, 25.268414635812086, 59.32173821233935, 67.61201274010443, 39.81615612583776, 1.4046821478874454, 0.3505652968681628, 0.08986872485688618, 0.13045061620012408, 0.3005183662378019, 0.453678218707923, 0.28405489159687874, 0.47284969158710977, 0.5555825295948214, 1.8535722864250985, 13.342309863336625, 113.37629025982274, 101.34343131895989, 100.06141247287874, 91.33956739979406, 92.82395701254569, 89.30809344014814, 87.33921266371205, 80.45535887441328, 77.05548763275146, 69.62906806699692, 69.15743443273729, 70.85724846009286, 70.71773759780392, 79.15659150769635, 81.72972909865841, 89.04256466896304, 88.30726146698, 82.57707872698384, 73.33928508143272, 66.11402034759521, 63.67063868430353, 65.2867454098117, 65.74033614127868, 67.01440826539071, 66.16968662508073, 67.98760321832472, 63.56942976674726, 65.71706864141649, 69.07079712037118, 71.85623691928002, 67.4650650639688, 66.29932095927578, 78.64937413123347, 90.02508701816683, 86.8907759266515, 74.6502588641259, 81.72208832156274, 86.07960624079551, 82.77787270084505, 75.56645393371582, 72.09583097888579, 70.8644107080275, 66.8501001788724, 73.88518487253498, 80.65247366505285, 89.88307368370795, 45.697754121595814, 66.87491309258246, 83.25288741819321, 78.8817588744625, 84.50686916228264, 81.40441556130686, 80.30740707151352, 81.52195330589049, 87.62425130413425, 80.49054253485896, 84.93006152491417, 81.49550868618874, 75.38594645838585, 67.29601875428231, 69.18194924631428, 68.30929248563706, 69.19664244497977, 64.56935175003545, 67.37015155053908, 62.741644920841345, 77.34702171817904, 81.5605886520878, 87.50443858485069, 86.67171155252765, 85.35989838261759, 79.08485920198503, 81.37968109500024, 78.15380619418237, 81.00468681704614, 81.55035126593806, 87.48195555902298, 83.66884693022698, 80.83695057899722, 86.60290533496489, 87.63237845513129, 81.17885574217766, 84.32192940865794, 82.37177402742448, 94.1095216812626, 79.6781647589899, 84.31826591491699, 21.08020386388225, 0.3344919141982833, 0.27136280652015443, 0.9285648155116266, 0.13047490118732377, 0.026319385393552726, 0.13951277750874722, 0.12673895085050216, 0.10511491642964464, 0.16094211068364883, 0.10476515132693515, 1.771314300356373, 29.107869825055523, 42.953499209496286, 60.046494160929036, 50.14258400086434, 31.597047121294086, 23.472049505479877, 46.39460632877965, 58.45268610985049, 83.25632341446416, 82.60207206972184, 35.14662542650777, 0.8968496334648902, 0.08216324397512982, 0.11925578102349274, 0.03431478650459359, 0.036414426661306815, 0.13684092329875117, 0.04333701931060322, 0.043754927934177464, 0.035939547909243454, 0.027330678910197272, 0.0429833471594799, 0.03697958121436738, 0.03009821175627651, 0.0731799744009491, 0.057182817479535464, 0.03988334939124123, 0.03131748473782453, 0.04956088614680114, 0.05309260510388882, 0.06940996379501398, 0.024645073421960397, 0.04428592645713399, 0.0127513553842061, 0.02596803448883997, 0.05118103570214683, 0.05021274270069215, 0.030877334666588617, 0.013253605500194094, 0.018270273858140555, 0.044415540873043, 0.05470104883575151, 0.008379249465501597, 0.02576383758306263, 0.0878047614148067, 0.009487583339514752, 0.1015315708073397, 0.04884619506136064, 0.06220736600939305, 0.04644522188051094, 0.07522080198771532, 0.19284504555886794, 0.1673124228874522, 0.3391872364426813, 0.6492135505522452, 21.00889321296446, 131.61122445137272, 110.3206854481851, 105.59015797030543, 74.52774755416378, 48.70245049076696, 40.649196947774584, 36.014328233657345, 63.10080851277998, 57.72343120267315, 42.45258900427049, 1.9064764798648897, 0.6521412321636755, 0.22080904744084806, 0.24898370818024684, 0.17814144341936036, 0.5183366830310514, 1.0616691602814583, 0.7477511501600667, 0.08666119132671626, 2.102024406194687, 20.232126635889855, 121.78449476918867, 105.31544300817676, 105.31249338580717, 94.49058778824346, 96.49669185761483, 92.7831643627536, 90.17834186553956, 86.0960566612982, 80.98884828629033, 74.61289436586442, 73.49373232933783, 75.22658055828464, 74.57598486254292, 83.45739195423742, 87.5886832514117, 93.05691442181988, 90.63034011471657, 86.79951021748205, 80.53361015935099, 71.14083582355131, 67.78890379013555, 67.50046053240376, 70.09095068900817, 70.16131016515916, 68.31939651120094, 69.00854126099618, 67.96684603537282, 70.09816000538488, 73.36412937410417, 77.60450178577055, 69.56704754983225, 70.6619458044729, 83.7379434031825, 94.66358784706362, 90.69873056104107, 76.56315957346271, 84.43779622354816, 89.79521259184807, 87.61110351931664, 81.11725099625127, 76.24343933597689, 74.97528999082505, 70.33125861998528, 78.88593227632585, 82.64634778422695, 92.00989261750253, 49.50164910285704, 67.05009398921844, 85.71011897056334, 81.0787647001205, 88.16221221800774, 83.90065116267051, 86.00162952176987, 84.83956460029849, 89.54442408777054, 84.12517547607422, 86.60405851179554, 83.62272770174089, 78.33278394514515, 69.50843164997717, 72.57494849543419, 70.58957807479366, 70.71300721937611, 67.28902909063524, 69.74481721078196, 67.14909461236769, 81.02712277443179, 84.98846561677995, 90.24291192331623, 86.36091862955402, 89.54434564036708, 82.34532156298238, 83.94703711232832, 82.12950491136121, 84.67990060006419, 84.9090454655309, 91.21508706000544, 85.01585160532306, 84.26929120094546, 89.86021411034369, 89.0783602191556, 85.03104686737062, 87.70622884073566, 84.3091111029348, 97.66405197881885, 84.64281851245512, 90.64931654161023, 30.870065227631603, 0.16413027751109294, 0.6333665621857489, 1.272282174998714, 0.6134227807483366, 0.4740708970254468, 0.3308213111614028, 0.1745463000430215, 0.31136347461611996, 0.20024933131231418, 0.23736362525772667, 1.344611293846561, 31.93104478620714, 45.168700910383656, 61.39248294215049, 39.205082231952304, 38.87990597755679, 41.622807671946866, 58.04764647637644, 68.91902492892358, 88.95905740799444, 90.98831130612282, 58.36497406805716, 0.4132718610907755, 0.07439602406755572, 0.06995739490394631, 0.10828092799431856, 0.048850335766591375, 0.10375542446009575, 0.035869339781422774, 0.06542276726254533, 0.06667607944578895, 0.0680598334198998, 0.045604850240652604, 0.03575736070953069, 0.05459532870220081, 0.004190816957082961, 0.05162192696344949, 0.031235471195090684, 0.06012058463848888, 0.07325266848408407, 0.06493780296295881, 0.08784141106110427, 0.06925525999958478, 0.028848835349743886, 0.03567042888232297, 0.019077236403621013, 0.08295011586479603, 0.12625108307768262, 0.12902541686930966, 0.09371443261061946, 0.226312592445362, 0.16420736127803404, 0.19805792148315138, 0.116597187795466, 0.09458314567323654, 0.15108101160055207, 0.19821020444073986, 0.19991999011366599, 0.26330270353824864, 0.18206735291788656, 0.1058017908625545, 0.24761553643451584, 0.2194349921398586, 0.22318166770762016, 0.49979481185155533, 0.914281320668036, 26.0012153656252, 151.94505814583073, 122.78928833623087, 122.61821023879514, 85.18097554483722, 55.82940493860553, 38.4054756933643, 39.2840709224824, 79.11921131995418, 94.5278424601401, 64.1939809245448, 2.505965040576074, 0.7155376432403442, 0.30270717136802217, 0.29539452505207836, 0.9020867943763734, 0.6495903432369232, 1.054672264764386, 0.8050218609071548, 1.2770617056277491, 3.2305550238778515, 20.192789185431696, 126.4491185834331, 110.10439811214324, 109.57270514580512, 99.40813387593916, 103.03351002354776, 97.99179738567722, 96.75580363119803, 89.8686864299159, 86.39774968547206, 78.99246385020595, 78.48727826149234, 79.25911441926034, 78.34880290492889, 88.15857225848784, 92.46317740409606, 98.19332092039048, 98.05836785224177, 92.65464398168749, 82.4329786915933, 75.15692710876465, 71.10842920118763, 73.64282946432792, 74.82412968912433, 72.81622917421403, 72.0537753258982, 74.90634256793608, 71.64336989002844, 75.76985236137145, 77.70380835379325, 77.45007807208647, 72.60561358544135, 72.6047428192631, 86.19926206527218, 98.51746559143068, 93.50954025022446, 80.5085305244692, 86.79592517114456, 93.70630202754852, 89.14269493472192, 85.2306092169977, 80.1773726555609, 79.39400472948628, 73.33055388542914, 83.11492981449251, 87.36108379979288, 98.10392225942304, 56.82331785078972, 67.96470442125874, 87.9487568332303, 85.74346696176838, 90.86998124276438, 87.42436732015302, 88.7071471060476, 88.78261350816297, 95.53406376992503, 87.8103599240703, 91.84840079276793, 88.39448713487195, 82.71228282682358, 73.50055725343766, 77.26131792991393, 73.94063149729084, 74.86256107207268, 69.49411499884822, 72.36365041425152, 68.21527327260664, 86.3098729041315, 90.05336730710923, 95.36904181203535, 91.84319972991945, 95.77585435682728, 84.17242434716995, 88.38295536656534, 87.45493827327606, 87.49004348631829, 89.37496200684579, 94.53272188863447, 88.11262561428933, 88.53737908024942, 90.44662414058563, 92.6583545438705, 88.24492716020154, 89.96669077104139, 88.4455014813331, 104.7053026383923, 88.14594222653298, 93.11254147560366, 30.407051001825643, 1.0796723490761173, 2.403109217843702, 1.9982817600811682, 0.6164669690112914, 0.5020176006420967, 0.8950992757754942, 0.38462339029196774, 0.3642787916525718, 0.319149624556303, 0.33439532583278997, 2.9717278672802836, 49.10033964341687, 62.95228012146489, 85.4376397594329, 71.25392560035952, 44.21735748167961, 38.9165291478557, 62.220899289654156, 81.43515125397714, 100.96335364926247, 106.66469912375175, 62.73197627836659, 1.3191487375767001, 0.17612779663214762, 0.224263031456259, 0.28704438118203995, 0.15075488797118589, 0.20745086423572034, 0.2133437657668706, 0.20221543468294606, 0.11293285135780612, 0.1467704187117277, 0.18265944695280445, 0.21337778007070865, 0.1547515686721571, 0.19962118517967964, 0.1966393105084858, 0.12614651207601832, 0.11844596480049434, 0.2282653812078699, 0.2315090587663074, 0.1323770821815537, 0.15009024540983862, 0.07226599320288628, 0.12549513815751961, 0.13153389516857364], [0.03233667853618822, 0.020563144371995044, 0.12818593006100387, 0.010091493323054767, 0.06347204693743298, 0.060523665630288666, 0.07063598792639471, 0.027482552010746255, 0.011889349421366088, 0.08127396911262505, 0.04828563320540613, 0.09691854172776784, 0.08977424323318467, 0.03886180944860943, 0.06579978211272149, 0.056719476011611765, 0.05435202683832857, 0.0446344236843288, 0.1371991613339032, 0.267913572249874, 39.22541972129576, 118.39229568358391, 89.44720422067951, 101.36265093280424, 60.50392489279471, 46.24513656862321, 50.176053585544715, 49.13020849227906, 51.91976285749867, 45.6004205057698, 10.826065271131455, 0.5600034085012252, 0.4078446490870368, 0.08998181475626846, 0.20138093510702734, 0.3099996542497989, 0.2104644549469794, 0.8202625366468584, 0.2460600255477813, 0.5921125436021436, 6.178999456667132, 105.78657457905432, 106.87824864541332, 103.77734045828544, 95.07353044325306, 87.9509376710461, 85.63505265020555, 86.5675098665299, 82.7448541887345, 81.74669727202385, 80.30022128935784, 72.84483109751056, 71.09324178388043, 70.08532601018106, 67.41667086078276, 70.68237350833031, 76.94986604875135, 82.74780381110408, 84.90676264609061, 80.70366844054192, 69.46647797861408, 63.32867860794068, 65.46681357968238, 62.36605444262105, 63.70529674714612, 66.39730176618023, 64.4334690801559, 63.52339683040496, 62.934241141042406, 65.76655326351043, 67.67472359441942, 72.29287516686225, 64.02490715826711, 80.93731618696644, 84.8064519513038, 96.25914527523904, 82.87359422253024, 78.88468496261105, 84.99565139893564, 81.42832632987731, 75.46603341256419, 73.8612505697435, 74.35268432863298, 74.67300076638499, 70.69238339701008, 78.00548568848642, 78.40859551583567, 81.51874480708953, 43.49432737596574, 72.25685996394004, 82.62291554481753, 79.23627053537678, 81.12545659465175, 79.78872852940714, 82.73832736476776, 78.96714887311383, 81.87182872526108, 79.83447121035668, 78.55144823751142, 77.01948027456962, 67.86134212247788, 65.16938417188584, 68.98638771426293, 75.24021471700361, 68.7234006389495, 66.28207821999827, 66.99005034662062, 64.59616899490356, 73.98415411672285, 82.18911709324007, 83.8536140995641, 82.09242282375213, 80.442901426746, 75.49580420217207, 76.62748644428869, 78.1981917350523, 77.35883589713805, 79.76761833313974, 81.71633028214978, 78.62209012431484, 84.9904268018661, 83.13263539345034, 81.80114761475595, 83.23767646666496, 74.68808620206772, 84.97207010945966, 86.28331845806491, 89.83861754017492, 87.79581577547135, 88.44129670050837, 11.340078153917867, 0.4169853344078987, 1.068381316238834, 0.1813477818523684, 0.041279820424895135, 0.07460505881857488, 0.10684814439305376, 0.38180020307340934, 0.09097744560530109, 0.07137754571533973, 0.036029053791876764, 8.01258837023089, 27.339871275809507, 45.94230997946955, 62.593869624599336, 39.833289038750436, 20.92760209114321, 22.7137259129555, 54.87555511536137, 71.8365623104957, 84.74887940191454, 74.51577648039788, 3.7137773008115835, 0.3430112409255197, 0.04263181239366532, 0.016077699575332866, 0.026337141396417737, 0.10098236237442303, 0.038415452149967035, 0.047773878811107534, 0.00961442260191806, 0.06980362573578473, 0.006714511677742966, 0.045917287709251534, 0.018868088654633013, 0.059951677572943514, 0.0056748470524325976, 0.01691573656224195, 0.0927456071780574, 0.0699128468911494, 0.05116564882618766, 0.01685999217443168, 0.07041807421633313, 0.029387245773367827, 0.02766996776054223, 0.0912166795422954, 0.04552813419591516, 0.03181950023938571, 0.027825378272081577, 0.06810628133074892, 0.0364397841716005, 0.0314215520366786, 0.016624481424749378, 0.057464243708959514, 0.059664249044632724, 0.0522418184986999, 0.03901472059829582, 0.0539937275161426, 0.05382835594636779, 0.045685216694349245, 0.024235999707372922, 0.04837202494062724, 0.015800330739077783, 0.01525221015101359, 0.18739241475780166, 0.11411973605713538, 54.907318469016786, 133.33727129044073, 100.78962402959024, 113.56385800146289, 69.38161357756584, 56.992144507746545, 47.45316774614396, 44.62871605350126, 54.031888592627745, 55.84353723833638, 10.500621314971678, 0.5835652087003954, 0.2946165167996961, 0.4797801519593885, 0.19672106741176498, 0.6891641777849967, 0.8751128998494918, 1.3119265509228553, 1.7931427806615832, 1.3889915640315702, 10.384568187498278, 116.67334833452779, 109.01586978666245, 110.61558492722051, 100.55865133962324, 90.78453633093065, 89.64263239214498, 91.48870375848587, 87.48477966554704, 86.85127765901628, 84.43308937934138, 78.14041522241409, 74.40890758268296, 73.14313519385554, 70.34490846818494, 73.89680293298537, 82.26037086979036, 87.41310227301814, 88.94234811106037, 85.91443523283928, 72.46416507228729, 67.17113048799577, 68.34277383742794, 67.70198406711702, 66.53798933952086, 69.60362757405927, 68.48213564965033, 65.86727188479516, 66.80268656822943, 68.6720254344325, 70.66504447690903, 76.93850686473232, 66.18364241815382, 85.1545701488372, 88.50422720755301, 99.3250031625071, 82.81761415543096, 81.45546128672939, 86.37335254300027, 85.15225595043552, 79.35859357157062, 76.87703547939178, 77.84405662167457, 78.9235556510187, 75.02586503182688, 82.59302708410448, 82.44167066389515, 86.10321890923285, 48.950210925071474, 72.95125284502583, 85.28355336958363, 82.2988179422194, 85.69316648667859, 82.43683830384286, 83.48560948525706, 82.14655937687044, 83.64222188149729, 80.6622560562626, 83.40798577954693, 77.84002442513743, 71.96394520421183, 68.20256479324834, 71.68340160000709, 79.47914369644658, 70.47697467188682, 69.46330870351484, 66.44779051503828, 68.27364598551105, 76.35815297403644, 86.53093768704323, 86.31902771611368, 86.09089482215144, 84.05518470271942, 79.30680259581536, 79.78151921303042, 81.88908715401926, 79.85897817919331, 84.86203978138586, 81.09305781702842, 84.50056199104556, 87.79603542820101, 84.0088144425423, 84.89868256353563, 84.96347227404195, 77.00629326605028, 88.53941871273904, 87.15074277693226, 93.51006584782755, 89.377880250254, 96.68593052894839, 17.86380344821561, 0.41288017565684937, 0.7834092948225237, 1.3678889673563743, 0.5882568537227569, 0.3181138430391589, 0.5734779757838095, 0.5366937431596941, 0.32732556003236, 0.05069577262826985, 0.14575873832068137, 7.250025676142785, 31.192225179364605, 39.364608949230565, 36.20315505612281, 29.483962366657874, 30.111182697357673, 40.05989220834548, 67.75997238774454, 83.22230077558949, 91.10539405576645, 93.65588388135357, 12.770622449536479, 0.749245511908685, 0.14107501464745692, 0.11845572476064968, 0.044369908845833236, 0.042232657602477464, 0.08191208971003372, 0.04331212145306411, 0.0670843813267927, 0.106217845553352, 0.047461724795040586, 0.0829688313927862, 0.062297369849177144, 0.037670389508768436, 0.04176486899415332, 0.02370905378953584, 0.02872523663926029, 0.006674034464653702, 0.08163862696458256, 0.03126521455875087, 0.12915644854787858, 0.027995133780003078, 0.02726866792316639, 0.08550608395448617, 0.14251043359118123, 0.08527609669873792, 0.17338930809449765, 0.17139490543594285, 0.16890242305253783, 0.18890632707024776, 0.2209516930123491, 0.12172554889994285, 0.08834394175679454, 0.13454086688016692, 0.1462676352070224, 0.16581070669476064, 0.3030793981686715, 0.08801039473544206, 0.13763017772186187, 0.11145747326795133, 0.12744850914684996, 0.11933753792677196, 0.28271102016010596, 0.23613442186146016, 62.14380118154711, 153.68320157451015, 112.30549889226114, 129.43884326565652, 81.21915417332804, 66.00926952977335, 68.7377800480012, 75.14201425736951, 71.7918472905313, 75.03728697376867, 14.910078279433714, 0.6200346711181826, 0.9445329070571931, 0.3213519128339906, 0.5049958134130125, 0.6931393160935372, 1.2717119604349136, 2.1024026697681797, 3.562273301424519, 3.519375074294306, 10.598898260824143, 123.41564378430768, 112.10956865741362, 114.16090549961214, 103.66134028280936, 96.02569364732312, 93.12670907666607, 96.30634707789268, 90.84305024916127, 91.0724304568383, 87.64929171531432, 82.34419192037275, 78.92141403690462, 77.27255944282778, 75.25468826293945, 79.30597889807918, 85.90028332125756, 92.69431483361029, 93.67435824486518, 89.38201442841562, 76.10321460231658, 70.34657939787834, 72.34239116791757, 70.72891635279503, 71.6451035776446, 78.19001751561319, 72.31807247284921, 69.83447474818077, 71.36499927889916, 73.41078988967404, 75.23025189676594, 79.55344907699093, 70.9812581154608, 90.27783670733052, 92.54804964988463, 104.23002119987243, 86.1631448807255, 81.72375925125615, 89.55369657085788, 87.72211443993353, 82.14130340083953, 80.87266768178633, 80.30524976791875, 83.4738031510384, 78.01808434147989, 88.19879224223476, 86.91522798230572, 90.35822176164197, 56.0904190617223, 74.39085683514996, 87.83130538079047, 85.05910750358336, 89.66940649094121, 86.095915455972, 88.99926170226067, 85.88630399396344, 88.15460281987345, 85.67593943688178, 87.52482706500639, 84.11216105184248, 75.31386113935902, 70.14771523014193, 73.90506344456827, 81.72595577855265, 74.11822072921261, 73.32444283270067, 70.41964530944824, 72.45535542888027, 80.0293424052577, 90.64031862443494, 90.64496271071896, 91.39335878433721, 89.05851302608367, 85.51293357726067, 83.3451101856847, 86.00384173854705, 83.41215133666992, 88.39848795244771, 86.61235824708017, 91.29931603708576, 90.37894756563249, 87.361860429087, 88.69220287569108, 89.92264255400627, 80.51144092313706, 94.22640831239762, 90.04331034998741, 99.64638648494598, 91.94563634933965, 100.46482824510144, 15.426148445375505, 1.535012825362144, 5.158847849215231, 3.7800354486511605, 0.32380434414071424, 0.28913316587286614, 0.5690969334494683, 1.3852991428106063, 0.4008843112857111, 0.45000013865290156, 0.1956561285882227, 12.815992505319658, 44.78884681578606, 61.75130136551396, 82.90703635061942, 52.620627649368785, 29.529287315184074, 37.76828273650139, 76.28067831839286, 95.6631568170363, 103.71998756162583, 111.07498861128285, 12.630700718971992, 1.0687346972765461, 0.43258996319866955, 0.26852950694099553, 0.1893441922842495, 0.21891111057371865, 0.163191681908023, 0.23882561213066503, 0.3347293095242593, 0.20209906592724786, 0.16773102865103753, 0.21497357186050187, 0.1261915197415698, 0.13393456957513286, 0.08700440637767316, 0.08592843588802122, 0.18626055049319423, 0.10329783248204379, 0.17491841959136148, 0.11580858454709092, 0.21480680984114447, 0.18805586222198703, 0.10648786856402313, 0.23805927905824878], [0.03305549883554059, 0.013291202222688064, 0.029756201378580545, 0.044451899405929356, 0.010545967323254916, 0.04960700463984282, 0.04347869578088003, 0.05132813224448793, 0.018009899724875728, 0.05325125808256769, 0.024777432347858147, 0.03188517121147485, 0.03299226593827048, 0.020839633164747108, 0.03499586165191666, 0.10342230644798088, 0.11747045142035331, 0.037361790140670155, 0.07979541941876374, 0.2666639296277877, 74.71065552003923, 100.56440153429585, 94.63932406517768, 70.42924727163008, 62.164958446256584, 39.34191803778372, 66.98568082624867, 74.56737918238487, 48.94476275290213, 34.674383824871434, 0.09832631255830489, 0.043728145500344616, 0.04904462332506815, 0.15680014906871706, 0.20188898929665167, 0.026556390014687375, 0.3578715693325766, 1.4851583973053963, 3.279764834911593, 2.5395473933989003, 93.3128647650442, 110.23154566364904, 102.56144492856919, 97.10516129770588, 92.46997879397486, 89.55159418044552, 89.38281459193077, 87.20724059689431, 85.7923867625575, 86.13028326342183, 81.01353568415489, 75.78407487561627, 71.10467157056256, 66.48513932381907, 66.62973357785133, 64.83990507741129, 71.11106503394343, 80.17297175622757, 78.58132885348412, 78.45146702181908, 68.50288498786189, 64.22990199058287, 62.4684283041185, 61.798675752455196, 63.06505610865932, 63.058611654466205, 64.31666874116468, 59.39650251019386, 60.93575823691584, 62.48846377095869, 68.8560708876579, 69.35977382044639, 66.17478570630475, 83.62814057257869, 85.4660612537015, 85.42374672428255, 80.28129193090624, 83.38580869859265, 83.95220679621544, 78.37336478694793, 67.85046931236022, 68.39141122756466, 74.35989364500969, 79.52905977925947, 79.64565615500175, 78.5230581222042, 79.48004584158622, 84.66419542989424, 49.665349221998646, 66.32496541546237, 83.62985072597381, 75.92721785268476, 84.4726033364573, 81.90845581793016, 80.6640995702436, 75.83530103006672, 75.58194729589647, 71.09467737136349, 72.41338606803649, 65.71411901904692, 63.92643605509112, 64.27187527379682, 68.1617093855335, 74.26683933504167, 70.12734243946691, 61.15324974060059, 64.84377645677137, 63.61884770854827, 75.01496084274785, 82.29882578695975, 84.03951875625118, 83.55272123890539, 78.7276646398729, 72.78565037635066, 72.4916373529742, 75.3611727683775, 78.8379224654167, 79.83527921861219, 82.22643452305948, 85.15016140476351, 85.00639084846743, 83.94707633603005, 83.34585543601744, 74.47010440211143, 74.5163962148851, 74.66353216478902, 81.77126699878325, 81.28239846998646, 84.82659724450882, 89.89625284748693, 77.38942253974177, 5.115244330898409, 0.16526070153040273, 1.5769852505576227, 0.5451653272874895, 0.08706305040827683, 0.08268564699157592, 0.15139714544338567, 0.3014727892173875, 0.10590349669538199, 0.04287584204106562, 0.1049684557402807, 15.93974163455348, 31.828149249476773, 70.82244919192406, 50.91008593959194, 40.968642619348344, 29.073188227991906, 45.90693412288543, 67.55303598219349, 70.71300721937611, 84.0249667629119, 40.279117399646395, 0.3801184868620288, 0.018457701099255396, 0.05974966018731075, 0.07452404502058223, 0.05069275424184819, 0.09974008951816829, 0.02155517460778356, 0.022158669946234555, 0.02575960111684136, 0.04524878023432628, 0.00705637697753827, 0.026253206888213757, 0.021121616723136078, 0.028737553417862906, 0.06332836331679456, 0.02539818381680356, 0.07570707629765235, 0.04180241496332231, 0.06291925321303068, 0.048814819930421735, 0.03620395932586924, 0.020338301396658345, 0.020724543775882454, 0.04718055137463155, 0.04187501328546674, 0.04641117693315591, 0.024707884970872153, 0.033246710551001375, 0.012467669195405418, 0.04216680851494593, 0.028923536583240476, 0.04967916629187042, 0.05286871973845748, 0.1017431719529052, 0.019133361920173612, 0.09224723633979598, 0.03245748677140763, 0.011422211987777584, 0.06096704667734523, 0.0520598572949248, 0.05245112521093219, 0.10183911680454209, 0.6393290551439409, 95.94699521218577, 109.46287093623992, 103.06302193672427, 82.32519195925805, 72.88049328711726, 43.27365090770107, 30.93036774666079, 56.80001504959599, 58.880514714025686, 39.33140608572191, 0.07870297803873978, 0.05469986906034812, 0.5341749073516938, 0.56537926197052, 0.5153626684219607, 0.9990999403019106, 1.0992427699027525, 1.0344582075072875, 3.016216125219099, 5.369299188736947, 109.01779959278723, 112.56983526291387, 109.04618186335411, 101.18673263057586, 97.6315825985324, 93.41460320257372, 94.35074744686004, 89.2946397104571, 88.30981885233234, 89.40201851629442, 86.0995711049726, 81.59823556100169, 75.84384395230201, 71.82555613979217, 71.34977263789024, 66.59358501434326, 75.5260064524989, 84.47169334657731, 82.81601382840066, 81.96469476146083, 72.46462791196763, 67.80500119732272, 67.90153857200377, 65.0414913700473, 67.27415546294182, 66.65354236479729, 66.81435954186225, 64.1888661538401, 64.45951361810008, 66.30161946819675, 72.51061377986785, 72.57407772925593, 71.466016000317, 89.38064944359564, 88.37249832768595, 87.06608233913299, 79.34357873855099, 83.9893751759683, 86.45608317467475, 80.16802956981044, 71.75511037149738, 71.90786315548804, 78.89041162306263, 84.84753485648864, 83.66931761464765, 84.92769241333008, 84.57881327598326, 89.86212038224744, 51.77196010466545, 69.1719550471152, 86.62577275306948, 78.66215321325487, 85.4589617636896, 83.46145552973594, 83.87644229396697, 80.26829319615518, 78.72636241297569, 76.1061014667634, 74.03872213056012, 69.152374575215, 66.78668329792639, 68.31843945287889, 70.98274077138593, 76.57315377266177, 73.49897261588805, 65.9000942783971, 66.0990055145756, 66.77069571710402, 76.92281738404306, 85.15169112913071, 85.50521435276156, 87.27161453616235, 82.31127538988667, 77.96621491832119, 76.18296423266011, 76.53886441261538, 83.37967411164315, 82.83068349284511, 87.18482817372968, 87.44687388020178, 85.34141617436563, 86.5659801421627, 87.52134400029337, 76.43042656683153, 76.78123551030313, 77.47834267154818, 85.76536163207024, 85.10173582261609, 89.36673287422427, 91.92123920686784, 88.00495655305924, 9.524443399521614, 0.45079132361758145, 2.0956123115554934, 2.0587211943441823, 1.482439581905642, 0.6976313492463482, 0.5696969335117649, 0.3293440178517373, 0.27400164234061397, 0.11645258869975807, 0.13097619848145595, 19.082593687119026, 37.99078310689619, 54.64835966787031, 27.942068845995014, 34.21448199979721, 39.54181378887546, 54.12686878635038, 74.71498581670946, 77.41175651550293, 96.0420891546434, 63.23617735216695, 0.5087293888772688, 0.043144298401931604, 0.05060596031046683, 0.05140564502066663, 0.021567181120776845, 0.013572017496992505, 0.046293965480740995, 0.06261232774704695, 0.03427351351767298, 0.026994289702645717, 0.06790401879698038, 0.08463537906326594, 0.02834555580310764, 0.03661812560993337, 0.013165003601311436, 0.0368037793575035, 0.027422615206770362, 0.03527529605273758, 0.03548387881188143, 0.038674979756075534, 0.054484521744832884, 0.08206476337246357, 0.041681763776127374, 0.09160525465924894, 0.08060898181171187, 0.19459341141966083, 0.07066722133106763, 0.09289959085083778, 0.09611607994884254, 0.15268896886658284, 0.3163722800391336, 0.1535756237083866, 0.1647294501984312, 0.24970065922506396, 0.1018268057715989, 0.2503677839112859, 0.1004196324896428, 0.2122675501290829, 0.18471199568481217, 0.32432880793367663, 0.15365534281778723, 0.21477995079851922, 0.6752705910513479, 112.93003436057799, 125.54460433221634, 118.79352277325047, 98.92371331491779, 83.51464286927255, 58.690562171320764, 89.86729006613456, 104.96224926364039, 73.4703314688898, 54.51015887721893, 0.3657272187692504, 0.3132455687849753, 0.39726221693619607, 1.0486239699586746, 1.1726087427908376, 1.0549611718423906, 1.3228818533882019, 7.759610693300925, 13.295842524497742, 4.669971965974377, 112.09698569390082, 116.50013646771832, 113.89299977210261, 106.25803562902637, 100.11670220282771, 99.57862361784905, 97.72544491675593, 95.94372395546206, 93.07367863193636, 94.1394022972353, 90.18225639097153, 85.98677158355714, 80.62497000540458, 76.72083100964947, 73.10380166576755, 71.10325951730051, 81.27726800980108, 88.38530878866874, 87.7464174455212, 86.25787012038693, 76.77842709325975, 72.71399651804279, 70.72027144893524, 70.40813707536267, 74.42349879972397, 72.0059851677187, 74.19720157500237, 68.60650616307413, 69.81200741183373, 70.06024637529927, 75.56764633424821, 77.42521808993432, 72.76187296836608, 92.88513814249347, 91.92236100473713, 91.58729645513719, 83.33374315692534, 84.98433143861833, 91.36638856703236, 85.25009555201378, 76.23221351254371, 75.61805663570281, 83.15618530396493, 88.35315319799608, 89.6030870560677, 88.19052388591152, 88.83470258405133, 89.80894873219152, 58.33492871253722, 72.13563519139444, 88.86077065621653, 85.18038718931138, 88.21041030268516, 89.14299303485502, 88.56132122778124, 83.28749056785338, 84.94667668496409, 80.02016405905448, 78.88714036633893, 74.16797991721862, 71.08023520438903, 71.02905611838065, 73.84562384697699, 79.62142375207718, 77.16174464071952, 69.64959775247883, 69.4450226137715, 70.79264702335482, 82.85364504783385, 88.5923550205846, 89.83633472073464, 92.1519059519614, 84.87557980322069, 81.2347573618735, 81.02087836111747, 81.62371527764105, 87.55535879442769, 85.57786449309319, 90.84449368138468, 88.32551617776194, 88.29205051545175, 90.78604252107682, 89.54320030827677, 82.52853547373127, 80.76036237901258, 83.5056527968376, 90.3209121765629, 90.15435264956567, 93.24972245001024, 98.09175506714853, 90.13770611055436, 7.270118017350474, 1.7770929322127373, 6.666949660547319, 2.883693455688415, 1.475424300278387, 0.7469838977821412, 1.1553161158677072, 0.8216508105397226, 0.40890788719538723, 0.2320590792524238, 0.3138067435112692, 29.258402547528668, 55.14316666510798, 97.80077795828544, 71.08749158920781, 55.759261192814, 42.60860520024454, 63.74772502530006, 87.78105981888311, 88.94845131904849, 107.59782314300539, 67.38890047996276, 0.648221436046785, 0.14509149106039157, 0.24654889689578166, 0.16054559889579975, 0.1544286472903144, 0.16077256010424706, 0.126661897727078, 0.12491983676990195, 0.09720878945963998, 0.09592091905013209, 0.09948636119764659, 0.17239028347596047, 0.052756484027110764, 0.10202808771282436, 0.13397875752660537, 0.10208505401087385, 0.26132300976784, 0.08567674536137812, 0.12220964752017491, 0.12787446169362915, 0.1302303812436519, 0.2403468942089427, 0.10269243916076037], [0.033946439939280676, 0.09184399063909247, 0.06266546360547505, 0.057032219915380405, 0.03712573546856161, 0.0474068001213093, 0.05034861222450292, 0.03624628185324612, 0.025693319189632614, 0.05392061591508889, 0.057478033291596564, 0.048114646211146354, 0.04066396617300568, 0.025140785935124563, 0.0080263247289094, 0.03864237505401816, 0.055778448079382224, 0.11448977950720057, 0.21376960340046117, 4.9195214913737395, 99.48919357792025, 98.21701203623127, 88.33532210319274, 62.02712243603122, 38.95822394278742, 49.39258760021579, 94.32223966044765, 65.35892486572266, 48.52615956337222, 5.973904113615713, 0.4494820180679522, 0.17568594776093963, 0.21142102297275298, 0.4924373340702826, 0.7984480297853871, 0.23863033631876593, 1.5492170760708472, 3.2615564571272944, 1.521140750377409, 74.65503631099578, 106.9628071015881, 99.73443585057413, 106.67041009472263, 100.12359772959064, 101.50209903717042, 96.87057218244, 90.39008709692186, 87.87667935894382, 91.03004532475626, 85.75656767814391, 78.76968106915875, 77.1872792705413, 70.76730066730131, 66.57017630915489, 62.798425151455795, 66.79304538234588, 67.69351959228516, 70.64347928570163, 75.32034873962402, 72.0683822324199, 66.44291893128427, 62.07752097037531, 63.289023445498565, 61.62128263904203, 59.981261222593254, 59.96217496933476, 59.498495901784594, 62.33522853543682, 59.94725427319927, 62.92880081361341, 66.02042475054341, 64.69972741219306, 72.2271833112163, 83.58868152864518, 81.9358653406943, 82.07692946157148, 77.302565574646, 84.33738354713687, 78.59475904895415, 72.66918736119425, 66.91779244330623, 73.52129090216853, 76.11093382681571, 81.76970589545466, 80.32737978043096, 85.3266445282967, 77.63605333143666, 82.77996724651706, 42.199231347730084, 67.1493221098377, 84.50566107226958, 73.38606326810776, 82.36277611024919, 79.0089064259683, 81.48582043186312, 74.41475975898005, 73.57670614796301, 70.62180426812941, 67.17415071302845, 63.83770027468282, 65.13903287149245, 63.20273130170761, 65.75432723568332, 71.18243648159888, 71.88268153898179, 61.36245719848141, 62.748709109521684, 61.31879337372319, 69.66633058363392, 78.14858944185319, 79.86921556534307, 80.98220379121842, 76.20019912719727, 69.5943001777895, 71.2499483170048, 71.54491055396296, 76.35650557856407, 78.66255329501244, 81.28041375067927, 79.92693716479887, 82.24494811027282, 82.65356494534402, 79.19397954017886, 67.940581844699, 67.79022955125379, 72.47763449145903, 76.45738109465569, 81.97392017610612, 85.0149965286255, 84.45422310982981, 88.06307823427262, 63.23611067187402, 2.978467970125137, 1.3335658994413193, 1.5066918418292077, 1.313870943361713, 0.10294920118946223, 0.43957518353577585, 0.3486035295551823, 0.18471348189538528, 0.18722853322903957, 0.16265755008545615, 2.8265405999075983, 23.381446676869547, 37.43309659342612, 84.00407621937414, 49.654598005356334, 32.42671862725289, 36.67289418558921, 61.217749195714156, 66.6647054303077, 85.23744198583788, 79.31056807118078, 5.532560002419257, 0.41869211701616166, 0.0704550073151627, 0.07833874919601987, 0.034326044166640896, 0.019255024343428594, 0.03322194675884901, 0.04139221318426632, 0.034482008176705534, 0.052214875186402956, 0.020315659668056235, 0.014560655878496268, 0.05542522025925498, 0.0336591761198736, 0.03660435517949443, 0.07050410589022983, 0.03178151568488008, 0.03686878574831832, 0.007875567722705104, 0.03767075340053247, 0.053998825831278685, 0.011815514824833843, 0.02777920040722576, 0.027353768800235084, 0.06976686883717775, 0.047768784326411066, 0.05416632329504337, 0.08622197779796778, 0.033702697574851975, 0.022372400816229564, 0.01693613365322592, 0.03698899643495679, 0.040748239675116156, 0.049160348566909956, 0.07083507885615672, 0.11517804822013264, 0.044241393766095566, 0.014280961007781088, 0.053534771901585405, 0.16543814281542457, 0.15249574617032083, 0.6054956093430519, 10.011091866800863, 120.25012631570141, 106.44599560768374, 102.94606470292615, 77.0474624633789, 54.29400097939276, 38.27022844745267, 65.23076926508259, 61.99815573230867, 56.39688561039587, 6.420384568552818, 0.7524178513596136, 0.1927265777222572, 0.8949580091622569, 0.7964529529694588, 1.9019661218889299, 1.7227900460843117, 3.1282527456360483, 3.0246982507167326, 4.366049564653828, 89.844924711412, 110.5417972995389, 105.44359468644666, 108.19360763795915, 107.6207297848117, 106.08527091241653, 102.22923586445471, 95.74755053366385, 92.1893959660684, 93.99349012682515, 90.91882259615006, 83.29334274415048, 82.03374416597428, 76.00823048622378, 69.71157120120141, 66.59130219490298, 70.67278723562919, 70.16590718300112, 73.45579516503119, 78.82781843985282, 75.10379468241047, 69.16640881569155, 66.33709338403517, 67.84084381595736, 65.52561775330575, 64.45068828521237, 64.75702539567025, 64.62361774136944, 65.29153854616227, 64.7708752847487, 66.9287750797887, 70.5122132455149, 68.41113290479107, 74.57789897918701, 87.26311083762877, 85.75481045630671, 84.6825207433393, 80.2204010563512, 85.53343972852154, 82.3107890159853, 76.54629338172175, 68.97116891799435, 74.16832508579378, 80.64920240832915, 84.31528491358604, 82.55693343377884, 90.5847700180546, 78.8369026491719, 85.12231257654007, 46.61337260277041, 69.52956538046561, 90.28015875047254, 78.31408208416354, 82.6252846564016, 81.14036160130655, 84.40069060171805, 79.53749287512996, 77.8279592144874, 73.05984758561658, 67.99030180900328, 67.19235835536834, 67.79110031743204, 68.33319540946715, 68.59122460888278, 73.53013192453693, 76.1734328731414, 63.8399556375319, 65.68518761665591, 65.01950256286129, 71.94006581460276, 82.38369018800798, 87.1987682773221, 82.73052184812485, 80.87400128764492, 72.30627398337089, 75.68031249507781, 74.91505807445895, 79.02567848082512, 82.28603886019799, 84.77613202987179, 82.09216394732076, 85.08482256243306, 84.80588712999898, 81.23870326626687, 70.75936963481288, 71.17404260943013, 75.88846483538228, 79.95520960900092, 82.34760438242267, 86.61133843083536, 88.89856661519697, 90.38155986416726, 77.04237122689524, 5.625762381861287, 0.9953703791383774, 1.4564995996413694, 1.8066058259817863, 1.6358264415494859, 0.5345342945187322, 0.34335021951025535, 0.5790623890296106, 0.47972658709172283, 0.41148629400037956, 2.191742250034886, 26.650865770155384, 38.780575875313055, 62.82599941376717, 38.47520759028774, 35.47107604242141, 49.213778511170425, 67.12255585578181, 80.81505590869536, 90.84481531573881, 98.37400882474839, 11.534359032107938, 0.6095246802414618, 0.10602700539053449, 0.13454436024110164, 0.07276293911760853, 0.05943554115571803, 0.01844135278295125, 0.025918600750305963, 0.032080671104091796, 0.03341458339784895, 0.04562039416463626, 0.054372676738327554, 0.07418246173690404, 0.08912747350311087, 0.05830406759595198, 0.028939178183434472, 0.05172589275565359, 0.042028709675275513, 0.03126417842483328, 0.031476415423375946, 0.03644981992340857, 0.03177909484703935, 0.027348817957024422, 0.15390493426351778, 0.19016376846740324, 0.1629892814784281, 0.18134772056533446, 0.20534963827700387, 0.11018254208348452, 0.06393182609650878, 0.11549295632228737, 0.09325798976445392, 0.19284893728552327, 0.08737264186023705, 0.17198244890859052, 0.14483851350603566, 0.0857693577305444, 0.17269552354851078, 0.1943007351890687, 0.321850881220833, 0.30797298396787337, 0.8508307318533621, 11.824561472861998, 141.5230852557767, 117.7164948371149, 119.65209822500907, 82.88935430588262, 63.87268781661988, 67.03116463076684, 134.9403282903856, 86.67313929527037, 75.51333719684233, 9.745800399011182, 1.0965173355033322, 0.601041880586455, 1.3766801020791455, 2.493142077038365, 3.411989404309181, 2.6927850804021283, 6.398831634752213, 15.46845022709139, 3.9862457254240593, 90.99220229733376, 109.05785483698692, 110.37083687320833, 115.2441386253603, 108.22049940786054, 110.58013454560312, 104.6991680514428, 98.39395799944478, 97.0205165493873, 96.59015409408077, 96.18425153916883, 89.42655686409243, 85.4000634531821, 80.76470052042316, 74.9344345831102, 69.90613645122897, 74.91491686913275, 73.60387248377647, 79.28216226639287, 84.5247708597491, 79.76561792435186, 75.63657806765649, 70.89641724863361, 72.42437654925932, 69.36152319754325, 69.0405164226409, 69.34742619914394, 67.1700636033089, 71.98105458290347, 68.2287819154801, 71.65266590733683, 73.91286896121117, 71.04643221824401, 78.20770740509033, 90.8834977303782, 89.21876538184382, 89.3470190417382, 85.01320008308657, 87.30635889114873, 90.16717880002915, 81.5424123887093, 74.20417554916875, 81.51962341800814, 84.11565980603619, 86.83195606354745, 86.82388382573282, 93.26063448382963, 83.98864561511625, 85.4820723687449, 52.434683768979966, 73.77524083660495, 91.78827870276668, 82.99480330559516, 89.82084135855399, 85.09774284978067, 89.08965664525186, 83.16138636681342, 81.83288743419033, 80.28474361665788, 74.65603259301956, 71.40613709726642, 71.33992748875772, 71.09330454180318, 72.33733131039527, 76.69107590952228, 79.62119625460717, 67.77950579120268, 69.17101367827385, 68.67557125706827, 74.86167461641374, 85.45968347980131, 88.48598818625175, 87.38342562029439, 85.04595971876576, 75.93501552458733, 80.41301296603295, 79.30814404641428, 83.73178528201196, 86.30504838881954, 86.63476282550444, 86.18685168604698, 89.54509873544016, 88.44675663978823, 86.60996560127505, 74.23926507273029, 74.54628467559814, 80.36741933514996, 84.1632930694088, 87.64886025459536, 91.52310294489708, 90.22358248310705, 92.65701309327157, 77.16965998372724, 4.255083260997649, 4.011488383816135, 7.8794523400645105, 2.4608298367069614, 2.4879777864102395, 1.9022466939303184, 3.1879095444756174, 0.6071594910275552, 0.6571569630215246, 0.6127431688289489, 4.960643129964029, 37.46284777118314, 53.61486219590711, 113.212382255062, 69.32044813709875, 44.09438333203716, 53.71532194076046, 76.84324033798711, 92.04972036423223, 103.22093655986171, 113.32356575996646, 12.015299470193925, 0.8057462123613205, 0.286259600712407, 0.19056337525046643, 0.14252083706519297, 0.1278971991832218, 0.12151205551720436, 0.2324135174914714, 0.12659868781244563, 0.1217966112157991, 0.16103278485036668, 0.13060832306021644, 0.17946954876665147, 0.17297119262718386, 0.1326270719930049, 0.1425360362496107, 0.12857727075536407, 0.11473550220891354, 0.10695194164591451, 0.11830328858547634, 0.1710463967174292, 0.151060342548355, 0.16423569120947393], [0.033932834217745456, 0.04840474455587326, 0.043523492772252335, 0.08610960036035507, 0.10096543949217567, 0.034268855703093355, 0.08008159922375795, 0.044488866978715506, 0.016055931186964436, 0.0373671489257005, 0.035482993980328885, 0.07278109540141399, 0.033046501132869915, 0.06198153861107365, 0.08230182161975293, 0.058793965501770865, 0.042141673170150294, 0.23013273584506205, 0.5250451617663907, 22.97536761529984, 107.85332633603005, 86.57053793630293, 80.62169090394052, 60.078637984491166, 62.395903679632376, 73.25329888251521, 52.43200086778211, 53.06730324222196, 22.225233931695264, 0.1679513555380606, 0.28649472841812723, 0.2601953896303331, 0.9950949552078402, 0.6207143443246043, 0.41464683569727406, 0.7790556477923548, 0.050414836695117336, 0.30844823427258, 69.09721036111155, 109.28630152056294, 102.36275334512035, 99.81818629849343, 98.97017771197905, 101.5436290925549, 97.89351063389933, 98.30103705006262, 96.52945149329402, 97.96202659606935, 86.43539659438595, 84.51073661927255, 86.7170306174986, 78.46276344791536, 72.08997095784834, 65.74100686657813, 64.04222834494807, 63.8489104086353, 63.95168042952015, 66.50876768173711, 66.51310582314768, 68.1728018483808, 65.95992611300561, 63.28644644829535, 60.525733270952784, 61.05336266179239, 59.38639063988963, 58.131734248130556, 58.25831697833154, 59.51189079592305, 61.28408432006837, 65.02051845673593, 68.07956710938485, 63.26845845868511, 73.70219061451574, 84.1146949029738, 80.53403377532959, 84.79516336994787, 81.5348735932381, 78.38683420611967, 78.93039626459922, 70.39886459227532, 66.0077319606658, 74.01188527384113, 79.22715494709631, 83.0103672704389, 79.6948819006643, 82.78088508113738, 75.10274348720428, 78.7601104859383, 41.18349436790713, 66.76056031257876, 80.82130816675003, 72.40762802862352, 76.72991521896856, 76.66446655027329, 79.66969243941769, 76.2226664635443, 78.45558551050003, 72.36031639960505, 68.29886682571905, 64.44666785578575, 63.338041305542, 63.617612161943995, 63.85901443419918, 63.589798635052105, 72.70379051085442, 61.6490569422322, 60.7033460370956, 60.24843738925073, 62.814346051985225, 72.67528272444203, 80.991162484692, 77.32577816132577, 72.83260899205362, 68.25964312399587, 68.7408551862163, 71.31284744508805, 72.60671969382994, 72.79052980484502, 74.24063005755025, 79.44881593027424, 82.25372637471845, 80.36934129653439, 71.03421795752742, 64.7607163460024, 65.67043558243783, 69.39422007529967, 73.56455464516917, 78.00507776198849, 78.87565566647437, 86.184553177126, 86.08690969405636, 91.53905130201771, 52.52006592289094, 0.2570207059503563, 1.0825511236344616, 1.3695910308630237, 1.0733471594510542, 0.4252896049330312, 0.20154659395977376, 0.1296678122373358, 0.18020212800512392, 0.058333883737964984, 0.08014000576710509, 9.385161015295214, 27.584636980487456, 47.263289728472316, 50.388567601480794, 34.06034854150588, 25.220108685954926, 48.78767967224122, 57.56930558912216, 71.11513645418229, 83.85290807293308, 26.38805324031461, 0.5788139926810419, 0.126204619845075, 0.13086606568146136, 0.011945867557979882, 0.014457994350983251, 0.06019265052952594, 0.016883373177880724, 0.09466120237184149, 0.08168890531505309, 0.03447197625533708, 0.02466897919563757, 0.055401735833936164, 0.07108306151724632, 0.06207830317678952, 0.03557385966902779, 0.01991995035730783, 0.04479225694892868, 0.12100830674171449, 0.04441267953464582, 0.052714670948203535, 0.019025063900757703, 0.04334224786068644, 0.022603696167108514, 0.07989401493461863, 0.06365577780431317, 0.057246713042860074, 0.04915036644125658, 0.037170337107513225, 0.03622878440505555, 0.17969465604232204, 0.026193660789079247, 0.062103775600271846, 0.028906994829735452, 0.0477563162454434, 0.021630394865848848, 0.10602227862804167, 0.023404056949901487, 0.18245894642126176, 0.023796797669943304, 0.2769564434645638, 0.6130100125747343, 35.54736614227295, 124.90425386736472, 96.43539305656188, 93.2065999123358, 73.61720854236235, 72.88875379870015, 55.43591668528896, 53.7166202452875, 57.749569877501465, 24.424697122266217, 0.2025053223534938, 0.24417448398326677, 1.194789500967149, 1.5122627106405075, 0.7220498196059658, 1.639548525694878, 1.951901203682346, 1.9406278215108381, 1.968565883655702, 84.37193962835497, 110.40748750009845, 109.00170218560004, 104.14308578737321, 106.65629740684264, 103.01785976656022, 100.7757309944399, 102.03055212574621, 100.17865996206962, 101.12675959064116, 91.04484050504624, 87.74179689345821, 88.94628617071336, 82.95858413942399, 77.46647357940674, 69.52036350004136, 67.21677118732084, 67.58895704823156, 66.9447861948321, 68.81858087355091, 71.66794746152817, 71.23820474070888, 69.14838160237959, 67.24853454097625, 65.29192686080933, 66.47387427668419, 63.052904605865486, 62.839751243591316, 62.54976649438182, 63.76876461890436, 65.8605646318005, 68.00297890940021, 72.1739096795359, 66.74617305878671, 77.4936399152202, 85.92222506000151, 85.20839291234171, 87.61845404101958, 83.12995249225249, 82.61966782231485, 80.52021134284236, 70.68754319221743, 71.47078560244653, 78.61248031739267, 82.80743168246362, 85.65173841291859, 81.57459935834332, 86.47610295203425, 80.70736331324424, 77.14196020557036, 46.052226558808364, 71.41297771084693, 84.50855578145674, 76.69123280432918, 82.86708308804421, 81.45612808965868, 83.7014732053203, 78.09016966050672, 81.37477028754451, 78.3875088537893, 69.81608667681294, 67.36797071272328, 64.74479152310279, 65.23007500556209, 66.9536978198636, 66.75877955652052, 75.78179990091633, 65.58133109923332, 62.58151023618637, 62.58776249424104, 65.95826302805256, 74.77298982681768, 83.19434996574157, 81.38434087076496, 75.72713775019493, 70.83775428033644, 71.30009189728769, 74.12484953480383, 75.50075423332953, 77.78197334658715, 80.76222158247425, 82.77942595943328, 86.35541946657243, 83.7437249768165, 74.89428520202637, 67.02067621292608, 68.41419235352548, 72.13493700950377, 77.01493032516973, 79.79103488306846, 83.17647964723649, 87.75689017388129, 88.66687220911827, 91.65861298961025, 68.41712628641437, 0.9235131704518873, 0.40902255523589354, 0.9120184808008133, 1.6314105881798653, 1.802700738753042, 0.5917222677699981, 1.1266038759100823, 1.5429671469234651, 0.3446525689815322, 0.15302710475460177, 9.525778966565287, 32.69460866528173, 44.54367514579527, 42.726868583310036, 29.610384279681792, 37.23611908574259, 60.99918296260219, 62.51643811502765, 78.3547649075908, 94.67944991204047, 45.89848925990444, 0.4799174042719026, 0.06290050704152354, 0.048610194015406796, 0.040074748798243465, 0.0450990368582068, 0.009256465146468293, 0.038741062500423966, 0.04724010704986511, 0.06411129751452996, 0.019208352351861618, 0.026476929459961194, 0.030768546350901167, 0.022526175730050575, 0.06292890975131624, 0.0068718618281456015, 0.04338040670019485, 0.031896024762142094, 0.02567353496898807, 0.00021457190585703846, 0.03932551097785754, 0.026112470790864, 0.03095157816255045, 0.1775620970875025, 0.26386240737572797, 0.12720482423901558, 0.16966783681944494, 0.16047521073731685, 0.10533122901594448, 0.13292586160523276, 0.3288943548837016, 0.12167629710729085, 0.20821552723646167, 0.21171015987713493, 0.2550400469091631, 0.08575044301969391, 0.19374524483517294, 0.23782974379437588, 0.27738713809559423, 0.19478926945838237, 0.6976488773380557, 0.7224643651035525, 39.994047380262806, 143.99298606380341, 107.09626182433098, 105.74620554524084, 76.92979135820943, 78.82238203479399, 96.57993239741172, 73.96917066266461, 76.22677710748489, 37.47140638289913, 0.3294804427892931, 0.7019108389654468, 1.1948004100591907, 5.419943851809348, 3.041991980806474, 2.604422905752736, 4.99388276569305, 8.223345164329775, 2.809052222198056, 85.10797239119007, 111.87419506811328, 114.21836822263657, 104.95646769000639, 114.74132999297112, 110.01528970656857, 106.97844166909496, 105.8739257627918, 105.1546964337749, 103.66136381703039, 98.24584145699778, 90.54073749050018, 95.50393996700164, 87.23046102831441, 84.1777587706043, 71.7246727789602, 71.44968325091948, 71.2989700994184, 71.17004963659471, 72.59946330901116, 74.8992823016259, 75.38884901231336, 73.55153237619709, 71.29842096759428, 68.71983912683302, 70.45274226896225, 66.89523097007506, 66.04769306798136, 67.36509953775715, 68.09673924599925, 71.14497000171293, 70.7274180073892, 75.70719642023887, 69.47030621190225, 82.07659213773667, 90.56048270194762, 87.55517052065942, 91.73528748173868, 88.26118146219562, 84.91155578244118, 86.21164106553601, 75.83190425749748, 73.29907294242614, 82.91485755674302, 85.93396079155707, 89.00672989506876, 85.73060943234353, 89.48858522599744, 81.28710531419324, 79.8693803048903, 50.48033929640248, 72.75984118061682, 88.99366840239495, 82.27560535553964, 84.44369546828732, 82.90087038470854, 84.9788950335595, 82.90321596207158, 85.62709023875576, 80.12953542893933, 73.96144359342514, 71.84807838932161, 72.19009337886688, 71.17101453965711, 71.82463046043151, 71.38762351005309, 80.97640652810374, 67.7126999824278, 66.93959297672396, 65.92160455642208, 70.45088306550058, 79.18775866108557, 89.21555688304286, 84.7344058559787, 81.0274600982666, 74.90334587712442, 76.73970545491865, 78.68562467636602, 80.27030144968342, 81.10910815577354, 83.76829470357588, 87.18998216813611, 89.45358983932003, 87.47192998086253, 80.22513927951937, 69.9351776799848, 72.92851094276675, 76.20423132373442, 81.90789099662535, 83.40462823067942, 86.4828964971727, 93.89941600061233, 94.1275881182763, 95.85833395681074, 70.20797068072905, 0.45513161007435093, 6.409591676727419, 9.007351456149932, 1.809110381910878, 1.7899861306913438, 1.5942137712432494, 3.1674519325456316, 1.082909407634889, 0.26939610560094157, 0.14191202699176728, 17.157716020461052, 45.9868759493674, 63.75848016431255, 72.9843262703188, 44.271160633333274, 37.72359125075802, 65.91581513804775, 78.28849254115936, 89.22359774189611, 108.61108902961978, 46.41217854715163, 0.9847895404504192, 0.29519950971007347, 0.20525882621445965, 0.15505003652745677, 0.1926894224579296, 0.09888687441425939, 0.13726460056439524, 0.26773804618466285, 0.11612536956466014, 0.1421776603186323, 0.13861731265581426, 0.20379709981141553, 0.2216452324102002, 0.11269207758408402, 0.08636724339016984, 0.13133560097025287, 0.17052557950298633, 0.11539346448356107, 0.060576893419267676, 0.2131668300998788, 0.16108040487573994, 0.11098367086942158], [0.03077250894068951, 0.05620748413005664, 0.0746078014133438, 0.05053108670718728, 0.033565077540134235, 0.03841406553082409, 0.006760203076766865, 0.031154030303080237, 0.02192059471722572, 0.020557814315261862, 0.0896477697777652, 0.025061798439691627, 0.024567688965509017, 0.0331525583451073, 0.017408162558210954, 0.04876387125301746, 0.13309104548346612, 0.03201702068890295, 0.14703718584872064, 56.96691974516838, 101.51164608616983, 90.79330675063595, 68.03984134427964, 51.93523660782845, 40.53375767123315, 89.05079380158456, 85.11110244258758, 51.66882922572475, 3.938940225108978, 0.006626343576147432, 0.1500884527640958, 0.37797530992857875, 1.0885187647035046, 0.3768980677329725, 0.8262781041764444, 2.8799990732823653, 2.077161237116783, 39.878204099593624, 122.11140863357053, 95.98308886251142, 107.53332368789181, 95.80577419650172, 102.31823444366456, 94.56465782657747, 97.9599085161763, 93.0522075776131, 96.97882175445558, 84.32243147204, 86.17487276754072, 87.12369411222397, 82.01118269274312, 77.8028089769425, 70.78029155731201, 66.07482802483344, 65.57087013798376, 64.3894640091927, 65.81097802808209, 62.14649977222566, 64.18983105690249, 61.85213765790386, 61.92148516255041, 59.329645710606734, 58.96566937046667, 60.02632141113282, 60.81809105411653, 58.75406926678073, 58.58561915736045, 61.79161156377485, 64.55127354591124, 66.62599163670694, 68.00012342391476, 62.694007735098566, 73.42410241403888, 82.99184583848523, 79.57849733291134, 78.4283564167638, 79.44679198726531, 78.28585670840356, 76.0090071155179, 68.09141266730525, 71.25400404776298, 74.89226125901746, 77.33752173762169, 73.63613790081394, 77.2031178012971, 77.82517433166504, 76.37158316950645, 74.54725742340088, 44.96479649697581, 69.85812664031982, 77.76964925950574, 69.11217028094877, 74.55019135628977, 78.48133194831111, 81.13325426655432, 77.03508346311509, 79.39622479100382, 75.43483488021359, 65.40283972217192, 57.71557861758817, 61.82432805338214, 62.66937525041642, 63.78999248627694, 61.274925585716005, 69.55112272693266, 70.79569862734887, 58.317415329717825, 59.60395274623748, 57.56636381149293, 59.80371905911354, 64.16623407794584, 64.02995132630872, 65.67658193649785, 63.65775369828748, 63.98047062658495, 70.75322720312303, 74.22375602106895, 73.99035146159511, 73.67958991758286, 76.71723811857163, 77.55173806221255, 76.02727751578055, 63.54391867114652, 61.655823030779445, 65.24189702926144, 66.41595655871977, 71.82674854032456, 76.93716541413339, 81.53394791387743, 83.0339877836166, 85.43546676635744, 85.38583309419694, 87.9989004135132, 37.1265672868298, 0.5960794081611018, 0.9432674523803496, 1.3574586496237786, 0.5530663904163146, 0.27454443095672515, 0.27506671905998265, 0.8795582322824387, 0.30396864238765936, 0.12491104974141046, 0.4319029661916918, 17.168347604813114, 32.45251213350604, 69.69935694048482, 55.080483267384196, 26.714723917745776, 46.57833014765094, 68.57471143045734, 69.40239429473877, 82.07296786769744, 77.627730061931, 1.7935839247319008, 0.1489910471343225, 0.022581186588673342, 0.0630369856052341, 0.07170612848694287, 0.018846912069186088, 0.02163381353321095, 0.03833803130433925, 0.05313193605792138, 0.07957134636179095, 0.029060440325749018, 0.015626353129083594, 0.04304573352959368, 0.08061940826836132, 0.042626369338963306, 0.008662949060840953, 0.03263574010962921, 0.08103784549260333, 0.02487746427857107, 0.01557996842048822, 0.04962644412092144, 0.038951729018721855, 0.04213914508000017, 0.006852196829934275, 0.020620551170601, 0.0186568092659957, 0.03211492672562599, 0.028960126857723922, 0.046602365665978966, 0.0349122354941022, 0.01808178941569021, 0.014789568695930705, 0.02501117151921555, 0.07119831944545431, 0.028014510058827942, 0.08565595373511316, 0.031519343160213, 0.0373025753745629, 0.15658284056811564, 0.010449810839828946, 0.12561346809830398, 77.84959500835788, 112.95542778507357, 101.68033153780046, 80.53194707439792, 69.84934053113385, 59.542457826675914, 82.83576688458844, 82.40333341783094, 56.657813441368845, 4.131615383009757, 0.06482014717954783, 0.3092239136176725, 1.4488879951738542, 0.9089180310406993, 0.3984810934672433, 1.9841009210194311, 0.8727842377078149, 1.4063160602123508, 50.954291051433934, 126.47016602177774, 100.63436092868929, 109.96698964026668, 100.71935869032338, 106.82294322598366, 100.17645559003277, 104.48755618064635, 95.88836362285, 102.24177175952543, 90.9614509151828, 92.525158697559, 90.35622135285409, 85.67445678095665, 81.79628387574228, 75.3000779305735, 68.23497141561201, 69.29520376266973, 68.51399314018988, 69.20992359038323, 66.28513766873267, 67.58711353425058, 64.95765855235439, 65.50794747567946, 63.395045111256266, 65.21005130583241, 63.9976074618678, 63.828733736468905, 62.15857282761605, 63.74423803821687, 65.71700588349374, 67.74523212063697, 70.63650531153526, 69.57523745875206, 64.9845346327751, 76.33899611811485, 85.91241128983037, 82.11639635024532, 83.95412875759988, 84.13760938952046, 79.9508479333693, 78.65541458129883, 70.96728663290702, 73.08607255258869, 78.21417931587466, 80.55835247039795, 78.9382488496842, 77.66671842144382, 80.72123281417355, 80.30492028882428, 78.44199057548278, 48.81637965479205, 73.40416892882317, 80.50038768399148, 71.89808076427829, 77.65335882863691, 81.3680551898095, 83.03052825312461, 80.6342032647902, 81.81038087414157, 79.66564455339986, 71.35188287304294, 61.11722277056787, 65.16883504006171, 66.21133435157039, 68.76911194093766, 66.31386510787472, 70.48261504019462, 74.03427416278471, 64.08286017756309, 63.86698469038933, 60.98383865048809, 63.28850177026565, 66.49422353313815, 68.03253004627844, 68.79741576410109, 67.30880568104406, 68.43289421450707, 72.6810956770374, 75.53043873079362, 77.73121003181704, 77.39971483907392, 81.81419341794907, 80.62373838117047, 78.37865214194022, 66.26634167086694, 66.65924549102783, 67.66620420640515, 72.75587174200243, 75.46312301389634, 81.7339103452621, 85.51889557992259, 87.41303167035504, 89.10977840423585, 86.0177347736974, 91.04008659239739, 55.43531264028242, 1.081353820139362, 0.3559692197990033, 0.9415531927539457, 0.8409117318449483, 2.0306272179849687, 0.4104518914414991, 1.3018887153556271, 0.6413387795609813, 0.38608199105628077, 0.11478344399121501, 19.983652330213978, 36.99935305503107, 51.93435799690985, 33.40017834017354, 36.3499693716726, 60.903371226403024, 77.5067877000378, 79.13661095403856, 89.50367066168016, 96.34100514073526, 6.299521634655615, 0.5170931691123594, 0.05278441176239041, 0.05621887585749069, 0.03469041090518717, 0.038422994285581574, 0.036839019402020404, 0.03718675820217018, 0.0721821142360568, 0.048426666161826545, 0.06171617341498214, 0.03812629609338699, 0.02083833081527583, 0.05224588259513821, 0.02493850807959755, 0.13593605088610805, 0.020905620148105007, 0.04686254061638348, 0.04941568950251226, 0.09746319193753505, 0.04211405187004036, 0.026547905590925968, 0.09380846990332489, 0.15401175756367946, 0.21042993502511134, 0.11882183817966331, 0.09056753493965634, 0.17256545714072644, 0.17381690773031405, 0.19529845745813465, 0.1333847176283598, 0.1827314898612038, 0.22572195397750025, 0.1334946052802186, 0.08523263653079349, 0.32601671413548533, 0.12262806942265843, 0.2345028078003276, 0.3293471741339853, 0.1569276567428343, 0.17133156528636334, 87.59102098403439, 128.41197459928452, 115.51937134035173, 95.51529130628033, 71.63491325993692, 56.565155290788226, 114.715787518409, 100.75256547620221, 77.44200583427184, 6.520268215287117, 0.22721735760569575, 0.34166776785446756, 2.1859763658815816, 2.8871522507359906, 1.016141229098843, 3.985399474059382, 9.31383369430419, 5.069295725514812, 48.35188865661622, 134.78194298282747, 101.98029087435816, 114.84427652051373, 102.97934993620842, 113.34871599751135, 102.21677057204708, 111.23542924081127, 98.69288967501734, 105.47185928590837, 97.1600744801183, 97.14036064763224, 96.71488546556043, 91.34400752282913, 86.86197004010602, 80.49699875616258, 74.84187449178388, 76.4984953788019, 72.515579500506, 73.09550193048292, 70.53594358505742, 72.73069012549617, 68.4423000581803, 67.97542818130987, 65.37859555213683, 67.42025590712025, 66.45636481623497, 68.29926690747662, 67.31092376093711, 67.36937492124497, 69.75201868241834, 71.64252265807121, 74.03934970978769, 73.16552408279912, 67.96868170461347, 81.23283540048908, 89.72726145098287, 86.0391430700979, 85.86751584083804, 89.44420752986785, 82.7683727202877, 82.20403778937556, 74.41822713421237, 77.77361085337978, 81.62859470613542, 85.51485553864511, 82.2618378362348, 84.423110869623, 85.72714990185153, 84.76633394918134, 82.2069795670048, 53.76399070985856, 75.38278502802696, 84.86571111986714, 76.11893546196723, 79.89871178903888, 86.79233228006672, 86.67910129793229, 83.83640273924797, 88.97476257816439, 84.08333163107596, 75.46571177821006, 65.80791073460733, 70.04319190979004, 69.63130381799513, 72.92839327166158, 68.64560434895178, 75.8838991965017, 77.55494656101351, 67.00814816259569, 69.03811593209544, 62.65228156120547, 65.92864128851122, 72.42498059426585, 73.62802643929759, 73.49632109365156, 73.21622463964647, 71.86147720583024, 78.27980841359785, 81.20569259889665, 79.94483101752498, 81.9774503092612, 86.16731828258884, 86.59553127904093, 84.65030239474389, 70.33272558642973, 70.28975209882184, 72.08092597223097, 75.54325703651675, 78.5592302199333, 85.65307201877718, 88.233669957807, 89.22009114296206, 91.3390810258927, 90.34568586657124, 94.76545180043867, 56.67416188024706, 1.5897623713939422, 6.237708022517543, 5.829440768687956, 0.8584235212014568, 2.063189509414858, 2.9457274560005438, 2.9378027973636507, 0.8932460784431427, 0.2932101632318189, 0.873660519719124, 32.04818441021827, 49.88098544459189, 93.20517216959308, 71.12948448427262, 38.928139363565755, 64.00904509329027, 88.56571428237423, 93.09735405829646, 100.9871389019874, 106.74464487260389, 5.368090608427602, 0.8419374929320428, 0.16550373526350146, 0.2193362893716943, 0.13730880383762623, 0.1664506505814291, 0.15520509272333116, 0.21217765737204783, 0.19610154742915786, 0.1812972047276074, 0.09938408845975515, 0.1649001039444439, 0.13029487052511785, 0.18801527488375866, 0.157247360555395, 0.11794057659684651, 0.13214815978802022, 0.1619888779016272, 0.11242484313345726, 0.20421762079481157, 0.10655582822378605, 0.1512709401187397], [0.023626569102728562, 0.0290564815664003, 0.0188639345428636, 0.05103814115207042, 0.07327290852704356, 0.053443013720454714, 0.036513416712442716, 0.06276818833524181, 0.06531008338976292, 0.02717099362804044, 0.0398545291635298, 0.024054708830531568, 0.09062164372974828, 0.024465307060088363, 0.08945466965557107, 0.09883903222338808, 0.029154037117897987, 0.22438022758691545, 3.7164663307128416, 96.69961175610943, 88.18356560122582, 79.62980193476524, 43.927576695719075, 29.813882727776807, 35.79064330747051, 71.99937205160819, 68.37296039827409, 18.521043639029227, 0.051446833737915566, 0.13154757749890128, 0.3683688125062374, 1.057020906479128, 0.07218694825085901, 1.0726330429315567, 0.5593388119051533, 2.2725300827334007, 8.871683536037322, 116.52789115905763, 98.40523089132002, 105.90927416278471, 99.55803901918473, 104.41717317027431, 95.85664733763664, 102.89213995779716, 94.88539003556775, 96.16153317113077, 88.20394623664119, 90.3692279323455, 85.99467123708418, 82.11314078300231, 78.66607558342719, 71.30209230607556, 64.24982763105824, 65.56943847287086, 63.39123648981895, 65.49416426689395, 61.15446959772418, 63.7683057015942, 61.56101934371456, 63.07905504780432, 62.099097928693226, 63.524938321882686, 59.934624241244414, 58.63020473910917, 57.066289071113836, 60.702086956270286, 58.461307479489236, 62.33163956672915, 64.16421797967726, 70.41087488974296, 67.36152233616, 64.27622518231793, 75.43558013054633, 82.24325364635837, 78.23289686633696, 75.50014234358265, 81.70443765578732, 78.1015916024485, 77.31921211365731, 70.4137852884108, 65.1565227200908, 69.9664625044792, 69.07828100265996, 65.74884376218243, 65.04191106365573, 71.35803314947313, 71.94575325135263, 76.94199777418568, 39.68908702173541, 69.39328655119866, 76.00347657357493, 68.80941821682838, 69.296325560539, 71.58276142612581, 78.58230160128686, 75.7112599957374, 74.2973396855016, 67.28094900808027, 62.79324370045816, 60.502183360438195, 62.40645485539591, 65.21975917200889, 68.75753310418898, 63.54294200097362, 61.97224063258018, 68.49467154472106, 63.846902155107074, 56.53728292834375, 59.65952096446868, 59.241094281596524, 57.38976693922474, 56.496094119164255, 58.09612697170627, 58.34033766100484, 58.386413743419034, 61.27202303178849, 63.69185870693576, 67.39664323868291, 72.97597946659212, 73.85042482806791, 76.96714016699022, 69.50480737993794, 59.569930107362815, 63.77812339413551, 63.773287111713046, 67.55528742267241, 70.71674131578015, 78.0517618117794, 80.55075876174435, 83.80523558585875, 80.4977204722743, 84.1185780494444, 82.29626055686705, 87.27186556785338, 29.478449475380685, 1.2187722205154359, 1.4694942894481844, 2.4113604137974405, 0.502740205415795, 0.7158418107898005, 1.0631144311158889, 2.237759251748362, 0.36327331657371215, 0.4300371437303482, 5.848398564323302, 27.39781645036513, 54.77509537050801, 77.76082392661803, 34.4495221876329, 26.121073192165746, 46.082213078775716, 64.95167693784161, 69.25061425855084, 86.87679659935736, 28.848418766452422, 0.7141457534124775, 0.0427080879378463, 0.08802885745441721, 0.0430217549775637, 0.009802977907501403, 0.013084510743107288, 0.01572494481449887, 0.02834995506301282, 0.1025907486496914, 0.06085912404101222, 0.027783069151243376, 0.09248256322837646, 0.13208348664545244, 0.04143173949071958, 0.03761127050365171, 0.007100504599586731, 0.025195203075606017, 0.07234641711317724, 0.033957230287694165, 0.0765018159103009, 0.015582296370168128, 0.062389641309217106, 0.03783668038405238, 0.03356624199377914, 0.019094253131639094, 0.02443088289921082, 0.05415924847306264, 0.07192130726311477, 0.02699878855398105, 0.014006381689180291, 0.026057339273393158, 0.034484088105419954, 0.0486270900845768, 0.06250158207671297, 0.06050752415772408, 0.026965494372791825, 0.09631353911132583, 0.2150809620657275, 0.564718158735383, 9.3009320382149, 118.33202454351611, 96.25119855326992, 92.26029672930318, 52.70109115108367, 42.88736804839104, 34.974590270749985, 66.01508248236873, 74.64775639195597, 20.383447754767634, 0.07792637938813818, 0.2788084150562363, 0.4291199219803657, 3.3516670282809966, 0.3516182693983278, 2.041133899361857, 1.40825456909595, 1.4959517794270671, 14.322645491169347, 120.90003951903313, 102.94546850265996, 111.41253994357203, 101.52229924355785, 110.33006775763728, 99.7452929712111, 104.70478488552956, 97.032346417827, 99.35260880377986, 91.95133163082986, 94.73985441269414, 88.05012656796364, 86.10183039019185, 82.17866789910101, 74.74356420578496, 66.18365026289418, 70.66913943136893, 66.39998466737809, 68.25174347046884, 65.55646719471102, 66.62427363857147, 66.15766848287275, 66.37532864847492, 65.37248057703819, 67.37545459501206, 64.39852076192057, 61.7827352400749, 62.10595423175443, 63.63603161227319, 63.38200715280349, 66.12035889779368, 67.56403430815666, 72.73141968634822, 70.79781670724192, 67.93003851367583, 78.55596680794993, 86.7646481913905, 80.55712084616385, 76.67872044347948, 85.56055115115258, 80.38930616071148, 79.83483206841254, 73.57281515675207, 69.0136952554026, 73.11530989985313, 71.97558679888326, 70.72074213335591, 68.16368626010033, 74.02278161817982, 75.96050308596703, 79.2085236887778, 43.04065427472515, 71.51263729218515, 80.04627135492142, 72.94307078084638, 72.33922189281833, 74.30316832757767, 81.6236525197183, 77.46759537727603, 77.14254071635585, 69.73945925312658, 64.79044398953839, 63.07694481265161, 65.99240333803239, 68.33142249814927, 71.37914334574054, 67.98503014349168, 64.54700208479359, 71.01633979428199, 67.86892014165079, 59.74820183169458, 62.64864944642591, 62.10567182110202, 60.67530501273371, 59.53326771336218, 61.137917195597005, 59.75068469201366, 60.63616760315434, 63.71222365287043, 65.90531103072628, 70.30333134435838, 74.87557549630442, 77.43075647661763, 79.29821260513799, 73.6026487042827, 62.70259772577594, 65.30878128543978, 66.0739964823569, 71.479446195787, 75.06180178734564, 81.13782775017523, 83.22692917239281, 87.21231614389728, 82.92191782305318, 88.93510741572227, 83.6061909890944, 93.00255821597193, 43.53647324346727, 1.0863613385346629, 1.1408448988391509, 1.1947822690971437, 1.519753457077088, 3.605757432599222, 1.8013994924483763, 2.6099127531051636, 0.2559458539490738, 0.4193145481328811, 4.19600599235104, 32.40224499856272, 48.37861568697038, 55.9429693222046, 35.1352152516765, 41.54834931896579, 55.352240762402936, 74.0898855270878, 76.14963193093577, 93.34363183667584, 50.89129778646654, 0.8616498545292886, 0.022572418712379954, 0.0657992841555707, 0.03494461803066154, 0.10292269454728212, 0.029566975746063456, 0.03921096934185874, 0.0066856962380810615, 0.05736989232020513, 0.04083317584328113, 0.06914839839502689, 0.05636671933555796, 0.06350284750242868, 0.01781897912282617, 0.033327421744263945, 0.022382566802984765, 0.04744824547801287, 0.06340979463270595, 0.06542990720199962, 0.0841461476539412, 0.03153323616471983, 0.12164346257885619, 0.08603938840209477, 0.21604683039890182, 0.1584295108313522, 0.13675222563887798, 0.13447686789497254, 0.21006587472173477, 0.08147843797961551, 0.15844984280486263, 0.14733173133384797, 0.1573232032598988, 0.21933644258927917, 0.16257047653198242, 0.2773026539193046, 0.1892681657186439, 0.2746605698860461, 0.29747022496115777, 0.6998112677566467, 10.97170679799972, 133.51713549706244, 111.97296819379254, 106.1426002748551, 66.52150754005679, 45.31926108944801, 53.02957004116428, 92.66262992735832, 85.83480327360093, 33.03052240802396, 0.18104090235166012, 0.32983740911849085, 2.085030492274992, 5.036275742515441, 0.7948920335019789, 3.100113416871717, 6.298500347521998, 6.57496125467362, 12.340403160741253, 129.91894921948833, 106.32632409372638, 115.51965375100414, 106.5992739892775, 116.26269971170734, 102.11459282905825, 114.49194569741528, 101.32106596423735, 101.95277152522918, 98.58409097117763, 100.81520572785409, 91.63741650119906, 92.14617144676947, 87.44242591242637, 79.10913082861131, 69.59954830908006, 75.9147447155368, 69.8643082957114, 71.86929841195384, 70.16865284212174, 71.24834798997449, 68.80919071935838, 70.47352298613518, 68.2255655719388, 71.10274960917812, 67.18977743579497, 67.07187098841514, 65.58298241707587, 69.60354128191548, 66.03653784721129, 71.83682118692707, 70.54262730383104, 76.07153754080497, 74.99763181132656, 70.76128375145697, 82.65678128888531, 91.6238921688449, 83.84701667293426, 80.37865300332346, 88.95053017523982, 85.7239257135699, 83.36479263920938, 77.2933558494814, 70.86355563132994, 78.79154436049923, 77.21544973311886, 73.89577527200022, 72.48243547254994, 77.14094038932555, 79.27565897664716, 83.78486279518374, 48.05503191486482, 75.22856527759184, 82.85928541614165, 76.61580562591553, 74.8182539786062, 79.33003087197581, 86.81177154664071, 83.21170253138389, 81.50315730802475, 73.14231149611935, 68.89314513052665, 66.97035220361525, 69.31093246706071, 72.26395160921159, 73.62919530560895, 71.44539217795096, 68.18754211548837, 75.6821560090588, 71.25721254656392, 62.674521400082504, 66.85791354025564, 67.39084597556823, 63.64550805860951, 64.00253003643405, 63.1846962436553, 63.23923680090136, 63.14311127508841, 69.20451071954542, 69.47259687608289, 75.20875730822164, 78.84972879963537, 81.94040744535386, 86.79529759191698, 77.58360339749244, 65.06470395672706, 71.83033358666205, 71.39400912869361, 75.97950304708174, 77.37055593921293, 83.95954162843766, 86.63455886225547, 91.83477447878931, 86.26407530999954, 94.28736978961577, 86.79324226994669, 97.14054892140051, 41.68048612533077, 2.3354260238908955, 10.89719549302132, 7.093547130784682, 1.067850080228621, 4.245520522517543, 5.7597299545041984, 4.110717239879793, 0.8759880786941898, 0.5866546267943998, 8.842720754684942, 45.880399288669715, 71.94142295468238, 105.70368705257293, 44.729109118061686, 38.638589997445386, 63.19933845150856, 86.25006460374402, 85.71452771463703, 111.67599770330615, 48.516981217169, 0.6503222942832978, 0.11590429191147128, 0.21712209608766342, 0.19312618450532038, 0.20751392859364712, 0.13786682228167213, 0.09328004543579395, 0.10663363211337598, 0.21210446533176208, 0.10874480189334963, 0.1676613299716865, 0.14879381013733728, 0.21567593659124068, 0.13909714416630808, 0.08880467469533605, 0.11380170997712882, 0.12405995670105181, 0.18548352283335504, 0.10041318202932036, 0.13048706666356133, 0.11445184283319021], [0.047096860099343524, 0.037636447983283194, 0.04218448982423833, 0.019345552953440818, 0.03537381112936043, 0.018900325634486733, 0.0326289372488616, 0.06207071507589952, 0.040522998334058834, 0.05991486321774222, 0.04905436413302537, 0.0472994520509195, 0.09172245078990537, 0.08682439869810497, 0.005743634087153741, 0.0420705687194582, 0.1706406152656963, 0.33066331318789915, 36.789655300878714, 96.06294831921979, 82.13906764984131, 77.30111429768225, 67.03431821638539, 45.15100317616617, 65.92040431114935, 85.92582579581969, 43.25090116070163, 4.203996350688319, 0.06924928451377539, 0.08518791231777399, 0.3542184331003697, 0.7607403241338269, 0.25078496475133205, 0.28994316595696634, 1.0999818915320982, 0.27008877165855905, 70.27435287352532, 110.47363435068439, 92.34771067096342, 99.57427763169812, 99.21818133323424, 103.3021531566497, 97.64473038335001, 95.09027896388885, 85.81492470156762, 81.75501269678917, 81.1874065091533, 79.71329350625315, 77.45866806276383, 78.30395452437863, 68.35490965074109, 66.00084427864321, 63.22729710609683, 64.73472672124063, 61.91618604044761, 61.91109088159377, 62.413060126766084, 61.375138221248505, 59.76089854394237, 62.17365041855843, 60.71941991006175, 61.47952425864435, 60.00599961127005, 57.48184065664969, 57.52645369498961, 59.63465705994637, 58.32440891573506, 65.26140689849854, 65.99660811885711, 69.14620076456379, 70.75820076850154, 63.64590421799691, 67.75767387882357, 80.82705836142264, 78.76591559379332, 75.61996290760656, 74.13596553187217, 79.2648724586733, 75.96034619116014, 77.59984985474618, 68.35425069255214, 66.99673406539425, 65.13105477056196, 64.43983900931575, 65.5900073820545, 75.43795708687075, 71.93251132965088, 72.79108678140949, 36.92234123906782, 71.35993157663654, 77.58070868830528, 70.64965309635286, 67.58285384024343, 66.62189668224704, 66.27560630921396, 62.70823809408373, 61.64689179389708, 58.58753719637471, 56.56628493339785, 57.162273391600586, 59.97806449090282, 65.28581580808087, 69.62212547179192, 69.14409837415143, 62.09682295399328, 68.00716015600389, 70.03500200087025, 58.08822731817923, 57.73395492184547, 58.17741417115735, 58.1507852000575, 56.12105669513826, 58.58372465256722, 58.043127905937936, 58.19569633853052, 56.4211650817625, 57.77004464980095, 58.40412324474704, 64.49902757521599, 66.74861277303388, 68.59818289356848, 60.35546318177254, 59.58297198818576, 63.56237342280727, 67.34619371352657, 70.45669601809594, 74.63562057864281, 78.52800030862132, 80.62340105733564, 82.36698873581426, 83.69890013048726, 81.10797851316391, 83.06420572342412, 81.03011946524344, 90.58647232670938, 22.25562249460528, 1.1546484549199383, 2.825078046129596, 2.4821292873351806, 0.10376110117161468, 0.6853048719706074, 0.31291918468571484, 0.7054613194158, 0.08003193374362685, 0.08774861483083618, 16.424156312019594, 30.295441919757476, 50.749229538825254, 51.92894904844223, 16.51561813969766, 40.90799885411417, 63.46119980658255, 73.05774519520422, 73.44945661483273, 80.55569310342112, 7.337712222529996, 0.4346282473735271, 0.11667534408550109, 0.030355008258934946, 0.12386596025598627, 0.05891995632179803, 0.04768922992591416, 0.00880132273455421, 0.052534988856003176, 0.05544788497049482, 0.02762137863394474, 0.015286654421699145, 0.027380162444446358, 0.02847095290499349, 0.037596848898477135, 0.07861987282071384, 0.02241595674516453, 0.08006279176521687, 0.01974663828619786, 0.020610676297257026, 0.04507889640667746, 0.0663343429445259, 0.029658203411306587, 0.08481265946982369, 0.050534817555378524, 0.03282748425619737, 0.06593040776469054, 0.10390350159497992, 0.05631513480517653, 0.045443734289297176, 0.036404103626527136, 0.08131633377483777, 0.05788360023871065, 0.05614008754491807, 0.08408473804593088, 0.07592668306202659, 0.11340356642200101, 0.0610864338194651, 0.049785706139500105, 57.66366212598739, 111.59876623461324, 93.40248307874127, 93.20299917651762, 73.90180787732525, 54.90429432161393, 42.476637055796964, 86.29037087963474, 50.24017257075156, 5.187688056499728, 0.11296611489547838, 0.7199987264410143, 2.1332018558056127, 1.7802275188507575, 0.8558764320708091, 1.0669713467359543, 0.7699819798431089, 0.4792796513966976, 81.01277474434146, 112.30379658360636, 96.97118097735991, 103.35146519445605, 101.19970783110588, 106.39702873845255, 99.05970973353233, 99.3142480234946, 91.43943094438123, 86.39357628360872, 84.19406014104044, 82.63498860020792, 80.86043773158904, 80.40661165791174, 72.25168243531259, 69.86050359664425, 65.15792300624233, 68.36338981505364, 66.03431778569376, 66.6153149450979, 65.35868167877197, 65.73170300452941, 64.39680276378509, 66.81787398553664, 65.68716449122276, 64.5757765923777, 62.88505069671139, 62.60954733817809, 59.70773866099697, 62.50773045324511, 62.66104021380025, 69.12079949532786, 70.10482803467782, 71.64631951239802, 73.99566235080843, 64.90276498179283, 70.36517927723547, 84.86791549190399, 82.60984620740338, 77.93689127891295, 74.9631541775119, 82.99722733036165, 80.63878459315147, 79.87158467692714, 71.37355789061516, 69.98401118863013, 67.08543454447101, 68.77179484213553, 69.141038925417, 76.02996826171875, 78.34787722556823, 78.14540447727327, 40.97439281402096, 74.72243832003686, 82.2169973004249, 74.24312468497985, 71.38974158994614, 67.15864950610747, 69.46731736583095, 63.79109467229536, 63.39138161751532, 60.79087372749083, 58.42148757749989, 60.36409631852181, 63.95616369862711, 68.45571456416961, 72.65168574548537, 73.4506647048458, 65.24285408758348, 73.37198195918914, 74.54375866920718, 61.00626284076322, 60.83012880817537, 58.037279652011016, 61.46421524786181, 59.575990169279045, 63.31131819755801, 61.59714045063142, 61.39187497477378, 58.12224603468373, 60.02884741752379, 62.483549041132775, 67.10793325977941, 70.43160069373347, 69.31630611419678, 62.08480088941513, 62.354593276977546, 64.89765805582847, 69.71658399028163, 74.76896547502088, 77.19218223325669, 82.0852291968561, 86.08952199259113, 84.88197326660156, 87.83941684230682, 82.06953187142649, 85.09414995870283, 85.20715344336726, 93.6622538105134, 35.26184897268973, 1.751286923404663, 0.7183872451705318, 0.9071666927587603, 0.4617435617312309, 3.692110863424117, 2.08901880729583, 1.4416269525404901, 0.17933830258346375, 0.14533406514073574, 15.080940646509971, 36.44633023969589, 42.02245796880415, 36.56693527775426, 21.968863894862515, 60.41715421984273, 75.27221341286936, 79.23912602086222, 80.0917237804782, 95.60096371558406, 16.041651675778052, 0.6946857105339728, 0.1241967416999321, 0.12686024555155348, 0.08828960314032533, 0.023514339137041283, 0.016282517012328874, 0.056616831721077045, 0.00948866926914742, 0.05610280970652258, 0.027816667852382508, 0.041109404166138945, 0.035262804989132195, 0.036062731017028136, 0.043454433776318066, 0.04730941502437477, 0.06260423785856654, 0.031999764558408535, 0.0256444753388003, 0.00960117694170725, 0.10325125433624753, 0.13581804270225187, 0.10797962561369905, 0.1666997823744051, 0.13217714855507498, 0.20399536336621932, 0.14944470908132293, 0.2828698148650508, 0.16902583981713942, 0.17717992646559594, 0.1578853432569773, 0.1732460802961742, 0.14774768643321531, 0.1528669310913932, 0.25211990360290776, 0.25602655365101756, 0.2032949291770497, 0.23355888022530466, 0.34021983103406045, 63.00567142425045, 129.41759970880324, 107.88648605346681, 105.30906523427656, 90.02906430152156, 67.68013646525722, 86.78182817274525, 107.69624325536914, 62.18156968393634, 10.33091506650371, 0.42247211740862944, 1.568127680690058, 2.606807706817504, 3.9344920121854354, 1.285651941453257, 1.5751821860190363, 6.684482655217571, 0.6551778208344214, 83.00515836285007, 116.99153884764641, 101.34814600790702, 110.16984678083851, 106.07643773478847, 111.8094132023473, 105.45437335968019, 104.12675303797569, 94.57333410939863, 92.37056239958733, 88.54947566986085, 89.0819295760124, 86.9528199780372, 86.58621957225185, 77.14971865377119, 73.55407407206874, 69.65879178816273, 71.5093974144228, 68.73323794334166, 69.40820724733415, 67.07924504433909, 67.59163994942942, 67.1154877447313, 69.14322760797316, 68.6926257225775, 68.08704314693328, 67.81848630597516, 66.42837478268531, 63.154042920758656, 65.97532533830213, 67.63616669562556, 72.62593146293395, 71.13943161502962, 73.40056034826463, 78.05541746077999, 70.2369099278604, 74.37120576058665, 89.14008263618716, 86.21648127032866, 80.72411967862038, 77.35943994214459, 85.08157483993038, 82.22396342985093, 84.11320440230831, 75.60517557205694, 74.25469567698818, 70.66277734694943, 71.53193535343294, 72.05707011684295, 81.6889129146453, 82.1878933137463, 82.65404347450503, 49.5730205505125, 77.70286698495188, 86.78898257593956, 78.50856104204732, 75.05578487150132, 72.16618261029645, 73.92942136333835, 69.90732100702101, 67.6741195494129, 64.3019873096097, 63.10172242503013, 64.72605436078965, 66.16384229352398, 73.5957924012215, 75.38603275052964, 77.16220748039984, 68.81024975930491, 76.89325055768414, 76.02510452270508, 66.11952735531715, 66.05989948395761, 61.11463400625414, 63.42357250951952, 62.704488308199, 65.63624035927558, 65.46751176157306, 64.44398495458788, 63.231097882793804, 63.654196108541186, 64.93725046034783, 71.51513191961473, 76.21900296980336, 75.4684966610324, 66.467496502784, 66.42201269826582, 71.58247117073306, 74.05368205039733, 79.09138602595176, 80.83622101814517, 84.40789207335442, 88.73377999951764, 88.68313435585269, 92.89458320986841, 84.48254262247394, 91.55337579788701, 88.02462331710323, 101.778837942308, 33.08149753078338, 3.1964027016393604, 10.976372457319691, 6.35966774917418, 0.4835300297746736, 3.719280141015207, 3.688157359438558, 1.4137515257443152, 0.4987406442242284, 0.3060498887733106, 28.233402890543786, 45.42343924122472, 70.09596347808838, 68.7948662234891, 23.323603483938403, 59.08407395885837, 82.17429053398871, 92.0054760286885, 90.09768224531605, 111.02730043472783, 12.721075069519783, 0.7336496165202511, 0.35312427568339533, 0.17268528861384239, 0.24347273212286735, 0.17174735184638731, 0.19960875923354782, 0.24874825871759848, 0.13250534062183675, 0.12768652500404468, 0.15226955104979778, 0.09672983895025908, 0.10086177247426203, 0.1579477181357722, 0.12265633806706437, 0.20128089934587481, 0.14196147030640033, 0.18342447767574943, 0.18217895660669575, 0.1947790192019555, 0.11132385987307757], [0.007363530833484426, 0.06408439633706886, 0.038157855085427725, 0.03463039940763866, 0.003152458990488442, 0.07647210702059731, 0.03948001942086605, 0.03139162481191658, 0.06858795145226103, 0.030982160392487725, 0.027005537788593964, 0.025994397489534273, 0.03122346659731721, 0.05402389222816114, 0.0436787826249436, 0.1334996154952434, 0.4352680840078862, 6.85209680949488, 95.16644354789489, 79.55162909723099, 86.45975451315604, 52.80668920086276, 44.66855948971164, 45.48467920672509, 77.88611227466215, 78.11574351403021, 28.501455706934777, 0.40583584397550554, 0.11493961101457958, 0.6244452538028841, 0.7046976216858434, 1.7775858025397024, 0.6957269159536208, 0.23010770009169657, 1.3483192819741465, 16.425108467378926, 113.81787069382207, 96.82147195262294, 95.61004792490314, 91.54007111826252, 103.42842994197723, 96.73131235184209, 95.85245040155228, 91.89311581273233, 87.9649248430806, 77.55964556047994, 72.23101938924482, 71.01705366565336, 70.80342569658833, 65.8473462443198, 65.37630881032636, 64.45579521117672, 63.09202632596416, 61.75934614673738, 61.518936234135786, 61.16613472661665, 61.43068682762885, 61.918464937517726, 62.69010105440694, 60.39582829321585, 60.70605639488467, 59.52489345304428, 56.785368919372566, 56.84143920098582, 58.33150840574696, 59.74545617257396, 60.756501997670824, 64.42016832290157, 66.72400382257277, 69.34236634162166, 72.425780757781, 65.64689351666358, 61.916915601299664, 71.82343805989912, 74.08386076650312, 79.26679442005774, 76.17945763372606, 76.2153551655431, 77.39707116157778, 77.4224018281506, 76.61035353137602, 70.6448442705216, 69.92542666773643, 72.82093601842081, 76.4260256674982, 72.74493617396202, 77.23230808011948, 69.32422930194487, 41.06396405927597, 72.7879253510506, 71.68959110013901, 70.57760700102776, 65.31120531020626, 61.745174623304806, 58.30658566567206, 55.343611548023844, 57.176593965099705, 57.73076995726555, 58.07724860406692, 57.74761653715565, 60.948741282186205, 65.34609087051885, 68.7157912408152, 68.60864777718821, 62.89172657074467, 63.00895444808468, 81.20879911607312, 64.98504061852732, 57.59753488725232, 55.894892831002515, 56.691361473452666, 56.48217754979288, 58.376603895618075, 58.19681421402962, 56.69721364974976, 57.21622951569096, 56.92837461348503, 56.41282612277616, 56.172333840400945, 58.45849514007569, 58.28393790029711, 58.592091068144775, 59.01471468710131, 59.774615072434955, 63.42975024254092, 71.38540344853556, 72.89657500482375, 78.82633578392768, 76.73539869246945, 83.26818466186523, 79.04664747176632, 75.85495210463002, 74.11679298646989, 84.13487941988053, 80.10973530430948, 92.7648155150875, 17.74829553019616, 0.5887983859546724, 3.3412085185127878, 2.5694880706648675, 1.4877556192298091, 1.5321812418199356, 0.42966782806381104, 0.14454550019675685, 0.02857851931044171, 1.4625970466483025, 24.005723268755023, 35.42991076746295, 70.7160117549281, 46.76115182138259, 26.139863306476226, 41.494106861852835, 62.64300907811811, 68.70019589701008, 74.58822265748056, 50.02013544882498, 1.0875672222145143, 0.015045884478416656, 0.006111621548752151, 0.07289189469790266, 0.01191907363282817, 0.04689850844442845, 0.04194694894155668, 0.015185486765638476, 0.051846306455591996, 0.012359990749598272, 0.022388569101871505, 0.011732776371401646, 0.020253631444047057, 0.014294732395829934, 0.059547259757715854, 0.057481810105063265, 0.04924429265121299, 0.06853848515499024, 0.16707729518173203, 0.0807872274890542, 0.028161169931052193, 0.08959284893447354, 0.011951811442662393, 0.056669848835876876, 0.0280193172605528, 0.0635872167655297, 0.02792901464647824, 0.03739597298385155, 0.0450744454358374, 0.08319138759566892, 0.03671471397542665, 0.0375446361759978, 0.1060476974253693, 0.10516775351378227, 0.08927998628707663, 0.22052253055716717, 0.6808877315732741, 14.448249590012336, 119.30739248952558, 85.33034724573936, 96.36764587894564, 67.7770503874748, 70.26591977765484, 43.886572237937685, 63.40458039314517, 84.36182775805074, 29.038575272406305, 0.3217572346329689, 0.46171153925599595, 1.7712987334497514, 1.843567545856199, 3.801928402916078, 2.375125558145585, 0.4397408423885223, 0.986135587576897, 22.181281812729377, 121.06825428624308, 96.21180226725917, 98.70096191283196, 92.67733097076417, 109.8669299771709, 101.90748383921962, 99.24672834334835, 96.34736722515476, 90.53966276107296, 82.48173375283518, 77.16901671501898, 74.53148949530818, 74.24572913877427, 68.84651599391815, 69.03147143702354, 66.92264833757955, 66.03195651885002, 65.92836672259916, 67.90479413924679, 64.14013070444908, 65.40552654573995, 64.36519630493657, 65.9540896261892, 64.23231817060902, 65.1533926686933, 61.78544559786397, 60.76211883175758, 58.921307363817775, 61.78490038841002, 63.71573025180448, 62.93353511441139, 66.99252928456953, 69.91904889383625, 69.50617236475792, 74.51438796135687, 69.36316274827527, 63.54225950856363, 74.31492759335426, 78.4405706774804, 82.7192097325479, 79.39071778328189, 77.1906368194088, 78.8927807346467, 80.85274988605131, 80.15317163159771, 75.54072318538543, 74.35551627989739, 75.7037918029293, 77.36294654107864, 78.60333335015082, 80.87070649670017, 72.62852022724768, 46.3649453655366, 75.4248171467935, 75.87070434324204, 73.34996177304176, 68.55091048825172, 64.67500471299695, 62.15062218327677, 59.46546562256352, 58.84278543533818, 62.570456997040786, 62.642879639902425, 61.10579690625591, 66.40109077576669, 69.19959206734934, 71.18900252926734, 70.32049563623244, 67.07329088641752, 64.99410913836572, 83.70599962049916, 68.57950456680791, 61.054194204268924, 58.31964715834587, 59.424845557059015, 58.29631297819076, 60.9838229610074, 61.18867658799695, 59.30234209183724, 59.36071480474165, 59.2725085443066, 59.97979425614881, 59.761102507191325, 61.697094209732555, 59.379934418586, 61.81136854233281, 62.12198888101886, 62.658337700751524, 65.51525485131049, 74.37273548495385, 77.77602703340592, 81.59089288403912, 79.59541843783471, 84.60631693563154, 82.47877628572526, 80.65192453322872, 75.143504758035, 87.44386934464978, 83.10984642274919, 97.21798435334237, 33.4126946233934, 0.7943378148540374, 1.8721565988755997, 0.8411033151130524, 2.728854461062339, 4.421889407019462, 0.7583777702623798, 0.8754584974338933, 0.08769030021803995, 1.3885358336471743, 29.05373327193722, 40.01997424710182, 46.84104265705232, 37.92238873820151, 39.761172340762236, 50.1831962216285, 70.96282297565092, 75.58863885941045, 79.6023767225204, 72.82049671296151, 2.473293658225767, 0.13323606592753243, 0.10499397412903848, 0.04249707667998249, 0.04978232386131441, 0.016271515989736203, 0.0631949644265396, 0.01151584612671286, 0.0853643270449773, 0.025692576084346063, 0.012020853201618359, 0.06300279127073384, 0.02141017140069556, 0.027947492687211885, 0.057071658121722366, 0.022512276979884314, 0.0538886355746898, 0.014463283230490504, 0.03243601715732967, 0.06007742707527453, 0.19715858022532157, 0.21868899104095277, 0.133147077154248, 0.11799666955466233, 0.17366454816393315, 0.25189151747092126, 0.1136806144589378, 0.23477735839063124, 0.1971328703145827, 0.18506102534311433, 0.08145835115424088, 0.1927500200127402, 0.1811907491496494, 0.26555052808215546, 0.1758873982415084, 0.3334789927447996, 0.7877873953792357, 14.45687194024363, 130.10063340587, 101.04508015417285, 111.84185120367236, 78.09045207115912, 64.71964128555791, 64.38226645992648, 109.33045171922254, 92.52024789010325, 44.53672078347976, 0.41050781585997154, 0.31489716241917304, 2.0349908548016704, 2.4026476039040476, 6.778599927502294, 3.4585827492898513, 3.19428633778326, 2.771641145790777, 21.765694925861975, 127.54289504020446, 102.27868910758727, 105.29388566170971, 96.70635823280581, 114.24619351663898, 104.17353122465073, 102.85119825793852, 100.6341334312193, 97.89580914282031, 86.05963353187808, 83.01506626990535, 79.30506106345885, 80.27400416712608, 72.91254689616542, 72.35305217004591, 70.9160840126776, 69.86373562966624, 69.65239832478186, 70.48925169052617, 66.66879254002725, 68.96014705781015, 68.29157121719854, 71.50385118299916, 69.29973017784857, 69.00763911585655, 65.59644791387743, 65.18296341742239, 62.149519997258345, 63.94369448384931, 65.86907617507443, 69.64453005021619, 69.8620411657518, 72.54293411008774, 72.64267998356974, 77.99851171432003, 70.45821005298247, 69.7907324760191, 77.907073420863, 81.35140865079819, 88.82088799630442, 83.62688541412354, 79.37043912949102, 83.13087817161315, 83.10783816922097, 81.34852178635137, 78.68638561617944, 77.88846569676554, 79.77361171476304, 80.62415415240874, 81.5873235271823, 85.57748794555665, 79.50332903092908, 52.15488541510798, 77.85407435509467, 80.3469680970715, 76.43348601556595, 70.73469008168867, 68.25139830189367, 63.51776822920769, 63.1960593500445, 61.59156284024639, 65.43531302482852, 64.9714849072118, 64.49649372408467, 69.33216033443328, 72.02799750912574, 75.82863300077378, 74.70612126012003, 69.91978629942864, 68.15060123320549, 85.28215700580229, 71.27221169010286, 64.22009606515208, 62.12300477489349, 63.60430355994933, 61.979634300354995, 64.0810166635821, 64.27247931880336, 64.0525520232416, 63.343450254009625, 63.915323980392955, 62.73163895453177, 63.14881832368913, 64.06761000233313, 64.52691562714116, 66.3284484801754, 66.77316681031259, 66.65378555174797, 69.8427587939847, 78.21118262506302, 82.14079349271714, 85.93397648103776, 83.37621458115117, 91.25829588982367, 87.69787419226863, 84.93860444714947, 78.96458364302113, 92.41974107680782, 85.63390731811525, 104.11751977859005, 30.751554735245247, 1.3159879200881528, 14.426508872739731, 6.547978289665715, 3.6491810121843895, 6.688434443166179, 1.7416414474287343, 0.7045333111478437, 0.0755052580948799, 2.5897711371221854, 42.147063824438284, 51.57337834758144, 98.8103646616782, 59.82453115524785, 36.555321139674035, 56.77032662976173, 82.37133472196518, 87.18153338278495, 94.94712029733967, 75.78144688760081, 1.7353731321711696, 0.14997566929988324, 0.1861884922630364, 0.19329611812868427, 0.14709134826496725, 0.12122343955261093, 0.14781897857544885, 0.1454614349190266, 0.18688894177396453, 0.12681202797759927, 0.13579338999284854, 0.14199562250606476, 0.15283352965789457, 0.09354212411469029, 0.1817040280589173, 0.12824505672699985, 0.14455352879820332, 0.14694913170270382, 0.24522597030285867, 0.23022342533353837], [0.03470140043646097, 0.024989686583379106, 0.013245938875291859, 0.020556590489802823, 0.020339944655255928, 0.07548247464001179, 0.03209796362376261, 0.054604119561131925, 0.036678887873647675, 0.025046693101044626, 0.05782292990554726, 0.047434452064936204, 0.10579199259800297, 0.07074028313640626, 0.18971523930949552, 0.12806943107035854, 0.41043883730326935, 42.742577675850164, 94.75178626275833, 80.64718631006058, 69.42616385798301, 46.10828115094093, 21.740803564748457, 54.927644191249726, 98.67062630191927, 39.9961027022331, 9.327095227856791, 0.12341489534704916, 0.5004687240767864, 2.2566082016114266, 2.504826082337287, 1.3475815086595475, 1.36376888521256, 0.4051610430882823, 0.17022485934918927, 72.3146286318379, 109.0400629658853, 86.63419800419962, 87.14233321528282, 89.18070270169167, 101.01748235764043, 94.30559312143635, 98.73746348965554, 90.29111785273399, 87.08338783633324, 75.04510033515193, 72.79132996836017, 66.45117159812682, 63.26575202326622, 62.573791011687256, 64.42107831278156, 62.45017751570671, 64.13222712855186, 63.098172680024184, 60.25785892240463, 61.99531985867409, 63.80574080251879, 59.71987055193994, 61.00338382105674, 60.9094391330596, 59.93727184111073, 56.86441644545525, 57.93145018239176, 56.41052761385518, 59.79130867988833, 58.79543066024781, 64.67884863576582, 64.40363945499544, 66.47653364366101, 63.575933056492964, 68.3922270805605, 68.7713869156376, 61.36931742391279, 57.25005995842719, 69.0452781800301, 72.18785762786865, 74.43197896403652, 78.21340268658054, 76.22454135648667, 73.49321457647508, 82.54740991900044, 76.09205153680618, 73.92814267066218, 75.64632907990487, 75.25344094922467, 76.48546526508947, 72.10770007102721, 58.773508533354736, 49.1937901127723, 75.6349620511455, 70.01312302004906, 66.45545482635498, 62.43988129400439, 59.950400014077466, 62.974496426120886, 61.093257088815015, 60.45177305898359, 60.63226484483289, 56.424993315050685, 54.00620883510959, 60.638191546163256, 64.55833773459157, 69.32243285640594, 66.50867354485297, 67.56530515609249, 59.59985386940741, 80.91904578670379, 76.69627697237077, 59.707989692687995, 55.60526893984888, 52.1285427770307, 56.09430613056306, 57.57015674344955, 54.98499316553916, 56.538008566825624, 54.68515542245681, 55.488876527355565, 56.39845063609462, 59.939793925131525, 55.464859854790475, 58.431050315979995, 57.72141902677475, 56.344286626385106, 56.17384003054712, 60.035837081170854, 61.33765212951168, 72.25221587765601, 74.55737713844546, 79.93412294695455, 76.89228565462174, 76.33101017244401, 71.74013476217948, 77.16668682713663, 76.14927891762026, 84.22740028750512, 76.5559345676053, 91.51348529323455, 15.638534984280987, 0.7809415724008315, 0.855648689452679, 3.782295959611093, 2.198731913681953, 1.5349397712176847, 0.32610104509419013, 0.12681567455611883, 0.07048290057648575, 10.229284494153916, 26.419275306886245, 53.95556319144465, 55.11739669307586, 21.54133927437567, 59.11578632170155, 59.3319599090084, 68.52787833059988, 61.51814391536098, 83.51432907965876, 14.868480563163759, 1.0677288544754828, 0.0918238808310801, 0.06484771102306343, 0.061850545236900936, 0.023184465507285732, 0.04330180224872405, 0.0444140546624699, 0.01160979436169709, 0.041104298190123616, 0.02500068569075196, 0.0303157156092986, 0.019716996429187637, 0.06751573479343807, 0.06226026438056462, 0.062036068749523936, 0.09390063028061583, 0.0519538690306006, 0.04518588441574285, 0.13357866044727065, 0.006578793935102201, 0.01763034337801078, 0.02973291422090223, 0.06289592200529671, 0.023678994414606885, 0.039010480301634926, 0.03177365562277696, 0.07029250474466432, 0.07258519139741698, 0.040228445188052235, 0.027904093806301395, 0.045681060667360024, 0.05403279033940166, 0.1482134066041439, 0.17244349594318098, 0.03658950839552187, 0.3107912682237164, 59.65492394662673, 104.30515027815296, 90.60193430992865, 82.45327303486486, 57.33973710767685, 42.45591517417662, 49.63098533691899, 87.24666826186642, 47.8739203945283, 9.959586243475638, 0.17574328178119275, 1.6139374096547405, 4.957163497324913, 5.309969907806766, 2.7199126828101376, 1.5812927484512331, 0.6747468320592758, 0.8150897271210148, 84.75238600084859, 109.46947620761011, 91.34694930045836, 89.1640796969014, 93.72485483846357, 103.43514503971224, 96.74045147434359, 102.15635038191273, 97.12965257706182, 92.46586815003427, 79.36577150898596, 77.29341076266381, 71.3411355787708, 66.87161830163771, 67.0450419764365, 67.53065493799025, 67.19316636362385, 66.79077040764594, 66.0586678597235, 64.17495742920907, 67.45352545092183, 66.9609385152017, 64.73272631245275, 65.02757087830575, 62.55356727107879, 63.73072939534342, 60.06199144547986, 60.56077180370208, 59.19059376562796, 62.4556335326164, 62.949789416405466, 68.1721507349322, 67.86555474804294, 69.50805510244062, 65.92143981687485, 71.34629741791757, 71.19225025177002, 62.956849682715635, 61.32677931939403, 70.5154452785369, 74.56062486094814, 80.64883370553294, 81.76606593593475, 77.91800898890342, 75.11318483660298, 86.41669473340436, 77.94377896093553, 77.45420440550774, 78.24129858324605, 79.31276459847727, 78.48064161116078, 73.97116322671214, 64.84853036942022, 52.12378886438186, 78.3704936119818, 74.2811167624689, 70.14745635371055, 64.05113604760939, 64.98229888177687, 64.99242251919162, 64.53819636375674, 64.27906105595251, 62.984824026784594, 59.47293381537161, 57.4307753193763, 64.87856003545946, 67.4035152312248, 72.42867546696817, 70.99530020067769, 69.86937599797403, 61.95081272432881, 82.44691095044537, 81.58684499802129, 64.72515613802018, 59.50343416583154, 54.88368618872858, 59.818847640868164, 59.4451791240323, 58.464174732085205, 59.07146353875438, 57.98667323204779, 59.53398550710371, 58.86131863440237, 61.21828263805759, 59.265448277996434, 61.283339069735625, 60.55490786029447, 60.05708848276446, 60.02402290221184, 62.74819135665894, 66.29914053024785, 76.66470189248362, 79.12134508932792, 81.56200070534983, 79.1988197449715, 80.70631211803806, 74.84817381828063, 79.72076169906124, 77.51770757859754, 87.94445791552144, 78.82035024704473, 97.38816815037882, 33.21030424487206, 0.8777417458834187, 0.8682269338638553, 0.7608771167935864, 4.612858824191555, 5.819847631839014, 1.7689125840702367, 0.47204125432237504, 0.1354421693230829, 9.625477771605215, 34.299864153708185, 48.522335252454205, 38.26734942774619, 22.003635706440097, 78.85126636874291, 67.10937669200283, 78.72133393441477, 68.72876644134521, 96.97493860798498, 27.93730708860582, 1.1661333999326153, 0.0894711941720978, 0.07142272958111379, 0.11234720778321067, 0.05304686582436966, 0.011947587425369891, 0.07156421069896991, 0.05896114886948659, 0.018304883795339736, 0.11393982796899735, 0.0430051461913653, 0.027945533417345538, 0.05618022289127112, 0.04944609553222695, 0.06990307927011483, 0.16012768261134624, 0.03717961060183664, 0.05964587442576886, 0.09112300997179362, 0.09952196896436716, 0.09792222416088467, 0.10815025637707404, 0.16815119723398841, 0.11064105336704563, 0.17660278646696, 0.1729793744462152, 0.11521819888824418, 0.1501808889330395, 0.13445212325501826, 0.1532641783236496, 0.21645225945018956, 0.14255065320720597, 0.2872363934593816, 0.3095610842349068, 0.4442198520466205, 0.5376620782959847, 67.74016441837435, 119.05446237133397, 106.3369615616337, 91.81979102473106, 69.78441746004167, 35.292266953376036, 74.9277743985576, 121.84201240539552, 59.949384120202836, 18.628812720698697, 0.48054299167087006, 4.288565103084811, 7.391916436533775, 6.431933497228931, 6.29676862109092, 6.834627063043657, 5.289008761605909, 0.6888633810224072, 82.4306409589706, 116.80145294435563, 97.30466088941021, 95.07798625576882, 96.88783061119818, 107.3538124945856, 100.51134755534511, 102.85559131253152, 101.8576148248488, 96.90714436192667, 83.35621049327236, 82.69943314213907, 74.73157744253837, 70.65722327078544, 72.11483878474083, 72.36387791172152, 70.50145810650241, 70.6862017416185, 70.86628560096987, 67.5317688911192, 71.93025204443163, 72.41385675245716, 66.49041883407101, 69.35258019355037, 67.73083702210458, 67.78843310571486, 64.70823503309681, 65.40569520765736, 63.41686133415469, 67.64103043463923, 66.30610665967389, 71.38886297902754, 69.96334814256238, 73.97358725147863, 68.2720221242597, 73.47502262361589, 75.83706609664425, 67.77195915099114, 63.2906198501587, 74.2716246266519, 79.26584520647603, 84.62474423070108, 86.3794400615077, 80.0410153788905, 77.70620099959835, 88.97516265992196, 82.60732804575275, 82.0632403896701, 82.38250563221594, 82.37104446657243, 80.98569470067179, 82.32313663728776, 68.26829587259601, 55.25580144697621, 82.3191515091927, 77.5417987761959, 74.99978127018099, 68.61479020887806, 65.95951034176734, 68.26886853864117, 67.49370621096703, 66.55600086335214, 65.25843374190792, 64.38569853382727, 60.29258758791032, 68.50450884911322, 71.92838499622961, 76.22363921134703, 73.4193406566497, 73.93235529622724, 64.61713014110443, 84.96194254967475, 83.83707738691761, 66.59384389077464, 61.48205810977567, 57.895584029536096, 62.17293654718707, 63.88525901302215, 61.18756263486801, 62.723405899540076, 61.79108988854193, 62.861057558367335, 62.58787232060587, 65.59867582013531, 63.117949270433, 64.27860606101252, 64.09372906531057, 63.16615519985076, 63.16735936749367, 65.93118298438289, 69.09375867535992, 79.57290403304562, 81.42137588993197, 86.10390924638318, 80.97064064395043, 84.72235633480935, 76.73022900858234, 85.98424557716616, 83.17453415163102, 93.82672663657897, 82.37229962502757, 103.81914507958197, 31.151446257868123, 2.3618581410377257, 8.351952818132217, 7.451575686854701, 6.920974120017021, 6.535462496742126, 1.5381474120001641, 0.4897984063192722, 0.17391407832262978, 17.3985573937816, 44.52389463301628, 77.7764271151635, 78.35333716484809, 28.07425468198715, 78.12736157448062, 75.09569106563445, 91.51951005381923, 77.48234348912393, 112.16670190134357, 29.319811174946448, 1.525024877440545, 0.17967890527459884, 0.18819694497412254, 0.3514481672356206, 0.11592639354808677, 0.07909098625062935, 0.1291444209674674, 0.15080255396183462, 0.11926411606010892, 0.2516199699452808, 0.22371828165506163, 0.19953909119771374, 0.28263606611759434, 0.14231419250849756, 0.3456707304764179, 0.3358397080052284, 0.14672679766531915, 0.09876433098989149, 0.189343671344461], [0.1312932975950741, 0.051047031602431694, 0.035845365059832414, 0.07583449204121867, 0.04021430703540964, 0.0329621663437255, 0.025750771953514027, 0.08240664543043222, 0.024803737891958128, 0.053383239710162726, 0.026668143090641788, 0.027843184070661667, 0.04739584123355247, 0.026494961254478946, 0.0495954750165824, 0.12833371608247682, 0.9640965250230605, 81.82315995616298, 83.77066381515996, 85.9277085335024, 58.50638335750949, 54.78053569793702, 33.12724021173293, 49.977142349366225, 46.87379444799116, 30.857692110923033, 2.1029280222231344, 0.205919623014427, 1.023651771247387, 2.7010941313159083, 2.6576600103609027, 3.0365197841198217, 0.327682250569905, 1.6946508398940487, 27.086350840906945, 120.22020647602697, 90.78725845583024, 91.87613979462655, 76.89780835182437, 93.19509952299057, 97.60906034900297, 100.4234629292642, 94.05272576116747, 91.78793353419151, 84.71151490365305, 82.7224966787523, 73.96047084562241, 71.84189673393004, 64.04369138902234, 62.412020698670425, 63.5034711899296, 64.10619828008836, 60.438178123966345, 59.60112471734325, 60.64463992272655, 62.81831941296978, 59.77072015885384, 61.90536422114219, 62.077870061320645, 62.276098805089156, 57.33481061074042, 56.32168592945222, 54.595972491848855, 58.3168387413025, 56.21286369139149, 60.937884161549235, 65.25565670382592, 60.93149462053853, 64.14309209392917, 64.83445690524194, 69.14978581090128, 63.990096122987815, 61.47126374706146, 60.81129750897808, 58.89077955676664, 67.6610972804408, 73.09926740584835, 72.43825389492896, 80.05726968088459, 72.12499772348713, 75.84484807906613, 76.70656142696258, 71.33823302484328, 78.26541331506546, 75.90915926041143, 70.25526662026682, 59.82383689572735, 62.4089063367536, 49.73874069029286, 74.07973443308185, 67.34900213056996, 65.85200602008452, 64.03422278742637, 68.93299641147738, 65.28558046587052, 68.58432123737951, 62.73265092603622, 62.21012846116097, 58.31038251999886, 61.08285496311804, 58.16601184106643, 64.71908038662326, 68.11577058607533, 70.94368180921002, 62.09627382216915, 59.41335301245413, 73.54906912772887, 86.10835721415859, 69.73017892529889, 61.14723674712643, 57.39767051512196, 54.48020373621295, 54.172744827885786, 57.777387326763524, 54.10140083682153, 56.32366280401907, 56.31582590841479, 56.0298772781126, 55.676291296559, 56.701779288630334, 56.23682152840399, 57.061135076707416, 55.191035270690925, 57.87829422181653, 56.707250995020715, 57.97184275042627, 58.331280908276966, 63.85878301435902, 68.25798003904282, 70.65683887850854, 70.39979811637633, 70.870772792447, 62.257471469140825, 69.71022190586214, 73.36106208062941, 84.92874360853627, 73.43468496876379, 85.36285584972751, 16.698177014627767, 0.5220752533885741, 1.9305923148508997, 3.8196138797267793, 1.0778122875959644, 2.454256679742567, 0.10455503639194275, 0.0867477132968845, 0.2546219774071248, 23.33635118699843, 28.481947798882764, 75.83625024364841, 60.422559245940185, 15.728114074276341, 43.457480630567, 52.246845383797925, 64.98690766672935, 68.67885820327267, 60.036119491823264, 1.7980893797451452, 0.08461064208419093, 0.015537299238325608, 0.03656785875078171, 0.02755104410161655, 0.04421003012647552, 0.11887750212824154, 0.06876058170511838, 0.024556653468959758, 0.019954433889999505, 0.03900666518377201, 0.014219784098977764, 0.051219527789902304, 0.013197595854440044, 0.03808338367830842, 0.08393507510904344, 0.006851312477186683, 0.028878735761428555, 0.09580401403288688, 0.0651662044167038, 0.06243764820899214, 0.022797167841945926, 0.11239878082227324, 0.06165431947597574, 0.017008586418664744, 0.054416814894084974, 0.024495933340081287, 0.033430131152272224, 0.058735030357755964, 0.06031685636468953, 0.046703623337370735, 0.030542678732965744, 0.06316448944891173, 0.045668450860126365, 0.11319204954610718, 3.571282985710329, 99.75914678265973, 92.20532863370835, 96.80458222666095, 72.06399702256726, 69.47324014479115, 34.05285289210658, 40.75716018676758, 51.069667570052616, 34.02675344097999, 2.7815340988097654, 0.6753086502994261, 2.811142110055493, 4.004342560806583, 4.954171709475979, 3.788246685458768, 0.6460911600339798, 1.0917712675948297, 36.31628405663275, 121.35127682839672, 95.29850975159677, 96.04110856210032, 79.20588785602202, 96.1598857756584, 99.97017814267068, 101.2037870960851, 96.22553056286228, 95.27574431511664, 88.9870160625827, 87.20181988131615, 75.95611787611439, 75.10748955511278, 68.12054018820486, 67.56020607486849, 65.61971933610978, 67.93376476533952, 64.39781081291937, 66.03165841871693, 63.78777634712958, 65.78987175418486, 64.42476534074353, 65.16094323127501, 64.54556649731052, 65.201096534729, 61.771136791475364, 61.05878337737053, 60.225934751572154, 60.80193481137676, 60.53848489638298, 63.486342199387096, 66.43246973714521, 63.88903625549809, 63.56231458725468, 65.06989325246504, 71.8027828585717, 67.76867220478674, 63.37913205546718, 63.18528459918115, 60.971436116003225, 69.3156942244499, 76.55503242246567, 75.65962591478902, 82.88482789070376, 73.89222160462411, 80.98287843888806, 79.34469269167992, 77.08092812568911, 80.30444175966325, 78.00047289940619, 74.50015760237171, 65.37313169048679, 62.93608857739357, 51.80336652263519, 76.565214895433, 70.0225131742416, 70.92144197033298, 67.13344435538015, 72.71138421950802, 69.6424747282459, 71.48118772814351, 67.44497468394619, 65.5160040240134, 61.13083339506581, 63.52882539072345, 61.62522462106521, 66.70097950966128, 72.6247625966226, 74.6333848276446, 63.57727842946207, 62.35855879322175, 75.64538771106352, 86.76491491256222, 74.67554246225666, 64.86859329285161, 60.34815972851169, 57.767291145939986, 56.33492000641362, 58.567129104368156, 57.87634872621106, 58.84738245318013, 57.95123461754092, 58.80488357236309, 58.20065029205815, 60.97063987485824, 59.04871379175494, 59.634555078321895, 59.65540639815792, 60.731112495545425, 60.124706222165024, 60.94041409031038, 59.93756601887365, 66.10743861044607, 68.9570640748547, 73.62886582651447, 71.59965899682814, 74.5925372646701, 65.93037497612738, 71.57906655342349, 74.89095118737991, 88.68464054599886, 75.5445671081543, 94.20758878031086, 34.973237053040535, 0.2621403030089794, 0.4857798461471835, 0.696787242927859, 5.911930174596849, 7.268719692384043, 1.5283477378468362, 0.33083028971187534, 0.17337024782694158, 26.72363946514745, 37.077333696426884, 55.23887641968266, 42.28327989578247, 17.590443664981475, 53.21178374751922, 59.05039256618869, 74.68267333122992, 73.50089457727248, 85.338191986084, 6.098879162342318, 0.24015983085959192, 0.010073417478481369, 0.055328440371780634, 0.033140645677884745, 0.02210654149342689, 0.07175132767447541, 0.030749242850429112, 0.05021047508043628, 0.03827145443327966, 0.04172371858130059, 0.03543408692724282, 0.05423294996181804, 0.0553845065165191, 0.05343887301522398, 0.01651315927325237, 0.08289032270230594, 0.05095057347188554, 0.07745662193384863, 0.26818004827345576, 0.173237775903075, 0.12497650429366097, 0.17734431361238803, 0.20771265180120546, 0.11030930665231521, 0.09659955037697669, 0.20075842738151553, 0.10043385108151745, 0.18399674535518695, 0.10828227630906528, 0.1598855068967227, 0.20772238111784383, 0.13095411982747818, 0.130984119830593, 0.31283448600480634, 4.151676835552339, 113.82444458623087, 106.09139765462568, 109.63275663314327, 82.47123749025407, 76.19516280389603, 45.72462627964635, 69.43793881324031, 61.631539637042636, 50.134550986751435, 4.227262869957955, 0.5636817337043825, 3.2928726605830656, 9.335623441203948, 10.479791568171594, 8.59013972743865, 4.082147185840915, 2.9577264766539297, 34.73990701859997, 129.82040359127907, 98.76350018285937, 101.50065560494701, 85.0487446015881, 100.47052352659165, 105.57627277989542, 101.07245829797561, 96.58796541152462, 99.07859202354186, 91.27802541179042, 92.28197959161575, 80.47282126642044, 79.47017715823266, 70.25574514942785, 71.72770084873324, 70.70489575785976, 72.3164878352996, 67.70437671292213, 67.07720541184949, 67.74792286657518, 69.24288718931138, 66.74911483641594, 68.49834288320234, 68.04795280579599, 69.57242904170867, 64.39747741145473, 64.69482837184783, 62.355095340359604, 64.44448309559976, 64.19336903479793, 67.99965273949408, 68.73870572736188, 65.89157489038283, 65.80138783301076, 68.25357129496913, 73.93157082219278, 69.21871754430956, 66.42733927695983, 66.65909644096129, 63.61235226354292, 73.84178776894846, 79.53227612280077, 80.54941731114542, 87.05112241929578, 77.51030214371221, 82.27105540613975, 81.34460726091939, 80.91381334489392, 83.3268633196431, 81.54077283797726, 78.10960108234038, 70.52738497334143, 64.5815150199398, 57.9975538869058, 80.50927577480194, 73.60822631466773, 72.92968765381845, 70.96338779695573, 77.00557939467892, 74.24332864822881, 76.0038060526694, 70.62043928330945, 69.93574250128962, 64.6503290822429, 68.48015877508348, 66.95150913730745, 69.80768495990385, 76.40088327469365, 77.82691586402156, 67.64123439788818, 65.43727813228485, 78.19462237819549, 89.00470595205985, 75.46600203360282, 69.07369182955834, 62.763578814844934, 60.47923357255998, 59.87682027201499, 62.9095184418463, 61.09100172596594, 62.6953923317694, 62.79995879819317, 61.5622195889873, 63.62341334742885, 63.41299387716479, 62.38714894940777, 63.403674325635365, 62.6599144935608, 65.49851809778522, 63.06466779401226, 64.87500244571318, 65.54923434411326, 69.32437835201141, 75.85670148172687, 78.28937115207796, 74.94821779189571, 79.13570096415859, 69.33855379781416, 77.09218532808366, 77.2254753112793, 94.76012522174467, 80.16410719963812, 98.60226723455615, 31.397849552093017, 1.1278986257891501, 9.547989387666027, 7.754230672313322, 4.478543631492123, 6.358412590719039, 1.5700496420744927, 0.44017962690803314, 0.6164450282531401, 39.01431775862171, 43.91232652048911, 101.37007205717026, 77.02338695526123, 22.841805027377223, 58.97119599003946, 69.05734339068013, 86.70676185238747, 83.7602146210209, 92.91146509109005, 4.854361607182411, 0.3097939443203711, 0.17834745978395786, 0.11659456011388572, 0.16185006276974756, 0.12938483467986509, 0.23330199562253492, 0.21947988489222145, 0.10746984772624509, 0.13905297153659407, 0.13871164872281014, 0.14395829380279587, 0.16397620190776166, 0.14475963709335174, 0.20796808083691906, 0.15780268236994743, 0.1273060704190885, 0.10470443885893592, 0.31081051235237434], [0.019234236547603242, 0.04354115492934662, 0.02947217428065356, 0.010386847988552144, 0.08954340561984048, 0.021565242918328415, 0.0762326585789842, 0.04061597842542876, 0.025046794607694593, 0.06295950347257238, 0.11116500388109878, 0.027357641374692324, 0.03615854180327827, 0.11658977972523821, 0.28692609720653106, 0.6217165711906649, 16.51570050947128, 93.81488892339891, 80.5783800924978, 71.18045960703205, 55.278982654694595, 47.88737020184917, 54.304638447300086, 59.09633528801703, 41.39087400128765, 16.77153318159042, 0.21875390933165628, 0.45452067027649573, 0.41043080870182286, 1.5357204454560436, 3.654677723684619, 1.0733510818212264, 2.120588739072123, 4.261936622281229, 101.29090293761223, 99.03662266269808, 93.68131652955087, 79.41608767355643, 74.97855340280842, 89.46065795037055, 94.74939361695321, 89.96833816651376, 92.63200406105288, 92.34872264246788, 88.89607198776739, 83.27493898330196, 73.86539259264546, 71.76486922848609, 61.823994651917495, 62.938128209883175, 60.25659591920915, 61.38139047930318, 62.376562472312685, 65.29517066094184, 60.33878918617003, 61.467055043866566, 61.130872618767526, 61.17830191889117, 59.742188838220414, 58.25275897979737, 55.87177438120688, 57.9706621170044, 55.75093400093817, 58.06150813256541, 60.122392023763354, 64.25871179949853, 65.19797825044202, 61.41326365932342, 61.368289762927645, 64.3710131799021, 65.8986508461737, 60.759177054128344, 62.24404127367082, 61.5011247511833, 61.18900214472125, 56.8300800169668, 69.35693402444163, 72.18872839404692, 73.42770314985707, 72.26643839190083, 70.45995943007931, 72.80568584319084, 73.36627098821825, 72.51744654870802, 69.74550754793229, 62.74331585053475, 70.07820298594814, 60.178226963166274, 50.83741226503926, 74.52715919863793, 67.22615349677302, 67.32815081073393, 64.78624313108384, 69.6871897482103, 68.56802771168371, 67.60865519123693, 59.2811377586857, 57.18608610091671, 57.15984152209375, 56.42010604181598, 56.223269739458644, 62.313577052085634, 66.97279976260278, 69.10251340558453, 61.61375168831118, 56.675746517796675, 72.62224443497198, 74.65601690353887, 82.31449957816832, 65.17530302847585, 57.570309715886275, 55.95668977306735, 54.30963946926979, 50.65123304244011, 55.50838247422249, 53.686574889767556, 55.18390047934748, 55.89778754018969, 55.84029343820388, 55.145006256718794, 53.2562045897207, 54.07764696305799, 56.37925847884148, 55.85984645351287, 55.83739088427637, 56.083084229500066, 55.70659552851031, 54.49656786457185, 54.69312175627678, 55.94080417386947, 58.374611331570534, 60.59938753804853, 59.197053909301765, 58.636500143235736, 66.14448147435343, 71.82377538373395, 85.66690229600476, 67.91492954377206, 92.6113567044658, 17.32805867348948, 0.6242886041441272, 3.954586804874482, 5.754677451425984, 1.1086475104093552, 1.4445529181149699, 0.4108226779968508, 0.14897908084094524, 6.697352442049212, 28.219957005593088, 35.00708318525745, 63.89122493805424, 33.57806174985824, 32.02746841215318, 43.72755542878182, 61.25367810649257, 64.25607596674274, 82.58358986146989, 37.61107021762479, 0.44299120023365945, 0.08239723787072205, 0.023735372740174496, 0.04376153544252438, 0.06327548026738149, 0.025655857490135298, 0.06877244074618624, 0.09276894221623098, 0.06480393675907005, 0.004965753196888874, 0.04175143564240106, 0.009291558676669675, 0.05366290776780056, 0.07641962233690486, 0.024088073874853795, 0.010227337949007992, 0.008008201003840735, 0.012281415026424634, 0.03608000629972066, 0.019310808950854887, 0.012706161942332985, 0.02008751485376589, 0.11550634753920379, 0.03898766620324985, 0.09933092195781008, 0.07025796950103776, 0.024960374144176324, 0.018117481452082435, 0.047825792759296396, 0.05305692455881546, 0.04251046023601967, 0.12380215279277294, 0.20397477092281466, 0.6942581721851904, 26.766354076323974, 107.38665842240857, 86.55055738264515, 85.76740126455985, 62.76356704773442, 65.54375087061237, 52.694776135106245, 46.47385389574113, 49.765099017850815, 18.79178524017334, 0.16935548745095733, 1.7247390963377494, 2.668929715310374, 4.138317242745431, 3.824609998733767, 0.3498099954618562, 1.2757060364369424, 8.134341191860939, 107.37277323199858, 102.56981526651691, 98.76095064224737, 82.62476690353887, 78.12649080830236, 92.46880208292316, 99.20126022831087, 93.7319621732158, 94.60249300925963, 95.80780598425096, 93.98549633641397, 88.25616082837506, 78.6652675751717, 75.06533976524108, 66.83054324119323, 66.54959955523091, 64.36783213769236, 65.27099317119968, 64.21464397061256, 66.18092029325425, 63.006824601081114, 65.07017958548762, 64.2854662864439, 63.848078866158765, 62.58817826547931, 60.717956865987475, 60.3677676570031, 60.528584834068056, 60.46503851490637, 60.13354332216325, 63.837453165361964, 66.30472598537322, 67.26411419530069, 63.156113932209635, 63.34467403350338, 65.62362209443124, 68.4111721284928, 62.55603444191718, 66.23939498778313, 64.52919452421128, 64.60682999703192, 61.1011371304912, 71.78716398054554, 73.31196185081237, 78.2095116953696, 76.30974308136972, 71.99056240820116, 77.79002205018075, 74.276088283908, 75.26075224722587, 74.86254538259199, 70.06616130951913, 72.1391417903285, 60.91437347473637, 54.49563826284101, 77.72721705898162, 70.97479404941683, 71.50098000803303, 68.78709993054791, 73.41813256663661, 71.34262607943627, 69.77296413913851, 63.01941933170442, 58.0911926300295, 59.916459744976414, 58.86180500830374, 59.891372265354285, 66.03809895053988, 69.8295953196864, 72.12047130830827, 63.120726308515, 59.0002921319777, 74.72088506144863, 74.61261979995236, 83.80179174484746, 68.04021789181617, 59.543293291522616, 59.68277277485017, 55.84501989426152, 54.091877322043146, 57.67943397645028, 56.882090645451704, 57.83861552515338, 57.95796932712678, 57.82116490025675, 56.32801271254017, 57.425833132959184, 57.00672003530688, 58.55143962367889, 59.74438928788709, 57.94853994923254, 59.37151308982604, 58.452693954590835, 56.534278392791755, 57.671930482310636, 57.96508058424919, 60.6764542671942, 62.59741152486494, 61.37416547344577, 61.62161996287685, 68.278015505883, 72.8297927302699, 89.61778025473319, 71.46888717528313, 97.75855756575062, 31.593403239404005, 0.3144068355041166, 0.1741507688477155, 1.5223150099477463, 6.718202290996429, 3.791446113778699, 0.9099480822201699, 0.34480875898753444, 7.249008311379341, 36.60401736536334, 39.65988105343234, 50.01218872685587, 29.611311920227546, 51.40632852431267, 55.08655509641094, 65.91697615961876, 70.973068206541, 88.2368706118676, 56.09477681498374, 0.5869378341782479, 0.03384561893800574, 0.05556533007972664, 0.03149964703967975, 0.030824064742773775, 0.04881369378117304, 0.036846917768519734, 0.05837670422249264, 0.03683174922761898, 0.0227015198493797, 0.032229778627234126, 0.04570964340781493, 0.05022033463202177, 0.062315625724412745, 0.046911937965741085, 0.02340657929439218, 0.022636768182799704, 0.04007312086140437, 0.15625333083012413, 0.12028586284648027, 0.15057925465366534, 0.09985574581209691, 0.21239968497426281, 0.11067499106209125, 0.2525925798521888, 0.16118060917623583, 0.10909067526940378, 0.20908469995183332, 0.29366178738494075, 0.22123465524806132, 0.20232394337654117, 0.32207378216328164, 0.42440933926451596, 0.9013754357734035, 30.214040971571404, 124.60197248766501, 101.61463183741417, 97.33830698074834, 74.52688463272588, 65.76089720572195, 74.15978216355848, 88.58410235374205, 60.83949542814686, 29.929943699990552, 0.44588097581459635, 1.9070728027051496, 2.404668114839062, 9.428808169980204, 9.471304109019618, 3.150333973669237, 5.105476158280527, 7.002229450210449, 111.93723540152274, 107.7534314124815, 101.943389215777, 86.73866641136908, 81.67758510958764, 98.63650952616047, 103.13673111700244, 98.82305745155581, 98.2307638660554, 100.74343419844105, 98.48396855015909, 89.85000025841498, 81.28554421086466, 81.1653470993042, 68.67561048076999, 71.7088342482044, 66.00745739475374, 71.37260867703345, 68.96075894755703, 71.90382311421057, 66.9508658685992, 68.71313187383836, 67.23783431514617, 66.93640016740369, 66.922044292573, 66.18128899605044, 64.0244992317692, 64.80711406277072, 62.984914241298554, 65.3424705228498, 67.68343910094231, 69.90352415269422, 68.64525133563627, 64.99125365288027, 65.24534479264291, 67.49360422934255, 71.88421126334899, 66.80058417781707, 69.72300883262389, 68.30491512052475, 67.39054003069478, 64.6574285722548, 75.91394455202165, 79.590052635439, 80.36216335911905, 79.24471932072794, 74.22650952492991, 77.52043754823747, 77.34367985879221, 79.34426123096098, 80.10003136050317, 74.2054150181432, 74.7552607136388, 61.11907020691903, 60.991263697224284, 83.06855955431539, 76.09605235438194, 75.35523429993661, 72.4721980864002, 76.30320056792229, 74.62947030221262, 75.90216959676435, 66.7092792449459, 63.42019142643098, 66.04169184161772, 62.750203532557336, 63.03959208150064, 69.37704793868527, 74.27469192012664, 77.64569451732021, 66.63203208677231, 62.13592898461127, 77.40963059086954, 77.68625182490196, 88.19860396846649, 69.89122359983384, 62.306838420129594, 62.65143432924825, 59.82524894898938, 56.34753827125796, 62.23456874970467, 58.21197417474563, 61.17182608573668, 60.79994224732923, 61.548640343450735, 59.97502465401927, 60.655716696093165, 60.34386081080283, 62.95466100015948, 62.56698962180846, 60.99725707884758, 63.70123709401777, 61.67557216459706, 59.98978061060752, 61.456790201125614, 62.18995178899458, 65.41185332882789, 67.50600676382741, 65.90396958012735, 65.32765180833879, 72.5050832379249, 79.44754508233841, 94.85314815275132, 75.67920638668922, 104.91346282343711, 27.37667291395126, 1.6700519405065046, 13.01818480414729, 11.464016226030166, 5.436795824958432, 3.6433761494774974, 1.6033646608552627, 0.4381505664317839, 11.460960699665932, 47.847573834080855, 47.7204341273154, 87.88699519249701, 47.96756698239235, 46.866761638272195, 60.525964690792954, 78.92281824542631, 82.02606416517689, 101.95565838967602, 57.63198898684595, 0.7676747681633119, 0.15176852954731834, 0.2303935581397626, 0.17443426734497472, 0.14657276802726332, 0.17198643256579677, 0.1729809525873392, 0.19186206282146517, 0.12457210180019179, 0.1742596759070312, 0.1407681811120241, 0.1016218466083369, 0.20929195737886816, 0.15708102754527525, 0.16481879137216077, 0.12157863621870357, 0.18612031043777544, 0.1354843501241938], [0.0475327258238629, 0.05431103730393995, 0.062450215881389964, 0.01922430613288476, 0.08159994718528564, 0.04939137770223522, 0.09406077330030742, 0.029226918892574408, 0.04458604140147086, 0.043067770048735604, 0.026697486173361543, 0.04937989021381063, 0.06744677921937359, 0.027115253070669792, 0.04586753412900914, 0.11564828830981448, 54.734259574644035, 89.25742426226216, 78.1458673169536, 63.207100822079575, 59.13866550691667, 32.37968940888682, 38.2517344720902, 51.76358584434756, 31.560184686414658, 2.7960417203364836, 0.0856659665042835, 0.5467236726995438, 3.177211279830625, 2.1734321357742434, 2.346449354963918, 2.092519767822758, 0.17398605994399519, 57.43332485998831, 106.2454055970715, 92.69406380191927, 90.18865769909274, 74.3433726218439, 72.49252380863314, 79.93307175174837, 91.60479022610573, 95.47097636807351, 91.91381023776148, 90.88261127471925, 88.5865185337682, 85.14157925882648, 75.0276065641834, 69.08573350598736, 63.45694011257541, 64.04380906012751, 60.718455006999356, 60.302185627721975, 57.997683325121486, 59.0943427239695, 61.43201258874709, 60.1551281252215, 59.90305308372744, 61.24655508225965, 60.27636466487762, 55.54184813653269, 56.7564885077938, 58.295089198697, 57.22878502261255, 58.22853834398332, 59.67796394901892, 64.14013070444908, 60.77572945625552, 63.05877639401344, 63.104573988145404, 66.41439545539119, 59.511651531342544, 62.717930270779526, 69.26608408651045, 69.47085534372638, 65.79316262275943, 60.86663430736911, 60.68607191885672, 69.16931136961907, 72.06666423428443, 75.45589800803893, 67.92615536720523, 64.65438873537126, 71.33465582324614, 65.9756548173966, 67.7925515943958, 71.72995228921214, 73.51379133039906, 63.29895880914504, 53.019281664202296, 76.45851073726531, 65.6286427282518, 68.68212161525604, 67.15815528746575, 69.16377298293575, 61.94300328531573, 59.62262322825771, 54.86388214172856, 56.389833188826046, 54.08639777091242, 54.52882151449881, 58.027920876779866, 61.379739161460634, 64.68632859568443, 65.99658458463608, 57.372559501278786, 54.35113814569289, 62.95906974423317, 69.36251163482666, 72.32205760094428, 75.41792162003057, 58.98026843224803, 57.35518340141543, 54.432590084691206, 54.20863843733265, 49.849496656848544, 55.87557123553369, 53.54188649885116, 55.35780660567745, 55.6393543366463, 56.3205837434338, 53.82561899000599, 56.55512579025761, 54.170375716301706, 54.823007122162856, 54.17341555318525, 55.20848981795773, 53.84146928787232, 56.53025796336513, 54.1107988357544, 55.4127590117916, 55.295954750430205, 58.69159767704626, 57.14716049932665, 60.420029317179036, 59.37593360101024, 63.89641815616239, 67.1360174302132, 84.08461816849248, 72.30002172531621, 90.74011941109934, 8.84534776210785, 0.5801779356214308, 13.175099222890793, 9.010122610676675, 1.675307058518933, 0.5114301552455272, 0.032066638288538785, 0.3862017459206043, 22.558970758991858, 26.94598686310553, 60.05924578635924, 49.03100390588084, 11.95368197656447, 24.425258021200857, 44.576925077746, 64.08260130113172, 68.36530393169772, 75.81909379651471, 14.49554160717995, 0.3580168502465371, 0.03598940108091601, 0.0823313849527509, 0.08944585964444185, 0.1114633185188136, 0.043351211089400515, 0.04535538136898991, 0.046946197417714906, 0.0537682410269495, 0.10183001568000163, 0.013322913474703749, 0.022128317542674563, 0.06393669075482795, 0.06710091350419868, 0.04468898446629605, 0.017865762197142167, 0.02073794456889793, 0.021754696462002975, 0.048157704182930534, 0.008660171992115436, 0.01362451846005335, 0.027512435185452624, 0.08855895965450233, 0.03121691271512499, 0.020666752018094547, 0.0422385526490548, 0.029754678778831038, 0.033744828580247785, 0.03436406511032293, 0.06779087527144341, 0.022528498891680952, 0.07311444323990615, 0.17802296026099115, 74.95471323690107, 96.42106071595224, 88.24342097005537, 70.99635924062422, 72.93575948284519, 48.42864944088844, 33.86288858229114, 54.95537927073818, 39.12902355194092, 3.0557599904075747, 0.049549157340680404, 2.2905940682657304, 3.4412637689421257, 2.9218024688382305, 2.3146757050868008, 0.29450218583787646, 0.49942558811556914, 70.03340167383995, 108.57334013908141, 95.9587387884817, 93.52955218284362, 78.9549110781762, 75.48651602960403, 83.0690537729571, 94.0340474344069, 97.11376697786393, 95.67068776776715, 92.79348804104714, 94.4870105866463, 86.92413176259687, 80.17247753758585, 72.13621570217994, 68.13161696157148, 64.14492384079965, 65.48913578833303, 63.40614149647375, 63.26581478118897, 64.77737072975405, 63.86302309651529, 62.78619520125851, 64.05438377011207, 65.69533086592152, 62.51145670490881, 59.93250223898119, 59.98481881233954, 60.75932610419489, 61.36630504362045, 61.17243405311339, 61.39596992923368, 66.68852206199401, 63.07685852050782, 62.32596389708981, 63.82467408334056, 66.52788531395697, 63.159679366696274, 65.40745635186472, 73.2483410066174, 73.40079569047498, 69.02987110999324, 64.35952848003757, 63.536834870615316, 72.96901333716609, 74.45885504445722, 77.8362746392527, 71.19793768851989, 68.7442990272276, 72.73739737849083, 69.70983751358526, 72.10114186809909, 74.58855213657503, 78.43957439545663, 64.84332146183138, 55.70926666259766, 78.16311790097144, 68.19372377087994, 71.85574270063832, 69.14375320557626, 70.55324123751733, 67.09092586271225, 62.871169428671564, 57.891410627672755, 60.10976983654884, 57.14206534047281, 58.570216009693766, 59.62280365728564, 64.81870466662993, 67.52681101522138, 69.12909923061248, 61.48452920298423, 55.873908150580625, 64.33238567844515, 70.4825444375315, 72.23371013518303, 77.21604593338506, 63.71561258069931, 60.367206758068455, 57.978648062675234, 56.36826015287831, 52.679463201953524, 57.452889642407825, 56.18476775384719, 56.150423480618386, 58.319858966335175, 58.66470198477469, 56.91754494943927, 60.283825012945364, 58.01279229502524, 57.48114639712919, 57.33384178530786, 58.941687999233125, 55.0272096357038, 58.5936874728049, 55.580228528668805, 58.41791822064308, 56.687996079844815, 62.52732269225582, 60.695258109800285, 63.09007298561835, 62.18664915330949, 65.54627295463317, 67.83765100663709, 87.251233900747, 74.32561212970366, 98.06688724025604, 19.331438656776182, 1.4062705852331654, 4.003169036680653, 5.6815703549692715, 8.23684988483306, 2.197684885994081, 0.16387671772991458, 0.10336068999623099, 32.629481630940596, 39.93511376842376, 61.29805972499233, 49.4093047418902, 17.38728254072128, 39.63384043785834, 51.87578132075649, 74.00962598862188, 73.6007502771193, 85.82228306801089, 29.721201042975153, 0.49005991809310456, 0.021188676229587967, 0.051052309948229985, 0.13380471767196733, 0.017770872631620978, 0.10747295804321767, 0.02443551773115272, 0.06943992549373258, 0.07736771743023589, 0.010214297217316926, 0.0642254331239289, 0.04436164658756987, 0.0249316803209724, 0.055414556315349, 0.05564991001700682, 0.018388613375023972, 0.05058851648843096, 0.10007762019672703, 0.1838473122446768, 0.14628119496328218, 0.07123823262630932, 0.15948622187058772, 0.28675685306229903, 0.12635389207712105, 0.1390282422183983, 0.10642890277649127, 0.19469070458604446, 0.09533074789590414, 0.13411239390411686, 0.20340452571549725, 0.09658354680023848, 0.13716790494659256, 0.28849155191452275, 90.19420393051641, 111.31931304931642, 101.75295814391106, 86.01111381284653, 81.32643884228122, 44.24038179459111, 57.71688084448538, 72.72762283202141, 50.85162693454374, 5.455799708443304, 0.1900573588547207, 3.94955734572103, 7.929283601622428, 6.961224502132786, 7.364206362155176, 6.46334138608748, 0.5474670844212656, 70.27068937978437, 111.6182525696293, 102.8105232792516, 96.59788900806059, 82.74533271789551, 80.35623273541852, 88.27040687684091, 100.52703703603437, 102.92808455805626, 99.17290933670537, 99.75690318692116, 97.33500434506325, 91.95992946624757, 84.27473545074463, 76.96354727591239, 72.10162039726012, 71.3841796690418, 67.98122544442454, 67.61152636620307, 66.2289144146827, 68.31439941160141, 67.23062499876946, 66.23639829697149, 66.83395570324313, 69.97058099316013, 67.15144018973074, 63.94565959130565, 63.75478529161023, 66.41280297310122, 65.54789289351433, 65.65092571320073, 65.34230186093238, 69.55577465795702, 63.88459613246303, 65.30226230621338, 65.63381633450909, 68.7317866663779, 66.23496270948841, 67.42819478434902, 75.26993059342908, 77.49454206035983, 72.61655699822211, 67.68536106232675, 67.28604808930429, 78.23890593744095, 77.4604723530431, 82.26174369935067, 73.72368520306003, 70.12632262322211, 75.3279032245759, 74.50838673499324, 76.43020691410189, 81.11725884099161, 82.24382631240353, 67.96751283830213, 59.88691253046836, 83.30452934388192, 71.83387940929782, 74.1629514386577, 72.87514317420222, 74.37905050093129, 69.2117827938449, 65.01912209295458, 60.95653895408877, 63.8310440125004, 60.7877750550547, 61.4732837677002, 64.95715256660216, 69.04404655579599, 71.27647138411, 73.50805682520713, 65.62599120601531, 58.2111700888603, 68.23817991441297, 72.80128494385751, 76.04272380951913, 80.23299970934468, 65.30463141779747, 63.523161488194624, 62.04850719821069, 60.39859356418733, 56.54022470597298, 62.668069101149044, 60.26781389790197, 59.87723996562343, 60.13157821470692, 61.934621180257494, 60.64852306919714, 63.103220770435954, 60.3215935153346, 61.71319946166008, 60.392521735160585, 61.91086338412378, 59.56466628659157, 63.78109262835596, 59.05539751052857, 62.26200180668985, 59.27001783924719, 66.29763434010168, 62.75064283801664, 68.25635617779147, 63.63254854756018, 70.42690169426703, 73.89942307626048, 93.1450814585532, 79.32235871591877, 102.15846061706544, 14.180825333441458, 2.259231531812299, 28.031628324139504, 14.074248652304373, 5.253351474961927, 2.104231474861022, 0.23189944185076222, 0.5597241847745834, 40.52256322676136, 42.01845715122838, 80.04580851524108, 69.67561091146162, 18.046193661228305, 40.650997315683675, 60.50178327868062, 85.78630708879041, 84.96214651292371, 100.58577060699464, 24.669366728874948, 0.5316935792084664, 0.1370810918630131, 0.16725787742724343, 0.220903889125874, 0.13053552938565133, 0.19487223678058196, 0.18506407437305297, 0.14842961193813434, 0.19177999948301624, 0.22770209207890496, 0.13951539752944825, 0.07756988037257426, 0.09029078567701002, 0.2228284552092514, 0.17555951260991637, 0.1435452804810578, 0.12493771726205466], [0.02987005353544749, 0.02646949649187586, 0.022912395126636953, 0.024081025865950414, 0.065864700403425, 0.05742051541024158, 0.01800258933085828, 0.07464520182580718, 0.04050821666755984, 0.06536088268002195, 0.0287851945106541, 0.07230284969292342, 0.17085003306067761, 0.030679542255858262, 0.23804953441985194, 5.634083199885584, 78.46996491955173, 74.2083489510321, 68.77080640485211, 61.917201934322236, 46.89602644212785, 34.69437614563973, 75.47809077847388, 36.254883273955315, 22.46036825641509, 0.07931024827543767, 0.24364003040377172, 1.4956328417024305, 2.4634926357576927, 1.1631744619338744, 2.632744379581944, 1.8943729035315977, 10.746326427305899, 108.1689202400946, 92.61054085146998, 96.76782177340601, 77.49651109018635, 73.42195295518445, 69.48327356769194, 69.2670254553518, 76.06047645691903, 84.08729322495, 84.25940682811122, 86.89862066699614, 83.91165733337402, 77.19101336694534, 66.04600644880726, 62.037257840556485, 62.681048224049235, 62.27498877433039, 59.18475727881155, 59.91283939730737, 61.39846455666327, 59.12509410612045, 62.7909295020565, 64.10428024107411, 60.10638090871996, 59.9076775581606, 56.247019690852014, 55.91961553019863, 55.413661156931234, 58.18086585690899, 59.62801256487447, 59.95768777785763, 61.088475719574966, 63.32746267318726, 61.854946074947236, 61.98928725334906, 63.53967858899025, 62.08700918382215, 54.31850402585922, 66.41765886737456, 68.78570356676656, 73.70126493515508, 71.64643718350318, 65.67422851439446, 59.80751591344034, 62.97081724289925, 74.81119371229603, 74.33058569508215, 72.10600560711276, 63.68779120906707, 70.97681799242574, 70.10876609433082, 75.0435156976023, 68.6880208599952, 73.89758740701984, 61.839542927280554, 49.60542325050601, 75.90614688011908, 66.13631509965467, 70.60826424629458, 64.66191576373193, 64.65185096186977, 58.45682028801211, 53.60066713825349, 51.37536533417241, 52.84836046157345, 51.489310187678186, 52.745888540821696, 55.07558814940914, 59.57042040363435, 63.91415903645178, 64.95551693824031, 55.213392780673125, 53.93594349584272, 58.962186305753654, 70.32007202025383, 69.57013837752804, 72.2947108361029, 69.7062603119881, 57.410339770778535, 55.539506481539824, 52.96727103571738, 51.28977137227213, 47.65936674610261, 54.49537938640964, 54.90270968406431, 55.82488636816702, 55.3036622078188, 54.33803742931735, 56.53404305058142, 55.955328710617565, 54.349584887104655, 54.817202014307824, 54.09283045799502, 55.99793349542926, 54.80525055239278, 56.81657529646351, 56.01775323190997, 62.668210306475245, 64.0476647500069, 66.65882971978957, 65.89254763818556, 64.6146119794538, 63.5218474941869, 64.1550592453249, 66.59168658717986, 78.5429916074199, 79.93977900474303, 75.01427835033786, 0.6923827889465517, 1.2248870730400085, 11.923890594513187, 3.3445638610470683, 0.6471342040646462, 0.0330071778397166, 0.20553909182067842, 7.433874520563311, 30.089038956549864, 26.64164427788027, 76.2869619554089, 80.91041657232469, 29.588409200791393, 34.716400254157286, 57.44895550512499, 62.36640745593656, 75.12761131409677, 64.26341472133514, 11.521545629347525, 0.16798251999482033, 0.09791336052360074, 0.04427079239018983, 0.05759167477428433, 0.08544347924931396, 0.04646802831801676, 0.02839610611479129, 0.03274077842492731, 0.04569159054587926, 0.05064929790434338, 0.029917137299273765, 0.031961973441103776, 0.059509219661835706, 0.12125013005589286, 0.02745629051670192, 0.05877897699153232, 0.022872225306327307, 0.03736954295046387, 0.02567194533654519, 0.005879596977930276, 0.01967758695114284, 0.06424334425959857, 0.03442622931493867, 0.04823770674486314, 0.055484166894588745, 0.03827014059248952, 0.02559738391409478, 0.11304923543526281, 0.14011034141144446, 0.20124219658394016, 0.38949739488382495, 11.950463671838085, 95.97813883135396, 80.9644276095975, 80.16338548352643, 72.82776094252064, 69.32222889315698, 30.955510139465336, 48.25166033160303, 42.15678345772528, 25.353792867352887, 0.04501032770701474, 0.3548318243795826, 3.8459398477308215, 5.495244043488657, 3.170004414935266, 3.693275562217159, 2.1437807333084846, 15.371958940259873, 114.42568117572416, 95.35878873640492, 99.04309457348239, 82.39410800318565, 76.56504231114542, 72.110790898723, 72.80752151243149, 79.05027958654588, 88.3191619380828, 88.16789181001725, 90.14187166767736, 87.17623818305232, 79.4971630650182, 68.05621331737888, 64.21317308179795, 65.64115116673132, 66.2727508237285, 64.04248329900926, 64.03704689395043, 63.607131588843565, 62.76185297196912, 64.67688352830949, 67.29794071566674, 62.79917040178853, 61.75039137563398, 59.129063544734834, 57.71257015966601, 58.938369674067346, 59.41897376891106, 62.622887319134136, 63.157063145791334, 65.71845323808732, 66.08162156997189, 62.457355453122055, 62.67589030727264, 64.69936263176703, 63.50826824865034, 56.19680550790603, 69.72531518628521, 72.68617122404038, 75.54186851747575, 73.54064387659874, 69.71315583875104, 64.26337157526325, 68.90174296594435, 77.35177563082787, 76.75126860218664, 77.9513648248488, 68.01928027983635, 73.81356239318848, 72.96436925088206, 77.4956246345274, 72.56838244776573, 79.07982287868377, 64.83224468846475, 52.69378769782282, 79.3960286724952, 69.77813382302561, 72.48577733193675, 67.30396547625142, 68.0253521088631, 61.70149118669572, 54.44727543861636, 54.407596741953206, 55.9754857709331, 55.417203057196836, 57.87335595776958, 58.16144227981568, 63.71281200839628, 66.41393261571085, 67.90366449663716, 58.57110246535271, 56.852068824152795, 61.97033043830626, 72.48154117215064, 72.55483458119055, 73.66790125446936, 73.38039152083859, 59.52030820231284, 58.37271290440714, 56.38563625274166, 54.425780850072066, 50.60801244551136, 57.42541736172092, 58.17540591762912, 58.768107429627456, 55.919227215551565, 57.576420768614746, 56.474411256851695, 59.82792792781707, 58.62304641354469, 58.67183285374796, 57.492364375822014, 57.78873866604221, 57.369025445753536, 59.52242235983572, 59.08627833089521, 67.01899743849232, 67.67950888602965, 70.75124248381584, 68.26204361454134, 68.89016412919568, 66.51181144099083, 68.34890842437744, 67.57754295103013, 84.70003804852887, 80.28421801905479, 86.43986025164205, 2.4868898189836934, 1.225226358059914, 0.8959627487967092, 6.037691658543003, 5.541973690832815, 0.5651098441693091, 0.2810910199919055, 4.6080078328809435, 41.865096399861, 34.00158751395441, 74.07279968261719, 60.5394890231471, 35.43481765254852, 44.67488627279959, 63.905502365481475, 69.62891117219003, 80.39976319959088, 80.25690263317478, 24.0331425974446, 0.44745023031869247, 0.042892581062211145, 0.05183871452426238, 0.04641306533988926, 0.057309719944192525, 0.06359073310910214, 0.049558499782917, 0.05774063291028143, 0.0405745713731214, 0.019500055650789893, 0.015924117141102832, 0.11821865885248108, 0.04669320454160052, 0.026343446300034563, 0.003853900824680985, 0.013562630047090353, 0.11292072418596476, 0.14131260915629326, 0.0651192432269454, 0.14895427491395705, 0.2347453359153963, 0.12079379446203671, 0.2361727109359157, 0.23448627562292162, 0.10526913758968154, 0.16126535382241974, 0.17473829699860466, 0.239063068743675, 0.37468888466396644, 0.25996841310012725, 0.632312486488973, 13.601861922971665, 110.22746639866983, 94.44093842660227, 93.6730952416697, 82.8528448843187, 65.16080594831898, 46.80160322496968, 105.88867387463971, 54.55178699185772, 37.68368897899505, 0.1420869248648805, 0.770321571298184, 4.029461419390095, 11.06790881003103, 5.349022986427431, 10.24729601798519, 3.2034225185071272, 14.603373446772176, 119.15947206558721, 104.34857091596051, 105.7736542917067, 85.68540803847775, 82.76146934878442, 76.4532704507151, 77.1904799246019, 84.17545241694297, 94.32437342982139, 92.90296139255648, 94.73159390111124, 93.70132061742967, 87.45586395263673, 70.88020217034125, 68.61700242565524, 69.60324318178239, 70.79682042521816, 67.6399164815103, 66.70443904015326, 68.38839100253198, 66.4647900673651, 71.66931244634813, 70.26482151400658, 64.98749209988502, 65.28869090541717, 63.288721422995295, 60.798930275824766, 62.75776586224956, 64.45045294300203, 66.9291437825849, 67.64949490947109, 66.89946712986116, 67.1764099982477, 63.91604961887483, 64.2604886331866, 65.80143097908267, 67.01725590613582, 60.233014629733184, 73.25773116080993, 77.46816804332119, 80.1835778451735, 77.68523200865715, 72.93668516220586, 67.16155990477532, 70.56228622313469, 82.491084683326, 81.82170083445888, 80.39547212662237, 69.0988185328822, 75.42203226397115, 76.45416475111439, 81.76121004166143, 79.54774595076039, 80.65629405360069, 67.57824897766113, 56.14082544080673, 83.07755747149068, 73.9723164035428, 77.19925818904754, 70.58168626600697, 74.31016583596507, 65.84073312820928, 57.48056588634368, 58.7100249721158, 58.70930717837427, 57.47447836783625, 61.21161068639448, 61.54024647128198, 67.75749344979563, 70.55140556827669, 72.13811412934335, 62.80749759366436, 59.72919402583953, 64.88922888232817, 76.20339193651753, 76.63085968263688, 77.32264026518791, 74.20266151428223, 60.46393240651777, 62.02835013789516, 61.542203733997965, 57.951685690110736, 52.99672411334131, 60.42716410852248, 61.825120372156945, 63.30972571526805, 59.88105250943092, 59.90003285869476, 60.75550963801723, 62.76187650619015, 60.8741731028403, 62.304092761008974, 60.197976096983886, 61.65476006846274, 61.57879944770568, 63.12657064007175, 61.55699891428794, 70.85691113625803, 70.15077467887633, 73.35099727876725, 71.76110375312068, 71.56103149537118, 69.92551295988022, 71.37063964720696, 73.04261269107943, 87.65669715019965, 89.89086351087018, 86.65557492163875, 1.2752270169796482, 4.488766308753721, 26.74401225582246, 7.234651946252392, 3.272089246780642, 0.7970612880683715, 0.535636664398255, 10.543538908804617, 50.02442259942332, 39.33328882340462, 98.04278035317698, 101.96483673587923, 42.93232625530612, 50.49098068667997, 77.00034695286905, 80.23629450028943, 92.91363023942517, 93.4554978339903, 19.91939410086601, 0.3949459347753756, 0.23923991248011592, 0.17430908857814728, 0.1325078533902284, 0.16297069618538504, 0.17755357818978448, 0.11017540214403022, 0.12592191041837777, 0.20366760030869516, 0.17138733648725096, 0.17564243396684048, 0.2405200300798301, 0.1684463402676967, 0.23097068281664004, 0.11614673575686833, 0.12642582773321098], [0.04633210133761168, 0.0368009869670195, 0.10357963792499035, 0.03182176402920196, 0.043958236177962635, 0.05388692719861866, 0.03004856159790389, 0.053551353874706456, 0.025570599565042124, 0.10078958400915708, 0.0175071066440714, 0.11944255325943233, 0.11845673599670972, 0.1916580382854708, 0.19910608298115193, 39.23300950757919, 89.8878981990199, 74.24262262159779, 70.42525429879466, 47.7966457797635, 25.613483190536503, 50.984418776727495, 50.026889770261704, 35.37203619557042, 6.535257552900623, 0.25704758031474007, 0.36873389936743245, 2.1833809825681874, 2.145624492437609, 2.1243561756226326, 0.4196875103779378, 0.4035226261663822, 53.74544574368385, 102.86455000600508, 91.55734523650139, 86.84266413411787, 72.21037203265776, 70.99621803529801, 68.39029727443572, 65.80210954912248, 64.03485036665394, 61.559230742915986, 65.50899867088565, 66.51023464818155, 65.25289927759479, 61.19527401462678, 60.62475742832307, 60.48402278654037, 63.39951269088253, 57.4981890955279, 62.77210212522938, 57.941295331524266, 59.1866204046434, 60.214202942386756, 62.45908129599787, 61.418029339082786, 63.088653087615974, 54.25287100576586, 54.78397953894831, 54.131673689811464, 58.0116508853051, 57.498659779948575, 59.553103139323575, 59.72554622157928, 61.57276684238065, 62.17290124585552, 62.65552928370815, 61.766053399732044, 66.80271010245046, 55.845847514367875, 56.20290087115381, 69.63630876233502, 72.86729058911725, 71.70956380905645, 74.73349155918245, 68.64682812844553, 64.12451967116326, 58.354709225316206, 65.2531110855841, 66.79757964226508, 72.77869209166496, 68.19484556874922, 70.9895892297068, 66.73116607050743, 69.46775667129025, 67.06284169227847, 77.61828499455606, 65.08848136471164, 51.38173134096208, 76.44300953034433, 66.57427126361479, 68.3084217194588, 61.14819380544848, 57.45338778341971, 55.3756102438896, 56.222234233733154, 59.99280868038055, 59.863668564827215, 60.731512577303, 57.88240094338694, 57.01973838190879, 57.26973064484135, 61.24646094537551, 57.73547287910216, 51.554633340527936, 53.787034634620916, 61.53387261975197, 67.40760234094435, 70.94157941879766, 66.60588556720366, 75.63155743383592, 64.42815819094258, 56.80248222043438, 52.62787226707705, 50.720188310069425, 51.10747529614357, 50.27563471947947, 53.8554564599068, 54.5669783315351, 53.75442012663811, 52.821625586478945, 54.36338770774103, 55.52744911563013, 53.55089618313698, 54.84612949432866, 55.02337748004545, 53.575877758764456, 58.07788402803483, 64.22752503425845, 63.128586738340324, 70.1867820370582, 66.56267673738542, 69.84751270663354, 69.89005473352248, 69.54014793519052, 63.88741239424675, 66.58515191847279, 62.8285881780809, 73.36387834241314, 74.61579691979193, 92.31605714367282, 39.32606773991739, 0.13686923790843258, 3.5735609021879013, 17.2815550527265, 2.0121694019725247, 0.5598634289157006, 0.017835601315563245, 2.046737127727078, 21.68786725690288, 22.084875837449108, 59.61709268631474, 88.37521260784519, 38.34257656528104, 22.62261513740786, 41.921535384270456, 55.8950222692182, 63.055187425305775, 65.54844202533846, 65.40864090765676, 11.3377002170009, 0.1257056054929572, 0.046648794424629984, 0.10206718884047963, 0.04391333193428094, 0.02354546720462461, 0.043811909553985444, 0.06191658967685315, 0.0016008743043658476, 0.05640613455926219, 0.0404197794775809, 0.01293441592415254, 0.04232150847993551, 0.05271628739372377, 0.04630649101830298, 0.01471931747566428, 0.04555866279969773, 0.07421276817518858, 0.059725436487145005, 0.025944387269837242, 0.02069052181116516, 0.03250343672510597, 0.02945701148541224, 0.08242418884389824, 0.053547048460572004, 0.05303440540428123, 0.004140061238074615, 0.10391709199475666, 0.09122755799082019, 0.06384709677208336, 0.047187312100563324, 57.92766509517547, 101.82310581207277, 80.72237814626386, 82.05770984772714, 66.3079031052128, 50.27320677234281, 45.68907391640448, 51.363064781312026, 43.97459414697463, 7.951751428265726, 0.7649080875900485, 2.534140160968227, 4.8072711017823995, 3.6513530246673094, 3.9129528066804333, 0.6385800050150964, 0.738383365734931, 58.78923723774572, 108.04297293386152, 92.93351665619882, 89.59808211172782, 75.92670794456237, 76.23285678125198, 71.4887971262778, 68.88448453718617, 66.00190331858974, 68.19508091095956, 68.75207316490912, 69.57093069630285, 66.13884110604563, 61.97202097985053, 64.26929043185326, 63.89095037214218, 66.75481011790615, 62.01734788956181, 64.56897128012874, 61.72063627550679, 61.44347767676077, 63.54377354345014, 65.52138159351965, 62.74805799607308, 63.934061142706106, 58.7986195471979, 58.46904631583922, 58.733006138955396, 62.08392227849653, 61.462654144533225, 60.484481703850534, 62.1457152981912, 62.619486624194735, 63.03757990560224, 61.07979159201346, 62.84600350164599, 66.06346099607407, 58.56692906348937, 58.30641308138448, 72.86780834197998, 75.81008803459906, 75.60694848337482, 80.19555676367976, 71.25554946161085, 66.99241945820471, 60.31100311586934, 67.7689624601795, 69.34723008063533, 75.76565542528706, 70.58713836054649, 70.95815535514586, 70.70961044680688, 73.00862143116613, 70.07769307782574, 80.01549643854942, 65.51467434052499, 54.60390744670745, 79.33752259900494, 69.21272416268626, 69.04896520799207, 64.22963526941115, 60.864112223348315, 58.31219857738864, 60.86437109977969, 61.72279357910157, 64.21963322547175, 65.39699146824499, 61.151394459509085, 57.35396746666201, 60.65315931074081, 64.18425344651746, 60.40793272756762, 55.14508862649241, 56.06845378875733, 63.596258778725904, 71.71081896751159, 73.62892073969688, 70.067000696736, 75.13133756576046, 66.15802149618825, 59.31759618943738, 55.806517908650065, 54.4955558930674, 54.694149417261926, 53.21332916136711, 55.84993462408743, 56.90680549990747, 56.99767897205969, 56.25305621854721, 58.64640805029101, 58.65592764269922, 58.04526167531168, 55.624845489378906, 57.92908499317785, 56.1819318802126, 61.800801677088586, 66.10040187835693, 67.1910325942501, 71.52907202320715, 71.02383936605146, 71.59128081414008, 75.04125641238305, 72.36638038389145, 70.28633963677191, 69.47637019618865, 67.7623571888093, 74.25508006926506, 79.90193597732052, 91.85790077332528, 51.89020387588009, 0.24160979015211909, 1.022284580094199, 5.000920968670999, 6.500272462444921, 4.1981049506895, 0.19019805856289404, 0.7479198733645102, 17.982896412572554, 32.53127724893632, 58.548219357767415, 81.39197380312028, 40.92536318686701, 33.937492062968595, 53.034437702548125, 68.76962184906006, 69.23021793365479, 74.66487361538795, 79.39095312549223, 22.500443112465646, 0.18008762850396096, 0.05761918499164524, 0.0789301154474097, 0.01691698145511891, 0.017305788313669544, 0.024830937843709707, 0.0350556280013294, 0.018202206946068236, 0.034459393261180776, 0.060550065020159374, 0.04719358253022356, 0.12156015817796993, 0.11813882482989181, 0.05591886050458397, 0.007530231087002904, 0.14029337513831355, 0.22595820017158988, 0.19600154231152228, 0.1096919010723791, 0.1302496713375853, 0.20943434248047493, 0.12415556447400201, 0.22116454288123116, 0.12036397317123991, 0.3414495553701155, 0.20597603772917103, 0.2629064522202938, 0.257803080903907, 0.28720562736834254, 0.25841521579892407, 68.2553755852484, 116.46156387944376, 96.03287158473846, 92.29230326990928, 70.88334791121945, 38.00651965602752, 73.97426974388861, 76.85130473106139, 54.24312783825783, 12.396845086928337, 0.7058747004597419, 1.9741752407243176, 6.313509787282636, 7.417342710879542, 6.866385513736356, 4.651492209203782, 1.5619745850563052, 61.758051764580514, 111.44202047778715, 103.09811930502616, 93.5475480171942, 82.51647810782157, 80.74473565624606, 75.78813845111479, 70.85720139165079, 70.2237464535621, 70.36014295393421, 73.00994719228437, 73.94267897452079, 72.13718844998267, 65.8814630200786, 68.79226176969468, 66.78460444173506, 70.93466820255404, 65.80359220504761, 69.4254421418713, 66.00789670021304, 66.17992401123047, 66.30329039789015, 69.22373817813012, 65.65829192438434, 70.00059496971869, 59.83494112568518, 65.68003362224948, 62.442521049130356, 66.37758793369417, 65.01041050880187, 63.9991097296438, 66.30230980534708, 65.54628472174367, 65.8746773196805, 64.87761082187777, 63.07811760133313, 70.79437286623063, 61.42193994214458, 60.092366280094275, 77.70808373728107, 80.13741939298569, 79.67556814993583, 80.79639327141547, 75.38055712176909, 71.17142246615502, 63.71453392890192, 71.31256503443565, 74.30818111665788, 79.78087594432216, 73.41109583454748, 75.82612268386349, 75.5946949989565, 77.28130632831206, 74.47535253340199, 83.77946561382663, 70.30430409216112, 59.09056155912338, 83.78119145670246, 72.1383180925923, 74.45404621862596, 67.99215316772461, 62.886431371012044, 62.137466553718816, 64.53452110290527, 64.11961670844786, 65.21759402367377, 69.03291486924695, 62.94584351201212, 60.986588231978885, 63.38389381285637, 69.12038372408959, 63.33157723949802, 58.98546949509652, 58.56553662207819, 67.28843289036905, 75.04458258228918, 75.46203259498843, 71.58202402053341, 79.04138365099507, 70.5729393805227, 61.82927023979926, 57.79388089333811, 57.72863226552164, 58.086968237353915, 55.98300103218325, 59.15902260811099, 59.983367535375784, 59.220729335661865, 57.67817489562496, 59.61479809976394, 64.04798638436102, 60.56952653392669, 58.76942142363518, 61.237059024072465, 58.83720782495315, 66.04913650020477, 69.51744525663315, 70.55273917413527, 76.54592467892554, 74.45385010011735, 74.81887371309342, 77.71348876337852, 75.77873260744157, 72.76306536889845, 73.72007662250151, 68.7037181854248, 80.36286938575007, 83.07897736949306, 99.45081710815431, 49.64685524663618, 0.5296696974865852, 10.41712680170613, 28.762971893433605, 5.1066808162197, 2.5498176293988384, 0.18443251148827616, 4.349584435262988, 31.87318786498039, 40.863829043603715, 76.40275816763602, 107.44008894889586, 50.44317876138995, 33.512844501003144, 60.18766026343069, 78.12671046103202, 82.32873778189384, 85.54579519456433, 91.15295671647596, 18.660748658641694, 0.2959653524862182, 0.1746411570498059, 0.2470038152269779, 0.22455662699236026, 0.11087535369780757, 0.09435076822316456, 0.16936670297816878, 0.09505348535434854, 0.1021756592296785, 0.20489729400123322, 0.1703409982785102, 0.26094977173113054, 0.3517263490826853, 0.1567266199497446, 0.09911205063784316], [0.049502311064110655, 0.01905059761127397, 0.020606324917847113, 0.08791669452142331, 0.03011187110396643, 0.08116147676182371, 0.08269413524577696, 0.049406576886652946, 0.01586455284738012, 0.04926794561587515, 0.06425021606827937, 0.042318608837142106, 0.11748922057449819, 0.36063840312342493, 3.3073393423711104, 77.13684543486565, 73.83738686961513, 75.19925732766428, 58.60887881248229, 36.57712951783211, 23.671268647716893, 44.981807816413145, 39.51576532856111, 28.319677383668964, 0.432440392192333, 0.09290614856346961, 0.7164802991094128, 4.711474074471382, 0.3553827028841742, 1.6147341410959921, 1.3941005737550798, 0.8754039519736845, 82.93020186885711, 95.23214324828118, 90.73897407900904, 79.62507155633743, 76.86777868578511, 70.69046143562564, 69.58617302679247, 64.61917761833438, 62.710834703137806, 61.0215247831037, 60.347575295356016, 61.284049018736816, 59.23516365789599, 61.18069848706646, 61.47177365518386, 61.32686168916764, 61.28099349237258, 61.83727187495079, 58.77318297663043, 59.0233870475523, 60.843445254910385, 60.94999644064135, 60.23681540643016, 59.66546335527974, 58.52634822168658, 55.95286938451952, 54.58628031515307, 55.92699350849275, 56.831727412439164, 56.07181133762483, 60.0344564068702, 60.323813576852125, 61.89010620117188, 60.099497149067545, 59.693476923050426, 64.03547794588151, 56.99767897205969, 55.44875068049277, 60.823570605247255, 68.24001558365362, 71.36398730739471, 67.73006039281046, 74.02148723602295, 71.89337392007151, 67.19427247201243, 61.27976971287882, 57.89816102673931, 63.069578601468, 65.9655664813134, 66.36163173183319, 64.96317340481666, 62.578270358424035, 65.85659519318612, 65.98223655454575, 74.19751536461615, 60.23350492600472, 47.770059954735544, 77.5345031676754, 65.03454093010195, 64.35696717231505, 52.4434071202432, 58.47272157669068, 57.963135088643725, 65.68796857710808, 65.23333841754545, 67.57453057073778, 65.76453324287169, 62.09568546664331, 56.14811712695707, 55.62747347739435, 57.38970025893181, 54.614956763482866, 51.946101573205766, 56.00278154496224, 62.27158415702082, 71.78019000637916, 68.18786374984249, 70.07567697955717, 69.16482417814194, 72.2273245165425, 55.227513313293464, 54.64546495868314, 52.993648975126206, 54.005534187439956, 49.27460270543253, 52.478520178025775, 54.60362503605505, 54.71820531352874, 54.06348720673592, 56.072089825907064, 52.24002830443844, 54.915394629201586, 52.319475912278705, 56.58429253485895, 59.021147374183904, 67.70328629401423, 65.90891961128482, 71.3441401143228, 70.50680821941745, 74.13034085304507, 72.65623569488525, 77.04323414833316, 73.98726063389933, 70.75458434320265, 71.67190121066186, 72.50434583233249, 68.55830023365637, 78.15051140323763, 72.63695332311815, 84.65194194547593, 7.48821895930075, 0.7796589573544841, 8.575621074245824, 9.789293600666909, 0.3838591716222225, 0.8379657866974032, 0.03427843563258648, 12.513907244128566, 30.353898963620587, 18.688952461365734, 48.32462426154844, 34.145597334830995, 27.252727977691162, 27.337476668819306, 37.387644167869325, 48.44262092344223, 65.60943488151797, 66.12695632442352, 58.889128238924094, 2.4387253196008745, 0.05918604164053837, 0.013886464988782763, 0.06790162860265664, 0.04005763822445466, 0.10078275816575175, 0.044594315151053096, 0.03158008052606977, 0.05281038597346314, 0.03803346921960193, 0.033895943253751726, 0.043451331120224736, 0.036136198848966634, 0.09748366946775107, 0.02503779498980411, 0.060146888267369046, 0.04429929469141268, 0.07217957848502744, 0.04134561205583234, 0.06386868512978958, 0.008591405067202306, 0.06452479730209996, 0.03761811166881554, 0.05223036165379229, 0.04628878672637286, 0.010646692563539312, 0.0043901314887578695, 0.07292331962455666, 0.07290546977592093, 6.778555310541584, 94.36068673287669, 80.9511935326361, 85.80362043073102, 66.80823279965308, 51.903975317555094, 27.23883298135573, 30.262001752853397, 45.1217266052, 33.79426671612647, 0.35680551202066485, 0.339784907597688, 4.829818846717958, 7.146168178127659, 9.24968921369122, 3.5491331161991244, 1.638588157873, 2.4885573166031993, 91.19578899875765, 100.1749493998866, 94.31774462423017, 84.38216916976437, 80.09379479192918, 73.94622479715656, 70.6159128681306, 69.52319545130577, 66.67993991605698, 64.47178671436926, 64.71014522737073, 65.3583247430863, 62.95707325781546, 64.25948450642248, 64.13403926357147, 64.95541103424566, 64.60855583990774, 65.27248759423533, 63.0313668712493, 61.513127203910585, 62.79488717356036, 64.98695473517141, 63.18514731622512, 62.16653131669568, 61.14103940225417, 59.73871361824774, 57.59170624517626, 57.88966909531624, 61.57322183732064, 59.42300204307803, 62.85211455437445, 64.82145817049089, 63.628328077254764, 60.51175786602882, 61.870600254304954, 66.92655501827117, 60.758106247071304, 57.492168257313395, 62.77533023588119, 69.89644035216301, 74.48863367880546, 72.78336755691036, 77.21163718931138, 75.10493216976043, 71.8831600681428, 63.56506416874548, 59.536538970085886, 64.95132000215592, 69.77389766323951, 68.90053487593129, 67.46846968127836, 65.26083815482356, 68.46401429945423, 68.64824802644792, 77.92925834655762, 62.54389862860403, 52.380731567259765, 80.26109172451882, 68.79070851110643, 66.90406414770311, 56.484205415171964, 59.76852755392752, 61.99634359728906, 68.7121355918146, 70.0948573696998, 70.05928931697723, 70.73914589420443, 64.29956720721337, 58.562802730068086, 58.5581821780051, 58.42645722050821, 58.90595520696333, 54.69854247185492, 59.4675366340145, 67.2001560272709, 73.28841978503813, 71.77358473500898, 73.36682796478271, 68.17732826355966, 74.51398003485896, 56.880753117222945, 56.736860967451534, 55.034897481241536, 54.71859755054597, 51.25807469890964, 54.10988884587442, 57.60627392799624, 58.2201248599637, 56.57229400450184, 57.33901931393532, 56.03253272271926, 58.052757324710974, 56.181441583941066, 59.528443198050226, 64.31184030348255, 71.2844887087422, 69.30988911659487, 72.9120683670044, 74.18809383146225, 75.87834512033771, 75.94612367691533, 78.65320236452165, 76.29861923956102, 77.06833731743598, 74.85572045849216, 75.66228528176585, 72.78645053986581, 80.10978237275155, 75.87479145296159, 89.63044166564943, 13.28142193055922, 0.6170230262702512, 4.221287629296703, 4.966381557526128, 6.1241887461754585, 2.3747573456456585, 0.04782849704966911, 5.153056959952078, 35.276044030343336, 25.41499557033662, 52.8350636266893, 31.85232673921893, 44.6031068986462, 48.199590867565526, 47.142504261386016, 55.85716355231501, 71.26795199609572, 72.66883434787874, 76.46823821529266, 7.522466644164055, 0.23266177594421372, 0.037993540716988426, 0.04898004977393055, 0.11830826049610493, 0.04728331057835491, 0.05174467340111733, 0.015931522338500908, 0.04454766039646441, 0.01752043657395388, 0.06031443169640918, 0.08216049371948166, 0.06189706975654249, 0.011582020801612207, 0.02743704064238456, 0.1475351583212614, 0.14992740576065358, 0.1546959966541298, 0.16976905235600087, 0.15126202285530108, 0.1616481526364242, 0.16045965915245397, 0.12905416048822865, 0.1267649825181692, 0.2499591372907162, 0.25015519451229806, 0.1468783758220173, 0.19467360550357451, 0.6828411332061214, 7.41757462101598, 110.8129507495511, 92.76995382001324, 97.36091552242156, 77.01193363435807, 51.07135811159688, 34.25870672349007, 62.97370802971625, 54.64644947359639, 46.3377711849828, 0.8216678483351585, 0.45212995501295217, 4.211457189052336, 12.076890487824718, 8.29959309870197, 7.580828080254217, 5.359436388938658, 2.036428771192028, 97.07459818932318, 104.0751503359887, 101.19650717704528, 86.22542427432153, 87.13072299957277, 77.9145259241904, 76.39499187469482, 72.81483281043269, 71.17266977986982, 67.24818152766075, 66.02679467970326, 69.54272101002356, 66.95896164063485, 68.12494893227854, 66.64867862578362, 68.82159325384325, 67.39683151245117, 68.88408445542859, 66.16858836143248, 64.25429913305467, 66.29221362452354, 67.88216990809288, 66.65551923936414, 66.05604771644839, 63.94235695562055, 63.58519769483998, 62.649367240167436, 62.539081958032426, 64.3199517649989, 63.15772994872063, 67.16026552261846, 66.36222008735903, 64.41985453328779, 63.07904720306397, 62.28408082838982, 69.98351696998843, 64.14595934652513, 60.8344747943263, 64.967460555415, 75.28190951193534, 76.40473504220286, 77.31823152111423, 79.87863709849697, 77.19549271368211, 76.74882888793945, 67.66094823037425, 63.8035285857416, 71.41154212336387, 74.3012934346353, 73.17309425723168, 74.26377988630726, 70.80296285690801, 72.5078602760069, 75.20856903445336, 80.77596556755805, 68.62352924962198, 56.43324205952307, 84.46406825896233, 72.34215582570722, 70.9383003173336, 60.261789137317294, 64.49911778972995, 65.95413669463127, 71.34998444587954, 71.5564815459713, 72.52605222886609, 73.07774928308302, 68.61135421260711, 63.752663289347005, 61.26316239756923, 62.125417032549464, 62.206068808032626, 57.44191877303585, 61.88237520956225, 70.61071180528211, 77.05448350598736, 76.13556631149785, 77.50441858845373, 72.56395801421135, 74.05938517662787, 59.99342841486777, 59.16231347668556, 59.117665137014086, 59.814599713971546, 55.62744602080315, 59.01905282851189, 59.52137508699971, 61.42061025865617, 59.17907768680204, 61.09517512782928, 58.92085629124796, 60.70289496452578, 59.18783633939682, 62.39595074807445, 67.30059223790323, 75.26392936706543, 73.9045927601476, 75.16035526029526, 77.73950976710167, 78.2367721680672, 79.7035111150434, 81.11711763566541, 82.40045439812445, 77.8988992014239, 78.28307182558122, 80.2907762219829, 75.82941747480824, 86.14760445010278, 78.80372724225445, 90.40257592355051, 12.263688464318554, 1.7632006325068015, 20.138442785509174, 18.49865278890056, 3.234470775050502, 2.3077230588082345, 0.22095633550517021, 16.712158303106985, 46.93312421921761, 33.83391403382824, 65.48701770843999, 46.13398052030995, 39.73315485062138, 44.30028030949254, 56.478192421697806, 67.40919482323432, 86.1116990735454, 83.71198515738212, 86.76244381935366, 6.220204935919854, 0.3825343604530058, 0.0718595146111423, 0.16706896014511588, 0.18163367054395138, 0.15493697727159148, 0.12618141504184854, 0.14018532609747303, 0.2258114636905732, 0.16956374079229372, 0.11361479218448363, 0.2533239486717409, 0.14891197153877828, 0.2601584029053488, 0.06655660037311815], [0.027713899072560094, 0.057879367602929, 0.11708926905186907, 0.03443422344242854, 0.01856519664157062, 0.018016030343489784, 0.07836917054749305, 0.09224266279488803, 0.05089732653070843, 0.04565045928522464, 0.09343189938414483, 0.14524602631647743, 0.21667404190426875, 0.5439612209316224, 37.27708039745208, 85.34378528594972, 78.91379679402998, 70.91090648405014, 52.31604383837793, 31.531541578231323, 65.41173565772273, 64.23872732347058, 44.95403743559315, 10.95396395652525, 0.12981436485725065, 0.49590924454312174, 5.676109925393136, 4.4134469955198234, 7.146764868690122, 14.58777516118942, 3.5395294379803444, 27.462141360006026, 101.12071914057579, 94.38444060664024, 86.82432313119212, 88.00946727875741, 78.38500638161936, 79.96809851738715, 73.7935112368676, 74.29677486419678, 65.50612749591951, 63.904094234589614, 57.39076714361868, 61.62238874743062, 60.28848871108025, 59.11198554500457, 59.34437421060378, 63.34204212311776, 61.579093625468595, 62.04218433749292, 59.015440325583185, 60.47655067136211, 58.161101033610684, 61.95577060022662, 59.00295542132471, 61.650763173257154, 56.73276209062146, 55.43026454987065, 56.38640503729544, 57.89249320184031, 61.00619223810012, 59.088925930761526, 57.24491380876111, 58.627392399695616, 62.445129425294944, 59.24987254604217, 67.97036832378757, 56.04861051805558, 58.24806782507128, 65.87524998572566, 67.47614968207576, 71.60721348178002, 74.0826605212304, 68.8723801028344, 70.48603534698486, 73.70994121797624, 71.8357386127595, 65.62854859136766, 59.23787793805523, 56.30221920628702, 60.62314925655242, 61.20830412833922, 63.92627523791406, 62.926078688713815, 61.92172442713092, 63.20641048492924, 74.58585354589647, 58.74563617091025, 49.36969664789016, 73.77105174526092, 63.01711690041327, 61.4651370048523, 55.75621351119011, 66.29027597365841, 64.8957400168142, 71.99468874162244, 67.27632061127694, 70.97635515274541, 67.07062367470034, 63.74805842676471, 53.56322811495874, 55.55603534944596, 54.07204974082209, 51.623898475400864, 50.50617202635735, 58.365354537963874, 66.77681461457284, 67.71645761305287, 66.89031231787898, 66.34908014728178, 58.74811510885916, 72.28417534982005, 60.68856262391614, 52.73458034761491, 53.72204488323581, 52.3576876424974, 52.10066649221605, 47.39572463497039, 54.1902974344069, 54.74121785932972, 52.720855974381976, 55.97456793631277, 54.04431858370381, 55.89503403632872, 53.8892202223501, 57.266110297172304, 65.73752380186512, 69.18525188199936, 75.08965846030944, 74.5223895965084, 73.35347621671616, 70.51429994644658, 73.40000337170017, 74.05449005865282, 73.44471054692423, 74.67504824361494, 77.83356035909345, 75.24769075455205, 75.2526564751902, 76.20377632879442, 78.16842094544442, 84.19894741427514, 42.876306964505105, 0.07760086096823215, 0.6950617677742436, 14.99004658191435, 6.528007541933368, 0.49639273795389366, 0.23979210865593728, 0.16116373992014318, 40.796991855867454, 37.105621830109634, 33.78420975900466, 55.517627500718646, 14.048848363660998, 15.23954168442757, 18.426465488249256, 31.719005377061908, 49.850281130883005, 61.3113526375063, 73.42849546863188, 32.28112613001178, 0.40331630336661495, 0.08458973554473731, 0.025197248530363845, 0.006219142467729868, 0.07216867705386493, 0.037416936979899486, 0.027692697589255633, 0.026316907099117676, 0.01724257456859754, 0.03517310758451781, 0.05166924438409267, 0.08343779977651374, 0.07501635610336259, 0.03220346733747471, 0.023850385520246722, 0.02431948796936101, 0.11699982062583009, 0.017223625383790464, 0.04470838564297846, 0.0175694604554484, 0.09755758163068565, 0.0615568807528865, 0.06309355353756298, 0.07687230369136219, 0.08802767001813458, 0.13938113295983884, 0.10755807041160523, 0.5479216503520166, 51.58373340483635, 97.72076160677018, 88.79736162001088, 80.88619201414048, 73.03144178082867, 42.738902414998705, 26.30070794013239, 53.463188063713815, 51.223848096786014, 14.551956076775829, 0.22357529900487394, 1.889779317763544, 8.08671675382122, 4.008471345709217, 18.783809100427938, 12.068299516554802, 2.8015153879119508, 30.225780625497144, 102.94043217935871, 97.90866667224516, 90.83987312932169, 92.0078137613112, 82.96052963502946, 84.13113747873615, 79.0149154970723, 78.3677165738998, 70.01772003789102, 68.47439289093018, 61.69021437245031, 65.73698251478135, 62.63174010861305, 63.644892246492454, 62.310847082445704, 65.13834253434213, 64.54354255430161, 66.35627377417781, 63.53421080497004, 63.66648489429105, 60.55737503113286, 65.67580138483356, 63.61364664569978, 63.73657372690017, 59.48850562495571, 56.619958646835826, 59.34968902218727, 62.2800878555544, 61.43372274214222, 60.574974706096036, 61.63292423371346, 59.43596547649753, 63.500556868891564, 60.23241842946699, 67.1753901820029, 58.89208570603402, 61.37170614734773, 69.37528287210773, 73.07767083567958, 79.116544108237, 76.18272104570943, 70.78933654292938, 73.13471778746575, 74.75307203108265, 72.17563552241172, 67.75794844473562, 63.30331264003631, 58.02663433936335, 61.47630791510306, 62.804508747593054, 65.75256609147596, 66.57713459384057, 63.24972521874213, 67.23822655216341, 77.41563181723319, 59.524254106706195, 53.32794866254253, 77.44717551815894, 67.43275257848924, 62.34045313250635, 59.75442271078787, 69.46014727315595, 71.3358796027399, 72.35538205792828, 70.83414569977792, 74.21669575475877, 69.0456311933456, 66.9156429844518, 55.110634526898785, 57.39936890140657, 55.71094543703141, 54.03676409875193, 53.01540636247205, 62.132367472494806, 68.90543783864668, 71.51797956035983, 71.95064836932768, 70.84803089018791, 60.06478025067238, 74.93366579855643, 63.43032683095625, 55.5874692240069, 55.719566806670166, 56.302850707884765, 54.628449716875636, 50.409901372848026, 55.89547334178802, 57.14924720025832, 57.573086753968276, 56.92320492959792, 55.84806757588541, 58.718403154803866, 55.56849279711324, 60.958833540639574, 69.0945823730961, 71.83547973632812, 75.20174411035354, 77.72123936683901, 75.40218507089924, 73.3928019000638, 75.57953111587032, 75.37999230046427, 76.39679616497409, 77.82158144058721, 78.85734604251, 78.65359460153888, 77.89175264296993, 80.08314947928153, 80.90654127059445, 85.37738430884578, 49.86234634153305, 0.9396111292223778, 0.4844586202694524, 3.1636634132554455, 7.586955312759646, 3.9464750982099965, 0.3608937555503461, 0.22743788367557913, 39.995777145508804, 47.518467364772675, 36.75619748330886, 48.18513301111037, 15.133592582518055, 21.71862844497927, 34.425819304681596, 45.46136856079102, 60.211386680603034, 66.60465394296955, 81.88437246507215, 50.05527988556893, 0.3139671623226135, 0.022837810721548817, 0.034234056159132914, 0.052527006219832174, 0.08228756472348206, 0.03621671852024813, 0.012991764308554272, 0.08046326422763449, 0.04256676386801466, 0.026408433538651275, 0.09074591851282506, 0.06596557886129426, 0.0720926428273801, 0.03380739881146339, 0.15497332048271933, 0.13480954923697058, 0.26530381712702017, 0.08704527716843352, 0.23631960063451724, 0.22394982406929617, 0.20065650704406923, 0.3908077729565482, 0.17219335291414492, 0.25322185979495127, 0.2040919517317126, 0.3627715902703424, 0.36630150892080804, 0.7122730668033324, 59.29635263258412, 111.1263402815788, 102.11466343172135, 91.33162067782496, 74.78856948114212, 46.81614737356863, 91.42673815450361, 88.42826658679594, 66.48982263380482, 19.2462133976721, 0.2901747083712009, 1.749866535106013, 15.870923649880195, 9.36701318910045, 12.480872061944778, 21.32866640244761, 4.948366601620951, 35.88017140665362, 106.13826213344451, 105.02831766682287, 92.86384751719814, 98.16826481972971, 86.4650026444466, 90.64530003455378, 81.49732082120835, 82.3432505515314, 74.12801096516272, 71.44041076783212, 63.734530172040394, 71.38891789220995, 64.67103527438256, 67.03130583609304, 64.52620567813997, 70.23028112226918, 69.27390529263404, 70.45788057388799, 67.46732434918805, 67.93084652193131, 64.78605877968573, 70.20193807540402, 66.33979981945407, 68.80646074971845, 62.94886765941497, 61.511307224150634, 62.08408701804377, 65.66258691972303, 66.00445285920175, 67.32305957425025, 63.75645622130364, 61.886732962823686, 65.82461218680105, 62.37637812091459, 71.16648812447825, 62.11499921737179, 64.4392506537899, 73.417936448128, 74.69209486438383, 81.19474134137555, 79.61552450733801, 75.25614738464355, 77.49522455276983, 78.20849972386515, 76.9126662900371, 71.34133169727941, 65.3433609008789, 62.46474519852669, 64.64450436253702, 67.43716132256293, 68.89889532519926, 69.75451330984794, 68.1954574584961, 70.85778974717664, 80.27986418816351, 64.86009743905836, 57.2125267982483, 81.1888813203381, 70.50680037467711, 66.67375826066541, 62.430361701596176, 73.58360167472594, 73.5696380369125, 78.83459629551058, 73.77314629093294, 75.09036448694046, 72.20118584171419, 69.47859025770619, 58.13163618887625, 62.62363256946687, 61.99517473097771, 57.75354716085619, 55.69646796872539, 64.15107411722984, 72.20451201162031, 72.94134493797057, 75.80178829931444, 73.70069226910992, 62.665841194891165, 75.71954404154133, 66.74646331417945, 57.01395288590462, 57.810896135145626, 58.33517582185807, 58.15083619086974, 54.93923871747909, 59.467203232549856, 60.24901397766606, 57.815673582015506, 61.75772228548604, 56.90695062760384, 61.74500203901722, 58.31719567698818, 63.797515592267445, 72.04131003349059, 75.35648945839175, 78.85201161907565, 82.69247485745339, 79.86341045748803, 77.4367263240199, 78.28453879202567, 81.58374632558515, 78.06832990338727, 81.57733717272359, 83.72817670145344, 80.19580779537078, 81.41535112934729, 83.36687149540072, 86.11642160723287, 89.40735293972878, 50.29292060482887, 1.0612487312286132, 4.595037045017365, 26.389535896239746, 11.77817258142656, 2.5297297008575934, 0.7872163227969601, 0.3754861370450066, 52.40608184568344, 54.94889951521351, 51.69034734849007, 72.2562559189335, 19.89441840879379, 22.04283195157205, 31.270980488869455, 52.94436439391106, 69.96919247411913, 80.23193282465782, 94.35201045005553, 57.10425761438186, 0.6245778176573016, 0.15827489896647393, 0.20013066429284312, 0.1858563012173099, 0.1768623676992232, 0.07769113676922937, 0.11145157439093437, 0.15726968435750854, 0.13255058577464474, 0.14237650610025854, 0.2617432549595833, 0.18864544348851328, 0.20775875497248866, 0.2510938820459189], [0.006442009893831827, 0.03854190262274877, 0.038428035144123344, 0.08620237360798544, 0.03308028944077031, 0.04447542596608401, 0.05141463506245806, 0.0283163218879171, 0.11307446271060936, 0.04414253394990679, 0.060884067863826795, 0.02240819052883214, 0.056871452534030524, 1.605440697843029, 73.74531315219018, 73.92807206799908, 71.84889424231746, 55.63102714477047, 32.76840806007385, 46.91306914052656, 88.58413373270344, 41.646769431329545, 34.26386071789649, 1.8467251764189814, 0.060125349705377897, 0.8333015982662478, 6.020035599508594, 3.160715016626543, 18.74773310076806, 0.42497881838390905, 2.7375018164034817, 62.696918133766424, 73.22628944150864, 101.8258357817127, 88.61688552364227, 88.00600774826543, 81.04407525831654, 82.67276886970767, 81.61410547071888, 79.36275128395327, 79.44077507142099, 78.14753040190666, 67.7496643989317, 64.48207116896107, 59.06297160733131, 60.77920075385802, 64.06296983841928, 62.713513681965495, 62.427780782022786, 66.50217809984761, 62.61889434629872, 58.85250506862518, 60.530169471617675, 60.712877396614324, 56.46381693501627, 60.68005892538256, 54.82180687689013, 55.18928589359407, 55.270192623138435, 57.788330739544286, 57.40388747184508, 55.287368682123, 58.50715606443344, 59.127718171765736, 59.675528157141905, 61.51393521216608, 57.71642192717522, 58.56981985030636, 70.43256559679585, 70.63379103137602, 73.10167574113416, 72.57356782113352, 68.86041687380883, 64.65404356679609, 66.8338772558397, 68.28977477165961, 70.13139032548474, 68.20796197460544, 66.04559852230933, 59.2679468277962, 58.158402442932136, 59.25580709211288, 62.042549117918945, 64.00821355081374, 66.10778377902123, 60.47506017069663, 75.93424674003356, 52.51045611596877, 43.65927480882214, 75.41068092469247, 58.54216714059153, 58.37433676565848, 62.63830223391133, 73.1264494311425, 67.9664537983556, 69.01664487777218, 66.92792784783148, 67.2149198285995, 60.10842054120956, 54.99808211480418, 48.9280338441172, 52.924121041451734, 50.97054143105784, 50.288802116147934, 52.79804037463281, 64.99924352092128, 65.30207795481529, 65.21012190849551, 67.03218444701164, 63.07705856138661, 55.27010633099464, 68.99205161679176, 66.76523577782416, 51.33636912991924, 58.369100401478434, 53.584401069148896, 55.140636736346835, 49.19804980677944, 51.49724122016661, 55.741194755800315, 54.58960256268902, 54.12074204414122, 53.72318237058578, 54.87646510524135, 55.85603390970538, 67.12880811383648, 68.35152072291221, 76.93110142984699, 71.8584805150186, 70.75893032935359, 71.32715625147667, 70.60154914855957, 73.90106262699251, 75.03334106937533, 72.3275096954838, 72.13156377115558, 76.72247840512183, 75.24208960994598, 77.21860331873741, 77.02927051051971, 76.6439760884931, 74.13868765677176, 72.87254656514814, 11.120083197470635, 1.7416818968711363, 2.583564231472631, 16.844987407807384, 2.318821405210803, 0.15546315710150427, 0.11095540222501564, 7.658583185365123, 59.23812504737609, 26.52227870879635, 37.42874668490502, 67.76704049879505, 33.1541359040045, 13.97956459752975, 16.766624335319765, 34.42946318657168, 58.85483103413736, 61.18891193020729, 65.05567858296057, 5.19093087603969, 0.17185419046830747, 0.04795170697053114, 0.020754752537956642, 0.014889052873777767, 0.03686477144759509, 0.06638172548264265, 0.06651602835664827, 0.06528539237596336, 0.012065861824779742, 0.05054078538030867, 0.037769011837700685, 0.02837112590280031, 0.031034610602223588, 0.03999086600097437, 0.021256758463418773, 0.09658803607547477, 0.06524666663139098, 0.03518631110989279, 0.028240167002584186, 0.04742210655803642, 0.052381468666416985, 0.057909264184174046, 0.03527180652224249, 0.05512525853250296, 0.03285671817138791, 0.06614183271003347, 2.623658699374045, 88.97666885006814, 82.27686051399478, 81.92998963017618, 66.55509087347215, 49.629981210154874, 45.86641211663523, 72.921505589639, 47.448919819247344, 47.71236188950078, 2.301428144977939, 0.08644862491036616, 2.5435474755302554, 6.133595080144945, 4.053601646615613, 4.950577837805595, 0.5662377707419858, 4.36262337430831, 75.98886182231288, 82.27153393530077, 105.97935907302364, 92.891296263664, 91.81165602899368, 85.64775328482352, 84.88507978377804, 83.89050006866455, 84.67702942509806, 85.20955393391272, 82.7238695083126, 73.64000535780384, 67.5334555102933, 62.716651578103345, 66.14062970684421, 66.90382880549278, 67.19058544405046, 66.93809463131812, 70.3458498370263, 65.08594751358032, 62.353899017457046, 62.92687100748863, 63.425678822302054, 59.21236292008431, 63.25089408505348, 58.35736074755269, 58.25966235130065, 59.353156397419596, 60.589130540047925, 61.52620046369491, 59.60343499337474, 60.96600755568474, 59.87464727893953, 61.23626670529766, 63.56873942959694, 59.354403711134395, 61.65353236659881, 72.77471480831024, 74.92946886247205, 77.79324623846239, 74.56409223618047, 70.3126822748492, 66.88989654664071, 70.92393659776258, 70.14960581256499, 74.06675138781148, 71.68863404181697, 68.35685514634656, 62.54704436948223, 60.56055999571278, 61.94537631926998, 67.54604631854643, 67.894988213816, 68.73995304107666, 63.46584389286657, 78.14977399764523, 56.802148818969734, 49.647502437714614, 76.54044120542466, 63.5906772459707, 59.254516632326194, 65.50215805730512, 73.2335772052888, 69.68673475327031, 70.51379003832417, 70.7026521621212, 70.57697157705985, 64.42269040692237, 57.75935226871122, 51.069989204406745, 55.64225689057381, 54.211952840128255, 53.11585826258506, 56.15068235704976, 68.51211824724751, 70.22609987566548, 69.67097466991794, 69.28681773524131, 65.19322433779317, 57.9092142658849, 68.22687564357635, 70.85830750003939, 55.27683711821034, 62.33877043570242, 57.844004861770145, 56.61974683884652, 54.417598785892615, 54.41583764168524, 56.592117663352724, 56.382259092023304, 55.67739740494759, 56.12258249713529, 57.0151178298458, 57.38303615200905, 70.7160980470719, 70.89064351973995, 79.26223662591751, 74.23363254916283, 72.65937359102311, 74.89593259749874, 72.45868944352674, 75.97862443616314, 74.65621302204748, 76.55177685522264, 74.77949311656337, 79.84342205908992, 76.84393067513743, 81.40614140418269, 80.57079422858455, 78.92461469096523, 72.3228342302384, 76.1928564502347, 16.025147322685488, 0.6533794753974485, 1.8418870553854974, 7.582584811795143, 6.893402799483269, 2.3745911352096067, 0.32078362881175937, 5.957611078216184, 66.21749247274091, 36.41926980787708, 37.5482181579836, 36.466271569651944, 21.463711646295366, 18.001545321556833, 30.494980735163537, 42.79623177743728, 69.69861953489243, 63.29021976840112, 81.71353755458709, 10.760465591184555, 0.3191482149545224, 0.08514031527503844, 0.01740544677651938, 0.0982279162253103, 0.042538426275695526, 0.08618548136925505, 0.04793589874621361, 0.05154465933540656, 0.024772736228882306, 0.05162523646328238, 0.03788505500603107, 0.019031788237513076, 0.0551558522537591, 0.1889822770270609, 0.1380894627542265, 0.22107953776515302, 0.31624029841153856, 0.12477271724492313, 0.14311858482899206, 0.20227578708962088, 0.10838189838273872, 0.1337958004085287, 0.14410427951764676, 0.09241552287412268, 0.26689112066261234, 0.26933058976165714, 2.8724276731091165, 102.92208333169262, 94.3834835483182, 92.61876998409149, 74.60326102472122, 48.93387033093361, 58.38588814581595, 114.82064031785535, 58.748091574638124, 54.622017029793035, 3.60148768751852, 0.10882662774454202, 2.93226906849492, 13.887948816822423, 11.824162371696966, 31.520062761922038, 1.2591101205156696, 4.056924629595972, 82.73271837542134, 90.85673932106265, 107.04587505709742, 96.318373064841, 99.63983612675821, 90.6792599155057, 91.23357711299774, 88.82987022399904, 86.55045540102067, 91.20699128796979, 87.8120465432444, 76.43132086723082, 72.44797352821597, 65.92102404563659, 71.27483183337797, 71.71008156191918, 71.04782073728501, 69.77388197375883, 74.91600728804066, 69.93896668957126, 65.26547831873741, 66.80891529206308, 68.08636849926364, 60.796898488075506, 66.83060599911597, 63.542181061160186, 63.290839502888346, 62.47213102156117, 63.59746294636881, 64.73705660912299, 62.970275955815474, 62.32595997471964, 62.77378089966313, 63.80107318201373, 64.8428782340019, 63.151426699853715, 63.88192892074586, 76.95798535500803, 77.56316000415434, 82.80390939404889, 78.22484816274336, 73.65791490001064, 67.82669974911597, 73.39808925505608, 74.35928960000315, 77.35275622337096, 74.23213420375701, 73.88567909117668, 67.69245270759829, 64.56758276108773, 65.37510464268347, 68.65902669968145, 70.6032749914354, 71.80386543273926, 67.86903781275596, 81.991649289285, 63.12347196763562, 56.083331338820926, 82.33171093848445, 67.02209611092844, 63.28658765362155, 70.68060844175278, 78.03346003255537, 73.58379779323455, 72.64457841073313, 74.86608336048742, 73.88669106268114, 68.16161524864935, 61.09226865153159, 53.7043785279797, 59.85713781849031, 56.90129456981536, 55.02943754196168, 57.58404193385955, 71.36272430419922, 74.43357144632648, 70.61756810834332, 73.0593925906766, 66.98753218497, 62.74545354227867, 69.23053956800892, 72.6384359790433, 58.21634369511759, 64.72892553575578, 60.05697473402947, 61.4713421944649, 55.936819045774406, 59.3674652038082, 59.49543253068001, 57.85443444405833, 59.58537247873122, 59.685632182705795, 59.799714319167606, 60.175555829078924, 73.60497859216505, 73.13784783886325, 82.06628414892381, 79.13614026961788, 74.84109001774942, 79.15085700250442, 76.07516181084418, 80.16759026435115, 78.4071050151702, 80.13185747208135, 78.15926613346224, 83.74934181090325, 81.19456875708796, 83.95337566252678, 84.5665676363053, 83.31704170473161, 74.40587166816958, 77.35816124946841, 14.178239510905359, 4.55719990115012, 8.107121413753879, 29.56377083255399, 5.642243691029088, 2.0720621558927723, 0.5681126636843528, 10.648174016706406, 75.08190785684894, 40.42682601559547, 55.853586350717855, 88.62851142883302, 48.71643374043126, 22.609685044134817, 29.893298956655688, 51.13173515565934, 83.35825797050231, 75.57735812279486, 96.26819026085639, 11.766935971475418, 0.5142397060990334, 0.2720498035271322, 0.10680928841353425, 0.1198816212314752, 0.09503771926486686, 0.17746495713870372, 0.2701648901547155, 0.30138281985156, 0.18504587212397208, 0.18179051938556856, 0.09332854646228014, 0.18817622995664998, 0.22788002366019836], [0.03834080837306477, 0.004739225306923712, 0.07377257405389702, 0.08444133665292494, 0.1137906629892607, 0.06305370930462115, 0.05185600895915301, 0.004313617020905499, 0.02458236337969861, 0.07736953305861644, 0.03347246900140759, 0.19312684334093527, 0.7365503931237806, 22.47746390681113, 98.30441813315116, 66.85870585903045, 71.21065401261853, 30.612822463435513, 52.37960976939048, 64.80739647342314, 59.699901765392674, 38.33120953652167, 17.838286469059607, 0.2657763708022333, 0.12022606968399017, 1.8567761274114734, 3.241752410127271, 2.3180928249512953, 6.323381902710085, 0.53005856371695, 49.97539297226937, 77.71368488188713, 72.73468309833159, 92.66282604586695, 90.77084725902927, 87.75336788546655, 86.33876508282077, 84.11487533200173, 81.72077040518485, 82.96124350640082, 83.15004287227508, 80.63728624774565, 79.3968366807507, 73.97167313483455, 67.05587556285244, 65.17332615390902, 67.15761400038197, 69.30310341619676, 74.7274354196364, 70.3705450796312, 68.45190202036213, 59.75681927896316, 57.4778006153722, 59.55093014624811, 58.71791285853232, 57.3830283072687, 54.33598602971723, 53.71913840693813, 56.41617582690332, 54.36673741186819, 56.40667976871614, 55.575090223743075, 60.77397615678849, 54.68321384922151, 60.82997583573865, 59.764542425832445, 52.22399757754419, 69.17033118586387, 76.68283108742007, 71.7979818774808, 70.11193536943006, 69.98426222032117, 68.69291597797026, 69.49761375304192, 73.76821979399651, 72.29888423796623, 72.46192932128906, 70.18700168978783, 67.67706132704213, 62.874621114423206, 60.51864947042158, 55.37048370607438, 64.37513559095322, 64.30227364263227, 68.49792711196407, 61.56039960922734, 75.77286474166378, 45.953269081731, 44.270768396316036, 70.19116724691084, 60.94825098591467, 60.02810608956122, 63.95787777439241, 69.00456397764145, 57.63944933491369, 71.38558387756348, 62.803900780216345, 64.27647229163878, 52.3650420865705, 51.43003532963415, 50.90134297647784, 51.03807287831461, 47.94486822620515, 51.46257923495386, 60.14419647955126, 66.26203490841773, 66.70491756931429, 64.1487285398668, 68.26339290988061, 62.030554509932, 56.22889441828574, 55.979431675326445, 70.1704885113624, 56.143292611645116, 53.15462696936823, 56.39996859335131, 54.25341621521981, 53.53923105424451, 45.511088525095296, 55.25254980210335, 55.07214038602768, 52.26454311801542, 54.020011655745975, 51.95199297320459, 57.58206113692253, 68.82485666582662, 74.92969635994204, 72.78317143840175, 67.5999318399737, 71.96276064841979, 72.77751538061327, 75.01406654234856, 72.35260501984628, 74.06801439100697, 71.89842593285346, 76.42898313460812, 72.19000708672309, 76.88889672679286, 75.61378909695533, 78.83429819537749, 74.16473219471594, 76.97421612278109, 75.29566134175947, 45.44916606718495, 0.9247193605669084, 0.10847627275413084, 9.027079016931596, 6.577112674713136, 0.0061927990980386255, 0.3138728722208931, 0.4867470474733461, 41.098300487764426, 65.27565686933457, 29.020416659693566, 56.365589018790956, 89.48653774876749, 79.89711146200858, 21.630755586008874, 25.675425260297715, 41.9281602674915, 56.57215672154581, 66.16302644052814, 31.734161415407737, 1.1138512698873397, 0.13383369111726362, 0.022115150406475992, 0.07487102156324733, 0.008298086280363702, 0.11355479983913322, 0.05305285663193753, 0.03930656179305046, 0.0934846368768523, 0.05795190080759987, 0.05397721832137435, 0.040220680886939655, 0.13466593839468496, 0.0401888499336858, 0.10064414221673243, 0.09713990283348868, 0.05142408858744368, 0.12322300564377539, 0.046950567949322924, 0.06971176413278427, 0.1201560952129864, 0.05535702694267516, 0.14455550530504796, 0.17612798049324946, 0.23581695502563832, 0.8407619463339929, 31.423466551688414, 111.01772200676703, 77.8572593196746, 80.45345260250954, 41.40845406439997, 61.33491039276124, 58.260529195108724, 61.52885983067175, 44.86899652788716, 23.826431728178456, 0.11646290790409812, 0.3017425134537682, 3.18993593896589, 3.4889303724611964, 3.1368545034239372, 2.3771063550826046, 0.18703357917406868, 61.179204064030806, 89.73303517987652, 84.47585105895996, 88.93256571985061, 96.10781238925074, 90.83059280149399, 92.15419661614203, 87.82808903724917, 87.63843459467735, 84.99980126657795, 87.38735583520706, 84.58861135667371, 83.0249192637782, 78.15989371268981, 71.73287837736069, 68.66805599581811, 68.73642290792158, 72.76602283600839, 76.63851614921325, 72.03587362843176, 71.93553155468356, 64.77154208767799, 60.316729776320926, 62.01714000394268, 62.60234586654171, 59.7496295744373, 58.5591039349956, 55.0424127424917, 59.142587877088985, 58.865437123083304, 60.768304409519324, 60.12507884733139, 62.860006363161155, 58.68016789036413, 60.177689598452666, 59.425151501932454, 57.27017779504099, 72.53097872580253, 78.61506123696604, 76.46685754099201, 72.81283240164481, 72.33027104408511, 71.96753809528967, 72.55749394816738, 72.5615418341852, 73.58775154236825, 71.90035573897823, 73.58576682306105, 72.5734736842494, 67.35592119155392, 62.3272269002853, 60.045231157733554, 66.60675633338191, 68.8203537848688, 66.94044020868117, 65.29233478730725, 76.00743816744897, 60.83281563174341, 62.46772227748748, 71.14701747894287, 65.32333327877906, 64.40825608468825, 67.92487667452905, 68.96574820241621, 59.00858794489215, 73.84435299904116, 68.53500919957315, 67.89460382153912, 56.163900744530466, 53.817487916638775, 55.6644182820474, 54.79739404493763, 50.89147037075412, 53.75791888083182, 61.691104750479425, 69.72981806724303, 69.61453960787865, 67.32353025867094, 70.99790465447211, 64.81500587155743, 58.597209761219645, 57.31950552232804, 74.6096387986214, 61.71965568296371, 55.69361640561012, 57.60829394863498, 57.10862713475382, 55.02722532518449, 49.18116792555779, 55.80228959360431, 56.471402798929525, 54.31287150229178, 58.1421559856784, 55.68168063317576, 61.59310433172411, 69.5797638739309, 77.5699378598121, 78.28111848523541, 70.4280548710977, 76.16119507820376, 73.46021175384521, 77.13829671182941, 76.75539493560791, 75.98441385453748, 73.94265544029975, 78.9815047479445, 77.57015751254174, 81.37939868434783, 79.46658426715483, 79.96238754641625, 76.5025197305987, 76.22033657566195, 78.29043019202449, 51.88497535644039, 2.4903797478445115, 0.9542351348265525, 3.2870432830625966, 4.670222997665405, 3.7629231281818885, 0.7116986234341899, 0.16298356646251294, 44.21632589832429, 75.26904413777014, 36.5047304091915, 49.008842514407256, 81.06615820238667, 62.63892196839856, 31.362469773138727, 40.6691578895815, 51.453349897938395, 65.88052165123725, 76.58929824829102, 44.955582849441036, 0.9365812208383315, 0.09340722369210375, 0.07069091643056563, 0.04997221790554543, 0.06034727005528347, 0.031639096109316714, 0.09773126908487852, 0.07396635599434376, 0.04346001472684645, 0.027042411515609394, 0.045046736035616174, 0.12440714008745649, 0.11128793801030806, 0.17488115707472449, 0.1649656044619699, 0.1530072783991214, 0.1840502336140602, 0.21846052830017385, 0.16412865340469346, 0.16066608920453057, 0.16983138126952035, 0.1990302096331312, 0.22910202582997663, 0.25648266707937567, 0.3792468320217825, 0.8093801044648694, 35.47544556279337, 127.6962754034227, 88.0265688127087, 93.44236573865338, 47.63752698898316, 65.06685733795166, 73.33428798183319, 72.43823036070793, 56.838520957577614, 32.15519059088923, 0.5026136783342208, 0.39278866182411876, 7.643955686400014, 10.494581845498855, 7.984733168155917, 12.783290724600516, 0.5982804706981105, 58.90974421654978, 91.46452626874371, 84.86412648231753, 92.99545088121968, 99.04920562621086, 93.65927280918245, 95.70986440104824, 91.73178872754498, 91.3035600416122, 88.7431936879312, 90.5924343293713, 88.04910675171884, 86.32107519334363, 82.28523869668284, 74.37094688415527, 72.93047212785291, 74.4692728596349, 76.02886215333017, 80.86502690469065, 75.71507253954488, 77.43952689632293, 68.8323405481154, 62.52250602168422, 66.32480067591514, 63.9141551140816, 62.53573617627544, 63.516756257703236, 58.29959992439517, 64.3351548717868, 62.54285135576802, 63.90893051701208, 64.81548047834828, 64.57439591807704, 59.241537509425996, 61.903901177067915, 63.292447674658995, 58.9473166004304, 77.45436130031463, 81.518595757023, 78.36812450039771, 74.87844667127057, 73.65947600333922, 72.23207058445101, 74.62014290594286, 76.19426850349673, 76.64903594601539, 76.24757351413851, 77.0463877339517, 74.86025471841135, 70.7321091621153, 65.31432751686343, 62.06992726172171, 70.39539721704298, 70.85101973625922, 71.39881010978453, 70.01671591112691, 79.48225021362305, 62.59693691807409, 61.19692141009916, 75.04005616711032, 68.05240861831173, 66.22338387273973, 71.29219224376064, 74.32360387617543, 60.803370398859826, 76.4942592190158, 71.47799491882324, 72.62519405734155, 58.4264729099889, 54.941372486852835, 58.73100573016752, 58.08180639820715, 54.62209155482631, 56.765706077698745, 66.24827523385325, 74.71770794160905, 71.28840323417418, 68.65297056013539, 75.38399311804002, 69.2206238162133, 60.31330162479032, 60.631668644566695, 76.2687700025497, 62.417563007723906, 59.721953330501435, 61.32251178064654, 62.017128236832164, 59.28818233551518, 52.840523565969164, 59.74043553875339, 59.25158662180747, 57.36552669155983, 60.77498028355261, 58.36548789854973, 63.574948541579715, 73.79088324885215, 80.69613748981108, 80.60572685733919, 74.9805538115963, 79.94881614562004, 77.4255318795481, 81.8869141609438, 80.41002411996165, 78.30644915180822, 76.3003215482158, 84.26820078203755, 80.67633736518123, 84.09818956928869, 84.03065419966175, 83.32311353375836, 80.04821685052688, 79.87607186840427, 80.61347746079969, 52.367881882575254, 1.9980363667972627, 2.934011826592107, 15.31145049679664, 14.17196567981474, 2.8505879159896605, 0.9264347846469573, 0.86580922166186, 55.643657176725334, 82.39182518374535, 46.59068169132356, 78.39056045778337, 113.61926540251702, 98.22235430440595, 34.49223679880942, 40.82745690499583, 64.84206630337623, 77.22025855895012, 90.88316825128372, 51.40124905493952, 1.5059712288841125, 0.36066883213577733, 0.20504566991040785, 0.1868707854901591, 0.14272231818927875, 0.14998846296821872, 0.14448622031317604, 0.1505651433141001, 0.22892862948919498, 0.19158984113845134, 0.1609913394936631, 0.26928606473149796, 0.18600141359192712], [0.0401848777677984, 0.07130636082541558, 0.02952933976156337, 0.15566813158652476, 0.08304702598721751, 0.0873919089715327, 0.02543297378466495, 0.08168751869591014, 0.029142733490575227, 0.034628162430899764, 0.07472911909703286, 0.031311424982343475, 0.014966677690315393, 59.37067370260916, 90.08288706502607, 72.53310465043592, 63.580263353163204, 41.34280535482591, 26.8661097557314, 50.179760225357555, 48.47217598269063, 40.16732592736521, 15.378160207502305, 0.16586742784467437, 0.1160563143991655, 3.789225561964897, 3.396801987001973, 1.029462946518775, 1.1191485533791206, 29.14567755114648, 117.58559749972437, 91.61026585486628, 105.66525566962459, 83.0270294989309, 92.99925558028683, 89.21512542232391, 91.12898318998276, 85.11359707001718, 90.01584591404085, 79.52310562133789, 83.93078281033425, 82.53108501434326, 85.05868388760476, 76.0080579019362, 73.07862004926129, 70.12387506423458, 74.77848114505892, 72.82712551855272, 75.74730657762098, 72.00639309421663, 72.24439467153242, 64.74751364800238, 61.51189165730631, 55.23914314085438, 60.509329918892156, 54.62084816348169, 54.80567416837139, 53.71309795687276, 54.87387241855745, 52.663381484247026, 53.09930586045789, 54.47694032422958, 57.57452626382151, 52.778299085555545, 62.45636701583863, 53.721499673781864, 62.210136305901315, 71.09499900571763, 80.11468533546694, 63.531967209231475, 69.47467573227422, 69.85318445390271, 73.2935110215218, 66.5462733853248, 73.27084756666615, 67.21160150343373, 71.67033226259294, 66.2383359478366, 73.93288089383033, 67.85862784231863, 64.07548219926896, 55.337873120461744, 63.673741279109834, 63.80187726789906, 71.69144245886034, 56.38932328070364, 75.19272265895721, 39.060154576455396, 40.28482052587694, 71.51320211348995, 60.1469813623736, 64.03075148982387, 64.51511713766283, 64.06225988941809, 54.50583642528903, 67.05127070027014, 61.33369838037799, 57.362251512465946, 45.87081693833875, 51.37634200434531, 49.45833829141433, 51.854698581080285, 51.573566621349705, 61.632077001756244, 64.25159269763579, 68.39818123848208, 62.102169144538145, 64.66467318996307, 63.299790351621574, 62.98600073783629, 61.86751727134951, 58.57111423246322, 54.69914651686146, 63.497434662234404, 52.194681782876295, 57.409178749207534, 51.835322072429044, 50.44079788269536, 47.96848873938284, 50.85584740484915, 53.77028611398513, 53.125538672170336, 53.32794474017236, 51.064890123182735, 57.84352633260912, 69.54974989737235, 70.75247410804995, 68.6574891305739, 70.65331659009381, 69.07957538481682, 72.20771266568092, 72.13845145317816, 71.64968490600586, 75.1960252946423, 74.73742177409511, 71.33354971485754, 71.42905942855343, 74.25350327645579, 75.37934118701567, 75.97267027824157, 75.82826429797758, 78.33573356751474, 76.98548116991597, 68.03932359141689, 13.489252636509558, 0.10451293219962429, 1.4354680959255466, 13.521752415164826, 0.8582234190356347, 0.6683780673530795, 0.06126883169335704, 12.944117707590904, 79.63403024981099, 37.02069467113864, 41.73254774462792, 102.46557435681744, 127.59803572008688, 73.2489372068836, 12.959948393606371, 34.30726958859351, 50.508670576157115, 66.51789895949825, 56.05527854734852, 5.107303982780826, 0.2993025847019688, 0.105192796928027, 0.17379030915758303, 0.10784120884754005, 0.10091596553402563, 0.11434113546725243, 0.040760493251465024, 0.019074367404344584, 0.05402857685581811, 0.01861851444588073, 0.06522709308492561, 0.056309975203006506, 0.05859489372420696, 0.0737421450415446, 0.05372626706957818, 0.04830977263590021, 0.028232293533942396, 0.04468140785672492, 0.0577917960923045, 0.030760674797479185, 0.05149507812494713, 0.035961170740906274, 0.03852474991412413, 0.08734053511533045, 0.05061486991302622, 74.7912210033786, 98.90001435433665, 80.73872658514208, 73.56030279590239, 51.38718735787177, 39.51909149846723, 54.07648594148698, 51.53358590218329, 47.118401296677135, 10.814542328157733, 0.15816041478706946, 0.5372396267710194, 6.652875215776506, 3.0019185956447356, 0.7688804679820616, 0.6834065673812744, 41.34744551873977, 117.01766183299404, 94.24405897817304, 106.64762896876182, 85.25453567504884, 92.47051223631829, 94.66374474187052, 94.39376015816966, 89.65404648934641, 93.0346667382025, 84.67768053854667, 88.53197405415197, 87.23685449169528, 87.47803318885066, 81.2222920694659, 76.82722137820336, 72.12395437302129, 76.41371726989746, 75.48656309804609, 81.88434893085112, 76.57454229170277, 74.54076197839554, 66.33529693849626, 63.00567142425045, 56.08184476052561, 63.93391601500973, 58.682129075450284, 54.703810214996345, 57.83236718946888, 59.609275402561316, 57.413438443214666, 58.953859113877826, 56.59498099357852, 60.62949565149123, 56.51174045378163, 64.00788407171926, 55.74946311212356, 66.17527208020611, 73.34893411205661, 81.00268640825826, 67.90546094217609, 71.12375782382104, 73.20254341248544, 75.14613274605044, 71.73148201357934, 74.8947637311874, 69.70840192610218, 74.41514415125694, 72.17665533865653, 74.73054978155321, 69.47968852135443, 66.79723447368991, 59.95283972832465, 66.95901655381726, 67.9388952255249, 71.6422559368995, 63.94091352339714, 72.76893323467624, 65.074149024102, 66.33146870520808, 68.02425384521484, 67.1708716115644, 66.9881832984186, 70.0385948919481, 61.6638913462239, 59.53109079791654, 70.59546163005214, 65.41062562696396, 58.888379066221184, 50.76149871272426, 56.28779665116341, 54.10784529101465, 54.10508394241334, 55.315244966937655, 61.585239979528616, 67.07715834340742, 71.54425944051435, 60.874953654504594, 63.72223354155018, 67.27326900728288, 63.91970526787543, 65.10058187669324, 61.414412913783906, 58.65965781673309, 66.3104683353055, 57.48346451790103, 56.395932474443995, 56.69909638743247, 54.864850967161125, 51.7885870318259, 53.09634447097779, 56.72356805493755, 53.836327060576416, 55.19229042914606, 53.09796440985895, 61.582082471539906, 73.49676039911085, 76.25209992931735, 67.77631298188241, 72.05282611231651, 72.5901908259238, 75.88711554004301, 73.93159435641381, 76.27715602997812, 76.13528390084544, 75.74287429932626, 72.91774795901391, 74.26230507512247, 74.97270122651132, 77.84582168825212, 77.22181181753837, 76.59777056786322, 78.6523159088627, 76.60425032338789, 69.30909679782006, 17.765363724000995, 0.09231129661202432, 1.1656872303255144, 2.9321352176127897, 5.326587029041783, 1.8974354166177012, 0.08823989169491876, 11.022795669494137, 87.846249611147, 46.974567982458304, 49.77594437137727, 100.29160853355162, 117.7322784546883, 69.19814863512593, 23.801971827783895, 44.299990054099794, 59.704800805737904, 72.95738743197533, 71.03705775353217, 7.123161025585667, 0.36821400145849875, 0.1364707955790143, 0.12417068704962732, 0.04509421050428383, 0.06610204210324634, 0.08031227595863805, 0.0629672562823661, 0.055963684309033625, 0.05061283594958725, 0.02310233513614343, 0.06932295918945344, 0.0408981554210186, 0.16037151307588624, 0.1272326408915462, 0.19172736924261818, 0.2898463324433373, 0.13317611188657824, 0.17878802162745308, 0.0917987148427675, 0.14073978989355027, 0.21038775422400047, 0.11607368161240894, 0.1439760363991222, 0.2786797735719912, 0.18338206704826127, 84.7685069422568, 110.16960359388783, 93.78787948239236, 82.04999846796836, 58.78402440778671, 40.63918705909483, 74.16833293053412, 66.03614561019405, 61.010691196687766, 19.98648428147839, 0.27584978349266515, 0.3647806711735264, 13.202348909070416, 9.404758157268647, 7.499543332284497, 1.602242127541573, 39.25088767082461, 124.16451054234659, 97.14415750195904, 111.28920493587371, 88.60879759634696, 95.07203209784724, 95.50481857792025, 96.86397475581016, 93.93394070286905, 94.77414377274053, 88.08922475384128, 92.53067355002128, 89.50144275542229, 92.74448194811421, 84.70260327862155, 80.22247991254254, 75.95736518982919, 81.89413916680121, 78.22053355555381, 86.20868359842609, 78.71781164600004, 80.18787676288237, 71.87661755469539, 66.22918113585442, 57.88855514218731, 66.01845572071691, 62.26740291041713, 59.07741769667595, 60.331568102682795, 63.427510569172526, 59.282290935516365, 62.0281030285743, 58.40365648269654, 62.08130997996177, 56.2390729688829, 67.1673728573707, 60.715889776906664, 67.36226758649273, 77.44875231096822, 84.97243881225586, 67.39625884640601, 74.27222867165843, 77.4146669141708, 80.25948355274816, 74.30280746952181, 80.43351911729383, 73.18647738425963, 78.37208609427176, 75.23482538038685, 77.25424197412308, 73.51969057513823, 69.09035405805035, 61.25474106880927, 67.16542736176523, 71.89906135682138, 78.64586753229942, 65.24163815283006, 77.30197721912016, 50.46331228748445, 49.17817123474614, 74.04019694174491, 72.01618333016673, 70.61031172352453, 73.0704693640432, 64.19406329431843, 58.644254669066406, 75.24342321580457, 67.92652407000142, 62.931318975264034, 52.90797656582248, 59.70430658709619, 55.26763131541591, 57.51505136489869, 57.27158592593286, 65.96412304908999, 70.12491056996008, 74.00925728582567, 64.99752944515598, 65.87890563472625, 69.06458408601823, 66.7186301754367, 69.60641245688163, 63.46107429073703, 61.09531633315548, 68.4160594017275, 58.64835354589648, 59.948956581854056, 59.33331312671785, 57.67504092185729, 54.84028908514208, 56.57196452540737, 60.2647073807255, 57.40866491871496, 58.33881185900781, 55.633957155289195, 63.32226161033877, 76.55215340275919, 78.03326391404676, 72.33389531412433, 75.44084395131758, 75.04757142836048, 80.33241610373221, 78.03647241284771, 81.19104646867322, 80.87080063358431, 81.70641453035417, 75.86875884763657, 77.3437818404167, 79.58088997871646, 80.6897440264302, 80.53393179370512, 79.59264924449306, 80.55574017186319, 79.34092721631451, 69.40286497915946, 17.696598691325036, 1.3867509100706348, 10.25033095190602, 25.845552182966664, 5.368687789286337, 1.7986285830697708, 0.14717993867253104, 17.02772278939524, 96.37859713646674, 53.28143719703921, 57.438416096471975, 100.81383289829378, 132.92258262634277, 87.90620696160101, 22.40473924144622, 50.34426835275466, 70.9065761873799, 86.63562574694234, 81.62278959828039, 8.16164137855653, 0.7319027521917898, 0.22446020716621032, 0.2931976300333777, 0.1563356546384673, 0.20703340760402142, 0.4155060492696301, 0.25435291200635896, 0.12294017364301028, 0.2230065706516466, 0.13620710811547695, 0.21718425646183953, 0.15912812173126206], [0.09418916197553759, 0.04198564404261209, 0.06929820688861994, 0.028199066385446538, 0.0111540065207068, 0.08111001097507055, 0.07172538793735928, 0.04059986759638114, 0.04812936276017178, 0.04928702503562935, 0.06369359190425565, 0.3753012953506362, 3.503669413828081, 90.52120408704205, 73.57275239882931, 71.04271381132065, 54.643393947232155, 37.92278489758892, 28.407312939243933, 39.176754874567834, 43.01538636607509, 45.02075695222424, 2.782385988581565, 0.22355576376280478, 1.1474229587662605, 2.3595079058601014, 1.728576522681021, 2.147459671381981, 13.75889499341288, 101.59622807656567, 91.21787978756814, 86.24891142691337, 87.100795315158, 96.47886860755183, 87.7258171573762, 86.67941508754608, 86.43418065963253, 88.89178091479887, 86.2735596010762, 79.0462395452684, 83.57754199735581, 77.91199991779943, 84.41197918307397, 82.07929072841522, 79.9297377371019, 76.0246338382844, 76.75284539499592, 75.51762826981084, 73.34415666518673, 75.79974866682484, 76.04024487157022, 66.4877280881328, 60.32370767285747, 57.627486105888124, 58.88590797301262, 56.58880326055712, 56.37235118496803, 56.52699847375193, 56.123861189811464, 54.76151220260128, 53.21759277774442, 55.742034143017186, 54.359159392695275, 56.6417395684027, 53.78060979227866, 57.35967451526273, 68.72496174227807, 71.88037518532046, 69.42620308168473, 70.10957410258632, 70.4416419613746, 65.12952504619476, 67.70422766285559, 64.17496527394941, 68.68345522111463, 68.41712628641437, 73.36216034427767, 65.2008729596292, 71.95006001380183, 66.91212069603705, 68.28865297379033, 54.3757902422259, 60.07913220313288, 61.5663420000384, 73.99666647757255, 58.71404147917225, 73.70080994021508, 27.071063403160345, 23.02034151169562, 68.79680387435421, 55.76246969161495, 66.83927443719679, 63.26173159383959, 65.3315741785111, 62.83687614625501, 68.95081181680003, 60.123906058649865, 54.114089704328975, 48.025500389837454, 49.77776042876705, 49.152919015576764, 53.00947181640133, 56.32125839110344, 65.63338095141997, 68.79028489512783, 67.01964070720058, 55.95929422686177, 63.7548323600523, 58.785989515243045, 64.45292011384042, 62.16097724053168, 60.41731111464962, 54.147147440141254, 59.71867815140755, 55.39396693629604, 54.69884449435819, 52.09604986252324, 49.1842548308834, 48.33829764396914, 48.75628109901182, 53.94796556042087, 52.95718662200436, 53.4001555750447, 53.6656568896386, 59.620014852093114, 67.75795628947597, 65.53924798965454, 69.46667409712269, 69.34912066305839, 73.05149293714955, 70.6692414129934, 69.70836270240046, 69.97948477345129, 71.72511208441951, 72.42831460891232, 70.15019416809082, 66.68701587184783, 69.16232955071234, 71.62649585354713, 74.86354166461577, 76.0328943498673, 74.14455552254954, 73.2403079925045, 71.57060992333197, 47.40953922271729, 4.084177257553224, 0.46053574750981024, 4.01513667837266, 6.041982731511516, 0.9370067367149938, 0.10438114975488956, 1.1431644904998042, 56.8835654566365, 66.74532582682949, 40.47955051545174, 86.37423115391886, 95.06665845071116, 91.66119390918364, 24.973185677682203, 30.11042371872933, 53.976692999562914, 57.906727483195645, 66.03164272923624, 18.561600946610977, 0.397481593874193, 0.13021222495984647, 0.08457237599237312, 0.05185080722214715, 0.06176214635131821, 0.012567392775728818, 0.10982393632612883, 0.009336107647076491, 0.023768582651692054, 0.03609517101018179, 0.08994233058465105, 0.09252267559209178, 0.11513214423170975, 0.038727705757464134, 0.0841338902471527, 0.024354247293705424, 0.04536071717138252, 0.15824558844249095, 0.04809440616818686, 0.03692772472277284, 0.02431520170742466, 0.1236556001728581, 0.08312416338031331, 0.5679140324073454, 6.779252511839713, 107.16142808237385, 82.69525189553538, 81.01911329453992, 66.9990639532766, 47.73301709082819, 33.72116550322502, 45.88160737868279, 48.755755501408736, 49.90733200503934, 1.6373359411954882, 0.34962647143871556, 2.602071935130704, 2.4385137567597055, 2.0972391145844616, 1.7854968554550603, 21.67743375224452, 109.51758800014373, 91.93419087317683, 95.0997789444462, 89.35083943028604, 98.71334091309579, 89.59641902677475, 88.84817200322306, 90.56995914828394, 93.85605812072755, 88.3493406541886, 85.09778207348239, 83.05448609013712, 79.14725626668623, 84.81992137047553, 85.28065081565612, 83.11432576948597, 81.06195342156195, 82.38640446816721, 81.96573026718633, 79.27180720913795, 80.19911043105587, 78.12484341282999, 70.57018587666174, 64.39693220200078, 60.19193172454835, 59.395074767451135, 60.036974568520826, 60.47114172289449, 55.97566227759085, 58.770496153062396, 55.83888530731202, 55.62580647007112, 56.69463273017638, 54.929479860490375, 56.41940785992531, 56.58417878612396, 59.718635005335656, 68.74797036570888, 77.20688327666252, 72.7637400165681, 72.36563513355871, 73.61661234209615, 71.49794409351965, 71.26189585654967, 64.88394937207623, 72.0959564947313, 72.55790971940564, 74.81144474398705, 69.41433398954331, 72.89426080642208, 68.18715772321148, 72.97968218403479, 57.63799805794993, 64.23380474890432, 66.87100641189083, 76.33814104141729, 62.922458341044766, 77.35398000286472, 44.777016947346354, 37.33338994364585, 69.37128989927231, 62.2260493616904, 71.81869983673096, 67.76721308308264, 68.09889654959402, 64.58687297759518, 70.09283342669087, 62.69929509009085, 54.411075884296054, 52.21039479778659, 53.23292140037783, 52.485996215574204, 58.88845751362463, 61.233838758161, 69.71044940333213, 69.96711361792781, 66.56659910755774, 57.44948110272808, 65.14182952142531, 61.53931686955114, 67.1410615982548, 65.69773527883714, 64.82058740431263, 57.407303856265166, 59.92780716188493, 57.223517279471125, 56.547241826211255, 53.57474419378466, 51.63308074397426, 52.33512224689607, 52.714995953344534, 55.31489587599232, 55.72346172025127, 54.04264765401041, 56.23729221282467, 62.59498357772828, 73.0183724434145, 70.97069909495693, 70.49158942314887, 71.88004570622599, 74.37264134806972, 74.73608816823652, 74.5997779600082, 73.96557777158677, 74.80165450803696, 73.60422549709197, 72.05362627583166, 68.9181855417067, 73.77247948800364, 74.92746845368417, 75.45732575078165, 76.79422640031385, 76.4720586038405, 74.08961880591609, 72.8326560604957, 53.95359808398832, 6.711044946024495, 0.23884828833322372, 1.4428799046624092, 2.3293137454217483, 2.4931278584464907, 0.4162126274839525, 0.4340542023701053, 58.31985112159484, 76.55074134949716, 46.78443501072545, 83.91995706865865, 99.86472914295813, 82.62997581112771, 30.19754740499681, 40.69414338757915, 62.647335452418176, 65.83596352607974, 76.4269042784168, 26.954541552451353, 0.4355071647272956, 0.12167641202047949, 0.038158456464448286, 0.05063709795414921, 0.07297568173418123, 0.004458716467788984, 0.12960994195553566, 0.040297960006301446, 0.03444812410781461, 0.048420897519756714, 0.06696193749385496, 0.046973496960896644, 0.30606634434192415, 0.21954558459260773, 0.330213098636558, 0.1523799443196866, 0.19465915708532258, 0.3771397837948415, 0.2445944687051158, 0.09649915455449974, 0.23419278733912977, 0.22126027322824926, 0.15497802426257443, 0.8239737729872427, 9.382484978245152, 122.4726353922198, 91.2912202650501, 92.02538597968318, 75.21118917772847, 51.86764240264893, 42.44832931026336, 56.930578985521876, 61.98559630301691, 63.276562075461115, 3.52365511559671, 0.3570407623004529, 3.6758604838002116, 5.841902629021676, 8.776455252401291, 5.753090852691281, 19.94209089586812, 112.15157724195912, 100.83094227698543, 100.05395996955134, 94.96597120838781, 104.35581945603894, 91.64948955658944, 91.48205926341396, 93.66360310585269, 96.31584705845003, 91.68055472835418, 87.91037251872402, 86.3093629960091, 80.79663645836615, 89.58149048589891, 87.3655003886069, 89.44225418952205, 84.58501062085553, 86.77760770243984, 85.29842699727705, 81.44568674025997, 84.98663779227965, 84.59532645440872, 75.23054999689903, 67.89475287160566, 64.26419135062926, 63.283979277456964, 63.91182522619925, 66.16060241576164, 61.33331006573093, 61.830015490132, 58.83561926503336, 58.54350466882029, 57.93598836468112, 56.719637840024895, 56.66557188956969, 60.12259598701232, 64.13340776197373, 72.34653319081953, 79.09934843740156, 76.09116508114722, 73.09242679226783, 76.71926990632089, 74.5358354814591, 73.79577052208685, 69.20205531581756, 77.01210621864566, 76.00829324414654, 80.66579403415804, 71.39884933348625, 76.46022873540079, 70.06172118648406, 75.2504599478937, 58.51455365457843, 66.70493325879498, 68.90146055529195, 85.44906170137467, 62.580851277997425, 85.09971972434752, 31.197559602798957, 24.119328837240896, 78.66311027157691, 62.06971545373241, 75.44766103067707, 68.96343400401454, 70.47886525430988, 67.3604868304345, 74.40675027908819, 63.01464188483454, 56.55915406442458, 54.04536193416965, 56.45820010092951, 54.756295450272106, 61.06817745393323, 63.2373462184783, 74.8388542667512, 74.63383197784424, 69.7001963277017, 58.99904874063308, 68.36837906991282, 64.24865876474689, 71.42328569965979, 67.63901433637066, 68.3931213809598, 57.60743102719707, 62.25487878245693, 61.40731342377202, 59.7758270848182, 54.73708760353827, 54.503671276953916, 54.21030152228571, 58.7610589304278, 58.908504747575336, 57.92749251088789, 58.84467209539106, 60.65461843244491, 65.43831756038051, 76.88618244663363, 71.63934553823164, 73.85886576867873, 72.47723440970145, 80.0160377256332, 77.5081919085595, 77.46372007554578, 74.9321517636699, 79.45282459259033, 76.23244885475405, 75.82551079411661, 70.4273723786877, 76.75472813267862, 77.44415529312627, 79.75046973074637, 79.6695198551301, 80.65499967144382, 75.08936820491668, 76.154644720016, 54.274793132658935, 6.021387346329228, 2.307171965799024, 12.516365589634066, 10.158337643069606, 3.1349345032245886, 0.7579039602029709, 1.4411943886549243, 72.98977836485832, 81.97294742830339, 57.596248349835804, 89.52290596500521, 100.24557559720932, 99.16085197079568, 40.59730399039484, 43.87003944766137, 74.76640024492818, 75.32474963895737, 88.8186679347869, 31.59137733521, 0.4708204472497587, 0.2060265382451396, 0.11972546952986911, 0.2609338371023055, 0.2000226305737611, 0.3009402661794617, 0.23192571866656506, 0.10697621897223497, 0.23723515231282483, 0.17942709217388786, 0.3103798483648608, 0.15813447504995332], [0.07390260981816439, 0.09081405437281055, 0.0216111469067513, 0.09156769336832148, 0.07575921624177888, 0.2831057086586952, 0.07550630763533615, 0.06512564772199239, 0.1178317767898402, 0.3414091978582644, 0.24362650129102895, 0.8703499167196213, 24.100158253023704, 85.33523451897406, 71.71855388149139, 55.63759319243893, 26.80299097491849, 36.957983816823656, 69.52077927127962, 46.68545007705689, 40.192385950396144, 29.775704337704568, 0.6425401892873549, 0.35213675770548086, 2.8561481208570543, 2.585841657653932, 1.4935333930676984, 0.8189346304824277, 72.04862917623213, 96.42376715137114, 87.72780972142374, 86.7745247194844, 87.81794578798356, 89.89790024295931, 91.58499794621622, 86.87211328937163, 84.15510316048899, 87.43727191801995, 83.56965803330945, 86.24196883170836, 83.97872201858029, 84.22286602758592, 81.60718640973492, 85.09773500504033, 81.22449644150274, 80.80801917660622, 76.91268982425814, 79.19720372846051, 75.37948239234187, 77.00960374647572, 75.23480969090616, 65.63340840801116, 61.74215439827212, 60.47632317389212, 55.527045111502375, 53.13520731464509, 55.901596161627005, 54.36141083317419, 58.988968249290224, 55.01187316833004, 53.65954583691013, 54.09274024348105, 59.19093501183295, 55.35171516479985, 52.850027468896684, 63.36235607824018, 70.55142910249772, 70.39982165059736, 71.5368853845904, 69.01116924901163, 62.55613642354166, 62.1194471851472, 60.19372424771709, 61.43589965758785, 62.14083194732667, 64.54407599664503, 67.79016679333103, 64.93894492426227, 68.48063730424451, 69.954985649355, 67.95559667771863, 61.07346088655534, 61.69685886752222, 61.86376356309461, 70.27723973797214, 63.27601294363699, 55.20058624206051, 16.274465918540955, 12.972458793270974, 56.01676087225638, 55.780061521837794, 70.27454114729359, 61.827524785072576, 71.33730734548261, 63.30918835055444, 62.605577899563706, 51.319318586780184, 50.41216065806728, 47.65831555089643, 50.13259372403545, 51.31457251887168, 58.52442233793197, 56.55935410530337, 68.25058244889783, 62.4213324054595, 63.06413435166883, 62.295926386310214, 65.22355994870587, 61.27264668864589, 60.38275503343152, 65.26360734816521, 68.12014795118763, 60.79890281923356, 57.57787596794867, 59.634237366337935, 53.839786591068396, 50.96388124650525, 48.95041881069061, 50.101406958795366, 47.489033898999615, 48.826177735482496, 54.896037732401204, 51.99382505109234, 53.94559252646662, 58.8860099546371, 67.98626961246615, 66.25531196594238, 72.52873513006395, 69.69294778762325, 72.39541376790693, 68.47928800890523, 69.02089672703897, 67.20395288159771, 70.54974248332363, 68.12651788034748, 69.35915408595916, 70.36994103462466, 69.91351050715294, 75.24310942619078, 72.36745511331867, 68.31878462145406, 72.49483016229445, 73.53851795196533, 71.65622741945329, 72.38096375619212, 37.08974015328192, 2.2849353138477575, 0.7390885956345067, 8.21984690043234, 1.6989468158252778, 0.18838357931423574, 0.03246238973412303, 15.37860147414669, 79.53761054623513, 39.77002905261132, 49.76664050932854, 94.02474357235818, 51.474601299532004, 26.847225504536784, 20.48290729522705, 40.06470887891708, 57.47006962376257, 58.582591087587424, 51.63410056021906, 0.7059198077167235, 0.06485360990008039, 0.0323852829845442, 0.12007043126129335, 0.059560459452651204, 0.02559035505738951, 0.1132792303518903, 0.05830741923062071, 0.03734794693187841, 0.0508102338250366, 0.10562148440869586, 0.07045582702924168, 0.07985010277479887, 0.07548199966549873, 0.027808350052744634, 0.0468127717143826, 0.022756871617128773, 0.26530176401138306, 0.0625733913282954, 0.10940270288096321, 0.1582247814944675, 0.19142620475782504, 0.2906482732824741, 1.0972141690792576, 30.872079364715088, 98.37491096988802, 79.61008810227918, 67.37521925280171, 39.372504680387436, 49.191848539537006, 40.27996070923344, 43.100937181903475, 57.2224150934527, 32.66891910183814, 0.6492863595485687, 1.275192328518437, 3.268541708107918, 1.573531113324627, 1.8707387846323753, 3.0297154524633965, 80.63614091565533, 97.08935414591144, 92.99084601863738, 87.14460034524241, 90.12605667114259, 93.50338997379427, 92.30487054394138, 88.77393722534181, 86.86735153198244, 89.61717620972665, 86.76282036689021, 88.14472629177956, 87.95617011285599, 85.02997998268374, 83.83513973605248, 87.40893671589514, 84.36191405019453, 84.6746289345526, 82.91080967072519, 83.06243281210624, 77.98712899607997, 80.52345906534504, 76.91261137685468, 69.28333467052829, 65.03691004168603, 61.893773617282996, 57.22229349997736, 56.64018630981446, 58.13880628155124, 58.030897955740656, 60.97857090734667, 57.04463366539248, 55.52606844132947, 55.713063516924464, 59.82258173727221, 57.91829455283381, 55.691541471788966, 68.28236149203393, 73.5547879434401, 70.93188331973168, 75.31785411219444, 71.098968444332, 66.71419789714199, 64.38513371252245, 63.665978908538825, 65.09573774953043, 64.37289199521466, 66.68958110194053, 71.13310875431185, 67.3532461350964, 72.03639922603485, 71.96636138423797, 71.68763775979319, 63.250890162683305, 63.47393966490223, 63.30261445814564, 73.54595476581206, 64.929037017207, 60.83459246543146, 23.27698415325534, 20.45851799749559, 63.69497306885258, 58.11567998701527, 73.7889063742853, 65.23304423978253, 74.4705907760128, 63.718966207196644, 65.52406057234734, 52.03414701646375, 50.48509713142149, 49.18433720065702, 51.546768988332445, 53.75428676605225, 59.82722190118606, 61.59972529257498, 71.05358662143831, 66.05805596997662, 66.21510767167615, 65.63783284156554, 69.45867246197116, 66.00681412604548, 61.638258657147816, 68.90826978991109, 69.98827088263728, 64.1259160349446, 60.48472489080122, 60.74515458076232, 57.06365323835804, 52.021069834309245, 51.661490471132346, 51.68263204636113, 51.29363882926203, 51.730539875645796, 55.614792454627256, 53.333832217801, 55.41988988076487, 60.582980263617735, 70.01113045600154, 70.13285729192918, 74.4677980484501, 70.88457169071322, 74.25590376700126, 71.62140461706346, 71.62579767165646, 70.50980491022911, 75.58830153557562, 71.33439694681476, 70.19621141495244, 73.43226878873764, 74.65974315520256, 77.02316730253159, 75.4820288381269, 68.87608282027706, 74.02392695027014, 73.68842309521091, 76.51044291834678, 72.96570285674065, 51.46278712057298, 4.969401782558811, 0.7593885773131925, 2.075583218566833, 4.103216687517782, 1.187047967987676, 0.39613367749318, 15.074028449673808, 83.86042333418324, 49.93174091462166, 52.786073223237075, 89.40030051815896, 61.047973325175626, 28.306192275016542, 29.363204356162782, 50.4092384922889, 66.20181083679199, 66.59403216454291, 64.80826331723121, 1.3556809579172444, 0.04516273706911072, 0.12346230852868288, 0.06309733035102968, 0.04035384228993808, 0.09624960141316538, 0.08023186737010557, 0.012154895605729714, 0.05339057883247734, 0.01210753317742098, 0.04866903339843116, 0.04733888259638221, 0.23100580028708906, 0.19281594953950376, 0.15682520014384102, 0.15572765661824137, 0.28715445269500056, 0.6271696463227272, 0.1529256134263931, 0.2179616518438824, 0.20889164579491462, 0.3502671967350668, 0.41337497652538363, 1.3386272278524216, 35.318993983730195, 113.85590199501284, 88.20709982225972, 80.59320665174916, 42.30603356515208, 54.153136899394376, 82.9028315697947, 64.66410836865826, 69.80860279452416, 42.32519434344384, 0.735231925162577, 1.6265852148494415, 5.843350473911532, 9.649077692339498, 7.356924481930272, 3.236891122594957, 80.94612583037346, 103.24134857423844, 95.66908744073685, 93.02197394832488, 96.58422347038024, 98.6087626795615, 95.93390234055059, 92.58288814175515, 90.14508801121866, 94.80923329630207, 91.70803485378143, 92.8840555683259, 92.67684459686281, 87.51466028151974, 86.15691615689187, 89.7103246565788, 86.72489104732391, 86.83405845395981, 87.2565761689217, 85.88563719103414, 81.36293257436445, 83.79647301089379, 82.73438146037441, 73.66342975247291, 68.80333854306129, 67.2005953327302, 61.496817988734094, 60.79262310458768, 63.11097921863679, 61.04981291678644, 64.55140690649709, 59.46806615398776, 57.53220388966223, 59.692425727844245, 63.51270052694506, 61.480606832811915, 59.150773863638605, 71.78549305085214, 77.33242265639767, 73.65246280547112, 79.69283442343436, 76.11677815837245, 67.53196500962781, 67.5060224533081, 69.28262864389728, 70.01225225387081, 70.03107963069793, 71.25664772525911, 74.14850927168324, 69.47410306622906, 75.00329571385538, 75.27433149276241, 75.79053894166024, 65.84408283233643, 68.8253822634297, 66.43690201543993, 81.27911152378206, 66.83463035091278, 71.2066061266007, 23.1604270012148, 18.94566962795873, 72.50999404538062, 58.03540475906865, 79.8973624936996, 65.28795742219495, 79.8485525192753, 66.35265734887892, 68.84662582028297, 53.18286411223873, 54.51690927628548, 53.223884259500814, 57.17861006336828, 55.862423450716086, 62.12820191537181, 61.69039872384841, 74.95141060121598, 67.79230056270477, 70.06631820432602, 68.55444846614715, 73.27255772006127, 66.67811993629702, 63.47828172868299, 69.70122398868685, 73.70565798974806, 66.7255727706417, 62.600110115543494, 62.869153330402995, 60.09974033601823, 54.67002291833201, 53.75968786977953, 55.82669458081646, 56.8852363863299, 53.652183548096694, 58.5714711681489, 58.71094672910629, 59.56848275276923, 64.52085164285475, 73.57033621880316, 72.85706104770784, 78.75081446862991, 74.37350426950763, 78.08616884293096, 73.64517504169096, 75.02028742144185, 71.87318155842443, 79.57468478910386, 75.83703471768287, 75.9406872718565, 75.78722061649447, 77.03523251318163, 80.39279707016485, 80.51675181235038, 71.82703095097696, 75.82180807667395, 75.383742086349, 75.31578310074346, 74.25983398191391, 53.61391690469558, 4.2750226297686185, 2.657335679377279, 18.50148670135006, 5.757317206551952, 0.8542354104499664, 0.4319462654811721, 20.693034548913282, 94.4795580833189, 53.05228840920233, 64.28036720521989, 95.22321593376898, 65.89718387972924, 39.57213763267764, 33.029059363949685, 60.406089213586625, 78.84033864544284, 76.41032049732824, 75.62397156992267, 1.558424717476291, 0.18944914632987594, 0.249807084159505, 0.1651468148995792, 0.20161207915554125, 0.2406872977172175, 0.28311998853760384, 0.13132009535066544, 0.10597963051329698, 0.10903059099350246, 0.2655804361547193, 0.18300285352574241], [0.04412779441824363, 0.048157750148205995, 0.0532058367295371, 0.10771632119412385, 0.0977868717464228, 0.021921067776518966, 0.017585783873895006, 0.06533015489337907, 0.03084970570559944, 0.10093949975505953, 0.16019494513109808, 0.2505083150801159, 54.79410709873323, 77.5579667860462, 68.9221392908404, 50.26573857953472, 51.360699592098115, 39.90779446017358, 83.39600686104068, 51.94921985749276, 49.323193027127175, 16.88525445999638, 0.6137039656600645, 2.345049068812401, 3.3578008797860917, 0.9359587284345782, 3.5831547744812506, 28.032036250637425, 105.19590485480525, 87.61370797311106, 89.49204475648942, 72.7932519297446, 81.2083205869121, 86.04669755504978, 87.50519952466412, 86.76196529019265, 85.67469996790733, 84.02625330032842, 83.44101998113817, 81.82473674897226, 81.50619322253813, 83.1822298419091, 83.12889345230596, 81.75485580198227, 82.7699181341356, 82.0462251478626, 79.1182856405935, 74.74918888461205, 74.4911204614947, 79.01187173781857, 73.19095673099642, 63.044797066719305, 57.05107027484525, 60.123690328290394, 54.56438172248102, 50.747531152540645, 53.07304559215423, 55.02629572345365, 56.56697919291835, 55.57267404371693, 52.36854476313437, 53.77021158895185, 57.325349853884795, 50.0910166002089, 54.6451315572185, 65.26297192419729, 69.11998364233202, 67.60306973611155, 70.82496735357469, 64.68976459195538, 61.33134103590443, 55.999671105415594, 62.29745218830725, 61.40976490512971, 61.97112667945124, 64.51407378719699, 66.03907954308295, 67.26261584989487, 66.48997952861171, 66.2100713483749, 67.46115053853681, 60.37222346951885, 59.78258925099527, 58.17219741882817, 66.96192695248511, 60.374463142887244, 46.954418766883116, 15.97804455987869, 14.58928821548339, 44.60979061741983, 59.53564859205677, 65.52999511841806, 61.03417442690942, 60.52342299492129, 56.02946542924451, 52.757730176371915, 45.37611584509573, 47.24283849039386, 48.45444686951176, 52.043780357606956, 54.79199686358052, 58.88011070989794, 60.69505414655132, 64.10969703428208, 62.406866704264, 63.12646865844727, 62.43365649254092, 64.85851672387892, 63.2005936099637, 63.8919113528344, 60.2419380218752, 67.004421910932, 68.46843873300861, 65.43082191098121, 60.99395052079232, 57.18720397641582, 51.760475404800914, 50.1535274136451, 47.85342993274812, 49.06411655487553, 48.93477639844341, 51.9233988946484, 51.9601946492349, 53.341080757879446, 55.69780549695415, 66.33892120853548, 65.22892967347177, 68.0241047951483, 68.83278769831504, 68.02153172031527, 67.25087227359896, 70.1266913260183, 70.1916536208122, 70.15564626263034, 68.93502819922664, 71.48898540004608, 71.48008946449526, 72.59015160222208, 69.49406793040615, 70.31139573743268, 72.18078951681815, 76.81026889431861, 77.9129099076794, 79.66471102929886, 77.79462691276305, 64.56926153552148, 42.996021624534364, 1.352986657331067, 1.1408082491928533, 2.903045939822351, 0.1041642242982503, 0.07581573054795304, 2.0270269724630543, 54.91305689657889, 75.31714024082308, 38.85249253242247, 28.34940306601986, 34.88732930152647, 39.68623153624996, 22.89620634048216, 27.99096707374819, 54.242637541986284, 52.54725579292544, 69.15514376855666, 11.833051443099977, 0.6676640734076501, 0.15267910165411813, 0.14076087263322648, 0.03965675590499755, 0.11873555369675161, 0.07170177710753295, 0.03428292107738314, 0.044809501588104234, 0.04504782771090827, 0.0327772518710023, 0.07396090910920212, 0.008746100244142355, 0.08038965849986962, 0.03357100323022854, 0.021600854515488592, 0.005130690969376555, 0.06128712970342848, 0.059696566463718494, 0.050590810921764186, 0.07113297214551319, 0.04560614492924464, 0.11999174637059051, 0.15195885643122659, 65.52598253373178, 89.49354310189524, 77.4797704142909, 61.38619930513444, 63.73963317563457, 44.033049229652654, 61.14119237469089, 53.55743085184405, 57.86142018533523, 16.067814865419944, 0.6377703420096829, 5.091744920899791, 7.870384310522388, 0.36218590073047147, 2.781109992534884, 36.85448031271658, 109.49551290081395, 91.7984062625516, 92.38159994925223, 75.04155451251616, 83.02997912130049, 89.94631798036637, 92.33169955592003, 88.64188671112062, 88.08285482468145, 85.59602506699102, 88.22411506406723, 83.92664863217263, 84.40839413673648, 85.25089571552893, 87.18245121740526, 83.6937932045229, 83.30643561578567, 83.10368830157866, 84.90718626206922, 77.71941154233872, 78.03390718275502, 81.53761925235872, 76.50328067041214, 66.94253475435319, 60.06695324374784, 62.11010409939674, 58.86668051442793, 55.29345620063044, 58.385625347014404, 59.23316717147828, 58.889179229736335, 56.374182931838504, 54.869028291394635, 54.08625656558622, 61.623055550359915, 53.396617597149266, 57.2060509650938, 68.5628580277966, 71.0333001229071, 71.73596136031613, 75.53767942613172, 67.16539598280384, 63.10391895232662, 57.53356102974185, 65.37524977037984, 66.0369457737092, 67.08409309387207, 67.15351120118173, 68.89037593718498, 70.2152035313268, 69.41897807582733, 68.19774027793639, 71.66097348736179, 64.99607032345187, 61.87050611742082, 62.69154056426018, 70.50785156988329, 64.80913408340948, 51.91899015057472, 20.323107973221813, 21.237281060987904, 52.43598991824735, 61.35167068050754, 70.82413581109816, 63.55388933612455, 65.61763263517811, 59.38986193749213, 55.521271382608724, 49.04717191573113, 50.69076268903671, 51.45341265586115, 55.233443936994, 58.041060816857126, 62.931138546236106, 63.80994950571368, 68.27839989815989, 67.99314944974839, 66.16561520484187, 64.84985220816829, 67.09440108268493, 70.3080068096038, 69.12155259040095, 64.00003540900447, 69.36780683455929, 70.8111527658278, 68.13015783986738, 62.81829587874874, 59.3793107617286, 53.6475786855144, 52.61676803711922, 50.43649112024615, 52.222205054375436, 51.71439147764637, 55.191823667095555, 53.1287746275625, 55.355715982375614, 56.12322968821372, 66.97506689256238, 67.38213046904534, 70.92188127579229, 69.56685927606398, 71.27985246719854, 70.6619301149922, 71.59696040614959, 72.20331961108793, 72.54464426348287, 73.1298226694907, 74.78891464971727, 73.6804920627225, 75.73704565725019, 70.27902833877071, 72.0348616569273, 73.54706871894099, 78.89039593358194, 79.71199127935594, 80.85628786394673, 79.59218640481272, 72.84413291561988, 57.39590937091459, 4.92516185968153, 0.6662354113594179, 1.103090002171455, 1.2575492623352236, 0.14469435108044457, 1.3888153025219518, 56.71734717584426, 83.82676155336442, 50.85522767036192, 32.518200066781816, 35.67900872999622, 40.53704461743755, 34.29154872894287, 36.93378671523064, 63.59298359963202, 58.718724789157996, 80.78755224904707, 15.97378682705664, 0.6224673373564598, 0.19261410069321433, 0.09881482384498082, 0.02151996712200344, 0.07278091154031216, 0.09513663653764995, 0.031184290776089318, 0.05107517001189051, 0.07959084329946388, 0.06380211975004885, 0.022973331675354033, 0.15336281980477995, 0.16940365905963606, 0.1791464894889824, 0.22387948187608875, 0.1985617315456752, 0.13086851716281908, 0.20159853472103997, 0.10433108590903784, 0.19994070513113854, 0.1945413940496022, 0.2843248609813952, 0.37258315410825515, 72.70983096091979, 98.80718754183863, 90.64999118927987, 69.6564854345014, 64.07007325080134, 55.690207865930375, 110.29820242235738, 72.02405160473239, 68.36626099001977, 23.230484454862534, 0.8087759368842649, 8.030649904281862, 13.704586836599535, 6.681716403653545, 6.86680716852988, 39.59677403972995, 116.68350727327409, 94.92379003955473, 97.86045289808705, 78.35641230306318, 88.9715305451424, 96.19912516686225, 95.41687119391658, 92.3967795218191, 91.75510329584922, 90.19594546287291, 91.6291795238372, 88.83706385089506, 88.39016468294206, 91.09678837560838, 92.20165729522706, 89.4237719812701, 87.3202911500008, 85.53888397832071, 83.72504665005593, 81.26710122631442, 80.75114480910763, 85.88842991859683, 79.3400642948766, 69.10881273208126, 62.59758018678235, 66.0625353167134, 59.692104093490116, 56.34554570721042, 62.35953938576483, 62.585095282523866, 62.950001224394775, 59.60247401268252, 56.57932289185063, 55.97030039756529, 63.084605201598144, 55.62997987193447, 60.727139134560865, 71.38960038461994, 75.38759385385822, 74.66000203163394, 78.60479247185492, 70.71807492163875, 68.65457873190604, 62.400983149005526, 69.97341294442454, 68.11597454932429, 69.13982299066359, 68.79379933880222, 71.23419607839277, 72.48875048852736, 71.48548664585238, 70.07152711191486, 76.20140721721035, 66.96149549176617, 65.47746281470022, 65.51019107141803, 77.48726214132002, 64.75778633548369, 61.52784001442694, 21.995308514564268, 21.58914512203586, 59.88277442993657, 62.20504506941765, 75.09208248507592, 66.46456256989511, 69.41205117010301, 60.25298341628044, 59.270382619673214, 49.14760812636345, 53.194513551650516, 53.508828763038885, 58.985736216268236, 60.57120530836044, 67.45427070125457, 66.16587408127324, 69.79540009652415, 69.69517569388114, 68.73574826025194, 68.84408412441131, 71.15661159638437, 72.83591162773871, 71.25923648957284, 66.66258735041465, 72.50736605736518, 72.4978268531061, 70.44087317682082, 66.21543715077063, 62.93310757606261, 57.224599853638686, 54.15386253787626, 53.4513032820917, 56.57028575097361, 55.73528374395063, 57.36924902085335, 56.440882836618734, 59.48395567555582, 59.99646040701098, 71.52568309537827, 72.39912433008995, 74.63922915920135, 71.7894232657648, 74.02905741045552, 70.86522656102335, 75.5099247347924, 75.4414087726224, 76.34478553648918, 76.19004803319132, 79.61924291426136, 76.67206810366723, 76.7901392905943, 73.1252178069084, 74.67312628223051, 74.78750259645524, 84.02798698794457, 83.28364664508452, 85.62879254741054, 82.21442422559186, 75.70707090439336, 53.527103085671705, 3.1632853948300887, 7.475764453411103, 8.747378722313913, 0.8198374497794336, 0.20742480192453633, 2.9846734048858767, 70.7915016912645, 88.28688867630498, 57.442797383954456, 40.58075158826767, 49.560574869955744, 52.2831351526322, 35.02711865209764, 41.777431426509736, 74.3619332774993, 67.42096977849161, 94.73948570989793, 20.41543664470796, 0.9777599176572216, 0.2896160464132986, 0.3022045870461772, 0.22166285243245865, 0.21345995066146697, 0.17968307279290693, 0.12499741849399383, 0.12927022792639273, 0.14813574061038035, 0.1465596832455166, 0.24702096027472328], [0.1323860300885093, 0.04538620491662333, 0.0629391600077431, 0.029869262549665668, 0.025232507727078857, 0.025143024827083273, 0.05151276709511877, 0.06003082977728017, 0.03248657129945294, 0.06327731504796014, 0.13702015722951583, 0.4145515343594936, 71.41242857902282, 69.77312887868574, 59.46454386557303, 34.97513548020394, 28.383668891845215, 54.000690060277144, 54.546283906505955, 37.80982063662621, 64.26711351640763, 2.994160882888302, 0.04649494864767598, 1.8240369616016265, 2.776851033972156, 0.8883980289101602, 2.3436095589591615, 80.00351752004316, 93.36160413680538, 94.08502255716633, 80.91682572518626, 71.71814595499347, 73.97262234841624, 81.30523450912969, 84.3070871599259, 80.07789350325062, 80.28187244169175, 82.2731734860328, 78.18047831135412, 77.15114639651391, 77.9151221244566, 76.78323591909101, 78.69865479007845, 80.63327758542954, 78.70883726304578, 82.31937900666269, 78.33753001305365, 79.27921264402329, 77.26797811446652, 77.06767835924703, 68.58549010369086, 56.52257404019756, 56.31222125022643, 56.72501540953114, 53.58172993506155, 51.39585971832276, 53.449671576100016, 56.050830579573116, 58.883013263825454, 54.112720797138834, 52.36437920601138, 55.85238610544513, 55.82332134246827, 49.753096565123535, 57.66898085994106, 64.80665906783074, 69.34749680180704, 66.68067732164937, 66.90959468964608, 60.17998418500347, 54.72352012511223, 62.61140654163977, 67.53875855476626, 68.65802257291733, 67.94214294802758, 65.55939328285956, 68.42798340705134, 65.20051210157334, 64.49108869798722, 67.83270882021996, 62.812424090600786, 67.0101171924222, 60.205703166223344, 57.598813579928496, 63.420324787016845, 61.610825600162634, 44.08851938862955, 22.96669525484885, 23.350987511296427, 48.96565721881006, 61.54882469484883, 65.20637604498094, 58.40399772890153, 54.83733554040232, 49.836086073229396, 48.56487727934315, 47.97374079304357, 49.97406721115113, 47.71866513836769, 52.66147913471345, 55.58228777300928, 60.09052668848346, 60.08815757689938, 64.36872251572149, 60.72409537530715, 63.16907736562914, 58.4897485856087, 63.707536420514515, 62.6831780710528, 64.37104848123366, 61.146597400788345, 62.65664715920726, 61.058810833961736, 68.05921785293087, 68.13097369286322, 62.16787668966479, 53.9470555705409, 51.63814844623689, 49.13566843155892, 46.937783994982325, 45.10402494861234, 51.45466389194612, 51.63069594290949, 52.18804121017457, 54.17387839286558, 60.93427558099071, 64.64081341220488, 65.15156876656317, 70.85630709125151, 71.48267038406865, 64.36997767417662, 69.21003341674805, 65.95297567306027, 70.54754595602714, 70.40808216218026, 75.38601706104895, 69.73222640252882, 69.94496007119456, 66.03540820460167, 75.44848472841325, 73.59856159456315, 77.83221890849453, 73.71573063635057, 76.91334878244709, 74.6273208433582, 82.67115285319667, 76.76072935904227, 58.51503218373945, 1.1694212041554914, 3.3801856012113634, 2.678101687662063, 0.32219267900912996, 0.27570254139361844, 21.71579453252977, 69.38704213788434, 75.6005471752536, 32.37670448518569, 39.27900714258994, 36.48603639295025, 22.6820880751456, 20.288200839873284, 41.03890011387487, 64.73913938768449, 57.769519052197865, 36.26132772814843, 0.5753859024374717, 0.06006313570504708, 0.1710475152057986, 0.05522139873656054, 0.021697419898344145, 0.07903971198585727, 0.05823124327786988, 0.017356319473155083, 0.015105325240461577, 0.05225186574182684, 0.04273966225164552, 0.16491102835824414, 0.08039705124833892, 0.09961966815735064, 0.027279006279704553, 0.03126324762800529, 0.025548467284909664, 0.061411680278158, 0.06325828925436063, 0.09180789257610038, 0.02788954771183912, 0.08874616856055875, 0.8973771922530667, 85.16289341834285, 76.60912975188225, 69.69097875779676, 43.07777950840612, 44.57962759079472, 54.193196065964244, 56.7631330028657, 46.3069962686108, 71.32800348343389, 2.2126526505716386, 0.04496339716077332, 4.55724451811083, 3.2990832434546564, 0.9410139894293201, 5.658139096152398, 93.05478065244614, 93.43515642227666, 98.80598729656589, 81.03887419546805, 75.25514325787945, 75.04369612663024, 84.06730482655188, 84.41274796762775, 85.93711437717562, 83.42515791616133, 86.82242470402872, 80.12748010696905, 80.88281093105194, 79.82279039198353, 78.11864606795773, 80.73180752415811, 84.51698103258687, 82.07308553880262, 83.3285342493365, 81.59034375221499, 82.50624072167182, 79.3075321566674, 80.65734524880686, 73.0435226809594, 59.418377568644864, 58.89387430683259, 60.72227539554719, 57.13840576910204, 55.10023240120181, 57.320266462141475, 59.13092667056669, 62.130033662242276, 56.8265655732924, 54.73182378276702, 57.47102668208461, 58.87895753306728, 52.83796618061682, 60.35278028057468, 69.06444288069203, 74.14332389831543, 71.22744960169639, 72.37177756524855, 62.44566679000855, 58.48036627615652, 66.14419906370102, 70.49803779971215, 69.85950731462049, 71.74682632569345, 68.06303039673837, 71.7432334346156, 69.70732719667497, 67.05895070106753, 69.38658714294434, 67.41085006344703, 71.29973888397217, 62.469656005982436, 62.45650822116483, 67.08732512689406, 65.62482233970397, 51.54260343120944, 28.469441321588334, 28.13209395254812, 56.16917241004206, 63.09664295565698, 68.04593670752742, 60.90378307527112, 59.06804715433429, 51.02361502185945, 50.45038807776667, 47.37804259023359, 50.7323908036755, 53.43196207477201, 57.3566464454897, 58.751280461588216, 64.37640643888905, 63.119102447263664, 69.0283021619243, 66.06228428502237, 65.68142606366065, 63.690383895750976, 66.71683372989779, 64.03976117410969, 65.87076279424852, 64.34754563916114, 65.86758567440894, 62.12300085252332, 67.75944679014145, 69.9073366965017, 65.58300202892673, 56.52435087388562, 55.780520439147956, 52.1825812708947, 50.27156329924061, 47.76472160893102, 53.4342448942123, 55.53031636822609, 55.968896189043605, 55.00698589509534, 65.87471654338222, 68.83326622747606, 69.2676922582811, 72.72905841950448, 72.640318716726, 67.37467796571794, 71.38331674760389, 69.59558671520603, 73.71205929786929, 74.19987663145989, 77.74703287309217, 71.91227189956173, 70.83352596529069, 67.76269451264413, 78.22345964370236, 75.60391256886145, 78.30877903969058, 75.86369114537393, 78.6646556854248, 76.40524495032527, 82.84155630296277, 78.762220721091, 70.32335896645823, 2.998337716825547, 0.9321454491826796, 2.1843581430373655, 0.4885045451021964, 0.34448338612433405, 21.225496299805183, 76.42532748560753, 83.42911166529503, 43.84174346923829, 33.663094812823886, 33.087624272992535, 29.96846921982304, 33.882261168572214, 48.47117577829669, 72.42053262649044, 67.16301118173908, 45.48726012629848, 0.6085358752358345, 0.18116330788020166, 0.07207174394880572, 0.1465361490244827, 0.07619291393747253, 0.02783614372263753, 0.09643656517108602, 0.04585233111415179, 0.03984150183837741, 0.06041861965411133, 0.0752863408096375, 0.32617995215039103, 0.23653955979933664, 0.27342974238338014, 0.08146146147121346, 0.10003112632060245, 0.11143872709644419, 0.19166962153488593, 0.16025261623003792, 0.3294511782305856, 0.14212639371473945, 0.2476859552365157, 1.0661163926124573, 93.04529636136948, 89.70626108108029, 80.79673843999063, 52.13505391151675, 41.71042949922624, 72.86026170176845, 73.90821703018682, 55.12222120838781, 86.35860443115236, 3.7478296026106808, 0.11670490741849908, 6.609987530016131, 7.3288118743127395, 4.579056818639079, 6.863808516533145, 92.80131709191107, 98.44059498079362, 102.64688199566257, 86.12239929937547, 79.26839474708804, 80.76816789565548, 89.56698556100169, 88.63091191937848, 86.94809744434973, 86.84521367472988, 91.02747224992322, 84.03914220871465, 81.93651645414292, 84.74494134226154, 82.43924663912865, 85.44379788060343, 91.07558404245685, 86.23485365221578, 87.72226349000009, 86.13363296754899, 86.11425645889776, 81.64844189920734, 85.22941681646532, 75.97674954322078, 63.409436287418494, 60.400974442881925, 62.66862607771351, 61.052127115188114, 58.8923994956478, 60.91854687659972, 62.20679836888468, 63.14018910931003, 58.274787010685095, 58.07795463069793, 59.89576924231745, 63.68560252651092, 55.63562416261243, 63.825682132474846, 72.19096414504513, 76.30563243742913, 73.43222956503593, 75.48331537554341, 66.60222991820305, 60.572786023539884, 68.71007242510396, 74.42350664446431, 73.61142696872835, 74.99206204568186, 71.5328061196112, 74.7356959312193, 72.35400922836797, 69.29058321060674, 73.01943932810138, 69.07404484287386, 73.03527001411685, 66.81571668194186, 64.1934984730136, 72.8845254836544, 69.57785760202717, 57.576032453967684, 29.668727574809907, 30.559062457853752, 62.46858127655522, 65.62559896899809, 72.93633214889034, 64.04873163469377, 62.63796098770634, 55.45848600326046, 55.546425542523785, 51.9655643740008, 57.10737197629867, 56.9757725346473, 60.24250676555019, 63.02433798390051, 67.54036672653692, 64.44149424952846, 69.02915723862188, 68.65701844615322, 67.14071642967963, 67.23394332393524, 70.12988413533857, 69.2856567136703, 69.16682458692982, 67.51214135077693, 70.10093704346689, 65.74029299520677, 69.29322688810288, 70.14974701789119, 67.24677731913906, 58.21730075343963, 58.18396060697494, 56.39142959348617, 53.50571440112207, 52.52469039732411, 57.430516442944935, 58.07090613149828, 59.82340543500839, 58.33152409522765, 68.08376404546922, 71.92487055255522, 73.25711927106305, 73.85699872047671, 74.65320848649549, 71.47470797261884, 73.99559174814533, 71.47414315131404, 77.50980008033015, 77.52800772267004, 82.50242033312398, 74.24131254996024, 75.19124000303208, 67.92726147559382, 81.95432401472523, 79.5819882423647, 83.11309414525186, 80.22966569469821, 83.79859109078684, 80.20628052373087, 87.68728379280337, 81.77152587521462, 68.48003325923797, 1.8212909347588018, 11.825331238008316, 7.58086730395594, 0.45571834149379886, 0.2948184575765364, 30.220924731223818, 85.07838203061013, 90.26163731851886, 49.740960751810384, 53.803900826361875, 49.43257224175238, 31.25516353114959, 34.769901383307676, 58.01170972085769, 83.96275012723862, 77.41720076530211, 53.841018215302505, 0.6375495248263883, 0.27375655549187816, 0.2839568629860878, 0.182345304938574, 0.140402557989282, 0.22863638226784047, 0.17962203090710027, 0.1792208153393961, 0.12601240838487304, 0.14541891703922905, 0.15945562431889196], [0.030470216391427867, 0.02172435938020147, 0.014432324659860423, 0.02985050105640004, 0.008641929523418508, 0.059948808573667085, 0.13205636713293292, 0.10107345788949922, 0.04792740283113334, 0.15704457708183797, 0.3146927395174581, 4.391096349685423, 75.1973275215395, 70.01940665706512, 67.24756179317352, 37.58398232921478, 26.539272377567908, 74.45556025351249, 42.52495673394973, 51.436130692881925, 62.21944801269039, 0.1258918108238328, 1.338560792707628, 2.39693638778502, 2.0009381852803694, 1.7055226694191656, 35.250195610907774, 103.12826664217057, 90.90208192025462, 90.43270757121425, 74.22079855395903, 72.4474871543146, 69.35907563855572, 67.18871055110809, 74.50826121914771, 77.22498893737793, 78.54955765508836, 74.41540302768831, 74.09199576224051, 71.57966275368968, 70.2305321539602, 73.32183837890625, 74.21723704184257, 73.60906570188462, 75.83398311368882, 76.72479260352351, 76.84123992919922, 77.15147587560838, 76.84291870363298, 72.09261463534448, 60.97355027352611, 54.86052851523123, 56.46285595432405, 56.39790542664067, 51.92229278625981, 51.08512170853154, 53.088942958462624, 54.60564505669379, 58.60543889384116, 54.09295205147036, 52.409137372047674, 56.22199104678247, 54.1931176185608, 49.915890616755334, 59.174343386004054, 62.89327982933291, 66.98732822172104, 67.70982880746165, 64.41729714793544, 55.09033626125705, 61.223220902104536, 68.40090336338167, 67.85563899624732, 71.15792951276227, 66.74349800232919, 68.10503898128387, 67.4756476186937, 69.23424228545159, 68.1369278507848, 65.28249748291509, 65.55623969724103, 64.64588895920785, 62.951840816005586, 59.238395690917976, 65.364941781567, 61.225719451904304, 48.84103567369523, 42.17936062043713, 37.87872491344329, 51.35432966293828, 58.256300880062966, 61.81439268973566, 55.76035945646225, 52.03462946799494, 50.761208457331506, 51.75150102184665, 51.295270535253714, 52.765837715518096, 50.8324190878099, 56.46129485099547, 58.25089977633569, 62.33029419376005, 63.27109821381108, 63.95242960222306, 61.858260477742846, 62.846548711099935, 60.826528072357185, 60.133304057582734, 61.39044330966089, 60.38921125473515, 58.62586267532841, 62.2882346184023, 64.03001408423147, 59.01353405367944, 63.434127607653224, 72.07253210006222, 57.894105295981134, 53.26984659318001, 48.22467834718766, 47.488280803926536, 44.75495753749725, 48.597817344050256, 51.60316482667, 51.33985611700243, 52.874463835070216, 58.107254735885135, 63.98018821593254, 65.33743812191871, 64.13687513720605, 72.25714237459245, 70.4087568098499, 67.46916001842868, 68.72499312123945, 70.859892137589, 68.2822673551498, 69.39572626544584, 65.20831761821624, 69.1836593997094, 71.62683317738195, 77.7271072326168, 70.4821208215529, 74.96838661932176, 71.36460704188194, 75.34745231751474, 72.5991730536184, 79.72171091264295, 70.36707770439887, 81.43601417541504, 35.868102273633404, 0.24211572993907238, 4.164761862447185, 0.43881148580581913, 0.06602732554799126, 2.2646897550552123, 60.20988049045686, 67.11939442542293, 64.09195615399268, 39.86619772449617, 59.773975726096864, 23.969994398855395, 14.415598800105435, 26.512155071381603, 55.305105640042214, 56.01644708264259, 63.34223431925621, 3.3352644116647783, 0.250012073966284, 0.08290353005812054, 0.09582295938725434, 0.02157520206134406, 0.039421333255426544, 0.08542697771542496, 0.015259468834096146, 0.03716557970150344, 0.023847955106306943, 0.0760314379247927, 0.05597024968254471, 0.020470719694370226, 0.012969093851655001, 0.09358389122832207, 0.0466076516726565, 0.021375657224486914, 0.04366493175527261, 0.12851833561134915, 0.10444756191704543, 0.1813787624480263, 0.6106890113123002, 6.254090782134764, 90.06074136303317, 78.86091539936682, 77.56228923797607, 49.36666073337678, 28.119091295426895, 68.43603995538527, 48.084418312195815, 61.8804689376585, 63.62546474702897, 0.17507516118066926, 1.3143569495408767, 5.327377386631505, 1.0063771014252016, 1.4519555337967411, 46.898532836667954, 104.52746237477949, 94.55623257544734, 94.01544755504978, 77.13423313633089, 73.74506212049916, 73.35238579780825, 70.31194486925679, 76.28261596925798, 79.16035698306176, 79.81641261808335, 76.44211522994503, 77.62588654795002, 73.08170303221672, 75.26438436200543, 77.01686013129451, 79.6692374444777, 76.92436279789095, 81.3455564745011, 79.03699059640208, 80.79032928712907, 78.88460651520761, 79.86378700502458, 76.67936371218774, 65.39958023255872, 56.558063645516675, 60.1460046922007, 58.872924927742254, 54.48837011091171, 53.36719197611655, 57.03201540054814, 57.27206053272371, 59.232355240852606, 55.6615706413023, 54.45570853448684, 58.312045604951926, 57.497604662372225, 52.78131931058822, 61.466400008047785, 66.97440008963308, 69.6706844145252, 69.34304883403163, 67.99828775467412, 57.953615496235514, 64.8132682615711, 72.55413639929988, 70.75755749979328, 69.79864781902683, 70.89982971068352, 70.40168085405904, 71.83330674325266, 70.42501895658432, 69.44718776210662, 67.41645905279344, 67.72102325193345, 67.74707563461797, 64.81692391057169, 63.40280748182728, 70.20221264131608, 63.63741228657385, 53.761970689219815, 46.320736331324426, 44.369376782448064, 55.30830629410283, 62.49070344432708, 63.111234172698, 60.29696495302262, 55.43172367157475, 53.4943042262908, 52.21301886343187, 54.53793710277927, 55.25286359171714, 54.09795307344007, 59.0720126705785, 63.65831851959229, 65.76276817629414, 66.33928991133168, 66.13965695904147, 64.79178151776715, 64.0512066502725, 62.36366571918611, 61.948831927391794, 63.22322960822814, 65.33813630380939, 62.111673047465665, 65.17813890211045, 68.17249590350737, 63.658102789232814, 63.56220868326003, 72.29006674981886, 60.80407642549085, 56.22536036276049, 51.262961972144346, 49.73102146579374, 48.57791131542575, 50.34218949656333, 53.785587280027336, 53.8669607716222, 55.36864803683374, 61.1331436710973, 68.8287555017779, 66.27237427619197, 67.46136234652612, 74.3182380737797, 72.38009299001386, 70.1647069377284, 71.18967717693698, 73.95523055907219, 69.97114581446495, 71.177659034729, 68.33811406166323, 71.33604434228712, 76.48318244564918, 79.25003020994126, 74.36568306338403, 75.85109249238046, 75.28194873563706, 78.42415163593908, 74.8140178188201, 79.97789659807759, 74.49621169797837, 81.8401045953074, 47.55345490670974, 0.5226378070731317, 1.4782280595071855, 1.4399413139589372, 0.11280623234568105, 1.6144940184970058, 62.13145748261483, 74.46437774165985, 71.92109723244944, 43.8218060616524, 40.31162992600472, 24.582313645270563, 22.82176563816686, 34.543129551795225, 63.61072840229158, 62.872910961028076, 74.02342488688808, 4.8507662646232115, 0.3723099058674228, 0.10880392855934559, 0.07568181837878882, 0.023245465258256565, 0.03507542754373243, 0.07587324076842877, 0.01433408058684079, 0.045281921197930654, 0.03916573184992998, 0.03893402089635211, 0.19239389638025917, 0.12835129780033905, 0.1527257410869483, 0.1665308293435843, 0.12700492125605384, 0.1488025282179156, 0.24031030584967908, 0.310753331549706, 0.25973325475089015, 0.42784907404453526, 0.553441773499212, 7.496539777325046, 102.61978626251222, 88.41384795404251, 88.25394861159786, 53.78255136551396, 40.170828603929095, 85.73694798254198, 59.6142646574205, 71.63075554755427, 71.60338524849185, 0.4093899097173445, 2.5155574419806084, 9.108926134724772, 6.470333010919633, 2.274880563059161, 49.83406605259065, 105.51535837111935, 100.97920786949896, 96.62367466957339, 81.62657860786685, 77.28733108889672, 77.2381288774552, 74.20071601867676, 81.378355333882, 82.37867739892776, 84.83104521228422, 79.20436597639515, 80.8279840407833, 76.47212136176326, 77.8933451252599, 79.73949493900423, 83.68267720745456, 80.85736259337395, 86.29536797923427, 82.30605079281716, 84.74253300697573, 83.22142216467088, 82.05210870312106, 79.7871752708189, 68.23028810562627, 59.56811012760286, 63.70913674754482, 61.827026644060695, 57.57997051362069, 57.247067189985714, 60.288014104289395, 59.969851047761985, 62.789584129087395, 59.62903630348944, 57.350045096489694, 59.121611041407434, 63.06076503569081, 56.09077991977815, 64.02868440074306, 71.04451810159992, 72.81900621229603, 74.72307374400478, 71.14861780597319, 61.14426751290599, 68.88540237180649, 76.26512219828945, 74.46938268599972, 73.67724434021981, 72.42311354606383, 73.80836133033999, 73.58899885608305, 72.67905604454779, 74.32147795154204, 72.04834676557972, 72.43144466030982, 71.13564260544317, 68.78094180937737, 64.47361846123972, 74.86299253279164, 70.11119796383765, 58.06451659048758, 51.69372843157861, 47.88922548294068, 61.054586441286155, 63.784073629686915, 67.77715236909928, 62.875640930668006, 58.01503589076381, 56.6704866193956, 56.85759544372559, 57.2925353050232, 60.24789217979678, 56.57342756948164, 62.83150249911893, 67.26309437905589, 69.0856707480646, 70.64979430167907, 70.88172404996811, 67.29129622059484, 67.37956523895264, 66.69100099994291, 66.04260967623803, 67.8774473744054, 68.92884654383506, 65.03064993889102, 69.47062000151604, 71.71292920266428, 66.69463311472248, 66.76997400099232, 73.1845397333945, 63.03072360254104, 59.12834182862313, 54.425678868447584, 52.93978306554979, 51.17150014446628, 53.07643059761294, 57.15021994806106, 56.83487315331736, 59.40839513655632, 63.078243117178644, 70.39768003648328, 70.4365115011892, 71.33620123709403, 77.94604609089514, 73.78289730318131, 72.42243889839419, 74.40624821570613, 77.12125009106052, 72.59052030501827, 74.200880758224, 72.43168000252017, 73.28741565827401, 78.29576461545884, 84.90316191027242, 78.03237745838781, 80.23893817778557, 79.90199873524328, 81.52036866834088, 79.10980547628095, 83.7573120670934, 78.4447362346034, 88.46051631435272, 46.32964795635593, 0.6231713415153566, 13.557110621083169, 2.3118383605634016, 0.1601664926255903, 3.650114291137265, 76.65644138090073, 79.68273039787047, 81.98357705147036, 55.93166505136798, 79.57357868071526, 33.038826065678755, 25.343967330071237, 39.891320505449855, 76.47552597907283, 70.22249129510695, 88.20994746300482, 5.810743810669069, 0.5352688196205324, 0.17136436917128103, 0.12690336864081123, 0.12556095277109455, 0.11593275973873755, 0.23706760888378467, 0.10814230438442, 0.1320330627382763, 0.19436128677860384, 0.10383214050483319], [0.05252206878316018, 0.09810599333216106, 0.04804837577525647, 0.09800253315798699, 0.04020217986356828, 0.08986975907558396, 0.026612015658869382, 0.04529101849203149, 0.042077494154293696, 0.23335992719136903, 0.2942959856121771, 8.443763736755617, 72.91937182026525, 59.982939997027, 55.94701328585225, 28.967988298785304, 57.989893497959265, 65.41353210326164, 31.214747428894047, 77.53689581348051, 33.37163133005942, 0.316071605850612, 0.9289132935866233, 3.00736112940696, 1.3189892687143818, 2.7114933152352614, 89.56889183290544, 89.78328858652424, 97.2280962236466, 78.84732046434956, 76.01880519620835, 76.54406547546387, 79.92618406972578, 65.63878989988758, 65.68523860746815, 65.8972623271327, 72.75762111909928, 69.82481002807617, 68.58606276973602, 68.62055609303137, 70.39808011824086, 67.05509893355831, 69.38487698954921, 65.32416089888542, 67.53740141468664, 70.77997776769823, 73.65334141638972, 68.2676447591474, 70.19051613346224, 61.771509416641734, 55.119703046737186, 52.58667169078704, 55.71285563130533, 54.96087058897942, 50.26457755796371, 52.75076404694588, 51.66343204436764, 56.12748545985068, 58.82636639379687, 54.92156059511247, 53.03621453623618, 54.99261433078397, 51.76162858163157, 50.20597342521914, 58.98473208950412, 61.49177774306267, 64.0328578026064, 63.338959140162316, 59.549357275809015, 53.800802153925744, 64.27882571374217, 67.32323215853783, 67.06354771890949, 64.00049040394445, 65.89357529917072, 65.87078632846956, 68.85705932494133, 65.56905800296416, 65.03088135873118, 64.46613065658077, 67.75340634007608, 63.263300541908514, 62.80961567355741, 61.665024911203695, 66.81399868380639, 56.46445235898418, 51.93349115310177, 50.65003671953755, 49.111996927568995, 47.784945349539484, 58.783424285150346, 63.48878975837462, 58.54164546535861, 54.43810493715348, 54.619287060153106, 54.39513929428593, 52.730701123514486, 53.205609936867994, 55.26075540050384, 58.685278738698656, 63.40441173122775, 61.42432082083918, 63.7141691484759, 62.175874402446134, 62.0788545762339, 59.203847454440215, 62.516104713563, 61.633112507481734, 58.597562774535156, 56.167662297525716, 58.36022407777848, 59.847802577480195, 60.8199934036501, 64.0440091010063, 53.861791087735085, 66.58289263325354, 70.10434166077646, 53.18449581823042, 51.445971919644265, 46.32638062200239, 47.99765156161401, 44.99256295542563, 51.623576841046734, 51.36685379089848, 52.117505227365804, 52.94372504757297, 65.78991097788658, 66.04475129035212, 67.12182629492976, 62.90688653146068, 70.78208800285094, 68.31315994262695, 74.42064331423852, 69.32408025187831, 68.95882914143225, 68.65572406399635, 77.9773779838316, 72.88743588232225, 77.90841487146194, 70.50640029291954, 76.70110933242306, 69.8256572600334, 73.8087143436555, 66.61503253444549, 73.6901960065288, 70.21521922080748, 82.05822760058989, 71.24046402592813, 81.15123441142421, 10.457711565879084, 0.5410882073544687, 2.8313969844771973, 0.19632446369336498, 0.3366305558912216, 28.760204661277037, 73.37931679141137, 70.30780284635483, 46.25096913306944, 55.9969646699967, 59.61249174610261, 26.182948581634033, 18.153676409875196, 38.64164552380962, 50.91764042454382, 68.03911962816792, 15.15918016433716, 0.5972777535357784, 0.1983834169204197, 0.1167862199907822, 0.056395780880965536, 0.11072102528546127, 0.058306009628840035, 0.03341125091537833, 0.06832735898393778, 0.05832714982511056, 0.05061987629761139, 0.05768740512130242, 0.11310981766831492, 0.09612274491378377, 0.10028879233305493, 0.03404325813115124, 0.039178004578476956, 0.025405814052529396, 0.03139076487822158, 0.09305614857904373, 0.2437764553413276, 0.5801333799477547, 13.634070465641638, 84.77232733080464, 69.35592989767753, 65.07878918801585, 37.15911903688985, 44.563918498254594, 50.285997621474735, 38.29422158579673, 90.0092641768917, 33.309195041656494, 0.2980477939690313, 1.20247550789387, 2.4445164540121636, 0.8806902650863895, 5.555507829112392, 98.1042831174789, 91.97474033601823, 97.1673151754564, 81.0994355909286, 79.82731680716239, 79.4359976245511, 83.64628545699581, 69.26711174749559, 66.90218925476074, 67.86223642287716, 75.53608694384175, 72.8330796764743, 71.97526516452913, 72.03836825586134, 74.62386131286621, 70.56583989051082, 71.78886628920033, 67.8375647144933, 72.42752229013752, 74.39295922556232, 77.35479585586056, 71.18583325416812, 72.69851100060248, 64.39957587949692, 57.45008514773462, 56.16663855891074, 58.657182801154356, 57.07396514954106, 54.35631567432035, 54.65566312113116, 56.876811135199766, 58.85932999272501, 61.30712824483072, 55.6995980201229, 56.6328985460343, 56.695715304343935, 54.93758347726638, 53.3208687843815, 62.96596919336627, 65.08259780945318, 66.6355622199274, 66.35111193503103, 61.846438454043486, 58.2575717279988, 66.85824301935011, 69.15465739465529, 70.06361961364746, 66.92817887952252, 68.06196351205149, 66.82347513014271, 71.81581297228414, 67.49102330976918, 68.77060244160315, 67.96259418610605, 70.42562300159086, 65.15411438480501, 64.97754104675786, 64.18947804358699, 70.11737177448889, 59.310849712740996, 57.061088008265344, 56.24767080430062, 54.91105648779101, 51.754380041553134, 61.06382754541213, 64.87232738925566, 62.05914074374784, 57.49089740937757, 56.7436937362917, 57.975023792636016, 56.56065633220058, 56.66651718078121, 58.91612591282014, 60.34933643956339, 64.50475815803775, 64.70639936385616, 64.87100947287776, 64.53367387094806, 65.21371087720318, 62.39036529294906, 63.74762696604576, 63.45064078607867, 61.42320294534007, 59.34047145228232, 62.86919255410472, 62.88458001229071, 63.33226757664835, 65.44380887862175, 56.429774684290734, 68.78318540511593, 72.43811268960276, 57.93128936521469, 54.90604762108096, 49.02270809296639, 49.71483384409259, 47.115177108395486, 54.70031146080264, 51.99528809516661, 54.63288591754053, 54.9252397783341, 67.92041301727295, 69.13993281702842, 70.56564377200219, 64.9384860069521, 73.27991608650454, 71.306563808072, 76.32090614688012, 72.45602223180956, 71.88044578798356, 72.70131941764586, 81.97276699927546, 75.56504972519414, 79.44429735983573, 73.02274196378647, 76.84941414863833, 72.42407060438588, 74.78424702921222, 69.03834342956543, 76.14199899858045, 71.39927294946486, 84.82341227992889, 73.06133808628206, 87.40780707328551, 15.343294259040588, 0.30256728371304853, 1.2385182899813498, 0.396634178055871, 0.2334156217834642, 27.720725574801047, 81.74240619905534, 76.69823815745693, 57.858337202379786, 48.66414070129395, 36.13467439528435, 27.265281523427657, 27.870303200137233, 51.2247423971853, 58.30352229456748, 77.53244000096475, 20.836897280908403, 0.741705306835713, 0.2294116785689708, 0.13784400818328704, 0.08406420688956015, 0.040959806346725074, 0.09968143782668537, 0.046560272964979374, 0.07621997216295812, 0.028294045966298833, 0.0736225740383229, 0.19248204245682687, 0.23111717414952096, 0.21503286706584118, 0.2551175596853418, 0.2058363645788162, 0.1544046993818014, 0.23054672975934323, 0.18463147984397027, 0.17110388395526718, 0.3309602182238333, 0.6179108302439413, 16.453795702226703, 102.45459172033496, 79.88594055175781, 76.96990151559153, 42.94316768646241, 71.40507021257955, 79.149868565221, 48.05652633790047, 100.0858723732733, 39.54541844706382, 0.4002721151036601, 1.853555738925934, 8.611084203566275, 4.5607633744516685, 6.568227525680296, 102.09822870069935, 95.52548946872835, 103.35807046582623, 84.8122178354571, 82.99433262117448, 83.002789251266, 89.11688573898809, 70.56262354696952, 70.89191436767578, 70.95185602864912, 79.39430282961938, 78.01653108289166, 76.0287993954074, 76.05605986810501, 78.3962086708315, 75.15178095909857, 77.74241232102918, 71.73087012383246, 76.69762626771005, 80.24810867924845, 81.59058693916568, 74.37421029613864, 76.36093001211844, 69.86987806135609, 59.74119647856682, 57.09891926857733, 62.785697060246626, 60.357326307604396, 58.536256128741854, 59.23696402580508, 59.20786788386684, 59.86786157854142, 63.002502149151226, 59.38010308050341, 58.451980083219475, 58.26651473199168, 59.03789197244952, 56.595181034457305, 65.947460820598, 67.64132853477233, 69.99307186372819, 70.73972640498992, 65.653777276316, 61.2069038421877, 71.61576424875568, 74.67216922390845, 72.22232741694297, 69.621945042764, 70.50543538985714, 70.27613362958355, 74.71016130139752, 70.34271978562879, 73.05358748282157, 70.58393770648588, 73.4224707080472, 68.75160248048844, 69.42862710645123, 69.23777241860667, 72.96794645247921, 62.755267312449796, 59.877820476408935, 60.58927959011447, 61.16725652448593, 58.16859276063981, 66.23605312839632, 69.26721372912007, 62.94065029390397, 60.154963385674264, 60.317824117599, 60.09894017250308, 58.76765243468746, 59.152895865901826, 62.280750736113525, 64.56531563112813, 69.97199304642217, 66.30380030601256, 68.1131112190985, 66.91776106434484, 67.76066272489487, 63.531308251042525, 68.87529050150226, 68.05654279647335, 65.26060673498338, 62.04418082391063, 65.45390505944529, 65.6488743136006, 68.86257417740362, 68.82227574625324, 58.16498025771111, 72.56269501101586, 74.14237468473374, 60.90625416847968, 57.0136587081417, 52.12764063189107, 53.07162177178168, 50.92059789165374, 57.25620631248721, 55.60954040096652, 57.89967113925565, 57.80054500026088, 71.33873508822533, 71.51266082640618, 73.41314331177743, 70.5353944532333, 76.26334928697156, 72.00480061192667, 80.4870516254056, 73.13379995284542, 73.38847160339355, 73.97354018303656, 84.698516168902, 78.52155193205803, 82.2280191606091, 76.3877982477988, 81.98327895133727, 75.84300456508514, 79.8940912369759, 74.2449603542205, 80.72457467356037, 75.28184675401258, 88.35247855032645, 77.44442201429798, 90.84899656234249, 14.08962042100968, 2.3552244324837965, 7.80283276111849, 0.48785119467685306, 0.3758707131829954, 37.47814501485517, 90.7215509107036, 84.37276332609116, 63.3776415548017, 77.8370826475082, 75.2456432773221, 39.856203525297104, 31.13465851353061, 58.2583797362543, 67.91715745002993, 88.1782860909739, 27.507532988825155, 0.8018589596594534, 0.49882791696056245, 0.3719878118605383, 0.23810924331267036, 0.2992428298438749, 0.15627280478515934, 0.1261164737685073, 0.3329890029084298, 0.19765957108428403, 0.16650977724742505], [0.03004656785408095, 0.038272051981860594, 0.029001763736408566, 0.04352596340580814, 0.038233693959491874, 0.08455729938202328, 0.022427817701452205, 0.06700905190119821, 0.13523953906711073, 0.14134437116163392, 0.5568474326883593, 21.400810557027018, 64.58288000475976, 64.9793492594073, 51.04463500361289, 34.39778612506005, 46.98947691148328, 48.39519554568876, 39.87798444686398, 91.46096475662725, 10.36680377298786, 0.11737263731418118, 0.5456919054831229, 2.6550719814915813, 0.8318916900504021, 30.706888744907996, 106.1781055696549, 83.22332843657463, 96.38443362328314, 71.04167830559516, 77.35430163721885, 76.16402702946817, 83.88909586014287, 75.82573044684626, 67.65210720800584, 58.39706297843688, 64.36569836831862, 63.00798562265212, 64.12308800605037, 63.280213802091545, 66.67307576825543, 59.22407903978902, 62.39199307657058, 56.995439298691295, 60.37614583969117, 56.38423596659015, 59.607922184851866, 56.97295235049341, 58.82487197076121, 54.78665067303566, 57.65883368830527, 52.771329033759336, 55.34302711486817, 51.41095299874583, 50.43410239681121, 50.205628256643976, 53.50634198034964, 62.59332833751556, 59.01757409495693, 52.979402926660356, 53.43622961351949, 52.36574419083134, 51.74848864155432, 48.72887549861785, 58.8900617630251, 60.415232258458296, 61.11756793914303, 57.664458367132376, 58.492364806513635, 54.07807842377694, 61.95081272432881, 63.3093923138034, 65.73671579360962, 67.6905542804349, 64.21256903679141, 65.05685921638243, 68.7808241382722, 63.51743090537287, 64.671682465461, 63.48957031003891, 65.16262985044911, 58.63280527053341, 60.68296147931007, 64.82871455530967, 61.58626371814359, 51.91767223419682, 57.15563281889885, 51.483944385282456, 51.55027950963667, 45.528774492202274, 53.92472943952007, 62.47930111423616, 58.45890306657361, 57.77894843009211, 57.85958451609458, 57.0962324450093, 56.13554985292497, 55.17740503434212, 56.43877260146603, 59.35785539688603, 63.49920365118212, 64.42490262369957, 62.80194743987053, 61.908706080529, 63.327086125650716, 61.54016410150836, 62.76246093934583, 60.00829027545068, 60.56744375536519, 58.185200075949396, 57.300925254821784, 59.08964764687323, 57.34681698583788, 62.425694081091116, 57.73240950799758, 55.07112449215305, 71.48525914838238, 58.36864540653845, 53.90386635257352, 47.45397183202928, 46.25982976728871, 44.12014545932893, 48.226494404577444, 52.24764554731308, 53.102973276569, 51.06136783476799, 56.259159426535334, 65.84997423233526, 65.99066180567588, 67.86877893632459, 65.90329493245771, 67.788527242599, 69.81648675857052, 71.07395941211333, 73.74753321370771, 73.85516305123606, 73.20816809131254, 69.18201984897738, 69.13441796456614, 69.02958085460048, 70.19286171082528, 68.3649822973436, 69.8966129364506, 70.15800752947408, 71.30563812871134, 69.4296939911381, 76.39743158894201, 74.28085788603752, 82.06769620218586, 53.16792380425238, 0.7820932170556438, 0.4848116642284778, 0.7922726256712791, 0.030382533798054345, 5.38266025243267, 67.55182004744007, 63.54575434038716, 64.59376850435811, 38.23539387795233, 68.13435477595176, 23.557914110922045, 13.246926646078787, 20.619719566837436, 54.455520260718565, 64.75277354640346, 45.018709474994296, 0.3075913802510308, 0.025168041428250652, 0.019073557266364657, 0.08552829284341106, 0.10959306040838843, 0.10765757757209002, 0.04931052478270666, 0.08947327027037259, 0.023818659904082457, 0.040926676874439565, 0.04893291621438919, 0.06627035162021076, 0.014935784237158876, 0.04681138509523965, 0.03313247151973267, 0.08043186994449747, 0.0790695894149042, 0.17276794950087226, 0.2533911192609418, 0.169403184085123, 0.6082687250548794, 28.2127437668462, 77.85834189384215, 75.1941268674789, 70.6890650718443, 49.90704959438693, 38.585104557775686, 43.87047090838033, 48.80580886717766, 101.2553584191107, 10.279641843611195, 0.18589580071068582, 0.9767787122438032, 1.1643924804464465, 0.8469183514675788, 37.775994116260165, 109.02819387374386, 89.2301873237856, 97.40614045050837, 73.58620612852036, 80.27556527045466, 78.90526956127536, 85.73899545977193, 79.9100866625386, 72.19600831308674, 59.817882737805775, 69.21491284524241, 65.16321820597496, 67.29110010208623, 65.98739839369252, 69.98814536679176, 61.48118734359742, 65.46699400871032, 60.81099548647481, 61.9568217954328, 59.67715594076342, 63.99776043430452, 59.73980403715565, 61.3958954042004, 56.89856067780526, 59.73424603862148, 54.887177098181944, 59.00169241812922, 55.01939235195037, 55.80861637669226, 53.26865419264763, 56.49618433367822, 64.50203995550832, 62.8863529236086, 54.31237336127989, 54.3637328763162, 54.71050962325066, 54.005271388638405, 51.43465980406731, 60.47712725977744, 61.850968791592514, 63.28136305655203, 58.981249024791104, 58.158045507246456, 57.42856702496929, 65.19511099784606, 67.00706558842813, 69.90107659370669, 70.25128149217176, 68.45920547362297, 66.62046893950432, 70.43247145991172, 65.9821424176616, 68.19913664171773, 66.09062733188753, 68.39785960412794, 61.64857841307118, 63.846619744454664, 67.89429003192534, 65.7066822052002, 55.90019979784566, 59.07445238482568, 58.198751864894746, 57.96963445601925, 48.547991475751324, 56.27401344237789, 64.58529226241573, 62.54286704524871, 60.88228456435665, 61.15414796337005, 62.454735309846946, 59.45332196451003, 57.17460532342234, 60.18837805717223, 61.603816324664706, 65.11154882369503, 67.27084498251638, 66.081237177695, 64.72834502497028, 67.85708242847075, 64.92113736367995, 64.42540468708162, 64.14151137874973, 63.533038016288515, 61.33994671606249, 59.7430556820285, 60.968659077921224, 61.25441551208497, 64.51873356296171, 60.11867361684, 57.63342457432901, 74.46725676136633, 61.3951736880887, 56.67436192112585, 50.534522917962846, 49.07068260254399, 47.7105732887022, 51.003226541703754, 53.35955904376123, 53.17395248720723, 53.939195140715576, 58.92635937659972, 69.53692374690887, 69.8728669074274, 67.95845216320407, 68.45432604512861, 70.17058264824652, 74.0364706900812, 74.87293966354864, 73.66960356312414, 73.46095700417796, 74.86024687367102, 70.68588010726437, 71.1390786017141, 71.0958227034538, 72.52743290316674, 70.39646410172986, 72.33255386352539, 71.9720252867668, 71.48650646209717, 70.40566598215412, 78.91462049176617, 77.6623018326298, 86.77103381003104, 60.24014157633628, 2.057768548688581, 1.3062968465589708, 2.337772826994619, 0.18628083650142918, 4.76360482554282, 69.95031802884995, 71.68766129401423, 71.03355899933847, 47.15993135206161, 48.506767365240286, 24.017943413026874, 27.71605795429599, 32.079683003887055, 60.15646173108009, 71.50030536036338, 53.77677763662031, 0.45816752458772353, 0.03362076064091056, 0.14929041897337283, 0.049412154006741704, 0.028032223926857117, 0.05400339937618664, 0.03843323688112921, 0.08362493973465697, 0.020337232704003973, 0.014830269032127917, 0.14318770128152064, 0.12183195851262539, 0.1377060817133996, 0.18303643882034287, 0.1337392784414753, 0.19247623551036083, 0.13945228720624603, 0.26339291805221193, 0.30585735555618043, 0.32351764339593153, 0.8422118749830031, 33.808469618520434, 91.77080062127884, 82.57368979915496, 71.94027762259208, 51.481983200196304, 57.01049335541264, 65.99072456359863, 58.31692895581646, 108.93137408841042, 13.815876245498659, 0.22353348592596672, 2.5249699046534877, 8.905980740824054, 2.406551587966181, 40.12669409475019, 111.06061704697149, 92.90503240400746, 104.40271531381916, 78.44432046336513, 84.48430768905148, 82.2798179811047, 90.6343173980713, 82.33484098988195, 75.21422509224185, 64.71093754614553, 72.87746521734422, 67.77224156164354, 72.57502694283762, 71.2080103351224, 74.20739973745039, 65.3097971793144, 70.14545594492267, 64.8958537655492, 65.67941388776227, 61.96556083617672, 67.60685090095767, 63.23833073339155, 64.27358934956213, 60.84999561309815, 63.07097888761952, 56.83608908807078, 60.29172466647241, 57.023237136102495, 58.69071122138732, 56.055702163327126, 59.966642548961026, 65.58333935276156, 64.88767954611009, 57.48223289366692, 57.59114926861179, 56.73463698356383, 58.81777248074932, 53.52328269712387, 66.53095260743173, 64.87179394691222, 65.79347249000304, 65.58835998658212, 63.835221336733916, 60.59511215456071, 68.97403224822014, 69.58162307739258, 72.3884319490002, 73.16450426655432, 68.76142409539992, 67.84135372407975, 75.20881222140405, 69.33153275520571, 70.67388549927743, 69.05218939627372, 71.16417392607659, 63.07972577310378, 66.08468886344664, 72.60216974443006, 67.58542691507648, 60.192775034135394, 63.64146017259168, 60.187142510567945, 61.50847135051605, 55.875155464295425, 61.00448600707516, 68.48821532341742, 66.13480106476815, 64.97272829855642, 63.46850718221357, 65.34882476252895, 62.48767929692423, 61.87513451422415, 62.613477553090746, 65.2482944150125, 69.35918546492054, 71.03637526112219, 68.33444272318195, 65.99389383869787, 68.65198212285196, 68.34043610480525, 67.2398582581551, 64.37502576458839, 66.8654994041689, 65.21062397187757, 62.35255364448794, 63.89526105696156, 62.79246707116405, 69.02578400027367, 60.86668922055153, 61.33255697065785, 76.22631426780455, 63.91951699410716, 59.59939495209725, 52.95715916541315, 51.32533550262452, 51.76851234128399, 52.605475533393125, 57.556369612293864, 56.950445790444654, 57.93770244044643, 61.50962452734671, 73.23317712353122, 71.47262911642753, 72.9054238719325, 73.86028566668111, 74.6916320247035, 77.98228879128733, 78.85014457087364, 74.19680933798514, 76.55877436361006, 80.24418630907613, 73.92039206720167, 73.27906885454732, 73.51177523213049, 77.32634298263058, 74.45723118320589, 77.15056588572841, 78.65972918848838, 75.8698728007655, 73.96728008024155, 82.69229442842546, 81.44432175544001, 90.07662696223106, 60.450031526627086, 1.795329869754853, 4.291856461955655, 2.7631646587002665, 0.21406943489226604, 7.602000544148107, 82.84842045076432, 77.71188059160787, 81.01118226205149, 56.080554300738925, 89.43661382121425, 35.37941809623472, 24.074868771337695, 34.804437852674916, 73.0284764689784, 81.23030154935776, 65.69470328669395, 0.5045591739396895, 0.12688112144749011, 0.2343746106470785, 0.1761273829446685, 0.22065233649505725, 0.3224925564662103, 0.152718095529464, 0.2589687909330091, 0.10700116279504954, 0.12239104181888605], [0.055620446275438995, 0.042912572126595244, 0.0986745608069243, 0.0012289848218056103, 0.06138561413653436, 0.06257224985728822, 0.01618579458144884, 0.02358557573790031, 0.049713295508897117, 0.007358187370212569, 0.09622518619101855, 29.2265901642461, 63.015610710267104, 47.02488806939895, 29.645093333336618, 16.584879352200417, 40.340647620539514, 39.67033024757139, 59.311744013140284, 75.05441988668134, 1.4895665285087403, 0.09088114835321905, 1.4125898913029702, 2.81970170236403, 2.2055212913020967, 77.00918797523745, 93.03601603354178, 92.31181313914638, 81.57084957245858, 74.1192013217557, 79.18075330795781, 80.10424398606824, 81.62983417510986, 83.85530856347854, 73.72668189387169, 60.99260514782321, 58.163022994995124, 61.01347215713994, 59.68462805594168, 59.839385171090406, 57.64456802798856, 57.10066864567419, 58.99423599243165, 57.83312812928231, 54.89284492308094, 56.694071831241736, 55.84549842342254, 56.52680235524332, 55.896249971082135, 57.912199189586026, 53.77673841291859, 57.245659059093846, 56.17474609805692, 50.761545781166326, 50.87725962361982, 51.463708877563484, 52.20215389805456, 59.52341471948932, 56.712667788228686, 53.023882604414425, 53.49413164200322, 53.470554274897424, 51.590734835593935, 49.813269645937034, 53.93717512007683, 56.87649734558598, 58.20769094651746, 55.808534006918634, 55.77404852836363, 54.5701515290045, 55.544334919221946, 64.53599983646025, 64.46505592715356, 64.5684221483046, 66.14579939073133, 60.746464652399865, 61.885646466285955, 63.450421133349025, 62.738044185023156, 61.14032553088281, 61.34310814642138, 61.116646182152536, 60.20156898806172, 64.32577648470479, 58.14366609819474, 44.632752172408566, 46.99832577859202, 53.35633877784976, 53.33095319809453, 46.60823822021485, 50.4888508396764, 60.80921473041658, 62.3678901118617, 60.352623385767785, 60.919700053430375, 58.27836813465242, 53.048075783637266, 48.713076191563765, 48.354908881648896, 52.34457123664118, 53.82672509839458, 55.3870439529419, 57.61128279470629, 58.24796976581697, 64.66979580540811, 63.62512742319415, 61.92633713445356, 62.96851088923793, 63.0810123105203, 61.4302828235011, 59.85130917641425, 59.58183057846562, 63.360355669452304, 58.64706700847995, 58.96506140308996, 52.684687799023045, 64.65775020660894, 63.76755260652112, 52.109370231628425, 48.506057416239095, 45.27906463992211, 44.2216093309464, 45.108155204403786, 52.927592339054236, 49.78622098122874, 52.0109305074138, 48.938443814554525, 57.55556160403837, 65.19764092660719, 66.79783851869645, 67.37705492204236, 68.15609255144673, 65.11975049972534, 67.81889423247307, 68.93705214223554, 69.04757668895107, 71.05770511011924, 71.12971982648297, 66.58173161168253, 68.62560026107296, 66.82308289312547, 68.65605354309082, 64.3390497853679, 69.02186947484171, 63.248128814081994, 68.03107092457434, 71.97871685028076, 79.62359674515264, 75.92334255095452, 88.30124455113565, 12.65538517505892, 0.5058882139142483, 1.5092194416830618, 0.019722592701474508, 0.09599771170366196, 41.42144495441068, 70.18027090257215, 67.92842249716482, 51.07804183037051, 43.46614514627765, 39.3950661536186, 14.454850939012344, 21.05214911122476, 40.9669206988427, 54.61330544564032, 50.983508786847516, 1.5708603469594833, 0.034640082759001566, 0.07472846026141798, 0.02236875232249018, 0.09216781600468582, 0.07687226538696597, 0.1015596709124023, 0.026513747645602114, 0.05030993244520599, 0.026729692509698293, 0.04625702855147181, 0.03348586404876363, 0.042900414311236916, 0.011519689015263032, 0.08371441880421293, 0.045552568570260084, 0.023896369947901657, 0.023473098708857453, 0.04162761668163923, 0.058286290525669054, 0.0720782173917659, 39.910661712769546, 73.70535204487463, 57.134589302924375, 40.1764807393474, 21.85330302484574, 44.02807958664433, 43.169680641543486, 70.977461261134, 77.53841769310736, 1.397386171644734, 0.0764573598280549, 2.2011444164860636, 1.6768703681807366, 3.3446781000783368, 86.04901175345145, 95.91712244095342, 96.32572358654392, 84.45447414152085, 76.39081847283148, 83.30827128502631, 84.30508675113802, 86.41190159705378, 86.1030149459839, 76.9976483621905, 63.85369962261569, 61.48015968261227, 64.54582537374189, 63.14981852808307, 63.656121992295795, 60.46976497096401, 60.38564582024852, 59.83688269892047, 60.651009851886386, 59.716175679237615, 59.35412914522233, 58.00188026120586, 56.923126482194476, 57.8680254567054, 61.1027806035934, 57.71163663556499, 58.929814984721524, 59.23266903046639, 52.572511934464984, 52.933515118014434, 55.269906290115856, 54.87337035517539, 61.05199767697243, 59.45453397689327, 55.136055407985566, 54.8421561333441, 55.09648653768725, 53.914452829668605, 50.12324279354465, 58.025159528178555, 59.65431597925002, 61.66582115234868, 60.60067799783523, 58.964665243702555, 57.4217224890186, 57.34351042778262, 65.36299236359136, 67.5261442122921, 67.63131864609258, 65.94059667279645, 61.88182607773812, 67.2894448618735, 64.92229446288079, 63.92291376667639, 62.48902466989333, 63.50566379485592, 63.82000254046533, 64.0024672785113, 65.17376545936831, 60.05919871791717, 48.23404496715915, 52.68254226253879, 58.01443969049762, 58.687455654144294, 50.78824143255911, 53.642114823864354, 64.8092439097743, 64.17698137221798, 62.9208109455724, 63.35318165440714, 60.032734486364554, 55.92035685816119, 52.61725441102059, 51.162714035280295, 53.25152520210513, 54.38456850667154, 56.16120215385191, 59.87056801396032, 62.431969873366825, 66.574184971471, 64.87430818619268, 63.7412727263666, 66.41186160425987, 64.63128597505631, 64.44704832569246, 62.588005681191724, 62.141388923891135, 66.09219627995645, 62.77475756983604, 60.71144573150143, 55.70852141226492, 68.1435723458567, 64.76712942123413, 55.31124807173207, 51.5786970815351, 48.95350571601622, 46.87154300751225, 46.017180181318714, 56.33677528750513, 51.81266646231375, 54.55663111902053, 51.77565889973795, 59.04851767324633, 66.68256790407243, 69.67144535433862, 69.84409239984328, 71.55531267965995, 68.42327656284456, 69.23210851607784, 69.27205393391272, 71.46980500990345, 73.69258865233391, 74.80418051442793, 69.76479776443975, 70.38796040319627, 69.38013876638105, 71.76294726710167, 66.82475382281889, 71.96957772777927, 64.97777246659803, 69.65275918283771, 73.85880301075598, 82.9583409524733, 76.86403674464073, 93.79339433485463, 17.518066129376813, 0.2230457483880943, 1.060721907884844, 0.11801227476567992, 0.12656108821712195, 40.80451888422812, 78.15498290523406, 74.17646008153116, 60.1016426855518, 44.34192411361202, 34.54652632436445, 22.486777574785297, 26.906414070437034, 49.77732112330776, 63.545016934794766, 61.73752207909862, 2.464038335507916, 0.25313808041955194, 0.06893595455274468, 0.042418487550270174, 0.04796892479662934, 0.04221157869324089, 0.038865222370312105, 0.041747984416302175, 0.09660180267547408, 0.026471086124318744, 0.12462490057993321, 0.07207117704374176, 0.14748222164569363, 0.1230297523039964, 0.26394373526976955, 0.1685584648962944, 0.15280653271944294, 0.1499772934062827, 0.18888812482116685, 0.15359417835791267, 0.20045974502159705, 51.62466333758447, 90.03514397528865, 62.28898379110522, 42.10701642497894, 26.524722345413704, 58.16626287275746, 60.155245796326675, 75.80372595017957, 88.29045018842145, 2.603862987410638, 0.2337652796338643, 4.706315667398514, 7.344297882049315, 4.858008430850122, 91.15143483684909, 99.6889598907963, 100.32170880225398, 88.19247722625734, 80.3361423553959, 84.73338603973389, 88.98384678748347, 88.94157932650658, 90.53060208597492, 79.78737138932752, 68.33699226379395, 65.82047016389909, 69.84184880410471, 66.33468504874938, 68.28807246300482, 64.46536971676734, 63.72524592184252, 65.69682921132734, 64.90879366474768, 61.79850316816761, 63.17250551715974, 61.7789658423393, 60.75063805426321, 59.87393732993834, 64.97212033117971, 59.613056567407426, 62.26790497379919, 60.370093622515284, 56.040350006472686, 56.694483680109826, 59.40427664787539, 58.08148868622319, 63.562848029598115, 62.11971782868909, 55.70715642744496, 55.69474604821975, 58.143109121630275, 57.32787586027577, 56.399089982432706, 62.98319232079291, 62.65170497279014, 63.90765574670608, 61.80481818414504, 62.095461891543486, 61.35412608423541, 60.57117000702889, 69.47122404652258, 70.79397278447306, 69.53697866009128, 70.65545035946754, 64.10850071137952, 70.4170173214328, 68.11812400817871, 68.29936888910109, 65.51133248113817, 69.45653084785708, 64.11201515505391, 66.81581866356635, 71.77299637948313, 65.6185700816493, 52.87665251762637, 58.57210266974665, 61.6188076234633, 62.216251280999955, 56.478482677090554, 59.6696485242536, 66.30744026553246, 69.65419477032077, 66.7365946308259, 67.43143466211134, 65.63786422052692, 58.42923818096038, 54.606649183457904, 53.77157657377182, 58.65118549716089, 59.700148874713534, 59.912317722074455, 62.762221674765314, 67.03439666378883, 71.69308200959237, 68.34413097750756, 67.47184291962655, 68.9080266029604, 68.6183830999559, 69.1933947224771, 65.71221666951334, 65.37506149661156, 69.26772363724248, 65.28077556240943, 64.8403718394618, 59.12123841624106, 72.14892418153825, 68.58377210555538, 58.53211410583989, 54.22863468047112, 53.12090243062666, 50.616567134857185, 48.39956114369054, 57.984457092900435, 54.4996351580466, 56.84655397169052, 55.088277016916585, 60.78850461590675, 69.47941395544237, 72.71988007330125, 72.09130456370693, 74.43216723780479, 71.90249735309233, 69.74683330905053, 72.5485352546938, 74.20081800030124, 77.29418739195793, 77.001005911058, 73.88570262539771, 75.99895015839608, 72.9677503339706, 74.84789140762823, 69.37683613069596, 75.00928909547868, 68.5482354317942, 74.17563638379498, 77.48503423506214, 87.54113628018288, 81.83109883339175, 94.3726734961233, 15.891888718451224, 1.1960474786258515, 4.834685527509259, 0.4083375807010359, 0.34369569452058885, 52.101227391150694, 85.42876735810312, 84.95911844315069, 67.56746245968726, 60.54960873819167, 54.23126266848657, 23.392805860888576, 34.83937440379974, 59.994985595826186, 72.47363367388326, 76.87003012626403, 4.229386343109993, 0.38618017288465656, 0.31741428219022294, 0.19143499944719577, 0.22344457376147472, 0.2711029801397555, 0.15314587902638221, 0.1790487673133612, 0.24124326304562632, 0.11343301484181036], [0.07143728525167511, 0.056525356992478334, 0.050672778499222575, 0.0399856987379251, 0.03884803518773087, 0.006369190363799252, 0.07528787298548607, 0.06883393462386823, 0.03659698541366285, 0.10290974766136178, 0.3752622555100149, 18.89944841784816, 63.765516896401685, 50.87419625251524, 58.33481104143205, 35.11543473889751, 39.86174975672076, 36.452809995220555, 81.03468510412401, 49.551835829211825, 0.09481920800622433, 0.14726705819128022, 0.08090818511141885, 0.7835688862589099, 19.760798946503673, 97.87745245041387, 82.43318265484226, 88.47066740835868, 74.00869246452086, 75.62146125301238, 82.11340750417402, 82.975018870446, 78.5881067091419, 83.55796152545561, 76.42648850717853, 67.60282654916087, 58.013619915131606, 60.946297645568855, 56.091340818712794, 59.880993673878336, 57.77412391478016, 57.61919813771402, 57.586587552101385, 58.234727844115234, 57.03301560494208, 57.12300654380553, 57.04128003889515, 57.833257567497995, 55.2470467167516, 55.61667911468014, 52.391612222117764, 55.69235340241463, 53.02030540281727, 50.462908283356704, 50.007289686510646, 51.17021360704976, 52.69716093617102, 58.58518377427132, 51.963465905958614, 51.04215606566399, 53.64399756154707, 53.99999972312681, 49.1408851838881, 48.10554027557374, 53.28610481754426, 53.10303211212159, 55.687140572455625, 58.89263483785815, 56.54610826123146, 54.012382645760816, 54.674164941233975, 57.839211725419574, 62.99551640787433, 67.6844746066678, 59.384570660129675, 53.37027495907199, 66.64390902365407, 63.43837161217967, 57.89874153752481, 58.710919272515085, 62.22133859511345, 60.30302109256868, 61.059414878968276, 62.47180938720704, 55.673216158343905, 43.526267236278905, 46.28395234384845, 48.89366211429719, 51.86769339346117, 50.50708201623733, 46.9400119012402, 54.78269692390196, 55.782238437283425, 61.27801641341179, 63.047185790154245, 58.55075713126891, 52.15383814227197, 49.110537805864894, 48.085112571716316, 54.928765989119015, 53.988993552423295, 53.20835951835879, 51.25018289012294, 53.409451592353086, 60.960190680719194, 59.75348526431669, 59.44838762283326, 62.8017670108426, 61.17636034565588, 60.7573413848877, 56.66279485148769, 60.34107985035066, 60.865194797515876, 63.81847281609813, 56.545096289727, 53.66608050561721, 61.70562928722751, 63.15452144991968, 54.07723119181972, 50.9950876235962, 46.871178227086226, 44.5418433989248, 44.19525884812878, 50.53134579812327, 51.96222643698416, 50.812485602594194, 50.18542805025655, 50.68012129875922, 58.121806729224424, 65.22995341208674, 65.34045442458122, 66.13146705012169, 67.13604096443423, 68.9416491600775, 69.58271349630049, 70.9206888752599, 69.02126542983517, 68.6823961811681, 64.87863848286291, 67.58609371800577, 65.31638283883372, 66.5513018638857, 66.50457074565273, 65.8138099793465, 62.67292499542237, 64.34550992904171, 69.86859936867991, 78.13793628446518, 79.12561262807539, 89.35762513068416, 42.08908727092128, 0.30267502631871934, 1.1205992174725379, 0.48965557688666933, 0.2995058431500389, 9.754746344781692, 70.96703560121598, 63.47238248394382, 61.73053241545155, 48.159920015642726, 48.844738391137895, 28.394129853094782, 40.74121182964694, 48.17861403188398, 50.4157417820346, 56.8613060059086, 9.480628563511758, 0.4907105412454375, 0.1238473519803055, 0.06170773878693581, 0.06656077555230548, 0.008937673936147363, 0.05229342984215868, 0.10052506150978227, 0.04582999965115901, 0.04933205951425818, 0.13766353319008506, 0.06447176869598127, 0.044625797534301404, 0.09672574804074342, 0.04204838664361066, 0.06069300170507162, 0.03845887018307563, 0.07624169841649071, 0.03113961061312547, 0.1146951906623379, 0.7728475164021216, 28.946393689801617, 79.13051559079078, 56.601970657225586, 58.942452861416726, 32.49164169834506, 40.37964382479268, 43.02598461028069, 93.65025135778612, 49.78961383142779, 0.05438384246982394, 0.5481538669236246, 0.23734716968911312, 1.0556555539369583, 21.942346711312574, 110.61800110724666, 84.83060590682491, 92.51274831833379, 74.97794935780188, 79.18520912047356, 83.11678901795419, 87.48453647859635, 81.83139693352484, 86.5043753962363, 77.42422180791056, 71.38042203841671, 61.083721806926114, 64.22770938565655, 62.52892301928613, 61.632841863939845, 59.79716870092577, 61.71804751119306, 60.57339399091659, 63.107621669769294, 59.570946001237445, 59.42937981697821, 58.155370450788936, 59.51237324745425, 57.69662572491554, 59.33257179875528, 57.48420584586359, 59.13760254459997, 55.30827099277128, 54.631089472001605, 52.692960077716464, 54.65805576693628, 54.58562527933429, 61.253552590647054, 54.139283087945756, 53.74632435460245, 54.57993784258443, 55.42227860419981, 51.41559316265968, 51.53017736250355, 53.3605827823762, 56.66128081660117, 60.8316546101724, 62.19192474119125, 57.5770365807318, 57.785726285749874, 58.44516300385999, 61.88599555723129, 64.76331687742665, 70.90833340921711, 62.23250558299404, 55.90992335350283, 65.93704300542032, 66.84792718579693, 61.31875415002147, 61.40347734574349, 63.866514005968654, 64.5791498307259, 63.71501638043312, 66.5113329118298, 60.06725918862128, 48.26409816741944, 52.328034523994695, 54.38311330733761, 55.4436751334898, 53.562647604173236, 49.32934330355737, 57.02836367391772, 58.36956716352894, 63.74995685392811, 66.71262894907306, 61.234258451769435, 53.56545209884644, 50.45977823195919, 50.9370247779354, 57.145462113042036, 59.18997010877056, 57.053090295484, 55.24319102687221, 55.39016223722889, 62.931534705623505, 63.71949572716991, 61.91279319024856, 64.82046188846712, 63.94773060275663, 62.057348220579094, 60.05235418196648, 65.00729614688505, 63.58706082067182, 67.0340750294347, 58.99022340774537, 54.78174378795009, 65.78452556363999, 65.63579320907593, 58.842632462901456, 53.07590892238002, 48.90989680444041, 47.77843421505344, 47.42857840753371, 53.21368609705279, 53.62192246221728, 53.25407474271713, 52.91762559644638, 52.760083598475305, 59.46260229233773, 66.93949883983981, 67.01569480280723, 71.3136632980839, 69.12213310118645, 69.92017853644587, 72.9385208314465, 73.03186539680728, 73.04017297683224, 71.56406740988456, 67.16431340863629, 70.17273210710096, 68.4574874754875, 69.48596431363013, 66.07727558382096, 68.40434720439296, 64.98171837099137, 67.25139002646169, 73.66677945660007, 80.12598960630356, 79.88440298265027, 90.72803066622828, 49.22008568240751, 0.683122685840053, 1.917076440107438, 0.8183291145870764, 0.1546786371017656, 8.580756437393928, 77.21061737306657, 69.23924722979146, 70.46198337308823, 54.9917592540864, 42.50047329933413, 26.41495481614144, 52.40571706525741, 61.58959773279006, 57.719834389225134, 71.10777024299868, 12.704729572419199, 0.4807405504247835, 0.22682642293793542, 0.016772721353317463, 0.07104923873538933, 0.026494670141067718, 0.08501218706970254, 0.07602232147849376, 0.05203086086699078, 0.05321026088729982, 0.22406721938281293, 0.21682915938717706, 0.15535958201414155, 0.24048426909552467, 0.22524198457118005, 0.1874260153741606, 0.1670967231714918, 0.19404538276214756, 0.09014463908369504, 0.21762343934707104, 1.0386276870004594, 45.2786567134242, 93.00571180159046, 68.52162607254522, 77.51145532054286, 48.02506500674833, 57.34651888570478, 55.57389390084052, 99.39380153532952, 59.71029604634931, 0.2546764309367826, 0.5686002020393649, 2.6138716503497097, 2.713808494229471, 24.661516104975057, 111.23855929220878, 89.6617421796245, 94.8806361229189, 79.95761009954637, 84.18518773971066, 87.3038564189788, 86.56684306360061, 87.90281803377214, 89.6456761513987, 80.99520252596948, 74.57508271740329, 64.6578404211229, 69.0736133821549, 66.01338801845428, 67.12804717402305, 63.95444177812146, 64.86924440630021, 63.40918917809764, 64.91285331787603, 62.692654517389116, 62.818040924687544, 62.78475961377544, 65.0482339243735, 62.77963307596023, 60.29203453371602, 59.53429145197715, 62.14428755544848, 60.106647629891675, 56.774637314581106, 57.728302786427165, 59.32042814070179, 57.1802221575091, 63.85702187015165, 56.47357971437516, 54.405011900009654, 56.10390024800455, 57.35601102152179, 55.644135705886356, 54.35902995447959, 58.10270086411507, 58.966591127457164, 64.11450193774316, 67.02967413010137, 62.62302067971999, 60.07662973096294, 61.06354121238955, 65.1407273354069, 69.48521121855705, 70.91115751574117, 65.20255957880329, 60.10358818115727, 68.90980735901864, 68.12902819725775, 63.077152698270744, 65.77240543980753, 68.2637773021575, 68.7051929966096, 68.92778750388854, 70.4446308074459, 64.56932821581441, 52.17836080058929, 57.53065455344416, 58.51140006895989, 58.83149685398225, 58.378423875378026, 53.361390790631695, 62.20344474238735, 60.11826961271225, 67.41350943042387, 69.35716152191162, 63.69467889108966, 56.365930264995946, 53.34028843910464, 53.397256943487356, 59.272112384919204, 61.8374679934594, 58.22570247034873, 58.71782656638854, 57.811362897196126, 64.75671945079681, 66.13566398620605, 64.74608982762983, 67.01882485420474, 67.89778878611904, 66.5937654433712, 63.552591031597515, 66.66842383723106, 67.629530045294, 69.22251439863636, 62.50152918600268, 58.47291377282912, 67.71293532463812, 70.52492956961356, 61.48785537289035, 56.23308350962978, 53.94138382327173, 50.75075141845211, 51.46949045119747, 55.53249328367172, 56.19254189152872, 54.73883305826495, 56.544802111964074, 54.73161589714789, 64.08435067822857, 71.7004874444777, 69.23648588119015, 73.92698949383151, 71.05191569174491, 73.33742587797104, 74.5300695973058, 77.38120125186059, 77.71313575006302, 75.91155975095688, 72.17817721828338, 73.6157258864372, 73.03656439627372, 73.12473927774738, 71.02424729254939, 72.72989780672135, 69.75139894793111, 70.90960425715294, 78.78628053972798, 83.80248992673813, 83.12740295164048, 92.67562866210939, 52.192026338269635, 0.6140017593579908, 7.447119384042679, 1.8848287963098096, 0.5042394088400949, 13.817507951490342, 86.52793315149124, 78.0516912091163, 78.50260688412574, 66.49015995763963, 62.05482613655829, 41.52820794813095, 55.86154483979749, 65.76006566324543, 67.60811390415316, 82.08072631589829, 18.226346162057695, 0.8922278556612231, 0.539193763848274, 0.26224513448053793, 0.1807407031376516, 0.12380029119911695, 0.33703845174562547, 0.2216092415995175, 0.1970429162705137, 0.17177925174755437], [0.013820406184681963, 0.07107784445848196, 0.049680847854864214, 0.057980801474543354, 0.03949850512247893, 0.03067027450719428, 0.04644087433154064, 0.04800511862061197, 0.06157252809873993, 0.10787441875905761, 1.2263492590958074, 13.48391919366775, 55.31315042126564, 49.43899316172446, 44.079776425515455, 27.32042024212499, 54.37169921013617, 38.59550668347267, 96.07113038339924, 23.091403092107466, 0.102610329857036, 0.11616182002809741, 0.8437305063970628, 1.0309554083693413, 53.61181059191304, 97.7175295737482, 89.01220552382931, 85.10172797787575, 68.60046571300876, 75.46670021549349, 84.50726924404022, 95.15123259636664, 78.70352637383246, 85.96485337903424, 82.67351412004041, 70.62017256213774, 57.55891130816553, 58.38999486738636, 57.6401710510254, 59.289794429656006, 57.20268164911578, 58.014655420857096, 56.05612577930574, 57.79171182263283, 54.78679187836186, 59.74198487497146, 55.10900282090711, 54.7440968790362, 53.41156182750579, 58.12734119353756, 57.00258193477508, 60.36016218123898, 53.90414091848559, 48.727318317659446, 51.35171736440351, 49.77450093915386, 56.19222025717459, 59.476334510311005, 51.184290993598204, 49.58919640510313, 51.26701378053235, 51.69054738936886, 48.72666720421084, 48.39347754755328, 49.03799749189808, 49.52711705238589, 53.95746161860805, 57.14472862981982, 54.18036991550077, 54.10397783402474, 52.76895599980509, 54.21270201283117, 61.7737804689715, 65.84672650983258, 64.18975260949904, 63.5265229594323, 59.051686948345555, 63.03236315327307, 62.87424456688666, 59.93610689716955, 63.03665422624158, 70.10045851430586, 60.888874146246145, 64.05657245266822, 50.46273962143929, 45.45882294254918, 53.3556249064784, 45.194639544333185, 49.40010286146595, 48.73689674562024, 48.02776359742688, 47.6161696833949, 55.61037586581323, 62.23567093572309, 64.39364917816656, 57.09511064714002, 58.649196855483524, 58.91806748605544, 58.8107475157707, 63.34310900780463, 64.76600762336486, 63.05596013222972, 64.4238631956039, 64.3234662086733, 55.8858556901255, 58.56580726562008, 63.89003253752186, 61.92234416161815, 61.32709703137798, 60.35540042384979, 60.46996108947262, 59.39026594161988, 61.63293992319415, 62.548766289987874, 58.204400077942886, 54.675392643097915, 59.842009236735684, 58.528211347518436, 58.93926789683681, 49.9122977256775, 46.907264032671534, 46.646477407024754, 45.30716842220676, 47.42176132817423, 53.049648654076364, 50.52841970997472, 51.06413702810965, 48.48226039640365, 51.178634935809725, 55.88796592527821, 64.35066784581831, 61.83069013780164, 66.12160621150848, 65.05112471119051, 69.19045294484785, 66.68838870140814, 69.61126050641461, 65.08489631837415, 67.04632066911267, 60.14844832881805, 63.65669073597078, 59.73326936844857, 61.94192071114818, 57.40824522510652, 61.48105790538173, 60.115414127226806, 74.37948196165024, 72.82565855210828, 85.91581590713994, 77.3661942635813, 63.36610194175475, 6.553432835686592, 0.3693260546893843, 0.7275848967894432, 0.055936216226508545, 0.5853695602666947, 52.38494419282483, 71.14313433247229, 66.53321189265098, 47.33621443471601, 50.01649548930507, 35.94721648000902, 13.033919392093537, 39.62965134651431, 49.915314028340006, 53.9207011653531, 17.88076573802579, 0.41869227023374656, 0.10486540159270649, 0.12355602406446012, 0.020657769637182355, 0.014865200726255296, 0.0367040730141584, 0.032114378972760135, 0.10764797849039878, 0.04591430379678646, 0.06649439403366658, 0.0572364972603898, 0.10838409705508141, 0.07039162886118697, 0.04842126141152075, 0.06545424581535401, 0.008585344354111341, 0.028350133178455215, 0.08836291009379972, 0.13031937001693633, 1.167335974112634, 29.42087692599143, 69.38927004414221, 56.85015078513854, 53.49777160152313, 24.870831428035615, 53.088174173908854, 49.24851502141645, 104.42303319131176, 24.47677246985897, 0.14074409530768472, 0.377484247569115, 2.1580839012899706, 0.4543955527967023, 61.380429498610965, 104.83964381679412, 90.34278331264373, 89.16811189343854, 70.69585861698275, 78.14097219897856, 88.66551506903865, 98.08349455556562, 79.99795559913882, 90.45631239491125, 84.58135497185492, 75.50406471375497, 61.73069323262861, 60.30341332958591, 60.3005382322496, 62.90980869723905, 59.10316021211686, 61.134543957248816, 58.502527667630105, 60.39511049947431, 57.86411093127344, 61.0137898691239, 58.48912100638113, 58.48000934047084, 55.764599538618526, 58.205329679673724, 59.70076468683059, 64.27990044316938, 56.12153522429928, 53.65744736886794, 54.66992878144788, 52.257345568749216, 59.0246343612671, 61.18831965231127, 54.47222955765263, 51.75769052197857, 53.44611398635372, 52.51951286869665, 51.835392675092145, 49.56430896635979, 51.66668761161066, 52.16707614160354, 56.63501662592734, 60.82282927728469, 57.11944895405924, 57.61988847486435, 55.64609296860234, 59.141199358047984, 63.489644835072184, 68.75944722083308, 68.86426864131805, 66.65275004602248, 60.47090245831398, 67.11842167762019, 63.45880323840726, 63.19412169917938, 66.774610242536, 72.11407000018706, 64.65906812298682, 68.8232171150946, 54.23998994211997, 49.22480037135463, 55.95494431834067, 49.232037144322554, 50.68989192285846, 52.111386329896995, 52.08434943229922, 50.09054199341805, 56.58602622247512, 62.77872308608025, 64.06083214667537, 60.40971740599602, 63.731976709058216, 62.29396912359423, 59.865370873482, 65.31971293111002, 65.68406189641645, 67.03935453968664, 64.83540219645347, 64.55980077866586, 58.44304100159676, 61.164946248454434, 66.04649282270863, 64.70712500233805, 63.28306144283664, 63.232580538718935, 64.26512095236009, 62.55501462567238, 64.28648218031853, 64.05885919447869, 59.42216657823133, 55.37937964162519, 62.41083222050821, 61.71463504914315, 61.4678002941993, 53.72606923503261, 50.41086235354024, 47.597283471015196, 48.35437151693529, 49.0376405562124, 53.023545280579604, 52.33011338018602, 54.85057746210406, 51.67688969642886, 52.49686118095152, 57.2384968111592, 67.13189109679192, 63.99050012711556, 67.6226580527521, 67.48232349272698, 71.29746390927222, 69.7708539039858, 72.2443554478307, 69.03995944607642, 69.00358338509837, 62.77809942922285, 66.95945585927656, 63.2377855239376, 64.15314512868082, 59.30796677066434, 63.19056410943309, 63.057242747276064, 75.72741231610699, 75.0477675468691, 86.19693217738983, 79.57750889562791, 69.05862992809665, 10.518114105347665, 0.9516523766421503, 1.9979375720985475, 0.13470545320981933, 0.5195251611932632, 55.19727183926491, 80.91680219096523, 69.84556721102807, 58.58934540902415, 42.56337634978756, 23.455552016535115, 21.82688193936502, 45.530327750790505, 58.2325783852608, 65.87601092553908, 22.606696198063513, 0.39891022527890824, 0.0659751089950723, 0.22562743404940253, 0.07205826080133838, 0.019252676283940673, 0.0747782176721, 0.07560812072047303, 0.04547666074828275, 0.010753410526611393, 0.2495523139594063, 0.13527127042893441, 0.27102226511605326, 0.12801654802094545, 0.155019469619278, 0.1572744034591221, 0.10650764129334882, 0.1560778966954639, 0.25480727875424974, 0.35011931112216366, 1.715638339519501, 47.788169537821126, 78.89522829363423, 69.84599867174703, 61.95198943538051, 42.82013862363754, 81.17832229983422, 56.714307338960715, 110.89178254527431, 28.6774524565666, 0.3438271552083954, 0.6522659512777483, 5.989908854807577, 2.1402729086337553, 67.90228382233651, 109.50535020520611, 96.34195435431697, 91.33074991164669, 73.77181268507435, 82.75010232002505, 93.82370641154628, 98.56772684281873, 84.93939676592427, 98.29727157469719, 90.23922489535424, 78.97231855700093, 66.3952385994696, 63.94866804922781, 63.83511151036909, 66.22753374038204, 63.736079508258456, 64.37892067816951, 63.806788075354795, 64.70494808689241, 61.14621693088163, 67.25303742193407, 61.8987040365896, 61.628778288441325, 57.88608797134892, 60.6595802307129, 63.34936518822948, 66.99252143982919, 60.655073427384906, 56.64315162166473, 57.939192941111905, 55.044562201346125, 61.78966999053956, 64.64280989862257, 56.135036022432395, 52.25020293266543, 54.51177097135975, 54.71533806093278, 54.83767678660732, 53.893789783600845, 55.99758440448392, 54.803203075162834, 59.61540214477047, 65.66817629721858, 60.706727120184134, 62.402359900936005, 59.40679088715584, 62.744708291945926, 68.25641893571424, 71.34419502750521, 69.09959516217633, 68.03476579727666, 64.48837834019815, 69.1744653640255, 68.16189765930176, 67.98844260554161, 69.50985154797955, 75.9496694995511, 68.33894560413977, 70.4947743877288, 59.576029392980764, 57.16621929599393, 61.42765091311548, 53.440810941880756, 55.483134177423295, 54.745461863856164, 55.65554195834745, 53.982502029788115, 58.19035014798565, 66.00168366586009, 70.40011190599012, 64.53243047960343, 65.14728161596483, 64.57830652113884, 63.81278537934827, 69.15659504552042, 68.89382762293663, 68.37976963289323, 68.79292857262396, 69.15711279838317, 65.39750529873756, 64.88652244690927, 68.60876544829338, 68.70847994281401, 65.86797006668584, 64.37739879854264, 67.48629293134137, 64.65726383270757, 68.28746057325795, 66.34926842105004, 65.11045840478712, 58.976699075391224, 66.62034342365881, 64.41129984394198, 65.65544820600941, 56.723779862926854, 52.92225791561989, 50.26425984597976, 51.04910650560933, 53.91677879518079, 55.95145733125749, 54.046860279575476, 57.869198245386926, 54.434535580296675, 57.15674677202779, 59.702945524646395, 71.02613787497245, 67.3548464621267, 70.89194574663716, 69.06801223754883, 74.7673886822116, 73.2785903253863, 74.27881825354793, 71.65882402850737, 71.67885949534755, 66.5663480758667, 70.02976955906038, 66.20857300296908, 69.39563997330205, 62.479763953916496, 66.06666165013468, 68.12192086250552, 78.34977565273162, 79.20823343338506, 89.2022051349763, 84.92840628470145, 72.41617879559918, 9.360546181278846, 2.5397726845356727, 3.0515481002869147, 0.12840051128859484, 0.9900684378320171, 66.50590435151132, 88.21562705501434, 80.46296042780723, 65.51751805889991, 66.65519760501, 53.31219250156034, 21.99963685004942, 54.84820835051998, 66.74039932989305, 80.21240726594003, 29.54346864454208, 0.6224109532852328, 0.15954173260158108, 0.29637337091468996, 0.19413719073899333, 0.13162565718014396, 0.15621283542244666, 0.14046810447208344, 0.22806848128957136, 0.2143435564733321], [0.03745890327639157, 0.0429737902126245, 0.043798928194108515, 0.03915201121520612, 0.07570430305936644, 0.019944804164791302, 0.009413429858884024, 0.05415405822737564, 0.038459096179013295, 0.019086320291183168, 0.4806785892334677, 37.402494261341715, 52.54756566016905, 51.592550892983716, 31.98716998100281, 47.39486955827283, 52.95105203505486, 47.32156830449259, 89.42516834505143, 8.345464237274664, 0.16767568645938752, 0.8458010275517741, 1.7750127277066632, 3.846384791597244, 78.1145118897961, 90.22126828470539, 87.81611011874291, 78.10704369698801, 69.00570930973177, 79.48243064265098, 78.51558208465576, 90.20986203224429, 81.1998482673399, 77.56385818604501, 82.42511041702764, 73.56537049816501, 61.77387068348547, 58.28573042346586, 56.66168874309909, 57.414317054133264, 57.25445693539035, 57.255268866016024, 55.20419090024887, 56.74558824108493, 56.365769447818884, 55.966970305288996, 54.94485162919568, 54.81904160591864, 54.1476220469321, 54.42774987989857, 52.89927674878029, 56.305631668336936, 54.16177395851382, 49.03180014702582, 50.09093030806511, 48.9143330051053, 54.02016462818269, 57.40097315080705, 53.396903930171845, 50.47962542503111, 51.525039057577814, 49.88493134898525, 52.392318248748786, 47.157644610251154, 46.36482769443143, 47.39670914988364, 50.03511105814288, 52.57748942221365, 53.21000691383116, 53.91223276815107, 53.297703266143806, 56.03949492977512, 58.343087242495635, 62.527099117156006, 65.21956305350027, 66.34124325167748, 61.67090062172183, 62.10729175998319, 66.63000814376339, 62.50591047348515, 62.17368179751981, 59.58434481774608, 69.26121250275644, 61.46871028407928, 49.626611894176854, 47.318132308221635, 47.93507406788488, 45.91540252008746, 45.84849865205827, 44.58006689625402, 45.617773071412124, 37.96963760929723, 48.7600818757088, 51.86859946097098, 59.837227867495635, 69.10214470278832, 63.40421953508931, 60.2933132263922, 58.185058870623195, 55.994638704484515, 51.76038126791678, 57.0854498494056, 59.695798966192434, 55.508735487538004, 58.704612101278, 61.75870287802912, 59.26953538771599, 61.43680572509766, 61.56095658579181, 61.07582999813942, 60.90018233945293, 60.99425254329559, 62.48979737681728, 62.54702868000154, 53.77504787137432, 57.753704055663086, 57.15993565897788, 65.70760003982052, 60.60821679330642, 53.08027844275198, 48.9082690208189, 44.32531287593227, 48.818227091143214, 42.128220758130475, 51.59687726728378, 50.093185670914195, 52.38703873849685, 48.56273958759923, 51.608938555563654, 50.23398307061965, 56.6776135659987, 59.656771382977894, 64.39388059800672, 66.63277733710505, 66.32787581413024, 64.23729958072786, 61.965513767734656, 57.91390934298116, 58.47991520358671, 55.01288906220467, 57.7677853645817, 53.560972752109656, 56.00634697944888, 56.83323752495551, 59.551385141188106, 58.1560843221603, 74.81395506089734, 73.14447664445447, 86.64939326624717, 69.8840456624185, 73.68134713942005, 24.254123049397624, 0.19610608266966958, 0.7026972128979622, 0.5827079256696086, 0.2854809795896853, 19.7827132286564, 71.87860227400257, 66.5416685227425, 53.96921696201448, 51.11012681838005, 57.830531520228234, 31.40637678484763, 41.326001921007716, 47.8932459123673, 52.91582522853729, 19.667581858173495, 0.12814619308037142, 0.06172142494770308, 0.0022195269318012103, 0.030578430141172105, 0.044805376204631986, 0.05596802419712467, 0.033816499936003844, 0.07313495907451838, 0.04380932783768062, 0.051796054918198824, 0.0619412423862565, 0.02036549177231087, 0.0600897342777781, 0.025951870033637654, 0.07625220914281185, 0.02470352210014338, 0.05065951751725328, 0.051256503023567705, 0.08932030549453152, 1.1482329282068438, 51.310175541908514, 62.700016806202555, 64.29096937179565, 39.67892416061894, 42.50314835579165, 51.76287589534637, 60.41325146152128, 95.32541721097886, 9.000717747596003, 0.4757750442912502, 1.9318688011938527, 1.5256729265374522, 3.2805051822816176, 89.35738978847381, 92.04042434692384, 93.14118262260192, 79.83585188465734, 73.32410550886586, 80.07150003986975, 82.93151978523501, 94.09860180270289, 83.14134305523288, 80.85433452360093, 86.68412977649321, 78.24924530521517, 65.2540014636132, 60.979849600022845, 59.002500426384714, 57.992352824057306, 60.34915601053546, 60.85109779911657, 58.98559108857186, 59.3747058991463, 57.662673688703975, 58.8425697049787, 59.31945147052888, 57.648808110144834, 57.17736667202365, 57.73495512623941, 55.25919821954543, 58.118166769704516, 58.04696006159629, 51.551209111367505, 53.06111766446022, 50.02757226267169, 56.59374544697424, 58.85039875584265, 55.915948114087506, 50.99638592812323, 54.51568549679172, 50.00200233151836, 55.915842210092855, 50.151985922167384, 48.2793051965775, 50.35254063144807, 52.77104662310693, 56.29798696887109, 55.977988243103034, 57.93991073485344, 56.27921842759656, 59.302655881451024, 62.41839455020044, 66.11237295212285, 69.01571919841152, 68.69963892044561, 65.21325588226318, 65.87220622647193, 68.67907785600232, 64.55365442460584, 65.86632267121347, 62.9742963852421, 71.17457605177357, 61.80287268853957, 51.27145390356741, 52.847638745461744, 51.468953086483864, 48.795261613784305, 48.6073330140883, 47.35390040182298, 51.31909108931019, 42.02181862246606, 50.78255791817942, 54.73476556039626, 62.95255468737695, 71.96607897358557, 63.96079601780061, 64.2824342943007, 60.770532315777196, 57.66933387325656, 53.84826283301077, 58.56201041129328, 60.57424906761416, 57.21453505177652, 60.87837788366503, 63.30554054629419, 62.27156062279979, 64.28739609256868, 64.49889421463013, 63.555591644779334, 62.30669721480339, 64.40865224407565, 63.449766097530244, 65.08510028162311, 54.77195355199999, 59.68443585980324, 60.148526776221495, 67.63626867725004, 62.80620713387767, 54.370016513332246, 52.47831229240664, 49.12594879827192, 50.83363110019315, 45.754906977376635, 53.74229215806531, 52.24189143027029, 53.92140326961395, 50.59329571262483, 54.82330522229595, 51.949863126201016, 59.54442293413224, 60.51453098174065, 66.04366871618456, 67.92252325242566, 69.73716858894595, 65.37331996425506, 63.671740870321955, 60.11704975558866, 59.228236752171675, 55.78998119600358, 59.07945340679538, 55.08814365633073, 57.99381979050175, 59.018825331041896, 60.70899817251391, 60.634449605018865, 78.18456542107367, 75.37694854121055, 85.51822093225296, 73.05299912729572, 78.27669405168103, 29.26231118940538, 0.30710157427576285, 2.5316918665362946, 0.5272237932489765, 0.2816731242402908, 18.70238461802083, 79.85532253019272, 70.25750237126505, 66.79964280897572, 52.93618625210178, 46.891770670490885, 34.04336075628958, 46.79634332656861, 55.29378567972491, 66.58651690329275, 27.116288331247148, 0.1453965932371155, 0.046053919490546956, 0.12609549062026124, 0.03831153615347801, 0.06227134584238934, 0.06679923574049627, 0.033860760665829145, 0.09579055386805728, 0.05264995184036032, 0.17029651921362648, 0.12148285990641003, 0.18743799698929633, 0.14759538815386836, 0.12511224741296423, 0.09637668773892427, 0.08941701643409268, 0.22133648365495667, 0.36485207056806934, 0.23900073983015555, 1.6414638680796472, 67.14531344752159, 77.45214908353745, 70.98626305980068, 44.695655222862, 68.77014744666316, 72.77731141736432, 63.35973593496508, 105.95762914226901, 10.748585712525154, 0.4521178814672655, 4.080818482945043, 5.386668424452505, 7.17068495288972, 94.0142551545174, 96.72075333133822, 97.57334324621387, 85.6802854230327, 79.7831509190221, 85.22868725561327, 86.02155516224524, 96.74631934012137, 83.91260654695573, 84.43603900171097, 88.8257517353181, 80.94596109082623, 66.20133230763098, 63.36842006252658, 64.60242909769859, 63.48441631563249, 65.21988076548423, 64.93617573092061, 60.578198894377685, 64.2254501004373, 62.11416767489526, 62.45594732223019, 62.47528068480953, 61.35949580900131, 60.038312096749586, 60.78214645385743, 57.31638723804105, 60.097214329627256, 60.96765102878694, 55.5473590666248, 55.193137661103286, 53.88861617734356, 58.472729421431026, 60.99284049003356, 57.05938569961056, 52.422010590953214, 56.75103641325428, 52.04520025560933, 57.33711304203157, 55.376131919122514, 50.961280715081, 54.444306204395915, 56.32176437685567, 60.049706582100164, 59.29387369463521, 59.91749917307208, 56.91277534730973, 63.05635236924695, 63.58867291481265, 68.92387297845656, 69.78152275085449, 71.03134678256127, 68.17591621029761, 67.97336501459922, 72.7458304743613, 69.0392141957437, 69.17003308573078, 67.06459106937533, 72.7867486399989, 67.23693217000654, 56.02650403976441, 57.17217737628568, 54.59968697640204, 50.86012671070715, 53.003415676855276, 51.894844039793945, 53.01285682186004, 47.63790745888987, 54.26850949564288, 61.4109573056621, 65.45304606037756, 74.70080252616637, 68.45791109146612, 68.19280593625962, 62.8607790700851, 59.51092589286066, 60.39636565792946, 62.094324404193515, 65.54529628446026, 63.196314304105705, 64.291204714006, 68.09292670219176, 64.29944561373803, 66.59034513658094, 66.316602922255, 67.94876390887846, 65.91936880542387, 67.04661092450543, 66.70552161432082, 69.13310789292859, 57.6470705001585, 61.2065076828003, 65.22129281874626, 71.73402370945101, 67.56467757686492, 58.71549667850618, 55.46433817955756, 50.959386210287775, 54.1140151792957, 47.32908356574274, 55.48691534226941, 54.79526027556389, 57.57343584491361, 53.77101567483718, 57.65247160388578, 55.716201413062315, 63.553912870345584, 64.94227501653856, 69.96279901073825, 72.81670770337506, 73.03975720559397, 71.07934090398973, 67.88238956082252, 63.65723986779491, 63.62657085541756, 60.28742182639338, 65.03545091998193, 59.46963510205669, 62.323987022522964, 63.40904405040126, 63.79196936084379, 62.5864092765316, 81.08203595684421, 80.50012096281975, 91.1236644560291, 77.40293118261522, 80.83589938379104, 31.38074605695663, 1.018777552150911, 2.9292831642012445, 1.0209664798551992, 0.4566728257604184, 27.415541641173828, 85.99330625226422, 80.52651066933909, 72.12205594585788, 71.39197734094435, 80.63364628822573, 44.03580273351362, 57.546061623481016, 62.60694680675384, 80.89187160614999, 38.46036534155569, 0.3026563950604008, 0.1782230624268132, 0.1593561401410449, 0.13427239902798208, 0.24405981594276047, 0.25932704428991965, 0.10957881117299681, 0.17077969086747016, 0.10855129574455562], [0.0798269822412441, 0.027781345453413746, 0.037592554975661545, 0.04735920690901337, 0.08297285335438867, 0.07852683144230997, 0.02257600974952502, 0.08276588704076507, 0.04994321764717179, 0.03661466672295525, 0.20656601736141791, 40.2305898358745, 50.75103382910452, 50.88123298460438, 38.750730560671904, 35.45333516213202, 43.530330811777425, 70.97133451892485, 69.45925297275667, 1.5233241622486424, 0.47002438996588036, 2.225324357709577, 6.028804058028806, 8.21165208854983, 104.25620694314281, 78.9147852313134, 91.95267308142878, 70.88650934157833, 75.63858632118472, 73.86105445123488, 85.71575149413079, 78.58562777119299, 86.57466426972421, 78.38311579919632, 84.25029908457111, 69.33568262284803, 67.39396033748504, 55.04870030187792, 57.5248259113681, 58.34502881573093, 61.874040172946074, 58.980837175923014, 57.92045970116892, 56.06829297158026, 58.982970945296756, 52.52649468760337, 55.6175773374496, 52.80723048794655, 53.44940877729847, 53.92078353512672, 56.75657479993759, 53.54893892042099, 51.54598059192781, 46.970712292578916, 50.96383810043336, 49.90409604964718, 54.993359581116714, 54.92629881828062, 53.96973471487723, 48.19794739446333, 51.69694477511991, 47.40459311393, 52.052264444289676, 47.09429048722791, 46.7981436944777, 45.276240533398045, 48.53511041210544, 51.85837776430192, 56.36838566872382, 53.1275979165108, 54.04325169901694, 52.10462024134975, 58.46136239267165, 63.445663298330004, 64.51412477800923, 62.95921094955937, 61.45879060991349, 56.943707158488614, 67.02760311865038, 61.042587910929036, 67.38184805839293, 58.45414523155459, 65.27716305948073, 49.90963835870066, 43.47134620912614, 49.6565435009618, 49.3546857372407, 44.48034455699306, 45.585127184467936, 43.28858337094707, 47.701936229582756, 42.84057417223531, 43.90581930837324, 50.424720087359034, 67.20578855083835, 56.167662297525716, 53.27535752327212, 53.132242002794825, 53.700283573519805, 52.33268253264889, 47.98180518611785, 60.320746283377375, 55.538255245454856, 62.271693983385646, 63.30306945308563, 62.378558958730395, 57.077699245945105, 61.235576368147335, 56.52254266123618, 62.363438221716116, 63.69580068895894, 63.36839652830555, 62.10673870578889, 58.82701750724547, 56.90631128126576, 59.32580178783786, 57.83070018214565, 63.8065331212936, 56.478212033548665, 52.37120020774103, 49.081461275777514, 46.23864504598802, 49.29804278958229, 44.16656671031829, 49.572247843588556, 51.97051832752844, 51.152837507186405, 51.64814656780612, 50.88281762215399, 49.2799763525686, 50.472733820638354, 52.54348247281967, 53.85309519306306, 58.2239217142905, 52.93113816169001, 49.81674094353953, 51.16767583354827, 51.83072897695726, 50.26490311468802, 51.753717160994015, 50.8276455633102, 52.48890661424207, 52.32048788378316, 52.73197589382049, 56.160335310043834, 63.48981741935977, 71.39859045705488, 74.94776279695573, 74.37185687403526, 71.83171426096271, 67.5831833193379, 44.16521741497902, 0.601929929708281, 1.072252818172978, 0.26585628909449427, 0.0738538789653009, 2.612576287600302, 62.42319553129135, 65.41082174547257, 64.5288807345975, 41.26879022967431, 40.056413066002634, 32.288994404577444, 29.515908110526304, 44.21984034199869, 51.24398554525068, 17.581488893878078, 0.7462086780898033, 0.17824871105051812, 0.047640568020963864, 0.03621599073672006, 0.04762394008256736, 0.01918151437665426, 0.020889336949274428, 0.01862151176488448, 0.010186129121951038, 0.0568994568781026, 0.06407046885860544, 0.03461553730190762, 0.0685237303015686, 0.07700913465551792, 0.08248964339614877, 0.039877492649060105, 0.08166019233965105, 0.03881744912735397, 0.03828566919471468, 0.46312684073082866, 55.014399174721014, 63.52943335810016, 61.43774709393902, 48.10621884561355, 42.838883630691036, 47.806071235287575, 82.8803877676687, 71.01462964088687, 2.044298884368712, 0.9806505819001506, 5.355536572394833, 6.910337142405972, 14.626379128425354, 117.71378055695565, 79.6737011017338, 97.58729903928696, 71.67467040400352, 78.71422659966254, 75.0692464459327, 87.58733395607241, 81.7585506746846, 89.4968222033593, 78.16839741122338, 87.57147189109557, 72.94599686899494, 69.69195150559949, 56.19852742841167, 60.22911971615207, 61.17565431902486, 65.16519115817162, 59.98052381700086, 61.038092874711566, 60.85625571589316, 60.85114094518847, 56.853692685404134, 58.263945579528816, 56.320807318533625, 58.39777292743806, 55.23575813539567, 59.57248357034499, 56.67702128810268, 54.203378538931574, 50.825386278090946, 52.58018016815186, 51.16929185005927, 58.31610918045045, 54.44865219054684, 55.69818596686087, 47.93169298479634, 52.35633442478796, 48.77448874135172, 53.25178800090667, 49.04038621533302, 48.888092348652506, 48.74811864668324, 51.90275153806133, 53.19759653460596, 57.320305685843195, 55.74852566565237, 57.5931457550295, 56.171600357178725, 61.65981992598503, 67.14630188480501, 68.71058233322637, 68.24985288804578, 63.57208521135392, 59.32790417825023, 68.90901504024383, 65.21101228652462, 70.15358309591971, 61.9602224903722, 66.58966264417096, 52.42606632171139, 48.555385143526145, 53.13355207443238, 52.118446596207164, 47.778987269247736, 46.86049369073684, 48.46707297909645, 49.092420378038966, 47.570862385534475, 47.164755867373565, 52.363159348887784, 65.73783759147891, 55.157342110910726, 52.26551586581815, 53.9900839713312, 54.299864922800374, 56.13052137436406, 52.83234542415988, 66.49384698560162, 60.3297402781825, 64.98376192585116, 65.54300169790945, 64.57441160755774, 58.93665167593188, 61.91426407906317, 58.56774883885538, 62.89135786794848, 67.42249950285881, 66.09234533002301, 66.97393724995275, 59.58545484850484, 57.62319503291961, 61.21320709105461, 59.4841714059153, 66.25866167006954, 60.47163201916603, 55.700974772053385, 52.39233393822947, 49.80755083022579, 50.556401898784024, 46.08328780820293, 52.3077166465021, 53.98847972193072, 52.753717591685636, 53.88738063073928, 53.46931480592298, 52.304253193639944, 52.87473055624193, 56.14979197902065, 54.63965200608777, 59.82736310651226, 55.96505226627473, 53.1328538925417, 53.74980349694529, 53.623801277529815, 55.62373938099031, 53.515924330680605, 53.625248632123395, 54.28566594277659, 54.703202247619636, 54.90408251362463, 58.20803611509262, 66.58610897679483, 73.55109307073778, 77.34521742789977, 76.81431678033645, 73.13026981969034, 70.5772461429719, 51.498739565572436, 1.1830977735019501, 1.8512498755608837, 1.4336582898132264, 0.027125032183023232, 1.6791553939542465, 65.83652834738454, 73.68919972450503, 71.9096988247287, 49.70771081985966, 36.306544811494895, 31.01343374098501, 45.357127651091545, 52.21790221429641, 64.29600569509691, 24.88835265559535, 0.8150157536710463, 0.14784366192836917, 0.027773989094120842, 0.05377197570558037, 0.06301117227262547, 0.08885076254486077, 0.031896223945002404, 0.05741698374491065, 0.004513064660357251, 0.18694607661135737, 0.09700522457640018, 0.12469617740040827, 0.1669467997647101, 0.2179147059758825, 0.36804769909189594, 0.12538536541884945, 0.14838956086145294, 0.07997530452426403, 0.14059588793785344, 1.2021553444285547, 71.62912384156259, 71.55102945143177, 72.99418710893201, 50.3918545476852, 56.638931151359316, 65.49341117182087, 86.8655550864435, 82.73300078607376, 2.495312128336199, 0.7408081872328636, 6.127754670958366, 8.361687160307362, 21.17150095201308, 117.79975106639247, 84.31973288136145, 100.96688378241755, 77.10274434858754, 81.37979092136507, 80.09577166649603, 92.23798628776305, 86.18076416753954, 92.69480905225201, 85.72808342595255, 89.55079401693037, 76.27694422198881, 73.58901454556373, 59.08628225326539, 62.17926333027502, 65.52730437247985, 68.22850734956803, 65.56539058685303, 64.7435598988687, 63.09437190332721, 65.94035348584576, 60.380789925975186, 62.65151277665169, 59.97529529756116, 60.30561770162275, 57.672479614134765, 62.716792783429554, 60.643133732580374, 57.15606820198798, 53.15707060598558, 54.5823932463123, 54.15666311017929, 58.84404059379332, 55.83508845298521, 55.696201247553674, 49.45898548249276, 53.15440731663858, 50.694245753749726, 55.88741679345408, 53.676612069529874, 51.623788649036044, 51.63285716887444, 54.449401363249756, 60.49256178640551, 62.51297073979532, 60.41911148255872, 58.29529708431613, 57.93612957000733, 65.82970342328473, 69.65989005181098, 68.14097573680263, 69.66377319828158, 69.26479754909393, 65.38087444920694, 73.36874208142682, 69.50076733866047, 71.77982914832332, 65.12403372795352, 67.63402508151147, 56.995549125056115, 54.85488422455327, 57.4786086236277, 55.163692428219704, 51.42196309181952, 49.861408895061864, 50.78770014547533, 52.7164315408276, 52.22293069285732, 50.77340702856741, 52.860559032809356, 69.0749469880135, 57.80506357069939, 55.74890613555909, 54.365188075650124, 57.45794949993011, 57.19847686829106, 53.79787214340703, 68.12417230298443, 62.65857304296186, 66.80816219698998, 69.72234987443494, 68.18226260523643, 61.288347936445675, 65.0487595219766, 60.7882849631771, 68.78076922508978, 69.94432464722665, 69.62859738257625, 68.45759730185232, 64.04266765040737, 56.74698068249611, 64.99650962891118, 62.65101855800998, 69.98929069888207, 63.364219204072036, 57.88138897188249, 55.208987958969615, 50.95484410562823, 54.84600005611297, 49.75225717790666, 56.22612522494409, 56.8715786933899, 55.67740132731777, 56.806035887810495, 56.209702261032604, 55.79807304566907, 56.533191896254024, 58.80240071204401, 58.918969631195075, 65.06051486538303, 58.2448201025686, 55.946322948701926, 55.547794449713926, 59.48963134519516, 57.1712399298145, 56.743729037623254, 57.57292201442104, 58.50718744339482, 58.91321943652246, 59.12987155299033, 62.56211803805444, 68.97316148204189, 74.65861351259294, 82.45592455710135, 79.63552075047647, 78.99882593462544, 72.12323265690958, 53.247504772678504, 0.9155432206969109, 7.408849798863934, 1.7242791984350452, 0.21164259092221338, 4.05527086027207, 79.80412775470366, 77.59664135594522, 81.15416049957275, 57.19766101529522, 57.30494176187823, 47.308255780127745, 46.74952199382167, 61.184177629409305, 78.18122356168686, 35.01815211388373, 1.3848083562427953, 0.43036404876939716, 0.2029353581489094, 0.13392637243434308, 0.19606566387078456, 0.18515290992875255, 0.11849602864634608, 0.09536205024849023, 0.0702315241458916], [0.07354266340694121, 0.07248736196948637, 0.0632407458408946, 0.07381485444643805, 0.09509104664527601, 0.04898038685261723, 0.036419620737433434, 0.03843771466504663, 0.05133578163241187, 0.03323435355278273, 0.3715747372517663, 41.22720918347759, 53.22753990850141, 54.8015360678396, 28.877952252664876, 35.61771385131344, 40.11078103896111, 83.76310933020808, 43.5309152449331, 0.04036162574324877, 0.07908844283872074, 0.500110286858774, 0.1386584515773481, 32.67926239198254, 100.55261873429822, 82.54461719143777, 89.51117807818999, 67.25741478704637, 73.59588653810563, 76.32895485047372, 82.94933519055768, 76.2067965538271, 79.59082141999276, 74.37857197177026, 76.20143859617173, 74.36364343089443, 71.95673588783511, 63.08204389387562, 65.10989750585249, 66.74781260951873, 65.39324168236026, 65.0722780535298, 62.88006928659255, 64.24423825356268, 60.74406808422458, 57.55652258473059, 56.638699731519154, 52.362798490831935, 52.8269874665045, 52.494872539274155, 54.75274178289599, 54.82015163667741, 46.43555587337863, 47.818085455125384, 49.27602652580508, 50.61497073019705, 56.584645548174464, 53.759421148607814, 51.396546133102916, 50.21227275171588, 50.74948841525663, 47.48946928208875, 46.58020111822313, 45.85829673274871, 44.92501581868818, 46.29513894357989, 47.12362981611683, 49.73544589934811, 49.68810681373843, 51.61935244837115, 50.576723698646795, 53.9960773529545, 56.48287573168355, 61.168719568560206, 63.996909279977125, 65.33837556838989, 56.97644325994677, 61.83292981117003, 60.56320367320892, 64.57816531581264, 62.47474332009593, 64.56911248545494, 56.259249641049294, 47.187501692002826, 43.23976162941226, 48.03586329183271, 51.98882795149281, 53.84787059599354, 51.46438744760329, 45.7041750415679, 44.37906895914386, 44.45576698549333, 39.67360934903545, 47.72551751905873, 41.40599473830193, 44.638133664284986, 55.11937749001288, 57.370994475580034, 60.526160809301565, 61.803335528219904, 58.946747856755415, 63.762469214777795, 60.93449131135018, 61.09224903968073, 60.67051972112348, 61.59170796794277, 60.632166785578576, 61.808516979217536, 58.33509737445463, 63.53210056981733, 61.0079376928268, 61.81040756164059, 60.2267780611592, 61.20180083859352, 55.82829883021694, 57.08159415952621, 60.46671728934012, 62.08580893854942, 55.31800239316879, 53.703762715862645, 54.100455545610004, 45.92387091728949, 46.37037784822526, 43.42500732791039, 44.15816107103902, 53.57670145650064, 48.70446658903553, 50.66085069410263, 48.52482203514346, 50.01454214895926, 47.35927404895906, 50.5018574191678, 48.11327911192372, 52.03147980474657, 48.26303520510274, 52.63064538278888, 49.263255288524014, 51.2542543103618, 48.56155895417737, 50.997578328655614, 50.542567699186264, 51.769818490551366, 52.831749223893695, 57.99453366187311, 59.06308927843648, 70.42243803701093, 69.6537946885632, 77.42493567928192, 71.81878612887475, 68.87366664025092, 66.90276976554625, 63.02100004688386, 8.642042490743822, 2.8216908343376654, 1.1459231424716212, 0.33646774688555353, 0.26716007881106874, 36.91351198380993, 72.98744847697597, 70.35941339308216, 47.10352766898371, 46.87512413147957, 34.99960714770902, 26.200405090085923, 43.61748587700629, 55.18321406456732, 11.293643174632903, 2.262344667988439, 0.3094677134386955, 0.15501042978177149, 0.0851963086414241, 0.10613309324628885, 0.05036969496417911, 0.0763864507297835, 0.07359853419925898, 0.057321873929111235, 0.08581175303627407, 0.01900910054363551, 0.11908188672556032, 0.02512124111695636, 0.10534694147927147, 0.020869550813410073, 0.04099604230554354, 0.035749519799625686, 0.10574726072410423, 0.08490488879502782, 1.3433873917787307, 57.38878634668166, 62.407690402000185, 66.19742562693935, 32.64708915064412, 38.166681797273704, 49.3964550572057, 92.05996559512232, 47.00622543211907, 0.0705604593179399, 0.25090229877781484, 0.8210232925991859, 3.932324657517095, 49.61101262800155, 99.25582039740779, 83.36905233321652, 90.9627688315607, 71.01787736338954, 76.11917080417757, 79.46417593186902, 86.26737010094428, 80.54466339849657, 83.30845171405424, 77.3970397826164, 79.81669502873575, 79.47387203093498, 74.49373276002946, 66.28932676007672, 69.69058652077952, 68.44815223447739, 71.04755401611328, 69.24259693391862, 67.43141112789031, 65.1074891705667, 62.84869424758419, 58.67430786932669, 58.83137526050691, 55.94750750449396, 55.98653508770851, 55.01981204555881, 57.4158428561303, 56.2346956037706, 51.84507700704759, 52.52386669958792, 49.945751620877175, 52.14552271750666, 58.19914017954181, 55.62423359963202, 53.1689553876077, 52.813922051460516, 52.44729418908396, 48.51423555804838, 48.395019039031006, 51.29177962580035, 47.10345706632061, 48.59477750716671, 49.95392584031629, 53.009530651953916, 53.100313909592174, 55.558510365024695, 54.75361254907424, 58.64879285135577, 59.78742945578791, 64.67597353842952, 68.69819548822218, 66.62264193257978, 59.83602369985273, 66.00184840540733, 62.97940723357662, 67.19400575084072, 66.41107713022541, 68.29026114556098, 56.012677684907, 49.151165716109745, 49.72359641905754, 51.475676028959214, 55.5702264847294, 56.82693427608859, 52.47829660292595, 49.18283493288102, 45.71350243783767, 47.31894031647713, 43.59478319844892, 49.33151237426266, 40.78413824881277, 45.0239223049533, 57.36519329009518, 61.112174680156095, 62.74377869021509, 65.82070550610943, 63.40880478582075, 64.22188858832082, 63.661170082707564, 62.921940588182025, 64.0900145807574, 66.44746888068416, 63.57716468072707, 64.41449265326223, 61.80207252502442, 66.05842467277282, 62.792796550258515, 65.9506614746586, 63.60212664450369, 62.15673715837541, 61.78924245219078, 60.16001539845621, 61.49014995944116, 64.30530955714565, 57.736822174441436, 55.83647697202621, 56.11666364054526, 50.1834943217616, 49.606246948242195, 46.50027890359202, 47.771413172444994, 53.486792887410815, 51.89275733886227, 52.51451184672695, 51.30220920808854, 53.67704353024883, 49.185325637940444, 53.13462680385959, 50.282079173672585, 52.95283671348326, 50.65573200102776, 54.12066359673777, 54.646618135513805, 53.578521436260594, 50.840648220431426, 53.846599748057706, 53.05143333250477, 55.180464483076534, 55.337300454416585, 62.36323425846716, 62.99663428337344, 74.65014903776108, 72.4415800648351, 79.91267542685233, 72.52833504830637, 73.09055189932548, 67.8171762343376, 67.71607322077598, 11.78985438039226, 1.0704834615030596, 2.1077049787967437, 0.04248352075416235, 0.3156373259280959, 36.47392019148796, 82.5926270023469, 73.38302735359439, 59.04094357644359, 42.74328370248118, 26.467902891097534, 35.54660128008935, 47.21598202182401, 67.36512307197818, 21.28966823700936, 2.7465073331709835, 0.34432005617887745, 0.09047120704405731, 0.05706331159378733, 0.08018986276921727, 0.05632111795186516, 0.034181023722574595, 0.06866465217523998, 0.06157450460558457, 0.2572525088344851, 0.12091437670131847, 0.22665294998836136, 0.13248995757631718, 0.2677094557833287, 0.26001974099105407, 0.14820822784977575, 0.0817414895901757, 0.22212399139760003, 0.16553021126216458, 2.416309219214224, 72.53298697933074, 73.88601641501151, 77.56253242492676, 37.712455641838815, 57.36260060341128, 59.78804134553479, 99.03822298972838, 55.37433155121342, 0.16658528287324215, 0.39189120514258263, 2.2808136382410606, 8.032033030063875, 53.67433709482993, 103.26238816784274, 87.51441709456905, 94.17650007432508, 75.6457721033404, 80.50431005416378, 83.77733968919324, 89.6687553774926, 81.14801022314256, 84.4549212917205, 81.37115386224563, 83.05075983847343, 83.78399202900549, 80.15297551308909, 70.16298109485258, 74.45405406336631, 72.6793384552002, 71.84222621302452, 71.66476249694824, 70.8047357682259, 69.69359890107187, 66.72945591711229, 62.51782271169848, 63.71772673822219, 58.236900837190696, 58.35104573157526, 57.760732943011874, 61.58519683345672, 61.057312488555915, 53.46801257902577, 54.996819111608694, 52.52285472808346, 55.63691070002895, 60.50904358586958, 57.37198291286346, 54.059953151210664, 53.131190807588645, 51.92077090663295, 50.92703057873634, 48.21491164545859, 54.49161391104422, 49.06296337804487, 52.0786423836985, 52.07622228130218, 58.06708574295045, 55.534764336001494, 57.9406677522967, 57.1786924331419, 60.34814011666083, 62.479481543264086, 67.39515273801743, 68.8768437600905, 70.20242444930538, 61.63976876966415, 69.4715456808767, 67.91656909450408, 70.911494839576, 70.20622130363219, 69.84944251275832, 57.990215132313395, 53.70464524915142, 54.90285088939052, 56.392472943952015, 59.0175780173271, 60.995648907076934, 54.88222314465431, 53.96775784031038, 48.683372082248816, 49.47240391085225, 47.56702238513578, 54.143601617505475, 48.04300200554633, 44.648673072938, 56.79157803135534, 63.16619834592266, 65.19720554351807, 68.11100098394579, 65.76353303847775, 69.2890142625378, 64.2709299825853, 66.04308820539906, 66.17222047621205, 69.26991231979864, 65.01003003889515, 68.6412662075412, 65.44742530392062, 68.34675112078267, 64.85050724398705, 70.12971155105099, 66.99092895753923, 62.0932496747663, 62.74844238834997, 64.6242178640058, 64.19782484731367, 69.48874135171214, 60.30353100069108, 59.19860716789, 59.05297348576208, 52.038504769725186, 52.777267502200225, 49.121606734491166, 49.86292685231855, 57.51218411230273, 52.4573629133163, 55.80171692755915, 53.63206571148288, 55.82571006590321, 51.43290650460028, 55.94338509344286, 53.009091346494614, 57.6308475771258, 52.64483259570215, 59.71529314594885, 56.619895888913064, 57.0572401631263, 54.4758891290234, 57.53328254145961, 56.59669899171399, 59.07268339587797, 58.80553860818186, 66.9180513197376, 65.53752214677873, 78.17042919897264, 75.72057170252647, 84.4659431519047, 76.18280733785322, 75.04779892583048, 70.53868924417804, 69.55451165476154, 11.150811045400559, 5.507690214341687, 5.616375659742664, 0.6452102202080912, 0.5163709627043817, 48.6296199214074, 86.42421783939486, 82.91513996739542, 63.898230291182, 65.84403576389437, 52.440190776701904, 44.62886902593797, 62.06946834441155, 80.03186841164866, 34.755176805680804, 3.4563188062560175, 0.5257894927936216, 0.3415343153380579, 0.20719842294291144, 0.1383298917883827, 0.2472791319052058, 0.17491780672102206, 0.23915833943793852, 0.241986230436352], [0.03174929019634522, 0.06780847231106413, 0.08346202347667948, 0.046869312833634116, 0.01779278657669502, 0.07582213504300003, 0.05225088131884414, 0.08598268257393953, 0.11464425347625248, 0.12769679058223002, 3.4958437950380388, 44.486239879362046, 47.129364321308756, 35.313557578671364, 45.953084730332904, 63.07985128894929, 45.914967136998335, 93.36854673201039, 19.709419819616503, 0.48709310471050205, 0.262525093651587, 2.6007361229388946, 5.215837926633897, 76.68156023948424, 86.3542898239628, 87.96712137037709, 84.34447519240841, 70.39569531717609, 68.51424417188092, 79.3027154860958, 83.2578609835717, 80.29227456738873, 74.7004573575912, 78.14437681628813, 78.19342213292276, 76.43064621956118, 75.12255145657447, 72.48532233699676, 71.95763018823439, 73.46923320524155, 70.70047132430538, 67.62113617312524, 66.01966381072998, 67.97464370727539, 63.072818479230335, 62.254137454494355, 55.93078644044938, 55.02214193344117, 53.57758006741924, 53.18218554219892, 52.64185943911153, 52.83685614985805, 48.94770060816119, 47.945715458162375, 49.486124361715014, 52.54798927614766, 54.46675785126225, 53.119513911585656, 49.14347394820183, 52.39030215048021, 48.57719352168422, 49.036138288436405, 48.0855675666563, 48.309911451032086, 43.00566281041792, 47.00307969124087, 46.494920945936634, 48.850480741070164, 48.797042369842536, 51.850097640868164, 48.83094733761203, 55.39617130833288, 56.22453274265413, 62.40865922743275, 61.8625319388605, 64.49088081236809, 54.08965333815544, 57.804110434747514, 65.84699323100429, 60.905724648506414, 62.44956170358966, 65.72006140985798, 53.43611978715467, 42.78255447264641, 43.758118537164506, 43.788093290021344, 48.84287134293587, 54.37011849495673, 47.9107161491148, 46.790899076769435, 45.16202503635038, 43.69205797872236, 40.766079656539425, 45.06700169655585, 38.32638109883955, 43.489432257990686, 63.89224867666922, 59.68136072158814, 59.90466125549809, 61.211869562825854, 61.606154057287405, 59.162325243796076, 58.70567114122453, 59.47758966876615, 59.13315065445439, 60.83172129046533, 62.623911057749105, 63.3488513577369, 58.86382110657231, 58.71354726053054, 61.35283954681889, 64.32275233730194, 60.60682042952507, 60.08565510472944, 59.2625771030303, 62.01228018729918, 58.78889599154073, 57.68345048350673, 50.78936715279856, 56.04738281619165, 56.06879895733249, 49.67492764995944, 46.742885343490116, 45.74063347231957, 45.0862487669914, 50.629742376265995, 50.31674900362569, 48.857521395529474, 50.319537808818204, 51.20697406030471, 48.8155794912769, 48.43173242384388, 49.10833735619822, 49.11862573316021, 48.215692197122884, 48.62232431288689, 48.63606829797068, 49.6637685068192, 48.753456992487756, 51.4473133702432, 49.54808212095692, 54.56669984325286, 58.72060360447053, 64.05301486292194, 66.68186972218176, 73.80576472128593, 70.3503684074648, 77.51201229710733, 69.18776219890964, 64.37357056525447, 64.11734565611809, 71.79227875125024, 34.000473560825476, 0.28266594354664126, 2.439595105186586, 1.117636234529557, 0.44308120024300396, 10.657994651025342, 69.75778456657164, 66.64966706306704, 56.39159433303341, 42.52716502835674, 39.034074737179665, 27.982202537598152, 39.9444019409918, 49.116433128233886, 13.239641824076253, 1.4741419303801753, 0.13182664800795818, 0.05920585650469988, 0.09936950214567686, 0.06872483604257146, 0.03105917521151564, 0.07267131500186459, 0.03722486341552388, 0.06397258580452012, 0.05876869609158847, 0.006094041746109725, 0.062339167606325886, 0.04560917863742479, 0.09972299809657759, 0.057411663264276526, 0.10667090995177146, 0.07484090664694387, 0.05625908781263617, 0.11596102072226426, 5.579802499663446, 60.38620671918316, 54.17890687142649, 45.99990606307984, 32.1319152462867, 56.86975871362994, 58.89107373452956, 98.8233712411696, 22.25671487469827, 0.7261085534288038, 0.41500974686876424, 3.7509983874136403, 11.072060638858426, 89.74557891968759, 88.37869567255821, 91.58783774222098, 86.68012895891744, 74.36704020346366, 72.15395266009916, 80.7828140258789, 84.44479373193558, 84.20712947845459, 79.61193161626016, 80.72220556197628, 81.24839936533283, 79.65263797390847, 77.59422517591908, 76.52549697506812, 75.58092747965168, 75.99803232377576, 73.80253268826392, 71.2418996134112, 69.57600624330583, 69.77207768347957, 68.53661737134381, 66.41081825379403, 59.22182759931011, 57.99720871833063, 56.39313190214096, 57.536722460100734, 56.840674338802216, 56.68383052272182, 51.50094785997945, 52.325610499228205, 51.13430823049238, 54.87015008926392, 55.743744296412316, 55.93253973991641, 50.44193537004533, 53.2684737636197, 48.33286123891031, 51.36080549609277, 48.59077668959095, 50.69001743870397, 46.50155367389802, 50.01420874749461, 49.740960751810384, 52.698541610471665, 53.93182500716179, 55.09190913169615, 52.61607377759872, 56.48192259573168, 59.18239208959765, 64.06774728528916, 66.61353418903967, 66.5618295054282, 54.693690499951764, 58.30440482785625, 69.16023500504033, 62.95969340109057, 66.51872265723445, 69.12925612541937, 56.891610237859915, 47.8684800670993, 49.58862373905797, 48.80465176797683, 52.121368761985536, 55.129297164178666, 49.1566688014615, 50.398816754741055, 47.21885319679014, 46.118961764920144, 44.199887244932114, 50.04131232538531, 42.309497018014234, 47.14014299454228, 66.9055389588879, 60.05119708276565, 62.754945678095666, 62.16009470724291, 64.39589669627529, 61.539583590722856, 62.89039688725626, 62.8807988474446, 62.03655181392547, 63.24936436068628, 63.88135233233052, 63.86656107441072, 62.13464244719475, 61.410616059457105, 64.9466916053526, 66.22779261681342, 62.93535901654152, 62.05943099914059, 60.61896408757856, 63.88249766442084, 60.35134469309161, 59.58887123292493, 52.62321641368251, 57.525453490595666, 60.30918313610939, 51.31374097639515, 50.516091700523134, 48.62397563072943, 48.35741135381883, 53.211415044723026, 52.40731739228772, 51.260985097577496, 52.404822764858125, 52.567663884932, 50.48042166617609, 52.04829500567529, 51.487490207918235, 51.24884928426435, 49.981817814611624, 51.565937611364554, 52.80528891471125, 52.69690990447999, 53.855993824620406, 54.26080203825428, 51.67699167805334, 58.21712816915205, 60.33789096340057, 66.93251702093309, 69.3242371466852, 76.65345253482943, 73.72631319107549, 81.02166283515193, 69.38406113655337, 65.53026183958977, 66.41421502636325, 73.34276814614573, 40.393576083644746, 0.7084292053214966, 0.899679807405318, 1.0948879584189386, 0.4650510390920024, 10.24754410789859, 76.79863514438753, 73.26394419516288, 63.62155806633734, 48.73066409941643, 34.042195812348396, 35.291576616225704, 52.66788044283467, 60.95486410202519, 24.827389217192128, 1.5504745634332782, 0.24561811538953937, 0.1906199585045538, 0.07248176186675988, 0.05852038018225182, 0.06931388870842996, 0.014564718059714765, 0.04920297752945654, 0.029729729210357034, 0.17088420058210052, 0.13519847675436927, 0.21539767813538352, 0.15815885196770393, 0.20759586935802815, 0.20527114490828208, 0.3594722334415682, 0.14905233416826497, 0.3054687651174684, 0.4946947806785184, 7.692811748673839, 71.48692223333543, 70.16949222933862, 50.61302915696175, 68.52402656309067, 99.00074082036173, 62.288968101624526, 112.88528011691187, 25.22565687856367, 0.7112158041807913, 0.6514108745801834, 5.495643634949961, 17.262451148802235, 95.22265895720452, 92.81989343704717, 95.55858642824235, 91.49495601654054, 81.7036767159739, 75.51485123172884, 85.4768556164157, 88.09800301828693, 85.97593015240085, 80.4204733141007, 84.81413979684153, 85.92156610181256, 83.64819172889956, 81.78027276069888, 78.90590498524328, 79.84557936268469, 82.11179933240338, 77.36316619380828, 73.31480949155747, 72.36528212024321, 76.06300246331, 70.58111359996181, 68.89719301654448, 63.108343385881, 60.57418238732123, 58.94071917380057, 59.454118205655014, 60.2587846017653, 60.16330234466061, 54.83924573467624, 54.41139359628001, 54.8427797902015, 57.831845514235965, 59.0811792496712, 58.56393629504789, 50.16472185811689, 56.60614013671876, 48.94192295689737, 53.374707237366714, 50.35523137738628, 55.035093599750155, 50.456918824103575, 53.07656788056897, 54.559816083600445, 56.4796240868107, 58.74980565040343, 58.2919434578188, 53.49288432828842, 58.65220531340569, 61.98811446466754, 66.13410288287749, 67.69846962344262, 70.90726652453023, 58.1266273221662, 61.008447600949204, 73.0951802961288, 67.68238006099578, 67.64104612411992, 71.57058638911094, 59.074609279632575, 51.94233609784035, 53.008302950089984, 53.265296643780125, 56.4468252274298, 58.59024363179361, 53.3999712236466, 55.67136479962257, 50.223475040928015, 49.05751128350535, 47.45245779714277, 51.872792474685184, 45.6399070062945, 46.441717916919345, 70.09529667515909, 65.54015405716436, 65.27919876960017, 64.86246655064245, 67.48066040777391, 63.5299942570348, 65.02598624075613, 66.04825788928618, 63.347533441359005, 67.73146460133215, 67.18629437108194, 68.61884593963623, 63.288325263607895, 64.31657852665072, 66.66496430673908, 66.97678489069786, 65.75096184207548, 67.76445173448133, 63.5055539684911, 68.39642401664489, 65.26459578544863, 63.24564987613309, 57.11864486817391, 60.83249399738928, 61.95475862872217, 55.164041519165046, 54.564750425277225, 52.15816059420186, 52.32301389017413, 55.86085058027699, 55.15978182515791, 54.33744907379151, 54.4585051844197, 56.845471397522964, 52.857119114168235, 54.034151800217174, 55.111948520906516, 53.44162287250642, 54.401379785230084, 55.05008097617857, 55.91613638785578, 57.579739093780525, 57.28207434377363, 58.123587485282656, 54.52961775564379, 61.1220080621781, 62.431291303327015, 70.79218418367448, 73.52825703159456, 83.0755570627028, 76.35838047150644, 85.18312500369164, 73.20540674271123, 68.81712175184681, 65.87655221262287, 74.61950748197495, 39.792586603472316, 0.9636868824881892, 8.855273319828896, 3.234936066212193, 0.9550243892496633, 15.719439752640264, 83.84537712220224, 80.80159433426397, 69.7171566563268, 63.672811677378995, 57.90773553232993, 43.143871445809644, 63.12413092582457, 73.48776248193556, 38.71476634856194, 2.031887524550961, 0.356929924699568, 0.2627190058269809, 0.23972576544169458, 0.1983872320382826, 0.13637256778536305, 0.37778455403543293, 0.1553992500468608, 0.10969202364644698], [0.08395887746085083, 0.006211377687812333, 0.09799178494440933, 0.05287751059738859, 0.021932078375210686, 0.044259144023301146, 0.057927956729526484, 0.18329370646707474, 0.14848850877775302, 0.2265195127937102, 6.993759091823333, 49.73976050653766, 52.47054207709528, 26.20282715366733, 35.299221315691554, 56.08642608888688, 52.186605622691495, 85.73933278360676, 6.894015669822694, 0.21326312735196085, 0.3506221405921444, 2.355315382442167, 16.271252516777285, 64.3624428010756, 80.1066444766137, 90.53122966520249, 82.82292504464426, 71.4539586344073, 69.18268665190666, 78.90830547578874, 79.31005816305839, 84.40668398334135, 72.28517947658416, 72.32555635513799, 73.79177754925144, 78.14676946209323, 74.13719715610628, 73.48275753759569, 73.07007712702598, 75.01361154740857, 71.61221842611991, 73.26417953737321, 70.13391633187571, 70.71414470672607, 67.1962022781372, 64.65470252498504, 57.734825688023726, 54.39726521891933, 52.2589772747409, 54.7128983466856, 53.32349677239695, 51.468525548135084, 49.711488062335604, 48.83947457036665, 48.2137349344069, 52.581764805701475, 51.832235167103434, 54.58731582087856, 51.07406846938595, 51.71072013916508, 48.68345052965226, 50.79481140259774, 45.098776817321784, 46.7172997228561, 43.46316806731686, 44.2633786509114, 44.98584393532046, 45.14921065299742, 48.42888478309878, 49.47924844680294, 50.46885851890811, 56.29363313797982, 57.96542967519453, 60.95483272306381, 63.225806605431345, 65.4400041795546, 61.236949197707645, 56.19963745917044, 63.60343279377107, 65.5495559784674, 62.52084293673116, 68.10002619220366, 52.35147460814446, 46.12693202111029, 38.93854148926274, 44.48557699880293, 48.89159502521638, 45.33185974244149, 47.51214842642508, 46.63989959224578, 52.36543432358773, 44.32506576661141, 41.019437313079834, 47.551862424419774, 47.11199606618574, 54.82277962469286, 59.813034688272786, 60.59648106175085, 59.54827862401163, 58.460217060581336, 61.208547315289906, 60.39840529041906, 60.420586293743504, 56.12033105665638, 59.34024395481233, 61.70788857244677, 61.12061562076692, 59.2325395922507, 63.76315170718778, 63.411307257990686, 61.42576033069242, 59.090840047405614, 59.76114565326322, 60.64229042299333, 62.01198208716608, 57.01948342784759, 53.006059354351414, 47.321148610884144, 54.32707440468573, 60.2666058078889, 59.665259392030784, 50.145623837747884, 46.96016503918556, 46.32280734277541, 42.97842979431153, 47.72958109455724, 51.82578286816997, 51.26265602727091, 50.0316515276509, 47.48913195825393, 48.91942816395914, 47.976133438848684, 48.70894985814249, 48.09041561618928, 49.32831564257222, 49.05674642132175, 49.643254510818, 52.92526637354205, 54.01166092964911, 54.1347292161757, 57.03995820014708, 61.194324801045084, 63.66699088004328, 69.938550918333, 72.05506970805507, 73.17347080476823, 75.03290960865637, 71.92447047079764, 66.6293570303148, 67.8816286210091, 74.01226966611802, 71.74950138215097, 70.92538002998599, 5.789196270127451, 2.3323452472686768, 0.22200604450077782, 0.02195006228923317, 1.0716433799074543, 57.75798336152108, 68.39497273968112, 61.58158825289819, 40.498813275367986, 35.732427489372995, 39.77326893037365, 33.47680184148973, 39.32107456268803, 17.602781480358495, 1.286431267376869, 0.06396761389389154, 0.036374593919683854, 0.032292739563291116, 0.01300822945326687, 0.03551514669051094, 0.03977122093220392, 0.05738993318030431, 0.029598400672717445, 0.04433400613526183, 0.050172959754784266, 0.03551656012273124, 0.03834478053895216, 0.06580789498383961, 0.08338943664585391, 0.06983177946700204, 0.07389310266702406, 0.20523090997049886, 0.3306385838697034, 11.439352362386643, 66.52153891901817, 61.7859947296881, 31.299127417225993, 29.88416767889454, 60.149291638405096, 58.71367669874623, 92.56329198037425, 7.145845072884714, 0.24451337063745146, 0.26473461379927976, 4.310924574252098, 26.063885035053378, 73.574384104821, 84.36529513328307, 93.27920298422538, 84.74749872761389, 73.95252412365329, 71.45271916543284, 83.47134774731052, 81.165205893978, 87.48002575289819, 75.9026873496271, 74.36460048921647, 78.53088717306815, 79.97897132750481, 78.06080679739676, 77.64908344514909, 78.71388927582773, 76.7695233129686, 75.07014859107234, 75.02336255965695, 72.77391464479508, 72.94114881946196, 70.3056533875004, 67.54748190602949, 61.84759555324432, 58.223800120815156, 55.605131656892844, 57.84229078600484, 55.703257591493674, 54.40892642544162, 52.08154101525584, 52.878052803777884, 52.351780553017896, 55.265493623672, 53.60450713865219, 55.91427326202393, 52.024458762138124, 51.46259884680472, 48.997597079123224, 51.86598716243621, 46.97763919830323, 49.713967000284505, 45.422015420852176, 46.619781755631976, 46.894641845457016, 48.75666156891854, 52.324574993502715, 51.695438584973736, 52.84015486317297, 60.04868284348519, 59.76338140426144, 62.300488102820616, 64.60706141687209, 65.7011555856274, 63.8675416669538, 58.095797492611794, 65.88845268372567, 68.34897902704054, 62.698714579305346, 71.00346657537645, 55.43720714507565, 49.52321037169426, 44.584134394122714, 49.39483119595436, 50.92640299950877, 47.72474873450495, 50.163560836545884, 49.628141618544056, 53.31217288970948, 46.396128208406516, 44.678016324197095, 52.19917681909377, 51.162447314108576, 57.647847129452614, 63.1576632684277, 62.68120511885613, 63.16475883606942, 61.244742947240034, 63.861787549911014, 63.15191307375508, 59.75315186285204, 59.3923879438831, 60.28359751547537, 63.19109755177652, 64.49981597162062, 62.345379629442775, 64.44905657922068, 65.34554173869472, 63.86336826509046, 60.651049075588105, 62.08272987796415, 63.47225304572814, 64.79646875012305, 58.034584983702636, 55.236534764689786, 49.18434112302719, 53.75642053542599, 62.535591048579064, 59.57418587899978, 53.26228818585796, 50.40665757271552, 47.8305232909418, 46.668670177459724, 50.36814381999355, 54.767497739484234, 53.133869786416334, 50.9707885403787, 51.78812811451574, 52.33107436087824, 51.05263663876442, 50.96896856061874, 49.92422565337151, 52.40534444009104, 51.27301108452582, 53.70586118390484, 54.921795937322806, 55.98143992885467, 57.32200407212781, 60.357291006272845, 64.598659699963, 67.0154280816355, 73.84760072154384, 74.16302988606115, 74.3600897635183, 77.88864612579346, 72.04806435492732, 68.48542259585473, 68.96548932598483, 77.40067974213632, 73.34787507211009, 75.99603975972822, 8.880014650283321, 1.3432937451908666, 0.4669219483771632, 0.11725832167412005, 0.8263870112357602, 57.59182391628143, 79.11701479265767, 67.94512394935855, 51.64954293158747, 33.81990332757273, 37.82998554168209, 49.1671101508602, 51.982187378791075, 28.37650272154039, 1.784204802205486, 0.040722947282296036, 0.08811891875079564, 0.016517022271610556, 0.04503708715820986, 0.03759922760148202, 0.10803538149282818, 0.04376910439121627, 0.046760677735531525, 0.16636094168549584, 0.1587798275173672, 0.16899588577930005, 0.1439229311842111, 0.1136320215019007, 0.16116326494563013, 0.19963679805157647, 0.34179990269964744, 0.39971002107185705, 0.6270521590786596, 14.450347077461982, 79.80437094165434, 75.46454291189872, 39.65977514943769, 59.66649101626489, 80.45969701582386, 63.78797638800837, 103.05585184404927, 8.508824090803824, 0.38476499398389175, 1.164912562216482, 6.898765169805096, 31.664629559363092, 78.90086081720169, 88.14216106168686, 98.46176009024344, 87.26376195107737, 77.55187142279841, 74.88529512959143, 86.45271778106691, 85.40739828540434, 90.59424646439092, 77.01984897736581, 77.10028110011932, 82.25031391266855, 83.0004358291626, 80.71228196544033, 80.93267210068242, 82.03003360379128, 80.8508514588879, 77.9506431087371, 80.15664685157039, 77.35729048329016, 78.94559152664678, 72.90269390229257, 71.09751716736825, 65.37017422337686, 59.41516122510357, 58.26456139164587, 59.831807151917495, 56.99554128031577, 57.736076924108694, 56.17910385131837, 56.75943420779321, 55.0020750876396, 57.48803800152194, 54.48611474806263, 58.72461226678664, 52.54937387281849, 52.3481249040173, 49.8047306460719, 53.26405717480568, 47.04349187112624, 52.01813982379053, 48.967167331326394, 49.6406186780622, 51.31066191580988, 51.32514330648607, 55.734067809197214, 54.994053840637214, 54.43943069827173, 62.51200583673293, 64.38658891185638, 67.00217831519343, 66.91526643691525, 69.13656742342057, 66.6119573962304, 60.62445540581981, 67.5132082354638, 71.63274026686146, 66.55136462180846, 72.28894495194959, 57.30287467279742, 53.62436609883463, 48.09229443150182, 53.03293151240195, 53.13580351491129, 51.15132739467006, 52.06207821446081, 48.593467435529156, 55.28019858944801, 48.211911032276774, 49.35550159023654, 55.035360320921875, 55.84417658467447, 60.88865057114632, 64.05564285093739, 66.63421292458811, 65.97699626799553, 63.65871075660952, 67.04071167976626, 65.76823203794419, 64.0819658771638, 62.2288263997724, 63.02905267284763, 65.46803735917615, 66.69657861032795, 65.58146053744902, 68.25300647366431, 65.46021223068237, 66.81399868380639, 63.420360088348396, 66.76350993494835, 66.02944620193975, 68.49233381209835, 61.63772129243421, 58.99559313251127, 51.7147562580724, 57.924213409423835, 63.134470293598795, 62.776177467838416, 56.07232909048758, 52.562866826211255, 51.38887397704586, 49.909826632468935, 52.31438859816521, 58.454784577892674, 56.96767676261164, 53.75584394701066, 53.76791700240105, 53.98297271420879, 53.70830089815202, 53.33356941899946, 52.99226045608521, 55.35023250887471, 54.371809036501, 57.29961126081405, 58.758164221240634, 59.760212129162205, 59.40941103043095, 63.415582641478515, 66.9758435218565, 69.14285890517696, 78.94230458044237, 76.59411491886263, 79.71276790865006, 82.28588981013145, 76.11918649365826, 71.87850813711844, 72.51572070583221, 79.36726200965144, 75.62010411293276, 76.01882088568904, 8.181877866868051, 5.4672731314936, 1.46011050910719, 0.11592569640807568, 1.5195670219198352, 70.592817952556, 82.94133355540615, 78.01740184906991, 55.79128342290079, 53.90778872274584, 54.773624481693396, 56.12204513242168, 67.00773239135742, 44.50817377336564, 2.550506985956623, 0.22620927782789355, 0.12676845289646618, 0.13822525949968448, 0.2717949107529656, 0.06551822181791067, 0.12827962261414336, 0.19052674092592733, 0.10292390496620249], [0.03622302725430458, 0.05240182745300474, 0.03558473045667333, 0.01518846014439459, 0.04063501954078674, 0.07338985950956423, 0.03089428244669351, 0.045645383952726284, 0.1660974840483358, 0.2619098024743219, 12.070706871248062, 54.50370657828547, 44.07739946919103, 35.678353694177446, 29.8963858619813, 45.76603866392567, 61.98274866227181, 73.49536403532952, 1.1456037144507132, 0.023263227006781007, 0.6458022529559752, 3.7417273752151, 46.43424580174108, 73.96021196919104, 84.59389086692565, 88.13087248033094, 81.59189701080322, 65.46885713454216, 72.01677953043293, 80.21820452905472, 83.86197659277147, 77.56177932985368, 72.24313166833693, 76.7370068642401, 70.5931866553522, 73.73523266084733, 77.936459818194, 77.23520278930664, 74.5832569368424, 76.5759543449648, 72.83022419098886, 76.75968600857642, 72.56933166134742, 69.72857075352823, 68.40812836923908, 64.67687568356915, 58.13862977489349, 53.92257605829547, 54.58194609611265, 54.746881761858546, 53.760990096676736, 51.865410574020885, 47.00060075329196, 46.740943770254816, 49.22746758307181, 52.816793226426654, 54.568884603438846, 51.55877144105973, 52.378809605875325, 52.2720976029673, 48.155534805790076, 48.948677278334095, 46.02077307239656, 46.61986804777577, 45.42714195866739, 43.100403739560036, 44.776142258797925, 46.28150086249075, 46.89650497128887, 50.03441287625221, 50.150507188612416, 54.418846099607414, 57.325738168531856, 59.36974410087832, 63.25739345242901, 66.83799574452063, 65.90061203125985, 65.22010434058406, 63.665857315063484, 61.25290147719845, 61.60495381201468, 65.57772251867479, 52.78510047543434, 42.65810943418934, 40.06917645854335, 46.70688975241877, 54.248395581399244, 46.823988191543094, 47.0017578524928, 50.21040178114369, 51.34114657678912, 50.001531647097686, 41.54360325105729, 52.66574667346094, 49.0670112640627, 55.897277632067286, 61.7140898396892, 62.31304753211237, 56.757614228033255, 57.147423298128196, 53.268003079199026, 54.22937600843368, 54.456606757256296, 56.63580502233198, 58.54910581342636, 58.57609956495224, 62.27627531174691, 61.918786571871856, 64.26450121787288, 58.937549898701334, 56.805106286079656, 59.744326529964326, 63.414249035619925, 56.143892734281486, 56.18441474053168, 49.144230965645086, 46.94262027740479, 50.44890149947136, 50.5203749287513, 48.92057349604946, 54.856547309506325, 56.593596396907685, 47.890876800783225, 47.44436202510711, 42.83053290459418, 45.32162627866192, 51.90300256975236, 50.53537014992007, 50.66170184843002, 49.420479574511134, 50.64815398185484, 48.174805410446666, 48.957388862486816, 48.64819234417331, 49.392897467459406, 50.45670701611427, 52.91580561668643, 57.423691518845104, 59.620010929722945, 60.11935218687981, 64.70576001751807, 63.19920116855253, 69.13466899625718, 71.57705045515492, 75.10051558094641, 72.3562136004048, 73.31115384255686, 65.30221131540114, 70.80301777009042, 74.4808203174222, 78.86258632906022, 72.02475763136341, 83.99180704547514, 34.69340732020717, 0.7254345799165388, 0.43438907472356675, 0.14331931518691202, 0.10173505142090783, 31.61121472235649, 74.67477367770287, 61.847066033271055, 49.959511295441665, 36.08033780128726, 24.851180353472312, 22.43993466900241, 29.421139724792976, 23.911796231423658, 2.962399735566109, 0.09544881736679424, 0.08929743010911251, 0.0621910521670455, 0.06350737125162156, 0.040812614043393446, 0.0203655683811033, 0.029793620943242026, 0.037462281724137646, 0.08549876015393004, 0.010738330085821932, 0.09873536520547445, 0.02511460104987266, 0.016332622993016438, 0.02155859327514566, 0.06083745141363433, 0.05952004065376617, 0.24253618963543447, 0.4601999864943566, 19.477601858877367, 66.52645757121425, 56.95990262493011, 50.31952211933751, 34.081042966535016, 56.84542825145107, 72.3233441383608, 80.2456924992223, 0.9402775031424339, 0.07629355490808526, 1.4183017202923376, 4.719325188667544, 56.72727469475039, 81.59459560148179, 86.63263690087103, 90.67226240711828, 84.00936357436642, 68.92715207992062, 75.37775654946604, 82.76623895091396, 87.34193478861164, 81.70062511197983, 72.42967959373229, 75.75911291183965, 71.6926819278348, 74.12386894226074, 79.02800836870748, 78.96157910746913, 76.83745091961276, 79.5918647704586, 78.18218846474925, 78.92400280121835, 74.13546346849012, 73.25268699276832, 71.23528649730068, 69.55147574024816, 61.45916715745003, 58.22109760776643, 57.17466023660476, 55.50857074799077, 58.34899825434531, 54.29780175608974, 48.57934298053865, 49.95568698452365, 51.37002698836788, 55.005926855148815, 56.034897911933164, 54.90398445437032, 50.54250494126351, 51.39798564295615, 46.787992600471746, 48.66359549184, 47.6913889761894, 49.162685717305834, 47.89049240850633, 47.030579428518976, 46.30359557367141, 49.06146503263905, 50.42166848336497, 50.78225197330598, 52.80278252017114, 57.108595755792436, 61.915417255893836, 63.889655989985314, 66.84452256848736, 68.4700704390003, 65.60328460508778, 69.69345769574566, 67.11236553807413, 64.72345775173557, 62.47009923381191, 66.4020949025308, 55.94721332673104, 48.65200096561063, 45.218777810373616, 50.751492746414684, 55.16178223394579, 48.45553728841966, 49.37576455454673, 52.43876303395918, 53.710889662465746, 52.713054380109234, 46.61783233765633, 55.82969519399828, 55.11561201464746, 58.483523784145234, 62.27110955022997, 62.05932117277577, 59.240858939386186, 59.25034715283302, 57.369311778776115, 58.19770459205874, 54.57608607507522, 60.41897419960269, 60.74075368142898, 61.76548857842723, 63.448801194467855, 64.6851989530748, 64.64586934735699, 61.529350126943285, 59.98435205028903, 63.64844591386857, 65.07367833968132, 57.58603449790709, 56.27433507673202, 50.77565454667615, 50.799396653329175, 50.52091229346491, 49.38272283923242, 47.143826100134085, 56.08648884680964, 58.055236262659875, 50.92743458286409, 50.04940809742097, 45.41476295840356, 48.54612834991948, 53.3363268452306, 52.31662042679326, 52.961701270072695, 52.7570241497409, 52.72211897757746, 50.943732030930065, 52.25984411854898, 52.31052506354548, 53.499717097128595, 54.392158292954974, 55.92310643965199, 59.55564091282507, 63.70645384634695, 62.664770387834125, 67.51206290337348, 67.09115336018225, 72.0093584060669, 74.33831276432161, 75.06014654713293, 72.6117560171312, 74.1507528674218, 67.75068421517649, 74.7606029818135, 77.78453857667985, 79.39500101151006, 74.76766324812367, 84.53701649942707, 41.016954452760764, 0.41102835728276166, 0.3611468403570114, 0.539581343050926, 0.07665580724396052, 30.790266567660918, 82.67141172962805, 67.2372773385817, 61.71516064674624, 37.396810746962025, 28.37977593944919, 38.278889040793146, 42.01022409623669, 30.625399543393044, 3.7574600019762596, 0.15287793211398587, 0.015505447217653838, 0.09763356989189502, 0.071735002340809, 0.09769554640496932, 0.02623988844965014, 0.061844347585593505, 0.05578724659919258, 0.24645180291225835, 0.1747452837204741, 0.1524803171595258, 0.11786266545494718, 0.144455898553133, 0.24727729329418754, 0.16809847506303943, 0.19578375883640783, 0.23119107099069705, 0.509319031430829, 22.932858928557366, 81.34474062150525, 61.52435302734376, 53.63803948125532, 46.16590469114242, 67.06062947550129, 77.39240354107272, 90.2245238519484, 1.514659769112064, 0.11592548956433613, 2.563357896381809, 7.904089727709371, 60.00764308437225, 83.56777529562675, 91.06774714685257, 95.70601263353902, 90.21253708870181, 73.82637285417127, 79.77247422741306, 89.7791700978433, 87.86725782578992, 83.80980122473933, 76.41624327628844, 75.68162256671538, 73.76059470638153, 78.2138341472995, 83.97996933229508, 82.9018117535499, 79.5477302612797, 84.38800565658077, 79.41025118674003, 83.9043225011518, 79.66392655526438, 77.51373813998315, 75.02763009840443, 70.99487658469909, 63.537956668484604, 61.36074312271611, 59.60069717899446, 60.349752210801654, 60.88095095849807, 58.76025876691265, 52.8150438493298, 54.61364669184531, 55.0348033443574, 58.30001177326326, 57.811453111710094, 56.24907893519248, 53.96598100662232, 51.628671999900575, 48.418851360198, 50.29080644730599, 49.20859706017279, 51.45997478115944, 51.51859852575487, 51.66754268830823, 50.7463897428205, 53.68577864862258, 52.53219781383392, 53.86863170131561, 56.18848223840037, 60.43176897110478, 65.44231837795627, 65.43854113548034, 69.16023500504033, 73.52390320070329, 70.75332134000718, 68.45157254126765, 70.24785334064116, 66.61803706999748, 66.71655916398572, 69.39704418182373, 57.6330009583504, 49.7351360321045, 50.092295292885076, 53.81469518907609, 57.94051477985998, 50.64692627999091, 51.323723408483694, 54.09010833309543, 55.335284356148016, 54.269482243445616, 49.927689106233665, 61.289489346165816, 56.46897092942269, 61.84683853580106, 65.45010036037814, 66.20923980589836, 60.76355441924065, 63.79555048481111, 57.747910714918575, 58.702913714993386, 58.13817870232367, 64.30419952638688, 63.29606802232804, 64.0384824814335, 65.74596474247595, 65.33179383124074, 68.40834802196872, 64.29413472452472, 61.96725922246134, 66.07179995506041, 66.98506893650179, 59.93377700928719, 60.503807221689534, 52.822731694867535, 50.64667524829988, 53.77516554247949, 51.90175525603756, 48.99101534197408, 57.44092249101209, 60.39032128549392, 55.10877532343711, 53.72939148256856, 47.71468785501296, 51.98965164922899, 58.712343092887636, 55.21893508972661, 56.09196839794036, 55.855508312102295, 56.54853228599795, 53.026722400419175, 55.67983711919477, 54.28315170349614, 56.26180310403147, 57.71118948536535, 59.1510013611086, 63.58762956434681, 66.71553934774091, 66.11853107329338, 71.10298495138846, 68.93851910868, 74.49893382287796, 77.8444645481725, 78.19977637260192, 75.89715680768414, 76.83275976488667, 70.92574873278218, 78.11659074598744, 81.64743777244323, 84.54057801154353, 80.18185984703803, 87.38573981869607, 40.642368101304584, 1.4402201699633754, 2.1856711564525484, 0.9143820765518373, 0.22390539096968792, 41.33165405642602, 87.0399122853433, 77.72706016417473, 66.92726888964253, 60.25197928951633, 38.97159922507502, 45.01422620588734, 61.12548328215077, 43.52463553028722, 5.201173655448422, 0.3452933862084343, 0.24635751281053792, 0.1735386645962154, 0.21833967026923934, 0.22235086067549645, 0.13895549450910863, 0.11000968200424988, 0.10843058327032674], [0.03439506485817894, 0.03183244521008625, 0.07353732377410897, 0.036059325756204706, 0.07513028869946158, 0.04504882362520984, 0.08593824181345203, 0.016529944259673357, 0.20834746289878123, 0.23406888027825665, 18.281904574363463, 61.74988931225192, 41.576759046123875, 19.218807797278128, 38.77197803989534, 48.08222962963966, 68.06318729154526, 54.726932587162146, 0.09725510713554199, 0.32995302710802327, 1.4051034349587657, 5.887305044358777, 86.82883385689028, 87.15360610715805, 83.97787478662308, 83.32104252230737, 73.10368399466239, 66.94553928990518, 80.02051707236998, 83.2552251508159, 83.15223939957158, 71.7302974577873, 79.4555231832689, 78.04310121843892, 80.7603859132336, 75.56497127779069, 74.90398130109234, 74.68787439407842, 72.2701411093435, 72.05085708249, 72.1646293517082, 70.3712511062622, 70.43532694539716, 67.85171662607502, 66.1462857646327, 62.76219814054428, 61.076975330229736, 54.58003982420891, 52.09638326398788, 53.83234193248134, 54.86712201949089, 50.387908643291844, 47.058181147421564, 45.162813432755016, 49.896721993723226, 50.97842931747437, 50.629495266945135, 53.21974615896902, 50.03809205947384, 50.038260721391254, 47.533297846394206, 47.62965086967715, 47.38928018077728, 44.51843861610659, 45.60010671615601, 41.906202839266875, 43.684566251693234, 43.84943131477603, 44.47037389201503, 46.901576595921675, 48.61458155416673, 52.95021264783798, 57.98641043324625, 61.832427747787975, 65.2367469572252, 64.16563787767964, 64.061734291815, 63.94928386134487, 65.26115586680751, 57.881640003573516, 59.7800632446043, 62.63169304017098, 54.272620139583466, 50.945763818679325, 49.817780371635195, 52.827434616704146, 52.439249407860544, 46.303199414284, 44.85917491297568, 43.16949236777521, 42.47036518589143, 45.158432145272535, 44.64696291954287, 50.41269410041071, 55.947342764946725, 58.06889003322971, 58.63499787545974, 61.66770781240156, 55.3930373345652, 50.52648598147977, 51.41439291738695, 55.93986280502812, 55.62899535702121, 56.873139796718476, 58.82512300245224, 62.57604637453633, 61.67512501439741, 57.58552851215486, 56.26174426847889, 57.94018137839533, 64.56039305656188, 62.51647733872937, 54.74495980047411, 54.02376928637105, 45.50772313148745, 47.887170160970385, 49.12770994247929, 45.38641206679806, 47.482828709387014, 45.87123270957701, 51.5484752193574, 53.8361309420678, 46.581632783336026, 48.56115887241979, 46.85730480378675, 44.424446859667384, 50.60206220995996, 52.2417776815353, 51.51638238660751, 49.99482047173285, 49.73741885154478, 49.81297939054428, 49.41125023749567, 47.94149106548679, 51.40710907597696, 54.949232916678156, 59.09457414380966, 62.11150046317809, 66.48960298107517, 66.76119573654668, 68.10611371071109, 70.16815077873969, 69.93543655641618, 71.75884446790143, 72.11988295278242, 72.33075741798648, 72.59464663843956, 69.30617070967152, 72.59467801740094, 72.80184192042198, 74.18839977633569, 75.25509618943738, 75.86907263725035, 79.84146087400376, 4.877518300087222, 1.2612001309471748, 1.1173503918032492, 0.5800342788138698, 11.738266387293416, 68.67803450553649, 64.92533429976433, 50.88060932774698, 38.66025717027726, 21.141465402418568, 22.043330092583936, 26.503206183833463, 19.02898665397398, 2.523441651175099, 0.07505299042790167, 0.055805437356954625, 0.08464145414050549, 0.017455476148414518, 0.011519601872761645, 0.010446917900304881, 0.11665967758744956, 0.0190875785905988, 0.05867045297617874, 0.03621889804039271, 0.042493070040138504, 0.07214498195436693, 0.1324582262144935, 0.09382756081439796, 0.1057833894306133, 0.0374550421932532, 0.1794073424271999, 0.404267049124164, 24.967588455446307, 71.68922239734282, 55.256060323407574, 25.958787087471258, 39.97718118852185, 59.07699015832717, 77.02679941731115, 59.18986420477591, 0.1174818125042704, 0.14203804845531143, 2.9297656157324394, 9.884430689196433, 91.94454593043174, 89.82002550555815, 84.59237683203914, 85.52324156607352, 73.65713042597618, 70.17185349618235, 80.86674490282613, 86.92592036339545, 88.62151392044561, 75.84283198079756, 81.71658915858116, 79.30593967437744, 81.82685482886531, 79.02188947123867, 76.35350888775241, 77.82178540383616, 75.3733007369503, 75.27187608903455, 74.78493736636254, 74.425138350456, 73.40660079833, 72.08583677968672, 69.77535678494361, 65.56955222160586, 63.95374359623079, 57.232393603171076, 55.66854069309851, 55.84022675791095, 56.00438579436272, 52.63588174696892, 51.650954984849506, 48.507371410246826, 52.48383891197943, 53.06289842051845, 53.28761100769044, 52.681836235907774, 50.74030614668324, 50.13372336664508, 48.27144084438201, 48.2487734671562, 46.51692152023316, 45.49326919740247, 47.56776763546852, 46.927911389258604, 45.466036181296076, 46.81815170472669, 48.270577922944106, 49.84581747362691, 49.81636831837316, 55.50532302548809, 59.46954488754273, 64.0884142537271, 66.5020525840021, 65.41808205266153, 66.80124313600602, 64.03449735333844, 66.8988395506336, 60.787971173563314, 62.781617795267415, 65.19783704511582, 55.00479329016901, 55.937811405428, 53.253137296245946, 55.70179846978957, 54.739805806067686, 46.903910406174205, 46.2036535816808, 43.670029947834635, 42.99894379031274, 46.50161250945061, 44.672419101961204, 51.09007958442935, 56.48098122689032, 60.73027703069872, 61.20094183952578, 64.25658587486514, 58.09056505080193, 53.636443076595185, 53.427623933361424, 56.07435695586666, 57.536722460100734, 57.45319166491109, 61.59902711068431, 65.13033697682043, 62.95289593358194, 57.737736086691584, 57.711813142222745, 61.09197447376867, 66.71545305559712, 61.178439201847205, 57.52394337807932, 57.45315244120937, 47.106190958330714, 49.17151497256372, 50.10348189261652, 45.74475588337068, 45.76597590600291, 46.696001252820416, 50.26772329884191, 57.07380825473417, 50.35301131586875, 51.36985048171013, 48.843098840405865, 47.50390752669304, 51.92825478892173, 54.005165484643754, 54.3245287864439, 52.85839780684441, 53.27295703272666, 53.83060040012483, 51.5088043674346, 50.132731006991484, 53.75493787950086, 57.66554878604028, 61.19598788599814, 67.1390768789476, 66.25736728791269, 70.25751021600539, 70.24486449456984, 72.60645297265822, 71.35826064694312, 73.67558910000709, 73.32072442577731, 72.06871955625473, 71.13267729359289, 72.65731042431247, 75.03902850612518, 76.74445152282715, 76.86919073904716, 80.23933825954315, 76.69846565492692, 86.647887076101, 7.273982532562749, 1.426985970427913, 1.3581446966817303, 0.641998166759168, 10.7751166243707, 75.6766882250386, 73.50293420976209, 60.727048920046904, 46.738213800614886, 17.206829978573708, 30.118168438634566, 41.32312682367141, 19.498286477981075, 3.8305492026190606, 0.14465293636725796, 0.061141737706718914, 0.07848368537041449, 0.0382858875297731, 0.05227135884906015, 0.018850855506776322, 0.055886255802526597, 0.0045383130031217255, 0.18990738948266353, 0.15577693139353108, 0.16850902158166134, 0.13070924748336116, 0.14198730279120708, 0.17179423642735328, 0.24230591892715425, 0.10338548060146072, 0.400058192711684, 0.5180642621651773, 31.434633539568996, 87.89703646013814, 55.31156186134585, 29.597161969830914, 55.59523943931826, 68.6452199566749, 83.27382503017303, 67.27130782219672, 0.22191869515565135, 0.4573422027451377, 5.496127557369971, 11.054911055872518, 97.43507969763972, 93.01543143487747, 89.44947919537945, 90.60598219594648, 79.00313269707465, 74.18003728312831, 88.47089490582867, 89.26207619328653, 87.15476712872906, 79.5900369459583, 81.78647795031148, 84.1815399354504, 84.77683805650281, 81.8037599132907, 82.12456272494408, 82.53063786414363, 79.42929037155645, 80.16649984544324, 79.14507542887043, 77.99755465599799, 77.19839526760963, 75.30697345733643, 73.50404031815069, 68.6279615279167, 66.7379988393476, 60.568753827002745, 57.896278289056596, 59.634951237709295, 60.11158197156845, 54.98107079536685, 53.487844082616995, 51.00362270109115, 57.44877899846723, 56.280873667809274, 53.94054443605485, 56.59602434404435, 51.409101640024495, 51.18988037109376, 49.77810559734222, 49.72857390680621, 47.385950088500984, 47.14652861318281, 51.183094670695645, 50.44641079441194, 50.41743624594904, 50.93391433838875, 49.84916717775407, 52.50681223407869, 53.36637612312071, 59.03507963303597, 63.693690453806234, 67.63711590920725, 68.22613823798396, 69.88268067759853, 68.99642113716372, 68.69238253562682, 70.33128999894666, 64.25123183957993, 64.81928909978559, 68.99020810281077, 57.87699983965967, 60.019947559602805, 55.4916496430674, 58.858765171420195, 57.19846117881037, 47.06690057631462, 44.80738393722042, 42.55448433660692, 43.67645871254706, 46.275025029336255, 47.90637800770421, 56.050120630571925, 60.6916848305733, 64.21528723932082, 66.74196827796199, 68.69581068715742, 61.160557116231615, 56.27284457606655, 55.578514452903505, 59.998162715665764, 59.715924647546586, 60.476436922627116, 63.26509306507727, 68.55511526907645, 65.59904844530168, 61.640490485775864, 61.08986031624579, 64.24801157366845, 69.58903635701826, 66.07024669647217, 60.65845451047344, 60.31158754902502, 49.19200151197372, 52.1704964483938, 51.47760975745417, 46.807443634156265, 46.933469387792776, 46.5890186063705, 52.22243255184543, 58.503931876151796, 52.17752141337241, 53.88093225417599, 50.830685400193744, 51.18822120851087, 53.982627545633626, 56.19717421070222, 56.24154798446163, 55.747278351937574, 55.376057394089244, 55.33941461193947, 55.477713461845156, 54.28421466581283, 58.80627209140409, 61.526926102176795, 64.61696147918701, 69.20353797174269, 70.61772500315021, 72.85520184424617, 73.073105196799, 76.66932244454661, 75.47723570177632, 76.25180182918426, 77.22283947852351, 75.89193221061461, 74.4100764489943, 75.05067010079661, 77.2545636084772, 78.534025069206, 83.05862811303909, 82.57881241460001, 79.75524717761625, 87.53360532945203, 6.617208613503364, 3.6649781129052563, 3.827778538388591, 0.7195084914565087, 16.382139882733746, 86.53769200847995, 80.77379257448258, 69.49482102547923, 57.4019145196484, 38.60539105630691, 44.112061454403786, 61.71272485486923, 31.21101333249, 5.561646828728338, 0.2470541472036031, 0.20423019995852826, 0.2572219572480648, 0.1449417668364702, 0.20116823845573012, 0.262937126380782, 0.1864603155803296, 0.06627135519539157], [0.06615087254753997, 0.014408992494516557, 0.008659405904191156, 0.08750017251699202, 0.08423282284169428, 0.03697743999861902, 0.03591014545470957, 0.04236661956735677, 0.04665256357721744, 0.23405311418877495, 20.615518708382886, 57.91587837280766, 36.81374649847708, 49.95442398132817, 58.991658995228434, 44.03731676840013, 79.3053513188516, 36.15816939261652, 0.6741367809234128, 0.4199792979465377, 3.2511678145777796, 21.937047589209772, 99.23166644188666, 76.39824744193785, 86.2064007789858, 72.14711204651864, 68.23354367286929, 74.92317738071566, 80.82320659391343, 81.20245272113432, 75.81899965963056, 79.55819514489944, 81.88569822619039, 78.99331108216317, 78.97485240813225, 71.7060415206417, 74.4543678529801, 73.83177788026872, 71.29028597185689, 68.3429071980138, 68.35858883396273, 68.75792534120622, 68.751296535615, 68.70090976838144, 66.42827280106084, 57.79279047443021, 54.78079849673856, 53.22815572061847, 51.55309184905022, 54.84414477502146, 52.68233829928983, 47.37080189489549, 50.094582034695534, 48.16202240605509, 48.39299901839226, 49.61091849111742, 53.267579463220414, 50.9494508466413, 48.14734881924045, 50.14554539034444, 49.101532043949256, 46.81828898768271, 47.23358561915737, 45.37098146254017, 45.88661624539284, 45.566715578879084, 42.18684450272591, 42.23230477302305, 41.98310090649513, 45.67802067725889, 47.77022469428278, 49.96142541208575, 54.93532026967695, 61.626817103355165, 65.29721813817179, 63.34809041792347, 65.5371573663527, 64.67755425360896, 65.24033592593285, 58.99767591107277, 58.6950768193891, 59.86846562354796, 49.105187692949855, 45.09393661252914, 46.92136887581118, 51.21133965830649, 59.276015143240656, 59.025265862864835, 48.89912205357706, 41.53235389340309, 43.13567761451968, 45.36701986866613, 41.00849390029907, 46.98398559324203, 55.34685142578618, 61.416644742411954, 58.444743310251546, 58.64731804017098, 55.105837468178045, 51.25212054098807, 55.265093541914425, 53.82614458760908, 57.087544395077614, 58.53159243060697, 61.04552184381793, 56.37097835540772, 57.16344618028211, 57.792661036214525, 62.87922205463533, 62.23574938312654, 61.15642686044017, 56.865867722419004, 52.59514793272942, 47.673051895633826, 47.62511268738778, 50.05890807797832, 47.672216430787124, 44.03129593018563, 45.09552517244893, 46.56979899252615, 49.16293282662669, 49.22917381409676, 48.75868943429763, 46.4068558908278, 46.56182089159566, 43.72364482572002, 48.90142840723838, 51.650598049163825, 52.677643222193566, 51.43490299101799, 50.068619866524976, 49.78487560825963, 48.90675106356221, 52.562278470685406, 51.26402101209087, 55.56873598406392, 61.6019885001644, 64.29524083291331, 66.2572103931058, 70.70335034401187, 71.15820407867432, 69.49510343613164, 70.00062634868007, 72.75085895292221, 68.3163998203893, 70.59769738105037, 71.88452505296277, 72.48442019185713, 72.0607179211032, 76.54040198172294, 68.55076143818518, 77.89052101873583, 74.5487008556243, 89.10693860823109, 45.90065833060972, 0.7893062106543972, 0.5939441678985473, 0.06608595425683646, 1.1738706428197123, 52.45749627390216, 65.90651127599901, 58.782333866242446, 43.34210411194832, 39.507179260253906, 22.626209989670787, 20.05867942687004, 10.08020991279233, 4.177758636013154, 0.25891372453301187, 0.021612746115293235, 0.0774334554350184, 0.07322531148430801, 0.034432266087782, 0.04469071965544455, 0.0651965414985053, 0.06332896469581513, 0.05543804457110744, 0.04136918075082283, 0.046256208837392836, 0.04358536969389647, 0.09222695799244028, 0.16326859713562075, 0.020256651745688532, 0.0886121951043606, 0.0815211933466696, 0.15350048580477316, 32.64684792487852, 67.87070874244937, 43.97055410569714, 52.69468199822211, 62.98989957378757, 53.72990531306113, 89.06780904339206, 39.12441476698845, 0.6695846864773382, 0.5722571380676762, 3.992513918107556, 27.255999234414872, 101.42485187899683, 82.09425849299278, 87.53629607539024, 75.59964503011396, 69.30408400873985, 78.98683132663851, 83.74050078853485, 85.88373876387074, 79.53123277233493, 80.67569409647297, 82.8086397724767, 82.52204787346625, 80.02054060659101, 74.73087141590734, 75.82619328652659, 75.55944858058807, 73.1337764186244, 72.78077879259664, 73.63789512265113, 72.57672925149241, 73.14687713499993, 72.67441195826378, 69.61723819855722, 61.01277397524927, 56.526492487999704, 57.27107209544028, 54.43026019680885, 55.590709101769235, 54.76037471525131, 50.53062800438174, 50.15672414533554, 50.6753634637402, 51.24615853832614, 52.80111551284791, 55.18956830424648, 53.96269798278809, 48.63453465123331, 49.216453567627944, 47.81894837656329, 47.231471461634484, 48.070995961466146, 45.98279276201802, 48.63824129104615, 49.352838300889545, 46.76122242404569, 45.082750012797696, 44.9518762096282, 46.82083068355438, 49.113138337289136, 52.157203535879816, 57.160888794929754, 64.12205642269504, 65.59174106967065, 65.79808519732568, 67.5673447885821, 68.24665223398517, 67.70652617177656, 60.72189100327031, 62.19545879671651, 63.21369040396906, 52.17862359939083, 49.150565593473374, 48.393681510802246, 55.25593872993223, 59.6486089306493, 61.94441926094794, 49.740972518920906, 43.393620521791526, 42.90422247302148, 47.49641972203409, 45.216353785607126, 50.64260775043119, 58.65311530328567, 62.878727835993615, 64.75034952163696, 61.418425498470185, 59.25900382380332, 52.18699001496839, 58.54111202301518, 54.69897785494405, 60.41720521065497, 60.41540876511605, 62.03685383642874, 60.561030680133456, 60.13104477236348, 62.252603807756984, 65.61116072439378, 64.03307353296589, 64.17762071855607, 57.57222383253036, 54.21137625171293, 50.50932168960572, 50.23195520524056, 50.109216397808446, 46.956364262488584, 44.367392063140876, 45.92092913966025, 47.21935918254238, 49.71275106553109, 53.89805339997815, 49.7804041062632, 49.48377878435197, 48.204952747591086, 48.01212118517969, 50.79448192350326, 53.174442783478774, 54.8651373001837, 54.55710964818155, 52.313647270202644, 52.70103623790126, 51.770402923707046, 55.711333751678474, 54.80432095066194, 58.1107456453385, 63.73302398189422, 66.00446854868244, 69.63737564702188, 72.25292190428704, 71.95144068810248, 71.89810429849933, 71.699993225836, 73.13616906442951, 71.25175260728406, 72.70353163442304, 74.40800543754332, 74.8958541500953, 73.30810223856281, 77.96892919848042, 70.87170631654801, 80.76554775238037, 77.9054024911696, 90.66241725798577, 53.00090928231516, 0.20840409211814406, 0.6376271142113594, 0.05152349232605869, 0.8771010512305845, 58.01174109981906, 72.79375399312666, 67.74607150785386, 53.53603432255407, 35.30565008040398, 35.8669843981343, 37.174435892412745, 8.733831836331277, 5.652339871852629, 0.1238745557624967, 0.015530943581383797, 0.0631222473607669, 0.04734662774529669, 0.051568561278644114, 0.0935241210484697, 0.040290693662339644, 0.034227843186067, 0.13132279198015892, 0.10625477099130232, 0.19206631718383682, 0.13724072926467465, 0.17785629017218468, 0.24497368222763463, 0.10401627739831325, 0.15748199796484363, 0.15623396412739832, 0.2455731460283841, 40.100174950015166, 80.05719907822149, 50.472141542742335, 75.77834037042435, 78.96348537937288, 61.806810748192575, 96.32220914286953, 45.66206839776809, 1.0349648061298555, 0.8026481527955303, 8.021011169879667, 26.830541703008837, 104.60788665279266, 84.59772694495418, 92.45159072260704, 79.44107317155408, 73.97047288956182, 83.07974615404683, 86.5292118441674, 87.16920145096319, 82.31785712703582, 84.85517563358431, 87.2238479122039, 85.85832964989447, 82.51851774031117, 79.09272747655069, 80.66383284907188, 80.49363336255475, 78.01062399341215, 76.43858509678995, 76.00364131312217, 78.26860612438571, 76.76057246423538, 73.79982625284504, 73.37173092749812, 63.82612536030432, 60.74929268129411, 58.67222116839502, 57.36294184961627, 59.41506708821943, 56.479545639407256, 53.4209402145878, 53.39058499182425, 53.849929840334006, 55.64209999576692, 55.111242494275494, 58.88256219125564, 54.40620037817187, 49.918385244184925, 49.212958735804406, 49.304506855626265, 48.17620569659818, 47.492579721635394, 46.25230273892803, 49.76888018269693, 52.89689979245586, 49.447991078899754, 50.48350464913153, 47.59332579951133, 52.102882631363414, 52.78204102669993, 56.01094399729083, 59.87715759584981, 68.26112577992102, 70.57628123990952, 68.04520714667537, 70.65713697864165, 72.12645684519123, 71.17951823819068, 64.00798605334374, 63.28478336334229, 66.8369367045741, 56.04838694295576, 55.770898865115264, 51.02794924089986, 56.61762091421313, 59.82042051130726, 59.97853125295332, 51.47586430272749, 43.4038814421623, 42.73437992219002, 47.22211268640334, 47.20490132608722, 55.18827784445978, 61.36844273536437, 65.32631428011003, 66.26419221201252, 63.38589029927408, 60.99999881559803, 56.9516303462367, 60.08180333722023, 58.22327060084189, 63.106962711580344, 62.965992727587306, 65.5021345230841, 62.88728644770961, 61.99911279063072, 64.8690757443828, 66.72781636638027, 67.13560165897493, 67.3422242749122, 60.03770412937288, 57.70104623609974, 53.08732301958146, 51.298384897170536, 52.015809935908166, 48.17116937329693, 43.906521412634085, 46.40034867871193, 47.19634271437123, 50.799702598202614, 53.85120853301018, 53.31964500488774, 51.43205535027289, 50.14184659527194, 50.3671867616715, 54.69997413696782, 56.37777974528652, 56.08787344348047, 57.89881606255808, 56.62648154843239, 55.527382435337195, 54.36760425567628, 57.4582476000632, 57.790790065642334, 61.501575823753114, 68.40917171970491, 70.34721482184626, 73.18035848679082, 77.09153421463506, 76.79321442880939, 74.17761325836182, 75.58540682638846, 79.26003225388067, 73.4535280350716, 75.3280601193828, 78.11436283972957, 79.64950007777061, 78.8106619927191, 81.75967247255387, 74.21515034091088, 84.19262455355737, 82.89728533837103, 93.92880239794331, 48.93361929924258, 1.4604960045506878, 2.516870700543927, 0.16213406688503681, 1.569840775862817, 71.12224378893453, 79.81052121808453, 78.34475501891106, 62.637086299157914, 64.40218033329134, 42.45833135420277, 54.6144978461727, 25.526090821912213, 7.087714076042176, 0.27991976348623154, 0.10360440554758234, 0.17811395618463718, 0.21997123836509644, 0.1903477827868154, 0.1956373900775948, 0.28535285904522867, 0.12347001537320115], [0.0878043324055691, 0.04821821746806945, 0.034282243089570154, 0.01424549975537605, 0.03788480602745568, 0.08049933164710961, 0.060423986100020914, 0.048098370673195015, 0.042224648153229107, 0.14893185918129262, 34.19299525599326, 58.02008790354575, 51.02937306127241, 32.13134650261172, 49.76926065260365, 50.839561723893695, 82.75796274985038, 17.970478188607004, 0.49031579145981424, 0.6635249309962796, 1.8208491778181446, 47.95289339557771, 97.29737312563005, 82.40767940398186, 78.771940354378, 66.09953111217868, 74.57717726307531, 79.80187631422474, 79.58220789509436, 73.60730063530707, 79.59751298350673, 80.84768218378868, 76.5106939500378, 74.10978763334214, 74.29086777471727, 72.24433191360967, 70.55772842899447, 71.8524871333953, 73.22224940023115, 74.89379098338466, 71.86181452966505, 71.57117474463679, 66.60153173631238, 63.2765503083506, 56.72938885227327, 52.463685774034076, 52.93815528192828, 51.659462605753255, 54.74382623549431, 52.787410751465835, 53.31003519796556, 50.838902765704745, 48.389351214132006, 48.42384061505718, 52.312686289510424, 49.76163164261849, 52.615885503830455, 54.355931282043464, 48.76320408236597, 48.59406363579535, 50.57454678320116, 49.07363614728374, 46.4980431525938, 47.006888312678186, 46.09431359075731, 45.7952210980077, 42.66583258105863, 41.6184106949837, 41.664455398436516, 44.1246130389552, 46.17499282283168, 49.47910331910657, 50.15502183668075, 54.44714600040067, 62.913221159288966, 65.36192155653431, 61.83842897415162, 63.309988514069595, 61.16442849559169, 59.90491620955929, 60.994507497356786, 59.43963289260865, 53.33267904097035, 60.67818795481036, 44.98071739750524, 51.22942178480087, 62.268308977926935, 68.9947815864317, 65.22093980543076, 47.71553116460001, 43.48484308488908, 44.86521536304105, 44.22189174159881, 42.457539035427956, 52.71146189781928, 58.83831001097157, 57.88828449864542, 58.781282671036266, 54.6149802977039, 50.15394318488337, 53.666249167534616, 58.89392922001501, 58.71537900740101, 58.69013855534216, 58.69627706466183, 59.39188980287122, 63.14786518773725, 62.532880690789995, 61.462265829886164, 59.86935992394725, 54.48869174526584, 52.51159752568891, 48.37161033384262, 48.80752294294296, 48.7293932514806, 44.231776114433046, 45.27957847041469, 45.68027211773781, 43.39184761047364, 45.80382677816576, 46.93285749804589, 52.97044031081661, 48.33011557978969, 46.98313443891464, 47.05629448736868, 44.32276725769044, 45.17005020572294, 50.36508829362931, 52.201130159439586, 50.60208574418099, 50.60099532527309, 49.806076019041, 50.27240268645748, 50.35062259243381, 52.491424775892696, 55.03476412065568, 59.5939899259998, 67.00125263583276, 67.87072443193006, 69.33218386865431, 69.38916021777739, 69.35315285959553, 69.64586365607478, 70.89166333598476, 70.99897153915899, 70.5343432580271, 69.70623677776706, 71.36997284427767, 72.12271490404683, 66.37559536964663, 71.73861288255262, 68.75917265492102, 78.81296050164008, 76.24201159323417, 85.40622941909298, 4.953005784942258, 1.081881991797878, 0.4523550929321397, 0.2992007256515565, 28.911412031419818, 70.79093686995968, 56.57568685470089, 46.24766649738435, 24.204642349673858, 21.70869896488805, 14.279294475432366, 10.582963631999109, 1.7436335211799991, 0.07215756877896286, 0.03035638147153922, 0.05230147759580324, 0.04416568512697855, 0.09241372256750062, 0.043850646789876685, 0.03719480212537512, 0.0841614157862721, 0.14233558168334348, 0.03593370648882082, 0.0679157782466181, 0.004896560135567862, 0.01018967132099093, 0.02397085667677945, 0.025539385312567317, 0.050866579591867425, 0.08212611169343995, 0.05568744832529657, 47.20166537069505, 65.2171076497724, 60.20400085756856, 37.95669771009876, 54.597321787188136, 59.8699757360643, 90.65509811524423, 20.02641793220274, 0.6311334465299884, 0.9063319020694303, 1.113973476233021, 54.25298475450086, 98.2640177203763, 85.83979252846011, 80.28259415780344, 68.8780047816615, 77.29833725960025, 85.04296302795412, 83.27549595986643, 76.9233351369058, 80.86902772226642, 82.56205604922387, 80.56658160301947, 76.01611445027014, 78.07121676783409, 75.60489316140452, 73.17542414511405, 75.10420260890838, 75.48996771535566, 77.46085674531999, 72.20775973412299, 73.3729076385498, 69.68609148456206, 67.1674983732162, 58.952384302693034, 55.92742496921171, 54.903843249044115, 54.79172622003863, 57.08615587603662, 55.476234728290194, 55.13062684766708, 53.405744952540246, 50.46823093968053, 50.552761939264116, 53.05844653037287, 51.96128114577263, 54.385384359667384, 55.75782168296076, 48.156554622034875, 48.596283697312884, 50.205683169826386, 48.26540039431665, 46.97967490842266, 46.754817193554295, 47.49483900685465, 49.32300475335891, 46.191607982881614, 44.518630812245036, 44.23297635970577, 47.88527173380698, 48.12507760140204, 52.83239641497212, 50.80639023934641, 58.43132880426223, 65.42486383068946, 68.2211882068265, 66.22120303492393, 65.54118956288984, 64.12069928261542, 60.13623799047163, 63.19660848186862, 62.274063094969726, 56.18488934732253, 64.35440194222235, 47.68068875035932, 56.94932791494555, 61.440296634551025, 69.58845584623276, 65.02648438176801, 47.965578340714984, 45.05640345235025, 45.34942411607312, 47.24538018626552, 44.04742863870437, 53.66483319190241, 61.636532814271995, 60.010216159205285, 62.438712427693034, 57.16821578241164, 52.59950568599086, 54.232419767687404, 60.71529357664047, 62.65415645414784, 61.368917342155214, 61.87461283899123, 61.997838020324714, 65.70117519747826, 64.07844751111924, 64.6205779044859, 59.58880063026183, 52.910604553837935, 52.79700879127749, 49.42299773616176, 48.20779646596601, 50.350379405483125, 45.09872582650954, 45.404474581441576, 44.925058964760076, 41.86473946417532, 45.91429641169887, 47.25324453846101, 55.88831109385337, 51.26797868359474, 49.15519399027671, 50.41323538749449, 46.803395748138435, 48.82036086051695, 53.187280701052764, 53.93990116734659, 52.15767814267067, 52.385544315461196, 53.51706966277092, 53.27027805389897, 53.56386746129682, 54.71424764202487, 58.55240060437111, 63.062035883626635, 69.6064987490254, 70.0123385460146, 71.30399857797931, 71.41841411590576, 71.66011056592389, 74.46595453446912, 72.33428755114156, 73.0007610013408, 71.2531489710654, 71.33227102218136, 72.41074239054035, 73.68177860013901, 68.85356841548797, 72.67099165147351, 71.79645215311359, 84.14934512107604, 76.66143063575991, 95.824491746964, 7.214467429345654, 1.5325222428767913, 0.16183530791632592, 0.4206046401973694, 30.469887371986147, 79.22669995215632, 63.86783584471672, 56.60080179091423, 28.698148842780824, 31.191393636888076, 31.639212600646484, 8.7341260140942, 3.2969516804141388, 0.0924737302346095, 0.15609255961833463, 0.07449004603850265, 0.019390097135798107, 0.048544628380407254, 0.011707111468328344, 0.044276764045559594, 0.027251469249266292, 0.19076384513849215, 0.16292886778471932, 0.1659747107975906, 0.13706272107458886, 0.194430862883887, 0.21944430776901785, 0.2017276511797982, 0.12550788586057965, 0.14354682797866483, 0.18368497821352175, 57.26616913272489, 78.5501617000949, 65.67268310054656, 51.909803959631155, 68.421032967106, 66.9285789612801, 100.11547842333394, 23.494789446553877, 0.6774284462294271, 1.6234201072685182, 2.6453457292049163, 57.52986223466935, 104.15580995621221, 88.23130869096326, 84.58990573883057, 72.3316752526068, 81.30472460100728, 86.74819777088781, 83.58042886180263, 79.30312341259372, 83.69177710625434, 84.20749033651045, 85.91475686719342, 79.76797134645524, 80.99524174967121, 79.76714764871906, 75.85896861168646, 77.90121339982556, 78.86449260096397, 84.02073844786614, 75.9477004697246, 76.30366340760263, 72.32659186086347, 70.55047204417568, 61.15539919945502, 57.559864444117395, 57.43017519673994, 58.547430961362785, 60.332262362203295, 57.561143136793575, 57.76470238162626, 56.03311715587493, 54.834884059044626, 53.989264195965184, 57.99913460208524, 53.68158563490837, 57.05262745580366, 57.844110765764796, 48.76225094641409, 50.199124966898275, 51.32167985362392, 49.70496123836887, 46.79038524627686, 47.722685567794315, 46.854351259046986, 54.23766397660779, 48.369335359142674, 46.90116474705358, 47.42045910127702, 51.37185089049801, 50.8736078969894, 54.52188284166398, 53.6450409120129, 60.91988440482848, 69.66523231998568, 70.38352812490156, 68.04892555359872, 68.80395043280818, 67.349959188892, 65.08869709507113, 66.85173972960442, 63.4887779912641, 60.099889386084776, 62.203307459431315, 47.8037452697754, 60.219160818284564, 66.40674683355516, 69.83841280783378, 64.16754807195356, 49.196967232611875, 44.982145140247965, 45.96036464937272, 48.175558505519746, 48.5075165379432, 59.28213404070947, 63.879936356698316, 61.513021299915934, 65.62971745767902, 59.33581952125796, 54.45178616431452, 58.270397878462276, 63.64135034622685, 63.612764112411014, 65.4766430393342, 64.97965520428073, 64.27039654024186, 67.28945270661386, 66.38224770945888, 67.95984068224507, 64.46453032955047, 58.45423936843873, 56.39195519108927, 52.66720187279486, 51.21536401010329, 51.534327230145855, 44.016787082918235, 44.44006966006371, 45.92386699491932, 43.04475315155522, 46.507468608117875, 47.05463532478579, 56.66332437146095, 54.93786196554861, 51.09387251638597, 52.51302526843164, 48.91819261735486, 49.68006987725535, 56.31410791027931, 57.86067101263232, 53.57487755437052, 54.59768656761416, 55.2537618144866, 56.23869249897619, 54.951425521604484, 58.10916885252922, 60.60102708878056, 66.12690925598145, 74.7431484345467, 73.58581389150312, 74.26041449269941, 74.60484566227083, 73.8380144488427, 76.31577568669474, 75.30418857451409, 75.6166132034794, 75.63247526845625, 75.69739049480808, 75.5473441462363, 76.01357275439848, 72.83548016701975, 76.51984876201999, 73.97408147012034, 89.40525054931642, 81.61909472557807, 90.78568950776132, 5.698410561007838, 1.7816569776304307, 1.1637471279790326, 0.34986754398672815, 39.79812106778545, 85.93588275294151, 73.07073608521493, 66.2821174437, 41.74138092225598, 38.53760465498894, 44.81275366198632, 28.888523040279267, 6.109527416767613, 0.27968822107199703, 0.1860784054283173, 0.13319895662848028, 0.24872483174887397, 0.1981885394742412, 0.14635950447090212, 0.26521780077488194, 0.1558173655141746], [0.06530868144886148, 0.04507361039999993, 0.02435767745238639, 0.10319772011209881, 0.017526348857509515, 0.03190071705067831, 0.15137768681010894, 0.011091750385540148, 0.044036377146239244, 0.42556551915984003, 43.23543525511219, 54.1619190862102, 34.32034284837785, 36.1021501018155, 53.96240772739534, 51.5416032268155, 85.54497149682815, 7.717774693043002, 0.28193613754645475, 0.3343443963075838, 0.38460812982051606, 73.01806649854107, 86.03908031217514, 81.53317128458332, 69.99354254814887, 73.4712100798084, 76.33232808882191, 84.01417240019768, 77.42595549552672, 81.04672678055303, 82.93359079668599, 78.59748117385372, 76.97154106632357, 77.09180878054711, 69.38896409926876, 67.30896257585096, 65.79045226497036, 64.66620291433027, 66.15907269139444, 67.48439450417796, 63.069790409457305, 61.95680218358194, 56.59691864444364, 54.66632804562969, 54.36310529708863, 55.49182614972515, 52.24997543519544, 51.674026366203066, 52.953609420407204, 54.10285603615546, 52.02224262299077, 47.69324425728091, 46.42816612797399, 47.47490944400911, 50.16198404373662, 51.87795039146177, 49.91607496815343, 51.2096804957236, 48.64819234417331, 48.6000923187502, 46.34138761028167, 48.63213416068785, 48.190353685809725, 49.3264485943702, 50.774242493414114, 49.030027235707934, 45.47407311777915, 41.689703695235714, 43.45866910872921, 45.15467843701763, 42.74714723710091, 48.22270147262081, 47.958521996774984, 50.134170516844726, 52.52932271649761, 61.506349348252826, 62.569339121541674, 60.6122999806558, 57.11822909693564, 55.026786019725186, 56.49772582515594, 60.75637255945514, 59.06600359947451, 69.4261795474637, 58.381349963526574, 52.88403049592049, 54.34606259868991, 55.92146296654978, 53.89133830224314, 58.37705496818789, 52.65588191247756, 45.18777147416146, 44.42875362211659, 34.516406443811235, 43.206586222494806, 55.46488731138168, 59.522951879808986, 57.7312877101283, 48.63011414004911, 51.572903740790586, 56.52940288666756, 57.70855757497973, 58.394893907731586, 58.3423263026822, 63.17381166642713, 58.50121759599256, 62.818664581544944, 61.17290081516389, 56.71113806386148, 48.485127648999615, 49.67717124569801, 47.0866967785743, 50.63116619663854, 45.33217745442545, 46.40667546179987, 49.783616527434326, 44.17634517915788, 43.30437091089065, 47.45384631618377, 46.43305732357887, 47.53992665198542, 49.948010906096435, 49.40898702990625, 47.348922914074315, 47.202696954050374, 47.1011350231786, 46.729321787434245, 49.919950269883685, 49.748158301076586, 49.83524668601252, 49.67117394170454, 51.299781260951875, 50.57818674272107, 49.734610434501406, 50.87056413773568, 51.87176873607021, 51.32740259170533, 59.10355637150427, 62.41284831877678, 66.13254962428924, 70.39592281464608, 68.05094165186729, 67.99376133949526, 65.09366673807945, 68.93942125381963, 65.14939577348771, 67.73160580665835, 64.90134116142028, 67.1357193300801, 65.56615937140681, 68.477052257907, 68.99349504901518, 73.67130587177893, 76.99842499148461, 78.77527436902447, 25.458700579981652, 1.0966373355157915, 0.7447399956084068, 0.3540616915110619, 6.861139833927155, 67.01622824515066, 61.5399601382594, 51.52616477781727, 31.80304215800378, 18.647283161840132, 13.255484277202239, 2.7121424674987797, 0.5422064505757824, 0.04388024842727088, 0.06397910904319537, 0.04297641789420478, 0.03950727682921194, 0.03638196368551543, 0.07861039631309048, 0.07666002838842331, 0.03248743697880738, 0.035174612947289026, 0.054212690766660444, 0.04508828481418952, 0.02353216983347891, 0.009020302264440444, 0.039056947364682154, 0.12131504834659639, 0.033859983086586, 0.06105354183443612, 1.0461009053453323, 58.75571273988294, 60.45264774753202, 37.63248243639546, 33.342758763221006, 59.6620979616719, 60.999033912535644, 93.47486649790119, 7.984650798382298, 0.3765044517574772, 0.6728653814042769, 1.180068723136379, 82.69314950512302, 86.8817074068131, 83.62327683356501, 72.39651203155518, 78.52294829583938, 79.34970548076015, 86.72822506197038, 80.32240621505245, 83.90167097891532, 84.31177046991165, 80.64171068130001, 81.80481895323723, 79.01257776444959, 72.5084956999748, 70.50054811662244, 69.67138259641587, 66.35306527537685, 70.54294109344482, 70.6304491719892, 67.0865406528596, 63.99452840128253, 58.81873738381171, 56.21667623519898, 54.14753575478831, 55.31064010435536, 53.168257205717026, 55.10433127803188, 54.88901668979276, 55.8414387702942, 53.18422125231836, 51.09045220959572, 49.6963987042827, 52.49387625725039, 51.36190768211119, 54.72967824628277, 52.05961888836276, 52.73336833523166, 48.59832332980249, 50.77991424068328, 46.087131730971805, 48.419981002807624, 48.41588604834772, 48.60650931635211, 51.608244296043154, 51.06832611945368, 47.52445290165563, 45.22401417455366, 45.440152460528964, 46.06197757105674, 45.02412234583209, 49.26036057933685, 49.50454381204421, 51.326218035913286, 53.85404048427459, 64.48595431543166, 63.12581754499867, 64.01916088596468, 60.72968867517287, 57.64867474955898, 57.810574500791496, 61.451902927890906, 62.12369903441399, 71.21636498358943, 58.67943832951208, 58.69545336692565, 57.59631503012873, 58.66969516200405, 53.866725429411865, 58.571698665618904, 54.22597531349429, 45.63797720016972, 47.17332624620008, 38.284949102709376, 46.335213799630445, 58.48067222102996, 62.24974047753119, 58.3244324499561, 50.40798333383376, 53.86427394805416, 58.58042593925231, 59.8527329967868, 58.747503219112275, 61.0923392541947, 64.7993673816804, 62.28181369843022, 65.05932246485065, 63.15401546416744, 57.35697200221401, 51.29563139330957, 51.22699383766421, 49.403005415393466, 51.08234074807937, 45.813899424768266, 46.65805624377343, 49.8599301615069, 44.57112781463131, 43.10219626272879, 46.12045226558563, 45.019478259548066, 48.05314133244176, 51.21296744192801, 51.21861173260597, 49.38763756905833, 50.01868809423139, 47.94866508053195, 48.567348372551706, 52.44324630306613, 50.041700640032374, 52.20953972108903, 51.37121938890027, 53.932099573073856, 51.43986478928597, 51.52991848607218, 53.37417771739345, 52.27757323172785, 51.25081831409086, 61.24528031195364, 63.59473689909905, 69.99199713430097, 71.56627962666174, 70.26744950202205, 69.68759767470821, 68.54490141714773, 71.30848576945644, 69.19559124977359, 70.99136998576503, 68.28200847871842, 69.09003242369621, 69.068357406124, 70.50631400077575, 69.57474324011034, 77.3985851964643, 79.95477030354162, 84.06101334479548, 32.049876912947624, 1.2898133310579485, 0.19288748682987308, 0.42091652991310247, 6.419214721648924, 76.55106298385128, 68.53944932260822, 62.47781061357068, 41.415004422587735, 20.76526107326631, 31.523357552866784, 13.339641671026907, 1.423573753526134, 0.057100482179873416, 0.01978768527718081, 0.06636180719661136, 0.053135054035773205, 0.029371753560319066, 0.04041367758726401, 0.09323425636055971, 0.05028754352561889, 0.12841839178074754, 0.14181922310061995, 0.19679539326217868, 0.20173613943399923, 0.1278653452473302, 0.1638243173158938, 0.265288005072263, 0.2002829472504316, 0.14466991287566003, 1.2067434143635536, 67.3635462791689, 71.28974468477311, 45.043777342765566, 52.42851780306909, 74.32131321199479, 66.56536748332363, 103.82153772538709, 10.1095070762019, 0.4952960371250107, 2.228327912669028, 1.9837725450915678, 82.68896825851934, 90.30480692463537, 88.89148281466576, 77.12191689398982, 81.19076405802082, 82.00307907596712, 92.13675775835591, 83.45670161708709, 85.3778471485261, 88.1338534816619, 84.60444988742952, 86.26330652544576, 85.03030946177822, 75.86536207506734, 75.58160997206166, 71.87921416374945, 68.6954027606595, 73.91515178065147, 75.81346127294725, 71.04240002170687, 70.07107996171521, 62.170810622553674, 58.816352582746944, 58.929152104162405, 60.40614412676904, 57.60967854530581, 57.75319414754068, 57.54635187887377, 58.63868882579189, 57.537204911631925, 52.008894797294374, 52.19678809565883, 54.9052200009746, 54.36143044502505, 56.92900611508278, 54.946577472071496, 53.74891311891618, 47.823863106389204, 50.42679894355036, 47.69888854795887, 50.10139911405502, 48.985096485384055, 48.36985311200542, 53.43816334201444, 52.60422429730816, 51.422170977438654, 47.91214389185752, 48.7295070002156, 49.81559953381939, 49.241984275079545, 53.37369918823243, 52.93051058246244, 53.54133736702704, 57.294829891574004, 66.38975512596869, 69.02221464341687, 64.88708726821407, 63.62214249949302, 61.30095835654967, 62.33688769801971, 66.63666832831599, 66.33444970653903, 74.5611818375126, 62.497936294924834, 64.08490373242286, 62.74541824094711, 59.817619939004224, 53.729077692954775, 60.774117362114694, 55.64299429616621, 45.007620934517156, 47.78066996605166, 43.426337011398815, 49.421868093552135, 60.83853444745464, 64.53982022500807, 62.418688727963364, 52.10462416371992, 55.85744596296742, 62.529166206236816, 61.63657988271406, 63.121777503721184, 63.26532448491743, 66.85536399964364, 63.14266020251859, 67.97590671047088, 68.55972797639909, 60.10622793628324, 54.48877411503946, 54.04304381339781, 53.06875451918572, 54.144660657452, 47.26003416122929, 47.48235018022599, 50.18785991976338, 44.26022506529286, 44.250572112298784, 48.380188557409475, 46.45071583409464, 48.993961041973485, 52.863967572489095, 53.88426234645229, 51.11794802450365, 53.410294901940134, 51.82594760771721, 52.56636165803479, 54.64142883977583, 53.26741080130301, 54.144295877025975, 53.842442035675056, 57.13589937456193, 55.82439607189548, 55.78744342250209, 56.4173682274357, 56.018282751883234, 54.08173799514771, 67.61033396567068, 66.14259089193037, 73.37114257197227, 75.85945498558783, 73.55113229443951, 72.65729473483178, 70.46608617228847, 75.720242223432, 71.62709205381333, 73.69298873409149, 73.6157964891003, 73.73187511197983, 74.66910977517405, 75.48329184132238, 74.08666133880615, 80.72413536810106, 83.84650676481186, 87.41442018939604, 32.357551551634266, 2.2909711060985445, 1.548739159780164, 0.49125207347735284, 10.379908411733567, 84.93967133183634, 74.62908590993574, 71.19319162061139, 57.41836494015109, 45.371232494231194, 43.72699845221735, 39.54642257382793, 3.7081295780597197, 0.21798651905790453, 0.22097101374979944, 0.2537713133760037, 0.14856925444497218, 0.11380735604513077, 0.17032627406860554, 0.17895096852894754, 0.11249237378398258], [0.02364309170403548, 0.031893789700623, 0.043566979753274115, 0.11946725193411113, 0.04020840815839268, 0.007116262549384227, 0.08145064430972261, 0.03712593848186155, 0.16681566083383176, 2.4091658476860296, 58.4291361993359, 46.5739567049088, 40.42374303264003, 43.64660163079539, 50.496193516638975, 58.98577543996996, 77.86985012792772, 2.125335297276897, 0.10343369817541492, 0.3726891806769756, 11.52358526183713, 98.72400191522415, 79.08460032555365, 82.22694443118188, 64.85236644744873, 75.61514623703496, 78.89223944756293, 83.46179285357076, 81.37049490405668, 82.34100695579284, 80.11489714345625, 77.0547188481977, 74.14165296862203, 71.62653507724886, 63.42228204973283, 63.887424161357266, 57.34279655641126, 56.95055953917965, 55.3362924052823, 54.826898113373794, 52.096230291551166, 52.64160056268015, 53.096995584426395, 55.148450097730084, 51.168436773361705, 53.48125842309768, 52.277224140782515, 52.90536818965789, 52.48105795152726, 52.73258778356737, 49.88016959159605, 48.58594825190883, 48.75928563456382, 50.653810039643325, 48.092996535762666, 49.68885206407117, 49.96812874271024, 52.56410629518571, 49.596299817485196, 48.65042417280136, 47.75338203676286, 45.483192628429784, 48.81515587529829, 50.14530612576393, 47.25738656136298, 51.17586574246807, 48.138264609921364, 44.07354770168182, 39.42790423670123, 43.426658645752944, 41.7212317066808, 46.213714461172785, 47.20814120384955, 51.94149671062347, 45.844187967238895, 51.062289591758486, 56.774794209388, 57.38227913456579, 53.53366521096999, 54.87961084611955, 54.039325406474454, 56.533407626613496, 58.19619055717223, 67.64296024076401, 46.714432470260135, 50.22881338673253, 44.685092279987956, 51.580054221614716, 45.50676215079523, 33.2989655002471, 59.816937446594245, 42.15078223136164, 50.002120002623535, 45.581667653975956, 55.99267359702818, 58.475369176556995, 59.11425659733435, 51.19842329332906, 48.547301138601, 48.215296037735484, 52.28646524490849, 54.790047445604884, 58.7247456273725, 54.53807046336513, 58.889449873278224, 58.249130787387976, 55.994728918998476, 49.420605090356645, 49.42086396678802, 46.476521107458304, 44.62966134471279, 47.22732943873252, 47.51810258434665, 52.59004885150541, 44.197549512309415, 47.545315988602184, 51.612484378199426, 45.65201144064627, 44.58848822501398, 44.1198238249748, 48.093514288625414, 50.99442474303707, 48.43325822584091, 47.226337079078924, 46.55131286190402, 45.8594459872092, 46.16285308714836, 50.47172184913389, 50.83039514480099, 49.7878566095906, 48.28904051934519, 51.28438988039571, 49.15212669680196, 49.2384345300736, 50.30806487606418, 51.948615812486224, 52.4630581948065, 51.790069687751036, 52.996284807882006, 56.18827435278124, 61.05737916884884, 58.06150028782507, 60.47932378707394, 60.466811426224254, 61.317051841366684, 62.62715093551144, 61.71161874648064, 63.63758487086143, 65.69759407351094, 61.5345472674216, 64.75904933867916, 65.04641394461355, 75.31290408103698, 75.71274265166252, 86.31403061651415, 46.46460886924498, 0.10477987553683982, 0.4920346782572808, 0.09662516069628539, 1.0169477051784916, 54.436567368045935, 64.95430884822723, 54.29336555542485, 39.84032577083957, 23.78845730135518, 16.16995828766977, 3.9745452952000404, 2.243467526089761, 0.19540678229062788, 0.05460924085890574, 0.04192607304562004, 0.030501298493735736, 0.007032836532039989, 0.07045938933808958, 0.02772091452272669, 0.06606291033207409, 0.03580971898871564, 0.02385906529642882, 0.04322238191361389, 0.04452759655372751, 0.08240679098713784, 0.04258176003913245, 0.06967525238231306, 0.02559337344381117, 0.17893618303200892, 4.044990573198565, 74.05677287809311, 53.576752447312884, 48.793692665715376, 37.50918665239888, 58.86638241429483, 65.04808095193678, 85.93588275294151, 1.8492910193820156, 0.10830097651529698, 0.3884148820032997, 16.560419451805853, 105.67814457801082, 80.47581011249174, 84.57631864855367, 66.35263381465789, 79.44788240617322, 81.05421850758215, 84.30384728216356, 82.5227068316552, 84.55965642006167, 81.70993681876891, 79.66467180559712, 75.30947592950638, 73.82070110690209, 66.66556050700527, 67.52726601016137, 60.55759860623268, 59.66207442745086, 58.24719313652285, 57.827213195062455, 54.944671200167754, 55.62683413105627, 53.949769850700136, 56.92723712613506, 54.820390901257916, 55.65732663677585, 54.8659453084392, 54.847341506711906, 54.65306258970692, 54.44594183275777, 53.31115307346467, 52.15475205452212, 50.90675584731564, 53.020729018795876, 51.95094570036858, 52.11606963988274, 53.156866642736624, 53.492601917636016, 49.73916038390129, 49.12739223049533, 49.08303022384644, 45.79993186458465, 48.26447863732615, 49.76499703622634, 46.490406297868304, 51.39217269036078, 49.26629120303739, 47.21886888627083, 40.900624798190215, 46.594396175876746, 43.907678511834916, 48.6793359633415, 49.623579902033654, 53.15020253581386, 49.50740321989983, 52.24226013306649, 59.94158644830028, 59.3689674715842, 56.71085957557925, 56.708443395553104, 57.14563861969979, 58.50847005844117, 61.5130252222861, 70.56289811288157, 49.86733167402206, 54.873997934402965, 48.60503450516732, 58.16000276996244, 47.6059401419855, 33.74821416793331, 59.98232810728012, 42.07479415401336, 51.001441863275346, 47.305616025001775, 60.44576791024978, 60.82297440498107, 61.695670389360004, 55.38345498423423, 50.55349934485651, 51.63335530988632, 54.53385391542989, 56.40958232264365, 60.9770921737917, 60.378185472180775, 62.147472520028394, 60.6307900336481, 59.98893730102047, 52.90185766835367, 50.635339598501886, 48.1122043824965, 46.337296578191946, 47.851339309446274, 48.31211582306893, 52.12685223548643, 47.48173044573876, 49.67289586221018, 53.722641083502005, 45.343415044969134, 44.76078617957331, 43.28885401448896, 48.48171518694971, 53.511825453850534, 49.853717127153956, 48.379812009872936, 49.30180434257754, 48.977377260884936, 50.14405488967896, 51.82022094726563, 52.08865227237825, 51.355576976653076, 52.6607221172702, 53.101474931163175, 51.01938278444352, 53.43517057357296, 52.53892467867944, 54.12847303575086, 54.25734643013247, 56.25554692360663, 55.36381567678144, 58.13084779247161, 61.22173432380923, 60.57196624817387, 62.743998342944735, 61.37473813949093, 63.91089562446841, 64.91396727100496, 62.806913160508685, 65.05921263848582, 67.97927210407873, 63.559459101769235, 66.27908937392696, 66.81046070591097, 77.72839377003332, 79.20945721287882, 89.90190106053507, 53.76067238469278, 0.07199027815893774, 0.9946328509719142, 0.0666793123368294, 0.7649204675709048, 59.970635521796446, 74.58206453631001, 63.212274428336855, 47.663520536115094, 26.428392856351792, 35.2142470882785, 12.73698224175361, 2.3461551772009943, 0.076406690772743, 0.03567617454175507, 0.03465983633612914, 0.0711648873684387, 0.03839511251557739, 0.016629305863452536, 0.057528690855589606, 0.02919483129986592, 0.12014771421109477, 0.11390067321518738, 0.14283879419728635, 0.30785644667283185, 0.18654040241193387, 0.29698712991610654, 0.26173381675635615, 0.16287514969946879, 0.2782135018177571, 4.31540294039634, 85.95878155000749, 58.8748037430548, 57.065775240621264, 63.56671940895819, 70.96261901240196, 70.50108940370622, 93.89597215960103, 2.9584464767286858, 0.2094354303253274, 1.5016550282316825, 15.766690584921069, 110.47983169555665, 83.5150037273284, 87.25374421765729, 68.49289863340317, 81.59288544808665, 86.36067544260334, 87.11330767600768, 85.42244449738534, 88.157756405492, 85.72274115777786, 82.20692465382238, 79.34276288555515, 77.7261580190351, 71.15529368000647, 70.08807951404204, 62.751144901398696, 63.920446595838, 61.75224273435531, 60.48032006909771, 57.84516980571132, 57.69263275208012, 58.007061712203495, 62.57685438279183, 56.761944524703495, 58.326260274456395, 58.74076850952641, 57.96333512952251, 56.72530174255372, 57.47858901177683, 55.86466704645465, 55.66197072305987, 54.2874780777962, 57.771268429294715, 54.599000561621885, 55.50098880644768, 56.26788670016874, 53.438473209258056, 49.97124310462706, 49.944033622741706, 49.216610462434836, 46.339242073797415, 49.61149507953275, 52.13991765053042, 48.84725263041835, 54.74792903469455, 52.29902075183008, 50.12715339660645, 44.496081106124386, 50.263071367817545, 45.731906198686175, 52.13550106171639, 52.609080191581484, 58.19894013866302, 51.57695947154876, 56.54135434858261, 63.791188809179495, 61.60431054330642, 59.48304568567584, 59.534899419353856, 60.30668066393945, 61.972789764404304, 65.28689838224842, 71.65568613236951, 55.81821833887408, 57.643485453821, 55.51152429273052, 66.92003603904479, 47.179174500127, 37.06076168244885, 60.92661911441434, 46.63890723259219, 56.244395625206735, 49.82623700172671, 60.84555941243326, 62.358288149679865, 65.35442198476484, 60.12936599792973, 53.880900875214614, 54.79074954986573, 57.42909654494255, 61.43442484640307, 61.697541359932195, 61.45711183547974, 63.69158021865353, 63.155062737003455, 62.47774001090758, 55.2563113550986, 54.17116411270634, 51.65413994942942, 47.963777972805886, 50.39643587604646, 51.18796233207949, 53.689959895226266, 49.02589697991648, 49.900648286265714, 53.66251899350075, 46.2243244724889, 45.158447834753225, 43.503176243074485, 50.313065898033884, 55.31708455854847, 53.53825046170143, 52.55579479279057, 52.58412999491538, 52.30814026248071, 51.9722088690727, 55.71517767444734, 55.18512425884124, 53.33633468997095, 53.45113069780412, 56.23671170203917, 52.62989621008597, 57.26561215616042, 55.27105162220617, 56.10069567157377, 58.32599355328468, 60.36691650267571, 58.94685768312024, 62.008710830442375, 65.41219849740305, 62.774416323631044, 67.72559673555436, 65.14103720265051, 67.69632800932854, 69.54866732320478, 66.38162797497165, 70.24364071507608, 71.51728922320952, 66.28024255075763, 70.21171262187343, 71.8832306708059, 80.07664618953582, 84.6699691587879, 93.33424952722366, 58.36591543689851, 0.42282758220549554, 1.6391104459762575, 0.3431197802626318, 1.8832124120766118, 69.32732797438099, 78.1086048003166, 73.94517360195037, 63.88843221049156, 48.504559070833274, 44.914809811499815, 37.74616056872953, 4.32080747619752, 0.28768480004322144, 0.22521386914435895, 0.12514212484201118, 0.11994486178962455, 0.18570274655376712, 0.12473994400352241, 0.1366884258365439, 0.14384779328059766], [0.042315487028850664, 0.018515330063359394, 0.0219113556968589, 0.08136972244228087, 0.015599954696822793, 0.026199375804994377, 0.04230867267676419, 0.10575838432076479, 0.2342131193126402, 4.134172768362107, 55.559098720550544, 49.77039813995362, 33.72861800655242, 39.859906242739775, 53.04022319855229, 62.24165255023588, 70.21579973159298, 0.37244743397158964, 0.09888409351509425, 0.9071854465911466, 44.912723110568145, 94.58609750193935, 76.4081161252914, 77.86427251754269, 69.08640030891665, 78.35192511158606, 80.60559349675333, 84.3577092693698, 79.73427818667504, 80.57547753857028, 77.627730061931, 72.06318901431176, 67.67435489162322, 66.65064765561011, 56.73355048702609, 55.60068761148761, 54.543502946053785, 54.00772286999611, 53.85390320131856, 57.0961618423462, 53.13831383182157, 53.51883865171864, 53.560298104440015, 52.30759113065658, 51.329230416205625, 52.22139312374977, 52.529401163901056, 53.12999056231592, 50.95534616901029, 50.81869471457697, 51.09333515167237, 49.45191737144224, 49.07593073383455, 50.916189147580056, 49.77785064328102, 49.522347450256355, 53.05331214781731, 54.43329611132222, 52.759424640286355, 48.38228702545167, 46.008029291706706, 46.45657977750225, 50.4755187034607, 50.74452661698865, 47.55876971829323, 47.82347871411232, 45.53588574932468, 47.89607001889137, 42.17486950658983, 42.93479342614451, 42.160627380494155, 44.8295610181747, 46.9794277991018, 47.97676494044643, 49.690322952885786, 46.2802613935163, 47.97650214164488, 51.759192789754565, 49.816458532887125, 51.24988086761967, 51.69879221147107, 53.08704060892905, 59.13746526164394, 60.08875377716557, 50.93053325530022, 41.54469759233537, 32.174712227236846, 41.581022662501184, 60.50388566909298, 28.115869068330337, 36.878422460248395, 38.87215145172612, 34.18667239527549, 50.77614092057752, 60.71072009301955, 58.627055075860795, 55.025236683507124, 49.241588115692146, 47.23076151263329, 49.17171501344251, 49.86833580078618, 51.85411807029478, 52.02399592245779, 53.82641523115097, 51.228582397584, 50.42375126192647, 47.62355158405919, 44.5295310789539, 45.18429625418879, 44.977097049836196, 45.679491566073516, 47.07667904515421, 51.55626504651962, 52.720181326712336, 46.26365015583654, 44.87495853054909, 51.438801826969275, 48.2554611083, 46.0117280867792, 45.67857373145319, 48.76867186638617, 50.27586613931964, 47.831350911048155, 47.16072367083642, 45.36385451593707, 46.20108442921793, 46.82867150152884, 50.72127872897733, 50.59636300609958, 51.082203465123335, 50.876663423353634, 49.79525419973558, 50.18623998088222, 49.28462043885262, 50.89777754199121, 49.64111681907408, 50.29542307699881, 49.15247578774729, 52.97198180229434, 50.96936864237632, 50.508156745664536, 49.59827276968187, 50.605109891583844, 51.71748230534216, 54.933637572873025, 54.07499151845133, 59.72279271771831, 59.614574524664114, 59.62072872346448, 59.118594738744925, 58.23823052067911, 64.94162782546013, 73.12685735764043, 76.52711299157913, 79.22655090208977, 75.19771975855674, 0.407880685862995, 0.6717497735254226, 0.016943857734722477, 0.15544719182916228, 48.23658666303081, 71.10653077402424, 56.788389144405244, 42.64829566401821, 20.459225985311694, 17.9661714261578, 4.221399907142886, 2.4200315485077524, 0.2551364360917961, 0.04162008603734355, 0.022019969727543574, 0.021518691585609512, 0.06495711603952993, 0.007202226232977645, 0.059939975579900134, 0.042427060074142875, 0.03151709277693543, 0.10213130273886266, 0.09935656292063576, 0.027152140204223896, 0.024691272354234132, 0.053016846669056726, 0.06358378086118929, 0.22747670901158165, 0.3433688814120908, 7.061282694339753, 66.926437347166, 59.632236957550056, 42.614747631934385, 40.080445428048414, 64.51589768932712, 69.36156242124497, 75.72196806630781, 0.30637817277062324, 0.06705946814749511, 0.45983349003138085, 52.493942937543316, 97.43314989151494, 81.58242840920725, 79.65687413369456, 74.00077712151312, 82.00914306025352, 83.82100351395147, 85.61192635566958, 82.1859948865829, 83.47954550097066, 79.4752997736777, 75.9580712164602, 69.9011315068891, 68.98399506845783, 61.506066937600416, 60.405645985757154, 56.93946315396217, 56.564002113957564, 56.98588048258136, 57.757469531028505, 55.09208563835391, 55.01711345488026, 56.55691831342636, 54.91174290257116, 54.67310197891728, 54.497611215037686, 53.93622590649513, 55.56051469618275, 52.42901594408097, 53.1134577720396, 53.436802279564645, 52.43531919294789, 50.8448176999246, 52.70406038530412, 52.31125070202736, 52.84877231044155, 55.11611800039969, 55.34252112911594, 51.666162014007575, 47.243054220753336, 45.28000993113364, 46.05373274895453, 50.29585061534759, 51.623808260886904, 48.83230840006183, 49.038405418396, 48.48075028388731, 50.567882676278394, 44.64149513552266, 46.55454097255584, 45.565072105776885, 44.762111940691554, 49.54965499139602, 51.19208474313059, 52.29094851401545, 47.71720209429341, 50.02270460128785, 52.37091779708863, 53.59078668778943, 54.35782578683669, 52.28117788991621, 55.52409941150297, 59.29134376587407, 62.3354011197244, 57.5309173522457, 45.625555053834, 37.72384228244905, 48.52417484406502, 63.72400645286807, 30.629504303778376, 38.04508047719156, 42.12191358689339, 35.91932450571368, 54.692435341496626, 62.83562491017004, 60.44973734886416, 57.851763309970984, 49.6389046022969, 49.63105986195226, 51.10134463156424, 52.60202384764149, 52.801354777428415, 53.42053228808988, 53.691477852482954, 52.95461746954149, 53.19911449186264, 50.358502634109996, 46.59324299904608, 48.12131997077696, 46.635208437519694, 48.931579666752974, 50.82789267263105, 52.338428804951334, 52.99018159989388, 47.79659478895126, 46.500945706521314, 53.39743345014511, 49.20114455684539, 45.873123292000066, 46.79713172297324, 48.977447863548036, 50.40942676605717, 50.822715144003595, 48.64535647053873, 47.6376485824585, 48.40846100161153, 48.85739195731379, 53.51675587315714, 52.9482122390501, 54.77832740353, 52.320511418004195, 51.67783106527021, 53.98492213218443, 51.25057120477, 52.13766621005151, 51.35193309476299, 52.91550359418316, 52.83699343281408, 55.011794720926595, 53.85600166936075, 53.57883130350421, 52.71637270527502, 54.36290917858001, 54.33895526393768, 58.056573790888635, 56.43582297909645, 61.41679771484868, 60.257400005094475, 62.55187280716435, 62.95753217512562, 63.592206970337905, 67.94993277518981, 75.08691280118882, 80.42769047521776, 83.53503134942825, 79.88300661886893, 0.5068817993085231, 1.330024857194193, 0.10505402010054359, 0.09596857737990157, 49.028528890302105, 77.25194346520209, 66.34507932970601, 50.65276668917749, 26.76156682352866, 39.96497085017543, 24.455168054949855, 1.2559213561396445, 0.12485316413785182, 0.03494201333171899, 0.06746526492098648, 0.021134504237242287, 0.0033829351060933647, 0.04377062890618559, 0.03602516589566104, 0.06394694101125484, 0.2669693842049568, 0.3536231521396868, 0.267096953166108, 0.19475744616600776, 0.06395369407630737, 0.19697197652872533, 0.16013496044662692, 0.28064334885247294, 0.580301183846689, 7.5776063434539305, 80.9562926138601, 62.53599113033664, 49.889767631407715, 55.01403439429499, 73.64596736046576, 74.46286370677333, 86.6738296324207, 0.896512309630071, 0.28250497315199147, 1.2223383904464784, 53.790403950598936, 102.55702049501481, 84.3826320094447, 82.6783464800927, 75.9941021088631, 83.24994564056396, 86.80351887979816, 87.42700315290882, 87.06419175670993, 86.6104127514747, 82.6334039626583, 80.50725183179303, 75.98564547877159, 70.7782127011207, 62.07851333002891, 62.6260369823825, 60.66097659449424, 58.87215222081831, 60.7425501269679, 63.1857866625632, 60.44890188401746, 58.31275163158294, 61.40743109487719, 56.45215572849397, 56.84606367541898, 57.92333479850524, 57.08585385353335, 58.55443631449054, 54.57503487986904, 54.64631219064036, 55.35804979262814, 55.309557530187796, 56.75157770033806, 57.19312675537602, 55.52244809366042, 54.635443302892874, 59.052844047546394, 57.24376455430062, 54.11699618062666, 47.09971512517622, 45.301288789318455, 47.350597766137895, 52.20037314199632, 51.86945061529837, 50.796290136152706, 48.058071751748365, 49.85831022262574, 54.740680494616115, 47.59575374664799, 49.87185808920091, 48.167125409649266, 49.08583471851964, 54.11850237077283, 55.69634245287988, 54.71838966492684, 50.31186173039098, 52.86524626516527, 56.74806717903384, 56.09372561977756, 57.10079808388987, 57.3810867340334, 59.8091083957303, 62.764947722035075, 65.23326781488234, 57.80993123208323, 47.06610433516964, 45.117604194148896, 55.30064982752646, 69.13203316350138, 30.449422405612086, 43.797589348208525, 46.018317668668686, 38.16513638342581, 57.69611973916331, 63.30335970847838, 64.08334262909429, 60.48152815911078, 53.0031999464958, 50.89971127048616, 55.82518839067029, 55.42388285360029, 56.288663494971495, 56.64177486973425, 57.27135450609269, 56.109077776632006, 58.602328454294515, 53.174921312639796, 48.848390117768325, 50.901233150113015, 50.047282172787575, 51.22563669758459, 50.29603496674569, 53.93852833778628, 54.02751122751544, 48.06701475574125, 48.42983399668048, 54.25983321282172, 50.91614207913799, 45.66181344370688, 46.10494713629446, 50.10904381352086, 52.71224244948357, 53.39304431792229, 51.97538598891228, 50.91054877927227, 52.222687505906634, 51.82659087642547, 56.33278231466971, 55.192110000118134, 56.68640751992503, 55.64274326447518, 56.09395311724756, 55.160695737408055, 53.51903084785708, 55.62642228218817, 55.18551649585847, 54.642911495700965, 54.902152707499845, 58.218269578872196, 56.83779531909574, 56.30785565222464, 54.613580011552386, 57.14686632156373, 57.43643137716479, 60.19832911029939, 60.46137502116542, 65.3849458694458, 65.4197725942058, 64.03677232803838, 65.44810779633062, 65.30573360381588, 73.10203659919001, 76.94304896939185, 85.98318653721964, 85.71005621264058, 85.91041872578283, 0.8122980414379029, 1.9942922193196513, 0.12197592175535618, 0.49537218626468416, 60.0001121336414, 83.62908194142004, 74.58150755974555, 67.04852504114952, 35.70557102080315, 43.41434240341187, 48.69469204256612, 4.134175710139736, 0.5456471659483448, 0.12570344512501072, 0.171249425339122, 0.11716581655726319, 0.2713960240925512, 0.12628626949604482, 0.21030395952684267, 0.1441145757393491], [0.019695327632249366, 0.06588028263180487, 0.052237486271488096, 0.06104493100616721, 0.0812181749290997, 0.12273577372393302, 0.1136847283510912, 0.06815344170336762, 0.3059503279866711, 6.560452897702494, 64.02368337877336, 42.95901406195856, 36.283853900048044, 36.25739751323577, 50.92341415343746, 76.39194811544111, 54.69317274708902, 0.05734992806889838, 0.0705334164142128, 1.8981175413054807, 79.35877400059854, 88.06367443453881, 82.51206936374788, 75.97774582524454, 75.91297180421891, 82.25516980694186, 82.16817948126024, 80.88973783677625, 81.00691472330402, 76.73722651696976, 70.75071688621276, 66.67045562498032, 63.80546231423656, 58.0119058393663, 58.202062345320186, 59.364284161598455, 55.204959684802645, 53.46805572509766, 53.833047959112356, 56.116942128827496, 54.50368304406443, 53.24929729584725, 53.576517105102546, 52.480657869769686, 52.85895086103871, 51.86595578347483, 50.65630466707292, 50.160932848530436, 51.335470907149784, 51.13694406324818, 53.57132780936457, 47.82779332130186, 47.19670749479725, 47.56138593919816, 48.57547160117857, 48.30169800789126, 51.79013636804397, 54.40534137910413, 50.39623975753785, 51.09459815486785, 53.642558051693825, 46.67811524483466, 48.954788331062566, 49.15846132463025, 46.99254420495803, 48.19465652588875, 46.863906152786754, 48.46260147710001, 45.187594967503706, 42.75518809595416, 41.79649414554719, 41.653131515749045, 42.87517732189548, 44.001007387715006, 44.578870573351466, 49.695979010674264, 46.05608617105792, 44.246218281407515, 49.65167976194813, 47.407452521785615, 48.86347555345105, 49.69204095102126, 60.258878738649436, 56.655063859878055, 62.292961074459946, 40.203921641072924, 30.546924683355517, 42.312634914152085, 53.77940954700593, 40.00702258079283, 26.049654676068215, 44.81313805426321, 41.652421566747854, 58.36096540574105, 59.923924015414336, 55.872802042192035, 52.1954741016511, 51.4317141040679, 51.33531793471306, 50.13762612496653, 49.00697154383506, 49.420816898345954, 47.549865938002064, 44.46223497390748, 44.34057481827275, 46.66162560063024, 44.14684895546206, 44.02760105748331, 42.59861100104548, 45.4799174493359, 50.35479207192698, 48.42239326046359, 51.561230767157774, 51.70530726832729, 52.00977340821297, 51.03852002851425, 54.02321623217676, 47.25426043233564, 48.58597178612986, 45.822281529826505, 50.808170995404645, 50.14451772935929, 48.545885162968794, 46.0985379834329, 46.53590971423734, 45.34221087732623, 46.7054541649357, 49.878286853913345, 50.63799112073837, 49.94513580876012, 51.30242493844802, 49.41350167797458, 50.93140794384865, 51.94209683325983, 49.883119213965635, 48.76401601299163, 50.59988529451432, 51.436358190351925, 51.5282710905998, 50.925814643982925, 52.28583766568092, 51.590377899908255, 51.89975876961985, 53.382567667192035, 55.911437388389345, 53.28368863751812, 56.79364119806598, 57.680881331043864, 58.857482556373846, 57.538844462363954, 63.68089175993397, 63.93462596401092, 75.57347497632428, 75.18651746934461, 81.9995960112541, 72.55905505149596, 2.3850288073862753, 1.7699218589452006, 0.1798342679056429, 0.28855198092999, 20.911204622637843, 79.30185256465789, 59.07738631771457, 48.56857215204547, 23.929046815441502, 24.684207016421905, 11.823061166271088, 3.7403609195063194, 0.40159563924516406, 0.06761747126978251, 0.0993594357503518, 0.07588686181172248, 0.026831679879837943, 0.04058508976032177, 0.010098397690472345, 0.025604190605302012, 0.0358924335019002, 0.016031982320841524, 0.022512104610101353, 0.0487950012358206, 0.05999231087644735, 0.16173383190987572, 0.03635367588891137, 0.10449420134987562, 0.4948713179797896, 12.169101488205696, 72.78092784266319, 56.63236118132069, 38.94690790484029, 38.37634425009451, 60.57142103871992, 84.10203349205756, 60.54186597947152, 0.03707187182660546, 0.07829196420648406, 2.276814046405977, 88.49585686960529, 88.37883687788441, 85.21485697838568, 77.01706409454346, 78.90458706886538, 84.52735962406283, 85.94510032284646, 81.68041706085205, 83.042601308515, 79.1356695851972, 74.53672978185838, 67.55533449111446, 65.44165157502698, 62.4004065605902, 60.943571598299094, 61.98720447478756, 56.67013360608009, 56.612478686917214, 56.57015631275793, 58.25607730496315, 55.88761683433287, 54.30589360575522, 55.34079136386995, 54.940003579662694, 56.166163952119895, 54.254667451304776, 54.24728162827031, 53.70994829362439, 53.16593124020485, 52.215395819756296, 54.7172482552067, 51.464634556924146, 50.35192089696085, 50.05263620807279, 51.494836807250984, 52.02162681087371, 54.633854742973085, 57.432391335887296, 50.709970535770545, 51.10898540865991, 54.58356211262365, 49.095824995348536, 50.8412326535871, 51.29951846215033, 49.05568345900505, 47.42566408649568, 46.16840716331236, 50.75900408529466, 48.7718411414854, 45.36665116586993, 45.39072667398761, 44.57301839705437, 45.084052239694905, 44.93119747407975, 47.79853636218656, 52.357750400420166, 51.20759771716211, 46.245999490061116, 52.25282307594053, 49.29695237067438, 51.386300902212824, 50.612181925004535, 63.825882173353634, 58.8628875824713, 64.82315263440533, 45.12422515499977, 33.877267991342855, 48.74800489794824, 56.176079703915505, 45.29072584644441, 29.004823277073523, 46.69531876041044, 48.15709198674848, 62.22449610310217, 60.239219819345784, 60.0774142049974, 52.789944602597146, 53.0421490823069, 52.38687792131978, 53.126417283088934, 49.680913186842396, 50.26198094890964, 49.97124702699723, 46.89281402095672, 46.86519269020327, 49.13681768601941, 47.36126269063642, 46.559137990397794, 43.56203925225043, 48.90540961296328, 51.25439551568801, 49.57415019312213, 50.41777356978386, 51.225699455507346, 54.26408898445868, 52.01078145734726, 53.694329415598226, 48.35372432585686, 48.82570312869165, 47.41290069395497, 50.78941029887046, 51.0015046211981, 49.43807924947431, 48.91566268859371, 48.720669900217366, 46.96737827793245, 46.81155427809685, 52.319515135980424, 52.003489771196925, 51.86380240225023, 52.143459550796024, 53.565432486995576, 52.90056328619681, 52.5615999006456, 52.71571766945624, 51.72852377737723, 53.5670445811364, 54.47826216297766, 53.97120168132167, 53.95498268065914, 54.94012909550821, 54.84523519392937, 54.99813310561642, 55.53899265104725, 57.86929238227106, 54.66816763724051, 57.575789267017, 61.24533522513605, 62.12326365132486, 59.79547423701133, 65.23863753964825, 66.40874724234304, 76.06329271870275, 79.30410400513681, 83.87134321274297, 78.40270411583685, 3.0009230490653747, 1.8614853005255423, 0.09869069461860965, 0.3589650219486606, 20.58357688688463, 86.90268424249466, 65.79249189745995, 58.74636965413248, 28.226717210585072, 44.451923062724454, 31.204145262318274, 2.651054248694451, 0.27563812872094495, 0.0713619175216844, 0.023758257701692563, 0.028401704302297968, 0.09868490299390209, 0.05237295742957823, 0.06428681974930149, 0.04760195718958013, 0.12241842180129983, 0.20326938780565418, 0.1162959237192427, 0.20088287070393565, 0.16799563542008403, 0.30630024630696545, 0.2408662711780879, 0.2703721016164749, 0.6065254766614206, 13.292604607920493, 87.28465249461513, 55.31920656081169, 47.405130478643606, 51.08773792943647, 68.58675310688635, 91.42283147381198, 67.28294157212781, 0.24305309980146347, 0.36829931300974666, 2.6223954510304237, 91.08400929358699, 92.4092605037074, 91.27027480832993, 81.24339442099296, 83.04791219772832, 88.0790501256143, 89.08211784978067, 85.12341084018831, 87.05932017295592, 84.40848042888027, 78.82074248406195, 70.27704361946353, 69.40916430565619, 64.18433973866125, 66.00439010127899, 65.5541608410497, 60.80991683467742, 58.28904090389129, 59.00613254116428, 60.43996672476492, 60.60227832486553, 57.45712580219392, 59.96295159862888, 57.40107513243153, 60.059794918183364, 56.70250100474204, 56.36966043902982, 54.44489848229193, 55.879736792656686, 55.737825439822295, 56.849213338667354, 54.18479042668497, 53.70373133690127, 53.11238696498256, 53.302323818206794, 54.039270493292044, 56.186113126816295, 58.69601818823046, 51.26442893858879, 51.68985312984836, 56.10813248542048, 51.905936502641254, 52.12519699527372, 51.40025277291575, 49.27971747613723, 48.908720093388716, 46.059502555478005, 53.28778359197801, 52.64800579317155, 48.49200356391169, 47.8090012458063, 47.45612913562406, 49.473553165312744, 49.362769742165845, 49.58375607767413, 53.165154610910726, 51.527388557311035, 49.41414102431267, 54.95344554224322, 49.53604436689808, 54.57588211182625, 53.437833862919966, 65.73321311704575, 63.06624458682153, 68.66174882458103, 52.02277214296403, 39.50723417343632, 53.35655058583906, 62.74096242843136, 46.893555348919286, 31.800561258869788, 51.00460721600441, 49.09328329947687, 60.45546400931574, 64.70916463482764, 63.27084325974988, 58.12873755731891, 55.66239041666831, 54.591191122608805, 55.98657038904006, 52.97205632732761, 53.67010877978418, 52.52664766004009, 48.80157270739156, 48.977306658221835, 51.902476972149266, 49.11893560040382, 48.68561175561721, 47.68484646274198, 49.23432780850319, 50.197450114834695, 51.684652066999874, 49.729385837431884, 51.56827926635743, 53.76080574527864, 53.702103553279755, 53.936186682793405, 50.85142689366495, 51.15482614886377, 46.190768595664736, 53.54661295490881, 53.83207521130962, 52.660012168269006, 50.069835801278394, 52.492856441005586, 50.62024631807881, 52.232207098314845, 54.32478766287527, 55.161939128752685, 54.12989685612341, 56.76548642496909, 55.50842562029439, 55.26301860809327, 57.66823560960832, 54.234561381801484, 53.80776828335178, 55.133164621168575, 55.85379423633699, 56.85699139871905, 56.201073046653505, 56.65935101047639, 57.355195168525945, 57.48632784812682, 57.771931309853834, 61.886305424474905, 57.03194872025521, 62.208618348644634, 62.91970091481363, 63.64483733331004, 62.48109363740491, 69.77694142249324, 69.54723958046206, 81.38485862362771, 83.041440286944, 87.24851962058776, 83.3472361103181, 3.916704553750254, 3.856210574027031, 1.3481593228155568, 0.26375405189971773, 28.400166380789976, 97.08448256215742, 73.32529006465789, 69.64966051040157, 41.38224478690855, 49.04107263011318, 52.020873715800626, 7.917326746448395, 0.6498330398913353, 0.2218575460175353, 0.2586181371683075, 0.22461008460771656, 0.19975267651100315, 0.1653087505650136, 0.18139437531992314, 0.19572761991331655], [0.059318793186497305, 0.08353223543493979, 0.056309216775961464, 0.1692406202275907, 0.05879901402119187, 0.018214012360981396, 0.018674147750941977, 0.12533881791657017, 0.5906164658165748, 16.27533668471921, 62.274278825329205, 36.563346309046594, 35.0060280676811, 46.074795876779866, 51.04856129615538, 80.53852881154707, 39.10566583756478, 0.1559786576657526, 0.9053378876659178, 7.72377101644393, 101.75440942087482, 76.93746351426648, 79.99600225879301, 73.86299994684035, 79.17665835349791, 79.12752674471948, 82.63433748675932, 81.41318598101216, 77.34862988994968, 73.86509449251237, 68.85687105117306, 63.65067382012645, 64.5782280737354, 70.20675474597563, 67.87616083698889, 60.54453319118869, 57.60219858538721, 55.276025187584665, 52.01234648304602, 52.86372830790859, 51.454597211653194, 51.02737265248453, 50.758804044415875, 52.86365378287531, 51.09823811438776, 51.84003676137617, 50.911231271682254, 49.94417482806791, 50.52232434672695, 52.15022563934327, 50.14864406278057, 47.91770189039169, 46.83171526078255, 48.84517377422702, 46.951939828934215, 48.84102390658472, 48.052349013666955, 55.38166246106548, 51.29577259863577, 47.65345573425294, 52.92633718059909, 49.691468284976104, 47.44680566172446, 48.06381802405081, 50.31015157699586, 43.66428367553219, 46.36960906367148, 46.25854715224236, 48.29007994744086, 44.07334766080303, 43.32358267999465, 43.23436052568498, 41.59265641243228, 42.714548418598795, 44.473652993479085, 46.017497893302675, 47.955701812621086, 51.74550764022335, 54.930801699238444, 50.39382749988187, 51.57368429245488, 48.69304856946392, 59.34835541632868, 57.109219412649836, 61.37616588223366, 40.52542655698715, 30.677682776604932, 42.10633785493913, 46.97615654237809, 45.19181543780912, 35.25458474313059, 39.27285686615975, 58.14192064346806, 57.715217759532315, 56.27645707899525, 55.449593990079826, 51.0025401269236, 50.02740360075428, 46.830424800995864, 48.014804086377545, 47.964829168012066, 46.559526305044855, 46.518204135279504, 46.41499873130552, 45.238636770556056, 43.330956735918605, 39.65929662027667, 42.21660744759345, 44.41970863649922, 50.337168862742764, 44.4662122572622, 49.27569312434043, 54.77757430845692, 52.39645634928058, 49.64711412306755, 49.66575714849657, 53.14874733647993, 45.82334056977303, 43.05613979216545, 47.5418839147014, 48.06141753350535, 48.60663090982745, 47.57027010763846, 45.47321411871141, 45.62564919071813, 46.33503337060252, 45.18833629546627, 49.16903211224464, 49.16139525751914, 50.03706047611852, 47.86894290677963, 48.78827979487758, 49.76998629108552, 48.75516322351272, 50.61466870769378, 50.57210314658381, 52.13594036717569, 50.37802034808744, 50.79678043242424, 50.246542499911406, 51.50977319286716, 50.46699931544643, 54.00365537212741, 52.00660021074357, 53.23888340303975, 53.48303917915591, 59.24206310702909, 60.22576216728457, 61.03246427351429, 60.530781361364554, 59.83203857175766, 64.038015719383, 73.13992669505458, 73.17926806788292, 79.84084113951653, 70.88109647074054, 2.887656520451269, 0.6255254990631535, 0.2057924217754795, 0.09217267300212577, 6.234551495121372, 72.93640275155344, 61.82466145484679, 54.3239757322496, 33.189707879097234, 23.837677163462487, 21.01148589964836, 4.976695920190504, 0.05831013884275191, 0.06039951342127978, 0.03144677739680535, 0.05189844639971853, 0.016702375329670407, 0.0855596028568764, 0.016158351396781304, 0.043057914327589736, 0.07461478813521324, 0.020267120337173827, 0.02067214527708148, 0.1284716119088473, 0.034103177698148836, 0.20331025093553529, 0.06286388420830331, 0.14123152641038741, 0.5063914111064327, 26.431093408215432, 70.54948360689225, 42.11241360633604, 31.32945518339834, 50.447183501335886, 60.95915909736388, 88.06445106383293, 41.04117116620464, 0.1410655611224713, 1.0400298117629945, 10.948312801699485, 106.46424247372536, 75.82565984418316, 85.58061799695416, 74.72974177329772, 84.29445712797104, 81.22941509369882, 85.4912664044288, 82.81862612693541, 78.95709191599201, 76.29919190560618, 71.07560680758569, 65.10989750585249, 68.0762174052577, 71.84977285323605, 71.02466306378766, 62.40778453888432, 60.292450304954286, 57.34541669968636, 56.59398471155475, 53.91586880530081, 54.33216956353957, 52.47049108628304, 54.24021743958997, 53.50834238913752, 52.63994532246744, 55.35673579862041, 53.89737090756817, 52.960073486451186, 53.02073686353622, 52.68320122072774, 51.61297467447097, 52.29798132373441, 50.65159782286614, 49.85989486017535, 50.65032305256013, 51.48002593748031, 51.01129485714821, 57.294206234716604, 51.56181912268362, 46.99041828032463, 52.5763205559023, 50.94674833359257, 48.42551546712076, 48.02369217718802, 54.19101522814844, 45.391872006077925, 46.80233670819191, 46.90932719938217, 50.628193040047925, 48.05416507105674, 46.01410504310362, 44.53213553274832, 47.16066875765401, 45.38617280221755, 46.15298440379482, 47.52937939859206, 51.2885005243363, 52.58603626681913, 58.589761180262414, 53.997658068133944, 54.735867746414684, 51.12385511398316, 62.435076390543294, 60.22882946075932, 63.696392966854965, 41.19623422622681, 36.50637780466388, 47.31894423884731, 49.507548347596206, 49.40221701898883, 40.09658205893732, 42.79965208422753, 59.18926015976937, 58.24117622067852, 59.98283409303235, 57.16278722209316, 52.55084083926294, 51.686758379782404, 50.01054525375367, 47.50906936583981, 48.9285437522396, 48.65193036294753, 47.930492739523615, 49.38726102152179, 46.8665341408022, 46.88833859659011, 43.87056504526446, 44.77461645680089, 46.47093172996275, 48.27550049751036, 45.543502992199315, 50.14077971058507, 54.76666619700771, 51.60747158911921, 50.284765997240626, 50.60816149557791, 53.92840077800136, 47.81073101105229, 44.797464263054636, 47.18632498095113, 51.38919953377017, 50.45239240892472, 49.584924943985484, 47.69926901786558, 47.6418141395815, 48.906868734667384, 48.68991851806641, 52.13934890685543, 50.13636312177105, 53.6780829583445, 51.03631173410724, 51.53307991643106, 52.93685305503107, 51.75224234980922, 51.91213384751351, 53.51831697648572, 53.00288615688201, 52.950804925734005, 51.141023328227384, 53.21183866070163, 53.240440583998165, 53.13325005192911, 57.757073371641106, 54.87447646356399, 55.209203689329094, 57.39137903336556, 61.345222303944254, 64.50871190717145, 64.63407870261901, 63.39816339554326, 63.03711314355174, 67.35614868902391, 74.82683612454322, 80.6523952176494, 83.89382623857068, 80.24581017032747, 4.378203518929021, 2.170192503160046, 0.5951160985615946, 0.2832560151094391, 6.130454242229463, 78.64798561219247, 67.59888064476752, 65.998153532705, 36.24856041323754, 30.49869521971672, 44.47744200306554, 10.978090455455165, 0.1304284302938369, 0.009731634054332972, 0.030534092802554372, 0.0570403979039721, 0.007767608697195688, 0.0543468059491246, 0.008034460103860306, 0.1136969704361212, 0.14134294623809476, 0.15669550145826033, 0.16953283680542824, 0.2708776277159491, 0.19110933547058415, 0.3042226158563168, 0.21058220266094133, 0.24328024487101266, 1.024189442396164, 29.38712493065865, 84.26424703290387, 46.310220456892445, 48.311354883255504, 63.96215708025041, 68.17065238952637, 95.0930638467112, 48.67229923125237, 0.3170962331275786, 1.0847113690068646, 9.613415502732801, 114.38643393977996, 79.08241948773785, 90.79239676075598, 76.9180085582118, 89.6311398475401, 82.03635646450905, 89.37651526543402, 85.58094747604864, 83.47937291668308, 76.73054279819613, 76.94545730467766, 67.73424948415449, 72.87692393026045, 74.44884515577748, 73.82274858413204, 65.76122668481642, 65.38297291724913, 59.20816990637011, 58.75327302563576, 58.72935833469514, 58.25258639550979, 55.85723023260794, 57.071709786691976, 56.95455251201507, 57.208596583335634, 57.23789668852284, 57.193797480675485, 55.30148921474334, 56.55341955923266, 56.50636288427538, 57.807546431018466, 53.93904609064902, 53.096050293214866, 53.29177656481343, 53.75499671505344, 54.821532310978064, 53.194231140998106, 59.001888536637836, 52.369250789765395, 47.30295273565477, 53.677518137039684, 54.104715239617136, 53.001638843167214, 52.31943668857698, 58.89216807580764, 45.788227511990456, 46.92799375903222, 46.591101384931996, 55.40776975693242, 51.17712874566355, 48.679951775458555, 48.42229127883912, 48.13735854241156, 49.72594199642059, 51.01100067938528, 50.988945191906346, 53.41731202217841, 54.95350045542563, 62.12064743041993, 55.583895944779925, 59.67080954582461, 53.64273848072175, 66.43348170864967, 63.972837694229625, 66.56403387746504, 47.33493181966966, 41.669056338648645, 54.66222916879962, 56.26412514717349, 55.44493813668528, 42.040273374126805, 46.89150787168934, 61.586491215613584, 62.86835708925801, 61.766853563247196, 60.57957956867834, 53.97306088478335, 51.71778040547525, 51.424504787691184, 50.98303810242684, 54.94997032227055, 50.987340942505874, 51.64999008178712, 53.521290133076334, 50.223122027612504, 49.526469861307454, 45.38043829702562, 47.60362594358383, 49.4855595404102, 51.45984534294375, 49.50323374040666, 50.92710902613979, 55.87341785430909, 54.17629065052156, 51.12917777030699, 51.03950062105733, 54.950837166078635, 49.626180433457904, 48.134412842412154, 47.31179375802317, 52.67263827785369, 52.510714992400146, 51.85554581303751, 51.540599100051395, 51.8061984738996, 52.18932382522091, 50.338482856750495, 53.79940186777423, 53.31194146986931, 55.85624964006486, 52.88890207967451, 53.82102981690438, 55.94594247879521, 54.83243257768693, 56.46336978481662, 55.91836821648383, 57.56186877527545, 57.74180750693045, 53.75666764474685, 54.8320403406697, 55.932508360955026, 56.00038889915713, 59.94410068758073, 57.120382478160245, 59.39640445093955, 59.85274868626749, 63.85870456695557, 67.75817594220563, 67.63243259922152, 66.64421496852752, 65.54995998259514, 71.0267105410176, 79.16459314284786, 83.0030716619184, 88.83462413664788, 86.65071118262507, 5.157754978825969, 3.1414208777489203, 1.2347251128765846, 0.3414928853031128, 10.181464918198126, 87.07468801929106, 73.37465701564666, 74.20996496754309, 60.255070117212114, 47.033866374723374, 55.423804406196844, 22.70057616695281, 0.5022092145537177, 0.22608754645672538, 0.11437722586936529, 0.1449852806305693, 0.11941494345064126, 0.2926497239499323, 0.1047348065842544, 0.22525114698275445], [0.1118887577866835, 0.01765548063802623, 0.07165054880803631, 0.03893353060008057, 0.028995805487577474, 0.05489690304403344, 0.03307313034911791, 0.12176978281669079, 0.06868796423077583, 32.57855553780833, 64.98205177245602, 40.09073772738057, 21.462478060876172, 47.20762737335698, 53.855244651917495, 87.64834250173261, 28.493391313860496, 0.302458192792631, 4.3403859869126356, 52.57105673513105, 91.86518853710544, 79.45687247860816, 80.5850402770504, 76.98174707351193, 82.45766608945786, 82.23089818031558, 83.2564018618676, 77.51098463612219, 76.37288539640366, 68.73898029327393, 65.33542986839049, 64.78207757396083, 68.5332598224763, 66.94469990268831, 68.35960080546718, 71.52696178805444, 64.00350670660696, 58.02341799582205, 59.574013294712195, 59.51813520923738, 61.038112486562426, 57.662375588570875, 58.135374207650464, 56.74999306278845, 50.92468107900312, 49.94118205962643, 50.781338061055834, 50.315486000430205, 54.203982583938114, 49.80791168828165, 50.195430094195956, 50.01885675614881, 46.59326653326712, 50.31651366141535, 49.553498914164884, 47.90050229718609, 49.66775363491428, 52.701216666929184, 52.680137849623165, 47.08511998576503, 53.32439107279624, 46.005052212745916, 44.45527668922178, 47.170266797465665, 51.02081444955642, 42.071632723654474, 45.47007230020339, 43.197015639274355, 45.250835341791955, 43.9183355915931, 45.88497277229063, 43.26434312328216, 43.44629795320573, 41.60828313519878, 42.92656821589316, 42.55870872928251, 45.015732396033506, 53.51126063254572, 57.30070167972196, 53.377095960801654, 55.968970714076875, 55.48336167489329, 59.91017610796037, 60.02770993017382, 62.82006486769646, 42.18333398142169, 39.33910569837017, 46.15034464866885, 39.04483379856233, 42.446058257933586, 41.46798387650521, 40.52644245086178, 47.001075360082815, 60.99897507698306, 57.1768646086416, 56.208094089261955, 53.32366935668453, 53.53843089072935, 49.6165039462428, 46.81146798595306, 46.1715607489309, 45.436316382500436, 44.94842452387656, 42.76608444029286, 40.063920482512444, 40.473729718116026, 42.33082686701129, 45.34417206241239, 43.801496028900154, 49.15377409227433, 45.351314698496175, 51.9830620673395, 52.43221267577141, 50.67287668105095, 49.17812808867424, 52.34170398404522, 50.81612948448428, 50.69078230088758, 42.25146947368499, 46.86428662269346, 50.80018112736364, 47.48566850539177, 48.45596874913862, 46.301646155695764, 45.66905806141515, 44.044671212473226, 44.50890333421769, 48.727941974516845, 47.4767098119182, 47.196738873758626, 49.724820198551306, 48.370939608543154, 48.11136499527962, 50.538147188002064, 51.832392061910326, 49.61023207633726, 51.01435430588261, 49.58862766142815, 52.28992477540047, 51.59661839085241, 52.82475563787645, 52.81125483974334, 52.474852761914654, 54.22641854132376, 56.487802228619984, 57.03400796459567, 62.2976992976281, 63.626472796163256, 65.0714151320919, 62.38325795819683, 62.13002973987211, 65.35137038077077, 70.94600385235202, 75.5781739757907, 81.63590600413661, 57.470740349062034, 5.7808058300325955, 1.1728415109457508, 0.36774892480142657, 0.09008658494079307, 1.7084277974021052, 64.56487632566883, 67.22663987067439, 52.603710466815585, 26.50580671525771, 27.38773007546702, 20.467255077054425, 8.679399144264961, 0.06316717458708633, 0.07305198409143956, 0.043759578087877844, 0.05135846932628944, 0.026066132047544086, 0.043111820104381735, 0.017380845778050925, 0.0416025732673945, 0.033764141656818895, 0.03335224299301063, 0.09050248641400568, 0.07252419547688577, 0.07518089646773954, 0.011578729496367518, 0.019506691887433973, 0.14329452458168232, 0.026310590704181985, 42.534448869766734, 71.2325329934397, 44.22668487794938, 21.522760968054495, 51.52720028354276, 63.33711562618133, 92.6384916613179, 30.447904448355402, 0.5818928694052081, 8.524406686905893, 63.73787595379738, 95.715253737665, 82.11697686103084, 85.11550334192093, 79.97417819115424, 86.00342596730879, 83.89597569742511, 84.75506105730611, 78.47833525749945, 78.26216559256278, 72.67891483922159, 69.41383192616125, 68.05978267423569, 72.99797611851847, 70.39349094513925, 73.21267097227036, 74.48310313686248, 66.0720980551935, 61.27249371620917, 63.27942932805708, 62.53743848493023, 63.13954584060177, 60.632559022595814, 61.980775710075136, 58.43055609733828, 53.400237944818315, 52.048240092492875, 54.04090219928373, 52.32822672013314, 56.061762225243356, 52.292113457956624, 52.39229471452775, 51.76962629441292, 51.13640669853457, 50.388904925315614, 52.31498872080157, 50.49272614140665, 53.80273196005053, 54.06724875973117, 53.33659748877249, 47.14241404687205, 55.10543738642047, 46.445875629301995, 45.65283121601228, 49.925033661627005, 52.07377472231465, 41.65937985143354, 45.30002970849314, 43.73544723756852, 48.11327911192372, 48.07332192697833, 48.584806842188684, 44.746191040162124, 47.36427899329893, 43.858209579221665, 44.413746633837306, 46.05632151326826, 48.10519510699857, 53.92221912260979, 61.48545880471507, 56.254785983793205, 58.08931773708713, 57.67016933810327, 63.10594289533554, 63.71141956698511, 63.71701286685083, 44.54274946643461, 43.112865109597486, 48.36668383690619, 40.6096790682885, 47.03179928564256, 46.15394930685721, 45.660169970604684, 50.39448253570065, 63.441113348930116, 59.146318051122854, 58.99098826992897, 55.40463186079457, 55.177950243796076, 53.11941192996118, 48.78714230752761, 50.17047989752985, 46.313087709488414, 48.764816176506784, 44.93965410417126, 44.332400598833644, 44.75191377824353, 45.18997192382813, 46.243791195654104, 45.81159307110695, 49.973745576797, 48.635330892378285, 51.21635244738672, 52.16169464972712, 50.9350557481089, 47.95435643965199, 52.770477879431944, 50.839349915904386, 52.81604013135357, 46.3976030195913, 48.940028452104144, 52.76444135173675, 48.919259502041726, 49.02962715395036, 47.36283556107552, 47.922330287195024, 47.53546299472932, 46.59253305004489, 50.201101841465125, 49.749374235830004, 49.663172306553015, 52.62627194004675, 51.13559084553873, 51.906415031802275, 52.52236443181192, 54.153364396864376, 51.600003396311116, 52.029126382643184, 53.43939888861872, 54.3328599006899, 53.431024628300825, 54.27876649364349, 55.57390174558086, 55.102785864183986, 58.6540174484253, 57.881177163893184, 61.36963905826692, 65.91157897826164, 69.05191483036165, 68.73679161071777, 68.06419926304972, 64.95814492625576, 68.31030445714151, 72.80965528180523, 79.47514287887081, 84.6078388152584, 67.54323790150305, 7.963951470390444, 1.38086159383097, 0.8675275875195381, 0.14047925871226097, 1.6903770498691069, 67.90701420076432, 74.15446342960482, 62.45345661717077, 31.17723191938093, 39.719281427321896, 38.11213731765747, 24.376997178600682, 0.25010910666277336, 0.06502561196083985, 0.05681496887137333, 0.06000300929430993, 0.059766839709012747, 0.017292485196864413, 0.06973545923228226, 0.02593214901524686, 0.22962475826423015, 0.12604378734625157, 0.22412087618102952, 0.16717754544750338, 0.16941979287132142, 0.2106662578279934, 0.2646840826397942, 0.3315208720103387, 0.2208542619501391, 48.78094496265535, 83.8921082404352, 50.55751585191297, 33.548514535350186, 65.8786859819966, 67.20404701848184, 102.74285454903881, 35.35910806348247, 0.48056670975300575, 8.765389265552644, 63.31158099635955, 99.88194050327425, 87.41126660377749, 87.72969245910646, 83.52077745622205, 89.51312357379545, 87.20401640861266, 89.53139397405809, 81.04926847642469, 84.44385236309421, 75.49036779711324, 75.37558355639058, 71.33306334095617, 74.51679629664268, 75.46551565970145, 78.5102084375197, 76.33318316551947, 69.76639809147005, 64.70049227437666, 66.54034276162425, 65.29132673817297, 68.21356311921151, 62.785697060246626, 65.15243953274143, 62.79053334266909, 59.00193952745008, 55.68282204289591, 56.080283657197036, 54.061031803008056, 61.42569365039949, 54.95415156887424, 56.193961789531095, 55.69137673224173, 53.25699298612533, 54.99184946860037, 55.68624627205634, 54.62521376148347, 54.933331627999586, 56.53517269319104, 54.99602287046371, 46.694930445763376, 55.71251830747051, 49.3172114126144, 49.88874389279274, 53.47346467356528, 55.55928699431881, 42.790285464256044, 46.457015160591375, 45.13670613688808, 50.510510167767926, 49.94133895443332, 50.43442010879517, 47.82075266684256, 49.23338643966183, 47.699437679782996, 48.52180181011077, 47.231169439131214, 49.94043288692352, 56.66271640408424, 63.67538082984186, 59.098272938882154, 62.04267071139429, 59.84221712235482, 65.98357800514468, 66.82841731655982, 68.89078386368291, 47.5333409924661, 48.69426450421734, 56.01921235361407, 49.45410997636857, 51.18426745937717, 52.195717288601784, 47.62711309617566, 53.60717042799919, 65.47113603161228, 62.64557430821081, 61.63409702239498, 58.204368698981504, 55.515972260505926, 55.59509823399206, 49.5219865922005, 52.87584843174104, 48.563877074949204, 50.47499310585761, 48.61073370902769, 49.02015070761404, 47.27320155789776, 47.65129843065816, 48.07078415347684, 45.57497609046198, 50.515287614637806, 48.65179700236167, 52.37500490680818, 53.927788888254476, 51.71348933250674, 49.83394445911531, 53.687178934774096, 52.814294676626886, 52.54730678373768, 49.5029434850139, 50.640654410085375, 54.25535386608493, 51.6154496900497, 53.000870058613444, 51.5279455338755, 51.23569757707658, 50.57906927600984, 49.55988453280542, 53.73229795886625, 51.20932356003792, 51.65833296314363, 55.04300502038772, 53.83142802023119, 54.13596476277998, 55.48988457648985, 58.00966616599791, 53.83581715245401, 55.28008091834284, 53.67086187485726, 58.65163264736053, 57.842490826883626, 55.636298810282064, 57.668776896692094, 56.4570116227673, 61.684970163529925, 63.215749648309526, 62.31773868683846, 69.43215723960631, 71.31611085707142, 73.35182882124379, 69.85584382087954, 68.42679885125929, 72.49554403366582, 76.96058196406211, 82.49142985190116, 89.58694258043843, 75.9933647032707, 9.3652069376361, 2.3191891274144574, 1.5083593394487136, 0.13904265999313326, 3.1710570810302614, 78.62412975680444, 79.65432459308256, 72.64495495826968, 48.42573511985041, 51.21199861649544, 47.811346823169345, 40.38556268138271, 0.780962348705338, 0.19426820709580378, 0.1298309123564151, 0.09986804152328162, 0.13762935034690366, 0.28357673015805984, 0.3027896330721917, 0.207729107369819], [0.011495601295703843, 0.05399628624980969, 0.06076756504274184, 0.018028735911713976, 0.11741400606209233, 0.017995799876629345, 0.011901993702556337, 0.08949974626903573, 0.031065985733162493, 40.480825285757746, 60.30731216553719, 37.80060306672127, 35.85500547962804, 49.56659178580008, 59.487634858777454, 82.56017331154116, 18.19528099029295, 0.434235489416507, 7.067157424265339, 52.39989234555153, 91.25824882138161, 75.58345348604264, 75.92828473737164, 77.08070062821912, 85.20712990914622, 80.64639399128576, 78.28195002771194, 75.25401361526983, 71.83883728519564, 64.04183610793083, 65.1624611885317, 67.78891947961623, 86.82335038338938, 96.501430080783, 81.85577054177561, 65.97816513430688, 71.94463145348334, 69.04335621864566, 67.73234321225074, 68.51787628666048, 67.4643825715588, 65.57001113891602, 67.22923647972846, 67.18024607627623, 59.562195193383005, 50.521649699057306, 49.781784780563854, 53.26572418212891, 52.09454367237707, 50.65496321647398, 50.211974651582786, 48.377160487636445, 49.37663139835481, 46.7715774813006, 48.98033472799486, 48.66760807652628, 47.67953165115849, 49.431513201805856, 54.03040985907278, 49.985563678126184, 54.51295552715179, 50.20485554972003, 44.75892305374146, 51.956848867477916, 49.89304673287177, 45.447051909662065, 45.59285817607757, 45.599267328939135, 44.50348654100972, 46.513101131685325, 44.587574312763834, 44.40094401759487, 44.96205868259553, 41.909999693593676, 41.37777328491211, 42.549087155249815, 45.294142230864495, 50.45743265459615, 50.425147625707815, 53.021972410140506, 55.67449485102008, 55.50869626383628, 57.63312255182574, 59.03881765181019, 52.44654109401088, 43.7017148540866, 39.378125436844364, 39.329076197839555, 39.90215409186579, 41.12708676245905, 40.43093273716588, 46.45823109534479, 47.76320757404451, 54.74879980087281, 59.48377132415772, 58.11780591164866, 57.13920201024702, 58.510191978946814, 51.51409564479705, 44.02540845255698, 44.08498533310429, 42.76340938383534, 42.68391470755301, 40.370116387644124, 44.198596785145426, 44.98536540615944, 47.71417794689056, 42.3814058303833, 49.25299044578306, 47.67456593052034, 45.31266758518834, 53.2725412614884, 52.41932768975535, 51.63725806820778, 51.65401051121374, 53.80153955951814, 52.16650739792855, 50.53269901583272, 45.747579989894746, 46.87835616450156, 51.18787996230587, 47.009614359947946, 45.7440733909607, 45.306246665216264, 44.35326368578019, 43.01369974690099, 46.305564603497906, 49.28495384031727, 49.00808941933417, 48.55809157894504, 50.47395367776194, 48.57115307161885, 50.686204894896484, 48.16255192602835, 48.324996886714814, 49.49321208461639, 51.05694732358379, 49.187055403186434, 50.97317726381364, 50.52163008720645, 53.463505775697776, 52.96236807300199, 55.56626096848519, 57.10286517297068, 62.0308094639932, 63.60567638950964, 67.5102036999118, 66.56714823938185, 67.28129417665544, 62.47518262555523, 60.88973314531388, 65.20816072340935, 72.9684014474192, 70.98149345767114, 84.66813348954724, 54.71776208569927, 7.262367413889978, 1.4108396561876422, 0.6288839672361651, 0.07526847563924328, 0.2748318058588813, 50.49167886857064, 70.83755031708749, 53.84961997309039, 34.94086965437859, 15.017586523486724, 23.200764656066898, 20.12963314210215, 1.6144838448493712, 0.11514338274155894, 0.023319055664262945, 0.03503292881613297, 0.0274158391590801, 0.02065390472360436, 0.07567045729487173, 0.03997405803191566, 0.023509118247837312, 0.07766441562243047, 0.11757315316748236, 0.031094016890311917, 0.04158078572682796, 0.020918561288365917, 0.021376961489178, 0.065734549725969, 0.041909935403495066, 51.56585916396111, 66.89737258418914, 42.738670995158536, 31.763689018064934, 58.33548568910169, 66.31333951027163, 90.37326797362297, 17.14724329210097, 0.513736478263332, 6.02724785766294, 52.47708066817253, 97.56556910853233, 79.35564394920104, 79.15245732953473, 79.93842970940375, 87.56474894862022, 82.59514516399753, 81.19498452832623, 78.09760647435343, 74.3898291741648, 66.50335481089931, 68.24638551281345, 71.10770748507592, 84.96617870946085, 87.20115307838687, 80.54802094736408, 68.78647235132033, 73.79469579265964, 72.33718226032873, 70.51654354218515, 71.63302267751386, 71.38644679900139, 67.76231796510758, 71.27848748237857, 71.02435711891421, 65.29997164203276, 53.31649534163937, 51.5010106179022, 54.237675743718306, 55.12843816511093, 53.96472584816718, 53.25549856308968, 51.60668319271457, 51.58236449764621, 49.67762231826783, 50.930878423875384, 51.92072776056106, 50.18715781550254, 50.273571552768836, 58.240007354367165, 50.33969094676357, 53.56151403919343, 52.90774514598232, 48.764584756666615, 53.55945479485297, 51.4079680750447, 46.66692472273304, 45.76088074714907, 45.89567299812071, 46.75478973696309, 49.7764503571295, 47.047873158608716, 45.076615425848196, 48.05210974908645, 43.40080238157704, 44.537136554718025, 44.911546399516446, 47.22199501529817, 52.1853583089767, 53.43299365812733, 54.16461375451858, 56.88013730510589, 56.16067655624882, 60.863751365292465, 62.52059974978047, 52.21590180550852, 46.01965911926762, 45.65572200282928, 43.03043257805609, 42.17986268381919, 44.02882875934724, 46.65136468025946, 48.477710447003766, 50.70947631712883, 55.50731558953562, 62.831537800450484, 58.790147227625695, 57.806856093868134, 60.8256612285491, 53.27213333499048, 45.56382086969192, 45.35071849822999, 44.71599663457563, 45.5855861017781, 42.93708409032514, 45.96227876601681, 49.64091677819529, 49.77760353396016, 43.69357593597905, 49.18347820158928, 48.347691720531834, 45.59706687927247, 53.46195251710954, 53.263778686523445, 52.591123580932624, 52.97427246647497, 54.05362636812272, 51.24615461595597, 49.918863773345954, 48.74389033163748, 50.13634350992019, 51.2697123712109, 49.34291078198341, 47.899706056041104, 47.068771546886815, 47.041260042498195, 45.107304050076394, 48.528022689204064, 51.13826590199625, 51.04951443210725, 51.36271961273686, 51.75630592530774, 51.76974004314792, 54.06873141565631, 52.0134957375065, 50.79543898182531, 53.10987664807228, 53.001921253819624, 51.488847347997854, 52.31532996700656, 52.94313276967695, 54.75991187557098, 56.702916775980306, 59.18192924991731, 59.376549413127286, 63.76973344433693, 68.59643351647162, 70.02391738276329, 70.66265183110391, 69.12734985351562, 66.39222621917725, 62.665127323519805, 68.5922287356469, 73.95840767891177, 75.0552906528596, 85.19139336001489, 67.43560021923435, 8.690627909475758, 0.5501235709075005, 1.1190742734939823, 0.09615623061695407, 0.39187193037040774, 51.67889010521674, 80.00730652962962, 62.1240520477295, 40.69539462366412, 19.875443943085212, 38.05236431860155, 38.415258084574056, 1.4152716893342234, 0.09171673577399024, 0.0608382519755152, 0.07379646067537608, 0.0409975017030393, 0.03502157922353476, 0.019605517229666154, 0.07946584073285903, 0.13744381917340143, 0.12576972705221948, 0.1256169461374802, 0.10495576166337538, 0.15503791701649466, 0.11392169466782963, 0.11214355096941996, 0.2517434786404333, 0.10083084550475883, 61.141211986541755, 77.9713139995452, 49.60013981788389, 47.94557817520634, 70.87192596927767, 73.62375105580976, 99.40412521362306, 24.60452602755639, 0.7495524373746688, 12.592834157328452, 59.517746894590324, 99.97646177968672, 81.79658982061571, 82.94494998070502, 82.63868347291024, 90.84467411041261, 87.25483463656518, 85.1146011967813, 78.31805936751827, 79.44100256889098, 69.66807996073078, 73.82591785923128, 74.95183421719459, 90.36556443860455, 86.43481608360045, 81.65800463768744, 73.77427593354257, 79.5724411933653, 76.59850797345563, 75.37394400565856, 74.87923899004537, 75.79538699119323, 70.9887812214513, 74.46743719039425, 75.19511530476233, 68.09793164653163, 54.530629727148245, 53.50765205198719, 58.99550291799731, 57.1007235588566, 55.633317808951105, 55.63628312080137, 53.504137608312796, 55.25187907680389, 52.05353136985533, 55.958470529125584, 53.75814637830181, 53.69677697458575, 52.516441652851725, 59.71638356485675, 51.24452683233446, 56.434779628630615, 54.774538393943544, 52.30839913891208, 57.98328822658908, 54.69525944802069, 50.962378978729255, 47.31735175655734, 47.60302974331764, 47.1451557836225, 51.90360269238872, 49.094703197479255, 48.98273914091049, 50.42176654261928, 47.45871005519744, 48.7140489393665, 48.505484750193936, 50.29718422120618, 56.81735192575763, 55.398716926574714, 58.42508831331807, 60.963320732116706, 57.90515461275655, 63.94390629183862, 66.6904910918205, 57.61005117047218, 49.82022793062272, 50.18213718168197, 50.189707356114546, 54.23405147367909, 52.24544117527624, 51.857012779481956, 52.47764156710718, 49.59160866275911, 59.68712660574145, 65.04005970493441, 65.11562416630407, 60.357969576312655, 62.781296160913286, 57.970642505153535, 49.06684652451546, 47.81752455619074, 47.22277948933263, 47.996243430722146, 44.69578466107769, 49.33117112805767, 52.161498531218506, 52.68198136360415, 44.343414614277506, 50.3351096184023, 49.34487588943974, 47.25057732674384, 54.729238940823464, 54.072928351740686, 53.87237756483017, 53.11459918175974, 53.94121908372449, 52.14731916304558, 49.898577274814734, 49.11769220905919, 50.974844271136874, 52.98203483704598, 51.19630913580618, 49.62188936048939, 50.52558775871031, 49.761972888823486, 47.52950883680775, 50.928454399108894, 53.2498856513731, 53.76679520453177, 53.27086640942482, 55.28938478039157, 54.62018528292256, 57.587991760623076, 54.60957527160645, 52.94547050229965, 54.962086523732836, 56.25636669897265, 55.50521712149344, 55.49587011337281, 55.40279619155392, 58.59279709477579, 59.96565411167761, 60.743664080096835, 62.84160652468282, 66.75813628781226, 70.35023504687895, 72.92656544716128, 74.17687585276943, 73.03326960532897, 69.2566390191355, 66.01421171619047, 73.08056554486676, 76.23269204170474, 79.35816211085167, 90.03681490498205, 73.25263207958591, 11.70795136882413, 2.6054711591812874, 3.0714796243175386, 0.17321022738131786, 0.5487354195887043, 60.86766981309461, 83.23569959209811, 73.72790567336544, 54.566962642054406, 25.236819944074078, 49.72708340614073, 58.47238425285586, 2.939628415530728, 0.18665530027881747, 0.11793505310291245, 0.10893169670335709, 0.16449632964307265, 0.09666909583874288, 0.13659081091323208, 0.0946356839830837], [0.040228494983767314, 0.021428827556871602, 0.06536111250639924, 0.04467730162545078, 0.07526738779439081, 0.06956232336139487, 0.0388397537772694, 0.004969234108894823, 0.12732578952225948, 43.45711585014097, 58.89878119191816, 36.162872314453125, 25.240242212049424, 56.22921605263987, 61.98383515880954, 85.93681627704252, 7.26131719927634, 0.15217169097835018, 0.2803273835489827, 39.50649284547375, 100.61334486930602, 76.72571043814384, 76.6770887374878, 74.70106140259774, 80.97493171691895, 76.96342960480722, 78.00845884507703, 70.44052800824566, 65.84948001369354, 60.491659641265876, 62.980293689235566, 70.12865251110446, 68.37088154208276, 67.10696835671702, 89.94580022750363, 91.80490170755695, 71.30417900700724, 68.3523287311677, 66.1449521587741, 67.46998371616488, 68.57710407626244, 68.29244982811713, 69.20418124045096, 68.56863175669025, 68.1668084667575, 56.61872702260172, 50.756964452805065, 50.9070029566365, 49.69821083930231, 50.94446943652246, 50.07221275760282, 46.476556408789854, 47.785459180032056, 47.57851885211083, 45.79930428535708, 47.781732928368356, 48.06632834096109, 48.27923851628458, 50.57651581302766, 50.18610662029636, 50.16914236930109, 56.79366473228701, 52.30682234610281, 50.21692468274025, 49.122712842879764, 46.59059539917977, 49.59497797873713, 46.00887652366392, 45.87378225018902, 46.45868609028478, 44.82032775878907, 43.95247590157294, 45.631069906296275, 45.166237661915446, 41.48148859700849, 43.32702259863577, 43.78396695660007, 44.67408218691426, 48.18457211217573, 48.742815602210264, 48.84148674626505, 50.75113973309917, 46.88796204905356, 48.15504450951853, 43.11864668323148, 42.515923515442886, 36.11669032804428, 33.45154569995019, 34.30786186648954, 37.120224814261164, 38.37185705861738, 43.893079450053555, 45.22736387868082, 44.067597466130415, 53.745386908131266, 50.36393511679865, 53.99829741447203, 54.82608226037795, 49.894815721819484, 43.02343114729851, 44.4903701351535, 41.906524473621005, 42.46290876019386, 41.43412597717778, 43.90836492661507, 48.606517161092455, 45.37401345468337, 46.550202831145256, 44.32197493891562, 45.629057730397875, 51.16525180878178, 48.51454934766216, 49.46607320539413, 53.60815102054227, 55.467868312712646, 50.01461667399253, 52.914970151839725, 48.19292676064276, 50.0768489991465, 45.94902507720455, 50.757038977838334, 46.38423165967388, 46.96858244557535, 43.885787763903224, 42.35643994423651, 42.22885308727142, 47.1393036073254, 49.39745133922946, 47.58545752494566, 49.90633572301557, 51.096037664721095, 52.79515743255616, 51.982756122466064, 54.042957521254024, 53.52775419912031, 55.119369645272535, 53.592959680864894, 56.59678920622795, 55.1908822982542, 56.7011752436238, 61.324861280379764, 65.34170958303636, 65.7391280512656, 68.13146791150494, 67.0282385426183, 69.85637726322298, 68.79922005438036, 69.33405876159668, 66.49663186842396, 66.61405194190242, 62.166135157308275, 67.8113083685598, 68.52659963792371, 77.2332259147398, 76.16124214664583, 71.95027966653147, 10.39622841342803, 1.8587842583656313, 1.908902588390535, 0.08776598204407962, 0.22435324597022227, 33.410243142035704, 78.36104854460686, 58.930579846905125, 39.662693392845895, 35.27847197748, 27.798741517528413, 22.669540412964363, 0.6821256683718774, 0.10859957460554377, 0.10527309826425008, 0.0095882817667218, 0.04613739626121618, 0.0470452219428074, 0.029831354603952462, 0.08108613967534997, 0.07222240279999471, 0.08181183944426237, 0.028458038577809933, 0.15037489303898427, 0.07210234150050149, 0.019792548020280177, 0.012181183912851399, 0.06647361006828086, 0.015112009357600925, 54.31590349443498, 64.37373922717187, 45.38858113750335, 29.453209023321833, 62.88186573213147, 67.47357660724272, 92.91181810440557, 8.006787184746035, 0.3249942012611897, 0.2043521917995907, 42.24260883946573, 104.01436144305815, 79.32497101445352, 80.58961376067131, 76.45047772315242, 82.98160060759514, 78.1739357979067, 81.01861123115786, 72.24962711334229, 68.23098628751694, 62.70422158702728, 67.48887385091474, 74.87635212559854, 71.93837919542867, 69.52345432773714, 86.50425772513114, 86.55914737332253, 72.34880032077913, 72.64130715400943, 70.82880343160322, 67.6333268996208, 72.12600185025123, 71.56622471347933, 71.63415232012349, 71.64212257631364, 70.05729675292969, 59.08050460200156, 52.41853537098054, 53.179259454050374, 51.18416547775269, 51.507227574625325, 52.838970307380926, 50.495530636079856, 50.04434039515834, 48.739179565060525, 48.943507594446984, 50.876785016828975, 49.910132577342374, 50.614927584125155, 53.467843917108354, 52.62626801767657, 49.69564953157979, 57.16160658867129, 56.4618714394108, 51.54425474905199, 51.87512236256754, 45.25394970370878, 49.35543883231379, 44.94124266409105, 49.72620087285196, 48.62196345483103, 48.143787307123986, 45.28163379238498, 45.75673480187693, 47.10682638229863, 44.89276216876122, 45.665731891509026, 46.50667236697289, 47.160068635017645, 52.036759314998505, 49.37989873270835, 49.692539092033144, 52.25509412827031, 51.29412128079323, 50.06513287944179, 46.483169524900376, 46.80161106971003, 41.705961919599964, 38.571435097725164, 38.82162740153652, 39.83941185858942, 43.62725650110553, 45.79047895246937, 46.12346464587797, 47.653357674998624, 53.21315657707953, 52.77058770579677, 55.45936461417906, 56.09202723349295, 51.74185591359293, 44.90110505011774, 45.104625071248705, 43.19863165578535, 44.33861755555676, 42.94825107820573, 48.04410026919458, 51.011851833712676, 45.51785853601272, 46.22537174532491, 43.43959854495141, 45.663535364212535, 50.26577780323644, 47.76736136405699, 50.90766191482545, 53.54830741882325, 55.49931003201393, 50.73588563549904, 53.35142797039401, 48.71024424029935, 49.593432564889234, 46.78042242603917, 51.477707816708474, 49.408516345485566, 47.10472006951609, 46.24925505730414, 44.75738548463391, 46.52329537176317, 49.890018663098736, 51.89298091396209, 49.51714638740786, 51.56426668167115, 52.878476419756495, 56.72016343762798, 55.300022248298895, 56.510049912237356, 56.41451666432043, 58.07512660180369, 54.76901177437075, 59.86176621529364, 58.99124322399017, 60.76730028275521, 63.354809438028646, 69.53668055995819, 67.3958509199081, 70.87089046355217, 67.94565739170199, 72.32980820440477, 68.70509101498511, 74.20563467087285, 69.53411532986549, 70.38270442716538, 63.06138084780786, 72.19432169391264, 70.70847295945691, 82.05921603787331, 76.83778824344759, 86.85551381880238, 17.23276469015306, 2.1116415675609344, 1.8497840122830485, 0.05084334031468438, 0.24970107291254307, 37.34003051634758, 84.65846092470231, 67.53164337527367, 42.77566679062382, 35.479732713391705, 48.91086562987297, 37.49259110419981, 2.6341245635863277, 0.16341177896866876, 0.10202331498505608, 0.024625476892857302, 0.04135971573451835, 0.008276694232688077, 0.07043771671071168, 0.04157382198759625, 0.19482493851213686, 0.22913539661995827, 0.1440884674628896, 0.27827819028208334, 0.1626319627487852, 0.1276079243830135, 0.13425497818858395, 0.1289628428076544, 0.39616009220480924, 67.92883826840308, 74.04709246850784, 48.80415362696494, 36.372652438379106, 75.97910296532416, 72.58681758757561, 103.71754784737865, 10.471180985050818, 0.3593842865478608, 0.41542217796367986, 44.5140730181048, 107.29884439899077, 81.43597495171332, 83.47029655210434, 79.57768932465585, 88.39702883074361, 80.10414984918411, 85.211836753353, 74.98468798975792, 74.01495256731587, 65.98146776999197, 71.7783857160999, 77.46677167953985, 79.3880662610454, 78.80667686462402, 88.33385513674828, 84.29257439028832, 76.40888490984517, 73.6081321777836, 72.9188697568832, 72.86297598192769, 75.148376341789, 74.9111121700656, 76.06829766304263, 74.0325326304282, 73.33482142417662, 62.37878253383022, 55.01341073743759, 57.24763985603087, 52.873789187400575, 55.684289009340354, 55.989308203420336, 54.686053645226266, 52.688108105813306, 53.69137587085847, 51.27080279011881, 54.574701478404386, 53.4237172526698, 53.64894759270453, 54.84479981084024, 54.31666443424841, 50.734430436165106, 58.23332363559354, 60.26950051707607, 56.162406321494814, 54.09788247077696, 47.28315653339509, 51.46750965426045, 46.335445219470614, 50.130059872904134, 52.084965244416274, 50.6920256922322, 48.760391742952415, 51.01753142572219, 49.30104340276411, 47.33768140116046, 49.21717920610982, 50.447842459524836, 49.98421438278691, 54.05082971818986, 53.521074402716856, 54.753855736024924, 55.81877531543855, 54.406223912392896, 52.528887333408484, 48.97774204131096, 51.84171553580992, 49.531961179548695, 47.02634719110305, 49.94880714724141, 48.02646921527002, 47.82212941877304, 49.45525530845889, 49.002374525993105, 49.569004043456054, 57.53458869072699, 55.96247134670135, 60.20127088792863, 59.75526994274509, 54.14084026890417, 48.03420020687965, 49.96292767986175, 47.18500314220306, 46.58959127241566, 45.92224705603815, 49.21616331223519, 55.51384241350236, 45.64652012240502, 47.37531654296383, 45.953531880532545, 46.215475605380156, 53.11358328788511, 50.17980729379962, 53.228461665491906, 55.25174571621803, 55.6702979149357, 51.32331940435594, 54.87076590138098, 50.10483903269614, 51.50555664493192, 48.26218797314552, 55.21022742794406, 50.951918017479684, 51.433722357596125, 47.52324873401273, 47.37848189569289, 47.85622658268098, 53.63033202386672, 54.404011695615715, 51.73139495234336, 55.12977177096952, 57.091643271907685, 59.44118615119689, 57.90113418332992, 59.56299927926833, 57.79259827829177, 62.01911687850953, 56.32450611360612, 60.9638031836479, 60.81516496596798, 62.378876670714355, 66.6239990726594, 73.34896549101799, 68.31547414102863, 74.14819548206945, 73.00902935766405, 76.68301936118834, 74.14303364292269, 75.88125551900556, 72.6618839079334, 73.0332068474062, 69.30345642951228, 75.66860029774328, 74.80270570324313, 84.65040437636837, 82.79054195650163, 93.3233061144429, 20.18845888876146, 4.222576127898309, 7.107559798225281, 0.2870491309271705, 0.39664517907846364, 44.36825890694895, 93.38416561003655, 76.47159576416016, 60.36417868829543, 59.97579736094321, 53.67878506260534, 57.45994598634782, 6.3481928552350695, 0.5116596139006077, 0.3637705995671211, 0.1057165252765821, 0.2037104552671794, 0.09234704993545048, 0.19115418225767153, 0.17116654994747332], [0.012621883652172984, 0.06506738673535085, 0.09700720874412407, 0.08411410219606855, 0.10692426288921027, 0.006629513264934142, 0.04216869692167929, 0.038698042833035996, 0.06205183100856601, 39.40609193617298, 56.627379771201845, 37.171764758325395, 35.871812835816414, 57.51388642095751, 65.88409100809406, 74.6602059948829, 3.513207392346475, 0.12855485502269962, 0.04830026165432027, 41.99343242952901, 94.75290021588727, 77.08448179306524, 76.4694933737478, 68.97267510814052, 77.19217438851634, 75.19407979903683, 71.39529566611014, 62.37135356472385, 60.50943582288681, 62.11861172030049, 70.48239538746496, 71.93306830621535, 71.78293566549979, 51.90712498080347, 40.42801449375768, 65.19621318386447, 86.96882324834024, 77.08008089373189, 69.09142094273722, 71.0759598209012, 66.9957064044091, 65.78809492049679, 63.06150636365337, 65.30487068237798, 65.84466334312194, 63.36656870380525, 50.78876310779203, 51.4459954538653, 50.837510324293575, 52.67255983045025, 52.33285903930665, 47.79406878256029, 46.206312948657626, 47.33216654869818, 47.88127091623122, 46.64057031754525, 48.41480739655034, 47.44429534481418, 52.790140721105764, 50.51059253754155, 50.907324590990626, 48.33048036021572, 59.942755314611624, 58.53232591382919, 51.97720204630206, 51.16131767149895, 46.155577090478715, 46.6655989616148, 49.50228844919513, 48.48766934487128, 42.31306637487104, 43.895750584140906, 41.74495812385313, 45.41397063962875, 42.14846018821963, 42.38520660708028, 41.81305047004454, 43.854087168170565, 43.7153450904354, 43.94589416442379, 44.078364372253425, 43.46455658635786, 42.4603239182503, 45.38265051380281, 43.06942878230926, 39.62867859871157, 30.383503052496142, 34.62721340117916, 35.569817789139286, 31.232037236613614, 35.94973856402982, 38.91734892322172, 41.79541157137963, 40.84894757116995, 46.9254324513097, 46.1542474069903, 48.93378011641964, 48.46322905632758, 46.49676053754745, 42.699733626457956, 40.390724520529474, 41.86716348894181, 42.50156764061221, 43.520509196865945, 44.20135813374674, 44.010424998498735, 45.943455311559866, 41.2177994174342, 43.853145799329205, 42.04279153577743, 47.63296527247275, 45.87655536590084, 45.81665292862923, 52.8296507558515, 50.37013246167091, 46.6751342435037, 46.45039027737033, 47.717123646889966, 49.64773777992495, 48.012678161744155, 47.01368578018681, 45.04288304236628, 45.29870786974507, 45.59239141402706, 42.8741967293524, 43.68791987819057, 45.51013146677325, 49.31820377226799, 48.06035849355882, 51.748794586427756, 54.88870290017898, 55.70788991066718, 59.06795301745015, 59.884582642586004, 60.30230329882715, 61.19939642567789, 60.75815331551337, 65.58943079363915, 64.63332168517574, 69.25915718078613, 66.6342286140688, 68.36873208322834, 65.28849478690856, 65.56900701215191, 66.19282076435705, 66.45578430544946, 66.78375720977783, 70.14197288020965, 69.22001192646643, 68.59901443604501, 61.858531121284734, 65.2702675327178, 66.41332857070431, 76.91637685222011, 75.50664563332835, 82.42571446203416, 50.21598331389889, 0.9514350528197905, 3.0074427637361714, 0.12093278579413892, 0.048808695057467114, 25.416770442839592, 83.0918505883986, 55.1049510125191, 43.08060361493019, 18.85865772924116, 23.73322444577371, 22.712764932263283, 1.951746637782743, 0.05679992290454046, 0.018834330990249594, 0.11457813242750783, 0.05049820621347716, 0.04645447239219662, 0.044774364965457114, 0.013443461240028903, 0.029113491914505442, 0.038570922033320514, 0.10603517954868656, 0.15396701802890148, 0.09148244310410754, 0.012762865855268413, 0.05799762093492093, 0.05209490581746063, 0.18196701072156432, 52.0298324092742, 64.88438867753553, 42.87953507515692, 39.29918381475633, 66.15337740990424, 72.70714805972192, 81.66383327976351, 3.363086763889559, 0.10865329269079432, 0.15187487787296697, 41.59203275557488, 96.72922565091042, 79.38311622988793, 79.56462783198204, 71.19283860729587, 79.4406730897965, 77.57602537831953, 74.04411146717688, 64.24992569031255, 63.12921431756789, 65.5245469462487, 72.78724285864061, 72.05610521378057, 74.54899111101705, 57.85505417854556, 49.58006120497181, 68.17906979591616, 87.13437864857336, 77.10472122315439, 73.87803831408101, 73.63226259908369, 69.6167439799155, 65.64668563104445, 65.87726608399423, 67.58426589350547, 69.45245942761822, 65.23760595629292, 53.60078088698849, 54.075242550142356, 54.438614845275886, 53.39589588103756, 52.64137306521016, 49.59514664065454, 50.64264305176274, 51.19392825711159, 50.610632588786466, 49.281863012621486, 48.90562534332276, 49.131236153264204, 57.44723750698952, 52.187570525753884, 48.9339566230774, 48.4852296306241, 61.265637413147964, 61.78314316657282, 55.356786789432654, 51.33093664723059, 46.461082658460064, 46.442361185627604, 51.28058518132856, 50.4767934737667, 47.50608836450885, 45.6820999422381, 45.03224949682913, 45.90370993460379, 43.65002193758565, 44.92490599232335, 45.32224601314914, 46.00444816773938, 46.28894159870763, 46.980682957556944, 46.92882137913858, 46.75509568183653, 44.17805925492318, 46.61182326655234, 46.15438076757616, 44.62164402008057, 37.66040971202236, 39.95212901023127, 39.11218873916134, 35.838645273639315, 43.57466143946494, 41.359134181853264, 42.613696436728205, 44.355205259015484, 48.68206985535161, 49.31656029916579, 51.54747109259329, 50.74365585081039, 50.13284867809665, 45.94722470929546, 42.83504363029234, 44.175780357853064, 45.075603454343735, 46.05264233004662, 45.85795940891389, 45.79071037230953, 47.33835997120027, 41.73616809229697, 47.11792668988628, 43.08340418723322, 48.98160165356052, 47.87994515511298, 47.06608080094861, 53.226018028874556, 51.607365685124556, 48.092937700210086, 48.05157238437284, 49.288480051102184, 50.92758755530081, 47.920278887594904, 48.46590803515527, 47.71860238044493, 47.592219691122736, 46.86742451883132, 45.444874994216434, 46.06198149342691, 48.79517139927034, 52.13393995838781, 51.56325471016669, 53.453150718442856, 55.967307629123816, 59.98162600301928, 64.28763535714918, 61.50476863307338, 64.90841711721113, 63.88066591755037, 62.02609085267591, 66.29446506500244, 66.62543466014247, 71.82989428120275, 68.55688818039434, 71.60181630042293, 69.3954203205724, 68.70901338515743, 70.60208259090301, 69.45358907022785, 70.59252769716325, 71.80326138773273, 72.12258154346098, 69.89219634763657, 65.92477383152132, 67.02455151465632, 69.90535982193487, 79.00683541451731, 80.53397886214718, 86.1911270695348, 69.60416886114305, 2.2884249975604396, 3.527810621646143, 0.34988317218038345, 0.15861890308799284, 29.49149331738872, 88.08929535650438, 64.94614639589864, 47.33893263724543, 25.358623266220096, 35.57544246796639, 44.01495533604776, 4.777703785127209, 0.15806260068089734, 0.022457461473682237, 0.08130043745040894, 0.03380272567512528, 0.06734354121069755, 0.026160397251406987, 0.042962134184856574, 0.11147204426027114, 0.37483962012394784, 0.2453315678623415, 0.26299360238256, 0.2531894695975127, 0.23101428854129008, 0.11522766007410905, 0.16286376563291396, 0.4422951021021413, 64.32888692425144, 71.6857393326298, 46.85409630498579, 48.37914520694364, 77.44492407768004, 76.3727363463371, 92.66942347249677, 5.056990759987985, 0.3991033100793439, 0.4526255526129277, 47.21762157255604, 99.85014577065745, 82.70276715678554, 82.14437069431429, 75.4376511419973, 83.07077177109258, 83.5299793366463, 76.88587650176018, 67.05167078202771, 65.55211336381974, 68.79965935983967, 77.59246010934153, 75.2752414826424, 76.36945724487305, 60.28105581960371, 59.52177124638712, 72.75817809566375, 83.65173755153533, 78.89333771121117, 76.86059290362944, 75.13897834285613, 72.08515428727674, 68.08389740605509, 68.6535353814402, 70.19376385596492, 73.15698900530415, 69.64460065287929, 57.32251790262038, 55.55816519644953, 57.81744649333339, 57.74196440173734, 55.09439983675557, 51.489545529888524, 52.19756472495295, 54.58864550436697, 54.609143810887495, 51.66767604889409, 52.35772294382895, 51.53092653520646, 56.70122623443604, 52.08252553016909, 52.84482248367802, 48.28900914038382, 62.36932962171493, 63.42629071204894, 58.1331737579838, 52.748206661593535, 46.38225478510703, 46.93260254398469, 53.93941479344522, 53.37291079182779, 50.6165082993046, 48.67612354217037, 48.959487330529, 50.23304170177829, 48.27118196795064, 47.42366760007797, 48.689812614071755, 48.173008964907744, 50.28827651854485, 50.146027841875636, 50.53966906762893, 49.99551865362352, 47.00568806740546, 50.69790924749067, 49.57090247061945, 47.476035164248565, 44.58141226922312, 47.43962380193895, 47.991105125796416, 46.04761385148572, 46.6655283589517, 44.05044494136688, 44.9967755809907, 45.432750948013805, 49.74553815780148, 51.26372291195778, 52.818981908982806, 54.433605978565836, 52.051146568790564, 48.617625313420454, 45.24313965151387, 47.791432949804495, 49.785918958725475, 48.76913078369633, 48.50148393261818, 46.4184739512782, 48.34878998418009, 43.24339766656199, 45.62200923119822, 43.0126642411755, 50.00124139170493, 51.00590552053144, 49.3282764188705, 55.05152048603181, 51.864504506511075, 47.555600443193995, 49.62278366088868, 51.165832319567286, 53.88553711675829, 48.99412185915055, 51.031177351551676, 50.04661144748811, 50.709735193560206, 49.48545363641555, 48.267051712159194, 48.14988659274194, 50.155441530289195, 54.70872102245208, 52.75641225999402, 56.65027856826783, 59.94308087133593, 62.42684725792178, 66.41747059360628, 65.17916656309559, 67.48836394279235, 66.2922606929656, 65.56038564251315, 71.35262812337568, 69.17907807134813, 73.11890279093097, 69.45682894799018, 75.62437165168025, 71.8010413262152, 71.07487724673364, 73.55704722865936, 71.90505473844468, 73.08446438081803, 74.10170755078717, 74.68968652909803, 74.2184922002977, 70.36277878669001, 69.5403205194781, 73.32307784788071, 82.02571899660173, 84.68128911910519, 90.40543140903597, 71.55233167832898, 3.7309648817585366, 7.634595930576325, 0.7274131092333025, 0.19002947325427688, 36.322077397377264, 96.21207683317124, 70.98538444888207, 66.24902048418599, 36.73307511114305, 42.89753483187768, 62.77934674293765, 9.864034364300391, 0.24922634354762493, 0.12658011018028184, 0.29807270714832895, 0.25243983724184577, 0.17844672945718612, 0.15191260004235854, 0.13317372169225447], [0.0864984742515991, 0.02764745626688725, 0.037282898406227755, 0.073560168516011, 0.023080428851948633, 0.01803853417626552, 0.025097729878560193, 0.0400718376641312, 0.3790985480431588, 45.69893867738786, 57.18925537601594, 54.069343305403194, 41.21635206284062, 54.96928407299904, 70.66110641725602, 73.04469154727074, 2.305385816481806, 0.09344252502365459, 0.2983557919581091, 29.133224025849376, 96.61985428102555, 77.03138859041276, 76.97811495873236, 63.08785684647099, 67.45673394972279, 61.58498110309724, 60.137595130551254, 59.131197314108576, 65.95701571433776, 68.78558589566138, 72.35904555166923, 71.99010741326117, 74.34683999707623, 74.24300701387467, 62.949738425593225, 48.127317274770434, 50.79683534560665, 76.56720745948054, 74.31161711292883, 64.6592407072744, 63.80621148693947, 65.21533473845452, 66.18673324584961, 67.41734550845239, 64.65627931779431, 59.30013379743023, 51.20560515311457, 52.22841416635821, 49.417380902075, 49.83372872875583, 49.92406483619444, 48.84489528594479, 45.08108692784464, 45.83770821171422, 47.892359456708355, 47.710090837171, 46.50979457363006, 46.18408879926128, 48.281419354100386, 52.16578960418702, 49.696320256879254, 47.036521819330034, 53.26664593911941, 63.258252451496745, 62.610272976659964, 56.75567657716813, 49.08490903915898, 49.41741620340655, 55.57656503492787, 52.080207409397254, 44.96738133891937, 43.671849927594586, 43.64488363265992, 42.81786757130777, 41.95559332447667, 44.18345643628029, 42.834306224699944, 41.092565982572495, 42.99813578205724, 42.413467284171816, 44.48353344394315, 43.41879821592762, 43.09712071572581, 45.334107260550226, 44.28065669152045, 39.46878710100728, 31.313300901843657, 33.76009110481509, 33.16479298376268, 34.585824551120886, 34.23478811017929, 37.98973583406018, 42.72620570275092, 41.709331235577984, 47.513352594067975, 44.16956732350011, 48.132412433624275, 46.092591670251664, 45.95130789664484, 43.749242213464555, 41.74295771506525, 42.49673920293009, 42.2506183193576, 39.96567295443627, 43.61186512054936, 43.51164071790634, 44.593348041657485, 46.146736068110314, 45.890648441929976, 46.77324841099401, 44.27317280923167, 48.18401121324109, 52.038649897421564, 53.20647678067608, 48.70612575161842, 48.7132134745198, 49.25265312194825, 47.68210080362136, 45.33006721927274, 45.03173566633656, 46.607857750308135, 45.30534844244681, 45.524248077023415, 42.1644752256332, 43.44793750393776, 42.07218577784877, 48.28538879271477, 47.32948364750032, 48.50711253381545, 56.04224451126591, 59.676951977514456, 63.60653931094755, 63.18174662128572, 64.4768661837424, 64.22435183678904, 64.1953851330665, 63.430777903526064, 68.18065443346578, 66.92661777619394, 63.704629944216826, 65.56097007566883, 72.82336004318731, 71.30883878277194, 74.94998285847326, 71.95683002471924, 71.98834234668364, 69.51247169125465, 70.79860902601673, 70.6721047432192, 68.30654682651644, 64.95077871507215, 61.490059744927194, 64.02262041645666, 71.36001002403998, 80.69387035985147, 76.64232084828039, 87.37035628288024, 22.14913602798216, 2.0690551688594203, 0.23734790513352041, 0.24835180821678332, 22.28377922888725, 75.31881117051648, 59.81332494366554, 39.74201940721081, 29.308720673284224, 28.538325986554547, 27.436822460543727, 0.8990648533067397, 0.18382241438713767, 0.015300273549773041, 0.07968269724158511, 0.12002697875422817, 0.02890619426785458, 0.04538297202558287, 0.06844127625827828, 0.045285410728425755, 0.03570838853897106, 0.06119547494416756, 0.02341294548504295, 0.02420283576113082, 0.03913049180541308, 0.029980149946265647, 0.058522333706458735, 0.5922514200210571, 61.09271580173124, 61.4796027060478, 48.15056516278175, 40.00470053765082, 66.69364467743905, 73.14589654245685, 79.87155329796576, 2.1184650207719495, 0.043024746550908016, 0.3370648358137377, 30.025188653699814, 100.47565398677703, 78.64264334401777, 80.35893132609706, 68.57766105282691, 70.60132165108958, 62.782472871964984, 64.7387000822252, 62.229744234392726, 69.23324600342782, 70.61669734216505, 74.2084038642145, 73.58439399350074, 79.39438912176317, 73.66971338948896, 63.73557352250623, 53.37873158916351, 56.036659056140536, 78.38134288787842, 73.64788147710985, 65.80575735338273, 64.8295892438581, 66.10843489246984, 69.28305225987589, 70.47672364019579, 67.82401684791812, 60.25441900376351, 54.28177887393583, 53.63891809217392, 49.93337262061335, 53.88512919026037, 52.95407226008754, 51.74689615926435, 46.52146754726287, 49.309299991976836, 49.22356090238018, 48.59909603672643, 49.60221475170505, 48.75772845360541, 49.83408566444151, 55.86582414565548, 49.560037505242136, 46.8585285832805, 55.52846500950476, 65.594412203758, 62.8307415593055, 58.065712913390136, 48.9480967675486, 50.08685496545608, 56.41809386591758, 53.30262584071006, 49.542461364499985, 47.896191612366714, 46.584233314760276, 45.59400350816789, 44.72893261140393, 46.82813021444505, 45.430558343087476, 45.64880294184531, 45.145307894675966, 44.56478534206268, 46.62902678212812, 47.023452481915875, 44.47908547616775, 47.3756185654671, 45.746477803876324, 44.577572268824426, 39.283011882535874, 39.16230486285302, 36.59177172568537, 39.45427433136971, 38.55906786457185, 41.22660906084123, 45.458889622842115, 43.95459790383616, 47.68789414436587, 47.23944956256498, 49.14172457110498, 49.054506747953354, 49.25636368413126, 46.28830225236955, 43.411490840296594, 44.88115979779152, 44.04989973191292, 43.729293038768155, 43.77377663889239, 44.54788777136034, 48.11424009261593, 45.81704908801664, 46.725348426449685, 49.26367498213246, 44.783841871446185, 49.144768330358694, 53.786305073768865, 52.401822151676306, 48.90309149219144, 49.727126552212624, 49.61085965556484, 48.71797130953882, 47.11158813968782, 45.82927119347357, 51.208139004245886, 47.85801126110939, 49.111463485225556, 44.428549658867624, 45.85851638547836, 43.32582627573321, 51.42919594241727, 49.643132917342655, 51.595351465286754, 58.64785540488459, 64.07834160712459, 65.47725100671092, 64.27274996234526, 67.30384780514625, 66.80332199219735, 66.10710128661125, 66.21318571029171, 70.12727183680381, 70.10513397955125, 67.2757322557511, 69.40737570485761, 72.7657247358753, 74.30599243410173, 75.459655638664, 74.7514481698313, 75.40988860591766, 73.01011977657195, 73.16459840343845, 71.75303936004639, 69.92567769942745, 69.15931717042001, 64.59135232433196, 67.00217047045308, 72.73718557050152, 84.20087722039993, 79.23780810448432, 92.62879556225192, 38.05671814949282, 2.359596894633386, 0.3128049150109291, 0.17920624434707627, 27.176402576508064, 79.58808360561248, 69.31775739116054, 45.097882516922496, 32.95155332934472, 44.904697941195586, 45.6529567318578, 6.97951598513511, 0.21347288222562885, 0.04393400481691764, 0.012915119126949821, 0.06341886128328982, 0.01546075652098103, 0.05322951267683699, 0.06707733331788933, 0.40134617037350134, 0.13821441169467666, 0.19710804906583604, 0.1716690270170089, 0.1206855309165774, 0.07927456389992468, 0.13224865520192733, 0.1922633396762033, 0.5991580397371323, 73.84985216202276, 67.68830283995598, 67.90108357706379, 60.01623307504962, 73.585492257149, 80.90979683783748, 87.87110174855879, 3.128920284009749, 0.20327164010415155, 0.4690539404269188, 32.83909701531933, 106.15737192092404, 82.90371018071329, 86.76271054052538, 69.49279708247032, 74.45963951849168, 65.68273613529821, 69.19982740955969, 63.1389614074461, 72.8815915507655, 75.4090178397394, 77.27026877864715, 76.87949872786, 83.32098760912496, 73.32102252591041, 62.69820467118294, 57.008724366464925, 64.21105107953473, 75.91821993550947, 70.70269923056327, 67.8055424844065, 67.49244320777156, 68.38867341318439, 71.9465220359064, 74.1692429204141, 71.06916627576275, 63.80118300837856, 56.26658055090136, 57.19258939066241, 52.04021492312032, 57.08524980852681, 55.81933229200302, 55.13264294593565, 49.558076320155976, 52.21113220337899, 53.34648970634707, 53.402254043086884, 52.19395614439442, 50.66692644549955, 51.56170537394863, 57.24716524924002, 50.486281687213534, 47.53367831630092, 56.22142622547766, 67.49602040936871, 65.22995733445691, 60.50221473939958, 50.16076418661302, 51.141125309851866, 59.34379762218845, 56.08989738648938, 49.83288541916878, 50.655327996900006, 48.68002630049183, 48.37933740308208, 46.498482458053104, 50.73247709581929, 47.39480680035007, 47.33016221754013, 50.3772044950916, 48.170016196466264, 51.20856654259467, 50.01512658211493, 48.999346456220074, 50.56173632221837, 48.767452009262584, 49.287836782393924, 44.65800831394811, 46.66020962499803, 46.846184884348226, 45.956132411956794, 44.13536033322735, 46.16833263827909, 48.2811487105585, 47.043291830247455, 51.34770477971723, 49.55406765783987, 51.946262390382834, 52.34317879523001, 50.58274061449113, 50.16468655678534, 45.91690871023363, 47.39583838370539, 46.66910556054885, 46.30953011974212, 47.00115380748626, 46.95814109617665, 46.90260425690682, 47.76517660387101, 47.76827527630714, 49.13112240452921, 44.98907596834245, 50.984705109750074, 56.51730237468597, 54.14240921697309, 49.5478153997852, 51.24489161276048, 50.23794858686386, 50.04761557425223, 48.66143818824522, 48.408978754474276, 52.54132124685472, 51.411419760796335, 52.18579369206583, 48.82046676451161, 48.04449642858198, 46.55037149306267, 53.41866916225803, 52.72776719062559, 53.669457666335575, 59.60980492253458, 65.6892982605965, 69.86793256575062, 68.38946573195919, 70.59814453125, 69.34829696532219, 69.27877687638806, 69.52936926195699, 72.33784121851768, 72.56240475562312, 70.11100184532904, 70.68851594002017, 74.58514751926546, 74.62166478556972, 77.67173905526438, 77.24624033897155, 75.71427237602973, 75.94918312564974, 76.62801988663213, 75.5386443291941, 74.83025643133348, 72.841426480201, 68.61184058650848, 70.38917633794969, 76.00014255892846, 88.92042990653746, 85.88033414656117, 95.09151058812296, 40.35274421015094, 4.744426886881552, 0.527609717701712, 0.22599112663057544, 32.543171836483864, 89.33631881590813, 75.2107028038271, 56.44688014061221, 52.848007448257945, 58.45338429174116, 63.91588880169777, 17.39992041741648, 0.6823671392856107, 0.16533231542956445, 0.182451254898502, 0.2687225304543972, 0.18664702652923523, 0.2391927827510142, 0.1651028414527255], [0.010231367571489706, 0.03562860431209688, 0.043270323695915366, 0.06098605331874663, 0.0851346155808818, 0.05298268680851306, 0.047284237544743285, 0.0884440005005848, 0.9822512766526592, 56.7771593986019, 50.76183603655908, 38.75016573936709, 39.59926474478937, 57.77991725552467, 72.26160603184854, 58.71631253150202, 0.8737454635481682, 0.052484292987613916, 0.10762452087815731, 26.439193102621264, 92.79248391428303, 75.92589993630686, 80.27392571972263, 66.5930986404419, 66.33248852145287, 61.34008007664835, 64.5354114809344, 69.4385899266889, 70.97395466219994, 72.91723020615117, 73.48012954958024, 74.46600944765153, 73.52449155622914, 63.99226519369311, 64.07850242430165, 74.893798828125, 57.859498223950794, 51.71132026180145, 74.71796681804042, 69.72560544167796, 67.11242045125654, 69.16247075603854, 64.87960730829548, 63.45969753880655, 63.07086513888452, 56.850982327615064, 50.880868204178356, 50.111428614585634, 51.228731447650546, 47.24186966496129, 51.14836600518996, 50.419726910129675, 45.88059148480816, 46.55721995138353, 43.89113003207792, 46.483471547403646, 44.41175799215994, 44.51776789080712, 45.808733663251324, 50.99221252625989, 51.87761698999713, 48.79444183841829, 48.31330430123114, 49.440895511258034, 57.319250568266845, 56.92784901588195, 56.30853422226445, 52.4878671861464, 54.03548540607576, 53.92814974631033, 51.30002444790256, 50.56230114352319, 46.43572061292587, 45.192286122229795, 41.97795867919922, 42.91293405717419, 45.32345802553239, 46.93277120590211, 44.17306607769382, 44.237432172221524, 43.26260159092565, 43.36648556493944, 44.91130321256576, 44.25798146955429, 43.42622718503399, 40.35412488445159, 31.53754476578005, 36.23089013561126, 37.294330981469926, 40.482857073507006, 35.25278829759167, 35.65132071894985, 43.78692442371, 42.875020427088586, 43.93582936256163, 42.84256281391267, 44.78632865413543, 44.97782268831807, 45.46181571099066, 43.77886787537606, 42.72653518184539, 40.37388578537972, 43.34760327492991, 42.06550990381549, 43.05073084369783, 45.95787002194313, 51.352478304216945, 52.744374505935184, 54.13391336317986, 53.231638785331484, 49.91249384418611, 46.74437584415559, 46.37349613251225, 49.39734935760499, 55.70376749961607, 52.40367351039764, 46.57299964658676, 43.894020818894916, 49.36153027319139, 44.15101059021489, 44.11583477450956, 44.193058398462114, 42.76279749408845, 41.848406714777795, 42.17710525758805, 41.85968745139338, 47.62494402547037, 47.18248498055243, 51.37531042099, 61.61637575395646, 63.28224166747063, 64.24192405516102, 60.15336305864396, 63.65005408563922, 60.316345384044034, 58.975538053820216, 61.500916865564164, 64.67536949342298, 65.83742264778384, 73.63658505101358, 68.87123477074408, 63.73097650466427, 65.63212187059464, 68.86344494358187, 67.45421578807216, 67.52171193399738, 66.87721160150343, 68.17313917221563, 65.92307936760687, 66.83128849152597, 61.55996030376804, 63.76787424087525, 61.865913021949034, 68.24527940442486, 72.12972810191494, 79.56438464503135, 81.58695482438611, 64.8815175025694, 0.4747650646153958, 0.2018977839860224, 0.21800971620025175, 23.038380492118097, 76.72780498381584, 60.841472302713704, 45.893966767095755, 28.145343718990205, 29.55594962643039, 27.477681790628743, 1.1502392205499834, 0.20605695193573353, 0.04493610910891045, 0.058270355896844026, 0.11948277287545706, 0.00605411037066651, 0.061674869784544555, 0.03651939219825211, 0.016088424806272792, 0.024093541827413346, 0.02097612130455673, 0.05737666070701615, 0.09840773238289742, 0.0620724655868065, 0.0675976908795776, 0.06519924578887802, 1.9058849374132774, 68.64509444082938, 59.31398368650868, 45.77544842996905, 43.84293586977067, 66.46194242662, 79.25629815747662, 56.193259685270256, 0.20091179818395646, 0.03584252670407295, 0.1304075620587795, 28.394561313813735, 94.74107034744756, 77.85713380382907, 83.0499126065162, 68.77016313614385, 70.61495580980855, 62.66563723164221, 67.4969696229504, 71.92652579276793, 74.79605336343089, 75.73339785298994, 75.4980242636896, 77.62477259482108, 74.20186135076708, 65.67821756485971, 63.57422682546801, 75.51969928126182, 60.63240605015909, 56.24628228525962, 77.98659555373654, 71.24255857160016, 71.87649988359021, 70.85519313812256, 68.65652422751151, 65.6085366587485, 65.32382749742078, 61.503623300983065, 52.65796861340923, 54.08292647330992, 53.528793627215975, 52.0769557645244, 53.141404659517356, 51.48519562136743, 48.850708238540165, 47.08221743183751, 49.328645121666696, 49.50265715199132, 47.95081061701621, 49.305526671871064, 47.62426937780073, 53.42141089900848, 53.444823526567035, 48.64121444763676, 45.615741283662864, 47.87462642115932, 59.87004241635723, 60.08246621777935, 56.66212020381805, 56.03164626706032, 55.276221306093284, 55.052155909999726, 54.30862749776533, 53.46402352856052, 49.87285829359486, 46.97787454051357, 46.02285192858788, 45.3623914718628, 48.50827355538645, 49.07433040680424, 47.30261541181996, 47.433767703271684, 47.42831560873216, 46.43447329921108, 47.667238943038456, 44.93063657514511, 46.51822766950054, 42.52858100398895, 37.065739170197524, 41.57364860657723, 41.70515391134447, 42.38273551387172, 40.96389262906967, 40.71121354256907, 46.45499513995263, 45.74445386086741, 47.07732231386247, 46.561503179611705, 46.799673418844904, 46.744207182238185, 47.12000554607761, 46.23282817102248, 44.298417183660696, 44.178184770768695, 44.627241242316465, 42.88233956983013, 47.769824612525206, 49.011305762875466, 53.94030909384451, 55.79644918441773, 55.40598115613384, 53.9772617432379, 52.10927609474429, 47.444997449075025, 46.86754611230666, 53.425784341750614, 58.248405148906095, 53.359712016197946, 46.33455876381167, 44.54829569785826, 50.29827071774391, 45.24936053060716, 45.86804774499709, 45.90964055830433, 45.091500820652136, 46.301340210822325, 44.26193129631781, 45.01409676767165, 48.18211670844786, 49.518358399791104, 53.17189716523694, 63.82885140757408, 64.67287878836355, 64.12955599446451, 62.878512105634144, 64.99769418470322, 64.13272919193392, 62.76610089886574, 66.09079207143476, 68.00708955334079, 67.57587202133672, 73.3507070233745, 68.24899781134822, 63.50223564332532, 66.9577064821797, 71.45726911483273, 68.92795224343577, 70.3535847510061, 67.36419739261751, 70.7312854643791, 68.98185345434374, 68.06149282763081, 64.94996678444647, 67.19402144032141, 63.362885598213445, 71.01264492157968, 72.75085110818186, 84.70127751750331, 80.31976253755631, 78.89237280814879, 1.3197411380467878, 0.1454921090795148, 0.1480559448921873, 24.670078639061224, 84.9884734615203, 67.97300415654337, 55.32314854283487, 27.47638740847188, 43.67674896793981, 44.37325992891866, 12.5223893696262, 0.16291276461655096, 0.04257889103985602, 0.013869591902250485, 0.025796325456711556, 0.017412322415639798, 0.019946315273221944, 0.034574578411035964, 0.2124382345186126, 0.10312537076852976, 0.07141345225635075, 0.21255363800352622, 0.3232230059802532, 0.06528249656360957, 0.14187344680390052, 0.21309052774262047, 1.9357987709583777, 81.26608141006963, 63.18736345537248, 55.41757175999304, 56.43719580865676, 74.65716223562919, 84.09720113200527, 70.69399941352107, 1.5759580798687474, 0.14849768651108589, 0.33014289433917693, 31.456600773719053, 100.38067771542458, 80.92631001626292, 86.25176691239881, 72.07893340818345, 73.36904802630025, 65.69878255167316, 72.01109209368306, 73.75820990531676, 77.4031900590466, 77.73837227975169, 80.17391312506892, 79.73992639972319, 76.22272922146705, 67.5362325483753, 66.07307080299624, 75.21825728877899, 64.84631030790268, 62.16302079539146, 74.52216994377875, 74.12535944292623, 74.22523867699408, 73.28667040794127, 71.64830423170521, 69.98987120966758, 68.80361310897335, 64.98159677751603, 57.92853586135372, 56.25374655569754, 56.01055568264377, 53.9172730138225, 56.37211192038752, 55.36779688250635, 52.32268833344983, 50.43400433755691, 50.4620296724381, 53.329243044699396, 49.578507946383574, 49.44364117037866, 48.848817656117106, 54.54600541822372, 54.56381690117621, 51.20608760464577, 45.42198011952062, 49.09911586392311, 60.902068999505815, 61.02638852211737, 60.463818657782774, 57.767612780294115, 57.73945408482706, 57.420871334691206, 57.44267186810894, 57.91488601315407, 51.920268843250895, 49.5212217300169, 46.69561293817336, 49.43458834002095, 49.89535308653309, 51.23563089678365, 49.874635127282914, 49.85390540092222, 51.09202115766464, 49.703411902150805, 49.29487743685323, 48.45432527603642, 48.36784878084737, 45.418610803542606, 42.09622206226472, 49.079460866989635, 52.33287080641716, 53.36583091366676, 46.29375042453889, 43.28732429012176, 49.45065436824676, 49.87007733314268, 50.786758776633974, 49.37339936533282, 50.102724875173266, 50.2318649907266, 49.37659609702326, 49.439926685825476, 48.69065200128863, 46.32586286913964, 47.4540267452117, 46.31461743385562, 49.14906724806755, 50.39792245434177, 56.98347606966573, 56.43134755472983, 56.445013092410186, 54.26695623705464, 50.36447640388243, 47.43536410793182, 47.47880827996039, 55.162958944997484, 58.075456080898164, 54.88489820111183, 48.58295548346735, 45.81806105952109, 50.71033531619657, 46.714793328315984, 48.78820919221448, 48.49142697549636, 47.580060343588556, 48.608211625006895, 46.80238769900414, 46.83572392309866, 50.03100825894264, 53.412361991020944, 55.35322919968636, 66.35412431532338, 66.71713967477122, 68.18788728406354, 67.54945878059634, 71.10016084486439, 66.84930001535724, 66.06054275266587, 66.94710039323377, 72.57676847519414, 70.28307622478854, 75.37287712097168, 68.59561766347578, 68.75422262376355, 72.99216316592309, 77.06585053474673, 71.69725541145571, 76.01427878102949, 69.86720300489857, 73.16436306122812, 72.34490148482784, 73.93084126134073, 69.06253660878828, 70.33559676139586, 67.01283147258144, 76.45720066562777, 76.42169537082796, 89.54363961373606, 84.5398170717301, 84.93809453902706, 2.1857498490041305, 0.21463178939396338, 0.263468362390995, 29.99581402347934, 94.99731879080497, 76.69212710472846, 65.79322538068219, 50.4052298299728, 55.872841265893754, 61.64280468417753, 21.96486503847184, 0.5147708808222126, 0.3974724927496526, 0.23008549886365093, 0.3292589820921421, 0.16296931722712132, 0.18086097894176362, 0.20930134961681984], [0.053787362581539544, 0.039650144566211014, 0.021237008716730822, 0.04933826099600523, 0.11452381679367636, 0.0648083494255139, 0.024456949040834463, 0.22858882352950113, 2.90045325313845, 62.04603218263196, 50.55562526948991, 33.06469801933535, 28.591585889939342, 55.238801894649384, 76.97296096432594, 21.43015184710103, 0.5287984410120595, 0.3657082504322452, 0.5575177902656218, 24.878107424705263, 90.1163056588942, 78.86163711547852, 78.92890576393374, 69.23439133551814, 62.868937600043516, 64.88482013825448, 72.68304117264287, 72.45287649093136, 73.39861485265916, 75.03250168215844, 74.61986049529045, 69.35927175706433, 66.21667661974507, 69.94959631273824, 71.14137711063509, 64.4628672445974, 67.36936707650462, 55.43442226225331, 59.18269411210091, 76.3266484968124, 64.07761989101287, 66.4316068157073, 61.01990092185236, 65.93661938944172, 60.2475352441111, 61.22833567280924, 49.228703129676084, 49.59371105317147, 48.18139106996598, 50.096307877571356, 49.69879919482816, 49.212511585604766, 44.9261180047066, 46.60794012008175, 45.268501697048066, 46.34656513890913, 45.79256565340104, 46.24921583360242, 47.322497906223425, 52.42091624967514, 53.108229252599905, 52.40338325500489, 53.88354847508093, 63.11301492875623, 60.893953615619296, 54.68444155108545, 50.66993098105154, 52.984411793370406, 53.51600277808405, 54.51853313753682, 53.75540071918119, 52.131986618042, 48.4175609004113, 48.11140421898135, 46.43084902917185, 48.63477391581382, 44.9693033003038, 44.350796514941806, 43.07464553463844, 46.69833114070278, 42.290967741320216, 43.25477646243188, 43.402002626849765, 44.19807903228268, 42.43966087218254, 42.68473056054885, 34.08961334536153, 40.17795555053219, 37.53922808554865, 39.24094838480796, 35.12900221732355, 35.30732101009738, 45.61806332680487, 40.765648195820475, 45.875676754982244, 45.16107974513885, 46.98894346913984, 44.217800709509085, 45.18280967589348, 45.76948250493696, 43.04507478590935, 40.90092682069348, 46.74114773350377, 45.513661599928334, 48.82274566158172, 54.4393208719069, 54.675447556280325, 54.29721340056389, 56.29627289310579, 52.58971937241093, 51.41873890353788, 46.17132148435039, 50.601418941251694, 56.26642365609446, 56.57202336095995, 52.625765954294515, 45.76151224874681, 44.90695330404466, 49.051007993759654, 44.994912455158854, 45.49135900312855, 43.67705099044308, 41.463355479701875, 42.270951886330884, 42.190739416307025, 43.819197685487815, 45.932935514757716, 45.911974368556855, 51.54879685371153, 61.68931222731068, 62.47329204313217, 59.58262289724043, 58.97365923850768, 64.75481710126324, 63.0284329383604, 66.1578881356024, 61.409545252400065, 67.7497350015948, 66.47115999652495, 57.73635149002076, 51.199529401717655, 55.28777660862092, 61.23201877840104, 68.87207415796095, 66.73020116744503, 67.85783552354383, 64.01383822964084, 65.84387102434712, 62.26227245023174, 66.27569260135775, 62.3922872543335, 66.76991124306956, 61.42884723601803, 68.3413774736466, 67.5280975526379, 83.53629435262373, 72.81389928633168, 91.76101038532873, 6.590174167386948, 0.29883756933193056, 0.2921228086756122, 15.04429982554528, 79.1076873963879, 59.89077214271792, 48.31812489417292, 26.434996166536887, 31.363826913218347, 27.38393714351039, 3.553413402649664, 0.06940266297709557, 0.06425595789727184, 0.03957122218825164, 0.061645145573082476, 0.026963065874071854, 0.07371843462028811, 0.03849225629481577, 0.009680050481561451, 0.07375362103865032, 0.04750372939592889, 0.03697642493211935, 0.04645383270877985, 0.02156834557442175, 0.09747136609568711, 0.2201301556441092, 3.4970089841273526, 72.39177380838703, 57.3611101027458, 39.17527614101287, 33.41415766746768, 63.600424335848906, 83.2240266184653, 22.835988152411677, 0.6255682774128453, 0.45925300988939505, 0.8092778776922535, 25.76323732253044, 92.75192660670128, 80.892805130251, 80.59784289329284, 72.13063024705457, 65.42978640525573, 66.58718370622205, 75.67398963436004, 75.10628930984005, 76.96972108656361, 77.34880247423726, 78.52556843911448, 72.15050881908786, 68.26769967232981, 70.46479963487195, 72.13386228007656, 66.1761663806054, 68.29876484409456, 58.975200729985396, 62.27885230895012, 76.00837169154998, 67.50952905224216, 70.45015350464853, 62.55737589251611, 65.85284540730139, 61.888176395047104, 64.15439244239562, 52.47361721531038, 51.35773035787767, 50.2632753310665, 51.540634401382945, 51.38139793949743, 51.42922339900848, 47.582935440924864, 49.69111134929042, 46.716542705412834, 49.088270510396654, 48.934729330001346, 50.949866617879565, 49.6677654020248, 54.431448674971065, 54.813385548130164, 52.459339787883145, 54.601569714084754, 64.97510525488084, 61.989173504614065, 56.48975949133597, 52.00947923045005, 54.216926405506754, 55.61724001361478, 57.14421872169741, 56.49672954313217, 55.61380401734383, 52.497759403720984, 50.24830364411878, 50.012357388773275, 49.280972634592366, 47.769471599209695, 48.401228151013775, 45.2861366733428, 45.83597060172789, 44.55472446257069, 44.76215900913362, 45.113666134495894, 46.08172278250418, 44.189151717770486, 45.902466543259166, 39.27734405763688, 42.32187994064824, 39.35172396321451, 42.019822136048354, 40.220144564105624, 39.297983569483605, 46.39197049602386, 44.6799147513605, 47.15488718402001, 48.443142598675145, 50.419338595482614, 47.473787646139826, 49.20640837761664, 48.00207207279821, 46.139746404463246, 42.8933104392021, 48.2449766128294, 46.75795116732198, 51.028412080580196, 58.035997036964666, 55.41670099381478, 56.344871059540786, 55.64202547073365, 54.62307214736939, 52.89282444984683, 47.432477243484996, 50.56765125643823, 60.28733945661976, 58.01793059995098, 53.489161998994895, 46.53618035777923, 45.19294115804857, 48.82419301617531, 46.25634670257569, 46.61526318519346, 46.93386162481001, 45.00303176141555, 45.877618328217544, 44.02994271247618, 46.4929283818891, 48.09931939648044, 49.865911776019686, 55.268502081594164, 63.33684890500961, 65.21693898785499, 63.50093341642811, 61.53282926928613, 66.75502192589545, 64.62642615841281, 67.80762918533819, 64.24070419803743, 69.08297215738605, 67.57972378884593, 57.71141306046517, 51.601964581397276, 58.78573848355202, 64.85903839911184, 71.35378914494669, 68.08823554746567, 70.00003014841388, 65.23389147173974, 69.14391010038315, 66.57471056907409, 69.62874643264279, 65.83717946083316, 70.58121558158629, 64.36450989015641, 70.75312522149855, 69.48297546755883, 86.5925032092679, 74.31037764395438, 99.117564693574, 10.042876793492226, 0.3262414230454353, 0.24729229329574495, 15.423025258125799, 90.04496559020012, 66.11349474999213, 59.46528519353559, 25.185887967386556, 36.60501756975728, 43.18390707815848, 14.0801743730422, 0.47756395152499603, 0.1887332678081528, 0.06417555313917898, 0.04818465898654634, 0.011585456705952605, 0.061466068690342296, 0.05089261892041372, 0.10537748540481252, 0.2246881796107177, 0.18894509111921634, 0.17313136629039244, 0.24453710404134568, 0.271939272361417, 0.2258177302897938, 0.3528922429728893, 4.956793323639901, 84.72927539579331, 63.77486782689249, 44.47981111464962, 41.0758331514174, 74.17455380962741, 89.11146502340995, 31.567672491073612, 0.7497386886708198, 0.6456810884898709, 0.8954646077848251, 30.26331574686112, 94.5102467075471, 85.91343110607517, 85.50589684517153, 76.24212141959899, 68.57518995961836, 68.79203427222468, 78.70642108301963, 78.00166529993858, 77.78228713620094, 80.58951962378718, 79.72436243487944, 74.83893271415465, 68.65739499368976, 73.96869213350358, 74.06318987569502, 72.36765907656762, 68.38286046058901, 62.95860690455284, 67.61101645808067, 74.77422929579213, 71.09957248933854, 71.17846704298451, 66.86219676848381, 71.74975241384199, 64.07911039167836, 67.87237967214277, 54.79201255306121, 54.25913110856087, 52.75252911352342, 55.05891415380663, 55.69025493437245, 55.220115723148474, 50.02218292605493, 51.852580501187234, 51.80633575685563, 52.41591522770544, 50.46784262503348, 51.55775946955527, 55.1565811710973, 56.12823071018342, 55.50355403654037, 52.5944144495072, 57.72950695407007, 67.44880291723436, 62.018575591425744, 57.84675836563111, 53.10180441025765, 56.38422419947963, 59.38670442950342, 59.0883493423462, 59.784777933551425, 57.130702234083614, 56.44820197936028, 52.308920814145, 52.10246293775497, 53.492888250658595, 51.45930405585997, 50.46808581198416, 47.57037208926293, 49.343836461344075, 46.578106572551114, 46.562268041795306, 49.666274901359316, 48.34919006593766, 48.95112091495145, 49.164572377358716, 43.23753372315438, 49.0292388393033, 50.990620043969926, 50.27294005117109, 44.122761680233864, 41.49526788342384, 50.104756662922526, 45.79333836032499, 51.041661847022276, 50.3226835496964, 50.69188056453582, 49.52382226144114, 50.90159793053904, 51.097108471778135, 49.267973899841316, 45.519486319634225, 50.24006274438674, 50.13595519527313, 53.52871517981253, 59.63569256567187, 58.60480346987325, 59.27590531687583, 60.782566147465865, 55.87364535177908, 53.046204813065074, 50.34974790388539, 52.83685614985805, 63.124327044333185, 58.18931464226016, 54.062836093287316, 47.21698222621795, 44.89836723573747, 51.020053509742986, 48.98289603571738, 49.62483113811862, 50.7038987067438, 46.58342530650478, 47.966825654429776, 48.21610404599098, 48.793928007925714, 48.818740921635786, 52.89029059871551, 56.86277297235305, 67.15055373407179, 66.20690991801601, 66.65666457145446, 64.1094381578507, 69.6918652134557, 67.99455365827008, 70.35480068575951, 63.84241888600012, 71.74069958348429, 67.75772879200598, 60.98634896739837, 55.52074186263546, 61.7950475600458, 67.40475470019926, 73.83293105709937, 70.19674485729587, 72.90840487326346, 69.48488958420293, 72.10023972295946, 68.82104412201913, 75.27686534389373, 69.85282359584686, 77.1784931613553, 67.1723150437878, 74.57964051154353, 72.10094574959048, 92.10395889897501, 76.51121170290055, 106.88232006565218, 11.037355507573775, 0.4201309833555453, 0.34470316142805163, 19.507553077513172, 97.81134482352965, 75.544355300165, 68.73235148768272, 46.677334693170366, 58.471948869766734, 61.94591760635377, 27.810475287898896, 0.5029868550838963, 0.3548754301042326, 0.20396262076833557, 0.3481441832357838, 0.25957010866653535, 0.15821408690704455, 0.17655343508287785], [0.06608480512495003, 0.0701564092249159, 0.04363267562322078, 0.05386977448999401, 0.012646566047483395, 0.02607960944935199, 0.07131732354361205, 0.22284647359723048, 2.908562018025306, 63.83601365550872, 45.70759927072833, 40.835572288882354, 48.350735479785556, 59.60243871135097, 75.12267697242, 10.955998686052139, 0.526052107734065, 0.20500926541224604, 0.5898912563439339, 20.649666863103068, 94.64424271737376, 76.53011752713111, 77.89415313351539, 66.34406735820156, 63.061016067381836, 71.9149704902403, 75.19678623445573, 73.72080618335356, 75.12088052688107, 72.40433323767878, 70.85442435356879, 67.42689255745181, 71.20751611648068, 68.34413882224791, 68.22518902440225, 70.91726856846964, 63.09880025925175, 65.7368766107867, 55.32735724602976, 66.28882469669466, 68.88515918485581, 66.13862929805633, 65.50358580004784, 63.99069624562418, 66.21614317740163, 60.4514318127786, 50.580469562161355, 47.66564646074849, 50.146314174898215, 48.935627552770804, 49.7638830830974, 48.59355372767295, 46.18662657276277, 44.07428118490404, 44.730058331643384, 43.19957694699688, 46.87047220045521, 44.32765060855497, 49.2437336521764, 53.367435163067235, 63.529237239591545, 53.452793782757176, 62.670901052413456, 66.33965861412787, 63.65612983703614, 53.758797491750414, 49.60260698872228, 49.90902646895378, 54.83437415092222, 54.815503628023215, 56.37540671133227, 60.924548102963364, 53.71274102118708, 50.18194106317336, 49.314352004758774, 45.73545986606229, 46.75940636665591, 45.91479847508092, 44.93872058007025, 44.64121664724043, 44.30645412014377, 44.24305292867845, 43.845944327692834, 40.586384111835116, 42.763738862929806, 41.349449849897816, 35.79970006019839, 45.88211728680519, 32.13733792304993, 38.95134802787535, 43.29999354577834, 35.34280277067615, 41.670052620672415, 43.88913746803038, 44.90047354852, 44.44494124381773, 48.93685917700491, 44.902615162634085, 46.595094357767415, 46.451598367383404, 46.27480537660661, 47.45047307783558, 50.66549870275682, 56.33697140601374, 58.98194720668178, 54.75954709514495, 55.142754816239886, 51.29232091288413, 53.19973814872004, 49.60656466022615, 49.16834961983466, 48.99384337086832, 47.13584407683342, 51.97034182087068, 54.787105667975645, 54.692847190364716, 50.789484823903734, 48.20063029566119, 46.30522335729292, 44.30687381375221, 45.193282404253566, 41.911305842861054, 42.901998489133774, 41.592283787265906, 41.35054419117589, 47.051171871923636, 46.94413038992113, 46.04451910141976, 53.86294426456575, 59.419766087685865, 61.86524621901974, 56.149278148528076, 57.53654595344298, 63.43370006930444, 63.34664698570006, 65.08497868814777, 68.57377790635633, 68.44372780092301, 54.9442397394488, 55.5505322640942, 59.47734648181547, 66.58836041727375, 67.27563811886695, 72.40505495379048, 65.95008880861344, 69.11200554140153, 65.26861621487525, 65.7334759158473, 61.68000836526195, 67.24938177293348, 60.683816556007635, 66.47775742315477, 62.842998966093994, 69.65526165500765, 62.69000691752281, 84.76329018992763, 72.6894267912834, 97.47088309257262, 17.37673528732792, 0.17776668852856084, 0.23750179687574988, 8.925749486492528, 77.60158354236235, 57.51325099698959, 49.618692628798954, 15.208138208235464, 32.44653051899326, 29.5540355097863, 4.7710784116098965, 0.1318132108257663, 0.07706977051472472, 0.056917628483666535, 0.08955911808316747, 0.019389321471774773, 0.02782374842002267, 0.0798785093150312, 0.02482906092829522, 0.0016745664564246734, 0.024775681836951165, 0.024794261384334777, 0.042479368557612744, 0.07361339630499002, 0.1225527706405809, 0.14663814597072142, 3.481318767993681, 74.38366320825394, 51.282911146840746, 41.56430552082677, 53.42190511765019, 68.21140581561674, 81.64651209308256, 12.096242481662381, 0.5458435908921304, 0.25129498012604257, 0.6106062738164779, 22.153150573853527, 96.1410427093506, 78.39122726071265, 81.44119954878285, 67.33093569355627, 66.53509463033369, 73.51259108512633, 77.50017458392729, 77.202819701164, 76.94090735527777, 74.48456225856658, 70.97817513250536, 68.12102656210622, 72.49726987654164, 70.63806641486384, 71.83986494618078, 72.94831891213694, 66.9991345559397, 67.23432771621212, 59.979115686109, 71.73833831664055, 69.68183179055491, 67.81596814432453, 66.59374190915015, 66.04705764401344, 66.76198805532148, 61.71751406884963, 54.6859359741211, 50.157920468238096, 53.27001525509743, 50.68513016546927, 52.240334249311886, 50.3295555422383, 49.35914154975645, 47.29774775043611, 48.195064452386674, 46.061604945890366, 49.02985857379053, 46.21334575837659, 51.34733215455086, 55.716162189360595, 66.50735562847507, 54.78943163348783, 64.14999938780262, 69.13401003806823, 66.84217699112432, 55.42244334374705, 50.64149771967242, 52.336448008014315, 53.60939048951673, 56.81058583721038, 59.260149155893636, 63.43933651524206, 57.48494325145599, 54.91850506874823, 52.187535224422334, 49.264235881067094, 48.19002420671525, 48.10084519847747, 46.2311258623677, 45.82549395099763, 47.58901903706212, 48.63700966681204, 44.663201532056256, 42.14243542763495, 45.62195039564564, 44.370698621196134, 39.62255577887259, 47.40183568769886, 36.772165452280355, 42.949384643185525, 45.83938698614798, 38.96289940803282, 44.80198675586332, 45.41092688037504, 47.325086670537154, 48.19156962056314, 49.159724327825735, 47.362812026854485, 50.456989426766675, 48.1645994032583, 48.25677117993755, 50.42606153795796, 54.47022522649458, 57.70803982211698, 61.3912630850269, 56.386142238493896, 57.185187878147254, 56.1565423780872, 54.158451710977864, 51.83507888547836, 51.7324383028092, 49.80788815406061, 44.96303927513861, 52.51080128454393, 57.902981619681086, 57.356207140030406, 51.005293630784564, 49.96654410516062, 49.70742840920725, 45.096780330904075, 45.246967884802054, 43.85019225458945, 45.26302214591734, 43.59102556782384, 44.8018612400178, 47.877917289733894, 48.78860535160188, 48.451199147009085, 58.666470973722404, 63.6882265921562, 63.42583179473878, 58.78405186437792, 58.336685934374415, 66.23118938938265, 65.05052851092431, 66.797987568763, 71.31147461552774, 68.21398673519012, 56.794147183818204, 57.954576476927734, 61.51765361908944, 67.98865441353091, 66.8114491431944, 74.67519729368149, 70.23225015209567, 71.35818219953968, 67.4291596874114, 69.1629022167575, 63.84443498426869, 70.48304650091356, 63.93959952938942, 70.95733950215002, 66.26478056753835, 73.3506364207114, 63.558439285524436, 87.56143062345444, 74.49181079864502, 99.7794254364506, 21.519750548947243, 0.20861387763532901, 0.14662834004529063, 9.042442940896558, 87.7308770148985, 65.1124039003926, 60.386724472045906, 21.251093687549716, 47.10758732211205, 45.80404643089541, 16.65796095325101, 0.16102371436934318, 0.07722963774276358, 0.01316170750801722, 0.09333888864925793, 0.03315726978584163, 0.0544676295061025, 0.036546078871094415, 0.1644913807150818, 0.18557229710202064, 0.13207014139381149, 0.16800560988485816, 0.10874244234254284, 0.07809347848618224, 0.2276093188312746, 0.3507475951506246, 4.603141642385914, 86.96432821212277, 56.23472698273198, 53.85662924858832, 63.001172465662805, 74.02967714494275, 87.75971428040536, 16.18055457069028, 0.8898282844212748, 0.4636122033961358, 0.7550514164951541, 26.129363121524936, 100.91001725965931, 83.84809140236148, 84.31765402517011, 71.63220682451802, 69.60987198737361, 77.04836460851854, 78.9986062818958, 78.25314414116644, 78.72092600791686, 75.31663033270067, 75.1493412448514, 68.2234239578247, 76.85348556887719, 72.97012729029503, 74.4901555584323, 76.11629962921143, 69.54519210323211, 70.56815408891248, 62.19340739711639, 70.4045206500638, 73.53602332453575, 70.17758015663394, 71.70446472783243, 70.34064092943746, 70.41788808761105, 66.77783443081763, 57.97610636680358, 52.43444450439946, 54.84389374333044, 53.78236701411586, 54.053700893156, 52.815636127225815, 50.708527103547134, 50.86952078726984, 50.895455498849195, 47.09700084501698, 52.521791765766764, 48.29030352254068, 53.91227983659314, 57.44529593375422, 70.21631748445573, 62.94956976367582, 66.0131291420229, 71.99342573842695, 69.61831292798443, 55.3096281328509, 52.1716143238929, 54.655172824859626, 59.05351477284586, 58.9719843864441, 64.24461480109923, 64.93404196154687, 59.865661128874756, 58.31708192825318, 55.61409035036641, 52.186876266233384, 50.42427293715939, 49.94627721848027, 48.47811052876134, 48.486002337548044, 50.94869775156821, 51.470588714845725, 46.821419039080226, 45.042424125056115, 48.59021579065631, 46.687136696230986, 44.49048780625866, 53.40071647397934, 49.353587473592455, 52.11170011951078, 49.03589902385589, 43.03874408045123, 46.01664281660511, 49.47630666917371, 49.56454430857013, 49.65688866953696, 50.47362812103764, 49.5725812450532, 52.71584710767193, 49.52121388527655, 51.49874741031278, 51.51176183454452, 56.19584060484364, 60.87831512574227, 63.29358516200897, 58.50229624778994, 59.19385325524115, 56.606359789448405, 57.78929956497685, 55.23147882953767, 52.70778663696782, 52.08977014787736, 47.56590843200684, 54.43153104474468, 59.069620024773386, 56.794751228824744, 51.82023271437615, 48.85605050671486, 50.340322448361306, 48.71192693710328, 48.69641396307176, 47.59393768925821, 47.46821788049514, 47.9386708813329, 46.74159880607359, 52.45055760106733, 51.83869923314741, 51.01143606247441, 61.49323686476677, 65.57528280442762, 66.10086471803727, 63.18841465057866, 62.548134788390136, 68.43170965871504, 66.10708559713056, 71.35193778622535, 72.15310542814194, 70.23304247087049, 60.73772561165595, 60.63121364962671, 62.89748461015763, 68.62145039343065, 69.15309629132672, 77.84063631488432, 73.19928000050207, 74.31901470307382, 71.67336817710631, 73.17945634165119, 67.90244856188374, 73.95843905787315, 68.39301939933532, 75.54677148019114, 69.704801190284, 76.87380344636979, 66.56961148785007, 91.48861746634208, 75.7553082127725, 104.90288026871221, 22.466187092565722, 0.283551050890838, 0.29971072570450846, 11.42308040972679, 96.31632558761105, 71.65916135234218, 71.12364799745622, 31.480523309400006, 59.22880157347649, 57.79411231317828, 31.06369499237307, 0.3663051861428446, 0.30666150272853915, 0.10682477105048396, 0.251796507246552, 0.153523008789747, 0.15643282523078306, 0.13609360452861557], [0.03424236438267174, 0.03713583633784325, 0.04266365483823804, 0.023344947520883817, 0.025460983874396454, 0.033321013418777336, 0.023441112622798934, 0.08531357371999372, 2.746389416917678, 60.493977762037716, 42.302366149040964, 52.7785736514676, 52.02778100967408, 57.905676287989465, 80.189712432123, 11.011376669329982, 0.7222053660981117, 0.5826730533472954, 0.8248921591908702, 17.19820860893496, 94.40263255949944, 73.54077723718459, 79.29784390234178, 61.249771425800944, 65.65462450827322, 72.99974902983635, 76.46482575324275, 76.34720956125568, 68.52949434711088, 67.09160835512223, 68.79303839898878, 72.2210330347861, 69.76174616044568, 72.73682471244567, 68.66273726186445, 66.48704559572282, 64.90630295968825, 65.8099425223566, 59.59337803625292, 59.44168429220877, 66.69995184867614, 62.864426874345355, 62.66195804842057, 64.09001850312757, 63.76026876511113, 58.766789513249556, 52.750830727238814, 48.40956318762995, 50.468117190945534, 47.69984168391074, 49.160367596533995, 48.805836323768865, 45.794287573906686, 41.959382334063136, 44.37557020495015, 41.968603826338246, 44.349513899895456, 45.77811564168623, 47.341007571066584, 49.85237567655502, 57.2837648853179, 55.937838862019206, 61.233297471077215, 55.00207901000977, 50.001390441771484, 55.27600165336363, 49.45947970113447, 45.281374915953606, 45.08147132012152, 47.08748517497894, 50.043465706609915, 51.00329322199668, 56.88566784704886, 53.93327628412555, 49.21152314832134, 48.37668195847542, 45.93459075497043, 44.07565401446435, 42.76281318356914, 44.179345792339696, 42.12290986891716, 42.20990803933913, 44.803151699804495, 39.18325031957319, 47.148015191478116, 40.59204801436394, 42.23140262788342, 48.84257324280278, 29.93225789839222, 36.089794635772705, 48.677543440172755, 39.44626877384801, 42.600540807170255, 40.700736891838815, 43.52433350778396, 42.34894429483722, 49.72266289495653, 48.22046179925242, 49.98521458718085, 52.21094392961072, 49.66236037592734, 54.69701274748772, 54.979627363143436, 56.521377717295, 57.25743009198097, 56.41634056645056, 56.861498202047045, 57.281050605158654, 53.47100926983742, 52.01863796480241, 51.85287467895016, 48.7001637489565, 47.35523793005174, 54.21001126689296, 57.921950201834406, 56.07396079647926, 51.25190481062859, 55.60289198352445, 52.68608024043422, 45.23226291902604, 44.4925235163781, 40.98066076155632, 40.688950169471006, 42.458409801606216, 42.072629005678245, 45.02836242798836, 46.15452981764271, 43.1868213991965, 52.78879534813666, 59.34125592631679, 59.57805333598968, 54.38872229668402, 53.443611514183786, 64.6781857552067, 60.6333395742601, 66.48007946629679, 61.344273090362556, 53.46634164933236, 61.192257711964274, 65.51092063227009, 66.0026171899611, 67.81658787881175, 67.65943419548773, 68.1747708782073, 67.1468274824081, 70.05066010259813, 66.59491077546151, 67.46073476729855, 63.36340727344636, 63.42787927196872, 64.7820971858117, 68.24808782146823, 63.911601651099424, 70.53542583219468, 64.24530121587938, 83.32501196092176, 74.53976569637176, 97.82708921740132, 26.098709798628285, 0.4834753923839139, 0.10776783294615247, 5.1460859275633295, 73.48449906995221, 56.64205335801648, 54.23146270936536, 19.711553588990245, 22.936434168969434, 31.378096495905233, 8.874292892794456, 0.18901388581481673, 0.06378253854270424, 0.08011915285380618, 0.0480939120414757, 0.06748250189928279, 0.041446655222605315, 0.09880258175995081, 0.06547608698207526, 0.07798022770833585, 0.04035452027775107, 0.12189444830460895, 0.09365283914150731, 0.05190404267200539, 0.12891148427321067, 0.15039364687137066, 3.839751083043314, 73.37389607583323, 48.240752220153816, 49.84509967988538, 59.90613606668288, 63.11057129213887, 86.64938542150682, 13.094292513785824, 0.8932566811000148, 0.6893905108013462, 0.9178184405449898, 19.136995000223962, 97.54598863663213, 75.93998908996582, 83.1088815196868, 63.484545753848174, 68.15974820044734, 74.10886979872181, 80.29212551732218, 76.87953010682138, 69.82637897614511, 66.38212219361337, 70.1884372772709, 72.25786409070416, 72.98103147937407, 72.3356996044036, 71.51103696515484, 69.4122943570537, 66.82367909339168, 67.52076272041568, 63.045365810394294, 63.73526757763278, 69.17404174804688, 65.81653210424608, 66.66707454189178, 66.15763710391137, 67.15573126269926, 61.816828481612674, 54.660236604752086, 49.67885002013176, 55.08642565819525, 50.363444820527114, 50.73785074295537, 49.91461192407916, 48.165893785415165, 45.94417702767157, 46.507131284283055, 45.73651890600882, 47.00053015062886, 47.76382730853173, 50.59919103499382, 51.28227572287283, 58.45067001158192, 57.7344609075977, 63.55521117487262, 55.17121553421021, 51.31660430662094, 54.92454944118377, 51.93478945762881, 47.93502307707264, 46.29897894397859, 50.53308733047978, 52.634912921536355, 54.94525171095326, 58.40076569587954, 56.728514163724846, 51.430741356265166, 49.68801659922446, 47.811774361518125, 47.33679494550152, 46.491155470571215, 45.96819370023666, 44.61718036282448, 45.10348758389873, 46.38867178270894, 42.97816699550998, 48.49292532090218, 42.450035541288315, 44.02545944336922, 49.32956295628702, 36.02826049250942, 39.49906387636739, 50.802001107123594, 42.082199588898696, 43.54759708527596, 43.68025948924404, 46.10792421525525, 44.91948919911539, 50.654190509550034, 51.346100530316754, 50.97577387286771, 54.293102756623306, 52.80292764786751, 57.24367041741648, 56.24346994584607, 58.39550971984864, 58.81586620884558, 61.06181144714356, 59.9230924729378, 59.4599429253609, 55.171211611840036, 54.35215796193769, 51.606667503233886, 48.80907227916103, 47.92181645670245, 56.25240902746878, 61.50656115624213, 57.91823571728122, 51.82309212223176, 56.28914594650269, 55.29244030675581, 46.00721343871086, 46.91128446209816, 45.6719135469006, 43.04628287592242, 44.58819012488089, 43.408419624451675, 46.992967820936634, 48.86212625811177, 46.978098115613385, 56.615797012083, 62.01082498796525, 62.11347341537476, 59.688915206540024, 58.07565219940678, 65.97378776919457, 62.91154238485522, 69.67193172823998, 63.39866153655514, 58.43234862050703, 63.69524371239447, 66.07495354067895, 66.90199313625213, 69.16652648679673, 70.88733303931453, 71.58551492998677, 70.57545754217333, 72.40400375858431, 68.16493357381513, 70.28895978004702, 67.30126688557287, 68.39358422064012, 67.8360899033085, 69.79598845205, 66.98414325714111, 72.42437654925932, 66.96894015035322, 86.02948619473366, 76.20354098658409, 103.15736278410881, 30.00767723206551, 0.37284598355331733, 0.19094012196986906, 6.608850042666159, 84.62775661099343, 63.62582560508483, 66.33095095234533, 24.19189072424366, 29.507496587691772, 49.387053135902654, 23.648648338933146, 0.2534925033368411, 0.023300426321164257, 0.04452444027147947, 0.08766921747836375, 0.011314996067554721, 0.07692659634255594, 0.05354535157581972, 0.16140404638023148, 0.17565633080178694, 0.21094779514016646, 0.25589313177812484, 0.18839407471879838, 0.24482982623721325, 0.3366810257636732, 0.38987182801769626, 5.186867790837442, 86.55442483963506, 51.97536245469124, 67.23116628585323, 67.7907943725586, 71.94554928810366, 95.09579381635113, 15.918631438286075, 0.9975448431026552, 1.047667401932901, 1.127093927033486, 21.00752038340415, 102.10118616780927, 80.07909374852335, 88.92246169428672, 66.97981296047088, 71.88457996614518, 75.16658398412889, 84.0139841264294, 82.46920570250481, 69.96920816359982, 69.70436188482469, 72.7843246152324, 75.04522585099744, 75.19662933964884, 75.22968707546111, 73.72910591863817, 72.73746013641357, 69.91045890315887, 68.79163419046711, 65.41809381977205, 64.1650220655626, 70.42845495285528, 67.47170955904069, 68.35056366459017, 66.48774377761349, 68.81674520431027, 65.41487747623076, 58.02427307251961, 52.54415712048931, 56.3300484226596, 54.60804946960942, 52.645926936980224, 52.08418861512215, 51.04609804768717, 48.89742366729244, 50.06605855880245, 47.689490549026004, 50.34899873118247, 52.3857129773786, 52.67364632698798, 53.956116245638945, 62.295032085910925, 60.77505088621571, 66.61522080821376, 56.937890283523075, 51.844943646461736, 56.645226555485884, 53.29882506401309, 48.710095190232806, 50.69111570235222, 52.56845228133663, 56.25901822120913, 56.02489979036393, 59.34309944029778, 58.47482788947321, 55.53010456023678, 52.45212654913626, 50.356690499090384, 51.21102194632254, 48.23313889964935, 49.07216133609895, 47.61654623093144, 46.96868834957, 48.80531464853595, 43.396656436304895, 52.18418552029518, 48.15287151644307, 47.16128064740089, 53.61600360562725, 46.25547985876761, 49.97613822260211, 52.888909924414854, 45.41637113017421, 45.86525109506423, 45.36032438278199, 48.83105324160669, 47.4133203875634, 52.778997267446215, 53.54827603986187, 54.18365686170517, 56.646403266537575, 53.01772056087371, 62.40711381358486, 59.47851927049699, 60.17825834212765, 62.70276638769335, 62.8437206822057, 60.81828717262515, 63.11815323368196, 57.055663370317035, 56.100487785954634, 53.95824609264251, 50.247860416289306, 47.80813440199822, 59.34983414988364, 64.15610259579074, 59.9715062879747, 53.164103415704545, 57.90260114977437, 56.80810689926148, 48.35623856513731, 50.941005983660304, 47.990340263612815, 45.47508508928361, 47.794857178964925, 46.50736662649339, 49.53809968886837, 51.52096763733895, 49.82970045458887, 58.58345400902533, 63.4455652390757, 66.32654220827165, 64.89593613532283, 60.89993915250225, 68.79736085091868, 66.49357241968956, 68.97422052198841, 63.8018576560482, 60.6500724054152, 66.00403708796348, 68.64780872098862, 70.09805017902006, 73.27883351233699, 71.92594528198242, 73.92080783843994, 72.02132163509246, 74.29870467032157, 72.44004249572754, 73.81678658147013, 68.31898858470302, 69.64840535194644, 72.15430567341467, 75.02742613515547, 71.19858880196848, 76.97691471345964, 69.2085821397843, 91.48850763997724, 80.80685815503521, 108.15562340521045, 31.94002897508683, 0.6015703586801406, 0.4913391010655511, 9.141671061515808, 94.59054546971475, 71.48425502161827, 74.5465043283278, 34.51735957976311, 37.326117869346376, 65.79436679040232, 39.43210901752595, 0.4823889877767333, 0.3125664471618591, 0.15819233000999497, 0.1930392641694315, 0.13074983482158956, 0.2621873714510472, 0.184325672866356], [0.03382080918057792, 0.036251452946735006, 0.0374529124688237, 0.0405118785678379, 0.10853841014566923, 0.03514539435385697, 0.07777519959716067, 0.28968956021051256, 3.366022412815402, 60.47189481796757, 50.173684473960634, 28.334703983799105, 38.15482054987262, 64.05245788635747, 80.07162555571526, 16.988071549323298, 0.6210324853177994, 0.7073853645593889, 0.526738767662356, 16.64073194226911, 91.91404557997181, 75.51490614491125, 78.12009734492149, 63.086711514380674, 67.18973821209323, 74.40121973714521, 76.92564933530747, 73.0704693640432, 69.68917446751749, 71.26547305814682, 71.65497226099815, 69.9344559638731, 67.98386912192068, 68.04952175386491, 68.54319910849294, 67.72823256831016, 64.32198355274816, 66.71139732483896, 62.714258932298236, 58.03639319635207, 64.4577681633734, 65.29584530861148, 64.65070170740928, 63.67216056393039, 59.519762992858894, 58.4447786115831, 48.7612585867605, 48.25223299764818, 49.56119460444297, 48.03156437412385, 51.195963967231016, 49.77829387111049, 45.1848610754936, 40.96477908472861, 44.589284466158965, 41.85308218002319, 43.48747891764487, 44.10162402737526, 46.247623351312455, 48.12014325972527, 54.336444947027395, 51.8937026300738, 59.19078203939623, 53.40043014095676, 52.1850327522524, 50.75176731232674, 50.275462135191894, 45.95955271874705, 46.22447352255545, 48.12688581405148, 50.386284782040505, 53.35738605068576, 53.64030661121492, 55.99700389369842, 58.31078652412661, 54.07022191632179, 55.323999697162265, 52.355632320527114, 47.9817698847863, 44.892522904180716, 44.33063945462627, 43.618297807631954, 41.95974711448916, 43.687876732118674, 42.259180853443766, 39.901216645394605, 46.330683462081424, 51.04246985527777, 32.08317195215533, 34.856903476099816, 58.61413871088336, 45.64896768139255, 40.77514033163748, 44.32370862653179, 42.625910697444795, 41.21898005085607, 45.10587630733367, 46.905977495255016, 48.378372500019694, 50.7534029406886, 52.542596017160726, 53.654411454354566, 56.13734237609371, 57.454960653858805, 61.527906694719874, 57.60019817659932, 59.8360433117036, 55.66187658617574, 51.76421342357513, 48.54230796137164, 44.813777400601296, 43.75727914994763, 47.793076422906694, 55.402764812592544, 53.89665311382663, 56.09163107410554, 59.04005712078464, 57.52884634079472, 55.01765081959387, 45.91601440983434, 43.1001958539409, 41.65171554011684, 41.387206585176536, 41.99074952833114, 44.10861369102232, 46.26167720363986, 46.51567420651836, 45.125609751670595, 52.47812401863837, 60.5283377247472, 61.4058425349574, 53.32600316693706, 57.37214373004053, 60.51585282048872, 62.93216228485108, 61.29310184909452, 50.18379634426486, 63.18658682607836, 60.454718758983, 64.0866413424092, 63.988990014599224, 66.0175221966159, 67.90907736747496, 68.76236546424128, 70.0422897646504, 71.76681472409156, 67.5950994799214, 70.72897126597744, 67.08537178654825, 68.35672963050105, 63.162193605976725, 64.37527679627942, 63.803595266034534, 67.90295847000615, 69.05040079547514, 84.11022340097736, 72.78296747515279, 98.96372933541575, 33.67346163718931, 0.21207938361312115, 0.04329041435172962, 5.037251922392077, 70.58959376427435, 53.098529231163766, 58.473270708514804, 31.293802799717074, 38.39938425248669, 30.839253048742975, 14.959709990409115, 0.2041144134296525, 0.05925284833797525, 0.044659677772752704, 0.08015785561574083, 0.048659350047068256, 0.04275069008731554, 0.0455631137705378, 0.04969540735586517, 0.01232115009183725, 0.03931475127296102, 0.04982960297756138, 0.08375063944127291, 0.030427842153116103, 0.043428723865579215, 0.36144353088832676, 5.68751911963186, 72.2773818046816, 54.001258803952126, 30.07340438904301, 43.858244880553215, 69.5085963895244, 84.61282022537725, 19.652700385739728, 0.7552690467526837, 0.8018373253364718, 0.801305721604055, 17.30052363487982, 93.3662639125701, 78.99474666964623, 80.80685815503521, 66.6636856140629, 71.06751103555003, 77.40322928274833, 79.19212818145752, 74.12236275211458, 69.93072186746906, 71.56828788018996, 73.54833956687682, 73.28346190914031, 72.12871613041048, 69.90948615535613, 69.13888946656259, 70.8066341953893, 68.20387486488589, 69.46737227901336, 64.37309595846361, 63.28137874603272, 66.84666418260144, 66.14961193453881, 68.16261937541347, 65.02147551505797, 63.60617845289169, 60.83465130098405, 52.66205572312879, 50.1773440453314, 52.1996122021829, 51.292379748436716, 53.16591162835398, 50.877875435736875, 48.58061775084465, 44.06204338996641, 46.52075367589151, 45.03444602412563, 46.749094455472886, 44.60395020823325, 48.07860143723027, 49.88326826403218, 56.51398797189036, 55.8977287046371, 60.37275298949211, 54.0719909052695, 53.164797675225046, 52.1508728304217, 51.97768449783326, 49.10926695792906, 49.14610978095762, 50.74641327704153, 53.89954390064363, 56.062389804470925, 54.206390919223914, 56.75533925333331, 59.92440646694553, 57.56711690656601, 57.43594892563359, 53.326446394766535, 52.82148438115274, 48.32220415915213, 45.28086893020138, 45.48189824627292, 45.678746315740774, 45.55975337182322, 44.45169164288429, 41.22804072595412, 49.706102648089015, 53.24907372074743, 39.2814782357985, 38.54560629014046, 56.72771400020969, 48.52547707096223, 42.600893820485766, 43.925117369621034, 42.90251624199652, 41.60844787474602, 46.46442059547671, 48.54928193553802, 50.1924765494562, 53.45972461085166, 54.037073965995546, 57.39607018809165, 57.06312764075495, 60.46126127243043, 61.18437767028809, 59.78688816870413, 59.36110704175888, 55.13847158801172, 52.500450149659194, 50.2134180838062, 46.17252172962312, 45.56255786649643, 49.90061690730434, 55.67090980468258, 57.069619163390136, 56.64786631061185, 60.549785244849424, 57.75498667070943, 55.26713317440402, 46.07211689795218, 43.739487278846006, 43.723786031046224, 42.9189548953887, 43.79704413875457, 46.19013317169682, 46.56825357867826, 48.841012139474195, 47.000577219070934, 55.83915595085391, 61.50058738646969, 62.0909119421436, 56.983927142235544, 60.7821778328188, 62.1740230437248, 65.2883888829139, 64.40247843342443, 53.135434812115086, 64.15338439326133, 59.97445591034428, 66.33000173876363, 65.97548223310902, 68.34447614608273, 67.66498827165174, 70.20917877074211, 71.30632846586167, 73.00064333023565, 71.42997726317375, 72.47235498120709, 72.4369595127721, 71.47575132308468, 64.96926484569427, 66.42762168761223, 66.53697736801641, 71.02732243076449, 73.29614685427758, 86.25398697391634, 75.71142473528462, 102.18483463410409, 36.53686246564312, 0.18332916101621044, 0.08999924325654585, 6.741849280172779, 81.05020984526604, 61.02470190294328, 70.67990241512176, 36.457410935432684, 48.247443783667784, 46.18894469353461, 30.199763544144172, 0.2932799385199624, 0.0647130634094919, 0.06910114609185727, 0.06023291994126574, 0.040468621413193406, 0.03152029310923911, 0.047644034568821235, 0.2013636521634556, 0.1501016907634274, 0.12452568453285964, 0.2106140412750744, 0.38746107189405354, 0.1274408023023317, 0.2797540433464512, 0.5043475804550033, 7.511543333530427, 84.52356276973602, 61.745104020641705, 41.4162282020815, 53.112583083491174, 78.38197831184634, 92.89348494622016, 22.968026899522354, 0.8258501981054583, 1.0928544546327283, 0.7465162777131604, 20.471304924257343, 98.36516780237999, 82.35278975579047, 84.2656590861659, 70.44573691583449, 74.60952897225657, 80.90981252731817, 81.44196833333662, 77.98106501179358, 72.7755698850078, 74.79148772455032, 77.48507345876386, 75.38204762243456, 73.98613883603004, 73.23932739996141, 73.03960031078708, 73.33681398822416, 70.97788487711261, 72.37492330612676, 67.36774321525328, 63.867937826341205, 70.74333498554846, 70.71767483988117, 70.30637510361211, 68.60637280248827, 65.4934190165612, 64.99020245767409, 54.84898105744393, 52.619949079328975, 54.552932323948035, 55.185347833941066, 56.23296191615444, 55.263861917680316, 50.18561632402482, 47.42566016412551, 50.41349426392586, 47.874034143263295, 48.76338451139389, 50.47703273834721, 50.025513018331225, 53.87174606323243, 59.00803096832768, 58.78329484693466, 64.47055116776498, 56.154989119498964, 55.66739536100819, 54.41971294341549, 55.57887531095936, 51.460837702597345, 51.54393311469786, 54.59690993832004, 56.5856182959772, 58.691593754676084, 57.23746522780388, 59.89452192860266, 63.741590438350556, 60.17944289791969, 59.663635530779445, 55.17562427828389, 52.6123083022333, 50.466599233688854, 46.977705878596154, 47.20607019239857, 45.964318398506414, 46.9893749298588, 46.63186265576271, 43.8781822881391, 52.04812242138771, 57.05120363543111, 45.65338819257675, 47.85414380411948, 62.39965346551711, 50.06916115360875, 43.71389381347164, 45.276507254569765, 45.37080887825259, 42.519277141940215, 47.959392762953236, 51.40481448942616, 52.8269874665045, 55.3254823530874, 59.92322583352367, 60.559320526738325, 58.86230314931562, 62.87477016448975, 64.58846938225531, 62.231721108959576, 63.41138570539413, 58.468152015439934, 55.13041896204795, 52.34594014383132, 48.20467818167902, 48.723701892360566, 53.01965036699849, 59.38155435746717, 57.27164083911527, 57.98838338544292, 62.52158426469373, 61.63893330481745, 59.17829321276758, 50.78839440499583, 47.684783704819225, 47.01977329869425, 46.601546656700876, 46.53487420851185, 50.604392097842315, 49.81482290452527, 50.22236501016925, 49.608604292715754, 57.7270790069334, 65.67843329521918, 66.30801293157762, 63.42618873042446, 66.52164090064265, 65.44682125891408, 66.71657485346641, 64.97070435554751, 59.31756088810583, 66.29719503464239, 62.82023745198404, 71.49499447115006, 67.76480474779683, 69.0076155816355, 71.55984693957915, 70.91731563691171, 75.55523595502301, 76.9004677188012, 73.81357808266917, 74.65000783243488, 76.03425933468726, 75.20220695003387, 69.2574627168717, 70.37527545805901, 70.11657161097374, 74.15421239791378, 77.07537404952511, 91.24032358969413, 80.52287070981919, 105.73261061022359, 40.60117144738474, 0.31240789760505, 0.2424123438615953, 9.274961044711452, 89.19726294855919, 69.75139894793111, 82.09323867674797, 51.420955042685236, 64.95683093224802, 61.746104225035644, 45.66604568112282, 0.7008428511119659, 0.12749229873260184, 0.2448699232791701, 0.19158958066855708, 0.21865991034334709, 0.15157455608489054, 0.19610029104496204], [0.057354501613806334, 0.03507908944401049, 0.04893756253764995, 0.07017233619286169, 0.024698354837094105, 0.07469912675479728, 0.1035993340455236, 0.20255943880446498, 4.444188081449078, 62.08136097077401, 55.54327587927542, 35.72413559882872, 38.7404029600082, 61.93825329503706, 77.59774746433382, 22.39358598186124, 0.9062752115630335, 0.9476528460941008, 1.1777925226957568, 12.291937374299573, 90.42169355577039, 73.00495793742519, 75.63911976352816, 62.10554630525651, 69.10922065857919, 71.0686485229, 71.17034773672782, 74.43202603247859, 71.04481620173301, 72.06158868728146, 72.01597936691778, 72.9454634266515, 67.49495352468183, 70.19990628765476, 68.10686680578416, 65.91110829384097, 65.96636664482855, 66.81927819405833, 64.72815282883184, 56.32564360095609, 62.69820859355312, 61.411953587685865, 58.815238629618, 59.26859009650446, 56.21925323240219, 54.64844988238428, 47.96672759517547, 49.38957914229363, 46.32767892652943, 48.37901184635778, 49.14007325326243, 48.64294421288275, 44.4261020998801, 41.74757826712824, 41.55460942176081, 41.09944189748457, 43.033958788841005, 42.48624686271914, 44.64104798532302, 43.752988076979115, 44.37040052106304, 45.31445618598692, 52.93455846848027, 51.19612086203791, 49.36516631034113, 49.94607717760148, 49.3389727223304, 50.56432900890228, 53.36008856373449, 52.58683643033428, 55.31153048238447, 55.17500846616684, 55.298276793572214, 54.40783600653372, 55.48552682322841, 57.43519975293068, 56.52174249772103, 59.88157810703401, 57.66348954169982, 53.29875053897981, 55.33340946320565, 46.0047423455023, 43.32892102579917, 42.95732352041429, 41.203188588542325, 46.02180857812205, 46.927978069551536, 46.72985915214785, 35.54917827729256, 33.70805301973897, 54.66282144669564, 50.30689208738266, 45.7304431546119, 43.173728527561316, 41.29976518692509, 39.209275245666504, 39.96390396548856, 42.339605131456935, 46.955720993780325, 51.986576511013894, 50.92831711615286, 52.92754919298234, 54.502196465769124, 55.04635472451487, 54.59444668985183, 54.18393927235758, 50.716391455742624, 45.71845246899513, 43.370964911676225, 44.94944434012137, 43.606365957567775, 46.81255448249079, 46.87436319166615, 47.473932773836204, 48.959357892313314, 53.71229387098744, 55.80028526244625, 55.034752353545166, 47.1308312877532, 42.23218317954771, 41.82575502703267, 41.17140954540622, 40.709864247229795, 41.10861239894744, 42.50003399387483, 46.585288432336625, 47.09468664661531, 44.78105306625367, 52.131986618042, 62.65452515694403, 60.2097902759429, 55.91017438519386, 55.245571905566806, 62.19791027807421, 64.62677917172833, 47.611815852503625, 57.4285081894167, 61.629507849293375, 59.88757148865731, 64.21949986488589, 60.00422669995216, 64.33375850800546, 64.73944141018775, 67.16009293833088, 66.63453455894225, 71.15819623393398, 66.58720724044308, 71.98463962924096, 65.68399521612352, 71.03444545499741, 64.93438713012203, 70.53416282899919, 63.879971658029866, 75.23097361287763, 68.13326435704386, 83.48370321335332, 72.25030960575228, 99.23936213216474, 32.87316083908081, 0.3320195033184944, 0.2685626019393244, 4.41856715948351, 65.873641813955, 59.73607778549195, 56.09734596744661, 30.72680457945793, 37.55204639127178, 35.60002003946612, 16.002530936271913, 0.4245009633802599, 0.06943626359345452, 0.016614386301127174, 0.057138763593449715, 0.09428121510051912, 0.008653639177341134, 0.03988032334394032, 0.07282500756123374, 0.03330520519445981, 0.0545080597963064, 0.1466646526129015, 0.15753278959422343, 0.07772352696666796, 0.1739513408392668, 0.22101431303927976, 5.910054301061939, 72.29646805794009, 58.71126444109025, 39.31404959770941, 46.401121385635875, 69.78772009572675, 81.88068543711017, 25.257443766440115, 1.0295350200706914, 0.9819740141111036, 1.0767013988187237, 14.263656966147886, 94.21161313210764, 76.99999393955355, 77.27745456080284, 64.11647488993984, 70.4400416343443, 73.42411025877922, 72.61632165601178, 75.12817613540157, 74.83524568619268, 72.53322232154109, 74.08778313667544, 72.90801263624623, 69.31319175227996, 71.06078024833434, 71.21569033591979, 68.13178170111873, 67.23966213964647, 68.14390966969152, 69.33117189714986, 61.55046816795104, 62.05143328635924, 63.64934413663803, 62.2467633985704, 63.41047571551416, 58.8781887485135, 58.23728130709741, 51.603215817482244, 51.51849262176022, 48.62425804138184, 49.288931123672, 51.11104465300038, 49.95058398092947, 45.94624411675238, 44.91639444904943, 45.59270128127068, 44.36757641453897, 46.16544969620244, 47.68465426660354, 45.15725543422084, 46.49804707496397, 46.87860327382242, 47.051760227449485, 52.99030319336922, 54.386223746884255, 50.95666800775836, 50.73317135533979, 52.2703403811301, 53.918230072144546, 53.569958902174434, 53.98945246973346, 57.89841205843034, 58.1917308222863, 57.770483955260254, 56.95113220522481, 57.684231035171024, 61.377723063192065, 58.28306713411885, 62.03038192564442, 59.20399258213659, 57.50994051656416, 57.588066285656346, 48.75555938290012, 44.913813529476045, 42.787967343484205, 44.451970131166526, 46.31923014117826, 51.823162724894864, 49.51513421150946, 42.453043999210486, 40.13571946851669, 54.24208841016216, 52.294478647170536, 46.44550300413563, 42.687735096100845, 42.95891600270426, 41.425896844556256, 40.70552610581921, 44.057077669328265, 48.29826201162031, 53.47138581737396, 53.39535851632395, 55.063526861129276, 56.64348894549955, 56.60168040183283, 56.40009410919682, 54.859857789931766, 51.87265911409932, 48.57429489012688, 46.49382660465856, 47.26944784964285, 46.53816115471625, 48.430947949809415, 49.38429963204169, 48.35290455049085, 49.90431178000666, 54.76419902616932, 58.86198151496149, 56.701045805408114, 50.01956278277982, 43.25176015976937, 43.11895655047509, 42.42333596752536, 42.961202744514715, 43.4142247323067, 45.27171804058937, 49.42741040260562, 48.03758128996819, 47.436634955867646, 54.70330815161429, 64.90260024224558, 63.37990476239113, 59.317890367200306, 60.01420128730036, 64.6094972087491, 67.05207870852563, 53.310223471733835, 59.902158783328154, 63.743586924768266, 63.21119577653947, 66.98495911013696, 63.13907515618109, 67.38363665919151, 66.49882839572045, 68.93029782079881, 70.3103994554089, 71.85275385456701, 69.84916010210591, 73.01525023675734, 69.22336163059359, 75.17946504777478, 68.48090402541622, 71.75865619413315, 67.2420940091533, 77.97070210979831, 71.08764063927435, 85.66461163182413, 74.26728648524131, 100.76157123811784, 34.57419080118979, 0.41729066641099993, 0.3431852961019162, 6.4976738922057615, 74.2754214809787, 68.97373414808705, 67.10616034846153, 39.566689460508286, 49.97432216521233, 54.58376215350244, 24.374728087456, 0.6365605359596591, 0.0781216245565203, 0.057532391060263886, 0.1214647955531555, 0.056392881238172134, 0.06679997118490358, 0.04881380103348244, 0.20582096621153817, 0.1885359695241336, 0.1954303931204542, 0.19736775287216712, 0.4403200048592783, 0.32661135158231186, 0.38039691385722935, 0.7034785000066603, 8.478205088646181, 84.85418719630088, 66.15232621469806, 47.553945202981275, 53.89979100996449, 77.23687371900006, 92.17762885555145, 28.5463236993359, 0.979549315187239, 1.692273148125218, 1.556403103374666, 15.989441006414353, 96.76269915796097, 78.5753825403029, 83.89876058024745, 67.85695691262522, 72.77168673853721, 76.94538670201456, 76.46724977800923, 79.30133481179514, 76.44646121609595, 76.62086548343783, 78.88685795568651, 77.67490833036362, 71.54043905196652, 75.23793974230367, 73.21568335256269, 72.52506379158267, 71.08964889280259, 72.70858364720499, 70.61879973257743, 62.763002226429606, 66.94873209922545, 67.20223488346224, 65.36736188396331, 65.32992286066856, 62.14917482868318, 60.007454810603974, 54.615600032191125, 53.99081745455342, 53.51010745571506, 53.8104433398093, 54.36698844355922, 53.345791524456395, 49.77095119414791, 46.310094941046934, 48.007277058016875, 46.95453643798829, 49.3104531688075, 49.038260290699625, 49.39876141086702, 49.625643068744296, 50.73374402138495, 52.354792933310236, 57.17855907255604, 55.78511745698991, 55.251902611024924, 55.37935218503399, 56.00236577372397, 56.39016266792052, 57.05515738456481, 57.55221974465155, 61.882026118616906, 61.28211529024186, 61.19902380051152, 59.228075934994614, 61.195607416091434, 63.76468927629533, 60.85882486835603, 67.57163586155062, 62.12435014786259, 57.42463681005663, 58.50556750451365, 49.532369106046616, 44.868121839338734, 44.04081160022367, 44.983859216013265, 46.73184779382522, 53.08746814727784, 54.42802444581063, 44.686021881718794, 44.08513046080067, 60.73902391618299, 54.39038930400726, 46.94113369910948, 44.69342339423395, 42.64256508119645, 41.5820267892653, 41.951184580402995, 44.99543413039177, 50.54698036563013, 57.95208577186831, 52.969934325064386, 58.35301476140177, 59.33680011380104, 61.48134423840431, 58.19958340737128, 59.397690988356075, 54.85091086356871, 50.30153412972727, 46.94449909271733, 49.092816537426366, 48.95599249870547, 49.65990497219948, 50.76992004148422, 50.29880416008734, 52.51682212275844, 57.62732921108123, 60.64875056666713, 60.33694174981887, 51.6383602542262, 46.61251752607284, 45.249356608236994, 45.773267592153246, 45.87910490651285, 45.868577264970355, 47.3285226668081, 52.10873873003068, 50.72123166053526, 48.57494992594565, 56.24650978272962, 68.79744714306247, 67.07991184726839, 64.6616098188585, 61.34974087438276, 69.44648958021595, 62.63869839329874, 55.24668978106592, 61.386724902737534, 65.02275028536397, 65.92363634417134, 69.75506244167205, 66.32874658030849, 71.67990284581339, 70.01097356119465, 71.84438351661929, 71.94418430328369, 73.31515466013263, 69.77822795990976, 77.34453493548979, 72.1527837937878, 78.47424030303955, 72.8949668330531, 77.00485767856722, 71.80697194991573, 81.74430462621874, 75.45780427994268, 90.39630797601517, 79.27261521739345, 105.06558802820022, 38.838944665847286, 0.6480527741293753, 0.6701027457752536, 10.28363089407644, 85.77228853779455, 76.32521290932932, 75.81864664631506, 48.8633265033845, 58.1051484231026, 66.55985263086134, 41.092848393224905, 0.5925251892016781, 0.20715026665599118, 0.1309744364792301, 0.2521754143339011, 0.18363400272304015, 0.117658709866866, 0.2182393280729171], [0.048333567326828364, 0.05527596717940704, 0.024688690637929306, 0.011261446521647516, 0.08718310404689082, 0.04600508904625331, 0.11195985074605673, 0.338774498912596, 4.519425024909358, 58.86334649978146, 50.6360887712048, 30.023417703567016, 36.959521385931204, 61.04088952464443, 77.27298305880639, 27.682788410494407, 0.574967128134543, 0.541134785500265, 0.552710374036143, 9.16589463910749, 87.39105070790937, 71.4291927891393, 71.82122584312194, 66.28665954835954, 65.03635306512156, 68.94965079522902, 70.69137142550561, 71.8168955464517, 68.61941076094105, 72.10032601510325, 69.0491299475393, 70.67346972803917, 67.79319486310406, 65.67385196685791, 66.66647049688524, 69.5373159839261, 62.344116626247285, 66.42469559946369, 68.00505776559153, 54.798496230956054, 64.61774595322149, 58.77572859487226, 55.72439524435229, 52.094500526305175, 51.300526511284616, 50.96013930536086, 49.658504686047955, 48.45936944407802, 46.07716106599378, 46.64974081900812, 46.28046535676526, 48.60201428013463, 45.72423012025895, 42.44577584728118, 42.3378675214706, 40.571749748722205, 43.529154100725734, 42.74539786000406, 43.25970295936831, 42.518284782286614, 44.1971258963308, 43.32444952380273, 46.46371064647552, 49.50095484333654, 47.44984942097818, 52.25774957287697, 48.43512135167276, 52.20408370417934, 53.40384260300667, 54.434853292280636, 51.21171228347286, 54.0530772362986, 52.2792088600897, 54.898602962493904, 54.46436912782731, 56.760999233491965, 55.87122524938276, 57.40729601152482, 54.49605403407928, 57.355406976515255, 58.13708828341577, 57.97162702006679, 45.64755955050069, 43.22902217988045, 47.17521290625296, 47.51327022429436, 40.417184829711914, 41.14584353662307, 40.23992115451444, 38.18234382137176, 40.074130412070986, 46.85424927742251, 50.085431145083525, 42.05124424349877, 42.92689769498764, 42.72269125907652, 43.87396181783369, 50.03560919915476, 54.46858567576255, 53.88049687108686, 55.3583949612033, 52.33274529057165, 53.33590715162216, 52.18882176183885, 53.571759270083525, 52.404069669785045, 52.266990677002944, 49.35956516573506, 50.14747127409905, 48.531031147126235, 48.97671045795564, 48.67835144842825, 45.97129237267279, 46.17320422203311, 49.09040035740022, 51.12596142676569, 52.78210770699286, 47.835877326227006, 42.31883225902435, 38.266894432806204, 40.34888459790138, 41.23259459772418, 41.138795037423414, 42.13676368036578, 41.55424464133478, 46.24460704864995, 46.243720592991004, 45.578674885534475, 55.09873013342581, 63.87029909318494, 58.61841801674136, 57.575977540785274, 52.95618641761042, 66.9124109514298, 55.358885257474846, 50.23925081376107, 63.21559667587281, 59.065179901738325, 58.768362383688654, 55.80229351597448, 58.99653450135262, 61.46080278581189, 61.29527091979981, 65.17659348826255, 66.74519246624362, 68.51479330370503, 68.59104417985486, 71.25452964536606, 71.05202551810973, 72.9736574234501, 69.7008474411503, 72.07926288727792, 67.58639181813886, 71.97965037438178, 69.04942804767241, 81.55675257405927, 74.70435619354248, 97.5106716156006, 30.488887333100845, 0.3944860675161885, 0.3739812339265501, 4.096582488667581, 63.85713954125682, 56.46040839533652, 60.17691296915854, 25.96072081596621, 18.938126910117365, 33.47186749981296, 16.681857993525846, 0.2832509895726558, 0.11949476981235128, 0.03511500364590076, 0.03366905865409682, 0.057977664344493425, 0.026661935863235307, 0.04327212783297704, 0.07804337633593429, 0.0487262218619787, 0.03964441422853739, 0.05604678952705957, 0.02665708078101518, 0.038309364294212674, 0.15943130868817532, 0.4102011048986066, 5.938076203869236, 67.30948817345404, 56.47832185991349, 36.4015289275877, 44.66596680302774, 68.35413302144697, 84.47760043605682, 31.12846116865835, 0.6932818084474534, 0.7258060406292639, 0.6876969049053808, 9.727795739327709, 92.0040325964651, 74.3159709438201, 75.71146395898636, 67.41780834813272, 68.54848646348523, 70.20120851455196, 73.56624126434326, 74.6018881951609, 71.87132235496276, 75.41498768714168, 73.34348201751709, 72.94208234356296, 69.09056586603965, 69.23976498265421, 70.14609921363093, 71.35594644854146, 65.82101929572322, 65.97049297824984, 71.16209506988525, 60.00085738397414, 65.18611308067076, 60.74319731804633, 57.73398237843668, 56.070838589822095, 55.30701975668631, 53.237161482534106, 51.770799083094445, 51.62267469590711, 51.25022603619484, 50.334383979920425, 48.328346590841974, 50.27853727340699, 48.44434284394788, 43.99701049250942, 45.37972050328409, 45.1719682447372, 45.153297762716974, 45.30659183379143, 45.02014506247736, 46.280069197377856, 45.62377822014594, 46.971994907625266, 49.12225784793977, 51.245279927407545, 51.28090289331252, 54.60419377973003, 54.1545646421371, 53.941089645508804, 54.68839530021914, 57.211663876810384, 55.807463199861594, 57.604826573402654, 56.44436590133175, 58.36387972677908, 58.88028721655569, 59.96943919889389, 60.631221494367054, 58.7517511460089, 57.108454550466234, 62.23303902533747, 61.605153852893466, 59.90561046907979, 45.81528794380927, 44.8365742160428, 46.401125308006044, 47.80517693488829, 45.32129679956744, 45.28313213779081, 41.77403857631069, 42.68819009104083, 45.6519212261323, 49.30878223911409, 49.14916530732186, 43.205589940471036, 42.99963020509289, 41.61208783426593, 43.253976298916726, 52.814530018837225, 56.48470747855402, 57.45318774254092, 56.644171437909534, 56.11827181231592, 56.73939874095302, 54.573309036993216, 56.953705280057854, 54.46044675765499, 54.22902299511818, 50.970082513747684, 52.189221843596435, 50.96800757992653, 52.883881445853945, 51.06443512824274, 49.59031820297242, 48.063457165994954, 51.012906951289025, 53.071037338626006, 55.51165373094621, 49.84700987415929, 43.194034637943396, 39.74705965288224, 43.306567438187145, 43.87597007136191, 43.39911968477311, 44.92216425557291, 43.77716948909145, 48.89937308526809, 48.22851834758636, 47.62155902001166, 57.89983587880289, 63.64689265528033, 60.503752308507124, 61.9323815068891, 57.12516776977047, 67.87152459544521, 56.79966203628048, 53.92756923552483, 65.06060507989699, 61.36296318423364, 62.24965026301723, 58.9561144767269, 61.87859796708631, 62.30657562132805, 64.93537164503529, 67.6301811587426, 68.45675006989511, 70.25629428125197, 69.51742172241211, 71.47248791110131, 74.2361899345152, 76.00205667557256, 72.25398094423356, 74.89444994157361, 70.13961161336591, 74.37740310545891, 70.83055280870008, 85.29046458582725, 76.42998726137223, 99.26234722137453, 32.98936497780585, 0.5394818129078035, 0.3322992786284416, 4.786282498990336, 73.57217188804381, 64.67633047411519, 71.12473057162377, 34.82125697597381, 29.56051330412588, 47.63496175889046, 32.203757378362845, 0.3799279454735018, 0.0833095949623854, 0.023615602554092487, 0.0758902479203478, 0.1237248468603338, 0.084211832032569, 0.014406714340551727, 0.0992026711784063, 0.17205666750669482, 0.14059066321820984, 0.12729113936544428, 0.17764835858777647, 0.22168664712338682, 0.45257097650920197, 0.651590200441499, 8.35086141863177, 79.74894000637917, 62.67047351406467, 44.2886269477106, 53.873197340196185, 75.60127673610565, 89.90528214362361, 34.73589443391369, 1.0431814361964504, 1.0730870572790023, 0.8641678936058476, 12.581744636258772, 93.74041095856698, 77.21094685216104, 78.53864562126898, 70.68768439754363, 71.47744578699913, 74.3120328841671, 76.55226322912401, 76.27244918577134, 73.39140553628245, 78.65112350833031, 74.75576277702086, 75.93099117279053, 72.24637154609927, 71.44863990045363, 74.29612375074818, 72.9884212247787, 69.74188327789307, 69.92071982352965, 70.6342617157967, 63.407777124835604, 69.11537877974972, 65.52696704864502, 60.20579730310748, 57.43862005972094, 58.992725879915305, 56.928766850502264, 55.09165417763495, 55.12959526431177, 53.674274336907175, 53.44842426238522, 50.930341059161776, 53.788250569374334, 51.24247543273434, 48.296591081926906, 48.75874042510987, 49.05432239655526, 48.968838261019805, 48.89361112348495, 47.923663893053615, 48.909402585798695, 49.79707417949554, 49.04510090428014, 52.17556022828626, 54.21538491402903, 52.82010762922226, 57.183654231409875, 56.27497050069994, 57.43252861884333, 59.90193128585816, 61.55604577833607, 57.89029275217364, 59.76320097523352, 57.882640207967455, 63.125715563374186, 62.85140460537326, 62.78192766251103, 61.930639974532596, 61.76872453381939, 58.55521294378466, 63.88100324138519, 63.90658101727886, 61.654108955014145, 47.35611654097035, 45.24955664911578, 48.52551629466396, 51.624679027065156, 48.12119837730162, 47.77033844301778, 44.91717107834355, 45.059255015465524, 46.664108460949315, 53.28915642153833, 50.25229661695419, 44.16689226704259, 42.59837565883514, 42.66148267253753, 43.694383944234545, 54.9681269737982, 57.0532315008102, 58.79665443974157, 60.91170234064902, 58.373109063794544, 60.112064423099646, 56.94118899683799, 59.413309866382235, 58.63777491354174, 57.554510408832186, 55.00541694702641, 55.54296993440198, 52.60599720862604, 54.32639583464592, 53.25550248545986, 51.21461091503021, 49.01939369017079, 54.08593885360226, 56.22894148672781, 56.82007797302739, 52.93685697740125, 45.79984165007069, 42.92356368034117, 46.57000295577511, 45.55689788633778, 46.385988881511075, 47.91418352434712, 45.99322626667638, 51.27982031914496, 51.26489962300947, 50.244710753040934, 61.480355801120886, 67.21807341421804, 64.7294472109887, 66.43212456857005, 59.89219988546064, 69.64689916180026, 59.44011534413984, 57.495890586606926, 66.77497110059186, 64.01222613550001, 62.60359318025651, 62.522380505838704, 65.16577951369747, 65.50161677022135, 66.39789012170607, 70.8798413122854, 73.3046740870322, 74.46799416695872, 73.00465199255174, 75.16919628266366, 77.43371394372757, 77.84229155509703, 75.72483924127395, 76.99777387803601, 73.26913741327101, 81.67902854181106, 75.74863233873921, 89.29394152856644, 81.02881723834624, 99.21581222165017, 36.90971905185331, 0.6866109599509548, 0.8018589596594534, 7.971145097286471, 80.42763556203535, 72.45920719638949, 82.56217372032904, 43.807540401335686, 34.55281388375067, 60.35447082211895, 45.660989745970696, 0.777888558804989, 0.2674201196960865, 0.16642607448081817, 0.10006860334185824, 0.24434674651392047, 0.13138899729857523, 0.17505387925813276], [0.03239150361848935, 0.0026690362034470687, 0.017129634056360494, 0.05960049137713448, 0.09309449127965397, 0.0655896365342121, 0.10686842274040946, 0.37870762869715696, 4.576499433286728, 58.0166244506836, 51.99832793205015, 42.14444760353335, 42.264856523083104, 54.8683967897969, 77.52521499510735, 37.13297643969136, 0.2517370741453863, 0.4489276768459428, 0.8257816792015107, 4.380124009424641, 79.8345261235391, 75.62543069162678, 75.11837805471113, 67.10734490425357, 65.11971127602362, 64.97141038217853, 65.1666973483178, 68.86823807993244, 69.91813105921592, 69.72096920013428, 69.3301756151261, 70.87448335463002, 64.78765910671603, 66.3364658048076, 65.07088168974846, 66.07382389806932, 63.9998745918274, 70.06754198381978, 57.8787805957179, 54.27343599257931, 59.57893586927845, 53.157933527423495, 52.45777083981422, 49.829955408650065, 48.224070379810954, 46.930617824677505, 47.356053783047585, 45.66912081933791, 45.64260167460288, 45.31573880103327, 45.469032872107725, 47.96195407067576, 45.813491498270345, 41.9343654571041, 41.04930223957185, 42.80138184947353, 41.31885144018358, 42.540650137009166, 43.35673063032089, 42.075339363467315, 42.6457029773343, 44.24258616662795, 48.48510019240841, 46.89190010870657, 47.73951253583355, 52.99608868937339, 51.45979435213151, 52.59847802500571, 49.88362127734769, 51.91892739265196, 53.803547813046364, 54.737350402339814, 53.800586423566266, 53.49592808754214, 55.580228528668805, 55.1602368200979, 59.106047076563684, 55.924361598107126, 58.35495633463706, 57.39754107690627, 58.66126991087391, 59.92610877560031, 50.018472363871915, 40.40510785195136, 44.556211040865996, 41.69519893584713, 35.84229307789957, 39.204544867238695, 43.084678957539225, 38.806585111925685, 35.619110215094786, 38.59419268946494, 46.74368158463509, 41.42692058317123, 42.73477608157743, 43.632132007229714, 53.38826687105241, 56.739037882897165, 59.55282072867117, 58.16847116716447, 56.67411481180499, 55.32534507013137, 53.817680112777225, 52.668515866802586, 52.442367692147535, 52.771191750803304, 50.902868778474875, 49.305648265346406, 50.54061435884046, 49.80976304700298, 47.869413591200306, 48.811472769706484, 47.75559033116987, 43.57845829379174, 45.95342205416772, 46.60043662594211, 43.06229791333599, 40.690589720203036, 40.243263013901256, 41.09280132478283, 39.66157943971696, 41.14297236165693, 41.118928232500636, 41.21098233807472, 44.27163524012412, 46.20213954679428, 45.3295337769293, 46.16983098368491, 52.00194435734903, 60.90653657913209, 57.232785840188306, 56.68075146213655, 55.58877537327429, 61.8769544939841, 49.780306047008885, 55.91089217893539, 61.58897799830283, 59.46562251737041, 57.69320934049545, 57.008363508409076, 53.06885257844002, 56.829962345861624, 57.02265662531699, 61.14037259932488, 62.59927857306696, 69.30936351899179, 68.38535508801861, 67.76319657602619, 69.97288734682145, 75.72757705565422, 73.3038817682574, 74.47488969372165, 72.58436218384774, 75.08602634552987, 69.92188084510066, 79.38810548474713, 72.46262750317975, 117.63570970104588, 27.12550590115209, 0.24939261527071077, 0.49987889766212434, 3.9121725001642784, 70.51698284764444, 56.89107679551648, 62.496418337668146, 25.35730927221237, 35.94161925777313, 28.396351875797397, 33.07704171826763, 2.5908811678809505, 0.11427472330509655, 0.06489010632879312, 0.07579899152680751, 0.06285605478971716, 0.04296712524768326, 0.029122788391466585, 0.0407791015271458, 0.06219050824461926, 0.05754114744523841, 0.057586434732882254, 0.09210688137118855, 0.08000374936889257, 0.05141596039456706, 0.38358567823325435, 6.62998769552477, 70.78320980072021, 54.41277427058066, 52.22501347141882, 51.79631410106536, 62.0218978389617, 84.61610717158165, 40.75778384362498, 0.26977770931778416, 0.42691947231369637, 0.8053710744265588, 4.626280684624949, 83.07186219000047, 79.02081474181145, 78.50357963192847, 69.78961067814981, 68.0383429988738, 65.10511221424227, 68.10331313840805, 70.84576376022832, 73.73918640998103, 71.76554387615573, 71.72220168575164, 73.94167484775667, 66.2949671283845, 70.2518149345152, 68.45528310345065, 67.29834079742432, 63.888353763088105, 71.09456754499867, 63.48144315904187, 58.19558651216569, 63.32311668703633, 57.58259850163614, 55.921651240318056, 52.46320332250288, 53.01150752652077, 50.54918081529679, 49.7299781153279, 48.12846260686075, 49.93476113965435, 48.15585251777403, 47.05973832837997, 50.727299567191835, 48.909096640925256, 46.5642096150306, 45.971268838451756, 45.0417887010882, 43.986035700767275, 44.92410190643803, 45.00811515315887, 45.437959855602635, 44.32197493891562, 46.252028173015965, 51.45857841737809, 50.19908182082638, 48.896776476214015, 54.59145392141035, 53.22549635364164, 55.59791841814595, 54.864925492194395, 56.67807248330886, 55.75388754567793, 58.02672063150714, 55.341097308743386, 58.48541828893847, 58.05738179914413, 60.033071810199374, 59.02987464781731, 59.01114925261467, 60.94623881001627, 60.96141053784279, 62.85272252175116, 61.18377362528155, 52.909929906168294, 41.39122701460316, 46.801097239217455, 44.13341875999205, 40.7948463193832, 42.81412563016338, 42.83476906438028, 41.20324350172474, 38.76810273816509, 42.63515572394095, 46.365663159278135, 42.66194158984769, 42.652276869743105, 43.640957340117424, 56.5731922272713, 58.71679106066304, 61.293144995166415, 59.82318970464892, 56.609568288249356, 57.556138192453695, 56.51962834019815, 56.88107867394724, 54.40294873329901, 55.25716643179617, 53.600894635723485, 53.67358792212702, 52.63519140981859, 52.17761555025655, 50.19270012455602, 52.052856722185695, 50.06252058090703, 47.03087752865207, 48.28552999804097, 47.8003014287641, 44.45854402357533, 43.25223868893039, 42.46594859707741, 43.68665687499508, 42.897252421225275, 44.85324428927514, 41.56540770684519, 43.89750388360793, 46.17766003454886, 49.97936241088375, 47.21134185791016, 49.39823581326393, 54.39604143942557, 64.00503250860399, 61.169664859771736, 59.894078700773186, 57.57486751002651, 62.105177602460316, 52.52811462648454, 58.77427339553834, 63.52842923133605, 62.65060278677172, 60.66638946533204, 60.94042193505072, 56.27220915209863, 58.44581411730859, 59.03568760041268, 65.55001097340738, 67.05326326431768, 71.90307786387783, 69.88098621368408, 70.11064883201354, 71.85637812460624, 76.81804303200015, 75.64232041758876, 76.90173072199669, 75.55196469829929, 78.11482567940989, 72.37725319400911, 81.11145373313659, 74.73212657436248, 116.30711663153865, 27.370893301502353, 0.3498411905621329, 1.1279557453047846, 4.918186414626337, 80.1319908326672, 62.828572488600216, 74.43736830065328, 30.800013657539125, 40.124799589956964, 42.610095700910016, 51.155657691340295, 5.873576748755671, 0.13154773071648615, 0.09875225744420484, 0.12756699996609844, 0.03662284854198656, 0.08329322366344352, 0.048855981834593325, 0.09371781105836553, 0.11829510676644503, 0.1338198555693511, 0.2410825990861462, 0.17465326123900954, 0.26217894448388007, 0.3692081077925621, 0.6231865406997743, 8.580145528239589, 85.19144042845696, 62.91534708392236, 55.47506586197884, 57.53762460524037, 70.47377401782622, 91.47891352253576, 45.0425967093437, 0.46395847513791055, 0.7034756195160651, 1.5154920470330024, 6.156066829158414, 86.80070261801444, 80.38430906111195, 81.02400056777462, 71.4798148985832, 71.78683450145107, 69.29874174056515, 71.05070760173183, 74.51856136322021, 77.425916271825, 75.42642531856414, 77.02368505539434, 75.99949144547986, 69.37337660020398, 71.92526278957244, 69.04931037656723, 70.05060518941572, 68.29172811200543, 73.02988852224043, 67.03605974874189, 62.50352567242038, 65.58480239683583, 60.0535975733111, 56.733491651473514, 55.29901027679444, 54.70966631366361, 55.161974430084236, 52.61777608625351, 50.76744502590549, 53.25658898199759, 50.952239651833814, 50.15568471723988, 53.64748847100043, 51.72908859868204, 50.138183101531006, 46.82523942762806, 48.50347257429554, 47.86267495924427, 47.611101981132265, 48.568344654575476, 48.07849161086544, 49.40784954255628, 48.676959007017075, 53.97623015988258, 51.79042270106655, 51.93793127613684, 60.914240114150516, 55.62031907420005, 60.1285344554532, 58.76422820552703, 60.25544666474866, 60.062771997144154, 61.57125672986431, 59.57592348898611, 61.39960988875359, 61.771631010117076, 62.495312229279556, 63.87054620250579, 61.30107602765484, 63.70408865713305, 62.97492788683984, 63.556674218946895, 64.56735526361774, 52.456664731425626, 41.6001049933895, 49.014337755018666, 45.417277197684015, 42.56589058906802, 45.53860787422427, 46.89249238660259, 42.86925062056511, 41.84107972729591, 44.27277664984427, 47.16494414114183, 44.37678613970357, 43.55248435851067, 44.00370990076373, 58.20393331589238, 62.093394802462676, 64.73868831511467, 63.59628623531711, 61.824657532476614, 60.78378992695963, 60.41152954101563, 61.110370389876834, 57.98727727705433, 59.66139977978122, 57.91898096761396, 58.56864706162484, 57.01065809495988, 54.51627385231757, 52.91466420696628, 53.85557805338214, 53.63446620202834, 47.791146616781916, 50.0600024192564, 50.69725028930172, 47.46123213921824, 45.031927862475, 45.887545847123675, 46.96265966661515, 45.487338573701926, 47.65450692945912, 45.26112764112411, 46.630803615816184, 48.404154239162324, 52.78038186411704, 50.56223446323026, 50.08698048130159, 55.89260608919206, 66.75952480685326, 63.002882619057935, 62.62243624656432, 63.02614227417977, 64.49701147694742, 57.23761035550026, 61.785484821565696, 65.00109487964262, 65.05735343502414, 63.02869965953212, 62.71764001538677, 57.419467126169515, 63.18639855231009, 61.67081040720786, 67.193511532199, 68.65009938516926, 73.79613138014271, 74.23377375448905, 72.01504584281676, 73.57613348191785, 78.55719843218404, 79.46587039578345, 79.0572614054526, 81.04166692303073, 80.39137717216246, 76.86789635689028, 86.32963380505963, 77.51681327819824, 115.75592948544411, 30.873008966445926, 0.5685698036705295, 1.8031270513611457, 7.9320410278535665, 90.13765904211229, 71.0322646171816, 84.29980724088608, 42.32121313771894, 56.834841774355986, 54.343917062205655, 73.26290084469703, 8.316653447766459, 0.30663373970216323, 0.15484449513737233, 0.2029334429290987, 0.21481512955600218, 0.15044543441505204, 0.15586285581511838], [0.10444812116123016, 0.0136380217173287, 0.03647311282674632, 0.02841324158643763, 0.04450009399724584, 0.055003025373744394, 0.07869568488170063, 0.40245206425747565, 4.230101195073897, 60.12470229979485, 43.345897043904955, 40.04894487319454, 43.73099534742294, 51.662169041172156, 77.43274904066517, 41.30980645456622, 0.13890162320627322, 0.15525255953111958, 0.47578950803126063, 3.095991986413156, 67.74860535898517, 80.73190166104226, 73.34117566385578, 72.25207467232981, 66.20667457580566, 65.01850628083753, 65.48755899552377, 66.8959056177447, 68.88093086981004, 67.89541182979461, 67.38326795639531, 66.41419149214222, 65.39061369434481, 66.66536438849666, 69.9680628315095, 64.90934671894198, 64.74763524147772, 65.24797670302853, 50.63096615575975, 61.04140727750717, 55.20801521116688, 51.725836953809186, 49.85148529852591, 50.222941598584576, 44.30411638752107, 45.49697191484513, 45.26285348399993, 43.7275868077432, 44.47040919334658, 46.3337036871141, 47.346902893435576, 49.30369492500059, 45.95867410782845, 44.648316137252316, 42.37728734170237, 41.37522374430011, 41.99462483006139, 44.416743324648955, 42.60858951076385, 41.9762759823953, 42.47963374660861, 42.34785387592931, 43.57630099019697, 47.05378024808822, 46.35368031840171, 51.05516656752556, 50.56812586322908, 50.83092074240408, 49.79496394434283, 52.72373891645863, 51.676752413472826, 55.14954443900816, 53.89244833300191, 52.60585600329984, 55.833241016634055, 56.19247128886562, 57.11868016950546, 55.8110757027903, 56.38423204421998, 56.95499573984454, 58.82471115358415, 59.30982989649619, 57.71071880094467, 44.20586493707473, 45.401022895689934, 42.3810528170678, 37.54323674786476, 43.456892275041156, 46.476572098270545, 46.234024493925034, 40.22017202069683, 35.05955273105253, 41.85193292556271, 44.70221734816029, 40.058287958945, 47.3805921308456, 56.418184080431544, 56.64947840475268, 54.25515774757632, 52.6956743578757, 56.36670689429007, 52.412863623711374, 53.14496224926364, 51.47516612083682, 51.62780907846267, 52.150398223630845, 51.17885851090955, 49.23190770610687, 50.9756052109503, 49.70836585567844, 50.563881858702636, 49.312280993307795, 48.090548976775146, 46.16317079913232, 44.73966813856556, 44.40483893117597, 45.74484609788465, 38.803945356799716, 38.91847856583134, 38.41052378377607, 40.282792660497854, 41.42959171725858, 39.137295830634336, 41.61714769178822, 43.28000906975039, 47.67129467379662, 45.677091075528054, 47.19039247881982, 50.539163081876694, 58.26480850096672, 58.14167353414721, 60.63025266893449, 58.839765210305494, 58.709758250944084, 44.77328285094231, 57.134785421432994, 59.99093378743818, 60.70331073576405, 60.31868311666674, 58.47291377282912, 56.14042535904915, 56.16980783400997, 55.146339862577385, 59.270594427662516, 61.80589683594243, 66.31458682398643, 67.93784403031873, 70.88952956661102, 66.85002173146894, 72.71771492496615, 72.59531344136884, 73.89788550715294, 72.77091795398344, 79.41609551829677, 73.27072205082064, 79.30757138036913, 82.4650401453818, 115.58451406417356, 16.67616271203564, 0.17182013019919398, 0.6186503808825248, 5.98189349136045, 71.47633967861053, 56.36094493250693, 58.531278640993186, 30.87651360419489, 33.82814814967494, 33.176673843014626, 31.393866385183028, 6.6608003647096705, 0.13498921217697282, 0.06809952443525677, 0.06339641107666878, 0.08192349675922625, 0.032552554452371214, 0.010331364070636131, 0.05865113223872839, 0.030279989098949783, 0.06724843905577738, 0.03392116286821904, 0.03946724873516829, 0.11444831882873852, 0.11318511645039243, 0.40693637524400994, 6.178245871297776, 68.9517374961607, 48.86345986397036, 46.714471693961855, 49.54386557302168, 58.59941413325649, 83.03539199213829, 48.28271373625725, 0.3295615868222329, 0.20473220205355078, 0.3434974003222681, 3.3649295424261405, 70.10283547063028, 83.10962677001953, 76.76445561070597, 75.16651338146579, 68.4295601998606, 67.9912353331043, 67.69949728442778, 70.81032906809162, 70.35207071611958, 70.52514137760286, 70.47841810411023, 69.67390860280683, 66.48864592275312, 68.74448730099586, 72.27965677938154, 68.01741323163434, 66.59758583191903, 69.25851391207787, 56.139048607118674, 63.772965477358916, 58.075271729500066, 55.34782809595908, 52.257965303236446, 51.22037679918351, 48.20051262455602, 49.59524077753867, 47.104480804935584, 48.296304748904326, 46.68082560262373, 48.83308502935594, 48.92912818539528, 52.10444765706217, 47.32021116441297, 47.35167641793528, 44.92130917887534, 44.731411549352835, 43.13407728748937, 47.62075101175616, 44.82354017996019, 44.38833751986104, 45.41444132404943, 43.68886516940209, 45.65354508738364, 48.24612978966006, 51.130695727563676, 54.31229883624662, 53.90041074445171, 52.80357091657577, 54.33793544769288, 55.92547162886589, 55.31635892006659, 58.02939568796466, 54.600730326867875, 55.49900800951066, 59.47025875891409, 60.22037675303798, 59.31241473843975, 58.17006364945443, 58.79364990418958, 61.799252340870524, 61.589680102563676, 61.576238139983154, 59.862915469754135, 45.24896044884959, 47.255315549912, 44.00134471154983, 41.77985545127623, 47.19941785258632, 47.31849316627749, 45.43115454335367, 41.71448522998441, 37.884941870166415, 41.31537229784074, 43.314380799570394, 40.68009737999209, 46.67201203684653, 57.72933044741231, 59.46709340618503, 57.59229852307228, 56.00520556972873, 57.15909234939083, 56.31285667419434, 55.550740149713334, 56.62503811620898, 55.862662715296594, 54.84346620498165, 52.866305305111794, 52.577716919683645, 53.733784537161554, 52.12221599394276, 50.6201639483052, 50.23790544079196, 50.567149193056174, 48.50836769227059, 47.91818041955271, 46.69068644123693, 45.667634241042606, 43.21555276070872, 41.33468212619905, 40.48003296698294, 43.34309647160192, 43.63943546049057, 41.219999867100874, 44.879936018297755, 45.517736942537375, 51.12567117137294, 47.39037844442552, 49.777199529832416, 53.976390977059644, 59.73546981811524, 62.385317202537294, 64.23990795689245, 61.363135768521225, 59.89639682154502, 47.48841416451239, 59.93524397573164, 61.26986965056389, 64.20555976129347, 62.287152044234745, 61.51654358833068, 59.4919063198951, 59.36885764521938, 57.542923727343165, 63.23618519690729, 62.46659655724803, 69.2358269230012, 71.17863962727209, 73.97545429968065, 70.11162942455661, 75.71922240718719, 74.00135763229864, 76.29858786059965, 74.92149076154156, 82.58550397811398, 75.89345409024146, 84.26509426486108, 81.96205892870503, 118.27953538587018, 17.35912972880948, 0.34421516342028496, 0.9517948689960665, 8.304259738614483, 80.96180746632238, 64.26665459909748, 69.071134444206, 37.76983207271945, 34.313612061162154, 47.34632630502024, 44.06851137838056, 7.734042233036411, 0.084328951554433, 0.12349024775528139, 0.045410876778224786, 0.019655037153091644, 0.025462154073700793, 0.028624662701340935, 0.223259027266214, 0.13569192930815682, 0.24071738965088324, 0.20123335592929395, 0.19902291647609205, 0.3040168139963381, 0.25623378043453543, 0.5700243288470853, 8.191636233560502, 83.15449868479084, 53.529385905111994, 53.77635009827153, 59.010556974718654, 66.28950718910464, 91.42706763359809, 53.85226365058653, 1.0099845788171216, 0.368063633720721, 0.8247211070791368, 5.006044564708587, 71.33832716172742, 88.36539099293371, 80.79850350656818, 79.71551356777069, 71.07227279293922, 72.02437323908653, 70.17597198486328, 73.56885356287803, 74.19413428152762, 72.97369664715183, 72.15505092374741, 73.03790584687265, 69.46633677328788, 71.64696278110628, 75.31544577690863, 69.21854496002197, 68.63268406160417, 71.85705277227586, 58.88130311043032, 67.35232830047607, 61.06600446085776, 58.200089393123505, 53.42222675200432, 56.41332034141787, 50.48696417962351, 51.650154821334354, 49.00022506713868, 50.8334545935354, 49.54572869885353, 51.72777068230414, 52.00463510328724, 54.858080956243704, 50.39775771479453, 51.65989798884238, 47.19066704473188, 48.75151541925246, 46.684340046298125, 52.3966093217173, 47.45951806345294, 46.652164843774614, 48.634879819808475, 47.42667998037031, 49.077433001610544, 52.0898211386896, 51.966945048301454, 58.3273938394362, 57.65023585288756, 57.00395084196522, 56.72146958689536, 59.855466888796904, 61.04981291678644, 62.00401967571628, 60.47159671783448, 58.7483504510695, 63.93761481008222, 62.646496065201305, 62.88736489511306, 61.0772342066611, 60.80329195145638, 62.95533957019929, 65.3448082554725, 64.48056890118507, 62.139408126954116, 44.652611132591005, 49.574107047050234, 43.72206803291075, 43.16901776098436, 48.215194056111, 47.956823610490375, 48.21594715118409, 44.03027219157065, 40.01580084523847, 43.277063369750984, 43.873718630883005, 40.55838231117495, 48.65665681900517, 62.70704569355134, 63.03449300027663, 60.923053679927705, 56.3019524851153, 62.58555027746386, 59.13892830571821, 60.57472759677518, 60.75700798342305, 57.52911306196644, 58.78917447982296, 56.93878458392236, 55.91502635709701, 58.982264918665734, 55.742618576172866, 55.756884236489576, 53.915492257764264, 54.84887123107911, 50.19591646809732, 50.71022156746157, 48.74743615427325, 47.97886733085879, 46.571650351247484, 43.179470877493586, 43.90704701023717, 46.96962187367101, 46.83269977569581, 44.195121565172755, 49.11409539561118, 48.15671151684177, 53.37884926026868, 50.00892139250233, 52.24398989831248, 55.784431042209754, 63.579337673802534, 66.42424844926404, 66.7479302806239, 65.19979038546163, 62.6546859741211, 51.787057307458696, 61.73136788029825, 64.90578128445533, 67.74774243754726, 64.97901978031283, 64.57308192406931, 62.395601657129106, 63.21398850410216, 60.30117365621752, 67.08912157243299, 67.26558900648548, 73.330914743485, 73.61585924702307, 76.11938261216687, 70.99417840280842, 76.91703581040906, 76.74081156330725, 80.56186691407235, 76.86220107540008, 86.10625482374623, 78.5327777554912, 87.79486656188966, 81.51261022014003, 124.43151412471649, 22.670042476346417, 0.4398655921461121, 2.065431143968336, 10.158342546032323, 90.43313118719286, 72.55813721687564, 80.4676123588316, 49.77489317617109, 52.18273032096125, 63.01402999508766, 66.84814683852657, 10.300380395304773, 0.27310679035802043, 0.21792947615106262, 0.1748816933362715, 0.12524321014361997, 0.1666726628618856, 0.15555024597673647], [0.11113198549156228, 0.03488395918881701, 0.022447354858741168, 0.03566965513351945, 0.04280316711012875, 0.07302753822577578, 0.08354021041023155, 0.2546603584121312, 3.0959959087833284, 53.233952983733154, 50.21104112748177, 27.52225756645203, 33.60600471496582, 55.26722338891799, 67.56441085569321, 51.03976734222905, 0.13301011595514514, 0.17332605987546906, 0.17652352701031393, 1.1408599754495006, 56.080962227236846, 82.72113953867267, 74.00128702963553, 70.87591109737274, 67.2896723593435, 61.77947575046171, 64.22930579031667, 67.55232995556247, 69.0031676138601, 70.10048989326724, 68.39731047230383, 67.0125961303711, 68.58076757000339, 69.70295767630301, 68.38265649734005, 64.99852964954992, 64.84029339205834, 54.70945058330413, 56.54527671875493, 58.81925121430428, 53.77189820812595, 49.78280851917882, 48.93149337460918, 45.03492455328665, 46.214408720693285, 44.748756270254816, 45.45200194081953, 46.88250995451405, 49.29100605749315, 46.387879463934134, 45.685218226525095, 46.89366909765428, 44.53174721810126, 44.72322556280321, 44.39412693823538, 44.88984000298285, 42.41265927591632, 43.13412435593144, 42.23373251576578, 40.26502040124709, 39.69907337619413, 42.746837369857296, 43.47654727197463, 45.99345768651655, 44.69827536613711, 48.91155204465313, 48.78079983495897, 50.91222363133585, 48.72048947118944, 52.910604553837935, 52.78849332563339, 53.34595626400363, 52.42124180639944, 56.289910808686294, 54.813401237610854, 56.31359800215691, 56.78217218768213, 56.19844113626788, 55.49705466916485, 57.50458255890877, 58.08181032057732, 59.41262737397225, 57.697849504409305, 47.45233620366743, 42.189884339609456, 49.08216730240853, 42.536731689207016, 45.2079559910682, 44.328509607622706, 44.680389358151345, 46.498576594937234, 38.92577809672202, 40.51018422649753, 41.59149931323144, 41.62420011335804, 51.83425518774217, 57.10644629693801, 55.52568012668241, 56.262399304297666, 56.213193170485965, 55.602221258224986, 53.0245376402332, 51.18584425218644, 52.92387393213088, 53.10863325672766, 50.45809553515527, 49.19922651783113, 49.90766540650399, 48.97972283824798, 49.12029274048344, 48.40403656805716, 48.49806362582792, 47.521887671562936, 45.441650805934785, 42.30836345303444, 42.71274412831953, 41.97988064058366, 38.38591875568513, 38.464927058066095, 37.872143176294145, 40.93470235024729, 40.32074159191501, 42.38905445221932, 44.187774965840006, 43.245633417560214, 46.84704780578614, 45.48041166797761, 47.01259928364908, 46.48583281424738, 55.81424105551935, 56.019102527249245, 57.912736554299634, 62.895111576203384, 56.829350456114746, 48.94580218099779, 62.762982614578746, 58.36082812278502, 60.84411205783967, 59.50013545251662, 62.50858945231285, 55.20256311662736, 58.37221084102508, 55.313836836045795, 58.248420838386785, 59.6361554053522, 62.58993156494633, 66.17094962827622, 69.86982314817368, 69.09141309799688, 72.89445692493071, 71.56150217979186, 76.06422624280377, 72.75522847329417, 79.86562267426523, 76.54731319796655, 83.36175672469601, 87.1724727076869, 81.15191690383419, 5.412386425079839, 0.06295388421764778, 0.3665066366234134, 7.184971205649838, 77.8538703918457, 56.14436341870216, 61.221118511692175, 25.42383070914976, 27.786705724654663, 31.720399779658166, 24.563772601466027, 8.16932677261291, 0.043924922844575304, 0.09006884234446673, 0.03530285606581358, 0.09202808156729707, 0.0484660852159704, 0.044894575652095585, 0.036227872760425654, 0.02673326056420563, 0.05949095995616048, 0.02383595816941271, 0.07019738726798566, 0.12278506382098123, 0.17231543668575827, 0.3439338252909722, 4.675201466006618, 65.53870670257076, 53.875550762299575, 32.57754748867404, 46.14012687436996, 60.31140711999709, 74.1406645313386, 58.39535282504175, 0.36449145766035207, 0.13424930913794425, 0.30161613958977884, 1.2965041591275124, 57.964186283849905, 82.18909355901903, 78.78849275650518, 72.37746500199842, 70.15867433240338, 65.90480896734422, 63.77446774513491, 70.13532838513775, 72.18747323559177, 72.85663743172923, 71.0761716288905, 71.30432805707379, 67.71862276138799, 71.76271976963167, 69.74575857962333, 67.15519782035582, 68.26901758870771, 58.87820443799419, 59.26961775748961, 61.121925692404474, 54.97835259283743, 54.57930634098669, 51.88636779785157, 48.625877980263006, 48.04889732791532, 48.129094108458496, 48.116707263454316, 49.99517740741853, 52.29337253878194, 49.047477860604566, 49.36707650461505, 48.23785751096664, 47.52300946943222, 48.404824964461795, 47.162547572966545, 46.837320327758796, 45.20797168054889, 46.20065689086915, 45.1146428046688, 43.37774668970416, 42.130236856399044, 46.06751595774005, 46.45176702930082, 47.658166500829886, 48.49529835485643, 50.076841154406154, 51.639760540377715, 54.347855121858665, 52.86954126050396, 57.66832190175211, 56.290695282720755, 57.35980003110824, 55.26391290849256, 59.763240198935236, 57.363267406340576, 60.591731071472175, 59.88326864857828, 58.492019637938476, 57.407021445612756, 59.62705550655242, 58.68282725734096, 60.46685064992597, 60.017594137499415, 49.71787368097613, 44.55789766004009, 46.81985401338147, 42.18317316424462, 46.1326547591917, 46.55230129918745, 43.93560578746181, 46.280014284195445, 42.1321980414852, 42.25761582774501, 42.44620730800014, 43.82123731797741, 51.80509236551101, 58.802804716171764, 57.285149481988725, 58.284894958619155, 57.86077299425679, 56.79102889953121, 56.23551145676644, 54.885231602576475, 54.22366111509262, 55.72918445833268, 55.23800173113423, 53.00938160188737, 53.843136295195556, 52.16236145265641, 51.914601018351895, 49.77540700666366, 49.87286221596503, 49.62061066781321, 47.80743622010755, 45.30230860556326, 43.275176709698094, 43.524462945999645, 41.46211208835725, 40.34486416847476, 40.80826474774269, 42.514374179224816, 42.237109676484145, 44.84869826224543, 44.943568629603234, 46.652082474001, 49.73008794169272, 48.12215543562367, 48.624042311022365, 48.77753250060543, 56.41668965739589, 60.047510054803666, 61.420971116712025, 64.56775534537532, 61.18051413566836, 52.228072920153224, 66.21873978645571, 61.173053787600615, 63.60491937206638, 62.71416871778427, 64.89299435769358, 58.61639015136227, 60.11683794759936, 58.13663328847578, 60.12177228927613, 60.744024938152684, 66.5862972505631, 68.7727205214962, 73.56756702546151, 73.5064172744751, 75.1751975090273, 73.21826427213608, 76.88011061760687, 75.11745237535047, 81.14852013126497, 77.60618840494465, 84.50104052020659, 87.69522267003214, 88.3808921998547, 4.593669608716042, 0.13966498385754325, 0.630104314656027, 8.786536724336687, 87.94515609741212, 63.98511863523915, 69.87264725469774, 35.209936403459125, 37.150583959394886, 43.78600658908967, 43.855052071232954, 8.646439467706989, 0.08977838010797579, 0.0858839031969828, 0.0583443216859333, 0.04213589686720122, 0.05777930119825948, 0.026274433269375758, 0.22582070271094, 0.139491694769071, 0.17269592191423142, 0.14308740505047385, 0.1605582087030334, 0.32016374110694856, 0.4204913511151268, 0.6905668541308373, 6.510789807765715, 81.12544090517106, 63.631854288039676, 40.027779763744725, 46.070642086767386, 71.77770322368991, 80.75557708740234, 64.45220624246906, 0.8863048315528901, 0.4772129913251247, 0.6681311418933253, 2.467830777168274, 59.68717759655368, 83.56361758324408, 81.1961769288586, 77.86839885096397, 72.22775597726145, 69.03503294914, 68.50730942141625, 72.5811379955661, 75.18217148319368, 76.43287412581905, 74.03661974014776, 72.55107695056547, 69.78013423181349, 72.87409197899603, 72.90558861147973, 71.01165648429625, 69.94019046906503, 63.043494839822095, 61.151625879349254, 63.862501421282374, 57.26671041980867, 58.71299812870642, 54.65364702286259, 51.459460950666866, 51.25580756895004, 50.03713107878163, 49.69915613051384, 53.53769348513696, 55.846082856578214, 51.70506015900643, 52.310077913345836, 52.22919079565233, 48.49134068335257, 52.5734729151572, 50.10391727570565, 50.01016870621712, 45.925502623281176, 50.12895376451554, 48.91905553879277, 46.13076809913882, 45.52303998701034, 49.806311361251346, 49.83414842236427, 50.66768738531297, 50.33783174330189, 52.67124191407235, 53.53165303507159, 56.24290120217108, 54.5053461290175, 62.917928003495746, 60.0807874433456, 61.5803252497027, 58.12045743388515, 64.19111759431901, 62.81906074093234, 63.936936240042414, 61.32270005441482, 60.72092217783774, 59.14183085964572, 63.314197217264486, 62.22781835063812, 63.911276094375125, 62.02159189408826, 50.681823607414, 46.609591437924294, 48.77105666745094, 43.15653677909605, 49.278866321809836, 46.316617842643495, 45.96066667187599, 49.67524928431357, 43.551546912039484, 42.7924310007403, 43.0029446078885, 43.66814328778175, 54.16487655332012, 61.760083552329775, 60.712591063591745, 62.62420523551203, 63.01726595047982, 60.50190094978579, 60.58319599397721, 57.86063178893059, 59.00156297991353, 60.853521823883064, 58.80957080471901, 55.50240085970972, 57.258245944976814, 56.12444170059697, 55.095780511056226, 54.12850833708241, 54.33894349682716, 51.447274146541474, 49.11207929734261, 48.86647616663287, 45.719374225985625, 46.18806608261601, 43.77172523929227, 45.117568892817346, 42.1744772695726, 46.762461893020145, 45.12722184581142, 47.64186120802357, 48.70754172725063, 48.030403352552845, 52.24320542427802, 50.14112095679007, 51.991722660679976, 48.44468801252304, 61.79854631423951, 62.28395923491448, 65.5042016121649, 68.19936413918772, 63.099851454457934, 54.528044885204686, 69.22328318319013, 64.08319357902774, 66.13560907302364, 64.5316420831988, 68.82176583813083, 61.506651370756096, 65.40503624946841, 60.60176057200278, 64.28248920748311, 65.27466058731079, 68.193770839322, 74.26602348204582, 75.5542161387782, 76.5316080277966, 79.60283956220074, 75.41732541976437, 80.1741013988372, 78.39486722023257, 83.80877356375419, 81.68244100386097, 87.68096877682595, 87.63987018216042, 98.86672127631404, 6.974251183771319, 0.19423998441667328, 1.3657489467051722, 10.296537453128446, 100.82054799602878, 69.76347984806185, 83.82680862180649, 41.36252703205232, 50.82746905665244, 60.887269896845666, 64.50518177401635, 12.34630044429533, 0.20556141562279195, 0.16930391441189474, 0.1575337701867665, 0.17087738239957442, 0.21749004811769534, 0.16214329058364516], [0.05514737549087694, 0.0846543780437881, 0.03898430690770188, 0.018154108115742286, 0.03947580976772212, 0.06381518154915783, 0.06777802797695322, 0.19258077586850814, 2.067046915331195, 50.55635483034196, 46.727309611535844, 36.58706880384876, 26.49669308816233, 51.52727088620586, 60.89147075530022, 64.44094119533416, 1.9435182406056313, 0.20076107804573354, 0.20630734011290536, 0.7135620557012097, 41.92668545630671, 79.73594911636846, 71.34411658010175, 73.11720832701653, 64.93750541440903, 66.91244233039119, 68.03320469394808, 70.13222186796128, 67.7259889725716, 65.81744209412606, 68.97340466899257, 69.54040681162189, 67.62042230175388, 67.30461658970003, 65.25372689770114, 68.0348442446801, 55.433963344943145, 55.843674521292414, 59.32130675162039, 55.79759059413787, 50.13282906624579, 46.41122541119976, 47.24493303606587, 46.89119800444573, 42.80382156372071, 47.66127301800636, 47.66104159816619, 46.39214700268161, 45.57606650936989, 44.65527442193801, 43.156685829162605, 45.91711267348259, 46.59616908719463, 45.128316187089496, 45.82775715858706, 43.99219382193781, 43.90640766389909, 42.776435575177594, 42.69246939689883, 40.6002849917258, 41.03196144104004, 41.658924856493556, 42.196913226958245, 46.444192932498076, 45.46560079820695, 48.031007397559385, 48.82482844014322, 48.420157509465376, 51.794423518642304, 52.6427419724003, 51.91301638080228, 53.802920233818796, 53.47403733961044, 55.96430701594199, 56.60386908438898, 55.49712134945778, 55.27029068239274, 55.46517364440426, 56.29597479297269, 57.06560265633368, 59.569365286058, 57.36012951020272, 57.66291687565466, 50.60525109691005, 42.0252703082177, 50.398087193889005, 46.64985064537295, 47.06843814542217, 46.054132830712106, 46.379532660207445, 48.65855524616857, 45.62131497167772, 39.42009479768815, 42.131515549075225, 42.60728336149647, 55.73370302877119, 56.929531712685865, 55.39422581272741, 56.00850036067348, 53.85657041303573, 52.22131859871649, 53.98842088637814, 53.02691067418745, 52.34035076633577, 50.842950651722575, 51.47298528302101, 49.32755078038862, 49.54697601256832, 48.515145547928356, 47.325851532720755, 47.81617133848129, 48.89405435131442, 46.92148654691635, 44.78705821498748, 42.244334682341545, 44.52324744193785, 40.32130641321982, 38.33985836275163, 39.9692540784036, 41.264405019821666, 41.01883719044347, 42.63969390623031, 41.54789040165563, 41.2803533769423, 42.496119468442856, 47.93235586535546, 45.89853240597633, 46.476270075767275, 44.97905823492235, 47.677370425193544, 51.43873514667634, 57.16620752888342, 58.275481270205596, 58.74572638542422, 57.28924443644863, 64.04683712990054, 60.87444766875237, 61.036367031835745, 59.20008197907479, 59.674222007874526, 55.99789427172754, 57.7847025471349, 55.15872278521138, 57.16148891756612, 56.18437159445978, 60.516962851247484, 61.78797552662512, 67.28751505574873, 65.68326957764165, 70.76382544732863, 69.2011296364569, 71.50329420643469, 70.77141915598224, 78.67038234587639, 75.38474621311312, 83.3924767278856, 77.45716187261766, 57.08061748935331, 0.23551732271669373, 0.07858118538053767, 0.3337261327091725, 9.895857534100934, 77.94668151486304, 57.66387785634687, 67.18806728239983, 27.913470845068655, 27.315440793191236, 37.39025254403391, 30.75099579749569, 8.589074803936867, 0.1941532785854032, 0.12639169085530505, 0.04197330619659155, 0.03139604513923968, 0.031053396993346756, 0.026385489205319076, 0.0720876326123553, 0.04672215500425908, 0.049899102474052104, 0.04075011659053065, 0.06412164353194737, 0.08391324926408068, 0.10549443638733319, 0.33190713354176093, 3.6465682233533556, 62.03377477584347, 53.92590615057177, 38.97011264677971, 33.992260117684644, 60.818742167565134, 66.60980793737596, 72.07609361217868, 3.137998609773575, 0.1555712214641033, 0.0849168933928013, 1.0369125080685462, 46.29062821788173, 80.98213318855532, 72.14760626516035, 76.46141329119283, 70.02840457424041, 70.8267245754119, 70.9746685335713, 73.0061032695155, 70.09189205784952, 68.64106224429223, 72.6741530818324, 70.93730403530982, 70.83251399378624, 69.17450458772721, 69.59833237432665, 69.02974559414771, 60.06386633842223, 59.44519089114282, 61.70995566152758, 57.704254734900694, 51.3029662255318, 49.85014384792697, 49.339376726458156, 49.12934164847098, 48.908257253708385, 50.46307302290394, 50.64162715788811, 51.3415035124748, 51.28158930809268, 46.5723132318066, 45.71599706526726, 48.137248716046734, 48.440985295080374, 48.45383105739471, 46.91767792547903, 46.71831561673073, 47.42695846865254, 45.978956683989495, 44.32103749244444, 42.9269173068385, 43.57718744585591, 43.395052186904415, 44.73101146759526, 47.79841869108139, 44.94204674997638, 51.35787548557405, 51.68156123930409, 51.07340558882683, 53.962054714079834, 55.17542815977528, 55.032724488166075, 57.346424748820645, 57.00598262971448, 59.01305552451842, 58.044018283967056, 58.60923574816797, 58.32877451373685, 59.38702998622772, 58.173664385272616, 59.2093466174218, 59.61685342173423, 61.080007322372936, 59.58566665649415, 50.61164456029093, 43.35956650395548, 49.92643002540835, 47.90835880464124, 48.34727594929357, 46.13605153176093, 45.3118948782644, 48.085810753606985, 47.679382601091945, 40.47761286458662, 41.384943377587106, 41.43503596705776, 56.883906702841486, 60.425591238083385, 58.41166596258841, 58.017977668393044, 57.17336193207772, 56.35007604475945, 57.59602477473598, 56.15107459406699, 54.94094887087422, 55.57485095916256, 54.58626462567238, 54.02526763177688, 52.524604105180316, 50.13667298901466, 50.46398301278391, 52.06965231126355, 50.998892322663345, 50.670680153754454, 47.15247492636404, 43.87756255365188, 46.4196349728492, 44.25657333866243, 42.01740987839238, 41.951255183066095, 41.76052208869688, 42.59743036762361, 44.634387800770426, 43.17319116284771, 43.72881843197731, 44.606244794784054, 49.058833122253425, 48.133287122172696, 47.69918272572179, 47.51817318700975, 49.52995684839065, 53.61685868232481, 60.16114111869567, 61.235003702102176, 60.561960281864295, 59.691837372318396, 65.60057424729871, 62.62194987266295, 64.45937633514404, 61.72617858456027, 62.33929211093534, 59.01931562731343, 60.96927489003828, 58.342875434506325, 60.48976121410247, 59.62809101227791, 62.550119507697325, 65.24097134990078, 70.27889497818487, 69.12937379652455, 71.3814732336229, 72.0794354715655, 74.81404919778147, 74.21510327246882, 81.04685229639854, 77.9023273529545, 81.74638348241007, 83.65996668415686, 58.169243874088416, 0.09760049021532459, 0.13761818078496765, 0.48635643456251393, 12.119425650565857, 87.85057206307688, 64.4242044418089, 78.21957649723177, 33.42603460434945, 39.66530961375083, 51.898338871617476, 50.02689369263188, 12.64531841201167, 0.118448983186916, 0.02969762629589006, 0.024856197677793044, 0.031232900970104723, 0.05484596585794803, 0.00789644792788632, 0.1552740406365164, 0.22599222979718642, 0.1294496457182592, 0.20861888785035382, 0.2634047158062458, 0.24552635337796905, 0.22193459914095942, 0.5429382177610551, 6.033623180081768, 75.36735442376907, 61.6594276889678, 49.07200444129206, 34.25660433307771, 71.84455610090687, 71.88912207080473, 78.80670039884507, 3.387454978881344, 0.4769768217398275, 0.7380897395553128, 1.5740062104117487, 47.849554631017874, 82.97331656179121, 77.73532067575763, 81.32315189607682, 72.18200545157157, 74.31950107697519, 72.74660710365542, 77.20113308198991, 72.2737418451617, 70.17165737767374, 73.88008579131096, 74.10866583547285, 72.23952308777841, 73.25005116001253, 72.62182081899336, 74.15795433905818, 63.74058238921627, 62.22582186422041, 63.99754078157487, 61.27274082553003, 54.19819316556377, 53.019638599887976, 52.24493911189418, 51.678858726255356, 48.073349383569536, 54.34285802225913, 54.403015413591945, 54.74989021978071, 54.72922325134278, 48.91791020670245, 48.56484982275194, 50.82495089500181, 49.17274659679782, 48.666776534049745, 49.17464110159105, 48.86871191763109, 49.96760314510715, 47.889452980410674, 48.980428864878995, 46.61375307267713, 46.43252780360561, 44.842442081820586, 46.76111652005104, 52.40534444009104, 48.20343871270457, 54.94027030083441, 54.42667122810118, 54.0642128452178, 57.337191489435014, 59.4330236988683, 59.54637627447806, 59.657128318663574, 60.268261048101614, 64.00423234508884, 63.45878754892657, 62.14586827062792, 61.138842874957675, 61.746214051400464, 61.19900811103083, 63.23850724004931, 62.986800901351444, 63.08138493568667, 62.53304935270741, 53.35699381366853, 43.10113722278226, 51.242997107967255, 48.901608836266306, 49.003778734514796, 48.0477951418969, 45.857849582549065, 51.009216000956876, 48.59075315536992, 40.710436913274954, 42.73727070900702, 42.713858081448464, 57.70508627737723, 60.84470825810587, 59.923198376932454, 58.77385762430007, 59.94378297559677, 61.0041408385, 60.69366562751032, 59.2252008376583, 60.84668513267272, 57.997310699955115, 58.76050195386333, 57.87307746948735, 55.15235677842171, 53.685115768063454, 53.15316784766413, 54.853746737203295, 54.04424013630037, 54.552736205439416, 50.08253251352618, 46.80706316424955, 50.538374685472064, 47.42355777371315, 43.02412540681901, 45.71582055860951, 45.715024317464525, 46.035128947227236, 48.70759664043304, 44.5874801758797, 46.18495172069919, 47.32272540369342, 52.14305554666827, 50.36804183836907, 49.520103854517785, 50.20864848167666, 54.21363161456201, 56.975529347696614, 66.4645782593758, 64.82773396276659, 65.49280320444416, 63.35777474987892, 68.74808803681405, 67.01999372051608, 67.43466669513334, 66.49052866043584, 65.92379323897823, 61.49033038846908, 64.91836424796813, 61.22221677534042, 63.51318297847625, 63.01557933130572, 66.71095801937965, 68.15144062042236, 72.32267733543151, 72.29766045847248, 77.0964293326101, 75.54814430975145, 77.53797838764807, 76.82574656701858, 84.611494464259, 81.3949312702302, 84.27801455220869, 83.30571389967396, 68.09551546650549, 0.5869179771792504, 0.37655072346810375, 0.9900233305750356, 13.47856515838254, 97.50343876500284, 71.95686924842097, 90.41280546495992, 41.09148733077511, 45.40796941326511, 69.02227740133964, 68.9860111667264, 16.56238652044727, 0.37426925234256253, 0.28926992788910866, 0.09842891471400377, 0.21382134497886707, 0.23240429379286306, 0.08898251434607853], [0.045986105387489644, 0.061480241316941485, 0.025141172809526328, 0.05090861866671232, 0.039044448640197515, 0.065172900025162, 0.07181983891754382, 0.1788992422723001, 2.7184160534412634, 54.737366091820505, 52.824692879953695, 41.68758169297249, 40.47004661252422, 47.35946232272733, 55.0450328857668, 72.15644728752875, 5.995459498897676, 0.29185179741151873, 0.18676007046334206, 1.2213001880914935, 31.672060489654545, 70.3809864290299, 70.82997229791457, 72.66695945493638, 67.5087445782077, 68.98169655953684, 66.48595517681491, 70.36412808202928, 71.46151311935918, 66.90893573145713, 68.01056477331346, 67.51822102454402, 66.67307576825543, 68.08501135918402, 66.87317156022596, 59.53699788739605, 58.554652044850016, 56.77220544507427, 53.39956721951885, 50.555790009037146, 48.915996090058364, 47.32389819237494, 47.339042463610255, 46.420395912662634, 45.138514349537516, 49.36173031407018, 47.7074706938959, 45.849824413176506, 42.73502711326846, 45.02517746340844, 46.270278961427756, 44.556642501584946, 46.42357695487238, 45.07268913330571, 44.70764983084894, 44.260389804840095, 44.41657074036137, 42.32086012440343, 41.90818755857406, 41.48065313216179, 38.737217995428274, 42.37230200921336, 43.518222455055486, 44.648261224069905, 44.72927385760892, 45.59789057700865, 51.242216556302964, 48.821631708452784, 50.13795952643118, 51.184161555382516, 51.557037753443566, 52.01983428770497, 52.33972710947837, 53.92454901049214, 54.5470291568387, 54.51420676323676, 55.226552332601244, 51.08461572277931, 55.780881297203806, 55.630481935316524, 57.485747337341316, 58.36448769415579, 58.95408268897765, 50.68111758078299, 41.195736085214925, 45.74459506619362, 45.24350835431007, 55.86589474831858, 48.14687813481977, 42.2175488164348, 44.871895159444506, 50.643368690244614, 42.67162984417331, 38.90757045438213, 44.43675525726811, 57.55966832560878, 57.68931834928451, 55.351542580512266, 57.345604973454634, 55.14414333528089, 52.359825334241314, 54.02134133923439, 53.4078904890245, 52.12867613761656, 52.68022414176695, 49.20317634459465, 51.96392482326877, 49.2223685018478, 49.78922551678073, 49.04037837059268, 49.66186223491546, 46.73740971472956, 46.03365413604244, 41.29464257148005, 42.47631934381301, 40.917922450650124, 39.210538248861994, 38.594541780410275, 39.87497206657164, 41.20459279706402, 44.75199222564698, 42.0750294962237, 42.337310544906124, 42.9461722220144, 44.2684934216161, 47.6959232361086, 44.89038913480697, 47.4225575693192, 45.11174809548163, 45.47917219900316, 48.523649246461936, 48.43717275127288, 53.23252524099043, 55.20486162554834, 55.464094992606874, 56.394575334364376, 57.68452129056377, 55.88932306535783, 58.95692248498241, 57.13838223488101, 58.13279721044726, 56.9028909744755, 58.33511306393532, 55.51668220950712, 57.21653153819423, 58.37217553969353, 58.69320584881691, 62.756475402462875, 64.09030875852032, 65.21444043805523, 67.99081171712568, 68.87864020562941, 72.71323557822936, 70.76575525345342, 79.32781865519863, 77.52872943878174, 74.37322970359557, 27.357023800573042, 0.7706063721449145, 0.8792465877148413, 0.7861573441374687, 10.161523588242071, 78.83661239377915, 57.39057102511006, 57.19497026935701, 31.49119607863888, 31.90629855279, 38.17782917330342, 39.752656875118134, 7.499812995233844, 0.09974376674020484, 0.045026829240903746, 0.04879162661851414, 0.07986306498247771, 0.04157703189599899, 0.04865780637990083, 0.06831700913608074, 0.05017124371783388, 0.029329199291345094, 0.02856171517182262, 0.04940189991987521, 0.055139952098890666, 0.12152965255682507, 0.18534463109268298, 5.226932350666293, 68.14916564572242, 60.84885812574818, 43.2679791604319, 47.63919007393622, 57.049011030504786, 58.259901615881155, 79.77660056083434, 7.338660945815425, 0.3292407798430612, 0.08443093317891322, 1.2504902217657337, 34.406835033047585, 72.67037191698628, 72.85114611348799, 75.53309025303011, 68.09291101271107, 71.16804922780683, 70.02208171352264, 72.68281367517287, 72.46748339745307, 69.20669940210158, 70.38085306844404, 68.74103561524423, 69.93154556520524, 70.9537701452932, 68.15836752614668, 61.5492404660871, 61.79716171756868, 57.3456520418967, 56.51895761489869, 53.02309028563961, 52.35579706007435, 50.16944831417453, 49.84348366337438, 50.01432641859978, 48.42924171878446, 51.11220567457138, 49.73262179282404, 49.89444309665311, 45.372919113405295, 47.736002014529326, 47.032775955815474, 48.22066184013121, 49.404715568788596, 48.130310043211914, 47.794284512919766, 48.07500070141208, 46.41852101972027, 44.82815288728283, 44.18544507795765, 44.97371988911783, 43.13824284461237, 45.337943338578754, 44.662522962016446, 45.87980308840352, 46.95526599884034, 49.1386612000004, 52.07650861432476, 52.14968827462966, 54.05069243523383, 54.07503466452322, 56.24651370509979, 54.91047205463533, 57.07330226898194, 56.78760467037078, 57.889845601974, 56.112737348002774, 58.569074599973625, 55.46378512536326, 58.07556590726299, 57.712507401743245, 60.817475241999475, 59.769590516244214, 60.782691663311375, 53.19609426682996, 42.349148258086174, 46.864117960776056, 47.173259565907145, 58.7461970698449, 47.8548498307505, 42.69790972432783, 43.5610233583758, 52.008604541901626, 43.88952186030727, 39.742101776984434, 45.651164208689046, 58.637853360945186, 59.37771827943864, 56.658095852021255, 61.31376489516228, 56.38378489402033, 56.715374223647586, 57.770236845939394, 55.56995191881734, 54.714243719654704, 55.148465787210775, 53.838398072027395, 55.002561461540964, 53.380967340161725, 52.22921825224354, 50.87004246250276, 53.32145713990735, 49.87953024525797, 49.10608199334914, 44.479073709057225, 45.24110394139444, 43.99395888851535, 41.44121762244932, 40.961923599243164, 41.97704476694907, 44.11660355906333, 46.01016306108045, 44.742915861068234, 44.80793699141472, 45.469158387953236, 47.76125815606887, 47.87239851490144, 48.36875484835718, 47.936623404102946, 45.808639526367195, 48.01857348411314, 50.613605745377086, 51.94393642487065, 54.03714064628848, 57.24955789504513, 59.45778169939595, 59.57710412240798, 60.7609970338883, 59.58354465423092, 59.95282796121413, 62.55910173539193, 58.753759399537124, 60.38417100906373, 61.685950756073005, 61.47191878288024, 59.57307584824101, 61.76464919121035, 61.7737530123803, 67.41863989060926, 67.56686625942108, 68.51043947281377, 71.64991240347587, 70.88672114956763, 75.44886912069013, 73.83263295696628, 81.01152743062666, 79.77657702661331, 83.75663741942375, 25.726572967344715, 0.833521741292169, 1.096332248660826, 0.9362920073251572, 11.344985039003435, 86.78908455756404, 62.57376355509605, 68.58399960302538, 36.59150500451365, 38.176934872904134, 53.77458503169399, 58.3446365787137, 12.17658733167956, 0.21946975720986245, 0.12018945834208881, 0.0439345334175854, 0.10922924525314763, 0.029765155031195575, 0.018468351636622703, 0.10758348154805361, 0.23125784321417733, 0.14108554069553653, 0.21466169746652727, 0.1366777925361549, 0.13357680651449388, 0.18021305241892416, 0.5556224274539179, 7.390463198384932, 84.29544556525447, 63.81876307149088, 55.25385987374091, 52.511593603318744, 67.15115777907833, 65.6787274729821, 86.41921289505498, 8.06789477025309, 0.32138724480905845, 0.2003179727903297, 2.3347646142205885, 37.08997941786243, 72.64593555081275, 76.62461526932256, 80.33589916844522, 70.99584148776147, 75.85733690569478, 72.58098894549956, 76.75690112575408, 76.49896606322258, 69.77542738760673, 73.43902311017438, 73.74047294739755, 73.79070281982422, 73.29485247212072, 72.92302746926585, 65.65224362957862, 64.10474700312461, 61.89758223872032, 58.24661654810752, 55.29849252393169, 54.958238678593794, 54.2138316554408, 53.61371686381679, 53.93865777600197, 49.45944439980292, 53.76550866711525, 52.5489188778785, 52.14644447449715, 47.61337695583221, 50.09475069661295, 50.34837507432508, 50.725644326979115, 50.926281406033425, 50.63363336747693, 49.45446691205425, 47.80272153116042, 46.16245300539079, 47.336689041506865, 46.746042851478826, 48.6889849939654, 45.23862892581571, 49.075758149546964, 47.02363683331398, 50.323240526260875, 49.28813096015684, 51.27119110476587, 54.76021782044442, 53.237679235396854, 56.5600012963818, 54.73120797064997, 57.274257060020204, 58.86673150524017, 58.296061946499734, 61.34066058743385, 60.4222454563264, 60.803892074092744, 60.58738900769142, 56.728623990089666, 61.07493569774013, 59.966124796098285, 60.75530959713844, 63.258985934718964, 63.27229061434346, 53.37084370274698, 42.61776785696707, 48.6105768142208, 47.40669550434236, 60.98918091866278, 50.227828871819284, 43.69622745821553, 45.83148341025076, 54.179734491532855, 42.7853040541372, 38.98756719404651, 45.6066256953824, 61.71286998256561, 63.36465850953133, 60.986733359675256, 62.57738782513527, 60.80146804932625, 58.23327656715148, 60.66006268224409, 60.12805200392201, 58.67479032085788, 57.80488706404164, 57.81987836284023, 59.44161368954567, 57.98456691926526, 56.438541181625865, 55.40555754015523, 56.641194358948745, 53.21230542275214, 52.24695913253292, 47.52849294293312, 48.277661723475305, 46.61587507494035, 46.05175979675786, 43.14233779907227, 44.55597569865566, 46.32343884437315, 49.301906324202015, 46.30351712626796, 47.22700780437839, 47.16949016817155, 49.238830689461004, 52.67371300728091, 49.49292182922364, 52.77588290552939, 49.4451081368231, 51.126118321572584, 53.615674126532774, 55.650470333714644, 57.05269413609659, 59.801071459247225, 60.68837827251804, 62.57743881594751, 61.19308533207063, 62.43399381637574, 64.41948975286176, 62.87599002161334, 63.016410873782256, 64.11692596250965, 63.46235298341321, 64.07851811378234, 61.961026576257524, 66.84259276236257, 64.71451867011287, 71.12426773194345, 69.84466506588844, 72.26264153757404, 74.13364348873016, 77.1120717448573, 79.8497998329901, 77.47944093519642, 86.00900357769382, 84.36120017882317, 82.95494417990409, 32.93691896623181, 0.8755441154203109, 1.6976263253919541, 1.3001813811640586, 12.43417134208064, 99.0241103018484, 71.16968877853887, 81.09332453820014, 46.79943023189422, 53.77750327510219, 67.35889434814453, 74.73763358208441, 19.493279572456114, 0.32520368034320496, 0.21040914339884637, 0.18161263376955064, 0.20845776423811915, 0.16407044604420662, 0.11838160575397554], [0.03567619369395318, 0.03297242809147124, 0.007651655544196406, 0.0338359815519183, 0.03590790081709143, 0.10249487274596769, 0.07520233926874015, 0.11235165875405075, 3.987613406873519, 52.15322625252509, 46.288537594579886, 45.027734848760794, 31.253941712840913, 52.74349197264641, 54.59041449331469, 74.26155198004939, 10.614567149070002, 0.22756258746789348, 0.10132582257351569, 0.41264927675647123, 25.123679176453624, 53.862842282941266, 74.57419626174435, 68.45955848693848, 72.67299990500175, 72.75726026104343, 73.60650047179192, 70.48194823726531, 67.62108125994283, 69.78873206723121, 69.19881543805523, 65.04932826565158, 63.77200057429653, 62.45354683168473, 59.27165738997921, 55.23012168945805, 55.60911678498792, 51.153178753391394, 53.329246967069565, 48.22097955211517, 48.64861203778175, 48.40157724195912, 47.41257513723066, 48.184242633081254, 47.30259579996909, 50.338451477789114, 49.6365943262654, 44.69538457932011, 42.9154404517143, 44.52019976031396, 44.52589504180416, 44.52537728894142, 46.89808176409814, 45.771184813591745, 46.880270281145656, 45.24959587281751, 43.392286915932935, 42.982740479130904, 43.76659870147706, 41.05993186273883, 39.58523834905317, 41.833164384288175, 43.688555302158484, 45.17743995112758, 43.649974869143584, 42.128966008463216, 45.06524055234848, 47.896991775881865, 47.282262232995805, 48.70519222751741, 52.323206086312574, 52.339174055284076, 55.6778210209262, 54.99882344276675, 55.8227643659038, 53.05177457870976, 55.09767893821963, 55.04008285460934, 56.509285050053755, 57.943629141776796, 57.20605488746398, 56.180515904580396, 59.35462728623421, 54.74685430526734, 41.171040842610026, 42.57317835284818, 50.63415504270985, 55.87149589292465, 46.51319919093963, 44.29582057460662, 47.59759726062898, 51.91609151901738, 45.192658747396166, 44.3760173551498, 45.1955299223623, 58.812947965437374, 57.240756096378455, 55.79590397496378, 57.0825590625886, 52.6029848283337, 54.046648471586174, 55.78280325858824, 53.46765956571026, 52.73816147158223, 49.0997826668524, 48.65347185442525, 50.769229704333895, 50.90472798193655, 50.37154059256277, 49.70991126952633, 48.141327981025945, 47.49692570778632, 42.25524671616093, 42.01197739570372, 43.43175380460678, 39.448488835365545, 39.155162226769235, 39.1386608154543, 41.19216672835812, 40.81662724095006, 41.08195989362655, 42.59033087761172, 43.16593477802892, 42.81560436371834, 45.035630579917665, 44.506581291075676, 44.73943279635522, 43.93935165097637, 45.72128049788937, 45.048837200287856, 47.03766322905018, 48.42389160586942, 49.61312286315426, 53.04338462891118, 51.50480747222901, 50.81532147622878, 52.43104773183023, 51.410082232567575, 51.877318889864036, 53.96514946414579, 53.319048804621545, 53.50191754679526, 56.67199280954177, 56.59563995176747, 56.74280728063276, 56.56229196056243, 59.04473650840021, 61.11459086018225, 60.38167638163413, 62.06245514654345, 62.371996833432114, 62.83611128407141, 67.5174287057692, 71.0361477636522, 77.85208179104713, 75.03290960865637, 68.00081376106509, 6.3165128519458165, 0.8183403301142878, 1.5764790196572582, 0.4685417340407449, 11.698048364731575, 79.59188830467963, 55.27061623911704, 60.79163466730426, 37.29394658919304, 42.74645689995059, 42.22280871483588, 56.70713332391555, 13.351055768228347, 0.10906302715621649, 0.08050096341438832, 0.12721899686561478, 0.0358472956014016, 0.04339425756986584, 0.057518861947521094, 0.052382142823790355, 0.046179029309461196, 0.05861085133566972, 0.021993669929103028, 0.027388020591329665, 0.0861363061853955, 0.14954931072650418, 0.302304883277224, 6.570427485050694, 67.61950446713355, 50.778698305929865, 49.86574311410227, 33.95563302501556, 59.71255925393874, 59.22760132820376, 84.21367199190202, 11.863811650583822, 0.3766009788359366, 0.16609179967593762, 0.528213333699011, 24.837216715658865, 57.9027109761392, 74.546873031124, 72.62063626320132, 74.293229041561, 75.97585524282148, 75.61990799442415, 73.13729870703914, 69.38077419034897, 72.3659489231725, 72.0240359152517, 68.48172772315242, 66.90105176741078, 65.62592452572238, 63.27576191194596, 59.4346240258986, 58.40838293875418, 55.01161821426884, 56.35511629043087, 51.831933144600164, 51.48073980885168, 51.81591026244625, 49.75306126379198, 50.992153690707305, 51.85392195178617, 53.3850230709199, 51.98105381381128, 47.79780680133451, 46.25899038007183, 45.45564974507978, 47.58024469498665, 46.932367201774355, 49.31350477280156, 46.94442849005423, 48.470238331825506, 47.10785404328377, 46.2490197150938, 46.29269530696254, 44.99919568338702, 46.08806525507281, 42.198850877823375, 44.642201162153675, 44.97535943984986, 47.43985129940895, 46.56512744965092, 46.79564906704811, 46.722206607941665, 48.4877948607168, 50.40692037151706, 51.31259172193466, 55.91276707187776, 55.85674385870657, 58.29420666540823, 58.36454652970838, 56.888950870883086, 55.40573012444281, 57.82624044725972, 57.52730092694683, 59.09583714700515, 59.98299883257959, 59.6369908701989, 57.123371324231556, 60.60508281953874, 55.85909728080996, 41.714085148226836, 42.65668953618696, 52.6356856284603, 56.62362606294694, 46.37492779762515, 46.62588888599027, 45.853731093868134, 53.43381343349334, 45.83155793528403, 43.46320336864841, 46.19720912748768, 58.46182915472216, 60.34364900281353, 58.48484954526348, 60.68426370620728, 54.06789595080961, 56.22655668566304, 56.301034650494984, 57.48257413987191, 57.330378332445704, 53.66089905461958, 52.752615405667214, 52.789034612717174, 53.13656837709489, 53.45310757237097, 53.83202422049738, 50.83723575838151, 50.459201643543864, 46.07601573390346, 44.91300552122055, 45.73471853809972, 43.941355982134425, 43.073523736769154, 41.25291639758695, 44.078901736967026, 42.028470962278305, 42.914224516960886, 42.92578766422887, 46.30555675875756, 45.23880543247346, 46.00584453152072, 45.491304089946134, 47.62461062400572, 47.05820860401277, 46.75716277091734, 47.950779238054835, 47.00957121387605, 49.774402879899554, 51.76926935872724, 53.970613325795824, 53.677627963404504, 52.5172810400686, 53.48321568581366, 52.68810026107296, 55.98908855069069, 58.887151364357244, 57.75896787643433, 57.42255403149513, 59.48902337781845, 60.54434099505025, 60.55681805456839, 60.69024532072006, 60.90705433199483, 63.57887091175203, 61.97611201194025, 64.64876013417398, 63.8672161102295, 65.87551670689737, 68.59256605948173, 75.57119215688398, 80.11572084119244, 81.82178712660267, 78.51067912194037, 6.1025720738595535, 0.7967246383909257, 2.442504523261901, 0.38215205193527285, 13.81917299762849, 89.39819028300624, 62.12681339633081, 69.9750917188583, 39.88641362036429, 39.14352455446797, 56.43767826018795, 73.20824653871598, 20.229482958393714, 0.09072380155445108, 0.13829550976234098, 0.02879865850592333, 0.08718724858256117, 0.032805623937278025, 0.04860988374979747, 0.1250964047146901, 0.12332878706436004, 0.17184355716791846, 0.21990152436398694, 0.07661847577941033, 0.1737300640032176, 0.2871398050938883, 0.3692563406882748, 9.453853484122984, 80.83840185596098, 57.050101449412686, 58.82437382974933, 39.59725256889097, 72.63774564189296, 66.0346394200479, 92.86311011160575, 13.35824155038403, 0.4417437945883121, 0.2720718668593515, 0.6935822987748731, 27.953667294594553, 59.097947382157855, 74.54356255069857, 75.93247382871567, 80.11938433493339, 80.4874046387211, 77.43000338154455, 75.96818308676444, 69.92381849596578, 77.03968832569738, 74.48273443406629, 70.42065728095271, 69.09913232249599, 68.84249164212135, 65.48711969006446, 61.71377605007541, 61.802743250323886, 58.47771475392004, 59.37621601166264, 55.73290286525604, 54.17607099779191, 54.613493719408595, 52.85386354692521, 52.74698288209977, 54.46106256977205, 56.015270371590894, 56.15908015158869, 48.990964351161836, 47.19364804606284, 48.97927568804834, 49.57541711868779, 50.42399444887715, 52.07272744947865, 50.98233599816599, 51.05467234888385, 49.17551186776931, 47.63710729537472, 49.13930054633848, 47.68302648298202, 48.59948042900332, 45.63828706741334, 48.3325082255948, 48.75942291751985, 51.002634263807735, 48.680238108481134, 47.593204206035985, 50.44255902690273, 53.298632867874645, 51.706813458473455, 53.338695956814675, 58.18430577555011, 59.28399324417115, 61.86199457414689, 60.5305773981156, 60.59990529091128, 60.31900475102087, 57.69368786965647, 59.353729063464755, 61.07356286817982, 62.63453675854591, 63.417634041078635, 60.11558278914421, 64.31558224462694, 57.22726706535586, 42.34149179150982, 42.472589169779134, 54.57483483899025, 59.28440117066907, 47.88716623860021, 45.74294374835107, 48.76425527757215, 55.99620373018327, 48.08364952764204, 43.718969360474624, 45.88387058627221, 62.5940029851852, 61.16935107015795, 62.0433492814341, 62.54009000716671, 56.33189193664059, 59.587278750634965, 61.96898114296698, 59.940719604492195, 61.390917916451734, 56.40569917617306, 55.05202647178404, 54.51197493460871, 57.48648866530388, 55.009119664469075, 56.370672410534276, 55.30252864283901, 52.83871143094955, 48.367978219063055, 48.11942938835391, 49.46884239873579, 45.56387186050416, 45.41008749315816, 43.765139579772956, 46.32133253159062, 43.17729396204795, 44.4261020998801, 45.22634406243601, 48.92489987034952, 47.95330132207563, 49.97801703791465, 48.93491760376961, 51.44094736345353, 50.372309377116544, 50.657359784649266, 50.02315175148749, 50.423080536627005, 52.77183501951156, 55.80517253568096, 58.04609714015838, 57.789915377093905, 55.514936754780436, 57.05066234834733, 56.88408320949924, 58.6485339749244, 60.122952922698, 60.74183625559653, 58.645235261609486, 62.63791784163445, 63.2300074638859, 64.65740896040394, 62.725202345079, 64.05260301405384, 66.71852819381222, 66.70550592484014, 66.8694531533026, 67.58505821228027, 70.13924291056972, 73.47614442148517, 77.99957075426656, 84.96892436858147, 79.0048820741715, 73.66837978363037, 9.082246172812678, 1.0662580882349322, 5.03363843887083, 0.8644273829075598, 14.928623245608422, 99.85873576133483, 69.18162761196014, 81.09053181063744, 53.01966605647918, 68.57801406614243, 67.23653208824896, 83.30775353216356, 26.48431997145376, 0.19284660837823348, 0.1946491213335145, 0.23455025928635753, 0.1329471282060108, 0.18662539220625357, 0.10477245214485353], [0.004629654623943592, 0.01539223665942348, 0.017276734429141207, 0.04850882143082638, 0.05340550222524232, 0.021126228572440245, 0.12255981098860504, 0.23306463094007587, 2.9519473545012938, 49.67178190908125, 43.270516933933386, 43.14004713489164, 48.78124306278844, 51.12658900599326, 54.621730696770456, 76.33061793542679, 12.550129352077363, 0.47215347088152365, 0.5411417109351004, 0.3409384827940695, 13.828359188572055, 48.30366703771776, 60.79754960152411, 69.80246036283432, 69.23535623858052, 66.50275861063312, 60.79967160378734, 64.80473318407613, 70.84670512906968, 65.6017078122785, 64.44241992888912, 62.164656423753314, 59.52544650723858, 54.42060724381478, 54.093359977968284, 48.70847132898147, 51.13068396045316, 48.97916586168351, 48.487747792274725, 46.38477294675766, 46.41509286818966, 46.68823103750906, 48.066716655608154, 46.794699853466405, 48.97510620855516, 50.15828524866412, 47.5259316352106, 45.42511801565848, 43.58668350404309, 44.08254954122728, 44.66650416774135, 44.4289497406252, 45.58429956436158, 49.2020074782833, 51.673653741036695, 48.91775331189556, 45.431236913127286, 42.80642209514495, 43.23950667535105, 43.024478420134514, 41.09426829122728, 42.02853372020107, 43.23232089319537, 42.32084051255257, 42.18693863961005, 43.64117699284708, 44.699585437774665, 44.27007805916571, 48.28460431868031, 49.30205929663874, 47.9297161102295, 50.6122289934466, 53.79156889454011, 51.8359653411373, 52.12884479953397, 53.58824499191777, 55.90716592727169, 53.2512741704141, 57.06597135912988, 54.64956383551321, 56.02791217065627, 57.79149609227335, 58.69593581845684, 57.26128970423053, 49.22295685737364, 49.57196935530632, 53.27358068958406, 59.30995148997153, 41.36345663378316, 27.75024337153281, 42.312254444245376, 51.82637906843617, 49.726483283504365, 48.235676673150834, 48.99374923398418, 59.76251848282353, 57.31601853524485, 54.54609171036751, 56.21516220031246, 54.0248675500193, 53.78157077297088, 52.79316486850862, 53.01476701613396, 51.705048391895915, 50.57768075696884, 49.165431376426454, 48.80826427090553, 50.176249704053326, 48.26015618539626, 48.57824863926057, 48.444425213721495, 44.00476501834008, 42.10551807957311, 43.314839716880556, 41.42419845827165, 39.74492980587868, 40.163701657325994, 38.29551204558342, 39.73453160255186, 41.896008599189024, 41.68824457353161, 41.98157118212792, 42.3540472984314, 42.48635276671379, 45.25694247215025, 45.498984090743534, 41.79071649428337, 43.299848418081964, 43.66784518764865, 43.54638899526289, 44.27660488313244, 44.02177241540725, 46.52084389040547, 46.958039114552165, 47.53239962362474, 50.13750453149119, 47.95225404923963, 47.365036010742195, 47.30733402313725, 48.4012399181243, 51.36224108357584, 51.829920968701764, 55.027554804278964, 55.86172134645524, 56.85558719019736, 55.95811751581008, 55.20777986895654, 59.08764331571518, 56.65324780248827, 55.40099582364483, 57.869449277077955, 56.96717077685941, 62.64138913923695, 70.44803542475547, 77.08349335578181, 74.55481190835276, 52.21150090617519, 1.8514480778286535, 0.2575084741317457, 1.536589863319551, 0.17256856745769902, 20.014084039195893, 79.50249748845255, 58.67382934016567, 57.2698796949079, 43.037594825990745, 48.51677725392003, 38.86508726304577, 59.703596638095, 19.350640619954756, 0.04261799982839054, 0.04900706969501992, 0.03275858613872721, 0.010254580993205309, 0.04063417301363042, 0.04998866581327973, 0.010572924042090533, 0.07274433084192776, 0.09471816866989098, 0.05120709035245161, 0.02658666580945494, 0.1119478001830078, 0.13919383978411076, 0.3025319823814977, 6.450729004798397, 64.51113593193793, 47.26996560250559, 42.43410679601854, 49.65247208072294, 60.41296905086887, 58.126635166906546, 85.34285960658904, 14.113300750332495, 0.48560842631324647, 0.2909960159130635, 0.2779641555201623, 16.004487218395358, 50.38265658963112, 62.11202998315135, 69.70296552104335, 69.5509736768661, 67.934094244434, 62.58210251408239, 66.44053413021949, 72.54348324191186, 68.19726959351571, 67.30040396413496, 64.26837259723295, 61.38941172630557, 57.478565477555804, 57.11240829959993, 51.99658247732347, 52.42929050999304, 51.71643895487632, 51.14917793581563, 48.34364775688418, 48.95016777899958, 50.433584643948464, 48.72149752032373, 51.521771723224276, 53.39837481898647, 53.848274600121286, 49.078162562462595, 48.301348916945926, 48.895172226813536, 47.468033529097035, 48.441377532097604, 47.469241619110115, 49.785118795210316, 52.13017056065222, 54.7151223305733, 51.88277098440355, 47.17917057775682, 44.101898593287316, 45.420038546285326, 46.88031734958772, 43.882151726753484, 44.77518520047588, 45.832016852594194, 44.62493881102532, 44.640702816747854, 45.26480290197557, 47.30204666814497, 46.278712057298236, 48.923840830402995, 51.268774924739716, 51.486242894203436, 52.932958141449966, 56.57207827414236, 57.22792994591498, 54.46039968921293, 57.07345131904849, 57.01056788044592, 55.80215623301845, 56.30474913504816, 57.1576802961288, 58.649016426455596, 58.09527189500871, 61.9609598959646, 59.20734620863392, 51.27330918465891, 50.7309591385626, 54.36094407112368, 59.72092959188647, 42.64918211967715, 28.347394812491636, 43.69464674303609, 53.586201437057994, 52.17109657103016, 50.053663869057935, 47.30200352207307, 61.357789577976355, 57.88874733832575, 56.629642978791274, 58.369508327976355, 57.7234939605959, 56.09467091098909, 56.73646088569396, 55.20104908174085, 53.838986427553245, 53.84320689785866, 52.31360804650092, 52.636572084119244, 53.03182540401336, 50.672868836310606, 50.24127475676998, 49.896168939528934, 46.05674905161704, 43.86006878268334, 46.161974476229766, 43.402747877182506, 43.30665373033093, 42.51783763208697, 40.806919374773585, 42.79224272697203, 44.43792412357946, 43.03443339563186, 45.79440524501186, 45.72662668843424, 45.77520916538854, 48.303384627065356, 46.93717210523544, 44.188382933216715, 45.03938821054275, 48.43855734794371, 46.48737038335493, 45.29111416109147, 46.267129298179384, 48.75459055746756, 48.98790098005726, 49.83961620638448, 51.69379118950137, 50.89656552960796, 50.274787487522254, 50.64496117253458, 51.32581795415571, 53.70251540214785, 56.18867443453882, 57.404346389155236, 59.015365800549915, 58.59042406082154, 59.28931982286515, 58.93037588365617, 60.68491481965589, 59.070761434493534, 58.61466823085662, 60.53369176003241, 58.85397987980997, 63.97580300607989, 75.73615135685091, 78.13143299471948, 81.48036049258324, 63.29727218997095, 1.5880934028856217, 0.43724272159799454, 1.7626421850535179, 0.16790946585036096, 21.913784011717766, 89.70608065205236, 63.79901786004344, 67.35237536891815, 47.66679571520898, 51.73215196978662, 49.33446199663224, 69.25815305402203, 27.83366434035763, 0.0328073016698322, 0.06657850282687335, 0.08068595832634358, 0.035051261300161, 0.09152560449776151, 0.04743747045135787, 0.1670354974245833, 0.15472694660627073, 0.29125265536769746, 0.14375627641716313, 0.1089882186704105, 0.24260521415741215, 0.28995085747972615, 0.477242439744934, 9.807481631155937, 80.41193823660575, 55.72323814515145, 58.75093137064288, 60.14591447768673, 72.40005785419096, 64.25571118631672, 94.66285828621157, 15.95356700881835, 0.8600340831664302, 0.7136732916678152, 0.3965217776356205, 19.243632478098718, 52.63607786547754, 64.72890592390492, 69.50875328433129, 73.7483569114439, 70.58510657279723, 67.05053329467773, 70.53112691448581, 74.33604563436201, 71.74802657096618, 70.181565284729, 68.66087021366243, 64.60028356121433, 61.46902407369306, 60.52171284152616, 55.37701445241129, 56.877972156770774, 54.53279487548336, 54.29744482040406, 50.45143535060268, 51.7645154460784, 53.97994856680594, 52.22295422707835, 52.82138632189844, 54.30148878405171, 57.35340656772737, 53.024380745426306, 51.14292175539079, 50.75658790526852, 49.35417190674813, 51.7714854978746, 50.88823833773213, 52.806716657453975, 55.93152776841195, 57.75921106338502, 56.29798304650092, 49.059441089630134, 46.05660784629084, 49.419922597946666, 51.27611367933212, 46.20969010937599, 47.86853498028171, 49.23505736935524, 47.07867160920174, 48.06762272311796, 48.24031683706468, 51.714246349949995, 49.37419168410763, 53.31138449330484, 54.71598525201121, 55.27142032500237, 56.43603870945593, 59.85751044365668, 59.721843504136615, 58.29257495941655, 60.16226291656495, 61.044478493352095, 57.65157338111632, 60.25684302853, 61.628068339440134, 62.17263060231363, 61.7429506394171, 64.04109870233845, 61.069169813586825, 53.56747996422553, 51.56005405610608, 56.290287356222834, 62.014578696220156, 43.79335711079259, 31.42837735914415, 45.85038531211115, 56.45621930399249, 52.837205240803385, 51.657270000826934, 49.384107435903246, 62.80252010591569, 60.79911462722286, 58.35207339256041, 62.55359080529983, 57.40898655306909, 58.526489427012784, 59.79201862888952, 58.22432179604807, 57.37560326053251, 56.58953282140917, 55.63610269177345, 55.92613450942501, 56.65827628104918, 53.92385867334182, 53.90370945776663, 52.63665053152269, 49.13275411052089, 46.90318476769232, 48.083135697149466, 45.904627769224106, 45.93008002927227, 45.883160637271025, 43.86325766963344, 46.328169222800966, 46.10217794295281, 44.9403718979128, 47.17341646071404, 46.41058606486167, 48.36916277485509, 49.81221452836068, 49.14352886138424, 46.39537511333343, 47.11018000879596, 51.01600170135499, 49.366766637371434, 49.10021804994153, 49.122818746874415, 50.80791211897328, 50.812732711915054, 52.94528615090155, 56.848428864632886, 55.741304582165135, 53.287760057756984, 53.83924922635479, 53.716883044089045, 57.69802601106706, 60.07559814760762, 61.13610113820722, 63.38689050366802, 63.05790955020536, 62.39608803103047, 60.71172814215384, 64.73214187929707, 61.693442483102125, 60.86412399045883, 64.10318197742586, 63.78437172982001, 68.09094982762491, 77.65855989148541, 85.2638630713186, 81.49064494717507, 58.96934070894795, 2.5489794679226416, 0.6426705468085505, 4.809482337967043, 0.2201628216332005, 25.40431103398723, 98.5565088641259, 70.3397152500768, 77.11520179625481, 59.72024317710631, 68.3200397799092, 62.65921631167012, 88.525282490638, 35.33351067573794, 0.07688431595001491, 0.16713582429914706, 0.22335092717361069, 0.1455724870245303, 0.18847117380749798, 0.1041486727133874], [0.10342985241403503, 0.07581245169163713, 0.06434053017367279, 0.03889952778756138, 0.06944478249117252, 0.03179162996070039, 0.0703411819713731, 0.1432218075159096, 3.7072117434393976, 47.63349871481619, 48.022236977854085, 40.89856555384975, 28.148024659002985, 52.76636331312118, 49.652017085782944, 79.65898436884727, 15.608793612449402, 0.5798420826754263, 0.840530832928996, 0.11761380945362392, 5.171319515474382, 38.78011695800289, 56.035321527911776, 56.408538972177816, 64.5750391867853, 58.982174704151774, 61.21574094218593, 66.5036686005131, 66.24013239337553, 60.96408559430031, 61.33872293656873, 55.88851505710233, 54.36285818776777, 50.82935179433515, 50.693767224588704, 48.70731422978063, 48.40977891798943, 48.00554337040071, 48.11489905080488, 48.49266644447081, 47.27495485736478, 48.27103684025426, 50.22403986223283, 50.02767424429617, 50.173182410578576, 48.4581260527334, 45.865831605849735, 43.77161933529762, 43.43128704255627, 43.48179932563536, 44.92870284665016, 51.961916569740545, 58.29331628737911, 58.725467343484205, 60.244640534923924, 54.40320368736021, 50.268386179401034, 42.683385187579745, 41.999872961351954, 41.667091231192316, 43.89156933753721, 46.00658193711312, 41.70711509643063, 43.53046809473346, 41.42296291166737, 43.948537841919936, 45.23983701582878, 43.620737521879136, 47.181335726091945, 49.91774982021701, 48.40840608842912, 47.30862056055377, 49.366495993829545, 53.284155399568625, 51.00701947366038, 52.14277313601587, 53.79563639240881, 53.81371067416284, 52.87182015757407, 51.13803055978591, 53.11101413542225, 53.67781623717278, 55.732353733431914, 58.585999627267164, 54.53482666323262, 48.709353862270234, 55.42193343562465, 52.522611541132775, 26.25942107169859, 18.671762674085556, 30.070197851427142, 53.98108997652608, 54.669316891700994, 47.01642359456709, 49.77641505579795, 57.23058146815146, 56.929441498171904, 55.94838219304239, 54.20961118513539, 53.52786010311496, 51.58059943106867, 52.54638110437701, 53.678608555947584, 51.683098808411636, 51.39605975920155, 49.646380639845326, 49.85619998747303, 48.70504709982103, 46.391444898420765, 47.36672655228646, 44.78738377171178, 42.36420231480753, 42.49584098016062, 41.325346885188935, 40.59637831103417, 41.12248189987675, 38.81815218156384, 38.69744908425116, 41.595551121619444, 44.00358438491822, 43.54406695212088, 42.15365340632778, 43.260326616225704, 43.364532224593624, 43.50345080898654, 43.7746395603303, 41.73525810241699, 42.01038099104359, 44.421524693889005, 44.279487825209095, 45.49937240539059, 43.94209338772682, 44.67710241194695, 46.45721520147016, 46.720555290099114, 46.11753794454759, 48.03189385321833, 47.31189573964765, 48.700967834841826, 44.257365657437234, 46.59340773859332, 49.24616944405341, 51.449337313252116, 51.94312449424498, 53.322041573063025, 52.98449416314402, 55.32948317066316, 55.16123310212166, 56.04328393936158, 52.1884334471918, 53.70049145913894, 54.583063971611764, 61.22968104577834, 65.97295622671804, 73.27697430887531, 73.38852651657598, 51.75552929601362, 1.772030868357228, 0.47700559600226344, 1.0197157953535358, 0.2246034349645338, 28.611401704049882, 78.30063619921285, 55.40711472111364, 54.422019297076815, 41.41750689475767, 26.37916514950414, 44.5691313282136, 66.88329127527052, 30.68840849784113, 0.10808477118130654, 0.02788845603654702, 0.008721483923915413, 0.06022974833725922, 0.02231216906840282, 0.06753303305876833, 0.08029618811222815, 0.10621497272363595, 0.12432500780109437, 0.08251458721896333, 0.0348503279289411, 0.023030123688400756, 0.06484663849996944, 0.19989371329786318, 5.48616522742856, 61.860472694520034, 54.670709333112164, 48.556671680942664, 35.08270648217971, 62.149131682611284, 54.19908354359289, 88.53981879449661, 17.377431508033506, 0.4636560542689216, 1.7619466997923392, 0.23690026463760486, 6.332827460381293, 39.9775851926496, 58.38412307923841, 58.81629766956453, 65.22369723166189, 61.10094493435275, 63.940070213810095, 69.16609502607777, 69.36593978635727, 63.213274632730794, 63.4128644389491, 59.24768778585619, 54.4544808326229, 51.84362180771367, 50.2415846240136, 52.05513169688564, 52.15582286157916, 49.43393330420218, 51.045356719724595, 51.919605962691776, 50.07626064362065, 49.56772927315005, 51.93566022380706, 52.294498259021395, 55.03581531586186, 50.9317962584957, 48.027869501421534, 47.04968137125815, 46.582632987729966, 45.94857792700491, 47.152635743541104, 55.18261001956079, 61.06132115087202, 61.22371512074625, 63.59175589776809, 56.621315786915446, 53.91788098119921, 44.36334417712304, 44.66838298305389, 45.34206574962985, 47.61360837567238, 47.24756102408133, 45.79378551052463, 45.42690661645705, 45.13707876205445, 46.554093822356194, 49.779843207328554, 45.05880394289571, 49.32944528518185, 49.91828326256045, 51.943552032593765, 49.38349554615636, 51.802640884153305, 55.13224678654825, 53.702958629977324, 54.543055795854144, 54.712615936033195, 55.9385488110204, 57.35031574003158, 53.937096672673384, 57.01834201812745, 54.83693938101492, 57.08991742903187, 60.58172902753277, 57.44495076517905, 50.82782599233812, 57.0940790637847, 51.61122137500394, 29.631251288998513, 21.955088530817342, 32.04048087519984, 54.59223839544482, 55.41113122817009, 47.45699597943214, 51.87351419079689, 59.026999550481, 57.6283960957681, 59.01051775101693, 55.92992744138164, 54.51559135990759, 54.682437219927394, 56.82403172216108, 54.71145491446219, 53.74208819481635, 55.92775444830618, 52.3582406966917, 53.34213195308563, 50.32606463278494, 49.96595967200495, 49.72627147551506, 45.295742557894805, 45.789706245545425, 45.577553087665194, 44.43971272437803, 43.701267703886955, 42.61180977667532, 40.27552843093872, 40.946336100178385, 44.508773896002005, 46.14973668129214, 45.136682602667044, 45.41774788210469, 45.58758651056598, 46.42575779268819, 47.18019039400163, 46.82275264493881, 42.973040457694765, 44.09490108489991, 45.17639660066174, 45.94175300290508, 47.31910505602437, 46.474983538350756, 48.66079884190714, 46.830228682487245, 49.627408135321836, 47.70704707791729, 50.288174536920366, 49.70472197378836, 49.84753939413255, 49.379722226050596, 49.4295088706478, 52.240142053173436, 53.0106093037513, 54.67872273537421, 53.68850861826251, 54.27722500216577, 58.65464502765287, 58.33649373823597, 60.44682302782613, 55.997337295163064, 57.78767962609568, 57.965755231918834, 66.14148478354177, 70.72726111258231, 76.50717950636341, 81.02451047589703, 61.88690554711127, 2.0431059935400566, 0.5835661280059046, 1.2468747770594013, 0.13175725576377686, 31.103716896426295, 87.84006795575543, 62.09772117676274, 65.69382075340518, 49.358349230981645, 35.90504707828645, 56.515039167096546, 77.70841321637555, 41.47218473495976, 0.19342751752945686, 0.008243221936056451, 0.07568046240316284, 0.04221386546569486, 0.00873895838946825, 0.025077357685433763, 0.15809954144060612, 0.15068871329628653, 0.1632012580070765, 0.12749059035653068, 0.13228069299892073, 0.1492862054897893, 0.2569478816322742, 0.46599197892412064, 8.242319630038354, 80.45304467601161, 60.971777362208215, 59.86031886070006, 37.99075565030498, 72.05238680685721, 62.22929316182291, 98.84386170294978, 20.341490161034372, 1.1106940070467612, 2.966427519436806, 0.3353189827213365, 9.114565522440019, 42.299710704434304, 62.32980389748851, 62.83686830151466, 68.68118024641468, 62.227269218813994, 66.1213630245578, 71.44353297448927, 73.77441713886877, 63.85710423992526, 66.01375672125047, 62.92356837180353, 59.8096614499246, 55.072748353404386, 56.693001024184696, 55.78709433155676, 55.402819725774954, 53.77857408215923, 54.5329596150306, 56.94473089710359, 53.644801647432395, 52.57120186282743, 54.3617207004178, 56.53213677867767, 57.50271158833658, 53.08386348908948, 50.80442905426026, 50.67659901034448, 49.30731135029947, 48.760854582632746, 48.569313480008034, 58.708828649213245, 66.59818203218522, 61.928274785318685, 64.9191761785938, 60.051059799809615, 56.550540539526175, 45.79642134328043, 47.98362516587781, 48.665403704489435, 49.8619148808141, 49.374603532975726, 47.11436517776982, 48.16255192602835, 45.874460820228826, 49.217971524884625, 49.6037091747407, 48.7243216268478, 51.25480344218593, 54.588873001836966, 53.9243568143537, 54.257628840784875, 54.37416638097456, 60.924704997770256, 57.317701232048776, 57.17244801982757, 60.17253168167607, 58.33471690454791, 62.15166161137243, 55.57219943692608, 58.290315674197295, 59.15067188201412, 58.43236038761755, 64.84184665064659, 58.02434759755289, 54.4307348035997, 59.820950031280525, 54.8759473523786, 33.18337325126895, 27.060147446970788, 36.24943510178597, 56.526292447120916, 60.08139933309248, 48.479420600398896, 53.22888528147052, 60.97766876220704, 60.821844762371434, 60.806527906848544, 57.88589577521048, 57.39717237411007, 57.403722732297844, 60.988408211738836, 59.78138508335237, 57.31929371433874, 56.77373909181165, 55.2663016319275, 57.51900903640255, 53.46615729793426, 53.000191488573634, 51.81187806590911, 48.186184206316554, 47.96153829943749, 47.162080810916045, 46.312142418276885, 45.44324328822475, 45.59552931016492, 41.67806994530463, 43.18992791637298, 47.38269844362813, 49.52885074000205, 49.86133044765842, 46.796994440017215, 47.21675472874796, 48.56350837215301, 50.45655012130738, 49.502759133615804, 46.692149485311205, 45.98067860449515, 48.12086497583697, 49.970741041245006, 51.14338459507112, 48.57140410330988, 52.62426368651852, 53.00872264369842, 54.38789075420749, 51.8719962335402, 55.4386309654482, 53.487793091804754, 53.605632858891646, 53.46435300765499, 52.181204518964215, 56.158178006449056, 56.94947304264192, 59.21703446295954, 59.15331555951027, 58.90867340949274, 62.59806263831354, 62.61974157825593, 63.60782977073424, 58.5270542483176, 59.784723020369015, 60.970400610277736, 70.17481880803263, 73.06028689107588, 79.39219259446668, 79.9697223786385, 58.144481951190585, 3.0910434261445077, 0.7991957928865188, 4.1640607387788835, 0.4066403895135849, 34.791796053609545, 95.99058058954056, 67.8708734819966, 74.25544877206126, 58.08106899261475, 39.520876176895634, 67.29989405601256, 91.38078366556476, 48.68143835375386, 0.359963295801032, 0.11379048678903811, 0.09206202692322193, 0.18134358369054335, 0.14786425437177383, 0.08078938019612143], [0.041501495626664935, 0.05786187398517805, 0.05013521077231534, 0.0577341326542439, 0.09827621806893619, 0.03008966413026135, 0.11213102543185796, 0.11141071126105324, 1.5555562391396494, 45.3648704098117, 45.13665122370566, 43.36898803710938, 27.66437484372047, 44.94539253173336, 41.28352265204153, 80.48290960250363, 20.72214638033221, 0.5001281826726852, 1.9266661448824791, 0.2251687772091358, 0.41573345480907353, 20.101186152427427, 55.031830187766786, 66.32179614036315, 72.19829113252702, 69.80174649146296, 73.38985227769422, 63.98996668477213, 61.14045889146867, 55.04947693117204, 53.37938662498228, 48.1539580129808, 49.73317876938851, 48.132220237485825, 47.38412618637086, 46.214377341731904, 46.142633268910075, 47.774515767251295, 47.181778953921416, 48.6168251499053, 48.306969673402854, 49.648926258087165, 51.083646897346746, 52.143388948132916, 49.95534181594849, 47.14443014514062, 45.402391802880075, 44.76486936692269, 42.62076847014889, 45.40123078130907, 54.67209000741282, 54.504240020628906, 57.110843273901175, 60.52019488426947, 61.41209479301207, 58.54290062381376, 53.84632518214565, 45.91950139691753, 43.164122643009314, 43.28009536189418, 45.068739306542184, 44.05272383843699, 41.87962878134943, 41.39955812884916, 43.17719198042347, 41.71744661946451, 45.31969647253714, 42.75460758516866, 42.44895688949093, 47.08033077178463, 47.08219781998665, 48.02078570089033, 46.59977766775316, 50.91351016875237, 50.20058801097255, 49.63626092480075, 51.4970019555861, 52.274553006695164, 51.85861702888243, 53.30317105016401, 54.13159132003785, 55.599173576601096, 56.30377638724543, 56.618856460817405, 50.43656172290925, 47.93408563060146, 56.12738347822621, 51.16176089932842, 41.43841705014629, 42.60537316722255, 43.85964516670474, 52.34217859083607, 52.16163973654471, 50.89899347674463, 53.89579803712907, 58.96022119829732, 55.950676779593195, 52.78543779926916, 50.59678662207819, 53.94848331328362, 52.2646450996399, 52.88717231442852, 53.796342419039824, 47.87310061916229, 47.574145409368704, 49.57589957021898, 46.60229975177396, 45.24462622980918, 45.18628489586615, 44.666555158553585, 45.0106607714007, 43.0986661295737, 41.539908378354966, 40.56143783753918, 40.70280005854946, 39.61116521589218, 39.479777582230106, 41.06028879842451, 44.4213560319716, 42.77408999781455, 43.5625962288149, 42.7293396765186, 44.370624096162864, 45.95001743685815, 47.9535327419158, 42.73847095427975, 41.870297462709495, 42.41738180960379, 40.835023157058224, 41.330065496506236, 43.74768111013597, 43.03072675581902, 44.19716119766236, 43.33796601141653, 45.58549588726413, 44.261127210432484, 45.27569140157392, 46.45607379175002, 46.76740015706709, 45.51859201923494, 45.743532103876916, 48.1147539231085, 48.54534387588502, 47.56703807461647, 48.554392783872544, 48.70292509755781, 48.76907194814375, 48.34466757312898, 52.33562431027813, 50.79414852203862, 56.547437944719874, 59.194614195054584, 67.9039155283282, 68.3402007625949, 74.65899790486982, 72.00782083695935, 47.32767543485088, 1.7001469385239387, 0.37899570840020336, 1.085690368087061, 0.21581798461416077, 35.629343678874356, 76.21994433864471, 54.16969322389173, 51.43342425746303, 42.13922300646382, 26.371787171210013, 37.72884330441875, 61.184805208636874, 34.22528028488159, 0.23579921242931198, 0.05558194269636466, 0.040214261070134184, 0.03608344220406106, 0.01682652179301987, 0.03985275950042471, 0.006297977224382903, 0.07028783926920545, 0.036112358192763025, 0.0429551244803494, 0.05711627508243246, 0.029297082970339446, 0.021942238616306457, 0.15519239098554657, 2.624336043673177, 57.603700853163204, 52.8763779517143, 47.4311161810352, 29.71488210462755, 56.31452760388775, 46.95530130017189, 89.28012694081953, 22.691156594983994, 0.5137603495630526, 2.835781704033575, 0.3424295043993381, 0.6428881157790461, 17.739195631396388, 57.68484684728808, 70.27315262825259, 75.30479261952063, 72.07577197782456, 77.20622431847357, 68.5638778440414, 63.71872302024596, 58.17945380364695, 55.98072213511313, 49.609118123208326, 51.783970402133086, 50.79553704107962, 49.997805395433986, 46.589226491989635, 49.40371144202448, 49.959260263750636, 50.457256147938395, 50.7862449461414, 52.175764191535215, 51.66564033877466, 52.68702945401592, 55.38016411565966, 54.29349107127036, 49.766824860726636, 48.625807377599905, 46.01365789290398, 43.60685233146914, 48.94492357007919, 55.74379528722456, 59.37068939208985, 62.51808551050002, 61.22238151488766, 61.080952613584465, 60.34179372172202, 55.339316552685155, 47.50932824227118, 44.46297237949987, 45.94925649704472, 47.082531221451305, 45.29903342646938, 44.718934489834695, 44.09657593696348, 46.3783912504873, 44.6973692986273, 46.895567524817686, 44.28335920456917, 46.28564288539272, 49.817454814910896, 52.20591545104981, 53.30989399263936, 50.018805765336566, 52.69631762658396, 51.864775150052964, 52.09977611418694, 53.72860308616392, 55.33655912645402, 55.106382677632, 53.58854309205086, 55.91961160782845, 56.54528848586544, 58.48559871796639, 59.63939528311453, 55.05093997524631, 48.9681165449081, 57.84719374872024, 54.2744008956417, 42.48200285819269, 44.737330405942856, 44.596383956170854, 53.74855226086032, 55.23395776748658, 53.26841100569695, 56.41874497936618, 60.01271863137523, 57.633475565141254, 53.59594068219585, 53.28631662553357, 55.27376590236541, 53.23507085923226, 55.74084566485498, 55.94778991514637, 53.15976527429397, 51.50607439779466, 51.05040481013637, 48.66111655389109, 48.01355285029258, 46.81000494187879, 49.298874332058816, 47.1416413399481, 45.93468881422474, 44.93087191735545, 42.544078288539765, 43.522466459581935, 41.98592109064902, 42.52519992090041, 43.189331716106786, 48.233891994722434, 45.47190012470369, 45.358516170132546, 45.72746607565111, 47.15164338388751, 48.39279897751347, 49.31828614204161, 46.686105112875666, 44.55640323700444, 45.09486621425998, 44.695768971597, 43.929733999313854, 45.264438121549546, 46.11995020220357, 47.125944014518495, 46.16913672416441, 48.4823388438071, 48.200532236406886, 49.34900222286102, 50.38004036872618, 49.90850087135069, 47.712220684174575, 50.52223413221298, 51.10974242610317, 52.5077183015885, 50.63810879184354, 51.24732348226732, 52.3291955455657, 52.66453858344786, 52.60993526827905, 54.45814432636384, 54.21308640510806, 59.76265576577956, 62.993629747821444, 71.61961601626489, 70.26762208630963, 78.68555407370292, 75.86100824417608, 52.94987140163299, 1.8104716895088073, 0.7380445710112973, 2.020951098492069, 0.2928350252970573, 40.07214961513397, 81.83654308319092, 61.42379522323609, 61.90594473192769, 51.15106459586851, 30.918353526822983, 49.96838369677144, 73.0295119747039, 42.20247907023276, 0.419542474612113, 0.048976353399695895, 0.06869495861352452, 0.026649255192868655, 0.07191249725198554, 0.043350716962689356, 0.15320932642827112, 0.20496248808358947, 0.08546446239756, 0.17018854678157838, 0.17480041140750532, 0.07938923194043099, 0.21634952705954352, 0.27906787371443165, 4.473443079379297, 75.30530252764302, 61.806414588805175, 59.155731739536414, 37.78208947950794, 66.58752103005686, 54.31332649723176, 99.69200365005001, 24.973740693061586, 0.9097311261200136, 5.283844961274055, 0.49939172702931595, 1.7711898876774697, 22.13971253364317, 62.118141035879816, 73.00793893875615, 81.91828527758199, 74.66543843669277, 80.051543020433, 71.21406647466844, 66.42311096191406, 60.3853084964137, 59.70682082637664, 52.72353887557984, 53.9465025163466, 52.90738428792646, 53.45717114786948, 51.3913333031439, 52.659247306085405, 54.047719278643214, 53.95273908492058, 53.68048737126013, 54.3201082752597, 54.64920297745736, 56.55045424738238, 57.28095254590435, 58.38665693036972, 52.09093116944837, 49.78530314660842, 49.826319371500325, 45.26801140077653, 50.74369507451212, 59.053930544084125, 59.68453391905754, 64.95589348577684, 64.76100660139515, 66.26546305994835, 63.99835663457071, 60.20790361589002, 50.601132608229115, 48.66345036414362, 50.220035122286895, 50.19964271976102, 48.34174148498043, 47.20519550385014, 47.28925581901304, 49.44250368302869, 46.44202778416295, 49.803106784820564, 46.55059114579232, 46.47317924807149, 51.360005332577614, 53.68905775008663, 55.09650222716793, 53.328427191703554, 55.281387067610225, 55.32259548864057, 53.06857016778762, 56.00559388437579, 59.83620020651049, 56.76384295186689, 57.3206743886394, 59.88578288785873, 58.91065812879994, 60.2659821510315, 62.16145969206288, 56.585033862821525, 53.09948628948581, 60.3368515353049, 54.72603436439268, 43.30167624258226, 47.05893816486482, 46.74544272884246, 53.682083775920255, 57.28762841993763, 55.156522335544715, 57.904213243915194, 63.962710134444706, 61.107754168971894, 57.092819982959384, 55.75726078402612, 58.055212728438846, 56.24228146768386, 58.846146906575854, 59.95709157759144, 54.51014711010841, 52.75812633575932, 55.18659122528569, 50.3024794209388, 51.464477662117254, 49.114640605065134, 51.865520400385705, 49.20808715205039, 47.352147102355964, 46.598357769750784, 43.8583037161058, 46.846934057051136, 43.451993234695934, 46.81517854813607, 45.16589249334028, 50.50369308840845, 47.808044187484256, 48.90031053173927, 48.3234553952371, 48.60132786535448, 50.764487558795565, 52.13543045905329, 47.95430152646957, 47.13325923488986, 46.06091853111021, 45.97758777679936, 46.9993063711351, 49.6176375112226, 49.32129459996378, 50.31451325262747, 48.388927598153394, 51.931478977203376, 51.385763537499216, 52.96008917593187, 54.14483324173958, 54.601318682393725, 51.338236178121264, 53.23585141089655, 55.40819337291103, 56.59056048239432, 54.50161595498362, 54.50824476057484, 56.05406653496527, 56.22880420377178, 55.469598077958636, 58.43676520932106, 55.84651823966734, 62.77317293228642, 65.9346503596152, 74.88931948138823, 73.12742217894524, 83.76742393739762, 77.43958180950534, 57.39164575453728, 2.4674439334100295, 0.8654764330675526, 4.3213487632813, 0.34855339676141744, 44.28468888805759, 91.35417430631577, 68.8408128676876, 69.57767717299923, 61.646801579383116, 40.131302879702666, 60.003673645757864, 84.52442569117393, 54.25499300802908, 0.8266471134078118, 0.13024461515728505, 0.12783477067827217, 0.14138927923575526, 0.12129804119467737, 0.1459105463037568], [0.06251816404983401, 0.08410402813986426, 0.04803280886863509, 0.031375554202484994, 0.05911716650570593, 0.07263458874677459, 0.1193813581560408, 0.25943313214567404, 4.152017591461059, 46.36839705128824, 40.517640652195105, 43.210528204517985, 26.273174862707815, 46.7535424232483, 44.840041591275124, 75.85821551661338, 35.77826822957685, 0.0812546866795709, 1.070312715826496, 0.11255817307579903, 0.24473057188574346, 4.361987460044123, 50.449717352467204, 68.70620496811406, 69.51906911788448, 65.8128607657648, 60.65718366253761, 57.69547647045505, 53.16482120944608, 51.94346966282014, 49.504214332949736, 48.94786534770843, 47.359026939638206, 48.64100656201763, 48.734111862797896, 50.247436800310695, 52.184550300721206, 49.841577391470636, 51.84757163447719, 53.48571423561343, 50.5535150343372, 52.581301966021144, 50.91789145623484, 51.423951733496885, 48.29157044810634, 45.037164226655044, 42.83495341577838, 43.08099585194742, 47.36543609249977, 53.75368272104571, 56.610831291444846, 59.430179980493364, 60.662047401551284, 55.9781765168713, 61.314200278251406, 59.60347421707646, 54.14519802216561, 48.40355411652596, 44.45652008056641, 41.124780408797726, 44.847207761579945, 45.78435221026021, 43.84042555286039, 43.10047434222314, 45.80085754394532, 41.736387745026626, 43.86330081570534, 46.77700211924892, 42.342652813080825, 44.56548352395335, 47.10022503329862, 46.469562822772616, 47.53124252442391, 48.8483508940666, 46.32659635236187, 49.65888515595467, 50.65177040715372, 50.920805777272875, 51.21597197748, 51.82633984473444, 50.34427227512483, 54.44519658242503, 56.484593729819025, 58.81061023281467, 59.533848224147675, 55.977023340040645, 55.40001130873158, 52.31869928298458, 44.07174341140255, 43.423328553476644, 44.21930297728508, 51.65492834583406, 53.11793711877639, 48.26322347887101, 53.21515306349724, 56.301783823197894, 52.16955507955244, 51.323433153090946, 51.23326570756974, 51.65812899989467, 50.70701699103079, 51.342374278653054, 46.24068467847763, 49.49086258488317, 47.80043478934996, 47.51101878381545, 46.17278845079484, 48.231522883138354, 43.791101747943515, 45.85957150305472, 42.0948374655939, 40.503041590413744, 42.81769106465001, 40.03844468824325, 40.42359398257348, 39.89862003634053, 40.14133630260345, 40.62836131741924, 47.12068411611742, 41.738639185505534, 42.01122037826046, 45.511641579289595, 49.17517062156431, 52.596332488521455, 55.595698356628425, 54.11082236997543, 47.760285408266135, 41.88841881290559, 42.58910709811796, 42.202330020166215, 42.15024878901821, 43.58185506636097, 44.566287609838675, 44.937006504304954, 43.6393177893854, 44.51439857482911, 45.42193697344872, 43.25628657494822, 45.01803874969483, 46.65066649836879, 45.358394576657204, 46.44589524115286, 47.58195877075196, 47.652102516543486, 47.455764355198035, 48.209181062636844, 49.661356249163234, 49.81951405925136, 50.62281939291185, 52.48479204793131, 60.0250348737163, 65.49820430817144, 73.48478932534495, 72.41322132848924, 76.9476067635321, 75.66332863223168, 69.47125542548396, 2.9915027416521505, 0.7388989122644548, 1.128012619672283, 0.3497172988230183, 45.50200039340604, 73.53070459058209, 59.977766390769716, 54.99703484196817, 26.986969747850974, 37.016768378596154, 48.65717457186792, 60.96958867965206, 30.584691224559663, 0.1882242330259854, 0.04648449920838879, 0.0663306887051271, 0.04885702371417035, 0.032156119273314555, 0.049089002798521714, 0.03417682173030992, 0.03534669544728052, 0.04570265668594549, 0.017766848754798694, 0.0323297492709131, 0.12484103696601045, 0.028801427913769603, 0.32228896093945353, 5.5961185789877375, 61.800072116236535, 48.30515361601307, 55.75614683089718, 33.200510086551795, 53.02116832425518, 52.31178414437079, 84.43833751063194, 40.22722836463682, 0.09488991026075617, 1.4479847468676106, 0.09980142251738619, 0.1917155102015503, 4.45963486548393, 53.492868638807735, 72.12820622228807, 70.0168022032707, 68.63153872951385, 63.99867434655467, 59.552424569283765, 55.88729519997874, 56.00894358850295, 52.87828030124788, 50.77243820313485, 51.73259911998626, 50.78504862323884, 51.238772715291674, 51.95757058358962, 53.21873418746456, 51.647515066208385, 53.69882052944553, 55.13597696058212, 54.30135542346586, 54.344254386040475, 54.54509542834375, 53.57900388779179, 51.4906398711666, 46.79501364308019, 44.44259958882486, 44.65556467733076, 48.397466598018525, 56.65972363564276, 58.04065681272938, 61.50991086036929, 62.41335038215884, 58.592769638184585, 62.82630535864062, 63.724743858460464, 57.7843338443387, 50.741223981303555, 47.15866442649595, 45.1031384929534, 47.536188633211204, 47.754637195217995, 46.17414166850429, 45.45992905093778, 47.50881048940843, 45.18725372129872, 46.02750778198243, 48.65528398944486, 44.861434198194935, 47.53104248354512, 48.37537188683787, 49.707153843295195, 49.311441606090916, 51.472871534286014, 48.706321870127034, 51.81248211091565, 52.42887866112494, 53.64687658125355, 54.60385645589521, 52.8232180687689, 52.91760206222535, 55.61305876701109, 58.62546259357084, 60.459233407051336, 60.626498960679584, 58.8965375961796, 58.352822565263324, 50.5378883115707, 43.700467540371804, 43.48823593508813, 43.30453957280805, 52.42141046831685, 56.45055540146367, 51.54942051056893, 54.52707605977213, 59.56901227274249, 55.07795726099322, 52.426144769114835, 55.073011152205936, 52.90233619751469, 52.584455551639685, 52.84466558887113, 49.29801141062091, 51.5877499118928, 49.43036786971554, 49.54667006769488, 47.58497899578464, 50.16467478967483, 45.8876125274166, 50.006575815139286, 44.931676003240774, 43.003595721337106, 43.557767791132775, 41.34302500755557, 41.75121822664815, 42.029059317804155, 42.13102525280368, 43.14896268229331, 50.854521643730905, 44.81385977037492, 43.84202195752052, 46.78838483748898, 50.66637339130525, 56.15187083521197, 56.82339629819317, 57.12543449094219, 50.016671995962824, 46.34794973557996, 45.71418885261782, 45.019368433183246, 44.1479197625191, 46.31952039657101, 46.46232212743452, 47.61518909085182, 46.38102316087293, 48.36069045528289, 50.123297706727065, 47.01865934556531, 49.796489746339866, 50.37618860121697, 48.9155371727482, 49.117703976169715, 49.413493833234234, 50.48909010425691, 50.0864548836985, 51.75704333090013, 54.26107660416634, 52.68751975028746, 54.13066564067718, 54.75158076132498, 62.326124714266875, 69.39545954427412, 76.64805535347232, 75.80152157814273, 79.88673287053263, 77.57616658364573, 76.0247907330913, 3.7751721999337597, 0.7597387714251396, 2.5153431825099455, 0.2729729088323732, 49.56967869112569, 79.83877797280589, 68.2131944164153, 65.80245471769764, 38.08821085960635, 49.03451050481489, 63.78092788880872, 70.26540986953243, 42.31640038951751, 0.11119242216790877, 0.05548877491345329, 0.028234980587336807, 0.021427136417778752, 0.0912064063032308, 0.09161902125924827, 0.1986910931525692, 0.15608393346830723, 0.11821750205971542, 0.08939114564488973, 0.16182237635216407, 0.19369592409460776, 0.19582785485732943, 0.6738710403442384, 8.006221382848679, 77.91334921313872, 55.66868582079488, 61.10280021544426, 37.30790630463631, 65.77586104792934, 58.362024445687574, 95.30918644320582, 43.887231196126635, 0.29658272742263736, 2.318124694208945, 0.22436447681919222, 0.31835473172606965, 6.6305981143828365, 59.59813194890177, 76.17737877753474, 75.68596070812595, 73.48009032587852, 67.63839460188343, 63.640538415601185, 58.73974869328161, 57.765349572704686, 55.52389152588383, 54.95409273332166, 53.87627247841128, 53.694847168460974, 54.350636082310835, 56.058247781568966, 58.18425478473787, 53.60708805822558, 56.331397717998875, 61.064196248208326, 55.81680236324188, 59.74173384328043, 58.50264926110545, 56.93254801534838, 54.29016097899407, 48.69591582205988, 46.50544074273879, 46.81522561657814, 50.61644554138184, 60.00951013257427, 62.27058003025671, 65.55385097380608, 65.20244975243845, 60.777055217373764, 65.81282154206308, 65.80919727202385, 59.80880245085686, 53.84204587628765, 49.66816940615254, 46.72974148104268, 49.85472909865841, 50.865963197523556, 48.465033346606845, 48.46588450093424, 51.890784386665594, 47.144218337151315, 47.51794568953976, 49.333924631918634, 47.472403049469, 49.86964587242373, 52.16002764240388, 53.27926812633392, 51.256031144049864, 55.095658917580884, 49.98708163538287, 56.27164433079382, 56.16668562735281, 56.34637724968695, 57.00702205781014, 55.35200934256277, 54.277240691646455, 60.54784367161413, 63.97368492618684, 65.12605767096242, 64.029684605137, 60.8382716486531, 59.802679631017874, 52.22553122428156, 42.971149875271706, 43.31240784737372, 45.56890033906507, 52.76992874760782, 59.33926336226925, 53.86630573580342, 59.29686254070651, 60.29989104117117, 57.50131914692541, 55.26945521754604, 57.82660130531558, 57.127066196933875, 55.005695435308645, 54.574662254702666, 51.12348641118696, 55.459721549864746, 52.9927860536883, 53.48208996557421, 51.17236698827436, 54.43095837869952, 48.79858386132025, 53.390428097017356, 46.776441220314275, 45.651756486585064, 46.849609113508656, 43.666017363148356, 45.37889288317773, 45.67334913438367, 44.77488710034279, 44.72654781033916, 54.15086192469443, 47.01901628125099, 46.785972579833, 50.674296579053326, 55.38599668010589, 58.67026390567903, 59.800694911710686, 60.48876100970853, 51.35576917279152, 48.91247380164362, 48.61920995097007, 48.25776746196132, 46.551061830212994, 50.76391097038023, 49.27269643352878, 50.27197907047887, 48.621316263752604, 52.19299908607237, 53.24337451688705, 51.09392350719821, 53.269183712620894, 54.876390580208074, 51.240537781869214, 52.676093885975504, 51.01024366194203, 53.49259799526584, 55.04782169095932, 55.469460795002604, 57.64236365595172, 55.40721670273812, 58.068160472377656, 58.15183639526368, 66.60649745695054, 72.6905172101913, 80.24302528750512, 78.43681304685532, 82.0014238357544, 77.06105739839616, 79.99883421005742, 4.429983217870036, 1.0020974278450012, 3.7595243944275767, 0.9212071232257352, 56.0719721548019, 87.34985013161936, 75.67414652916693, 76.13737844651746, 40.747660206210234, 49.09866479135329, 68.97691126792662, 78.86029566487959, 51.77920080000355, 0.4939466192116661, 0.1508138767413555, 0.11183182979303022, 0.15936810643442217, 0.23739325753863783, 0.1646593837968765], [0.034987518954421246, 0.05781367556342195, 0.08356821858474324, 0.04971174418085045, 0.03618653465603148, 0.16874217278053685, 0.17877813909322987, 0.30020990859596963, 6.35773156919787, 50.57216982687674, 48.05682836040374, 33.200957236751435, 29.51612384088578, 46.328047629325624, 42.58280777162121, 69.57016975648942, 57.20461145524056, 1.0051128112020031, 0.486172144451449, 0.2385058163875534, 0.2542615330387508, 0.8866704699973907, 52.392679106804636, 72.87852425729075, 60.50570172648276, 61.9288396066235, 50.55486432967648, 51.7240640424913, 49.76179638216573, 51.2816285317944, 48.143234252929695, 50.830363765839614, 50.82172278435, 53.07907035273891, 50.60863217999859, 52.05307637491534, 53.820162973096295, 55.953065503028135, 53.860594764832534, 56.598032597572576, 52.573029687327725, 51.62576944597306, 48.22331728473787, 49.903762648182536, 45.922454941657286, 44.294016284327355, 43.35934685122582, 45.58886520324215, 54.00025859955819, 57.79785425432267, 56.801434947598366, 55.09325450466525, 48.56402612501576, 60.30359768098401, 59.48261422495688, 59.071651812522646, 54.76734476704752, 46.912825953575876, 45.260174505172245, 44.579443239396625, 45.24794063260479, 48.57824863926057, 43.65102214197959, 43.66685675036523, 40.882742712574625, 42.1513117513349, 40.62579216495637, 41.92386527215281, 44.44349388922415, 43.83528332556448, 46.24221048047466, 47.835736120900805, 46.451539531830825, 48.079856595685406, 48.05437295667587, 47.26527837014968, 49.46814421684512, 49.645380435451386, 51.359291461206254, 49.895239337798095, 51.35270580168694, 52.34949381120744, 53.58465994558027, 57.26416872393701, 57.30139986161263, 57.02479039469073, 55.779120152996434, 46.22876459552396, 40.17064033016082, 34.499128403202185, 36.17179570659515, 49.96810128611904, 54.076654603404386, 55.93761136454921, 55.815394232350016, 55.88124298280286, 52.27787917660129, 50.23923120191021, 48.856023050123646, 50.75470516758581, 51.226201518889404, 50.549282796921275, 47.31380985629174, 47.541766243596236, 45.17553367922383, 47.067751730642016, 44.34251639150804, 47.16508926883821, 45.819822203728464, 43.37815853857225, 40.37256394663165, 42.971577413620494, 39.59954323307161, 40.430999417458814, 40.01543214244228, 40.57266758334252, 43.3503253998295, 41.08924373503655, 45.94437706855036, 44.0211840598814, 41.846661260051114, 46.57338796123382, 53.034331798553474, 57.99534167012861, 61.028934140359205, 59.51087490204842, 56.24382295916158, 48.69161298198085, 41.32248355496315, 40.948407111629365, 43.17853735339257, 42.47313437923309, 42.87027043680991, 43.720059779382524, 44.83604077369937, 45.081934159801854, 47.677727360879224, 47.67173005688576, 47.11658916165752, 48.920757847447554, 46.65356512992613, 46.78920069048482, 48.66945943524761, 45.72915661719538, 50.29968277100594, 47.77945010892807, 49.69007192119476, 49.692037028651086, 53.629880951296904, 53.139608213978434, 62.01842261898903, 63.5858880319903, 74.63650703430176, 72.29533841533046, 82.6765892582555, 70.98368998496764, 92.07552171522572, 5.369629158127693, 0.34765783997793354, 0.820325784865887, 0.18884672542973874, 53.037042156342544, 75.27590828557169, 59.44328854160925, 43.727669177516816, 21.317919108175463, 23.034413014688802, 48.81606586517827, 60.06472141511979, 34.2647667854063, 0.7176117803300581, 0.044976822851646336, 0.05112261766748083, 0.03122004984517492, 0.04223852200553783, 0.013946978273921678, 0.05889310110961238, 0.0446957758357448, 0.024344412639977473, 0.16096821896010832, 0.06676578834172218, 0.09311442488744374, 0.1750903756868455, 0.41840379216497947, 8.718644419024068, 61.70403288256738, 55.557388567155414, 39.1803163866843, 30.746226195366155, 51.8649398896002, 50.9725732188071, 75.53408653505387, 63.519144981138176, 1.3190933340980162, 0.5128377345540832, 0.5843741975484357, 0.48898135822626854, 1.2126660707496828, 57.134267668570246, 76.16752578366187, 62.19531366902014, 64.96825287418982, 53.50958970285232, 53.69396855754238, 50.58099908213462, 51.96415232073877, 51.485725141340694, 53.528417079679436, 52.536037814232614, 57.02264878057665, 53.31441648544804, 56.88358899085753, 55.18950554632372, 58.02214714788622, 56.165881541467485, 58.82487981550155, 56.95157543305428, 55.77180885499524, 51.62607146847633, 51.79347038269044, 48.64077121980729, 46.38672628710347, 43.94454486908452, 49.71540651013775, 55.33265636813257, 59.51567196076917, 59.13414693647816, 58.5014803947941, 54.00544397292599, 59.954573415940814, 60.73272458968624, 61.62049816500757, 57.096310892412745, 50.56464279851606, 47.587320650777514, 47.63639342400336, 47.69165569736112, 50.93565194837509, 44.78877229075278, 45.937963993318625, 42.99902223771618, 43.12187479388329, 43.004776354758974, 43.462936647476695, 48.20090093920308, 46.23455793626847, 48.7061139845079, 51.569393219486365, 52.47066367057062, 52.47943016790575, 48.10900765080606, 49.27998027493877, 51.760569541685044, 51.46670164600496, 53.7110661691235, 51.53837903853386, 53.583922539987874, 55.936858269476126, 56.14460660565285, 59.651158471261304, 58.8612715659603, 59.28027091487762, 58.61897499330583, 47.01103425795033, 39.69029903411865, 34.887286155454575, 36.5493042238297, 52.13978036757439, 55.53484278340494, 58.02563021259924, 59.22507139944262, 58.21713993626257, 54.504228253518384, 51.874596764964444, 51.454350102332334, 53.058450452743045, 54.3902559434214, 52.50844394007037, 48.69707292126071, 50.16099952882337, 47.75457443729524, 51.06634532251666, 48.06637148703299, 49.68249390202184, 46.813931234421275, 46.11800078422793, 42.36070748298399, 46.62170763938658, 43.30925818412535, 43.35248662579445, 43.97570810010357, 42.040948021796446, 44.97700683532223, 44.625170230865486, 49.57809217514531, 46.500106319304436, 45.54092207262593, 51.66899396527199, 57.73684963103264, 61.22869260849492, 63.14375846616684, 63.72120195819486, 60.08052072217388, 51.55748882601338, 45.86979319972377, 44.50824437602874, 44.84077899686752, 44.94720858912314, 45.60813973026891, 46.12098178555889, 46.803505574503255, 48.9661043690097, 48.835842455587084, 50.35248964063583, 49.04345743117794, 51.506352886076904, 49.81460717416579, 50.12979707410259, 53.72311176792268, 49.171758159514404, 52.02186607545423, 50.906242016823064, 53.28730898518717, 52.48653358028781, 57.31405342778852, 56.653977363340324, 66.89521528059437, 66.7975482633037, 78.58147790355068, 73.84343516442084, 86.14003427567022, 72.80134770178026, 96.3033974555231, 5.867650537721573, 0.6489354299922144, 1.0017441693813571, 0.19061382980115954, 59.05752343516196, 80.74448462455504, 65.98024399049821, 52.04183093963131, 28.70015121275379, 27.09642348750945, 57.745918150871034, 67.61135378191548, 48.129415742812625, 0.7022907572888559, 0.08251230427694899, 0.05386828061854167, 0.03293457568713254, 0.04992209660309938, 0.05825733623257088, 0.19981304423943644, 0.1661543430940759, 0.26262805586861027, 0.3006504091524309, 0.1813586449791347, 0.32413835847570055, 0.4340090338260897, 0.47201554441163623, 11.672572570462382, 75.27395494522588, 66.93484690881544, 42.50669810079759, 36.808961206866854, 62.96992294249996, 56.51515683820171, 82.28984355926514, 70.3926044894803, 1.5336026107111287, 1.3421552772483518, 1.2710694271710612, 0.7904174671538415, 2.0482036038752525, 60.89336918246362, 78.74378558128112, 66.76092117063462, 67.58164575023036, 57.16887474060059, 57.23126396056145, 54.315691686445675, 54.98407925328901, 54.12944970592376, 56.54493547254994, 53.20926950823877, 58.61024379730225, 56.79807739873087, 59.2260088459138, 57.955164832453576, 63.828647444325114, 60.9033045461101, 63.32019452125796, 58.5407550873295, 57.55241586316017, 54.052445734700854, 55.47384992722542, 50.0406062987543, 49.53622871829618, 46.58220937175136, 51.40015471366144, 60.13846589672951, 62.508150146853545, 61.056637840886275, 62.720730843082556, 55.64992512426069, 62.93773989523611, 62.946953542770885, 63.82154010957288, 60.73120663242956, 53.36501898304109, 51.06996959255588, 49.78113758948542, 49.825287788145005, 53.65522338498024, 46.442039551273474, 48.36375382638747, 46.01413249969483, 45.38328593777072, 44.71298817665347, 46.0309830019551, 49.31457165748843, 49.58585454571632, 50.89900524385514, 54.310376874862186, 53.328799816869925, 56.127030464910696, 51.51839456250591, 51.61944658525529, 55.5564550430544, 54.69367873284125, 56.55193690330752, 55.782611062449796, 56.47332083794379, 57.7332567399548, 59.61340565835277, 63.75707595579086, 62.778154342405266, 60.18050193786622, 60.00474837518508, 45.87831651010821, 41.02990611906975, 34.85600917570053, 36.62069136096586, 51.263303218349336, 58.8748037430548, 61.01317013463667, 61.770258180556766, 60.567467289586226, 57.07542819361533, 54.421646671910445, 52.7350627991461, 59.020111868458415, 56.91885894344699, 56.90718596981418, 52.2831351526322, 52.90665080470424, 48.815018592342255, 54.586162644047896, 49.386605985703014, 53.50418467675486, 50.578327948047274, 47.968912355361454, 45.55676060338175, 48.02073078770792, 45.07634478230631, 46.010672969202844, 45.54361281856414, 46.58998350943289, 48.28947198006415, 47.100126974044315, 51.690519932777654, 50.52514060851067, 48.194652603518584, 54.781104441612, 59.39064248915642, 63.65848325913953, 66.38392648389264, 65.07032079081382, 62.84773718926215, 55.07236003875733, 46.531716700523134, 45.59522728766165, 46.894535941462365, 48.15135748155656, 49.403060328575876, 47.89459913007675, 48.05526725707516, 50.09651184082032, 51.67776438497728, 54.01888593550652, 53.35094944123299, 55.22119045257569, 52.67776481566891, 53.22472364671769, 55.93019416255336, 50.679046569332, 56.31971297725555, 54.15913420338785, 56.81982301896619, 56.473430664308616, 61.34171178264003, 59.26347532579976, 71.47683389725225, 69.0902756106469, 82.67303559087938, 78.35492964713805, 87.51506820801767, 76.3019375647268, 98.71176412028652, 6.7364104236325915, 0.7547324787705176, 2.013385091577807, 0.5717296405665336, 66.46609229426231, 89.80782693432224, 72.57336385788457, 62.881367591119584, 35.31492256349133, 34.96672199618432, 73.92662079103532, 79.3418921193769, 64.76614490632089, 1.2997507784635791, 0.1726957074096126, 0.10980062427059298, 0.10887129067052757, 0.11153405907774165, 0.1399611534490701], [0.07856730386734971, 0.10112323828281895, 0.12152593703039231, 0.041920492095091653, 0.08753591817953894, 0.1318407899910404, 0.05031921743084827, 0.22966588186400555, 8.476429235550667, 60.940021853293146, 47.11020746538716, 50.179866129352206, 36.33500945183539, 36.659813081064534, 44.308011301102184, 56.72496834108907, 71.1821932946482, 4.515974810046535, 0.14768727273950655, 0.8375590859401612, 0.12043838329132527, 0.6736419494113615, 43.06326673876855, 74.08441774306759, 58.17054217861545, 61.6269818429024, 57.421569516581876, 65.1971153290041, 58.80188688155144, 60.886893349309126, 55.14378247722503, 57.45030087809409, 56.53708288746496, 57.920436166947894, 54.84413300791095, 57.674283904414025, 56.746596290219216, 60.20515403439922, 57.56494783586072, 58.18058736862675, 53.09280257071219, 51.57744584545013, 49.475177026564076, 48.73557882924234, 44.51071154686713, 45.83153047869283, 42.61990554871098, 54.10333064294631, 51.97423673445179, 60.684134267991595, 53.027679458741225, 78.03145177902715, 78.91076872425695, 55.37036603496921, 60.77177178475165, 54.153101598062825, 54.17036394919119, 50.33698843371484, 48.35304575581705, 46.04488780421596, 51.04205016166934, 52.221032265693914, 44.569958948319965, 41.58539610524332, 43.96075994737687, 41.2213138611086, 41.19380235671997, 39.506630128429784, 43.98194466867755, 43.17181048854705, 44.62545264151789, 43.86261832329535, 45.971590472805886, 48.74542790074503, 47.370829351486705, 47.38300438850157, 49.067607464328894, 50.44114305127052, 47.70862779309673, 49.827245050860995, 51.819503153524096, 51.79036778788413, 53.25070150436894, 50.48372430186118, 55.7583119792323, 58.79978841350925, 56.401337500541445, 50.72068645108131, 37.78789850973314, 33.046937527195105, 31.17787518808919, 50.54576443087671, 56.010438011538604, 56.57964452620476, 56.12160190459221, 55.53156760431106, 52.29113678778372, 51.13717156071817, 47.665246378990915, 50.69482234216506, 49.22703219998268, 50.454883113984145, 48.11442052164386, 47.28409005749611, 45.66648106421194, 44.37205576127575, 46.18669717542587, 48.1048224818322, 44.809964856793805, 40.27279453892862, 43.46772586145709, 43.529342374494, 39.667023689516135, 42.211049449059274, 41.60157195983395, 43.04569452039657, 40.47347476405483, 43.69061454649895, 44.85278144959481, 44.8377077810226, 44.016112435248594, 47.866703233411236, 57.72929514608076, 58.23124477940222, 57.275594588248964, 58.4376948110519, 57.30520848304995, 53.71437664954893, 49.359314134044034, 46.39588502145583, 43.32078210769161, 43.36805451300837, 44.097391789959325, 44.14291481817923, 45.12726106951314, 45.212858953783595, 45.172584056854255, 45.329278822868105, 46.41495166286346, 46.286164560625636, 48.05490247664913, 47.990053930590236, 49.9429432038338, 50.93320046701739, 51.91914312301144, 48.3333868365134, 49.7944305019994, 48.54339445790937, 55.14928556257679, 52.7387184481467, 62.14748036476874, 63.559976854631984, 73.70584626351634, 67.8712421847928, 77.3046208966163, 69.58523950269146, 90.9996626454015, 7.258040549293642, 0.394005362665461, 0.5231841809807286, 1.3347385655487738, 67.49102330976918, 70.76923831816643, 61.33400432525143, 46.461274854598514, 32.13849109988059, 46.318865360752234, 57.957447651893865, 55.20128050158101, 32.33816327587251, 0.8652667088374015, 0.25395633893147596, 0.03550492324716142, 0.12891278662268194, 0.05501168216728876, 0.10610436494912832, 0.04881951221895795, 0.10010094757402137, 0.0510254126012085, 0.04690936007987588, 0.0012362626570862748, 0.3267161830538704, 0.18939136797862668, 0.40975058391209573, 12.974393502358469, 69.31547457172026, 57.392438073312086, 44.11034345626832, 35.575163979684156, 44.960878049173665, 51.403182783434474, 66.97216433863487, 77.34825334241314, 6.068676912015484, 0.24640421353040204, 1.4398519574634492, 0.16878338831086315, 0.9874137286697665, 44.138984603266564, 76.847335292447, 61.16139258107832, 66.58107265349358, 59.41059166385282, 68.40452763342088, 62.377986292685236, 64.49949825963667, 57.1905654476535, 61.1394900660361, 59.166694764168035, 61.54371384651431, 58.011839159073375, 62.193230890458636, 59.047207601608775, 64.46582078933716, 58.94667333172214, 60.27077528738207, 57.23108353153352, 53.977191140574796, 52.619992225400864, 50.45154125459733, 46.485805357656176, 47.76753394834457, 44.798535070111676, 55.418418991950254, 57.6442503160046, 63.338923838830766, 57.22530195789953, 74.26293265435004, 69.07936357682752, 60.34667707258656, 62.76812876424482, 59.04994933835922, 55.96426779224027, 53.09766238735568, 49.834340618502715, 49.41354874641665, 52.656642852290986, 54.48694236816899, 46.39745789189493, 43.82586963715092, 43.69549789736348, 43.6426753382529, 43.63182998472645, 43.67635673092258, 45.64666132773123, 45.54632317635321, 46.80539223455614, 48.042829421258745, 49.20576510890838, 52.07835605067592, 50.609557859359256, 50.469576312649636, 50.334242774594216, 52.94213256528301, 50.73966287797498, 53.00796954862533, 53.88859264312252, 56.62702675788634, 54.735083272380216, 54.62580211700932, 58.814073685676824, 59.966505266005, 57.11719751358033, 51.33147008957402, 37.53368577649517, 32.891060575362175, 31.043790924933653, 51.40795238556401, 58.859071116293634, 60.076676799405014, 58.162026712971354, 57.238116341252486, 55.35212701366794, 53.09762708602413, 50.28935909271241, 52.88039053640058, 50.008219288241484, 51.91799386855095, 50.04366966985887, 49.244675021017756, 47.63392625316497, 47.54913637715001, 47.0644098712552, 50.7241734381645, 45.31802162047356, 43.342170792241255, 43.96753780303463, 45.925455554839104, 40.90089936410227, 44.318280066213305, 43.58484391243228, 45.61048530763196, 43.497065190346014, 47.163367348332564, 46.48399322263656, 47.04346441453504, 44.379163096027995, 51.88353584658716, 59.08723931158743, 60.8926631558326, 59.158936315967196, 59.17080148573845, 60.21303799844558, 58.35215183996386, 53.19202676896126, 47.303458721407004, 45.72579906832787, 45.25438116442773, 46.710035493296964, 46.51657242928782, 48.79842304414319, 48.61493848985242, 48.43110876698648, 48.65995553232009, 50.178924760510846, 49.732884591625584, 49.93738520529963, 50.485046140609256, 53.66892814636231, 54.654784510212565, 55.863317751115375, 51.421849343084524, 53.593418598175056, 51.127275420773415, 58.558990186260594, 53.993072817402506, 63.504349800848196, 65.48737856649583, 77.45836996263074, 70.88322239537393, 81.51546570562547, 72.46840123207339, 95.94910544733848, 7.355966443015683, 0.4660007736134914, 0.9877853119565595, 1.4328930599074212, 74.71613899354013, 78.56082270222326, 68.79449752069289, 55.58404499484647, 31.10528192212505, 39.46157778463056, 61.1997494389934, 67.21094254524478, 43.19973776417394, 0.9677905397069071, 0.15256728346069015, 0.03064662537297174, 0.11928955784007428, 0.0683007144459313, 0.10453503383623977, 0.15644273840852324, 0.1823109075907738, 0.28214524890626635, 0.14863018907846945, 0.2194948082849864, 0.391479815927244, 0.3577616510372008, 0.6733777410080356, 17.03534003226988, 84.44676276176207, 61.5246158261453, 67.81811760317895, 51.968243352828495, 51.89314173113916, 63.640561949822214, 70.65406968516689, 89.05667735684304, 6.4187719841157245, 0.2974313689816383, 2.077086712083509, 0.16632675884231446, 1.6365339390693174, 50.938491744379846, 79.20475821341239, 65.81024846723004, 69.62396114103257, 63.725955870843705, 71.78819164153069, 65.97905158996582, 67.33513262964064, 60.355741670054776, 63.10877484659996, 61.985392339767955, 64.26609370016283, 62.28980356647123, 66.0101402959516, 63.27521670249201, 67.95474160102107, 62.389004230499275, 63.2697920645437, 61.167327127149036, 57.01363125155049, 54.589249549373505, 52.27463145409861, 49.156268719703924, 49.9966129949016, 46.83491199247299, 57.59531090336462, 57.830743328217544, 66.64612124043127, 60.21809785596786, 72.41704171703708, 65.48306395930629, 63.299951168798636, 64.39647720706078, 61.008894751148844, 57.145430734080655, 53.451954395540305, 50.9113097190857, 51.82400603448191, 54.57513686149351, 57.05080355367353, 46.998047290309785, 48.22538437381868, 46.00798614563481, 47.61626382027903, 45.92880918133644, 46.14606142044068, 49.50695999207036, 49.12074773542343, 48.73468845121322, 50.580720593852384, 52.24153449458461, 53.49944645358671, 53.85626839053247, 54.27929209124658, 52.07155073842695, 55.37166433949625, 53.98389839356946, 55.649309312143636, 56.53095222288563, 58.660712934309444, 58.74121958209623, 55.60882652959516, 61.78162128694596, 63.70636755420316, 60.96826684090399, 52.97299769616897, 36.38799675049321, 35.10528364489156, 31.442878361671205, 52.3014251647457, 61.36546957877375, 62.366148579505186, 59.6479578172007, 59.924159357624674, 57.84518549519201, 56.863404473950794, 51.07122475101102, 56.25324056994531, 52.740683555603034, 55.3336997185984, 53.55952539751607, 53.33879401606899, 51.269202463088504, 51.56476482268303, 52.18833931030766, 54.11237562856367, 49.100433780301, 46.59399609411917, 46.524354411709695, 49.58041029591715, 44.23941296915854, 46.8895859103049, 46.32513723065777, 48.38063178523895, 45.39361353843443, 50.67124889742944, 49.60350913386191, 49.29419102207307, 47.40110612684681, 54.58244815949471, 61.47813573960335, 64.59312131327968, 59.830806947523556, 63.321006451883626, 62.86166944811421, 60.67264172338671, 54.806737130688084, 51.39923687904112, 47.589297525344364, 48.66930254044072, 49.050133305211226, 50.11802996358564, 52.899355196183734, 50.698062219927394, 51.05737878430275, 51.590052343183956, 54.811706773696415, 53.05517919601933, 53.632395190577355, 54.250474437590576, 56.980593127589074, 58.493965133543945, 59.77017102702972, 55.49596032788677, 55.28832181807488, 53.388612039627574, 62.83591516556279, 58.50730903687016, 68.64332937425183, 68.32519377431562, 81.28242984894784, 71.90525085695329, 84.14805858365952, 75.85194756907802, 100.3696087867983, 9.375276642460978, 0.8579310798837293, 1.2166015563472625, 1.781456446455371, 83.57642804422687, 86.02437926876931, 77.47293764545073, 64.48541695071806, 45.167987039012296, 61.05140539907641, 82.31153426631805, 76.1986380238687, 55.86142324632215, 1.274681194655357, 0.2828215819693381, 0.17152990544995955, 0.22537134617807406, 0.15001058758747193, 0.19712513282654748], [0.0737004085714298, 0.05910525383848337, 0.10837472013888821, 0.06612948337269407, 0.13852178149165648, 0.12146654989450209, 0.09278604129870092, 0.2423900047377233, 13.304997336479927, 60.929666796038234, 45.68305307818998, 38.822509934825284, 25.370184452302997, 45.49386932003883, 43.17789408468431, 54.799990653991706, 74.03574112922915, 18.613770431087865, 0.14325096482230773, 1.0305619456114308, 0.04533539030460581, 0.21885274999564697, 27.95343783593947, 82.17327071774392, 60.75481537849673, 72.63510980913716, 66.47063439892185, 72.09984748594223, 63.40197201698058, 69.06752586364746, 63.33107125374579, 66.62901970647997, 57.438431785952666, 62.585938592110914, 59.962504448429236, 60.68878227664579, 55.33064811460434, 58.83059470884262, 56.07678490300333, 56.02788079169489, 50.692767020194765, 46.72513661846038, 45.67149385329216, 48.20007724146689, 43.64699386781262, 47.856116756316155, 53.50370614759384, 57.944523442176084, 55.04785699229087, 59.059994528370524, 54.84520381496799, 59.99510718930153, 74.96554682331701, 58.742988571043945, 59.22016451435705, 55.17073700504919, 52.59860354085123, 52.20671561456496, 48.35513245674872, 49.45249395985758, 56.21140456968739, 57.832218139402336, 44.83084755559122, 40.37174024889546, 43.94175998626217, 43.54419246796639, 41.58557261190107, 41.3886853187315, 40.01006634004655, 44.83950030419135, 43.03838714476555, 45.48177665279758, 47.841423557650664, 45.45901513868763, 45.68402582599271, 48.08776017158262, 47.03736905128726, 50.57151086868779, 51.0110124464958, 51.58081516142815, 53.78094319374331, 52.69354451087214, 51.44788211391818, 57.63567601480792, 56.69103199435819, 59.4489759783591, 55.04486030147922, 52.47842604114164, 36.66441009890649, 36.77919826199932, 32.97069449578562, 47.55529449832055, 56.49246984912504, 56.299234282585886, 56.2939469275936, 54.81630379153837, 54.91924247434063, 52.87449521403159, 50.27231247194352, 50.77266570060484, 51.946886047240234, 47.65977859497071, 47.73795927724531, 45.78525435539984, 44.58558567108647, 43.13998045459871, 45.0979805761768, 47.42788414801321, 42.90076686489967, 40.39970282585391, 40.79719189674624, 40.41066585048553, 39.04938374796222, 42.352246930522305, 40.60883183633128, 43.83035682862805, 43.44501533815938, 50.684600645496005, 45.49307307889385, 44.432432805338216, 47.48578617649694, 50.310853681256695, 57.42275015000374, 59.042590971915956, 54.80764712056806, 57.248491010358265, 58.792771293270974, 54.499415505316954, 54.762555553067116, 48.28227050842778, 45.871558266301314, 43.33754239543792, 45.178436233151345, 44.0288209146069, 46.841266232152144, 46.2550836993802, 48.0121329522902, 46.587696767622425, 45.71062734050136, 46.90104707594841, 46.93806248326456, 48.49278411557598, 48.69102854882517, 50.357102347958474, 51.53062059033302, 48.585301060830396, 51.66394195249004, 48.08532045733545, 53.736922433299405, 51.445442399671, 58.585925102233894, 57.77920730652348, 67.38996736464962, 64.06162838782033, 74.98034200360699, 67.877164963753, 91.2151498179282, 5.526754894564229, 0.24625044436224047, 0.7500730707280098, 3.6857855512249857, 74.58251953125, 63.188171463627974, 65.90239278731808, 39.95676132940477, 48.99488279896398, 31.98727784618255, 55.41918777650403, 55.25792344923943, 44.49406893022599, 1.1763167309184228, 0.19679550051448808, 0.05756004683433041, 0.09626457077120582, 0.044444495166141185, 0.06729167705822377, 0.08084976324631322, 0.0850407085231235, 0.10590343540834804, 0.06353149152991754, 0.04405372520728458, 0.17790544237340652, 0.02855557689232932, 0.20064541409092568, 17.27409274347367, 71.49142511429326, 54.12819062509845, 47.729428122120524, 34.2597226173647, 52.92304631202452, 48.848103784745746, 62.17168138873193, 81.66489231971003, 21.870988991952714, 0.2258392420387076, 1.4860743933147, 0.03410591646247814, 0.2041003786988797, 30.410420317803663, 84.88301661706741, 63.26693657905825, 76.29065682811122, 66.44538217975249, 74.07911469859462, 65.03762783542757, 71.73791470066195, 63.57749023745137, 68.31476026965727, 60.095770897403845, 65.74886729640346, 61.44401896384455, 63.031284501475675, 59.17695960690899, 63.30338716506959, 59.06194394634616, 59.72478135939568, 53.73070547657629, 50.45845247084095, 47.35690101500481, 49.89496477188603, 46.83667705905053, 49.4241391458819, 55.50799023720526, 59.719580296547186, 58.881816940922896, 62.42272484687067, 55.05151264129147, 58.525077373750754, 68.61103257825299, 62.333792947953754, 60.417868091214096, 60.44911761437694, 53.94401965602752, 56.78518064560429, 50.153021427892874, 55.07813769002115, 58.312673184179495, 58.471933180286044, 47.84247083048667, 41.91197264579035, 43.97746532194076, 43.65041025223271, 43.805810636089696, 43.43870424455212, 42.71270098224763, 46.640397733257664, 44.19037157489408, 49.560308148784024, 48.805483310453354, 48.01153675202401, 49.664474533450225, 50.723522324715894, 51.058849673117365, 51.9772530371143, 51.376459675450484, 53.46806749220818, 55.778763217310754, 54.91681452720396, 52.980901272066184, 59.40273515639767, 60.775235237613806, 60.86116260097873, 56.40621692903581, 54.584040641784675, 37.20739556897072, 36.806360675442605, 32.33231502194559, 49.44239385666386, 60.05770037251135, 58.645278407681374, 56.76995792696553, 56.91319504091817, 56.22552510230773, 54.244700708696925, 52.86432843054495, 51.54677683307279, 52.34139019443143, 50.04374419489215, 50.15606126477642, 47.2022537262209, 49.89435680450932, 47.531928939204064, 46.044989785840436, 48.728675457739065, 45.597541486063314, 42.87713458461147, 42.39325531067387, 43.87023556616999, 42.343656939844934, 45.85368010305589, 42.29092851761849, 44.245614236400975, 46.94237316808393, 53.819076476558564, 47.83666964500181, 47.64785066727669, 49.10184975593321, 53.333165414871715, 59.62587879550073, 61.47355833361226, 58.67139747065883, 59.181862569624386, 59.4985233583758, 56.48438584419989, 56.94818258285523, 50.923857381266934, 46.33833992865778, 46.31771610629174, 47.57154487794446, 48.894830980608546, 50.59244455829744, 49.51716992162889, 50.127149474236276, 49.04365354968656, 48.536542077218336, 48.11083155293619, 48.52521034979051, 50.15664962030227, 53.80017849706835, 52.85491474213139, 56.00074583484281, 51.78174249587521, 56.66021000954413, 51.955585864282426, 57.00238581626647, 54.12707667196951, 62.94927558591289, 59.10735714820124, 72.30379504542198, 64.40293342836442, 77.70572247043734, 68.48272400517618, 97.29150525985226, 5.862632845678638, 0.340652578780728, 0.7049872642082553, 4.755927766523054, 81.94921708876088, 69.21899995496197, 72.5013962099629, 50.39593773503458, 50.855109999256754, 41.101607045819684, 68.78842569166615, 61.31298434349799, 59.12416058201944, 1.3247294123134306, 0.07576731379113852, 0.1413139421492815, 0.12495132298358988, 0.0740849847094186, 0.11350450616690422, 0.3739447987848713, 0.12372919057886447, 0.16056836702890936, 0.2267567089368259, 0.42974946239302236, 0.2547881571996597, 0.11990218303136288, 0.40767148257263247, 23.18105278476592, 82.53721175655242, 60.05470760406987, 53.480175848930116, 36.971982755968654, 60.651633508743785, 60.045705764524406, 67.91536884923136, 89.87331482671922, 25.42630180235832, 0.211924082269111, 2.6556902450899926, 0.14204422312398113, 0.4156951504128595, 33.3362280168841, 89.18286785002678, 66.1108353830153, 79.26071474629065, 70.2543487856465, 78.55817117998677, 68.51515416176089, 77.53604073678294, 70.00936538942399, 72.32569756046419, 62.91724551108576, 68.12931845265051, 63.58060852173836, 67.30425573164418, 61.597222820405044, 66.55762472460347, 61.74556293795186, 62.80987847235895, 55.98136540382139, 54.60954389264507, 49.97000755802278, 53.63486236141574, 49.78899801931074, 53.02615365674419, 57.97205848078574, 62.902956316548014, 59.88357459345172, 65.53794184038716, 58.239611194979766, 63.15180716976043, 75.25591204243322, 62.48243116563367, 64.01168484841624, 59.78693131477603, 55.76530556524954, 58.0230139916943, 53.34149652911771, 56.90214964651293, 62.65653341047226, 62.41537040279758, 49.342534234446866, 44.78435570193876, 49.07302033516669, 46.30618433798514, 45.73122370627619, 45.334519109418316, 44.695984701956476, 49.28913508692096, 47.14795243355536, 50.65287651554231, 51.660047038908935, 50.07670779382029, 50.28978663106119, 53.865423202514656, 53.77271406112179, 55.34361939276419, 54.886231806970414, 56.963064055288996, 59.15686530451621, 57.42969274520875, 56.036321732305716, 64.6709176032774, 64.14234292122626, 66.28684782212781, 60.598434402096665, 57.11587959720243, 37.7883574270433, 37.71180845076038, 32.44900749575707, 49.863503440733886, 60.37090555314095, 61.10216479147635, 61.29496889729654, 58.447363453526656, 60.089298986619525, 55.800599052060036, 55.9193919550988, 55.80451357749201, 57.2940650293904, 53.04751096233245, 51.97120474230859, 49.35908271420387, 51.58285871628792, 48.36728788191273, 50.741773113127685, 52.44891412796513, 47.55840886023737, 44.413142588830766, 46.01616820981426, 45.501211997001406, 43.062070415865996, 47.46917101644701, 44.93888531961749, 47.717394290431855, 51.298671230193115, 55.04682933130572, 49.55438144745366, 50.34460567658948, 53.69804390015141, 55.22686219984486, 61.460959680618785, 64.35889305606966, 59.48274366317257, 63.06648777377222, 61.567487332128714, 58.80748018141716, 58.95417682586178, 54.320524046497965, 51.82081714753182, 48.957306492713194, 49.40517448609876, 51.89967247747606, 52.67777658277943, 52.624785361751435, 53.361104457609116, 51.4045948366965, 49.389226128978116, 51.447234922839755, 51.44312820126934, 53.58400098739132, 56.187254536536436, 57.90662942394134, 59.587831804829264, 54.9804118371779, 59.87116813659669, 55.11486284194454, 60.990016383509484, 55.309843863210375, 66.75883446970295, 64.53445050024217, 74.49877692807105, 67.99143929635325, 83.88380066041024, 73.14014634778424, 102.77395109976493, 7.67242621029577, 0.7392823852358327, 1.5598848197729358, 4.766097001491055, 92.83208416354273, 75.72102669746646, 82.14571214491322, 57.27545338292276, 68.04951390912457, 42.71235581367247, 76.14033591362738, 73.81774363979217, 74.83245295862999, 1.9351130916226296, 0.413510880523151, 0.1606176264824406, 0.30635359667001233, 0.08747938089072706, 0.2788012138297481], [0.08107733732509999, 0.03144785758077858, 0.05755715485241625, 0.08028474275863941, 0.024478198404634194, 0.07322027062576625, 0.02172540509021811, 0.18899628111431677, 22.924482707054388, 63.614211467004594, 52.41999841505482, 49.389477160669145, 24.77521973271524, 44.41284841106784, 40.87915766623713, 51.958100103562884, 74.20091213718538, 43.750183582305915, 0.1734356870574336, 0.6489910173320002, 0.22663600412347626, 0.25342173213439606, 10.095927830665342, 68.6778776107296, 64.76121448701429, 70.98696124169135, 65.50680214358916, 69.62265891413536, 66.37132783089915, 65.70642332876882, 63.38832216878092, 67.14753350903912, 64.40937788255754, 62.495688776816095, 59.12450967296478, 58.60873368478591, 56.875685414960316, 57.00405674595987, 51.98314051474295, 48.937549514155236, 46.53182652688796, 45.34286983551518, 44.40606271066974, 41.914675158839074, 43.758687280839496, 53.77147459214734, 56.4418085159794, 58.66310950248473, 58.272719921604285, 52.468376928760165, 50.4773033818891, 36.45697555234356, 35.51887012297107, 62.72553182417347, 54.936630341314505, 57.698563375780665, 50.406214344886045, 52.6266602546938, 44.03836796360631, 55.550826441857126, 55.12042476284889, 54.88520414598527, 45.871683782146825, 43.53878744186894, 41.716175771528675, 43.550531018164854, 40.50181781091998, 39.781019533834154, 40.63929688545966, 42.382943399490856, 42.857299158650065, 46.31222086568033, 45.91032697308449, 45.93177841555688, 46.44816629348263, 48.733437215128255, 49.49218834600141, 49.21844220930531, 44.32053542906239, 48.9764476591541, 52.40758019108927, 52.84013917369228, 54.09766281804731, 58.061688561593336, 55.44239251844345, 58.638888866670676, 55.018517663401944, 57.087309052867276, 39.151632093614154, 39.84144756870885, 37.471402460528964, 50.33091660468809, 56.297218184317316, 54.67700473723873, 56.16062556543658, 53.45409993202456, 53.356362312070786, 51.168405394400324, 49.09739002104729, 47.65924907499745, 47.06377052491712, 46.36842058550927, 46.624402307694965, 45.52436967049876, 46.59425104818037, 44.56608756895989, 45.920015227410104, 43.312756938319055, 41.61060910071097, 42.826688981825306, 39.74640461706346, 41.66889944384175, 39.560735302586714, 41.53982993095152, 41.76121634821738, 42.42843897111955, 45.23913098919777, 53.97582615575483, 50.74413830234159, 44.875570420295965, 45.595843099778705, 49.85146960904522, 57.891430239523615, 57.46666108408282, 59.748711739816976, 58.01276091606387, 56.67157311593333, 58.81686249086934, 59.169546327283314, 52.21765118260538, 49.96667354337631, 45.80077125180153, 44.448212500541445, 43.86918829333398, 48.68383099955898, 45.843854565774244, 49.55814692281908, 48.39243419708745, 48.71803406746157, 46.060836161336596, 48.560786247253425, 47.69593892558929, 50.39693009468817, 50.10008119767713, 51.124600364315896, 47.81366886631135, 53.41812787517425, 51.95662529237809, 51.17391632449243, 54.69462010168261, 57.91040666641728, 49.93025825869653, 59.85621998386999, 55.40473384241904, 71.7779307211599, 70.57797570382395, 86.12955370256978, 2.4739812987466014, 0.4240714025593573, 0.11634993291790448, 9.957702525200384, 78.4590607304727, 52.05471984801754, 62.6803304303077, 40.52468130665441, 56.82445141576952, 35.33328710063812, 42.901265005911554, 68.24334175355973, 43.990118888116655, 0.5712911318386755, 0.07473837343915817, 0.0417188692447399, 0.04313503639892705, 0.0384810752415609, 0.035213514892083984, 0.03687143641253633, 0.06133587587805045, 0.04977000516749198, 0.06450782845457716, 0.017003815606116288, 0.09759891207420057, 0.01299152969412746, 0.17031731083989146, 30.766373449756255, 74.12742260963687, 60.12156048128682, 60.08041089580905, 26.968746416030395, 51.40586960700251, 49.31523453804755, 62.40308553941789, 78.67375558422458, 49.94771672833351, 0.11056089758752816, 0.7565879437231249, 0.5669056768378904, 0.17977270508004775, 10.682516328750118, 71.81902931582543, 65.09000716670867, 72.91350395448747, 67.93265081221058, 72.77302818913614, 68.88228016514933, 70.20851981255316, 66.36667589987478, 67.9558712436307, 65.81621046989196, 65.25182062579741, 63.88642395696333, 62.274494555688676, 59.350089103944846, 60.95051027113392, 54.05469717517976, 51.206911302381954, 48.06806202857725, 48.44517830879458, 46.08998329408708, 45.6390283953759, 46.8222584262971, 57.394430637359626, 58.48206858481131, 60.459158882018066, 59.74255361864644, 53.80696027509628, 52.045812145356216, 38.92067509312784, 41.19574785232544, 63.44432969247142, 57.141261254587484, 60.572621283992646, 52.03054235827539, 55.64763838245023, 51.37876210674163, 56.98614720375308, 58.28859767606182, 58.621559835249386, 48.08122550287555, 44.9085497087048, 44.14107522656841, 44.14084380672824, 44.710748503285075, 42.49341695539413, 41.56066163893669, 43.632198687522646, 43.29400800889538, 46.79428408222814, 48.41068106312906, 49.24276874911401, 48.09159232724098, 51.22034149785196, 50.64959741407826, 51.09657895180487, 48.34918222119732, 50.77300302443966, 54.16058155798144, 54.32710578364711, 56.628070108352176, 62.09171210565875, 58.27646970748902, 60.6808747783784, 56.37955657897457, 57.885778104105306, 38.43460713663409, 39.92160120318013, 38.968269132798724, 50.630511160819765, 59.40716743469239, 57.32438102845223, 56.65298500368672, 55.40304330087478, 56.04766522684405, 54.462702120504076, 51.29855355908794, 51.345010111408854, 49.52594426370437, 49.99612662100023, 48.52454746923139, 48.47372139653852, 48.49987576084752, 46.78276015866188, 48.39079856872559, 45.96793090143512, 42.47906500293363, 44.46251738455988, 42.74819843230709, 42.59885026562599, 43.04856961773288, 44.71414135348412, 43.68554684423631, 43.136505234626036, 45.95015471981418, 57.22710624817879, 52.85733092215754, 46.61987197014594, 47.98955186720818, 52.47234636737455, 60.21763501628753, 59.488866483011556, 60.13908563121673, 59.90769717001147, 59.18623993473669, 59.51743702734671, 60.80831650764712, 54.02889974655644, 51.62931919097901, 49.0837872412897, 47.165042200396144, 46.30042629857218, 51.485976173031716, 48.94126792107859, 52.375404988565755, 52.67073985069029, 51.85481232981528, 47.17400089386971, 50.506627021297334, 50.918130720815356, 53.22651616988644, 52.42969451412078, 54.018387794494636, 52.146436629756806, 56.33280192652057, 54.983318313475586, 54.20425322748, 56.55066605537169, 60.62536539569978, 52.054280542558246, 62.808340903251406, 58.58252048492432, 74.4545796609694, 73.33145603056877, 90.48702455336048, 2.63985465611181, 0.5636890881484555, 0.21435825003971978, 10.787497585819615, 86.55981417625182, 60.74915932070825, 67.32604057558122, 46.798724205263206, 62.397154915717344, 35.18261709520894, 55.76499177563576, 75.49703582640618, 58.152005057181086, 0.8238709333442873, 0.02618099352525127, 0.1226282609446395, 0.0863012678981308, 0.03227306642539559, 0.02019122209129555, 0.16660189165944056, 0.13611318573596018, 0.12207159081534033, 0.24789705842493043, 0.12823079216984973, 0.13311965120655875, 0.11351306336901842, 0.31015428143643564, 38.1530947069968, 86.4879406652143, 67.37008094787598, 63.24689326747772, 35.031354811883745, 61.09880332023867, 58.49695397961525, 67.08386559640208, 86.70989974852532, 57.47469409819573, 0.387209335402135, 1.8535505908150829, 0.9403004857801622, 0.4142574485271208, 11.373932130875128, 75.9221109267204, 68.5233989838631, 78.13656345490487, 69.81694959825086, 76.06308091071345, 72.7465678799537, 71.61801568923458, 69.40011932003883, 72.81297360697101, 71.45077366982737, 68.73604636038505, 66.66326984282463, 66.44439374246906, 62.96842459709414, 64.60102096680673, 56.619621323001006, 54.20773236982284, 51.930447393848056, 50.71301037265409, 49.085681746082926, 47.957306062021566, 48.79608138915032, 61.212293178804465, 61.16341260171706, 64.33156198070895, 62.37162028589557, 57.04601433969314, 52.726602246684415, 41.295540794249504, 47.92702928666146, 66.92188739776611, 60.28506055954964, 61.64551111959643, 55.04451905527423, 59.04518758097003, 51.06735729402112, 60.36514751372799, 62.88596853133171, 61.49942636489869, 49.80445215778966, 48.1964921951294, 45.671038858352176, 45.97225335336501, 46.3703582363744, 45.55576824372815, 42.89306725225141, 46.83305671138149, 45.44143899794548, 50.57315434178999, 50.35696898737262, 52.462261953661525, 52.17857653094877, 55.13612993301884, 55.94407543059319, 55.437654295275294, 48.71557474136353, 53.704025514664195, 59.90760303312733, 57.28608692845991, 60.845802599383944, 65.05550599867298, 60.393463104001945, 67.23491607173797, 57.12390084420481, 61.75049727962863, 39.105477563796505, 40.63111089891003, 38.73154232578893, 52.842233719364295, 61.408796079697154, 58.820808395262695, 60.423308418643096, 56.540287463895744, 58.20695354092506, 56.945719334387014, 53.55733279258975, 53.08347909681259, 52.17547001377229, 51.82306466564056, 52.211724481275006, 50.71535202764696, 52.211151815229854, 48.77857977344144, 51.96314034923431, 47.47308554187898, 46.58844986269551, 47.06198584648871, 45.13365453289401, 45.94831120583319, 43.87127107189548, 47.93513682580764, 45.50471075119511, 46.084797920719275, 49.30500891900832, 59.95176107652726, 55.72267724621681, 50.68039194230111, 49.52046863494381, 53.79787998814737, 63.96998220874418, 61.94976545149281, 64.25953941960489, 62.24943061028758, 59.78417781091506, 64.67937031099873, 63.78565042249618, 57.090909788685465, 54.422089899739916, 52.7303167312376, 52.237376782201956, 51.489486694335945, 56.44113386830976, 51.759424209594734, 55.418454293281805, 56.88917444598291, 54.098886597541075, 51.71945525753883, 52.477861219836825, 55.16382578880557, 56.09130159501107, 57.46592367849043, 58.16192473134687, 55.4474994444078, 59.388900956799915, 58.84298547621697, 59.137528019566695, 61.081937128497714, 64.88946814690867, 54.438603078165364, 64.10862622722503, 62.296565732648304, 77.18996217173915, 75.59728376327023, 97.08383929344916, 4.758201270334182, 0.8274539572096641, 0.4288975419777055, 12.29013014224268, 95.17741049489668, 65.12740304393154, 80.23758103770595, 53.979485727125606, 74.75683750644808, 46.33701024516937, 58.82925325824369, 85.13470726628458, 72.91082889802995, 2.3309312328215572, 0.179782526327237, 0.15546298856216093, 0.1686184036154901, 0.07259578639340979, 0.10195633591783625], [0.1100378740398634, 0.020558913651433204, 0.12685512808421928, 0.011004262186977412, 0.02524005752357264, 0.026813751507189967, 0.042962551702775305, 0.0484770211210895, 30.768428771726548, 64.81220922162457, 39.52684210192773, 37.70314393504974, 33.7792597278472, 56.96901036847023, 37.13995041385774, 49.816438921036266, 65.70551333888885, 66.36677003675892, 3.075337520530147, 0.12710461227764047, 0.6210102381244783, 0.18784016250602661, 2.2925253452793246, 53.8380999718943, 72.65296443816155, 65.28357613471248, 68.74775855771958, 63.71409070107245, 64.96182803184756, 63.564789602833415, 64.02663300114294, 62.35400099908153, 63.427424277028734, 62.00978948223976, 60.579485431794204, 55.38401980553904, 55.01760767352197, 46.57658469292426, 45.906518351647165, 45.72856433929936, 44.96813051162228, 45.06611131852673, 43.64979051774548, 43.229622302516816, 51.51691582895095, 56.36847196086761, 60.631378389173946, 56.23300113985616, 55.38025825254379, 47.88955103966498, 49.51779750085647, 44.881034281946, 35.26361403926727, 59.34495079901911, 59.75222618349137, 58.256904925069506, 51.57143285197597, 50.11431940140263, 49.53949213027955, 55.581118906697924, 52.905615298978745, 55.90645597827051, 51.04587839495752, 42.245899708040305, 38.42813914821994, 40.4110384756519, 39.87625075924782, 40.57529164898781, 40.088611802747174, 41.23407333127914, 42.72719414003434, 46.92262011189615, 44.95200564784389, 45.980717828196866, 46.9599610759366, 45.53781947781963, 45.36221496520504, 48.102461214988466, 50.151738812846524, 46.23356949898505, 48.66889069157262, 54.11865534320955, 54.8361627517208, 54.48305137695805, 56.37981545540595, 57.73301747537429, 57.31735606347361, 55.04424841173234, 44.72623402072538, 38.17921769234442, 40.6808896987669, 53.84450520238569, 56.688564823519805, 55.0669942363616, 56.05708675999796, 54.03035494589037, 53.35718600980697, 52.834620398859826, 50.95933914184571, 49.5503649403972, 45.12824558442639, 48.86205565544867, 49.383715198886016, 46.50261271384455, 44.565750245125066, 43.88395993940292, 46.10925389874367, 41.96130429544757, 42.881406045729115, 39.82177688229469, 38.375520552358324, 38.672287079595755, 39.889327941402314, 40.498758362185576, 43.03762228258195, 42.44237515234178, 48.208859428282715, 55.30922412872315, 55.404247468517674, 48.36977466460198, 46.2143498851407, 48.86520531869704, 54.344556408543745, 57.76685576285086, 58.32956683251166, 60.36086820787, 56.7777555988681, 57.74874617976528, 58.42888516764487, 55.13509834966352, 54.76659167197443, 49.1477846330212, 46.81379787383541, 42.4721694761707, 44.612410760694935, 47.819317079359486, 48.52357472142866, 51.007376409346065, 52.08839339594687, 48.17323646237774, 47.45345800153671, 45.09232844075849, 47.959639872274096, 47.84785232236309, 50.50683882928664, 49.436400475040564, 50.951631684457105, 48.41050063410113, 51.00701555129021, 49.548537115896906, 55.22510497800766, 52.280005101234686, 57.425546799936605, 59.130091205719985, 73.54762569550546, 77.6908488427439, 75.58776024849185, 0.5751565050694251, 0.06047604177447577, 0.48590784411757226, 19.603280482753632, 78.35596515286353, 62.84190070244574, 61.43984556198121, 46.84259199327039, 48.30369841667914, 71.72991306551042, 49.45145453176191, 54.935634059290734, 51.8879210564398, 3.745920388929306, 0.2104255223586675, 0.07809787583086761, 0.07331907298536071, 0.05183907075514717, 0.03514103531356781, 0.06113246804283512, 0.02874397898032781, 0.045336156392530094, 0.009679397391606002, 0.021596001348488277, 0.050959295382903474, 0.03286606827450376, 0.04715587568259047, 37.761089109605365, 72.10765300258514, 50.86651232934768, 41.49618571804416, 16.770556511417514, 59.379742222447554, 44.72485726879489, 57.70556088416808, 73.29157337065666, 72.35004763449393, 4.352742433547974, 0.24276672081360895, 1.0694777412760643, 0.37438903785040306, 2.7871281341198952, 56.146795288209, 74.83818746382191, 68.78301282082835, 71.83206727427822, 66.36999422504057, 68.14489810697495, 65.6695334372982, 65.44496205545241, 65.06326052450365, 66.52610455789875, 63.013010178842855, 62.39192247390748, 60.09183676012101, 58.468199083882, 50.44909761797998, 49.055201007473855, 46.42218451346121, 47.08589661505915, 47.62209246235509, 45.42352161099834, 43.5905784176242, 54.07537591072821, 57.60002559231174, 60.706174065989835, 57.77353948162448, 56.2447839398538, 49.689024648358746, 49.08954920307283, 43.09030363636632, 39.39223812472436, 61.41181630472983, 62.56543636322022, 60.01498576133483, 53.72553579268917, 52.16028651883526, 51.491502792604514, 58.72964466771772, 57.11573446950605, 58.83122621044036, 52.91439356342439, 42.36430821880218, 41.667714888049716, 41.85228201650804, 42.059277257611676, 43.682456016540534, 43.03098955462056, 42.26801403107182, 44.93248793386644, 48.46851641131986, 45.347227588776626, 47.466299841480875, 49.21163297468617, 48.21334269738967, 47.36807192525556, 49.35691364349858, 50.91635388712729, 48.99048974437099, 50.59300937960225, 54.74814476505403, 58.255190849304206, 59.20332185683712, 56.55798127574306, 58.323585217998875, 59.302279333914484, 56.59290998212753, 45.02566383730981, 37.66568922227429, 41.10621583077216, 54.850004796058904, 58.44027573062528, 57.65922592532251, 58.21575141722157, 57.850135526349476, 54.56638997600925, 55.67868394236411, 53.663381914938654, 52.38284964715281, 47.579617115759085, 51.499986879287235, 52.4521069372854, 48.09519698542934, 46.85248421084496, 45.84603932596023, 48.146819299267186, 44.245979016827, 45.107798268718106, 41.783722908266135, 41.727833055680804, 42.180670692074685, 42.28584512587517, 42.46002974048738, 45.14610413582095, 43.989765874801144, 51.1601056591157, 59.11069900758805, 56.781521074233524, 49.17419002902124, 48.56507339785176, 51.73936913090368, 55.14255085299092, 59.86215845231087, 59.20570665790189, 61.45096155904955, 58.3625735775117, 59.18251368307299, 62.01832455973472, 58.63433499490061, 57.02905793343821, 52.369325314798665, 48.331841422665505, 45.32199105908794, 47.55952281336631, 50.35642770028884, 52.266739645311915, 53.97429643138763, 54.91296275969475, 52.392624193622225, 50.36541777272379, 47.38132169169765, 51.14799338002359, 51.42775643256403, 54.474790865375155, 52.108750497141195, 54.7603198020689, 51.5098947863425, 54.37445663636731, 52.955496080460094, 58.56524636668544, 54.72254345493933, 59.348288736035755, 62.572900633658136, 78.58445106014129, 82.05092414732903, 78.79276029525265, 0.6261908311036326, 0.3388338860484862, 0.5502136015603619, 21.888527870178226, 86.56804330887334, 69.14574576962379, 69.10973841144194, 58.61346406321372, 55.84961691210347, 45.89772047535066, 57.83189258267803, 63.57925530402892, 66.50338618986069, 4.881088147240301, 0.14291460625827312, 0.05193002837439699, 0.03089137897346049, 0.01368587539951888, 0.05669937769491827, 0.28917671031048225, 0.12114669286435652, 0.35818744270551595, 0.1330727513038343, 0.12833167062771897, 0.16240685547311462, 0.19245182794909324, 0.1844055145498245, 49.10361482251076, 82.13631414598035, 56.18446180897375, 50.48935290305845, 42.25895727834394, 73.85739095749395, 53.36489738956575, 63.799210056181884, 79.17652499291205, 81.53343800575503, 5.56386738054214, 0.4253816580580127, 1.4801978247780956, 0.529913742455744, 3.5971897504022046, 59.63005611973425, 77.3252211847613, 72.97098236699259, 76.05490669127434, 69.08953036031416, 71.04287855086788, 70.67192431419127, 67.94771271367227, 68.88278222853138, 67.71839526391798, 65.23635079783779, 65.33186051153368, 63.06891964327905, 61.468769119631865, 54.51871748893492, 51.823233327557965, 49.95768739331154, 50.606443497442434, 49.382648314199145, 47.80928757882888, 46.70080223391133, 57.05859730320593, 61.788210868835456, 65.5889561868483, 61.53235466249528, 59.0789552657835, 51.61284915862545, 50.29180272932976, 47.28789867893342, 41.575386216563565, 60.938296010417325, 64.72528949860605, 61.973644841101866, 57.76644783635294, 55.11749867470034, 54.79027102070471, 62.64812384882281, 61.56094874105146, 63.47630093174597, 57.990466164004424, 45.23408682115617, 44.050641059875495, 43.60290250470562, 45.08556235221125, 45.33631163258707, 45.78622318083241, 45.83768859986336, 46.124253042282604, 52.03500209316131, 48.0069475789224, 50.492396662312174, 52.936649091782115, 51.416001089157604, 49.96436718971499, 52.52909521902762, 56.36291003996327, 52.12946061165103, 51.93880596468526, 59.85442746070124, 60.42645808189147, 58.60750598292197, 60.221945701106904, 62.92206218165737, 62.63677250954413, 58.19308011762558, 48.68185412499213, 39.150773094546416, 41.09458992558141, 57.19427600983651, 63.38967538649037, 60.91338895982312, 60.28647653518185, 61.95338972153203, 58.28308674596972, 58.847609950650124, 57.379105937096384, 55.42258454907326, 49.44157408129785, 53.37502494935067, 54.30236739497031, 51.745801817986276, 49.38992431086879, 47.628717345576135, 51.6385720622155, 46.458333076969275, 48.84823322296143, 43.92330131223125, 43.15569739187918, 43.59434389298962, 45.21960935285015, 45.13576084567655, 49.2117271115703, 47.40607184748496, 54.2503293098942, 60.49589972342215, 59.14492168734151, 53.620165240380075, 49.9597897837239, 54.09506620899324, 59.18789909731958, 61.380127476107695, 63.82746288853308, 62.92555309111073, 59.967893785045995, 61.47595097941738, 65.04314268788984, 61.050150240621264, 61.28152693471601, 53.679247902285674, 52.08353750167355, 47.054078348221324, 51.03843373637046, 54.733298593951815, 53.78341820932204, 58.20483546103201, 57.39667423309819, 53.81385972422939, 53.09345368416079, 49.08003745540496, 53.802461316508634, 53.94213691834481, 55.77387594407605, 57.37250066572621, 58.39700414288429, 55.076098057531546, 58.197198606306515, 55.741637983629786, 62.09950193282097, 56.869895996585974, 64.90754242866271, 65.66051198590186, 81.0743010428644, 82.98609564381262, 85.75463002727878, 1.2720574967322813, 1.3022450381709685, 0.6108304004996055, 23.65476723640196, 96.22076880547309, 76.23823042838805, 76.6719739667831, 62.02616537770918, 69.75971437269642, 95.40428823040378, 69.6494722366333, 72.96938203996228, 85.49099968325707, 6.459015992379959, 0.3440999437964732, 0.21582017562562422, 0.11006247312311204, 0.176703940716482, 0.12877729631239368], [0.026154280039331606, 0.002544681220540717, 0.018726799058757963, 0.01586609938737726, 0.12709183393106346, 0.04947993746628204, 0.052150895353406675, 0.20155085340863277, 24.052585786388768, 59.33726687585155, 48.96620635063418, 46.315260702563876, 51.4420573942123, 92.79198185090097, 35.65511365090647, 61.94625100781841, 54.33240490574991, 74.96307573010846, 9.805121344904746, 0.11666002998789472, 0.5764541354390883, 0.085262437351048, 0.17404678007287366, 39.066857907079886, 76.45295666110131, 57.83272412515456, 64.20564997580745, 55.39266078702865, 60.33460401719617, 58.420299099337676, 58.98210802385884, 56.40009018682665, 59.06323440613286, 55.28825906015212, 53.60172617820002, 48.069819250414454, 47.8641301585782, 44.43446851545765, 43.852024001459924, 43.59823096183039, 47.18043750332248, 46.20693268314485, 44.88885941043977, 44.67005391274729, 54.02203559875489, 55.28830220622402, 57.626470212013494, 55.93896458225866, 54.92000733652423, 48.63504848172588, 52.31895031467561, 47.25601373180267, 46.224465677815104, 60.52767484418808, 57.0467282110645, 60.00800002005793, 50.75681932510869, 50.831536554521136, 49.45153690153553, 55.797461155922186, 53.04825229029502, 51.992828769068566, 51.855663484142674, 46.71161620847641, 41.7098254542197, 40.78364403017106, 41.639313005631976, 42.53153062635853, 41.71072367698916, 41.40093488077964, 43.60731517114947, 41.13157787630635, 45.107963008265344, 44.70356664349956, 44.80597580632856, 46.99452107952487, 47.24395636589297, 44.41808869761806, 47.13527141078826, 48.690436270929155, 47.19651137628863, 49.77242992770288, 54.49053525924683, 55.8461416921308, 56.83133909779211, 56.707145091026064, 54.43035433369299, 55.98181647639121, 47.535243341999674, 36.94212959658715, 46.282371628669004, 56.24591750483359, 55.3754258924915, 54.2929615512971, 56.88985301602272, 55.33431553071546, 55.23916275270524, 51.004756266070956, 47.76844786059472, 47.79138588136243, 46.42987628136912, 45.530272837608095, 47.48351904653734, 46.18266497888873, 44.183252473031324, 45.567570655576645, 43.79726379148422, 42.06265441833004, 41.270131680273245, 39.798976144483014, 40.53097278841081, 39.182834548334924, 40.40489212159188, 40.21440613654352, 42.64918211967715, 42.10483558716313, 51.55179354452318, 56.858415219091604, 57.73841465673139, 54.721531483434866, 45.4732298081921, 49.083669570184526, 48.57895466589159, 55.592097620810236, 54.56763728972405, 57.88066725577078, 60.56285850463375, 56.92606041508337, 59.520508243191635, 58.556044486261186, 58.1914484116339, 54.36032825900663, 50.8107989834201, 47.67580932186496, 42.57444920078401, 46.102381906201764, 48.53087817468951, 51.76358976671773, 52.541882145789366, 52.10247078249532, 51.1049767463438, 50.05588393057547, 49.23307657241822, 46.72161433004564, 48.72775762311874, 48.05978974988384, 48.59576202207997, 50.659285668403875, 50.393556856339984, 50.37344294209635, 52.63261441261538, 55.35872444029778, 58.87903205810055, 71.56792702213411, 71.61239885514783, 85.11903347507601, 51.2371959224824, 0.8809401936108067, 0.4548673097404742, 0.391139151949075, 35.56904115984517, 77.27341451952535, 64.33943025527462, 59.17022881969329, 36.05628582739061, 78.42255130890878, 74.34618888362762, 48.572145431272446, 55.23094538719424, 55.49812939859206, 3.4740175210660507, 0.10608408660177263, 0.10056721932825544, 0.03260498934034859, 0.02143895523923059, 0.05132953035494974, 0.021974785861769514, 0.06559825502336025, 0.07011755324539638, 0.050866453187359925, 0.05165404136923533, 0.0744547447069518, 0.11638810707917137, 0.15271474006435565, 32.326086298111946, 68.06374426810973, 55.80714941024781, 34.710591223932084, 41.375070771863385, 98.68732775411299, 40.25951339352516, 66.37731336778211, 60.50339929519161, 81.16664932620141, 12.671337454549729, 0.12276275534062617, 1.0878131057946914, 0.04683331436207218, 0.09340985903456327, 41.72508347419001, 81.73650695431618, 59.84151501809398, 65.95724321180775, 59.769982753261445, 62.41493501970845, 59.757980300534165, 61.22555078998689, 57.878949257635306, 61.325841872922844, 57.77432787802912, 57.381243628840295, 51.13006422596594, 49.09653102197955, 45.583989697117964, 47.280920782396876, 47.51772603681011, 50.97139650775541, 48.59029816042993, 48.09355743469731, 48.861981130415394, 56.89570126994964, 58.370418317856334, 59.70991949881277, 56.31060523371543, 56.19732326076877, 49.402291544022106, 52.58127450942994, 49.10516808109899, 49.829312139941806, 61.92092426361577, 58.67648478477233, 60.83967193480461, 53.81501290106005, 53.70313121426491, 52.5399641067751, 58.14210107249599, 56.487570808779815, 55.70300263743247, 53.04000354582264, 48.66593714683287, 44.680067723797215, 43.261624920752745, 43.6927757724639, 43.325555632191325, 43.733678248620805, 42.07199358171032, 46.14811674241097, 43.77436499441824, 46.81912837489959, 47.85599516284081, 48.07367494029384, 48.13440499767181, 48.27133494038736, 48.04882672525222, 49.840616410778416, 49.63186787020776, 49.69670072678597, 53.09199456245669, 54.058329289959325, 56.6610219401698, 58.04150012231643, 57.1570566392714, 57.249008763221006, 57.2024384621651, 48.258422497780096, 36.57242659599551, 48.36302426553542, 57.775406529826505, 57.66163033823813, 58.12930237862372, 57.355391287034564, 56.57832660982686, 56.18228097115794, 52.59197473526002, 51.11488465339907, 50.763832522976784, 48.71495892924648, 49.89817719305716, 49.309962872535955, 48.93554126062701, 45.75775461812174, 46.201947350655836, 46.403635624916326, 42.97570374704177, 43.86374796590498, 40.84746883761498, 42.200941501125214, 41.53955536503946, 41.74925704156199, 42.60269418839486, 43.63422655290173, 44.721876267463934, 53.3456346296495, 58.08168872710198, 58.919204973405414, 57.92639424723964, 47.96129119011664, 50.26869212427447, 52.95421738778391, 55.701386620921475, 59.47675812628962, 60.21834496528872, 60.99573127685055, 57.76127423009565, 61.62467156687091, 60.441178737148164, 61.12986456963324, 56.90466388579338, 54.77791947703208, 49.632118901898785, 46.33424497419789, 50.06147723044119, 51.80207998521867, 55.912484661225356, 55.39736763123543, 56.11825612283523, 54.623013311816806, 51.78385273102791, 50.448144482028106, 49.597139204702074, 52.42440323675833, 50.865665097390455, 50.82824568594656, 52.73549033749489, 52.449337743943744, 53.43291913309405, 55.81335852223059, 58.579684611289736, 61.56578502347393, 76.52450853778471, 74.12098992255427, 87.26923757983793, 53.28303752406951, 0.9857127070426942, 0.9171860809287719, 0.26598373548157755, 39.61112991456063, 84.1660544180101, 69.44496770058909, 66.81593633467152, 48.39770586259904, 95.23726586372622, 66.11461654786142, 52.632465362548835, 70.11745022189233, 66.31761489375945, 6.257752804986893, 0.1189349817052003, 0.13012970196864299, 0.09595195327194468, 0.037144577401059295, 0.06583117639585849, 0.08195872148198467, 0.15367066457627282, 0.09932775035380356, 0.1997876560856258, 0.23670273652720838, 0.15617238598004465, 0.18056994213932948, 0.3050937497567746, 44.44236816898469, 80.90408586686658, 64.03352068316552, 60.42301031851, 59.61433133771343, 106.99636690078243, 50.88736757155388, 78.83855788938462, 66.49668678160637, 90.54435391579905, 13.357237423619917, 0.34448399899467347, 2.001584028044055, 0.26693463445671145, 0.3006021762567182, 46.32996566833989, 85.69822634420088, 62.37658992890389, 68.75328909966254, 63.09641938055716, 67.82831576562697, 64.62613982539024, 62.905682363817775, 61.104074985750266, 66.09077638195407, 61.105808673366425, 59.82900657961446, 52.95873595822243, 52.03112286906089, 50.78528788781936, 49.85502719879151, 48.49649467775899, 54.02192185001989, 51.37553791845999, 51.10304301784885, 49.52114720498362, 60.48916501383628, 61.27101498265421, 62.6418205999559, 57.80480861663819, 59.97394600222188, 51.73499568816155, 53.71280770148001, 50.75755280833091, 52.43131053063178, 63.63865567791847, 61.64593473557503, 64.4139749003995, 55.96718995801864, 57.367997784768384, 54.422666488155244, 61.03817132211501, 63.21044268146638, 59.803228762842, 58.325260070062455, 50.52272442848452, 48.58098253127068, 44.6037305555036, 46.463165437021566, 47.11369053010018, 46.31016946608021, 46.42880547431208, 48.8202549565223, 46.57716912607993, 49.2294797589702, 48.89027710883848, 49.06948235727126, 52.49732794300203, 53.058062138095984, 50.15855196983584, 52.329587782582934, 55.282171541644686, 53.94416870609407, 54.8035757003292, 57.40185960646599, 59.62626318777762, 59.28318915828582, 61.974233196627715, 57.7688757834896, 59.16326269026726, 49.69898354622626, 37.45168078330256, 49.13391905446207, 60.988553339435214, 61.00568625234789, 59.82309949013495, 62.67141488290603, 60.25968674690493, 61.15853709559287, 57.884279758699485, 53.314855790907345, 54.202715658372455, 50.57034984711678, 51.91602483872445, 54.31959444476713, 51.7726190628544, 48.197272746793686, 49.29821929624004, 49.21180948134392, 46.948656805099986, 47.239492708636874, 43.66911211321431, 44.42910663543209, 44.85164788461501, 44.83557401164886, 44.08879003217144, 45.770953393751576, 47.07203888124036, 55.0146423616717, 63.93956030568769, 64.56855158652029, 61.04548262011621, 50.65394340022918, 53.002921458213564, 55.63412189483643, 58.78740941324542, 60.31922048138034, 62.85367173533287, 63.29926867638866, 59.37490986239526, 63.976258001019886, 63.9897862557442, 63.86376050210769, 59.19112328560122, 55.97528965242448, 52.47473901317966, 48.61096905123804, 52.19554470431421, 54.212827528676684, 57.713076145418235, 58.00588107878163, 58.40852414408038, 56.828303183278734, 56.63320056853756, 52.94944386328421, 52.055621993157175, 55.876971521685206, 53.967224397966945, 54.95855246820758, 56.68764306652931, 56.78575723401962, 54.112093217911266, 59.94257880795387, 62.71466685879616, 65.8962817345896, 79.68160075526085, 77.65604957457512, 89.23818895893713, 58.78571102696081, 1.073812328038677, 1.540648535855355, 0.5259171536853237, 42.87274153001847, 93.58300624355194, 78.52323855123213, 74.03799256970807, 49.282219948307166, 95.95788371178412, 100.69899374438872, 69.50799234451787, 73.0704144508608, 85.10302236003261, 9.492682007051284, 0.280275963727505, 0.32088459920017953, 0.15525677301470311, 0.17526651462239606, 0.17835246999898266], [0.018854680200738293, 0.07201031901903691, 0.04210137694533314, 0.00949879216345688, 0.04120839038683523, 0.023914547299125025, 0.03815990054018555, 0.26661778049122903, 32.846406352135446, 58.54175921409362, 45.42136430740357, 42.74275810487809, 64.24023743598693, 93.28602006358486, 39.78238059628395, 60.12264305545438, 56.137228627358716, 73.86588681128718, 20.68122625350952, 0.18292406904360942, 0.31668950172681964, 0.045459385465590224, 0.1347205298201692, 23.988831581607943, 83.2240972211284, 56.80070930911649, 63.79102014726209, 46.818606699666674, 51.92486586109285, 48.14891776730938, 49.97908392260152, 46.857293036676225, 48.39734892691336, 45.62010295929448, 47.53314095158731, 44.765944096349905, 43.33918194616995, 42.20455400405392, 46.986158586317494, 46.5484691435291, 49.51121576370732, 45.3836860195283, 45.60827701322494, 49.84444072169643, 56.83542228514149, 57.04093487031999, 58.0173893128672, 52.54325105297951, 53.0844557669855, 53.811671041673236, 55.1710037262209, 53.889490865891986, 58.453392136481504, 57.65286384090301, 59.09841414420836, 55.17440049879013, 49.799757080693404, 49.95560461475004, 54.956187278993674, 54.25502830936063, 50.790571320441465, 51.065941318388916, 51.49579386557303, 50.555331091726984, 45.80470538908436, 38.361670663279874, 41.404429712603175, 41.943147643919914, 42.804833535225164, 40.33126138871716, 42.16529107862904, 41.122285781368134, 40.48810912716774, 44.70193101513771, 47.55282732748216, 45.22839546203614, 43.684844739975475, 44.369663115470644, 46.648917121271936, 48.89661173666678, 48.11202787583875, 49.70848352678361, 54.08463662670505, 52.03290362511912, 55.50620948114703, 56.729192733764656, 55.251620200372514, 60.81848329113376, 49.41879687770721, 38.44471508456815, 48.59506776255947, 55.6124351101537, 56.17236521936233, 57.2956378998295, 55.42544787929904, 54.11713738595286, 52.01302113071565, 50.88754407821163, 48.12607388342581, 48.25693984185496, 45.80952205965596, 45.00326318125571, 45.14739067323747, 44.514818268437544, 43.82454387603268, 45.04021975301927, 41.15941101504911, 40.91331366569766, 39.46628070646717, 38.85364178688296, 40.73128431074081, 41.02696826381069, 38.75451957025836, 40.30766833213068, 41.39276458371071, 46.780544019514515, 50.69908988091254, 50.96861162493306, 52.35927620241719, 56.23158516422395, 49.4417231313644, 48.885260397388095, 47.85498711370653, 51.94053180756108, 56.25537041694888, 56.91434429537866, 57.391261362260394, 60.59441397267004, 28.543768275168638, 40.75271221899217, 62.23353716634936, 55.24346559278427, 56.033913397019916, 47.887205462301935, 44.3939112078759, 45.037964390170195, 48.27927381761613, 53.874303448584776, 57.924429139783314, 56.44187127390216, 54.75840960779498, 52.64452272845853, 50.43889161079161, 48.531282178817264, 48.129137254530384, 46.89618333693474, 46.688066297961825, 51.20920588893276, 51.56534141109836, 52.84346926596857, 50.924245695913996, 58.83670576157109, 65.6980255342299, 77.7700807202247, 69.0388298034668, 92.09126610909739, 22.87233283442836, 1.3747306841035045, 1.4131944266057785, 0.14105771638212666, 51.54237201136928, 71.72104850892099, 67.09800966324346, 66.5639397405809, 32.30719027980682, 48.15637811537712, 52.09422988276328, 48.55637358080957, 52.05418248330393, 60.624055324062226, 10.573924529937006, 0.17856910434221068, 0.09157622758779796, 0.035241243444503315, 0.04265324753378669, 0.07851440549617814, 0.028077444181807583, 0.028189553488646785, 0.06285280657691822, 0.029464530638389053, 0.04540809970949927, 0.02024684007459831, 0.0733510724779579, 0.45396786123033495, 41.59070307208646, 66.79374356423655, 53.366450648153986, 51.43223577930082, 64.92476163371917, 96.6729082599763, 46.475732711053666, 64.56681397653395, 63.89819498985045, 80.79485570230793, 24.34798340643606, 0.12328636111511339, 0.6050169576079615, 0.06531977440200507, 0.155555531983414, 24.110123034446474, 85.09167886549427, 60.25810995409566, 66.77396697382774, 49.82764513261857, 54.659185409545906, 51.737262818121145, 53.09068056844896, 49.13965748202417, 51.70691151772776, 49.143250373102006, 48.5263752937317, 45.134148751535726, 46.291961823740316, 45.05408140920824, 49.925049351107695, 49.39440365760557, 52.21478000763924, 47.90878634299002, 48.08063322497953, 52.092523651738325, 58.60018291781026, 59.315164319930545, 62.63695686094223, 53.87926524685275, 54.37213851559547, 55.405581074376265, 58.236869458229314, 55.53998108833067, 60.364355194953184, 60.932537971004365, 59.76271067896197, 57.686051014930975, 51.953397181726274, 51.71881591120074, 59.09198145712576, 58.736967732829434, 53.978477677991314, 54.6885561173962, 55.23160434538319, 52.5832631511073, 46.077737654409106, 41.2391371111716, 43.36343788331555, 42.0430935582807, 43.2778399990451, 42.6224393998423, 42.95293438819147, 43.58574605757191, 41.966321006897964, 46.888793591530096, 49.70725974728985, 48.99136835528959, 46.77591954508136, 47.85492435578377, 48.29444946781282, 50.79572139247772, 49.412866254006666, 52.052927324848795, 55.92519706295383, 55.81482156630486, 57.33876043750394, 58.665776714201904, 56.681484945358775, 60.49907292089155, 50.624145154030096, 37.3911899905051, 51.885520565894346, 60.02133215627363, 57.14845488148352, 59.227526803170484, 57.565955884995006, 56.61398879943356, 55.55909479818037, 53.02132521906207, 52.05566906159925, 49.189173483079486, 49.90770855257588, 48.36529531786519, 48.59347920263968, 46.38116044382895, 45.91802658573274, 48.00172298185287, 44.41521360028175, 41.80424474900769, 42.18647579992972, 39.395360331381525, 41.87699687096381, 39.70682397965462, 40.876953294200284, 43.209849634478175, 43.41368736759309, 48.671714798096694, 55.07133237777218, 53.64288360841813, 55.22700340517106, 59.6686012514176, 52.14744467889109, 51.50026928993964, 50.54323450211556, 54.91964647846838, 58.46635556990101, 59.323883748823604, 59.94785831820581, 62.72861088475874, 27.738674340709565, 43.64839807633431, 66.09709924267185, 58.26492224970172, 59.40801074427944, 51.136653807855424, 47.145167550733014, 46.78413691059236, 49.85918883354434, 55.92538141435193, 59.040700389492905, 60.65958807545324, 57.80015668561382, 55.72516402890606, 51.82191541118007, 51.72797856792327, 50.98415990029612, 49.05501665607576, 49.293045689982755, 52.754698184228715, 53.74131941026258, 54.71232568064044, 56.031312865595666, 61.42121038129253, 67.87298371714931, 78.59384905907416, 71.77880148733817, 94.71387263267272, 22.322944095057828, 1.0920507364696073, 2.239279905634542, 0.04682779852901736, 58.006779301551084, 77.76732721636373, 75.60830562345444, 75.27602595667686, 41.88641055937737, 55.05072424488684, 60.5750374640188, 51.99461736986714, 63.328619772388095, 71.84574065669891, 13.733965389190184, 0.2802254632115364, 0.08488649502396585, 0.052770430657772295, 0.07559806964690648, 0.053056579819249536, 0.1607370902333529, 0.1480305873818936, 0.1704184038023795, 0.1509105263938827, 0.15317849905019806, 0.16996766831124985, 0.12236107245928819, 0.6918259962431846, 52.25780056368921, 78.6595566042008, 65.66346553064162, 57.60769774836879, 73.10954401569983, 102.48495086546868, 54.667426309277936, 75.82870360343688, 71.00731049814533, 90.45228019837411, 27.759710011943696, 0.32768543749567003, 1.0055780410766602, 0.37079081480060855, 0.2194043333011289, 28.079422404689176, 87.97485628435689, 64.07584305732482, 69.8928866847869, 52.08038783842518, 59.28820586973622, 54.55176738000686, 55.16183322475803, 52.651186835381296, 54.35103616406841, 50.35842418670655, 52.926827476870635, 47.91541122621106, 48.998612972997854, 46.868522782479566, 55.766066505062966, 52.69139505201771, 57.05764808962422, 52.2325954129619, 51.92212804671257, 56.27750827420143, 64.10706904626662, 61.19656839678365, 64.09965576664095, 59.36605315054617, 55.73066319188764, 56.23008289644795, 60.09819884454051, 57.14748605605095, 61.79508286137735, 63.135666616501354, 62.40065759228122, 58.641975771996286, 54.789957231090916, 54.336480248358946, 63.3314242670613, 62.39125959334835, 58.32011392039638, 58.754328143212106, 59.038492095085886, 56.7634311029988, 50.804209401530606, 43.67122627073719, 45.585750841325336, 45.77265178003619, 46.18827789060531, 44.64864953871697, 46.87669700191867, 45.32192830116519, 45.71647951679845, 49.45056023136262, 52.98729865781723, 51.88199827747961, 50.14218784147694, 52.27065809311406, 51.00362270109115, 52.742048540423, 51.50816502109651, 54.06785280473771, 59.59348786261774, 56.76380372816517, 61.35221196759132, 62.43340938322006, 59.36632379408806, 65.80693014206426, 52.1645736694336, 37.12396283303538, 51.076017887361594, 61.78673998002083, 61.83365937202208, 63.39345262896631, 62.93071885262767, 58.346472247954345, 59.77221850425967, 55.943918535786295, 55.67476941693214, 52.10736590047037, 52.31948767938922, 51.63090382852862, 50.772296997808645, 50.35564714862455, 50.168350050526286, 50.52458755431637, 47.005448802824944, 45.07501509881789, 44.35961400308917, 41.300569272810414, 46.07012825627481, 45.53195945678219, 42.230394578749134, 44.605154375876154, 45.24084114259289, 52.70141670780798, 58.56536011542044, 56.00102824549521, 59.64320390455185, 62.32512058750276, 55.28781583232265, 54.84754939233103, 54.14000088168729, 56.44337746404833, 61.21606257654006, 60.78410371657341, 61.699537846349905, 64.52379734285417, 32.11455091353386, 45.83335438082295, 68.04301846411921, 61.40242615053731, 64.30857689149919, 53.20586881329937, 49.97934279903289, 49.52728963667347, 53.92770651848086, 60.10399610765519, 62.516959790260564, 62.613281434582134, 60.1677385453255, 59.00279068177747, 55.572344564622455, 54.28493245955437, 53.95266848225748, 51.76420950120496, 52.16675450724941, 54.8961514811362, 57.484358818300315, 58.109074715645086, 56.8911866218813, 64.23211812973022, 73.55100677859399, 83.77362912701022, 75.59983330388224, 97.07365682048183, 27.81265416452962, 1.1576135216220733, 3.8319163937722487, 0.31534468034102076, 63.25154127613191, 85.5355421189339, 83.26308558064123, 80.45560206136396, 49.60310905210434, 62.06211782270863, 59.58976161095404, 67.40613537449991, 68.37973040919151, 88.8351183552896, 18.216071513391313, 0.3735549213184465, 0.20533630834712138, 0.11456540770708554, 0.23215358385876303, 0.3133191132257062], [0.04232460730558923, 0.029228947110353943, 0.03439143360141785, 0.07539842713383899, 0.11208596414015179, 0.02047873488927801, 0.025833733530054172, 0.2753114075429978, 19.721163395912416, 53.473845143472, 53.057842485366336, 26.86506836645065, 46.33843014317174, 64.65331400594404, 27.221874613915723, 62.34601505341069, 57.76877380186512, 74.62225314109557, 35.135325078041326, 0.08343633654857836, 0.22653284272359264, 0.35442662515467216, 0.3809513470097896, 7.376299519692698, 80.61062982005458, 61.14580900438371, 65.61824060255482, 57.64876496407294, 56.613102343774614, 52.76750472284133, 49.80076120745752, 49.14436432623094, 49.83433277376237, 47.53236824466337, 46.948892147310325, 46.35997964489845, 46.86776968740648, 47.453858083294286, 52.05047976586127, 48.469885318509995, 47.51888705838112, 42.784327383964296, 45.833370070303644, 51.0409362085404, 55.31124414936189, 55.66375540148828, 52.8792687385313, 48.15873545985068, 61.07097802623626, 60.050098819117395, 57.48688874706146, 54.98944897805491, 59.40460612696987, 57.7813999114498, 59.60595707739554, 54.62890471181562, 50.595370646445986, 50.037335042030584, 54.99562671107631, 51.291312863749845, 47.545210084607525, 50.68603623297907, 49.91800085190804, 45.689658349560155, 47.131415720908876, 46.03683517825219, 39.80917822930121, 42.88015873201432, 41.33285822406892, 44.194125283148985, 40.7982313248419, 44.00016015575778, 39.7489070892334, 46.55486260690997, 49.64838104863321, 43.8836226155681, 44.56094534166398, 46.63103111328618, 45.96496951195502, 45.91149976176601, 46.36048955302085, 51.017166645296165, 51.72971617790961, 53.40575279728059, 52.83084707875406, 55.611658480859575, 55.696895507074174, 56.48586457775485, 49.555350272886216, 39.730334666467485, 53.29278069157755, 56.954866301628854, 56.81711658354729, 54.799249326029134, 53.21212499372421, 54.151779759314756, 54.60613535296533, 53.93355869477796, 46.954422689253285, 47.964421241514145, 42.952738269682854, 45.21696959772418, 45.90867957761211, 43.711681596694454, 43.72282897272418, 44.74227651473015, 40.48258642996512, 40.86064015665362, 41.68626377659459, 41.47706416345412, 40.80573874135172, 39.404648503949566, 38.89749780777962, 41.364570586912095, 42.43226720440773, 48.191942245729514, 53.0925319271703, 50.12612181325113, 51.76309162570585, 54.61028914297781, 52.86031976822884, 46.99541145755399, 48.14355196491365, 50.09974387384231, 57.36820567038752, 55.69376153330649, 59.7763369929406, 52.450812555128536, 16.262931208456717, 46.440702023044715, 56.99363500841203, 58.66196809276458, 59.1188104691044, 51.57595142241448, 49.690146446228034, 45.267697611162745, 44.69268206627139, 53.48090933215234, 57.23601002846995, 60.24305981974448, 59.625894484981416, 57.5854382976409, 51.059186996952185, 51.72120463463568, 49.506622668235536, 47.106583195347945, 45.82899270519134, 50.22239638913063, 50.937636667682284, 50.65233130608836, 53.8047049122472, 67.4711133587745, 68.76516603654431, 74.41779567349342, 74.32039537737447, 76.60735684056436, 1.5158624658661506, 0.7191410144009899, 0.16235845403805857, 0.78491885575556, 60.41645996032223, 64.99024560374599, 75.1899456208752, 56.33005626739995, 36.00533423885223, 47.23864155430948, 21.12163389882734, 39.95645538453133, 61.16803315378005, 63.75929993967857, 10.04598036889107, 0.20105297286664287, 0.06505594138176211, 0.11061035622391971, 0.020142374410023613, 0.03214993311332599, 0.08296504691844026, 0.027622834201000875, 0.06998271410984379, 0.035520168396854596, 0.058465907500395854, 0.06467759353859771, 0.08730809895261642, 0.23930351309958967, 29.19184384807464, 65.16359475351149, 54.606433453098425, 37.27782957015499, 69.3216719165925, 75.59020780747937, 37.50234603881836, 71.17334442753946, 64.26495621281286, 80.18338172666489, 38.62865071142874, 0.06363685926302307, 0.17243778092726586, 0.6345964090958719, 0.5275800547772839, 7.945119680896883, 81.72839549279983, 62.49417081955941, 69.68049818469633, 59.08742366298553, 59.15778706150671, 54.83961443747244, 51.58154864465037, 50.93386726994669, 51.51395836184102, 48.60142984697896, 50.11439000406573, 48.19032622921852, 49.78553064407841, 51.690731740766964, 54.18098180524765, 51.14026631078413, 49.84402102808799, 46.980467227197465, 49.5355030798143, 54.43839519254623, 59.071318411058, 58.84871998140889, 57.1337499157075, 50.474871512382265, 61.756698546871064, 61.533754948646795, 61.08252548402356, 57.3125982284546, 62.54704436948223, 60.92495602946128, 61.13874873807354, 56.550917087062714, 53.15569777642527, 50.984505068871286, 59.33360730448077, 56.05213280647032, 53.77250225313249, 56.443071519174886, 56.33532401054137, 50.502077071897446, 51.90798790224137, 49.27615204165059, 42.11360600686843, 43.964160642316266, 42.353192221733835, 45.57601159618747, 43.101368642622425, 43.16950021251556, 41.2543127613683, 48.6781317956986, 50.12029317117507, 48.086081397148874, 46.46487166804653, 48.755986921248905, 49.11005143196353, 49.65120123278711, 51.18520882821853, 52.03648867145662, 51.459460950666866, 57.32793861819852, 54.90409035836497, 58.56246932860344, 56.95169310415945, 58.617621775596376, 48.02887362818564, 39.50059360073459, 53.08187484741212, 59.70154523849488, 58.096185807258856, 56.760465791148526, 55.616683037050315, 56.4013296558011, 57.17173807082638, 54.839080995129, 50.13542959767003, 50.489011656853464, 44.54028621796639, 46.207685778217936, 47.83090768321868, 46.92917439245409, 46.76534483509679, 48.42186374049033, 42.83930332429948, 42.88441058128111, 43.41679388476957, 43.79579682503977, 43.089334810933764, 41.8325093484694, 40.86591966690556, 43.909337674417806, 44.619827962690785, 53.324449908348825, 56.22536820750083, 53.45535116810953, 55.610317030260646, 58.329943380048206, 54.817449123628684, 49.11273433316139, 51.42037845426991, 50.80260122975996, 59.7639815268978, 57.442946434021, 60.847940291127856, 54.81693529313611, 24.49112638350456, 51.721647862465154, 58.993067126120295, 63.42624364360687, 62.405623312919374, 53.66034207805511, 53.12132996897544, 47.81905035818777, 47.46277755306613, 56.779504975964954, 59.720223565255445, 63.09871788947814, 61.287759580919825, 59.79001037536129, 52.83488319766138, 52.32349241933515, 50.81630991351221, 50.615837574005134, 49.63132658312398, 53.45653964627174, 54.79426007116995, 55.278719855893044, 57.53967208247031, 70.51499812833725, 74.54669260209607, 77.88948551301034, 78.22279284077307, 79.42874908447266, 1.3312947245374804, 0.7340103520020362, 0.24510508162840722, 0.9364183199021124, 69.6760109932192, 69.75703147149855, 80.80059805224019, 61.767300713446836, 38.293672453972604, 52.22014581003497, 28.843839399276245, 51.18929593793808, 62.28042125701905, 78.81864793838994, 16.217778844218103, 0.32876598919110916, 0.16077305040051862, 0.12179284206321164, 0.03559892989634987, 0.02866430009054321, 0.15069629756673691, 0.14490902423858643, 0.1653748486311205, 0.15309847350562775, 0.3553948683604118, 0.30958737637246814, 0.16274804039107216, 0.36137302015577594, 43.18044754766649, 77.5705026811169, 71.25086615162512, 39.514843571570616, 57.56124119604788, 76.82178497314453, 43.84441852569581, 78.00277140832718, 70.492138554973, 87.00788221051617, 44.22974824905396, 0.317517489555382, 0.5213799519884972, 1.1907862319100289, 0.4687051865602694, 9.391393661499023, 86.37598837575605, 66.37013543036677, 73.69983719241235, 64.4084482808267, 63.37870843948857, 57.40104375347015, 53.78334760665894, 53.314502777591834, 54.15620027049896, 52.88326563373689, 52.811886341341086, 50.830865829221665, 52.20691565544375, 53.8413437720268, 57.281686029126575, 52.57941922833843, 52.23431733346755, 48.09026264375257, 52.19585457155782, 56.648721387309415, 61.70202855140933, 62.760080060651234, 57.276998796770656, 49.19262124646095, 65.08903049653577, 64.3391360775117, 62.71276843163275, 60.53654724551786, 64.14017385052097, 63.40668278355753, 63.04967649521367, 61.29201535255679, 54.44302751171974, 53.248877602238814, 62.69442350633683, 59.44241777543099, 56.43046109907089, 62.440151937546275, 58.93686740629135, 53.947028113949685, 56.59034475203484, 51.41194143602925, 44.21009325212048, 47.26053622461135, 44.510844907452984, 48.09084707690824, 47.35705398744153, 47.14528129946801, 43.75841271492743, 52.79914256065123, 53.78363393968152, 51.375173138033965, 50.57635891822077, 52.1923715068448, 51.45770765119984, 52.30997985409152, 51.97647248545001, 55.45077854587186, 54.95206486794257, 60.37775008909164, 58.58668211967715, 61.29896579250213, 59.10180699440741, 59.505050182342536, 51.4777470404102, 39.664458459423436, 55.05784726911976, 62.041874470249304, 64.79621379606186, 61.18254984578779, 58.352359725582986, 59.71121388096964, 60.44533644953082, 61.46849847608998, 54.32404241254253, 51.36470433204405, 48.59107086735387, 47.61020375836281, 51.3828609835717, 48.420745864991225, 48.74968759475216, 50.738152765458636, 45.351244095833074, 46.243842186466345, 46.99310902626284, 45.62245638139787, 46.1978720080468, 43.9848982134173, 43.95293874125327, 45.99791742140248, 46.892802253846206, 55.65015262173068, 60.80325272775466, 58.02477513590167, 59.31368950874575, 63.34511333896268, 56.308953915872884, 51.388901433637066, 51.823531427691066, 54.17764779060118, 64.23447155183362, 58.53516570983395, 63.851338355771965, 57.66439560920962, 22.275626582484094, 48.071960864528535, 58.627423778657, 63.303018462273386, 65.45523474293371, 56.3474049106721, 56.402675028770204, 51.013871854351414, 48.96564152932937, 60.10878532163559, 63.3247091693263, 66.12710537449007, 64.89654018032935, 61.81030165764594, 55.4098407683834, 56.468315893603915, 52.23763565863333, 54.07001795307283, 52.1071344806302, 57.057428436894575, 58.674068604746175, 56.75029508529171, 59.32914756959485, 74.33212326418969, 75.40830396836805, 81.33178111045592, 79.85634234643753, 84.21344449443203, 2.9418553411960606, 1.304085242652124, 0.7974293779942297, 1.4042805952410544, 75.82653061036142, 77.68212549148068, 86.94437119268602, 70.12409471696424, 51.15772870279128, 70.57973292566115, 32.4171539275877, 56.68319117638373, 78.39211371637161, 91.18424154097035, 25.25753398095408, 0.7358789936669412, 0.5530019164566071, 0.21784212680593615, 0.26109468492288745, 0.19585282932366097], [0.10440240869478834, 0.049632105510681875, 0.022225673911311937, 0.04232789382278439, 0.1100073224534431, 0.05344328951210745, 0.08280837427704565, 0.3843032268266524, 26.64669432947713, 58.62268947785901, 61.5016346593057, 51.550785495388894, 13.907316500140777, 29.587556085278912, 32.70752895262934, 51.18037254579606, 68.25394784250568, 62.93223288751418, 59.06358349707819, 0.9379587082132217, 0.1156869144629567, 0.028815422424926396, 0.030235703471266938, 0.2620127340478282, 52.87258894212785, 72.7804885372039, 59.25923524364349, 62.27647927499587, 60.077072958792414, 60.60604380023096, 56.964295679523104, 54.80882383161976, 47.85282588774159, 46.95312046235608, 45.33573896654191, 46.7099884248549, 50.210390014033166, 52.27957364051573, 49.30041582353654, 49.454729710855794, 48.97476496235017, 44.39586454822172, 44.55665426869547, 56.48221285112443, 58.41876153023013, 54.760045236156834, 54.40287420826574, 54.04480103523501, 59.33551357638452, 58.77562269087761, 58.324526586840236, 57.78173723528462, 57.45367019407211, 58.819102164237734, 57.21762980184248, 51.14789532076929, 52.358856508808756, 49.3729208361718, 56.756653247341035, 51.351623227519376, 48.66981244856312, 49.63218165982155, 51.12147031291839, 51.17430071676932, 45.500105888612815, 49.960154564149924, 40.571020187870154, 40.62013218479772, 40.51590696457894, 40.959460350774954, 41.501598588881954, 43.27135632115026, 38.49759255686114, 45.674035549163825, 47.347263751491425, 41.72544825461603, 42.87973119366554, 45.53933351270614, 45.773330350076, 45.81850820972074, 49.465531918310354, 51.194092996658824, 47.177346675626694, 54.006467711540964, 53.697969375118134, 52.564510299313454, 56.20705858353646, 60.98570569869011, 50.334223162743356, 41.29189691235943, 56.599134783591, 61.191277119421194, 55.19143927481867, 57.88908858453074, 55.16252356190836, 51.78500198548841, 53.00893445168772, 51.61840715715962, 47.31409618931432, 46.498643275230165, 44.42192477564658, 46.803556565315496, 43.84675625831851, 42.84577131271363, 44.93785373626217, 43.031142527057284, 39.06871318817139, 40.973471057030466, 38.34380818951515, 40.63758673206453, 39.150067067915394, 38.747647577716464, 38.42655451067033, 42.91020408753426, 45.44248627078149, 48.59688381994925, 53.111916280561886, 51.18973916576755, 50.00567366999965, 52.43704895819388, 57.656684229450846, 48.174703428822184, 51.097159462590376, 49.35781186626804, 56.18844301469865, 57.378462668388124, 60.435844313713815, 57.459667498065585, 45.6726352630123, 45.36268172725555, 49.287071920210316, 58.65810063577468, 60.70465218636298, 56.503652526486306, 53.513923921892726, 47.54286058487431, 44.77686789727981, 52.41878640267157, 57.94000879410775, 59.69229236725838, 60.690661091958326, 58.925441541979396, 55.408679746812396, 55.10458230972291, 52.37895865594187, 50.71356342684839, 49.36807670900899, 49.76065105007541, 51.28462914497622, 50.6412309985007, 59.07344825806157, 68.3279315886959, 74.15729538086923, 71.98172138583276, 84.53510238278298, 33.08173287299372, 1.0952801954361702, 0.18661184777175227, 0.5982641683470818, 5.2688570945493645, 71.89724137706142, 64.01639169262302, 73.88145862087127, 56.8857188378611, 35.33172599730953, 54.31450713065363, 33.19593660293087, 32.76807858097938, 52.13079421750961, 63.52012165131108, 24.784090172859933, 0.28613172531608616, 0.10195586094332319, 0.013957184480292904, 0.07321640188174863, 0.07103603137957473, 0.029860213136060104, 0.045477698797420155, 0.05015491838416746, 0.008441676055231403, 0.060478259599016565, 0.09738889673063833, 0.10367930596393925, 0.3285807797745351, 36.28902750630533, 66.26876569563343, 71.94985605055287, 48.196484350389056, 19.699307949312274, 41.400401438436205, 42.438103691224136, 58.40180512397521, 71.28024470421576, 68.2877508286507, 63.52822919045726, 1.2246007400174295, 0.07578023769442113, 0.2721151661488318, 0.17260730086315065, 0.25823267236832653, 58.53861739558559, 74.41632086230864, 65.89882343046128, 69.17043316748835, 63.215698657497285, 64.14153099060059, 57.40168702217841, 58.42312712823191, 51.3079672475015, 49.410759941224136, 48.07676576798963, 49.910858215824256, 53.362371383174775, 54.81769231057937, 54.20044068367251, 53.003454900557, 49.9720589576229, 47.30740070343018, 47.84533808308263, 58.53180423859627, 58.61159309264153, 60.515358601847005, 54.93313943186114, 54.64532375335694, 60.57961879238006, 59.15806162741877, 60.66011367305633, 60.86298258073869, 57.88929647014987, 61.02764368057252, 60.59721454497307, 54.28585029417469, 54.59539590343353, 53.47248408102221, 57.823024103718424, 55.004252003085234, 53.32722694643083, 52.90469354198825, 55.942851651099424, 52.0276790280496, 47.356626449092744, 51.89638553127166, 42.62716977827011, 43.69709037965344, 44.01508477426345, 43.69088126767067, 44.01770491753855, 44.54788384899017, 43.29905609930716, 47.24472122807657, 51.3960950605331, 45.112430587891616, 44.489432688682314, 47.57537703360281, 48.95560026168824, 49.341714459080855, 51.359695465334006, 52.790799679294715, 49.31540712233513, 56.51967540864022, 54.1020990187122, 57.9494656285932, 57.66013199283231, 61.96181497266216, 51.29907523432086, 39.277908878941695, 57.91987134564308, 63.57775303625292, 58.406747310392326, 57.53364732188564, 54.637577072266616, 53.446498378630615, 54.70057818197436, 54.058650924313454, 51.23204585044615, 49.089482522779896, 48.216029520957704, 50.90007997328236, 44.37777849935716, 48.17686465478713, 48.07897014002646, 45.27400086002965, 41.576472713101296, 42.82610847103981, 40.580524090797674, 41.32581364723944, 40.67222518305625, 41.86690461251044, 41.90053893673805, 45.05545816113872, 48.150082711250555, 50.049133531508915, 56.102594098737164, 53.55397132135207, 53.94544739877024, 57.05116441172939, 60.8666931429217, 51.4888551927382, 54.12592349513885, 51.92410884364959, 58.874380127076186, 63.08216940972113, 62.34190048709993, 61.69772571133029, 55.65928389949184, 44.1519715709071, 49.69276658950314, 61.0364297897585, 62.874197498444595, 58.32495020281885, 56.578208938721694, 49.39559605813796, 46.61220373645906, 54.474594746866536, 60.07458225373299, 63.46451420937816, 63.69767165953114, 61.5277890236147, 59.73835668256206, 58.85925546769173, 55.81665331317533, 54.25898990323467, 51.1696840870765, 52.70362500221499, 56.25057728059831, 55.13289397762668, 60.58314892553515, 72.09257541164276, 74.83742652400848, 72.83944960563414, 86.99734672423332, 33.201565204128144, 1.3372579529400797, 1.4361440919099318, 0.6510367172379649, 6.383498599452357, 79.12542435430711, 70.88491685928838, 79.24795919849028, 60.073025072774584, 32.27717434206317, 64.50333826003536, 36.86437253029116, 38.76066592431838, 60.18538921110092, 74.42243975977745, 30.06808957745952, 0.2935780999400924, 0.14796701740593682, 0.1137688448051772, 0.05300784513594643, 0.057371941605402585, 0.23627047907681237, 0.1190411844741433, 0.15565236549704306, 0.10727467150577616, 0.18199835903942588, 0.15223677780839706, 0.1755102684781436, 0.29469358524487865, 49.76749950839628, 79.46335223413284, 78.39064674992716, 69.07338588468491, 23.03869624291697, 42.719576897159705, 53.16489181210918, 66.42360518055578, 79.42812934998544, 74.9519048198577, 72.90196434144052, 1.6297142856544065, 0.3215038433911339, 0.8695427664825994, 0.3410654388848813, 0.6470286065051634, 60.39555764967396, 77.66052107657157, 69.56363508778234, 71.7934476175616, 65.29562173351165, 67.90626110569124, 60.897770081796956, 61.55408851562008, 52.7661201261705, 50.931345185925885, 51.03404068177747, 52.11971744414299, 56.93914936434839, 57.51363538926648, 55.124343210651034, 57.280156304759366, 56.03942824948219, 48.37860391985986, 49.918526449511134, 61.79642038960611, 63.2409312648158, 60.478166687873106, 56.94556243958012, 53.95461397786295, 62.661444217928, 59.544167980071045, 61.82929769639046, 63.82815714805358, 62.4941433629682, 64.74984353588474, 63.76862733594833, 57.06943481199203, 59.28635058864471, 55.29369938758112, 62.63455637039677, 60.55464113912275, 58.127192143471014, 59.3934077601279, 59.72508730426912, 57.65771189043599, 51.943410827267556, 56.25669225569695, 44.98465545715825, 47.06517081106863, 46.039125842432824, 45.56977110524332, 46.98395029191048, 46.778084693416474, 43.58709143054101, 49.49051349393783, 52.592425807829834, 47.36025856387231, 47.09762842424455, 50.96763103238998, 51.57940703053629, 52.88472475544099, 53.12966500559161, 57.06936813169911, 53.229050021017756, 57.99285880980953, 59.83174831636491, 58.85278747927759, 59.23461060370169, 67.52340639791181, 52.801033143074285, 41.78658231612175, 61.0630234595268, 67.90397828625095, 62.981576304281916, 60.89101183799006, 58.3219535120072, 58.20776547155073, 58.0311607545422, 58.6057173821234, 52.0436038509492, 51.58553769511562, 50.167369457983206, 53.86393662421934, 47.35885435535062, 51.249720050442605, 52.11485370512932, 48.0986878948827, 44.074747946954545, 47.619852788986705, 42.74283655228154, 44.30870163825251, 42.66856255069856, 41.22487145085489, 43.46373681099185, 47.38875850554436, 51.32014228451637, 53.02688713996641, 59.62401566966888, 58.93808726341494, 59.30931214363345, 61.960147965338926, 63.69686757364581, 54.260213682728434, 56.78689472136959, 54.53819990158082, 59.56091257833666, 64.33219740467688, 65.50694727128553, 61.55339425609958, 43.99335876587899, 45.316209485453946, 50.60733779784172, 62.71721639940816, 67.05301223262664, 58.932450817477324, 57.96163282086773, 52.290987737717174, 48.5638064722861, 57.821753255782596, 62.43506854580295, 65.07955405019945, 65.49168532894504, 64.23768005063458, 62.67577655853764, 60.9687767490264, 57.32127843364593, 57.61820185569025, 55.01873339376142, 54.936700943977606, 59.68821702464935, 57.72614156046222, 65.39504989500969, 74.80548274132514, 79.54695363198557, 76.06830550778297, 91.97268501404794, 38.80495732830417, 1.1652867808457346, 3.1255830824375157, 0.73864420335139, 7.167265136395732, 86.54317548198085, 77.24672671287291, 85.31030393415882, 73.60130725368377, 49.89546291289791, 77.63753598736179, 46.73007488250733, 46.81763002949376, 68.89315297526699, 90.77007062973516, 40.357509889910304, 0.47535746508548343, 0.3059160072476633, 0.19881009725072693, 0.23194197505231828, 0.27359386906027794], [0.05127472825528634, 0.05097797260649743, 0.029495275662010236, 0.12628132056805397, 0.0972531765939728, 0.15526356055371224, 0.018538142246524655, 0.3289033947212081, 28.525894034293394, 65.1728868484497, 45.240013522486535, 51.85732656909574, 36.516811309322236, 31.453198117594567, 40.00330809623965, 53.0942734595268, 74.63398102791079, 55.23618959611463, 74.24072419443439, 6.8984494190062255, 0.09523872541443956, 1.053095226806979, 0.04193994689792876, 0.10113250794670275, 17.618537641340687, 86.06874127541819, 57.85084547535066, 68.0367426718435, 62.9245371972361, 63.34873368663173, 57.29934846201251, 58.78487948448428, 48.15693509194159, 48.88436217461863, 45.90763622714628, 49.36977117292343, 51.75527434195242, 53.757883579500266, 53.50967207262593, 51.10918152716852, 46.6567147931745, 43.96973433033113, 48.38299697445285, 55.37801465680523, 56.47652541437457, 56.23941813745807, 56.53609052781136, 59.948815376527854, 57.87572899172383, 59.04034345380722, 54.22942699924592, 56.81284904479981, 53.48834222362888, 55.62733227206815, 51.761867846212084, 51.02491724875666, 53.182354204116336, 51.88834467241841, 53.446980830161806, 49.11773143276092, 47.61150206288984, 49.37365039702385, 48.859961109776656, 48.21677084892027, 46.477234978829664, 47.35682256760136, 44.90112858433878, 40.703713970799605, 41.3899600890375, 41.1130525219825, 42.66984516574491, 40.91696539232808, 40.31007666741648, 44.50214509041079, 43.6778276197372, 41.61474327887259, 43.33351412127095, 43.92373277295021, 44.86353266623713, 45.342508977459325, 47.812774565912065, 51.6677584186677, 46.78695317237608, 51.75324255420316, 53.85153408973448, 56.40396941092707, 53.2244255465846, 54.35900642025856, 54.05559147557905, 40.745165578780636, 56.570901563090665, 58.22381973266602, 56.39872912437686, 55.55740033426593, 53.07461846259333, 50.972526150365034, 53.3964999260441, 49.941809638854004, 48.94903421401978, 46.947735048109486, 46.623425637522054, 44.565342318627145, 45.845647088943, 42.197246628422896, 44.77834663083477, 42.68702906946982, 38.914571885139715, 40.91881675104941, 39.91020671782955, 39.79781120054184, 39.043472736112534, 38.75170330847464, 41.47289860633112, 47.15960579533731, 44.73607132511754, 46.32534903864707, 55.3349744889044, 50.13533938315607, 50.07052221605855, 51.96742749983265, 54.87252312321817, 49.58858451535625, 48.9334741715462, 47.466319453331735, 53.20499020238077, 58.031435320454264, 56.20906291469451, 61.22629604031963, 57.23073836295836, 50.405861331570534, 47.95922410103583, 54.80237545505647, 61.210618326740885, 57.074937897343794, 54.340222189503336, 49.6471494243991, 45.45294723203106, 44.38234806060792, 55.6718707853748, 59.38622197797222, 61.70275811226138, 61.66826478896603, 63.4724844655683, 58.327574268464126, 59.53446011389456, 54.19457281789472, 56.277516118941776, 53.27342771714734, 55.62268034104378, 52.816526505254934, 58.66933430394819, 66.28244692279448, 70.41781748494795, 70.2572827185354, 73.34784369314872, 6.3496098114598185, 1.1487547260138298, 1.6210125074271233, 0.6280274809368196, 9.769514068480461, 73.81884974818077, 56.15615406344014, 72.56407568531652, 51.522097279948575, 43.81665598961615, 46.21888022268973, 28.63757960257992, 49.34872765694895, 56.907778247710205, 70.93643326913157, 43.49316243202456, 0.30913247336303035, 0.16629418478377406, 0.041623859020370635, 0.028322967700660232, 0.055448995797985026, 0.024066542973741892, 0.05813493836490859, 0.06611682760018496, 0.1035211394510923, 0.04854576985141443, 0.1301284149409302, 0.1164416259815616, 0.44590769696139526, 37.37937188917591, 72.79437372761389, 56.73463698356383, 49.91523558093656, 39.287416704239384, 37.36654181634226, 42.949670976208104, 57.34639336985927, 81.1571728798651, 62.28534383158531, 81.75808783500426, 8.327664521432693, 0.09109268055087136, 1.7088352336037544, 0.11342909247163804, 0.3142873564314458, 20.108493528058453, 87.349818752658, 66.88202827207505, 78.85988773838167, 63.65559247232253, 68.80454663307437, 57.71470785140992, 62.09691709087741, 49.85758066177369, 51.80008349880096, 49.225690749383745, 54.57983586095995, 52.06967584548458, 55.304831074130156, 55.228674334864465, 53.88364261196506, 49.288338845775975, 46.313217147704094, 50.41201945274107, 58.65944208637361, 58.00052312112624, 59.046493730237415, 55.26569366455079, 63.12307580824822, 58.19743394851685, 61.54403155849826, 56.969783075394176, 59.6357435564841, 55.96445214363837, 58.83147331976122, 53.09686614621071, 54.03620712218746, 54.420289531830825, 56.78140732549853, 56.75815943748721, 52.01490779076853, 51.96247746867519, 51.27825921581638, 52.77416098502375, 51.37921710168162, 48.904193678209865, 52.151233688477554, 45.90755777974283, 42.73457996306881, 41.434506447084495, 44.74931716918946, 43.06899339922013, 45.40853031219975, 42.55437843261227, 47.15644436497843, 47.40245149981591, 44.72772844376103, 44.91104041376422, 46.9072404984505, 46.66645011594219, 46.572003364562995, 50.644062949765114, 53.361959534306685, 50.48974514007569, 53.83002773407967, 54.27048637020973, 57.659967253285075, 56.04499409275671, 58.32758995794482, 56.811170270366055, 40.83144987783125, 57.134856024096095, 58.6626309733237, 59.37985204881238, 57.535204502844046, 54.57176362314532, 53.3641952853049, 54.11803168635215, 53.368270627913944, 50.97375385222897, 50.691358889302904, 48.91948307714155, 46.315350917077836, 46.75557028862738, 45.57301490537582, 47.34039175894953, 44.552006260041274, 43.23820444845384, 41.266511332604196, 42.53326039160452, 42.34902274224066, 41.89761677095967, 41.92983511955508, 41.919362391194994, 49.186859284677816, 48.52353942009711, 47.34204307679207, 57.19883380397674, 54.61939296414776, 52.93894367833292, 55.357175104079715, 58.259328949836, 53.51690884559385, 52.11613632017567, 50.299569022270944, 54.906553606833185, 59.129436169901204, 58.02921918130691, 62.1700849840718, 62.256824278062396, 51.848187446594245, 48.59345174604847, 56.64812518704323, 61.521666203775716, 59.134464648462114, 57.17849239226311, 52.128609457323634, 48.41620376033168, 48.17462890378891, 57.91399171275478, 62.017881331905244, 62.97880711094026, 65.49038310204783, 65.21447966175695, 61.2198123624248, 62.60216543751379, 58.213884369019546, 60.15914070990778, 54.350961639035134, 57.97136029889507, 55.322913200624534, 60.74872001524895, 68.30305591706308, 72.74766614360195, 74.40990386470672, 77.24757394483014, 6.318351953260361, 1.2311892187403095, 3.2147368404173084, 0.7434253274433075, 10.95313927819652, 80.56580497372536, 65.04573537457374, 81.81910422540481, 55.03735288496941, 44.09013932751071, 57.13363224460233, 34.193968003795995, 49.99129033857777, 60.792332849194935, 83.52022047965758, 50.487121074430405, 0.3756005599373772, 0.11716128131675145, 0.04204446810387796, 0.07208793904752502, 0.04086518299675757, 0.09289630433364261, 0.13143344571994198, 0.14846155780457682, 0.15190941311659353, 0.13201262351245652, 0.21184215682648846, 0.32483166804717434, 0.5163761108152328, 48.3915908875004, 87.40135085198187, 62.635835063072946, 69.70875493941769, 49.85818470678022, 45.311432038584066, 58.906582786190896, 65.03992634434854, 85.99424762110557, 66.0422174392208, 89.29351006784748, 9.302561783021497, 0.28401539210350285, 2.626245502502688, 0.4005741988939624, 0.3237878885721007, 20.686605784200854, 90.37114204898958, 62.581259204495346, 80.83822142693305, 66.74164664360785, 70.95275032904841, 61.81942901303692, 64.91458700549218, 52.73169348316809, 55.16155865884597, 50.191743066233975, 55.83676722741897, 55.668815259010564, 57.779776050198464, 57.664117120927386, 57.051760611995576, 50.94941946767992, 49.716300810537035, 54.082730354801306, 61.49564912242275, 60.72049856185914, 61.838009280543176, 53.30741113232028, 65.34902872577791, 61.986231726984826, 63.65265461706347, 59.96903519476614, 63.23242756628222, 56.871872871152824, 59.65850899296423, 55.87610860024729, 56.86978617022115, 56.962922849962794, 57.96133079836446, 61.19187724205756, 56.5768047302, 55.82245057629001, 57.52517107994326, 57.18947110637542, 56.59310610063615, 53.781904174435525, 57.005959095493445, 48.139629594741336, 45.12105587990054, 45.31473859663933, 46.74797657997378, 46.12755960033786, 46.48552686937394, 46.92511866169591, 49.86975962115873, 49.19234275817872, 48.817038612981, 46.91167277674521, 49.806511402130134, 50.82828490964828, 49.94001711568525, 54.8085061196358, 56.42857443901801, 53.59036307181082, 57.483931279951534, 56.567532247112645, 61.71183447684012, 59.07755105726181, 60.091024829495346, 59.339267284639426, 40.419624543959095, 59.245526559891246, 62.1546269232227, 62.319068370326875, 62.638223786507886, 58.244369029998786, 56.68138688610446, 58.182101403513265, 55.763607178964925, 54.58041637174545, 52.65499937918879, 51.1672326057188, 48.832504518570445, 50.211688318560206, 49.391152012732725, 50.24594237727504, 48.49557684313867, 44.40818079056279, 44.145487893012266, 46.55609815351425, 44.2862892150879, 44.00369028891287, 45.01187278378395, 45.18982287376158, 55.16827375658097, 50.70569515228272, 51.89479697135187, 61.71059893023584, 58.71602227610927, 58.56455602953511, 60.18941748526789, 61.50919306662775, 56.127995367973085, 53.36456006573093, 52.230893104307114, 56.07591413682508, 62.613340270134714, 58.91172109111663, 64.06899852137413, 53.201966054977916, 51.277368837787265, 48.69330352352512, 59.82879084925498, 65.54302523213049, 60.963285430785156, 59.55211077966998, 56.01104597891531, 50.97383229963241, 50.07002799741684, 61.849776391060125, 64.15613789712229, 67.59087116487565, 69.29320335388184, 69.12401583886916, 63.34800804814985, 66.08315129433909, 60.037559001676506, 62.01321763377037, 58.43632590386176, 61.667017475251235, 58.042276751610544, 65.23691954151278, 72.74135897236486, 75.85921179863715, 76.19846543958111, 81.83316200010239, 9.090592976539366, 1.2747874663722132, 5.046966162420088, 0.9673290483413205, 13.64912844473316, 87.06988703820014, 72.27040783051523, 85.10587784551805, 67.41736119793308, 56.19735856210032, 65.62549698737361, 39.928331990395826, 67.43640822748985, 74.2870395414291, 91.5456408839072, 59.610812971668864, 0.49877524075488894, 0.2715950537352793, 0.14840083767569837, 0.2472779827733194, 0.09986485459751661], [0.03504144388341135, 0.08084276886356455, 0.016825332441517425, 0.08207795540651969, 0.087377751666692, 0.08391026152117599, 0.02227515169990159, 0.29718481124408785, 33.14522035660283, 61.648425440634455, 52.9132168523727, 47.27283677747173, 21.686792527475667, 35.14105958323325, 41.14222318895402, 51.267649204500266, 73.01069244261711, 55.29833170675463, 70.2362431249311, 28.2489864672384, 0.3104106450994169, 0.6901207458107703, 0.31144731527855324, 0.03065863763162446, 0.8046214727144089, 61.65818821999335, 62.82730164066438, 61.066071141150694, 65.27126773711174, 61.67847864089474, 58.15651578287925, 52.688002201818655, 51.08487459921068, 45.580337970487534, 51.52700416503414, 49.974310398101814, 54.85641394892047, 57.10639138375559, 54.46895045618857, 49.18116008081744, 44.836327106721946, 43.28602598559472, 45.64373916195285, 55.77057330839096, 58.09256545958981, 61.28523357452885, 70.13232384958576, 59.7778667173078, 57.0365692723182, 56.98337408804125, 53.96838934190812, 54.74345361032794, 55.56282889458441, 54.22062127820907, 51.537480815764404, 53.51086839552849, 50.48812520119452, 49.29032748745334, 54.80665868328464, 48.08455951752202, 51.4349579042004, 49.3756978742538, 48.024978714604536, 46.06025565055109, 43.41547596839167, 47.55110148460635, 48.85330092522406, 44.649583062817975, 39.49595343682074, 40.07428730687788, 39.600119821486935, 41.13001677297777, 43.518234222166, 42.413024056342344, 42.15417115919052, 41.701706147963, 42.660996298636164, 43.27315276668918, 43.92316010690505, 44.34988260269166, 48.888147261834916, 49.67321749656431, 49.95089384817308, 49.010737019200484, 51.85074875431677, 52.22022817980859, 53.50698132668772, 56.0831783663842, 54.76002954667615, 46.704057801154356, 57.1509651983938, 54.54025522355111, 56.71153814561906, 53.988954328721576, 54.37550390920332, 50.36634737445463, 52.95604128991404, 48.47900090679046, 48.48381757736207, 46.61547891555294, 46.18122154666532, 45.56901016542989, 44.59599956389397, 39.73672812984836, 45.233929926349276, 40.171330667311146, 40.75561869528986, 39.36232220742011, 39.95352145164244, 38.84541265426144, 40.934251277677475, 39.87900426310878, 44.77919778516216, 46.99201076261459, 45.976869983057824, 45.21262361157326, 51.79159941211824, 48.0388835168654, 50.293077499635764, 48.55086657308763, 57.457314075962195, 48.90852005250993, 50.71702687971054, 49.299125363749845, 52.519183389602176, 59.458985867038855, 58.40103241705126, 54.7196565904925, 62.17570181815856, 62.134261977288034, 59.86415493872858, 55.52080854292839, 59.56874947394095, 55.72341465180921, 55.98296965322187, 51.27152842860068, 45.49050000406081, 45.15911463768252, 51.39631079089258, 57.60734865742346, 62.129676726556596, 64.04511913176506, 63.13612161144134, 61.73654933129588, 61.231708911157426, 63.36157944894607, 60.12840501723751, 57.58834085156841, 56.303564579256125, 56.357034329445135, 57.35355954016409, 66.53183906309067, 65.43464229952905, 73.92524796147501, 65.815779009173, 0.5194962337132424, 0.8785352291118715, 1.7193399537955563, 0.5259639156922218, 14.019361945890612, 75.98018553949173, 49.45079557357296, 69.09568063674435, 61.37957049954323, 47.04555111546671, 44.53623833194856, 31.50854668309612, 27.25481075625266, 58.6180571586855, 72.24234719430247, 33.595688881412634, 0.41699412909726946, 0.24718392249797624, 0.07545243633250076, 0.08038009006169536, 0.07557327904167675, 0.1216682531840859, 0.02901035158203975, 0.05452503630470845, 0.0610010456594248, 0.1201100456678579, 0.053511410050334475, 0.06683224646915352, 0.3763489971958822, 41.944104702241965, 73.78499184885334, 57.46206406624087, 51.87678152515043, 35.337962565883515, 40.63200127693915, 47.875418739934126, 60.44038249600319, 78.90303381027715, 61.66280484968617, 77.87621221234723, 31.405562893036876, 0.2873305303435172, 1.2527931433531547, 0.7132641394292155, 0.09994798279818028, 1.5003651813153298, 65.220649550038, 73.17774618825605, 74.74792588141658, 64.48820575591057, 65.27237384550034, 60.60800106294694, 56.38840152371315, 52.16620537542528, 49.654135165675996, 54.84182665424963, 55.00547186020882, 56.072799774908255, 60.11061314613589, 57.3482447285806, 52.8698040593055, 47.44893158635786, 47.7864162383541, 48.83193185252529, 57.07425148256364, 60.32255841839699, 59.51725659831878, 71.74524168814384, 62.95149564743043, 57.7264278934848, 58.93976603784869, 56.81839135385329, 58.59158508239254, 56.32265083251461, 57.209039811165106, 54.61499990955476, 57.21650408160303, 52.62750356428085, 53.614281685121604, 54.588892613687825, 51.68624454928983, 55.24461876961493, 54.43673995233352, 50.8974951313388, 49.188694953918464, 48.95925983305901, 50.68486344429755, 49.62775722626717, 46.836680981420706, 43.26908526882049, 42.49952016338226, 42.345076837847316, 43.70944584569624, 45.27937058479556, 46.68794470448648, 43.907913854045255, 43.92747471409459, 43.61808207727248, 45.87964619359663, 46.034756322060865, 47.03134821307275, 50.98490907299904, 53.444662709389966, 52.988016451558764, 52.162502657982614, 52.464474170438706, 56.29395477233395, 54.07725080367058, 58.10886683002595, 57.93382713871618, 48.17267556344309, 59.58462330602831, 57.63006310309134, 58.22227431881813, 56.40756622437508, 55.3702679757149, 52.393279229441, 54.97412820016184, 51.04673739402525, 49.681140684312396, 48.870535819761216, 47.60749340057374, 47.40785652591337, 46.33449600588891, 43.62793507114534, 46.1993036731597, 42.409776333839666, 42.00141445282967, 41.229593984542355, 41.525587804855846, 41.425826241893155, 42.3208365901824, 42.233422648522165, 46.95737231162287, 50.8201224573197, 50.313258094172326, 48.78567141871299, 54.03130415947207, 52.11118236664803, 54.470370354190955, 52.040163932308076, 59.775560363646484, 51.24518579052341, 52.31934647406302, 51.72721762810984, 54.59057531049175, 61.235348870677335, 61.38836837583973, 57.320035042301306, 62.74989366531373, 62.53655987401163, 60.330599277250236, 59.720878601074226, 60.73235196451987, 57.764545486819365, 58.51822107068954, 53.64967323118641, 48.74672228290189, 47.69124384849302, 53.25501611155849, 58.42446857883085, 63.26171982672907, 67.14889849385908, 65.06880675592731, 65.01761982517858, 64.91675999856764, 68.21280217939808, 62.47311161410425, 60.441527828093506, 59.021853400814926, 57.72380775020969, 61.93185983165618, 69.68297712264523, 69.19295541701779, 76.20209755436068, 69.29086562125914, 0.6751529812332123, 1.0566985366805908, 2.6760269989890437, 0.49630016388912357, 16.345243127115314, 82.77205974824967, 54.60228750782629, 78.53537436454528, 66.87784702547135, 52.741397426974395, 50.4718630544601, 36.019980369075654, 34.74248009343302, 66.09611865012877, 79.7293987581807, 43.520148338810095, 0.5422864301550774, 0.223425084484681, 0.18011600440067632, 0.11704079866889985, 0.16046413310593174, 0.18813231779683023, 0.20233267677887795, 0.12433679789424905, 0.1957126658770346, 0.21106833141417275, 0.2107735561026681, 0.08518652569863104, 0.5004981418530787, 53.676255133844194, 81.35270303295505, 70.8634614944458, 64.0401691006076, 28.367430279331824, 52.24149134851272, 56.60861515229749, 65.70203419654601, 84.91009666073708, 66.95773786114108, 82.78003784918016, 35.313985117020145, 0.3918047597812068, 2.2647066702765803, 1.2648252590048699, 0.19774059254315593, 1.446571590438966, 69.01529558243291, 62.555587291717536, 68.00603051339426, 70.97018918683453, 65.84423972714332, 65.72607048096197, 59.05176147337883, 57.324922315536014, 50.65972889623335, 57.56552050190588, 56.23307174251926, 58.66178766373665, 62.72604173229587, 60.70087102151687, 56.99372522292599, 49.86828088760377, 49.26754636149253, 50.08442309594924, 59.093511181492964, 64.7407828607867, 59.08324633875201, 69.98072424242574, 66.60980793737596, 58.26149802054129, 63.369106477306744, 58.702768587297015, 60.694583462130645, 60.13287651923395, 59.02967068456835, 56.55552587201519, 60.93128281254923, 54.98592668964017, 56.24622344970704, 61.02615710227721, 57.21769648213541, 59.87920115070959, 59.455208624562914, 55.723669605870406, 52.983748912811286, 52.02016768916961, 54.99587774276734, 53.07568926965037, 49.99938611061343, 44.5193721402076, 45.33218529916579, 43.32005646920974, 46.02711946733537, 48.14716054547218, 47.35685394656274, 46.94944912387479, 48.093388772779896, 49.188090908911924, 49.1826388143724, 48.67040080408896, 49.60573704011979, 53.29346318398753, 55.94881757613152, 54.54946494871571, 54.368839802280554, 57.64876496407294, 57.391367266255045, 56.76725541391681, 62.09994908302062, 59.43132923495386, 48.773370865852606, 61.158486104780636, 59.27431283458587, 62.15798054972003, 58.55164750929802, 59.572067799106726, 55.01920015581193, 60.24521712333926, 52.62377339024698, 52.109138811788256, 51.544435178079915, 52.356773730247255, 50.57960664072345, 49.819219881488436, 45.65926390309488, 50.40674386485931, 45.433288312727406, 44.57173185963785, 43.21768653008246, 43.46354853722357, 44.25456116276403, 44.827501773834236, 45.08929644861529, 51.0576964962867, 54.438708982160016, 54.9947206435665, 51.795600229694, 57.398105898211085, 54.84829856503395, 59.922661012218846, 55.690223555411066, 64.96498161746611, 54.02239253444057, 54.745508932298236, 56.330985869130785, 56.61166283392138, 65.82347469945108, 62.400488930363814, 59.06411693942163, 64.74750580326204, 65.13364745724586, 62.293945589373195, 61.01373495594148, 64.67034885960241, 60.25486615396316, 62.30910555008919, 57.3506962099383, 50.59172676455591, 51.094413803469756, 55.10174251371815, 63.02091375474007, 68.21190787899879, 71.07696394766532, 66.84348706276187, 66.10372804826306, 67.8497475962485, 69.315764827113, 65.05323102397304, 63.86915768346479, 62.021564437497055, 63.348906270919315, 63.63402335874496, 73.67470264434814, 71.94450593763783, 78.63615574375277, 75.24965193963821, 1.3854619211727575, 1.1438879226484606, 4.680076972130807, 0.7075401143200937, 19.113178368537657, 93.4525639011014, 65.1427944244877, 82.55061057306106, 75.7340254322175, 59.638818694699204, 65.14162163580617, 44.16728450405983, 42.635034130465606, 80.13234384598272, 90.08167113027265, 57.12948237696002, 0.7128035060821042, 0.4449639685692326, 0.43444205736441, 0.26199597204404496, 0.358167126053764], [0.06017429506286018, 0.08845494789702278, 0.015684166911899323, 0.0213766033430734, 0.0757256998950916, 0.06408967085242753, 0.12218569195078266, 0.1575446486352913, 38.38798976713611, 63.933260979190955, 49.07560517711025, 50.19571250484836, 26.2470224595839, 36.02256913338938, 44.448518445414884, 43.216556887472834, 69.10645146523753, 61.16234963940036, 63.90666730942265, 56.92258911748087, 0.362099148933926, 0.12240763528332596, 0.3907205002202142, 0.30619207469205706, 0.144841868971144, 25.255209976626983, 58.77254363029235, 52.51463344020229, 68.49156502754458, 55.09933810080252, 57.24673378852106, 49.98255522020402, 49.541637666763805, 46.57327421249882, 52.22928885490664, 54.461952947801166, 58.62383480994933, 55.49474831550352, 56.06252708742696, 47.21751566856138, 47.413924432569935, 43.63103374358147, 53.379484684236594, 53.514461286606334, 63.3376020000827, 66.85027276315998, 52.9718170627471, 57.70683565447408, 57.87961998293477, 56.31929720601728, 55.37564162285098, 50.87370987861387, 51.122317544875614, 54.793220643074285, 52.32479856860254, 52.744496099410526, 48.57051372528077, 53.49106434852847, 54.27860175409625, 48.936125693782685, 51.24746468759353, 49.460166115914625, 49.843522887076105, 48.55920945444415, 44.62841795336816, 43.25343893420312, 48.62842359850484, 47.65125920695644, 46.49235571584394, 40.97293369231686, 40.5848700769486, 40.74423989941997, 41.95151405949747, 41.1633647641828, 43.49943037955992, 42.9034693779484, 43.07337860907278, 42.67133174404022, 43.7321916703255, 43.99286846960745, 48.29852481042185, 48.76173319355134, 50.7999457851533, 45.26858406682169, 52.36783873650336, 54.53734090251308, 52.75591804135231, 56.66875293177944, 57.12801933288575, 53.25691453872189, 57.75823831558228, 55.82989915724724, 56.64774863950668, 52.99989731081071, 52.316714563677394, 48.56188843327184, 51.45796260526104, 48.57858596309539, 47.02571961187547, 43.89861391436669, 47.683108852755645, 43.70309945075743, 44.277040266221576, 43.455864614056004, 43.11297101359214, 41.64806381348641, 40.25600287222093, 40.434937477111816, 42.49550757869598, 40.891748474490264, 44.16746493308775, 43.3356753472359, 46.35838324023832, 44.46492571984568, 44.423858504141535, 46.82317626091742, 49.07935496299498, 47.73920266858993, 50.69639129023398, 49.19253495431716, 54.030198051083474, 51.67596009469802, 51.098085141951046, 53.37648407105477, 50.33742773917414, 55.491563350923606, 58.2627571013666, 60.37773832198113, 59.66823647099157, 57.77950932902675, 60.34331167897871, 61.50095608926589, 61.46205402189686, 59.83201503753663, 57.880251484532515, 55.06366022171513, 48.10958031685122, 46.658683823001006, 47.195028720363496, 52.21663921110092, 59.34671194322648, 61.78987787615869, 62.899261443845695, 64.54599011328914, 62.396158633693574, 64.67207470247823, 65.72340326924478, 63.96451834709414, 61.19956900996547, 59.98758408331103, 59.1068393953385, 62.405635080029896, 61.475366546261704, 76.68028939154841, 54.12809648821431, 0.08373711032853012, 1.6710306944385653, 0.6809556376068824, 0.3714257791157692, 22.821618549285397, 76.4024757569836, 58.46333142249816, 66.98287240920529, 69.66180416845506, 38.933611069956136, 42.849740751328014, 38.35031540163102, 34.36912536621094, 54.267787779531176, 77.06050826657203, 38.34671466581283, 0.19972379499625778, 0.11561750689701689, 0.08612974847276365, 0.0457601439237835, 0.08348078496994511, 0.07108226478580507, 0.03130756198398529, 0.022009562423092224, 0.011992762672654804, 0.007613017420930368, 0.06361224868845555, 0.006787322110481441, 0.0674465493929963, 47.81394343222342, 73.46722495171332, 57.010430597489886, 59.53228319844892, 27.635480703846103, 41.403115718595444, 50.7457229398912, 48.69329960115495, 78.69700739460608, 68.39562385312973, 70.76402941057759, 60.97433474756057, 0.3826554329885591, 0.12181373328090676, 0.7211906366771268, 0.18575862500696413, 0.09266413372731017, 27.599849893200783, 67.23079758305704, 67.75570484899706, 67.88538625163417, 58.224494380335656, 60.67261034442533, 53.091684695213075, 51.91181221315938, 51.002904907349624, 54.60185212473716, 57.554373125876154, 61.94123037399785, 60.33205839895434, 59.37524326385991, 50.12771037317092, 48.66152055801884, 47.20812159199869, 54.747846664920935, 56.86710719139346, 61.892616518082164, 69.43012545185705, 57.3454676904986, 61.27774969224007, 59.110267546869096, 58.69955224375571, 57.62094751481087, 53.57903526675317, 53.93193091115644, 56.19637796955725, 54.808086426027366, 55.54655498073947, 51.807206523033884, 54.3375785120072, 57.41203815706315, 50.919825184729795, 55.73460517391082, 52.98219173185287, 53.17772188494283, 52.88309304944931, 48.04133499822309, 46.847079184747514, 52.24755533279912, 50.40507685753607, 47.29414701461793, 43.12159238323089, 41.96801154844223, 41.85766743075463, 45.311130016080796, 43.37828013204759, 45.19370602023217, 44.56645234938591, 45.411805491293634, 44.250709395254816, 47.5022130627786, 46.00588375522245, 49.56630153040732, 51.07224064488565, 53.508044289004424, 47.73953214768441, 53.0569403402267, 54.58459761834914, 54.83955952429003, 58.90126012986707, 59.328806323389855, 55.001329837306855, 60.17904281616212, 57.78979378361856, 55.23868814591439, 55.97580348291705, 55.398811063458844, 51.043893675650324, 55.014842402550485, 50.54454849612329, 50.455475391880164, 47.05521191320112, 50.19824243360951, 47.05601992145662, 47.55630646982501, 44.396492127449285, 45.42084655454082, 44.173442625230365, 41.61806944877871, 39.74716163450672, 43.41649970700664, 42.305841369013635, 44.89992833906605, 46.00343227386475, 48.81661107463222, 48.25841857540993, 49.194915833011756, 50.594837204102554, 53.17429373341223, 51.13002107989404, 54.895355239991225, 50.847763399924006, 55.01907463996641, 53.680318709342714, 52.2484221766072, 55.346710220459975, 52.55832864392189, 57.572270900972434, 60.49493874272993, 61.72623349774269, 60.55607672660582, 58.71997994761313, 62.85245580057945, 62.764500571835434, 62.10420877702775, 60.988694544761415, 61.30702234083607, 58.212119302442005, 52.483297624895656, 48.058981741628344, 48.17451907742409, 55.96132209224086, 62.942513419735825, 62.485435701185665, 65.89941178598713, 65.32425895813974, 66.70287793682468, 66.86899031362226, 67.42384095345774, 66.70863597623764, 64.12716727102956, 61.81227853221279, 64.24153181814378, 66.27368434782952, 66.45347795178814, 78.2568625480898, 57.96387249423612, 0.07893472729671387, 2.0706542701490465, 1.4904613192042997, 0.4593285461587291, 26.975900819224698, 83.74589796989196, 62.83185159006427, 73.26839216293828, 81.95116258436634, 54.40935004142023, 55.428601464917584, 35.92259184006722, 34.15270074721306, 60.99232665954098, 82.47042948199858, 49.18916956070931, 0.352450700536851, 0.09099056103056477, 0.0373497165949835, 0.13193098918324517, 0.06563880405719243, 0.17552817961381328, 0.16165186050197772, 0.08421304245148936, 0.11039804261658462, 0.28096087697532873, 0.12934548840407403, 0.21734513492593843, 0.25766362225817097, 61.52784785916729, 84.60714063336773, 67.62187357871764, 62.80952938141362, 35.54189443588257, 54.34378762398997, 58.57159668399442, 56.97337204410184, 81.65991090959119, 73.72701137296616, 75.37796835745536, 67.18316431968444, 0.5081023918765207, 0.5638558501678129, 1.3616068012291387, 0.7843137688694463, 0.25098567978749353, 33.4781236802378, 57.521550732274214, 55.75552317403979, 77.0584450998614, 60.79425873294954, 62.98254905208465, 54.9374108929788, 54.113218938150716, 52.91061632094845, 56.17164742562079, 60.41223164527648, 65.21626434018536, 64.04033776252501, 64.3188338894998, 53.422273820446385, 52.89934735144339, 48.987143962614, 57.85223399439166, 59.2946973923714, 62.94995807832288, 65.2099375570974, 63.74413213422222, 62.44898511517433, 63.33282063084265, 60.24658603052939, 60.531153986530924, 55.106476814516135, 57.80185507189844, 59.8362551196929, 56.13897015971523, 57.38658197464482, 53.870667411435036, 58.31656025302026, 63.14737096909554, 57.29774029024186, 60.80095421883368, 57.818050538339925, 58.132361827358125, 56.60137837932956, 53.51346892695273, 51.98297577519571, 55.82551394739459, 56.79390399686752, 50.33971840335477, 46.5950825906569, 45.431378118453495, 45.4303700693192, 46.848750114440925, 45.213270802651685, 47.552164446923044, 47.16251619400517, 50.49669165765086, 47.705505586439564, 50.511314253653254, 48.21343291190363, 53.76801898402553, 53.236769245516875, 57.157837190935695, 50.25876852773851, 56.64446169330228, 57.27424529290969, 58.45773420026226, 61.16555813820132, 61.4360918537263, 56.3522647273156, 61.48417226729855, 62.83462470577609, 60.27015163052467, 58.50290813753682, 57.43266197942919, 51.286547183990486, 56.410053007064334, 52.35205511892996, 52.37706807351882, 46.47343027976252, 52.58730711475496, 49.63440564370925, 49.88389976562993, 47.516329673028764, 49.26837398159889, 46.87138219033518, 45.157380950066354, 43.39814693697038, 46.99346596194852, 45.36814951127576, 48.60898040956067, 49.350449577454604, 52.37418513144217, 52.98177988298478, 51.816777106254335, 53.174427093998084, 57.50116617448869, 55.79619423035653, 61.806846049524125, 57.849249070690526, 59.79704710745043, 56.738680947211485, 55.3882049745129, 59.86539048533286, 56.80397664347003, 59.271649545238866, 63.0341007632594, 64.62408450341994, 63.223308055631584, 62.04129788183398, 67.78513047002977, 64.88659697194254, 64.85711643772741, 62.90245817553613, 64.61496891513949, 61.840146972287094, 54.095109355065134, 51.113676563386, 52.61540697466943, 59.62838519004084, 65.72634112450385, 68.7372858293595, 68.50661908426594, 66.59126297120126, 67.73082917736423, 70.1830244064331, 70.96155997245543, 70.1950974618235, 68.46146475884223, 64.33514702704646, 66.74433738954606, 67.69612404607958, 66.19380920164048, 81.04421646364274, 61.16751932328748, 0.24628614405951194, 2.837691898307493, 2.775067336136295, 0.8263505454505644, 31.120137899152695, 89.4533544971097, 72.50324756868424, 80.06724034586261, 84.05073673494401, 54.81795118701074, 64.2208020917831, 56.48961044126942, 47.59985654584823, 73.74382265152471, 92.37851696629679, 64.24052769137968, 0.49457867239271447, 0.16666480279978246, 0.25846985318968374, 0.20457676281371426, 0.15275745712701352], [0.04032990204230432, 0.028280662410261653, 0.008563694709371175, 0.04000283995523088, 0.039623105492923534, 0.09802127166861489, 0.09433553073435061, 0.3553003024670386, 50.7472958103303, 61.77007382915866, 52.62017265442879, 32.77542714149722, 30.020287652169507, 32.70709160835513, 56.69362075867192, 37.184990990546446, 51.16338868294993, 71.54689527327015, 54.70235109329224, 76.08691323188044, 6.139309483189737, 0.3463803423989204, 0.07779203054885711, 0.13333939586675939, 0.1076062266985255, 8.974626141209757, 54.37806129455567, 42.97758256235431, 71.36708597983085, 55.32245820568454, 56.74085394028695, 46.413641591225904, 52.60595798492432, 49.47179594347554, 55.57396058113345, 50.37601993929956, 58.27718750123055, 56.30075223984257, 55.17603612715199, 44.43101682970601, 45.92298053926038, 44.049001509143466, 57.19119694925124, 55.92840163938461, 74.31901470307382, 44.44802422677317, 51.78762212876351, 62.7760950980648, 54.793542277428415, 56.094835650536325, 52.296604571803925, 53.02637330947384, 50.24619340896607, 48.58066481928672, 51.364759245226466, 52.675419238305864, 50.785189828565045, 53.62169496474728, 55.882054913428526, 49.360400630581765, 51.69475609256376, 49.95807963032877, 48.81820355692218, 45.522428097263465, 44.61047703219999, 45.380371616732695, 45.61777699378229, 45.83501746577602, 47.02117358484576, 43.10798568110312, 42.1337434553331, 38.42282041426628, 42.77189739288823, 42.379287750490256, 42.46919239720991, 41.47472643083142, 41.328931931526434, 44.220220811905406, 44.634015175604056, 42.065305940566525, 46.43517148110175, 50.054609160269464, 48.35599537818663, 41.12782416805145, 45.702366828918464, 51.75567442371, 53.10904510559575, 57.958800869603316, 57.770895804128344, 58.090141434823316, 57.257281041914425, 54.16635920924526, 53.90570986655451, 51.25221860024237, 51.54362716982442, 49.170546147131155, 52.13688565838722, 49.90912060583792, 49.60109687620594, 46.76008101432554, 46.019635585046586, 44.26939164438556, 46.20037055784657, 42.14463587730162, 44.111241679037775, 41.42015057225382, 40.26476152481572, 40.13381711898312, 39.42328760700841, 37.95510915017898, 43.47089905892649, 46.98811977140365, 46.58104835018035, 43.03987764543103, 43.80895637696789, 48.1495806478685, 48.01993846893311, 46.36064644782774, 47.40203572857765, 47.36502816600185, 54.0263266717234, 49.97907607786117, 48.335759870467655, 52.403999067121944, 47.438172524975194, 51.80774781011766, 54.67815006932905, 57.252201572541274, 57.473254588342485, 59.14282321929932, 56.67102790647938, 60.498421807442945, 60.76014587956091, 59.54246567141626, 58.808743184612645, 57.03829119282385, 52.98213681867046, 47.64594439537295, 46.7528481637278, 46.37266066766555, 51.93396968226279, 58.90059724930794, 57.22001068053707, 60.741628369977406, 61.81632641823062, 66.43548211743756, 62.587684046837595, 66.11969209486439, 62.3356560737856, 62.05860730140441, 59.41041123482489, 63.96423201407156, 60.76067932190434, 74.90488344623198, 47.47955353029313, 0.27565409399328694, 1.6808329426473188, 0.2999998779306489, 0.1929145910206341, 30.78462031579787, 77.35778470193186, 55.533501332806004, 71.90769057120048, 54.91662233106552, 21.29646178214781, 48.46346047616775, 49.55056105890582, 49.13224420239849, 52.36904682651643, 67.48262943760042, 37.87543796723889, 0.18734081107522213, 0.1358282623151618, 0.09196730015138466, 0.058265793843254934, 0.05159499131203179, 0.0614218807388698, 0.06576376065852181, 0.04791220747715524, 0.1464425637236526, 0.024132976203315684, 0.04127040137386611, 0.019154540420840346, 0.34265494875369534, 60.75424271245157, 68.34321314288725, 54.936771546640706, 45.5941290240134, 28.240710266174812, 40.749641003147254, 72.637541678644, 42.12389830620059, 56.746451162522845, 79.78013069398942, 61.56986821082331, 83.41804273666875, 6.49253313579867, 0.33772759379879125, 0.9986019218640944, 0.19030164897201524, 0.4325980837306669, 10.996039221363684, 58.614609395304036, 56.94005935422836, 76.52750522859635, 57.17706072715021, 62.72605349940639, 49.501366692204634, 54.97854871134604, 51.337502694899044, 57.93287400276431, 53.889106473615094, 61.394640245745265, 57.70950678856143, 58.1101494450723, 45.3489024408402, 49.04362217072518, 46.599569782134026, 58.158100420428866, 55.532783539064475, 73.76628214313139, 49.39855744761806, 55.17074484978953, 63.950519407949145, 57.540550693388916, 58.35894930747248, 55.38307451432752, 53.95763028052546, 51.60346684917327, 51.496868595000244, 53.356291709407685, 54.147629891672445, 53.985126095433394, 53.7028488036125, 58.24045450456681, 52.79924061990554, 55.98593496507215, 53.7488385938829, 54.04296928836454, 51.15381025498914, 48.688078926455596, 48.7320565408276, 50.246224787927446, 48.39232044835245, 48.939800954634144, 44.33405976141653, 43.78378260520197, 42.431922035832564, 44.80201813482469, 43.98044632327172, 45.674447398031916, 43.61281433413106, 44.838347127360684, 46.22233975318171, 47.73865353676581, 44.433574215058364, 48.53766779745779, 50.431121395480254, 50.019594161741196, 44.68839883804322, 48.173154092604115, 53.099333317049094, 53.7390483579328, 59.68251782078897, 60.1054395398786, 58.488156103318744, 60.10922070472472, 56.60315129064745, 56.167948630548295, 53.601514370210715, 53.96489843245476, 52.00972633977091, 54.17214862761959, 51.35428259449621, 51.20516977002544, 49.25705402128158, 48.656919617806714, 45.20138602102957, 47.645975774334325, 44.10449127997122, 44.85944947888775, 41.8335291647142, 41.92572839798466, 42.48425037630143, 40.96719134238459, 38.79700276159471, 47.22038292115735, 49.07429902784286, 53.607005688451956, 46.29925743226082, 48.92622563146776, 50.57469583326771, 52.74036976598924, 48.997648069935465, 52.620682562551195, 51.68209075927735, 56.6324160945031, 52.36193164702385, 51.547341654377604, 53.135328908120435, 51.79920881025253, 52.95007928725212, 57.649929908014116, 58.296701292837824, 59.16277239399572, 60.55551975004135, 60.38793256205898, 63.13678056963029, 63.63286233717396, 61.262142581324426, 59.62030510748587, 61.70564105433803, 56.43796067084036, 50.948784043712, 49.75879969135408, 49.96854059157833, 52.91674698552778, 61.25907136547951, 61.472871918832105, 63.645586506012954, 64.49814896429739, 67.80638187162339, 64.96733111719932, 68.36528824221703, 65.78608274459839, 67.24847178305349, 62.18329944918233, 68.16918542308193, 65.35620274082308, 77.80236182674285, 50.015781617933705, 0.19639434623381785, 3.115205961850382, 0.52142585597692, 0.2079141635688082, 35.06471457019929, 84.28895796498945, 63.28717208677723, 78.12643589511995, 66.09583623947637, 27.67797762347806, 50.94618743465793, 51.335988660012525, 37.64946237687142, 62.96393348324684, 74.3404543784357, 52.502572151922415, 0.2107184130938784, 0.1861310050251984, 0.06998469827756768, 0.09070437356469133, 0.04751530498446477, 0.1802973374123535, 0.12057428728909263, 0.17071127921583193, 0.2449077986661465, 0.1330870311827429, 0.15737051685010234, 0.20003537827682114, 0.6344099126515851, 72.55008851328205, 80.40779621370378, 67.32170243417063, 45.061051461004446, 41.54943189313335, 49.23428858480146, 71.20823783259239, 52.44487800905782, 63.321912519393436, 84.30885222650345, 64.92772302319928, 88.83267079630207, 8.21527292651515, 0.5805539315746677, 1.666206669422888, 0.9579493129445661, 0.5648438584419989, 12.707483076280164, 57.45952237036921, 42.71142228957146, 81.62845350080921, 58.51552248001099, 65.19616611542241, 51.25741181835052, 57.8459660468563, 53.35775083111179, 62.02036419222432, 56.10483377210556, 64.93536380029494, 60.30309953997212, 62.65415253177766, 48.206933544528106, 51.26406415816277, 47.70254811932964, 63.64310364569388, 58.416470866049494, 70.92535649576496, 53.40152840460501, 58.270260595506244, 67.52208063679358, 61.65407365368259, 61.82354750171785, 57.62425407286614, 57.30448676693825, 53.53240613014468, 52.28851272213844, 57.92109904750701, 56.1645479356089, 57.372128040559836, 57.13112192769205, 64.05089678302889, 55.8903193473816, 60.23116719338202, 57.787256010117076, 57.51019939299553, 54.60172268652148, 55.882572666291274, 54.359657533707164, 53.36334020860734, 54.354770260472456, 52.38368511199952, 48.1041282223117, 47.14911345512637, 42.33860100469282, 45.35155004070651, 46.35122491467384, 47.42922559861214, 45.92317273539882, 46.38790299815517, 49.02325330242034, 51.06849870374126, 48.093333859597486, 51.647444463545284, 54.474045615042414, 52.79378460299585, 45.549884688469675, 50.914016154504594, 54.7514356336286, 57.45122655745476, 63.821728383341146, 60.147989411507886, 61.31322753044867, 63.350439917656686, 59.773579566709465, 59.58504299963675, 55.09477638429212, 56.88913914465136, 54.996874024791104, 57.83669356376895, 55.41455153496035, 53.16315420212285, 50.95015687327231, 53.393871938028646, 48.57534216296289, 52.978653753957445, 45.30465026055613, 48.62948656082154, 45.08830801133187, 44.92835375570482, 47.4650642948766, 44.065259733507716, 41.17084080173124, 49.28695424910515, 53.03656754955169, 58.100908340946326, 50.636253510752034, 54.554356144320586, 57.258673483325595, 56.183104668894124, 54.24410058606056, 56.74741214321506, 56.03407813656715, 61.424395345872455, 54.60143243112872, 53.69087772984659, 57.044253195485766, 52.79337275412775, 55.516862638535045, 59.32753547545403, 61.7066804824337, 63.34160674002863, 64.354507846217, 61.477594452519575, 64.76812962562808, 65.41462252216955, 63.21649489864227, 63.005840086167865, 65.4097705502664, 58.91882058112853, 52.86074338420745, 52.94033611974409, 51.92854896668465, 56.51282302794918, 66.70568635386806, 62.72053472457394, 66.54017017733666, 67.75171972090199, 71.30768560594129, 67.41595698941138, 71.89793171421175, 69.45119642442273, 70.76158185159007, 64.64861108410743, 71.24394709064116, 68.943845687374, 78.8309798702117, 53.17245806417158, 0.6190000846982002, 4.7956790270343905, 1.55105801599641, 0.46458259164806337, 39.659932044244584, 90.61792189075102, 69.71171240652762, 87.29945551964545, 68.59029108478178, 34.6978945116843, 62.68285643669867, 71.52064677207701, 61.32378262858237, 70.39116890199723, 83.95376789954402, 69.3103676457559, 0.21039759079294823, 0.3419948261111014, 0.19324688931867, 0.24446012752671398, 0.14052569896223085], [0.0691428519184551, 0.02198616418266489, 0.0554654207230816, 0.05400840576077181, 0.05849670423495193, 0.028813938129573103, 0.04512062521591302, 0.20115595040542467, 46.794413520443825, 60.939253068739376, 54.49263372728902, 40.72731094975626, 57.01599251839423, 42.22436981816446, 36.12171096186484, 35.8336599411503, 47.45616835932578, 70.5570145576231, 58.39109313103461, 73.76961615777785, 23.105717782051336, 0.37394813892822115, 0.408633443857393, 0.1577311604013366, 0.13647625012503517, 2.3057067153915285, 47.55536510098366, 38.82776198848602, 64.77970061763641, 59.57079302880072, 54.55719201795517, 47.09020337750835, 52.56307078946022, 52.57831311994984, 56.09354519074964, 58.35541132957705, 57.17401304552632, 57.908759270944905, 51.00251267033239, 46.12706145932598, 43.61894892108056, 51.57512772467829, 54.71889957304924, 70.16125525197675, 51.250379008631555, 39.25151525005218, 62.09111590539256, 57.21480961768859, 61.71834953369633, 53.48442769819691, 54.493692767235544, 47.462455918712, 50.92078224305184, 47.27909688026675, 52.95163254584036, 53.547303292059134, 51.349465923924605, 52.9262508884553, 53.48833045651836, 48.93696508099956, 52.14384002070273, 49.56182218367054, 49.67544540282219, 47.552231127215975, 46.09401156825405, 44.65008512620003, 43.61450095330515, 44.24171147807952, 49.587756895249896, 46.759806448413485, 43.35130599237258, 41.968423397310325, 45.99257123085761, 42.24340900298088, 43.5661381290805, 40.67051110729095, 43.52777734879525, 45.83536263435118, 44.48721262716478, 41.63351574251729, 46.51541140771682, 47.29375477760069, 48.788130744811035, 44.16963008142287, 49.79077877536897, 51.50933388740786, 51.38870139275828, 56.64161797492736, 59.125741297198886, 59.252982985588815, 57.97797733737577, 56.4060482671184, 55.90360049278506, 56.19707615144792, 50.620720924869666, 44.10661328223444, 50.603054569613555, 49.300404056426025, 46.850785824560354, 43.44966726918375, 43.950879496912805, 47.05339193344117, 42.49450345193186, 42.980740070343025, 42.67314387905983, 40.85535280166134, 41.46750142497402, 38.03165812646189, 41.088376891228464, 42.3417349784605, 47.06315863517023, 45.886161250452844, 43.50359593668292, 43.895095548322125, 43.58339655783869, 46.64921129903486, 47.8041414291628, 48.36630728936965, 49.51693850178873, 48.149317849066954, 52.88424622627997, 49.27524597414079, 47.343160952291186, 52.40115142637684, 49.14449376444663, 47.24588617201775, 48.36058455128824, 51.32966187692458, 50.02031980022308, 54.385525564993586, 56.12063700152982, 60.96283828058551, 59.74845286338561, 60.454605010248, 58.58261854417863, 57.52211163120886, 55.19323572035759, 52.14047854946506, 47.62178651748165, 48.626093710622484, 46.232400632673695, 49.89166998094129, 53.53680702947802, 59.12925574087328, 61.35449870940178, 66.3171834330405, 61.69661568057153, 67.29554806986164, 64.76772169913015, 66.11042745651739, 59.003190763535045, 65.94894347652313, 57.701932691758685, 77.9136630027525, 33.519206585422644, 0.4796023889174385, 3.0944107809374413, 0.07142386339124172, 0.3173310543981291, 29.141178592558834, 77.79483872075235, 53.75423969761018, 74.78995015544277, 43.169970896936235, 31.38378981621035, 62.62946513391311, 37.86024662756151, 38.49045384314753, 52.10267866811445, 77.65960324195125, 35.056810994302076, 0.3560429174573191, 0.10561637460224091, 0.05417222983293957, 0.09826392235775148, 0.03293654836353756, 0.03453763382088754, 0.03266518086855931, 0.03389954386699585, 0.026346661954096733, 0.031015510115051464, 0.05332325885613119, 0.047302466606901544, 0.16983466012583626, 58.64054410688339, 67.21721833752048, 60.54359182234734, 39.32822896588234, 39.1102118645945, 45.84476063328405, 55.276433114082586, 44.54916254166634, 50.105368552669404, 77.84642573325866, 63.04456956924931, 78.58121118237896, 25.091084280321677, 0.5497879631096317, 0.6670790273816355, 0.8328127115964891, 0.28499429925314845, 2.8195752059259727, 50.86691633347542, 50.44489675952543, 78.00292045839372, 62.03730490899856, 58.578739320078206, 51.25167339078842, 55.25178101754958, 57.14766648507888, 59.878522580669774, 60.18260825064875, 61.52789492760936, 57.95787126787248, 54.53632500863845, 48.901542155973374, 46.937536885661466, 54.748505623109885, 59.17519061796127, 68.98372050254576, 59.195771294255415, 39.613577473548155, 63.98184345614526, 57.72232509428456, 64.64682248330885, 56.07696533203126, 57.73075426778486, 49.26029782141409, 52.88675654319025, 49.81906690905171, 52.686951006612475, 54.70294337118826, 54.39610419734832, 55.97913357519335, 58.72859347251154, 53.99157054962651, 55.81376644872851, 54.60335831488333, 53.583585216153054, 51.650374474064, 49.64115212040563, 47.38439290754257, 47.21345209306287, 47.62877225875855, 51.83653408481229, 46.93176707913799, 47.118777844213675, 46.01795681061284, 45.63671419697423, 43.61103357807283, 45.0350304572813, 41.731382800686745, 47.80525538229173, 46.07008903257309, 46.02955918158255, 43.684507416140654, 48.42612735686764, 49.288852676268554, 50.01186709250174, 44.805120729631, 50.72807227411578, 52.35201981759841, 55.18007616842947, 58.84227944958595, 60.59138590289701, 59.59959891534621, 59.679787851149044, 58.44968941903884, 55.34956962831559, 58.11225575785483, 53.79651500332741, 47.13084305486372, 53.31989211420859, 51.03699422651722, 49.53753094519339, 47.043382044761415, 45.4421450245765, 47.04793591653147, 45.351063666805146, 42.870188067036295, 43.3369932636138, 41.92616378107379, 43.41708021779215, 42.46079460267098, 40.95130966555688, 44.01648113804479, 49.112012617049686, 49.268656392251295, 47.48115777969361, 47.50029110139417, 45.81029476657991, 49.94222933246244, 52.422061581765455, 54.348266970726755, 53.79824084620322, 51.01646846340549, 56.44094167217132, 54.19113682162378, 49.477404932821955, 54.17673387835103, 52.69492126280262, 50.40475914555211, 49.96379844604, 53.66571180282101, 53.57828217168009, 57.37661523203696, 57.40338540846302, 61.17086902741463, 61.297545894499756, 63.37756310739825, 60.49420133713753, 58.681929034571496, 58.9240098768665, 56.21955525490546, 50.63675949650426, 49.39105395347842, 50.003598736178496, 52.45177353582075, 56.88501281123008, 61.87118076509046, 62.49181739745602, 68.68039577238022, 66.27107204929476, 70.855726580466, 68.72886057822936, 69.62383562518706, 62.794471402322095, 69.24877858931019, 61.16719376656317, 82.56352301566832, 36.328490472609, 0.27266619787100826, 4.396045400250343, 0.12597838642015574, 0.3632833063602448, 34.297863744920306, 83.87716401007869, 61.650441538903024, 80.5654598051502, 45.80939654381045, 23.50339316552685, 65.03296805966285, 47.66823130269205, 45.19924832928566, 59.76844126178373, 84.18384628911173, 47.66821561321136, 0.382973880416924, 0.19465567904614633, 0.07262673634555071, 0.06723642679712466, 0.006563450151588769, 0.19483272196544757, 0.11766352855990972, 0.17021637109498824, 0.16501031335323088, 0.16890099812899867, 0.17929681126148472, 0.11785510416713454, 0.45950946548292715, 68.86665344238281, 76.88575098591467, 70.87621704224618, 51.78975589813725, 73.42481628541024, 60.238451034792014, 48.926908123877745, 50.006720942835656, 61.42923162829492, 82.20384167086694, 68.2458677599507, 82.76660765371015, 29.691122347308745, 0.6562698944922417, 1.084246568141445, 1.439841416093611, 0.4387390138881822, 2.8149014567175223, 54.99593265594975, 38.076722237371634, 75.94102459569132, 65.88172974125033, 61.04271734914472, 53.61093590336462, 58.35375216699416, 58.638496629653446, 61.62544819616503, 62.900704876069106, 62.17363865144792, 61.603090686182824, 57.204937011964866, 51.61129982240739, 50.95444010150049, 55.93237500036917, 63.40199162883144, 65.10032692263204, 59.979064695296756, 44.234768882874526, 64.35620623250162, 63.060306118380645, 65.83899944059311, 59.46595199646489, 58.92759884557417, 52.0372143099385, 56.39642669308571, 52.545855506773925, 56.358336556342344, 58.59568395922261, 55.907283598376864, 59.83929103420627, 62.349090191625784, 58.7997531121777, 58.60004171248406, 57.32973114136727, 60.71277933736002, 56.1011585112541, 52.18223217994937, 52.59845841315485, 50.77306970473259, 50.88608887887771, 56.09527103362545, 51.17989009426486, 49.621528502433534, 48.18594494173604, 52.19148112881569, 47.287286789186545, 49.04175904489333, 44.281413708963704, 48.060138840829175, 50.445136024105935, 47.37451637944868, 46.080965765060924, 52.15857244306996, 52.2550392150879, 51.83165465631793, 47.18408922995291, 56.420965040883715, 56.741410916851414, 57.731958435427764, 61.829074121290645, 62.63220294829338, 62.67494501606111, 60.453812691473196, 62.90761216994255, 60.59437474896831, 61.83771510278026, 56.71558210926672, 46.88218439778974, 56.794284466774236, 53.69831062132313, 50.494216642072125, 47.55820881935858, 49.46045637130738, 49.55167501203476, 48.90038897914272, 46.92677390190863, 47.743121116392075, 45.51200635971562, 45.40590624655447, 44.106550524311686, 42.12228228968959, 46.48466394793603, 52.51172304153443, 53.622852063948116, 51.207374142062285, 51.59194292560701, 50.091299010861306, 54.38915767977315, 58.10637220259636, 58.93470225795623, 58.653546764004616, 55.322289543767134, 59.04753708070325, 55.91758374244937, 52.542219469624186, 56.63568342885664, 53.8219201949335, 50.9995081347804, 54.54329506043465, 55.87678324791693, 55.96274199024324, 60.98525854849047, 59.72126691572128, 65.68769008882585, 64.13314496317219, 65.75274259813371, 60.80850870378556, 62.15081437941521, 61.84868204978205, 58.896349322411325, 55.30277182978969, 53.26578694005167, 54.15663565358808, 54.95252378525273, 58.88905763626099, 67.16330143713182, 66.31510457684918, 74.31579835953252, 69.28587636639996, 75.17687628346106, 73.97503852844238, 72.96944479788505, 65.22400317653533, 71.66705316112888, 64.58927346814063, 84.54928567332607, 39.547881695532034, 0.7627537257729039, 5.875516360805881, 0.20102407603013903, 0.48431778266545267, 38.73919879236529, 91.24148461126512, 67.39159122590097, 87.38450819446196, 58.58024551022438, 45.84769064380277, 79.61287298510152, 57.342502378648334, 49.28501659824003, 70.92198325741676, 94.10126901442005, 64.82605126596266, 0.33939481562664436, 0.22655020227595685, 0.2052754809659335, 0.1783676385398834, 0.16013843848580317], [0.07703990840743627, 0.15723263634549034, 0.09885308227591938, 0.06417878986065907, 0.13155404328098222, 0.026428562498861746, 0.022164869512761795, 0.11723200655392102, 47.69338938497728, 59.80192261357462, 58.32897455461564, 53.61896891747752, 107.30906609565982, 83.2029164221979, 34.58929192635321, 19.602268511249175, 53.478803019369806, 65.60714421733734, 58.93748714077858, 64.90652653478807, 45.12663741265574, 0.0627987360912225, 0.4761120310473827, 0.12529820759570406, 0.17330788826990515, 0.0564985937108436, 32.75451110255334, 36.990417895778535, 54.38966366552538, 65.33985037957468, 54.151281618302875, 54.85532353001257, 54.503012318764966, 61.25337216161913, 56.09623593668784, 58.2971013745954, 54.33656654050274, 55.1634806202304, 49.530513824955115, 46.22474416609734, 47.31557492286929, 54.09065354254938, 58.02694420660696, 66.10704637342884, 36.82570580513247, 53.03279030707575, 58.746769735890055, 60.03956725520473, 55.67443601546749, 54.80682734520205, 53.37674294748614, 51.9668822903787, 50.355098016800426, 53.808662583751065, 52.79065847396851, 53.46461972882671, 48.02752825521654, 51.085933639157204, 52.049114781041304, 50.82593933228524, 51.51661380644768, 49.40367221832276, 47.93340313819147, 48.90707269791634, 41.953020249643636, 43.27504727148241, 44.517473713044204, 45.761037641955966, 45.583597460100734, 44.763963299412886, 44.27284333013719, 45.8905033142336, 44.50859346697408, 44.14782954800514, 38.35046837406774, 40.76387528450259, 43.77527890666839, 45.788690351670795, 44.45872053023308, 45.616223735194055, 45.928730733932994, 47.19548763767366, 47.5858772185541, 51.62251387873004, 49.52882720578102, 51.72687245953468, 50.484963770835634, 56.850370437868186, 58.51040770930629, 56.43560724873697, 59.529619909101925, 53.81014916204638, 53.991739211543916, 53.434025241482644, 48.46552756524856, 48.173008964907744, 48.44512731798234, 48.94917934171615, 48.40034561772501, 43.72698668510684, 43.91721379372382, 46.08324073976087, 41.62140738579535, 41.20501641304263, 42.097304636432284, 40.73834457705098, 40.791269117786044, 41.39276850608088, 44.01400612246606, 43.1590667078572, 42.890478487937685, 44.025004448429236, 44.82273609407487, 42.873682898859826, 43.14495009760703, 45.9174656867981, 48.84780960698282, 49.16634921104678, 50.34012240748252, 49.19514333048175, 51.91570712674049, 49.27698358412712, 49.262286463091456, 50.94247687247492, 48.39909438164004, 50.27108869244976, 49.55935109046198, 48.47841647363479, 48.79448498449018, 52.460034047403646, 54.80385026624126, 59.48077463334607, 60.81176034865841, 56.04105211073353, 76.05938603801113, 67.47269799632411, 53.8117887127784, 58.137594269168, 50.65576730235931, 48.75720285600232, 47.349546570931714, 47.62992543558921, 48.18284234692974, 57.1665644645691, 57.58663462054346, 63.51213570564025, 59.51623678207398, 65.1004602832179, 61.58058804850425, 66.31127634356099, 60.93970021893902, 68.80151856330134, 59.230162635926284, 81.18556299517232, 19.90017056465149, 0.20180462769442992, 3.1581769979769185, 0.27546738304438134, 0.37719362445415994, 35.0547674394423, 68.35945960014098, 58.04016259408767, 62.90901245609407, 49.095401379369925, 35.38150871953657, 42.598163850845836, 40.08523071965864, 20.676752790327996, 57.858250910235995, 69.58648681640625, 28.705177730129613, 0.5073489597247494, 0.06324009849659859, 0.04665359779591522, 0.2027275338168106, 0.02880494617256186, 0.05119419326224635, 0.11578005543279073, 0.04261184814235857, 0.02451301135513331, 0.07859555718999717, 0.18740723089825723, 0.034350302340763236, 0.10525750837499097, 57.73919913076586, 65.04529999148461, 69.33536098849389, 57.48732805252076, 84.8115510325278, 83.74312093180995, 31.9155926089133, 27.50034916785456, 58.48610862608879, 71.24058954177364, 65.70980833422753, 72.19960904890492, 49.27299845603205, 0.020037182877140663, 0.41351458838870453, 0.681644810303565, 0.28566683252011577, 0.08393934221878167, 32.211939442542295, 44.97023290203464, 67.46120545171922, 67.62352097419001, 56.36974280880344, 57.14538366563859, 57.128580231820386, 64.49730565471035, 59.569557482196444, 61.42643890073223, 57.097989666846495, 57.54184899791595, 50.75444236878426, 48.44857115899363, 49.59906508845668, 58.111016288880386, 59.664725949687345, 70.51035404205322, 40.19343322323215, 51.79931863661736, 61.22164018692509, 62.96778525075605, 59.82910856123894, 58.20757327541229, 56.817712783813484, 54.87364884345762, 54.69596547465171, 56.28448224836781, 54.64723394763086, 52.54798535377749, 51.17091963368078, 52.795592815645286, 57.96057770329138, 54.262331762621486, 53.92151701834894, 52.50869104939123, 52.169645294066406, 51.368775752282914, 47.24627056429463, 46.336410122533, 47.283882171876975, 47.656828972601126, 48.7338569087367, 47.844592832749896, 47.124284851935606, 47.77830085446758, 47.01372892625871, 45.82353276591147, 41.67471239643712, 40.7009094761264, 46.36721641786637, 47.906083829941295, 46.37988175115278, 47.840384129555, 49.49746785625335, 50.06952201166461, 49.851226422094534, 51.982473711813654, 52.71936547371649, 54.41990513955393, 52.874216725749356, 58.87605105676959, 60.10778511724165, 60.067643580898164, 60.948725592705514, 56.97217964356946, 55.73506016885081, 55.07490173462899, 50.40290778683078, 47.87486176336966, 51.85097625178676, 51.87781310850575, 51.11783427576865, 46.254628704440215, 47.025625474991344, 47.10203324594806, 44.860026067303075, 43.19390127735753, 43.30261761142362, 44.427690659799886, 41.55877497888381, 42.09398238889633, 45.31694296867617, 44.49279808229016, 45.524922724693056, 46.127073226436494, 47.67524057818998, 46.26289313839328, 47.06956386566163, 50.707189575318374, 51.9269133383228, 52.73516870314076, 52.53294306416666, 52.51910494219873, 55.8765753622978, 53.22955208439981, 53.11272821118755, 53.597042868214274, 51.3340941552193, 51.26805320862801, 51.43306732177735, 48.91338771389377, 51.75262281971594, 53.99437112192954, 58.452372320236705, 62.96881683411137, 62.930357994571814, 57.15561712941816, 70.17576802161433, 68.23254739084553, 56.389805732234834, 63.4598034428012, 53.00392950734785, 54.625778582788286, 50.298549206026145, 49.729938891626176, 52.02585904828964, 58.23879926435409, 58.57985719557732, 64.22068442067793, 60.62051342379663, 67.03124307817029, 63.50435764558854, 69.60894630801293, 65.66024918710032, 72.31462078709757, 62.46390973367999, 86.74843311309816, 20.975633475088305, 0.36925030391543145, 3.6396861797378914, 0.1541409812747471, 0.37911996786152163, 37.668046566747854, 77.24882125854492, 64.31642163184382, 72.20116230749315, 51.46317935759022, 34.08850331460276, 47.758610556202555, 50.07674701752202, 24.133316009275376, 60.384037648477864, 80.8224299646193, 39.004300025201616, 0.6157706257316374, 0.18180171959102157, 0.14381836018254682, 0.15613896922478754, 0.0742212181249934, 0.17762601946390447, 0.1993916805593237, 0.17170055919597227, 0.16983787769511824, 0.21790284693481463, 0.22252536018288907, 0.09387883507917005, 0.1720948952941164, 70.4259132569836, 77.27718783963111, 72.6024756893035, 67.41299167756112, 112.67421737793954, 96.1263495106851, 49.56807051935504, 29.941467623556818, 67.31367726479807, 74.11155269991967, 70.39060408069243, 75.62849014036118, 56.00433480355048, 0.16609379150454076, 0.813405191706073, 1.1163217502255594, 0.5784716433094395, 0.1324583181450444, 38.36499291081583, 40.403331018263295, 56.48816700904601, 74.58190764150312, 57.82449107016287, 59.5961158506332, 57.885350565756525, 66.86673887314336, 59.79644698481406, 63.687285223314845, 59.82016163487589, 60.73568205679617, 54.016057906612275, 51.242565647248306, 51.55235444345782, 61.42095150486116, 61.861041438195016, 66.98638685287969, 43.87097689413255, 53.56778983146914, 62.7650575483999, 65.83511629412251, 62.02924051592427, 59.75118283302554, 58.78316540871897, 54.48383585099251, 55.952355554026944, 58.37586256765551, 57.160296517033736, 56.25695505449849, 54.70577924482284, 56.92228317260743, 61.05875199840915, 57.74382360519902, 58.46031511983564, 55.213071146318995, 56.18237903041225, 55.279465106225786, 50.440087933694166, 52.71181491113479, 52.455240911053075, 52.251481625341604, 53.34161420022288, 52.92403867167812, 48.636660575866706, 49.01049775461997, 50.28021997021091, 48.156589923366425, 43.785167201872795, 43.86973742515811, 49.228452097985056, 51.42023332657353, 47.05772615248158, 49.31716042180216, 50.664655393169774, 55.06232661585654, 53.359606112203295, 53.8214377434023, 54.553716797982496, 56.679084454813314, 55.27755491195187, 60.412718019177845, 63.369569316987075, 60.452659514642534, 62.695917929372484, 57.37621122790922, 58.75742289327807, 56.74715326678369, 54.32381883744271, 52.30905809710103, 55.568065258764456, 55.264148250702895, 54.450797727031095, 48.41008486286287, 51.31205043485088, 51.86726193274222, 47.967790557492165, 45.56774323986423, 46.10873614588092, 46.472810545275294, 45.45615180846184, 45.61631394970802, 48.82896261830484, 48.64462690968668, 50.64121530902002, 50.116190371974824, 51.556876936266505, 49.58631346302648, 51.09677899268366, 54.679142428982644, 55.94555024177798, 58.84231867328767, 59.797615851125414, 58.84077325943978, 58.28371824756746, 55.50426398554156, 56.836324430281124, 51.9011825899924, 52.014276289170795, 53.1779101587111, 53.845426959376184, 51.3865166325723, 54.43736360919092, 58.516428547520796, 60.06114421352264, 64.02849612697479, 64.65167445521202, 59.730256988156235, 68.0731422670426, 70.73799271737376, 58.81431295025734, 64.87739116914811, 55.90318864391696, 55.000255107879646, 53.07361433582922, 53.58105136502174, 54.08621734188449, 62.73535736145512, 59.345723505943056, 69.8014013228878, 66.17546819871473, 70.9061525714013, 66.94592368218207, 73.67365144914197, 68.3202672773792, 76.18906744064824, 65.77416266164472, 90.55424613337364, 22.28288100611779, 0.5141917796384904, 4.713500959257926, 0.29890847843020196, 0.7428538258517943, 44.13650174294749, 83.07152486616566, 71.18618626748362, 78.0337816669095, 64.27211453837734, 47.137036477365804, 59.779518035150346, 57.53928376782326, 30.11103168610604, 78.20609923331969, 89.33098439247378, 54.73184731698806, 0.699285057283217, 0.3309406676600057, 0.30791699826236696, 0.22210712214150738, 0.1588433821715655], [0.06520892914024091, 0.017861573611416163, 0.00029000671342909037, 0.0709880436319978, 0.03544443677509985, 0.03667711438010297, 0.030720388148761088, 0.12104428989151794, 52.143604678492395, 60.918276233057824, 30.102606434975904, 32.38988364896467, 111.6789943941178, 74.7689890092419, 62.60626823671403, 18.352815143523678, 52.52461979466101, 70.49893994485178, 56.383118091091035, 60.30329958085091, 59.71379087817285, 1.780924107278547, 0.0419853605900801, 0.5056229023443115, 0.6233138338692727, 0.37366398159534703, 14.497160565468574, 38.026821844039425, 40.80074164175218, 72.34006912477555, 52.902171457967455, 58.32097291946412, 57.1620302046499, 62.985604578448886, 58.91072873146304, 60.31225042958414, 51.862111860705966, 51.66633067592498, 46.04421707891649, 46.918925239193825, 55.087971072043146, 56.815731986876465, 63.97131581460277, 53.60194975329984, 42.456789862725046, 56.005605651486306, 57.98318232259443, 59.22608729331725, 56.194318725216775, 56.33356678870417, 54.87379004878383, 54.60110687440442, 54.61063431155298, 53.95872854417371, 50.07736675200924, 52.9101848602295, 48.28039561548541, 50.788217898338075, 53.520721389401345, 49.841098862309615, 49.55824890444356, 49.82575847256569, 44.40978111759309, 47.363145428319136, 42.8188834651824, 46.4917242142462, 43.80889754141531, 44.64569599397721, 42.960790895646625, 43.38402248197987, 45.33629202073621, 45.36048912232923, 45.563754189398985, 43.91542911529542, 40.04481853977327, 42.51342104327294, 40.63921843805621, 46.19343188501174, 44.24492782162082, 47.364894805415986, 46.01961597319573, 48.26271357074861, 47.20612902795115, 48.14153978901525, 47.32525141008439, 52.356024557544345, 54.47055862795923, 57.77145670306299, 56.936933225201024, 58.640497038441325, 59.0653681755066, 53.29251004803566, 55.46813111151419, 54.605507773737756, 51.77722784780687, 47.63598157513527, 46.97376781894315, 50.68780522192679, 47.03325056260633, 42.89845658886818, 42.7856021542703, 45.988809677862356, 40.168710524036044, 42.49350324753792, 41.33017532287106, 42.07838312272103, 39.844738437283425, 43.01885374130742, 46.56889684738652, 46.47866272157239, 42.98914963199247, 45.91666944565312, 42.69113579104024, 43.31497699983659, 44.16384850778888, 50.07091445307578, 48.97187809790335, 50.32020068937733, 47.20692526909613, 48.99812267672632, 51.82951696457402, 48.78067039674329, 49.44179765639767, 50.13329190592612, 51.82115447136664, 57.49881667475547, 53.165280126756244, 55.46752314413748, 51.431741560659106, 54.78940025452645, 53.05544983956122, 62.285779214674434, 57.13750362396241, 68.86460596515288, 77.53869225901943, 58.25594002200712, 58.12844730192616, 56.5466691601661, 54.32846292372673, 59.58168152839907, 56.37404564888247, 49.95970741395028, 48.22024606889295, 51.58040331256006, 48.10980389195104, 54.291714237582305, 55.69830756033621, 61.45390725904896, 58.804534481417754, 62.08613057290355, 59.21427311435823, 67.95492987478933, 62.92629834144347, 73.46437731096822, 8.917599781866997, 0.1364148864823003, 3.168559266674903, 0.11978062019953806, 0.605417897384013, 50.12154832963021, 66.01235251272878, 63.06651523036342, 58.240929111357666, 63.865670696381606, 33.1386072404923, 39.960032586128484, 37.994709399438676, 38.370582288311375, 57.85443444405833, 67.54909792254048, 32.63516122295011, 0.3168231687478481, 0.20045464287602133, 0.15034918312824544, 0.1084497967554677, 0.13987717489081045, 0.057724790212007306, 0.036753941507589434, 0.02206805706655066, 0.05366464295694905, 0.06564716207644632, 0.08601655898195121, 0.03262310731975782, 0.3007207053803629, 64.35413522105064, 68.16730268539922, 42.83310990179739, 39.320270476802705, 103.31816427169308, 78.96901592131584, 51.0661845053396, 19.32429405950731, 64.7260308265686, 72.62047936839443, 64.91311219430739, 65.69530340933031, 67.31213185095018, 1.9222116806814749, 0.061817335325383374, 0.9621332561777485, 0.3037660580969626, 0.5739092526416625, 14.55658055120899, 44.06540878357426, 52.41890799614691, 74.02366022909843, 54.63012064656904, 61.9166410353876, 59.245134322874016, 69.2694337906376, 61.13360258840746, 61.426321229627064, 55.474826597398334, 55.155259332349225, 47.3632356428331, 50.53361685045304, 57.83960004006663, 58.787330965841974, 66.15736253799932, 58.53445576083276, 41.9423278685539, 55.241418115554325, 59.701239293621434, 62.915790311751834, 58.125854615242254, 59.99783715894146, 57.78878573448428, 57.38499341472503, 56.31433933011947, 56.19780571229997, 51.99078129183862, 55.37697915107974, 51.021873489502944, 52.78290394813784, 55.10092666072231, 54.81669995092577, 54.266399260490175, 51.97363268944525, 50.18306678341281, 53.286618648036836, 48.692770081181685, 49.33637611327633, 48.958016441714385, 46.557423914632494, 46.796370783159816, 45.41359801446238, 48.564194786933164, 48.07497716719105, 47.56255872787968, 46.408624879775516, 42.689107925661155, 44.132477391150694, 45.401623018326305, 47.08545338722968, 48.3124178455722, 48.606501471611764, 49.1098984595268, 50.17287646570514, 49.77396749681043, 48.92990873705957, 50.1627802848816, 52.4677768061238, 55.29493101181523, 59.836584598787375, 59.688436677378995, 60.70888834614908, 59.961829800759595, 56.28289368844802, 57.46565303494854, 53.00348627951838, 53.36628590860675, 51.084596110928445, 50.709790106742616, 51.999587012875466, 49.46823443135908, 45.7673369684527, 44.14337765785956, 46.84403934786397, 42.15732474480906, 43.25475685058102, 41.48664259141491, 44.408298461667954, 40.74130596653108, 43.80177843955256, 48.83935689926148, 49.91366663286763, 48.19965362548829, 47.06121706193494, 48.537899217297955, 46.88303162974697, 47.56763035251249, 51.18983722502186, 52.27967562214021, 51.56157201336276, 52.24090299298687, 53.81725649679861, 56.433426410921165, 51.56442749884821, 52.66843741939914, 52.8825556847357, 55.283120755226385, 58.01792667758081, 55.972034085181456, 58.04005669009302, 53.638831800030125, 56.563856986261186, 56.48638625298777, 63.84683155244397, 60.992083472590295, 68.20248634584489, 77.6263572323707, 60.557484857497684, 60.997782676450676, 60.71545439381754, 58.66127383324408, 61.95648054922781, 59.716175679237615, 52.24361335077594, 49.43924419341549, 52.172751811242875, 51.15285319666709, 56.87933714159074, 56.198378378345126, 63.81742554326212, 61.75654949680452, 65.29093450115573, 62.67431351446337, 71.0185363215785, 65.95448186320644, 81.5824519434283, 8.733647484933178, 0.17258027328118203, 4.1097491498916385, 0.08234366534217712, 0.7892144639645854, 55.25520916908018, 74.24162633957403, 69.51238539911085, 64.44368685445478, 71.16930438626197, 39.045449610679384, 45.721762949420565, 46.747949123382575, 33.95227939851823, 64.93385761014878, 75.37870576304775, 41.767197962730165, 0.4693186391265162, 0.1972222421318293, 0.06739899831553621, 0.2269527048713738, 0.09458273198575744, 0.17845972230838192, 0.1050337800575841, 0.1360646923703532, 0.22318621826989038, 0.14942267639262063, 0.18441165857497724, 0.16527481286996798, 0.5606981583179966, 74.52593541914418, 78.80807322840538, 43.29660854031963, 44.13418362217565, 118.84918120599563, 78.97271079401817, 77.5216377935102, 29.160800249345844, 69.13029947588521, 78.71253998048844, 68.94397120321952, 69.33700838396626, 74.811170178075, 2.5068904747886043, 0.2466535445062384, 1.6983708402802868, 1.5169444271633703, 0.8852180285799889, 18.434671086649743, 41.63454732587261, 42.232300850652884, 79.3309251723751, 56.468045250062026, 64.1790327718181, 62.11976881950133, 72.45454742062476, 63.29089049370059, 64.37994833915465, 54.98886846726941, 58.03766796665808, 49.45008562457178, 52.9261096831291, 60.63272376214305, 63.653858784706365, 63.96994298504245, 59.20178821009975, 44.78210426145985, 57.33473608570715, 64.68503421352756, 64.79770429672735, 60.55077368213285, 61.86138660677018, 59.276281864412375, 59.2716730794599, 59.11040482982513, 58.611094951629646, 54.08304414441509, 57.0482579354317, 51.42645420566682, 56.09933460912397, 60.64873487718644, 57.486727929884395, 57.281438919805716, 55.82237997362691, 52.72560988703082, 55.46547174453736, 50.19080169739262, 55.51816094306208, 52.781244785554954, 49.38894371832571, 50.190389848524525, 51.26324046042658, 50.90954857487833, 51.10096416165752, 48.94120908552601, 48.780788067848455, 45.87927749080043, 47.50498617849043, 47.28090117054601, 50.25173964038972, 51.33491000821514, 51.428305564388154, 51.88512440650694, 52.48756516364313, 52.91885329831032, 51.13371203022619, 52.17705465132191, 56.25944968192809, 57.22343883206768, 61.93717856560985, 62.27505937699349, 59.740137438620295, 63.312326246692294, 56.42199270186886, 61.3572875145943, 56.69909638743247, 57.64770984649659, 53.7354358550041, 52.87465210883848, 55.34153269183252, 54.17512962895056, 47.48738258115707, 47.68471702452629, 50.475510858720355, 45.636851479930264, 46.59825186575613, 44.451632807331706, 46.45590512983261, 42.82302156571419, 48.283917903900154, 54.393335004006666, 52.79713038475283, 50.70616975907357, 51.08682793955649, 50.6786229533534, 51.47593098302042, 51.33829501367385, 57.020809188965835, 57.2319229187504, 57.123343867640344, 57.08129213702295, 59.11200907922561, 58.16913404772359, 52.946831564749445, 55.068343531700876, 53.87885339798466, 59.36536673576602, 61.85763289851528, 59.8138976097107, 60.206071869019546, 59.45762480458906, 61.81898970757762, 58.180724651582786, 65.47461125158495, 65.8102092435283, 66.41008869294198, 80.321394243548, 67.92240558132049, 61.90821186188729, 65.8187678552443, 59.41995043908397, 63.904557074269945, 61.35510275440832, 55.72669375327326, 53.378570771986446, 57.439412378495746, 53.480838729489236, 60.748441526966715, 61.48848295211793, 68.23646976101783, 65.99283479875135, 69.67619142224713, 65.7482514842864, 74.94617815940612, 68.50363023819463, 86.53817053764098, 10.566749534299298, 0.24767028107758493, 5.44927288447657, 0.10214266382277974, 1.4686851780260763, 60.41190608855217, 80.62707239581694, 77.63519040999874, 72.99660328895816, 76.48748920809838, 48.99103103145477, 56.21696256822156, 52.580140944450136, 50.402523394553896, 78.09399789379489, 85.30855455706197, 54.572234307566, 0.38583724128623165, 0.35886055819930573, 0.30483711030214067, 0.43226210821059446, 0.38485481013213435], [0.06937030342317398, 0.12596530929928826, 0.07569306454951726, 0.12812720942160777, 0.18869542306469334, 0.12959008495653832, 0.05504329095504457, 0.11595523675843594, 51.01307561320644, 57.9502030341856, 47.77242122157928, 60.693371449747396, 99.70570056669175, 68.20411805183657, 59.72921363769039, 37.40474962419079, 25.40803728565093, 73.6807587838942, 48.8477272372092, 60.317910409742794, 62.983506110406694, 7.502109542969735, 0.3522465840703057, 1.3985250073094524, 0.5061593171088926, 0.1974359040539111, 1.9480333789702386, 36.507040685223, 31.00900342387538, 68.81619607248615, 54.24154320070821, 60.440249135417325, 59.18364332568262, 67.04435163928618, 56.74419187730359, 57.93685913085938, 47.44624084041965, 50.32505266128048, 46.25383246329523, 51.83120750611829, 55.75907291904573, 57.542978640525575, 58.055149970516084, 48.75651644122217, 47.61344755849531, 55.460811968772646, 58.74084303455969, 61.269144012082016, 55.633945388178674, 59.68216872984364, 56.136479454655806, 61.80316294393232, 56.19262818367251, 55.72883144501717, 52.52405889572636, 51.34934040807909, 47.448688399407175, 49.9156121284731, 51.28477035030242, 53.17466243620842, 48.15154575532483, 53.16707264992499, 48.72481584548951, 47.99264661727413, 44.38244611986222, 45.59372109751548, 45.413923571186686, 44.34577980349141, 40.16685916531471, 43.7221033342423, 43.78755984767791, 43.74887743303853, 46.081142271718676, 46.85509650937973, 41.170013181624874, 41.07283646060575, 41.14379605939312, 43.45534686119326, 44.73607132511754, 47.41394796679097, 45.38419985002088, 45.868224251654844, 46.12486493202948, 48.97693795542563, 46.265274017087876, 54.93174699044997, 54.6445079003611, 61.89242432194372, 51.9772961831862, 51.237454798913774, 60.52734144272343, 55.12186035033196, 51.631594165678955, 53.79793882369996, 50.70219247571884, 47.70343849735875, 48.499922829289595, 49.3609772189971, 48.591400346448346, 46.268180493385564, 43.69673344396776, 42.14483984055058, 43.3016566307314, 39.91168937375469, 42.284252643585205, 42.555610056846376, 43.20879451690182, 45.82179123355497, 46.31304848578669, 43.86548949826149, 40.13318561738537, 45.85198956151163, 43.334682987582305, 42.45241249761274, 46.45379097230973, 49.417894732567575, 49.05181992438532, 49.62711395755891, 47.56428849312567, 49.61798267979776, 51.01186752319337, 48.13924912483462, 48.65626850435811, 50.89412189299061, 53.89495472754202, 59.84006766350039, 58.727157885028475, 59.096613776299264, 58.051078550277225, 56.16435181710028, 53.913456547644834, 58.56645053432834, 60.13256272962017, 70.990891456604, 42.93871579631683, 56.870696160101126, 61.72857515273556, 60.99752772238947, 62.69346252564461, 59.757819483357096, 57.43522328715171, 58.041664861863666, 50.23683855610509, 50.49840965578633, 48.81976858262093, 50.242208280871, 48.51094076710363, 53.923670399573545, 53.685060854881044, 61.07322946671517, 59.398797096744666, 65.2930643481593, 63.202429279204345, 63.951586292636016, 1.967557589373281, 0.2712510496137604, 2.067668120707235, 0.06137262511577818, 1.4053408609282587, 64.19095285477178, 60.76089897463399, 63.363489643219985, 61.96429391061107, 81.7192877492597, 34.84887438435709, 35.741092005083644, 48.446402088288345, 38.90452277275824, 55.88711084858064, 67.68426279867849, 23.905126240945634, 0.56891196918103, 0.23866137820145777, 0.09785375888309172, 0.13370039181843882, 0.13358324165305785, 0.03254649852732978, 0.12713823587663714, 0.06084262633756284, 0.17195111591248743, 0.13174916587529645, 0.3133552725757322, 0.03487240658291886, 0.08311628033557246, 58.71962301192745, 66.63302052405574, 45.48792692922777, 56.7381828061996, 106.83491429974957, 71.06093714314123, 67.45783221337103, 37.3927903175354, 33.54697304387247, 78.8613860837875, 56.37113917258478, 67.05656590000277, 69.99415443789574, 8.51638642049605, 0.45274898469928776, 2.3845975918154565, 0.7454798526821599, 0.47060784252901233, 2.031259822749323, 39.33645025376351, 41.41483183830015, 75.89967496933477, 54.92440823585757, 65.85245317028415, 62.19810639658282, 67.71066819467853, 58.467583271764944, 60.368842386430316, 51.18652674459642, 52.7219581604004, 47.98085205016598, 55.21769562075215, 57.315657677189, 60.66941753510506, 61.285159049495576, 53.31613840595369, 47.99023043724799, 56.3699899181243, 61.47478995784637, 63.97302596799789, 57.84000404419438, 63.046860233429946, 59.18860120158042, 63.398347746941354, 56.69899048343782, 57.91968307187481, 54.243598522678504, 54.85795151802802, 48.77144890446817, 52.18065146476992, 53.9887660549533, 56.82139588940529, 50.51002379386656, 55.64433182439497, 51.853678764835486, 52.39817434741605, 49.184007721562544, 49.66879306300994, 46.33620615928404, 49.43662405014039, 45.18905408920781, 46.84332155412244, 48.19769244040213, 48.19690404399749, 49.76107074368385, 47.226694014764604, 42.35571822812481, 42.42165719309161, 45.0698140359694, 44.81453441804455, 46.32722000921927, 48.411638121451105, 48.59783303353095, 48.961903510555146, 48.233711565694506, 51.624553511219645, 48.272774450240604, 54.98965294130387, 55.57690235876269, 64.07090087090769, 54.74298684827743, 53.801457189744525, 62.79687189286756, 57.196025386933364, 54.831212720563336, 52.3179461879115, 52.413377454203946, 48.825754119503884, 50.151468169304636, 52.877425224550315, 49.85763949732627, 47.373598544828354, 46.748686528974964, 44.550739334475615, 44.2443355437248, 40.06053547705374, 43.93989293806015, 44.157255003529215, 46.16366109540386, 47.58617139631703, 47.08120938270323, 46.65940553911271, 43.870690561109974, 48.16047306983702, 47.416328845485566, 47.738073025980306, 49.91032085111065, 52.99715557406026, 52.19775692109139, 53.76269240533152, 51.87390642781412, 53.65579212865522, 55.71718985034574, 49.99960576334308, 52.513001734210604, 50.98202220855221, 56.86333779365786, 61.799609276556204, 60.205059897515085, 61.47653149020288, 59.05806079987557, 59.59599033478768, 57.740140499607215, 61.331443017528905, 60.08985596318399, 70.31777351133286, 46.718284237769346, 57.54200589272284, 63.322932335638235, 62.52393376442694, 67.28167856893232, 64.46387529373169, 61.74950099760487, 61.58919372866231, 51.782581883092085, 53.584326544115626, 49.759235074443204, 51.73944757830713, 51.49496624546667, 55.738857023177616, 55.804199787878225, 63.130422407580966, 63.178098817025464, 68.1491264220207, 69.03057713662425, 68.63965803577055, 1.7846291536285033, 0.5175894102261913, 2.945494810419698, 0.014774459526844084, 1.7960861517537026, 71.8026416532455, 67.60230879629812, 70.0051684533396, 71.65476829774919, 89.67774544992756, 41.82085598668745, 42.64773476508356, 55.43279447863179, 37.4509669119312, 64.7922404350773, 76.46017382221838, 32.90308852349558, 0.5890806740330112, 0.24735489800091714, 0.06957456544642487, 0.16005879598519496, 0.08065235770998463, 0.16297942958772182, 0.18054248554812324, 0.18115817509110899, 0.15119687473822027, 0.32625073867459453, 0.2814198862160406, 0.23699688364661511, 0.37804021289752376, 71.70837140852406, 77.48940375543411, 61.91810407946187, 79.34092721631451, 107.94813786783527, 77.66422379401423, 73.85741449171498, 51.025831161006806, 40.597456962831565, 81.79055721529069, 64.09708269180791, 71.2903408850393, 74.58442580315375, 9.57148144322057, 0.4271260096180824, 3.5376099280772673, 1.0343545098458569, 0.48378927392825005, 2.674793903866122, 42.623212106766246, 31.412362321730587, 76.62911815028038, 58.19145625637424, 67.09884120571998, 65.67915108896071, 70.03078937530518, 61.572660938386, 62.83134952668221, 52.3177618365134, 57.003574294428674, 51.980618430722146, 56.26108531028994, 61.264731345638154, 65.2797047553524, 61.98909505721062, 52.971236551961596, 49.710884017329064, 57.30735794190438, 63.07204577230639, 69.49545644944715, 59.400115013122566, 65.76984805445518, 61.092884463648645, 68.10722766384002, 60.630350728188795, 59.888253981067294, 57.76135659986927, 57.05787166472405, 51.420209792352495, 54.79648013268748, 56.71147931006647, 60.4088701740388, 55.666124513072354, 59.959335173330004, 56.51511761449999, 57.35292803856635, 51.250308405968454, 56.08110735493322, 51.56633377075196, 52.489345919701364, 49.19351554686024, 50.18755789726011, 50.878036252913944, 52.711983573052194, 52.01077753497709, 50.72154937251922, 46.23735066383116, 45.620840364886874, 47.672287033450225, 49.92397462168048, 50.09788074801045, 52.306763510550226, 50.97246339244228, 53.19169336749662, 51.939131521409564, 53.66121676660354, 50.06247743483513, 57.79150785938386, 59.95056867599488, 66.44545278241559, 55.364737433771936, 53.8778845725521, 65.42662497489684, 59.57343278392669, 57.944217497302645, 55.88065854964718, 54.889934524413086, 52.317267617871686, 52.18761367182578, 55.6087363150812, 54.22555169751568, 49.58624286036338, 50.192990379948775, 46.87609687928231, 47.563782507373446, 43.82065288482174, 46.340289346633426, 47.90320873260499, 50.327339403090946, 51.95315791714577, 52.998677453687115, 51.916166044050655, 47.919670920218195, 51.63135490109844, 51.88066074925085, 51.59544952454106, 55.349565705945416, 59.29896493111888, 58.084171587421054, 59.51486787488384, 56.62127656321372, 58.82207139845818, 58.38264042331327, 51.369842636969786, 54.27198471561555, 52.761115181830625, 56.73779056918237, 63.19356080024474, 62.92969119164252, 63.16940684472362, 62.61928658331595, 60.740612476102775, 59.133484055919034, 63.75017258428759, 63.212525460027884, 68.84690823093538, 53.071272680836344, 60.42719156511369, 67.13035352768438, 65.19868035470286, 66.66729419462143, 68.59983028904085, 63.91382563498713, 65.54695544704315, 54.08801770979359, 56.25704526901246, 54.04394595853744, 54.89179765024493, 55.05963586991834, 60.38580271505541, 57.210447942056966, 66.12782709060177, 64.66941925787157, 72.34821980999362, 70.14063927435106, 74.81721847288071, 2.53274453263129, 1.4088184098082206, 5.0636916391311155, 0.22032526291666493, 3.0902721901093764, 76.97796590866582, 75.75980324898997, 78.56736521567069, 78.99556252264208, 96.10621206222042, 47.251036244054, 50.21387307874618, 63.700213355402795, 55.216440462297015, 75.39720366078039, 85.86542913990637, 40.695959444968935, 0.8393116499627791, 0.32687326172186487, 0.17746834324732905, 0.3763374139464671, 0.22182610576912282], [0.08490413802886203, 0.126655554519065, 0.04285533386733263, 0.07016761709124812, 0.041028225659242565, 0.06575773154655773, 0.24618169563191555, 0.14271356946518346, 52.40634072211481, 65.3002344408343, 57.9402715929093, 38.11987223163728, 67.70116821412118, 55.92605998439174, 47.51552558714344, 32.6464694161569, 31.98601092061689, 64.64758734549245, 54.7871684258984, 56.68073185028569, 63.334875952812936, 17.793438088509347, 0.6163701354976624, 1.0952646285295486, 0.40648328020207347, 0.1748733582996553, 0.03407302830788878, 23.534317131965395, 33.33581224564583, 60.55738679824337, 63.41679073149159, 59.86023649092644, 64.11667493081862, 60.383108046747026, 61.436966542274725, 55.188007200917895, 47.27897136442123, 46.838355833484286, 50.8918273064398, 58.3163562897713, 55.85946206123599, 61.083109917179236, 55.065311539557676, 47.029794954484515, 51.76331520080567, 50.6198658481721, 61.68646850893575, 60.45249869746547, 55.57875371748402, 60.101760356656975, 58.69557888277116, 59.485426564370435, 57.706066869920306, 55.51802758247622, 53.15616453847578, 52.43293831425329, 52.44911024647375, 48.79370835519607, 55.3266159180672, 49.13595084221133, 51.050149856075166, 52.73451366732198, 53.47202124134187, 51.66314571134506, 48.159516011514974, 45.107284438225534, 44.32533248778313, 42.599473922483384, 40.26635792947585, 41.66392587846325, 41.619708999510735, 43.37741328823952, 44.07700330980363, 43.30925818412535, 45.394601975717855, 43.69425058364869, 38.29567678513066, 42.06407823870259, 44.01795594922958, 47.2034304372726, 46.673910464009936, 46.5255154332807, 48.7339981140629, 46.892037391662605, 47.20223411437004, 50.71670524535641, 59.86226435630553, 56.4721441268921, 42.039528123794064, 43.741538678446126, 54.40055216512373, 59.24284365869338, 55.50151832642094, 53.5834518555672, 48.26138780963037, 48.06437892298545, 46.17685594866353, 48.00941082739061, 47.40964904908211, 47.997420141773844, 45.38230534522764, 42.4923304588564, 43.74926574768559, 42.51437810159499, 43.709571361541755, 44.63700402167536, 45.69011726687032, 43.74770072198684, 42.98198346168765, 42.21133970445202, 44.14276576811268, 43.23439582701653, 43.00098734517252, 43.383018355215754, 47.16756036204677, 46.4691117502028, 51.15903092968849, 51.8069633360832, 47.57233327434909, 49.089325627973004, 50.61042078079716, 47.49548227556291, 51.771618858460464, 48.408621818788596, 56.474344576558764, 53.01558679149997, 56.894622618152255, 60.59465715962072, 60.03870825613699, 56.30260752093408, 61.46592147888676, 55.816963180418945, 66.99811473969491, 56.19712714226016, 44.08302414801813, 63.47379845957603, 51.99218550036031, 57.18704708160893, 54.32474451680338, 67.46686935424805, 61.86437937521166, 60.635069339506096, 57.649643574991536, 53.117301694808475, 50.331422590440326, 51.04147749562418, 50.32338173158708, 51.80145632836127, 50.67788947013117, 58.78746432642783, 60.30634334010463, 64.95690545728131, 60.85971524638515, 38.20997299686555, 0.2269613310214012, 0.5700049621443595, 0.9168055497350232, 0.05668696707054492, 5.417773310215243, 76.10638387741582, 55.3447372682633, 67.51997824638121, 56.314049074726725, 82.96612293489518, 33.80733605354063, 37.46967661765314, 44.495347622902166, 30.130963210136663, 51.71104961825956, 66.4351212593817, 14.84856374802128, 0.4994409405175717, 0.3612103950112097, 0.13275071858398377, 0.10616820305585863, 0.0671484186163833, 0.07964115995433062, 0.06426485600851237, 0.05090748868702401, 0.034593458647929856, 0.05519603356538762, 0.062068014615966435, 0.18743338513999216, 0.043550930211260434, 58.946339930257494, 72.33587218869117, 60.503771920357984, 49.63150308978174, 79.85353392939415, 62.75504765972015, 53.259056152835974, 36.894519867435584, 33.91527968068277, 71.59433241813414, 58.88243667541012, 64.00696231472877, 70.38579525486116, 21.403291456161007, 0.6043036991069394, 1.2331011290511777, 0.7819780587188659, 0.029356077486168475, 0.01978613394913414, 25.463052449687837, 41.632774414554724, 67.15955949598744, 62.80184545824605, 63.9938812102041, 66.49367440131404, 64.04267157277754, 62.52155288573235, 58.126886198597575, 49.5760250860645, 50.08190101192844, 51.737196137828214, 60.36559466392764, 60.10695357476512, 63.26644628278671, 56.66756053124705, 50.8776165593055, 51.850227079083844, 53.67077558271347, 61.564827965151885, 61.23856521421864, 58.60248534910141, 61.63675246700164, 60.22058071628694, 62.241209322406405, 59.32722953058059, 58.73162546465474, 56.80698902376237, 53.22423335044615, 53.30597554483722, 50.02438729809177, 59.250629563485425, 53.3149185488301, 55.82105813487884, 57.38343623376662, 56.21611141389417, 54.87035013014271, 51.60379632826775, 49.55608767847861, 48.95911078299246, 45.58934765477335, 44.78401053336359, 48.49935800798478, 44.61013578599499, 44.64244434910436, 48.46899886285105, 45.25791914232316, 48.005406087444676, 43.68742958191903, 42.02613715202578, 44.058878037237356, 46.35813220854729, 50.15864610671998, 48.46394292769894, 49.79508946018834, 50.429105297211684, 49.01395336274178, 50.237826993388516, 54.56939058919107, 60.10699672083701, 57.32679720847838, 43.63396767647036, 43.60389094198904, 56.1702000710272, 61.4853411336099, 57.3037846626774, 54.24362205689954, 51.17229638561126, 49.57717826289516, 49.10402667137885, 50.90913672601023, 49.393948662665586, 50.54143413420647, 46.36624759243381, 44.6138188915868, 45.019121323862386, 44.96370215569773, 45.39562571433283, 46.68187287545974, 47.69526035554948, 46.72433645494523, 47.40038048836493, 45.29937075030419, 47.12037032650363, 47.698496310941636, 47.44586037051293, 46.293295429598906, 49.58078292108352, 53.701730928113385, 54.212525506173414, 56.661414177187034, 53.80582278774631, 53.35834703137798, 53.408722031501036, 50.57780627281436, 54.27677000722578, 50.075962543487556, 57.98346473324684, 55.28701959117767, 57.83077078480875, 61.66854327724826, 62.53099010836694, 60.56917352061118, 63.306905531114154, 60.8293600236216, 69.1297346545804, 57.7180536331669, 47.181767186810895, 64.93165323811193, 55.980557395565896, 61.130319564573234, 55.2955585910428, 65.3869580453442, 65.0082649723176, 61.673010856874534, 61.0778578635185, 54.630681545503684, 53.39389154987951, 52.98930298897528, 53.33053350448609, 53.960521067342455, 55.11722018641811, 61.01040486366519, 63.33229895560973, 69.36055829448085, 66.58587363458449, 40.5920676262148, 0.33928952450233124, 1.41125934979608, 1.5793913795102028, 0.19816270698943447, 7.389199704893175, 84.90371104209655, 64.06391905200097, 79.53675546953755, 60.637783619665335, 93.22000657358478, 40.748087744559015, 45.254667497450306, 54.16052664479902, 29.806787160135087, 59.22295724191974, 77.49946855729627, 19.59103680426075, 0.7028838932033509, 0.3182431586807774, 0.18439564733735977, 0.23611070377932442, 0.01931824000372041, 0.14583948398790053, 0.25918994519499045, 0.17287658076853524, 0.1549969925995796, 0.23399938078176594, 0.17382531937572265, 0.31734159576796717, 0.26069071143865585, 69.64613822198683, 84.22683546620031, 73.43867009685886, 55.94550317333591, 79.18286354311051, 68.3523993338308, 59.7101430739126, 44.514320127425655, 44.43565307124969, 77.56995354929279, 67.17523328719601, 69.34094644361927, 75.41330891270792, 23.780926350624334, 0.8824661181819056, 2.6442634001854928, 0.7009796437717254, 0.3190476735753398, 0.13496733270585537, 28.241477089543498, 37.57780851856355, 63.18346854179137, 67.81397558027699, 65.82760103287237, 70.84753667154621, 66.48790067242038, 66.33726596832275, 59.443692545736994, 52.9632584510311, 52.39612294781593, 54.82832977848669, 62.46191716963246, 62.76771691537673, 65.98168742272162, 60.07103643109722, 49.3574353187315, 53.03582229921895, 56.13147451031593, 68.3191611689906, 64.18457900324177, 60.3089556386394, 64.71471478862148, 60.51424464871807, 64.77556643947479, 63.805113223291215, 60.8663244401255, 58.23362958046698, 57.25322923352642, 56.78909124866609, 52.88341076143327, 61.21930637667256, 56.181445506311235, 58.10729788195703, 59.75251251651395, 59.13867335165701, 58.01401215214884, 53.64276201494279, 52.91313840496925, 52.584082926473315, 48.6776650336481, 49.79992574261081, 51.67448528351323, 49.959903532458895, 49.95071734151533, 52.90793734212076, 50.74607595320671, 52.35328282079389, 47.17984522542646, 43.947153245249105, 45.38899690874162, 49.641387462615974, 52.0641335364311, 51.54571387075609, 52.79437688089187, 53.524533933208836, 50.359416546360144, 52.7901642553268, 56.14517142695766, 67.26893086587229, 60.64734243577527, 44.21128957502304, 44.46442365646363, 58.48374735924506, 65.46078097435736, 60.323990083509884, 59.40460612696987, 56.78447461897328, 53.611288916680124, 51.65324564903013, 52.82976058221633, 53.21002260331185, 52.98625922972157, 50.749617853472316, 48.31102148179085, 47.429096160396455, 48.17491915918166, 48.689404687573834, 49.52080203640846, 51.00747839097054, 51.248649243385564, 52.31968379789784, 49.928508881599676, 51.458503892344815, 50.19161362801829, 51.96183419996693, 51.33506690302203, 55.38873841685634, 57.06161752823861, 59.6518958768537, 61.70609212690785, 56.753848752667835, 57.19050268973074, 56.30734966647241, 52.53254690477925, 56.879148867822465, 52.66446798078476, 59.72251815180625, 59.51408340084938, 63.18102882754419, 65.01266194928077, 66.71128749847412, 61.917429431792236, 65.89448528905069, 62.32301427472023, 69.83079556495913, 59.275571915411184, 48.66197555295883, 64.12574345065703, 58.73200985693163, 63.10511527522918, 62.804026296061856, 68.61060896227437, 67.34130644029187, 66.14389311882758, 62.54157266309185, 58.61024379730225, 57.228667351507376, 54.856457094992365, 56.85701885531026, 56.46447589320522, 56.817571578487275, 64.18970946342715, 67.20720844884073, 74.70185372137254, 70.34952117550758, 48.07594207025344, 0.824337695394793, 2.045811938662683, 2.387230973089895, 0.4332013626492793, 8.832629476824115, 90.42312914325346, 67.76117263301727, 82.14120141921505, 69.72216160066667, 99.242076412324, 45.91829722927463, 55.515866356511275, 60.577488945376494, 45.04113366526943, 67.37708630100374, 89.3879685863372, 27.820987239960704, 0.9502069832336519, 0.483183512884763, 0.2447017056927566, 0.3203146604280318, 0.23509015209011494], [0.0670658573207836, 0.1024630188100761, 0.043034391597874706, 0.047003991090722626, 0.06273447663613385, 0.01333884906113869, 0.2821235226527337, 0.40948885763364457, 21.508359985966838, 77.32052218529486, 41.00512066195088, 36.845596144276286, 27.333460161762854, 39.59829591935681, 49.07072182624571, 28.92818408627664, 52.42297941638578, 70.39064330439415, 60.70343625160956, 56.027676828445934, 62.184021165294034, 30.378101948768865, 0.25110244690891237, 1.275214514424724, 0.6015913801327829, 0.4361504027920385, 0.36064149811863905, 7.909778635348044, 39.07886820454752, 49.49727566011491, 70.56844434430523, 58.270954855026744, 64.6820257556054, 63.006228400814926, 62.53857204991003, 53.18939485857564, 48.27825400137132, 47.17017266058153, 50.09744144255116, 57.119397963246996, 57.61130632892732, 59.33074397425498, 44.02514957612561, 50.135206022570216, 53.56680139418572, 50.34995971187469, 57.39365793043568, 51.71777256073491, 59.872635103041134, 59.27938838158885, 56.16747010138727, 56.89749771548856, 56.13251001604142, 58.6828782481532, 53.529456507775095, 50.809041761582904, 51.30628847306775, 50.04219093630391, 55.33317412099531, 51.211782886135964, 54.04731919688564, 51.234187464560236, 54.24684624518118, 52.39969622704291, 49.48175876371322, 44.18151878541516, 45.53207712788736, 41.25764285364459, 44.987546243975245, 42.98705116395028, 41.6614116391828, 42.96178717767039, 38.94196964079334, 40.78380092497795, 43.791509674441436, 41.55045563174833, 42.08597290900446, 42.10836964268839, 43.00801231015114, 45.54837065358316, 44.4837530966728, 45.03275940495153, 51.16281993927495, 50.481217907321074, 52.07720679621543, 54.77660940539453, 56.30066987006896, 53.52518504665744, 49.21769303660239, 47.07548664462182, 48.012838978921216, 60.00186543310843, 55.24697219171832, 53.097411355664654, 50.356808170195556, 51.962987376797585, 50.399189379907426, 50.06135563696585, 47.844149604920425, 45.98236914603941, 44.28392010350382, 42.13005250500095, 43.10656970547092, 44.302967133060584, 46.79591971059, 43.549652407246256, 41.409956332175966, 38.90349118940292, 40.33414040842364, 40.461142832233065, 40.25063706982521, 40.17430382390177, 46.12356270513227, 42.76688068143783, 46.33373114370531, 50.40782643902687, 48.39328535141484, 48.83004127010223, 48.95556103798651, 48.57937043712985, 51.559253892590924, 47.16900379427018, 50.44917214301325, 50.61805371315249, 55.257303714752204, 54.906514383131466, 57.3510649127345, 55.06815918030278, 59.22987238053353, 57.98231155641618, 59.010643266862445, 59.515911225349676, 59.93263167719687, 39.239724605314194, 43.882136037272794, 56.89762323133407, 57.07694615087202, 56.710439881970814, 53.18317005711218, 48.28645959977181, 57.57576965516614, 64.87374728725803, 57.51773034372638, 59.31351692445817, 51.74274236925187, 51.783903721840154, 48.73229188303794, 51.58003068739369, 58.37072426272977, 59.4409861103181, 59.37851844295379, 61.84953320410944, 54.57635279624693, 21.914419435685684, 0.8649025412817156, 2.7189894549308287, 0.3054559867708914, 0.17667329719951078, 17.07488929071734, 77.46580677647745, 48.44529990226992, 50.11929296678113, 60.82311168793709, 83.23589571060674, 25.610270769365375, 37.76155979402604, 40.2733358260124, 34.17590548915248, 58.45111716178156, 63.39825361005722, 6.297005924486346, 0.26606638104684893, 0.17559144315460037, 0.07785418326215399, 0.03823704942460022, 0.008563569262473574, 0.04623471624067715, 0.03648605971266666, 0.013839336217290932, 0.09994729331904843, 0.058585516808013764, 0.10196794981076833, 0.317896488573282, 0.4717353400924514, 26.965702656776678, 87.93895875253986, 44.60730383473058, 47.928849266421416, 42.90426561909337, 52.393216471518244, 57.542123563828014, 37.09994223810012, 57.48993250631518, 76.44402150184878, 64.41197449161162, 63.45227641444053, 69.5062743463824, 34.10017628823557, 0.29308532154367817, 1.8138030075257825, 1.0260298920254554, 0.13281825689538834, 0.5289527004764927, 8.715219209271094, 44.259911275679066, 56.74688654561197, 70.81401609605359, 59.84014611090384, 68.80063995238274, 64.10750835172593, 63.885945427802305, 55.94448335709111, 49.351641977986986, 50.137116216844134, 53.36013955454673, 58.846539143593084, 59.98569350088797, 60.57624555403187, 46.16552029886554, 52.62655042832898, 54.032029797953946, 52.37605217964419, 58.16399574279786, 55.11848318961359, 58.78065509180869, 58.28715816620858, 57.68377996260121, 57.33062936413673, 58.486873488272394, 60.150503650788345, 55.79116182942545, 52.10949182510377, 54.37332307138751, 52.280307123737956, 56.54329199944773, 55.30364651833811, 56.73194623762562, 52.22093812880978, 56.001773495827955, 56.68035530274915, 52.21241089605516, 47.43983168755808, 47.47867099700436, 44.253690396585775, 48.40224796725858, 46.25677424092447, 45.76591314808015, 47.181265123428844, 43.391573044561575, 43.023493905221265, 46.86757749126804, 43.75755371585969, 44.496257612782145, 42.59211163366995, 45.270784516488355, 47.20346573860415, 47.9522148255379, 46.46721724540957, 51.02229318311138, 50.09546849035448, 52.54401199279293, 56.903789197244954, 58.76407131072014, 53.79348693355438, 49.2612313455151, 45.66578288232127, 50.01456568318029, 59.678575838765795, 58.17374675504623, 55.457603469971694, 55.671968844629106, 53.85689596976004, 52.79127036371539, 52.57034678612986, 50.627549771339666, 46.97422281388314, 46.5904071254115, 44.589343301711544, 45.69842092452511, 44.889479144926995, 48.260101272213845, 46.62936410596294, 43.64479734051613, 42.19573259353638, 44.08720539462182, 43.50554535465856, 44.84167329726681, 42.40657960214923, 48.69673951979607, 45.559012043860655, 51.430604073309134, 52.868639115364324, 52.71791027438257, 51.93738606668288, 53.73598498682822, 53.250085692251886, 54.82430542668989, 50.853576352519376, 51.474244363846324, 51.05643741546139, 57.05290986645607, 56.92820595156763, 57.04641442145071, 55.75514662650324, 61.59304549617153, 60.875039946648386, 63.11523891264393, 60.57047182513822, 60.39747176631805, 42.033248409148186, 47.72228548603673, 56.368856353144494, 59.01750349229383, 58.25202549657514, 60.78695920205886, 50.416326215190274, 56.81279805398757, 68.70847209807366, 59.6709664406315, 62.799107643865774, 54.27400865862447, 53.75396513169812, 51.971773485983576, 54.156047298062234, 63.94612635335615, 63.50432626662716, 64.1316544625067, 64.52038880317443, 60.36726559362104, 27.36040488366158, 0.9728864952921868, 3.7141168309796244, 0.26767139653525046, 0.14957606251682007, 20.480149868995916, 85.7090913095782, 55.32632566267445, 57.552341338126894, 66.93174823637932, 93.63878234740227, 30.30248453540187, 46.899921355708955, 43.91020844059606, 28.228523462049424, 66.44852007589033, 74.92116128244709, 9.386002363697175, 0.44355265075160616, 0.2774572504624244, 0.10431662982990665, 0.10045989807094298, 0.05333481529246896, 0.1470100663362011, 0.3171625763418213, 0.12454328157248036, 0.21386775458531998, 0.22375249514176002, 0.1443608423634883, 0.3821104993262599, 0.5667506206420161, 30.100215750355876, 102.06809705303561, 54.063051823646795, 51.1889664588436, 41.35853798158708, 59.301083011011926, 64.45649339306739, 42.66532267293623, 66.71659838768744, 82.55505854083647, 71.05893673435335, 69.72624871038622, 73.35865374534362, 40.14215607796946, 0.38894388103677385, 4.066542526406627, 1.4885171719135777, 1.3116746612133519, 0.43244814500212675, 9.91031244877846, 41.74834705168202, 50.58394478213403, 76.83153598539292, 59.99202812871626, 71.90239537146785, 64.64143706906226, 66.64344618397375, 57.22905566615444, 53.8804498026448, 51.80144063888058, 55.75430331691619, 62.583334138316495, 63.05519919241629, 62.3686549740453, 51.294070289980986, 53.95697132233651, 55.64328847392913, 54.538046929144095, 57.92918697480233, 56.34239996633222, 58.43113268575361, 57.59249464158089, 59.115845157254135, 60.72762158609206, 63.545589600839925, 64.21351040563276, 58.51123140704248, 52.69521936293572, 56.3319193932318, 55.182158946990974, 59.871454469619266, 59.10551363422025, 61.95342110049341, 58.21002475676998, 61.977888845628314, 60.267100026530606, 55.8737277215527, 52.54890318839781, 52.83860944932508, 48.90748062441426, 54.53782335404427, 50.76594668049967, 51.00902772718861, 52.97319381467758, 49.006045864474395, 49.66865578005391, 52.33483199150332, 46.501887075362674, 46.60752827121366, 46.423780918121345, 47.57256861655943, 51.34687715961088, 49.51241993135022, 49.22090545777352, 56.378391635033395, 54.26025682880033, 55.14106819706579, 59.64147021693569, 59.77719599200834, 57.0056256940288, 51.077123995750185, 48.205278304315385, 52.321417485514, 63.612815103223255, 60.978515994164255, 59.11895559680078, 57.931308977065555, 56.444711069906916, 56.22507402973791, 52.983662620667495, 52.09103707344302, 50.24485980310748, 50.42856008775773, 47.1930165444651, 48.67633927252985, 48.91089308646418, 52.81751102016818, 49.74945268323345, 47.28370174284905, 48.579825432069846, 49.61064784757553, 48.434513384296054, 49.15675509360529, 47.09291765766759, 53.435358847341234, 50.22589122095416, 56.50031458946967, 55.47928633228425, 55.90124707068167, 57.51465912788146, 57.45914190046249, 56.74798088689005, 58.825574075022054, 53.79996276670887, 54.40753006166028, 53.18963020078598, 58.29081381520918, 59.407893073174264, 59.53190665091238, 57.900275184262185, 63.47160977701988, 62.60728413058866, 66.43566254646548, 66.08486144773423, 59.88535142713978, 46.08167571406211, 48.88896311483076, 59.23794854071833, 60.58809111195227, 57.15206738441222, 60.14806001417099, 56.8016428332175, 62.36184573942616, 70.63078649582403, 62.14724110018823, 65.17559328386861, 57.00235051493491, 55.95307727013865, 56.12093117929275, 57.19615482514905, 65.08683789160945, 65.95061440621653, 66.053466796875, 70.16947653985792, 65.07689468322262, 33.766986631578014, 1.1713825118157173, 4.341641635664048, 1.0153080931594296, 0.5630914782804828, 22.99416753553575, 91.69283174699353, 59.64528276074318, 64.40099185512912, 73.8665065457744, 98.29749122742685, 35.951927246585974, 54.89042874305479, 57.62305774996358, 51.22080825990247, 69.70052580679618, 90.05517944212883, 14.351502368527076, 0.7906825948626764, 0.6295290132684093, 0.16481275459931743, 0.3606019986252631, 0.16842277540314585], [0.01099200573779883, 0.06104128825808726, 0.01743349134020748, 0.09189256827437109, 0.11648402894817053, 0.017749209580342137, 0.06326125018418798, 0.15699639015140074, 7.299927050067533, 72.77825278620567, 51.03338172358852, 55.13879322236585, 21.686370872682144, 31.1353547342362, 37.67272203199325, 25.69448797933517, 67.74392989373976, 62.91407623598653, 66.9195104414417, 58.69433156905636, 60.44309285379226, 43.0845965877656, 0.11120435781776906, 0.5548299861050422, 0.9484883109408041, 0.08576328265330485, 0.10148213515358587, 1.505121055149263, 31.988272167021233, 48.589007700643236, 61.93406028132286, 62.58354202393563, 66.1583274410617, 63.83290321596208, 59.762471414381466, 56.653494911809126, 49.99020384204004, 51.44755263482371, 55.51164980857603, 61.510330553977724, 59.66315307924825, 57.53113308260518, 49.91030516162996, 49.296771941646455, 56.05363899661649, 53.614418968077636, 48.83010795039516, 58.33252037725141, 63.97132758171328, 54.48303568747736, 63.3084156436305, 54.52475793900029, 57.032984225980705, 57.63340888484832, 50.94448904837332, 50.19384937901651, 55.99933770395095, 46.90480862894366, 56.50890458014704, 50.56192067361648, 51.12367076258506, 49.4199735887589, 51.241961602241766, 50.675418376922615, 49.637535695106756, 44.96751469950522, 45.021121732650265, 46.59822440916493, 41.8162864254367, 42.49042810932283, 40.382593447162265, 40.10261074189217, 38.76463144056259, 37.782540552077755, 44.011829207020426, 43.516531913511216, 41.37570227346113, 44.82933744307488, 44.17774938767956, 47.50039308301864, 44.84074369553597, 47.68532891427317, 45.44956222657235, 50.032628197823804, 48.185270294066406, 49.60374055370208, 54.469460364310976, 48.28036423652403, 46.96321272080945, 45.056991807876095, 45.45129199181834, 50.056766463864236, 54.677569558543546, 57.76809915419548, 50.74593867025068, 49.710185835438395, 47.80354522889661, 44.73565163150911, 47.77211527670584, 44.93807338899182, 42.6496135803961, 43.87055720052412, 40.517393542874245, 42.44346557124969, 40.85383092203448, 40.51565593288791, 43.31108993099582, 43.868192011310214, 36.73908810461722, 34.36528536581224, 42.48657634181362, 40.7121588337806, 46.65022327053932, 46.69629150821317, 45.154811797603486, 50.6123701987728, 52.65123390382337, 53.427247385824884, 51.00544660322128, 52.14885673215313, 53.853518809041674, 47.907919499181936, 52.34521450534944, 44.875142881947184, 55.32112459982596, 58.82533481044155, 60.23219877673734, 61.503925323486335, 59.341161789432654, 59.46562251737041, 61.1726733176939, 57.77113899107903, 43.455629271845666, 36.395916015871116, 52.138195730024776, 60.89385947873516, 62.27827179816462, 61.652434102950565, 65.01391710773592, 63.16970494485671, 42.35377273251934, 57.755743688152684, 61.01726116672639, 56.69387963510329, 57.68530968696841, 50.8142702810226, 52.30277053771481, 56.807891168902, 57.04282153037287, 62.05552039607879, 61.987463351218935, 60.05113432484289, 73.7613478014546, 11.64957179177192, 0.47412862941142053, 4.208631121343182, 0.2336066228247458, 0.12287035238959136, 31.653809701242757, 72.9662206096034, 45.840124391740375, 66.50941879518571, 64.48100428427419, 65.42073749726819, 23.152441055543964, 56.186776007375414, 33.56720462922127, 45.311059413417695, 54.08072210127308, 57.909010302635934, 1.9358121315317771, 0.20681554752011455, 0.08739536402807122, 0.10050742616576534, 0.02162579259264373, 0.010202979225845588, 0.07923179321111211, 0.026589360523728595, 0.032525120843802734, 0.07222498451629955, 0.0062162595831098105, 0.13338925286887154, 0.1863566332406575, 0.2111381067023162, 9.321102826826035, 82.38566706257483, 56.450700529160045, 54.58710009051908, 32.05719997805934, 42.52979301637219, 47.65563264969857, 33.89444012795725, 73.68268074527865, 71.02684390160346, 73.49719185982981, 65.26133629583543, 66.87618394051829, 50.23312014918174, 0.043835122018091144, 1.009450646177415, 2.075515312533225, 0.0380631015005131, 0.08170257232362226, 1.5146046107815159, 37.768510233971384, 52.926117527869444, 62.53321016988447, 65.5606484413147, 67.15278164032968, 66.34819369162282, 63.343112930174804, 59.479523397261104, 51.45182409594136, 52.97928525555519, 56.535996390927224, 64.30476827006187, 63.416669138016246, 59.7927011212995, 51.15746590398973, 52.726029580639256, 59.3627622819716, 56.98371925661641, 50.93263172334241, 54.952535552363244, 64.52240097907283, 58.103599086884536, 62.808960637738636, 57.15602113354591, 58.92322932520221, 57.26970711062032, 53.27028197626914, 53.46617298741495, 56.08800288169615, 49.824287583751065, 60.231339777669604, 55.89403383193478, 54.84416438687233, 52.96274069816836, 54.551520270686, 54.063318544818515, 55.72958061772009, 47.62388890789401, 48.49372156204716, 51.157242328889915, 46.40032514449089, 46.23289485131541, 44.06715816067111, 44.12524454055294, 41.82094620120141, 42.1076596936872, 46.62833252260762, 46.596035726608775, 44.36527006087765, 45.87412741876418, 46.184010351857836, 47.948661158161784, 47.03907528231221, 50.738799956537065, 47.00124009963005, 52.56979373193557, 50.14321158009191, 53.99290807785527, 53.80200632156865, 49.610667459426395, 48.58235536083099, 45.22890929252871, 45.642558528530984, 51.771371749139604, 56.302336877392186, 58.988964326920055, 52.77526317104217, 51.91637785203996, 50.32235407060193, 47.355284998493815, 50.23925865850141, 48.61724484351374, 45.15700048015964, 44.90168163853307, 43.760758292290475, 46.394790680177756, 42.85818169193883, 44.634960466815585, 48.366636768464126, 47.217225413168634, 41.75693704235939, 40.20847551284298, 47.18193584872831, 45.971590472805886, 48.43984388536023, 48.73069940074798, 50.29706655010101, 51.88838389612014, 55.95335575842089, 56.054203817921305, 52.69829057878064, 54.84088528540827, 56.38581275939942, 49.30322816295009, 53.866760730743415, 46.242936118956536, 57.084571238487, 58.85147740764003, 63.939015096233746, 62.503070677480395, 62.127821445465095, 58.85875732667985, 58.505504746590894, 56.09876194307881, 44.813687186087336, 39.555102779019265, 54.695200612468106, 62.915594193243216, 62.86798054172147, 60.862186339593705, 61.96927924310008, 69.65952919375512, 48.17417390884892, 60.05468014747866, 64.20749348978843, 57.85447759013022, 61.22410735776348, 53.479787534283055, 55.6091324744686, 58.004712212470274, 59.242392586123565, 63.98596978956654, 67.394164300734, 64.68721897371354, 80.38828634446668, 16.09530479677262, 0.502428223769511, 5.554764049668466, 0.29269311516996355, 0.13218136203865852, 35.64201685690111, 81.8700558139432, 48.84257324280278, 67.66997752651092, 72.44813042302286, 73.6291717713879, 25.947873092466786, 61.05378235540083, 46.75131059462025, 48.49159955978394, 59.84968531516291, 69.44786240977626, 2.7975783088514885, 0.15161713525172205, 0.17111330683673584, 0.06928369718333406, 0.10041747212169633, 0.019730916246771812, 0.16516412848666792, 0.12424990054099791, 0.12110196099045778, 0.23235580042725612, 0.1816538033346015, 0.1315274447082512, 0.2758717548943335, 0.2951332584263817, 11.870627749350763, 99.09304203525667, 64.09024600059756, 77.13638259518531, 30.733690300295432, 47.70854542332311, 52.39790762624433, 36.78000234788464, 79.2376119859757, 77.59956744409378, 77.60208560574439, 70.86670137220814, 71.90702376827117, 56.1571385783534, 0.16683401630049752, 1.8280502817323132, 3.396558309755018, 0.4689337871968747, 0.2715095583229296, 2.092662444037776, 39.93962057175175, 50.74549544242121, 64.95939223997055, 66.65278926972421, 71.3238771500126, 71.54828379231115, 65.92315781501033, 58.970411516005, 55.26838048811882, 55.310875446565696, 59.484355757313395, 66.05977396811208, 67.65133842345207, 61.18931985670521, 53.96947191607568, 58.9692073483621, 60.72333443549372, 57.71499810680267, 54.320080818668494, 53.500356443466686, 62.74322563602079, 61.227751239653564, 66.59393802765878, 58.86834752175116, 61.69084979641823, 59.649711116667724, 54.84265035198581, 55.24598767680507, 60.997735608008604, 51.109946389352125, 63.6023659090842, 57.99002293617495, 59.73360276991322, 57.20302681769095, 57.72765167297856, 59.42674790659259, 60.833270626683394, 51.134316075232725, 54.74366541831724, 55.42169024867397, 51.197838860173384, 50.19022118660712, 50.29479549777124, 49.28167473885321, 48.06571252884404, 49.74944876086328, 52.8711219756834, 50.72520894388999, 49.98708555775304, 49.34934346906601, 49.69445713104741, 51.107879300271314, 51.98964380448865, 55.166700886141875, 51.427995697144546, 55.2365190752091, 51.960202493975245, 57.86086320877076, 57.23848504404868, 49.987626844836825, 48.39993769122709, 46.409256381373254, 47.331358540442686, 53.74105268909086, 60.018915976247484, 62.03088398902648, 55.9740541058202, 53.92895383219565, 53.533465170091205, 48.71450785667666, 52.155493382484686, 52.29673793238979, 47.90944137880879, 46.93057467860561, 46.040243717931936, 47.62392813159574, 48.58290841502529, 48.283439374739125, 52.496818034879624, 52.41299306192706, 48.80711109407487, 44.62838657440678, 50.746570171848425, 50.08663531272642, 52.23943210417225, 52.68760604243125, 54.321861574726725, 56.97543128844231, 61.08522799707229, 61.64835876034152, 57.5416293451863, 58.84959466995732, 61.77885209360431, 52.290128738649436, 58.40269157963415, 49.3848644533465, 59.93084699876847, 63.761308193206794, 64.77819050512007, 65.0902150523278, 66.3407176540744, 58.70230574761668, 60.81077583374516, 58.194582385401574, 47.093302049944484, 44.37677045022288, 55.7244776141259, 66.74097984067856, 65.26148142353182, 61.056300517051454, 61.875503217020345, 64.24386170602614, 50.88836777594782, 65.12877587349185, 68.2540576688705, 62.05498695373536, 66.1075484368109, 56.838391519361934, 57.96546105415591, 61.86049622874107, 64.85187222880703, 67.70813434354721, 70.96500381346672, 67.8570745837304, 78.8305954779348, 20.64524046836361, 0.6829898155504658, 6.443871721144646, 0.5716571992924137, 0.18816070901530405, 38.94777474864837, 86.69165288248371, 58.25501826501662, 80.85708802746188, 75.9216167080787, 83.38722859659504, 32.64836588213521, 75.36454600672569, 48.14287339487384, 61.61882723531416, 65.94531136174356, 88.21710971093948, 4.963695714550634, 0.44074616424979707, 0.2651122645024331, 0.24370441243292826, 0.26784155998499165, 0.10225142532538983], [0.014805589509647221, 0.08453936526371587, 0.025859200207877065, 0.05475907616557614, 0.04564714978539175, 0.05888212306965744, 0.11522857171873893, 0.07888365987568133, 0.19085209846736925, 48.046622353215376, 55.13914231331118, 50.327237421466464, 32.031935991779456, 31.25004287688963, 41.75754108736592, 20.49572756213527, 56.55236836402648, 64.54016147121307, 64.3079924583435, 59.858675387597856, 62.33356937285393, 50.867022237470074, 1.747275074162791, 0.17224324055977408, 1.7760395306733348, 0.017511599749747305, 0.08734988138800667, 0.12016548745093808, 19.4207255301937, 51.88454781809161, 64.16477495624174, 65.2008572701485, 64.55738459863971, 59.70762883463214, 59.978707759611076, 53.200883480810354, 50.703784958008804, 52.654112923529844, 57.10726214993385, 58.772194539347005, 60.16158042415496, 59.94233169863301, 60.52631770410846, 50.65057408425116, 56.76052462670111, 56.52036574579055, 58.50720705524568, 61.394016588887865, 49.73850927045269, 57.6401710510254, 58.264698674601895, 59.185541752846014, 57.64270490215671, 55.39393163496449, 50.33579995555263, 51.44903136837868, 52.862308409906205, 45.46051740646363, 54.41345676299065, 52.91048296036259, 49.708597275518606, 49.74137260067848, 52.48632177229851, 50.67672844856016, 48.002287803157685, 48.185701754785356, 43.165479783088934, 42.99770824370846, 43.455774399542044, 42.50310128734958, 37.91773288480697, 32.32811024112086, 35.671242437055035, 35.365132824067146, 38.908029371692294, 44.075422594624186, 43.92168529572026, 40.829402400601296, 42.517923924230764, 46.83530030712005, 43.1414552657835, 44.83393053854666, 42.524701779888524, 48.04766570368121, 47.780415011990456, 51.1836398801496, 43.173324523433564, 36.81766494627922, 38.021667849633005, 43.42732937105241, 43.11692084035566, 41.60616113293556, 55.032367552480395, 50.88296667222054, 51.62131755582748, 48.90001243160617, 46.18856814599807, 41.90577922328826, 45.25604817175096, 42.855996931752856, 43.464689946943714, 44.669598917807306, 42.99624912200436, 38.86802904067501, 46.04963387212446, 43.341884459218676, 38.87279864280455, 37.66924288965041, 32.131805419921875, 39.145018977503625, 41.765864356871575, 42.66282020076629, 45.70211187485726, 48.305083013349964, 51.02867095701156, 52.82696785465364, 51.543258467028224, 45.16592387230166, 51.61837577819825, 50.65370805801884, 53.36669383510467, 50.99499740908223, 53.29627552340108, 46.70900783231182, 48.93785938139885, 57.562233555701475, 55.0878220219766, 58.24651848885321, 56.05924406359273, 62.354848231038744, 47.6704199852482, 47.67584462319651, 52.45351899054743, 51.20418525511219, 60.1366380722292, 61.171649579078924, 62.29053704969345, 60.347755724383944, 53.04877004315777, 58.14343467835457, 66.40431496404833, 46.17763650032782, 60.72247151405581, 57.2977638244629, 56.838411131212794, 52.376114937566946, 54.38086971159905, 55.92192972860029, 60.00093975374776, 59.3773417319021, 65.92754302486297, 64.68684634854718, 67.9010521981024, 12.125850492908109, 0.15582729401367326, 2.7104977686559004, 0.1979138356663527, 0.3084804406089168, 53.13101037856072, 54.06762138489754, 59.24231021634994, 64.99479947551605, 72.17324287660661, 49.074255881770966, 35.36574471381403, 63.321265328315, 23.98854132621519, 36.04155340502339, 61.663314757808564, 45.21909552235758, 0.300063677732983, 0.01661730509611868, 0.039029218812262824, 0.05883482480121236, 0.07440078147356549, 0.04750526540221707, 0.04714712312805557, 0.03213779445016577, 0.021469177407843452, 0.02010114930359827, 0.04167301505203209, 0.055802139348440596, 0.1299484455657582, 0.04220639993887275, 0.3469826407249897, 58.20807141642417, 64.77555859473445, 50.294273822538315, 38.80767945320376, 40.21482190778179, 46.32281126514558, 24.794027497691495, 65.74547052383423, 71.51819921308949, 70.05645736571282, 67.01414938895934, 67.78004707828646, 56.967072717605106, 2.02476364229956, 0.2028260067585976, 2.935026739874194, 0.3404184623110679, 0.16819707057889433, 0.14464901399708566, 23.503530448482884, 58.25119787646879, 60.91676612054149, 66.23787310815626, 64.86754994238576, 62.79127074826149, 62.353149844754135, 57.00544918737104, 52.472067879092315, 55.08662962144422, 58.63234243085308, 62.43723369413807, 62.24961496168568, 60.97147533970495, 60.53475472234911, 54.30912956114739, 58.022017709670536, 56.923859965416696, 53.511539120827955, 60.6752500995513, 52.98870678870909, 60.55014610290528, 60.92969817499961, 61.28514728238506, 60.69310472857568, 57.17224013420844, 53.281766676133685, 53.49400612615771, 55.472524166107185, 49.138029698402654, 58.0132237557442, 56.289389133453376, 53.79388701531195, 54.77043167237313, 56.37342983676542, 55.04651554169194, 52.31116440988357, 51.69909031160417, 48.73581809382285, 46.7989517027332, 47.726094107474054, 45.90443949545584, 41.924143760435044, 39.32307889384609, 40.16348984933669, 41.158634385754986, 45.36268172725555, 48.029618878518384, 44.59156336322908, 42.960277065154045, 44.42845159961332, 47.718084627582186, 47.136463811320645, 46.268870830535896, 44.84308142815867, 49.818760964178274, 50.237776002576275, 51.8574873862728, 45.696000822128795, 38.53286250945061, 37.9334419773471, 45.38671016693116, 43.55422981323735, 42.58295289931759, 55.47921965199133, 53.05532432371571, 54.079953316719305, 49.971066597969305, 52.093198299407966, 45.22555958840155, 46.79069903589065, 45.61603546142579, 46.614223757097804, 45.55063778354276, 43.3817788862413, 43.982595782126154, 49.0764759432885, 46.423106270451704, 44.42324269202448, 41.24238091130411, 36.16859897490471, 44.51479081184634, 45.247803349648755, 46.40772273463588, 51.02483487898304, 50.444990896409564, 56.68099072671706, 56.03040679808586, 55.33379777785271, 48.787954238153276, 56.22114773719542, 55.031775274584376, 54.62163655988632, 52.50051682995212, 55.881576384267504, 48.97339213278986, 52.540846640063876, 57.2979050297891, 56.34730685141779, 60.497672634740034, 59.22576173659294, 65.08315478601764, 49.69741067578716, 45.54121232801869, 52.93102049058484, 54.01963510820943, 64.13125438074913, 63.92467491088375, 65.1304115018537, 64.04486025533369, 56.069712869582645, 54.39597868150281, 69.26805311633696, 50.86682611896146, 62.89028706089143, 59.75920408002792, 58.09127892217329, 55.474877588210575, 57.56696785649946, 60.37976618736022, 63.08830791904081, 63.13629027335875, 71.34963927730438, 66.99316470853745, 70.77899717515515, 15.149377180683999, 0.2607117328912981, 3.1896478899063605, 0.17485903245547127, 0.8268733851371274, 58.89784766781715, 60.78303290951637, 62.36208892637684, 72.28240243850216, 79.60468307618173, 54.33056531413909, 35.27926037388463, 72.2686662981587, 29.510969846479355, 38.58740306669666, 73.1737453706803, 52.38573258922946, 0.14045390120196727, 0.04732757896905945, 0.07788435180461215, 0.04042650955999571, 0.015651228961594883, 0.06692508866469707, 0.17509572298055695, 0.11979902929235851, 0.0754994051831384, 0.1420611843106247, 0.17812609101735777, 0.2133984950881812, 0.22759316969783078, 0.1867498202069152, 0.47187709700196023, 70.68471124095302, 73.211957100899, 70.07950521284535, 46.35707709097093, 47.59543603466403, 59.28186731953775, 32.57578438328159, 68.57488401474492, 78.08124234599453, 76.38752368188675, 73.00792324927546, 74.18187295236896, 62.34496778057468, 2.6897185223717845, 0.3677457072321446, 4.270970821380615, 0.8450186985634989, 0.35586322387379987, 0.31843210660642196, 24.41682884770055, 60.510239908772135, 64.09949494946387, 70.5760851214009, 68.34700999721404, 64.67605983057331, 66.11158847808838, 59.11102456431235, 54.34547032079389, 58.90409600350165, 61.388937119514715, 65.06281729667418, 65.523825230137, 63.61214830029396, 64.69842518529585, 58.689848299949404, 60.33467854222944, 60.84852472428353, 53.685986534241714, 61.12281999280376, 58.82098097955027, 63.68244501852221, 63.017426767656886, 64.72721538236065, 65.5292812470467, 57.383828470783854, 55.74166151785082, 57.07717364834201, 57.063488498810806, 50.92484581855036, 61.04585524528258, 59.56951041375438, 58.70741267358103, 58.24467105250205, 62.0624198452119, 56.439380568842736, 54.499144861775065, 55.58708483173002, 52.8826694334707, 50.627106543510195, 53.19557259159704, 54.856472784473056, 50.72561687038791, 45.27733095230595, 47.85356721570415, 46.23900198167371, 49.62169324198077, 52.49093840199133, 48.84316159832863, 46.21016079379667, 46.43683456605481, 50.13641019021311, 49.63520972959457, 48.865809363703576, 48.2506444377284, 51.248276618219194, 52.68327182339084, 54.97691308298419, 45.89783030171549, 39.795034162459835, 38.49040677470546, 45.63503542254048, 45.371797315536014, 42.386034227186634, 58.747679725770034, 53.084749944748424, 58.122752020435954, 53.91453127707205, 50.828351589941214, 48.10067261418989, 49.840581109446866, 45.550900582344305, 47.114675045013435, 49.296481686253706, 45.89084063806842, 45.18165257669265, 53.4203165577304, 52.91257358366444, 48.761462550009455, 49.769178282830026, 41.71425773251442, 50.66266282912224, 49.37823564775529, 51.71914539029522, 51.70475029176282, 53.37446405041603, 60.08324284707347, 60.15686573520784, 58.40917917989916, 52.63318707866054, 61.38470095972861, 58.599331763482866, 61.013079920122706, 57.079040696544034, 58.51411434911913, 50.64453755655597, 53.61718423904912, 60.167154112169825, 59.57172263053156, 62.408655305062574, 60.64846423364455, 68.36794760919386, 51.98103420196041, 48.127207448405606, 56.32468262026387, 53.756746092150294, 64.84610634465372, 65.48690788207516, 68.11260915571644, 66.81308869392642, 58.569843384527395, 55.069343736094815, 64.90831905795683, 51.03504480854158, 67.31476768370598, 62.76646567929176, 60.419138939149924, 58.69070729901714, 61.42955326264905, 61.49796332082441, 65.64199839868854, 66.25597876887169, 72.84262672547372, 70.74041674214025, 63.174301962698664, 18.475573562806655, 0.4018621459122627, 4.6509509221200025, 0.5248972761534876, 1.0494365134546835, 63.51345754438832, 67.75997238774454, 68.31629783876481, 76.9506662122665, 85.29221396292411, 61.381696424176624, 46.593399893852975, 81.66729281025549, 33.64464790590348, 50.48013533315351, 76.78474995397752, 68.84287603439824, 1.2374062980374982, 0.16978728524859876, 0.2271798346191645, 0.10454649451158701, 0.19382635822459576, 0.1337334102079753], [0.04187541165118737, 0.06678792062185465, 0.02522022733765264, 0.061721945887491594, 0.044305745151735125, 0.09880067420101936, 0.03571328767124684, 0.0800507182195302, 0.17378274020889115, 24.16832708543347, 65.5527997785999, 43.413608920189645, 33.742040357282086, 31.389983238712436, 42.15170791072231, 28.275113374956195, 49.645486339446045, 65.18541097640991, 60.931431862615774, 54.81033002176593, 55.98726857093073, 57.81883501237439, 4.30865450251487, 0.1868039979449203, 2.065413248154425, 0.36537776010171064, 0.06325454308441089, 0.07349354951011558, 11.20016917105644, 52.99280174316899, 63.27689155455559, 66.4223264878796, 59.6609212506202, 57.191750003445534, 54.98623263451361, 54.05772916732296, 54.91401395490093, 57.48877148474417, 60.90454009271438, 56.89534433426396, 62.21316045330417, 61.08310599480907, 57.768911084821156, 56.14417122256372, 54.949217227197465, 58.0611982653218, 55.25086318292926, 42.16822108914776, 57.34419684256277, 62.10060804120956, 57.72070123303322, 55.59992274930401, 54.244433987525206, 49.64136392839494, 47.38583241739581, 51.6910102290492, 54.55691745204311, 48.13213786771221, 53.35438151513377, 52.874377542926425, 51.65918411747102, 51.79430192516696, 49.967571766145774, 51.2793182557629, 48.41247358629781, 48.71542569129698, 47.24818468093873, 43.92683929012668, 43.13280643955354, 40.03568333964194, 31.733653468470422, 21.048114953502534, 19.744836861087432, 27.57054586564341, 40.22535739406463, 44.29598923652403, 46.88449859619141, 43.77245087777415, 44.60025533553093, 45.186241749794256, 45.61288187580724, 44.181644301260675, 45.610532376074026, 52.745425701141365, 57.14780376803491, 53.38933767810945, 41.754360045156176, 47.411531786764826, 41.97391079318139, 39.086822771256976, 44.549084094262895, 41.0672039370383, 49.02932120907692, 51.58851085170623, 47.65899804330642, 49.40571185081236, 43.889317897058305, 43.68904167605985, 45.652270317077644, 44.65021064204555, 42.082297648153, 42.1537632326926, 39.940722757770175, 39.67038908312398, 33.9038420492603, 31.85833973269309, 33.5149900374874, 31.0840364040867, 38.321772313887074, 40.64476074710969, 38.658127323273696, 42.7978007255062, 45.57004567115538, 48.07281986359627, 52.70607648357269, 49.955788966148134, 54.00436924349878, 52.193018697923236, 51.23122607508014, 50.163003859981416, 54.817825671165224, 47.55625547901277, 54.44243131145355, 47.15565596857379, 50.19413963440926, 47.16159443701468, 53.36424627611714, 53.52629507741621, 59.551302771414484, 59.47936650245421, 55.06678635074247, 44.26202151083177, 51.93076118346184, 52.07908953389814, 59.05477777604134, 57.16847465884302, 62.0072477863681, 58.178732087535245, 64.51059072248398, 52.97515499976374, 62.88727860296927, 59.447097163046564, 56.27660220669162, 59.37898128263412, 58.57877462140976, 57.57297692760345, 55.545386114428126, 56.86161587315222, 63.663927508938706, 58.69481402058756, 67.33187706239762, 50.13980304041217, 25.159845390627464, 10.118036270141602, 0.27130026310201616, 1.3152206064231935, 0.10715857088085144, 1.6362324068623206, 60.66882917957922, 54.18926192868141, 64.54036151209186, 66.13112188154652, 63.43936004946309, 23.50198111226482, 48.97961301188315, 52.9236582017714, 38.62308094578405, 47.67434627779069, 60.77416050818659, 26.728650293042584, 0.13793042290114588, 0.03363161227635799, 0.03102909668438858, 0.048017743749604117, 0.0364736644100518, 0.14157701674247944, 0.022679230521222758, 0.035248697480006565, 0.05344585207621417, 0.09315718791537708, 0.030949111359434265, 0.02899543968059363, 0.061695573310698235, 0.11097062439207109, 0.12047230566461241, 28.379870076333326, 78.35666333475422, 47.492363991275916, 39.12662698376564, 40.64195233006632, 49.57543280816848, 32.19692460952267, 53.57472850430397, 72.82848265863234, 68.1413209053778, 58.77654837023828, 63.447373451725134, 62.94351754649993, 4.436980235961176, 0.12211923382335133, 2.499208022509852, 0.570697566914943, 0.07203890175949182, 0.033055950827415914, 13.419770790684609, 57.585501055563654, 61.649119700154955, 68.11548817542293, 63.36956147224673, 60.22004727394351, 57.470183372497566, 56.505056735008, 56.19728011469687, 59.604835279526256, 61.22233836881576, 62.83109065025084, 63.85430366762223, 61.2926507765247, 61.44206954586891, 57.646474299892304, 57.42578998688729, 57.974721770132746, 56.96352297259916, 48.31562242200298, 58.08618768568962, 65.5658495041632, 61.04645144554877, 57.21513125204272, 57.969626611278905, 50.949917608691806, 49.796830992544855, 54.00378088797293, 56.96784934689922, 49.92074258865849, 55.39302164508451, 56.42223588881954, 53.94547877773162, 53.63247756035098, 55.472810499129764, 54.453131537283625, 52.56227062594507, 51.474722893007346, 50.89021128992881, 48.17458575771701, 45.29917463179558, 45.177432106387236, 37.24153195658038, 26.606686153719505, 26.5609513175103, 35.50061541218912, 45.38526281233757, 46.82321940698932, 47.13906042037472, 46.93907837713919, 43.03553558165028, 45.33975547359836, 47.07187806406329, 45.19962879919237, 49.45675365386471, 54.640342343238096, 57.87736069771552, 53.22382542394823, 45.1806955183706, 46.769612373844275, 42.04374074935913, 38.41273207818308, 47.59981339977634, 42.205095291137695, 51.321848515541326, 53.180718575754476, 50.49520115698538, 49.493694536147586, 47.24990660144437, 47.492666013779186, 48.11339286065871, 45.639914851034845, 44.789603833229314, 44.14036135519705, 42.724424946692686, 43.65128101841096, 37.85733230652348, 35.22917170678416, 37.847165523036836, 36.76182216213596, 43.734607850351644, 45.128924154466205, 44.84241854759955, 45.95409670183736, 48.49446289000973, 52.552970686266505, 56.30809099443498, 53.81018054100775, 57.66052815221972, 54.046146408204116, 54.46323164047734, 51.64930366700696, 56.929280680994836, 50.11682579594274, 56.88645232108332, 49.22673017747941, 51.824547321565696, 50.5436973417959, 55.41826209714336, 55.5276216999177, 61.490738314967004, 62.22819882054483, 58.732880623109885, 47.222018549519206, 54.63766336441041, 55.201162830475845, 61.50786338313934, 59.50174754665744, 63.16546486270044, 60.106596639079434, 68.15215449179372, 57.72984820027506, 59.63725759137062, 63.78417953368157, 58.88951263120098, 64.30083805514921, 61.49055396356891, 59.70208652557866, 60.14125470192202, 59.86541794192407, 68.9968212189213, 62.34626216273155, 70.1327709997854, 57.55986836648757, 34.84681514001662, 11.071100638758752, 0.18374615799515479, 2.2188066042238668, 0.08458190612615117, 2.677590063502712, 66.63524843031361, 61.71939288416217, 66.71605710060366, 74.0067312794347, 70.19090052573912, 28.73747060375829, 51.57484139165571, 63.491386367428696, 35.034653525198664, 45.483635856259255, 70.311631079643, 35.418688866399954, 0.20517034305920526, 0.03385020397423256, 0.04150425737363197, 0.02782696790452446, 0.04021155294932185, 0.07715552639696868, 0.14139761427237144, 0.2250228374595604, 0.22740092759411182, 0.2473496119942396, 0.16334502206694695, 0.1465038967228705, 0.2076935608901324, 0.30715011360664524, 0.31450385287884747, 38.012183558556345, 89.81544417719688, 59.817670929816465, 47.60596367620653, 45.175600359516764, 62.75534575985324, 37.72523472386022, 64.37175843023485, 77.09737070145147, 74.26052431906425, 64.48767623593731, 67.73166071984076, 69.64787975434335, 6.277763266717234, 0.49199897856000935, 4.367941127669427, 1.0179392681006463, 0.16359960840594384, 0.2460712104314758, 14.324906737573686, 53.81315761996854, 63.87202885843093, 70.33449065300726, 67.41612172895863, 64.06842977769914, 61.33359639875351, 58.60823162140385, 58.85412500750635, 61.63401073025119, 66.43138716297766, 65.00836695394209, 67.0566600368869, 65.24367778531968, 62.16264817022509, 58.59912780023391, 60.313360460342906, 59.87908347960442, 60.652618023657034, 54.81506432256391, 59.709684156602435, 68.61468822725358, 62.076387405395515, 60.246005519743896, 60.933463650365034, 53.84017882808563, 53.24922669318415, 56.86325542388424, 60.33334101400068, 53.511182185142275, 57.61164365276214, 59.28869616600775, 58.5970175650812, 57.65801783530944, 58.002872620859456, 60.249680780595355, 56.074490316452525, 54.71053707984186, 55.12415885925294, 52.555806559901086, 51.38087234189434, 50.74314202031782, 43.718777164336174, 37.01460715263121, 36.134042893686605, 41.665671333189934, 51.73876900826731, 50.147263388479914, 54.54958654219105, 50.82651592070057, 48.04888163843463, 48.24590229219007, 49.14795329493862, 48.27845796462029, 50.7772627184468, 59.5676080642208, 60.11250765092912, 54.45874444900021, 47.10767753662602, 49.7099308813772, 45.36572548650926, 40.807958802869244, 48.35185727765484, 43.68114986727315, 55.117286866711034, 57.82675820012247, 52.91342473799183, 51.939919917814194, 48.60303017400926, 51.82726552409511, 51.34733999929121, 50.02794488783806, 47.63214549710674, 46.55327404699018, 45.584091678742446, 46.59344696229505, 44.11889422324396, 40.67159760382868, 42.928184232404156, 43.03259772639121, 48.84130239486695, 48.77098606478784, 47.58177049698369, 50.32403676740585, 52.578858329403786, 56.37649320787, 61.63821943344609, 58.164160482345096, 60.95459738085347, 56.04626886306271, 58.25069189071656, 56.07645150153868, 61.21439164684665, 54.062122221915956, 59.469058513641365, 52.465093904925936, 54.262065041449766, 53.12125152157199, 56.960910674064394, 58.054271359597486, 65.22401494364586, 66.06045646052208, 60.06527446931409, 48.02808915415118, 57.708730159267304, 57.194546653378396, 65.81419437162339, 61.80300604912543, 65.73571166684552, 62.266575290310776, 71.25159571247717, 58.594554316612985, 60.964913214406664, 57.19033402781333, 62.87816693705898, 66.0366790525375, 62.42986356058429, 61.5163984606343, 62.26273921228225, 62.934511784584295, 73.66222166245984, 63.66824996086859, 75.39940018807688, 54.98127868098598, 35.68624942533432, 15.859077111367258, 0.4244664281366333, 2.370600368707411, 0.32246479343983436, 2.8777299821376805, 72.43455902222665, 67.50751295397359, 72.2813904669977, 79.68053387057397, 78.93312623423915, 36.446302783104684, 60.08818503349059, 69.17226883672899, 58.18220730750792, 69.15711279838317, 74.70845899274273, 49.85149706563642, 0.3634742767580094, 0.20510839718964793, 0.18027240891129742, 0.23545255764357506, 0.16180291771888733, 0.2770103147673992], [0.02648587353647717, 0.08985142659155593, 0.04227402251994899, 0.0704524485814956, 0.0639522844745267, 0.045817313235132925, 0.08879912055788503, 0.21128481253981593, 0.5853991619040889, 9.686246072092365, 62.207833874610166, 44.79198078955374, 43.67862778325235, 38.878023239874075, 35.23836182009789, 28.751336182317427, 65.31500608690324, 62.880618418416674, 62.332843734372055, 62.88793363878804, 48.51229398481308, 61.94488210062828, 12.716200543988137, 0.4190975307456909, 0.7194536395611302, 0.22144667774198518, 0.18236166857663663, 0.1754256617277861, 3.8991127235274163, 49.0581702416943, 67.25834046640705, 63.333667862799864, 61.53154665423978, 60.285892102026175, 56.465554545002604, 55.92809961688135, 55.462078894338305, 57.184611289731926, 59.249131218079604, 60.605726088246996, 62.71687515320317, 60.830862291397594, 59.57244826901344, 56.900737593250895, 57.71042854555192, 53.66403695075743, 48.23945783799695, 58.911591652900945, 59.77348150745515, 55.73754695154006, 53.43826140126875, 54.41868136006018, 48.46445675819151, 50.659336659216116, 50.918742610562234, 47.27722198732438, 55.60813619244484, 48.30672648645217, 51.4187781272396, 53.482493969701956, 50.353411397626324, 51.97382096321353, 50.38334300441127, 50.58564316841864, 49.22319612195415, 51.68945697046096, 52.19297947422151, 49.539303856511275, 44.61555650157314, 41.23161792755127, 38.78115638609856, 26.6279532447938, 26.53681501265495, 25.601474854253954, 30.353718534592662, 39.78107836938674, 42.184345952926144, 40.17945389593802, 43.24159337628273, 45.168928407853656, 42.75019099635463, 46.79243664587698, 49.74699727950558, 58.17571970724291, 59.879675757500436, 50.87002677302207, 45.26804670210808, 42.53520980958016, 47.45597616318734, 46.457642739818944, 44.037822754152366, 44.975124097639515, 43.455397852005504, 54.13119123828027, 55.7803713890814, 49.45703606451712, 47.274735204635135, 43.818809370840754, 44.87096163534349, 45.15959316684354, 44.759919335765225, 41.2045810299535, 42.17319073215608, 37.99335225935906, 29.609374269362423, 21.621689027355565, 20.999971782007528, 22.920793717907323, 25.683925036461126, 33.98340732820573, 42.02858078864313, 43.6850526255946, 45.00388683811311, 48.01087387146489, 50.80969679740168, 49.70566334262971, 52.34976053237916, 52.18916300804385, 49.544348024552875, 52.92188136808334, 53.107621285223196, 50.07476229821482, 53.383960108603205, 48.899129898317405, 50.45163539148147, 50.87907960337978, 52.134493012582105, 54.306976179922785, 55.55384666688981, 55.710106049814534, 60.74995556185323, 57.88721369158838, 59.1927706810736, 59.09582537989463, 56.74832997783538, 55.818300708647705, 56.720300720584014, 57.70754952584544, 58.90354294930735, 62.069687997141195, 60.649817451354004, 58.64360747798797, 59.72351443383002, 58.69072298849783, 61.800001513573434, 58.708836493953584, 60.41121967377202, 54.925110340118415, 65.36150578529605, 57.83326933460852, 70.85731906275596, 37.47470901858422, 26.771717917534616, 4.3126827766818385, 0.26380982310060536, 2.38421491557552, 0.30399398457619453, 6.1033447807835, 58.322494799090975, 52.05795188103953, 65.26698843125375, 65.04795543609127, 59.26997469317529, 21.14269506546759, 59.206628414892386, 43.448102243484996, 36.285638578476444, 41.48639155972389, 60.325825752750525, 18.601212962981194, 0.3639817333990528, 0.016200359828109225, 0.08826013173787825, 0.04864048896237247, 0.007093841071060349, 0.05042620927035328, 0.06839663631493045, 0.02211625931874639, 0.07062461918159839, 0.037537224275330384, 0.02081671947493188, 0.09611330671055664, 0.10783332580279921, 0.2225052120704805, 0.6667588026292863, 11.635439492041066, 72.68055438995361, 51.663486957550056, 38.15174933402769, 42.165640169574374, 42.841790106988725, 31.616111801516627, 74.01077916545253, 66.72937746970885, 70.4519421054471, 66.1375859475905, 57.42020453176191, 67.22144665256624, 14.839078476352078, 0.46001833172575124, 1.2158637830326635, 0.5600550121838047, 0.10584252375748851, 0.2503565530623159, 4.401958863581381, 55.34241914749146, 67.02171171865156, 62.33254955660913, 63.98462049422726, 60.51895541529502, 58.59850806574668, 59.98290077332528, 59.93942522233533, 59.64898940055602, 63.275954108084406, 61.34794050647367, 63.91850894497287, 61.25191303991503, 59.4387895830216, 58.006524347489886, 59.336082320059504, 54.90653007261215, 51.23456008972661, 60.16291795238372, 61.6205216992286, 56.21596628619779, 56.434779628630615, 55.54575089485415, 52.837954413506296, 52.31568690269224, 54.0792316006076, 50.688754435508486, 57.886280167487364, 50.726958320986846, 52.80712066158172, 56.11249416105209, 54.72201001259589, 56.03900855587375, 52.93552337154266, 55.362666422320956, 52.24424485237368, 55.381976250679266, 54.2075401736844, 51.57430010457193, 49.842255961510446, 45.12943798495878, 44.1895321876772, 32.0432637968371, 31.630369617092995, 30.966496698317993, 35.76532833037838, 44.37783341253958, 46.709019599422334, 44.916202252910985, 45.67730288351736, 45.485718634820756, 45.77618583556145, 48.127062320709236, 50.796313670373735, 60.25534860549435, 61.27671810888476, 51.2649663033024, 47.07870691053329, 43.715956980182284, 50.577633688526774, 47.400392255475445, 47.43061411765314, 46.39860714635542, 43.887482227817664, 54.67550639183291, 56.37417900946833, 50.994154099495184, 48.77138222417524, 45.09572521332772, 48.259991445849025, 47.777524225173465, 46.74596440407538, 42.923583292192035, 45.201307573626124, 41.82927731544741, 35.22703009267008, 28.895426411782545, 26.832763725711455, 27.68087233266523, 31.656751478871993, 39.22051675858037, 44.96092511761574, 46.97942387673163, 47.23443677348476, 53.69977758776758, 56.151600191670084, 51.703514745158536, 54.16300166037775, 55.15378059879426, 52.917092154102946, 56.24619599311583, 55.786251021969704, 50.777023453866285, 56.33654779003513, 53.49308436916721, 50.4222450717803, 51.438091877968084, 54.813899378622736, 55.300465476128366, 58.49970356110604, 57.522668607773326, 62.775479285947746, 58.643438816070564, 62.26883457553003, 59.16742040264992, 60.62418868464809, 56.92867271361813, 59.36444497877552, 61.92735302832819, 61.22857885975992, 63.66802638576877, 64.18631269085792, 58.65286034922446, 66.22308577260664, 59.40185654547907, 64.82892636329898, 60.80597877502442, 63.65962859122985, 58.740886180631584, 69.80223286536433, 60.34207613237443, 74.2449603542205, 45.62252698406097, 32.869689541478316, 5.165782109383614, 0.619815998981076, 3.2098507929232816, 0.40676725367384575, 7.477523146137115, 65.60393571853638, 56.0491321932885, 70.73404681298041, 74.51919678718814, 65.38354166092412, 27.808806319390577, 63.6932707601978, 54.05084540767055, 41.40421005987352, 45.194929799725934, 72.11469757941462, 22.91858542350031, 0.275052531111625, 0.16775630955253878, 0.11445486121961188, 0.04761613364661894, 0.0922038910850402, 0.1280750464948435, 0.08130963816637955, 0.18919904926611533, 0.07793061585435945, 0.08747476138054364, 0.14295143976567254, 0.2404681506055978, 0.32342954328463924, 0.6638888534038299, 0.7358587689457402, 15.612333551529916, 91.70357904126568, 58.203011558901885, 66.32076063463765, 54.099600468912435, 51.03690793437343, 38.00482911448325, 78.01099269620835, 75.92132645268595, 75.91551350009057, 72.04680135173183, 62.1250012613112, 74.48770015470444, 16.451268715243188, 0.5357374815690903, 2.352810949087143, 1.226549790270867, 0.5337640390761438, 0.19470205800908227, 5.337324517388498, 57.29381792006954, 66.62341071713355, 68.2570465149418, 65.92675070608816, 63.83186771023659, 58.81575246011057, 62.557940713820926, 61.529703140258796, 62.716879075573345, 66.34610699069115, 65.50699826209777, 65.73233058375698, 66.7838199677006, 62.40208141265377, 63.087401851531006, 61.024137081638465, 59.39774197916831, 55.963298966807706, 60.0941627256332, 65.04387224874189, 60.69410885533979, 60.98212849709296, 58.75328479274627, 55.29462898931196, 53.69277615700999, 55.55701986435921, 51.159968376159675, 61.91784912540067, 53.77289449014972, 54.75187101671773, 59.140881646064024, 56.85209235837383, 61.19736071555846, 55.52000837941324, 56.93048877100791, 54.341861740235366, 60.122443014575595, 59.20979768999162, 55.43588530632758, 54.618643791444846, 50.01844098491054, 49.05044709482501, 37.402192238838445, 38.15370659674368, 38.23085569566296, 43.90016717295493, 49.760658894815755, 50.39664768403577, 48.11809186012515, 51.76919483369397, 49.86435851743145, 49.898898909168864, 52.38366157777848, 54.71726394468739, 62.0261065421566, 64.19078419285437, 53.28341799397623, 49.79257914327806, 45.4715588784987, 50.79590966624599, 48.88133410484561, 50.34072253011888, 50.18864831616802, 48.08967821059689, 56.35162145860734, 60.00454833430629, 52.753572463989265, 53.053084650347316, 47.96914769757179, 51.18186696883171, 50.55710400304487, 49.20590631423458, 46.187132558514996, 48.49416086750646, 44.75906033669749, 42.24701366116924, 34.796291089827015, 35.145770349810206, 35.99078224551293, 38.78939336346042, 44.73213718783471, 49.248009035664225, 51.27942808212773, 51.1369832869499, 56.8790311967173, 59.919452513417895, 55.30334057346467, 60.40361812037807, 59.82254643594066, 55.839406982544936, 59.152252597193566, 57.74524742557157, 54.40855380027525, 62.26815600549022, 55.61726354783582, 53.81209465765185, 53.38887483842912, 56.37219821253131, 57.99376095494917, 61.58400835529451, 59.76265576577956, 64.56975967653337, 56.90234576502154, 64.4853816493865, 63.62508819949243, 61.04782035273891, 62.071323625503055, 62.524996726743645, 65.06663768522202, 65.257206040044, 64.28858064836072, 65.87642669677734, 59.140403116903, 64.18533994305518, 64.86716947247906, 66.51989936828613, 64.60388429703252, 66.94128744063839, 61.17390101955783, 71.46943630710726, 62.31217284356395, 76.12879630058043, 41.093185717059725, 36.0224671517649, 7.280862369844991, 0.6958596023821062, 4.937330032548597, 0.2828721437723406, 8.437285942416038, 72.78008061070597, 61.418974630294315, 77.40518262309413, 77.36282886997347, 71.52555757953276, 33.457503780241936, 74.72643129287228, 61.06090930200393, 52.48286224180653, 57.28729894084316, 83.53767502692439, 36.21283154333792, 0.6105331583849846, 0.2717362590614827, 0.24971290131009397, 0.145214524781031, 0.14636224706567105, 0.19608164446488505], [0.05065762911051993, 0.06497731011721396, 0.03471803603573673, 0.03311392070064622, 0.04996930294099355, 0.06123574435590737, 0.14680634823537644, 0.09275247132585895, 0.052134363176000696, 1.7127563780353916, 57.09004686724756, 47.24063804072719, 50.92352397980229, 31.528501741347778, 41.65977601082095, 23.257774345336422, 50.4115330788397, 69.28189908304523, 56.665869989702784, 65.9643348570793, 50.834144930685724, 65.61834650654947, 17.497428578715173, 0.19612143507167218, 0.21999114132936926, 0.5206787670331617, 0.20665220225289946, 0.08129145889993637, 1.4507420505246809, 43.46588626984627, 61.19953370863392, 70.61460279649305, 60.785543226426654, 58.468081412776826, 61.699212289625606, 62.94792236820344, 63.660009061136556, 60.894938130532545, 62.48349805032054, 59.73687010426676, 61.4188491144488, 59.94135502846011, 60.145141770762784, 56.39500287271316, 60.18137270404447, 57.70955777937367, 62.39856696897938, 60.395659631298436, 57.13062770905034, 58.25128416861258, 60.33836557019142, 55.50667624319754, 56.08162903016614, 56.64612870062552, 54.68486516706405, 50.62332145629391, 53.89551562647666, 51.63695604570451, 48.092086545882694, 54.286317056225194, 52.5196893753544, 51.563580266890995, 50.260612041719504, 50.530922182144664, 51.254830898777136, 51.53236996742987, 51.61243730975736, 49.46755978368944, 46.28973783985261, 43.812439441680915, 36.60642177827897, 40.834344587018414, 34.729289162543516, 24.19218490200658, 28.15930343443348, 37.2851957813386, 43.02604736820344, 42.289241898444395, 41.90459074512605, 44.544683194929554, 46.32827904916579, 44.08254954122728, 52.829399724160474, 62.389627887356674, 59.27879218132266, 60.20002357421383, 49.68139956074376, 43.67190876314717, 46.08411150593912, 47.71399359549246, 42.71616835747996, 39.321482489185954, 43.604993128007465, 52.7742668890184, 58.7471031373547, 57.849088253513465, 46.3999838982859, 44.84038675985029, 45.24994496376284, 45.99206524510538, 43.22857502968081, 40.8128539208443, 38.17298112377044, 36.154082282896965, 20.106308767872473, 10.057580778675696, 10.815568027957793, 11.755282609693467, 17.51445754881828, 39.15100059201641, 42.04250520275485, 42.91319685597574, 45.88636521370181, 53.24916393526139, 50.377047600284705, 51.90119435710292, 48.09776221552203, 50.41155661306074, 50.09617059461532, 54.16824979166831, 48.03956993164555, 48.30794242120559, 52.13236316557854, 49.64565892373362, 54.049519646552305, 56.14441048714423, 55.97535633271741, 57.04852857897359, 59.47983718687489, 61.0342764085339, 58.02245701512983, 55.990461380251, 56.916215265950854, 54.705951829110425, 55.10829287190592, 51.8390404793524, 55.232149554837136, 55.28646653698337, 59.513753921754905, 58.34870799895256, 60.43535401744228, 62.71205456026139, 61.90912577413744, 57.55268650670206, 59.62051691547517, 61.48455273720526, 62.37582114435012, 63.5381410198827, 60.32473533384262, 69.31330942338514, 64.34467054182484, 39.944452931804044, 39.21191892316265, 0.6472387597445519, 0.484096046176649, 2.5230474529727815, 0.4016981111659158, 17.76565201820866, 62.964251195230794, 56.473446353789306, 64.51309319465392, 67.74583616564351, 49.9731925226027, 16.391970322978114, 66.70125407557335, 37.30659231062859, 34.094857554281916, 44.31702490775816, 55.53816503094089, 7.4761395300588305, 0.33145324176838326, 0.11751914396882059, 0.08391255212406959, 0.03874522618829243, 0.0893077569743318, 0.07346721906815806, 0.014329715800892203, 0.048906298489460064, 0.04034793192160226, 0.02278387238602004, 0.03380736816794642, 0.05688377505829258, 0.10833122166654757, 0.12898122891783714, 0.08336077729660658, 2.1545054739521396, 69.07166004180908, 54.590779273740715, 47.893908792926425, 41.537233321897446, 47.28547465416693, 22.985493213899677, 62.282555026392785, 74.13718931136593, 66.43411713261759, 72.24098220948251, 59.28079651248071, 71.8429087054345, 20.93277177503032, 0.23399948803407533, 0.5823724404458077, 0.7257199936336087, 1.051826094908099, 0.22473203048350351, 2.1680435346018885, 45.132418986289736, 67.87129709797522, 67.2718491092805, 61.91853554018083, 62.202860309231674, 65.33336277930968, 64.47218287375667, 64.40157236591463, 62.468804851655044, 64.49831370384463, 60.90053535276844, 64.02059255107757, 61.05169173209899, 62.22189557167792, 58.06612083988806, 60.39333758815643, 58.91893040749335, 63.765085435682735, 61.74308007763278, 58.85644312827819, 59.39010904681299, 60.362103754474276, 58.21306459365353, 58.335328794294796, 57.288216775463475, 56.88335757101736, 53.80702695538921, 56.57759312660464, 51.714673888298776, 51.056229529842255, 57.37330475161153, 55.062836523978945, 55.098847804530976, 53.10656224527667, 54.2073283656951, 52.821892307650664, 54.20120946822628, 56.135718514842374, 50.41382374302034, 50.46646195073282, 47.32532201274749, 42.00731761993901, 41.96326548053373, 38.3083381960469, 30.760289853618993, 31.708987643641812, 39.926908170023275, 46.99769819936445, 44.56756630251485, 45.53618777182795, 46.23425983613538, 48.490061990676395, 45.5282175156378, 52.783331486486624, 63.649740296025435, 59.13985398507888, 60.124278683816236, 51.87249437455208, 44.14638611578172, 47.08820689109064, 52.218588629076564, 45.919352346850985, 45.242649355242335, 44.567001481210035, 51.91334978226693, 62.57091199198077, 56.22150075051093, 48.55940165058259, 46.5137836240953, 47.28609831102433, 46.49818828029018, 46.04449556719872, 42.379346586042836, 42.607350041789395, 40.27950571429345, 25.156221120588242, 13.658649998326457, 15.232686361958905, 15.681447675151212, 22.002278566360477, 44.78601094215147, 45.5470762714263, 47.10158609574842, 50.1542216731656, 55.92977446894492, 54.424337417848655, 53.29818964004517, 51.22309500171293, 53.38384243749803, 51.846638110376176, 55.21451065617224, 52.13725043881325, 51.615139822806086, 52.86281439565843, 51.75991450586627, 56.564304136460834, 56.704811280773534, 59.343495599685184, 57.18203429252871, 59.5516832413212, 62.02415320181078, 62.84150846542851, 57.137319272564305, 60.39244328775714, 57.452889642407825, 56.84949574931976, 54.8665258192247, 57.18411314872004, 56.61581662393386, 63.09586240399269, 60.08749469634026, 63.43948164293843, 65.04447237137826, 62.72211151738321, 60.79247013215096, 61.225452730732584, 64.59815763658094, 65.84456136149745, 67.38592732337214, 62.71358820699877, 70.62724851792859, 69.6859424344955, 42.752238473584576, 42.120105374243956, 0.5839302955615906, 1.801587153346308, 2.1030322101808365, 0.39736413727364234, 19.485336772857174, 70.25156390282416, 60.473302948859434, 70.73681600632207, 74.45156728067707, 55.105480532492365, 20.339089670488914, 71.06984876817273, 48.69197776240688, 35.94079163766677, 47.35401415055799, 67.87539205243512, 9.091432363756242, 0.4550471565415783, 0.16830438417532753, 0.045153429100830714, 0.04939982382160041, 0.019058193373043212, 0.09556085772572026, 0.11136602535242997, 0.18418123464911215, 0.16700828598151285, 0.22031346516263103, 0.17137671850862043, 0.166214389065581, 0.2656883932650089, 0.2886495192445094, 0.2539233818289734, 3.042101807171299, 86.3775416343443, 61.500163770491085, 73.46109820950416, 48.54208830864199, 58.41778486005722, 34.60630716816072, 67.29367317691927, 81.21574955601847, 71.13478752874559, 77.9865720195155, 64.24047670056744, 78.5827487514865, 22.845652872516265, 0.41303158527420414, 0.9868732383174281, 1.3303115579389757, 2.347568211055571, 0.3924896117419966, 2.6897697583321603, 48.120684546809045, 65.15339659106347, 66.73093072829708, 64.97521900361585, 68.19592814291677, 68.7419456051242, 66.94898313091647, 67.65540984369093, 63.929244472134506, 66.15282827808012, 64.48679370264854, 66.14617593826787, 62.71850293682468, 65.35498288369948, 60.70097692551152, 66.24116789910101, 63.193784375344556, 65.08473550119709, 65.96180885068833, 61.03148368097121, 64.05348946971279, 63.59169313984533, 59.46557152655817, 59.52673696702527, 59.615335464477546, 59.66996623623756, 55.81289568255025, 58.87827504065729, 55.79659038974393, 54.07008463336576, 60.681357229909594, 59.81224236949798, 60.27558019084316, 57.86667616136613, 59.91464368758663, 57.0632335447496, 57.52531620763964, 59.380079546282374, 55.32225816480575, 53.493284410045995, 53.33092966387349, 47.75753582677534, 48.31259827460013, 45.33089091700893, 39.26593388280561, 40.22256074413177, 45.846325658982806, 51.23121038559945, 48.98457088778096, 48.5596134585719, 48.57495384831583, 51.599575857962336, 49.81688214886574, 57.2993641514932, 64.96833524396344, 61.420084661053075, 62.28308062399588, 56.3576344520815, 47.62410463825349, 48.788471991016024, 54.74478721618653, 49.29774468944919, 46.80735734201247, 45.29211828785558, 55.10552367856426, 64.1442217365388, 63.07775282090711, 50.714426348286295, 49.17492743461363, 51.19769765484718, 49.7627220615264, 48.48224078455279, 45.56138900018508, 46.31638250043316, 45.318331487717174, 35.33340869411346, 21.268903209317116, 22.612791561311294, 22.98686996583016, 28.151894077177975, 47.65717806354646, 50.291120236919774, 51.76864570186984, 53.01226846633419, 60.276407810949514, 56.90927267074586, 57.86689581409578, 55.96307146933771, 57.41173221218971, 57.853901001714895, 60.392196178436286, 53.16117340518583, 52.805971407121234, 57.758430511720725, 55.14833242662492, 59.32307966293828, 61.03453528496527, 61.197086149646395, 58.54976477161531, 63.58133808259041, 64.84308219725087, 63.359053442555094, 60.00116725121776, 63.444682705786924, 58.484822088672274, 62.51570463180543, 57.19229129052932, 59.99040426746492, 57.441699120306204, 65.5994995178715, 61.940802835649066, 64.83300170590802, 64.98323240587789, 61.21064578333209, 60.78882625026088, 64.67059596892327, 66.87222234664425, 67.14238735937303, 70.06298418967955, 69.2950782468242, 67.0891058829523, 67.25004073112243, 42.09829699608588, 48.83151608128702, 1.2450965950565955, 2.7140624676981284, 3.740642349566183, 0.5273785430096811, 21.83069448317251, 79.34499079181303, 67.38981831458308, 79.07132702489054, 78.70132984653597, 63.6427741665994, 26.951211460175056, 85.66155218308973, 54.937752139183786, 49.8667590079769, 59.71270438163512, 82.66958390512775, 18.43401016727571, 0.6340942844267815, 0.3973992853876083, 0.20866068560750256, 0.15826006750425986, 0.2181109164150492, 0.18440376786935717], [0.04147503878019991, 0.046826994136696866, 0.022418038589098764, 0.017549574728153886, 0.07323299534618855, 0.027583867138732347, 0.06747619699566595, 0.05833884798771432, 0.06713588541794209, 0.18958747116548402, 45.35730808011947, 58.64077160435339, 40.32934727207307, 32.492849788358136, 45.20691656297253, 16.826758192431544, 45.40993844309161, 64.46793494686004, 57.43348567716537, 64.6334275891704, 54.97938809856292, 61.80456323008384, 26.601371342136016, 0.18283780754333545, 0.2595203435949741, 0.5581598332332027, 0.4747302535801165, 0.194929126469839, 0.42334291423040055, 41.12039912131525, 53.655592087776434, 60.55897143579299, 72.65888721712174, 70.55234693711805, 64.04403655759751, 59.02003734342514, 58.79734869926207, 57.26821660995484, 59.92145684457595, 60.67788200993692, 60.25165373279203, 57.21668451063095, 56.974548755153535, 56.208098011632124, 59.57409174211564, 59.53058088979414, 56.83006040511593, 58.81212034533101, 58.51636578959804, 56.912861639453524, 58.25816792826499, 61.5081810951233, 59.90743044883975, 58.45034837722779, 60.292344400959635, 54.05137885001398, 52.28810479564052, 52.70548812804684, 48.23866159685197, 54.87497460457587, 53.22749676242952, 52.06486701965333, 54.54069060664023, 50.752951868118785, 52.3049396084201, 53.27991531741235, 50.82129524600122, 52.27838908472369, 49.121504752866684, 43.49435875492711, 37.5315990755635, 34.797020650679066, 30.97982098979335, 26.22502188528738, 33.33887169438024, 39.47962853216356, 42.22402072721913, 40.19886962829098, 42.171523724832845, 42.290740243850216, 43.05917178430865, 44.2649515213505, 53.85440134233045, 64.58220535709013, 57.261117119942945, 58.646557100357555, 59.38017368316651, 57.9738353144738, 49.06882732145248, 49.98180212513093, 45.454096486491544, 48.65184407080374, 52.83585986783428, 58.683180270656464, 55.53800029139365, 60.86588121229603, 50.924728147445194, 45.23047039585729, 45.07974939961588, 46.68409685934744, 41.41347862059071, 41.131730848743075, 34.07941910528368, 26.99438498866174, 21.69257998466492, 14.400308420581204, 12.717036989427383, 21.14281273657276, 33.651916057832786, 41.70286716953401, 42.72406408863683, 46.27537412028159, 48.930901096713164, 49.35937296959662, 50.35101482945104, 50.32150291627454, 49.61228347593739, 51.571342637462, 49.89003435257943, 51.057923993756695, 49.666914247697406, 49.60172837780368, 48.89794142015519, 51.89871934152419, 56.287714281389796, 54.97196305182673, 56.73746501245807, 48.42875142251292, 47.25253458945982, 51.52786316410188, 56.245752765286355, 59.589843980727665, 59.877447851242565, 57.444193747735795, 52.286979075401064, 49.43630241578626, 49.09290675194033, 50.51626428481072, 54.17907161097373, 59.05707628496232, 60.85407880044753, 58.55072575230753, 63.45144879433417, 61.144742119696836, 57.33592848623953, 65.11929158241519, 60.45721730878277, 63.81131056816348, 74.23928860695132, 75.14916866056382, 46.284066092583444, 61.33961331459784, 29.43520142186073, 0.07262980835812707, 1.2248164703769069, 1.2055421884982818, 0.21644597752921044, 27.46877997152267, 64.2865998514237, 55.7207945085341, 56.38246697764243, 73.48807627154936, 39.74175660840927, 35.12090644528789, 71.00773411412393, 30.06735021068204, 43.60365167740853, 39.052682461277136, 41.98417171355217, 2.1411566676632052, 0.18533908461611118, 0.06470708792368252, 0.09692560505842972, 0.014642268182679772, 0.06289400678548603, 0.011613177597492693, 0.024288742945739822, 0.048584399834996274, 0.011869027023954738, 0.02662796177901328, 0.05555283901612124, 0.05217716833876987, 0.017305039462723562, 0.15380267684738483, 0.030718202882957076, 0.27519983449770563, 54.885639529074396, 67.37152438009939, 43.91077326190087, 41.707373972862, 55.119353955791844, 18.279851213578258, 51.4525693462741, 72.42282329067108, 64.33168749655447, 71.76411613341301, 60.64720907518941, 69.8156395266133, 30.615689716031476, 0.2545264002776915, 0.671028670284056, 0.9359950716457061, 1.1499823053036968, 1.2175915870935687, 0.7387125383942359, 44.32377922919489, 58.16121870471586, 67.40930464959914, 69.66055685474028, 66.97782824116369, 66.8752190374559, 62.966871338505904, 60.4603159812189, 60.0297103389617, 63.47976438460812, 60.85969955690446, 64.310530231845, 60.20660531136298, 60.387493256599676, 58.29685426527455, 61.513068368358, 60.74761390686036, 58.15255418900521, 60.990922451019294, 60.58831860942226, 58.666596489567915, 59.98401080408404, 64.40481224367696, 59.95131392632762, 60.14428669406522, 60.11818724293863, 54.116356834288574, 52.44323845832579, 54.07800389874367, 52.19976909698979, 58.618602368139456, 57.80405944393527, 55.99890624323199, 56.5010755292831, 54.47351217269898, 54.40880483196628, 56.74557255160425, 55.35564145734234, 54.30413638391803, 51.08055606965096, 48.426221493751775, 42.816761462919175, 39.97451789917485, 36.067770527255156, 31.02391823645561, 39.17692745885542, 44.52604409187071, 45.864658817168205, 44.65137558598673, 44.630936115018784, 44.775377396614324, 44.94776164331744, 44.90542750204764, 53.78889776045277, 65.17357718560004, 62.34005305074877, 60.048796592220185, 58.97678536753501, 55.43755623602099, 50.54371303127658, 50.775631012455115, 45.83663740465718, 49.265306688124134, 52.18074952402423, 62.09188468994633, 58.3940270639235, 62.71172115879675, 53.660389146497174, 47.35848565255442, 46.6673836400432, 47.20727828241164, 43.4969828205724, 43.68881025621968, 38.44112611586048, 33.01709221255395, 26.63226785198335, 20.104716285582512, 16.670675316164573, 26.863913228434903, 38.093000073586744, 44.986820605493364, 45.64297037739908, 49.50726201457363, 52.6488765593498, 53.632053944372366, 52.05176630327779, 53.57559142574188, 54.08975139740975, 55.09468224740798, 52.82284152123236, 54.70617932658042, 50.49072965498894, 51.11637515406455, 52.545910419956336, 53.8879297625634, 59.38274675799955, 59.79879256217711, 59.13127576151202, 53.102169190683675, 52.43720585300077, 52.615956106493556, 56.414846143414906, 61.723907532230506, 60.787218078490234, 60.20510304358698, 55.21974702035227, 51.91458925124138, 51.67758787831953, 53.524267212037124, 56.70435628583355, 61.54789901548817, 63.500572558372255, 61.52231731722432, 64.83515900950279, 62.918645797237275, 57.58427335369972, 67.16713751516035, 64.38217624541252, 66.21098133825487, 71.6455428831039, 78.25734892199117, 49.91464330304054, 62.598878491309385, 32.402794130386845, 0.054505926241437276, 1.8458968208682154, 1.4029830261584253, 0.17119844984864035, 31.110934057543357, 72.77691133560674, 61.147452477485906, 64.05519177836757, 78.95664476579236, 46.13340785426479, 39.65293453585717, 77.25730142285748, 37.832209525569795, 44.768599540956565, 45.44428271632041, 57.07200004208473, 3.031467281041607, 0.048389246597165064, 0.04118540008822757, 0.051722085298669916, 0.009270268135644015, 0.04887172111099766, 0.011484645280776726, 0.13120657644204556, 0.2817092223032829, 0.08872055824125007, 0.1423234008853474, 0.15446350429086916, 0.25701385712431324, 0.1693737050217967, 0.3499106287715897, 0.14187752239165768, 0.48917698643861285, 65.33063280966975, 77.73346147229596, 54.685324084374216, 43.19652142063264, 63.782202659114716, 27.757611543901508, 59.22592255377001, 76.77546962614983, 70.21982408338978, 74.54224463432067, 68.02712502018099, 73.89541441394438, 34.93929678393949, 0.5362570117558203, 1.8028246611356737, 1.406190176644633, 1.3153056728263057, 1.0722851777268996, 1.229774836570986, 47.0028914174726, 58.41323098828716, 68.23801517486572, 66.81941155464419, 67.60846691746866, 67.93124660368889, 63.874127326473115, 60.79355662868869, 63.259358559885335, 65.0935019985322, 63.001062639297984, 65.86275331435665, 62.660369488500784, 62.26118595369401, 60.76241300952051, 63.881379788921734, 63.86267008319978, 61.06834611585064, 63.33433074335899, 62.48395304526053, 60.278494511881185, 64.32348189815399, 66.16157516356438, 62.953229335046586, 64.35719074741488, 63.77987277123236, 57.06615963289815, 57.16143008201354, 58.50567340850831, 54.434751310656154, 61.8375385961225, 62.97785789735856, 58.70436891432732, 62.43475867855934, 58.216955584864465, 60.50218728280837, 60.85002306968936, 58.75034693748721, 57.38234973722889, 57.85618774352535, 52.97784966807212, 47.5677127222861, 45.58731586702409, 43.45096165134061, 38.044790221798806, 45.84637664979505, 48.79080972363872, 48.13962567237116, 48.399674892425544, 49.73928982211698, 47.080821068056174, 49.18212498387983, 46.761167510863274, 56.37733259508687, 68.6260631007533, 60.75072826877717, 60.217074117352894, 60.7974946883417, 61.52749484585178, 53.59822742400631, 52.67054373218168, 50.066411572117964, 52.37851150574223, 56.619660546702725, 62.91809666541315, 61.77410210332563, 64.94542467978694, 57.96257811207926, 50.66864052126485, 48.70402336120606, 50.445473347940755, 47.09909931305916, 47.400407944956136, 42.958543377537886, 39.23981874219833, 34.197992355592795, 27.4123860943702, 24.045594161556615, 35.5238829120513, 44.706429973725356, 50.96989816234958, 52.39919416366085, 52.976782783385254, 54.64813217040032, 56.997400483777454, 58.688491159869784, 57.2702483977041, 56.91242233399422, 59.354497848018525, 57.01008542891472, 57.38907660207441, 52.649080522598766, 54.73547943176762, 54.7382447027391, 55.009774700287856, 60.91881359777143, 60.729151310459265, 61.3766404890245, 54.089633726304584, 52.681549902885195, 52.95009105436264, 57.88307559105658, 63.15290935577885, 63.00303559149466, 60.49280497335619, 57.587658359158425, 54.38163065141248, 52.20481326503139, 57.14516401290894, 58.708601151743245, 64.50090639052853, 66.11227097049837, 64.44856628294914, 66.33601080986762, 64.56647273032897, 62.82838421483194, 68.38209952077558, 68.15830476822393, 70.37737000373103, 68.68727560966246, 76.40724535911315, 52.64414225855182, 64.14099362588698, 38.5766871513859, 0.20480833587146577, 3.3497607563772513, 2.2673736368456194, 0.27534082531929016, 34.17921204720774, 79.44120653213994, 68.00797600899973, 71.68427236618535, 84.42176157428374, 53.8128242185039, 46.95369705077141, 87.63799528921805, 42.238823752249445, 60.265585991644095, 54.13536856251379, 78.77244241776006, 7.414346510364164, 0.29948895857218777, 0.337014519158871, 0.17122538550005806, 0.16481387308768689, 0.16510457281143437, 0.1889551728362999], [0.10357859604541333, 0.019359114624920393, 0.09101607175844331, 0.026261530433511062, 0.12070876636332083, 0.05937543772761861, 0.08865533351537683, 0.13694621442306426, 0.24284561254805137, 0.20979558358029013, 40.6527937612226, 55.805521626626295, 40.00041730942265, 37.505664363984145, 38.74940479955366, 26.18780251472227, 26.60680186363959, 70.79059954612487, 57.385715130836736, 66.16318333533503, 55.663963287107414, 63.540043369416274, 44.540097944198116, 0.4493308842422501, 0.11370217983400631, 0.9832101735857226, 1.2686036046474212, 0.9180758460875481, 0.04245547044481482, 39.54916038820821, 62.873840562758915, 49.79261052223944, 57.84373029585808, 69.5914525370444, 76.45647894951605, 76.76965667355445, 70.92947498444589, 67.56452068205803, 63.246038190780155, 60.24486018765358, 58.43676128695088, 60.20595419791437, 56.35752854808685, 59.12124233861124, 58.614432888646284, 57.133130181220274, 57.65848851973011, 56.08154666039252, 52.50488242795391, 56.92320492959792, 52.2777928844575, 66.26223102692636, 75.99654182311028, 56.15103929273544, 58.07480104507939, 53.46731439713509, 50.33028902546052, 52.440226078033454, 50.19970547768378, 54.57605861848401, 54.49633252236151, 54.40007755833288, 52.34295914250036, 52.511613215169604, 53.27930342766547, 51.112335112787065, 53.019517006412634, 54.19756950870637, 52.43993190027053, 46.417046208535474, 45.06316169615715, 44.00645948225453, 38.657668405963534, 37.23079250704858, 38.617432732735914, 40.96475947287775, 41.35368208731375, 38.62204544005856, 39.98359426375359, 42.0056035441737, 41.04528181014523, 50.63698699397426, 62.13376383627615, 61.90264994098295, 53.90779264511601, 54.44880908535373, 59.461370668103626, 60.18568338886384, 57.84989626176896, 53.1503241292892, 55.508911994195756, 61.515696356373454, 59.03871959255588, 54.62515100356072, 58.38757476499004, 58.99844469562654, 61.883238131000155, 44.61141447867117, 44.581761360168464, 42.15484972923033, 41.620364035329516, 40.75916451792563, 38.280638417889996, 28.60588489040252, 25.44333665601669, 24.2084901948129, 20.72835941468516, 28.21753494201168, 40.49376518495622, 41.0538011981595, 42.401633493361935, 49.010168275525494, 49.0016528098814, 51.78193076964348, 51.92126120290449, 53.167457042201875, 51.0674867322368, 49.54241037368775, 50.367567231578214, 51.58822844105383, 47.700155473524525, 50.11841435586253, 48.62623883831886, 52.004544888773275, 57.00073842079409, 59.74761347616873, 56.115494774233916, 50.58438016522316, 50.43658917950046, 43.81341611185382, 48.79950169594058, 59.063912976172666, 55.15522795338785, 56.63128645189347, 51.280255702234086, 45.732890713599424, 44.510735081088164, 46.1077320191168, 48.608905884527395, 50.0477607019486, 53.51913282948156, 59.996503553082874, 60.64162362006403, 70.06987971644249, 58.32150243943738, 55.38985236998528, 62.11540322149954, 82.8826548976283, 72.3561429977417, 47.7649373392905, 52.73295648636357, 66.97483155035204, 16.335677446857577, 0.24176283919763183, 2.350281265474135, 0.7810426347198025, 0.2414654898307016, 39.36839403644685, 61.45470742256411, 54.775322867978005, 61.71955370133924, 66.06219014813824, 40.43937367777671, 19.212139767985192, 47.81677146111765, 38.02165608252249, 42.88339076503631, 41.60571790510609, 38.78685166758876, 0.7940334021564454, 0.08363372676314847, 0.04703252020502283, 0.1107637346872399, 0.04760905882463821, 0.050891883476006414, 0.00949813141262219, 0.007207366204144614, 0.0699565522072296, 0.07929669618005715, 0.028826408125760577, 0.05275257314825731, 0.07220902690483678, 0.07699546764694876, 0.11400482286849331, 0.13743039731296802, 0.21994228024155865, 46.82796155252765, 68.46735615884104, 42.587985300248675, 42.91701724452358, 50.65788538225236, 26.69782046348818, 32.70147085189819, 79.50201111455118, 62.79151785758234, 74.0144818828952, 62.49845797015775, 71.75770698055145, 48.80270627237136, 0.4455907817088789, 0.216211692520207, 1.2200494423027963, 3.912213194754816, 2.1171225895804744, 0.03070685520557867, 41.12028145021008, 63.81169496044036, 52.40189275433941, 64.29652737032983, 70.12156086583292, 72.51622276921427, 71.47204860564202, 69.20881748199463, 66.0139528397591, 65.57984059856784, 61.29164664976059, 63.534744247313476, 62.492550880678245, 58.73905835613128, 60.34732034129482, 59.85725941196565, 59.63812051280853, 57.94166011195029, 56.973152391372196, 55.06020461359332, 61.5731708465084, 56.89820766448975, 66.70563928542599, 69.56686712080433, 57.24506285882766, 60.300424483514604, 56.12898772762668, 51.26284430103918, 57.249993278134255, 50.8162393108491, 55.63994269217215, 55.525617368759654, 58.537075904107866, 55.84039541982836, 54.02843298450593, 54.12156966424758, 56.13478106837119, 56.13618527689288, 55.99454848997055, 53.27521631794592, 48.52615564100204, 49.69473954169981, 48.70015982658633, 41.991153532458895, 40.781180781702844, 42.52110888881069, 44.33704076274749, 44.90992646063528, 43.03977958617672, 44.52886819839478, 43.27719673033684, 45.47347691751296, 50.64754209210796, 61.91883364031392, 63.506903263830374, 55.48226341124504, 55.20303772341821, 61.16671523740215, 63.00711485647387, 55.37261355307795, 53.7057670470207, 57.56384957221247, 62.540619527139974, 59.55455833865751, 58.41722396112258, 58.78540900445754, 60.14585564213415, 60.14496134173486, 47.528736129883804, 45.9956189124815, 44.35258903811055, 41.940468665092226, 44.49572024806854, 42.878550560243674, 31.493643637626406, 30.302308028744115, 29.199716045010476, 26.667973187661943, 34.96534916662401, 41.96160631795084, 44.30741510083599, 46.994034705623505, 52.58968799344955, 52.13603058168965, 56.31530423318186, 55.42606761378627, 54.36849463370539, 54.145311770900605, 52.25318001162622, 52.92861607766921, 56.509536081744784, 50.467615127563484, 52.66038479343538, 52.146899469437145, 56.33573585940946, 61.318479584109404, 61.54629868845786, 57.57666003319525, 52.70768073297317, 49.793783310920965, 44.85573499433456, 49.40347609981414, 61.261715042975645, 58.69580245787098, 58.4052764215777, 52.12731899753694, 48.19393088740688, 47.239794731140144, 47.09673412384526, 51.854337723024436, 54.384454757936545, 56.412229922509965, 62.553916362024125, 63.113807247531035, 70.35540473076605, 62.533163101442405, 55.76942797630064, 66.75335099620204, 75.26141905015515, 70.50101095630278, 53.36506997385333, 53.65145790961481, 69.2457034510951, 17.400740192782497, 0.39693613927210536, 1.1840214916775305, 0.8163582461495554, 0.23816208805768724, 44.97631257580173, 66.69249934534874, 64.48619358001217, 66.90302079723728, 73.77338163314327, 47.77473149761077, 23.22148261531707, 57.360557048551506, 50.735430640559045, 46.668191648298695, 48.02666141140846, 56.24158328579318, 1.6691205001646474, 0.017726807254216364, 0.09011041793611743, 0.07020073507221476, 0.08084839960980801, 0.029427524761206685, 0.023460287803543672, 0.15205685439850056, 0.15342396894289603, 0.23265465132651791, 0.17031784710143844, 0.2350888190971267, 0.1715913916667623, 0.1823446767464761, 0.21678265785017323, 0.4369114345360187, 0.3028261907879384, 58.49684415325042, 77.76419716496622, 55.25682518559118, 54.33005540601669, 52.85176115651285, 41.2182387228935, 37.880595884015484, 84.1012333285424, 70.66728022790724, 79.57909353317754, 66.21302881548482, 76.17449191308792, 54.84185018847066, 0.7957945463638153, 0.5165066521975302, 2.078751267925386, 4.669874887312613, 1.556966453790665, 0.07632491088682607, 44.76905453589655, 63.71008596112652, 58.85620386369767, 68.76114952948787, 72.4522332222231, 71.96180359009774, 72.85306807487243, 69.48541518180602, 68.09505262682515, 65.49097145757368, 64.54129503619286, 64.64035057252454, 65.70521131638559, 61.35693842364896, 65.23727647719845, 62.746622408590014, 62.79700525345341, 61.99566502724925, 58.694284500614295, 57.901573488789225, 64.65788356719479, 59.056942924376465, 65.2099101005062, 67.07348700492614, 59.31981232858474, 64.19369066915205, 58.49712656390283, 51.88330834911716, 58.29663461254489, 53.52422014359505, 59.77628600212836, 61.30787741753363, 62.92232498045891, 59.89950726109167, 58.4014089645878, 58.365409451146284, 59.63737918484596, 60.87584403253371, 60.68340078476937, 60.46043757469424, 53.24709684618058, 54.20799124625422, 53.21605913100704, 48.33735627512778, 48.03229785734608, 48.22092071656258, 50.06630566812331, 52.56242752075196, 46.50205965965025, 47.91102601635841, 46.42585977431267, 47.43400304548202, 53.95539845189741, 63.99406163923202, 63.321006451883626, 55.312428705153934, 57.45191689460509, 63.966424618997884, 65.50166776103359, 59.9038101011707, 55.92726415203464, 61.309756232846176, 64.94438917406144, 61.55457096715128, 57.801541282284646, 61.666001581376605, 64.12361752602362, 67.63761012784897, 48.74915023003855, 49.25020556296072, 48.34745245595133, 46.84420016504104, 47.70290505501532, 47.41676030620452, 37.6136040687561, 38.3253259812632, 38.07326270687965, 34.03428831408101, 41.95510302820514, 49.654150855156686, 52.104843816449566, 50.55203630078224, 54.6721645324461, 56.806122179954286, 61.54779311149352, 59.72183173702609, 57.646862614539366, 58.384770270316835, 56.16599529020248, 55.15385904619771, 57.09502043262605, 51.84458278840589, 56.86410657821163, 54.766317106062374, 57.88279710277435, 63.632889793765166, 65.71470737457275, 57.98599466200798, 50.86584944878855, 50.892192086865826, 44.409949779510505, 54.11188533229213, 64.07523901231828, 61.469055452654445, 62.96893058284637, 55.26072402154246, 50.016369973459554, 49.9370204248736, 50.02041001473704, 53.25949545829527, 55.01196730521418, 60.46382650252312, 66.22552548685383, 67.62392105594759, 74.02875146558209, 62.3079288390375, 58.72155281805224, 65.45641929872575, 71.04036823395761, 75.0353571676439, 60.83777350764121, 56.10031520166705, 70.06507089061122, 19.89210028802195, 0.5520357263665046, 4.963645214034665, 1.2952458137466063, 0.5902853319721838, 47.65222411001883, 76.78488331456339, 68.2629143807196, 74.41929401889925, 76.96162531452795, 54.169575552786554, 29.22166366730967, 62.64228736200641, 53.917359305966286, 58.80072585998043, 59.19418273433563, 70.8545498694143, 4.653092045937815, 0.25658152306512483, 0.19735351895853398, 0.27590696429533346, 0.20780292760220268, 0.11687574502561363, 0.09782011996233657], [0.09273683547132439, 0.014070761803117011, 0.1657472746146302, 0.014839670846178649, 0.06225556443114916, 0.05027541635377754, 0.12789708427003316, 0.1405554384954514, 0.06079530508648004, 0.4752925314730214, 19.949531632085, 60.57768114151494, 45.47239042097523, 34.87178494853359, 31.015402770811516, 47.635134343178045, 14.409579923076016, 35.68377833212576, 63.936987230854655, 64.08324456983998, 55.52057712308822, 58.50901134552495, 57.60643866754348, 3.1151762989259537, 0.23918558152452593, 1.280775699884661, 2.8497085696266544, 1.7021428120713082, 0.10123557741603545, 26.742090294438025, 75.89910230328961, 57.94639441274828, 53.48544751444171, 47.96354263059555, 49.815768195736794, 52.52856177668418, 50.83868703534527, 49.17184445165819, 55.26340692274032, 59.09412699361002, 60.10243500432661, 57.824079221294774, 53.9290322795991, 55.52694705224807, 58.985630312273585, 56.191518152913744, 41.45933112790508, 46.511441969102435, 57.337936739767756, 58.198273335733724, 59.64633787831953, 42.351603661814046, 54.86753779072916, 58.64314463830764, 56.99908318058137, 60.66406742219002, 50.907289289659076, 52.293772620539514, 48.15306371258151, 50.952894687652595, 52.048561726847005, 52.130143104061005, 49.98436735522363, 46.92280054092408, 54.06305574601697, 53.85537801250335, 52.50783597269366, 52.95600206621232, 53.700781714531686, 50.26662895756383, 44.541058924890336, 43.83248667563162, 40.567525356046616, 40.50427321464785, 39.64794528099799, 37.45224952697754, 41.04424238204956, 42.44929421332575, 40.27836430457331, 42.32222903159357, 44.592673393987845, 53.216835760301166, 58.44534343288791, 58.409732234093454, 47.68873745395292, 49.54842336716191, 57.33342209169942, 54.610485261486424, 56.72603522577594, 54.52139254539244, 57.212016890125895, 57.610706206290956, 55.696499347686775, 49.232339166825824, 54.05829791099795, 63.520804143721065, 61.69834936818769, 50.147031968639745, 41.66424751281738, 42.04103039157006, 39.505308289681714, 39.869727857651256, 37.92590318187591, 34.75028561007592, 32.38202518032443, 27.13159145847444, 28.166742209465276, 37.21900578468077, 42.42788199455508, 41.90576745617775, 46.93820368859076, 49.256708852706424, 50.103725079567205, 49.16447431810441, 52.10711879114951, 55.207081687065866, 48.76731864867672, 50.2469112027076, 52.03409210328133, 52.948902576200425, 46.740539766127064, 50.137614357856016, 49.9771737283276, 53.95957185376076, 57.11766427563083, 56.92745285649454, 54.66593973098263, 50.4966720458, 50.346688455150975, 52.747920328570956, 55.02367950254872, 55.958431305423865, 55.96979048944289, 53.069754723579656, 48.08270423643051, 44.33620529790079, 45.031672908413796, 44.57496389265984, 47.760324631967855, 43.19450924473424, 49.09766066458918, 59.248221228199625, 59.76973956631076, 59.78997115165957, 68.20173325077181, 52.787375450134284, 51.83994262449203, 56.2152563371966, 37.729270842767534, 61.66159283730292, 60.20642095996488, 66.7445727317564, 4.761400453505978, 0.30112072585090516, 1.8314306293764424, 0.24569417259866194, 0.9257481247186662, 48.74058769595239, 54.600389080662886, 62.32758383597098, 59.157190861240515, 67.61762957419118, 35.221632911312966, 42.97373079484509, 35.823740266984515, 28.519930070446385, 63.49395551989156, 46.270600595781886, 35.103145953147646, 0.7514872690362315, 0.06451260884322467, 0.01964688023191787, 0.03669726249251155, 0.08389525385873933, 0.06532454712977333, 0.023408521327280232, 0.08807382681557248, 0.04511453481691499, 0.07003673863026404, 0.03714189992376393, 0.006445181497838349, 0.046595501518177415, 0.10666140280063115, 0.14701150658149875, 0.07832171140058387, 0.37748774093004966, 23.634861207777455, 71.40290506424444, 49.30414207520024, 37.56888120405136, 38.97947534438103, 52.345277263272195, 17.371759760764338, 45.91351586003458, 73.08757089799451, 69.51535855570148, 62.16447991709556, 64.46367133048274, 66.09942128581386, 3.717288312412078, 0.39378466805623424, 1.2529070146622197, 3.5758660301085445, 4.895335176298696, 0.18822152107473344, 28.606504624889745, 74.32536894275297, 58.85379945078204, 54.49671299226823, 54.15961665491904, 55.809851923296534, 53.81999038880872, 51.683134109743186, 49.797842964049316, 54.41443735553373, 61.17301456389889, 62.51166066815777, 61.54927184504848, 55.99414840821297, 58.11819030392555, 60.80242118527813, 57.49308216956354, 44.04374945548273, 47.30360777147355, 58.38225995340655, 58.40834763742263, 58.28526366141535, 44.30951356887818, 55.15916993541103, 58.341126057409475, 59.640046396563136, 61.97356247132825, 52.511417096660985, 54.434535580296675, 49.96829740462765, 54.330545702288234, 54.98686805848153, 55.21978232168383, 53.29696978292158, 53.060133149546964, 57.1395157998608, 55.73423647111463, 55.22750546855312, 55.36176427718132, 56.167148467033144, 54.346246950088016, 48.67209919037358, 46.60477868972286, 45.626971029466205, 43.87993558760613, 42.836459605924546, 42.48443080532936, 43.57679913120885, 43.463599528035815, 41.57884574705555, 44.828164654393355, 45.47460656012259, 55.50832756104008, 59.61354294130879, 58.85121068646831, 49.65523342932425, 48.44282488669119, 60.680251121521, 56.88978633572979, 58.88187969884565, 57.603187022670625, 57.1008373075916, 59.34601376133581, 55.14456695125949, 51.088534170581454, 55.9912262424346, 65.34471411858836, 65.90778212393484, 48.492203604790475, 43.77520830400529, 43.17534454407231, 42.343048972468225, 42.23196744918823, 42.70266363697667, 39.46288785626812, 38.16979223682035, 31.28189056150375, 32.9070108936679, 41.64165858299502, 47.77191915819722, 44.79444403802195, 48.67229923125237, 53.607582276867284, 53.82130046044627, 52.07219400713521, 53.880045798517045, 55.28603115389424, 52.02744760820943, 52.65294405721849, 53.888121958701845, 54.10370326811268, 47.12527328921903, 53.72875998097082, 51.83012100958055, 57.41259513362762, 59.21928198106828, 59.216716750975586, 55.79315047110281, 48.76443570660007, 49.57279697541268, 52.61375565682688, 56.06016582058322, 59.9644224874435, 59.11086374713529, 54.151799371165616, 49.71998783849901, 45.91674789305657, 48.11942154361356, 46.823454749199655, 48.894136721088046, 46.897834654777284, 50.299941647437315, 59.30875516706898, 64.62684585202125, 61.493801686071585, 66.74039148515271, 55.63564769683346, 47.70579191946214, 55.96135739357241, 44.11126913562898, 61.44148511271323, 63.695788921848425, 67.65821041599398, 6.850128760260921, 0.8554226015844654, 1.437933550726983, 0.39012806910660963, 1.1436153179214847, 54.5043969154358, 61.51458240324452, 66.54745009637648, 67.67061295047884, 75.3108173801053, 39.413638576384514, 46.189768391270796, 42.81298814281341, 37.61992300710371, 59.05852756192608, 53.32773685455323, 48.38593482971192, 1.0287897697379513, 0.009280498282262876, 0.08262494218445594, 0.026273722722825986, 0.07769465311280183, 0.11630595181017153, 0.04620403058887009, 0.2176701400669352, 0.17525206620414413, 0.19746685400605204, 0.08591790217906238, 0.2412878800063364, 0.2199430922947584, 0.2929310620792451, 0.20806166613774918, 0.18573849221631406, 0.6977566812307604, 29.931461657247237, 83.8175282939788, 61.04219959628198, 49.42199753176782, 45.25595403486683, 62.60298129050963, 23.514783728507258, 46.95123772467337, 76.0912827522524, 76.03445545319589, 66.73802237356863, 68.26143172479445, 71.99073499248874, 4.0506223613216035, 0.6685803145650895, 2.6111137338223, 7.986592861913866, 6.562463112415807, 0.3454771553797107, 32.35199159191501, 75.11551472448534, 61.65021404143303, 58.50256689133183, 59.47178063854095, 61.23460754271477, 58.92599067380352, 54.69071342099098, 53.58616221335627, 56.58721470063733, 63.8007946937315, 65.63198851000878, 65.57961310109785, 58.24641258485856, 60.84122519339285, 64.35163667125087, 57.819619486408854, 43.35598537998815, 50.075695822315836, 59.51978652707992, 59.713857558465776, 55.14105642995527, 48.70219161433559, 57.418043305796964, 59.517193840396025, 62.12579750245618, 63.47817190231816, 54.976528690707305, 56.57505927547332, 51.81304300985029, 55.66515176526962, 57.76946021664528, 60.08530993615428, 58.06569330153927, 55.024918971523164, 59.783711048864554, 62.26575159257459, 59.94706992180117, 59.21932904951034, 59.70785240973196, 59.481982723359145, 54.673411846160896, 52.8523495120387, 49.99915469077326, 50.15395495199388, 48.20720026569982, 44.93503747447845, 47.554266837335405, 48.953882263552764, 45.359335945498565, 49.63560588898198, 49.59367575183992, 60.90024117500552, 62.55966263432657, 60.80400190045757, 51.610334919345, 50.41804421332575, 62.92689061933949, 59.28347156893823, 63.018356369387725, 61.4072310539984, 60.707542973179976, 62.14868061004147, 59.06693712357552, 52.41995134661275, 57.624560017739576, 67.52688161788448, 67.60562712146391, 53.415139029102946, 48.229255753178755, 46.01130447080059, 44.81123570472964, 45.29632306868031, 47.049120472323516, 46.07019493656774, 43.857260365639966, 40.61937124498429, 39.39039853311355, 47.08505722784227, 51.93297340023903, 49.98574802952428, 52.427548977636526, 57.252060367215066, 57.642814728521536, 56.52777902541622, 60.279506483385646, 61.69012808030652, 54.30493262506301, 57.28984455908499, 57.52587318420411, 57.96309194257183, 51.223012631939305, 54.588586668814386, 55.01861180028608, 59.917440337519494, 60.82657121842908, 61.22576652034637, 58.88124819724791, 50.87660066543087, 50.230127380740264, 53.86282659346058, 59.595245084454945, 62.20364086089596, 59.51921778340494, 57.090176305463245, 52.27194463053058, 47.72882799948416, 50.756074074775945, 50.31021433491861, 53.82017474020682, 48.84846856517177, 51.741722553007065, 64.25487179909983, 64.61967183697608, 66.2889031440981, 67.67286439095774, 57.72569441026258, 50.332493397497366, 67.85876904764484, 54.22019766223047, 62.6670688967551, 65.76270934074157, 70.62949995840751, 8.275255772375292, 0.8687251361627734, 5.342801617037866, 0.5226824853208758, 1.408645335224367, 59.84135027854674, 69.04032814887263, 71.38622714627174, 74.43677210038709, 80.18562532240345, 48.431618675108886, 53.633697417474565, 51.86932902182303, 41.67808563478532, 80.95324885460639, 62.80783099512901, 66.42913572249874, 2.206543068731985, 0.21105353059547566, 0.15897856604668403, 0.1609069166044074, 0.19745105727305337, 0.24211436630256716, 0.18287251132630533], [0.05694996122451079, 0.024134075539487026, 0.042384840968635776, 0.05244439895895701, 0.04319708185991453, 0.08150184962658152, 0.12104068161739458, 0.1483295455334648, 0.07085284443512078, 0.3752034812444641, 7.251162182900214, 60.15048011656731, 42.57865005923856, 42.44920007644161, 30.934337185275172, 47.37541460221814, 58.720701663724846, 13.12230706214905, 60.201027700977946, 53.28125284564111, 64.01699181525939, 58.318144890569876, 66.48493536057012, 14.653693533712818, 0.3663726631672152, 1.7200138660207873, 2.7991595143272034, 4.342574669468788, 0.2819732162019899, 17.32414218687242, 75.31940737078267, 60.715195517386164, 62.20875170923049, 55.32654139303393, 50.308033497102805, 52.77574954494354, 50.40410410973334, 48.629537551633774, 48.117134801803104, 57.7853536605835, 59.23777987880092, 54.58505261328913, 53.961984111416726, 58.355336804543775, 58.96829343611195, 34.75955809316328, 44.35376182679207, 59.47803289659562, 55.26838833285917, 57.16208904020248, 50.60759275190292, 50.32692755422285, 41.47638167104414, 51.005030831983014, 57.889112118751775, 59.130412840074115, 50.466077558455936, 51.66936266806818, 49.513023976356756, 49.004088601758404, 55.597875272074056, 52.20912394985076, 53.16362488654352, 52.680569310342115, 50.80972817636306, 52.594065358561856, 52.660545610612445, 55.67875454502722, 54.00163927385884, 54.74017058649371, 49.942954970944314, 41.59753191855646, 44.59665459971274, 42.44849797218077, 41.81610991877895, 40.389740005616225, 38.52800269280711, 43.31836985003564, 42.61598710090884, 43.76830101013184, 46.210129414835286, 54.606613882126354, 60.086929875035445, 59.775595664978034, 44.056885473189816, 47.81404933621807, 53.94480413006198, 57.75022099095007, 54.875017750647764, 54.391958252076186, 59.066890055133456, 53.74232745939686, 52.13599135798793, 44.51088413115471, 49.91612988133585, 54.70378668077531, 64.59197990355953, 56.87174343293714, 44.81236534733927, 43.817487532092684, 43.016629757419715, 41.64431402760167, 38.57975444486065, 35.40030079503214, 36.77857068277175, 34.59532060930806, 42.077018137901064, 43.176383972167976, 42.03284832739061, 45.105393855802475, 49.696010389635646, 50.58081080836635, 51.695991639168035, 51.404555612994784, 52.75288997157928, 50.035283642430464, 50.23689739165768, 52.08946420300392, 53.651238256885165, 52.6252011329897, 44.901258022554465, 52.708755462400376, 49.08938054115542, 50.70896640900643, 56.422765408792806, 56.81912483707551, 58.97533801294143, 57.72039921052995, 52.786132058789654, 49.4701720822242, 54.3828740427571, 55.85507685138334, 53.84839227122646, 50.14086600272886, 46.30017526688115, 44.46767530133648, 42.68692708784535, 53.48017977130029, 53.96774607319986, 50.642544992508434, 44.60646444751371, 47.52873220751363, 57.77756383342128, 63.06248695619645, 61.355345941359005, 68.4850303588375, 36.6053548935921, 34.6156894776129, 65.77477062902143, 61.35451832125264, 68.87518067513743, 45.60279353972405, 1.5565791197361485, 0.24347904468736342, 0.7893726457991909, 0.5877397750173846, 9.099618350305866, 65.31271934509277, 48.84238889140468, 70.14642869272541, 55.984177743234945, 69.93464423764136, 26.522888637358143, 29.34713048319663, 48.59654257374425, 29.037210287586337, 34.923030714834894, 51.25112033659413, 32.2567387934654, 0.11594975922977734, 0.1106895850370488, 0.05279384613517792, 0.10078732404978046, 0.032170916261572036, 0.02318164438850457, 0.023966221844837553, 0.09429246127124756, 0.042702568274351864, 0.053756424120717475, 0.021879794789598356, 0.10212383338160093, 0.07969285556746107, 0.10408834328935032, 0.08410431925327548, 0.14693832986297148, 0.35231893341387477, 9.531514452349755, 73.36640434880411, 47.44640950233706, 38.4391531636638, 41.609491225211855, 51.06782013370145, 56.23296191615444, 18.424543526864824, 64.231612143978, 66.30128214436193, 71.99583407371276, 62.88057527234478, 71.82152394325503, 15.994305726020569, 0.3556314975984635, 2.622651875980439, 2.8502741263758753, 7.413715499062692, 0.44730228341875544, 20.630325655783377, 74.7254663898099, 62.29432605927991, 64.07536060579362, 54.379838128243726, 56.45662723049041, 57.23156990543489, 54.11290122616676, 49.853791652187226, 50.91991932161393, 58.85565473187355, 63.427800824565274, 56.42351458149572, 56.879184169154016, 60.77324267356627, 59.60489803744901, 39.611651589793546, 43.28186435084189, 58.5744051010378, 56.20755672454835, 57.2483576497724, 54.94201967793127, 51.09200154581378, 42.71578788757325, 54.80144585332563, 58.677182966663, 62.365752420117786, 53.35580533550632, 54.123832871837, 51.75028116472306, 51.787641740614376, 58.38900250773276, 55.37228799635365, 57.57742881774903, 54.92635765383321, 53.69158767884778, 57.78055267949259, 54.912668581931825, 58.031199978243926, 58.583591291981364, 57.03088183556834, 53.124828723169145, 47.47826699287661, 49.111694905065725, 44.943580396713756, 44.75770319661787, 43.255168699449115, 40.53470688481485, 44.15291686211863, 44.423878115992395, 44.53510084459859, 49.20879317868141, 56.07156422830398, 61.57560663838541, 60.24367955423171, 44.0945480715844, 45.88804006576539, 56.67771946999335, 59.340357703547326, 56.24472118193104, 55.49770186024328, 57.861945782938314, 57.89336396801857, 53.498681591403106, 46.55908699958555, 49.553530293126265, 57.2608543211414, 66.42982605964907, 56.75984997903147, 47.492010977960405, 44.093896958135794, 44.844156157585886, 43.95877130569951, 42.29352512667256, 38.22548204852689, 39.77916817511282, 40.40306821946175, 44.84428559580157, 45.57570172894386, 45.79167135300175, 49.07565616792249, 53.03488877511794, 52.77261949354603, 55.64958780042587, 53.16289924806165, 55.11948731637771, 54.00918199170021, 53.37582119049565, 55.582581950772195, 55.50982982881608, 54.578282602371715, 48.500193472831484, 54.32981221906601, 51.49497016783684, 52.16068660059283, 58.80005513468097, 59.56314440696471, 60.24328731721448, 61.37342022311304, 54.64313899317096, 50.560073237265314, 55.61167809271044, 57.35901163470361, 55.530088870756096, 52.351086293497396, 48.44601769601145, 46.78079897357572, 46.179342731352776, 56.49242278068297, 59.18823642115439, 53.90247391116235, 48.56947037481493, 49.08044930427305, 58.98533221214049, 65.10492001810383, 62.44042650345833, 65.75911252729355, 41.93207479292347, 39.3210078823951, 66.85151223213443, 61.24602163991621, 71.2737649486911, 48.411963678175404, 1.3852001029637553, 0.42690182164792095, 1.6643842381815759, 0.5751728074204537, 11.94555482556743, 73.43121759353146, 56.85122159219558, 75.65402477018296, 65.2778769308521, 82.0506025129749, 33.61438289765389, 34.38495212985624, 57.88432290477138, 34.65765099371634, 35.84161058548958, 62.45904207229615, 40.7603451513475, 0.28809959068894386, 0.005244818439091286, 0.09288031607866289, 0.03218379419957919, 0.039576986999881845, 0.09134298445837152, 0.06768959844785352, 0.22966419647057212, 0.15693038401584472, 0.2276058254703399, 0.12967594809109165, 0.22151740297915476, 0.19334263498744658, 0.1931022059532904, 0.30787805035229654, 0.3036087955678663, 0.5606889039758713, 13.030519677746682, 87.74434643407022, 57.47061091084635, 58.75496356718002, 47.065488523052586, 63.90127012806555, 69.34009136692171, 24.280487260510846, 68.29122604862337, 66.4671121105071, 75.1242772994503, 68.88252335210001, 77.15127975709977, 20.190698562129853, 0.449325705487882, 4.369914079866102, 9.36496865364813, 10.434889255031463, 0.6287140795780767, 24.044501781463627, 75.46817502667828, 62.95330386007986, 65.450574967169, 58.62645495322443, 59.018895933705, 62.02052500940139, 56.46438567869125, 54.62425278079126, 53.33166314709572, 59.69362597311697, 65.3693897493424, 60.68491481965589, 58.106011344540505, 64.99064960787373, 62.51858757388208, 44.32003336568033, 49.52681895225279, 59.69541065154537, 55.21956659132435, 58.22847558606056, 55.108332095607636, 52.32698725115869, 45.55177527089273, 56.95152051987187, 61.29206634336903, 64.31325235674458, 57.247918344313106, 56.60916820649178, 55.364972775982274, 54.45593603195683, 60.72202828622634, 60.33070518124489, 62.17824743640039, 58.12459945678712, 58.13766094946093, 60.60165074563796, 58.672323150019494, 61.90141047200849, 62.63595273417812, 60.020288805807795, 56.627007146035474, 51.08756534514889, 54.08874727064564, 49.64267792240266, 50.2786627892525, 48.235315815094985, 44.74048006919123, 50.052899006874334, 48.67811218384774, 49.10942777510613, 53.112688987485825, 60.667307299952355, 63.068845118245775, 62.40783945206673, 45.26206116522513, 48.3652796283845, 57.444801715112504, 61.26242106960666, 59.70574217457926, 58.36528393530077, 61.30554752965128, 57.78671472303329, 54.33094186167563, 46.739127712865034, 50.180368192734264, 58.42038146911129, 67.74633038428523, 60.776772806721354, 50.7577097031378, 46.422870928241366, 51.41489890313918, 47.97930271394792, 43.5830553116337, 41.812501338220414, 44.317997655560895, 45.50402433641496, 48.56515968999555, 50.52230081250591, 50.42596740107383, 53.8197942703001, 56.157903440537, 56.88973142254738, 57.296579268670854, 58.79284189593408, 57.84635043913319, 58.389402589490345, 56.01224622418804, 59.00235922105851, 60.162764979947006, 56.95132832373343, 51.33857742432625, 56.678758898089015, 53.91681409651234, 55.2823245140814, 61.88942763113207, 61.99553166666339, 62.831965338799264, 62.861026179405954, 55.04079280361053, 51.31894988398398, 57.131486708118075, 60.1006660153789, 59.173464775085456, 53.009318843964614, 51.6340103457051, 50.22467920857091, 46.84396090046052, 57.31292770754907, 61.053288136759114, 55.05322671705677, 51.61963485902356, 50.276674147575136, 61.42636829806913, 67.96604587185767, 65.66887055673908, 66.319379960337, 48.820313792074884, 46.773393538690385, 64.22617966128935, 64.83305269672026, 72.24168823611352, 53.93095031861336, 2.5320890065162414, 0.862693879152498, 2.0101382270936043, 1.025439330166386, 11.306991000329296, 78.16580864690965, 61.96630216413929, 81.49405740922498, 67.47094861922726, 82.54624889742944, 37.66876828285956, 37.42589119941958, 68.54235972127607, 47.549183445592085, 51.34735961114207, 74.07672989752986, 57.54998007128316, 0.7909518900898196, 0.18654365062473283, 0.2933936259679256, 0.2525438260166876, 0.19994323322128868, 0.12905929327732132, 0.18150562660828715], [0.03948096553945253, 0.02909701719369379, 0.02081893346903305, 0.036344563273052057, 0.0607312984404064, 0.027197584539892215, 0.03600751522988562, 0.0386409156565224, 0.023200319696878715, 0.0926534544616457, 1.1295028751896274, 41.90448091876122, 56.32268613384616, 37.943632295054776, 31.34657044564524, 47.917599908767215, 91.31165581364786, 22.49666783117479, 55.49057099127001, 48.439985090686434, 44.59170064618511, 66.53155665243825, 55.77127933502198, 56.085563167448974, 0.9315691672025189, 3.0108142860474127, 0.9714296412083411, 5.400508507605522, 0.22401632050112372, 9.747030062060203, 67.6833135850968, 61.378774258398245, 43.758373491225704, 53.19130113047939, 56.78748307689544, 60.47175361264137, 59.37917347877257, 61.686735230107466, 58.03872308423443, 58.22143493160125, 57.54919167487853, 54.89230363599716, 51.054801787099535, 60.47868051836568, 46.948998051304976, 55.13208596937118, 67.44917162003057, 60.078512468645656, 60.280079149430804, 58.81765088727398, 56.010257582510675, 52.58979389744421, 41.3618641514932, 48.683591734978464, 57.879518001310295, 59.72029024554838, 50.19901121816328, 49.49781302482852, 51.6341946971032, 45.9291112038397, 55.19908789665469, 53.383320762265114, 54.9032509711481, 54.4905823276889, 54.957599332255704, 54.34647052518783, 53.678965491633264, 53.21166215404388, 52.16604455824822, 55.86111337907853, 52.899390497515284, 45.448350214189105, 40.907061407642985, 42.932514529074396, 41.57583728913338, 40.5300235748291, 40.150934342415106, 41.968784255366174, 42.630578317949855, 42.839185653194306, 47.113361051005704, 54.442952986686464, 55.79110299387286, 59.500578680346095, 47.06789293596822, 42.14028204641035, 54.403733207333474, 54.71886819408786, 54.330369195630475, 53.38279124229185, 54.26588935236777, 55.875653605307306, 48.73022087158696, 44.75736195041288, 47.95575280343333, 52.6052519582933, 63.18435891982048, 54.80870616051459, 46.03183415628249, 41.88688908853839, 45.035006923060266, 43.237255234872144, 42.392572818263886, 41.18240394899922, 39.71017368378178, 39.89590967855146, 44.414695847419004, 42.80212709980626, 45.13171688202889, 49.400993239495065, 50.86814403533936, 50.26609159285023, 51.602533325072265, 49.717265713599424, 51.495032925759595, 50.95220827287244, 54.812506937211566, 49.907112352309696, 56.613043508222034, 49.93588293752363, 46.37260575448313, 51.97490745975126, 49.09049057191419, 49.094691430368734, 52.903563899378625, 55.37557886492822, 54.406706363924094, 55.25759397014495, 60.90478720203523, 57.096028481760335, 54.21249020484186, 55.12998357895882, 55.701990665928015, 49.89219950091455, 45.456230255865286, 41.54161068700975, 48.83501483548073, 60.53501752115066, 58.20394900537307, 60.941626102693625, 55.16558693301294, 51.11548477603544, 51.91853123326456, 53.9720332237982, 62.576575894509595, 59.30836685242192, 81.38026160578575, 57.73478254195183, 54.385364747816524, 60.313580113072554, 66.29361783304523, 29.787891141829956, 0.2898004590984314, 0.3172554568417611, 1.2783714095430991, 1.437243458724791, 26.240017106456143, 47.96598234484273, 56.18334001110446, 66.01776538356658, 53.81684857030069, 48.240379594987445, 14.908286736857507, 26.720162283989694, 34.386760342505674, 22.46845618371041, 32.582109205184445, 53.00491009989093, 25.377866414285478, 0.14997542415174747, 0.13522072394769039, 0.055570072163977934, 0.04343900476552306, 0.04832739265815866, 0.019164338685391892, 0.08537263909895575, 0.044333519669429916, 0.02804359841731287, 0.10443079225238293, 0.040159263618050084, 0.061019872270164, 0.010855482166422712, 0.034863765111132976, 0.07600335314148858, 0.04410280846059323, 0.041907104708614855, 1.6597075471954963, 53.963427543640144, 61.900229838586625, 40.38113040308799, 43.916346949915734, 55.404208244815955, 94.37877670411142, 25.21106173915248, 58.59972792287027, 52.824065300726126, 54.53391275098247, 74.20408925702496, 59.908363972940755, 61.12784847136467, 0.8784698971336888, 3.5138766467571263, 0.9904907667829145, 4.506507679339379, 0.3058484995797757, 11.514183340534089, 73.10002834566178, 61.94874171287783, 49.286248222474136, 59.46268466211135, 60.480535799457186, 61.22964966681696, 62.38243033809047, 62.24462570682649, 62.331616032508116, 60.12475329060709, 60.75053215026856, 57.310072222063624, 53.49754018168296, 61.70735513010333, 53.0018820301179, 56.09800492563556, 65.9427853553526, 60.998127845025834, 62.83463255051644, 62.528118933400805, 57.62199086527671, 52.687292252817464, 43.17907471810618, 52.42046125473515, 61.74992461358348, 58.233068681532345, 53.50356101989747, 52.81687559620027, 52.8495293278848, 48.36747223331083, 57.2161824472489, 56.95478000948506, 58.23794418765653, 58.67402153630411, 56.98391145275485, 59.78003186564292, 55.21151396536059, 55.91462235296927, 56.609733027796594, 57.72352141718711, 56.083194055864894, 49.2530139800041, 45.40231335547663, 45.65091317699802, 45.176082811047955, 42.74956733949723, 43.77594178722751, 44.84436404320502, 44.03328457186299, 44.508118860183224, 49.115511371243386, 56.65211423750847, 59.887077270015595, 59.093617085487615, 47.90338916163291, 42.801530899540076, 55.16177831157562, 57.76809130945514, 55.8925433312693, 53.6595929053522, 56.43154759560862, 55.18417112288937, 49.86395059093353, 44.37570356553601, 47.14974887909428, 54.24489682720554, 64.82763590351229, 57.44321707756289, 48.340717746365456, 43.39109059303038, 45.454516180099986, 45.2704668045044, 47.193973602787146, 44.39769629509219, 42.90025695677727, 42.03165592685823, 48.545026163901056, 46.24991401549309, 47.951402894912235, 52.959881290312744, 53.398794512594904, 54.244402608563824, 54.202123380476436, 52.514727577086425, 54.17191328540925, 54.021655128848174, 59.243749726203184, 54.36013214049801, 58.05120014375257, 52.91316193919028, 48.94574726781538, 53.18885357149186, 50.70695031073786, 50.27053171588529, 54.99707406566989, 59.033965679907034, 56.21745678686327, 56.82225096610285, 61.25712979224421, 58.673405724187056, 56.75624924321329, 56.87893313746299, 58.03996255320888, 52.76115440553235, 45.233239589198945, 44.037720772527884, 50.69699141287035, 64.74720770312895, 60.10587492296773, 63.050194248076416, 57.38978262870543, 52.78809716624599, 54.40194852890507, 57.937871102363836, 64.99139878057665, 60.65474394829043, 79.9685456675868, 64.55045377054523, 54.19952677142236, 62.58703293338899, 67.91045804177561, 31.830194765521636, 0.397542298681313, 0.2751193339786222, 1.6225406383314442, 2.2794287964220974, 33.54044621990573, 55.65112144716325, 61.29702421926684, 72.92014844955938, 64.21391833213069, 53.225645403708185, 17.65326826803146, 24.713879746775476, 42.23318730631183, 29.150217694620935, 37.209647009449625, 63.71718937350858, 31.491896221714637, 0.10351376202438148, 0.08236394368953283, 0.04634335133877974, 0.1362313318156427, 0.0499625843498976, 0.0232029837676354, 0.06553565031818806, 0.18558233285382872, 0.07771689264524369, 0.26858726997048626, 0.12190931807121924, 0.20254796280735926, 0.08983573711086666, 0.12732584314841416, 0.15018072039369615, 0.13152059588220813, 0.17859153539663364, 3.205644541209744, 69.21218287560248, 70.37055292437154, 55.88930345350697, 44.20954019792619, 64.48695059745543, 93.91718433749293, 36.174655114450765, 64.31919082518547, 63.25300039783601, 56.31999146553778, 79.86726222499725, 63.76937258628107, 68.73198278488653, 1.79753914475441, 5.697365739653188, 3.7354817361600943, 12.33545607136142, 0.29569155266208036, 12.972008701293701, 77.12634917228453, 61.06554162117743, 53.473994193538545, 59.827884781745176, 61.85156891422888, 62.163746433873335, 64.63745586333737, 66.28006996647005, 65.43691335185882, 61.33388665414626, 64.81656305251583, 57.891159595981726, 55.610215048636164, 62.8217593316109, 60.086341519509595, 63.47956042135916, 63.35677454548498, 63.0451814589962, 65.99476460487612, 63.376311871313284, 58.579543405963534, 54.15825951483942, 43.79131747830299, 53.41187953948975, 62.06769151072349, 62.50404342528313, 54.54729587801042, 54.00388679196758, 55.52813945278045, 50.52279895351779, 61.33257266013854, 60.83519258806783, 61.691457763794936, 62.68706513989357, 59.281098534983975, 63.550331746378255, 58.10996117130403, 59.71591288043607, 58.05625607890468, 62.012868542825025, 59.99649570834253, 53.16267175059165, 48.345102956218106, 50.28862953186036, 48.540660565899266, 47.982997586650235, 46.53072826323971, 48.261650608431914, 48.157193968372965, 49.1048974375571, 54.998795986175544, 59.75591713382352, 62.06010172444006, 62.87094193120157, 48.97720467659735, 41.992581275201616, 57.42437008888491, 60.21264968379852, 58.768413374500895, 56.17560509712466, 58.992384633710316, 58.46764210731753, 52.139823513646284, 45.878065478417184, 47.887880109971576, 54.72390843975929, 68.43662046617078, 61.60376925622264, 53.07698757417741, 46.44231803955571, 50.10657272031231, 49.582693115357436, 49.881514964565156, 46.793001467181796, 47.796535953398674, 44.88419178993472, 52.3484936068135, 49.81353244473858, 54.740358860261985, 57.083402372175655, 56.55677710810016, 57.75967782543552, 57.53678521802349, 58.635809806085405, 58.892572079935384, 57.84320469825499, 62.8581432373293, 57.989787593964614, 64.14846574106525, 56.05481963003836, 49.747122795351096, 55.041192885368105, 53.27302763538977, 53.76626176218833, 55.390479949212846, 60.550726613690784, 58.0286818165933, 59.6233331772589, 64.18660294625067, 60.811591686741004, 56.991426714005016, 60.00879626120291, 59.17838734965171, 55.77455451411586, 48.109894106465006, 46.5808718435226, 53.19475281623102, 66.76318045585387, 60.6650205581419, 68.33372885181059, 60.095096249734205, 56.60694422260408, 56.32732629776002, 61.2615934495003, 66.58143351154943, 64.72805084720736, 77.73676410798105, 68.02049621458977, 60.027615793289684, 61.64398139522922, 70.42158296031337, 37.3712408158087, 0.5228581339601548, 1.7230787080141807, 3.21995874085734, 2.920714991707956, 33.578269635477376, 60.98004571853146, 66.97694963024509, 77.3133913163216, 65.4873550322748, 61.6048792869814, 22.977821057842625, 35.20629644393921, 50.47636985778809, 36.873374369836625, 50.792873751732614, 73.05622331557736, 44.74709318530175, 0.3587645520606349, 0.28890398300943837, 0.1816121587950376, 0.23140094843843292, 0.13140290945528016, 0.16199488403095355, 0.12312099337577821], [0.05069461583550419, 0.08254261837611276, 0.03634137251684743, 0.033654533627052466, 0.089606462316888, 0.0845151185809124, 0.020168710597640565, 0.01187087042302254, 0.03191296105092812, 0.03663997443753385, 0.26327944510886747, 38.69163613165579, 57.2839766933072, 38.91675272295552, 30.60422855038797, 31.641917074880293, 51.78284075952346, 24.850786155269994, 46.39582226353307, 68.95398109189927, 46.121793716184555, 69.53781020256781, 51.876020585336995, 69.29947914615755, 30.59977666024239, 1.629043928077144, 1.9901349972332678, 7.126087113734215, 0.15085628736884366, 5.331153648514902, 55.413672924041755, 45.31941406188473, 60.525517540593306, 64.54845336175734, 60.10998556690832, 62.90374471295265, 60.62400433324999, 57.412191129499874, 55.716483823714725, 56.38230616046537, 55.079663492018184, 51.85016432116109, 56.599264221806685, 57.859694342459406, 74.94594281719577, 78.97623308243291, 55.03167721533007, 58.07538547823506, 55.764658374171105, 58.588509944177446, 55.520000534672896, 56.53520407215242, 45.97906258798415, 54.71059199302427, 62.06431042763495, 58.263682780727265, 53.10054140706217, 49.05367128310665, 51.669821585378344, 43.42785889102567, 53.99885831340667, 57.81884285711474, 54.55369326376147, 55.59467069564327, 54.66461396986439, 55.661378445163855, 51.594210055566606, 54.95305722759616, 53.844583649789136, 54.91472782627229, 54.69968388157507, 45.98123165868944, 41.394270773856874, 42.58905218493554, 39.68290536634384, 40.76342813430294, 40.07446381353563, 43.69048510828326, 40.718316954951135, 46.525793921562936, 48.96781060003465, 52.788073632024954, 55.268855094909675, 57.32072537945163, 54.684182674654075, 45.78747441691738, 53.16949275232131, 56.49569011503651, 52.18913947382281, 49.349237565071356, 54.621428674267186, 54.25320048486033, 48.43740417111305, 43.38665046999532, 44.4036739872348, 50.98477963478335, 61.88055915217247, 56.628344674264234, 48.873206953848566, 43.46176778116534, 43.398743137236565, 41.50607401324857, 39.93995005084623, 37.73694299882458, 39.09316916619578, 41.202204073629076, 43.01137770375898, 42.05939885108702, 46.378944304681596, 53.055426305340184, 50.14108565545852, 51.46910213655042, 47.35510456946589, 51.29260332353654, 50.06998877371512, 53.85607227202385, 50.783114894743896, 52.06404724428731, 54.8928645349318, 47.572203836133404, 47.16015100479127, 52.82730910085863, 48.31613625249555, 48.892446179543775, 50.37418427005891, 52.32077421680574, 55.573325157165534, 56.18259083840155, 58.00382967918151, 58.01504765787433, 56.16605412575507, 58.792461426027366, 53.5180934013859, 49.423225233631754, 45.79715090413248, 42.82489253628639, 49.184823574558386, 59.12837712995468, 56.55739684258738, 61.00071268696939, 59.193759118357015, 59.307731428454005, 52.25211312693935, 55.17737365538075, 55.47294385971562, 64.95480306686895, 61.93535466347972, 80.90053219949046, 54.32272449616463, 58.130451633084206, 56.75795939660842, 15.2058946124969, 0.4932593157695186, 1.3818202456158977, 0.8568317130688698, 9.63716055116346, 54.529201984405525, 56.76341149114794, 58.98164518417851, 56.98965380268713, 35.421897365200905, 40.74159229955366, 24.410513831723122, 56.0202282474887, 35.04388286221412, 23.5551154998041, 34.5761598310163, 55.84046602249146, 14.071658907398103, 0.5869025328466969, 0.22717698477208617, 0.13565474340031225, 0.07897026611552124, 0.1139275782230881, 0.06481552766936441, 0.07638597575527045, 0.009101056550148754, 0.03849533596827138, 0.0553214728021093, 0.03374300146054837, 0.08897992496889445, 0.021275406958715572, 0.08992218247224247, 0.01703675738686035, 0.05470286829457168, 0.036489246638431665, 0.4997016555599628, 46.14254697676628, 66.1543030892649, 41.662988431992076, 40.114958363194624, 44.655282266678356, 60.382700120249105, 28.222571265312936, 49.31071596760904, 72.42524731543757, 47.99088547306676, 76.66914201551869, 56.618303406623106, 81.30102972830497, 32.96936481229721, 2.629514062596906, 0.3155739244914824, 6.271113378386344, 0.3658242055004643, 4.928556180769398, 62.355130641691154, 47.56003664385888, 65.30211325614684, 63.903521568544456, 60.60509458664925, 63.597662987247595, 62.670010674384336, 61.38163758862404, 58.17404485517933, 58.344138437701815, 56.00048303604127, 52.47132262875957, 58.893886073943115, 62.626240945631466, 71.88487806627828, 71.73360793821274, 57.909598658161784, 60.2970394780559, 57.98366085175545, 59.4844969626396, 57.81748571703511, 56.54994041688981, 50.55753154139365, 56.026143181708555, 63.141248149256555, 59.19672835257746, 57.02825384755289, 51.65382615981564, 55.36720460461032, 45.171281829957046, 54.255612742516306, 60.35465909588722, 56.221434070217995, 59.00205327618507, 55.884392646051225, 58.418569334091686, 56.364855535568736, 56.7858317590529, 55.80103051277899, 59.088980843943936, 58.79780369420206, 48.559382038731734, 45.302159555496715, 48.497553717705514, 42.29235626036122, 43.93418588945943, 42.35189783957697, 44.91068347807854, 42.39733065328291, 48.11977847929924, 52.35356130907613, 56.93776476767756, 56.81435131257581, 59.8444018825408, 54.32968278085032, 45.30315191515031, 50.34454291866672, 57.64307752732308, 55.59287817247453, 52.158219429754446, 58.87492925890031, 54.869506820555664, 48.3182268757974, 42.85730700339041, 44.48387076777797, 52.133331991011104, 64.40516133462229, 57.08057434328141, 51.07759860254104, 45.71697765781034, 45.610167595648, 43.673756199498335, 40.97726006661692, 40.935624107237786, 41.731720124521566, 45.3871573171308, 46.69762903644193, 45.49562654187603, 48.27605747407483, 55.731639862060554, 53.76885052650206, 54.74967056705106, 50.95502845702633, 53.49580257169662, 53.39223630966679, 56.751503175304784, 54.48047437975484, 54.8913348105646, 57.23375466562087, 52.19657628766952, 49.171063899993904, 55.1553770034544, 50.744252051076586, 50.85700058167981, 50.73621903696368, 55.03774512198664, 57.530301540128654, 58.88739062893776, 59.1292675079838, 60.446877941008545, 57.08455554900631, 60.20636996915264, 55.054615236097774, 51.72507993636593, 48.940048063955004, 44.26872091908609, 52.59275136455413, 62.595364047634995, 60.55539423419584, 61.33943288556991, 62.42920068002517, 63.06353422903246, 52.81074493162094, 57.60061002546742, 55.92650713459138, 68.59101280089348, 59.782369598265625, 80.70559040192636, 62.4547980677697, 59.69605784262381, 59.974895215803585, 17.934296284952474, 0.7193109633461122, 2.7516623081699496, 0.8045629435969938, 14.90224236442197, 64.16520249459052, 58.24145470896075, 69.10470993288102, 63.05956479041808, 40.21043669792914, 40.38455855461859, 26.526838464121667, 56.710620310998735, 51.12909932290354, 29.6600434472484, 42.37257657512542, 66.74503557143673, 17.342169400184385, 0.470925493225936, 0.24397272706752826, 0.09130432000083309, 0.06332468609475801, 0.028457314624721487, 0.0651052468005688, 0.0112256491481657, 0.14298045917624427, 0.10656777153452558, 0.13928276727036124, 0.2417807809768185, 0.16835056395540315, 0.14284971861108658, 0.16932177958228897, 0.13011339961761428, 0.18883043840046854, 0.1597311401799802, 0.5818757703227382, 60.92275557979461, 76.31142185580346, 54.0226435661316, 41.35065793991089, 49.97207072473342, 65.25937903311946, 34.14479324894567, 55.032653885502974, 82.95290454741448, 56.516717941530295, 81.54064732213175, 59.215041898912006, 84.31086832477202, 37.78279942850913, 3.1796747734469757, 4.399759884803526, 14.268990408989692, 0.28802420763719466, 6.149702783553831, 67.14121064832135, 51.92544244950818, 63.53948247048163, 63.53002955836635, 63.09863944207469, 66.52756367960285, 65.95008880861344, 63.808196206246656, 63.04363996751847, 60.80100520964592, 60.180223449583984, 53.50978189899076, 61.07434734221428, 64.032234145749, 74.85302186781361, 70.42148882342924, 60.86730895503875, 63.49969394745366, 59.50013545251662, 61.93158134337395, 61.438319759984175, 56.30739673491448, 50.646043746702134, 57.573730022676536, 65.63911937898206, 62.45294670904837, 58.96888179163779, 52.52179961050711, 57.19806501942297, 47.499353654922984, 57.229526350575114, 62.838417637732725, 61.403073341615745, 65.08803813688218, 61.61228079949657, 62.27619294197329, 60.02713726412866, 60.953146103889715, 60.88082544265255, 62.72810882137668, 61.82779935098464, 54.06078861605737, 47.62341822347334, 49.84810813780754, 45.07635262704665, 46.848754036811094, 45.77496990080803, 50.67937604842648, 45.545566158909956, 52.35825638617239, 54.13669432363203, 60.45612688987487, 60.592127230859575, 65.51242682241624, 55.47604253215175, 47.76086199668146, 53.98825222446073, 59.36320550980107, 57.065041757399044, 53.839539481747536, 60.465850445532034, 55.21350652940812, 49.76057652504214, 44.09245352591238, 45.96813878705425, 53.737330359797326, 67.58239884530344, 59.573742651170306, 54.17001093587568, 48.69527647572179, 49.306166018209154, 47.7401008913594, 44.337676186715406, 45.44376496345767, 45.18113874620007, 49.27109218412831, 52.787516655460486, 48.87452094785629, 53.15502312875564, 61.80699509959068, 59.39182312257829, 58.1996657771449, 53.59725075383341, 57.298520841906154, 56.43687417430263, 61.48178354386361, 58.5749150091602, 59.398620590086914, 60.73611351751513, 52.407164419851, 50.895435886998335, 59.97120034310126, 53.18525675804385, 53.22249966282999, 53.89717478905955, 57.525276983937914, 60.91300848991641, 60.22186333133329, 62.39800999241491, 62.83084746330016, 59.801342102789114, 65.20844705643194, 60.09130724014775, 53.9545786765314, 50.932286554767245, 47.21950038786858, 54.412229061126716, 62.221315060892415, 61.18694682275096, 65.83390820410945, 66.75859128275226, 65.32394909089612, 57.53975052987376, 59.954373375062026, 59.78034565525671, 69.7649311250256, 64.2111805177504, 78.86162142599784, 67.91322723511728, 61.227166806497884, 59.842613281742224, 20.61169635864996, 0.38013359411589565, 6.240044284251429, 1.265320213090989, 16.480083427121563, 69.49759806356123, 69.88591271062052, 69.80382534765428, 69.56072468911448, 48.785404697541274, 52.579285867752574, 33.10289406007336, 75.01365077111029, 53.245629879736136, 36.61695726456181, 52.889980731471894, 75.4479669755505, 27.269331370630574, 0.8387307714550727, 0.3536515586799191, 0.23855519841515252, 0.2180375711571786, 0.18874790008750655, 0.28248410491693404, 0.14602653201549284], [0.012624661678508406, 0.06197530648580963, 0.008966415639846556, 0.09891715020902696, 0.03577707981270167, 0.03511444057127641, 0.03454226482238981, 0.028328138794149124, 0.015390951546930499, 0.044789238562507015, 0.1393707601293441, 33.09677516260455, 59.9821476782522, 42.60100364685059, 27.65540046076621, 29.764441251754764, 52.232779764360004, 21.988128615963845, 51.54176796636274, 62.12423247675743, 64.70606204002135, 57.125442335682536, 63.338421775448715, 51.188385948058105, 56.4319908234381, 1.7140814037092271, 0.6031153435187956, 1.1906928304703006, 0.30426956172431674, 1.381291828809246, 40.826605750668435, 46.169360299264234, 62.20707685716691, 55.00395782532231, 62.02945232391358, 59.611311112680745, 59.35732587691277, 53.6161095096219, 52.43082415673041, 51.62232952733194, 51.7925407809596, 48.54977615417973, 52.78897577716459, 55.29274232925908, 66.23420176967498, 54.45634788082492, 56.81601439752887, 56.73321316319128, 57.332818046692886, 55.772071653796786, 58.22911885476882, 56.137762069702156, 47.66039440708776, 59.16568671503375, 59.65976807378954, 56.39943515100787, 52.30458267273442, 49.64976956767421, 53.71368631239861, 44.76385347304806, 50.39017969562162, 57.86345981782483, 52.3207232259935, 54.91930523226338, 51.97400923698179, 53.02742450468002, 53.175886215702185, 53.47968555265858, 51.9656349766639, 56.35181365474578, 53.289854603429, 45.916947933935354, 41.368241925393384, 41.08403482744771, 41.93959789891397, 39.53185096863778, 40.831312594875214, 42.08512175467707, 41.675543938913655, 49.63784556235037, 54.35111853384203, 52.88856475583969, 55.97489741540725, 57.32514589063583, 55.185704769626746, 48.98434731268114, 53.47156232403171, 56.523460495856504, 48.49234088774651, 51.70181243650375, 56.091466334558305, 49.55177699365924, 44.184248755055094, 45.24019395151446, 42.92314006436256, 53.57233585849885, 60.15354348767189, 54.86989121283255, 49.792214362852036, 41.6028545748803, 40.69613202925652, 39.495447451068515, 41.75847461146694, 40.24378861150434, 42.226680094195956, 39.605838637198175, 43.372957475723766, 41.544474017235544, 48.624148215017016, 55.55869471642279, 51.326343551758804, 50.481288509984175, 51.53553139778876, 49.16964400199152, 52.12687576970747, 52.80488098821333, 50.55759429931641, 51.24626836469097, 53.064906674046675, 45.41910894455449, 49.73822293743011, 50.930344981531945, 48.92145602933822, 52.42559171492054, 52.973860617606874, 56.62403398944486, 53.64632744942942, 56.98034601826822, 56.98512738750827, 58.585407349371145, 55.19328278879966, 56.886923005503995, 56.185469858108036, 54.948609259820756, 46.66253951288039, 41.51433452483147, 44.788176090486594, 59.617653585249386, 59.33489776426747, 61.47457814985707, 57.20145394725185, 59.60622379856726, 59.69954875207717, 55.09268576099027, 54.683755136305294, 58.37261484515283, 59.29750973178495, 70.42350492169781, 76.50484177374071, 48.74352162884128, 59.59892426767657, 10.91676223662592, 5.466752436853224, 0.4282244877709497, 0.1707513456142718, 31.27189243993452, 60.29290529989428, 59.852776142858694, 59.94964299663421, 54.413841155267534, 43.452103061060754, 63.921709599033484, 30.607274270826775, 40.96715211868286, 23.90546944833571, 19.307727929084532, 38.01071266974173, 53.941179860022764, 7.232707921535739, 0.3648672084654532, 0.09888459147224504, 0.03177926338638269, 0.12431177746264205, 0.11090697780732187, 0.03113691015319238, 0.02594257355667651, 0.029175880199839032, 0.0771433072945764, 0.06445080086949372, 0.005676544894794784, 0.04064568731513235, 0.07625440781515452, 0.04391035185225549, 0.008580334139086546, 0.1197538530874637, 0.07813810310777157, 0.13652193960883927, 38.27930873440158, 72.91955224929318, 45.34698832419611, 33.010110393647224, 40.371112669667895, 53.25562800130537, 26.290009675487397, 57.94580213485226, 70.73300346251457, 66.13901369033321, 62.3762486826989, 69.93205547332764, 56.39779560027584, 65.30627489089966, 4.423317640058456, 0.6197729754832484, 2.4288002521761003, 0.971166781119762, 1.6661931862754207, 44.68825763271701, 51.33542776107789, 61.79248232995311, 57.41829041511782, 64.61616523804204, 60.27418774943198, 60.23294794944025, 56.408715478835575, 55.97350889636625, 52.699200568660615, 53.81955108334942, 51.04002621866042, 56.917348830930656, 59.89246268426219, 63.341151745088645, 57.54148421748992, 60.35455711426274, 57.18916516150198, 59.76697037296911, 59.29073187612719, 60.28994391041418, 58.702819578109256, 50.33361519536665, 60.34451584662161, 62.611379085048554, 59.37311733922651, 55.652160875258915, 52.05464532298427, 56.65040800648352, 47.55938945278045, 51.477382259984175, 60.87365927234773, 55.89569691688784, 57.550666486063314, 53.78647373568628, 55.928048626069106, 55.17931915098622, 57.73668881385558, 55.29839054230721, 58.81557203108265, 55.65718543144965, 49.617374712421054, 43.630880771144746, 45.97857229171261, 44.0494212027519, 42.3448807193387, 44.79860959514495, 45.29791162860009, 43.754392285500806, 51.53731607621717, 56.57429441328972, 55.754083664186545, 58.22829515703263, 60.42993722423431, 55.37230368583433, 49.67655935595113, 52.64623680422383, 55.11984032969321, 47.73469978763212, 53.01482192931637, 55.47096698514877, 51.62236875103366, 43.32291195469518, 44.90239158753426, 43.13417534674368, 54.01089214509534, 62.17415248194049, 57.628855013078265, 53.96529459184217, 44.66212288025887, 43.50785170831988, 43.35512245855024, 42.302648559693374, 45.02836242798836, 43.37821737412484, 42.02239521088139, 44.478073504663286, 43.581870755841656, 52.3309527674029, 55.523067828147646, 54.61674536428144, 54.01162170594739, 53.123844208255896, 52.50523936363959, 54.9253535270691, 55.84096808587351, 52.95202478285759, 55.21835850131128, 53.876923591859885, 48.17708038514661, 53.617294065413944, 53.59930215343353, 49.92682226242558, 54.429562014918176, 55.405384955867646, 56.95278352306735, 58.09771160925589, 57.68272092265468, 59.609506822401485, 60.87007814838041, 58.39259147644044, 57.981782036442915, 58.91536497300672, 55.068559262060354, 51.47184387330086, 43.77615751758699, 48.01704375974594, 61.49340552668418, 61.91261276122063, 62.55686206202354, 62.18182071562737, 60.10736934600338, 62.43625310159499, 57.84049041809575, 58.48910531690044, 58.227726413357644, 67.21211925629648, 62.54702475763137, 80.22120906460671, 53.64550767406341, 62.579521594509, 11.004427209977182, 10.389351517923417, 1.0053784904941436, 0.3874937685266618, 39.19953207815848, 61.08855808934858, 66.91589401614281, 65.95065362991826, 60.40326510706256, 48.17969660605154, 67.62275218963623, 34.93347598660377, 46.82114447316816, 33.57761852202877, 22.854595876509144, 42.64027441701582, 65.82876989918371, 7.951974513069277, 0.2424880333485142, 0.16185755510964703, 0.015048961279042547, 0.09214792070129225, 0.04195064914623096, 0.0383209666958259, 0.00916738635785277, 0.19664501020264244, 0.20548978640187174, 0.10697929098481133, 0.24575694584317748, 0.3710255134970911, 0.19717201740751344, 0.15214573591947556, 0.09179669237064739, 0.22474879248728677, 0.2319351415480337, 0.2858455455110919, 47.98346827107091, 80.97424137976863, 59.36200526452834, 42.036225488108975, 44.4406384037387, 67.15678245790544, 31.07972375808224, 62.84917669911539, 76.22207026327811, 76.54164929543772, 68.56130476920836, 74.95290110188147, 61.58571850868964, 69.3056764910298, 8.024057870911014, 1.685715558067445, 3.7082492103499756, 1.1137329859118308, 1.9610963425328656, 55.162856963373, 51.70238118017874, 63.572579429995635, 61.54902473572762, 67.94219001646965, 63.979003660140506, 61.8262460923964, 58.84429554785452, 58.33034346180578, 54.29452265462568, 59.05165949175435, 52.55415524205854, 57.9452294688071, 61.50411751962478, 65.04604131944718, 59.58501554304554, 63.84357206283077, 59.5058621129682, 62.291898112143244, 60.244640534923924, 60.41936251424975, 59.230252850440245, 53.202307301182906, 60.277419782453975, 65.8068516946608, 59.1927706810736, 56.8635025332051, 56.232773642386164, 59.64956598897135, 48.81839183069045, 53.71542784475512, 63.958701472128595, 58.45883246391051, 61.615336325860795, 57.03665164209182, 58.22836968206591, 59.86755955603815, 62.644464277452045, 56.178393902317175, 62.51690879944832, 58.21619856742121, 52.81649512629355, 46.54325631357009, 48.60427356535389, 47.990646208486254, 44.808662629896595, 47.286678821809836, 48.41701569095735, 46.62536328838718, 58.33478750721101, 60.265264357289965, 58.092408564782914, 60.818130277818256, 61.29964436254194, 58.349578765130815, 51.53418994718983, 55.093611440350934, 61.95612361354213, 50.53234208014704, 55.623441280857215, 58.16385061510148, 52.26930487540461, 45.05526596500028, 44.65339952899564, 44.62201272287677, 56.887887908566384, 65.96402106746551, 60.5350685119629, 57.971015130319905, 47.29414701461793, 46.58581402993972, 46.510892837278305, 45.156706302396714, 46.801724818445024, 47.95856514284688, 45.423729496617476, 50.154390335083015, 48.96900692293721, 56.06921080620059, 59.575974479798354, 58.05509897970385, 57.46204837676018, 58.71373161192864, 54.558298126343765, 59.507333001782825, 59.83936163686938, 57.39870602084745, 59.615959121334946, 57.32511451167446, 49.63825741121846, 58.72476523922336, 55.15762059919296, 52.77968368222637, 57.34240039702385, 59.382856584364376, 59.82864572155861, 60.166067615632095, 61.019716570454264, 61.38401454494846, 60.988996567264685, 58.398584858063735, 60.3260140265188, 60.41134126724736, 58.087701720576135, 53.035936047953946, 45.342685484117084, 49.917208533133234, 64.96942566287133, 62.604118777859604, 62.670971655076556, 64.62370403351323, 64.12450398168257, 64.63039167465703, 59.8807151855961, 60.73113602976645, 61.00638835660873, 68.35212476791875, 66.21558620083717, 76.52821909996771, 57.21377411196309, 62.24988168285739, 13.756956361955213, 9.942286629830638, 2.4283148588672763, 0.49960776382396305, 43.55570462442214, 71.8170367517779, 72.57554469570037, 72.8343113007084, 68.20288642760246, 54.44461607163953, 77.75336357855028, 38.83192362323884, 57.13364793408302, 35.962180322216405, 34.26552380284956, 56.621637421269575, 77.05981792942171, 13.653735268500544, 0.5886833501919624, 0.31606281116124124, 0.172044210917046, 0.22801099405173333, 0.20533083847934203, 0.15471418358145222, 0.17201416494865573], [0.036090398282413526, 0.031830298248678446, 0.13321936521078312, 0.0638944793102001, 0.015026031309858927, 0.03224688920102293, 0.0633151980958158, 0.05997475980210209, 0.02945187678109975, 0.04195203959581353, 0.24957618525912686, 13.525949351249205, 63.27059615042902, 44.31211802267259, 41.84112287336781, 30.63007893100862, 56.461275239144605, 24.348881629205522, 53.10540514607584, 67.59622127779069, 60.66842517545147, 62.693266407136, 64.70362624814435, 58.04627364681613, 67.22751063685264, 15.101307553629722, 0.32853974810531067, 4.999992347532704, 1.6034139356305523, 0.1255125513360385, 34.60094136576499, 55.858595217427904, 52.72105993763093, 62.04100370407105, 59.21928982580862, 58.28948805409094, 52.28532383518835, 51.544756812434045, 51.62780123372232, 50.64931500342585, 49.363122755481356, 49.6963987042827, 49.734449617324344, 54.111806884888686, 55.17439265404978, 57.295932077592425, 53.89742582075058, 52.2977420591539, 57.78334540705527, 57.39597212883734, 58.4101793842931, 53.60608785383163, 50.86459036796324, 60.91746822480233, 60.52902021715718, 59.71739553636121, 52.46405447683027, 52.3726357952241, 54.33928866540232, 47.97030871914279, 47.08216644102528, 55.22171605017878, 53.98272952725811, 56.05197198929326, 51.810109076961396, 55.603476416680124, 54.978383971798806, 54.486597199593824, 53.59813720949235, 54.021333494494044, 52.41860597364364, 46.293260128267356, 42.49862194061279, 41.524571910981216, 42.28025967074979, 40.419765749285304, 43.805332106928674, 47.20933752675211, 51.01145567432527, 51.857314801985225, 55.14424139453519, 54.190893634673095, 55.25854318372665, 59.94915662273284, 56.611298053495354, 53.16657843128328, 53.67756520548175, 57.357172043092795, 49.837458902789706, 51.977264804224816, 56.90904909564603, 53.06391431439308, 44.478446129829656, 42.819342382492565, 44.89771612228886, 54.52606801063784, 55.225948287594704, 54.885145310432684, 50.60846744045135, 45.28760756215742, 41.31082234844085, 42.13148809248402, 42.2356427100397, 40.36042813331851, 40.71131552419355, 39.591953446788175, 42.136187091950454, 41.90885043913319, 49.13092628602059, 51.70151041400049, 51.85788354566021, 52.13764659820065, 53.7170164046749, 52.023082010207645, 52.1667270506582, 53.554253732004476, 51.900249065891394, 51.952200858823716, 49.57757049991239, 44.655050846838186, 47.483307238548036, 46.512516698529645, 52.74311934748004, 54.34195195474933, 55.18275514725716, 55.89790913366503, 62.55983914098432, 57.36518544535483, 55.8607917447244, 56.53647492008825, 55.253220527402824, 55.95150439969955, 56.22920036315919, 55.60894027833016, 53.067636643686605, 46.922043523480816, 42.06859288677093, 51.19251228147938, 57.58633259804019, 56.00618616227181, 60.611488050030125, 61.19356778360183, 61.27201518704815, 58.927045791379875, 58.955537888311575, 59.09304834181263, 61.46800817981843, 58.4208050850899, 74.23398556247835, 70.04985993908298, 51.4021158987476, 13.056622070650901, 14.0741741272711, 1.1378436727869896, 0.9744207548999018, 40.28486759431901, 65.24394058412122, 55.46259272483088, 57.760054372972064, 60.376157606801684, 60.434310666976444, 60.44710543847854, 36.47171189708095, 41.70808784423336, 28.9455033117725, 29.580609567703743, 42.653312375468595, 45.51688578820998, 1.0442581268087512, 0.10412458690904802, 0.11784905207253273, 0.058935569193694866, 0.031231232813649604, 0.03574847792004866, 0.035928964404569524, 0.09660065354358766, 0.0365220581842286, 0.03535200443659579, 0.10468995979716701, 0.053131181461315964, 0.025535936001688245, 0.061429905509876634, 0.058285857685991836, 0.0479499104943487, 0.004185604207563184, 0.10479977084023338, 0.32948298620120176, 18.49681123610466, 75.80783659412016, 45.74867040880265, 45.71430652372299, 41.868693213309015, 61.416052464515936, 26.897418114446825, 62.906357011487415, 73.36550220366448, 67.21016591595065, 65.63786029815674, 71.31331028476839, 60.19691705703736, 78.0747704352102, 17.79612098970721, 0.2588821617105315, 2.8444574965584666, 3.004016818538789, 0.6431000463424191, 37.545390129089355, 61.04911865726594, 55.41719129008632, 67.80113374033283, 61.679200357006444, 62.375558345548576, 54.93353951361872, 53.77590687044206, 54.1008517049974, 54.05509725693734, 51.615677187519694, 52.99737914916008, 50.69322201513475, 58.026795156540416, 57.21824169158936, 58.11191451164984, 54.83136177062989, 54.24115096369098, 59.95820945309055, 61.12968806297549, 60.79573354413433, 55.760928200137236, 52.64551508811213, 63.06944131851197, 61.56139196888093, 61.09971723248882, 57.75442577177479, 54.00669913138113, 55.19898591503021, 50.3194397495639, 49.00345710016067, 56.12330029087683, 55.94263984311012, 56.700171116859686, 53.802653512647076, 58.43389403435492, 54.350259534774295, 57.216974766023704, 56.82363556277368, 56.72348176279376, 56.414544120911636, 49.971760857489805, 44.03019766653738, 45.17022279001052, 44.765198846017164, 42.12371395480248, 46.22750159232847, 49.92593972913681, 51.5490282735517, 54.6271082662767, 55.85799901716171, 55.08707284927369, 56.90976296701739, 60.81573370964297, 57.661677406680205, 55.066668679637296, 52.52635740464734, 57.84271440198345, 51.83065837429416, 50.714124325783025, 59.806774585477775, 52.51931675018803, 44.2792328711479, 44.501623415177875, 45.146021766047326, 54.77762922163933, 58.081602434958185, 56.016533374786384, 53.986569527656805, 48.58399491156302, 44.06387905920706, 44.149892714715776, 43.66243623918103, 42.08563950753982, 42.07875967025757, 41.877518546196725, 43.18511516817155, 44.44911464568108, 52.467059012382265, 53.85090651050691, 54.14405269007529, 54.26355946448542, 56.339972019195564, 54.83799842096145, 53.93268008385935, 57.21059699212351, 53.874856502779075, 54.26887819843908, 52.142569172766905, 47.76175629708075, 52.972162231322265, 49.58363056182862, 55.6889997759173, 54.9230863971095, 58.92186041801207, 58.01257656466577, 64.01569351073235, 60.05570780846381, 57.344679294093964, 59.34159717252178, 57.49348225132112, 57.13973545259046, 59.37668277371315, 57.83686614805653, 56.31095432466077, 49.82242053554904, 45.337817822733236, 54.29868428937851, 61.56735004917268, 59.88815592181299, 62.15509368527321, 62.90629425356465, 63.13300332715435, 62.09044518009309, 61.211493015289314, 62.60269887985722, 64.43118233834544, 62.997834528646166, 68.64486694335938, 73.48046687341505, 52.93144802893362, 21.323826197654974, 17.403223053101573, 0.6281393910607984, 3.1082199754253512, 48.01727517958611, 72.10915134799096, 64.92034896727532, 61.44354827942387, 66.87841969151651, 63.04976278735746, 69.21288105749315, 41.74791951333323, 48.7880366079269, 39.79874864701302, 32.39635555974899, 47.11650286951373, 55.79581768281999, 1.0401631723488531, 0.08372843055234802, 0.189858972725849, 0.006367791295727536, 0.03385575811168359, 0.021523644344039985, 0.028360973322583784, 0.045327484277227235, 0.09926561296226517, 0.0999784654366874, 0.20426845838946683, 0.16590654429408813, 0.12558952018979097, 0.24640646582889944, 0.11638904936731824, 0.146778600530759, 0.14459416210170717, 0.21465429705717873, 0.4157243536845331, 24.532742731032837, 86.17463742533039, 56.97634520069246, 56.63836240768433, 45.91966221409459, 70.36992534514397, 32.885800676961104, 68.26584046886813, 80.08634228860178, 72.61849464908724, 71.39565652416599, 75.51568277420537, 66.7500562052573, 82.38461586736864, 21.159320031442952, 0.3484030290236396, 10.325088385612736, 5.540411116615419, 0.6618731841444969, 46.04113409596105, 59.12127371757262, 58.13370327795706, 67.33355583683138, 64.40040742197345, 64.33809272704586, 59.20905636202905, 57.879286581470126, 57.33696006959485, 56.5767772736088, 54.67769899675923, 55.82185437602382, 53.99819543284755, 61.09679898908062, 60.79377235904817, 59.52836082827661, 56.55329404338714, 57.47475293374831, 61.11192757083524, 61.75460400119905, 64.42402009041079, 58.66572964575983, 54.150661883815644, 65.5687795146819, 65.18508149731544, 64.79053028168218, 58.68440405015023, 56.4471782407453, 59.386676972912205, 52.6444560481656, 52.344116241701194, 61.46576850645004, 59.38491975107501, 60.65848981180499, 56.8415411826103, 62.41650396777738, 60.83486310897335, 60.89959398392708, 60.174873336668945, 59.69845833316926, 58.83975736556515, 53.7762402719067, 46.65647160622382, 46.87209606170655, 49.66141900708599, 47.667160495635, 47.90267529026155, 53.90437233832575, 55.29716676281345, 57.57996659125052, 61.414318776899776, 59.6804311198573, 61.557485288189305, 65.54648868499264, 62.482725343396595, 57.05649099042339, 53.678333990035526, 61.8813750051683, 51.59072699085359, 53.85473474379509, 63.39762210845948, 57.190800789863836, 45.14476268522201, 44.02894250808224, 45.820798873901374, 58.68596907584899, 61.16305174366121, 59.782193091607866, 56.62466156867243, 52.18022784879131, 48.50817157376198, 46.553572147123276, 48.65285996467837, 44.5015057440727, 46.353594026257916, 43.84472447056925, 48.19223250112226, 47.63371444517567, 54.67728714789114, 55.93298296774588, 57.52644585024927, 57.71424501172958, 60.42171985872331, 58.069031238555915, 58.870547971417835, 58.48988194619456, 58.794524592738, 58.96186074902935, 54.082981386492335, 49.670962133715236, 54.140228379157286, 52.075355437494096, 58.352249899218165, 57.977008511943204, 60.866869649579456, 60.42108443475539, 64.61256450222385, 62.40848664314517, 58.737838499007694, 62.1422440005887, 58.60786684097783, 59.82129519985568, 64.20525381642004, 61.97659446347145, 59.1603954376713, 50.78706472150741, 47.28862039504513, 58.81238706650273, 62.867851103505785, 62.333843938765995, 65.15052541609734, 66.13645630498087, 66.39078278695384, 67.1540524882655, 63.563754097107925, 66.77196656503986, 67.79376752914922, 65.55097587646978, 67.87861624071675, 67.80868822528471, 60.13991717369326, 21.99755799385809, 21.352192778741163, 1.8729627685200785, 2.4079084828976662, 49.41168169821463, 75.5206798738049, 67.92167602046844, 67.09426772209906, 70.20486416355257, 72.15055588752993, 75.83625808838876, 48.1738365850141, 57.98995233351185, 46.37339415088777, 48.226619920422955, 57.66650192199215, 68.85377237873693, 2.9517742799174402, 0.3027186320433694, 0.3743884556235806, 0.10808092541992666, 0.2327398556254564, 0.13875686323210118, 0.14047489201109256, 0.16273176868356046], [0.023199078634441383, 0.04693069562856709, 0.015180924712049385, 0.026695007878926494, 0.06872973134440762, 0.10446795517758978, 0.02082165882682368, 0.020053544599983483, 0.027765768970693314, 0.040137437773087335, 0.1733851252544311, 3.642301665198419, 58.79634849486813, 44.24985824092742, 37.45097867904171, 24.480657577514652, 55.654553521064024, 23.222070970842918, 35.59552892561882, 67.01300405686902, 61.069224726769235, 60.92872542719687, 62.18915947021977, 59.08997712596771, 66.51077593526533, 30.72908739889822, 1.0935476109866173, 0.3248727916469497, 0.8591657071824997, 0.20859215138179643, 33.134492674181544, 55.412711943349535, 50.31528595955142, 64.32301905847365, 55.91246112700432, 60.07904198861892, 56.4464565246336, 61.59405354530581, 56.157036596728915, 55.21857423167075, 53.428922237888465, 50.435843929167724, 47.85248856390677, 49.63306811548049, 49.71549280228154, 50.314454417074884, 50.09977133043351, 53.22887743673017, 56.26178349218061, 57.6039283506332, 58.20148183453468, 50.09428001219227, 50.528713887737645, 58.800164961045795, 62.46263888574416, 58.18489413107596, 59.60004998791603, 53.26064471275576, 53.30864667892457, 52.6916656955596, 44.13448172230875, 51.591197675274266, 58.43571401411488, 51.736141020251864, 54.16780656383884, 55.90956641781715, 54.30577985702023, 54.741104110594726, 53.30310436987108, 51.30717100635652, 49.47238429900139, 46.49708609427176, 41.12377628203362, 41.4733261446799, 41.38427265228764, 42.17087261138424, 47.57605560364262, 49.73114698163925, 54.26476363212832, 53.194286054180516, 52.16244382243003, 53.62653909191009, 53.9785365135439, 58.26367493598693, 58.50864264272875, 54.78575637263637, 52.88756455144575, 54.34595277232509, 49.76722494248421, 51.829277699993504, 55.05694512398013, 51.756486354335664, 46.983459995638945, 44.99509680655695, 51.37293346466557, 54.51566588494086, 56.752554370510964, 52.33081940681704, 52.41689582024851, 49.13841409067954, 46.61303527893559, 40.631938519016394, 39.815661907196045, 40.82602916225311, 40.698042223530436, 40.53710345299014, 41.66545952520063, 40.33569366701188, 47.792005615849654, 52.18823340631301, 52.06343535454043, 52.30415905675581, 51.00079074982674, 51.34144859929239, 51.80230748268866, 52.151355281952895, 51.17031558867424, 53.162726663774066, 46.87508883014802, 46.28405432547293, 50.02103367159444, 51.965944843907515, 56.63127076241278, 58.78810367276592, 57.68683941133561, 66.39643100000197, 63.77791943088655, 54.706791216327304, 59.87508266202865, 53.19811036509853, 49.93471014884211, 51.9862078082177, 59.749606040216264, 59.15628479373071, 55.741857636359434, 52.84215919433102, 44.74100958916449, 42.34752831920501, 54.04219658144059, 58.70942877184961, 59.823342677085634, 59.25788987067438, 62.517348104907626, 62.184750726146085, 60.539249758566584, 59.78348355139456, 62.056049916052054, 65.34357663123839, 61.35120391845704, 71.68109524634578, 31.62244642934492, 22.793767759876868, 10.81796165435545, 0.5182581130535372, 12.349934520259982, 48.41613315766858, 48.02586517026348, 47.02565293158255, 58.270774425998816, 56.37633239069293, 57.34271810900781, 60.20973928513066, 36.64003256828555, 40.147549336956395, 22.27239847183228, 27.50893915853193, 38.78728705067789, 32.654231786727905, 0.21954814332627484, 0.047026330214594646, 0.018995387569790887, 0.0362488750608698, 0.14611253304587257, 0.05206150821440163, 0.04433220965907939, 0.048434292567112756, 0.0420938884358733, 0.06524225396494712, 0.11294902347388769, 0.032443904032510136, 0.0376824094283004, 0.0985237410772712, 0.02130866858116802, 0.01937159228198711, 0.013742275750114313, 0.06915502505557192, 0.18155228136287582, 5.358405295879611, 72.76865082402384, 46.99737264264015, 39.96303712168048, 39.015749423734604, 63.3922210047322, 28.23417167509756, 40.652068122740715, 75.3677466607863, 66.0355023414858, 65.74546660146406, 67.23971705282888, 65.45867466157483, 71.19210120170348, 37.37967391167918, 1.125334131140863, 2.4012796773064524, 2.3589465166291883, 0.5334002392426614, 36.03544235229492, 60.374941672048266, 52.617599579595755, 66.21389958166307, 58.38540569428475, 64.81521767954673, 59.286982090242454, 62.737455829497314, 56.36066252185453, 57.989999401953916, 54.74696413163216, 54.73565986079555, 48.72671035028274, 53.167347215837054, 51.89747595017957, 51.33382743404758, 51.95091824377737, 55.269604267612586, 57.60339490828976, 61.73972645113545, 58.881773794851, 53.54269450710666, 50.314222997234715, 60.20991579178841, 63.118565082550056, 60.12533380139259, 59.37575709435248, 56.7890324131135, 53.58086309125347, 55.06016931226177, 43.881614362039876, 54.0182230549474, 58.934466915745894, 56.53657297934256, 56.12812872855894, 59.70085097897438, 56.592435375336684, 58.55460497640795, 55.8185988087808, 55.61953067779542, 51.90232792208272, 49.255767483865064, 44.09412445560579, 44.68319777519473, 42.99588041920816, 44.88414079912248, 50.174088478088386, 53.32455973471365, 56.24990655529884, 57.196684345122314, 55.31311511993409, 56.1193230075221, 56.28548637513192, 58.716406668386156, 61.5691896407835, 56.732903295947665, 52.65406977745795, 56.92660170216715, 48.37445405221755, 52.380041230109434, 57.38862945187477, 51.01409150708107, 46.74032795813776, 43.562188302316976, 49.58807460723385, 57.5193424378672, 61.110852841408025, 54.13347798009073, 54.67848739316387, 51.41827606385755, 47.5600915570413, 43.826709024367794, 42.806951615118216, 42.68517771074849, 44.14462497157436, 44.050307658410844, 42.203185096863784, 43.79096446498748, 51.38329244429066, 55.76618809853831, 55.10401356604792, 55.91388886974704, 54.32847861320742, 54.03945876706032, 53.73491417977118, 55.38554560753607, 54.43409627483737, 56.2042893901948, 47.857328768699404, 48.81343787716281, 50.64629870076334, 53.770544990416504, 57.549678048779896, 60.8893762096282, 57.143006709314164, 66.48854394112864, 64.88547909644343, 57.416038974638916, 60.36120160933464, 52.68525262032786, 51.67579535515078, 51.95991223858249, 61.88368920356997, 62.77720512882356, 57.400784877038774, 55.9226789013032, 48.43614901265791, 44.71867561340333, 55.539863417225504, 62.964568907214755, 60.71337161525604, 62.19238365850141, 64.35891266792052, 64.81235434932094, 61.39449511804889, 62.423572078827895, 63.69452984102311, 70.77055623454433, 60.52964779638476, 71.57275153744605, 34.69400352047336, 25.816316796887307, 9.415971232998757, 0.38356208272518655, 20.799269983845374, 51.42670915972803, 58.19239370284542, 52.159078428822184, 63.91922281634424, 62.22367240536598, 65.82508287122174, 65.66355966752576, 39.05727555674892, 46.36341171879923, 36.17347840339907, 31.971609938529234, 47.532603586873705, 39.31228453113187, 0.3454210471001364, 0.04016763312862285, 0.05046947408587702, 0.054913691860894044, 0.02859817904179856, 0.04385733473745566, 0.05760089464245304, 0.050717429933889266, 0.14410460127457497, 0.2940055770018409, 0.25026088400233176, 0.1178747466615131, 0.1822126491536056, 0.17630218888723082, 0.1036154218919335, 0.15883771312092582, 0.12309232636565164, 0.22865176531336, 0.4092659566911959, 8.141754471486616, 84.53658503870811, 59.33329743723716, 54.985761950092936, 35.627884557170255, 76.77144527435303, 33.016131231861735, 48.33295929816462, 79.10145082781392, 72.87454697393602, 70.96260332292127, 72.61157558810326, 69.99002810447448, 76.8754743760632, 41.3707757765247, 1.797186621735173, 4.46127784828986, 3.5938265631275796, 0.6475979017634547, 40.82921020446285, 60.68177692351803, 56.82509860684795, 70.25736116593885, 62.24568866914319, 67.13463675591254, 61.434593508320475, 64.73040426931074, 60.76089897463399, 58.95454552865798, 58.417804471908084, 58.1674042824776, 54.81399743787704, 53.765269402534734, 53.525800858774495, 55.56315445130872, 54.66508073191489, 55.531159677813136, 61.17349309305991, 64.12713196969801, 61.47912417688678, 54.03002938916607, 52.57337877827307, 60.51579006256596, 66.24228185222995, 61.160470824087824, 63.54708794624575, 58.36325606992168, 57.59591887074133, 56.43996500199842, 46.5383808074459, 55.743532488423014, 62.32392034223003, 58.310661008281095, 59.204831969353464, 62.420434182690045, 60.916558234922356, 62.14316967994937, 60.465826911311, 56.95798850828602, 55.153815900125814, 53.004470794431626, 46.58262514298963, 48.11642485280191, 44.813671496606645, 49.41599630540418, 52.855338358110004, 55.731337839557284, 60.352639075248476, 61.07057402210852, 56.88792713226811, 57.7080790458187, 57.3856915966157, 64.2678979904421, 63.16883810104863, 58.46450421117968, 55.921239391449966, 58.992976911606334, 50.742094747481815, 53.95559064803585, 58.270703823335715, 54.899136404837336, 46.90090587062221, 46.22290457448652, 52.553700247118556, 62.28170779443557, 62.414413344475534, 58.125548670368815, 56.737967075840125, 55.7613165147843, 51.01739806513633, 48.4515090142527, 44.262798140125895, 45.11942809627902, 45.629108721210116, 46.478266562184984, 45.021866982983006, 46.264877857700476, 54.95207271268291, 60.179293847853145, 57.46590406663957, 58.96577919683149, 56.52535500064973, 58.066928848143554, 57.759163994942945, 59.01769568843227, 57.22186203925841, 57.956737702892674, 51.375620288233605, 49.89921662115282, 55.11758104447396, 57.64190866101173, 59.510368916296194, 60.57357049757435, 59.836870931809955, 65.02599408549648, 67.1918406025056, 58.89415279511483, 62.87472701841786, 57.0199501898981, 50.849383338805175, 53.797836842075476, 62.54868784258443, 64.39475136418497, 58.87514498925979, 57.00920681799612, 49.99975481340962, 48.9287987063008, 58.882420985929436, 65.52048729312035, 64.34712986792287, 64.19974680869811, 65.57436889217746, 67.51716982933783, 64.75648410858648, 65.43992180978098, 64.6184519798525, 73.10049903008246, 62.52124301848873, 72.4919903662897, 45.274067540322584, 33.4667605738486, 14.309913477590008, 0.46748539072371303, 20.145020600288145, 58.494930036606334, 63.035363766454886, 57.31870535881289, 69.24950030542189, 69.826535870952, 70.73151296184909, 72.37972428721767, 47.44249105453492, 54.40723196152718, 36.86130131444624, 44.1941370502595, 58.62298365562194, 56.21325985077889, 0.8494693016813648, 0.17272313335730186, 0.11469515235794168, 0.19771715025267295, 0.226123629197959, 0.13841512673083814, 0.19447615400197046, 0.12824802914814604], [0.06280724349762164, 0.1415718379881113, 0.011000113820867434, 0.04941447142271265, 0.02626383827338296, 0.046267822730324926, 0.05606529438087056, 0.08970225395094003, 0.08397914048644804, 0.05761768345931365, 0.0591373490920711, 0.10922398222910781, 45.873676346194365, 53.34214764256632, 47.41483834482009, 23.544938910392023, 50.0168877263223, 27.5990967981277, 26.32043550091405, 70.2382121547576, 58.587066511954035, 66.81017829525855, 61.404179450004335, 58.36787662198467, 57.48923824679468, 52.00243465362057, 0.650412570084295, 1.5604835940945534, 1.3232254285004832, 2.817226686785298, 39.820580559392134, 52.29513760535948, 52.89960230550459, 62.64438975241877, 66.13535019659227, 61.23381522393996, 62.63273639063682, 59.37221519408688, 59.14351355644965, 57.26489044004872, 57.01423529655703, 51.3682109309781, 49.48579096025037, 46.215428536938084, 48.50609663994082, 49.510184180352, 50.24058834198983, 52.903528598047075, 59.53074955171155, 59.68685988456973, 59.61737509696715, 43.57619116383214, 48.922946530003706, 53.51678725211851, 56.877972156770774, 60.21687015410393, 61.94768659530148, 58.656292423125244, 51.446983891148726, 50.81149716531077, 44.184409572232155, 49.005814444634225, 55.45283779021233, 53.087515215719904, 53.00855790415118, 54.07738808662661, 54.45974465339415, 54.19862070391255, 53.486079016039454, 52.358734915333415, 50.29224595715923, 43.82639131238384, 39.630459354769805, 43.173320601063395, 41.34586088119015, 48.17158514453519, 51.044297679778076, 53.37463271233344, 55.49005716077743, 54.51621893913516, 54.958560312947924, 54.34783158763763, 57.375375763062515, 55.88696964325444, 56.796849696866936, 53.89123632061867, 54.16560611417217, 55.53607440763905, 48.688757496495406, 49.154538954457934, 56.227188187260786, 50.238646768754535, 48.77916028422695, 47.94589980956047, 51.8619785001201, 58.42327225592829, 58.09387945359754, 54.69662051047049, 54.77176920060189, 54.31225176780455, 49.84466821916642, 44.58848822501398, 40.72709521939678, 39.256033820490686, 39.49723997423726, 39.872477439142045, 41.55379749113514, 39.211232508382494, 44.81756641018776, 52.58838968892252, 50.987752791373964, 51.769747887888265, 51.41743667664067, 49.26956638213127, 53.41712767078031, 51.34582204203452, 53.91250341169296, 51.60933471495106, 43.198992513841205, 47.619017324139996, 49.25512813752698, 52.057065425380586, 61.556379179800714, 48.34142769536665, 58.10956108954645, 59.53652720297537, 43.35325541034822, 55.55801222401281, 51.08283888909125, 57.13603665751796, 52.84317116583548, 51.144176913845925, 43.893397162037516, 47.32121136880691, 58.699736595153816, 57.65920239110147, 49.8457625604445, 45.09169693916075, 45.88535716456752, 52.48308973927652, 59.361091352278194, 60.14389837941816, 57.95649843831217, 58.149494740270804, 65.92945714150706, 61.61907434463502, 64.82612579099595, 60.76082837197089, 62.313894764069595, 52.28509633771835, 12.348417543595838, 10.259949584161083, 0.5670942570413313, 1.6163508930513937, 37.189964555924945, 72.53775658146029, 45.689297491504306, 65.39493222390452, 57.39911394734537, 56.77054236012121, 64.70494808689241, 52.02798105055287, 36.24988225198562, 39.501028983823716, 21.5282150237791, 23.01744680250845, 43.472409171442834, 18.634555070630967, 0.11249063476439446, 0.1768831133602127, 0.011649802345932733, 0.031357443883955, 0.06104309622558856, 0.07184819949250068, 0.027430687858272466, 0.05141710569601386, 0.02596709794635254, 0.0960279108896371, 0.05078666513004611, 0.059956285591808066, 0.02496659286290167, 0.06678179191846041, 0.09529018354031349, 0.02963663037535885, 0.039094209881319154, 0.062014296530715884, 0.08843375790503719, 0.4493005471604486, 51.608883642381244, 63.921799813547445, 36.50708775366507, 35.56132193534605, 61.846728709436235, 33.32829698439568, 35.83567603941887, 76.40051457189745, 65.26964387586041, 73.51150851095878, 66.297391153151, 63.25703259437316, 64.58448817653041, 59.6715194948258, 1.1292500048875809, 1.8540730014924083, 1.9390605894788622, 3.261724138452161, 43.884595363370835, 56.144967463708696, 55.01346172824983, 66.19256188792568, 66.71938327050978, 64.40112129334481, 65.3168103771825, 62.17202655730709, 62.17098320684126, 59.24076088013188, 59.55947699085359, 53.84771370118665, 52.240016537327925, 49.937122406498084, 52.43709210426577, 51.04703549415835, 52.97132284410539, 56.17682495424825, 61.672744135702814, 61.50395670244771, 58.604058219540505, 44.86147734426683, 49.564677669155984, 53.317817180387436, 59.436679347868896, 60.82408443573983, 63.36110876452539, 57.55798170643469, 52.47003216897288, 53.289866370539514, 47.31987384057815, 50.195841943064046, 58.24955440336659, 56.46097713901151, 55.66436336886499, 57.69626094448952, 57.35758781433106, 57.954717682253936, 57.218167166556086, 54.119796752929695, 53.94379215855753, 47.704289651686146, 42.877624880883005, 46.206587514569684, 42.63577938079835, 50.33014782013432, 52.92006531069356, 55.811887633415964, 56.17876260511337, 54.9693311414411, 57.90826897467337, 56.9725993371779, 57.10820744114538, 57.4414873123169, 59.3700735799728, 57.00961866686421, 55.26282248958465, 57.46074614986297, 50.27607402493877, 50.99880603051955, 56.872731870220555, 52.126718874900575, 48.411908764992994, 49.250291855104514, 51.06130507684524, 57.36966086972145, 59.73474025726319, 56.65771145974436, 57.71763001718829, 56.60759533605268, 54.64930495908184, 46.42369070360738, 44.20379784799392, 41.27122602155132, 41.5350014932694, 42.56578076270319, 44.081827825115575, 41.96729767707087, 48.281689997642275, 53.60573091814595, 54.357892467129616, 54.783932470506244, 54.91242539498114, 55.42094499834123, 54.61392910249772, 53.817735025959635, 57.418462999405406, 53.73612226978425, 45.16269576164984, 50.74529540154242, 50.17481803894044, 53.80596399307252, 60.45655442822365, 51.2557565781378, 57.39815296665315, 61.31083880701373, 45.53304203094975, 57.24283103019961, 53.72733616059827, 58.04939977584347, 55.14091914699924, 53.40449371645528, 43.910479084137954, 50.41734603143508, 60.171790353713504, 59.76294994354249, 51.93711150077082, 46.555101871490486, 47.39745047784621, 58.26351019643969, 60.079461682227354, 63.281982791039255, 59.713837946614916, 61.375957996614524, 66.43085372063422, 65.51910269644954, 64.90368281641315, 64.56853589703961, 62.61127710342408, 52.01472736174061, 11.553469800180006, 11.006734544231046, 0.8711215204769566, 3.056637130437359, 41.917114873086255, 70.28740652145879, 50.74676236798687, 64.89686181468349, 63.508609494855335, 64.38826768629013, 69.7794125157018, 59.571000914419855, 40.44310777418075, 50.296125181259654, 28.4134102636768, 21.239230478963545, 58.269009359421275, 23.17109977045367, 0.18131614242109562, 0.05130545604192922, 0.04145179950301686, 0.08830362254933966, 0.011785355858474731, 0.02249082460278465, 0.018653409750831705, 0.02817806791544201, 0.14976101146349985, 0.20643124717377848, 0.06005806803342797, 0.14513135827597112, 0.10039219888107431, 0.13212222005090407, 0.14127304837588342, 0.13005179082674365, 0.18477205697807575, 0.27747208192463846, 0.1890323485337919, 0.7567327649843308, 65.74345050319549, 69.48414433387019, 66.17296572654479, 36.04584055562174, 67.3998046690418, 40.24037614945443, 37.40054484336607, 84.87539152945243, 70.00991452124812, 78.23089645754906, 72.32455222837388, 67.88234249238046, 67.77137079546529, 66.00503336998725, 1.77013109287908, 3.9513623714447026, 4.361354487557565, 3.6947964612514745, 47.4874924075219, 58.4323956889491, 56.235856625341604, 67.6666513566048, 69.07237391318046, 66.66890236639208, 69.20702888119605, 64.90716195875599, 64.21004695277061, 61.9907699092742, 61.63474029110324, 57.070140838623054, 55.87498680237801, 51.08948338416315, 54.251404039321415, 53.75628717484013, 54.4950734415362, 57.70005387644614, 63.84406235910232, 64.98180858550533, 62.19768670297439, 45.81184410279798, 49.610345825072265, 53.12519742596535, 59.80331113261562, 63.212270505966686, 65.21013367560603, 61.4900872015184, 56.40348695939588, 55.79014985792099, 48.765239792485396, 52.48274457070136, 61.47890452415713, 60.82289987994779, 58.12475242922383, 58.91581212320636, 60.249947501767075, 61.606079532254135, 60.30579813065068, 57.502990076618815, 57.08395150399978, 51.756180409462225, 44.36735676180932, 50.845072653985795, 46.12620246025824, 55.73961796299104, 57.027975359270656, 60.487599988137525, 60.59282933512042, 60.02717256546021, 61.18174183753229, 59.29688607492755, 62.045561498211285, 61.67308930427798, 61.47812789486301, 59.87017969931326, 57.83948236896146, 59.62540418870988, 51.29037933964884, 52.60194147786787, 61.227488440852014, 54.1251939342868, 51.442528078632975, 48.423566049145116, 53.652771903622536, 61.70562928722751, 63.978615345493445, 60.77048132496496, 61.971146291302105, 59.195841896918516, 59.81967526097452, 50.654190509550034, 44.7572599687884, 44.535355798659786, 44.559815699054354, 44.38774916433519, 47.4665234165807, 43.78927392344321, 50.74577785307362, 56.06258984534971, 55.870432930607954, 58.07428329221664, 58.135303604987364, 56.63218075229276, 58.11184390898674, 59.268903886118245, 61.22158135137251, 55.60715952227193, 47.250761678141934, 53.15261087109966, 52.03005206200385, 55.93777610409645, 62.77096856024958, 55.98272646627119, 59.061422271113244, 63.29825278251403, 49.77673669015208, 56.396305099610366, 55.272012602898386, 60.222639960627404, 55.96872360475602, 53.4737745408089, 45.007962180722146, 52.46875739866688, 63.57382282134026, 61.69343071599161, 54.75400478609147, 49.08003745540496, 50.24466368459886, 61.6505592100082, 63.751561103328584, 65.06531584647395, 61.82324155684441, 66.5435669499059, 71.17471725709977, 66.408951205592, 68.23868982253536, 68.61710440727973, 64.83201326862459, 57.448829989279474, 26.9697230862033, 17.60980252296694, 1.1504885362040613, 2.4209680143863928, 51.84921510757939, 79.11577532368322, 57.54252364558559, 72.94934657312209, 69.91806045655282, 68.07361295146328, 76.07175719353461, 63.32495627864715, 47.74080691799041, 57.5111956750193, 34.329423135326756, 39.53733836450885, 66.49114839492306, 37.563880182081654, 0.3348111583580894, 0.26829735165642155, 0.0714812203941326, 0.18831746592637033, 0.1436980843784348, 0.22009051825490691, 0.11902757109172883, 0.11150645692982983], [0.0727163992762085, 0.05076521849860588, 0.02154488987740009, 0.021984193421479677, 0.02027596099182002, 0.0833655959896503, 0.026864705930253672, 0.14360623043631354, 0.0031767961674279747, 0.08700219238357199, 0.06634951148542666, 0.13635297125625995, 28.332242696515976, 55.65346702452629, 43.65521907806397, 30.956023969957908, 35.84981618389007, 36.36938118165539, 14.114525510418801, 64.87101339524793, 56.50235422195927, 57.792982670568655, 57.46761029766452, 60.93500121947258, 52.007914204751295, 51.15491636337773, 6.909953240425357, 1.2480294247788768, 3.2601681832344305, 6.827076990758219, 55.9055773673519, 44.839359098865145, 61.31650663191273, 54.68679889555901, 66.14322631589829, 58.57997878905266, 63.13957721956315, 61.11326117669383, 62.68427633470105, 59.14787523208126, 55.54042431616015, 48.727573271720644, 45.60104024025702, 46.01946692312918, 47.92649192194785, 46.86789128088182, 50.67995263684181, 54.34107334383073, 58.00892483803534, 58.17567263880084, 56.88341248419977, 45.72702677019181, 48.83799191444151, 57.91829063046364, 55.72076312957272, 60.72052601845034, 58.69649279502131, 57.967551677457756, 52.47744544859856, 50.35448612705354, 47.63574623292493, 42.58791469758557, 49.57301270577216, 55.44837413295623, 54.332844211209206, 55.112360369774606, 51.311920996635195, 53.985157474394775, 52.848972351320334, 50.347967147827156, 49.09444824341805, 45.77602894075456, 42.11419436239427, 43.25839288773076, 45.86887536510345, 48.7058315738555, 49.603677795779326, 54.797982400463475, 54.685449600219734, 55.45608159034483, 56.297022065808704, 53.868565021022675, 55.42851909514397, 56.13482029207292, 58.05815058369791, 56.01214424256356, 56.00193431300502, 55.514207193928385, 48.364020547559186, 45.90884431715935, 53.989456392103634, 50.41927191518968, 46.64461428119291, 44.75091357384959, 52.764413895145545, 62.03567320300687, 57.824357709577015, 54.662217401689105, 53.638490553825136, 53.28307674777124, 53.14320502742645, 50.525022937405495, 43.01567269909767, 44.316636593111106, 41.54817281230804, 38.93119488992999, 40.819349365849654, 37.83171138455791, 43.09470845806984, 49.671856434114524, 51.23422668826196, 52.81979776197865, 52.92528206302274, 52.216466626813336, 52.544074750715694, 52.2406715731467, 52.95286809244464, 48.36100816726685, 41.985717127400065, 48.765275093816946, 48.86378934306484, 54.54613485643941, 57.10492049494098, 46.850530870499156, 50.59140513020177, 44.60855507081555, 48.41227354541902, 57.58630514144898, 59.35589813417005, 60.12654973614601, 54.5927365364567, 56.18907843866656, 48.17197738155242, 59.85292127055507, 63.98282012631817, 56.89801939072148, 51.767072831430745, 46.05387395428073, 42.10350198130454, 49.05034119083036, 55.26441104950444, 57.898172793849824, 59.410925065317464, 58.18938132255309, 56.079538406864295, 60.597814667609434, 65.31585331886046, 59.65854429429578, 53.8393747422003, 36.154705939754365, 6.236729881455822, 3.6986911296844487, 0.16096032825448822, 11.564232783932841, 51.56305859165808, 48.788150356661895, 67.3308886251142, 57.01674169109714, 59.92643040995444, 55.96922566813808, 64.34640815181118, 49.162987739809104, 45.69725205821376, 27.100188962874878, 31.325042516954486, 36.167590925770426, 41.4149102857036, 6.004114698979163, 0.08364193156481751, 0.10787505461203475, 0.07003512984562306, 0.052830675812137705, 0.04244761804359094, 0.04334872130364661, 0.06075856350963155, 0.023688338772063295, 0.05284918449638833, 0.07231827870371842, 0.05119784367120555, 0.06588086485862732, 0.021302652875742605, 0.039777391770434, 0.030507189709873452, 0.023968822713340485, 0.01079001516524342, 0.03955822933705584, 0.08523904102584047, 0.1268865606717525, 33.12933867977512, 65.29408416440411, 42.8348788907451, 32.97256938872799, 48.974419793775006, 35.84568200572845, 18.18350603503566, 75.31684998543032, 60.56868714670981, 69.51897498100035, 65.60365723025414, 69.17412804019067, 55.77118912050801, 62.86433273746122, 9.834595014972072, 0.46959170350624674, 1.5550767293860837, 7.332232671399271, 61.828524989466516, 46.94405586488786, 64.81366442095849, 54.49266902862057, 68.74355377689486, 61.33412591872677, 65.93770980834961, 61.56720884384648, 66.09533417609431, 60.23969050376647, 58.16852608034688, 51.406658003407145, 49.98244147146902, 49.23270786962202, 48.953992089917584, 49.23704208866243, 51.57167211655648, 57.382114395018554, 61.72124032051333, 59.90846987693541, 60.490898701452444, 49.330551393570445, 50.43263935273694, 57.099574304396114, 56.566512430867846, 62.11207312922325, 62.40638033036263, 60.189460631339784, 57.19820622474917, 52.74657887797202, 50.278529428666644, 46.622833359626036, 53.6221028912452, 57.767950104128936, 58.475494692402506, 56.30850676567324, 54.51290061396938, 57.12145720758746, 56.2056779092358, 53.186264807178134, 51.6950620374372, 49.69386877552156, 42.045956888506495, 46.60231151888448, 49.36388761766496, 50.42096637910413, 53.18746897482103, 57.585124508027114, 58.06369681512156, 56.87049219685217, 58.09352251791186, 55.66512823104859, 58.407680834493334, 58.65173855135518, 59.149742280283284, 57.09953115832422, 55.30146960289248, 59.02861948936217, 48.546187185472064, 47.04399785687847, 55.19935461782641, 51.42477543123307, 47.65783702173541, 46.25311074718353, 54.01413202285767, 61.36095885307559, 60.23747828698928, 57.01262320241621, 56.51009305830925, 54.98122769017374, 54.970429405089355, 53.39118511446061, 46.290945929865686, 46.243398958636874, 42.63848973858742, 42.25917693107359, 43.48411352403703, 41.49544046771142, 44.71330588863742, 54.376056963397616, 56.46913174659976, 56.011508818595644, 56.37450064382246, 55.4971174270876, 54.12451928661716, 54.600534208359264, 54.26086479617704, 50.329359423729684, 44.51270411091466, 51.459766895540305, 49.682803769265455, 57.077412912922526, 56.957678641042406, 51.00078682745657, 51.745911644351104, 47.166289514110936, 49.61238937993204, 59.35803190354378, 60.68721332857686, 62.832926319491484, 58.60030058891543, 59.24821338345928, 49.603234567949855, 58.24921707953177, 64.09925176251319, 58.10996117130403, 53.07155509148875, 49.59386794797836, 43.512338899797015, 51.72997113197081, 56.66847052112703, 61.57450445236699, 61.65021404143303, 62.51713629691832, 56.73915163163216, 64.24654460722401, 66.96909704516011, 65.29708477758592, 53.574916778072236, 42.321723045841345, 3.81498817955294, 2.9547682740995964, 0.24753996952166482, 13.775657242344273, 55.363219476515255, 54.769972755062966, 72.79273417688185, 61.77026994766728, 66.08217854653635, 60.53837899238833, 70.94258354556176, 55.8393128456608, 48.40671162451468, 37.794644986429525, 29.10274132605522, 36.84214445852464, 54.878422367957334, 8.142230058870009, 0.1559057260953611, 0.18943181742102871, 0.07377075076463722, 0.013486224267962239, 0.061573328660620805, 0.024608023494722384, 0.037389702554191315, 0.005709907066287293, 0.1467693461886337, 0.20536186504027537, 0.17716391522797847, 0.17086757647414363, 0.1100960584177125, 0.1646726677614835, 0.09840732635629755, 0.2438986770087673, 0.15249240602697098, 0.251181629756766, 0.2784762086887514, 0.31095836732176046, 42.40051169549265, 72.39746908987723, 62.421842313581905, 41.23981960358159, 51.41116088436496, 51.19500690890897, 22.015396933401785, 80.81809182320872, 68.36229939614573, 71.29386317345404, 68.10679620312106, 74.67901768222933, 60.68170632085493, 67.30018431140532, 10.022698160140745, 3.773343885137189, 6.023956498792095, 9.0176280660014, 65.15604026855962, 53.130586762582105, 64.56996363978233, 57.74909527071061, 71.0190305402202, 64.70485395000827, 67.73570860585859, 66.32968794914984, 68.40553960492535, 64.24079049018123, 61.03360960560461, 55.18266885511337, 51.51896722855107, 52.06980528370027, 52.34916433211296, 52.32983881427396, 53.72639479175691, 59.53456994025939, 64.98896691106981, 61.45649602336269, 61.450514408849905, 49.46862274600614, 52.129378241877404, 57.4145249397524, 56.041224695021114, 64.4898178500514, 63.60186776807232, 61.72702189414733, 59.474353713373986, 53.528224883540986, 52.93725313678865, 47.8950031342045, 56.17915091976043, 59.69934086645804, 61.843590813298384, 59.872721395184925, 56.688655038033765, 59.45052531457717, 60.90298291175597, 55.78838086897328, 54.95948991467876, 54.292396729992284, 46.65454180009904, 48.86010623747303, 52.701408863067634, 53.34661129982241, 55.31849268944033, 59.97287911753501, 62.37899434181952, 59.27072778824837, 60.811391645862216, 57.047959835298606, 60.12072501644012, 62.378217712525405, 62.309156540901434, 61.239765459491366, 59.03603669135802, 61.82093912555326, 51.12771864860289, 47.664940434117476, 57.31309244709631, 53.17588229333201, 48.628607949902936, 47.31159371714438, 56.50952823700444, 65.04639433276269, 61.94081068038941, 60.68200049861785, 60.07362519541095, 58.762796540414136, 59.12182677176691, 56.682947989433046, 47.7483457134616, 48.467798617578325, 46.15221954161122, 44.22810085358159, 47.47893771817608, 43.291772257897165, 47.41359495347547, 57.08697565140263, 59.23196692620555, 60.12671055332307, 60.771618812314934, 60.74747270153415, 58.480115244465495, 59.278925541908514, 57.96286052273166, 52.378805683505156, 46.06161279063071, 54.99627390215474, 52.70779055933799, 56.92544068059614, 59.78535452196675, 53.21158370664043, 51.55137777328492, 50.089698683831, 50.44541451238817, 61.70169907231485, 63.47835233134609, 64.70619147823703, 60.18404383813182, 61.554237565686634, 52.09275114920832, 60.53880260836694, 68.47842508746733, 60.92423823571975, 56.18498348420667, 52.26282904225012, 45.919050324347715, 56.45552896684217, 59.92101361674648, 63.83526448280581, 63.8004965935984, 64.5468451899867, 58.475428012109575, 65.1577425772144, 68.5846193375126, 64.60677900621968, 55.59698881641511, 47.609568334394886, 13.631725868871136, 5.710966558225694, 0.5325537427298485, 14.743725657463076, 67.28345932499056, 55.626900811349195, 80.49822253565635, 66.42172244287306, 73.35537464387956, 65.37053115906255, 77.88650451167938, 59.910003523672785, 61.07522203076271, 38.70081840022918, 47.848256326490834, 54.85234645105178, 68.51249479478406, 17.45136622459658, 0.4045624832712835, 0.4083020955083832, 0.2189705589966428, 0.24361868719420127, 0.12976542716064762, 0.12483597312483097, 0.1557695616276995, 0.16967254059930004], [0.045866235609977477, 0.05859119351953269, 0.02398596010020664, 0.06310486099532535, 0.06501211349161402, 0.02525963681569744, 0.050458863768125736, 0.03201453090314904, 0.05122011384716438, 0.04200539761973966, 0.14288331922744552, 0.318621606115372, 7.132712487251529, 61.91317366015527, 35.91312716084142, 41.812426813187145, 28.885312580293228, 63.70096645047588, 19.48215376946234, 46.85497883827456, 68.90648118911251, 47.817799122102805, 48.80198063388948, 57.96277423058787, 58.486261598525516, 55.00445596633419, 25.472772082974835, 0.8281555711742371, 1.7779715431313363, 2.5577045352228227, 51.72750003876225, 31.209728756258567, 55.17136458427676, 61.72711995340163, 61.49024017395512, 61.88443053153254, 61.39110226784984, 62.76452410605646, 62.55884678133073, 55.785160603061804, 51.8727336391326, 44.95930910110474, 46.81648469740345, 49.12899255752564, 51.09948935047273, 52.970310872600926, 48.70618066480083, 55.4487193015314, 59.48104527688796, 61.532774356103715, 57.42446814813922, 62.103843996601725, 56.38074897950696, 58.34618199256159, 59.58926346994216, 61.204628867487756, 58.633793707816835, 56.673091073190015, 52.07652430380545, 51.71659192731304, 48.450214632095836, 44.691854446165024, 45.723618230512066, 55.641519484981416, 55.04508779894922, 54.93951720576133, 53.16864552036409, 53.00110932319395, 53.60352262373894, 51.57084449645012, 46.81886165372787, 42.21576806037657, 45.283155672011844, 46.731604606874534, 49.42998739980882, 54.637188757619555, 53.158596407982614, 55.410962566252685, 53.208045728745006, 55.862725473219356, 56.75723375812654, 52.16965706117692, 54.87170727022233, 58.42030694407802, 57.195523323551306, 54.0696963187187, 55.91959199597759, 54.32843546713553, 48.83265749100716, 48.68867904909196, 51.47649580432523, 50.84467257222822, 46.416493154341175, 47.41775658822829, 53.17308172102898, 56.92358147713446, 56.510708870426306, 54.43108781691521, 54.96349857699487, 55.056113581503595, 53.1793692804152, 55.089865576836374, 46.272385274210286, 46.08330349768362, 43.144691221175655, 40.376105846897254, 39.04881108191706, 38.48500959334835, 40.48163721638341, 48.51651445511849, 52.79075653322282, 51.64246697579661, 51.276156825404016, 52.50065019053798, 51.03712366473291, 50.87661243254139, 49.78470302397206, 41.71197491307413, 44.13418362217565, 50.66987214549896, 47.51264264506679, 53.0153710611405, 53.58296548166583, 59.4274970792955, 47.013572031451815, 45.05840386113813, 50.33481936300955, 54.726203026310095, 54.737432772113436, 55.53769826889039, 55.273083409955426, 55.395900664790986, 57.49166619393134, 58.62011640302597, 56.552266382401996, 55.90507530396985, 53.039540706142304, 48.5520472065095, 44.734800477181714, 44.32445387686453, 48.903248386998335, 59.96682690035913, 57.36167492405061, 66.02152301419166, 57.054376832900516, 59.27266151674333, 52.73900478116928, 59.547019543186316, 48.023099899292, 32.248111540271395, 3.086706510474605, 2.5579786108386133, 1.7310367067975385, 31.32765873785942, 65.9717167577436, 50.820718657585886, 57.74916979574389, 55.28311291048604, 59.99817840514645, 61.5822393663468, 60.02298739648635, 46.68784664523217, 46.33156599537019, 25.621704478417676, 35.07949406100858, 27.825990223115493, 39.3486645144801, 1.7730351176954087, 0.09241907752209133, 0.051705147094664075, 0.02814515103255549, 0.03543811271928492, 0.022691237034216043, 0.044464520704481876, 0.03779909611048718, 0.06782809948368419, 0.06400788330563134, 0.06541355888569547, 0.01657376257372239, 0.13026220453602652, 0.06158479316640766, 0.053960532926383524, 0.06495909254637457, 0.021000902333687392, 0.05612926272254798, 0.09996931068599225, 0.11178956472224767, 0.23276260843680752, 10.494169016038219, 74.49562334245252, 38.11862099555231, 36.46326311172978, 43.496563126963956, 63.52972753586308, 21.253927599999216, 54.964439945836226, 75.29108785813855, 49.84893183554373, 54.341524416400546, 63.12005558321553, 64.95149650881368, 57.00115026966218, 31.496701125175726, 0.9238454687499231, 1.6959855489192472, 2.636496126651764, 55.16104090598322, 36.719040870666504, 58.97000751187725, 61.477237516833895, 64.31263262225737, 66.06397090419647, 65.50305235770442, 63.933135463345444, 65.00824928283691, 61.43453075039772, 54.44185080066804, 49.68869516926427, 49.65086783132246, 50.2526927763416, 53.82570920451995, 53.648920136113325, 50.04910215254753, 57.42668820965675, 60.72312262750442, 63.299911945096916, 58.62187362486317, 63.570563331727065, 59.05902178056779, 59.85914214964836, 60.7765688434724, 60.89838197154384, 60.117343933351584, 55.99814138104839, 53.72239789655132, 54.50837419879053, 51.299051700099824, 46.62297848732241, 48.07988012990644, 57.65448770215435, 57.680685212535245, 56.81564569473267, 57.066857814788825, 57.05276473875969, 54.700170255476436, 55.060875338892785, 50.38855583437028, 46.144131614315896, 48.527932474690104, 49.06430090627363, 51.14788747602894, 57.77684211730958, 53.847133190401145, 57.148725525025405, 54.92958184211485, 60.040363496349705, 59.10310922130462, 55.064456462860115, 56.126693141075876, 61.316428184509284, 59.4642222312189, 55.733922681500836, 53.63634109497071, 58.346123157009, 47.416599489027455, 50.62772235562725, 53.00349804662889, 53.48231354067403, 46.841121104455766, 48.14247723548643, 55.4795491310858, 58.5068069734881, 57.079068153135246, 56.9919523116081, 58.016832336302734, 57.86357356655983, 56.91468946395382, 56.39825843995618, 48.69753576094105, 47.91441886655746, 45.521463194201075, 43.47844569913803, 41.38930113084855, 42.25250497941048, 44.8107022623862, 52.08383560180665, 54.656730005818034, 54.42889521198889, 53.46124649047852, 55.635741833717596, 53.68994812811575, 53.36186539742255, 52.933640633859945, 42.861578464508064, 45.841858079356534, 52.389984438496256, 50.37697307525143, 56.30712609137259, 54.536062209836906, 59.819039837006606, 50.464300724767874, 45.00875449949696, 51.73884353330059, 57.6347150341157, 57.509320782076934, 57.46082067489625, 58.06595610034082, 56.847714993261526, 59.18915425577472, 61.52738501948696, 59.15179367988341, 58.564191249109086, 52.230500867289884, 51.276705957228145, 48.15337357982513, 47.27075007654006, 49.8325284834831, 61.88838428066623, 60.821166192331624, 66.87831770989203, 58.09291062816497, 59.753057725967906, 53.868882733006636, 60.49586049972042, 50.592895630867254, 37.46255359342022, 3.8160043185757058, 6.213766365281998, 3.5487933408829475, 39.381867377988755, 68.69778756172427, 57.31870928118306, 64.32501162252119, 61.38013532084804, 66.18656850630238, 69.3351334910239, 68.74385187702795, 51.45187900912378, 53.26292753219605, 36.61212882687969, 30.000299253771384, 32.20968211850813, 54.62038532380135, 2.57277550716554, 0.04024173298309888, 0.08172637467542965, 0.029935134619834925, 0.07506933874420582, 0.07770155556499958, 0.061742848596505584, 0.03339336276234638, 0.043586553299739476, 0.2194330615982894, 0.15216853469610214, 0.147691041892094, 0.14040289506796869, 0.15202573590701626, 0.19136261946010977, 0.12268475992905518, 0.10616801153387755, 0.2559450725393911, 0.21208384224484045, 0.35333498050608947, 0.5780385891276022, 16.11749658661504, 86.36960275711553, 48.90307188034058, 58.97902896327358, 43.622251556765654, 81.40929498980123, 27.506717135829312, 61.002116895491085, 83.09224282541584, 59.10503118268905, 60.49884150105139, 69.28212658051523, 70.05076992896296, 67.30740931726271, 36.20410034733434, 1.5524314584270602, 3.281688512332978, 3.063577029012865, 63.58822184224283, 42.74753555174797, 59.73556787736955, 61.19912970450617, 66.6933544220463, 66.88549564730737, 68.56317966215073, 67.65847713716569, 68.52704678812336, 61.13692091357324, 58.039578160931995, 51.07196215660342, 51.1672051491276, 52.0670517798393, 57.85402651756041, 56.85915654705417, 53.95620253778274, 59.8395420658973, 63.91176639064666, 65.49738453280541, 62.165280080610714, 63.124986002522135, 58.45006204420521, 61.53618289578346, 62.91155415196573, 63.53179854731407, 62.45967357389389, 58.993424061805975, 57.81005282555857, 55.22075114711639, 52.83484397395965, 47.66466194583524, 50.266691715486594, 59.30348742392756, 61.27008538092337, 59.40925021325389, 58.657575038171586, 60.54421940157491, 59.25051581475043, 59.251629767879365, 52.23872215517106, 49.69178599696006, 52.3883919562063, 53.57298304957729, 55.84819309173092, 62.10061980832008, 57.28017591661023, 61.09133512743058, 57.87782353739585, 63.54935507620535, 61.603337795503684, 58.24072122573853, 60.0592653982101, 63.59717269097606, 63.830679232074374, 57.365409020454656, 56.32729099642847, 59.67208039376044, 49.74528320374028, 51.3997507095337, 54.55292055683752, 55.890111461762466, 48.13062775519587, 50.10860450806157, 56.71960253869334, 62.333541916262725, 59.00360653477331, 60.24687236355197, 61.5900880290616, 62.41388774687245, 59.067886337157226, 60.4934560868048, 52.94026551708099, 52.155760103656405, 48.77552032470704, 45.3436464648093, 44.06359664855465, 43.2588674945216, 47.68068090561898, 54.60031455562961, 58.87689044398647, 56.330946645429066, 58.194025408837106, 59.580822529331336, 57.220093050310695, 55.34958139542611, 54.975532408683534, 42.72883761313654, 49.28198460609683, 55.71460500840218, 54.29857054064351, 56.041601242557654, 57.68108529429282, 59.797223614108184, 53.829270716636415, 47.43051605839884, 52.81667163295131, 59.377690822847434, 58.89534127327704, 61.36013907770957, 60.26038885116578, 60.83804022881293, 62.483584342464326, 65.07791057709726, 59.334634965465916, 60.40049983609108, 56.47972999080535, 55.53117536729383, 51.586937981267134, 51.387724722585375, 51.279730104631, 63.72734831225488, 62.6318460126077, 71.59772134596302, 60.37668320440478, 60.28712764863045, 55.22631306802073, 60.4569858889426, 50.698544671458585, 47.242399184934555, 6.940932120046308, 5.55423992295419, 3.8386611544316818, 39.81190819894114, 78.6920730529293, 61.979387191034135, 70.0633607372161, 66.60678771234328, 74.54421366414716, 72.88762415609052, 73.38855005079701, 57.04138986525997, 62.08704056278352, 40.58551334565686, 53.48192522602697, 40.916561388200336, 71.41451527995449, 5.99024078538341, 0.3494675541597028, 0.20715967421570133, 0.08642906668565928, 0.19782532186758137, 0.22106691263616088, 0.21215701896336772, 0.16060918419351503, 0.19121836510396775], [0.055171664308516256, 0.02680768409082967, 0.02592247523998301, 0.016230742875186187, 0.026174070005635583, 0.05884495248357135, 0.0346513097775319, 0.01360278933369104, 0.07059386841231777, 0.07783369807105872, 0.020177087769092574, 0.05950598294035562, 0.4301281549757527, 42.879637056781405, 49.8337483406067, 42.31118363718833, 19.52692566379424, 52.63654070515787, 29.11335918211168, 31.67085632201164, 70.02212878196471, 57.45309752802695, 67.94838736134191, 57.98995625588202, 56.77792818315568, 56.951783318673414, 44.22390391749721, 1.0962523303685652, 1.045474306710305, 0.05588057143012843, 21.222634930764478, 34.807756177840695, 56.46193811970373, 64.90948792426818, 61.99811258623677, 61.546251620015795, 60.164212334540586, 58.319341213472434, 50.008650748960434, 48.61284002181023, 47.26278766509026, 48.88815510657526, 49.42872047424317, 50.67785809116979, 53.34032766280636, 49.19537867269209, 52.30182132413311, 55.83749678827102, 57.74953849854008, 60.293611326525294, 58.77294371204992, 60.27592143704815, 66.34044308816233, 63.25937032699586, 60.91480493545533, 57.63588782279723, 57.54139400297596, 54.83075772562335, 50.529639567098315, 53.295710702096265, 51.0446624602041, 45.836896281088556, 43.31058786761376, 48.8109471721034, 56.98385653957244, 54.15961665491904, 56.230526124277425, 55.739559127438454, 53.344504987039876, 50.8803229947244, 43.91125571343207, 39.665744996839955, 45.11773755473476, 47.694985789637414, 52.61167680063556, 51.5928646825975, 53.74236668309858, 53.0455772338375, 55.5776083853937, 58.056769909397254, 55.47463440125989, 54.70991734535464, 55.37642609688544, 57.70320746206469, 55.01803521187075, 50.461606056459495, 50.42115857524257, 53.37576235494306, 48.00096988677979, 47.169176378557765, 50.88120552801317, 49.342055705285844, 44.16985365652269, 45.53428934466454, 52.89501313240298, 58.123320764110936, 55.74918462384132, 53.06047439575196, 56.16628162322506, 55.92280441714872, 53.901528619950824, 56.36212164355863, 52.723264309667776, 51.582654753038966, 46.187363978355165, 41.49698588155931, 38.791840922447946, 40.024371224064986, 39.87109676484139, 47.654067623999815, 51.36575160488006, 50.905512455971014, 50.901213538262155, 51.88837212900962, 52.01895959915654, 52.86755261882659, 46.888762212568714, 41.29885911941528, 44.52415350944766, 50.32876322346349, 47.060565948486335, 55.35875581925916, 53.59346174424695, 55.19746403540335, 48.92160900177495, 45.855511849926366, 55.03263035128194, 52.303343203759965, 55.164920130083644, 54.663037177055116, 51.692547798156745, 51.044909569524954, 51.40487332497874, 53.834942463905584, 49.96189217413626, 49.10947092117802, 45.55346189006683, 46.656887377462084, 41.89307466630013, 44.58728405737108, 44.08486766199912, 48.35765061839935, 55.23987270170643, 58.94689690682196, 60.61497111474315, 61.64724872958276, 61.975911971061464, 60.5508089834644, 43.784041481633345, 23.785799895563436, 1.5220686360712976, 1.35755536056334, 5.893735770256289, 59.87334112967215, 53.892503246184326, 53.92843607933291, 52.27293699018417, 59.91621263565556, 55.01795284209713, 58.029725167059134, 35.4670242340334, 58.89102274371732, 37.93139057774698, 21.522874716789495, 35.430577570392245, 39.79064110786685, 31.646063020152432, 0.37753548352949085, 0.02596988459117711, 0.04397246243071653, 0.03938440015659698, 0.17775089179556217, 0.08665896967173585, 0.05078660767345179, 0.029370299908482743, 0.08234248556677373, 0.024867233174342303, 0.06671059170677777, 0.03151764052980129, 0.07674834300433436, 0.07599761514293571, 0.10337943616773813, 0.07976135148877099, 0.04745294542742833, 0.01590789427169629, 0.035891533348589175, 0.08626792009078688, 0.12136815356150751, 1.1921091738247103, 54.999560848359145, 54.75293397903443, 38.31758322254304, 33.53580997836205, 63.08434632516677, 29.332041125143732, 39.36535027719314, 76.451583831541, 61.313898255748136, 72.42798512981784, 63.69358847218176, 64.13284294066891, 62.95218598458075, 48.709475455745576, 1.653435554715895, 1.5158645496253045, 0.059878677054638826, 22.28257113887418, 41.248895968160326, 58.18203864559051, 64.23170628086214, 64.76690584613432, 63.749188069374334, 62.18057340191257, 59.54044957314769, 51.104239340751406, 52.32408861960135, 48.94207592933409, 52.98941281534011, 51.18736220944313, 53.05639905314292, 54.03494411899198, 53.12284008149178, 54.8248427914035, 56.432445818378085, 60.34255073916528, 60.44783499933059, 60.554131231000355, 60.0021674556117, 67.03121954394926, 64.53724715017503, 61.093539499467425, 62.043816043484604, 59.35081082005655, 58.25622243265952, 53.05234724475492, 54.14087557023572, 54.02012932685114, 47.556333926416215, 44.582173209036554, 51.344382532181285, 60.143423772627315, 55.975599519668094, 58.5049948384685, 57.4186198942123, 56.55220754684941, 51.83528677109749, 46.33668468844506, 43.26644943606469, 45.40454518410468, 50.41683612331268, 53.850129881212794, 55.4727908872789, 56.20685854265767, 54.239017194317235, 56.19270663107596, 61.071240825037805, 58.248762084591775, 56.58074671222318, 58.0207468617347, 60.49138115298364, 56.97616477166453, 51.8402877930672, 53.174764417832904, 55.90024686628773, 50.508639197195734, 47.86939397934945, 52.890941712164114, 53.05114699948219, 45.389177337769546, 46.628630622740715, 53.36166143417359, 59.949172312213534, 58.3292922665996, 55.03800399841801, 58.01378073230867, 59.872756696516475, 55.78501155299526, 58.0769818828952, 53.278381670674975, 52.67183811433854, 48.05063101553148, 43.874730602387466, 40.857325753858014, 41.88818739306542, 44.075712850016934, 47.91524256429365, 53.32762310581823, 53.78432819920202, 54.067084020183934, 55.03331676606209, 54.48808770025931, 56.188337110704, 50.662317660547075, 44.020156398896255, 45.57055557927778, 51.62911915010022, 49.62217569351197, 55.62123690882037, 57.55733451535625, 57.145054186544115, 50.735360037895944, 47.641606253962365, 55.82373319133636, 55.5845078345268, 56.74204241844916, 55.85368440997217, 53.388004072250865, 53.40506246013027, 53.94571411994196, 55.786804076164, 53.281197932458696, 49.29685431142008, 48.36510704409692, 47.80685570932204, 46.34560415821691, 46.960678869678134, 46.24568177807716, 49.42449215919741, 58.12598405345794, 61.73756130280034, 63.77959036057996, 61.71351717364404, 62.46410977455878, 60.21251632321266, 46.196973785277336, 29.255953027356057, 2.132726513570355, 2.3588315421535127, 8.222444490078958, 67.88948905083441, 57.83647783340947, 59.241106048707046, 58.22377658659413, 65.98054993537166, 58.872615060498646, 64.1093675551876, 40.25719527275332, 63.8664787046371, 46.83632012336485, 30.95477077268785, 37.0971534329076, 50.209923251982666, 43.0145352117477, 0.6088279692396041, 0.053797302572357084, 0.06886824770199676, 0.05831698766879498, 0.07808759493092376, 0.05588760794771295, 0.02270706441073168, 0.07425691016138562, 0.06658692213316118, 0.10538306252490129, 0.17701958426304404, 0.138389723255269, 0.15790991935758822, 0.12328761749930921, 0.14644031142515523, 0.19085263472891625, 0.09484892455680717, 0.08006486020261243, 0.20551777925462494, 0.19396554107867903, 0.16456561463494457, 2.9135904965862154, 67.84022408147013, 65.04178162544005, 59.93269051274946, 29.4246639743928, 71.29716580913913, 37.74139881134033, 43.469302654266365, 80.79787592734061, 68.20865231175577, 78.27041825940533, 67.19376256389003, 71.98252154934791, 68.61010689889231, 57.845059979346495, 1.7439807735143171, 3.468893434732191, 0.14003221576492633, 30.21796334174372, 51.830936862576394, 60.04288165800033, 66.5347808407199, 65.43959625305669, 67.10339899986022, 64.9177876595528, 63.22186854577834, 53.566216961030044, 53.858672803448094, 52.564474997981904, 55.79197768242129, 53.84275974765901, 56.49513706084221, 56.79936393614739, 55.27187924231253, 56.884855916423184, 59.69034687165291, 60.66970779049782, 63.90843629837037, 61.923458114747085, 64.04458176705145, 68.11545679646154, 67.06070792290473, 62.29825627419257, 62.34317133503576, 59.87225855550459, 61.65823528843542, 54.609057518743704, 56.8958346305355, 56.341164419727946, 48.99801285036149, 46.39326880055089, 54.92884443652246, 61.86683085656936, 57.90191865736439, 62.871593044650176, 61.92090072939473, 58.83215188980103, 56.88862139178861, 48.90627253440119, 46.502938270568855, 49.40253080860261, 54.076152540022335, 59.02869009202527, 59.85881267055389, 59.21879560716691, 58.37436814461985, 59.73017854075278, 66.395521010122, 59.87776164085635, 58.59586046588037, 60.37286281585694, 63.16264860091671, 59.211335259099165, 53.98469071234427, 53.3891180253798, 58.606376340312345, 52.31233719856509, 48.98487291028423, 54.27976669803743, 54.041298358671135, 46.33322123558291, 47.71237365661129, 54.76931379687402, 63.80448564406365, 60.63196282232962, 57.11876253927908, 61.758122367243615, 63.16669648693454, 57.747910714918575, 60.22562488432854, 56.615969596370576, 57.591325775269546, 51.32337039516818, 46.38264309975409, 44.605256357500636, 45.93070368612967, 47.24636862354894, 52.61336341980965, 57.226533582133634, 56.90260856382309, 55.281100734587646, 57.719210732367735, 58.730103585027884, 58.175966816563765, 52.662899032715835, 45.70544588950373, 48.43992233276368, 54.637577072266616, 52.69080669649186, 59.1048978221032, 59.671037043294604, 59.13773590518583, 54.937038267812426, 50.30936710296139, 56.32275673650927, 56.749177209792606, 57.94773194097704, 58.822471480215754, 54.01275919329736, 56.72609798369869, 54.8609717430607, 59.46039007556055, 55.606202463949884, 51.14469466670867, 50.00219845002698, 50.83825557462631, 47.45741567304058, 48.45350550067041, 49.14924767709548, 52.844908775821814, 60.701875148280976, 65.27353094470116, 66.3438477054719, 62.40239520226756, 60.70767633376583, 59.03712711026592, 51.30718277346704, 35.3191351890564, 3.8656431388470436, 4.003226156196287, 8.526835614635099, 71.74846587642547, 64.44014887655935, 65.27992048571187, 63.63211708684122, 73.58582958098381, 64.76163418062272, 70.01792400113999, 45.352546322730284, 71.48480415344238, 52.90129676941903, 35.75704428457445, 47.70052025395055, 60.095166852397305, 60.6761287104699, 1.4447585974008808, 0.12130760963285163, 0.1669457425633746, 0.11085682203091922, 0.2674581176571308, 0.2587718144059181, 0.10276540137466886, 0.20796146183725328, 0.1639944654438765], [0.0666632934383327, 0.013705146341254155, 0.05526874297028107, 0.008663546609421893, 0.04162954722320841, 0.01072425896587271, 0.02246249850178438, 0.01755878885066317, 0.02875157665731686, 0.04987092959063669, 0.03020364460685561, 0.0165707575938394, 0.1125676878878186, 21.907094409388883, 50.97945697845952, 44.2675285185537, 28.07031858351923, 36.65693798372823, 49.16134034433673, 19.198150634765625, 67.0203467338316, 53.02150957046017, 57.64567805874733, 57.309252446697606, 63.10178910532306, 53.61044168472291, 62.2696739627469, 9.202772763467605, 1.1204866944782197, 0.24868110345015604, 1.1164796256249951, 25.183163881301883, 49.283263298773, 68.80820228207496, 61.62431070881506, 62.16680588260774, 58.3394786619371, 54.86556091616231, 52.035990530444735, 53.88562340890208, 55.75737845513129, 53.78633253036007, 54.937646235189135, 52.060972106072214, 52.539497344724595, 53.411475535362, 56.068857792885076, 56.79461002349854, 59.9596332734631, 57.935768711951475, 60.907862340250325, 60.254175816812825, 57.90295416308988, 60.33198387392106, 59.81381523993708, 58.30880964955976, 57.20213251729166, 53.53230807089037, 52.758742147876376, 50.768927681830625, 54.058235153075195, 48.03158790834489, 44.6256919060984, 45.6870460510254, 53.85430720544631, 57.574177172876176, 55.11256825539374, 55.972551838044204, 52.16778609060472, 45.13958907896473, 42.87421241883309, 44.81833519474153, 45.19720477442588, 48.92989304757888, 53.22878722221621, 53.793028016244214, 54.96293767806023, 55.026181974718654, 57.27725375083185, 55.59069733465872, 57.40746467344223, 54.77789594281105, 57.02967766792544, 58.882228789790986, 54.62391545695644, 45.370495088638805, 46.700939516867365, 51.369913239632886, 48.26628684997559, 49.29084916268626, 50.7708574879554, 49.58927093013641, 45.895751445524155, 45.12571173329508, 48.83647395718483, 55.9937051803835, 56.19145931736116, 55.98571923471267, 57.82944894606068, 55.2353855102293, 55.37261355307795, 55.10033830519646, 53.689191110672496, 53.14458962409727, 52.16554249486616, 44.10698982977098, 40.23976033733737, 41.928576038729766, 40.53510696657243, 40.194025501128166, 46.033775729517785, 52.80838758714738, 49.49027030698715, 51.38023299555625, 53.899618425676906, 55.33224844163465, 45.91342956789079, 41.390132673325084, 46.677546501159675, 50.000927602091146, 48.19775912069505, 51.094021566452525, 53.80861943767917, 55.290373217675, 54.47798759706559, 46.88138815664476, 50.280435700570386, 56.537326074415645, 51.71403846433086, 51.37085068610407, 45.15480395286314, 41.214971388539965, 43.429066981038744, 45.41356271313083, 46.45210827550581, 47.09753428736041, 47.378372069328066, 47.00030657552904, 50.43086251904888, 49.23284515257805, 49.453427483958585, 51.51347983268, 53.92232110423427, 57.33400260248492, 61.41541311817785, 58.72718534161968, 56.91615643039827, 54.81733145252351, 34.05193897985643, 26.62832586996017, 1.5863142402902728, 1.8174709139331695, 10.2317448008445, 51.140772296536355, 52.12908014174431, 55.222951596783055, 57.555389019750784, 59.42667730392949, 56.592168654164965, 56.12705399913173, 47.708800377384314, 57.85610537375174, 24.733297440313525, 44.978332596440474, 50.37274476020567, 43.41946109648674, 20.08158999104654, 0.11457866868905484, 0.03710733786706002, 0.07031445316369496, 0.10616159171707208, 0.030560997810455102, 0.061937729873123674, 0.0715813557467153, 0.10771986052033403, 0.06253416762657224, 0.06650501201229711, 0.02810524934301934, 0.10723923993927818, 0.0211463728544092, 0.0200909890625025, 0.08678585681463442, 0.01907815570913015, 0.012676923239092915, 0.024382002659202106, 0.024685074702926704, 0.024377986443259066, 0.04447566345334054, 0.09442486424720097, 28.003714776808216, 61.88212025550104, 38.16990206318517, 33.014405388985914, 52.04193684362596, 48.012450664274155, 22.075897532124674, 71.6169801835091, 61.11499878668017, 65.91907855003112, 64.22816438059654, 70.40427746311312, 60.805923861842004, 65.54508447647095, 12.11383137010759, 0.79014866222297, 1.233349954408984, 0.8543621520361594, 31.052926125064975, 50.10155993123209, 70.82360236875473, 63.57315209604079, 64.6971974834319, 59.90777561741491, 58.131593042804354, 53.79054515592514, 56.46673517842447, 57.10109618402297, 56.00800614203177, 57.24230151022635, 55.8444276163655, 54.16704562402541, 55.822152476156916, 57.54433970297537, 59.488831181680005, 60.57463345989105, 60.075127463186945, 62.57907444430936, 61.591625598169145, 59.00581090681015, 61.84312797361805, 61.485937333876095, 60.678415452280355, 59.82183256456929, 55.38833049035842, 54.83897509113435, 51.92745854777675, 55.760414369644664, 50.14111311204972, 46.64937211621193, 48.850512120031546, 55.25048271302254, 58.564101034595126, 58.47151348667761, 59.187338198384936, 53.90589029558244, 50.6909195838436, 43.837958382022, 49.60473683572585, 46.86817369153423, 51.9482510320602, 55.7512281787011, 55.29253836601011, 56.93297555369716, 57.685748992427705, 58.14152840645083, 58.157943525621974, 60.3350394002853, 58.01272561473232, 59.546882260230284, 61.129715519566695, 56.63331039490239, 47.09091332650954, 48.255978861162745, 53.10904510559575, 49.006367498828524, 48.148941301530414, 51.24369528985793, 54.362760128513465, 46.95186138153077, 44.78031958303144, 49.021272505483324, 58.14762376969861, 58.575264100105535, 58.911270018546816, 59.047242902940326, 58.92145641388432, 57.4935842329456, 58.839761287935325, 55.87070749652002, 54.555305357902284, 53.24443355683358, 47.81566535272906, 43.90825902262042, 42.729508338436005, 42.08085813829976, 43.48751029660625, 49.356709680249615, 56.314351097229995, 52.64262037892496, 53.8324321469953, 56.80451793055381, 57.241418976937574, 47.60623824211859, 43.426588043089836, 48.70448620088639, 51.032769833841634, 51.85749130864298, 53.471283835749475, 56.60663043299029, 58.309374470864576, 57.911806952568796, 48.5979663941168, 52.38044131186701, 57.599547063150716, 54.24987823732438, 52.50278395991172, 47.05845571333363, 44.20099727569088, 46.60100929198727, 44.97590464930381, 48.51088193155105, 49.70520442531955, 48.55189423407278, 50.02334786999611, 51.55297810031522, 52.384175408271055, 52.675148594763975, 54.72343383296844, 57.64657235914662, 60.56931472593739, 64.807074839069, 61.96880463630923, 58.80338130458709, 57.46848106384278, 38.08577506772934, 30.7802096105391, 1.0730673228540728, 1.9452089047239673, 13.966830622765327, 57.17306775431479, 58.75608536504931, 60.17457915890602, 64.23831155223232, 63.986813099153586, 64.34632185966738, 62.25542791428105, 52.50692990518386, 63.144523328350445, 32.81812998556322, 54.69271775214903, 54.41134260546777, 51.33146616720384, 26.616395981081073, 0.2081980297882711, 0.08014974274462269, 0.08512785102451041, 0.020991644161122463, 0.053873547473021095, 0.0465463531473952, 0.06307506017507085, 0.013131489169843977, 0.03868652470109444, 0.19580822768470935, 0.10127944361057975, 0.1783099367974266, 0.17054116173136621, 0.11377769312070263, 0.14533599568230493, 0.11052545069927171, 0.15891432191335386, 0.1905292383725605, 0.1800858052147012, 0.0954619098094202, 0.2793495795659481, 0.24304268100569326, 41.24869984965171, 71.03751274847215, 61.42648989154447, 40.58348940264794, 54.408365526506984, 63.297276112341116, 26.55690735386264, 80.23667889256632, 65.60229224543419, 72.15890269125663, 69.8657517279348, 77.15954811342301, 65.11256471756967, 76.66907925759593, 15.122752131954318, 3.7409529522542035, 1.1370774622886413, 2.075038499409153, 42.037453189972915, 55.832225122759425, 69.92113559476792, 67.72696956511467, 66.87936106035787, 64.56482141248642, 60.66408703404089, 57.652906986974905, 59.97391070089033, 60.4745973310163, 58.416612071375695, 59.4422608806241, 56.76947939780451, 56.03417227345129, 57.73048754661315, 59.637234057149584, 63.16438621090305, 63.71312579801006, 63.52401656489219, 63.602993488311775, 62.19057152348181, 62.044671120182166, 67.28943701713317, 64.77720599020681, 62.6236286470967, 63.40763984187957, 58.46510041144587, 56.12011924866707, 53.54167469086186, 59.44125283148981, 53.03780309615597, 49.232162660168065, 53.5110370574459, 56.58146450596472, 62.43759455219392, 60.773132847201445, 62.7599859237671, 57.60467752333611, 53.06530283343408, 50.11305247583697, 54.905616160362, 50.130130475567235, 55.18739531117102, 58.93466303425451, 60.44188084140901, 59.09197361238542, 62.67033623110864, 62.24815976235175, 60.29609810921454, 64.25935506820679, 63.255879417542495, 60.84707736968995, 63.92700087639594, 60.06437232417446, 46.44098051132695, 48.78263942656979, 56.94255398165796, 50.99093775595389, 49.256904971215036, 54.454198421970496, 55.73993959734517, 49.075518884966456, 46.49954934273997, 50.03238501087312, 58.1818699836731, 61.73417629734163, 60.32184062465545, 64.64082517931539, 58.533616373615885, 59.13156601690478, 60.720345589422415, 57.83364195977488, 56.8630632277458, 57.8678136487161, 49.37149309342908, 47.55395697009179, 47.057196632508315, 45.41179764655329, 44.76163341153053, 51.48206164759975, 58.33136720042075, 53.74447299588112, 55.22964316029703, 61.23149318079795, 59.52738023573353, 50.1705151988614, 45.09841595926593, 52.895040588994185, 51.86636370997275, 54.75407931112475, 55.162688301455596, 57.776277296004764, 60.57528065096948, 58.76564418115924, 49.95149397080945, 54.477501223164225, 59.6398816570159, 56.72503894375217, 55.25729979238203, 49.782333912387976, 46.85750092229536, 50.564870295986054, 49.23878362101894, 51.75226588403025, 52.36028032918131, 52.6075190882529, 51.54823595477689, 56.37983898962698, 54.69886410620905, 54.70223342218707, 56.60132346614715, 59.785511416773645, 63.695165264991026, 65.86251012740597, 63.50284361070203, 60.126812534947554, 56.9215496893852, 45.391962220591886, 37.44364776918965, 2.8765515550490353, 3.6861084113197946, 13.636159127758397, 65.3471734446864, 61.12925660225653, 68.66326285946754, 68.41888350825157, 71.95599848224272, 69.32568842364897, 68.47993127761349, 58.382954212927054, 73.27466011047363, 38.352468782855624, 61.428835468907515, 61.22846903339509, 61.60231797925888, 37.22465399772891, 0.24502435128294656, 0.11536761667699584, 0.1708399207000771, 0.1879729561868214, 0.1786676845363071, 0.10259241872136632, 0.12266528597401997, 0.1361231448789758, 0.1083176082841331], [0.06736759637151996, 0.06658428679070165, 0.05876404593788809, 0.0548883764854362, 0.03434351097131449, 0.04182225664056117, 0.04474195944626005, 0.027533301505290216, 0.06274263547252744, 0.053048386508899356, 0.051403997931629426, 0.061933520219979755, 0.23766161813851328, 7.642758382904915, 50.262683053170484, 48.31555181933988, 40.80683700499996, 25.352288638391805, 56.23396212054838, 30.23513940072829, 52.66049854217037, 54.8478239582431, 51.40939581778742, 67.28062737372615, 56.21411100510628, 57.82525985471664, 54.6809624087426, 51.09983059667772, 0.33722335472702986, 0.97491460581941, 0.3016023500071418, 17.39368188765741, 41.32438590449672, 61.697827692954775, 66.39112011078866, 61.823637716231815, 60.76690020099763, 59.90086440117129, 62.01478658183929, 60.01547997997653, 58.60472110009963, 59.65587316020843, 60.22332637540756, 57.51588682974539, 57.58444986035747, 56.98045976700322, 57.1536990904039, 58.17733180138373, 57.886115427940126, 56.69536229102843, 56.072870377571356, 59.0129731547448, 62.82197506197038, 58.8002630203001, 60.62821303644488, 57.84351064312843, 58.31867833291331, 53.855315254580596, 52.299828760085575, 50.38327240174817, 50.6041528332618, 50.1519270866148, 46.43926643556165, 42.66027850489463, 46.006350517272956, 54.7178993686553, 55.37071512591455, 53.25838934990668, 47.45916112776726, 43.83739748308736, 44.41083231279927, 44.93029140656994, 47.4414163251077, 52.87130240471133, 52.85862138194423, 54.87419797528175, 54.44201554021528, 52.94833775489561, 55.848271539134366, 56.88915875650222, 57.3935834054024, 58.40684536964663, 57.73240950799758, 57.80971942409393, 49.567203675546956, 43.88667029719199, 48.19437411523635, 48.7387441819714, 49.51690712282735, 49.8692536354065, 48.77150381765058, 46.51516429839596, 44.408400443292436, 41.15560239361179, 45.360406752555605, 51.551903370888006, 56.999522486040675, 57.60458338645197, 56.99061086100917, 57.05365511678881, 54.51694849998721, 55.00852738657306, 55.76210491118893, 54.934669156228345, 52.79942104893347, 51.4904555197685, 41.676524531456735, 40.03596967266452, 41.21972530118881, 38.36795430029593, 42.82265678528817, 52.23177171522572, 53.79246711730958, 51.933373481996604, 51.758996671245946, 49.472109733089326, 42.37963684143559, 43.13570114874071, 47.299430447240034, 48.92732781748618, 46.308059230927505, 50.179509193666526, 53.34800766360376, 55.065688087094216, 55.54017328446912, 49.305526671871064, 55.654765329053326, 55.60649271934263, 55.74536031292331, 51.638124912015854, 43.80020556911346, 45.067703800816695, 51.867713005312034, 55.19899375977055, 53.69370183637066, 53.861700873221125, 57.72153669787992, 56.34023089562693, 57.661716630381925, 58.21368432814076, 59.43790312736266, 55.99374048171505, 59.41347852829964, 57.69646883010865, 61.53392753293438, 59.45057630538941, 57.858627457772535, 45.35348769157164, 25.19372682417593, 11.35172269036693, 0.1088267503186099, 2.0094705661458354, 27.223323929694395, 57.16225377974972, 50.1620860253611, 57.15225173581032, 51.416444316987075, 44.63547429730816, 60.34748115847188, 55.48679374879407, 61.05027575646678, 52.08124683749292, 30.35562872886658, 44.38031627285866, 39.80857418429467, 60.77799658621512, 12.088218292882367, 0.17018444055030424, 0.21891661108501498, 0.06436776459938096, 0.02523430037282167, 0.13501680666400542, 0.016722452578945987, 0.035802502440468925, 0.02523782054683374, 0.07862562614102518, 0.08627734297225553, 0.024620610319318312, 0.06037475345956703, 0.017421687840514125, 0.09103590577480294, 0.02921763773737175, 0.03128341872305159, 0.07862750305643967, 0.014983587166024073, 0.06421751177479183, 0.08685612239904943, 0.04498473270946453, 0.2053794084537414, 12.706213208936877, 63.50105893227362, 51.13582618774907, 48.190200713373, 40.172236734820956, 57.81237094633041, 31.7979528827052, 57.40779807490688, 64.06726875612813, 58.90562572786885, 71.83442854112195, 61.89689190156999, 65.68756457298034, 61.35623239701795, 54.56461314232119, 0.5520089439326717, 2.5204655528068542, 0.19422849309780907, 21.271727315841183, 45.38937345627816, 63.19949926868562, 69.44914894719278, 64.99917291825818, 63.337817730442175, 62.980172095760224, 65.75269945206182, 62.59364604949952, 61.00272878523796, 61.59745816261538, 62.89171088126398, 60.1052983345524, 59.4655401475968, 57.71426070121027, 59.5966257587556, 58.97161960601807, 59.2130022664224, 58.7246750247094, 58.77104136251635, 60.61908960342408, 64.68516757411342, 61.964501796230195, 60.7374353562632, 59.112189508253536, 59.55048691841864, 56.93617620775777, 53.92256036881478, 52.33993891746768, 52.43075747643748, 52.33959767126268, 48.33953711294359, 46.07872609169253, 50.22332599086147, 57.455121471035866, 56.805373007251376, 57.22113640077653, 51.506513703253965, 46.399909373252626, 47.1235631358239, 48.59682498439666, 49.71617921706169, 53.99603028451243, 56.5885365393854, 56.48722564020465, 57.311711772795654, 56.31473548950688, 58.19813997514787, 60.1322607071169, 59.4123802646514, 60.54485482554282, 59.529427712963475, 60.20671121535763, 52.4674081033276, 43.113218122913, 50.3245113741967, 49.92013854365195, 52.50143858694261, 52.54238420917142, 50.440405645678126, 50.039064807276574, 44.759848733102125, 42.259812355041504, 47.59637348113522, 51.97777471234722, 60.39374159228418, 56.628038729390795, 58.79106506224602, 59.239768520478286, 58.26269826581402, 58.022947311401374, 59.362232761998335, 55.599871758491766, 55.43233556132163, 51.85559288147957, 44.38117527192639, 42.3721686486275, 43.44422694175474, 41.062042097891535, 45.36169328997212, 54.8426660414665, 55.41774826665079, 54.03915674455705, 55.6429393829838, 53.12225564833611, 47.01162261347617, 44.63085374524517, 48.53937402848275, 50.776737120843705, 48.05523980048395, 51.13996036591069, 54.753569403002345, 56.642225942304066, 57.4488692129812, 51.16217667056669, 57.02071897445187, 57.546744115891, 57.97752626480595, 54.08244402177873, 45.30640748239333, 47.90626818133939, 53.35674670434768, 56.18988252455189, 56.469084678157685, 56.17473040857623, 61.416515304196274, 58.81077889473208, 60.33015212705059, 60.34593182225382, 62.0728611946106, 58.503198392929576, 61.89495032833469, 60.60779709969798, 63.3426736247155, 61.99841068636987, 58.13785314559937, 47.4424792874244, 31.332347931400424, 11.898351061728693, 0.5280851825110374, 1.3939668454470173, 32.328565236060854, 60.11366475012995, 56.30281148418304, 63.898477400502856, 55.413778828036406, 50.14950306184831, 68.02215929954284, 60.78398604546825, 66.653809085969, 58.47598106630387, 37.93934122208626, 50.99782543797647, 42.02867492552727, 69.3634137799663, 15.358128663032288, 0.2721077504177248, 0.17923914016254489, 0.03960260498006979, 0.01771554193128982, 0.0662574890039621, 0.03688837461654217, 0.06934141424754936, 0.014766018195528419, 0.06523587245253787, 0.1596438368001292, 0.07793826141184376, 0.22369099360319877, 0.12941713294675275, 0.2704660546395087, 0.13788690910704676, 0.08395808072940958, 0.15528758507101767, 0.0794377559495549, 0.1301581085088753, 0.17393407321745352, 0.2360825270654694, 0.6848053213569426, 21.514945645486158, 73.16509262208017, 64.99542705474362, 57.1461759844134, 40.334548334921564, 70.27407046287291, 36.80649011365829, 63.942333421399525, 67.93913841247559, 64.05315999061831, 76.84527997047671, 67.91074829716837, 72.73870745012837, 68.25074718844506, 62.36587009122295, 1.1843378553467414, 2.7842143033781364, 0.3710326840800624, 25.541625368979673, 52.76716739900651, 63.07737235100039, 74.27201686366912, 67.0904944019933, 66.35042944262105, 65.04416642650482, 67.26793458384853, 65.42070219593664, 63.968931013538, 64.7597671324207, 67.39902803974768, 61.78695963275049, 63.81895134525915, 60.03871217850716, 61.80448086031022, 62.30730910455028, 63.19740864538378, 58.84677056343325, 62.206104109364176, 63.518560547982496, 66.91907113598239, 61.914405284389375, 64.23554628126084, 60.22054149258522, 64.00233784029561, 59.46039007556055, 55.812315171764745, 55.220900197182935, 55.34412930088659, 52.74081691618889, 50.24391843426613, 47.29235841381935, 51.44861951951058, 59.43904061471263, 60.91492652893067, 59.30339328704342, 53.332577059345866, 47.77986980253651, 50.317925714677386, 52.1506178763605, 54.26783092560307, 58.256547989383826, 59.34375447611655, 59.11853590319234, 61.663436351283906, 57.13470305165937, 61.10894264713411, 61.887964587057795, 63.162173994125865, 63.93394739397111, 61.575987108292125, 62.74484165253178, 52.15026094067482, 45.196941975624334, 52.191951813236365, 54.0747679433515, 54.94893873891523, 54.40375674155451, 52.70842990567608, 50.44288458362703, 47.14477923608596, 43.46401529927408, 46.77712763509443, 53.11640347203901, 64.0796281445411, 61.392326047343595, 62.96623199216781, 61.713015110261985, 59.416361470376295, 60.40118232850106, 62.23890296874508, 59.96961570555165, 58.35743527258597, 57.297697144169966, 50.000837387577185, 44.58072585444297, 46.91438313453428, 44.46147011172387, 47.80179585179975, 58.19162884066182, 61.128966346863784, 58.86380541709162, 59.64192521187567, 55.97497194044052, 48.88230685264834, 47.244215242324344, 52.238412287927446, 53.706524064463956, 50.34802990574991, 52.48357219080771, 56.20422270990188, 61.11099012436406, 58.21302144758163, 51.36534367838214, 58.88019307967156, 59.331450000886, 58.58190075043709, 54.31322059323711, 48.515914332482126, 51.28901827719904, 56.751765974106334, 59.03517769229028, 59.249217510223396, 56.81297456064532, 64.02029052857431, 61.710234149809814, 62.63889058943718, 62.50827174032889, 63.36480363722771, 61.08828744580669, 65.67329106792327, 61.859260682136785, 66.60931371873426, 61.85664446123185, 59.03268698723086, 50.890603526946045, 41.87730281583725, 16.978200904784664, 0.49167679262257397, 5.067212456657041, 35.524443810985936, 69.39698142390098, 61.714301647678504, 69.87614600889145, 59.88683408306491, 57.961189593038256, 71.64235791852398, 67.85814146841726, 71.36031596891343, 66.56531257014122, 45.75001185940158, 59.95228275176018, 48.0017622055546, 83.58113488843365, 24.006331236131732, 0.3918487332280605, 0.3488304754418712, 0.2532022479440897, 0.18751903376992674, 0.18255922733055008, 0.1206306943429574, 0.12158882518809651, 0.17993847118510356, 0.20484264128871504], [0.04077242890132531, 0.05786514901105435, 0.07214829911507907, 0.014252565001257727, 0.0342125061058229, 0.05644613967066812, 0.0018530736809724102, 0.012177906971755288, 0.05200569104823855, 0.012020360032517103, 0.025127814151346687, 0.04736573014768863, 0.16300409761888368, 1.8286342245917169, 41.72327918391074, 44.617725572278424, 33.72040064104142, 24.21941791811297, 51.011510587507686, 48.59682498439666, 42.73101452858218, 59.53220082867531, 35.82958067617109, 63.57219111534857, 58.42266428855158, 61.461712775691865, 43.879441368964414, 57.18050456816151, 6.098763452422235, 2.2427887109018143, 0.09852412412123335, 7.690434792349416, 34.39379707459481, 58.87111279272265, 63.10645280345794, 64.91285331787603, 63.91593587013983, 61.728222139420055, 61.10558509826661, 61.78287644540111, 64.51263427734375, 59.95025096401092, 61.817581576685754, 60.34840291546237, 62.4040190635189, 60.83598490684264, 61.908145181594364, 58.18725539791969, 58.11899831218105, 59.978727371461936, 61.05626913809008, 60.25773340655912, 56.245356605898955, 57.914768342048895, 58.83511327928113, 57.78190197483186, 56.04928908809539, 54.59001048918694, 53.50088204106977, 51.85888375005415, 51.3465202239252, 52.66110650954708, 47.75690824754777, 45.72233169309555, 42.405846118927, 46.795609843346384, 53.82315966390795, 52.91005542201381, 45.27982950210572, 46.681970934714045, 45.54604861044115, 46.74511324974799, 51.518335726953325, 53.642675722799, 53.48449830086001, 54.279056749036236, 56.46068688361876, 57.571702157297445, 53.93016976694907, 54.73658946252639, 57.34117661753009, 56.499212403451246, 58.02047229582264, 50.219058452113984, 43.90838061609576, 47.167109289476954, 45.20160959612939, 43.595704955439416, 45.19769899306759, 42.987215903497514, 44.094893240159564, 48.320945078326815, 46.23681329911756, 43.79449852051274, 41.73033945022091, 50.441460763254476, 56.40413807284448, 55.340685459875296, 57.187521688399784, 54.18388043680499, 56.804066857984, 54.70303358570222, 56.60169216894335, 53.49302161124445, 53.52582047062536, 54.57761579944242, 45.531555452654445, 40.52863113341793, 43.381712205948375, 39.62643892534318, 41.4530945593311, 46.29313461242184, 51.754144699342795, 54.43373149441135, 52.72115407451507, 43.570178170357984, 44.34770960961619, 44.25512206169867, 49.853058168965006, 46.82845969353953, 48.19599405411751, 49.23012302767847, 53.418488733230106, 53.631665629725305, 55.73603291665354, 47.80698514753773, 53.36324999409338, 54.39538248123662, 56.75972838555613, 49.131648002132295, 42.95266766701975, 49.31781153525076, 57.061174300409135, 55.40336885759908, 59.57924965889224, 57.41013972989975, 59.786539077758796, 57.837281919294796, 58.66936568290957, 57.48336645864672, 61.038202701076386, 60.32104438351047, 62.517995295986054, 55.89460257560977, 63.36020661938576, 53.07607366192726, 60.23841181109029, 32.88786384367174, 20.37445179877743, 2.0734653838219184, 0.5060187246530287, 2.1504450853793853, 44.66424096015192, 56.18143373920072, 53.57675636968305, 55.01178687618625, 55.681362921191806, 54.135093996601725, 56.23542516462265, 62.95691244063839, 62.96290582226169, 37.82942072037728, 34.49226425540063, 44.45328020280407, 44.21356847209316, 37.45593655493952, 0.8948764361200795, 0.1397079460683369, 0.06528762935270226, 0.035471196226294965, 0.09097126327575215, 0.02260886917581722, 0.032231283990005334, 0.02399440813479164, 0.002126528885245564, 0.060076228147673036, 0.04138643305087763, 0.03561283056173594, 0.043635713161840554, 0.0567467755547935, 0.019798766739005526, 0.07089770654396665, 0.021219294848701647, 0.06620976938715865, 0.025050904669408357, 0.015032543057215311, 0.06943052559490166, 0.059659610382251205, 0.14153538752467404, 3.655778438814225, 55.98648409689627, 52.56984472274781, 35.48640858742499, 34.83152574108493, 60.1473500651698, 50.19399450671289, 50.76886884627804, 65.44282044133833, 45.32571731075164, 72.50003122514295, 62.32579915754257, 68.33932999641665, 49.97610292127056, 64.09239153708181, 7.320742087979471, 1.4549111622956492, 0.3216159067326977, 8.494611382484436, 37.94942955816946, 60.736572434825284, 65.55647896182153, 65.26784350795131, 68.16413341029998, 64.44747194167107, 64.26660360828524, 64.58879886134979, 68.07487595465876, 62.392091135824884, 65.79258995671427, 63.23023888372607, 63.92370216308102, 62.53077045563729, 63.791847767368445, 60.01785693630096, 62.470958232879646, 63.92262351128363, 61.87057672008392, 60.877554185928844, 59.27012374324184, 59.78460534926384, 61.71958115793044, 58.47238817522603, 58.440303187216486, 56.877113157703036, 54.6618212423017, 52.48701603181901, 53.80404203168808, 54.973622214409616, 49.80506012516637, 48.487696801462484, 45.60495084331882, 49.13003590799148, 55.450633418175485, 55.03298728696762, 48.108419295280214, 47.53831455784459, 48.283345237854995, 49.45129763695502, 55.28305799730363, 56.492618899191584, 56.202143853710545, 56.96337784490278, 58.23703419777655, 59.38603762657412, 56.44986506431334, 57.28549072819372, 59.07248335499918, 58.09802539886967, 60.11353923428444, 52.779048258258456, 44.32793694157755, 47.67074161960233, 47.62662279990412, 47.17610328428207, 48.12063747836698, 47.82870331118184, 47.25870840011105, 48.676829568801395, 48.62476794950424, 44.67504316760648, 41.669836890312936, 51.62309046714537, 60.78278187782534, 57.360509980109434, 58.04293963216967, 56.86333779365786, 57.47260347489388, 56.31402554050569, 59.03072972451488, 55.20084904086206, 55.97697627159857, 56.630109740841775, 47.14227284154585, 43.13730147577102, 44.86536833547777, 42.01398172686177, 43.837169985617365, 47.73358583450318, 54.8221363559846, 56.65312620901293, 53.646923649695616, 44.85719803840884, 45.607700424809615, 44.95893647593837, 52.839629265569876, 50.49458534486833, 50.36744563810287, 51.10177609228319, 56.865138161566954, 55.206277601180545, 59.59206011987502, 49.115103444745465, 55.45523043601744, 57.36620526159964, 59.15288802116149, 50.6257023349885, 44.13481904614357, 52.09991731951314, 59.41203901844641, 57.93903604630501, 61.44874149753202, 59.53722930723622, 61.74706520572786, 59.80894365618306, 61.69845919455252, 61.0083338522142, 64.5791615978364, 63.22563794351394, 64.78026543894123, 58.72359637291201, 66.08200596224877, 54.23841707168087, 60.24511906408495, 36.37253476727393, 23.675596983202045, 1.0718884054691562, 2.214511608885181, 3.842968897473428, 48.20914576130529, 60.69393234868204, 62.16764919219479, 60.78864974360312, 59.53767253506569, 58.41155613622358, 63.27371443471601, 69.04176373635569, 69.55888901987385, 42.71002984816029, 45.29183587720318, 43.33467514284196, 43.20289134979249, 47.2235639633671, 1.6209057454139957, 0.17778130548615612, 0.09318649077848082, 0.0605835737059674, 0.0882205862792269, 0.0989242288614473, 0.0795543545316304, 0.09461761196894992, 0.061536104448380015, 0.02355989455545862, 0.23457852793076348, 0.11754481557516322, 0.25950296872085143, 0.08880161800451818, 0.14770673137278328, 0.1619891690150384, 0.21586261689662936, 0.15817539946686837, 0.12357182845833803, 0.22278343988282068, 0.1333190485714905, 0.3108101139866537, 0.2969661084634643, 5.885816014582112, 72.04367130033432, 62.261162419472974, 46.37146826713316, 37.30723165696667, 68.94576764875843, 58.784047942007746, 55.51929843041205, 73.08247966151085, 47.69424053930467, 77.10809446150257, 67.82589958560082, 74.2220772466352, 54.456073314912864, 71.15928665284189, 7.822551496567265, 8.985513660215563, 0.3665275661455047, 10.626116568042386, 47.04082073703889, 58.08059830819407, 68.87966002187422, 67.94012684975901, 72.31131030667213, 65.6612297796434, 67.46349611589986, 64.95481483397946, 71.47447263040851, 63.87705733699184, 65.97617257025935, 64.82854197102209, 67.81859613233998, 65.41624638342088, 67.33028458010766, 60.12021118594755, 64.01770568663075, 66.6796104369625, 65.78723592142906, 62.76978400445754, 59.189424899316606, 63.21283924964167, 63.62403700428625, 59.97315760581725, 61.94421529769898, 58.90722605489916, 57.91345434804117, 56.65673478957146, 57.04341380826889, 57.52328441989038, 51.527125758509484, 50.78104388329291, 48.62806666281916, 51.3525410621397, 57.913768137654955, 59.790841917837824, 51.332760549360714, 51.21854897468321, 53.34157889889133, 53.06252971772225, 58.711578230704035, 58.626968783717004, 59.97616998610958, 59.91047813046364, 62.44641204034129, 63.21419246735112, 59.302298945765344, 59.320961583045225, 63.24567341035413, 61.01193458803239, 62.699573578373084, 53.70484529003021, 46.88839743214269, 49.16249744353756, 50.09236589554818, 50.0045754063514, 52.344382962872906, 49.905033496118364, 48.73601813470164, 50.687613025788345, 49.85741592222645, 45.67115652945734, 41.271830066557854, 53.133705046869096, 63.43154668807984, 60.696046506204915, 60.959563101491625, 56.76853802896316, 62.214545049975, 59.184863182806204, 61.59613632386731, 58.31856850654849, 59.45368674493606, 61.18923748693159, 50.95356149058188, 47.33086824417115, 50.43285508309641, 45.7144477290492, 46.948307714154645, 51.1955834973243, 57.33369665761148, 58.911999579398866, 54.898391154504594, 48.169015992072325, 47.69892777166059, 48.75259407104985, 54.618451595306404, 51.8286265865449, 51.844198396128995, 53.8203473244944, 58.5391822168904, 57.13566795472176, 61.45746877116542, 51.079889266721665, 56.145269486211966, 60.253073630794404, 61.50300748886601, 53.93339787760089, 46.46218876684866, 55.65547527805452, 62.07155112297305, 60.434416570971095, 63.85707286096389, 63.66941490480977, 65.05135613103067, 62.44133649333831, 62.64800617771765, 63.237569793578125, 65.7735860732294, 65.8463970307381, 65.74588237270233, 60.67443032418529, 67.6504990362352, 57.77043688681818, 59.365582466125495, 42.93794308939288, 31.576333084414085, 2.982141514939647, 1.4341684430837633, 4.093816727399826, 53.14806484406995, 66.47676898587135, 65.1332748320795, 66.07922107942643, 67.0950992645756, 65.5547962650176, 70.01005572657432, 73.27760188810288, 75.11168649119716, 50.42698721731863, 50.640693633787095, 59.71445375873197, 53.04244718243999, 63.11378371331, 2.898351598170496, 0.21644193258497024, 0.20034899935126307, 0.18837973355285584, 0.19288814566548795, 0.2541317424226192, 0.16396544603330476, 0.104128340739877, 0.1559547097572396, 0.13366224063980964], [0.036193303042842496, 0.05131797008817235, 0.024023776115368933, 0.030429713322871157, 0.08066669121504792, 0.07136017850209629, 0.0892352544131779, 0.15612946973452646, 0.03092420775623572, 0.038456119927427465, 0.03486889790022566, 0.01980337284265026, 0.02668873744926626, 0.09769403721175848, 32.13467071133275, 47.33892479250508, 49.711774395358184, 40.06679165747858, 33.35540448465655, 64.7030378926185, 41.43441623257053, 59.98627793404364, 52.020391264269435, 53.742500043684444, 62.39919847057712, 58.756524670508604, 54.32934153464533, 65.3145157906317, 28.08803200721741, 2.562377548986866, 0.26301480769630403, 2.002141372330727, 30.66664130456986, 49.160367596533995, 57.44156183735017, 62.03709310100925, 57.242556464287546, 55.07395252104729, 59.563811209894, 60.221835874742084, 62.32072753290977, 63.726238281496116, 62.027271486097774, 58.891234551706624, 64.69085893323346, 61.521811331472094, 62.75962114334107, 60.796380735212765, 58.75338285200058, 58.9895526824459, 56.023483814731726, 58.857121698318, 57.47283489473405, 57.02069151786066, 56.837003000320934, 60.816777060108805, 56.21144379338911, 59.39594945599956, 56.35677545301376, 54.097654973306966, 51.83471802742251, 52.48471752289803, 50.26409510643252, 44.860987047995295, 44.19796920591786, 42.774329262395064, 44.6657746068893, 49.208361717962454, 45.71592646260416, 46.04985352485411, 46.68233963751024, 52.11000173322616, 50.36502553570656, 52.06403155480662, 55.710655181638664, 56.8203603836798, 55.79419774393882, 55.50695865384994, 58.575122894779334, 57.76889147297029, 56.349256269393436, 59.3359136581421, 53.287167779860965, 45.690995877788914, 43.73236425461308, 44.445533521713756, 40.058499766934304, 41.68152163105626, 40.71124884390062, 43.50693387369956, 43.226715826219134, 44.89627269006545, 44.569766752181515, 45.210470230348655, 45.593242568354455, 43.06383156007336, 50.593268256033625, 58.821612481148016, 56.01352491686421, 56.75340552483836, 55.09239158322735, 55.97971408597885, 56.77215445426203, 56.054862776110255, 53.7507801671182, 54.334730871262096, 48.90372691615936, 45.48782886997346, 42.99069896821053, 42.41327901040354, 40.20447861763739, 43.40778420048375, 48.53729517229142, 53.344414772525916, 44.80535214947116, 40.169902924568426, 43.13262601052561, 44.000995620604485, 47.58564972108411, 44.836527147600734, 48.421997101076194, 48.76792269368326, 53.813310592405266, 55.36046597265429, 59.18876201875749, 44.91263681842435, 51.42688566638578, 56.59582822553573, 53.32415180821573, 50.06750983576621, 44.90141491736136, 50.08192454614947, 55.061393091755534, 57.187576601582194, 57.52738721909062, 56.37443396352953, 56.61363970848822, 56.556565300110854, 59.90081733272922, 59.257172076932854, 57.57666003319525, 60.94597208884455, 60.749759443344615, 60.96067705462056, 60.210547293386156, 57.68819655141523, 48.3365325773916, 29.382129792244207, 10.410159691687554, 0.7805427163839341, 0.7233725163725115, 6.998727263942842, 47.727376722520404, 55.85209977242255, 52.70707668796663, 52.39739771812193, 57.94508434111073, 57.57883694864089, 63.83635490171371, 49.133660178030695, 63.62559026287448, 37.1590131328952, 49.68286652718821, 41.59339774039484, 61.48281120484876, 26.54126690280053, 0.19029778788887686, 0.0744330337751777, 0.03762123347710698, 0.06757053306266185, 0.02894886345001719, 0.036964688465119376, 0.08795943456671892, 0.03497615787050417, 0.020910496297743053, 0.0759272576279698, 0.03342604024275657, 0.01797318879154421, 0.07726546001410292, 0.025703881626888633, 0.02399112927847572, 0.020523418882681478, 0.04180334959058993, 0.10804944686711797, 0.03909574971804696, 0.017829355783760548, 0.029616645056634184, 0.019204338051138387, 0.07229672865040841, 0.30677451601912903, 41.496832909122595, 56.2865375703381, 36.417865599355395, 48.91789059485159, 44.56509913167646, 70.89758611494496, 47.67974738151797, 64.36018351585635, 48.91696491549092, 60.23970227087698, 67.50295515983336, 65.29651211154076, 60.86950155996508, 67.50096259578582, 30.06232173212113, 0.9687414080385239, 0.8066617793613865, 2.5876753657094897, 33.788375316127656, 53.27493782966368, 58.07567181125764, 64.04763337104552, 58.34926497551703, 55.20851727454893, 61.4653213562504, 62.549209517817346, 62.44940873115294, 66.83965882947369, 65.56524938152683, 61.674791612932765, 65.83818358759727, 63.85525680357411, 61.97046379889212, 62.34763106992168, 59.14432940944549, 59.00480285767586, 55.74677236618535, 59.03045515860281, 59.20003098826255, 60.15928975997433, 59.325774331246656, 63.96320827545659, 58.70634186652399, 61.432471506057254, 57.275967213415335, 55.96171040688792, 52.35486745834351, 51.96360318891464, 52.3220411423714, 47.45672533589025, 45.15250936631234, 44.958861950905096, 45.60786516435685, 51.989655571599165, 46.477642905327585, 49.88293094019736, 49.7040787050801, 52.92457603639173, 52.289434479128936, 54.95403782013924, 56.1775545151003, 57.42341695293304, 58.94283725369362, 58.12656064187327, 59.625110010946955, 60.22455015490132, 60.449627522499334, 62.015912302078746, 53.92718876561811, 46.96781366102157, 44.46933054154919, 46.531104810776256, 42.46914140639767, 44.27154502561016, 43.68993989882931, 43.94097551222771, 45.735385341029016, 48.75865413296608, 46.10124441885179, 46.71032967105989, 45.06339703836749, 43.47054604561099, 53.70749288989652, 60.21367342241349, 57.49622398807157, 58.10421489900159, 57.07797381185717, 59.131181624627885, 57.09729932969617, 58.55857049265216, 55.51694108593849, 55.38921302364719, 51.88959983087356, 46.52505651597054, 45.34088119383782, 44.9308640726151, 43.69396425062611, 47.48057726890811, 50.88424928726689, 54.14409975851736, 45.88695356922765, 42.73221085148473, 44.19748283201649, 46.095337329372285, 51.42543438942202, 47.11039181678526, 48.97960124477264, 50.53380512422132, 57.50990913760278, 56.66078267558929, 62.298526917734456, 47.645226601631414, 52.62861751740979, 58.90289183585875, 54.94782086341612, 51.79930686950684, 46.114321601006296, 52.9373158947114, 57.00909306926113, 58.81422665811355, 59.25454801128757, 55.80388992063461, 58.77041770565895, 56.79256646863876, 61.590931338648645, 61.39640923469298, 59.691805993357015, 62.914154683389974, 62.76927409633514, 64.59774186534267, 61.0561240103937, 59.63429620189052, 51.425630507930634, 32.73601124363561, 11.746271944815113, 0.8942414411614019, 1.0103496656783166, 8.727973776478922, 54.03145713190879, 60.2351091754052, 59.50172793480658, 56.77475890805645, 64.41970548322125, 64.08914773694931, 70.60972336799868, 55.136251526494185, 70.08428265971523, 40.80478560539984, 63.823281641929384, 43.98959329051357, 65.46217341576853, 32.51295389667634, 0.43279723594746283, 0.10528314167693739, 0.09670327102104503, 0.08582985569392482, 0.01644620893432969, 0.048933042618896694, 0.14028644970347806, 0.06499002717675702, 0.09089247879361914, 0.06109129464734466, 0.1556817219863015, 0.08873955722177222, 0.17644679564381802, 0.17321589643195753, 0.11794422317536608, 0.10270594529086545, 0.17006914431770004, 0.22688535042107108, 0.11500992256427005, 0.1354777464462865, 0.10275222466237123, 0.08574036130261037, 0.1958567363720748, 0.539582384930503, 54.160432507914884, 66.91614504783385, 68.62465889223161, 54.54551119958201, 48.788593584491366, 79.4853331965785, 52.788607074368386, 72.15519212907361, 62.86934944891161, 68.28738212585449, 72.98773873236873, 69.7292689354189, 66.70309758955433, 77.83445465949275, 33.23258722982099, 6.761548894066965, 1.3566707435154146, 3.2490852811644158, 42.73527814495949, 57.651447865270804, 60.839487583406516, 62.763484677960804, 58.88329175210769, 56.20906683706469, 61.96931062206146, 63.03064907750776, 65.34189785680464, 69.1132293208953, 68.77917674279982, 63.39857132204118, 67.17747688293457, 64.84480804012668, 65.41050795585879, 63.26279063378612, 60.10952664959816, 58.70111726945447, 55.6298190547574, 61.4860353931304, 61.423077429494555, 62.11072383388397, 61.00499591519756, 66.52696747933665, 60.4303922191743, 65.7506598195722, 59.38730455213978, 60.06071275280368, 55.13401185312579, 54.51093942888322, 56.23975546129289, 49.07553065207697, 48.58400275630336, 46.1025897918209, 47.2824191278027, 54.04968830846972, 49.815768195736794, 51.117359668977805, 52.97319381467758, 57.192495253778276, 55.66024095781388, 58.99796616646552, 59.402170335092855, 60.574617770410356, 62.498097112101895, 61.709610492952415, 63.11923580784952, 63.70066050560244, 65.95945542858493, 64.48370287495275, 53.92685536415347, 48.9866340544916, 45.389091045625754, 51.122494051533366, 45.532536045197524, 47.257959227408136, 46.79724154933807, 48.49702812010243, 47.76992267177951, 51.79690245659121, 49.05235728909893, 48.652656001429406, 47.07619659362301, 41.340142065478915, 53.31668753777781, 66.33410453796387, 59.888234369216434, 60.070581436157234, 58.862334528277, 62.17574104186028, 62.60677814483643, 62.841461396986446, 59.12451359533495, 59.101355921837595, 53.76657947417229, 51.63998803784771, 49.32216928851221, 47.057251545690725, 45.31026709464289, 49.609973199905895, 52.276655397107525, 57.69945375380978, 47.65387935023154, 45.61616489964147, 46.2914676050986, 48.704199867863814, 51.77505093236124, 48.8655936333441, 52.58311410104075, 52.515210028617616, 60.06448607290945, 60.408513238353116, 62.83359312242078, 47.968833907958, 55.33326433550928, 59.210872419418834, 59.01547170454457, 55.622441076463275, 50.39006986925679, 55.54262084345664, 58.98965074170021, 62.56964898878529, 62.90357212866507, 58.84843364838631, 60.44540312982375, 60.03471920567175, 64.20148049631428, 63.568978694177446, 59.19536729012767, 65.04360944994035, 63.65740852971231, 67.57893147007113, 61.45863763747677, 60.39222755739766, 54.300257159817605, 42.644577257094845, 15.977890606849426, 0.9376650820336035, 2.0320715082268563, 9.632196791710394, 59.35673752138692, 65.9644054597424, 64.99777263210666, 60.91817425143335, 70.02649045759632, 69.19196697973436, 75.52119762666764, 58.920632716148134, 73.56840641267839, 49.06375961918985, 65.09382363288634, 53.662060076190585, 74.72844739114085, 46.391409597089215, 0.4515177588309012, 0.2454219509156481, 0.20434675257532828, 0.1734981998320549, 0.1299390839713235, 0.16683858218452624, 0.4310578486371425, 0.15812463848100555, 0.14291727224424963, 0.1949023133924892], [0.06110541364778915, 0.046881838371196104, 0.07098615139482484, 0.036570739241377, 0.03489386087523834, 0.07803749278067582, 0.032412731914871165, 0.0556526794248531, 0.047832917376992204, 0.011052324628126959, 0.017078352130709157, 0.0437096904422487, 0.05082633316276535, 0.1519661036229903, 4.628066343645896, 46.510178965906945, 41.288762938591745, 33.51283273389263, 36.51515214673935, 51.921673051772586, 48.154820934418716, 51.279149593845496, 79.32785787890035, 55.84908739213021, 63.93162927319927, 56.21367954438733, 60.22407554811048, 55.15041128281624, 51.601537043048495, 1.683616109432713, 1.1132129041417953, 0.3914210416616932, 11.892854840524736, 41.91993505724015, 60.48183018161405, 61.67840411586147, 61.86909014178861, 61.055974960327156, 62.1303709860771, 62.46631022422545, 62.58610725402833, 57.670236018396196, 59.871729035531324, 63.78793716430665, 60.742597195409964, 63.07748217736522, 63.128625962042044, 59.99435801659862, 58.613075748566665, 58.642422922195934, 60.49265200091947, 58.0013507412326, 58.826711562372026, 61.7129131286375, 60.5234073054406, 58.00885423537224, 58.61103611607706, 58.94577510895268, 60.698968671983295, 56.873339837597264, 52.727990765725416, 49.73400638949487, 51.85652248321041, 45.834723288013095, 45.62466075343471, 43.46600001858127, 42.838369800198464, 42.331583884454545, 44.51801500012798, 48.248228257702245, 48.11345561858147, 51.41497735054263, 52.44274816205425, 51.8664421573762, 53.872844326880674, 55.27121636175341, 56.14497530844904, 55.65035658497965, 57.12279081344605, 57.57662865423388, 58.67685740993869, 52.13359086744247, 46.028049069066206, 43.100297835565385, 42.39513412598641, 38.297484997780096, 40.31702710736183, 42.04903202672159, 41.398028404481956, 41.71450484183527, 40.44020914262341, 40.700434869335545, 41.1839807418085, 44.88903591709752, 47.887150549119525, 45.196137889739006, 45.841748252991714, 55.56996760829803, 55.7451210483428, 57.32952717811831, 55.38098781339584, 54.72880355773434, 54.10386800765992, 54.76586211112238, 51.422135676107104, 54.08717440020654, 50.241341437062914, 50.146584818440104, 44.979113148104766, 42.35473371321156, 41.03463649749756, 41.34733569237494, 45.14606491211922, 44.260801653708185, 40.79578376585438, 41.71120220615018, 43.07566535088324, 46.380517175120694, 50.30308738831551, 44.856048783948346, 51.14879746590891, 50.51527192515712, 53.058238644753736, 50.969549071404245, 59.552695212825654, 44.32907442892752, 42.747461026714696, 59.613307599098455, 51.5158881679658, 53.211760213298184, 45.41667707504765, 43.31055648865239, 50.39427857245169, 57.61371074184295, 56.94392681121827, 56.821866573825965, 57.38167116718908, 59.11653941677463, 59.97173770781487, 56.41694853382727, 57.83929409519319, 58.74924082909861, 59.46826619486655, 60.37922882264661, 58.1108437045928, 66.40509943808279, 49.541300342928984, 17.102645943241736, 1.8586490591687543, 0.39051996904515457, 2.510345837762279, 7.862778344461995, 58.049725332567775, 50.92748557367633, 54.681899855213786, 59.221835444050456, 54.92361199471259, 62.32317901426747, 47.79111916019071, 46.56993235311201, 58.19865380564044, 28.448299746359552, 48.76327468502907, 31.176771040885683, 52.6983533367034, 7.339035532166881, 0.06619231790424356, 0.047373927288478425, 0.09520491029346183, 0.03575544165928037, 0.02154695639957584, 0.05111167027104286, 0.013863506291301982, 0.023495686811304862, 0.07019942506186425, 0.020050248506689267, 0.06049430914103024, 0.02555913314403546, 0.16064833128644576, 0.043455958291287386, 0.05100118507060313, 0.031249756819658706, 0.0733462231413972, 0.04347137198032391, 0.03214377376641477, 0.019879309392924753, 0.03465038664158314, 0.04820761481119741, 0.03731749493688826, 0.03440813048772755, 8.849617262040416, 61.076892960456114, 41.898428701585345, 47.556639871289654, 47.74303874661846, 55.54999882175077, 52.50209362276139, 58.447273239012695, 82.79388381588845, 59.8798797207494, 71.58869204982635, 62.24054251947711, 64.77625677662512, 60.07732006811327, 58.34341672159011, 2.755485393347279, 0.6720927357673646, 0.4341594934944184, 14.47219664050687, 47.160711903725904, 62.10236134067659, 62.87879843865672, 63.546499590719904, 61.451887238410215, 64.17660874705162, 66.09079991617511, 63.822512857375614, 60.636175447894686, 62.68822616146457, 63.92210575842089, 62.48230564978815, 64.3452706644612, 64.13606320658039, 59.816921757113555, 57.795406695335146, 57.645434871796645, 61.007290501748365, 61.30586916400541, 61.351690292358406, 62.010071892892164, 62.25526317473381, 59.30198515615156, 61.45537422549341, 60.31618848923714, 64.61440409383466, 58.95876207659322, 54.640507082785334, 51.27513308678904, 54.00841320714643, 49.458824665315696, 47.61251795676447, 44.349694328923384, 44.738648322320756, 45.58252273067352, 47.24629017614549, 52.04003057172222, 50.670801747229795, 54.93827773678688, 56.34693422625142, 54.741445356799716, 56.18988644692206, 56.84609505438036, 57.45404674160866, 58.5197860963883, 60.38479466592113, 58.537609346451305, 60.90601882626934, 55.0315870008161, 45.98404007573282, 44.167778722701534, 44.21529823733915, 42.093488170254616, 43.157419312384825, 44.998356296170144, 43.0193087362474, 43.65494058978173, 43.79881312770229, 43.90864733726748, 43.644609066747854, 45.975246121806485, 49.7524493740451, 44.708485295695645, 47.455356428700114, 58.25414749883837, 57.37226532351587, 57.44402900818856, 57.499350117098906, 57.479224435744754, 56.49128921570317, 56.511407052316976, 55.57352519804432, 56.736947259595325, 52.34963109416347, 52.027486831911155, 45.40514138437087, 46.734793493824625, 45.579906509768584, 44.71507095521496, 48.35299476500481, 47.84000365964828, 42.25384250763924, 44.916288545054776, 46.068578920056744, 48.929292924942516, 52.05933647771036, 46.71296158144551, 50.55719421755884, 51.74925350373792, 57.454964576228974, 53.57545806515602, 61.110888142739576, 48.23742997261786, 43.58148636356477, 60.228017530133656, 53.52818173746909, 55.720657225578066, 46.120617005132864, 44.49846198481899, 53.854315050186656, 57.107972098935036, 58.110016084486446, 59.157900810241706, 57.614914909485854, 60.99091068390877, 62.060219395545225, 59.42928960246425, 60.00389722085769, 62.809694120960856, 62.10427937969085, 63.60425649150726, 61.72903014767555, 65.96810033244472, 51.68896275181925, 19.389650552503525, 1.6242958989835556, 1.144508270006026, 2.845910244411038, 10.730110368421002, 62.5171676758797, 56.61811121048466, 60.83452186276836, 63.27907631474157, 61.91391891048801, 69.6529866803077, 53.029981890032374, 50.79384257716518, 65.12917595524942, 35.557391720433394, 60.406387313719726, 31.45003864842077, 61.72487635766307, 9.272346784991603, 0.10312078190186333, 0.09072937101366059, 0.05845911996138673, 0.010815951071919934, 0.009908434698328136, 0.04439107202474148, 0.03205216497242932, 0.05273899807023907, 0.038055160999177925, 0.03642352012496802, 0.2469709040897508, 0.14007076530927612, 0.31747909322861706, 0.1585720951158193, 0.14443268608902732, 0.1665885310860411, 0.14750420836912048, 0.2360695342142736, 0.08451555525102923, 0.1517825336345742, 0.13839554552349354, 0.34534324321054644, 0.19323248686569353, 0.37895749593454026, 15.582479411555877, 74.92214971973051, 60.074252774638516, 48.274237494314875, 51.2084920175614, 66.31255503623717, 57.76906405725787, 63.27863700928227, 92.02330712349185, 67.97735014269429, 77.55213029922979, 66.720230502467, 73.6689995181176, 66.99704785500803, 63.15496075537897, 3.362724925241163, 2.381013035774231, 0.9664604272092543, 20.368838887060843, 53.27795805469636, 61.361841386364354, 66.66906710593932, 65.49159119206091, 66.00807712924096, 64.2914596680672, 65.31929323750158, 65.45457186237459, 63.46485153321297, 62.482015394395404, 64.46669940025576, 63.47531641683271, 64.59136409144249, 66.1495570213564, 62.72858342816753, 58.89438029258483, 60.487152837937884, 63.71250998589301, 63.160428539399184, 62.24008360216695, 65.20702323605938, 64.54988502687024, 62.43799855632167, 65.28029311087825, 63.12367985325476, 67.08735650585544, 62.83283218260735, 56.10119381258565, 54.0515043658595, 55.80489012502856, 51.82002875112718, 51.477758807520715, 47.17177298761184, 46.802701488617934, 49.45024251937867, 48.30232166474866, 53.04423578323857, 53.1774002505887, 58.05857812204669, 58.31710546247421, 58.73638722204394, 59.37649842231505, 61.71519987044796, 61.0459650716474, 62.72814020033806, 63.0680057310289, 61.10289827469857, 65.2925818966281, 54.70340621086859, 46.35430789762928, 46.110932673177416, 47.957129555363814, 45.3660039747915, 47.92718225909818, 47.19420502262731, 47.27764952567316, 46.804517546007716, 46.55589811263546, 46.01841965029317, 44.99287674503942, 49.04248468337521, 50.74531501339328, 45.59770230324038, 47.45365019767515, 59.855074651779674, 57.167462687338556, 60.64337691953106, 60.42178653901624, 60.02827082910846, 59.066411525972434, 58.752084547473544, 56.8109663071171, 59.13081684420186, 56.12683434640208, 54.64582189436882, 48.576479650312855, 47.889578496256185, 46.708376330714074, 47.516184545332386, 49.68401185927853, 49.442817472642474, 45.03705440029022, 45.73414587205457, 48.53054085085469, 51.0222186580781, 54.08521713749055, 47.785070865384995, 53.50720097941738, 54.04283985014885, 59.33523116573211, 53.79624043741534, 62.17284633267311, 45.903435368691724, 45.72373982398741, 62.431918882554584, 56.14770527808897, 58.11817461444486, 48.95307425529727, 47.90502478999477, 55.66014682092975, 62.20238570244082, 61.63278302838726, 61.18158886509558, 62.011742822585575, 63.527064246516076, 65.85284540730139, 60.675418761468705, 64.03100252151489, 63.90251744178034, 63.06316944860644, 64.58891653245496, 64.36749089148738, 66.83899987128474, 53.57834492960284, 28.094903999759307, 3.127216749614285, 0.5179499005598407, 6.0160852824488, 11.4672629679403, 70.45268735577984, 61.52051302694506, 66.5897254020937, 69.86644990982549, 68.82142851429602, 74.23250290655321, 59.63233109443419, 57.270993648036836, 70.39163958641791, 43.54481612482379, 62.11326160738545, 41.20243549346924, 72.2625317112092, 17.895274585293187, 0.1615359360772756, 0.21763807162642482, 0.16217502194546884, 0.13306322117005626, 0.06274975242934401, 0.15734572624487264, 0.1382654791157092, 0.16489005287087735, 0.17040040073615892, 0.19275665433416445], [0.009041786242666985, 0.0542043442387254, 0.03633824687811636, 0.011282786858388254, 0.07556144298324663, 0.02505849851595779, 0.0794490480855588, 0.03002744629949091, 0.027381765483427915, 0.012845336177927113, 0.02000297705132154, 0.02749930826887008, 0.1187758039562933, 0.04682638892723669, 0.8673171278449797, 32.34085402181072, 45.850377467370805, 30.745259331118678, 27.607108239204656, 47.3559243448319, 55.500945660375784, 41.15418641797958, 61.99163675308228, 57.29660280289189, 60.70500519967849, 60.40350829401324, 60.41456153315883, 53.77508317270587, 58.260148725202015, 6.728033221537068, 1.2810660778514802, 0.6345589627181331, 2.281800114339398, 41.66945249803605, 63.9964032942249, 65.04886542597126, 63.70674017936953, 64.83591210457587, 64.89006826954504, 62.03635177304668, 61.06420801531885, 64.35906171798706, 62.08436158395583, 64.08788473375382, 59.865986685599054, 63.28061388384912, 59.76432669547297, 59.62021489297191, 57.50628486756356, 59.641007377255356, 58.12034760752032, 59.30439349143737, 58.39756111944876, 60.24205961535054, 57.9897326807822, 59.27522282446585, 61.69159896912114, 58.65151497625536, 59.444296590743534, 57.38982577477732, 56.21553874784901, 53.32199842699113, 50.47092560798892, 49.53484019925518, 43.96791827294135, 43.41404430327877, 41.420425138165875, 41.30307174498036, 43.46823576957949, 46.56707686762656, 49.02148431347263, 56.72982815773257, 52.72834377904093, 52.51020900664791, 55.71576995234336, 54.708375853876916, 56.96528019443635, 54.15539226224346, 56.610831291444846, 57.24569043805523, 48.78259628049789, 45.13738862929806, 44.327838882323235, 41.161274140880955, 39.22154834193569, 40.64305843845491, 38.69693525375859, 40.57971608254218, 43.82958412170411, 40.63938709997362, 41.12100708869196, 40.71098212272891, 41.818043647273896, 42.08418823057606, 43.31294521208733, 44.8845055795485, 43.64174181415189, 45.61298385743172, 55.24469721701838, 56.150513695132354, 55.8419055323447, 54.473774971500525, 53.235129694784845, 54.26960383692096, 53.03179010268181, 53.26142134204988, 52.13843891697546, 51.09512375247095, 48.75218222218175, 45.26719162541051, 42.543007481482725, 41.850956255389804, 43.50357632483206, 40.378973099493216, 41.98936885403049, 42.64605991301998, 42.363245256485484, 47.76936569521504, 48.674248649228005, 48.521460563905784, 53.214470571087254, 54.91451601828299, 55.33715140435004, 52.559768153775124, 57.08901136152206, 48.52997602954988, 36.58357397202523, 59.28802151833812, 54.71650692724413, 56.82747556317238, 51.33943250102382, 48.47397635059972, 42.123227580901116, 45.92522805736911, 45.27387142181397, 51.779232178964925, 54.48635009027297, 54.88261930404171, 55.7726364751016, 56.800473966906154, 55.82124248627694, 58.0375934416248, 57.8138457575152, 58.27337495742306, 60.30581382013137, 58.87465861535842, 39.381808542436175, 3.6312530838674117, 0.26310116112712895, 1.36079830267737, 0.8933452408640616, 14.862821563597649, 54.17020313201412, 56.32099951467207, 55.043565919322354, 56.08891287157613, 56.80910710365542, 62.86190871269473, 53.74919160719841, 64.45346532329437, 37.227211383081254, 32.69865459011447, 47.70593312478835, 40.34028284011349, 44.70517089290004, 0.25763904615756006, 0.06841928187397218, 0.06375251172651207, 0.009755690172765284, 0.11368366348887644, 0.011412237523003452, 0.011108161904098047, 0.028396242095397848, 0.03258081543589792, 0.022644704853695248, 0.07671938488079656, 0.01313657790888101, 0.040854024926140424, 0.03636038298868845, 0.06001117962202238, 0.056785152729360334, 0.06198286011274304, 0.05079843607100268, 0.04168938252053434, 0.021230309277832992, 0.027449204203402324, 0.0495277336918779, 0.11190252438668283, 0.06724060197631199, 0.0672858318073615, 2.0823122897455772, 46.64188431155297, 46.13678109261298, 29.6191958842739, 43.04632602199432, 52.542784290929, 61.254533183190134, 46.29341702307425, 68.68594200380387, 61.48727878447502, 66.81730916423183, 64.70854490034043, 66.05510634760704, 60.216560286860314, 64.56455861368488, 8.432120180899098, 3.1963541623084777, 1.1426086171019463, 3.5226512339807328, 44.02783247732347, 65.3118799578759, 66.11477344266831, 68.05116914933728, 66.25863813584851, 69.21264571528282, 63.4782934957935, 64.63757353444254, 65.69259305154124, 65.22674491328578, 65.0854846739, 63.83046742408507, 64.76292071803924, 63.34240690354378, 61.11475167735931, 60.357687165660245, 62.24646529843731, 59.315399662140884, 60.52674132008707, 59.877110527407744, 61.35617356146536, 63.209795490387954, 61.759404982289965, 63.99878417291949, 61.05864217204433, 59.342711125650716, 59.53161639551963, 57.076416630898755, 54.62464894017866, 52.93847691628241, 51.07912832690824, 45.698303253419944, 45.38070109582717, 43.738169362468106, 42.523842780820786, 45.66705765262727, 49.800827887750444, 51.25937692580685, 59.892046913023925, 56.305545376193145, 56.16207292003017, 58.34724887724846, 59.61488046953755, 59.27650151714202, 56.5806015845268, 60.870156595783854, 60.65615992392264, 51.72697051878899, 46.71396178583945, 46.20890563534152, 44.06962140913933, 43.063231437437, 42.72924946200463, 39.95858915390507, 44.51878378468175, 45.14670425845731, 43.13155520346857, 41.75321863543603, 44.43743382730792, 44.36445813025198, 44.099992321383574, 47.94449167866861, 45.38870273097869, 44.8627285803518, 47.09512595207461, 57.469740144668094, 57.96817533431515, 58.03668345174482, 57.951101256955056, 56.94699410469302, 56.4603691716348, 56.43005317257297, 54.031547346422755, 54.821598991270996, 55.44691893362231, 51.07868509907877, 45.76215943982525, 45.19955035178892, 43.72426848257742, 45.257534750046275, 43.051248596560576, 44.44572179548202, 43.37899792578913, 45.340437966008345, 49.344730761743364, 49.80783716324837, 51.6481504901763, 55.11700445605863, 54.699856465862645, 56.6851366719892, 56.15214540112404, 57.306051792637, 53.21966771156558, 38.81197837091262, 59.681372488698656, 56.983887918533824, 59.089839843011674, 52.812211898065385, 50.126329698870265, 44.40051647924608, 47.90496987681235, 47.73870452757805, 53.002701805483916, 55.07725515673238, 58.40717092637093, 59.24881742846582, 58.32784098963584, 58.48251573501095, 60.89596186914752, 59.47395363161641, 60.23143391455374, 63.60129510202716, 60.66034117052632, 41.40333144895492, 5.15939551015054, 0.7930565481224369, 2.827330222052913, 1.1511642870403107, 17.100480794906616, 58.46367266870315, 60.14400428341281, 59.97571106879943, 62.53153531782089, 62.047758025507775, 70.6746542838312, 57.31129992392756, 70.42339509533298, 43.114740002539854, 47.277853488922126, 47.14461449653872, 38.701971577059844, 54.02695425095097, 0.40214565973128047, 0.16791125849610375, 0.01060289052885867, 0.09194222609362296, 0.11877591886948194, 0.04661101096820447, 0.0216148337048869, 0.03049455883522188, 0.03182912421893449, 0.03152951872306726, 0.0776541653660036, 0.13662758313359755, 0.12037387102722161, 0.1450046779768121, 0.15017793183365177, 0.27196519677677466, 0.20538648710616175, 0.2235251049240751, 0.1812020412856533, 0.05077268019498837, 0.24351279852130722, 0.15453646650477765, 0.27380546254496424, 0.35961025184200657, 0.2664844199053703, 3.0167311814523514, 60.75513309048068, 64.14249589366298, 47.19476984393212, 40.1007789950217, 62.827893918560406, 67.55713878139373, 49.24617728879375, 73.35985399061634, 71.17979280410275, 72.59222261367306, 70.42479145911433, 72.65079144508609, 65.19178875031011, 70.17468544744676, 8.1830398690316, 2.6927529659963425, 1.0423154504068437, 4.69459415443482, 51.036617678980676, 64.14128388127973, 69.63806598417221, 68.3775495713757, 70.640961124051, 69.99005948343586, 66.69231107158046, 65.88092173299482, 68.36211896711781, 67.72463183249197, 70.0314091097924, 65.35954852258006, 70.05401765146564, 65.26534495815154, 62.957775362076305, 60.56186614498016, 62.719020689687426, 60.85169007701259, 63.52124737155054, 60.45179267083446, 65.64040591639858, 62.96051317645658, 63.511500281672326, 67.43145035159203, 63.98299271060575, 62.30542244449739, 62.39551928735549, 61.184871888929806, 57.04406884408767, 54.57982801621961, 53.739256243551935, 47.479886931757775, 46.25897469059114, 47.760089289757516, 44.465235587089296, 48.22776917488345, 52.56683626482564, 54.91277056355631, 62.897959216948486, 58.47592615312146, 56.970124321599165, 61.00172073610368, 60.84028774692167, 64.1394050659672, 57.31118225282239, 62.27549083771245, 62.423536777496345, 50.874380603913345, 48.015055118068574, 47.36381223124843, 47.2787909353933, 45.7201704671306, 45.54926887635262, 43.13526968802176, 46.470139411187944, 49.7953365695092, 46.950570921744074, 45.25283967295001, 46.53255608774001, 48.010983697829715, 46.740269122585175, 49.57671542321482, 46.7657684510754, 46.26190862348003, 46.88138423427459, 58.283486827727295, 61.448180598597375, 59.87347841262818, 59.27910989330661, 57.55149802853985, 61.112523771101436, 58.01212156972578, 58.41205035486529, 59.71350454515027, 57.769770083888886, 52.73651015373969, 49.218485355377204, 47.038588908410844, 46.5099161671054, 47.21638994832193, 44.80677989221389, 48.034694425521366, 45.66331178911271, 47.25056948200349, 50.84793206184141, 52.847046467565725, 52.847262197925204, 57.709636226777114, 57.66625873504147, 58.60910630995228, 55.88452600663709, 59.782369598265625, 48.85283808554373, 36.995850378467196, 64.26330097260015, 58.52688166403002, 61.74774769813784, 54.23009772454539, 52.970220658086966, 45.61510193732477, 51.146349906921394, 50.265460091252486, 54.756832814985714, 58.9247747390501, 59.87407461289437, 61.93253840169599, 61.90376781648206, 60.978849395628906, 64.24956090988653, 62.83315381696148, 63.29168673484557, 65.68270083396666, 60.697419335765225, 47.53086205451719, 6.5252035375564335, 1.373844105870493, 5.837955744035783, 3.341505147757069, 19.484499346825388, 66.10605793614542, 65.33769699835008, 65.59273342932424, 65.60636758804321, 68.8055899835402, 72.98840553529801, 63.53352046781971, 74.3919707882789, 50.96939217659735, 48.89780413719916, 60.055872548011045, 53.36870601100307, 68.76146331910165, 1.3178259182360865, 0.23778895727328717, 0.12408559766387749, 0.17724997754539215, 0.15360645108645962, 0.1801677766225992, 0.09293362813731355, 0.18538835939140091, 0.13110134660476638, 0.13966276220256282, 0.19354722642850494], [0.02849979611534265, 0.1057577791113046, 0.08510676828483421, 0.03147800888625845, 0.04401172826727552, 0.04897672495233917, 0.0790003810318247, 0.03284458333866731, 0.05540388088012415, 0.06099904616994243, 0.029246787382890622, 0.05165348595549023, 0.02050984763510285, 0.03602068811174362, 0.0904602519867401, 17.54195336372622, 48.879341540798066, 40.18212895239554, 33.588597236141084, 38.775853341625584, 64.32556075434532, 51.90019023033881, 50.66583210422147, 66.85053948433169, 57.89639988253194, 61.0030778761833, 57.81281417415988, 55.73065142477713, 58.577899932861335, 14.822103438838838, 1.8237180238769901, 0.21895442518495747, 0.8566423974210217, 32.839244104200795, 65.44138877622544, 64.31503311280282, 60.86784239738219, 58.41905570799305, 57.30423965761739, 63.11476430585308, 57.935180356425626, 61.25206208998158, 59.29406589077365, 61.24803381581461, 59.79734128521335, 60.07957543096235, 59.60395666860766, 59.02190046925699, 57.611616196170935, 57.3777723312378, 59.06328931931527, 56.61132943245673, 55.12534733741514, 55.686175669393236, 58.228330458364184, 58.22176048832556, 60.04659222018335, 60.53795145403955, 59.72444011319069, 60.0638271147205, 60.27272862772788, 54.08486804654522, 50.065093655740064, 50.47083147110478, 47.2212968334075, 42.99071465769122, 42.99161288046068, 42.801566200871626, 40.67178979996712, 43.07190772025816, 53.904274279071444, 54.90415311628773, 51.266241073608406, 53.79236121331492, 54.75450684947353, 54.952602232656176, 57.426276360788655, 57.763549204795595, 53.76811704327984, 47.02936741613573, 46.86849140351819, 45.71181974103374, 38.94418970231087, 38.945378180473085, 40.5614927507216, 38.00987328252485, 40.086023038433446, 39.63739802760463, 40.5218062093181, 39.61853534944596, 37.70171619230701, 37.47495612790508, 38.014627195173695, 40.31679568752166, 41.40289214349563, 41.19213142702657, 43.661224226797785, 43.56471038633778, 46.67841334496775, 54.095858527768044, 55.58502558738955, 54.7367149783719, 56.91643099631033, 52.70647656533026, 52.808838659717196, 51.57883436449113, 54.36818868883195, 50.72371452085434, 51.137689313580914, 48.08765818995815, 44.19001856157857, 40.53754275844943, 41.09615495128017, 40.30531491002729, 40.58388948440552, 40.16084617184055, 41.98752926241967, 45.733290795357, 46.69308693178239, 53.557195509633715, 53.69558849642354, 54.71497720287692, 54.48541264380179, 56.73497822976882, 55.67743270627914, 47.976188352031095, 33.12227841346495, 56.291264026395744, 54.91562212667158, 54.8541860426626, 53.56073740989932, 52.97503732865857, 49.16864379759758, 44.040568413272986, 45.33807669916461, 42.790316843217425, 42.528886948862386, 45.56424448567052, 48.52838354725992, 50.24293391935287, 49.034839983909364, 55.5516383724828, 54.72568135107718, 57.56302195210611, 56.83786984412902, 61.27086593258766, 35.24027985911216, 4.814855004510572, 0.39776296264702277, 4.130568600470021, 0.41751522210336506, 23.515691757202152, 57.515078821489894, 54.43640655086887, 54.83559400804582, 59.528388284867816, 58.09439328409011, 60.98167350215297, 56.168925300721206, 59.75049641824538, 29.59116074346727, 43.554716187138716, 43.5482011302825, 40.959260309896166, 20.979355804381832, 0.14577885578957298, 0.13916239953569828, 0.08395993466218633, 0.037505558030980254, 0.05714498039695525, 0.03673920963680552, 0.033331470518943765, 0.11839873547996245, 0.04511920029237386, 0.036511041839877446, 0.0771540631690333, 0.022768707675558907, 0.019408253419603554, 0.0448611818794762, 0.01500071784962089, 0.04343230915706485, 0.020473201819244894, 0.03583861199477988, 0.05996193165981001, 0.016553210349933758, 0.028557626177526774, 0.09219319649761723, 0.0874643196021357, 0.08759490694970855, 0.04087627978034077, 0.03507229424412212, 25.798575916597922, 62.88274434305007, 28.270777194730698, 42.596186976278986, 49.38568422871251, 67.46039744346373, 53.33192986826743, 60.52887508946081, 70.99080516446021, 61.79070549626505, 67.79776834672498, 62.71676532683834, 62.18966153360183, 66.51825197281377, 13.998729298191687, 2.9337556467902277, 1.912595132185567, 0.8843159447273902, 35.7700155627343, 66.18889839418473, 67.16795336815619, 62.85144382907499, 62.2882346184023, 59.49748393028014, 65.3023878220589, 59.30212243910759, 64.7423125851539, 62.1855430449209, 63.73967632170647, 62.785520553588874, 62.40766294540898, 61.458610180885564, 61.88446583286409, 60.98781201147265, 60.363782528908025, 60.39822093902096, 59.20072132541288, 55.541577492990804, 57.15816667003017, 57.88591538706134, 60.34248798124252, 61.63098266047817, 62.71145051525485, 60.90617572107623, 62.61753328384892, 61.85188270384266, 53.613567813750244, 50.262290816153254, 51.39499679688485, 49.591808703637895, 44.72036223257742, 44.46668686405305, 45.05577587312268, 41.78512711678782, 46.581381751645, 55.02818238350653, 58.02600676013578, 55.873410009568744, 57.72701232664047, 54.68187239862258, 57.50475906556653, 59.00379088617141, 60.11817547582812, 57.20954971928751, 48.76068199834516, 47.46474658289264, 49.21243313820132, 42.78670434028872, 43.34436339716758, 43.43643711459252, 41.86320973980812, 41.866320179354766, 42.46231255992767, 42.45961789161929, 42.08744379781908, 42.458143080434496, 41.358777246167584, 41.74234974768854, 42.941555592321585, 42.88930962162633, 44.17540773268669, 45.02585211107808, 42.018523831521314, 49.83796488854193, 56.09493763216081, 56.81112712429416, 55.798869286814046, 57.97762040169009, 56.99170520228725, 54.02078436266992, 54.43962681678034, 56.83563017076062, 52.46757284287484, 53.67440769749304, 51.39625980008034, 44.48350598735195, 43.95481363419564, 42.296462981931626, 42.371392019333385, 43.59837608952677, 42.24651159778718, 43.75709872091971, 48.471289527031686, 48.18647838407948, 55.14851285565285, 55.62594767539732, 55.502640124290224, 58.87314065810173, 60.25612523478847, 56.635330415541134, 52.3308821647398, 38.51482352902813, 56.5351923050419, 57.080480206397276, 58.27294349670411, 54.50942931636688, 55.62706162852626, 51.246958701841294, 46.423784840491514, 46.45952155513149, 45.324568056291156, 45.96621290329964, 48.59687989757907, 52.044156905143495, 53.29100778025966, 50.33265421467443, 56.0752865575975, 56.3570107952241, 59.83379971596503, 58.72855817117999, 62.473935311840435, 40.49050569534302, 6.933854203070364, 0.6476521407884936, 2.28621008415376, 1.3286607303927023, 24.63289849219784, 62.44072068122126, 60.13544959406699, 60.685899334569136, 65.73998705033334, 66.0309680815666, 65.09354906697428, 62.65167359382876, 64.00555810620709, 38.717978769733065, 55.91681103552542, 41.36945001540646, 48.27359030323644, 24.589077772632724, 0.287538354675616, 0.12203871032163022, 0.03948713637768261, 0.04233319132078079, 0.05351168584198721, 0.027092400667888504, 0.06499597201904943, 0.03563247305611449, 0.027744475556837938, 0.060236570350224936, 0.021158704954770305, 0.09724421336525872, 0.2526607463556913, 0.1754876229191019, 0.09761711432328148, 0.14503611822522458, 0.17947002374116452, 0.19644910619864542, 0.11733447081379353, 0.09563406508776451, 0.1558290713376576, 0.18948052529125445, 0.24369431539408623, 0.18284597404060826, 0.1896186815875192, 0.12600645588170137, 37.67908411641275, 75.7974030894618, 58.64067746746925, 48.353108513739805, 53.06907223116968, 78.50393264524399, 60.73386992177656, 64.33539021399714, 77.30856680100965, 70.7348705107166, 72.80588980643981, 69.3124072782455, 66.98196241932531, 71.9153078140751, 16.846395538699245, 3.8394377837258005, 1.2072117698769416, 2.275004362867725, 39.9659945887904, 66.8810006110899, 71.22096200143137, 67.19580219637963, 64.25541700855379, 62.01669677611321, 68.13590803454, 63.159804882541785, 66.82016464971727, 64.86257637700727, 66.72103851072251, 66.24310554996615, 63.715863612390336, 64.16262549738731, 66.14870978939918, 63.00099595900505, 60.21189266635526, 63.14277002888342, 61.62087471254411, 58.48564578640846, 58.90320170310236, 60.170539117628536, 63.40778496957595, 64.70904696372249, 64.6606174592049, 62.3154244884368, 66.78313747529062, 64.96447955408405, 58.17084420111872, 55.41362585559968, 55.38721261485931, 51.39725215973393, 46.11775759727725, 47.57445527661232, 47.60961932520713, 44.10950014668126, 50.430874286159394, 58.9454613193389, 63.15990686416627, 56.868574157837905, 61.271179722201445, 58.81022584053778, 60.98504281813099, 64.72875687383836, 64.04404047996768, 56.28816927632978, 47.840086029421904, 49.721705836634484, 52.66675472259522, 45.60617854518276, 47.80952684340939, 46.157769695405044, 45.013347594968735, 43.763860887096776, 45.15183864101287, 46.04069086813158, 44.615152497445386, 43.45697856718495, 44.405972496155776, 42.726456734441946, 44.271035117487756, 44.08331048104071, 45.68576735834922, 45.74326146033503, 42.547910444198116, 47.096439946082334, 56.76733386132025, 59.386939771713756, 60.64123530541698, 61.71758467151273, 60.48908264406266, 56.60501049410913, 56.200339563431285, 60.03006335227721, 56.37212760986821, 56.59921715336462, 53.570743376208895, 49.240858554840095, 45.88991103633758, 44.80165335439867, 44.27844055237309, 44.791227694480654, 43.746033714663604, 45.04168671946372, 51.972612873200454, 49.99663260675246, 56.965362564209975, 57.25085227720199, 58.25364543545631, 59.27374801328106, 62.45183275591943, 58.66320363936886, 51.94675660902455, 35.11746652664677, 59.126772880554206, 60.00159086719636, 59.708970285231075, 56.31093863518008, 58.03097248077393, 54.780065013516335, 47.630388275269546, 47.7249683872346, 49.13745310998733, 48.011328866404874, 50.85052082615515, 54.51664647748394, 55.66091952785369, 53.47059742096932, 60.076017841216064, 58.85096749951763, 61.69538797870759, 60.19158263360301, 67.8278293917256, 41.502806678895034, 8.790153149635561, 1.5029887566643378, 10.256221371312296, 2.4998177059235114, 26.958014811238936, 68.82351521522769, 65.52651989844539, 66.26539245728524, 68.23608536874094, 68.07158900845435, 70.5604427091537, 69.05887311504733, 72.40167387070196, 44.37968477126091, 55.65122342878773, 52.93924962320636, 59.49947649432767, 37.06875155048986, 0.36239706520592013, 0.2682619277508028, 0.15573501106231444, 0.12895132084527325, 0.10267693354117294, 0.14714001016991754, 0.15838296332907292, 0.3195047522744825, 0.08585090012920481, 0.14395024987959093, 0.30972190141197176], [0.026430198096580086, 0.029667813984316685, 0.010163770845880913, 0.019560254839879852, 0.037798939062462705, 0.020115636026246414, 0.037786283289953586, 0.07456071764951752, 0.03427863098500717, 0.041306713941477, 0.041214212655059757, 0.09300033141288067, 0.05274289745777365, 0.05421833300422277, 0.20090205354555962, 4.5151261072005, 41.78296981319305, 42.36065256980158, 29.995051122480827, 29.431271206948068, 44.801210126569195, 64.18555959578484, 47.28874198852047, 61.60906445595526, 59.70645604595062, 61.28044043817828, 62.37268717058244, 59.91835424976965, 61.54679290709957, 16.40534266348808, 4.25224248440035, 1.894948633928453, 0.16237990449993842, 17.336834976750037, 64.24929026634463, 65.04400168695759, 63.29094148451283, 58.07846061645016, 53.208014349783625, 54.4860912138416, 57.63276561614006, 54.518238959773896, 57.7103461757783, 55.10785748881679, 58.84525652854674, 55.546296104308105, 58.24684404557752, 58.26395342426916, 59.11701794593566, 57.74570634288173, 63.666355456075365, 62.42684725792178, 60.94037486660866, 57.276320226730846, 56.3318056444968, 54.04757022857667, 58.00079376466813, 57.69322110760597, 61.49067555704425, 60.6978625635947, 61.100635067109145, 58.95030936887188, 50.12734167037472, 48.270864255966686, 47.464162149736964, 43.63451288592431, 42.12989953256423, 39.21849673794162, 42.303895873408166, 42.460449434095814, 50.14746735172887, 55.12688882889287, 55.83441380531558, 55.00979038976855, 55.356567136703006, 56.43971397030739, 54.34561544849027, 50.114637113386586, 46.22843903879966, 47.77300173236478, 45.52438535997945, 40.11968874162243, 39.11555413276919, 39.085861790564756, 40.588474735136955, 39.7377283342423, 41.54805906357304, 39.93640030584028, 39.36290271820561, 39.69504902439733, 38.80283532604095, 39.953756793852776, 37.919513640865205, 37.219382332217315, 38.45174789428711, 38.31259396768386, 41.14138772410732, 41.94147279185634, 43.48148553602157, 46.12859902843353, 53.60984940682688, 53.90693756841845, 55.371813389562796, 54.592312920478086, 54.01341422911614, 53.976834204889116, 54.64901862605926, 52.890922100313254, 50.13240545026718, 52.59467724830874, 46.469441229297274, 40.08544252764794, 39.31197074151809, 39.873136397330995, 40.30795466515326, 41.988478476001376, 42.74920255907121, 47.024025147961034, 45.46997424094908, 54.726167724978545, 54.93307667393839, 55.47510900805074, 56.900361045714355, 55.149493448195926, 55.573827220547585, 53.14225581384475, 45.65245859084591, 52.47259739906558, 53.998779866003225, 55.37360199036137, 55.64803454183764, 56.63136489929692, 55.690635404279156, 59.12690624114006, 52.92195981548679, 51.91576596229307, 49.248048259365945, 47.98148747413389, 48.87956119352772, 47.91854519997874, 47.31746158292217, 52.12719348169143, 54.79126730272847, 59.08639207963021, 56.581276232196444, 43.38956871340352, 40.695763326460316, 6.6996990000048, 0.19153025481970082, 1.1272073080462794, 0.11987635054655614, 27.295299422356393, 52.94725125835788, 53.29680504337434, 54.41465308589321, 50.28560146208733, 54.2098347602352, 59.366955295685806, 60.83470229179629, 48.9255117600964, 27.364062493847264, 52.420096474309126, 31.978978110897927, 43.52911879939418, 5.199193839103946, 0.13943406963540664, 0.12246374356290027, 0.01394985301885754, 0.019402442642697887, 0.030439105560822837, 0.029769590680277156, 0.026804520147702387, 0.06619366621899028, 0.050038419393522125, 0.014693213987254329, 0.038986827336972764, 0.05384122239305608, 0.03044099779799581, 0.034656997980369676, 0.008407839866835744, 0.06243164207966578, 0.04576534566078936, 0.08604174795290155, 0.07021940463492948, 0.01778469668821462, 0.025819223824768298, 0.041607093186147755, 0.06295805556639548, 0.08213627768019516, 0.12519404262063966, 0.3453279520955778, 8.624495767777967, 59.21546159252044, 39.74170561759703, 37.31789265909503, 46.77159709315146, 49.394984168391076, 70.00692567517682, 51.42201800500193, 67.63924183384066, 64.1460221044479, 67.23816379424065, 65.27269547985446, 64.0951136619814, 66.45372898347917, 18.362725011764034, 4.326951869072453, 2.354020755137167, 0.3058453126540107, 19.45706040628495, 67.30982549728887, 66.54834439677578, 67.97806401406565, 59.585137136520885, 56.95375627087009, 56.657797751888154, 60.46812149786181, 58.67261732778242, 58.9854302713948, 57.51625945491176, 62.87537813186646, 57.70747500081217, 59.71452436139507, 58.76180418076054, 62.84487778140653, 60.42590502769717, 63.86493329078921, 64.82279177634948, 61.224472138189505, 59.4623512606467, 58.579900341649214, 55.32860848211474, 57.80667566484021, 57.97723208704303, 61.65696836286976, 62.29527135049144, 63.30175153670773, 60.39033305260443, 55.47472853814402, 51.76602555859474, 49.16654140718522, 45.01069215036208, 45.32683126388058, 43.60110998153687, 44.98675392520043, 45.117855225839925, 53.100529639951645, 55.64955249909432, 57.83210831303751, 56.796226040009536, 58.4257786504684, 58.62680796653994, 57.172044015699825, 52.57582633726059, 46.69908815814603, 46.05831015494562, 48.61339307600453, 44.14535453242641, 42.427638807604396, 40.85952228115451, 41.756093732772335, 41.71872138977051, 42.197513349594615, 42.108907007401996, 41.89248238840411, 44.018285428324056, 42.693551971066384, 42.244526878479995, 41.73579154476043, 40.782243744019546, 42.20766836597074, 41.36543350835001, 43.71251313917099, 45.23298463513775, 44.57905492474956, 47.8564658472615, 56.70298737864341, 56.96767284024147, 57.53105855757191, 55.824082282281694, 55.34292121087351, 56.483899470298525, 58.24705585356682, 53.36141824722291, 52.52078763900265, 53.947918491978804, 47.432414485562234, 43.039379504419145, 43.46737284814158, 42.354188503757605, 42.67748594284058, 42.84288052589663, 44.20377823614305, 47.47587826944167, 47.28696123246224, 55.388055924446356, 57.3639577434909, 59.28242429610222, 59.74378524288055, 56.82369832069644, 54.30898051108084, 56.38950370973157, 51.80398625712241, 52.400010016656694, 55.33752402951641, 56.084347232695556, 59.054734629969445, 57.9241898752028, 59.6851497311746, 60.27834546181464, 54.96678944556944, 53.5186033095083, 51.312740772001206, 50.18707544572892, 51.5089887188327, 49.96699517773044, 50.62830678878292, 55.02584465088383, 57.12636017030286, 60.118948182752064, 59.85950693007439, 48.38974737351941, 40.837031410586455, 7.767125954551082, 0.42272443612737043, 2.2059525068729156, 1.1411803840629517, 29.13607951133482, 58.94348836714222, 59.969278381716826, 62.062109977968284, 56.29428425142842, 60.59735575029927, 64.20078623679377, 67.49181562854399, 52.7619977151194, 39.03432969124087, 52.06107016532652, 30.838988288756344, 53.61545055143295, 5.769530486676001, 0.20788442403558763, 0.06367181585500799, 0.03594597921736779, 0.0429528683514124, 0.01116252733364461, 0.06496318345589024, 0.0065439656628446, 0.08557295576939661, 0.043259464399588686, 0.03429122547048234, 0.027178516611456875, 0.16306843368276475, 0.1860559284086189, 0.09435617680390997, 0.148734484288481, 0.16506591601477516, 0.1926550251101294, 0.17471384347206162, 0.16943670809268954, 0.19131728237675083, 0.1858575882450227, 0.16138788192502915, 0.20557079253898514, 0.26594638103438967, 0.24519229307770732, 0.5643069840246632, 13.894130472213993, 71.48358037394863, 58.920683706960375, 43.44795711578862, 42.35169779869818, 62.454523501857636, 75.94606091899257, 58.68015220088344, 72.91962285195628, 73.6219467655305, 73.54065956607943, 73.56027926168134, 69.95938654868834, 72.47655191729146, 18.94943706450924, 7.08980469934402, 4.327152400247512, 0.7794583036053566, 22.61076173474712, 69.96854136067053, 68.66389828343546, 71.48936194758262, 62.2687678952371, 58.435435525832645, 56.78388234107726, 63.12286007788874, 60.008341266262924, 61.095539908255304, 59.55792765463553, 64.57967935069915, 60.75061059767201, 63.06992769241334, 60.61938770355717, 64.78431332495906, 60.96743529842746, 67.96380227611911, 66.79757179752474, 61.98292909129974, 61.9663296207305, 60.1842164224194, 56.21723321176345, 62.327748575518214, 61.194846476278, 64.60218983311808, 65.58480239683583, 66.86935117167812, 64.83205641469648, 58.04652075613699, 54.612501359755, 53.022494085373424, 49.20708694765645, 47.47059091444939, 45.102950219185125, 47.60549691415603, 48.64227740995346, 54.56765297920474, 57.29601444736604, 60.6018154851852, 59.390222795547984, 60.75941239633868, 60.82025620245165, 59.41067795599661, 50.686381401554236, 46.45750545686292, 49.65298983358568, 52.458233679494555, 47.10849338962186, 43.75851469655191, 43.73544723756852, 44.51677553115353, 44.877817938404704, 45.56902585491058, 45.03774865981072, 43.357483725393976, 46.354233372596006, 43.3362284014302, 44.77971946039508, 43.15008840253277, 42.152480617646255, 43.594885180073405, 44.155972388482866, 45.40270559249386, 45.08894735766996, 42.993985914414935, 46.20388500152096, 57.20183049478839, 58.776826858520515, 61.24620991368448, 59.99264394083331, 59.419193421640706, 60.004654238300944, 59.64456888937182, 56.108705151465635, 54.4786661671054, 55.666783471261304, 49.66672597392913, 45.56788052282026, 46.478858840081, 43.733250710272024, 44.53849761716781, 45.35549202272969, 47.46003189394551, 50.821628647465865, 48.57529509452082, 58.11054168208953, 60.00769799755466, 60.82472378207792, 60.108714718972486, 58.47969555085706, 57.27194286161854, 56.246070477270315, 44.87468396463702, 53.767905235290534, 55.36078760700842, 57.86753123806369, 61.292540950159875, 61.99217804016606, 61.873377292386955, 64.13813421803137, 58.90887345037153, 56.454748415177875, 53.44424301578153, 53.14649981837119, 54.893629397115404, 53.66986167046332, 52.264637254899554, 56.38297688576483, 59.68491046659408, 63.66382944968439, 61.738792927034446, 51.234830733268495, 47.65944519350606, 10.178865367366422, 1.2382986372517002, 5.713661226534075, 1.7638450043816722, 32.18566740712812, 64.91583431920698, 65.62646581280616, 66.61419314722862, 63.9841615769171, 66.18814529911165, 71.36536013695502, 71.2451865596156, 61.25411741195187, 39.17528398575322, 61.59555973545198, 41.22014891716742, 64.89415145689442, 10.911926934795996, 0.6644573519306799, 0.313088244968845, 0.14905602671205997, 0.11214635485122282, 0.103855766656418, 0.2829892632942046, 0.12515304159493218, 0.1737106053699409, 0.14312468288886931, 0.1563111704684073, 0.1473026506362423], [0.01384708519664503, 0.03239314304664731, 0.002538602791666504, 0.05272176109194275, 0.13414178103689225, 0.020546947358055942, 0.03501626257334025, 0.023489226774883368, 0.015341438326774346, 0.016746649466034387, 0.01375277211228686, 0.019475257384680936, 0.09683827869594099, 0.04283371103566982, 0.1070642424747348, 0.5114550990683417, 31.611583425152688, 41.25749772594821, 35.23356868374732, 31.357160845110496, 37.54890849513393, 61.088118783889286, 67.05804071118756, 57.26196042952999, 63.756354239679155, 58.61385237786078, 63.77643285259124, 56.83442992548789, 60.829991525219334, 15.631049140807121, 1.3369113134761013, 4.9753897709231225, 0.18515621942858543, 13.376108927111472, 61.52449423266996, 64.74295585386216, 59.26342433498752, 58.66904404855544, 51.64322399323987, 53.2809429783975, 54.150587358782374, 53.72550049135762, 54.75706031245571, 59.96669353977327, 60.43886846111667, 60.05277779794509, 62.48942475165091, 58.79129255971601, 60.86381412321522, 60.6700215801116, 63.46216863201511, 59.827386640733295, 60.87818568752658, 60.55926169118574, 61.31262348544214, 60.00059066280242, 58.80529149886101, 56.56204877361175, 56.93433269377678, 60.05688059714533, 60.47931594233359, 59.80683734340053, 55.680994218395604, 48.9296067145563, 47.41516390154439, 44.147378475435325, 41.65842671548167, 40.393172079517, 41.87660855631675, 41.448717194218794, 43.26224465523997, 48.70544718157861, 52.32543399257045, 52.889368841725016, 53.99016634110482, 51.31035989330661, 48.95350963838639, 47.67525234530049, 47.04353501719814, 44.393016907476614, 38.531677953658566, 41.070259463402536, 40.60359939452141, 39.64526630217029, 38.93934557514806, 40.87032448860907, 38.961903126009055, 38.757131868793124, 39.924217424085064, 38.403353691101074, 38.038286932053104, 38.86489114453716, 37.51838853282314, 38.48333866365495, 38.99346643878568, 38.11230205720471, 39.09132957458496, 40.4313132070726, 43.170912265777595, 43.346912937779585, 43.781315434363584, 50.931823715086914, 54.409059786027484, 56.37297484182543, 52.58091365137408, 52.49031474513393, 54.90950322920277, 53.97308441900439, 54.701507783705196, 50.5721462926557, 43.30923464990432, 38.07671439263129, 39.44029500407558, 38.54956396164433, 40.76043928823164, 39.041185994302076, 42.91403624319261, 47.54438246450117, 44.91713185464182, 52.00417618597708, 54.14819079060709, 52.493087860845755, 57.34358103044572, 56.09076423029746, 54.91184096182547, 59.4740399237602, 60.05302882963612, 52.665236765338534, 55.38541224695022, 52.39619355047903, 54.44852667470133, 52.97892831986951, 53.55322214864916, 50.1636157497283, 59.632240879920225, 55.567370999243956, 58.71814427837249, 53.83239684566375, 52.22412701575987, 47.63990394530758, 52.413659864856356, 55.89447705976425, 59.72584824408255, 58.2630552014997, 57.39080244495023, 55.5762630124246, 32.700807971339074, 6.29594394276219, 0.22873035061263272, 1.2014157325029373, 0.9322462663535149, 27.64919330996852, 59.60166208205685, 52.13533632216915, 54.25382414171773, 49.638449607356904, 61.38213180726575, 54.71177654881632, 66.08893286797309, 38.785780860531716, 36.64408045430338, 51.198870443528705, 44.24228414412468, 35.46433741046537, 0.3788413570052193, 0.11994319171794962, 0.021650362947595217, 0.030788472297811703, 0.02077982085005891, 0.03162503648068636, 0.052228178303208084, 0.05408884882326088, 0.020974905139976935, 0.011792900866918988, 0.014610069507222264, 0.032281363157615546, 0.024104035316756176, 0.02623492228468099, 0.012191208173340608, 0.025553211284380768, 0.04930946375093153, 0.005042937512870037, 0.006778841517159656, 0.061624629738470244, 0.04494914026450246, 0.04511912751402106, 0.031172971827008074, 0.05655382865018422, 0.1316187011017915, 0.0947458780701122, 0.15904901549220085, 1.8047932006659049, 43.89854331170359, 49.38052238956575, 26.24785988561569, 37.571579794729914, 44.09685834761589, 67.50752079871394, 71.17689025017523, 63.606758963677194, 69.64837397298506, 64.48880587854694, 69.08709849080732, 62.40659213835194, 66.95911853544175, 17.04531461961808, 2.0374056865130705, 2.6110171454568065, 0.37925761853975637, 14.378210767622917, 65.19337731022989, 68.01844089261948, 64.97153982039421, 61.753701856059415, 55.520588890198745, 54.50002739506384, 55.444232110054266, 54.26605016954484, 57.13296151930287, 63.509754826945645, 64.39942682943037, 63.09136736777521, 62.469608937540364, 61.58570281920895, 63.9712962027519, 64.00215348889752, 62.41420938122658, 62.75958584200952, 62.93778696367818, 62.908443712419086, 63.34152044788484, 60.6056829421751, 60.42761910346247, 58.8340267827434, 59.610487414944565, 60.82157804119972, 60.92539533492058, 61.7768124611147, 57.707906461531124, 51.161984474428245, 48.6838702232607, 44.724370894893525, 44.53734051796698, 43.077049947554066, 44.44593360347133, 44.14874738262546, 47.15005482396772, 54.43233513063001, 55.03486610228016, 55.77459373781758, 55.55422713679653, 55.35308407198999, 50.1650474148412, 45.95594413818852, 49.05044317245484, 48.62506604963734, 41.8227191125193, 41.91519291170182, 43.107464005870206, 41.297427454302394, 42.803852942682084, 42.70999454682873, 41.00675236794257, 40.16397230086788, 42.391451020394605, 40.62473312500985, 41.07784140494562, 40.754810687034364, 39.926888558172415, 41.4005857898343, 40.554903168832105, 42.239820034273215, 42.27820042640933, 41.9285564268789, 44.53099412302817, 43.547871651188025, 44.8556447798206, 52.63164166481265, 57.0476342785743, 57.90684907667099, 54.26011170110395, 57.021468147154785, 54.865855093925234, 55.37608485068045, 54.67879333803731, 51.05390356433008, 45.039231315735854, 41.09050673823203, 42.52479983914284, 40.38898298817296, 43.640596482061575, 43.05213112984934, 45.270478571614916, 49.492039295934866, 47.29757124377836, 54.61585498625233, 55.31011842912244, 52.86807821642969, 57.765153454196074, 57.56923106408889, 56.10472394574074, 60.591409437118045, 61.52727127075196, 55.605704322938, 58.40852414408038, 52.455005568842736, 55.822474110511045, 53.62061631294989, 55.55563919005856, 53.72054653782999, 62.61626243591309, 59.386877013791, 61.30379815255443, 57.0521253924216, 54.197973512834125, 49.93727145656463, 55.08772788509246, 57.75124080719487, 62.7844262123108, 60.085019680761526, 60.247186153165764, 60.170899975684385, 41.03595441387546, 6.590531103072628, 0.4378824356582857, 1.9425126429527038, 1.002783291041851, 29.6928148500381, 64.24043355449554, 57.485162904185636, 60.35765578669887, 56.987916192700794, 65.8174656283471, 61.55617913892193, 70.92900430002521, 44.768956476642245, 46.71198098890243, 41.638069614287346, 47.2421520756137, 41.08193243703535, 0.4249104526975463, 0.07275794422434223, 0.11469654663796387, 0.02645386446778092, 0.03587545699349815, 0.024781276194018223, 0.024209190460462725, 0.03393408294106203, 0.04026736245460568, 0.03440529979284733, 0.05750420285508998, 0.033709255287483815, 0.16620390898277684, 0.18035044262726463, 0.14045264481777145, 0.15882959258892845, 0.27821684196110696, 0.13499077499633835, 0.13150064695265987, 0.1553552919217656, 0.1554644134857001, 0.16249538459364446, 0.12299009959303564, 0.1084398452733313, 0.2970411237930098, 0.1903405509168102, 0.29855365714719223, 2.544016443913983, 58.253147294444425, 60.26045945382888, 51.481802771168375, 45.49218270086473, 50.95153754757297, 75.39679573428246, 78.98655676072644, 70.78678700231737, 76.2524058741908, 69.95248317718506, 77.03789188015845, 66.84214561216294, 71.6939998442127, 17.786717107219083, 6.751358576359288, 16.5392876825025, 1.078112961784486, 17.20532771079771, 67.18084227654242, 72.13424667235344, 65.7105653516708, 64.5914190046249, 57.603665551831654, 57.55138820217502, 57.385287592487956, 57.08788564128261, 58.60811002792851, 67.244886736716, 66.93519207739061, 64.52460142873949, 68.0453718862226, 63.50911940297773, 64.83433138939643, 65.62273171640211, 67.04468111838064, 64.19100776795419, 64.28727449909334, 65.37310815626576, 66.08093907756191, 65.00822574861589, 61.957300324593824, 60.010035730177364, 61.52761251695695, 62.43153056790752, 66.24253288392099, 63.33547215307913, 60.84858748220629, 53.37744505174699, 52.13961562802715, 46.61418453339608, 46.63917003139373, 46.13802840632778, 45.879148052584746, 44.88008899073447, 49.19852441357028, 55.245466001572154, 57.706980782170454, 54.84600005611297, 58.17137764346216, 54.70494377997614, 49.66332135661956, 47.566426184869584, 51.27024581355434, 49.94299811701621, 43.62763304864207, 44.76341416758876, 45.42973072298112, 43.38033153164772, 46.66253951288039, 47.18565425565166, 43.482301389017415, 42.24484066809378, 47.91517588400072, 44.32017457100653, 43.51643385425691, 41.44486934907975, 41.41310207305416, 43.43809235480524, 44.3815282852419, 44.94610640310472, 44.14559379700692, 44.14512703495641, 46.69947255042292, 43.41642910434354, 45.00876626660747, 53.423505444680494, 57.429539772772024, 59.568984816151286, 56.97184624210481, 58.43698093968054, 58.64223072605749, 59.24470286215506, 60.610699653625495, 53.81246728281821, 47.35290411979922, 42.78459018276584, 45.6108618551685, 42.05973225255167, 45.613223122012236, 45.49419487676313, 47.71136952984718, 50.142340813913655, 48.32221592626264, 56.89769383399718, 60.0120557508161, 55.063993623179776, 61.80264519106958, 59.76979840186335, 58.544795128606985, 63.47033892908404, 58.54969416895221, 57.41567419421289, 59.08130868788689, 55.596733862353915, 57.74509445313485, 56.13474576703964, 58.966132210147, 56.10632035040087, 63.61086176287744, 61.52097978899556, 64.0686611975393, 59.068498226904104, 57.42933580952307, 52.80045263228878, 58.92229972347137, 61.39345176758305, 65.35754026905184, 62.021940985033595, 61.09548891744306, 57.60477558259041, 39.13977869095341, 9.389365796119938, 1.0641067907694848, 5.373404439418547, 3.6210404576793795, 32.057184288578654, 71.41861023441439, 62.47411181849819, 63.70585372371059, 62.44533731091408, 73.44932325424688, 67.29859967385569, 77.37573346784039, 49.91511790983139, 50.63426486907467, 62.91988526621173, 55.356339639233006, 55.62906595968432, 0.6471710988590795, 0.29028836517564716, 0.1797020717734291, 0.09664933843117568, 0.1191930077789772, 0.08515031272245031, 0.14610862599745875, 0.13483533575650186, 0.1797767040590125, 0.29158550524903887, 0.07986200012026295, 0.10223578947085528], [0.06669365350277194, 0.013432044614737314, 0.044223854183069164, 0.04443087412284748, 0.01801559175815313, 0.10491815440717245, 0.07658051612276225, 0.03901784623702688, 0.027966809594222618, 0.025262465595357844, 0.01465992172128491, 0.006883638514761603, 0.04095827034043689, 0.24160937646463995, 0.13244209240280813, 0.3828297026695744, 15.321891846195346, 54.90328235010947, 47.92789613046954, 36.81329150353709, 33.89587571544032, 48.04976024935323, 64.81685723027876, 61.27341939556984, 61.16559736190304, 59.94905856347854, 61.362531723514685, 59.91321202247374, 53.53577152375252, 19.11362159636713, 3.4217563511863833, 2.788638246636237, 0.2728156156597599, 14.555525433632637, 70.86230047287481, 65.4528146405374, 64.14770480125182, 60.71712140114077, 55.719354998680856, 53.59463845529864, 54.329510196562744, 57.39672522391043, 57.70753775873492, 59.14455690691548, 62.098462504725305, 61.51367241336454, 63.10025153621551, 64.12451182642292, 63.090382852861964, 62.14014553254651, 61.653253878316576, 59.647753853951734, 59.41721262470369, 57.389939523512325, 59.601038425199455, 59.22585979584725, 57.964884465740575, 60.27286591068391, 59.29985530914799, 59.33268554749028, 59.702521908667784, 60.74039282337312, 57.79764636870354, 50.54075556416666, 45.91774417508034, 44.378151124523534, 40.933141246918716, 41.67058998538602, 40.366868665141446, 43.45065962883734, 44.35978266500658, 47.971034357624674, 53.26845022939867, 55.841266186006614, 53.80635230771957, 47.03362711014287, 47.39278677971133, 47.832704128757605, 45.55786671177034, 40.349845578593595, 41.42292761033581, 39.00002071934362, 39.42241291845999, 39.08291216819517, 39.54663830418741, 39.94909701808807, 39.484339298740515, 38.171890704862534, 39.21859087482576, 38.32537697207543, 38.70041047373126, 40.382377716802786, 38.84273759780392, 39.48948937077677, 41.27580734991258, 36.849573427631015, 37.81391166871594, 38.068077333511845, 38.93417589126095, 44.45538651558661, 44.29802102427329, 42.64021558146323, 47.76421170080862, 54.464365205457135, 54.28899211268271, 55.59810276954405, 53.258499176271506, 52.11834853695285, 51.53411542215655, 47.0688303824394, 40.7163949935667, 39.311480445246545, 39.15362073529152, 38.809723008063536, 39.26928358693277, 41.21093526963265, 41.98640746455039, 44.93895592228059, 46.052406987836285, 50.015059901822, 53.86871014871905, 53.9658280341856, 53.05223741839009, 53.73138796898627, 53.85334230238392, 54.69698921326668, 53.55508919685118, 51.676630819997484, 54.56560550197479, 53.247292964689194, 54.72602651965234, 53.117215402664684, 49.391865884104085, 44.25783241948774, 43.64153392853276, 54.13834564147457, 57.98189970754809, 56.98925764329972, 51.84643414712722, 52.294196236518125, 52.68036534709316, 53.81076105179326, 58.28929585795249, 61.66644480920608, 61.60381240229453, 65.77035011783724, 48.669698699828125, 7.4906493579187705, 0.21847286231575475, 1.0092122396153789, 0.5575279639132562, 29.38734850575847, 55.22691711302727, 52.31136052839218, 54.82629799073743, 56.35245692345404, 60.37297656459194, 58.51604807761408, 53.73304320919899, 30.73519256807143, 59.06807461092549, 35.25103892049482, 45.27965691781814, 12.376560549582205, 0.11936970595871249, 0.12698118019128038, 0.12506576885859813, 0.0186884697646864, 0.032473440552430774, 0.026626722631795753, 0.017481858301306927, 0.0141289078765699, 0.03843135230483548, 0.02607169193065455, 0.046498782917737, 0.025728664571239103, 0.031312493674997846, 0.008145786085796934, 0.010835515999896152, 0.05472085220859416, 0.0366350791356977, 0.028914665285077308, 0.014625287843838096, 0.012649411106512192, 0.008277624071906171, 0.027976527419542114, 0.051991039616686684, 0.06996104148246589, 0.036946447911642255, 0.1389833188225185, 0.10440944904281248, 0.30587276924521695, 20.76795966394486, 66.14626223041166, 44.174070204457934, 46.60670849584764, 45.11898879081973, 52.86455985038511, 73.89361796840545, 66.510313095585, 67.59695868338308, 65.62936836673369, 69.48070833759924, 62.602208583585686, 61.858546810765425, 19.90064124907217, 1.9437806716849728, 2.1299467788588617, 0.6406048060424867, 16.75600451807822, 73.92425952419158, 66.63000814376339, 67.02518693862423, 63.88681227161039, 58.454851258185606, 56.59873077946325, 57.70455283503379, 58.11849624879899, 59.43789136025214, 63.257699397302446, 62.105185447200654, 63.6459199074776, 65.95805122006324, 66.6797673317694, 65.09509840319234, 64.05063790659752, 64.83963443386939, 63.090406387083, 62.204750891654726, 60.5637018142208, 61.37368302191458, 58.78719760525612, 60.265888014147365, 63.031955226775146, 63.62580991560414, 59.38850087504233, 60.98233638271209, 61.6744464443576, 58.82292255278557, 51.08744767404372, 48.08441046745547, 45.873123292000066, 43.02813406913511, 42.81540824520973, 42.698753033914876, 46.13805978528915, 45.71840147818289, 51.197925152317175, 56.536937759768584, 58.8698301776763, 54.07705076279179, 46.028696260144635, 47.15236117762905, 48.67354262259699, 46.411409762597856, 44.77882908236596, 42.63046849158503, 43.203699358047984, 42.283213215489546, 40.343318754626864, 42.44741932038338, 41.27821960756856, 40.95093311802034, 40.33611336062032, 41.81308184900592, 41.339557632323235, 40.97147064824259, 43.13193959574546, 41.159152138617735, 42.168366216844134, 42.85939370432208, 39.578366356511275, 40.1907346325536, 40.763298696087254, 41.544062168367454, 45.66240179923273, 44.835691682754025, 41.749139370456824, 50.05281271473054, 57.95110517932523, 57.09166288375855, 58.80577002802203, 53.838715784011356, 52.83165508700956, 53.942301657892045, 49.524187041867165, 42.378954349025605, 41.599116556106075, 40.745365619659424, 42.40888987818072, 41.407818640432055, 42.747786583439, 42.69947867239676, 48.12730158528974, 47.39245337824668, 50.09678640673238, 56.42286739041729, 57.20011249665291, 56.288894914811664, 56.37389267644575, 55.0346621390312, 56.901502455434496, 55.525601679278964, 54.61056763126005, 57.589474416548214, 56.275111706026145, 57.33932133643859, 54.08715086598551, 49.252825706235825, 46.12716344095046, 48.78786010126914, 57.349954881975734, 59.369700954806426, 60.577363429530976, 53.709771786966634, 54.27134144690729, 56.25622549364644, 55.61325096314954, 60.16855047595117, 62.86553690510412, 64.04999071551909, 64.37481395659908, 51.08463925700034, 9.560394863928519, 0.1417535846872676, 1.2888201133858774, 0.501242135801623, 31.96524589292465, 59.9433397477673, 57.446103942009714, 60.80847732482418, 64.45383402609056, 66.89979660895564, 65.08047972956012, 58.56493649944183, 37.131901710264145, 60.50147733380718, 35.440493322187855, 52.56280014591833, 14.695510902712423, 0.08606191138706862, 0.15796834122269385, 0.1022730902918885, 0.02108461467639333, 0.022683308024199742, 0.05761258514417757, 0.0012578765111562287, 0.06607774945516741, 0.028193422232664404, 0.034537660633964885, 0.04811299529166953, 0.021623088302271023, 0.13161765922221447, 0.1671238886492868, 0.19419100075479478, 0.17853122895523427, 0.13494939092666874, 0.14306362568130418, 0.08827107913431623, 0.1651988475913963, 0.09137268568719588, 0.10880914561810995, 0.19496600594251387, 0.16006756003104872, 0.11740028542736847, 0.25095636926351056, 0.23423671482070801, 0.5026215537180824, 26.98137252561508, 78.51078110356485, 65.09917374580138, 55.33029510128883, 47.29499816894532, 61.92298350795623, 77.42925028647147, 74.018278737222, 72.58840222512522, 72.03692482363793, 74.26984387059366, 71.0871934890747, 65.36194509075534, 23.940653108781387, 7.548039517095012, 10.258966049840375, 1.4654986199832734, 19.645832315568004, 76.6359587638609, 69.71737630905645, 70.54565537360408, 67.5449872785999, 60.25794129217825, 60.09896762909428, 59.29109273418304, 61.46261099846133, 62.45854785365444, 66.84169846196329, 66.05902871777936, 67.95154094696045, 68.88069552759971, 69.99716681818809, 67.90232304603823, 67.41234840885286, 66.2629762772591, 63.79671935112246, 64.53455248186665, 61.41531113655337, 64.87183317061394, 62.337334848219356, 64.0775453659796, 65.46428757329141, 65.50460169392248, 59.83881250504525, 62.54586373606036, 66.3705825805664, 61.904293414085146, 54.54718212927542, 49.0002642908404, 49.6620544310539, 45.204857318632065, 46.099706849744244, 44.47273908122894, 48.42489573263353, 47.70846697591966, 52.919429886725645, 59.52733316729146, 60.60619677266767, 55.419521177968676, 46.59444324431881, 49.46254699460922, 50.09688838835686, 47.97639231528006, 46.27091438539567, 46.1687562542577, 44.97227645689442, 43.43248336545883, 42.45366373369771, 45.41608479715163, 45.88497277229063, 45.24511652608072, 43.60392624332059, 44.96537308539114, 43.160110058323035, 44.53803869985765, 43.67732555635514, 43.33726782952586, 46.84571812229772, 46.63163123592254, 41.56371716530093, 42.8176361514676, 43.56498102987967, 43.42060250620688, 47.97761609477382, 46.65275712167063, 41.4919299464072, 50.39338819442257, 58.83791385158416, 58.29312409124067, 61.46146566637101, 56.07968353456067, 55.22144148426672, 54.08541717836934, 51.89551476509341, 45.862870216369636, 44.8054031402834, 44.19709059499925, 44.220154131612475, 43.05424136500205, 45.822210927163404, 46.84319603827692, 50.00708572326168, 49.35514073218069, 54.036222811668154, 59.94096279144288, 60.0225833923586, 58.421726842080396, 57.43008498222598, 58.4864341828131, 59.88960327640657, 58.96563799150529, 56.29075804064351, 58.58522692034322, 58.0150515802445, 57.23652385896253, 57.055004412128085, 53.175815613039084, 51.01200480614939, 52.66401298584477, 58.03574992764381, 62.42681195659023, 62.925933561017445, 57.14448152049896, 58.29120605222641, 59.6496287468941, 58.23532404438142, 62.27800115462273, 65.34531031885456, 66.96182497086065, 68.02200240473594, 49.509458541870124, 10.060321534833601, 0.5835911331157531, 5.837540953390061, 3.809492938941525, 35.35671149530719, 65.53023830536874, 64.50431885257845, 64.71269869035291, 68.41306271091585, 71.6126577315792, 69.233363674533, 64.91198647406794, 45.10532717550955, 72.71423970499347, 45.67835800109371, 64.3066196287832, 24.21335981738183, 0.4401405564238949, 0.3161529643881706, 0.26931532929020546, 0.15509636952511727, 0.07855798057731121, 0.17595357291640776, 0.11875678965401266, 0.12166091406177129, 0.098412704293526, 0.2172239244945588, 0.08204845336055563, 0.12784135903442098], [0.041293732581600066, 0.018334052593056715, 0.09657547223351656, 0.030521772193512132, 0.06864136310234185, 0.03459802070151895, 0.04501678582821642, 0.01475992109326105, 0.07160218567737649, 0.04195066446798944, 0.04222049978711913, 0.06480371459357201, 0.03977564892040626, 0.05499184432048952, 0.036612594455120065, 0.13327789432819814, 1.678998253999218, 43.18795104180613, 36.73922146520307, 20.64446383906949, 32.39939931900271, 48.68489788424585, 64.57543926854288, 60.6869819087367, 67.20250160463395, 61.677607874716486, 60.67072368437245, 58.02402596319876, 61.386277752537886, 21.822790907275294, 0.9591031639326004, 0.9022598076731929, 0.3598607625932463, 19.585337600400372, 67.46158984399611, 63.433880498332364, 60.73912197543729, 56.64779963031892, 54.06535817730812, 50.383590113732126, 51.43158466585221, 58.07660141298848, 58.72411804814493, 61.60705620242704, 59.99235368544056, 64.40892680998772, 60.2592670532965, 63.156113932209635, 56.670004167864406, 60.366790986830196, 61.797624557249016, 62.967243963672274, 60.77827899686752, 60.580646453365205, 57.87295587601201, 56.51191696043938, 58.21504539059055, 58.7967917226976, 61.607562188179266, 60.468486278287834, 60.0058937072754, 61.00852212598247, 59.27051598025907, 52.50905190744708, 44.70596713404502, 43.23513323260892, 41.62461196222613, 40.65600226002355, 38.00707663259199, 42.32337044131371, 44.97901508885045, 49.67719870228922, 54.813185507251376, 57.0274732958886, 48.95705938339234, 47.741101095753336, 47.927943198911606, 48.62866286308535, 41.727570256879254, 42.252402997786, 40.21107604426723, 38.68240287227016, 38.71545276334209, 37.13577308962422, 38.651678946710405, 37.985158428069084, 38.70701574510144, 38.72369366307413, 38.78448647837485, 36.42889530427995, 37.57314874279884, 38.6158480951863, 40.393772202153365, 39.901248024355986, 39.51975045665618, 38.195134670503684, 40.2078636230961, 38.56825013314524, 38.04269175375662, 37.236377962173954, 44.09709368982623, 45.441238957066695, 44.76226491312827, 45.481851177830855, 48.2556023136262, 51.69405791067308, 50.64237633059102, 48.8761918775497, 44.336005257022, 42.094382470653905, 39.41185782032628, 39.05777762013097, 38.00773166841076, 38.56941115471625, 38.77301354562083, 40.60754137654459, 42.23514064665764, 44.630626247775176, 46.244556057837706, 48.48447653555101, 47.88521682062457, 50.966426864747085, 50.98005317872571, 51.841060499991144, 52.5263770164982, 51.556147375414454, 50.6803644857099, 51.361766476784986, 52.838931083679206, 56.04102073177215, 53.957187052695986, 58.963774865673436, 55.881270439394065, 59.00989017178936, 60.36553190600488, 59.31444260381884, 56.84416132588541, 56.856791357840265, 53.58813908792312, 52.684295562005815, 52.88612896396268, 54.154709769833474, 58.46801865485407, 61.30297837718841, 59.305024993035104, 57.32819357225972, 45.58051055477512, 14.027961742493416, 0.2535786269412887, 0.9826537486045592, 0.4408866954186271, 22.67810098586544, 58.6297889678709, 51.081101279104914, 57.877596039925855, 51.51546455198719, 45.95241400503343, 67.11091426111037, 44.54039212196104, 52.54524753939722, 59.902123481996604, 35.343720605296475, 41.841507265644694, 0.6212774495924673, 0.06291894677786097, 0.030218690573688478, 0.06787672308423827, 0.022043300935277538, 0.02888972912314198, 0.020217150337092822, 0.08410571353329767, 0.03545913417192717, 0.13897228715640886, 0.011908930628710698, 0.02247471185851722, 0.038566122492474895, 0.016875616537647384, 0.045158301420029134, 0.09264936355213005, 0.0251467518448349, 0.02992444194763178, 0.05513330628614753, 0.04803765437475616, 0.05998157415418856, 0.022559031325903152, 0.07700411677961388, 0.08104019738253086, 0.06906507867238215, 0.06312316666627604, 0.10000855737035313, 0.05641285315035813, 0.2973544537540405, 4.250891227875987, 56.6989512597361, 38.814500454933416, 22.998907719888997, 51.998535817669286, 54.357923846091, 71.11261829253166, 65.8736575034357, 74.30423521226453, 66.89170868166032, 67.97374940687611, 63.68564959495299, 65.8734300059657, 23.032096855102047, 1.4887907572330967, 1.8194993921825964, 0.45328690099620056, 23.40613211354902, 71.6824366969447, 64.32736896699475, 64.90243942506852, 60.7376471642525, 56.46509562769244, 52.65230471088041, 55.56648846595518, 60.022269602744814, 60.89779753838817, 64.59729079277285, 64.23610718019548, 66.45187762475783, 62.71951883069931, 65.02843379974365, 59.669444561004646, 62.19760825557094, 61.86988638293359, 63.74939595499347, 61.76891280758766, 63.34466226639287, 61.975625638038885, 58.126635166906546, 59.08729814714002, 60.63715211806759, 62.85814715969948, 62.96283521959859, 60.40253554621051, 63.76171219733454, 61.17694477881155, 54.65400395854827, 46.336143401361284, 46.26771373133506, 43.41846481446297, 44.52456143594558, 40.33600353425549, 45.126786462722286, 45.375029348558, 50.701506060938684, 54.89194670031148, 58.20487860710391, 48.22550596729402, 48.38973168403872, 49.383036628846206, 49.64234059856784, 43.93018899425384, 42.388297434776064, 41.59732011056716, 41.91917019505655, 41.89164692355741, 41.79359159161968, 42.69337154203846, 40.108286411531516, 41.309033747642275, 41.634861115486395, 40.60110476709182, 39.81645422597086, 41.28792355137487, 41.19484962955598, 41.5190060677067, 43.875719039670884, 41.58006560417914, 41.06206955448274, 39.536185187678186, 41.04190464942686, 40.648875313420454, 41.062434334908765, 46.92401255330732, 45.38894199555921, 45.34274824203984, 45.276738674409934, 50.975644434652025, 55.52349536649643, 52.57688929957729, 50.33480367352886, 45.54736260444888, 43.82179037217171, 40.80372656545332, 40.67099355882214, 39.92473909931798, 40.182030893141224, 40.89235644186697, 43.00305443425333, 42.268688678741455, 45.031210068733465, 48.44886925912673, 49.311139583587654, 48.754633703539454, 53.53213940897296, 51.18878995218585, 55.663782858079486, 53.95320584697109, 53.93866562074231, 54.076889945614724, 55.51432486503355, 54.06002375387377, 57.187988450450284, 57.238775299441436, 57.11305941304853, 55.27928467719786, 57.32324354110226, 61.04438043409779, 62.83140051749445, 60.62948780675089, 59.10155596271638, 56.72738059874504, 55.0344777876331, 53.52291791669784, 56.54220942528018, 61.25274850476173, 63.66946589562201, 62.04250597184705, 63.42609067117015, 48.13449521218577, 16.70941068280128, 0.49672856025638124, 0.7443256952589559, 0.8699116531398989, 26.081180726328206, 63.19930707254718, 55.77890442263696, 66.16199093480265, 58.22469834358462, 51.03295418523973, 72.7701021009876, 50.57191487281553, 65.20347349105343, 58.59390320316438, 37.361207392907914, 48.90303265663886, 0.565934032201767, 0.07825843253803831, 0.0323508320105893, 0.017854531348172217, 0.058214776217937476, 0.04152355512844459, 0.021672734630204016, 0.07416256643351048, 0.01364379897788768, 0.02710426353939599, 0.07475819213375931, 0.01370365821546124, 0.06969897812532802, 0.09368805620338648, 0.1212163455784321, 0.22006909843654404, 0.18851076523142477, 0.17013141194418555, 0.18247570842504504, 0.1342390435597589, 0.11637761933548797, 0.1608122587804833, 0.21244758079128884, 0.250207947326764, 0.3027889895583353, 0.29788817188912825, 0.1670726526889109, 0.15989486849115742, 0.5281296768976796, 5.409560357370685, 68.5562841353878, 50.82388008794477, 31.992333781334665, 48.04868551992601, 64.94136110428842, 77.2663385637345, 74.93696058950117, 79.78718311555924, 72.85284842214277, 70.61585011020784, 68.80569196516468, 72.00662843642696, 27.58462913574711, 2.1733519723338466, 5.971609036768637, 1.656344359920871, 25.02194073892409, 75.0972443242227, 69.05870053075975, 68.37296824301443, 63.25808771194951, 60.458750955520145, 55.76380721984371, 58.17688857355426, 62.78456349526683, 63.24374360422935, 69.20975100609564, 66.99481994875016, 67.68452951985022, 64.89994479763892, 67.2922375894362, 60.8632924479823, 65.14528120717695, 65.24380722353536, 66.16451694119361, 64.35978343409877, 64.58868119024461, 64.17445536582701, 59.230001818749216, 62.41948496910834, 63.06031396312099, 65.81304119479272, 65.74421928774926, 62.72215466345511, 66.15991207861131, 64.08243656158447, 59.09644511438186, 47.56506120004962, 47.20698802701889, 45.920011305039935, 47.46862580699306, 43.95833592261038, 47.64202986994098, 48.23650821562737, 53.02174883504068, 57.728036065255445, 59.12449790585426, 49.858031734343506, 50.20185885890838, 49.74403589002548, 52.610806034457305, 45.93791692487655, 46.16066440459221, 44.184656681553015, 44.92786345943328, 43.690551788576194, 44.11161038183397, 46.5760120268791, 43.580799948784616, 43.81462027949672, 44.52840928108462, 44.79522851205642, 39.703662549295736, 44.09452061499319, 42.932377246118364, 45.65740862200337, 45.61434884225169, 46.42623239947904, 44.38692546659901, 43.969224422208725, 44.97759519084808, 44.84361879287228, 44.37419737538984, 48.86787253041422, 48.775418343082556, 46.3704719851094, 44.84803930405648, 52.32212351214502, 57.84772719106367, 55.3018500727992, 53.44034810220042, 47.12512816152265, 45.534587444797644, 44.23318032295474, 42.07071096666398, 42.684153972133515, 42.81689874587521, 42.659054725400864, 44.65739250183106, 44.7166242138032, 47.45926703176191, 50.742188884365945, 53.32123356480753, 50.60857726681618, 56.85661877355268, 53.493566820698405, 57.25658286002375, 57.50693205864199, 55.819336214373195, 56.74446644321565, 58.123124645602324, 55.17838954925538, 59.52975326968778, 57.679524190964244, 59.19525746376284, 57.976577051224254, 59.259046969875214, 62.16543305304743, 66.44727276217553, 61.92273639863538, 61.63669755381923, 60.642902312740205, 56.16022156130884, 57.010614948887984, 60.48967884432886, 64.85457474185576, 67.76046660638625, 62.88167353599303, 65.75519800186157, 51.36727348450692, 17.364458268688573, 1.0969134948907362, 4.06172659127943, 3.081856990052808, 28.851060482763476, 68.49635816389515, 60.22984927700412, 68.61860275268555, 62.41699034167875, 59.40166434934063, 75.67690787776824, 59.24553832700176, 67.51920946182744, 69.56287414796891, 47.213248129813906, 59.06978476432062, 0.9046094299804781, 0.12528536796209314, 0.16653182525788585, 0.12145086807469208, 0.0988876251804252, 0.09069069889524291, 0.11638762444377908, 0.14145815054014807, 0.09032963399565028, 0.244543171457706, 0.13992488684673465, 0.11366140097379686, 0.1701113404405694], [0.024582671730088133, 0.04447771656897761, 0.05656353115374523, 0.1205917847372832, 0.057605586930989265, 0.09353310725982152, 0.01371346414089203, 0.03388837430505984, 0.13170128538002893, 0.07240410353387557, 0.03452882380975831, 0.015346091353304446, 0.02481740107008767, 0.06182693440707461, 0.03380895013951006, 0.020688292495305502, 0.34299049526453024, 14.096294333857877, 55.19401234965171, 39.626827239990234, 25.03540231335548, 35.84567808335827, 55.622586204159646, 64.7065366468122, 54.85992839259487, 60.63392792978595, 60.01102416746078, 59.6858439906951, 59.03147497484761, 23.075084071005545, 0.7505639798698888, 1.2387305882669266, 0.2459106690460636, 30.498265720182854, 69.34629655653431, 63.19463160730178, 59.14843220864574, 59.431654791678156, 53.332310338174146, 52.43852376937867, 52.213258128012384, 55.90672269944222, 57.849229458839666, 59.80486046883368, 63.01992923982682, 60.81984827595373, 61.6587334294473, 56.941761662883145, 61.66367169349425, 65.27784555189072, 62.877606038124334, 62.144224797525716, 57.20366224165886, 57.26354506707961, 54.916002596578295, 53.554842087530325, 55.20766219785137, 58.533008406239176, 56.75888899833926, 61.3854109087298, 60.4044928089265, 60.685130550015366, 60.27372490975165, 49.67242125541934, 44.08402827478225, 44.31350654171359, 44.118427461193455, 41.622038887393096, 41.32415448465655, 43.967529958294286, 47.34831886906778, 51.64488707819293, 54.63357625469085, 60.668036860804406, 52.2601539857926, 47.960993089983546, 47.97985184577204, 42.65175127214001, 40.31116316395421, 42.06913809622488, 40.148835874372914, 39.91568234659011, 38.16849000992314, 38.49470569241432, 38.67527592566706, 38.24245806663267, 38.462805055802875, 38.551862470565304, 39.11068647138534, 38.05979721007809, 38.65168679145075, 37.017227295906316, 38.74199151992798, 37.682680929860766, 39.602026093390684, 38.978843842783284, 39.81439498163039, 38.75275058131064, 39.24134846656553, 37.22969424340033, 36.325199604034424, 42.15571657303841, 49.75708953795895, 47.95394459078389, 45.674110074197095, 49.828884601593025, 54.825560585145034, 49.905849349114206, 48.23866159685197, 41.234653842064645, 41.05359723491054, 38.51938132316836, 38.745788374254786, 38.65012961049234, 39.49023069873933, 40.61408781236218, 42.25709023014192, 43.55756382788382, 45.10648427471038, 44.7269675039476, 45.080933955407914, 47.384134031111195, 46.78123043429467, 47.698017781780614, 47.270695163357644, 47.89597195963706, 47.634173362485825, 51.59900711428735, 53.302182612880586, 55.175471305847175, 56.123284601396136, 56.702328420454464, 55.43589315106792, 58.60280306108537, 59.517731205109634, 61.526875111364554, 54.55482682874126, 56.53188574698664, 47.589438730670565, 52.85164348540768, 51.20834688986502, 52.55030347454933, 54.04011380287909, 57.29872872752529, 54.47401031371086, 59.02273593410369, 51.559269582071614, 23.5118733298394, 0.5291674502434269, 0.2824933286155424, 1.59210488440529, 27.14249956992365, 56.92990041548207, 57.01063456073884, 50.1765085804847, 47.78121125313544, 62.82196721723003, 65.69107117191439, 34.18092612297305, 36.87675545292516, 28.420460724061538, 44.01433560156053, 19.265607556989117, 0.34630734954149495, 0.17634178031115763, 0.07968003891648785, 0.0845539209342772, 0.049508144823654045, 0.040324240652543884, 0.06480677128438989, 0.013590249431980474, 0.04568772180186165, 0.05431153143065111, 0.10229216588120307, 0.008633600232461769, 0.049351123612253904, 0.047282682386257, 0.10616145382124571, 0.045060575413968296, 0.05823168760886597, 0.05098760616214526, 0.051517677718713406, 0.06260512652055872, 0.040803830845341574, 0.004720237338915467, 0.04494597632137518, 0.07695676488501411, 0.049000772452282335, 0.028771031460153963, 0.03887396343352814, 0.09299172824549098, 0.10358115477908043, 0.19973946915518856, 21.298403355383105, 65.09718510412401, 31.500931401406568, 35.84933373235887, 45.206798891867365, 61.989208805945616, 71.67959690093994, 61.49659441363428, 67.78258877415811, 66.13542079925537, 63.98621297651722, 65.10106040585426, 26.57196141058399, 0.6940928810546476, 1.8599925935268404, 0.41399722378100123, 34.39434228404876, 73.09141482076338, 65.2150680172828, 61.92269717493365, 60.60267056188276, 58.5448068957175, 53.54469099352437, 55.332950545895486, 57.31022519450034, 62.258201029992875, 64.30832978217833, 64.10267599167364, 64.36105820440477, 64.03825498396351, 60.09243296038721, 64.90178831161992, 64.13023456450432, 62.94461188777801, 63.72404567656979, 59.71013915154242, 59.11560197030345, 56.24955746435351, 56.97797298431397, 58.1286826441365, 60.14836203667426, 58.071545477836366, 61.865285442721465, 62.03437489847984, 62.83284002734769, 61.19930228879375, 49.54117874945364, 46.4593215142527, 45.68777561187745, 45.04265946726645, 43.62205151588687, 42.99663743665142, 47.16125319080968, 47.52040109326763, 52.121478588350364, 55.63986816713887, 62.182664025214414, 52.19579573600523, 50.5179391368743, 49.7405332134616, 44.469640408792806, 42.96781193825507, 43.71579224063505, 41.472769168115434, 41.70775444276872, 40.76420084122689, 42.305841369013635, 41.23028039932251, 42.0714444498862, 40.681713396503085, 42.132280411258826, 42.03961833830803, 39.91373685098464, 42.533574181218306, 40.10942782125166, 41.04603490521831, 40.4038683829769, 42.754395777179354, 43.941928648179584, 41.570714673688336, 40.450073903606786, 41.8986052082431, 41.53400128887546, 41.02188094969719, 46.08963420314174, 48.7328920056743, 46.584268616091826, 46.41024874102685, 52.020426565600985, 54.7172757117979, 50.81683943348547, 49.37305419675766, 42.119395425242764, 42.09982672045308, 42.16160012829689, 42.425218705208074, 41.8451197685734, 39.447135617656095, 43.050397442233184, 42.98495269590809, 44.3153343662139, 48.1035751681174, 46.630929131661695, 46.38238030095255, 50.3779262112033, 48.08868585094329, 51.16449086896835, 48.88457398260794, 49.24032119012649, 47.840921494268606, 53.5398978571738, 55.472453563444084, 56.239484817751, 57.80642855551935, 58.38697856472385, 58.36189108510172, 60.427324925699544, 59.71457142983714, 63.02667571652321, 59.50195935464675, 58.47893461104363, 51.232014471484774, 54.327490175924, 52.826489325492616, 56.16752893693986, 57.36598953124016, 59.9542204026253, 58.983543611341915, 63.20906985190607, 54.686394891431256, 27.902839260716593, 0.82754343627922, 0.321320625803163, 1.637076451893776, 30.024939583193873, 62.55210422700452, 61.3118782351094, 54.90326273825861, 52.68334242605394, 68.03983349953928, 71.156125222483, 42.150876368245775, 47.29391559477776, 28.821440704407234, 51.13373164207705, 23.7360171733364, 0.42303807252357084, 0.22745107570963524, 0.08773030532944588, 0.07538948688776263, 0.09331952960741136, 0.06479212368327765, 0.030854026441492384, 0.029807822298138376, 0.0219664795534505, 0.04253232055493901, 0.11032737100556975, 0.03141349087649536, 0.038441912826871684, 0.12306785751735011, 0.2668081993056882, 0.16733413381922632, 0.1996851228778401, 0.10453914006751393, 0.3210007687730174, 0.1481609142595722, 0.12814497500057184, 0.1872193554957067, 0.12570918312356358, 0.21759373045736746, 0.10828008529760184, 0.11669841865378043, 0.12526823823610622, 0.14739341673351106, 0.25169619569374674, 0.38559344146520863, 30.31376919438762, 79.5062315848566, 54.21289028659944, 41.74404813397316, 49.36592332778439, 68.29776071733045, 77.30645656585693, 68.78849629432925, 72.52049815270209, 72.82922790896508, 69.60562798284715, 71.27805602165961, 27.516905492351903, 1.9569068834666286, 6.272164573592525, 0.9842447600057049, 35.623354219621234, 77.57331109816029, 69.6567129319714, 66.13432253560713, 63.51268483746437, 61.20598992993755, 56.25852008019724, 58.76783678608557, 60.472334123426876, 64.74210862190493, 65.11307462569206, 69.73705091784078, 66.86298124251827, 67.35820401099421, 61.90710183112853, 68.22452222147297, 64.77482118914205, 65.97608627811556, 65.08341366244902, 61.427588155192716, 61.213544414889434, 59.63070331081268, 60.35587503064064, 60.7908501932698, 64.36499234168761, 61.530668043321185, 65.22758037813249, 63.286921055086204, 65.05651797017744, 67.21408044138263, 52.54232537361884, 49.44102494947372, 48.70524714069982, 49.228969850847804, 48.66083414323869, 46.14182918302475, 48.474960865512976, 50.3610796313132, 56.114176857856016, 56.58804624311386, 65.14848186123756, 54.12047924533967, 50.839420518567486, 50.867767487802816, 47.995545248831476, 46.55774162661645, 47.09785592171454, 44.59958068786129, 43.78069569987636, 43.768171571916156, 45.146202195075254, 44.15512907889582, 44.696165130984404, 43.19454062369562, 44.92756928167036, 44.09253197331583, 42.24892777781333, 43.94512537987002, 41.33226202380273, 44.54176102915118, 44.25296868047407, 45.82608230652348, 44.337625195903165, 45.34800029570057, 44.169716373566665, 44.53334754513156, 44.087174015660445, 42.72865718410861, 47.76953435713246, 50.40053475287653, 47.18181425525297, 44.60807261928436, 52.82013900818364, 57.12229267243416, 53.76503013795423, 51.36389240141838, 44.248681529875725, 43.67869446354528, 44.778370165055804, 44.61397186402352, 45.10201277271394, 41.800608711857954, 44.35059255169284, 45.71020764689292, 47.20831378813713, 49.55714279605497, 50.94117856794789, 48.34787999430011, 51.37136843896682, 51.78660623488888, 51.970883107954464, 52.63404607772828, 50.95289076528242, 50.72705638024115, 57.633667761279696, 58.25575567060902, 61.18132606629403, 58.60557617679719, 61.40883922576905, 57.384432515790394, 63.37549209594727, 61.09275110306279, 64.43295524966332, 63.248517128729056, 62.499328736336004, 52.07823445720058, 58.54104142035208, 55.31311511993409, 57.58004111628379, 60.85834633919501, 62.633234531648704, 62.23686333625548, 65.46879045424923, 57.1742287758858, 27.84243476006293, 1.1898664361046207, 2.308192027191962, 4.0086248084422085, 32.34627473738886, 68.14542370457804, 66.13884110604563, 62.67725921446278, 58.80195748421454, 74.99026560014295, 75.54404151055121, 44.8705497864754, 44.41102843130789, 40.64601982793501, 60.17976845464399, 34.55143713182019, 0.6107860286870311, 0.3082549962545595, 0.19332107727325734, 0.1550585401034163, 0.23064219963646707, 0.18530194467354208, 0.19973353963465462, 0.09544026016468003, 0.13043858861971286, 0.16861045162283606, 0.1184595398785126, 0.16130289213070947, 0.199851333313892], [0.028203009823036772, 0.04592201064130472, 0.025902394160267808, 0.025131830367289727, 0.018573022229717146, 0.03468746146667869, 0.07202307438297618, 0.05295271744891521, 0.04959345637490192, 0.014294928705860532, 0.019486846379755486, 0.048644001475505294, 0.050135812151335904, 0.029106292603237015, 0.015077447300897011, 0.0709325252401252, 0.03994249903987493, 3.1076448578988356, 37.84932674900178, 38.7504324605388, 42.34764991268035, 36.512688898271136, 49.17772016217632, 62.50802463100803, 67.30214549649146, 62.19337209578484, 60.62329830661897, 57.72086205021028, 63.97517934922249, 28.031059580464518, 0.9091054467904953, 0.059615924218369115, 0.34554405017725887, 38.12088420314174, 67.85885533978863, 61.976339509410245, 58.303557595899036, 56.31751644995905, 52.35183546620031, 50.69770136187154, 53.26853652154246, 57.01518843250891, 56.936199741978804, 60.94229682799309, 59.67539871892622, 62.597858675064586, 62.049287749874985, 64.12146022242885, 64.67702865600586, 59.120300969769886, 60.104254984086566, 64.18776789019185, 60.51586850996941, 58.54770944964502, 54.83405643893827, 51.83029751623831, 49.647557350897024, 53.33021187013196, 56.449990580158854, 61.836671752314416, 59.718011348478264, 55.88040359558598, 50.96237113398891, 46.44798194208453, 45.027177872196326, 40.025077250696, 41.66915832027313, 42.022316763477946, 45.13834176524993, 44.796216949339836, 47.73406044129403, 51.91462063020276, 54.416908448742284, 60.17714438899871, 55.97485034696518, 48.86758619739164, 43.07504561639602, 38.641782806765654, 40.98701500123547, 39.82393810825963, 41.43135286146595, 36.80240692630891, 37.302783689191266, 37.93608565484324, 38.0907957015499, 37.62492795144358, 39.3931677264552, 39.07720904196463, 39.682999503227975, 39.42329545174876, 38.797140044550744, 38.07332154243223, 39.53261583082138, 38.538789210780976, 39.30312187440934, 38.99703579564249, 38.02384868744881, 38.59534978866577, 39.60674078233781, 40.422613390030406, 37.95851376748855, 36.6301207388601, 41.94565403846003, 50.87807939898584, 53.25092115709859, 58.20416081336237, 60.14385915571644, 50.617320229930264, 46.94376953186528, 44.04359648304601, 41.408175576117735, 40.240168263835294, 38.87872926650509, 38.36162359483781, 39.27592023726433, 39.34411848745039, 39.42355825055031, 41.66056440722558, 42.5679890571102, 43.631735847842315, 43.775020030237016, 45.30238705296671, 46.06504878690166, 45.604315419350904, 44.35886875275643, 48.01586704869425, 48.21725330045147, 53.523694545991965, 51.843837538073146, 54.56862572700747, 55.99211269809354, 56.34028580880935, 56.13285518461659, 59.16003065724527, 53.77960958788472, 54.28644649444088, 53.44793396611368, 48.5594291071738, 50.777733402867476, 49.896243464562204, 54.023808510072776, 53.907196444849816, 52.979579433318115, 54.26024113931964, 53.55900764465333, 53.005686729185044, 52.1959134071104, 33.958794455374445, 3.6402323697843864, 0.30779304523621837, 0.11260349483739947, 29.715399857490297, 57.30662445868216, 50.7632363227106, 47.741281524781265, 57.90274627747075, 61.71300334315147, 55.32160312898698, 30.240471862977554, 26.712219484390754, 32.004246019547985, 51.506207758380526, 4.470420893161528, 0.22398108045660683, 0.05999918651556777, 0.04707553604197118, 0.01611005338359504, 0.01735297741458541, 0.046023969283147205, 0.01049198110723087, 0.09453253790495858, 0.056575987743394035, 0.04130593253179424, 0.011274898067987975, 0.06095316133371765, 0.026080164863097093, 0.017610379126704028, 0.03611626141073723, 0.08922537187895468, 0.025294727473069104, 0.013637226901107259, 0.029098821330755472, 0.06756085737217819, 0.026177676364539132, 0.025730495521378134, 0.04103970931722753, 0.027492411562331745, 0.021839402803790667, 0.01993963881696184, 0.04497858102343256, 0.038876702197857445, 0.12910956396691262, 0.11718016538408496, 5.220892881193469, 54.86266620697514, 39.229240109843595, 37.35289981288295, 49.64847126314717, 53.40239524841309, 72.90240364689981, 72.21727540416103, 71.91602168544647, 65.33553185001497, 64.80376435864356, 69.18983321036063, 33.40985874975882, 0.5196916167774509, 0.23584004491567614, 0.3893996114211698, 43.256278730207875, 70.55088781541394, 65.26190503951042, 62.27486325848488, 57.769256253396314, 55.2811360359192, 55.10565703915012, 53.95830885056527, 58.60684310236285, 58.630063533782966, 62.614054141506074, 64.11459215225713, 65.81828932608327, 64.21267494078606, 68.51426770610195, 63.91175070116597, 59.40422957943332, 61.01858300547446, 65.1156202439339, 61.856103174148075, 62.7349925810291, 57.99288234403057, 53.92040698759018, 51.661851329188195, 55.73867659414969, 60.05607651126001, 61.698753372315444, 60.77884774054251, 60.291202991239494, 54.382885809867616, 49.22188212794643, 46.5763807296753, 42.42126887844455, 42.715544700622566, 44.33585228458528, 46.41857985527285, 45.88470212874874, 50.97132198272213, 54.62482936920659, 56.08098576145788, 61.23893391701483, 58.66169352685252, 52.41924139761156, 45.82637256191623, 40.919648293525945, 41.21164914100401, 42.10208992804251, 42.8685014478622, 40.4775736408849, 40.64993435336698, 41.59245637155349, 41.063787552618216, 41.20702858894102, 41.1072434917573, 42.106110357469134, 42.69749003071939, 41.86463748255084, 40.25562632468439, 40.611597107302764, 42.78426854841171, 41.88204496137558, 42.97075371588431, 41.65670479497602, 40.86448015705232, 42.155551833491174, 41.16358441691245, 42.78650037703976, 38.625952120750185, 40.677453702495946, 46.224540202848374, 53.90398402367869, 53.44612967583441, 56.813700199127204, 59.81550578148135, 52.70216980288106, 48.895031021487334, 44.97204503705425, 43.01801043172037, 42.14676964667536, 40.09769601206626, 40.20472964932842, 40.89763987448908, 44.22528066942769, 42.10862851911976, 44.432628923846835, 43.8334672681747, 48.299893717611994, 45.34161859943021, 48.13509533482213, 48.428127765655525, 50.45173345073577, 46.82331746624362, 49.22653405897079, 51.05082058137464, 55.05892592091715, 51.90223770756876, 57.32791116160732, 57.08845438495759, 56.763070244942945, 59.296713490639966, 58.8977849098944, 56.8718336474511, 56.75571580086985, 55.525421250251036, 52.19044954546037, 53.61656058219172, 52.15750163601291, 56.225854581402196, 57.16148107282577, 56.014874212203495, 57.37246144202448, 56.30809883917532, 59.6546454583445, 55.053815072582616, 36.1678498022018, 4.845435763559034, 0.3359230583713901, 0.4046358438509126, 32.83896169354839, 63.58763348671698, 55.21691114671769, 53.514261245727546, 60.87656574864542, 66.81471255517775, 61.0071728306432, 37.56634735292004, 29.271660158711096, 36.43702637764716, 60.3762831226472, 5.547958737419498, 0.38977223658753984, 0.03646077498072579, 0.01977025869212324, 0.0908797081079214, 0.020469710373529987, 0.045825092858004, 0.002575803303062135, 0.005617157758904562, 0.04101619041795212, 0.046037720561388044, 0.03897421369929949, 0.020465244080931432, 0.09112268055398619, 0.10343476303762968, 0.22728894086134052, 0.15657867304980755, 0.17946053957266195, 0.17710065168719138, 0.17547011014915284, 0.2196004671315032, 0.11988287761567101, 0.15639588447107425, 0.11978305635913727, 0.09731378180966263, 0.056317000229272156, 0.14103104120060322, 0.1502031361263606, 0.08431163796734426, 0.26937943552770927, 0.14965434138092304, 7.21783870650876, 67.77297112249559, 52.472852353126775, 56.42416569494433, 51.45824501591345, 62.655305708608324, 76.08321835917812, 80.1924345570226, 73.17478872114613, 76.06854869473365, 68.77524652788716, 76.91142682106265, 35.43501377105713, 2.72606639131423, 1.3811701127598364, 0.588943513651048, 47.61800535263554, 75.62259089562201, 68.61791241553523, 65.6691921910932, 60.64900159835816, 58.70452973150439, 57.39572501951649, 59.06732936059276, 60.36043674715104, 61.2149093997094, 66.89545846754505, 69.59323329310264, 67.20217212553948, 66.6783788127284, 72.75813887196203, 65.709431786691, 60.86943487967215, 62.6444564327117, 68.60871837985131, 63.78958063740885, 65.19443635017642, 63.191395651909616, 57.546332267022905, 54.4140451185165, 56.45162620852071, 62.577827130594564, 66.27799895501906, 63.671062300282145, 61.00342304475846, 55.60327245343117, 49.945343694379254, 49.83827867815572, 43.862610478555005, 45.72663453317458, 48.37276351067328, 50.47308291158369, 49.547525144392445, 53.29023115096554, 55.22956079052341, 56.186434761170425, 62.34018248896446, 60.76520965945337, 54.66053470488518, 48.539519156179125, 43.05875209070022, 45.52472660618444, 46.118047852669996, 46.5965848584329, 41.961100332198605, 43.10847205500449, 44.64215409371161, 42.318569460222804, 43.23262683806881, 43.918025724349484, 46.49292445951893, 45.96516170809346, 45.150975719574966, 44.46803223702216, 44.28907017554007, 44.433291804405954, 44.60170661249469, 45.721511917729536, 44.40555672491751, 41.50390886491345, 44.435041181502804, 44.28764635516752, 44.830251355325025, 40.36387589669997, 43.68138128711332, 47.51701216543875, 57.26545526135353, 57.913093489985314, 59.928846589980594, 61.13813684832666, 54.224484812828806, 51.06814961279593, 49.27017434950798, 46.03629781353859, 45.91863063073928, 42.50498402503229, 41.32988506747831, 43.7463318147967, 45.20568493873843, 44.36742344210225, 48.02309597692182, 44.907341618691724, 49.95562030423073, 47.909009918089836, 50.54852970184819, 51.631951101364635, 53.23244287121681, 48.98000524890039, 52.51427258214643, 53.034261195890366, 59.0924717533973, 55.39011516878682, 59.23743078785559, 58.33932176713021, 59.41635362563595, 61.205946783865656, 59.73410483329528, 60.35434530627344, 61.04915395859749, 58.01537321459863, 51.980810626860595, 55.97652127665859, 53.55846635756954, 59.15220160638133, 61.252120925534165, 59.24063928665654, 60.56637294830815, 59.595013664614775, 63.8083452563132, 60.06948709487916, 38.444373838363155, 5.273310455583758, 0.8301790238868806, 0.9412335808719359, 37.57494126596759, 69.14165865990424, 61.09435143009309, 61.74910091584729, 69.08028141144784, 73.70661504807012, 66.27718310202322, 40.65756336335213, 39.224513653785955, 45.68106051414244, 72.84007718486171, 10.053892770121175, 0.7453102101722072, 0.25132367777968606, 0.14016390627911016, 0.16494249925017357, 0.10174650443537582, 0.1960101531397912, 0.10729033800382769, 0.245271950900074, 0.1858878180745148, 0.11641327306748399, 0.09193580627681748, 0.1382882625705773, 0.1523386215370509], [0.016666610514925375, 0.02742782268943566, 0.02027647235550948, 0.08395435754209758, 0.10331692339311685, 0.03880489294627502, 0.034832137171179056, 0.032192198184108546, 0.03681019151342973, 0.06504061196239726, 0.03607590772932576, 0.01826226057845258, 0.08146112439252677, 0.0989100332522104, 0.05279065154853368, 0.11902093677030456, 0.043224197541994434, 0.06434380902998871, 18.10201487233562, 54.96096080349338, 34.26295072801652, 26.415107788578158, 39.757163678446126, 58.061257100874386, 57.06061732384467, 56.819940690071356, 66.85659562387775, 59.310100540038086, 61.080976147805494, 33.745303769265455, 0.1399449430285923, 0.316499603852149, 0.7953781622552103, 39.18407401730938, 70.05564151271697, 64.4042827237037, 58.595887922471576, 60.17105294812111, 55.076101979901715, 52.53866580224807, 54.66090733005155, 57.78065073874689, 58.83461513826924, 57.79148040279266, 60.196897445186494, 64.81904591283491, 63.255561705558534, 68.61262506054294, 64.24310861095306, 61.42198308821648, 62.582530052431174, 60.84899933107438, 61.270877699698175, 60.340040422255, 56.506625683076926, 50.6316251139487, 48.7691778521384, 48.91008507820868, 50.157085003391394, 53.48060730964907, 53.342241779450454, 50.22766020990188, 47.3023957590903, 46.61439241901521, 43.79811886818179, 41.46788973962107, 40.47432984075239, 44.00967190342565, 46.1781777874116, 44.59673304711619, 45.984247961351954, 50.645859395304036, 53.323896854154526, 52.6317475688073, 46.66427320049655, 41.86601423448132, 40.37231291494062, 40.015891059752434, 38.68226166694395, 39.838905872837195, 40.40246809682539, 39.43474877265192, 38.48322883729012, 39.30762083299699, 38.42374217125678, 39.97618882886825, 38.24145001749839, 39.981515407562256, 39.06739919416366, 36.76276353097732, 38.90584853387649, 38.90652318154612, 37.39976036933161, 38.08583390328192, 39.06598714090163, 38.651769161224365, 37.507299992346, 38.00710801155337, 39.119970721583215, 38.51533343715053, 37.624225847182736, 39.62765878246677, 38.96169916276009, 38.377638632251376, 43.740989546622004, 52.61803888505506, 51.28962624457575, 48.69229939676101, 47.64958435489286, 43.47876733349216, 41.95284766535605, 41.758341250881074, 40.05891553817257, 37.94193390877017, 37.72269695035873, 40.542280981617594, 40.30695446075932, 40.74017632392145, 41.17406106764271, 43.532323375824966, 43.71035191320604, 43.76807351266184, 44.303786908426595, 44.330580619073686, 47.1642263474003, 47.5700229983176, 50.31327378365302, 50.45326709747315, 54.787015453461684, 56.465358426493985, 54.64180930968254, 56.73742186638617, 54.94642842200495, 57.15404818134924, 60.091099354528616, 55.34049326373685, 52.81676969220562, 54.82953786849976, 50.662725587044996, 56.21207529498685, 58.99539309163248, 59.43078794787007, 57.923538761754195, 58.34948462824668, 55.59333708978469, 54.00911923377745, 50.86240953014743, 37.27619001942296, 10.465462169339581, 0.16783175389132193, 0.8313928135941107, 35.55755645998063, 58.75268074773974, 50.01651510115593, 53.7123840855014, 55.807463199861594, 62.2085948144236, 46.03235583151541, 27.707077687786473, 39.623097065956365, 47.496823726161836, 29.044341156559607, 0.0960261565482905, 0.042438340718827905, 0.10915746281464254, 0.05057760739638921, 0.11191145697187994, 0.03374342663934635, 0.03615596391741307, 0.011174669827244455, 0.022851699895616022, 0.019919130643228852, 0.012204643440312676, 0.05577999940742889, 0.042457715082432956, 0.027876855550153602, 0.022915735269986817, 0.05921030747553995, 0.04317168604522463, 0.06353190904783626, 0.046092009382142175, 0.05553577823804752, 0.039416832488871394, 0.050958751460477236, 0.06513996590529719, 0.05926404088254898, 0.022036877288032445, 0.03379931275342261, 0.05685866269613466, 0.03925899539383189, 0.0077663298091670925, 0.043828617931614, 0.03651247442429585, 0.0825411934525736, 27.822640518988333, 63.413590077430975, 36.49280248149749, 45.52542871044528, 46.7596064075347, 63.6181926727295, 67.3615929388231, 64.45794467003115, 73.56261699430405, 65.38596176332044, 67.34516605254143, 37.8957401552508, 0.1109468220402637, 0.0991665194892595, 0.8052088476477132, 42.608295333000925, 73.40663217729139, 66.34887618403282, 62.66029104109734, 62.864481787527765, 57.285482883453376, 54.79940229846586, 55.84323129346294, 60.39400831345589, 61.14942542968258, 61.20267160477177, 62.90385846168765, 63.822371652049405, 65.25232661154963, 68.08278345292615, 65.08002081224996, 63.1610208172952, 64.06856706065517, 63.42597300006498, 64.49776064965033, 61.60662081933791, 57.26205456641413, 53.11183783315843, 53.31595013218542, 52.46253259720341, 52.32417098937496, 56.242034358363, 56.73382505293816, 53.30858784337198, 50.92652067061394, 50.470858927695986, 45.36031261567147, 43.92460746149863, 42.8300347635823, 45.549300255314, 48.74913846292804, 46.68590899436705, 48.840388482616795, 54.45051531637869, 54.17308999646095, 55.22004904285554, 50.77717250393283, 45.853017222496774, 43.612606448511926, 43.84616005805231, 42.37064676900064, 41.474891170378655, 43.07340606566399, 41.66187447886313, 40.68068573551793, 40.56956106616605, 41.53467201417492, 40.70488675948113, 40.13977912164504, 43.2349096575091, 41.40964254256218, 40.85011251511113, 40.507466023968114, 42.06292506187193, 39.534224002592026, 40.735504781046224, 41.15643785845849, 41.20540865005986, 40.36152247459658, 41.52721166610718, 41.68979783211985, 41.007293655026345, 40.343354055958415, 42.314486272873424, 40.70943278651084, 44.69611806254233, 49.548827371289654, 55.16821099865822, 54.299147129058845, 50.569588907303356, 48.460557922240234, 45.37266808171427, 44.94230562640775, 44.26769325810094, 42.89226708873626, 40.25076258567072, 40.304648107098, 41.947442639258604, 43.425034784501605, 45.658118571004565, 43.930271364027455, 46.449295936092255, 44.86658819260136, 46.2308277622346, 46.1794957037895, 47.09832268376505, 49.46865804733769, 49.39839663044099, 51.99369169050648, 52.856248347989975, 56.42822534807267, 58.13937502522623, 58.13912007116503, 57.92952429863715, 56.47052026564076, 57.99171740008939, 60.77799266384494, 57.23000095736597, 56.13021935186079, 58.26873479350921, 53.46058753228957, 58.86855932974047, 60.372462734099365, 62.15516821030648, 60.80352729366672, 60.50417200211556, 59.61266825276037, 57.00636309962119, 56.842992459574056, 41.7220671715275, 12.337818318797696, 0.3345686149212622, 1.5039769487996257, 40.74396533350791, 64.43801902955579, 56.23820220270465, 57.960456109816036, 60.10238793588454, 68.75925894706481, 51.28713553951633, 34.964674518954375, 36.29824899858044, 52.32475150016047, 31.26003315371852, 0.22655233200038635, 0.06192163053539492, 0.03667147597298026, 0.05271534127513728, 0.06308429919543766, 0.012608682042017821, 0.02862904855470744, 0.09541966772127537, 0.012673732482888287, 0.10740524353159052, 0.0462970451541966, 0.034298246666308374, 0.01394769456613088, 0.03052113634053498, 0.11946115387423385, 0.13481799152589616, 0.1576571869513681, 0.26984521698567177, 0.10771282783318913, 0.14524640936043956, 0.1475764964256556, 0.16650455252778146, 0.15764106846144124, 0.14946695627464404, 0.24634576102177946, 0.16020075207756412, 0.1464087026373994, 0.209708939036054, 0.11477714674847742, 0.23746111760697058, 0.27892286859212384, 0.2628650528288657, 38.272617170887614, 79.67233611691384, 47.799524799469985, 40.41444701533164, 52.17828235318584, 72.15043821642476, 68.50239861396052, 70.74979905159243, 78.86294718711608, 72.29598168403872, 72.1704815280053, 42.4264189504808, 1.076951204769073, 0.8069825556970412, 1.1970020854665389, 47.31651236934047, 78.7253818204326, 68.00602266865393, 66.34642078030494, 66.20312090842955, 61.47872017275903, 58.80940998754194, 61.36281021179692, 63.0623810522018, 66.96983445075251, 61.998351850817286, 64.91341813918083, 68.68887593669277, 69.74451911064887, 69.53333085583103, 68.68200394415086, 65.47217938207811, 64.7728443145752, 63.30681139423002, 66.49575325750536, 64.57156396681263, 61.52924030057846, 56.176256210573264, 56.51140312994681, 54.93420239417784, 55.04316191519461, 56.615326327662316, 57.57345937913465, 55.01200260654573, 53.91426847827051, 51.732967822782456, 48.99003867180117, 47.00894363464848, 45.8139935616524, 48.74673405001241, 51.5401872511833, 50.48193962343278, 52.63917653791366, 54.23877008499638, 56.31689279310165, 58.19267611349783, 52.01029116107572, 48.49174860985049, 45.65276061334918, 45.923435534200365, 44.05658737305672, 45.02518923051896, 45.406423999417214, 44.53031555298836, 43.815494968045144, 42.89822909139818, 43.95795153033349, 45.06749983756773, 42.36320211041359, 46.78154422390846, 43.3810846267208, 42.09008747531522, 42.312560389118815, 44.44708285793182, 41.91998997042256, 43.79370620173793, 43.567844360105454, 43.54356881110899, 43.19652534300282, 44.16882207316738, 43.98645539437571, 43.823692721705285, 41.77722746326078, 45.35388385095904, 42.83502009607131, 46.12531208222913, 51.05753567910964, 58.1574022385382, 56.091023106728834, 52.571460739258804, 51.13587717856131, 48.2026699281508, 46.64363761102, 45.80715294807188, 45.90498470490979, 41.76997107844199, 41.761047686299975, 44.825524899267386, 44.6582083548269, 46.403172785235995, 45.27691125869752, 48.22045787688225, 47.04080896992838, 48.88680581123599, 48.076914818056174, 50.50591707229615, 50.95712692506852, 53.354275611139116, 55.17617733247819, 55.66937615794521, 59.8009890894736, 61.01972441519461, 61.647942989103264, 59.811167640070764, 59.216042103305945, 60.988251316931944, 64.41081739241078, 60.982489355148815, 59.32735112405593, 61.09183719081264, 55.289486762016054, 61.3085481428331, 62.65602742472003, 66.0281047513408, 63.42700850579047, 62.52477707401399, 62.38001023569415, 64.11062271364274, 61.182467476014175, 44.78666990034042, 13.728299525476272, 0.6263921590101335, 2.5052957861654224, 43.91981432514806, 68.84828890523603, 62.46000305298836, 65.29357817865187, 66.98943845687374, 70.3338630737797, 55.92000384484568, 42.5167707474001, 54.36880057857883, 60.43212198442029, 45.476112750268754, 0.2132785103974804, 0.1674693636596203, 0.22791138729981839, 0.10782692130775222, 0.17741529931945188, 0.0990678703472499, 0.10500630814461939, 0.2116715490457512, 0.15276531718911665, 0.11514388069870973, 0.17389751550170685, 0.15304300873990984, 0.16981402171715615, 0.1527418442551167], [0.02414883805378791, 0.07303349838982667, 0.05789517965768615, 0.07803228338279071, 0.027126577765410467, 0.05463871992223206, 0.05976713082242397, 0.04188345940483194, 0.019604452367451404, 0.025940535762797923, 0.03768838108367017, 0.031886280123745246, 0.035884531304961255, 0.026993688323625156, 0.05295848226054542, 0.013360167372851603, 0.12755832785079557, 0.03938894688842758, 1.9533312753323588, 39.82595812889838, 29.68251862833577, 28.87026244594205, 34.390914132518155, 50.775348601802705, 60.40963111385223, 56.34331387858237, 62.85876297181653, 64.13324302242648, 61.816989298789736, 35.08516580827775, 0.10550945171064909, 0.10350694384185538, 1.3283726813331729, 51.035903807609316, 71.52038789564564, 64.54816702873477, 59.87920115070959, 56.68815297465171, 56.45238714833414, 56.06129154082268, 53.32348108291627, 54.315785823329804, 57.89834930050758, 58.131859763976074, 59.424739653064364, 59.14382734606343, 62.8222692397333, 64.58058541820895, 62.998462107873735, 62.61676842166532, 62.10640530432425, 63.57925138165874, 60.30056961121098, 60.12394528235159, 55.99987506866456, 51.32875580941477, 44.325104990313136, 46.181445121765144, 49.14412113928026, 50.812979821235906, 48.7304130677254, 47.88307912888066, 46.55885950211556, 47.0166628591476, 44.338872509617964, 42.80277821325487, 41.6564812198762, 42.55702603247858, 46.87430827848373, 47.36522428451046, 42.84193131231493, 48.276681130932225, 51.00660370242212, 49.19237413714009, 41.030004178324056, 41.28333437827326, 39.13615049854402, 40.654452923805486, 40.0782096770502, 39.69596685901765, 41.01060021308161, 38.52415877003824, 37.834864970176454, 38.23757471576814, 39.28019562075215, 39.09874285421064, 37.59704382188859, 38.8135669308324, 39.02264887286771, 40.910109089266875, 39.58055111669725, 38.90288714439639, 39.8729520459329, 37.617812771951, 39.79712870813186, 38.88223586543914, 38.329919076734974, 38.5138782378166, 38.547096790805945, 40.74716990993869, 40.13049487144717, 38.50946164900257, 39.218026053520944, 41.17820701291485, 43.025188369135705, 44.86856898953838, 46.4837618027964, 49.634221292311146, 47.167505448864354, 39.863330471900206, 43.159113776299264, 44.022247022198094, 43.30979162646879, 41.4080108365705, 38.32830306022398, 38.3025997684848, 39.16455238096176, 44.69180737772296, 42.19215539193923, 43.35348290781821, 43.63463840176983, 43.43055748170422, 43.30682631461851, 43.96462740436677, 48.3878646358367, 48.68284648464572, 48.75439443895894, 52.2940158074902, 53.787552387483665, 55.16844241849838, 54.08777060047273, 56.94031038591939, 55.46677397143457, 56.6546323991591, 54.980717782051336, 55.0498652458191, 55.82608269106958, 55.507346968497004, 59.40539060100433, 58.63182860036051, 63.35740212471255, 62.29291792838805, 64.80214834213257, 61.62293395688457, 58.353693331441576, 44.026094867337136, 44.78551672350976, 42.15020564294631, 15.5714742214449, 0.25465137986165864, 0.7682498244027939, 35.30249257241526, 60.39982126605127, 49.36031433843797, 61.99034629329559, 55.52136944186304, 64.95757618258077, 35.74715598937004, 36.26479902575093, 37.512795232957416, 45.958505445911044, 3.9564570400022694, 0.1914165520499791, 0.08457065995542273, 0.05730947862649637, 0.0349219533194217, 0.004422815193632437, 0.07173551561971826, 0.026990413297748855, 0.11972480303337497, 0.009944965600997452, 0.0689122824358844, 0.017896597236094457, 0.04335831655489822, 0.04866485438880421, 0.02407524956300134, 0.004833812267714811, 0.046712260978717, 0.13219349687137913, 0.037541407115396955, 0.024591958630950223, 0.05686480289084777, 0.03212958964849672, 0.03555265052484409, 0.06839336511949379, 0.04292702820572642, 0.03412440599453065, 0.03488244999560618, 0.030772279114312226, 0.031481546297248815, 0.07600480104766547, 0.05184017009131851, 0.1860383543516359, 0.14839912163874797, 4.186729096597241, 54.92265885876071, 28.675069616686915, 27.889236480959003, 47.82608316790673, 53.40933392124792, 66.52186839811264, 59.694210406272646, 70.68424055653234, 67.94850503244709, 66.60104536241101, 38.92932784172797, 0.0661336585518814, 0.23196337954892268, 1.6503028066888934, 55.115627704128144, 74.04660609460647, 67.1154014525875, 64.70316733083418, 61.0557984536694, 60.00044945747622, 58.65323297439083, 56.06653182737289, 57.96803412898895, 60.82468063600602, 59.0923580046623, 62.69132875627088, 60.78234257236604, 64.46434597815237, 69.60425515328684, 63.11021827882337, 65.0834724980016, 62.608558900894664, 65.26840832925612, 61.78522202276415, 61.775321960449226, 55.65182747379426, 54.123648520438906, 47.839211340873476, 48.780937117915, 51.380252607407115, 51.01940239629438, 49.72865235420966, 51.15566945845082, 49.98743857106855, 48.68814168437835, 45.314675838716575, 45.22402986403435, 45.832424779092115, 45.38930677598523, 48.30394160362982, 51.60137230350126, 44.36670957073089, 52.55181358706567, 54.022423913401944, 51.08387439481674, 43.76957185806767, 43.59200223799675, 40.691287902093705, 43.44248933176841, 42.21126125704858, 41.807865096676736, 42.59888948932771, 41.66540853438839, 40.3448720132151, 41.49069832217309, 41.46257885040776, 42.915797387399984, 39.99536137427054, 42.18758975305865, 40.20442762682515, 44.261782246251265, 41.29932195909562, 41.986662418611594, 42.466454582829634, 41.98878049850464, 42.777573062527566, 41.04599960388676, 40.57055342581965, 40.19236241617511, 40.22387473813949, 41.97226732007919, 41.29849433898926, 40.442566487096975, 40.56509348653978, 42.4542324773727, 45.098404192155414, 46.32931847726145, 51.39008598942911, 50.219450689131214, 49.82114184287287, 44.04462806640133, 44.39165192265665, 46.32365065236246, 45.11969089508057, 42.86191578834288, 40.11881405307401, 41.11243278749528, 42.14087432430637, 43.91084386456398, 43.715400003617816, 45.879042148590095, 45.696055735311205, 44.31744852373677, 46.094301823646795, 46.79369180433212, 51.48927880871681, 51.72919058030652, 52.29598091494653, 54.90897370922951, 56.95043010096396, 58.07931569314773, 58.98821515421714, 59.62261538351736, 57.8872803718813, 59.15753995218585, 56.11356104573896, 56.42804884141492, 58.031596137631325, 58.07500893069852, 61.71691002384309, 61.59825048139019, 65.71595468828755, 64.39950135446364, 66.30236471852949, 62.3708515013418, 60.06358785013999, 51.38963883922946, 49.47221955945415, 45.39411560181649, 19.17434184781967, 0.5260593396040701, 0.9263660205948738, 39.948920511430316, 64.35127581319502, 54.51454408707158, 66.40081620985463, 62.281142973130756, 69.70254190506475, 43.254921590128255, 40.880781527488466, 40.669232414614775, 55.5903600108239, 4.026480418059134, 0.32103913445626536, 0.10342353984953896, 0.084001288088339, 0.04990620410911018, 0.022378328421543685, 0.026977002928634326, 0.03943459806783546, 0.03827013676204989, 0.07779201522709862, 0.07251263521010838, 0.014264962219092396, 0.04519768216977677, 0.0745193872060026, 0.035438300410826365, 0.15803641579564542, 0.14286252760118054, 0.24891595536422348, 0.16409822439234104, 0.07952494441621727, 0.2116278667123087, 0.17850167328311553, 0.09061962125762817, 0.1751462541400425, 0.09211938392611281, 0.16183644172645387, 0.10012029129410945, 0.1363931755505262, 0.11484476166867441, 0.18645950352712987, 0.1435592079595212, 0.4331294116714309, 0.2018953478264232, 6.531812241000514, 67.11760582462435, 41.61655933626237, 43.84643854633455, 48.862859741334, 63.003612179909986, 75.39157898195329, 69.37711069660803, 74.7513226539858, 74.83849340869536, 72.61296410714426, 45.51735647263066, 0.2233532254373835, 0.41238393454301747, 1.9064417914036784, 60.109428590343846, 74.68005318795481, 72.18570032427388, 65.2265017263351, 63.3123105572116, 63.449460152656805, 63.153670295592285, 58.753618194210915, 62.4602815412706, 62.51386896256478, 63.54185158206571, 65.99755733243882, 63.757099490011896, 65.52394290124217, 71.31643249142554, 67.01094089015838, 68.30980239375945, 65.14866229026549, 69.29920458024549, 63.58326004397485, 65.41507359473937, 60.06439193602532, 56.7132326095335, 48.97117207127233, 51.61935637074133, 53.515386965967, 54.82663923694242, 51.67281827618999, 52.81567927329771, 52.64169469956429, 53.150159389741965, 48.98651638338643, 47.86161591929775, 45.77029051319246, 48.702289673589895, 53.43429588502454, 53.57257120070919, 47.69638607578893, 56.27759848871539, 56.442604757124386, 52.74157001126198, 47.517145526024606, 46.648575875066946, 43.0535824068131, 47.72728258563627, 45.23387501316686, 45.37214248411117, 46.319720437449796, 43.87400888627575, 43.46963605573101, 44.961521317881925, 45.22230009878836, 45.68202541720483, 40.94903861322711, 44.82596420472668, 42.817118398604855, 46.48531506138463, 44.25894245024651, 44.551437516366285, 44.598784446716316, 44.09837630487258, 46.92396156249508, 43.30845017586985, 42.01783349437099, 43.17641535112935, 41.51330294147615, 44.848913992604906, 45.434802347613925, 43.83500091491207, 44.08415379062776, 44.885321432544345, 48.35774867765365, 47.67382460255777, 51.95023182899722, 54.764697167181204, 52.55341391409598, 45.64406471867716, 45.99329686933949, 47.73715126898981, 47.18622692169682, 45.4099541325723, 41.95466764511601, 43.742181947154386, 45.10212652144894, 48.35555607272733, 45.01904287645894, 47.95599206801384, 49.110749613854196, 47.1771623242286, 48.84841757435953, 48.828691974762954, 55.12734382383285, 55.19121962208902, 54.51761138054633, 57.47611399619811, 59.69108427724531, 59.93724438451952, 60.42172770346365, 61.426109421637754, 59.25224165762625, 61.34306500034948, 59.89868356335548, 59.864935490392874, 60.00594862045781, 61.145224571228034, 64.85707329165551, 64.25845684543734, 67.01582031865274, 66.41342270758845, 70.32834822131743, 66.55907600156723, 65.17302020903557, 57.18740009492444, 58.56622303685835, 50.81909087396438, 22.06782921668022, 0.9443887599533605, 1.4075634965012152, 44.417425817058934, 72.01572833522674, 60.317624076720215, 73.10293874432965, 66.54403763432657, 75.8625065895819, 49.08164562717561, 53.71902465820313, 48.98875605675482, 65.89288496202039, 9.285445540182053, 0.6318207806156528, 0.3703287412081996, 0.19746162928640845, 0.2262872655785853, 0.14472427447476696, 0.3682838993207101, 0.12443233671928607, 0.20237416810085698, 0.19762263032457522, 0.16066550697770812, 0.1225978012887701, 0.12041507123578941, 0.16903771417996577, 0.11756606685418276], [0.03559619496246019, 0.01557682745999867, 0.029398558976789637, 0.05431535803983289, 0.031477091495969126, 0.036472798730697364, 0.10601156871886024, 0.06725082158922188, 0.015109424768466384, 0.013847157017387932, 0.03248392829611417, 0.05820673995561177, 0.04757297225296498, 0.11513759111685139, 0.03869363782747138, 0.029581031544254194, 0.15644335127886266, 0.14794561290933242, 0.12888329223759715, 25.496749531838205, 53.08586782024753, 43.662683348501886, 35.2677325279482, 38.47688636472149, 72.36413678815289, 63.459603401922415, 54.23268256648895, 66.27102498085269, 54.22570859232257, 47.02799458657542, 1.3622308258087406, 0.23226858897795602, 4.5759650103507505, 66.4711364623039, 73.67913492264287, 65.52930478126773, 65.7797638062508, 64.35480986872028, 60.41023515885877, 57.79031153648131, 53.47823035332465, 56.4946702987917, 56.559381561894575, 58.43154845699188, 57.25579054124894, 56.92288329524379, 61.18582894725185, 59.94661492686118, 59.26335373232442, 61.69620775407361, 61.24666883099464, 60.16657360138432, 58.94609282093664, 52.66042793950727, 49.12915729707288, 46.67807602113294, 46.80791431857694, 44.64329942580193, 46.34490205395607, 46.5056368612474, 45.99237511234899, 47.07006200667351, 43.223405345793694, 42.39120391107375, 43.02796148484753, 42.039171188108384, 43.560003542131, 44.32493240602555, 47.59257270443825, 46.82007758848129, 43.5315389017905, 43.32660290502733, 46.46290656059019, 43.53434731883388, 41.12591005140736, 38.28871850044497, 39.191012690144206, 42.25454068952992, 40.23013876330468, 39.64324628153155, 40.18019522390058, 40.7300526865067, 38.08419827492007, 39.624167873013405, 39.08375155541205, 39.480330636424405, 40.28712687953826, 40.304773622943515, 40.446473167788604, 42.613963157899924, 41.60287810910133, 41.106419794021114, 39.95080324911302, 37.90649921663346, 37.982483371611565, 37.99175585469892, 40.10132812684582, 39.313422018481845, 38.00113424178093, 37.87272368707965, 38.630698188658684, 38.660343462421054, 39.04040936500796, 36.88618090844924, 40.57261659253029, 42.24074179126371, 44.870969480083836, 46.469245110788655, 44.23711838260774, 40.96308462081417, 46.65274535456012, 48.520177948859434, 38.884189205784956, 40.7965603951485, 38.686160502895234, 39.06974477152671, 38.81926613469278, 41.110122511463786, 42.177638699931485, 42.420205916127856, 41.88544957868515, 41.767233264061716, 45.20657139439737, 43.13515986165693, 45.777852842884684, 50.93158052813623, 51.291897296905525, 54.2901845132151, 52.9809836418398, 54.05805472404727, 55.07806708735805, 57.24853415643015, 55.28863953005884, 56.50056954353087, 56.851013706576445, 57.165913351120494, 58.276501086450395, 60.03453877664382, 59.49763298034669, 62.53392011888566, 61.219067112092056, 61.72593539760959, 63.538780366220784, 62.720926961591175, 60.39584790506671, 49.26641279651273, 38.230506604717625, 37.40039579329952, 21.320247034872732, 0.4673902426035174, 0.9831870070868923, 39.34653858984671, 55.791381482155096, 60.22172212600709, 52.98761244743101, 58.31452062053066, 49.59932396488805, 27.211690179763306, 34.517116392812426, 37.92303985165012, 28.27455835957681, 0.20039433643462198, 0.05027881395372172, 0.014016092811230452, 0.06196571123455802, 0.020669555899897413, 0.012122079271883255, 0.024316641952722304, 0.02823583286015257, 0.16860511965088307, 0.05468827815005376, 0.08420634684303115, 0.06599990726118127, 0.13080154575647848, 0.05374516262823055, 0.010752364816594749, 0.05748798094329335, 0.005492769020249046, 0.04240543724248006, 0.03491611572943869, 0.035250049625192924, 0.036315965210838665, 0.044533510752502954, 0.08490848940827193, 0.03601614137991302, 0.0361280859778485, 0.12286620019304177, 0.05160760878014469, 0.028576270842383948, 0.03446916854309459, 0.07130158043676807, 0.011179616840015496, 0.08600483783670972, 0.05869286870884319, 0.12217261482991519, 32.514381639419064, 61.426572261318086, 38.86197290112896, 48.88312662801435, 45.59713355956539, 76.01701659540977, 68.33352488856163, 58.968034559680575, 69.7794831183649, 61.70049490467195, 54.98728382971979, 1.6062737112083745, 0.33794405960267593, 5.593841643102708, 68.9613159241215, 73.06096153874552, 68.89831481441375, 67.2195403806625, 67.3054010637345, 63.92014457333473, 58.864150585666785, 58.92739880469538, 58.478809095198116, 61.10677357642882, 60.07911651365219, 59.540528020551136, 58.942735272069136, 62.75393762896138, 61.7737530123803, 61.12143147376276, 61.77374909001013, 64.14766165517992, 62.44028922050231, 61.04149356965096, 56.11838163868074, 50.650495636847715, 50.57822204405262, 48.88342080577728, 47.3175282632151, 46.01472869996102, 48.44036556059315, 48.88041234785511, 47.7156880594069, 47.54075819446195, 46.77634316105997, 45.18420603967483, 43.736102273387296, 46.89908981323243, 44.478661860189135, 48.96795965010121, 49.64144629816855, 45.329620069073094, 46.36383533477784, 48.34564816567206, 46.41682655580583, 42.32559050283125, 40.2429021558454, 42.78607283869098, 43.82022142410279, 42.72759422179192, 42.51336220772036, 42.93195363013975, 43.01477055395804, 41.68669523731355, 41.998198109288374, 40.749338980643984, 42.98572148046186, 43.00674538458548, 44.53748172329318, 43.789568101206136, 45.0708338522142, 44.047397259742986, 42.68075719956429, 40.56808625498126, 40.05476174816009, 41.97646425616357, 40.59972801516133, 42.24878265011696, 41.32647652779856, 41.466740485160585, 41.45423204668107, 39.433689732705396, 41.132056405467374, 42.28354269458402, 41.49535025319746, 43.18663312542824, 43.45589207064721, 46.71863332871468, 49.22916989172659, 45.69958194609612, 45.10074192477811, 49.96443779237809, 49.723074743824625, 42.188923358917236, 42.03968109623079, 40.465528042085715, 40.60294043633246, 41.93336133033999, 43.29908747826853, 44.351137761146795, 42.86981151949975, 43.38963539369645, 45.18329997216502, 46.08196204708469, 47.09753036499024, 47.560044488599225, 51.97300118784751, 52.38363412118728, 56.08380594561177, 56.36258840560914, 57.01937752385294, 56.87525003187118, 59.385872887026885, 57.43629017183858, 60.26593116021926, 58.176092332409276, 60.0090237586729, 61.76159366484612, 62.44903610598657, 61.21032022660779, 64.32091274569112, 63.67666344488821, 63.19679283326673, 64.44885261597173, 65.17263189438852, 61.737992763519294, 54.384137045952585, 45.35647653764295, 42.02354446534188, 22.3141775977227, 0.673227281339707, 1.167750151888017, 45.1153645207805, 60.430941350998424, 66.89218721082135, 61.082094023304606, 63.31928845374816, 55.07243848616078, 37.89735617176179, 38.912544019760624, 43.8123413824266, 30.065577299364154, 0.19357010181392395, 0.038896949901696176, 0.029459137379402117, 0.022714529937553792, 0.09060361002001072, 0.013889945900788712, 0.024620152581783555, 0.053904868977805304, 0.05132566927181137, 0.08444803226138316, 0.03452955159328638, 0.016726129800982533, 0.06355768407604868, 0.05437373010922344, 0.00575810213640873, 0.14054584707463944, 0.18267961038697153, 0.1832028177957381, 0.17429637151860422, 0.10516291183810081, 0.21160209551453593, 0.23836937612823902, 0.12231532168845016, 0.14297445304691792, 0.09884735959912501, 0.2498502915184344, 0.2368454893510188, 0.10486248279771498, 0.26521087534004645, 0.1935801528874905, 0.1446179721143938, 0.20341278414332098, 0.22482940025867956, 0.2341639211461429, 46.30017526688115, 73.98014545440674, 60.34248013650218, 53.596062275671194, 52.656517336445475, 84.21563317698818, 73.2586411506899, 67.38320519847255, 76.63583324801537, 67.54588157899919, 59.72572665060721, 2.7284560953417136, 0.46479154979029014, 7.024866429067428, 69.71237136471656, 76.46764201502647, 73.43324938128072, 70.89251841268232, 70.47713156669371, 67.63123235394879, 64.41026826058665, 58.755187142279844, 61.58294931534798, 64.20651289724535, 62.61651738997429, 63.50209836036929, 62.578521390115064, 63.26998033831197, 64.25938644716817, 64.4345045858814, 65.33260576186642, 65.4515241807507, 65.89067274524321, 64.05546242190947, 58.2057297614313, 55.2158050383291, 52.52437660771032, 52.27810667407129, 47.284152815418864, 50.02835281433598, 51.257364749908454, 49.60658034970684, 51.626977535986136, 49.96270018239176, 46.849801309647106, 46.69966866893154, 47.70607040774438, 48.02411579316663, 46.93787813186646, 50.81667469393823, 52.23392901882049, 48.5969897239439, 48.57247491036692, 50.23279067008726, 47.3104444626839, 45.220793908642186, 42.86716391963344, 44.357197823063025, 48.85268511310701, 45.466377427501065, 45.79000042330834, 45.71562444010089, 45.67796576407648, 44.62623319318218, 44.60160070850004, 44.14216564547631, 43.98463933698593, 45.86386257602323, 47.770558095747425, 47.82105076697565, 47.15421645872055, 46.945597356365575, 46.22131209219656, 44.23506698300762, 42.791442563456876, 45.11724333609305, 43.167633164313536, 45.718021008276175, 45.30382264044977, 43.677964902693226, 44.15107727050782, 41.79361120347054, 44.102467336962306, 44.386042933310236, 42.509596732354936, 46.48655060798892, 47.39888214295911, 49.4680893036627, 50.588149562958755, 48.49162701637515, 46.557765160837484, 53.67569031253938, 53.805222665109945, 43.41813141299833, 45.922686361497455, 44.147327484623084, 43.220781280148415, 44.10947269009006, 46.12697516718219, 46.858520738540165, 47.02097746633714, 44.95744597527289, 47.188607800391416, 49.65970885369086, 49.25100964884604, 49.99102361740605, 54.6735099054152, 55.60152307633431, 58.87043422268283, 58.14764730391964, 60.608416834185206, 60.02357182964202, 61.31606732645343, 59.54266963466522, 63.5265229594323, 61.823104273888376, 61.6901869158591, 64.27657035089308, 63.624327259679, 62.967667579650886, 65.08320969920005, 67.14817677774738, 64.36862445646717, 68.31491716446416, 68.03801351977934, 65.84422403766264, 60.15288452948294, 53.39569976252895, 45.80337178322577, 26.596988093468454, 1.0120870918035507, 1.8741555367746663, 48.30546740562686, 67.45299200857839, 70.97964209894981, 64.02371083536457, 68.73370862776234, 61.28557482073384, 39.8739012595146, 52.14924112443001, 49.54768596156951, 46.38307456047305, 0.31597060481867484, 0.16141259592146645, 0.08307448257842372, 0.0893835154091639, 0.15580155345941746, 0.11969566104873536, 0.10706557546772304, 0.21399213662070615, 0.4333685230343573, 0.28581539229039227, 0.10503852214183539, 0.17401238272507347, 0.23606316036274358, 0.23846657736407173, 0.10404581008779426], [0.08669889817434935, 0.013638220900189013, 0.023671243520032977, 0.005800311187011821, 0.06868607199360287, 0.02368395866435622, 0.022840832938410105, 0.08525789444965702, 0.028765144074455868, 0.09020120701602391, 0.013660259334550751, 0.029885361887394424, 0.0627878538122581, 0.0073958654895484935, 0.05347147005640211, 0.06643041037023067, 0.12657662448022636, 0.06545844397717906, 0.13758741469392854, 2.8368056877966854, 38.21543293614542, 33.36646556854248, 35.706414330390196, 34.25125814253284, 46.6552556714704, 69.59641825768256, 62.40150874660861, 70.28004031027518, 53.151355712644516, 57.41679599208217, 4.130707354314866, 0.50589811177023, 10.46231250609121, 73.40842077808996, 69.35865986731746, 66.8623536632907, 63.789141331949544, 64.30820818870299, 62.304037847826564, 59.81948698720625, 55.940851242311545, 54.45581443848149, 56.7062625577373, 55.60020515995642, 55.344984377584154, 58.05503622178109, 56.54428435910133, 54.17919712681925, 54.815911554521136, 53.555430443056174, 50.62194078199325, 47.20125352182696, 45.80130861651513, 45.689991751024806, 45.964385078799346, 45.36250129822762, 44.90297994306011, 45.89078572488601, 45.865906130883005, 44.57053161436512, 44.54942926283806, 44.60441697028376, 45.96114127866684, 44.402375682707756, 42.87729540178853, 42.1112721966159, 44.344289302825935, 45.13464297017744, 51.411953203139774, 47.19444820957799, 42.49599003022717, 43.291787947377856, 45.044761857678814, 42.22020033867129, 41.21015471796836, 40.698673725128174, 40.05497355614939, 40.180956163714015, 40.40895961946057, 41.92441048160676, 40.4294853825723, 40.47024273103283, 39.54675989766275, 40.71711670967841, 40.839098499667266, 42.47985732170844, 43.20625282103016, 42.82302156571419, 41.531118346798806, 39.65513106315367, 42.67199854696951, 41.504944370638945, 41.8887443696299, 40.410050038368475, 38.98315060523249, 39.99883659424321, 38.84682862989364, 38.87137090006183, 39.5816493803455, 41.18290993475145, 39.40637434682539, 38.581809766830936, 38.311177992051654, 38.503095642212905, 40.057319133512436, 40.201281885946955, 40.618445565623624, 42.46555636006017, 42.399311450219926, 40.323098936388575, 43.21587439506285, 45.55333245185114, 40.524398896002005, 41.001818026265795, 40.76536970753824, 38.64784286868188, 40.12320318529683, 41.80386427910098, 42.01697449530325, 42.04133241407333, 41.77096736046576, 41.58086184532412, 41.25403035071589, 42.92818815477433, 42.590040622218964, 47.9307359264743, 50.49184753048805, 55.403890532831994, 54.93521828805247, 54.10220884507703, 52.94883981827767, 53.74732063662622, 53.73738135060957, 54.84760038314327, 56.150548996463904, 57.84990410650931, 56.3772580700536, 61.80214312768752, 60.65185316147343, 59.91769921395087, 60.371180119053015, 61.743233050069506, 60.7398711481402, 62.699820687693936, 58.85213636582898, 58.21035031349429, 49.69252340255245, 42.48501523848503, 20.23582543096235, 0.26782611565243813, 1.3108470411069932, 44.40789445754021, 57.120609975630245, 43.006914046502885, 53.10263595273418, 49.983296548166585, 36.5327557440727, 30.30509291156646, 31.184064688221103, 43.14410286564981, 7.269316873242778, 0.3742359734831318, 0.10086442313848004, 0.12769027883487363, 0.09586142466193247, 0.02577912678281146, 0.0682364090255672, 0.02132871901736625, 0.05704030597342118, 0.036991057211473104, 0.018926447317484888, 0.011255102356024569, 0.05115415750732345, 0.049574055198219516, 0.04436584857983455, 0.024122706794690703, 0.026112696786801663, 0.06993008386944571, 0.01898367791586826, 0.05469797682317515, 0.0535127392128831, 0.04221414891822685, 0.032483074108078595, 0.03448068667503615, 0.028396563852326046, 0.015102011910189065, 0.060223566007710276, 0.0362706549405571, 0.06391030285627612, 0.07119199155919975, 0.040191921946262164, 0.03917738404725829, 0.03594722794068437, 0.09406052815217165, 0.21020495032350864, 5.932309339123388, 52.94577252480292, 35.933068490797474, 41.16187426351732, 46.022667577189786, 51.68535024889054, 77.00934487004434, 63.9439376708, 76.03295710779007, 56.798175457985174, 64.21903310283538, 5.411857395402847, 0.7565554003081014, 11.630204108453567, 78.27764326526274, 73.66399457377773, 68.19024070616692, 65.79527678028231, 67.41703956357895, 65.63864869456138, 63.5524929723432, 59.46566566344231, 57.73967765992688, 58.9073907944464, 57.416395910324596, 57.808899648727916, 60.49857870224984, 58.604018995838786, 56.34947984449325, 56.461239937813055, 55.009080440767356, 53.96593001581008, 51.52753760737758, 48.3867310708569, 49.21834022768083, 46.88413773813556, 45.94926041941489, 47.08473167111797, 47.80780492290374, 47.987276892508234, 46.60393930250599, 47.0024089659414, 46.34572182932208, 47.90907659838277, 45.47385738741967, 44.85793152163106, 45.18689286324286, 45.524765829886164, 47.24545863366897, 51.93759395230202, 49.7680486402204, 44.48056420972271, 46.021883103155325, 48.48521001877324, 44.98327478285759, 43.2939923194147, 43.266406289992794, 41.894118016765965, 41.30790018266247, 43.823296562317886, 42.84167635825373, 45.18928550904797, 41.64039950216971, 42.0928958923586, 42.231410472623764, 43.42436798157231, 44.5119902395433, 45.542090938937285, 46.27179299631427, 43.84686216231316, 41.9179307260821, 44.99661868618381, 43.963431081464215, 43.92155585750457, 40.67759098545198, 39.99846004670666, 41.795227219981534, 41.27212032195061, 41.53923373068533, 42.97249917061099, 42.67068063059161, 42.65821926055416, 40.42348807857883, 41.00106100882254, 41.910089908107636, 44.011436970003196, 44.345748424530036, 44.57372834605556, 45.97777212819746, 45.047774237971154, 41.37509822845459, 46.17801697023454, 45.91732840384207, 42.25146947368499, 42.78269567797261, 42.3472890546245, 41.65934847247216, 42.23724303707, 42.27680406262798, 43.14969224314536, 43.6560506205405, 43.118054405335464, 43.60771525290705, 42.67006481847456, 44.84794908954252, 43.68690790668611, 50.90712847248201, 53.077419034896366, 57.51128588953326, 57.28862077959123, 57.759340501600704, 55.95425790356052, 57.52499457328551, 57.24232112207721, 57.44179325719034, 58.64296420927971, 59.244373383060584, 58.634040817137695, 60.91284375036917, 62.4192927729699, 62.40514086138818, 62.349423593090435, 63.92824426774056, 64.06295807130876, 64.14034251243838, 60.604514075863754, 63.402160290748846, 55.78593723235592, 47.828350297866336, 21.354881563494285, 0.6185864585061228, 1.7563618575373006, 48.08844658636278, 64.42961339027651, 51.79083062756447, 55.42450651045769, 56.62168056734147, 43.31293736734698, 37.831903580696356, 33.79835382584603, 51.15726978548112, 8.73972225573755, 0.2792183946697943, 0.18817426877156382, 0.10970330046069239, 0.03168444659921431, 0.04028387547981355, 0.03889762022862992, 0.01162951154964826, 0.014725233589659536, 0.018858372744533326, 0.01115569765979965, 0.013589482386446288, 0.017345511887763298, 0.04115032475261439, 0.06340317563304017, 0.008319887227468915, 0.2085777029635445, 0.19990597070465166, 0.11414498631511966, 0.15633988344380934, 0.2203242363588464, 0.13181570827239944, 0.11595613308130734, 0.15864424527652804, 0.1454798363509678, 0.16156843352702357, 0.131347689837698, 0.12408758183160137, 0.21413010905586907, 0.11726887836571663, 0.1510203221151906, 0.21303466461118192, 0.362535696476698, 0.14864837600579187, 0.5505049601197243, 8.111434550054613, 66.17321675823581, 46.53015951956473, 53.1940624790807, 46.220025554780044, 59.15029925684775, 82.4750578788019, 74.06612380858391, 82.0040439790295, 63.31953556306901, 70.2450841472995, 6.397050878693981, 0.967240243429138, 12.674079191300178, 77.24469492512365, 75.62397156992267, 72.62786126905873, 69.84009158226752, 69.62136453197849, 68.70755426345333, 66.2540646522276, 63.145633359109205, 59.52775678327007, 62.03426899448518, 60.67942350141464, 61.06546709614416, 63.01299841173234, 60.869956554905066, 59.799271091338134, 59.54391302600984, 58.25841895995602, 57.75038180812713, 53.28783458279025, 50.168616771698005, 51.059151695620635, 51.002689176990145, 49.653813531321866, 50.812175735350586, 50.255654165821696, 50.774968131895996, 49.179638201190585, 47.53347043068179, 48.03797352698542, 50.48148070612262, 50.90997219085694, 48.30875827420143, 49.98278664004419, 47.735150860201934, 50.04003755507931, 56.98478614130328, 51.04786311426471, 47.64326933891543, 49.64847126314717, 51.27585872527092, 48.24481187328216, 45.929228874944876, 45.473492606993645, 45.28341454844321, 44.020211312078665, 47.573894377677675, 46.75396996159708, 47.34622040102559, 45.46988402643512, 45.30092400889243, 45.28297132061374, 46.816374871038626, 46.714848241498395, 48.01516886680357, 49.29494411714616, 46.407220671253825, 45.5274095073823, 49.360310416067804, 47.72436826459823, 46.636600878930864, 44.97176262640184, 43.147648688285585, 44.72649681952692, 44.06570296133719, 44.21999723680558, 45.93069976375949, 45.72312793424053, 44.496222311450595, 43.48412136877737, 42.68891572952271, 43.995233658821356, 47.04655916460099, 46.857202822162265, 45.79307163915327, 48.49672217522898, 48.7056903685293, 46.137538110056234, 48.63910421248406, 48.466355185354914, 43.53739892282794, 44.078113340562396, 43.00251706953972, 43.330458594906716, 45.99973740116243, 46.99791392972393, 45.959929266283595, 46.12811265453216, 45.85480190092518, 47.24752964511995, 44.90413311989077, 47.643371320539906, 46.859344436276345, 53.21765945803735, 55.168093327553045, 61.008996732773326, 60.03605281153033, 58.63222475974791, 58.04892516905262, 58.73189610819663, 59.60325848671698, 59.590954011486424, 59.782620629956654, 62.47082094992361, 61.187550867757494, 63.188861800778305, 63.36619215626871, 64.00876268263787, 64.75806874613609, 66.56324940343058, 64.94828801001272, 68.34975565633466, 64.76104974746704, 67.21377449650919, 61.18499348240515, 50.94066473745531, 24.394424269276282, 1.3602551769825721, 2.4551362712537093, 54.597627732061575, 67.39278362643334, 55.22070407867432, 62.2551808049602, 64.68547744135704, 46.841050501792665, 47.62776028725409, 43.838150578160445, 58.93307055196455, 16.14227125721593, 0.6937042599724186, 0.3492577379990009, 0.25253726830405576, 0.24536336051119914, 0.108466780924749, 0.19454237464214527, 0.1229895020444547, 0.18220569307525314, 0.1933535900447638, 0.06995998428113039, 0.14207359493499802, 0.1082152895809662, 0.16338355628953827, 0.15190354488309354, 0.11783743051872139], [0.012736118853002066, 0.06227208511723627, 0.025254760666059393, 0.08978755784130867, 0.03345359642539294, 0.02696996449583, 0.022265757546730103, 0.052447945946046425, 0.06390724233501861, 0.019423544534572193, 0.06109885593515731, 0.08001695672470717, 0.04276874677969083, 0.021955401922065406, 0.1084709867474533, 0.01695200891023682, 0.025691290971853083, 0.015463944404355943, 0.06825171546229432, 0.2673521523754443, 13.095912452666992, 53.78401833195841, 26.37394839717496, 30.59591900917792, 36.900827038672666, 66.02176620114234, 62.25314509484076, 66.46512739119991, 57.09195706152148, 59.89166644311721, 10.241268315622884, 1.883640318147598, 16.160841718796764, 78.6402742324337, 67.98769735520887, 64.38786368216238, 62.239428566348174, 62.49987002341979, 61.83371428520449, 60.544042894917155, 56.419894233826675, 57.305953733382694, 55.2751701108871, 56.17134148074735, 53.285708658156864, 53.24146824498331, 49.18619248174852, 48.89831404532156, 46.73584076666063, 46.554874374020486, 46.26395217833981, 46.914124258102916, 45.62404101894748, 46.37090344582835, 46.065829338565955, 43.14808799374489, 44.06078038677093, 44.64096169317923, 42.91172596716112, 44.947314493117794, 44.62340124191777, 46.261618368087284, 44.08768784615302, 46.33884591441001, 44.390694864334606, 45.86130126830071, 44.353114635713645, 42.30524516874745, 46.87736772721814, 47.198060712506695, 43.94419577813918, 43.90246568187591, 41.965159985326956, 40.17076584600633, 39.87765889013968, 41.217591531815074, 40.258760298452074, 38.57094480145363, 39.966218163890225, 42.011694985051314, 42.41912726433047, 41.08490951599614, 40.30555025223763, 43.28167215470345, 42.145188931495916, 46.35190740708382, 46.61830302207701, 47.4969570867477, 46.79771615612892, 39.96822641741845, 47.18324592036586, 48.34414982026624, 45.62332714757612, 42.27922808739447, 42.25279131243306, 38.985704068214666, 38.6604219098245, 38.46130671039705, 39.22016766763503, 37.78789458736297, 38.213142271964784, 38.41700746167091, 38.22437986250847, 39.065539990701986, 40.31854898698869, 38.2579122051116, 39.913395604779645, 39.64831006142401, 41.53056921497468, 41.65435921761298, 45.06999054262715, 44.881379450521166, 39.85911392396496, 40.515055810251546, 40.96471240443569, 38.72451343844014, 40.03932722153203, 40.74968022684897, 40.9177420216222, 42.22041214666059, 40.02106466600972, 41.073205163401944, 40.13140486132714, 41.59792415557369, 42.4707809571297, 43.06185468550652, 46.07789062684583, 51.54451754785354, 54.506040388538, 56.69170664202783, 55.73138490799935, 55.697621145556056, 53.941572097039995, 55.37923843629899, 56.171659192731305, 56.71134594948062, 54.65698103750906, 57.25957562846523, 55.799402729157485, 61.3888547497411, 60.49564476936095, 58.97809936154274, 56.52380958680184, 54.94571455063359, 59.149667755250015, 66.64847466253465, 61.82112347695136, 59.69665404289, 18.036862342588364, 0.19119003517252786, 1.8449935725619717, 44.40436432438512, 43.17648595379245, 40.94431607953964, 51.710433806142504, 55.942047565214104, 31.42073658204848, 28.44858019582687, 32.85180353349255, 41.94228472248201, 0.4486290557730583, 0.046762286520172516, 0.05020545337409262, 0.05210195382636401, 0.029609528099817616, 0.02958107367909003, 0.06541163600500553, 0.030356584484839154, 0.048318287703178586, 0.045486669687013474, 0.027928761837463227, 0.021221859328028177, 0.02792612457978389, 0.0467581496453814, 0.011374905100843359, 0.01843543475373618, 0.03106875705622858, 0.035014312879572955, 0.014118256381592684, 0.0264624695503904, 0.0657285895619181, 0.055627701128081936, 0.04321969677543929, 0.09312547187531188, 0.03776226260308777, 0.0820971076046267, 0.031725535725033095, 0.04604374584291251, 0.026719831042892994, 0.06750316329060063, 0.04870593202330413, 0.08560252676327383, 0.05492984099433788, 0.03611267994969122, 0.05906743590810126, 0.33503914612435526, 19.63405736031071, 66.0906587108489, 26.17224051106361, 42.411098172587735, 44.98562820496098, 76.06974894000639, 68.75698397236486, 72.1956866787326, 61.06005030293619, 67.55520897526895, 11.132391595071363, 1.7651255356688655, 16.50510226526568, 80.60072191299932, 69.2396943799911, 66.07288252922797, 63.58604884916737, 65.55340774597661, 64.43562638375067, 62.17010459592266, 58.166945365167436, 58.10973759620421, 57.14184961011333, 58.44795965379285, 56.226674356768214, 56.564727752439445, 52.541580123286096, 51.62732662693147, 50.12869488808417, 48.35495987246114, 47.25127550863451, 48.74595742071829, 48.50741847868889, 48.30851508725075, 47.3652046726596, 46.77925355972783, 46.84429822429534, 46.84500032855619, 45.25168649611935, 46.79989307157455, 46.61658110157136, 48.93859678699125, 46.28086543852284, 46.30523904677361, 46.08330349768362, 46.90648348100724, 46.08930472404727, 44.33676619683543, 48.22740831682759, 49.302761400899584, 45.697322660876864, 46.657369828993275, 45.09637632677632, 44.10582880819998, 42.361001660746915, 43.30659881714852, 42.07764179475846, 42.58376482994326, 42.89116490271784, 43.660922204294515, 43.56945645424628, 43.25530598240514, 42.26953198832851, 45.07397567072223, 44.42368984222413, 48.741603589827015, 47.656652465943374, 50.646306545503684, 48.194593767966, 42.78093453376524, 48.12728981817923, 49.61841021814654, 45.72179432838194, 43.95646887440836, 43.38129643471011, 42.018594434184415, 41.700929518668886, 42.37291389896024, 41.050243608413204, 40.060598234976496, 41.799286873109885, 41.66578900429511, 41.42230003110824, 42.713607049757435, 42.46497584927467, 42.030059522198094, 42.33502772546584, 42.75075189528927, 45.30491305935768, 44.07350063323975, 45.61904391934795, 46.495807401595584, 40.75828982937721, 42.869152561310806, 41.95679356974941, 41.42251183909755, 41.641666427735366, 42.99936740629135, 42.528781044867735, 43.83196892276887, 41.82944205499465, 44.22845778926727, 42.60502407627721, 43.92159508120629, 43.68695497512818, 45.13216010985836, 48.51562407708938, 53.69806351200227, 58.08448537703484, 58.843252197388686, 58.689914980242335, 56.88055307634416, 56.85558719019736, 58.728546404069476, 57.759003177765884, 59.863919596518244, 57.35037457558417, 60.27547428684851, 59.00510095780896, 64.82736918234056, 63.20737931036181, 61.313753128051765, 57.17114971530054, 57.29848946294477, 60.64761700168733, 66.8565171764743, 63.84555285976779, 60.333474374586544, 17.899879447875485, 0.1915752088590976, 2.8943448970394754, 48.191012643998675, 50.72109045520906, 44.76841126718829, 60.13313539566533, 62.61769802339616, 39.783031709732555, 36.593540714633086, 37.87545365671958, 49.5221277975267, 0.5732567295912774, 0.025536462687136188, 0.07234576593844161, 0.026697346362315362, 0.06502650828371126, 0.04067860994367831, 0.009486996324642772, 0.045334444186019326, 0.042925193425147765, 0.008380277938539944, 0.0663102877837035, 0.028669314136007623, 0.029828125543351618, 0.04402374818680748, 0.04693363357575671, 0.016640092381426407, 0.08309194172221808, 0.1596628817459268, 0.1651939599504394, 0.17018237211290868, 0.17026196864824142, 0.1943614246744302, 0.14678685895858273, 0.1875338652321408, 0.1338861987835938, 0.11665105909830141, 0.14665886098819395, 0.1314413057820451, 0.10476866000962835, 0.1736541600116799, 0.16712551275568624, 0.12078516065113007, 0.14324040813071115, 0.23148368593425522, 0.3385630892890115, 0.3835048712790013, 29.800678068591704, 77.12899284978067, 39.25177020411338, 47.16747406990298, 48.304918273802734, 81.72766593194778, 75.60362231346869, 79.0123502669796, 69.12444729958811, 75.61358513370638, 12.249446338222874, 1.9104118428884016, 18.06650761635073, 83.25865330234652, 71.65214030973374, 69.76196581317534, 68.03518156851491, 69.40652062816005, 67.60987897073069, 66.08413188688218, 60.51339349439068, 62.930267780057854, 61.88786260543331, 61.538191149311686, 59.91423968345889, 58.24200776315505, 54.82142640698341, 52.12105889474192, 52.892028208701845, 51.23110840397497, 48.84081209859541, 52.06357263749646, 50.43735011931389, 50.40639869628414, 50.0958332707805, 48.87070448167863, 50.463410346738755, 51.06561576166461, 46.8875031317434, 50.42521038363057, 48.950387431729226, 51.317353479323856, 50.14960504347279, 51.235454390125895, 49.009077856617594, 50.83077953707788, 49.49075275851835, 45.561098744792325, 49.90632395590506, 50.958013380727465, 49.929493396512925, 51.088906795747825, 47.11421612770327, 44.69915789942588, 44.076034484371064, 48.63981416148525, 46.25148296356202, 43.66217736274966, 46.37636730747838, 47.779206921977384, 46.01542295948152, 46.32572166381344, 44.46525912131033, 49.19455105258573, 48.32120395475819, 53.24620646815146, 50.60538053512574, 53.62468773318876, 52.314502346900206, 44.58309104365688, 51.85143516909692, 53.560925683667584, 49.09667222730575, 47.07002670534196, 47.77915593116514, 43.89250286163823, 43.91174208733344, 45.8540056597802, 43.72174247618645, 42.928290136398815, 44.338892121468824, 42.80724971525131, 42.61799535443706, 43.41571915534235, 45.613901692052046, 44.45831260373516, 44.50466325206142, 45.60455860630159, 48.189016157580966, 46.385220096957305, 48.41689017511184, 47.81848553688296, 44.22061304892264, 45.8052231419471, 44.734529833639826, 42.457809678969845, 44.40469772584977, 45.909224787066066, 45.13925567750008, 46.586237645918324, 43.2718466174218, 46.48293418269004, 43.428459013662035, 46.318739844906716, 46.515956617170765, 47.83998797016759, 50.07622141991892, 56.69643702045564, 58.860373343190844, 61.8120353452621, 62.31363588763822, 59.508760744525546, 58.3969884534036, 62.160910560238754, 62.40645093302574, 61.8552637869312, 59.945818685716205, 63.91322943472094, 60.30244842652352, 68.27039826300837, 65.45721553987073, 64.79947328567505, 60.237811688453924, 60.456060209581935, 62.98434549762357, 72.33740191305839, 68.89291763305664, 65.15545191303377, 20.502240657806396, 0.6663756360930781, 3.061496456784587, 55.284470050565666, 53.45884207756289, 53.82499533314859, 63.92409047772808, 68.86018937633884, 44.490825130093484, 46.745689838163315, 47.412426087164114, 61.47490762895154, 1.9468544615853218, 0.2168406200625243, 0.23730508081855314, 0.1416566898866046, 0.19032101567474105, 0.16280232538138667, 0.09988800577458837, 0.1444780538159032, 0.2094520391115258, 0.2351211786510483, 0.22666614202241744, 0.13310492699665408, 0.10254584057557006, 0.10367461750584264, 0.15733768232166767, 0.14681408572341167], [0.06648032099849756, 0.06293831348058677, 0.026151133333182624, 0.06815359492095248, 0.0034915199296759263, 0.026679902540279493, 0.05256282083029228, 0.033954480032046, 0.023091021932721622, 0.03713118618414287, 0.03213138803989897, 0.031033865581717224, 0.03981341705507329, 0.022263589517904386, 0.049087371031243, 0.01803173323071772, 0.0842815077292823, 0.02306455167971792, 0.08690000391535221, 0.03534445847054163, 2.09613349649214, 37.66605792507049, 37.75893180601059, 31.133364131373746, 25.22760629653931, 44.31708766568092, 66.15479730790662, 67.16008509359052, 59.51064348220826, 58.78969615505588, 27.978140923284716, 0.9406406901055767, 7.2490141949346, 75.75078179759365, 66.16207722694644, 65.57955818791544, 57.756700746474735, 55.33068733830606, 55.621087858753825, 58.18881650124827, 56.13926433747815, 53.25813831821565, 53.79216901717648, 50.269543278601866, 49.62071264943769, 49.60131652893559, 49.21846182115617, 46.40286291799238, 46.0370469862415, 45.97332416042205, 45.2457284158276, 47.981212908221835, 45.42919335826751, 46.468903864583666, 46.34611798870949, 44.42506267178444, 45.05057873264436, 44.396782382842034, 45.70543804476338, 46.43617560786586, 45.19518867615731, 45.12271112011325, 44.58913541609242, 42.79884799834221, 43.270520856303555, 43.22740224099929, 45.771059297746234, 43.659655278728856, 44.25673023346932, 45.30436784990373, 42.72420529396304, 42.59388454498784, 42.0201829941042, 42.35596533744566, 41.82411939867082, 40.01008595189741, 41.83669451744326, 41.87171736071187, 41.26247129132671, 41.10303871093258, 42.38229620841242, 42.56516887295631, 43.84584626843853, 46.15277259580551, 48.27162519578011, 56.21589568353469, 58.41065006871378, 58.09898245719172, 60.33984430374638, 42.34694388604934, 46.61409039651194, 56.66913340168615, 55.76926715912358, 60.98037519762593, 52.225593982204316, 47.20861973301057, 43.549193489936094, 44.00993862459737, 39.929583226480794, 39.56430465944352, 40.23509271683232, 40.698277565740774, 38.14238663642637, 39.14362261372228, 38.52815174287365, 38.67320883658625, 38.25501749592443, 40.19474721723988, 38.77082878543485, 37.86473381903864, 42.139364211790024, 41.53482890898182, 41.017809529458326, 41.51437374853319, 41.976750589186146, 39.3678762835841, 39.570643209641986, 41.75383052518291, 41.36886950462095, 40.15920662110852, 40.710291785578576, 43.21825919612762, 42.23974550923994, 40.468042281366166, 41.33705123778313, 41.715591338373, 42.27488602361372, 43.85128267349736, 46.34210148165303, 52.90040246901974, 54.58992027467298, 55.5044993277519, 56.01492520301573, 54.562969669218994, 53.518987701785186, 56.17731917288996, 55.7372292395561, 58.59029854497602, 62.06965661817982, 58.781855337081424, 54.77923739340998, 50.93555388912078, 48.30593809004753, 58.3914343772396, 62.49960330224807, 61.93026342699605, 65.66765069961548, 53.884701651911584, 9.365355987702648, 0.5383095145225525, 5.378227974137952, 44.806556317114065, 54.92257256661692, 58.60232060955417, 63.93967013205252, 29.806136046686483, 31.079698262676118, 33.31270556296072, 39.727106555815666, 20.872310400009155, 0.2772035527854197, 0.10213134104325887, 0.03207325345776495, 0.06416595022704813, 0.011976991795123586, 0.058955242331590385, 0.036590600070813974, 0.03401292487978935, 0.029508728165960604, 0.049752454093146714, 0.035359423998142445, 0.0529032473212048, 0.049679419100885434, 0.05227569107627196, 0.02469965144090595, 0.03666111463380437, 0.06736679197919947, 0.031957593333396705, 0.027730258880183104, 0.026300863302763433, 0.056236990006460305, 0.043905314824153344, 0.036257589311008497, 0.008853463636290644, 0.07936792703525675, 0.019251718674035325, 0.06250467707192706, 0.03205564109638574, 0.04287815945703657, 0.03887672135005555, 0.0343430666403184, 0.029822770588760896, 0.08698999626381744, 0.07486042656725453, 0.04232418978767049, 0.13314764405931198, 4.087032988186806, 54.19719688354, 41.982689057627034, 36.13108542657668, 35.7215311450343, 49.76258870094053, 72.23543597805885, 70.43680175658196, 64.62376679143598, 63.511680710700254, 31.68834617061, 0.8558421113318013, 7.676765822595166, 78.13912084025722, 71.70240156112179, 67.71737544767319, 60.840829034005445, 58.41811041678152, 59.10965565712222, 60.455507155387636, 57.30280014776415, 55.134306030888716, 56.14827402176396, 53.90572163366503, 53.23774199331961, 51.82172321504163, 50.128632130161414, 48.49065819094258, 48.10459106199203, 47.62978030789284, 47.67257728884297, 48.88313055038453, 46.97883159883561, 49.27335146934756, 48.41012016419442, 48.06111158863191, 48.37331656486758, 46.989614194439305, 48.50504936710481, 48.43441924741192, 47.59426324598251, 48.14303421205091, 45.78384622450798, 47.016572644633634, 46.76826700087517, 46.95157112613801, 47.00589203065442, 45.56671950124925, 48.87093982388897, 48.008418467737016, 44.731321334838874, 45.80925141611407, 45.08707246472759, 45.05672508670438, 44.41622949415638, 44.30409677567021, 43.07166061093731, 43.03092287432763, 43.76597896698983, 44.38337572159306, 44.328372324666674, 46.15132524121193, 45.65170549577283, 46.44714647723783, 50.45540871158723, 56.96748848884337, 60.33896177045761, 59.73841944048482, 60.906007059158824, 44.253031438396825, 47.502954390741166, 57.560237069283765, 56.76831445386333, 60.085145196607044, 52.56463581515897, 47.18434418401411, 45.7789275723119, 43.98536497546781, 41.9396645792069, 42.567416391065045, 41.26563664405577, 42.55359003620763, 40.91593380897276, 39.07999392478697, 42.186177699796616, 41.944092935131444, 40.742365006477606, 41.106827720519036, 40.40781428737026, 40.90693981416764, 45.05956096033896, 43.92006535683909, 44.23613386769449, 44.2140156222928, 43.972558436855195, 42.44189270081059, 42.79844007184429, 43.428015785832564, 43.13528929987262, 44.11976891179239, 44.58620540557369, 44.22349991336946, 44.18736311697191, 43.59295145157845, 42.537033711710286, 43.71114030961068, 43.42763923829602, 45.4093030191237, 49.53331831962832, 54.23243937953826, 57.30751483671127, 57.21014984192387, 58.198343938396825, 59.42973283029372, 56.29570807180097, 59.042555670584406, 59.82952041010703, 60.62552229050667, 64.25071016434701, 61.087161725567235, 58.43707507656467, 52.96570601001863, 51.54623946835918, 59.92557533325688, 64.54367983725764, 65.28008130288893, 66.71773587503742, 55.57511768033428, 8.883794834536891, 0.6611595579212712, 6.366540232012349, 49.60071640629923, 58.62861225681921, 60.38824635167276, 69.08134045139437, 36.13191304668304, 40.12106157118275, 36.46401228443269, 46.009759056952696, 23.85589853409798, 0.24645266093073354, 0.0692402140327519, 0.03128549290610658, 0.12935189289912102, 0.05102797899575484, 0.0231513322045606, 0.017213152961865548, 0.03529228788289813, 0.06232013032140751, 0.05711589969934956, 0.008868701125104583, 0.05236253863380802, 0.05559325398456666, 0.11810451941264254, 0.0283284567206377, 0.05153208783256912, 0.1648658138489531, 0.1706880054646923, 0.20025778892299823, 0.12446707880665218, 0.07481820746174744, 0.1749063766891918, 0.15183425989122162, 0.08391825181822624, 0.18657217973903303, 0.15221391774473653, 0.1711007889600531, 0.07265266842178761, 0.17672381303723783, 0.10188660659496823, 0.16512542572473327, 0.10300468127693861, 0.2015408023350662, 0.1220857251375433, 0.16636112554659768, 0.3406723132056575, 6.555780374234723, 70.27896558084797, 49.5693374449207, 48.62329706068962, 38.36126273678195, 59.6612899534164, 80.03051911630939, 76.60060251912763, 71.60336171427082, 71.78580684046592, 34.83919397477181, 0.9299714142276395, 9.272575263054142, 83.23740974549325, 72.61381918384184, 73.14147210890248, 62.801315938272786, 62.039521048145915, 61.55008769804432, 65.72734917363813, 59.49313402175904, 56.33887375554731, 58.00807368370795, 57.43922802709765, 56.372292349415446, 55.554140844652736, 53.742978572845466, 51.1080793411501, 50.25251234731367, 51.31048540915213, 48.764867167319025, 53.28939960848901, 49.43157595972861, 53.467251639212336, 52.03889308437225, 50.31754916714084, 50.37763987818072, 49.094738498810806, 50.135123652796594, 50.6686052199333, 50.49606015605312, 49.636841435586255, 47.60619117367653, 48.45478811571675, 47.98992841474472, 49.50034295358966, 49.86089898693947, 48.933752659828436, 50.2482722651574, 49.805617101730846, 47.49715712762649, 49.03288272119338, 46.8551435778218, 47.90736252261747, 47.52970495531636, 47.308667628995835, 45.98764473392118, 47.255872526476466, 48.07437312218451, 46.454249889619895, 46.7616460400243, 49.60894553892074, 48.8440009855455, 50.76193801818356, 52.092276542417466, 59.78395031344507, 63.7801787161058, 63.318186267729736, 62.98527509935441, 45.78075147444203, 50.823087769169966, 60.55146401928317, 59.501363154380556, 66.93996952426049, 57.0644808584644, 51.393855387164706, 47.842776775360115, 47.67987289736348, 45.990786552429206, 45.03719168324625, 44.551814063902825, 44.36984746686874, 43.118587847678896, 42.578253899851155, 43.668943451296904, 45.78310489654542, 43.84577566577543, 43.294392401172274, 42.75424672711281, 42.893153544395204, 47.45428954401324, 46.420219406004875, 47.1244692033337, 45.637526127599905, 45.56495443467171, 43.271144513160955, 44.10942169927782, 46.16626554919828, 45.66340984836702, 44.684503924462106, 47.43779989980882, 47.60244138779179, 47.48486834187662, 45.48762098435433, 45.369302688106416, 44.93227612587714, 44.84727444187288, 47.55458062694919, 50.783424761987504, 56.64195529876217, 58.13314630139259, 59.31963189955681, 62.003968684904045, 60.21969033825783, 59.11847706763976, 61.51748495717203, 60.84614776795911, 63.589567215211936, 66.4250329232985, 63.56981023665398, 62.416472588816, 56.711208666524584, 53.71968361639208, 64.07776501870924, 68.55382088691958, 68.972777089765, 72.58720982459285, 59.38156220220751, 11.466449076129544, 0.6940260781876503, 7.975665628910066, 56.0062018517525, 67.91422351714104, 71.34776438436201, 74.89890575408936, 41.108361367256414, 46.38111729775706, 47.76715740080803, 57.9255783942438, 36.28740756742416, 0.5090356401858792, 0.383590336047834, 0.1703523976668235, 0.3078101443186883, 0.15852677335421886, 0.18260782794846644, 0.10958366817043674, 0.13064739354435476, 0.14317248677534444, 0.1467411388312617, 0.0794001333715935, 0.12981385923922062, 0.15708901018144625, 0.23292282806529155, 0.06122724077994786, 0.18589031552114796], [0.014076942217446143, 0.04013377587280927, 0.015959853227550707, 0.047958157430853576, 0.008447971382749178, 0.022461397250393228, 0.02003950029311161, 0.03740829167767398, 0.04417637205352226, 0.06698263718956901, 0.05857363478430818, 0.06380934395917481, 0.0537196327481539, 0.052698540966957814, 0.057327018209522775, 0.05689911979941591, 0.011284491404019778, 0.009462661541728003, 0.02030587289482355, 0.01809172940650775, 0.08810836205919904, 28.289732048588416, 47.24965949212351, 48.67626866986675, 35.99559891608454, 23.681666851043705, 55.87470046935543, 65.41464213402041, 56.66843521979548, 61.050577778970045, 34.20264036424699, 0.2310063825139115, 0.43607483587918744, 57.07506733555948, 72.78860784346058, 65.46301672535559, 64.3909348980073, 54.16713583853937, 52.69273650261664, 49.640120537050315, 48.98066812945951, 48.79376326837848, 48.81804273974512, 46.53572928520941, 49.17950484060472, 46.263505028140166, 48.00129936587427, 48.63513869623984, 49.53084722641976, 46.71668783310921, 45.84100692502914, 45.317813734854425, 47.557510637467914, 48.234570564762244, 46.207242550388465, 43.99679868452011, 45.010907880721554, 44.305371545976215, 43.24775934219361, 47.09842074301935, 47.18430496031239, 47.08956403117026, 44.48179191158664, 42.53417430385467, 46.64577138039374, 46.61251752607284, 45.19329809373425, 43.794235721711196, 44.105805273978945, 43.9447174533721, 42.629703629401426, 41.587294532406716, 41.523234382752456, 42.31441959258049, 41.499939426299065, 42.00938078664964, 42.2539758682251, 44.34266151920442, 43.15564640106694, 44.84489356317828, 44.321614080859774, 44.971754781661495, 45.241743287732525, 46.65956635628977, 49.440213018848056, 54.81331886783723, 60.240322005364206, 59.58787887327133, 63.83066746496386, 44.29782490576468, 39.54106461617255, 62.17491342175392, 61.16943343993157, 61.45813949646489, 55.79420951104934, 52.26617874637727, 45.358429877988755, 45.274259736461026, 43.33631469357399, 42.49950839627174, 39.501331006326986, 38.60588527494861, 40.60866709678404, 39.953223351509344, 40.00537518532046, 39.965127744982325, 39.49061901338639, 40.09388346825877, 39.184721208387806, 39.167376487485825, 39.382542025658395, 40.678344080525065, 41.82335061411704, 40.8181804995383, 41.62857747847035, 39.54979581217612, 41.49479327663299, 40.67348426388156, 41.46985484707741, 43.284645311294064, 42.365371181118874, 42.50958496524442, 41.873329454852694, 41.18581641104914, 42.91126704985096, 42.43822528469948, 40.371810851558564, 42.6637105787954, 43.157293796539314, 42.217909674490656, 47.14574021677817, 49.61290321042461, 54.0297273666628, 52.57408872727425, 56.355324176050004, 55.79654724367204, 60.508121828879084, 58.71124482923939, 56.52700239612211, 49.735234091358805, 47.993497771601525, 47.816712625565074, 60.065301925905295, 59.85662006562757, 66.21852013372606, 61.758153746205, 70.50789079358502, 31.960497863831062, 0.36844560515976726, 0.38016638267905484, 6.0463973591404585, 55.73342846285913, 56.02944973976382, 54.26664244744086, 55.97745872312977, 30.311839388262843, 33.76750438444076, 28.459966836437104, 36.73023923750847, 3.6270840946705114, 0.11910701440947673, 0.05523996104696586, 0.036677558711099054, 0.1245619741178328, 0.049619461229491624, 0.15465583832513902, 0.06826118430903844, 0.06506620695994747, 0.025631172221995173, 0.06050362093974987, 0.029960637686834223, 0.037054703796222326, 0.07730269188722295, 0.026524162610932708, 0.067062241385781, 0.0445356481378117, 0.04379023309616793, 0.015840103151276708, 0.06083437557061834, 0.012937031156804054, 0.03168194915258116, 0.013045686364714659, 0.001885810772599202, 0.017940174232447342, 0.05979608128508253, 0.01874006387116688, 0.011770874881486018, 0.03985515735562771, 0.013893384677958826, 0.006455663974667269, 0.06050455173657787, 0.06629570913050445, 0.05798704509112624, 0.040624424544793945, 0.03191486669463977, 0.015552643979448947, 0.04881093203420601, 38.23059681923159, 55.23825276282526, 47.19906483927081, 48.44260915633171, 32.062338282985074, 68.49533834765035, 72.8239562434535, 63.995069688366314, 65.77668082329535, 39.008116491379276, 0.1816914488952006, 0.4771846460719263, 60.696689774913175, 74.53372524630639, 68.85868318619268, 68.51328711355886, 58.93192914224441, 54.776927117378484, 52.74092674255372, 52.263731187389745, 52.97843017885762, 50.360754074588904, 49.49863280019453, 49.97463987719629, 48.4692616616526, 48.24608272121799, 50.442319762322214, 50.49566399666571, 48.94535503079815, 46.65110188145792, 48.07983306146438, 49.71454751107001, 49.087321296814956, 48.694786179450254, 47.40277313417005, 49.183776301722375, 47.55957380417855, 46.952724302968676, 48.894779989796305, 48.587332848579656, 49.57500919218987, 46.881341088202696, 44.8867727095081, 48.520868286009765, 48.551003856043664, 47.542640932144664, 47.165379524230964, 46.34331349403628, 46.00000019996397, 45.69386313038488, 43.43436218077137, 45.520074675160075, 43.495205986884336, 44.15092037570092, 45.00221198604953, 44.45922259361514, 46.11309782151253, 44.924333326278195, 45.205480975489465, 46.558706529678844, 46.05384257531936, 47.62490872413882, 47.6030493551685, 53.07750140466998, 56.890304088592536, 61.17553664791969, 59.26293796108615, 68.71042543841948, 46.47383820626044, 43.80120185113723, 65.38819359194848, 62.08238470938898, 62.422913120638945, 57.30266286480812, 54.471829475895056, 47.503880070101836, 48.49504340079523, 46.017874440839215, 42.35956215089367, 42.902120082609116, 41.54470151470554, 42.8886349739567, 41.84019719400714, 42.96532907793599, 42.04141478384695, 42.165640169574374, 43.16824897643059, 42.70514257492558, 41.305895851504424, 41.46015874801144, 42.97974771068942, 44.122526338023526, 43.909549482407115, 44.321986706026145, 41.74850786885908, 43.319864273071296, 43.27410982501122, 44.34978846580752, 44.88397605957524, 43.309403311821725, 44.401842240364324, 44.895982434672696, 42.79679659874209, 43.2888069460469, 44.69440006440686, 42.550173651787546, 43.07854044821955, 44.81955112949495, 44.12640163975377, 48.637378369608236, 49.583395219618275, 54.04633860434256, 54.812495170101045, 58.25874451668032, 60.66818983324113, 61.43888458128899, 60.059222252138206, 58.868339677010816, 54.77463253082768, 51.41520484801262, 49.469685708322835, 61.74417049654069, 62.47464526084162, 68.21579102546939, 62.80259463094897, 73.59405871360534, 31.026122608492454, 0.48661227728570666, 0.28720397261842606, 7.979891492474464, 62.77929182975524, 59.358380994489124, 60.274729036515765, 60.552456378936775, 38.08346086932767, 43.419994538830174, 31.907938103522028, 47.77877153888826, 4.162798716175941, 0.22695449751711663, 0.09532657271671681, 0.04422090474456068, 0.012661698199207745, 0.10260121341073707, 0.0544268429850138, 0.049789528918242267, 0.03144664907707803, 0.05563395623598368, 0.03879609825690428, 0.032618158391766974, 0.018136574278375315, 0.04255204731898923, 0.05950288028426229, 0.08127426788691552, 0.034560972689500744, 0.09702859791896998, 0.1112163394329048, 0.15143215566152526, 0.10803497546622831, 0.13250458985567093, 0.11260929412298626, 0.12751656839804304, 0.13983968254779616, 0.15717309599201526, 0.1973737283579765, 0.11358427890245953, 0.17330842453145212, 0.1031766526941811, 0.10007289343423421, 0.1964225229476729, 0.15849090511760405, 0.16242689633321378, 0.11526306099709004, 0.1371797639876604, 0.1286564382814592, 0.1045870818498154, 50.35141883357879, 66.67793166252875, 57.869782678542606, 52.30617907739455, 35.122667589495265, 74.00518586558681, 77.2732105562764, 72.56438947493031, 72.62559413909912, 47.53284285145421, 0.44533717596242506, 0.9514418556805581, 64.03562699594806, 79.32188803149809, 74.07700446344192, 71.2838532847743, 61.60634233105568, 57.20895744139149, 55.72112398762857, 55.125017858320675, 56.6115883088881, 54.03125316865983, 53.50762851776616, 53.16817483594341, 50.90887392720869, 51.53208363440729, 53.30095491101665, 53.669567492700395, 51.796757328894834, 50.128165368110906, 50.25233584065592, 53.77576174274568, 52.64762924563501, 51.20388715497909, 49.98109217612974, 51.13828159147694, 50.25509326688705, 49.90455496695734, 50.28108289164882, 51.71366583916449, 52.476221669104795, 49.74732675860005, 47.716292104413434, 52.17295969686201, 52.491679729953894, 49.28376928452523, 50.56575282927483, 49.551212172354425, 48.38141233690324, 50.02709373351067, 47.12058605686311, 49.05569914848574, 48.338172128123624, 45.8422032479317, 47.22917295271351, 47.19001200891311, 49.23398263992802, 48.33046074836485, 48.307306997237674, 47.926805711561634, 49.41580018689556, 50.3811425547446, 49.3506339288527, 54.858492805111794, 57.814681222361905, 64.69349868835943, 61.717831780833585, 71.34580319927585, 42.86795623840825, 42.65383012833134, 66.39436783329134, 65.31443734322825, 63.442341050794056, 59.5148168840716, 57.77327276045277, 51.2675158439144, 50.473875230358495, 48.27272738179853, 46.04773544496106, 45.31350697240522, 43.247786798784816, 47.36673831939698, 44.0396309668018, 46.89672462401852, 44.31644439697266, 45.73853108190721, 44.98338853159259, 45.04851164356355, 42.977053042381044, 44.894413486603774, 46.435049887626406, 48.15262440712222, 46.513281560713246, 47.093815880437056, 42.1310370199142, 44.97312761122181, 46.248905966358805, 46.94580524198471, 48.21317011310209, 46.870860515102265, 47.072941026379986, 46.11531003828972, 44.47821863235966, 46.404012172452866, 47.24395636589297, 43.81790722570112, 47.25937128067017, 47.37348087372319, 47.31222521874213, 51.608903254232104, 52.50109734073762, 58.441821144473174, 58.406786534094046, 61.819982067231216, 62.518756235799486, 66.86628387820336, 64.09350941258093, 61.49369185970676, 56.63211407199983, 52.49309962795627, 52.50307421530447, 64.56914386441632, 64.08232673521965, 71.65434468177058, 66.260834663145, 76.48410812500985, 35.53146093122421, 1.7161081659217037, 0.6664030926842844, 8.65770451484188, 69.725173980959, 66.99448262491535, 65.18071589931365, 66.47630614619102, 43.56801302202287, 49.82288337522938, 44.614101302239206, 63.27580113564769, 9.629570764880027, 0.4739028479783766, 0.3113679179260808, 0.20824353541097335, 0.2334668271003231, 0.18855522897455002, 0.38758156220278434, 0.15995341293033094, 0.12692982165683664, 0.15221227831657858, 0.2969986212349707, 0.12878624421934928, 0.07147131487727165, 0.12287119508630807, 0.16278691169235016, 0.23986018322888883, 0.1951490243476245], [0.026366411700784683, 0.04295456523616468, 0.08055865749596589, 0.05060123737841364, 0.045445936792079485, 0.0147565474335645, 0.03694659346834787, 0.10191699730292444, 0.03960666141562885, 0.0211533710675975, 0.03703438331403079, 0.04727726997507196, 0.019687163050196344, 0.013452074941127531, 0.044233522212673584, 0.06231647991244832, 0.01594555611166382, 0.15223922928975475, 0.09479473149704357, 0.12070989251256951, 0.3233272858685063, 1.940634195362368, 36.627379002109656, 55.30769832672612, 40.39034012825259, 23.020359162361395, 32.80982044435317, 64.713224287956, 60.866395042788604, 52.950467601899184, 41.576437411769746, 1.8843297972794504, 0.2286532668456916, 27.70295527673537, 73.89401020542269, 62.75709905932027, 69.59726548963978, 62.21467056582051, 57.364216619922274, 50.838012387675626, 54.53321064672163, 47.36265905441777, 55.44288673708516, 53.94147403778569, 56.42869603249335, 51.95253033791819, 52.63616415762132, 47.79095442064347, 49.61978304770685, 47.63651893984887, 48.89687453546832, 45.91975242860856, 46.605076789855964, 46.39439059842018, 46.866973446261504, 45.368930062940045, 46.998490518139256, 44.467200694545625, 46.395386880443944, 44.32736427553239, 44.903289810303725, 45.52274580924742, 44.33429902599704, 45.90779704432334, 43.952573960827245, 43.93615491928593, 45.87652006456929, 45.764285364458644, 44.65001060116676, 45.08256173902943, 43.03113468231694, 41.35450970742011, 42.94351285503757, 43.19201461730465, 43.195693800526286, 41.18619295858568, 44.97981525236561, 44.8304396290933, 46.83009139953121, 44.853765964508064, 43.13346539774249, 44.0773053323069, 46.052658019527314, 49.777274054865686, 53.50866402349165, 55.67512243024765, 57.54893672081732, 55.75101244834162, 63.25090977453417, 43.16375394021311, 23.58588453262083, 58.65048731527021, 62.05913682137767, 61.10324736564391, 54.508358509309836, 49.870873574287664, 46.421054870851584, 44.93996789378505, 43.50271340339415, 46.10717896492251, 45.661629092308786, 43.48865562869657, 41.67725016993862, 42.544584274292, 41.02669369789862, 40.686098606355735, 41.086486308805405, 38.969983208564024, 38.52912056830622, 39.50089954560803, 40.83855721258348, 41.36739469343617, 42.34025232253536, 43.191630225027765, 40.78291446931901, 41.38465312219436, 39.823789058193086, 40.31557583039807, 42.26813170217699, 42.74121661340037, 43.54423953640846, 40.83321102203862, 41.55149505984399, 41.15573967656782, 41.69230030428979, 40.88305650218841, 41.78455052837249, 40.71042122379426, 42.592954943257, 39.46934407757175, 41.72813507818407, 41.509776730691236, 44.7976682263036, 43.690002656752064, 46.99824733118857, 47.312268364814024, 50.20246682628509, 45.993767553760165, 45.06791168643583, 43.98276444404356, 46.9537127402521, 53.26274318079795, 61.23641967773438, 61.92849836041851, 67.08654849759995, 62.28169994969522, 60.55850859611266, 2.901914336027638, 0.12861179067723214, 0.20025956624698257, 12.423136734193372, 62.083628100733605, 47.262544478139574, 59.491537617098906, 46.25951990004509, 29.972024848384244, 19.647540507778047, 35.03050365755635, 21.25274500539226, 0.21571474660548473, 0.04366216617786596, 0.02714486045372342, 0.03400186640060237, 0.0772775718641858, 0.046207458832331245, 0.04939975870412685, 0.037437085092308066, 0.034087813804827394, 0.032019428120205, 0.046189287226767316, 0.005697754517783441, 0.021186567572576386, 0.007105099690717555, 0.048683918486799926, 0.08599425050159616, 0.03497929883099372, 0.0611636784648703, 0.017111663548876683, 0.10220215055010012, 0.0372925894184699, 0.05660049872653139, 0.030715963990998366, 0.04777699295851973, 0.07263690999318516, 0.05415609602125422, 0.05626158908970895, 0.04236935067080683, 0.0426102968143119, 0.024058997007687728, 0.011872275236753688, 0.10330809039934989, 0.06284338369544956, 0.07634493642516675, 0.031081592859399897, 0.10342333300579941, 0.11432726161494372, 0.3843359234592607, 3.0959297187866706, 53.72182915287634, 58.222964655968454, 42.901653320558616, 32.66894851961444, 39.327377811554946, 74.35532800612911, 67.01898174901163, 59.54037504811441, 49.12003386405207, 2.43072368444935, 0.2605923151056613, 30.78789745607684, 77.81401126615464, 65.54003638605919, 72.85204825862762, 65.1524434551116, 61.39939415839411, 54.81323649806362, 57.6763706053457, 50.93360054877497, 57.75637126738026, 56.701081106739665, 59.32815913231143, 54.8691616519805, 55.44529507237097, 48.85609757515692, 51.96988290356052, 49.21299011476579, 51.11923063955, 47.98601388931275, 48.458988974171305, 48.019918857082246, 49.07495798603181, 47.7867849411503, 49.15763370452389, 46.50990047762471, 47.98889290901923, 46.534066200256355, 46.932920255968654, 48.86708021163941, 48.71821841885967, 49.24159988280266, 45.0039731302569, 47.72109308550435, 48.48320176524501, 48.96770469604, 47.78293709601126, 46.15999367929275, 47.67217328471523, 43.57079790484521, 46.38273331426805, 43.66510737326838, 45.06426780454574, 44.93094644238872, 47.282885889853205, 46.81266430885562, 49.59730394424931, 47.15784072875977, 44.25987205197735, 46.90784062108686, 48.437349257930634, 51.353851133777255, 55.27685280769102, 56.664728579982636, 59.40408445173695, 58.65183661060949, 65.67887652304866, 49.83533297815631, 27.25133945865016, 62.15004559486144, 64.34102665993476, 61.85129827068698, 54.60410356521607, 50.630048321139434, 49.18687105178834, 47.385146002615656, 44.352067362877634, 47.748251576577466, 46.26468173919186, 43.10874269854638, 43.588523095653905, 43.79162342317643, 44.08748780527423, 43.79344732530656, 43.79266285127209, 40.12200686239427, 41.19813657576039, 42.1134687239124, 43.950130324209894, 44.238734399118734, 43.09153918297061, 44.30872909484371, 43.27128964085733, 43.38210052059543, 41.75861581679314, 43.4009906553453, 42.81999741831134, 44.974743627732806, 45.43542208210115, 42.43875480467274, 44.3901143535491, 42.55153471423734, 44.184389960381296, 44.11444233309838, 43.24872816762617, 42.4500943768409, 44.14387187650127, 43.0142371116146, 43.48416451484927, 42.87125102935299, 47.71852393304148, 46.30876917992869, 49.12470148455713, 49.73299834036058, 51.94675268665437, 47.627289602833415, 48.25623381522394, 47.413567496884255, 49.402954424581225, 56.167944708178126, 64.81440574892106, 65.1476542411312, 67.70368637577181, 63.90629468425628, 60.03941428276801, 3.264877478922567, 0.15582957695568764, 0.37819462557954175, 14.497921505282003, 68.438856217169, 52.23009294079196, 66.51153687507876, 49.94036228426042, 40.40458225434826, 24.40982153338771, 41.119877446082334, 27.049270714482955, 0.21273490972816947, 0.07689861881156122, 0.03402808575981087, 0.01304964225123366, 0.09183981545990513, 0.02637886254477405, 0.043452576013101686, 0.04611921316433338, 0.10399507208456917, 0.06636708554240965, 0.032663120092042995, 0.037889934986108736, 0.026355357052037315, 0.019251094312377034, 0.05966596508158311, 0.044753006434128176, 0.07166885830942663, 0.09953581983403814, 0.12486267128899214, 0.18108634668732845, 0.11313039478996109, 0.1267361852730955, 0.09718009946687568, 0.1943993460266821, 0.1625825194341521, 0.17042326079981943, 0.14040752223903133, 0.11230222310029692, 0.20693225335449944, 0.08796961587523261, 0.31330584458285765, 0.16362122740716706, 0.1993577275425196, 0.12512109572848967, 0.2640398639825083, 0.23615958018889352, 0.3296290025595696, 0.5400333349262515, 4.149575916028792, 66.18326587061729, 68.16284687288346, 53.679051783777055, 35.899853860178304, 48.37001785155266, 78.52491732566588, 74.3815294388802, 66.57220809690415, 60.42413603874945, 2.8307789660269216, 0.2556415025385157, 35.62122437261766, 80.83682506315171, 70.22727658671718, 75.38904513082197, 68.03238099621188, 64.405769301999, 57.00557862558673, 60.53532738839427, 52.23736893746161, 60.85641261070006, 61.12008217842349, 61.42472090259675, 58.44917558854627, 60.43765252636325, 53.93269577334004, 54.042251494623, 51.16643244220365, 53.79563639240881, 51.341052439904985, 51.22797835257746, 51.98479183258549, 53.49714009992538, 50.79401908382293, 52.62010989650604, 48.065822355208866, 51.39076455946892, 49.571106433868415, 50.58139916389219, 50.63394715709072, 50.96802719177739, 52.15084537383049, 48.33548530455559, 49.02187655048986, 51.083525303871404, 51.44806254294611, 51.21664270277947, 48.114902973175056, 51.601540965418664, 46.536258805182676, 49.54230839206327, 46.386894949020885, 48.272241007897165, 47.69226366473783, 51.26277369837607, 48.41786684528474, 54.336441024657226, 49.47738139860092, 47.03141489336568, 49.68013655754828, 53.29323960888771, 55.22422244471889, 59.33525077758297, 59.278584295703524, 62.30140593744094, 60.68439314442297, 68.12139526490243, 42.56300372462119, 23.094690038311867, 64.9492254564839, 65.0094416833693, 65.03479196179298, 59.39928347064603, 53.27860916814497, 51.94554067427113, 49.18017948827436, 44.57996491462954, 49.73394363157211, 50.00184543671147, 46.25254984824888, 47.29763007933094, 46.36923643850511, 45.57207353653447, 44.82244976105229, 47.03421154329854, 42.243495295124674, 42.88886247142669, 44.96709500589679, 46.42872702690863, 46.506825339409616, 45.67227832732662, 46.104770629636704, 43.85060410345755, 46.34724370894894, 43.75154856712588, 45.04831160268476, 46.522318701590265, 46.43993716086111, 49.245565399046875, 45.6016521300039, 47.21967297215616, 44.23756161043721, 47.0963458091982, 47.10860321598668, 45.449118998742875, 46.689921579053326, 47.8378620455342, 43.717722046759825, 45.82758849666965, 46.7739583599952, 49.82459745099468, 46.991642059818396, 52.35952723410822, 51.2911912702745, 54.02002342285649, 50.80500172030542, 50.93622853679042, 49.11701363901938, 52.325951745433194, 59.66554964742353, 66.7193675810291, 69.27457994030368, 71.6186511132025, 66.67547625880088, 64.81691214346117, 5.152644130491442, 0.17476284245569862, 0.41955307726898505, 17.2350122082618, 73.42280803188201, 59.199713276278594, 71.65108911452755, 59.159171658177534, 46.89004874998524, 36.00747193059614, 56.18406172721617, 40.91234876263527, 0.2339984461544983, 0.17203904748443635, 0.16874739750018045, 0.1414397184646899, 0.13460932449708063, 0.1472395096695231, 0.3135087353087241, 0.28096038667905715, 0.17398907833041685, 0.21410634500845788, 0.1637001804286434, 0.13114081545462533, 0.18616111228062263, 0.2709539607167244, 0.09987250015500093, 0.15465729389219515, 0.1669358293856344], [0.00887819870014585, 0.04945770942515904, 0.023871182892171126, 0.07398845763095925, 0.025828043411996578, 0.01617535854870033, 0.022775836123694337, 0.0322881736792624, 0.01286625229347978, 0.02185724882198678, 0.06810494067688143, 0.03336048609907589, 0.06588172287710252, 0.052875488125268495, 0.05151125024102869, 0.035921544843022866, 0.08299416592044216, 0.03814066024196725, 0.14565772196698576, 0.10292656329129973, 0.12394895056082357, 0.17580591712988194, 12.26748041568264, 38.83373183588828, 36.02291430196455, 31.269148741998983, 32.796660892425045, 64.91333576940721, 55.42486344614337, 60.06234838116554, 54.829428042134936, 6.06432798408693, 0.5586553389026273, 2.742832562615795, 52.72369184801656, 73.34921652270903, 63.80897675791095, 69.06885946950605, 62.71941684907483, 58.07385967623804, 55.05216767711025, 61.18549162341703, 58.99779750454811, 63.428098924698375, 61.31547897092758, 66.0894976892779, 60.557555460160785, 60.97711570801274, 53.537442453445934, 53.03339435208229, 50.75758810966246, 47.266984601174634, 47.755649166722456, 47.55726745051723, 45.70501442878477, 46.61990727147749, 47.45235189314812, 47.00899070309055, 46.18959972935338, 46.025895687841604, 47.016584411744155, 46.03187730235439, 43.515033568105395, 43.96046576961395, 44.15745896677817, 46.93152389218731, 46.93506971482308, 44.987836499367994, 44.03075464310185, 42.890443186606134, 44.534928260311005, 43.03753991280833, 43.34975665615451, 44.03956428650887, 41.722145618930945, 42.93673892174998, 43.3541222541563, 47.723740685370664, 47.01286600482079, 43.91171463074223, 45.324591590512185, 46.42500077524493, 47.441926233230106, 53.64105578391783, 58.34265185940651, 63.79837851370535, 63.168398795589326, 60.90344967380647, 61.66010625900761, 55.31816321034586, 15.708922897615741, 41.511863431622906, 66.28412569722822, 61.417029134688846, 59.27818813631612, 51.3272221626774, 52.01943812831756, 47.41969423909342, 49.880357865364324, 44.739115084371264, 42.543635060710294, 45.276738674409934, 42.908701819758264, 41.82751617124004, 42.13854443642401, 40.35242257579681, 42.12505148303124, 39.84811559800179, 40.215775043733665, 40.8883987703631, 44.21414113813832, 42.560356124754875, 42.36155079257104, 44.72794417412051, 42.762311120187086, 40.89350961869763, 39.60849015943466, 42.62704034005442, 42.69448157279722, 44.70638682765346, 42.74429959635581, 41.74527975820726, 42.64578142473775, 42.74167553071053, 42.41063141053723, 42.18927637223275, 41.3759336933013, 41.181560639412176, 40.99896646315052, 40.912748844392844, 41.223459397592855, 42.567502683208836, 39.8758702893411, 42.040022342435776, 41.38107199822703, 43.69430157446092, 42.468949210259225, 44.6647116445726, 43.35112556334465, 47.895834676681034, 48.00572379942864, 60.8848576391897, 59.68904856712588, 66.93110496767106, 62.591139654959406, 72.60376222672002, 20.284884475892593, 0.3342282573782629, 0.5743474549343509, 0.6617093639027688, 22.791126043565814, 61.77062296098279, 51.07347226911976, 59.20984083606351, 32.72602488917689, 21.170620379909394, 28.257488204586892, 37.30352109478366, 4.211904829548252, 0.12221212198417034, 0.11403842348485224, 0.0574135555014495, 0.045181104027095347, 0.017662741236328598, 0.04408230028686024, 0.02678537561047462, 0.014967964718028184, 0.13451765441606123, 0.07391607764387324, 0.04794357877765452, 0.027483425350979935, 0.03714218720673554, 0.034027840611675096, 0.03815558746517186, 0.030029771376341104, 0.010571152463765636, 0.012267290280320713, 0.06282725754464347, 0.02578565385192633, 0.07573107783232005, 0.041796945095542944, 0.010665957759615156, 0.05389472214324821, 0.0900368198692318, 0.07221648860121928, 0.012253336946389849, 0.0380715667720764, 0.029800686189123703, 0.021658487310032212, 0.04729129321452591, 0.05779699782931036, 0.032209274283940756, 0.03110953208599841, 0.06323832500305387, 0.11700613319032616, 0.10231765362644389, 0.08982144191019958, 0.2677629287204435, 19.332986031809163, 50.90788548992526, 36.82177559021981, 40.53003534193962, 40.09298524548931, 69.63494377751505, 67.37056732177734, 61.14573055698026, 63.239460376001176, 7.522093528701414, 0.5101283267140388, 2.469108489251906, 56.78031690659062, 75.65568001039567, 67.30486762139105, 71.74407282183248, 66.2648747044225, 60.63930549929219, 57.59155719510971, 63.486452025751916, 63.73721307323825, 65.02403682278049, 64.8375948013798, 65.92840594630088, 63.11068504087387, 61.05458251891598, 54.05248495840258, 55.060110476709184, 53.1893007216915, 50.12983629780431, 50.4554989261012, 49.40792406758955, 49.3703281494879, 48.716500420724195, 49.52058238367881, 48.429469216254454, 48.02068371926585, 49.149526165377715, 49.232766705174605, 48.9777224294601, 45.68226468178534, 46.86034464067029, 47.84709138254966, 48.11362820286905, 48.023519592900435, 46.915555923215805, 46.646473484654585, 45.84544312569403, 45.95472035869476, 45.36124221740231, 45.92422785297517, 47.092497964059156, 44.51909365192537, 44.88470954279746, 45.461933382095836, 49.437738003269324, 49.14935358109013, 46.924557762761275, 47.57454156875611, 47.65345573425294, 48.15063968781502, 57.16135555698026, 59.628891175793065, 64.10788882163264, 62.56968429011684, 61.37224351206134, 63.62613939469861, 61.26530793405349, 19.26371305219589, 46.88568315198345, 68.18009745690131, 61.18381677135345, 60.167958198055146, 52.476578604790475, 53.61827858032719, 48.971277975266986, 50.139897177296305, 45.268948847247714, 45.46382396451889, 46.912488629741055, 45.19602021863384, 44.77611872457689, 45.17703594699983, 43.32363759317706, 44.85171456490794, 42.89137671070714, 43.05120545048868, 44.437123960064305, 46.83157797782652, 47.227760899451475, 45.88433734832272, 45.534018701122655, 45.79102416192332, 41.74258508989888, 42.66994714736939, 44.728489383574455, 44.89331522295552, 47.20802353274438, 45.44484361525505, 45.703206216135335, 43.131339473109094, 46.74437584415559, 42.49102430958902, 45.062232094426314, 43.54376492961761, 43.501999532022786, 43.765072899480025, 44.31752697114022, 43.04382354982438, 45.72142170321557, 41.727370216000466, 44.94072883359848, 44.19623944067186, 45.89138976989254, 46.6567853958376, 47.10061334794568, 45.54566029579409, 51.110656338353316, 51.02721183530746, 62.71455703243133, 60.73906706225488, 70.27571785834529, 64.08544109713647, 73.5159250997728, 20.461477425790605, 0.653736656231265, 0.9229210764169694, 1.2086578987298475, 24.5561533974063, 70.29842838164299, 58.149635945597005, 64.57317213858327, 41.87592606390677, 32.40316479436813, 29.4093196622787, 49.150561671103205, 6.423738195050148, 0.2623529077297257, 0.12685846822756913, 0.032247544206198187, 0.03873658088606693, 0.029101902919430888, 0.05503992399861736, 0.015773680455411877, 0.026599252634050868, 0.07497704047108851, 0.055905178174256324, 0.054530146111163406, 0.029295989379827535, 0.050437826993724996, 0.01995657319052806, 0.03290163390638848, 0.0473679632939879, 0.0460806482982251, 0.10813678855136519, 0.1249070660842042, 0.14154511684131238, 0.1737007841227516, 0.11628329859025056, 0.15346899959108523, 0.16308629885315895, 0.2006864764036671, 0.2701212844300655, 0.11059366316804964, 0.1604720850985858, 0.14263616394131415, 0.2437176810757768, 0.2532896892197671, 0.20741761601980657, 0.13238604541026777, 0.20204560831189158, 0.2207443742982803, 0.40534150275972586, 0.30970872469967414, 0.25987835180374885, 0.40201073632605616, 30.665109619017574, 61.62041971760412, 51.35625162432271, 48.70304276866298, 44.98310219857001, 81.34323443135908, 70.89428347925987, 71.93833212698661, 73.26685459383073, 9.828219202256973, 0.8507725091711168, 5.208903176169242, 60.684369610201934, 80.11444999325661, 70.41817049826346, 75.04317052902715, 71.06817783847933, 64.03264991698727, 60.94615251787248, 67.2687739710654, 67.36784519687777, 70.08618893161898, 69.05759442237117, 72.0868879748929, 67.90817522233533, 66.561460802632, 57.81109225365424, 59.76547594993346, 56.34370219322943, 51.914138178671564, 53.65944777765582, 52.732858427109264, 52.20898666689473, 53.30024496201546, 54.41895984834241, 50.71823889209379, 50.24649935383951, 51.891529636998335, 51.690268901086625, 53.466471087548044, 47.98957932379938, 50.23549318313599, 49.332979340707105, 51.730504574314246, 52.51520610624745, 49.06231618696644, 48.37044931227162, 48.2504169402584, 50.10827895133726, 47.38474984322825, 47.9299710642907, 49.57777838553152, 46.70892938490837, 47.13079598642165, 47.33117026667441, 52.16038457808956, 51.661408101358724, 50.026830934709125, 49.89057563966321, 52.627119172003965, 49.82119283368511, 58.85027323999713, 62.959097200824374, 70.2963181464903, 65.24397588545277, 64.41299430785641, 67.4859477627662, 57.747573391083755, 13.97042351384317, 46.813950846272135, 68.47016457588443, 65.29535108996977, 64.3769085022711, 55.179503502384314, 56.61909572539791, 50.70824469289472, 53.994449569332986, 47.66233598032306, 46.457654506929465, 50.310743854891875, 47.48975169274115, 47.76640822810512, 47.603935810827444, 45.13932235779301, 48.10312801791776, 45.100133957401404, 44.08545993989514, 46.70994920115317, 48.912736600445164, 48.0640180649296, 47.81693227829472, 48.77855231685024, 47.975902019008515, 44.25587907914193, 43.3514158187374, 47.27962640024001, 47.433179347745835, 50.67455937785488, 47.736986529442575, 46.32852223611648, 46.803752683824115, 50.331657932650664, 45.70633234516267, 47.63155714158089, 45.48035283242503, 47.26469001462383, 45.81730011970767, 45.74935682358281, 45.980129472671024, 47.53008934759325, 44.692560472796046, 48.357760444764175, 46.02810790461879, 48.78806798688827, 48.69701016333796, 49.93210177267752, 47.7789637350267, 54.56128697241507, 52.38646999482186, 65.73522529294415, 63.83836315524194, 72.39659832369897, 67.00217831519343, 75.12935284645327, 23.802748457078014, 0.47175056992038605, 0.9160925976691708, 1.3653759538165986, 28.20856055905742, 76.8419381110899, 62.084161543077045, 72.88216421681066, 43.59825057368125, 38.1456696602606, 44.99726979963241, 62.97468862225933, 13.752606453434115, 0.5283739057279403, 0.2690412230308979, 0.11314123493408966, 0.17275178504566993, 0.09008192712621343, 0.23652920229060037, 0.15884748840283963, 0.0967918384459711, 0.31257588536508624, 0.19946818209944234, 0.14189281350662633, 0.14182412606333533, 0.12736036307028226, 0.13658097434428432, 0.19895767642846032, 0.2813626134828214, 0.14278205772561414], [0.027815122269995274, 0.043461163858732874, 0.06066943684052076, 0.028027931919261336, 0.0717241392140427, 0.024539556301709627, 0.028477137149762244, 0.02894451973148652, 0.06511053280724634, 0.0284169054019355, 0.08605801966041328, 0.08626608147976861, 0.0944311002029046, 0.05279167044547297, 0.008923387353969438, 0.07019374835034532, 0.09930917272163976, 0.041409009662006176, 0.06313980992643103, 0.10440731931838299, 0.03004754653140422, 0.03186743053036832, 0.055755170497802965, 36.89242139939339, 41.79320327697262, 31.170179497811105, 30.025029797707838, 39.84727228841474, 71.82415977601083, 54.23906034038913, 70.40155533821353, 17.105683818940197, 0.03374464088870633, 0.18200632635383837, 10.220440530007886, 77.77699978120866, 63.793789340603745, 70.49136977041923, 62.918128044374534, 64.0723599926118, 61.0365003924216, 63.21482396894886, 63.40985598102693, 67.67072277684366, 62.90858099537512, 66.16211645064816, 64.45646593647619, 64.69214939302014, 60.66727592099098, 58.35589770347842, 57.63345203092022, 54.3379040687315, 52.42150068283082, 49.92368436628773, 48.01436478091825, 46.7086273624051, 46.23197701669509, 45.94279243100075, 47.332931410881784, 48.16522698248587, 48.20806318713773, 47.280657983595326, 45.243845678144886, 43.860884635679184, 44.817429127231726, 44.708414693032545, 48.321713862880586, 46.3725822202621, 44.491997918775006, 43.851380732751664, 43.500179552262836, 43.2143368259553, 43.38653672126032, 44.58342444512152, 41.11943814062303, 44.63554097760109, 43.72213079083351, 46.27209894118771, 43.959579313955004, 47.02098531107749, 44.49129581451417, 46.918552614027455, 46.795786350004136, 53.86991431636196, 60.89929980616416, 64.08413494786909, 60.38010743356521, 62.80957644985568, 56.52573154818628, 59.606533665810865, 20.752935024999804, 23.10541772073315, 68.88564555875718, 60.7466019353559, 63.48057631523379, 53.94434521275183, 58.919561909091094, 56.316849647029755, 56.07604749741093, 52.319264104289395, 46.436956159530155, 45.50982159952964, 47.628623208692, 43.753309711333245, 43.30952882766724, 38.62632082354638, 43.50782817409885, 41.58497641163488, 41.40839522884738, 41.22368689506285, 44.908016266361365, 42.697254688509055, 42.37714613637617, 43.619737317485196, 43.89693513993294, 39.447457252010224, 41.843574354725504, 40.74114514935402, 43.69223840775029, 43.23265037228985, 42.63324552966703, 40.871207021897845, 41.15848533568844, 41.08275221240136, 41.123442880568966, 42.63754444737589, 42.77450184668265, 43.457708128037, 41.549318144398356, 42.610703668286725, 41.66891513332244, 40.536754362044796, 42.50286202276907, 40.02760325708697, 41.789214226507376, 43.93070282474641, 42.912173117360766, 42.19312421737179, 45.963655517947295, 45.16776738628265, 53.19021071157148, 62.31873104649206, 61.16290269359466, 65.77952061930011, 68.57806897932484, 61.632182905750895, 0.5949058840351721, 0.16280319872162036, 0.375869058433079, 0.8780558419323737, 32.158226505402595, 52.92550171575239, 45.819943797203806, 54.44893067882907, 16.610974880956835, 28.62507312528549, 29.629111636069517, 32.290106396521296, 0.3526283716482501, 0.06446755521239773, 0.10079100893269624, 0.024816485595018156, 0.11781050252818293, 0.010072303778161446, 0.04338678055172486, 0.0909332040276739, 0.11299335698206579, 0.10227178028153797, 0.028142427589984673, 0.028357175441699165, 0.10752306785434486, 0.027164541252498186, 0.012873784852995267, 0.057955865312608025, 0.07640479853557003, 0.06366781687604324, 0.029598159355021296, 0.10618144105519019, 0.10625617293220375, 0.03446277553936647, 0.03471749211331049, 0.0633017034570296, 0.047947627552334345, 0.06014007008484295, 0.05592320422311464, 0.035665560393564166, 0.08611017492629829, 0.030976784370479085, 0.030342817884839834, 0.06597254260052597, 0.045115503918139205, 0.08235695696766339, 0.14164501470663857, 0.031120494804194862, 0.008268906948937765, 0.04332526752184476, 0.07252662397560573, 0.10037307732648428, 0.42972393634338535, 50.171009417503114, 50.592605375474506, 36.09713339036511, 35.904450878020256, 45.48211005426223, 77.41022679113573, 60.73978485599641, 79.57153904822566, 18.697893504173525, 0.10677531241409241, 0.19721271199805124, 11.472767033884603, 82.54234221673782, 67.00844626272878, 75.4300731228244, 66.62906677492204, 67.0314548861596, 61.790140674960234, 66.85421866755333, 65.70001025353709, 70.38667386577976, 64.47727018787016, 68.91426317153439, 67.69380984767791, 66.94306035195628, 63.21912288665772, 62.09617968528502, 58.318144890569876, 57.88127522314749, 54.694788763600016, 52.9332366297322, 49.89570217747843, 50.21699136303317, 47.62154333053097, 49.150420465777, 51.814992427825935, 49.921397624477265, 50.440429179899155, 49.950544757227746, 49.20136028720487, 46.90928405331027, 46.45386941971318, 46.98277750322896, 49.771370887756355, 50.949548905895604, 47.89376366523005, 46.56091090171568, 45.9428983349954, 47.47623912749752, 46.433657446215236, 47.48244431711013, 43.33560866694297, 46.24394416809083, 45.94997036841608, 50.047603807141705, 45.449460244947865, 49.099484566719305, 46.87757561283727, 50.441692183094645, 50.94438314437867, 56.98786127951838, 60.850866379276404, 65.84929958466562, 62.26133108139039, 67.76585594300302, 56.88781730590328, 64.74179483229115, 25.65247743360458, 26.00150562101795, 69.87226286242085, 60.8924082017714, 64.55396821421962, 55.5556901808708, 61.35833086506013, 58.17750830804148, 55.902396325142156, 51.75980467950144, 48.176519486211966, 46.04953189049998, 49.74239241692328, 44.63854943552325, 44.493959103861165, 42.41902528270599, 45.0053616492979, 43.11099021665512, 44.90583935091573, 42.88094712841896, 45.614972499109086, 45.94902899957473, 45.86415283141598, 45.30514447919784, 47.65786840069679, 41.84437059587048, 43.45269533895677, 43.423108900746996, 42.64248271142283, 45.347608058683335, 44.84774512629355, 44.74052713763329, 42.13635575386786, 43.845355972166985, 43.36231608544627, 44.41035378363825, 45.820606677762925, 45.23879758773312, 43.333812221404045, 43.70337009429932, 42.549193059244466, 43.75580826113301, 44.52880544047202, 42.99895947979343, 45.41673983297041, 45.213004081479966, 46.03066528997114, 45.11736885193856, 47.81779127736246, 46.430468559265144, 55.59581995010377, 64.10588056810441, 62.96338435142272, 68.4038608304916, 67.507567867156, 63.56371095103603, 0.30351726338267326, 0.22320817434980025, 2.215628013495476, 2.070255414132149, 38.995098144777366, 59.26475401847594, 54.890326761430316, 60.03599789834792, 27.303359893060502, 33.63514008060579, 34.63034345257667, 42.488631663783906, 0.6167318515719906, 0.009389679218011518, 0.15443554208163293, 0.05928425794287075, 0.07900044231885865, 0.04682128295122136, 0.06790028794878913, 0.04491266681842747, 0.03388991797222726, 0.019847470778791655, 0.02732805122861699, 0.05519302667028481, 0.06535100014579874, 0.035050751851691354, 0.05726143342232513, 0.10098009475416715, 0.03805981115287831, 0.022607302526012066, 0.11864642702764082, 0.23152284834894443, 0.3330482674702522, 0.18764307872662622, 0.16623049223374936, 0.17785927791508938, 0.08377118591940211, 0.11193532061072127, 0.2544765126320624, 0.15707941876063425, 0.25708540973644106, 0.15669528695364154, 0.3167126375821329, 0.1659805943528491, 0.20682746784821635, 0.2024901997778685, 0.36219573729941923, 0.1471499693129332, 0.14575746661472708, 0.1941169966613093, 0.16914242307745642, 0.33571495824763853, 1.1859520332467173, 70.9553155591411, 61.40431673296037, 50.94857615809287, 47.26931448905699, 51.37092521113735, 89.75951902327999, 69.61772457245858, 90.42562377068305, 22.83306206426313, 0.1890738704992879, 0.29700756914192633, 13.636216002125895, 87.23550519635602, 69.84069562727406, 79.08832657721736, 67.5902122066867, 71.31742092870897, 65.40255338914933, 71.25503170874812, 67.87933795682846, 74.22534065861856, 66.05342757317328, 74.95430531040316, 72.14668058579969, 73.04145951424876, 65.08311163994574, 65.11218424766295, 60.09220546291721, 59.878946196648386, 58.938259847702525, 56.00305218850413, 53.64509582519532, 53.41427218529486, 51.00590552053144, 50.2484409270748, 54.367502274051795, 54.358123886969786, 52.53350788547147, 51.13052314327609, 50.263608732531154, 49.36500157079389, 49.630318533989694, 49.11293045167, 52.50727115138885, 51.76108729454779, 51.316572927659564, 48.12092381138956, 48.53346301663307, 50.847998742134344, 47.99267015149517, 50.08437602750717, 44.93560621815343, 50.023143906747144, 48.72348616200109, 51.98085769530266, 48.03032098277923, 53.78905857762983, 49.659497045701556, 51.136508680159054, 51.87429474246118, 59.659979881778845, 62.84573678047427, 68.95990387085946, 64.41661857789563, 68.17547690483832, 59.181529168159734, 64.92007440136325, 15.618479905589936, 22.668534325015163, 73.97167313483455, 63.71563611492034, 68.96213177711734, 56.32439628724129, 62.7466106414795, 60.990993053682395, 58.59982205975441, 54.99904701786657, 51.782883905595355, 48.60354792687201, 52.55581440464143, 48.161226164910104, 48.359458831048784, 43.210316396528675, 47.678170588708696, 45.80826297883065, 47.656738758087165, 46.11634162164504, 50.177073401789514, 47.13553420958981, 47.130937191747854, 47.52820660991054, 49.31806256694179, 43.180082767240464, 45.4235843689211, 44.11382259861116, 46.28593314078547, 48.01570623151718, 48.369602080314394, 47.896438721687566, 45.835456771235314, 46.02282447199668, 46.794291926968484, 47.006868700827326, 48.266177023610766, 48.19185987595589, 46.17067037090179, 47.728125895223315, 45.052426168995524, 46.874159228417184, 47.67350689057381, 44.92965206023186, 47.29015404178251, 47.70688233837005, 48.400408375647764, 47.857862211042836, 50.36488040801018, 47.652588890444854, 59.90981917227469, 68.73797616650982, 65.45467384399907, 69.98140673483573, 67.3501709968813, 66.96390382705196, 1.507795743884579, 0.2215023570123219, 1.047678188450875, 3.4884439985598292, 41.8383183786946, 65.56324897273895, 58.56652113699145, 64.45111582356115, 27.280596417765466, 47.030030296694854, 44.920909097117764, 56.29318598778018, 1.578815158817076, 0.4331952033023681, 0.29678074582930536, 0.15688403569642576, 0.1783141962462856, 0.15702790700860564, 0.22876221987028278, 0.28386281803250313, 0.14221568892319358, 0.10436870848699924, 0.09127452684145781, 0.1838643193965958, 0.2039092550835302, 0.16675225939721833, 0.11650547941005039, 0.24167783408155366, 0.27178078409164186, 0.10814165320968437], [0.028217239906230283, 0.07767889468419938, 0.08980445774091829, 0.060590905167402766, 0.06397426353707429, 0.0028671599472046743, 0.04532856063076085, 0.057514713581411116, 0.11337649287475694, 0.08661322656177706, 0.08764417406411902, 0.07055871263747254, 0.0374151328428378, 0.039637940785577225, 0.03148375646091037, 0.12176427464451521, 0.025873482002005465, 0.057486077214801506, 0.05759661987183556, 0.08141093031172791, 0.02867135576032583, 0.3133614012791265, 0.1461687179342393, 10.271881434225268, 46.96601329311248, 38.815747768648215, 67.06248867896296, 29.460384999552083, 73.0492179624496, 65.28229351966613, 59.52153590417678, 49.40357415906845, 0.4665606306685556, 0.08411685245171671, 0.11684746872032843, 34.87511896318005, 82.058070705783, 65.03771804994153, 70.33551831399241, 62.54923697440856, 69.54822801774549, 69.26080457625851, 69.2337166878485, 65.97631377558555, 67.84010641036495, 61.992527131111395, 68.27860386140885, 64.05238728369436, 63.438171571300884, 60.05160500926357, 60.00084169449345, 53.48887174360214, 53.45013049341018, 49.961900018876605, 48.97378829217727, 46.010974991706114, 47.89858425817182, 47.340113270667295, 47.609835055566606, 48.134126509389574, 46.886671589266875, 48.71765359755486, 47.38874281606367, 45.0101783198695, 46.04478582259148, 47.453818859592566, 45.57951819512152, 47.58993294931228, 47.100111284563624, 44.684401942837624, 44.90016368127639, 45.35266007146528, 41.94106486535842, 43.301487968813994, 43.384116618864, 46.49763522609588, 45.03275548258136, 46.875159432811124, 45.198652129019464, 46.060569440164876, 44.8904989611718, 46.99215981268114, 47.82541636497744, 51.70456201799455, 60.112637089144805, 63.14429975325062, 63.41427649221113, 67.59359328977524, 57.140472858182854, 58.64733765202185, 35.151767653803674, 24.788902921061364, 63.19143487561134, 60.03948488543111, 64.72934130699404, 59.06895322184409, 62.50213323100921, 62.01797939115956, 60.688609692358206, 58.66109340421615, 52.44860818309169, 44.52444768721058, 47.42258110354024, 45.05186134769071, 42.9759116326609, 40.18161119953279, 40.91974635278025, 41.91813861170123, 41.60536489179058, 41.692767066340295, 43.059344368596236, 43.92357980051349, 42.42474409841722, 43.21326994126843, 42.53042844034011, 41.36741038291685, 42.48430136711367, 43.00571772360033, 42.862009925227014, 41.793936760194846, 44.277381512426565, 42.36741081360848, 41.836851412250155, 42.90546586436611, 41.37519236533873, 41.76954354009321, 42.567043765898674, 42.40981947991156, 43.157438924235684, 41.3922978216602, 43.98094838665378, 41.39077594203334, 46.15099183974728, 43.31791093272548, 45.589426102176795, 41.521226129224225, 50.16190951870334, 46.3986385253168, 48.10366930500154, 44.0632789365707, 53.59890207167595, 56.220645673813365, 68.90008772573164, 58.61964964097547, 80.36230456444525, 19.061414849373605, 0.6430478297895001, 0.3524629273001225, 1.3889804097913927, 0.980572440931874, 33.183322260456706, 57.17207147229103, 57.828068271760024, 30.788905505211126, 22.76092379323898, 31.360863562553163, 46.8521821883417, 14.695751147885478, 0.5595850632075341, 0.14625674143673914, 0.08451339488308277, 0.040770050198320425, 0.12196649887388754, 0.08720164337465841, 0.0051605698348383515, 0.03607061023132936, 0.023029139265418056, 0.03448756997503581, 0.10515985514728293, 0.04884554005618538, 0.04610392204936474, 0.07636688484419739, 0.05420195787484127, 0.05697558303513835, 0.03794407441971764, 0.01718444573212295, 0.026747442766903873, 0.0648095292009173, 0.05716368443362656, 0.04633877396343216, 0.04399968153466621, 0.04264641785994173, 0.06839181762188673, 0.06690639611934462, 0.05519605271758572, 0.07686284250549733, 0.08271425271466856, 0.06065609924975903, 0.050646589783531044, 0.11823034935420561, 0.15440549611324264, 0.062497797602367025, 0.01826801198354412, 0.06621769839717496, 0.0747355695573553, 0.07155988996307697, 0.04103802009335449, 0.14367128662284345, 0.1736160394765677, 15.339124779547415, 59.092832611453154, 40.37187360948132, 78.69299873228996, 38.22931420418524, 74.60486919649186, 71.00559250000985, 65.7541036605835, 56.78714183069045, 0.22615166801598766, 0.1489289940124558, 0.021343190418255907, 37.09302317711615, 82.94695823423325, 67.25874839290496, 74.81711649125623, 67.27961540222168, 71.26973275215396, 70.27192884875883, 73.64578693143784, 68.41912669520225, 71.45839091270201, 63.38569025839529, 70.0329545236403, 68.46502627095869, 67.62168530494937, 63.01588135380899, 63.66106810108308, 55.32147761314146, 55.252310537522845, 52.09192352910196, 52.225484155839496, 47.6988846255887, 49.10184191119287, 50.57515867294804, 49.7175245900308, 51.16548715099212, 50.48175919440485, 51.77624333289362, 50.683318030449655, 48.57351826083276, 48.862942111107614, 49.77889007137668, 47.188792151789514, 48.064845685035955, 47.95276395736202, 47.0443900938957, 46.07900065760459, 47.98617470648981, 43.190633943003995, 45.674412096700365, 46.18053120951499, 48.598797936593336, 46.92145909032514, 48.162489168105594, 48.77146851631903, 49.42373906412433, 46.8591953862098, 50.13912054800218, 51.68649950335103, 53.223205689461004, 62.83083177381947, 63.00584793090821, 63.36372890780049, 68.92105671667284, 59.61244075529037, 63.14571572888283, 45.68490051454114, 27.687944366085915, 64.8537471217494, 58.302973162743356, 67.47533382907991, 62.33206318270776, 63.84411727228473, 62.8525617045741, 62.18451146156558, 58.07060803136518, 53.58016883173297, 46.0787300140627, 48.01764780475248, 45.71164323437599, 45.57693727554814, 41.80385643436063, 43.74342533849901, 44.827219363181825, 44.96947588459138, 42.51622553794615, 46.630838917147734, 45.57604689751902, 45.65333720176451, 43.38819196147304, 47.172137768037864, 41.29199104924356, 44.568907753113784, 44.191862075559555, 45.4111151541433, 42.80416673229587, 46.644673116745494, 44.701013180517386, 46.54417022582024, 43.83966069067679, 44.12781369301581, 43.81529884953653, 45.62150716781617, 43.82095098495484, 45.25267493340277, 44.43221707497874, 46.23700941762617, 44.148861131360455, 47.2880438066298, 44.71890311087332, 47.418286108201556, 44.319656818143784, 51.984595714076875, 48.93088932960264, 49.73839552171769, 46.572022976413855, 56.06197011086249, 59.02172004022906, 73.04711557203724, 60.72834330220377, 79.68633113368865, 20.343857311433364, 0.940160322333536, 1.4334119159367777, 2.4873646709226795, 0.6723164947282884, 40.421923052880075, 60.064639045346176, 63.716432356065326, 37.98924946015881, 28.704918853698242, 31.810822179240567, 57.33544603470833, 19.37372769078901, 0.5825577111494157, 0.28520160264545874, 0.12252245654141712, 0.12876595821111433, 0.07458553889826422, 0.023755995827096126, 0.03182433616940773, 0.05757898835825825, 0.05734900493294962, 0.007069124680598297, 0.06237182210409834, 0.0712391749144562, 0.11191950089508489, 0.1219595657781728, 0.03808765461848628, 0.016178030280336257, 0.026036446140478217, 0.025481578233020923, 0.1707621014887287, 0.28627011143872816, 0.22440972197200024, 0.10354724772755178, 0.18220906386211996, 0.2160588120140376, 0.11818453729633363, 0.2687682812252353, 0.21982537522431345, 0.2235977147375384, 0.417447132208655, 0.1310638695835106, 0.23042490645762415, 0.20337893837882629, 0.3834938702564086, 0.4985690711727066, 0.13602473322422276, 0.30046253374988036, 0.13484471267269504, 0.19042852845403457, 0.17671783755142845, 0.4347028030503181, 0.5780043296756283, 23.758156991774037, 75.40476599047261, 55.07778075433547, 85.70840097242787, 41.6930926230646, 87.61901101758404, 80.53164112952449, 74.83736376608573, 61.79719701890023, 0.7326421189692713, 0.30737666112761347, 0.24429626131971038, 40.555542515170195, 88.31918547230383, 70.82015068300309, 75.1932482565603, 68.87674177846601, 73.27905316506663, 75.30900524508569, 75.82433408306491, 68.57285222699566, 72.79125152095672, 67.0579073506017, 74.52762988305862, 71.77350628760554, 71.32455179768225, 66.79667749712544, 64.93538733451598, 55.266768393978, 58.05219250340616, 54.99618368764078, 56.26759644477599, 49.82000043315273, 52.78675963801723, 53.916947457098196, 53.359217797556234, 54.10114196039016, 54.26825846395185, 54.989362685911125, 54.13834564147457, 51.12950724940146, 51.25767461715206, 53.651183343702755, 49.69427670201948, 51.64732679244011, 51.67787028897194, 47.580009352776315, 50.30340902266964, 52.92665489258305, 46.82947558741416, 48.35725445901194, 48.32323182013727, 52.52427854845601, 49.310053087049916, 50.29647034983481, 49.401063842158166, 50.368383084574056, 48.25607692041705, 50.393752974848596, 53.26885815589659, 53.34053162605532, 64.06445641671458, 67.04950563369259, 66.370527667384, 72.53836847120716, 60.29731012159779, 65.52642576156124, 29.91735289173742, 18.72094331249114, 69.34292331818612, 59.066140882430545, 69.69076694980745, 63.77941777629238, 67.27001344003986, 64.92868008152132, 65.16228860424411, 59.4950952068452, 56.32741651227398, 47.353841566270404, 53.559278288195216, 49.6530722033593, 51.12010140572825, 44.868776875157515, 45.89228407029183, 45.340669385848514, 47.02556663943876, 44.702331096895286, 50.21526944252753, 47.307059457225186, 48.00779873324979, 47.93865126948203, 51.34819507598878, 42.56623183527301, 44.74037416519658, 45.53051994692895, 46.70981191819715, 45.385082383309644, 49.284130142581084, 47.604002491120376, 50.41554566352598, 47.65011387486612, 47.65489524410617, 45.63147391042402, 47.0243271704643, 46.66364954363915, 47.93865126948203, 46.690027483047984, 49.21088380198325, 46.77890446878249, 51.84677931570238, 49.12700391584828, 51.37336100301435, 48.809829296604285, 56.06386069328555, 52.50840863873882, 51.71464643170757, 48.01527084842805, 59.09145585952267, 62.47021690491707, 74.88716217779344, 61.618917449828125, 81.78414806242913, 23.540320319514123, 0.8063266618597893, 0.8563526323245418, 5.533562167998284, 4.550556876967031, 43.28823428000174, 69.18869572301065, 72.69968771165418, 41.19470842422978, 35.88500768907609, 46.15971519101051, 65.51877713972523, 29.77252917905008, 0.7674927456725029, 0.41989294451571285, 0.20000597582228724, 0.29860351414930436, 0.2405819912711459, 0.155174387919326, 0.1252275896108439, 0.15683742690711253, 0.26763471624543594, 0.1572647354295177, 0.1897030278679825, 0.1849139364616525, 0.17749953834760576, 0.2869613985380819, 0.19115130176707623, 0.14771439225202607, 0.1317083180671738, 0.19556439722016936], [0.05315195010494321, 0.028988399332569494, 0.04203277377171382, 0.051940845535887833, 0.04396349537156282, 0.039663895844451846, 0.06837168483123665, 0.061968300611742085, 0.1753825003341321, 0.06609538479918434, 0.13409215386115736, 0.011715674416101989, 0.046898849353554754, 0.031020796121728998, 0.06882581409187087, 0.19350856963184573, 0.06558497105875323, 0.006958062520190593, 0.036855819710199876, 0.03186595198067446, 0.05073286277512389, 0.14283007611670803, 0.0133258217359863, 1.080677701580909, 40.30504818885557, 42.753505399150235, 27.72769170422708, 31.83212261046133, 37.92921758467151, 71.6904697110576, 58.67794390647643, 59.90034664830854, 5.406956393872538, 0.0066553754356479455, 0.05901646041761964, 0.6960123909577247, 66.39333232756584, 72.93913272119337, 69.08649444580078, 71.12848035750851, 70.97433120973649, 69.27774137066257, 72.16799474531605, 64.18381806342833, 66.30348651639878, 65.6695452044087, 66.51095636429326, 65.56259393692017, 62.423540699866514, 59.76391484660488, 61.808465988405295, 57.17227935791016, 50.674084771064024, 49.2847930231402, 50.26061596408967, 47.223426680411066, 45.57208138127481, 46.02242831260928, 48.82860568261916, 47.89743500371134, 49.72210591839206, 48.51065835645122, 49.791143555794996, 45.191984099726525, 46.38606732891452, 44.6237228762719, 45.888993201717255, 47.053384088700824, 46.042314729382916, 44.97608900070191, 45.438669804603826, 44.357715575925766, 41.81768278921805, 42.55431175231934, 43.79298448562623, 43.630398319613555, 48.79367305386452, 49.851579435410045, 56.09713023708713, 53.658777052356356, 48.05604780873945, 45.00731106727354, 46.79262099727508, 46.9449854666187, 55.206634536866225, 58.42860275699247, 65.85246885976484, 65.59661265342467, 62.05574004880844, 61.824688911437995, 48.18685100924585, 24.314949204844815, 30.796087364996637, 64.43653245126048, 60.61335509823215, 61.92263049464073, 65.66345376353111, 63.73334561624835, 60.33791841999177, 58.158355374490064, 55.78643929573798, 49.211585906244096, 45.611814991120376, 46.94485210603284, 41.064446510807166, 43.101384332103116, 42.848920975961995, 41.69934488111927, 41.68162753505092, 40.091047594624186, 44.75835431006647, 42.67610526853993, 41.20120386923514, 41.01557770083028, 43.738083070324315, 41.318565107161, 42.449235377773164, 44.87605287182716, 43.820876459921564, 42.071436605145855, 41.578649628546934, 41.474067472642474, 41.620124770749, 41.059598461274184, 41.234512636738444, 41.05682142319218, 43.250214745921475, 43.14230642011089, 42.61377096176148, 42.56920106949345, 43.52850298727713, 44.391408735705966, 45.061106374186856, 43.262801631804436, 45.62332322520595, 49.39530188037504, 56.85006449299475, 54.83640593867148, 56.848162143461174, 47.76700050600114, 52.32432003944151, 59.30061232659125, 66.796144054782, 68.65421002910983, 63.31145548051404, 1.0762180892690536, 0.2957903780043125, 1.2100958151202048, 6.626833129313685, 0.5433492086106732, 43.17593289959816, 56.374112329175404, 52.05766162564678, 22.16413321033601, 31.66298608626089, 31.97320242081919, 48.96715164184571, 2.533744246728959, 0.1373238344827006, 0.10283052650911194, 0.039540241592593735, 0.09712090385296653, 0.002229354882259823, 0.011892869595378157, 0.039521418812294165, 0.05372691441387419, 0.022722079734047575, 0.00844025975018139, 0.0677237046822425, 0.07104675661051466, 0.04257548194859297, 0.06400994408214766, 0.04984793546158941, 0.021071188985520316, 0.04287456267423207, 0.017109382522082137, 0.011024065559820063, 0.019496838081507914, 0.09204047686991193, 0.031059029654810028, 0.048737333967320384, 0.01117685605065837, 0.08598344866186382, 0.015944573603900933, 0.248682773521831, 0.05752112956777696, 0.23987136811258333, 0.01739484986530677, 0.12352189484743342, 0.0368841726242775, 0.12165740537907808, 0.12249259443412866, 0.12302582993382409, 0.05373269837770251, 0.03423985544471972, 0.06747988187858174, 0.0809945845075192, 0.04977307334962872, 0.1296964792474624, 1.4308889738975035, 57.23197390956264, 46.53512916257305, 40.1734056011323, 46.483632364580714, 47.81692443355438, 82.67130190326323, 63.28602283231674, 64.9626438848434, 5.650179626480226, 0.17052590125991454, 0.09493208340098781, 0.7676656363952545, 69.73353647416639, 76.18696505023588, 72.03833687689998, 74.08674763094994, 72.76150426556988, 71.33476564961096, 72.22246077752882, 69.19169241382231, 69.88147258758545, 67.1263527101086, 68.39119157483502, 68.62909117052632, 66.10792498434743, 63.88099931901502, 62.96845989842569, 60.78869288967502, 52.97535111827236, 52.70061262192265, 52.88785088446833, 50.25662691362443, 48.401134014129646, 49.883723258972175, 51.41292202857233, 50.913337584464784, 50.99477383398241, 52.143067313778786, 51.94854913219329, 49.54057862681728, 50.34072645248906, 49.041398186837476, 49.96897597466746, 48.801651154795, 48.88732356409873, 46.87022509113435, 49.04348488776915, 46.0157367490953, 45.83908888601488, 44.37225580215455, 47.744901872450306, 43.9906366409794, 51.29575298678491, 48.930187225341804, 56.145253796731275, 52.35353385248492, 52.001101047761985, 48.901502932271654, 52.882936154642415, 50.93011356169178, 57.54032711828909, 59.02091987671391, 67.53962932094451, 65.37876421405424, 65.4478685317501, 60.599112972136474, 64.157428356909, 29.808958192025464, 36.757276135106245, 69.83926003979099, 61.28312333937615, 66.5971779054211, 65.38723261125627, 66.45954978081488, 62.6538073632025, 59.412646985823116, 59.00685425727599, 50.216257879810954, 45.46624798928538, 46.263826662494296, 43.15801551265102, 45.40735360114805, 46.28291291575278, 45.10285215993082, 44.26982702747468, 42.97028303146363, 45.01378297805787, 46.24882751895536, 43.91710004498882, 43.7099047630064, 47.006123450494584, 44.9445374550358, 45.04259278697353, 45.99939223258726, 47.8026391613868, 46.029653318466686, 44.66437432073778, 42.62129799012215, 44.975084873937796, 44.40312877778084, 43.608915498179776, 43.53853641017791, 44.956049611491544, 45.76874902171474, 44.85568400352232, 45.747897701878706, 47.632776998704486, 45.3824543952942, 46.997066697766705, 47.137373801200624, 48.899557436666186, 52.26923035037134, 60.71345398502966, 57.13306742329752, 58.556436723278416, 49.50763463974, 55.627877481522106, 60.56401560383459, 69.19233568253057, 69.37693811232045, 65.6106782728626, 0.7305587275374321, 0.5554470239627747, 5.0092177621779905, 4.032068814962141, 1.1808285597831973, 47.60442218472881, 62.48028955151958, 58.00254706413516, 30.96234879186077, 35.94719686815816, 35.17482726804672, 56.628356441374756, 2.757739530455682, 0.19754277331934822, 0.09742883289413107, 0.05112033089502685, 0.06556122999397979, 0.032531958178526936, 0.0053854812792832815, 0.03547328381588863, 0.025677261986739697, 0.02986549531229802, 0.061915206888149825, 0.08556546342949714, 0.09840077630454495, 0.021454315302112413, 0.09353579622843573, 0.09375698879481324, 0.0361367121278759, 0.09458621002493367, 0.02258317075639723, 0.17561460965343062, 0.14064321684981548, 0.23529512657513543, 0.10057837356843295, 0.116432425265591, 0.10427337650570179, 0.10585339454513405, 0.11372271865125626, 0.24324808449995136, 0.22147186671293553, 0.18995646507509295, 0.10885136472361703, 0.22079105969638596, 0.15327485758931408, 0.21094070116598762, 0.23175397707569986, 0.18310471257615477, 0.2455006587889887, 0.1362220774735174, 0.14506579647141118, 0.48383186841684006, 0.2708895480440509, 0.29405883543433686, 2.5623238615451323, 75.4348035012522, 63.18635540623819, 48.50504544473464, 47.022726843434, 51.66502060428743, 85.73355120997276, 73.53370912613408, 74.07793014280259, 6.476919651031495, 0.2962841676367868, 0.1372667762541002, 1.286221665720786, 77.71047638308617, 76.95835405780424, 74.65556975333922, 76.16907904225012, 74.06375469699984, 73.85139757587065, 73.9375328248547, 67.88508030676073, 70.39911562396635, 69.80344880011775, 74.8415607021701, 72.60819450501474, 68.05035329634144, 65.46089080072218, 67.37066930340183, 61.847689690128455, 56.55728701622256, 55.920972670278246, 56.00359739795808, 53.92539624244937, 51.12687533901584, 50.82629234560075, 54.76049630872665, 56.35246476819439, 55.30302678385089, 55.14960327456075, 54.07577599248579, 51.31846743245279, 52.04309786519697, 50.3745255162639, 50.4885958856152, 51.931800611557506, 51.94810198199365, 49.56482279685236, 51.39531450886881, 49.93322749291697, 46.38875415248256, 48.38116130521221, 50.20695794013239, 49.09820587404313, 53.09479121238955, 53.53319060417914, 59.60479605582453, 57.84261242035897, 54.809102319901996, 50.44521839387956, 51.959241513283025, 51.373784618992964, 58.03252573936217, 61.54859719737884, 70.40863129400438, 67.30992747891334, 64.91517143864786, 66.11943321843302, 50.97136120642386, 18.701435404439128, 35.864658432622115, 70.77367059646114, 62.86522311549034, 65.35296678543091, 68.72531475559359, 66.54381013685658, 67.58029645489108, 60.0672709557318, 60.23399914464643, 53.32386547519315, 48.31846221800774, 51.776039369644664, 46.2143067390688, 49.439448156664454, 49.49853866331039, 48.007955628056685, 45.430170028440415, 42.940806419618674, 48.63649975868964, 47.44516218862226, 46.081040290094194, 45.239389865629136, 49.659818680055686, 47.17736628747756, 47.02522539323377, 46.22796835437898, 48.44580981039232, 46.85142124852827, 46.854010012842, 47.497753327892674, 48.912807203108265, 46.02988473830685, 45.93242952900548, 45.84221893741239, 47.28447837214316, 47.86029800291985, 50.313473824531805, 49.210267989866196, 49.109608204134055, 50.755289600741484, 52.04157990794028, 49.71795212837958, 52.086514580634336, 55.23632687907065, 65.1485171625691, 59.08931424540859, 62.57374786561536, 48.71627684562437, 58.051455097813765, 62.78724639646469, 73.35670824973815, 68.50912940117621, 70.2383533600838, 1.8842033008413932, 0.8298665825878421, 9.14779878431751, 15.324790477752687, 2.330885390120168, 53.375868258937714, 69.16358470916748, 63.59979283425116, 30.82089831752162, 47.03854576233895, 45.336088057487245, 70.62086289928806, 5.944056837789475, 0.41432075803318336, 0.21330388322953256, 0.17143216795257984, 0.23171700567247408, 0.07944042193553141, 0.1222184345486664, 0.10958034334884537, 0.2325352335408811, 0.14927281427287287, 0.12127417755583603, 0.19393767079999372, 0.20521834612854067, 0.17153617204918017, 0.23957582671315442, 0.16556643189922457, 0.11687895493401636, 0.19136494836739956, 0.1551214512437582], [0.10105736238221008, 0.02314308335283591, 0.009920636563742114, 0.019013823475688696, 0.06790627875635702, 0.030704261997954983, 0.03082487105031408, 0.052941318060601913, 0.027700965593178428, 0.090189125809458, 0.14172980531809792, 0.04228159912952012, 0.11766090853920869, 0.0051362915509079975, 0.01213003222214719, 0.09612041600649396, 0.09912927229438098, 0.033631642919874964, 0.028573154779751937, 0.006153440373318811, 0.08910057615608939, 0.07794111125892209, 0.1316047429798111, 0.034117545677168716, 12.17373969093446, 52.519724676685954, 36.11142258490286, 32.16276468769197, 19.474422777852705, 58.56963942127844, 63.248893676265595, 72.266556063006, 19.904379267846387, 1.392289296753945, 1.1234745599569813, 0.44610476541903715, 9.93035379917391, 78.42897615125104, 68.24383597220144, 76.12628598367014, 71.96410994375907, 72.75802120085686, 72.08043175358927, 67.14030850318171, 64.96414615261939, 64.34302706872263, 59.52542297301754, 61.85980589159074, 61.97522163391114, 59.092491365248165, 54.07168103802589, 51.40078621525919, 49.49003888714699, 47.521820991270005, 49.97463203245594, 50.11243666371992, 48.565477401979514, 48.46320944447672, 49.6321032124181, 48.359541200822406, 49.30990403698337, 49.145548882022986, 49.24580466362738, 47.7180257920296, 45.286579901172274, 46.909099701912176, 44.73835022218766, 44.25855805796962, 44.83724494134226, 43.74071105833977, 43.31887975815804, 45.30375988252702, 45.2668817581669, 43.69716098231655, 46.26883160683417, 46.93497950030912, 50.53503282608525, 62.654623216198345, 63.69076828802786, 64.06255014481084, 59.12867523008778, 57.2277848182186, 49.66296442093388, 48.90338959232454, 44.2856655582305, 51.99212274243755, 58.72605962138022, 61.05248797324396, 62.55187672953453, 63.121134235012924, 58.969089677256925, 35.390039874661355, 10.984849679854609, 40.19473545012936, 68.52789402008057, 62.496779195724, 63.559372809625444, 59.74846855286629, 62.36803523955807, 57.3069578601468, 54.95294740123134, 45.18097792902301, 42.56864801529915, 45.469766355329945, 43.936256900910415, 43.44445443922474, 40.760604027778875, 41.714300878586315, 42.224597315634455, 41.93325542634533, 42.91933536529542, 42.021944138311575, 42.945568177007864, 40.17353503934799, 42.72730788876934, 45.58665298646497, 43.94181097707441, 42.19566591324345, 42.825139645607244, 43.45599012990152, 42.32281738711942, 41.43132540487474, 41.83420773475401, 44.78351631472188, 42.788108548810406, 42.48641552463655, 43.282895934197214, 44.78125310713246, 43.15571308135987, 43.210920441535215, 46.283407134394494, 50.698097521258944, 47.084668913195216, 51.88026851223361, 52.5304719709581, 59.97970011926467, 56.29928135102796, 63.58549971734325, 56.003413046559984, 62.174517262366514, 46.25832749951271, 61.52561603053924, 57.08728551864625, 77.99617398169734, 38.50831239454208, 0.2332932775419566, 0.5314836711172135, 2.4445919596379806, 2.771087601300209, 2.610065725541884, 54.69621258397257, 55.3011832698699, 37.25212627841581, 27.205210424238636, 31.86260727144057, 41.73747424156436, 30.428061177653653, 0.3104427595052027, 0.1381155557089275, 0.0813398756567509, 0.08301838962060791, 0.045275114506723425, 0.03499512237706973, 0.10172395080688501, 0.056007121494340326, 0.013782783606720549, 0.07249953510660319, 0.07923508738918651, 0.027432811837042534, 0.012248469415240952, 0.0882709872037653, 0.041527006354543476, 0.1151447540389434, 0.03533469851038629, 0.031466697598056446, 0.0512826151304668, 0.029109948757855646, 0.018911250048286973, 0.040535102523262465, 0.05607765903996845, 0.01781067281450716, 0.06620157224636886, 0.019642469480693824, 0.02358860753086065, 0.023753213012711178, 0.11206360203364205, 0.09797014296054841, 0.0708056534189851, 0.11905554096184431, 0.030109680092502988, 0.08481744751935044, 0.16171175325589796, 0.13825199596824186, 0.036994473963615396, 0.022013132392819372, 0.05487050748460236, 0.06528280299877928, 0.06835462405316292, 0.033179999614555034, 0.07130393232669562, 20.00487039166112, 63.73982929414319, 32.10145215834341, 40.86189923747894, 29.380572611285796, 64.85737923652896, 72.53821942114061, 77.92297470954158, 22.445875098628385, 0.5574462682970109, 1.211468031810176, 0.4820163932538802, 11.019897037936795, 82.12379394039031, 71.23927162539574, 78.07616679899155, 72.62657473164221, 74.20382253585323, 74.60792864522627, 70.21035548179381, 65.70665867097917, 66.95827130348452, 63.08921006418044, 63.38099125892886, 65.06564140319824, 61.42896882949337, 56.83396316343739, 55.56293872094924, 50.825194081952496, 48.26116031216037, 52.305002366342855, 52.90266175423899, 50.83807514559839, 50.276654535724276, 50.66559283964096, 49.99224739689981, 52.1608905638418, 51.311917074265025, 51.6981214861716, 50.68215700887865, 48.01252126693726, 49.42606502963651, 47.1666072260949, 47.93609388412968, 48.30796595542662, 48.43008502837151, 46.240119857172814, 47.05809877764794, 49.446186788620494, 46.93810170696628, 48.62827454843829, 47.16404984074254, 51.89991566442674, 64.28325406966671, 64.74621142110517, 64.16985050324472, 60.71706648795836, 57.47696907289567, 51.59641834997362, 50.69256305694581, 48.98633987672868, 54.756942641350534, 60.67334382764755, 64.26109267819312, 68.00692481379356, 63.51710534864857, 61.55597909804314, 40.01479671847436, 11.663406971962223, 45.0405845334453, 67.64090491879371, 65.26876918731197, 65.47720001589867, 62.58686034910141, 62.777499306586485, 60.22382451641945, 57.0317094556747, 49.132001015447806, 43.78028777337844, 46.707250610474624, 45.757687937828806, 45.08320893010786, 42.71903561007592, 45.04016091746669, 45.18414720412224, 46.02707632126347, 45.11973011878229, 45.16525314700219, 45.252439591192434, 44.38282658976894, 44.710466092632664, 45.78368932970109, 44.76062144002607, 44.73475733110982, 46.20628549206642, 47.14988223968014, 44.4346175655242, 45.07027295327956, 43.21116755085607, 45.84510187948904, 44.76789743669572, 44.57207310584284, 44.33727218258766, 46.91433606609222, 44.023937563742365, 45.87699859373031, 48.81201405679026, 52.15010012349775, 49.152679750996256, 54.01574019462832, 54.82410930818128, 62.7717883356156, 59.23658355589836, 67.42649247569423, 58.34074166513259, 64.06695104414418, 48.23060112614786, 63.64329584183232, 61.450463418037664, 78.28176959868401, 40.16753773535452, 0.28297556564211845, 2.539954584452414, 6.02318085009052, 2.751621858727548, 3.616893776962834, 60.733571821643466, 60.507725669491684, 43.05506898510841, 33.422218138171786, 34.415801571261504, 46.479070648070305, 35.52983706997287, 0.30324668112781744, 0.10371966347579034, 0.03248523064558545, 0.07403322780925421, 0.019470178221742955, 0.09852509705289718, 0.0934885745687831, 0.06990091890216836, 0.03410083346910054, 0.06370235978054904, 0.06614173311860332, 0.047642314701431224, 0.02789175596028086, 0.04787886733069055, 0.005743672391549955, 0.09304336257158749, 0.06079175809939062, 0.019791423786251296, 0.07432025797184437, 0.19003534148777687, 0.13683036660715459, 0.12097037006770411, 0.1540539843300658, 0.14275028039851498, 0.10300733960203587, 0.16311711090947353, 0.12342808738110528, 0.10474674223411469, 0.1526910526257369, 0.24357998443226664, 0.1210638787597418, 0.23951432517459317, 0.06320018531574358, 0.2012645969948461, 0.2829425319308235, 0.3415994634551387, 0.13151318015110108, 0.23680750671173298, 0.15043771224877528, 0.15163343760275072, 0.14346176157555274, 0.21821107475026963, 0.14173191972076893, 30.65988306076296, 78.39758934513216, 53.09246524687737, 51.19495591809673, 29.66431098599588, 73.92432228211435, 75.26850285068636, 89.43356221722019, 24.1940950962805, 1.758375626898581, 1.1528944200085056, 0.44150358005877466, 13.331734172759518, 84.18190863824661, 74.9333284747216, 79.64530314168623, 74.87701892852783, 78.73015926730248, 77.85729854337632, 71.88106552247079, 68.33563512371433, 72.07683101777108, 67.6641018159928, 67.76460862928822, 70.06521209593743, 65.92518175801924, 58.42902637297108, 56.746219742682676, 55.41630483442738, 51.39052921725858, 56.43401084407684, 56.22976910683417, 54.829608471162864, 52.600949118214274, 53.9143547704143, 53.192183663768155, 54.226340093920314, 54.74590901405581, 53.490856462909335, 54.52872737761467, 50.45225904833887, 52.52773023420765, 49.673048834646906, 49.44524934214931, 51.38555565188008, 50.35543141826507, 49.21208012488581, 49.52005678607572, 53.28364941381639, 49.43093269102035, 51.692928268063454, 51.483905161580736, 56.285329480325025, 67.61992808311217, 67.5599628879178, 67.4835943406628, 65.33476698783137, 62.65310133657148, 53.201828772021884, 54.07166142617503, 49.570914237729966, 57.44086757782967, 62.970377937439956, 63.11176761504143, 70.1328416024485, 67.18295251169513, 65.27147562273088, 41.13997959321545, 14.759687742879315, 45.03248483903947, 70.37306324128183, 68.51976686908354, 66.75743026118126, 65.18961183486446, 65.75923804313906, 62.46397641397292, 59.26771148558586, 50.517017379883804, 46.043224719262895, 50.362232808143865, 49.204615854447894, 48.557330639131614, 42.47014945553195, 47.59815031482328, 48.244156837463386, 47.7189318595394, 45.95670900037212, 46.560189185603974, 49.32275764403805, 47.430398387293664, 47.583449271417436, 47.87441461317001, 49.02901918657365, 45.75568360667075, 47.70488977432252, 48.89970648673273, 46.79308775932559, 47.31641038771599, 46.92765251282723, 50.75145744508313, 49.136174417311146, 46.22265354279549, 48.01010900928129, 49.9392169521701, 47.88879009985155, 50.52538379546135, 50.466348201997825, 55.10018141038957, 51.13315897603189, 58.61973985548943, 57.95503539423789, 65.92110249304002, 62.51061731769193, 71.53903484344482, 61.750971886419485, 66.99713414715183, 51.45419712989561, 65.52282502574306, 61.06808723941926, 79.97075788436398, 42.802193780099195, 0.2562987293687559, 2.3379238382462533, 11.539581667992378, 10.639918408086224, 3.215458311380879, 67.46326077368953, 66.79011144945699, 49.08514830373949, 40.1392456793016, 46.21734265358218, 53.1733052961288, 49.265357678936375, 0.3721899671419975, 0.3121382652992203, 0.16440203954135219, 0.19549285992980006, 0.13947206759645095, 0.23107936004957846, 0.20008805448249464, 0.19125041822271963, 0.12649898146910052, 0.16754572730391257, 0.19390388632253294, 0.1670361562601982, 0.11500115085753704, 0.1997127939736651, 0.1004168592513569, 0.26427486911416054, 0.15111859587411727, 0.1159726269543171, 0.22023178486814424], [0.056046969557721774, 0.08724370926258065, 0.004982205892672702, 0.04791361707893591, 0.022067750631380948, 0.03400222263148716, 0.03450084627876359, 0.05974243980862441, 0.007171010544087979, 0.01886281988493377, 0.08798681454913271, 0.023618720531944307, 0.06190260091135579, 0.05654145249976747, 0.0793421481766047, 0.017967058172930154, 0.17878517178037476, 0.1051018086652602, 0.04059571923027116, 0.03917245044102592, 0.0030186009262838675, 0.04754825059564845, 0.06676131438824438, 0.0715871167279059, 1.55864093813204, 41.59297020204606, 49.94443370449928, 35.41937920355028, 22.857984804338027, 56.89217505916473, 55.678942818795484, 61.58018796674667, 41.79019089668028, 0.24947369801661662, 0.5507596690327891, 0.14074020358102937, 0.06927812772412455, 29.030959990716752, 83.65436553955078, 64.64934064495948, 79.61662277098625, 65.62662270761305, 68.6991290123232, 61.90880021741314, 64.1998331008419, 59.14728687655542, 59.14740847003076, 54.20787749751922, 56.10420227050782, 53.124063860985544, 54.256361915219216, 51.20418133274202, 50.46145308402277, 48.36905294849027, 51.20623273234214, 50.847300560243674, 49.886829776148645, 49.33803527585922, 50.796847112717174, 50.455585218244984, 47.86442433634112, 50.22835446942238, 47.51453322748984, 48.52391596763365, 46.39622626766082, 46.828769560783144, 43.7064609219951, 47.69797071333855, 44.860343779287035, 47.97951059956705, 46.76737270047588, 45.482600350533765, 43.338805398633404, 45.971464956960375, 46.619785678002145, 48.04490043270973, 55.592976231728834, 64.37582200573337, 61.83308278360675, 65.65490691892563, 63.498681975949204, 63.3667177538718, 54.18839508487333, 56.99910279243224, 49.839792713042236, 48.401514484036355, 48.240505110832956, 55.61151727553337, 59.769555214912664, 67.88528427000969, 59.27949820795367, 70.68147920793103, 44.293588745978575, 40.64494902087797, 62.22738296754899, 54.21117228846396, 64.72558759873914, 61.41825291418261, 62.424568360851666, 60.759957605792636, 49.02138233184815, 42.82333927769815, 42.098049886765025, 45.11868676831646, 45.10900243636101, 41.850654232886534, 41.09653149881671, 43.17547005991782, 42.36551238644508, 43.47394281818021, 41.96638768719089, 41.73857642758278, 43.131759166717536, 46.34793012372909, 44.83951991604221, 46.25344807101835, 43.95994017201085, 43.25327027228571, 40.41592574888661, 44.42370553170481, 42.024317172265825, 43.075979140497026, 40.74133734549246, 41.96750556269, 43.19228133847637, 43.38783894815753, 41.49511883335729, 44.37653118564237, 43.9361313850649, 46.11158378662602, 47.38858199888661, 57.046033951544, 55.54404074145902, 56.70305013656617, 55.80860853195191, 61.6286684620765, 56.90324006542083, 62.601694753093106, 59.510168875417406, 62.79826433427873, 53.29666776041831, 64.44654233994024, 57.57020773426179, 80.38528965365502, 27.539906271042366, 0.3404466849901984, 1.3359103736377533, 1.220215775312916, 0.778552787678857, 7.672225188824439, 69.07671205459103, 42.93188302747665, 21.198012252007764, 32.87825011437939, 31.559239395203132, 55.09953029694096, 7.508058307632324, 0.5867999383518773, 0.15948298897954727, 0.11760391159764222, 0.06830516541677137, 0.06419681207907778, 0.0043125258244183515, 0.06827338808967222, 0.07806196162897734, 0.029702607782617695, 0.037167782204285744, 0.11127067804937402, 0.09683036500768316, 0.07396501534047627, 0.1347736350350803, 0.03854729588173571, 0.11113561674832337, 0.03580699171570521, 0.08695733027472612, 0.04375913758732138, 0.016098382034068628, 0.03708186161313807, 0.0549776487112526, 0.04655256229002149, 0.08449969723099664, 0.09658300287781224, 0.05860513248931497, 0.0572512099789756, 0.020642196984901544, 0.06342670602363444, 0.11323146476981141, 0.03081206589065973, 0.027541339682835727, 0.04324310076152606, 0.0520159183220277, 0.11379728964980572, 0.03237675259550733, 0.10966010076264221, 0.03667986846619076, 0.023238313827483405, 0.0626128371955166, 0.03352939316462125, 0.09045377854377994, 0.08035876983476263, 2.5673734228457175, 59.13058934673187, 53.182001190800825, 36.5660095983936, 31.348810119013635, 60.451761291873076, 66.69158151072841, 69.85574183925506, 46.27027111668741, 1.5723644533464987, 1.8350566154526127, 0.2176635210672694, 0.2661599357041621, 32.38477083944505, 85.52840340522029, 69.57071888831355, 82.3864358471286, 67.26338463444864, 71.72898738614975, 66.29330404343145, 68.76867263547837, 62.6771140867664, 62.33071780973866, 57.01638083304129, 59.664953447157345, 56.43362645179995, 54.456908779759566, 52.30408453172254, 52.57988991275911, 50.51249488707512, 52.03144842578519, 52.06005427145189, 52.07173508982505, 51.69504242558634, 55.3315463373738, 53.48740085478752, 50.426022314256244, 54.492712174692464, 52.15263005225889, 51.093327306932025, 48.50552005152549, 48.14366963601882, 47.969516400367986, 49.90715942075176, 48.02376277985112, 51.496656787010934, 48.5864346258102, 48.41888273915937, 46.51681953860868, 47.03613350468297, 48.99926016407628, 51.426501274108894, 58.047442513127486, 67.12389730638074, 64.69939401072841, 69.83667127547726, 65.17877824844854, 65.86058816602154, 55.02028665234966, 58.2972425799216, 51.7488024311681, 50.14922457356607, 49.961456791047134, 59.41540048968408, 61.7027541898912, 71.9302285102106, 61.03076980959985, 70.94434076739897, 45.70326112931775, 41.330391053230535, 65.63538528257801, 57.92998321594731, 65.12967409626131, 63.23959373658704, 65.42848025598835, 61.88788613965435, 52.268132086723085, 45.66816376101586, 43.111833526242165, 45.731588486702215, 46.44450672211186, 44.26235098992625, 44.28218249351748, 45.541043666101274, 45.716055900819846, 45.46479278995145, 44.2885131989756, 44.514892793470814, 43.702162004286244, 47.91265379997992, 46.939180358763664, 49.548129189398985, 47.40567568809756, 44.228602916963645, 43.51794788914342, 46.647473689048525, 43.90713330238096, 45.006554049830285, 43.33593422366727, 45.23823668879848, 47.016333380053126, 46.0342974047507, 44.391091023722005, 45.9888175226027, 45.62212690230339, 48.28834233745452, 49.78913922463694, 59.001892459008005, 58.33153193996799, 59.053271585895175, 58.589204203697946, 65.64071186127202, 60.74611163908436, 66.08184122270154, 63.026554123047866, 66.43500358827653, 55.15816580864691, 65.88456953725508, 60.14831889060236, 82.04468757875505, 28.604225727819628, 0.4817341051755413, 2.8098820486376366, 4.35218692787232, 2.327107902496092, 10.115249426134172, 76.53669926428026, 49.20510222834926, 28.940923944596324, 40.117311785298014, 32.33710619711107, 62.721554540818744, 7.922419944117147, 0.6245619443155105, 0.17012729039115293, 0.10701830784279494, 0.18295535607443703, 0.07709057746274818, 0.03764275288690002, 0.03787000520875858, 0.029201220473154422, 0.05471055981733146, 0.024880938487307682, 0.08486031779959317, 0.021009405909646905, 0.03242080648159308, 0.148635980703177, 0.04948911903005454, 0.12908805221799882, 0.10122429294091079, 0.07581422901562146, 0.01852559564154475, 0.16625992533180023, 0.14747221653740253, 0.14748586822421322, 0.11702931501091489, 0.20949927609293692, 0.2869096416379175, 0.11042376784908195, 0.23075999331570443, 0.202662676813141, 0.2052584738140145, 0.28134670949751334, 0.10792752397396874, 0.21888343947789363, 0.13137228126006742, 0.22230465025190385, 0.13912887552813177, 0.2848223891229399, 0.34135811511547337, 0.1732391395395802, 0.07389684117609456, 0.2859021134434208, 0.14701173640787601, 0.19642601630860762, 0.1493113331737057, 2.7841532614923294, 78.27328158963111, 67.02506926751906, 55.24937660463395, 40.76845269049368, 69.8286461061047, 69.80102477535125, 77.62798893836238, 51.6521591524924, 6.32642517166753, 3.1599540768131136, 0.377308537642802, 1.0146785527467728, 34.04577301394555, 87.54219532012941, 70.8032609570411, 84.73947355824133, 70.1917242234753, 73.89775214656707, 70.8713689927132, 71.61164576007475, 62.72116230380151, 63.14953219506049, 60.669641110204886, 64.62073087692261, 59.630491502823375, 59.24296525216872, 55.446922855992476, 55.920953058427386, 50.514040300923014, 56.604932046705684, 56.94713531001922, 53.9038271288718, 52.781417369842536, 59.156245570028986, 55.11788306697723, 53.9870245225968, 57.46399387236565, 54.28551297033987, 52.12302400219826, 51.36284512858237, 50.42295894315166, 49.276406995711795, 52.66682532525832, 49.916831985596694, 54.05451674615183, 52.760009073442035, 50.19730890950849, 48.421102800676906, 50.07684507677632, 50.85474129646055, 54.29531889577066, 61.08980932543355, 70.33041138802805, 66.27312737126505, 71.43108337156235, 67.2106836688134, 68.79848264878797, 57.15752732369208, 62.81586793161208, 55.12710063688217, 54.14174633641397, 51.88381825723956, 61.12686395645142, 65.28332118065127, 73.5101435261388, 63.28712894070534, 75.95188956106864, 37.43921941326511, 37.14887772836993, 68.80835133214151, 57.35334773217478, 67.95080354136806, 64.72492864055019, 65.43339106344408, 62.853248119354255, 52.84545398527577, 47.77857149800947, 45.40443143536968, 48.73821858436831, 50.04834905747445, 47.70397586207236, 46.85073875611829, 50.103674088754964, 48.7240941293778, 48.397090050481985, 45.885176735539595, 46.41093907817718, 48.04024850168536, 49.599543617617705, 48.5198994605772, 52.03689267558437, 49.41464308769473, 48.03980135148572, 44.09787424149052, 48.45659632836619, 45.75806840773552, 47.03322702838529, 45.76325378110332, 48.1476822207051, 51.758110215587, 48.598401777205936, 45.37321329116822, 48.22876937927739, 48.89601553640058, 51.43824092803463, 54.3072154445033, 63.291502383447465, 59.86799493912728, 62.33811539988365, 60.34948941200011, 66.88220870110297, 62.558317261357466, 67.96120566706504, 66.66795315281038, 68.16648683240338, 57.08521842956544, 67.38534681258663, 62.22543747194352, 83.25478584535661, 29.221773493674498, 0.7663146250190274, 4.313905085286787, 7.347416656632578, 8.231342877111128, 10.20873421622861, 85.66592170346169, 51.98921626613986, 31.717654120537546, 50.21430846183531, 43.5242276037893, 70.85466754051947, 14.387242024944676, 0.9365473903955953, 0.3814955452276815, 0.3082002362897319, 0.33308222048705627, 0.1766377047545487, 0.11455447563240606, 0.13375657670680555, 0.1520203732915463, 0.1096639465240221, 0.20892379084421744, 0.2252084145983381, 0.17208504340341016, 0.13620021332415844, 0.4141666517863351, 0.12932042200719157, 0.33374577520355103, 0.20847817282042197, 0.2930462510595399, 0.3154818407229839], [0.01808110951265741, 0.04383005434647203, 0.10558306509929319, 0.035536283056341836, 0.02424597225692724, 0.018583406551530766, 0.06966026770251413, 0.02939932889515354, 0.011148031992507319, 0.057812771579671296, 0.012115615405022137, 0.0680085591551277, 0.048365049710076664, 0.04098908622719107, 0.02923429631928523, 0.018924800228447686, 0.037078383573961836, 0.07064022439261598, 0.03275334992776475, 0.03627622823020624, 0.02583861351013184, 0.023998658007551587, 0.12337819973547613, 0.12395953789593712, 0.09609119741306191, 18.251372844942157, 56.708121761198974, 33.33674576974685, 37.69169453651675, 25.176429171716016, 57.112824070838194, 69.49080451842278, 65.11907977442588, 1.6494265246775843, 0.5048651494566472, 0.29147635304158737, 0.2651396904501223, 3.416766851179062, 65.11849141890004, 75.886182015942, 70.10261581790063, 71.09110801450669, 67.45340777981666, 59.69895647418115, 58.881750260629964, 57.12142190625591, 52.77855403961674, 51.88039402807913, 52.79854636038504, 52.43768045979162, 57.691326602812744, 57.23362914977535, 63.50826824865034, 61.68908472984069, 60.87240411389259, 58.02682653550179, 53.74330805193994, 47.99058737293367, 49.62023412027667, 50.09029096172702, 49.8362272785556, 48.56654036429621, 47.856987522494414, 48.49678101078157, 50.28417371934461, 49.89721228999477, 48.56917227468183, 47.04499806127241, 45.95537539451353, 46.455622719180205, 46.94241239178566, 44.033723877322295, 45.010225388311575, 47.43818036971554, 48.69686503564158, 47.64775260802239, 59.10972233741515, 62.45255839440131, 66.045363180099, 64.59193283511748, 66.47854189718923, 66.36131009747906, 62.41972031131868, 62.41342098482194, 62.927698627594985, 59.94943118864491, 57.550376230670565, 56.5529880985137, 59.80049879320207, 62.66388785454535, 62.82572877022528, 62.136329066368845, 58.90270748446065, 53.032421604279556, 59.99736647452078, 62.45444113208402, 60.40754049055038, 61.7649394466031, 59.287048770535385, 53.12756261517925, 45.02199642119869, 45.042494727719216, 42.69825097053282, 45.27779771435646, 43.680122206288004, 44.786822872777144, 44.36960427991806, 45.03861942598897, 44.33472656434582, 43.43459752298171, 41.678415113879794, 45.07881979788504, 41.968458698641875, 45.61275243759156, 44.00923652033652, 45.34005749610163, 44.67709064483643, 44.83380502270114, 41.4796176264363, 43.58969196196526, 42.74174613337363, 44.641400998638524, 42.482461775502856, 42.332176162350564, 43.37270644403274, 44.896198165032175, 43.61372824638121, 44.07395170580956, 42.01421314670194, 47.14445367936165, 52.1643461719636, 61.01084416912448, 58.97024285408759, 58.33150448337678, 60.25370513239215, 64.51659194884762, 59.45503996264551, 65.46281668447679, 60.8039273754243, 68.48106876496347, 58.98291210974417, 65.46305987142748, 59.814838978552054, 80.69500784720145, 21.30636968920308, 0.7098284495934364, 2.2128946117816435, 3.7390949745332045, 0.8618206002058522, 22.180685612463183, 69.16485555710332, 18.6434196272204, 21.394681853632775, 29.499634196681363, 42.04241498824089, 37.556749313108384, 0.5103781326643883, 0.14846549549650762, 0.0616387066040789, 0.02383191514039232, 0.046517326075944214, 0.01758123331162478, 0.0655310231471254, 0.04143647774453125, 0.05735822480111834, 0.027631822327572494, 0.034901556228437734, 0.020214133865890965, 0.05487284405277141, 0.026178191558668212, 0.014471897889199037, 0.03782421613352434, 0.023680172274790467, 0.046390078871721224, 0.03946283223828481, 0.05509808156338911, 0.04732422733439073, 0.04849143123494522, 0.059081309760409984, 0.05088349481323554, 0.0481873709377983, 0.03945909755965395, 0.041813427477233836, 0.017312499243886243, 0.06355101911110744, 0.06854639118236881, 0.027793173850964636, 0.0431385527424995, 0.05057481117546559, 0.04000367116062872, 0.0334884534259477, 0.03800496691837907, 0.058116759098465406, 0.07451193317049935, 0.028629906573182637, 0.006689908285249746, 0.02209563814704457, 0.020305248533165263, 0.07069638629834499, 0.10415079477693766, 0.09359155976844412, 25.405911361017537, 70.64896275920253, 34.419637649290024, 45.49202580605784, 33.35538487280569, 65.24251676374867, 73.20642655895603, 70.11054685038906, 1.8940165807162563, 1.5249447140001482, 1.2442684846539653, 0.4846039624704469, 4.363128379467995, 68.48273184991652, 77.17635154724121, 73.91563815455284, 74.18810952094294, 70.20535053745394, 62.81452648101315, 63.53739576954996, 59.152738971094934, 55.64687352026663, 54.594348630597516, 53.42911443402691, 52.97202494836623, 60.09926965159755, 58.91989531055574, 63.43374713774651, 61.720361709594734, 62.04810319408294, 59.235316630332704, 55.03116730720767, 50.64484742379958, 52.066208470252256, 53.13240281997189, 51.87463598866617, 51.127542141945135, 49.89023831582839, 51.248060887859715, 54.106590132559504, 50.239466544120546, 51.1185638366207, 48.94214260962702, 49.277764135791415, 48.87639584079866, 49.097146834096606, 47.80716165419548, 47.43583871472267, 49.932090005567, 51.76424480253651, 49.9220448155557, 60.37698130453787, 64.43255909027593, 67.8722620010376, 66.58275142792733, 67.11631928720783, 65.26582348731257, 64.6739339059399, 65.15084705045147, 64.35621799961214, 60.84401792095554, 56.930276963018606, 56.485856733014515, 63.78421091264295, 64.81172677009337, 67.11786470105572, 62.933546881521906, 64.9058714989693, 59.076072323706846, 57.025253234371064, 62.8589512455848, 62.541992356700284, 64.04888068476032, 60.97777466620169, 55.83989727881647, 48.365299240235366, 47.15635415046446, 46.075454834968816, 46.618824697309925, 46.08186791020055, 45.14550009081441, 45.21912297894878, 47.04370760148572, 44.9045685029799, 45.542451796993134, 44.45545711824971, 44.91465291669292, 44.3963195431617, 48.2791639912513, 45.62931268445907, 46.57645525470857, 44.825473908455145, 47.604257445181574, 44.696345560012325, 45.37267592645461, 45.58420542747744, 46.220100079813314, 44.98294530376312, 44.21703192495531, 44.93422162148261, 46.15598893934681, 46.55264254539244, 45.92720493193596, 44.851820468902595, 49.195527722758634, 55.42677364041729, 61.74973633981521, 61.52374505996705, 60.925097234787486, 63.05084928389519, 67.16064207015499, 62.31718563264417, 66.70156002044678, 63.373064148810606, 70.21093599257931, 61.767179119971495, 67.67809683276762, 63.276648367604906, 81.21287838105233, 24.398327027597738, 1.2920760483511033, 8.441583879532354, 1.4781031565320109, 1.1662727666478003, 26.476596824584473, 74.8618785796627, 24.946656727021743, 28.51768255233765, 30.589545157647905, 46.39627725847306, 44.62506040450066, 0.4696189455928341, 0.07026216766286282, 0.02353938446650582, 0.02460148493428865, 0.13278716904742102, 0.029844535146689707, 0.05422600920522406, 0.053891864635290644, 0.005042926021551173, 0.0672979130139274, 0.02611460626095293, 0.052479217655115554, 0.0024817913870191985, 0.04406967898830772, 0.04259654936651069, 0.02984422105064075, 0.03399980945452567, 0.07688166528579689, 0.03598331068191798, 0.065445474108621, 0.11684487168226512, 0.12204818682925356, 0.29183240006527594, 0.18989942216825104, 0.1290300440403723, 0.12834276358086255, 0.20527640027144264, 0.10864278196447319, 0.12617443598085834, 0.14153238446001085, 0.18318124475979036, 0.21911141192240102, 0.1449976606114257, 0.1784434659226287, 0.09226667199043498, 0.16870609003930323, 0.22129264810392935, 0.21278505784369287, 0.11889898323363836, 0.07922348115713367, 0.13960005024508124, 0.15663280482253722, 0.21281890360818756, 0.3032520437432874, 0.14326846227049828, 33.46195567038752, 82.73726832482123, 49.64237589989939, 58.06105313762542, 37.32711415137015, 73.33768475440242, 82.13450201096074, 76.57301256733557, 3.8993620391814945, 6.643296297519438, 0.9661589562892915, 0.6967171918480628, 5.420444934598861, 69.01327163942399, 80.57186111327141, 77.54091232053696, 75.3013801574707, 73.5161525972428, 65.02018897764145, 65.48958293853268, 62.691281687828806, 58.11719009953161, 57.66660782598681, 57.947159274931884, 58.06279466998193, 64.19109798246815, 63.40567473442324, 67.68580821252638, 65.75080102489841, 66.24851842080393, 64.12509625957858, 58.28952335542249, 53.75822874807543, 54.32072800974692, 55.33855169050155, 54.86072071136967, 53.94413340476252, 53.76044488722279, 52.94757289271201, 55.965244462413175, 53.63110473079067, 54.035559931109034, 51.45456975506198, 51.51829258088143, 50.822056185814645, 51.642259090177475, 50.55479764938355, 50.294520931859175, 53.90987934604768, 54.42947964514456, 51.704405123187655, 64.19431824837962, 64.99676458297238, 67.91608272060272, 67.16046164112707, 70.07906590738605, 69.07297011344664, 67.6319383805798, 67.71412772517051, 69.06445857017272, 65.85133921715521, 61.63600329429873, 61.229582986524036, 66.23184050283125, 65.98468411353328, 68.45209813887074, 63.61359565488754, 64.71891564707603, 59.17219000477945, 60.970345697095325, 66.54417099491243, 63.094285611183416, 64.94134149243756, 64.05501527170982, 57.530372142791755, 49.99635019610005, 50.665114310479936, 48.65002409104378, 49.61417798073062, 48.251879984332675, 47.55680853320707, 48.09719347184705, 49.662462357551824, 48.721171963599424, 47.21435816057267, 46.8692405762211, 50.21808570431125, 48.752068473446755, 50.0571116324394, 48.18009668780912, 48.58363797587734, 46.62334719011861, 48.65371504137593, 47.02020083704303, 47.29946182620141, 47.76932254914315, 50.799039717643495, 47.74462730653825, 47.075561169655096, 47.900792552578835, 49.985932380922385, 48.57087458333662, 48.53438085125339, 46.37474736859722, 51.61605765742641, 58.18023827768142, 65.67006295727145, 64.07130095266527, 64.73092202217349, 65.9123791417768, 71.54949188232422, 65.01885929415303, 69.80498636922529, 66.38231831212198, 75.62325769855131, 64.32126183663645, 71.35163968609226, 63.80523089439639, 84.25421361000308, 26.26560272709016, 1.3135296971567216, 5.667075726293749, 9.780614376068115, 3.762580901384354, 26.733972949366418, 85.04009969772832, 25.34005084345418, 35.92481582395492, 44.051052908743586, 53.114399140880955, 60.95899828018681, 0.8740366382464286, 0.2835039211617362, 0.143188375438894, 0.142925929037794, 0.18189378803776157, 0.12001920296179673, 0.15536569539577733, 0.10631773575779893, 0.12995903290087177, 0.12174370518374829, 0.1706373976964143, 0.18125039675543386, 0.15748690092755904, 0.11480466462671758, 0.14631634307724817, 0.09132409273015876, 0.07290218325872576, 0.18180927321795495, 0.14416933570417667, 0.12686922410202603], [0.05796773584499475, 0.024592586823048133, 0.020123702932089087, 0.026529647800470554, 0.07565578671112176, 0.061492211440758365, 0.020697788155126958, 0.02049764385446906, 0.03299913008607203, 0.09615235421205721, 0.016215989936984355, 0.1055605344534401, 0.08475587703287603, 0.0274132976623913, 0.04475820817113404, 0.07482299551127419, 0.007527661819626848, 0.04150971575009246, 0.013829813744392128, 0.025804216162331646, 0.10256751320294796, 0.08095297827235154, 0.016272994539430066, 0.019485607232537963, 0.05827252009523012, 0.2680346141419103, 41.078049290564756, 49.59455828512869, 35.45437459022769, 26.157525739362164, 39.470293291153446, 66.7879698353429, 75.19022018678727, 10.057467029940698, 1.6095856625226237, 0.7621931945604663, 0.31601041074722047, 0.05739475953422728, 24.667956636798, 83.04761409759521, 64.29251870801373, 73.58297409549837, 62.70038158662858, 65.79314693327873, 58.89702004771079, 56.65955105135518, 51.68928438617338, 58.272166867409986, 58.09505616464923, 64.67374170980146, 64.3925509145183, 67.92624165934902, 68.39974234181066, 70.44151644552909, 69.09079336350965, 66.28596136646887, 57.83754471809634, 50.853078211507494, 51.01286380521713, 49.988662350562315, 47.792072296142585, 48.33735627512778, 50.9277169935165, 50.053734471721036, 50.38315080827283, 48.911308857702444, 49.13069094381025, 49.964971234721524, 47.40283196972263, 46.826788763846125, 46.51279518681188, 45.43149578955866, 44.77213359648182, 45.4272674745129, 46.44033332024851, 48.831488624695815, 56.99128943104898, 62.26073488112419, 63.36536845853252, 62.01178989102764, 64.76001424174156, 63.33964947731265, 59.85905585750457, 61.6478096285174, 62.41266788974885, 64.52741376815304, 63.253137680792044, 60.256333120407604, 61.04097581678822, 62.071755086222005, 64.05413666079122, 64.08850054587087, 58.6725781040807, 58.48213526510424, 63.14042837389054, 63.5538108887211, 62.90459978965021, 61.28079345149379, 52.53386874352732, 48.26479242693994, 45.2023313122411, 45.67352956341159, 48.115993392082956, 44.887090421492054, 46.05894557891354, 44.82965907742901, 45.69159207805511, 44.349761009216316, 43.79125472038023, 44.875837141467684, 43.836511027428415, 44.904341005509906, 45.69633814596361, 45.3401751672068, 44.456700509594334, 45.1576437488679, 44.53639522675545, 45.010209698830884, 44.34365780122819, 43.57858773200743, 43.02396851201212, 44.700354222328436, 45.001223548766106, 44.2035311268222, 44.11538370193974, 45.404655010469504, 44.13159485786192, 44.93526104957827, 43.854393113044004, 46.18298269087269, 54.2080500818068, 59.923496477065555, 62.13116722722208, 61.8752404182188, 60.014923003412065, 63.628841907747336, 62.235482661954826, 61.64291843291252, 64.75602911364648, 64.53707848825763, 62.126734948927364, 67.08920786457678, 64.40154490932342, 74.64585796479257, 5.4644833457085396, 0.5748655142322664, 2.1894121170043945, 1.520916072110976, 1.9249140711561328, 38.32864430642898, 53.69749476832729, 14.86158601699337, 35.60908463693435, 24.935436787143832, 54.311165271266816, 12.800557978691595, 0.7184427099362497, 0.058613241529993476, 0.06317984568135393, 0.04603674379928459, 0.02197818729215332, 0.052497186247379556, 0.0734043538930916, 0.030563060502191226, 0.051481598807919415, 0.02468872702710571, 0.04752210784523238, 0.038940019364799225, 0.010758598857078581, 0.06990602104774407, 0.057229476064563765, 0.02797646230206855, 0.055491525169101455, 0.044833867014535976, 0.03978573829836903, 0.03167145374801851, 0.0421789548389854, 0.043769970070570714, 0.04098583801439212, 0.030068554577507803, 0.08014699248897453, 0.022187170332237598, 0.00960641027983999, 0.022924370996113268, 0.03243824264274971, 0.0428351589418467, 0.02242314073467447, 0.03248595842911351, 0.041970395062479286, 0.04934211441826436, 0.021320542943994367, 0.08826887280109429, 0.0849196513093287, 0.007588361359892354, 0.039083886846539476, 0.01062108128662071, 0.06460715941483937, 0.030578085401606177, 0.025801109675798687, 0.05534029558240887, 0.020222336752340198, 0.3618266667810179, 55.8852320332681, 50.830701089674434, 40.05197686533774, 39.07077635488203, 45.0953172868298, 75.84058054031865, 79.91252637678578, 11.764154030430703, 3.251703218106301, 3.637136639125886, 0.4187134755474906, 0.29090282897795405, 25.926323590740083, 88.38049996283748, 67.29342214522823, 77.59198942492085, 65.82638509811895, 68.17899919325306, 59.51364017301991, 59.026905413596864, 55.36476489036314, 59.845927684537834, 60.96770201959918, 66.87040236688429, 66.38282037550404, 69.60813829975744, 68.10247375119117, 74.14581068100469, 70.50265835177514, 69.09623761330882, 59.633790216138294, 52.86348119858773, 53.620431961551795, 52.96571777712915, 51.74482514781337, 52.21170094705398, 53.1714774716285, 52.17155941071049, 51.29723172033987, 52.79392580832205, 51.13949752623036, 50.89627919658538, 51.96346198358844, 48.13044340379777, 49.59671951109364, 48.73564943190544, 47.04369191200503, 48.38873932438512, 48.79179816092215, 53.745281004136615, 58.18865176170104, 66.09494193907707, 64.13529049965643, 65.15826033007714, 68.2797727277202, 64.78630196663642, 63.18470408839565, 63.504157604709754, 65.63305147232549, 66.77217837302916, 64.06595868449058, 61.61874878791071, 61.471102929884395, 64.10964604346984, 65.01314440081197, 65.60127635155955, 58.67608862538492, 57.45165409580354, 63.42252915905368, 66.24767903358706, 65.22239108239451, 64.35862633489793, 54.551983110366336, 51.31576099703389, 48.41136747790922, 47.28901263206236, 48.703980215134166, 48.16590947489585, 48.194491786341516, 46.90294158074164, 48.41722357657648, 46.70830572805097, 46.46360866485104, 45.619020385126916, 46.301391201634566, 46.40543207045525, 46.72341077558456, 47.92435423020394, 47.58104878087198, 47.042828990567116, 46.82120330872075, 47.13982528255832, 46.358920604951926, 44.3579234615449, 45.936649999310895, 46.58863029172344, 46.377536173789736, 46.888366053181315, 45.71251792292441, 47.19892363394461, 45.845258774295935, 47.43242233030258, 46.738272636167466, 48.44081663316297, 55.73593877976941, 61.94629415389031, 65.79228008947065, 65.02605684341924, 62.47446483181369, 65.79226439998996, 65.74523910399407, 63.03514803609541, 66.01660436199558, 65.86439286508869, 65.17978237521264, 69.65271995913598, 67.11395017562374, 76.87092442666331, 5.721984986336001, 0.3187882455606615, 8.262201143849282, 0.8681400288497249, 1.7691563838912596, 44.5518885889361, 63.46176462788736, 20.00580195457705, 42.552491772559385, 25.060136779662102, 63.034951917586795, 15.588213916747803, 0.6509512218256152, 0.11683804583885979, 0.128519055733998, 0.10273349381262258, 0.022679872119859345, 0.0419150069055538, 0.05134720783380251, 0.07578673412001903, 0.11924668755983153, 0.04932372064720239, 0.060193205943271044, 0.018543217579023014, 0.07996994190879407, 0.052649545813760454, 0.004482779768295586, 0.06973142960980054, 0.02691355744196523, 0.04438764378128033, 0.03294535071378754, 0.032893260565376094, 0.21410585471218635, 0.1521994693264846, 0.19692599593151003, 0.1901314395569986, 0.2198564937157977, 0.22851451300084594, 0.08536421213178866, 0.12514148132815478, 0.07350961437388774, 0.25356678322197934, 0.141555642889392, 0.13943013194347584, 0.19917098595009697, 0.09382548471612316, 0.14763465782086696, 0.20613475582532345, 0.11771602090448142, 0.10240701778281121, 0.15083851412900035, 0.3059405527047573, 0.10434823861766247, 0.15560684455258234, 0.20694584375427616, 0.16781670792448908, 0.21176272883049904, 0.8716897125686369, 69.51787671735211, 61.03300948296825, 53.78644627909507, 43.129021352337254, 54.18162899632608, 80.13357547021683, 91.31458974653675, 12.270723235222603, 7.072233951860859, 5.2472683691209365, 0.6079287658776007, 0.5839609390785617, 27.046468180994836, 90.13634897047474, 68.9270265640751, 81.91653590048514, 66.32305129881829, 70.47980662315123, 63.245418456292924, 61.52732618393437, 57.630247454489435, 64.36774976791875, 64.19871130297261, 71.57405376434326, 68.90721074996456, 74.9095118430353, 71.42966347355997, 77.13207583273612, 73.01326551745015, 71.77022718614148, 60.63938394669564, 56.84784835384738, 56.091501635889855, 57.446723676496944, 53.864466144192605, 54.51500300438174, 55.01504244342927, 57.15741749732726, 54.87335074332453, 55.645124143169774, 52.34232371853244, 54.15387430498677, 53.150590850460915, 50.36371938643917, 51.14279623954527, 53.08892726898194, 49.68532977565643, 50.351767924524125, 51.691904529448486, 55.862764696921076, 61.14644050598145, 68.77190466850035, 67.3017297252532, 66.15004339525777, 73.01950993076449, 67.83217537787654, 64.54818271821546, 65.93104962379702, 67.56476386900871, 70.46043795924034, 67.36596245919505, 65.5739962670111, 63.9162378926431, 65.60975651587209, 66.52306079864502, 66.37990997683617, 62.65034391034035, 60.12624771364274, 63.778621535147394, 67.96196660687848, 65.74501945126441, 66.68153239834693, 55.32086964576475, 53.653521076325454, 49.51044305678337, 51.29524307866251, 51.85258834592758, 50.46992540359498, 50.462763155660326, 48.77979570819486, 50.17739895851382, 49.92725372314454, 48.944821588454715, 48.99542800841793, 47.72624707991078, 49.13969278335572, 49.38071066333402, 50.52834910731162, 48.836662230953095, 49.830582987877634, 49.02341411959741, 49.49416522056826, 48.34235337472732, 48.3059851584896, 50.34496261227516, 50.03889614535917, 49.068050692158366, 49.07234568749705, 48.473537045140425, 50.29581531401604, 48.11732307557137, 49.365978240966804, 48.03106623311197, 51.46731745812201, 59.45642455931633, 65.70621936551987, 70.72746507583126, 65.56382556115427, 65.9207808586859, 68.98564246393019, 68.70068227091144, 64.67529496838971, 70.15224164532077, 68.7837423816804, 67.05603245765933, 72.17641999644619, 69.88663442673223, 77.65378244461553, 7.836034644034601, 0.7047802978946317, 9.017208372392963, 13.561711561295295, 4.0667357031376135, 50.603517409293886, 67.66395276592624, 22.919697415444162, 56.33812066047423, 37.64515953679239, 73.78048896789551, 25.01823606029634, 0.8748656066675341, 0.1757977506326091, 0.1606501852192225, 0.21109725889419356, 0.1232422267897956, 0.2246977557097712, 0.20899079289407502, 0.2409448411556021, 0.2179418408101605, 0.12252648616389883, 0.12424128205184976, 0.19263939691647408, 0.2161415188663429, 0.20006773783074272, 0.1612682802782905, 0.13519044815292283, 0.17709752604846032, 0.12629915509493123, 0.15237425994728843, 0.14918217074967202], [0.041506283676191684, 0.05908317135406598, 0.07341147084990818, 0.019372101730456757, 0.03220224542723548, 0.018430550943218896, 0.019937003474502314, 0.020515026389470985, 0.0722853982100083, 0.04851911765252871, 0.037760079252503576, 0.031490097753703594, 0.056539119762038036, 0.016556759252242984, 0.09287365111372164, 0.027922880197424563, 0.047082871333846164, 0.06746591609572211, 0.04406105666871994, 0.03601711431157685, 0.06644679699093103, 0.01390361195174797, 0.09650773473925169, 0.08859063739017134, 0.07659447424474262, 0.21011597687198272, 6.672072275992363, 54.95196680868826, 35.195906085352746, 34.53792848894673, 23.448119125058575, 50.681729470529866, 82.06319332122803, 34.69077933219172, 0.8814609495382156, 0.9713505809345554, 0.39710296257849664, 0.0658243045871777, 3.114054746204807, 64.28148115834883, 77.17454725696196, 71.85731949344759, 72.6684421108615, 65.00213430773827, 60.18286320470995, 57.54710105157668, 60.50805907095633, 69.04664316485005, 70.81149008966261, 72.0565523639802, 72.18657893519249, 70.72267193948069, 70.73922434160787, 68.61866551060831, 69.39721676611131, 67.24563983178908, 62.120086531485285, 53.19403894485966, 50.69248460954236, 49.930485756166526, 50.542312745125066, 49.670393390040246, 46.5719602184911, 47.25506451822097, 50.55140087681432, 48.406468437563994, 49.95089384817308, 48.087536596482806, 49.08076701625701, 46.69893518570931, 47.06173089242751, 46.10113851485714, 47.40424402298466, 45.92906021302747, 47.30420004936957, 47.50016558554865, 53.0052827250573, 60.01896304468955, 61.42689781804239, 63.518791967822665, 64.52077319545131, 64.9491430867103, 65.97773367358793, 62.26188021321451, 63.81975543114447, 64.35065607870779, 64.90024289777203, 62.18468404585316, 62.240138515349365, 64.06018103322675, 64.16054664119598, 58.313100722528276, 61.619772526525686, 63.785999513441524, 62.569107701701505, 63.25904477027155, 61.3329452853049, 54.72708555959887, 46.866400780216345, 44.7971583181812, 46.690278514739006, 46.93886264677971, 46.81934802762924, 48.551745184006236, 45.4061572782455, 45.74899204315678, 44.65372116334977, 44.40308955407912, 46.36112889935894, 46.3279378029608, 45.744155760734316, 44.602408716755534, 45.17204669214065, 45.89447275284798, 44.19205034932783, 45.199362078020656, 44.84700772070116, 47.14022928668607, 47.91655655830137, 46.51806685232347, 45.37082849010345, 42.874879221762384, 44.69983254709552, 43.43238922857469, 44.21896957582043, 45.82723940572431, 46.027641142568285, 45.86006572169643, 45.9585682038338, 43.145044234491166, 50.18784423028269, 58.84539381150277, 61.41659767396989, 62.825528729346495, 64.31544888404109, 59.11892814020957, 63.46515747808642, 60.100693471970104, 62.74366494148009, 65.01569786379414, 66.31468880561091, 64.38003855366861, 72.58873954896005, 42.0140915532266, 0.17271032436720787, 0.42019294454686107, 13.378004412497244, 0.9594942364961871, 1.0544462381832063, 72.40482745632049, 24.550966062853416, 21.399149433259044, 27.9547655582428, 28.324082205372473, 43.99778712180353, 0.6293475423609057, 0.09604578372091056, 0.020211169105624, 0.015976252297179836, 0.05564167840226043, 0.04241049725321993, 0.11564893182367088, 0.02125560358587292, 0.028216782168695526, 0.01552110605482613, 0.045538418926298625, 0.03634149126047569, 0.026314472854738275, 0.053457036959908666, 0.03343208850691876, 0.011212725244883088, 0.011227421684100503, 0.05750946587912979, 0.021547492661122835, 0.04952240555036453, 0.054102630745018684, 0.023300840008643367, 0.0565325812016043, 0.09439352359021864, 0.02678947418086952, 0.0441508574952041, 0.013258053598204448, 0.06870756842075817, 0.024645435398504622, 0.01814436730778506, 0.022593532095573122, 0.07756599630679815, 0.09096486644158441, 0.047387483214298566, 0.07577050837778276, 0.06019560762891366, 0.058651193525762334, 0.015302477967775157, 0.01476471010039771, 0.05770684843282065, 0.051228636575322, 0.011736085871234538, 0.03137190379352579, 0.05137466825544835, 0.05970136600456411, 0.0983208043861293, 0.30498668130847717, 9.193183548988836, 66.95708674769249, 36.762787065198346, 42.411525710936516, 31.400444199962003, 61.3536593221849, 87.89498898290819, 39.70435288644607, 0.9585532966640689, 4.290291436256902, 1.6135565720258223, 0.1995126151990506, 3.344303023430609, 67.46959932388799, 79.99280944947274, 75.4410400698262, 75.89252056614046, 64.61198791380852, 62.08406348382274, 60.81727912349086, 60.91625229004891, 70.7873361341415, 73.00901366818336, 73.91998414070376, 73.79861031809162, 73.51863937993204, 73.24523448944092, 70.85858991069179, 71.50075251056303, 71.49184088553153, 65.00555461452853, 54.96073722839356, 52.72167574974799, 52.17722723560949, 54.58431520769673, 52.332102021863385, 51.216517186933956, 49.56748608619937, 52.26997560070407, 50.615692446308756, 53.11622304301108, 50.68082732539023, 50.23049216116629, 47.651518083387806, 48.84826067955264, 48.438788767783876, 49.604591708029474, 49.309574557888894, 50.75889818130001, 51.052005137166674, 56.30391759257163, 61.635210975523925, 63.37760233109998, 64.29125178244807, 67.20694957240936, 67.12349722462316, 67.62292477392381, 64.14867754905455, 66.06122524507585, 65.13751491423577, 66.39191242956346, 63.07267335153396, 64.52376596389279, 66.0857008349511, 67.7670326540547, 58.47064272049935, 62.90991067886353, 66.54135473312871, 63.00504776739306, 64.7324792031319, 63.74428902902911, 58.90179749458068, 48.826766091008345, 47.0939649305036, 47.8441378378099, 47.73402906233265, 48.61214183991956, 48.357901650090376, 48.45277986218853, 46.60122894471692, 46.85547697928644, 45.916967545786214, 47.73586865394346, 47.878078106910955, 47.174526491472804, 46.61918947773595, 48.393328497486735, 48.22705530351209, 45.0850445993485, 46.79443705466486, 47.950834151237245, 48.29915238964943, 49.78748006205405, 48.4331601665866, 47.447350871178415, 46.376159421859256, 46.64056639517508, 45.80880426591443, 46.480027706392356, 48.448135775904504, 46.926267916156405, 48.81030782576531, 47.44780194374823, 46.529073023026996, 52.27126606049077, 61.10178432156963, 63.26586184963104, 64.57459595895583, 66.4053112460721, 62.392087213454715, 66.89119877353792, 62.342673194023874, 64.76164594773324, 67.7946618295485, 69.56745547633018, 66.08105674866708, 75.97292130993259, 44.7021585126077, 0.25810881127272883, 0.35540210023041696, 6.700136834575284, 1.177971358260801, 1.9159684931078267, 77.67625762570289, 30.23930888022146, 26.24967594300547, 36.908942422559186, 32.24154157023276, 53.85748432528589, 1.0940116764076295, 0.09299747390492309, 0.05584228618611252, 0.06004866430415742, 0.0698683525045072, 0.055922181495735725, 0.027808777146762418, 0.045059039407680114, 0.0502943808603431, 0.01060092359811308, 0.04508011831691669, 0.06060002927458095, 0.05197157332253072, 0.03273247020138848, 0.024562596396032362, 0.06008396563570827, 0.06176238766901436, 0.03848346160544503, 0.015179718123568643, 0.011715590146430319, 0.0457336564338015, 0.11717517049081864, 0.1660735208180643, 0.3350399122122796, 0.12451104459262664, 0.14478525507353968, 0.08217916328219638, 0.1524978912165088, 0.13701312454237094, 0.16396144705434001, 0.16940099307365958, 0.22798438015724384, 0.15341082287411537, 0.11696911582182493, 0.08194921433084434, 0.16453730002526315, 0.15269172678311027, 0.07928998524984045, 0.14890230350917386, 0.1708454824984074, 0.13942044859211292, 0.2050856443782968, 0.11551983834755038, 0.15119238546298397, 0.31904221902931895, 0.2535494083478566, 0.5653085980203845, 18.36675132474592, 87.27973384241905, 53.295032132056456, 55.5246603104376, 35.80839987724058, 61.10236090998496, 99.2107209851665, 43.100721451544, 3.42290339931365, 7.1953135152016925, 1.3176447537637528, 0.5320223228585336, 4.084674663120701, 69.75183825339042, 82.725540438006, 79.78298617947488, 78.0112829516011, 69.4249322337489, 63.77979040145875, 65.26524297652706, 64.30244622691986, 76.19059716501545, 76.60959259156259, 76.95786768390288, 76.01968380712694, 75.9721133016771, 74.62661481672718, 72.86092850469774, 73.15170949505222, 72.2175342805924, 67.90349191234958, 58.96181760295745, 57.367550634568744, 55.371511367059526, 56.735025298210886, 56.44847654527234, 52.73172878449964, 52.828776067303075, 54.26545789164882, 52.25683566062681, 57.10755632769678, 52.34426529176774, 52.35601279043382, 49.84050266204342, 53.14120854100874, 50.78811983908377, 52.89056908699774, 51.14687942689466, 54.1993934108365, 50.44838766897879, 58.38422113849271, 64.7077408144551, 65.37883089434716, 67.22616134151336, 68.44394745365267, 69.57295463931176, 69.7808559479252, 67.23024845123291, 67.13880231303554, 67.51634613160165, 69.30310341619676, 64.83790859099358, 66.02260558835923, 69.0323265137211, 70.27182686713435, 59.98392451194025, 65.5629861739374, 65.81259404459308, 66.07884453188989, 66.76454544067383, 65.08064446910736, 59.86815183393417, 52.23815341149607, 50.08829055293914, 52.63283406534503, 50.9218648172194, 51.94807060303227, 54.25453801308909, 49.73690502105221, 49.328864774396344, 49.79960803062686, 47.545119870093565, 50.58197575230753, 50.80311506025253, 51.13239803621846, 49.1872436769547, 51.24985733339864, 51.221267177212624, 48.257653713226325, 49.15682569626839, 50.888712944522986, 51.30202093432027, 53.25277251581992, 50.68374949116861, 52.32354733251756, 47.68465426660354, 49.14445846311508, 48.99194886607509, 49.50882704027238, 52.245421563425374, 51.130554522237475, 50.86485316676479, 49.37951826280164, 48.30526344237789, 56.116459677296305, 63.68649290454004, 67.29676400461506, 66.9741569026824, 68.4737810011833, 63.42667118195565, 69.11269587855186, 63.47876418021418, 66.69103237890428, 68.78910033933579, 71.89814352220105, 68.93876229563068, 76.73447301310878, 46.86284319047005, 0.29766588381701903, 0.649981293226442, 30.377694022270944, 6.243699442955756, 1.5741930132912052, 89.19214033311414, 32.6766618605583, 36.06195757465978, 46.00043166068293, 40.88120906583725, 68.01921752191359, 3.3680032097524215, 0.31642268862455125, 0.1538614970782111, 0.14579531135818652, 0.22917797578678978, 0.10856526152741526, 0.23155272577799138, 0.07413053629739631, 0.1282617651046284, 0.09354149592259238, 0.1391576038252923, 0.18668045860625085, 0.15323560324407395, 0.2376317713529833, 0.1353109997486876, 0.12361293673635491, 0.21184404140278218, 0.17863302671861264, 0.10472627236477791, 0.14963802370813586, 0.16209072163028104], [0.08633912030246951, 0.02209741930146852, 0.01890468850521551, 0.0642461596327203, 0.020515367298597292, 0.030548472272893114, 0.11607534402320463, 0.036367373540997505, 0.06183477531697962, 0.07498084792807218, 0.008431237149653176, 0.10644997019440898, 0.06303591308214011, 0.03153778289655044, 0.10244743658169624, 0.06633315550824327, 0.020523905348513397, 0.02505460295886282, 0.02033183561457742, 0.07054803337180807, 0.014701678301207723, 0.08126234755881372, 0.06746295133545514, 0.043049330312398174, 0.14855106751764977, 0.06235641990638068, 0.26706799504257017, 10.86729722638284, 44.64886134670627, 33.37264330156388, 30.557391528160345, 27.17898545726653, 66.3674525291689, 66.84261629658361, 1.4830095513213066, 3.8856513942441637, 2.703513743415956, 0.20890895938200338, 0.16480625817371955, 22.990562877347394, 91.53327757312407, 67.57125931401407, 77.19199395948841, 70.29664762558477, 69.58039145315848, 63.467020603918264, 75.28929141259964, 70.82583811975294, 75.50514728792253, 68.22384757380333, 75.1769547308645, 72.72892505891862, 71.81229852860974, 71.56359672546387, 73.13903239465529, 63.75779767190257, 56.859784126281745, 51.81229383714738, 50.27823525090372, 49.38224823244157, 50.76404040859592, 51.76272684527982, 53.10909217403781, 55.69980982811221, 51.523183776486306, 50.477221012115486, 51.17449291290776, 51.079885344351496, 50.38983452704645, 49.9147766636264, 47.06344104582264, 46.71000803670576, 45.92463970184327, 46.80349772976291, 46.31299357260428, 47.854740004385675, 46.87277463174636, 53.378005950681626, 57.942593636051306, 62.122455643069365, 61.51799094292426, 62.93934806700676, 63.785415080285844, 64.57018721488215, 63.048236985360425, 64.57118741927609, 65.1193308061169, 64.37389219960859, 60.38582624927644, 59.01121201053743, 59.20913088706232, 60.20043150071175, 63.76725058401785, 65.72785515939036, 62.8333773920613, 62.07958805945612, 56.51093244552613, 46.40120767777967, 44.95748519897462, 48.75972886239329, 47.69598599403135, 50.38432359695435, 53.27274130236719, 54.270039220010084, 48.42258937897221, 46.967327287120206, 44.877209971027995, 45.517293714707904, 44.63325423579062, 45.92758540184268, 44.86907105292044, 45.74125712917697, 46.08116972830988, 48.812006212049916, 50.721290496087846, 47.21163211330291, 48.98664189923195, 48.564159485601614, 49.70037598763743, 47.40951176612608, 48.09391829275316, 46.35039729456748, 45.994552027794626, 44.4520015101279, 44.51415146550825, 44.54782501343758, 44.74437890514251, 44.680922800494784, 48.33391635648666, 46.90431441030195, 45.63612584144839, 49.70472589615853, 65.43425006251182, 58.130271204056285, 63.81369929159842, 61.95841427772277, 63.504208595521995, 57.30009763471542, 68.87372155343333, 60.17629323467132, 67.61023982878655, 61.180008149916134, 78.52614110515964, 4.922005332285359, 0.136402981475957, 0.21500884254853572, 5.074515909917894, 1.045164439466692, 8.673878408247425, 60.54689053566226, 12.416144128768677, 40.846107775165194, 16.937569072169644, 43.292093892251295, 26.002692137995076, 0.16590389362987013, 0.08030917330254471, 0.017404864549696926, 0.049955628271545136, 0.06924876357398688, 0.027288655157110868, 0.01314531705687724, 0.014920571646202477, 0.04573387859929954, 0.014861513928119695, 0.035721683994896954, 0.06329641745035207, 0.021743270260612332, 0.02146255840817767, 0.05074574454357067, 0.08109108094246158, 0.02459167900885786, 0.06548470547122341, 0.014779085740296832, 0.04316222868979939, 0.028283025791508057, 0.06234735325579682, 0.07191940736506255, 0.031652117688809676, 0.040199843295399225, 0.0430110527292615, 0.08091524078120148, 0.03378174252687924, 0.024161116527994315, 0.1610130504254372, 0.03966935039047272, 0.032881462811342174, 0.11285235849960197, 0.03909981381448527, 0.06596990725806644, 0.06841360516245328, 0.014129985187713419, 0.03425705028818019, 0.033021614766649665, 0.1568398017796778, 0.08983860994058271, 0.040063150227069855, 0.18614105609876497, 0.08089494711208729, 0.19412894763292807, 0.21507526237157085, 0.19948840682064334, 0.3355508009272237, 18.546176225908344, 54.537725294789965, 41.204098578422304, 41.45569509075534, 36.57648624912385, 75.92998704602643, 69.23583476774155, 2.066402666030392, 3.230643032058593, 3.6506675904796975, 1.1505584034227556, 0.2704081077489161, 25.851694614656513, 91.73276147534771, 70.95901043184342, 80.15277939458048, 71.09677191703551, 70.84891734584686, 65.45974546863188, 76.84172630310059, 74.67789588436004, 77.38776729952905, 70.62951564788818, 76.25126054210048, 74.56210751687327, 73.34569423429429, 73.74643495005947, 74.99012439481675, 66.72023834720736, 59.7811968095841, 53.822528162310206, 53.81945302409511, 52.69226581819596, 53.55848989179058, 54.563844357767415, 56.27073434091384, 56.6340164215334, 52.92681570976011, 53.51183329859088, 52.58992333565989, 53.56342031109718, 52.26977948219546, 51.97941818544942, 49.21675166776104, 50.37080318697038, 47.28816147773497, 49.31435984949912, 48.949689249838556, 49.98306120595625, 50.049204134172015, 55.83692804459603, 59.368598768788004, 64.56639428292551, 66.45708653234666, 66.91405050216183, 67.12040639692738, 66.1296235361407, 67.674190152076, 63.73813483022875, 67.18038728160244, 64.33486069402387, 61.10015261557795, 60.680070692493075, 60.911427774736964, 61.01941847032117, 65.20911385936122, 65.55221534544422, 65.50586861948814, 63.56196549630935, 58.72253733296549, 48.723325344824026, 49.30296144177837, 51.87578132075649, 49.40148353576661, 51.54203468753446, 54.21060746715915, 54.77889222483481, 49.70702832744968, 47.696715554883404, 47.238170869888805, 45.01925076207807, 45.248391705174605, 46.24864708992743, 46.46723293489026, 49.15256600226126, 48.25562977021741, 49.912533067887836, 50.60379589757612, 49.44573963842085, 52.57918780849826, 50.935016524407175, 52.070221054938536, 51.098767634361025, 51.833623686144435, 48.49988360558787, 47.75715535686862, 47.15467537603071, 46.99209705475838, 46.974885694442264, 47.82820517016996, 46.41189613649922, 50.29796869524064, 49.58052796702231, 49.713484548753314, 52.71507047837781, 65.91927466853973, 60.77808680072908, 65.49117542082264, 64.51455231635802, 65.08689280479186, 60.845963416561005, 70.37161196431806, 60.867179516823064, 70.32819132651053, 62.79587168847362, 79.7225110761581, 5.2381591546920045, 0.2059621255724661, 1.2753882018789169, 5.235526754010109, 0.8785714497489314, 9.961468000565807, 70.47095775604248, 16.932885762183897, 41.089906615595666, 17.281184388745217, 52.96126588698357, 32.842940938088205, 0.11776786207431748, 0.014975137216219259, 0.12677193859652167, 0.0831849754397427, 0.0699243918361683, 0.037774830275485595, 0.02138904844140334, 0.058057551993237394, 0.09156996098857734, 0.027544235495189508, 0.010334562487720002, 0.022092589117105932, 0.0360796194253189, 0.043745099026108944, 0.0617343680031838, 0.03319957699146002, 0.09104273161820828, 0.0652653898202604, 0.045129917862434546, 0.016941538403531717, 0.08230600445981949, 0.18017911472387854, 0.13413274119938576, 0.10638076947220873, 0.21687406746129836, 0.09932733666632446, 0.32620232191778004, 0.2227674286452032, 0.16836343423253106, 0.18748547911884325, 0.20723649751274817, 0.18563560660808318, 0.20104552649201887, 0.15269215579234785, 0.14565933075162674, 0.13212120881484402, 0.12153699167913969, 0.13343691885952028, 0.14235543868234082, 0.20767079275702277, 0.3114646901526759, 0.08582984037216633, 0.29170023457657906, 0.1693411003197393, 0.23640308889650533, 0.4385477983422818, 0.24934283487739103, 0.3810888138269225, 31.938042294594553, 68.95922922318982, 53.659977297629084, 51.94924339171379, 38.008441617411954, 80.4980028829267, 82.03777636251142, 1.9923236797894202, 13.573991521712273, 7.406613067273171, 0.584525024938968, 0.42935832854240175, 27.92128420645191, 97.05780260024532, 72.76432837209394, 83.94800986013105, 75.45854953027542, 77.49535006861534, 67.91462359889861, 82.19758941281228, 76.73608118487944, 81.9498368232481, 72.3685690664476, 79.88206525002757, 74.98608435353925, 75.92033017066218, 76.41815739293253, 79.71913783780991, 67.9301404953003, 62.140000404850134, 56.038730067591516, 56.650125595831106, 54.216263524947635, 58.55710744857789, 57.623504900163226, 59.86098566362935, 62.066012736289736, 58.69095833070817, 54.9605332651446, 55.321269727522335, 56.82503192655502, 56.30072086088119, 55.915661781064934, 53.5722731005761, 52.65160652898973, 53.24759890956264, 51.37941322019024, 53.553469257970015, 51.38893281259845, 51.385265396487334, 58.13994376890121, 63.84734146056637, 67.63907709429341, 67.8173723528462, 69.24548379836544, 69.52765910856186, 67.81901190357824, 68.28493456686697, 65.61628333983883, 68.5245600054341, 66.29379826207315, 63.396386561855195, 60.54292501941804, 61.16458146802841, 61.80368461916524, 66.87710177513861, 68.65496312418293, 67.91080321035078, 65.99883602511498, 61.230893058161584, 50.717081792892955, 49.93092506162582, 55.23288303805936, 52.97611598045596, 54.704488785036155, 57.0705016966789, 57.481346438007975, 52.29429037340226, 51.088671453537486, 49.6101850078952, 47.687890221995694, 48.34143161773682, 48.295861521074855, 48.2755514883226, 53.035845833439986, 51.93330680170367, 55.005307120661584, 55.40571443496212, 52.749920737358835, 54.874378404309674, 55.32689832871961, 55.0703517852291, 51.59626929990707, 54.52411467029203, 52.154744209781775, 50.97786057379938, 50.049584604078724, 50.472839724633005, 48.157233192074685, 49.73683049601894, 49.97825630249516, 53.87713539984919, 52.916437118284165, 52.40665058935843, 55.37186045800486, 70.94816900068714, 62.524106348714525, 67.9343060524233, 66.98111518736809, 68.57945749836584, 62.893876029599106, 74.02657847250663, 61.42227334360923, 73.23914697093349, 63.512928024415054, 83.89083739249938, 7.028927553084589, 0.2689153088196632, 1.3196948050491273, 15.232852082098685, 2.5019404436311414, 10.936216212088063, 75.36840561897525, 19.14659696240579, 59.80461335951283, 30.082188537043912, 62.29961341427219, 46.45377920519921, 0.2678528061557201, 0.22159281667442093, 0.1835138341712375, 0.24716443322118253, 0.11889735912723888, 0.22812000836335847, 0.13253794532389412, 0.19432155745885066, 0.19860066413398714, 0.13473099458121485, 0.14464763503882194, 0.10916050418370193, 0.13641287933193869, 0.0999608377535497, 0.14425653183171827, 0.18278267985630423, 0.16732984372685034, 0.12094003298590261, 0.18866868659613595, 0.14738276811136355, 0.19460330927564254], [0.03686431562528014, 0.04303586248668932, 0.03918107659105332, 0.05094293940572008, 0.02591919638366709, 0.0181921960921177, 0.024584845504573277, 0.019091604382640893, 0.054895704116431944, 0.024393917241644476, 0.010649614231360537, 0.033196064478327195, 0.029541300309281197, 0.03683528472338954, 0.04265797046583988, 0.0031160681382677853, 0.08052416055673554, 0.07384054137453919, 0.03686080694258694, 0.01294143137431914, 0.08777605610028391, 0.049561273021202897, 0.027314568081149654, 0.027889044009028908, 0.021519907750189308, 0.09883422119122359, 0.2733891090798763, 4.277222098842744, 48.836909340273955, 26.728493398235692, 30.5791038082492, 30.231419032619847, 39.85489345365956, 87.26145559741606, 7.047465655111498, 1.7437234905458268, 2.839549876028492, 1.3282285342293403, 0.05520460225882069, 1.7865956093995803, 71.129743360704, 82.23914300241779, 75.20308556095247, 73.7138557434082, 69.09182886923514, 72.65254082218294, 76.66800452816871, 72.49820340064265, 71.61096326766476, 70.10049773800758, 74.78287419965191, 72.6549256232477, 72.70950148182531, 70.7903955828759, 62.77156476051577, 58.614856504624896, 55.21225137095298, 51.34820292072912, 50.207605131210826, 52.36153941000662, 55.1354984314211, 63.47927801070675, 65.28697682965186, 65.5902035005631, 59.720200031034416, 56.61197662353516, 50.406857613594305, 48.8065266609192, 48.49508654686713, 47.84258850159184, 47.96670798332461, 46.80217196864467, 45.35619804936071, 46.53710995951007, 47.56161735903832, 47.38166293790264, 46.37991313011416, 48.32651876634168, 54.53942760344475, 58.30573843371484, 59.50420687275549, 62.577395669875614, 64.11465491017988, 62.619612140040246, 63.12000851477347, 64.92762888631513, 64.42780517762708, 65.65131795021796, 63.64028346153998, 62.91984212013983, 62.667908283971975, 65.00328356219877, 63.183429318089644, 63.67663991066718, 60.7528934171123, 54.54995916735742, 47.921326160430915, 46.66486940076275, 50.13063646131947, 50.314399503892474, 53.92974222860029, 56.781093535884736, 58.66944020794284, 59.45173732696041, 58.15176579260058, 49.68426681333973, 44.73969559515677, 44.82358724840226, 46.531893207180886, 44.21664753267842, 43.90096341409991, 44.23873832148891, 52.546216364829775, 61.056979087091264, 60.736533211123565, 59.06033577457551, 51.662847611211966, 50.417640209198005, 52.72259358436831, 51.38656762338454, 46.62258625030518, 49.74558130387337, 47.40862531046714, 44.79362034028576, 44.475720082559896, 45.11977326485419, 47.41921178756222, 46.805525595142, 45.92455340969948, 45.255255852976155, 48.976973256757184, 48.1884866376077, 50.77056331019248, 62.15576441057267, 62.69301537544497, 60.76394273388771, 62.47659075644709, 64.58312711408063, 62.827846850118334, 66.8725832047001, 63.45863457648986, 70.76633576423892, 25.228257409987915, 0.20016270208983653, 0.1904671392854183, 0.7157186238515763, 2.2512338190309467, 1.5278212822252706, 23.700329488323582, 37.68357130788988, 15.320214052354137, 51.14856604606875, 32.126690649217174, 49.388406353612105, 11.165774887607945, 0.17178547238149952, 0.024656107003289848, 0.025875717063524553, 0.08758032829650948, 0.016777980546917648, 0.04895630487871747, 0.054292049814736655, 0.02848608314149803, 0.027375519951625217, 0.0621014581843009, 0.08406320331437935, 0.05023380245773062, 0.06407914863478753, 0.07696560553966031, 0.025719856475329688, 0.06764372510294761, 0.012187708109136552, 0.13427455939592856, 0.022684141144817396, 0.06560256809837396, 0.035778799680091684, 0.009547876374375437, 0.01147410774137825, 0.040936750930643855, 0.01776098626695814, 0.04882906916581335, 0.06819811229023241, 0.06610712892706357, 0.028239690112851323, 0.08092702321347692, 0.07320727777457045, 0.046739012769032875, 0.02060956930020644, 0.032050303378773314, 0.12613260758019265, 0.07975410429700729, 0.011155707235898704, 0.07538122079905964, 0.04155260518253331, 0.030646765184017922, 0.03022595883287009, 0.018244736317184665, 0.05720756211948972, 0.045659407192180236, 0.02546203724529234, 0.033685843640517805, 0.008705606751684702, 0.23854225152923217, 5.862497523907693, 66.34270237338158, 32.4400213456923, 45.954508550705455, 39.42888482924431, 52.562470666823856, 93.07166253366779, 8.863674056145454, 1.0480635613203049, 3.2820020567986274, 3.347908662211511, 0.23639164354291656, 1.5402522538938832, 74.75031068248134, 83.92115731393137, 80.2485558294481, 74.99487830746558, 71.40095172389861, 74.79054635570895, 79.69619197230186, 73.98979448503064, 73.35261329527825, 70.30733216193416, 76.19557857513428, 75.76740480238392, 74.44518166203653, 71.57967844317037, 65.28556477638983, 61.97963037798482, 58.17014601922805, 53.0512725153277, 53.29046257080571, 54.22318650830177, 58.30457348977366, 65.49417603400447, 66.96461769842333, 67.95470237731934, 62.64569982405632, 57.61337734037831, 52.48916156830327, 50.99228705129316, 51.11557106817923, 49.83928672729, 51.07417045101043, 49.58086921322731, 47.75851641931842, 48.99884831520819, 47.97197180409586, 50.40796764435307, 50.99913550961403, 52.342194280316754, 56.198970656241144, 58.91903238911783, 61.929933947901574, 64.64728532298919, 66.4389024242278, 65.56428055609426, 63.995356021388886, 66.64962783936532, 66.41492889773461, 66.75400210965064, 64.5742743246017, 63.069147140749045, 62.648935779448486, 64.944196977923, 67.01338060440557, 65.99399582032235, 63.734369354863325, 58.305844337709495, 49.485077088879, 47.454819063986506, 52.141894525097264, 52.774251199537716, 55.055701732635505, 58.15572738647462, 59.64722433397847, 61.039022476442405, 59.618779305488836, 50.537982448454834, 46.3381241982983, 48.857019332147416, 47.90611520890267, 48.926978726540845, 46.41612445154498, 47.260277348179976, 53.64911233225177, 63.37050284108808, 64.053516926304, 59.35569809329126, 53.85782557149088, 53.812282931420114, 54.67082700421734, 53.13099076670986, 50.369434279780236, 51.994629136977665, 49.63871632852862, 48.54389652129143, 46.99698825036326, 48.000930663078066, 50.3883832500827, 49.00971328058551, 49.50371619193785, 47.75990101598924, 49.34557407133041, 50.2139985945917, 53.82070818255025, 65.93233616121354, 66.6864824295044, 63.45121345212383, 64.05710981738183, 68.7822832599763, 65.72653724301246, 68.43083104779645, 63.82172446097098, 71.76467310997748, 27.493265367323353, 0.41755965520297333, 0.4482890965957796, 2.772519756709376, 3.1535049648054185, 1.0602393337795812, 25.038126399440152, 46.30596076288531, 19.697458551776027, 65.74859665286156, 35.258040351252404, 60.56528645177042, 16.355265763498124, 0.18646529515183743, 0.04631987457434016, 0.021905062284560937, 0.012960208189343254, 0.06866728751769952, 0.027345711470491467, 0.06972911602426922, 0.11554367134287474, 0.08803424305252491, 0.04366357961008626, 0.0617466445621704, 0.029287221503534147, 0.01986794639378786, 0.018165766058730024, 0.06603231278037833, 0.0315654099423198, 0.011793830706137083, 0.06665046146560101, 0.04468248804069815, 0.046875908850662173, 0.07687558254767811, 0.220414083150606, 0.13996047929169672, 0.1809660862049749, 0.1129311276599765, 0.1216229544051232, 0.18031339461524643, 0.12461873357214275, 0.08019461251434781, 0.16115759589499043, 0.1681885823246933, 0.17163757144683794, 0.07534028872126534, 0.13531666879932727, 0.19134375837541398, 0.12134730830908784, 0.08594782557338478, 0.1458414298512282, 0.17085735686123374, 0.21723426668153656, 0.14393819165566277, 0.19793634332956808, 0.16471550739820928, 0.1995413741397281, 0.11831655722832489, 0.2376597642057365, 0.15750347907024045, 0.4935722780083457, 10.29295534856858, 86.68776973601311, 44.20302514106997, 51.445877782760135, 44.60811576535625, 55.28653713964648, 105.86933658969019, 10.251093852904535, 7.537755552799472, 8.895178533369496, 2.945405576498278, 0.17038904731312107, 2.127588944089028, 79.60301999122866, 85.4267983282766, 86.05862156037362, 79.39049813055223, 74.80391379325621, 77.27072377358714, 83.26479573403635, 74.49509774484943, 74.7666669660999, 73.27018076373686, 78.1244041073707, 77.84019700942501, 77.68956230532739, 76.45077582328551, 66.53689107587262, 63.567641165948686, 60.38126453276604, 55.64552422492735, 56.60586949317687, 57.24472161262267, 60.865983193920506, 69.40814448941138, 69.59390009603193, 72.09541520764752, 63.42696535971857, 62.98639689722369, 54.83660597955027, 54.889491296583614, 52.90897677021643, 52.07978379341864, 53.490162203388834, 52.63827047040386, 50.59753187241093, 52.55490049239128, 51.718666861134196, 52.8454343734249, 52.84086873454433, 54.5602200877282, 57.996534070661, 61.060364092549975, 62.95067194969424, 67.51260419045725, 70.26376247406006, 66.82342806170064, 65.27399770675167, 69.10354106656968, 67.62881617392263, 69.12661244792324, 67.20050119584607, 66.16615649192565, 67.28436931487053, 68.57384066427909, 67.54734070070329, 70.20542898485738, 67.57181629057854, 60.033907275046076, 52.06953464015838, 51.486223282352576, 55.29845330022997, 57.126371937413374, 58.80324402163106, 61.30371186041064, 63.207512670947665, 64.48094152635144, 65.77038934153896, 55.12418631584414, 50.14954228555003, 50.850791469697036, 50.28408350483064, 50.37957752904585, 49.060174572852354, 49.56343820018154, 57.645795729852495, 67.70808727510514, 68.47581278893256, 62.211422843317834, 54.29061205156388, 56.01656475374776, 58.97154900335497, 57.052666679505386, 52.823210224028564, 55.04373850360994, 51.35158008144748, 50.65974458571404, 49.38760619009695, 49.83280304939517, 53.266222323140795, 51.40755230380643, 53.488542264507664, 50.243247708966656, 54.550559289993785, 53.23698889824652, 56.96496640482257, 68.28693497565486, 68.5791358640117, 65.86964884111958, 65.58698715702181, 70.76973253680815, 66.30283540295017, 72.46501230424451, 64.94598557872158, 73.51023766302293, 32.29162631496307, 0.4775776185335652, 0.3199618309736252, 3.702735338480242, 11.30107802729453, 2.4116550818566354, 28.811683808603597, 49.07824100986604, 24.354035623611946, 70.3545339645878, 42.33219577420143, 71.31847212391516, 24.888166343012166, 0.2246671121928, 0.23671056594579454, 0.15333756954679567, 0.1581064055884077, 0.1378101930623093, 0.1383519397988435, 0.1290302738667496, 0.21283080861453088, 0.116969560152821, 0.19725702252359162, 0.10264448971757967, 0.18987850796791816, 0.14163102594114121, 0.11027118611720302, 0.2082141023129225, 0.0934840469891506, 0.1076404478461031, 0.23991731806628167, 0.15519476585811184, 0.14673416743115072, 0.19660348823714643], [0.03346648968515858, 0.024787284238564394, 0.03448917109879755, 0.01571624014045923, 0.03308565205624027, 0.07061852112172112, 0.03501494873255011, 0.03093871746152159, 0.025349405083444812, 0.007912413200228325, 0.08919737902620146, 0.033685292057212324, 0.021981257389509873, 0.03578004840340826, 0.03555784460097071, 0.08522601753112771, 0.0067641709334096845, 0.02939032353160362, 0.030447501884472948, 0.012183939914158996, 0.033737795893102884, 0.028180142098497, 0.03056096716693813, 0.02373481349598977, 0.025923637778408108, 0.03479102123228293, 0.0406359426767355, 0.1429368994168697, 26.791329768396196, 43.1071815952178, 25.517687143818026, 34.07297857346074, 19.996515743194088, 78.47366763699439, 32.95988052122055, 1.1039138224817093, 1.593499654723752, 1.792914915469385, 0.4799387015161976, 0.3240511470264004, 7.45290978300956, 86.08345800830473, 74.93543870987432, 75.94332310461229, 76.90448422585764, 75.03158384753813, 81.67836958362211, 77.40158973201629, 70.6581489501461, 77.53744494530463, 76.74449074652888, 74.43383032275786, 68.99920601998606, 62.9619409191993, 58.819459099923414, 51.65360650708599, 51.86330426123835, 52.85061582442253, 52.344810501221694, 54.202766649184696, 63.900921037120206, 69.38300209660684, 70.81908379831623, 67.21804987999701, 67.47473762881371, 63.04473430879655, 58.31462652452531, 54.394048875378026, 49.465571142012074, 48.79863877450266, 46.79597070140224, 45.405741507007235, 47.63446754024875, 45.50495001577562, 47.779308903601866, 47.41751732364778, 46.95606616235549, 48.40516228829661, 51.82518666790378, 55.0379922313075, 56.169568569429465, 57.887790280003706, 56.84294539113199, 61.00997340294623, 61.47809651590163, 61.963768313007975, 63.523263469819106, 63.07154370892433, 66.12819579339796, 64.47410091277092, 64.57529021847633, 65.53381942933606, 63.555979959426395, 59.261290565613784, 55.22809382407896, 51.887752394522394, 50.5897577347294, 52.828344606584125, 55.140672037678385, 60.614476896101436, 59.37505891246181, 63.27035296347834, 63.5992907708691, 62.06840538209485, 63.475912617098906, 55.90549499757829, 47.06450400813934, 44.83705274520382, 45.074281615595666, 42.59190767042099, 46.01736061034664, 46.79253470513129, 60.73069280193698, 64.92471848764728, 63.191556469086684, 62.5255693927888, 56.20226936955606, 53.1780513640373, 53.7007228789791, 52.66309122885428, 50.536715522889175, 48.55562440810665, 48.78386712843373, 48.14743511138424, 49.80029444540701, 45.143295718777566, 48.480973858987134, 48.24133665330949, 49.30672299477362, 47.77698293808968, 46.79490381671537, 44.927683030405355, 47.021134361144036, 50.50314787895449, 59.505269835072184, 61.72034602011404, 65.62639128777289, 63.42862452230146, 74.08531988820722, 59.553675805368734, 76.16845146302255, 31.102067539768836, 0.24915794721774517, 0.38534461610740234, 0.07163259936797042, 1.280137824435388, 3.6635189912011548, 0.07510261760363657, 34.515029691880756, 26.859047528236147, 34.169543404732984, 64.33532353370421, 43.686256793237504, 46.92080013213619, 4.81813165449327, 0.2244123113491843, 0.05763646027433777, 0.02533560592470871, 0.026547599155756257, 0.07106223158658513, 0.0816961754894545, 0.0892989163196856, 0.07741100139795773, 0.06552927646665804, 0.020290064670506026, 0.015187169286242176, 0.03821272613300431, 0.024856753091538147, 0.010389614523568702, 0.00701496274315662, 0.0117561420530922, 0.03585281526489604, 0.07207945079332398, 0.022837123157636776, 0.00921651270360716, 0.022770695673722415, 0.02593907445008236, 0.020168046016366254, 0.04428106562925443, 0.0296172924009302, 0.03126362492630799, 0.02700864810556654, 0.047910196496354, 0.08180270767620496, 0.022441672401562817, 0.06019378050921425, 0.06797302799719958, 0.04192570149297676, 0.018762140609924833, 0.057149209202297276, 0.05251106009968827, 0.06097415980372218, 0.047711040449118426, 0.023733020850246953, 0.0335093216610051, 0.08729053255651267, 0.02734845789570001, 0.008709644992655564, 0.0765744946716774, 0.017110962578425967, 0.05337358700231679, 0.007678305349057361, 0.012159195274204738, 0.2769266886095847, 35.66615120057137, 50.07859837624335, 31.085766169332693, 41.13191520014117, 29.525121758061072, 88.08931104598507, 30.871712623103974, 0.7163826688643425, 2.067564177897669, 4.363466683895358, 2.0697175591222705, 0.39191336040535285, 8.226306553809874, 89.18230302872198, 77.4916865748744, 79.64717018988826, 76.6344996421568, 78.29636866046538, 85.40158533280896, 77.10269728014546, 71.34694853136617, 80.08108631257089, 77.90391199050411, 76.43681218547206, 72.16289566409203, 66.85589744198707, 61.39383223748977, 54.52625628440611, 53.366717369325706, 55.24082191528813, 54.28663869057932, 57.32591075281943, 64.22755641321983, 71.45671998300861, 73.96915497318392, 70.64102388197377, 67.58461106208064, 65.79926975311773, 60.45621318201865, 55.59997766248642, 51.34990130701373, 53.63322673305389, 49.39579217664657, 46.88004670604583, 50.64279994656963, 48.517573495065015, 49.39679238104051, 49.05866446033601, 50.81063032150269, 51.29205419171242, 55.15136834113829, 58.491635245661584, 58.42239756737986, 60.86473195783554, 62.16483685278124, 64.19313369258758, 64.42600873208815, 64.52025936495873, 65.91164958092475, 67.1974652813327, 66.02107586399202, 64.31698645314863, 64.47758789985411, 67.17342899691674, 64.56500184151434, 63.80202239559543, 58.62754537213234, 53.16278942169682, 52.6078603344579, 53.41836321738459, 56.94928869124382, 60.56360767733667, 61.81404359879033, 63.6534430134681, 64.3868124869562, 64.149917018029, 65.99206601419758, 59.19689701449487, 49.51113731630387, 45.99466577652962, 46.71389118317635, 44.32606204863518, 46.37918749163228, 47.303137087052875, 62.202162127341, 67.3464604346983, 66.00910479022612, 63.61703557352867, 59.94596773578275, 55.30057530249319, 54.24633633705878, 55.043561996952185, 54.047181913929606, 51.06937339228969, 51.82137020172612, 51.318604715408824, 50.973898979925345, 48.38991995780699, 49.97669127679641, 50.93309848539291, 52.89601333679692, 53.04931525261172, 49.432729136559274, 48.92541370084209, 51.16885254459997, 53.95973267093782, 63.60057730828563, 65.13623622155959, 66.8908457602224, 65.6362795829773, 76.48266469278644, 62.08620509793682, 75.4031107502599, 33.85690304540819, 0.338792609231126, 0.49231476000239777, 0.44262421347441216, 4.32525985663937, 2.053343869986073, 0.18647804285489744, 39.286428266955966, 33.65128847860521, 41.89458870118664, 79.55952875075802, 47.74460377231721, 56.77215445426203, 7.462237669575599, 0.4864620014784798, 0.11957018350761746, 0.047478762590476585, 0.03183904505755392, 0.11540781331038284, 0.0137278483992803, 0.01887453145407621, 0.05523458310973741, 0.01617763191461563, 0.04724684479315916, 0.029689731759830352, 0.05542209845096354, 0.0260446222138501, 0.03650018254355077, 0.07474204300031548, 0.04470116143385249, 0.01636996977932511, 0.06656223878024087, 0.03185855731698534, 0.02812679748110954, 0.03859083265847257, 0.10330748518988972, 0.12820394844898295, 0.1342424449901427, 0.07635833530296242, 0.15587589463158963, 0.15674872924723934, 0.11530842106308668, 0.2263147221697915, 0.13319610678140195, 0.13564314482913864, 0.224867245002139, 0.1176513017966382, 0.05935306029935038, 0.2716680465927047, 0.11939399094591219, 0.37885827222658747, 0.2079349245515562, 0.15487340729563467, 0.0964279160384209, 0.1284632921939896, 0.1281586956352957, 0.11122344106796289, 0.2522642652113592, 0.07644218362627492, 0.12004616159585216, 0.1127605505227562, 0.22193150414574533, 0.3591038064370233, 53.26584185323408, 69.03693922104375, 42.23524655065229, 52.7778793919471, 32.45235131632897, 95.42880304398076, 39.82014909867318, 2.447576638190977, 7.848620059028749, 9.19603511210411, 3.3251280265469707, 0.469802224467839, 9.308549281089537, 92.76904383013326, 77.40766940578338, 82.62846177624118, 79.97999114374961, 80.72976789166852, 89.54783654982045, 78.99087921265634, 70.16358513985911, 82.86659671414284, 82.28402276192942, 82.68028413095783, 76.6103692208567, 68.79786291430074, 63.576643005494155, 55.54864560404132, 57.217488596516276, 58.29291620562154, 55.09651791664862, 61.14220826856552, 67.56355577899565, 74.82343150723365, 75.6641209510065, 73.29061631233462, 71.19934974178192, 69.94916485201928, 63.24843475895544, 60.289006463943, 53.25329026868267, 55.356731876250244, 51.97227162699546, 50.75050430913126, 52.94001056301979, 51.676313108013524, 52.16958253614364, 52.6109629292642, 54.13054404720184, 53.14533879680019, 57.689349728245894, 61.64289489869149, 62.670955965595866, 63.70305707377773, 64.53563897840439, 67.5695256263979, 67.32935105600666, 67.78323204286637, 68.1012813506588, 67.93592206893429, 70.03053834361415, 67.60420722346153, 67.1812423583, 69.05142845646029, 66.62135539516326, 64.49941588986304, 58.68564351912468, 53.90435664884506, 55.80219153435, 55.7968924122472, 59.64619667299333, 63.9435689680038, 63.904929699436316, 67.99880550753686, 67.73109589853595, 66.3971919398154, 69.89948411141673, 61.9581122552195, 51.97003979836741, 48.96955997713151, 47.765278585495494, 47.24561552847586, 49.85368967056275, 49.545348228946814, 64.25417753957933, 70.89999445023076, 69.90993330555578, 67.67491186818769, 63.261351123932876, 57.56452421988211, 57.12033148734801, 57.86684874565371, 55.91496752154443, 54.44564765499484, 53.108868598937995, 55.374523747351866, 54.95494781001922, 50.44232760706256, 53.419936087823686, 53.15813356830228, 55.96226738345239, 55.08143640333607, 52.07160172923919, 52.12177276611329, 53.698663634638635, 57.08229234141689, 66.92114999217372, 69.36057398396154, 69.17735222847232, 69.1917787059661, 80.2067590528919, 63.14645705684539, 78.89715025501867, 37.31666103486092, 0.23718891124571526, 0.547771190683688, 0.31956793920647714, 7.3522308757228245, 9.044996403878736, 0.43175851265268944, 42.221243689137125, 39.1417634102606, 52.29891092546525, 76.19117767580094, 53.65017921693864, 70.97596291572818, 12.603067621108025, 0.6999546181290381, 0.32435522264530586, 0.20936816780557557, 0.13964722593945844, 0.24361081181033967, 0.10957389288852293, 0.1712716725324431, 0.1799721943755304, 0.15965321371632238, 0.16905700427389916, 0.1357803205328603, 0.17469643795442197, 0.1338589566970064, 0.11390573705636686, 0.13413540718536224, 0.09008298432754894, 0.14314715990856772, 0.16693726963093206, 0.14049591346373483, 0.15979824948214716, 0.22778706655146616], [0.07099551298925955, 0.06941243059813015, 0.06946218034793293, 0.04061014849632498, 0.04530132620505268, 0.0153903788962071, 0.08056478619936012, 0.04618747925926601, 0.03032259316363883, 0.004507077683228999, 0.015409997450338017, 0.07222340637517553, 0.00816452938447436, 0.01810900468920027, 0.053249067071104245, 0.019851923664851535, 0.051371190216272115, 0.02897366746178558, 0.06136372700453766, 0.0676132807688367, 0.043148048402320956, 0.06320140339554318, 0.03640157936681663, 0.026356314661942666, 0.01853886236917348, 0.11011495014592526, 0.08685537929376287, 0.26440424604281304, 6.8816690291127856, 31.698022657825103, 24.681724156102828, 62.864085628140366, 39.52865423694734, 29.688058976204168, 72.56435809596893, 0.2757887416068585, 2.7555089275683127, 3.1427525224224215, 0.6112824536619649, 0.2667417335173776, 0.06767777771118187, 18.87367452344587, 96.16299229283487, 72.24206478365006, 83.2403358336418, 78.7532384933964, 80.67230516864409, 78.81259964358422, 80.68122463841593, 72.16817517434397, 76.42444102994858, 67.3207296863679, 63.7178522540677, 58.33892953011298, 53.68089529775805, 54.79552699673561, 54.18744587129163, 54.11094396345077, 54.95246887207032, 58.79985117143201, 65.96965359103295, 72.72594405758765, 72.43004045178814, 70.0351510509368, 67.71541426258703, 64.77659017808976, 60.84149583693474, 59.792536381752264, 51.702734193494244, 49.01629109536448, 47.51722005105788, 47.12219030626359, 49.09264787550896, 48.758324653871604, 48.226635609903646, 48.78186671964584, 46.773675949342795, 48.34487938111829, 49.16203068148706, 55.16879150944372, 58.29847028178554, 59.1509307584455, 56.59564779650781, 57.402828431898556, 56.74133246944797, 59.45693054506856, 56.756974881695164, 62.908016174070305, 62.796165866236535, 68.80933192468459, 66.42642928707984, 62.523023774546964, 61.68720983689832, 59.07100069907404, 53.6027067707431, 54.18447271470101, 55.781520643541896, 58.310335451556796, 59.17695176216864, 62.47262524020288, 61.184267843923266, 64.36558069721346, 60.03985751059748, 58.028222899283136, 60.87934278672742, 63.152815218894716, 49.16154038521552, 45.64851268645256, 45.01463805475543, 46.97477194570726, 44.56389496403356, 49.69136238098145, 58.643313300225046, 64.54269532234439, 63.85218558772918, 64.45206895951303, 58.67571207784838, 57.55533802893854, 53.153175692404474, 52.80307277556389, 51.8068927334201, 51.15826998987506, 48.47092474660566, 50.01007849170316, 47.93991819504769, 50.56134800757132, 51.17134324965939, 52.42130064195203, 48.805569602597146, 47.74008127950853, 49.317862526063, 49.94163705456642, 45.388184978115945, 50.49691523275068, 51.63217075409428, 57.528450181407315, 59.69486151972125, 65.55871863518992, 62.95728506580476, 70.6691708103303, 60.692818395553104, 1.915947900664422, 0.29358275775467196, 0.1100075905842166, 1.2106584300917964, 3.91891677052744, 1.7594675166952995, 1.4750215218913172, 27.90603207003686, 25.454774287439164, 36.06485620621712, 20.69261093293467, 44.19941656051144, 35.39535860861502, 0.764115339806003, 0.029954487916022062, 0.15771119615002988, 0.044926598127330505, 0.06288577900117924, 0.04893630615345413, 0.06045209003552314, 0.0376726916029809, 0.07813913732646935, 0.0635792532815568, 0.017899424100535053, 0.011381809468260937, 0.05274908744820184, 0.07507023506707723, 0.051213571456291025, 0.009242906347818432, 0.07751915769110765, 0.02119810294149624, 0.031023184400832945, 0.0325721318292762, 0.046610585789406495, 0.044317581210165255, 0.03330134794176106, 0.05833606708854918, 0.043912558185477416, 0.03154837406210361, 0.06581315034700018, 0.010454807648315065, 0.049331971414146886, 0.06983955525943349, 0.03875602802802478, 0.07086186895086881, 0.06591201399362857, 0.03822907444930846, 0.061653342713872274, 0.06655183530622913, 0.10851216397338337, 0.04588109005482928, 0.03257848269816849, 0.05782838828200775, 0.02427833755650828, 0.024070078469512445, 0.038884133250722965, 0.04716045688837767, 0.017906839831642086, 0.052659803731066566, 0.09206484612678328, 0.08944355371978976, 0.061639721670578566, 0.15342225290594563, 3.848571022672038, 49.483916067308, 27.87366859374508, 57.52125263214112, 39.16322661984352, 46.91227289938158, 75.4611304498488, 0.3737622553542737, 0.1761121531167338, 1.982896998524666, 3.0796798294590366, 0.5856159954301773, 0.08835081356547533, 23.109451878455378, 100.72316338939052, 72.31844902038574, 87.65984289107784, 78.51782568039434, 82.56018115628152, 79.18498162300357, 81.59392095381214, 75.1864625561622, 79.09113499426073, 68.73109632922758, 69.51156954611503, 59.59011070189938, 56.30978938071959, 54.53998065763905, 59.223545597445586, 56.20346569245862, 56.69693123909735, 60.511487222486934, 70.66264398636358, 72.64303299688524, 73.41706568194975, 71.9423564787834, 70.3722160093246, 67.22842847147297, 64.18897598020493, 61.132100320631466, 55.011826099887976, 51.903634071350105, 50.69120199449601, 49.54453629832114, 50.99985330335556, 47.83395536484257, 48.96542579896989, 50.035067912070986, 47.68909046726842, 49.82830801317769, 52.2935490454397, 58.82379331896382, 58.7587918004682, 60.20185139871413, 60.35884818723125, 60.03120083962718, 58.36113406765846, 61.08328250146682, 61.208923862826445, 66.1274819220266, 65.08046404007943, 71.53923096195345, 66.81137069579094, 66.04451594814178, 64.96384413011613, 61.62937448870752, 55.66468108084894, 54.870275605109434, 56.981228551556995, 60.648891771993334, 61.141941547393806, 64.85784599857946, 62.80811732815158, 66.18969071295955, 61.97805358517555, 60.893934003768436, 64.13494925345144, 62.529130904905266, 49.577970581669966, 47.46737849327826, 47.59189413439843, 48.96783413425569, 46.56218959439186, 52.10175298875379, 61.42025724534066, 66.52942288306453, 63.895661138719134, 64.94742901094499, 60.401005821843306, 59.221780530868045, 55.6932084791122, 54.373209322652514, 52.778765847606046, 54.29669172533097, 51.011459596695445, 52.163216529353974, 50.16518469779722, 52.12538526904199, 53.27605178279262, 54.02788385268181, 52.62338507559992, 51.140964492674804, 53.20682194925124, 54.025044056677054, 48.86930811789728, 53.225202175878714, 55.645175133982015, 61.569479896176254, 64.38498074008574, 68.05749201005506, 68.5007433737478, 70.53955216561594, 64.44063132809055, 1.672319315614239, 0.526814395862241, 3.093618952458905, 2.5826213917424603, 1.081967180775058, 1.1541986080908007, 1.5188689626032308, 35.35540926840998, 32.791854027778875, 44.9724058951101, 20.129558617068877, 50.95545207300494, 43.89078486350275, 0.6759297331013988, 0.06138521194037411, 0.09686977257050815, 0.051974748756976864, 0.08476009051645957, 0.05518273427902211, 0.04169895861958785, 0.03489703630968448, 0.02698578229624658, 0.013776471042224478, 0.03566099450953546, 0.029137752003847595, 0.05793751750682151, 0.062144336125422875, 0.052433145127349326, 0.016400073204309713, 0.03849128336315194, 0.024965675472612345, 0.04033073707814178, 0.0021600162642331977, 0.04673053600615071, 0.0065618207783348145, 0.13956361510340246, 0.11929197101703576, 0.14713729821866559, 0.1310648042107782, 0.17545961474459018, 0.24531521954603736, 0.18764856391616408, 0.1747956463406163, 0.13924285408950623, 0.09585911873728038, 0.1318740075634372, 0.1526012977645282, 0.1710541495272229, 0.13460610692779865, 0.12911710227208753, 0.3102382446729368, 0.19219520381621777, 0.14333983102152426, 0.16946594200788007, 0.14424727748959296, 0.1720609269555538, 0.21570140135384377, 0.14108031597589293, 0.10872972528299979, 0.12579133073168416, 0.16079768778816347, 0.21560475170131654, 0.5191530876101986, 9.639056036549231, 73.49027279884585, 46.96173398725448, 85.44625328433129, 51.174857693333784, 42.77205428769512, 86.93072918922671, 0.6931950872944248, 8.23777066123101, 12.881949120952239, 4.364276653335941, 0.6493972890800046, 0.1508802812426321, 25.079681950230754, 102.3151828396705, 76.39347783980831, 89.60893138762444, 82.32324646365258, 83.20040610528763, 81.59193623450496, 86.24847996619441, 78.54729836986911, 81.83236968132758, 71.84836079997402, 73.49303414744716, 62.19863199418592, 58.060009787159586, 59.21415936562323, 63.402693733092285, 59.38393915853193, 61.15791343873548, 62.385336814388154, 71.92714552725516, 77.63377051199637, 78.6832320305609, 76.31197098762759, 74.0576514890117, 72.16524908619543, 67.5112392056373, 65.95878078091529, 57.53086636143347, 55.19718162475094, 53.228602870818115, 51.80615925019788, 55.60317831654703, 52.224099559168664, 52.99378625808224, 51.70648005700881, 51.93668788479221, 53.618309959288574, 53.55638357900805, 62.33944508337206, 64.45546965445241, 64.37869318069951, 61.826046051517615, 62.49678704046435, 61.27874989663402, 63.82090076323479, 62.47686532235915, 68.21362587713426, 68.04621911817982, 73.45177865797474, 70.68704897357573, 68.19722252507364, 67.04814849361297, 64.0700497165803, 59.04941589601579, 59.73172787697085, 61.55744214211742, 66.20473692494055, 64.78694915771484, 68.9892981129308, 66.18627825090962, 66.71290351498511, 63.55936104251493, 62.23997377580213, 66.81038225850752, 65.17616987228394, 53.22826162461312, 52.092080423908854, 49.8954786023786, 52.34902312678676, 50.12025786984352, 56.333696226919855, 65.2883614263227, 70.49355845297538, 68.31465044329244, 68.18601239112117, 63.190469972548954, 61.36970181618968, 58.24846790682886, 55.702649624116965, 55.45962741298061, 56.2895695624813, 51.94074361555038, 55.35469224376064, 55.38291369715045, 55.36889514615459, 56.99882038177983, 57.23941072340935, 54.34464270068754, 54.6586048987604, 53.74350417044855, 57.22308581875217, 50.659301357884566, 57.14394023341518, 57.954274454424464, 63.39785745066982, 66.27567691187706, 73.00632292224516, 69.60918165022328, 72.90773022559382, 64.16698717301892, 2.9878294419857765, 0.5898991623713125, 1.232528217857884, 3.6840204846474434, 12.444441087784307, 4.65081952271923, 1.7151106581572564, 37.844796411452755, 37.53790624680058, 50.95552659803822, 31.058482162414062, 61.702801258333274, 57.46543730458906, 1.685627304738568, 0.3104235153765448, 0.2953769969603708, 0.18005968161648322, 0.3052049857233801, 0.1960369815388995, 0.2671309674699461, 0.24345986184573945, 0.16947507377593748, 0.13318279217327797, 0.12682191817270172, 0.1531012773874306, 0.17173668790248134, 0.1449557096366921, 0.11076399515713416, 0.09377123036932561, 0.16491248392530028, 0.13695318582317523, 0.151009229162047, 0.12700943351392785, 0.10099210701281987, 0.13393479940151015], [0.09986653233007078, 0.007422182046162386, 0.04766034075028954, 0.03980276843292579, 0.08965100266880567, 0.015063381926607222, 0.04767567783053364, 0.15706815726814732, 0.05780562780977738, 0.055859844921337026, 0.023162088079017498, 0.02912197825348666, 0.05022486987253351, 0.04897071499257319, 0.03897138683485889, 0.08597188839508642, 0.034416465524343715, 0.06969723144486066, 0.012717876384305138, 0.016654508240941553, 0.10519046802073719, 0.021910112719201756, 0.024768095651280977, 0.029862044086199135, 0.023460174805574843, 0.1892410462061244, 0.040399129577581926, 0.16459647265653457, 0.5840015723820656, 14.536827495021207, 27.692768881397864, 31.19832446498256, 71.80911356402983, 14.574712687923064, 59.80357000904699, 12.607812708423985, 2.1757340767691216, 1.0028018610131357, 1.625389995113496, 0.512317254418327, 0.413776008231986, 0.07484739541166252, 30.816673924846036, 94.65517044067384, 74.1598919899233, 83.2567548751831, 78.90876831546908, 82.12522952787339, 73.02052974700928, 76.64716105307303, 64.2996927230589, 61.87397741502332, 54.24531652081398, 58.49219222222605, 56.23563697261196, 54.431844834358465, 53.83980228054909, 56.80768720565304, 57.81480281583725, 63.39168364001859, 68.26285162279683, 71.25641238304877, 70.81769527927523, 72.2944127359698, 65.56411581654703, 64.2598061407766, 63.47284140125398, 62.49947778640255, 56.40532655100669, 50.53581730011971, 47.29183281621626, 46.28698433599165, 46.77486442750501, 48.853238167301306, 47.14312399587324, 46.99513296927176, 48.600100163490545, 47.29090321448542, 46.58270359039307, 52.85658174945463, 55.10146402543592, 55.80352906257876, 55.88926815217542, 56.10117812310496, 53.8723030397969, 56.74674926265594, 59.74183582490491, 61.743468392279844, 64.43807002036803, 65.59436121294576, 63.26309657865956, 66.17422872974028, 61.591551073135875, 59.26841751221688, 59.0561153042701, 58.16975770458099, 61.00721205434492, 63.854229142588956, 63.89084054577736, 66.06128015825826, 63.250603829660726, 66.70800839701008, 65.4539325160365, 52.15195932695943, 66.7285773061937, 63.01847796286307, 52.07262546785417, 43.38580716040827, 44.603636418619466, 44.82013164028045, 45.9348927774737, 48.24871855397379, 63.5481430638221, 60.67838407331898, 64.73882167570054, 64.3340487633982, 60.114241338545284, 57.70405861639208, 56.02638244628907, 54.989739233447665, 53.93432355696156, 50.00812515135735, 49.65591199936406, 49.42630429421702, 50.74617009009085, 51.70733513370637, 53.363351975717855, 52.41720176512196, 51.0966181755066, 52.99190352039953, 49.20463154392858, 50.88976021735899, 49.46743034547376, 53.969220884384654, 47.045629562870154, 57.44261695492653, 59.1977285569714, 67.7592977400749, 65.96081256866455, 75.22006942379859, 40.76365955414311, 0.09503175910081595, 0.3664375967796772, 0.16831348529986798, 1.6969996041828588, 1.5326840406463993, 0.15639357088554293, 1.6828155781953567, 20.772795946367328, 32.47832329042497, 34.851949522572184, 33.00954949471259, 55.687764229313025, 9.794095562350366, 0.1226501327548777, 0.034088258135823474, 0.046266861289979956, 0.07750185176489816, 0.03861423664455933, 0.015385805351299145, 0.056618034479118166, 0.06988244852231396, 0.036835537532404546, 0.03499757385842743, 0.020205251076408935, 0.08216630832682695, 0.07570460183365692, 0.036963991325108275, 0.027214961329234705, 0.09356152146093308, 0.10630480419363707, 0.009511078298542528, 0.027703108724146604, 0.023445770437378558, 0.04825314341653739, 0.06537627338642074, 0.03606527442893675, 0.02141137032829706, 0.056829306206876234, 0.038284585180301825, 0.018271174011451584, 0.03463200436184003, 0.06396447293340199, 0.04128977573747116, 0.010712112641833242, 0.0682859672533889, 0.04141472467792131, 0.029816726155038324, 0.030234799487516287, 0.054676687239759394, 0.04313764492830923, 0.08770900042427164, 0.04221950387281757, 0.09303069913819914, 0.025336818258848884, 0.06229838491567682, 0.05441144844817539, 0.036457591885400396, 0.027386599498230125, 0.04385992411463972, 0.041605212440293644, 0.05561872640804899, 0.043622436858112776, 0.04081957395218554, 0.6413574721063338, 26.539866616649014, 37.98463675283617, 45.21172538880379, 81.63329370560186, 21.98043880924102, 77.65554751119306, 10.319915759947992, 0.9347845914383089, 2.8874621179796036, 4.230292410619797, 1.7732290298708024, 0.40540285108070223, 0.05746933819365598, 35.83265189201602, 95.75378710223784, 70.12211784239739, 83.76872616429483, 81.92379228530392, 83.65462441598216, 75.33224136598649, 80.9571712247787, 68.8170825281451, 64.62378640328684, 57.123712570436545, 61.724531189087905, 56.59565564124816, 55.1550514467301, 55.95152401155042, 58.312029915471236, 59.17735184392622, 66.34097653050577, 71.37732336598059, 73.72086109653597, 72.99249264501756, 74.89556389470255, 67.26386316360967, 67.4095792155112, 65.42420487250051, 65.0703521697752, 57.73820677111226, 53.285508617278076, 49.38872014322589, 49.26449867986864, 48.52464160611553, 51.756768764988074, 49.783938161788456, 48.962562468744096, 50.20334935957386, 50.844268568100475, 51.06423900973413, 55.396806732300796, 57.76318442436957, 59.25922739890314, 57.43321895599366, 59.868014550978145, 57.024558974850564, 58.17415468154415, 62.153936586072376, 63.765713014910304, 66.33295920587355, 68.43935828055105, 64.02705661712154, 68.29580737698463, 64.26403445582237, 61.55390808659216, 58.6724643553457, 60.20886851895241, 64.4361755155748, 66.08820330712103, 67.03881325260286, 67.28647170528289, 65.33263321845763, 67.24409441794118, 67.0131217279742, 54.88192504452121, 67.22776951328402, 65.72791007257277, 53.26788540809385, 46.492547911982385, 46.85738717356036, 47.46759814600791, 47.18429319320187, 51.64322791561004, 66.92560580468947, 63.96580488451066, 67.01116838762837, 67.84613901568999, 62.91905764610537, 61.91460140289799, 57.66516831613357, 57.87986316988545, 55.563578067287324, 52.14107474973125, 51.1649654757592, 53.83035329080398, 53.70146420694167, 54.96940958884455, 55.72360684794765, 54.72440658077117, 54.833389636008974, 56.3050982259935, 53.37697828969648, 52.42110844581358, 54.43626926791284, 57.369405915660245, 49.82371884007608, 59.05248318949054, 62.59690161674254, 70.4495886833437, 67.5935697555542, 75.32151760593538, 42.992883728396514, 0.15468095068729695, 0.9834900101827038, 3.602492794875176, 4.8942839810925145, 0.5021872125085324, 0.4264730269149427, 2.833191959127303, 27.42701849629802, 39.98184096428656, 41.94124529438634, 31.38782789630275, 67.27924669942549, 11.816296058316386, 0.14887472434389978, 0.04861626909264634, 0.01112801794548549, 0.03320853638973448, 0.08527991947748008, 0.04854693430505934, 0.04602372796545106, 0.04981913821651571, 0.005518785366157611, 0.03602018632415322, 0.06918345457844197, 0.04132379004130921, 0.003960399734487217, 0.02046784111899474, 0.007933460987142978, 0.04774778968684616, 0.08218455654118331, 0.05301622230739844, 0.062408575172265696, 0.024689362880082864, 0.04031132824058014, 0.06692328835807501, 0.2057341531279587, 0.16287593110915155, 0.1691053137784043, 0.2080617274247831, 0.16152649787404846, 0.19428835520821233, 0.09846396323653961, 0.21083305049086773, 0.11311905668868173, 0.14615289055772368, 0.23383297116285373, 0.08783483802671395, 0.12042152169611185, 0.11127774904091513, 0.11017687303284485, 0.21044426086929538, 0.13623271077390642, 0.20077745700555466, 0.10296647647215475, 0.10761140545289363, 0.1671413094886849, 0.09666593955649484, 0.09038554309236427, 0.1457555360731579, 0.10910438824324839, 0.30559890813404517, 0.1798771994729196, 0.2494369870832851, 0.7163484094123687, 50.04321075254872, 57.639786658748505, 47.258445601309504, 89.12855086788055, 25.841951447148478, 79.57937594382994, 15.582571587254925, 4.460532107660848, 8.874591973520095, 6.564460579426059, 1.4179775118827822, 0.55362906667494, 0.1702629492407845, 36.636726010230284, 96.48622697399509, 74.98367601825346, 85.66599230612479, 83.74229723407377, 89.00598464473602, 78.76031444918725, 82.28598394701558, 71.73418844899824, 69.13455916989234, 60.20458136835406, 65.9947253811744, 60.55165229305145, 59.757748880693995, 58.73404948942123, 61.89046313685756, 63.032527892820305, 68.1844199088312, 74.08518652762137, 74.20819990096554, 75.0677167215655, 77.29931000740298, 71.1322379881336, 72.44688310930806, 68.3485475663216, 65.93567017586001, 62.04097624747985, 56.085975016317065, 53.7328863143921, 52.85534228048017, 51.47655071750764, 55.31281309743082, 52.73071289062501, 52.78575943362329, 53.66822211973129, 53.483690292604514, 53.70793611772599, 57.57940961468605, 63.336303695555664, 61.63373224196896, 60.48734111170615, 62.87315414797876, 59.708636883766424, 62.7660773646447, 66.33224533450219, 66.84100812481296, 68.19170767261137, 70.66776660180861, 66.68827103030297, 70.98559625687139, 66.355481455403, 61.58567928498792, 62.76236680246169, 61.17495221476401, 67.626980504682, 68.69303364907542, 68.84478230630198, 70.07867367036881, 67.70846382264169, 69.20143558133033, 68.49530696868896, 55.66522236793272, 71.95204473310902, 68.47839370850595, 56.97181094077326, 48.81718766304755, 49.51135696903352, 49.488277742939616, 50.1590540332179, 52.76456294521209, 68.06062206145256, 64.71451867011287, 70.45268735577984, 72.13069300497733, 66.1898083840647, 63.70723047564107, 63.412248626832046, 60.06003810513405, 60.55037360037527, 55.74136341771772, 54.5476528136961, 57.006688656345496, 57.306742129787324, 58.98829360162059, 60.83167029965309, 57.64397967246271, 57.238406596645234, 57.695143068990404, 55.49765479180121, 55.511834159974136, 57.68782000387869, 59.962100444301484, 53.51921912162535, 62.86560750776722, 64.78550572549143, 72.7554089023221, 72.65392149648359, 75.94896347292008, 47.808354054727864, 0.34749067959285557, 0.7006129634476478, 6.701619980796692, 7.409029247299318, 7.665616485380358, 1.3337166655448176, 2.852288998903767, 33.7479043006897, 45.219009230213786, 54.107641327765684, 49.13719423355595, 77.23882705934587, 19.425399034254013, 0.26819622805041654, 0.24087377883974584, 0.15409766666350827, 0.2089622637797748, 0.24152769617015318, 0.10857266959764304, 0.179664901187343, 0.13213266949019126, 0.16106143653873475, 0.1655677648922128, 0.148084458684729, 0.2102907062057526, 0.13369979426985787, 0.11547668461477566, 0.08110611158753596, 0.2460847395442186, 0.20653044023821432, 0.0924604692526402, 0.18535583129813596, 0.09909437698943001, 0.2261557742472618, 0.17993002889617798], [0.06951355420413517, 0.032099899910991235, 0.05793098660726702, 0.03483332460746169, 0.05787171821500506, 0.060132091279111566, 0.05126301860136371, 0.03906305308543867, 0.030435526014996633, 0.0315115922656391, 0.057889027971654176, 0.021376727832361095, 0.02936442401410351, 0.04956490044752437, 0.04037072303734961, 0.08982731014369957, 0.05397986515515274, 0.011568174719990743, 0.0953344634223369, 0.041530591646029104, 0.005631454874791446, 0.062090958949298634, 0.04883783321166712, 0.020475580522249785, 0.03340464340703141, 0.051234447352227666, 0.0196819287544537, 0.09225187117173787, 0.04890045706903742, 1.7540518266539422, 32.2078013420105, 27.078831657286617, 53.94900891088671, 42.44735656246063, 24.854849730768514, 41.77132037378127, 0.46998905799081253, 1.7448884344870046, 3.6622866315226403, 1.5054434249478004, 0.5053449656453826, 0.41591314839259275, 0.08550833625298354, 46.903945707505756, 87.5378885576802, 78.99412693515902, 81.38714928780833, 73.06786491024879, 75.57448694782873, 63.73846038695305, 58.15485269792619, 59.23927822420674, 65.11976618920603, 66.6767627962174, 66.7772460752918, 65.87412818785637, 65.57139181321668, 62.9334488222676, 64.85509249471849, 68.95411445248511, 72.35824538815406, 74.32405887111541, 70.25347801946825, 69.74550754793229, 68.8812917278659, 66.72577673389067, 67.38460156225389, 63.27277306587466, 57.769879910253714, 51.15019382969026, 47.6829872592803, 48.79245319674092, 48.36012955634825, 47.286290507162775, 50.811877635217485, 47.83726584526801, 48.576083490925456, 48.19074200045679, 49.14366614434027, 48.42105965460501, 52.60747986455118, 56.89446572334536, 55.74341873968802, 55.633886552626095, 57.77214311784314, 61.83648740091632, 61.67702736393098, 61.42930615332819, 65.46294612269249, 68.6397207936933, 69.33703191818731, 67.75237083435059, 63.872468163890225, 62.84563087647962, 63.420313019906324, 65.2816737851789, 64.28929059736191, 64.23789185862388, 67.29605797798403, 64.61811857838785, 63.64771635301652, 64.86720085144043, 53.311270744569846, 60.922763424534956, 64.14508073560654, 61.975606026188025, 49.83162633834347, 43.0413132329141, 46.02249891527238, 46.20044116050967, 45.033940038373395, 47.40453035600724, 61.51548847075432, 64.30931821946176, 65.23036918332501, 66.76921306117889, 63.90898935256466, 60.79223086757045, 58.07942159714238, 54.51522265711139, 54.194533594193004, 51.701392742895315, 50.17901497502481, 48.56745819891653, 50.034659985573064, 53.58540911828318, 54.84783964772379, 54.2684781166815, 52.14106298262074, 52.28857940243137, 56.29215048205469, 55.7291530793713, 51.509631987540956, 53.932731074671594, 55.338351649622766, 59.87025814671671, 64.17975841029998, 71.2696699942312, 62.473954923691295, 77.2010075661444, 12.168763183778333, 0.46824872073146606, 4.01750284817911, 10.152337397298506, 4.671315868054667, 0.8214348963191433, 0.3929515934038547, 6.165162805588015, 36.49741126644996, 39.122892887361594, 25.513148961528657, 46.600742570815555, 36.92472604013259, 0.7038283876834378, 0.10423111909579846, 0.063211178677457, 0.03967257179019432, 0.03357689444636626, 0.07082556404413716, 0.022394138561081023, 0.059015249998699275, 0.017666366747430256, 0.08374277171829055, 0.01512578936413892, 0.039221824807745796, 0.052537107089113806, 0.0036144054601825177, 0.03902747596223508, 0.034816367251257745, 0.05031089388555096, 0.05242605115317049, 0.03709649772293145, 0.04190794357489194, 0.020040385124664155, 0.05427984986454249, 0.024396483636190815, 0.013195966002381137, 0.0022152856775304124, 0.015861888776623433, 0.0713849154811713, 0.0363686605687103, 0.04385649587117857, 0.024879444615855336, 0.04155109215888285, 0.08363178089982079, 0.1133868810270102, 0.02069467975337419, 0.023668271098886768, 0.010610279446888355, 0.03248316603862951, 0.008332866672126037, 0.005621411462104129, 0.07972817988164964, 0.05067685791741937, 0.07616845275005026, 0.07071674891537236, 0.07654021223706585, 0.05882927449420095, 0.02145218557768291, 0.038173590531392444, 0.01530662537627523, 0.05888633655324098, 0.07389543923519312, 0.09415596738577851, 0.12698237528844228, 10.521709938203136, 52.4932800569842, 28.672104304836644, 68.28660549656038, 40.471666551405384, 39.30574986242479, 44.02520056693785, 0.5375277984046167, 2.0713264663373274, 4.558162843027423, 3.746262125430569, 1.499162852283447, 0.3750064434303392, 0.04821380097118597, 53.266226245510964, 86.3486651451357, 82.58311133230887, 80.38695273860809, 76.14943581242716, 77.37163851338049, 67.33135146479454, 60.93931582666213, 62.09373997103784, 66.80332199219735, 67.80310277015933, 67.10525035858154, 67.99474193203834, 67.42511964613392, 64.58238970848822, 63.483047408442346, 69.95531512844947, 74.28241114462577, 75.44367590258199, 73.13664759359052, 72.62663748956496, 71.39542118195565, 68.75182997795844, 67.54845465383222, 64.86626340496925, 59.73250842863514, 53.97320209010955, 50.760439672777736, 52.1890139579773, 51.834066913973906, 50.856286710308446, 51.736941183767016, 50.6617763734633, 50.24874687194825, 51.071311043154815, 49.64059122147099, 52.47134616298061, 57.209788983868016, 59.772995133553785, 59.58674530829153, 57.03556514555409, 58.98307292692123, 64.208121069016, 62.04678135533487, 62.88865927726992, 67.19744174711167, 70.4829288298084, 71.39553885306083, 69.04166959947156, 65.8690526408534, 63.20238613313245, 63.587806071004565, 66.65167531659527, 65.13509088946928, 66.7011599386892, 68.04882357197424, 67.51072145277455, 66.32589109482305, 66.7154844345585, 55.86853450344455, 64.94900188138409, 67.16914576868858, 64.63295298237955, 52.314482735049346, 45.12211884221723, 48.220791278346894, 48.15336573508478, 49.10958466991302, 50.425575164056596, 64.96051796021001, 67.40828483335434, 67.31151211646296, 69.27767076799947, 65.23434646667974, 63.78172805232387, 61.265335390644694, 57.80601670665126, 54.50773093008227, 54.81032217702558, 53.79142768921391, 52.60447140662901, 52.38665042384979, 56.419572599472545, 58.92166037713328, 57.52396298993019, 55.21329079904864, 56.84501640258297, 58.510654818627145, 61.78325691530782, 53.992307955218905, 57.67133428204445, 58.599135644974254, 63.24041743432323, 66.43210887908936, 74.81815199698173, 64.33704937658003, 81.19462367027037, 12.609691523736524, 0.5751979963914041, 2.7104269208446627, 2.6053189221889745, 1.4608990280858933, 0.14349016811578505, 0.4635501196307521, 9.06746962378102, 41.56907120058614, 45.75339294249012, 30.35419902493877, 50.97044729417371, 45.921207627942486, 0.5929356897550245, 0.022443503351701845, 0.05610055740802519, 0.03322555503297237, 0.025150011548952713, 0.021370179695828308, 0.038533498638219414, 0.05813779204242653, 0.09771662914464552, 0.03867891361756671, 0.04424858733170456, 0.00852448824462631, 0.031011765860321543, 0.02552390842127704, 0.031974721144163804, 0.039080799512204625, 0.061591944597180814, 0.041107546402922565, 0.07185871021882181, 0.03544296588628523, 0.018145074023895206, 0.041626674393492366, 0.015526244589578242, 0.25380267701562376, 0.11661282365000057, 0.11512260643705247, 0.1628519219136046, 0.09046199866720746, 0.14842896842427794, 0.17661079974664798, 0.0797027764060805, 0.09409307922807433, 0.22549559031763386, 0.1452112306029566, 0.15051706363597225, 0.10130418058965476, 0.07560294962698415, 0.1674387048208906, 0.1462154799411374, 0.18567242479372412, 0.18641246572857906, 0.16286028759373775, 0.14371461655584075, 0.11792610519595685, 0.15668151269276298, 0.13421144907272634, 0.11752209340732907, 0.10246334822788354, 0.15167549582979373, 0.13950317076617672, 0.19896382045361305, 0.13863926873572413, 28.86262166884638, 73.37732422736384, 46.752875620319, 81.74556762941423, 56.067771296347345, 41.92141771316528, 49.30774281101842, 0.6500092401139198, 5.962923928614586, 9.924913471744908, 7.440613642815621, 0.7043479178701678, 0.732830883033814, 0.11437228460225368, 52.89799413373394, 85.95332945546797, 85.2033801232615, 86.39912251503237, 76.41377218307989, 80.39854726483746, 69.73374043741535, 63.75013728295604, 64.75296182017173, 71.27430623577487, 72.745391168902, 73.58568053091727, 69.85475340197164, 70.97144434528967, 67.99116473044118, 71.08184337615967, 75.076628346597, 77.85257600968885, 79.2817621846353, 75.32713444002214, 76.07436164732903, 73.754436585211, 70.14000385038315, 73.6424764510124, 69.0622228191745, 63.483973087803015, 57.03986014089277, 53.622820684986735, 54.86472152894544, 55.137977369370006, 53.279181834190126, 55.875226066958525, 53.29245121248307, 54.20313927435107, 52.94709044118082, 51.913283101974, 52.76481397690312, 58.62366222566175, 64.89944665662705, 61.849988199049434, 60.75446236518122, 63.177012320487734, 68.88878345489502, 65.57225473465459, 64.24414411667856, 72.05448919726958, 73.47625424785, 74.99995385446857, 71.98172923057311, 68.50858811409243, 67.72382382423648, 68.91009761441138, 70.7650492268224, 67.734375, 68.21919564277896, 70.79667921989196, 69.4224532958, 66.61444417891964, 67.24022696095129, 57.45229344214163, 64.84984044105776, 70.52103857840262, 65.14550478227677, 54.488323042469645, 46.77715116931547, 52.29465907619846, 49.9867521562884, 50.774666109392726, 51.569142187795336, 69.50596055676861, 72.1288259567753, 69.89204729757002, 70.33736967271375, 66.69206003988943, 65.53663961348995, 64.50369127335088, 58.35315596672797, 58.21376669791437, 58.244055240385, 57.202281567358206, 54.701637221920876, 54.671093725389056, 60.693657782769975, 62.20836339458343, 59.904869141117224, 59.749998277233495, 58.25911321947652, 63.461901910843395, 63.0372465041376, 59.812571848592455, 59.939366386782744, 62.655372388901256, 64.57788290516024, 71.37595053642028, 77.26818992245582, 67.02607339428317, 80.37137308428365, 15.759194935521773, 0.5315296976797043, 8.941044768979474, 23.895773349269746, 9.883880576779767, 2.1193115172847627, 0.8663538795325064, 11.519144158209524, 53.8046343095841, 51.7078411194586, 41.580399005643784, 64.01417555347567, 59.53461700870145, 1.45450139718671, 0.29427474965491607, 0.1652244962151012, 0.12250485184091715, 0.18590726138603303, 0.11064580311217617, 0.0656574659590279, 0.4105152009475616, 0.303650685255566, 0.16488544102157318, 0.15292788104664895, 0.15639818273484707, 0.1295454833175867, 0.131881132181133, 0.16445155946477769, 0.12651107033654568, 0.16340175853861919, 0.1900914038020757, 0.1336173632092053, 0.1373851674819185, 0.10659355805405688, 0.1541821968050734, 0.1363845647222573], [0.009351175638937182, 0.04843274506950571, 0.03977874008518073, 0.07132691496442403, 0.06093865928931102, 0.05095567178702162, 0.10415753635067133, 0.0265438127661905, 0.0808184915372441, 0.017791589564313332, 0.05661903805429897, 0.06357458397565831, 0.07222083231974995, 0.1047797299801342, 0.004111285539223783, 0.06918226714215933, 0.008846264325022217, 0.06199199571124008, 0.03586583875960881, 0.1054189843876708, 0.036259228739166455, 0.07201274751775688, 0.0700896523231941, 0.15035434656085508, 0.09387656745891418, 0.09741638396536151, 0.05259747864798673, 0.25607064967193915, 0.6449827840251308, 3.732922144474522, 32.30144596868946, 62.20846929857808, 52.12557354281026, 74.13926816755726, 21.399496563019294, 30.988803217487952, 3.5972051947347583, 2.1025531907235426, 3.9387419002671398, 3.7680177967394557, 1.639777494053687, 0.23752652619394565, 0.13472950837064174, 2.6360293646012587, 85.73550455031857, 78.3335841086603, 87.3206441633163, 73.83775557241133, 67.88036561781361, 63.31819803484025, 72.54760957533314, 70.13875653666835, 76.52434379823747, 73.51892179058444, 75.81652072168167, 70.76091504866078, 70.23458003997803, 70.0866517712993, 77.27890583776659, 71.02845991811445, 73.58947738524407, 72.25028607153124, 73.40826388328307, 70.73432137889247, 70.04067374813941, 64.36056398576306, 66.01507463762837, 63.87122085017543, 60.35745966819025, 52.095449739886874, 49.35527409276655, 47.0560787570092, 47.80956214474094, 48.45317209920576, 48.05548298743464, 49.256889281734345, 48.56113533819876, 50.4118037223816, 47.99024612672868, 46.95920013612317, 49.71816393636888, 50.04693308184224, 53.87058504166142, 58.917153573805294, 64.46437343474358, 64.31675503330847, 65.05494509973835, 61.95273076334308, 67.81577987055626, 62.46445886550411, 55.19424376949188, 67.77460282848728, 66.099060427758, 68.16258799645209, 65.93444639636625, 68.54818051861179, 66.30183127618605, 68.96978039895335, 69.38516724494197, 68.04162210033786, 64.53528596508887, 55.2686393645502, 66.93512147472751, 68.13967350990542, 65.93736463977446, 61.94143825961698, 46.48563669573876, 46.31517048804991, 45.48983320113152, 45.04788406433598, 45.34859257359659, 48.88364830324727, 62.25990726101784, 65.4387450987293, 65.15196100358041, 63.6097478097485, 67.00932487364739, 62.455037332350216, 59.719525383364775, 58.16357997155959, 56.64276330701767, 52.51755560598066, 50.0072112391072, 50.93518910869476, 56.42353811571675, 56.160370611375384, 53.985502642969934, 55.324733180384484, 56.91917665543095, 56.17657000018705, 56.22393262001776, 55.539608463164306, 57.85086116483135, 55.80739259719849, 57.41003774827527, 64.39015434634301, 68.43877776976555, 63.47262174852433, 78.67393601325251, 37.014626764482074, 0.19488417243044223, 1.0367942240930375, 0.8690889359962556, 1.4172329969944493, 2.7328064941590835, 0.443906307580971, 0.036119739449913466, 14.618325521869046, 46.25223213626493, 24.80158982738372, 29.931547949391028, 51.56212898992723, 8.309954039512142, 0.19189410061845857, 0.026394479247110508, 0.10806194176116299, 0.07691622351206119, 0.0852316712600089, 0.02702507877632255, 0.017957482073876648, 0.03033816581591964, 0.0484377552845305, 0.06806895752707798, 0.011503193227033462, 0.028465613272161256, 0.06649673826271488, 0.05921732867136598, 0.04646603265897401, 0.03882910132468228, 0.016372769830688354, 0.029410735944346077, 0.06898026507828506, 0.0681853109610177, 0.0616387602302336, 0.05369517156073163, 0.11359501945515794, 0.04636650251585149, 0.023282415594064423, 0.020022937472188668, 0.07255473174154758, 0.017287105344416156, 0.03817917148192083, 0.09392653171333576, 0.03780485709167777, 0.10143720409682683, 0.020126646624938137, 0.04748723935335875, 0.002790977530586984, 0.05280812984452613, 0.028375525162705494, 0.025910273374569033, 0.03549516328700608, 0.08025798330744428, 0.05869177703355109, 0.016466598364434416, 0.07430083764296386, 0.07942214307765808, 0.03212089646577595, 0.04928321374820606, 0.09665509175148704, 0.04133830740747433, 0.046624325576328465, 0.11073305286587247, 0.1895027265193001, 0.6955019312520182, 7.501081391688317, 57.10391636817687, 65.68279104848062, 65.76562758414977, 76.76502043201079, 26.884648838350852, 43.56742074412685, 2.6648651592193113, 1.8718755365379396, 1.4077876844713766, 5.345333016687825, 4.554793036753132, 1.2477337761271385, 0.8586920809841926, 4.850981504686417, 89.17582327319731, 78.35494533661874, 89.08018019891556, 77.52144167500158, 69.99833568449944, 67.82319315018194, 72.622267969193, 71.72625741650982, 76.98104104688092, 78.60974250301238, 79.41906867488738, 73.37100136664607, 73.05059079200991, 73.57210128538071, 78.8900193860454, 75.10271995298325, 76.46918742887436, 73.8901113694714, 74.58430028730824, 73.43615977994858, 71.45009117741739, 67.70116821412118, 68.30756664276123, 66.09277679074195, 63.192321331270286, 54.87637881309756, 51.18005875618228, 49.507230635612245, 50.528690353516616, 50.17520635358749, 51.737866863127685, 50.593283945514315, 50.060720212997936, 52.645644526327814, 51.16388290159164, 49.34233419356808, 55.11069728482155, 53.37182429529006, 57.467425946266424, 59.16442371183827, 65.18361845324117, 67.29213560781172, 68.19105655916276, 64.7247285996714, 70.03952057130876, 66.68230902764105, 60.56682402087797, 68.15728495197912, 67.44351556224208, 68.5495533481721, 68.17746162414551, 66.37499132464009, 70.74700632402974, 69.46586608886719, 72.61815732525241, 67.67408032571116, 65.94846494736211, 57.74623194048482, 67.49244320777156, 69.90728178331929, 65.70261862970167, 63.326321263467115, 49.56266941562776, 48.87426991616526, 47.7077531045483, 47.042315160074544, 47.66323812546269, 50.33427023118543, 64.0454525332297, 67.26329049756451, 66.83789376289614, 66.34229444688367, 70.3399270580661, 65.01823955966582, 62.28291196207847, 60.009819999817886, 57.724953082300004, 52.94143830576251, 52.2516385201485, 53.07938021998252, 58.02752079502229, 57.979197194499356, 57.06280208403065, 55.7929386631135, 60.12995827582575, 58.85081060471074, 59.59361337846326, 58.12614879300518, 61.802688337141475, 59.35320738823184, 59.502684993128625, 66.81725425104942, 72.54468348718459, 65.70258332837012, 82.97643092370804, 37.72079067845499, 0.14262022931248913, 1.4277887079984912, 4.750215324663348, 2.775133280984817, 2.59458486591616, 0.19175718538463118, 0.045139018986975, 19.150315369329146, 54.55294016868838, 35.44698484482304, 26.47209982718191, 65.73382108442246, 11.4271665388538, 0.11840746888229925, 0.09445081930607559, 0.04773169417955703, 0.07794039113627327, 0.08890304038481367, 0.05738828609126711, 0.06945176155216272, 0.006895675192466907, 0.027772755692562753, 0.01714871922177413, 0.011955926292425683, 0.03554746027915709, 0.0654442943332176, 0.03814710687185007, 0.022498108183724747, 0.02491359681551976, 0.05475334582790252, 0.027489305075798786, 0.030074351947874795, 0.01467875503529344, 0.08453823145358794, 0.04445333199034776, 0.02423465522306581, 0.11553265499852358, 0.10583824132599177, 0.11179349475329924, 0.17702103983010017, 0.17648755152138973, 0.34180223160693723, 0.39024803847555195, 0.2425305205847948, 0.2579951544682826, 0.11459506297063445, 0.22867310852293046, 0.26738383777199254, 0.11430184281761609, 0.21005151823403376, 0.1272117343520926, 0.21179807612732535, 0.1440410159768597, 0.1500170227260359, 0.10268562863911353, 0.27805256206662426, 0.20577949021131764, 0.14819782437576404, 0.16255982790983495, 0.3505711497799043, 0.23604868130097467, 0.12365351641370405, 0.2929468434904852, 0.6175313409297698, 1.4183565109006822, 14.172140225287407, 78.60244689449188, 76.77439489672261, 70.34457114435011, 98.99407279106879, 33.57437864426644, 42.156171567978404, 4.679073825959237, 4.294394235457144, 12.294780112081959, 10.056788459900888, 4.2781575841288415, 0.33807371232298117, 0.7056255073797318, 4.504700937578756, 91.42873856329149, 80.40737259772517, 94.25232733449629, 81.18029917440107, 73.0006197960146, 70.07544948208717, 79.35553412283622, 76.06451649819651, 83.55023445621615, 78.56975001673545, 82.79397010803223, 74.78373712108981, 75.86663292300317, 76.48851686908354, 83.09453348959647, 75.9392987528155, 80.56059606613653, 77.77129665497812, 77.318066781567, 76.05787984786495, 77.58627060920962, 69.47305187102288, 71.01713995779716, 70.75347039007372, 66.89873756900911, 57.84286345205, 54.29218099963281, 53.09232011918099, 53.42039108276368, 52.84932536463584, 52.409219741821296, 55.93153561315229, 53.54282786769252, 54.8467335393352, 53.04195688616846, 51.58674970749886, 58.86405252641248, 53.669814602021255, 59.94950571367818, 64.58313495882096, 69.92923921154392, 70.67616047397738, 70.02722786318871, 67.9394914257911, 73.62390010587632, 67.27402994709631, 58.77189251684374, 70.7023540619881, 70.4777277669599, 72.30359108217301, 69.46224966356831, 71.74263723434942, 70.82573613812848, 71.97080150727304, 72.31905306539228, 69.94355586267287, 65.74958116777482, 60.56216816748343, 68.15243690244614, 70.12894276649722, 71.09558736124347, 65.0096534913586, 50.743628394219186, 49.98269250316005, 49.74577742238199, 48.87546623906782, 49.02566948244649, 53.8233361705657, 66.3906180474066, 68.99503261812272, 68.96727792678341, 69.25678022446172, 74.65329477863928, 66.71086388249552, 64.07653731684532, 64.16625761216687, 62.540776421946866, 56.74879673988589, 55.41651664241668, 55.36666723989672, 60.6477346727925, 62.87887688606017, 58.95227055395804, 61.20678224871236, 62.81889992375528, 61.61199054410381, 62.9599012867097, 62.80835267036193, 64.3191869028153, 62.946655442637784, 63.62375851600402, 70.97463715460994, 71.7620921904041, 70.75022266757104, 81.5931757034794, 41.2607297589702, 0.2650545014729423, 2.537136116335469, 7.263330846063553, 9.595063713289077, 8.270470480765066, 1.3057544563085803, 0.10910012113351016, 25.64558190684165, 62.81505207861624, 40.162328827765684, 44.16209520832185, 74.94627229629025, 18.55585467430853, 0.49935538381818806, 0.26437963929868513, 0.31673558957634435, 0.3090733620187929, 0.2481950206622001, 0.1380333544746522, 0.21479346458950352, 0.1998925182007013, 0.29916104229707874, 0.21170864302304485, 0.19612998461290715, 0.10835182177083147, 0.14118369188039534, 0.24837008707465666, 0.22306376677607337, 0.1218604876269256, 0.17910199510234018, 0.16010739660311132, 0.17372419576971762, 0.08031239087182669, 0.1765705341653478, 0.0947853928852466, 0.17316777078855425], [0.046575437675440506, 0.043154479710445295, 0.04152777627290737, 0.035526772074761896, 0.14419745113099777, 0.06401123494030007, 0.0444517461883445, 0.08855424821376802, 0.043790623801009315, 0.02871620637785283, 0.08320395143762713, 0.06955737443340403, 0.030392203742878574, 0.05283431089933842, 0.04953094360028063, 0.047907733523677436, 0.04768780883281462, 0.03884626552462578, 0.039340365422709335, 0.07281709387297593, 0.01271968435180644, 0.04279148043884386, 0.013342458292871956, 0.0608907443200869, 0.048388017026046594, 0.07037229280197813, 0.09714884307956505, 0.044463624381610466, 0.08707593600716322, 0.20643878547895342, 28.172496326508064, 60.198874319753344, 51.108251925437685, 53.499007148127404, 51.12462389853693, 22.971192252251413, 20.93446820012985, 1.2642104274803594, 1.8404088121268058, 3.1512182229949586, 10.772208186887926, 1.828596839501012, 0.3496337952392717, 0.5632574435683989, 35.06086280269008, 96.79152073398714, 77.66839719587757, 80.01123674454229, 73.93714843257781, 71.35251829701086, 71.99419452298072, 75.38854306743991, 78.38636352169898, 76.02906611657913, 73.35491964893957, 75.48762213799262, 74.15861329724713, 77.78064758546891, 73.54324833039315, 74.54950101913946, 75.59139236327141, 73.60116604835757, 72.78942369645642, 70.3096071366341, 70.14471853933027, 67.93480811580535, 64.54470749824279, 61.4727738595778, 60.05710809461532, 54.22128808113837, 50.240592264360004, 50.03449132365566, 47.37628144602622, 50.28232236062327, 48.75389237557688, 49.90077380211123, 50.519939545662176, 49.05107075168241, 50.690684241633264, 50.63300971061953, 51.08438822530931, 57.47901655012562, 62.16053401270221, 65.26076755216046, 65.18073158879434, 67.32393818516886, 66.99278031626056, 63.16513930597613, 69.717070364183, 52.45020458775183, 46.737507773983864, 69.21606602207308, 64.86519652028238, 69.83270968160322, 66.41852963355281, 68.94247285781368, 65.46723327329083, 66.46246017948275, 65.72621560865834, 63.006906970854736, 59.23754061422041, 71.3998769944714, 65.65657000387868, 62.382642146079775, 62.751164513249556, 54.145201944535785, 44.9978816893793, 49.423209544151064, 45.42010522657826, 48.66590576787149, 46.7160798657325, 50.313866061549035, 57.30186662366314, 66.48337425724154, 65.16863499918293, 66.95005001560335, 62.933135032653816, 66.26581607326385, 62.74226465532857, 58.84730792814686, 54.736381576907256, 50.453569119976414, 51.399962517523, 54.683598241498395, 56.77291931644563, 57.60328508192494, 57.45800441311252, 58.06616790833012, 55.8651416532455, 56.13718155891665, 60.879334941987075, 57.934768507557536, 55.0827347078631, 58.676045479313025, 63.10073398774671, 67.1377746520504, 71.13142997987809, 69.61515149762555, 66.75446494933098, 1.995029379763911, 0.18848150067271727, 0.4683214377972388, 2.9100005472860033, 1.5442275760635253, 0.919466510174736, 0.2043799548259666, 0.19157554593778428, 40.79035520553589, 38.64147293952204, 19.997949369492073, 54.0072992540175, 34.78269615480977, 0.3639878008154131, 0.048076632928343556, 0.12413382289871094, 0.01582869035642474, 0.07336205051791284, 0.04863532552976282, 0.03432559983564481, 0.037904563435022874, 0.05004232261149634, 0.009493067571442694, 0.020970126666549235, 0.025192186604404164, 0.04088289878000656, 0.03760427229046341, 0.03012874419049871, 0.006442409217162359, 0.02605494524862978, 0.1055165763283449, 0.020289919113800414, 0.01731564020437579, 0.015821816632524133, 0.06680646761050148, 0.050572777212026625, 0.05589737556874753, 0.027613087647384214, 0.010788901464923496, 0.05409797293043906, 0.04111033113252732, 0.03637377420560487, 0.0760220073824448, 0.016126315515007705, 0.05156438226901716, 0.09108095940562988, 0.013241914998469575, 0.09871455059657175, 0.1159004997762461, 0.02523601257933244, 0.05682928705467813, 0.016770361802510677, 0.031501533531193296, 0.11292748108145692, 0.11376935042320721, 0.02449474398857884, 0.05179869409109797, 0.01254985702314204, 0.04895355462306931, 0.02608597947044238, 0.07574079948807917, 0.06660219792637133, 0.052613842286049366, 0.09314775737302919, 0.026406702179942402, 0.05540760789787578, 0.5656723365668328, 42.33448643838206, 72.75741715585032, 52.327646209347634, 79.1669544096916, 47.20375207162673, 34.53757547563122, 25.46962045854138, 1.5965961208266597, 0.9719412040806586, 3.0398501215442537, 8.132932570672805, 5.855846164687987, 1.4927840977907183, 0.9481023252010347, 40.72239229756017, 97.24445250726517, 82.25469912252119, 81.35295406464608, 77.14261131901895, 72.44527493753742, 75.62408924102783, 76.1578453740766, 80.94677694382207, 76.97685195553687, 78.05919862562611, 76.48851686908354, 77.75771740944155, 77.3227422468124, 77.77677228373867, 76.95455720347744, 78.45576593952795, 74.87670513891405, 76.00357071045907, 71.7479245893417, 73.78116361556515, 68.40342936977264, 66.0200168240455, 63.246822664814616, 60.883029814689394, 57.122163234218476, 53.67279560335221, 51.83270585152411, 51.02208921986242, 51.70040038324172, 53.182338514635646, 51.88427325217955, 50.854164708045225, 50.789394609389774, 53.72891295340754, 52.06958563097062, 53.45420583601921, 58.83736864213021, 64.53941622088033, 65.32520817172143, 67.99096861193257, 67.5878038714009, 69.58469821560767, 64.37668884954145, 71.73079167642902, 55.92545986175538, 48.177217668102635, 69.54614131681382, 66.67512324548537, 71.35183580460088, 68.26388712852233, 71.29190983310824, 67.94579075228783, 67.81670554991692, 65.86837014844342, 64.5439975492416, 58.923966730794604, 71.69213279601067, 69.38886996238463, 65.49240312268658, 66.46307206922963, 57.95955788704657, 47.61167856954759, 51.591770341319425, 49.2579875453826, 51.06284656832295, 49.92158982061571, 53.36293228210942, 59.69764248017342, 66.83137478366976, 67.07183960945376, 65.08290767669678, 65.07274481558031, 68.31130858390563, 63.62853988524407, 60.78710825212541, 58.268299410420084, 54.18241739273072, 54.422717478967485, 56.68816474176223, 58.651707172393806, 59.080049607061575, 60.886893349309126, 62.28859155408798, 60.75472516398276, 58.897435818949056, 62.606244702492994, 63.02032539921423, 59.26939418238979, 60.684793226180545, 66.62499535468318, 68.49027849012806, 72.63792607092088, 74.06834387010144, 71.3891375449396, 1.7923849051998508, 0.3722844717483367, 2.3764927492987726, 2.043177454221633, 1.0330962870390186, 0.06327821137083155, 0.18394261358245728, 0.9169538643571639, 43.31555751062209, 53.54853491629324, 22.237958100534257, 56.275362737717174, 44.391342055413034, 0.27250645321703726, 0.04736313310962531, 0.060652808902124246, 0.03284547200065947, 0.0761577198582311, 0.038356585953865326, 0.01112426315704661, 0.013979391453997984, 0.10322400458878088, 0.09382820432825435, 0.04441965476519639, 0.010276659647183073, 0.05343040008278144, 0.10289909903921428, 0.059326358304749575, 0.04964480724846644, 0.044819196430786, 0.048710134015568805, 0.018122037760012092, 0.02320950892153046, 0.03279650366053947, 0.05417808274468107, 0.03576694446946344, 0.036333198358695355, 0.21188806081491135, 0.16737732585639725, 0.13202281248184944, 0.14126318116341868, 0.19254562775454215, 0.16637051778454937, 0.17126834771085173, 0.12854909404150902, 0.12777545249029515, 0.13464932960848655, 0.2168885158795503, 0.22514254635860845, 0.12820387950106976, 0.11209682726691808, 0.17817744955180154, 0.22804009007109752, 0.2299621280643248, 0.16294576768432895, 0.18750631671038367, 0.15068666018064947, 0.11327972064816183, 0.06971341888270072, 0.10094529137976709, 0.1678715904633845, 0.17698757710956758, 0.12125657285533606, 0.22364567184159834, 0.23719283361588758, 0.24427396816111382, 0.6723291198572805, 61.72840256844798, 81.81176154844223, 65.69504845526912, 72.50232973406392, 66.20774930523288, 36.36963221334642, 27.395900372535955, 2.0682917775646334, 7.427263365637872, 7.292020042096415, 24.92340491664025, 4.159004803626768, 0.41590950181407316, 0.5905717262817968, 38.32434146634994, 100.61552570712183, 84.49172096867716, 84.51565527146863, 80.68165609913488, 77.34943789820518, 78.48537198958859, 81.8508989580216, 84.42818641662598, 82.38725954486479, 80.75917782322054, 80.85845301228186, 80.46719658759334, 83.60503781226375, 80.49335879664268, 80.00239572217389, 81.14176580982824, 76.6812542946108, 78.08767503307712, 73.98085932577811, 75.57732674383348, 72.70068399367794, 71.29712658543741, 67.00370803956064, 66.33249636619323, 61.13223760358749, 57.57842902214297, 55.4886882535873, 53.017948058343705, 54.69272951925955, 57.08876425220121, 56.212228267423576, 56.64638757705689, 54.30286945835237, 56.19667999206051, 56.69545250554239, 56.094745436022365, 64.26858440522226, 68.48905471063429, 71.55854471268194, 70.84892519058721, 72.57104181474256, 70.99933239721483, 68.70588333375993, 74.80306656129899, 59.65685375275151, 50.83536086543914, 69.40915646091585, 68.10886721457204, 72.30210058150753, 71.7316859768283, 72.56833537932366, 70.52765953925349, 68.07039660792198, 67.34532294734832, 64.98390705354753, 63.70786982197916, 71.08287888188516, 68.62621999556019, 68.74279283708142, 68.64606718863212, 59.482116083945, 49.29852131874331, 53.492515625492224, 51.62892695396177, 53.285598831792036, 52.81049389992991, 55.86622030504289, 63.59468198591664, 73.16637131475633, 68.54639191781321, 67.45821660564792, 65.94136545735022, 72.34017895114037, 67.40809655958607, 62.98847183104485, 60.26324433665122, 56.431076911187944, 59.85022660224669, 60.18613053906349, 62.08959010339553, 63.54295376808413, 63.70797572597381, 64.28328937099826, 62.09460681484592, 62.91940281468054, 67.38959866185343, 65.15521657082343, 60.918182096173695, 64.60428830116027, 68.6326369931621, 70.37205126977736, 77.24740136054255, 77.27408132245465, 71.40227748501685, 3.557068316205856, 0.5015603993688861, 1.7399968711599227, 10.037985597887348, 7.064070518939727, 2.006269544363022, 0.6979554350818358, 1.3923775500828222, 58.00760299928727, 51.85548697748492, 33.9420106334071, 70.2757727715277, 57.74403541318832, 0.8817261385340845, 0.2661988836142325, 0.16389272896753204, 0.13901425345290092, 0.14835487240024153, 0.15616299374209297, 0.0703539220135539, 0.11295836974656391, 0.21324173817711495, 0.15471147163020027, 0.13543374235591582, 0.09635981082195237, 0.08960153637153488, 0.1935771651445858, 0.1492959041629107, 0.179014369965561, 0.06067160869978609, 0.2656629897894398, 0.12936370597491342, 0.06773266791095657, 0.16930976732363626, 0.11395422276109458, 0.18351509055543333, 0.13906758849418935], [0.023239868985969695, 0.040606352530660174, 0.0036421708805832054, 0.06547989443905892, 0.13879403381818725, 0.07579189755262868, 0.042221511023179184, 0.022617167823256987, 0.04867108651406823, 0.01979187003246719, 0.014062982180245943, 0.012072112144631966, 0.03833715413366595, 0.1246207100789874, 0.07142056155228807, 0.029571045588161197, 0.0377772472828867, 0.041832051074673096, 0.014998476084832464, 0.048402296904955185, 0.025119777889020985, 0.04844576856421848, 0.07766160407974836, 0.003534575507435347, 0.14806872323876427, 0.05280756293946216, 0.006471642653547949, 0.10196579710370111, 0.15835559866841764, 0.39564114424490165, 7.013436642385299, 65.85194326216175, 56.29589634556925, 27.157457528575776, 62.7255985044664, 41.159775795475134, 15.433582317444587, 0.10139103197763044, 0.4647951963688097, 1.8294893012892817, 4.117678221194975, 23.72712123778559, 1.9710866193617544, 0.08401207460631287, 3.072150349617005, 87.01491109786495, 83.58604569588938, 86.4920199301935, 74.23702147699173, 79.29775761019799, 75.42638609486242, 80.8508671483686, 76.22651038631317, 77.88725760675247, 77.85787120942148, 76.71907378781226, 71.43153836650234, 77.51255358419111, 75.6527853012085, 77.94040572258734, 73.20463795815745, 74.41269659226941, 72.84269732813682, 71.62935918377292, 69.75815326936784, 64.66061353683472, 62.723817748408166, 62.77491446464293, 62.11994532615908, 55.438046532292525, 50.55377391076858, 49.65429990522323, 47.53212113534251, 48.004672604222456, 50.122246511520885, 49.14306994407408, 50.46153937616656, 48.67960268451322, 50.32954377512778, 48.93276030017484, 55.40605960353729, 61.38781924401561, 68.19727743825605, 63.711246982697524, 68.36033036631923, 64.78747867768811, 70.15938035903439, 62.56923321754702, 69.88533219983502, 50.17986220698203, 53.73535348523048, 71.42878486264136, 64.26929827659362, 71.98977008942636, 68.43638512396043, 68.81352101602863, 67.15103226323282, 70.61310445108722, 63.8984146425801, 61.93386024044406, 71.30728552418371, 68.87387844824022, 65.62397510774674, 64.62735576014366, 63.03205720839962, 51.29589811448128, 47.61975865210257, 48.52477104433122, 46.8311269052567, 47.50344860938288, 48.59404794631466, 47.90597008120629, 60.21630533279912, 66.47812612595098, 67.92945800289031, 63.898100852966316, 65.97670601260278, 66.00662585227721, 67.20481580303561, 59.12099130692021, 56.36473001972322, 51.34479830341955, 50.87253708993235, 59.8105675174344, 60.28994391041418, 61.766586842075476, 57.42411513482371, 60.09286442110616, 60.43359287323491, 62.69103065613778, 56.33681843357702, 60.205487435863866, 61.45566840325633, 63.48621668354158, 63.983965458408484, 74.2643133286507, 64.87661453985399, 80.05786588115078, 21.69827526615512, 0.751979832928027, 0.3698660853889681, 2.41685712529767, 3.921148354007352, 0.5632693945400177, 0.5967205931102076, 0.11364676103356386, 7.6129576852244725, 55.401246855335856, 23.3000986806808, 36.76933350101594, 50.84832429885865, 6.56983079448823, 0.15099854989638253, 0.07860344023473802, 0.04271810453745627, 0.05745196714997292, 0.035034660174841845, 0.03347292099328291, 0.05561025730604607, 0.088268390165702, 0.052642176047928875, 0.004172340831569126, 0.03680002552667453, 0.039320224971180005, 0.05141495298894663, 0.017185751912033847, 0.034543084536468795, 0.058342582666345184, 0.04714665198398214, 0.05325273663226155, 0.04241857948082109, 0.0209885185223914, 0.07993480145570733, 0.01646375809345515, 0.05809187656268478, 0.05997987343899666, 0.06804903924104667, 0.038979151135971474, 0.03466014277129885, 0.037695597631916884, 0.11398527230466567, 0.08254677057266235, 0.009272913054202594, 0.00733911800536237, 0.04919242466829958, 0.07166444564298277, 0.012425493182344063, 0.030566446610816547, 0.04603337301241775, 0.04606812659110274, 0.0753421426540421, 0.05049226903206399, 0.10334963534748363, 0.048252067063003785, 0.035735102024890726, 0.03968474492731114, 0.05001692296636682, 0.028114589870036132, 0.032832724297599446, 0.01657160412099573, 0.0623062564690988, 0.028867384253610528, 0.022074024891480807, 0.06240250009502615, 0.18806891636021678, 0.35650624743392395, 11.968749761581423, 81.89112678650888, 48.15993570512342, 36.28484233733147, 78.31771419894311, 39.65266781468546, 24.850464520915864, 0.1492296528792189, 0.18781535657903842, 2.7272281483296426, 3.948431870629711, 10.111793818012362, 4.433659459314039, 0.7756803869720429, 4.9890293229010805, 89.5337160172001, 89.34479898022067, 85.55112961799868, 77.95440073936217, 82.35800650811966, 77.51676620975618, 80.05685390964632, 79.83271398851949, 81.20660258877663, 81.267501308072, 78.59524542285551, 74.56915209370275, 80.35271044700377, 80.27379235913678, 81.06359297229399, 76.57318515162315, 77.43474160471271, 75.65335796725365, 74.60970155654415, 71.12300472874796, 67.60982405754828, 65.37602639967396, 65.8060868324772, 62.68628458822928, 58.01042710581134, 52.154371584615404, 51.52607848567348, 50.71063733869984, 52.551115405175, 52.665860422195934, 51.73005350174443, 53.52665985784223, 50.75802741512176, 52.34675991919733, 51.580269951974195, 56.52815557295277, 64.8503738834012, 67.52618343599381, 67.12254801104146, 70.2309008567564, 68.92963886260986, 72.54416573432185, 66.03417658036756, 70.50079914831346, 51.916793623278224, 53.19379575790898, 72.01718745693084, 65.42994330006262, 72.36902406138759, 68.09053405638664, 70.32671651532574, 69.26732355548491, 70.6466720950219, 66.95022259989094, 63.7608531982668, 71.79369864925262, 70.80424154958418, 66.39607014194613, 66.76524362256451, 63.365576344151656, 54.84573725731143, 48.236582740660644, 50.354282163804584, 48.795693074503255, 49.76764071372248, 49.14771010798793, 50.968564556490996, 61.42909434533889, 69.06584708921372, 69.65617164488762, 65.07618473422143, 65.85514391622236, 69.61281376500284, 68.99232618270382, 64.98336968883392, 58.38630783942438, 54.20159778287334, 52.8681605862033, 62.46214074473228, 63.57465436381679, 64.90114112054148, 59.45192952309886, 62.36627017298053, 62.15106541110624, 66.83610516209757, 58.833273687670314, 62.56103546388688, 63.85882223806074, 67.44679466370614, 65.66609351865708, 78.47478159012334, 66.41365020505845, 81.76053539399179, 22.054610829199515, 0.8193343445178002, 0.9782380790960405, 1.6364455631663724, 2.656615924450659, 0.9379193006503967, 0.19660886617437487, 0.08582409471273424, 9.581393272646013, 68.2997375918973, 36.332612883660104, 33.13975649495279, 65.87976071142381, 9.378571433405723, 0.20875106866080917, 0.06062446364892587, 0.016682661972158862, 0.09072197826519128, 0.013421800103969874, 0.01473820824626713, 0.044235173132150404, 0.028280756256032376, 0.03039446178703539, 0.03301239489848095, 0.05747745872565335, 0.025264091616977128, 0.029177693912999767, 0.027129707234581153, 0.030901328540377082, 0.03971232409258524, 0.013985154350408384, 0.05304983441507625, 0.02856910983551174, 0.04203265119764594, 0.036664297729129755, 0.025084357813841877, 0.0433306263068751, 0.03322895646335618, 0.1547396636658138, 0.08545411254970298, 0.1774781798162768, 0.16936464986253172, 0.18204907406001322, 0.18767859456279587, 0.09166942984466592, 0.15558223780845443, 0.1466224105247567, 0.2172438121370731, 0.13368321612717646, 0.17490669844612, 0.10486529434039708, 0.14512195071626097, 0.0942585159153227, 0.1023938104269966, 0.13356324675823414, 0.14230026503003415, 0.16176576245455973, 0.08163226843481103, 0.12542085061150213, 0.2045098526944076, 0.14742275790101098, 0.15482499053882015, 0.30149243171176604, 0.19798250778788523, 0.13026939044075628, 0.3273748348076498, 0.28632922278296563, 0.9298724356678225, 17.877582734630955, 94.98712847309729, 69.20488726708197, 41.937456284799886, 81.16676699730658, 59.111887485750266, 25.53045249754383, 0.30863856115648824, 1.9756523808163984, 6.918456938958938, 16.298637524727855, 43.403391145890765, 4.438144199309811, 0.9812004491686822, 4.377376879415205, 91.8005008082236, 88.97922623542048, 93.58688939002253, 79.39571488288142, 86.7044476539858, 80.1834366398473, 86.24580490973689, 82.76869435464182, 84.13868411894768, 83.84017605935374, 82.44309840663787, 76.58501502006285, 83.32546695586174, 81.3146403528029, 82.81488418579102, 78.22460497579267, 80.7656732682259, 74.96685689495456, 76.3552111964072, 74.01537618329449, 72.33020828616235, 68.40655942117014, 69.205365796243, 67.02111551838537, 62.37812357564127, 56.29181315821987, 55.71221628496724, 52.113865267845895, 55.46524424706736, 55.856010375484345, 53.729364025977354, 55.47780759872929, 53.52887599698959, 56.26665507593463, 56.09834617184055, 61.752329026499105, 69.11724582795175, 72.55472475482573, 70.99351159987911, 72.51306918359572, 71.4585634969896, 75.71795155925136, 67.88034208359258, 72.99636794674781, 54.28115521707843, 54.19134470724291, 70.86172780682965, 67.55717016035511, 74.53967155948763, 71.04977407763081, 72.36356412210773, 70.12076070231777, 74.05529022216797, 69.31653361166678, 66.70319957117881, 72.9975603472802, 74.26996154169883, 72.62033816306823, 68.04149658449235, 66.86156918925624, 56.60774438611923, 51.37295307651643, 54.37821426699239, 51.80333906604398, 52.57885440703362, 51.93227521834835, 51.92901180636499, 62.96400408590994, 71.53423386235391, 72.36878087443691, 67.48415916196763, 70.77708305851107, 73.42645583614227, 73.7591669636388, 65.06506089241275, 62.852251837330485, 56.09829910339848, 56.330644622925796, 65.49875736236572, 66.80717375970656, 68.7791375190981, 61.877248671747026, 67.14154797215616, 65.8782466765373, 70.05853622190415, 61.25910666681106, 66.29858355368337, 67.31884694868519, 69.93031394097113, 69.89690319184335, 80.08478903001355, 67.9442531831803, 82.17954651001962, 26.035281150571763, 0.9187642833398235, 0.7579811818657384, 5.584200457219155, 10.577924366920225, 2.44786101002847, 1.2743539218941045, 0.2666563606790958, 14.037069486033532, 74.07606309460056, 36.022765251898, 52.19035540857623, 76.72652629113968, 18.003098580145068, 0.5039265691753357, 0.21873032914534693, 0.15813755472340893, 0.1402819297847248, 0.14156275218532932, 0.1394594424674588, 0.09318024716189793, 0.14415081169816757, 0.18081141305306267, 0.23520774658649202, 0.12711280175755102, 0.11815631461720313, 0.1979047038982953, 0.19700266601097202, 0.1175802854460574, 0.27318949721032576, 0.15010588892525242, 0.12840701537507196, 0.1393616896483206, 0.08712257543999342, 0.20474828989996066, 0.14167818631375992, 0.2006222782356124, 0.12232696622489922], [0.04465243824186825, 0.03541343319680422, 0.058345777252989436, 0.06277021846824116, 0.054615607049556515, 0.025833953780332403, 0.023344127806804837, 0.053493054583668716, 0.03926034753901824, 0.08332925277852243, 0.03324484895734537, 0.048784942501374794, 0.05139678521382232, 0.043206688602485006, 0.02458649259361048, 0.02657192244735216, 0.03841799173143603, 0.06909112566180768, 0.047713955413670316, 0.051491182567852165, 0.06649626328820182, 0.024002986404323773, 0.053362068870375236, 0.04797901417459211, 0.042737789166670655, 0.005255764877919349, 0.016062545398580694, 0.05546181244895824, 0.07140618974282857, 0.04096554434527794, 0.09619680263342396, 31.16890668869019, 68.57469574097665, 40.67393141408121, 35.38984375615274, 63.96595393457721, 15.563057795647653, 1.1495058599018282, 1.1129922708196025, 0.7608230003426153, 1.5455358090900606, 7.688985966867016, 6.108853259394246, 0.22138140705083648, 0.06554047667211102, 23.373011619813983, 104.89232124820833, 77.43626348433956, 89.42217949898013, 73.90160391407629, 78.91848794875607, 71.65490165833505, 82.31563706551829, 77.70259241903983, 75.31704610393894, 75.96772809182444, 81.21823633870771, 78.20359676114975, 79.67729399281164, 74.4249971451298, 75.58739939043599, 76.98628917817148, 77.42908554692423, 72.18577877167733, 71.65780421226256, 67.33969826852122, 67.27081360355501, 61.880543462691776, 59.26736239464053, 54.97197481893725, 51.080242280037176, 50.95693472893008, 49.68025422865345, 51.79679655259656, 49.849351529152166, 53.52016049046671, 50.211315693393836, 49.64514117087088, 52.507702612107806, 52.75780470140519, 63.21452586881576, 65.32922467877789, 69.30930860580938, 65.06278199534263, 67.7588741240963, 66.87448947660386, 69.63037813863447, 65.66986291639267, 67.19933232953473, 45.55787847888085, 55.461882775829686, 71.93036187079646, 66.73120529420915, 70.6218905602732, 67.9634492628036, 68.9198015582177, 65.91484239024501, 68.0020296958185, 61.62962944276872, 69.97871598889752, 64.05567422989877, 64.42674221531038, 62.100494292474565, 60.591178017277876, 53.7640142440796, 46.95518755143689, 49.179657813041445, 49.90717903260262, 49.18155624020485, 48.62323822513704, 49.46442188755159, 49.985987294104795, 59.91436127693423, 66.9471945301179, 68.55881798651912, 69.37263919461158, 65.72113221691501, 67.68438831452401, 68.06934541271579, 63.6249077704645, 59.51693496396465, 52.62919802819529, 56.00325615175309, 61.91111049344463, 65.8553086557696, 63.37379763203283, 65.461455622027, 63.74901940745693, 62.14794712681925, 58.22989156169277, 67.22777735802435, 57.466370828690074, 60.741950004331535, 67.4410052453318, 73.70934501771005, 65.19596215217345, 78.13404529325425, 50.538586493461366, 0.2529183051158344, 0.05599872517069021, 2.452691899191949, 4.575857635467283, 0.8910963744405778, 0.25643486319290054, 0.19475111827975322, 0.10383712773722026, 39.245765055379565, 45.99167693045832, 17.841642056742025, 54.54684088307043, 29.689131744446296, 0.3815958721022452, 0.04211676382129231, 0.08673778479738582, 0.047587164031762275, 0.044402954048447074, 0.034434522216719006, 0.06303676343973606, 0.08121352477539932, 0.0864592811933929, 0.03896560287103057, 0.017702382455970493, 0.01861525665698273, 0.013230035847593701, 0.02983941001847627, 0.027395440152876323, 0.02364257076424697, 0.03983787058161632, 0.02677909560471533, 0.051934843237001094, 0.02738664354828577, 0.042436038624615445, 0.013192550207848751, 0.015614785201426958, 0.05450346326876072, 0.1261389354664472, 0.050870475148962396, 0.055360926330209746, 0.09877186929506641, 0.08867048673451909, 0.08844707251316117, 0.06111053494556297, 0.054919065967682874, 0.0725519968076579, 0.052139492134653756, 0.11025302217251833, 0.04726467165915717, 0.05960453632137468, 0.07489464771483215, 0.04378416184936801, 0.02513861216063942, 0.10651013107910272, 0.04580243197720378, 0.028757408501640446, 0.07322397849131977, 0.046320855166883244, 0.07592965548317279, 0.050284402565129345, 0.016335436450918357, 0.044665473227899884, 0.03398030102553387, 0.008917866732865092, 0.01046080228632256, 0.05018616711059886, 0.05425492902436564, 0.043552462387109, 0.1317654988698421, 42.69252431008124, 76.26478487445463, 28.556865069174, 59.95142375269244, 71.98620073256954, 17.719683800974202, 1.460579967787189, 0.5523633668499609, 0.6977389079909171, 3.6279972714762536, 6.068049332787914, 6.9134323827682005, 1.0977159873131783, 0.07069908292783846, 30.2341744976659, 105.42773262146981, 82.80246596182548, 89.96981297769855, 77.03811153288811, 80.01834407929452, 78.06726301870039, 85.30076472989975, 78.01657815133372, 79.10422002115558, 81.01082924873599, 83.23950429116526, 79.6346970527403, 80.04575360205867, 80.57454401446928, 77.79483087601201, 77.41125445212089, 78.39726771077802, 75.10832894232966, 73.39210371817313, 66.87845891521823, 69.4328946451987, 64.38865600093719, 63.52556197874008, 57.911038168015025, 54.43252732676845, 53.72431201319541, 52.1420318080533, 51.774823434891246, 52.04564740580898, 54.251211843182965, 52.9751746116146, 52.16808419073782, 57.13723690279069, 55.06510365393854, 65.4400747822177, 68.03779386704969, 73.17008187693935, 67.28684825281944, 70.23869068391862, 66.89785895809051, 70.74310748807846, 66.42315803035613, 70.73021857969223, 49.40663753017303, 56.86871144079394, 72.0164422065981, 70.79343934212962, 72.92906007459088, 70.05186034787086, 71.73065831584316, 66.94166398817494, 69.33345471659015, 62.80826245584796, 71.52049772201046, 66.54038983006632, 66.76673412322998, 66.00528440167828, 62.84257535011538, 57.34769559675648, 48.81932535479146, 50.643772694372366, 51.54021863014468, 52.23643933573077, 50.15506498275265, 51.660372595633234, 51.011816532381125, 62.72443356052522, 68.69465751032676, 70.27703577472319, 67.63180501999395, 66.03271745866346, 69.85807172713741, 69.66283182944022, 65.36649111778506, 61.124957684547674, 55.030296541029415, 59.52030820231284, 64.46150225977745, 67.7127705850909, 65.36202746052896, 65.9190393263294, 68.28304398444392, 65.80269398227816, 61.72653944261613, 67.14168133274202, 63.198385315556685, 62.318636909607925, 69.96818834735502, 75.8163324479134, 68.3454724281065, 79.499798897774, 54.61911839823569, 0.27926154074168974, 0.25863250897776696, 3.1415218787808574, 0.8920008484875003, 0.7419762568127725, 0.2184378827411321, 0.39024494348033784, 0.1627943274234572, 42.43205147404825, 66.06735198728501, 17.722443188390425, 52.45262076777797, 40.84292281058527, 0.5547763599503426, 0.08422995001197824, 0.03398488989220031, 0.025042615598067645, 0.04039113928053168, 0.06856997136867816, 0.05239917295834711, 0.14088068878458393, 0.07577241593671423, 0.027431591842023116, 0.028740497110711954, 0.10671603253051158, 0.04935789199906492, 0.0634017315573029, 0.0683013579597877, 0.03676165601298694, 0.03493263258508617, 0.0505090770011227, 0.07984909153873883, 0.048611511686636556, 0.025493550272057616, 0.028301323801579497, 0.0277206827811296, 0.014087213541290933, 0.03234474544203089, 0.2355750857461845, 0.11556460086496607, 0.14187194527156893, 0.2033390864850052, 0.212701860695116, 0.08258787885067925, 0.12321340656208417, 0.14034697064949622, 0.17889960999450377, 0.22670660678657795, 0.14250038251761468, 0.1449772213856059, 0.13372931929845966, 0.17606444116080963, 0.1662106812000275, 0.1996869308453414, 0.188288553768108, 0.13648337474273098, 0.21295436327495884, 0.14251155207955069, 0.16746970073830697, 0.16108114032014725, 0.10671784815889214, 0.1235357074127082, 0.15564208459709922, 0.18767194491961312, 0.12178956320689571, 0.10645491146152058, 0.2059892757285026, 0.13098726079108255, 0.23584439629508605, 55.88320416788901, 87.67537547696023, 62.5022901258161, 54.59556848772111, 84.40743707841443, 26.775373566535215, 1.9145224868289887, 2.0295828869265895, 3.362718306241497, 6.870725616332024, 23.413208069339877, 16.04790589501781, 0.9987564264766633, 0.1912220576477628, 28.164318184698786, 111.3486994466474, 82.30645087457474, 96.90082934594925, 81.38634127955284, 87.71817638028054, 77.90504947785409, 90.56784106839089, 83.18582273298695, 80.64447987464168, 84.84062364024501, 85.69847737589191, 83.47839232414, 83.3775717212308, 82.34387813075897, 79.57972111240511, 82.09889473453646, 84.67026725892099, 78.78314264359014, 76.26157637565368, 70.69290114987281, 75.53216457366943, 67.4727842884679, 66.44130291477327, 60.56478831075854, 56.86637763054141, 56.15991169406522, 55.75043978229646, 56.07268210380308, 55.427511046009684, 57.597460362219046, 53.600200376202984, 56.33135064955681, 60.54255239425167, 57.83852531063942, 68.78859043121338, 72.43113871543639, 76.10127695145147, 69.5081727735458, 74.26246981466971, 70.8056692923269, 72.8916798868487, 69.67390860280683, 74.15633832254719, 51.63581463598436, 60.8629237451861, 74.64621097810807, 73.3082748228504, 76.07948426277407, 73.15762442927208, 73.87637522912794, 70.98555703316966, 71.39989268395209, 66.97421181586482, 71.44022249406385, 69.10712611290717, 70.56194889929988, 67.34362063869354, 65.84668728613084, 59.76634671611171, 51.148632726361676, 53.442901565182595, 53.50812273640787, 54.55995336655648, 54.871695503111816, 56.394991105602635, 55.381587936032204, 67.14302278334095, 71.10179255085608, 74.68838430220082, 69.66245528190368, 66.58468907879245, 72.76414009832567, 73.84477661501977, 69.29153242418843, 64.66513995201358, 57.70949894382108, 62.59358329157676, 65.7858552471284, 69.93421277692242, 69.05770424873599, 72.69682438142839, 72.71608321897446, 68.63499826000583, 65.27687672645816, 72.989088027708, 64.06003590553038, 65.38886039487778, 75.11081572501891, 80.1815539021646, 69.60690667552333, 82.24748980614447, 57.43389752603347, 0.29969316696928394, 0.20270171665376235, 7.373559744127336, 13.900110125541689, 2.868034128219851, 2.300356847624625, 0.9275532730164068, 0.1729196195881213, 56.39228859255391, 58.78849590978315, 29.942540391798946, 71.00735756658739, 50.14282718781502, 0.8983898379148976, 0.18567686810368494, 0.15173652239384192, 0.11656794621939622, 0.20126870322612025, 0.12203796721634366, 0.10830514403360506, 0.2824335124704146, 0.2013852405211618, 0.08921938873226605, 0.11567008351126026, 0.22760787858597695, 0.1347284818128232, 0.1561348783152719, 0.23257474835601546, 0.1283699903456915, 0.13518614273878837, 0.07818770730086873, 0.17586374144640662, 0.18675942694948566, 0.12419209154623172, 0.13139975317303212, 0.12394407058074591, 0.18325068296924715, 0.2110619728844012], [0.05699454371126429, 0.03343750474854343, 0.05655354519765224, 0.029201858241351384, 0.0308075861915225, 0.05303214544490461, 0.033408489168411305, 0.026528393331494544, 0.03297848018607305, 0.05558159029591949, 0.0969193384592091, 0.015899029676802456, 0.025060128368016694, 0.05235213132935667, 0.03606552340751214, 0.020414802936776992, 0.027701346721920758, 0.04167244048608888, 0.02251218121889378, 0.05854400250339701, 0.04300041176799325, 0.015054593940505819, 0.04622157400233611, 0.02993391654003532, 0.044048217035109, 0.030240144866007953, 0.04484219055983328, 0.01961637844121264, 0.06192681312020268, 0.03297602870471535, 0.2978808174450552, 4.340685067638274, 66.30937007165724, 62.16509572921261, 26.237500905990604, 49.08018650547151, 56.68622316852693, 1.836442437864119, 0.46684497186253154, 1.3002972136582098, 1.0815094892055759, 1.8041608410496868, 6.245345857835585, 0.6055900526623572, 0.5588380355508097, 0.16986606973073176, 37.77582937671293, 102.87003347950598, 77.72463613940825, 85.27186470647013, 81.10027497814548, 76.554561738045, 73.05156353981265, 77.34229918449157, 83.03940849919474, 79.59524585354714, 78.86603801481186, 78.03758636597665, 76.41463510451779, 74.21944925861975, 75.50656718592491, 78.58105428757207, 77.31162624974405, 73.94100804482737, 70.94010460761287, 65.13552235018823, 66.99758914209181, 63.714278974840724, 62.44061869959678, 55.884659367222945, 51.23256752567907, 51.80970899520382, 50.6702055469636, 49.84067916870118, 50.53229893407514, 49.69786959309732, 50.62088174204673, 50.59923810343589, 50.70413797132431, 52.74662986878426, 58.05386735546974, 61.66419336872717, 68.18343147154778, 66.6017984574841, 71.50571823120117, 66.29244896673387, 68.6014227713308, 64.12610823108305, 70.51288789318454, 39.40761381579984, 49.66275261294458, 78.03877876650903, 62.10846847103488, 69.41726007769185, 63.36375244202153, 66.47350557388799, 62.184068233736106, 65.70871399294946, 68.84012253053727, 66.75051120019728, 67.0522669822939, 64.62471600501769, 60.18021168247346, 58.38798269148796, 50.256422950375466, 50.02609352911673, 49.72680884022867, 51.23598391009916, 46.28655287527269, 49.37638821140413, 48.64162629650485, 50.04222623763546, 60.54150119904549, 70.60039597172891, 66.61018448491251, 69.61292359136766, 65.22510144018358, 67.79499130864298, 67.91545514137515, 65.41415576011904, 61.671437986435436, 53.08133748269851, 60.03162837797596, 70.05930500645792, 68.85966377873575, 69.4595040044477, 61.5951596536944, 64.58150325282928, 66.05461212896532, 67.27134704589844, 58.574887552568995, 61.93211870808756, 67.83948667587774, 68.18429439298569, 68.8876381228047, 75.16981601715088, 60.861464623482, 0.9670487827351018, 0.11972733112352511, 0.3302060199841377, 0.7006229532341803, 0.14922255890504008, 1.4440958394158272, 0.6725262189584394, 0.5088975604984068, 16.122005351128117, 63.98656598983273, 16.81409089796005, 33.444877670657256, 64.30936528790382, 15.494655582212634, 0.37786597386002546, 0.08967992248794726, 0.12174928996471629, 0.025480134157283653, 0.04226293722768465, 0.040044695168973944, 0.02464006129171579, 0.04735983510111128, 0.0803085451104468, 0.07715457644794257, 0.017591705733549692, 0.011845784873941974, 0.00991061517608262, 0.041575710394329606, 0.04510455269126162, 0.03450980950747767, 0.05615752753651431, 0.05393125687635714, 0.024908525313461022, 0.05172713764853055, 0.08674575211179834, 0.04560590361154849, 0.031033817701221957, 0.010048820310452533, 0.05631701938147026, 0.04804298251626953, 0.04506747020528682, 0.048828942761305845, 0.06171593209728599, 0.04278616761908897, 0.06281598839127729, 0.05360065546307353, 0.028089686266837582, 0.04627245756226682, 0.0075768379610963174, 0.04908319202161605, 0.01971716688375079, 0.02438261361432172, 0.06999720849337117, 0.1139575552435652, 0.08747964136062131, 0.055673107159354036, 0.023535946646945614, 0.026210422792862502, 0.02760558956182532, 0.09679319442159708, 0.0368812921336822, 0.025471638242203384, 0.011296497917013064, 0.04242971073836089, 0.09247431246143195, 0.08446653328475454, 0.0026803884294725236, 0.13596243495422025, 0.019993188362869046, 0.2313815051269147, 5.528323842633156, 84.16191239510813, 55.56513132587556, 30.967190957838493, 69.22615435815626, 58.83315601656514, 4.202397494546829, 0.3082061504885074, 0.30575353532068195, 0.9767250248020696, 1.939056421960554, 4.995233531921141, 1.1446171157783078, 0.7025288574157224, 0.13790532586074647, 47.77612786139212, 106.90233984301167, 78.56016374403431, 89.4697892281317, 81.62615499188824, 78.9649994142594, 74.67729968409385, 83.53953423038607, 84.61182394335347, 82.430217342992, 78.92074723397532, 83.29524901605423, 78.52635291314895, 77.07491120984479, 73.55581560442525, 78.56801632911929, 80.23053646087646, 76.8769884109497, 73.03814118908298, 68.604796009679, 69.98841208796348, 67.28333380914503, 65.0435035459457, 56.96229134836505, 53.14462492542883, 53.24888152460898, 52.266119910824685, 53.29265517573203, 54.182495840134166, 52.22025171402962, 54.06925309088923, 51.53445666836154, 54.69937793670162, 55.317527786377944, 62.95102496300975, 64.06592338315903, 69.86454363792174, 67.3704339611915, 72.49913692474365, 70.17461484478366, 70.71607451285087, 64.7962922434653, 73.32587842018374, 42.5913820728179, 51.383947480109434, 77.70373775113013, 64.4871114146325, 72.40796535245835, 66.19803751668623, 67.60345412838844, 67.21657506881222, 67.68297626126197, 68.5407672389861, 69.03911221411921, 67.34617802404588, 67.59989261627197, 62.65454084642472, 61.034084212395456, 51.7197141339702, 52.28434716501544, 53.099851069911836, 52.60541669784054, 48.762851069050456, 50.02699567425636, 50.628765706093084, 52.1033376263034, 62.977869664469075, 72.2120508070915, 69.98658426346319, 70.6237340742542, 66.47778095737581, 70.43808044925814, 69.3395814587993, 69.2740543427006, 63.76117091025076, 54.23639705104213, 61.0012931977549, 71.56643652146863, 69.27988298477666, 71.34876066638579, 65.12886216563564, 64.98976707458496, 67.93261158850886, 69.96283823443999, 62.56425965216852, 63.750235342210345, 70.96338779695573, 72.00283942684051, 71.13542295271351, 74.68276746811406, 65.13194514859107, 1.1489794042802628, 0.17016132001674947, 1.1970512376677607, 1.0771273437046236, 0.2543431826897206, 0.2786161882742759, 0.18624490697778043, 0.3336362859174129, 17.53060594681771, 82.66020944041591, 30.264861160709014, 21.13813727132736, 75.0592444019933, 19.62583803361462, 0.42241153517557734, 0.05203175718986219, 0.08765689112366208, 0.03847477799882332, 0.03088139110214768, 0.021236349881115942, 0.015818129834388534, 0.08252970213370939, 0.060292284094518235, 0.016025532818128987, 0.012332978489388143, 0.021084513169743364, 0.02821029531919668, 0.0240499533397416, 0.06183176842187682, 0.04786394776836519, 0.040289770526390885, 0.07794171646838227, 0.09048695015090127, 0.007540729364395263, 0.010542660696251739, 0.09784755357090505, 0.0465655206672607, 0.06246776695573523, 0.10527496751878532, 0.17374230608824762, 0.19467164431848835, 0.10742430379914661, 0.11411539233860471, 0.14240238455034074, 0.13249403316407435, 0.14458184340788474, 0.08739156423196678, 0.10840347141868646, 0.13055638229895022, 0.15453421420628025, 0.11256136000156404, 0.1352236810470781, 0.2002986980181548, 0.16840825037610146, 0.27322274542623953, 0.14052088793006637, 0.07791999787572892, 0.14115687880304553, 0.098614729340038, 0.13678887528517555, 0.15668710513461023, 0.17749967624343213, 0.0964292566922884, 0.1789799572960023, 0.24654485195154147, 0.2747030418005682, 0.15043864687604291, 0.24044124559769708, 0.1704083833723299, 0.7877478652423429, 8.400114620885542, 94.97077218947872, 80.78366910257648, 45.30575244657455, 63.698036439957164, 83.96110273176625, 5.1713842345822245, 1.2402904658548295, 4.718348518494637, 4.803191346506919, 9.387958645820618, 14.873686528974964, 1.1571048392403511, 0.6684510602105049, 0.2887008164919192, 42.90423031776182, 111.35984682267713, 83.72417588387766, 93.16347737466135, 87.40786198646792, 83.09904421529463, 78.8869442478303, 83.86749144523375, 89.62644084807366, 84.91497608923143, 85.17195409344089, 84.09272963000883, 80.51104084137948, 78.91869191200503, 76.72729507569345, 82.5948392191241, 82.56813572299096, 79.7270453360773, 79.44400710444297, 70.95988119802168, 73.01677996112456, 71.26748131167504, 69.41224728861164, 59.98117493044946, 56.82533394905829, 59.029862880706794, 57.13233394007529, 57.81584224393291, 56.445248434620524, 54.84066563267862, 57.30279230302381, 55.45807415439237, 58.34209880521221, 59.49171412375666, 65.91541505629017, 67.0845716230331, 71.6533640892275, 70.48842799278998, 76.19141301801129, 74.49385827587497, 73.78416815111714, 66.55477708385837, 75.01696909627607, 44.3812733311807, 51.530526453448886, 82.19896224237259, 66.26226240588774, 74.0393889334894, 67.86366416561988, 69.93777428903888, 67.01320017537763, 71.42123822242984, 69.99797482644358, 71.09808983341341, 69.88850147493424, 70.14425569964995, 64.10990491990121, 63.95506151260869, 55.09876543475736, 55.59106995982509, 55.771557823304214, 56.278786966877604, 50.82869675851638, 54.59974188958445, 52.19035148620606, 55.171803889736054, 64.90971934410834, 76.44323702781432, 71.28761091539937, 74.22985138431673, 67.60008089004025, 73.9322219356414, 71.61585838563981, 72.5189370493735, 66.54995256854643, 56.84853476862754, 63.72197074274864, 74.20551699976768, 74.60441420155188, 74.70041813388949, 68.36324076498708, 68.99831171958678, 71.65967910520493, 73.56336224463679, 63.89326064817367, 69.22869605402794, 71.39648806664252, 74.31735161812075, 74.02300127090948, 79.74904983274399, 64.29926126233994, 1.9153934981553786, 0.270605176206558, 1.4391996182741658, 7.1817293667024185, 3.0329803353355778, 3.129097035815639, 1.6985490629749915, 1.0118956311095146, 27.162678203275128, 79.62180814435406, 26.945059222559777, 46.88657353001256, 83.38816212069604, 27.517440895880423, 0.8354885647854499, 0.2815490486400743, 0.2696952169700977, 0.1751970457694223, 0.09195642936373911, 0.1534065327817394, 0.21882956817505822, 0.12117686140681468, 0.13173801163511892, 0.1514582179727093, 0.18180755718100458, 0.1268761265542238, 0.18508941656158817, 0.14074282360173043, 0.19784004607748604, 0.12998391543665241, 0.13490454413958136, 0.19115361535260755, 0.14859081215916142, 0.25247454102481565, 0.09459541074090427, 0.15431678313161099, 0.10988278720047205, 0.08463957722509101, 0.2409253518788084], [0.03335699656858079, 0.017681761284268672, 0.04473491526779629, 0.020842739651280067, 0.05562402007560577, 0.0721543358879224, 0.03156175570292098, 0.06446383202508574, 0.04064007955152662, 0.027840309325725805, 0.032021513794578856, 0.03203396846900784, 0.0063182608385930865, 0.11788609242367169, 0.012023191685007225, 0.032244395584829395, 0.0491389517311848, 0.03827168809009656, 0.05326635767555526, 0.04587666206662694, 0.0631741498176369, 0.02863221632827434, 0.02093476979362388, 0.0446165087182195, 0.05887013379364245, 0.022217061167823213, 0.046195132477629575, 0.040978376318009636, 0.023118844330911676, 0.05541879278157027, 0.01570150731206541, 0.20614895909543962, 21.049813339787146, 75.92284048757246, 52.27826749124835, 30.72986402819234, 69.22183975096672, 27.429724931716922, 0.13965409008725999, 0.39065127651537623, 1.0074964478131265, 1.45323459419512, 3.4815072869100883, 2.510870454772826, 0.1451444890229933, 0.2417185746373669, 0.1610837450190898, 43.20276583394697, 92.62957219154605, 78.67144923056327, 83.34632612043812, 77.60383498284125, 79.54922860668552, 79.00041057217506, 77.78273428640058, 82.01723883228918, 84.4760864011703, 79.8750049837174, 73.07997718934091, 77.13271910144438, 76.59042789090064, 78.03238530312815, 77.45107435411023, 72.31915504701676, 71.1648250395252, 68.70749150553058, 67.0859601420741, 62.03546531738774, 59.06923955486667, 53.90513720050935, 54.74967841179141, 52.935954832261615, 52.224456494854344, 53.08637380599976, 55.490535689938454, 52.81436920166016, 53.93065614085044, 51.3439118477606, 53.540741166760846, 53.38910625826929, 59.66863655274915, 59.10083816897485, 66.76027790192636, 63.75027848828224, 73.13769878879671, 67.21510810236778, 74.23772750362274, 61.43864923907865, 71.63343844875213, 38.31912471402077, 43.7824333098627, 81.8999207404352, 61.88636426002749, 68.12554513254474, 57.32791116160732, 62.91910471454744, 59.05420118762601, 66.91786304596933, 61.655148383109804, 65.02835142997004, 59.97717019050353, 59.896345830732784, 56.819140526556204, 51.06438021506033, 49.42409599981001, 50.98182216767342, 52.52760864073231, 51.56964817354756, 48.99744018431633, 50.027956654948575, 48.64787463218936, 50.26534242014731, 55.17223142808484, 69.74058889573621, 67.70207820400115, 70.06680457822739, 69.2204983003678, 70.47739828786543, 70.20538191641532, 68.80088313933342, 65.117079365638, 57.45889086877146, 62.94915791480773, 69.84635952980288, 69.33579244921285, 70.44469356536865, 68.28304398444392, 70.75994230085804, 64.46980591743224, 66.05470626584946, 66.91730606940486, 67.25582230475642, 59.93117647786295, 79.95615097784227, 69.64038018257388, 84.65010627623528, 7.047063612168835, 0.231536086348276, 0.1272953834925448, 1.36491225611779, 1.4239138965645146, 0.4889270272706786, 0.10038626169966114, 0.341915336828078, 5.148401106557539, 56.699927929909, 36.33822187300652, 42.42544620267807, 49.15567251943773, 51.330191396897845, 1.653914819321325, 0.14126750189931164, 0.1863562961619708, 0.03373467408481144, 0.015337300494373327, 0.043098237365484245, 0.023618559653480208, 0.029241464987036683, 0.04495778939716759, 0.06941038514337233, 0.012093524302115605, 0.021675640018656853, 0.05008762139045904, 0.03327352362835119, 0.0026735510947483204, 0.015909456133451915, 0.015496652528283097, 0.04212871479291109, 0.03163562956145935, 0.06173373981108589, 0.08799501935080176, 0.06024583618366911, 0.03145364729026633, 0.06111585159575748, 0.017721021375168237, 0.04924077247720092, 0.049319767633513104, 0.028377225877897396, 0.042791645147747574, 0.03855239036643217, 0.06999607468324323, 0.12120587315650717, 0.08281305507426301, 0.07528586583512445, 0.04850970626237893, 0.04016473348582945, 0.02227193030017999, 0.025724541102986664, 0.039385633558155074, 0.04615223538430949, 0.08759386507013152, 0.03984829703826578, 0.025211605018064864, 0.03528520156959853, 0.07199867448258786, 0.04711128170451811, 0.043256920987680074, 0.01557977689850715, 0.01442933883217554, 0.051782843731944604, 0.02266080036098438, 0.019290693397183093, 0.0649389980601207, 0.03189544445053945, 0.06778275473944603, 0.027130168802555532, 0.05300018808714325, 0.17917590726527477, 29.106748027186242, 84.86101996514105, 35.20780263408538, 43.89904537508565, 89.50540434929633, 29.231955966641827, 0.15284802404142198, 0.3242179090457578, 0.673800069958933, 1.1554380770652526, 2.9833096458065897, 2.353560857234463, 0.4047337805311526, 0.05354764217871332, 0.1614328819297014, 53.97521818837812, 99.94126242976036, 80.05686959912701, 86.69200589579921, 81.08792735684304, 83.08572384618944, 79.86042161141673, 82.13657302241172, 86.2455774122669, 87.25047296093356, 79.5435647041567, 74.40629528414819, 76.12575254132672, 79.05279774819651, 79.00953400519587, 80.83069832094255, 72.56172226321313, 73.16320988439745, 70.80949752561509, 68.18085055197439, 66.53578496748402, 61.81065467096145, 58.179422424685576, 56.186434761170425, 55.26141828106296, 55.33479405987648, 55.10524126791186, 56.04253084428849, 54.99763104223437, 55.14997982209729, 55.454983326696585, 55.49615252402521, 54.662488045230994, 63.17353710051506, 62.49248812275549, 69.92745061074534, 66.9544901386384, 73.28368156186997, 69.24182814936485, 74.27912419842136, 63.62273477738904, 74.4778863845333, 40.69371977160054, 45.66549654929869, 84.94362508097004, 62.19803187154955, 71.4419012684976, 59.27044145522579, 66.93565491707095, 62.71188197597381, 69.66122365766957, 63.99320264016429, 67.61887688790598, 62.54695023259809, 63.34897295121224, 57.67605681573191, 54.33350709176833, 50.52081031184043, 52.78658705372965, 52.606707157627234, 54.15959312069801, 50.000213730719786, 53.80196709786692, 50.73696036492625, 52.893432417223536, 57.357532901148645, 70.94721978710544, 68.9166715068202, 71.10400476763326, 68.32534282438218, 71.13168101156913, 72.07250856584119, 70.2267509891141, 66.18946321548955, 59.87458844338695, 65.34603203496626, 73.21725230063163, 70.64487564948298, 71.72394321810815, 70.10351796304026, 75.46875553746378, 66.24756136248189, 66.86460510376962, 68.82628440856934, 72.61236006213774, 62.623840455086004, 82.85053068591704, 70.11636764772477, 86.43913853553035, 8.210901444958102, 0.21009421997493316, 0.3888637175963771, 0.06623020095209922, 0.5220309428630338, 0.2940570887538695, 0.09627647577754914, 0.420720043682283, 8.521868913404404, 67.57243602506577, 51.7052915788466, 25.320792005908107, 48.23970886968797, 62.13243807515791, 3.0359255450387157, 0.19199451942357326, 0.07210614895748516, 0.0697956737431307, 0.034241843442883224, 0.07691565660699722, 0.041792038302387924, 0.04653185876386781, 0.058150233310316844, 0.042615939051874226, 0.06704013208828627, 0.05031284740975788, 0.11350527991570773, 0.06751913622382187, 0.0572749242306717, 0.08229620619526795, 0.030401086532360608, 0.042058242364756526, 0.032866822871109175, 0.01840874425045425, 0.0445618866492183, 0.03167242667968235, 0.05532699246560374, 0.05590040161604843, 0.030953677243462978, 0.028163115794379866, 0.21506089056211136, 0.07463440764695406, 0.10159472709581738, 0.07970089949066601, 0.24180537239918787, 0.20311727338740904, 0.17487311315151954, 0.300951665567775, 0.0921778517564939, 0.06838149841754668, 0.19544933081394245, 0.0788155393374543, 0.14885949451596509, 0.12356786012289026, 0.11999205280576022, 0.10249570012092592, 0.10442346079094757, 0.1253809297697679, 0.17100473685610681, 0.14003371729725791, 0.1629837196800978, 0.07903176765408247, 0.16691758117127806, 0.17042114639714842, 0.21089711076309606, 0.06761662857306582, 0.13672610204066002, 0.1536606901114987, 0.19667030642590216, 0.3050798682435867, 0.20043023531475376, 0.5551790770503783, 41.46801525546659, 98.89707257670742, 74.05983232682752, 48.248083130005874, 85.59794702837544, 42.97828074424498, 0.4138492462375472, 1.9145341313654378, 4.658417644039278, 4.123562266749721, 11.02488531220344, 9.108837881395894, 0.22308262786076916, 0.3099206552630471, 0.16181725888482987, 51.70490718656971, 105.05256575922813, 84.28177218283378, 90.74377506009995, 84.91418377045663, 86.11213053426435, 85.3224083685106, 84.88908060135381, 87.57217007298624, 89.98361972070511, 83.98038510353335, 78.09431952814903, 79.16234170236896, 77.61402530054893, 82.07792574359526, 85.40414271816131, 76.88996361147973, 77.00234736165693, 73.76182633061563, 74.91184173091766, 69.34846170486944, 65.62304942838608, 61.85407923113916, 61.27468239876532, 58.982833662340724, 58.57375398758919, 58.99826818896879, 62.097458377961196, 60.19003329738494, 59.73625821451987, 60.115665158917835, 58.422013175102975, 58.420875687753, 65.95626261926466, 66.73801452882829, 73.79426433194068, 70.60798968038252, 78.69867047955914, 72.56534653325235, 78.46907061915245, 65.70464649508077, 76.13762163346814, 43.6278409342612, 48.87615657621815, 88.71091258141303, 68.03245944361534, 73.60415489442887, 62.04790707557433, 68.87623971508395, 63.97033914442986, 70.19688606262207, 65.96351115934311, 70.94808270854335, 64.47445392608643, 65.56607700163319, 60.685259988231046, 55.29096941794119, 54.701425413931574, 55.83053850358533, 56.486299960843986, 56.350079967129616, 54.01710125707812, 56.74465471698392, 53.92328992966683, 56.24111260137251, 61.43815109806677, 76.36767648881482, 74.16778379871, 74.11401594838789, 68.2897904611403, 71.47165636862479, 76.50524970023864, 75.27306064482659, 70.40090422476493, 62.16217356343424, 68.66027401339623, 75.24937737372615, 72.95629701306744, 75.54450435023155, 73.20717965402912, 78.93676619375907, 70.23114404370709, 72.90693006207867, 74.15577350124236, 73.93615999529439, 63.81239706470121, 87.63302172383955, 72.29884501426451, 87.10747903393161, 9.295073978362545, 0.24975739569673616, 0.7803758317905088, 7.096435956416592, 4.232939029893568, 0.8347003522419161, 0.35702305034764353, 0.747040588288538, 10.14073698751388, 74.9569332984186, 44.95055044850996, 53.78125306098692, 60.62212551793745, 75.29041321046891, 3.855935762966833, 0.24721188470721248, 0.2522963949389035, 0.20896863763130483, 0.1546417116638153, 0.1840298863187913, 0.17403924176769872, 0.16296833663457827, 0.2272450899885547, 0.14945244656935816, 0.21028617096524085, 0.10213221438349256, 0.18907266008036752, 0.15875632393985026, 0.17047927714884284, 0.20827056299294197, 0.14443257883671792, 0.15516861161637693, 0.16227455208859137, 0.13450455431255604, 0.20456554728650278, 0.11220099990286174, 0.09696076849415418, 0.13305182178174296, 0.09929438722470116, 0.20223130802473716], [0.017884878006072778, 0.018242792369076805, 0.027722316463628126, 0.038773885537539764, 0.00507335263987883, 0.07176198395750216, 0.04679647702423315, 0.013514817542126103, 0.03685713355099002, 0.04279542962209352, 0.027924488982065555, 0.04484907769027256, 0.028740671395714727, 0.09565085773506472, 0.05226861625429123, 0.034396424664244536, 0.03079750447443897, 0.04454988971232407, 0.025950826238840822, 0.033300493753725485, 0.0660121187026943, 0.032556898170901884, 0.04205014098495726, 0.018546695618199247, 0.016182149918149077, 0.06491495822105678, 0.03556014286474355, 0.06488368651198764, 0.06656594664579438, 0.051758485966392105, 0.08295799890953688, 0.06982178968046943, 0.39930350417571686, 57.41685875000493, 72.43284886883151, 30.652814949712447, 36.867314307920395, 75.63426386925482, 5.928647806567531, 0.17932953853760997, 0.41559767338537407, 0.9785629616629694, 1.28563380049121, 1.5322178914662332, 1.1799006740893088, 0.052183591986014966, 0.26604462414979935, 0.12995201553548538, 40.35969072772611, 96.58909505413425, 81.52918615648824, 89.38789013893374, 75.46531954119283, 83.62304933609502, 88.99180919893327, 85.58680749708607, 79.0229328217045, 77.09430340797671, 79.37345150978335, 78.92655234183036, 78.91477738657306, 78.17665792280629, 79.07211934366535, 76.45250166616133, 72.84447808419505, 67.36560944587954, 66.38748015126875, 59.77244600172966, 58.525253880408506, 53.32110804896201, 55.04623313103953, 52.07060152484525, 52.414926790422015, 51.787700576166955, 55.886993177475475, 50.14043846438008, 54.14591189353697, 50.53333443980063, 54.04558550926947, 54.31393838697865, 58.09235757397067, 55.745917289487785, 62.5407999561679, 59.02577577098724, 71.80330061143445, 66.60517954057264, 75.80442413207024, 63.253510305958415, 73.61563959429341, 43.10565579322077, 40.97959779923962, 82.2193193435669, 63.01912907631167, 68.32218923876363, 57.13606411410917, 60.74360524454425, 57.56734440403601, 61.951659956286036, 61.056229914388354, 62.96860502612207, 59.650530892033736, 58.245992891250125, 51.73666269548478, 52.52969926403415, 49.58385021455827, 52.41126329668107, 52.58628337613998, 49.819223803858605, 49.78251041904573, 50.568929949114406, 51.3304659628099, 50.66301584243775, 52.37050594822053, 66.45360346763366, 71.45303295504662, 66.94397034183626, 72.7367070413405, 68.14088944465884, 71.20338193831905, 69.12933457282283, 73.12891267961072, 60.95709200828307, 61.54292545010967, 70.48930660370858, 72.73436146397745, 70.75637294400123, 72.71320419926798, 69.3249745522776, 73.04513869747039, 69.75704716097924, 64.99053193676856, 62.837186013498616, 80.08094510724469, 65.5059156879302, 87.2193842549478, 25.307326509106545, 0.4086076113725863, 0.5729140124974713, 0.8995636684759971, 1.903455641961867, 0.2373190695840505, 0.09594627656042577, 0.0796531109259494, 2.5761872337710474, 52.03621802791473, 58.38929668549569, 103.68236418693297, 61.79767162569108, 55.19929578227382, 31.187284954132576, 0.645470138519041, 0.2642631939341945, 0.1721699412671789, 0.05245104860213976, 0.054246754866213574, 0.08871343362355426, 0.025234966869315794, 0.08928633715596893, 0.1066962751229444, 0.10730459490009855, 0.03249695562126656, 0.03563923378204627, 0.04080457395062812, 0.08397498828989845, 0.05876989884962959, 0.058946386355185704, 0.06589168202011816, 0.06374363659790928, 0.008336376312429146, 0.07400814609061326, 0.1011645151001792, 0.03121696251084007, 0.1262849748074528, 0.010191775189952986, 0.02224125805491161, 0.08650939866539933, 0.054897841501740686, 0.046553309225747665, 0.019179020760460727, 0.02978560766355405, 0.027680352082355853, 0.03375894758069227, 0.021319430201284347, 0.06502073198076218, 0.022907346607215946, 0.06243636118127935, 0.048307451389489636, 0.027589428937062625, 0.06640220301285868, 0.11316850766419403, 0.054819643076869755, 0.040967750678499865, 0.0706476554454815, 0.013665100052622298, 0.036940656286934694, 0.015199690993364542, 0.038588354364037514, 0.06561421263482302, 0.03333783670959454, 0.05384307249539322, 0.026526882223063902, 0.004605556370675444, 0.030165661967569785, 0.017538366861821666, 0.03541634816135611, 0.08694311168285147, 0.05715173346200778, 0.0613774782827785, 1.234707707358945, 73.79692369891752, 73.27662914030014, 27.109514397959558, 67.84887683007025, 80.66427999927153, 7.780463484025772, 0.22248772994404842, 0.1509359911564858, 0.46975947676166413, 0.7742931549587558, 1.2837426051978142, 1.8280895054340365, 0.2615504459508004, 0.1182353595692304, 0.36442983354772296, 53.569727482334265, 104.65502569752356, 84.51608673218759, 91.87193501380183, 76.75261789752592, 90.31086306418143, 90.01092726184477, 85.5039748837871, 79.43059259845366, 80.35056883288969, 81.63126976259294, 81.55142599536528, 78.90946649735974, 80.5328021510955, 80.21820452905472, 76.45388234046199, 72.41074239054035, 70.74906949074038, 70.4534718298143, 64.57658067826303, 59.82136972488896, 56.29207987939158, 57.23126396056145, 54.15387430498677, 55.868110887465946, 54.8219520045865, 57.711899434366536, 54.16237800352035, 57.16415612928329, 53.08942540999382, 55.695165741828184, 57.12493634993031, 60.453424376826135, 58.12030053907826, 65.04073827497422, 62.5499390786694, 73.521847878733, 69.2211337243357, 78.56204648171702, 64.55347007320773, 73.93390071007514, 43.38562673138034, 43.14554237550305, 82.42408275604248, 65.1234689066487, 69.94156329862534, 59.22511062314434, 63.86897725443687, 62.98469066619874, 65.62346127725417, 64.11379983348232, 65.98378196839364, 64.03379917144775, 60.66877818876698, 53.45064824627292, 54.75003142510691, 52.14059622057023, 53.05072730587375, 56.0056487975582, 51.42814866958126, 51.68889999389649, 50.428140394149295, 52.95381338365617, 52.31240780122819, 54.27121593106178, 69.0560176295619, 72.08750770938012, 72.47872491036692, 71.94591014615952, 69.3349059935539, 72.6476300147272, 72.06480503082275, 75.98883828809186, 60.289865463010734, 64.66653631579491, 72.31236150187831, 75.05212922250071, 72.95830526659566, 73.75127515485211, 69.32936760687059, 74.05740045732068, 75.53025045702535, 71.20469985469695, 64.3498480704523, 83.54039715182397, 67.84319723806074, 86.85583545315652, 28.89331029307458, 0.28997684318211775, 0.7015285917347478, 1.5963046396932297, 0.798326742745215, 0.1516505213634622, 0.09700453509726832, 0.14187640390328823, 5.695138813987856, 54.16670045545025, 65.17444010703795, 80.50431789890413, 55.00815868377686, 63.08656246431413, 38.62819179411858, 0.4426741011200413, 0.10893312162689625, 0.08471860685535977, 0.1361182572380189, 0.03901252192595313, 0.11393053532247582, 0.007754084851307375, 0.058760414681127, 0.030849935531976725, 0.07421361853278453, 0.007623350989419006, 0.08779736866633739, 0.061323718062692115, 0.06024954021878301, 0.04799725472806923, 0.08668114791714376, 0.041856090913737015, 0.08674688592192628, 0.04759713466609678, 0.018420135977888302, 0.04673867185990657, 0.03212876610397812, 0.0428959556795176, 0.07719294213119053, 0.037318475529431336, 0.037709053966306874, 0.16967117696279482, 0.21952195844102293, 0.12899952309746898, 0.10918643625993883, 0.18552300700497243, 0.28101683203731814, 0.1614731168674846, 0.12920871106607298, 0.2434897239530279, 0.21966077357290253, 0.15148921389012568, 0.09660329654692643, 0.12252915214987532, 0.3019224521854232, 0.20676080287704546, 0.1597573250652321, 0.12155569954625062, 0.08848343870692676, 0.11879981315184025, 0.09120192468887375, 0.16772028809833914, 0.1159669885471944, 0.10441045261799328, 0.09821603420160471, 0.2568600726343932, 0.12247357247096878, 0.08571462840923379, 0.14336903429319783, 0.16863052312645221, 0.18962405952474765, 0.38714930475238835, 0.2472620021792189, 2.1575350146139822, 86.4494308348625, 88.80734012972924, 52.1186113357544, 53.88500759678503, 97.79229779397288, 12.870594839895926, 1.5105882262991321, 0.7572730101885334, 4.897259589164488, 3.5369134622235454, 5.781950181530369, 6.500645087611291, 0.15166538346919323, 0.4260130677252047, 0.8969803587082894, 51.434310713121974, 105.3869713506391, 85.91358800088206, 100.61258392949259, 79.2247623012912, 91.64073482636483, 97.49848873384538, 89.68788869919317, 80.85944144956528, 79.9182608819777, 83.21010220435359, 81.14273855763098, 82.55243055282101, 83.57563572545206, 82.76504655038157, 84.49014417586788, 77.341444107794, 77.12353291050081, 72.6180318094069, 67.0328434052006, 66.80751892828172, 61.221047909029075, 61.25086576707902, 58.859126029476045, 58.174025243328465, 58.987234561674065, 60.21357144078901, 57.88284417121642, 62.011480023784024, 55.829820709843794, 59.84925777681413, 61.25902821940761, 64.74728615053239, 62.10695443614837, 67.31594439475768, 63.91376287706437, 77.44429649845247, 72.91168397472751, 79.85926843458607, 67.61202058484479, 72.82626259711482, 44.47006010240124, 46.683771302623136, 84.18867080442368, 68.93342787219633, 73.07945943647816, 61.024133159268295, 65.97927124269548, 64.0310299781061, 67.55336546128797, 66.61943343377882, 67.9028800226027, 65.75849279280632, 61.18864913140575, 56.06624549435031, 56.943742459820164, 55.8384342347422, 56.101323250801336, 58.78284377436484, 53.84506217895016, 55.63760888191962, 54.80352078714679, 56.71777863656321, 56.344161110539595, 56.05203082484584, 71.62123203277588, 77.73010392342844, 76.95356092145367, 75.40569951457363, 71.69461957869991, 73.28265390088482, 76.29548134342318, 78.91567168697235, 65.8694056541689, 65.30642001859604, 75.74726735391926, 78.90837607845184, 74.97086555727067, 76.55836643711214, 74.89179057459678, 77.58332098684004, 78.51249125695999, 71.78009586949503, 69.51624501136043, 88.65143376012003, 71.93374295388499, 90.12462892839986, 32.53856501271648, 0.5290978894599023, 1.7212966036412025, 1.985983781276211, 5.22350468943196, 0.7556430202338004, 0.3098211864069585, 0.29072831414880296, 6.09711213457969, 74.07788307436051, 69.97082418011081, 101.43206904011389, 74.05164241790771, 73.57185809843003, 44.56367138893374, 0.5952699290167901, 0.3758357182866143, 0.2306371587779253, 0.12919602465004693, 0.24029642433649112, 0.17572049832632466, 0.19629106225986637, 0.19309405477777605, 0.1390198305729897, 0.21493462395043145, 0.08619730976680595, 0.19122794120302125, 0.15175535283502073, 0.25131574110879057, 0.11496178159910826, 0.21123624256541654, 0.18479111724563185, 0.12007143483647417, 0.10756384671455431, 0.1710291290956159, 0.2515786624844036, 0.23631039225766737, 0.16828874065991373, 0.11650315816363982, 0.15161476037915678, 0.14360813033436576], [0.10498943122764749, 0.003287809729132982, 0.009626076714466176, 0.06366268408695056, 0.0036597095059997015, 0.05168638177095883, 0.03112803885502921, 0.02915079656597828, 0.013719849483740908, 0.04824592303785105, 0.00537355233269233, 0.014013925740014643, 0.04896009701394266, 0.056767034749951095, 0.02703097765333951, 0.10700200549176625, 0.09243999938330344, 0.005243945098857606, 0.06221505370171321, 0.058232246853050694, 0.04508722378241439, 0.06682942726559217, 0.006211833031322327, 0.12779044483097332, 0.040007149199804956, 0.04655621269898069, 0.05296452286382837, 0.0546304231900121, 0.04924621936234255, 0.093025267574816, 0.21933379192506114, 0.17119739264730485, 0.6383248058057601, 15.213785440691057, 73.08875545378655, 55.93553643072806, 26.961727334607033, 55.276025187584665, 63.48718943134431, 2.345355258833978, 0.381306505371486, 0.7415460218344966, 1.3563431030319584, 0.22850841494096866, 1.7787056392238987, 0.7782733800911135, 0.1702271882564791, 0.0656187172318178, 0.853628975249106, 53.18804164086619, 94.65675507822345, 75.87935709184217, 92.62515560273202, 76.02391996691304, 82.66588118768509, 84.0626528955275, 91.5292610660676, 81.99763482616794, 76.83973373905306, 77.78373056842436, 81.68986997296734, 82.06834731563445, 77.95617365068006, 74.0567885675738, 70.51313892487558, 68.2277464097546, 61.15580320358277, 52.90144581948557, 52.48772990319037, 57.35186899861982, 60.417248356726866, 60.24178897180865, 58.10220272310319, 56.24659607487341, 57.56368875503541, 55.24939621648481, 53.7681366551307, 56.32914627751997, 53.974049322066776, 53.997403114072746, 60.066333509260616, 57.41567811658306, 59.81114018347956, 56.332786237039876, 65.64906650973906, 67.83022203753072, 75.34915462616952, 68.69177064587994, 73.45618740204843, 28.860189799339544, 45.143491837286184, 83.90554628064557, 65.25472317972492, 73.01314000160464, 60.07084031258861, 61.20414249358639, 55.046911701079345, 57.697672997751546, 54.478250395867136, 58.26839746967439, 50.82495481737199, 53.51224514745898, 49.122285304530976, 51.11550046551613, 50.05005528849941, 52.12946061165103, 50.897114661432084, 52.78801479647237, 52.81702072389665, 54.19737731256793, 55.0303828331732, 52.85606399659188, 50.73017466452814, 58.93186638432165, 72.48001144778344, 69.15700297201835, 70.38212391637987, 76.60963966000465, 72.37519002729847, 72.64486082138555, 68.24868402173443, 71.0314016957437, 63.201378083998165, 71.21564326747772, 71.27648707359069, 72.73680117822462, 71.86706266095563, 74.08725753907235, 65.14950167748236, 66.60279473950787, 72.65247806426018, 74.97017522012034, 63.532198629071644, 92.75657853772564, 30.286110601117535, 0.18527634201511262, 0.08430345614831294, 0.29884308516498537, 0.12089892470788573, 0.3809779149390036, 0.07268739518739524, 0.03548363366374566, 4.126002471293173, 44.217639892332016, 56.772146609521684, 39.80318484767791, 63.471829429749526, 43.11222184088923, 66.88302455409881, 1.9003532923037008, 0.07210290074468621, 0.12092117956208608, 0.014940478440914905, 0.019654309369563576, 0.04796813955650695, 0.04536895644700816, 0.029727379235649304, 0.01843381447777633, 0.0551206466831988, 0.10127189764452559, 0.03014494120443781, 0.04282323095286566, 0.09211192989060957, 0.010746935168431412, 0.017062013390504064, 0.02275598295513661, 0.016207386769594687, 0.06903508633014656, 0.04522806521685374, 0.019613434748363592, 0.02162619478880398, 0.04136213274191945, 0.04722586164491312, 0.031515732970869834, 0.005525176454665921, 0.06450166910766594, 0.028536863279558962, 0.028430045725056724, 0.02941948083800174, 0.02648735208617103, 0.02666506150196637, 0.0945628596650016, 0.02188381483598102, 0.03313693781233123, 0.030527785983717734, 0.05253546383051623, 0.03930172011736901, 0.025482832701996933, 0.041853076357754974, 0.02710663841196126, 0.04217772143742731, 0.10443788622656178, 0.06332053772864804, 0.028968645755441922, 0.05313910664089265, 0.0419925005295344, 0.022518059028492823, 0.06429370687974077, 0.031002000154506777, 0.027617371994100755, 0.029197790314473455, 0.05933702990953481, 0.030360861170676448, 0.01923343790094218, 0.06224894160104375, 0.09842381256842807, 0.16113798404412885, 0.0958823541840238, 0.4306295135569188, 21.656807968693396, 86.85378013118621, 42.51094602769421, 27.268193883280603, 99.23027007810532, 59.07584482623685, 4.3638770618746365, 0.3262709021087616, 0.15429488833873503, 0.9710644930601121, 0.5136855180946089, 0.8538619272651211, 1.248502070384641, 0.3366508725429735, 0.022199366451992143, 0.9793929719636518, 62.29894268897272, 97.2769061980709, 81.68580639746882, 96.00849797648769, 77.99799396145728, 84.60187681259649, 87.9325495996783, 90.06530700191375, 80.67887121631254, 78.01387956065517, 77.9528788597353, 81.23036430728051, 81.91950905707576, 79.70377783621512, 76.66638066691738, 75.66630178882231, 71.44987152468774, 65.77424895378851, 56.5076494216919, 55.336174734177135, 58.69270378543485, 59.900177986391135, 61.08134092823152, 58.60568992553219, 56.57607516934795, 58.91354499324676, 55.48496592429377, 56.14060578807708, 57.694197777778875, 55.918854590385195, 56.455391683886134, 62.81749179286342, 58.3628716776448, 62.78492435332268, 59.87385103779455, 68.94071563597649, 68.83245821922057, 77.44217057381907, 69.23273609530541, 73.53416412107407, 33.05327999976374, 45.66057005236226, 86.7635577724826, 67.48251176649525, 74.63504006785732, 60.42111973608694, 62.51903472408172, 55.54587641069966, 61.6455856446297, 56.426013131295484, 61.40065323921942, 53.61518775263141, 56.46091045871858, 50.6524097534918, 53.033723831176765, 52.358217162470666, 53.22963445417343, 51.978802373332364, 54.7108155681241, 55.491190725757235, 59.037421288028845, 56.1500822344134, 54.88418825211064, 51.468003872902166, 62.021870382370494, 73.24424605215751, 71.15885519212293, 72.56871977160054, 71.46556885011735, 70.96389770507812, 72.87835951774352, 72.27012541986281, 72.02896241218814, 65.0724624049279, 73.70379094154605, 73.2321886862478, 73.0406044375512, 72.19139560576409, 77.89493760754986, 69.3537804388231, 69.81905198866322, 75.06183316630703, 79.43216939126292, 64.18906227234872, 93.12579908678609, 35.25474948267783, 0.1479671553017632, 0.2223247064337615, 0.5371052243055836, 0.1194368382435172, 0.34125389651425425, 0.06169735829556181, 0.02487064418082516, 9.993433356285095, 42.05191889116841, 81.66604549654069, 47.59035656529088, 69.27884747905117, 47.44003172843687, 76.97370621465868, 3.6954576257736456, 0.09901203019844909, 0.03376957705064166, 0.027223625783658317, 0.045121257238450556, 0.09647613361237511, 0.059589206902009834, 0.015181013769770582, 0.11453669473168351, 0.04025974371019871, 0.024852901584498828, 0.03841735204801925, 0.03576197255883486, 0.05387064016934845, 0.08546512123317489, 0.03570526673067962, 0.010392197197483433, 0.025028226551629847, 0.0644725960709395, 0.030766952888018666, 0.04845481606260423, 0.03839258442542726, 0.04133795883746878, 0.055116578756320866, 0.032805623937278025, 0.05052708006734329, 0.0691657962517873, 0.21080062964991217, 0.13574149519685777, 0.13091576946598868, 0.16742712157147546, 0.1542745870087416, 0.2373944679575582, 0.18880627598733674, 0.17890566208910558, 0.05871252269454061, 0.10750221494104593, 0.1175369708348186, 0.13405843067073053, 0.13499443689661642, 0.10010040365159513, 0.19898681841309995, 0.26537429721605393, 0.17423473208421664, 0.09854881513503291, 0.22724930347213823, 0.1699620758694026, 0.12093583482407755, 0.18899245067469536, 0.1181803621171463, 0.20295310074523573, 0.13040613713524035, 0.1793453965576426, 0.12792532227092213, 0.1753073624305187, 0.14367465740971028, 0.22434550848218704, 0.4109053848491561, 0.38913390148551236, 0.891537947520133, 29.485911784633515, 98.45302104949953, 75.92522528863724, 46.654635936983176, 70.6253344012845, 87.59231536619126, 6.046387553215028, 0.733230168059949, 1.6847716151706635, 4.600348914823225, 1.3197581758422237, 6.8441201794532045, 5.17207702321391, 0.1936319097876549, 0.11002816004498352, 1.3586740940809252, 60.757980731225786, 99.39044398646202, 82.2993278503418, 99.63331714753183, 80.67751407623291, 86.6522095280309, 88.84885449563303, 92.11590643851989, 84.37929799479824, 78.7104925032585, 80.86264994836624, 81.43214671842514, 83.48946909750663, 82.96253004381734, 80.4704599995767, 77.25176303617417, 75.13481278573313, 67.64762001652872, 60.789340080753455, 57.446853114712624, 63.7083169721788, 65.16277890051565, 65.01245014129147, 63.914578730060214, 62.65544299156436, 64.54076943858978, 58.11420909820065, 58.323389099490264, 62.719271721378455, 59.63934036993212, 60.5816819590907, 65.12007605644965, 63.84197173580047, 66.60982362685665, 62.77278461763936, 71.19195999637728, 74.37668923408755, 80.15442679005285, 73.89221375988376, 73.90782479316958, 35.400430233247825, 50.791567602465236, 89.03876781463624, 72.68734009035173, 78.90751315701392, 65.98920268397178, 65.04607269840857, 58.42511969227945, 62.973590358611084, 59.897291121944306, 63.595921454891084, 55.42165102497224, 58.93354908112557, 54.09532116305444, 56.00400924682618, 56.07250559714533, 56.53143075204665, 54.5740346754751, 59.00539513557189, 59.109341867508434, 62.3816890101279, 61.362978873714326, 60.213257651175226, 55.384133554274044, 64.83323312574818, 79.05818708481328, 74.97716488376741, 74.45250080477807, 73.55550965955182, 77.40563761803412, 76.97569877870622, 73.50782148299679, 76.46366473167174, 71.0945047870759, 76.18800840070172, 76.02038983375796, 75.37531683521887, 76.5602570195352, 77.73070796843498, 73.35597084414574, 71.70005598375874, 78.7562979421308, 81.23581640182003, 68.20345909364762, 97.16060792246174, 35.74946626540154, 0.1941943715416616, 0.3763289869793, 0.8220503407139933, 0.48375412581428406, 0.760830661221858, 0.20422091497288597, 0.16551006314975603, 9.425560447477526, 62.868478682733354, 71.39642530871977, 49.02785424263247, 76.83674489298176, 55.2146008706862, 87.18537730555381, 4.178290607467774, 0.3472394640407255, 0.24235732342687347, 0.0919053466209481, 0.14721991314042002, 0.14412053590340002, 0.10574204366533987, 0.12178876647545446, 0.16926173361078387, 0.1711447624069068, 0.22111246422413858, 0.09834871296921084, 0.23323232758670087, 0.19189613841233716, 0.1706511413137759, 0.11732214445909185, 0.2996813079282161, 0.12176830426699693, 0.18522559635100827, 0.13804129114554775, 0.0690818943023201, 0.12765932122185347, 0.14731444839027621, 0.14229729260888793, 0.06523808644663903, 0.19879344249925307, 0.11400470029442542], [0.03406669276075498, 0.020623648081034906, 0.05579616003219159, 0.045923278516819405, 0.015907855009690167, 0.041930267377005476, 0.07472692042469017, 0.02662405856103907, 0.043694108213868835, 0.022013253051667445, 0.061560140457004316, 0.05406787333589408, 0.015425511688414602, 0.037570844043887434, 0.010890831378468824, 0.008183532195436138, 0.034714730366343455, 0.057569680389978235, 0.043563402122667724, 0.0271728839499936, 0.17277784735685395, 0.05895535724477903, 0.0550150529541556, 0.02147364561566182, 0.06259496436424314, 0.029661118375858473, 0.0778021582312161, 0.01286168640945107, 0.04941755492660788, 0.05995930014779011, 0.07069320703345923, 0.1471823288668548, 0.06634514478425826, 0.09732176444583363, 51.55496281962241, 76.65566475160661, 52.11446539048226, 14.606073998635816, 66.85992179378387, 64.58143265016618, 5.1544812706209004, 0.3636577088505991, 0.42978850223364373, 0.37214856775056937, 0.13460244502752058, 3.188917103313631, 2.565773586111684, 0.2398645039647818, 0.036043578818921125, 1.4119498095204754, 74.23096533744567, 102.31164486177506, 77.4022408454649, 90.02573028687509, 92.34893445045718, 92.1036764883226, 81.57183016500166, 83.11006607547884, 82.68634811524423, 83.19039621660787, 80.87413464823078, 81.52017254983225, 75.58332797019713, 76.3743523628481, 71.10563647362494, 60.41079998016358, 58.3335284263857, 68.06001801644602, 69.82617501289614, 64.13834994839084, 69.6491192233178, 66.14230063653761, 71.19267386774864, 68.05632314374371, 63.94599299277029, 56.31617499936012, 55.872429417025664, 50.15280961990357, 55.51409344519339, 49.87964791636313, 57.352806445091005, 54.33460535541658, 61.466129364505896, 57.22237979212115, 64.63196454509612, 64.70214751458937, 77.28638187531503, 63.75529127736246, 83.3576774597168, 33.33719291994649, 40.055452085310414, 82.30706276432161, 67.010909511197, 73.31737472165015, 62.24519837287165, 64.96073369056948, 57.48133859326763, 57.843098794260335, 51.579913016288515, 56.39376732610888, 51.915577688524806, 51.9329067199461, 52.02064621833063, 55.015234639567716, 54.14159336397725, 55.177169692131784, 55.29508398425195, 56.13278458195349, 56.82608704413138, 63.03914100893083, 59.15598669359761, 55.596306324005134, 50.377298631975734, 53.923348765219416, 69.16747570037842, 76.56843908371465, 73.71657002356746, 71.81963336083197, 77.78253032315162, 77.45255701003536, 73.72948246617472, 72.93155470202046, 70.19422669564524, 71.71919715019965, 74.86343968299128, 81.8981086054156, 68.93705214223554, 67.10390106324228, 78.16889947460544, 76.09606804386263, 59.28417759556925, 63.28391651953421, 82.18260595875402, 24.451747748159594, 0.15059958662717574, 0.31780799009626914, 0.03325968041955944, 0.6285543042805888, 0.3264221891520485, 0.08835014706898121, 0.17295066147081314, 7.708806193644001, 41.252622219824026, 67.77367714912661, 5.946871138388111, 13.292341809118948, 32.75898260454978, 73.22788976853894, 14.538850457437578, 0.26190940410860125, 0.06135493231516692, 0.11438720799501866, 0.09788055663868304, 0.02798840178236846, 0.024030555993498817, 0.1294985221278283, 0.05336516003514971, 0.06557747105797453, 0.07730360353185285, 0.04571277670742524, 0.059486547289716626, 0.0637622372127108, 0.02638726844452322, 0.06702517805200431, 0.015063003670694608, 0.0646376803577427, 0.032744620355867574, 0.0616059371931178, 0.02992459899565626, 0.02920026286324907, 0.06448704448919143, 0.012281875636789107, 0.050965558151684465, 0.010699883963341915, 0.032698279697327845, 0.007870852451531157, 0.020410736925118876, 0.032257315657672384, 0.051261241277379375, 0.07086035209677874, 0.04216361009786206, 0.01627338907471107, 0.05561568886942922, 0.03805128076384145, 0.1068864334675093, 0.04165269456984055, 0.030307033917896693, 0.09700448147111362, 0.09455717529260343, 0.05834092791642874, 0.06174417009817497, 0.04851729819370855, 0.030258946578889608, 0.07334492845280517, 0.02096312462292131, 0.06033340386385399, 0.010757641247173232, 0.0752066063784784, 0.0537068888755335, 0.0187018035250085, 0.0343296601016435, 0.04491221482655214, 0.064537008743613, 0.049942807790132306, 0.032423189015037594, 0.04029660403067547, 0.05295508849104086, 0.032943362715624036, 0.046849111095070846, 0.09837760214483547, 62.69884401752103, 83.95853750167355, 32.94159443147721, 24.81050733597048, 107.70239353179933, 59.11872025459044, 10.01551139739252, 0.2133970088776081, 0.48895316619065504, 0.7770156475805468, 0.10390077432196948, 1.4493062178934775, 0.9656868622668329, 1.021337021262415, 0.11750052037138133, 2.3700161806998716, 86.06729784319478, 99.35293043813398, 83.69540137629356, 93.77626926668229, 92.45934917080788, 88.24065962145406, 80.84056700429609, 82.47179446681854, 86.10357192254837, 80.88877293371385, 81.06968049080142, 81.91870104882025, 80.79553034997757, 80.4928175095589, 72.491041152708, 63.51886649285594, 60.30906938737439, 69.24797842579504, 69.51765706462245, 65.2504046501652, 68.47695027628254, 68.28796263664, 69.5242388017716, 67.48602621016964, 63.27829968544745, 58.78166706331315, 57.05604384022375, 54.818198296331595, 58.51318082501812, 54.706877508471095, 59.847818266960886, 57.32056848464474, 63.24198246002198, 58.504932080545736, 66.29062114223358, 68.13752405105099, 80.10037652907833, 66.94496662386003, 80.08191785504742, 31.91140155638418, 42.45388730879753, 83.92376961246615, 68.48062945950416, 76.21051496075046, 63.63160325634865, 67.31217107465191, 59.86177406003399, 61.46661573840726, 56.27298970376292, 58.51271014059744, 54.445286796938994, 55.181233267630304, 54.68508481979371, 56.45827462596279, 54.48347891530683, 59.04154369907995, 56.782572269439704, 57.7095381675228, 56.953579764212336, 61.626836715206025, 58.691840863996944, 57.75111136897918, 54.25269057673793, 58.58215178212812, 69.25800400395548, 75.64286170467254, 74.23982204929476, 74.68257134960544, 76.65775929727863, 77.01076476804673, 73.38738118448566, 74.3747123595207, 72.11707453573905, 73.52976322174072, 77.1107538284794, 82.19236481574275, 71.75971523407968, 64.63216458597492, 78.38636352169898, 80.9399284855012, 64.45963128920525, 62.252337086585264, 87.93641705666819, 30.349209770079586, 0.08170320051572016, 0.21556001216653856, 0.12854319516449206, 0.5109716669446038, 0.3782181291570587, 0.10546471983675035, 0.04348002877386828, 15.287097480989273, 36.274487280076556, 98.0934024626209, 17.392056065220988, 16.01094049792136, 36.84721216078728, 78.75090860551404, 21.715872979933216, 0.5322734771236297, 0.09361140144568297, 0.1261855595775189, 0.24044993303475842, 0.06545836736838664, 0.025063931994560747, 0.11781703725817705, 0.017032699036081473, 0.038114134447589036, 0.023727497356312893, 0.023818941441394632, 0.04620845091619319, 0.013788014072023574, 0.08051707424343595, 0.06443652865146438, 0.006982256055644323, 0.10276167818735685, 0.0220661131184428, 0.03221101330352887, 0.044191647846732414, 0.018781356010285598, 0.042853004960042816, 0.021878869738429788, 0.04662555131700732, 0.06936808176819356, 0.05943684350518931, 0.05135665752834851, 0.1298542320728302, 0.10651589972117256, 0.18040449779120185, 0.12659262039608535, 0.09307766032795753, 0.09399887339602556, 0.16202681457563756, 0.14823370793413732, 0.21073647744713292, 0.07594454057154156, 0.14426734899320912, 0.25396920920860383, 0.21244030295600816, 0.1250535574170851, 0.15320457668314058, 0.1140570470822915, 0.08504837706324556, 0.18967354880465617, 0.1536365123766084, 0.21406886798720207, 0.24249056143866432, 0.15642948508743318, 0.18539729197659802, 0.08677434251313249, 0.20285102719020462, 0.12281258936010062, 0.21086173282275278, 0.17107612092889127, 0.13449030507716442, 0.060968812510010705, 0.13546862999998754, 0.2345956576567504, 0.1721429290069688, 0.15418759006406033, 75.77398653953307, 93.72669835244456, 77.5236931154805, 25.169074727642922, 82.41918763806744, 86.80200484491165, 11.665843744431774, 0.6320035385508692, 0.7686227560043336, 1.1564520097547963, 0.9503701906050406, 7.789492780162443, 8.595688900639935, 0.8830172111911159, 0.23031895649769615, 2.27035463817658, 82.20907411267682, 107.52478076565652, 85.02907783754411, 94.89976944461947, 97.31183882682555, 93.6019277572632, 83.31196615772863, 82.93376338097357, 86.06718801682996, 80.64191464454898, 83.03513311570691, 85.26842086545884, 83.50568417579898, 83.3994193230906, 80.1492492614254, 67.35272838223365, 64.44494201290992, 74.10456303627261, 76.23452771094539, 71.09095896444013, 77.08171259972357, 74.080762094067, 77.6892485157136, 77.03538940798852, 69.82560234685099, 64.35301734555152, 61.04605136379119, 58.428304656859375, 63.08151437390236, 57.94968135895268, 63.52707209125642, 59.1035367596534, 67.85207748413086, 65.68755280586981, 69.97952399715301, 71.78009586949503, 83.52430758937713, 70.7550314934023, 84.2404382459579, 36.87069539100894, 43.32524184257754, 84.87173588045182, 72.88805561680948, 78.11044831429759, 66.98725761905794, 71.73304311690792, 63.41473933189147, 64.86053674451767, 58.2092716616969, 63.01728163996051, 59.19683033420194, 57.86919432301676, 57.139045115440126, 59.44450055399249, 59.79707456404164, 61.51317427235266, 60.71575249395063, 60.790963942004794, 61.44195187476374, 67.61329927752095, 65.26004975841892, 60.036119491823264, 57.827550518897276, 60.347363487366714, 73.74003364193824, 80.91914776832827, 83.25855132072203, 77.09921421543245, 76.58784697132727, 81.3243599860899, 79.91593883883569, 79.32146441551947, 75.31776782005065, 77.99356168316257, 79.834228023406, 82.86326269949637, 70.90565050801924, 68.58126963338545, 79.25929484828826, 79.22706865495252, 68.81376420297931, 68.51898239504906, 90.13041050203385, 28.804919681241437, 0.29372105194676307, 0.6376917720321686, 0.4438533862271617, 1.9667302144150582, 0.6281936300858375, 0.325460227867288, 0.2111604611479467, 14.626966503358657, 57.68946347698089, 83.59713031399636, 13.49962926680042, 25.227861250600508, 45.81078506285145, 92.23501313117244, 26.892446510253418, 0.708817397394488, 0.2199704416336552, 0.27094182588400384, 0.273739701557544, 0.29802974493753526, 0.10787579771732131, 0.2573265129279706, 0.12648321537961885, 0.23268912528311056, 0.18728957511484626, 0.12541290627972734, 0.1424309596299164, 0.11353751689556146, 0.14659740541490818, 0.18360357371068772, 0.09013846441502534, 0.19051099015820414, 0.1536409863300862, 0.11290933245853071, 0.12039932812894545, 0.0891712554279835, 0.15837131879262387, 0.0880684258957063, 0.12306330695507989, 0.1457181356606945, 0.1400405508015425, 0.12012955026641009], [0.09464951187011697, 0.05223870818172732, 0.06119125379970478, 0.03164779695291673, 0.02885793838950415, 0.013052497843971417, 0.02809925853545147, 0.038157609937291954, 0.018475181310467662, 0.0627250001285105, 0.04608975325320517, 0.05225402994021293, 0.011436064772668385, 0.03770498603942894, 0.09411751743285887, 0.07419581464942425, 0.021747271154796886, 0.016133172001930016, 0.026151441683572148, 0.062169184187246915, 0.022345786921740062, 0.026124875669577913, 0.03559337192845922, 0.04244097223084781, 0.014794162350646673, 0.04477085245232429, 0.03317966253586835, 0.05060235969722272, 0.1635437759180223, 0.027554039505400488, 0.05883235416765656, 0.0628763561197106, 0.031418893711581346, 0.049575851674401955, 1.693100277935305, 65.87153942354264, 60.98309340015535, 57.45825152243338, 15.423564584024492, 59.114138926229174, 70.19858052653652, 10.829808192868388, 1.3542730721735186, 0.031718426429095774, 0.2390009083694989, 0.5450013844716934, 0.6691925720341745, 0.8196985733605201, 0.4861438604852846, 0.1643065083771944, 1.6809503686043525, 62.798852689804576, 101.09156808545514, 85.27890928329961, 80.53670883178711, 89.12802527027746, 93.54371978390603, 91.22950569275888, 85.30015284015288, 78.36300188495268, 81.6381888235769, 84.99306263462191, 81.40727104679232, 75.38404803122245, 71.43206396410542, 72.51282599664503, 74.33490030227169, 71.24707714203866, 75.38530318967759, 69.4013430995326, 75.30763241552538, 73.85641820969121, 77.17430407001127, 75.99679285480131, 77.721921859249, 71.00902065154045, 68.59448017612581, 55.90385152447609, 55.9928697155368, 52.379664682572894, 54.95463009803526, 54.27699750469577, 60.903794842381636, 55.51657238314229, 65.17022355910271, 62.17161078606883, 75.05267835432484, 67.52807401841687, 86.3941175706925, 40.47420432490688, 32.34028920050591, 88.49937131327968, 68.92913679922782, 76.14184210377356, 64.63428658823814, 67.99728362791001, 60.22717029817643, 62.56836637373894, 53.62433079750308, 54.44278824713923, 51.372419634173, 52.49176209972751, 49.06255545154695, 56.48046347402758, 57.765600604395715, 62.46554536204185, 57.050548599612334, 58.95668322040189, 61.412663536687056, 64.93061773238644, 63.89522967800018, 62.13870994506344, 56.33952879136609, 55.50564073747205, 62.43724153887842, 74.91071208830803, 75.48387235210788, 74.78790267821282, 75.87015521141791, 79.56720090681507, 76.08651315012287, 76.99708354088568, 74.4677431352677, 75.7187674122472, 75.72153660558885, 73.55623137566351, 74.750302837741, 79.05672011836883, 60.73457987077775, 54.01478313630628, 67.41109325039771, 66.25389206794001, 9.788665040846794, 0.11143875773996116, 0.17448620810624094, 0.24946249781116364, 0.5956762620518284, 0.18040688798552562, 0.6011985302452119, 1.519330821691021, 15.102685286152749, 49.415913935630556, 68.77215570019138, 6.9385693823137595, 28.99843373606282, 42.98490562746602, 68.09668433281684, 24.008406169952888, 0.24196861041409357, 0.048117093862064426, 0.012506437074813633, 0.03390634289732383, 0.03491640301241029, 0.061141147819017215, 0.02848323904007914, 0.03612811279092585, 0.10591991395959932, 0.028648204583254074, 0.052963791249860684, 0.013259580028393577, 0.12940250066739897, 0.04865923130343999, 0.0202464263871192, 0.06037278078316201, 0.019765911143152945, 0.06712604884899433, 0.017586954073199344, 0.06619751964124941, 0.06628241750501818, 0.026191098224972526, 0.01994498994111294, 0.019397355818880663, 0.04318877363637571, 0.0679159774294784, 0.064241953810016, 0.014403236301375494, 0.09506503029936746, 0.028411891356471087, 0.04642663658746789, 0.03253786854686276, 0.02268832590010378, 0.02846276150986312, 0.025008944118575707, 0.05809278820731467, 0.03506141196515772, 0.07407504854904068, 0.041157196561295184, 0.05447777634065959, 0.031248230389469576, 0.03275873169543282, 0.04723868212632595, 0.03345450040914359, 0.03634360183270709, 0.03659466033681266, 0.050198991422451315, 0.04256421662566643, 0.06794957038495811, 0.05189389200700868, 0.0177083081460648, 0.04267779682132025, 0.019260959609621958, 0.05284349629355054, 0.08170238080164118, 0.03870648895240119, 0.12262684368197957, 0.03757181697555127, 0.014354846357638317, 0.1129044984437285, 0.09664616682716916, 0.12935325653562624, 3.833860173340767, 80.8101607907203, 59.75654079068092, 24.51312695780108, 30.02261754005186, 104.47538114363148, 60.12774998141874, 17.44675547845902, 1.5287584835483183, 0.46869501291263493, 0.2701199667588357, 0.6550981476902962, 1.4110374907332084, 0.09805853418525189, 0.3992545051920799, 0.32479701022947993, 3.2774430369177177, 74.09952671297135, 102.6719851647654, 84.3977645135695, 82.53568987692557, 91.8898916244507, 93.74815371728714, 85.67168758761498, 83.26101456919025, 79.22275404776298, 80.80972148526101, 86.84741020202638, 82.11959700430594, 76.74368273827338, 75.4407419696931, 74.09906387329102, 74.77819088966616, 71.87864934244465, 76.94206837684878, 71.55706990149714, 76.43536875324865, 75.26132491327103, 80.67386627197266, 76.95641640693911, 75.56015460721909, 70.63711720128214, 66.85443832028297, 55.681308008009395, 58.60700784191009, 54.21307856036771, 57.99111335508285, 57.35481469861923, 62.83728407275293, 59.822440531946, 68.63387646213656, 65.33243709994902, 77.33989869394611, 65.50256206143287, 88.17758006434288, 42.1493701780996, 36.54415022942328, 87.97158502763318, 71.70124053955078, 77.61775939695298, 65.05137182051136, 68.07486810991841, 59.77699987349972, 62.52012122061945, 54.81931617183071, 55.92449888106316, 53.657549350492424, 55.87355905963529, 50.86582199219735, 55.81561780744984, 58.36515057471491, 60.214097038392104, 58.597535317943944, 59.78665674886396, 65.35320997238159, 69.98703925840317, 65.52258968353271, 62.61585843178534, 55.36078368463824, 56.507272874155355, 64.94393025675129, 76.31265348003757, 77.45236873626709, 74.65760154108848, 75.023158596408, 79.2492457359068, 77.29981991552538, 79.24859462245819, 76.42813590265091, 77.25455576373686, 79.24428786000898, 74.72833756477603, 75.21562930076354, 82.5844684723885, 67.56280268392256, 54.807800093004786, 67.56095916994157, 75.8394116740073, 13.143440792637488, 0.18898117386044996, 0.10361398164663585, 0.11166417911168068, 0.32264252583826747, 0.31956772470185835, 0.6773904482683828, 1.86883018382134, 27.394062742110226, 40.98468119098295, 100.60961861764231, 19.09395875469331, 10.2095785064082, 37.24303422435638, 73.85252721848028, 34.52028566791166, 0.1872996261884128, 0.04521591889281427, 0.03117172884935093, 0.013932104676871771, 0.07140223672913928, 0.01748757523244187, 0.01647180010144028, 0.037975422737579194, 0.04456442240024767, 0.02671629554712244, 0.008662795843256098, 0.013578781095753997, 0.04685516318967266, 0.04194613305791732, 0.02716469063964342, 0.06683694258812936, 0.01505256284989657, 0.018768836218383045, 0.01886218211673681, 0.03858641616158909, 0.026004015723423615, 0.056167264514031916, 0.06531455734324071, 0.038786545140488494, 0.012966650031176547, 0.031591081548662435, 0.017043543010649663, 0.018181373184967427, 0.18915162842360236, 0.10087119535573068, 0.14174198611609398, 0.1534778862110069, 0.1494485701644613, 0.10293036308740416, 0.06264788954849206, 0.10419348119607857, 0.09681874345387183, 0.1967629111341892, 0.21903751508122493, 0.1751471121585177, 0.10421045004360138, 0.09267321953009214, 0.19879521982323742, 0.21014560915289388, 0.1418450402636682, 0.11506558651284826, 0.12191238242291635, 0.1403827622773186, 0.12115521176207451, 0.16238145199754547, 0.12429155274144105, 0.15054418314849177, 0.1187983346021464, 0.16521061470191326, 0.18260143877517793, 0.19568032164487148, 0.2511753325140284, 0.14102719543922332, 0.16909684084596174, 0.20827603286072133, 0.13641681702386949, 0.19407106202936944, 3.712772683751199, 96.42561066535212, 77.86371554097822, 88.0766967035109, 29.965433305309666, 72.96138040481075, 89.94671806212395, 21.68525495836812, 1.4068317293159425, 0.5004839232612042, 0.5832938910011323, 1.0599928373290648, 3.1869517507091647, 3.136043308242675, 0.7413399748263821, 0.41769136103891563, 2.887500851385055, 67.74696580825314, 104.90167217869913, 87.92936463509837, 84.1070855048395, 90.78744672959851, 94.7569481019051, 92.07581197061847, 87.56058339149722, 79.23686673564296, 81.12120474538496, 90.34935720505254, 89.88378755507931, 82.33903792596634, 79.27645914016232, 79.3947107561173, 83.18699944403865, 79.86748972246724, 82.47266523299679, 74.87515972506615, 82.41654396057129, 81.53118656527612, 85.22572978850334, 84.72712593693888, 81.6543960571289, 77.6131937580724, 74.14056254971412, 62.2457161257344, 63.13860447176042, 58.246640082328554, 62.79162768394717, 63.429118740943174, 69.40829353947794, 64.77115377303093, 72.39506859933176, 69.47287928673529, 81.0144848977366, 73.72362244513728, 91.04538179213002, 46.68687781979961, 38.61176883020709, 91.41040540510609, 75.10856428454, 82.83275450429609, 70.8760444579586, 71.6918739195793, 63.83296597388483, 67.46038175398304, 58.05680913309897, 59.766574213581706, 57.39567010633407, 59.894153225806456, 54.389965688028646, 62.16689217475153, 64.69635809621504, 67.61640579469743, 62.55373201062603, 64.66423388450377, 69.20650328359297, 73.72831359986337, 72.32668599774762, 70.14487543413716, 61.870168793586, 61.17233207148891, 67.14889849385908, 79.33450237397226, 80.31719730746362, 78.60883251313241, 81.91850493031164, 79.0381908416748, 79.55541810681744, 84.87668591160929, 82.53783149103965, 80.04922097729099, 80.12284386542537, 76.33284584168466, 77.07009453927317, 83.93531707025345, 69.19224154564643, 64.16407285198089, 74.15033709618353, 73.72525415112896, 12.482600846598226, 0.29054025488515056, 0.432313681249657, 0.3138835361647991, 1.466908834634289, 0.5659013662126757, 0.8398486469541827, 2.064825628072985, 27.168520573646795, 67.87324259358068, 82.12647684158819, 15.89955989391573, 42.07393907731579, 60.80271144067088, 85.00408449480611, 42.588675637399, 0.32554897149243667, 0.10316705361248986, 0.08332527678219542, 0.2540279068653622, 0.13849008077334973, 0.16079753457057863, 0.16799914410277722, 0.18731093364617518, 0.1631598126503729, 0.12084899109698112, 0.17590137168524728, 0.08094156356227976, 0.2438290396164502, 0.2130273561323843, 0.12184413164974221, 0.12859366503694367, 0.0791391195549119, 0.17046331187650082, 0.11438490973124582, 0.13478949305511292, 0.16155652852068025, 0.16145860716219873, 0.14838966811376234, 0.07706500544783569, 0.1558288721547973, 0.14944467843780596, 0.17109858262683117, 0.1856477567625623], [0.02826325497740219, 0.06421825488007839, 0.014577570142254475, 0.025884371941849112, 0.04430551915579746, 0.02020179601987043, 0.04942475615309612, 0.0394608787140779, 0.0046091565051146095, 0.035931982790991183, 0.05375165522338883, 0.05627462407574058, 0.0163391845360879, 0.028460804155216585, 0.07734658872528423, 0.043200096415896574, 0.10526781225757254, 0.0177437626952005, 0.029131548606880733, 0.06928791832779685, 0.029739351274685997, 0.07151498188895565, 0.017985563026741147, 0.042022075353851246, 0.010511364089325072, 0.07644636646634148, 0.007733928599214603, 0.013950082845234824, 0.105438994604253, 0.010885689013277092, 0.052366729134753834, 0.08535151805488334, 0.07371213737755053, 0.05258086220090909, 0.27716589190306207, 8.628491682391013, 85.77823485097578, 55.43405748182728, 53.108531275103175, 21.976592925287065, 63.09189296537831, 87.32076183442148, 22.467555999755863, 4.106157484554475, 0.03474229420985907, 0.33566044343094675, 0.2585873404337514, 1.0851354752817461, 0.19143620986611615, 0.02572494521436672, 0.04319574503648666, 0.2646301194064079, 30.42183049263493, 91.06012990397792, 101.56586893143194, 91.63789503036007, 77.45286295490881, 85.97473775186847, 86.42477481595932, 94.60611727929886, 87.4092818844703, 80.56873890661424, 81.16276617973082, 79.39882924479824, 79.06762430744787, 77.27318702205535, 72.13392503799932, 81.58810015647643, 78.2896770969514, 77.75699569332984, 74.6655325735769, 77.97997459288567, 75.88448755202755, 75.71118154833394, 75.96498243270382, 71.91169923351657, 73.68786611864644, 68.4961385111655, 63.55553280922675, 52.92512909058602, 56.908150872876575, 54.20361388114191, 62.98554182052613, 60.90034707900017, 67.36869242883498, 63.382462147743475, 76.51620880250009, 63.49487335451188, 85.66061865898871, 38.44930425766976, 28.138287375050208, 86.61242100500291, 67.32078459955031, 78.58976194935461, 64.3999053585914, 68.63893631965884, 63.78269295538626, 63.979988175053755, 55.69988043077531, 55.88207060290922, 53.1812677075786, 55.663414155283284, 54.95005269204417, 69.24602508544922, 72.02604416877993, 72.40757311544111, 62.40037125925865, 61.7484615695092, 66.39956889613983, 71.71864801837553, 67.09707613914244, 66.71522555812713, 62.43083238601685, 58.56152403739191, 58.75639915466309, 71.34108066558838, 80.08729934692383, 80.67122259447652, 80.43717476629442, 77.40249187715592, 77.55944159723099, 76.02391996691304, 76.50543012926656, 75.75824214566138, 77.76677808453961, 85.08364585138138, 68.3305674214517, 53.91500980623307, 75.90870426547143, 73.48493053067115, 38.66529349357852, 2.408733161226396, 0.058344306364174814, 0.2576839389099229, 0.1831430935811612, 0.2923257300449956, 0.01591714382577207, 0.27753226579196993, 5.9073424723840535, 18.50102190048464, 53.40181473762759, 66.38256149907266, 6.7193515454569175, 32.44984099941869, 44.80061784867318, 63.72694823049731, 32.20557539693771, 0.2343947434377286, 0.05951230699617056, 0.07474267119241339, 0.018199833988722776, 0.015864516458203717, 0.030433530355953885, 0.043273499130361506, 0.0320124299070167, 0.06122736335401574, 0.0688767359561978, 0.06716909532945964, 0.04832094602827584, 0.0217686967188192, 0.08913973857077861, 0.06014374730687949, 0.05943355698799414, 0.05826069552811885, 0.04664946475156373, 0.09768309747619976, 0.034892734725989645, 0.028785234730270122, 0.018514196253231457, 0.025367253016860738, 0.028241147595127265, 0.015135168195551923, 0.01670292116731646, 0.020272697457262588, 0.03626012889247748, 0.017159362098262194, 0.003414499364988578, 0.07991016406806246, 0.03642370781650947, 0.07307325069221758, 0.08123051660555987, 0.07248330170348768, 0.03591782165571086, 0.04011600263296597, 0.010586502950548405, 0.018599235843266212, 0.11516807375535851, 0.04552099042602124, 0.03275894620005162, 0.038647768313005086, 0.04319947588467791, 0.031383979254432266, 0.049095717559178034, 0.02601476202178146, 0.02031129871254727, 0.02815159766243831, 0.01545796796093665, 0.06847059444314049, 0.03222653807531441, 0.04623912507668138, 0.05131454950559044, 0.07145381742908109, 0.04751838082748075, 0.060393514952832655, 0.11708876343383906, 0.04971803759314841, 0.07460366453855269, 0.06060456451509268, 0.0937955153565253, 0.27857245997555796, 0.3980285500086123, 14.369706088496795, 97.04094425324472, 54.82791792961859, 22.578798340212916, 31.64302906682415, 112.86500930786134, 80.17811006115329, 26.549337179430072, 6.664467290524514, 0.06702126334271125, 0.28691641385516814, 0.6762369650025523, 0.3548532135544285, 0.34740631799063376, 0.03968835703187412, 0.3788422763107285, 0.8357730591970106, 40.091620260669345, 100.2417944323632, 104.05846457327567, 85.75058214126095, 77.3613775930097, 85.84009847333355, 88.68703319180398, 91.8297303107477, 86.14336829031669, 83.65005093236124, 84.24484699003159, 83.09008552182107, 81.68139765339514, 78.18668350096672, 76.39817683927475, 82.38122693953976, 82.38377648015177, 78.21960787619315, 76.62648231752458, 79.68836292143791, 76.22641624942904, 76.93876574116369, 77.25000581433697, 76.2312956779234, 75.74671822209513, 67.72543199600713, 62.80597963640767, 54.803669837213334, 57.646058528654045, 56.32167808471188, 63.98688370181669, 60.195826638129454, 70.21964365436186, 66.87622316422002, 78.11888141016807, 68.27075127632388, 87.48307735689225, 39.00357438671974, 29.740002924396148, 85.8775100400371, 68.73572472603091, 79.43985723680066, 67.40367997077205, 70.85087068619268, 66.99761267631285, 67.52848978965514, 60.29672176607194, 60.6309312389743, 53.4593088396134, 56.20415210723878, 57.1239596797574, 68.14523543080976, 72.46576539931759, 73.00261236006214, 63.78108870598578, 64.04033776252501, 67.17391537081811, 70.90346182546308, 66.93195219962828, 68.23237480655794, 64.76360321044922, 61.20016128786149, 59.14284675352035, 72.73828383414977, 77.89471795482021, 79.7938354553715, 79.67675270572786, 76.4656259167579, 75.96080118610014, 76.79366942374938, 78.1631257457118, 76.60431308131065, 78.12332937794348, 86.45546344018753, 72.80440715051466, 55.83650050624725, 72.34124583582725, 83.1243670371271, 48.176539098062825, 4.118199406131621, 0.06086100861730595, 0.31389217763658495, 0.32293943087420157, 0.5190621376518281, 0.16931866926531638, 0.49747191069106905, 10.232445924512803, 36.44885624608686, 45.03332422625634, 99.66602971476894, 20.6203196894738, 12.430676510257106, 43.89596239213021, 69.73305794500536, 43.395993555745775, 0.2884921954283791, 0.11221340286635584, 0.05858677702264921, 0.014884794382528673, 0.0630443400493072, 0.012553857917326593, 0.04667568028033261, 0.06094083497901598, 0.0790505291473481, 0.023860601302717003, 0.02955938189951403, 0.05484839052622838, 0.06275210048883192, 0.10265342996365602, 0.009612528449525277, 0.048575260406059605, 0.06601477702779156, 0.010126210512563346, 0.07620452783040463, 0.05235209302496045, 0.009253801075711606, 0.059436234465289506, 0.02478044690384019, 0.01018768811087695, 0.022177333763289838, 0.06381590167180666, 0.03171462663299134, 0.02085572675681643, 0.10329888968337929, 0.1707671117037535, 0.19326331424376658, 0.10671675265316041, 0.09806810262342615, 0.22501375165677842, 0.14006083680977746, 0.1565671357656679, 0.08633133684915882, 0.08880502709578122, 0.13353047351683342, 0.2669421114748524, 0.1809224191932909, 0.09952502565518503, 0.12631941812052844, 0.18729225642258124, 0.06643017288297415, 0.14921799302101135, 0.16937093178351081, 0.07248232877182384, 0.2257182001466713, 0.15336870336003844, 0.17966900741861713, 0.14026211875100292, 0.2017247553674444, 0.15186828951681816, 0.14092345181251728, 0.1423839831183995, 0.1696815038280141, 0.1687969633888814, 0.14142762959724473, 0.1503558174496697, 0.351670271446628, 0.17493020202363693, 0.36356651374409277, 0.54639125182744, 16.591204174103275, 116.24869685019218, 70.65589750966718, 77.46776796156361, 32.863015628630116, 77.27337529582363, 109.76236743311729, 39.96930899158601, 6.083044063660407, 0.14832894798488389, 0.4174991649004721, 0.6404371247176202, 2.554744616631539, 0.811899737004311, 0.08655394667819624, 0.9257076139892302, 0.6572340008231902, 33.19698779813705, 98.20875152464836, 107.84473634535267, 91.25156510260798, 78.84528083185997, 84.64030819554483, 86.44552415417087, 93.58874074874386, 89.63610556817825, 84.50663382007231, 89.59193183529763, 85.03707947269564, 88.1421689064272, 85.73630471383372, 78.37614182502993, 87.25183794575354, 87.07950468986266, 87.04164597295946, 80.42057529572519, 84.900329959008, 78.88159413491526, 82.05313636410622, 82.13549044824417, 81.02648735046387, 82.07488982908188, 74.24059083384853, 71.41769239979406, 60.34159760321341, 63.94409064323672, 61.77125446258053, 68.21423776688115, 66.6271291240569, 73.23928817625969, 70.80996036529541, 84.1616064502347, 71.93107574216782, 90.01357093934091, 42.18239261258034, 33.66693481322258, 89.39418162069013, 72.259613467801, 84.277771365258, 69.5358725517027, 73.93456751300444, 70.8632496864565, 72.33133792877197, 65.52055789578345, 64.68886636918592, 59.808841674558586, 62.67037153244019, 63.569672953697946, 76.46527290344238, 79.24062436626804, 79.27271719901793, 68.6484912133986, 69.40463789047735, 70.99871266272761, 75.3656364256336, 71.7478382971979, 73.75694690212127, 69.41290624680059, 67.17346037587812, 66.35485387617543, 78.22343610948133, 85.52551654077347, 83.58617905647525, 82.72397933467742, 80.61816077078544, 83.46624082134616, 79.65625439920734, 80.9429173315725, 78.12540823413481, 80.7067749577184, 86.71404961616763, 75.0581382936047, 63.52274571695636, 82.8597874795237, 81.27544018530077, 44.22084054639263, 4.189309525874354, 0.10896564205928196, 0.5762523172363159, 0.2769042575551618, 0.9210007697824509, 0.29400649630735, 0.4518002614138588, 8.437922346976496, 33.14727960094329, 73.68512830426617, 77.81594891701975, 16.012422173253952, 48.23928133133919, 62.97406496540193, 81.5387253607473, 55.15520834153699, 0.28775304315551636, 0.21371937867614532, 0.17867862427186582, 0.13659769038279213, 0.14298923854385653, 0.09522393225662171, 0.10642730165272953, 0.13272304748815875, 0.12992615240716165, 0.1179926016277844, 0.18956841089792792, 0.1504504599518353, 0.08153468415501618, 0.19196032125863338, 0.14336834481406596, 0.149548988969576, 0.2070512268091402, 0.22536311839376727, 0.22784545777305482, 0.16849252004777232, 0.14533863102476444, 0.09712088853120805, 0.161304454950075, 0.1162302929667696, 0.14957777855377044, 0.0870973711472846, 0.08499603027537947, 0.1874535945394347, 0.17552548298431983], [0.022489648657820882, 0.05823039675071355, 0.07090444811770032, 0.02261646493758646, 0.007699642812968382, 0.05050979712377152, 0.03488691245776511, 0.025062497494922533, 0.06248933999168296, 0.03932023646249887, 0.016277903247804894, 0.0035535175101681347, 0.10592405849526967, 0.03088771898840224, 0.08824815012274251, 0.0330034546524046, 0.07883171145353587, 0.014559022195997738, 0.09690868983706159, 0.024043719299257766, 0.06432041270478119, 0.02769798551115298, 0.06346589908184064, 0.03178369137458503, 0.026594815069749474, 0.03242489739110874, 0.07975094035388001, 0.03596933340773948, 0.05198682230266352, 0.08746722307536872, 0.05846529846049606, 0.04719015045632278, 0.1326393293997934, 0.08628560906095852, 0.08580178623237918, 0.1662905075617375, 16.47371349796172, 81.8012809753418, 69.2952351416311, 75.7078867573892, 12.420752913721147, 42.84253535732147, 109.7597865135439, 50.451851121840946, 12.100400194045037, 2.691742955676971, 0.3215252325659798, 0.03595680787017749, 0.19702718082454898, 0.05310883467656471, 0.086494306733291, 0.08033065440794153, 0.14001470299497729, 5.000938619336774, 26.64227185710784, 76.19024415169993, 107.10864082459481, 100.33291893620645, 90.93275485500213, 85.74161560304704, 79.59984287138909, 86.17843427965718, 92.60017010473436, 83.59454154968262, 79.24915159902265, 82.34477243115826, 87.15461023392217, 76.43268585205078, 80.19568227952527, 76.54350065415906, 79.45617429671749, 77.75116705125379, 81.31030221139231, 76.9820059499433, 78.9112864771197, 76.61187541100287, 78.74243628594184, 74.8896489604827, 74.50530375203779, 65.83033884725263, 61.27928333897745, 54.10351499434441, 62.51062516243228, 62.628151139905384, 70.98295257937524, 67.65271125301238, 75.6368761677896, 68.48651301476264, 87.73341086602981, 37.80838112677298, 30.91175021663789, 87.15006812926262, 71.80855658746535, 76.13746473866125, 66.9196516467679, 71.31094901792466, 65.47421901456772, 67.66005392997496, 60.368971824646, 58.47470629599787, 55.53520364146079, 56.42376953555692, 65.55287822600334, 76.12181448167371, 74.40946455924743, 76.49036038306453, 68.89463563119212, 64.6705763570724, 69.87301595749395, 74.36189405379757, 70.69439949527865, 72.76023341763404, 69.94113968264672, 67.76474198987408, 63.181554425147276, 65.9816481990199, 76.71695570791923, 83.99438796504852, 83.64139818376111, 82.24375570974043, 80.6997460703696, 79.38526568874236, 80.46245051968484, 86.86702205288796, 82.68117058661677, 66.9506383711292, 75.33917611645114, 84.2893188230453, 46.855512280617994, 8.013261056715443, 0.27439685177899176, 0.08674258050779182, 0.04382047824741852, 0.140223155519174, 0.04899208501522099, 0.2854933902140587, 0.022520255785615697, 10.776730679696607, 19.73047902507167, 57.98841084203413, 60.852451016826016, 5.880176626866864, 42.8318900446738, 46.30143434770646, 61.70094989961194, 39.22869097801947, 0.2741799569658695, 0.05190940528747536, 0.058557654190207684, 0.10370212772320356, 0.039817201529419234, 0.009061086870309328, 0.01877909605090897, 0.03802051084236272, 0.01282597809369045, 0.03739774264695664, 0.04139801630029275, 0.03096788817445838, 0.03024302727182306, 0.04325100295846501, 0.055133938308685064, 0.03197092326327918, 0.0414744642142567, 0.06796761941645416, 0.03865471290003869, 0.017266918927611365, 0.02160407016955076, 0.054504436200424555, 0.01762515121710397, 0.11144991198013868, 0.01737564404104506, 0.039752444117179805, 0.05791796694299387, 0.07915929831083744, 0.014097586371785691, 0.05706719949000305, 0.07126413405902925, 0.016473485494873697, 0.020423143719052596, 0.030689327113871134, 0.02063007747393943, 0.04711981209355497, 0.03874435667849837, 0.0910579844287807, 0.030327576565586274, 0.00601174044159932, 0.05009582236168846, 0.08768288448693291, 0.032624850169785564, 0.03584148099405631, 0.11419439898623575, 0.008533525209303105, 0.04260775723284291, 0.011002680215413773, 0.09074034139273629, 0.048677437382960514, 0.002033233740216782, 0.043187513421740265, 0.014141232316051761, 0.02383767612158291, 0.07346021702453014, 0.027945380199760683, 0.0468371294799351, 0.0752919255906055, 0.05038862499678808, 0.04633414679236951, 0.06272577387731403, 0.04739416733143791, 0.021533618808814117, 0.052762953639631315, 0.10888774623914112, 0.16301053275744762, 26.812685112799368, 92.00327165665166, 63.8654157423204, 38.73360941486974, 20.851865045485958, 90.6941649221605, 110.0779534924415, 44.21349786943005, 19.125196510745635, 2.3655064355942512, 0.4842828184125885, 0.12281730846171418, 0.3040089998995104, 0.463435237085627, 0.13500928368058898, 0.01914854386761304, 0.16971832201365503, 8.79743601045301, 37.9178427111718, 89.8062893652147, 104.86014212331465, 89.50287049816501, 81.76674058360439, 82.66157442523588, 80.93158952651486, 85.77379472794073, 89.8034417244696, 84.88379324636152, 84.72280348500898, 85.90804961419876, 86.97126296258743, 80.77678142055389, 83.4360150367983, 79.44333245677333, 82.11549420510569, 80.06014085585072, 81.93150366506269, 78.50153215469854, 79.22203233165126, 77.0128357794977, 79.11765021662559, 77.35059107503584, 76.57877060674852, 66.80249044972082, 64.78057922855501, 58.28558137339931, 66.75989350964947, 65.67744878030592, 72.31530327950755, 67.45097591030982, 78.8978562816497, 69.24411096880513, 86.86986184889271, 38.73118539010325, 31.0006978050355, 87.21295156786519, 72.27586776979508, 78.74329920737975, 66.3169559355705, 71.18846908692392, 65.8605646318005, 67.39149708901682, 59.75992187376946, 58.35649782611478, 58.365389839295425, 58.26883677513369, 65.79827739346412, 76.54827810102894, 75.06292358521493, 76.0034530393539, 67.19959120596609, 66.0645043465399, 70.1611218913909, 74.70134381325015, 71.29977026293355, 71.52436517900037, 68.58705905175978, 67.28476155188777, 63.788494140871116, 67.8958511352539, 80.90612549935618, 80.86892574064194, 81.76048832554972, 79.89711146200858, 78.20517355395903, 77.60057157085788, 77.27532863616943, 82.44997039917978, 85.3515515788909, 67.61664113690777, 71.62298925461309, 93.05884422794466, 62.31971163903514, 12.09738193019744, 0.30004998008089684, 0.0748086620062109, 0.07588378213826688, 0.22876433427295378, 0.5726121738553047, 0.33399254744572027, 0.08426807820796968, 22.447420512476278, 31.81263235307509, 39.760889930109826, 94.02672044692501, 18.592868120439594, 13.033537941594279, 42.864465328954886, 65.55969530536284, 50.69598728610624, 0.3254010552360166, 0.1688628775938865, 0.0751040042227795, 0.034006991528815804, 0.0527098139507636, 0.04352173843090573, 0.01830869125232341, 0.013167748111300172, 0.027121015967080192, 0.02611503910063015, 0.0057925962028093645, 0.043812116397725004, 0.05006339769029329, 0.0493199821381319, 0.022672123140505245, 0.06380280156830145, 0.02182629886984585, 0.03265264383967846, 0.014606030308641495, 0.021844263631670226, 0.02579459026756306, 0.003613298223729456, 0.01321406770242198, 0.005283114216816162, 0.004511027824088571, 0.021363750302923784, 0.06185333379694532, 0.004503373648115104, 0.06667155952703568, 0.13496409981481491, 0.15168208418594253, 0.1560524472546193, 0.11764679719964344, 0.06594650327197968, 0.08212081802588317, 0.1514313742518425, 0.13725430434269292, 0.13215448767427476, 0.13047638739789688, 0.09063871982958048, 0.1204389272137515, 0.16185927114659743, 0.1738693541096103, 0.14565024494884476, 0.211245849307987, 0.0876254508752496, 0.12780523032791194, 0.1250509603790218, 0.20509531240790121, 0.13259391570764203, 0.17274979321706682, 0.2061862522555936, 0.11887764002406791, 0.15049830980358586, 0.11855778299392232, 0.11895120744743656, 0.16512838282412098, 0.2231118617759597, 0.10009459670512907, 0.16882575297307584, 0.19731742089554188, 0.12483714523935512, 0.26079594127593503, 0.2922171600643666, 0.15514207433067984, 0.3519322735167319, 30.327018960829708, 113.14429775361093, 84.58093920061665, 101.5057860651324, 21.353646016890004, 57.782090248600134, 130.66336800975185, 73.88451022486534, 21.625654543599776, 3.239020969598524, 0.3953454036626124, 0.213323112036432, 1.0236765312090998, 0.5674279649411479, 0.46205774971073676, 0.26733272438568456, 0.27553887436947516, 6.7327856632971, 30.69808106268606, 84.86481681946786, 108.19220342943746, 95.58990263169812, 86.3735721957299, 85.2181282351094, 79.40166904080299, 86.34640585991644, 96.9638853688394, 92.66050400272493, 86.97125511784708, 91.4052749449207, 94.73892088859313, 84.7376065100393, 87.30455460086947, 84.14717212800058, 85.87014382885349, 85.89879282059209, 87.94754089847689, 85.16519977200417, 84.76842065011301, 83.38014479606383, 85.71165653967088, 85.47491012081024, 81.20493950382357, 75.4994127827306, 69.24427570835238, 63.36276792710828, 71.90498413578158, 73.26108870967742, 77.99652699501284, 73.76832962036133, 83.6543498500701, 75.25251526986399, 88.19498754316761, 46.534866363771506, 41.12291728296588, 88.10704015916394, 79.67876095925608, 81.28928615200905, 71.18705703366187, 76.58084946293985, 71.710873880694, 73.03887859467538, 63.501537461434644, 62.81955888194423, 61.09513198175738, 61.30663010381884, 72.47022905657369, 84.27646129362046, 80.46634935563611, 83.17144332393524, 72.75926851457166, 71.45485293480658, 76.64803966399163, 82.00121202776509, 77.17826566388531, 79.64070612384428, 73.91169225015949, 71.83835091129427, 67.57029441095167, 71.62221262531897, 83.6592528127855, 89.75394925763531, 88.79569069031747, 82.75320883720153, 80.46941664911087, 81.23583993604107, 81.5459660560854, 85.66274458362211, 86.05962568713774, 73.11458033900108, 80.31588723582607, 91.54691173184304, 53.87640583899714, 10.154274067571087, 0.32483945150048504, 0.19258610784046112, 0.30605283055093985, 0.388324054618997, 0.7584263708802962, 0.2209995888293751, 0.07750907597402412, 16.19499183470203, 35.84644686791205, 74.43155534805791, 73.89011921421175, 14.77772476211671, 62.66779845760715, 61.707990554071245, 77.8790206293906, 62.86256767088368, 0.8153943236797088, 0.18644975888873302, 0.18540472302946354, 0.16756238205538643, 0.0900382524536502, 0.16116597689688206, 0.12330437184221323, 0.07955309048655533, 0.08828480742991933, 0.10254916539716144, 0.0796940430037437, 0.15857825446273052, 0.16602801519536203, 0.13912322179925057, 0.11737871239142073, 0.1406425273706836, 0.08390539686285681, 0.17136395548380193, 0.17600297026576536, 0.19508646560772774, 0.08197458716289652, 0.16553629400028338, 0.15058964280591858, 0.16784016553673053, 0.09440840867858741, 0.1535476308556334, 0.2490641474122963, 0.2181652167271222, 0.10830702094901955, 0.1622258442183656], [0.07993895365225692, 0.05620723898192087, 0.009291933102142668, 0.038083651809081916, 0.044723998514875296, 0.014832994389918544, 0.10814372164707993, 0.015526703284722904, 0.012211240414950636, 0.036484657771765225, 0.032239021478040565, 0.04620255970005547, 0.03263267575793209, 0.07315799533840149, 0.03809794700974899, 0.00816472090645543, 0.04412397163950148, 0.08091200789016101, 0.022893436365730824, 0.0385210765225272, 0.05773451186776642, 0.009710015053109778, 0.06821235386474479, 0.013189608430219515, 0.01313363230081215, 0.09748346262401152, 0.028469162174470486, 0.038275028233446425, 0.060160137758019476, 0.03211822281892021, 0.016753000334926674, 0.042810195966834025, 0.007610160870582707, 0.05355570525411637, 0.12706657601219992, 0.06573765238206233, 0.004483258573248262, 19.197154352741858, 75.63544842504686, 69.27929462925081, 69.9737738024804, 19.47715666986281, 18.59844376963954, 94.71693992614748, 68.19113500656621, 24.87115110120466, 9.888270689595132, 0.4264888696132168, 0.17172800046542, 0.16377600781138868, 0.22400928781397883, 0.04224398038199833, 0.08744176597364488, 0.06394790628203942, 0.10939203127617798, 0.7617568308787962, 21.59006295665618, 52.19522306996008, 81.15392515736242, 105.03054557308074, 105.06750998958465, 81.60935155807003, 79.06758508374615, 85.79353209464782, 88.3305525010632, 83.09508262142059, 79.22379739822881, 82.74741157408684, 84.86354597153203, 81.1474532465781, 79.05613176284298, 80.48282331035983, 79.7208950596471, 78.74055354825913, 74.0691440336166, 78.44848602048813, 79.93095367185532, 77.51234177620181, 76.74269430098995, 70.66695074881278, 69.36942285107028, 64.8705348660869, 64.25005120615806, 67.10445803980674, 72.26819561373803, 71.83318122740715, 74.26992231799711, 71.08473808534684, 75.59325941147344, 50.921123489256836, 31.480489969253544, 76.90155029296875, 76.18090891068982, 72.50852707893618, 68.5785553532262, 69.35472180766445, 67.85116749425089, 70.85070594664543, 67.4865282735517, 63.6336781901698, 58.10636043548585, 61.23697665429885, 72.45038186350178, 74.30574924715104, 80.61649768583237, 77.49629928219703, 73.14461784978067, 66.48857532009002, 71.5746578093498, 74.82168997487715, 76.80346750443982, 75.66035547564107, 73.3646785059283, 74.35936020266625, 72.59171270555066, 73.51827067713585, 81.28312803083851, 85.85877680009412, 81.13818076349075, 84.02655140046151, 83.85425736827236, 87.34299382855816, 84.57049785121795, 75.4975143555672, 75.10619517295592, 91.05027691010507, 65.9533835995582, 9.007940792268323, 0.49547085838933147, 0.17311546230508437, 0.058330271633402, 0.09341507609332762, 0.19736173142108226, 0.041960953028812524, 0.5777370569206054, 1.7420193432800233, 14.994230770295667, 23.738686346238662, 71.88760019117787, 65.9953921841037, 6.908898122849004, 51.03400145807574, 55.444165429761334, 63.17131311662736, 34.81231397198093, 0.11985838578473176, 0.07992268960562446, 0.03895914091938927, 0.0376904456906261, 0.08235675778480307, 0.013835057616233827, 0.09100134754853864, 0.05467945664760567, 0.04681236568778273, 0.014226615688042536, 0.05666675767110241, 0.078402771163852, 0.05449439661817686, 0.06958617167847772, 0.029696029002567934, 0.05551584846069736, 0.02324698402756645, 0.05495139104764789, 0.06162130108643925, 0.02581551212877516, 0.01150122055062844, 0.018725782077038483, 0.016859978767893007, 0.03832234565408961, 0.02867794220125483, 0.10592379036449617, 0.02433438263382883, 0.05768915180176978, 0.02274945588602174, 0.036934244131008466, 0.041955452517516194, 0.026092152223892273, 0.08271541716831346, 0.021086922516265226, 0.02582594433108405, 0.04821477773328943, 0.05042515206901778, 0.05785786351489444, 0.017146545447288983, 0.04056895594863642, 0.03306787115551772, 0.027709289138475736, 0.07831985746780712, 0.01604156416555446, 0.014948252318126541, 0.06198302099120714, 0.015754385573428967, 0.10152829195102377, 0.017534266376206954, 0.018528930039235184, 0.05983666479287129, 0.009357884653934069, 0.01610508147296646, 0.01649318161540695, 0.010458867914313752, 0.009197969545399951, 0.06535361250562054, 0.04872565878735435, 0.02272293392208315, 0.02809961668155607, 0.05690148318066232, 0.08818488658195542, 0.033451681205582236, 0.02507866003490504, 0.054491424197030645, 0.09905080190829693, 0.036229569645177935, 0.06307288065492626, 31.897628153524092, 87.53479772998442, 61.53027188393378, 26.720427043976326, 15.776379819839233, 60.297212062343476, 117.04418490009924, 62.155882081677845, 35.41716306440292, 18.405110143846084, 0.7003136988609069, 0.24407323780319384, 0.3495294234204677, 0.10409254145117537, 0.10375730137551024, 0.06934225694426606, 0.007885742806754406, 0.18230332332032342, 2.4448520618100322, 32.86416292190552, 69.18726798026793, 93.73272311302924, 103.77668150009649, 96.88566546286307, 79.8141533328641, 82.24331640428113, 89.271191781567, 87.30158928901919, 85.37537605531755, 84.18488963957756, 82.88490633810721, 85.73544179239582, 80.49010322939965, 79.45635472574543, 79.75289375551286, 77.65222918602728, 78.75450934133222, 75.2910800133982, 79.90513663138114, 79.3282344264369, 80.10476173893099, 75.53039166235155, 70.4526638215588, 66.22268569084906, 62.623954203821, 65.23976718225788, 70.360456743548, 72.64096983017461, 74.82118006675475, 75.16900800889539, 74.61698932032432, 79.582200050354, 48.10817218595936, 35.92533357681767, 77.23332789636429, 77.72920177828881, 75.04517878255537, 75.94991268650179, 73.95866655534314, 70.57957603085426, 72.31334209442139, 71.47761837128671, 65.89073550316596, 62.58180833631947, 63.52994326622256, 75.01261526538481, 76.69218201791087, 82.42706375737345, 81.24016238797097, 74.48099290170978, 66.93563922759026, 72.40732992849043, 74.80909916662401, 75.42033780005671, 76.82228703652659, 77.23881136986518, 75.16016698652699, 69.88896431461458, 67.61348755128923, 77.59588826087214, 83.61547916166245, 85.32126303642028, 82.87208018764373, 79.62554224075811, 84.4734505684145, 82.00081979074787, 78.11182898859825, 70.42712919173702, 89.22475091872677, 80.7773619313394, 14.987965764537936, 0.5473214664286183, 0.14554314585703035, 0.15738263636106448, 0.054772635921835906, 0.10474812119237839, 0.37805366540147417, 0.9232186249667599, 2.5860296862740673, 27.278805855781805, 27.819577147883756, 53.565699208167295, 96.78099309244465, 15.955131053924562, 17.87929681039626, 52.421688956599084, 68.84274267381238, 47.94524085137152, 0.14983863149198795, 0.03933655413528604, 0.08835935544583105, 0.03212133888155222, 0.08334816748937292, 0.03270772173099461, 0.055759146494129976, 0.09623716014527506, 0.00920731007241674, 0.008329103265198009, 0.06696095690131187, 0.017782363950485186, 0.048477312234500726, 0.046064552790935964, 0.04422943130315793, 0.03530338083604171, 0.01211695988932925, 0.03008007653988898, 0.06500557110074066, 0.06413079062176329, 0.032279777355612285, 0.0661863117749172, 0.04835073535721149, 0.1192562559980058, 0.02862112145991095, 0.03671545325027358, 0.061506751789561206, 0.03786365817030592, 0.05155231638420975, 0.05323117125719305, 0.02759362518366787, 0.17834477847622288, 0.1483036824051411, 0.09015592355881968, 0.14238759905340212, 0.13133796052105967, 0.10512394094539267, 0.16922491542514295, 0.0854878357401298, 0.09426780090096498, 0.08703591557399881, 0.14090903403778232, 0.12657170619575248, 0.08677206723199737, 0.25820451097623, 0.2587367582225031, 0.1432072212018313, 0.2078287754087679, 0.1973518948521345, 0.26027831098725723, 0.14393702720201787, 0.12419248991195234, 0.13483029489796008, 0.17208300560953158, 0.10992705942161622, 0.1414897593279039, 0.21072569092915905, 0.0926186970525211, 0.26758026271577806, 0.12756324613526945, 0.18765884481610792, 0.11636283383854937, 0.09556027549889781, 0.14765883555575726, 0.20638977117355795, 0.24771060794591906, 0.14099423833672078, 0.07310204793729129, 32.457564146287986, 105.81816534842216, 81.37124015438943, 98.45313872060468, 30.199069284623672, 29.512801593349828, 108.34053177987377, 91.14402155722343, 39.78837005553707, 14.527794276514362, 0.6226177357377545, 0.378415841128557, 0.3022970998239133, 0.3282946919000918, 0.18899407478109484, 0.4169859472782381, 0.23356249616030725, 0.22681028912625006, 1.2314048265257191, 24.827708890361173, 59.453031709117276, 86.34360528761341, 105.69770151568999, 103.18984785387593, 84.50884603684949, 80.74686158087947, 90.28754849587718, 94.58936875866306, 90.98977042782693, 86.98453626325055, 91.52762151533558, 89.66022814473799, 89.67361127176594, 84.3325747213056, 87.5813719534105, 82.8624076227988, 84.13824481348838, 78.007046791815, 87.42466542028612, 87.11785762540757, 83.91754873337285, 81.61769836179673, 74.85964282866448, 72.34456416099303, 69.13313142714962, 70.2713248037523, 74.52621782979658, 77.79355218333583, 80.46246620916551, 81.82813352154147, 78.87611850615471, 79.32550445679696, 56.70416016732493, 43.20164403607769, 76.76399277102563, 82.09075973879906, 78.19602658671718, 78.75021042362337, 77.53293421960647, 76.226165217738, 79.51878316940801, 77.52857254397485, 72.57581926161244, 69.58282332266532, 70.45607628360872, 80.9151626402332, 81.35387189926641, 89.48766739137712, 87.3529488040555, 81.10569569372362, 72.85843387726815, 79.94851020074661, 78.54993420262491, 80.23742414289906, 81.56097304436469, 82.00360467357021, 83.31178572870071, 76.46754787814233, 76.98292378456362, 85.37758042735439, 90.12113017420616, 87.0432698342108, 88.94947898003363, 85.5496391173332, 90.37409167135917, 83.60071536033385, 80.06622837435815, 79.14754652207898, 93.19471513071369, 75.78978584658715, 10.910369753837587, 0.5977385707439915, 0.1850391305502384, 0.23177846124575985, 0.20220516910476072, 0.36909316396040304, 0.48718074516903975, 0.642371956379183, 2.3922802892423447, 24.152657216595067, 38.307918502438454, 89.30508890459615, 78.38308442023494, 15.163397692864942, 72.38022635059973, 72.02401238103067, 80.85142412493306, 58.65335849023635, 0.39127517852091026, 0.15294151741170114, 0.18868747107203931, 0.15452868305146694, 0.14690937173943366, 0.11356531056545435, 0.21347096700581814, 0.17657931353296005, 0.12397663697840706, 0.15646094065760413, 0.15239232430054298, 0.1599302464315007, 0.2139232040292794, 0.15115605757361458, 0.12450643274332247, 0.16068816785850834, 0.10901258026640262, 0.12139858257385994, 0.1924725276448073, 0.1382821798324585, 0.08623753704370991, 0.15072295742650188, 0.20350964830046703, 0.251015541894782, 0.12441733671772866, 0.21511667708475746, 0.15841944443602718, 0.11803181000774908, 0.16666279564942085, 0.18378185769242628, 0.10738530226292149], [0.04258291683189812, 0.010937994623917245, 0.05562923330393049, 0.02420024255350713, 0.05413421271969715, 0.0242561478197815, 0.021889445582224477, 0.08741346668572196, 0.02352107304989571, 0.02254152047117391, 0.02114602045396403, 0.08123865245931572, 0.0706094429798184, 0.037152946911632054, 0.09576201709287782, 0.059908190591921734, 0.15353630807611252, 0.04697089226195409, 0.008941398081069273, 0.11531895477204554, 0.016962523466997573, 0.018520007030137123, 0.05945294284291806, 0.018847770087661284, 0.04746694951468418, 0.0720574947134141, 0.0643275220007185, 0.0512776930155533, 0.0405660716276015, 0.022133860188806732, 0.11863703478968914, 0.027061421987450412, 0.06395332635410371, 0.07172040836585146, 0.024516772846841527, 0.036388617159137805, 0.11960662631017548, 0.15315035297986002, 14.125382631055771, 91.17395708637854, 68.25608945661976, 74.9070172156057, 38.74355654562674, 23.51242442284861, 77.03516191051853, 84.36291817695864, 32.76494068484153, 12.809566682384862, 4.375811853716451, 0.249257170925698, 0.1492714966016431, 0.02265094463983851, 0.13997033118240296, 0.22263682597587187, 0.6739048094999406, 0.3266515252330611, 0.34690253857162695, 0.07947986014187336, 1.6757611954404463, 13.405179573643593, 47.44792353722357, 87.97662919567478, 96.6384070919406, 83.90153761832946, 75.13747215270996, 83.95723527477634, 88.42881571862006, 80.87346000056114, 79.92768241513161, 82.09865939232611, 80.77372981655984, 79.90051607931815, 82.77602134212371, 77.28228692085513, 82.05593693640925, 82.09667467301892, 80.2546041242538, 79.50263869377875, 77.86581793139058, 75.37948239234187, 70.41915893554688, 64.43504979533535, 63.127429639139486, 63.54198886502174, 71.91686891740369, 74.07050117369621, 77.1655022713446, 75.70086571478075, 84.55538103657385, 51.43737016185638, 29.523803841683176, 78.75024964732509, 78.59159761859526, 76.92621415661228, 75.76390604819022, 77.90777944749402, 74.64756027344735, 75.20516441714379, 69.55108350323093, 69.29798080075172, 61.86900384964482, 65.34955824575117, 74.41464993261522, 81.11272458107241, 80.30011930773335, 77.45480845051428, 76.47278816469255, 70.11790521683233, 76.80099641123127, 80.21082262839042, 80.78442219764956, 81.19720458984375, 82.90988399136452, 82.23027060108801, 82.06058102269327, 78.71820388301727, 81.89793602112802, 84.21190692532448, 89.34562267795687, 84.83402621361518, 80.47166808958977, 84.28645549281951, 79.48767877394154, 70.01561764747866, 83.80503946735014, 30.198888855595744, 0.924619646562684, 0.14558129703565953, 1.7270960730891076, 0.2029611293466822, 0.2519005266649108, 0.19923697676389449, 0.0834902308340515, 0.12418513546787924, 5.082092458201993, 20.64605239898928, 39.398462926187825, 80.20722189257222, 54.2091405007147, 11.970052969071174, 50.52365795258553, 60.719008061193655, 62.6765335759809, 21.45491376999886, 0.14593026540692777, 0.08056248027470805, 0.02555460747962277, 0.03183666252410941, 0.041356421556443944, 0.05828187019834596, 0.024970149426090143, 0.06166301457391632, 0.006528817231751859, 0.057465274097217675, 0.029666525041384083, 0.028333712083798264, 0.1109087551313062, 0.05998546205040428, 0.038980786733689814, 0.032325351926227736, 0.024442575316155152, 0.012286175305264132, 0.06679804830421364, 0.03710302862248594, 0.04157917311174735, 0.04242562748972447, 0.07127641444845546, 0.03393219070388906, 0.04409787485436086, 0.01739277185181216, 0.0427344145493642, 0.04126947057703811, 0.07867736771943108, 0.03262724419454894, 0.07827732426625106, 0.04602198894586294, 0.036625537510600784, 0.04285311987323146, 0.033180811667754766, 0.025189997508160533, 0.026595765018775582, 0.020943685141842694, 0.0363356038747776, 0.04915345377559143, 0.019669973952395302, 0.017073571742061647, 0.07229155755691952, 0.09597747932158171, 0.05398387945587597, 0.07812871853069914, 0.03914037817007592, 0.054015055403954564, 0.027519644072820103, 0.10657136448689046, 0.046318641172782074, 0.07203482617173465, 0.02812786042810448, 0.02929938889499153, 0.07305403720707664, 0.0253742799583462, 0.015449850301768993, 0.031161530303858945, 0.03522743087922854, 0.09663639154525534, 0.049777007211119904, 0.04514452332871095, 0.03187944661946066, 0.06735477972054674, 0.05120733167014776, 0.01861870788308161, 0.022615834830268737, 0.12200668018551604, 0.11503758599921582, 0.10120946913957597, 26.677522197846447, 102.7981835026895, 71.10067075298679, 39.416129281443936, 4.355906315388219, 47.943377725539676, 107.74121715176491, 75.91094786121, 36.486040315320416, 28.52335429960682, 4.922253422198757, 0.4372127215948797, 0.054638252608598246, 0.03560952106190305, 0.07994846080339725, 0.31958218844186875, 0.4376049892556283, 0.44779138459313306, 0.24908078684201165, 0.29896510764956474, 4.722563105244791, 23.399109109755486, 66.09627554493566, 94.59092986199164, 90.25439662318077, 80.34197099747198, 81.56111424969089, 87.00250856338009, 89.50807940575385, 84.41247340171569, 81.73150985471665, 83.7598616077054, 83.41499897741502, 83.17016463125907, 85.54565398923813, 79.78522193047309, 81.7048220480642, 82.82569423798593, 79.6853897648473, 79.97813194028794, 80.88270110468711, 74.3994782047887, 74.0304067057948, 66.73661816504695, 66.00901065334197, 69.75645096071305, 75.32445938356462, 76.19931267153832, 77.68006232477005, 75.7223524585847, 78.49069072354224, 57.12391261131533, 35.54864091257895, 76.67819484587639, 79.05108759480139, 76.84521721255395, 73.2186565091533, 74.55143867000457, 73.41686171870079, 73.65241573702905, 70.37963713369062, 68.36454299188429, 62.56212588279479, 64.82050503453901, 71.99060163190289, 79.56406301067722, 78.38085651397705, 79.12279636629167, 76.16634907261019, 71.52537715050482, 76.92840283916843, 82.36844785751836, 81.05192784340151, 79.80091141116235, 77.26189059595909, 80.1608673218758, 80.08777787608486, 80.48769489411386, 85.11104752940517, 84.83792504956646, 84.4144267420615, 81.92128196839364, 77.59225614609258, 81.02197662476571, 76.7346534421367, 73.14337053606587, 92.60635176012593, 42.26619797368204, 2.389213731212001, 0.26950158058635654, 0.7967905219524138, 0.05097808751968607, 0.1438493560999632, 0.4065277439451987, 0.05895202476230841, 0.4461752761515879, 10.163030758980783, 34.94179925610943, 33.2689279894675, 74.73321699327039, 91.82197186254686, 17.625048775826734, 21.877927664787542, 58.52772497361707, 67.36241663655927, 34.694544807557136, 0.19669112869568411, 0.039603914990420305, 0.007801166221108889, 0.044456637659741026, 0.05934368338315718, 0.019530182058412223, 0.10664603507687008, 0.04790291866107334, 0.08505273610353471, 0.10979811150220134, 0.06763823991340977, 0.07572829693315491, 0.03398369479503843, 0.06607134496012042, 0.06690534657888836, 0.04403531994490374, 0.02302858193645314, 0.03664971141505145, 0.06041817149267562, 0.04151757581219558, 0.03203244203881871, 0.0685618355149223, 0.046528384555131204, 0.04743550160539247, 0.09995467840663849, 0.015276146568207732, 0.026806695837407347, 0.021417602453561082, 0.10778140036329147, 0.03507150900399974, 0.057739135208389455, 0.04700708608593672, 0.15094121587612938, 0.09900965532588382, 0.12675032725617771, 0.11477395982271242, 0.1561833257156034, 0.1439099536547738, 0.10512337404032869, 0.1867858110175979, 0.10293647646903993, 0.09566906764502488, 0.17370305174300749, 0.1950057046187501, 0.16785544132994068, 0.19605106223494778, 0.21642146271563348, 0.28740729235353013, 0.2635319476887103, 0.19707198164636092, 0.09619484144833781, 0.27339465555644804, 0.07070493583957996, 0.12630149166310026, 0.1735237258816919, 0.10961079534383551, 0.1491907815779409, 0.14474215496691967, 0.1491823852542908, 0.16575233079493046, 0.10763054232924216, 0.09869022730497584, 0.2045478659772104, 0.1706677500999743, 0.24231958593572342, 0.129370033861168, 0.20259993421214245, 0.24036327316876382, 0.1854220212947938, 0.3119039956119753, 27.54553291105455, 119.60794018160914, 88.5833178797076, 94.46905397599744, 53.95277438625213, 44.35573870135892, 92.56375482005458, 101.58594362197384, 49.72228242504982, 20.452958037776334, 5.930592321580456, 0.33486680698490917, 0.2099449094384909, 0.13005912994905827, 0.2559987293376077, 0.7244806472332247, 1.2996017283970311, 0.6697922656613012, 0.5668785879688879, 0.335776214638064, 2.7027957045262863, 15.740003758861175, 53.912793667085715, 93.92875532950126, 98.64278531843617, 91.12782216841175, 82.02296549274077, 89.94169742830339, 97.82635181180893, 88.5825647846345, 87.45975494384767, 88.63191604614259, 87.6271224791004, 88.89533458217498, 92.32870286510837, 86.36047932409471, 88.1553166912448, 89.32519497409945, 83.95753337490945, 89.7127486813453, 87.31461940273162, 82.57372117811634, 81.06611113394462, 75.90709609370079, 73.81902233246835, 75.46717089991417, 79.93696274295931, 83.36345118861045, 84.2528643146638, 82.95645037005025, 81.5150499343872, 62.59215162646387, 43.23077155697731, 79.73626290598224, 85.61954359854423, 82.32341120319983, 79.94439955680602, 83.7458901251516, 80.68989307649674, 80.24227219243204, 75.00444889068604, 73.91495566214286, 66.65848455121441, 72.68309608582528, 79.29165440220987, 86.15295456301781, 83.63957820400115, 81.74315144938808, 82.03867066291072, 77.21289234776651, 83.61223143915977, 90.44614561142461, 89.93695920513522, 85.41076367901218, 83.41864678167528, 85.11496989957749, 84.5875366272465, 85.6368177167831, 92.3438039902718, 94.34201625085647, 95.22329438117244, 85.83356380462648, 81.60280119988226, 89.37974729845601, 91.19995455588065, 82.99107705393146, 90.00534965145974, 34.29226260031424, 1.394474056939925, 0.2883608573146405, 3.6677580927648856, 0.8307163886004879, 0.38392122474408924, 0.4374726705493466, 0.1362227056656153, 0.35826573689137736, 7.368777884591011, 35.379359260682136, 54.61872616121846, 95.6336292143791, 67.70825985939273, 22.18626126166313, 71.96296461166875, 77.77499152768043, 80.78271204425444, 44.917802579941295, 0.3966275284126882, 0.17715127477722784, 0.15072566937775383, 0.07935697197793953, 0.14465020909424753, 0.2304157900113252, 0.16899438424696847, 0.21003428125573745, 0.15390493426351778, 0.370665758607849, 0.15362966355056534, 0.13673031552424356, 0.2559421614052788, 0.14120520362930913, 0.19460991295354982, 0.13601590789133503, 0.09796193049800012, 0.10616562900043304, 0.18987832410681635, 0.17159971138162, 0.17546698451042178, 0.13456265442073345, 0.1313270514290179, 0.1391861329395925, 0.16595900599514285, 0.1446755666045412, 0.15099093498241517, 0.10507200018412645, 0.18166233755407796, 0.1809986602635153, 0.18122009031714933, 0.16464112026076164], [0.05634599282676655, 0.04207494691194546, 0.021673740120604638, 0.041087137820619735, 0.048868109006434686, 0.04557689186185599, 0.027236478823807933, 0.017680943485409502, 0.08838523389591325, 0.06112679899219544, 0.03839397104457021, 0.01929581469495691, 0.032955076199986284, 0.05956774877925074, 0.0665822719794608, 0.04837769782170654, 0.09787700199071439, 0.06713324241460332, 0.09273477469480808, 0.024154512850087018, 0.04658694814650282, 0.02939069699946671, 0.059246911156562075, 0.08887768287451998, 0.06630278012204556, 0.05195065146131862, 0.013496551133181541, 0.06304337094808299, 0.022778647666376446, 0.07985879021186022, 0.030894316920650103, 0.0619045352833646, 0.03281658282503486, 0.03541494239001505, 0.05366770730864617, 0.02138138373172091, 0.07932232948200357, 0.04778596384811306, 0.08883906438225701, 8.073201246799963, 62.35696238856163, 73.90531447625929, 91.29368351351832, 55.41342973709107, 33.07218190162413, 59.585901998704486, 106.66560911363172, 57.20106171023462, 40.275536275679066, 14.801751240607231, 0.5938079881091273, 0.1630646645301773, 0.08567249357339837, 0.11239959287547296, 0.09648921839412182, 0.13836510118938264, 0.4965221148825461, 0.4564831730338835, 0.10605903552664865, 0.33667115855120844, 0.08864526712005177, 7.063258588314057, 33.24677052036409, 65.50843384958083, 93.76886383179696, 74.90307915595271, 75.13435779079315, 77.65452769494827, 94.7576698180168, 86.40186032941266, 71.52280407567179, 74.34713809720932, 74.02868086291899, 89.18772374430011, 77.99782922191005, 82.22787011054255, 81.82457985416536, 83.29309171245944, 80.39810795937815, 80.70031089167442, 80.85591916115054, 72.32307741718908, 65.64361441519954, 71.16131844059115, 76.63359749701716, 79.00296795752742, 77.2785920481528, 72.2700548171997, 75.84557763991818, 58.249652462620894, 31.385529387381773, 73.14601421356201, 79.92559571419993, 71.81764079678443, 78.29060277631207, 78.23840387405889, 77.59777099855485, 75.8630714108867, 73.70064520066785, 69.02379928096649, 62.09957645785425, 66.26577684956213, 74.60245301646572, 75.57705217792143, 81.55057876340805, 80.52233726747575, 81.37611958288377, 74.58634776453819, 78.29142647404825, 78.50315601594987, 85.56356353144493, 83.47794517394036, 84.63525618276289, 82.52097314403903, 91.29325205279936, 89.32608142975839, 94.80365568591704, 89.87427972978162, 89.23621208437028, 89.57599916765767, 94.07498913426554, 80.87159295235911, 53.7461047018728, 24.22002196311951, 3.8953107210897633, 0.14552154217756566, 0.014028775396816915, 1.006720737824517, 5.378584909823633, 0.2663111001733811, 0.0727550560728677, 0.2858797743195488, 0.4248110757720086, 12.86160574805352, 25.730811088315903, 51.565113913628366, 64.97499150614586, 32.591962199057306, 16.89849049814286, 58.439487334220644, 56.70780797158518, 61.26229947613132, 19.616828349328813, 0.5618516415838273, 0.046578452231422554, 0.0960414400023799, 0.046221792337394534, 0.061117981320186976, 0.14518040322488354, 0.04997063976442141, 0.05980536244028519, 0.08904511139037148, 0.05823118199083594, 0.056074253779145024, 0.07900729880578096, 0.03443637231905614, 0.04857264804623781, 0.03099750130317144, 0.058083039738478205, 0.05775982341278465, 0.10000707882065928, 0.047265625438622894, 0.02025476525417499, 0.03871251423392565, 0.01569355531941138, 0.1203623414039612, 0.011929983682479831, 0.039812562867037715, 0.01587062696700976, 0.05126402600698414, 0.019863225376954483, 0.06302067559332618, 0.05163815653612537, 0.10207386146630011, 0.11469792559622757, 0.050528750139018225, 0.01643763258001737, 0.02581619203180796, 0.01856437692749164, 0.054775393838363315, 0.03605659082231503, 0.03764537290760106, 0.0751871171016847, 0.019553771820820628, 0.015042252264045661, 0.028621037190239278, 0.012343065952131105, 0.006548257670440381, 0.025510398460732355, 0.02148719388060272, 0.053258918961810495, 0.037849378291397326, 0.055000784566565875, 0.02292224510212339, 0.04613483752754908, 0.013977231086051513, 0.0441146330277045, 0.061078075800211205, 0.046151928949139776, 0.08388995253030332, 0.06679546658790882, 0.06661200385180212, 0.023689317449386564, 0.046919526066631086, 0.043444283111321355, 0.018908421268626567, 0.0819132694854371, 0.01649260896468355, 0.04784363877749251, 0.0650481885719684, 0.018922207020823995, 0.05100084416147682, 0.03316282009285304, 0.07595071524021126, 0.01031989190397003, 18.41667329111407, 80.03423752323275, 81.4613683762089, 74.6306077895626, 33.64994702800628, 42.237144977815696, 83.23715871380222, 92.86063901839718, 32.274999387802616, 47.378995726185465, 21.0223900887274, 0.9350595863596086, 0.6008554454292021, 0.037531650985681245, 0.06477568343642258, 0.3968264048378314, 0.09405549495450913, 0.5645070249034513, 1.2206094832189622, 0.07932878760320526, 0.6921849544009855, 0.5604335821924672, 16.434303483655377, 56.360172225582986, 82.6251434510754, 89.68555096657046, 73.91991353804066, 82.05210085838073, 82.47372427294331, 92.4812359963694, 88.19275179216939, 72.78957274652296, 75.24954995801373, 77.03753102210261, 82.26266937871134, 80.28344923450102, 80.90082245488321, 79.45802565543883, 82.7192097325479, 78.69079436025312, 78.6523315983434, 75.87753711208221, 68.74199267356627, 64.77450739952826, 72.22407679403983, 76.59548774842294, 79.12618529412055, 76.4388047495196, 76.78827224239227, 81.36828268727949, 58.59675084390948, 40.368778859415364, 73.27335003883609, 77.01239647403841, 77.67791286591562, 81.53768985502182, 79.50394876541631, 80.31027040173932, 81.06047076563682, 74.67726830513247, 72.30268109229304, 67.78091784446471, 70.25921252466017, 78.83418836901265, 80.64779819980745, 83.02993989759877, 83.49732952733194, 82.33689631185224, 74.84971138738817, 78.32199742717128, 78.44235143353863, 82.22117070228823, 83.54952842958512, 85.72036420145344, 83.83924253525274, 86.68235686517532, 81.94167044854935, 86.05061208048176, 84.48132668772053, 92.26720010080646, 88.92501123489873, 92.0460411810106, 91.54334237498622, 73.75470330638271, 40.52950582196636, 8.944844565083905, 0.24946602181561534, 0.04162672035876782, 0.9270369297554417, 7.375016414350079, 0.5319805863884188, 0.3118822693584427, 0.3814046565563448, 0.40271636459135246, 21.980978135139715, 29.892796893273633, 42.96017900589974, 85.68369004034227, 59.79167346031436, 13.086838049273338, 34.48620811585457, 57.78647938082295, 69.66558533330118, 28.901908128492295, 0.6055572028121641, 0.03484585014502368, 0.017889731173073093, 0.06554125042091455, 0.06716357183552558, 0.09166554577888981, 0.01634140236062869, 0.02154150185355496, 0.035691975105193355, 0.060752488432392004, 0.027869943521856785, 0.04222901102395789, 0.10131000285787929, 0.041696281142292485, 0.01697540715066416, 0.07558112378202139, 0.019926584678732102, 0.1229616700701656, 0.033062087191689404, 0.04160640753745552, 0.011408072877525082, 0.01822636552876042, 0.05721310093518227, 0.06530820647434843, 0.017018470868107774, 0.0993724286015476, 0.03732592190405534, 0.025161320921934904, 0.09517949915701344, 0.02237751828356376, 0.05006263160236901, 0.10799672469616899, 0.025984817560041146, 0.12771039630376524, 0.14206754284039622, 0.18090928844626875, 0.15358000573131347, 0.1320385938930896, 0.1631024326648443, 0.15650486813918238, 0.11569043080652915, 0.25437594060936286, 0.20682823393614064, 0.18581091816867554, 0.07526079177736275, 0.13731119403194997, 0.1716583783948614, 0.1790342729298338, 0.15345661961022886, 0.1740082918155578, 0.10827115271240474, 0.1433192538998781, 0.10427251082634735, 0.13877972329576171, 0.1501461545065526, 0.1193640139254351, 0.22777862426254059, 0.24421050543746642, 0.20410007226370996, 0.12341111087270322, 0.18882126066713564, 0.10788856074213983, 0.13097440583571313, 0.1616683620358667, 0.14824763541260075, 0.08034174736108511, 0.11940830146833775, 0.23051400248321796, 0.1614715234046021, 0.13582099980163959, 0.11647004018267317, 0.17767736267658973, 16.64368352582378, 91.37582578966695, 100.5853077673143, 117.43084430694581, 76.18290147473736, 51.96964756135018, 76.39977716630506, 120.88505606497489, 73.05875716670867, 57.40059268090033, 20.028192804705714, 0.8721353305924324, 0.7905299288611259, 0.15377708951071387, 0.271151366253053, 0.43179862501640476, 0.4800935432074532, 0.8761436251863357, 1.1183514542156652, 0.28843596457473697, 0.7031716971147446, 0.30211645629136796, 10.046867805142558, 43.92030069904943, 75.91411713630923, 99.41069910603186, 82.59906753416985, 85.68698483128702, 84.52857555881624, 97.17732506413614, 96.69361052974578, 76.45395294312509, 78.06145791084536, 80.0264790750319, 91.60303300426853, 85.52339846088041, 88.23227359402566, 86.6650592127154, 88.68540933055263, 84.94793968815958, 85.99012128768429, 83.89889394083332, 75.2581242592104, 69.12989939412763, 76.72895816064651, 81.37365633441557, 86.99097679507348, 84.52562593644666, 79.73944002582182, 82.66479861351752, 70.83720514851233, 47.26859277294528, 73.41047610006025, 83.15463204537669, 79.17039040596255, 87.23082188637026, 85.05600883114724, 86.27978048016949, 87.24126323576897, 85.43912241535803, 79.67251654594176, 74.09864810205276, 74.92804896446967, 84.75328814598822, 84.63060425173852, 88.92123791479295, 88.5847770014117, 89.59750944568266, 82.20906626793646, 84.9951022671115, 81.38582352669009, 86.6630195802258, 87.48298322000812, 93.6697220033215, 92.00536620232367, 97.71212454765075, 91.97540713894753, 95.8261783661381, 94.51896221406999, 101.04510368839388, 102.83751703077748, 102.70269732321464, 90.69134866037678, 64.1692582253487, 31.78698789688849, 5.213725730296105, 0.2934646269967479, 0.14841759967948162, 1.9883520348418144, 9.437932583593554, 0.8232945287900587, 0.3342315668780958, 0.45593765714476187, 0.6888446884770548, 21.70466284598074, 44.54314170345184, 63.910562223003765, 75.50062871748402, 47.34129390408916, 27.89965625732176, 79.36306507356706, 70.92829042865385, 83.21255760808145, 36.069629730716834, 0.4338815874390064, 0.15142752849046262, 0.2259619846459358, 0.1808071229606867, 0.10044324331946912, 0.22703610120281098, 0.10430451797982378, 0.13875150061663122, 0.2096292046048949, 0.15559542984251054, 0.1640557831213359, 0.23103678088274696, 0.2647187098139717, 0.09138262950845304, 0.12116258918878534, 0.18837250168285063, 0.10800407914024208, 0.2893304488351268, 0.13007653546669792, 0.1772894310734926, 0.11361354346116705, 0.10291772263665354, 0.177191571002045, 0.15116345798296316, 0.11716768581179843, 0.14885134334045072, 0.16141792789341944, 0.19517833487160746, 0.24821146090905516, 0.13021866009841043, 0.2176906712233059, 0.21333978210966434, 0.19467260958927293], [0.05940746020285353, 0.006038175263036524, 0.03757857387104342, 0.04810620392222078, 0.04922217569283901, 0.08400980698605699, 0.005394136636412793, 0.03986499009413585, 0.08395729931972681, 0.034759753353653416, 0.043144344367207065, 0.10257737275453345, 0.013832982475568932, 0.03148630944891803, 0.033702391139682264, 0.07211123578130238, 0.029605373988048207, 0.12642923682447404, 0.0305976512871923, 0.018755351155695897, 0.11745722108190099, 0.042334662209595406, 0.042834921454590176, 0.07093663913227859, 0.03583432190240391, 0.028159999731747855, 0.02936043269601801, 0.06014788801211023, 0.08437526156945575, 0.04932097805243346, 0.06773007087289326, 0.019344262095288407, 0.04291021640622809, 0.015452922314345358, 0.04390997263873297, 0.018933648543973124, 0.04056250548831398, 0.1356409538176752, 0.05071556067935402, 0.028645559664695498, 1.247591590208392, 33.981155887726814, 68.32806494928175, 67.74942121198102, 63.68167231159826, 43.16442074314241, 42.51962623288555, 90.80769400442801, 82.18665384477185, 48.50476303408223, 24.545249208327263, 5.441820381149169, 0.03335855172706708, 0.15487559830709813, 0.11892427179601886, 0.0903368658656555, 0.5391185646576266, 0.259049843035398, 0.4734417243349937, 0.9865194895575125, 0.18326335406351477, 0.0636595584482195, 0.17313220898710913, 3.6918024670693184, 20.37590503692627, 55.00345183957008, 81.50375350829094, 82.67386713335591, 73.94108649223082, 79.48733360536637, 83.35481412949102, 94.35778417894917, 74.68629760126915, 94.6683103807511, 70.20616639044978, 90.0436084501205, 78.52665885802239, 91.3261450490644, 80.35006676950763, 83.01354439027848, 79.21885521181169, 81.83056539104831, 67.22614565203267, 75.3643734224381, 71.30380245947069, 80.42007323234313, 67.7666090380761, 79.360946993674, 79.82354348705661, 78.18972726022044, 10.440719858292612, 32.59509225045481, 93.68712948214625, 68.95729157232469, 86.56043391073905, 75.82943316428893, 82.75621337275352, 78.78759061136554, 83.795453194649, 75.61537373450496, 76.19772018924837, 70.87046684757357, 78.3166394695159, 83.09816560437604, 84.30991911119031, 76.89708663571265, 81.95334342218216, 82.72244961031022, 78.08083441949661, 82.0838563672958, 86.05185939419655, 90.80139467793127, 90.1632328956358, 88.2185374536822, 96.95534244660409, 107.56201190333213, 110.2087410034672, 96.46651314150904, 70.41591905778455, 36.81102045120732, 16.14530619113676, 5.152214140661302, 1.5288911086897699, 0.25941103816993777, 0.12281334778714566, 0.41766905255856057, 0.10999507270753385, 0.16799791836209838, 0.09655460399845917, 0.22985145900278325, 0.10822956945987479, 3.2203627449850885, 20.270226578558646, 45.5072485246966, 79.73514895285331, 57.28232537546466, 21.49062498923271, 29.06988363112173, 62.98677344476024, 60.99194618963427, 52.310599588578754, 11.001076525257481, 0.21929237721187456, 0.12866941581089653, 0.017893695678081245, 0.055954299731961185, 0.034552013291226286, 0.07095841901196588, 0.07204725211786647, 0.01447343389548722, 0.01418184455213768, 0.10192649679318552, 0.05433932127010438, 0.05583571698216181, 0.026112124136078264, 0.028992990114455743, 0.018345135970101244, 0.03908663327174802, 0.11355194233117566, 0.015615593424187073, 0.010912956955331949, 0.1941065625437806, 0.029336404348272952, 0.11278920221112429, 0.04391535823684066, 0.0627011249983503, 0.028243790598466035, 0.06926309707905016, 0.01764722795586192, 0.02669803009578778, 0.011492659518074606, 0.06776178691295848, 0.12097680520626808, 0.03855744654673242, 0.03789921614131139, 0.1641895114293983, 0.015296518761334161, 0.07535057728208842, 0.011016229437964578, 0.037504144598759954, 0.0064141980293507305, 0.03779722685595194, 0.04422480796253489, 0.04888306687315626, 0.07916741118195557, 0.0273781476332055, 0.037019421616869594, 0.012976732705869983, 0.028179787782832023, 0.02899281582945297, 0.009030523792570157, 0.07785452800171991, 0.04442555747265297, 0.016289896354259505, 0.06461997606581257, 0.056723838882340546, 0.0464359445557479, 0.047163766388210564, 0.10666135683535569, 0.04173083170767754, 0.017759986522216952, 0.04848059492125627, 0.027532150458183982, 0.05716314817207956, 0.04523415561585177, 0.050736758332218856, 0.03726035243861618, 0.044721087380763025, 0.09335986413662473, 0.10402303429380541, 0.08908343876922324, 0.03394141823293702, 0.1005633122798416, 0.05789786479586075, 0.07860199998944037, 0.0950720553256331, 4.960868175952665, 53.89584902794131, 82.13894997873615, 72.4947674043717, 50.656147772266024, 41.17171156790949, 71.55596379310855, 119.46047475261074, 81.47427297407582, 48.883962092861054, 32.32581369338497, 9.416741978737617, 0.24760104205098846, 0.22225969621250707, 0.16191554796551505, 0.1508249390509821, 0.9219922714175718, 0.3646664627857747, 1.9012865712565763, 2.4307190266347702, 0.5689551765399595, 0.36360448106162013, 0.32259557997026755, 11.102560008725813, 43.8598059838818, 72.75585605252174, 85.32929605053317, 80.22576685874694, 81.22886596187469, 88.73322302295317, 84.22711787685272, 94.14367768072313, 82.82957738445651, 99.82829816879766, 75.06328444327079, 91.6309210561937, 81.61388581798923, 88.03012248008483, 82.54327574083882, 80.01687711285007, 78.46799588972523, 80.75815800697573, 66.98546117351901, 72.31120832504766, 72.59929856946393, 81.91980715720885, 76.0425276910105, 78.69566594400715, 69.13821481889295, 81.87191501740487, 18.51832151412964, 43.96819283885341, 90.62910064574211, 69.58455701028147, 83.37379840112503, 76.35299113488968, 81.90938149729084, 76.76259640724429, 78.94539540813815, 72.86421545090215, 71.89753163245418, 67.02117827630812, 75.59892331400226, 78.91970388350948, 78.92270841906148, 76.95363152411677, 83.41252003946613, 79.69500741650982, 79.56873063118228, 79.8474621003674, 86.84044407260033, 90.18285259123772, 84.71437038913851, 84.22239534316525, 90.50438496374315, 93.0213071453956, 103.83745470354634, 99.84998103111022, 86.41845979998189, 59.986948659343106, 34.280240535736084, 14.20057446725907, 3.7343675378830206, 0.8003163650151223, 0.23141047857221098, 0.14376032136140332, 0.4593336636260633, 0.6293438038518352, 0.13081585627890405, 0.3701911518169988, 0.21137622215094107, 4.642612943726202, 27.64881087887672, 43.67538790549002, 79.82821110756167, 86.23984290707497, 34.66411505976031, 11.652081128089659, 47.58387288739605, 65.98687279608943, 63.256232430858, 15.381409891190069, 0.23102849181140625, 0.11283207249136702, 0.1686479133223334, 0.011023341606731617, 0.015523191729199984, 0.08744659232756785, 0.09443427946779037, 0.03235656234826292, 0.034446454036139676, 0.06677101306136578, 0.09545178212706121, 0.028584159632784226, 0.030522116933078058, 0.06805696825106299, 0.025246301140155525, 0.01999077135546794, 0.05789552056681245, 0.052505383388169354, 0.03355919015443614, 0.11458892660636096, 0.053088096676454435, 0.09566653955487475, 0.09740160612930214, 0.003196549983958023, 0.05278921896411527, 0.07770063625949045, 0.050292929123726585, 0.021575370600687403, 0.054312642258141315, 0.09357006334128881, 0.10693874961185841, 0.00634078525998179, 0.05531041432292231, 0.034562213751938076, 0.14872935149938832, 0.15453805996766015, 0.12902359358004986, 0.12928774069634177, 0.1551662827090871, 0.175883062183857, 0.09130289507729393, 0.14283315579016365, 0.16712145248968757, 0.10917482236700674, 0.15282108839000427, 0.16089352538749097, 0.19618217052230913, 0.13155045798949658, 0.13956076525632413, 0.11589587260518344, 0.12685731909568274, 0.17358072282325837, 0.13804521351572008, 0.13617720004291306, 0.1879017253316218, 0.1427648207473178, 0.17377748484573058, 0.1673420245248464, 0.13972708294468542, 0.09572268613884527, 0.1923927012830973, 0.16269927123381248, 0.14297684324124169, 0.099356570581515, 0.15684873436487493, 0.19159632224229076, 0.1780861625147443, 0.16955701454031855, 0.16636906221749323, 0.12175424655358638, 0.38756807905531704, 0.16032582359208217, 0.1921661997274045, 0.2007637899969855, 4.224580459056362, 62.73291764720794, 98.90737272077992, 85.59789995993339, 82.67778950352823, 59.71446944821266, 59.7898534805544, 105.53323653436478, 98.63479937276533, 66.5211231477799, 40.68326273272115, 9.001514969333526, 0.21042051214364269, 0.6227781851926159, 0.28932355404380833, 0.30432989880923306, 2.7506255767037793, 6.832496235447546, 2.564704740239728, 2.4827607889329237, 0.3080273762104973, 0.18875355381638775, 0.29272899872833685, 7.793766692761452, 31.368329794176166, 69.46486980684342, 92.59934640699818, 94.31422233581544, 85.4073590617026, 90.04660514093216, 92.25074968030377, 111.42080829989527, 101.87577539874663, 112.4563140253867, 83.61219221545805, 103.66657272461923, 87.89340434535858, 101.76159520303051, 91.910703720585, 90.63993423215805, 89.59442646272721, 92.71493081123599, 76.91503540162118, 84.39702710797711, 80.76805806929066, 91.26270463389736, 80.32013124035251, 86.6537392523981, 72.77023546157345, 94.66606678501253, 18.761426095039614, 37.63222355996409, 100.04722918233564, 74.38756988894555, 90.77793890430083, 81.58566044222924, 87.48418346528085, 82.0156620394799, 84.59866831379553, 78.3495246210406, 81.19359600928523, 73.57900465688398, 81.4578696220152, 85.59935123689714, 82.67295714347594, 82.76264605983611, 86.71450461110761, 89.4520365807318, 85.59857460760301, 92.21511886965845, 93.71110300863944, 96.23002559907975, 90.68512778128348, 88.51207194789764, 100.25737408668765, 107.59771331664055, 121.39051621960057, 113.45007788750434, 87.00521499879899, 46.26127319951212, 21.429086923599247, 7.144437432289124, 1.6329859101003217, 0.3672656152517565, 0.2133942509610807, 0.7215956826844524, 1.764678875765493, 0.9085631791141726, 0.20033994419199808, 0.40194865256067247, 0.2506673855767135, 4.819218641327274, 32.50241056565316, 61.441673386481504, 93.59675022863573, 68.51553070929744, 34.599964695592085, 42.94088486702212, 82.33310730226579, 75.87083770382789, 78.41600095072101, 19.018914007371475, 0.3511575747641825, 0.2762283841448446, 0.14397876367213266, 0.19119063272110878, 0.14934056708889623, 0.1677226629709044, 0.27763482964327263, 0.10454642556367383, 0.13796390094343694, 0.1885879409289168, 0.294638947854119, 0.12230202240208465, 0.14319838054718512, 0.16821613084645043, 0.1016346785810686, 0.08827412050337562, 0.20918125767380963, 0.18098788906729993, 0.12304204035430186, 0.2972978551781947, 0.1436535593482756, 0.2836785279214382, 0.15254397906603354, 0.17602573839887498, 0.1207966902743905, 0.18876184288772846, 0.2192973108181069, 0.12419484946275912, 0.16615192225623518, 0.18669611744342313, 0.17887367025738765, 0.08782294834212911, 0.12331096785924128, 0.26974645293047356], [0.02710339019916231, 0.016659899584708676, 0.04604435488281231, 0.043654336759279815, 0.059233405026457006, 0.02198559727760092, 0.029800318466920047, 0.05057552363723517, 0.036497279070317745, 0.021937368212327845, 0.06966270386211335, 0.03308545287337995, 0.01017339195259997, 0.03411342029369647, 0.039135394768128474, 0.08324283039978436, 0.02965586301269791, 0.05142418434843422, 0.06145682966997547, 0.009780694325003895, 0.010525069402290449, 0.018025372785726385, 0.08719526186224916, 0.022639533760206356, 0.12159585021436216, 0.05926699415149708, 0.05048774528287111, 0.0022662968389810093, 0.011796398058293328, 0.03461874721031036, 0.03728985831501984, 0.04778430526775699, 0.1200012305390931, 0.02866039878778881, 0.04801508159406724, 0.05157517261743065, 0.016834439311717308, 0.03920339273228761, 0.0722210391634895, 0.15730565984643277, 0.16658333700991448, 0.286388487344788, 26.85264818130001, 81.69703222090199, 76.44628863180839, 63.73339660706059, 35.84934157709922, 25.802827765864713, 54.961980619738185, 83.94967294508412, 79.13883886029645, 60.839044355577045, 18.715136243451028, 1.4876426059392192, 0.0363059486112287, 0.11165439616888763, 0.09448413646990254, 0.770914707212679, 3.9022729281456243, 0.9731150346417582, 0.8969085303045089, 0.3361405354113348, 0.37738223530111775, 0.17381583520722005, 0.21999348555841755, 2.2068973077881724, 16.306288107748955, 49.355281937506895, 78.37626734087544, 83.90118460501395, 81.71864448055145, 79.18777435056626, 81.9998078192434, 81.46466316715365, 79.87305948811193, 93.27160143083142, 87.4348557379938, 90.18289965967979, 81.80124959638043, 89.14250666095366, 83.59329423596783, 83.05860457881805, 78.00328131644957, 76.09396565345027, 72.28509318444037, 75.92151472645422, 71.07943504087388, 70.75991876663701, 72.94136062745126, 39.60900398992723, 0.49157009189648015, 3.4337835638753833, 81.28338690726989, 72.11549774292978, 82.79047135383853, 85.4762907951109, 84.84855467273344, 87.08649435350972, 89.60792726086032, 80.36015510559082, 83.72359537309217, 79.24316606213971, 82.13480011109384, 87.13638690210159, 88.8820142130698, 85.52736789949479, 82.50975516534622, 80.93267994542276, 76.93070134808941, 77.64173292344617, 72.77680935398226, 78.50311679224815, 84.81317489377915, 85.50731674317392, 86.77843140017602, 78.06147360032605, 51.720933991093794, 19.711981127339026, 2.4122789838621697, 0.11178375011490238, 0.4088360281480897, 0.21208673805719425, 0.7014036887595732, 0.40629108406362996, 0.3142245678651718, 0.09381590095619041, 0.10068146602040338, 0.15940633422184378, 0.07573745934472931, 1.6856159053502546, 10.554722566758434, 40.78415393829346, 57.08478696884648, 62.01900312977453, 28.80035992591612, 20.3659265272079, 55.077259079102554, 66.82545200470956, 60.90393212533767, 45.065334689232614, 2.5082208937214268, 0.47077546256684494, 0.12342619514393231, 0.07416580698543018, 0.04016251183084903, 0.0757983097085549, 0.019799787551164627, 0.12158260455415135, 0.018013846992905584, 0.05722127509333434, 0.020880532683804635, 0.018928291674162594, 0.03805999118354052, 0.04502567244813808, 0.05568380174677699, 0.04412043614373092, 0.03935866343278078, 0.04793104940965291, 0.037692617549891436, 0.021143325739690376, 0.2277044975949872, 0.13422287910455658, 0.07073504309500418, 0.017063219978984807, 0.02619452263799406, 0.024246610025124207, 0.0407361661294295, 0.04251536702917468, 0.1120364442167263, 0.01724030503312186, 0.04963068058714271, 0.017218528983874187, 0.03169595515505681, 0.02562959025043153, 0.11082592570493299, 0.02433968204704504, 0.022605211105978778, 0.05587739216524267, 0.04561917608483665, 0.02787051042692075, 0.01956298211289029, 0.04518619851179181, 0.01759753949309309, 0.018096620877904278, 0.07079289805504584, 0.02287865661445164, 0.08597146704672806, 0.018608522744128303, 0.054303690520746094, 0.03462939583245785, 0.009609614442583294, 0.04797377796362966, 0.04097165389647407, 0.02833451647611876, 0.017093752413207007, 0.051601391976639155, 0.06076336688091678, 0.02724433697069124, 0.031129352695819353, 0.045712205971921646, 0.03472030748643222, 0.05059717711241496, 0.0686636715826969, 0.03462773725210178, 0.037164767648303704, 0.03823049937284762, 0.05837440212828018, 0.0829162317959051, 0.09522275248121831, 0.07250855196147196, 0.04901491060492493, 0.03938582508013614, 0.017362829305291656, 0.025071332403909297, 0.0682539294563955, 0.10954093578602038, 0.12811601687703403, 0.5190048342750919, 45.15443132769677, 92.27553121505245, 80.90883193477508, 62.90587063758605, 22.88540021065743, 35.422752441898474, 85.60002588456678, 94.22993060081237, 73.86169771994315, 55.03863550001576, 19.448609659748694, 2.345477587753727, 0.28153228663629104, 0.30072793725036806, 0.2550085913389921, 0.8919720435815474, 0.5334695548780504, 1.2505257682454203, 2.2698905727555676, 1.2924863037563141, 0.7289501880445789, 0.12828051127613554, 0.29679744654605467, 7.24682649297099, 36.554144428622344, 74.78625528274044, 83.69531508414977, 82.25656617072322, 81.48623620310138, 87.9519888662523, 82.67872302762925, 84.1751229378485, 79.93282072005734, 93.70135199639105, 80.79252581442557, 90.033308306048, 80.60768804242535, 85.89986755001931, 83.06320944140035, 82.88532210934548, 77.18268225269934, 81.50917422386908, 74.87071175729075, 82.76207339379096, 68.3074725058771, 79.24234236440351, 82.38567490731516, 64.11232109992736, 1.6388627237850621, 6.641643018491807, 87.04670583048176, 70.24761015369047, 88.32496704593783, 80.6084882059405, 84.8393371028285, 84.91480350494385, 87.68749560079267, 77.12592555630592, 81.42771444013043, 79.18196139797088, 82.44296504605202, 85.52369656101351, 87.0863845271449, 85.2906842385569, 84.40680949918686, 86.31548189347791, 81.84390144963419, 83.33169567969539, 77.42787745691116, 82.22581478857225, 92.18871347365841, 90.80480713998118, 97.6816398866715, 95.04210441343247, 76.0828104326802, 42.10428645533901, 11.31268039826424, 0.8710327768518079, 0.44897967889424295, 0.22140552349869283, 0.37368334829807287, 0.6917248726371796, 0.24968663981604963, 0.2418097237785978, 0.14099201668174038, 0.19102287478744986, 0.2642588425547846, 2.5217251239284395, 19.174286934637255, 40.344369949833045, 60.5478907400562, 88.71728251057287, 54.72140204521918, 19.623390474627097, 30.677645514088294, 61.7514935616524, 67.50592831642398, 52.76770084134994, 5.271600792484899, 0.697044832331519, 0.10332953320035052, 0.21238696791471975, 0.017310647226329294, 0.09314981048866626, 0.044910349402456515, 0.08032080251723528, 0.04472094565449704, 0.042852169924205354, 0.05397355642109629, 0.034556985201854865, 0.009762676894634722, 0.011527370004313848, 0.015744881295118363, 0.02499619641551568, 0.07236409842246964, 0.10414963032329276, 0.04461255187409059, 0.02237497678687496, 0.06496800214893396, 0.052705332336406556, 0.050268559866855224, 0.03292104274395012, 0.06994038775202728, 0.025064006688133366, 0.027076310906258803, 0.08998071925053674, 0.04852023997133778, 0.015736912065486035, 0.02416508294822228, 0.014890796681415411, 0.0738400434173884, 0.013319987018832998, 0.025539594071526683, 0.020040038469878417, 0.09198957798822273, 0.1256597704524475, 0.11850524468407517, 0.13089410449949004, 0.21033023634264547, 0.0792309505143954, 0.08329718433801206, 0.1496054190060785, 0.13531202630650613, 0.1299401564944175, 0.12601900440190109, 0.09092790269923788, 0.12289142746838833, 0.18517091299497312, 0.16966060494943974, 0.12594769693790905, 0.14563377405847275, 0.09648578632022105, 0.19601298766511102, 0.09000262936517116, 0.23038660206141012, 0.12796037079345796, 0.1612025652561457, 0.14303212414585775, 0.17181187177137022, 0.19018930983879875, 0.2671848081292645, 0.17664271496957348, 0.0863779916037475, 0.09541166210246664, 0.23037221493019214, 0.1748865809772284, 0.21107481251801216, 0.14545202735931645, 0.15241853982931183, 0.18161966645669553, 0.21767017071045217, 0.0973938839630254, 0.1920825429260731, 0.1863590540784982, 0.2139080967754126, 0.6307250910228299, 47.368087614736254, 111.92446416424168, 97.58118014181815, 81.79400890104233, 56.08101321804909, 39.889951598259714, 67.7525826423399, 95.27681904454386, 97.34072316077449, 81.48261193306216, 30.035688838651105, 2.7660115640009604, 0.29464443304365684, 0.6160733223922792, 0.2953044637556999, 3.0762754572976023, 10.987928740439877, 12.45380868834834, 5.91993082915583, 1.359826290319043, 0.4935634833189749, 0.2502800362004388, 0.5060922997372767, 3.3346758109907952, 25.26968352256283, 66.44891231290757, 95.37408598007696, 97.21971019621819, 93.47896929710143, 83.3054942469443, 91.4312881039035, 80.19233257539811, 89.84137104403588, 105.71818413272982, 94.29445359014696, 99.19441176999001, 89.18493886147776, 97.21015530247843, 90.19095620801373, 90.1451821481028, 90.86778471546789, 90.7027078443958, 86.25391637125324, 91.17579275561918, 80.60014140221381, 83.86937418291646, 94.94511988855179, 59.785225083751065, 0.9377216499659323, 4.183929995183022, 84.64860793082946, 81.122161803707, 91.55524284608903, 86.4954637712048, 91.43248834917623, 93.26494124627884, 100.94778968441872, 88.62019600406771, 93.0809977746779, 89.70899105072023, 91.2858073942123, 94.20672585887294, 97.38186882388209, 92.53563142591908, 88.8986921310425, 91.26294782084804, 88.233669957807, 86.32529566364904, 77.51386365582867, 88.51924988531297, 99.7008603618991, 103.71381375097461, 102.7516249687441, 87.76635877547726, 59.13215437243062, 24.403900715612597, 3.875600075529468, 0.25822703396120383, 0.4633864832501258, 0.27934568783929276, 1.3833091528184953, 1.7950784703416212, 1.6403632755241089, 0.6291975729888486, 0.7322874509038464, 0.5698920101408036, 0.20409362180338753, 2.4281361458763002, 19.560510958394698, 59.94970967692714, 72.772000528151, 74.33010716592112, 44.24745775038197, 32.457819100349184, 72.21041910109982, 80.54010560435634, 81.81442091541906, 63.46312961270733, 7.485970460599469, 0.6425183711032714, 0.17972157637198127, 0.31718010443352884, 0.10134554167668666, 0.18483444717862915, 0.10028670091302165, 0.1778861829229901, 0.1171864549659433, 0.10656291453708565, 0.11030340011441901, 0.1760808660859062, 0.15262544485590152, 0.14355646536475228, 0.16019868364016857, 0.14383930502639664, 0.14597639922172795, 0.21342063502919292, 0.13919930965189012, 0.12955746493272244, 0.3064606344747928, 0.17449365448086493, 0.1468368078912458, 0.12675234206741856, 0.10844077223971968, 0.088167772177727, 0.08926401335385539, 0.17567211221302712, 0.1351993347728445, 0.09756783954799177, 0.1168835438006828, 0.0687836179690015, 0.15522213051876715, 0.1566210070685033, 0.2526337340954812, 0.1482516343915655], [0.06255266098906437, 0.05379056482906303, 0.07846880794292496, 0.025116048956049547, 0.038496270595539006, 0.04961557716371552, 0.0571262342254481, 0.021811771927581682, 0.0111477600312942, 0.04319456909152289, 0.05600899840975481, 0.033757771635728503, 0.05835277163573812, 0.06581509621032784, 0.05593301397898505, 0.0379478090983485, 0.030098859100572528, 0.04566754304593609, 0.0409719450098853, 0.031109961095236005, 0.1448456074802145, 0.049672367261542436, 0.03655779235545666, 0.008593546282950669, 0.027038450841040864, 0.015128039747416494, 0.041109070917891885, 0.04887086309252247, 0.04317626342057221, 0.038785116386509715, 0.0351117362809037, 0.04247135144748515, 0.06120156917360522, 0.06751654684663781, 0.0497660176798461, 0.07119648849531528, 0.0644901165017678, 0.07984916048665201, 0.1100573633166571, 0.07396628704643057, 0.06498544597096982, 0.0643770266023855, 0.2073771359338876, 9.115590241647537, 58.84641755011774, 83.15898587626796, 80.76513982588246, 76.20237212027274, 34.475205867521225, 37.88077631304341, 64.25566019550448, 81.09053181063744, 86.74113750457765, 56.46169493275305, 13.95776798648219, 2.2364756561094716, 0.0899806579635028, 0.16690207555169062, 0.10217491612439195, 0.567701427686599, 0.9576877398836998, 2.930550334915038, 0.3321069292724133, 0.3170515548798346, 0.3112709005513499, 0.05903843181928801, 0.08441467679315999, 0.8530428873435144, 12.427761208626533, 41.31600379943848, 79.53015019816738, 98.52542015814014, 101.03050462661251, 85.20931074696203, 88.25373680360856, 83.14032323898809, 85.69699471996677, 86.59325630434098, 92.20016679456158, 94.26213325992708, 97.54145437671293, 90.65235245612361, 84.54857180195471, 73.86582405336442, 70.56621643804735, 61.81097630531558, 60.46645841290874, 51.82137020172612, 16.43155586334967, 0.11072960547021321, 0.3240487874755937, 0.09564429236155364, 50.698117133109804, 97.54297625633978, 71.49495524744835, 88.23546640334591, 84.6777746754308, 89.13781550622757, 89.13780766148722, 93.8750502371019, 88.57173119821857, 88.63967449434342, 87.84936397306382, 93.04218199945267, 90.6043348004741, 85.70789890904581, 76.53372610768965, 73.74163396896856, 67.98237862125521, 62.68481369941466, 55.00049437246015, 42.91017270857289, 24.921202505788496, 20.42915709557072, 8.609262262621234, 1.3914019830765263, 0.16614724911989706, 0.21031401060040922, 0.016928357860794472, 0.6053162834817364, 0.25936770823694044, 0.0576856124755596, 1.1909349142543733, 0.729421607909664, 0.23871855900412609, 0.17767322580179862, 0.05381087765037533, 0.18902557631654127, 6.5276525674327734, 19.64754246896313, 52.47407613262054, 68.76169081657164, 38.26568634279313, 19.759563399899392, 26.69742234291569, 59.28549551194715, 64.79524889299947, 54.77791163229174, 15.580497634026313, 0.31588587549424946, 0.02221407725535814, 0.3409444276363619, 0.04118018302946322, 0.10110531182539079, 0.037185693339955424, 0.03429031382585245, 0.018862670497788538, 0.02061156878968881, 0.06490562727013904, 0.03893185669796602, 0.051361537508426175, 0.10268589676988703, 0.034881331507236726, 0.03776132031494091, 0.03252084607318525, 0.03359779715538025, 0.0849102360887393, 0.03773137393798079, 0.10236292176188962, 0.1093639694755116, 0.06554332651918934, 0.13654625523955594, 0.01849628703278159, 0.11036731482994173, 0.032221784499744256, 0.05571636431399853, 0.11838343670411457, 0.07730408616724514, 0.030626415973529223, 0.017361758697417476, 0.07896108838218836, 0.06813982066007392, 0.03592027313706856, 0.03662423899156913, 0.023655349110823967, 0.06841043355844675, 0.025965479585612496, 0.05852107349182329, 0.07588637917633019, 0.040244782013037515, 0.02175476732513597, 0.036638660596743707, 0.01765525272686876, 0.057891896970930605, 0.019650658960604382, 0.007476761501522796, 0.06882511695185978, 0.016548914511898355, 0.05920528959963591, 0.04614737072599031, 0.06955610272744972, 0.03408802830944619, 0.03669921984715808, 0.011383658612988169, 0.05364209698933748, 0.023818589040949464, 0.054957849168849576, 0.061576772225840445, 0.06174468720752386, 0.0350952883731694, 0.01816758551755019, 0.014087771827865754, 0.11124356619773373, 0.059917257242505594, 0.043717010412365205, 0.04340763346502378, 0.04273619187334853, 0.011747741899002465, 0.015318019018929093, 0.09121687106427648, 0.052312796544884486, 0.0432288630174533, 0.07564042664823994, 0.11941110535014061, 0.009573692579813784, 0.02687064885732628, 0.0244165608854664, 0.08535869629873384, 0.10243993658091753, 17.706561511562718, 72.8447683395878, 91.52664092279251, 80.4923076014365, 42.651206062686065, 25.11585993151511, 54.640648288111535, 96.13811662120204, 106.06306245250087, 88.52815366560414, 50.74894712817285, 16.55266688716027, 2.999024621901974, 0.29042849797875653, 0.13807676101644195, 0.1863054279237986, 1.0094413918352898, 0.643652732814512, 0.36109048692930135, 1.184711951401926, 2.1913495227213833, 1.6757357000343263, 0.15888036889654977, 0.24318834496361597, 5.767697759212987, 36.07841976227299, 69.42037443960868, 87.26338540354084, 86.01564022802538, 89.0331902042512, 82.07678041150494, 85.34813127210064, 91.14166029037969, 91.06194203899753, 84.39577194952196, 83.41177478913339, 81.95525753882625, 82.60604935307657, 80.53987810688635, 76.4419504903978, 72.65347434628394, 72.27181988377725, 74.25675884369882, 78.3213149347613, 67.62022618324526, 35.88667077402915, 1.2512252984508392, 0.2261356721001287, 0.44267780898559483, 61.40206529248146, 87.25163398250457, 74.04522542030581, 86.9835948944092, 83.34722826557775, 88.95389556884767, 88.04251716982934, 90.07368518460183, 84.97761634088333, 84.82890359817013, 83.33156231910952, 86.72760532748315, 87.43403988499796, 86.10297572228217, 79.27423907864478, 76.70464731031849, 72.81204792761034, 73.19546745669457, 73.73418146564116, 72.21019944837018, 57.48388028913929, 46.29175786049136, 25.098199459814257, 8.952974657858572, 2.229983888326153, 0.9086502067023708, 0.18765346687887946, 0.33564150573745855, 0.18485713870294634, 0.32011363895670064, 0.6343233753596583, 1.2774860570507667, 0.48308076517235854, 0.08190920155855917, 0.05707161981732615, 0.5253680831482334, 11.548857092857363, 29.030922728200114, 46.822474156656575, 89.90660790474185, 66.20530174624535, 24.804639470192697, 10.57140931006401, 41.18000738082394, 71.79951944658833, 63.8555549037072, 21.59692318208756, 0.4126313502990431, 0.12824094283484644, 0.16723158528968213, 0.11562938125984323, 0.0782911291706466, 0.11413592349497542, 0.03429574155879598, 0.0848963315929136, 0.043270116852175806, 0.018589604202838197, 0.10630236037315861, 0.019540326977749507, 0.0815215151035978, 0.030105062497539387, 0.014101210925277444, 0.00816963536048969, 0.011044709714159611, 0.011869524023495616, 0.048702936619520194, 0.06367091570169696, 0.024963329328344237, 0.048485984349803585, 0.10334561338588115, 0.056905095285225304, 0.10898288669845752, 0.1419306429283273, 0.01254927575392949, 0.05702662747353316, 0.07387467059156588, 0.06324052750583618, 0.009901905713993455, 0.03832830581814051, 0.06302594627824522, 0.03121524455866987, 0.08306486051409476, 0.00997118304498614, 0.04263702945242967, 0.10461872128108818, 0.1062060707819558, 0.17337453791931753, 0.12156831701436352, 0.09542675403457496, 0.22151407815756338, 0.17325711196228383, 0.1832879148423672, 0.1382239265066962, 0.1224796781917253, 0.14835366198132116, 0.14190352341580775, 0.20789816765294922, 0.10868608125395353, 0.18379855840917558, 0.08390060881333006, 0.11270527727901937, 0.07861003625176607, 0.12442722691283112, 0.08599588226887488, 0.23980234359060568, 0.17654580484715202, 0.11863018596364606, 0.08885065529255137, 0.1728480669759935, 0.09500594959864694, 0.16959784702668268, 0.10746486049385802, 0.1793603965592, 0.12065638127105853, 0.10612950029392397, 0.1751911009271299, 0.1633902518979965, 0.1365760713815689, 0.15834527180319832, 0.20783277438773265, 0.1897961688378165, 0.25640472529395936, 0.1079232951686267, 0.1299550798871825, 0.1121351316631321, 0.139694539529662, 0.20087799838473722, 15.811708607981283, 84.00720627077165, 105.54709819055374, 97.92667819607644, 93.38632291363132, 48.85535624719436, 53.60956699617448, 78.40950550571566, 95.58107729881041, 102.5039743608044, 79.31034057371079, 23.563748636553367, 3.7139165449527005, 0.27611120333594663, 0.29550980596292403, 0.3298507696918903, 4.71555333945059, 13.422243845078254, 12.250579903202674, 3.722923532609017, 1.9115067970368171, 0.9676459023068029, 0.2135165645590713, 0.1444969302223575, 2.136718750961365, 22.756626836715206, 56.69595849129462, 91.89310012325164, 107.37980996408771, 110.7238894124185, 101.37177436582505, 103.61732344473563, 99.87663745880128, 102.89560733302947, 97.16616984336608, 100.57224627464049, 95.93860918475737, 99.856076394358, 91.54695095554476, 91.6373380537956, 84.86578172253024, 86.53147897412701, 85.28201580047609, 91.02438142222744, 78.44747404898368, 25.006384618820686, 0.2112472589097677, 0.37132542159768844, 0.4978251078676793, 57.249122511956, 98.67887112402148, 80.31726791012673, 92.28290527097641, 87.50774122053578, 92.41617956469136, 94.00098185385428, 98.8040025772587, 95.217206862665, 94.81616804676672, 93.55088987658101, 97.05614736003261, 94.84342851946431, 89.98766760672294, 82.4525042503111, 79.40352824426468, 78.67756028329173, 80.76495155211418, 81.47891706035983, 72.13285815331244, 49.242537329273844, 32.97820583466561, 12.00144369756022, 2.343401183043757, 0.4604979946969017, 0.23459345132352846, 0.20278269214735878, 1.0086313611076725, 0.5093966514593171, 0.6368550814447865, 5.326891993322681, 4.4517151098097525, 1.6683631149991867, 0.6175703807703911, 0.21430319896148098, 0.4285847329564633, 10.729091532768743, 32.610813110105454, 66.7262238840903, 80.12894707341349, 51.45664076651297, 32.03213995502841, 35.730999746630275, 74.61968791100287, 83.55243098351264, 76.85789431295088, 28.629642686536236, 0.8188860911515452, 0.21083375529175807, 0.4515715994902196, 0.22169521198638026, 0.20985520054255763, 0.2154228364628169, 0.1278408917207872, 0.22322435412676106, 0.20521103764974302, 0.1636208443632049, 0.19335408034103532, 0.19373430509961423, 0.2189579032241337, 0.14582627663208594, 0.0870784181320379, 0.05219943085384946, 0.12761075124745408, 0.17595599375424847, 0.13699800196674564, 0.15476450023631896, 0.13093872146020014, 0.16603661070187248, 0.13874557109609728, 0.21517586503778735, 0.3503756747851449, 0.13434890056810073, 0.12749706379949086, 0.15182673690780518, 0.17536583026089977, 0.14763668029298707, 0.1350357596792521, 0.24890725260540364, 0.1756391091452491, 0.12364995410485614, 0.11305456740721581, 0.12022109011248236, 0.2169041747167226], [0.08552293788882033, 0.025518009544260083, 0.020488699777953086, 0.06712408766390816, 0.0897107498660203, 0.0869703384476804, 0.07683091962169256, 0.040095463815716006, 0.031206650967379252, 0.04917689989651403, 0.02852410408518007, 0.07449305676404508, 0.04486500848865798, 0.04581035715678046, 0.0562935272952722, 0.02172911870143106, 0.04104493403687112, 0.05228825108779054, 0.024503050296897852, 0.0214905014652158, 0.04766969468384501, 0.057372964332781495, 0.040167997020386884, 0.030563106467466683, 0.012616825556652922, 0.02912272135877321, 0.07224916225118984, 0.10946976621785473, 0.04785848173102544, 0.061321994364862485, 0.05341022515729551, 0.05312692584289659, 0.050566479969289035, 0.045130228128043876, 0.047886106861575, 0.034836691563888904, 0.05336363935062001, 0.07857246729995936, 0.049396912687488144, 0.14596161372478933, 0.028703316948526812, 0.03785280653485849, 0.05624473515537478, 0.2980710523984125, 0.5675380364541085, 25.61077871630269, 64.85192321961927, 82.2061009560862, 78.48008463459631, 54.541412322751945, 36.35599413225728, 32.194669246673584, 46.191380485411614, 89.29242749367991, 82.28042202611124, 57.030026758870775, 18.54811583795855, 1.3607134814223936, 0.047812121920287616, 0.22803417587232208, 0.12861654042236267, 0.7684302534307204, 2.881812434042654, 1.1891521970110557, 1.8095987169973313, 0.12625169594802205, 0.2857000500925126, 0.08901338002854779, 0.5341962965265398, 0.407300389582111, 3.021230385188134, 22.046432687390237, 50.24109825011223, 65.43686236104658, 64.63556135854414, 65.50871626023324, 67.95933077412268, 71.61167713903612, 72.77109053827101, 80.45456655563848, 84.7313307177636, 84.43871405816849, 73.63477291599398, 56.66441086799868, 35.05777981973464, 27.127484736904023, 21.285365396930327, 2.4747003182288143, 0.12504073310523264, 0.29344363618762265, 1.0686377411888492, 0.17497347066960028, 7.599164670513523, 88.74291912201913, 98.26817543275895, 97.04808296695833, 98.70301723480226, 100.33892800731044, 105.74319316494851, 102.3861385160877, 103.79545396374118, 103.47085429776101, 105.0382177291378, 105.1126721597487, 95.46470842053814, 89.91739442271572, 78.40555175658196, 68.5842663241971, 45.196330085877456, 19.109836509150846, 7.556370141044741, 1.9683568948699584, 0.19803913700724804, 0.19896820247653993, 0.19223857971449054, 0.14799340147404902, 0.19059294624434364, 0.9543148079706777, 0.17267810270911263, 0.33965715477543496, 0.23178385450474678, 0.5626616110244106, 0.5698584248462032, 0.6133476428447232, 0.08854492492372952, 0.06621945273852156, 3.673544569361595, 28.97841003633315, 53.60156143865278, 65.34991125906667, 66.18524274518414, 26.786165968064342, 26.378592483458984, 60.00801570953862, 75.22021847386515, 64.71937848675636, 35.10364409415953, 3.9968775549242577, 0.6285736096962806, 0.052857783833338376, 0.08243640028541127, 0.17734426764711259, 0.11907389642851007, 0.09688835020267195, 0.06714748398911569, 0.08509912272734989, 0.018742249136970892, 0.01100997816050245, 0.021711701692472545, 0.03830167660189252, 0.03453541216590712, 0.03857788960299185, 0.01736984858589788, 0.03782921868766989, 0.04325863702463047, 0.09936256904996212, 0.018094106194292827, 0.04181368411668847, 0.08444763389566252, 0.08663067038381293, 0.02773839473393896, 0.046057684812694795, 0.04665666214761235, 0.018912425993250746, 0.0369668947983413, 0.05982314334100774, 0.022476981393992904, 0.07071199917024182, 0.09469945314190081, 0.0751673596941175, 0.009183905128720067, 0.016673694913005157, 0.05781739492029433, 0.061967388967112194, 0.08791136254947032, 0.031019861494461377, 0.0820893394730745, 0.05846320704046277, 0.003938639725205459, 0.06465582131978966, 0.033514013949541316, 0.045913621978533846, 0.13934049965633502, 0.0540839841649417, 0.013037281422575396, 0.04492107846383606, 0.02675161603087139, 0.07697321279274841, 0.07715073834744192, 0.03279301413004437, 0.029394808976400285, 0.040852301228310794, 0.02233367890209681, 0.06316982908174396, 0.026143292423277616, 0.03278160325041221, 0.08595921730081882, 0.09212737422316306, 0.010071302118200448, 0.07879217365576376, 0.07268451469679994, 0.04189382840488707, 0.028571377455767606, 0.07891285548647566, 0.029641947025553356, 0.0784225132496607, 0.03574338726579182, 0.05292595799772009, 0.03452732227742672, 0.08690452383410546, 0.02094910329868717, 0.12635688748090498, 0.031191371343729478, 0.031173033114042015, 0.055200760327880426, 0.09403708586168867, 0.10474962272470999, 0.05013460939329478, 0.11919207315170958, 0.3477277378401449, 0.9182499012639447, 39.35734079730126, 79.54088180295884, 95.83583524150234, 71.22741037799467, 33.31242707467849, 26.629728117296775, 40.846896171569824, 79.99922644707465, 116.85780955899148, 79.23959670528289, 55.41296689741073, 20.700898901108776, 2.4830130463646305, 0.20910175306902778, 0.0781464304835085, 0.39212467809838636, 0.35504222276710695, 1.3199173995564062, 0.1939291825457927, 2.875001483386563, 2.4244741230241718, 0.5183855900841375, 0.5700592011693986, 0.47755242956261484, 1.7232756845412718, 19.47799017352443, 55.45008820872153, 78.5927115717242, 84.2627957559401, 82.1838846514302, 79.93576249768658, 83.22498367678735, 87.71652114006781, 88.01970466490715, 89.90689031539425, 93.5855479394236, 91.44170591908117, 89.49101709550428, 80.77262370817124, 70.77654961616763, 62.31129815501552, 43.05732434795749, 10.714764095121815, 0.6663190068737154, 0.3085237398983971, 2.1124101069665726, 0.12515434394440345, 16.69796520663846, 96.32202086910125, 84.81729338246008, 86.79985538605722, 82.78645484678208, 84.69497819100657, 86.69046832669167, 88.23614105101555, 86.48131970436343, 89.0367909400694, 92.16194721960252, 91.37155040617913, 85.60296766219601, 80.58140816227083, 75.71513529746764, 78.20860170548963, 72.72876031937139, 59.32414654762515, 31.29831744778541, 10.48768533814338, 1.6258707306077405, 1.1389350722874365, 0.4572054100853782, 0.10336013075204627, 0.14267249183068353, 0.7268566842521391, 0.3836998866210061, 0.9480437960836195, 0.3675177501093957, 2.2877461823724934, 0.7036846083018088, 0.20976457234111526, 0.13267527424520062, 0.05272623121498093, 4.12468308402646, 28.054293740180235, 48.68661196001115, 58.65078933777348, 84.82360055369716, 41.39846770994125, 13.500695170894748, 31.612683649986025, 68.68840525227209, 72.30706630214569, 41.18427884194159, 6.812952535767709, 0.5851172415479537, 0.051550355199123585, 0.01862157496713823, 0.23208609151263393, 0.05451303170693498, 0.09796950710757125, 0.07599527091388741, 0.024968540641449155, 0.010627415876144604, 0.027917004303045334, 0.026374018953872785, 0.009948202322477536, 0.019757874880827243, 0.07641598341926452, 0.06584054565117245, 0.03736185525814372, 0.029399443808342182, 0.024943190792034713, 0.058851575313676754, 0.030055425745705446, 0.03135210425112277, 0.054927343547704725, 0.01635609401179658, 0.062216988073722015, 0.021761631472937523, 0.022711071050575665, 0.02627253528654335, 0.058062803525958336, 0.02031331735422775, 0.057319207943134734, 0.053446591351061105, 0.0249921553017151, 0.08792411025253036, 0.009332990626834575, 0.00883216351916593, 0.03176712280800266, 0.01955816725028619, 0.10451149195432664, 0.24941498503809978, 0.1913896163985614, 0.16306659507174648, 0.16310730498404274, 0.14858345771508832, 0.2869066385732543, 0.24438109789644522, 0.12288843206460438, 0.09395328350365163, 0.15626840744047396, 0.1323069238494481, 0.18486581081824918, 0.16922169785586097, 0.16252556845786112, 0.1636501242436709, 0.19628865674378412, 0.13291640808024716, 0.19848619527634115, 0.25378225311156244, 0.1719703293976284, 0.16265543568278515, 0.19707498471102408, 0.10379174468858589, 0.1516643569113747, 0.13222771035807748, 0.10487551395330699, 0.18218289429862655, 0.2650531225146786, 0.12708132320474233, 0.13699266999479265, 0.14203617920077619, 0.1376733850807913, 0.14367669520358886, 0.20402125713806, 0.16255982790983495, 0.16269804549313363, 0.13830505521787753, 0.1636121109608681, 0.19644411130537912, 0.28702513705338206, 0.1286857334836837, 0.1447574307601298, 0.23744745059840142, 0.4295803714663752, 0.8004100116029863, 42.15641083255891, 89.00222701411094, 108.62308363760673, 97.44743516368251, 72.73127848102202, 49.46669293988136, 47.32164282952586, 62.984498470060295, 105.11712797226446, 104.61227186264531, 79.85798974190989, 31.070763103423584, 2.739903042393346, 0.33101295571654077, 0.37887187794812266, 0.7085946190261072, 3.496623366109787, 14.184384884372836, 13.00329254519555, 8.424588249575708, 1.644367525173772, 0.9035218915631695, 0.4877377217335086, 0.49661888710914126, 0.37166436953890714, 8.18173126828286, 34.22619027476157, 61.214646600907855, 79.4419910061744, 81.44199186755766, 85.07965287854596, 94.30560881091704, 102.63600918554492, 95.1190613162133, 98.6909677136329, 105.11993638930782, 110.0691124700731, 103.48397854835757, 96.20221599455803, 77.80201665816769, 66.29659098963585, 34.38769778897686, 3.9297005918718155, 0.20055815667635013, 0.9140604421977074, 3.391159167212825, 0.25136500056232175, 9.68139115841158, 93.19936706173806, 100.80186182452788, 96.39417679079118, 93.99172506024762, 93.66836486324188, 99.00820901316982, 96.6295660695722, 102.48056565561603, 103.3618986991144, 107.01831648426672, 107.55530465033748, 93.55539275753884, 90.86064600175428, 82.26765078883018, 88.56838933883175, 79.44755292707875, 55.765050611188336, 25.281762461508475, 5.164923110315877, 0.3619493634229706, 0.3211317391645524, 0.29307012235926044, 0.4265347429581227, 0.3583254611059543, 1.5910641079948795, 0.48564912090378426, 1.5798875593370008, 1.6630817661362312, 3.4011241937837298, 2.729464879920406, 1.127242119081559, 0.3127762326790441, 0.09459666712510009, 6.283053563487146, 40.31348520709623, 69.30124421273509, 75.91447014962473, 79.72991651104343, 38.83584599341116, 37.575498242532056, 73.76014755618188, 90.19436867006364, 83.53943224876159, 53.61341091894335, 8.398509390892523, 0.8387323649179551, 0.14218325276047955, 0.13173905351469595, 0.21743872022676855, 0.26154229477528607, 0.20155226301041343, 0.20154457148765365, 0.15374572587109384, 0.11165330832403515, 0.09399223907460129, 0.1153094782644222, 0.1868478641394646, 0.12354201997720426, 0.11812557150880176, 0.133051791138226, 0.12645577411017112, 0.13010606049529969, 0.20842702879059702, 0.1585461247351862, 0.15029115962886042, 0.1738386799491221, 0.1646910079063908, 0.18159881354339663, 0.16933232095212708, 0.12956714828408536, 0.13838842090579773, 0.16082218727998196, 0.12050320965147789, 0.1514476766028712, 0.18094941613174256, 0.3306939567048704, 0.13881883974517548, 0.19538972917343342, 0.06972146280590566, 0.08892121965125685, 0.17504175974717065, 0.21031578792439354, 0.2128746441655582], [0.10213602184047622, 0.07776147130155757, 0.10702810610734648, 0.13608173016578923, 0.03670881126797007, 0.037712876745049036, 0.022717159534353885, 0.05791025626803598, 0.042932069064268184, 0.02511200975746878, 0.060622927642637686, 0.043933077850529266, 0.023458797762530948, 0.03179889055900276, 0.03933021858815224, 0.029906569116358316, 0.036544772691183516, 0.07362556944210684, 0.026762710899234782, 0.05157563610062484, 0.03879183497760565, 0.10661804222411687, 0.040851795610280774, 0.03439778447031014, 0.04184151226053796, 0.009443544775187489, 0.07570218099581619, 0.06459815022084983, 0.07298153464592273, 0.061752083786432786, 0.051943894565826466, 0.04481944157892177, 0.08019317226905016, 0.12814525845310382, 0.020766038928301107, 0.046316327587250745, 0.05286043449755638, 0.08377405108823892, 0.044577959173869704, 0.13059248036194232, 0.03887652216719524, 0.04394222494034518, 0.17721257713292876, 0.06947240762172208, 0.15744450562182935, 0.43842648065859274, 4.426966915207525, 31.711099839979607, 64.7836112206982, 93.16974532219672, 90.64441357889484, 78.64461237384428, 37.98510743725685, 31.834589781299716, 64.7185665561307, 76.1161192001835, 77.59211494076636, 45.02291033344884, 17.632954312909035, 1.416943844768309, 0.10622389764795381, 0.3303492784259781, 0.4151552116438266, 1.4175460511638274, 4.813364994141364, 3.5918962667065286, 5.92410913398189, 37.08489602611911, 17.01770897834532, 0.41037516007500313, 0.3086491944568773, 0.22767599912420397, 0.143550903566422, 0.39135276790588136, 1.1394485350578063, 2.0264002512539587, 4.399135247353585, 11.125790246071356, 4.674696460846932, 7.927270935427758, 16.066410656898253, 22.88919706498423, 23.006393563362863, 13.289899153094138, 6.174513245782545, 1.358003491355527, 0.3674310902434011, 0.15384206908845133, 0.09814072775864795, 0.4761108359502208, 1.7053703098527848, 0.13470217435350343, 0.09545332962466825, 6.709240165448959, 55.93514027134065, 90.39078527881254, 102.85038240494268, 100.2104546946864, 101.20309675893476, 101.72274804884388, 96.71213980643981, 101.9976277505198, 98.98815001210859, 93.9124539590651, 89.99758335851854, 86.90340595860636, 63.11925149733021, 24.977396342062182, 4.7855264621396225, 0.2600758186271114, 0.32842229150476, 0.22810012072084412, 0.25703389798441245, 0.3496192089251934, 0.47991345125821333, 0.37037945622878693, 0.38842493307686626, 0.7215254477435543, 0.5466548473604265, 0.6858236054258963, 1.3911449452561717, 1.7608717252169888, 0.18213720481482246, 0.052921028221927346, 1.9523118268097601, 31.9964091239437, 63.297582057214555, 64.32257975301435, 58.23915620003977, 43.9088709123673, 22.11455837372811, 47.77431180400234, 75.34529501391997, 70.95468013517319, 43.965835494379846, 10.820950500426754, 0.13662248098802182, 0.5998964872091048, 0.15612973020442072, 0.09394548472858245, 0.11071848187355265, 0.02798579708342591, 0.07272598303614125, 0.050329820087720314, 0.020551407904995066, 0.02325252667369862, 0.018205133401938987, 0.07177141449985004, 0.05069472308781359, 0.07865952553167459, 0.035129245220413136, 0.053127377834771915, 0.01951069852727796, 0.09565173107529841, 0.020764238621679046, 0.04014191938744437, 0.025355888102504037, 0.029483198285883958, 0.1445557964184592, 0.01822180539039114, 0.02387170957761907, 0.023442462852765477, 0.022396637922933987, 0.016184660771320906, 0.04407632480105085, 0.048925511974601016, 0.009474130835564388, 0.12926201546384444, 0.06746615358297864, 0.023972890640218413, 0.025060643562145775, 0.04170910545414494, 0.053434303300755645, 0.06087277189738328, 0.03723640069966355, 0.018742224239113352, 0.06165917647341567, 0.04826682574686505, 0.01677412903987833, 0.07717667808455807, 0.08651135985048548, 0.05816432166724436, 0.02334282354211375, 0.026514795270838568, 0.04074947307667425, 0.05779502898334496, 0.03478370892304567, 0.027465112019150008, 0.032176761512434295, 0.030871487500506545, 0.08902959810990481, 0.039151394514427076, 0.0381642940544313, 0.02376441704860378, 0.03499655879192776, 0.011481599123667807, 0.09218064031653828, 0.085449822457327, 0.07154272959357308, 0.059959732987467325, 0.03464146171726527, 0.04405389757706754, 0.05495511423495989, 0.04574726215533672, 0.04463074646229225, 0.026279839934901367, 0.0770359783763847, 0.030462455920754906, 0.04446025742518325, 0.06618215191748834, 0.07228506879220087, 0.025681054121964884, 0.03676275151871866, 0.09763753056646356, 0.0657426396144494, 0.13746336973722906, 0.03949080976927954, 0.005080634305599116, 0.19253591375966228, 0.1835524909678967, 0.1652621877409758, 0.2845616434370318, 9.420537852471876, 43.135065724772794, 80.41016532528786, 103.45625523597964, 73.2149459469703, 47.96972820835729, 26.329627575412875, 45.204767104118105, 93.41326959671514, 106.28022055472098, 83.62595973476287, 38.497055192147535, 15.664700135107964, 0.6840950659205837, 0.27965252137472557, 0.22285706093234403, 0.3256637621070108, 0.5613712738117864, 2.1141913533210754, 1.2444757574027585, 7.293491911503577, 23.68720131535684, 4.002102397141918, 0.7157008506117329, 0.6899743923737157, 0.42930678614685613, 2.9312149315111102, 4.974944581908565, 11.516427916865196, 13.495143055915834, 22.90700854793672, 35.416782594496205, 20.586916785086355, 26.828527565925356, 37.868114902127175, 44.51741095512144, 45.189826796131754, 34.28564948420371, 18.61223678435049, 6.309309419124357, 1.6137298917578113, 0.17487303654272712, 0.2142212122318245, 1.7737472730298198, 4.273273252671765, 1.0751069553436772, 0.08628454419874376, 19.272973768172726, 80.06111360365345, 95.37781223174065, 107.52178407484486, 102.43659588598437, 107.10181590049498, 103.77249240875246, 107.19366996519028, 106.99517450025006, 105.76416215588971, 98.98598486377348, 98.51274305774321, 92.6550126844837, 81.782437909034, 59.87434917880643, 28.98691373486673, 2.810744970075546, 1.9586630021372151, 0.9847907049040642, 0.5895761797024358, 0.3138619018418174, 0.03725061163065895, 0.41486369986687943, 1.746332724728892, 1.4375105476187122, 2.3901881950516857, 0.3195976021309053, 0.5928422883152962, 1.0028584902324984, 0.28035254187641606, 0.025750469348783937, 0.6088092766942517, 22.676226092923073, 62.37249105207382, 78.64971145506829, 76.04072340073125, 61.50790652921123, 24.767200446897938, 22.38441744158345, 61.22128325123941, 80.33149042437154, 53.32562661940052, 15.822586321061658, 0.4799023276615528, 0.6982219723924514, 0.16575652895675552, 0.0595640562354557, 0.056618601384182135, 0.13665557598635075, 0.08686246560706247, 0.06018819572824625, 0.0036527206295079765, 0.024812664731495807, 0.05600242920580411, 0.02564996244355796, 0.040179093803970084, 0.0181744420044725, 0.053665573753777056, 0.04765573656186462, 0.1025542752036164, 0.10932240154474013, 0.0173132615013709, 0.051150859498809424, 0.05487290533980536, 0.040299155103463324, 0.0382498775668923, 0.007166051082388168, 0.03927687205554497, 0.01701151862019493, 0.036293342634434664, 0.042738934468117454, 0.026048017898574475, 0.07521866460240657, 0.05286521105576427, 0.09011498382014614, 0.09239241766232638, 0.10258830482921294, 0.04216007843253113, 0.04098964164093618, 0.06748744316639439, 0.01914889818327802, 0.029032430236017513, 0.04346502877231087, 0.2043912469619705, 0.1475154851833659, 0.16541931237424576, 0.172056453002076, 0.12263688709466689, 0.1482252196799363, 0.1568531163878018, 0.1023628451530972, 0.2526100619786209, 0.17913608601497066, 0.2317584203856607, 0.12640881292041273, 0.09565810492682843, 0.09416563541538293, 0.12762817208685223, 0.1353980886239198, 0.17945920657967368, 0.22686979883620817, 0.08739716433469327, 0.137051398295068, 0.2383882831782103, 0.21242453686652646, 0.10657982209757452, 0.12373402459366668, 0.15952809623652892, 0.09346454239059841, 0.2261975107173766, 0.118927841765746, 0.21986516583110058, 0.1504778399342491, 0.16680361793166207, 0.09888046225833316, 0.17229397090211993, 0.2843695392291392, 0.26777604414570716, 0.13887741482786595, 0.2138050119843214, 0.1910432680479942, 0.11202083134482946, 0.23910109734823629, 0.28587839536128506, 0.11342699339072551, 0.3421636718896128, 0.14930742612529188, 0.28003657657292585, 0.6931914100723883, 8.532764277150555, 47.815590827695786, 94.95283126831056, 118.14159347165017, 110.55412923136066, 93.3978311477169, 59.69423786286385, 47.67222035315729, 79.56635367485785, 92.4938032704015, 103.0976878443072, 64.96138088164791, 30.449357686504243, 3.0270739813004774, 0.31354847995023577, 0.7099426886247051, 0.9114667749212635, 3.5173070046209522, 14.631226197365793, 10.318972429921551, 12.517608000386147, 86.90083288377332, 37.77146377871114, 0.2682770656481866, 0.6438192496857336, 0.23581545349330674, 0.6297652134972235, 0.8838306127055999, 3.0632507368441555, 3.8556018712059146, 9.156102441972303, 19.70344997221424, 7.441350067815474, 11.3851785467517, 20.234113316382132, 26.988434753110333, 30.506216364522135, 22.875698228036207, 11.009032072559481, 1.9636931967350746, 0.3278977664247636, 0.23646926357140466, 0.3142369172025112, 1.146664347860121, 2.8591801130002548, 0.8727126544521702, 0.27646872124844984, 8.06706715014673, 62.86409739525088, 97.96372890472414, 118.69531446887602, 115.56782830146052, 120.03266226860785, 122.50879964520855, 122.43745173177412, 125.41587998790126, 117.33466779032062, 105.72892358226161, 106.21071615526753, 98.47571588331654, 87.23454029329362, 59.00641495181669, 23.378752008561168, 1.1930713802576065, 0.7589265343643005, 1.1559846348339513, 1.097531268192876, 1.5130273276759734, 0.49541710966056396, 0.5409857967207509, 1.6625365566822792, 1.2256035184667957, 2.7600248013773276, 0.8279009848352402, 4.568999861517261, 4.502016075195805, 0.9503681068458866, 0.12260609802099005, 4.395327606508809, 46.863706111907966, 80.79760136142855, 78.10123858913299, 70.20211850443195, 59.94175118784751, 34.82909779394827, 62.86472497447845, 87.31130107756584, 90.50435358478178, 63.232309895177046, 20.5145529777773, 0.5437454905721449, 0.7813862711191178, 0.21301099249432165, 0.33477000411479707, 0.16889016564574935, 0.3376584313809872, 0.1990438459981834, 0.12127063822962585, 0.13070895636994995, 0.14629481600657587, 0.1817514029361548, 0.15292106286412285, 0.1837077310248729, 0.10573306511486731, 0.1677946292705113, 0.19439744612862989, 0.18204355822695842, 0.22071524763539915, 0.11985049507911168, 0.11453152363819462, 0.18479484043294386, 0.10751947490197998, 0.16750411340786567, 0.16014461315447287, 0.09652405241203886, 0.08599173007232529, 0.19332693018499883, 0.1209556381969202, 0.1945825789364115, 0.19951381029621248, 0.13215398205624473, 0.21815582448917054, 0.22059972157641766, 0.13810348216324084, 0.11279562202792977, 0.14928062836970055, 0.12949674480384396, 0.1904572567511951, 0.15036013818556263, 0.15439454105592545], [0.03687076608560259, 0.0885126189959626, 0.016720087282479774, 0.0203332643685562, 0.014348966632819465, 0.010964688957638798, 0.05979865151006849, 0.08364786108535144, 0.06184393389811439, 0.02035513617879441, 0.05068801215759689, 0.034960468389814904, 0.033633071673853744, 0.028259330692010063, 0.02672351018014935, 0.02440793856587862, 0.020307274835724986, 0.03350959362221822, 0.02462134384850581, 0.07657892265987974, 0.04182676506799556, 0.023425143520017306, 0.028196183979631435, 0.0064227322488272145, 0.018739437594288783, 0.045858448326227166, 0.06430090044534977, 0.07558738272036276, 0.011487414688623, 0.04243257590719769, 0.04018324600051969, 0.03179086578799592, 0.00498773034421667, 0.03209851712228791, 0.017984567112439585, 0.008238109256771785, 0.054387975514175436, 0.04503463567685216, 0.06568539752474715, 0.027056825459904732, 0.00819948597645928, 0.0720220018598822, 0.19427396807699435, 0.0790339203611497, 0.04173932762275781, 0.1692089961180764, 0.14821086319223528, 0.22567598870204342, 5.761764684031087, 29.138142678045458, 64.13077977395827, 77.34025170726161, 89.74200956283077, 70.33177637284803, 38.71704916800223, 34.044796343772646, 50.763189254268525, 86.20693422132923, 85.68369004034227, 58.786279770635794, 19.32697892189026, 1.1635267398049756, 0.15392053181365614, 0.30821460809919143, 0.14121877870732738, 0.6677843185682452, 2.088728306754943, 7.101195752620698, 2.2183302813960664, 2.6276896701705073, 0.1953166137419401, 0.07835845297743237, 0.5277938239516751, 0.011157795783102272, 0.07393476252834644, 0.048755440455410755, 0.1560578864788817, 0.16495147780064615, 0.21632652910005665, 0.4325165413320065, 0.8042693174173756, 0.749649087027196, 1.191792319859228, 0.562568454732818, 1.109189532937542, 0.2962357202364553, 0.1384834158084085, 0.11513359213788664, 0.11735596724094884, 0.47699346116954283, 3.369219634802111, 2.0406507123862547, 0.04573125474815888, 0.10883913796034553, 0.4291325777528748, 7.462841714582137, 21.140986873257546, 22.302486973424113, 20.990267838201216, 17.270492007655484, 11.736446407533462, 7.46984951919125, 5.478670558621807, 2.8712977853513535, 3.3381358317790495, 1.7891829028244943, 0.6528137960741598, 0.23712672022802217, 0.08582117591774271, 0.10264622873716778, 0.21788925653503788, 0.34207407024598896, 0.033029156902264205, 0.06187915862087281, 0.11609828835653684, 0.31721001250609276, 1.023009728279806, 1.2394192093803038, 2.963450440476018, 0.2562016507069911, 0.7770671899760924, 0.15121555196181422, 4.439357192285599, 28.69945695323329, 71.64653132038733, 62.12322834999331, 36.76411282631659, 32.8115874721158, 28.5827644794218, 35.0641183699331, 66.21418199231549, 70.82982324784803, 42.547698636208814, 19.66730336989126, 1.6698348618322805, 0.4433272370407659, 0.019751531672814203, 0.10834206181067614, 0.21658994077194124, 0.029429985818663434, 0.0758049133864622, 0.05248693599095268, 0.06696762186625312, 0.039600149668272466, 0.04340472999179075, 0.12550804673904373, 0.03320085635829357, 0.037279282471225146, 0.09003817584485778, 0.0433271176241819, 0.015230968448093102, 0.02178914743595787, 0.06314665875247409, 0.09131692980806674, 0.07385440756596866, 0.08477954914973629, 0.019709205314997705, 0.043749994327945095, 0.04212337516007885, 0.036858907044534726, 0.03410817642185477, 0.0700643637608136, 0.04295297177328218, 0.03683065755232688, 0.045140290692929304, 0.02499499748791418, 0.02250237146302337, 0.03634191643927367, 0.04838137504374308, 0.042526594047705014, 0.04023879503590926, 0.025203997764976758, 0.02119995878949281, 0.046806183358233784, 0.045392793272772146, 0.09799516339215542, 0.03721974977862932, 0.048956695583558855, 0.061567732388333934, 0.025741854690075405, 0.03905082632216715, 0.023439748986293713, 0.03191561937602538, 0.03533450698840522, 0.03146551016177381, 0.05801928973185921, 0.033582115335570234, 0.0394915720267642, 0.030582563185523597, 0.01755198598989556, 0.031148388065517913, 0.019685661517864755, 0.0681206684619669, 0.007690333887078469, 0.04531649091551381, 0.08211209994530486, 0.029451553108951742, 0.0973474054086593, 0.052211787852068106, 0.016582407875947894, 0.01739646248038738, 0.048729619461922884, 0.014447965302444516, 0.07845307249696025, 0.01875843657481094, 0.06301190005615354, 0.007146754763990401, 0.011047508807912951, 0.049664556995154395, 0.06397490322049107, 0.0152815455728541, 0.02159675977553331, 0.08785865570027983, 0.009463617236413544, 0.02223270468323702, 0.08673057591001834, 0.026731914164678707, 0.05033994010920006, 0.17432064118404544, 0.1727500077216856, 0.03300827334544832, 0.1139480710750626, 0.3883544836313494, 0.11699764493612513, 9.649783718970514, 40.56457965604721, 80.05349636077881, 93.54685768004387, 76.02467306198614, 43.34989786148072, 32.13563953676532, 40.507281672570016, 77.55645275115967, 105.79429380355343, 101.48663705395114, 54.17284680951027, 14.63831784263734, 0.28276188839827815, 0.04384456022131828, 0.4273006163777844, 0.13460120396508327, 1.0046058448572313, 2.9824908510331185, 15.774700064812938, 9.097064887323688, 4.790592203217169, 0.535483262952297, 0.18603011124557067, 0.9937207773327829, 0.06571257832430064, 0.14927210947198255, 0.20101517408845887, 0.5751405704406001, 1.040667074341928, 0.6149615755965633, 1.582701492213434, 2.424915634816693, 3.6803290440190226, 4.008138189392706, 2.544669028251402, 2.1145808937088137, 0.462239588340444, 0.03326775498628136, 0.23007173992453084, 1.2392175750386332, 3.6102188835220956, 5.037992760058373, 4.769982599443005, 0.6444724468934921, 0.13709106632778723, 2.41530460215384, 23.502365504541707, 43.828717277896025, 50.2619299580974, 48.45185026045769, 44.769866466522224, 33.11553193676856, 26.522808228769613, 20.414401138982466, 15.392309177306393, 16.52396298223926, 11.565001568486615, 8.077535956136643, 3.0455723693293915, 0.8624509986369842, 0.43190223074728445, 0.1535925542515132, 0.20253146127347024, 0.09528076065884483, 0.14316212926660815, 0.1325745796484332, 0.20836911254352142, 1.0639013566317097, 1.1521255128806638, 1.0528765546698724, 0.7678325209886797, 0.3090556500659835, 0.32792911474262515, 1.2604916528348, 15.460170103657632, 63.83257765923778, 88.63616005066903, 62.48115247295749, 43.720448094029585, 28.65116277048665, 21.892801292480964, 48.0008129919729, 78.81332920443627, 55.981486997296734, 26.451254390901138, 3.273895988541265, 0.30533276918915014, 0.10807574666555851, 0.24227994854652116, 0.13328826715869288, 0.03087895302732866, 0.056318880975126266, 0.07110312535998321, 0.06561771365663698, 0.04463273829089538, 0.046727682328632766, 0.07309477010201063, 0.01984430875088419, 0.06701897273981763, 0.08022180863565977, 0.0383836786533075, 0.021251600776468555, 0.0661251932803181, 0.024651560271459243, 0.08620045838817474, 0.11650292067638329, 0.10920111450456804, 0.0258094159841177, 0.06668678169409115, 0.06926350310565003, 0.008956038978912177, 0.007162557721453449, 0.029728806074408275, 0.038369651583413926, 0.005844991349975669, 0.025039198845925353, 0.043423533619892214, 0.06768612806955654, 0.031035185168166796, 0.09547682554130593, 0.09022928413844879, 0.014272164403190537, 0.03935364555687674, 0.03021937239194109, 0.03649854694583243, 0.04208440426737071, 0.06753683285487276, 0.12160620006221919, 0.17961576430787965, 0.13137153049390163, 0.1055719338417534, 0.13505615293979645, 0.16290104347130946, 0.16489406717160057, 0.14647512246043454, 0.23739066816145377, 0.20052952030974053, 0.10011849864836662, 0.19794867734514898, 0.1763933533502202, 0.16704095197060417, 0.1533961139859692, 0.13501645426356024, 0.07807011280449168, 0.099172372401001, 0.19164751223739118, 0.11230487376451494, 0.13012579492022916, 0.16128655913616383, 0.11617519592325534, 0.09466445058464043, 0.12773241367070906, 0.11053152577651125, 0.12787770224554887, 0.22368610596224187, 0.17719613688607372, 0.1440378290510947, 0.14041283888922584, 0.10107574849239281, 0.15614598659017395, 0.17411062584048317, 0.09641203503575056, 0.09243384769727146, 0.18393423258056565, 0.13980073463772574, 0.15132994421066778, 0.17294905268617217, 0.1276115939441708, 0.2305844366069763, 0.3764647684029995, 0.1592407213343728, 0.19623950454256228, 0.25999078286751626, 0.3025532796257927, 0.3242108303933375, 9.356906221758935, 44.884893894195564, 91.78004957014515, 103.00707324858635, 106.5792855908794, 89.51083290961482, 55.37875206239762, 45.06655846872638, 65.32180747678204, 98.67111267582064, 110.6560088742164, 80.06506735278715, 31.964157435201834, 1.7593791407923547, 0.21421444001457385, 0.777215565885267, 0.22074337838397873, 2.413693243457425, 11.031376834838621, 6.001422972448411, 6.476734809337124, 5.262647001974044, 0.5578290671110153, 0.5359473283733092, 1.4364744290228815, 0.14520432048987958, 0.3018932795572666, 0.2436023848431726, 0.32780298602677166, 0.22774062630149627, 0.21924000744137073, 0.5103492664714013, 0.7286078999600103, 0.8964137600794916, 1.214730218052864, 0.940669249863394, 1.647451733869891, 0.39000953998296495, 0.18721990707901218, 0.3235242623955973, 1.1925180809151743, 4.506170845800831, 12.229627582334704, 7.396018255141474, 0.3165550379743499, 0.22982951824463185, 0.40313768230618974, 9.070735977542016, 24.906746610518425, 29.823990675710863, 26.750752848963586, 22.931344893670854, 13.813661086943842, 8.844527986741836, 6.2657539498421455, 3.6343696521174524, 4.528801941102551, 2.515770475710592, 1.8885550479735098, 0.8841477118192181, 0.4491788311110389, 0.6425447858149006, 0.2347896464409367, 0.4892634624435056, 0.2458057762874711, 0.12886974780309585, 0.13765738916493234, 1.9109012811414658, 3.7000720491332397, 7.201247570976135, 5.4259357625438325, 3.1682704821709664, 1.1709282523201359, 0.41982460947286704, 7.818891434900223, 42.95062018978981, 93.11458110809328, 77.82909670183736, 46.63631846827846, 42.65175519451019, 41.12214457604193, 45.599977277940326, 78.66089805479973, 89.33173748754686, 68.80419361975886, 34.19382679846979, 3.998233959559472, 0.6539028666673169, 0.14790851893203874, 0.24152797196180592, 0.2753990480015355, 0.1030138053841168, 0.16522544616412732, 0.17045008919892773, 0.19779405015851223, 0.09782924406951475, 0.16465382199854622, 0.3092818298647481, 0.1323705857559558, 0.16401078311666367, 0.15540165556294305, 0.11527921013053387, 0.10251917305492586, 0.12381720642048506, 0.11929475957708013, 0.22387491599206003, 0.18552289975266303, 0.24045094427081848, 0.10106254879745746, 0.16345363801285145, 0.1321826490663713, 0.07482289591984403, 0.1239639352406225, 0.15311396380345668, 0.13202650502564447, 0.13842266503601305, 0.16418229488115157, 0.1211055999080981, 0.1410486305793447, 0.12883619315201236, 0.1480512564340907, 0.1958087026592224, 0.12660522254243975, 0.16963579902245154, 0.07233720107544815, 0.17745683660670636, 0.1610409513476395, 0.22312988016393878], [0.046779596276821635, 0.02707028945517396, 0.07997747255308975, 0.049835953846453666, 0.04009402740085798, 0.043226729462584185, 0.03678086183724865, 0.03804571130463193, 0.05635435084602045, 0.04959440632392803, 0.030568905753053488, 0.018740422017271482, 0.04003657846741619, 0.03750932335312809, 0.06403769561720472, 0.08816004235057101, 0.026023439882743745, 0.06393526583128879, 0.08179760553062924, 0.012777568997755166, 0.04224661189401823, 0.05058540617145839, 0.02769861944891032, 0.027173770696765957, 0.08133405338852637, 0.02913877856166613, 0.0351903943585292, 0.012107449865359212, 0.01537801902515874, 0.02648850504849707, 0.02873127724254324, 0.09531701193942178, 0.002286635755163227, 0.07680795230572263, 0.08740823430519912, 0.04212052914344015, 0.05474536319173152, 0.04715756107602389, 0.06149500766168199, 0.03200013802627162, 0.03121322591698939, 0.040968275448728, 0.09680092424875307, 0.1344480629890196, 0.042507744454328096, 0.06900623545891817, 0.0838981266884554, 0.2294467041088689, 0.1264725054704374, 0.08195990891826731, 3.6807389317020296, 37.59054053214289, 61.08953475952149, 82.12406850630238, 82.51805490063083, 74.40420858321652, 42.270218403108665, 23.559245755595548, 34.8414767942121, 63.419344194473766, 87.75477993872859, 56.97302687552668, 19.27214418688128, 3.577029258012772, 0.1274813589970431, 0.1330797993127377, 0.18649048412278776, 0.6929298370115219, 2.265881420143189, 2.3452199370630327, 1.8404078315342627, 1.3476448794526439, 1.083017885684967, 0.27894309331332484, 0.31041640608060744, 0.17135732116237765, 0.25502564445618664, 0.273827004937395, 0.16046607896925943, 0.8527107729065804, 0.5788188956437573, 1.0171587777233895, 0.47385807780008166, 0.2227430670492111, 0.1406686356471431, 0.15274936723853313, 0.11881519619735981, 0.058936687682064316, 0.5924423291317878, 1.5657450859585118, 2.037110895879807, 3.3047878405740185, 0.9955488469812178, 0.36675981336062957, 0.08796917154423653, 0.6871645657285568, 1.1577463919116606, 0.9100104724207233, 0.9431351949611019, 0.7749206116122584, 0.5374451834828623, 0.11236093607881378, 0.12606866222115296, 0.1785056262968048, 0.034477748727846536, 0.09416887596730264, 0.044544879497299274, 0.1083997558922537, 0.5573312938213348, 0.13638628075920767, 0.21143202399534566, 0.3803907238668011, 0.3942500205049592, 0.26126739178453723, 0.6758037269596131, 0.5869043714577152, 0.17713393054662213, 0.20874547621896192, 0.3854686917076188, 0.7034539239060494, 11.007090499324184, 29.528924495943134, 59.67553207951208, 59.80003203115156, 37.49840405679519, 26.593785478222756, 46.9531322294666, 76.53732684350784, 70.82146859938099, 73.84675348958662, 58.241074239054036, 24.544462773107714, 2.6931415257915376, 0.311448632949783, 0.1882633954406746, 0.04826682191642542, 0.045801183253887205, 0.17585893041424214, 0.16020321888068031, 0.04229945280859548, 0.06307661533355713, 0.050915578575504404, 0.03494076843884203, 0.032497959196447365, 0.0750077682577314, 0.02144426231332604, 0.07438380496516343, 0.09193651873858706, 0.03428142337549118, 0.0639245482612281, 0.08340208475748379, 0.031280769974053386, 0.010797853202318713, 0.016443832146544612, 0.036023281319367315, 0.06055112222149488, 0.03199032443996159, 0.11269116593945412, 0.027349754499511856, 0.004606400503807011, 0.026336766013334838, 0.07561397363221453, 0.03278331162648336, 0.03323362576925466, 0.029974814143873034, 0.030664475221607475, 0.07704560810159292, 0.015310733522769186, 0.02159727305444258, 0.07450783460010445, 0.045954400838743296, 0.034299943551060655, 0.04934220251837566, 0.05555509514505825, 0.029854752844379797, 0.04170135647479085, 0.06133024130136736, 0.05061277466255331, 0.0570740636378046, 0.09061601298350482, 0.02935535161786022, 0.04274528150657012, 0.03345540439289424, 0.061598816405861616, 0.024222980043099775, 0.03433843946925575, 0.04272208436422291, 0.008828616532076512, 0.04595183827463658, 0.00589211676983283, 0.07788179307094506, 0.04586017585449642, 0.07320773742732502, 0.049344887656550256, 0.04391145501886645, 0.030166705762366616, 0.019229107588950186, 0.01865770941930673, 0.06519909257129317, 0.027740551271445812, 0.06826581914098033, 0.0022359207345758595, 0.05674753398183854, 0.0032770071711931983, 0.036767114389447436, 0.0179539657303042, 0.03427628292551926, 0.06044986455010311, 0.030658135844034054, 0.04605325299405283, 0.03091525218840088, 0.05967469465348029, 0.01615602057427168, 0.044266352910668626, 0.03201355414104558, 0.03579404482978486, 0.018959297167678035, 0.04546275625245706, 0.06183214763539934, 0.15719014910920975, 0.0581537151799327, 0.09996728821387214, 0.11236109695727788, 0.04221196939808227, 0.18381691387584134, 0.21371386284309052, 7.189239724989861, 48.22811826582878, 77.53234586408063, 92.18870562891807, 71.24022868371779, 46.16884646877166, 32.08790233058314, 37.4030198589448, 62.50139974778699, 93.29174672403644, 108.51426924428633, 50.20806012615081, 13.968903595401397, 0.7800521136772248, 0.18006486037085134, 0.25481000602726017, 0.2515969566640354, 0.293943707741076, 0.792811522560735, 1.1585486391859672, 0.3891355868789458, 1.0796660977986552, 1.5107937830109752, 0.25254175757929204, 0.17466182610200298, 0.8464382901307076, 0.4412516597057543, 0.25511400503737314, 0.09344057149944768, 0.49518921382484904, 0.11916711400713652, 1.2146199013917678, 0.4798137985410229, 0.130210600853447, 0.08426461549055192, 0.29588267627742987, 0.05605024075315845, 0.03972240964010839, 0.5711590582805296, 4.4184509592671555, 7.525022068331319, 6.430141954652726, 2.639623236271643, 0.9603134602788956, 0.11194684257310246, 1.0240087682201018, 3.1300572810634493, 2.5486342993474778, 2.8966765009587814, 2.3047496570694834, 1.1711915414179526, 0.33725068874416814, 0.31925185132891903, 0.15019032713626662, 0.07443406033299624, 0.2484101841166135, 0.06419918312120342, 0.1583443678194477, 0.7138612590009167, 0.2270208407313593, 0.3636026730941188, 0.2049420335360112, 0.38422995817757427, 0.22803272030526595, 0.24622257408355516, 0.5132260798446594, 0.3954839430028393, 0.2508029678175526, 0.15310763591720214, 1.0074687460737846, 1.7485695788937232, 19.433071190311065, 57.583610473140595, 86.22584789030014, 71.49564558459868, 39.314845838854396, 30.88757076571065, 46.662021760017645, 55.813915498795055, 76.56122192259758, 74.47449745670443, 32.968015516957934, 5.23162252479984, 0.19102917203018743, 0.3118847208398004, 0.12348817931788585, 0.07220669033666773, 0.11202330580882489, 0.10108836596050572, 0.021773816101373206, 0.08545988119177281, 0.07621278625822837, 0.033435060928064975, 0.0832004733984509, 0.044064373829432076, 0.05090849226220481, 0.04622836154134524, 0.058100004755561395, 0.041741116438061006, 0.045491687562917514, 0.017971922831249335, 0.005866250768679405, 0.08374882381289236, 0.030559561395597075, 0.05893834626242038, 0.02924120834758205, 0.037747519240984996, 0.05555781858762907, 0.011611617650956878, 0.014727468651178625, 0.018630113017054337, 0.034575118503022584, 0.0623836619929681, 0.033780723629939946, 0.05496081009867692, 0.10218197945505382, 0.04286639617695924, 0.07524898636244959, 0.034217857229974, 0.10037221930800908, 0.043968654973732854, 0.06400715552210327, 0.019163584088786476, 0.041718470879019275, 0.03765565763798453, 0.04095708673459388, 0.12752347851112006, 0.215250788436782, 0.1818123375696521, 0.1834631344724086, 0.14221516798340506, 0.14511459627218787, 0.125900904287494, 0.08872203679094393, 0.17799464565130974, 0.1307720360496352, 0.08334506483327958, 0.11295123746798885, 0.10114479599700821, 0.15889346900005497, 0.09496078105463136, 0.14509829392115917, 0.16121462348007387, 0.20424127758991337, 0.14099275212614767, 0.12456690772406517, 0.12747851681084404, 0.15572425518785754, 0.08525178106802125, 0.12860282744851806, 0.13493699562405387, 0.17292875135617872, 0.15145489315111793, 0.1172618916438472, 0.06165660241799009, 0.09576957071981124, 0.10873314203514207, 0.17666471701475883, 0.26412186603392324, 0.1353312397916471, 0.19516652179581506, 0.11109865300597684, 0.12784030183308548, 0.1826879147800707, 0.21894088075045617, 0.0716498286853875, 0.07806846571545448, 0.23127924771078173, 0.20649812664956818, 0.27373112137279204, 0.14902319218362534, 0.24550205306901088, 0.16412387301604595, 0.3887634520088473, 0.3446724259805295, 0.21829528313490654, 8.53594139699013, 57.251985842181796, 88.34616353434902, 106.32040915950653, 102.10428484024541, 93.7853926997031, 60.28622550349082, 40.474800525173066, 47.62952143146146, 85.2711586798391, 110.70836467127647, 81.64532753729051, 28.457962505279053, 6.213413351966489, 0.3924206331852944, 0.46778866961117715, 0.5303437322858842, 3.8027594550963375, 6.941059106780637, 10.717042992191931, 10.23119664961292, 3.4096899147956603, 6.943666502352684, 0.2644831837425309, 1.0560378624546913, 1.0194208208591709, 0.6082226372053546, 0.6637306715692244, 1.595439634496166, 0.553068045166231, 0.838438677451303, 1.7001714533375156, 0.3888408881762336, 0.41422652921849684, 0.15471001606314413, 0.42313689786580305, 0.18490979958686138, 0.2284926028862115, 3.88547194580878, 9.083002209663391, 14.912396400205552, 12.072644522113185, 7.975521481806233, 1.4821025032189585, 0.1494317315518856, 0.6612001299377411, 1.4303539380911858, 0.7944173041370608, 1.019289544032466, 0.6230812495754612, 0.3435240601820331, 0.13395857877067982, 0.25051334061689917, 0.2634643480902718, 0.12074549261841083, 0.34554025038115443, 0.2832521233827837, 0.2878243506195084, 1.1637443087754713, 0.4131156404412562, 1.0089051915753273, 0.7512350116045244, 1.4722104082184455, 0.22951393598510375, 0.654803540918135, 1.2768056483999377, 1.3816564866612036, 1.01186229096305, 0.31847586554865687, 1.458172490519862, 17.63555092196311, 46.7770609548015, 83.1490073665496, 82.0690062738234, 51.930482695179606, 37.64393183492845, 60.46172803448093, 89.76387285417127, 82.15482773319368, 92.51510958517753, 82.03008067223334, 41.33496453685146, 7.168972348013233, 0.4627195271032472, 0.35259760555721104, 0.2478944537259879, 0.13433091282363863, 0.2657108243194319, 0.2715519995939347, 0.14675934108034258, 0.1815518983189137, 0.14390341126390044, 0.1572439591250112, 0.21197142650283154, 0.1572423656621287, 0.23627772626857604, 0.13263690856195268, 0.2742132664688172, 0.13820854346117667, 0.15364317734154964, 0.1586073351603362, 0.116501365517897, 0.19531217043197927, 0.08163463564649706, 0.12440266613397868, 0.10429023044003595, 0.11933288011219233, 0.2803855143006771, 0.11340979471682541, 0.082354168407619, 0.11085412540142575, 0.10470820801152338, 0.11910430245822477, 0.07104622034896767, 0.1297038949785694, 0.2009578860334812, 0.1279560117531688, 0.08875845661086422, 0.07439552611040492, 0.18603394168519205, 0.11686198608649355, 0.1608616408080824, 0.20097218123414826, 0.219603868561887, 0.13236028953425347, 0.11409590306181101], [0.03878358038022153, 0.045400408186739495, 0.06502961860068383, 0.04958596020456284, 0.004958188557441557, 0.06146122701466084, 0.034764748246919726, 0.031906185003237865, 0.07188302584953847, 0.034391108014050036, 0.04071967608685936, 0.024269228771088586, 0.03056389170758907, 0.10892053480230032, 0.03260127381391583, 0.09290070933920723, 0.0357107749028552, 0.03704303244669591, 0.024622360830225294, 0.030800277712724866, 0.053894718312808586, 0.06188609554702717, 0.09119309935598605, 0.01817294813302015, 0.027965758138546543, 0.03677240039612498, 0.03809752949183026, 0.05122256149808246, 0.011850421621103682, 0.06604394965594815, 0.06444939126771304, 0.04278771511669602, 0.017864693504487796, 0.030939274790486505, 0.0452438619498524, 0.05128112508945408, 0.00887968778354867, 0.07792026600650243, 0.08144426279731336, 0.04513658282737579, 0.02765205087921312, 0.01401129614321455, 0.055403405905611096, 0.04620809851574802, 0.06303474096761597, 0.14707282425895815, 0.07263929252662966, 0.12321215017788834, 0.17315307722216652, 0.056183896282868045, 0.37723290944291704, 0.1239626635346682, 5.617798989818943, 42.48976915113388, 79.58831894782283, 80.47389599584764, 78.10166220511161, 65.1699136918591, 45.46181571099066, 42.563580313036525, 41.45204728649509, 60.991032277384114, 90.98334558548467, 64.31924573836788, 28.689927554899647, 4.955552874072906, 0.4986205829247352, 0.3831856271191951, 0.35599422490885185, 0.21102737635374072, 0.38421812978002334, 0.45657715670043425, 0.8913922682404519, 0.2597935305487725, 0.17063117706246916, 0.7689549930153355, 0.6428772679740383, 0.22101936921958001, 0.40411668138638623, 1.3498406713047337, 0.5725817141994354, 0.9011655889691845, 0.3200193488549802, 0.16249092596192516, 0.5617302319695873, 0.2512447400799682, 0.32322469137368665, 0.9794144837125656, 0.8803158013090011, 2.977303271332095, 2.393605560064316, 2.869846508387597, 1.863127547887064, 0.6472318343097164, 1.1296158884802172, 0.8599819279005452, 0.9210931906296361, 0.7321606480306195, 0.6094120346730756, 0.540482139875812, 0.4051790308327444, 0.3400667973103062, 0.058776904723697135, 0.13416415080428123, 0.20753899499052958, 0.8496331219230929, 0.3100758953200233, 0.19809653231453514, 0.5737284558915323, 0.8443922225025393, 0.40676428125269953, 1.0227172665538327, 0.39809973489853645, 0.47682722008997397, 0.9171024241274404, 0.41258559952820506, 0.6544821517121407, 5.833666632252355, 18.57769443142799, 42.367151937177105, 65.98810442032354, 52.3908708941552, 31.28116688420696, 37.5367844489313, 43.80145680519843, 64.36377248456402, 69.22669564524006, 60.442422128492794, 59.51699379951724, 30.634799503511, 5.5906297122278525, 0.11132641094586543, 0.4327913523922044, 0.05365547288449542, 0.05904724949129647, 0.0897538806161573, 0.03945235598592028, 0.12001732604638224, 0.026518116261990323, 0.03949678908552855, 0.12938040669166273, 0.06575426882913997, 0.026281582784929106, 0.05046497331932188, 0.08197926029923462, 0.01066071484538336, 0.09289537736725423, 0.022951400493301695, 0.020178483964334575, 0.042288447955563184, 0.020695869104876634, 0.02536061486499685, 0.03925503088882373, 0.028372546995899854, 0.028148552462939295, 0.026248621851986936, 0.0050780454072200006, 0.029367517094097795, 0.04252583562065998, 0.05457181363336502, 0.05489761550580302, 0.048147430943865935, 0.02632338437251747, 0.021008909867715933, 0.047094569496449926, 0.034964379268668355, 0.023889676254663258, 0.03919956229266621, 0.0472316571000603, 0.019157487944129015, 0.03767392500453899, 0.04605950810195458, 0.015167779600878638, 0.0722795452982668, 0.08940193982374284, 0.07168342930174644, 0.033415269046541185, 0.023239600855196198, 0.09368534425213453, 0.03430515294894576, 0.07964098375410804, 0.05831580406295196, 0.015438622325628757, 0.02976497883097299, 0.10282465827561195, 0.07366311541127582, 0.027282007429147923, 0.04305068245758453, 0.04498284430273118, 0.014285700219202668, 0.024924222455029527, 0.03552746921477299, 0.052946619389037934, 0.012387247200334265, 0.011700717506990319, 0.015603460506686281, 0.08190483485739078, 0.07344661130299492, 0.060311191144489476, 0.03940128856488774, 0.0203741236679977, 0.04183728345519593, 0.06248712982802142, 0.06258553382189525, 0.03677492465583548, 0.055077033297669505, 0.05270967222449761, 0.09945616201167146, 0.04988220257444247, 0.036345601322189454, 0.041862227278010505, 0.028521711975636504, 0.044142269649572914, 0.02932021882565272, 0.13702810922216985, 0.020914577631159656, 0.04901573414944353, 0.04096142662268493, 0.029895052899636572, 0.02752738922173458, 0.05912599566903326, 0.11137126539383205, 0.16790134531836357, 0.03906365446445923, 0.07031274478762381, 0.11039345374991817, 0.36783926188945776, 0.37385102962293937, 9.367803546690173, 52.4932800569842, 93.73113063073929, 93.83681497266217, 72.42351362782141, 39.841404422636955, 25.70974207693531, 42.60247453566521, 64.14307640444848, 102.75840282440187, 101.68419115005001, 71.24994047226446, 22.06144948159495, 4.6681103110313416, 0.780404391548326, 0.44757737027060607, 0.2153432092839672, 0.18850134234995614, 0.2647739600750708, 0.6732948809381455, 0.40816573185786126, 0.27155393013550394, 0.40950825497988735, 0.18129925784324447, 0.1552286729096405, 0.4125109825643801, 1.0605336341165728, 1.1124808918083868, 0.313454526927202, 1.668029468386404, 0.4757361883117307, 0.08492023353615115, 1.3865058845089329, 0.41103623266662326, 0.2851659029481873, 1.3451424072827063, 1.1893045565774365, 1.8190182889661484, 3.6547610740507808, 2.9981984726844297, 3.5929077479147145, 2.2054722616749425, 2.539776852053981, 2.1487476796873155, 0.6921175386636489, 0.3535443676575538, 1.326536889518461, 0.9037476117091795, 0.2077323402608595, 0.28043745506194334, 0.0911555074215416, 0.16519730009378927, 0.474990600900304, 1.450804808447438, 0.547674234595991, 0.14366138876686174, 0.3857564036884616, 0.6918101841884275, 0.2627854716152914, 0.6413004751647673, 0.25692325956638784, 0.5908931767748249, 0.6051842712106243, 0.10713284564835411, 1.3617944621270703, 0.9404226921258435, 5.021884566353214, 23.13300375015505, 60.01711168596822, 69.52149314265098, 56.89561105543568, 46.24905501642535, 31.641809209700558, 39.26789899026194, 63.33668808783255, 73.78440349332749, 77.50442643319407, 43.00852614064371, 9.042196812168244, 0.36543095724717267, 0.4123824023671689, 0.0387438778735457, 0.06143416495873563, 0.1169642051982303, 0.03389496266120865, 0.16777452712337818, 0.08823893408501342, 0.09350649336533201, 0.04930542263713095, 0.10513239855607671, 0.05199918696176141, 0.0247843501218144, 0.06949342141348509, 0.0845298657734548, 0.02973480071241577, 0.007659432294237758, 0.028848069261819608, 0.03301912115045613, 0.037845574664853276, 0.05285496462977702, 0.03062594482945579, 0.03196675766019091, 0.04294388597050021, 0.0837862165644765, 0.03826816791608449, 0.026092935548794848, 0.007637457062129773, 0.04658692133342547, 0.0202637514655268, 0.0688480842678297, 0.0660651856132092, 0.03505335272019429, 0.05057679151274985, 0.029473036129568374, 0.05512013340428953, 0.018239157281876094, 0.0020189648738221056, 0.045837595412928256, 0.046116696565502116, 0.06622950381208813, 0.015551874061085045, 0.04096876957543916, 0.049975017956908674, 0.04348832933652786, 0.1185697339655411, 0.16027345382157834, 0.1202677372061918, 0.10354596069983898, 0.17559921128615258, 0.20741750876749718, 0.13288119867924722, 0.20035229352933748, 0.24747382549028246, 0.15415823357480188, 0.1412670269247986, 0.1701875815107938, 0.10318214554459819, 0.19239247145672, 0.1648399353988709, 0.14236320681389303, 0.1547081468086089, 0.09018927136616361, 0.13876285403966904, 0.099830097188392, 0.13208776141606993, 0.19114007091810628, 0.19671835546051303, 0.21220998628245247, 0.16689841365141256, 0.10320222470909358, 0.20795848941610706, 0.16791671304212463, 0.14076314025348233, 0.13939104613757905, 0.1506849135001821, 0.22396808760541104, 0.08830835697271171, 0.13623065765826933, 0.14103867143632906, 0.13672060152936366, 0.08531404869450677, 0.12116002279423899, 0.25689180399621686, 0.1748732663691044, 0.15495904060381074, 0.16076926592617266, 0.20296587909181274, 0.18230286366756887, 0.27332858813385813, 0.221709844265734, 0.21613477729260924, 0.209546068743352, 0.3157740879443384, 0.14005434038417955, 0.45647342839548666, 0.5445510473462843, 11.742640810628092, 63.29641319090321, 101.9981376586422, 109.18828148995678, 93.84928810981013, 84.05028174000402, 65.92583287146785, 58.81218310325377, 53.4846277390757, 79.92921213949882, 116.57967429007255, 86.52858426493984, 42.03273850102579, 10.027804105512558, 2.0003993496779473, 0.4704567087033103, 0.5810980991490426, 0.8234314440238861, 1.3559940120866223, 2.0852217078208923, 2.426583867880606, 2.1380300483395978, 3.232014145581953, 0.7156040170981038, 1.9211332740322238, 0.5185928015458969, 0.9986548125743867, 2.601642680744971, 0.8024617176382773, 3.0652670802608615, 0.6549176573753357, 0.4394629363331103, 1.0989711457683196, 0.4920639428159883, 0.7343685747154298, 2.000960984056996, 6.394434167492775, 10.78227004697246, 4.41885055072846, 7.873381001334037, 7.633733499434687, 5.474752110819663, 3.109479056250665, 2.660448080109012, 1.5099423835354469, 1.0821450357475588, 1.1000337403628135, 0.6208733228906509, 0.43553685829524075, 0.7889063740449568, 0.22408770457390817, 0.3338351623425561, 0.40659356621965287, 2.177521206678883, 0.8093291749396633, 0.29063809963483966, 1.0706776188265894, 1.5489537869730305, 1.2084829855349757, 2.444533614381667, 0.34204171069206735, 0.480984871185595, 0.7609322138371006, 0.44299662413616336, 2.266611961587783, 10.120339682025294, 27.64908544478878, 64.11919309246925, 91.22432031939107, 71.8443521376579, 42.964501457829634, 50.31525850296021, 58.902715329200994, 81.34994168435374, 83.63335732490786, 80.7823904099003, 83.64340643728934, 51.73057517697735, 11.98285166294344, 0.3492488820225962, 0.7512488011871615, 0.33323792019678705, 0.13789542800476476, 0.18776007567442235, 0.18177266953693283, 0.19741282948563177, 0.2111588830068227, 0.16356200881062016, 0.3467038766511025, 0.37800776141305126, 0.20696663538054114, 0.11870914664600166, 0.20657850459458368, 0.2552884585794903, 0.13772079060154577, 0.2151936229558722, 0.14319220587851542, 0.2478704751739579, 0.2089605477428244, 0.11364734326038631, 0.17494665759225048, 0.08757450602828495, 0.07985728101864939, 0.1815687062879724, 0.13792337489224252, 0.10843789941000362, 0.11046889042782207, 0.11864748422897632, 0.2398471137689006, 0.12744814908552554, 0.162010359007024, 0.09987351139106097, 0.15983338227435467, 0.18216640808649603, 0.11153685529866528, 0.10829365271474085, 0.138586163520813, 0.09399487441706081, 0.17342401187746756, 0.14850487241581564, 0.16170323435817996, 0.19622687941357014, 0.13765164350550022, 0.12199260715034702], [0.022130592823809674, 0.0827677716170588, 0.027491369682754722, 0.03234800897658833, 0.07502222433686256, 0.13397144904780772, 0.03533197123737585, 0.05910441497220628, 0.048416431227158156, 0.07480519162791391, 0.028441556196119037, 0.04487820052271409, 0.013415465514445979, 0.037777695444322405, 0.003936726660017044, 0.06219123602814733, 0.10780074408337956, 0.0952782861948494, 0.11835721351446644, 0.05250427639111877, 0.054008202747471874, 0.012871623527438892, 0.09366425385157909, 0.007926557577335307, 0.027951041589521115, 0.05360569632161529, 0.05555741639146882, 0.035636506509035826, 0.018239664815125928, 0.057737143379786325, 0.08738461581449355, 0.06761675880801293, 0.067678980469223, 0.07997915794652316, 0.03573461938949843, 0.09127153143767389, 0.07102215752726601, 0.01390649148473336, 0.06096949815870293, 0.029853440918809468, 0.056269062277410305, 0.04838155507440529, 0.030119918857611, 0.009224528856124849, 0.05723785323601577, 0.08967164107748578, 0.08289932423541624, 0.16128053768507897, 0.1380708161741495, 0.01918479131775037, 0.049894597877057335, 0.06396700868443136, 0.27664311350353304, 0.37595682146568454, 12.103418457892634, 41.5098237991333, 71.62258132811516, 74.11015633613833, 70.02468616731706, 62.99069973730273, 59.556719564622455, 17.028077763895837, 35.18595110985541, 48.45908311105544, 77.41597698580834, 78.66202769740936, 53.2861283517653, 35.04453397566272, 18.123385906219482, 8.596708716884736, 3.5996740816100954, 0.7120033425669516, 0.24370795175913842, 0.036550150628411965, 0.038703175622128674, 0.31998086059766434, 0.14293521402343629, 0.012280657556989502, 0.08198367296567849, 0.05916103270025023, 0.7801209390163423, 1.3824473345471968, 0.5922770380012451, 0.8641694870687301, 0.8749268324144426, 0.8196426182985307, 0.28107814971477757, 1.606949216896488, 0.871510815716559, 0.6613483832728478, 2.7248936026327075, 1.226740392946428, 0.8055078057992844, 1.0979965593545669, 1.0445474016089593, 1.971597262928563, 0.9657221023113498, 0.5058829432293293, 1.5956668868180246, 1.3617814692758745, 0.2092651749450353, 0.39331269660784357, 0.1930500200438884, 0.1674794760202208, 0.7713189564885632, 0.9060950889702767, 0.25668264667112983, 0.7080681634045417, 0.36958581978274935, 0.20699334120558155, 0.20071348866387723, 0.5905803677535827, 1.809710994843514, 4.908432950896602, 13.642887953789005, 22.072308563417007, 35.40827105122228, 55.337943723124845, 71.37930024054744, 54.44035637763239, 33.948364873086255, 29.14604429275759, 49.609349543048495, 70.44686655844413, 65.84439662195021, 60.52605882767708, 58.63621381021316, 51.32511977226504, 11.328535599093284, 0.24876382562421986, 0.24813701248457357, 0.03464142724330868, 0.17545169339545313, 0.132012638834215, 0.09687597022181559, 0.06669032868118056, 0.02428027575895671, 0.05253298553608118, 0.058429870724437706, 0.04839865798731485, 0.06303337733111074, 0.04777037778929357, 0.01693946613569654, 0.011737542395900575, 0.05012659228316719, 0.04645134292302593, 0.06827059186874859, 0.03578363752533351, 0.05139143408967122, 0.046145532114972035, 0.04242693366963537, 0.018068043883108807, 0.08940432235718736, 0.06931286981149067, 0.05908993207999776, 0.04372863196617654, 0.06025676059746935, 0.05856496649944495, 0.08492868348595597, 0.08807413325074219, 0.05333121850966446, 0.000884289904441234, 0.029091595206409696, 0.04128702165138337, 0.04346011814871623, 0.019001698219067147, 0.016973055260736617, 0.0770227863423286, 0.03167262969298228, 0.058217840569634596, 0.029815770460352786, 0.12415898888702355, 0.014974221741149743, 0.02969659207719228, 0.05555996363381705, 0.03067325267399992, 0.08761470266167196, 0.10103637923396404, 0.06285186811921097, 0.040804838250962, 0.05106955458740554, 0.026286859215507587, 0.04050425599299131, 0.0670934364860577, 0.023810571930821867, 0.05987334508268584, 0.06380636387714936, 0.02363011800503779, 0.04736445844173432, 0.16207481764497297, 0.05910399745428755, 0.10888463592216854, 0.044745774564122966, 0.06133107633720483, 0.043943190211129766, 0.044292790604935545, 0.06363710441115884, 0.05057659232988954, 0.09832438967761495, 0.0716768562673561, 0.014169282625399291, 0.044817851946478894, 0.033057965638656775, 0.10268913732180673, 0.013012266736627828, 0.009734803743119682, 0.009711070339225475, 0.022632977962794325, 0.045213865777177197, 0.06165552606445648, 0.03432079646435957, 0.17080302590564375, 0.023855368922194167, 0.07191248193022705, 0.05929591780107829, 0.03568672357247241, 0.04903041239407274, 0.041097273163857966, 0.07071441234720331, 0.04680429112106081, 0.04802431678399444, 0.06231374497855864, 0.17024503810511482, 0.07889944894780075, 0.15142682368957228, 0.062258556004493475, 0.014015509626798093, 0.07295210920875111, 0.27145694340429, 0.7474821613680932, 18.114242861347815, 51.98752180222542, 88.70840226450275, 88.58130178143902, 66.11596584320068, 61.09790509746921, 33.6329553204198, 21.1326910603431, 59.746503445409964, 73.51523476262247, 97.53125621426491, 69.15326103087395, 51.4084348370952, 24.6799571283402, 7.053099649567758, 3.012236390383013, 1.4391719165348238, 0.4345408827066422, 0.3366388296408038, 0.08746838752901362, 0.04504488210283941, 0.33708821681718676, 0.27375805702420974, 0.14578879961083013, 0.010654536346274038, 0.8209547736952383, 0.7957217986545255, 1.3400820594641472, 0.5370498821139336, 0.6755477923058695, 2.3827776120555018, 0.5815429817284308, 0.5475218137425761, 0.9434418752789498, 0.6294481756706393, 2.267968611371133, 3.5489257208762632, 3.1291870051814668, 3.9421683357607935, 4.18517779919409, 2.1196503120083965, 2.2095873182819736, 1.6809078354027964, 0.3232319845307258, 0.7421520280261195, 0.7123643231968726, 0.2718693132121717, 0.03455697754097562, 0.10566525867268925, 0.2795712241242009, 1.436391936675195, 0.5514062472408818, 0.30876652848336006, 0.16961269381065525, 0.391560776099082, 0.2946470683861164, 0.2691248798322293, 0.26266979233872506, 1.3556847577133488, 3.2126180250798506, 4.006586891989555, 2.038298270875408, 17.300329477556293, 43.34882705442367, 66.6753036745133, 82.31958296991165, 64.69622473562917, 40.701309557883974, 31.04403215069925, 51.10611815606394, 57.727518312392704, 70.3920082892141, 70.77996207821754, 59.72818597670525, 17.30146892609135, 0.9182378890052919, 0.2400254590376731, 0.045768057612041314, 0.2749725208888131, 0.020019963135822647, 0.12985481429965268, 0.1861248150347702, 0.02696859511366535, 0.12071130977522944, 0.04320241383186752, 0.12966690825358515, 0.1637088219004293, 0.029823779909601136, 0.03229107715249543, 0.11876017576263798, 0.030179438143668157, 0.058130943216383464, 0.08801342078274296, 0.019656107760965824, 0.04752835529225488, 0.02685336591375451, 0.034886632835672754, 0.022384623749061458, 0.021661279700516213, 0.10074435417810756, 0.046814261755395326, 0.05884498695752794, 0.039463985200610854, 0.03188832174806345, 0.02322745261593692, 0.05034347177453099, 0.03975771863253848, 0.061489419050274365, 0.0095483350695201, 0.024272476983887535, 0.051195599033587405, 0.010790042935930675, 0.016834021793798577, 0.03357911610134667, 0.021333687097555207, 0.032325685174474796, 0.03486824672549002, 0.01570468370412146, 0.04073317838652481, 0.052029650448070425, 0.05958076078264464, 0.058677914672561234, 0.15076043444775766, 0.19699995405972007, 0.16979024234798648, 0.1797055651343638, 0.19589913167780448, 0.20471723269551031, 0.1459648312940713, 0.13277978395983098, 0.23323635720918257, 0.2020238667366005, 0.15955126273535913, 0.20495144109572136, 0.09981342711515966, 0.28128039692678763, 0.18818674068297112, 0.29705800837086094, 0.21495880168532172, 0.23388607637776485, 0.1820176031680838, 0.20036292682972648, 0.16289456236747005, 0.11667848504599064, 0.21140254493201935, 0.10382111649960281, 0.10258193863856216, 0.15563728888669323, 0.13869283360338983, 0.1790564128708455, 0.12383091939432968, 0.16392478208628394, 0.2717140425116785, 0.15391585867731802, 0.25741844347888426, 0.1896531708658703, 0.1270224187042444, 0.2404745704224033, 0.13874347201518475, 0.16794766299426558, 0.17041032923565758, 0.15431039395832247, 0.11839984630745266, 0.16296418443802865, 0.3015820333553899, 0.09066949358149883, 0.1438142233077557, 0.2761130419469649, 0.3601878208498801, 0.33089859411120415, 0.22262095263408077, 0.19183025485084904, 0.3521813746661909, 0.16625076292022584, 0.4113364165588733, 0.4519146230191954, 19.971090939737138, 62.51100563233899, 103.75214315229847, 100.07780798019903, 86.27750550546955, 85.28691091845113, 82.7566134545111, 27.84587467870405, 50.97915103358608, 64.01778413403419, 100.66775598833638, 102.22105380027526, 74.25008296966553, 48.40389144036078, 27.76306167725594, 15.371791258935007, 6.166541518703585, 1.791227438276814, 0.48981397322589354, 0.22307415492832663, 0.22424953298703318, 0.8228810251720491, 0.9230933542693815, 0.47685896677355616, 0.15746762615538415, 1.087169469364228, 2.2484538391713174, 2.038840906273934, 2.9575207973680193, 1.5514484144026235, 4.1785318332333725, 3.5648855999592817, 0.8511711200398784, 3.6468459761911824, 6.412191227559121, 7.6881524632054, 10.899257679139415, 7.758101561377126, 8.97898095269357, 11.90728916275886, 17.145295835310414, 11.941460851700077, 3.2017582078133864, 1.8915430360263394, 2.207797001446447, 1.8773769058527487, 0.3115382958804408, 0.42697187272771714, 0.11260518789171212, 1.2397811706027677, 2.721074930121822, 3.4977375643868602, 1.7269650414105386, 1.3295337029041783, 0.4319722511835637, 0.2133657984555729, 0.33649005536590854, 0.4205630569448395, 1.6133317711853212, 5.785514635424461, 17.70122512694328, 36.6779108970396, 56.56451986682031, 77.94547342484998, 101.12456306334465, 74.38998606897171, 49.71245688776816, 41.11961464728079, 64.48609159838769, 89.82677198225453, 78.10711429965112, 76.51558122327252, 80.66917511724657, 69.81064242701378, 19.73670186535005, 1.1548323160217655, 0.47916173514339233, 0.16880915950863593, 0.40475087961362255, 0.22822116261288045, 0.26670882238015053, 0.49782624167780726, 0.13334336420220713, 0.2136103796862787, 0.3083390207780946, 0.18934736388825602, 0.24345773212130994, 0.23812513197621993, 0.10141766885475767, 0.28833762952877634, 0.15127947433821617, 0.20199291678445958, 0.26606769871807867, 0.18324483005750566, 0.20052573583539457, 0.145273084541963, 0.06942193774927048, 0.09957143526163795, 0.12564710701905912, 0.28152502412276886, 0.14756793156266212, 0.1070249421642192, 0.2527250211325384, 0.18435902833457918, 0.1307143036636614, 0.18127535590000693, 0.14607666480925777, 0.16545167192816734, 0.17138201983705645, 0.1623270291114046, 0.1220443640505114, 0.09177328838456063, 0.13328750107076862, 0.12855586625875967, 0.07347501018234799, 0.11442115335094352, 0.17962561619858589, 0.2048660069704056, 0.16744939940831355, 0.12810625691687869, 0.1316313415525421, 0.2144132551526831], [0.04697611698159768, 0.017428163198694106, 0.02231775576459064, 0.03062490678031839, 0.024396619616797375, 0.04525214336031387, 0.03457053729723539, 0.016562512572554332, 0.03360200297808455, 0.0413339177236682, 0.03330950677815465, 0.04421685980032048, 0.040752878337497675, 0.03091181628406048, 0.08277815976931203, 0.04612146163239114, 0.04103909644688811, 0.038054276167625384, 0.028349805675867586, 0.06436532843978175, 0.06864899333806769, 0.010203000293263506, 0.04692997933635789, 0.018385700325691895, 0.0449420960860387, 0.0382442583119677, 0.04813018630469038, 0.0235326333166731, 0.07716081240364621, 0.10052379746470722, 0.01840931307073803, 0.07176920050574888, 0.0319810566912976, 0.034600338117489894, 0.0636926151421522, 0.09528997669657392, 0.03126776946197835, 0.002331008285944981, 0.05132180818867299, 0.037388557252744516, 0.08400213844593495, 0.03999799061867018, 0.061327678737260645, 0.061765321785764354, 0.09535068150369391, 0.04905815243781094, 0.04374264371431163, 0.10309511029552068, 0.08745720264531913, 0.06134020810526225, 0.04966158840444781, 0.06367690267882521, 0.09366479011312609, 0.052169139737323414, 0.2806963314933162, 0.415801054407512, 8.630340099334717, 43.96720047919981, 82.47167679571336, 67.88857906095444, 72.0436320766326, 72.84407015769713, 46.124358946277255, 38.535686615974676, 21.32688956875955, 38.30851078033447, 38.88530315891389, 64.24459126687819, 93.67883759160196, 76.8097040730138, 64.36849501825148, 48.34001171973444, 33.7963181157266, 23.054532812487697, 12.433169176501613, 4.677913294684503, 1.593792361597861, 0.6404792289099386, 0.2969063842488874, 0.20160110877646556, 0.25264323358574226, 0.3832403564405057, 0.3293562139714918, 0.5335066335335855, 0.23179597401570892, 0.21008632926931306, 0.12994605537143447, 0.1180764499510969, 0.3624750223130949, 0.6551780659825571, 1.631862273620021, 2.4776984799292783, 3.18052176025606, 1.6027125668141151, 1.0846676100646298, 0.12038399104870136, 0.5143840983510017, 0.27313139710214834, 0.5587529691476976, 0.3966835754052286, 0.3263894925194402, 0.4314296770720713, 0.22731788366311984, 0.5049936377233075, 0.3827789263619531, 0.28937626089299884, 0.23667275184585204, 0.5314218324999656, 1.569101776807539, 6.019953720031246, 9.402920526842918, 21.39459163911881, 34.24848894919119, 44.136270323107325, 49.84128321370771, 41.16122707243889, 71.70300560612833, 64.09400363122263, 21.590312027162124, 22.477314856744584, 51.55497458673293, 66.16458754385671, 67.26292963950866, 54.4848439001268, 56.606375478929095, 38.49484297537035, 14.254952246142974, 0.972844820109106, 0.17375779638607658, 0.0042406399640434935, 0.11665829862918585, 0.03492142854919357, 0.1649743072207897, 0.08429686779216414, 0.08145075922291126, 0.04053616355503759, 0.04953924416294021, 0.07881765374012532, 0.03418920554160591, 0.06257649015394912, 0.03744528989397711, 0.05698503272968435, 0.013662768272502769, 0.015436068380011186, 0.006107069550067067, 0.028616105499226722, 0.03855192305279836, 0.03624132526437602, 0.04760884432001941, 0.021578408139307174, 0.11484073970707194, 0.1312164436545103, 0.02335579915633125, 0.01431147428980518, 0.11387743010756471, 0.0669122796746031, 0.029476920195344477, 0.014393889071089367, 0.05517351824129301, 0.04345208571683015, 0.02646755445898781, 0.1563315024419177, 0.053994030120872685, 0.05883993077722769, 0.08421365532182878, 0.02585348136152231, 0.05610705000318347, 0.09604179240282505, 0.03866333905006609, 0.07907247756637874, 0.026481759644323782, 0.10708612194585224, 0.08478783822107701, 0.08539101754825923, 0.05370101298115427, 0.009958875842482574, 0.027436038982423566, 0.015201003876544777, 0.021261100266729633, 0.0346903074833174, 0.06902517315240637, 0.09784213732928039, 0.03770791249529969, 0.024361354674422936, 0.00778688442698049, 0.026594418619248657, 0.024012937886460174, 0.0173415033326995, 0.02378856797041672, 0.03874737123448042, 0.05929040196802347, 0.04119987531955685, 0.04213865478372863, 0.015820687610445725, 0.012792324808786714, 0.06510952157118628, 0.035412023595023545, 0.04220517036775428, 0.12215512504260387, 0.02941366623065645, 0.02128750923269939, 0.09818748976554602, 0.1138678003823565, 0.05390568103100504, 0.07703201770181618, 0.04330888856202365, 0.056823131538206534, 0.06397554673434747, 0.06042605836785609, 0.010682922776698345, 0.04502944926160478, 0.10790238096829384, 0.03256152917240416, 0.07615000535283359, 0.013388895670012122, 0.025352145762993925, 0.02574558936870627, 0.03363808571931816, 0.08508731731243672, 0.008581081074812721, 0.027898821206162536, 0.053831228776083845, 0.06849458831692896, 0.10527351195172918, 0.11208276955350754, 0.08887614303779218, 0.05529270620055257, 0.039574773005780675, 0.08615262385818266, 0.07654870815214611, 0.18592653615820795, 1.3440166870432517, 14.906593253535611, 59.06103787883636, 92.09383918393044, 74.0844020535869, 74.36514177630025, 39.45029704801498, 32.03963560442771, 25.178486454871393, 37.59520815264794, 80.92837318297356, 77.10021834219657, 90.54377340501355, 94.16942411853422, 64.43120979493665, 50.16436884480138, 27.82159128496724, 14.837199661039538, 7.74772983404898, 2.496507960942484, 3.0116176364883303, 1.2984237916046575, 0.25132072068029837, 0.29551489278674126, 0.2808819086320939, 0.21136485340614475, 0.4380523846034081, 0.28899536197704656, 0.5315841205658451, 0.3864289675989459, 0.12998368561027512, 0.1379092175874018, 0.05860905485948729, 0.20705065990407623, 0.6431685652463668, 0.29121211399474456, 0.640949484321379, 0.2969548316492189, 0.33723156718957814, 0.5268829760532225, 0.3492179014269383, 0.4153502576293484, 0.24134227224896032, 0.34064105681834683, 0.23230770542736978, 0.33392467205562903, 0.22555749022191574, 0.06651159270756668, 0.4424624463483211, 0.2124591180754285, 0.41212030836651403, 0.19305815589764427, 0.2614474224467432, 0.917305161635722, 1.9852664778309486, 1.9734749750744913, 3.4330133084327947, 18.23416344581112, 25.52108587757234, 45.45841109368109, 45.71667955767724, 74.21524447779503, 74.87893304517193, 58.8563842927256, 32.16265486132714, 33.06473724303707, 37.67994311548049, 58.074169543481645, 64.30827094662574, 69.31829867824432, 53.43115798888668, 22.271341393070838, 3.5703175923516675, 0.09759797744693295, 0.11838420279203885, 0.07540418045415033, 0.02673156750989297, 0.187753533283549, 0.01785345116419898, 0.06966662623228566, 0.028177072001140446, 0.010750316489007204, 0.05276115333300926, 0.13370779222778736, 0.04060602311285273, 0.015054963577929285, 0.08825011130782866, 0.05302514340127668, 0.059599330753929196, 0.043112310400653275, 0.01592414874222971, 0.020776396437037378, 0.04340949122824016, 0.015545121953642417, 0.00581369282782919, 0.04671229928311321, 0.014797361725340448, 0.025656027944698453, 0.0152979752860002, 0.09018331886299195, 0.07356894022274403, 0.08713032058890789, 0.03247422196211354, 0.018008164535727234, 0.07386772217409265, 0.07834480129062169, 0.13516551965186674, 0.03177554019907069, 0.06739491506689979, 0.04251272785627554, 0.05534672689053321, 0.02822536426866728, 0.11380311191803026, 0.00261296431304917, 0.020633289297561974, 0.04982863387633717, 0.05594560846446022, 0.0731353727619975, 0.09074412586708223, 0.06102631506960719, 0.08692745284567918, 0.1806519901560199, 0.09332439426573054, 0.0882164723870735, 0.22961314437129807, 0.11013006506067131, 0.2354602951316103, 0.09080972597603837, 0.11883652408517177, 0.1606374375161625, 0.1511531770830193, 0.17020199928552876, 0.18084712807209263, 0.10435517937425645, 0.14285816090001216, 0.2189770707439992, 0.18927412588269482, 0.13411984027874085, 0.13908333926191255, 0.09803255614373954, 0.1983621043543662, 0.21636576812353828, 0.12277764042899494, 0.2337333184456633, 0.14930725758594854, 0.10641389511405461, 0.22887463561229168, 0.24687952512214262, 0.259725992237368, 0.15662865262598763, 0.15904798893438232, 0.13292291982760354, 0.17396536024828113, 0.09140670765191318, 0.13918599504376614, 0.1714973773566946, 0.2730808659426628, 0.27650120337643935, 0.19059712908441023, 0.17461773008108142, 0.11548848236880957, 0.166863878407786, 0.22138932839997355, 0.1604122229881825, 0.16941073771205642, 0.1809081699578993, 0.13665770571078026, 0.2103888880341284, 0.3301068575632188, 0.30129790666603273, 0.19757513287326983, 0.17782017678743411, 0.14413824785620938, 0.1901840391538797, 0.178363271838715, 0.29896572051990417, 1.2538661567434188, 18.95686407243052, 78.48264986468901, 108.86157943356423, 86.52019823751142, 91.5745016836351, 94.64681579220681, 71.29176078304168, 61.286727997564505, 32.6809411664163, 56.41505795140421, 56.27071865143315, 90.52729945028983, 120.46062423336892, 105.86059754894626, 100.84905578244118, 82.83682592453496, 68.07667240019768, 54.9942970275879, 39.79749741092805, 22.94364348534615, 11.667470547460741, 3.6410644025571886, 0.7052498178616647, 0.37604538122973136, 0.8690319390546891, 1.0060750789219335, 1.0278336307214153, 0.9783851679775023, 0.440578023272176, 0.2662518968985927, 0.6724367398888834, 0.3376602393484885, 2.7566849031756004, 3.5626307274064715, 4.472431598171111, 7.299320063283367, 11.149923609149072, 8.195865529198802, 4.848037765872094, 2.8813339048816315, 3.5974564715739223, 0.2764024393212411, 0.8450553482097964, 0.9061713300405011, 1.282879438611769, 0.982741205201995, 1.8530687521542273, 1.780494117448407, 1.8491842573688877, 0.9154941910697568, 0.2974858837983301, 0.7651036545153588, 2.2640795813452814, 9.609118546209029, 16.530342717324537, 32.47742899002568, 59.12074419759936, 66.92400547765916, 81.88404298597767, 61.802084292134936, 91.07461129465412, 75.85528158372449, 31.887010297467633, 32.675267457962036, 66.94538239509829, 85.54149627685548, 81.08671142208962, 70.32437878270304, 80.79767980883199, 69.36907768249512, 24.375387045644946, 2.543771295778213, 0.21428781591596144, 0.18381319068852933, 0.38395174568699253, 0.13507501402449223, 0.22245437447582522, 0.1540443163004614, 0.23290804256835293, 0.14398420289639505, 0.11375244286271835, 0.1421935336604234, 0.24235183823733564, 0.137562976489144, 0.12075108506025807, 0.18803081114686307, 0.1354012908714433, 0.1303938490849349, 0.17576575880089115, 0.15644613983890704, 0.15267982177676695, 0.22665388461562896, 0.13416651035508803, 0.09789217053161514, 0.13008867029941854, 0.1482341522651334, 0.1740478066306922, 0.09929297762292047, 0.2881342791501553, 0.2810912038530073, 0.21706657003491156, 0.10633376231717487, 0.13769172522569859, 0.28688727187052854, 0.12973171929197927, 0.4708365350961686, 0.0825520565793399, 0.20453154830442322, 0.2703604877235428, 0.17992422194971194, 0.1139354536069497, 0.21331218762263177, 0.10995963348015664, 0.1721049004024075, 0.15919421979736897, 0.19884143024683001, 0.17705591215241342, 0.1706314375323634, 0.19868536281489557, 0.17816240358496868], [0.08664886497201459, 0.0280679619285248, 0.05140922648171264, 0.034975908891928774, 0.034182410341717546, 0.05804813294220836, 0.04531112830004385, 0.03205258057512824, 0.08966343627581674, 0.0369908771808109, 0.03921743895437929, 0.07472430040398914, 0.018415616059135047, 0.05498029937547061, 0.08470027437133175, 0.09051294351417212, 0.027422626698089224, 0.07068646545972555, 0.012660264657179435, 0.06639520096923075, 0.047022936445090084, 0.07427304397307097, 0.05861218815909759, 0.03026630293818251, 0.05237378480453646, 0.10187787319263143, 0.04021727945655584, 0.02118964341559237, 0.06464210834594504, 0.0823397046676086, 0.04289669112392491, 0.11097800947966115, 0.0484387397075132, 0.08916249138212974, 0.10944170441718833, 0.027241722695649635, 0.03953736493243806, 0.07655217086956387, 0.07837586615595125, 0.020928980084136132, 0.030017399056363973, 0.07325951731012714, 0.017902327573768074, 0.038872201431302295, 0.020351164012907014, 0.1156541258997975, 0.02227014914575604, 0.13752458016237906, 0.10499311611056329, 0.03670989145194331, 0.027767358603136196, 0.050009166326133475, 0.07315396571591978, 0.010982567534571695, 0.15227336616766068, 0.11649291556809219, 0.34227815606901724, 0.7938535247118244, 23.15720085174807, 75.09987231223815, 72.83719032041489, 68.32449559242495, 64.91158639231037, 55.96872360475602, 45.77744491638676, 27.75766645708392, 37.73412673704086, 29.786139803548014, 23.880109363986602, 51.171876692002826, 53.32977648704283, 50.21963896289949, 56.26035967180806, 49.36700590195195, 43.30104081861435, 32.811964019652336, 20.14798983450859, 9.25576594568068, 8.736290181836775, 6.5096067228624905, 5.185622438307732, 7.762726526106558, 6.731663865427818, 6.095892767752371, 3.8829045093828634, 1.452279497058161, 0.26546383757264386, 0.02390510718067808, 0.10885474317136312, 0.08362112461679405, 0.07095851094251679, 0.321683751479272, 0.6147562027458222, 0.31162005278371996, 0.16056396968422398, 0.09902455573601109, 0.17059973681405668, 0.1994278858746252, 0.19989981135774046, 0.1993764660531475, 0.34859724763420324, 0.4652311003977253, 1.4274561645523196, 2.818626727788679, 7.338958555652249, 15.132494318869808, 27.845390265987767, 43.126056040486986, 47.459063068512954, 47.578193295386534, 47.79151531957811, 48.09001553443171, 39.65067525063792, 34.46559213822888, 43.868529335145034, 24.774562735711378, 36.900744668899044, 54.41794787683795, 44.591496682936146, 86.55583689289709, 68.5109572256765, 58.3126300381076, 62.25569071308259, 46.752404935898326, 16.497810579115345, 0.938033968690903, 0.17544665253691136, 0.06741754530418305, 0.12273162918826266, 0.10567740882716833, 0.14671584260800194, 0.02447583502338779, 0.13679400807426823, 0.06763172050517413, 0.0629617251275528, 0.07072594963134297, 0.09085556101654807, 0.00402338796242651, 0.07898281463572095, 0.053796111305634824, 0.0705457657515522, 0.054317254107445485, 0.20763098682847717, 0.03097091805219891, 0.097168309373721, 0.021546402901050546, 0.08482273352602798, 0.08122532252943324, 0.042176154787622155, 0.05024314489996722, 0.0334664935155982, 0.040878133713117534, 0.03842181451017818, 0.028004815216146173, 0.03514689205574893, 0.04166286055659575, 0.11370297656544756, 0.07475110582045971, 0.04297651748563494, 0.04462519615528084, 0.0300049290601765, 0.06879024462954653, 0.06274610585082444, 0.0869557521336021, 0.09486115132007869, 0.07966022788276596, 0.06281381653201196, 0.12921568246618395, 0.06721536704008618, 0.05404124028920647, 0.051844621062158584, 0.11531404414845091, 0.08806358422002486, 0.10152168827311647, 0.0710512918510264, 0.027388319365620136, 0.08711702896342163, 0.03069059690460563, 0.07942115482423576, 0.06167307330836212, 0.06564655686698614, 0.014509469713835467, 0.048011572911374034, 0.0630697894901518, 0.054120932585529746, 0.03144110451572605, 0.04570827977130971, 0.05464820409073465, 0.0160234768296622, 0.0630632394383992, 0.04780428484082223, 0.05748339207662691, 0.013822127967291783, 0.07119232863788644, 0.022830132605327715, 0.056199681524547844, 0.06140042644655032, 0.0269320220761602, 0.022803850043865464, 0.024592925816954627, 0.029561500132624662, 0.060605077794001955, 0.09775228287664153, 0.036334761178060886, 0.023057252777019338, 0.02797875290496215, 0.04890878827521398, 0.030139199375445326, 0.05223955853932327, 0.08178181645850982, 0.03610637121563477, 0.03284621893638565, 0.0353338941180658, 0.05974769134134535, 0.097155278218129, 0.03642253570198532, 0.05944949927769842, 0.09169996610932774, 0.07051268607498178, 0.054796947722112944, 0.07840650967292248, 0.14555871276365173, 0.020086961355240598, 0.14831255370330426, 0.0575339155752332, 0.06002901414889963, 0.07049697361165477, 0.09090003242055256, 0.0755399082516951, 0.09388088053392787, 0.20319835613331488, 0.05946555648059134, 0.39828362664388073, 2.20324999382419, 36.15796542936756, 90.79134556554979, 85.72467096390264, 78.10002265437957, 69.1890016678841, 53.122471378695586, 25.737457544572894, 19.892512136890044, 31.482364862195908, 46.42216882398052, 67.18016762887278, 88.59102925946637, 85.83521120009884, 77.91752261500206, 70.61082163164693, 51.50099100605134, 43.605051963560044, 29.355963660824685, 14.553805474312076, 10.757681688954754, 7.02723652124405, 4.398026687483634, 2.6682712474176964, 2.424935736963826, 2.4966231805662957, 2.4426530830321775, 2.6483301626097773, 1.0496662172578997, 0.24141144998852285, 0.14632123071820508, 0.11595730519583149, 0.05954509172889014, 0.06854863581998695, 0.13363331315978882, 0.5513846129179001, 0.2438598210292478, 0.009231534730192394, 0.30016440297326735, 0.1605636326055373, 0.3170566723471688, 0.17773792958788334, 0.24495555658734616, 0.1941813940122243, 0.1706540218043712, 1.0125173267818268, 1.5260815884797805, 2.923843081920378, 1.426332528072019, 1.141670925482627, 7.3537007839449, 15.358789582406322, 25.832908422716205, 36.93709719565607, 49.54290459232946, 66.13600131004088, 59.43034079767043, 75.27049541473389, 51.73215981452696, 70.95542538550593, 63.02572650294151, 21.587668349665982, 38.641249364422215, 57.9210441343246, 63.4835926178963, 75.71501762636247, 61.305692657347656, 30.663338668884773, 3.508225491931362, 0.055096085904346365, 0.17263403733170804, 0.077061228634369, 0.10422230142379, 0.04592229792427632, 0.06761177923650512, 0.050431763407804316, 0.05616410057090464, 0.05875015293338126, 0.0534926945223443, 0.0720513200447444, 0.10023773257290164, 0.13019060595862328, 0.04793578766346459, 0.014996675778210405, 0.02919897392031647, 0.09513146544416105, 0.026873347402039557, 0.10729720215162925, 0.033451018539527734, 0.041395714206080285, 0.07541304409143425, 0.056464204023922646, 0.04408578215647609, 0.008536231414895625, 0.0700065930704436, 0.1184627804304323, 0.02799214220665876, 0.07429883815348148, 0.024717953281417012, 0.07175698140335661, 0.11581667443557132, 0.07903311596882921, 0.041674949424040895, 0.09264836763782848, 0.05473250440592247, 0.07100022442999386, 0.13610364028042363, 0.1005428194278671, 0.13722373743451413, 0.04624028569988666, 0.03229807536568373, 0.07364193308016947, 0.0475558655096158, 0.022048154102277853, 0.042015521471659024, 0.05532133490628293, 0.10862025897949935, 0.030351719826519973, 0.02191241481341422, 0.15171249787653648, 0.11707010919288283, 0.14490880973396764, 0.18381447771624213, 0.11818283658114173, 0.1921914346636303, 0.23677404399120042, 0.135561847578614, 0.2376515823867052, 0.1725262027954863, 0.1539565839113728, 0.21569090594928111, 0.1557841326200193, 0.23399165861548918, 0.17866412988833844, 0.14567266068150922, 0.12372391223306618, 0.1318476081735665, 0.2106862374010586, 0.19668061796936298, 0.09370990503098696, 0.16359331116320627, 0.2803530321726876, 0.07753537577246467, 0.14363212420815422, 0.1586724985991755, 0.17545135631676645, 0.13933095420079847, 0.13593153096735477, 0.20345202316680264, 0.13770641879208628, 0.1645748383335529, 0.17782319517385575, 0.1547661856297524, 0.21752249960216785, 0.1408240748869796, 0.14468541849524746, 0.26247762684379855, 0.19162828343049174, 0.1322929504057092, 0.15075661932989476, 0.12030502270546653, 0.2923505206502253, 0.11914698121648644, 0.17428206099617868, 0.28050554495665336, 0.18537106112607066, 0.21463713668767484, 0.2559660786702748, 0.14162509642060728, 0.20466768212856787, 0.19466749212193876, 0.21177824977184498, 0.2491125794908693, 0.376125636600679, 0.2757683636680726, 0.5602381378412247, 2.2263740820269433, 42.90859591576361, 108.58240081417946, 104.32768037242275, 91.71946464046356, 89.69918512528943, 79.21056332126741, 69.45545611842986, 41.45607948303223, 54.979309651159475, 41.30811591302195, 42.35275291627453, 76.63823373856084, 80.93660231559508, 81.61018310054656, 96.43475763259396, 90.72617930750694, 92.70645849166378, 89.27990728808989, 83.52586869270571, 70.2334503973684, 52.77168989181519, 44.29172169777655, 33.63545779258975, 26.871569695011264, 19.38571837640578, 11.111806015814505, 6.063595971753521, 2.755887926586213, 0.698420419808357, 0.5203916985661753, 0.26834690222336405, 0.21851130460779514, 0.1006640758245222, 0.31562862316927603, 0.8313064601632857, 0.43280924820611555, 0.2940739120446867, 0.45518836186778167, 0.4214798190420674, 0.5099475606074256, 0.6743537370235689, 1.0179330168231842, 0.8931011346078689, 2.13025517521366, 5.823697438163142, 9.339211429319075, 17.951641005854455, 28.608259885541855, 42.39979782412129, 56.92866094650761, 68.60518040195589, 73.56089899616858, 81.43071113094207, 75.06753629253757, 65.80637708786996, 51.669586243168006, 66.68457615760066, 38.469994760328724, 51.36526915334886, 69.60958173198085, 73.05523487829393, 113.58470932129892, 86.44261375550302, 70.74745347422939, 83.61163523889358, 77.69237072237077, 36.682915841379476, 2.7156659816541984, 0.3050216762048583, 0.18791778253451472, 0.2920585185770066, 0.3074180605190416, 0.21358486895840015, 0.13388431420730007, 0.23277022335077488, 0.19430275766118882, 0.09690102129693955, 0.15188990851804135, 0.17579854736405034, 0.16957616673842554, 0.30781458762864916, 0.11065235316392877, 0.11686266790474616, 0.13673129611678664, 0.2641273818669781, 0.11931972638253244, 0.20599347389032766, 0.12154322763484333, 0.17575074347757524, 0.2475423443942301, 0.13732089270507136, 0.12705415772694734, 0.07947858077503982, 0.1332037370171278, 0.1682667079712114, 0.19567889672133232, 0.16748050257803934, 0.10179092987410485, 0.22576497747532784, 0.28979785439948885, 0.15004939760171598, 0.23992045902677123, 0.20528609894456404, 0.22647118796744656, 0.2561545209778894, 0.12242468840052044, 0.22005800548340046, 0.19190433555312697, 0.18284407414255605, 0.23941988185528787, 0.26792175406890534, 0.22735254148081427, 0.1435255766996453, 0.15559031237517634, 0.19909679799550967, 0.27414097841228213, 0.15300999035037335, 0.06614902627564247], [0.044300823036821625, 0.05945454779711943, 0.052439764127015114, 0.004275985824454937, 0.029114365254739122, 0.015725730054621256, 0.05852178212315325, 0.030932150172790697, 0.01843353677090378, 0.06297114417858182, 0.05628189041970238, 0.07120048747428002, 0.08877279777680674, 0.0070081206203828905, 0.062234309321689996, 0.06501536170441298, 0.08810267002592165, 0.06730406469995938, 0.05015115689245924, 0.051246122532193704, 0.1312398553014763, 0.07736080731715887, 0.05948478528749078, 0.027293111873610366, 0.07059610538905667, 0.019223802430074544, 0.04158964170323264, 0.03467907280390782, 0.11174677105079736, 0.046834157058788885, 0.057313634653485594, 0.05929050538989325, 0.023552961459743883, 0.0038434693405795246, 0.029132929480364247, 0.04858590136732786, 0.061289136853790095, 0.04341897156630312, 0.010075600829065568, 0.042926740922754815, 0.01763534976259595, 0.03931126174246592, 0.030690108523553902, 0.06640519075576337, 0.015121467670636072, 0.09210329607970293, 0.0773312976103156, 0.10105338638588306, 0.06772074758285476, 0.031841494623691804, 0.04091549199074507, 0.11446824477564906, 0.11650714948172532, 0.04910829672289472, 0.08901279780172533, 0.04496249700746229, 0.3517364614432858, 0.09140480775386096, 0.06666479497066428, 1.6608283644722355, 35.767285593094364, 67.29644237026092, 69.39797770592475, 63.37116179927703, 63.58590372147099, 74.76408604652651, 70.95753562065863, 47.1910475146386, 42.07355468503891, 24.576120222768477, 28.33608073572959, 20.599397766974665, 15.979507603952962, 25.116658133845178, 23.2795121208314, 22.678471649846724, 23.700778599708315, 26.21380586777964, 24.214030542681297, 21.9190360653785, 26.7154711292636, 32.94588550444573, 37.199911686681936, 42.226201565034934, 46.33168758884553, 44.846097730821185, 41.304970172143754, 30.55239246737573, 22.21467883356156, 18.332618859506425, 13.788486334585375, 11.931790248040231, 14.631510569203286, 12.609201227464984, 14.140275870600055, 13.254131059492789, 13.384201757369505, 13.9616560359155, 11.409965965055651, 13.018742761304303, 15.664840359841625, 21.84553869308964, 23.829679450681134, 31.924390485209805, 52.558301187330684, 62.86288146049746, 64.06309927663496, 67.61879844050254, 64.67194526426255, 38.63434599291894, 36.67182337853217, 28.628889591463153, 22.6913115286058, 27.297503794393233, 30.57791925245716, 37.139012967386556, 50.80063612230363, 67.41689835825275, 77.23416728358116, 68.47709148160874, 71.75420822635775, 59.947513149630645, 21.94061694606658, 1.4243362868024458, 0.29575679270971206, 0.03534980959469273, 0.08525289189551147, 0.020491620488164407, 0.1161254691560903, 0.023639824339038423, 0.05564084719686259, 0.020305382598552014, 0.11335688868477461, 0.04821488498559883, 0.05280887294981269, 0.06534314008369561, 0.06648455746471882, 0.024224638623455842, 0.06822670269156657, 0.008171782321897487, 0.022200896712620894, 0.047501925258867206, 0.05433572831773951, 0.1282458381366826, 0.0616299004233893, 0.07862603216762505, 0.05749649984101134, 0.04162129645626392, 0.040139517701801755, 0.02924962190821046, 0.05107731122763888, 0.0695280026223871, 0.04665659703013878, 0.08034868045679985, 0.029722047263696313, 0.06590793840587139, 0.12711472463824097, 0.04089253233565439, 0.06648898545292116, 0.019815530658008593, 0.07056853388466182, 0.07120387358290535, 0.058226979998571265, 0.027659242529602304, 0.06490250929228722, 0.04942022857346362, 0.16054281033575535, 0.179856009480934, 0.038490674323252136, 0.03999281569474167, 0.0828478814313008, 0.08469692656710263, 0.04683198519952355, 0.08604423007777623, 0.0439215941925443, 0.025838515833921494, 0.024433460785076026, 0.06879561490589572, 0.05281423939572227, 0.04670638125389815, 0.02350137884458227, 0.07212557694724492, 0.044304232128084674, 0.014630226238119989, 0.024697119520316203, 0.05473492907420282, 0.013204271353090243, 0.05260608947625565, 0.09318548720330001, 0.07805141259826, 0.06099605842703774, 0.04637856840065891, 0.08118586134045355, 0.058707853388642116, 0.04001476028333268, 0.07986923199026816, 0.03541526797738287, 0.04063544855002434, 0.037133714274292996, 0.09081144201298876, 0.10819608375670449, 0.021261238162556005, 0.044431368249558637, 0.04541163520526983, 0.0245010546378551, 0.016832248300253864, 0.010700860725445373, 0.0814696126467278, 0.006398923193750483, 0.03143168929513664, 0.10812984779477121, 0.040471206959937854, 0.07719608309168009, 0.028605052765699166, 0.034359395804424445, 0.08303826960224299, 0.0539934593853691, 0.02597054151157218, 0.02053574715260296, 0.023873379649294, 0.06299252569254848, 0.08057672184922042, 0.08928643674739907, 0.04587641691849117, 0.002737567556323484, 0.05500368420935928, 0.044704884621164495, 0.047668625991190636, 0.11527859726019445, 0.061637607267907554, 0.10924818294663584, 0.024561889679922212, 0.282868497193821, 0.1427008524056404, 0.052667089227226474, 5.2619787281559365, 48.460412794543856, 83.82391391261932, 84.63003943043371, 71.80771720024848, 60.30966558764058, 46.90258464505596, 39.125301222647394, 25.374218610025224, 18.485730540367868, 27.543622716780636, 35.517987589682306, 34.4282982426305, 36.428722719992365, 35.731823444366455, 38.93247750497634, 40.294697053970836, 25.16231256146585, 15.817927525889491, 13.511938644993691, 8.61984677853123, 13.457997229791458, 16.05272060440433, 16.784939842839396, 15.845930307142197, 18.44728150675374, 10.04069987804659, 6.048246266380434, 4.90984941682508, 2.4739352108970767, 1.4609245234920134, 0.6829940443558078, 0.5205718824459661, 2.940012807807615, 2.3556914396824378, 1.5147767047728262, 1.7309513952462905, 1.5543465556636935, 2.4581437485833324, 0.5167977043217229, 4.804111142312327, 4.333738059766831, 4.79056719810732, 10.331654433281193, 18.567813980963923, 27.373740942247455, 43.119125212392504, 60.756466696339274, 74.53299568545434, 72.28186899615874, 66.07139202856249, 64.38282735886114, 56.735323398343986, 49.954467127400065, 45.29617794098393, 44.38495251440233, 24.42145332213371, 34.14607586399202, 45.67805990096062, 57.25111899837371, 72.81591538460025, 77.00321028309484, 71.90775332912322, 38.32259601162326, 5.71558024614088, 0.23272827237604127, 0.13872687855074484, 0.06992431522737588, 0.05728628148414916, 0.12812913230229772, 0.08457388518558395, 0.024022831912002256, 0.1023432486239941, 0.04065346693800342, 0.11657437369708093, 0.0688438784451254, 0.06988002002359399, 0.06576328568400876, 0.0155581837527514, 0.02901881685360305, 0.0352986195995923, 0.04557011581416573, 0.08370224566709611, 0.08919753990466557, 0.0653723280336107, 0.1112072995953983, 0.027514653009993416, 0.020965622069554466, 0.018845948713621306, 0.036627280360628525, 0.025405534430437034, 0.04532437779069428, 0.04048855502098318, 0.0144717121128774, 0.0267704100828738, 0.031233699616765788, 0.04710371275582621, 0.016000012514151393, 0.09272332934121932, 0.11695167199978906, 0.06055895547052065, 0.04876124357143718, 0.021074804920522917, 0.050103395140819976, 0.02922003942301437, 0.04981449572369457, 0.1236288790260592, 0.10363285039221087, 0.076874632598652, 0.15733212052333742, 0.09765199430647398, 0.05559027390254121, 0.10564598390051436, 0.028455939496897405, 0.00399435323009628, 0.038177880623768416, 0.03509831825090993, 0.149079943977056, 0.12596136394647822, 0.18618377316142284, 0.1733749056415212, 0.16625227977431592, 0.1253537259875767, 0.18880134238110435, 0.12162436400690388, 0.11224658979523568, 0.17245399134774364, 0.23020995750782952, 0.14896239544595444, 0.28335554525256157, 0.23589606126469953, 0.17843287858751514, 0.15256837130554263, 0.18351449300685238, 0.1538490251668038, 0.1761273829446685, 0.19128982578554463, 0.2621019679692484, 0.2087229379122296, 0.056857892777770765, 0.21912308710236705, 0.24049802803464476, 0.09455571972554731, 0.13547941651796142, 0.15746497549116611, 0.13553311928145348, 0.1322465561210148, 0.30035935702823824, 0.20849688068753292, 0.12824004651197504, 0.1285913974166878, 0.18002301664842715, 0.1249492851897113, 0.242878983338033, 0.14587947377754798, 0.13681440133481257, 0.11568270097937315, 0.15956466927403407, 0.13561257792095985, 0.11580417188064707, 0.16422683523306925, 0.2681161871840877, 0.15458566467127494, 0.09649904730219035, 0.3478833762628417, 0.16407806095817398, 0.21490290791036623, 0.2806296818439038, 0.1478713023806772, 0.3995826053282907, 0.16319790254196814, 0.20516899474445852, 0.3043484074934837, 0.49168607760821625, 0.3452704035707059, 0.16307612520552453, 5.938008052687492, 57.84254574006604, 102.09572622852941, 109.86821651458742, 87.63056632011168, 88.64025500512894, 99.198349829643, 98.24931667697047, 73.46520885344475, 65.67501691079909, 41.67549687047159, 48.38248314396028, 42.106804616989635, 33.838742471510365, 46.08564123030632, 52.40971003809283, 63.64816742558634, 54.29243595369401, 54.640185448431204, 64.65889161632907, 48.79525769141413, 62.013849135368105, 73.87655565815588, 75.76435319838986, 76.06297892908897, 76.61126352125599, 70.76988158687469, 66.4704147461922, 48.61132598692372, 37.43948613443683, 28.605384788205548, 20.932467791341967, 19.572223155729233, 22.511894472183723, 22.919415004791755, 25.286659540668612, 31.509695937556607, 37.09776924502465, 44.58966885843585, 48.08190407291536, 57.29025640795308, 60.891568814554525, 72.36063803395918, 77.14890280077535, 81.48967219937234, 99.37271487328314, 95.45133313825055, 91.80716883751654, 87.91273378556775, 83.1164909178211, 51.120677994143584, 50.75930610779793, 44.910106889663204, 37.648952468749016, 43.24301719665528, 49.16785932356312, 65.16548141356438, 83.70802356350808, 84.82461252520162, 109.98057673054358, 77.056091677758, 89.87850804482737, 85.6560294858871, 45.00059596953854, 4.304809599153457, 0.372705789463174, 0.1553595513706246, 0.4226051409158015, 0.14749714503845862, 0.3248691144249132, 0.1458326811271329, 0.3083346387551677, 0.25059158883748517, 0.2314015153434969, 0.26993258165255674, 0.28886926390471, 0.23979914134308217, 0.1408769962407889, 0.22466499779012897, 0.12379466045287349, 0.08855557354587702, 0.17661559545705396, 0.1320672609032162, 0.23974942223679638, 0.24563299281702888, 0.2442076709121466, 0.17478749516510195, 0.18317105579039744, 0.1328106266596625, 0.09379956030076551, 0.15508080261849588, 0.14619442784497816, 0.11753572977238125, 0.10340072575115389, 0.16704211642424907, 0.08021690567294437, 0.2513607411134628, 0.2151483624813057, 0.1557341990091147, 0.12238629973463475, 0.06204394796382516, 0.12001787762968771, 0.15638800908721265, 0.10291866492480041, 0.05822098536056377, 0.13713834927447383, 0.2968744230606864, 0.21258561451348568, 0.1927671497387271, 0.3142118814491457, 0.23645032587791645, 0.16378074223476072, 0.18216870635026888, 0.09307846472027803, 0.17594185177116625, 0.14378989235528056, 0.0972756919180674], [0.029306505851808096, 0.04174136158619677, 0.05734822352326686, 0.0829345029928992, 0.07002189184629148, 0.017830108465146155, 0.03078799732329865, 0.0995272932754409, 0.022391357661915884, 0.10198733183525263, 0.09391475694193956, 0.050200037132467956, 0.08646324186796144, 0.036770228536859635, 0.056286801043297016, 0.047973410241426005, 0.04192678933782924, 0.029534156539387284, 0.026223704842249715, 0.031794142729092034, 0.04139722722973074, 0.06110378188051044, 0.103979826934876, 0.07599339399847292, 0.06389231894225364, 0.04451625462200853, 0.06270248097397628, 0.050178176813548615, 0.06352272365362414, 0.05212916909987408, 0.012684728717431428, 0.07839141774081415, 0.03991198958829045, 0.037577436230475866, 0.06756876339955677, 0.03484672348525736, 0.029352300672701774, 0.07380199949106864, 0.069426181876371, 0.11736028031596255, 0.04918734933580122, 0.045134089211182254, 0.016247447422375123, 0.0336530014512039, 0.05658063023621517, 0.11903907007147228, 0.021511605272309917, 0.05042756141553964, 0.07820226297143006, 0.06271145569400922, 0.021775154840020884, 0.03149896713664695, 0.18837873763855428, 0.08896887798102633, 0.08895490453728745, 0.023590001810882843, 0.08882475385983145, 0.05305928410962225, 0.02061383066428525, 0.14149354380224982, 0.15949694710152765, 4.55246118768569, 22.08511314084453, 64.79162070059007, 90.07617981203141, 72.50035285949707, 71.21389389038086, 69.49858650084465, 81.72546940465128, 74.34283133476012, 67.95562021193966, 69.25241070408975, 64.4843892897329, 52.177458655449655, 40.76942151592624, 15.240514432230304, 20.016947369421683, 11.019690132910206, 11.275212937785733, 14.462532900994825, 15.369200533436192, 4.929487253389051, 18.471376626722275, 27.394823681923654, 33.79699668576641, 28.858687531563547, 57.22705133499638, 57.796708922232355, 56.96537433132049, 63.08040826551376, 66.71968137064289, 61.87017663832634, 47.76596500027565, 59.502433961437596, 61.65908252039264, 45.64908535249772, 34.28785385624055, 27.69669125157018, 32.78030656999157, 32.01454812480558, 32.1901330255693, 34.85526784773796, 18.79756877499242, 27.95908408780252, 31.247148167702463, 23.326296191061697, 18.95346926104638, 36.88164664853004, 30.016169163488573, 20.82938005847316, 44.550013695993734, 35.30472047867314, 60.67703085560953, 76.22208595275879, 75.24236417585804, 85.64903982224004, 74.54927352166946, 79.26087164109754, 78.30970471905124, 57.3377327765188, 25.161732050680346, 3.7794657243836314, 0.1373496056804734, 0.1278701716012532, 0.11555716215122132, 0.04017959942200011, 0.2070774116943921, 0.037608485774046956, 0.13733808371809222, 0.07879741369716584, 0.08403121914354064, 0.04175079212854466, 0.06244204555367751, 0.00942535593264526, 0.052689167881204244, 0.04692118464698715, 0.057865953403374845, 0.03408276145496676, 0.12426542148234383, 0.1449054389471008, 0.01991885485157611, 0.04025418957274768, 0.043500284138586254, 0.09678443803662255, 0.059446752852489876, 0.04631653060055068, 0.09833110826871089, 0.08712957748362134, 0.02741606132457814, 0.023143650257899877, 0.07295446109867866, 0.06947454500703082, 0.09002523661981668, 0.02076308182891338, 0.029286861442209735, 0.04609747924992154, 0.04005846942985251, 0.0197214818739843, 0.03879774534594148, 0.028772069509291363, 0.015045030290381083, 0.08847773135189088, 0.041675156267780455, 0.04610952981297047, 0.05750990254924663, 0.05023705450096919, 0.09132817597879518, 0.056417024499105836, 0.029840335069644838, 0.0690972850087189, 0.04037100648988159, 0.072269486563821, 0.060349043548828175, 0.059450284517820806, 0.012727734020670817, 0.01448149505567046, 0.01958569853506502, 0.1378343861189581, 0.03145194274463481, 0.03259091630517956, 0.03953837233805849, 0.0165981758806494, 0.039357154239569946, 0.06745801772922277, 0.03361249072176795, 0.023452173017205733, 0.10817068794201459, 0.02978708238280829, 0.02560117413410016, 0.025293304464749755, 0.05872297979470703, 0.07785472718458022, 0.03940606895353525, 0.02130528438776251, 0.0015992911357898267, 0.09100063508676906, 0.08751128079189409, 0.052445793238979195, 0.05236079578378028, 0.03499212314284617, 0.027565622754815607, 0.05127892258667177, 0.012413546998774814, 0.0597253100826375, 0.0176713501493777, 0.019748802484583952, 0.059814157129655925, 0.003395251166488555, 0.02106940591587655, 0.038629795890301466, 0.027237627955694354, 0.029455751270776796, 0.022080438962626844, 0.0282207868933197, 0.06559482294945948, 0.014468005204933786, 0.06897776763165189, 0.05158178012577757, 0.045658089520950476, 0.06952797963974938, 0.016398498893625314, 0.06247962599680309, 0.0130995289392529, 0.06705746865801274, 0.03595350220078423, 0.07531036532694295, 0.0516322193547122, 0.05654958452308371, 0.09950274781834695, 0.09903010221258288, 0.07668965300845523, 0.02700880515359102, 0.14581394261650502, 0.0432907514304163, 0.1037842829922034, 0.087325312948275, 0.16642141666623855, 10.097954715451888, 37.713083221066384, 84.7765713353311, 103.08616392074093, 83.44735853133663, 74.41788981037756, 59.919181869876006, 61.7700973633797, 40.44426879575176, 37.864400417574, 31.61664132148989, 23.962687023224372, 33.07140919470018, 32.658832726940034, 26.98186282188662, 25.852004481900124, 16.518438323851555, 18.327586458575343, 16.786718637712543, 12.072090487326346, 13.569987762358881, 25.40867270961885, 37.197366068440104, 46.698335063072946, 49.18378414646272, 60.490129916898674, 59.137512330086004, 60.65098631766535, 59.99613877265685, 59.245812892913825, 48.5332041402017, 52.07666550913165, 50.7436833074016, 44.37102810029061, 39.26668305550852, 33.21525035365936, 26.18733379148668, 21.565261810056626, 29.83571856252609, 28.55827908362112, 32.02942763605426, 30.915097959579963, 36.81893579421505, 48.4652098532646, 49.13446426391602, 45.512351528290786, 60.68626803736533, 59.198340446718284, 39.123606758732954, 49.88749657907794, 30.7244570409098, 28.389711303095666, 32.76403069496155, 34.70034599304199, 44.60412671489101, 63.932813828991314, 83.9096490798458, 90.75251410084387, 82.14410397314256, 44.45199758775773, 10.215238486566852, 0.1260353067529298, 0.1874318529641436, 0.043828491527106495, 0.043612263210478334, 0.1988208837687008, 0.08122991139609968, 0.14088438132837897, 0.037438475541890635, 0.007512174873432566, 0.019297699271250638, 0.10058211207750345, 0.030269901636206818, 0.027726177546766498, 0.03970917164077682, 0.023341425431651935, 0.07906982690216073, 0.09159077559748004, 0.062266270509890975, 0.02018923026269242, 0.06340588758429212, 0.028934508877535983, 0.032472226303070784, 0.023294952622945272, 0.024531656019990484, 0.07029736174210426, 0.034635949714650074, 0.05535005937300383, 0.07438760476126786, 0.04654609267750094, 0.08768895956417246, 0.12280024002276121, 0.020236246993825324, 0.05947796710496468, 0.042866924777627, 0.0427287761422415, 0.030874404380278244, 0.08464733003488473, 0.03716134706572179, 0.024875811443874435, 0.07120784191835312, 0.03799545593679913, 0.03821273762432318, 0.04574084233853125, 0.05931787388098817, 0.026273113682926185, 0.040042159417944576, 0.038508573967602946, 0.022792734108084155, 0.02365538166956075, 0.04935310011909855, 0.02469268578645443, 0.032880267714180296, 0.04065237909315094, 0.06930411342651614, 0.24147681261022247, 0.21721045666884994, 0.15942337201727977, 0.147570199182918, 0.13346910987409855, 0.11335618388388427, 0.11599347220673678, 0.2546598221505842, 0.1345288546215142, 0.16128652849264685, 0.19781212983352525, 0.15560040941401837, 0.2337751928116045, 0.16071861219261924, 0.1520383763577669, 0.15305724265354295, 0.12882217374299804, 0.0916388935800041, 0.07910052404528664, 0.17213044177380302, 0.13762337486109427, 0.1477062870417872, 0.16223808630339562, 0.10967240413470615, 0.13448662785512788, 0.1791846100240946, 0.1468666546767758, 0.1609993221298341, 0.16764629932661212, 0.139128630379996, 0.0783208916865049, 0.09192292067793109, 0.20685588971020716, 0.10357105774023842, 0.13317649493054037, 0.17486074849242167, 0.1623072027559242, 0.15418732959416606, 0.12240883038048783, 0.18024317499610687, 0.19873863656915006, 0.3283937317469428, 0.16776495102432468, 0.09450971614569427, 0.1358612500611813, 0.20146986259327782, 0.14855256904998135, 0.15485525101182923, 0.16263757051239092, 0.12449779893241583, 0.12666915257972094, 0.19148605154646983, 0.31560891938786356, 0.28420568834389415, 0.17510316935518097, 0.25428445438944525, 0.4150411871171767, 0.06094274253794744, 0.14443653185040722, 0.2541317117791022, 0.2600671771553255, 10.391277401678025, 41.61884607807283, 99.11239500968688, 124.69781168045537, 104.62454103654431, 98.53395523563509, 93.96993237157022, 114.18375722823606, 102.72432527234479, 94.66958122868692, 100.16871283131262, 101.88621674814533, 92.79558258671915, 73.84513747307562, 37.00352645689441, 42.23630166822865, 29.381023683855613, 33.61764630963726, 41.57712774892008, 37.18616770159814, 15.145626414206722, 33.982862118751775, 43.088797446220156, 54.99919999030329, 47.238669010900686, 81.68249591704338, 83.8644790649414, 86.32567221118559, 90.89162488137522, 95.13298573032503, 84.56372784030053, 76.44670440304664, 88.81530254117905, 98.99250384299987, 81.30111602044876, 67.68056792597618, 60.91084334158129, 63.62383696340746, 65.15198061543127, 66.44211092302876, 70.72890066331433, 41.8647982997279, 49.16666300066056, 49.12882389560823, 36.15381163935508, 27.346233360229004, 48.6117535252725, 43.88986310651226, 37.53728258994318, 76.12851388992803, 60.571338668946304, 112.3963252959713, 129.74434883363787, 109.05341471395185, 109.21575377064367, 92.51028506986557, 101.54154239162322, 96.32452334127119, 92.96083204207882, 48.074682989428126, 8.712618677846848, 0.19150092897395934, 0.2348902491071532, 0.27005604438243375, 0.20046323838253177, 0.2938324104874365, 0.20685322372423065, 0.288884156653958, 0.4009662826936091, 0.12161780629427203, 0.15289064917352893, 0.1659874891441676, 0.1700618051953854, 0.14013381434544442, 0.13788723086397495, 0.13397262882321112, 0.12493163452393587, 0.21747247406071235, 0.3057914719946923, 0.13311781259554048, 0.1219179365603674, 0.1583835302341369, 0.1792977765322693, 0.09515259414911272, 0.1845544880075801, 0.1704675866471183, 0.21315544603332398, 0.13957104615626797, 0.12314883301094656, 0.13127457440620469, 0.23081712815309727, 0.13512824181347124, 0.08869160011771227, 0.10218084564492588, 0.11728852852097443, 0.09257949633343567, 0.11724476191786029, 0.1330882109581463, 0.1463292899631685, 0.1194746753260974, 0.16235782584596067, 0.12423100881278516, 0.20308235509982034, 0.1693445323936401, 0.1556649906260352, 0.2206399411924424, 0.18430003956440957, 0.1067915075128117, 0.1970200408850947, 0.11523224127989624, 0.16768353119973214, 0.12288490806015269, 0.10651282004771695, 0.10636432922535366, 0.20485008766333904], [0.04894457224215712, 0.06267680936763365, 0.07500906294632344, 0.034175362332814166, 0.03909502576495852, 0.015958405321373815, 0.044782814915261926, 0.05812530480926076, 0.09855911901761448, 0.07735319240319152, 0.04425994841562164, 0.08843768793608874, 0.03810443577446765, 0.04951858277162237, 0.15244752859636662, 0.03186096283306759, 0.07158595227426098, 0.022520472205454306, 0.025511030483269886, 0.05187701509003678, 0.02293293011344729, 0.036368614603434844, 0.03448980312133509, 0.06066335793284159, 0.10904653328320674, 0.050502917654211485, 0.057858081849952864, 0.04502851080389754, 0.058025134982721466, 0.043926301802839005, 0.056818783989236246, 0.01938100941779633, 0.01952301530588058, 0.06966006085877458, 0.031395468658076665, 0.07418907307569059, 0.08228858362042135, 0.0353126504999255, 0.08505217685934999, 0.027506827421846892, 0.07157223163953713, 0.01507412152169573, 0.09248047180834318, 0.05306175857361767, 0.003740426684324179, 0.08516247053780863, 0.0958883296698332, 0.09180533384243328, 0.005296446061918452, 0.06023945084082023, 0.05061002057646552, 0.03706566651441878, 0.061445832477822426, 0.028114708613664396, 0.07418376408637532, 0.05588459339173091, 0.05490909150290874, 0.04893280130120055, 0.02699850510144907, 0.10832333862180672, 0.04198008224428181, 0.12296422880383269, 0.09916666504596511, 3.484545162608547, 16.170916326584354, 43.51878335399013, 62.884070104168316, 74.13995065996724, 76.2826551929597, 73.70486567097326, 69.20216514218238, 60.91709559963596, 67.99376133949526, 60.2063895810035, 58.65528829636113, 64.17484368047407, 48.73086806266539, 53.52948004199613, 54.72255522204984, 37.413033669994725, 58.31919216340589, 41.98412072273993, 42.73468978943364, 29.864606818845196, 38.68294023698376, 29.113682777650897, 26.964204311370853, 47.260889237926854, 30.523506172241706, 25.42699213950865, 37.26807463553644, 70.84643056315761, 84.86225943411551, 72.2249867839198, 44.8851292364059, 31.94206664639135, 30.29680298220727, 16.308552295930927, 44.74849739382344, 96.32800640598421, 36.37272304104221, 24.47571146872736, 36.949856665826616, 42.03252669303648, 41.66578508192494, 47.02638641480477, 56.18441081816151, 49.59128702840498, 70.82977617940595, 82.7605672036448, 69.62174107951503, 76.47796569332, 74.5235663075601, 76.30658949575117, 83.59308242797852, 82.97612497883459, 75.88074561088317, 42.926438777677475, 20.211402793084424, 0.5490054502602547, 0.33306420209907717, 0.13349759302312328, 0.040922566812725804, 0.08508210025367238, 0.08033027902485863, 0.06680067598579392, 0.15443476067195017, 0.014003055909979007, 0.0891565235571996, 0.08326565981992791, 0.028214880355423497, 0.06356201630326049, 0.014186582805949354, 0.03877269810125713, 0.005310930869346786, 0.03858205329086031, 0.03902499383736042, 0.07171938180803292, 0.07430428503862313, 0.12017950685995242, 0.05988523859771029, 0.012870133486426166, 0.017256743364757108, 0.06423775947863056, 0.09308968790836873, 0.057683088215849096, 0.017125140950684587, 0.05519775726321725, 0.028198635460989132, 0.08834561948934871, 0.023478752437738643, 0.13275336924820177, 0.03080955120704828, 0.04608276270089611, 0.05478264486056663, 0.02888128300377679, 0.06969595973890635, 0.035154342260812564, 0.15448896905347226, 0.04165930207818747, 0.0556697899986419, 0.061861040641463576, 0.05383463020646765, 0.05592847107759407, 0.060238167643547065, 0.07997846080651207, 0.021876682557405967, 0.08315812405799666, 0.10478821057345598, 0.025014620830094623, 0.07018244855346219, 0.09136140121207123, 0.0868281601898132, 0.053677325542535514, 0.031643732856478424, 0.0925257935699436, 0.08678242474073365, 0.0652426446697885, 0.035715628069855516, 0.04417554850900366, 0.038344837995546485, 0.034417756382496126, 0.049424235213307605, 0.10615633635391152, 0.13709967715605614, 0.07988875957145807, 0.04369128517986786, 0.02187494353781785, 0.060737752731168465, 0.03832503845314345, 0.020599045167346636, 0.0682533395686938, 0.04204398163804605, 0.0411572003917348, 0.021774718169904044, 0.03235096224553643, 0.02482998980990341, 0.07757571030167804, 0.07591369787171003, 0.09946600624149847, 0.0331258371983084, 0.013977340253580724, 0.0370293386250494, 0.07633680823229014, 0.02944201148385483, 0.04620873436872517, 0.029020002374665874, 0.03222236289612709, 0.013444822961314312, 0.01616710969697564, 0.07607724232178542, 0.07058070702177864, 0.04710734784302693, 0.05232222708723238, 0.038681633229697907, 0.05042193066929618, 0.09287020371806237, 0.07331730332225561, 0.05573419117999654, 0.06673070917566938, 0.013334967868192302, 0.02648320180484124, 0.11963740772297306, 0.10110191039500699, 0.04616514396583361, 0.04966320101952842, 0.01837956779185803, 0.056033068892335704, 0.03747608279809356, 0.020342708317442768, 0.08927781059737168, 0.08980134742394572, 0.1436271599584049, 0.055505548408555413, 0.028560721172740864, 0.16966782149768647, 0.09065519071995251, 0.033444817057780685, 0.11251268277485525, 7.197357560357741, 32.67105483239697, 68.47073724192958, 90.79231046861219, 90.92165454741448, 88.70215000644808, 88.04311337009554, 77.07615067881923, 69.09457452835576, 70.82611268566501, 55.658974032248224, 45.973477132858775, 24.963877893263295, 20.20361492710729, 15.865855947617563, 20.517133897350682, 19.262430437149543, 21.04395724111988, 4.224807956526357, 16.081032272308104, 27.464045670724687, 37.45894893523186, 35.264524029147246, 50.41346288496449, 58.682803723119925, 53.76610094501127, 51.17825446590301, 62.27691073571483, 78.49021219438123, 71.48302339738416, 72.24939177113195, 65.67565233476701, 47.98883799583682, 35.772043428113385, 26.719360159289455, 32.24892935445232, 60.39935842637093, 41.784848628505586, 35.58490714719219, 29.55470035153051, 36.979290131599676, 33.708151078993275, 31.773740091631492, 20.743083992312034, 30.748181496897054, 30.784641888833818, 28.81110133663301, 46.01132016028128, 46.86156057542371, 58.8671511988486, 71.55464587673065, 86.76108667927404, 96.64081542722641, 93.31732842230028, 64.36399998203402, 37.386059530319706, 4.153432586500722, 0.2048810222937215, 0.28479340035588513, 0.05253181342155703, 0.07580429285524354, 0.1656858343631029, 0.04809757394175376, 0.16183290240024367, 0.06056655889316913, 0.03882345142624071, 0.0536167050050872, 0.08294905100258128, 0.07447137647578794, 0.06385176607798185, 0.044980653291267735, 0.10316686975138803, 0.0527656004734097, 0.008695939679690188, 0.03842718861696701, 0.07008397561167518, 0.06610025711838277, 0.023506456092300437, 0.08002791178202437, 0.02239803986383542, 0.08178413770492039, 0.007918213922229987, 0.028244336436112082, 0.03416192515062229, 0.055992224914652694, 0.012310393259770448, 0.030786242981952046, 0.040909738670433723, 0.051726084277634664, 0.03828099222793695, 0.027001364524626446, 0.03380497797362266, 0.013361155626273925, 0.03157834150648165, 0.020114100019958232, 0.10688477871759285, 0.021477104502639944, 0.020795106219368118, 0.0463223873427318, 0.05261877589228173, 0.04796583746229449, 0.05415805720634038, 0.07131924642430199, 0.029496775279122017, 0.0546507015373678, 0.03182399334506162, 0.015153298623889927, 0.06404666267635842, 0.06470845156018773, 0.08804990955057644, 0.07468373604839848, 0.055655617372042714, 0.01118499190441423, 0.20291681882114182, 0.20200996990165404, 0.20185102197912433, 0.08946636781817482, 0.20273608335804558, 0.19768489795106073, 0.18274111192553275, 0.20028737523863394, 0.29145465743157173, 0.19599133802037086, 0.20248328966479148, 0.13969833932576642, 0.11199188088217091, 0.1226931562527053, 0.11927676417173878, 0.11724593403238444, 0.11143807592170854, 0.1496011289137025, 0.06074621034185253, 0.14268735393641457, 0.1067037214975684, 0.22032152440759445, 0.24901966834741257, 0.14411005582059586, 0.16466463916003704, 0.13663521336932338, 0.11555933784092627, 0.1087053866696454, 0.07609378216007064, 0.09102567084013455, 0.21727908282510697, 0.1626345061606938, 0.16710439937249308, 0.1674076016511648, 0.20600243711904173, 0.16721358222346153, 0.23514043810146473, 0.10828537896515862, 0.17364475245196975, 0.1906982986556907, 0.16919244861891194, 0.14941166004826947, 0.2537143011126788, 0.21563207039669638, 0.1593457213452747, 0.14711295194443197, 0.3053582339517532, 0.1918420985701584, 0.1307015406388429, 0.14719771191237435, 0.1209816238993118, 0.13205526396632195, 0.1902995652128612, 0.168707407710533, 0.26734124328340253, 0.17119875628381007, 0.25703472535937066, 0.2104180453405265, 0.1262225003372277, 0.2496057409312456, 0.18885620959824134, 0.2648670550796294, 0.18571944727051645, 7.642439200032142, 32.7259954714006, 77.26102767452117, 107.51481794541883, 112.99753050650321, 107.89635473682036, 111.00971252687516, 107.32127251163607, 96.10461173519012, 99.49962708257861, 91.31646463947912, 91.59669445407008, 109.92409460006222, 97.81300790848272, 92.23111429522115, 97.46943181560886, 79.60167854062973, 111.51218383542954, 83.99535286811091, 75.84140423805484, 54.56906503246677, 58.13653522922147, 50.06950239981375, 42.65003719637471, 68.47819758999732, 44.607558788791785, 34.67569781887916, 48.42114986911897, 81.30203385506907, 96.92198661065872, 86.58727861219838, 59.57501742147631, 44.35724489150509, 47.528222299391224, 25.986410379409794, 66.26441186474216, 126.24859917548396, 56.96580579203945, 43.822684672571, 62.68469602830949, 63.652505566996915, 57.15328331916564, 74.09103085917812, 87.85226652699133, 76.47445124964561, 95.92734413762247, 118.41331958770753, 93.4292414880568, 96.24201236232635, 87.23693293909874, 94.19546081173806, 99.33077689140075, 107.16971997291812, 100.77844527459915, 64.736487865448, 35.39954769995905, 2.88229194379622, 0.45152796312205257, 0.31164392408344055, 0.20586585896390103, 0.24844134857337324, 0.36422519614138915, 0.10531394607237271, 0.2746582409787563, 0.07942324624426904, 0.1532857973248728, 0.19166902398630498, 0.24695383565079784, 0.135856255167915, 0.22609949742834415, 0.19369895780278792, 0.18291895157627522, 0.14926179792852173, 0.16963379187208993, 0.17436806202655838, 0.11164590791468659, 0.35819446007090233, 0.22282896082728143, 0.1466898109403349, 0.1723363968513666, 0.08593227398852188, 0.19776233411844701, 0.13908591331733813, 0.14280395251849007, 0.16229532839309785, 0.15542974034624715, 0.1797493393983572, 0.11015822645276786, 0.2556719621943851, 0.20633666595864683, 0.1224204212907822, 0.09853000001561257, 0.13706432985922984, 0.1802780626401786, 0.06336008701773901, 0.1896959798590791, 0.19788706855427837, 0.18919544865287122, 0.26298836234115786, 0.21817309211098382, 0.0831105423370196, 0.10706126239270934, 0.12417869266843605, 0.20698279983574347, 0.13136829760286117, 0.1887672361467154, 0.08533502418187358, 0.18250002405576168, 0.21605525736606893, 0.2748877609208707, 0.34790669597925683, 0.1305840993600507, 0.2068478611087607], [0.07273254840965233, 0.018281611959419904, 0.037395582279010166, 0.04442974031271954, 0.21880411873421363, 0.030980434779438282, 0.061240137870153116, 0.06377595018655544, 0.07399719103329605, 0.03697945097942026, 0.07052341896680094, 0.058353813515315135, 0.1469812154649727, 0.03677022470642002, 0.038450573450855674, 0.027570372499946146, 0.08098362945020199, 0.0745498315401135, 0.03419423873926844, 0.01665269644300063, 0.008416843315165852, 0.03795181190775287, 0.014934370804938578, 0.05822594194943386, 0.07434003836204929, 0.036797880480486544, 0.009453024155640555, 0.09271291054544911, 0.06296254867207139, 0.041036798183115265, 0.024034867153292703, 0.022952394492383447, 0.040375511086876356, 0.029913862273397467, 0.0490787448812156, 0.04706057434480998, 0.05451839049196532, 0.006692206549022588, 0.01631861699054078, 0.027131863772088004, 0.008241518348034832, 0.04729746405275599, 0.06754465461257966, 0.07081674637212869, 0.076468973720987, 0.053879070966955156, 0.03429885187576856, 0.0466452359462217, 0.05870514143739016, 0.018403864270376585, 0.06588936843458684, 0.05642146397862704, 0.06540673304229014, 0.056389112085584676, 0.032107219881107735, 0.057192807266068076, 0.06854357197880745, 0.13212827214550588, 0.2053579120265861, 0.04762883921484313, 0.07076692767441273, 0.037852726095626434, 0.20560301419708038, 0.08298266694069871, 0.13564974850704595, 0.12133036244420276, 4.038671879999099, 19.739775042380057, 38.42192219149682, 50.10487825639787, 56.569046281999164, 72.03241409793978, 74.50120879757789, 67.3189724645307, 56.1961857734188, 51.97057324071085, 53.02820897871449, 52.941983515216464, 52.31797364450271, 57.84527570970597, 52.73075211432673, 50.15702224546864, 62.27290207339872, 63.574415099236276, 72.84672952467396, 70.53225655709544, 60.58780085655951, 46.0559331986212, 72.12984577302011, 65.666273947685, 48.592667272014005, 42.638709391317065, 56.36560470827165, 84.11839762041646, 100.81096956806799, 71.52532223732241, 72.52460095190233, 73.98840596598964, 79.960128261197, 36.04173775642149, 54.2438534767397, 66.39814899813744, 75.24259951806839, 78.64178042257987, 72.33923758229902, 89.43728846888389, 79.94534877038772, 79.45833944505262, 80.80099028925743, 84.85980403038764, 81.3169074827625, 76.4931688001079, 69.16940550650321, 73.42418870618268, 52.13633652656309, 29.06991893245328, 8.72470840331047, 0.43989884036202587, 0.244703927347737, 0.03970610345864008, 0.1473527834300072, 0.06300154637785689, 0.03635722670644041, 0.02970461493297931, 0.11397630141507234, 0.010693680566375055, 0.07740019955822537, 0.021317938245051814, 0.033845641920643474, 0.02968620584015885, 0.05744465101029604, 0.026510194912853263, 0.07209784456438596, 0.02230101291300549, 0.08350831050906452, 0.032247532714879325, 0.05438591473765912, 0.027498473233032613, 0.03917459548721391, 0.042040630003377315, 0.028426153998401378, 0.06972857210184298, 0.07106903444735274, 0.06924337031499994, 0.03218513485344668, 0.028407624246732845, 0.031548157642265005, 0.06659157228686156, 0.06664451662330859, 0.06337387276993645, 0.025546174766796253, 0.06314466692387097, 0.03392274100934306, 0.0637117826620177, 0.06030630350353257, 0.06671072960260414, 0.0948958014768939, 0.02498033073460383, 0.03548227385768006, 0.08420836931515126, 0.07439405522159032, 0.10692368832326705, 0.04898101887515476, 0.052455066733302615, 0.0542377571635429, 0.15663343301463514, 0.061779421634010734, 0.10686721998236834, 0.020714276282477285, 0.03365806912282302, 0.058443675628833236, 0.05319753616687752, 0.036158216215910456, 0.032662085873345216, 0.14102862036276248, 0.0659224174676403, 0.03394856583327055, 0.1216738915912086, 0.07502030911705188, 0.04645760569180693, 0.036353166440441724, 0.10964654866726169, 0.06211984812492325, 0.08501266204421559, 0.15712202857098273, 0.04711095228671067, 0.010867074991936886, 0.17525609582662585, 0.06959128148493267, 0.07518169319918079, 0.03996242881722508, 0.0713140063828999, 0.05146204441365215, 0.03772392756335678, 0.0983262436103917, 0.04226873651327145, 0.012357031734990738, 0.051684512516423586, 0.08257168375195996, 0.06193805546049149, 0.08848452655177924, 0.019298202974060853, 0.05398969023278164, 0.046297703989811485, 0.035246801412393974, 0.12399174423227388, 0.0535038794060388, 0.09468826059732707, 0.013932584439434353, 0.028620315152370644, 0.008557677088725952, 0.0733588023051139, 0.06386193589517666, 0.02949525267937251, 0.07002551544217334, 0.010715799439968842, 0.05439222347171557, 0.05370744045883898, 0.04346582933419174, 0.06230662036086283, 0.06124554645089854, 0.06771814288391222, 0.01743870839897183, 0.019622365418340892, 0.036802358264403964, 0.05672446324399883, 0.08097737051186063, 0.017330458260051185, 0.12550423162118082, 0.03492717420862567, 0.04739710527862753, 0.039180984660502405, 0.17629405303347498, 0.09952267376525749, 0.20846953134863608, 0.04157247367284952, 0.011918908923924451, 0.05947725081275548, 0.20423720200215617, 0.12580953298076508, 0.16751188153941787, 0.7146173571386646, 9.87223505973816, 34.03464917213687, 60.68735845627324, 73.2110078873173, 82.6494150777017, 96.88029966046734, 97.28949700632404, 83.78057956695557, 74.33747337710473, 69.244016831921, 56.555317986396055, 58.007493172922445, 61.98246625161941, 54.42114460852839, 49.31068851101784, 33.79505119016094, 33.83625176645095, 29.114145617331232, 26.46943457664982, 25.322180524949108, 31.769023441499282, 36.578800447525516, 35.61996529179235, 31.27368300191818, 35.060752976325254, 53.03942303503714, 65.29143656453779, 78.67128449101602, 58.154001543598795, 40.87982839153659, 28.83628099195419, 19.660354891131004, 49.272025708229314, 67.44410391776793, 39.26774209545505, 29.20328736305237, 36.02962547732938, 35.509330918712, 41.87030922982001, 41.90957999998524, 47.38634624788838, 57.00715149602583, 77.507383900304, 83.8006228785361, 92.28806711012318, 100.67323946183728, 96.23944713223366, 92.54171894442652, 74.84197647340837, 46.56513921676144, 18.75875888332244, 1.0758382322326785, 0.12686582267164223, 0.14879149655180593, 0.024791578161379984, 0.05589056121666105, 0.0192614862950699, 0.0616773825529362, 0.08478501901751564, 0.04257797939522613, 0.011169064936468439, 0.06929295152545938, 0.05206743390449593, 0.00399565797359232, 0.07759754380752003, 0.06848084469956738, 0.0851103459154406, 0.01565488607382342, 0.05385224639828648, 0.0333857593396979, 0.04264880422382586, 0.053628054597685416, 0.020250224268003818, 0.07115562536543416, 0.045327656647010196, 0.0515631182239421, 0.04843923000378474, 0.08943950111467032, 0.021245313109830025, 0.05034978816946668, 0.00669156447158105, 0.020742240406933333, 0.03922218103863059, 0.06096921853661057, 0.023278866691755194, 0.039002202721613075, 0.03938489811374776, 0.0461458308892625, 0.057714965134378404, 0.07150521426792107, 0.06279158466044935, 0.04752663542486487, 0.04106304435540111, 0.023764972462348884, 0.03506517345686594, 0.07611206867882321, 0.1177251986378143, 0.09464031115414635, 0.08803206736281996, 0.11227772360847843, 0.057571427070445595, 0.0986962334343022, 0.02247235039249063, 0.02915632197513215, 0.01445163869404144, 0.015025963319555647, 0.014813983918077525, 0.04106114062690928, 0.040218122153272556, 0.03332596617720781, 0.1365383798556943, 0.17476048290489182, 0.23326674025625954, 0.09378278297522376, 0.3011173550640383, 0.22535006425553755, 0.18418504976697508, 0.20231911702261818, 0.2550424983905208, 0.11271879107000367, 0.17226610062343461, 0.22750269471397325, 0.43221939114793656, 0.11020357119700602, 0.18048821587956723, 0.1376824249182978, 0.1535981926586359, 0.25359261570678604, 0.2620734388549482, 0.18710261901780484, 0.10764477624287529, 0.13509035110473633, 0.18774188874709993, 0.15050521991666288, 0.11527868152986612, 0.11223139061081795, 0.12119699419746477, 0.1794385528492351, 0.12716478848409268, 0.14359677691132794, 0.1310331954230224, 0.2269506823992537, 0.08504509820692963, 0.16447691697507136, 0.07536296492382404, 0.16381895470042385, 0.1368670775404861, 0.37293711737278973, 0.12933978870991739, 0.07358651427972702, 0.1006873036103864, 0.18361743990211718, 0.17393064114355272, 0.19620996419220202, 0.1258958710898315, 0.2853702032758344, 0.11962130455480469, 0.20521603254300935, 0.1278849417764333, 0.2375731196615004, 0.22739314414080114, 0.07694940278006178, 0.1532159454279369, 0.18423991698411205, 0.18770821152194855, 0.16244526712163804, 0.2445396321314958, 0.31971839887480585, 0.25924271333121485, 0.11601092368965188, 0.15439282501897506, 0.19431956563024752, 0.39534886638003014, 0.33463872728809235, 0.3226509834489515, 0.45201010821807774, 7.84886863923842, 30.268971804649603, 56.397611248877745, 76.7575522392027, 91.96522466598019, 114.80540583210608, 119.32174836435627, 118.77122802119102, 108.91377833581741, 92.23095740041425, 88.48818471354824, 87.86149194163661, 84.64605054547711, 88.52129736254292, 84.95761225300451, 91.55782376566242, 108.4929943084717, 112.11623668670656, 129.4641190190469, 121.73634375295332, 98.33982929106682, 67.90757117732879, 106.62083133574455, 92.29278964381065, 73.04894339653754, 65.85432806322652, 76.542998590777, 108.37680585922735, 133.83625953428208, 108.7361655696746, 108.81648786606328, 117.55607774180751, 119.97263431549074, 52.32078206154608, 81.30378323216593, 98.30499864393666, 120.06273115834883, 117.75724041846492, 106.47511528384302, 119.19900171218382, 102.15108656114148, 104.10630964463758, 101.91732114361179, 103.57458529933807, 105.410278074203, 110.83979545101043, 109.78988678224626, 107.3961348687449, 80.55832893617692, 47.64990598924699, 15.666807428483041, 0.8592533476410374, 0.44145537780657895, 0.2381759695708752, 0.42682374196667827, 0.17277167268818425, 0.27821059068364484, 0.09967394548678592, 0.34680818718287254, 0.10447338674097292, 0.1258868542349627, 0.14647501520812511, 0.1448426197373098, 0.12773586872724757, 0.18344287910769064, 0.17556125929038371, 0.20433368311534006, 0.08418573141698876, 0.13127046817493054, 0.15775028195592666, 0.07818856531934393, 0.16527462900886614, 0.1447090293250738, 0.16372016000170864, 0.07630567441904738, 0.16372769830688355, 0.10721933697500538, 0.18958739455669157, 0.08423905113651868, 0.20490953608626322, 0.10236142022955803, 0.10222521745750021, 0.1407819247293857, 0.22303784236071572, 0.19432940219919528, 0.15965197265388506, 0.14483181789757746, 0.2248988844334118, 0.22549604997038844, 0.13188130072047635, 0.18142158676299358, 0.10339048315560627, 0.10102738536173299, 0.20170598621329955, 0.19480103656889933, 0.24276074532779957, 0.21285497102766268, 0.23168896685444543, 0.23679710323772124, 0.22263874119568258, 0.25645937800647756, 0.1600608950661075, 0.13582565761621923, 0.20442728373792865, 0.12462260231616036, 0.16881541078609807, 0.11063536899464746, 0.19185293105340775, 0.16118125269009223, 0.24794771215848385], [0.04279856292170383, 0.037869836669415236, 0.027188828154917688, 0.025999350247964747, 0.056349256361323985, 0.07715321281143735, 0.07752442071514745, 0.019351061125616395, 0.04695220737748089, 0.016063115176474376, 0.03736231491089829, 0.10449613189144481, 0.05073601905737193, 0.09796646573851187, 0.06303956732153893, 0.03759998985896668, 0.061904489318089145, 0.022870587793389158, 0.02952183209990542, 0.043880267579468994, 0.030390426418894244, 0.026869982360832156, 0.017068959892757477, 0.03713922244646857, 0.012897558476505502, 0.06058841538164885, 0.025715886224662105, 0.0803172785127836, 0.029418381501830397, 0.023378954163842627, 0.011596664572284828, 0.015601572099952929, 0.016573768319381822, 0.02933469788742162, 0.02441656854634564, 0.02862714099577598, 0.06611374026585011, 0.024544518636239153, 0.030248311363280784, 0.1564108231855977, 0.05377131303952587, 0.02824380783544433, 0.0617382520689599, 0.03305867043954711, 0.08331241416594676, 0.06481671510564704, 0.052799392611749714, 0.06190208763244653, 0.04228827941621985, 0.022402540630390568, 0.021580344426535794, 0.02313398414351527, 0.02531465341997964, 0.11456333926968998, 0.041776164960596836, 0.034049517069492614, 0.069367085853892, 0.04041169724997975, 0.030230317873159246, 0.03753813208952066, 0.0355909702428166, 0.08305962047269268, 0.09500401139619852, 0.05219561956642617, 0.04514958333945082, 0.3585241230264787, 0.16296153377381065, 0.18018282258943205, 0.02489969998057331, 0.23799860489464578, 1.6727117977796064, 1.7854023508487211, 9.30170572573139, 25.28486505631478, 31.028860422872732, 43.41409529409101, 47.51421159313571, 48.93197582614038, 53.0554812185226, 56.883228132801676, 58.50128035391531, 47.568030434270064, 47.56521809485651, 59.79564289892874, 71.95115043270972, 75.23371142725792, 79.94700401060044, 78.98058691332417, 77.33778061405306, 84.46876725842877, 87.05103612715199, 83.66821150625907, 79.15212785044025, 70.88910595063241, 84.01967156317927, 85.81515219903763, 79.77474135737266, 86.88229576233896, 83.43556004185831, 94.58420691951629, 91.20847394389492, 93.64171628029116, 95.61702974380987, 93.39598763373591, 91.26744285706552, 87.02418358095231, 86.43378057787496, 82.25131803943266, 64.15207824399396, 48.69805743617397, 20.29097003321494, 8.615081098771865, 5.858270189454479, 4.5684727930253555, 0.9136782562540424, 0.2948309907749776, 0.17678876197145832, 0.03201259270070061, 0.15006818207761935, 0.05746031367790796, 0.03705124107880458, 0.04306375191757276, 0.0474020044109033, 0.06405402095087114, 0.0821785427509777, 0.04501480549093216, 0.08276971748038646, 0.05573311099602331, 0.04594850196172634, 0.03465241294414286, 0.021504940307368676, 0.024400804372083758, 0.03399544275335727, 0.01834468972388535, 0.02603020443911514, 0.0025371134688612074, 0.06445792548718952, 0.11089679649880818, 0.003985066089831714, 0.037927714612094626, 0.05273359715037289, 0.02863702161477939, 0.12148947890607581, 0.039737264084960186, 0.06772768833944875, 0.026611213181768695, 0.03425561387332217, 0.09861767111766724, 0.061533423140645034, 0.009306872774276042, 0.07937208689268559, 0.05295486249510319, 0.08737845646758234, 0.05307035791056772, 0.07705188236169278, 0.12342654754437747, 0.0423475478084818, 0.05603358983212421, 0.027925701316205725, 0.044681499787275834, 0.01546247255793142, 0.011821632036909223, 0.0686625607552067, 0.03403150634239278, 0.04579888882055398, 0.09160132462819738, 0.03636239396948968, 0.10336043718721598, 0.04595092663000669, 0.03421460135629581, 0.039138922603019786, 0.060139288675160184, 0.038567447824583906, 0.03783758819824265, 0.11396424319114416, 0.03932524667752366, 0.02582545020437289, 0.029960417436555992, 0.05999547098913501, 0.06221833638846875, 0.09947103943916098, 0.053904328885818684, 0.09822367975908904, 0.03475977633629115, 0.06217335936643424, 0.05722926155994496, 0.03959918056704825, 0.01322664782374857, 0.06611083679261708, 0.04577697104504032, 0.009968883823603392, 0.08571252932832127, 0.050086862963414004, 0.025910552996661396, 0.04212285038985072, 0.019944545610116857, 0.0034237134874978616, 0.03999399547014506, 0.04346573357320121, 0.054637026867919394, 0.021428325769281196, 0.08922826003042922, 0.03540401797621481, 0.05559485510832841, 0.030861551340128628, 0.004892537695160437, 0.05456668850515158, 0.051531999732457826, 0.04231295893870054, 0.029813728836034576, 0.01699860429301137, 0.06997419521212578, 0.09132938639771554, 0.027520739578551827, 0.04013754502539674, 0.04974314995530633, 0.11900475699334376, 0.028191974326487512, 0.037084167537790154, 0.047496279190865257, 0.05537180094829491, 0.0314862864662803, 0.12479997465326903, 0.09291186357938475, 0.051330411356062665, 0.058011050456233566, 0.01587075049868755, 0.06767006320578438, 0.0385302925602563, 0.03483817011358277, 0.1059013669709525, 0.03304210378818455, 0.05259470924014046, 0.1085538697999812, 0.07233571486487504, 0.031885607881591685, 0.038702620208383574, 0.11049534344384748, 0.08127016931652062, 0.04142441952060308, 0.09954181830248526, 0.10858318032396418, 0.0524241014594032, 0.1383993912848734, 0.38372930439729847, 1.5831269468030624, 6.397418600897636, 13.779463902596506, 26.77637573211424, 48.400141654476045, 59.43685977689682, 76.6092944914295, 77.98955302084647, 78.57458237678775, 80.03181349846625, 80.02251748115786, 74.67796648702314, 64.31542534982005, 66.35053142424553, 67.46709685171804, 70.62693472831481, 64.69538927078247, 69.9737031998173, 65.59771483944309, 67.24159194577125, 66.62771747958276, 65.62253167552333, 62.800943313106416, 64.88287464264901, 66.41467786604359, 78.43026268866755, 58.20354107887515, 59.03126708922848, 62.188312238262554, 67.03735413089876, 68.4078851822884, 73.36654555413031, 78.7043422268283, 88.76691618273335, 83.87117062845539, 89.31820531045237, 96.75528587833529, 101.36885612241684, 99.39987336435627, 92.86336114329677, 79.69132823328819, 42.966297903368556, 23.240080533489106, 15.42757030456297, 11.1958251460906, 3.112668678645165, 0.41155600800148906, 0.09409274981026688, 0.03173335748274, 0.08451655882621005, 0.035478834122900045, 0.13851448833461733, 0.0853003970076961, 0.03155636627437367, 0.04439599413965498, 0.012279636744830397, 0.029380578893206777, 0.08168132870548195, 0.10347145864920271, 0.0406827429880298, 0.02669789219996141, 0.06567144706364601, 0.026313409907743338, 0.08123950281691167, 0.018463611467591217, 0.030789489279531186, 0.03650514679330011, 0.018353522717652303, 0.08599627297371627, 0.05360566950853794, 0.08954847712189921, 0.0042744311447736, 0.013165549438957487, 0.07893519461034768, 0.06136019533920673, 0.10733711533248426, 0.05951089356395026, 0.11548835979474169, 0.06700972605857157, 0.05424623009598544, 0.030704581839663368, 0.026914624219399788, 0.045138065207509265, 0.0355897176890604, 0.08366373442714253, 0.07093306916255145, 0.12169220109259891, 0.07193206313757167, 0.013154393283560151, 0.0591537433736507, 0.056019585744868365, 0.011497993405247408, 0.01632107613277772, 0.011980912250076092, 0.00859277157653724, 0.0338440369664421, 0.029606904248676957, 0.02650259149020478, 0.16768408278303762, 0.04815176317107774, 0.06603012942979414, 0.04462300131337778, 0.07658540376371915, 0.02631018659280193, 0.06510221309238864, 0.05366776859568012, 0.033710101814640146, 0.2018335858179677, 0.14193648051831032, 0.1034088003178758, 0.16559712138147126, 0.10773635439334378, 0.16581976185402564, 0.23771953438558888, 0.11908368703218238, 0.16666035948982164, 0.1106339440711083, 0.14777989276955206, 0.10916880857680114, 0.10810422981458326, 0.18206292492968423, 0.2721872397007481, 0.13767171500911637, 0.1930829311811155, 0.19409291085696992, 0.11824737948876236, 0.18124713322087643, 0.08260029713593184, 0.12964145881274056, 0.17569897125565237, 0.15509404061782747, 0.10004705328854824, 0.22054427213245825, 0.08787924814368449, 0.16873849555850032, 0.18377078006104117, 0.16638320420057545, 0.15567784558140463, 0.19695843209422406, 0.10159173935291269, 0.10555120350252237, 0.17314962982650728, 0.1583747815100416, 0.1535018341195199, 0.13303083097261767, 0.29246040830208414, 0.18490163308958854, 0.2016203222616065, 0.16462601300689483, 0.24438298247273893, 0.13445455941461748, 0.14306468288263968, 0.1707532608340825, 0.14725374358315624, 0.22076559493378287, 0.13371315484325733, 0.09437575035037533, 0.07951347607999079, 0.17002742316934372, 0.13998992771150606, 0.2562712727775497, 0.23729026467809755, 0.1151941667100595, 0.13000161206770328, 0.24626996428255113, 0.17108655504641995, 0.1265603987379901, 0.19530276287226908, 0.19967888692213645, 0.25867246812389744, 0.11623149572481072, 0.2646793941816976, 0.5363152344380656, 0.24436749217491, 0.3416846217888017, 0.13802457510703994, 0.6028663342998875, 3.6583963757561104, 9.3015056848526, 19.920745357390373, 37.97537995922951, 57.806510925292976, 85.58373235887098, 95.39016769778345, 105.21536765560028, 110.18143346232753, 109.20875626225626, 117.1652449330976, 102.92296978735156, 97.91752338409425, 99.14887305228942, 99.70631245643862, 102.26118749187839, 112.13456200015162, 111.39654451800932, 105.58866746963994, 114.70229456501623, 106.65033540418072, 101.8907274738435, 95.85269358850296, 86.39640039013278, 101.91320265493086, 103.42943406874134, 101.11335292939218, 112.66159519072502, 100.67495745997276, 116.3089366112986, 126.49340998741889, 119.18407317130797, 117.83726461472051, 110.72494060762467, 112.29786595990582, 111.76262717093192, 119.99807480842837, 112.09254557086577, 99.17786721260318, 82.85679863345239, 40.68773815708776, 20.601553109384355, 11.441746969376842, 6.910023352792186, 1.47529951987728, 0.5433805875720517, 0.24359696094066868, 0.1258827556645678, 0.24471555656242758, 0.13428549913148727, 0.3125263041546268, 0.24186425391704808, 0.23875171528948894, 0.13452186789964476, 0.1803789104545309, 0.18599336966872218, 0.3107800833400219, 0.12601515097964194, 0.17649220933596935, 0.10570305745087324, 0.20155338149878288, 0.13503329287613594, 0.22076686663973719, 0.08240810099748835, 0.1464346117309986, 0.10141654270550898, 0.14712977523524917, 0.13278143870974743, 0.18737739943448575, 0.13479416619145101, 0.08985973864553437, 0.09539647057892815, 0.2455095913741858, 0.11901399601371059, 0.14445375350694503, 0.17265168799748346, 0.18637105101539245, 0.23732574987075022, 0.25427115510307974, 0.1305467295911043, 0.20636185492959716, 0.0897860946133733, 0.23416566782661025, 0.16586733591412345, 0.12551220659647258, 0.24859977555611443, 0.206206047967557, 0.11638833690554866, 0.1413443098746, 0.11737415416827125, 0.12173745390628615, 0.07938509506563987, 0.18037172454980113, 0.1799869645507105, 0.1490281411116162, 0.15075737009606055, 0.1420625326253714, 0.2696846143132256, 0.2276938489728397, 0.16649417969728672, 0.17163060004672698, 0.23251087194488895, 0.1310436295405511, 0.2053615432833472, 0.1646488271052799, 0.12971782245703284], [0.050973552279174335, 0.013371080295332979, 0.014422543632287173, 0.054726444650441415, 0.05156650433256742, 0.03784527206012318, 0.038836808169200536, 0.004076745507547692, 0.0296419010602779, 0.00845281114321082, 0.041395074522663514, 0.03537287650209281, 0.05104017511550939, 0.13535258300121755, 0.059198762530521046, 0.052171882332092336, 0.00482431038342897, 0.02398765123929949, 0.05759088570372232, 0.05405422930996265, 0.0345862191170454, 0.1281910551892173, 0.02142126435383914, 0.023150627403670264, 0.0799579909371753, 0.01665764345577167, 0.05230374904649873, 0.04023403379945986, 0.038751963931586475, 0.023413451103072976, 0.06527345672610306, 0.06296043043896075, 0.023704621970893878, 0.016613428691221822, 0.017425908984976913, 0.03350912630858441, 0.022198002815486926, 0.023379086314009565, 0.05575262708589435, 0.12930707675555062, 0.0244467179366057, 0.046722346526240154, 0.05770448888201387, 0.04376563401291928, 0.05186650053327603, 0.1404392995661305, 0.038714762701983416, 0.04279258743589444, 0.046249651124760996, 0.07440992090250216, 0.05114849611756302, 0.033494923038468245, 0.05430069511696216, 0.0420851550335365, 0.0900167943308911, 0.10399475032764097, 0.0032925336187960763, 0.10440736528365843, 0.0659277341178348, 0.04899863889741321, 0.08472504199392374, 0.024337745759816422, 0.0573286691289996, 0.045874279533182426, 0.08827179159608581, 0.11759327063637397, 0.03335232343224268, 0.09295089575912684, 0.09835637384845365, 0.15372548582813433, 0.04271874039043342, 0.16280609453397413, 0.11157094621129575, 0.3042910121861966, 0.021090959799626184, 0.4543579225578616, 1.1193060610563526, 1.9898348133410177, 3.9773806785383536, 8.968201298867504, 18.802020665138, 16.812984789571455, 8.277866109724968, 16.474268513341105, 46.06293070700861, 52.17507777675506, 61.895381789053644, 55.020941688168435, 59.53585255530573, 65.0986481481983, 78.70162010192871, 93.3504096923336, 88.72234236809516, 94.63835131737494, 87.93779773096885, 79.47451529964324, 77.95882517291655, 83.01432886431294, 76.11123977168914, 75.35840357503584, 73.57888698577881, 52.57044484538417, 34.031197486385224, 41.28782549212056, 36.258821333608324, 22.45748923670861, 20.474291809143562, 8.891038471652616, 1.3456919068290343, 0.3785599269453557, 0.07137726226280774, 0.3295124346210111, 0.2824913980739732, 0.24809922902814804, 0.04992644032163005, 0.16571283130155456, 0.0448083141518216, 0.060069448269543156, 0.07350564603843997, 0.04761062547444336, 0.09539860030335766, 0.03736277073321324, 0.04044954582387882, 0.04012676999874173, 0.07380914709140217, 0.01068327613475342, 0.022127308221834324, 0.02652122083330347, 0.05544077950499712, 0.055206138265108874, 0.031730122676479726, 0.0144820571726849, 0.004646780519490881, 0.08912309914106324, 0.06108500889592594, 0.07515795213440735, 0.01037353338042815, 0.023893604370495005, 0.04459304344509879, 0.04371265137207605, 0.03753740047555297, 0.013980205422417532, 0.04932704163835414, 0.02490142367840294, 0.05387091979144081, 0.029304104166165478, 0.037910136724672014, 0.009937116072603292, 0.03138456914213396, 0.05810214214087014, 0.05813110409484756, 0.06750812754034996, 0.04564910330959866, 0.015907958431559947, 0.010303496664780523, 0.04783999602941256, 0.05130225762484535, 0.03492464228803593, 0.10805448772565973, 0.007407547372783865, 0.03607791871012699, 0.031403704103262674, 0.030234523695863547, 0.07001033924039334, 0.10760821852712862, 0.041220536710874695, 0.027080961059959188, 0.014547295305096816, 0.05584662607420356, 0.1403660309170523, 0.012747260644250821, 0.044838593777028785, 0.10749713577810796, 0.04408560212581389, 0.056877565915666284, 0.06023707596825496, 0.11097663818227668, 0.04052538852838259, 0.036301260153132106, 0.08924239435263219, 0.03886459034777457, 0.030881615182865533, 0.05367370194665367, 0.027095097297381972, 0.15556262595759285, 0.039240609283649155, 0.0701008755112848, 0.01091218033369871, 0.05881959880371729, 0.043103247580509034, 0.16221928650573378, 0.019730259326376745, 0.0422173090309145, 0.0560840750263343, 0.052624475586438374, 0.05361563248199321, 0.034638006660726764, 0.04558069165796042, 0.03752689741011109, 0.05071150807423457, 0.02763722133221886, 0.02461734869998069, 0.11089875768389433, 0.019954401331262726, 0.04275190433667552, 0.01041697726900419, 0.007575915782757465, 0.06681287210554847, 0.03571875370858658, 0.04310355784611837, 0.013223722325487724, 0.03583210407786312, 0.021099155025196173, 0.04990273373081319, 0.06514515998142381, 0.040985857166590235, 0.03875398640370658, 0.0331602881722633, 0.0391430594778109, 0.08722615052735613, 0.031492736926602746, 0.12248500250279905, 0.0723865524595303, 0.062043511293708324, 0.0454176260128377, 0.047191000813918735, 0.03898133065611605, 0.037606582045555115, 0.05680640400837987, 0.038812783651895104, 0.03220969946273873, 0.03290696587834147, 0.08337705666499753, 0.1018532587876243, 0.08688573169732287, 0.03710353424051597, 0.04387760925437174, 0.0213218912587411, 0.019632925940377098, 0.09342381715654366, 0.07597800329207413, 0.05008058487287453, 0.02161985732645037, 0.09785121547118311, 0.08277344066769847, 0.2723303755685207, 0.18118442126339485, 0.2218937360110783, 0.20057122613633835, 0.375617750950398, 0.2542798272183826, 1.784166191374102, 5.617212595478182, 11.0696062157231, 16.553037551141557, 31.59437010365148, 42.61997615137408, 38.73826134589411, 32.49456190293835, 51.189441065634455, 82.52522499330583, 79.61431641732493, 91.37278203041323, 83.96010644974248, 85.91239560034968, 93.0313797919981, 101.75688835882373, 110.33596700237645, 109.12034603857227, 110.93450500119118, 108.136105691233, 109.4854010305097, 103.71806560024139, 106.7684458148095, 102.01773382002308, 101.94524841923868, 100.5542504402899, 87.68988824659779, 75.38805669353854, 81.95295902990526, 69.62644007898146, 50.63328819890177, 38.798497184630364, 24.079497168141028, 7.717647706308673, 2.3203624063922517, 0.3738470459657331, 0.21433902123282034, 0.20767869878440134, 0.3633129999281899, 0.026941328129220395, 0.11933491790607093, 0.04499559583623083, 0.05837708343601516, 0.07756037322143394, 0.09660808459645319, 0.05838250733851906, 0.054327822290360935, 0.03254595460490354, 0.009560477563119944, 0.011444400766894463, 0.032454962511697126, 0.01730549911547813, 0.08898668952526585, 0.07726088646919498, 0.013678288256238787, 0.016501633480431575, 0.007985937052346286, 0.015219532670603405, 0.05707630444498313, 0.06451646992636305, 0.03032642360326023, 0.053187657463093924, 0.03340337170107711, 0.036411584475107735, 0.09870340401727347, 0.02098726213819558, 0.04552372535991092, 0.022748297178036263, 0.08776612760078523, 0.03843270061958221, 0.0570013465720319, 0.08281888500336679, 0.017233567289827813, 0.055934603611427935, 0.022239974857638442, 0.017890799865727464, 0.03591294167563319, 0.09594220097266859, 0.033041778200816725, 0.019923240704942616, 0.05630947724585572, 0.13719859442883922, 0.06039113241938814, 0.11725978490205542, 0.06253099602256572, 0.04886745400125942, 0.02290261218384389, 0.07700436192774966, 0.03913972316490066, 0.04268838032599419, 0.0639241881999037, 0.03692322778665731, 0.03265403428926103, 0.03887043559863683, 0.02050236295608263, 0.041522639653375076, 0.03551670567943685, 0.02854726675357069, 0.152334270157641, 0.03443744484215014, 0.03525322889007869, 0.2521704041188763, 0.1197589705547979, 0.11704450653445338, 0.2787724395673121, 0.18984755801577724, 0.14261079110926198, 0.17608930837483178, 0.10570022292555341, 0.3016451590003506, 0.12143628176061377, 0.19249380956734383, 0.10959216408551702, 0.14952571521843636, 0.2821021334778878, 0.19733914714907447, 0.11139397990078696, 0.10310644839680004, 0.20857756506771813, 0.14384609256540576, 0.21612219812889255, 0.20511326950884637, 0.18326263394086592, 0.15976697777307805, 0.11714033647290162, 0.16315734584725675, 0.13739737892343154, 0.21315003745257857, 0.10199240333731137, 0.12214116692062348, 0.07629835061849126, 0.12680243655678727, 0.224575013102543, 0.1883837478535791, 0.058182010637416, 0.07370181051233123, 0.1421417920820175, 0.0844551645399582, 0.10038508192425775, 0.16931421063359708, 0.20354334084737688, 0.11177485583410149, 0.11081845634767126, 0.11006107884308985, 0.2177901094358775, 0.12666177515301014, 0.29424919296176205, 0.2563952870907322, 0.14008014222546933, 0.1468109447629221, 0.21711089588221044, 0.14200532117918616, 0.10207085840163693, 0.2013469208031893, 0.15243752348807552, 0.1301045436412096, 0.2474228806433178, 0.21116301988161382, 0.23682114307678517, 0.1448904236237849, 0.22859931893406377, 0.1716269687899659, 0.27643084586147343, 0.14340050518512726, 0.12725838144580204, 0.12506632810278287, 0.23326962074685484, 0.09880612874704023, 0.10543550124331828, 0.2144116770115591, 0.38645032613027486, 0.2856813881906771, 0.2853219397366047, 0.45551722809191675, 0.3138054871270734, 0.11834224415642601, 0.6940032794110237, 2.5566643716827517, 6.761326299559686, 9.95652973651886, 23.583054542541507, 32.6490052284733, 33.141874574845836, 30.495365127440426, 48.470383459521884, 80.30553217857116, 76.42560205151959, 88.0467454848751, 83.81354316588371, 92.56675151086624, 95.16411366001253, 108.3315730864002, 126.11834510680168, 126.56909604226391, 134.21688633580362, 121.4395066230528, 123.00799969703921, 118.79577421372937, 115.51187176858227, 111.42490325435516, 104.13041653171663, 103.03143901209678, 82.26928249482187, 68.87504731455158, 74.77244853973389, 60.47851970118862, 41.331387335254306, 28.60235671843252, 15.002285357444519, 4.094028535389131, 0.8913426870299924, 0.1954751326552322, 0.6940926971935457, 0.28442650552718873, 0.4062993884567292, 0.15875067021096909, 0.2996061087375687, 0.1267049901728188, 0.13677032063564948, 0.2376967509307208, 0.1923398871815974, 0.22244063085846363, 0.10820201327723843, 0.17732980390710218, 0.12556376431377667, 0.1332828279344305, 0.11118599469022405, 0.0993385292108982, 0.17616915005830028, 0.1886985487034244, 0.15920391847049037, 0.09414841375884511, 0.22692710221294435, 0.09759042381999955, 0.2766219694768229, 0.1985854955930864, 0.14744840652471589, 0.12095335525490584, 0.09205236655449675, 0.12694754893140447, 0.20901783579780212, 0.17519509990609464, 0.13597789460853224, 0.09614634808273086, 0.1309988133969807, 0.22975632620434608, 0.17913881328798112, 0.17275901691567513, 0.07102126886527385, 0.13090836905664013, 0.18664079057353158, 0.05681101968812366, 0.282055095679337, 0.1845788496035722, 0.08232072866972416, 0.1172044580321639, 0.14053711367230262, 0.17472322038825483, 0.1709253241818759, 0.2782153404287754, 0.1253435676617007, 0.14965686947107315, 0.08648355085883411, 0.13386692401141892, 0.13670053002574753, 0.13997331892530765, 0.2270083075329181, 0.11453167685577947, 0.1281761471182108, 0.10369105009181846, 0.26071835189096393, 0.10238634873061411, 0.18753156696836795, 0.19808511760446335, 0.3089888471989863, 0.10781119352266674, 0.1293778939232711], [0.024437362087830424, 0.02618572794862332, 0.0663601141422987, 0.0118105496174746, 0.031560953225820296, 0.04012281315461282, 0.05875171958318642, 0.04107998255940695, 0.08352268231852401, 0.020729954271847685, 0.005215700873504243, 0.14678875885663495, 0.009106782099772847, 0.027865195691946055, 0.056582273494812756, 0.07704845794867124, 0.019661924283530925, 0.04700902045794553, 0.04590640926072675, 0.028271990294958797, 0.0499647485482837, 0.027537622241183158, 0.026034230231157234, 0.07217820718764298, 0.03257198627257059, 0.01034523600772504, 0.03286444033766466, 0.039000961659175735, 0.0585647443339469, 0.05011585939134802, 0.026173114310950044, 0.019752525671895955, 0.038070095883261774, 0.026073953805250988, 0.04511718165069338, 0.02171455536999049, 0.00828706993601255, 0.061251606206379594, 0.01954233221289131, 0.020760540332224582, 0.07205450697050941, 0.04404113838268865, 0.0810005599933286, 0.014730635467135619, 0.03930297267112521, 0.0029422413518336876, 0.1351884716460782, 0.06457539740949869, 0.0333012483503309, 0.02773073960035559, 0.031667008522837874, 0.018009880572677623, 0.09223940692120984, 0.021039953665627588, 0.060434772617994785, 0.040731508314849875, 0.049528043957487236, 0.0303606370899586, 0.024850923162434372, 0.05171120301970551, 0.057527223797214616, 0.05067664724324019, 0.034074035713509206, 0.05032631140502711, 0.013092197477817537, 0.10879060629034236, 0.05656358094946031, 0.10515598640326532, 0.0652229025839798, 0.06528390616539025, 0.05299794344952511, 0.008928170615446665, 0.07553502827161744, 0.14749904493651084, 0.03993666911077115, 0.015977432072583227, 0.07020982087499673, 0.035307475575996984, 0.14729096013451778, 0.36223554322796486, 0.2690408859522112, 0.1522371761741177, 0.20036102693167426, 0.3715848496123668, 0.08098185212621767, 0.43255383449216045, 0.6749471180861997, 0.7195859582674119, 3.0634046898734186, 3.138802205362628, 6.954641294094825, 8.992673946965127, 8.972052085784174, 6.819893660083895, 7.858887843547329, 4.623622788536934, 4.559660698136976, 6.036650759558524, 2.5995996161814663, 3.0849441405265563, 1.6740521452119275, 0.7840838812051282, 0.5201491857728651, 0.5070054458995019, 0.06503143422906438, 0.2492943261900256, 0.20825436789422266, 0.14206285438229962, 0.061115437908278364, 0.04265296025081508, 0.11345756795978355, 0.06260434128043633, 0.02728727619884716, 0.03894846548416442, 0.047643099941553614, 0.1767244718728527, 0.021752970848953532, 0.09122555850133782, 0.0868309181063406, 0.043776209856713974, 0.07576221164556281, 0.011182341240196219, 0.032002936162415056, 0.040988576778721426, 0.008272272947755071, 0.05789830529641721, 0.05787352618250636, 0.04789881242979919, 0.06836789269601146, 0.03296972380109853, 0.037671113461856885, 0.039399645306290164, 0.03360223280446183, 0.034071511453798706, 0.005238828110328365, 0.1155615441741482, 0.05939103144731733, 0.006926010837853556, 0.044570256159791065, 0.0329306494865206, 0.014948579820714172, 0.02244253616569744, 0.0771688103615757, 0.048887130969594565, 0.02189597456655916, 0.09058806609602706, 0.030870175574936216, 0.04940104190140002, 0.08587594354344953, 0.029767953167339007, 0.014328039983557838, 0.0021883227342304086, 0.01340380182579881, 0.04271281853077873, 0.027847694413315867, 0.01751461813616897, 0.04072121975402679, 0.06578688885295583, 0.05647352348352152, 0.05277377080112215, 0.04861403594634706, 0.03065585481723951, 0.05839802061898574, 0.06386973083980622, 0.046953096039473056, 0.046837945363574454, 0.0433228237013663, 0.010097336658697215, 0.07247646053832385, 0.01882142623916509, 0.008193088184681632, 0.01884831592530733, 0.050160005207984686, 0.0282104600281004, 0.0557592231029224, 0.028689856783697204, 0.030138379661366347, 0.05263916915282608, 0.02425926388241351, 0.03921297266178074, 0.02405952177791586, 0.01857795775116932, 0.023093463837980263, 0.028829771251748168, 0.0281043108853121, 0.08431382131792846, 0.008186638681969095, 0.16253833148267963, 0.019285547201551737, 0.009944880373715874, 0.010810651658703724, 0.04921769790892159, 0.028294934628290996, 0.05455547680837974, 0.03668403598449884, 0.020531501110282638, 0.025706932572047078, 0.03552147840720511, 0.02674001171403835, 0.049477708150422385, 0.011910426415382855, 0.01285152999879492, 0.02435781726343257, 0.042913751901998635, 0.04785826339596703, 0.07860466597541686, 0.0489475753068203, 0.02858432817212757, 0.01253421159250842, 0.04156534905515371, 0.057826181948785825, 0.020280798837061853, 0.017399703032307087, 0.043990281635835286, 0.01426864805961809, 0.021627679084157272, 0.05582506452957469, 0.03408869480594032, 0.05865990011502178, 0.07216745897406532, 0.038466439131767526, 0.024493008799430345, 0.07240019648546174, 0.04821355965348983, 0.05610346854213746, 0.015505945174804619, 0.04927682840535718, 0.058749448132490924, 0.07439476002248065, 0.07390564352634453, 0.0789731772496335, 0.02931220171552512, 0.00529583893723846, 0.022690884633770874, 0.09973927746496855, 0.09439898579711876, 0.07485257416603065, 0.06963542347112972, 0.05740090738981963, 0.02520648755073067, 0.08258530479525367, 0.07889896631240845, 0.12827186980434965, 0.1303968368278396, 0.03294591378841189, 0.02802691302232204, 0.07022770902802868, 0.030245559192412806, 0.08551103288247701, 0.060363974602472406, 0.05406123518403019, 0.03266675517924371, 0.05084106886398889, 0.16681630434768815, 0.3010230649623179, 0.3862837173285023, 0.4963249544943533, 1.0515161050904183, 1.4140795339499752, 1.4331503428759114, 1.3914383875746883, 2.8175375346214544, 5.583075717572243, 5.54819506022238, 9.154306977025925, 11.283025318576444, 19.304919512041156, 23.9409061016575, 23.638940472756666, 21.676527684734715, 22.89449226471686, 15.936434095905675, 15.904184368348892, 18.358167217623805, 10.873384744890275, 12.44584039334328, 9.328941683615408, 4.176918758500007, 1.5664829818471786, 1.7291699037436516, 0.5409709039715029, 0.6459980650294213, 0.48202209294803683, 0.25748913807253687, 0.16661896009839353, 0.043428857930965965, 0.1461189222191611, 0.08024522794350501, 0.026387086498641202, 0.039196543906244545, 0.07393161390697764, 0.09349187640773673, 0.0665615109967128, 0.01956571130112054, 0.02160786421999576, 0.05369037968076525, 0.07531836328487243, 0.02798918319205123, 0.08254157649653573, 0.022990819547445546, 0.03151817296090866, 0.02622937389288939, 0.0667958036665955, 0.09286449636302649, 0.0434229935279056, 0.0473925355641592, 0.02336582724726008, 0.06284330708665714, 0.0620740398974909, 0.031156366871249293, 0.013874765868569094, 0.0941616747408144, 0.047678355307829, 0.026593215861207536, 0.010349255096497796, 0.041427859255383094, 0.018624980227961656, 0.02198294278294329, 0.01813620272573204, 0.03939367365092039, 0.020377195680574067, 0.05097195881629183, 0.07625240066479291, 0.08869979725850206, 0.022308206478614482, 0.04167082021012903, 0.08538239139823184, 0.023069749586284164, 0.04475816986673782, 0.037392483453356454, 0.012647069750293609, 0.07773588396488659, 0.06378801607136285, 0.10240609847730207, 0.029412948023227435, 0.03769647863302981, 0.06627990473662654, 0.025244759388207912, 0.02966751904046584, 0.031309323986211134, 0.06120304772329908, 0.08635101764793358, 0.021530464441785892, 0.055652441937596574, 0.06654278014696415, 0.027559162718394113, 0.04183316573260292, 0.008624825652899041, 0.03210915233789673, 0.03286116914222798, 0.02379192535074488, 0.020913482125427936, 0.14076173065170167, 0.08464726108697154, 0.12608715558364508, 0.16961531383135628, 0.13748028495859715, 0.097336542281893, 0.13506139298119854, 0.10894418393652286, 0.13262094328961066, 0.1567179171909248, 0.06720556877553463, 0.35044174220773483, 0.1672891184927956, 0.16267841832051355, 0.07679384096615738, 0.1999822883836685, 0.14164001981337226, 0.2738104574382305, 0.16376387297866807, 0.08422926053284638, 0.15041120560659518, 0.11933922332020537, 0.10366301893466905, 0.1901756581519881, 0.2058225290309037, 0.08655566271514663, 0.10471699504001487, 0.0921912046690141, 0.11465720802305207, 0.22899437515485674, 0.12856148934412387, 0.17181105971817048, 0.14384506600758723, 0.09980129228243906, 0.1492092289751576, 0.07611014579813327, 0.12104264280248074, 0.15208691568864932, 0.1396671595472482, 0.11201304023063953, 0.24551709903584373, 0.14497887613552232, 0.16230324974223492, 0.11686112040713911, 0.13614802741475646, 0.11974677443504335, 0.2881284262384138, 0.17206324054108513, 0.18011951308336951, 0.10084886389273791, 0.26026102804368545, 0.09446704504831184, 0.19069207802174554, 0.159199015507775, 0.23360769534783982, 0.124091167123087, 0.117177736885365, 0.1676850633755807, 0.20904486337977074, 0.17133951727901736, 0.12183313062714955, 0.0975180744764305, 0.1679019735104615, 0.16166591055450902, 0.12649387932352482, 0.16023248343938784, 0.21876854161101006, 0.27242218354536646, 0.13893598991055645, 0.12647899423515604, 0.12936704611826327, 0.10240396109199333, 0.19093048458378162, 0.26711947615108184, 0.20213401485835353, 0.12048591904702688, 0.1369641868457679, 0.15570118061957822, 0.2909470475729435, 0.7434616706544354, 0.3768917858119934, 0.3825403359388152, 0.4684822243307868, 0.5671032662353208, 0.36889223441962277, 0.7742049016298787, 1.9923214734561983, 2.435867137485935, 3.5088636125287707, 5.1511565716035905, 9.987166389342278, 12.797957447267349, 11.877136922651722, 10.775977584623522, 12.17246295944337, 7.663336117421427, 7.188517028285611, 8.729859455939263, 4.042946528042517, 4.935214404136905, 3.358668213890445, 1.578705455026319, 0.650078188027105, 0.4873129413012536, 0.1899858062425929, 0.3230757025941726, 0.2984929523400722, 0.30308543494151485, 0.23005749068913922, 0.3514880038076832, 0.28845180727301106, 0.20464633891899742, 0.09564203240217702, 0.09082585978772371, 0.2557078917180338, 0.4054766406695689, 0.24892779908353285, 0.1670754412489553, 0.2972435548661217, 0.19323535203453035, 0.2112185152908487, 0.15022147627126786, 0.27011769913857986, 0.16264886264839482, 0.19287869214050232, 0.25221679840357075, 0.12428283466086273, 0.16891042101046733, 0.18895232298922157, 0.11030507018609394, 0.15641929611804026, 0.16712845453331548, 0.13496111207191022, 0.12136641454191939, 0.1438113428171604, 0.18693574974613805, 0.22164785243090124, 0.15772642597796457, 0.10134674443472778, 0.1733654367947771, 0.12266805155142663, 0.17706535035564056, 0.16719705004605556, 0.11344065273841543, 0.12059029852671009, 0.15199149177680094, 0.17116598304240935, 0.19507525008051627, 0.1147015798356264, 0.11602518058592275, 0.16343957263856165, 0.1360067914450361, 0.16383056859335593, 0.11192117096675981, 0.09964636632151182, 0.16135345393371198, 0.13133743958127114, 0.20677074669830262, 0.121691036638954, 0.13288695966043781, 0.21754021155497721, 0.08893707767128946, 0.13408322127596026, 0.090178209056537, 0.13230002905812957, 0.1840219036826203, 0.11822729266338772, 0.11282243510527958, 0.17853447716803322, 0.16789930752448498, 0.13917477951655466, 0.11275283601735869, 0.22128126403737455, 0.1476302451544231, 0.09266529052007584, 0.12732123895998926], [0.023496895315005414, 0.03784262139590518, 0.03848066155408179, 0.08088288888815912, 0.03236070688393328, 0.027751048591228265, 0.018550648631888534, 0.027355873626807047, 0.02080486426430364, 0.009718810700090423, 0.07747915257970173, 0.04575026138956028, 0.050871930716018525, 0.05890484906793122, 0.027076441141205932, 0.039997776114051385, 0.04588350323179076, 0.05009375775473253, 0.018021391043739936, 0.05758620490650496, 0.02100846362150004, 0.05028134970475109, 0.1046141630579387, 0.04108189394877803, 0.01632337056611094, 0.03718469359521424, 0.013341245001121877, 0.1191544582346274, 0.041666411374124794, 0.041047822188345656, 0.07887350154980537, 0.041012417434925036, 0.02870405239293412, 0.023331724843310735, 0.0027560934775523963, 0.0516556999495914, 0.06123507785941325, 0.015079926552941963, 0.010070476658462037, 0.10982642611188274, 0.06673198088162369, 0.0340852014450056, 0.027238091438888546, 0.08065592001883254, 0.03254844056021783, 0.025225783390323483, 0.06192012900306333, 0.03039816965258891, 0.0404672960810844, 0.05664343029380806, 0.035903622216034325, 0.02690842656809236, 0.03829146848030148, 0.0697193407423554, 0.012928384896968643, 0.019815530658008593, 0.043506286437472994, 0.027077075078963276, 0.06609156968132143, 0.024973642787024863, 0.048942216521789955, 0.06798137835557423, 0.01856432330133694, 0.06283224477703053, 0.01815456393805723, 0.07829531967159241, 0.03401148463449171, 0.06061298382138053, 0.14224832426876793, 0.013036341049648341, 0.04243027764342485, 0.08134427300143628, 0.039866725283284346, 0.09532766056156929, 0.03593000628414654, 0.0856903434220341, 0.15319588924607924, 0.061164222387296546, 0.059077456338150855, 0.060015864249679356, 0.03547508795295031, 0.04210582025529396, 0.03259508765392727, 0.11910856956796301, 0.010561692235510676, 0.04001459557442896, 0.056344705799053756, 0.14026859985484233, 0.15325944390027754, 0.21595525224843334, 0.3174549767807607, 0.23551027470779037, 0.2420109291110308, 0.20390242157924562, 0.2459643564877972, 0.007750976449554607, 0.07788211482787326, 0.1914890699328915, 0.05928133914787924, 0.16956528828990075, 0.09222462142427122, 0.008754955262937134, 0.03441602885422688, 0.0727447138858899, 0.030742545326751088, 0.061341740281110814, 0.060832253507068085, 0.07602555436953422, 0.07801996468896828, 0.04888767872246043, 0.06222776310037702, 0.06332260999648322, 0.08212827972226566, 0.041118221838147416, 0.04575631731460172, 0.05703111674876944, 0.10117657332410736, 0.049238060525948965, 0.03956320507812404, 0.07625094509773678, 0.01601143584271232, 0.003605704616582502, 0.03545545694989062, 0.046183667971842715, 0.04846523868881407, 0.025627527558695407, 0.05111190009742014, 0.030919787428912618, 0.04242951538594019, 0.06580234084638857, 0.01477528402897259, 0.051097432526970105, 0.05636976836549659, 0.03388646291568875, 0.04381344939071325, 0.023991215463367202, 0.07786171390644966, 0.019858291770722118, 0.04514926924340187, 0.021301055582420483, 0.031066148526846405, 0.086371602430459, 0.05944954524297388, 0.014597312228063182, 0.016248537182447412, 0.024236445953588814, 0.028427033084294492, 0.018786098094536893, 0.07692263566798742, 0.03571694191064566, 0.09775464242744832, 0.040469383670678066, 0.038925479015996384, 0.07675159121713332, 0.02860036622282238, 0.021637366265959797, 0.044113640943842555, 0.029464674279874856, 0.06093901168975619, 0.03520890304277982, 0.05942983380068214, 0.026706432165097327, 0.028290334270305695, 0.056470007139949076, 0.12524330973505013, 0.05334762811300255, 0.05769230042313857, 0.047832384945884834, 0.03405139781534672, 0.030886862885146856, 0.0461741263467458, 0.030054085091837955, 0.10412722225150756, 0.04232102201410359, 0.04569959233424837, 0.004086218663536373, 0.006719783320271921, 0.03923919968186848, 0.02907156200718976, 0.01545352943902535, 0.015154513830859816, 0.02146930381235096, 0.029316966782414147, 0.07948125442189556, 0.05610982324146936, 0.05947813181386841, 0.04669972011939653, 0.05870753929259316, 0.0814341044714374, 0.04759026668785561, 0.02922591148695398, 0.07163816882717995, 0.024206160582722198, 0.041194903408928264, 0.04060310814830084, 0.031625871516523824, 0.03450137870987097, 0.06037397204988426, 0.02045891044901744, 0.00532466060136475, 0.023065216260992234, 0.0650545087973437, 0.03867475759057749, 0.04322736148512171, 0.00668171736892433, 0.017096676953857946, 0.09719045697561196, 0.06600292564760293, 0.03372347004891884, 0.024625865682478876, 0.07855596576607035, 0.1287112748550792, 0.014405180249483356, 0.04438841369964423, 0.02868560691093726, 0.103742370321866, 0.04188044101841027, 0.04326348253075154, 0.04796265819740873, 0.04170683783388907, 0.04081948585207424, 0.03719515452582029, 0.050494636243750016, 0.02341637947416354, 0.044009521934053594, 0.04144730256690134, 0.030902247845886216, 0.06216243112219438, 0.0476903101098874, 0.05383017540518796, 0.05861047978302645, 0.08577740931462857, 0.1104066840883705, 0.037634973264028954, 0.05219633585863537, 0.03130642051297811, 0.035641880615824656, 0.09959998735857588, 0.06443960066404074, 0.043254507810718594, 0.0885032037753732, 0.03059257212425432, 0.031410192867981336, 0.048601832165713274, 0.0689054795751168, 0.03445337947097517, 0.05984689206666043, 0.10146850644941292, 0.05800775244771954, 0.05433973878802312, 0.06586574228300203, 0.0511264787506192, 0.09227643961146956, 0.03700616829577954, 0.06732442731698675, 0.05966918265086509, 0.03442967288015831, 0.13692937581048858, 0.18624155151267208, 0.04737438694123299, 0.06616856917859086, 0.09176802536052081, 0.09113053295521006, 0.20511264131674845, 0.12307270685391081, 0.0831018625608375, 0.09321995349901338, 0.05695952200180581, 0.08944304044088049, 0.09045436077060239, 0.15744272829784503, 0.09642692778499858, 0.13556921734444558, 0.14015163355056318, 0.05372987151326192, 0.11722005558230224, 0.14465167998306214, 0.040124904574646104, 0.06530072945620745, 0.12306298519815169, 0.07473353176347672, 0.22945091759245242, 0.09808065114362587, 0.03022732438459512, 0.07765162195409499, 0.09005277748069457, 0.10147121073978563, 0.07697456110749515, 0.07201093955025559, 0.02367505097701665, 0.06407608811353004, 0.031776011343144124, 0.05790532266180362, 0.01947931956589943, 0.031375567609023665, 0.06110324944940306, 0.0384592762096755, 0.027344428273218296, 0.003582223542898353, 0.047909169938535466, 0.06582038987788462, 0.01395350055498702, 0.033472813740973516, 0.08620307074799653, 0.06439876051679735, 0.053505296668698715, 0.04029074728849434, 0.032785487316188314, 0.013818443084375994, 0.052539727109814846, 0.04333538371288488, 0.049887120858916355, 0.021955886472677513, 0.05794677950982606, 0.07096875353806442, 0.006763040474916418, 0.030125593653910106, 0.04573588191922154, 0.024357330797600652, 0.06391353191687696, 0.0853288188696869, 0.03342743069233914, 0.054634380034141006, 0.023276518632267273, 0.036752374857784285, 0.04337929587270464, 0.00992633434267895, 0.047440959981852965, 0.01888108916670805, 0.04069834819904739, 0.07411389686768094, 0.03517018112864706, 0.02635864931489191, 0.06854406227507899, 0.06634233324157615, 0.10867787645228448, 0.030463396293681957, 0.04081564392113397, 0.06437907205714334, 0.023143031641901023, 0.028300528985358057, 0.09968283210670757, 0.033432306841977184, 0.06087221265319855, 0.051064981042497584, 0.016704361412614104, 0.014938721226738587, 0.03794361093652345, 0.10920038672103997, 0.028790135777765707, 0.027647971461016326, 0.014129778343973862, 0.14071352839950593, 0.09677445591096917, 0.14692929002546495, 0.1081908054109062, 0.0677403134684409, 0.07379217824387936, 0.10730822615685964, 0.20452036342072874, 0.11996995883002398, 0.09350517569410224, 0.2048805932844839, 0.12373990814892516, 0.2180907989461576, 0.17498733686102977, 0.14793962210176453, 0.19148756840055992, 0.13865488160762096, 0.1268542700657441, 0.09714229302781244, 0.10576099668058658, 0.18071336912051325, 0.11081940629669737, 0.28315571887839225, 0.22296278106589473, 0.07581479592068542, 0.13358644390058133, 0.10959047103120435, 0.20788165079730175, 0.07877127477718938, 0.11580646248354066, 0.17807231164507328, 0.20097976550459865, 0.1423047849487874, 0.13866108691980764, 0.1665918252641155, 0.2543600213022963, 0.13051611671765007, 0.15548894362103555, 0.10914169672516086, 0.34760927000353414, 0.1530495511307832, 0.21232604860298096, 0.14818545971666613, 0.19121015264141947, 0.12378083256584023, 0.1754338282250589, 0.2514303172187459, 0.10851902812118493, 0.125160166212628, 0.1571848937460492, 0.17153693813710444, 0.14465068406876058, 0.1589070440780732, 0.16722587027376698, 0.16820871511534338, 0.18898279796684944, 0.2528842448467209, 0.1332293856408327, 0.19928960700429257, 0.09321564808487894, 0.10422951031115749, 0.2957891216201167, 0.16051244261043687, 0.11121076997369529, 0.22187528861386163, 0.18085391561110176, 0.0899104843096387, 0.1073672991967009, 0.2316267758367523, 0.10667101720408087, 0.13765559651918952, 0.20905811670086077, 0.196668345240816, 0.20459930112044658, 0.17098443552611337, 0.13493210798309696, 0.14922577647432206, 0.12305492595318826, 0.12428874119875893, 0.22402015094074512, 0.22412475258592637, 0.1561983257171608, 0.32382974761628336, 0.3433359089878298, 0.22587633601600127, 0.13444751140571412, 0.1559039181278598, 0.2898486919941441, 0.21743881215731944, 0.29508674156761944, 0.47640305252805837, 0.35556086429184486, 0.22299765338820798, 0.2759052176148661, 0.3865824303319378, 0.20230796278244068, 0.30643121669850043, 0.2443609804275536, 0.2713528167336218, 0.264393612742424, 0.17384882295323958, 0.09741628437393135, 0.10915365535765888, 0.19004154679996355, 0.18026649471252196, 0.28678142916290994, 0.19403453495713974, 0.11122757028187476, 0.2601287706244377, 0.2005030136675604, 0.3281502383610895, 0.15784912261991732, 0.1504168133702009, 0.12813382842127355, 0.07649398649171477, 0.16670391924919623, 0.14179936610162258, 0.15659422463467046, 0.24097908528581743, 0.15419192612171173, 0.1508838971776347, 0.1386962656772906, 0.15620393348076653, 0.12072925921529533, 0.32639730661626787, 0.15570783026276097, 0.14613281905410752, 0.1557556035057191, 0.1613538522994326, 0.15080062342026543, 0.1611208849616589, 0.11324926099229245, 0.12717775835265077, 0.13790269051828694, 0.1672516567932983, 0.22502769445700033, 0.1463501581982259, 0.1924012814678492, 0.17451400177613383, 0.0896377646694741, 0.10113081489239009, 0.13701755253057327, 0.11749801526386892, 0.16409258598521834, 0.2164076118459625, 0.1379230684570728, 0.13199584618691476, 0.13594501411482213, 0.12144951975994533, 0.15194528135320834, 0.14821418801382666, 0.14157877874470529, 0.13353957464137386, 0.17206759192049506, 0.26760352114515923, 0.12988495219859386, 0.10848074670760863, 0.17959671936208205, 0.15677967919938027, 0.18900472340324234, 0.16737603882868446, 0.10560707429484015, 0.15126001570493947, 0.15263212514260124, 0.14607729300135566, 0.14602345234203726, 0.17670014092037756, 0.10465954610657309, 0.2360140847703142, 0.18938113304395832, 0.13126938033007807, 0.13564954932418563, 0.2471041267797832, 0.23629171503407342, 0.15035426995206266, 0.11441780554671442], [0.048478323470560775, 0.09766623588098634, 0.03375332449532805, 0.017921173336705374, 0.061689283728839896, 0.019361330534241373, 0.023961918345922907, 0.014323705841126222, 0.02774079258914196, 0.005185804292259197, 0.019519251898952553, 0.011751344427466394, 0.023537507551091335, 0.013046507994013449, 0.06459060425479567, 0.017590589160400055, 0.029258705795772617, 0.0046333490829584345, 0.09055900072017986, 0.015140994294216076, 0.05453631694939348, 0.03713292520373099, 0.02389492012650496, 0.04184395225057679, 0.03957960319014327, 0.03976436827572123, 0.020266624295242855, 0.052461180114938374, 0.03388677318129809, 0.002004021490950348, 0.037215003863938396, 0.042013636895365296, 0.025368884784139456, 0.04329519857081675, 0.013448291424391492, 0.032126707242681615, 0.026082112641644575, 0.08193897173529671, 0.041226366639978466, 0.015698464985396114, 0.03384629692581873, 0.017381814879275138, 0.08549879079744702, 0.054342856765874935, 0.06636638074151932, 0.06516107928849037, 0.09236711377818739, 0.06510237397085275, 0.022083633549271092, 0.04704745125866706, 0.036260040792366194, 0.060572404144031394, 0.0476237332388278, 0.012123411307261597, 0.013141675266407192, 0.0412413704719755, 0.04205846069981495, 0.008024541180460684, 0.06789571440388119, 0.03867441668145118, 0.012508932606226975, 0.027374259736989776, 0.05664480925207177, 0.13697138807225612, 0.026625140660232114, 0.04066441816488101, 0.07153424133937206, 0.11598087006038237, 0.0746425205180722, 0.04206213792185149, 0.013804458149318254, 0.012445322410654158, 0.05962389536322125, 0.17163018635924787, 0.0902030149835252, 0.019735154628212896, 0.014624941189052358, 0.061215841391634565, 0.06071618352566035, 0.12953023816789352, 0.031217697955247377, 0.020531924373860803, 0.04189471323643962, 0.061479433094181364, 0.006942751774218895, 0.012801916229598706, 0.06301869525604191, 0.014950611868933325, 0.0675776806629954, 0.04945692418503666, 0.03263636064084788, 0.11531028265674269, 0.10958124733259601, 0.04572034565611713, 0.03585090770596459, 0.0446346573411457, 0.034898235237285975, 0.07549777341585967, 0.04231831772373088, 0.012404593346159787, 0.023555460821596846, 0.035325026650342255, 0.05051687194575226, 0.043546498392618475, 0.0782851690065957, 0.05804360919301549, 0.05228506033158591, 0.07270352133820135, 0.047654736817123435, 0.027867647173303752, 0.055869700642482895, 0.041444157775972164, 0.02245940925222972, 0.026649753150019436, 0.04847628184624257, 0.09589675663700027, 0.0328715879379982, 0.022606925227709358, 0.14642877414101554, 0.06425649798925846, 0.06116960415496461, 0.044686961994175954, 0.04485850057174121, 0.01915182272392896, 0.13765800203527176, 0.04259910426973816, 0.09263591104817968, 0.024143197731445395, 0.02680444736934958, 0.033993604142339, 0.049840657626308744, 0.020357664268944534, 0.033564755783206036, 0.09809795706983536, 0.006895655082658895, 0.03933234448214212, 0.09271318633710185, 0.0290766698984249, 0.057610815481072476, 0.006371242043021466, 0.07184176435393673, 0.02820491355152861, 0.08117652272865658, 0.05083992356254209, 0.015236045695811272, 0.02371137886638603, 0.02622631145641208, 0.07431716297663028, 0.022611039119862744, 0.011016051322522183, 0.02845189263743739, 0.025548292999906887, 0.04918063840558452, 0.033936909805502624, 0.051178193515947754, 0.08561787150439717, 0.06760204225898751, 0.056911243140817656, 0.01203146830741917, 0.0230274117371488, 0.012717740403698578, 0.10912255984881233, 0.03521585912113229, 0.07854738558131842, 0.04356804078504924, 0.02741439125290321, 0.049880183932761994, 0.07533327901675817, 0.022386630899423075, 0.050155393358680515, 0.04274839565398232, 0.04417490116470764, 0.06126755232652349, 0.015037343555670834, 0.06991372023138308, 0.03667536003875636, 0.0275150437148348, 0.06024165717404216, 0.08562137252621113, 0.06494865076796663, 0.02582163125607035, 0.0189039702977865, 0.024759791258181778, 0.03469785727981118, 0.06307881783633944, 0.02208032021899858, 0.015452336257083282, 0.03741145945124088, 0.026888389538432804, 0.052744464107578805, 0.07255694573564876, 0.05119418943180673, 0.019810510866884744, 0.026947006755959124, 0.027707726319110202, 0.02552354452951301, 0.01878155136270629, 0.02296308333414697, 0.041870642753858725, 0.010415512125849003, 0.04466080009156177, 0.07052118965094128, 0.052370417848109245, 0.021751231829365416, 0.04990065380209877, 0.022640050869555246, 0.008360868143368392, 0.03662022852128552, 0.014504856906921394, 0.02095768539865892, 0.004562786160667818, 0.04478405214725964, 0.07267586556413481, 0.016666767562949852, 0.015988886044661126, 0.017690358705998912, 0.054753548841202454, 0.05476599010909277, 0.09186924089707675, 0.05584665288728091, 0.04826102646127824, 0.05658867415942012, 0.03320464083263951, 0.02457488827677744, 0.023610919841655323, 0.03670294686490971, 0.02269136726916317, 0.04004408612907414, 0.04432290935167863, 0.010337965833323618, 0.021475407617887663, 0.03882235975094861, 0.016954609778739752, 0.018298676567933252, 0.016533131185438366, 0.1310462955265276, 0.05635782122431744, 0.02012927622173823, 0.09241121745998822, 0.04655481458851888, 0.09235490999755361, 0.08361646680221443, 0.06226833894728653, 0.05933925539495484, 0.059854798094039006, 0.032407737021604856, 0.056287440726713794, 0.020544934462034897, 0.024805833142431035, 0.020857408319810228, 0.019771110964938998, 0.05618161717129331, 0.08179279449846476, 0.1348189108314053, 0.04863302343555036, 0.05976139665431073, 0.04212742393475868, 0.10737962555140258, 0.04782067912240182, 0.12589619284675968, 0.013517808157860512, 0.0347793115783603, 0.021262278126913215, 0.08954011910264531, 0.050410148237020745, 0.05432966473181883, 0.14571263514939817, 0.040528200071064696, 0.06185843594252102, 0.0528073714174811, 0.0345231662504375, 0.024406963718994975, 0.028213966795573794, 0.01887466743468277, 0.04156146115893799, 0.016900363092821453, 0.04082228973387711, 0.02388547617761839, 0.08133416830171501, 0.04532889004856829, 0.11240977418398666, 0.08465374219081095, 0.07785900195519771, 0.06332463629904293, 0.018361061022827224, 0.0785310985520482, 0.02269324609979747, 0.049494355241017, 0.023008994983449098, 0.05223229985624071, 0.11642581392680446, 0.014781260472391883, 0.016024631707208054, 0.01638483380027596, 0.04328768707871918, 0.030048251332294558, 0.025954059129881284, 0.03541227640403855, 0.03844231119259231, 0.028300917774979627, 0.027732721852859663, 0.009991581093580013, 0.036124044864047924, 0.09626147577599173, 0.027339693849846244, 0.0825191454421128, 0.032378533749931285, 0.06561682499464482, 0.1251663255595392, 0.060007314708444386, 0.04827594219316398, 0.024644140709912585, 0.025879717957709106, 0.056388181288756674, 0.04474135423679987, 0.006720002612940246, 0.014900624631874025, 0.03894950736374144, 0.12415587090917173, 0.041994423410224344, 0.021567914649964343, 0.03546460787014615, 0.017149851116682255, 0.05444111903348277, 0.014909145444811834, 0.018363880226388574, 0.02110644052135608, 0.00841244405526067, 0.014523280363890433, 0.02369463409958107, 0.048188700100346926, 0.06725843650318923, 0.04484825414575396, 0.020405378140088533, 0.04622643483021567, 0.05494882465310155, 0.018582935407457334, 0.06013353535484883, 0.04582283289862737, 0.025782200710607633, 0.09039187097861882, 0.024817682607399843, 0.06420183378542144, 0.051001587266763376, 0.06338875019742597, 0.010124618964900654, 0.05598408140001759, 0.04414750203009575, 0.07590249766625705, 0.056348199159988475, 0.04395751605531381, 0.020515677564206625, 0.1920083243279688, 0.2840969038586463, 0.15645711021798273, 0.13395546845370723, 0.09807970885547901, 0.14109798196342685, 0.07972582033084286, 0.20763877028178787, 0.2099375396726593, 0.11935125856149582, 0.10503282244767874, 0.1587579020809743, 0.14466836537805297, 0.14425807932932533, 0.1313592271218377, 0.11619903657945896, 0.15147821286753302, 0.07302608265871964, 0.15629765667742299, 0.139421965446203, 0.1413688093664185, 0.10081966828194358, 0.09348630694852722, 0.1382352339644586, 0.14731817157758823, 0.21342608957521378, 0.14677855456548353, 0.1872803667379964, 0.13103201564761902, 0.15418034287229662, 0.1187214500180656, 0.168172923487521, 0.11588402888587407, 0.145142681055492, 0.08403713334231608, 0.16350648275786833, 0.10201523275745493, 0.24881545995031637, 0.08432610936823391, 0.17042571228117714, 0.21666391422190975, 0.11318438100598513, 0.23433077509605119, 0.2139473817641697, 0.16734078346240908, 0.1632420292064067, 0.2157388477315826, 0.24515434108193845, 0.14626325318409553, 0.1497128398548211, 0.16002865808625377, 0.1976201022344251, 0.14791279370265623, 0.07925196430615841, 0.10471003130078317, 0.1822763110601133, 0.15735165576540655, 0.12114632514215286, 0.10799687791375384, 0.2572554812556313, 0.11253900555593353, 0.18523434507510356, 0.12152937676517234, 0.29972831508324993, 0.1683524485316969, 0.12329839635640384, 0.17985156617097317, 0.1689864782195899, 0.2934202858276906, 0.12041909319739189, 0.1784284352775543, 0.07344522468385196, 0.14264523442233765, 0.23906452431073114, 0.14319035194573865, 0.1225654953610032, 0.2508360321723646, 0.15504655848828056, 0.2106649708002806, 0.226548440273731, 0.12284203777990996, 0.30208719173266046, 0.16388560434983623, 0.3102250373171222, 0.08095372137763808, 0.14170951930986297, 0.16896862837095417, 0.14420502007968966, 0.19594586304118558, 0.14635374348971153, 0.22362173925484383, 0.18844886532714292, 0.19975436190443657, 0.11294569865229631, 0.12120417244131527, 0.07717472456035114, 0.13067580008458707, 0.1948980692653887, 0.13822343621042468, 0.13567977915367774, 0.06666235115018583, 0.08857404392573143, 0.2789087419308001, 0.17768312365778033, 0.29732923413957324, 0.3333033134620036, 0.22487262293936747, 0.3152556915677363, 0.1416419963202169, 0.14336569414984796, 0.174622954800725, 0.15898549148151953, 0.1259430161406917, 0.1642986329933328, 0.15706135440737973, 0.2906436767549284, 0.11367515991291693, 0.16437567079499846, 0.28749723107584063, 0.19090376343698273, 0.25074770223469506, 0.09292763732974568, 0.17050820462886365, 0.08310462047736492, 0.20133814143557704, 0.1335975828190004, 0.3465774108565623, 0.16947118204928216, 0.14075714944591447, 0.23205069825053218, 0.07071966004948463, 0.120991000815505, 0.18252861445709584, 0.2396633445976242, 0.16899462939510423, 0.19529865664099494, 0.17837842505785728, 0.1303468878951765, 0.15032082255328857, 0.046418860795036446, 0.13424347154796124, 0.2162964371663909, 0.14574075057621927, 0.1724420097326079, 0.14270264505138322, 0.19061675625703028, 0.12340952507069997, 0.3050448120601716, 0.09528284441799888, 0.11234761380981054, 0.10702083593294506, 0.08635738383858435, 0.1433371190702723, 0.2252545024478628, 0.12522274793516244, 0.25948697280499244, 0.15779701331930776, 0.14430542356304585, 0.12193912655235299, 0.15808443418673931, 0.11206493502663029, 0.17813364464429118, 0.13479064218699932, 0.17014288794129126, 0.07188254321414618, 0.1332355449877439, 0.3363337427858384, 0.16490114582402093, 0.17891638732004553, 0.12037813813695986, 0.21691713692440143, 0.11388241733995177, 0.1670751041702686, 0.13409017735431272, 0.21403419484774913, 0.14449210386843453], [0.027701478872087695, 0.1247144409365231, 0.02467517876216481, 0.03433301556675184, 0.028091760449892575, 0.017072014668355548, 0.06921399850398302, 0.043047974336772196, 0.01785005739469442, 0.025089329724470456, 0.04188494561540504, 0.02009694731133359, 0.07416436674013253, 0.05573902136435913, 0.019544563443970778, 0.02426494250915224, 0.06063441130062265, 0.058371452689771695, 0.030704869122634974, 0.041958834795701894, 0.021332587761383866, 0.04851799533371964, 0.06373101529935676, 0.051127765778331995, 0.02951440487747952, 0.031359338036347786, 0.061092558692419724, 0.020076954331729683, 0.032657926015916376, 0.025310156483864112, 0.02535614091151905, 0.030642727900656964, 0.038503766765878085, 0.019673917389985536, 0.04038210710390441, 0.044725270220829595, 0.025744888398255554, 0.03880577777782756, 0.0486050229219179, 0.03238756975699817, 0.03317962040103251, 0.007661738218889842, 0.058819640938553124, 0.051164917212219975, 0.12437624376147025, 0.02361671146636288, 0.07291732115610954, 0.04813705811337118, 0.04396293995781772, 0.027129061805504947, 0.05501740101364352, 0.052201652508829875, 0.08104469431864639, 0.016529091986857595, 0.027776208833881447, 0.03948711722548451, 0.05215878605902676, 0.013278914172382606, 0.04335946185634502, 0.014663868989314766, 0.006306932313412789, 0.03017204347997904, 0.023735813240730957, 0.008837420797546305, 0.034234963973323186, 0.06437321148452259, 0.0334059112825461, 0.04275682645158903, 0.02984985179688421, 0.04634219454601408, 0.02627023702277051, 0.044111982363486485, 0.10479106042053431, 0.11653278278367174, 0.08309631608426572, 0.05984048757161345, 0.037659254420789025, 0.05180180823851017, 0.012271028789391202, 0.07216655499031467, 0.08514713345756454, 0.04502441606394226, 0.05858022314045699, 0.16825431266859656, 0.056021137072915034, 0.05299674452192361, 0.03512910349414714, 0.07375878447125997, 0.037937137493563276, 0.0742522906512022, 0.03416489757176849, 0.05853615393261275, 0.034740823321044445, 0.0630284820292746, 0.027254439755192688, 0.08928760120104398, 0.00924685744628791, 0.049096675169083386, 0.0440684762302666, 0.03920268027051803, 0.05153051735232434, 0.047256554957599416, 0.022357167157855247, 0.0447006251723055, 0.08795741209459883, 0.07394669051732748, 0.04619119095525915, 0.0029071897170656635, 0.021231332005211906, 0.062010898930771705, 0.06381586336741044, 0.04656761974817322, 0.07857234472589147, 0.0512483058827779, 0.01757597411802459, 0.04596371646790255, 0.10430260276001307, 0.07056158546718859, 0.028439026190749103, 0.11858193008529565, 0.12355541885499993, 0.0365063801948582, 0.05139797648054458, 0.032351912194562536, 0.03888801731649907, 0.07698190022980975, 0.035183055236214594, 0.02093692633113073, 0.027581819768754706, 0.03939714402921739, 0.03083528410042486, 0.08916826768507881, 0.06536737910561985, 0.09254654689181237, 0.0347323312364038, 0.03297123682474898, 0.022608097342233506, 0.005941626159549361, 0.030563857233632478, 0.04591284056885108, 0.044813837645755666, 0.022879353754462737, 0.019410521039859425, 0.010961404355663446, 0.008805645385666961, 0.04336601956897686, 0.04075372103421439, 0.026414456904955932, 0.04156731790111911, 0.06356340675284305, 0.023351447776921337, 0.07775681348697794, 0.017993645254342307, 0.031525278426406365, 0.01899981364277342, 0.035415493973320535, 0.05186545482325939, 0.05601181761331617, 0.011332752070419732, 0.011591023292332407, 0.021888237078523925, 0.013820816999331359, 0.07000231063894688, 0.03407210517194002, 0.035000327944515214, 0.03213303321371636, 0.023978080885905414, 0.01650523217845588, 0.04395586513583699, 0.008582703265992385, 0.05128212100375564, 0.022927253401928374, 0.08011658645925984, 0.021371242642823248, 0.02157992116295763, 0.10886782795310983, 0.007669745752918384, 0.055516174048065185, 0.04296948479849004, 0.0512922793296316, 0.022004623071200425, 0.1276960168334265, 0.06214739281624075, 0.06313629358285858, 0.10795756228147976, 0.0321731838818279, 0.029700361229779742, 0.04153295119683589, 0.06655312233394192, 0.060491892133629134, 0.14161349784943367, 0.05344996213792794, 0.12122317908271668, 0.04554838189975389, 0.02405891465323587, 0.04824239520295974, 0.014062904613843609, 0.06510566814892715, 0.03191533400827358, 0.01932341301242911, 0.011553765563744933, 0.007386471815181957, 0.04027361373206781, 0.022615884625983816, 0.015846726938992018, 0.007562351717253126, 0.05414131435475523, 0.015112711285661547, 0.04552394752540896, 0.019075570162385702, 0.010962953768490304, 0.038065146955270926, 0.06394929673162199, 0.04019657593040217, 0.025989902468638557, 0.02953617326584795, 0.04379905842905564, 0.029972299460261583, 0.06053102007436176, 0.037829965623396064, 0.010443288558763603, 0.050900383221526305, 0.010696057354160135, 0.04087599249736917, 0.018393998973131664, 0.09767063322567171, 0.055350584143231955, 0.029017378523525213, 0.027069672754394914, 0.06212854322286383, 0.016446712637139906, 0.05285856524302114, 0.048129347438413295, 0.02566760927889376, 0.021697132615372542, 0.003455882477048304, 0.04406522801746765, 0.024184386448694334, 0.009857146069407463, 0.00933057553465328, 0.028777403396464167, 0.02776669019142226, 0.08476025139492366, 0.034462461443317514, 0.03456263893073605, 0.07380646578366719, 0.032111356755898844, 0.024816156177210714, 0.05756539412804189, 0.010691508707109719, 0.04259899318698914, 0.008509129139354393, 0.02681585633376193, 0.10303175482418268, 0.13155476340363104, 0.07422603681803712, 0.05591641668410552, 0.029202302572347467, 0.09603598545635901, 0.1011476764876035, 0.05302759488263438, 0.06843853366350935, 0.09052437354600237, 0.07669899162025222, 0.05441936596687283, 0.01471172362911485, 0.06965753276862445, 0.0941490036465468, 0.05495537087441452, 0.052045519959421895, 0.018392122057717175, 0.05586263731182103, 0.03607951600344912, 0.0755139225493035, 0.022525164493990522, 0.09833028089375266, 0.02002833456161522, 0.015684707961495847, 0.04277938774095909, 0.06918111801027291, 0.07439921865419996, 0.051173665936315255, 0.055708121207933274, 0.06701583944020734, 0.007112840051582504, 0.07216666990350332, 0.0543125503275904, 0.08102781740167449, 0.034276937930694515, 0.019458323011114713, 0.015444469491710827, 0.06498006037286212, 0.06873860264257078, 0.04613686766054842, 0.03968947168980395, 0.05096432091968675, 0.04750718062202777, 0.06635920249766881, 0.06038698788371779, 0.0329599293669866, 0.01898632474964665, 0.03143466554672247, 0.005154540722874264, 0.01858423775692861, 0.029361273477514906, 0.027153632160456433, 0.05740713568464403, 0.06299422257730077, 0.037607945682060336, 0.03344130454464786, 0.053428929193966815, 0.03905843740569488, 0.03857367228896868, 0.09314790292973481, 0.06548528003716661, 0.04870214371851856, 0.037649341243048834, 0.06343312584043992, 0.04380059826578345, 0.015583840037335553, 0.031107252974423672, 0.011505623640973243, 0.04189891522870429, 0.03777951107270295, 0.0643619193485187, 0.022361551096001943, 0.039503262528488715, 0.013019368371685908, 0.011361997476929139, 0.02297816377493643, 0.03276515151223829, 0.0311840552040526, 0.10000489547007507, 0.03192762014335923, 0.025622938692028967, 0.06958682285321337, 0.01576054970838971, 0.052342310082167394, 0.021917289047832453, 0.04139510133574086, 0.017957248417059743, 0.12680471183792238, 0.03374434594485549, 0.08484830554094046, 0.022105179772141482, 0.02853104101133443, 0.02156471431766066, 0.05122637278550575, 0.043397352565079934, 0.09016914623639277, 0.036142905948743705, 0.027889794775194703, 0.06571083930471251, 0.13259884931387442, 0.13985578571596455, 0.13357536626919625, 0.08600045581378284, 0.18548085684737853, 0.16967866930269426, 0.15690139524878996, 0.19069068374172335, 0.11597117138726097, 0.12566321784810675, 0.1115053614240981, 0.14310243569554823, 0.2029819975817396, 0.15587211015724367, 0.15901400527406126, 0.2700166981066427, 0.16148477672569214, 0.07684985731518076, 0.09806933602498424, 0.15419489854285795, 0.2094029481973379, 0.13887507059881765, 0.15172394323012522, 0.14937770703146536, 0.1303544568438684, 0.12626235223104879, 0.07897574364417985, 0.16034830061178054, 0.11662714183330537, 0.20022916787814712, 0.1842078025783262, 0.181583491784911, 0.08008248022487087, 0.17357542149482236, 0.20292048072141988, 0.09589144764768501, 0.13158464083267798, 0.12423994905886152, 0.1003937157351644, 0.1530868902562126, 0.12743938503967178, 0.16949836284883563, 0.12048206562476775, 0.2770904475642789, 0.10671512854676093, 0.15382614978138479, 0.15619345339796237, 0.16587171793705033, 0.16959295938572577, 0.16587844418902553, 0.11792522419484393, 0.1281538079943388, 0.18832232292381026, 0.09686470872932866, 0.13171585637234873, 0.2119377186341632, 0.12650108055001305, 0.2473772984118231, 0.08768143658075603, 0.09229617403639902, 0.05230209812702191, 0.0920788272314014, 0.1400048970695465, 0.178661402615328, 0.10415226566575228, 0.19902778879529048, 0.13785249643748806, 0.13170591255109157, 0.12228039573998221, 0.09731949682557776, 0.07936641784204591, 0.2767195997218932, 0.17746651995806925, 0.12885136169291314, 0.1501556233532967, 0.13517106612843854, 0.19128193507992453, 0.1791397785587657, 0.20852164064924564, 0.16518409273797469, 0.21331776474272052, 0.11713415414335267, 0.37415403271875075, 0.1640209720860566, 0.23226889541312573, 0.1177519734107679, 0.20123180843168692, 0.12621274037707236, 0.15006686440638958, 0.17440366979327895, 0.2656243176710221, 0.16701694277505721, 0.16556603353350394, 0.11382123755831873, 0.21051647231703807, 0.07944080497949355, 0.15088075621714517, 0.15898907677300517, 0.18768976412473187, 0.10146262289415445, 0.15036254370164487, 0.21925411878093598, 0.179146382236673, 0.22911293492201837, 0.23614902349729694, 0.14494843180141143, 0.10447673454520204, 0.0446036231193331, 0.13183404841730673, 0.1837370109053389, 0.2035940865114812, 0.2651285974969787, 0.12310428499814965, 0.10999033062328255, 0.16551344925838132, 0.19736098065491647, 0.11147674804012622, 0.2990803272733766, 0.19431473927632456, 0.18362238883010804, 0.14813191017075894, 0.1455644890666008, 0.15842497559084048, 0.1521847757600969, 0.18985284402245478, 0.1761486801889635, 0.19697677223913132, 0.09855115170320196, 0.18288827741578703, 0.0947333678543087, 0.24105243054368805, 0.2250632715802039, 0.13032870096785407, 0.19111612300959327, 0.1636059362921984, 0.09644578120881513, 0.2521673704106962, 0.1993053271284988, 0.11257411536550331, 0.11596197067129037, 0.13488974332088424, 0.11139679144346908, 0.1516639279021371, 0.09420777025121836, 0.0842830628877686, 0.16214598721313864, 0.21345619683063802, 0.11444189901193304, 0.18193351735751476, 0.08111358860567694, 0.10309967617954939, 0.11751627879998378, 0.10950243220694604, 0.1478048672358836, 0.13651236350978577, 0.1806925621724898, 0.13400503434240818, 0.08856088253519229, 0.22471246459791738, 0.0695862406263909, 0.1560867373501101, 0.20045496463294954, 0.19228118952483902, 0.11615563769854846, 0.32838720467782795, 0.07583452268473564, 0.17967614735807144, 0.104180779458294, 0.10339940807992413, 0.10910770540396053, 0.14139568373080225, 0.14666347283749812, 0.13823868136011785, 0.11243978950885997, 0.14976865702098416], [0.04771644519942422, 0.09019431988558463, 0.025066404543336362, 0.055260361968389446, 0.050758411807398644, 0.03702676456962382, 0.04319070034750527, 0.03691466675410348, 0.024363888510232492, 0.02858911047599489, 0.09161404168774044, 0.001905058133190558, 0.05028524143140643, 0.0724372368366007, 0.047575722508613146, 0.04378406225793785, 0.06979609509148905, 0.041941908083014914, 0.018189920810982585, 0.026163061322163672, 0.01835580182922704, 0.035339570829584714, 0.0172570287325089, 0.03515906136242613, 0.05087355865285762, 0.010744002009291324, 0.00763547528843065, 0.023026300909658595, 0.027213699199379455, 0.05090949583738562, 0.04383754285593187, 0.035257653047841404, 0.03311108234488676, 0.04609845984246462, 0.04291296666187625, 0.057185920135628794, 0.0463427001640441, 0.03180875011058825, 0.03389962813666752, 0.013029139823160105, 0.02416577817301356, 0.011743518839319868, 0.012483109697519292, 0.04088270342758587, 0.014269647804359275, 0.06532597205331249, 0.058318987158277345, 0.07974237549088656, 0.025333162104230256, 0.06523660789694517, 0.030345526005652164, 0.06675350029141673, 0.11281949332765034, 0.06100823539459418, 0.04012726795589251, 0.03915505641470513, 0.0671613195370282, 0.03817146846784219, 0.03937249131981404, 0.012318064672722211, 0.08085940063240067, 0.028844736779348987, 0.09397435858244858, 0.07773728590578803, 0.13497994251308904, 0.060993564810844204, 0.06911167213993688, 0.004945527039273012, 0.021390888967641422, 0.09126162592081294, 0.0379316829475424, 0.03034493611795047, 0.05663494970048628, 0.028980859112174764, 0.04595428592555466, 0.0840076772616275, 0.06445319872469672, 0.00821018343671195, 0.1135609515251652, 0.021040099222333204, 0.12681658620074873, 0.11454785663274028, 0.03030407490328916, 0.07222837828580411, 0.05601287098421205, 0.04622611307328747, 0.09045654412118659, 0.06293020443990827, 0.04931771068743641, 0.04371104258743506, 0.05209145076092213, 0.07012667735257457, 0.061107650624528054, 0.08790313476516355, 0.06678535422730832, 0.02405793406069279, 0.0437310949388531, 0.08722731498100104, 0.05572397922796588, 0.06605694250714395, 0.051918900947296814, 0.0313368974058258, 0.0976482251538865, 0.021475376974370693, 0.06113093969742618, 0.046988531436410644, 0.040653394159650615, 0.07128843436798743, 0.0818342168725306, 0.02754962300851701, 0.03240542726651315, 0.02499087976532117, 0.030700264934210048, 0.07406394793501786, 0.020795284334810513, 0.014547299135536438, 0.0545588169517296, 0.04156015497902709, 0.02481289072743347, 0.012992541887797417, 0.018240283431124785, 0.03166723834921516, 0.0714106866789441, 0.05562939035195497, 0.055382357639891494, 0.030462260568334214, 0.055637334683729764, 0.06543338524117585, 0.03780496051354754, 0.02768977304860469, 0.15242771756264473, 0.011134071955307117, 0.038378323698716785, 0.0764353960872658, 0.04613300274697043, 0.0309033184537604, 0.05257982798221131, 0.09840253064589155, 0.048303590306351264, 0.04510239232331515, 0.02512353746550939, 0.037656094308101365, 0.0359661694646122, 0.01124060605727737, 0.03030314602168097, 0.027626425238145937, 0.05357966848438787, 0.02892469529122595, 0.06784316077227555, 0.039204714233956994, 0.01486625026671156, 0.011669247572670781, 0.02112362004305807, 0.053429090072430914, 0.03487996787073151, 0.07399853934804279, 0.03349590746145095, 0.04434175511461593, 0.01852758747014788, 0.061837456624714605, 0.06074671212944293, 0.023034542100504044, 0.04107231018884529, 0.015895889673922813, 0.012441912361781203, 0.020468260552133286, 0.05069530914507566, 0.03270364997367705, 0.04398634777434411, 0.03094612744696919, 0.04276719545164416, 0.028619005142020124, 0.004936971273573657, 0.00956998375665036, 0.02060115190913841, 0.03106626727047467, 0.052490889004641966, 0.01964270888317016, 0.03341753666679705, 0.055789763198023846, 0.022151405517492565, 0.027194914723476096, 0.05305319371062422, 0.04483478632004512, 0.038797599789235866, 0.048571816840839964, 0.012355075337954107, 0.041259113068301836, 0.04290751977673462, 0.0777680826403441, 0.050872984086914416, 0.041371996123944564, 0.02047531622191591, 0.013949925797210347, 0.03910807607274863, 0.034113607985237916, 0.02672949141161817, 0.1133389009403125, 0.02459359231344875, 0.09967983670292363, 0.05835366795860952, 0.060232448797192306, 0.03333720851749663, 0.032588572076131264, 0.03338194805227461, 0.05168175459989617, 0.02955660674600832, 0.04977238770093649, 0.01211492496828038, 0.12628377204941166, 0.027633025085613615, 0.04913833886084538, 0.06301589903511828, 0.048284694747698885, 0.046070099267507755, 0.0109239369105067, 0.009566215561672805, 0.05481656340341415, 0.02308815867910462, 0.029769640475992235, 0.020812343197664427, 0.06540821925286325, 0.0563219300050649, 0.023713790128127705, 0.0320552044262689, 0.08980192198988893, 0.08678900543600322, 0.04099484337794204, 0.13187722513271918, 0.008761893146701397, 0.01238265929127773, 0.08389133148856702, 0.1220420351432216, 0.07893167060589598, 0.03203357393372684, 0.026350517291575674, 0.036704069183718775, 0.016315025953395713, 0.08261967916041613, 0.008731501481135287, 0.06243677486875846, 0.008806660452166633, 0.008668214000100571, 0.05924726355700724, 0.06931032639958205, 0.09336476709934012, 0.025227694779694564, 0.08123316726977788, 0.028545960573659792, 0.027627528404756903, 0.061823287828555035, 0.057167859612813884, 0.041927176212231, 0.07793468378123738, 0.12129240278755465, 0.018461167647112763, 0.02973291996656166, 0.012229613118594693, 0.13451800681650639, 0.0682365162778766, 0.014947708395700303, 0.00908420357342449, 0.058242604361786965, 0.05043349093607357, 0.1189858805868895, 0.07386502554459919, 0.03540232109146253, 0.012088103272441414, 0.028260407045543678, 0.09455208846878621, 0.03863592459369571, 0.03404932937795117, 0.03174213493513244, 0.054577126453119906, 0.04731052968230459, 0.030629539697040475, 0.02551324830781068, 0.018225704777925726, 0.02522585616867629, 0.08293209747681696, 0.011095641154585587, 0.05054124503306324, 0.05017712344265273, 0.034211471887125124, 0.02933199551226872, 0.058367986141914324, 0.012680818796187881, 0.018875266898483522, 0.05883945963315426, 0.06661163612959847, 0.05623017182393421, 0.04655921959408349, 0.058920132522020614, 0.02425904937779471, 0.0764789941510366, 0.0481979123076364, 0.02493332549478979, 0.09691545439343299, 0.05018909739690924, 0.035526507774428014, 0.0285963787351765, 0.02373186022704167, 0.06168719996968585, 0.045297568543784084, 0.035580608903640704, 0.11074439862803107, 0.03568059103863855, 0.026084194485578808, 0.06135320095645805, 0.07001199399030979, 0.0777144794682822, 0.10351933914447024, 0.0741919382445274, 0.0721376198494146, 0.055091336159215826, 0.056262320703676635, 0.04360351448638305, 0.029903638830047943, 0.019399822621996847, 0.08105068512621426, 0.0621302018032199, 0.05893410213531987, 0.06649542825236436, 0.003889124111024543, 0.03239637593768778, 0.007371091642492121, 0.03170133117706545, 0.10095760241271028, 0.1572550520781548, 0.03028388657126456, 0.05900435239797639, 0.012402835174373562, 0.00462706285273476, 0.04738192907684753, 0.022909577838295413, 0.023291271570469105, 0.042238514344658584, 0.03611201728363672, 0.0366337729557868, 0.052175820024023135, 0.09527320703191143, 0.013528257597147698, 0.031503948623374585, 0.06861886310000574, 0.033834977976737485, 0.014787055927539065, 0.05237651207754689, 0.01587753516486696, 0.04442075027092811, 0.027016939092127067, 0.07893654292509442, 0.003580795028322046, 0.1358306831530025, 0.1952614554113919, 0.1281238692782579, 0.33399607145017196, 0.09537935617469973, 0.07995887959916746, 0.12689118018193593, 0.22259527336685891, 0.11185206983598972, 0.19659012766374698, 0.17979231693090933, 0.17088479813068144, 0.18097284310046705, 0.203060889316182, 0.12652114439274997, 0.12375610324764445, 0.2311138186844126, 0.1297957948859661, 0.12402503841346312, 0.1017575437623647, 0.11228566027937398, 0.16898456299977918, 0.13226881863609438, 0.21465529297148028, 0.36075923051084247, 0.172805487809162, 0.15455538887650738, 0.09885400924230776, 0.08625117340876211, 0.12486284748921472, 0.09909114409838954, 0.144148206999225, 0.11389851284724091, 0.20205362159157955, 0.1403692331645758, 0.17643086101499297, 0.16494522652318402, 0.10918145668843102, 0.07924156849302592, 0.24596074055279457, 0.10012304154975761, 0.12075625615374697, 0.1772907181012054, 0.12855073346966697, 0.09016725399921979, 0.18168706687227373, 0.1245255159935163, 0.15081911678275756, 0.24676131775542615, 0.1146922029194332, 0.11074896451205977, 0.20495099676472528, 0.2796454733658222, 0.17923265905870547, 0.1253870891166791, 0.1273728656252065, 0.2700509575586165, 0.16905010948258062, 0.12174451723694803, 0.07852434931743531, 0.20862333116031465, 0.0976026582441503, 0.16741981309267784, 0.20914960292077836, 0.23500770570770388, 0.1577689591795206, 0.13420118349454097, 0.16277641628778752, 0.1589453791178042, 0.12460880507264407, 0.12495174433194822, 0.15272635395728773, 0.17200768384481632, 0.16523945025138317, 0.18819662321719433, 0.22919220970042292, 0.10927273606460904, 0.15233546525480288, 0.19986487774839326, 0.16395263704321078, 0.24446677716989673, 0.1321215458935307, 0.1659401295886886, 0.13685840542518324, 0.25812839248007347, 0.15523887720079194, 0.243832471690351, 0.14686311535056562, 0.156262508563457, 0.15612179353352518, 0.33979143466680284, 0.14498023977202756, 0.14417849811575106, 0.2209445530728948, 0.21729158538003124, 0.12401808999598989, 0.15092123630306414, 0.17107529355393303, 0.19563922868861308, 0.16313614053351266, 0.11179642887004923, 0.1272986623488607, 0.2709860138354763, 0.2652978109976938, 0.09145435832080342, 0.1763521684634109, 0.1538857361001353, 0.08113873161135182, 0.13779366088490333, 0.19821535255159103, 0.30292832563000344, 0.19170601071128923, 0.1611025907820271, 0.16243895455714197, 0.14297474416032915, 0.11556909014020236, 0.20020005653702444, 0.1014142367808569, 0.17621488550737982, 0.10467472996923233, 0.14306374825537205, 0.18235671964864578, 0.24042149585100914, 0.2098531167834036, 0.14262743053897736, 0.12400012523416551, 0.1093899398561447, 0.14076663361441705, 0.14391386070318762, 0.20481037366534435, 0.16030210550994645, 0.08591528215836133, 0.2080766661393066, 0.17246140707885066, 0.2056208793674746, 0.19150315062893977, 0.1668270295786281, 0.1339446819357334, 0.1874730838162284, 0.13617378329077076, 0.17385971672352285, 0.10086050076830773, 0.16820137599302878, 0.17945251097121548, 0.10747012351789784, 0.188838467001915, 0.20483027662961714, 0.14254904442256497, 0.16758450667463964, 0.11982201193008693, 0.12560141753525506, 0.2513769055686651, 0.2805469137045645, 0.12059009934384977, 0.2507760321661349, 0.20503960249404754, 0.1290427457781569, 0.07432100107713092, 0.13149339976089616, 0.19945600130144628, 0.12179147842670641, 0.10177730883081114, 0.19419495376848406, 0.16016918925508378, 0.18327147459551213, 0.11208889825690178, 0.11861201435808214, 0.14889787552097153, 0.24087987689962312, 0.0968725381479148, 0.2175597161535294, 0.1280342369911171, 0.10341063892889409, 0.11922825548437335, 0.24787562328480908, 0.12317111084778463], [0.04332539392635227, 0.03577322256000292, 0.017084507647180752, 0.016326387037312793, 0.035204126484571927, 0.01761447386665931, 0.1030450004843935, 0.058099648524676605, 0.030991529647801674, 0.026811029979838964, 0.030617552336245298, 0.023095264144602324, 0.018073015793737386, 0.04145699357914348, 0.12993289398089533, 0.09840707354728254, 0.036025495313468485, 0.003388188314631642, 0.016007298967921208, 0.016534686343924656, 0.06710086753892322, 0.029388954149438973, 0.18184518741984523, 0.026476586635615078, 0.0352635404335395, 0.04946954548358918, 0.030939115827242215, 0.027905022687909585, 0.08239300906538002, 0.05171590296912098, 0.044802066704799096, 0.07612344508449878, 0.031192426629845175, 0.024211477232916702, 0.021313552391685305, 0.04867110949670596, 0.07628950230296581, 0.1039781645240803, 0.022988678331697182, 0.017046490533938332, 0.020240822453953086, 0.012761633411320228, 0.021884782021985422, 0.04362041438599268, 0.02575812831280693, 0.040188451567965175, 0.024773718736645196, 0.08286285078934125, 0.08122028167089147, 0.013369790394790472, 0.05333091590493437, 0.02336244305385457, 0.0352344750576923, 0.07977720184792435, 0.03422255717938946, 0.06495716966568463, 0.04216936724861303, 0.0317781717110906, 0.1442618178383958, 0.03026808409260646, 0.030512121400886008, 0.015197261537034667, 0.05757824908341131, 0.04039981139583453, 0.024364574158924724, 0.020302546158012365, 0.05734523961080178, 0.003767935465270233, 0.04094624659046531, 0.027023648107123953, 0.014608417630135534, 0.03439675025161236, 0.005332294667530204, 0.03300265409052372, 0.053165697552744424, 0.05471681109479359, 0.051503608513983994, 0.019678780133084908, 0.05101354972970101, 0.034834833800672524, 0.048485850284416834, 0.03412870757822548, 0.044531358045435725, 0.02016705967816374, 0.054614848622511473, 0.0354121768126084, 0.03762324445790822, 0.03641501271856889, 0.05739264130111664, 0.025861847041655454, 0.03194638355184467, 0.04384114729961561, 0.0617103319945595, 0.009174482247251417, 0.07148855185556797, 0.015773379765901596, 0.09142970561140007, 0.051250527537758314, 0.0356835174945093, 0.02025230611193805, 0.014479478329209792, 0.03340385816690903, 0.003100011892984772, 0.0429627662073941, 0.08448544033472577, 0.04400372264846679, 0.08273771032691002, 0.036495800520623886, 0.045615368627852974, 0.03649195858968362, 0.026922116559299252, 0.048084067811648694, 0.16379197308373067, 0.02134658035732085, 0.044859764616816275, 0.09504939444483289, 0.04267264488002947, 0.06466023398623352, 0.011164236667325661, 0.06574728976814978, 0.13028390014604216, 0.020704202226272995, 0.023105163915803837, 0.056096987438298045, 0.0764771708617768, 0.039872608838542815, 0.01927620858975476, 0.05159247088276091, 0.11812076813751653, 0.09542765035744637, 0.039969867530969844, 0.01998809579339239, 0.0357402156617853, 0.00633175595618424, 0.07098976732982744, 0.060913409031326735, 0.04456300130714813, 0.012050039236313634, 0.06757738188870492, 0.04140675736350879, 0.027839200413455407, 0.010121387031470096, 0.016440283244235382, 0.036530025498641115, 0.05202053017133186, 0.03817133057201582, 0.0543029397545803, 0.03573384564069491, 0.04223672169891577, 0.06482091326747211, 0.025594499593059865, 0.040212843807474266, 0.03147467448856802, 0.04567861684688157, 0.02379660423274242, 0.025362340478046287, 0.04152591850969099, 0.043436963141204855, 0.10196859332462473, 0.007166256489712866, 0.03717736979465812, 0.07080263503256344, 0.02462273046764876, 0.04761213083721457, 0.05390259369667019, 0.02203041342117133, 0.03200813598420111, 0.03935787819265839, 0.043906804865166064, 0.14879593986176676, 0.052587163274086295, 0.04683833606841584, 0.03668861335984642, 0.024033459466731837, 0.029924997361376885, 0.016688166313894814, 0.037744837933250015, 0.043337003988844734, 0.02178830473924116, 0.012664219586088533, 0.029276044280718894, 0.07871840704953478, 0.03873627445089721, 0.023052552827603878, 0.04091646109196929, 0.019172842261351405, 0.05463551384426894, 0.04305347867850815, 0.05270792554403025, 0.042554663509250655, 0.04563330274616038, 0.05249181980146997, 0.029702343482283816, 0.03486766066822795, 0.0416716743981646, 0.022882569408524903, 0.045838472583601554, 0.033498734325891545, 0.07325318942387259, 0.04774741047332364, 0.022414185166839632, 0.037468889232484565, 0.04005355880625787, 0.03572631882683885, 0.02743052889502818, 0.05443912337444002, 0.00406511006839273, 0.023981746616623095, 0.01289528702581001, 0.0191838835035601, 0.08342830794713191, 0.0673405075025174, 0.04552292479803005, 0.0463722481752836, 0.0356409574798759, 0.03655801835139433, 0.03753501794210846, 0.010498997515007373, 0.14509772701609522, 0.021799903310414766, 0.02024872082045242, 0.03860839522413669, 0.09053180459886791, 0.07446776820166458, 0.02436844290294234, 0.05097043813176213, 0.062337493704211336, 0.06498739949517673, 0.007021876686673251, 0.020520410072358868, 0.03178613136462387, 0.027188266995513154, 0.06354893918239302, 0.036870042132514144, 0.07794459695897757, 0.048325473607908336, 0.018599164980133216, 0.06072623459922691, 0.026011640213490016, 0.0409357741685404, 0.052121887434153795, 0.034601295727395245, 0.030713859164426406, 0.0825527383975925, 0.04109480636074178, 0.02279171329592505, 0.05609094300457547, 0.03180274972692132, 0.061374375626685164, 0.04129860873123811, 0.010850252658729593, 0.05959549648386817, 0.057411713059991605, 0.04453582050759466, 0.028032141572405255, 0.05384448592761352, 0.010514481109566988, 0.04815480454013713, 0.07780326139782706, 0.06778198865152175, 0.03190660060593679, 0.02338680081940707, 0.055226791995547475, 0.07412021709305626, 0.02334127029884727, 0.039479498481077534, 0.06838524458749641, 0.023357961439497532, 0.018277070973248735, 0.07775590950322729, 0.02355475985114613, 0.023786315671919335, 0.07164923113680656, 0.015419210615237395, 0.040227989365737286, 0.013860895846699996, 0.06403740067335387, 0.01181402382621121, 0.0688946164483505, 0.02990315810987546, 0.020355814166607398, 0.1163341515066643, 0.09847898622073474, 0.01577945675836095, 0.06466625543731837, 0.06184859554313364, 0.06933854907871255, 0.06253439745294952, 0.21479226949234165, 0.05295591586599908, 0.012732199355659467, 0.05324679178996913, 0.003086502411245038, 0.030525414941592083, 0.023474985200370994, 0.027991456557966532, 0.09242809437696012, 0.022829684443892013, 0.005398362568925105, 0.04618021674574383, 0.03185008246932299, 0.04328491384043329, 0.0359077169559896, 0.0521117597517948, 0.047691666085513375, 0.02169541274798253, 0.07694507438328958, 0.08107628012376447, 0.05872192642381115, 0.047889500631079565, 0.10391574368000993, 0.03310923607298925, 0.05716706671181226, 0.04736815481596897, 0.11219529254782586, 0.025361788894740805, 0.06536998380456241, 0.035925126304068876, 0.05179176482582285, 0.07672528375781353, 0.10195072815423051, 0.030436181020171895, 0.0555202572967016, 0.09089619432005192, 0.11573210598961, 0.0665951039521925, 0.04417536464790183, 0.03716805416549887, 0.0195832432232677, 0.026463559310462688, 0.06788447589403199, 0.03824939876193962, 0.037379628497987025, 0.05296670621441257, 0.05785224809040947, 0.01235310361915899, 0.03636001909692441, 0.03506925287506273, 0.01916285247481879, 0.07432467829916747, 0.0501000703192286, 0.010841088331935388, 0.01546068661545794, 0.049109599072366, 0.06636850280506958, 0.03632130867411052, 0.006162945609239321, 0.06348456481411573, 0.05640491264902296, 0.05550942864389189, 0.031208907096316258, 0.024121398699559995, 0.12631907338096252, 0.12275828138714838, 0.08440987342187474, 0.10247355251903496, 0.16543900083389976, 0.10028296240395117, 0.2563424883109908, 0.11976892203693429, 0.11164310403288373, 0.0752876278373503, 0.09264899582992639, 0.08761753718699179, 0.15257590961071754, 0.19203780339129511, 0.14942682858917022, 0.21679658532863666, 0.11322699847721285, 0.1704147878673769, 0.08260525372480193, 0.09909544185164476, 0.16507233583158062, 0.1338229505645652, 0.2581378306833006, 0.15597801415189622, 0.12759713786503962, 0.06393941419739878, 0.13891625548562697, 0.15079164486979285, 0.18243040198520308, 0.20966191655926167, 0.19006025466707446, 0.14800970382507772, 0.1641714011108683, 0.10639475823770608, 0.18053594315724988, 0.10220325371671109, 0.17427950226251157, 0.16496424082546465, 0.11474153898175686, 0.12666300089368898, 0.1557795514142321, 0.14020988687632546, 0.2963885700991077, 0.1189794760918425, 0.06978502512098321, 0.12713433648910255, 0.13829428402166213, 0.1672348028589641, 0.23783990212025183, 0.10549028419078359, 0.12638889463438144, 0.16860800014147836, 0.09312101324359257, 0.3076025651347253, 0.09855265323553355, 0.20134070016924413, 0.22281976777219006, 0.174661795458486, 0.29377832467998233, 0.11936492557006499, 0.14558233891523656, 0.21292477695932313, 0.1834540027043512, 0.16461873517161416, 0.14871646590050192, 0.1948189323828105, 0.13643062192826502, 0.15466985773415337, 0.2011035193478869, 0.056890137418503725, 0.1291462289349687, 0.1904957756520279, 0.1344461324474504, 0.09603720353615862, 0.166965538275338, 0.19939119026305216, 0.09834911133493147, 0.08144928833409663, 0.18468263919555372, 0.15395260025416652, 0.10599080773611223, 0.08998752977218359, 0.1897254895659224, 0.1644338781554853, 0.14540123572993666, 0.11961208085619635, 0.20441079752579813, 0.10706998047328765, 0.16045941400431818, 0.18748092855657303, 0.2813904071527143, 0.16041389305985745, 0.19769347813581267, 0.16703096218407157, 0.171120063732228, 0.1087399295741512, 0.1768269131500875, 0.11197455963420291, 0.1111380912123188, 0.06452603836453731, 0.13101821074322348, 0.08945681470175905, 0.12614119542582383, 0.08039090722318619, 0.259109444675907, 0.28892380936491874, 0.19247223653139608, 0.14586530115094878, 0.095634869480085, 0.175126014097083, 0.198583748912619, 0.23926268061322553, 0.4162675100228479, 0.11659603866357958, 0.10747089726670135, 0.22468428788406236, 0.12946568759939364, 0.19894603189201127, 0.09896328402382713, 0.07782088142008552, 0.230392592868978, 0.10474173201908989, 0.11199596413080731, 0.14144953971187915, 0.19580812043239995, 0.09539543636023037, 0.1260934068611072, 0.14324858994974246, 0.2068687293438181, 0.18277555523860842, 0.13845995819616702, 0.1105634103559198, 0.176310523923847, 0.09714480579620409, 0.19441174132929695, 0.1509635550000014, 0.22341612125596694, 0.08761222053679728, 0.1980421400719112, 0.1811371996037422, 0.19059711376265173, 0.1461478650209404, 0.10297601426681204, 0.2014841424721864, 0.17417105485595044, 0.0987843948326284, 0.1619423303993479, 0.19084062247026354, 0.27828385933272304, 0.23829874282162036, 0.11240421238565639, 0.16275724876792202, 0.10870848166485948, 0.09593523723343689, 0.2060576260931069, 0.15340961245519502, 0.08382196222702343, 0.13014620350253198, 0.1674430562003005, 0.11959452978185109, 0.26197957776246533, 0.27061384832186086, 0.14684440748345468, 0.12274753317357072, 0.2585918143872292, 0.11478617126422544, 0.12797627477876602, 0.15730064963140797, 0.21854557938152747, 0.17414514576235127, 0.10978912529084953, 0.23996409539493824, 0.21515695798781612, 0.1781363872390601, 0.14481006100052787, 0.1176092971957499], [0.02972813383225472, 0.08956090306803104, 0.0210173693936198, 0.027705573612042976, 0.02220940220380022, 0.0867973251508609, 0.02643159812226171, 0.0264936646506671, 0.023785607040589376, 0.048570116125648065, 0.04146468510190326, 0.09951007161890307, 0.03212130632281544, 0.05959446609561002, 0.03233675131454103, 0.06755454480768212, 0.033521517780759645, 0.12248180791615479, 0.05191568720845446, 0.006522617665224619, 0.021768415181507027, 0.08288591003586208, 0.06375195631276696, 0.024405927585077383, 0.040071910442484, 0.07783647130934462, 0.06182338741998519, 0.03038196880821019, 0.047716468182061954, 0.04704684221876725, 0.01491705338741022, 0.06180151560974698, 0.0679344095049366, 0.04941502683645776, 0.0045986591853321565, 0.022913820050176115, 0.01989096159025306, 0.04879992718117372, 0.019371086663957086, 0.05981660861101362, 0.025215902771320076, 0.037951984277535836, 0.028138501389372735, 0.012673872293934468, 0.06076728542064948, 0.022807077189246495, 0.028766044227766897, 0.03021134762093425, 0.020399820172197877, 0.061922745193324746, 0.038629734603267525, 0.01253276368633153, 0.04656422214822904, 0.04961474595831768, 0.06863246116066171, 0.015213874153672688, 0.03519986703571293, 0.05788942250693518, 0.022037790847882148, 0.05321668453454491, 0.030059191067853284, 0.03763689997515852, 0.031221220044479258, 0.013849710005395597, 0.057681195978676124, 0.010697163393600814, 0.022903249952040856, 0.03670164451543843, 0.07511161147586762, 0.05354948845061083, 0.009089891776262272, 0.10183385378050228, 0.02205434409270604, 0.06620479747653008, 0.09120359476054869, 0.022331681327834245, 0.054522852954124255, 0.021919481974515705, 0.11239642127146644, 0.010511326742538763, 0.0914516157260345, 0.011732573358101711, 0.09980961199729674, 0.04960022476171294, 0.023452812700622508, 0.04698159451025629, 0.05823365645483137, 0.08472553995107451, 0.012596784696553745, 0.06850596472260452, 0.04693818413802693, 0.03304370108150667, 0.03996472708099792, 0.06463459302340785, 0.11390572939548763, 0.05545306372486296, 0.05553982701272734, 0.03766067551388856, 0.016789489102760152, 0.06555343121891061, 0.06156366829189563, 0.034946874159598545, 0.11222493248961626, 0.03663607121955964, 0.05249740075199835, 0.016218970019009807, 0.008277664291522196, 0.016139017252792275, 0.016700804849425634, 0.025206420518037294, 0.03095076227891109, 0.07444402713689112, 0.07207753557351328, 0.06852644991369979, 0.02898756238151222, 0.0522838230995882, 0.05700575540803614, 0.01903994707390666, 0.03634937047477692, 0.01283997930811658, 0.045572433230136676, 0.07792833291234509, 0.04585342661988351, 0.04480346481526091, 0.05192071274523774, 0.07085465240262209, 0.08101904569494148, 0.06727032618777407, 0.018878969018377604, 0.048330445518536914, 0.07706160401745189, 0.026731642203465588, 0.06655555849354114, 0.0202264353227351, 0.061898820267449466, 0.04093039623131195, 0.029796375029329813, 0.030286412746194872, 0.03860486355880576, 0.033018443162643143, 0.028352596151131778, 0.04146361257880926, 0.03617304767812452, 0.014384315844865577, 0.04168966980350595, 0.05321086226632038, 0.06598796395044174, 0.0807053097073109, 0.055719470800531495, 0.04264567092421555, 0.05319349505307694, 0.025653285349929528, 0.03158127753845146, 0.03815178000818818, 0.03212508505150195, 0.03545014029969612, 0.043560287975255525, 0.016710235391773524, 0.0407224225120679, 0.0513891205041399, 0.051767958643575834, 0.02540320743836703, 0.017912330766839367, 0.07866560826979338, 0.006321526288370332, 0.03484265172793981, 0.03444920429178784, 0.04711106336945969, 0.10536132861048945, 0.009769432832516972, 0.06253669571672237, 0.03743215914695494, 0.04783748709146054, 0.030957197417475046, 0.008324721242271124, 0.026681842657947735, 0.048786095463700836, 0.005276583796066623, 0.014972475060682385, 0.043433714928405906, 0.02383098625878413, 0.05151381663557503, 0.04035662318910322, 0.009117737157090057, 0.006568432117121355, 0.09363178704534808, 0.05917568030136247, 0.049708289124311945, 0.09299331404749425, 0.07255549782947188, 0.05016494647509629, 0.060995790296264236, 0.016822247022402384, 0.008322065790003587, 0.07716776848199867, 0.020085651344890078, 0.021369120579272993, 0.02681399857054555, 0.11171549934172824, 0.0752637718593882, 0.02239636787694068, 0.031432869070540034, 0.03971144692191193, 0.001724772507347347, 0.020375849281047142, 0.05084056707639849, 0.016300309404370286, 0.004894894373137504, 0.03556354046468774, 0.010384880100196649, 0.059266806459955634, 0.028947379154663895, 0.04224754269084623, 0.0317296534476261, 0.014206433101677367, 0.01713541418974919, 0.044939131325771736, 0.031548824138759125, 0.021620068000629548, 0.0511205377387664, 0.049600833801612745, 0.050420103549596765, 0.03848861737717544, 0.01952968601648125, 0.03532090126687, 0.016495702044677832, 0.10313029671388288, 0.1144579102495505, 0.048499984606619806, 0.08623259577659831, 0.05046318450401868, 0.04486474801876372, 0.06833239984247955, 0.0362177872129025, 0.0342103572291953, 0.037056400680974606, 0.044541826636921016, 0.10641666835234051, 0.042789488610240727, 0.03949892647083729, 0.027703124045905088, 0.07679177252876182, 0.0007511866163939328, 0.043987807171839866, 0.0691856072855092, 0.034507223960733226, 0.02106300908170881, 0.03989174571489135, 0.03787407313563651, 0.0767577275814068, 0.07457500518930536, 0.04965239534935644, 0.06753808923906858, 0.015086348284967245, 0.05310179815898019, 0.04257067857730774, 0.03815513164285691, 0.01095333170416134, 0.06443472834484232, 0.03196872076049688, 0.07151066881394194, 0.04200861135858201, 0.03423546193047397, 0.039535790621753664, 0.03466306156629036, 0.01927864091891435, 0.05189096938157755, 0.09834337333637862, 0.06844938912939641, 0.027213699199379455, 0.05425225920794953, 0.030236473389630838, 0.014500422215449714, 0.07298079154063618, 0.03279273450795201, 0.03983318978439897, 0.046639482625910354, 0.005468854628082726, 0.10662395642289232, 0.016969445071393446, 0.060433776703693216, 0.09995391997959345, 0.03007813067656131, 0.05088996059531647, 0.017414752829579577, 0.06797197845674331, 0.011114854639726541, 0.013300118528516784, 0.036859424153883616, 0.04082814264561861, 0.03652441007415614, 0.053349397776107636, 0.04466188410597463, 0.026413131572846926, 0.016465309421501814, 0.01373043777646437, 0.05484511550035208, 0.023601897241127108, 0.049085260459011605, 0.024094487945999832, 0.040792695757362156, 0.0154521246252942, 0.013604158715855692, 0.08817570884862254, 0.03050986144150938, 0.07407586826311965, 0.016453622750216917, 0.11636687112191033, 0.041971467585573276, 0.05394977705192663, 0.027894584739941265, 0.05404366878792644, 0.04347507984587743, 0.03818583644686207, 0.015129557559116474, 0.02808279339073887, 0.0065384330716164365, 0.02376193492372911, 0.05924843950197101, 0.015222947507525886, 0.05446987414372064, 0.026564412870474403, 0.014560818672180178, 0.03123737492358252, 0.02740339023031054, 0.06228325467917228, 0.021188385116176742, 0.025071171525445198, 0.013930807115450023, 0.08638222806996877, 0.03969974109842893, 0.021827428849534165, 0.035415605056069555, 0.03979351026036086, 0.047464222241673744, 0.03044097673057789, 0.0632161735707233, 0.007565537685408227, 0.07551559262097844, 0.03733275540833993, 0.016385448585835197, 0.03514201207567127, 0.014011491495635242, 0.01777639229511542, 0.05150820504152968, 0.051395337307645436, 0.04199255032524948, 0.03228169257542299, 0.061880859336064714, 0.06654434296632968, 0.01538479315762919, 0.0791532768597526, 0.13660553512313675, 0.156530823198057, 0.12938674989967577, 0.11923015538242557, 0.12753131559058545, 0.16984212182221875, 0.13437009056008634, 0.11797675126863104, 0.11160243242498367, 0.2327387831023624, 0.12426522229948353, 0.2392720881729357, 0.15920673767405172, 0.16660967511275124, 0.16366327031245156, 0.13582786394944116, 0.09894453019144074, 0.16920510439142106, 0.21553497641317307, 0.10095891242306079, 0.11184165870109875, 0.21545822972491865, 0.1540053224251155, 0.2144380764014298, 0.15074759481414673, 0.2053623859800639, 0.13662563727026986, 0.0946629950175843, 0.07972402768510004, 0.12120501513803199, 0.09406491783597777, 0.14615446869884768, 0.1935302192765859, 0.0597715741323848, 0.17872694909812945, 0.09057654413364588, 0.13522794049593712, 0.1864022920809446, 0.06882975944468091, 0.1639862529813282, 0.24486350346236463, 0.11683488955661175, 0.09207787728237529, 0.12051141445314693, 0.13361123450581106, 0.19418536234767209, 0.07169454523752775, 0.16825985914516836, 0.22393002835733278, 0.1573720643477094, 0.30845074704097164, 0.14560110806938142, 0.11769352856302455, 0.17516664740058685, 0.2700545122065852, 0.1438016594657975, 0.13232227625145068, 0.19640573030037267, 0.09459147304897347, 0.16205750405788422, 0.1381121542785437, 0.19225014764214718, 0.0961770299040983, 0.1223887435551132, 0.15436098640484197, 0.13031947726924575, 0.08499880351366536, 0.1308520922377225, 0.1170906326883743, 0.15564471993955875, 0.14572755854216315, 0.1843180119871132, 0.09410776513358278, 0.15221610875619998, 0.20573946977815322, 0.17641864957347994, 0.16191127319489756, 0.13730140342827768, 0.30985078804435273, 0.1396955048004466, 0.11339105620619752, 0.13064973777340305, 0.1609596081318394, 0.12741233447506545, 0.1275170586943146, 0.1536990098294712, 0.17178692794855566, 0.21441797425429668, 0.09402519617710384, 0.13693078541226927, 0.19848310028112706, 0.16226617108669975, 0.285204483136054, 0.1550192551146592, 0.18851419730532556, 0.11940092404162693, 0.10914912777802638, 0.10141795230728966, 0.15330499548825527, 0.17612033493576512, 0.0874103946731456, 0.22667818492458713, 0.27604197963110866, 0.11131691911648359, 0.10234439775588051, 0.19063316586036838, 0.10194900445640089, 0.10986134439947144, 0.1159911662820847, 0.20483286600680123, 0.16038228427210163, 0.19199504036336176, 0.44102799267538134, 0.18539946766630297, 0.1678280613475269, 0.23931022402980637, 0.147257175657057, 0.1001020277579946, 0.17414111613986955, 0.09987407829612495, 0.2643182603341918, 0.17564984969794753, 0.19783247712879412, 0.11412250929542127, 0.15750833606768042, 0.20652953625446369, 0.13169549375532136, 0.1910394222866143, 0.19737305420060314, 0.19530921333259155, 0.10709532266182285, 0.12735915265136188, 0.24429725723401194, 0.15887546593383436, 0.147978508724801, 0.13427904867116483, 0.21153512410819533, 0.23576058627616978, 0.21256410276457188, 0.1270369896965642, 0.08458276414462636, 0.17945180617032513, 0.1851700090112225, 0.07925269208968648, 0.1831642988949053, 0.11964994858229354, 0.11725369450305739, 0.19393912636704985, 0.1336965920223344, 0.17500754626047227, 0.12978617282163712, 0.16057169185050074, 0.05557512068339894, 0.2144883317692626, 0.19159089833978685, 0.09331344686929258, 0.11805562002043571, 0.1494258020313517, 0.13890945262485935, 0.1827819444118969, 0.15944925046736197, 0.16246428142391867, 0.10832922983794444, 0.13508373210507055, 0.11060480208646868, 0.11919926671731858, 0.09683105448681502, 0.1469256434469454, 0.2497383047856631, 0.1017115478433909, 0.12793465322183986, 0.11273465675091553, 0.1174365520297039, 0.18972311469335712, 0.1287199929356575, 0.11448909768894797], [0.04194280823632594, 0.021715062903240327, 0.025684225725971406, 0.02953609091139609, 0.02235157663122781, 0.03530925289998132, 0.06454219515886038, 0.0297092133757448, 0.03876421750793534, 0.06542275960166609, 0.026828895150233182, 0.04175090704173331, 0.015219157287520508, 0.019960064636242968, 0.03513704016504269, 0.043947985921535766, 0.01838047369082849, 0.15709153827159636, 0.020387354006450024, 0.072871049445483, 0.04337958315567624, 0.004364099342285866, 0.11966707830828045, 0.041297631969134656, 0.04938411901915266, 0.04501474803433784, 0.06121406406765023, 0.019002420256935784, 0.11159555295542364, 0.03136168418061589, 0.05410124795631536, 0.08008307011257257, 0.03298256343470947, 0.020036070134430643, 0.027274419328257925, 0.033370085180767124, 0.044187576089414864, 0.09254014239676538, 0.027832462670161363, 0.005388076880931734, 0.05061367864630396, 0.024788485081385703, 0.018837538983432517, 0.06848138862199361, 0.028211429129324617, 0.08990229482972815, 0.05230060425556956, 0.02467572651503067, 0.02563335557257937, 0.04776404224215977, 0.01439676381602523, 0.02396653977132613, 0.013274226671895914, 0.013438429957586191, 0.04733661114568672, 0.027799459602383357, 0.01930655524765532, 0.03980246965863532, 0.05161146986328306, 0.00244060913363712, 0.039684059278618906, 0.007529395093555533, 0.04690943668866831, 0.024974671260063207, 0.01758997629006063, 0.0028997330481351745, 0.048804473913004326, 0.022840166441915978, 0.04804936019823917, 0.009758963283421773, 0.022395573060719237, 0.02989286188817313, 0.04870479055229695, 0.041521743330503666, 0.0631710701441813, 0.019182736286893487, 0.059047172882504044, 0.006503528190566408, 0.07809570780204189, 0.06087551066171258, 0.026329407738822124, 0.013060050513294917, 0.1149312223518087, 0.06571771877427256, 0.02191611118764887, 0.03392859775152418, 0.036287926392810005, 0.04477353759049889, 0.008001148206887828, 0.0602292082452726, 0.04602768480957997, 0.07371069713225288, 0.048329461095554214, 0.05573565440793192, 0.05733515406327863, 0.013873939451220778, 0.03934575868169627, 0.03618793276649329, 0.09610080415563238, 0.06356807988918116, 0.031661592281213215, 0.04843577877768586, 0.09069531840542633, 0.022128302220916076, 0.03465456948164971, 0.029682256656909184, 0.05734596739432985, 0.042128584557963956, 0.04326400730097967, 0.029851301618280913, 0.060523543056220784, 0.0422252916670855, 0.01004498604039151, 0.05232343367571312, 0.0421118761803354, 0.019496481850623124, 0.017100599324030262, 0.002809507761060471, 0.03802323811537316, 0.12795720685033068, 0.05211625668791033, 0.04542135303058932, 0.02961688445911052, 0.0045084949458889184, 0.09852623852390437, 0.045985059677473, 0.029816513565639337, 0.06345790878479039, 0.017176468841611378, 0.041229637835415146, 0.09310543867609195, 0.03289885300722334, 0.0283205640997978, 0.06947141936829976, 0.0368453549491542, 0.0458417744225552, 0.023695580218167558, 0.07326277318380534, 0.07512140974041916, 0.04611194682037158, 0.022669024314851533, 0.015520969116609665, 0.04575377773313273, 0.022876888866566365, 0.050959429448290225, 0.07191777559778384, 0.031464332301590237, 0.02699650752718651, 0.019194444025596304, 0.08556291235670929, 0.040645078275232546, 0.006206123761066626, 0.08602969738985262, 0.05157281689706349, 0.024375584757616444, 0.03213749184543568, 0.05044977030446453, 0.026532304210347996, 0.03704543413233854, 0.007249900363310571, 0.049210554139027675, 0.04202278015474158, 0.09256940695547289, 0.04706024492700254, 0.053965144775687694, 0.014807351511873066, 0.06671876586492985, 0.0465892349189568, 0.029851043063606468, 0.041036541543660626, 0.04924948672733961, 0.02399427406940489, 0.040202934460173693, 0.012527220082589456, 0.01954505374024232, 0.03927470402671926, 0.0165915358135657, 0.03968077276142375, 0.02957143629300258, 0.09300275225072138, 0.033012057819794265, 0.017169265699903333, 0.02551508500360914, 0.043513568103193276, 0.022250933745395274, 0.007071704960488264, 0.07534568198025227, 0.012145565612421883, 0.043660534410587246, 0.02195352309143111, 0.012600611305735525, 0.06998890410027198, 0.04649416340755359, 0.08138581794957, 0.011486641897429383, 0.015707847647248738, 0.04440695685785144, 0.053983944573349534, 0.02557101708296086, 0.0511136276256894, 0.04672758273720261, 0.09752848561132148, 0.06052768759189114, 0.037929583866629875, 0.046647599327468106, 0.004533509153031534, 0.045561179398528995, 0.04818578130535541, 0.08198379553974637, 0.017172217053631623, 0.09902886881102478, 0.0030840535633145805, 0.05835635309678413, 0.060503858427006396, 0.03312676033425716, 0.028591870307742108, 0.06203026563349751, 0.012608579577757947, 0.05084673025374932, 0.06378410519250939, 0.024042240749563903, 0.03099571631830787, 0.056208158287430005, 0.025589474056276585, 0.013824573702990048, 0.005917680166256164, 0.02932151159902494, 0.04630993458352262, 0.016569076030845606, 0.04707361699172086, 0.015291526740897569, 0.04982449700154605, 0.09493366154211183, 0.024548136486461567, 0.02993087900141555, 0.012713240594753336, 0.041129307130411755, 0.04042320772104206, 0.0803745129416066, 0.04782882646747655, 0.0195606034098854, 0.03453366548543976, 0.07267409590102973, 0.04652270018273304, 0.03315589848845717, 0.020854749994712974, 0.07462847812642014, 0.07515814365638841, 0.08764196007001786, 0.05750773452042092, 0.05242586729206866, 0.03154557401074037, 0.05623190318264308, 0.04101608699608234, 0.053579132222840865, 0.02269586995093813, 0.018341667507024064, 0.04809008926273354, 0.023966281216651685, 0.08144620866064103, 0.05621836257858142, 0.02993839623917255, 0.07170406004954731, 0.03662035875623265, 0.02180565088506668, 0.10135638182081523, 0.019605415723016186, 0.07731327156145727, 0.03976901076854237, 0.04224090070854272, 0.032570166813750426, 0.012508305371738972, 0.06429189125136023, 0.024115697090183536, 0.041674677462827776, 0.03817253333005694, 0.04260498399455701, 0.025018711739610282, 0.035434979419674606, 0.10876144132306499, 0.01048684640291838, 0.03772282822718544, 0.006386404838262787, 0.04075770086098102, 0.052453699266357776, 0.022325694350705996, 0.03648417513637293, 0.03482934861113468, 0.021520260150634477, 0.04160831892682661, 0.05593859492951343, 0.02813198198113711, 0.04149804440056605, 0.07821580740593134, 0.03646004719719772, 0.06643142926716997, 0.09331936106806801, 0.03673579288466323, 0.02611306450900532, 0.011315462423578627, 0.06219865175925436, 0.03601636737585068, 0.03633542767455501, 0.08357944943371319, 0.05325057626431508, 0.05378743152945273, 0.05778660201617788, 0.011464094014597997, 0.009431034559383988, 0.01677500238011201, 0.03330120238505545, 0.052824635208854755, 0.01707658246760407, 0.017305213747726336, 0.11515270603159744, 0.07796971698201473, 0.013205834172455775, 0.027416208796503565, 0.05865523463956291, 0.05165355490340341, 0.050436133939412334, 0.029180781247334617, 0.013221106135226307, 0.04443801406230177, 0.022362592975578965, 0.019981436574110584, 0.04742848040956644, 0.024116668106627562, 0.0404428119110244, 0.031172918200853373, 0.04363274074069435, 0.049263291631735144, 0.02302595808531248, 0.0012328280694594968, 0.08033843786125222, 0.05175167544474525, 0.05874426171724355, 0.006468009002762096, 0.06853289271314299, 0.02939228663190959, 0.04099922923130855, 0.008582355653596743, 0.007417405487954497, 0.1261118925627201, 0.05717640149316961, 0.05627874945921283, 0.037840028188281485, 0.005368548820936872, 0.0893015823056621, 0.04276416557390363, 0.04998685784577843, 0.07920898677360627, 0.18202745505879003, 0.11509314269548464, 0.10048923923844293, 0.17900104003567852, 0.08010056756076314, 0.17527685680937383, 0.15104980117851688, 0.09460761452153807, 0.1495009399349651, 0.15694472518178726, 0.13257195962773216, 0.14427625093488924, 0.09859472678433504, 0.10082365960002908, 0.11623911063877806, 0.14771669051579892, 0.09752212708154995, 0.3810623684717763, 0.1371601827803158, 0.1664686383258912, 0.14035902887342439, 0.19442304878705935, 0.2904326042100307, 0.1988645661021433, 0.10001320752405352, 0.15055230368048916, 0.12315480083587671, 0.066570351651359, 0.30556026665914443, 0.12701107294208583, 0.1255362770790535, 0.16744772933663862, 0.12181433849036695, 0.155968131617673, 0.10164912699932054, 0.15403627237725645, 0.1361337015705724, 0.10607726841924653, 0.12004230817359303, 0.18073924757059545, 0.19242139893674082, 0.06396174566039155, 0.10413442347799579, 0.1413612404177266, 0.08560332349471508, 0.13519642363873222, 0.16864394498688562, 0.13347307820954632, 0.15081700238008655, 0.20468124188482764, 0.09100679443368027, 0.12975595831390352, 0.08363942645730511, 0.15262607304799944, 0.19215115376057165, 0.2797806112756652, 0.17585243398864425, 0.1215043486726861, 0.16712607966075022, 0.05412858963433293, 0.18625177112558197, 0.07569830459091934, 0.12717307755543342, 0.20716431670852248, 0.07883116753110964, 0.1606839390531663, 0.15059296762750995, 0.1390943556062637, 0.14496510187464376, 0.09698365920133169, 0.11001825452812257, 0.15978887256595398, 0.20831660487719122, 0.19580672615237776, 0.1749973113258039, 0.12092238232012718, 0.16342817325024836, 0.15654505711169014, 0.17492477812113302, 0.12383717067179181, 0.1040155879191814, 0.14424920803116215, 0.1521441118130761, 0.2361789009263439, 0.14246479007265261, 0.15753216140212553, 0.14353167475952258, 0.11101298905428379, 0.1529769259955614, 0.2409998922338409, 0.23739687347364044, 0.12146894008882585, 0.10432416047420233, 0.12406493627255964, 0.09878118492422566, 0.08054462276519307, 0.12187426954868341, 0.09653901410920006, 0.15858332596478925, 0.12651965818217686, 0.2850561991574303, 0.1165081837004231, 0.2213002476961382, 0.128759921438271, 0.21084881658034943, 0.15310120077863817, 0.1236884806665682, 0.15911580303743963, 0.10470601700005994, 0.10686663775554589, 0.07241270670126523, 0.17419776068099085, 0.12512587611713719, 0.13437830302263462, 0.14913668044872824, 0.09663240788804908, 0.1957614197125358, 0.19793085814003022, 0.1457033348419974, 0.19141547952688512, 0.17024937416276625, 0.23663599494724508, 0.1037629321217537, 0.1307238950844734, 0.1570273094600247, 0.1904197950516978, 0.18610278234606792, 0.1797200595178912, 0.16570795898235616, 0.246125832500477, 0.12721224763100186, 0.07371815882863537, 0.10794833858287144, 0.3773827562409063, 0.1866964545221098, 0.21465377611739023, 0.07228812548301874, 0.16281527226730702, 0.17784927280679827, 0.171415482557589, 0.09278001984761608, 0.1069105422544864, 0.13528302221769287, 0.1419533957396784, 0.16638971594793184, 0.12653445900087396, 0.1305650544142531, 0.2106243834620522, 0.09627019385657004, 0.17909764372293027, 0.0950480001648107, 0.08135396401367842, 0.2013176256009648, 0.12772389477299106, 0.1278946021451585, 0.10065564119647588, 0.2551230142313627, 0.16064430166396404, 0.13607785376089235, 0.08956676364065179, 0.10365813895459138, 0.20434436238100454, 0.26709241792559624, 0.1119761684188439, 0.2648603747929296, 0.10973661762451935, 0.13952028517040516, 0.18140407399304453, 0.13494700073234497, 0.16218442950517903, 0.3276715253389651, 0.0965416724342973, 0.15290001076796364, 0.07091744096889611, 0.11552061975723314, 0.23384669945845682], [0.05448663231706428, 0.02287139601614927, 0.041631585017087004, 0.0208180831114371, 0.06613932760252107, 0.06398871195532622, 0.03372390671903568, 0.013522996488327702, 0.0011218842935763421, 0.07110092668764054, 0.05231642397120596, 0.09184929196752849, 0.046159532371788256, 0.03957015349559727, 0.02603126355567046, 0.11134247580963759, 0.03823884207034304, 0.01868137004484813, 0.009711360495026794, 0.0216638365189635, 0.07446560017283886, 0.01808709074412623, 0.025526651016045964, 0.019468324288966197, 0.0641549913392913, 0.06732520106579028, 0.017538167678961353, 0.0700163300479612, 0.030210294250038364, 0.068579716007075, 0.027818184706472585, 0.04753345743783059, 0.06483103328895184, 0.04345222744309614, 0.011404613032937052, 0.07449927739799023, 0.013923749530447588, 0.06588336230526048, 0.02601312642406312, 0.08082945425544055, 0.029911588907482165, 0.03567589108922309, 0.01990492162745326, 0.059888873684911005, 0.042300808784221454, 0.035319740643664714, 0.051117864091910666, 0.02808228202704941, 0.0842041558315677, 0.01989675704540024, 0.05290588266366432, 0.010034273258380352, 0.018629291387755546, 0.02503039841089518, 0.010991843901724826, 0.053565587788339586, 0.02254965632492977, 0.027009975352895357, 0.12447460945094786, 0.04147815675805173, 0.04786349960692948, 0.046485675153352564, 0.018549415230330442, 0.025997791259038835, 0.06948622784787609, 0.05104013681111317, 0.04715971761353074, 0.04509837036171267, 0.05095510871239728, 0.04825107497914184, 0.04443521401093853, 0.0761829394726984, 0.026714161992253318, 0.04625559213661379, 0.019659825202618397, 0.06647953958881479, 0.06623398542644517, 0.045417484286571705, 0.030926052112913424, 0.0003689328919027767, 0.10211676239005982, 0.01017938563299756, 0.02379946557113961, 0.042654772048756, 0.04861743354629125, 0.015887773929974966, 0.035390174767423066, 0.018965623138712782, 0.06395301608849438, 0.04239828198126728, 0.02287122939202574, 0.07049726472506601, 0.0679092281948655, 0.053632720073144284, 0.01954011438835052, 0.039555299050745465, 0.06414973597613073, 0.042401250571973866, 0.04802956448627576, 0.12076273725758638, 0.06520994803718021, 0.021676706796091412, 0.05657381971456832, 0.03574244114720533, 0.015148499083044309, 0.018131246136861946, 0.014985276389897112, 0.013569814994210198, 0.0069997764864726175, 0.025833519025435372, 0.027955806656410138, 0.04620062915848629, 0.015855177846406738, 0.02230450627394021, 0.055072160978471084, 0.01242035081715233, 0.05254215560853482, 0.049958014635429274, 0.09979430556056962, 0.09335389631169458, 0.010531686486736422, 0.012640384675544358, 0.08227761324134567, 0.05542159283293351, 0.008510047487253624, 0.019963523523221095, 0.05738806009532944, 0.0311678581901135, 0.07462563594022105, 0.05798523712362494, 0.0838982186190063, 0.03256892575131309, 0.03974245050020757, 0.028704092612550147, 0.04394012968987227, 0.0566972901053246, 0.00864390219982353, 0.03015549023515515, 0.05414875306849999, 0.062390108622850916, 0.017826825778390613, 0.042229926499027404, 0.06929665173013365, 0.045485731229306235, 0.014216983090004614, 0.07531912937279671, 0.10459278154397204, 0.03661536003252672, 0.04758011219241927, 0.04727888259015257, 0.06483415892768292, 0.02705573186939282, 0.03072452119311258, 0.03214736671877965, 0.04512635172314702, 0.00752251131475092, 0.05477797172422852, 0.004718719048410534, 0.013827074980062824, 0.013607169441398115, 0.03021612609436195, 0.015302657998437363, 0.04455048343046539, 0.05087952647778777, 0.03335617302406219, 0.042343150463796435, 0.0341952882797247, 0.07108336795241603, 0.019163279568836577, 0.03263490507379174, 0.029581797632178473, 0.032793443139281966, 0.032283837621610974, 0.03065063584325535, 0.048428769073178696, 0.06921117163954243, 0.013586365366204372, 0.028885349015434904, 0.06426452659070492, 0.050183983760014664, 0.07145675154583109, 0.03972383456364755, 0.11357213640885969, 0.031523259784725886, 0.027469333163612795, 0.05988960912931831, 0.025324200790735985, 0.026479277519449115, 0.05025812957976615, 0.07447132284963325, 0.05556298585067834, 0.006915882676689616, 0.05987053737044335, 0.015633215361665335, 0.03820688471258168, 0.01922475429432046, 0.038322648258819696, 0.015632420545443892, 0.05543891791134112, 0.03018897785354526, 0.03448803345823, 0.06765159282592997, 0.018472934757629712, 0.03594963728720623, 0.03646277830064778, 0.041164148809208025, 0.02418440368567263, 0.01932089258315823, 0.03940958912754732, 0.019347345599183635, 0.008661322081611763, 0.01791105331522563, 0.04009126182345133, 0.03248401256578584, 0.003884346116401796, 0.06952754296963254, 0.015004987832188848, 0.007336860440010506, 0.006243437509833565, 0.04068858440845244, 0.05622903035292703, 0.02951701915252113, 0.028403686554802042, 0.04909860954109219, 0.041167236143542875, 0.06559628617739485, 0.06884145760728468, 0.032256059273476564, 0.011387537890714745, 0.03716425819983406, 0.04052325114307385, 0.040099903295237216, 0.03463511850925223, 0.09181013721371852, 0.047330884638452725, 0.021209835578056595, 0.021058655787079085, 0.03349876496940851, 0.018145018482520696, 0.03676181689145104, 0.013680873802983233, 0.033837954228323315, 0.0464589961413895, 0.021913311136285626, 0.017708380924417608, 0.006992400974981608, 0.10843416856181239, 0.04185142543827815, 0.019338284694259206, 0.038429866094262376, 0.01784181237340935, 0.07336611844479077, 0.03955189762036166, 0.0456989718030297, 0.0386999580528467, 0.014959870041498255, 0.026530205129435467, 0.06544427135057988, 0.0056554875317810765, 0.021325045625769326, 0.011017164065232201, 0.05548526623076009, 0.047585911478006074, 0.025038756430149082, 0.020960431823867465, 0.03429160468400486, 0.023241123454945705, 0.06114277192541669, 0.020911074694125883, 0.03542004836603038, 0.03201814683815164, 0.07773394576243817, 0.02575916253150471, 0.021770548736376148, 0.0492961070079717, 0.020557414034321424, 0.02300058525326031, 0.0215093472281531, 0.05519267043940002, 0.0017661845871067097, 0.08300221750452634, 0.013338214165771441, 0.027200145188779123, 0.025470828104223457, 0.09695801823850601, 0.010379370012801262, 0.055715659513108196, 0.08902349238914829, 0.021648961006693786, 0.0020535084965353414, 0.071830288356831, 0.040577467185475176, 0.0222728802492061, 0.022085269146989432, 0.04865759570572165, 0.10850198266486968, 0.009107483070223563, 0.04879238504555918, 0.008910802444593321, 0.03563848301588047, 0.13140310863814048, 0.032024564739737305, 0.0950546957732689, 0.04657175662296434, 0.07692731646520477, 0.060072045307606466, 0.027174511886832696, 0.04255839052700228, 0.06138787792635061, 0.02807511144407815, 0.005571306917831423, 0.05180204955620631, 0.12206904740343172, 0.02254703821944854, 0.03493381619092918, 0.04387717641469452, 0.0920030151704146, 0.1005263715201328, 0.012655698773150724, 0.04093295879541867, 0.03278289410856462, 0.0301321073164863, 0.05272047789466958, 0.010568947088153613, 0.047077347839912104, 0.04132496215583336, 0.07924967370326481, 0.06645847217089708, 0.057405710761104865, 0.026301171653152957, 0.06722358716351372, 0.03993147886508415, 0.05872225201117897, 0.019688727784781687, 0.12636883079164452, 0.037459144594087716, 0.0078848019550224, 0.05132231380670302, 0.013599349598911022, 0.06531900831408079, 0.044164497690695914, 0.02236779279736502, 0.08545811152866772, 0.035612727139866164, 0.02624742867004487, 0.031606286478739594, 0.05163167926272558, 0.026591681770139167, 0.020548565718795986, 0.04048089797218, 0.0228538257896059, 0.011097045010706831, 0.08490229175696451, 0.07708850136447339, 0.10197128229323896, 0.11497612276505079, 0.15995840782359724, 0.09470604149804962, 0.15760336161380814, 0.1461263379502681, 0.14088027509710482, 0.17945396653827161, 0.1602599859958695, 0.11739064804128102, 0.09105672804458488, 0.14325968290288604, 0.08364210010416086, 0.17103406270184826, 0.09209824756028191, 0.11172042528708136, 0.11519733065318678, 0.20361215086473575, 0.17006209630879665, 0.11768221344438293, 0.0885546389186094, 0.09589189963956034, 0.13561758813598465, 0.18486990172776485, 0.12913816969000524, 0.1503638920163916, 0.17284016094861493, 0.17854809821132692, 0.09476066356705082, 0.15404751854798487, 0.16654869451397852, 0.1419460872608808, 0.08962857161438273, 0.2476858633059648, 0.21981964488663983, 0.12364495921158984, 0.1262458736797975, 0.16697934317973354, 0.16008891856237767, 0.15025737515139967, 0.08716274909074269, 0.14008662332930874, 0.1278115965185627, 0.13662946770989126, 0.18454561670941694, 0.10402502612240853, 0.31072878609261206, 0.1235248059815457, 0.09576622291558212, 0.18914939144686346, 0.11936870238353169, 0.11855676409698303, 0.08758465669328168, 0.1466900254449537, 0.0995897907283037, 0.14906181833676754, 0.35183274337360937, 0.07372778855384358, 0.08839022112830032, 0.10412699242513027, 0.16399864828394306, 0.17046132004789769, 0.1405411892600598, 0.11140930165927257, 0.14741301326261413, 0.11316331358806742, 0.15768312668848425, 0.1095417631609786, 0.2491368491563105, 0.10806813175159116, 0.06006980450042795, 0.22402398138036653, 0.09311750456089936, 0.19436776788244325, 0.1469316036109963, 0.14065806363378802, 0.15918490416820974, 0.09380743568462711, 0.19436657278528138, 0.17881380814698436, 0.1931091313881259, 0.07472878201834618, 0.09748949939685483, 0.16502067086196717, 0.2112523610553434, 0.16482381690894404, 0.13298083607467914, 0.2342060713037368, 0.08566824944629785, 0.14052307894152982, 0.11971953234845593, 0.1999922781702011, 0.05952811139004846, 0.16861333211343135, 0.14400007623818614, 0.13006513607838463, 0.15387588420942908, 0.141407129084391, 0.12096471633882293, 0.10759920933313909, 0.1542658689281633, 0.11330325486919574, 0.11259656174168473, 0.07877626967045569, 0.14789403987026986, 0.1432590853543051, 0.21411733070929206, 0.13169595340807594, 0.08557954412554541, 0.09407514510976692, 0.1122950065520502, 0.08786336714101416, 0.19350218045855724, 0.11538628623971056, 0.12722401474151881, 0.23675921252898632, 0.1711353701689551, 0.21061594117312663, 0.16851508899802164, 0.1561761551326321, 0.2438708833388744, 0.16066602791749662, 0.19776037293336085, 0.24964137934148314, 0.2347230887220752, 0.1453698874120751, 0.324569053106731, 0.22842515650535786, 0.2578466253415231, 0.14524826329321633, 0.18130618327807996, 0.14214975939643, 0.15705216135228836, 0.1480327324280816, 0.2875132269916996, 0.11269068330406182, 0.18788975903824454, 0.1266759247969716, 0.19379972900834777, 0.20387828980963077, 0.20965355087912854, 0.21215927126186512, 0.15519586902472282, 0.1251354215726737, 0.1883145088269826, 0.10349381309483321, 0.09947945874544883, 0.13512681688993208, 0.17992641296117537, 0.18651173540180732, 0.18642066286936884, 0.15699288146870752, 0.12755581508240393, 0.1298798194095012, 0.23884191448169373, 0.0870971030165111, 0.23142731718478665, 0.10056148132970257, 0.08288638501037514, 0.20136964297102344, 0.18104353769411966, 0.19609051576304823, 0.11902498171454477, 0.12043733375086901, 0.18535762394387878, 0.1502757459398239, 0.11503630663238226, 0.11250676091520057, 0.18869894706914503, 0.20375897927630335, 0.15028147627749752, 0.13275339989171875, 0.1418326756045703, 0.2184817489356764], [0.06858596728453714, 0.033055211552568985, 0.06101491185085428, 0.027325256922913176, 0.030083340074446414, 0.027489546393494935, 0.08476108643076113, 0.04072489314562371, 0.04692777683357558, 0.0025298018778313796, 0.032161493380103386, 0.051399424386721466, 0.04443021911767222, 0.038296911535003496, 0.015217918140302985, 0.01561587017344972, 0.026853321863698865, 0.04437347115468114, 0.0595993499061273, 0.020084936967900684, 0.04288615358452644, 0.021112904388217196, 0.08747994013491177, 0.015794938437700752, 0.04963101383538977, 0.04367642307413682, 0.048179070375138716, 0.04087511915713549, 0.012997906418487191, 0.04314240233431901, 0.05994357236270463, 0.018365086814869317, 0.04634689449542954, 0.026880037264838338, 0.01850480018484016, 0.037090414984812664, 0.032892015672499136, 0.03716316269410234, 0.024804503979882406, 0.012096133789107686, 0.03253405342899984, 0.01425538995047851, 0.042914498837724815, 0.0825839871240239, 0.03960162438752671, 0.05818098024915784, 0.06843222875989254, 0.08626599721009694, 0.023760665132994616, 0.06801491002401999, 0.07935218392841278, 0.019848123868747104, 0.04108942076263409, 0.03183430297330263, 0.042056104979447784, 0.034761488542801915, 0.043709472107190284, 0.07265482112885484, 0.02693082506377851, 0.018500144285480344, 0.06755809179477154, 0.09612168005156903, 0.024549733779783693, 0.0637299312849439, 0.01777718711133686, 0.018836677134517702, 0.11122091297781277, 0.03600153591363661, 0.06379308757342159, 0.060079610425858736, 0.04976517881356901, 0.021347880791572314, 0.022602552780881528, 0.044758863176309296, 0.014168814354155575, 0.028903126085717833, 0.048760201691860156, 0.0063438917465147475, 0.07555383573015852, 0.033647807375077284, 0.060771066064555804, 0.023096750355175426, 0.03375485284073699, 0.029746221168146982, 0.008952196090362005, 0.03785438850642212, 0.032884278184463905, 0.03642294172858519, 0.031731478652105696, 0.058948378183788834, 0.023160923625372594, 0.02925290267974619, 0.08065290929329011, 0.09353510674930389, 0.06596220807442743, 0.02745374902001312, 0.03451381231688204, 0.040731619397598895, 0.037382715832321875, 0.10957240667794982, 0.03439532149763357, 0.014332074394089081, 0.048008508559676914, 0.052353027652228074, 0.055004427314645825, 0.04406431637283775, 0.03647325455301231, 0.07259754073475638, 0.13245061130052613, 0.007469119774478098, 0.07225245642926424, 0.02711283989370831, 0.06938868953335671, 0.05438859221495448, 0.0358118946784206, 0.021103100378006216, 0.038240362754872734, 0.030379921438232548, 0.006412108045732302, 0.01584122547008578, 0.05924638638633394, 0.09576777807406842, 0.012323860127869393, 0.014696759059123937, 0.02773052318051698, 0.01607724949867735, 0.07648349108715212, 0.0439806902150233, 0.0074038883453355206, 0.04384868177435091, 0.05788810483570542, 0.09733676444739105, 0.05975008919654835, 0.02821436707651423, 0.03354440848793715, 0.03452365271626942, 0.032924222008835886, 0.058516155207349416, 0.09593311516988663, 0.024688215663416252, 0.04741489767066894, 0.03348312911487395, 0.024939892783520684, 0.033788449626656315, 0.03233054983279398, 0.008612322140364878, 0.023501394166340752, 0.0295520925729145, 0.03717536647473613, 0.006538742858420818, 0.06697971073369827, 0.061854670620373184, 0.021448563897020875, 0.055324786132381815, 0.02002679664010723, 0.06550375041702101, 0.022559176882608764, 0.04915632277486786, 0.057826204931423555, 0.07416160116272588, 0.061306814332642866, 0.07534485460529405, 0.03351752263223452, 0.0038902265594280777, 0.05118867742919153, 0.1259885830504279, 0.0752868770711845, 0.04245148678760856, 0.03109607383638861, 0.026054167669386636, 0.06003368728523774, 0.04012889972317123, 0.0824086295981561, 0.05101934901528782, 0.06438652609264658, 0.04278607568853805, 0.015399160179039164, 0.03350907268242971, 0.03168666825419472, 0.015326718904919203, 0.03058765575500025, 0.03331352873975712, 0.04903216290497973, 0.05204289227784161, 0.04651207454322327, 0.03202076302841306, 0.04643044787489119, 0.014325526257556294, 0.06167681564787223, 0.027367098730117567, 0.022203020691390962, 0.06677216985413144, 0.06590023156135313, 0.07027807930905013, 0.04984883178446082, 0.03284287879303579, 0.04047050981992676, 0.012442794320504031, 0.052584370883602294, 0.024936087241756822, 0.029870153126877644, 0.028075270407322436, 0.05348933139635671, 0.0318868451135894, 0.028706170626044757, 0.05308770214117343, 0.04063158746688597, 0.010849424326161464, 0.03381096878119054, 0.033472518797122666, 0.04712497552616462, 0.035945611495164134, 0.02032020065422741, 0.029167445571792704, 0.012583419335104767, 0.12525428777500508, 0.04172292951073858, 0.024464251773972667, 0.017666303545176502, 0.029162452593746207, 0.05348647005795952, 0.011613662148104801, 0.04949799032821771, 0.09426203991977439, 0.021933851868755395, 0.042061578677666765, 0.053539372259570714, 0.025329009907680656, 0.022864051148175232, 0.04900680539468604, 0.05476035936284931, 0.02356445852426752, 0.055236165081301046, 0.03542877410748794, 0.06173390451998961, 0.021811637862194932, 0.04736881365158385, 0.08854433503602782, 0.038433436063989516, 0.06770682010439134, 0.04002267780203012, 0.08170323882011638, 0.03488058840195018, 0.05265660148354308, 0.020706178733117638, 0.043340286675600276, 0.004358718532227701, 0.0375439198837886, 0.04293959204768462, 0.06253991711644397, 0.03194903230084287, 0.08931983052001846, 0.03874904513659497, 0.016845193270954396, 0.08831839272451979, 0.037492618805939154, 0.06560117381835176, 0.05378309930224092, 0.008683607579329082, 0.032306199728120724, 0.05901141189819863, 0.035183828985018116, 0.03010271826849109, 0.01446303042147549, 0.10869188053954033, 0.04209243669925679, 0.03600748458636865, 0.02947040270232866, 0.007070978613375056, 0.03340214596039826, 0.023908347732597784, 0.030789925949648026, 0.007382999042860203, 0.05454534529558113, 0.051647131256158316, 0.05157680438470937, 0.040510055278578115, 0.02366723688018899, 0.11237078030864078, 0.023858155567018736, 0.07465731367589006, 0.06132796602023225, 0.03040246740584412, 0.05323921901083762, 0.08739051469151052, 0.008911513948752996, 0.04162335723278023, 0.027003986460547295, 0.02440675687525542, 0.04428548978701715, 0.061427714498413194, 0.05379782351214559, 0.04705841780730313, 0.01096889669556291, 0.056416561015911644, 0.023838237280987447, 0.09139544615942626, 0.01905171418442361, 0.019926762794174498, 0.08220596869866695, 0.040412110937458855, 0.024231253792682005, 0.010454675498148127, 0.01622444180200898, 0.011080396962502312, 0.006941388616518628, 0.06230608409931583, 0.05581019093252479, 0.13635021333973255, 0.0209102358278488, 0.05056984692571625, 0.0674505943372365, 0.04433043999597431, 0.05065371440122685, 0.019791586579935207, 0.006858737784392771, 0.060400030530628666, 0.027634260402391517, 0.0547684109469335, 0.014428621582356433, 0.13091390021145344, 0.016194087483229178, 0.019427947624916994, 0.040000128003978924, 0.022144495404415557, 0.037692690328244245, 0.028072650386621396, 0.019194336773286906, 0.03184584600310172, 0.06426458787773887, 0.04924199438744015, 0.025703925676944277, 0.01895242535899724, 0.041390681008417765, 0.017673075762427142, 0.04462770126279324, 0.05697132358627935, 0.05541865871618352, 0.02145619987840614, 0.033607924837739236, 0.024771152342098857, 0.03876245167526988, 0.051640918283092405, 0.09076526989379237, 0.08189780217024588, 0.05124403877303966, 0.005745428648116368, 0.013882998440925394, 0.10016918302543702, 0.03191106306809572, 0.042683672715699485, 0.06101544045152203, 0.16007298393355263, 0.2111822180449963, 0.11811379673740557, 0.12027541340719308, 0.11934580401547494, 0.2189759982209052, 0.1343084817692157, 0.12340104447737818, 0.09806301579960892, 0.21275963904636525, 0.12481105994553336, 0.14813681313347432, 0.10143652227857422, 0.06062521058465205, 0.07736209434487167, 0.28371854835460264, 0.15596767196491843, 0.30356641558389513, 0.21197170229448428, 0.07618857787982111, 0.12326978297243196, 0.22311691795625996, 0.22842000839450669, 0.1257783072369714, 0.08526304256050818, 0.1179861588283412, 0.18550460557303122, 0.16244204955235605, 0.0795973090815448, 0.07846566698243541, 0.2645156965140374, 0.2698974948256247, 0.12910970186273898, 0.17476929291602106, 0.14122766532724904, 0.08488837960025958, 0.12172665206655381, 0.10408928557749718, 0.16256324466197722, 0.21345616618712104, 0.08710416634717295, 0.1286590123368848, 0.17314966047002425, 0.13798095406063143, 0.15410567994319624, 0.1796444466397647, 0.1965811491132744, 0.16949281637226382, 0.1245683249867251, 0.174971126440552, 0.18854795113926937, 0.1552480549341248, 0.1666875556111336, 0.11591304829644582, 0.15634201316823884, 0.10505306249063824, 0.17454116725392882, 0.11387969772782057, 0.10918835914062877, 0.1496184884660667, 0.1369492634530029, 0.2590521719426878, 0.2107225806121865, 0.10851269257405113, 0.1711830514813623, 0.14887167531396114, 0.24430330932861377, 0.11880230293759417, 0.1261083685582684, 0.09929989539687673, 0.1069521714722918, 0.0931883140677406, 0.08574347161958296, 0.18873237914616064, 0.08222769495219955, 0.19583228284553175, 0.1320795029882462, 0.10898477893563048, 0.13250523336952733, 0.1846169854604429, 0.17289656034160047, 0.1513045713786156, 0.14917167534510936, 0.14226007605752639, 0.08229636707373204, 0.16377796899647484, 0.07916456133487725, 0.06736375061014006, 0.19843191028602664, 0.10042481124401094, 0.11185050701662419, 0.19509051055196794, 0.17638576907976983, 0.12346146583196618, 0.13226843559213225, 0.11468732293935553, 0.10426911705684277, 0.08881635753618133, 0.17497808251890445, 0.22616521245048893, 0.12865970181601663, 0.16121034870945639, 0.23111332838814105, 0.15182449993106628, 0.19317060228317015, 0.16641268326390177, 0.14221421803437895, 0.14004358450972265, 0.2164934136934819, 0.10370774314768853, 0.16123890846727357, 0.14427404460166732, 0.2255537823563622, 0.17016731082431732, 0.12875036066097598, 0.15394486276613129, 0.14265510163480236, 0.11898515280336143, 0.11711988192532333, 0.10600831284518204, 0.20653060877755766, 0.17494249007394239, 0.13927441691198658, 0.20102936203681654, 0.12191831960432953, 0.1148609567673937, 0.15208152242966239, 0.0648323126557854, 0.06354046241951085, 0.09178307132735368, 0.18237501382827762, 0.1942946830944669, 0.23183884429595164, 0.11782427678906149, 0.20173678294785563, 0.19129809953512686, 0.12859596330071651, 0.17760698983986534, 0.1250270890793012, 0.21477593649779597, 0.14738184880585442, 0.19893014322846167, 0.11070352017639146, 0.11906581420090892, 0.24850999005138877, 0.09158525210354598, 0.09157414382864391, 0.09846451481984508, 0.11474882447791677, 0.09000858952922207, 0.13949505023417935, 0.18399950327171435, 0.1356685176611908, 0.12158282671964939, 0.1299888183993678, 0.12537927501985144, 0.11606946046794615, 0.14078396252326428, 0.14895185407611633, 0.22330889959008465, 0.17099457853023084, 0.1281723703047441, 0.20968241707211543, 0.16183055817119538, 0.12462711457403437, 0.18842572947182964, 0.22092955307133738, 0.24466369240995378, 0.1980466293471475, 0.1359394982817673, 0.08194792730313155, 0.10472265642977531, 0.17560788340145544, 0.20692914303752685, 0.21227285145751892, 0.22193299035631844], [0.05988874344996387, 0.052009659383686326, 0.07355954798479235, 0.03523964615118119, 0.015375578077510001, 0.030240483859914447, 0.058452435844247384, 0.046490482355077425, 0.05121006277359782, 0.020153879135426496, 0.01666177075446373, 0.04632689960060581, 0.07233310250505325, 0.04457911979707499, 0.03804356625844394, 0.04421999693037041, 0.005408585054664723, 0.033698407482476, 0.044475088887397325, 0.05063656552304184, 0.04825269908554131, 0.028233115163241184, 0.014733006509261267, 0.03466283940079232, 0.026036944097628998, 0.017237997193249966, 0.01611660535056745, 0.031907968072881626, 0.015243783183846504, 0.027745645756142277, 0.020675954649284966, 0.036163605644457766, 0.04765731853342826, 0.03268901003344405, 0.030898105225435672, 0.04610230177340489, 0.04351021646852455, 0.030617408694759495, 0.024956386656530445, 0.01572053885132435, 0.023136125359263633, 0.034741191043248104, 0.04597127009483595, 0.01898198294633579, 0.014763143450592556, 0.012808547678193258, 0.015385348571374293, 0.01652688948407529, 0.06664011927862322, 0.05010808742935619, 0.028556687719819528, 0.04370279565093018, 0.011624293533274004, 0.03415547469029984, 0.02633766808186568, 0.009479616025102236, 0.017567426492009434, 0.05249527102756885, 0.021204936445780823, 0.02960453895221074, 0.04462645253947666, 0.009659146814937554, 0.0500833006545661, 0.06660376074573686, 0.0160758801165127, 0.0010595285669795329, 0.013271474501027936, 0.059255882046155395, 0.0958699512205297, 0.04535880961245106, 0.027865548092391224, 0.03034925110818398, 0.012151042183470583, 0.05876657402803821, 0.04099565543114178, 0.032416608319768024, 0.025288064423347675, 0.02507232640299105, 0.0076451409240103066, 0.05694089074348731, 0.0602090371502263, 0.0825025902820691, 0.0877052159499257, 0.01679319696831367, 0.018463820226550586, 0.02142817063647653, 0.06236685019346976, 0.04699691243830228, 0.005786156755000834, 0.04888949818128059, 0.08030510537566678, 0.0118968503797547, 0.04056726672476338, 0.016917642205953598, 0.07179966016161828, 0.01563963230564109, 0.04922083503897152, 0.009914295270948881, 0.02443970057121929, 0.04835149761469615, 0.07720484713753385, 0.014091796662297942, 0.03194014951136084, 0.06424348981630418, 0.024402980061788714, 0.03479319692198788, 0.01068036787347087, 0.02821687792968606, 0.02818592606232532, 0.03697426456417288, 0.06264340793413502, 0.04035823580418383, 0.11776500456635991, 0.0725267771931906, 0.13552728169147046, 0.028934589316768032, 0.057753464883013125, 0.027270541008141254, 0.06858208321876104, 0.011899054797756816, 0.013946955291283949, 0.04531626875001577, 0.05067459412760312, 0.05324301497650243, 0.11813543106038725, 0.015285609669292407, 0.023864707533991145, 0.04377272032621888, 0.012984892499873476, 0.031000651839760043, 0.012633112585923124, 0.052053613678341916, 0.08252977108162257, 0.06764313521524591, 0.019193957559764385, 0.02818775701246435, 0.05563787094527676, 0.014019422420871355, 0.027684870085889296, 0.0512403232466069, 0.03893201374599049, 0.08259332573582089, 0.03437315474354452, 0.014785315950341044, 0.04085843376214466, 0.017329613648114667, 0.007487307659410422, 0.024196371894269705, 0.04344780711577304, 0.07088328110835246, 0.0071852573854548326, 0.013427588855847718, 0.024799206481886008, 0.06515291279121753, 0.005764464017814927, 0.07085659060507052, 0.014154336249996579, 0.016109411784958456, 0.017565076517301704, 0.0180305840988313, 0.05839827725844038, 0.02797801554533503, 0.12350906287470173, 0.0413790900981234, 0.0259098022304956, 0.032101326749750206, 0.03075713547126901, 0.03252296430629588, 0.06435595918446779, 0.0287951996189452, 0.031456636948390834, 0.04743932055369501, 0.03672837332311658, 0.03885771470865415, 0.03830643017746268, 0.04414296678958401, 0.09673337061559001, 0.05038262269790134, 0.039126822244255774, 0.03985077916314045, 0.017861709592022726, 0.06889337538591317, 0.03711138664173984, 0.01075492067743213, 0.1168154462450935, 0.01683693867357027, 0.0173297266460835, 0.04555749834605283, 0.0024681981144127466, 0.03768022224727658, 0.026933016075241952, 0.11880935860737679, 0.0495074017183675, 0.0211518848570244, 0.042473055993116675, 0.043339486113719405, 0.02792682171979499, 0.015083124970025836, 0.0441924867130095, 0.011921329761765177, 0.0493028370903865, 0.045138000090035706, 0.02970680211400313, 0.0232150458220032, 0.04104664624338189, 0.030387511454342358, 0.043465404155393766, 0.03793446384670754, 0.045309695715625445, 0.0456474983553973, 0.055976577568799264, 0.03080231167616383, 0.0429074623201403, 0.017429222315249425, 0.03652301962457357, 0.01768549596289954, 0.028028209626133886, 0.012539403753415232, 0.04783401671316355, 0.010831994868274178, 0.024826517516386606, 0.011476511342240679, 0.02583195812128965, 0.01556797531403361, 0.09486376367990049, 0.0516939468892111, 0.030012877222390908, 0.006214897383019449, 0.05316399683755252, 0.014466231711389077, 0.06394193079623003, 0.059653987296886986, 0.033436895708643624, 0.038772579357628865, 0.007912469699212742, 0.047413338681743036, 0.02297302524018432, 0.027925425524552985, 0.05049945876723336, 0.06911039277310334, 0.004679502528761664, 0.020735224956766735, 0.04013149676123454, 0.024223908924707965, 0.033568720288214185, 0.026639989359424483, 0.04768839105963708, 0.014743206012363156, 0.040671784100272966, 0.013657263930766814, 0.018712323827428684, 0.04366190953841133, 0.022790663755468787, 0.015664331937929796, 0.02462554201033087, 0.03757593086770466, 0.06158321119484402, 0.06851568637836365, 0.04769091148890796, 0.021514725165381547, 0.008077941339222655, 0.017671217999210762, 0.03508483127300297, 0.041861419055250385, 0.022514404789094004, 0.018806838009866978, 0.03233303578810827, 0.020174331767784975, 0.039192403201013803, 0.03204436619736014, 0.021211959556826664, 0.04604187275793764, 0.023936076285017115, 0.017787671024580638, 0.014685603861336508, 0.07278815873207585, 0.012832151804750246, 0.03284981954962977, 0.03608351881285349, 0.04856836178430146, 0.0359125126663956, 0.016475659269358844, 0.017944998671150496, 0.013314259553989096, 0.025165051770126148, 0.04917722165344223, 0.07684612646698952, 0.03873663834266124, 0.04725823652059321, 0.08347746014835374, 0.04004487519963615, 0.038050533828115275, 0.047970951099189064, 0.030300822860050588, 0.03161979069362485, 0.016897748817779848, 0.026948077363833308, 0.021519256575453668, 0.035684988383323915, 0.09209170516940857, 0.1504386621978014, 0.04119835463502715, 0.04939285625192908, 0.026923654480807246, 0.08850471296858403, 0.05070095521307761, 0.005747557414935963, 0.010666099485881146, 0.054057171087591886, 0.08391203884516032, 0.02010412172474448, 0.0542332832100651, 0.029456842946068897, 0.0436420563698536, 0.010380597668699922, 0.03026785235100937, 0.03970077531712671, 0.01741055466775452, 0.06650210087818485, 0.13138345082200345, 0.017147531785491495, 0.047958440883385564, 0.039350745914083336, 0.0713664451013169, 0.02525759519137923, 0.05834075554664578, 0.02128816040743503, 0.026234952928197962, 0.02565526185677417, 0.03325501877454019, 0.005296367537906213, 0.06138765193041294, 0.012617209558224967, 0.03473842546584145, 0.034925764606844996, 0.05646827961167982, 0.05685197091811607, 0.039096297470912825, 0.060432190901689956, 0.029650471668930787, 0.02429472417720864, 0.017632574609090245, 0.01999426088596304, 0.08478488112168928, 0.018234690989277536, 0.05493302025922364, 0.012215874289282629, 0.018211275511871905, 0.041251930994011705, 0.02268909198802806, 0.07377155515695773, 0.044253329415955854, 0.11672088035172033, 0.17023648856387985, 0.1621863753685067, 0.1334153764670895, 0.1766265351926127, 0.1265739125289744, 0.12181005605887021, 0.20451975055038932, 0.1498516856302177, 0.07432030393711983, 0.17083250496897007, 0.16582901619615095, 0.09359475435508836, 0.11686780069383884, 0.17032894005458202, 0.1857159845530987, 0.12444489290036502, 0.11190834665490736, 0.13878169980260635, 0.1490855057753863, 0.1131184591401008, 0.12326390707805274, 0.15801740149336477, 0.0934161639381801, 0.08449177588185958, 0.21447840326976395, 0.159311844937263, 0.13363231724548724, 0.13642732775019062, 0.07626027604865451, 0.12248903978616, 0.2129729332462434, 0.1388244475087812, 0.12169105196071249, 0.18870553542529384, 0.13291374209427065, 0.07843717617253143, 0.09947321512886595, 0.1147404358151459, 0.11388720538947852, 0.1293796865690139, 0.15384133364404404, 0.046883175194623976, 0.1398803005295415, 0.16931358244149916, 0.1634763755024441, 0.10285294990265563, 0.13850900314507947, 0.15497618565155616, 0.22163420074409057, 0.12576883072934805, 0.1185510490810679, 0.11281456738229721, 0.28614012163973623, 0.1753853808247274, 0.23605862512223183, 0.14375846742862655, 0.11058423262570174, 0.10612098139620597, 0.14382931523986403, 0.13508917132933296, 0.20687795304242643, 0.14152749681905394, 0.1570013237576331, 0.10761786357409532, 0.14128164388239384, 0.10976886992613155, 0.10625060347299423, 0.20948876536661581, 0.15060887161281802, 0.0780712083102234, 0.11729428950216501, 0.26220572691771293, 0.07229335020266234, 0.0763341192636759, 0.14027089811861515, 0.1110008925259594, 0.09229429712098453, 0.12751032478146015, 0.1829765613881811, 0.17776368546389765, 0.11269516491841887, 0.15907556809965642, 0.14792491321361836, 0.10252534772359556, 0.1529758534724674, 0.1441666543964417, 0.1966504647486633, 0.08594810902591675, 0.13381388008354173, 0.2865278234164561, 0.115599557456951, 0.21369166161504485, 0.16164062965300777, 0.19166790549793553, 0.2093635559562714, 0.1696616008637413, 0.08538432960068026, 0.10784506226979917, 0.16161115058968145, 0.12359361599890456, 0.0765550053948837, 0.09201609995216133, 0.13437540721028082, 0.22075698410551395, 0.10527640010320372, 0.19207025487576762, 0.2092219675861059, 0.19600108265876773, 0.12058829903722772, 0.18131831811080057, 0.1911710208702472, 0.17082185634682256, 0.2862363422830259, 0.2719338178153961, 0.19225483610024377, 0.14186171033690054, 0.14028392161332792, 0.19564342685043815, 0.12727634620762643, 0.12463443071371126, 0.11040626274001215, 0.15346458692464138, 0.165588342013859, 0.21347680459580115, 0.12068215246883132, 0.2249897884265069, 0.1787318827043618, 0.1326081036559997, 0.22889332815764413, 0.08137729905185201, 0.08642596402956594, 0.3108834745662828, 0.23202431418241995, 0.07855035800246463, 0.13761862511596373, 0.1478191471147922, 0.08978003485789222, 0.16124402593460777, 0.1742570099210547, 0.1300823883784394, 0.12118493597353659, 0.12805947192734288, 0.18270973296415421, 0.09345789274741566, 0.12052360291202223, 0.14315610781552332, 0.1349047126789247, 0.13385956956734582, 0.15196095551213912, 0.15050681337954538, 0.08896598216867255, 0.15047852941338094, 0.23126581052858985, 0.09271569144461425, 0.18922621474391033, 0.09094845683824632, 0.09321664399918049, 0.08489672995863423, 0.11002572388538431, 0.117622772682338, 0.07691995436025244, 0.20179477580372365, 0.10365875948581005, 0.25305522034966177, 0.12210788806119274, 0.16890014011052348, 0.1368599529227903, 0.14804828401294448, 0.2425368025057739, 0.12043904212694015, 0.1161895217674394, 0.18351826215943984, 0.1165303236414348, 0.12786226557387462, 0.12850058535414358], [0.041573584500339725, 0.04410306126960824, 0.07785372360939942, 0.0279178221019045, 0.1437783397493824, 0.026542382096991907, 0.05170046629744673, 0.02459168475451729, 0.025031250683710943, 0.01455973657298713, 0.055017182678585096, 0.047885945983110904, 0.035414482737260486, 0.026419857824822108, 0.11124916630046022, 0.032245429803527174, 0.06840887073908122, 0.03088480402385035, 0.051949766629766074, 0.04604679104241152, 0.03432739248138762, 0.034633957886046944, 0.01613996337137876, 0.041260074508646806, 0.05588109620035656, 0.03010686663460107, 0.012033926492046204, 0.10195905552996744, 0.046996854981707956, 0.035579953898465445, 0.06395000536295195, 0.03854543811851933, 0.06336068456631995, 0.06290440642905813, 0.02439116315555669, 0.028154154480885596, 0.01364004227422899, 0.06447938360994862, 0.04215150590865843, 0.05597124559684627, 0.05099589906392559, 0.030903908341462095, 0.03914302500385431, 0.08343264400478333, 0.014466843624118597, 0.01565743810422118, 0.04990574828679523, 0.011970342151940832, 0.055793517028852824, 0.03754655522624812, 0.022717153788694454, 0.037484325904158816, 0.10042320245936995, 0.04405464834323333, 0.04868655382925945, 0.05518583310467582, 0.02543705128764193, 0.05704199519729423, 0.04179550101980568, 0.012244238694679114, 0.020227574878522468, 0.058109810680992184, 0.021299257191018234, 0.02902231979063682, 0.020402991776204398, 0.014848135160132041, 0.022935473525355903, 0.03598408060028188, 0.05004057593102898, 0.0632356092213623, 0.01174060387476798, 0.04011322556424045, 0.08158411980877, 0.08400928604626849, 0.06523156703840341, 0.04404871116182016, 0.05108676092218488, 0.04957937950929327, 0.06918001484366194, 0.0412169399280702, 0.08963918959301326, 0.029444328899825775, 0.029313165071089903, 0.06382222955806122, 0.033714656207349994, 0.016961550535333735, 0.06255116711761202, 0.06319105737812578, 0.039214198402459585, 0.039574524027205286, 0.0033754463572310467, 0.013809728834237305, 0.07122028318624343, 0.027477359849839445, 0.027337299825082866, 0.06664022653093261, 0.0569239218959645, 0.023016874197750323, 0.0892099122246427, 0.035519785352892456, 0.031638184464686823, 0.028272302475787943, 0.03202436555687699, 0.05011282568316787, 0.06501759102027263, 0.034877677267837914, 0.032173486486557996, 0.04210867776325153, 0.01317804050256288, 0.061262886851064624, 0.0861375242651951, 0.06754185839165604, 0.0742885112882622, 0.04249339562750632, 0.04677168258856382, 0.02313417758071615, 0.19805266611999084, 0.046806095258122495, 0.04250268444358822, 0.02799333921904045, 0.11376342090267329, 0.05539104124651321, 0.10312904032968706, 0.038699755039546764, 0.019296601850299105, 0.06463228709875576, 0.013779699145215414, 0.03639933855963811, 0.05862587048942524, 0.06112005741846177, 0.031277314917514884, 0.016293232667169744, 0.03129440825432539, 0.027879724549430034, 0.033679335723601045, 0.04518072098313321, 0.02060198119931644, 0.020578667228560776, 0.012451675194766254, 0.06401741343940939, 0.08291031759712966, 0.010774529655463995, 0.09337712409755877, 0.056399350850692684, 0.024736998227214622, 0.039769359338547916, 0.02303761794352003, 0.03179708642194108, 0.056498291106113506, 0.03242718033312309, 0.06992803841468788, 0.04987461447355248, 0.013622907760192551, 0.060751565296443245, 0.012032371333559916, 0.04455996376852836, 0.05073196645225248, 0.0271352996764284, 0.016079471153657765, 0.036548993835646304, 0.03569010968109773, 0.03373368966182874, 0.02555146460391341, 0.029865698325597954, 0.04768231981283715, 0.04575797589495779, 0.001174726046062255, 0.05282582264513739, 0.05688556387359577, 0.06296980735515395, 0.0703010006597446, 0.0192386492140471, 0.06363177626964546, 0.04128835847481124, 0.0378301341627394, 0.05453918211823029, 0.012596378669953875, 0.06202789459137186, 0.044972299102453456, 0.05850600071191307, 0.10635378785551557, 0.024587139937906496, 0.03934232277735587, 0.0401040708135453, 0.02874843186638769, 0.016935244991233753, 0.07277865158093554, 0.021122005512757648, 0.031105322432854486, 0.027960439573132226, 0.05262619162338877, 0.04746779604184051, 0.03790031164704311, 0.007918442790997366, 0.036030344650029175, 0.06731660555927985, 0.06427319870600778, 0.029153876239433888, 0.04874181941211705, 0.06737302027402386, 0.04170483451396708, 0.05495391147691877, 0.04038640868759925, 0.02430628061354641, 0.06546800475447409, 0.020784335023152734, 0.10127818722638393, 0.02271892536701935, 0.01647199353864116, 0.02808074410554142, 0.018647259980019544, 0.0789888897129605, 0.05779966764572648, 0.12577871326357126, 0.009461163839836036, 0.07421213232221142, 0.05301222715887332, 0.05025455577959938, 0.05709339969701344, 0.04352858342650918, 0.007504991841532531, 0.05566925373709491, 0.022305126805158875, 0.03311826058873727, 0.05561146772496643, 0.040268844834739165, 0.005225224304012955, 0.0391479088143716, 0.14956850888988665, 0.04046832646934256, 0.011797377693226502, 0.026085445124115196, 0.024298813171504487, 0.042369867780155716, 0.021598818636829817, 0.03047435326621898, 0.02552330321181686, 0.045349222022078695, 0.05044880886411956, 0.040731638549797, 0.04431080899291462, 0.013974855255876339, 0.05581612811393796, 0.034789596308743766, 0.0686824637194795, 0.053383940680613445, 0.016813571076659907, 0.019256975952415697, 0.09616725462218446, 0.03805653995744163, 0.045391502414619735, 0.007367504435786678, 0.01650614956874521, 0.0234019655298682, 0.06323517638168509, 0.0030487589350330735, 0.04828251522755431, 0.0689068049072258, 0.015371339696068919, 0.01673270283537286, 0.07568590162742524, 0.03195880758275669, 0.07713802894877811, 0.05591784160764468, 0.06441330852647943, 0.07698393802368834, 0.008510235178795074, 0.03448798749295454, 0.05066477288041384, 0.05956139024947921, 0.0409126689567441, 0.024901630522142497, 0.04472792471548723, 0.061133138369768865, 0.03284941735346952, 0.03822561556233033, 0.087135529986793, 0.0251749936761635, 0.0599267797154044, 0.031271678425611994, 0.03399608243677405, 0.032710900995880365, 0.04496069670084023, 0.045283284834435875, 0.030174454741720712, 0.04905009319284751, 0.05695411342106039, 0.06845756328754848, 0.03484347144201879, 0.027940584489354686, 0.021056792278203274, 0.027602866119254502, 0.0727089912059807, 0.04233294617264502, 0.00040464111788746635, 0.027797622906584895, 0.05016707619952579, 0.06308069858219355, 0.02772328364963253, 0.06538391894390506, 0.027849130828173894, 0.011708418605849149, 0.020914106487086224, 0.024546814984792185, 0.03318434716352532, 0.02959806359403076, 0.05027161272723348, 0.0034023999638344736, 0.03839509336337928, 0.04416815193009473, 0.039570751044178204, 0.07568230867506036, 0.059827134659093235, 0.042911388520752235, 0.026191278255634734, 0.0155371546392299, 0.06276959410658287, 0.049966491398311434, 0.05266106394570201, 0.025374590223955534, 0.006776036677746884, 0.03139995410287332, 0.030359449653675964, 0.0178489982781391, 0.020106789625940785, 0.060790551510909875, 0.04120832143892204, 0.018046032261824416, 0.025102634756495396, 0.0466611820663656, 0.023590656816058105, 0.050087747794966546, 0.04312582036119796, 0.027187749886164264, 0.035503241684167616, 0.04278421792532167, 0.015872560381408662, 0.029107660070181857, 0.05965640047384847, 0.03548712319424076, 0.03403018867116302, 0.03842539597122419, 0.03336333977659384, 0.010669445374890441, 0.0196406040565982, 0.04117516515355918, 0.03891643151761063, 0.0024346942166542456, 0.018907862024441845, 0.048084152081320365, 0.037678272553509286, 0.046510534706495466, 0.1786957846413697, 0.19258086779905906, 0.13213771034873303, 0.1058505063936595, 0.2378266181556448, 0.11141270308965638, 0.1329773733572614, 0.0799363719359521, 0.08304799125800211, 0.060060224570934816, 0.18190704135885163, 0.12316803117432903, 0.10667993446751949, 0.10053325865057208, 0.24012627620850843, 0.10634196711884392, 0.09741872053353057, 0.10283708422174377, 0.170014338387597, 0.25269474533777087, 0.18892468253691352, 0.1374060203952174, 0.12932673457168764, 0.16938527294945332, 0.14054537210012638, 0.10549694915572483, 0.09694129453911897, 0.15326558792543027, 0.16145912810198723, 0.14347037240382166, 0.19676179264581975, 0.09972105223324992, 0.17167013018361985, 0.11538253240888158, 0.09065897519429846, 0.1861710254583628, 0.12667825370426142, 0.23312483012916582, 0.11518214679052753, 0.16008792264807611, 0.11359380903623759, 0.1083377410747832, 0.2235692775537891, 0.14851155270251537, 0.0646411890404359, 0.10828281257061229, 0.16285213641822338, 0.11254482782415806, 0.12866567730182601, 0.18330671464002904, 0.16591719291623563, 0.18898328826312097, 0.2582381575578644, 0.11379937340895976, 0.07287811277614487, 0.09628882511488854, 0.12209651931639641, 0.09817815881462828, 0.15093850392487743, 0.11161143395809398, 0.08333857606856093, 0.2627973306563593, 0.11404951643799582, 0.08626415093819942, 0.15217362151991937, 0.11373940404624709, 0.10171238287922837, 0.22010458362919672, 0.2632865544048048, 0.201900894302995, 0.08550429896962258, 0.2120079842185782, 0.15090844263472866, 0.20058103206176914, 0.09178263465723685, 0.11953605429059076, 0.13964656710384354, 0.11289488404027878, 0.15204183907518465, 0.12260370016578706, 0.16559243292337464, 0.13148362447898235, 0.12764305717522098, 0.20262976567591393, 0.22287867993356722, 0.08398681668744934, 0.1574547865217732, 0.17195133041710625, 0.2490555059405104, 0.2518288668004736, 0.1516443466947925, 0.07577562584511696, 0.17637544221455054, 0.14487566877036326, 0.11143069083411848, 0.09458651646010338, 0.15476814681483855, 0.11432174578188889, 0.2290208971187953, 0.1296068009950461, 0.19203273188923636, 0.19805796744842685, 0.21201507819275703, 0.1289476283014782, 0.11246351525187494, 0.084653680903777, 0.11799337537658793, 0.13777840041345166, 0.15940495526358006, 0.09939102921634914, 0.19970983687427737, 0.17920253648152276, 0.14315509657946326, 0.20988169186297925, 0.16679750455002632, 0.13841085196022065, 0.29610064361364613, 0.18645346675428653, 0.08482533056409129, 0.19921950995922091, 0.25688383668180437, 0.1691865344201365, 0.15605846870570414, 0.19531034714271947, 0.08793475121379861, 0.11936078869527388, 0.09793070475420645, 0.1022143543307339, 0.12978183676398572, 0.13062004420545795, 0.20767568039797968, 0.10801196218498292, 0.14363744085834873, 0.15443192614663034, 0.2552539233358637, 0.23966075522044014, 0.16651809696228276, 0.1258357561704132, 0.15813888771639717, 0.11980078363370512, 0.2605252058034943, 0.10496812632247325, 0.1751448751817788, 0.10971581833737512, 0.11492068864284985, 0.24585451480121384, 0.1398109082853602, 0.07272841153486122, 0.13953785922738815, 0.1977550256396494, 0.149997211692314, 0.15864818296845884, 0.12058803090645422, 0.20692535856318092, 0.1815910760553614, 0.1437431916354164, 0.17826271513777395, 0.0809726054449716, 0.12775299079235525, 0.08505940106847594, 0.11869213949408262, 0.11913526773212418, 0.1674138988939024, 0.15267153270542622, 0.10317007965979078, 0.14118828840794104, 0.09511048229591501, 0.1368483390298582, 0.22398596809756374, 0.2207454314996158, 0.1338744776383523, 0.07010712678874693, 0.1260434043022894, 0.1397196672135784, 0.14259882481588473, 0.13798348215078154], [0.04903094482518012, 0.0271496350967115, 0.07513385866918872, 0.028498447800595916, 0.018029193649248734, 0.019185768079853827, 0.0740843948217169, 0.05898283681862297, 0.05800486046580538, 0.026700736301380302, 0.012426540807580516, 0.016281431082696203, 0.04412863328452072, 0.048787807670211604, 0.010965839047135125, 0.0317086779602593, 0.03445591139156492, 0.01557349497752805, 0.020954283968275113, 0.028495488785988385, 0.06099184494345419, 0.09086033374431635, 0.03473582459733852, 0.018258066247067144, 0.024695052998140458, 0.02953067466977143, 0.007125776882598838, 0.04386181252137308, 0.07862035545610613, 0.08656423523901932, 0.03979795357032169, 0.03488501639015252, 0.06153418922856931, 0.03120352915908781, 0.055104229418981465, 0.06001428993899496, 0.0255348902916716, 0.040996436840824546, 0.01609620634436367, 0.06517136784931345, 0.06025151672562765, 0.02281410796117158, 0.08029699250454865, 0.07336052600294352, 0.046620954789461634, 0.08420634684303115, 0.06576906964783708, 0.04147307759511375, 0.03907703802049641, 0.08011729892102942, 0.02078953292971898, 0.023974616253267855, 0.010642649534518921, 0.044429498995023395, 0.005254257121123374, 0.011948483748241298, 0.050290266968189716, 0.010209277426193078, 0.04364949508359836, 0.022227640842057528, 0.015696186831431286, 0.018644885107454275, 0.06660060446348882, 0.029362085530714645, 0.011126760603679765, 0.024005807523104935, 0.0039418946412737455, 0.011786450406596547, 0.05597894478048529, 0.024432016709338755, 0.03758039332986359, 0.031945504465951555, 0.07337488249064454, 0.04374932400101135, 0.06393102936506753, 0.06647518820940487, 0.01744292188255537, 0.08902341578035586, 0.05654945045769696, 0.06894580644345091, 0.030944656558154576, 0.03422053087682974, 0.05094427239870833, 0.06748692222660588, 0.03643198539653132, 0.04527961144283895, 0.024673286524991837, 0.08603936541945705, 0.05994982747060638, 0.08828808628623525, 0.022763869830317075, 0.06646562743210985, 0.08203352996779066, 0.0905959491407679, 0.05462843136140897, 0.027510971957517248, 0.054489259998644554, 0.06990811246777735, 0.0482132149139239, 0.05917584117982657, 0.0225510218766548, 0.041246323230405973, 0.029931440160820083, 0.048882886842494054, 0.03720700207556929, 0.060510600000740065, 0.06480288721861378, 0.038233548402786255, 0.019090995342741092, 0.025211009384703734, 0.014356723273052804, 0.03212942877003262, 0.0323455345125929, 0.04096995318128217, 0.05886805769536765, 0.03747797120482691, 0.040175374447097706, 0.029919023790787307, 0.07273037271994738, 0.029415698278875604, 0.021654871375029607, 0.05603135285538532, 0.007533197283684727, 0.0273402952288668, 0.06520819369583361, 0.06738139361503624, 0.06165176074230864, 0.08992769064441805, 0.004224892547954956, 0.04567966255689821, 0.05136290880581064, 0.021716127765455076, 0.012036783042393867, 0.05545025984306009, 0.03938699336422067, 0.02524306058823582, 0.04580454637987479, 0.05099805177099282, 0.01714546526331575, 0.049625907859374443, 0.10249478847629602, 0.04727058585793261, 0.030287651893412395, 0.028715601168392647, 0.07326516337812909, 0.055011253158051165, 0.07064587046061793, 0.06877070172659813, 0.030092512062119863, 0.03113179843151762, 0.08694621433894481, 0.04546971233080953, 0.052155660420295694, 0.02062533538968813, 0.07690304679976356, 0.020563860664204247, 0.045787554549714254, 0.031841123071048534, 0.04951662541697583, 0.043737089576860594, 0.05670550639831251, 0.02020955266010377, 0.06970019620512763, 0.03765535120281481, 0.08224783540372888, 0.006600978883779458, 0.020416637717355645, 0.050782141380853234, 0.03581648737552666, 0.02630410576990295, 0.032830855043064204, 0.049605154537505684, 0.010771751629128572, 0.012008471305542176, 0.0218540484896831, 0.05258062088321294, 0.0426891157704015, 0.05977694823917362, 0.038441545104668025, 0.0121805758305615, 0.08226515665169686, 0.021295053283533743, 0.06130122572123524, 0.055714858951227325, 0.0528184682010643, 0.03473085651714956, 0.0198836492810158, 0.008682134775294652, 0.06144098314126173, 0.059120341940152074, 0.0442664371803403, 0.06883645505313912, 0.012907676582765436, 0.024887852430824312, 0.03326497408711622, 0.041587937157601125, 0.0024491871637667743, 0.04395928954885852, 0.026493656989787857, 0.022642375946405436, 0.033473874772748644, 0.013055379292176617, 0.011763086640125802, 0.063534046433145, 0.1063806392372616, 0.08310532527825526, 0.052652916600627285, 0.03221947474465255, 0.06383648262389245, 0.06792305608189876, 0.004942739436838536, 0.030392071592711636, 0.027484624278581435, 0.04115515876741659, 0.05259055321315124, 0.0364449207911328, 0.07633221936562369, 0.04523446205102148, 0.01020533494621275, 0.028041148851174983, 0.05363747364871445, 0.007824689908433826, 0.032177964270475416, 0.047614980684292894, 0.03625488119019616, 0.026510154693237236, 0.02698845785832213, 0.0244763023370216, 0.04074043706960736, 0.07648244920757509, 0.02322871666101198, 0.01543357955186718, 0.024436695591336297, 0.1047735016853098, 0.018093035586418647, 0.03708355849789035, 0.03590905760985709, 0.004027528188852293, 0.03346784949122417, 0.03277803711112469, 0.03810641611175191, 0.006763193213696322, 0.06905131207238283, 0.07877758734168545, 0.05425013331395965, 0.05780224553159168, 0.032329132570134055, 0.03187656229842575, 0.08125765143983787, 0.03771700978940053, 0.09146477711657364, 0.058042237895631024, 0.022252582749652288, 0.058889489005049395, 0.029493391085716508, 0.05203523905947805, 0.032468173697951346, 0.0033324417721990857, 0.02486290860800974, 0.03975055571044645, 0.08614066522568466, 0.06312909235637035, 0.04395997902799038, 0.051893459167331464, 0.026481773050862457, 0.11337447806351608, 0.031958148747141805, 0.03790204300575199, 0.050640104849252014, 0.06373846550442039, 0.060966747903054765, 0.05039202259673227, 0.05331601932524674, 0.09097614325582982, 0.09238720060356202, 0.01948807786609377, 0.026811962691886772, 0.057926340284006256, 0.09954498224561253, 0.06588463401121479, 0.035371884418230866, 0.09407261701961679, 0.022043479050719933, 0.02277404347795152, 0.05620859495754685, 0.06536207777718384, 0.020168082405542655, 0.03226377760931369, 0.07057285462055476, 0.048229053781758395, 0.041863326614181844, 0.05602997389712161, 0.05165848084875653, 0.029043034808109366, 0.01943949065471609, 0.0718454109324563, 0.06085898997562547, 0.0836487114429474, 0.04592466130552273, 0.07539098842009422, 0.1150689572997151, 0.04483658279622755, 0.039011859259898626, 0.04290421027690173, 0.00951726924658062, 0.017151197516209176, 0.021173488536489107, 0.04499378020785028, 0.007118536872909435, 0.03746843724060924, 0.06071110436272237, 0.042063149157911546, 0.033216250895131985, 0.037830555511097756, 0.04656298491623133, 0.03895721037782008, 0.07029563804427463, 0.04187858325519389, 0.016120740310138753, 0.054708556497409466, 0.06802390389625104, 0.048980157026239944, 0.051664291625662204, 0.06385182353457616, 0.017455336337368337, 0.06884004034462475, 0.014057334197024185, 0.0646128208045998, 0.04082844141990908, 0.03496961547963081, 0.044462827650169214, 0.03906344762071967, 0.0496980082243681, 0.08919347197778764, 0.028257808092260556, 0.10402046789925906, 0.028753662331690712, 0.029549966678924622, 0.020425020634467085, 0.007105903604233097, 0.09037130917873114, 0.039344260979804306, 0.058272830360839446, 0.09060955486230313, 0.06589210336847652, 0.04315155708501416, 0.017210115423245777, 0.04644343689564736, 0.03785469877203146, 0.015497151443043785, 0.039602401966769854, 0.04080830862925899, 0.08833077270537616, 0.15934069580849142, 0.17135615670873275, 0.0739095582356376, 0.15445831021474254, 0.1448326146290187, 0.1907097899745549, 0.14997790627662214, 0.1822707952270585, 0.09725311530693885, 0.14056041806695924, 0.15302564918754563, 0.15289334580302238, 0.12241007144292518, 0.11445473864554398, 0.12672129252384748, 0.19081803819825574, 0.07661735729104088, 0.16626033901927934, 0.10777540189484436, 0.14783653731067337, 0.27394832262108404, 0.1593430247157812, 0.16648818888971884, 0.09253088805464008, 0.10950531269754134, 0.1195324460164674, 0.1402908776916804, 0.20928112489561881, 0.16147893913570913, 0.19139255817619064, 0.08853472829345735, 0.14871995926143664, 0.12350563080080094, 0.11312150050916019, 0.1168992562640098, 0.11054290218218682, 0.15502066471643988, 0.12328860575273154, 0.15549292727824182, 0.13095798091061656, 0.18448797625399407, 0.1295251513440763, 0.21825492562305546, 0.25812247828129803, 0.24089283910730194, 0.09756442279584947, 0.2512069413017842, 0.14000442209503344, 0.16491159526330812, 0.09442739233735109, 0.15535869335214939, 0.1850866433233023, 0.24065734367937813, 0.07935164000598655, 0.10267147133427282, 0.12889446179953315, 0.17817289898953131, 0.10091139198911768, 0.10400407361767947, 0.10244870828765054, 0.08223355552482028, 0.1249214378936637, 0.2299163466499698, 0.04416980284957155, 0.05806868708121681, 0.13230467155095071, 0.12999870093359103, 0.1753818721420342, 0.21187990963939698, 0.16310940406495528, 0.12537567440660732, 0.1430584928922115, 0.13985727192653766, 0.20409720709487317, 0.19878408090481836, 0.10524488324599882, 0.1129010816915862, 0.10150036804618374, 0.22087912916416125, 0.19198759398873777, 0.11987080406998435, 0.15350345822591938, 0.17042238745958577, 0.11978718557304914, 0.12788077425812522, 0.1076433283366984, 0.13511393129104568, 0.16349592606627172, 0.25529464856991846, 0.1772454576266389, 0.14708410107320355, 0.14236377371895698, 0.15462354005825135, 0.16383672794026716, 0.10812663788636846, 0.15571489359342283, 0.21292356654040276, 0.1427103212523845, 0.09739264290058806, 0.15132902490515865, 0.14859205322159877, 0.16298460834208997, 0.15681271291067525, 0.13345112212963645, 0.2053400928214673, 0.15278356540347302, 0.08621297626485748, 0.21750877130656474, 0.17413196905005365, 0.1526519974633571, 0.16479732558852242, 0.1460442439683022, 0.1355425728064391, 0.13577762390336684, 0.16556315304290864, 0.12690568222634255, 0.15792801435435974, 0.12027729798348681, 0.23123331307884187, 0.16067538951193133, 0.1706268716483347, 0.09747405506430135, 0.14066397783256349, 0.19360710386066668, 0.2150219886173164, 0.09022481018497099, 0.1554448016348385, 0.15590756470637937, 0.09518114624605065, 0.17480536033549618, 0.1394685895572747, 0.1739897831313072, 0.13463376270186517, 0.13935834950497075, 0.14647870775192015, 0.1604216918349266, 0.11973420293220591, 0.10959823916275656, 0.21733508385237188, 0.29647452516421197, 0.09155188897444357, 0.15316657872209627, 0.10135848090172776, 0.14691012250559946, 0.21072035895720606, 0.10786615267035463, 0.21544922053092913, 0.12871901234311442, 0.20083028642881304, 0.18239539176706346, 0.18279885963326503, 0.24015719551713238, 0.18421719481627788, 0.18140480943745185, 0.2049376668348428, 0.09946851134901086, 0.12003084749824579, 0.13912836991010175, 0.22656555467795944, 0.10845145150538414, 0.12158638136761805, 0.1693892412849011, 0.10183094264639002, 0.22555811841401363, 0.1431726246711708, 0.1034588948072445, 0.1422654999600303, 0.16957062026185377, 0.10264927776710642, 0.054314182094869115, 0.13999866111384285, 0.14187382984786265, 0.0974286949983047, 0.08219911987262388, 0.1440304746070216], [0.022681754780933264, 0.05278116354959146, 0.020206756439180146, 0.05454694641934288, 0.030209003391885952, 0.05114956864065701, 0.01981910445817536, 0.0603943461582305, 0.017670522774419477, 0.003993115040488661, 0.031872344984402584, 0.0709294302449111, 0.027868202587048856, 0.033910521906950784, 0.10122286035649239, 0.07338763785458381, 0.05694567113213482, 0.03607126906694424, 0.02901908689959636, 0.04308665411606912, 0.07820364192969377, 0.05003341683937658, 0.08926837239414455, 0.041437810737519495, 0.03589580428876704, 0.06391638942483453, 0.037569737046836846, 0.08813961078563044, 0.027482536688987768, 0.022194741196149302, 0.04482232206951707, 0.030710656916902914, 0.08456577231446583, 0.0626612309696934, 0.054226740819191745, 0.11942202976394085, 0.046837133310374715, 0.02754471046970256, 0.033570601034068295, 0.015294457027207942, 0.014744113826553428, 0.029986489323839068, 0.026432659154036836, 0.04771941379013081, 0.0407548510139027, 0.08347582838107502, 0.04883191518245205, 0.03930252067924988, 0.04001787443074488, 0.07716205346608355, 0.051417975205807924, 0.0728055642497155, 0.06568790263225956, 0.07000495364228565, 0.023992360764814, 0.01616091396088802, 0.03681895938972312, 0.07533010741275165, 0.021113737508834853, 0.015544741782509993, 0.03682814095349562, 0.09827405004011047, 0.040467414824712666, 0.024265777544989705, 0.022448697427828467, 0.08574646702336688, 0.0639950972981751, 0.056627384582234014, 0.014367251236352229, 0.02370307447328683, 0.03833079943433404, 0.028544026201650984, 0.0509214123350478, 0.02402781339872989, 0.057900890843161655, 0.02956997881072664, 0.002308102257008995, 0.0034202663312410757, 0.07806134109775867, 0.09091364580296701, 0.016829002002674728, 0.04394000711580438, 0.013620478303862676, 0.04005662315795499, 0.03589076343022528, 0.021921891321037567, 0.047454389503165606, 0.023843115345845302, 0.013944852379931798, 0.03191189810393318, 0.02129629243075127, 0.014117473056690108, 0.0358626326816457, 0.02305780627554463, 0.04949040988820696, 0.028119870131054235, 0.047096411937907826, 0.040597703397995046, 0.01977332304382036, 0.05668128269814676, 0.1131429433101608, 0.021195187976944353, 0.049208696375811295, 0.00822360816997506, 0.006830985770530759, 0.10838212820911601, 0.08584884701356774, 0.05240830089596491, 0.06073685640829706, 0.03145968214788985, 0.08363820071662627, 0.004344292617808547, 0.014597092935394858, 0.016820274345997362, 0.015100001886997734, 0.024741613906958414, 0.024413910221248388, 0.0345648490943976, 0.05444549722597004, 0.07541947922999821, 0.07096515292482031, 0.029274194178381757, 0.060511611236800114, 0.03127209019787129, 0.03195315193865569, 0.01752043657395388, 0.015190929820340489, 0.0063442661719877395, 0.09700783693622198, 0.052849667131780624, 0.07916779422591771, 0.012171275523160736, 0.07576469377043747, 0.05036566151125778, 0.024577441264785106, 0.006105658511871533, 0.04781032544410518, 0.021776250345752608, 0.010699996003700842, 0.023885296146956184, 0.04054419598692367, 0.033643233830169324, 0.0515033059092539, 0.07839828188861571, 0.052133305974665194, 0.010350594792755382, 0.045117618320810224, 0.007871616145430674, 0.0485960022366095, 0.021923055774682475, 0.021789409821071935, 0.10320683655839774, 0.0428565634384511, 0.08969571922094592, 0.023121223033916567, 0.029807444999835668, 0.07421373344597317, 0.005315457012564425, 0.02382338666657527, 0.03211423341605452, 0.06893885036509845, 0.015388138089028579, 0.016846097254705046, 0.04287015000778822, 0.041811642492370266, 0.10370870841847313, 0.06232391096531384, 0.03594170827718993, 0.0814938286860143, 0.03895634086802602, 0.046257170277737805, 0.06462473347182236, 0.04583813167447525, 0.03866125912135167, 0.04216296275356605, 0.03407884674567369, 0.010925828190069767, 0.05325500425251742, 0.04147471702327171, 0.055808057377655665, 0.031096366865019646, 0.039143940478923826, 0.029625772994251984, 0.02479495277868644, 0.03692957482510998, 0.02119845917238103, 0.04392855793177601, 0.056090318642917185, 0.009837960354953764, 0.042018064883567637, 0.037031759462890126, 0.009270622451308995, 0.041406466250097564, 0.005628799901328861, 0.0385628474665986, 0.045172998816856456, 0.034420744125400825, 0.010771011396671736, 0.03645087712474408, 0.027171173658702644, 0.04664123696725696, 0.04479241399695316, 0.02739505136325475, 0.056566921092810175, 0.0392232573921642, 0.01766312428029074, 0.0404742751420746, 0.0944301885582747, 0.05421385522030535, 0.06704262187404018, 0.05945693033056394, 0.016354096437534018, 0.05826331554881989, 0.030119995466403426, 0.04319749554739364, 0.054372194102935256, 0.0321290131673337, 0.03215864736346468, 0.12462578924192537, 0.021341514600921544, 0.120168766307254, 0.05602237047447313, 0.05208116220009904, 0.04281616762220379, 0.04626499586588433, 0.05360114958978469, 0.03613168659109262, 0.04634958346404376, 0.03555196104571223, 0.013433191831403924, 0.06646495327473649, 0.03082449375201137, 0.12074848036131552, 0.07859088405365906, 0.02567011247118635, 0.06131801453809585, 0.03920593614419622, 0.08741227924943933, 0.06995508131841499, 0.028651075497750315, 0.053178230751185655, 0.015200367065957718, 0.019438467927337177, 0.02398801896150314, 0.012956248472384628, 0.10388119311462488, 0.03973938614851044, 0.04228847476864054, 0.09959894547899885, 0.03517953123176291, 0.02686996512385386, 0.02619621377708691, 0.007733280776113633, 0.057055581766631336, 0.06358338249546867, 0.06852741518448438, 0.08080124689806854, 0.023209708104390773, 0.013312948586028672, 0.07571223206938275, 0.014391854150040496, 0.029947715698771422, 0.07099344455186399, 0.01047056894974723, 0.03567556933229489, 0.052202748014561595, 0.09155322196743182, 0.054001177721206224, 0.010766520206215642, 0.025623995893364473, 0.03251643340674139, 0.04452612566491289, 0.01676537457012361, 0.016693440829253486, 0.04118054309078763, 0.03310292350849317, 0.051199115377159855, 0.05454717624572016, 0.04316672945635454, 0.025687429888714707, 0.01418962992066818, 0.010196817963714562, 0.016902843302476312, 0.05580806886897453, 0.04362902904470121, 0.03422294405379123, 0.06721965713246215, 0.022028023226847573, 0.033301060658789454, 0.020740254323989637, 0.022784697845758452, 0.06343122977282732, 0.07335675685035606, 0.04249028148009412, 0.053167505520245725, 0.05209932997522335, 0.021567244323030598, 0.07656140988993068, 0.02130820892841345, 0.010896109724267116, 0.03336370749879749, 0.03952502708641752, 0.03671605462929414, 0.10195739311917175, 0.021919568159407186, 0.04618689703244356, 0.07755833542755536, 0.021344002471455646, 0.056567166240945946, 0.039671464793143735, 0.09425151387169477, 0.04936123214241478, 0.04692300410580732, 0.04015620692723221, 0.04672857099062493, 0.05894866546676044, 0.014620781331623514, 0.07104532402609626, 0.09867525028605616, 0.03346605301504174, 0.06919503782785709, 0.018438102654932488, 0.052370038634586724, 0.07328849075542343, 0.031813911627978086, 0.05510636297385058, 0.031136841205279195, 0.05815993198343824, 0.022881810981479865, 0.01747929573720021, 0.018706116600022204, 0.06758168730283938, 0.01935475941507086, 0.027800085879261457, 0.02021917280921292, 0.010329703575060254, 0.0513685395520541, 0.03544372048289065, 0.030544862083549944, 0.0505506525927734, 0.023177189587224877, 0.06613224128922147, 0.02255438883308201, 0.009167193878261794, 0.07065979793908135, 0.009726527120707738, 0.07731486502433978, 0.03734135091485035, 0.032133841436476476, 0.03003030572266829, 0.02749103834972747, 0.034622294197399775, 0.07217878941446543, 0.27536791418829276, 0.09114914889177007, 0.203140210059862, 0.15311748780790838, 0.14399698124297206, 0.12801810317943174, 0.17643941055622794, 0.09637115658411095, 0.10874430393619884, 0.1145648101585046, 0.22444421125035133, 0.09473345212398038, 0.171480446813568, 0.12589729601337066, 0.13797215937126067, 0.14760422880851454, 0.12355852917197252, 0.17181547238461434, 0.12298548008285223, 0.2129088423304981, 0.13841596942755485, 0.21113654388295067, 0.20453862695684358, 0.07996240360361916, 0.21477501719228684, 0.11881990763809412, 0.248036471105391, 0.11509272134712628, 0.06910922065857919, 0.1633423254374535, 0.10861361699719584, 0.1464145708708994, 0.19482328376222044, 0.18708227172253594, 0.1731981538356312, 0.16520742777614825, 0.07205427714413212, 0.13173937527162413, 0.12625017143305273, 0.16911312787523194, 0.19684906538215377, 0.18423182709563166, 0.0978893360062953, 0.18184117311912198, 0.1260876075755204, 0.26948135586515554, 0.17787199497463244, 0.20429847371434012, 0.20266033258409272, 0.12400560276282412, 0.18029156110940442, 0.17279372069864504, 0.1609847051722388, 0.10486752365625675, 0.21153353064531283, 0.2721946860753721, 0.26403827051962575, 0.1436048821215668, 0.12088449161139228, 0.17649761791671478, 0.1434795807806715, 0.22152377683068478, 0.09759058469846364, 0.10025339907095318, 0.13350012111327342, 0.13068392061658446, 0.12626069748113233, 0.09636344207871346, 0.19121283394915445, 0.1509123496831425, 0.15444490367606764, 0.26849858763237155, 0.1342250854377785, 0.2430045298270641, 0.08769118121915287, 0.12361222427458533, 0.20381995987507606, 0.11971990007065958, 0.22096159086833078, 0.12619210196839226, 0.17541962495494276, 0.09576549513205405, 0.18680598977352345, 0.18966544359441728, 0.10828367824996672, 0.18914634241692482, 0.11586147525738325, 0.108009219590214, 0.10503849915919766, 0.24937717093815728, 0.1397665211510274, 0.11436784129229285, 0.049421389196668906, 0.11780793613363659, 0.1692643536314849, 0.11830629165013952, 0.08856608427219814, 0.0772696428541695, 0.15000729340939753, 0.2730934910716549, 0.08663584147730181, 0.13042251609506147, 0.19461619487452894, 0.09585109013583391, 0.3209983479351767, 0.22408635625916146, 0.1322929657274677, 0.11944413140055635, 0.12401180807501079, 0.13756792541713486, 0.10788061641036503, 0.14310625081341113, 0.07783559796911094, 0.09987335817347612, 0.1607528410010761, 0.09975878972439997, 0.15268547550564812, 0.11160672251735965, 0.19263196586360856, 0.12575544717331089, 0.10836342034200508, 0.15167725783201957, 0.0948585772646531, 0.09151327048218058, 0.1295860400122981, 0.19848323817695343, 0.25545817769823537, 0.2813623070476517, 0.09959007418083568, 0.3048797660777646, 0.21726080396723366, 0.11156096408564238, 0.12250961690780618, 0.13722096419622823, 0.1083201670178002, 0.127100590316038, 0.10463555223278462, 0.15666090492759982, 0.18270628556849497, 0.122965500509787, 0.1383679970017364, 0.18451587717619636, 0.2892064958089783, 0.1877857702634027, 0.11564976685950834, 0.20156960724101913, 0.1747800028252025, 0.11808616394597678, 0.2072326670731268, 0.11653611526614237, 0.13520288942081315, 0.09234547945520571, 0.15193645602032063, 0.12274416238670388, 0.1819677461659716, 0.17298364921683268, 0.09102334193284474, 0.11580769588509876, 0.11405519314951475, 0.20610950556733917, 0.14953781940763997, 0.08171714331594207, 0.1600363802525305, 0.14323305368663805, 0.26342653399032934, 0.1567136424203073, 0.12028654466473288, 0.18234619360056617, 0.16151103821973647, 0.20650212562853293, 0.179407786758196, 0.1833241048359102, 0.10336101175315919, 0.07218974447178264, 0.12433682853776602], [0.07216562036304705, 0.020105086995529074, 0.009269684951211657, 0.029711277982700738, 0.05704802430925831, 0.017148654104300567, 0.024165136574376977, 0.03144308676823013, 0.0596246384685078, 0.03037560836321885, 0.035532050420560186, 0.03484749340362126, 0.025725858774216428, 0.03042534853692257, 0.03613715262843236, 0.0038726316744296424, 0.07623791394214477, 0.009487806462622699, 0.07582448693292757, 0.05656380311495835, 0.02178107478445576, 0.02194252398405825, 0.10297306482830357, 0.0852183566518849, 0.04171860877484564, 0.021130951504493435, 0.016570468395647985, 0.0701921702092213, 0.037345476298322605, 0.06643200383311318, 0.02748865581628296, 0.0304547414153574, 0.08518778208282687, 0.09122146759182216, 0.05480028403502318, 0.02972457918428606, 0.04085919601962932, 0.01667077611801365, 0.07397499746612965, 0.04230244055150017, 0.02548970642589754, 0.0367340691868336, 0.04420031230115602, 0.03229428706089816, 0.02705262155242024, 0.03304202717939212, 0.028638394827383663, 0.0649939418860501, 0.01903482960657247, 0.047811424780276515, 0.03353715746573383, 0.031168750682545286, 0.04185266267027586, 0.014406622410000814, 0.06100449305508406, 0.036231166938500065, 0.015282032038686017, 0.020849098181051594, 0.046543430521964066, 0.040165522556391456, 0.04801685891805157, 0.09616257382496711, 0.08788127827668384, 0.01891486406806977, 0.03340610280452717, 0.027836461649126107, 0.014747628254906065, 0.023369282303798585, 0.007560017543108834, 0.011761463491336234, 0.036769807188501286, 0.04780147712857974, 0.06584707272028731, 0.041290806125729315, 0.03329588573486094, 0.05324091206515028, 0.03564384180091081, 0.03874118507449185, 0.028681152109657566, 0.02300312291950949, 0.041542852883257216, 0.05684666575924043, 0.05768780348702304, 0.05475896891326674, 0.010845558454973564, 0.029203363604122595, 0.08117523570094379, 0.018865010896397215, 0.0886953309659035, 0.032918476349403786, 0.020033961477419062, 0.055333975357033556, 0.029367597533329844, 0.044899041944694136, 0.03558047866869358, 0.01745791039279392, 0.029816781696412834, 0.010429622507804345, 0.017114237604302265, 0.034697826636294206, 0.02561789591826739, 0.016414527368221073, 0.03761539588712397, 0.07389687948049077, 0.08721897994438488, 0.01871495533944859, 0.06657978985458612, 0.0076618670174221125, 0.08296540697976466, 0.06795518580944308, 0.025742398612501643, 0.024439639284185345, 0.026753925785963095, 0.007478476102058326, 0.03930751174207657, 0.02154207450427836, 0.04604962556773136, 0.047676489883733374, 0.02771050721827534, 0.06789557650805482, 0.02935354365035892, 0.012380955703256112, 0.06799980277015318, 0.0263813944653638, 0.06164616447002177, 0.06186008686199785, 0.1207468639157953, 0.050974781850292805, 0.067793702135884, 0.03454383913307421, 0.00411671327216731, 0.05136294327976723, 0.03653024000325992, 0.0341462318394934, 0.07408335294213987, 0.04616336281140966, 0.06046338983240628, 0.041637453250586993, 0.03358941998392825, 0.028021749589712392, 0.04737664307017, 0.025408434073230433, 0.04846148485798509, 0.07411604957474817, 0.021612545017213113, 0.04891662535467937, 0.04635857350583519, 0.05250445259134135, 0.01156816322867188, 0.035580605073201085, 0.05553999938251031, 0.027533349385785482, 0.02622672322867138, 0.036223195793647925, 0.01830426326412107, 0.025966554023926298, 0.03350911098682592, 0.03638885847683396, 0.058987988759913755, 0.08076085874270048, 0.025319054595104633, 0.030486390422729236, 0.06661412591535239, 0.04674869612039578, 0.011430884103080439, 0.005007118114360398, 0.06441152354161586, 0.015118494291879959, 0.015168863615291494, 0.03853048025179775, 0.017765944771048044, 0.04668553217103885, 0.004828735977606548, 0.034243344975214814, 0.058503595195830836, 0.012638730883237817, 0.09796795960996421, 0.07879358325754443, 0.02484499172668063, 0.029892049834973393, 0.009547076770104468, 0.06850149843000597, 0.03787902206362736, 0.04243208561092616, 0.039435605473455884, 0.03501219847690194, 0.03602504715203278, 0.027703185332939032, 0.030940948692601056, 0.0034940171369066044, 0.04781307569975334, 0.01838446500891399, 0.0377718961587356, 0.03960446274328617, 0.019739084659264456, 0.014141250510639964, 0.023481577386959426, 0.06543436583371894, 0.05825909823479672, 0.06427830851246273, 0.032421231660391056, 0.030269399848616416, 0.05923837310664597, 0.039184696356495546, 0.03672037153474746, 0.03707890834418997, 0.022223984687438896, 0.03435839222924363, 0.031796576973471435, 0.016814745106403867, 0.07344033704289506, 0.06425861239192948, 0.06070189598587252, 0.07015142199252883, 0.05205720280026717, 0.019558701596613375, 0.056792020707601504, 0.02968386161111055, 0.07170163155082734, 0.03717516346143619, 0.07470006904294414, 0.04395263224479653, 0.008528291871170364, 0.05713086139651076, 0.021568500707226417, 0.0006683700579038311, 0.05393180079878338, 0.0724111975080544, 0.028378677614513906, 0.0698953417820796, 0.10184468626375161, 0.02924339935904549, 0.030715418153352318, 0.08332506993845587, 0.048611327825534734, 0.009917540610918115, 0.010728172717555877, 0.03614457218997902, 0.05657524463810748, 0.1302599982028046, 0.03020943240112355, 0.020959794055670503, 0.05219188871823492, 0.018373963858691916, 0.0311016739391151, 0.06540009105998663, 0.06870788251680714, 0.05042513674725929, 0.01194896351080388, 0.05538141535174462, 0.03261568009733193, 0.037853093817830086, 0.07233704019698405, 0.037537051905547424, 0.11771294123102581, 0.05077786661023575, 0.02755233112932934, 0.01421379137619008, 0.12424180299163827, 0.05250702664676694, 0.0519242673932064, 0.03788024780430621, 0.06867511693628565, 0.030564261345012538, 0.023058524482973644, 0.049648147391816305, 0.05989954528969623, 0.027971369732591896, 0.03711032177952509, 0.010980954919491085, 0.06902442238624058, 0.02677423286161596, 0.026817890297200893, 0.047834097152395595, 0.051505588851268255, 0.07962855014709697, 0.04776549014833666, 0.04233550107587249, 0.09845621808762513, 0.030272083071571206, 0.07011378409280893, 0.04220750693592333, 0.017589756039782398, 0.030162490363563263, 0.014028600154204235, 0.04642027422725674, 0.017817226696699377, 0.045888651342641924, 0.09011870700745814, 0.04997874880509992, 0.002471895685659782, 0.05305790132091892, 0.02097959742851315, 0.055441281292587526, 0.06594800480431126, 0.06873643461374507, 0.024764675068699067, 0.017366857012553562, 0.04191712130822482, 0.03201503460595925, 0.037250646104615544, 0.025020081121774933, 0.07549538322153591, 0.07154335012479175, 0.10265180585725654, 0.003123564548009346, 0.023167971634275975, 0.09097752987497276, 0.02529320870375922, 0.004967425662588569, 0.034791071027998006, 0.06404904904024256, 0.023725227820837212, 0.0519260025823549, 0.046283987185527245, 0.015779270982039312, 0.047136271492608135, 0.039155470102184245, 0.030001669356058684, 0.07906715325530499, 0.02354486582560405, 0.06091843073767039, 0.01501585191656505, 0.02641939625684773, 0.062316522047284155, 0.04106614318105482, 0.03341654075249549, 0.07756839416200116, 0.029208289549475717, 0.061515328143873525, 0.03842862120138542, 0.007014299598297165, 0.0062631183086083305, 0.020244363695383072, 0.021565848127788594, 0.034360931810712626, 0.005988572027549269, 0.048817072228919116, 0.032974121145783894, 0.14203011178441588, 0.03974264968306788, 0.02641229462178965, 0.027842136445425214, 0.025812212205041322, 0.017044471892257853, 0.053780728260115276, 0.01696928802336897, 0.012997870029310786, 0.017532626948048993, 0.013083600056087299, 0.05953587186072142, 0.05608564167613945, 0.16750284170191135, 0.12925904304269822, 0.11678312499556812, 0.09710244113399137, 0.1394617713747486, 0.1520302864692865, 0.0767427122580909, 0.15613189057236718, 0.11702959080256763, 0.14104685325536037, 0.150298023776662, 0.10074499769196396, 0.16544185068097808, 0.1565749192189786, 0.10262190544557187, 0.15710568025467858, 0.10451191330268499, 0.07817997747371275, 0.11583935829900927, 0.16642342381660016, 0.10914337445771503, 0.1881050910320013, 0.27071273495112697, 0.192339779929288, 0.14046199109044769, 0.16378114060048135, 0.19434052579585584, 0.1910436664137148, 0.08704007543142765, 0.16940062535145592, 0.15612211529045336, 0.10845381871707017, 0.18346160229656006, 0.17030249469943587, 0.21666828092307816, 0.15909338730477518, 0.15653433188075022, 0.1884526191579719, 0.1550577893372505, 0.1695667438569569, 0.09605235675530088, 0.20911051711488157, 0.235414850795942, 0.16718577323181016, 0.15844696231426733, 0.1130739494317001, 0.11128691145248952, 0.27868593291890237, 0.16319777996790025, 0.21550318376431543, 0.16820787241862667, 0.19951237005091485, 0.1348049373876664, 0.14736154747586097, 0.20387376989087752, 0.0869277056546942, 0.06264584409373422, 0.14913119525919039, 0.1303099318137092, 0.1014702378081218, 0.2118980046361685, 0.2283731544570577, 0.24605103167555026, 0.16792106442153457, 0.1550272530725887, 0.09952008438807342, 0.10131101409393935, 0.07143590629341141, 0.12770343256453354, 0.13145665818404767, 0.19372158804007117, 0.11595165912782955, 0.12760171907082682, 0.25784435772126724, 0.11198595902251621, 0.22441358305513862, 0.09315393204169889, 0.1392748305994657, 0.20028783489138852, 0.12308139429097215, 0.0898854638780317, 0.24601473442969785, 0.20885838225724238, 0.11596036188664938, 0.16517131439139768, 0.08677389052125715, 0.16580322967661967, 0.08719094112635621, 0.1521054550164169, 0.24617763536591686, 0.07242661119709093, 0.19098712912490293, 0.13844831365971796, 0.23626301738042987, 0.11630743802074464, 0.1096244470306462, 0.14153696566579804, 0.19246281364992743, 0.11761730281455864, 0.20451095586101856, 0.12602803657852835, 0.08009729636532646, 0.19940559271602862, 0.12650483438084204, 0.2426900047688715, 0.10399788362725128, 0.1835553561367335, 0.24442597532704954, 0.22537324607612627, 0.2077298734577433, 0.06302862375554058, 0.10444778408254347, 0.15369033771416835, 0.1047252304852009, 0.2906236665383462, 0.12506140215742972, 0.2047589078785912, 0.1879533596577183, 0.15047947936240705, 0.15181973486417724, 0.16427165137663965, 0.06990700930116639, 0.16286649290592442, 0.1896323179525714, 0.12105314586792262, 0.11652041812457385, 0.28957746622543185, 0.11219255761393618, 0.20691774364921356, 0.10190001313364315, 0.16707279058473726, 0.11624309429598433, 0.1148225834232665, 0.1842175165732061, 0.18903518305911174, 0.14727769149166925, 0.12720290135832565, 0.08766079817207591, 0.1278939969356983, 0.15812230957371576, 0.22888690834083866, 0.13593176079373206, 0.16392364827615602, 0.24589890193554664, 0.16288383713653012, 0.1539673397858297, 0.11409391889408713, 0.1509467163874257, 0.2799824294784377, 0.10746635436531037, 0.12336460167482016, 0.1484046221500443, 0.08890723854663873, 0.251568703341388, 0.18169485032558444, 0.15338068497517418, 0.16759333200752738, 0.12083913154539563, 0.11575207024091676, 0.1705233884915229, 0.08792568073277512, 0.17963436492268117, 0.12614684149382577, 0.22176132537424567, 0.12570094767837756, 0.1111344752773162, 0.12678565923124552, 0.07434766093689589, 0.10776697492767727, 0.13857052000539918, 0.1653923001140356, 0.18158929873137705, 0.06040439723179706, 0.10130077149839171, 0.23854289504308857, 0.1915316337779645], [0.02125721428573372, 0.046250099286196694, 0.029311123446771697, 0.04334484106831012, 0.009753044296596802, 0.06483337751800014, 0.02255449033973198, 0.01793218968105653, 0.09477551035102337, 0.03378268864546572, 0.009752942789946834, 0.012787357686207661, 0.04151419353400988, 0.009501798100949777, 0.04643997034778999, 0.08560796598753623, 0.014377994661880358, 0.03935867492409964, 0.11023078264007646, 0.09530825555444726, 0.0193507757578646, 0.029818775440235774, 0.04217836495128371, 0.020768381242129593, 0.04949112618041616, 0.07806737020972275, 0.08225880578280458, 0.03249331670362623, 0.030618123071748885, 0.03777962215545197, 0.08815748361690391, 0.1078173069043025, 0.05964732616238537, 0.05011384841054679, 0.07908663487121945, 0.04406310212347777, 0.029133159306741534, 0.06318652596805366, 0.059184566921284126, 0.05644458834262145, 0.001048124630019189, 0.027782988712011326, 0.03072796858877184, 0.011190153421804069, 0.04849766719064886, 0.03801055936022632, 0.05738867679610849, 0.07494187703536404, 0.03287483615079715, 0.021990800929826596, 0.00913454321092896, 0.08147337413843601, 0.07997034793539394, 0.08752860970074132, 0.08318271548036607, 0.003286060654640859, 0.028273871040812908, 0.04981360323126278, 0.0425274329139821, 0.030988957507595904, 0.028319889942424434, 0.04584640159361786, 0.059031265066756364, 0.004114300095205826, 0.012634951196941397, 0.058514335748529246, 0.024891847579349435, 0.006862685052422627, 0.03769205830570671, 0.0568963963568451, 0.035498618343544584, 0.04453102096674904, 0.05942170177736591, 0.07937283765885138, 0.03558211426641192, 0.04152104619049257, 0.0442258651638704, 0.015414466615766289, 0.04463140146746751, 0.1029217599200145, 0.04834021697001112, 0.09949342452830846, 0.11619671533304839, 0.05334979614182826, 0.008944923043130867, 0.008183927688327047, 0.06372279900636885, 0.09724873328401197, 0.10778284826946836, 0.06691663871489226, 0.00504329422255978, 0.04398777269788327, 0.014775605785900788, 0.034944376712965394, 0.010417684942724244, 0.01931494391042619, 0.043442563243931344, 0.05394815294552715, 0.04233582283280069, 0.020720316885760235, 0.04649204134400334, 0.03390376501145863, 0.04140884878354208, 0.03377907654090274, 0.05598829488360113, 0.05048375779522523, 0.04389006584402054, 0.04941126534474954, 0.04431757737972564, 0.04431231818612545, 0.08408051690146809, 0.02256591079546319, 0.010267125682965403, 0.005371678290107558, 0.03811773506083316, 0.02915632197513215, 0.030026722346402468, 0.026822810496894584, 0.07140656512591147, 0.0358988571491453, 0.04918736082712009, 0.04033984203312186, 0.09452869214357869, 0.052471859380602844, 0.03241322987202195, 0.026830534578391144, 0.07518815132038248, 0.012966205700180464, 0.016582651108863856, 0.04758067526704362, 0.10614955647578163, 0.04936832994703324, 0.04112068098038435, 0.03651676834711144, 0.0821351208874295, 0.05820771288727561, 0.016343675726543994, 0.05704190326674331, 0.07206276539833316, 0.03537080040381801, 0.006848881584441951, 0.04567809590709306, 0.04979946124818056, 0.044377156037596927, 0.024592515959915136, 0.05337813756458702, 0.05607215469823249, 0.03182437447380395, 0.015102009994969254, 0.04072461735397097, 0.013350681289129201, 0.05861724816983747, 0.029192107857295105, 0.015171930839818333, 0.02090786861616277, 0.057762075711282036, 0.011327611620447809, 0.023141371146325144, 0.09112380670323487, 0.07023893221611939, 0.04039894954691972, 0.02594262909805102, 0.062384401267815026, 0.03518596637032686, 0.019984340047343604, 0.05237877586736314, 0.019181364989509026, 0.03603640057507061, 0.03878253850064451, 0.013271234140941694, 0.009603837182024315, 0.026050015472837036, 0.01644710142676148, 0.08838327271082709, 0.015552831670990395, 0.03440047726936398, 0.05217937084155218, 0.10894544032071868, 0.04232663743858857, 0.03440869739279151, 0.01476346808035047, 0.07921595817371722, 0.06902580134450428, 0.04143111129862167, 0.040361009042469725, 0.03311621130353982, 0.043757854390048215, 0.04941126534474954, 0.02209564772314362, 0.03852329817750762, 0.023155664431772405, 0.036627058195130485, 0.06886524463733358, 0.023985192097062548, 0.038085544046254895, 0.019159719175208482, 0.050790974374620185, 0.0735185009938094, 0.015415515198612647, 0.01034534517525425, 0.019343992049295097, 0.05643997649331728, 0.08842358425740274, 0.07083436639438714, 0.04650743205040213, 0.0734241113006588, 0.03393680638363285, 0.02926490919273948, 0.08545415851497844, 0.010446181498287667, 0.07367731102051274, 0.01076425928922911, 0.058503055103844216, 0.04866075198796969, 0.02864669155960362, 0.030610992708393646, 0.01824993805419053, 0.10709359896399322, 0.08071272543841794, 0.026359880801230192, 0.06542901854000746, 0.03180785378771684, 0.01640020726969646, 0.014851641927605436, 0.0046377435548140885, 0.043400761656342976, 0.06489232798377353, 0.03446895020803617, 0.05954786879761566, 0.005061708103429767, 0.11652793344711104, 0.006866589706811694, 0.04022491735316092, 0.04941624491625736, 0.12285257148886881, 0.03155798080467409, 0.03080600038951924, 0.034555548786996834, 0.018880522261644085, 0.024946281956809185, 0.03876222567933221, 0.02361403590428733, 0.010223784258649235, 0.05750897941329787, 0.11753612813810188, 0.07547958648853725, 0.080864112073135, 0.004413058585111773, 0.03830081858341733, 0.0371999885406225, 0.03176053253663404, 0.028487496573718327, 0.005861007375642658, 0.08015648431835637, 0.038790846724183335, 0.05077465670183302, 0.023468375776804263, 0.09331845708431737, 0.02823998505670217, 0.05964762110623622, 0.01789081710270576, 0.059106724727297985, 0.08541933215794065, 0.10798508015971993, 0.06586859979095959, 0.02986082217595991, 0.0526407128199935, 0.029828027867141272, 0.038815932273263895, 0.04814440106612541, 0.02012226077157163, 0.05533004915642162, 0.08078385670218738, 0.0656787478815644, 0.05278793193640248, 0.05151147240652673, 0.03947634985970874, 0.035114616771499, 0.07899309553566479, 0.01599903096399841, 0.034874245193937135, 0.03790210812322555, 0.038436622989754525, 0.044505376173483754, 0.028631469392548167, 0.08045918097899807, 0.020547261454104897, 0.009191140829164897, 0.005562385345148224, 0.055658455727802175, 0.1253455518294246, 0.05605690188766007, 0.06477061193436384, 0.025960233798550985, 0.028692156962689855, 0.017109263778453874, 0.03153674676263284, 0.06227771586347973, 0.03164046357626156, 0.02862773854435692, 0.018778299319467718, 0.08182926794453975, 0.05717845843924631, 0.05372299204370188, 0.04528893856331707, 0.04269258997913811, 0.05340261024332816, 0.05387389604302664, 0.029390444190451698, 0.055637568340546666, 0.10158452280466596, 0.07559419324200961, 0.024991948457975543, 0.06528527746277471, 0.02696531817256924, 0.07476885607766529, 0.027725949635609027, 0.020336016539424177, 0.04019993522595014, 0.020810562043240475, 0.06801435077983527, 0.07846719149740473, 0.02388137760722349, 0.018668430819807035, 0.02615018912981595, 0.054560437227689454, 0.023602266878550573, 0.04588470215939226, 0.036373326044169166, 0.11721001216961492, 0.034313622050948685, 0.034660541137019475, 0.06497667426423681, 0.06418474236383073, 0.11770385542824385, 0.06756679455359137, 0.03745318443003682, 0.03128087531114298, 0.039514102672617284, 0.09516129690793254, 0.03769150289196161, 0.05306900193494174, 0.07695569236192011, 0.033761843393046054, 0.03437170683736763, 0.017953647803815625, 0.036485577077274366, 0.06653501967629118, 0.019637712074684042, 0.0333534725641291, 0.0789890888958208, 0.04171829850923631, 0.1248751738439164, 0.21315892407250023, 0.12770801377032073, 0.15433547567696343, 0.08665700848664969, 0.15424613450323382, 0.1532889842506378, 0.10973624990231569, 0.20746007261257018, 0.1536388412838982, 0.1186707120148405, 0.11241784875070858, 0.09213508872856056, 0.12758979108184576, 0.09031602827411506, 0.16733465475901482, 0.16001612488781253, 0.1915913733142999, 0.1425854335989683, 0.18601193964000673, 0.16987408301041973, 0.09090606153251664, 0.11855639637477937, 0.10131047017151311, 0.13710050453101436, 0.25953275421934746, 0.16674882732331756, 0.120025301021674, 0.09999575604113842, 0.1654621520109715, 0.2264216374005041, 0.16726117160531784, 0.20516835123060212, 0.11120901563234868, 0.16251767775224102, 0.12536952272057533, 0.13104168367722344, 0.1288480828365972, 0.12189969600689028, 0.1107140155809541, 0.1110499834401473, 0.2487953118379078, 0.2339518220434266, 0.14916596032919424, 0.2605290668866327, 0.1236832712686831, 0.1371784156729137, 0.18841201649798503, 0.1372934820791406, 0.13635850241107328, 0.17265188718034377, 0.14408644499076953, 0.1864352951487226, 0.1252785421186878, 0.18596061174907993, 0.08731386759468625, 0.20020592477052443, 0.18609089266148307, 0.23769604612983045, 0.13250553980469704, 0.09591579392191865, 0.12950204613228, 0.10759540953703466, 0.1658123614446771, 0.11911917222483505, 0.10778275633891744, 0.11221815261148638, 0.14839804911565396, 0.20165222216277354, 0.1575148324932783, 0.25902128327758084, 0.13158709231403568, 0.1907286357374922, 0.17447502322254643, 0.11698796158476223, 0.15861242198415343, 0.1662114932532272, 0.17427482912617345, 0.23284980456434914, 0.19607799788636548, 0.11806703473050749, 0.21657967519375587, 0.19004836498248964, 0.14436102622459013, 0.10032075352125591, 0.11337318337492405, 0.18329223557826013, 0.202919791242288, 0.15384341740319807, 0.14334430497500206, 0.15736913789183865, 0.12687695392918202, 0.11343709042956752, 0.194830117266505, 0.14432141947890484, 0.11511995577283445, 0.20405963814306646, 0.1549406698153865, 0.11241954946590048, 0.15306366247034844, 0.09646766067993257, 0.10131935679143476, 0.21177382178364262, 0.11569038484125369, 0.11051298644874366, 0.16756786724492428, 0.2339675728111498, 0.1914010004651162, 0.17930203598112832, 0.14132491252835722, 0.1762500336213458, 0.0676586484957126, 0.17159200453710172, 0.06936074264587895, 0.23010379304328274, 0.10914270030034166, 0.1656720141369489, 0.11341064507442136, 0.14743144533807231, 0.14504295172950915, 0.11705203717874905, 0.14693843711528087, 0.1431501629732309, 0.21020367861755435, 0.1095484204650406, 0.14979782964914076, 0.13696792535483837, 0.067965374778836, 0.08583819839142023, 0.3264593597381346, 0.2190828981298593, 0.11217056322963008, 0.1293380573512085, 0.27155956854262664, 0.29493787536217325, 0.14026617901700159, 0.07817613171233286, 0.17192523746240526, 0.1860359335137952, 0.17621539112540985, 0.09600325818023375, 0.11982849303392634, 0.06677819130521628, 0.13070311877996693, 0.1605318859219551, 0.18478641346577676, 0.07234585786899252, 0.1560941837247341, 0.17513856261728272, 0.13107324649970378, 0.0806616963217816, 0.12000201194877587, 0.2563763953625195, 0.24854751303792003, 0.19463735422299755, 0.2163289959031728, 0.11166168166504753, 0.14090068367940767, 0.1676090368099751, 0.19808286530596597, 0.18805423811558755, 0.1194608397781849, 0.24314628673657296, 0.18941977451885902, 0.05696140274765992, 0.11260803773879044, 0.23498237884092718, 0.139182930692069, 0.10401197964505804, 0.07412513537753014, 0.07599093485623598, 0.18292884943225693, 0.09572314579159984, 0.18226861953735354, 0.10585411466778287, 0.13584946762890587], [0.044887259512418703, 0.028665679048806913, 0.03722869002470567, 0.09838831205401691, 0.03477457332454863, 0.08085994455482691, 0.04848819068302551, 0.047975884705421426, 0.0557694771897889, 0.0167410321263296, 0.04938242213440038, 0.0500021183172301, 0.020426962667355136, 0.01838653919196898, 0.027100601639117927, 0.01307378742738717, 0.0188966867168464, 0.08248817250733415, 0.01462399315524606, 0.07822050352490718, 0.007744604992049356, 0.01892309376759635, 0.009720946170179354, 0.02545368114125825, 0.1081434841598234, 0.04225432256897611, 0.029862773784947012, 0.016662600044641766, 0.0596376849458583, 0.017850938395807342, 0.06718948859000398, 0.020711631363918705, 0.04324736404082468, 0.01801671216174239, 0.016880653565749526, 0.03160192360801082, 0.020408967262013786, 0.017724350027199236, 0.01784274125501754, 0.008468549462005256, 0.048456459321201815, 0.05457190173347631, 0.06728215458532495, 0.011683390513362904, 0.03477925029132636, 0.046830181062461874, 0.008197667475249018, 0.024105770505904674, 0.05124161410475931, 0.02234196031255828, 0.011779529759810578, 0.02049531686239906, 0.030290021020318234, 0.01475545192783278, 0.048098998865292925, 0.07494588367520802, 0.07544812325748705, 0.027649543856480913, 0.04207012438846212, 0.015366533451953964, 0.03305621129731017, 0.0006250372520768114, 0.05349626066163183, 0.01771696493960917, 0.037242414489869154, 0.02600673533555481, 0.031267374926697344, 0.050010824906489545, 0.08121969178318977, 0.061624147103077946, 0.06095053748257699, 0.0568672965070413, 0.014877646782195136, 0.056465211429543076, 0.06676450897488864, 0.027995620245834994, 0.03184153675852764, 0.03457301942211005, 0.014920352353534151, 0.0065562982420106575, 0.02593670723839633, 0.10498537862252806, 0.014297552557001192, 0.03361415696300326, 0.01231437212892718, 0.05123849612690749, 0.0327513006425673, 0.01629471504730323, 0.07244544929914898, 0.017652123257698073, 0.04220537721149383, 0.010532913185025175, 0.04389480026739259, 0.013212332513273485, 0.04096901472357493, 0.06877850050166731, 0.07737429046462621, 0.026054707761373253, 0.03196478881422551, 0.025347995481664137, 0.036672242060904546, 0.042422091993953914, 0.042062758453070156, 0.047960961312656446, 0.02285661243443047, 0.04590865389834489, 0.015021502772616524, 0.03435460392445807, 0.03203667467460036, 0.04459293236234977, 0.09959228817493686, 0.039722099374499054, 0.0445194338868943, 0.012766653202444076, 0.047308614462493896, 0.0452982158880801, 0.025433270643735607, 0.014920241270785131, 0.0336338147791403, 0.038547326525252675, 0.04135138835878142, 0.019945112515180823, 0.025179620847226154, 0.08706858156309014, 0.03370555508280954, 0.031162074226285183, 0.035931917673517624, 0.04654129696709495, 0.020528683821941097, 0.07486794955067097, 0.03742191655140731, 0.04490006850251267, 0.02150588259551554, 0.03637665086576054, 0.009387577264269274, 0.04746127663360489, 0.04880951094110647, 0.05687685728433633, 0.01399422578904177, 0.02344646183173022, 0.009602873826459532, 0.07154111314805285, 0.04531217017962087, 0.021226710579808683, 0.1200925941849428, 0.037927902303636074, 0.005484168725689092, 0.07208146560456484, 0.030719407556218006, 0.019672065372428587, 0.05608626220735812, 0.048469256819976915, 0.02126668313247783, 0.0431797337988692, 0.05054830453328548, 0.027365210323384213, 0.019260946203083284, 0.04488453606984789, 0.041544109267453035, 0.07426236470740649, 0.018963058659386252, 0.04888346906931651, 0.011733079933741642, 0.03436182813358403, 0.07224640433466242, 0.09935347558630091, 0.13426912017166615, 0.006468200045938214, 0.02472071311316423, 0.061426090392013716, 0.014243505053943204, 0.05182098341925491, 0.04912673262879253, 0.0718748516913864, 0.048343522639404383, 0.03849198816404228, 0.060821662341514905, 0.021477579477152998, 0.013874180768916925, 0.034230673880947214, 0.09644546711276616, 0.04383542079238161, 0.07076976219973258, 0.013319921901359433, 0.0625643170168323, 0.03347980046284295, 0.05197469513082216, 0.037161113408904885, 0.013312159515466663, 0.06202070868664211, 0.04182615219765613, 0.03543330168712043, 0.03102704356875151, 0.08279518990386879, 0.01496878538971707, 0.0256395532238868, 0.1027800336540226, 0.024580413685931314, 0.02062096102764049, 0.035478094848053116, 0.08291068531933331, 0.038413812721809076, 0.0380995404726315, 0.07029168503058535, 0.014842977473181824, 0.04359973384247672, 0.05297079712392823, 0.02081458592006276, 0.01742024951043629, 0.01218887639322108, 0.020255550494297378, 0.02615546747561424, 0.058434425117147554, 0.04249568623039992, 0.04834918402916482, 0.033682396244858546, 0.01426931934416174, 0.04759933716887909, 0.07779537069220697, 0.02808937025556882, 0.04350983342456241, 0.014898006526392796, 0.02308067208486459, 0.049767021255026904, 0.024082201810914184, 0.027961073510889566, 0.03572298251392861, 0.06877548977612488, 0.04379266542532752, 0.05895087946086161, 0.1178601603474348, 0.0987889070905024, 0.0723693001594755, 0.005442291965723159, 0.06648867135687221, 0.03649349076553218, 0.02789124268137159, 0.06281423021949108, 0.05729735528509464, 0.013437064405861161, 0.022577829208345186, 0.03965628859136374, 0.017225927478002927, 0.01288689836303914, 0.041281172570081494, 0.038090910492164474, 0.04933647601114166, 0.021705172708137863, 0.025150377355936556, 0.03478519130317915, 0.05086907320806096, 0.03920961719667239, 0.0848215920550208, 0.07877248519610974, 0.053133196272556825, 0.01941438978387704, 0.02138725005000109, 0.10696812908375457, 0.023220004326093103, 0.04967714381975032, 0.01919005625700999, 0.02094405286404635, 0.005866140164735337, 0.012205023611445102, 0.014365210569643927, 0.01762221518513416, 0.022240501543086384, 0.01915947019663309, 0.05932642725266277, 0.03113228872778916, 0.007100571632280105, 0.050685215936673265, 0.1122191561866672, 0.023109235673121387, 0.03439604545072202, 0.026554369457787084, 0.003513430762517777, 0.03426420937983259, 0.010951303486381809, 0.056292791850864894, 0.047764061394357876, 0.005282566942755254, 0.04755265177077344, 0.03691022727458227, 0.024671158715782147, 0.012484165941244893, 0.04558465616296857, 0.051178254802981694, 0.03668741826268454, 0.0476124219506258, 0.02165137418365527, 0.0636678436891206, 0.050063401520732916, 0.030256805363141244, 0.07814832272068148, 0.04194758479453383, 0.02800069174789373, 0.009944386247004713, 0.05341270728217018, 0.07827300353035813, 0.008884127263069875, 0.012690591205271983, 0.020783955809630213, 0.010802686259511017, 0.0750637692849963, 0.035130662483073054, 0.0395669550785134, 0.04646337433387676, 0.053567947339146375, 0.06281576622577925, 0.053117866853191975, 0.09771681300574735, 0.040559299410350864, 0.08497457981349961, 0.010026582693230483, 0.036679228782773986, 0.02599444345480973, 0.06323089395018835, 0.062288743699149746, 0.05726480037875234, 0.055709335457293264, 0.03254228504374623, 0.02496740874654103, 0.03938456869594032, 0.023458755627695112, 0.06630202169500052, 0.030468130717054013, 0.04277464565670779, 0.028697100145021276, 0.0454062802506791, 0.04229441961093296, 0.07196164945320738, 0.026700362833517215, 0.013457646315556862, 0.01638212184902401, 0.11759377625440398, 0.026651202971416137, 0.020559781246007453, 0.009316641352920523, 0.01995108225533078, 0.03612953771446501, 0.0642951624467969, 0.07570261766593303, 0.04472291067002281, 0.03767206724132261, 0.011038871166566688, 0.0381127133544895, 0.05597370090864359, 0.02246468185236858, 0.042399097864906636, 0.04343377621543985, 0.00851743640528331, 0.1433551068147344, 0.12207558213342583, 0.08535805278487744, 0.24817033730927976, 0.21516472611936832, 0.2696721424018183, 0.16257980748290018, 0.17542475774403543, 0.12662709435267797, 0.14602133793936622, 0.16457162076427093, 0.12874188772853346, 0.11019184239088528, 0.09021284389159373, 0.11355050974675726, 0.1393580890350765, 0.11427655425523559, 0.20221388718533903, 0.10036536282108677, 0.135819498269308, 0.12735855510278096, 0.07486066405451106, 0.11580937361765294, 0.1124587118805897, 0.1761712491392128, 0.12292220888118591, 0.1825251364179196, 0.20196533761918548, 0.10419155831538862, 0.1394410103920006, 0.1831690792835528, 0.10348801380924641, 0.12323389175317942, 0.15385636428911842, 0.18401476374316603, 0.09580595989621456, 0.12900980399741283, 0.1353970314225843, 0.12675057240431348, 0.13811665887553848, 0.10737238602051813, 0.1383984413358473, 0.1524731006112791, 0.043934295930328875, 0.08775184772187665, 0.0972676556557417, 0.19588751778487237, 0.09894305164174688, 0.07374018385645843, 0.11455128870664105, 0.09612270660938756, 0.23998312501897737, 0.10810276658664789, 0.0977305336404712, 0.2002585856544395, 0.1363929763676659, 0.17272057462363474, 0.07514243119306142, 0.286663175830918, 0.13853883460885094, 0.24429842168765686, 0.15794797860566648, 0.1794926386566893, 0.10707851469276414, 0.10683328228732271, 0.13381824678471013, 0.08702165101684871, 0.2217919382476999, 0.14351164922118187, 0.12948099403612076, 0.11056423773087802, 0.16518243798805823, 0.1252120916521357, 0.1394340083483727, 0.19436657278528138, 0.20849616056488407, 0.183641602315249, 0.12173599833923003, 0.056887161166917895, 0.08919737136532223, 0.1729382661681983, 0.18092005964248412, 0.13872260378012735, 0.11377979220161516, 0.1054591810210578, 0.16396694756563635, 0.0883478028399329, 0.10200678280765012, 0.11906356956329077, 0.08740667914671284, 0.2728150947199714, 0.11895460121694112, 0.11734773945664206, 0.15599355041500063, 0.16897579895392542, 0.14767887641585645, 0.16397096186635957, 0.06848937125816461, 0.19116686867369762, 0.13601900288654914, 0.16873622793824444, 0.14417862068981896, 0.09169540022529903, 0.15556487825609025, 0.1328024448406312, 0.18430911004543307, 0.1691518153154081, 0.14163097997586574, 0.15280690044164658, 0.14663829918830626, 0.22172821505415827, 0.16607728997065177, 0.18965853348134026, 0.1738223929198519, 0.0970479492999373, 0.14060563257625028, 0.1430521803277154, 0.12270121549766873, 0.23785275707562126, 0.1430087737859257, 0.20154680846439255, 0.10521865239547146, 0.11678150855004789, 0.3082707776657997, 0.09636982359112271, 0.09354048468653234, 0.09742894780731971, 0.16101193193706775, 0.09769924660964359, 0.2618648790784421, 0.1664883421073037, 0.1474401940621676, 0.1965039580940239, 0.17783258741180744, 0.12339111597787951, 0.17949826174205352, 0.10726200041150856, 0.17743062107793747, 0.13007137203408828, 0.09369129675530619, 0.12199270674177717, 0.16649595702127104, 0.10767144376351949, 0.1406846009194851, 0.1910771138124889, 0.09440446332577737, 0.09186131954793969, 0.21536442991946975, 0.11869368699168968, 0.14288258378303823, 0.23906141399375855, 0.11863053836409124, 0.14362950418745318, 0.1816937165154565, 0.12303152196710149, 0.10145038080912444, 0.1522406848568109, 0.14850707874903757, 0.1283432002509794, 0.24045627624277147, 0.14718292641543573, 0.10337880031476099, 0.1753058762199456, 0.1071393573957105, 0.14874654251240915, 0.2057588518026375, 0.236659467881245, 0.14382217530040972, 0.1249559271720148, 0.18321372688777987, 0.09204114336640605, 0.16101107391859257, 0.12254804387808808, 0.14580168520971654, 0.16534337773919106, 0.10285844275307271], [0.016716710749953505, 0.10757321596986825, 0.025701437806410175, 0.08617594357459776, 0.02605300704618135, 0.04200340196069691, 0.034768318216646873, 0.0274178080050455, 0.04557157138122186, 0.027821810217574242, 0.07585436436197451, 0.04182165526154061, 0.04009927127269968, 0.10260826141964044, 0.01774416489136075, 0.03683366061699006, 0.0544837020307539, 0.13619868114830988, 0.020134996983312795, 0.010035926093076988, 0.026560256843485182, 0.03952382049793678, 0.12733441567228687, 0.010542033461763734, 0.04203228347544228, 0.027159938979293072, 0.04972011752186283, 0.04268398681174844, 0.03860020191378651, 0.08312948003050782, 0.03336974810208044, 0.04258748271592683, 0.05557857957037707, 0.04980978811339987, 0.04963932205892859, 0.07273503819540625, 0.05988138900589078, 0.04696887745071323, 0.02739797207346607, 0.08491403588484372, 0.011935342467510173, 0.040704162806392684, 0.03123728873869104, 0.02885315800085664, 0.03745249495090496, 0.022182162032432617, 0.04815653206840639, 0.015002457826818912, 0.015939167895985228, 0.020440081923058438, 0.006274752311348435, 0.06039106347147496, 0.06006661374422331, 0.05041575217018685, 0.09713488495758466, 0.0171465665147069, 0.015991806754872443, 0.015012446655741623, 0.00954133015306246, 0.01546166912322083, 0.11413521103320584, 0.03221961264047892, 0.08850016240631381, 0.08349498057918203, 0.034299081702145844, 0.06544365081936121, 0.06228195616014062, 0.049470660141519004, 0.03146229642293146, 0.0341706432312006, 0.04581956553363031, 0.02938558719301176, 0.021090823819019625, 0.010630158470913528, 0.030549563948185216, 0.04188714428774772, 0.012348316527242142, 0.030198915929142988, 0.06527612271207957, 0.00554418501128713, 0.03991416910843503, 0.15845109918905845, 0.05522991380383892, 0.0033965482491053523, 0.05558742788590251, 0.0176588935597289, 0.04391806635765299, 0.06673318363966481, 0.02185888825014474, 0.02454516598053517, 0.046819750775372794, 0.06627058144658804, 0.007588139673199265, 0.03948647754206773, 0.06636081128230979, 0.0356011898557265, 0.041215580122004596, 0.039893913743717056, 0.07738647126262227, 0.14010873262680348, 0.061837238289656184, 0.03490482359343479, 0.03812126672616409, 0.022231953917071227, 0.07168221122194683, 0.03687512129545212, 0.025732952748395266, 0.08545838732032046, 0.027503787968007308, 0.02216485610622312, 0.04059619803522383, 0.009193437177717928, 0.018945316063059915, 0.08593923772775358, 0.03737625005024095, 0.04317071311356079, 0.013348251832799326, 0.023870108453857324, 0.03724900284601796, 0.04047880272170709, 0.04761872302380301, 0.08760258315070983, 0.039880001587012125, 0.06095370525614389, 0.09894864408359413, 0.04711494360479617, 0.028093671839263652, 0.06581579335033894, 0.03167186743549762, 0.04708587822894897, 0.033481991474306395, 0.03391176679982774, 0.07983606804402606, 0.03643475863481722, 0.03481562031553157, 0.03507847274323145, 0.030377864492155855, 0.11304869917371582, 0.040784261129315824, 0.04475402150062784, 0.044907752364393205, 0.05854594836672468, 0.047158989830002676, 0.04760008410460526, 0.04066873123989471, 0.08533539190407723, 0.05737613593678802, 0.03867282321856868, 0.023154727889284975, 0.10372813640823288, 0.0422856938694754, 0.04760876005034774, 0.07713685683425396, 0.035281934204601476, 0.013948094847071317, 0.023886791933628342, 0.018187524870999398, 0.02973933020726808, 0.06557160282447454, 0.040648537162210674, 0.030720045324414972, 0.10640896916870149, 0.02301464488189067, 0.008296236178026566, 0.01457152187809228, 0.02977369308111168, 0.024322422086111, 0.04057978843188575, 0.053969932825214444, 0.04970305674378911, 0.03671790090119166, 0.025661396305827845, 0.018072226723175377, 0.10230244678114692, 0.05241094389930368, 0.019161858475737033, 0.04894024384538493, 0.08468458489064248, 0.05998552333743823, 0.030940063861048514, 0.08993975652922546, 0.0542543659497413, 0.05560649198389823, 0.02190286744265787, 0.06705834965912566, 0.07779418325592434, 0.038866402145715497, 0.06211451998340988, 0.012705031962644671, 0.028714775708654237, 0.031882566512532295, 0.030366830910826405, 0.02999990926905265, 0.06644860495843234, 0.056303482607848225, 0.012777572828194788, 0.08848649539774464, 0.04513803073355267, 0.018632974355451522, 0.03157832809994298, 0.039139405238412084, 0.05959849188765211, 0.01703907671805111, 0.028901484742340063, 0.042813333096883954, 0.021814382372183666, 0.03478844334641772, 0.04724204525231354, 0.05845487966472584, 0.042041055182175296, 0.024721214900754636, 0.0760943107607384, 0.026059357915073637, 0.009185466990475694, 0.020945602276873206, 0.07786682371290461, 0.04394745732086801, 0.10896925033340532, 0.044432019424294276, 0.005220975388862914, 0.052907139047860145, 0.01599616387994179, 0.015553848652709878, 0.05551947588701883, 0.05588051014309449, 0.005899261976141604, 0.04688423239595948, 0.06584243788834541, 0.013761916329273054, 0.07315612608386625, 0.07142202478022346, 0.02735299696665137, 0.018186695580821366, 0.055201706446466915, 0.03922385111030552, 0.04943752300835425, 0.041503035463392735, 0.0645864060929706, 0.02844066178846744, 0.07172688180881162, 0.022715445412623308, 0.06447858687850737, 0.051160500715336496, 0.006674159432746351, 0.01907148691374929, 0.08899838002699037, 0.057507431915690826, 0.034321999222400694, 0.08274818274883494, 0.013344835080657036, 0.03997402738839869, 0.03919292031036269, 0.05761284561407182, 0.05078988652976771, 0.039096914171691866, 0.048795077844613025, 0.013241067513703339, 0.021268941176634644, 0.03188566533818601, 0.048493147271895604, 0.05491736525249097, 0.05308119422425667, 0.05953213718209056, 0.05836312148359515, 0.04310032112463828, 0.04478583330168359, 0.10249814394140437, 0.03458769766673927, 0.029359273988032536, 0.043151147227974675, 0.02506994961520597, 0.023728129378850424, 0.023981152898481777, 0.039329268639126135, 0.03062818755185412, 0.03853598842397332, 0.02996772974579325, 0.055999384006305095, 0.012637146996454367, 0.082616898261251, 0.058812110294257446, 0.0513137910785454, 0.04588387861487366, 0.04334874428628434, 0.02354579853765186, 0.03724555161991908, 0.049351050833901094, 0.07238929505429922, 0.026030893918246995, 0.08589409216637574, 0.0630431411217057, 0.05077191410706409, 0.11594279549054562, 0.08743753716830285, 0.06008120771918086, 0.013947464739753595, 0.0185475823649716, 0.05464581772685052, 0.03096357318422487, 0.0203687361546702, 0.09232376086255235, 0.058539972880915295, 0.03064957672670003, 0.09079601300219375, 0.05463755163814753, 0.07405621810786187, 0.016672264243806564, 0.032540829476690104, 0.03839882421157053, 0.05060827389599816, 0.029775301865752668, 0.04358840723251624, 0.019531287140243, 0.0312741682113659, 0.02673400175427237, 0.03474513639605815, 0.040634425822645426, 0.09324359497235668, 0.047822433463748426, 0.03460306156006071, 0.04078103972959422, 0.011607237543249804, 0.03532315356536739, 0.029346005345183997, 0.0726361668878986, 0.0227503617849922, 0.045789791526453155, 0.06691331389330088, 0.0507478091505266, 0.050460415096172405, 0.04175147394679728, 0.02858899939324587, 0.03858273510911292, 0.04107893684939031, 0.05815383009312134, 0.04922851123997281, 0.0639774504628393, 0.08009051648719658, 0.02306198145473196, 0.0682664243504405, 0.015501499949623982, 0.0673264957543823, 0.015217195144824445, 0.03695166880084622, 0.042210747487843044, 0.04929134194108267, 0.04700589481921447, 0.006804798012449136, 0.037523457675331065, 0.015316021444666532, 0.08313904846868209, 0.04172090320817886, 0.11641989206714977, 0.14316804346538362, 0.15844181420341616, 0.11238266999322562, 0.23472474347199165, 0.16756904702032768, 0.09782591158704412, 0.0742211644988387, 0.19185611797917276, 0.21896128933275902, 0.14581740533392276, 0.17645767409234278, 0.13708271596941257, 0.23628955466612694, 0.1017498828831219, 0.0974007404499477, 0.1417997951108602, 0.16866928717542082, 0.11821290553216973, 0.1110634589267354, 0.22301800068347688, 0.17100954788827127, 0.2473085190379812, 0.20176134372670806, 0.13801386519785852, 0.14029697575155767, 0.1687438122086948, 0.15474836642463363, 0.19429923365673712, 0.15678766183555126, 0.12825544487925308, 0.14540859017400973, 0.16087143141175472, 0.17733398674716874, 0.1108145263166197, 0.21930506362790064, 0.11730294629570939, 0.1319820719260362, 0.18665767515138273, 0.16741841881265565, 0.09086255539929675, 0.15105729351841635, 0.14323130700617068, 0.11739700657105255, 0.15433248793405874, 0.10114271223785416, 0.08581180666242877, 0.16574630934384563, 0.1121970545500517, 0.1451743051650063, 0.09176509890465007, 0.19367021418386893, 0.1927973795682192, 0.1596633107551644, 0.15521258506323063, 0.08789294579577062, 0.11193424042674804, 0.07438747452632075, 0.12087906004800913, 0.0949162943288684, 0.1872170112666584, 0.19068058670288135, 0.18093599427130916, 0.2207476531545962, 0.11285901580366398, 0.18099403309245266, 0.21648550766610333, 0.11240011381526148, 0.1096897560261911, 0.21421154420222008, 0.1830777003159446, 0.14063826792182463, 0.17589715820166374, 0.11052533578608306, 0.15517411212767326, 0.1251159859220347, 0.18297323656658973, 0.10800092285799404, 0.16151275425668687, 0.1233904877857816, 0.09982600627887635, 0.24640828911815923, 0.19121626602305522, 0.1994827224482452, 0.11642389870699375, 0.12041075816077572, 0.1901392230103093, 0.10479200270868118, 0.09991297258004066, 0.10940177591457483, 0.2146769119727035, 0.16695636054200513, 0.2015147093803652, 0.1380829816503871, 0.25297220706218676, 0.05575537351110289, 0.17425262789812782, 0.18559397739027778, 0.16765610525204291, 0.26618825031384347, 0.14585770155873992, 0.13203853260605566, 0.13518692414847114, 0.14781706335563816, 0.11839105161808192, 0.18578235841085836, 0.1082047482111281, 0.16669805101569624, 0.1354874144758909, 0.1252142903244784, 0.11914607723273578, 0.20185336620817262, 0.11743024712608707, 0.08644778221364945, 0.12409426211830109, 0.09535867180074416, 0.33798420260990825, 0.19771132798444843, 0.16868010433691163, 0.25341287615799135, 0.10892097147241717, 0.19574326342873036, 0.09744811532718521, 0.11955270138118537, 0.16242962360622423, 0.16452482811385588, 0.08953906956218904, 0.13899401340994144, 0.15924790723910257, 0.19163191468725282, 0.11085948801689571, 0.09836174412480286, 0.20683246274148265, 0.11866588566091754, 0.15782119105419806, 0.16410513450541805, 0.0982014632092849, 0.16128928640917425, 0.10129053656372333, 0.1320888492609224, 0.12093034197366047, 0.12673917301600018, 0.09732683594789236, 0.14874786018363892, 0.09275039522758416, 0.1701710646551463, 0.19744354961139543, 0.13566631132796889, 0.14611086297419765, 0.2568156395347849, 0.16344585455954075, 0.24168325798405757, 0.17913910440139233, 0.10981596901171631, 0.06616445528643747, 0.06758444521936678, 0.08308768993423832, 0.1193880690862575, 0.12056535470389551, 0.18172757760170968, 0.14650720622270338, 0.1692539195139562, 0.1788911830273367, 0.22439642268563473, 0.09049516261344956, 0.1489674209827377, 0.056852786801755435, 0.1650398996688666, 0.25243389239955333, 0.16722158018139102, 0.14657433084662885, 0.16792691733327605, 0.11635193240738685, 0.2265866527393941, 0.19420086796725952, 0.1457077015431658], [0.05899187665612948, 0.030253290934788606, 0.04425141419614515, 0.05806387221861271, 0.0532662044579704, 0.00905999902545685, 0.016632686226418423, 0.006555458896928617, 0.014056400527366468, 0.026617194413237517, 0.01713678548713365, 0.03432188430921205, 0.013526767556134973, 0.06075655252883031, 0.04155367387518768, 0.037940707463290424, 0.022653325258063215, 0.03648895552502044, 0.023440296739159573, 0.04924010598070679, 0.038461386781906894, 0.06000868600582885, 0.06168265706829487, 0.045555655904594934, 0.02333056422010545, 0.05061220775748934, 0.04661433195935623, 0.03194899208122685, 0.04041748121380806, 0.007070927860050072, 0.02408861396684041, 0.02859588460846534, 0.05953688309678148, 0.0380547090073026, 0.028726198079605258, 0.040328764401736765, 0.02537966172601427, 0.005921576202156083, 0.025092135521493135, 0.020620888249287685, 0.024015104000066078, 0.04722467037819086, 0.02752085449174047, 0.037136889708739136, 0.0102047891085667, 0.048781939436711615, 0.06403709806862377, 0.048214329571853724, 0.033128369118898146, 0.020979543802358454, 0.04204976177143474, 0.008247402860903212, 0.06606516263057148, 0.008344987140698059, 0.025297508372234243, 0.1301313720403179, 0.03742950465229731, 0.03029140763946118, 0.02044670283794403, 0.013062749058008196, 0.04416750458579871, 0.06222667908596416, 0.02234261723295335, 0.1193277013578242, 0.0453109406085024, 0.04479592267964636, 0.07076224687719537, 0.007867625784955078, 0.012771186527736005, 0.03687804009044363, 0.021258643039712505, 0.017340641483784686, 0.032882864752243605, 0.02193878355976795, 0.03729351638485828, 0.03489684478770341, 0.04050728970117146, 0.04020473093635613, 0.05014500903686689, 0.010880567715503277, 0.03151065380793185, 0.04960109810194662, 0.020149512434258096, 0.02606827517851226, 0.03197843858581637, 0.03177838047004996, 0.03521141581117146, 0.048180238659223246, 0.007146540738176555, 0.08263297844678164, 0.014370873874624171, 0.017930705385703235, 0.016483481027065747, 0.027561460982166955, 0.01742972601805964, 0.044286520175275304, 0.08076025353324029, 0.020593686382316297, 0.04004279527092173, 0.08291951831310027, 0.01792324368932074, 0.06504168448549125, 0.045483245273991946, 0.013074991143038197, 0.09103875562188127, 0.03308091380242859, 0.07564857782375428, 0.03908496320007309, 0.014728952946531919, 0.02404909149082678, 0.03857456478140047, 0.03168105666014937, 0.0374151328428378, 0.020117744683257995, 0.06124861080259566, 0.040357121146254005, 0.061951236003228737, 0.022645026610623446, 0.04544346615852368, 0.05089575222002403, 0.024860790374899105, 0.04718634682977873, 0.05809751496980748, 0.027982290315952514, 0.009588682047662236, 0.043759306126664725, 0.0074492761820194224, 0.06499774168215453, 0.03524749855240507, 0.03244988717919877, 0.037449082029202295, 0.035269914285069516, 0.048738402659974756, 0.003117149519253402, 0.03281704630822905, 0.036882391469853545, 0.08767176089027236, 0.05184861621068371, 0.0430475989536893, 0.04694463076790975, 0.025883919949973785, 0.0337483219411825, 0.017614270853359374, 0.051845505893711126, 0.06222457617461201, 0.0606932123792508, 0.06600228979462577, 0.044874894853320815, 0.012401042528630746, 0.05836651525309971, 0.047224632073794647, 0.03722587082114431, 0.01643513896382384, 0.06186894283840253, 0.0206334731586638, 0.027169105221307086, 0.015414615045301618, 0.018621224481912873, 0.01757768440931555, 0.04525747916270648, 0.02961868668095239, 0.012441459412295974, 0.031944897341271566, 0.04431786083225762, 0.07205262239421568, 0.043282527476549155, 0.020172041164891377, 0.017926805998168645, 0.013157558184297336, 0.05808560613302454, 0.04203386927744554, 0.00284508464486158, 0.04138250685026569, 0.04291459459871535, 0.058861771943948926, 0.006785471050534398, 0.031870473814647526, 0.017923908270595056, 0.022665010014128302, 0.06441022119214458, 0.05513920899360411, 0.08514567022962917, 0.03583262118721201, 0.01591732289882437, 0.03838512272904477, 0.03180358284753898, 0.020216667701700525, 0.020430241523671056, 0.03719573292220312, 0.05098181836787732, 0.029707989550285765, 0.06877681510823389, 0.03376340238197196, 0.0198748794895026, 0.030717890702127933, 0.03718276688408467, 0.04251100415844591, 0.026515645628434517, 0.049160421345262766, 0.052471070310040835, 0.04231777763174426, 0.051103277777832364, 0.05972865405642699, 0.036675061264465895, 0.03755049291817892, 0.026825233249955123, 0.05099271213816059, 0.0693035158779352, 0.009750702940378218, 0.08234453102153155, 0.07581040623687929, 0.061478027322840315, 0.0452534188967078, 0.03412168255195983, 0.07605146346313339, 0.039364106487482786, 0.017871272284537554, 0.031227231919465047, 0.03287847123799786, 0.0057386329694230475, 0.10025863911235526, 0.01387230959916187, 0.029070420536182584, 0.02607635549089361, 0.02573808362226813, 0.03884985464655104, 0.036666362336085695, 0.020287716611018105, 0.051809894296550946, 0.09133166167885066, 0.01898244259909036, 0.058259680461619175, 0.04883813964683683, 0.008349983949184177, 0.020569512477865624, 0.024939728074616967, 0.05737209865342706, 0.11736854640466553, 0.023933414129480243, 0.029222014014639204, 0.027961347387322498, 0.08674419695331205, 0.046270369972673156, 0.02080611873327965, 0.06516258082082195, 0.024681780524852297, 0.056103729012031714, 0.02464849400454231, 0.049505203046024814, 0.05232146482974772, 0.037479786833207455, 0.10007771978815717, 0.028649464797889514, 0.016089039591832027, 0.04747381366248574, 0.01922294058115973, 0.03245560602555352, 0.043837688412637486, 0.02994956963154818, 0.007996857156901951, 0.0407254638811273, 0.03990096175262044, 0.06486394442617893, 0.09108831384970296, 0.062532156645771, 0.04362298844141826, 0.04362355917692185, 0.060576636779813044, 0.02971975091514328, 0.03623795447750919, 0.03092861659223995, 0.024491811787048658, 0.022579598871450272, 0.05390662331915191, 0.013715491401061658, 0.03016088923980152, 0.023041402417865973, 0.04194796783849598, 0.05802871261332786, 0.0511372346250761, 0.06553720547667434, 0.010656606698889407, 0.13332614254566932, 0.05312253615909046, 0.011462028450032156, 0.05966833995414838, 0.14441881989759786, 0.014314644936201795, 0.08252997026448289, 0.030270052938571865, 0.03476699671497749, 0.028071891959576357, 0.019561629967703935, 0.04571776010937268, 0.03689051966273016, 0.03200169509997772, 0.0372078639244841, 0.03651239015462418, 0.08520612988861338, 0.03765108026263695, 0.06993542350227795, 0.04157818102788541, 0.02481712719365474, 0.04506907515948819, 0.014411970661322196, 0.026072546118690122, 0.022006551697549802, 0.03547210787092486, 0.0479682736218937, 0.002642712464758886, 0.034363038552504395, 0.00846095274262611, 0.08082952320335374, 0.05014390970069555, 0.01900071954174388, 0.0696186691282257, 0.04452469691093411, 0.018008601205844074, 0.00874077306023889, 0.031144377595234304, 0.0574764474895933, 0.018877028900709365, 0.05277271359978665, 0.09241118681647124, 0.046663752291351564, 0.004462178227596827, 0.0528757754082401, 0.021386554825209805, 0.02561709727160633, 0.026209426878560937, 0.021737953610417825, 0.0333369174040854, 0.01991975117444752, 0.027781749564793803, 0.027145825724508015, 0.027949015286961393, 0.04037549193467825, 0.014689037850457094, 0.02877908495945796, 0.04984260732007604, 0.05958437288720762, 0.06072547234174225, 0.05140425840152368, 0.04849225477946382, 0.026351762184452628, 0.049806700779065016, 0.01573113576253696, 0.018892986512172128, 0.010518417843887884, 0.026029564755698367, 0.0941446905715331, 0.060566240966680555, 0.11175613264523207, 0.2106628257540926, 0.12894154556335943, 0.16143747845724707, 0.12532427756776734, 0.25777948539583917, 0.11110278221988872, 0.1301779961513896, 0.12566285012590309, 0.08236373684579328, 0.131807679670953, 0.0956682479309459, 0.08724973837454474, 0.22224607516921338, 0.08356254187322433, 0.11001863757208472, 0.13893807366971048, 0.11674526493035017, 0.07278994371693942, 0.11520573463771613, 0.15071443852878388, 0.11580827811192121, 0.24092443257329926, 0.15035120560036552, 0.10456746999895382, 0.18604961584412283, 0.16544326028275877, 0.14737855462778002, 0.10213846566095468, 0.05336748894243952, 0.11545079850381422, 0.21809404715895656, 0.15955380614726775, 0.13999930462769924, 0.13047117800001176, 0.1895941820957007, 0.09685789054680256, 0.09673990534558412, 0.2053519518625352, 0.09352987436878105, 0.13368971255277434, 0.12192499989102926, 0.054106480336838195, 0.09842951992346395, 0.20144543971025175, 0.11522615854177745, 0.10663353252194582, 0.23398243491688084, 0.11962685869225573, 0.19098179715294994, 0.17263166245914277, 0.08966833157765289, 0.11822536212181854, 0.11988958088500846, 0.11206312705912899, 0.28152557570607434, 0.14315817625291888, 0.14531975461831018, 0.06822316336535639, 0.1430427114809713, 0.12022947877525322, 0.23500169957837752, 0.10203367249379236, 0.19940007688297381, 0.14834675186824414, 0.11563528779773943, 0.16545573219416604, 0.14650803359766162, 0.16019966423271165, 0.12513168306360323, 0.15633593043012006, 0.11957759157784524, 0.09682877920567991, 0.14721372314999182, 0.10772415061271, 0.14830970385622594, 0.12938128003189642, 0.09773261739962524, 0.22376651455077434, 0.11803540296011394, 0.1056365610190457, 0.1299615609910219, 0.1346918474882841, 0.07603067183686842, 0.09106654163089492, 0.10213285789734895, 0.11580840068598909, 0.20701004192233088, 0.13265249079033253, 0.18310255220820829, 0.1457761591600795, 0.1870655250405112, 0.0730141929741348, 0.12586082256729567, 0.11216569091043166, 0.11356598472282772, 0.10770085387893262, 0.22384433376212276, 0.1115056831810263, 0.26251265238369664, 0.13132404836435474, 0.15204482681808934, 0.21043865310568965, 0.10354309553100217, 0.20624262100506216, 0.08536236585989114, 0.2577920798813143, 0.10837517979164278, 0.12063992570244497, 0.21289857675231275, 0.2176901502835174, 0.10440237039039213, 0.1419573793968847, 0.10402555472307629, 0.10153782974568107, 0.08075269224542765, 0.11049693690672999, 0.13036331282027308, 0.1662398231846671, 0.12753385134161482, 0.1450445911576671, 0.13120265407187323, 0.1282356568281689, 0.08439509558581537, 0.1603644344234659, 0.18600847692258898, 0.08015139749453914, 0.22492980374203575, 0.09665522198643416, 0.10314641520380975, 0.08766736354558699, 0.13763025433065432, 0.11960755327656386, 0.14456676679753488, 0.22477336858789768, 0.09768075324715146, 0.20233451538989622, 0.13714119912155215, 0.12986013094984716, 0.23852973365254942, 0.1886079664672575, 0.09408814562184196, 0.12372270947502506, 0.15892284081107186, 0.1101495007113103, 0.1486329929602723, 0.1345957187755454, 0.14996754876788587, 0.13536102529014313, 0.162311140447855, 0.11617013974295509, 0.18059597380699652, 0.11091350487643674, 0.2091259154821596, 0.08000120595698396, 0.118044933093892, 0.11901597252055524, 0.12133625366034047, 0.08653739151815254, 0.1075402205629695, 0.18168216390955835, 0.1290611472100981, 0.08343271295269651, 0.1775965863658536, 0.17208654493574174, 0.13907659768817887, 0.1381080174037526, 0.11707453718108517, 0.07704188491428092, 0.12704466589756552, 0.09932378967923504, 0.15353405577761514, 0.0813878940478448, 0.1646733112753399, 0.13287055005709972, 0.1968127221710259], [0.07358342694539217, 0.005976971062350899, 0.006514381262428698, 0.07549708393672783, 0.008150236099027097, 0.041006809671319304, 0.060527649287494927, 0.07348518382998244, 0.014698880165064288, 0.020588002009918133, 0.03683734166946623, 0.03573706320997688, 0.033842160051027616, 0.03398611180243954, 0.020768059485201395, 0.06908948623364972, 0.028318656540866342, 0.021768957188713457, 0.04212052914344015, 0.025496493964906664, 0.1085310327189584, 0.02181225456297398, 0.05072282702331582, 0.058368771382036715, 0.0380006768260031, 0.03184146014973521, 0.05410611261463454, 0.008034858469580932, 0.04864177599008526, 0.0934558243100201, 0.03240866398799323, 0.01945552104453166, 0.014370914094240196, 0.035300105810165405, 0.00806767288820758, 0.04574078871237655, 0.020410001480711565, 0.07527505633451285, 0.07977757723100724, 0.05564001216102512, 0.03701926839928474, 0.01723170186573219, 0.006090546948760147, 0.059938669399989236, 0.05525658898536236, 0.06774479508279793, 0.061213665701929605, 0.023486926595890717, 0.030935124509156715, 0.02917041224727948, 0.03632181046170093, 0.10254120574362817, 0.01394618058487052, 0.016697872647895448, 0.10148906824930061, 0.016283488028772896, 0.0725977399176167, 0.030453088580660766, 0.024151603631194563, 0.04281710607991104, 0.061847680068064126, 0.035421101736926267, 0.0793195409219592, 0.01672215571987533, 0.06033405503858963, 0.03679347547492193, 0.07245472662391202, 0.06944284428872409, 0.026381563004707138, 0.009573877398525516, 0.03610981478085441, 0.06553059413788781, 0.039890887696416154, 0.04653021167483061, 0.0012036517305645132, 0.08364941624383773, 0.06850673847140805, 0.03817016228793129, 0.006132636298125069, 0.03265871125603876, 0.018148988733188282, 0.041992960182288964, 0.006388189823126361, 0.0680710029818358, 0.05236880140258901, 0.04373960617569186, 0.06602113555756307, 0.02802094711261171, 0.026073070888918255, 0.03400231839247769, 0.05019074065550681, 0.03796267886495879, 0.045017961773180196, 0.0509548980382181, 0.02856209247012533, 0.05733298986489254, 0.03485082205565226, 0.031110995313933784, 0.020865423514718012, 0.03255508254252134, 0.019263468547573975, 0.11701606168982484, 0.03521946356481603, 0.05118850505940857, 0.04180292824223157, 0.11711231297663144, 0.08201726592115818, 0.04793492581454977, 0.0709210722256572, 0.01731601941789831, 0.009328932276055699, 0.01668672606859717, 0.01756143376922175, 0.03314554864060014, 0.032517073090158166, 0.024404180904610023, 0.06616595681876906, 0.017703751838135145, 0.042624898450148684, 0.0524037886380909, 0.031687020654639894, 0.01603152554091667, 0.02364693938063518, 0.059460247491276076, 0.07043962426964315, 0.04886747315345753, 0.059107644032807126, 0.08137237310649888, 0.005929309380946742, 0.04154472596823208, 0.030616249986774022, 0.04603926422855547, 0.08124800639287119, 0.07586718867382697, 0.041610670816754146, 0.07639643285543689, 0.019621605076076045, 0.04594045420808177, 0.026209382828505292, 0.10276307246737904, 0.0259492117085404, 0.05811861303124217, 0.06723184559133745, 0.029486856355722395, 0.02364887949830342, 0.0497810866293167, 0.06576538476492129, 0.0656357397054953, 0.06433840044924329, 0.02632194412721982, 0.019179336771729494, 0.008363807048167913, 0.08634436800475083, 0.019588808852037596, 0.05322328821245221, 0.03010105777291521, 0.03367930508008407, 0.0472229773238782, 0.03707058096845304, 0.032398635897064404, 0.022982021027635184, 0.04930825716245079, 0.052045286302604986, 0.02851834118876967, 0.06703068622417989, 0.023279531273029508, 0.1497457356702897, 0.05068001803010703, 0.02523301526032869, 0.006773369734160483, 0.047440894864379406, 0.01903900670097961, 0.004471740441306705, 0.019480146940857656, 0.03439506485817894, 0.049180623083826036, 0.042321389736307245, 0.011418782786706523, 0.04811129840691725, 0.05500851822416148, 0.0394779892878667, 0.010252806542050696, 0.04937729317574732, 0.055845059424398415, 0.04969998090077312, 0.020517981573638898, 0.05148377449762437, 0.06480094901616536, 0.00943387483036326, 0.06884607711746808, 0.05945891449828783, 0.07846558271276374, 0.08536218965966856, 0.018198162001828035, 0.04404051402103036, 0.031733547089501254, 0.0477968882619133, 0.028507075865843126, 0.04002761906914173, 0.020975184762069297, 0.061611269165070794, 0.007119857895773866, 0.027298122088635163, 0.017850264238433975, 0.014690806555952278, 0.06915327837510456, 0.016933672595769167, 0.021999183846938036, 0.04492891554330145, 0.020427064174005104, 0.04811953768254288, 0.05133901835389195, 0.06135193308094337, 0.021097551986214616, 0.020222637441850478, 0.04601032908765539, 0.0464516416973164, 0.019277643089392976, 0.05296131295542564, 0.07171906005110472, 0.03375038654813844, 0.048147813987828074, 0.028527308247923374, 0.06331191923949989, 0.034171229288462675, 0.026415368549585826, 0.04613980560773804, 0.10180848094845012, 0.06813735385695774, 0.018107570189562057, 0.07231225725263357, 0.045270969971053066, 0.04920252936802084, 0.07408370534258504, 0.05825999455766813, 0.047744491678332134, 0.04155247111714656, 0.05434969027015952, 0.04120155305211102, 0.05545261556342725, 0.03230289788916707, 0.036051526981135534, 0.06657019843377414, 0.05540773047194366, 0.072509310388517, 0.011373418890270255, 0.020768666609881387, 0.011560090577169772, 0.04454864481944711, 0.06494068345355411, 0.05832957449339091, 0.008634263856126177, 0.03739313079765247, 0.021630850688163793, 0.00599966498069285, 0.030897053769759597, 0.10335859857619771, 0.049167446371528416, 0.019562639288544174, 0.0708032172593859, 0.007629415054144639, 0.06842244581709947, 0.04715479932905686, 0.003869959703391238, 0.022936053836958546, 0.048799222380283384, 0.055569256280338576, 0.0655486891346593, 0.06534282598764667, 0.020474766553830237, 0.03352945828209481, 0.026667616405193845, 0.0011409506658955869, 0.040002093019504706, 0.03874517639257735, 0.03681886362873259, 0.04647132249609117, 0.024738139698221803, 0.06030518884560274, 0.01926645629047867, 0.049204180287497665, 0.07576794198323643, 0.026951321746192636, 0.07189296200991639, 0.03440049259112247, 0.01808042386396518, 0.030602849193758545, 0.05586663629078577, 0.022634611645292853, 0.04795898097537218, 0.009930394608677636, 0.0050732013375137846, 0.042758132631499926, 0.029151715871487415, 0.014378200548010008, 0.030332678711161982, 0.0649512937713054, 0.022709050493675376, 0.02697406881188433, 0.019703925053979603, 0.013228142652810823, 0.020908989019752033, 0.02496892177019148, 0.062289655343779636, 0.030473659956647508, 0.05956116808398117, 0.024963350395762154, 0.06426187209604729, 0.06607954976178947, 0.023153383404977863, 0.021003847941756252, 0.025293143586285656, 0.020298991510043704, 0.04526631215647344, 0.06845960108142707, 0.01643175860085795, 0.059692084849361456, 0.034103851855522206, 0.026464340720145453, 0.04966299034534924, 0.04686771937075162, 0.05845564958308974, 0.03705494511391848, 0.06235833129575176, 0.03828868758113634, 0.055476280019408276, 0.02840925409879175, 0.04100853336914893, 0.01893634134302697, 0.06798638857059902, 0.051954267396321224, 0.028108803990988, 0.09541067384904432, 0.026323596961916457, 0.07027057930827141, 0.0377733095909559, 0.034257134557851864, 0.04180263329838072, 0.01702829403051686, 0.03702870277207225, 0.03406989117783885, 0.034024063798208395, 0.07793321289242276, 0.06548501956727236, 0.04580811251916232, 0.03391353263249321, 0.04011082387859783, 0.0559403071360242, 0.050832048178680485, 0.04699440350035026, 0.11322892901878204, 0.06667434808708007, 0.16796004297512193, 0.08438092295921619, 0.10421182900186508, 0.15961493996362533, 0.11032504209827994, 0.12149257390128991, 0.20398014886004312, 0.1682042105183486, 0.09983981884415112, 0.21370476171855005, 0.10035481379036942, 0.12644443600889177, 0.11470482804842534, 0.16126662552837404, 0.15273409144532296, 0.24377947372774927, 0.083836778367479, 0.05916469077008867, 0.19488789561775424, 0.11144714640273203, 0.17735238817910995, 0.20066599121257184, 0.10746273076942853, 0.17022551818480416, 0.15087957644174177, 0.09449577334547236, 0.24313435108671266, 0.13142432927364303, 0.1216230080312779, 0.21516320926527824, 0.12100060755807547, 0.14610842681459843, 0.09606462182296861, 0.07453281672731524, 0.12526505897122045, 0.15402288116034002, 0.12647489566476117, 0.13766947803237747, 0.19657961693742584, 0.14379041329506906, 0.14373355424932896, 0.07196423883039145, 0.16155150298389698, 0.16990661110368468, 0.07794938500850432, 0.16862493068460496, 0.17480905287929122, 0.11804814300229473, 0.11699644217808401, 0.076365168807247, 0.19382309469003833, 0.13542442672675656, 0.1764973880903375, 0.13673500398234015, 0.2865589572296989, 0.16566773936633142, 0.1763189355692556, 0.19271663390100005, 0.16427710592266054, 0.1611561556496928, 0.2055769978511718, 0.1372802900450845, 0.14270950919918476, 0.10526035822206929, 0.08872338510569065, 0.08292488858944948, 0.30625970493401256, 0.2546244595319994, 0.20790674783770116, 0.16096372968487202, 0.18478091295448043, 0.1275720408246402, 0.21567926141283206, 0.12178277566788659, 0.09709838086799269, 0.14605256368315991, 0.14081498908419765, 0.11894262726268462, 0.06343995551428487, 0.11264045091886675, 0.15987963866322272, 0.12243408829935136, 0.0809971432411863, 0.217257249319265, 0.07176944565388464, 0.10374784018964538, 0.17429775047686794, 0.08997263702293558, 0.09233689160957452, 0.16792624317590268, 0.22491224500681126, 0.11041006253611658, 0.1285892370487413, 0.12762778904289007, 0.16559586499727544, 0.1658366004666013, 0.11708789009360537, 0.1740429955985277, 0.16532085475421723, 0.13521372190406247, 0.10610617291662963, 0.23887649569059574, 0.18027250084184832, 0.10617284554867976, 0.14333874317667178, 0.23166494233713997, 0.12794087385578504, 0.14316648064601806, 0.14057967751737566, 0.10120940785254202, 0.07799119808741155, 0.12973774074306413, 0.13468806301393818, 0.14151822715517015, 0.1056749879893276, 0.12178692786443619, 0.2031422325319821, 0.1401289267044875, 0.07741785788488004, 0.16496050231639417, 0.15808854041801346, 0.15368201799931067, 0.1403419910779884, 0.25492084362814504, 0.13474323666624485, 0.20396162485403402, 0.10186304173041737, 0.17622260767365658, 0.16009247321034634, 0.13240597901805756, 0.25742699302011923, 0.18135420166917388, 0.16427443993668403, 0.09041674585352022, 0.11468711609561598, 0.14395185866423194, 0.12206523994644805, 0.15561403045731206, 0.185938716956204, 0.18032068777228558, 0.1224213865615668, 0.14902175193832767, 0.12321344486648038, 0.1138329357209225, 0.2042652867854603, 0.16593559434817684, 0.1897513526942461, 0.12725927776867343, 0.20342626729078833, 0.17057687675039615, 0.08581307070750384, 0.12243125377403152, 0.14181396773745938, 0.11710372513100026, 0.22311619783361114, 0.14778222167684188, 0.11215482012278612, 0.11561691700931519, 0.18601944730166467, 0.2195099308606117, 0.11301339018128573, 0.10336658887324796, 0.17636608062011583, 0.1767364228444715, 0.15860488367897851, 0.258660180073592, 0.2436217362241399, 0.20327683418027817, 0.11702887834079805, 0.09859069716185333, 0.09504012478094909, 0.1771939152310933, 0.15531493440991448, 0.1294898959778009, 0.3005188258905565, 0.1020283635044771], [0.06503785404586984, 0.01689814526828066, 0.04191419868279369, 0.06730742016506773, 0.03332036990492094, 0.01861884003324855, 0.06357359189179636, 0.03804253203974616, 0.05943816117641907, 0.033316301978043014, 0.08394411494654995, 0.018914015625693628, 0.0673028696027975, 0.06234344237694337, 0.045274195201214285, 0.06462241988629103, 0.05814656374915954, 0.10073651709864218, 0.047584049884350076, 0.07249389669948048, 0.02969469984001931, 0.02610851203151528, 0.0386481283743295, 0.04771659458656946, 0.015198765942195972, 0.025072044865678877, 0.012414529506537705, 0.05150616341721147, 0.020995637394427773, 0.10634833330949468, 0.013330561905017784, 0.03685836312210849, 0.06414895073600835, 0.12587808252822968, 0.051346947363908255, 0.014241138799867083, 0.05041516611292478, 0.07050494858694654, 0.05383477576317326, 0.03135691528328725, 0.04445258122418196, 0.041948266612786445, 0.04899408833514299, 0.007185504448810413, 0.011404976924701084, 0.04226187619590952, 0.03746829551434325, 0.03295586144010867, 0.08473297100394003, 0.0122086922149925, 0.017715003754523014, 0.06251214259874917, 0.03911972827007694, 0.03797470261493037, 0.06584271367999815, 0.101014323562624, 0.033273726641651125, 0.05759254811451801, 0.0360317274387325, 0.04725126129004264, 0.040671343599716504, 0.045038852990875324, 0.03952644434907744, 0.05956867191519949, 0.0648417815025295, 0.022044697130519538, 0.0513290936848329, 0.052710817525944406, 0.07789169092692676, 0.017384155277883815, 0.015307573410081527, 0.056920692835363655, 0.0510372065248028, 0.023788612020472368, 0.03289306138251578, 0.03495263897122876, 0.026645537751216083, 0.08256838957388556, 0.01218934179163508, 0.014136111018277947, 0.09629037261249558, 0.11678870977653612, 0.060083463848117864, 0.040432477384925856, 0.10755807807248448, 0.028906232572250792, 0.059110018905372395, 0.022096917513878118, 0.019112166182528582, 0.0424717000174907, 0.06709376590386515, 0.05225962238206018, 0.028432309514872973, 0.023899533891028935, 0.03309125215896676, 0.03641418917405029, 0.05878852627750847, 0.03932460316366727, 0.03387292614206672, 0.04238200261287632, 0.012048643998681538, 0.027013955179661996, 0.046490926686073505, 0.025788695220985723, 0.040791381916572014, 0.03517397709431187, 0.038481094393759005, 0.04370746112638905, 0.074982640573815, 0.017767340966290044, 0.04633504694568054, 0.01940439425168499, 0.09975281423859059, 0.01961159422212551, 0.019389652804802024, 0.03181926849778862, 0.03509347657522848, 0.018147341644151077, 0.015392099721207014, 0.03485982358876256, 0.018885199228421818, 0.026317778524131547, 0.029941927904503483, 0.12141347532310795, 0.03336785586490747, 0.0767406897859708, 0.06386602680469233, 0.0747306282902437, 0.01668492959241473, 0.0746150486051075, 0.03203480733528493, 0.02488000769047968, 0.028202234159013437, 0.028632444239431815, 0.06437399289420535, 0.05835356070630013, 0.09329747393607132, 0.05067486608881624, 0.046582734662919276, 0.07294713729812254, 0.02667366466935604, 0.04948025922321024, 0.03995911548695257, 0.035085551395651796, 0.026239478592610648, 0.0042490458637926614, 0.06136221015044759, 0.0666822464535794, 0.053864507635514584, 0.04457594819306847, 0.0924194299225365, 0.018778389334798824, 0.035391703112832004, 0.05919315093647569, 0.03425367184043412, 0.14130877871667186, 0.029379898990173976, 0.06004378432407976, 0.012086114316668001, 0.0159744203894309, 0.08917158484579095, 0.017254715146977576, 0.01509668281106579, 0.06569395472686138, 0.043070179395257466, 0.058696978770556955, 0.013695917854596291, 0.08838356382423833, 0.04558309334360304, 0.0065197591996571476, 0.015640496069775717, 0.029009154569658063, 0.060405335689504305, 0.017800206138241677, 0.08251071847494572, 0.030600233003497127, 0.01974189045628713, 0.09409084991221467, 0.04656981459007629, 0.03366251626322347, 0.01800198220617829, 0.02442175879203264, 0.0598708859404489, 0.0054730958823535234, 0.04497310732521358, 0.02205754250978991, 0.03208577133444769, 0.028255954159483797, 0.011465665452452678, 0.04378229259483276, 0.09074296141343732, 0.09612083735485231, 0.019225217777514653, 0.004376679942417409, 0.027942492048286145, 0.028367879605221174, 0.015695567257822524, 0.04571297589028555, 0.013445451153412223, 0.010590208900882112, 0.01858920200667795, 0.028332643391143893, 0.028971166184712804, 0.05992625494517627, 0.0070838594242119265, 0.049107844731019396, 0.0145084910365122, 0.022730956777870175, 0.008570723566076448, 0.061590132799239895, 0.08232422203065888, 0.006526865143959801, 0.027644255934583566, 0.02704685291035041, 0.11108630366863743, 0.022986255578636643, 0.07438581211552506, 0.007574191127317928, 0.03305511962201807, 0.024195450673540755, 0.0391763843025171, 0.031363413624104955, 0.03873066285685186, 0.005972929469745366, 0.05713003785199216, 0.02417819645826615, 0.025375166705118555, 0.07208345743316798, 0.05341192587248741, 0.07508381014509548, 0.04114015493541956, 0.06705385272301013, 0.051779622332223, 0.020530148965096282, 0.03286708717144305, 0.04358435845783642, 0.028108189205428766, 0.05281648403334041, 0.05373457146267738, 0.019662652067058993, 0.02254597335723379, 0.03482233507618789, 0.047718360419234926, 0.017294266351288366, 0.027851210756888314, 0.027520701274155613, 0.052445015659736055, 0.05566386047810797, 0.034790753101509427, 0.021007121052412737, 0.03142766733353417, 0.022681438769664497, 0.03190063469622645, 0.05463471711282769, 0.021953295180273634, 0.028721000173039017, 0.038427889587417725, 0.029963751834246422, 0.02665771471877252, 0.023374223570910194, 0.06762155451841893, 0.029427854179014123, 0.03478808328509331, 0.00666648323174506, 0.04690752529929723, 0.03363476089772678, 0.04474724545293758, 0.013321624531771147, 0.07237533693231883, 0.09825058476698977, 0.07904930340666926, 0.05733040814858772, 0.06042576342400524, 0.0433937672735943, 0.025740190364059903, 0.06400286926016693, 0.06283085432744796, 0.006825150095767552, 0.02535037801510865, 0.08062127752289658, 0.07936410425651459, 0.07486953535267422, 0.05741655856611268, 0.023519671108994274, 0.08385039941077271, 0.029254030744214694, 0.04441406615378876, 0.053078233294429324, 0.02540814295981921, 0.010236070393734883, 0.030010368284438888, 0.01536475708557954, 0.04643802831490194, 0.0036062607485350343, 0.029732406687652393, 0.06593835209646533, 0.04119332526780425, 0.023984644344196688, 0.05402999028803841, 0.06106683729036201, 0.029540718082458745, 0.03331342914832696, 0.024348921067411863, 0.024975023660508376, 0.015023877645181793, 0.07162490784521065, 0.021211641630338087, 0.020374951042955922, 0.019188541318139723, 0.06960778301882167, 0.015490599476071376, 0.04945970508420179, 0.04132001322784251, 0.028517372087545456, 0.018656652217971224, 0.039941127742490465, 0.03180220963493471, 0.03636398360193257, 0.013533782048691666, 0.03970075999536822, 0.012102056606372279, 0.07577968611111564, 0.005731012309796267, 0.009260662350683443, 0.007830794192775483, 0.04681652171477195, 0.09420334992389526, 0.07825388197576807, 0.042618313924439495, 0.05038528485343822, 0.045493212077886834, 0.08901049187707324, 0.015310146507897205, 0.029099765534122145, 0.08102641546077306, 0.034337596772539045, 0.07394871298944758, 0.06012873964444284, 0.01816695349501266, 0.02852502722112883, 0.029897025576041594, 0.11871541324522226, 0.03734060397912418, 0.03578194064058123, 0.07271518119640889, 0.04124775581482438, 0.04766368472407903, 0.031041518800080787, 0.01308189455284587, 0.04149607555460065, 0.02705379366694439, 0.018446805413752314, 0.10634839459652863, 0.1619474325449236, 0.14991899411524498, 0.1422670934229128, 0.08123702835291624, 0.18278090253231988, 0.17917051400628783, 0.09188607184877319, 0.11213447282751722, 0.11305104340276412, 0.2065751644512338, 0.19447488229601614, 0.14744417771937388, 0.2004217930258282, 0.1594970083885616, 0.18864420242607596, 0.18843342099458943, 0.14897430045229776, 0.1399870931861862, 0.15589397430660265, 0.11402446536287186, 0.08206918369978666, 0.1698719839295072, 0.1295912340884247, 0.07589853699168853, 0.11801032890235225, 0.15191908114619795, 0.17092555400825318, 0.14528094460406613, 0.18249697502582304, 0.13399858388208574, 0.16151146722897408, 0.14239001989124284, 0.22322683625163572, 0.11428770849541312, 0.13254762867525702, 0.1477077426088433, 0.16280499136736318, 0.16666608982749526, 0.10353377990184293, 0.1055300364931745, 0.17213987997703015, 0.1659962378682629, 0.13503516213067118, 0.15554900491429915, 0.17948169892113056, 0.08869716191604253, 0.14645760969048546, 0.16145561941929404, 0.08207916582544005, 0.1961837180199162, 0.1325817195878875, 0.12217509695478987, 0.199712380286186, 0.189059360794002, 0.23477397228200592, 0.10852295815223649, 0.07889922678230271, 0.11614534147684613, 0.09247948355492085, 0.14165152645399495, 0.1588139950387901, 0.20751230448724764, 0.138462133885872, 0.13447150527950258, 0.08944954452735764, 0.1763707997217294, 0.11985945830782575, 0.12982957936342687, 0.11108734554821446, 0.13958460591252775, 0.13041943642160586, 0.19682994382756372, 0.14541133276877866, 0.10280860873359828, 0.14391928460569153, 0.08365797344595195, 0.20015214539823994, 0.07261254073631379, 0.08796782322948979, 0.12718934160206588, 0.20992293803682252, 0.10597803705041448, 0.10307713021193782, 0.13748819098597573, 0.11004905892355789, 0.0940370552181717, 0.09196692476830176, 0.11574735113930319, 0.2855268222910743, 0.230335074987623, 0.1510141321247624, 0.15988045071642246, 0.11604941194696773, 0.17642926755211047, 0.1435489117378189, 0.1668165954610994, 0.14321760935408456, 0.13185540694863568, 0.17127902697651617, 0.16522734606217954, 0.17491727045947508, 0.22049804638710715, 0.17640050861143297, 0.26000380636222903, 0.18025083587534968, 0.13139622916858043, 0.09729622307443812, 0.1415758829323515, 0.08801885234612612, 0.2522110067788632, 0.14677043403348616, 0.14857417272944606, 0.1327253457519316, 0.14343298731311677, 0.16205048669249783, 0.12160356471975967, 0.11977702724717318, 0.1376078079544729, 0.15750836671119736, 0.28946693505971666, 0.15941712073981762, 0.14940320243758543, 0.2313521179941393, 0.14885330452553688, 0.20734623194702212, 0.13721978442082483, 0.0990180439886547, 0.08821214399030132, 0.2924054031891208, 0.06429666397912849, 0.17304297506568894, 0.12477140723457261, 0.20163075637913522, 0.16810794390978354, 0.1899872771314075, 0.1485550664966145, 0.10901297863212325, 0.18389623461952134, 0.1500056386594811, 0.19276282900283415, 0.11611739458936839, 0.07817463018000126, 0.15204271241541834, 0.1883492432534695, 0.11502286178931115, 0.11359642139605938, 0.11564356154732167, 0.11577673061119935, 0.15244757456164207, 0.24334959114991853, 0.1460998159863295, 0.13878651083477084, 0.2280638387967502, 0.1154923894172234, 0.2881423383951187, 0.13992790523315632, 0.1289796967419886, 0.21975851107028224, 0.1923939729890516, 0.23566444224167257, 0.11349217981220254, 0.13671433493014307, 0.14966610849144, 0.133024120042401, 0.2143403389040501, 0.15833892859518528, 0.21284013956544862, 0.2779374650168804, 0.12672417301444278, 0.22733381829194485, 0.18209549898822464, 0.13335068800276326, 0.11312931460598785, 0.12805345047625805, 0.10615080519909821], [0.07294460154709316, 0.04450855543836952, 0.05942509554687047, 0.06547766512319927, 0.04663724947961108, 0.044878878510527076, 0.044411871311885696, 0.04692216906996985, 0.041730958112185045, 0.04370401756116941, 0.025386744208874244, 0.07456342193989024, 0.042013207886127696, 0.025984231502779072, 0.07125147828652013, 0.04259960988776819, 0.010371953324084322, 0.011792555169743157, 0.02128438550918814, 0.026480650732053385, 0.026391028021011623, 0.033766137315861644, 0.02770661549162, 0.05060887527501872, 0.03301000470415719, 0.07761638957045733, 0.048453988687646006, 0.046459310237438455, 0.06991850062003059, 0.00922294305412159, 0.04523473784267422, 0.06572047669079996, 0.04957284477929916, 0.09284697593219819, 0.059182057983332106, 0.047907622440928416, 0.032799705908062964, 0.05281128995721379, 0.048484375565162594, 0.07087372033105743, 0.027519354874628688, 0.015911348370624887, 0.024277701703531128, 0.03629819580143498, 0.07778020215130622, 0.06822549993352545, 0.05859507758530879, 0.04704940095243435, 0.0682484902321331, 0.04580014137431018, 0.04451191856435711, 0.051268139899137526, 0.02705005132743428, 0.004760180205677546, 0.018597477671479987, 0.03213329751405024, 0.01540608561387466, 0.054076020680968805, 0.04009096687960048, 0.05083381401134595, 0.07435474725019547, 0.04904340141482892, 0.01961143717410103, 0.029279798111547867, 0.036345402139329144, 0.017208225101292614, 0.03416907275095582, 0.02412674024761204, 0.02694614873748393, 0.02817131101994986, 0.028144923121398015, 0.08144641550438059, 0.027596283508765123, 0.043121553251459714, 0.04853263527395264, 0.017111064085075935, 0.04868235183699478, 0.04810325831415192, 0.03031434048147452, 0.009060730639424537, 0.05741113466360877, 0.08068179846891473, 0.08918192703276874, 0.09080686080720156, 0.023762819755281654, 0.05006328277710465, 0.11245311943874245, 0.01337060819364964, 0.04288323861997455, 0.016079875265037822, 0.06948605164765351, 0.028582292293468793, 0.04319201035785579, 0.030694796981650497, 0.030107611655107433, 0.022147548264793815, 0.026830973163727793, 0.03259264000300919, 0.023070548232945225, 0.0058797827542519145, 0.06534900065631637, 0.05612812891242005, 0.02061172392249348, 0.07145849822629845, 0.02452424411932307, 0.023510845776106563, 0.08291014905778632, 0.046566792373215, 0.040659189614797794, 0.06845967002934025, 0.04817210663590701, 0.07543403490055954, 0.0506962820767395, 0.02607578667060983, 0.0519243210193611, 0.045223349945679794, 0.045108996001222444, 0.01645483316913728, 0.0973852041868433, 0.04544359256303118, 0.020249061729578723, 0.0904157576000979, 0.020477595333490643, 0.0814376131541306, 0.041617684351700934, 0.03490681542203792, 0.009413711396196197, 0.05135098464726921, 0.02487138154045228, 0.026077202018049937, 0.020502347634324146, 0.0489214823521193, 0.08047743685423367, 0.06035047613324658, 0.036838969606305325, 0.05108430177994794, 0.08052888731922835, 0.041485844450371887, 0.024353814454028205, 0.08373493463882516, 0.07241132774300153, 0.09357498928664193, 0.07316183343890213, 0.054347824846063895, 0.04438987309713999, 0.040212579507140384, 0.02002933813679603, 0.017749345560948697, 0.05737907388397763, 0.06352932350109182, 0.02207365716927715, 0.05538907240054781, 0.0967818180159215, 0.042030084803099596, 0.034311308465417356, 0.07006702974679009, 0.06737140382850362, 0.0413977213564419, 0.1023497986757467, 0.033636377343247016, 0.0404966295877051, 0.013930981400452796, 0.015183650069840014, 0.012977466235057482, 0.033365274148602644, 0.0265343094454898, 0.014174947845599344, 0.020804216920007623, 0.029025694407943278, 0.03726765325653457, 0.0673110667435873, 0.048407992768672206, 0.05178367493734245, 0.029642824196226658, 0.020459155597153212, 0.07659635116015712, 0.06060662912204862, 0.07389601380113633, 0.012418586899706674, 0.027852055368824836, 0.04901196882729569, 0.018937549846727523, 0.043637800751434225, 0.0614029468758212, 0.09406978249429696, 0.012271169558047287, 0.026257847465815085, 0.008732315449554835, 0.051858598336337075, 0.0036108184928795506, 0.07941532489513198, 0.03932816547251517, 0.05714360909957079, 0.04589819296773884, 0.013638772483494495, 0.023268719857198097, 0.031543461523289164, 0.04087700373342922, 0.06773835994423398, 0.026120210194119045, 0.03597722028291995, 0.07994174221230131, 0.03310074781878822, 0.011064326353070718, 0.03911071141520816, 0.03043403788920372, 0.05050954048431689, 0.03392073385898144, 0.06369628087286988, 0.06731033129917999, 0.03830520826722345, 0.06854942489054895, 0.025252088934423465, 0.03777699064343207, 0.013132897814014747, 0.03492951843767397, 0.032574793984813076, 0.012168025395141975, 0.041054219022513404, 0.11745756582146692, 0.04985563847566805, 0.031732277298766765, 0.11041987612242661, 0.02820309026226882, 0.02704606192456859, 0.031797304756999496, 0.03485114764302008, 0.07285545189534465, 0.02201659702545693, 0.02267776346284776, 0.02245255659574703, 0.03012524508390456, 0.058484320423655936, 0.06758223888614485, 0.00520678744050524, 0.043122756009500836, 0.04047470798175182, 0.01999281489500596, 0.005961994522236168, 0.05606782630146031, 0.04798516969106371, 0.016794824905152765, 0.05519103484168168, 0.008294503861707787, 0.03311190588940536, 0.027638870336475874, 0.07012417224506218, 0.026561224029489586, 0.03328656627526207, 0.06912483353047602, 0.06324795089782247, 0.0077988363562091715, 0.04925209142628217, 0.004086882766005734, 0.03661871166719544, 0.02237471057132127, 0.049801736529315674, 0.10823230439376448, 0.04100399429819757, 0.10930430654796863, 0.010854980378832308, 0.07000205016905262, 0.043391522635976155, 0.03323249962000597, 0.046025409528444854, 0.046446236947010604, 0.048665279567602186, 0.01206163589226743, 0.04155331764430289, 0.020155759881280606, 0.06627048951603713, 0.029260680387397448, 0.08337367821725146, 0.05268556726796012, 0.006321217459175857, 0.018108583340841918, 0.05285733950234229, 0.03216776380976362, 0.025030678032987544, 0.06917688920493088, 0.02542790228260621, 0.01096022362265015, 0.037157604726211685, 0.03766698807838463, 0.04076096822597808, 0.019663557966029453, 0.0320452893333089, 0.09840558733670943, 0.05124817181739116, 0.035746903609364264, 0.04096417304789347, 0.023916895358612942, 0.031307142550846746, 0.018097023074064526, 0.03789953023736035, 0.03490067139688519, 0.0344953534283465, 0.06361828546129888, 0.022633113943400885, 0.028434864418100447, 0.026263010898424734, 0.04492558689127046, 0.009541808958015135, 0.00820854209333418, 0.04408366009292584, 0.016689539526499087, 0.05794486429001536, 0.039759901983122674, 0.0745572242885828, 0.008792290557926942, 0.031463424487399964, 0.01787633421049724, 0.022987460251897577, 0.027639508104672837, 0.035495481213494655, 0.09485945826576603, 0.07397377938633004, 0.023719043576068456, 0.13060686749316033, 0.06297336966400185, 0.04315460228451318, 0.04198322320477136, 0.03635937558306802, 0.003356487835727392, 0.004693058454581807, 0.0858818807248627, 0.01606967480432603, 0.02880956185230565, 0.020727711549449353, 0.010319890946360126, 0.0733883886207496, 0.017839571566230828, 0.032961806282401085, 0.03928965423256159, 0.08022250577567086, 0.03656728035439888, 0.02532210554026308, 0.03378192638798106, 0.035098283776953336, 0.03844892636181847, 0.020376328085999817, 0.01856563331168746, 0.08494908440737955, 0.03381239753516932, 0.006417156565153311, 0.04366582807814402, 0.08874310420886164, 0.0184089683311721, 0.011327607790008189, 0.05073984949699333, 0.054103760724707003, 0.11813600562633046, 0.28709239957313387, 0.23814319632947448, 0.10212436198226868, 0.16092761630012145, 0.1413686867923506, 0.14538231335820692, 0.0934670628198693, 0.16661656990406976, 0.16811134534016733, 0.08476661758557444, 0.16606589058233848, 0.15169028132673235, 0.19541571487582501, 0.09391704754483315, 0.17218057456756794, 0.14478036743258277, 0.09254082421501798, 0.12696536813652323, 0.1798298092739236, 0.09545890674475702, 0.060211572901255665, 0.14248912102512776, 0.13289607610673676, 0.10829085649381723, 0.09789566389254986, 0.15247187487060024, 0.10963547869675583, 0.14723266084348002, 0.21470332668433267, 0.15879029227841288, 0.1428981353679011, 0.14030103601755636, 0.19564423890363788, 0.16973341394576336, 0.1203639884929984, 0.12692959949133858, 0.1464896474874789, 0.1042948729328571, 0.15373049604315914, 0.2177935108662613, 0.15438378518146856, 0.0641395814806944, 0.11567995838460424, 0.17092216789962786, 0.2333608924621536, 0.1227134882262157, 0.25861038435851375, 0.17342010482905373, 0.11985439446664627, 0.10941358132948799, 0.1415179666852759, 0.13231472262451727, 0.13980891645675705, 0.09429437649105826, 0.09204769341815865, 0.11388159762587279, 0.14969710440885636, 0.2142859313396677, 0.18673642898999876, 0.2095600115435739, 0.16710652909692258, 0.1697906407137071, 0.13759768027211391, 0.15249603728373207, 0.18957443234901275, 0.039937435198695435, 0.09390978503131098, 0.12589926485933606, 0.14665778846509997, 0.17077343959000804, 0.1449648720482665, 0.16694787228780408, 0.17457098339594182, 0.19180074514400577, 0.18993430981232276, 0.11247993251609226, 0.16527894974475907, 0.12934608595265498, 0.09095074744113991, 0.09411944797442806, 0.23095606585904477, 0.16724477732373824, 0.2667618356645107, 0.19789931063930835, 0.11000965902161215, 0.21203337237238887, 0.2812476390071454, 0.11459563753657764, 0.15709261079469036, 0.2371207140986958, 0.2685178317610295, 0.07505580197058379, 0.11788237689723892, 0.17925502882609445, 0.1626995317037067, 0.10558770759211433, 0.1808553711781579, 0.15166631809646083, 0.10888891069278603, 0.061457028852835785, 0.20411010801551804, 0.1479960981035425, 0.09553071982677906, 0.24730706347092507, 0.10850392086731811, 0.11031459265899275, 0.2346708108821223, 0.16116622204501785, 0.1065048833768214, 0.13842609710991383, 0.16401921008383075, 0.1657041898297687, 0.13496606099990108, 0.1700055283764678, 0.16481558912463729, 0.14763903984379384, 0.11327748367142294, 0.08513479944198363, 0.15483934702652116, 0.27128794440819376, 0.16004313714802265, 0.170680329263691, 0.08080564424275391, 0.18865860487905242, 0.14669387120633356, 0.13064664277818896, 0.11677530323786121, 0.15615787627475877, 0.09944592707700307, 0.06907729777477442, 0.12522355232748295, 0.16352030298402234, 0.168210186004158, 0.11093480212073173, 0.17217888917413451, 0.18442976889350723, 0.12146858768838069, 0.09726286760621494, 0.09655677968816412, 0.22359838889491176, 0.19626374356448653, 0.18844071415162858, 0.2829520927081185, 0.1820537931616268, 0.10243236763222564, 0.19849333521579543, 0.19097761431288338, 0.19807598583640593, 0.17570480884563539, 0.2077042248340384, 0.1164762914601353, 0.21742059458648005, 0.21210535399375424, 0.06942235143674959, 0.1286676231651537, 0.14112300239503384, 0.16202375022394044, 0.11001737352700965, 0.2209457328482982, 0.15015465808251213, 0.16936166211962703, 0.06475742756118698, 0.10895061907508682, 0.13599877816534814, 0.12945031987563257, 0.16185432221860657, 0.16320597710869006, 0.10619366015758246, 0.121657497309629, 0.11155056827250989, 0.3023523500850124, 0.15596986297638188, 0.17778253122683496, 0.11938560994402056, 0.15467446958345754, 0.15280300871499125], [0.03305262983626416, 0.039362482381083315, 0.05161012537897595, 0.01660394260749942, 0.029790171632362954, 0.02547711577086199, 0.04359180866290004, 0.02977939660570795, 0.06691912850064617, 0.09472745365553326, 0.03619599201145672, 0.017651880024782112, 0.05077231630322434, 0.07586452268785046, 0.06587236128266781, 0.05693973012028202, 0.05095605100054414, 0.04514450417651285, 0.013224972964024112, 0.025128785167790713, 0.026766709878199527, 0.018301744750069997, 0.05151846295883579, 0.0059829120742036935, 0.005509559273524511, 0.02997773102364473, 0.027566350538343675, 0.10743955660971904, 0.02528255816639191, 0.06584208548790024, 0.026762358498789614, 0.04099471314299492, 0.029956113937641346, 0.027316293694199096, 0.07251603664049218, 0.0562657680993359, 0.01846094356639491, 0.06416800717312483, 0.10267917817879109, 0.03505628300650466, 0.058960961177945144, 0.05948852379656127, 0.04678187921883599, 0.05274405042009969, 0.020591445575137774, 0.012869695858699421, 0.035170135163371606, 0.02614671683629915, 0.04221486521043605, 0.03728499748714028, 0.03766570488111146, 0.013216916591890398, 0.03851006783905529, 0.0262216440657334, 0.0603754276169404, 0.04822443044113536, 0.014440544783287953, 0.04754531264845883, 0.026903525520596775, 0.029227422595384623, 0.040862536162979184, 0.051387676428402626, 0.054324639195035544, 0.05219107666503518, 0.03604882269076282, 0.05513800623556299, 0.024254142584639694, 0.05296133210762374, 0.004188976430844877, 0.0685653978237702, 0.044368422635260134, 0.03647246931288992, 0.004372950051836069, 0.06111470629431068, 0.12161604429204619, 0.016666058931619893, 0.06258683617136652, 0.031414245473100774, 0.016842251493325158, 0.03579867200084752, 0.05773291840488392, 0.03530627664839549, 0.028586808381782427, 0.03200886185250936, 0.02859013128815399, 0.015870646119207864, 0.011443710330152705, 0.031528905852727836, 0.026262501449955088, 0.020681750104432146, 0.07491744649145873, 0.055369380110454176, 0.05833268481036348, 0.01720293909461508, 0.01986275040244143, 0.03904761641376442, 0.06321797004690574, 0.057404343294160026, 0.06230339513070161, 0.040959580350787415, 0.11148188082921891, 0.02361404931082601, 0.03212020890186391, 0.00991479610092938, 0.05607445296200533, 0.062005881054867665, 0.027602969541124282, 0.05018718983797778, 0.02390372247675494, 0.02349663101467154, 0.04441922192551917, 0.036985257925886306, 0.03998459940175376, 0.056549174666044213, 0.06736918983440246, 0.023328587713260806, 0.018965439277610952, 0.040934376058078585, 0.013600695998437945, 0.02892138579139306, 0.01783558407858495, 0.02516060271450589, 0.009235077886842191, 0.08459645413583325, 0.034536147610314434, 0.029953210464408322, 0.01921713171947387, 0.022302315262476766, 0.023543592204429933, 0.05768572355830862, 0.06657870200973365, 0.07716267399730221, 0.04441032381427865, 0.04267614207140381, 0.02700686695114259, 0.03243863334759109, 0.025846121171789787, 0.044751891776198344, 0.0321029719235676, 0.026428815307876757, 0.06370012663424977, 0.06555143172942823, 0.12059726992682104, 0.06917031617054055, 0.013330431670070657, 0.013514601122287494, 0.025983708647770748, 0.014987325675094561, 0.031325028788658886, 0.06163789072043954, 0.007293353827985665, 0.02026513808466975, 0.015815540457204465, 0.10563885928281855, 0.00251151631668871, 0.04922245531493137, 0.09060334188923722, 0.07079323513373252, 0.020800480326156945, 0.03996504883792612, 0.04160744558659293, 0.01372127632249988, 0.05014522737192531, 0.07275204534732527, 0.027932613344502547, 0.047413560847241076, 0.031433826680445386, 0.016226410647974383, 0.030018544357810772, 0.09760817407720512, 0.04658351224216242, 0.11969870241779475, 0.035107151244676886, 0.054385765350513884, 0.08948264718656579, 0.01411512020915266, 0.017092932699128024, 0.06062397718309395, 0.02005596735304402, 0.037871162001524246, 0.052323192358016975, 0.022242242477894313, 0.079697176303354, 0.05152040116128422, 0.06278426085989322, 0.018233179880846894, 0.026686268730930267, 0.04615838707034146, 0.04058944113973168, 0.08526088219256171, 0.043822278554040583, 0.08618631640509253, 0.027268175711675037, 0.004791172771459265, 0.02527111855846259, 0.019733689485057708, 0.03397407273070947, 0.016939010313381592, 0.03026678748879462, 0.01642427009139811, 0.01818807262386526, 0.038432639332548264, 0.10846387745151598, 0.04265338159917344, 0.032267362900799325, 0.04117354870803895, 0.03731310142264251, 0.00946975168546722, 0.020997112113682014, 0.06992106701457693, 0.008235355170683996, 0.03388923615397465, 0.044719968892393575, 0.0325701629833108, 0.04815179381459471, 0.02988098752534678, 0.056644564103936, 0.05385053419177571, 0.10210163215355528, 0.003433220638638182, 0.0034595467713511283, 0.02408442921155403, 0.08149310856336549, 0.08678048653828521, 0.04395822851708339, 0.04495789664947698, 0.028448215415400845, 0.07418309758988119, 0.013276819879519603, 0.04078960459258768, 0.007963656342678494, 0.07188959888392879, 0.04398327576176774, 0.0156712228988087, 0.08089172188192606, 0.05561246746970762, 0.027451678667397752, 0.04549200548940609, 0.032759321583134514, 0.04716933584742008, 0.009741297295887866, 0.01725843833428958, 0.04855841030216506, 0.03605387121018383, 0.0706373285802622, 0.052373014886172554, 0.016726710112585176, 0.039107800281095895, 0.029644166765313958, 0.04345127366363041, 0.06877798722275803, 0.02547015394685009, 0.038474375802663066, 0.019920302757753, 0.0376320276559601, 0.017589294471808018, 0.09349672574429743, 0.0669979895915716, 0.07306054895443302, 0.020861064474428856, 0.015212189717849177, 0.010229749210749664, 0.07652238537106784, 0.04608319171013371, 0.02979942788970807, 0.07163359528227199, 0.06125813327549447, 0.035448140810213746, 0.037748170415720636, 0.02785354540983756, 0.019833508826371644, 0.019642913811689904, 0.05360503365556079, 0.014811934632880074, 0.059021202501870935, 0.06543624274913343, 0.044243274511949676, 0.014440171315424867, 0.048145550198011824, 0.009661932502152219, 0.027791645505555698, 0.008783139637671411, 0.00862684237935971, 0.024796760746187745, 0.024534385208220735, 0.034893228852700804, 0.08223524857913295, 0.01210819009781605, 0.06266537167492413, 0.028620788211663886, 0.01777394081375772, 0.008384096886842482, 0.01489463190908634, 0.09019869424763227, 0.032541848373629396, 0.040485659208629406, 0.0063060168383432735, 0.024949754250325987, 0.020086926881284006, 0.1132862477172767, 0.013771583401267568, 0.007122092478488002, 0.07559138169932751, 0.04350480405733951, 0.0032447247048689714, 0.02312374154796764, 0.01770751141462355, 0.04638323387611778, 0.028017166468705383, 0.08299945192711969, 0.013927240976162497, 0.027292740320967093, 0.021144505515093767, 0.06599660542222761, 0.01677673565404069, 0.059172022231524034, 0.06382826633090455, 0.07438173652776787, 0.060356386501582406, 0.09397706287282129, 0.02893993661047951, 0.03545100214861093, 0.0176655508637909, 0.06901547447928498, 0.061450425174928484, 0.07901885141167911, 0.04940924287262944, 0.018756019567409833, 0.05261436705627749, 0.100098948084539, 0.02624600374650571, 0.02039187392520328, 0.04778977130509673, 0.041953188727699944, 0.0262026010351556, 0.03548794673875936, 0.04953214635832175, 0.013003977665287113, 0.019868549688028234, 0.02287844019461303, 0.06074950451992693, 0.04145756048420745, 0.0023755852664415276, 0.04905265958739385, 0.06031734666096107, 0.034686017390941425, 0.01795688835573533, 0.03937545224964138, 0.029935383598410317, 0.03967493900188035, 0.02825552323502639, 0.05022553253858801, 0.09654208612177642, 0.18290361449603112, 0.10694348403523046, 0.15467453087049146, 0.14762213994418422, 0.1296601360363345, 0.18996107692439712, 0.11247827776617582, 0.22338013044528424, 0.19528278329920387, 0.1553382388045711, 0.12175030886165558, 0.1808628941615743, 0.13452153082095808, 0.19611849329404293, 0.17409806199852498, 0.1485189837553809, 0.10589235011608371, 0.19690059245594088, 0.11433467734605075, 0.1699087255063557, 0.17011820458837096, 0.18312570338528003, 0.07178179499122404, 0.09953639439998135, 0.13615194978492876, 0.12856153530939934, 0.19872935158350777, 0.12855329220333409, 0.21788418503297916, 0.10693348658781861, 0.1586440614154262, 0.09669031647424545, 0.1104472944092366, 0.17847144345362342, 0.10690018474575012, 0.124395135489683, 0.2739382715475175, 0.19724044438091018, 0.06773506576615958, 0.21632272930395222, 0.14181130175148288, 0.2996939637007252, 0.19110185845244318, 0.21998718831567998, 0.18921492260790643, 0.136149023329058, 0.12673658363881612, 0.14854461705732733, 0.20840312684735945, 0.10194964797025728, 0.13173672460740612, 0.14672028591796277, 0.1456062561802326, 0.21550735128262352, 0.19284254811223478, 0.14015074488857102, 0.11131769286528712, 0.14387175651086917, 0.12883400214054894, 0.1652447515798192, 0.10833831564072641, 0.12845154040523116, 0.19723013283744936, 0.10639835119007096, 0.12311695609241725, 0.17467612130267007, 0.23498818578739322, 0.11896944800091368, 0.10096779138210321, 0.17326206089027468, 0.1812235223910501, 0.08131636441835473, 0.1889937989894421, 0.20097034262313, 0.1668631123198617, 0.17723365987260498, 0.14810189484588562, 0.1573554402397525, 0.0859765921749415, 0.1927035644410118, 0.13832543315666337, 0.1829061885514567, 0.11186148505657913, 0.11827275232081452, 0.09278996366887324, 0.13153535073562977, 0.21704063029779544, 0.12222347540720818, 0.16535123780129418, 0.1368660203391506, 0.15722197240158436, 0.1054517882725885, 0.15081573067413223, 0.15103293192242423, 0.11843016806749568, 0.1091151287959468, 0.10142625670038885, 0.14396186377252304, 0.17553921127992292, 0.18088838956769437, 0.13160681141720665, 0.08929657209063731, 0.13689568326357873, 0.1472868998685191, 0.22218566147550461, 0.13161583593295467, 0.09564426937891592, 0.16919968048891715, 0.1622713498410679, 0.12035125611169685, 0.15040110856775316, 0.1219601020397198, 0.14191925886177248, 0.23416248090084524, 0.07566298793761, 0.12684506168889423, 0.14794890708740682, 0.2088139644793926, 0.16364735100538502, 0.07724924959362515, 0.11475750425409888, 0.0671704130006894, 0.20295368297205818, 0.15219228342175484, 0.12205910358217456, 0.1639151447001965, 0.14880317173177196, 0.11770569403926212, 0.12483853185849807, 0.1134553769483201, 0.13354245513196916, 0.22977881854580295, 0.12042567389266146, 0.10340172932633471, 0.09593569688619145, 0.12040751760885601, 0.169851437451378, 0.15987654366800863, 0.140000086037382, 0.10373985755347437, 0.18853399301728896, 0.1461852347898868, 0.11314702655879721, 0.13645561171635506, 0.18186556535863108, 0.1492566191741536, 0.13488891594592603, 0.21933555392728699, 0.3525734584658377, 0.13748184777796268, 0.12284661898569715, 0.10358058021313722, 0.19310588317532695, 0.11614334198736376, 0.11377061446828228, 0.1387817457678818, 0.15595175265785188, 0.10919886220607067, 0.1258999543384679, 0.10549491136184624, 0.09818921346337565, 0.25243315695514607, 0.1943229057735974, 0.09330258374252627, 0.12803125690909165, 0.1310415151378801, 0.15736863227380862, 0.09223353868770985, 0.09160729245312753, 0.07076834493707265, 0.22456631034372315, 0.1436314040855054, 0.1693190829527955, 0.12506634342454134, 0.1531228963886538], [0.031776379065347776, 0.038556810693755265, 0.0036584907079926666, 0.06857922571080347, 0.02241243082549303, 0.010522548015409661, 0.04772812037939026, 0.08410762109222912, 0.02562356879934669, 0.10009109568331512, 0.04287154045737079, 0.06199245536399465, 0.06822753772740403, 0.056959073840370106, 0.0699298310604307, 0.03533125877560627, 0.06932676664643711, 0.013940985551133994, 0.05305364570249954, 0.03621755738652522, 0.06848419250379648, 0.014319915621120845, 0.03786488774142439, 0.018786017655304844, 0.05077805813221682, 0.07014143986687546, 0.011833904765456194, 0.05300327925191772, 0.026621986293203892, 0.037905053731294415, 0.05595734110102058, 0.021671631463593053, 0.022511687092182618, 0.04515718676209931, 0.050450536392388806, 0.03936621705971418, 0.02540845131020873, 0.01843207737340802, 0.019348927570747274, 0.03439769637019884, 0.02315070018202307, 0.0660081810107635, 0.0443316925497305, 0.018796679683991017, 0.05980550033611156, 0.03157515266549683, 0.06918906234204769, 0.13119488594032105, 0.03945548928553059, 0.05303870315753645, 0.013987570400199583, 0.013103368954973356, 0.03304700292046032, 0.03634439856414834, 0.0074341536063941265, 0.05946984657296731, 0.029645020953349532, 0.021097517512258024, 0.01846083822930532, 0.057989929412161155, 0.02997057384721214, 0.07323569197568201, 0.03756263924221839, 0.026178697176698237, 0.005163795064999572, 0.045311882896649266, 0.06211881390622547, 0.05485101054692942, 0.04131506046941204, 0.00985433548433526, 0.021219294848701647, 0.06028607878233157, 0.01628038728789937, 0.04230841986774918, 0.018754799572390415, 0.04111806095968332, 0.051881933374510664, 0.02170849561450943, 0.011084469677429768, 0.07658525820701353, 0.04217885524755524, 0.049153177983938694, 0.05969543648403018, 0.04156244175148107, 0.006292811397748489, 0.017313405142856703, 0.015282242712865194, 0.03780902077954623, 0.06413175589254787, 0.01734182892006732, 0.0449626961903226, 0.046254527274399035, 0.09121347729477192, 0.06414726534257494, 0.029855618523734233, 0.04876741824010688, 0.05247888057642887, 0.028067096249170365, 0.07338345501451723, 0.011576867902711516, 0.037057063347029115, 0.04872997952324729, 0.01738495392454488, 0.06577304564416409, 0.030071350798431425, 0.08042152009664044, 0.019313319804026716, 0.0257513216215997, 0.029942404794236346, 0.05306185050416858, 0.05598560974542653, 0.03715378960834877, 0.04138601170251927, 0.03640233013298243, 0.08350839477873619, 0.01005318509640112, 0.08750149784910102, 0.048404572186090296, 0.025998859951693206, 0.020460279831182093, 0.043669294626001394, 0.030726786898148638, 0.04816926061926831, 0.06745453969004654, 0.0595440651710716, 0.036445621761583516, 0.14623392733835405, 0.05026397866106803, 0.10608648445697562, 0.0468610046100953, 0.023556322670511665, 0.019815233798937935, 0.01884166819734439, 0.06502646997931504, 0.04737436395859526, 0.0898472514123686, 0.033830956015135014, 0.034707226535125126, 0.07846463276373764, 0.05597311485138151, 0.041237206784107035, 0.050700687082304116, 0.007410654338121775, 0.027230175835410916, 0.033588561965453054, 0.03803431191631863, 0.039221215767846, 0.08088927040056837, 0.03615719731897116, 0.0631952670312697, 0.030347328227494034, 0.0350077513365015, 0.04524304989665266, 0.06683446812413393, 0.054612090705984065, 0.019176146015524864, 0.03585569192505172, 0.03784749754554322, 0.07160784706713692, 0.015270058084429513, 0.09915314359410156, 0.05801104662579395, 0.02493550693015418, 0.07036754305684759, 0.03598180914958639, 0.02740346875432278, 0.05034517632016251, 0.028635612012998714, 0.05096113782436137, 0.07604741851889318, 0.03296582058312432, 0.06454578811122526, 0.05005340790376068, 0.07394708122216886, 0.045538702378830606, 0.034514915483493, 0.018550108539901914, 0.06231171867599892, 0.02467659985526435, 0.042827452097328446, 0.05773993577027033, 0.09634627404833034, 0.061682323820047805, 0.06797063014199657, 0.022629846578403827, 0.05370473233802665, 0.014968331482621932, 0.03656222417409863, 0.07229614642358596, 0.028909404176257314, 0.08149674748100581, 0.04792299016468948, 0.0438003224741307, 0.03905108679206141, 0.019320260560620698, 0.017863670777108882, 0.03245540301225359, 0.06469424062919232, 0.0055630997221376155, 0.028332821506586288, 0.05989421714818286, 0.0546913999583452, 0.04847753056955915, 0.01619327926046906, 0.002662829694248015, 0.031506455646106796, 0.09303250710570043, 0.026944112858825156, 0.021772824017511263, 0.09922347046555051, 0.03826542915175519, 0.04041005016094254, 0.013821923996381944, 0.0371224566122457, 0.02092280350024662, 0.04404992541118015, 0.03738774519954478, 0.055261963092151194, 0.04082104867143978, 0.03900717846268127, 0.0625643897951851, 0.09632673114538194, 0.03389060745135911, 0.10717265923777897, 0.05067150296282865, 0.03579812041754204, 0.016066305932679003, 0.06520499910918937, 0.04826951088503965, 0.041038832146554224, 0.054094989017973986, 0.04911099335238819, 0.04561662884248842, 0.026696656883183508, 0.03056533769854615, 0.05439408506537157, 0.04542470466525805, 0.05823054230741917, 0.019547367325773644, 0.021171864430089633, 0.00463532415338822, 0.03410099817800426, 0.01005927358017934, 0.08720863009652785, 0.01113991050290004, 0.05612077446834696, 0.06171910753173213, 0.01684214807145538, 0.04667381102579736, 0.01682172225217425, 0.03246139381982146, 0.057874230983396696, 0.00745781806237515, 0.14195284415637294, 0.031194496982460542, 0.10180923171461591, 0.05545769089592561, 0.08965881676563332, 0.09566393485593219, 0.046679989524906686, 0.0349941149714493, 0.037868028701913935, 0.02541224727587354, 0.055756331121008244, 0.07907553425719661, 0.01812025277514852, 0.021302511149476615, 0.009755214240642325, 0.035813714137240764, 0.026937802209548896, 0.020131559163752585, 0.011024760784611348, 0.07446745410561562, 0.10189217605417776, 0.08264482216609102, 0.02919723681594816, 0.050054545544328234, 0.048761569158804995, 0.05258873375433107, 0.09707761988524469, 0.06106797493092957, 0.04843023613155369, 0.04587039546740632, 0.037684316987231854, 0.00928262704908247, 0.010732940657274618, 0.028505300457078605, 0.03819642761241525, 0.04643570323805175, 0.024138220075157382, 0.10847150768724181, 0.05525800241758266, 0.08450921970389544, 0.009272326996940519, 0.06812010921778218, 0.03344347257347357, 0.04788627157047872, 0.04866021572642269, 0.05122259597203905, 0.052725951592888565, 0.05028831727442242, 0.03898634087114085, 0.07853201785755735, 0.032392556989385236, 0.06520207265331861, 0.09711847535424656, 0.01668872938851916, 0.041827512003721735, 0.04933812693061848, 0.05117527089051662, 0.014094279744782516, 0.023235843193927602, 0.04495774343189213, 0.015817672096853776, 0.08800106378452432, 0.04346210614687974, 0.03009083816000531, 0.04544849169530696, 0.009193637318188145, 0.03209820111101914, 0.035538926059680606, 0.029559943058918563, 0.006016206734197876, 0.05327835461244949, 0.06166823546312029, 0.06926381720169898, 0.07667801613288541, 0.038558250939052914, 0.01420694350775692, 0.08204997787552495, 0.02319129135069107, 0.06935830648627973, 0.0740629366989578, 0.03962608557494898, 0.06537841843260873, 0.0299090895456292, 0.09392322221350285, 0.0738713993961292, 0.04341128004354335, 0.028189231731718587, 0.02687037306567354, 0.031001655414940852, 0.03612761483377507, 0.04697396810497007, 0.05888813685986304, 0.05723874572844756, 0.019201214327627135, 0.03545487472306817, 0.004228027283980121, 0.04490390660301332, 0.041436052565733274, 0.04721982104163017, 0.1360709896130908, 0.14945975504815578, 0.12215744628901444, 0.3363004639264076, 0.1424685439034816, 0.29969402498775916, 0.22912231183821158, 0.1477427834704999, 0.08041486279257844, 0.1674814984923409, 0.1482264913858906, 0.10196902233386233, 0.21726471101564748, 0.2382995548748201, 0.20554865259797345, 0.14940101142612197, 0.19036672048030362, 0.1512960678026561, 0.2723121426759228, 0.0967920529505899, 0.22456569747338373, 0.11418093882140615, 0.1397764190070091, 0.10115036545621772, 0.13659926852391613, 0.1467655004272538, 0.1324545949577324, 0.16243610471006364, 0.22073996163183646, 0.14659676190105178, 0.2416310567528971, 0.1060552127479065, 0.12027205794208473, 0.14886741586510213, 0.13855789487640705, 0.1173173027834104, 0.10004289343111938, 0.10057355487538923, 0.1391410869696448, 0.12261258678570872, 0.13154892581364802, 0.1668914575730601, 0.16053649777125928, 0.08920568341930067, 0.13973984596950395, 0.178420253458523, 0.16858685611476823, 0.2570683106539711, 0.10237434413284065, 0.2009342292383794, 0.16365062986170092, 0.12917075907030415, 0.11236423791776742, 0.1618819779926731, 0.08889755519527583, 0.26794636081303325, 0.22862691342109637, 0.13116163772440728, 0.102590105135835, 0.15209411691513755, 0.07273804892094866, 0.34051020900087975, 0.10112062592299716, 0.16004500640255792, 0.14185383495303894, 0.11243656427869875, 0.1453658271460764, 0.3143934136436832, 0.07727518933074129, 0.19062838547172087, 0.14235432019397137, 0.0989683785085236, 0.12638394570639058, 0.10353734221069083, 0.08704706215329709, 0.17003082459972751, 0.08984486121804484, 0.18831214927617582, 0.12324814864945029, 0.15993104316294193, 0.1273028298671688, 0.128840314705045, 0.18522809379764144, 0.3187341597532073, 0.15271253373113372, 0.14821964255984754, 0.11364689892939023, 0.16099317810468136, 0.17305583002105837, 0.08536353797441529, 0.1089492554385816, 0.15979164580423988, 0.14950020449055781, 0.1463154390934975, 0.13083670919220294, 0.1164145830778345, 0.20884362740382073, 0.13182723023478063, 0.24528736458911052, 0.12071217545458388, 0.06491207006958223, 0.11855975950076697, 0.10279226041729413, 0.1939071192135734, 0.18376641335987276, 0.14754490295965828, 0.16866338829840385, 0.11077305797727839, 0.10457934436178017, 0.20332232448122195, 0.11627595946793595, 0.09756338857715169, 0.15595181394488583, 0.0774397756603937, 0.13346077483748237, 0.10356627735159091, 0.18160820578134831, 0.1593222024459993, 0.14333066860994986, 0.1002085522838658, 0.22084342946688976, 0.14894852925452495, 0.06935263743564006, 0.16824226976642687, 0.12371920079233185, 0.09414530344187252, 0.18609346671690866, 0.11149399267930178, 0.2940598466703969, 0.17782501846311555, 0.14378595466334976, 0.1693579542540735, 0.17574412447790946, 0.195102155088417, 0.1010634144768119, 0.24233406499749233, 0.11278642131195915, 0.17204575841465305, 0.1909070882585741, 0.12252248718493408, 0.18017945180256523, 0.15138822817994704, 0.14915244653820992, 0.1258767955005169, 0.19938576636054825, 0.15852197764381287, 0.11994074789747117, 0.2003073241681822, 0.1508913741957757, 0.14149524451744172, 0.21458424597738252, 0.14048748649656773, 0.15493317747548704, 0.20123687993374564, 0.16226928140367233, 0.1379041154418261, 0.24166943775790356, 0.1864021695068767, 0.17584659639866124, 0.07279387374799098, 0.2669628877793589, 0.1647518965746126, 0.1327538901879903, 0.2138086125975655, 0.1713590831646035, 0.16572896511323992, 0.11533335722502201, 0.11650313518100208, 0.18843095419147324, 0.15241546015585625, 0.13935124020903342, 0.13731844122371367, 0.07212325570083435, 0.20859091031935909, 0.2112167992538983, 0.10744121902051473], [0.0771327659247383, 0.06446492753081745, 0.028412494650711457, 0.07160687413547309, 0.045331766708723964, 0.08758742993156757, 0.03414264654800777, 0.027671727847548264, 0.01993521274397931, 0.08571574689760324, 0.0612079545164541, 0.02138375860428618, 0.01988003909167263, 0.05942184733407152, 0.02124814571993005, 0.06564362275023615, 0.02004064942499803, 0.023326457988831307, 0.01990164468635715, 0.049144367972809466, 0.05931095993747154, 0.0576809584914196, 0.05552521388557169, 0.08887895458047429, 0.05871056917033369, 0.013011632798870486, 0.01653445460232756, 0.03863988909870386, 0.10687171691848386, 0.03574917122962014, 0.055555121958135605, 0.012858284979067262, 0.009758507461106826, 0.05265193600808421, 0.04825489392744438, 0.025658854809139046, 0.07053556146040078, 0.04564864748728372, 0.05594559314270174, 0.05385596575515886, 0.010471502619404948, 0.014626266521161363, 0.03598678489065459, 0.019207911851305156, 0.02167336282230193, 0.065590011917295, 0.01551609296697162, 0.022260935023246754, 0.028495622851375132, 0.040354918643471696, 0.07672886138841992, 0.025566805514597127, 0.017656426756612716, 0.022135459397348668, 0.036874113889831694, 0.09275296928300973, 0.06021825701839501, 0.007984187977854162, 0.024896130010846163, 0.03641347671228071, 0.031728843309646176, 0.021868979543327324, 0.04355488322494973, 0.02781550148351779, 0.034491932845764586, 0.03028978736350133, 0.06347431838812848, 0.010127274417168191, 0.011543169610142227, 0.024075232326023044, 0.03671127041020701, 0.008489277886016475, 0.07774581246438526, 0.025233873278803887, 0.018612062070338477, 0.055195596895270774, 0.03757332233832248, 0.057753530000486684, 0.04652378036670628, 0.05164358043862928, 0.0277881023489059, 0.0029648428608197723, 0.019733603300166228, 0.013867040829462631, 0.03545158437543339, 0.013048891485067866, 0.06270437704158888, 0.04920542518037462, 0.02063543434374996, 0.05325631426286794, 0.04010533868905999, 0.05417543208046306, 0.018870149431149327, 0.07652212490117358, 0.057173984485768506, 0.06875611541251983, 0.0420463182062151, 0.05862163019276435, 0.013721609570746942, 0.008215659050150745, 0.02865993338937481, 0.06830229258705532, 0.026649883384966565, 0.037866550152220076, 0.07009584997450152, 0.004159210563351911, 0.05304585841874923, 0.0658625323745993, 0.05831731708660241, 0.04344892943458211, 0.011706029369135298, 0.06684240479502948, 0.010115956425696853, 0.042704253667785276, 0.02766806020161077, 0.036393550765370174, 0.06891110266048102, 0.036839080689054345, 0.014886927937397794, 0.017347358159660813, 0.08212155347029049, 0.03511578505558353, 0.036712840890451785, 0.053595158782216816, 0.04495748296199788, 0.02261417241947305, 0.03339258518310324, 0.02186462433347779, 0.03803451492961857, 0.018620964012018616, 0.05033381140580581, 0.017604524299742717, 0.0159159142546536, 0.016267507434672406, 0.047485243694316, 0.041539210135177265, 0.03242333074130359, 0.004651300438244137, 0.03445486185110865, 0.0392493503468652, 0.06435877838802916, 0.02815129697292803, 0.0070629399570245905, 0.028688192457681703, 0.04168291673845342, 0.05554154688011735, 0.008235628089507022, 0.08934993011456344, 0.025064282479786107, 0.030478769763102456, 0.03820526826706144, 0.009336781804449856, 0.006453856007165967, 0.06815208572774165, 0.017139397846955447, 0.06558387555302152, 0.01970728051908795, 0.04742941886727368, 0.027648159152557774, 0.03501439331880501, 0.02386736394386859, 0.05278148913695928, 0.026349314533534552, 0.017335242479138317, 0.06329958522391897, 0.01637355315559093, 0.04390729899187723, 0.03199917850114646, 0.03191324067302048, 0.05961582079649933, 0.06277154380035016, 0.04505559584246047, 0.04536380450571737, 0.02828392594481909, 0.03902814245872921, 0.06844178187630831, 0.03969785269169558, 0.0507687846378934, 0.04991144798095188, 0.032834103255863153, 0.053721643728955146, 0.06712114588627893, 0.035783832877754204, 0.07991009512014928, 0.022936565200648, 0.032929734011451085, 0.04675489377170321, 0.0523507945059288, 0.06955888362661486, 0.004727813948486602, 0.04775202232262781, 0.04095837376230667, 0.03130338872001777, 0.05512928049410543, 0.029885993909931956, 0.015562057284818543, 0.038539780559198517, 0.06542171006120982, 0.052014041406613205, 0.1105949272131247, 0.028262695733217463, 0.024800556711852554, 0.05477536319484634, 0.07517458390324347, 0.08098741392454795, 0.04394970578892578, 0.04889355461683966, 0.05505882338770936, 0.0389006232932931, 0.03380325810623265, 0.011214086966168497, 0.024493479943503777, 0.040033782246492566, 0.01764974263947337, 0.05015227155038907, 0.045397198278336756, 0.03803260737068711, 0.054864627759783506, 0.028280417262125882, 0.024912104859287222, 0.07134560750977648, 0.02110781181874054, 0.04535096104166681, 0.11026612993690277, 0.012522431075452797, 0.02943237601298719, 0.06111905001284135, 0.04732368341196449, 0.018080609640286818, 0.0756463791514116, 0.02453827885009589, 0.0434265022105988, 0.06567241999530984, 0.04944897985326187, 0.03357931528420698, 0.05345176627498962, 0.06113605716476037, 0.09186093650397756, 0.04155602576511522, 0.042234683905037186, 0.08050286331244054, 0.04126240341593662, 0.022395929291604028, 0.030769770176360206, 0.034636501297955556, 0.05961053095938218, 0.021439458942040805, 0.021954946099750457, 0.07047338576446618, 0.04998101259491617, 0.026346294231893077, 0.05330727443159108, 0.02762419400706647, 0.03294322481979767, 0.009454931714572012, 0.008730656869198767, 0.008042121940713015, 0.041282195297460404, 0.02395411574041411, 0.060676431223269434, 0.06970042603150492, 0.04913860699161888, 0.054678506698579564, 0.06740704223874115, 0.043840484633561105, 0.04380457043167084, 0.03745480470599667, 0.11471607421915378, 0.06579873257226522, 0.01999453667761578, 0.040684995286527185, 0.02291351169978659, 0.031618708594431805, 0.0155441164632418, 0.0634742149662587, 0.035975439128495997, 0.030784099850983872, 0.02196655999268255, 0.07535531170546048, 0.12776999794427427, 0.06084133930985005, 0.019529530883676583, 0.08194533026506824, 0.007314979053673245, 0.034015920283573295, 0.03053635467715081, 0.01948130947928275, 0.05892389018328921, 0.04884146829886783, 0.05599696699890399, 0.036781444064071106, 0.05889362587984051, 0.08338888506254843, 0.05359528518672432, 0.04715552711258492, 0.027498425352537346, 0.030828571254988352, 0.02468725613829109, 0.04630120884206507, 0.031314954732454596, 0.03625324559247783, 0.06352544709619495, 0.035227327457358765, 0.032983099696256464, 0.049979001614114935, 0.05892804621027843, 0.0536263155780973, 0.036855513275030165, 0.013914513382910481, 0.04781959510798897, 0.03899423540720055, 0.018105974811459744, 0.04093031196164028, 0.011164858156154233, 0.030453500352920066, 0.018689894688225562, 0.019654309369563576, 0.025718121286181193, 0.016559053685576204, 0.02101335317767676, 0.021523489211235317, 0.0368179175101461, 0.025216785687652808, 0.0070667359226894, 0.05295191305659471, 0.03268362443533636, 0.03973195892608455, 0.025430951312544848, 0.05576719807821417, 0.01979114033371931, 0.028767900075763467, 0.07261822510871195, 0.010195603714354578, 0.02341518246178185, 0.09869247960347323, 0.03471762617869723, 0.02629853631069343, 0.04470222246562762, 0.05209895076170083, 0.04702930263574085, 0.0648437503484949, 0.10988051191933694, 0.04761575443309642, 0.0659269986734275, 0.04434716369536135, 0.023951095438772635, 0.01867208314398604, 0.033113545317563324, 0.019991231008222508, 0.04149634368537415, 0.034757194619986324, 0.01453916519700039, 0.16140485843343122, 0.14360312011934098, 0.12817846070374214, 0.13029531485611393, 0.1924097084350163, 0.20725528198865154, 0.14845591939745412, 0.1203882581584396, 0.1531598371483626, 0.185306801670982, 0.17757833815149723, 0.08797146214713013, 0.14950625658515962, 0.13333933457972544, 0.10210588394153504, 0.3264218827168788, 0.10250828694552185, 0.1269317675201643, 0.10073586592390653, 0.24193868701977117, 0.13678424811411288, 0.155064714772086, 0.21958926692605021, 0.2167023105486747, 0.210966901372998, 0.1610523200924358, 0.11391791785436292, 0.21992536502019053, 0.18266261855681099, 0.10153992882659359, 0.16466100790327595, 0.13274915576461824, 0.12467682601944094, 0.17289643776753258, 0.1289415762068764, 0.12625394824651942, 0.23535619910445907, 0.24155368187254478, 0.12414133822124813, 0.2484429726797727, 0.09819823797912368, 0.14529338587195645, 0.12042395785571107, 0.0922649406317261, 0.1756667955628326, 0.16934842412029544, 0.10614610141924313, 0.3345672666065155, 0.11472631681470141, 0.1836418014981093, 0.14423396288146897, 0.08471617069576057, 0.11065283579932106, 0.08739045340447657, 0.21609628903529338, 0.13771561184717765, 0.17994452327970537, 0.1035011675389063, 0.07447951999042304, 0.22296170854280073, 0.18106880327386243, 0.13994201657272157, 0.14615236961793515, 0.10821365781368748, 0.16999043644435946, 0.12261031916545284, 0.14226661844839975, 0.16899731070283922, 0.12958397157490253, 0.16083879606618037, 0.10416945667877313, 0.10999340263585891, 0.14837806954258873, 0.11671992274181497, 0.10674931905082158, 0.1371348559135391, 0.11706947333990567, 0.2073839541164137, 0.3178330871366686, 0.12543536797766724, 0.18543761884493215, 0.16392032345456464, 0.11942478001958902, 0.08431043520930313, 0.20144196167107553, 0.1340237575312776, 0.18671952909038914, 0.23015412501990798, 0.22396840936233922, 0.21048550704313865, 0.1431873182375585, 0.19578362094058147, 0.13525855336939135, 0.25412542985812314, 0.11994548998172246, 0.18700653627034158, 0.1015837796993794, 0.14786905008217982, 0.11929494343818196, 0.12282218844179185, 0.1528949545876634, 0.15585427563036644, 0.24664499496500342, 0.27340467598649765, 0.22965256725588154, 0.11231502442951165, 0.1770736087834643, 0.15952826477587223, 0.1624365643628182, 0.15324548577829716, 0.08314235796851498, 0.2682310084421789, 0.13124267450503765, 0.12137188440969876, 0.19814461199266298, 0.14786180289041612, 0.1857810560613871, 0.15959820860335905, 0.18471087719644272, 0.09608041089508804, 0.12531991086659894, 0.14114400852591763, 0.22898283787071708, 0.21992905756398556, 0.2126805481290625, 0.1935061641157635, 0.12540614172335596, 0.09656709889250417, 0.15962663046534986, 0.11682852336596097, 0.1371421950358537, 0.086326073825119, 0.08945877588684521, 0.13060080007680003, 0.10003401447207698, 0.07835481405979203, 0.17627611125428833, 0.08417382641064544, 0.13668834922775147, 0.13397737856834166, 0.1471844739130428, 0.12941753131247338, 0.09432970080524684, 0.17113489519444205, 0.11524419991239426, 0.1889316232935075, 0.08597010341022285, 0.19187329367043512, 0.09345763993840064, 0.11686663624019393, 0.20423982202285723, 0.16945826580687878, 0.12195092430638692, 0.0973553344186756, 0.1174304309871889, 0.176155605623799, 0.09286350044872492, 0.10933236068775577, 0.2186569226004424, 0.07019337296726243, 0.15252764607148786, 0.16958450177504172, 0.14523015297468633, 0.104964142665267, 0.10884205675533704, 0.1469104136190107, 0.16422153390463323, 0.09585439197478757, 0.15240850407750378, 0.1793740176024937, 0.0845715486174149, 0.08356824922826021, 0.1413436663607436, 0.11137804527196193, 0.12649386400176635, 0.12592242369728704], [0.03667126912924071, 0.012573684272806973, 0.030371121003202377, 0.05112700735128695, 0.01664472529814849, 0.03004068429882248, 0.031204754899766658, 0.006809680386551566, 0.05777719828690733, 0.03603163167774197, 0.079123567970049, 0.04445388357365324, 0.041525014525940346, 0.0557968418504442, 0.028456759210976384, 0.026066543819803386, 0.020298740616248503, 0.01190018094700551, 0.0506890157327777, 0.04141729873334689, 0.15570619083460302, 0.014316028682515027, 0.05148191290396837, 0.01407685220211504, 0.04335787605434176, 0.02486930352695767, 0.08774340543295107, 0.02232076265969344, 0.0898301063646232, 0.02309101427184238, 0.04700155110068379, 0.02932126262044955, 0.014186602915757367, 0.0653342764464117, 0.02038868316899865, 0.03456005721443123, 0.027462742892244173, 0.04322749555050846, 0.05461897400598373, 0.03192275931547967, 0.04090301241845854, 0.012928835931234063, 0.02618209286142261, 0.04659810621711997, 0.012256332350173786, 0.022566740085641225, 0.02767267588135456, 0.028739051119754874, 0.013795608876182908, 0.005687882517269182, 0.04782796461856173, 0.05699751230197088, 0.037375407353524244, 0.04075466715280087, 0.0357905782819275, 0.04607998180173097, 0.012931688651142102, 0.023867415654803478, 0.05313401598663581, 0.0328289398232535, 0.04162295120618036, 0.024313629311960072, 0.043681682267737006, 0.016867869473513097, 0.09367995099314759, 0.06463715941795418, 0.04100932243971094, 0.052432271787115646, 0.013060568580253711, 0.05562372896219454, 0.04964838870951245, 0.04704183200374246, 0.02681903176820807, 0.01374231980016996, 0.026008495422560843, 0.04531435736064469, 0.01899858215643514, 0.0763315758517673, 0.029791213511939973, 0.055364917648295243, 0.02919307887373913, 0.03577491561431558, 0.09130812745781676, 0.035401164298696865, 0.025354915170840202, 0.05930601867035993, 0.01878220253744193, 0.045065543494157256, 0.022207611473277215, 0.09007540005709856, 0.05049980733723891, 0.06048485944648424, 0.028101179500921603, 0.05340732934494173, 0.07371662665278682, 0.02209996079815732, 0.0713606458157301, 0.03776305167364978, 0.03820943578536953, 0.07044985920431153, 0.05423031461935851, 0.09420941734025556, 0.09097747624881806, 0.05173914224630402, 0.05051527082199051, 0.052980105092208234, 0.03539390944605393, 0.06209627559949314, 0.03193829174814446, 0.009610515553504229, 0.034460308736250285, 0.0954200124608413, 0.03877224227894218, 0.027005646956123175, 0.07555021979515592, 0.011841829945032877, 0.055400456467102614, 0.02426904874042638, 0.058703153439226656, 0.024146476587761315, 0.009493577019912342, 0.025617131745562922, 0.034660292158444087, 0.011702739979110418, 0.09163592881973713, 0.016972637742817882, 0.056193211912027294, 0.008217116532426688, 0.05224666783526059, 0.013900642403431479, 0.05924237208561071, 0.021867617822041916, 0.00803302560422209, 0.027843676282153017, 0.01643213972960028, 0.02799784573125503, 0.025455054353862524, 0.025740320599007032, 0.011788158782667691, 0.031578285965107145, 0.036117820399663145, 0.03153101834017904, 0.044368767374826056, 0.01951269801676033, 0.037305854230878815, 0.06013081957315726, 0.011816209092015221, 0.04039580092555092, 0.013516126594866716, 0.04880562687533037, 0.029542244512647874, 0.050606753211468465, 0.028146968576155847, 0.059081838361077735, 0.08902055061151905, 0.03698011364547476, 0.056099902402849934, 0.03329872026018078, 0.03707340783289364, 0.011621871737823372, 0.028632490204707272, 0.07591137662529945, 0.026506563656092174, 0.03849999761329063, 0.028495624766594944, 0.010002214393969025, 0.025173888594332724, 0.028093238999586434, 0.036813428234909816, 0.02835825754089221, 0.01347033177397304, 0.032140272744600816, 0.035482120640095205, 0.022140481103692326, 0.017642930202606707, 0.04946407178537019, 0.020716578376689748, 0.04552020518589885, 0.013586958126735785, 0.114801018048198, 0.04827356349015909, 0.035392147443828084, 0.036697438692734126, 0.014173853297477529, 0.024094738839795033, 0.02810915447621336, 0.04365471214236271, 0.05528712908046381, 0.010265053415130223, 0.046434845219576554, 0.07478153483281214, 0.04207366371467229, 0.003586703242035583, 0.03695893897524765, 0.07786170624557041, 0.027947485026332642, 0.048586023941395745, 0.0326424318876478, 0.03605056554079056, 0.04734172478258129, 0.012995798719085514, 0.0437137353864889, 0.013752744341599605, 0.013797311506594622, 0.0910617229378512, 0.012347427865249977, 0.09723669038184228, 0.025412231954115055, 0.009108451213837873, 0.03536904606247141, 0.03324562653658852, 0.0499376711706, 0.029507916112760865, 0.05051630504068829, 0.026369374545831836, 0.06871410315075228, 0.03598025782153972, 0.025475116281379617, 0.026083527989084684, 0.03428003675634823, 0.07713933129824939, 0.021555739597627716, 0.03730830954267614, 0.05618350174758704, 0.07891368286143388, 0.09715477260009897, 0.0349518230875894, 0.11876774471132986, 0.059405617761395635, 0.06229442041066866, 0.08048473001127282, 0.07031636838350566, 0.06222201744094492, 0.02103539735769793, 0.08672994771792043, 0.0456453686309678, 0.018218534194954464, 0.006884905911471334, 0.09099574744581215, 0.03247342140023266, 0.05428515502341813, 0.07065985156523605, 0.035136614986244714, 0.01234730146074247, 0.04276575520634652, 0.0645307804487886, 0.020802832216084487, 0.019412660340387976, 0.021634074003105203, 0.01109434933882327, 0.07454094492019185, 0.05774700676181144, 0.06530360994680275, 0.020636951197840033, 0.03623007909364758, 0.04684680900085838, 0.0600962843295307, 0.026729171569909782, 0.06602888070647756, 0.026522940700693477, 0.09899723704063124, 0.04321844422168309, 0.08453155882776746, 0.01793175875659912, 0.014067408253228473, 0.05446717368378755, 0.03417437407939184, 0.04306099783148497, 0.011558302719476483, 0.02563225815162784, 0.02343091407730695, 0.0018118528837916413, 0.003772575324664133, 0.11460717482071732, 0.028918386557169502, 0.07851925483273883, 0.033616328822268594, 0.035418014402591416, 0.03315129046959262, 0.0539540671443026, 0.02196680514081832, 0.021888754187872814, 0.05088780788824924, 0.03094238127701946, 0.0261940821374376, 0.03577513011893438, 0.016180152343886516, 0.009433404643899732, 0.06850486155599356, 0.009762855010077117, 0.028725255791458394, 0.028744080486977776, 0.0365802961882324, 0.03513895921529301, 0.07667872093377576, 0.047504595075283325, 0.054604525587731795, 0.014320080330024564, 0.08695801209297874, 0.04314008491834806, 0.020460749060035716, 0.0253988349915392, 0.011213544958962068, 0.04353059823775003, 0.06664725155719826, 0.02063911922666575, 0.026072542288250504, 0.019845446391451745, 0.05111304539886694, 0.02848887553198203, 0.0403561175710732, 0.030401517456818013, 0.04575650117570355, 0.04943902071024622, 0.036632363354006124, 0.025396666962713487, 0.06432340044768588, 0.04349399072628829, 0.026262823206883286, 0.054551998769203504, 0.013178134348333604, 0.014091631953394222, 0.013304124210750865, 0.08783492229638562, 0.033336871438809944, 0.021844527932004105, 0.020690110038905855, 0.0023512385134029415, 0.05923464225845472, 0.0064284884419682775, 0.03709957739638706, 0.004665597554131021, 0.02690279965228852, 0.05382288607858843, 0.02676461462772662, 0.08927500671556882, 0.06951240507224876, 0.035426506487232064, 0.02691545159435801, 0.015712831049196182, 0.01941422315975351, 0.014920993952170737, 0.03902069991454482, 0.007976542420369844, 0.02644801921691866, 0.03050325201794265, 0.010374287977033566, 0.019614061025241693, 0.08125530721078958, 0.010743323063868429, 0.04162622623205666, 0.04710975335910917, 0.10502352214027798, 0.0995076967463378, 0.06944063029462291, 0.17848543221912078, 0.25950532827165823, 0.13078813921780358, 0.1155195395732599, 0.15539598651230335, 0.10922923759226838, 0.1354434716725542, 0.1475593513779102, 0.12027087816668135, 0.1291480215807115, 0.15189524048999434, 0.11399171510410887, 0.19287334484679086, 0.25083394841321055, 0.17931820043633062, 0.2652175249832292, 0.082191803732947, 0.20303899452330607, 0.1179060873184954, 0.12039732097858384, 0.1525214254375427, 0.08314670934792488, 0.11272403111140575, 0.18700881921235593, 0.11910355935293822, 0.17325282186990784, 0.09513123561778376, 0.13933777238332457, 0.0893116410401079, 0.1613217991806807, 0.08545352266200128, 0.11497319630918004, 0.1927837585249255, 0.11796182021498682, 0.12439527338550938, 0.22404206105537955, 0.1848286249104046, 0.08782432730039282, 0.21774086530410477, 0.18063317503659956, 0.1596944139248902, 0.16788122784947196, 0.15208227319582818, 0.10842289940844621, 0.3137323104085461, 0.14913531681222303, 0.15999691140267158, 0.15632241663913574, 0.17209465014598063, 0.18209326201148573, 0.18164577473315502, 0.19012901871915788, 0.10838568285708466, 0.08600516725451716, 0.1296412749516387, 0.1864250755358127, 0.1116331295681096, 0.18430975355928947, 0.06751289260723899, 0.23833955998622605, 0.09258813780522154, 0.13700950860736832, 0.15454326936554524, 0.20611997032838486, 0.14564376384500535, 0.09695546716571816, 0.20449488333636717, 0.14968021983100524, 0.15639030735098547, 0.10664266429000324, 0.05440696683381835, 0.24957960201126916, 0.2228869996484249, 0.22344728571272668, 0.1381468427397551, 0.14099832924623645, 0.10650117551126789, 0.09797083243968026, 0.11217252441471624, 0.24703671104244648, 0.10793117055248831, 0.2240923777102463, 0.19099198612234286, 0.1844384410088101, 0.14434905993121286, 0.12473022234776329, 0.20113790137392862, 0.18021619337941372, 0.24715951493670865, 0.15530171173234142, 0.09063619173943036, 0.09803943561329957, 0.19368024993567698, 0.14254660826296578, 0.2531712520266733, 0.12051555898881729, 0.14957351910491146, 0.13618188850100965, 0.16820606445112538, 0.31401833699595544, 0.09904286523740138, 0.09646880981181899, 0.14140015768428005, 0.16517588027542637, 0.1577090357820834, 0.15614025625250033, 0.0879373252692242, 0.08124980669949325, 0.21284830606272145, 0.13885669981039342, 0.11626773168362918, 0.20367143074831656, 0.1651159415562307, 0.0786622298220473, 0.15802533816426031, 0.17650095806006463, 0.15874952107908266, 0.12656812090426683, 0.10878184990536784, 0.27566540145104934, 0.21945175414364185, 0.16228288712520755, 0.07903567470249631, 0.209478453823155, 0.11897025239323417, 0.160495282240933, 0.10433522278382894, 0.11281665114145126, 0.14744742593217283, 0.14143625574727214, 0.0975204187054788, 0.11216381399501717, 0.07925951793309181, 0.14418773713611788, 0.12288332225814944, 0.15969458246423354, 0.12332771454126605, 0.13485197518621722, 0.11308228446831627, 0.16540097222933847, 0.13961174074680577, 0.0780235116760577, 0.11256814754057316, 0.10461951035165018, 0.18162067769275558, 0.15394682395121745, 0.14607145541137265, 0.1378002798845691, 0.0746643003977595, 0.14888442301702115, 0.21424401100845109, 0.20558988345005821, 0.07365290345924516, 0.12425898634377988, 0.11642944518356554, 0.1709069993587271, 0.2242809119484117, 0.2327542274349159, 0.1394511227526011, 0.09756534976223785, 0.10117613665399053, 0.14983222699694096, 0.09184489462284312, 0.09999733418226243, 0.10624229141901578, 0.1512349339862985, 0.11065485827144116, 0.14188001983829085, 0.1408515621217028, 0.1478269305681029, 0.13901825243186566, 0.17626904792362647, 0.19301784435106864]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.04284439796221353, 0.010284992768579434, 0.03519731596292507, 0.1548850977973592, 0.02546218088677814, 0.07533059770902319, 0.046043619438405, 0.02519984939886678, 0.010442126977948413, 0.012404265843572156, 0.015793778772105374, 0.07551405278425063, 0.0664906555245961, 0.040623290734666015, 0.036067507575236024, 0.029694196137209094, 0.02191563812835563, 0.061354162396803025, 0.0535768837547831, 0.04616156633522722, 0.021123959036964565, 0.042957449557199594, 0.02393955240897354, 0.055588584678668174, 0.051678648113363215, 0.03669004977470444, 0.04790432443241439, 0.024693982390266274, 0.016756589456851927, 0.018119143862878124, 0.03576943425521736, 0.02322286374927048, 0.029762780158630306, 0.0479448811271258, 0.014670804000249314, 0.14014374284494308, 0.05887259293587939, 0.04665217287237606, 0.025303114220620166, 0.09390308942285278, 0.041831070482130014, 0.09273109747277153, 0.018375997822130882, 0.01626371912988684, 0.050546990692495346, 0.02915415203108663, 0.04652112204160902, 0.10513227598200883, 0.041930512525141246, 0.01343514727083065, 0.045867208541641315, 0.030362724679552262, 0.0550834569449146, 0.047552536857584794, 0.021254812600091103, 0.044466045219451196, 0.11592888333384069, 0.040308037892945354, 0.06102861716381966, 0.023275024760814927, 0.03209934832768575, 0.03187525228807523, 0.0340912152352112, 0.016893081427101168, 0.03375786356627941, 0.05812957957987824, 0.03606512504179151, 0.04031709688264997, 0.046357516304499684, 0.021164883453879627, 0.027737259008591215, 0.04525608871312392, 0.05781430375551986, 0.01786076538865605, 0.022135369382017565, 0.038004354048039646, 0.05128711206658233, 0.04511290304963628, 0.02141262862771269, 0.030690650530760328, 0.07428928503706571, 0.01027766322236388, 0.007489326779895853, 0.019807362245515953, 0.025284682145161975, 0.019803351775232344, 0.010670466187049546, 0.03477609400907832, 0.035611263911930785, 0.04225694258967715, 0.054292923154970335, 0.02437081777550761, 0.03185616329222197, 0.03727282818046309, 0.015508374631134494, 0.03201219816541961, 0.010585799107267972, 0.0582369736155435, 0.010642385234185045, 0.04473455137603226, 0.022850338174330614, 0.04251840839823408, 0.059289302631852135, 0.02638926793400559, 0.07989416815220349, 0.07835420885033186, 0.021586057527231115, 0.07011604405218555, 0.046566937929920615, 0.007201609532198599, 0.16211624767991806, 0.049894980921019474, 0.014043413421830103, 0.02138837045359035, 0.008626335803719779, 0.09044165137193858, 0.03255706287980561, 0.038259698814081575, 0.08634122704426128, 0.02385720944843225, 0.06521605375793672, 0.07177516833067903, 0.05238977305951619, 0.04842094731547179, 0.017585172918775392, 0.09081125049100769, 0.056412018114520665, 0.09744186404972308, 0.05765340230878323, 0.031739819434381304, 0.05560182267799974, 0.06417209042176124, 0.042369967371585875, 0.025720860050510497, 0.01600128613532551, 0.01756779995987252, 0.06142818564248662, 0.0493491547662885, 0.02153097772069516, 0.047161992894665855, 0.0382924375815257, 0.06385601020508236, 0.05628689297384793, 0.03131723767446895, 0.02867842292142732, 0.03998258842095252, 0.04197423699341955, 0.09831415474294655, 0.02843330542917454, 0.04165127730718063, 0.06724710606278912, 0.023319124612176133, 0.03896250404537686, 0.014354045795757445, 0.04856985565575381, 0.08713641098790592, 0.06990910072119967, 0.023407954422216264, 0.09739514034722122, 0.03152879285475901, 0.03251978887184974, 0.02839128167608813, 0.08323132375916166, 0.04149068612605333, 0.035208726842557235, 0.02399409786918231, 0.08044239599257708, 0.04667857992312601, 0.016542684301854144, 0.03566333873858375, 0.0470993613764163, 0.08396414048489063, 0.03627593711679501, 0.04147314654302694, 0.09309544122868008, 0.03337483492589766, 0.005460357276587597, 0.04856590264206452, 0.04572846235767488, 0.10269674457489483, 0.03128204359522751, 0.031558702842542724, 0.07629102681793513, 0.09725306168078415, 0.02220494931774034, 0.0431173627505139, 0.045598047379884994, 0.03951103449048054, 0.02521643711764726, 0.06213377560338667, 0.043278087997027946, 0.13875105628563514, 0.016944995375290033, 0.06493801746757762, 0.05362419734498667, 0.02887413540344325, 0.05142548669790549, 0.08120337411040261, 0.011389494287751375, 0.05455031720620971, 0.022249822917905067, 0.014798251344942519, 0.007508739447897121, 0.057856147477944056, 0.04133745704987838, 0.04304918475569256, 0.014814884071388553, 0.039000839085107854, 0.07827405307081439, 0.0854445058071325, 0.09111987667218333, 0.06186249620851971, 0.03928332634630703, 0.0709947009360598, 0.05018340153319221, 0.03531588339096597, 0.047132023535068, 0.0841390613406416, 0.03922704569694977, 0.07922007206587062, 0.012725303606731037, 0.038564475403437694, 0.02348668910863419, 0.026640789921305356, 0.005014112975914031, 0.023352863124361443, 0.04953030391686386, 0.07318115417635249, 0.02015200605045163, 0.05577559057142466, 0.04182478856115092, 0.007119297215174283, 0.07790435436031512, 0.02503316015786221, 0.008259844128793527, 0.04588069551954827, 0.033348814749549476, 0.027288126556443113, 0.022960974677135388, 0.06790642431306262, 0.024829591444182782, 0.03031114781005008, 0.05230348091572524, 0.024722641739513607, 0.011106744641438128, 0.028952036969243523, 0.023496100498783975, 0.0825897864096107, 0.04667194177126212, 0.057329010038125905, 0.02765374393352578, 0.07088601604224214, 0.048437701658375805, 0.02507467829291859, 0.038429536676454934, 0.07593573822129158, 0.021499246358871463, 0.01952000649555797, 0.02678310415977913, 0.016830306267365813, 0.0110503988746073, 0.06465807361828704, 0.04236755036418477, 0.06886185086782902, 0.01859038178208134, 0.06805466998729014, 0.025791401426578243, 0.021744484509972316, 0.028262940881353234, 0.05940467547324877, 0.060586833410085215, 0.049272503839024616, 0.057249099406744205, 0.08305137736662742, 0.05228759608261528, 0.04807746796418102, 0.03748403479074759, 0.05631077193444776, 0.02364456450806991, 0.028089038922541568, 0.055159563949752244, 0.05554337016937714, 0.06954420538198564, 0.06404744408604118, 0.02741946850062138, 0.048598545648518114, 0.04883065496781661, 0.027903323887937495, 0.015003033350372027, 0.03201698429972655, 0.0228250649337086, 0.02144972260500635, 0.05116848718194712, 0.03206963177710291, 0.03137148627560706, 0.02446890384289286, 0.09531424636201513, 0.03293889642302548, 0.01917959724162375, 0.04736199929949738, 0.03525941888050687, 0.061809965559551795, 0.004232863214002141, 0.04403289144618377, 0.049569048813634345, 0.059938045038330945, 0.07543921365492767, 0.04859952241062157, 0.06930975183363884, 0.03754280905629839, 0.028970101322498054, 0.06168687055187841, 0.05558856935690969, 0.01939084981718371, 0.04830996415788128, 0.05335944501923458, 0.044291534220739726, 0.01209805666979763, 0.04146208806383995, 0.07031598533954352, 0.011307426161252925, 0.01339043837956964, 0.0077012573432688036, 0.018959760650872223, 0.025131636930088845, 0.04326418350120226, 0.08261756475774512, 0.03759585681461519, 0.05593026755377651, 0.04390375200478781, 0.0257529687106369, 0.041681668015136834, 0.04359085488343432, 0.0663247821672309, 0.008395761533099557, 0.014594424076588645, 0.05155060417769898, 0.005423499828940559, 0.06338203543676965, 0.03365724940874404, 0.021631572726032427, 0.04510734891218524, 0.05864514526160014, 0.0754045864807502, 0.02544863262183724, 0.01018353782954716, 0.08017999555675254, 0.025225768068564997, 0.06379361617408934, 0.03129437952602823, 0.03703511109755885, 0.027111709914019993, 0.07325218584869178, 0.11402542297277721, 0.15956995528071158, 0.32206097317318766, 0.12160420057273681, 0.1407495498537056, 0.12350123345611558, 0.15729018487036228, 0.07921910679508602, 0.20264514872143347, 0.13224149994071455, 0.24234581678625078, 0.1717059677767177, 0.14179642432399336, 0.18179324665857902, 0.21083525682408966, 0.08301117307236118, 0.2167767436513978, 0.16849066611499558, 0.15240289631389803, 0.1856017302000715, 0.22309316923060726, 0.14514985163846325, 0.18319316508789218, 0.1495317213477627, 0.12273120783990431, 0.11469077799589404, 0.1755866474441944, 0.10158384098641335, 0.15726968435750854, 0.14422455532175882, 0.13329456440143048, 0.14058568364670201, 0.1429403927778044, 0.17163705050704942, 0.20256444901948978, 0.13082658150984397, 0.20880763659313803, 0.09021240722147689, 0.22423788845058412, 0.1214726556152586, 0.16895673868636932, 0.10272009493482691, 0.1358358006203367, 0.18311428867520826, 0.25174364717977665, 0.1702319686451266, 0.1532021098800244, 0.1468306485443346, 0.10086826123898068, 0.07696847836937636, 0.15466391289186093, 0.12767840447204729, 0.09364842647506345, 0.11634280830020867, 0.08566595118252501, 0.29438525017711425, 0.14175298713868664, 0.1731943233960098, 0.09873942547147313, 0.1435703009126648, 0.1516686010384752, 0.08313913273835376, 0.1437724868376409, 0.1639933009902316, 0.1431788912703914, 0.1380392380299107, 0.0835231113277616, 0.1332296920760024, 0.15029235472602231, 0.1460649283422578, 0.16117909232214575, 0.18767459558383112, 0.10571228114948159, 0.09638991041649735, 0.18315729685127738, 0.1666788375305553, 0.12050717798692566, 0.13025313405500305, 0.18075277668333825, 0.24017754281240128, 0.09004838013600919, 0.11803322727040899, 0.16677159545642717, 0.11516582911774037, 0.11869417728796122, 0.086314904263183, 0.16099163060707433, 0.11544990218094281, 0.24024072974439592, 0.22454910400894382, 0.1115623660265438, 0.1246292672811016, 0.21892254060554892, 0.11000596647781712, 0.22105987994901596, 0.17958423212891628, 0.19752732898679473, 0.21569397030097825, 0.12387915995092162, 0.15803558842068718, 0.11973264777371961, 0.11804831920251732, 0.13769186312152495, 0.1567084023789052, 0.15449215597923727, 0.07171135320658646, 0.13774597957249612, 0.16413922541804854, 0.16142109949742595, 0.25569756485281453, 0.10169130780043141, 0.12759014348229095, 0.09896828657797269, 0.14325916196309751, 0.17212693309110982, 0.1894054027093995, 0.08996672282416014, 0.18525099982657742, 0.2345501673558066, 0.19003475926095442, 0.13726441670329342, 0.1438716032932843, 0.1272928094371192, 0.1415794988673541, 0.19180711899553576, 0.14232122519564244, 0.08800525428547014, 0.17223709653462135, 0.1584304761021368, 0.15630602235755614, 0.14547263512447958, 0.14150696566268323, 0.1281029320952873, 0.15289201281003414, 0.15158186456368816, 0.1500433148635972, 0.15327399957083887, 0.12993009009909245, 0.17625331247766174, 0.11219070368115941, 0.15054646609050615, 0.13929341589250874, 0.1780802789594858, 0.19823352415715495, 0.11577511416567911, 0.18110723024414432, 0.23273840005840027, 0.11581419231069666, 0.10161036295035195, 0.19912152731370544, 0.1161208496459069, 0.21050937834285924, 0.1342659026023842, 0.060797293084643544, 0.16507016014187567, 0.1754994053513773, 0.09035688374311694, 0.26887078378950396, 0.0917813552904033, 0.1880126701848161, 0.11945701699944274, 0.2292542015352557, 0.09043068865374213, 0.18364445216232733, 0.10961376010410248, 0.2039521713290484, 0.11992608497460043, 0.16574866889465242, 0.09813823031201478, 0.17877740364882255, 0.27175127438479857, 0.13208520268240284, 0.14991462741407657, 0.2626586074550306, 0.138494064430556], [0.014977034241441759, 0.058134451899076664, 0.015513870354381301, 0.015328604438822838, 0.022655039379793792, 0.10201154787453914, 0.04180557507600996, 0.032626412989151095, 0.044977228878246206, 0.031139541665212284, 0.028882832416603645, 0.011984991668272885, 0.09793838095520774, 0.04181259244139637, 0.014969855039981345, 0.04438361032835899, 0.008709690957931022, 0.10216232163891678, 0.0500895289493905, 0.011429215946625318, 0.015030803080017289, 0.10219267404247677, 0.012088101357221605, 0.02237516830885603, 0.0710295809192523, 0.023143119742012313, 0.024651749878220504, 0.011172792911829968, 0.020345328338143807, 0.04585681272850883, 0.013698723651618968, 0.02799107351400439, 0.015729874590291612, 0.033427262152995796, 0.03265167473845425, 0.04614518354496649, 0.06432146990611669, 0.035001312367497914, 0.054306777855080944, 0.04467581158443805, 0.026515400480298747, 0.014957695309403203, 0.04424749565641246, 0.021663574133849433, 0.06532481526054683, 0.05749929606193497, 0.08056906096997761, 0.06331307220182593, 0.07291954281108995, 0.029816888948722236, 0.08302005969228284, 0.0390860931797614, 0.03326187526146251, 0.026133180062677112, 0.04363340340674885, 0.028405982903355075, 0.08379027683047519, 0.011094260281102072, 0.01176279073866505, 0.02173185172010093, 0.03309778305852125, 0.01594623601469662, 0.0514268848083673, 0.04815269396790574, 0.03986021736636758, 0.05379618791442725, 0.023932849139636083, 0.03382104666783445, 0.03894922774164908, 0.026200266382206353, 0.03374978516911788, 0.04602333343017005, 0.048569154685303095, 0.05213172400310155, 0.044914873151649395, 0.054151909350748026, 0.101300465063222, 0.030427706172509544, 0.0018581528439103898, 0.007262095525455211, 0.044423986992408196, 0.062204431892643054, 0.03208258249346287, 0.1090893729199325, 0.009279796354202254, 0.028858938134245338, 0.06298452007373975, 0.058987544428917675, 0.0036276788910805822, 0.0756263153086747, 0.09136475667717958, 0.05546162092697717, 0.06835049483925104, 0.13637209281085, 0.021188205085514535, 0.031328623656243566, 0.09083895223034967, 0.03508389664573535, 0.06444236624144739, 0.005481089052233485, 0.00728678462403496, 0.07366225739280063, 0.02553534802920636, 0.024686832874712926, 0.07700593240799443, 0.05022840919874368, 0.05041380630685918, 0.03529606086592521, 0.08958816813725619, 0.010607048471067703, 0.02393428938493373, 0.054563202805096106, 0.04496755318776254, 0.04406143205180284, 0.048850607727804495, 0.017371116461412563, 0.030999906819253683, 0.019263056775314674, 0.06274184640196544, 0.020924808735388423, 0.008703683870994757, 0.09670180779310966, 0.049907740115398364, 0.07743875676345441, 0.12414100114256145, 0.02224797856122736, 0.006657311722876565, 0.04654665192168567, 0.03090719485865726, 0.03077586823623748, 0.0136614314490749, 0.0760528424213971, 0.005364594370832728, 0.011678947203402078, 0.021055779126923413, 0.04149483066172369, 0.07963245719551079, 0.1144569066743697, 0.06680281337110267, 0.020084856528668635, 0.044541209936141975, 0.05775487831523342, 0.011677493551565755, 0.049384735719931704, 0.04524676542308542, 0.025350186493127577, 0.020029656063284607, 0.046917488272752494, 0.026222885128170736, 0.09641932819278971, 0.013017316213658741, 0.05032582876963481, 0.04004840686496708, 0.06511962627090755, 0.06037004967971195, 0.045111650495880076, 0.0626102248356948, 0.07123211158379432, 0.04909153088867184, 0.020296126341206894, 0.05046775038804739, 0.05416992773872711, 0.05828842408053818, 0.026484525221730434, 0.049609521238674084, 0.04730035603467015, 0.04634460389253594, 0.051262704505314755, 0.02371533954095456, 0.053194521610895475, 0.029783029777688846, 0.03688401940669264, 0.026473978106232903, 0.012208540912627453, 0.04773919034989611, 0.038968939183940815, 0.01363374790432112, 0.02714442186838677, 0.0247265066530916, 0.028009750737598347, 0.013425582663096009, 0.0740271220884977, 0.027340111367764975, 0.05417242518536026, 0.023463984177778327, 0.012696998573148684, 0.05077711584406996, 0.08566588223461183, 0.005213776556399441, 0.08171581032295382, 0.02291216913069929, 0.047471469433437434, 0.01654249277987307, 0.0774534120254459, 0.0325991211068486, 0.054878754421107234, 0.04268101822104185, 0.01884104575090591, 0.024619962975022294, 0.02363374351613945, 0.05921407662812741, 0.04266263211085912, 0.05462996353725753, 0.019360560615877473, 0.012989323360905533, 0.019927230107808308, 0.07182626639522853, 0.04595691360713494, 0.03695514300958284, 0.01868971848800298, 0.09477655989147964, 0.05102141362224376, 0.0541537479617663, 0.043773720070960066, 0.036455806900536826, 0.042314931615105564, 0.02006467585752328, 0.029998262180015448, 0.03419008271227922, 0.013723381149071841, 0.07066908292472363, 0.07415350361336624, 0.02012154639458224, 0.03539343447154088, 0.02710538585820506, 0.010666256533905624, 0.08607889555634991, 0.11353266755900077, 0.008094776121358718, 0.05870455538012809, 0.03380835642136874, 0.02351452874380254, 0.04171775458681007, 0.026875883153068925, 0.06249394418010789, 0.0026929168398642255, 0.04633896548541323, 0.01151190364673253, 0.053241551748567054, 0.016517294232823675, 0.04595601728426353, 0.034150146548786474, 0.05185518158419479, 0.058903301570324175, 0.04075378615168795, 0.0750262386375858, 0.012642762420939343, 0.07807624916876517, 0.027449418708021124, 0.03221816090386241, 0.04316950652508005, 0.03207050894777621, 0.0311247791509114, 0.07083120245125986, 0.012667480247816252, 0.003381726362990336, 0.020692726229167274, 0.05390696805871783, 0.043707943761781345, 0.0415587606990049, 0.037419311852464755, 0.03843707115119023, 0.03624464242508815, 0.026998499355789636, 0.07892142801034836, 0.05722836523707356, 0.07084845475131465, 0.023454528737572894, 0.048901878162136966, 0.04963960168102095, 0.05321226803766144, 0.038396089277680845, 0.08655539458437313, 0.02984495841026787, 0.019041986783005057, 0.018562390844547944, 0.08597417899798002, 0.06644627605114253, 0.05487005932316665, 0.03542036246207934, 0.05611211384436297, 0.050860343636163784, 0.01106538259679632, 0.030650764162982666, 0.07788690287740001, 0.03677094482906884, 0.0959893613452873, 0.03299346486587198, 0.018493134580973177, 0.0647635332819435, 0.029569390838244752, 0.030526380212376678, 0.04583720087764725, 0.02155234582812315, 0.07796236253794163, 0.0360420887779084, 0.04785400777754765, 0.0744987871017187, 0.055941356676480467, 0.027211759081711213, 0.07823521241305337, 0.03478351357062498, 0.00824844952852976, 0.05937608890235425, 0.02561128074904123, 0.013562711443932307, 0.027342168313841668, 0.07505132035622675, 0.09743146057571135, 0.04061246974273555, 0.04586017585449642, 0.035146099154747305, 0.028186768759042028, 0.00956997992621074, 0.03926263814191184, 0.029069913002932747, 0.10192056727265159, 0.03653590522345997, 0.017427879746162125, 0.01680424012574217, 0.051347460642817526, 0.04430921936047174, 0.054531241616895126, 0.013450311981291782, 0.02058635109044131, 0.023652853579410625, 0.036564602877103516, 0.00821013172577706, 0.012319868809783892, 0.04135695781799094, 0.04821459004174798, 0.04565540055233625, 0.022413242878692768, 0.030447507630132382, 0.04748004961818938, 0.07872786823539965, 0.08269381348884876, 0.04944078654291169, 0.026060608553610025, 0.048385040774460764, 0.04602386203083781, 0.025903558613912716, 0.004553349872660493, 0.03639382655702291, 0.06948589843006865, 0.021346701016168923, 0.07156250232289876, 0.03780352409868952, 0.08577261360422259, 0.025732291997560573, 0.028707457653757547, 0.041295011948433616, 0.08615558861844963, 0.2643956352145441, 0.1713678012451818, 0.10751795038701066, 0.1084770541638136, 0.23044244987109017, 0.09278401882658083, 0.21320989956298184, 0.09387701945078951, 0.11728694271897117, 0.15059115966000866, 0.1633215644547055, 0.1754601356843787, 0.10181747482068117, 0.18619482014929095, 0.10400444900076236, 0.14936931070781526, 0.21407845940801407, 0.15566748807266836, 0.16802756596476803, 0.07932853479419025, 0.21257631420608492, 0.18351099964591766, 0.18022339460590195, 0.33818341611373814, 0.1193673081035095, 0.24990391767313405, 0.13441400271990608, 0.1044643622252249, 0.10429170132885057, 0.10556764374937742, 0.22893187770199394, 0.11757047952062662, 0.16373800985034437, 0.13262549385188088, 0.14774845252113958, 0.10476407880384116, 0.10298383602451894, 0.09931011500978663, 0.11792969814832173, 0.17864030455389332, 0.18816176621663958, 0.22518578436105485, 0.19282828355508466, 0.19855230866420656, 0.13122117807788233, 0.13291008019399259, 0.12075389660294018, 0.2223370710928594, 0.12778256944711172, 0.20234649700503196, 0.12950399199560766, 0.11139254731636856, 0.14482994864304222, 0.1564252103168157, 0.07740590691326127, 0.17414687712106014, 0.12138953507547418, 0.11907931267013473, 0.1426986154289015, 0.17367481374211852, 0.1020344309208374, 0.36116586998105055, 0.11633261933081573, 0.15212076145314402, 0.13841071406439429, 0.12176592173355243, 0.08965195261783178, 0.10362377225030815, 0.12941639750234543, 0.09253461890283132, 0.21858117182648953, 0.12990402778790844, 0.11881181774961373, 0.18674143920502356, 0.12538846041406357, 0.13259486565666814, 0.17520231645434134, 0.1155991820738681, 0.09142815045291379, 0.1345982775092125, 0.22972499320824302, 0.12394105985520348, 0.21278887296155577, 0.1619496695216625, 0.10710182674829999, 0.1506943823469262, 0.1511853221323221, 0.15989658452810782, 0.1674231685577862, 0.16538532871392467, 0.1789336396201003, 0.15907152315541623, 0.17576620313188723, 0.10834077478296335, 0.14046908506462652, 0.20976087979732022, 0.1613988829476218, 0.12305078907839714, 0.16799123807539865, 0.2122778769943022, 0.19460281897937098, 0.16956443027142556, 0.10074603191066174, 0.11938866663483844, 0.23669858433065877, 0.1488718132097875, 0.0955055998037419, 0.2006240862031137, 0.13312959502781593, 0.14180200144408212, 0.12006876118961843, 0.09206808667870299, 0.19605516846622192, 0.10612994462492005, 0.14369777794326508, 0.16405543072089074, 0.09576787766549857, 0.18056281752163367, 0.08569670961268487, 0.11730049481435169, 0.21606861793946838, 0.1812879657072406, 0.18975791040687792, 0.2438637433994201, 0.09139101817122391, 0.09446712165710427, 0.16842891942829857, 0.12540483171300543, 0.13381555015521665, 0.1366326393138978, 0.29850741608008263, 0.20443247781405527, 0.09623330672301593, 0.13101844056960077, 0.1789596406442504, 0.17630575885695798, 0.14253295657615508, 0.14344991785624336, 0.09656396559289387, 0.1457973491520651, 0.23194592806600758, 0.08229855042431625, 0.123147553644113, 0.15514477096017332, 0.17942582046793354, 0.2756373319895037, 0.16542539511236454, 0.11972261202191153, 0.15394238064125662, 0.11425550215907636, 0.11224334158243672, 0.11945099554835789, 0.14950058753451995, 0.1202337152414745, 0.11983404717137737, 0.12630755907946056, 0.15685274866559815, 0.13720196521570607, 0.24528485182071888, 0.15396225296201246, 0.08842110979340731, 0.19530129198345447, 0.14178237427146206, 0.13097520256715436, 0.1177825249971882, 0.1621297001838684, 0.19468509682243873, 0.09385930749798015, 0.08928717219180639, 0.1354949987463413, 0.15244250305958335, 0.21431686597005015, 0.10359845304441068, 0.14337032132091063, 0.11112357384615368], [0.022725080883490945, 0.01854818565921197, 0.03396661869520622, 0.01755727774223253, 0.04016342347547893, 0.03312641559469123, 0.03175935850689008, 0.03288558053393518, 0.03318919266964639, 0.029238184215500954, 0.05721228888198253, 0.029547082357889706, 0.043599124802576925, 0.009463705336524835, 0.035453074416446115, 0.0398627799304743, 0.024750933366557284, 0.05314184157478233, 0.00767247781397835, 0.01696806994356936, 0.057568944945570924, 0.06613326784704002, 0.038956823503418316, 0.032704182404784427, 0.06035056423335787, 0.03495899750100028, 0.028404466049264998, 0.09066001707387548, 0.023872328193617925, 0.027918046182622353, 0.04586464980797422, 0.08926998883966478, 0.0310332527113778, 0.018470243873795675, 0.08665290225537554, 0.08364809857260797, 0.024231341892793298, 0.03796168678109685, 0.03164586449612773, 0.028807838154476018, 0.05760521154790636, 0.012704250552961904, 0.11407010888140048, 0.04903992720609231, 0.05666537105195946, 0.03321656499118094, 0.0582281674348539, 0.03635386741089244, 0.010431047431343507, 0.06362278622785403, 0.049038969596186956, 0.03869308241372628, 0.02363667571766963, 0.009146372566089757, 0.0499601137163418, 0.04849290978463908, 0.014357425201113426, 0.03657869889491028, 0.12203685638885345, 0.02079874130656883, 0.05223066425852237, 0.09443974933556973, 0.007930409563179579, 0.02962515246303332, 0.018644609315801534, 0.06963439691331118, 0.046370198890086145, 0.03161013990099872, 0.038160402327775955, 0.006107028851646089, 0.05225031441378017, 0.01680281520220301, 0.015669140097264563, 0.03791793933018081, 0.01846549604388495, 0.06104969224261661, 0.01761788678836198, 0.01697050418794876, 0.0685299969007892, 0.07376365679045839, 0.032394476039635564, 0.03132513604096828, 0.02873769705934871, 0.06913627122318552, 0.03561808592489651, 0.01515276044712312, 0.00778983386548897, 0.040050440828406045, 0.012352936037425554, 0.054663721201640945, 0.02925973043837134, 0.06579113298005636, 0.02021960947932976, 0.022902158276748755, 0.027326325615567547, 0.05399776096906393, 0.03145812507418375, 0.04579164162879029, 0.02779881417330715, 0.09550309469622952, 0.04575161736518626, 0.058936220368430506, 0.058067147244489005, 0.06563273664083212, 0.023512004484092037, 0.03452581691465551, 0.07065039804025043, 0.07738448709489838, 0.07127244611300769, 0.060138832852845235, 0.062258862439663186, 0.04803929380291412, 0.030158073866679787, 0.09611223418746265, 0.015066111114837471, 0.0875422460657935, 0.05911072753670235, 0.028621393421124068, 0.08411329014286881, 0.08365388253643628, 0.0784860832256175, 0.0369549399962829, 0.0763000053684077, 0.008889745560384566, 0.023845503624949246, 0.024746260230219173, 0.06735818115093055, 0.04892494889997667, 0.008495731219168632, 0.05160229979082943, 0.06793510664494769, 0.05742513108998538, 0.05274565920474068, 0.07662291908937116, 0.084786512888968, 0.028222907041650147, 0.01006648629798644, 0.029508548135298397, 0.05308188753382814, 0.015210931418433547, 0.018899011793696595, 0.040152495231239066, 0.05606883753752036, 0.031197254898987954, 0.033744537466836554, 0.049868141030592304, 0.01751636673185614, 0.04813941766417796, 0.04551712168200363, 0.019571491434509238, 0.010846182816631852, 0.04906397087559585, 0.049515338389263044, 0.061254333479390036, 0.029144150753235145, 0.02505457040012604, 0.029683137658022107, 0.08211456674842105, 0.03460285088588153, 0.04249513464709444, 0.01087484120826928, 0.0305493820023032, 0.04446974925456509, 0.017937192235202078, 0.012160004454574758, 0.049856500324582866, 0.038588844660309055, 0.016711466878111807, 0.011751399011230998, 0.06524007061436292, 0.00543412211681566, 0.029990156969776558, 0.032505413231950615, 0.02551095770491708, 0.10939123454473673, 0.04099011278500961, 0.019706035626210996, 0.026899020923602007, 0.05419243540194246, 0.04736877534718764, 0.03173647737581163, 0.04956971531012847, 0.028038737589433312, 0.07449480344451244, 0.08322706431030266, 0.03832839008781218, 0.016711328982285435, 0.044842037342248425, 0.04732051563839759, 0.06978266557017643, 0.07449476514011621, 0.031046550082523498, 0.03166092386949928, 0.04121619682278364, 0.01570945547427982, 0.04269710223701212, 0.00836484988535484, 0.02577798148136466, 0.032545234482254715, 0.08358917108947232, 0.0358608438663425, 0.01767918722884309, 0.11495205994334914, 0.04233150209690775, 0.008872069996751605, 0.062362579253291896, 0.03802758566434345, 0.07825991108773217, 0.003889901211462735, 0.11847143722397667, 0.048524342372172305, 0.05881311003899863, 0.012763762178139822, 0.057586668389699155, 0.07651910651475191, 0.035019575903612765, 0.10971126011422566, 0.03266104782420782, 0.036037626315749464, 0.018752102942896948, 0.035040662473728584, 0.015949399000213995, 0.06874116137623787, 0.01141268281160944, 0.11034782555314804, 0.07804938246526065, 0.03506250747088944, 0.061185665188297156, 0.05371366875366338, 0.03372144757679874, 0.0338879912610977, 0.027167293423366164, 0.020529417351128596, 0.08755474095983852, 0.05973231978714467, 0.025341432023372863, 0.10106151457875968, 0.05077712733538882, 0.027665338674259764, 0.006647559423600474, 0.04147074485738431, 0.008628078653747517, 0.00803208954053961, 0.05255841965516729, 0.03652635210704419, 0.010490607894626598, 0.026218100909083605, 0.036056667431107456, 0.035873334929947896, 0.049355183878252586, 0.011481849059853102, 0.06263843602350642, 0.0699199868306037, 0.03160173974690899, 0.052008023785967986, 0.09909135860300834, 0.037348942846179976, 0.05990773093916717, 0.038855676914775567, 0.07220809227756916, 0.036819472668632384, 0.04288750189927317, 0.03494500107462368, 0.036830577113094835, 0.019539212319819678, 0.02699500791007473, 0.02319683208160343, 0.05241521100904192, 0.07342583499848843, 0.028336307206641764, 0.010239795496266697, 0.05543357444806926, 0.09370666447906725, 0.06949246380357973, 0.047644835130702105, 0.048548566072338054, 0.03466832459033017, 0.019391893611980543, 0.05027795976568615, 0.060473157453440854, 0.02596079304273571, 0.0767169946864728, 0.006938155725478165, 0.009991493951078626, 0.00597582767612391, 0.012165199488311285, 0.029382926952694694, 0.05587079997865423, 0.046182105152477185, 0.019959804166348714, 0.02185833666683926, 0.0673877215012908, 0.04584461660875429, 0.06486724626513259, 0.03775450213241481, 0.06371151070080458, 0.02796272826080601, 0.01873085932475665, 0.05531727464028424, 0.051004973375388694, 0.032879333086912675, 0.0022536712311839145, 0.03982708023320283, 0.020023824218961022, 0.030086705115653818, 0.01923080830414209, 0.016501397908394857, 0.062209537868658384, 0.05879223414306199, 0.01420426794568137, 0.024215190844129653, 0.03656739526758752, 0.015858060252221844, 0.047814868345496156, 0.08239895390767245, 0.03190939299642079, 0.011354935103877178, 0.018577658976878852, 0.01886926076915716, 0.029424950705781102, 0.02625906554561469, 0.030359039796636473, 0.07051274736201571, 0.026030644939671603, 0.015933318814683347, 0.016768293365115122, 0.052416340988730235, 0.030564138770944653, 0.040523638017475605, 0.0597851760234804, 0.02583949259602495, 0.008982580095048874, 0.05501678814330409, 0.024483850218295574, 0.03521467551528927, 0.028125466403341102, 0.012729781390648457, 0.1313695386652985, 0.013837576130284898, 0.04912292134136923, 0.033327004226345214, 0.09318776248443512, 0.04349689419952132, 0.08034344807627701, 0.03115157882172254, 0.022964755321041714, 0.04155651989182638, 0.054378196401821996, 0.014138095186001832, 0.027772389885578907, 0.061120084231539126, 0.06807719297226399, 0.10737841513248221, 0.17369316920878428, 0.14346623552903054, 0.12663635635568252, 0.08033004919848136, 0.08167921430281094, 0.08898675847317904, 0.12179369242080759, 0.1860489110432325, 0.11981800529024295, 0.14088778275876276, 0.10161410145942243, 0.11823533658659267, 0.16837504812546317, 0.1001401482931068, 0.095252905701918, 0.15415336125560347, 0.10102976023429826, 0.19529407543520774, 0.142631521448493, 0.18362943683901142, 0.14118373784567081, 0.17520853708828651, 0.176694885557217, 0.11149556315954655, 0.20578702851649255, 0.3250756823728162, 0.15480913251878756, 0.0905537836614155, 0.16569070668230135, 0.16507221325751276, 0.23318890572315265, 0.14790481106648523, 0.3033910733797858, 0.23150461545634657, 0.15382955121176858, 0.06200061036994862, 0.12851991375247318, 0.15990547114802947, 0.2301982823278635, 0.1960901173973276, 0.1490280185375483, 0.24108584729894517, 0.20417502630622159, 0.15081346305387636, 0.11131188591882107, 0.18252501384385172, 0.1612984947860241, 0.13536218974378803, 0.2623413244803106, 0.13736290496683892, 0.19309184844455413, 0.10988604307415024, 0.0749183351534509, 0.1326922507536027, 0.10235864699127213, 0.11619105394328795, 0.18502000899564836, 0.2948139529795416, 0.19315796183241954, 0.288055801103192, 0.11709835485465105, 0.10572556511408861, 0.11823980287919122, 0.16248206998552048, 0.17509094259190947, 0.14960702779071947, 0.10589798852320641, 0.1809091199069254, 0.10285581507149244, 0.12340745663330441, 0.2153381071383915, 0.12251636614241909, 0.08313239882549933, 0.18893203698098662, 0.15101439259465665, 0.12488275045348753, 0.12242133293541209, 0.19583596006756832, 0.1882127263853627, 0.2902452803907856, 0.16819179989397529, 0.21463166681989548, 0.1364169089544204, 0.07846221192589692, 0.2152571776100705, 0.11955652415992753, 0.15698499076308745, 0.13287102503161277, 0.16435371471508858, 0.09917358281992136, 0.09997624378170698, 0.1373747486861483, 0.12254851885260114, 0.12322834527660763, 0.27974408420343555, 0.19373764524296408, 0.14836699191120364, 0.1364186096696123, 0.2442004237203829, 0.2703046245921043, 0.16922005842770302, 0.12999232708206102, 0.0926948691748323, 0.12090113104110765, 0.19560616433380112, 0.13248343050720232, 0.17767834326913282, 0.139232435293736, 0.13690388040436854, 0.1910414600804929, 0.20474858101337187, 0.2090432852386467, 0.2553981930137642, 0.11513834188301718, 0.15432076678881723, 0.22849352219172064, 0.17751041679613053, 0.16396670241750058, 0.2242538843664431, 0.18531803251995196, 0.10099032968883553, 0.1430862865621044, 0.14713225736012384, 0.1106090845179654, 0.1027517726704959, 0.15829089488233292, 0.12614972198442106, 0.0955005512843209, 0.1754708762370771, 0.15831874983925975, 0.19572997946412335, 0.11789392184225783, 0.158843933754871, 0.1794205497830145, 0.1082368549560347, 0.11524495067856005, 0.34346936150423946, 0.11611446047261839, 0.12296717058146193, 0.14730854951325925, 0.12578537056763328, 0.09921703532698656, 0.11460226419712267, 0.07570082502019021, 0.12138683844598071, 0.15187870831258837, 0.16380075245134293, 0.09382988972168776, 0.09878159861170477, 0.19106376856084795, 0.1314780473588936, 0.1404766540133184, 0.23719730756936536, 0.16746590094220254, 0.20382965854819746, 0.11831795150834708, 0.1897507091803897, 0.10468268196188635, 0.13942426370997585, 0.062061705881909984, 0.2112648176449922, 0.298667773604393, 0.10270059033627472, 0.1363375882107404, 0.25800572648163766, 0.10878298371549576, 0.20346565953185483, 0.14133277259046031, 0.11219116333391398, 0.16496658505451295, 0.1477397957275952, 0.10382087901234628, 0.1283929883051784, 0.20142564399828836, 0.23989289518325563], [0.07661849110116882, 0.11415375036097343, 0.02031523065881864, 0.00746771160911228, 0.052075795754189455, 0.020199103220816583, 0.034463530135971886, 0.010874205355292127, 0.02835767914450938, 0.005953191693181233, 0.037828548360736146, 0.05250193216207047, 0.07048536737960193, 0.05101947158935571, 0.021497679709066308, 0.07158490273380472, 0.046121408006236445, 0.08593068818651861, 0.09129021632214708, 0.046692614653898824, 0.07183898345477159, 0.04122163987748566, 0.06198776690589805, 0.05738533665275863, 0.03551722661922536, 0.04333926011778174, 0.08257401265924977, 0.07808217868929909, 0.04515213058179906, 0.04734812544718866, 0.03399073131262295, 0.014492567899006029, 0.07007532647901005, 0.03466347525376947, 0.08333346626210598, 0.016139735460221287, 0.030531861571474906, 0.05335187990098231, 0.08609145173742887, 0.06099341542369897, 0.05034133055878263, 0.03596055020968761, 0.04170581127607054, 0.00862479883982169, 0.065010818803022, 0.04180732941735656, 0.03989462237504702, 0.05890141316359082, 0.025257558802202828, 0.022485707135450457, 0.06992674372609585, 0.015969410174406104, 0.015029308250955036, 0.030698252038189003, 0.089998806586429, 0.04036959305766129, 0.021693403682401104, 0.025446520134386037, 0.033552295363117615, 0.0028521352871921997, 0.046725912665527676, 0.0611590244807303, 0.12235639166207084, 0.025447299628848993, 0.04885140445924575, 0.05031736732851114, 0.024021993045725172, 0.03919048798120311, 0.03745434888368172, 0.04003975390186233, 0.04048168704274201, 0.0064663609561149875, 0.051220309199585076, 0.01666305586695671, 0.030037595049267816, 0.04357416948844348, 0.0224806854291068, 0.06396312461865526, 0.020074518172130473, 0.028444499888968085, 0.020528453995563814, 0.03563775523235241, 0.06704993801371706, 0.06378870555049469, 0.02789872352995219, 0.041236601574646856, 0.023418055291497902, 0.02399773104116321, 0.0269148234022601, 0.06256649653697688, 0.02896599509122391, 0.04373808932160178, 0.027900763239050587, 0.008125080644423443, 0.03541811782446119, 0.009066999153864962, 0.025917871051558086, 0.022186475107446316, 0.008157018849986696, 0.10445076416456893, 0.035488394900195064, 0.01522232889152703, 0.07724315153374788, 0.07159229548227403, 0.01893909734433457, 0.07587394556931912, 0.04507421177902049, 0.016149445624661543, 0.015660190275089157, 0.040524250887815035, 0.05246835835878888, 0.01951586195988761, 0.01152148740666528, 0.027681872766885548, 0.03881651833052597, 0.035922272626550934, 0.022459888057182395, 0.022617296142984303, 0.030543835525731408, 0.04095569628501131, 0.018940888074857574, 0.07204429501847875, 0.042588566730339686, 0.03744215276392718, 0.0163787376556185, 0.040919540765424894, 0.025942692300304774, 0.019897888940308365, 0.032248639711929906, 0.002835591618467363, 0.04892805538650963, 0.05104823053003319, 0.0327016543146343, 0.02043233294370434, 0.018217532534993464, 0.03208003716633445, 0.0476811821722696, 0.09459060736961904, 0.04123245320853688, 0.022214615432124947, 0.012994488708734995, 0.011624168086376403, 0.051915457382077174, 0.03787959662957057, 0.01299626890554904, 0.06955535196128391, 0.04895386871911826, 0.040919330091245716, 0.021226794849480354, 0.02565728049845465, 0.015794004768043036, 0.03754160629825727, 0.05808614622501116, 0.007380844420573164, 0.022608591468944665, 0.069359892288283, 0.04053785277891063, 0.029358205295378165, 0.03509965124389818, 0.07953770744103579, 0.016939075430855155, 0.01740293783856736, 0.050882927908171574, 0.12509671881073905, 0.07658022500935101, 0.04484563412505292, 0.015096471179276707, 0.03952693464534898, 0.027155528228069027, 0.022859173083317377, 0.0558575504880038, 0.09040592103115014, 0.027314550844171358, 0.03015582539862202, 0.06738439667969942, 0.05440918848879876, 0.08604852783103144, 0.037850163531519716, 0.016187840036206668, 0.024572837076360182, 0.024482162909642346, 0.03451825562684286, 0.04437191216575523, 0.03412603010093013, 0.05514876594045951, 0.011485444885047694, 0.013809875348552823, 0.08955544086113092, 0.011363050847825025, 0.04278449371697442, 0.14095807898669474, 0.030749097293723496, 0.03256410705826936, 0.08143631080465932, 0.045414557830700954, 0.022162274389918295, 0.07784871339437463, 0.016511985243508415, 0.013170068400100836, 0.07581367743231597, 0.020272710863801262, 0.05048290360718966, 0.007595089048282394, 0.018163456303638317, 0.04167608706460845, 0.1417874610952793, 0.037965272072582476, 0.035028596588921164, 0.014239655462123696, 0.030486193155088735, 0.009388690964589197, 0.014140869381897634, 0.03488605826972954, 0.02791428660613395, 0.04430387206676026, 0.08176927559918935, 0.04554093935556951, 0.04931777197447035, 0.023163053349802093, 0.068503865641692, 0.06094533574557113, 0.03794674040569413, 0.03692726507001827, 0.049473931336955684, 0.03774945744343343, 0.05713469566657178, 0.08552034085075702, 0.006010158470035681, 0.03819018782627198, 0.04428048340243198, 0.005291818890855798, 0.058416303307298696, 0.0221010486430098, 0.05933321862211151, 0.009769752674225357, 0.03436860035083467, 0.006355107273726214, 0.06193450081252283, 0.05753737829265095, 0.043777079366508036, 0.03414772954138537, 0.0566740048628661, 0.04872131123838406, 0.010468525410209213, 0.06348063478306418, 0.034008983357418934, 0.02587789849888894, 0.06014047994188244, 0.0445429872601263, 0.06365032708873192, 0.04503004681018572, 0.0763217699263365, 0.03886093610837575, 0.053279032600262476, 0.08197858614186126, 0.034817125678302786, 0.030926234058795438, 0.025676329274691885, 0.05257473349751485, 0.010523986345487497, 0.011487732615111577, 0.06798441206375438, 0.02660244913591493, 0.07199887366544816, 0.049902607326305685, 0.023463809892775554, 0.09200703713201708, 0.06462915379914545, 0.016787125721513745, 0.03275924114390247, 0.04176443998491572, 0.016611848634877996, 0.05273133719099626, 0.034188799515006044, 0.028963897925531192, 0.06511260890552113, 0.05004971919040527, 0.023099791724234823, 0.03834057471624786, 0.1398966028805702, 0.02707894241827871, 0.01977556385099888, 0.03801176211826744, 0.016360025958067948, 0.028192836175402327, 0.09052585209569625, 0.05189078552047572, 0.014545050667478673, 0.024199660326684677, 0.013799237260114283, 0.04113840442451258, 0.07313635335454056, 0.024081366775076718, 0.05983971382280993, 0.022807278287326618, 0.021592772287887432, 0.08298696469395392, 0.025769698155683377, 0.0665281325458519, 0.02403712519744952, 0.06680506566960005, 0.06923593926213442, 0.016540531594786915, 0.03745686548251299, 0.007221922832315849, 0.026805393487936067, 0.017135952366515994, 0.04657921448890721, 0.08413365275989618, 0.029410946618525252, 0.052245924729974046, 0.018341257649984573, 0.07305265058793368, 0.07550564879972128, 0.021866664042576187, 0.038380687079963186, 0.04067576009659998, 0.03838379356649615, 0.01812298004815896, 0.03960260498006979, 0.013460533509421493, 0.0239437333338203, 0.03691144535438188, 0.057769311411726865, 0.02092059525180488, 0.06636289504146384, 0.032714099412964236, 0.02718719447241916, 0.11518593126487349, 0.07687643290527406, 0.07088362584791838, 0.06624107173974476, 0.017367873994273045, 0.012467222949189526, 0.07222270157428519, 0.012140338019948575, 0.0307050702207151, 0.03847535639520615, 0.06317453286159905, 0.05974143240300398, 0.03515595870633279, 0.026289232172853044, 0.019482163667318322, 0.026985301576074094, 0.043595719541753494, 0.04500860783962473, 0.04695539430324589, 0.048330847714697166, 0.056803190269537514, 0.012353523052297534, 0.09257043351329143, 0.048428857173289985, 0.21256315281554578, 0.15556605803149362, 0.11396442705224599, 0.05527240104011952, 0.15498243692901828, 0.1450541825784791, 0.1668064831004989, 0.11398673553260104, 0.16563470565503643, 0.07503159359217652, 0.05478162596362734, 0.19684483657681173, 0.1046870026977793, 0.21521603868853664, 0.1882287069794632, 0.12456836329112131, 0.13152908413640915, 0.15879914825481756, 0.15010971936487383, 0.13677228182073564, 0.15772972015603898, 0.1469990959571254, 0.16877122283462556, 0.19479368212482623, 0.1185148973919211, 0.10493782754506796, 0.1268097603573434, 0.24467705298335324, 0.15250127732513413, 0.22934642319958057, 0.12844456134424095, 0.1275090071102304, 0.12684139978861617, 0.06886745097055551, 0.13821929933563357, 0.15853382136312225, 0.08933715942886569, 0.2249265708509953, 0.1766145995427524, 0.19288986170243835, 0.18950905440555466, 0.11327987386574669, 0.08700124243454588, 0.12142068421047543, 0.17918231176032176, 0.14824334532022476, 0.12814738051665406, 0.1650326831206199, 0.09885745663796702, 0.11817086262688523, 0.17185137126474612, 0.1467991470088882, 0.11900249703396713, 0.11747739217694729, 0.1928309188975442, 0.11083972294844928, 0.08373747038985453, 0.15649052697323984, 0.16364825498913566, 0.11203475116241364, 0.17130262248458403, 0.2726698444495278, 0.29518464760434243, 0.11424528254616646, 0.135667797538542, 0.18322034588744565, 0.15436011306460828, 0.16521914892138975, 0.11752152650226509, 0.1776300337646277, 0.14432393224729648, 0.11241017254970728, 0.13458182194059895, 0.18815615845303382, 0.08401508533185528, 0.15492179340893222, 0.1097884741161139, 0.1287611012136744, 0.15095016378308498, 0.11612632717456549, 0.12851430598886746, 0.16701283654378307, 0.13139022303925407, 0.10713560356488151, 0.16580784152592384, 0.19334553079980035, 0.12660757443236728, 0.16398642152067155, 0.1139273100923146, 0.1371023737855496, 0.11883953481071419, 0.17823079991484844, 0.16835140665211987, 0.11607609478937042, 0.10292143050220706, 0.13013186233658947, 0.08111526633823112, 0.1613421617977081, 0.11613941961719144, 0.17613913473342696, 0.2667585261646779, 0.08072822339712613, 0.2058856699976229, 0.23540521340985454, 0.18395787405390895, 0.16902444553711723, 0.1563537802787558, 0.12194206066910299, 0.11637735120471447, 0.1941022877731631, 0.26875433842501334, 0.13412252158647583, 0.0921840264251636, 0.1608894497997338, 0.1309957184017666, 0.22485806726880614, 0.14317458585625695, 0.07811971699758884, 0.09654583229172616, 0.15115472458062634, 0.122160840058519, 0.17111384309828284, 0.1710070810851551, 0.10785239373123455, 0.2103757726088647, 0.13588668418026742, 0.06909994333381615, 0.17903114729110273, 0.21006377564082224, 0.06872004033216546, 0.10920351235977105, 0.14496853394854456, 0.16232777987757038, 0.0975392108422614, 0.13631419188553287, 0.19359628669917586, 0.1661648691421555, 0.21048720775833055, 0.13580799162868532, 0.13887197560360356, 0.12040878931481032, 0.15414550119350034, 0.11870277279447164, 0.13897935048707072, 0.08893384478024899, 0.22975375214892052, 0.0851319495949053, 0.10849676560610534, 0.0762577326367459, 0.21039569089489601, 0.15356564924361246, 0.07926134122235161, 0.21880376633376847, 0.18027910451975562, 0.12218316386063253, 0.26755473666614105, 0.15145464800298214, 0.1774770153626319, 0.1107434027137295, 0.21001531291873227, 0.11256257808136363, 0.10440515128955727, 0.19138008626478334, 0.22243784229841926, 0.14343952970399013, 0.12141833232054788, 0.1003757126689438, 0.1672574790615228, 0.1688694506282768, 0.1086452717502271, 0.08734429660703867, 0.2020315276158433, 0.17309963492856872, 0.13878395210110372, 0.17492611111412126, 0.14461153697582985], [0.054622226049222296, 0.020640967413783073, 0.08989281066122556, 0.009275027456873608, 0.02159760821790945, 0.028008482862083663, 0.040961553027192434, 0.04056538214846965, 0.028876035301495465, 0.03604087069810879, 0.04992556315095675, 0.04260072837613764, 0.02063754300076154, 0.01662759174172196, 0.0442652574049369, 0.029322361956620892, 0.050703602046856, 0.052793187299563046, 0.0632261059006616, 0.0312595818972876, 0.059576892038627025, 0.021448429831634128, 0.038841186361687804, 0.055089099182476925, 0.019235217140146324, 0.044820621354325164, 0.0739928319930069, 0.03706285114129705, 0.04890124613959943, 0.0330088785549085, 0.059249741851442286, 0.051284032393126726, 0.11031222544730672, 0.013134848465391947, 0.022635785675036813, 0.08121307278352399, 0.03796221155132498, 0.09548336793217929, 0.01277674258040685, 0.04916798646351503, 0.11375975900239522, 0.0043085723319241116, 0.07162138384075896, 0.12829220177786005, 0.007760346662478462, 0.05434530058635339, 0.03236855928515715, 0.022897954369264267, 0.09207728739467361, 0.05936421836996752, 0.04290212268730806, 0.07952729630614482, 0.03178142758476878, 0.0383470251765703, 0.07835679056663668, 0.039868249798253666, 0.04539749705262723, 0.019012668598142844, 0.026330254265978455, 0.03789933105450004, 0.037527797563422116, 0.004060210936116956, 0.03604475093344527, 0.017124468708531033, 0.12872302664383767, 0.0426138054970051, 0.051317878157621434, 0.047864836430357355, 0.0699983423034991, 0.0593932454414185, 0.015422203146191615, 0.045574256519396464, 0.0667897898763899, 0.023913645230594183, 0.01850106359098948, 0.011528439654578126, 0.027546332660882224, 0.028269711183384064, 0.06704736395829147, 0.06094164320177609, 0.019105146901922363, 0.007128706690104258, 0.02726733493017814, 0.03492038283917693, 0.022272470392166607, 0.042812103525765484, 0.029056117674636266, 0.03448393105739548, 0.030122376084628127, 0.041918358540222536, 0.028291648111095833, 0.04956906796583245, 0.009938166570669461, 0.027260809776283083, 0.04935604955760702, 0.04425137972218856, 0.02448037409433915, 0.04966212083555518, 0.09608388893426427, 0.022388946400174213, 0.07396195098877915, 0.06330101014745813, 0.04494097376722963, 0.07541846799393816, 0.050394060390610854, 0.015020361301609346, 0.031028753860042464, 0.044064128681296305, 0.10030593738080033, 0.045768275947099736, 0.016546484097958575, 0.05194143925402915, 0.09854201993514454, 0.026979349072902437, 0.0445690457408707, 0.1009431463335791, 0.02765241285575734, 0.10419014871360795, 0.046931312329346137, 0.0450712431883139, 0.030176948357914245, 0.06629298951837324, 0.024128553960772774, 0.056195782137013255, 0.051612944582537304, 0.05965729296628026, 0.03203560406672618, 0.01052831953030921, 0.08246716637645038, 0.034349026804369305, 0.06252434254894335, 0.0255988548029094, 0.00743712171829576, 0.033478030799737865, 0.018763820257698818, 0.022835183039968534, 0.02308460020069634, 0.0477073479053234, 0.04989906033921627, 0.05413345429265211, 0.03805599986545501, 0.0727408834462685, 0.05130842463263581, 0.060098437036597924, 0.06086018124234773, 0.06423279905932085, 0.013842948321853916, 0.03459727759623239, 0.03308282519179968, 0.012707647195296183, 0.008405730252214258, 0.03263913770957339, 0.02620627251153271, 0.036493885300813184, 0.010005649340699517, 0.027267463249905456, 0.03425548746881466, 0.06748127615860394, 0.0374172434150692, 0.07005970594623397, 0.03158513479115021, 0.018484690376827796, 0.02508713105212777, 0.059813908151080536, 0.08166282768211058, 0.0035126620411662568, 0.05969064077362419, 0.0006666892131174645, 0.09937786782581, 0.009372175066551615, 0.03967906055491298, 0.024326319558425777, 0.01606911172970168, 0.02921149562743883, 0.033887401373396, 0.03725794692253394, 0.10771840495327789, 0.018810986375976956, 0.033379925580154506, 0.016656343021520203, 0.06547656195658831, 0.039889512568592064, 0.04685384168800327, 0.06625394967775192, 0.0679471189036004, 0.045427290212002494, 0.01353413349152693, 0.03941866726945004, 0.07911997501768413, 0.03156468215879173, 0.014963220718557076, 0.01787868801564459, 0.026055154007589145, 0.06357070374032182, 0.009392329882229529, 0.02462156218356423, 0.06108952115379995, 0.028302442289948947, 0.06378187587664974, 0.04084005531284117, 0.010732980876890643, 0.026751248308667736, 0.029753171500840017, 0.01860152644615981, 0.0696551808786969, 0.057850512901260975, 0.06939439688839259, 0.05582474277264649, 0.043524871730516036, 0.015763571925250994, 0.046547318418179794, 0.0022552821704471906, 0.022347644684956442, 0.06396522753000741, 0.011691372191924001, 0.03842947155898137, 0.10463045774808816, 0.03203310662009303, 0.07149409067126052, 0.032243637157784354, 0.04382689423378437, 0.08535865799433763, 0.04301399833733036, 0.04148040522610949, 0.07342411896153804, 0.0686625607552067, 0.04003376692473408, 0.05820714598221164, 0.040837144178728906, 0.030384548609295202, 0.04084509617138294, 0.05207124136147961, 0.04251031467931406, 0.0572426719290595, 0.00561832269135442, 0.054155034989479094, 0.016376812859708746, 0.03223154445989959, 0.1267427736292443, 0.043859797710132216, 0.02381238181354298, 0.018527001412885807, 0.025311822725099423, 0.026334550104013858, 0.030714380104214917, 0.0706375967110357, 0.03613149123867193, 0.05967307437752044, 0.0549313846615053, 0.045153896414464524, 0.05671261569424983, 0.03397480817511678, 0.0854183592262768, 0.024579783578613595, 0.03920995044491945, 0.10685634153384356, 0.038651713665815136, 0.039582384089308406, 0.09602029597566974, 0.01805073795689931, 0.004769180781177936, 0.02255659133586432, 0.02389050937528091, 0.04872648616231257, 0.04094034005256911, 0.0380929904208789, 0.029040160063173504, 0.05850219708536902, 0.05176087616071586, 0.047602087424527255, 0.037994574935686205, 0.056449981601608384, 0.0855776442274932, 0.03612106095158285, 0.031961174794442715, 0.05941333226679314, 0.02583794126797828, 0.042285061846937866, 0.016527699622055216, 0.04039075623656954, 0.032038886753481724, 0.05333940032869578, 0.016433122237363172, 0.002239532839138842, 0.02810562472610224, 0.06256667273719946, 0.008603567670610164, 0.015266384692832589, 0.016255177249531114, 0.03392576705664396, 0.05203980877394638, 0.02046305689990761, 0.03849015338346362, 0.03281105167022155, 0.010004265594386287, 0.031165713143925515, 0.037652145124851696, 0.04263288108631969, 0.06826252496290593, 0.0328317130615394, 0.04077023788986187, 0.04622830791519054, 0.08782093353088825, 0.06434683507728962, 0.07301838347508062, 0.0069033729396910685, 0.04329743554755565, 0.0321786958844431, 0.04904308348834034, 0.01960216942543705, 0.007872841886109523, 0.012920794880858833, 0.019050879148586143, 0.07453084788134984, 0.02842217034119512, 0.04161360876394376, 0.05408918590194756, 0.10224541153518424, 0.018250386215626233, 0.039879534273378314, 0.036935795459055135, 0.014484486629014776, 0.01984668936910889, 0.06489641123240994, 0.08124696451329416, 0.013923170176454851, 0.016701609241746126, 0.05133458653524999, 0.04685661492628917, 0.029289393362799482, 0.051778009717142394, 0.031963526684370254, 0.01976477158736558, 0.0224027608806688, 0.038790099788457155, 0.03963058251106451, 0.032339869292392846, 0.010207472331521493, 0.02894036945015673, 0.06169784093095411, 0.047617807548733494, 0.029745682991380175, 0.028660036811244585, 0.09402384020147786, 0.12591929039767674, 0.026554708451693578, 0.029060164534096277, 0.011530730257471724, 0.0502455389247306, 0.021519352336444204, 0.018440686286457123, 0.09068413352173182, 0.24148599034355533, 0.14467838580810255, 0.13547642877505672, 0.09503103897816713, 0.11354277991960127, 0.15383854508399963, 0.09909800058531185, 0.14707152190948689, 0.10383452303827771, 0.12073803092202834, 0.17530550849774193, 0.09270794629569977, 0.12224022208923295, 0.10193986502746422, 0.06736332160090247, 0.2215597369978505, 0.10430929070759205, 0.18527851770481757, 0.08465019520372154, 0.08297206428382667, 0.16181174305177506, 0.14254032634198666, 0.11716767049003994, 0.14811343213002529, 0.1096464260931938, 0.23120680643666178, 0.12275065881230178, 0.17951396654450125, 0.10670684713629947, 0.14681183342491427, 0.15408968402733728, 0.21013545082701793, 0.1739180006928021, 0.10521103748150411, 0.1209351070405495, 0.23229855833755386, 0.1082802921413414, 0.19543515818734325, 0.04843573664285002, 0.1592837601539589, 0.26214554305038146, 0.17648087123469, 0.19951716576132084, 0.15326679834435064, 0.08417642344870875, 0.14756598569933446, 0.11852141680015672, 0.10109329190585883, 0.12814034782950917, 0.20235893827292228, 0.12033479288220407, 0.11364784887841634, 0.16632372513413432, 0.11748035693721426, 0.20516021537684626, 0.1414562966073713, 0.10208690028277137, 0.1719003855701416, 0.11460392660791836, 0.09293742027253875, 0.10330702553713515, 0.13475719478822526, 0.20500915815993664, 0.08823875022391159, 0.16619382726569332, 0.10375584580845411, 0.15649163013985082, 0.19232632742533762, 0.12789306996930994, 0.17949640780927675, 0.12656502590905275, 0.15568411218062525, 0.20892901556386104, 0.15541133891430595, 0.2275680113703974, 0.1846799119225433, 0.1971743156712863, 0.08866144689701258, 0.14723543408176593, 0.15165937733986687, 0.11579474133829917, 0.14259721603124373, 0.19149358985164475, 0.11268217206722307, 0.14021367135067142, 0.11845066091947018, 0.06585684034132189, 0.15165620573586033, 0.14090111268864525, 0.14904841179809264, 0.11170626798224066, 0.2605427951822358, 0.15260594025734933, 0.11091661519340931, 0.12460541896401875, 0.13114315968367363, 0.22753790411497318, 0.15622443399362027, 0.22525529917930404, 0.2193899614916694, 0.16910234135725807, 0.10743982474049253, 0.09265081145830693, 0.15604719189145874, 0.08921383459481502, 0.09574095733583936, 0.09181523935929423, 0.22068123333156112, 0.12875267424650733, 0.15176621596178702, 0.12832643824719614, 0.2410556021476946, 0.14700032169780425, 0.1470055923827233, 0.07199927203116879, 0.1485026967261107, 0.1764197680618494, 0.2934107863374295, 0.1354584716741116, 0.12309522217800542, 0.10707003409944235, 0.14374245619100912, 0.0793002508280258, 0.17296592194226482, 0.20761655373198373, 0.12223688194588309, 0.1750643746626954, 0.0953159394163278, 0.13610046867641712, 0.21412797933143957, 0.14274946834531524, 0.17423350634353776, 0.1465823594480753, 0.11078862488389978, 0.10663819033652545, 0.0629566268124167, 0.09767653210268867, 0.17765395102962372, 0.23270090771538599, 0.08230079506193438, 0.10938337448263362, 0.24179584226540982, 0.07692949981578896, 0.139078589516782, 0.1786839868873358, 0.16928987968112194, 0.13890171513682412, 0.12717009747340796, 0.11882641938545051, 0.09373353118257177, 0.15951338734838272, 0.19095202697621239, 0.1322061066786128, 0.21997922100126746, 0.13301981462826654, 0.07045242559885787, 0.13326853273376343, 0.2606125398268623, 0.09099940168521098, 0.1860865106385562, 0.1222291904231233, 0.0867512756057324, 0.16960881740575837, 0.1344963878152832, 0.2096305835631586, 0.09329863072883698, 0.16612916944488404, 0.1344248352031554, 0.28317395177099014, 0.1414641873129914, 0.16977652937414187, 0.1311907643872884, 0.12736747236621956, 0.27176163189353486, 0.12695553922845473, 0.16605239211311265], [0.02572799807474498, 0.029022840730425332, 0.024200499192961765, 0.09118844154140643, 0.01688935057890992, 0.030210102728057294, 0.020894745530019847, 0.08193182413496318, 0.020678662770097295, 0.01728214875554606, 0.06871452449911064, 0.055792521114551255, 0.013842132438214557, 0.09669204783295432, 0.021014868116547025, 0.06944316604565229, 0.038783381197361216, 0.0353289911553504, 0.03393424381952613, 0.03416635313882463, 0.07584649663899215, 0.07897474006899903, 0.047686303470043406, 0.021820325299256274, 0.04322976317076434, 0.0021204772694487007, 0.07101827346148991, 0.03976241858195394, 0.0227902730506274, 0.050576737886595155, 0.11012588988148397, 0.027585609988760085, 0.010754259926597438, 0.00911793633995037, 0.016425921010874932, 0.06292598712588511, 0.04439975180092358, 0.014242506266811924, 0.0176944017350193, 0.035160582046955824, 0.03939027605097621, 0.015164611827311738, 0.012692831054840599, 0.07853290651954951, 0.022575818227543946, 0.017770411063646598, 0.07570270959648394, 0.03838470138068642, 0.055732341077659404, 0.031402779052094106, 0.02383685640750393, 0.030695419428088976, 0.016197519557129954, 0.04619780612448531, 0.03543029096157801, 0.056310863864998666, 0.023479692810665698, 0.012892180539277053, 0.01626137107039892, 0.05407535035403506, 0.010730005582914719, 0.0632148673908124, 0.10454198991459225, 0.11206851265723668, 0.03133390583248148, 0.03205778997301335, 0.055025180636514584, 0.036037553537396655, 0.02312286820773396, 0.06510164618732468, 0.031059347581298604, 0.04047213775676586, 0.03011121609879117, 0.012042185877479855, 0.030379802694604285, 0.07128392977099265, 0.022303374379032084, 0.0017026046759471478, 0.007076234455340572, 0.0179325248445234, 0.05412711874551831, 0.03821601265019948, 0.05232757821138348, 0.01616339225532307, 0.018827288727005644, 0.05845069682465927, 0.059266523007423653, 0.018146594708424904, 0.0685152114038506, 0.037696271789290255, 0.04321537986998597, 0.03088977976491855, 0.03291402920900333, 0.06343684136687268, 0.03472266320679938, 0.06802957294689072, 0.053622136568470355, 0.07988981677279358, 0.0491019573453213, 0.03788037420881372, 0.017319641098560348, 0.04906019789256877, 0.004349877877581504, 0.04061150447195096, 0.02372255034354185, 0.05841213195855099, 0.030617136733546376, 0.06844134520619147, 0.031088600648687254, 0.07628788585744559, 0.04910892491499263, 0.053803048231789184, 0.03211338497367838, 0.06648336236755695, 0.02463707546403091, 0.05719140915560627, 0.07216933588947981, 0.029647786530756184, 0.019823971031714353, 0.023243235942396908, 0.03382700300144573, 0.021688025745172656, 0.018753487646820086, 0.023299171852188248, 0.06135002935245153, 0.01520164355996155, 0.018223186263874657, 0.020988349983048056, 0.018312500624526894, 0.05238114307904917, 0.025921824065247373, 0.09769841923468536, 0.014087861843196856, 0.05833851473946726, 0.003688766742162707, 0.02676595145115449, 0.02072907518595457, 0.037836044531075225, 0.007041952978338927, 0.03520352127511175, 0.03179518077822943, 0.038850647547552665, 0.036042705478687445, 0.06641870454674767, 0.02821813239866207, 0.028236930281104102, 0.058326981285767215, 0.05178571273122103, 0.031697761207338304, 0.039377451739123756, 0.05183964532109038, 0.030830107261276538, 0.03489515173339075, 0.02093960380842609, 0.01034399590289761, 0.03694013151670656, 0.028872340842480623, 0.03734527711546229, 0.04492600823962881, 0.04476851588415523, 0.03102150666827877, 0.03441010699457219, 0.07510198941153866, 0.025432414540480223, 0.031287365991081444, 0.013375886539447934, 0.04148458423573644, 0.004496212162437939, 0.0372032635664988, 0.018997038489267714, 0.055251348943960284, 0.011651221523812462, 0.043516483067745165, 0.019584819449171908, 0.1103229047129712, 0.0462209458102382, 0.018530052358044252, 0.016003548967531853, 0.05406654034290583, 0.05171447421514219, 0.023196297735276244, 0.025869528988316178, 0.02707470978249706, 0.11550392670136307, 0.019217411341566234, 0.00817533026659681, 0.05899026787148849, 0.024755393913496408, 0.021874338328357668, 0.01588121334451341, 0.004634668669408007, 0.143993319342694, 0.09349770633684051, 0.03325153690492434, 0.02836554878271155, 0.039172925415538976, 0.03345258901977251, 0.018134243455865694, 0.023381032177337238, 0.07165758915606045, 0.035302281499870365, 0.019562283057659384, 0.02238968184458152, 0.04251188132911921, 0.03945195762019965, 0.06334042537116236, 0.034719503094111724, 0.018257321226560784, 0.025061311973859707, 0.020636932045641928, 0.04932432202622295, 0.021960019517029007, 0.03820556321091229, 0.02922976490921311, 0.05671436620515682, 0.02116953360758001, 0.014791514559258378, 0.056783049818008184, 0.03179628777528002, 0.04896913685144917, 0.030305300643968008, 0.04964409095625724, 0.012810525142647808, 0.015561385042664987, 0.02562436744600775, 0.008974805260227333, 0.053032616588978045, 0.022111628317244114, 0.050263338977651256, 0.06426655672370427, 0.00699174453339149, 0.013427489264417562, 0.020401455769916216, 0.003982946180903744, 0.03254472503378507, 0.0417698409047819, 0.03926114810089912, 0.022579056864243843, 0.045888306603076, 0.10765255203530674, 0.010372295190820531, 0.03875414728217068, 0.019099144603035623, 0.03941116726867134, 0.03848043555814413, 0.07642140732176843, 0.06004894009581017, 0.005899768551781533, 0.04910181178861568, 0.051271832442932555, 0.07030722129368974, 0.07147220353926383, 0.03698478295137325, 0.052760774119486736, 0.010552127627776036, 0.009280159288356382, 0.014592097084518644, 0.03327030988950883, 0.025562433067769296, 0.017173785618656588, 0.024353699540839564, 0.08852921246040253, 0.05451022782513211, 0.05110503594961859, 0.01241544689682703, 0.032272074341533646, 0.022240371308139256, 0.031841211171159824, 0.02277191375352202, 0.049034457338312944, 0.04595151268726876, 0.05740023323244626, 0.03204190513990339, 0.07968634382010469, 0.01004252881337438, 0.05429466217455845, 0.03158263925973687, 0.07945115482735057, 0.02953687615151848, 0.04323332931005186, 0.025243104638291464, 0.02169093113362549, 0.06457418699057833, 0.004434937098619318, 0.0099415383151462, 0.08026944398279152, 0.012929023622775511, 0.057603434223922036, 0.03818776698843126, 0.03068270045332611, 0.04877531277616659, 0.03169380819364902, 0.048826751749842405, 0.01972934959696666, 0.046891763040255156, 0.03919066801186531, 0.05165866087941874, 0.008741629163494274, 0.016633831527865222, 0.037927434990002264, 0.042841440862825805, 0.049997870359689965, 0.04839936661864481, 0.05262482415644392, 0.05707553835705884, 0.03580378563774209, 0.03420458475668584, 0.01926815317523095, 0.05694706541215701, 0.08677655650723366, 0.0508861186643762, 0.02808284893211338, 0.04625145143138305, 0.04353332551076047, 0.023861371221080906, 0.021975228277545784, 0.016616684564900015, 0.014744923964533356, 0.0045109971805715994, 0.011140809698601165, 0.06543032855035798, 0.019660698542852077, 0.03623132398652454, 0.0993310675145157, 0.029950075249578205, 0.09448504811453243, 0.015457380946064669, 0.0350907607935369, 0.04151491365665871, 0.06136984421661305, 0.02596505249159471, 0.03272259149760489, 0.0374054494914749, 0.03258731952237506, 0.06134243742112191, 0.03850391615302332, 0.07090295424624797, 0.019745512136949167, 0.07799892791456754, 0.006731448924138903, 0.03226882229829508, 0.01804278787946509, 0.01331584056794283, 0.01213254116009921, 0.07805487531567774, 0.02174673297803008, 0.06753025982048243, 0.010183094456160982, 0.043375369672092705, 0.05774513367683657, 0.022639667825593103, 0.004440116331792407, 0.06699971328940123, 0.09259258111518237, 0.17805584075470127, 0.1916213120303808, 0.11125975363557378, 0.13634609178669993, 0.1438488351601747, 0.27089442036324934, 0.0866662092026203, 0.07092491032615786, 0.19389359010083063, 0.15377442352473736, 0.08405910474398444, 0.21831909314759318, 0.13082820561624345, 0.26815458351085264, 0.14384662882695276, 0.14582370257666036, 0.09061340062368302, 0.12628726541034638, 0.125645651452003, 0.11037031023372566, 0.16274819360865703, 0.17637181095778945, 0.14182411074157686, 0.18647834929006715, 0.21765697867639605, 0.11389277484868804, 0.1778102789314524, 0.14334632744712217, 0.24969215564910444, 0.12411957366331933, 0.12957916054273808, 0.11983237709970244, 0.07674072809036701, 0.18547478943101822, 0.11868775747115574, 0.06363193714810957, 0.14629037269661505, 0.11573229751159107, 0.24140784937527873, 0.11548500432963334, 0.1744222397645635, 0.17181718842156474, 0.11538385008011134, 0.12852300108680803, 0.08797629616193234, 0.23294479946695992, 0.08973557877564624, 0.09395717523030697, 0.19804975498587857, 0.07938685706786572, 0.12876949753732453, 0.1162915723398328, 0.09083823210770085, 0.11638722607805846, 0.09225472867969545, 0.05433872755196306, 0.11769185083047037, 0.28223671980442544, 0.08895744794919606, 0.19303307417900334, 0.20094262556202952, 0.1485032329876577, 0.12498069479460679, 0.18638064243620445, 0.11794162613730277, 0.14940228313207626, 0.15069819746478913, 0.16439676885643315, 0.13564447782212688, 0.15821869875634872, 0.12435236480087043, 0.09775658829077598, 0.22378845530892574, 0.24669108281452812, 0.1672332093960816, 0.14981327398169428, 0.09865149389952423, 0.08721477412168058, 0.1504268031567335, 0.18517773117749922, 0.2786850749004272, 0.15721549129774495, 0.16639556885967333, 0.25738832090170155, 0.12999562126013542, 0.17112401674591726, 0.18570908976178016, 0.11278947034189779, 0.14514663406918127, 0.1005957790860726, 0.23174150516429257, 0.19506221126404502, 0.1266745151951909, 0.23303104564547542, 0.1376664596459558, 0.14628159332900278, 0.11514280817561573, 0.15756951584931345, 0.13366555013964254, 0.15429012327184602, 0.08729520569285078, 0.1074160147278059, 0.17349622332521025, 0.2518606288058143, 0.13139394622656608, 0.24578670069815653, 0.12290613635653451, 0.28085328758724276, 0.14893530657695186, 0.13736137279099034, 0.13638926850211236, 0.0961786769931355, 0.09603426175852937, 0.11254777726266654, 0.17002442010468052, 0.05402795249415983, 0.20214014356174778, 0.1351309537647232, 0.1107906167125029, 0.1486906027721782, 0.125791231140254, 0.12602880266645264, 0.14894992353454714, 0.163272580792827, 0.08833868639363397, 0.12863607566443183, 0.2568521972505316, 0.11619583433193546, 0.15199519964235444, 0.17660290904102788, 0.109101346874189, 0.11202895953770607, 0.14100566836855105, 0.08465937293705442, 0.10835797345686345, 0.13619829810434772, 0.07018804865618868, 0.11849002251701972, 0.07903591985063207, 0.08249649222219184, 0.08568758550550669, 0.19281958079626485, 0.1958742031767484, 0.251324842233331, 0.11177126288173661, 0.17422892513775057, 0.07072281633173266, 0.23304206198982655, 0.10721101726014769, 0.10712264901808194, 0.12761629772402588, 0.20760458743860646, 0.15055973473335468, 0.13720476909750892, 0.1787445384768709, 0.11619270103232515, 0.18036093803182726, 0.2649951143370521, 0.13656804278012247, 0.10889990405449945, 0.24036983088139566, 0.1625431271930856, 0.19533051057688652, 0.16547978735498844, 0.1089945005913896, 0.1752616576249561, 0.21373958807558785, 0.13235808320103154, 0.17706144330722673, 0.09312200149701488, 0.20779794803069485, 0.1408226193199235, 0.2138298332330681, 0.11534065804294041], [0.06155842825049355, 0.026900267731698773, 0.0769894615176224, 0.05080573688892107, 0.023581944481139223, 0.022592970936168588, 0.023236308592341604, 0.05080569092364562, 0.017573300471168854, 0.03644560260938541, 0.0854844189879875, 0.05634476325564808, 0.03362345727040403, 0.10948802209309033, 0.03329740258895102, 0.04632144122414532, 0.038380035905227546, 0.024709357774906585, 0.00799266713476109, 0.02932344788625356, 0.04111068736341211, 0.024523993225527868, 0.043571250693451975, 0.05434613179175123, 0.01332619041579986, 0.04107642791143829, 0.003932156227341283, 0.04377601450429328, 0.08819632427466494, 0.056198486427385966, 0.04867627292931561, 0.020697690478916612, 0.014177120662474585, 0.01653262173696872, 0.05638939553811666, 0.06474021356552839, 0.018045292986977487, 0.01841010980217928, 0.025662459252822786, 0.039218588086265715, 0.05694970841549578, 0.02412816134071158, 0.04475805495354918, 0.022019347281105096, 0.0581653482250629, 0.03998481773681218, 0.084423448499893, 0.038324984826988755, 0.053533013729799184, 0.05082133826949904, 0.019606901933589292, 0.11637715202185417, 0.03810866457980968, 0.031112004634774024, 0.016760822092633576, 0.021883705668451808, 0.08308713835093283, 0.023648145969115922, 0.02511490748504237, 0.12360414970786342, 0.00849558374724321, 0.03838388932748668, 0.04588441104598103, 0.042967040978011586, 0.03348989750168497, 0.058657157520252856, 0.05347212123113775, 0.0328803941186878, 0.06740330372967067, 0.03823557470534598, 0.03589273227619068, 0.025306864221009518, 0.10790470987558366, 0.02678647111620634, 0.003537699470349077, 0.012980319912575427, 0.04176741240606193, 0.038919277534249334, 0.06643237921619607, 0.004913950331449028, 0.06361192310108774, 0.07136325817555189, 0.045037018210296674, 0.029180718045080864, 0.035955095663666725, 0.06089533701719296, 0.050461150540579716, 0.037193258458207694, 0.11578752479005246, 0.0275508200208987, 0.03567054762595123, 0.05016878457559694, 0.055060891825104916, 0.02036420665981789, 0.03765113005835203, 0.023539037811720086, 0.04769332849630906, 0.021175202658219684, 0.09356599541441088, 0.034078586275779435, 0.016237239300784086, 0.04774581701044114, 0.03778537930620294, 0.025502862070777246, 0.06091707859248404, 0.0698139449401248, 0.05164292926389364, 0.021821315467898405, 0.0093723512667742, 0.05984924395658797, 0.02747142266842627, 0.073185145494438, 0.015318086051622467, 0.019171229646270795, 0.10453528664525479, 0.027698345572477388, 0.01949469495053974, 0.0597592247950454, 0.11169992477422762, 0.03578471004842751, 0.05578829613964885, 0.031884510460640156, 0.022136173774338058, 0.05232165252128917, 0.05193088639287218, 0.18109972258248638, 0.04010062724832566, 0.07120788022274933, 0.0586063007733995, 0.04925013407163563, 0.014716838223619327, 0.02745880328509356, 0.04787723939385145, 0.04206360114978687, 0.05915763126986642, 0.03113898625146718, 0.0248210035985516, 0.02215070454704185, 0.06331407194656712, 0.0530478579082316, 0.02738410013637716, 0.04293396513188078, 0.030559864000327168, 0.10197596309045631, 0.06584610744950271, 0.030666484287188902, 0.021023388929484833, 0.02368144398074477, 0.029851688492682674, 0.09129613052092253, 0.04167939273400172, 0.08397917879084427, 0.06045756373374213, 0.06611807632350153, 0.03719241576149099, 0.05633195426555411, 0.01240651814206954, 0.023396160498621966, 0.056950662194961504, 0.026930625880918196, 0.037314143302219535, 0.031416074508019996, 0.13667901827683374, 0.008664995473208688, 0.05304390489454231, 0.01710797483552127, 0.04621689703555838, 0.055144429882808085, 0.08804036409503992, 0.0838692068693138, 0.022792228490054127, 0.020724924904624784, 0.05752029836237912, 0.028876525597767006, 0.05598993048131947, 0.03295788008178915, 0.11940334487946765, 0.027188922000688412, 0.10556326172645054, 0.03090526240186826, 0.02550710236743814, 0.06939042855294482, 0.024055089959273898, 0.021373100406039628, 0.029061905468904206, 0.016785377125826575, 0.04682807049023048, 0.017492861239119403, 0.058221533113429626, 0.027510035415029818, 0.02002144168551651, 0.05570449378161181, 0.023600558502479427, 0.036543788268200816, 0.03559765052951632, 0.03633374611156122, 0.053302850273828355, 0.05016432977431724, 0.05554992788200898, 0.03735432844428766, 0.04899221525016812, 0.04788530246925451, 0.0155396779413305, 0.036325211892084736, 0.03342284948655194, 0.014518658938487212, 0.043973504310293544, 0.03538531010910388, 0.012420664913201285, 0.10225620571403735, 0.06072243097268286, 0.04782927845935187, 0.011956955723073936, 0.045937623513201555, 0.0203381500942933, 0.046296646788475976, 0.07690676998707556, 0.02523052738979459, 0.10053610083677116, 0.03820668552972136, 0.07701107285796635, 0.07566052879537306, 0.02800194621686974, 0.018223358633657618, 0.052633086414707285, 0.020713203759383292, 0.045525563970929196, 0.04912629978911531, 0.013660302426996491, 0.00643278619522349, 0.027940996261613987, 0.027373715814563538, 0.10934463341630275, 0.0038610017415316358, 0.049827519218407335, 0.10897493470580348, 0.02136266820373074, 0.01861210037473469, 0.0564587188343848, 0.053123773391088175, 0.06490829325611554, 0.06040459258421775, 0.12516057223922786, 0.015371970760996546, 0.031026729472702554, 0.044724442845871376, 0.0347321703579397, 0.06783063523471355, 0.09581893742565187, 0.05924190094153728, 0.03452616548466106, 0.005748922009051087, 0.00590559704447045, 0.0499136351619757, 0.025729080173938025, 0.02949728089715204, 0.10332562615193668, 0.023852557379512057, 0.05931081821120555, 0.04329734744744436, 0.0066967523232432866, 0.025951967709848, 0.04665614503826346, 0.0316557202172736, 0.08873476151136622, 0.05186474236148981, 0.037896186263570865, 0.022457026718785206, 0.11422260634360776, 0.04632620246059472, 0.018768342091671882, 0.04483834862889302, 0.010159054617097062, 0.03540481087721644, 0.08366120633699241, 0.004872676386918512, 0.021868843562720765, 0.02932755028708808, 0.035196637975112084, 0.026019925454391107, 0.024480113624444893, 0.03497967804451624, 0.02034301283739267, 0.031992009833395, 0.03295048350288022, 0.05081117994362309, 0.04544954889664247, 0.07428651179877982, 0.05818900502016468, 0.0412572629659647, 0.009711893883744075, 0.06407614940056397, 0.0914786050036069, 0.03432578369674664, 0.04268762572938877, 0.03677980080547352, 0.057163554198679425, 0.05806608238227426, 0.03391239882236527, 0.003016973468249724, 0.07887641268391764, 0.09270554077961753, 0.06373548925283455, 0.08139500334378212, 0.03133349022978256, 0.013608787802138157, 0.02571044125474028, 0.0843998606527044, 0.03960584170154987, 0.01002648405941023, 0.08099504416027377, 0.026130161676255446, 0.011484177967142916, 0.021027083388499675, 0.03046694902643081, 0.03133793353974339, 0.03426671065690537, 0.024665501156461336, 0.08069831532456222, 0.024101710239905986, 0.032018698421457124, 0.026403486525880236, 0.023796190545263312, 0.11128408458804893, 0.04080946159158503, 0.052264931371375445, 0.04703043644586879, 0.05540760406743615, 0.034483567165631446, 0.017816387830422293, 0.05041510482589084, 0.022938729399034095, 0.03114725617060979, 0.04299583439264567, 0.04622605178625353, 0.03479551050751921, 0.08330662254123919, 0.08104717644352107, 0.10486652008107594, 0.03766559762880206, 0.012136740279534172, 0.045484651045332995, 0.05707133253435454, 0.01997954050649799, 0.040684256011680256, 0.045340833359307824, 0.004443935758899897, 0.04801628818254798, 0.06522627337084663, 0.022140084653191512, 0.038110085672909216, 0.040123659681769154, 0.1455526759908084, 0.0906547387280772, 0.18557856370124126, 0.08972031830419457, 0.1003022448370053, 0.17916090726371736, 0.09148768314550962, 0.12502795475865566, 0.08315309852121339, 0.13395081063912762, 0.15237999028496205, 0.08332697749738732, 0.1056411958509876, 0.12863417576637962, 0.11862774980404686, 0.26318160035917837, 0.13573679141700268, 0.12739217104089837, 0.10500892050444119, 0.12775779416364047, 0.07320693303500453, 0.1130235331854032, 0.18291021817393843, 0.14939771724804757, 0.10486283519816016, 0.1416054692479872, 0.08933334431100277, 0.14994013814195511, 0.18422035109852591, 0.084893251919458, 0.14059692981743044, 0.10942789951279279, 0.07164049773446976, 0.21553073228607256, 0.20092468378284287, 0.160495282240933, 0.13082478886410115, 0.08520866563964276, 0.16119640590923448, 0.29827872351292645, 0.16114598200205835, 0.04824797998392775, 0.15654475067652043, 0.09721939977739127, 0.20687472015138597, 0.14331395257144205, 0.17523156569129036, 0.10858140299997984, 0.1415556275676335, 0.06931120740069498, 0.17259760219002926, 0.15858098173574095, 0.10954695723710522, 0.11516462635969925, 0.10478564417890965, 0.29496772214770317, 0.21354843381672137, 0.11236403107402787, 0.14571242064477938, 0.3387208727578963, 0.1483210419575053, 0.08233537627083641, 0.14595589870887418, 0.13806301739908036, 0.1450728291585561, 0.20910659474470925, 0.2228827555213244, 0.15486896398567385, 0.11607470817022747, 0.10902957209656317, 0.10697371386472257, 0.20887690626325148, 0.202650434728111, 0.14563928989152755, 0.11416368652135135, 0.1206546958776251, 0.3303333131536361, 0.1914853467455795, 0.16865977236340124, 0.0865913087862634, 0.2916572110787515, 0.18739402354244264, 0.16493969536837072, 0.1998680340306413, 0.1490829470417192, 0.18038073374379068, 0.1146909848396336, 0.1751039814083807, 0.16072012904670932, 0.10870347911071394, 0.1705177347626417, 0.2326952386647463, 0.17251521709465212, 0.1883262452939826, 0.14428734388803283, 0.1446926197217357, 0.13126055499719036, 0.07736150445716997, 0.19901949972394975, 0.14395810994169406, 0.12561494664799783, 0.13739782325442762, 0.13680894678879169, 0.07136011721506234, 0.20174442850533994, 0.16291264204248307, 0.22454927254828716, 0.09837019407460768, 0.08690915100516812, 0.20687925539189772, 0.17385151958273304, 0.20562636455701244, 0.14436220599999353, 0.087405169953502, 0.1632317023411874, 0.1281212722401946, 0.1630399352119815, 0.16034384198006124, 0.2873194986774076, 0.10361408123806601, 0.15714363225044745, 0.19415664937227003, 0.13056660191186015, 0.1286445179533574, 0.1551221100793731, 0.26292640114984206, 0.23077997288876967, 0.17757915020469697, 0.09946864158395799, 0.15209230894763626, 0.06619776478938519, 0.14628537780334874, 0.13474673002717957, 0.16293093622211488, 0.15603632876469245, 0.08163013104950229, 0.15253585853403615, 0.14100404426215157, 0.20150847342466155, 0.1913976296782494, 0.1920995807215091, 0.09606142723632437, 0.24132010166443166, 0.23548450351001757, 0.09491992558562949, 0.14827087852022341, 0.0833550546198122, 0.15688670168240226, 0.179812373112767, 0.22781867533922198, 0.13860954452426205, 0.17542075876507068, 0.12993104004811856, 0.12882571306920823, 0.1802119339305547, 0.15261931615250726, 0.12783788099524476, 0.1301840942112669, 0.10604105544306579, 0.1173555841969867, 0.11315372982813467, 0.1668970806584243, 0.264404307329847, 0.20333508750604046, 0.3607342560445109, 0.08567627804774432, 0.10057157836854459, 0.14689051065473788, 0.1808559687267388, 0.17300856239613027, 0.13705495294303666, 0.20679936774315374, 0.23256077491227659, 0.13238489627838135, 0.18435579544353872, 0.1514626766044286], [0.021617229644870086, 0.010743975196213973, 0.06070022591419759, 0.04154987024864362, 0.03908710441582146, 0.06838118432149773, 0.08599531536381091, 0.0474021652893674, 0.03646595373509392, 0.08968853331621617, 0.058744097008339824, 0.025169954732841542, 0.041363569156777476, 0.05216363156514783, 0.04211757970493167, 0.026803397828893318, 0.014253432595831974, 0.02997956005856395, 0.03889105102467922, 0.026823408045475523, 0.016142361226581758, 0.0237453242223109, 0.009778081965182098, 0.06598470807676354, 0.05488936473885852, 0.047666779719293124, 0.02868744935239515, 0.007468032887235525, 0.054657803172425884, 0.030297478886261105, 0.03437421577531965, 0.03822098073038844, 0.022284335178893902, 0.0046901248166367655, 0.02110422269681529, 0.04381160694925536, 0.019909324717798063, 0.0017400661360419867, 0.020672128040103183, 0.01481804035363659, 0.04104567714215767, 0.049091461940758654, 0.04328350423865261, 0.01740391268545101, 0.056911197175542196, 0.022917098906492035, 0.011326049758692183, 0.052483706930351835, 0.04697805135360649, 0.026099236621972055, 0.01289725012611598, 0.044832687239132585, 0.03309156625501571, 0.04689688433802897, 0.05168931971814844, 0.05933807561955145, 0.006852900673214707, 0.06595162073931386, 0.07032553079508005, 0.022150777325394656, 0.02087344254006542, 0.05399414886450095, 0.06893449898568854, 0.022206477663149277, 0.018356014418626027, 0.044198584772886775, 0.05759688800260906, 0.05145208527063651, 0.03497703121073785, 0.05163556332850168, 0.036009767528383, 0.04935930926172484, 0.01709540333268383, 0.024972543450853518, 0.023664212748107892, 0.027527314528161963, 0.03691479315861099, 0.022851732454352805, 0.028514468614312432, 0.027166040869609966, 0.019342272181905085, 0.021180603578085863, 0.03679300050040887, 0.024441376388553652, 0.016183768278889118, 0.07231319954078044, 0.039857145353791215, 0.022057142228849476, 0.01004283333332428, 0.021883401148501905, 0.03386147695803835, 0.03936971808152814, 0.014316411726477166, 0.010292839424143876, 0.08129165808279669, 0.0037258456371003583, 0.03536744876914928, 0.05389428164269175, 0.053560309442541296, 0.06631747368843326, 0.13313924773566185, 0.0362310481948718, 0.025867267113719738, 0.09192688901337887, 0.04039043447964134, 0.017740660039107167, 0.028261272724898114, 0.007859681931985243, 0.05610783141286624, 0.04933549541859858, 0.01800919492398539, 0.05697095203363607, 0.02164091708348884, 0.06930353886057293, 0.09311712151693721, 0.023482067683230967, 0.03913244532961999, 0.04144352192299501, 0.03390349305024551, 0.10086176481338278, 0.06483173042896294, 0.03711216039054337, 0.02741614176381019, 0.008658401371400443, 0.15901228923711086, 0.046967283987830726, 0.027885592782930024, 0.02982378948570019, 0.04207117392891838, 0.0506302223150288, 0.03408452728763223, 0.04415204110104711, 0.02048422582447529, 0.06842367921865757, 0.040274012097788435, 0.024003945929448933, 0.016316661551114053, 0.034100618964481744, 0.03587960152916851, 0.0450014257653346, 0.01665938822101922, 0.041803181051246585, 0.01619048878520487, 0.06840337788866413, 0.07592541901695152, 0.05667111288095194, 0.010608042470149456, 0.023287506248321266, 0.012678811645826266, 0.10451234231192259, 0.014566952163623947, 0.03896103698700186, 0.08413850975733611, 0.02606732522948615, 0.02561762587227408, 0.0434408012417055, 0.039449123094879815, 0.039199412905520974, 0.07930736778484238, 0.030345503023014437, 0.011915755514506132, 0.057794282047618786, 0.03760884966581099, 0.09722067148334558, 0.033792670771119096, 0.10792641314647852, 0.021694751997147838, 0.0473952207023338, 0.03095593145718017, 0.0460201733174824, 0.07782463525091449, 0.058595564051140706, 0.040538323922984065, 0.01788941707702414, 0.039618328934715646, 0.04729108254034673, 0.071949269472351, 0.03483750361708864, 0.013589822337962689, 0.03703400410050827, 0.05571059950236833, 0.04122353211465863, 0.04402403163933947, 0.013126276899129154, 0.041946458645285144, 0.03451825562684286, 0.014592698463539203, 0.011981299124477852, 0.04114539497682164, 0.030329685222597855, 0.039810532734038374, 0.04565577210497953, 0.03352842789383666, 0.05107408599747766, 0.03269878914579749, 0.04586134413858095, 0.03850252953388038, 0.050715438105286136, 0.03552170440314278, 0.038161727659884966, 0.050589416641742, 0.054599875434031414, 0.025946821514216643, 0.06077238756622519, 0.00864066260551373, 0.06002592298412516, 0.014985844252570985, 0.05361417308449746, 0.05409168334858072, 0.015941864525478695, 0.011098016984760763, 0.02192679045331334, 0.07350686411823958, 0.014620451913816074, 0.047928352780159444, 0.027286429671690832, 0.02932833552721047, 0.024009523049537695, 0.03449886594147932, 0.06549992763827886, 0.017008528962070425, 0.005744490190409125, 0.04627821471301779, 0.035084026880682476, 0.029914178284666235, 0.061305745639988495, 0.049207072269411824, 0.062260402276390986, 0.06683067598890874, 0.02961676954592188, 0.05592038884999291, 0.05414712896210052, 0.030857636630835555, 0.046905813092786464, 0.010274032923212696, 0.08781456734023749, 0.058956828133593646, 0.06228747582363506, 0.03499973039593428, 0.034900460722706014, 0.034116254819016305, 0.055364140069052103, 0.04271459585476307, 0.05764114490199474, 0.07553734185714876, 0.038005951341361775, 0.03532608768211738, 0.02836652746003482, 0.01860639110447899, 0.03921186566473015, 0.011084463931770335, 0.037512743935710004, 0.0441720474871897, 0.0559041171424812, 0.044922660435399706, 0.033837019601055694, 0.03247889892889127, 0.03404094837605953, 0.03180492733184609, 0.027587718645771666, 0.048816183566926956, 0.03318277668328055, 0.05688500845985067, 0.020987447914517215, 0.025289161844299208, 0.014016555336814736, 0.0434408203939036, 0.047185071293384805, 0.02548861283538563, 0.0167851492146691, 0.06041976878599775, 0.04868391465636031, 0.021923733762495463, 0.033670518051592574, 0.03133900414761757, 0.04419666955307607, 0.08640685013585514, 0.03541697635345402, 0.05568092508662132, 0.014014235048014072, 0.017325890460802663, 0.04139196420569093, 0.022446749649280985, 0.045292324671942386, 0.04503730549326828, 0.03540070081550268, 0.05058654764246556, 0.01654035922500395, 0.03117878834957317, 0.05213988283949514, 0.04243875440630702, 0.027652726951806296, 0.05665804725140334, 0.03547102768695162, 0.020646948645251895, 0.053672943519608635, 0.02702402540542666, 0.07388882023552734, 0.04330606935846229, 0.011527539501267095, 0.08602465653131086, 0.05912646298266708, 0.03858369654945789, 0.05191188358191041, 0.04294167197639904, 0.06032312679434977, 0.014521503039906103, 0.04199341600460391, 0.08874685037881137, 0.05176199847952493, 0.0076666124533080774, 0.006318819125167906, 0.04505268087790859, 0.03523913287227193, 0.03523216530260059, 0.023933040661617153, 0.06260865052501041, 0.0364816470462228, 0.05134161539195527, 0.06760739721357822, 0.009370159297700851, 0.044895732444861246, 0.020948415734775124, 0.020977199573310155, 0.025554076963735205, 0.05483598373229465, 0.029652861863254543, 0.14975828419048942, 0.07820909647571464, 0.05183175078503067, 0.10576566215604545, 0.01928961704364948, 0.047834009052284306, 0.00749077755890246, 0.045251078498099125, 0.017130105200433926, 0.018195384933102517, 0.052178194896588405, 0.03319277413069241, 0.01291927994198857, 0.027675169497548092, 0.05474124929957813, 0.023384213357442812, 0.06221416503972104, 0.0030357703930818506, 0.03840762656182051, 0.07699028123170137, 0.10778817258054212, 0.011885416517484815, 0.03887092206446875, 0.02584668233119432, 0.02712165948093659, 0.11191904124233032, 0.09520913909880385, 0.08134143847611644, 0.09220618168793379, 0.20567058315200193, 0.30532746786071413, 0.11475192713401011, 0.13663706730210012, 0.1431777268167465, 0.22742771002794468, 0.14994072036877756, 0.10162863414734603, 0.22778078463048707, 0.08747040234025448, 0.12176091151852762, 0.15418650221920785, 0.12551878729174215, 0.18255095358096785, 0.1043627406620691, 0.10800031764853386, 0.1629199505212807, 0.2619475859307474, 0.1228605158206436, 0.24859856513719408, 0.11426671002540859, 0.15293309044453407, 0.13219642332724987, 0.12026585262989807, 0.10397673960054114, 0.15810821355590898, 0.21439096199408655, 0.15786614509359484, 0.21314142662430965, 0.12538472190499306, 0.06074884185387243, 0.10406713031472699, 0.2085094292077326, 0.1319633334154083, 0.13917467226424526, 0.15316881569883517, 0.16844333720303353, 0.09369078347639692, 0.1676087303748054, 0.10455845314408503, 0.1713246858168033, 0.10936917121251745, 0.08501245520047604, 0.19549973939936008, 0.08150443134288635, 0.19494598040417319, 0.13679644423386744, 0.17742000309930694, 0.09578454007785167, 0.11711950654224043, 0.10343124669405723, 0.1675317691819322, 0.11401017016220479, 0.1583351900861148, 0.18960211876659624, 0.15153735485528746, 0.07695394568145275, 0.1745779088307773, 0.15109596563683403, 0.10951213088006743, 0.09637581439869058, 0.22220032439837534, 0.19514484150755793, 0.16321869416823312, 0.2969648520792684, 0.08611781282290336, 0.07356781407349533, 0.19303040819302683, 0.10599411723594512, 0.17029057437133405, 0.0941188810693641, 0.13175906373127816, 0.0928751832895702, 0.1396492790550955, 0.1967225536223381, 0.08008062629209411, 0.14424845726499635, 0.12858483970405596, 0.13686595905211665, 0.11351615070335327, 0.09464095466800275, 0.16045691655768504, 0.1501159246770605, 0.09969747970781981, 0.10662513619829571, 0.1574029376910579, 0.17093560508181974, 0.15255090450086903, 0.10733053463721469, 0.14787980595663672, 0.12389907057607367, 0.09569639400128396, 0.14048564788554946, 0.1975870838448886, 0.2509754908181006, 0.10646100952139786, 0.2119653897299882, 0.07835440037231292, 0.22512688752143617, 0.2112711148877298, 0.17317924678565996, 0.16523575770758814, 0.08101875458153025, 0.1845511938295057, 0.15666122668452803, 0.19401769634456406, 0.22325682093299207, 0.09317192744704024, 0.13701487122283829, 0.17011222910256157, 0.18831780300505702, 0.08961235353302571, 0.23886171019365712, 0.08569953647712547, 0.11765386819118455, 0.14524979546906489, 0.13497001401359035, 0.1812470412903255, 0.14010767542546795, 0.07877092237674421, 0.20462439816084602, 0.1473245760726352, 0.11746229258395972, 0.09356844689576857, 0.18164392080037825, 0.10837671196749134, 0.08348427833087983, 0.11921592146879244, 0.1669120959817402, 0.1503339992655862, 0.1263902812535244, 0.0751652452914465, 0.18027162750161466, 0.14768036262642953, 0.09896595000980363, 0.13233093304499505, 0.15138465821021987, 0.13666296107394083, 0.13566770560799107, 0.24541635847380086, 0.13630049423344676, 0.19067995851078343, 0.1039492064005425, 0.0993796221671566, 0.0863081397068116, 0.14821506135406035, 0.16135774402608796, 0.3065326467396752, 0.1754829191392468, 0.19052948352069626, 0.24012048458380086, 0.0766045099965507, 0.1466223032724473, 0.2044129885372616, 0.20990979196804188, 0.20644057812469624, 0.11699528538531835, 0.17546467092489043, 0.13133242936624637, 0.14832098067047136, 0.17262990045691692, 0.2529280191107143, 0.15953434751399104, 0.1462067312170421, 0.07670902737206028, 0.1840567300396581, 0.15245442338768514, 0.17867306247353557, 0.1415495754730317, 0.14549171071379416, 0.16463986387656582, 0.10693512601597656], [0.04378306634363629, 0.042218473484559406, 0.0559233765928976, 0.045142849426596396, 0.0248454513794352, 0.04054298939844293, 0.06072923000301085, 0.03572703128860843, 0.04613044401330333, 0.06338512660154412, 0.028962258497373234, 0.06972878660646177, 0.007159703565130552, 0.025910150800501148, 0.015571080842956662, 0.03988897630704507, 0.03175399972185974, 0.04044396487335044, 0.03288550009470313, 0.05952143876422798, 0.024000230403016173, 0.08200195948443106, 0.032156969630910505, 0.02671711909164104, 0.022531388958375302, 0.05685431131672475, 0.09071300737559797, 0.057509109648245, 0.06540210587122748, 0.019387233882181106, 0.08733271335762355, 0.11592184298581655, 0.05615987559600223, 0.028591879883841164, 0.07372401940125613, 0.054959611171075416, 0.08071856302840096, 0.011119592893538217, 0.029655083518234954, 0.020825968071397756, 0.021670982204077226, 0.0313425702869051, 0.040672033078848355, 0.02960450447825415, 0.04012599241949859, 0.04905297751388243, 0.014327149406345862, 0.02807022763356086, 0.08696084661829857, 0.024834887026959372, 0.059723084597217466, 0.03282774855653125, 0.030263066216702425, 0.06428341831891768, 0.034305244879496676, 0.053843716009249615, 0.050192322627070456, 0.03714147091452633, 0.04524798350288503, 0.016340404531107317, 0.0087824932509853, 0.041725174148356727, 0.0246623448742133, 0.03062553305719649, 0.028664761658517585, 0.010628504678606989, 0.0475339783776191, 0.02035028301179409, 0.030974329058681766, 0.0295248351645686, 0.005053235170987225, 0.028246753443513187, 0.013668222818523647, 0.0718639349384654, 0.05262535275711168, 0.06387880132082971, 0.042354270230017366, 0.01206924601818525, 0.04787624347954989, 0.05752584100851128, 0.04455647040759364, 0.013165385687663672, 0.02658024407742966, 0.03903946140781045, 0.009610509807844798, 0.028613081367145625, 0.05103170984394608, 0.02767477113182747, 0.017503101919447223, 0.011200283976992773, 0.09636823012824021, 0.10223501572205175, 0.04716583482560612, 0.05301100141819447, 0.04119384620759276, 0.03139606237621798, 0.044142491815070954, 0.006789888983832733, 0.04959848957256444, 0.01889037223713052, 0.11527411564583741, 0.02066254044973081, 0.03892463248884005, 0.018586434514051484, 0.018996557769095226, 0.022518421005037044, 0.04372878135332177, 0.07031532650392863, 0.0339347034722807, 0.034636554924110254, 0.08613275919830607, 0.05133018919056462, 0.019308282775924574, 0.04987139307383088, 0.03967813741896422, 0.042462131579316435, 0.06749657493445181, 0.05870573515553148, 0.016234310929693522, 0.007458706724367315, 0.019076529687510866, 0.036131353342845555, 0.01872695227634282, 0.019943340936855927, 0.03208208262109228, 0.05135097698638997, 0.01470881345261249, 0.04613956045960227, 0.01038953887238618, 0.028612558512137305, 0.02915178864984022, 0.046739947396300496, 0.026274379643221057, 0.07044805889768947, 0.044204269145284934, 0.020645703752374938, 0.029216094070204326, 0.029583684123692014, 0.04826330557285298, 0.035759816021328016, 0.043628527257110805, 0.039242332981478785, 0.029954058906784462, 0.06022111452635258, 0.008237532775608764, 0.04387582043906854, 0.018111902416773865, 0.019532735046419888, 0.028753593383777528, 0.039218159077028115, 0.045198858114740545, 0.035240121125694246, 0.05565218912858156, 0.05306821286437973, 0.035306020008940855, 0.02288982617638765, 0.01896657308773889, 0.03219674874637877, 0.03624635463159892, 0.02049575544773571, 0.09183957031176937, 0.027100381388839696, 0.052727966404129425, 0.036109922033163815, 0.01318027077603244, 0.025951368246047248, 0.025911780652560057, 0.017038877535190795, 0.014537967227008796, 0.057749703391304905, 0.003685918331499242, 0.0712035977912526, 0.005673449420775738, 0.06105938708529838, 0.039367833505234415, 0.07852376709061284, 0.005624312541312388, 0.11988881479708419, 0.05532623020811908, 0.05133675073363608, 0.06786091102948112, 0.13097239868535152, 0.05087811304556747, 0.03888791772506891, 0.04042829454485928, 0.014737945861153066, 0.06678459580026327, 0.01246529815327977, 0.014991027794988647, 0.041459115642693736, 0.02554344174812638, 0.045588819850837035, 0.06893094433771987, 0.02560440702514062, 0.019051808030194333, 0.035890594890881936, 0.012794774374924602, 0.04074483058385311, 0.01001200882808095, 0.04180105898769633, 0.018922337255771124, 0.03974674442302316, 0.1183692487557569, 0.03987118774544328, 0.042328893567525575, 0.04455249441126662, 0.0732392696062884, 0.022934443137097745, 0.022452784506904504, 0.035021705628042264, 0.04707749722705734, 0.0025164666810944198, 0.03012981479837289, 0.04010543445005052, 0.023526031553985614, 0.04073498252358648, 0.032786467908731395, 0.01944903036459319, 0.05479082667959794, 0.02261307499852152, 0.023285587198070945, 0.03837301470940152, 0.01198485664527623, 0.010062801415070651, 0.06235422889491724, 0.03738588360588878, 0.06780165412853803, 0.051543341664176796, 0.028599852943913113, 0.0774680519656789, 0.009029039497216864, 0.02921785415721036, 0.04880333627243677, 0.015855057187558665, 0.007904795892236215, 0.08828440140331946, 0.06727615611687784, 0.010588555108575572, 0.018394357119236263, 0.03900049051510231, 0.017377948050477335, 0.03344266818115308, 0.0445802497767633, 0.03129491387235542, 0.03601414955130989, 0.06498629632856577, 0.10582297319366087, 0.05668496375062293, 0.054897822349542574, 0.03343025372634011, 0.01397011987489438, 0.0041125625120325675, 0.024275255967832865, 0.005615985644380412, 0.07329395296232355, 0.031620495494515184, 0.0341313046162888, 0.01270353234553289, 0.03478381234491545, 0.07358351887594308, 0.07244692784884284, 0.03442520658755976, 0.004966139592485683, 0.01913368367710181, 0.06641050740595787, 0.031557952076376926, 0.07936658638138926, 0.05967503939304621, 0.03624929640922816, 0.039033485922001065, 0.0620067467342221, 0.03379543634852575, 0.07406466039678744, 0.027077099976820812, 0.053475993805594986, 0.017864308545305845, 0.023627971043629993, 0.05153939631136675, 0.05602507859528546, 0.02773227369142396, 0.07420627174959069, 0.06227979962263377, 0.09605613356876759, 0.031991425691352736, 0.021147495173218272, 0.020113916158856406, 0.02113654203112087, 0.041901558232043064, 0.05203069232764745, 0.042945502416020444, 0.019377770781096433, 0.022447423806654352, 0.02439870912161085, 0.09458242555058773, 0.033567747356550354, 0.021815587045444597, 0.026572205899884144, 0.04700244359311558, 0.03983580597466038, 0.0846007212455715, 0.033149367588902676, 0.02408711434972863, 0.011826548406163291, 0.04777464489903181, 0.057293371627888376, 0.01969479520114199, 0.0386834756711558, 0.01848519024919839, 0.04513009023221751, 0.022299011508303306, 0.053327024178279024, 0.014566449418423638, 0.06809610002223523, 0.06668076790388554, 0.06777494830349762, 0.026197092862980022, 0.06296970776372379, 0.019678228549779426, 0.056734165747559843, 0.07633809526000293, 0.05114319861956662, 0.012530143665630492, 0.052669977378701015, 0.053975586554095636, 0.0020838841221355385, 0.06994320695558864, 0.049071827107259346, 0.021794272564171303, 0.05434933403927473, 0.01958551275874338, 0.014110998656120033, 0.028064363230500492, 0.04923318437631092, 0.1022647169508761, 0.09380226459113822, 0.06855766799661421, 0.06945656492344796, 0.03513819695780835, 0.039283491055210756, 0.027380131800929387, 0.01732538484277264, 0.015446630817267205, 0.10539816211788886, 0.031060856774509437, 0.035144467387468584, 0.1020504498193341, 0.06517650063840613, 0.06567483317227134, 0.024092999820206917, 0.04471968927030121, 0.0238749003338237, 0.027501623769621217, 0.16271330596458528, 0.20336121110425842, 0.15006049055485957, 0.11113844361276397, 0.14061785933952178, 0.2579757571220398, 0.20967682463026818, 0.16853819420981794, 0.18282384942135504, 0.13530309372130903, 0.15598564438762205, 0.17611638192207585, 0.10754783547693685, 0.1725945838036076, 0.11985396545740867, 0.13017957429251364, 0.14546246147684513, 0.08338885441903146, 0.08441515176767304, 0.10937814210211078, 0.13834104602856023, 0.129575529285977, 0.1346525012124931, 0.12837622630139514, 0.09105681997513579, 0.11592777250635049, 0.1971638662319991, 0.1713725050250369, 0.18809640359493995, 0.09899208892978008, 0.13833122478137094, 0.18382895677801103, 0.19417621525785617, 0.14214505561657492, 0.15329849906265736, 0.08717874500660167, 0.20659771807972463, 0.0940693075197839, 0.2459445301323168, 0.1521297400036166, 0.13431416614161384, 0.16253404139030367, 0.13555023368568192, 0.1631114725023508, 0.16151137529842316, 0.13708591821693605, 0.0784420408308506, 0.08719199066681248, 0.16835718295506893, 0.10440761809267345, 0.15996061415681917, 0.16935328111773537, 0.15699367820014878, 0.18136383905526132, 0.09589749974228683, 0.08970985354314889, 0.2029816605030529, 0.13042260802561237, 0.09316937637425239, 0.1596772535553863, 0.10321660417943232, 0.0926518609987632, 0.07957232695433401, 0.09452285455359567, 0.08460141838558259, 0.11656187880303591, 0.11707088294168634, 0.12460864419417998, 0.15204386154730476, 0.20957773881814173, 0.15584672200343302, 0.22586732682201172, 0.10469369064535826, 0.16016790222737098, 0.14737267107252153, 0.13061466626822948, 0.21786648840192827, 0.11534398286453179, 0.11995329641767087, 0.11538941953932086, 0.11806906486350684, 0.1394388959893296, 0.13832033101108768, 0.1250288970468025, 0.1769479703638823, 0.10462895621575656, 0.1623732242132387, 0.06601213402445279, 0.19422161362824902, 0.07859695147001937, 0.15674232475219235, 0.1495319358523815, 0.17714439530766782, 0.15523872398320707, 0.16759716244714876, 0.1348433796797068, 0.1474755566807524, 0.13029762844164527, 0.11757664652841708, 0.12875025340866658, 0.18577970774664035, 0.181821454015951, 0.17677308781252754, 0.12392110326477598, 0.11279908474534751, 0.18115653566295103, 0.19407890676971407, 0.1698784037463127, 0.1422602599186282, 0.20266866762070887, 0.15181334569088875, 0.11128317294341904, 0.12765645605301665, 0.0868425166775142, 0.0990830465490299, 0.19305480043253592, 0.09094674846217518, 0.14174468274558746, 0.08830487893353547, 0.08099536591720197, 0.218755824551467, 0.14383429481137183, 0.06422917929387863, 0.14498552577870508, 0.11191185533760056, 0.12204785741144612, 0.08972660022517366, 0.07777651726839044, 0.16216287179098976, 0.08231381855664716, 0.09407106186113051, 0.19209132229368533, 0.19140193509238382, 0.14958150174108245, 0.1405102852731943, 0.08801726654412285, 0.18679707251008482, 0.14322134786315505, 0.2015801945761327, 0.12782353982930222, 0.18276740406309405, 0.1390105609091059, 0.13542551457160903, 0.1580403688093347, 0.1340954173957148, 0.062216137716126066, 0.13705921239189564, 0.16636671798844493, 0.10044553392236272, 0.18235494232466146, 0.21365000175372248, 0.20319441844138408, 0.20772584383526158, 0.11264340035737523, 0.10837253678830401, 0.07426794948837451, 0.18453705184642347, 0.18525447786575366, 0.12105827865701531, 0.22887687258903058, 0.11823792596377673, 0.1208259165287018, 0.15098284509393478, 0.11877421815429004, 0.09208817350407762, 0.06233508052724985, 0.1647604154723306, 0.12891177538662188, 0.17070798503775753, 0.2545230907778586, 0.12231887633641883, 0.17130757141257488, 0.1557150314892492, 0.17173207605317717, 0.14666534209203336, 0.09272925120087401], [0.044321331210554614, 0.05578995472000492, 0.0606941431760788, 0.008434959379355273, 0.09276152648512395, 0.06926908788661804, 0.03852790619637217, 0.04741910732381287, 0.038911428963465076, 0.01653529921426408, 0.025065600151015867, 0.03742005878819093, 0.022612008221086957, 0.0954794685446447, 0.04369513477168737, 0.09804859036399473, 0.020234048321482637, 0.033477724364568154, 0.037018843220486757, 0.025640547222968553, 0.019140664653311816, 0.06395920224848294, 0.025122078068013635, 0.018986177277721224, 0.014901504675377042, 0.056861252073318734, 0.050667921501782634, 0.004874824784741167, 0.051417189965685534, 0.04754011474189259, 0.0031453748318111346, 0.010945361516919109, 0.06196397604540952, 0.0212795821379029, 0.011234059835964394, 0.03860592842102051, 0.07806589932090814, 0.04187874796409761, 0.048402124535172224, 0.09347044126761538, 0.01817815561568545, 0.03267872530306059, 0.07011495620733307, 0.047905764677712036, 0.07797801371423468, 0.07561028874929875, 0.07431722426366422, 0.04193003372018857, 0.03710895814301987, 0.02055723783409884, 0.019349967535104484, 0.028602819619399887, 0.04830088601597855, 0.09456611553867979, 0.044088386855418646, 0.07663696148102322, 0.03411092284706331, 0.011989625542604876, 0.07988623148130794, 0.03577540974102674, 0.06327338501690857, 0.028978514883126465, 0.03980100643069994, 0.05228396865629381, 0.05011048528455919, 0.029646262015786864, 0.054722732954448274, 0.07033097001934244, 0.07026636582468787, 0.030173908904074665, 0.01609773852021223, 0.03689854060329738, 0.021838902931420073, 0.01246444779568382, 0.04256268061937825, 0.06878114350500607, 0.06505519827647556, 0.025079188635572795, 0.03316016559819541, 0.04577748432394959, 0.014598714168964615, 0.060571323960058154, 0.013057752249522075, 0.10031884596232446, 0.05588868430124656, 0.04803018118705481, 0.05371781328933374, 0.012416840219239314, 0.022024811403225028, 0.04279609228814802, 0.09011218759922252, 0.0241447911943279, 0.09071528265673308, 0.06991899857718138, 0.0698055869208709, 0.05313576266710317, 0.021533490489086798, 0.012083778706108852, 0.029519192927006273, 0.025932698683332533, 0.02354298124931032, 0.03484341015498485, 0.01579458507964568, 0.004291369348779441, 0.07078364371292054, 0.011555516074651913, 0.07076572491637162, 0.07222126132898754, 0.010839220992619953, 0.09118199874196323, 0.02318823082943357, 0.027532912715668642, 0.05283125037808092, 0.020315625194099643, 0.022895746120822527, 0.04134382324052915, 0.069932175289479, 0.047531829500991496, 0.07651693082504696, 0.03898833269974397, 0.06564279537527792, 0.019186767824595014, 0.05739838696054875, 0.05062435025108918, 0.0635233786587994, 0.07065927699929284, 0.02748742432994468, 0.015803351998329163, 0.028363761882628166, 0.0481169100009626, 0.046060588285927816, 0.01842010341915152, 0.08117753396471662, 0.016401419603836634, 0.04273513467201302, 0.05844266439277319, 0.07049501242656862, 0.019919080847513773, 0.03617329282626029, 0.05718160323017547, 0.04065638956343455, 0.08823066799631042, 0.09550805894597884, 0.031067550467747836, 0.03707170711770173, 0.030456526400220972, 0.0175836886234221, 0.04615491669204447, 0.003935538744929457, 0.026537565319167993, 0.02498060844147638, 0.030765729062559626, 0.03932015602326682, 0.007135135604203829, 0.02464775472969538, 0.030569991682686155, 0.02422212202462458, 0.03310607596030159, 0.03295398452469418, 0.06148244765016341, 0.041194459077932184, 0.0829308181099834, 0.008926620245009901, 0.029867144316555034, 0.01979692429754763, 0.016220469636121587, 0.020737923501480012, 0.037387932891086224, 0.04465312389056048, 0.028338490557225964, 0.061820066428833434, 0.04802658823468993, 0.027437977184871995, 0.1212232556915091, 0.10112411162305264, 0.02489409796262701, 0.04702891959177871, 0.05175233811079975, 0.08987618655326868, 0.05869178086399071, 0.08949538722874657, 0.018370098945113923, 0.13093383381924323, 0.031410725299088706, 0.05067055684424216, 0.07269190744526925, 0.10639588438695478, 0.02361160549034755, 0.05261571920146385, 0.044533265604367184, 0.0439377011911523, 0.02615204880825214, 0.08954637804098668, 0.03079207482627563, 0.01882331847633806, 0.06961209609383537, 0.01803722033547538, 0.025020303287272973, 0.007522953730527192, 0.0656246620741102, 0.04138178289717725, 0.03504939204562576, 0.023738460074509346, 0.07355956330655083, 0.029337436651750922, 0.05868154975976195, 0.031142466205863223, 0.08264778692635798, 0.01709485174937835, 0.1460814145543883, 0.01906777330253634, 0.0621397587500753, 0.04726804627646362, 0.010208535278516432, 0.04397309062281444, 0.06370758450019263, 0.024126698112776204, 0.01158336720113913, 0.04410469686732658, 0.037571177292134494, 0.028677683646580385, 0.023214787267328754, 0.034791492376356356, 0.12086667240627351, 0.02468514365083989, 0.012720245511210974, 0.0917841285286892, 0.030511248060652328, 0.016298233306095485, 0.048369967994550546, 0.03494454525230873, 0.04221211495478788, 0.013491248847135614, 0.06167407688354293, 0.037612496244330565, 0.054981153563506184, 0.11144965151024443, 0.04930975869478238, 0.03556453254854968, 0.04538049756158744, 0.034423670581271576, 0.09159878887716802, 0.01717892606862851, 0.08940577026336424, 0.029638539849510117, 0.03862701882157595, 0.026628888745401657, 0.017348038062693614, 0.0023483824418602333, 0.02968364327605213, 0.04437584219680679, 0.03504635450700599, 0.0580803009741489, 0.07371738507983185, 0.023999393451958898, 0.019014143317397085, 0.06653035420083231, 0.09496690209714637, 0.026900223681643128, 0.09492520393142778, 0.028492889832705263, 0.050606925581251426, 0.021962794670534712, 0.01747706259090093, 0.0229890575452197, 0.07324125377401229, 0.0005153112567401672, 0.013645568640992768, 0.10306183143608993, 0.0764716397069635, 0.026882695589935588, 0.014005752539472475, 0.035580520803529414, 0.03638227395112476, 0.06032215769312555, 0.042403675240254214, 0.04538012600894417, 0.06348029004349824, 0.014425777480937542, 0.05084111865970397, 0.07656167035982495, 0.018347713855966445, 0.004405059190767427, 0.01486728831584896, 0.010179717923634717, 0.032213951250718485, 0.02824438048616773, 0.054383968874331445, 0.0509820481942546, 0.04506938925553714, 0.035016737547853304, 0.023204684482827302, 0.03525871791005616, 0.09361809705414119, 0.06112958755223982, 0.03640920577210285, 0.03688759320685941, 0.05332292943832375, 0.02896558523418442, 0.07074606710023458, 0.03665210927025445, 0.023165305648299477, 0.01265101797593337, 0.02706845467459531, 0.008155447412132016, 0.05167598595782634, 0.05318764597177506, 0.03063077692903819, 0.07259908057148419, 0.059719162227045146, 0.03350780863735465, 0.02476288433817606, 0.08241731703521744, 0.030908219501255985, 0.09287490749791746, 0.019914053395510684, 0.10235087119884069, 0.08039862938946293, 0.05327587631801444, 0.013063749760359287, 0.0498920506347091, 0.03212157828402856, 0.06535866102504154, 0.04568150499835611, 0.013544325333749576, 0.01824772980574879, 0.03612327494568402, 0.04840212836561184, 0.030959589527018612, 0.031896936406771985, 0.025115706131703434, 0.025101612029116482, 0.08292172464632219, 0.06969949140423728, 0.04219878119446578, 0.040845299184682875, 0.03714650411218886, 0.07367140448261654, 0.07144080925612681, 0.03080586440891268, 0.024443812548152866, 0.049002002023400805, 0.0030983413425048874, 0.03346177058354501, 0.09062866109513468, 0.04918775919284071, 0.041747651168055115, 0.07868600919121697, 0.08419595102989867, 0.08724510354260284, 0.01447589495294397, 0.03547584254955573, 0.18913288991297447, 0.12219158316692039, 0.13873259356665996, 0.12044726225036768, 0.174595819966447, 0.156600552520925, 0.18315669930269643, 0.1402894834116582, 0.1843251212830505, 0.18474993235882253, 0.1429728749057939, 0.1784177100466144, 0.21510029812493633, 0.14208979003371733, 0.1746783123141335, 0.16850643220447725, 0.20567766180442226, 0.24270754818233753, 0.12061681282976944, 0.16092730986495174, 0.11103224084382096, 0.1607810636802066, 0.10295218127148767, 0.16656672822371607, 0.09671498450540728, 0.24207227743200718, 0.2584836427723208, 0.1583058029533394, 0.17009669283945716, 0.11217483800024756, 0.1702030258433473, 0.2146125912305809, 0.13703172515717246, 0.24638069463112663, 0.06996229020578247, 0.15153193095278356, 0.21360656456841579, 0.13299068796538538, 0.10057973720493818, 0.18363015696166024, 0.09571035212326436, 0.15189596061264315, 0.10035685158424801, 0.1059935043656057, 0.09622980570120197, 0.12879077945986103, 0.14051972347642147, 0.16398809159234648, 0.12273709905604202, 0.07112036999915877, 0.18697163330451136, 0.1591055221374958, 0.11399539232614542, 0.12679787067275855, 0.12296300306315384, 0.19423638380342917, 0.16064926591371337, 0.12500381532816157, 0.32832818526414137, 0.14239342132162663, 0.22559919604851356, 0.1171265162467476, 0.11799774973863557, 0.11285143919409284, 0.1266815785258528, 0.22498994164409178, 0.0510612080594705, 0.12180730580322205, 0.1461954697245552, 0.13379164821197911, 0.09301407503024225, 0.08228522049443376, 0.11097264686419119, 0.112207381415271, 0.15815923501166607, 0.19891002575957006, 0.13924647002450882, 0.14265896271794073, 0.09748195343080068, 0.10368417828313767, 0.20181685445770142, 0.2134973204304134, 0.08880224619661609, 0.18221208224854163, 0.09774596265126621, 0.11583349772638853, 0.08786019553700763, 0.12140380729350353, 0.08179338438616646, 0.13826652099528622, 0.180127511041299, 0.09338807915487597, 0.32994889023323215, 0.17717483964177871, 0.14281853883256837, 0.09415618955127655, 0.08824612765062241, 0.15649052697323984, 0.22520092225843863, 0.19984788591823271, 0.15023027096063862, 0.162836600155119, 0.11495959824852406, 0.1373715311168663, 0.14334523960226966, 0.11237828797029872, 0.206848596553168, 0.1594948786641321, 0.1212484906277349, 0.15232794227138644, 0.141751010631842, 0.11936449656082739, 0.12552143795596016, 0.14178312503762786, 0.1145515491765353, 0.1443996983430078, 0.12373813848582008, 0.2393674661195086, 0.2021666195604109, 0.1256693312297425, 0.1172842460894777, 0.10195710966663976, 0.07646653756138778, 0.11435053536608336, 0.1832744929819338, 0.16483478728801976, 0.11921592912967167, 0.11556298441944585, 0.12794231410108267, 0.10352588153534359, 0.1221004723300857, 0.16584574755641723, 0.20359672185394073, 0.11975898587655638, 0.18932219023906416, 0.15800454653799534, 0.19450725717169626, 0.14428591896449366, 0.11348904651259223, 0.11799732072939796, 0.1794523730753891, 0.2144678006128919, 0.27323665758294446, 0.16110016994418638, 0.13001868050665627, 0.11280987892420062, 0.24554700710840766, 0.1535205726301478, 0.16120536913794858, 0.10978786124577446, 0.10291613683465028, 0.12276244890545646, 0.15005816164756977, 0.11484791795092245, 0.14580998960281574, 0.19794838623173777, 0.12919314415945163, 0.13921659259546187, 0.1447721243265175, 0.12963220447061524, 0.10411646637705066, 0.2269026640081598, 0.16760425642132762, 0.08403973804125864, 0.13252351222740066, 0.16519065045060652, 0.10281549586403756, 0.16791033919059462, 0.11193822408395429, 0.09447069928771067, 0.1825363366233726, 0.1642640517844308, 0.11649817859213199, 0.27575662720107263, 0.14555247680794808, 0.1492954445101561], [0.07590150175195548, 0.024793960694824497, 0.037894056539141366, 0.028591669209661986, 0.015234621729882014, 0.0191924387904545, 0.16513206004615755, 0.05292501187913361, 0.013000616454519333, 0.09529189191638462, 0.03666480334715978, 0.06252160378461404, 0.06794059949536478, 0.04282604632598739, 0.0451202804763471, 0.022959840867007454, 0.03372921570835095, 0.015163341078967338, 0.045515872958687045, 0.08503620392612873, 0.026018621189700022, 0.05141347826969239, 0.02844213267728206, 0.041275744837137966, 0.04842296212671265, 0.040649310911014196, 0.06645257329388012, 0.010905067207321767, 0.009579248632484627, 0.03935013687418353, 0.02467547753645528, 0.0150804877123465, 0.04520264258908649, 0.04494125721976162, 0.05035103306234364, 0.0293830169680258, 0.056471347793816566, 0.08883852812071001, 0.040098934194012996, 0.0989425536845961, 0.022757471080929525, 0.012577887222681557, 0.03873941924182638, 0.04047931600061636, 0.024507656400542588, 0.07180686904898576, 0.08402855315756413, 0.06024182954382512, 0.05190167546031937, 0.12625430830784384, 0.023933555855746233, 0.03055023235989915, 0.02623903809205419, 0.05873388122586955, 0.07746050599962473, 0.031101472841034976, 0.05487745207163596, 0.02846136531462112, 0.0770957715388748, 0.0042031160199023304, 0.05108062072747177, 0.01869243043925493, 0.036258133233434735, 0.04984479833153948, 0.05010459406842148, 0.05280702284747555, 0.027170541636165113, 0.046264405978182634, 0.05208707256843487, 0.017279025032034805, 0.02665995169551142, 0.02349609283790473, 0.02832569114323105, 0.06357418177949806, 0.039320619506461006, 0.059508373134679375, 0.034835435179693085, 0.023026680123181115, 0.0059532955938559635, 0.046400838576617746, 0.008252292417079933, 0.031235036440193657, 0.03178231241632133, 0.014442390097575563, 0.0732875178237596, 0.022272550831398657, 0.08044273307126376, 0.011922981638851906, 0.02100955529679214, 0.026002123486250642, 0.030472572111795028, 0.06956913388304173, 0.053729028816545205, 0.022588179056202213, 0.05225630522134805, 0.024568412918597463, 0.0678201704736679, 0.016150571773910237, 0.017796638083734342, 0.03058710800213439, 0.048270705982201526, 0.033908380691202424, 0.03156465151527476, 0.026866891196057684, 0.11115398753674761, 0.09754884822834885, 0.057528740651304686, 0.04652087306303363, 0.029898460075679808, 0.03249377252594118, 0.05819694935193947, 0.08739369395639628, 0.014771288880447467, 0.1404454895565587, 0.06609856406407011, 0.05616503902861188, 0.07713360862145502, 0.06885805107172459, 0.038440066554974166, 0.06224024650310317, 0.054838553957280614, 0.04133379131916069, 0.08972083924398308, 0.017061285606976, 0.06168095252266335, 0.051746469877299764, 0.11245823690607665, 0.01824854951982777, 0.010916108449530459, 0.04026995183178975, 0.04167697572660062, 0.030721809241860628, 0.07384277835127807, 0.08041312377299033, 0.009135139801899993, 0.03247306516934787, 0.0174855221168048, 0.04607422848141963, 0.0537573051218304, 0.06764989977161731, 0.03959256539782209, 0.03991819490047713, 0.03133153479035584, 0.07574774024467315, 0.009636555839660428, 0.037199950236226284, 0.01967272420804347, 0.03324320952918741, 0.0063659201259724804, 0.03619399635241397, 0.07472761756470127, 0.050377600991557685, 0.03990601793292069, 0.0832073835115279, 0.051549937681204853, 0.034811694114919634, 0.06632142670212254, 0.03670221525094202, 0.06544857676471434, 0.021612608219466863, 0.03725810780099804, 0.053815926169796344, 0.06868424870434307, 0.0639125206808169, 0.03139943699352443, 0.01755757843174281, 0.011263644236380295, 0.05694205902757184, 0.02829134167592612, 0.06844227217257985, 0.08581966672453188, 0.044751186975308006, 0.018862289369046208, 0.02391631121657068, 0.019793769930519407, 0.025145510782397566, 0.06459537698256393, 0.08706416889664628, 0.09568909318336556, 0.027082265324650273, 0.01087666162469935, 0.05596094937514394, 0.09970010738940009, 0.056454658568386114, 0.048679184063427874, 0.035336234516674475, 0.023204272710568002, 0.06153863253853014, 0.10789708730073706, 0.060392369651385856, 0.027539587256708936, 0.041959447666041316, 0.01770713028588122, 0.024382401024922732, 0.09516167229101544, 0.06560924072419444, 0.02888364255458357, 0.06890391675575126, 0.022517773660741026, 0.025332892058236946, 0.028080138896081238, 0.002776928196263109, 0.028340490046708335, 0.048129565773471716, 0.02561565319586906, 0.009894347299010524, 0.023999012323216568, 0.04377343278798846, 0.06520782597362995, 0.018558893653173602, 0.03881675198734288, 0.06365951248294403, 0.03018509953342859, 0.030848548912833777, 0.05142262152906868, 0.03818275677340646, 0.016714713175690944, 0.044553379242819165, 0.03379661229348952, 0.060773253245579625, 0.061548174163627054, 0.01464948760375621, 0.048671753010562355, 0.01780982820257064, 0.05095267255279807, 0.07940299087955106, 0.10853904599864637, 0.00786882183972686, 0.06468929936208072, 0.011659222354571666, 0.08511059106357637, 0.01701460212409016, 0.03953341957962802, 0.01800457732902179, 0.0821283027049034, 0.015171481720772723, 0.0033424195886078865, 0.07348025022375007, 0.09709523990750314, 0.019640948796164126, 0.02780306596128691, 0.03570041739411893, 0.07686574597873035, 0.016989650640396342, 0.01143688544435727, 0.03994245690503909, 0.03936144050150629, 0.044220062047843976, 0.03814449834246789, 0.002896583229754, 0.08227239618258131, 0.052475525111320524, 0.022282785766067046, 0.03863963245924923, 0.03831540872793525, 0.051434729548711935, 0.009922815126276786, 0.030153942737548105, 0.0668899099072141, 0.042872946228711836, 0.12632931597651015, 0.020359326679740223, 0.036230148041560765, 0.06746974653534352, 0.05275272253540255, 0.07307181044691995, 0.018825764212036328, 0.09850924669374382, 0.03390112966899911, 0.04740162136694116, 0.013565428183233787, 0.03986821149385745, 0.01499499996087604, 0.029605812573384856, 0.028976886946287368, 0.034803669343912796, 0.006194994418746642, 0.03736039586064797, 0.03167972175194131, 0.02189963455161741, 0.05395079977930554, 0.01652317587286234, 0.048989035985282356, 0.057677403843450936, 0.024336845606505394, 0.040470934998724735, 0.041332826048376105, 0.03814073685075968, 0.028177123712075335, 0.05837265544781282, 0.014055064661548504, 0.03991687339880774, 0.08260253411267074, 0.015773785792501466, 0.02782098858827545, 0.04622739244012102, 0.06980721102727037, 0.051029327310501575, 0.025883040864080675, 0.02969117966600724, 0.01980980989643403, 0.027336158354075688, 0.09951827642057212, 0.028483145194308414, 0.05166059525142755, 0.05814845215589289, 0.04194390757249729, 0.010703812079173664, 0.07106911105614516, 0.09408658280247643, 0.04143865726467583, 0.014048009949375787, 0.014465248246016282, 0.04752263644590013, 0.1214221474384108, 0.03446337308794741, 0.048166004745590116, 0.05917239378416731, 0.020702206567230246, 0.026451376597246817, 0.049263218853382335, 0.009522531313010523, 0.05236929552930017, 0.06686491245824484, 0.06423087617863091, 0.01729822894107671, 0.04658490269174499, 0.07165112337397953, 0.01607107291478784, 0.032340056983934294, 0.06965800008225827, 0.02575239031425407, 0.013195898969687763, 0.03843969500233089, 0.020226061854872013, 0.006248584184269872, 0.048276731263725996, 0.019967805954717824, 0.07786786559248164, 0.011213717328745031, 0.04425366649464254, 0.04171040014273698, 0.023017420035396374, 0.04751864129737501, 0.046004139097227205, 0.04463004932228116, 0.09627087567482265, 0.03660243612924411, 0.025282192359408064, 0.025161692474578178, 0.030565640303276242, 0.06876091112292583, 0.15872618604090907, 0.12061165705803903, 0.2125447054183291, 0.1662217435096541, 0.06374714145016286, 0.19348768607502986, 0.2584975549290257, 0.16121754993594464, 0.1613295979557499, 0.15328032745709344, 0.16811931265457986, 0.1100286043759796, 0.140100734668874, 0.18342645418259407, 0.13987188888413293, 0.09890637135193234, 0.11716505813021814, 0.10349391268626337, 0.22888120864668202, 0.18775482031126178, 0.10441058285294041, 0.1788082310268956, 0.10266168839147977, 0.17244856744523973, 0.2188539757363258, 0.15398410178961294, 0.22066405764029873, 0.19751861090621642, 0.12717976550301238, 0.1572334177551731, 0.15211038862264928, 0.16907108496994744, 0.15021854981539712, 0.13040638228337612, 0.17943464580082125, 0.13225214856286205, 0.08936302255718939, 0.18046783794078136, 0.12877554963192633, 0.18417627039936282, 0.12292849846304425, 0.1134721466129826, 0.11476793071074833, 0.16273302506775628, 0.11238597949305851, 0.18975415657604897, 0.2619970752106559, 0.12721964037947117, 0.17052973169953595, 0.21989406266760445, 0.2178244914619192, 0.062105166049854416, 0.1667145831931022, 0.15844159969879737, 0.17313942553535586, 0.11286577269915612, 0.1570420949569633, 0.12392796741257753, 0.16001149771674988, 0.11378299444913866, 0.08261291460404474, 0.14901559259141647, 0.16451650839899817, 0.09282560207911077, 0.13925633723697356, 0.11335914098327199, 0.19214894742734973, 0.09075896499017555, 0.1330580577374466, 0.13538402324963, 0.1591853791427228, 0.28780703703241967, 0.1408802904188633, 0.1134972206707443, 0.1510457409125182, 0.17182454286563784, 0.17458509473550707, 0.1917912303319862, 0.187620954107373, 0.12152168524241257, 0.11307046373164463, 0.1117523788144031, 0.12197773738373673, 0.10841264915201934, 0.17329397611320022, 0.10365980136538706, 0.06374463634265047, 0.1026713947254804, 0.13862543318781162, 0.16909477240856619, 0.14372028560648042, 0.30150315694270596, 0.11092937821822782, 0.19698728296545245, 0.17171062559129732, 0.13356939078338687, 0.13072331285765096, 0.2804860863233766, 0.19255364103423012, 0.2085006191966034, 0.11852553069231012, 0.11878023960537488, 0.12723133854207494, 0.12875020744339113, 0.2596209769047076, 0.17480666268496745, 0.11648819646647862, 0.2619965542708674, 0.07860271245120995, 0.1368367404586846, 0.11927108746021987, 0.2522229883939989, 0.1306684303187555, 0.26268686077767806, 0.22967607083339847, 0.074475291185081, 0.17096005860836277, 0.14678667509748092, 0.12083162388373768, 0.10837262871885493, 0.2055678660831144, 0.08733819088628215, 0.10251021748709102, 0.11495407475458999, 0.143360331534378, 0.15169173689378848, 0.19735339638446608, 0.08696800954039059, 0.1244921375426554, 0.12886484484038047, 0.18917914630184252, 0.09457910838987559, 0.17048508409530888, 0.18774196535589235, 0.10989947259546289, 0.10063414476932057, 0.06646270863711834, 0.12153449423250653, 0.16841528306324638, 0.2608006603775486, 0.1250878321908174, 0.09254090082381042, 0.0976140040063089, 0.13885388060683204, 0.12009490777047412, 0.170935865551714, 0.22036295444253953, 0.1978298571080931, 0.14498857480864372, 0.11366922273150376, 0.14104294620694655, 0.20132896370224415, 0.16120377567506608, 0.1520625387708987, 0.1333188187451132, 0.1209180002972003, 0.16709972623615496, 0.21027103306785708, 0.21871180513933783, 0.14100382975753278, 0.1506803322943949, 0.15961011360970237, 0.18694151072732865, 0.14665047998630232, 0.16762754549422573, 0.12399508437562375, 0.07722324856947507, 0.11175620159314525, 0.09112769076901098, 0.09285306633119622, 0.26021779004123907, 0.13365891581821826, 0.17011786750968427, 0.09628724697376452, 0.1185461997445072, 0.07775604739905366], [0.04343600170085988, 0.023980727719683802, 0.005402900682266561, 0.018612989036726858, 0.01611532406851409, 0.06743672048492778, 0.09486561761267724, 0.051768847305568, 0.004908963099061962, 0.0583317578439751, 0.026435332800892573, 0.0459886028341228, 0.0014463988988990747, 0.047007178016487634, 0.0521635358041573, 0.03262005828981919, 0.02270192970641919, 0.051879052883915366, 0.009902023500011814, 0.042014069735042514, 0.05095044323693841, 0.05497617782243798, 0.020855131123455304, 0.05087620165619639, 0.014625182506748506, 0.06579985106063467, 0.059590118546639724, 0.04641891825163076, 0.03789843473162863, 0.03141965022340658, 0.02879319629902321, 0.060481396729066494, 0.059973384674278006, 0.040987017789795514, 0.009201970439584506, 0.01253131194971502, 0.07994251596110483, 0.006893914147850968, 0.04833156017646675, 0.042616073117260976, 0.02663323820959176, 0.02977175487866325, 0.05211153375585714, 0.0059422543516472704, 0.031650708087029, 0.00860214945034034, 0.026865134939491272, 0.014159728551373608, 0.007762744038876507, 0.12125992065956517, 0.01973573877025516, 0.10327971450263455, 0.06949768852322333, 0.04289524321774802, 0.07434266604362957, 0.06738434305354472, 0.10158282208947406, 0.04635968816376502, 0.0999854981238323, 0.01661779347717041, 0.014761967505628784, 0.02284672223932801, 0.04984366452141155, 0.011399380652414215, 0.006362416710133755, 0.04396526120422829, 0.02126991602351829, 0.018279016836576404, 0.0418179129220305, 0.07051164419540475, 0.06268938853135032, 0.0822963057866981, 0.02981335345295168, 0.14305532128820497, 0.0029406651259294802, 0.03131831019756294, 0.04164185059527236, 0.02945597343627484, 0.03209186364866553, 0.08646603042800581, 0.0058953314662850914, 0.01793796406878579, 0.04408052296287591, 0.023281187938165762, 0.01401323626088279, 0.007722187344165099, 0.02869970484396383, 0.0863342862876673, 0.04122740851955549, 0.025993876549745762, 0.03709234169594223, 0.020593902802154906, 0.03220707944203769, 0.026385791810049165, 0.04383904821870308, 0.005382295789933133, 0.07572039856665558, 0.04516074524050759, 0.07185291093323501, 0.016994308454975966, 0.031189479106556506, 0.041737492842179154, 0.01259005078369932, 0.05410570658803467, 0.04958593339148549, 0.017384752826464754, 0.020694120509189465, 0.050027349423016274, 0.0037889889978443185, 0.0725964682116624, 0.07151417749663515, 0.05536972868045973, 0.00895861111911795, 0.0399424224310825, 0.017831205886097688, 0.02727497857244265, 0.07793293710077003, 0.0392306846145901, 0.05307375168007228, 0.05085097438084984, 0.018761795870358908, 0.007812306097137832, 0.015374744956892346, 0.03218724925611769, 0.04828774760807714, 0.02674579759308648, 0.042806530236116344, 0.044346880242829366, 0.10425393319418354, 0.06847997135933369, 0.04238163489067266, 0.08718095900070283, 0.02249835524708033, 0.02105063676173168, 0.05493099395666392, 0.03331337552217226, 0.06072096774474748, 0.050527815511750604, 0.008904084811107287, 0.01543852081897879, 0.025956552746074817, 0.03414863352513602, 0.018942912462197484, 0.04010836090592127, 0.048245057358496615, 0.05704185730146785, 0.06699322452468258, 0.024491668145562855, 0.05015198426741747, 0.033057536629419175, 0.026909562293440107, 0.02198825368747836, 0.05387579594107886, 0.08376457458061558, 0.04301990487522656, 0.05586613067275575, 0.049642734980631265, 0.04308553179726005, 0.04422283145569025, 0.03025919938790462, 0.1238552273641671, 0.06903455772947881, 0.03148163822779973, 0.05370311589250642, 0.010916174524613928, 0.04671811006001888, 0.06318178771424197, 0.0337210109066819, 0.019286577589809895, 0.06249882416018556, 0.07324144529599337, 0.012391719238592253, 0.018019607974096172, 0.06384490193018029, 0.027829193389944495, 0.07026982854210562, 0.02268737595107767, 0.012092082141598147, 0.04173597598808908, 0.03453320200224558, 0.0444054821385972, 0.012963731236185038, 0.058106351794014056, 0.026088497984493454, 0.029563413437215552, 0.07789573587116697, 0.01570279721260792, 0.04823338983940983, 0.03371842152949783, 0.1255705365310273, 0.03842807727895918, 0.07930672427098598, 0.04365964574859508, 0.047331930348469366, 0.07441686165909614, 0.01846362487412989, 0.08002164518280376, 0.052116953827921426, 0.07351237229041516, 0.022975243064725114, 0.036524072995469455, 0.06146491572801625, 0.04850978287117136, 0.03736527201028601, 0.029240419277020042, 0.08395366806296573, 0.041947554151016864, 0.021810636202233936, 0.01874601637433854, 0.030057635909366994, 0.02195675406725176, 0.08028839699803822, 0.05514767426516741, 0.07394992340836795, 0.054760570037028486, 0.04049774424563493, 0.008912091387525923, 0.03372650758753862, 0.03127834339055323, 0.033617776728445486, 0.021062608800768372, 0.06610604108221109, 0.0699501783556996, 0.044984391800338225, 0.03684380745154716, 0.08604969228467635, 0.05156532838760365, 0.03495131746955937, 0.084697600724476, 0.07328800045915189, 0.02399197389041224, 0.09793875633829063, 0.0484375752538683, 0.024255517712463776, 0.030878139058909113, 0.05415763968842165, 0.05641761055636791, 0.014102462521423737, 0.00809264831214903, 0.04845685768692244, 0.02597871758494406, 0.046827017119334596, 0.017898968278220104, 0.02621303706790411, 0.016324316684697426, 0.06528549962827275, 0.02243930902031641, 0.10198905553308227, 0.001872905782112221, 0.10770532017153119, 0.0452034316596485, 0.048866856452678485, 0.012428486670908189, 0.03690854571158848, 0.03796493116345617, 0.11931449400200961, 0.02651226909590825, 0.022890801023271297, 0.022344540113643296, 0.11136376539305334, 0.0758793311674268, 0.08681320615353123, 0.10101051610564032, 0.06322035641078988, 0.031879075066817385, 0.01918279948914724, 0.025795768127746643, 0.042290389988451235, 0.02556010224525967, 0.049243878963733875, 0.05189157076059811, 0.01054673245356929, 0.0402347922265049, 0.03669027194020249, 0.012469940646100911, 0.06274723200007312, 0.034278439463026104, 0.06407599618297911, 0.015012761709400484, 0.07765781194452318, 0.03261305624619126, 0.05094269042714469, 0.07847556483841713, 0.011107768326426947, 0.026784919788159674, 0.039228026289492846, 0.03027402893489888, 0.01952299423846266, 0.0353673989734342, 0.049304698684042504, 0.02563136565919605, 0.027941092022604523, 0.013007802359249084, 0.026506098257678173, 0.020834670830217582, 0.11919205016907185, 0.010831227822739993, 0.03883940903770347, 0.01197977556711844, 0.027565770226741032, 0.029131449015450575, 0.02542472876337988, 0.044714958677368785, 0.045499153089739626, 0.0357074998769789, 0.03579391459483774, 0.03876148640448528, 0.03239840990112674, 0.024942016762290752, 0.0471070567296157, 0.013119183882560222, 0.03381191489977702, 0.04460876739974465, 0.05606402650535588, 0.06653437616243478, 0.038065947517151796, 0.04443479266258017, 0.10057160135118232, 0.03163972813185425, 0.026432749169367938, 0.0268966747793339, 0.0285680832776932, 0.03587034335660358, 0.022465018931055264, 0.05331961993849086, 0.039641989560257045, 0.10733183698668596, 0.025615013512452284, 0.09873678246813436, 0.019495099061919798, 0.037967903584602385, 0.05173211338959875, 0.02891414051484918, 0.005595307016084272, 0.007526454273536201, 0.01677362150662849, 0.04570794269262303, 0.035659462333686893, 0.05953817778537351, 0.022221240177450162, 0.019903330079790567, 0.043408365078991464, 0.024243683569253455, 0.06559933520733349, 0.05370401221537783, 0.07295693556267409, 0.056782877448225216, 0.060688558395110795, 0.03559413035550425, 0.08257266434450304, 0.07609470912645902, 0.07354709139514355, 0.1055370155541647, 0.09290321444671962, 0.11749603875702429, 0.0994069715060534, 0.10049562841173142, 0.12334723446157672, 0.1545693929637632, 0.16907563553221766, 0.09711571743771916, 0.1593177284925215, 0.08662047375354075, 0.0713478674691531, 0.17045180523587813, 0.13840993265471152, 0.16530642165772377, 0.15373636427665913, 0.16560404681630675, 0.16529679959339483, 0.11450449605622601, 0.18237882894614052, 0.1673265648705344, 0.13502337969839573, 0.10087658861471761, 0.12365477279789987, 0.09090355642500425, 0.2070920133302289, 0.19350896799756637, 0.09211862549906777, 0.1138717380742873, 0.11220859183419137, 0.14492903445516864, 0.08894823957234622, 0.21616459343462222, 0.11875708076742389, 0.14559681797700544, 0.2090441585788804, 0.19408954007010307, 0.17822102463293463, 0.288850081063086, 0.09868713230976174, 0.1441853775853111, 0.08994934795003745, 0.12028320452138302, 0.17223772472671925, 0.13926111762562107, 0.15821610937916464, 0.1777061522607842, 0.134951229537687, 0.1802364487441317, 0.1932204899287993, 0.2123690261355331, 0.23349552475396665, 0.174527668784703, 0.11715635537139832, 0.20408686490789538, 0.22718412471154045, 0.17408309264048455, 0.11499331377807165, 0.16967440985383528, 0.11280583397996043, 0.17078257135806546, 0.06022664951160551, 0.203147656434486, 0.15789232997884675, 0.13586184760976222, 0.15681726347294547, 0.16558276489377022, 0.09095229493874697, 0.13220406888473418, 0.15791865275992503, 0.22005690231678948, 0.26798187664920287, 0.07821768432134583, 0.29452486204043515, 0.09654248448749704, 0.14110694519214093, 0.10916307057824828, 0.09141356413883549, 0.09728332981467248, 0.2552828048506091, 0.15447081276966682, 0.08077589704865411, 0.147490878439238, 0.23798427905046174, 0.22520607036928977, 0.16858970596184655, 0.22904919640671825, 0.2499247246211575, 0.17934626989787628, 0.17954030464733803, 0.11733410309158987, 0.1280258636501047, 0.18725536162814788, 0.14395314569194473, 0.14782346785068512, 0.07460282950271523, 0.11759006838885047, 0.16430048692610957, 0.12181371029826904, 0.2867911431577898, 0.1410124405858017, 0.17628809286942407, 0.08808079821568343, 0.17688476811012915, 0.16885743836962408, 0.2647579641592118, 0.15281954089239722, 0.10394530701300791, 0.15118575114155972, 0.18327262372739855, 0.17179596778606215, 0.10236696670612982, 0.07947095820019323, 0.1442292284580969, 0.12766388710588217, 0.20986715151417643, 0.19963149672314046, 0.1996457153150151, 0.09513539547521262, 0.22821616771961414, 0.09514610538439405, 0.12516708398658422, 0.16231648774156648, 0.18185563685913242, 0.09531575555522596, 0.10919146945760136, 0.10522753135451388, 0.16056577765172528, 0.19828002569415878, 0.12435385101144353, 0.2145982194211214, 0.13713428900847513, 0.1862335229112256, 0.07966169877158058, 0.15430077189399352, 0.12767202295963803, 0.1827128432811268, 0.13378513646462273, 0.2069013953329094, 0.1430582937093512, 0.1028499928032679, 0.13503410492933568, 0.08509487860024938, 0.09922387649215038, 0.18697816037362625, 0.13584922248077008, 0.2339185891492713, 0.09130183021507918, 0.13089923728858271, 0.09809333755965195, 0.1695601401790496, 0.09891243110741339, 0.16264756029892355, 0.17056647327638444, 0.13902946795907714, 0.18870659262662937, 0.10439781982812191, 0.22070579411041355, 0.13670075985212482, 0.13342346635556993, 0.19471590887875329, 0.12203936915724509, 0.1599967735068452, 0.1904987633949326, 0.09891895817652827, 0.14729434624314308, 0.14233254797516331, 0.1310358614089989, 0.15245992389898147, 0.2766328172818307, 0.15085158358898856, 0.14389250217185867, 0.14279396273195744, 0.2806561578425669, 0.1535346226826791, 0.13220593813926945], [0.10902620897057558, 0.12632532465842464, 0.043782346220987464, 0.04027785785916833, 0.05307116230288821, 0.004778779862869171, 0.11373411037869031, 0.017871685972016667, 0.04493679092716306, 0.03677689350180088, 0.021592590342005415, 0.04688729291721698, 0.04749101233638583, 0.027878324523748412, 0.05047839517975527, 0.05807413013591882, 0.02145674188561257, 0.03329234257821114, 0.0703720553147216, 0.045653477671646306, 0.01577254473006413, 0.08927689895274178, 0.015901961878332642, 0.020924709143958265, 0.02435333756429534, 0.0057466342789872045, 0.03648462712824826, 0.08820079822814272, 0.05448898420699182, 0.05873349435146778, 0.007249708362524548, 0.07217030882114364, 0.004879807707883659, 0.015376052094413149, 0.0830429274168226, 0.029137702208132516, 0.07383038304866323, 0.04583510562717434, 0.007728198740345938, 0.07565773257444944, 0.0956684471138062, 0.02432154874587732, 0.03503710016488068, 0.009008170304549559, 0.029889002720254566, 0.03687392619829025, 0.07956376209134057, 0.04622847262409426, 0.00929809723710341, 0.031811843190582535, 0.03750124878640618, 0.016304944236312183, 0.02428469991671943, 0.01240093048827182, 0.043778496629167954, 0.029722522238209367, 0.03115856554359198, 0.015017263433565537, 0.05859170679844195, 0.016084713110279654, 0.03009875950914237, 0.0545129819112199, 0.022449122606626442, 0.032535968648810545, 0.02816058195857031, 0.0709528572136356, 0.03978481516242027, 0.021044149912232836, 0.02734619219066395, 0.047980324184942635, 0.030088823348764452, 0.03785493242884836, 0.0327494582011094, 0.007608328484028819, 0.024234214722509348, 0.007800844464180692, 0.041873867984019944, 0.06007168524628205, 0.08024338933248674, 0.0695921471642871, 0.022233723580176314, 0.02674063224525702, 0.04738456441930706, 0.068372106179595, 0.06201155010550734, 0.009452884344594374, 0.0385787591127859, 0.02675437586261861, 0.053674862569858955, 0.019069154176019856, 0.053855192006355336, 0.02643005062465466, 0.05662313279425425, 0.016425813758565534, 0.04880639296325465, 0.01945992030443684, 0.07089788274418923, 0.0444592270369251, 0.024414886983351845, 0.04107680712496081, 0.062282818009055434, 0.05536784793460562, 0.017938372010605472, 0.008715864668990816, 0.046405369986689864, 0.03897911666201488, 0.04562205274499232, 0.04851979180990208, 0.043487387048380996, 0.07241916482246692, 0.08880174057858606, 0.044404405785063585, 0.016341710711018215, 0.08861429418527311, 0.02257759746674809, 0.028700426881832462, 0.04697297219066851, 0.04257965329734068, 0.046583742068539706, 0.03380673997584851, 0.040893057105882515, 0.053516688396132765, 0.03439317645144559, 0.013857908103795303, 0.0562086217706242, 0.05749941863600285, 0.011981282845109463, 0.06253331343853666, 0.014095772658624958, 0.022541633469142744, 0.040459642862720836, 0.0622848519724944, 0.030014832661817634, 0.03674148491794064, 0.023863671400073557, 0.025947775293682373, 0.0777846914265425, 0.039340572266448895, 0.05520377105342285, 0.03555017989128828, 0.01665914307288345, 0.02319058271936111, 0.040154341503136584, 0.03250178197518953, 0.04251022274876314, 0.052287653539209604, 0.09076633475600712, 0.03441985163296904, 0.059612024830834526, 0.022888290170099468, 0.010606118631849607, 0.043321747347832694, 0.02230655555913766, 0.033093370392077395, 0.040780112763205846, 0.016237461466282126, 0.022570507323008873, 0.07442879730895643, 0.01694567336310302, 0.02273574291217712, 0.020831671595994024, 0.039933650724349484, 0.008337793575089065, 0.030072047938442523, 0.03948839659231805, 0.10762947746702742, 0.03814204303067058, 0.023770361890896194, 0.05764649602614584, 0.03786761884487445, 0.03356973535471386, 0.1088501236611797, 0.042256436971647125, 0.03151327382863289, 0.015259205491372175, 0.018477479574240504, 0.004161293843701001, 0.044776617263954495, 0.06135579033364212, 0.015426901180387266, 0.058072253220504334, 0.03684882915789082, 0.06181902071881679, 0.022457924956876426, 0.019172673722008066, 0.029666929152764143, 0.0630484577719002, 0.022465700749307874, 0.01921619709220625, 0.04905702628856225, 0.009253535817767824, 0.036071479741123416, 0.035944493006794684, 0.06293269039522256, 0.06557348740076827, 0.08340013123327687, 0.03174164655408071, 0.027939701573021954, 0.06085447388731184, 0.02266871979490163, 0.04502981698380844, 0.04602948511620203, 0.04782323019518968, 0.06411229725927114, 0.036910970379868825, 0.0520557587245299, 0.021379351683501756, 0.03054310774220334, 0.041701322000834255, 0.024811341314606612, 0.012647544724806663, 0.010935296079203969, 0.051066543861863115, 0.06034972919752041, 0.02543117730848251, 0.05427670124317369, 0.03784753968037906, 0.044729146625726454, 0.028840147912682548, 0.06594671777659847, 0.033545220541136886, 0.025862209018199675, 0.024507200578227643, 0.016472635137277748, 0.016849324400086078, 0.06766379660656376, 0.05770322100649919, 0.05548030964188999, 0.016674639116371834, 0.03721665478341522, 0.024277201831160534, 0.015311255420167601, 0.049270446892947926, 0.06352458141684052, 0.04460820815555992, 0.024778661918976617, 0.018845784004717585, 0.03649659342162552, 0.10363689533645108, 0.03163085300325146, 0.017748855264677156, 0.04734111574268149, 0.0749133249384261, 0.016989022448298433, 0.03519080038512907, 0.04966279116248892, 0.07357824053014479, 0.0008472323761745958, 0.01418854877908504, 0.007363165026500582, 0.10687655859416532, 0.032183675455950925, 0.023151625233191638, 0.07002757621868964, 0.03489671455275628, 0.062440275890572425, 0.03641511230999905, 0.0530931375349962, 0.045270502657419255, 0.032095471922788894, 0.06666674849487121, 0.007923506153371907, 0.03227669768215668, 0.03046525980255777, 0.02399120014160872, 0.04973260475502861, 0.018506571763165055, 0.0346842055930005, 0.00639210740524915, 0.060829016785588, 0.04268117909950595, 0.020602536613061544, 0.022742863699433305, 0.010335901226367681, 0.05871116671891463, 0.02032465737072691, 0.019092895240793308, 0.08275457958300268, 0.02660061627055609, 0.02583986989432766, 0.03343262093802614, 0.03879691797098325, 0.04877504081495347, 0.042059743897088116, 0.04117450248750468, 0.004928550530870956, 0.04408925636521271, 0.015459616007583757, 0.02140915633419589, 0.0055440293996775105, 0.03426909319034988, 0.03548410480781909, 0.02365631055116894, 0.0956528572245471, 0.03977682486537003, 0.04703518619099933, 0.03723420202732086, 0.05873515293182385, 0.034279818421289805, 0.041857569463430874, 0.09617101611389269, 0.06290560535665962, 0.02249781898553333, 0.0281866921502496, 0.056480525527149446, 0.01529535143485954, 0.05311049325692077, 0.0426573307824231, 0.04628697492843194, 0.02225549005332493, 0.06939893978978358, 0.039866836366033366, 0.03240176536623509, 0.01960779634124089, 0.04035422533390023, 0.024592533196893432, 0.016294676742907015, 0.032645419630552494, 0.06701570154438097, 0.039312131252259984, 0.03596706961792323, 0.044362688467146895, 0.0465945860431079, 0.03435060877593295, 0.05609883371019556, 0.0318330274369087, 0.055248824684249784, 0.1277216424744937, 0.053790461407193256, 0.05441115733476416, 0.04803519523251922, 0.04296331012982034, 0.062286533535488194, 0.039141703502184926, 0.04212858072752434, 0.04675848289362846, 0.020440284936358372, 0.006830928792741391, 0.05532875063738996, 0.08830391366275088, 0.022065197643373283, 0.09929071000266461, 0.03540343574939236, 0.031607958465634335, 0.03648287661734127, 0.015434256582070264, 0.045339013900487654, 0.06727122251064548, 0.08247268987038443, 0.01701356982061219, 0.062125536327761036, 0.048117377314596414, 0.24023758878390636, 0.2053820591179594, 0.1782224342347153, 0.1138587452230915, 0.17275569209408376, 0.19686218080741746, 0.14953883064370002, 0.1062776233940836, 0.16242907202291876, 0.11965500476259379, 0.21565165160404098, 0.07992707928943057, 0.21721013491192173, 0.10947318296999702, 0.17368412937127775, 0.15825914819875073, 0.22378654008911503, 0.24128414149726593, 0.15738691113168196, 0.16072449574787773, 0.07606700738711704, 0.14448039804495152, 0.13763051480054855, 0.08431303224736646, 0.24424668010925096, 0.10795062152488578, 0.13752805820155528, 0.3131735565200929, 0.11531232811150052, 0.12360134582606055, 0.1063139895878492, 0.18941997370171934, 0.14415245112632552, 0.1698286539965099, 0.14607579146902408, 0.1339798913367333, 0.17999370612444418, 0.12215307958784605, 0.26453867915176577, 0.13901357929552757, 0.13651712857667478, 0.14082042830846003, 0.16302401590491497, 0.15670507755731383, 0.14439548485942427, 0.18066142835924703, 0.1497841626405716, 0.19364726218965747, 0.10706083338347175, 0.14539752786438312, 0.24406994362511944, 0.14074738948575913, 0.15833525137314874, 0.1240354878527503, 0.15584446970493565, 0.1611390106019474, 0.16700926657405593, 0.16779588565470713, 0.19307107214004765, 0.057974393149056745, 0.07778268427618089, 0.13754281305497693, 0.2934173746935783, 0.08083716109995881, 0.08215851721263702, 0.28686762937614996, 0.12705720675688598, 0.16960236694543593, 0.12608406824931023, 0.08552324432399004, 0.23778537198180155, 0.1250948801997208, 0.22837772034108642, 0.12546408861394853, 0.20654092032101848, 0.1854170264015275, 0.12339647093247022, 0.17625020216068915, 0.15246334065112377, 0.1853565207772678, 0.11648136296219404, 0.1565694646729577, 0.14994795223878277, 0.1781596150249243, 0.24061070424654793, 0.0586010569015578, 0.19564989263251906, 0.13573982512518284, 0.09086322189579088, 0.08430733255320981, 0.24315874332622175, 0.2014824417569945, 0.07563298793449517, 0.18268808331941405, 0.13357191887353698, 0.09447089847057097, 0.1471079876946826, 0.18412160236508618, 0.10153555446454596, 0.2338205298949634, 0.18612176600483157, 0.13365104043435666, 0.07078285464235852, 0.17349599349883296, 0.14533475461986758, 0.14012463661211152, 0.1215766903553759, 0.12218712453520107, 0.15569761064985108, 0.19485234913806762, 0.15549475056750162, 0.17440157071236642, 0.10987782295072272, 0.19346425910630535, 0.12401000010750948, 0.15456755435274494, 0.09620209630098074, 0.26287488939781345, 0.1932973745128801, 0.1936096625943338, 0.24830789605696357, 0.10967337706637, 0.1681440726162926, 0.1566293114616025, 0.12563826636441294, 0.14036989200019068, 0.11899996128293777, 0.11845355673182396, 0.124673830615657, 0.12890736272017803, 0.10498124940861618, 0.12523796244133867, 0.17190420068800452, 0.09939072278117943, 0.1617769626600127, 0.3284919135753186, 0.1807274804600785, 0.15127841713688067, 0.12273236463266997, 0.16083369392060465, 0.11113551715689321, 0.20341036330548026, 0.20659054749675337, 0.17359802108858863, 0.1531399341840898, 0.12759811079670347, 0.1768120970096319, 0.13721701118253893, 0.16461450636627215, 0.12455251293196795, 0.10892114001176051, 0.19772255883341838, 0.24276736432746535, 0.20454368313714383, 0.2282551769167185, 0.17208954800040493, 0.15789864254334282, 0.09909646074858405, 0.2197765754235368, 0.11820167468319978, 0.13064572347267983, 0.13312156642636946, 0.08380666345117554, 0.1958849130859298, 0.1252620942109535, 0.21787404202886168, 0.1579503075129563, 0.08635280263279715, 0.17850705122034397, 0.14488996397103035, 0.2164383626152431, 0.19783639949896645, 0.35931592086149805, 0.19091546926046574, 0.11275541007278428, 0.13667685790888726], [0.06061477646712334, 0.04891824946107884, 0.0245861018887691, 0.03723065887067107, 0.04850263527083782, 0.046896784746598814, 0.04289265767100357, 0.05710981313079115, 0.006595909775745485, 0.014417832191552848, 0.04542251748423423, 0.04797714108961725, 0.009861251343071703, 0.08247419140271603, 0.022658279931713498, 0.04103006427026084, 0.04504448756755841, 0.04747090635881309, 0.018877819886491187, 0.03964052250188205, 0.04230134121532883, 0.03669275406507715, 0.03042286449682809, 0.03137028351756594, 0.03162836896315698, 0.03937016241252422, 0.08304298870385655, 0.0519167865446258, 0.06517254762471685, 0.01586325720117818, 0.014535408493341699, 0.014349502894366461, 0.04727266195620741, 0.025547245374670433, 0.023508447920903567, 0.014419508008887211, 0.01640706375661877, 0.04350101575255395, 0.05454708431516925, 0.06309793173005024, 0.040131703604974096, 0.014914848969408102, 0.0004100084316310278, 0.056633758433764024, 0.02971508735490422, 0.06664334450878444, 0.01870693056844175, 0.07969265638460075, 0.027663777770114042, 0.0459423387843755, 0.0408367841174045, 0.017388692433615367, 0.07439439996115624, 0.013984220680750668, 0.001890121692990614, 0.04344912478700281, 0.025264214191045013, 0.005879281445466463, 0.03822380759482903, 0.047365304968890645, 0.04852875503861616, 0.024756445369172483, 0.024695215791824366, 0.003452673286852998, 0.014096427663800218, 0.01739186978328132, 0.09127497117245391, 0.021137407710475307, 0.03279063542703948, 0.06258781676390959, 0.07013348787422143, 0.05469050746591342, 0.04603503159277382, 0.022971201950924534, 0.024264691615357034, 0.07866388457196374, 0.03502531390216562, 0.0685592767812552, 0.04561022434744143, 0.0642952696991063, 0.0711688940082827, 0.02869497999669083, 0.04917851634203427, 0.016807300646999673, 0.055539524407997254, 0.035141870349405274, 0.09579860545214146, 0.0447367615396938, 0.029841823195437753, 0.04931743489578367, 0.037031759462890126, 0.04320467762168377, 0.010038315329790838, 0.008024056151043624, 0.0503158045091456, 0.04487708586478426, 0.07264744370214402, 0.03588465387902914, 0.06745896767824888, 0.04362698358994338, 0.01676413925334571, 0.010331041356098029, 0.05029449577353174, 0.02803027231787001, 0.05419305210272151, 0.04093459439313701, 0.029696915749340292, 0.07411969615326774, 0.026756143610503887, 0.013387660353234219, 0.02330040908418596, 0.0075909335000981255, 0.034332345239818096, 0.08568259827311962, 0.05920944562662513, 0.060425215671139385, 0.0664421544981099, 0.03783930806563266, 0.021859504950923786, 0.0018840370396520163, 0.03501150516733047, 0.0525008098432614, 0.016603768322496645, 0.10689257749266202, 0.034617793430844625, 0.04721483763968272, 0.08542971264931463, 0.0587553853139041, 0.05796116281060442, 0.020955810398464243, 0.028093849954706047, 0.03534771817465944, 0.020624092412030986, 0.012392691212646183, 0.05913326201299506, 0.02092512857709681, 0.03950936058836599, 0.0034305915206430423, 0.006465765322753859, 0.05161373365309931, 0.07405815631031029, 0.02898492320861307, 0.03522964104289009, 0.05895741419085573, 0.055191214872343894, 0.015429610258809503, 0.012581993453955699, 0.008600641214739411, 0.022527809412549102, 0.06250363902278966, 0.04450446452885386, 0.029842844007596857, 0.081450498753017, 0.039210816124273885, 0.07063670804904354, 0.028143011732026938, 0.03981494540048223, 0.040394100210359024, 0.09664461932956211, 0.030888395060995416, 0.0518006859197011, 0.06999274986165185, 0.021569812632796746, 0.03696539326600971, 0.038901726459904064, 0.018452733019066435, 0.05378768050802812, 0.08759491461058778, 0.018436587716062224, 0.039338519150811824, 0.05787528052385296, 0.06473977689541156, 0.024840146220559557, 0.08522638525333136, 0.040645560910624844, 0.025600965375140793, 0.0438918125244879, 0.03010949623140116, 0.010762181275734499, 0.02064974678139533, 0.0416352545782443, 0.032442774052821824, 0.013248170106371325, 0.02745229728339661, 0.024519456069796317, 0.03401051170282787, 0.10618224544751068, 0.017572099628347545, 0.014029586492406746, 0.08958896486869744, 0.03779862879685337, 0.047216136158714374, 0.0434916656494381, 0.10624672706809737, 0.05249171637960019, 0.06748894469872599, 0.02066692821831713, 0.02541486921179439, 0.028078196863193187, 0.023351330948512883, 0.01180069006588911, 0.038845346219116644, 0.020839409084029255, 0.01964718858230739, 0.0972636107115015, 0.01688410096140879, 0.015914372502705984, 0.021152003600652662, 0.026556062512099746, 0.053490989976712776, 0.03614289828786447, 0.046504176176723935, 0.05547898430978099, 0.035923011901397864, 0.07176601357998387, 0.08702031802386047, 0.014973985211503123, 0.030640715004635916, 0.028985769735769402, 0.019673806307236516, 0.02400275657794649, 0.08346343307846016, 0.046174513221147566, 0.03595266716494676, 0.006797106010884408, 0.046177489472733396, 0.03885191925350697, 0.03987240582524289, 0.016349743142904296, 0.012202937937071247, 0.01874907881081585, 0.04944481999583302, 0.14010888584438833, 0.053900057945640824, 0.030523938307118033, 0.03211604329877563, 0.012812084131573719, 0.028731784775793075, 0.07911052149269851, 0.04283134765442341, 0.01718024182463846, 0.014168903411876772, 0.03985749392379676, 0.005757003279042341, 0.05232007821060477, 0.02292923948487207, 0.01672621981631364, 0.02739748369241434, 0.04387755562821704, 0.050416928115150625, 0.04829127161252884, 0.09620195074427514, 0.02512258368604366, 0.04495588949911537, 0.06974154963128029, 0.014552717292380911, 0.019070400984116623, 0.042420797305361885, 0.041184653152501395, 0.040677357389922106, 0.010631482845412628, 0.028178293911379673, 0.09047903646264346, 0.02149661484685156, 0.047335067478519295, 0.01375890177329101, 0.1157042740153209, 0.0324049522920001, 0.02827279277205948, 0.07116184599937932, 0.0226696984722249, 0.028867932006476388, 0.05354468124888597, 0.05171635879143592, 0.04630385950628308, 0.0445406966572327, 0.062058484482188384, 0.021978124089899565, 0.016187085439601255, 0.03765861856781187, 0.05236959047315102, 0.033221395175543525, 0.04883036768484501, 0.05375034521303831, 0.03666238250931905, 0.016065106047467602, 0.06667417188685748, 0.05022383565383573, 0.05222321022301913, 0.0813883077353239, 0.02431159726374092, 0.028757831765218612, 0.010204050791329675, 0.04116163987125601, 0.03650776681400115, 0.02589540552317856, 0.02602148635853683, 0.034035593421468814, 0.03373951193005328, 0.04760340509575702, 0.008793867741441055, 0.02621166960095927, 0.005085003400792278, 0.027971199278028745, 0.046652509951062744, 0.024038205381422758, 0.05609528289266652, 0.08507604815907056, 0.007445070359315123, 0.019919364300045758, 0.03930977936233244, 0.007591043146432288, 0.05799982726814286, 0.007646808601660475, 0.03901099358054419, 0.044812991118599335, 0.05890766444105295, 0.018226656642171647, 0.0040618958507454206, 0.014978504172646472, 0.10351565426155444, 0.016815691224990353, 0.07264820212918906, 0.11789654952383812, 0.017276889561945875, 0.060228005487231485, 0.06008836681083326, 0.062184440828258955, 0.09035952674645571, 0.07555269425915134, 0.06724998655338442, 0.01869663817717904, 0.01925056379648947, 0.05569814674315914, 0.06822024457036488, 0.05184043822209201, 0.08652013921809774, 0.03073784920777525, 0.034477974723784194, 0.0750020225982993, 0.12587505648092878, 0.04265566454118779, 0.009558860159989808, 0.031006081487923384, 0.04347540160280563, 0.03424781126781337, 0.050137114500807184, 0.023625148009629022, 0.009756966666769116, 0.021459923065718145, 0.08336296830807002, 0.08780581095526296, 0.17828388980800108, 0.16158685028072328, 0.09865995917108752, 0.09603957840872389, 0.1200264118491642, 0.16213294839666736, 0.10744342535373666, 0.11141044313027976, 0.10436770491181843, 0.08615622447142679, 0.1701518971352808, 0.18954993285719426, 0.08042296034193809, 0.2805690996108517, 0.12177745135681284, 0.16380370955073065, 0.13760797649381623, 0.19555485176463283, 0.1090072942597251, 0.11812146527752762, 0.1543068546321123, 0.12634573324072745, 0.12388187190217358, 0.10442463290547171, 0.09957298275924499, 0.14143268577754498, 0.16298496074253516, 0.16639434311899448, 0.14090321176955778, 0.126217934453199, 0.11946752772576387, 0.11570225920408003, 0.1771922298376599, 0.1493522269471038, 0.0889692303814715, 0.08244367812069194, 0.12061642978580729, 0.09227761938687294, 0.1922983498943429, 0.17297974216841883, 0.10184476287254404, 0.16043759582023467, 0.07744101672283105, 0.12857610630171915, 0.1014270534318301, 0.21919189711972592, 0.1077206266082583, 0.1562725289935066, 0.07877350409304903, 0.14729293664136242, 0.19049530067751486, 0.12976820039893353, 0.13010498797220568, 0.11933186887613229, 0.11242163322505452, 0.1841853408803863, 0.16176236102417593, 0.12561043439012382, 0.14140267045267169, 0.08206477103334281, 0.09124693235442524, 0.14386817121938353, 0.143743084383107, 0.07087575812493602, 0.10862496275935443, 0.105068483840554, 0.14815066400314533, 0.052037058518298214, 0.31478194279536126, 0.21535537476020478, 0.17044284200716406, 0.08824167667978233, 0.14366843677576513, 0.10812514401491612, 0.11891292603386026, 0.21614970068537423, 0.10103377453502148, 0.1277501945714316, 0.21979143752926783, 0.16735368438305395, 0.1726445174145122, 0.0802150517401676, 0.1284241527619381, 0.10484246492025354, 0.12869396126799046, 0.1176434264127766, 0.18595512655954208, 0.1584763800905597, 0.10081635112123144, 0.16333471052348614, 0.20277147662014733, 0.09198725674181216, 0.20275566456539018, 0.14226035184917912, 0.19385738478552914, 0.12187117455346931, 0.24706465792992424, 0.23988357955409637, 0.13369974830458242, 0.11494239191374472, 0.08753812451276087, 0.17644396111849817, 0.12889777129936603, 0.10034810286015274, 0.14632020416038652, 0.15875719728008394, 0.11806492798871572, 0.18949348749893327, 0.1349821335245525, 0.07979306752883619, 0.18066201058606948, 0.09477413139275967, 0.18414536641249735, 0.25729280505930224, 0.17093004328348946, 0.19358312530863672, 0.11231782831131451, 0.17098215258409902, 0.10999069834548621, 0.13019328726635826, 0.06963202204074591, 0.1370925831818773, 0.09702137370984401, 0.2699654315027499, 0.09325579109211123, 0.13684115312512846, 0.13745143408736876, 0.1600854864884769, 0.14019019841667146, 0.14683578133342728, 0.17349119778842698, 0.12763007198490445, 0.07548795982954964, 0.07356418281673424, 0.15333453583861553, 0.10996924022272711, 0.18785729223201353, 0.12812673444709471, 0.12718998511592228, 0.13002549868918237, 0.22222624881373298, 0.18017229654135244, 0.11468415899622826, 0.21925151408199342, 0.24396238488055047, 0.0899546186349565, 0.1330162293367809, 0.23943460606519254, 0.14126411579068632, 0.13153741917302533, 0.1621490055995603, 0.23560632681173665, 0.2301195744545229, 0.23481520313409068, 0.20224796277621102, 0.17046285222374624, 0.11137221534285816, 0.18440027450842245, 0.19915736490680327, 0.16371810688607155, 0.1527041527292421, 0.1452522163069056, 0.1329353151302184, 0.15790340761023183, 0.1874254944343721, 0.10532624944443665, 0.16387322436897986, 0.13338890046842639, 0.14346995871634255, 0.0745750128501846, 0.11127843852004698, 0.2322967350482941, 0.14578944312468653, 0.1928198719096761, 0.15918827495507656, 0.16286229474409936], [0.06728525724141829, 0.040417940866562634, 0.013765980425711363, 0.042255697696800196, 0.02017440071569816, 0.024800842079604347, 0.033644497875244386, 0.059926431145398855, 0.04846876652370538, 0.028711167434530876, 0.050476847682148225, 0.015981063329344316, 0.022525681603339412, 0.024087535698086988, 0.01718032226387051, 0.07603567439101397, 0.0322993585629569, 0.02325951531078787, 0.07785164751112461, 0.015016736748117595, 0.05561674990120435, 0.0787257461718494, 0.08690119135163485, 0.07018469319108032, 0.024121772167423082, 0.03652108908300439, 0.018620339650360328, 0.051681241320986906, 0.06224978046732084, 0.0894895036734881, 0.0023366778153896092, 0.06229550825552114, 0.033067537907270655, 0.02103749069295103, 0.07951423450703583, 0.02533429208391857, 0.05593166949467794, 0.02392190940407736, 0.061726868002405094, 0.020960110066939267, 0.024521084006635413, 0.03072623723006297, 0.02888170052169552, 0.10593461518686627, 0.051843613656538154, 0.03393240903894748, 0.015646139264947945, 0.02365502926911558, 0.035035916559037664, 0.05382349128804861, 0.05386740727830799, 0.03857824200343701, 0.02846617251634598, 0.03520816759837251, 0.030313953607072754, 0.04010020973040693, 0.08079481942038383, 0.05413973621363121, 0.05302314008135469, 0.1007057739902408, 0.04523923860922937, 0.03483905494513531, 0.012027399422931335, 0.06824000963881131, 0.03584728794052236, 0.06211808995313703, 0.05375083550930985, 0.02333364580878087, 0.037905302709869804, 0.003651682101565624, 0.05950053222477437, 0.06388138303713453, 0.040869044079895944, 0.0582224945537746, 0.08802766235725534, 0.05432694128924801, 0.01458307448399043, 0.043512978215491584, 0.036085763450471625, 0.014259553638346975, 0.07636053397530511, 0.045169762095376376, 0.039328307198781165, 0.012535275497113266, 0.07527176215643845, 0.025686215639354724, 0.0019905178745712846, 0.032950648211783944, 0.014188682844471789, 0.05509965970451313, 0.06649608708797924, 0.015484280208305968, 0.0021831616956455215, 0.009222308158754342, 0.001253671406659358, 0.029772118770427285, 0.01938603495457961, 0.014603283883432948, 0.05218178018807404, 0.016326731776878718, 0.05096165110327063, 0.04895414068033138, 0.030388302440124176, 0.018682312332994996, 0.07662873369671645, 0.010503162160485743, 0.016032167139553254, 0.03483623191113434, 0.06088447005998704, 0.04969438462848625, 0.02460978358172842, 0.018045409815385938, 0.07779343248975855, 0.04249030446273185, 0.03509107872002548, 0.038272814239345254, 0.0687689780287685, 0.04670522829157211, 0.08538063705688523, 0.029334477637143388, 0.04847532423633722, 0.024646620919567444, 0.033897295398938085, 0.010763047912698841, 0.007692944331680455, 0.0729241699821526, 0.02157096559512279, 0.03096889941051843, 0.05235200109440954, 0.06337647363843937, 0.054013170827660835, 0.050613927624879346, 0.05205621454684485, 0.04141924842711418, 0.07852523031854823, 0.021145350127030286, 0.0361827080468497, 0.03671836821482547, 0.05490457924503473, 0.07077016822633243, 0.02218116420291124, 0.02348540782658083, 0.01605686102618253, 0.021059852799460776, 0.06122603419146711, 0.016681351961808342, 0.029263497675738992, 0.04315643706509183, 0.07301929511971052, 0.019796709792928833, 0.0568026501775509, 0.03917584421053048, 0.05689375718394595, 0.06722212393557833, 0.057305931639406955, 0.07448721151318281, 0.020060868400539604, 0.04198026610538364, 0.04509652792025478, 0.05206091832669993, 0.025204957290101918, 0.011960588895054835, 0.029649831985514012, 0.040779067053189205, 0.03410194046615112, 0.023685190150694504, 0.01597029692117846, 0.03205147166285784, 0.0289609101826265, 0.04376647287919637, 0.029697293047643, 0.02147361688736466, 0.05048692556879213, 0.043168001162308844, 0.08185528429044832, 0.06019377667877463, 0.028777432124761325, 0.06287116204358398, 0.05024199193764118, 0.0956868255631097, 0.03540458105083916, 0.054115347804561745, 0.013517989146132624, 0.032359737782709064, 0.0019308201139680143, 0.0184969152248795, 0.04515354401401935, 0.058126120692900116, 0.017849856296614293, 0.07721696664849598, 0.011058192861626947, 0.042556620863897186, 0.0476572189419981, 0.07175954779790295, 0.0920930381623968, 0.012610304233197485, 0.06923986929318598, 0.06644972344680179, 0.006406848852132117, 0.06357137023681594, 0.03261368443828917, 0.07468156035869353, 0.02788345539762128, 0.05940376382861888, 0.042282108577989766, 0.05653597497110886, 0.026024690521280133, 0.08289423741159901, 0.03546656522479269, 0.08701516225213006, 0.04024446025610932, 0.05533175370205314, 0.036751244878095966, 0.030306832819816568, 0.05689910447765743, 0.05259468242706311, 0.018845563754439354, 0.015798364765942097, 0.048138019553716146, 0.05934955544709679, 0.0282638295433454, 0.01374304471086831, 0.06470346432780066, 0.04224264355857046, 0.01412565966377095, 0.013391002411803892, 0.05573403030153244, 0.03474913537502289, 0.08905656440483947, 0.06258519674320856, 0.022104833117355744, 0.020066225270350135, 0.05831491923139942, 0.02528580829441067, 0.0034502318603993067, 0.014861205577730172, 0.14444011714189284, 0.005616417047642773, 0.037985960276977676, 0.05867977626621724, 0.031078162700718934, 0.0465349882330385, 0.02910114832282547, 0.024686170208658424, 0.0063210905758633975, 0.04460047832840393, 0.05313067967372556, 0.1300153403633064, 0.012121857106385213, 0.066740698962202, 0.06658519843533155, 0.029152788394581408, 0.04945249619683431, 0.017688958680317286, 0.1028450362143978, 0.033208992212049426, 0.032011292266449144, 0.005308953883697189, 0.025611441627505328, 0.008036508431447851, 0.06819996622300918, 0.06221648628613161, 0.032359439008418596, 0.024778081607373974, 0.04326120724961643, 0.0032494907293679014, 0.017203525151877154, 0.009303734686616208, 0.027830457435019558, 0.04037570260885743, 0.0871620519507316, 0.06610104618894477, 0.06045093324275748, 0.09756963219373457, 0.06745983335760332, 0.04812286250413426, 0.04517494851062375, 0.016506601560620532, 0.031755505084630944, 0.054978173481480735, 0.03158322148655932, 0.07455017627967943, 0.04385611665765605, 0.030948724485032504, 0.05058051853050148, 0.043504486130850936, 0.013837059978545915, 0.017287191529307636, 0.05574870854616166, 0.019981880905106664, 0.03529691122352116, 0.047288715328660705, 0.043357841580385165, 0.023541447158241947, 0.006936014988534754, 0.017912076042604544, 0.01806278468950862, 0.05063415617651997, 0.015385360062693157, 0.007229087669627682, 0.044534629240872405, 0.030958700865026445, 0.022835590981788213, 0.024573471014117523, 0.010269076334342602, 0.053316356403933424, 0.02039894300152458, 0.01626579522816164, 0.030695965265735026, 0.019981396354494557, 0.010176991608234183, 0.014461556659831155, 0.04107835845300748, 0.039413802611130866, 0.09838939989886938, 0.04730105700512086, 0.08425214357914464, 0.05465105010737335, 0.013896867505184585, 0.02836116867500448, 0.018925564401152156, 0.10314166545867921, 0.018992325133313576, 0.00843508578386278, 0.06025794420331236, 0.04227234478739481, 0.037174914482860796, 0.012813649823768966, 0.05257666403908403, 0.03442524106151635, 0.03767574829379878, 0.04107329461182799, 0.014280424746234092, 0.045027016932445194, 0.07310349584346817, 0.0092089849321412, 0.038120469994722836, 0.035112690060369434, 0.04106812734877871, 0.012821007140671775, 0.04377797568937944, 0.04060579328647545, 0.004226045031476045, 0.044411204815391576, 0.07978339183835254, 0.04761034202191138, 0.03786885990731178, 0.06820178185138973, 0.06841662354887494, 0.03883920985484316, 0.06926948625233866, 0.06434315785525307, 0.1677019939187073, 0.21136799436663428, 0.1555927178912586, 0.1872994270055525, 0.10540678060703701, 0.10260725784445963, 0.13530156154546047, 0.11956413907389488, 0.14177408520012133, 0.11479485870128679, 0.10499835615196537, 0.10337505414481125, 0.13996866111072803, 0.21357503238945238, 0.13603741964024885, 0.1590835967011029, 0.17522434914304366, 0.15658429613517177, 0.17032543137188882, 0.11854559453504702, 0.19382931532398348, 0.18359142355620864, 0.24937539361417296, 0.13234176552824437, 0.1429948003421868, 0.17287434379179634, 0.10748817254939388, 0.19168917209871356, 0.11020711052321619, 0.16052937315356347, 0.10017842204580385, 0.23268532548700613, 0.13295629061758518, 0.12088187159069123, 0.17908117283255826, 0.12528004365101938, 0.17075125368372088, 0.13732697544319017, 0.11111963615422288, 0.14577844210209387, 0.1836913367432933, 0.10842440860165704, 0.10268029666716054, 0.19862251296158762, 0.17734633608450814, 0.13515638788380932, 0.18089701571772177, 0.17587736248970035, 0.17105971132555317, 0.19383861563138424, 0.17431445119361724, 0.1386294015232594, 0.17640887429156613, 0.14250321704293453, 0.13372358896078604, 0.1674869223948448, 0.18082219957103654, 0.16797115125002401, 0.18260389025653564, 0.17684376708442168, 0.23628455977286064, 0.11589675360629637, 0.14984302883667333, 0.14456615392719546, 0.12227869502479032, 0.23106167874028608, 0.16391074735551112, 0.11081035879831161, 0.12538390985179332, 0.1332712446850154, 0.12393607262281642, 0.1515018696626348, 0.12702471696801726, 0.23580488147995166, 0.1916786920159094, 0.132496515288949, 0.2683582096811264, 0.2107954968608195, 0.2396261893332966, 0.0801072708301006, 0.1243404214901309, 0.09367215221807842, 0.08218758258848421, 0.10401595564138505, 0.1250991013441836, 0.1756468006680089, 0.11306221296470012, 0.19851971928390766, 0.1670956659701563, 0.06705759123208062, 0.24668185911591978, 0.10124290887747081, 0.07066922848142924, 0.13868396230522664, 0.11544007327287428, 0.11876398321962166, 0.15877564467730063, 0.19486103657512896, 0.11761418483670681, 0.18416435007126103, 0.17973168873258177, 0.09993013294954455, 0.12334511239802647, 0.23245943680165276, 0.12430171106731701, 0.09671322250318143, 0.14893541382926126, 0.06415475002159515, 0.16549530829633438, 0.11178912039125159, 0.1864936557267943, 0.11558850280820362, 0.12360205062695089, 0.09614590375173478, 0.11506397006732803, 0.14142972867815726, 0.18603354331947144, 0.1545276564936484, 0.19126218533323658, 0.13538880363827752, 0.20027904020201778, 0.10218742634019545, 0.10009446647018196, 0.13859443727039522, 0.11051900023894926, 0.18234748062827896, 0.1983893464409536, 0.10720521031368165, 0.10730440337811747, 0.13026431893869755, 0.1343678842268644, 0.23790569375118903, 0.1008762285533932, 0.10405588414399855, 0.2062256138531431, 0.07322880484524273, 0.15851257008410272, 0.165606452332389, 0.2495992598274062, 0.17718685190043143, 0.1278522068394288, 0.11551452935823511, 0.1010313077319053, 0.15313613438798537, 0.1978411339223385, 0.15599073121143928, 0.14718350864225818, 0.1288081543339837, 0.16918483370494458, 0.10846201585785997, 0.18251718442526557, 0.19904874896089877, 0.10873249852128568, 0.13692241973213612, 0.15520213562394344, 0.30266543489790737, 0.13098657131195068, 0.1919775735586882, 0.19252713439205002, 0.23277774633419132, 0.10003930813963376, 0.11511353595602898, 0.1109460712740979, 0.08741431704331791, 0.09150315812158008, 0.07882168336260705, 0.13447516717978064, 0.1168983982455346, 0.2005333507493619, 0.1788209021211632, 0.07985585609511023, 0.19220643466518772, 0.17489149926170228, 0.10800069303161676, 0.21525297944824542, 0.16343866865481102], [0.027187805427538774, 0.005215022406886302, 0.0610705413254759, 0.04019134738031895, 0.01924589257537117, 0.06355436691533654, 0.046556779604044654, 0.04658063558200675, 0.026613551665157564, 0.05343883854126739, 0.03193352859647524, 0.048703871246787815, 0.06729444263563042, 0.04430127119825733, 0.012249930727956517, 0.06524360227969385, 0.07904751076092643, 0.05139274026958212, 0.017223818820991346, 0.04422021526542883, 0.056603026816681515, 0.05041431575532883, 0.07721269953875773, 0.0013160253377375946, 0.043438859208817446, 0.029753579442659696, 0.02088393411418844, 0.020112248002401283, 0.09417233868472039, 0.037653091243438186, 0.054921008000570926, 0.02132582512023228, 0.02140981516981077, 0.027405533361278718, 0.03943403499321111, 0.015278347155770228, 0.02272542179261725, 0.02263821225853697, 0.0401004740307408, 0.03799976135093359, 0.030384715233418732, 0.017084988367353237, 0.017215267364536564, 0.03963524415608376, 0.011187575535938866, 0.031047067191872387, 0.026975465007126335, 0.04654971244294317, 0.04074696413872223, 0.05096112250260288, 0.11971305890549576, 0.09967711709079244, 0.055301903086083556, 0.07724139719240128, 0.05218109453938181, 0.011749729897165972, 0.08373869613053338, 0.04798971642289431, 0.027129439103807655, 0.026973174404232737, 0.040225442123389056, 0.039400150924320185, 0.01493272275829147, 0.023747013446183938, 0.013001599919892127, 0.028368050059784326, 0.039383208889874725, 0.030094911832542672, 0.013143876811579592, 0.020045868398982192, 0.005237215974052707, 0.08343876504729833, 0.06977611551842383, 0.018953695149731734, 0.08936425595874749, 0.06984399090851508, 0.04505066989710735, 0.05507673452337904, 0.059109245156568874, 0.03436586924738461, 0.033696607175853946, 0.029882778255869786, 0.030669328388607794, 0.053169876562371376, 0.06349780664388692, 0.05352787711026688, 0.01419705905831389, 0.042968259057811195, 0.05157707634592249, 0.015235384944976579, 0.024410922478343693, 0.08918018801318062, 0.0588060888431726, 0.04394627754546462, 0.05886498568279128, 0.029991597215074207, 0.026463875321731455, 0.02906189397758534, 0.05750162496922478, 0.07891605773399915, 0.00906195542249348, 0.04305665794339392, 0.03484772706043816, 0.07121010953860898, 0.0494528524277191, 0.10295605767638454, 0.014068952878005804, 0.034472696377985904, 0.01620589672858196, 0.050658295607014056, 0.12685328947320101, 0.031632697359929164, 0.029854247226349773, 0.07708637930092312, 0.0323940891652338, 0.041941107521134044, 0.03566334256902337, 0.02964588663270397, 0.050613889320483135, 0.003007976483786479, 0.025820600867812193, 0.06380618384648716, 0.054569837126520374, 0.0576058435704439, 0.032034786267867016, 0.03961944742308509, 0.02374647526941713, 0.04802596770347126, 0.042030318459916505, 0.050110761076211936, 0.025880340404147585, 0.025434707058593634, 0.07394946375561338, 0.05410875944841293, 0.07895046274267858, 0.018529724855456623, 0.02327901990934005, 0.0971349309228601, 0.046296535705726956, 0.01545374777408377, 0.050407532046759324, 0.018879099253324733, 0.04432429214038196, 0.06458128862563642, 0.015927598053108782, 0.02520618494600058, 0.08230688546093241, 0.0843305450173155, 0.05627285824307511, 0.01769235436504166, 0.007793403835216118, 0.02870516705086395, 0.014259553638346975, 0.04826822768776648, 0.09311082427419963, 0.07158288792256387, 0.041268244836359255, 0.01905914523728913, 0.029204210131278927, 0.07704748501700741, 0.09246941715959581, 0.05737517066600342, 0.0698774995943231, 0.05294951137095209, 0.009211965971776556, 0.06272728307052486, 0.04956875770022312, 0.09625002276152374, 0.0665973792333276, 0.013266622291637525, 0.03073350548924458, 0.047562806266209776, 0.044655552389280456, 0.06354325480999486, 0.030238411592079267, 0.025689090384290587, 0.03713993107779853, 0.018450737360023686, 0.03171413250628018, 0.030003837384884397, 0.024089540933228792, 0.019569535995082512, 0.02969533760821627, 0.06368496958466788, 0.05920374976290811, 0.03731475234211933, 0.03246736930563085, 0.06500914873134706, 0.03194932149903428, 0.07276129968945058, 0.0190270499837014, 0.02652250020013702, 0.05210455086442733, 0.045902647769018534, 0.057108365224614266, 0.053013391612518224, 0.033442786924781344, 0.01823975100001741, 0.040161994721500144, 0.03558884817926634, 0.02740242495952595, 0.013687424812345736, 0.03417766059658701, 0.04569303462161653, 0.01997239290616445, 0.011393952919470688, 0.07785938499915986, 0.024845062589813626, 0.045496521577719724, 0.033024518239882686, 0.03326137730431172, 0.015259254329477348, 0.028607511907936107, 0.03809941406812399, 0.09096469024136182, 0.04507961652932629, 0.01629835588016337, 0.034952692597383456, 0.03167729133800153, 0.044253436668265256, 0.013432682382934278, 0.028011621907353405, 0.035852018533454794, 0.027567256437314135, 0.024504017482902256, 0.08034377749408446, 0.01829784727775522, 0.019098062503842578, 0.04201209705863749, 0.09493903947934028, 0.03432536617882791, 0.022219014692030126, 0.044343030651009856, 0.05025703790447405, 0.060006835903491706, 0.035183323366988095, 0.051355159826456546, 0.06714310962706804, 0.05847052701057927, 0.06354069224588814, 0.090509879162475, 0.03608351881285349, 0.08457562420517208, 0.030623196489027435, 0.002436832320170417, 0.035792137270853404, 0.01770513079639885, 0.03803691278482157, 0.037430102200878244, 0.00799071073772446, 0.01329098484523955, 0.12688125934331648, 0.05531294624351206, 0.050078313422179034, 0.1314019135409786, 0.024456315103077123, 0.04544874067388235, 0.02206286873608347, 0.05310997614757188, 0.033166003188178424, 0.053516787987562923, 0.020010348732372927, 0.060433853312485644, 0.05614836129450029, 0.02986470815695582, 0.0461988058692265, 0.06549895470661503, 0.10342370072800307, 0.03312135175351174, 0.036027119419867956, 0.024064859495528286, 0.0421437684206232, 0.06450284888306934, 0.054890663257890174, 0.07553870549365398, 0.041854282946235714, 0.038286220778020165, 0.04870186026598658, 0.03975332511829273, 0.008115506460589748, 0.06506830604086, 0.09677770412376813, 0.024709827003760204, 0.026128784633211555, 0.03883420730069761, 0.03515646432436282, 0.01724677847608203, 0.041134229245325254, 0.011308008388075377, 0.07893305722503893, 0.06018029353130729, 0.0043549986965503665, 0.049799112678175016, 0.12133328890007351, 0.056044468280649, 0.09223429711475488, 0.017118460663984862, 0.043476573717329776, 0.05642164400928924, 0.03015231863114863, 0.031190293074976054, 0.007852056963113889, 0.033897762712571895, 0.017495542546854388, 0.06134855463319729, 0.016980666344264345, 0.02732343171843358, 0.02531205829713614, 0.023759209565938483, 0.01798152957381981, 0.026452929840513298, 0.036146311209567135, 0.03762492985134164, 0.036409588816064986, 0.10321691827548128, 0.034239319183172724, 0.10887597146774493, 0.011676266853277002, 0.11005697261181571, 0.03136269541667595, 0.047503599160981756, 0.04013362648566404, 0.02595722498822837, 0.08579221779420491, 0.012746454336710516, 0.018271748577394796, 0.05620738453862648, 0.09661830420936308, 0.07696744415067858, 0.0673061101547172, 0.06499502973090257, 0.02435992209000453, 0.06615653393730041, 0.029431958495068456, 0.0720575483395688, 0.07900709962292064, 0.0547975299489354, 0.03522478404545015, 0.037771187527405645, 0.01410081447477663, 0.03495395664245852, 0.06965742551631506, 0.005759395867390859, 0.021384268052755825, 0.0557711587527827, 0.07680604474679117, 0.012696520725805915, 0.03288401771456965, 0.06072714241341718, 0.06713559430453085, 0.04193786313877471, 0.0499470480867932, 0.22062710155883145, 0.08820229976047432, 0.15947204924398856, 0.1902532322152007, 0.17263900158145737, 0.10084072037810281, 0.211553035243865, 0.13907874273436685, 0.10655144620085917, 0.18289362470949852, 0.10840075946743451, 0.10555678062261113, 0.09206212651465209, 0.1240870685526921, 0.08160585372318184, 0.1376876496379414, 0.13370356342244533, 0.07214699676560779, 0.2265439663202532, 0.13868593881207128, 0.1063412469961951, 0.16753976713986168, 0.18083408925562136, 0.09164572708428868, 0.13830173039628615, 0.15136593502135048, 0.10931873964446207, 0.10138032972932824, 0.13430337962363997, 0.10083702017342853, 0.21484827051960656, 0.11901592655527977, 0.07736839158760925, 0.08422023601709835, 0.08920040507350238, 0.10369805213544639, 0.1472168334669644, 0.16960947624137326, 0.1520572221207042, 0.13873199601807903, 0.18664192438365954, 0.09009138065119905, 0.1442384061914298, 0.2313851210619173, 0.07575068202230238, 0.18616088245424534, 0.13234410975729266, 0.11318506282423774, 0.17272368494060733, 0.14341224165212724, 0.1810175366699696, 0.15677940340772753, 0.11053991443928211, 0.23000133644428947, 0.13804524415923705, 0.09108927912048756, 0.17559908871208468, 0.13574330316435906, 0.1505648215571719, 0.11208135229084762, 0.2172873718964477, 0.15147315668723277, 0.06951340098655032, 0.1102202642528761, 0.1733339965463646, 0.18997256824326134, 0.31108743781524323, 0.08778390850150779, 0.12590755393067676, 0.08535600733011962, 0.08494778205790827, 0.1681461104101712, 0.13357225595222366, 0.06469787188595341, 0.11917547202639042, 0.2700489350864964, 0.13518009064418657, 0.13040088177207979, 0.17350538573678465, 0.05668315578312163, 0.07545075859994659, 0.17118597793723309, 0.09523864880564714, 0.1961767925850807, 0.1544761294198613, 0.16265981770571203, 0.19222080647464723, 0.23608367619735582, 0.11695631449261021, 0.11286699843983497, 0.12502136640250683, 0.3397282477348082, 0.25461496004173834, 0.10818252400044473, 0.2231870609666071, 0.11439041024254215, 0.1960031204526463, 0.11685874553457384, 0.13261401785477517, 0.16230821399198425, 0.09008152876049282, 0.12084945074973569, 0.13667981500827497, 0.11290889578841387, 0.21246714667687494, 0.3484965223939188, 0.12275525533984746, 0.14997654264011692, 0.18030015661591486, 0.1688267642091359, 0.2375163525463112, 0.1021015478838836, 0.16778954244669408, 0.2189920707455566, 0.10156376182191795, 0.1649019272337037, 0.13192240899849322, 0.1628793785048108, 0.13136995235277762, 0.1249341089879313, 0.11514381175079655, 0.11943224171597151, 0.1645540620290464, 0.1197296906743319, 0.25022184416171045, 0.12395223707801874, 0.16689734112831855, 0.10429130296312994, 0.14336794644834536, 0.11997518354966757, 0.08917551487684251, 0.07139676686135993, 0.16815297455797273, 0.11696378384987194, 0.17799023298486588, 0.12222837836992358, 0.14009311975490663, 0.24287889140748212, 0.26711224428107666, 0.12055508146483092, 0.2608031118589063, 0.09311109240497313, 0.17634829205851402, 0.11884025493336302, 0.10264482679626635, 0.14074323728920954, 0.18207472268371813, 0.141113794018184, 0.11985550529413647, 0.07561925197801284, 0.13834990200496491, 0.24382533175089668, 0.13669383441728933, 0.34096943274621044, 0.1658344094551379, 0.13283563176951102, 0.1355823021261923, 0.11346745815488601, 0.1728632968039282, 0.1588318908527013, 0.16800761703521977, 0.14919715542947093, 0.11058682200288582, 0.07781879766093147, 0.13396737346005055, 0.16477806613810603, 0.12158654224608215, 0.13293608121814268, 0.13550694971796007, 0.15412964317346775, 0.10398852203281657, 0.14797735959291458, 0.22898236289620402, 0.1717688023082672, 0.18058388493955138, 0.12586518926846404], [0.04702486698665927, 0.0051972630523866225, 0.08706337216520503, 0.04492354909739187, 0.009786724394577886, 0.0031071044307487508, 0.04051142657596258, 0.0326870143744013, 0.021804654970765117, 0.10470846848141764, 0.0744211670732306, 0.026759753799847057, 0.03173239604239503, 0.005480081646613056, 0.05871477116259837, 0.015666316105653683, 0.025815247828441284, 0.047777766707323255, 0.04240228862111126, 0.07836590701293561, 0.05403509626405374, 0.01026136757460453, 0.01924235899482043, 0.012488331544333169, 0.02600831730711845, 0.04018806852400303, 0.006201643583124444, 0.04110387684176526, 0.06386751301526543, 0.003745392370488375, 0.012864071815725298, 0.0032113421841659735, 0.11970854664762175, 0.1108360380655335, 0.03415550150337719, 0.016083209662728252, 0.08094721729116094, 0.023273061660508958, 0.02566448938582213, 0.03560067274637761, 0.05174605618982066, 0.08778460564151888, 0.03682534856301162, 0.036464245359022776, 0.018311983515178005, 0.023221235812431382, 0.07697682872775101, 0.07246952744260912, 0.07022295928289814, 0.05414955746082049, 0.025727329663031047, 0.011710128897140104, 0.055812041034861926, 0.04239472733329862, 0.05529606549610054, 0.01460265760655485, 0.12987888478223356, 0.11286493766331866, 0.01802149063517009, 0.027975405100733045, 0.033375631657338915, 0.0650469551704103, 0.033224103296355854, 0.021237211730030757, 0.05038081856083967, 0.009077518498675238, 0.0304195913861716, 0.027142267246099732, 0.02622756209494847, 0.016351713904089505, 0.0458171830001858, 0.04590912504241832, 0.037687745230693015, 0.04507350697813015, 0.02569852284185829, 0.025464027158675656, 0.049075948660291975, 0.0629574848308919, 0.05846949279188149, 0.041651170054871234, 0.010790366608078682, 0.0011406769091638947, 0.017825264874244892, 0.009805825839359916, 0.019805019931687463, 0.016799092014891007, 0.03398357605141017, 0.05492323731643058, 0.026702927312843745, 0.04006250288277384, 0.02937954850494862, 0.031603796692985686, 0.05394868154619491, 0.04213244181066271, 0.07359212204333275, 0.050611564243632945, 0.06800724148389793, 0.18752367626274788, 0.09586009166894421, 0.010876577355027681, 0.008582438965658508, 0.05123421752585038, 0.04382744964752947, 0.014053131247149601, 0.031687622033660455, 0.03780519800080407, 0.03827801980679074, 0.021502159408203537, 0.030623997050908305, 0.04665635571244263, 0.11224481247125134, 0.035193619588690425, 0.14772216038357827, 0.06877016546505113, 0.02801500035509948, 0.031513199135060274, 0.024989583161509326, 0.07163479037943386, 0.036743066889504274, 0.04052788214457612, 0.02654495998285711, 0.046571354426804094, 0.036321833444338654, 0.03169456853591387, 0.041633959889652274, 0.08436652816711895, 0.050662700612578666, 0.027161070874201197, 0.03615772208919929, 0.06283542404191629, 0.044015723415800644, 0.005929606718822353, 0.0230544718778542, 0.07260867199229618, 0.1470923441792688, 0.027875459354911602, 0.05659637717349876, 0.024871529012377706, 0.03376046060434273, 0.03421497290893909, 0.05179716957612865, 0.05726225696684373, 0.010822798940353097, 0.06331361229381254, 0.07169126638121183, 0.03078319395201341, 0.039556107273505586, 0.05656658018368387, 0.00586485217941264, 0.007406393452847918, 0.05509643830479153, 0.07935520997571369, 0.07298553362488747, 0.03600544679249006, 0.02524609238119616, 0.010651420283642028, 0.05067706476115892, 0.04676496399746788, 0.0290773498014577, 0.06547174326354457, 0.023463212344194614, 0.01522620912686351, 0.02323089618115656, 0.045796483304471745, 0.04547069292335261, 0.07058911866718723, 0.059769019229157325, 0.04721293008075126, 0.04362455892166303, 0.00496014351806333, 0.04687400512217034, 0.10283625684678556, 0.017774722223440488, 0.06460284633982567, 0.06040461556685548, 0.10064866979636493, 0.00939272537512044, 0.025600367826559854, 0.010674379938732713, 0.03169857900619748, 0.0027006540884969817, 0.05612201553078429, 0.013107483804736648, 0.03214807535010961, 0.03816762653690192, 0.019893315395400412, 0.031920801960833134, 0.03040197519435277, 0.02877173051538487, 0.03233749441982758, 0.03563326595711612, 0.047783140814112085, 0.011903979785500035, 0.014329236995939527, 0.011214857842142304, 0.06393903881431588, 0.023866203320663304, 0.019167125330216462, 0.014116557581620592, 0.019241050899689718, 0.049648235491927595, 0.013379884560802772, 0.014380155029826829, 0.044418773764083465, 0.03239436495688654, 0.027474079078303713, 0.04001258459362773, 0.01766001013287854, 0.03485209759204619, 0.09140163614985444, 0.03091170520131146, 0.08134246503393497, 0.03604705302765773, 0.023268384693731225, 0.042038412178836526, 0.020245468777213848, 0.0163227193913753, 0.011562911695950936, 0.03731774008502403, 0.046427364370995955, 0.04261707286200216, 0.030776029114701578, 0.03712986085203387, 0.014535401790072362, 0.05784958593487259, 0.01554284763011721, 0.04953326867713083, 0.04453707689179048, 0.03626850606392949, 0.08664837467574305, 0.06899059194350435, 0.051920176483690746, 0.10187154530637688, 0.11922876110240338, 0.05074264188747733, 0.011538560633667776, 0.03435958349596589, 0.058627831674511396, 0.03312469572730122, 0.01684458423105459, 0.08965179173936767, 0.02836000613657938, 0.09772461944169576, 0.06130374615050613, 0.0483227463348979, 0.034186891956074585, 0.03736354448201676, 0.048175833653658635, 0.042170535532697555, 0.07160757127548419, 0.033271623730298974, 0.055131758788540486, 0.028249180027013345, 0.021491535683913578, 0.04072681219587403, 0.02186645528361682, 0.007150441562126001, 0.009281415672552203, 0.02561970388576869, 0.03456005721443123, 0.047028371838912855, 0.01699556483917179, 0.007827558907710256, 0.034110769629478455, 0.006724827051643403, 0.023262968452106562, 0.09060847467832989, 0.009043503237227279, 0.06568360487900435, 0.05296229354796871, 0.030791613258301254, 0.057284649716870445, 0.06554626829681859, 0.08700426848184678, 0.023061675019562248, 0.05392764477179416, 0.045305156644674084, 0.06948784429339633, 0.06970923604263414, 0.024222949399582805, 0.01657253300260392, 0.05957573141542174, 0.035777792274471254, 0.03262687647234529, 0.0700140011406714, 0.05780120365201466, 0.04388011053144451, 0.06092758548836555, 0.025333374693629243, 0.06933686368527912, 0.06352604464477589, 0.05343410411789533, 0.06434577787595411, 0.05432465068635441, 0.022521322563050256, 0.05864023080756588, 0.021452061088395216, 0.05555040285652203, 0.028176332726293517, 0.016370550090927753, 0.039301463477914376, 0.099637916371707, 0.04274009509132274, 0.008295354219303738, 0.028014824154876897, 0.01570131866291406, 0.02067878725938499, 0.08566627293945321, 0.010435622891471272, 0.12459394296691303, 0.013191309145411417, 0.095737885323263, 0.03331774605378028, 0.0306271820614535, 0.038850341112382954, 0.02669701119884849, 0.09473205018307894, 0.03595896057724472, 0.023023675143298124, 0.04148209828042215, 0.032426153775304556, 0.024155296174989595, 0.01800744824351803, 0.022029572639674432, 0.020364051527013222, 0.07207116938286251, 0.0964484625165501, 0.006954201915857172, 0.03134587787151818, 0.026424892937704444, 0.05190836340789834, 0.0066872269775147646, 0.038104343843916734, 0.0048158771917975, 0.010788754950607977, 0.008403226102311766, 0.033486618645369046, 0.049267535758835655, 0.036571103133141034, 0.054360584040442785, 0.04855282935163668, 0.05018487625244645, 0.06816036713820312, 0.049493761522875684, 0.041669808974068974, 0.0016407692906326586, 0.04575106195144115, 0.04252669363913517, 0.05785715105312486, 0.011826788766249534, 0.043472279794514186, 0.006591099222385956, 0.16896211662359778, 0.09293510668700741, 0.12228922873374917, 0.1641015492139324, 0.09946425190015186, 0.07787372616510238, 0.10613130060054603, 0.11492735360779109, 0.20529492427745175, 0.17291865431733672, 0.13874089795975916, 0.18937586235903925, 0.10256703822843491, 0.0646204280576879, 0.18436840525077236, 0.15588364744138333, 0.10982096390498262, 0.13526327247100492, 0.15859235048053727, 0.22749737806377873, 0.12409302105586376, 0.08592036898217856, 0.06628634753606974, 0.1908823742621368, 0.19832062835414566, 0.13159481448031243, 0.16455208552220177, 0.12482393022266128, 0.12065972141440838, 0.09577149360050118, 0.08338518485787415, 0.08373059092029449, 0.2081378612426981, 0.2732896402237877, 0.27496725020389406, 0.14317190454852197, 0.10386939536059096, 0.15444308038680785, 0.17438663199784296, 0.1522122476730616, 0.14428049506198976, 0.15748081818944024, 0.09517153184260092, 0.3002438003257398, 0.07304584006628684, 0.18636254743943292, 0.12300609550889462, 0.14324442243143437, 0.09534271418928139, 0.10452475293629593, 0.12711348357580363, 0.2094980350304996, 0.15879868860206298, 0.14177802289205213, 0.32087767376534404, 0.15527125207647202, 0.29578388157871466, 0.26878341912261905, 0.10687521794029783, 0.2341179252271691, 0.07392563076028902, 0.114054664548847, 0.08877287438559918, 0.0883764009021463, 0.18803006038069728, 0.06647370199883176, 0.13938113295983884, 0.12854917065030144, 0.15469351452925514, 0.07923090454911993, 0.12692371593608012, 0.11783081151905561, 0.1260963256560987, 0.13010247520381404, 0.1645313858264877, 0.19488501512715894, 0.07563282705603108, 0.16409502214481755, 0.15687798360182395, 0.1408947848023907, 0.08963223351466079, 0.13302945201435398, 0.26466030327062456, 0.0641301126339503, 0.12080073521863069, 0.16467838277739866, 0.10551118306935796, 0.1200476018411498, 0.22496633081426545, 0.14459662890482336, 0.1807508154982521, 0.07289282166429105, 0.1964911797474469, 0.12208335792585728, 0.19705033200162073, 0.12774409651155436, 0.31710371014571964, 0.33553790000657885, 0.14319016808463683, 0.11463831629483931, 0.22775895112464506, 0.16564336244858083, 0.15927335667994716, 0.12028548746339737, 0.1509317163858683, 0.12270655513050095, 0.19990616988751198, 0.11101459783892478, 0.10558989094269854, 0.18770226667965614, 0.15551044004819087, 0.11951645776148766, 0.21022456217437022, 0.2655411818094792, 0.1324120157909009, 0.135041183581756, 0.15181921392438874, 0.13659883951467855, 0.21451215710370772, 0.20432357075473956, 0.05630357070795952, 0.13231590239992067, 0.1424159136630835, 0.14668389674155943, 0.13523319585909768, 0.1738686033434445, 0.15605794776591564, 0.15122744164639904, 0.1420157093314394, 0.13181112706661224, 0.1451979313165911, 0.17307559508950482, 0.0799100261722361, 0.2121483162045479, 0.1604336428065454, 0.1816759126320962, 0.15803336676570678, 0.1252265707139046, 0.1379678846006432, 0.1956958579079759, 0.24938607287983744, 0.11744409033487882, 0.06341219248790896, 0.134892164158725, 0.0911754103858144, 0.09780652956255982, 0.1359145851024697, 0.10152593240021698, 0.09962762015000468, 0.19258152663467393, 0.2230964327651647, 0.11957081169971537, 0.14237990753064234, 0.12542684907994925, 0.1378703616078823, 0.0797010220647339, 0.176150809913393, 0.09482666204172759, 0.08706213110276768, 0.1460965371300136, 0.13390237856055462, 0.14831373347870766, 0.12668202285684887, 0.16709198874811973, 0.2912908065463266, 0.17047970615808042, 0.20333223765896213, 0.18492731235681042, 0.15481797317343374, 0.18137772056844928, 0.17473114173739188, 0.22618860877569646, 0.14439471877149998, 0.09989895317102633, 0.1655032602889884, 0.15479336642930586], [0.0614928970894506, 0.00426599795314213, 0.04984391349998694, 0.06279477158621435, 0.05100934390699671, 0.05349744043703522, 0.06387272241315053, 0.015096601414223833, 0.02058968548813174, 0.025611872551962737, 0.03665250380553546, 0.018841719908279278, 0.029515933222888462, 0.047727047856296265, 0.03926824590551757, 0.1240450639518038, 0.04125966465160732, 0.052873902323265234, 0.09075613812573495, 0.010068975126130447, 0.017436435033056526, 0.027179342071195284, 0.07309074814040815, 0.07803024558891213, 0.04039771997580125, 0.012122921968599962, 0.0166670625068007, 0.08706193191990738, 0.06915510166436434, 0.008417825822928741, 0.07224225213811283, 0.03565744752244603, 0.05771059077233077, 0.05587830764031219, 0.03867071647677691, 0.0526140452993493, 0.03266547581241016, 0.03141041311825956, 0.03127960743562829, 0.12679357291950336, 0.02542773565848268, 0.0976096909312952, 0.04457735779484914, 0.018991034275161165, 0.054660817728407925, 0.04595962172794727, 0.01693155244743872, 0.009018545050264127, 0.07169200182561913, 0.019595826217424006, 0.052802514420041156, 0.024290119988783717, 0.016596494317655603, 0.06192095637802155, 0.04713491168654254, 0.06912958327560656, 0.02599775295464262, 0.03899043944153575, 0.015987841292254387, 0.043192232523353837, 0.052411016677656484, 0.046856492352221286, 0.07107548490767518, 0.04564231577058954, 0.038470131675562555, 0.10368740351329889, 0.11860474418368071, 0.06503634485265901, 0.01128050774681352, 0.04045496206550349, 0.025403364486391508, 0.025338356180356878, 0.013073351714880237, 0.01013247519656415, 0.0858494675447864, 0.058007089781665036, 0.02434825457091774, 0.05444497628618152, 0.01507185964709929, 0.04037474116851245, 0.05114384979430226, 0.10173559534333407, 0.05768545542753512, 0.0032890821532947164, 0.02913801247374185, 0.018835788472525535, 0.035846816796448924, 0.04025951388382143, 0.022523389085226005, 0.04846362607373346, 0.03972465810816615, 0.05187703424223489, 0.008185641810057626, 0.012710323714981637, 0.022298450348898772, 0.0668518583200151, 0.079757881110474, 0.016804994722347588, 0.05617926528136577, 0.08425854041331238, 0.0651716972671209, 0.016405497106813615, 0.01449776005991284, 0.09076895477670817, 0.03748680802903349, 0.01615162322958631, 0.04609596622627109, 0.039214282672131257, 0.02155558638004286, 0.06768534665987377, 0.05767443525274435, 0.021167400052710887, 0.0709961871466329, 0.02097606384796241, 0.047260703323709394, 0.04131180842617347, 0.013786215680621326, 0.11240343097597362, 0.03970220790154511, 0.022632460853445436, 0.03145350364878053, 0.018431615805433645, 0.06164927861743397, 0.02643649725453748, 0.01891830763328941, 0.013380801951092099, 0.01352377981323028, 0.021686947476419232, 0.04717591654268965, 0.039500653999106544, 0.026586026126038165, 0.07216343701246285, 0.037298201012515256, 0.04052108311424813, 0.02859178795329025, 0.028310790733103792, 0.05356808906541236, 0.08489906652680329, 0.04867087200944943, 0.03753702892290969, 0.04515204631212739, 0.036630789043321725, 0.05525474271346485, 0.024850109194014824, 0.09779306173685098, 0.016171152725996032, 0.039568425967328014, 0.046121028792713924, 0.02730068465274188, 0.014474864564685812, 0.019269827077345505, 0.030097213926755136, 0.04046628101458473, 0.019297498173170516, 0.029876132443126653, 0.09235557649404773, 0.05433457152497384, 0.01325360454258419, 0.031932819965145284, 0.03335313548544242, 0.047913674535530235, 0.026920096002398964, 0.034256885579276475, 0.029177197871068795, 0.04863529871668547, 0.02899036051765565, 0.020146630028442993, 0.06871576556154797, 0.01865684182473248, 0.0750017008413711, 0.02269862786746554, 0.005582203082139454, 0.04501389767674189, 0.030797810909608682, 0.009170363567048504, 0.03589372436005262, 0.021099315903660272, 0.005263272060772344, 0.021875719201841184, 0.053450368164527806, 0.08490350983676412, 0.026457369320034504, 0.0594622201676811, 0.18223943158743844, 0.0192034991848613, 0.02849703436837562, 0.055693810685507716, 0.036873129466848995, 0.043694537223106435, 0.042107291144108584, 0.05470815813168884, 0.0757311927455087, 0.02098739811880214, 0.005968064811426185, 0.05446381055779996, 0.01926710938043412, 0.010241896492399035, 0.07671880265397411, 0.13685817559880598, 0.05050107904319322, 0.006712186122087823, 0.04245755420396886, 0.02359774887501713, 0.11496900580823423, 0.07626314887837057, 0.04522151899554076, 0.10771232987603835, 0.03955203168574841, 0.006784467954158544, 0.04311521770432592, 0.02552822149629074, 0.050102969962022, 0.01183536799339157, 0.010054374447903566, 0.03931397369371788, 0.04455142188817263, 0.03962119410355245, 0.02865335269410524, 0.04940352019583506, 0.04300297816253958, 0.04850324814117724, 0.027563102325544726, 0.05021713238449828, 0.025816350995052247, 0.0036557849812050985, 0.008409335653507903, 0.019991378480147932, 0.03116364662174977, 0.05934493593691338, 0.030645575832515478, 0.027614615992793155, 0.02737634158092401, 0.06313945752598586, 0.051619295451429584, 0.03285461142959614, 0.012208578259413762, 0.06434245305436273, 0.047851897205316254, 0.08935507056453536, 0.06149334908132592, 0.058225210335466175, 0.013742508449321313, 0.0691161690760524, 0.02352888523150356, 0.07908119564695705, 0.030500752656089685, 0.054433615202264446, 0.04543690078501259, 0.04687206691972191, 0.04580296440831116, 0.070610661059618, 0.02547818446351636, 0.085470047178528, 0.08858683759406691, 0.014491360352915383, 0.0043064359042252745, 0.04991226003415162, 0.08581103291362525, 0.022172325463484854, 0.027589076536617456, 0.026990057066864064, 0.006609639986568401, 0.03459798239712273, 0.07128414427561146, 0.03741343978852515, 0.041103853859127536, 0.06787686864094389, 0.054031587581360535, 0.024065242539490425, 0.07217993088547262, 0.013324218697004743, 0.035958489433171294, 0.02977970112565785, 0.03999982156880921, 0.016459242005141515, 0.027858333459364313, 0.03722848318096611, 0.027194089263737686, 0.043023455692755605, 0.09787921598481555, 0.03044193817092286, 0.006839392627889832, 0.02384225732737011, 0.047181700506517966, 0.04868928493270951, 0.04954610064986253, 0.005231613477301454, 0.07426119259288234, 0.020543316101294853, 0.033606032600566264, 0.04449524849112477, 0.026806919918125196, 0.05888838200799881, 0.06364927371783603, 0.015558297708330136, 0.03369197617435167, 0.04303546795140832, 0.032919771037995815, 0.0599573657757813, 0.03988234581606042, 0.038203962087150545, 0.016321426618003076, 0.01640583035506068, 0.030765317290300326, 0.05819432933123843, 0.03169963812275279, 0.034830650960605954, 0.027932661224997817, 0.010946533631443257, 0.03538172098717863, 0.014517689837262997, 0.05025633310358371, 0.058915026546005285, 0.0466671422304165, 0.03343448253168214, 0.0694785516468748, 0.052267562883395347, 0.0794564025296319, 0.038696162087181886, 0.023482416253236514, 0.056260600836286624, 0.013853234967457191, 0.03295246000972486, 0.03156415547334379, 0.04804950192450516, 0.025296836130080685, 0.036820257908754775, 0.035474601487118396, 0.08274868836686497, 0.01290738738457402, 0.04026829325143368, 0.05248964028132539, 0.022408397372571692, 0.0355184332077061, 0.02951462129731813, 0.05720160578587844, 0.038027076215873805, 0.05461349647732512, 0.048299480244637504, 0.06783585995435715, 0.00642494528531848, 0.011640324880699477, 0.042977325708395055, 0.008897817254276767, 0.03519342040583011, 0.06335313476982617, 0.030321737060383446, 0.004763632868191287, 0.0961592796468927, 0.07395117213168452, 0.05209966322347041, 0.029347125748773257, 0.1379487324025362, 0.13163989109377708, 0.057964012657682744, 0.17742329727738135, 0.19336736430564236, 0.17116267354257647, 0.16365243782920225, 0.34327413165761583, 0.09713227259776286, 0.08530679384186383, 0.11229601778811026, 0.09613334757065582, 0.14734768128443151, 0.19087256833670602, 0.18296575954844876, 0.18900634750964182, 0.1230519458711628, 0.1338310251312871, 0.21404156461358073, 0.135379258182741, 0.08131847116014651, 0.17596875677906698, 0.2642319375468839, 0.18879319120559002, 0.08015399453260245, 0.11585619691158495, 0.09814491059871451, 0.19681131256924522, 0.14527746656488988, 0.15318151743661973, 0.21729990509488892, 0.11170233029030985, 0.1140524275721081, 0.14368800266135123, 0.11295054798885701, 0.17522778121694443, 0.06707031595250292, 0.12311808224166594, 0.12576614942161307, 0.2737271990026197, 0.13028491138210221, 0.19517110300160226, 0.17303200468661326, 0.12253777063902348, 0.1551729936393038, 0.16498192213475704, 0.19175193002147062, 0.1496503577237168, 0.2182300584090333, 0.0407387976414494, 0.1313283384567307, 0.1483316752578943, 0.19183877374856703, 0.19642336564438959, 0.09764130737993026, 0.23905277252197268, 0.12415027080644524, 0.10295113173103142, 0.1225733171187101, 0.12002843432128431, 0.15385241127542912, 0.12526350381273416, 0.11877612571322149, 0.09980856245684047, 0.11652957287526901, 0.21777806653370782, 0.24006926394518346, 0.1482517416438749, 0.13320955928535233, 0.0959097188446791, 0.14016957532974983, 0.14403076572043283, 0.11767626094121127, 0.1336480373696935, 0.18168916595318627, 0.18445863508649413, 0.1777339459306771, 0.23011353768167958, 0.13924389596908324, 0.09282117409090843, 0.20332134388867887, 0.23688472837450045, 0.08434202101442122, 0.16341326517924187, 0.13267127526623587, 0.11983371775356993, 0.11475797922861193, 0.2648559008394518, 0.20860653851301442, 0.13291322115448215, 0.12013773974632064, 0.1428603672332341, 0.08223001619861012, 0.12997112176831693, 0.17211838354987485, 0.20644621653181894, 0.10512104513303888, 0.12596910143451345, 0.14433194552698445, 0.17033220358913945, 0.16795854144279035, 0.147772477038445, 0.1353676289680504, 0.27681603486980166, 0.11464728718443264, 0.10780460516651792, 0.13088362441668588, 0.12829719667112635, 0.1902168430387974, 0.0744997906768995, 0.1664259365849918, 0.16129818835085438, 0.17715421655485708, 0.1573464923327969, 0.1991443414120905, 0.10247054945437178, 0.11946351342504063, 0.16043859173453626, 0.08899349238603346, 0.11373470026639201, 0.1606301903243988, 0.08403884937926646, 0.1179348462591729, 0.10855955417237936, 0.14116686858957814, 0.1101023403386916, 0.11387794338647397, 0.18124633648943517, 0.16286568085272468, 0.09409020639835827, 0.19218743568466556, 0.15852655884960007, 0.0960614348972036, 0.18038618828981154, 0.10826926813611101, 0.20169542952170297, 0.1138642380735086, 0.16229799437907436, 0.06891187640928453, 0.19030341097424108, 0.205466604581283, 0.14848290101414727, 0.10371466092164479, 0.0915753925519605, 0.219503756191942, 0.09146481542096985, 0.1140305404401114, 0.1292445946244463, 0.26142146738786853, 0.11870576819825558, 0.09174974650264749, 0.14169318631531733, 0.14015655183503706, 0.1250407254443534, 0.12029155487975768, 0.17053023731756597, 0.10430344545672979, 0.1829299372771094, 0.14540911111379826, 0.25743698280665184, 0.13733983039855957, 0.1477582278030534, 0.16345140103611255, 0.10240091206205469, 0.10977622437020464, 0.08725352284889068, 0.0726848287928489, 0.0932755101952822, 0.17632249021722426, 0.22476127972045254, 0.12855851692297768, 0.08936709814494656, 0.20014120566268123, 0.11155638287985518, 0.2270878121376999, 0.2078881778664166], [0.10674266940763882, 0.030924763169980822, 0.025340755950779687, 0.02319221831707945, 0.03021568559380549, 0.026775006610419483, 0.039985821311992985, 0.08186278429122702, 0.047568268473109895, 0.03300729275290524, 0.0049135979310038595, 0.06299402339444046, 0.01609619676826462, 0.04394154695253219, 0.03660786386218764, 0.01896442612633109, 0.04696778960586075, 0.014664216601710408, 0.03782618114905011, 0.07510469370191136, 0.028178675040122003, 0.017121415848152775, 0.029156302822934046, 0.03338060739840711, 0.05746956035915402, 0.014849878967769686, 0.04255241887163251, 0.04604931530212203, 0.06167717570919664, 0.07349588607828464, 0.036074099761824456, 0.006829926175170488, 0.005218511937381399, 0.016925718687895327, 0.0916468225900204, 0.074869244239263, 0.08457283564512769, 0.0497243003619294, 0.006795759611357485, 0.06528379891308085, 0.03417324026926391, 0.02474247575587323, 0.020043801876806447, 0.013385406139517024, 0.03623657551924548, 0.03366964854179852, 0.005791030031809163, 0.03323673608622724, 0.014081474585128168, 0.03015081326837742, 0.029178205276689226, 0.03552168908138429, 0.07794858061618383, 0.02618889763741003, 0.03407597774639726, 0.04666129314911462, 0.06539082139610283, 0.0696230358293941, 0.07236076593999902, 0.01008572946903446, 0.06438930699181172, 0.00932653250563289, 0.06575601550960733, 0.02077176735075491, 0.08633564226329328, 0.052681418901850144, 0.014645931040567738, 0.039987885918948925, 0.05805822998105038, 0.005003421261320792, 0.01933034610814385, 0.05659618948195731, 0.05686243950960137, 0.1302735273155474, 0.0384625512355518, 0.035116907374392596, 0.0550153210849291, 0.014201553121599701, 0.011932169905893747, 0.031219511668408112, 0.06061540848966088, 0.054298975249572154, 0.029205740391907674, 0.013731740125935647, 0.0640204586389084, 0.048633555866657734, 0.038174218723490354, 0.03203576494519028, 0.017623417943175283, 0.06744651108860009, 0.03066891087068906, 0.027522424971985242, 0.07440833510049889, 0.027457405174631747, 0.03418186258885168, 0.030035488307476047, 0.04971652839993758, 0.022119289196486917, 0.023301784212010044, 0.05836850708170284, 0.0502893514931202, 0.013829853964008152, 0.006911031424909109, 0.029200241795831153, 0.07875763841213719, 0.04621345730077836, 0.03429369993447777, 0.03498990148786576, 0.06019632009068324, 0.013085397489879642, 0.03538196996575402, 0.04627457579537746, 0.07760344268453699, 0.018555769929662347, 0.016568507210561828, 0.050923411824530175, 0.044407952772153, 0.03563615793903028, 0.0507752082851385, 0.08459485301207151, 0.03675168154821281, 0.04968651307506427, 0.05476238566540903, 0.04498741401719951, 0.02631166897293541, 0.022597065676123868, 0.04918054647503361, 0.08395717674565893, 0.03618397209192476, 0.017608576904862158, 0.19952638945992918, 0.043370378609266014, 0.01935601388404687, 0.030327331417450504, 0.02083125024763567, 0.02730830339714885, 0.033783998655816244, 0.04310598634483834, 0.0540281976422956, 0.027405416532870264, 0.04209676892646859, 0.0939597569466118, 0.12618090942381852, 0.03929624641915003, 0.035049434180461594, 0.05502238058515134, 0.029646689109804652, 0.055305917386806784, 0.03804373862822691, 0.18230228144074642, 0.016070023374331575, 0.02565498606512143, 0.04149802907880756, 0.010013027725020244, 0.07747853204848305, 0.014571197248334366, 0.031368224656269435, 0.06692445281171991, 0.01219898492338196, 0.006173029241542663, 0.03768358537326417, 0.019583867584925987, 0.027250900428982514, 0.04125438630580902, 0.042696355301285946, 0.02415467755899074, 0.020511831802826737, 0.015670233687776473, 0.021854169148531173, 0.04170607557640441, 0.05699224544749145, 0.05676872780426376, 0.025685102896644704, 0.06963509405332227, 0.11743056888301527, 0.12134416734859829, 0.054983846362560033, 0.010274091337416923, 0.03043808666388354, 0.05797715489602378, 0.019088440439513615, 0.026091022244203958, 0.0838690459908497, 0.03064012511693422, 0.07967870592349961, 0.06876874820239122, 0.013739634661995357, 0.022801174481789914, 0.047619703616346085, 0.05710532385555487, 0.0023785919221418522, 0.051204466501310955, 0.0017274438798795607, 0.021365732555427862, 0.041251341106310006, 0.042160419341657436, 0.05831707193846664, 0.03237165428037125, 0.009050057119419499, 0.10084271220670593, 0.048044947531795314, 0.06909099542686055, 0.0628785586224929, 0.013345892281992542, 0.07409107510841663, 0.08954232543586724, 0.0844172738312233, 0.043251811181225126, 0.026773227371215343, 0.0565254221099519, 0.047167248257826415, 0.06779372511852173, 0.0578976234781646, 0.03924187332872422, 0.04787288418400192, 0.03124026690549668, 0.020419776762625384, 0.050593139829054, 0.010499860321532094, 0.015565971994111616, 0.02091972574201082, 0.011776452959184686, 0.010500964445752964, 0.03708869894786227, 0.038532104358197226, 0.06688482308339688, 0.0030994574368495738, 0.0375157508308128, 0.024145515147416342, 0.09538538528666382, 0.054523837377106955, 0.03203531486853477, 0.07027822486575573, 0.04038016507101636, 0.07692560808913362, 0.04528283667300017, 0.03147538311989798, 0.027053251659737963, 0.04559984768650705, 0.045905601037966634, 0.026477207166833744, 0.018196603012902123, 0.020168019203288902, 0.05840787250969199, 0.030772604701680042, 0.05759276261913681, 0.02310044289897046, 0.06393477170457763, 0.022511485994102496, 0.07939215839630173, 0.06232006903437357, 0.0582746115152634, 0.011246790302046126, 0.022759219676616694, 0.0686739065173653, 0.028588363540268717, 0.01973655273867471, 0.031217962255581256, 0.037083290367116856, 0.060493673288053086, 0.0185222574134147, 0.009866801650083114, 0.04739160093689158, 0.008550013336653431, 0.05855880332209411, 0.02996914892367298, 0.021997684229826255, 0.02952316509289367, 0.08763560920112556, 0.052950664333278136, 0.09137109988519261, 0.05352085591444085, 0.04199413229681311, 0.007330011135162486, 0.03645105332496666, 0.02319738558012872, 0.015262144396171696, 0.06421568848553204, 0.09463130962103607, 0.08510769525122258, 0.06654283377311884, 0.045397837961753534, 0.017179079286213365, 0.015094340497237301, 0.027784229774448662, 0.0250290596722475, 0.04652525508596052, 0.03828775678430835, 0.10672551669901419, 0.05612153672583162, 0.05455107946369437, 0.029976823209454457, 0.05635925380873585, 0.07208751003828741, 0.07270177465773399, 0.04137296139472916, 0.06344521853832469, 0.002909829368769762, 0.06508134485733125, 0.013047292276525931, 0.02966954725824537, 0.03571008925416297, 0.0643110204668295, 0.06959804604130407, 0.05804446721149068, 0.021033602796735305, 0.04043593244146436, 0.03707947141881432, 0.04909906919384676, 0.020755826976270448, 0.04046664107590914, 0.046688098565585194, 0.029801946403759143, 0.035417474310604796, 0.04153585083962929, 0.04313888982118618, 0.03611361840739846, 0.0402531017278952, 0.08911649546315593, 0.026198793578171925, 0.04344978745305731, 0.08247104278134723, 0.05977512878035346, 0.06771268833789133, 0.05427726814823766, 0.022384478192355846, 0.08050821060615201, 0.046491148851571545, 0.04022129375727908, 0.018336186147925836, 0.0964873184960696, 0.0532067675263651, 0.016010516537203184, 0.003578349292623781, 0.025241166435843034, 0.009400246443317063, 0.0402713576031308, 0.046457452474222075, 0.030972616852171002, 0.059469746981537154, 0.007480122233485624, 0.035005713542622906, 0.029789681336091414, 0.09698776543260583, 0.07484019418517429, 0.0548756517650139, 0.07086563810345627, 0.03767354196057685, 0.010969385076614638, 0.055652518546389, 0.02886725593388321, 0.01342864701479313, 0.2905070985997877, 0.12995733218567987, 0.157984689538998, 0.12114300032056148, 0.08819937330460356, 0.0558835361903954, 0.14978210952493454, 0.12079564839481347, 0.1476308886682795, 0.13691696518611524, 0.14671542892052283, 0.2561409765433881, 0.09581691495353177, 0.16285357666352104, 0.15214598106761135, 0.17617196926186163, 0.13813458533296663, 0.08122935215191496, 0.11240388296784894, 0.10827541982214298, 0.12224508674755213, 0.12191769141223162, 0.10248568735175556, 0.21991776542798167, 0.17027862339971528, 0.11170214642920803, 0.15122117504717844, 0.12648873887355291, 0.10152390992809689, 0.1158043940461451, 0.2050700161846415, 0.14085405956833594, 0.10185495184193696, 0.105555325055555, 0.18851395215718977, 0.12575746964543097, 0.16956654467409657, 0.14545765044468065, 0.16331373503611935, 0.12676221694076253, 0.16108818832905064, 0.1828200802687676, 0.1185294300798447, 0.11687197587302617, 0.10872106848945541, 0.11612445025915101, 0.059767804979797334, 0.12196966281701481, 0.13372965637714634, 0.11841628655430772, 0.09113483836934452, 0.18504757283916398, 0.1873416844154558, 0.20278050113589535, 0.15727274870920568, 0.10893635451793672, 0.18086272562223096, 0.15028685421472596, 0.12521057479804562, 0.16485386287733433, 0.11791140396868992, 0.11630124036943722, 0.13607730217758687, 0.14047863052016304, 0.09575613353761936, 0.18276239384806928, 0.08750545086279031, 0.1436814602704779, 0.17720571298512722, 0.15938520551689211, 0.08992478717118503, 0.15656785588831673, 0.09715339364183527, 0.18635415111578282, 0.11175876798769159, 0.16011937821824707, 0.10643356825195013, 0.12429434896236467, 0.10570122650073421, 0.10310476300336661, 0.1367175984647005, 0.1407691310610502, 0.1771790071600868, 0.12891787344649916, 0.09434488466790608, 0.15049420357231172, 0.1261544181033969, 0.08546700580946862, 0.22494149424376028, 0.1228320403324981, 0.08056670141917083, 0.12245858779116986, 0.2100098430509529, 0.11668862038922888, 0.3223095227393412, 0.1437877166655756, 0.17811101440700794, 0.20880140063743438, 0.16193715164497977, 0.17797003890718185, 0.1096033489692115, 0.12832305213857081, 0.20996637522212921, 0.11522268050260122, 0.14701310004438126, 0.1748368465491841, 0.19283428968441105, 0.1674304004277914, 0.24286125606346518, 0.1376906220590876, 0.12014019888855758, 0.07199375619811398, 0.1539751845261743, 0.12534505387227382, 0.10732862707828322, 0.1220203625158437, 0.22910807792457843, 0.14774416242876362, 0.11462470291242485, 0.12585076383284985, 0.19321192506580584, 0.17664184162933982, 0.1456313685423905, 0.1156766948500468, 0.18887064269473477, 0.1797560350068154, 0.282491612578592, 0.15528337158743413, 0.16032115045574405, 0.05288208414229655, 0.22137943054399184, 0.16333991992137126, 0.11412430194116409, 0.12453879995812332, 0.07583968611734529, 0.09537429999439948, 0.12969701550900936, 0.10305607811577859, 0.10540451298678115, 0.09204541047614428, 0.0769841448674279, 0.15468744711289484, 0.19437383529880356, 0.09419539793124122, 0.12825160677875244, 0.23897213410706292, 0.08179241911538186, 0.12413040614656864, 0.22048355200357977, 0.2661667385649297, 0.16744961391293234, 0.12388342706065987, 0.17411790367576385, 0.14353605678244946, 0.1631605634165387, 0.16258530799419652, 0.12696735230424713, 0.2432956279165322, 0.16745896018560857, 0.1355897485008163, 0.08038586636464443, 0.1546614154452278, 0.10212685942890183, 0.22535037069070726, 0.1010245431755339, 0.14725967310369015, 0.12586694360981066, 0.21381625815504984, 0.12188164697539423, 0.1862781551936942, 0.2704290372710074, 0.17325197917319116, 0.13039728115883567, 0.11499231020289083, 0.19102912606491199, 0.21226050212017952], [0.07603258705667912, 0.0692072645911286, 0.0554851436566922, 0.04081932497361014, 0.035503241684167616, 0.10850459502469148, 0.026513322466804136, 0.0634988944887394, 0.022091591287584558, 0.05061340285465122, 0.027713617535247922, 0.06241989795178656, 0.06891358478535568, 0.031272233839357094, 0.08924145972536457, 0.02224464033309731, 0.017399620677855228, 0.034765893548366525, 0.033158212073988495, 0.052658156642029365, 0.04503687648403068, 0.038881291064523885, 0.011465895278829963, 0.06106991696381762, 0.055743150578271, 0.0838042579350933, 0.0479203088569545, 0.013152849616392726, 0.07645708403640217, 0.06216690124523255, 0.006924017094030616, 0.03420688685089831, 0.050112339217335954, 0.022580912712240414, 0.01678104298339496, 0.013286187219613744, 0.04036284382304838, 0.037192431083249475, 0.008724622011575247, 0.06078364139783287, 0.07301913424124641, 0.06704112800258784, 0.04484202968136919, 0.02948201468004094, 0.006572776314456978, 0.041565418003066894, 0.010136847643391981, 0.05350250044777509, 0.045212168892424916, 0.03799613392461212, 0.05742835248970697, 0.10467440821230413, 0.0411287976819421, 0.034112968301821145, 0.006358666709744402, 0.019197261313937845, 0.010619324072444392, 0.06144667900497876, 0.03748749367772572, 0.03959245431507307, 0.021580641285606453, 0.041339877887719104, 0.03976239942975583, 0.0195011664782801, 0.018984160551260558, 0.036183167699604266, 0.03039901809496505, 0.05330663091773468, 0.11188225370020637, 0.022024169804588444, 0.034044437906554634, 0.0218833647593255, 0.02840064327052284, 0.03609108010066613, 0.0451582592851933, 0.09225665156038539, 0.014374178586407535, 0.04579199019879584, 0.030507229929489475, 0.07061472132561669, 0.09013278004262718, 0.023839338532378598, 0.01645399430286019, 0.038896777531913215, 0.013079035129668492, 0.06119625252341071, 0.056299629185589097, 0.09485082445485939, 0.09720918016448137, 0.061589209663291136, 0.0799805598874246, 0.02218198200177041, 0.10561213813601963, 0.02298024178843104, 0.03269584736816826, 0.03245124315482474, 0.026304084702485034, 0.07025523456714808, 0.04626920168858863, 0.021206252201790773, 0.03940472063878852, 0.05307474759437385, 0.07216931290684209, 0.07263278077927328, 0.03281351464289812, 0.023671500159487612, 0.03503469847923806, 0.02683186374093977, 0.038760735638319485, 0.04813747563128991, 0.03685678498098447, 0.0844140332793036, 0.01359816120501848, 0.05093481887372271, 0.02572998415768868, 0.02121747538988148, 0.06191733661257933, 0.0543071455772846, 0.046561203761807377, 0.06656968515486487, 0.015970992145969743, 0.013475641720898211, 0.04816679764659174, 0.013173497601171896, 0.039136057434182976, 0.008110947279830374, 0.027712650349243518, 0.050507391607689286, 0.03044895170586965, 0.030895467967756336, 0.02253133150178098, 0.06291763293707082, 0.02234993145741042, 0.014405350704046508, 0.059276903498797655, 0.05027942299362152, 0.06195542267373493, 0.02964515501873628, 0.014258663061135, 0.019515118854601058, 0.0207944224858957, 0.08741815514381855, 0.052976741966220646, 0.07099126886215902, 0.04395039526805763, 0.050192100461572416, 0.039883655826410944, 0.07439996942036575, 0.059284962743761084, 0.01170812557721811, 0.0037039352830634605, 0.025365611673482967, 0.08797664856237751, 0.018039060861713464, 0.0506482636856456, 0.06499620950630595, 0.05227238540687869, 0.01643852698766897, 0.01939781355641542, 0.06606466467342069, 0.009039413285321526, 0.02790781890883321, 0.035412123186453696, 0.03275299752731958, 0.05245420105394818, 0.01709165333229448, 0.05653117926070287, 0.04258243802694544, 0.1102504940823682, 0.009724783313070095, 0.03572635330079544, 0.008740503971855487, 0.04644224179848548, 0.029173585766505812, 0.0474012881186941, 0.057171081012535485, 0.02236209501842818, 0.0414659453165387, 0.09377193517021595, 0.012171595364869123, 0.011180720006626461, 0.13013984497276046, 0.0821152026013982, 0.026893150774882208, 0.04885818050693601, 0.028990080895563288, 0.02756551933294583, 0.01165292702705389, 0.04564284054081767, 0.03821780529594229, 0.05794371515812893, 0.051911515859706756, 0.007833638294194376, 0.00792254375541703, 0.03260246891107771, 0.019086285817226576, 0.017442900815137455, 0.04513785836376971, 0.062476197753341935, 0.02865089163664849, 0.05322888448473908, 0.047730403321404616, 0.04356070549317426, 0.018211712181988745, 0.04174416546799964, 0.053439336498418165, 0.02273224189036316, 0.006887662870388839, 0.12353233662584137, 0.08306676041214697, 0.07815190035128787, 0.0543913156575253, 0.05829345344776108, 0.018133601857229106, 0.02686942311664743, 0.031431635668981946, 0.016004698099418273, 0.03651391850003312, 0.02447365741846302, 0.03645795194672481, 0.030835241965589025, 0.07250971641511687, 0.030066495716211297, 0.059984446983904614, 0.04767462062919813, 0.04672986567921696, 0.027260601017323714, 0.033061390051678304, 0.02567670082733516, 0.027466102187792142, 0.03783975239662874, 0.0258751884628568, 0.014570525963790716, 0.019598551575214635, 0.027833611802047784, 0.014954388682400028, 0.042510452575140426, 0.01668090763081226, 0.046024237413920706, 0.01795096458086083, 0.050735601539453196, 0.012712672732079463, 0.038997625346265496, 0.04054825625292236, 0.03619485054044955, 0.025607812285964048, 0.05347502853481039, 0.025081584575555982, 0.06138694329908299, 0.016213293307490887, 0.10396402254099808, 0.06915240503487087, 0.10098833019935316, 0.06888824259682048, 0.09803645553127413, 0.0677893354347156, 0.028270890958787456, 0.05453951536647735, 0.021828890162249728, 0.038171261624102636, 0.04906197138611348, 0.010080364938344686, 0.08737300958244071, 0.008812818841467942, 0.10066848083008682, 0.0391736991643425, 0.05963540966472319, 0.0802513106816238, 0.13912339033859392, 0.01562821759556931, 0.04649137101706959, 0.019789690512322614, 0.0740340322015747, 0.0945628060388469, 0.06050380863129132, 0.03835207752643093, 0.024476267863065008, 0.026944716153065526, 0.02663304285717107, 0.07050798229512668, 0.017580664491341, 0.03862904129369605, 0.05208286291529095, 0.016380612655813177, 0.03862655533838176, 0.0957291902253224, 0.03788793932706599, 0.06070812428069692, 0.06811956529535594, 0.06220124879731767, 0.031442355154262434, 0.02804534126734061, 0.024745469244437355, 0.029629978816956285, 0.019755469364745003, 0.024902952023811882, 0.08348943410261024, 0.030631343834102157, 0.05354668839924759, 0.06645681742098063, 0.02304212062529499, 0.045446266209886926, 0.03885712482095246, 0.028959916183544748, 0.04092841206358806, 0.03210843413046772, 0.014521637105292853, 0.07169165708605321, 0.03704116319216067, 0.039922036831417394, 0.021405733836394165, 0.03395767844912987, 0.02089884984607418, 0.059580952304625706, 0.07787134363165787, 0.05882143741473556, 0.057888430423073234, 0.08291463067214336, 0.016268210320342934, 0.028300979062013572, 0.023387591805188887, 0.05401417440284164, 0.04670876378734266, 0.032280623882768616, 0.02679796626551017, 0.053348352066090995, 0.043943228515525984, 0.03722465274134471, 0.02816866610139128, 0.008802929603975386, 0.01000758083987861, 0.01364034487895908, 0.011947603704738281, 0.010667663262856585, 0.03521567142959084, 0.07607472189251455, 0.0294604761180498, 0.02097694293385552, 0.06613527499740163, 0.008506716920002814, 0.027485729360412207, 0.07815185438601241, 0.01893601000999972, 0.07034829126731043, 0.037972086424668955, 0.01962855157832946, 0.05642766546037409, 0.038708293089462865, 0.07229337318530006, 0.0220228732007766, 0.08136162489292123, 0.04418954110494064, 0.13596436549578944, 0.08870944230546875, 0.2524319925015011, 0.19352107218677, 0.0770920483515628, 0.1947512561755796, 0.2697669534433273, 0.1465088150073444, 0.14018383988689992, 0.11466688371353573, 0.11575269843301467, 0.11845864355564119, 0.16986913408242887, 0.1728148647253552, 0.20380923464413614, 0.19100134771677757, 0.08931619160237814, 0.11999724688188684, 0.17626871084493978, 0.1658079640999917, 0.07041665695367322, 0.16659654436572907, 0.14766491829387604, 0.18073819036925995, 0.1832671538596192, 0.18328509563880582, 0.16643972616762887, 0.04952273879861159, 0.1476941368873081, 0.09945576364595084, 0.09788223437123722, 0.12731487276933848, 0.15843375495845274, 0.17994224033769102, 0.18710922269571215, 0.09226284921169282, 0.18233779727691607, 0.12561661671967278, 0.11560102068488637, 0.19661456586853152, 0.14452659314678562, 0.16788190200684533, 0.13147286860452545, 0.14867736477284663, 0.12025015548832955, 0.22427354218258014, 0.20421149209141734, 0.12598522758531955, 0.1462509344902731, 0.14903952517817098, 0.23236620390126783, 0.17934289911100942, 0.13036795531309422, 0.18287877792552595, 0.16991209629322254, 0.23678686830305287, 0.13959409008103033, 0.1737250691099513, 0.1245482994483844, 0.09453637600545922, 0.14057229242978558, 0.21272243781676217, 0.16164021596552866, 0.10768670423497116, 0.1931377677547355, 0.13903677643787477, 0.07891627989949719, 0.12061570200227922, 0.18608065772681467, 0.18126365007652392, 0.1350338751029584, 0.14696932578038785, 0.13031658145689196, 0.15641641562744496, 0.14460931532084942, 0.2786995386404376, 0.21620174869894984, 0.17938134140304982, 0.1533331722021103, 0.1774505240422103, 0.13426751138702517, 0.08022057523410167, 0.10614250846687825, 0.11667619444309704, 0.17712846067884278, 0.1116356883017767, 0.17717735241017035, 0.20712421966656563, 0.23460281291796317, 0.1937389016271599, 0.22472230116686515, 0.172015467298127, 0.23881235880957496, 0.23608171501226966, 0.18267469210249765, 0.19355036738899448, 0.11977551039308311, 0.2348111581898505, 0.16621337782952095, 0.08855677630391814, 0.10396675747488776, 0.10047821523321253, 0.15734601735828385, 0.21883444049425665, 0.06422654778185873, 0.1818957032575723, 0.12686478079206523, 0.1895054078270351, 0.19542814082195684, 0.200054147430966, 0.18801228714085397, 0.12884929325551758, 0.19276828354885503, 0.16765008380095806, 0.13301503423961902, 0.21000567553264482, 0.1086516226191194, 0.2652612532819471, 0.13029968155728233, 0.09997575348543544, 0.14384377897987444, 0.17712167313983365, 0.12704199991158902, 0.08079560849094584, 0.12222142995245035, 0.13184072870400645, 0.12751257707995753, 0.13864127588608574, 0.12729027368608983, 0.1343153918822927, 0.08248546055608219, 0.22556950248056845, 0.18951516778719044, 0.09289388349580188, 0.1190968101183253, 0.12222377418149864, 0.0946229056365067, 0.12520529645224734, 0.19891292157192386, 0.15947335159345982, 0.1472178753465414, 0.14955390725404988, 0.1655628925730144, 0.2643508037492152, 0.08293757500547556, 0.10767864499000773, 0.09461683055926716, 0.17355032445442292, 0.15912835155763935, 0.12721023281976102, 0.10336755414403255, 0.09113547422232167, 0.1858981296179756, 0.055286083370447166, 0.10058310033092577, 0.1813666276153057, 0.1167505662587862, 0.05508027001914959, 0.09934146332764819, 0.22776154050182915, 0.12590015352132822, 0.11853235653571545, 0.21839036996806824, 0.179912454839195, 0.133887593063616, 0.18644090291232834, 0.11443629890920655, 0.2998693059048345, 0.17823311350037976, 0.08486809359202463, 0.13285553473378384, 0.17158697900031844, 0.13057007995103637, 0.15597179351795107, 0.1848791254263732, 0.1876896262289055], [0.02382013845377632, 0.07224155499810173, 0.03701012513990845, 0.059414952542752995, 0.030818845768789613, 0.06445655418980507, 0.0968878599064004, 0.01800894403019019, 0.04273688518292001, 0.05470871354543394, 0.0470312255164308, 0.003084607061839873, 0.07813458676419913, 0.010927055845968427, 0.06174081846350624, 0.029838329834503033, 0.05584613960837165, 0.04885436538907309, 0.01924720067050188, 0.01684010070147774, 0.05891404978390183, 0.014977648069391088, 0.01952624245126161, 0.044616585327011925, 0.08957409510208715, 0.050032424755514636, 0.0430994286322065, 0.04400128648886758, 0.018710259220472748, 0.050926820915793224, 0.04164963021814343, 0.0121863923531266, 0.029322419413215214, 0.010213414300984193, 0.02625676919706166, 0.029134214592857227, 0.016100153612393527, 0.06725774702405737, 0.07049885818794852, 0.0365516061954681, 0.0357165205622873, 0.012992993879672742, 0.03292554351050527, 0.10337801890507822, 0.04730387620868222, 0.08671317805325793, 0.09218817096083395, 0.05577312376830847, 0.030579355192340674, 0.011178227348042833, 0.0682936817587864, 0.037075369017979795, 0.04100489062106898, 0.02194079454056919, 0.05064480096822785, 0.028516280412253354, 0.03612411381196111, 0.023895295509587855, 0.06204216297896159, 0.016093764439105027, 0.05249311065962238, 0.025299069276379964, 0.027876562521522565, 0.05361739448421905, 0.00548690126555401, 0.038522340567602266, 0.005718123838080154, 0.03295443268612989, 0.06313834286805603, 0.051866925712074005, 0.04919566522021929, 0.07297879971203304, 0.017541888951053543, 0.07632895583106626, 0.03878547644783412, 0.08796142639532205, 0.029413897972253543, 0.03325178588349973, 0.021588618176118023, 0.08481069828473753, 0.10991455686669196, 0.03169360326512927, 0.029530948546204357, 0.03063482761893782, 0.02431308347431402, 0.03495272707134005, 0.06693720051477994, 0.0728862103255045, 0.031945847290297674, 0.039483493629602656, 0.012834247055223152, 0.018525796739624876, 0.04516798860183166, 0.054440149932258555, 0.03931949718765194, 0.06855808934497257, 0.0631347039504157, 0.12294070990455729, 0.004478933049305793, 0.06491282849662727, 0.04052358056088129, 0.008467634944545646, 0.02337579213593516, 0.0693861997476028, 0.08450589488230406, 0.0370580286178137, 0.02754831299816649, 0.051280726723733454, 0.06647035419460266, 0.03723530519393183, 0.030658156911451972, 0.05573301140459315, 0.044853095821435415, 0.00942569588416166, 0.02779009417750903, 0.08630951866507532, 0.03857396340237991, 0.06820558164749416, 0.05217719515184722, 0.02041301603669361, 0.0295202539587814, 0.03527012112880907, 0.03119462721740767, 0.026963979433921557, 0.011005017741192735, 0.017085959383797263, 0.017510010117304423, 0.020901276429574338, 0.04684203627309011, 0.07550338884034465, 0.024576675176860827, 0.02493260920258059, 0.02566820491225489, 0.08246967148396277, 0.010053966506083888, 0.05879088582831526, 0.023173339995405367, 0.07122886337099538, 0.056052293868795525, 0.014407127070420933, 0.030361820695801612, 0.03620319706838458, 0.043333828554398594, 0.03073369701122565, 0.03719910753950958, 0.042251848104980685, 0.0531316526053894, 0.035636935518273426, 0.0687396981483025, 0.07191885578175707, 0.01904742026160802, 0.038369111491427306, 0.04777449168144696, 0.04884201605173369, 0.05089222438513272, 0.02246017725537381, 0.07855710723707754, 0.05958076461308426, 0.051945273524090174, 0.03282763747378223, 0.029258853267698042, 0.051649751276859356, 0.023727838265439196, 0.03124818442419412, 0.04211107561845453, 0.04140190802694809, 0.039261289827165105, 0.0715236003781038, 0.022890523316398747, 0.052953924037395954, 0.08898448319204393, 0.04271977077869158, 0.02299094403673324, 0.010203177451095995, 0.06851420016779054, 0.023965679837631124, 0.02916664309469202, 0.028593029015727585, 0.05098761765346412, 0.051982287062151786, 0.03260631850289722, 0.025098568744837277, 0.0463202384661042, 0.04743441376053999, 0.049794527641948194, 0.021637056000350464, 0.05649799999270228, 0.05182893158146932, 0.023090679108375506, 0.019236666961543022, 0.08028504153292987, 0.02258456312119961, 0.023539095268314405, 0.020447101203664657, 0.0197569900492747, 0.04014996331064932, 0.01332708195062174, 0.025917809764524142, 0.020772675164945183, 0.03132887263481896, 0.06856302295120494, 0.03524172607989561, 0.04865895934222687, 0.04357966233886058, 0.013653991777720231, 0.03092580504955784, 0.021538586889003074, 0.04813667506940904, 0.05552763472341242, 0.02267385258399431, 0.03475861188264624, 0.06468104093425697, 0.03358843173050592, 0.030648925551964395, 0.012926117276712772, 0.04670083477732636, 0.022282808748704773, 0.055774705739872116, 0.07891555977684837, 0.12373575595237556, 0.05274837881687188, 0.062313630065369996, 0.04614265545481636, 0.03343087425755878, 0.03595619116939845, 0.04262819645866271, 0.07132391189976085, 0.02757267842459823, 0.08282702851800189, 0.032952900510281324, 0.04190084193983386, 0.07145033172902561, 0.059073729320399226, 0.029046223649094184, 0.02475024005698581, 0.0692450097431579, 0.061199788019181266, 0.05419899311457431, 0.02833858248777688, 0.054498384105822736, 0.03959084169999246, 0.05205673165619374, 0.05839519758498477, 0.05167759857290695, 0.020298447587617466, 0.024257379306119778, 0.016808436372347416, 0.02105459743630021, 0.03408270016793282, 0.008663065889249406, 0.026156051617656505, 0.045730572929906274, 0.07689818214144438, 0.027192413446403323, 0.02209034256426798, 0.05269652998615658, 0.12299869509954607, 0.024078053444804206, 0.05203704319653973, 0.041777471140507734, 0.013525632788397133, 0.02500954932803589, 0.026355334069399584, 0.05677370737577158, 0.06629534906918003, 0.05380628495326927, 0.017977712540737083, 0.060730432761051965, 0.030895718861551538, 0.06550343632097207, 0.06470348731043839, 0.0524925590763169, 0.03618644272548057, 0.11372781313595273, 0.0410066832668118, 0.032213234958509286, 0.13462971775762497, 0.04774861323136476, 0.0785778069327916, 0.06946077074615226, 0.0806782668035838, 0.0630631666600464, 0.04884403086297455, 0.010861804307017837, 0.03248438794886874, 0.03441626251104378, 0.013169050460771449, 0.05396979109894845, 0.04473384657514192, 0.025044396752491597, 0.06000638391161638, 0.08492442403709696, 0.03844706859860209, 0.08055638987571001, 0.013476476756735675, 0.04586676038020561, 0.01880534796885425, 0.022489091328855966, 0.008895854153970798, 0.044503150688063715, 0.004693030683894552, 0.03756872964121642, 0.05256637930870057, 0.005821901459937856, 0.04235274954548767, 0.01772881248935817, 0.03984655035779842, 0.03837267380027521, 0.06975913134914252, 0.032842488088194406, 0.06348722313921298, 0.03003621226056449, 0.04249274062233106, 0.043426237910264925, 0.03381030611513603, 0.022619709319945787, 0.046830514310708934, 0.05251701260285993, 0.06799677672285227, 0.03699065501531286, 0.04194290016687686, 0.04964692548157708, 0.07052514266463057, 0.01746789060322748, 0.02057482912806013, 0.04428640143164704, 0.05410962512776737, 0.04953364789065334, 0.020137161181698886, 0.06446303529364449, 0.0772250412152179, 0.01324751222836635, 0.04554300396252544, 0.04059918577812853, 0.05156587614046951, 0.014688926767708074, 0.049542461732222196, 0.012623281762634796, 0.04133258473067995, 0.01254168190738006, 0.07448665992987734, 0.028824596327819654, 0.0399312183951899, 0.06521925600546022, 0.052667024109752915, 0.046923578671750524, 0.02243676177796818, 0.07016840616181012, 0.023995266153266834, 0.02330589810416343, 0.007821487660910334, 0.05952547987802856, 0.17064855193659184, 0.1251599210644922, 0.24025510155385543, 0.21256765741254055, 0.14333995359559215, 0.15120265104116934, 0.21544079356376203, 0.09292137839140431, 0.13988302780255196, 0.14149673072801483, 0.0994876329036009, 0.13191156119348543, 0.12586842982038376, 0.11399587496153771, 0.16695922571084193, 0.12476198435310396, 0.20368362686807112, 0.12155440485765859, 0.06753817350874025, 0.07987650216466959, 0.12159231854903123, 0.09124160804335149, 0.16283767267821297, 0.18046472762380877, 0.29340180778695696, 0.11348147756390034, 0.16700649333577003, 0.1462349385744141, 0.09141736393493992, 0.19119550504030722, 0.144519284667988, 0.19242072477936747, 0.17175242334844606, 0.08707395950031858, 0.1177286000681981, 0.1630426165197165, 0.13264812408916413, 0.2205620147287846, 0.289238732788832, 0.11837305621274057, 0.17840485509124496, 0.09892826614480826, 0.17759756695839668, 0.2758892523425241, 0.19183653677182813, 0.17595698966855006, 0.19849903490995208, 0.18000725055894545, 0.15159669602590223, 0.09035137557094136, 0.20963885731274085, 0.0998835394819898, 0.26491170268385644, 0.18029954374557544, 0.12977149457700793, 0.23899839560110725, 0.10923484535587412, 0.15325988823127362, 0.23592243001105326, 0.14077123014196274, 0.20424610394383633, 0.2757602124925583, 0.12440402210960466, 0.1591784383861288, 0.10199234205027742, 0.10936249858669697, 0.16793929731413243, 0.15228118026448836, 0.09973484947676621, 0.20154716086483773, 0.1679249561481899, 0.19811386122338234, 0.12281641213884278, 0.1386943198139629, 0.21252814259740616, 0.1776284249799867, 0.11128514178938444, 0.1396737632251555, 0.14009512690526826, 0.20510222252097823, 0.2288832617623191, 0.268002009439853, 0.120996049334926, 0.14529762999905696, 0.07571728058880375, 0.14800107767505033, 0.1402193250795526, 0.1870613575222031, 0.2622872999598903, 0.13708414089295173, 0.07002129429771055, 0.0914893072519091, 0.12430282189480721, 0.18047044263972392, 0.15345715587177586, 0.1536814664160052, 0.30833929656974735, 0.32270577405729606, 0.17059092680292745, 0.12771915268873976, 0.24833803395590476, 0.20351406096691088, 0.11300221295847047, 0.12320707101495036, 0.1681105486087261, 0.11729882474267676, 0.12602216834502836, 0.17687552908976234, 0.19610490289426621, 0.22899895636064393, 0.2183530308426388, 0.18116471748198235, 0.1325771383821003, 0.08873460063290212, 0.16688218790917628, 0.40389782538817776, 0.09653241043129275, 0.1572377078475491, 0.08642251663390668, 0.10409608843826479, 0.12220279869413185, 0.11552323211705494, 0.11852473396086886, 0.0896653438347482, 0.14272136824025264, 0.1813291505940499, 0.2026557820218225, 0.12498175199594229, 0.15508751354871259, 0.18756372733942925, 0.16442773413033257, 0.1593144036709301, 0.14869519929972388, 0.24407345230781266, 0.1348323020483217, 0.18103074402578417, 0.20844826474785808, 0.14391962168437822, 0.08832137280654523, 0.12092959886837391, 0.1867996465655104, 0.1575309969484806, 0.10205871590803708, 0.14298488716444663, 0.24035225682441266, 0.13575952890659534, 0.15912977648117851, 0.10254446927818561, 0.2468717876341074, 0.18689988150952325, 0.14213111281635302, 0.16003461825030466, 0.18675060161659796, 0.22144594229757789, 0.1451018026038524, 0.1872554535586988, 0.10422560326274365, 0.15885292762710204, 0.21125962356886557, 0.06385758068532714, 0.0728057787543343, 0.10507612173715908, 0.17740186213726, 0.16279543059006815, 0.16677070679443498, 0.10775013631510158, 0.15432304973083158, 0.1550610069065325, 0.14751747701196902, 0.12189063318674603, 0.22797990620376604, 0.11948697869816136, 0.1577934739930976, 0.13303401789838268, 0.15858202361531798, 0.16799249445959447], [0.007256892352034488, 0.059456470677809375, 0.034708456106243596, 0.08063478365300164, 0.048330824732059435, 0.048501325260487296, 0.05074901573900735, 0.06972900111108057, 0.006765684914670044, 0.042345230392510855, 0.05458779805790513, 0.03666915089613007, 0.07564973461651996, 0.030431232092181043, 0.03214189302056067, 0.02356254330445682, 0.0269367469234332, 0.07321208880673494, 0.027557887182000185, 0.042675762857881286, 0.02843828117024274, 0.028051797473322482, 0.04338733596546997, 0.003119140869051579, 0.05944552711181103, 0.0955571421992875, 0.05142367489996457, 0.050012659687068195, 0.06701331135005721, 0.05022729071037424, 0.04263011550891303, 0.05011191403853798, 0.060312187058791045, 0.06495153891944117, 0.02678510939492093, 0.0818479604898922, 0.06561467228757759, 0.0537370459266728, 0.06235932721005333, 0.026303084957743847, 0.013013497265356203, 0.02632322157883356, 0.059299660140588406, 0.02669805690886513, 0.04680274362345377, 0.06686773932268543, 0.027941432931730827, 0.05362117129768576, 0.05584345063975742, 0.02057635747346907, 0.039969507469645435, 0.05358953186641297, 0.007140152043693009, 0.016657130176862402, 0.031054950236613234, 0.034263286243883834, 0.03176349538168119, 0.016252612770204584, 0.04640903954784717, 0.03693080822666807, 0.03081560904730953, 0.01298650415734418, 0.031992741447362694, 0.027431681857354222, 0.01592623537421347, 0.06540100270461652, 0.0569259443680846, 0.0709313990908765, 0.0464444098273112, 0.022756959717240066, 0.03915692566924038, 0.03784597686101352, 0.055128399492992516, 0.020997395566213998, 0.08569366058274623, 0.09689116174535406, 0.027783423466908357, 0.04073319753872291, 0.030968592975348718, 0.030522747040395776, 0.03191407379363814, 0.008939951132502287, 0.0421610398728761, 0.07776822819704972, 0.06257441022523469, 0.034079915438328064, 0.06751172049271484, 0.07327113120305924, 0.07704149420943952, 0.10474468145759837, 0.016466186592175115, 0.02369768695995933, 0.05095687837550237, 0.040089139759901075, 0.06690779806024606, 0.04999918420048011, 0.07503337091616086, 0.03905910773262863, 0.11620256824478989, 0.03284178328730407, 0.029833798424430916, 0.0590364974472792, 0.05011993497910519, 0.10182064642468769, 0.018651990572951974, 0.024415785221443064, 0.09242142175113963, 0.04449884527392926, 0.005125495935640028, 0.04865398743159829, 0.058597483101391026, 0.020654622931033373, 0.07794549328184898, 0.012753502345613897, 0.05381310313579537, 0.05195761137011071, 0.10034036537211749, 0.0679178390231344, 0.04498243061525207, 0.03750690251528736, 0.029047895635988925, 0.04908630233858863, 0.016711683297950416, 0.040081969176929806, 0.022394148137180075, 0.03967418440527493, 0.05414673442681951, 0.05788056270009088, 0.07861711490418642, 0.018000463436868404, 0.04342529179167844, 0.09057193228434171, 0.02837925984133636, 0.06600684801777525, 0.09866597296129312, 0.021843687150507204, 0.04939457611931909, 0.0345005436740335, 0.00545828165711775, 0.040976656450619625, 0.057438372919756564, 0.059132089898470915, 0.03082339633105984, 0.09356479265636976, 0.009535982859350983, 0.07808921903732323, 0.07098707836121321, 0.009465610980236483, 0.029443185513598785, 0.04326675755662784, 0.0381661901220439, 0.020642396167761857, 0.06865345963066624, 0.08854195250258332, 0.08172698754576907, 0.06261793551065269, 0.04768307823988219, 0.03353647947792084, 0.067375801173189, 0.030626540462816917, 0.019839938219276168, 0.051852530919976776, 0.04355070038488315, 0.06061682958276041, 0.0663516488707354, 0.016944093306759195, 0.0490392453878397, 0.008291281504376281, 0.02865974186739374, 0.04859738502531283, 0.02539288057314773, 0.09908382795871266, 0.023940224651127093, 0.0856461171661654, 0.05652081026064773, 0.052313945676770904, 0.09403799750631857, 0.03844737120333218, 0.08287489369151094, 0.051064314546003464, 0.025936820236365163, 0.07149071222351444, 0.05073441410317056, 0.05624714450189664, 0.020703378681754394, 0.04214635396736764, 0.03254222375671229, 0.016467561719999198, 0.03692115934926175, 0.058736194811400876, 0.043749572979586746, 0.029570564867988713, 0.043017909216183814, 0.030266092264003334, 0.03160724025820533, 0.014455043954864867, 0.046853960431631536, 0.024976504125422048, 0.0038595725087479, 0.05687130697732491, 0.03557994240714658, 0.14517507125293055, 0.039642652226311546, 0.07310538808064115, 0.04150990344163391, 0.07733763315744939, 0.06947551027781541, 0.004010124347029975, 0.026126359964931206, 0.027585280570952643, 0.03638581710777456, 0.029296500743516994, 0.04584960767158097, 0.08651642369166498, 0.04678743718672664, 0.0473278011345575, 0.03034158639850155, 0.030463758270226182, 0.048695187640166095, 0.04288165281797129, 0.014255232902454033, 0.05936241040246622, 0.05368596318388178, 0.024631494513502526, 0.08378982483859986, 0.00903178592242541, 0.06060219730340666, 0.0888580710236584, 0.050983936600987954, 0.06061465389305546, 0.07702514589313539, 0.01391453636554821, 0.02952901225897574, 0.031075653762766914, 0.03681376914403612, 0.0030703132975876575, 0.05695547322712599, 0.07412487490763588, 0.030438260948886315, 0.10740794782196322, 0.04636402805185607, 0.05821089598260099, 0.035124250327146826, 0.004598262734831341, 0.0431177917597515, 0.07826145858533921, 0.042637676796725685, 0.02741613984859038, 0.01875421543034815, 0.04820981731397971, 0.01334397514696203, 0.19210334987409655, 0.020537520646147674, 0.04537511196347975, 0.026727566615708416, 0.1071189564742869, 0.0687184009040075, 0.05123269301088107, 0.08623376789112246, 0.03330064697131034, 0.04195433402914674, 0.056980294475872675, 0.06616008092438982, 0.036136620197324984, 0.029966572953027584, 0.019491519516093597, 0.024993045878927075, 0.08243813164412014, 0.06346643917382726, 0.039922611397360606, 0.0819457516134266, 0.08635399772995904, 0.03892835184571244, 0.1146261967838772, 0.15547149213812045, 0.10784016696796303, 0.031200991492838632, 0.09743803361010167, 0.03733632920850669, 0.016232208018341375, 0.04735144643834041, 0.03081408453234021, 0.08632248853363338, 0.07440458893054917, 0.01915842448661645, 0.04465682792567438, 0.04008872224198234, 0.03291260045502455, 0.05103426857761318, 0.06386259090035193, 0.015444534609184392, 0.02553854644629023, 0.0770700156628605, 0.04357495855900549, 0.06538108441858523, 0.06416708403717607, 0.027397826516760454, 0.008278938870306217, 0.01914283459735734, 0.05470015634331973, 0.035875135236569954, 0.057406315970565044, 0.021516102208425442, 0.03770651438483789, 0.09274782883303781, 0.030838605091576616, 0.010889945589306374, 0.0670025707973588, 0.035099118812790805, 0.016090343856523116, 0.07030371261099655, 0.01316340247754969, 0.05633491519538145, 0.0349912881070087, 0.05507971843584411, 0.033862212402445656, 0.04903944074026039, 0.04419249054344912, 0.02850421261222613, 0.07043726471883636, 0.013802611877420738, 0.031409099277469425, 0.06466487647905465, 0.034131557425303806, 0.01994068069653886, 0.04128380025166177, 0.04220674084799905, 0.019556273097893404, 0.019636877038846576, 0.041282773693843235, 0.007045798260913862, 0.06980292859577364, 0.01835733975073503, 0.006213441815963316, 0.009445938799950865, 0.03955862387233684, 0.015091041531113368, 0.04328595955044993, 0.049863218915678804, 0.009568611501655992, 0.012111403836658406, 0.006610738365129838, 0.015236530246423378, 0.08383288664082367, 0.029240562918505845, 0.035080001088640386, 0.020282003510322784, 0.1476881614014987, 0.012764596256367382, 0.03792214898332473, 0.013769175012355611, 0.04145206380335074, 0.23701067322925215, 0.1403719144723108, 0.13472963094470963, 0.13105441605852497, 0.0737730183848931, 0.1540612315218295, 0.12457133571226751, 0.14157439672177838, 0.05801733237721267, 0.12602285782416023, 0.18647281813525385, 0.11849008380405365, 0.11114278733129464, 0.1785882412185592, 0.0715543664691429, 0.0570980268680761, 0.0963416162337507, 0.14166724657820118, 0.17425716313863956, 0.14177065312622056, 0.16613588037510074, 0.0747841242099962, 0.09614429496709379, 0.14813612365434248, 0.12428050575357293, 0.24126342647979337, 0.14934013807965865, 0.22763613190862442, 0.14871015333600585, 0.22846732198471026, 0.14057857435076468, 0.10141819745542542, 0.2211638687238578, 0.14262052042590034, 0.12499179540862962, 0.13109181647098836, 0.17799440050317397, 0.17276171354516862, 0.17701927782787433, 0.0939796062847299, 0.10272700504790391, 0.17634377213976077, 0.26866979296168975, 0.16812203992759028, 0.11544189656213408, 0.2710897421404239, 0.09017548178352656, 0.1484144433972336, 0.16968104417525953, 0.1124438574357379, 0.17059863364744574, 0.23269261864404525, 0.1699729543179274, 0.23220190868502666, 0.2300138543209722, 0.1198624537116097, 0.08630918158638863, 0.13380683207463834, 0.2824999476152082, 0.14812487748361405, 0.13630775674696893, 0.13993225661256622, 0.10579822089282737, 0.14055795126384305, 0.13826501946295464, 0.21750389898736633, 0.19347789547135755, 0.19931818208386823, 0.08454795310934705, 0.21096251935007113, 0.1451143511240521, 0.15253265628651266, 0.12281210672470833, 0.1599950574698948, 0.16089124244547662, 0.3110771415935409, 0.1517973038097543, 0.15402890261142485, 0.16247231002536514, 0.13837941171180818, 0.08351447751685497, 0.1899277674214494, 0.26030242743511356, 0.14627750241948714, 0.11000013654871334, 0.19067804329097274, 0.2103762169398608, 0.13994514221145263, 0.20496431137284926, 0.25240792201892026, 0.22447646355196355, 0.20231571559223438, 0.19719501536700035, 0.12148053099912022, 0.2947415423489386, 0.11994615647821658, 0.20105988297971988, 0.2653605382769339, 0.3100830046159606, 0.2212206205172885, 0.10309627474916559, 0.17168543662034697, 0.16185689627403216, 0.2178176886011516, 0.09284474661633854, 0.11238582627547365, 0.16088040996222727, 0.1947855309493119, 0.19814922384196715, 0.14865597559800073, 0.20813047615510805, 0.23280828259885314, 0.16253076253398774, 0.24836129238528593, 0.10113331233902324, 0.16261388307377217, 0.18945760394056, 0.19125196572032668, 0.08906989433472196, 0.1272704932958849, 0.12333622577810481, 0.08984869165766625, 0.1920888095252937, 0.1803648450802411, 0.09933128968001374, 0.14130965205690554, 0.17508464534917187, 0.11480520854914382, 0.16461700381290528, 0.20241601182328117, 0.12698127978271054, 0.18728405928179143, 0.29118125597315453, 0.1264797756448388, 0.23093555002443253, 0.3025626258984689, 0.1715097420157925, 0.10634655598551036, 0.14530688434118225, 0.13091083585975632, 0.21300078820317023, 0.1709554314373001, 0.08750749631754814, 0.18326485559584635, 0.15911908189375557, 0.2435794788142366, 0.1887053668859505, 0.10794948771475785, 0.1051410400278626, 0.1371226138285091, 0.10944433975964786, 0.17875599915221815, 0.2153372184763993, 0.14475919276235566, 0.18997575516902632, 0.14199401372142378, 0.16054345384961174, 0.10883670180074631, 0.15340018957372636, 0.1654842153431908, 0.08665437314419017, 0.0947012764311606, 0.14860409612376846, 0.15881189595787756, 0.128939860169926, 0.08728209792846635, 0.09440026516395231, 0.16193336717063384, 0.15397785051215082, 0.11680932520257852, 0.12886276108122643, 0.33351518273834263, 0.15818684482045714, 0.10507801397433204, 0.19895275814398644, 0.10642288132540642], [0.06352401834221617, 0.06774321694167391, 0.05911269638266775, 0.05980528200105314, 0.0031560078927976715, 0.05623114092515842, 0.024314843561320056, 0.04560169778884419, 0.015186500874528242, 0.03141069848601136, 0.06415928526210689, 0.030395758390847235, 0.04712558456606442, 0.03307260174845015, 0.08614034346875646, 0.05045131780207158, 0.04782724832635253, 0.03211272996850312, 0.08459460786393574, 0.06026236836107508, 0.020738484660884546, 0.043746569914923567, 0.021503534536027623, 0.03447408682756847, 0.0690281149300356, 0.01204878572494753, 0.018027730421313358, 0.03804532443023017, 0.06263094368360697, 0.04088013320259991, 0.06247560020476099, 0.040297236053213, 0.042737095857099186, 0.03317141942980309, 0.038064227649761785, 0.04067083032080724, 0.032236118004807544, 0.05661625715513384, 0.031182871598209587, 0.031272184043642015, 0.055987873535242774, 0.01924801655414124, 0.02917596063907108, 0.0509285714267002, 0.036367419506272966, 0.012090506873303845, 0.04856780637055636, 0.05461669106396937, 0.035192294256581415, 0.04469662619334075, 0.053227118652073614, 0.05025766609657196, 0.010397428620396363, 0.03052507977812521, 0.0426418136715168, 0.03846919321785531, 0.020299510534612403, 0.06334156684216953, 0.015103532594718761, 0.02275830994720661, 0.02498682716020173, 0.04448460369941689, 0.01876642495664137, 0.056168693268010696, 0.04419218027783979, 0.01350681862658671, 0.011912208527416713, 0.011960574530906255, 0.039631605238443425, 0.02445546474548117, 0.07033647819151802, 0.10187474755390037, 0.014442826767692403, 0.04789221258233151, 0.0635293541446088, 0.1464401428858119, 0.023664134224095655, 0.05132584547203395, 0.07586387917399406, 0.03193056192098847, 0.05485790916868756, 0.015391465783449671, 0.006738504593921525, 0.1071400928401178, 0.052848893382977095, 0.09403488718934598, 0.018832549835825642, 0.06486774422228336, 0.054930947991388465, 0.06811194272050936, 0.021679332562451883, 0.06135875892434871, 0.06294219371592326, 0.07791235997912385, 0.06026640181399642, 0.010434455564996649, 0.03605622310011137, 0.08609432456714493, 0.059852227869053046, 0.0498543054826798, 0.030076868546706055, 0.009857676585295029, 0.021265231395861315, 0.10139418825987848, 0.03951358939370802, 0.03815605094836604, 0.029894520468529195, 0.0373491267072818, 0.1691196702661053, 0.08587100993721716, 0.08916848985057685, 0.01866279624312395, 0.07215638134268022, 0.026143008970745632, 0.028582841961554466, 0.07970862931782201, 0.030015709832490935, 0.02212792300739356, 0.03337316485422273, 0.03292509917950919, 0.031910231862697876, 0.00530880018730738, 0.04988860706948946, 0.03832670086393914, 0.01046324897963073, 0.016893316999137882, 0.064687667594802, 0.053587287228794835, 0.05601454871676623, 0.009872306949428974, 0.01740099580567931, 0.015574769556312072, 0.04323609871789814, 0.01590657564285662, 0.028252177346017093, 0.046273775233496586, 0.03133223576080655, 0.04795078000414276, 0.0187114677241733, 0.03595674658314355, 0.029405922996961785, 0.11966410588713423, 0.03229999441593405, 0.022650735880879146, 0.08175808305461561, 0.03248865505860698, 0.03819119906233203, 0.02963263714205354, 0.03299372150532661, 0.07022756347132307, 0.055966147281710184, 0.09803817922910375, 0.016512038869663112, 0.07091403953851232, 0.10133183636372128, 0.06289661148442857, 0.06345008702708349, 0.019108109746969516, 0.02763158867075559, 0.027523602832168825, 0.09176741249018139, 0.0350270107869179, 0.06609271881320784, 0.050095856835645054, 0.041175931241483464, 0.01449352359369157, 0.07435830955904338, 0.0769302046166793, 0.04788087065061254, 0.009639230444126073, 0.049281164463008606, 0.007741456370680563, 0.03375263884663582, 0.04675348416992253, 0.049414946397225705, 0.0387874223111618, 0.05486452433791372, 0.06352836206074684, 0.02132691871074419, 0.019370600198125167, 0.02561849729728795, 0.018242907282265446, 0.012254599076245102, 0.004712502723709951, 0.030332175008351767, 0.03461429623947029, 0.08226909434362766, 0.030059859479567217, 0.051359875097630486, 0.021964173628798416, 0.03167804784982676, 0.021817404589044954, 0.030048404549879414, 0.1054373475152158, 0.014592370003341668, 0.04260093905031682, 0.0251989224324784, 0.01807889934899586, 0.06134114273252988, 0.08209473273206143, 0.0042313305593486275, 0.039496287297938144, 0.03619608011156802, 0.0237149890557292, 0.049501782463442896, 0.07906140759587288, 0.05411786057295338, 0.03788962089005978, 0.03580239901859914, 0.021768591381729614, 0.0357754020801475, 0.10914299907463212, 0.07737002335488796, 0.04203929701038907, 0.05040178638732722, 0.03269208204602042, 0.005745286921850376, 0.039040893992228855, 0.029695379743052107, 0.03285669518875019, 0.012463200987587053, 0.05919888510458893, 0.0827950826515594, 0.060590686832344344, 0.031864055913061864, 0.023136931666803938, 0.05797528181104891, 0.04361617025889216, 0.024337542746516488, 0.05855908294418647, 0.04871778340349275, 0.06081166872454267, 0.03721508430317044, 0.06131609931828515, 0.112851002523976, 0.019725323804924567, 0.06390647624709433, 0.03766740559630337, 0.061066147811230154, 0.030652070342893564, 0.04876632656481478, 0.01298433134046894, 0.05253480116446173, 0.029224262482696967, 0.013454614522596522, 0.005334558936151406, 0.018579505248776367, 0.0948061538679946, 0.05349058011967329, 0.06226073935507767, 0.05012008436625043, 0.23920410553053503, 0.016376843503225717, 0.08390559604571712, 0.01875006131857874, 0.034175327858857574, 0.025724623457438527, 0.027952679102459264, 0.05469704985678677, 0.046433171317462, 0.0709878980752922, 0.1097649245733215, 0.0959749895358278, 0.046776263794351014, 0.039918872888290116, 0.07003091636203951, 0.07114222648763849, 0.027403719648117983, 0.11182556319380961, 0.140714539635566, 0.10871143110336796, 0.09012380149215461, 0.07535711967296178, 0.03877577394427311, 0.003517749343788432, 0.0373088036693873, 0.03278621126927676, 0.0142178573878482, 0.06903013740215572, 0.061898854741406065, 0.02373202493594539, 0.051782977797331355, 0.05348581888322389, 0.10030706353004902, 0.053245998888967506, 0.04814790591837899, 0.06373098082540017, 0.016555518189805652, 0.0239082787846846, 0.005570946377702058, 0.015923117396361645, 0.05858432171085189, 0.02080675267103699, 0.019033216991491856, 0.013411138075283699, 0.024314127269110853, 0.02730103513796724, 0.0558038936897872, 0.05197440784785056, 0.026525692871561455, 0.01850421412757808, 0.021444103350081754, 0.024234615003449783, 0.03164828150352884, 0.04788509945595457, 0.02321199870728437, 0.03188957430181965, 0.02849782726937725, 0.02486195099810439, 0.01274131675956831, 0.05550213548685274, 0.025602880594951492, 0.07288477774108611, 0.03594978667435146, 0.045612476645938815, 0.07369791878567589, 0.04047868780851845, 0.03745464382753257, 0.029310056669337135, 0.016126018655937047, 0.025335680618281328, 0.03304872278785033, 0.024613376534093293, 0.025522180893007788, 0.038417999392315265, 0.05820832192717541, 0.03971376050744326, 0.06411904266344444, 0.05295747485492499, 0.02298719786678351, 0.01658211293209705, 0.07704609839786446, 0.03478720228398039, 0.027706002621280573, 0.008033838615031734, 0.015968448734061134, 0.027959920548563524, 0.02386823728410227, 0.04455289277698725, 0.06890463687840008, 0.06254927488043904, 0.03293924116259141, 0.03878374125868563, 0.034976912467109586, 0.027314951125111793, 0.012025829900296466, 0.01759689406401688, 0.009898740813256273, 0.027540295888038895, 0.020395355794819135, 0.08335124716282853, 0.02898213081812907, 0.14895320239086307, 0.12104648090298138, 0.1977938662974104, 0.0947865573388915, 0.090127631931776, 0.10173928022624985, 0.10072643538155865, 0.09988443580486121, 0.13021934957754228, 0.15234049079158615, 0.1734695481436868, 0.17179920067710264, 0.08471647713093028, 0.14888168042225225, 0.1928480486235311, 0.12180972664106278, 0.2757850643848219, 0.22036356731287896, 0.18260163795803824, 0.1693130461799522, 0.12005687916591284, 0.20357047568165487, 0.14100957541696488, 0.24516701217620607, 0.16546938388097673, 0.07543690773027559, 0.18584451878503447, 0.1180556736465904, 0.18455641854914928, 0.146792987661977, 0.1369047690663607, 0.12128322505422177, 0.1423722772949165, 0.11777131713085598, 0.13779292544049604, 0.2129321620469132, 0.23415229193145232, 0.13402539695943558, 0.1439343458942829, 0.13624237880351084, 0.15250644075774378, 0.10455174221386833, 0.11826888357679691, 0.24763700221815418, 0.0841906956667381, 0.1932299740973019, 0.1321607236299784, 0.1743230007348522, 0.11741358471373398, 0.1145293019832142, 0.2053187189683799, 0.20333340211260706, 0.13230153059046115, 0.15528527148548635, 0.10513680356164133, 0.09766635845505423, 0.1257893312422018, 0.2736520610990063, 0.20145581254074652, 0.08676041503466907, 0.15136991867855673, 0.15519827454080506, 0.13911065795729238, 0.13760914094746113, 0.15671508266560494, 0.18877339549362662, 0.20094778899463916, 0.09881019667391816, 0.11130760348732434, 0.11122482002622659, 0.10724736047127556, 0.1785074495860646, 0.137507098035947, 0.3904453827248466, 0.18567548914542123, 0.33119672488781715, 0.12695569244603958, 0.2579722637611051, 0.12024464731615399, 0.11355909759238844, 0.10572228625777269, 0.10055198183944149, 0.12015088581510129, 0.17281213745234475, 0.19903826887809462, 0.27209264316385795, 0.18114726599906722, 0.14799956082096025, 0.17690799589599335, 0.2018601077819063, 0.09225847484964518, 0.1070801541209221, 0.2228419536784772, 0.21064235588475583, 0.2142485615707213, 0.14185329869149194, 0.19366198639956214, 0.29852344263945857, 0.26042766748897495, 0.18087686760531319, 0.2429891161380276, 0.16783172324780496, 0.1878113422783152, 0.18355102007908208, 0.2541083307756532, 0.11766683805974261, 0.10940926059359506, 0.10323142798076715, 0.19706540861197058, 0.20944077761903887, 0.2615938065273147, 0.1518846378331223, 0.168698352551268, 0.08437287903601125, 0.12120283178744778, 0.1511682996586446, 0.11450720034659871, 0.18942666931017754, 0.10535058805779104, 0.06289010739795144, 0.13505143383818288, 0.12856046278630534, 0.2164720091968775, 0.11910594954726197, 0.11370401078414534, 0.07968891787553027, 0.12212073535568292, 0.20191840707294403, 0.12686747742155868, 0.05728039792889068, 0.12536118002307992, 0.13413667889131656, 0.07287145547208286, 0.14741131254742224, 0.14215086256304096, 0.1339644623259383, 0.19411290575179363, 0.09414744082718127, 0.19015279808832755, 0.14198362556917055, 0.19537403969274414, 0.27290972190037854, 0.11918397560234993, 0.15721152296229718, 0.10134629244285245, 0.10457173710869205, 0.11949801036427099, 0.0718458399416939, 0.12422120288735437, 0.12668619037515697, 0.11128266732538901, 0.18092473277882223, 0.11299449079219373, 0.15619962806663207, 0.19968124647294322, 0.15660809082609994, 0.1265671096682068, 0.14275404955110244, 0.09856276559613406, 0.13384528968843723, 0.21436411827321977, 0.12054971884936096, 0.20650787128796502, 0.20202207409085768, 0.2125102008182195, 0.0785508176552192, 0.12321526049486092, 0.11869319669541814, 0.1509502403918774, 0.07791376192002528, 0.131797015727047, 0.11959538780032627, 0.13693156682195204, 0.17090617198376887, 0.22089132528391578, 0.11849965990310717], [0.06701596201427522, 0.0788412569090724, 0.06458953939258091, 0.026727572361367847, 0.017133295956638553, 0.03533547992006906, 0.018049659688145887, 0.08836977424160128, 0.10083473723141417, 0.053804645525111314, 0.025735881119485826, 0.0444545385788285, 0.03605159975948834, 0.07995585355186656, 0.055305116824925914, 0.06150798902155892, 0.034808480376077276, 0.005808391978198122, 0.07124852884801165, 0.04040389464447095, 0.03654409470337053, 0.04333792712479349, 0.05505560581842738, 0.06617567081364893, 0.05379220042678137, 0.014131562371227532, 0.030773502939771262, 0.005019395152151946, 0.007994672848707847, 0.11481880660979979, 0.010240271428389656, 0.037951210528732314, 0.03473937541486756, 0.03448672344787948, 0.07060008138538369, 0.04155604874775295, 0.0218536367174238, 0.173416105850089, 0.03311988469513674, 0.05346428798211198, 0.028006567642272964, 0.0378271081154385, 0.01703463340809028, 0.07006054864295068, 0.04371827062700064, 0.044604626694513906, 0.021398195531219247, 0.011041428942623879, 0.05530227846916645, 0.06386244151320669, 0.047173411435177254, 0.04131421011181609, 0.05318306093554824, 0.052716869620546225, 0.01711793972419635, 0.03747381134739807, 0.01107079117754174, 0.02367966665676044, 0.04549369471327913, 0.03151355919638469, 0.038275212094548254, 0.06518989185532255, 0.031532337926628615, 0.012187569255700276, 0.08641052735789169, 0.13904938624510843, 0.06182369768559452, 0.04393512713572672, 0.03989046251761817, 0.02862743402440702, 0.027484051627858032, 0.014297780468158666, 0.06686935576820566, 0.020208752098222895, 0.08635615043702626, 0.035538301698022315, 0.029284589991514242, 0.010674431649667603, 0.04845752418341656, 0.05634434190728972, 0.020814110945549705, 0.016607753894922715, 0.02090926289618496, 0.029881744037172007, 0.05315222206615633, 0.04708271811626131, 0.06939031363975617, 0.025063512561422203, 0.15253567467293433, 0.11332022371671854, 0.07183364382193935, 0.05994479044250423, 0.041995258446061806, 0.0651686022719068, 0.08239321590911958, 0.08210542731948438, 0.10877546839295857, 0.10893020283190474, 0.06644655184279527, 0.05666066727210438, 0.04856538170227601, 0.03704391727824846, 0.04135452548883135, 0.009347127821867265, 0.020143081126133763, 0.021658832049598137, 0.01715828382950877, 0.0770307153523449, 0.027299937717015707, 0.07813541413915735, 0.04903218588761745, 0.02223549132806159, 0.019728698422231024, 0.04384929847512995, 0.026993447005929008, 0.02511397285777475, 0.05369763070296857, 0.06307565389321217, 0.022483843626574646, 0.02402100096186323, 0.0806275824265134, 0.031005487769782066, 0.018892511537659074, 0.01382967106051623, 0.03434513124727434, 0.032221144816327485, 0.026155727945508498, 0.06913925896609022, 0.033416414347987984, 0.045444033063587644, 0.027212257038861997, 0.06541325245052576, 0.060283596657456896, 0.06020222662857944, 0.009881848574525887, 0.0459023375034092, 0.09688408309293371, 0.011138194465949651, 0.06435825744824064, 0.005937816308540923, 0.02595678831811153, 0.0444238261139441, 0.015895737413947862, 0.023680917295296828, 0.0840733233358591, 0.06168268388137222, 0.01565581878587123, 0.021613426018326033, 0.044310640453571276, 0.04334864469485418, 0.042944996797990416, 0.031841157545005126, 0.03850235716409741, 0.04237781977280975, 0.09109460343156131, 0.0349037510703408, 0.012389951490706975, 0.012215514227958217, 0.037292225526705865, 0.014177419436765055, 0.013006898375498432, 0.04420972369130581, 0.055189835914080186, 0.008615744638166601, 0.05753540944668555, 0.08047945166547453, 0.03513841912330639, 0.06119420323821326, 0.013343263642802356, 0.05455760270236962, 0.06583822440476188, 0.04793568424159481, 0.040860172781732776, 0.014154382215272036, 0.01682305716038231, 0.01569208060015714, 0.05777913648935576, 0.007724674257089294, 0.0467328955569575, 0.07400338868460349, 0.03295728253320821, 0.0836221511746126, 0.09643235934838172, 0.03132231492218712, 0.0234089809800348, 0.006411520073250417, 0.0661850247472044, 0.06371150303992533, 0.009839834397538536, 0.047441772035052704, 0.02797903444227432, 0.046405837300323674, 0.06648644204101255, 0.028765310698579398, 0.012920979699570567, 0.0438439013857034, 0.024680899523739374, 0.020930924032243992, 0.07660440274424131, 0.04931231359800985, 0.0448113018947263, 0.04307552285852932, 0.022739006446734555, 0.05056461454519341, 0.039306634571403265, 0.032356171643421534, 0.03131734492677835, 0.001248790588673024, 0.03791703151599054, 0.022771563268296664, 0.05034896462494808, 0.011980612518175716, 0.05231987902774446, 0.05124315011104749, 0.056247351345636194, 0.024204310480385058, 0.06347394300504558, 0.040731546619246085, 0.045610147738649, 0.0064494893059975685, 0.031954977143135284, 0.03319199655144926, 0.03173484560853291, 0.05370033116290166, 0.014004094916726313, 0.023512490949923956, 0.07303303107619286, 0.03578096004803816, 0.0337930116802454, 0.023667738667779395, 0.051737253839570674, 0.06754324501079899, 0.03414720094071762, 0.03141063528375761, 0.020380225558314594, 0.11111199059673857, 0.039268605966841987, 0.014242481368954384, 0.03436515678561503, 0.03266279067423555, 0.10751470983509095, 0.04593246391103153, 0.014555038538791481, 0.046162558419089166, 0.04429839836854128, 0.03744040991389944, 0.019650674282362866, 0.04537852871562204, 0.05526186733116066, 0.0723800024077777, 0.03196032060640714, 0.20530269240900395, 0.01283059568865405, 0.12373210937385598, 0.10295746727816521, 0.016880326063161897, 0.06171622704113684, 0.06132293665300935, 0.04885733397977968, 0.022064002546211405, 0.06926563283007953, 0.021579842638945388, 0.07701466581033123, 0.059156631525125236, 0.09039667434990407, 0.08751787680892215, 0.003674552698935112, 0.01721629200713529, 0.029558173395813476, 0.16864817379222763, 0.08195464589422749, 0.05995271562208092, 0.1187093688114997, 0.09321515012772814, 0.12037370248787826, 0.02606165617884648, 0.05377756814742762, 0.052074539369993636, 0.09376759911256452, 0.0489311465512841, 0.037382727323640744, 0.02844156002655866, 0.04633600455558589, 0.06369864425411628, 0.05372581507770285, 0.04554807163414456, 0.04916437435895205, 0.04768194059931463, 0.08708261629386295, 0.1128886404236959, 0.016834293755011696, 0.06644885776744736, 0.03414204899942683, 0.02569363711612119, 0.039988268962911064, 0.06265736988655503, 0.10568833324096857, 0.04998424548595663, 0.046333526261150844, 0.007686726570565014, 0.016136425960388397, 0.005576406190577414, 0.031552170027768424, 0.09254465465463939, 0.012122070653394107, 0.031043315276263223, 0.036990091940688516, 0.03507852253894653, 0.0487063916760587, 0.053388173316395095, 0.06402282585059443, 0.02773824917723335, 0.05885735544706545, 0.01757074173750176, 0.03004778976432018, 0.036248794621637756, 0.056907803406037634, 0.029297308966277108, 0.055988390644591664, 0.021517017683494958, 0.03783167016902759, 0.039226536248480125, 0.06565627086186601, 0.06387560673418545, 0.046764772475486806, 0.0118853063923457, 0.055152355062384764, 0.035380912764418515, 0.009520143991516484, 0.046218023184807076, 0.02010519041739885, 0.08437243470501515, 0.07178066884197536, 0.04327723380899237, 0.04283613570395016, 0.02604833390984324, 0.05179579061786494, 0.06884049999737932, 0.04989459404661771, 0.04060975396104398, 0.03415812152407823, 0.09683529861391553, 0.03872691285646251, 0.03638589371656699, 0.04276120847451591, 0.05342707526119006, 0.06982392706577817, 0.051480840380874374, 0.07604648389162556, 0.024394327098683968, 0.04218003885339826, 0.05379480895616355, 0.23316011613895818, 0.17614478846230816, 0.1308010861037239, 0.1783110093205206, 0.1357740386118812, 0.21201274928546723, 0.13288179622782817, 0.1617379074976329, 0.16473108962658914, 0.09799871804012407, 0.21739981828197358, 0.10139231900534323, 0.08705308360438194, 0.15751939837730702, 0.26673073249478496, 0.16409434798744418, 0.20602540443501166, 0.14442464216582238, 0.16572796919893834, 0.17261920586949395, 0.1188000199955798, 0.12195155249848483, 0.16063958256235047, 0.13533543795347214, 0.2147251142248992, 0.15118844777105317, 0.13720443201882226, 0.1363910458260967, 0.12200078130849909, 0.2253475361653874, 0.10571335367257557, 0.17093433337586542, 0.1815731955632087, 0.10208061070091302, 0.13902379890843747, 0.12664647637716225, 0.153482559347345, 0.31199356661208216, 0.10348635905932996, 0.16830354147861082, 0.1861369651892493, 0.15225747750411112, 0.23380110190520365, 0.18447152068538053, 0.10663354018282507, 0.16304071662166428, 0.1477566496619294, 0.10237864188609586, 0.11369442702421259, 0.15073285528248356, 0.22286001803173175, 0.13571690377448836, 0.12710406835521423, 0.21246279529746503, 0.2117756757164194, 0.12666882316191352, 0.18785309407018846, 0.08756060919333851, 0.12945641793550985, 0.17415744913441522, 0.2181874792422018, 0.10113138179745405, 0.176062970271995, 0.1327508871233271, 0.19099555609207, 0.3269204833815175, 0.12435596541411455, 0.17824420645352335, 0.1392011176193914, 0.15089422404285402, 0.0829579835877784, 0.15680347389030844, 0.14184122514580527, 0.17778176513891067, 0.24283634288416756, 0.25934919955268987, 0.07888343004930405, 0.1867482114222742, 0.18653180690542345, 0.08916430701051029, 0.15854276927007785, 0.294016087728162, 0.12307758683398848, 0.0883320520722097, 0.1909926909232332, 0.17668226042822485, 0.280989283515561, 0.2037185604774183, 0.3409440905576752, 0.20782385712429402, 0.2333915819444003, 0.1144373637714213, 0.14241280334611095, 0.2850600295970517, 0.2042718904633676, 0.2950869867157552, 0.3316210763108346, 0.38493148021159634, 0.280025790054952, 0.12448731118873244, 0.16140672768796646, 0.13564185780142585, 0.18462090783061522, 0.18268671968290884, 0.1824856369245437, 0.13622926337824715, 0.2342512092042354, 0.1961046883896474, 0.18766475901488336, 0.15779085397239656, 0.16284580853196884, 0.11739714446687892, 0.20627732478803207, 0.21280146744703093, 0.14778989787784316, 0.1667069376356179, 0.1754036137173253, 0.1252951662266447, 0.12771086361739906, 0.21121355104109935, 0.19104841615884535, 0.1726901762547993, 0.17641239829601782, 0.16416233062984484, 0.1366315667908038, 0.14502816623257053, 0.09781082731581504, 0.17211297496912942, 0.15504141037742938, 0.12010154209189838, 0.15478276377243383, 0.11492903134034527, 0.12787975536118593, 0.1910604130957396, 0.2062035964861993, 0.1962727987237515, 0.2200182455201303, 0.12237514549445723, 0.13034861925388538, 0.1529707513268917, 0.13508079032744133, 0.10606954625296978, 0.1507850105483686, 0.09646875618566429, 0.16366518553226225, 0.1496509859158147, 0.12332612107838355, 0.17461872599538297, 0.14750719611202517, 0.16067375008377338, 0.10840782279809637, 0.20544918374188487, 0.18359508545648667, 0.09685109534691419, 0.2073103943539243, 0.20047419343984899, 0.13982842105530924, 0.13778403882057438, 0.12423471667833867, 0.10352207407835992, 0.1795716223216826, 0.17802974780000028, 0.17720117774461547, 0.17653265877837138, 0.1371355913579464, 0.1908641873348144, 0.21901136083949, 0.24278945830320162, 0.11627071176565464, 0.18941609729682246, 0.12532356510599776, 0.2773327764964873, 0.2247333021894578, 0.13487051451398482, 0.10627696455846872, 0.17395032960320675], [0.01641025642804321, 0.06926103630253384, 0.11880437137498973, 0.0272640522434226, 0.02418152894073677, 0.04724713973701001, 0.043894045670787175, 0.03859164088123268, 0.056083845199957016, 0.038432168188474836, 0.011455678538749776, 0.015175452929050212, 0.04023886781426207, 0.010665877320383106, 0.05091781172180369, 0.044202311790638396, 0.05169988407062427, 0.02597699197189462, 0.0035546889064848545, 0.04062832776276816, 0.05763808055029762, 0.024799520577934962, 0.027526607812051813, 0.03730684248430114, 0.019683118105956146, 0.02098294906318188, 0.002308409889191089, 0.04141150710863933, 0.05097170600727682, 0.1337152079588944, 0.007888805243231716, 0.03649998719113008, 0.03496224571379923, 0.0498736530332075, 0.05487368674948812, 0.0455528405314732, 0.037706345845494545, 0.016686685848981142, 0.0790664024891392, 0.04979786395485844, 0.02337617901033692, 0.042774411999890884, 0.02844347716158917, 0.00813195819876367, 0.04772211808050352, 0.06940671558221502, 0.027345648268237713, 0.04007074215839948, 0.07153966524187597, 0.04964654243761494, 0.00685672584598163, 0.08685431443154813, 0.054640409146105094, 0.02693475317961026, 0.012547829762972411, 0.04096533750153838, 0.04532217528791197, 0.05308523916849687, 0.009226846272095798, 0.03853544833198671, 0.03563075701916411, 0.04939492468932464, 0.020076898790355173, 0.07293341666339867, 0.09850928499814003, 0.07381397344532513, 0.09689640944763538, 0.03711293796978651, 0.07796491361072949, 0.027249814499349847, 0.03346170163563183, 0.11009183727324971, 0.0881503053730534, 0.07823810822540715, 0.06583929692785587, 0.2506020076332554, 0.04795576723652983, 0.04119166285700856, 0.025459702592343095, 0.033005538411558635, 0.028337538692980047, 0.07169220100847945, 0.10537514117576423, 0.1046078964587181, 0.007584416007082309, 0.08811642896504172, 0.04627010567233928, 0.07234200444673339, 0.11879755319246363, 0.18335119370491276, 0.08404395152484218, 0.03652266339368878, 0.12481747210145959, 0.09816306688251997, 0.11539865089880845, 0.0784311930258428, 0.11796912869378445, 0.2006563538264844, 0.1459260825668612, 0.0907838322041977, 0.039305879974797855, 0.0052030982483448765, 0.05530598633471997, 0.09585799258803168, 0.06307337478163742, 0.02902759047555587, 0.03798586834642676, 0.02991730966905673, 0.025458850319527333, 0.03520011984472794, 0.14539164430912466, 0.027436914237877055, 0.07865202553089588, 0.02061233104717347, 0.04051226161180004, 0.043738518330839374, 0.07450688465107834, 0.09545426425193587, 0.023724747100664724, 0.010209554175455725, 0.004604305253334103, 0.01275692484341562, 0.055212289951140844, 0.015303345562349406, 0.05584301013920096, 0.028574999136429642, 0.032673504413856615, 0.015094744608617358, 0.0067178537363126395, 0.033738297680693294, 0.019761868114132556, 0.04129521496173355, 0.04838639675008674, 0.06600756814042408, 0.0634611684889082, 0.014741845248687654, 0.10804609140200962, 0.017507911036391894, 0.05896799386509004, 0.019316535458088886, 0.04189645991690698, 0.04178072701418593, 0.04745979808391102, 0.018825980631874937, 0.042260091211045944, 0.04101360104076805, 0.02356011672095666, 0.030319599675074704, 0.0027204713466832597, 0.03049393255834378, 0.01603545557196823, 0.01344334441162045, 0.019051721845302853, 0.07540185920773976, 0.018159179617801023, 0.08613013917760504, 0.06130224078773491, 0.0317742704083362, 0.0064515826412506645, 0.03173516736546111, 0.04195960088362617, 0.062706368870192, 0.08141374951528926, 0.05140615829957589, 0.042785688814136295, 0.007838928610116484, 0.03280489998418958, 0.05743494467629541, 0.019014189282672542, 0.03068647152113338, 0.010241878297810834, 0.01971811874799671, 0.05549237552669741, 0.02352708684010131, 0.05094083649436793, 0.036622867694184665, 0.05358583932261794, 0.07317322516633619, 0.094986199851959, 0.0516901892279425, 0.04050111503250176, 0.05968479552276193, 0.037602422188126275, 0.039107394254496025, 0.05975164435503464, 0.019406280743198532, 0.02561051657633676, 0.07628106767491949, 0.019992426105384386, 0.013424076342714891, 0.03895408856952864, 0.006147512289199738, 0.06192383303817722, 0.032463266904796326, 0.03284507746537847, 0.014267927936969266, 0.06690882461806459, 0.048326825753094695, 0.05091010487728542, 0.047648083343501055, 0.033524333153881376, 0.04638665062826007, 0.037974415331958764, 0.022628369943929777, 0.07314610565381666, 0.0520597500426154, 0.03791710812478297, 0.019303504302496874, 0.014700205497173293, 0.05118198565117294, 0.03912153623757824, 0.030142254151043393, 0.02307012496936706, 0.039295047491548524, 0.03305501236970867, 0.01653379576671268, 0.01798644019741445, 0.024554460542276505, 0.03796889566846433, 0.06453954449464237, 0.019233774979628863, 0.03243812006868182, 0.00928310489642524, 0.04798611197921057, 0.02729382816581957, 0.0688868483167983, 0.05485738822889905, 0.06318035512982358, 0.034725742880254984, 0.03748465149152664, 0.0874565514705835, 0.031634442125176715, 0.028550068720153747, 0.03803216687013065, 0.06599833678093649, 0.0236077482376488, 0.027494849637150768, 0.09806156789343204, 0.034356097795910416, 0.05407403651324492, 0.09415095717075372, 0.047177973488766345, 0.008544485054669843, 0.06573797413899053, 0.020107714677109353, 0.060253830311158975, 0.017431158602478045, 0.0628397217951715, 0.07391804648983864, 0.09607183837121534, 0.18361025399738745, 0.2738332562148571, 0.05383781330179303, 0.02818620185397806, 0.041639150135339274, 0.021357121727158947, 0.061005580899936546, 0.029758227681140267, 0.07389052861159848, 0.05120473463208445, 0.05165394943868441, 0.0985303064507823, 0.0659925757997459, 0.05886220861406577, 0.1732562999090841, 0.2089026468175073, 0.06448593366170122, 0.06333074201979945, 0.11333894690558796, 0.32276445639229595, 0.225450191947241, 0.023250827873726527, 0.1460682991291246, 0.2069537804251717, 0.05486279297920485, 0.07075375096211511, 0.048794376874162305, 0.05646413124556984, 0.011736061930986903, 0.06751031089093416, 0.05953106082855694, 0.025597537131679636, 0.037568407884288224, 0.03604789189393482, 0.012525610340338562, 0.057273951299007864, 0.07885352963761938, 0.011247819732694377, 0.03397962686816051, 0.011410618204653505, 0.053468145234810735, 0.11071275919675828, 0.053503427414163474, 0.01802331583964969, 0.01846485061480874, 0.07551474226338249, 0.016122732138741883, 0.031103158234468395, 0.02675680436133858, 0.04197265119141629, 0.009403782896697521, 0.01555821248104856, 0.02764017268594715, 0.014432187721643959, 0.036299356424640265, 0.05669832432402238, 0.061228282659524874, 0.03604031528436369, 0.06113878060733119, 0.14031286441510724, 0.08314980434313898, 0.034353033444213296, 0.06451807105012479, 0.0759866600856185, 0.029810687466975183, 0.03754102790187444, 0.04728730189644041, 0.020134426247809204, 0.012900856485019528, 0.041454304610529256, 0.08088658143195414, 0.0445504144825522, 0.043336348983669476, 0.030958480614748214, 0.010243634554377247, 0.021997251390149037, 0.015181137301448374, 0.035580961304085876, 0.031746277555582986, 0.007653072806856325, 0.018307808335990678, 0.040002031732470765, 0.04385819275593085, 0.044030964735054204, 0.01138943587354715, 0.015885686340381303, 0.02248945522062, 0.06648025971146361, 0.12219736713074869, 0.038132275409636, 0.01618275129716964, 0.052094668330204104, 0.03926871321915139, 0.01013460492099365, 0.02357890119686002, 0.021764695824634646, 0.048657622518799, 0.011055831395600353, 0.025176811219763853, 0.07994507469477193, 0.020492781111369693, 0.018036163134139874, 0.12174888393811642, 0.19908208910736347, 0.29563758942869406, 0.11471763703851931, 0.18050456419587138, 0.13164879303545723, 0.11813242799572407, 0.1539375083220582, 0.11342343874275686, 0.14568671073404052, 0.06736616378710156, 0.18121644373862975, 0.10250800349298986, 0.12177012755625671, 0.18217126508393597, 0.08452643369955402, 0.11316740449758307, 0.14204908012142106, 0.10729457447004896, 0.14503788022745043, 0.17954738329975836, 0.10376935193855917, 0.1254093209882417, 0.12802358070809033, 0.12164210660323022, 0.14281365119161146, 0.10643072606575106, 0.1514607767063764, 0.2167831021811693, 0.17447499257902946, 0.15207473489065326, 0.29649943834350956, 0.13518655642626748, 0.15240596066559517, 0.12382443829049027, 0.14071555087162604, 0.14860769673701257, 0.10518327445512819, 0.20733575186421796, 0.11187491457789175, 0.19118752240413622, 0.10686799373117187, 0.14412465745643263, 0.14518916727073733, 0.2003055008789224, 0.15533286086734266, 0.12775165013848774, 0.12857313388057295, 0.19964003094261695, 0.14361284943597932, 0.13698885487692972, 0.24807759470516638, 0.1542701130552638, 0.22728091225989405, 0.10814454902203814, 0.15521080773924628, 0.09219704225899712, 0.18637495806380627, 0.18389249611045086, 0.21847949663717903, 0.1341119189296038, 0.23760158748876667, 0.12932075908587826, 0.10637580522245939, 0.21403675358141624, 0.11917603127057515, 0.24562985185653935, 0.2133608035623066, 0.2282976641529991, 0.21882164682592117, 0.20739196739610166, 0.3533460121721991, 0.23808282860104116, 0.2823925114447071, 0.2811834408390907, 0.4561294242739678, 0.1579639438780085, 0.16613949631010333, 0.11858332436531784, 0.17431857274664989, 0.18515180676214157, 0.0987938100532178, 0.20196884630187867, 0.2371106936686462, 0.2209192108843596, 0.2001362260911734, 0.2292407949965808, 0.1651066718923469, 0.3493774009327735, 0.36081086483693897, 0.20290917326365748, 0.1452992694272149, 0.21889739759987403, 0.28204832346208636, 0.32701541699709435, 0.3566604762548401, 0.3734933584928513, 0.3687053089660983, 0.4704742367950178, 0.3041869468025623, 0.18177847648339887, 0.19205810472128854, 0.12122717806168141, 0.26006723844235946, 0.257650813268077, 0.1022144079568886, 0.1908926091968052, 0.12105680010732144, 0.14938982654242747, 0.15629002644169718, 0.2339289313362491, 0.13183412502609915, 0.11240007551086527, 0.16502598751216166, 0.17068317911076933, 0.1438536155488222, 0.2179826120094907, 0.18508362493688063, 0.1898622056168895, 0.21717422071003148, 0.09856213740403615, 0.07256164951550384, 0.1386422718003873, 0.1262013256670006, 0.07781218632214493, 0.09011288473923361, 0.1373109642055727, 0.18824576009665767, 0.1254295610312012, 0.15324240610484155, 0.10622413513521034, 0.12695160153652393, 0.14816672120603824, 0.27557074362712525, 0.1631404612694056, 0.09671211167569123, 0.2045012418661387, 0.11061172752130417, 0.13007242923542378, 0.1324851618659112, 0.200840414111172, 0.147001670012551, 0.17129640185063885, 0.16177158472278427, 0.15482261566625488, 0.1423708830148943, 0.22020690233236362, 0.13572557588979123, 0.1515593875439898, 0.14063045382499695, 0.11292319864996019, 0.12988695934895547, 0.16841819419735865, 0.20932476126378585, 0.08432174266706552, 0.19605933598453001, 0.1544026769096813, 0.11199319855340066, 0.0933530229714609, 0.11385205727551254, 0.11046617081569088, 0.2547392501465736, 0.32931349690883394, 0.15319777382237298, 0.15599586400053195, 0.21146331102617327, 0.1907037225581946, 0.22418493645325785, 0.16840967529964063, 0.14174194015081854, 0.10504036075285367, 0.13790292034466423, 0.20489331034402694, 0.1487972881765135, 0.16616788752857717, 0.11073215654300106], [0.09375541831456846, 0.04151891263562345, 0.02490685524178609, 0.06740311986856884, 0.06635848237501998, 0.03442799514760414, 0.02814132825381333, 0.06278602669255869, 0.06356238402546414, 0.034694578423495256, 0.11200927107805207, 0.03111462274025525, 0.04680970736268548, 0.06885301787406206, 0.08425244235343511, 0.052495883897908276, 0.0046583225916800725, 0.04340648816357698, 0.03503171456677299, 0.037384768947958946, 0.07314432066895309, 0.09751059745828952, 0.04743206570105207, 0.019213720712991014, 0.042037898899927255, 0.022795382857082352, 0.02671181776320502, 0.07768922921029792, 0.06925625591388634, 0.04355211381710345, 0.022160717316212195, 0.027421992760331883, 0.07846257964810056, 0.03209619587587734, 0.02119703616406168, 0.0636497869967453, 0.040243330276421005, 0.03473578246250268, 0.05957725593039106, 0.0991748621867549, 0.055325046602276065, 0.06384093742517215, 0.018559916380552516, 0.057685244753355944, 0.04644355563927562, 0.08631903347709487, 0.02143928848747765, 0.040145075669692415, 0.05151605744275355, 0.03108493491796957, 0.05077090287100404, 0.01562958123207453, 0.05434256948290333, 0.08204126745582589, 0.019482246021770185, 0.008237929226109579, 0.016501593260815548, 0.03394908294261944, 0.05719441988114869, 0.05378109598231893, 0.04862424789837772, 0.05303177772270096, 0.021849662636316592, 0.051024087269099495, 0.07682651461612794, 0.1374590490013361, 0.03991639459385507, 0.16787436370167041, 0.10242539623211469, 0.01809460032100399, 0.07956565432851354, 0.2060503789013432, 0.09174902637999865, 0.2155773563971443, 0.1413755815836691, 0.15963309624743077, 0.030904661022847703, 0.013568459976194127, 0.11882318649441005, 0.09511966002924789, 0.09486803078963872, 0.07758507955699198, 0.07955846842378378, 0.15760880083807055, 0.2261924085718009, 0.1911864652028007, 0.2619849403779353, 0.580744227815059, 0.7048634031126577, 0.3523935197341827, 0.1506635243253362, 0.03536914565390156, 0.010633296558573362, 0.034698144562782786, 0.06300712349794566, 0.08129950282314131, 0.23438507540812417, 0.22032091153725503, 0.1865356833103203, 0.024489706960476698, 0.06247586833553449, 0.10342725537597172, 0.1442740752451843, 0.14620927462895073, 0.029402104048659245, 0.02841744740914193, 0.045580369901032224, 0.15097719136505358, 0.018332786632761843, 0.029387021692649975, 0.03709839379054405, 0.04792415844877401, 0.015120426748668956, 0.04603585896773204, 0.09463746130706803, 0.046424227240946025, 0.02000207689801051, 0.044065630213627895, 0.020074311328390916, 0.06741471843974245, 0.04009533358076888, 0.03745027329592455, 0.03610592688463869, 0.01971214517740713, 0.04015532975655891, 0.047899750887506434, 0.025903995284029556, 0.03914235084648094, 0.06700481543497694, 0.02234829777491189, 0.017543413466022863, 0.028532010112558643, 0.043395693984723864, 0.021187144053739407, 0.03545606215935081, 0.08438897454330037, 0.06351273003665191, 0.026631248296208443, 0.08197684712227314, 0.022909596990493518, 0.02168247160772162, 0.03986458023709636, 0.05285057111553127, 0.04860200453549624, 0.01313205511729804, 0.07858755157118844, 0.05435333301823947, 0.039981355019394434, 0.046407852111564535, 0.04247232820958861, 0.03420201836213951, 0.06524528767312728, 0.014408203423954548, 0.021176430314118345, 0.008185670538354785, 0.01706563890160572, 0.02495762963418759, 0.03855210308346056, 0.017900634519455415, 0.026153862521412875, 0.037610259267591664, 0.06853368178370499, 0.06105639934239369, 0.032250252327010516, 0.04206232561339294, 0.026545214707091935, 0.04110737020269998, 0.057633759814404675, 0.039399790862995776, 0.05570622130988106, 0.04038340179249644, 0.05855789167746421, 0.004383948201599021, 0.019826660000328577, 0.04718903962883258, 0.016426198717747486, 0.07171580417742653, 0.0727493487178318, 0.06370319098594689, 0.04043604352421338, 0.02437751338396582, 0.056512548002384366, 0.04889513275796368, 0.04324542583837625, 0.01859953078711706, 0.01262941238124885, 0.06286290744619985, 0.03160942935444896, 0.053156975641726494, 0.031314466351402864, 0.012839669042507247, 0.05579400349468474, 0.038949515024620684, 0.022018573532301574, 0.021946886854787028, 0.09203793345800332, 0.030417258648442167, 0.04260424471971008, 0.050365630867740804, 0.04219973114349189, 0.10176168063715582, 0.025671535479505698, 0.03699212207368786, 0.015631551993259742, 0.08206605040017637, 0.01355806224784183, 0.032999593569266225, 0.07643029394169008, 0.0298597113484697, 0.03462001125538542, 0.006758240455265849, 0.05879198899492622, 0.01593070645486155, 0.013087376869554001, 0.042929203895431374, 0.052697299904520475, 0.08208057542722072, 0.029093073756103555, 0.06377206995121895, 0.07753519957224209, 0.020736902689320907, 0.01722366943384611, 0.024437063313539953, 0.06584072185139503, 0.05569913116614184, 0.06076802469549641, 0.008371071476909903, 0.0693726170087053, 0.09379519359959711, 0.03473636085888551, 0.010123012095479476, 0.034480211700523095, 0.005277650094696231, 0.05591961893162901, 0.07134128677388353, 0.06165518898576979, 0.07577436946092114, 0.03988014714371774, 0.02185027933709564, 0.016806706928858356, 0.13919906450375436, 0.0423507692082034, 0.031067360860986576, 0.16754493057247133, 0.19056653153271447, 0.02059334930362961, 0.02443486655641708, 0.1142500859174517, 0.08219836910645809, 0.2366944168123507, 0.06819667204493476, 0.2686208552650867, 0.04998570871389201, 0.0637679790417033, 0.06627299462354953, 0.06162669434542618, 0.03269911090272569, 0.05990853533148766, 0.061416633036588474, 0.2195830922573805, 0.17325904250385302, 0.2215113968498284, 0.15543208457529545, 0.25545627780018315, 0.5114372951849815, 0.2131405379623175, 0.11556215704448762, 0.053847649870740796, 0.10092391752667966, 0.07093708346327467, 0.09207747891665467, 0.14341670028384657, 0.08773184516617367, 0.19165609242214313, 0.19522060760326926, 0.016360376443293308, 0.1150049200101245, 0.12196863625919628, 0.11885068905089172, 0.04578997538755498, 0.03369185743072341, 0.07151073776185513, 0.10007254103378904, 0.010642375658085991, 0.0493664798446961, 0.031104027744262453, 0.09894446890440681, 0.011855683687533583, 0.03981727430777204, 0.07909162210360651, 0.0306614012938113, 0.04319620468924123, 0.05964246916494543, 0.06533360994991756, 0.05941731209355978, 0.08028279689531173, 0.02665957631242852, 0.027768883118105513, 0.015757186582402116, 0.024248268605480273, 0.01790140826825894, 0.026801120632538394, 0.04164216852176093, 0.13693152085667656, 0.03688711440190673, 0.03461237335878034, 0.02310173184190306, 0.07124392465958673, 0.03773502434693998, 0.03374962046021416, 0.04057835967790696, 0.06654164633683621, 0.09089456255277319, 0.024576673261641015, 0.025612473930983294, 0.05239088005656677, 0.022909198624772892, 0.03033597863489582, 0.050954449876782396, 0.07606454058400086, 0.03756707489129998, 0.026630487953943592, 0.018311979684738383, 0.014746516469805954, 0.01591709690288671, 0.08897299953405896, 0.1547106902205175, 0.04023002332917625, 0.017681106279093414, 0.050315915591894626, 0.055515733547508724, 0.0451715930455154, 0.02250811712245547, 0.054567703571651256, 0.0542508227930915, 0.0215752269592016, 0.018698917288753777, 0.03775490815901468, 0.04431357073988165, 0.05769587805374496, 0.026351068874881155, 0.04194934679675968, 0.021848130460468032, 0.05178474362999682, 0.08330615522760539, 0.023216648860984755, 0.053500512449611584, 0.017784794364424966, 0.037803481963853684, 0.012129917308958548, 0.07711267909936367, 0.01828534280761115, 0.29548222679764996, 0.16599173327126812, 0.18186669916875903, 0.1682210338091658, 0.2061000213988366, 0.104613856622769, 0.13114309839663968, 0.10171521740454821, 0.09723361070838668, 0.14733804389834404, 0.21333022133236934, 0.16057017499641066, 0.14779961187272303, 0.18343576981175333, 0.216645022493697, 0.15553202840589708, 0.10149302892386915, 0.07333353672537112, 0.07385280644220692, 0.1553910682278295, 0.13976930971107177, 0.16275081362935806, 0.06656016268196606, 0.14147762449518328, 0.22264451749863165, 0.11452763957241852, 0.12608355497040097, 0.12151215510863451, 0.16104124246105073, 0.15064760501826965, 0.10036216823444252, 0.11636825008017403, 0.12944984490111952, 0.09659002024319865, 0.21685175898094333, 0.12980063656164756, 0.1491861237633613, 0.3023980395688165, 0.15470641544990002, 0.18780784891738048, 0.14153131193691684, 0.18664667412879007, 0.14480984649590908, 0.14221771139531367, 0.10830302963093405, 0.199651139217519, 0.1507293312780319, 0.0848523581460599, 0.13914465693937195, 0.1727526737076621, 0.13794015221778425, 0.1721523978537129, 0.17098822000045932, 0.16346436324379138, 0.12174532929014777, 0.1010436570692447, 0.24561935645197672, 0.16058676846085057, 0.25420459738421824, 0.16182387788449565, 0.16965934856524392, 0.14843164973201292, 0.19336344193547003, 0.10336649694269705, 0.2866177927822836, 0.23429130624619224, 0.13121756214287975, 0.34123839089466684, 0.24339345734446283, 0.1259882229891035, 0.2653639397073177, 0.46384748431944084, 0.17291453276430407, 0.5208652021904145, 0.20017065408249057, 0.35695440886962804, 0.14774570992637068, 0.1933611436716972, 0.18006273064642184, 0.2824216534293467, 0.16329188620851887, 0.22344635108545904, 0.1906497593248083, 0.4395431917040579, 0.4260803302449565, 0.40889005266851, 0.20877314731478694, 0.67522787398869, 0.833457941489835, 0.5226688183123066, 0.3986458943015145, 0.27139534993517783, 0.09263731298908111, 0.19206830901243996, 0.1631867942670661, 0.27814109118715413, 0.31064895973090206, 0.3452970940739878, 0.4705713767438166, 0.18031452842537435, 0.1686462738941754, 0.24903276845091776, 0.21378800483240237, 0.2685280360521809, 0.21461787723725845, 0.11940041076271765, 0.2390310309466816, 0.24764308495627296, 0.14723999996579465, 0.13969786435125336, 0.3005879270213266, 0.11964331426086927, 0.15110511272664995, 0.16686838300478074, 0.1744814583611104, 0.14003209319085846, 0.10712204380862175, 0.11505312226232021, 0.1424974867052609, 0.19715284988764795, 0.3923990907928636, 0.10173266888746332, 0.14314403426983666, 0.1479074004436693, 0.13614856367630346, 0.17189050303591838, 0.2357599121187964, 0.22462010503776614, 0.16829336783097637, 0.09386442496531433, 0.14677374353331907, 0.08764215159199892, 0.1398272719234228, 0.14963600123601575, 0.115475780631025, 0.18696331358965368, 0.19401613352519853, 0.15016771222074188, 0.2517863182771591, 0.10934496283411019, 0.15831429120754043, 0.15246919356286526, 0.1615299605914662, 0.20014491352823474, 0.11341256795511132, 0.16075680933652386, 0.18673060672177424, 0.12743420628530364, 0.09875822526913497, 0.2134251089826707, 0.23382630619791248, 0.16874992559033056, 0.20346650222857154, 0.09388546173971507, 0.1439473081019617, 0.1492290093653625, 0.0665512224358897, 0.13587090276902722, 0.09761582729556868, 0.15931539958523167, 0.08683552229476553, 0.15035785524354828, 0.10921448273884674, 0.09390703477566281, 0.13241082069373902, 0.15674106836799653, 0.10314457659279147, 0.145179407310582, 0.19756525033904662, 0.10347121350106694, 0.12725383854441105, 0.121984371705161, 0.09234840591107646, 0.051164645251006856, 0.14208571444596016, 0.09918784737707147], [0.03223147168154678, 0.054488827158967336, 0.053147920482461496, 0.04367779054108166, 0.028615574983339158, 0.02983676893035731, 0.06678460346114251, 0.03173851900012984, 0.05096950350449451, 0.03732687185308145, 0.05204996326938272, 0.011739747771512599, 0.025712802720766877, 0.03111798012058341, 0.05098857143292985, 0.015346766468287717, 0.00819396152491531, 0.04904072393753356, 0.025303796038872776, 0.02748122859385706, 0.02495295649784948, 0.013608229515563338, 0.033650304821710435, 0.02575003650910672, 0.040409831825884125, 0.030863278868397882, 0.034862079717699564, 0.0582340739727501, 0.006777360094636078, 0.030095928814262155, 0.03793917145700224, 0.012403325470645103, 0.05046033465694036, 0.0586842617110139, 0.021396253498331196, 0.05427133862770373, 0.014074558726391725, 0.05400559038765008, 0.05529391278903331, 0.021787312655379216, 0.013040047957591954, 0.08976402362027476, 0.03650454924471917, 0.017186705691499576, 0.05749405985097251, 0.02984115861416344, 0.004975089893466043, 0.03881974356068719, 0.03557751007798699, 0.058857171585963625, 0.05773684843593548, 0.01618180134814353, 0.06899059194350435, 0.02463813266536642, 0.032899764651853236, 0.00916029717172346, 0.1143995803149958, 0.014623193550975093, 0.06515400829694926, 0.07322499738825906, 0.058270198848819545, 0.06270538827764892, 0.003103642431538432, 0.027835538513177348, 0.1329961118678893, 0.11550721321855822, 0.06280559640858444, 0.15469572086247707, 0.12904389491004328, 0.07587501809241311, 0.40754351524576066, 0.4424884014071957, 0.18763794593753355, 0.1020716934374744, 0.3338654687808406, 0.17002271938948862, 0.6927783967506501, 1.3425016715641946, 3.37375438501758, 4.318877670072741, 3.731597609096958, 3.6866193000347387, 3.3362834924651734, 9.475921719304978, 20.289397162775842, 23.367708575341013, 30.84148095500085, 26.64813776170054, 34.386120996167584, 24.35594777907095, 12.132953905290174, 6.111892605981519, 0.9666868827996716, 0.14191109236449967, 0.21700407258204876, 0.029256899743491126, 0.20907052732523412, 0.3323609333845877, 0.45079579757105925, 0.2829875472572542, 0.11042038940133587, 0.0184171827089402, 0.048931426173376466, 0.05398238941486325, 0.08055560846602725, 0.036963868751040393, 0.05114576884455258, 0.03746906160226753, 0.041558082711191914, 0.05035477540185375, 0.030298901894580454, 0.015428201614638731, 0.07830907094983325, 0.04095817457944636, 0.04833945471252646, 0.07651222704519188, 0.029722336461887728, 0.020813570853563088, 0.03143098066380668, 0.07825306992256835, 0.10478222742676736, 0.04181284525041138, 0.041032408499309135, 0.020872592182469465, 0.04250122121565285, 0.009383505506951724, 0.016232045224657463, 0.01942679083215133, 0.013567817419947637, 0.03315705528122283, 0.019589189980779926, 0.0972502424772228, 0.02358685510473386, 0.01597804494292265, 0.030301956670178525, 0.03750636625374037, 0.042909913801497994, 0.033141963349114505, 0.011212354649849718, 0.036910637131621765, 0.05412482814262471, 0.02167657273070466, 0.02601978755856474, 0.03649931303375671, 0.018607950093404903, 0.05191232791290649, 0.05974831953344326, 0.10590862948447467, 0.03644412789013117, 0.034204262999757644, 0.013262080347856448, 0.025983666512934912, 0.056567905515792875, 0.08608644152240408, 0.028724437992599224, 0.03881400556213433, 0.017443802883668293, 0.030213814424050432, 0.040982206757631034, 0.021390442721425526, 0.032121882803978465, 0.06988914413077217, 0.013603391670321506, 0.021221121968401056, 0.04137702166072784, 0.018017748295659983, 0.06433715172592672, 0.04855997312153059, 0.030955056201726682, 0.0757751661923624, 0.046273997398994626, 0.05463307002379049, 0.024011511047701203, 0.04238082283747293, 0.08895250668208446, 0.032994748063145146, 0.010841323903972104, 0.10441694904359118, 0.04669366036391547, 0.00476237504758061, 0.02835743782681323, 0.05552273942157627, 0.0239898192681252, 0.025555463582878152, 0.029269838968532223, 0.03585562680757815, 0.021494247635165532, 0.016037806504285865, 0.03076330247905947, 0.02560617860346552, 0.013486867781818635, 0.0913971392137389, 0.036302271389192155, 0.03747000005997477, 0.028655560942546978, 0.018120597514714447, 0.04195208556108898, 0.01458644814368698, 0.021469501079991463, 0.09156498907794876, 0.06677381694316864, 0.02206002463466458, 0.050113603262411016, 0.053111887536942966, 0.038201686806015434, 0.04094490593659782, 0.017635985615573103, 0.021175773393723275, 0.03801586068866234, 0.08689775927773408, 0.06403800588281405, 0.0540002430939386, 0.07203226743806755, 0.018496627941907897, 0.05789998302897138, 0.04502879425642952, 0.012222768122991248, 0.05561396517159958, 0.06386602680469233, 0.04264387061759349, 0.01682606405548511, 0.013629307467190009, 0.051684160115978414, 0.03114171927013705, 0.0525941806394727, 0.03469212694213756, 0.022150419179290053, 0.04956429523806419, 0.046787678504422794, 0.02792832899778601, 0.06074329537730064, 0.03702730083117082, 0.05228168188383984, 0.036550579637649565, 0.062203826683182875, 0.06194987236672352, 0.022470128737510215, 0.06483061960147274, 0.08574168663471939, 0.04454654573853459, 0.0877092072680112, 0.05568470190008802, 0.13213380330031918, 0.1299259072590259, 0.03489191501191066, 0.08336414042259417, 0.021038367863624327, 0.2626583010198609, 0.1317973374839752, 0.1743566626382451, 0.3016190507238911, 0.31502899082918323, 0.3418287995361513, 0.7838255563570607, 2.748534217957528, 4.306514359289601, 2.8899231601145963, 2.6112054192250778, 2.7318278628010906, 8.706172262468646, 19.146612651886482, 24.083782357554284, 30.025198459625248, 25.710577541782012, 35.079188116135136, 26.158841694554976, 11.217041246352657, 4.119029968015609, 0.679532430104671, 0.24180915687353383, 0.1661615749640811, 0.015925426193843448, 0.2015465326727398, 0.18812451902176106, 0.4342700246601336, 0.20600432169533547, 0.1506226458736966, 0.03873064753509337, 0.18002425771086447, 0.1737485880092267, 0.06369876682818418, 0.04125331761315465, 0.03100511621713879, 0.1793121636634873, 0.08100255948281096, 0.029773488152591936, 0.08135788638385073, 0.03096736914988968, 0.06371400431699811, 0.04651046575858228, 0.03616590390823061, 0.036653250741261634, 0.058404199118095065, 0.03599017099927991, 0.01843562627571725, 0.07912912210750003, 0.07408411136918491, 0.0758944154386559, 0.024959634869329395, 0.02677193842828274, 0.05603319529684321, 0.04126185566307076, 0.05413193743856204, 0.053835438429227764, 0.02401103798840796, 0.06269581600903504, 0.07902387694846238, 0.05985699293594207, 0.02886869617918086, 0.04698298495983885, 0.03132486599497497, 0.024661132540073127, 0.035847751423716545, 0.022167305672361005, 0.00924583376129909, 0.03229968798076434, 0.03523766581389693, 0.02744727557705295, 0.05932832715071498, 0.14567829908863192, 0.04521815203911355, 0.040990446033256675, 0.02230555772961628, 0.035767718218266964, 0.017798068752932935, 0.008830751044555538, 0.004532602296451167, 0.07150535982462668, 0.10089414734994212, 0.04558435355823848, 0.01618653768673539, 0.01781015953559789, 0.08092755181414467, 0.028104215124321562, 0.03815701621915064, 0.011699815438459478, 0.033229209272371184, 0.03518460656426126, 0.07403885089461842, 0.041061634753620437, 0.011806460623178753, 0.08620715399663295, 0.02931517413667133, 0.03033090138717765, 0.035441525640987584, 0.06724922812633938, 0.033656724638515906, 0.13672700602441065, 0.025945383184138807, 0.031232809039553812, 0.014258111477829518, 0.04519546434523598, 0.18509965149625657, 0.12985979387116048, 0.14148205248338563, 0.13869756802676186, 0.12494383830456965, 0.13800528501310658, 0.16108317811402584, 0.20339179333419571, 0.14201146520433888, 0.10057008449709225, 0.10116323573334564, 0.10963694958557045, 0.11937570442715961, 0.11230255251810436, 0.18533966684293363, 0.10203422407709783, 0.11624427407138771, 0.09482145264384248, 0.057085895865795114, 0.0831172149628401, 0.1235114913734217, 0.13535160240867447, 0.1678395526663911, 0.19550603664209767, 0.10856396683882322, 0.08112314172209271, 0.24741431578032433, 0.12483355994786947, 0.08959811961939258, 0.1428134060434757, 0.15054652737754007, 0.04317146771016621, 0.1006492903275836, 0.17788422173790394, 0.1540600670681846, 0.11359658993540273, 0.1286689101928665, 0.10665902792806588, 0.33317415103796993, 0.1303473322261726, 0.07649859068013969, 0.17446750023913, 0.1814093293562051, 0.17253124365402808, 0.11750882476448052, 0.16815582440505106, 0.09820542388385343, 0.17165871547354808, 0.11924663393367683, 0.21326842868039686, 0.13719323181336926, 0.09473011198063051, 0.141279376262138, 0.14264862053096294, 0.2172411614728551, 0.09157608969197159, 0.17984156106268206, 0.16440157988859763, 0.260953602170752, 0.24420482106506827, 0.1271786240320052, 0.19809884590006646, 0.14158616383229533, 0.21822829640680746, 0.1886411840396543, 0.3003175899146065, 0.29606794698103783, 0.14318431517289532, 0.20224390251021232, 0.25152780956798987, 0.5505631215149357, 0.514167816408219, 0.26803099820690773, 0.28816535167636415, 0.365117565999108, 0.2964427784806298, 1.2749003570887352, 3.0817589307985003, 6.520413342983493, 8.709369974751628, 7.1461451342028965, 5.401726893840298, 6.046661628830818, 15.106066369241285, 32.24529527848767, 35.8423166121206, 45.67532600895051, 41.704589090039654, 51.50707852455878, 40.80182813828991, 21.335916903711137, 10.970828187081123, 1.248540558641957, 0.2959035138689703, 0.26030687074507436, 0.14926605737738072, 0.3008726359375062, 0.38108841546120187, 0.6843755766749383, 0.4723195893870246, 0.41762489525060503, 0.1783906518211288, 0.15759749338030815, 0.3031033001119091, 0.23026477875969104, 0.22204062570967983, 0.08204118318615422, 0.3796055450314476, 0.281595136489599, 0.13676477415907767, 0.15238117006036545, 0.10746214854260606, 0.20818051701832205, 0.2651055229286994, 0.206496196107999, 0.10770782527904357, 0.13224035080882812, 0.20366622135043147, 0.17359590668591762, 0.2464971246738588, 0.1916827369601496, 0.16164807602763176, 0.08608178370782445, 0.28165173506544483, 0.17477966574651582, 0.11338662821799518, 0.1085695669415497, 0.10613469437005059, 0.10583484755648721, 0.18258643877362052, 0.0975096092048672, 0.17870407371271044, 0.08970966968204706, 0.1334773529801638, 0.14564901920816592, 0.17666597339895465, 0.0901766692198092, 0.17321142247847973, 0.14029218004115168, 0.11527282861812461, 0.1619597972040215, 0.12543235725212482, 0.20504491914424205, 0.20076262554334057, 0.1676571930968954, 0.16171978185734442, 0.14431907524985654, 0.13408703639382316, 0.08949812216263625, 0.14026314530882145, 0.16487874541311495, 0.15743174259701084, 0.2129672948391207, 0.1987515681333119, 0.12705752085293495, 0.10023108292971888, 0.14323882998958712, 0.09185707542083918, 0.12017171574576248, 0.12796897396084764, 0.14861298274369011, 0.18103132625260662, 0.18504751155213003, 0.11149423016655831, 0.12457446901187783, 0.17685257709555088, 0.1467832736670971, 0.20696812159111425, 0.1410734365063329, 0.14357811500949247, 0.07199436140757415, 0.16514759630926196, 0.14706761486107303, 0.1344873326560182, 0.13330398728289913, 0.12687407343858673], [0.0031713681950819713, 0.03134740430170731, 0.057594011342453386, 0.018383243098674763, 0.07667548038185605, 0.030932433625322678, 0.08451402307518067, 0.03390351603288324, 0.0657977979449976, 0.021304667686983463, 0.050291071360510205, 0.04478802814358666, 0.02766125925606297, 0.011657772533174966, 0.0197626993195304, 0.025039624024723327, 0.025124598497284517, 0.08584944456214867, 0.03122797119431198, 0.018095578998327255, 0.025938681830021165, 0.062034149699273615, 0.035006525595822645, 0.08111156613355683, 0.04179294228613858, 0.08845710826496925, 0.03786484560658855, 0.023905381057111007, 0.03301814055791305, 0.01752767418961852, 0.056866836854286736, 0.03870256658222887, 0.04181552272770674, 0.015260658185598592, 0.053545546928240415, 0.08256463574305659, 0.009798335414680262, 0.048865638372878877, 0.04559429354905602, 0.03844318836326561, 0.019789010609289812, 0.0770075182099977, 0.03937579698920731, 0.02133515990158964, 0.033163758550560286, 0.033024702100984515, 0.08766776191130762, 0.013529783069726922, 0.019848970395903436, 0.01419819382605173, 0.019580858774603378, 0.016698993051484708, 0.007955341415870334, 0.022934920026830608, 0.027681621873090347, 0.09062387304560793, 0.08126106819198017, 0.056821787053899425, 0.04293313009604331, 0.04610991285693261, 0.03850867738947272, 0.017873599276607557, 0.0364577182899079, 0.06541000423772682, 0.4942700921768143, 0.4787845747365106, 0.33192031025405855, 0.23573768024723377, 0.0365448952652514, 2.3890288895176304, 6.212683300818167, 28.49875907744131, 44.824830639746885, 54.399732389757716, 54.962498372600926, 57.61300079284176, 90.01674805918049, 103.10079436148368, 120.94778260877057, 124.0945746821742, 123.07798262565368, 117.6552587939847, 114.80737486193257, 137.34445879536293, 141.80841415159165, 144.00461196899414, 149.14945940817557, 140.95743240848665, 130.2693973049041, 135.390741902013, 133.82271951244724, 109.81654320993732, 77.35339164733887, 77.19131931181877, 81.94236078569966, 63.33117715774044, 62.58821356681086, 59.89472981422179, 35.52423984773698, 16.606503378960394, 6.526225314986322, 0.6042397767305374, 0.16819471102808753, 0.2624136125368457, 0.43757508118306443, 0.030066465072694327, 0.0729078446484862, 0.04369938272922751, 0.028382356751770265, 0.067352106073691, 0.14833823297052615, 0.010660828800962098, 0.05363131813224285, 0.008593316456573385, 0.013280115015203915, 0.02823277042367526, 0.07138209627760995, 0.03490716782248309, 0.045831397761620825, 0.04126332655188538, 0.04594306656790357, 0.020597321469517007, 0.06949419516228861, 0.04916886746462795, 0.0378466165444303, 0.027843231951156934, 0.03742393136264817, 0.025707210278919628, 0.052564759032740715, 0.022869976838269544, 0.024816236616442763, 0.038159356617759314, 0.015597290626066107, 0.029285480568726218, 0.11342520840586194, 0.05229220793191945, 0.004862613822033088, 0.07791828183877854, 0.0316946815338827, 0.10879086676023661, 0.01991699517313992, 0.044582789358232296, 0.029743834804262848, 0.017105211173334432, 0.02449532046974186, 0.0406522641799623, 0.10350826917396438, 0.0276212464837778, 0.06412336339933739, 0.05204344386114709, 0.0739224591562825, 0.06832964192595213, 0.06252197916769693, 0.028297349720472292, 0.0327773591233117, 0.04516074141006797, 0.043030564988692926, 0.09009608443105414, 0.045227839220916076, 0.042927568297713034, 0.03406511845007058, 0.11669687881705262, 0.03513004195185439, 0.10745526141216678, 0.03273617040606276, 0.042800688815693703, 0.05938603655405103, 0.03781824447815457, 0.0364230681330927, 0.07052069169379051, 0.022439209428886255, 0.05453584963575967, 0.04035039489427882, 0.011529317782861332, 0.036944011752043045, 0.018211377018521872, 0.023694078685835968, 0.025941121820059997, 0.06382704825110494, 0.02670613913646629, 0.06199514433260887, 0.0785033738300685, 0.0555728568935827, 0.040634437313964294, 0.05271381292972834, 0.06628891393061608, 0.05489286193023286, 0.07064850580307745, 0.031729115270859296, 0.021205495689965544, 0.08184569286963633, 0.026152383971719012, 0.03295262471862859, 0.06405517391319718, 0.05123160899646821, 0.030800926972240694, 0.0467862842244006, 0.07133773978679411, 0.031386737170959675, 0.04758416862797834, 0.015869012436709337, 0.03821281040267598, 0.04869751654745591, 0.011341726790452677, 0.026896351107185888, 0.0022009959831202947, 0.009286741898845761, 0.020042306090134288, 0.02700426991307928, 0.005535273493507938, 0.04952852659287953, 0.057814702121240485, 0.014187219616536413, 0.037071435156488614, 0.03277864232058487, 0.05815487963357761, 0.02451362039503311, 0.0034819110324831623, 0.013509762319435757, 0.05278531574614106, 0.02226186965051438, 0.04592953362472115, 0.05624512202977654, 0.041836643771779154, 0.05482986268977966, 0.030019921400854667, 0.04616817001313452, 0.014326791260241261, 0.029440584645095854, 0.11158582363878528, 0.060231586948277495, 0.04060632571758282, 0.10283005919547812, 0.04642506610722311, 0.020806007650530627, 0.006100928397744053, 0.09699547227712409, 0.03381027164117944, 0.06167701483073254, 0.011866669388367765, 0.4136412074008296, 0.07485553126541838, 0.5189670814621834, 0.22615923696467954, 0.12267965778347947, 1.6980965195163604, 4.958892772274633, 27.706710946175363, 44.74146458410448, 54.78521900792276, 57.5076537747537, 65.50115785291119, 101.76377604084631, 116.21439964540544, 141.29073973624938, 137.7921267478697, 143.0694247830299, 133.29489400309902, 133.97882984530543, 160.93324784309635, 165.7834468349334, 162.30270416505877, 176.04679907521896, 168.67635173182336, 159.4837751696187, 163.3806028673726, 163.9500996374315, 131.70162723910425, 85.38794332934965, 90.56096907584899, 95.93296097170924, 69.61042896393808, 68.30310298550513, 65.26153241434406, 36.40694964316584, 15.041463951910696, 5.4045921852511745, 0.32543099395209746, 0.1877131604499394, 0.21327101805758095, 0.2374475731724693, 0.055984709592115496, 0.08923245819225427, 0.06200144540578608, 0.0497990743737788, 0.03387510949265092, 0.1138772692291006, 0.08026538371679284, 0.06832122261966429, 0.061854509741909085, 0.07703518164494345, 0.07767602951536257, 0.06137948160270049, 0.0349338008691707, 0.061293576333311305, 0.051305674376987645, 0.04239344413602545, 0.03884791261366299, 0.012037124909130077, 0.011040830436433035, 0.06684461112825141, 0.030957067182527918, 0.013490619697427798, 0.0637726521780414, 0.023966051390274398, 0.030865446897223595, 0.0029210671604115277, 0.008043412798865428, 0.018017361421258222, 0.01716281140914127, 0.06237163824299651, 0.06718208818065544, 0.028126190356429548, 0.0761230007535027, 0.025850510855595914, 0.08421547861108858, 0.047474556767772284, 0.052266716356239015, 0.05237573832874337, 0.02484433289106575, 0.02413867781269214, 0.0711180487527482, 0.06981778304062544, 0.03734884325474982, 0.07016918757149289, 0.0486056128096196, 0.03822535126199646, 0.031664851985331026, 0.0011483973996233075, 0.04596316488459707, 0.014709333434791095, 0.057037594022169236, 0.006201054174227701, 0.07469534994133058, 0.023797810821223165, 0.06362843995673523, 0.028117763389262463, 0.05285132571213669, 0.07470950724617129, 0.024127898955597513, 0.013688201433978977, 0.01850551456182955, 0.025124418466622313, 0.010944716087842902, 0.03375408675281271, 0.06350329566386438, 0.020881578393821276, 0.04174272522270199, 0.029658243630922614, 0.03320625344772012, 0.07452622071028718, 0.01361013611688489, 0.13876185812536748, 0.15529302429528008, 0.18263347657217135, 0.15221609343444148, 0.1527284377164418, 0.19560697638700086, 0.11985886075924482, 0.0995850103396562, 0.18121892586350444, 0.11855873294294843, 0.14349579120114928, 0.2135986585410372, 0.15842017988043447, 0.12074122550867258, 0.1453384624854211, 0.12909762831705232, 0.14618860557675362, 0.2273374801922229, 0.1231663994070503, 0.15342018446855007, 0.19293074015407793, 0.18041304733243682, 0.11227151829629176, 0.2737114482348965, 0.10919435760907589, 0.28700478975811317, 0.13859037700439655, 0.13927391129395655, 0.14954692053218044, 0.1852759283276335, 0.17411289346073905, 0.12580317445099354, 0.10489907115697862, 0.108897460234021, 0.17306583512934948, 0.15130089415657907, 0.09506719066731392, 0.09184580626747302, 0.13702993251142964, 0.15590215612563396, 0.06434527225792408, 0.09452850828247686, 0.17445136642744466, 0.1335464541109339, 0.09204554071109142, 0.10929401798714554, 0.2650803033142321, 0.0652684158675613, 0.12852629526488243, 0.176509614853609, 0.11266001680445288, 0.08624486084426604, 0.0648583902887279, 0.22097151936782947, 0.20539209486976748, 0.23471476900721752, 0.296461716174118, 0.1377177722151241, 0.17957559065713039, 0.10165113414968215, 0.19242575031615075, 0.16786429730634536, 0.29730300328904585, 0.25555521039472473, 0.7531043887138368, 0.6280072562156186, 0.5968089077261187, 0.29165641434731027, 0.13976691951674802, 4.136404596990155, 11.186798791731558, 44.10467563136932, 65.04741807137766, 78.74045941137499, 80.5023096453759, 87.98748631631175, 126.63713347527289, 142.6447262302522, 166.97366652950166, 165.70514063681327, 169.5217166408416, 163.45759114911482, 159.16631421735212, 190.17553729395715, 188.2767806514617, 188.0971988554924, 196.49450702051965, 190.4466672097483, 182.8757083031439, 190.0677191826605, 191.58079701085245, 161.2632917588757, 119.27417001416607, 120.68310891428303, 131.1820622413389, 93.84465971300679, 99.46755778404975, 92.38315320784046, 55.31284839876237, 26.87241888815357, 11.919091574607357, 1.3330483917267093, 0.24455689975330908, 0.24538715520212728, 0.7026981934905053, 0.20640492439270022, 0.2259720970065363, 0.16317009355031675, 0.3874817256244921, 0.16255566039152686, 0.24731987246101905, 0.19914622598838425, 0.14016029034410754, 0.13350511600653972, 0.14908043427332757, 0.19873771726364092, 0.11671315052456434, 0.1599087193608284, 0.1696600227226173, 0.1634836226942078, 0.1442048668621048, 0.25651928608215624, 0.21287035407318225, 0.12434835816102645, 0.1098019342809435, 0.14304427430033684, 0.09683427971697624, 0.0946839705049511, 0.09334697853773834, 0.13518762894936148, 0.09854693821961842, 0.13540663816515477, 0.09895886369650403, 0.14593933588795124, 0.24110728243906654, 0.09105829086395041, 0.09168252994817111, 0.24032040288852108, 0.10759271290754119, 0.23904422298073771, 0.17489321529865268, 0.16103751927373872, 0.16514611009868885, 0.16010468465185937, 0.0816788312588488, 0.22548961483182448, 0.28098716911289, 0.08863462615878352, 0.1696089246580678, 0.13761474871106688, 0.1963856587967565, 0.13430544806103553, 0.16638640644809893, 0.11905961654960148, 0.07703656060320717, 0.15752468438398454, 0.1316810759805864, 0.15035575616263575, 0.17028505853827924, 0.13133144877370329, 0.1332369545895246, 0.19597368735459544, 0.13794833403681556, 0.39263906017426525, 0.15518860651120064, 0.15128002592152165, 0.2252854983652792, 0.08267215618322935, 0.09765119757503272, 0.14033209322200668, 0.1042301768076516, 0.1298785170600299, 0.10086666011521894, 0.09637756107915794, 0.30822067551555177, 0.20809833110580522], [0.051140632225020285, 0.07730127462456304, 0.046071600799839345, 0.03842687452091806, 0.09785080944458324, 0.05294220289215446, 0.07530357012705458, 0.019688013407792297, 0.03703192800223347, 0.032376944117488406, 0.05209227430544073, 0.031163673434827118, 0.04947079803734537, 0.05843560872299056, 0.026674495874753883, 0.03397499586665823, 0.05112311562463161, 0.010184555768876547, 0.06938813028917198, 0.030486685366580085, 0.05432617137088411, 0.050399361719046874, 0.026759033677198237, 0.04520751107784529, 0.07287991308276692, 0.050584869909911394, 0.04198498520699721, 0.01699710084545997, 0.012854393252411918, 0.05166462104346964, 0.07120783425747387, 0.01787200006806562, 0.03507855701290312, 0.03412465114266642, 0.028615678405208934, 0.05727749445565766, 0.12507664730712292, 0.06445728963421238, 0.055950155196290825, 0.03225334732222461, 0.023471043678000573, 0.09640442778266246, 0.04747407413237999, 0.03454573137024718, 0.03801231753201254, 0.06312576370433935, 0.006060931904827275, 0.04479321838927366, 0.056395708102612734, 0.0680974713196197, 0.035354589983340234, 0.028813675744459036, 0.027306347957722125, 0.03326793884738319, 0.04773152947065331, 0.06453385246136496, 0.06137322649479874, 0.05739845590846193, 0.1366262348188508, 0.2100288879967505, 0.026104421121999625, 0.21670319921066686, 1.4242909343973285, 3.8911868391498445, 12.361614358040596, 14.025690690163644, 14.819574490670236, 43.143102661255874, 65.22417968319309, 90.12748441388531, 100.85026387245425, 111.93754134639617, 126.30058626974784, 113.72585973431988, 125.28909329445132, 116.3277796776064, 112.85547794834261, 113.36769242440502, 108.87770821971279, 96.3532978488553, 113.05498538478729, 110.90205915512578, 103.73177036162346, 99.20600629621937, 95.74140025723366, 106.47527217864992, 92.97033986737652, 105.77544289250528, 106.50097939275928, 98.24995994567873, 80.25296457352178, 108.67803604372087, 113.11313060022171, 108.71347073585757, 125.60121982328354, 128.08486461639404, 128.56083639206426, 117.29749941056775, 126.10382449242377, 125.56405144353067, 124.51892022163638, 76.02731673948227, 57.98538669463127, 34.78994077251804, 12.041896081739857, 1.269957067505006, 0.6018941993674924, 0.22350386896681404, 0.3398217104615704, 0.06473861244176665, 0.07694216324917733, 0.059075525796581665, 0.10915119621542194, 0.08384630850125706, 0.03874061050854864, 0.059242031176484404, 0.02261056989100912, 0.08313626756951695, 0.04128046393875153, 0.010580589709382866, 0.05679102479329994, 0.05007116199140588, 0.05570000833681515, 0.023684809021952174, 0.05665253524878814, 0.0335212764630635, 0.03639004591311659, 0.03479698522677345, 0.05102667664628356, 0.06247512139980832, 0.0242987078344149, 0.03616901805564281, 0.029767640986509865, 0.030084935452548728, 0.0330959482779426, 0.03469111570607751, 0.007651287821992751, 0.021628914400935177, 0.04066288215859283, 0.039488810279797164, 0.03987191552897135, 0.03423795937710712, 0.048722644231372306, 0.04093417304477865, 0.035874924562390775, 0.08895057614051527, 0.014253453663249892, 0.016727037615172805, 0.03913568205110008, 0.09689899882481945, 0.006353006756398828, 0.03601181298314083, 0.09183813006647172, 0.01572268102468262, 0.06324366463588611, 0.015323470692120254, 0.036086341846854456, 0.05544962782052256, 0.1234508018880602, 0.07397030900803304, 0.051827154257484985, 0.04037033616294784, 0.04347640900842605, 0.029049253526834712, 0.04509322225086151, 0.003287506406195462, 0.02650797708831247, 0.013724854910716176, 0.011648057580685184, 0.030521883276261152, 0.013184900819924811, 0.05210281950571845, 0.039808786053571014, 0.04032932747636111, 0.035140108347179434, 0.050912020097096125, 0.04983034991328755, 0.06147258809857792, 0.017972152657626618, 0.09899922120835512, 0.05601841746078384, 0.007908444864780553, 0.06294387144847743, 0.027068665348774484, 0.07572053646248195, 0.13892829838779666, 0.0504046285735263, 0.03741542778668865, 0.03733959274306413, 0.0569207732745957, 0.012110427074554947, 0.033030470743054346, 0.030741331077391104, 0.05659592518162343, 0.0471577947328408, 0.07273185126964124, 0.019720495535781788, 0.02322281203833559, 0.0316170078792399, 0.031665811510456186, 0.04411664017806611, 0.044936905840351704, 0.07976531216333951, 0.014777118809551243, 0.03663957607181322, 0.08189162750157618, 0.031977622702177015, 0.028313870406559402, 0.04767880729970433, 0.041117264228242065, 0.0336155244299481, 0.08381407152140334, 0.05500289130835764, 0.09317812509834768, 0.05393245580395865, 0.020939609554085522, 0.04553444292997161, 0.090993786260726, 0.06564874021757035, 0.03278906877723432, 0.04885546855568405, 0.04439630440526432, 0.013381091149283514, 0.03337991791927526, 0.05216148651895985, 0.0031632699275148976, 0.03575401290530159, 0.030008646501829068, 0.006422714054239013, 0.028155271054035234, 0.09494879177861637, 0.04003822938689301, 0.04762752537405299, 0.13847676616522575, 0.0896724301480478, 0.14225607707856164, 0.1250998061450739, 0.14864883565854642, 0.534415275098816, 2.956706415260992, 11.206381224816846, 11.637137878325678, 15.585392752001363, 43.47492733309346, 69.48617612161945, 100.58683749168151, 120.80782459628199, 133.2111749341411, 147.89679558046404, 135.50362771557224, 145.19186635171215, 130.28256862394272, 127.39051095900999, 127.30060238992016, 125.01634736214916, 120.13931151359313, 129.7298360640003, 132.22303575085056, 124.7532347709902, 119.2335185697002, 115.61129600771012, 132.46754061791205, 115.0395477971723, 119.91607373760594, 122.28853502581198, 117.92229375531598, 103.64099887109573, 129.48172261638027, 140.2690407537645, 134.88124170610982, 148.14197509519516, 151.6508960723877, 152.5615135315926, 142.92641516654723, 148.67766103436873, 144.70803414621662, 141.33554889309792, 86.35681583035378, 62.368109764591345, 38.03611786134782, 11.95888598119059, 1.1217124351570684, 0.4371047338410732, 0.1580759459325383, 0.32908915572108766, 0.06326352546532309, 0.13714279258443465, 0.03497787007701493, 0.03291957951601475, 0.10719241664534616, 0.08295472005322095, 0.02362719154916704, 0.06396610853112032, 0.040148274086776285, 0.05616253775153911, 0.02303075954137791, 0.04685202222918311, 0.02868140491867258, 0.04086225654088682, 0.05163435674002094, 0.02043465419011491, 0.005969855541949191, 0.021304340184395833, 0.021910009297331976, 0.054313787559588114, 0.02623434005785854, 0.0064760682477255265, 0.061799742116202275, 0.02532912673608911, 0.026899227767341563, 0.05299108313216318, 0.01246016153374747, 0.03159886883241275, 0.03380566745275452, 0.031040199213631214, 0.009224841036953995, 0.01105456543530548, 0.04711079906912581, 0.03643812559124443, 0.015618636708466277, 0.043682877364898884, 0.04386471216416648, 0.01095002411954826, 0.01880566206490321, 0.059127857262689265, 0.05798598788979073, 0.04281987165731769, 0.053480789516000986, 0.01966395824696989, 0.021799332574911175, 0.017602913599881916, 0.05817034311832921, 0.017524081237253644, 0.01316573617288903, 0.020233044746301828, 0.05929427071204109, 0.02494684120099391, 0.018641912686308066, 0.036821181044703534, 0.058691187145849394, 0.05996270157817391, 0.03912955717814546, 0.022180961189611305, 0.027399561705908952, 0.027634748783443245, 0.0319716778598846, 0.02975539315582043, 0.06307598714145922, 0.01769223945185302, 0.05008943701883958, 0.055915891913877386, 0.06365825992918785, 0.14173581144742428, 0.16919031889448244, 0.09407827074849799, 0.16653959338943805, 0.1406407500466993, 0.12773405309886704, 0.13767926863604976, 0.16393510895150323, 0.2436248465411125, 0.13007765395506737, 0.1912879258874924, 0.1484357099980116, 0.09610386084645026, 0.1558497403898547, 0.0833655959896503, 0.13398333873239257, 0.11241687581904473, 0.10729494985313186, 0.15392652262122403, 0.29006212408984866, 0.13982131175937193, 0.18322915589857489, 0.18548959024971534, 0.1661875606664727, 0.19490078121664065, 0.1944577832135462, 0.1793741095330446, 0.14552387108485546, 0.08104760545275866, 0.185598527952548, 0.1013794257455776, 0.12014008397536895, 0.12544969382185128, 0.12165924399009637, 0.13742108168380876, 0.17765752099935087, 0.15310815685699064, 0.2543922736039085, 0.1556921561038302, 0.14566155240660714, 0.09486475959420206, 0.17362055939532098, 0.13323122425185097, 0.10902804758159385, 0.21844692257863862, 0.20417370863499182, 0.12891097865518064, 0.24326360544129727, 0.15936294300181253, 0.1546606493573035, 0.16222589018364109, 0.13022227603341305, 0.17005835779972617, 0.12337806183964976, 0.18387717435196524, 0.20484159940913801, 0.17939476326348322, 0.35060023047751, 0.6081177750902792, 0.3471758787430102, 0.22677069770232325, 1.3981829030859856, 3.9655785118379905, 8.577762688359908, 23.148601055145267, 25.00718870470601, 26.928416605918642, 62.77820141084733, 94.56978828676286, 128.45865864907543, 142.11553573608398, 151.96347759615992, 159.97440092025266, 147.53221911768762, 158.40443303508144, 148.3453421438894, 139.35015493823636, 141.1112520771642, 135.3101921081543, 126.8709381165043, 140.61110281175183, 138.60796405423073, 131.75749747983872, 125.42578005021619, 121.92503329246276, 133.36046034289944, 119.78061076133483, 129.99774963625018, 132.64726361920756, 125.56453781743204, 110.72865116980769, 141.868379346786, 152.32202929835168, 141.04124561432872, 155.52564867081182, 166.07167828467587, 164.08049491143998, 151.09508052948985, 168.40839109113142, 167.85127332133632, 168.8356940977035, 113.41116797539496, 83.68900791291269, 57.895835061227125, 21.11621710561937, 3.1806460503608953, 0.8798070576402449, 0.2607060331971415, 0.8628263204328476, 0.16914184085063397, 0.32998241424079866, 0.21939799009311586, 0.19691133300863928, 0.37214783230616205, 0.16719894994410778, 0.18407807324922856, 0.13390650011358723, 0.12605948448782006, 0.10246397641998145, 0.10930351747740662, 0.16030978171094773, 0.09125699108887105, 0.14811315633837255, 0.24877436699405794, 0.11757072466876238, 0.0999709501141502, 0.1853064799140538, 0.13345847657370952, 0.1174752088263631, 0.11092555543948567, 0.14543676688786478, 0.12311099592836634, 0.12003560490425556, 0.12991679081272695, 0.1147841411312261, 0.08573858397862605, 0.10117895585755188, 0.13610587725716253, 0.14546471377534254, 0.0942400302137098, 0.11359259095643798, 0.08313366287057439, 0.10940519266671712, 0.12387676209571863, 0.17806719417773909, 0.19201334986475208, 0.1451092183349594, 0.09717610048791094, 0.16556827051024284, 0.1497950564108549, 0.17300919058822817, 0.15326724267534672, 0.17741286315985266, 0.08173371379774425, 0.10069753854505478, 0.14358995872880184, 0.10378063641368382, 0.1341902897242577, 0.18257516195937512, 0.19708024007418465, 0.1934101120118172, 0.2031459863628111, 0.14493669533441145, 0.09370601330433162, 0.2054497966122243, 0.10820167619855174, 0.23920494822725175, 0.17175367973264188, 0.18714890605018986, 0.15662293761007248, 0.13114357337115273, 0.12469957116991283, 0.09920858537718173, 0.11056891852809538, 0.15409032754119367, 0.10987759312434543], [0.03245246123462435, 0.010786001822130095, 0.044629501569415295, 0.026876969082701593, 0.06328931581529398, 0.016468007966215094, 0.06586270091394264, 0.042338243670641415, 0.110433834244407, 0.06332569733081807, 0.024482626392836535, 0.03000288743585829, 0.1288459684339262, 0.04731075184780264, 0.05556250704572566, 0.053282905174719716, 0.03888344760203073, 0.06190400285225722, 0.06631118410657491, 0.007342148840712805, 0.04709346632983896, 0.0411574493703102, 0.05028026569033823, 0.06358633193397714, 0.03772042654154282, 0.061792755394332835, 0.05583036585801071, 0.047469967901105845, 0.05565798075328912, 0.08112376991419062, 0.04997358537249027, 0.04081701521851844, 0.08500788165556808, 0.023843841214153557, 0.04404350559437468, 0.01718111516487214, 0.06599954719985686, 0.10706703103477917, 0.04596314190195934, 0.03414984394405638, 0.05178450614274029, 0.03980172272290915, 0.0436474074940047, 0.03351202978181743, 0.027950708341274052, 0.02630776383974139, 0.03217790298344147, 0.01807649766335324, 0.036957973704463055, 0.0536649915269546, 0.04709609784185887, 0.05807763115773278, 0.023707866353253206, 0.10801685748681908, 0.045730584421225136, 0.15757023597196226, 0.1147110486823705, 0.748028596562724, 10.4454041488709, 20.617960383815152, 37.734369923991544, 74.35748530972388, 84.55471423364456, 100.0819892268027, 105.47672302492204, 100.12125999696794, 110.83931692184942, 97.67910603554019, 96.05526831842239, 97.19681139915221, 95.61630018295781, 102.06106032094648, 95.08190078120079, 92.12420617380451, 95.74561288279872, 107.25309387330087, 92.67782518940588, 93.18845502791866, 104.36168732181673, 67.50593616116431, 93.31031522443219, 87.99464071950605, 62.81527173134589, 77.98363024188627, 83.04454680412047, 69.6681897870956, 54.46777766750705, 74.65462053975752, 61.66416983450613, 58.664956938835886, 51.94639967333887, 59.39600436918197, 64.49985519532235, 60.374533745550345, 89.34359089020761, 73.7427479220975, 89.19323859676238, 102.32021916297175, 94.83788228804066, 103.67745337947723, 99.79720946281188, 111.38054909244661, 118.07302259629773, 123.83575316398375, 108.51315529115739, 81.44881679165749, 59.783157994670255, 39.23158568720664, 12.310062646865847, 1.2713653209709352, 0.1844330171063062, 0.05701080775789677, 0.031868200448732224, 0.15704983244499854, 0.08012560331412862, 0.06896737947939865, 0.13210011075340933, 0.03595744755359427, 0.01486570634428532, 0.05975736703182902, 0.0753087105770265, 0.03229409170847747, 0.033073785354293166, 0.04088079969909403, 0.04549458337527129, 0.040611887515913096, 0.05677314430114724, 0.03374154589349224, 0.044931727085983565, 0.032184364935082775, 0.03325505324849679, 0.06527881168069379, 0.03786076235795214, 0.020261196562299327, 0.052489847125064944, 0.028459323690302914, 0.019509016964284163, 0.024597644918568196, 0.013292451903614546, 0.07985620849555539, 0.0317738413990986, 0.037786811890621344, 0.02145731070589635, 0.08148970713298168, 0.02368119308694957, 0.053037082881576596, 0.018408449306603403, 0.0506990208410688, 0.027519668970677643, 0.011182255055304739, 0.0344631394311305, 0.008763175386364662, 0.03578598941526106, 0.06426952914485047, 0.03938612002398699, 0.030682828773053426, 0.04584269372806434, 0.047400181121643514, 0.03803965154915087, 0.021142967593585773, 0.04206299594032668, 0.049714785549909844, 0.05181309654407444, 0.06672228986938154, 0.07714375928645173, 0.06738066583150817, 0.051492032925448114, 0.008553062366592068, 0.03518430395953117, 0.06448185807394405, 0.013696972183102082, 0.01754611775639557, 0.029941581249717745, 0.04687224695038411, 0.042979011101828474, 0.014743889745835577, 0.0267060874255314, 0.01775033956003045, 0.0823305958821889, 0.02468343144432912, 0.018848894321690166, 0.04941155645816077, 0.044068533686860915, 0.021183920738797997, 0.06478177383542061, 0.02426784406716545, 0.06827668226774662, 0.037308520216855316, 0.2326570108773247, 0.06393410520808351, 0.06357320501739461, 0.018398331200343468, 0.09080518307464738, 0.030678806811450954, 0.0203752153432898, 0.04354354129323075, 0.05152792414470066, 0.025016198971218644, 0.015130286300254446, 0.03372565722994266, 0.012309063139611916, 0.038676741758301374, 0.032513690811972466, 0.06198406287078416, 0.031899717305937124, 0.12451757166174152, 0.01999326305644166, 0.05259988799450859, 0.029931384619445573, 0.02619173407794968, 0.0339919570533018, 0.01748295572225846, 0.0398699926482814, 0.04964325592041977, 0.0206995137681764, 0.025787645680529457, 0.024892659632549174, 0.0601015818275271, 0.03419515421433795, 0.008296725516688199, 0.032964361185628566, 0.05278072687947462, 0.038632438893640236, 0.012054924004440828, 0.06609107172417064, 0.04457428578227278, 0.022580188759151968, 0.04258360631102997, 0.029089844695502715, 0.03494250362799053, 0.10438711757981971, 0.028808077556952357, 0.07972141532527824, 0.5736929094118457, 5.485002244672468, 15.01538803500514, 32.781710778513265, 70.71296015093404, 88.42112787308233, 110.1762245547387, 116.49708486372425, 118.76828624356179, 121.18936923242386, 120.21712349307154, 113.89495311244842, 117.39580969656669, 106.54436080686509, 120.34452207626836, 115.29180326769429, 117.84068492151077, 122.61012231149982, 146.70191611013107, 130.96451974684194, 139.21878691642516, 163.79337741482644, 100.2530045663157, 141.88078972601122, 137.12532381857596, 110.17598921252836, 129.31708505076747, 135.33278496034686, 114.39389428784771, 104.91205077017509, 132.3669396677325, 124.86683445592081, 96.37074455138176, 94.95449435326361, 109.12083241247363, 100.76866288338938, 109.80520756013932, 138.54206823533582, 107.87963759514594, 113.61226789412962, 129.38468317831718, 123.05252644323535, 123.48837237204276, 121.94644158886327, 126.93079348533385, 140.96838366600775, 142.29856921780495, 128.59866373000608, 95.6397638013286, 73.08939087775447, 44.71668304935579, 12.95045723838191, 1.307293373730875, 0.2362036762098151, 0.12322056182329694, 0.04748262750405458, 0.09350088560172627, 0.07040094449034623, 0.11349944998660397, 0.08810682222247125, 0.028739242641735944, 0.04327259514661085, 0.08181653556323822, 0.05305774044245482, 0.0414021953099197, 0.085358795890164, 0.06429969768730864, 0.02392896315864017, 0.07040249198795327, 0.06789586762146604, 0.05169867365170391, 0.05424021630577984, 0.05440101816108631, 0.022994343551897237, 0.05897873441778845, 0.05003660376514158, 0.05584238577754267, 0.05498193114274933, 0.06548664367367184, 0.049215817163067485, 0.016031923906637296, 0.03702873724602884, 0.023242782035301772, 0.004198746445904216, 0.028217054129908645, 0.05085310410527934, 0.032497541678528634, 0.00527389147581773, 0.019793854200191075, 0.04389695297445982, 0.028090151665251584, 0.0312673672658181, 0.05948475464397381, 0.023536655278275573, 0.03346150628321114, 0.08618204163447504, 0.02500694079865371, 0.06444749136966083, 0.11290279006765735, 0.038419328554863894, 0.07257184614577601, 0.06445227941918759, 0.013348347593789861, 0.023924052535045533, 0.07303358265949834, 0.023530444220429467, 0.04904725483708805, 0.06644667441686315, 0.04129246087564577, 0.049017760452003255, 0.02597743055723127, 0.024919099242035902, 0.055391458764431946, 0.02594596924140088, 0.011450405938610917, 0.08168493697960531, 0.04395081278597636, 0.07547993888898243, 0.0019461508500464863, 0.14640151673266966, 0.16633751471677136, 0.15566898960499995, 0.08027265389119426, 0.20875617080638487, 0.16160572668717754, 0.09930218599977032, 0.2076138111372148, 0.1737442519515753, 0.12005936129078751, 0.22105650916214914, 0.12123001258700125, 0.3417063786858513, 0.2552763543902867, 0.1762716679443275, 0.09853330951544548, 0.13998422801734942, 0.10855662005562937, 0.15502994970208214, 0.13421209258658273, 0.14078808407629692, 0.11194883440170558, 0.09964408337949746, 0.12680036045851248, 0.09322022929066613, 0.14875659358597573, 0.095018130396643, 0.1609914467459725, 0.18783450877714544, 0.22693772019157488, 0.15961664067881723, 0.16596643704800837, 0.26147849497295195, 0.04042540256294512, 0.1430987278299947, 0.07868161950741084, 0.10145713004373735, 0.13933931988093162, 0.14115876337933925, 0.07974995976133693, 0.12870093266810143, 0.15196392793328534, 0.2227404929937855, 0.15341840714456575, 0.06833814550191164, 0.1728774694305274, 0.15166909133474674, 0.1560281929109366, 0.1736553244653248, 0.16502231029012512, 0.14092925875898332, 0.2286880932027294, 0.10803654594647308, 0.19263955013405895, 0.18774631673530226, 0.44572071022083687, 0.1627024275160605, 4.782001231947254, 25.52777155753105, 44.050393950554636, 63.819602458707756, 105.58643171864172, 120.35449274124639, 139.76827959860526, 140.71994073929326, 134.70360540574598, 147.2019241702172, 131.17929304799728, 123.28079269778345, 120.5334234237671, 118.42265482871764, 123.39999352732013, 119.05858870475524, 117.63825139691754, 123.1186576043406, 137.7124555649296, 122.98742294311525, 121.53093707176947, 134.0336802697951, 93.67820216763405, 121.92461752122449, 121.79279450447329, 89.53769330055484, 105.44539113198559, 109.2098545259045, 96.2261659868302, 81.92671052871212, 106.18230250573929, 93.5711528408912, 88.12896620842719, 77.0237321238364, 89.52318837565761, 94.68504321190619, 88.40998834179294, 123.10573731699299, 107.97340577648534, 122.06590913957166, 133.1021801117928, 125.00590601275046, 131.28919786022556, 127.02777801021453, 141.3516619897658, 153.19665508885538, 161.228539559149, 150.66909543929563, 115.18020399155156, 93.96510001151793, 60.44177493741436, 21.876966684095322, 3.0462742284421, 0.35970772886949204, 0.2324302182082207, 0.16194567054269776, 0.21840294913178493, 0.3128958649692997, 0.2325190537639203, 0.2796961577428926, 0.1997383353450606, 0.11707325015337237, 0.15860614006317433, 0.21413170251875155, 0.14177122003128453, 0.23246829277805744, 0.19693459143802045, 0.08760966946400943, 0.2876291820599187, 0.16055923526085195, 0.1381632523430932, 0.20427843285424097, 0.09254611022169552, 0.09320874563268117, 0.15720559344176324, 0.07520473712394316, 0.16154995548628992, 0.09392906746436512, 0.11735061228635812, 0.07215752281368741, 0.15762537898075196, 0.11362698064335894, 0.12993073361294885, 0.06658853857868141, 0.12241157297525676, 0.20579531758783326, 0.18485896199220614, 0.12188803614868272, 0.15466334598679699, 0.1452662663594369, 0.053028667405728376, 0.1964920377659221, 0.11949617175325272, 0.05947903962805868, 0.11660913876708477, 0.1475578651673371, 0.16641502749295006, 0.18543417144927288, 0.1793568725547483, 0.14116578074472566, 0.12900297049312823, 0.14470968816068866, 0.07091617692382106, 0.1007771120977498, 0.18191166852991428, 0.2111416307067679, 0.1717812129326405, 0.20639591519871067, 0.12767347852669417, 0.18269108638407724, 0.1639099046587944, 0.14507843692216182, 0.14356101592702253, 0.10318000815928945, 0.16272161035768448, 0.30554102253048654, 0.11817831666238847, 0.154362533902449, 0.17187196370815078], [0.02884056543060128, 0.03575876648087175, 0.007536064367741347, 0.06697773422685362, 0.06200661266883535, 0.03480184605465301, 0.028334472426063115, 0.04222103987910575, 0.05803153947776845, 0.005062159137695187, 0.032817889004945755, 0.04940293030813337, 0.05560881706074842, 0.026430014235478257, 0.07147224184366004, 0.11923904200234722, 0.057503007757928104, 0.06267200216590878, 0.06062558213729532, 0.04473455137603226, 0.031136950372808406, 0.08444544288419908, 0.05360770347197691, 0.07923479627577529, 0.025669961168821302, 0.05163194356305946, 0.030971613276990193, 0.024357286747545007, 0.04373896649227508, 0.11015528467513862, 0.0793457641116073, 0.03586463217112807, 0.03995823448583965, 0.09809794174807687, 0.08425468699105325, 0.04612512736310882, 0.08002820289543561, 0.07911997501768413, 0.05743179605492661, 0.028429317941528656, 0.025707738879587383, 0.07769356526794934, 0.024586230208496415, 0.06404383964235745, 0.044408527338096214, 0.06734390893290121, 0.025102466217152057, 0.05667069536303321, 0.05602960234447833, 0.0318993189402165, 0.06319689113766917, 0.06538105377506825, 0.07010317377505765, 0.08681999369254036, 0.17447330718559606, 3.7742600037205607, 27.98887448926126, 59.75014732730005, 90.71997411789434, 100.83244062239125, 98.43416229371103, 93.0600287837367, 96.59869701631608, 80.438735869623, 97.88360272684406, 98.9043446510069, 65.95294429409888, 75.37996876624324, 88.61672078409504, 52.08067809381793, 66.75279401963758, 36.039960922733435, 43.388862686772505, 31.157637719185125, 31.58259907076436, 28.93734870418426, 35.8435639258354, 33.976786367354855, 23.183019853407338, 35.21829105192615, 24.778136014938358, 28.524952665452037, 22.837353137231645, 16.18138611316681, 29.212004830760343, 28.534631113852228, 29.11909172611852, 26.443225299158406, 17.42979318864884, 40.38723361107611, 25.235984479227376, 25.33598726795566, 28.17190012624187, 22.26763083088783, 33.455024842293035, 51.707688147021884, 53.960430852828495, 40.90178189739105, 41.12760059295162, 61.81915444712486, 79.93990452058854, 76.52508904857021, 70.40310075206142, 102.09659699470767, 106.74382901960804, 101.98313851510326, 112.3814752024989, 121.11915096159905, 106.17653662158598, 79.76278597308745, 37.46265165267452, 12.874460335700745, 0.23301302725749634, 0.29076085756382636, 0.018646968866608316, 0.08573543535725725, 0.08067520245188668, 0.022449023015196287, 0.02609316537517213, 0.028027140933479515, 0.0606224641594435, 0.010047808116782578, 0.06688537466670237, 0.007544748453168019, 0.03213159488363853, 0.04749411116203955, 0.04772903202402015, 0.023097503036561034, 0.0867928511973831, 0.02606849925923011, 0.0372989249656037, 0.012742409392470315, 0.024302545934915546, 0.018221552581376126, 0.06272992990430325, 0.06612331636490361, 0.020844911510545402, 0.05338081121144276, 0.016226090806265994, 0.03169933934846232, 0.10081206102885547, 0.03259911727640898, 0.01608966969914975, 0.05844313553684662, 0.059465464550040426, 0.009645904985166365, 0.03773423910681759, 0.019927661032265714, 0.058944252800316586, 0.07482412166052288, 0.040220117812315305, 0.025124564023327925, 0.059466410668626915, 0.02268540710511227, 0.07686445895101755, 0.01681538670504045, 0.06347335311734388, 0.05032529633852744, 0.07715976286318994, 0.06704297427448534, 0.020648007761807214, 0.014259022164849505, 0.07366083246926147, 0.08449491684234912, 0.010201538980547941, 0.04196931104806643, 0.012665430962618802, 0.05039743883835693, 0.045314184990861726, 0.060915718786418445, 0.11778382734665949, 0.025093788356189767, 0.01543364562695065, 0.03798958387285952, 0.060659033366509026, 0.009907722236558555, 0.053715963186996604, 0.05512942605081105, 0.02956869369823366, 0.02932602385689895, 0.11985565851172132, 0.025809203394718712, 0.028322454421750964, 0.060265379086617506, 0.024792913069588043, 0.028084386853621374, 0.023445161397478754, 0.03366504818381321, 0.011557892862436994, 0.015911023740866975, 0.033628260641689264, 0.02304515816391476, 0.012794653716076528, 0.06414395584274205, 0.07742180323769009, 0.04104255150342661, 0.0350509740171894, 0.1608062832946739, 0.02138627137267782, 0.035840220779420874, 0.027506407988708348, 0.048720024210671266, 0.01579282595024955, 0.04049836094641397, 0.04551303843336721, 0.05271900700585497, 0.0347508552424129, 0.03163302103207717, 0.07440988259810595, 0.05036487627113539, 0.05551301010493791, 0.021780530862029523, 0.041694963471062725, 0.03481226485042322, 0.012092053413300986, 0.028640200879665154, 0.021841277803985343, 0.04791276672133996, 0.022158376917603518, 0.1016848803227467, 0.04115498639763363, 0.07354504594038572, 0.016330732671063275, 0.038795255560187564, 0.014698516273300254, 0.04051194751575109, 0.026994887251226653, 0.061387747691403476, 0.06981928457295702, 0.18316583107075385, 0.12573323828438598, 1.3017347623263638, 18.941894346667876, 53.83447962422525, 98.66162838474398, 115.83206269048877, 115.99479398419781, 114.16005042291458, 114.3662101991715, 96.1996978329074, 115.84972120100453, 112.79473612385412, 98.6719677525182, 106.94177535272415, 117.09670543670656, 89.76057021848618, 117.04931536028462, 84.11627954052341, 72.54615829836938, 67.89262694697227, 58.20824400071175, 53.49382961949995, 51.86338663101197, 53.587589956098995, 42.42584628443564, 48.57360063060638, 42.30973628259475, 45.20190769626249, 34.556308715574204, 32.99653114811067, 39.47101892963533, 37.417273752151, 32.49216729594816, 31.239046512111543, 26.185745231566894, 52.12249840459516, 26.889077194275398, 33.76114230002127, 33.90246137495964, 29.944348604448383, 48.226851340263124, 62.250662234521684, 75.48535500803303, 74.59112521140807, 73.75760586031022, 101.32905975464853, 113.15795544655093, 108.93665359866236, 95.6590618625764, 124.67654458938108, 123.30805317048105, 120.25287981956237, 129.32514944384175, 142.7943568075857, 127.8620190774241, 94.11491886261972, 43.71001066700105, 14.512658830611938, 0.19305466253670955, 0.20830569578514946, 0.041498469579364025, 0.11428348735095033, 0.07640931079344404, 0.05908820455172851, 0.05831745881286841, 0.04323259386564455, 0.10619095586720975, 0.024887921378737497, 0.08991580095983322, 0.03719712337178569, 0.08406134172072334, 0.05381047162377546, 0.08694081341907864, 0.02353050742268322, 0.054012297487427155, 0.06973264002872091, 0.016895734006538987, 0.009418751297128058, 0.009998847437541812, 0.027777601198683825, 0.02869599889363012, 0.0964028419806592, 0.08226932417000495, 0.04593343301225574, 0.02394742396239552, 0.02565676147388595, 0.05724393597413456, 0.06904080900694094, 0.019824380888753844, 0.027930018221659046, 0.03581675167586054, 0.03440499335767762, 0.014507400318830004, 0.002609360108767907, 0.05386803163996628, 0.021137210442834807, 0.03603943045281115, 0.003955703376108901, 0.03504162774451318, 0.023009565718952688, 0.12014611308733303, 0.026424416047971577, 0.06023059486441555, 0.031691538658173334, 0.05415044995325227, 0.16064548143936744, 0.049032768114439906, 0.016905110922732183, 0.08531152826523589, 0.044254091673440514, 0.012363722555399423, 0.0468730858166612, 0.08001222996221435, 0.07870876966344734, 0.13544422243871998, 0.026854605060972037, 0.06936023702784892, 0.06274405273518736, 0.03814973838386997, 0.04910718972584413, 0.019149980282471068, 0.04925332099740063, 0.29148839594375703, 0.16360143169520364, 0.08940249140704833, 0.1804008512126823, 0.37728334867185165, 0.09698419546287868, 0.14285164915265577, 0.16120273379548905, 0.12271165727607666, 0.13930898279913012, 0.1495379266599494, 0.1256502173360317, 0.10386948729114187, 0.07596596038990444, 0.15559351462269985, 0.17541300595527695, 0.14083581135397957, 0.3488388411220043, 0.18084328231071273, 0.28351853811933153, 0.09284326806664468, 0.2962305721256041, 0.09948813852163092, 0.17430303648354548, 0.1560754452141062, 0.12266899383957348, 0.0861686121131624, 0.15109530680121916, 0.18903153648059215, 0.2823210814066472, 0.1779557283847563, 0.17855788881499923, 0.18852771109630986, 0.20924724848760715, 0.2080577897328523, 0.14418629689082024, 0.2417925634090939, 0.08649385474141567, 0.18545657186017883, 0.16574336756621638, 0.14633543398832122, 0.2740688129298149, 0.11155040739404579, 0.18449459525365985, 0.13703469757831868, 0.19222088308343965, 0.09606503551044772, 0.16968757124437442, 0.14292781361408774, 0.18668859446000668, 0.1232933248543451, 0.28660682240320795, 0.22868335877935733, 0.4369943865364598, 0.36625729032581855, 10.721209529907474, 54.7503883607926, 97.63454791038268, 130.11324774834418, 135.82031988328504, 130.76594583449827, 115.64536571502687, 119.68007256907802, 99.77036476135255, 120.11649116393059, 121.48812832370882, 87.6825612591159, 97.78220945788969, 116.06418855728643, 76.76800143334174, 93.08908570197322, 54.19038372655069, 64.65973100354596, 45.586398032403764, 47.68716458351382, 38.00420937999603, 51.02882000707811, 44.04897405255226, 29.428578499824773, 52.01322901633478, 32.403021627856845, 40.655990492913034, 32.24853515625, 22.897651733890658, 45.66783820429156, 42.12268629381734, 40.93551035850279, 39.18204615193029, 25.081274432520715, 58.06377134015484, 33.334168772543634, 39.707992845965975, 45.41781064002745, 30.59882156310543, 44.05095877185945, 70.08516911537417, 75.20641173085859, 58.86594703120571, 59.874847319818315, 86.28251044980942, 110.10615533398045, 103.36366376569195, 98.85675845607635, 128.50639389407252, 132.87612607402187, 134.7655631649879, 145.26670517459993, 155.70833698395762, 143.41956692357218, 117.8281568711804, 63.63063443091608, 22.481041108408284, 0.7027019932866098, 0.3417966851303655, 0.11880391172223514, 0.15038659886246727, 0.17293903225612256, 0.12751532733560572, 0.12118543393068737, 0.18345268503312143, 0.2710760751318547, 0.08969575752534213, 0.17381529894567307, 0.18609971799437078, 0.19427631230604267, 0.12066685369298344, 0.19786610838867005, 0.25776640061409245, 0.11666851058121651, 0.1724728677541979, 0.1179246113245045, 0.13620179146528244, 0.10709812654362572, 0.15148659386942465, 0.15280492393480194, 0.21270527744725828, 0.17392857270615716, 0.16844653945055701, 0.09240036199410116, 0.1779787263442432, 0.18471009578675995, 0.21189824978430427, 0.1026290147415092, 0.21264857161910306, 0.23874747116238842, 0.11466951139511601, 0.11950518094724226, 0.12788666547426294, 0.1551390253007412, 0.10743587172680324, 0.1137876905681145, 0.10403394338584716, 0.21555605915284928, 0.07172410857052573, 0.226201341156998, 0.09843432329474919, 0.12312808734995705, 0.16657578338298107, 0.19092872258155577, 0.16476683528913608, 0.22651280186349348, 0.14048448343190456, 0.18534011117392973, 0.14920057218161323, 0.06341259851450883, 0.129632449618751, 0.14616695593201345, 0.14130035174950478, 0.25948761631884887, 0.11239773894269621, 0.20620494480094603, 0.20396041443511365, 0.08391501126630653, 0.09982394550236003, 0.08944441173826495, 0.2034742090730898], [0.057466430889983336, 0.03849761891028574, 0.15849462830491606, 0.049353498484819174, 0.023446369901179306, 0.04705655238320751, 0.01672540201745447, 0.0475023006419501, 0.052567823384437835, 0.017709359601740877, 0.019435083733931668, 0.0166562530061891, 0.032195668562405536, 0.057940562706320524, 0.02643450159549473, 0.04798985048828106, 0.0399981898015305, 0.08285892075828968, 0.0380449184036303, 0.01728416739722654, 0.012353712659058793, 0.0921254130380769, 0.01831104314225095, 0.05380984343167755, 0.05628113582309696, 0.06837262711938351, 0.017906531481252565, 0.09966216305451048, 0.015737159128841615, 0.07414329932221482, 0.029420317789059014, 0.014208857769957714, 0.06612242770291145, 0.03161902077526095, 0.07207647071129854, 0.06672172296431757, 0.032260533226954366, 0.04331694397654745, 0.061847212754430315, 0.028050529597807797, 0.060135967684008425, 0.057818478934707186, 0.029553421735463124, 0.03378861433556003, 0.01698064910728605, 0.0914744374852988, 0.036846178493672804, 0.03454225333107095, 0.1611652874177502, 0.07797186202820271, 0.09551428724080326, 0.022469935300309333, 2.3643253118761125, 6.400919316276428, 33.675846438254084, 67.90084823485344, 93.99869903441399, 98.34679542049285, 82.5781769906321, 80.04553394932901, 70.81954663799655, 72.98841338003837, 80.06255703587686, 79.96041851658975, 50.6026231088946, 47.67961009856194, 31.716002802695, 32.59574140271833, 32.73913933384803, 28.96523871729451, 32.25923538208008, 54.1208008796938, 59.60072855795584, 79.77889122501497, 78.83673790962466, 96.74740975902927, 111.42975130388814, 140.66617288897115, 197.92198304207096, 114.37757722793089, 133.48759220492457, 127.28509333825882, 134.60294169764367, 151.8591739285377, 150.32609201246694, 135.7924553655809, 137.38110942225305, 152.27957356360653, 174.97026535772508, 139.3195604508923, 142.6504215117424, 144.3906359518728, 100.73001969245173, 139.2082122064406, 131.7471738015452, 94.74099974478446, 74.33031112917008, 75.59973132225775, 59.03999828523206, 40.13864163429507, 32.10308386433509, 19.521344131039037, 26.831402663261663, 30.493566720716416, 55.35640631952594, 72.24564982998756, 94.607372437754, 100.84637288124331, 108.09401865928405, 105.93767212283228, 112.80119234515776, 110.39219025642642, 68.82982238646477, 15.012070690431903, 1.1254600147085807, 0.4550205886123642, 0.025680282288381172, 0.10245037069844623, 0.021897246272513465, 0.050567177109300136, 0.0662650962570502, 0.021297759489126263, 0.052020966841448704, 0.0007704375081718149, 0.04484137850663355, 0.06364690267571038, 0.038150512132673495, 0.0383652618996078, 0.014223242028345986, 0.06704187110787438, 0.02275970039678918, 0.05266827666350911, 0.005155461464798259, 0.008148504740318224, 0.01842849208192239, 0.021477430090007764, 0.03229946964570592, 0.022774677415708863, 0.05559416179875693, 0.04371105407875392, 0.022913052047032024, 0.02427208053338672, 0.0508459756571439, 0.033540991735794855, 0.01883265708813504, 0.0139222125665495, 0.03232296173190398, 0.017608421772057493, 0.10544082555439203, 0.07496042402401086, 0.06990366149693727, 0.029565003069658435, 0.040364280237906405, 0.032276824086664185, 0.03315276518884686, 0.027617615227016713, 0.09206018065132442, 0.01287474437812043, 0.06850317616256014, 0.03014623206259022, 0.01716113942224653, 0.09856838102061903, 0.042579526892833175, 0.00736903517522038, 0.04103638066519653, 0.08227532263845205, 0.025745279103096937, 0.066458816910463, 0.0106247125433818, 0.016108532699065346, 0.10712160713850491, 0.05231239434872424, 0.03559568168355092, 0.01645521812831923, 0.07841636156362873, 0.08779915365120096, 0.033365067304863084, 0.05815000348393956, 0.04782070210503955, 0.05302487910094281, 0.018993715582896146, 0.059131300827908906, 0.05900262103926751, 0.01147554702906599, 0.01517214342921732, 0.005838830087844644, 0.0330500596112782, 0.10960641332090863, 0.0850723862587925, 0.05359092231599554, 0.011118179461317918, 0.0492028626162679, 0.05105707884555863, 0.036974199446699316, 0.07082921062265674, 0.03955781564957673, 0.042157481394467816, 0.02851252658142438, 0.06427206489587985, 0.05366977191560211, 0.03173515012848281, 0.032893739370328766, 0.021269594266590093, 0.05912983376953391, 0.0401758034563353, 0.030605293014237, 0.08252711275652533, 0.05107856378139508, 0.05574362938322368, 0.0226311834018317, 0.10964474069976038, 0.01422409813160137, 0.019779806062879584, 0.026369646507044955, 0.01475365353643053, 0.11636091861873867, 0.019471704651932084, 0.07901209451618695, 0.07988044751747962, 0.0223265006582463, 0.008888012286455882, 0.03723657689988613, 0.04878450583125796, 0.02294289308690256, 0.048820799246670744, 0.0605477246215507, 0.03913518026350968, 0.08040464317966854, 0.35641744252174135, 1.967846128729082, 25.666645034666985, 67.65824179495534, 103.27988193881129, 112.92475485032605, 96.14079167765956, 89.3604806161696, 79.43445221070321, 89.6540072656447, 104.61856334440171, 99.62145590013074, 83.46980233346262, 93.13743283671718, 50.38589646739345, 55.00661326992897, 59.81873389213317, 34.52197228708575, 32.34887330762802, 34.31307077407837, 46.506040865375155, 43.09449665008053, 46.83044833521689, 43.78809721239152, 72.03719154480966, 78.23251247406006, 92.4458875963765, 71.11772521849602, 59.42968968422183, 61.922406919540904, 60.10435304334087, 56.753907588220414, 72.24798756261026, 71.62477785541166, 72.6907290181806, 87.43877026342577, 81.42434904652258, 97.97108727116739, 72.56354224297309, 76.32348706645351, 64.86725968699302, 59.100053694940385, 70.23760810975106, 70.49509602208292, 56.91101028073219, 36.96535787274761, 32.90585771683724, 33.990565653770204, 43.89032202382242, 37.24119855511574, 52.35738954236431, 71.05102923608595, 91.59412137923702, 100.0571684683523, 120.23835920518445, 112.7326685382474, 119.94548366915797, 121.71064438358431, 132.9038493863998, 126.87952810718168, 80.5585878126083, 17.22312350426951, 1.1470538882478591, 0.38202279758068824, 0.02521602343016815, 0.046887024786443486, 0.04101091973303307, 0.020379809955615672, 0.03070089312630796, 0.020363752752722755, 0.051764155017031785, 0.07121448390065663, 0.050293430911316994, 0.06522341586288906, 0.04591885818949631, 0.03502688821285002, 0.035695640835911036, 0.05262247226651638, 0.04708745253963336, 0.018491073804456862, 0.02445469482711727, 0.021966194185698708, 0.03936625153367077, 0.014596603596733223, 0.0308706562951087, 0.02893168584353501, 0.024688263543911522, 0.12674245953319535, 0.02205975841911089, 0.017838363062530276, 0.03871007424388682, 0.03917539604909478, 0.005468769400801149, 0.08689085682553631, 0.03371204001708858, 0.023306016847791693, 0.05306099248569339, 0.07113628930622531, 0.04472848395967195, 0.057817866064367764, 0.004343716615450479, 0.049969739611110384, 0.05227792039213162, 0.060001339222634995, 0.05783286223548555, 0.039188300800179286, 0.06263306957759684, 0.02404867205768824, 0.024842563227960662, 0.0827576975608545, 0.05478161447230847, 0.027655701288172317, 0.015464394481011457, 0.027855684710366112, 0.025823772471818714, 0.067660617341678, 0.028648890231946306, 0.02879508853619618, 0.03264951820094739, 0.06857595451536679, 0.12685163472328456, 0.04537936375145951, 0.051015315562366485, 0.012567337234354308, 0.1817791046754968, 0.23491110202045212, 0.2854427977675392, 0.1919844530282482, 0.22308435921947803, 0.14074596456221997, 0.1455955922363266, 0.12652967861222644, 0.09584580412915639, 0.11055506765842439, 0.10675606062455524, 0.30945824459195137, 0.17002143236177583, 0.212955788198498, 0.14445956045341107, 0.11612933790010792, 0.20699779983730088, 0.14003281331350728, 0.16324598222009598, 0.183181643125511, 0.11945968298541924, 0.1564041275771395, 0.1723813202472464, 0.13057807790896586, 0.15126900957717052, 0.18887897773135096, 0.08818202907399786, 0.14561569438345973, 0.11507014473599773, 0.1740640783382039, 0.17173009954633253, 0.13587577508822565, 0.1807533435884022, 0.14271687896501634, 0.14805556184822513, 0.13353456442634906, 0.08457946996655195, 0.0826768369804467, 0.2071673963819781, 0.2064715893638711, 0.10498411457745299, 0.1414251168288531, 0.251601645122132, 0.10617323625352114, 0.14181007601080403, 0.25234240617963577, 0.22568142792630583, 0.20412573620917338, 0.2663794352162269, 0.21854058448826114, 0.17347936939087608, 0.25008993914290784, 5.6196542709104484, 19.33678092495088, 61.15534428627261, 103.63455049453243, 118.37558638664984, 122.8018085418209, 104.93845616617511, 102.46771597093152, 91.5184667033534, 98.65854540178853, 100.41419044617685, 105.67358678387058, 66.9496185548844, 64.3187750539472, 43.889106089069, 43.08779331945604, 48.50007972409649, 44.344701151694025, 44.91754370350992, 73.70800356711112, 87.14471801634758, 104.93667541011688, 110.1789309901576, 145.16180530671153, 158.82498956495718, 187.3059783443328, 253.69916946657244, 158.56763501321117, 185.34311448374103, 176.598566732099, 193.10054286833733, 208.44811839442102, 204.08492088317874, 185.01024646143762, 196.66186671103202, 219.35106800448511, 245.597043191233, 197.9270507443336, 203.80842516499183, 208.25758534093058, 148.0369967799033, 208.191218837615, 192.67990789105818, 139.10481852869836, 106.24317769081362, 106.78400193491291, 85.85777267333, 59.337914066929976, 47.50932824227118, 33.92637214353008, 47.699418067932136, 52.16944133081744, 80.03827756451022, 94.59715074108493, 119.52972812037315, 125.86329690871702, 135.9203089437177, 129.13168245746243, 145.31316172692084, 148.23581387919765, 102.73457834797522, 27.374250850369855, 3.1147181170602, 0.3354907702774771, 0.1494363280794313, 0.35093593020592967, 0.11235693709984904, 0.15099695643350003, 0.08915083918480143, 0.09559769889399891, 0.14626429506367253, 0.19808949962739023, 0.12536878727616804, 0.19137519862382643, 0.13855696024913944, 0.12027898337692024, 0.12015323770502884, 0.27855395129130733, 0.14446398844161343, 0.1309464436264769, 0.13454886483809642, 0.09436676413902352, 0.13574492727075854, 0.13228964090587633, 0.23104646423410988, 0.13520137256672307, 0.21330881683576494, 0.16421257067591916, 0.09045013196526036, 0.09094471832917583, 0.16314871969722933, 0.13721672006912772, 0.1526052507782175, 0.12352212467381071, 0.1634253693684455, 0.08163605290915697, 0.24312008652956257, 0.1695998694988028, 0.22679956389531014, 0.1282241501875462, 0.16667180484341038, 0.132118021889079, 0.15978838226968245, 0.18201576455706553, 0.19682819714709637, 0.08217429096299796, 0.17986118823530214, 0.10995274634971736, 0.10584047830273068, 0.2369471645403293, 0.11230398510252276, 0.14485766570414269, 0.11251387787201714, 0.12355709658755411, 0.06617526478704906, 0.2561500163808946, 0.07379171859112478, 0.10198766125306007, 0.1786394618571766, 0.20714686522560738, 0.25330367798526443, 0.15410077698048086, 0.1937244378871495, 0.18118362453195358], [0.026473325016277454, 0.0182265053398066, 0.09909470640723744, 0.05194445381001119, 0.055711744803815126, 0.037464078200320085, 0.043664583185267065, 0.04698446350953272, 0.01425938605661354, 0.03849003080939574, 0.026276099510611068, 0.02332810890830813, 0.040463925294217565, 0.08403099697804259, 0.01767377481765805, 0.03564200702033216, 0.03165002243833677, 0.03282307158975351, 0.04963874366254576, 0.03241912491859929, 0.052197124929197376, 0.09363653679047862, 0.12304941012013344, 0.06682442471144662, 0.04126695780864647, 0.039708198709112984, 0.037567706913837505, 0.0650094245229998, 0.014770383939086912, 0.030356373810659976, 0.08154328732240586, 0.08547252164252343, 0.015054962620319379, 0.05651621373310205, 0.10190143039630306, 0.019583722028220375, 0.054623773546829346, 0.025919724984334844, 0.07762550601675626, 0.04501323501068739, 0.04889251273726264, 0.06032866561004232, 0.053040170215911446, 0.02159647249256171, 0.01703213787667694, 0.14216996879587251, 0.05954124979794987, 0.05433587387444512, 0.1688797774934961, 2.2906742317061273, 5.504572910647239, 24.863796657131566, 57.414379812056026, 80.01581807290354, 69.94674867199313, 78.92689751040551, 80.56048623977169, 68.33571357111778, 73.91321412978634, 72.02284351471933, 70.44823154326409, 26.442119190769812, 32.05155960975155, 17.760937329261534, 26.824346319321666, 27.83247978456559, 68.9955033025434, 90.57130844362321, 85.79710145150462, 104.96973314592915, 122.31821167853572, 134.6951017072124, 77.35760427290394, 114.3960908151442, 54.795876087680945, 42.24751964692147, 25.450318474923414, 35.7819317233178, 44.310913855029696, 35.446623986767186, 45.24017826203377, 39.14046510573357, 35.36323439690375, 48.184258322561945, 29.558238329425937, 38.85729743588356, 26.11152025961107, 18.18766963097357, 28.69601115103691, 25.795043822257753, 18.695208641790575, 27.63479821143612, 25.78857191147343, 29.648529329607566, 38.87823504786338, 40.830630102465236, 67.24468277346703, 94.99079196683823, 110.78065395355226, 135.35926880375033, 126.60999851842081, 105.0916168766637, 66.71304472031133, 38.29862640750024, 26.43327816840141, 26.10227131074475, 24.401162901232322, 51.236454594519834, 66.9165921980335, 82.43206870171332, 105.54406227604036, 89.52032504543182, 98.74002871974822, 97.76357035483085, 81.32747434800672, 36.696091082788286, 10.473730525662823, 3.925261204281161, 2.398685519733737, 0.5666301916203191, 0.21329291285045687, 0.03974603196125358, 0.07946846075356007, 0.08781850503216829, 0.024479793782736507, 0.059757914784694874, 0.08413287901109265, 0.026985537148110812, 0.06270467964631897, 0.08223705654663425, 0.042919777183523106, 0.06230725238340036, 0.08300127521637948, 0.013412171336371573, 0.021003290612791336, 0.06764199374423874, 0.08674503965002876, 0.05251738415550321, 0.020933475105031844, 0.044551904523564924, 0.08346353266989032, 0.013654950345235487, 0.036332462914288044, 0.031594379557176464, 0.01322675890649759, 0.033782669493267616, 0.07902377735703223, 0.05896601352780577, 0.032750607332995826, 0.04680473928249652, 0.03170638927258551, 0.010290632133312043, 0.020184629904707114, 0.030412303974791884, 0.03620245396309803, 0.01704612855739411, 0.023043430635645505, 0.05057101520980078, 0.0058181758786010895, 0.06355563862129085, 0.024101905592326677, 0.007461263064009648, 0.06398827145476976, 0.026982363628884478, 0.03470059604414048, 0.12406875139042256, 0.10845813179208387, 0.011998779335690123, 0.07461813593944235, 0.05523415027006019, 0.08985544089227916, 0.0446273373710292, 0.07935566196758902, 0.01982578857531471, 0.03786900163357777, 0.027503019964863217, 0.046471529339830724, 0.039247189978918726, 0.03713698163929005, 0.006537997359109502, 0.03410057299920628, 0.12197065107043713, 0.005614733090624214, 0.051772248735951806, 0.046873288829961134, 0.020712996915643735, 0.022874054341246525, 0.016441434291341615, 0.08693011117077644, 0.017185010721967105, 0.04311395365925085, 0.050711320382693124, 0.038563858702658646, 0.015323916938336147, 0.03820498481452946, 0.0639071848784243, 0.04086304561144883, 0.06962803838353965, 0.09355821196110019, 0.0262642749434998, 0.036414671809442585, 0.049455196656767404, 0.04948877812092824, 0.12113805905344988, 0.04595109516935003, 0.02540075212656971, 0.02745896799399728, 0.07755560049366567, 0.020829727647886164, 0.045016081027326085, 0.053000046360877254, 0.03762250901350091, 0.07076715750079002, 0.014103086883082025, 0.052764160228112054, 0.027346826128421292, 0.04727173498981903, 0.029011998671076955, 0.050771952411460305, 0.06060674020479764, 0.05818933443797212, 0.10483471211045982, 0.05342529027632648, 0.08006993170467117, 0.06185222679989473, 0.7295628745229014, 2.2906112286352345, 12.242091894149782, 49.89837331156577, 78.16868766661614, 83.39675211137342, 93.41643102707403, 92.91930198669435, 80.4914289905179, 87.23315177425262, 100.71386737208213, 91.27303615693124, 56.95430540269422, 63.15530200158397, 53.90418406455748, 34.661918532463815, 27.55884151304922, 64.72164169434579, 37.9747288457809, 40.587027380543375, 59.40027190792946, 72.79662516809279, 77.93545569142988, 68.07548784440564, 82.6900351432062, 53.12347942782987, 47.02015376860096, 30.094192950956284, 37.44990787198467, 49.392383636966834, 37.342058381726666, 38.64979228665752, 39.6343699578316, 36.543161792139855, 41.4658736413525, 30.689353789052657, 30.56934299007539, 25.705425508560676, 21.386217378800918, 25.561072480294015, 21.923372245603993, 24.238651260252922, 32.63488469585296, 30.477265350280273, 36.760115931111, 45.172674271368216, 40.45890315886467, 50.85103465664772, 68.73661118168985, 79.62540888017224, 86.4879249757336, 80.57374385095413, 62.020944703009825, 40.62996556681972, 23.568675133489794, 27.460601829713394, 50.922943469016786, 58.92010711854505, 85.65886928189187, 107.39586814757317, 102.48590792379072, 122.62607066862046, 100.37052662141862, 117.58860203527637, 115.31651419977989, 93.22768657438218, 40.267389512831166, 10.052835691359736, 2.942242430102441, 2.0908618309805473, 0.38276565771910454, 0.11426673300804631, 0.07111268613727824, 0.12499931839204605, 0.028908982827898957, 0.025820769407155535, 0.044197010462202375, 0.021401311593851256, 0.05795047971450033, 0.0005566231465631826, 0.11202695238734446, 0.009156129653415373, 0.03404046957110686, 0.03366887096255537, 0.01758115478761254, 0.03532103533225675, 0.07537516104357858, 0.022732808795427124, 0.04851763527239523, 0.04057869292615403, 0.03750717830694011, 0.009624566563645439, 0.04111398154148652, 0.05972372811107386, 0.05385213531553746, 0.06326008956098268, 0.031457042974990704, 0.0602286528315275, 0.02540112367921299, 0.06071913296416883, 0.044748321806471196, 0.031242241497121515, 0.0920764446979569, 0.03630569580221369, 0.009362398827027892, 0.03855417152085612, 0.028105889026436116, 0.02421250187551543, 0.020388809573506157, 0.021650577452214017, 0.09921565636872284, 0.01969957750500931, 0.016927300659458966, 0.01335526824057583, 0.04297158004896295, 0.01280289586453188, 0.06943666962005439, 0.03207139377932876, 0.02528969427540658, 0.02849968886303325, 0.04603039676083192, 0.015276562170906654, 0.15579502639030257, 0.12177249476794275, 0.04544276518807296, 0.07738736758549368, 0.01223642938590098, 0.19144437636338896, 0.14590495386190955, 0.23225319061067798, 0.17885675503601953, 0.15628794268254312, 0.18752597452652073, 0.1768496659614386, 0.09591750995886904, 0.20658644126547923, 0.15807174777071323, 0.128259229353599, 0.1946877781301737, 0.17628786304304678, 0.13561708251795462, 0.1685946395680789, 0.19415614375424003, 0.09714929507144036, 0.18699412564596823, 0.1728374336756045, 0.12658985481867868, 0.1573699346232799, 0.17649754130792233, 0.26362274442949607, 0.24943576134260625, 0.1736918515375545, 0.2625087913005583, 0.12680420621989236, 0.26587099798264047, 0.1800347837589441, 0.15310890762315643, 0.19732094489999358, 0.20815672232739388, 0.05922451840653535, 0.12498349101553041, 0.19296705272168885, 0.16406200375528107, 0.18101001368655315, 0.14143397280525777, 0.157377289067353, 0.13110030472518938, 0.2710355337589018, 0.11851044642108104, 0.10825316496794263, 0.1539131314043076, 0.2214181333059265, 0.22629465066617538, 0.09226484870117518, 0.1783681594796719, 0.2659157068739014, 4.6143277518210875, 11.370907002879727, 44.24321766822569, 87.71626226363644, 111.56260982636483, 102.55866789048719, 102.47431339756136, 105.83503154016311, 91.16269203924364, 94.31885073261877, 96.29265016125095, 92.804729553961, 41.84611212822699, 45.56831198353922, 29.018098538921727, 40.51310639227591, 39.47973051378804, 90.65671413175522, 120.84861724607407, 115.10916986773091, 143.4844272367416, 172.21379618490897, 189.74162901601485, 110.88493408695345, 159.20605567193803, 82.44884860131049, 66.26771450042725, 39.12582289788031, 57.10878010719054, 69.34672801725327, 54.90252925503639, 66.90777470988613, 62.44233669773225, 55.566233511893984, 77.5615910560854, 45.39036581593175, 57.903001231531945, 41.27846671688942, 29.81715986805578, 47.24262276003438, 42.329226539980986, 33.71179496088336, 44.920638453575876, 39.58065309832173, 46.00812342859084, 60.15901911643244, 59.6497699522203, 95.48968607379545, 137.40749912877237, 156.77398220185313, 187.51739409662065, 173.3510325031896, 141.88060145224296, 97.77808312446841, 58.44347246231572, 43.37204356347361, 48.47543154993365, 42.51652363807925, 74.54924214270808, 89.05346885804208, 108.7287836690103, 132.07812770720452, 110.62233924865724, 125.76827356892248, 132.02734085821336, 116.69502335210001, 59.45187853228662, 19.260671254127256, 7.855651397858897, 5.139265906426215, 0.9749149122545797, 0.30000459703226245, 0.2270837978369767, 0.24288407016185024, 0.10124273267724823, 0.1910602905216717, 0.25824030260405234, 0.1890061483267815, 0.11149408460985269, 0.12208605455535075, 0.21028287678716645, 0.1372188497935572, 0.20877161513893835, 0.18157564704456639, 0.08403161750926126, 0.13650697025079883, 0.18125672464168843, 0.16503069129201675, 0.09097056613574106, 0.15971085417174524, 0.1433871752552448, 0.1320425469067789, 0.10477943120584374, 0.1563353635250561, 0.14563207334328085, 0.20131105256657447, 0.18790943217614006, 0.10294974511188847, 0.16556748910056007, 0.1500660063879144, 0.1503030186699283, 0.1429933141316137, 0.3247187773306524, 0.07449309506844129, 0.15111524040900892, 0.18651256277676553, 0.1868422257323419, 0.11852349289843153, 0.160929684737517, 0.12391463748269504, 0.17587446667734655, 0.12730635387162048, 0.13492584138387634, 0.15877264161263743, 0.13723430944786918, 0.09686054121102057, 0.34340923892394193, 0.2183120604604483, 0.08022570802319436, 0.17492174441295286, 0.18165129056620985, 0.1811322659975098, 0.23265411506497094, 0.2355865770650487, 0.18678384983251173, 0.17412228569869073, 0.07202619236082801], [0.022458465048863042, 0.029825413592099666, 0.05740870233444918, 0.07693860860120866, 0.030361389771344203, 0.08889854344869814, 0.006856265235617156, 0.023284851753663634, 0.02539932528781074, 0.049426138941799445, 0.032570021257044814, 0.04587071722433452, 0.0450824816981631, 0.06176935906912531, 0.028240327881048286, 0.04813359539595343, 0.16117049681563533, 0.010437280514217433, 0.057682092301547534, 0.05655172190839245, 0.0341006649297572, 0.053411335984785716, 0.03727797629131425, 0.025411117296185226, 0.06922057919925259, 0.02133771097437749, 0.03204489671324771, 0.02312903713074423, 0.038224769035174, 0.03989132053609337, 0.056869901205983855, 0.018740140479959307, 0.04414400483872141, 0.03572403971526412, 0.0770810779724871, 0.04409490243321465, 0.08500369115462227, 0.051412957329903884, 0.04338962273792394, 0.08451276669098486, 0.011246245422009981, 0.05756403815241591, 0.10640322350926938, 0.05001384329291121, 0.07402471657241545, 0.2809462293742165, 0.7160834042776016, 2.477695538151649, 16.09229830003554, 42.12862083988805, 63.92309027333414, 84.94416636805381, 90.83521335355698, 85.59950813170403, 75.54473184770154, 71.80713668946298, 85.90383698863369, 50.45947228708575, 25.65216756636097, 31.478828845485566, 19.739129812486713, 31.44494937312219, 26.562869356524562, 42.701373177189986, 75.78259221969113, 92.84884837365921, 84.95203464261948, 87.47487175849177, 71.768964182946, 30.64808261009955, 8.942254820177633, 2.3464768115551244, 1.3029169892111134, 1.1468376675921104, 1.014643312702256, 0.5680696401865252, 0.4116447209831207, 0.5240373577802412, 1.3236263682765346, 0.5162784192831286, 0.7745441253627501, 0.8255798609987383, 1.037299351826791, 1.423193651341623, 0.8628788434209362, 1.0226690336581201, 0.5459868186904538, 0.29454861076608785, 0.6511310992702362, 0.4922839939113587, 0.7204413414001466, 0.5514669826915187, 0.6549066257092261, 1.032561373806769, 1.2022983883657765, 0.6518056856528406, 0.9844457814770361, 0.8639246453681301, 1.0648500799171388, 6.106498856698313, 22.268997776892878, 54.488362266171364, 96.02348927528628, 139.93074417114258, 120.94185198507002, 75.05245085685485, 45.140836392679525, 19.20560117690794, 21.958185242068385, 45.78927086245629, 49.40838690726988, 92.18845459722704, 87.96308917383995, 92.25937889468287, 97.51035782598682, 102.25961069906913, 102.54850110700055, 84.09188239805161, 85.09738199172482, 43.31386304670765, 23.06494866648028, 5.0941807127768, 0.3084598788090291, 0.05985718445792314, 0.034897557249472994, 0.03542691251383193, 0.031600602106341434, 0.043563992010369416, 0.0712668996364359, 0.029283450435726877, 0.053302689395364256, 0.02314310825069345, 0.0335919710567161, 0.10522729386725735, 0.038746206780835506, 0.04682177707793252, 0.01687618344271135, 0.011315274732037178, 0.06283006525688595, 0.025780069070958325, 0.055108684220261155, 0.05762520261229046, 0.04743480446538137, 0.05829861688037073, 0.05863128290061028, 0.02539959341858424, 0.03130173780054095, 0.13701327775995578, 0.035268527665926565, 0.041674282927546775, 0.03463878423996991, 0.06022278459802751, 0.06745227206979068, 0.035062388727261175, 0.02159628863145988, 0.03732325974851847, 0.02346953448478974, 0.00539849232506728, 0.04418529697784013, 0.0381328844495358, 0.04358966744715168, 0.049847728617849855, 0.018126325937168255, 0.009557381610295946, 0.022730583310007088, 0.020233851053842136, 0.01205897469434046, 0.04479763105571751, 0.058636565076848196, 0.12303591931178687, 0.019869664345958063, 0.01643631873922723, 0.0396761111164045, 0.02320437804765759, 0.05737996637640942, 0.0872190029270226, 0.039477908848634655, 0.016794958970539512, 0.09008439392932961, 0.01881719934904287, 0.1210994788655831, 0.03797218601609911, 0.023148440222646442, 0.05623216365253734, 0.05721462161971196, 0.049237899647484866, 0.059256176990006244, 0.015285715006381996, 0.023268105071638862, 0.02310232556004438, 0.03573770289339366, 0.014358109892195752, 0.05802130071266044, 0.0019685925578796157, 0.05944416347530581, 0.08881785140763368, 0.06411692826077342, 0.015040051676483165, 0.03552536630342084, 0.036220464690197865, 0.06535249401725109, 0.01712840257002221, 0.05897397318133905, 0.0840671486671894, 0.008618137705320073, 0.05097245677344261, 0.03719515452582029, 0.017736456131622676, 0.03408625481590148, 0.03352271670836114, 0.10938663801719105, 0.012774316954516597, 0.08011441076955489, 0.05785627771289118, 0.04924222038337781, 0.02651037685873528, 0.02046439180811567, 0.056521074560981606, 0.0923577751663904, 0.029890839416053028, 0.09935143013154307, 0.11837838052381432, 0.37974626006137946, 0.8418439076312128, 5.723802514614598, 33.23616050904797, 51.53522937528549, 91.66794823062037, 102.21307569934477, 97.40939601775139, 83.50935551428026, 81.4416466989825, 94.08551677580803, 60.2253189394551, 48.52409247429141, 47.88738981370003, 34.8827636626459, 29.047057397903938, 30.2374477155747, 18.381460212892105, 49.214245273220925, 43.54962887302522, 66.72128954241353, 94.58088074961017, 72.22306482253536, 36.89680268687587, 14.480209062176367, 3.792134980040212, 1.4576441962872784, 0.7311425478227678, 0.4938642800815644, 0.5951494999950933, 0.5760500700243059, 0.694129714562047, 1.948062919320599, 1.030059269359035, 0.9177023629027029, 0.7730842069272073, 1.256045523670412, 1.1927123608127719, 1.2077471734054628, 0.8148475820499083, 0.8676311626069008, 0.4840527775306856, 0.7583788121419569, 0.5581350732714899, 0.9795677625844557, 0.6921255672650953, 0.8610535316890287, 1.2782088763290838, 1.3381010173789918, 0.468569251918985, 0.47939992720080965, 0.15871284078926812, 1.0098591855456753, 8.269435955632119, 23.28817467535696, 51.85379251357048, 73.97892951965332, 91.15335679823353, 72.82586251535724, 47.398925289031, 22.01088228533345, 28.76353083118316, 36.541663446734034, 73.42065857302758, 80.66355043841948, 106.58407088248961, 101.61869541291269, 98.26229187750049, 116.48856547570999, 119.73607617039835, 114.1470673776442, 94.66450568168395, 93.89058282298427, 46.55526268866755, 22.833360164396225, 4.488165695821086, 0.22694508995740648, 0.02760275695172529, 0.018520665865752007, 0.15222093511012294, 0.07737661937191602, 0.029627649909666473, 0.12038193027218504, 0.01547973826452489, 0.022631472600023114, 0.04104289624299254, 0.035029063902554974, 0.07698333281422816, 0.03752602023943778, 0.05217544847137986, 0.04264265636823351, 0.018759246712790865, 0.03868486229029875, 0.031452672443382686, 0.05223670869224495, 0.11268483805319957, 0.01532394087858378, 0.02615931706743375, 0.07911468135012735, 0.024992664750184745, 0.04148209061954291, 0.0323402714885531, 0.027420927898117134, 0.05088924813354689, 0.06803222361110872, 0.06428566295653582, 0.04279335735425834, 0.03290000596954938, 0.09512866922323743, 0.05222119158133865, 0.024971112781654925, 0.028013255589851932, 0.015400744065822614, 0.039167490021716204, 0.015399880301687988, 0.05922367954025826, 0.08413767472149865, 0.022586524306285768, 0.06486990459022984, 0.02154303211418371, 0.001415752748500616, 0.02313335020575793, 0.02060822481589933, 0.05490207030708271, 0.023193108894291426, 0.04446213434059774, 0.0705909189738093, 0.060533743516932574, 0.050482826998397234, 0.04175418972848885, 0.14650025014435092, 0.11156885479126247, 0.22256400165778978, 0.1421859647117315, 0.18938413610862148, 0.14479464731149136, 0.13406079022153733, 0.1992828654305589, 0.24252452977722694, 0.1448016493551193, 0.28037356332905833, 0.11061996296649018, 0.08803109443115611, 0.16364837756320355, 0.19007249675210447, 0.2230842979324441, 0.23298190876601205, 0.1688220910727978, 0.1558368547909683, 0.19492952483555964, 0.17434768408777254, 0.19397191493020904, 0.12196328130460556, 0.11321930695445308, 0.21226198833075263, 0.10094008198188198, 0.13429092303399118, 0.16879095725955504, 0.10559134650975467, 0.1147517279511498, 0.183221586949883, 0.1973705414322115, 0.19102512708594724, 0.09277877878517875, 0.16273910780587506, 0.19315230810353834, 0.202937901560818, 0.08999453181581152, 0.11440533363530714, 0.1797117398030335, 0.13624619392137374, 0.1867756986569974, 0.24251962681451153, 0.1911999023849926, 0.16190744275527616, 0.27840039662776456, 1.0192904633379753, 7.402649512214046, 30.32249450683594, 65.29233478730725, 97.51145608963506, 115.1135080091415, 116.04472575649139, 106.3349925318072, 100.24964701744818, 94.32453032462828, 111.21750400912379, 70.66182813336773, 42.39941343184441, 45.80936516484907, 35.55574432496102, 44.68089926627375, 42.08760069262597, 63.81135371423537, 108.81838629322668, 141.11834372243575, 125.81937420752742, 128.09477252344934, 102.71768862201323, 46.95785084078389, 16.009474512069456, 3.284818808878622, 2.090158010682752, 1.1046462025373214, 1.3136503100395203, 0.9160808305586539, 0.6783079151665011, 1.120854784404078, 1.8955087974186868, 1.3979053953962943, 1.3613984253137343, 1.1813258427766062, 1.6252532024537365, 2.5809347725683645, 1.4208719759218156, 1.5481137868858155, 1.1143469594178663, 0.44269696118370183, 0.80937514021512, 0.9439792399925571, 1.1129165200456497, 0.9702550752028343, 0.8403814151402443, 1.2259011283036203, 1.4343329374828648, 0.8432774726421604, 1.3196857345681037, 0.9665440840105858, 1.2322829471480463, 10.75454673459453, 36.01902331075361, 82.66280604946999, 138.49718063108384, 192.0204633282077, 156.3494876123244, 100.10548422413488, 67.28229830341955, 33.52413700472924, 33.15745422917028, 60.128789409514404, 68.66815013270225, 121.73571617372575, 112.22095612556704, 112.04866993811824, 120.05090128990912, 130.21335447988204, 132.5306437092443, 115.14467516253072, 114.65299037195022, 70.93790808031636, 41.60027757767708, 12.860603582474495, 0.46759172372760316, 0.11372127074507937, 0.10866364253865135, 0.21050810663690492, 0.2559636884759511, 0.15715014399780383, 0.2259434759616852, 0.09378855927817284, 0.19936330466260835, 0.09281317613297894, 0.13849014206038368, 0.27308972191906744, 0.10768527165055276, 0.1976366037683141, 0.11698533390318194, 0.1725237819576456, 0.13161484001865312, 0.09263567356092316, 0.1354837985408883, 0.2577288316622857, 0.19452925921688158, 0.09616454267093251, 0.1252383071809046, 0.1450871090374647, 0.15357019980588268, 0.22392454316779492, 0.12162131497696524, 0.12079076075385656, 0.09118640374752784, 0.18908361513768474, 0.11468204459355724, 0.1441152192532055, 0.18189188813970936, 0.08538528721058562, 0.06343841184711745, 0.18230292495460282, 0.13589281288366165, 0.17483934399581727, 0.14653777313088218, 0.15500189556229502, 0.22080000760334156, 0.07481923401956597, 0.18891358958376994, 0.1139687937534144, 0.11840713180361256, 0.0670818915410388, 0.07903595049414905, 0.3099699300383368, 0.08062611919857803, 0.13532607635903743, 0.14711742589790977, 0.14959492360151586, 0.14687456070415436, 0.2196384650925475], [0.02743790440651919, 0.0714028649212372, 0.10401582540643793, 0.04046405169872507, 0.036009886272011266, 0.06431583915987323, 0.007889717366666564, 0.023188592805977792, 0.06602354873452457, 0.06635419994352326, 0.031009502070505294, 0.0219331547287443, 0.026218732931621136, 0.022874008375971068, 0.0082035701827056, 0.03097004854240485, 0.023344773235881043, 0.08158071071750696, 0.05491076540502329, 0.07424371812732951, 0.0265638038305746, 0.06269671616234607, 0.07608537051466203, 0.030133139619964267, 0.05077631145174946, 0.03898453290363954, 0.06717913108126772, 0.05550721464979072, 0.07994217888241814, 0.008961430322679301, 0.03797091047970518, 0.023614070378243927, 0.05370916415666861, 0.022709762955444957, 0.07653975258431128, 0.0626858568660194, 0.0647455838418776, 0.0032003931119106714, 0.07853241622327797, 0.08723520568662113, 0.009296408970840275, 0.06506566303752123, 0.19504157285536491, 0.2851286404315503, 0.5438450820023014, 17.025279152777888, 39.82474219414496, 57.93452924297702, 83.76376828839703, 93.33408478767642, 92.35344517615535, 84.3841068206295, 78.48958461515366, 61.26969706627631, 65.30455689276418, 54.07674089554818, 35.70428448338663, 19.792103382848925, 27.664066937661943, 121.77443781206686, 59.217057997180575, 61.72726900346818, 101.71976704751293, 127.24053521310131, 93.78964454896989, 49.92306070943033, 35.8851763509935, 3.327567985942287, 0.29170538268743024, 0.2497850361490442, 0.12701771492438932, 0.04345783137626225, 0.13989340063304673, 0.18534213364604982, 0.4180461210348914, 0.20438882612412979, 0.10820303983505695, 0.1425569198064266, 0.6485883002319645, 0.2690499257897177, 0.3966038409740694, 0.4708187924998422, 0.6048082139703536, 0.3064192044398477, 0.22787095317917488, 0.27561968132372827, 0.3084708185445878, 0.2230228423591583, 0.3315046922333779, 0.24282857475261538, 0.22413082000228668, 0.3519116197862933, 0.3011781518017092, 0.6489361041495878, 0.5200909630906198, 0.23062533038037442, 0.19678039326062127, 0.43893053586925235, 0.028564492240548137, 0.49193183861432543, 0.9561108857873948, 0.5757064336249905, 1.4054937107909111, 12.904372330634827, 40.479707410258634, 99.69214485537623, 128.82642792117213, 105.47716233038135, 72.38323088615172, 35.988566106365575, 36.53161825672273, 32.551706913978826, 41.513091133486846, 75.04093477802893, 80.11313207687871, 83.94601729608353, 81.27808386279692, 83.52756315662016, 93.69170296576716, 98.06860523839151, 85.13587613259593, 60.476134900123846, 26.04563032427142, 1.3751387331754932, 0.05569328974571921, 0.0776370203182582, 0.06462415890587915, 0.017673357299739317, 0.05410030949860812, 0.07075035719261055, 0.014565845166573362, 0.050867744045512336, 0.035668291497014226, 0.04421179595914099, 0.06383965422789897, 0.05449782486163801, 0.05817903438583017, 0.03982076000782751, 0.05959570715804735, 0.1319607900034997, 0.09726744881200214, 0.059852082312347434, 0.007714712241243932, 0.007410692163713037, 0.08201215611470324, 0.05756941608964436, 0.035709258048765125, 0.04082440413654812, 0.022778749173026414, 0.03486255086177299, 0.034375142741708026, 0.014053297871273133, 0.06393579826239618, 0.010059172073529373, 0.027040482889260017, 0.04212365478217121, 0.07048870752295179, 0.02738628157174155, 0.007374258937254068, 0.007869441413335622, 0.06960762214035758, 0.015670641629596152, 0.03106846019715792, 0.06656423826972324, 0.012109820907484862, 0.07561008190555919, 0.016690234751290372, 0.028282832354307178, 0.06954023704653786, 0.03628855841534753, 0.022787986278173425, 0.05386903904558671, 0.08095600431965244, 0.04141140368676955, 0.06541846950929012, 0.07581255128306728, 0.02590851711800262, 0.08894109963289193, 0.1216792235631616, 0.06291390974975883, 0.05578952571076732, 0.016883465108431635, 0.014180470381923502, 0.010156899994810023, 0.0367145799100399, 0.030560105318023317, 0.03763359047532563, 0.07527457369912056, 0.055894142677707065, 0.020298372894044847, 0.01563384451137315, 0.07053758393252088, 0.07800245957989847, 0.07787915772848553, 0.05638456152331445, 0.05605839958955204, 0.056920447687227885, 0.07789337632036017, 0.09581374334952525, 0.03753936932151837, 0.03392132757712276, 0.04684626890887176, 0.06852396012794587, 0.043498694506143375, 0.08705129095863912, 0.012469581542386404, 0.10410161193219886, 0.025271809952814254, 0.060908241768277464, 0.047252621096108234, 0.018446916496501337, 0.028057271171541467, 0.0127222545767924, 0.037517466867763194, 0.05991923757978986, 0.028080060372069, 0.04182010010305432, 0.04444987693380925, 0.15729482736318343, 0.19113714446223554, 0.6306413116474306, 2.4040581862772665, 17.98848186769793, 40.84101261631135, 77.28384017944336, 97.91400894041985, 104.33943179345901, 94.25712831558721, 87.0839761918591, 73.19268257387223, 78.7088058840844, 79.36057044613746, 64.6643162542774, 35.58209873014881, 17.344238450450284, 86.13561768685618, 37.62579871762184, 40.34905325981879, 40.76375369102725, 70.36539892996512, 83.40510675984045, 51.55580220683929, 34.363512454494355, 4.2237842179113825, 0.3957033505843532, 0.06936193774304084, 0.26294058909819973, 0.07997269982532149, 0.021756056268068574, 0.10245224761386072, 0.1734567697971098, 0.21525612040873499, 0.17210039580541273, 0.29790520968456424, 0.6566647055648989, 0.5250878175420146, 0.1584242095029162, 0.13133033028533384, 0.3568945927245002, 1.0045399612957433, 1.0562201300936362, 0.6841184775675497, 0.5641755846238906, 0.3293068166221342, 0.06718061729184083, 0.037795227366469564, 0.3451656027426643, 0.20092898919697733, 0.2932115728335996, 0.4015950570183416, 0.44801560320681144, 0.19507822250166248, 0.08217232977791179, 0.16175566541571773, 0.06725971587002277, 0.8240816381669814, 1.1197269804054693, 0.6907860778512493, 1.1604563819785272, 11.053913793256207, 39.17638617177164, 74.3907234745641, 92.6611315819525, 62.35767625993299, 38.57462790704543, 27.87015611125577, 42.19464217462848, 62.348160589894945, 68.21581455969041, 105.80957535774478, 92.7318754503804, 100.27284391464727, 92.31704558095625, 98.2561259115896, 106.61443787236368, 112.20435665499781, 97.03167177015736, 68.23544994477304, 25.935445062575806, 0.7397170941675864, 0.023809001450577093, 0.009572874780954614, 0.037821883395794904, 0.08532615288371041, 0.02110970788635314, 0.051029855911169326, 0.026277022646559824, 0.029717448820930817, 0.019061470314139323, 0.11695045391998946, 0.07282971900196807, 0.03294938416670888, 0.1301521636665829, 0.034614617996398485, 0.04614459365726479, 0.049937655848841515, 0.029383193168248382, 0.03555436273135486, 0.023833244302940947, 0.028774021118278467, 0.01633203693575436, 0.021629025483684197, 0.06494084433201822, 0.01279010123858649, 0.08580066008313049, 0.042784432429940476, 0.01749172742899147, 0.040757222056028344, 0.02675540816609658, 0.03204147230022617, 0.05335852188328582, 0.012525259855113203, 0.09689163671986711, 0.03172322980038101, 0.0519276496713921, 0.035149236284797235, 0.030178392433651516, 0.015531168619711554, 0.010609170534617959, 0.08940792297043147, 0.049903342770713, 0.0310127062332486, 0.04640987841412426, 0.018859768939775326, 0.016484896374505856, 0.023103440217974208, 0.07186422605187663, 0.052715299140301444, 0.09517930763503236, 0.025457404328570254, 0.0595385531684564, 0.023299162276089195, 0.11338401585817338, 0.13178834361174416, 0.27077846529503025, 0.17528237264242866, 0.11293206228724412, 0.15965623210274404, 0.19687612360763937, 0.0810845538733467, 0.17668705613863084, 0.1608710330460341, 0.1276528860832895, 0.1129253666787859, 0.28511577015442235, 0.11759317870582305, 0.1310786704022077, 0.19800107775916978, 0.16307333664548013, 0.15515618567024508, 0.14814122579991817, 0.1988857407723704, 0.16163339778300256, 0.1664953747944486, 0.18146484008719846, 0.14714289066051284, 0.12124354169974405, 0.16202955717040649, 0.16976482355065886, 0.2439605309477737, 0.20327833571260978, 0.1294989664588244, 0.16207345400846776, 0.1740811161336399, 0.10826398212943347, 0.12812904803262604, 0.14546488231468588, 0.17590543195124597, 0.16616532879491008, 0.15849389286050874, 0.2809116941305899, 0.10980931936853355, 0.06006193677744558, 0.1565195463838116, 0.36764246922346855, 0.350139229408195, 1.8330193118702982, 28.08549423371592, 60.982152031313994, 82.9354186211863, 109.86907943602532, 120.91133594512941, 110.32064622448338, 106.38808573445966, 102.88130637138121, 85.60001803982644, 86.8882106965588, 79.01068718202653, 53.30383393072313, 35.68688877167241, 45.31518574683897, 139.32624416966593, 80.13210065903203, 92.6614296820856, 140.83965147695235, 180.65120666257798, 132.30934358412222, 68.16767138819542, 56.12306887103666, 4.7743972270719475, 0.7064485922455789, 0.44168023993411376, 0.38406993773195053, 0.11841889891412952, 0.24751000016206698, 0.21015489413853616, 0.551704163512876, 0.2935153113738183, 0.3669314476991854, 0.7180816680192948, 1.3441683111652252, 1.0787007044399939, 0.9418623858401853, 0.8265978386325221, 1.238990935587114, 1.7564063519239428, 1.0234574913497896, 0.8310359391954638, 0.542901200392554, 0.749584184058251, 0.7041449965007844, 0.5823207141891603, 1.229849239030192, 1.3498865140061225, 0.5383286973641765, 0.636029422523514, 0.6033220033972495, 0.24507600093080154, 0.31471327067382876, 0.46557899624589955, 0.09602644766170172, 0.8547957578013021, 1.4548094258193047, 0.775830417631134, 2.368494546221149, 19.645114521826468, 61.64271054729339, 143.78530440791963, 178.39292557008807, 134.12430271025627, 98.05381790284189, 52.25371345396965, 54.93533203678747, 50.25286928299935, 58.04875258476504, 100.5547603484123, 104.03867229338616, 105.23195928142917, 100.63869907009988, 105.75517208345475, 112.57609536570888, 122.98435564964049, 114.6059689983245, 93.85180627146076, 41.60801249165689, 2.4645678554811785, 0.18164788913582602, 0.21423403654367695, 0.16909376117250613, 0.17713765373393414, 0.1371848814549946, 0.19541191507972058, 0.13656807342363944, 0.13622540229510877, 0.12982193380594254, 0.2013038973053617, 0.13444769526681594, 0.2608478820372013, 0.27675885406713335, 0.10939880349342862, 0.1866246107965708, 0.32161039089964283, 0.1678032554205387, 0.13057798597841494, 0.054132397091316606, 0.15913313194628687, 0.18622509594405853, 0.16176248359824383, 0.12944895623912736, 0.09230308414947602, 0.1670519070279214, 0.09290102343525618, 0.14790265069853875, 0.15695367308874286, 0.15821448527276516, 0.11658133743631265, 0.11474864827769418, 0.10989412530175141, 0.24388035218561852, 0.1338690690576069, 0.09561521932482721, 0.09845208121283401, 0.21204228963582747, 0.08881262668799009, 0.15488528165846102, 0.22379341955867507, 0.2044580038636923, 0.24291557169729666, 0.13338171456369663, 0.13048862948292686, 0.16505393439963942, 0.19677458631415523, 0.174744333771448, 0.19826026062571234, 0.2744295177680831, 0.1151298076635407, 0.24645652201387191, 0.29828586345238073], [0.02580715793996088, 0.045132315717637546, 0.08469948530076973, 0.03410085645173827, 0.045619528485281814, 0.011586692980340412, 0.05188396733794963, 0.031812496280537984, 0.06918201433314432, 0.07720162956825188, 0.023502024273658474, 0.06726861781170292, 0.05508949754819755, 0.06858553827529953, 0.020918658964576262, 0.022301974353350462, 0.06350491210938462, 0.03486425540740452, 0.008309362136999206, 0.041977309005995916, 0.06406763050284597, 0.018315503689190073, 0.08084790931353647, 0.09051324228846258, 0.08041285564221683, 0.0688970526079497, 0.06830618431371066, 0.08398716142701526, 0.056118993313923005, 0.0475159561592004, 0.054911608101740006, 0.033139044554123, 0.027905842401988568, 0.03852976779002817, 0.036141760647296906, 0.05900082456308508, 0.04464494207152917, 0.06382039477748257, 0.041884765584742835, 0.029508588354914423, 0.03227656744720955, 0.05475635272300532, 0.29639255375631396, 4.439819541669661, 37.58924222761585, 82.00892340752387, 88.38916055617794, 95.33235980618386, 89.40543882308468, 87.45252209324991, 74.60009959436233, 69.22806847480037, 63.49226105597712, 39.57985293480658, 25.81807794109468, 14.393185396348278, 11.434024803100094, 21.194574294551728, 66.72313305639452, 58.19553552135345, 69.62356105927499, 79.63815658323227, 78.5824663408341, 31.8142326801054, 6.586062542853817, 2.0314282395185965, 0.22163988511648872, 0.188039927593162, 0.2512969259893702, 0.08001517940072284, 0.16895977239454948, 0.07003709103070921, 0.14277660317959326, 0.3633994452895657, 0.1831027360693101, 0.23627012667636718, 0.15405769219561932, 0.12149035990718873, 0.37486272533574416, 0.06552237401446027, 0.30099490357022135, 0.0841893703346291, 0.07080184596200144, 0.0951361998675331, 0.06949455522361302, 0.03893927242907305, 0.16607721336185935, 0.041131004015164035, 0.23112218436454576, 0.1687706712513201, 0.062222293232597654, 0.07976882084603272, 0.20273720184641503, 0.2569660838813551, 0.4665615806175817, 0.47824288928701036, 0.36709119235315635, 0.4675090475188148, 0.1991396376322354, 0.48543323732672206, 0.19461233379139056, 0.5377364194681568, 0.1717676072111053, 0.363386329864302, 0.2785052280993231, 2.85742852957018, 17.390606749442316, 79.83729531688076, 106.28196208707749, 92.41604620410551, 65.94193812339537, 30.96462376656071, 26.117596011007986, 22.147210144227554, 26.944035483944802, 37.94296156975531, 73.88188223684989, 72.48391028373473, 74.19647985889067, 78.23519537525793, 80.4491929085024, 85.5687802837741, 76.56496386374198, 36.29702521908668, 1.8345153283688331, 0.3706282509430763, 0.056636979833485625, 0.04401405717456534, 0.1113111734570515, 0.07522895316322965, 0.08183002637158479, 0.018989216731560808, 0.055634186062360966, 0.07014296438184477, 0.051486053609199105, 0.05596315953880549, 0.036125967744737864, 0.04406910825280413, 0.024578498466120615, 0.021545169499492454, 0.06002060633393065, 0.032613753386202364, 0.045938381940246596, 0.07212137112454062, 0.08826129619152316, 0.06735189922995145, 0.048927653190349384, 0.008680743368102178, 0.03372522822070507, 0.035426946987788525, 0.047104754635403236, 0.04631557299064533, 0.018975925106074543, 0.003503810613408625, 0.06897812003209706, 0.0045809568086218454, 0.01995771849197486, 0.037565002623464794, 0.04471355290602773, 0.025783074050841313, 0.019146720578353253, 0.09016613551085034, 0.02120214788573644, 0.01437327364504698, 0.05692059707437312, 0.03674369508160218, 0.02250755787827075, 0.02044297773541222, 0.0491895288559458, 0.02291891645009239, 0.07465079426765442, 0.027894590485600695, 0.06973549753667847, 0.06773980785041087, 0.023004475064695846, 0.01443977294970424, 0.02235865145320854, 0.04241038617047091, 0.031993317928525715, 0.03236915683373809, 0.03470323521703963, 0.04321636429296867, 0.04309848634405963, 0.03636880229497629, 0.06853720578815668, 0.019241315200023593, 0.021145938099512172, 0.016257090554122004, 0.02049558307795275, 0.051407667492786725, 0.03110983852116812, 0.035780213112311984, 0.02053978252074411, 0.08902778248152426, 0.04004273398388778, 0.05754952461669042, 0.058701594450300744, 0.03940544459187696, 0.08292908675127453, 0.09834186414316778, 0.052559055508144444, 0.05385752091364515, 0.03550572380904229, 0.14370600572757183, 0.018262130343505455, 0.0667146749554142, 0.05245290253491652, 0.04496038260479127, 0.022198349470272664, 0.07131169279736858, 0.04698569308065119, 0.03437408554037252, 0.07357093205134715, 0.05174887156294239, 0.012043066878592776, 0.060380759588893385, 0.09357420787695916, 0.11157740433249744, 0.11428301237643727, 1.8514793342159641, 22.1548116976215, 77.85591002433532, 95.09285203872189, 103.58752912090671, 100.7367112559657, 100.23485183715822, 86.48832505749118, 85.11525231022989, 80.29813458842617, 53.698981346622595, 43.097089336764434, 28.04028891747998, 12.011410440168074, 13.891913352474091, 45.88678882968041, 64.4929910475208, 61.54383151761947, 58.32018844542965, 71.89684914004418, 38.353774932123, 11.429192443047802, 2.530123899059911, 0.14490772188911516, 0.10083681332968897, 0.09923083257050284, 0.05347145090420401, 0.1092966763122428, 0.08713784357232433, 0.09864135855628599, 0.3824237680002567, 0.5360496164329591, 0.6170866422114835, 0.21662029317550122, 1.1771762202824316, 1.8084744676466913, 1.0992497566246218, 0.707399154142026, 0.48739760933864507, 0.5250803405238736, 1.2802476508002127, 0.5036431166433519, 1.1838379982979068, 2.0105145294820113, 0.7391226712253787, 1.3655035534212667, 0.9947483157438617, 0.470742336924999, 0.4859599687399403, 0.6077755482927446, 1.117916193700606, 1.157175319329385, 1.3896441483689894, 0.3977214100380098, 0.4415780744485317, 0.06114353035246173, 0.3801890282380966, 0.31561274982748494, 0.31204333168364345, 0.061744675716205, 0.39657754883650814, 0.3790803151505609, 2.2542310001388675, 17.690193460833644, 66.13945299579252, 79.02113637616559, 62.61790198664512, 53.06418888030514, 31.214276744473366, 34.630327763095984, 39.947877160964474, 50.9841206765944, 67.65624138616747, 95.32122027489447, 92.47090447333552, 88.43765674098846, 89.08524005643784, 91.22568530421104, 98.07472413586032, 86.88002863237935, 35.55770943241735, 1.3309603424802905, 0.17496510498946713, 0.0770466806246869, 0.10425060837259216, 0.08092454874948149, 0.03092746746035353, 0.05529216610856595, 0.05353153901054494, 0.03366290696806485, 0.07421843722582826, 0.07103027805926339, 0.01775810003070341, 0.014574982680290218, 0.054079759190039295, 0.04746953123098901, 0.05985704273165715, 0.12928187246284178, 0.04214824620454062, 0.025320272674904238, 0.029560724468601328, 0.0551225082768548, 0.039941805730303453, 0.03407534955429935, 0.053731204506250164, 0.013094414344748423, 0.09334592133640282, 0.034902245707569585, 0.058278208298067895, 0.012177892607606709, 0.011291237765802972, 0.014535035025478612, 0.010513820358732296, 0.04547278817382552, 0.04775142094360725, 0.09478653435625377, 0.010114114941848863, 0.05413845684679766, 0.058839972912063526, 0.014452726538893918, 0.04361411331281547, 0.013205012543156985, 0.052218127229641524, 0.037289383340506785, 0.03914597061192317, 0.02539837342356482, 0.03735754218313002, 0.03078029622443982, 0.09020923561747037, 0.019983602687716484, 0.12657665512374333, 0.05976109404958064, 0.06069814981592279, 0.15863083873785314, 0.08798991720522605, 0.362317422705312, 0.08312004948815993, 0.1452649946534826, 0.14145338547325906, 0.09603452222842364, 0.0879183033060643, 0.1784374138280269, 0.1796525518500036, 0.13116695437460177, 0.1448867004364729, 0.1254937975036521, 0.19100347744120708, 0.15173882065761476, 0.1620929892505369, 0.15320707412977375, 0.14239556636781464, 0.1003788076641579, 0.11797393972594893, 0.1440744174103583, 0.15027418312045837, 0.18447299157419514, 0.3193354468432165, 0.18612574966203782, 0.17951549872034983, 0.17526907335606315, 0.2065221818103906, 0.11673783387748465, 0.11336641881855265, 0.19884178264727517, 0.14930558751427359, 0.1134725756222202, 0.19100652647114572, 0.15108347840366826, 0.17360117737083666, 0.286297935752138, 0.12330771198556309, 0.11781167464270709, 0.16324933768520433, 0.23813020347827868, 0.13672671491099944, 0.32436662203361916, 10.345473923990804, 63.70333556205996, 116.12528339509042, 110.81426082118865, 120.8511354077247, 110.29199723274478, 108.73410240296396, 101.791789608617, 95.40792034518336, 89.52973088910504, 63.385525518848056, 42.962555962224165, 29.42315386187646, 20.952756251058272, 37.61789121935445, 97.85982531885948, 75.82995876189202, 93.16844309529951, 110.61967988168041, 116.00754953199818, 45.68410035102598, 12.167509986508279, 4.323293768590497, 0.3397640087191136, 0.2607290158348699, 0.453387595592968, 0.23907679703927812, 0.236049953006929, 0.4152163148166672, 0.23363173518690372, 0.43223128083252144, 0.41938030912030133, 0.29990485238452114, 0.24517894782606633, 0.6028541381801329, 0.7564746239973653, 0.4621939907871908, 0.4387312610783885, 0.21456143187899746, 0.19730081210934347, 0.5004629630955958, 0.1793759175005459, 0.2321705450454066, 0.4991927586736218, 0.2173337661811421, 0.5626434700623636, 0.6971148834113152, 0.31390207549256666, 0.17816084076560315, 0.3190365193351623, 0.5025096129505865, 0.5252129043782912, 0.7610690677838942, 0.6080634134911722, 0.6021014721162858, 0.2836806729676262, 1.1767388760082185, 0.8420676053051026, 0.864238802704119, 0.23003879814378678, 0.47317411450128405, 0.5515651032328606, 5.262851455519277, 25.10681494589775, 118.73096096900203, 144.00676142784857, 126.65175607127529, 92.65972737343081, 45.71215314249839, 40.50794847549931, 32.58365461903234, 39.21476656390775, 55.877905045786214, 99.39901044291835, 95.5006451760569, 100.251827855264, 101.43181800842287, 101.5299713996149, 108.88599226551672, 105.18463196293001, 58.46380995165918, 5.731726192658948, 0.7507733976648701, 0.21754165180027488, 0.1120256347161147, 0.3143920346854195, 0.18082272051082504, 0.14033478985150016, 0.1071338109191387, 0.16431295883751687, 0.20657663534004844, 0.2623378617628928, 0.10354926253879264, 0.20939674288515123, 0.15874193680863227, 0.11249985080212356, 0.13849731264335496, 0.21025031805038455, 0.17207428752895326, 0.12361287544932097, 0.1442422366310512, 0.13078354269025788, 0.10576162487268449, 0.13559760856291941, 0.10948331831323524, 0.09536790316023173, 0.1450261897257259, 0.18130462045871443, 0.23194062673757154, 0.18432145938277247, 0.08474517478457383, 0.1312557286432674, 0.10149012545063611, 0.19672673646240466, 0.11418506037443878, 0.21503671282722106, 0.10554914272600606, 0.12255305409311287, 0.18961915656203226, 0.1217478956846941, 0.11530731789647572, 0.1373667354064603, 0.12294409601318261, 0.11115090786329201, 0.12402912166209952, 0.0893393810838461, 0.19431242569079324, 0.1143560205556212, 0.18875680202918668, 0.14591403966469152, 0.18951236390538756, 0.09384711903910484, 0.1426623335048076], [0.040039244453392686, 0.04811561531237057, 0.022280518145811175, 0.04043904658887656, 0.0802229960719424, 0.031956562945138545, 0.007620885622717681, 0.02930345682186946, 0.03063246806813104, 0.03668159599446001, 0.04196499414261311, 0.06103193049409217, 0.0297886049825578, 0.02171100455246145, 0.058346516527836366, 0.027480832143356244, 0.03680574054258966, 0.03962863281729721, 0.04825431553106155, 0.051122686615394014, 0.06666330109921194, 0.03823481627830094, 0.032780304731380557, 0.024806438351891218, 0.013213605176837695, 0.014227209406183853, 0.06809919501744932, 0.03633388017694797, 0.033873209594598705, 0.016858574911771763, 0.03829686940016766, 0.05333047540437791, 0.07560131019882618, 0.06846899331937875, 0.06130162791739549, 0.018668877066022927, 0.08090027908404028, 0.04453866652423336, 0.0774945203034628, 0.10603308046777403, 0.20441455135662712, 1.0486359822173272, 23.571003060187063, 72.86059118086293, 88.55994055348059, 90.44260763352918, 89.50252532958986, 72.02323575173655, 76.6412147398918, 76.00719498049828, 47.078518636765025, 23.82384884741999, 18.38136019245271, 17.581673245276175, 35.005965309758345, 52.100313478900546, 76.05465565958332, 72.07010807529574, 45.49421056624382, 54.19336865025183, 45.570920359703806, 34.745943546295166, 4.831367692639751, 0.18832550984957527, 0.054468935686013395, 0.2671177907576484, 0.08903701384101184, 0.07977834331893152, 0.1682493637406057, 0.0960670196781716, 0.09699001007022397, 0.07636817953278942, 0.17775433919122144, 0.41214574248560015, 0.2886567511145146, 0.3182153037238506, 0.11449026214259286, 0.11934655478164075, 0.2607846338181727, 0.44843030192198297, 0.3839488958399142, 0.5939206949645474, 1.0592181692200324, 2.726374052224621, 2.1818206146840127, 3.511905900893673, 3.2257756158228847, 1.178563145860549, 0.1277186777142267, 0.2087696692756107, 0.18416614271700385, 0.311978796436902, 0.21172122218676154, 0.3956155262647137, 0.5435330084254665, 0.18438023364832326, 0.1689858347057335, 0.13832973857079783, 0.10827878294813056, 0.17484904266893866, 0.06137536388010748, 0.10974438575607155, 0.28070016193293756, 0.32632262836540904, 0.2786992322052679, 0.03745995281684784, 0.11475854613367589, 0.753954868883856, 15.097718584922054, 45.455790950405984, 80.49732823525706, 92.6434495372157, 73.93235529622724, 54.69927987744732, 30.314008458968136, 26.65685130703834, 16.83930193224261, 32.05966714889773, 41.8328349051937, 48.26898936302432, 67.15053019985076, 76.35314802969657, 85.49647531201764, 98.23912635926278, 42.95791579831032, 5.806732696871604, 0.46419154972799365, 0.04772455424010273, 0.05359401348077002, 0.07869304953924111, 0.11493100784718992, 0.08694701107038606, 0.01796658511363691, 0.04069002465375009, 0.04359416438326721, 0.04526964463894406, 0.07335099586916548, 0.05254912317820615, 0.022047960665076975, 0.06355230613882024, 0.01938583960215892, 0.020965989791758118, 0.003958911369291825, 0.03606605966905913, 0.04394012202899303, 0.06282359181392579, 0.026580207688253255, 0.06676927404177767, 0.020645477756437276, 0.04310178435257366, 0.04039441430640798, 0.03670097801894431, 0.010615063665975488, 0.025252035308268764, 0.036127637816412796, 0.02768438936571681, 0.02728486493710549, 0.011094402964977969, 0.07786382064824143, 0.0176865091141794, 0.018552349347080437, 0.038422117114908276, 0.03154264372443, 0.05150475764587041, 0.04579789673669204, 0.05046152975410224, 0.03381003415392291, 0.00930628384418425, 0.01111456448392522, 0.020426638995207125, 0.11672541559223207, 0.0455253494663104, 0.04781654607805033, 0.043684647028003974, 0.028986924613315253, 0.05152240065076659, 0.07382009448784013, 0.06430884477712455, 0.04344044118038109, 0.04313402899330662, 0.030189192358164058, 0.05247266377292333, 0.06444556082809164, 0.08415272834921077, 0.06600460338015711, 0.051029082162365805, 0.09625334758311511, 0.03879262787860729, 0.01531685360767428, 0.01918883817721038, 0.041965821517571326, 0.04482267830040186, 0.01670994619358211, 0.03322508005845932, 0.03377398971708552, 0.0671084518093736, 0.07846008986234665, 0.049405374128611824, 0.06830236919584774, 0.05134801222612301, 0.03481921326789645, 0.01963345262582504, 0.07591917540036863, 0.04347789521899916, 0.10388727585274367, 0.01661421393134421, 0.01118975792891316, 0.06468939129263163, 0.018723878348546646, 0.022454157719508778, 0.03716477147874333, 0.06093876654162042, 0.03889390087175754, 0.0418000515820759, 0.013103384276731841, 0.1303024701173267, 0.10694032009210318, 0.6412547550374462, 12.213945946385785, 59.08328556245374, 94.50132723777526, 101.33147593467467, 98.32529298720821, 85.58538759908369, 86.70142742895311, 85.16844749450685, 62.09716812256844, 44.54120797495688, 37.340611027133086, 30.786434412002567, 25.75429431853756, 28.941618204116825, 37.45566591139763, 49.097896006799516, 42.93222427368165, 48.76854635054066, 51.365010276917495, 41.29781184657928, 6.370477311072811, 0.47077497227057336, 0.17616694372507835, 0.22421190274819253, 0.18727246071061782, 0.0463568574688848, 0.22891384399225637, 0.18322034588744565, 0.45301028196850135, 0.510879858967758, 0.4943575794177671, 0.6011690511818856, 0.6782428283364542, 0.43171858415007597, 0.7325883089534698, 2.1545461685426774, 2.8810326178227705, 3.3302717247316918, 2.3939306264923466, 3.9157474954282088, 5.386538005644276, 7.734581068638833, 8.476471401030018, 7.535262396258693, 7.57954546520787, 6.382485647355357, 3.005943928034075, 2.514235603232538, 4.36569360956069, 2.8658964364759387, 2.2624613585010653, 0.9512444501442294, 1.5735430030092117, 0.4373904846368298, 0.5369518228596257, 0.5321018734285908, 0.3185647011043564, 0.61846376186417, 0.7233837931867569, 0.43535189402680247, 0.34231456056717907, 0.2183481585234404, 0.291738661546861, 0.05733343419588863, 0.12669429558539583, 1.3672724197949133, 13.89379216778663, 44.85142430951519, 64.71161611618535, 68.00678360846736, 50.77841981764763, 43.277581122613725, 31.127013814064767, 36.733232005949944, 39.1332204880253, 47.67149863704559, 53.920250092783284, 63.89615143499067, 81.49193148459159, 82.9748619756391, 96.12215257460072, 110.89801126910795, 46.30874564570766, 5.338134486829081, 0.2092920033441436, 0.04802899375077217, 0.018373419936265678, 0.13149534562422385, 0.035015370080908464, 0.07984578203890594, 0.014660569065580926, 0.05112849739229968, 0.016232606384061998, 0.048698803575168696, 0.058054391880549734, 0.06882530847384084, 0.015325271956352218, 0.041507670295334635, 0.013791627134196462, 0.009379476842079914, 0.03209783913447492, 0.04301107571189923, 0.020331557907704866, 0.005858609041634707, 0.03200241139218692, 0.0482639720693471, 0.06594687865506257, 0.05107014064466761, 0.03752052355858107, 0.004883362834657273, 0.06568634747377326, 0.054261383315127705, 0.05497146638170366, 0.07489775803180472, 0.011762960235618297, 0.012403191405258352, 0.02692980808205903, 0.041364936623722315, 0.018128139650328987, 0.03145031480779571, 0.08029812631467659, 0.12150165204319263, 0.011882823309861125, 0.034643714015762654, 0.0308028077180948, 0.07123816367839614, 0.035678553244759964, 0.06357108295384435, 0.06264016355177568, 0.03854180686175823, 0.03855695242002126, 0.02915210466110899, 0.024726158083086053, 0.06493635505678193, 0.26196725906864293, 0.1127576700321609, 0.15078033741203048, 0.23762216461041283, 0.17895982450535222, 0.18909075507713904, 0.1389378438433332, 0.1131119627145029, 0.1805599983180723, 0.17015951204924815, 0.13981650072720744, 0.27146393012615944, 0.16092953151993214, 0.12106446098656425, 0.20771844342591303, 0.13465974840425676, 0.2540921203551754, 0.16071533333630333, 0.14876328919443393, 0.1984296120222538, 0.1328833437254352, 0.12442974734210199, 0.28181310382581526, 0.12014777549812872, 0.1489297141351046, 0.10749564956753485, 0.1784749981015921, 0.12125308715528059, 0.1822505705058575, 0.14433173102236566, 0.1823705705183168, 0.2060691480554881, 0.233993987522779, 0.16404446034181505, 0.10093182355405823, 0.0888269295495364, 0.21941144259706621, 0.19492068418091346, 0.17341196897529787, 0.19639820731695623, 0.2870299480855465, 2.541718670437413, 44.64142845522973, 105.32884182468538, 116.98687122714136, 107.44400347432783, 109.49326930507537, 92.7274117931243, 101.08038148572369, 99.8905461834323, 66.42433474140783, 44.5541557188957, 35.01362962107505, 33.92849022342313, 55.753495308660696, 75.39506204666631, 104.60405841950448, 104.84478996646021, 64.16289614092919, 82.98888052663496, 69.92505012019988, 55.676911031046224, 8.642275871769074, 1.0614870152165814, 0.4145741186315014, 0.3856679052114487, 0.5212997885481004, 0.2462686466113214, 0.35929811697813774, 0.3091534028851217, 0.3313739976334957, 0.2498488359513783, 0.33135714369916147, 1.0737586405969437, 0.6200297681554672, 0.46359182545734995, 0.30420827469037426, 1.2780898569091674, 1.6253735701883993, 2.8190876062839263, 1.4293290963096004, 4.156601371303681, 4.777491486841633, 7.6214927627194315, 9.767086121343798, 7.592142647312534, 10.454220656425724, 4.189629199043397, 2.201322639180768, 0.5570108852078838, 1.6276872782937943, 1.6328271766824107, 0.7998887653793059, 0.33657015751927133, 0.6434841321841364, 0.251052835054936, 0.16651875579789763, 0.13970793074657842, 0.13565547884471957, 0.24082064298131775, 0.380470703446096, 0.3889312252642647, 0.41376298473727324, 0.657849629079142, 0.6413333250149604, 0.17093284716529233, 0.27456447181682436, 1.8978373369862958, 23.60735166457392, 66.56834848465459, 118.54634284973146, 129.53678484885924, 100.34293666962655, 75.70055976990731, 45.66674386301349, 38.08950916413338, 30.343436041185935, 50.445791059924716, 60.793493870765936, 69.27295607905235, 92.94571522743472, 99.10563284350981, 107.07710496840939, 122.36524874164213, 70.07510431351201, 13.874520582537498, 1.5918614523064707, 0.18637095908484153, 0.09388137849107867, 0.2768676079088642, 0.13148757749267165, 0.2917585491893753, 0.10394053428523964, 0.18717469256972114, 0.1691401094919251, 0.13859216965013935, 0.2234410650787815, 0.1301611881823309, 0.181554211904445, 0.14251412613497627, 0.14726382530023976, 0.14516305899427784, 0.11325074720286554, 0.13150916585037786, 0.15785114509203743, 0.19488234914118246, 0.17902301143734686, 0.25334582814285833, 0.2902040035734254, 0.09989245674542843, 0.1318310147091266, 0.13335421200721495, 0.1651862990711966, 0.0976473824571698, 0.18536284866352237, 0.16736903678505652, 0.1064725238228998, 0.06136298006881149, 0.13822484581220534, 0.11847522169832261, 0.09567092157780163, 0.09340208324213183, 0.20405067491435236, 0.19761887649374624, 0.10747666590877118, 0.19065415666949367, 0.08044250324488648, 0.13154887984837257, 0.09771727265850191, 0.13708217970786557, 0.2335001825685463, 0.08488394395117799, 0.17846568247243283, 0.15881292251569612, 0.12684112399696343, 0.1389142943005408], [0.04556809717248525, 0.040544180665165186, 0.04105806478389329, 0.0456798387571208, 0.05035745287914911, 0.01909590788155554, 0.09845961951800893, 0.012866420832823121, 0.05505370975081479, 0.030121981549347122, 0.11345001433285014, 0.003944122041913591, 0.028756615600638816, 0.03711496044190661, 0.040947330604878165, 0.010846507446389767, 0.04926470123351582, 0.04902164068733973, 0.018717837745263692, 0.03955835957200297, 0.024385993977287607, 0.03260457182242986, 0.02561434127029873, 0.031750533174002366, 0.05308348099671064, 0.08501022588461639, 0.06289032190257023, 0.03585846133289799, 0.07476929274778213, 0.0700718637615923, 0.08975024169851696, 0.16680098258920256, 0.015043815083411193, 0.1434770220470044, 0.0374426047558025, 0.031829660480481484, 0.09357515782598527, 0.02567418805894352, 0.08116496246187918, 0.26075696272234766, 6.609331023308539, 57.31888578784082, 97.22504461965254, 96.27551724833828, 90.10682136781755, 71.11011582036173, 54.32203023664413, 58.128666954655806, 57.244894196910245, 35.37601740129533, 23.642717715232607, 15.942463759453068, 25.995449481471894, 44.10432261805381, 61.31513380235242, 54.335801678319136, 47.44591136132517, 42.42189645767212, 39.00206819657357, 25.415121086182136, 4.054654312710609, 0.21719397045671943, 0.13308796581001053, 0.08506976623809145, 0.0209326075104576, 0.17290049803353127, 0.049481312594106125, 0.1527813131049756, 0.2738818261892565, 0.14174351829194254, 0.1824972354957173, 0.2798296409028192, 0.36574854665706236, 1.3743482530117037, 2.3820463351665007, 2.1690189790341163, 1.946325186760195, 4.340239878623716, 6.6360369709230245, 5.094472929354637, 3.0802277355424823, 5.357306051638819, 5.703745965034732, 7.539670159739833, 11.048388154275957, 11.252638716851513, 15.243562113854194, 7.9256205981777565, 5.139559593892867, 5.484768863647215, 0.43265921754702447, 3.62110419619468, 4.7890629691462365, 5.384742050401626, 4.88933983349031, 4.709946801585536, 1.6336539387702944, 2.805167849986784, 0.9765845549202735, 0.7743635124737217, 0.28241414576768875, 0.2025012774092536, 0.25428656879211625, 0.1353555094570883, 0.20034306983072914, 0.07858117771965843, 0.09950682340610413, 0.09180650595695743, 0.32915758269448436, 0.22736547304497612, 14.075813678003128, 48.291617516548406, 84.24163849123063, 81.04402818987447, 76.12989456422868, 69.31624335627403, 51.64125496341337, 67.33398729755034, 65.17633853420135, 29.226662728094286, 33.6329553204198, 67.16945955830236, 76.56635238278297, 81.09176343487155, 90.19086207112959, 70.70393869953772, 33.12047412318568, 6.751264929771424, 0.3657452065137125, 0.06399893156823612, 0.04528117043176486, 0.07707713261967705, 0.03246006082683321, 0.012811070022683953, 0.04163429696833895, 0.01358545946723391, 0.0212273579241047, 0.031080685045209624, 0.036822720881431334, 0.050884797162706816, 0.0762357535741983, 0.024752210818171024, 0.02851345546303257, 0.04498984251591948, 0.02388777252617142, 0.08397170177270329, 0.06388149795032318, 0.01486978863531183, 0.00786755635823694, 0.06400556205922077, 0.023091694174875176, 0.02684787689377704, 0.05699226843012918, 0.02263432819276087, 0.028494619276194323, 0.058728288784022295, 0.07611785264265153, 0.03925662435170624, 0.052941337212800026, 0.055523038195866736, 0.019594106350033995, 0.05796545290298039, 0.01804300812974332, 0.030262047319763133, 0.048344974376020894, 0.02684363468189634, 0.022557202290983933, 0.053718705781765526, 0.03831398380439609, 0.022407707893439842, 0.01724734729636581, 0.043224147746279355, 0.08085177039667484, 0.05120514831956356, 0.027178765590032263, 0.017485792162798105, 0.06625440933050648, 0.007190693258082555, 0.022864464835654345, 0.03039232631694646, 0.01812090586510397, 0.027638650086197643, 0.012590751754150037, 0.06155050690135649, 0.03840183110667333, 0.014715418088129692, 0.04751993598596704, 0.0656930124387145, 0.014202294311666442, 0.048068860966351726, 0.0280982262319735, 0.013506385786909492, 0.04884008167972488, 0.0455828367041484, 0.02645017958486513, 0.06422686953878691, 0.06473446024521705, 0.05945737849199965, 0.016652106555298935, 0.033834131449581153, 0.10857167368334149, 0.04636942897172225, 0.04317753895696613, 0.027341252838772152, 0.05100369783899477, 0.060482113021275694, 0.06695552533792873, 0.12576331489629325, 0.015492229328130283, 0.08745462858989354, 0.05226798040131408, 0.047865797870702324, 0.09637069693135639, 0.0032157431198884885, 0.09422178199935345, 0.0878199912427414, 2.216735347624748, 41.387461539237734, 102.21864546498945, 110.44955884256672, 104.58809437290316, 84.21214226753482, 71.7059003153155, 67.17142858812886, 73.74521117056571, 64.372899839955, 43.94735720849807, 27.18708319048728, 16.411124237122074, 44.27929955144083, 64.44118438228485, 51.11754794274607, 52.67674499942411, 49.13256975912279, 46.9312414815349, 34.750171861340924, 7.084725229970871, 0.18332280248643892, 0.17369114673666416, 0.05474025338527657, 0.0863833772018552, 0.13378083105048827, 0.04769867962046016, 0.7439666145270871, 0.9726494983319314, 0.9510369935343344, 0.8439318343035637, 2.9816156721884206, 2.233248771198334, 2.801399923140003, 2.7631607363300943, 5.494168333468899, 6.490215015026831, 5.880999344010507, 8.637772010218713, 11.075250506401064, 10.735009408766224, 11.873650916161077, 12.179036851852173, 11.059896388361532, 13.608352465014304, 17.123865965873964, 20.75715941767539, 20.172386976980395, 11.539579706807292, 12.912863281465347, 7.9850925553229555, 3.699202998991936, 4.3811918747040535, 2.1326740518693, 3.5096461253781475, 2.301229820136101, 2.3470833080430187, 3.695114418383568, 1.4912667534043713, 2.6433771896746854, 2.4851436288126054, 1.1260591567524019, 1.1081964378395388, 0.27644261297199035, 0.5699178732691274, 0.10364916806499805, 0.07180701460569136, 0.08509209004020499, 0.14256959090069418, 0.30325280983121167, 12.167595298059526, 42.86139411310996, 61.36193944561867, 53.25906791994649, 54.122134485552394, 46.90802105011479, 35.04266300509053, 62.34349689176006, 77.58654517512169, 47.80820108229115, 50.912674703905665, 81.25408680208268, 85.88763759982201, 92.67944120591687, 101.86423578569966, 74.48153418879356, 33.12245099775253, 6.412404996733512, 0.22164370023435165, 0.05508322328809769, 0.09338670785749152, 0.03267270002153612, 0.02569087536915416, 0.029596851259890585, 0.03686693181554156, 0.06881188661340745, 0.0281147277658625, 0.017895584084814595, 0.0705702499216122, 0.04035928151420048, 0.04138291287686556, 0.023326804643617045, 0.07875248264040678, 0.08086789654748094, 0.05274953560963754, 0.07892544231107158, 0.03756409863971415, 0.03664983781955896, 0.05400264861002084, 0.03731956720472344, 0.04474994974331029, 0.012868782298849716, 0.02578502949026804, 0.07516623354486882, 0.06541466205230644, 0.0536140734930673, 0.08368281767733636, 0.008886330723462087, 0.04781828509763845, 0.04201442979636692, 0.05326792815580003, 0.015324276042050652, 0.06468500926970475, 0.032791252127818526, 0.01659418647778371, 0.035511373707483855, 0.03735366194779354, 0.07435696124429665, 0.04815073278281958, 0.02108958658702191, 0.04537973913454241, 0.05966955803394799, 0.03880105101533475, 0.020122902370208216, 0.041921177743783886, 0.016208717847363125, 0.13705314497553533, 0.11671701926858195, 0.09191674600926139, 0.13833609710056938, 0.137801474981731, 0.1361504329308387, 0.1557741428334867, 0.12457911150469897, 0.18893798182327903, 0.0801311651124589, 0.27657977335395356, 0.11107655136936134, 0.09773421086250775, 0.0949424255879656, 0.12974342511546227, 0.10772634928505267, 0.1444419557529111, 0.14440403440065924, 0.08612260853330936, 0.16797283664345744, 0.11396781316087132, 0.1517954039117021, 0.09206465460480222, 0.1747287821865851, 0.22855315447574664, 0.20483217652766936, 0.38006587194338926, 0.11337088511115122, 0.13740435032354248, 0.15074453046244962, 0.26486408265848316, 0.20473486803952726, 0.19365642460123186, 0.2298698297912075, 0.11817998673406341, 0.1062993496476162, 0.2955800102603051, 0.15821373450659937, 0.2529060477090459, 0.38270994780525086, 14.122709535783338, 91.28901589301326, 132.68094893424743, 117.65119521848618, 112.0729180305235, 92.11310586621686, 76.443707712235, 81.391785529352, 79.02085396551317, 54.01787396400206, 40.73706588437481, 30.295063411035848, 48.02540625295332, 69.7680062632407, 83.19808406214561, 77.37720043428483, 67.87552541302097, 61.910941831527225, 65.11043879293626, 43.579050571687766, 8.400126387996059, 0.33911102601597387, 0.45983909779498655, 0.11999000735100239, 0.26248902623211184, 0.4998961806056961, 0.1265559937324255, 0.40215546565671123, 0.5346067357928522, 0.3758016426957423, 0.531428757934801, 1.6513025207865624, 2.916798014794627, 6.2454149896098725, 7.646666534485356, 7.69586923622316, 6.749608708966163, 12.0634259716157, 13.54403441952121, 15.237523624973914, 10.399055461729727, 13.702532495221785, 20.696596061029744, 22.1317599281188, 29.171622068651264, 30.416788285778416, 31.28587765078391, 31.170356004468857, 22.719125055497695, 15.56296758113369, 13.953149395604289, 13.681322278514987, 17.690995585533884, 16.27509447836107, 11.428097121177181, 13.399952034796438, 6.04275151606529, 5.310136118242818, 1.9320594038694137, 2.8602080191335375, 0.9290680433473281, 0.6601284648622237, 0.387355167899401, 0.17706478345057658, 0.3174769175389121, 0.21028405656256985, 0.28019236821320753, 0.17599399171529279, 0.5106996138009333, 0.83894012796302, 23.16078393690048, 71.72508855019846, 125.3669523423718, 115.68898247134302, 108.90527463728382, 95.19211938304286, 70.9576689812445, 81.30634846225863, 84.07776971017161, 44.557925116631296, 50.29898458911527, 92.24379924035843, 100.06794714158582, 104.04153562361195, 115.10677722192581, 91.94631099700929, 48.05080752218924, 16.331641327950262, 1.5220599333124778, 0.2657553187060741, 0.1328076695602748, 0.15551917345052765, 0.20168419867273302, 0.10756426806291265, 0.17657474764893133, 0.13367324166240233, 0.15148948968177842, 0.08451423757979948, 0.1251398418999968, 0.11474584439589132, 0.19628177727422408, 0.12582608047992955, 0.11088473827488, 0.16659107449794971, 0.2976225538840217, 0.16045512391194222, 0.10565863201214422, 0.09193593651176461, 0.11409275444044222, 0.1077983002629011, 0.13189237835186143, 0.17243457867974238, 0.16450665650829194, 0.14969509725849475, 0.1269346863151558, 0.14740408067741703, 0.15621168629056023, 0.1189943994846075, 0.10286048054695131, 0.16969189198026735, 0.12239961434275874, 0.1013277224715679, 0.09959254098395187, 0.12773439783843296, 0.12408979582570254, 0.12346307461660717, 0.1487737692772381, 0.12447929790904447, 0.1611998073396183, 0.14658507139932725, 0.09949855731740113, 0.23070063682333117, 0.19649239016636727, 0.09516436125962965, 0.2240473317402986, 0.1738060139600308], [0.05780744343815793, 0.08985092863440515, 0.040935877590410175, 0.06298140975676718, 0.0282320981815217, 0.06380336464292581, 0.060491126045704856, 0.04807935637091437, 0.03127667906453773, 0.057266604515814015, 0.03354907779383563, 0.03593136609021214, 0.01704973300107785, 0.05048266228949351, 0.03315718934660958, 0.030148639493892272, 0.02487449377264467, 0.00954950048077491, 0.009776974968131511, 0.07241239260521627, 0.015840220937295067, 0.02463870914652944, 0.019403752653048407, 0.009231144025351011, 0.008198471867569513, 0.02614671875151896, 0.015449952766028865, 0.050957744054856806, 0.055507980737715006, 0.0308628709265782, 0.10396714817972914, 0.031433468534340786, 0.026561553447297024, 0.08313835132867099, 0.021737675903545275, 0.06650511160372727, 0.031033289100554202, 0.047106930325108196, 0.30318661983455386, 16.09652367330367, 84.57285127332135, 105.82572767811438, 97.46767459377166, 77.76191434552594, 71.0123860451483, 47.04009902092719, 23.45962932032924, 11.854555837569698, 10.586485920413848, 16.5109936652645, 18.232341504866078, 50.51551118973763, 45.05041399309712, 40.86178548874394, 38.212589217770486, 46.21094134546096, 38.90233409020209, 19.33104641975895, 3.5985326718899513, 0.31784460909904977, 0.23719238928489147, 0.092985860011991, 0.0820475876812012, 0.1036813744013348, 0.06216156544283994, 0.17395020702913885, 0.20522177820244145, 0.0542212211556973, 0.4191660802931555, 0.9804669659464591, 0.7686632054467356, 2.1721823705780894, 2.1509218985034577, 1.8761739639505264, 1.6327414974089594, 1.0370136316745513, 3.293333293930177, 5.543971648139339, 8.059208191210224, 7.790805793577626, 7.3024868869012405, 4.903433890111985, 5.7999621956579155, 14.7867020868486, 17.20196035600478, 7.292620655029052, 8.178079051356162, 10.55543839931488, 3.832493962780122, 16.388199944649976, 17.727710931531846, 5.354007828620173, 7.629165899369025, 0.37430164254000114, 3.390390382659051, 5.423212657051702, 6.030445079649649, 9.037941040531281, 4.437432289123535, 5.609602707047617, 2.1012114949764746, 1.7539609992696394, 1.2884042195735441, 1.1868578556083864, 0.751421814483981, 0.2963111032882045, 0.12332363895350888, 0.027775898568272114, 0.12456536788733737, 0.11900975188661007, 0.20569480685216768, 0.05679256463002774, 14.529498546354233, 58.17511958460654, 70.69845522603681, 88.68067110738447, 79.00192460706158, 45.72979204116329, 45.28084539598035, 35.74581846114128, 20.449761306085897, 27.2901552338754, 55.269996504629816, 63.043745871513124, 76.34212616951235, 89.58737404115739, 86.99270263794931, 56.30800077992102, 19.811827021260417, 5.0256073859430135, 0.07300496927552647, 0.297366711160829, 0.04723623064496825, 0.015518559770087804, 0.06745162089505503, 0.05889847138596158, 0.08185708459707038, 0.05018270822362073, 0.04143601426133706, 0.021868073644356865, 0.08124786083616557, 0.06023249476246777, 0.007315578038669042, 0.012655477565262589, 0.03406069429230786, 0.046259165936780554, 0.030250640270570596, 0.05279763827040311, 0.033641016005628535, 0.04487325925560248, 0.04071147511562994, 0.040898481008386424, 0.06015958234427437, 0.10937575956866627, 0.09741504331149402, 0.027534056101895632, 0.035214177558138486, 0.030399117686395204, 0.018923538098592433, 0.03042606865957139, 0.055000332574690544, 0.03873325606447555, 0.026915024500340227, 0.028146439975488092, 0.02074308118843023, 0.09913934635058527, 0.02078470657579601, 0.09984630760886978, 0.033568264465899236, 0.026569417339839765, 0.01928954618051648, 0.057446734769450086, 0.024027677418123332, 0.011104682907311907, 0.005327294507409416, 0.02481475040586966, 0.03840401828769715, 0.038678434812614036, 0.03715924032393002, 0.02456900280629916, 0.09295513988622735, 0.06850645501887606, 0.041509194810303955, 0.02430195796243366, 0.043066291499041745, 0.011807158720799753, 0.03766347173481219, 0.017434979466000394, 0.07473458896481222, 0.03397015419097678, 0.06696961369485625, 0.05951747425921983, 0.03374756351413746, 0.13189567252993584, 0.042932976878458456, 0.039792215571768826, 0.04590077468404367, 0.079503133893013, 0.03520264410443845, 0.009897140647104431, 0.10459220697802883, 0.04504646790484267, 0.02532541504009597, 0.10199186707576437, 0.024313014526400837, 0.04606947873628909, 0.0992215552457398, 0.0456416645958539, 0.040194541966963204, 0.04501400492905129, 0.036906982892222946, 0.03833498227440062, 0.0641038932747418, 0.10862170688567624, 0.13866649550055304, 7.409607796899735, 77.24224736613613, 117.30105307794388, 111.05498452340404, 93.68266582489015, 79.55075048631238, 55.81478234260313, 46.038498263205256, 37.58146808993432, 33.662118142650975, 29.558726664512392, 27.97508735810557, 46.07107746985651, 47.97199926068706, 35.18943025219825, 34.62631125603953, 49.00427295315651, 49.09209089894449, 28.6811787082303, 6.094786169067507, 0.09998387401743282, 0.414905620198096, 0.1869911991900975, 0.13862616863221894, 0.4957630136801351, 0.19887466314098529, 0.8084757529920148, 1.1436415487720122, 1.8274387597076356, 2.793267869180249, 2.9201109467014192, 2.784696754909331, 2.8351443188805736, 1.9964101766386342, 1.1847098676427719, 0.5555699657528632, 1.8178266238781715, 3.298013662138293, 0.5031861911617941, 2.7648608386516575, 10.2631776948129, 7.745441131053433, 11.082043070946971, 15.237061765886123, 26.11804316120763, 22.528307630169778, 15.712533439359358, 10.302821090144496, 11.151589635879764, 6.407577049347663, 7.050886942494301, 1.4094712392937754, 1.6232014351314115, 1.7267287186076565, 1.7752496633798847, 2.3173301691009156, 0.36864901682542217, 2.09099494641827, 3.882230106861361, 3.084774498016604, 4.732690665029711, 2.8961788502431687, 2.390101412611623, 0.851037391731816, 1.1347901076078415, 0.6412842341007725, 0.5458733763906264, 0.3226901458636407, 0.09009416921124344, 0.07245217555112417, 0.12624175978764413, 0.12079180263343359, 0.24817396856604085, 15.77311444667078, 52.00487044549758, 59.056389870182166, 58.83775695677727, 60.14075656091014, 51.1317547675102, 49.77358702690371, 38.060263972128595, 31.402154353357133, 46.109901089822095, 70.0650316669095, 77.2753913940922, 87.9245714987478, 102.03114048127206, 97.11762659011349, 63.85406048067155, 19.33038942275509, 4.462082914767727, 0.035820585945921565, 0.06436982537589728, 0.08730910252779724, 0.002699630164105686, 0.02760636139540903, 0.053088433755141114, 0.0636569116144411, 0.03473410856038813, 0.03365531886717485, 0.04308424859998688, 0.04064980503772536, 0.018697653243678714, 0.0454059929677075, 0.05646171040772911, 0.051734878967005404, 0.06433851536243193, 0.0037684066093436656, 0.013760546947108402, 0.028048342416783976, 0.026785176427614306, 0.023199471254502575, 0.025285522926658876, 0.019557397331922285, 0.0427499852864252, 0.006496174225298267, 0.03534210658061408, 0.025718234284150026, 0.036720122556172075, 0.045711210057620084, 0.027122055931437402, 0.056927495696131265, 0.04668139529624774, 0.03313841636202509, 0.03240487951364729, 0.08150444666464483, 0.022024903333775943, 0.048133863526726925, 0.00856335571546468, 0.03355889904102491, 0.05417684168224374, 0.02948933273493763, 0.053456914385840784, 0.04447800768238883, 0.05992230193148698, 0.028035303600312724, 0.04995875007983658, 0.0725892210198987, 0.16363117122842422, 0.17189935901232306, 0.19202605160253663, 0.1856418732073038, 0.11404506546715576, 0.14285016294208266, 0.16901848537306632, 0.13694603056196245, 0.12452573815901434, 0.10403894593999272, 0.1371548814518798, 0.11453327031866198, 0.1557856341523509, 0.15894838218246737, 0.16146196262730708, 0.16747877121933047, 0.24264687401873453, 0.1326993753712985, 0.10448261810046051, 0.15220547545581095, 0.1825287523529222, 0.1505962158403089, 0.07986510277635629, 0.16103568066272045, 0.12014949919595835, 0.14479959623948221, 0.1880495036922155, 0.20157276352326717, 0.1546439486405542, 0.17514694361917435, 0.1011228169344606, 0.2361540796775972, 0.26600405213332945, 0.10377171148936595, 0.18242030494636108, 0.07495447918171845, 0.21006654887910814, 0.6018156293899782, 37.635082967819706, 126.15916129081481, 128.90870355790662, 118.89475914739795, 102.53572986971949, 95.9657206073884, 64.1862028644931, 37.46018448183614, 25.37239666908018, 22.106213531186505, 28.824284422782164, 30.589619682681178, 75.07770307602422, 66.65076532671529, 62.05779929314891, 54.48792688308224, 69.79304667442076, 64.14087595478182, 38.106457725647964, 6.86713174466164, 0.6008323402174058, 0.5287101263961484, 0.3640519070529169, 0.3747972707834936, 0.4859260157231362, 0.2586055426828323, 0.4063078767109302, 0.47557632108369186, 0.9816279875174646, 2.012230076136128, 4.9838522845698945, 5.066319136850296, 12.066408934131747, 9.363370287802912, 8.198240034041866, 7.502326253921756, 9.457717018742716, 14.260229795209824, 22.543567611325173, 23.7234498993043, 20.151370917597127, 19.08642976514755, 25.669206342389508, 27.455765547290927, 36.852158269574566, 34.250552115901826, 25.312307919225386, 25.07438478931304, 30.608896170893026, 19.62056244573286, 40.01096064044584, 44.38355615062099, 25.250809077293646, 28.52479773183023, 13.81953581686943, 22.539427549608295, 16.820898171394102, 24.339815070552213, 34.74258599742767, 16.743913812022058, 20.521450465725316, 11.263871404432482, 8.034487943495474, 3.602460925617526, 2.3425313974580457, 1.7235417928426497, 0.8052135054622928, 0.2391627367826239, 0.17388176473398365, 0.35358987328025604, 0.2720970251867848, 0.23970033132260848, 1.0866031771705997, 24.067369199568226, 85.69111900944864, 101.13988384123772, 129.22967110910724, 105.79199529463246, 59.81314843700778, 60.431368889347205, 50.17022886583882, 33.73204223571285, 42.88092751656809, 76.85632536488195, 89.6479981945407, 98.69011263693534, 111.47307780481155, 114.05383263864826, 85.4214168364002, 35.47038570527108, 10.981513704023055, 0.7191030164399456, 0.4024248528144052, 0.19575490796517944, 0.10874577482501346, 0.16429202931542553, 0.09922740815748131, 0.1538515685787124, 0.1176309698231278, 0.0747639377931914, 0.1425822466732033, 0.23186489128537718, 0.13943515748025911, 0.13015631586313248, 0.08971998122550788, 0.13332185245329334, 0.14562193033916337, 0.13452435002451943, 0.2088562218892959, 0.11829942750233798, 0.17974915553725537, 0.13266804237519542, 0.1052284659817815, 0.13471087711232324, 0.24718819726859373, 0.14185051013144756, 0.20970858663560885, 0.1900476601815993, 0.09901862621547715, 0.11032521829850252, 0.1633362580210932, 0.11993006097092745, 0.1327567553568271, 0.13839145461397787, 0.1690074690287152, 0.1588151748141935, 0.186392807912442, 0.10483693376544023, 0.2775463618097767, 0.128877040960135, 0.13003043229541472, 0.14814822784354612, 0.10695146667140146, 0.12651806471929436, 0.09674466275159391, 0.1261208021652795, 0.16906700938219027], [0.038156119896279234, 0.031179908753162434, 0.030351809841851075, 0.055168174778021155, 0.029386060252305002, 0.0455841428840593, 0.15441061358057684, 0.07081713707697007, 0.026579880185665625, 0.0794128044658611, 0.026019745423728903, 0.0571731954152065, 0.036193019590310516, 0.037987438826671535, 0.04907738124471038, 0.04306163368446212, 0.04724583355709911, 0.011141954042438057, 0.025543397698070736, 0.059320451766853376, 0.0352927130616961, 0.03668728036685817, 0.01672800480117721, 0.003235979093005881, 0.13358720998850562, 0.08651237874742478, 0.03224980416557482, 0.1162755381195776, 0.010041434265252565, 0.00435884350032035, 0.024176959226268436, 0.05167955209711387, 0.02217556218496494, 0.09706286503182304, 0.024008209208747553, 0.10062210952803012, 0.01696722533163284, 0.14223577574856822, 36.53326172982493, 109.04028261861494, 102.86997856632357, 90.33195757096814, 78.09180921123874, 65.16426940118113, 46.50030636018323, 24.8741203354251, 32.839793236024924, 73.59558059323219, 45.68157434463502, 41.652064631062174, 77.3851393115136, 76.35315587443691, 58.96482213850945, 79.1778507540303, 58.947089102960405, 21.909902826432262, 4.810737986718455, 0.3609576472832311, 0.10243868785760096, 0.07508214007342055, 0.10951744753026194, 0.09091452680407994, 0.10865153068856848, 0.09711829149314473, 0.20685362208995128, 0.5136048643579406, 1.4903467124508274, 3.0259198238772735, 4.791849322857396, 5.980648138830739, 8.073154178357894, 15.611140170404989, 11.122518989347643, 7.78904612025907, 5.746602271833728, 8.496412730986073, 9.208046390164284, 3.336169008285769, 6.009900194983329, 7.546337208440227, 14.736424165387309, 13.101152739217206, 6.589538253122761, 7.457856382093123, 7.323216122965659, 15.323913828019174, 16.2524349458756, 12.061053918253991, 9.669644640338037, 11.583070947277932, 2.419907013254781, 1.9572195699138029, 5.70768500528028, 21.483962843495032, 47.7882440628544, 55.72266155673612, 58.75348091125489, 43.44559584894488, 29.528169439684962, 23.024805168951712, 22.565452475701612, 5.052580054729216, 5.552190974835427, 5.360607706731366, 4.366108890502684, 1.308698807993243, 0.16818435351935127, 0.1265175361186266, 0.1136937835103562, 0.45713367361214857, 0.13816853834977075, 0.03416031253554168, 0.5465703325406198, 0.4871075378069955, 16.407723542182676, 57.60413623625233, 70.36264542610415, 68.7807378461284, 79.41032178940313, 66.40808043941375, 39.41690198836788, 20.569626977366788, 19.065851050038493, 44.30230425250146, 64.39740680879163, 62.280680133450424, 77.41559259353146, 85.46593573785599, 73.4939206031061, 43.196607712776434, 12.91769858329527, 0.9383951944689598, 0.2521630956400787, 0.09029060947678744, 0.04033167936628865, 0.03669318690475437, 0.08654507538003307, 0.048099826240251144, 0.10799749078409326, 0.00515979464961997, 0.06331212991367906, 0.06938111292378557, 0.028364005115544124, 0.03240535831859997, 0.031662057679627216, 0.08021201803198746, 0.04114099380169665, 0.015673194617603817, 0.014153965654963208, 0.08323579005176023, 0.023237921207422213, 0.022558948971451293, 0.04782800292295795, 0.036515213188625155, 0.032923015420355146, 0.028827436598798925, 0.026504359238090056, 0.03184103114049762, 0.029492148108059363, 0.03084511875415281, 0.039030260691839846, 0.030953072034002795, 0.06140851633503072, 0.036398361797534654, 0.029259144381109266, 0.04997433613865607, 0.04790602514760629, 0.01688077230937779, 0.03510284583054243, 0.08532610691843495, 0.023311425428537112, 0.06359530282357047, 0.10620475311072604, 0.023131015552808682, 0.025811647215197166, 0.03127065378301327, 0.11582109476289443, 0.0010151511284470138, 0.028891826288834698, 0.02820337563002062, 0.038202755498669805, 0.06373216443124317, 0.030093033001908374, 0.020724446099672108, 0.03569324681114766, 0.018522219109018485, 0.07108888378547085, 0.014148982253015764, 0.03464940987947968, 0.007088347741838305, 0.05676510420838191, 0.02966517481141754, 0.010862402813208681, 0.010070325356096992, 0.052466925774370475, 0.0570620896835481, 0.06114501656303483, 0.03655363249802782, 0.06890113585658612, 0.02676852742179988, 0.037152514071954836, 0.0690115061438372, 0.03655691135434374, 0.08902658738436238, 0.03442879953992463, 0.04035719009416719, 0.06363334291945062, 0.042903417375900095, 0.016412916668360273, 0.04213814150481936, 0.11032479695014416, 0.025765490417759267, 0.1842568934925141, 0.1738137667698245, 25.424166071799498, 110.81918731812509, 119.25416592628726, 105.91789553242346, 90.64712785905408, 73.06862585006222, 72.34054765393658, 43.549048362239716, 35.818986354335664, 27.75149460761778, 18.22995670380131, 39.092086592028224, 47.45609775666268, 50.435255573641875, 48.89857292175294, 54.12548026730938, 57.98238215907928, 31.80068285234513, 8.189349491750042, 0.4023886321773453, 0.336094570135878, 0.12955604000918328, 0.20635689067984783, 0.13051784807635894, 0.5116814627282081, 0.45347808589858396, 1.2996121471928013, 2.0490512035546766, 3.3729912388709287, 1.365265637155502, 0.532878012426438, 2.686481096090809, 5.511893033981324, 11.991564227688698, 13.340465368763095, 9.770738828566767, 7.129882006875931, 8.546965218359425, 9.169992535345017, 4.925132441905237, 0.5682592009825091, 4.025646669249381, 2.0001757745781252, 8.490209502558555, 12.847778412603564, 10.03693832505134, 8.422837891886312, 8.558189080607507, 5.491654584484716, 3.8874441625610476, 2.4037615570329853, 1.635940190284483, 2.289111412340595, 1.7874193071357667, 9.09175301751783, 30.558917330157374, 57.62047290802003, 66.86941392960088, 70.22553505436068, 54.96024300975185, 40.86540191404281, 29.133496630576353, 25.80361027871409, 10.941932086021671, 5.057147164498606, 0.6196049877232122, 1.168636730121028, 1.3256134164910163, 0.06550918964128341, 0.11529128367622053, 0.3102506859408271, 0.47690836412291376, 0.15109555194935492, 0.038295609185532216, 0.4402071141427564, 0.5554692098690618, 20.178660808071015, 58.605125104227376, 60.86674413373394, 45.52755071270851, 48.17439356157857, 48.90300912241782, 32.36659653725163, 35.677251508159024, 38.064115739637806, 60.71301075720019, 79.6053812580724, 75.511030843181, 86.40093465005198, 95.48063324343775, 81.61794939348775, 46.831158284218084, 12.261131078966203, 0.5632962995479184, 0.11603107946293971, 0.09253557651273667, 0.046584615408773386, 0.13617358410791044, 0.07237702232575224, 0.023102141698942553, 0.07827527115061399, 0.04447464455640124, 0.08722946768806827, 0.051787114672122464, 0.07530212222087769, 0.029578888413286018, 0.04690725333808411, 0.04565140923425075, 0.07168790325522423, 0.01784085859394362, 0.00562143492354681, 0.059250170860679886, 0.06462359200081517, 0.03902706993563522, 0.04649718562441488, 0.010195911107134196, 0.02675036347711519, 0.05946554115883285, 0.010132437849777841, 0.08076666568916652, 0.024324540319221637, 0.03608163423655975, 0.03125428056885158, 0.0557331990961346, 0.033462077018714724, 0.048311350777024226, 0.04313694778829814, 0.03859201243387596, 0.05745617680311684, 0.0407132945744501, 0.05050325090245855, 0.03942257048742425, 0.1461389017922263, 0.08179690839061815, 0.05541615360867112, 0.017455805566221956, 0.03419317387705369, 0.058445200143802556, 0.178210498584855, 0.10524778671923185, 0.07103259930567396, 0.13948198077419113, 0.09256481808880646, 0.2828338393761266, 0.2725586084829223, 0.229177761282171, 0.25339144101787, 0.13592036140541877, 0.11743728747411121, 0.17347685662248444, 0.17443575355554783, 0.22587025327788246, 0.21673232587354802, 0.1360194625393037, 0.13948037198955013, 0.12123735170931586, 0.085245399555612, 0.19700761493896285, 0.13708944222138775, 0.08371069561690093, 0.19102558673870182, 0.16202162049951094, 0.22042580429584752, 0.20023894316006094, 0.1286841400208012, 0.11697525984697765, 0.13941926881670952, 0.14758219611981224, 0.16040886752307415, 0.13916940157932622, 0.199668177012955, 0.19996810043531082, 0.20634588965725517, 0.27115219362801124, 0.2407313937381391, 0.6479865228456836, 65.36441618396391, 144.88432115124118, 123.74814310381491, 111.58148427163403, 107.84278300500686, 85.65453114048128, 66.64609770621023, 37.74854536979429, 47.1542086139802, 96.71167696675947, 62.85603692454677, 61.31224693790559, 109.44950349869268, 106.78673190455284, 81.30801154721169, 111.43621536993213, 87.22882147758239, 36.192537200066354, 8.716639107273473, 1.0243391053330515, 0.33989084223585747, 0.3042048426164735, 0.39380820227726815, 0.27127568700140525, 0.34489652202014004, 0.2701456153825406, 0.5022863749294512, 1.1634099267182814, 4.324161592991122, 10.484731793403625, 16.015089384971127, 20.658529458507417, 20.95537247196321, 29.099874073459258, 20.533368587493896, 15.054807855236916, 12.343411618663419, 15.457747059483683, 15.451848795337064, 14.00410000355013, 18.247846634157245, 30.922324926622455, 34.10382017012566, 34.93312689565843, 24.927392005920414, 16.521884126047937, 18.79256186946746, 42.71887087052868, 45.26949405670167, 31.522641720310336, 34.64038079784763, 32.42855821886371, 14.611168176897111, 7.030810290767301, 9.334894860944441, 26.128439403349354, 53.059199625445956, 63.35187942750993, 65.70289319561374, 49.23004850264519, 36.616808214495265, 29.21262456524757, 35.344324650303015, 15.645111818467418, 21.429379140177083, 14.811246318201865, 11.12760434227605, 1.8825473251842686, 0.2765509990915176, 0.314571421833769, 0.3802421028094907, 0.4603450835472154, 0.28205288934611505, 0.11574561978059432, 0.6587990878089782, 1.572920939614696, 29.038865527799054, 86.05972766876222, 97.36740312268658, 98.2805230540614, 111.27611990897887, 97.14194528518185, 56.326812467267445, 34.897766728555005, 32.955565914031, 66.19628029484903, 89.7234881308771, 86.77765477088191, 96.00843521856494, 108.58189875079741, 97.14269838025494, 66.18491326608967, 25.35716610570108, 4.970622620274944, 0.8861637488007547, 0.20121264091182142, 0.24414180267241695, 0.3448829162986048, 0.17837750575234815, 0.23857977451576343, 0.2094800472860375, 0.19513247684846002, 0.23426617856227586, 0.10429874167687471, 0.1762928426145546, 0.20710226358665576, 0.10928729173517036, 0.1758526025279876, 0.23085736309088048, 0.07282413422100006, 0.11312197548367324, 0.16190065521626704, 0.13464793532846436, 0.12003290061388286, 0.2992845969575067, 0.15617322867676137, 0.09047107680911019, 0.12637501312119345, 0.11247378849093953, 0.18933481536805633, 0.21262951135154695, 0.1679233780070659, 0.22042808723786186, 0.14046093388911218, 0.14049899313719044, 0.10799045809694838, 0.15311134378275565, 0.1241198571158513, 0.1273858737981608, 0.09825688200972735, 0.18343140311058492, 0.1515039993870643, 0.20339070548934324, 0.1829870261492268, 0.23731539236201396, 0.11350626050825081, 0.14685917765863482, 0.2034392754637426], [0.047609403564204136, 0.07532278361219553, 0.05577649838561493, 0.05617156992816637, 0.04774855577477044, 0.06907595712090693, 0.05685906106185529, 0.031082207644959132, 0.029445723179847966, 0.09532027547397921, 0.05802865898717315, 0.05936881106707358, 0.0895983724284076, 0.01748911123873005, 0.0324089972362403, 0.041927919317517555, 0.09832908579659078, 0.0044921241257519975, 0.04257098118203782, 0.05075377697545675, 0.08148131080933156, 0.05660451302725462, 0.035052571310511524, 0.026405175749753273, 0.08341135442136757, 0.0812946688083391, 0.046471146295868584, 0.024698712983198708, 0.062495242699139544, 0.03422389783325695, 0.10324798314081085, 0.045411305787462386, 0.05016691149062207, 0.009437079950716467, 0.04933919562327285, 0.0867190233041202, 0.23621473851944172, 40.05105118597708, 115.60563994992165, 97.50681200335103, 86.34312675845239, 72.1060291413338, 74.768353585274, 43.17707823168847, 17.188863561999415, 20.773864792239284, 127.98713484118063, 250.02158657197032, 120.75550017818328, 61.76791652556389, 70.00665110926475, 65.44929627449282, 54.78359514667142, 19.771603115143318, 2.5308286999502494, 0.8338275023045079, 0.2537842142966486, 0.03115807716254025, 0.030066597222861265, 0.14603851363062859, 0.02290127727563583, 0.2194982403588872, 0.26691673864280024, 0.8152879906758186, 1.9449109271649394, 5.108802328186651, 8.0670573442213, 13.531319076015105, 22.937053903456658, 38.844275166911466, 70.24447225755262, 89.05873267881333, 99.38268553826117, 103.12148878651281, 113.6200341870708, 120.66712917820101, 127.41268019522391, 111.19296566132577, 64.73188692523588, 32.13551990447506, 6.170073613043755, 3.75215107394803, 13.479572226924281, 21.967077255249027, 13.018211280145954, 11.362708268627046, 6.573077046102093, 6.882099509239198, 2.5124820586173766, 1.3978318509555634, 4.1123320306501085, 48.78457315506474, 118.74732509736093, 148.37438337264524, 157.02374304494552, 152.1012783050537, 149.8773414857926, 153.13695661483274, 151.76026744227258, 142.31363111926663, 129.38240035887688, 124.68606810415946, 97.21274406679215, 76.63399757877474, 42.7600283007468, 20.246961039881555, 3.9314614909310497, 0.895530613920381, 0.5950489892594276, 5.986361561282989, 6.262910231467217, 0.16403920497865448, 0.2985332179213724, 0.06243527716686649, 0.4301586452751391, 1.0381239075814526, 20.39657396654929, 57.86753516043387, 69.296553058009, 69.06595691557854, 73.17125858799105, 49.242945255771765, 27.361485496644054, 19.92373028109151, 37.69882932786019, 47.9791065954393, 79.94667453150596, 81.7355969644362, 77.23762681407314, 80.58333012365526, 57.73791651571951, 39.230718843398556, 15.890362916454194, 2.0501130627047632, 0.10777681915750427, 0.052098969913898945, 0.062401665059188684, 0.035620954924172936, 0.027289530412564357, 0.1262473752121291, 0.033941422063376636, 0.050994271127086495, 0.1047840583769064, 0.04145600915616078, 0.05077925705981832, 0.05221796252073781, 0.031397904817675876, 0.04432629546030395, 0.10262408113527684, 0.026188776978561958, 0.08018861404590069, 0.04093364827455052, 0.06646367390790293, 0.04422688789124932, 0.025213464696501053, 0.07011009920989314, 0.03049754274768695, 0.044641429558396346, 0.06991706803561219, 0.034885931865222035, 0.05195408736565902, 0.012425758440287845, 0.04426161848729657, 0.03458095992344522, 0.06046748840280118, 0.06666965962898347, 0.02209067198207542, 0.027306683121188998, 0.035081801395262444, 0.03265176283856554, 0.01943566596075412, 0.032308965305527376, 0.047298111397052006, 0.006483757855265492, 0.05207772246531902, 0.028760306229214036, 0.03088367404416204, 0.0716310212268464, 0.023945470438188603, 0.019193411722118338, 0.05441456642602721, 0.008052241004582855, 0.02335126774625913, 0.05520694265742937, 0.016165403236124306, 0.04475689049990428, 0.057544977884859815, 0.11547305335801457, 0.03494764407796245, 0.04384401246845242, 0.035888112766007264, 0.06439589534796054, 0.07724155040998613, 0.027450374402706663, 0.03992588259279728, 0.04122091209395759, 0.016102009460390095, 0.05587007602556579, 0.05090747336526552, 0.031264532740498265, 0.09385558431066814, 0.0693147543877844, 0.04213521887938823, 0.019986492754410834, 0.05040912934008145, 0.053573827063965226, 0.01751385779390412, 0.03938268411964659, 0.05510290791731208, 0.09709232877339087, 0.040735664341839097, 0.10778346113980779, 0.6396601889883319, 33.64746024531703, 125.99597500216578, 112.31344561423026, 101.23897075653078, 82.04735479047223, 89.0366497347432, 59.30082413458056, 34.99515525756344, 30.116185680512462, 86.12719243572604, 185.6217125923403, 79.49874770256781, 42.51832008361817, 59.12276814060827, 57.89102623539587, 56.954595658086966, 31.06268302086861, 5.086149169552711, 0.5669663510014934, 0.5159981536769098, 0.06088892103082711, 0.06713204731744143, 0.406587039150538, 0.14922142509491215, 0.8019477032846021, 1.6821410530997862, 3.212474858568561, 3.8425229730144626, 3.902779159045989, 7.377091348171235, 13.989426416735496, 22.862585744550152, 44.603977664824455, 76.68558459128104, 99.302716255188, 108.39171871062248, 113.14986751925562, 126.50056439061319, 134.87245559692383, 141.1153627211048, 125.72305648557602, 77.04428534353934, 36.71672667226484, 7.9803646283765, 1.6380863396390792, 1.8871823409872672, 5.005180172381863, 2.063544729063588, 2.0313010076361318, 2.5625682742364946, 2.2880089811740385, 1.60908286369616, 0.9303095960809339, 6.966487832607762, 61.51932847115302, 131.27280235290527, 160.5879851310484, 163.29528347138438, 160.24156139742945, 155.98214980094664, 161.19712921880907, 160.24582893617693, 150.44602240285568, 138.44604861351752, 137.17984476397115, 114.20713455446305, 92.41221012607699, 57.850210051382746, 30.893570030889205, 7.597629552887333, 0.5458893723064854, 0.7340428954170597, 7.216116786003114, 9.377718317893244, 0.0691910848141678, 0.22969024345999767, 0.0859339976863515, 0.3948579878816682, 1.2204039265071194, 27.328043368554887, 60.34062877778084, 65.11024267442765, 52.03248393151068, 50.20163136143839, 28.66000379285505, 30.437239523856874, 38.024876348433956, 58.721470448278616, 68.79878074892106, 102.04861071801956, 97.19338324762161, 87.28989278116535, 89.23261919329244, 64.2146949614248, 38.006068583457704, 13.877550613495613, 1.4820795818682642, 0.09194845438844736, 0.0730506664202098, 0.036469466248226744, 0.05034515333752479, 0.02393699176008663, 0.07443662672754257, 0.04372918354948202, 0.07359348567983798, 0.04644991033860753, 0.016521609223057187, 0.03844451752581424, 0.05483632847186058, 0.09007749147713186, 0.032306283997792395, 0.03262181263116579, 0.036317179460198655, 0.09018628362325892, 0.12773995197588398, 0.01660241426209048, 0.10445204353140247, 0.03526208869692299, 0.09730075065407062, 0.0016792428246962148, 0.015140019447332429, 0.06637434039505259, 0.014592246471663878, 0.007308556364038058, 0.058920511735543135, 0.01801474331577699, 0.01765965198677394, 0.08165714330971241, 0.057489965111017234, 0.029765492109882257, 0.010690900624819822, 0.0220549990978813, 0.035999524932835376, 0.027261552881569635, 0.023917012187021396, 0.039265606732618426, 0.042269058270199646, 0.021911033939930703, 0.01879999109904372, 0.14643879457106515, 0.1466967210534119, 0.1452378598192046, 0.13973043840979377, 0.1250926815273781, 0.2719015808355424, 0.2202312945718727, 0.1540696431672381, 0.07900809553722221, 0.2243790937767875, 0.18930158247390103, 0.18390985566281504, 0.18816170492960563, 0.19013651105905735, 0.18685112767402204, 0.1454602551436232, 0.23569430434896102, 0.0779764432339899, 0.14438270651284726, 0.1366256985573038, 0.17296460427103505, 0.2105040770144232, 0.1333993039424381, 0.19073559181584468, 0.15175003618482621, 0.15281630800135676, 0.1332730373307582, 0.11753346215212539, 0.11265843866332886, 0.19953985728563803, 0.134308175334046, 0.11161096664446016, 0.10711883390021902, 0.17309577384543035, 0.15179846826339924, 0.14280980543023156, 1.3612091709529202, 77.10270512488582, 146.55305431735133, 115.73072433471681, 116.16427959934359, 94.38268338480304, 93.64394418654904, 62.6729053835715, 24.708804199772498, 33.55664953108757, 146.07592152011011, 251.1270360023745, 136.6671282245267, 91.15795381607549, 106.46432876586915, 93.57504383210214, 83.72183815125497, 32.84436083609058, 4.95492333366025, 1.3393844904438144, 0.6123201044336443, 0.11784310723024032, 0.14172805863763058, 0.3137086842569613, 0.12487896597914158, 0.46499710650213305, 0.6310517509137431, 3.5568329739955167, 7.008169879836421, 20.17501300381076, 27.041796638119607, 23.676948239726407, 32.24502463494578, 45.909562110900886, 80.48190547573952, 100.70657176356163, 110.048214081795, 115.5265178988057, 131.94479850030714, 137.86341974812171, 148.12521872981904, 126.5461580214962, 79.79749894911244, 43.97990895855812, 20.754139192642707, 22.023355422481416, 38.62070398945963, 43.17408154087682, 41.575084194060295, 26.466441808208344, 19.39040953113187, 14.857995087100615, 12.051926562863013, 4.9614879104398915, 6.094177711394526, 61.119960584948146, 138.1690194529872, 169.2835189450172, 172.8177470545615, 170.16746428705034, 170.68153012183407, 174.16404570302657, 170.2930272010065, 152.4566136637042, 133.9971394692698, 135.1321949497346, 109.22365342417072, 88.80143304024973, 51.69578767591908, 27.217454102731523, 8.98913008551444, 1.3861556903969858, 0.6609054005915119, 8.049666045173522, 7.087311542803242, 0.22328533472553377, 0.4464313640229164, 0.33341678640534805, 0.6167249874241891, 2.6295878521857725, 37.07518815994263, 87.24004730101555, 96.56545885147588, 95.68756180424845, 102.55651058689241, 64.48009821676439, 41.70855068391369, 34.77736565374559, 54.87929705650576, 67.04337104674309, 104.94781494140626, 103.32698175984045, 99.87367214695101, 100.42600462513586, 82.87224492719098, 60.70492675227504, 26.059109549368582, 3.7954329579107227, 0.3314442019308767, 0.14974141493439674, 0.21259373504548304, 0.09418761447793055, 0.08494438828840371, 0.23296309364659173, 0.16321397506661955, 0.16672184570662438, 0.2556205270511489, 0.10392783254745508, 0.10557262332088525, 0.20165608324591192, 0.15677877521562963, 0.2042600773875752, 0.11683162602205431, 0.13603456979317052, 0.3387991669437578, 0.2320834561701744, 0.11208739672457019, 0.11439848480926407, 0.20065287578730814, 0.11759248156581195, 0.10248780175442658, 0.20601806531269706, 0.19478396812994636, 0.18877180203074412, 0.1771664586398871, 0.14191279307969157, 0.17705897650411054, 0.10379084070483524, 0.24103687895882517, 0.1583048683260718, 0.1223118742927909, 0.10951528716231547, 0.13148711783991707, 0.11996848794120936, 0.18668218996495972, 0.09542601092928842, 0.07966146894520329, 0.13263459497642133, 0.11246030534347219, 0.1249364915213758], [0.025664824549289002, 0.0405095688127462, 0.09331148568420641, 0.035764764949318864, 0.01571361820453838, 0.020663612972824805, 0.02407050173309061, 0.13553653603359578, 0.1071500979484089, 0.07097629950411859, 0.06984636578108035, 0.013844249713715288, 0.048487030059820226, 0.06438652609264658, 0.032618231170119784, 0.022217225876726934, 0.05412268309643673, 0.07366817925245532, 0.054481112653569835, 0.04662952348289471, 0.004435197568513573, 0.05654337155001779, 0.013949163539725688, 0.018898956252322085, 0.014399852107969985, 0.07421147348659654, 0.01819154300216225, 0.08204778686406151, 0.058345225669683955, 0.12266634317535548, 0.05246505268939561, 0.12469619272216675, 0.03582592940919342, 0.005423688956896865, 0.049673305719249675, 0.5085787147043214, 40.686459464411584, 100.52499740354477, 104.00019384199574, 96.08576866888232, 76.2615293072116, 54.410593432764855, 15.384478165257363, 25.379853094777754, 51.96907097293485, 130.1720440772272, 89.43380540417087, 58.77177484573857, 51.30940283498457, 75.59863305860951, 54.412499704668605, 18.615388408783947, 3.577073874973482, 0.41418678457698516, 0.10850038154110794, 0.06257156803903562, 0.13769918692208108, 0.09187287981471709, 0.11134288183623746, 0.1449837024894453, 0.282406484888446, 0.45208230434406194, 1.9227720893198446, 2.6728555175565907, 14.299950657352326, 24.54941672663535, 38.54326463514759, 55.53773357022194, 83.70557600452055, 121.2379752435992, 115.39959784476989, 119.49355602264406, 120.7250782751268, 119.70067285722303, 111.30818920750772, 111.31001703200802, 111.4374783731276, 123.03930805575465, 135.20559034039897, 137.20196693174302, 97.67776458494126, 27.375092198771817, 6.055412926981527, 2.857487855419036, 3.694553029152655, 7.691040798541039, 9.614680467113372, 23.291975452053933, 15.197296777079183, 28.662541566356538, 94.91222689228674, 140.9932985613423, 117.65168159238755, 112.99214116988645, 106.54956971445392, 113.16037162657707, 109.3810110707437, 112.82767618856123, 107.65295597814746, 117.03162547080748, 124.22170654419931, 132.79064978322677, 129.64962359397643, 138.31052287932366, 145.66341369382798, 151.64242375281552, 119.25513867408999, 60.5651609359249, 4.299194726251788, 5.5257689087621635, 22.44141536374246, 0.06301838115999295, 0.004787582213119154, 0.08552585668381184, 0.17321736732077214, 0.07183867701960188, 0.09554241032850358, 2.940699712884042, 29.328297222814253, 64.75406792856032, 59.3770710883602, 91.00778979639854, 68.19854828619188, 30.837578196679395, 15.55732427104827, 10.88481649275749, 13.784882656989561, 38.362686557154504, 65.02347200147568, 74.08376662961899, 74.38755419946487, 72.03350451684767, 55.46616992642803, 27.596496266703454, 2.8918583594983627, 0.37608595324620125, 0.06395569356578974, 0.03799776952233046, 0.06757252489126499, 0.007332075742118422, 0.01898362237449375, 0.048479733072341456, 0.05416425868808743, 0.048734576050792976, 0.05424865859470541, 0.04676178856302173, 0.13294075435448077, 0.049558863674681035, 0.058083863282996806, 0.009401879168205686, 0.0731756613259354, 0.04283838417200793, 0.07490085302701882, 0.0828017246338629, 0.002514317086259384, 0.050165026914328344, 0.07915886930159985, 0.02902941759525528, 0.03878979718372707, 0.03566561785015849, 0.026888575314754443, 0.04773683462952895, 0.02851277172956015, 0.06674727965747157, 0.10340165271754227, 0.019574440873017716, 0.03762669951444672, 0.050887528266156876, 0.046471548492028836, 0.05449489840576726, 0.012507158155072362, 0.05918689199813432, 0.010886829526674364, 0.05643533783093576, 0.0479468691252893, 0.014456797338601564, 0.03663058603002179, 0.02707630133015975, 0.0425874061071344, 0.030996453677934986, 0.046034721327164484, 0.09355658019382147, 0.04896102014989142, 0.04771885837638571, 0.12404892503494218, 0.04817091153874513, 0.03514953888952732, 0.05943553349483879, 0.052113192336213206, 0.015062850453109752, 0.03310899858573272, 0.008362808261036633, 0.038731888597530705, 0.07605535518978873, 0.05138137535522542, 0.052139591726083914, 0.016836530731750593, 0.061041564049739996, 0.037371864196874445, 0.006353119275562706, 0.03998717728761896, 0.012070997486702137, 0.03610852775314162, 0.08453984789910816, 0.13932471824509485, 0.043337410015444604, 0.06831337021844042, 0.15415328464681102, 0.03956942954250882, 0.019540654480337136, 0.08008038114395835, 0.21950072248376187, 41.12810265633368, 117.99379856355729, 118.91670873088222, 108.04364758153116, 85.48780687393682, 71.77920941383609, 48.959051947439875, 40.61200111143051, 24.925472005721062, 55.132529197200654, 88.23589001932453, 95.50538339922505, 61.10721288188812, 45.01548920908282, 48.46973626844345, 27.268091901656124, 6.281678282445477, 0.43930297717452055, 0.18238458992733111, 0.010332408823042868, 0.14765704291001444, 0.16889497667791384, 0.988902758446432, 0.46700854695612387, 2.2662596837166817, 3.2732416881668955, 5.422758152407985, 5.631468449869464, 12.303919234583455, 25.149961017793228, 39.926582613298976, 61.40310079820695, 96.28966915992, 127.32882776568015, 124.16977436311784, 123.85301943748229, 124.99358977040939, 123.21078623494795, 117.43672001746394, 113.02179428838916, 114.18931130440005, 126.33459321914182, 140.51244735717773, 147.1281365425356, 108.87417024181737, 33.02039484823904, 3.0589785402820957, 0.4139468764826175, 1.8639479361234175, 5.721358387700974, 9.974249043772298, 24.750369556488533, 19.182102257205596, 36.779296321253625, 104.80563686740015, 146.16505345990583, 121.8729442165744, 115.21556023628482, 111.5459240636518, 119.59352939359604, 114.43471831660118, 119.41947029482935, 114.11498238963466, 124.16957824460923, 128.9717438913161, 135.57766637494487, 133.30405665982155, 144.12586027576077, 155.59739666600382, 162.9942023369574, 133.30885764091246, 76.4963851436492, 7.802797459786939, 4.9292391634756525, 22.693645338858328, 0.10980350476118828, 0.10655593547609546, 0.10528432145234078, 0.025013956248820312, 0.03810640078999343, 0.017591734461846854, 3.6173725512719925, 29.609670408310432, 57.486159186209406, 48.277053756098596, 60.170472437335604, 48.7929238811616, 30.988106996782367, 28.46566604029748, 21.01316075171194, 27.51774095719861, 50.040437636836884, 76.82637414624615, 84.90017306420111, 85.23592795095136, 82.2828931193198, 60.628244415406265, 27.028062458961244, 2.865923647919009, 0.1567516250595931, 0.04007099113697487, 0.04790231728205278, 0.0528559452223201, 0.03625268251785348, 0.014787610383674264, 0.027495680842548612, 0.04751009175614004, 0.05235580089051397, 0.090594784687123, 0.007359148810557541, 0.08332667872309686, 0.02331698722686739, 0.026166424448151263, 0.05466549469518566, 0.040374775642469045, 0.045709130128905665, 0.042531945171856114, 0.008597743487165821, 0.004358293832234678, 0.018976275591299902, 0.00846584038358302, 0.03195674297580075, 0.022019891203531337, 0.03965504752892641, 0.050069603002479965, 0.007459049548713431, 0.022906735652096333, 0.05554697078262126, 0.04231108585372568, 0.11902982339022622, 0.081298514569719, 0.035319725321906234, 0.0495484410484712, 0.11941754814958382, 0.06639309422743898, 0.025949767122285503, 0.045400680147952614, 0.06213836447005311, 0.042555552171242815, 0.06663383735764412, 0.08844388558739617, 0.09612612336152986, 0.17827330247288753, 0.10735552442530472, 0.1299314384138392, 0.1119226878208499, 0.11266245296405208, 0.2070275853357969, 0.19247163898281514, 0.10286226553181488, 0.148351164534688, 0.1191814628339583, 0.13891768040916613, 0.16851732597476052, 0.13820376307252916, 0.20355248793719277, 0.17547467603318154, 0.12883890510326432, 0.17762791936195668, 0.14595793650275277, 0.07941144082935588, 0.19588220113467789, 0.16298866860808867, 0.14707956583269183, 0.08457639029309635, 0.17206822011259296, 0.08197432669300227, 0.2413293100412815, 0.2533049650129772, 0.17968929342685208, 0.20255527128615688, 0.2681291187482496, 0.14771252299749082, 0.09246716486109842, 0.14552001000171708, 2.037048628253322, 79.6315513118621, 138.5929335317304, 125.45420154448479, 123.53189499147477, 97.57154680067494, 77.82591173725744, 32.62446099712003, 40.14194426998016, 72.2788409263857, 146.60514339323967, 101.19729949582009, 70.10204315185547, 67.70403938908731, 114.309155402645, 80.80050391535606, 31.68842265682836, 7.346193857731358, 1.034349852031277, 0.45540268262547834, 0.1420085540702266, 0.2826180170860983, 0.2848764749303941, 0.5148583374196484, 0.32785376233439295, 2.212066011082742, 2.8633221359022203, 10.394327044487, 14.773816120239998, 28.707739037852136, 39.62499549311977, 55.215106856438425, 67.92744190462174, 94.74323549578267, 135.53284152861565, 128.86966028521138, 130.36973153391193, 130.76753831678823, 127.85585311151321, 119.87512419300695, 118.08802958457701, 122.1896363842872, 136.62202096754507, 143.7869361139113, 151.70345583269673, 108.13669404675885, 37.001863371941354, 23.178097278841083, 24.325072842259562, 19.83983470547584, 11.249355693017284, 12.91493429291633, 30.38136732193732, 21.402983550102483, 38.860266670104, 112.5507019412133, 156.5748042445029, 129.71759826906268, 119.72871780395509, 113.13889272751348, 122.17086392064249, 115.38082538112518, 122.22508676590459, 117.43399789256435, 131.73827786599438, 138.16525397762177, 146.8951948227421, 144.2947575353807, 156.5027738386585, 166.9180786994196, 171.61141426332537, 130.87870613221202, 71.21963624031314, 7.517370014421402, 8.970304669872407, 28.428660438906764, 0.2635473920212638, 0.08793643660723202, 0.25812379595252777, 0.2929433807730675, 0.12402970388892198, 0.40837708019441177, 5.833515130704449, 47.804180652864524, 93.98612391564154, 83.29644926132696, 125.81053318515902, 95.51609931453582, 46.07043420114825, 24.246970607388405, 19.66673658740136, 25.922550270634314, 58.37235204635128, 87.56422335101713, 94.93449026538481, 97.79153685415946, 93.41759989338537, 76.40567641104423, 45.14168754700692, 10.34244389303269, 0.7745177106511208, 0.11488344144797134, 0.16882834235025992, 0.1257567725054199, 0.10716263114685014, 0.1257093133585107, 0.08530213602728422, 0.12627060299799328, 0.310281727823519, 0.22541148918530635, 0.1938731508750108, 0.2515710169269193, 0.13590931441755066, 0.09872788818733347, 0.14040242009345563, 0.16280660015200416, 0.14803267114104765, 0.16851784691454905, 0.18931146500812424, 0.19423129697961194, 0.16173021597487314, 0.23141676049319007, 0.07698192321244748, 0.15259823341283107, 0.15857658439105557, 0.11911961655583113, 0.17528134608461013, 0.08442059865281468, 0.15981038431486777, 0.18590620418469753, 0.16827018601038765, 0.25947324450938936, 0.23719603586341106, 0.13477133677130745, 0.16945146294611116, 0.17306866965466933, 0.21624222878486882, 0.07952335861421402, 0.1512294181532437, 0.08864506793719146, 0.0790823141353265], [0.035453051433808384, 0.0318925543838451, 0.10656019492495446, 0.09166259634038133, 0.033225011110546133, 0.03245401256267102, 0.06550471568780561, 0.11315979724449497, 0.44014555131716115, 0.1105748633703878, 0.09691481854045585, 0.06671338026682216, 0.1376289826247, 0.08739098200514432, 0.045262447242895444, 0.06427614048363701, 0.03748123473938435, 0.04137174331492955, 0.06993145516683018, 0.10799150763740463, 0.22310861356316075, 0.394903953157125, 0.23790963144311983, 0.07270165974454534, 0.015470561488801915, 0.02806083156516956, 0.0904252800729967, 0.04621133906766773, 0.025556957454330502, 0.017967086901227315, 0.128664635422249, 0.06591576782445754, 0.08010756194351182, 0.12297382788552393, 5.169047972848339, 53.815361992005386, 85.73720685897335, 81.11756478586506, 102.05349799125426, 76.46953259744953, 50.86686142029301, 28.335812053372784, 33.824778833696925, 42.12731861299084, 78.66082745213663, 84.57054491966002, 75.1960802078247, 44.56328699665685, 37.80695730640043, 29.89371276670887, 6.923869319500462, 0.6328517511006325, 0.06652824745904054, 0.035602047874201695, 0.03233248037436316, 0.32265496710615776, 0.15576447480388228, 0.0032085313596912934, 0.19590944322126527, 1.1538113966103525, 4.394819169275222, 4.906307516559478, 20.76191725269441, 30.495161164191465, 50.31683529576948, 64.56478218878469, 84.38238097775368, 109.38490206195463, 122.39774165614959, 101.79611206054689, 98.37455011183216, 97.45642523611747, 111.65950021436139, 111.1050182773221, 113.63365265630908, 101.27752765532463, 97.84108423417615, 98.72208779858005, 105.34060109046199, 107.62233795658236, 127.02778585495489, 129.98024017580096, 33.771607183641, 11.440241759823216, 43.14615034287976, 99.99984695065407, 147.1656971593057, 161.7204361577188, 141.52043373354022, 61.49609627262239, 90.50681683324999, 116.55009177423294, 106.97266009546097, 117.1819228510703, 115.40989798884239, 116.9916957424533, 112.20310934128301, 115.2555605673021, 122.10195572145524, 126.4567985842305, 123.65370027480589, 115.59113502502443, 108.17053625660559, 98.0898174162834, 97.26045577756821, 103.23764585679578, 124.83729900852327, 138.93057115616338, 130.94355860064107, 44.053959385041274, 16.341654158407643, 4.605728935810828, 0.6434161648634942, 0.3067881217406642, 0.04618887736972782, 0.06402553780184639, 0.03799162932761735, 0.15654148714196298, 0.8971644036712185, 14.13499047679286, 39.75204106300108, 52.79734611511231, 63.92697734217491, 74.00507603922199, 45.883176326751716, 95.41525517740558, 104.73387318272745, 46.7792143360261, 32.076464699160674, 53.40998111232635, 70.10601259046986, 70.93255012266098, 74.79639853200605, 74.41992944286716, 53.99583024363364, 18.2471445298964, 1.3727946267012627, 0.2903453008301797, 0.09861163434482391, 0.13664454432024112, 0.08461225852971116, 0.0655611074199119, 0.10648006212807472, 0.08972914363708227, 0.11340118388855651, 0.055424653354191014, 0.018594101138953722, 0.07677180827745507, 0.03245800388075652, 0.06476587751099179, 0.13435072385736052, 0.15589017451049822, 0.17203291878104213, 0.05446148548094977, 0.02168809469308584, 0.033795007339288155, 0.037364348874337254, 0.056563967823862076, 0.11044997571697159, 0.07678183636838391, 0.0032300725551096783, 0.013322254639088869, 0.027592677149861574, 0.013997621473766143, 0.04655882888924211, 0.16618293349541005, 0.1563904758903288, 0.024259723535168077, 0.1363368680880916, 0.09870541116763508, 0.09127235881263211, 0.05090095012659027, 0.06939628146468632, 0.026887439589406696, 0.0384935318312097, 0.05026928381994367, 0.06280735841081028, 0.054102986975903475, 0.09201425368026381, 0.08169195434499173, 0.03393660337033291, 0.10945461299871245, 0.010086471616711107, 0.1321587011578583, 0.2702062589026267, 0.11214510612790624, 0.10213619804069882, 0.08000441586538669, 0.07750885380852608, 0.019291986170555317, 0.019159650227295297, 0.053021435535723166, 0.029965864321697625, 0.03820476647947104, 0.046416650631374894, 0.10496922948908423, 0.24960197177865814, 0.2761676486942076, 0.13202054486159356, 0.030138944651210503, 0.03667966928333044, 0.03687399514620343, 0.05694676280742692, 0.08061615239468314, 0.032959232226975506, 0.03379207705297778, 0.14142779813658807, 0.08834553521967704, 0.03194041381169471, 0.0579171127549583, 3.7303620624926785, 51.406960025910415, 99.81796664576378, 93.65589172609391, 114.94860372235699, 87.57417832651447, 77.68739715699228, 41.67354353012578, 25.170259283434962, 34.96348996316233, 48.386966413067235, 76.00768135439965, 50.94272398179578, 41.25386168879848, 42.862810088742165, 38.85257490219609, 12.433411382859754, 0.5343276959273123, 0.21407743285019554, 0.033595809157216744, 0.04521913646209625, 0.5634536233640487, 0.985936527290652, 1.189606211358501, 1.1155226898770179, 2.493564957572568, 3.9137875360827294, 5.9672713856543265, 11.15287519270374, 29.036521911621097, 52.093433641618304, 67.77708176643618, 89.3596882973948, 117.34954141801404, 126.69721634157243, 107.59086485831969, 103.96354321510562, 105.82786144748812, 118.60087948460733, 120.04958337353123, 119.97628996449133, 111.19169481338994, 104.13175798231556, 106.55140538369457, 109.7877843918339, 113.7652167966289, 130.79534792130994, 142.0825093792331, 43.97975206375123, 15.919656157493593, 55.42662851272091, 111.28687504799136, 161.564357203822, 176.07557358280306, 156.4574939973893, 70.81826010058003, 93.88487185201338, 119.87312378421908, 114.89916616870512, 124.04607065262334, 121.13930409954442, 122.22489849213632, 118.23860937549223, 121.09931161326747, 125.6918187295237, 131.76653462071573, 130.2653572636266, 120.07800486779983, 115.07186028265185, 104.61784162829, 104.619002649861, 105.60508651118126, 127.43521813423403, 143.40516398029945, 146.5568825506395, 59.632793934114524, 23.875204440086122, 9.784278850401602, 0.7688909480648657, 0.2181241237708638, 0.09033365595725276, 0.035847234314367656, 0.023665731517417778, 0.08121923979131446, 0.9808296013262965, 17.064740157896473, 41.24673081982521, 52.089405367451334, 47.15749556018461, 44.09415583456717, 26.5028610152583, 50.54304230597712, 65.02327196059689, 56.44344806671143, 44.05593625960812, 58.65115411819951, 82.99454442916378, 80.27983280920213, 84.83226114703764, 83.9575255301691, 57.226882673078975, 18.017503484602898, 1.4002519533518822, 0.17593409896137255, 0.09939887395669376, 0.08219597891213433, 0.04415866393115252, 0.02103886773599492, 0.11928169777797115, 0.05551918094316798, 0.15089823834357724, 0.05691604651210289, 0.034865105765000466, 0.09457346998275289, 0.05459040658728731, 0.0738609116524458, 0.10515721980482341, 0.18592420725091813, 0.08809634213966709, 0.06476057618255578, 0.09222305860490569, 0.1112953001152604, 0.06805295395033975, 0.0465985773611934, 0.0608750663307165, 0.059791040426540765, 0.005733558115729642, 0.029577591809474175, 0.04707217291598359, 0.028161250370284243, 0.008202105039550413, 0.17359578411184973, 0.13771164351172988, 0.03888733932868608, 0.141058957444564, 0.06521351800690736, 0.02716029712539767, 0.028441521722162445, 0.09899156798999156, 0.02604510867968202, 0.08091645886100109, 0.05579280456708324, 0.12896483463625755, 0.24371976483493085, 0.15312763081202585, 0.17254871045870168, 0.18485192930506122, 0.27475237786289186, 0.1226466776983392, 0.2586626009114327, 0.49107820216205816, 0.20684043005589517, 0.21723058945950002, 0.17295217832490323, 0.28444596416046547, 0.16959818410536937, 0.17541472199222735, 0.09434009661837932, 0.20981326488958252, 0.08048253899980938, 0.10074738788628772, 0.1545934787681026, 0.31147201395323204, 0.5099840263926214, 0.35990139589675013, 0.17545155549962677, 0.12591906057129945, 0.12228741310536863, 0.13993063250616675, 0.1870324913292162, 0.18602580583143621, 0.2053064768833499, 0.2752978018214626, 0.2346922307004852, 0.22416432868809472, 0.19825702773467188, 13.49257488404551, 94.80936665688792, 122.45922873097082, 105.4090307604882, 124.43717018250497, 97.7377062459146, 74.50153043193203, 47.86339667535598, 48.55030175178282, 63.86409390357233, 107.35578152441211, 110.08830854969641, 107.14612299396147, 75.6267172290433, 67.2918139734576, 52.314874972066576, 14.128470516973927, 1.5712199792746575, 0.32960010572306575, 0.15678170167150038, 0.12212967560175927, 0.5353696980784016, 0.39016606706765394, 0.6816966591342803, 0.7899066397259313, 3.7304664955985163, 11.068522660962998, 16.75575936994245, 39.671805058756185, 40.995863868344216, 66.41412873421946, 72.17747119165236, 95.16059137159779, 120.00444473758822, 134.41821375200826, 112.27071531357305, 110.38007797733431, 109.4702293026832, 122.77155137831166, 124.03314252053539, 125.95627277128159, 113.7850953686622, 107.54434554807602, 108.086119005757, 113.88884205971996, 115.05889292686217, 141.7447619284353, 146.7690827769618, 44.80133956478488, 15.808352039706325, 61.561454726803696, 122.44966599249072, 160.570334465273, 171.8220926100208, 167.24173699655842, 91.7234968370007, 103.00201339106407, 125.7942710384246, 119.5314225842876, 130.93355655670166, 127.86197985372237, 128.0882300100019, 123.90061347715317, 127.89562594506049, 132.209684002784, 134.43327565346996, 132.1293224826936, 123.86475516903786, 118.91411996656849, 107.10534603365006, 108.89894393182571, 112.53465944720854, 136.90675366309384, 154.0135279009419, 147.82329036343484, 55.17775020291729, 25.837578004406346, 9.776096786222151, 1.0278749994693264, 0.37486753636790865, 0.179681402721232, 0.24875719130279558, 0.2685631841661469, 0.4936886007987684, 1.8237527123382016, 24.97025566716348, 63.48917415065151, 72.7345262035247, 84.80519679284866, 99.2406016011392, 62.05396321512038, 113.99545992574384, 118.35836718159338, 62.80947839060138, 48.219245864499, 75.47407427141744, 94.2971835597869, 93.72769463446834, 97.5495344592679, 95.51543251160653, 80.46823993805917, 36.57679611636747, 4.8270972121146425, 0.3311985941423524, 0.2196325968590475, 0.18918339042894303, 0.23013129559976442, 0.14624882008760207, 0.3219001253526057, 0.11021871675526905, 0.28218343072841245, 0.19033760913918096, 0.10818394892398389, 0.14093046917790367, 0.1479101890037137, 0.18364854307184297, 0.270845789101816, 0.3431651633112662, 0.2777800186266822, 0.2823550650669683, 0.22290118759678257, 0.1717335316202333, 0.21644063023549898, 0.22347317948456735, 0.22064394017140712, 0.10951004712091339, 0.14001203700900078, 0.12923484998604945, 0.09225855911931685, 0.0831287062817043, 0.18216587182494903, 0.22303775043016483, 0.2014673345031277, 0.15288245203273912, 0.19966362645068478, 0.24643548523947117, 0.3943607355317762, 0.2344002745925419, 0.17677400711803667, 0.11261385234613573, 0.16563692731001686, 0.15427711509889172], [0.09050696036748349, 0.05436505033304134, 0.13488643382105137, 0.17706041674940817, 0.14893510739409155, 0.09215764235705139, 0.056246661866504344, 0.39405883560257576, 0.12860604501780004, 0.013635808680837434, 0.17232760216199583, 0.09626912899435529, 0.11430172790442744, 0.08890370688130779, 0.03629903466771207, 0.09547705536768322, 0.04237142676908163, 0.12347471915305623, 0.15144329457994432, 0.4283605756298189, 0.43594006569154803, 0.4265188696163316, 0.27734319529225754, 0.21063199837601956, 0.12413340155035259, 0.12108662391021369, 0.01333409740078834, 0.02067373490952436, 0.014879290040792718, 0.1461241009735292, 0.209919766432816, 0.20658811133715416, 0.1148466922102436, 4.4738897392826695, 83.68552484819966, 112.03949159191502, 106.55459819301483, 79.94447015946912, 60.274321110017844, 46.08353883989396, 12.776937465513907, 36.90431794812603, 101.01224991583057, 82.42303156083631, 55.205297008637466, 35.671575838519686, 50.09154219781199, 43.58728362667946, 14.974854261644426, 1.1019164780455253, 0.18985509632095215, 0.1454765574946519, 0.01968077770734747, 0.1765771225214966, 0.060581815534181176, 0.24912361115697892, 0.3528534789239207, 1.0815878140349542, 3.179127112511666, 2.5558389579096152, 8.265258631398602, 29.600909794530562, 43.79427886778309, 67.00866591545844, 87.07410750850555, 97.26444875040363, 107.11261810794954, 107.76390414084159, 106.57498667317053, 97.6836246059787, 91.17609085575228, 96.61213505652644, 108.087280027328, 114.8851005492672, 111.34387493133546, 96.94452454966884, 81.13371710623466, 89.24262123723184, 92.31755548907866, 112.04571247100831, 100.79033005622126, 122.96374751675515, 103.7922219307192, 48.363165470861624, 110.87116656764861, 136.16035799826346, 105.9382055651757, 108.33534640650596, 117.92275659499632, 57.675570441830544, 89.4356018497098, 128.7026143843128, 105.33878111070203, 100.92679715925648, 102.3140061286188, 96.50709398331182, 96.29392885392713, 93.8228984032908, 95.76268303778865, 98.92643543981738, 102.20763929428594, 95.56679987138318, 99.33316169246551, 97.45720186541158, 99.47017008258452, 103.6258977459323, 104.71112343572803, 100.81270325568416, 112.62371293960081, 133.7707402629237, 122.0562836431688, 80.98131733555948, 34.3539850173458, 4.252613638677905, 0.2982519717226106, 0.08746368374915854, 0.1710291290956159, 0.0176258196288179, 0.04526979402608929, 0.10845654599008062, 2.3856902170565824, 22.701972530734157, 51.53354667848157, 70.08119183201944, 83.75786119891752, 127.79666454561296, 127.0235183162074, 29.582853163442305, 33.306123825811575, 38.903338216966205, 34.31349831242716, 56.179354883009395, 70.57463384443714, 81.2057710463001, 74.78496874532392, 61.4097531380192, 36.41979932785034, 3.160571114670846, 0.33837778794188655, 0.0723702118041054, 0.10815322879822024, 0.2727987310819088, 0.13459766463887307, 0.23715918703425318, 0.25842002683108856, 0.07756660151625834, 0.03780246689735401, 0.09254444781089984, 0.18538949320152884, 0.3221683480566548, 0.2630662581612987, 0.28477645449100003, 0.3980434734013773, 0.26039509343043454, 0.19508989768162852, 0.03927648901158283, 0.1065538670386999, 0.07075712174898194, 0.17398414472418447, 0.1847125013028422, 0.08184377764982563, 0.11325113024682769, 0.02629823370596334, 0.039554115444902456, 0.04871700199380998, 0.12065422090311205, 0.1020492700439307, 0.0974361949990834, 0.12259066901019505, 0.22903654063420914, 0.24235914671613326, 0.12149789055148441, 0.056932624654784325, 0.03683344228193164, 0.053319688886404044, 0.07013852873276319, 0.014239733028526028, 0.02092914287782004, 0.08717142120604554, 0.14702163426385773, 0.06940784939234296, 0.11742915162035536, 0.06726998910908738, 0.3070074373916272, 0.12229277572083859, 0.07159943542172832, 0.16949517592307062, 0.10808369865821255, 0.033017565991969845, 0.11294926096114422, 0.027730082679960518, 0.0652548331286638, 0.05659832303682643, 0.11916758898164957, 0.09198086756852367, 0.31671279079971776, 0.47841835406518757, 0.3926047700787745, 0.14217821190193777, 0.17488602939392292, 0.1199723796678647, 0.09718627413554538, 0.052534893095012636, 0.020202744053676724, 0.06385501429078079, 0.15516058301493046, 0.24909476028575053, 0.11290056841267694, 0.03849265849097602, 2.8401600497384227, 88.90733703490227, 128.18479876364432, 121.78378874255766, 89.19053216134348, 83.35155856224799, 61.81319636683311, 28.576055265242054, 29.076135889176403, 44.94983265476842, 54.96052149803408, 48.642763783854825, 40.82369142963041, 49.2040902568448, 50.94703858898532, 21.150455474853516, 2.4419857898066124, 0.5009246689658011, 0.22037037017364658, 0.10223955862344274, 0.521541933619207, 0.4096169168910673, 0.9755723995547142, 1.2952786635967994, 3.486208983006016, 4.269518073528044, 2.080202299741007, 6.62743031017242, 26.489881892358106, 45.40936969941663, 68.06638010086553, 87.19232774549916, 100.73089830337032, 112.64221868207379, 114.85510226218932, 112.77449669376497, 104.90944631638067, 96.66945657422467, 102.23724534434658, 112.67085198433169, 116.71203074916717, 115.25981241656889, 99.76907037919568, 84.66641549141177, 92.44368322433965, 96.36970120091593, 114.05685286368094, 104.19450021559193, 124.01870819830127, 110.16279435926869, 54.818229675292976, 125.62943735430319, 145.8932802754064, 115.13595181126749, 112.83664272677515, 126.69046202013571, 67.10437174766295, 96.51915134922152, 130.75234305474066, 107.59201019041001, 108.52763668183358, 107.3399273041756, 103.10732903019075, 100.64947774333339, 96.35868718547206, 98.26704579014933, 101.9523714434716, 107.54476916405463, 99.54768396192982, 102.32179595578103, 98.80742288404896, 101.99822395078598, 107.95954412029637, 112.84885698749174, 105.94161018248528, 115.89631895865165, 148.3891942424159, 140.0845795293008, 94.52996054003316, 44.78941555946104, 8.76255633369569, 0.2908094888252597, 0.06107736716888124, 0.15554633892832265, 0.06264688980375087, 0.1207972648403337, 0.22756117786611282, 2.874320216717259, 26.813877513331754, 49.897631983603205, 52.36498325101791, 51.46815684533889, 125.71412917106383, 148.28773037079844, 50.310743854891875, 38.19069846983879, 58.00215090474775, 54.89852451509046, 67.01355318869314, 83.1644928839899, 89.89142048743464, 88.80361387806555, 74.6151065826416, 40.04133155269008, 3.5105338067777696, 0.3300635276302215, 0.12995451298211852, 0.1671242870150074, 0.2121250118098913, 0.04396118561647112, 0.1131283033699278, 0.15220029670144283, 0.09172655702117952, 0.07186159837029635, 0.09659150645377175, 0.08067433677253225, 0.1287039510545231, 0.25943300957160614, 0.31864164697547115, 0.17128788295292086, 0.1818807645430488, 0.10429481164582315, 0.04336664010019552, 0.09009562477829958, 0.05914546196318923, 0.05869484138524821, 0.11252762148937873, 0.06408599363039098, 0.02272973869807057, 0.04768581700421149, 0.016193101145026666, 0.11289990957706206, 0.14726862101064575, 0.1129693937517943, 0.04878313453387349, 0.06006935633899224, 0.27356521737190986, 0.06494601542550711, 0.1310732158561868, 0.023870434041225144, 0.07803586867427634, 0.06419477045475956, 0.01967627502557251, 0.15072651207447052, 0.19893104721221233, 0.28204323663826913, 0.3773845642084076, 0.24913147121908205, 0.2935551785893979, 0.2512805470295491, 0.44135456063574363, 0.24927981648473974, 0.16640833188449183, 0.27531263328367667, 0.21999605961384314, 0.20296379533265868, 0.18089044268333143, 0.10189035276491797, 0.16427486894592164, 0.16282798932685008, 0.2727605186162457, 0.22277174938109615, 0.34665867746357, 0.684457762587455, 0.5887601428454923, 0.30687487353720977, 0.24067948362038982, 0.29079453478897777, 0.1921882477378653, 0.23148745508684268, 0.1553127893637265, 0.22069747439555584, 0.3373025069313665, 0.4599533368262553, 0.45725275431909873, 0.3544226414974659, 13.092626487055133, 131.26316116702174, 143.2376003265381, 139.04463368077433, 111.79161348650533, 88.97539015739196, 69.76591171756868, 25.974025495590706, 63.565177917480476, 150.8167491420623, 121.07695410328527, 77.00027635020595, 55.80960873634585, 79.82819541808098, 67.90209554856824, 25.36890575962682, 3.0570984992288777, 0.7598207121895206, 0.2895554335367295, 0.22360318460531775, 0.4409766341409376, 0.2458201787404476, 0.4086508800185496, 0.630841046091049, 4.789290956912502, 9.592521036824873, 10.45859213798277, 16.752401821074947, 38.338650272738555, 52.1532811657075, 74.20261444584017, 89.33649924493606, 105.62902081397273, 117.64320927281534, 123.52176743168985, 119.44212590494465, 110.72786669577323, 102.64339893094956, 106.71457598286291, 116.39115733485069, 120.8662522223688, 118.20368459147792, 102.41772144071518, 86.31285390546246, 96.06741982121622, 98.48724765162315, 118.80455247817503, 111.33822671828732, 130.94054622034875, 119.81694759861116, 74.15791511535645, 143.12323970179406, 141.87843630390785, 121.32616581455355, 121.10986278903101, 127.49384187882947, 74.09048172735399, 101.84535349569013, 136.96241994057934, 109.37998340975855, 110.99690206589239, 107.87397369261711, 106.2903481145059, 102.19968472757648, 98.28081330945416, 102.5211621868995, 108.80372447352256, 112.67079707114928, 106.3244805797454, 110.40177652912756, 104.79110840828189, 108.72886211641374, 114.52729409740819, 116.59696409779211, 108.00017987528156, 121.3109548630253, 157.9573142143988, 142.75423880546325, 90.87344077325638, 43.59179827474779, 8.51791222249308, 0.35817880123373, 0.22762701546232547, 0.3214192059972594, 0.12931455377369158, 0.21526192735520103, 0.572154175850653, 4.867070576836986, 39.915494072821836, 79.88485013284992, 97.49650401453819, 115.30247995930334, 139.4644057366156, 137.29649605289583, 40.8122302639869, 48.46149536871141, 54.922847132528986, 53.39498981352776, 77.12707873313659, 95.94570867476925, 104.09389926541238, 98.66102433973744, 91.35765737102878, 62.04004664574901, 7.358393409559804, 0.5325935180148771, 0.15973798900602326, 0.44378995414703126, 0.2689653803263941, 0.24453258412259243, 0.32636700017798337, 0.36424033403877293, 0.3083298583665202, 0.13881553024534257, 0.3322551213204861, 0.2500894182031193, 0.4355177673841677, 0.43984861563771005, 0.41106819385482424, 0.7245300445825823, 0.3546830807482043, 0.3242434350953948, 0.19156924869504668, 0.18508701104550593, 0.12468490058616286, 0.255881808998604, 0.2791205192765882, 0.2947263431645209, 0.23855187359356114, 0.1625855224988153, 0.1037156644968256, 0.25205961248326686, 0.2737617342462463, 0.21950078377079582, 0.22263196897843193, 0.28994368689675487, 0.4190040373754117, 0.43410310942319136, 0.3180811157630336, 0.1317282516749636, 0.14956400429289188, 0.27120042652372395, 0.15084839666322356], [0.02710183695589583, 0.0845886936651603, 0.06843754541008704, 0.11698228487324332, 0.034933758734334866, 0.21914439966842053, 0.08738208772434343, 0.19690986211982467, 0.12853512059777014, 0.03338737578521813, 0.1381234464145476, 0.005809735504895329, 0.07193274495582427, 0.11023902574614172, 0.01427300614229734, 0.01623758404035001, 0.060784890121149446, 0.04465079881371029, 0.17992413001916102, 0.4906932276583487, 0.29789442316659037, 0.29936687480057445, 0.24465250752625928, 0.35075847359914936, 0.13838647504247006, 0.10462010023935188, 0.06131434880737817, 0.0470392617787565, 0.11363122477045945, 0.04278399575982363, 0.1873997998453917, 0.30973661030011795, 8.30735448868044, 90.32051993954568, 104.76711134756766, 100.51166918969925, 109.11236009290143, 92.55076393004387, 32.58900669313247, 15.73459775217118, 84.30070938602572, 76.13034171442833, 52.08560459075436, 44.087013198483376, 35.15984381398847, 37.43197871792702, 21.759299501296013, 5.858559464254688, 0.17825226569848676, 0.1365162705581996, 0.19306045416141712, 0.1931824766459965, 0.04288866252247845, 0.11647665918233896, 0.38374572932239503, 1.3567358303454615, 5.166460679423425, 3.4626568661582087, 3.6501157620260796, 11.458072854626565, 34.93300530218309, 68.86130332946777, 75.56914467965403, 93.2031011581421, 101.8743476560039, 105.97278518061485, 102.05686338486211, 105.48267718284362, 105.36205645530455, 92.83992890388735, 86.07798237954417, 88.31603973142563, 104.68189393320392, 112.94751244206583, 108.2795467684346, 91.33513512149935, 81.54075714849657, 90.14090676461497, 91.8223640995641, 92.44389503232895, 103.38816288978823, 125.08740502019083, 91.41657921575731, 24.520704976974, 92.27930453515823, 92.4496687612226, 95.0919577383226, 78.01007486158802, 106.09701448871245, 68.03673482710316, 91.09759638386389, 114.5542956936744, 104.48310036813061, 113.12403478930074, 112.7564851699337, 113.10025738131617, 108.62257372948432, 104.05036880124001, 103.32550694865566, 99.21129365121165, 95.62849875419371, 88.99729267243417, 91.24403415187713, 90.9667774938768, 89.1241107448455, 87.05326403340986, 89.9362845574656, 104.39916164644303, 115.87104320526124, 106.19918438696094, 106.94675676284298, 120.41647403470932, 106.88869783955236, 66.22541566048899, 19.819489371392038, 1.4182848050709695, 0.17321883820958678, 0.05727624190190146, 0.045448706199925755, 0.1685319582541143, 0.13578549928722844, 0.35023495975521307, 10.371088962401114, 31.412407428987567, 41.166910586818574, 27.039572654231904, 37.61745583626532, 45.68205679616621, 29.864871578831828, 14.689373373985292, 19.75761398192375, 31.14757291732296, 45.198581526356364, 76.05063130778652, 74.13010551083472, 75.35736806931035, 76.24285882519138, 48.65262462246803, 3.143954974028372, 0.07890028398363821, 0.12123205804175909, 0.1060153761758439, 0.09879196378132028, 0.1337859178743055, 0.1780091706783541, 0.02013663258103113, 0.015664988858324867, 0.029896983441205758, 0.08278480941249479, 0.2608733161562874, 0.11315880899107265, 0.07899959196126269, 0.15674468430299915, 0.06701171788717471, 0.19926942824836702, 0.05668834602880863, 0.07438198167590365, 0.07221644263594382, 0.10921461297379387, 0.11732908521568584, 0.03130623856709609, 0.06814272413330694, 0.07326428237701617, 0.03609917765002578, 0.02004763614686747, 0.13385944699327793, 0.023490965794471484, 0.04161278904986478, 0.015188922669978873, 0.13796166396669804, 0.11480140875303939, 0.021415871094852205, 0.05647359626187433, 0.06794909541044505, 0.06778066331941275, 0.1090413009026839, 0.05789099298717995, 0.033921124563822826, 0.06331473461262162, 0.15631579763946996, 0.008168003593210973, 0.025558206177647078, 0.07237339106899116, 0.22239984433737495, 0.1293093443758065, 0.13340834377994462, 0.09373886315452476, 0.07658605493845479, 0.06254527973191393, 0.08220233744190586, 0.02765623180405988, 0.03907742489489817, 0.034914621857986335, 0.05316424198568829, 0.07360699180994304, 0.4643709368763432, 0.35000406085483493, 0.2204615959236699, 0.2606450219548518, 0.36392069151324613, 0.13257877781025826, 0.07070826832205057, 0.007018435036673421, 0.0709024409673387, 0.08447820080384132, 0.0984100383075495, 0.16493621732919447, 0.13059758250751805, 8.452087986853815, 93.96647284107824, 122.8418637860206, 112.97364327215381, 121.6147816565729, 108.18271129362046, 49.42590813482962, 22.10236372486238, 35.59466208181074, 54.707740429909, 49.96016633126044, 49.835693836212165, 43.65815301095286, 46.51425430851598, 30.529834916514737, 9.27647311841288, 0.1662397159323577, 0.2717681589626497, 0.15751688560891539, 0.364646942865464, 0.23826025456430452, 0.5881106841468042, 1.362904370311768, 1.8200903217638693, 3.1266151560891062, 1.5180147439241412, 3.6138071167853574, 13.358163102980583, 38.11011729701873, 69.70351465286748, 80.34779179480769, 93.37947445531046, 102.61740146144744, 106.39928017893146, 106.49325232351981, 109.41288425076394, 111.31284898327245, 97.6562229279549, 91.63340783888295, 93.92477020140618, 109.88920903974964, 118.24079021330803, 115.00069279824535, 96.54551752151983, 86.11995174038796, 94.72088583054082, 96.67871336783134, 95.51886850787749, 111.90816279380553, 128.6344514354583, 100.51074351033857, 32.50908643968644, 100.26199463875064, 102.97121494047104, 103.60616822396557, 86.15799873105942, 114.48191227451449, 76.85778448658606, 94.72823635224374, 118.96807609065887, 108.96449458214545, 119.35672806155299, 116.7312111393098, 116.78457890787433, 115.26364064985707, 110.77725718098303, 106.79020712452551, 102.67115362228887, 100.24436750719624, 91.68833671077606, 95.65851273075228, 94.69703781989314, 93.52138580814486, 93.8083307204708, 92.70033959419497, 109.45311992399155, 124.87282783754411, 110.92525605232485, 109.88525529061596, 127.59567445324315, 118.524958087552, 83.7503537824077, 27.419091386179772, 2.9340799777738513, 0.08291022566657874, 0.23570613274651192, 0.07342282427294601, 0.2690303752258901, 0.12564849363820207, 0.3767568930502861, 12.922928083327509, 38.317006634127715, 43.507655589811264, 34.08803655255225, 33.12376891413043, 21.832033972586355, 33.60316491896106, 23.69724846655323, 32.12703189542217, 49.70850313863447, 52.10215699288153, 85.01590651850547, 79.77163484019619, 87.04578015112108, 88.56810692817935, 57.92253071261991, 3.818482275932066, 0.1308022658791273, 0.07441692294613009, 0.10961247307638969, 0.04875610312146526, 0.1141144960157333, 0.1552046024270596, 0.05914366931744641, 0.03785321256145835, 0.038337449077516794, 0.03081528920560114, 0.2666478417813778, 0.10498111151278981, 0.10627405342435646, 0.16328978712760633, 0.09401074009797267, 0.09755958878104726, 0.015712575367351454, 0.05788678333403603, 0.053527746875319755, 0.07104644251446571, 0.08599721526186313, 0.04939480211525675, 0.030715716927642786, 0.019265278430295088, 0.01491962169717637, 0.037943461549378214, 0.09298555357682128, 0.06841434826773983, 0.008695147736298462, 0.010927978024307278, 0.1303385835020773, 0.1659053185534093, 0.024492100985240073, 0.08731400549051263, 0.0532317879579721, 0.06723077306824346, 0.05364945526385019, 0.11318758325350863, 0.1380041818464956, 0.2863787120628742, 0.43311516243603926, 0.16452006304696684, 0.33755467243252263, 0.16005878066343648, 0.42054513048741127, 0.3043503686785698, 0.15889186021541396, 0.15190461740618752, 0.186640361564294, 0.20267724780546081, 0.2716925920497987, 0.16911527292141992, 0.1582578764927964, 0.15716923490887688, 0.13559409988022622, 0.33873352853040545, 0.551739219696291, 0.42839422221145323, 0.3588820086611856, 0.3880359136289166, 0.45662370420271353, 0.36008099754971845, 0.2466657712695099, 0.1212537153473785, 0.2515768391951438, 0.22499530425956174, 0.2247461877883442, 0.33631471316179923, 0.44293230339404077, 21.689369524678877, 140.2808863116849, 134.7542824283723, 125.92417993853171, 137.2161659117668, 119.2231321334839, 60.823904006711906, 36.70588916347873, 121.27336286729383, 105.75655275775541, 72.22191949044505, 68.32444852398288, 57.42549973149454, 65.25829645895189, 39.600131588597456, 11.50179551493737, 0.463107259523484, 0.3361266538981469, 0.629674079677751, 0.5749902946333731, 0.2952333401528097, 0.33777506060657964, 1.2753589066766924, 4.412168302843648, 14.94589344147713, 10.783475195207904, 12.460481620603993, 18.6175770913401, 45.02333394942745, 77.94006839875253, 77.49968036528557, 96.77957319444226, 110.46947663830174, 110.2277409645819, 110.29487625245126, 116.38583860089703, 117.62686083393713, 103.01480816256617, 95.77153190489739, 99.05850164351925, 114.02539545489897, 125.57934084246237, 118.66239793838994, 100.83864581200385, 88.62462043762208, 95.67599865698045, 100.53331282831009, 100.20775610400786, 117.11954147584977, 138.23028687507878, 105.42153527659755, 40.952058838259795, 106.04982053079914, 116.65941607567572, 110.98406807068856, 96.6737162682318, 122.45263130434098, 89.66245605099587, 100.32463489040252, 125.25481177914529, 113.90684573881089, 126.01869337020383, 122.09144376939344, 122.00207648738738, 120.37150013831355, 116.72437052572928, 113.18492566385578, 107.48317226286858, 101.39963103878884, 93.28097589554326, 96.46601107812698, 97.47078895568849, 96.29960844593664, 97.53360179162796, 100.76263812280472, 114.45028228144493, 127.15784380512854, 115.17974899661158, 118.11950268283968, 136.86384293340868, 123.59734366017004, 81.65248194048482, 27.167794935164917, 3.51871072284637, 0.5122160695252881, 0.3451484730166774, 0.24253911609130524, 0.4634558295290317, 0.30877550703383266, 0.5403582174931804, 18.933129810517837, 53.058795621318204, 63.43191146850587, 40.3583885008289, 48.26818527713899, 62.33701321386523, 45.48407516171856, 24.925405325428134, 30.54646968841553, 47.39503429782006, 61.86273982447963, 97.0664788830665, 93.71862611462994, 101.25129484361219, 101.39922311229091, 77.62097574049427, 8.626289271539259, 0.1788442065158198, 0.26226174326673635, 0.16026830571072717, 0.25009709440412065, 0.24272703745913124, 0.29688070498166547, 0.14351837547315707, 0.14567865148907708, 0.33574848225520504, 0.2569668652910379, 0.4747322760522366, 0.36569001753964736, 0.20880964374349964, 0.3517946228384972, 0.4367477062248415, 0.45145218170458273, 0.16209740191698074, 0.21780210637277175, 0.1739013919066037, 0.2025670690401908, 0.17255376663900193, 0.1502073036446687, 0.21960760707095747, 0.20536735022981323, 0.1439807401789773, 0.1487456691721755, 0.23948112292395485, 0.22614379263212606, 0.19258909558336582, 0.11697601061314346, 0.3126892357343628, 0.3437322522363355, 0.1332201006551904, 0.20002938746925325, 0.17897885412939135, 0.15880057317835672, 0.15749699796640104], [0.02917471957663375, 0.06455683509909338, 0.09979357011616231, 0.08198764130112626, 0.058226279028120546, 0.08307362455994853, 0.08859679673708255, 0.14151833440747955, 0.14842726770908604, 0.06456168443565408, 0.11477951396016345, 0.1383636456223265, 0.04517001873483101, 0.03704149644040773, 0.031128381679375327, 0.03358632498871415, 0.011879251424914167, 0.05283443347340631, 0.15016912182252254, 0.3388286153635671, 0.20423727861094862, 0.3342832931347432, 0.39483074579508076, 0.244005469665412, 0.17765330751576733, 0.09059938887554793, 0.05469124674076035, 0.11354287185015217, 0.14387886580680648, 0.16308939384837307, 0.5263768677269259, 10.765944161722738, 109.44467898338073, 107.2710269497287, 118.50066292670466, 87.32651987383443, 61.74763002703267, 39.40761773817001, 22.52944511751975, 31.96114113253932, 65.26789449876355, 39.981409503567605, 41.001496391911665, 35.8827248696358, 31.99005488426455, 15.13712271567314, 0.9801441671386842, 0.10665467654865597, 0.08771549684986954, 0.034530857773197275, 0.19222138870146968, 0.12713109593718283, 0.15548258509126403, 1.659457618671079, 0.8524851140476043, 5.119965883993334, 4.860324100140603, 10.44257317819903, 31.222449002727387, 57.11540891278175, 84.79143711828416, 105.47183575168734, 111.29046009432886, 102.42965329077937, 86.40826948227422, 99.54825662797498, 100.55257166585615, 101.40928006941273, 99.63807890492102, 94.34597784473051, 87.07238951037007, 86.01168647889169, 99.13827480808382, 98.26940705699306, 84.92171472118747, 81.57617615115258, 99.10131823632025, 107.35861347567652, 110.07339569830127, 104.20927970640122, 111.01467824751332, 103.90226010353335, 114.02079843705701, 48.0232842506901, 72.43148388401156, 100.02582088593515, 82.05117517902006, 76.23754009123772, 97.3465439581102, 50.40720670453964, 98.76051133678806, 112.52918381844799, 96.99164006017871, 97.92638794068368, 102.99293702648532, 104.97068235951086, 102.45675686867007, 99.5627772423529, 98.37549148067352, 93.74622391116236, 95.55278916512766, 89.81411057133829, 101.95885904373662, 107.83985691685831, 107.69664333712672, 109.29923749739125, 97.4990535551502, 87.62121538962089, 89.97763418382215, 104.28636212502758, 103.74704407107447, 102.69088314425562, 104.31604662249165, 107.3307332684917, 90.49649315495645, 40.61804548386605, 5.978572224417041, 0.08875893924625651, 0.061567854962401816, 0.07606413455740099, 0.04687042749156395, 0.06986508130907051, 0.0837329887754975, 3.0230770860948875, 19.64890549259801, 41.73292821453464, 62.412377634356105, 87.53728451267366, 56.92526809630856, 77.79559181582543, 28.30246210098267, 14.25975420782643, 24.926807572764737, 48.00149548438288, 56.512113078948, 74.4264562668339, 76.91723192891767, 74.22614866687407, 55.38638499475295, 6.945411957079365, 0.5133247213257898, 0.10699029966828325, 0.1649803593153915, 0.09337977476177678, 0.17837652515980507, 0.025647403709890864, 0.0228520714482593, 0.060814886293824644, 0.07064175656846455, 0.04971790352776166, 0.11577399567730966, 0.07071872542221701, 0.13012132096675136, 0.05933541729445419, 0.04415809319564893, 0.10600276636861025, 0.09959274782769142, 0.04429256460899788, 0.03257093673211432, 0.04728916349009641, 0.10461634640852291, 0.0622933172440577, 0.053737850318993294, 0.042033137663477854, 0.11472890619188549, 0.03547906777971695, 0.09204110506200984, 0.05040250650997605, 0.004531130450026643, 0.0844608718949941, 0.15037521479591248, 0.03812760227329789, 0.08287755201660818, 0.05129964526502356, 0.04090058775017819, 0.04556020263642554, 0.028378183487802747, 0.04298125573944661, 0.11975259670326788, 0.13783723596603642, 0.024053802931561105, 0.054222423913738424, 0.054395100131871245, 0.12670030171472219, 0.11238479205677587, 0.014480748119944287, 0.13172072869154716, 0.08159171940097887, 0.05906419918662118, 0.050218021046490445, 0.019136899331163977, 0.03173454300380282, 0.032299408358671976, 0.02736191614530981, 0.14442922337160957, 0.27981732220899674, 0.1258563409529386, 0.3179496244317101, 0.2943153523149029, 0.16439678417819162, 0.12693217354676417, 0.11429834179580213, 0.03537290331517016, 0.051855445884528666, 0.07250903459686427, 0.17351624886355094, 0.4944316754418035, 10.989157422896355, 124.49122044347949, 125.97404895290252, 128.04009468324725, 102.68426218340474, 93.96823006291544, 74.17759756888114, 42.83750687876056, 31.948846463234197, 66.45278761463781, 44.50575367096932, 48.6093726465779, 41.03122403544765, 39.17979078908121, 20.493007398420765, 1.838988301254088, 0.2276587468241492, 0.03677369891515663, 0.0557647159533395, 0.23269490158605963, 0.47028283738801563, 0.9404165021354153, 2.0530154940582093, 1.8265894439912613, 1.411733098568455, 2.9284749107976116, 10.288526012051491, 32.625774991127756, 61.09069185872232, 89.76176261901857, 110.64813275491039, 112.35122588373001, 105.83978545281195, 97.67821957988124, 101.73067123659196, 104.97576575125419, 106.53699459568148, 106.19894904475059, 99.56087097044914, 92.5643196413594, 89.85289496760215, 100.45888977666056, 101.36708321109896, 89.41811592348161, 84.50693976494574, 104.34501724858438, 110.69673876608573, 116.55625774014382, 108.84361497817501, 117.0650048409739, 108.8228734847038, 118.3122322636266, 53.56718186409243, 78.84210371202039, 111.68749024791103, 87.57621011426373, 84.88460909935736, 103.09753879424065, 61.186480060700454, 103.74364729850524, 117.14917106013145, 98.88624683503183, 101.52348379934989, 107.19935740194013, 108.1864453900245, 103.60410505725493, 102.97933424672773, 101.64455167708859, 97.90248501685359, 98.90441525367, 94.93676524008475, 104.81353652092719, 113.06612491607667, 112.29456332422073, 115.17580309221822, 106.37188634564801, 90.58539759728217, 91.04020426350256, 108.35267543792726, 113.01506350117346, 109.46835440974083, 109.39195448352446, 116.52905218062864, 104.46430437026486, 51.810968076029134, 9.171278092168993, 0.553476890969661, 0.28420011122380534, 0.27349924187987085, 0.0376854699495579, 0.08401413538282917, 0.14010531587466118, 2.7444828998657966, 23.698352613756736, 46.405777239030414, 52.449173004396506, 55.66878388004919, 40.339702329327984, 49.669110774993904, 29.9651881571739, 27.221847157324515, 36.766831028846006, 64.8684520875254, 72.52871159584292, 84.7030504288212, 88.24846513809698, 88.7092024280179, 64.27088291414323, 8.316257288379054, 0.41623606977443545, 0.1356947178682012, 0.14135607698511693, 0.09663500492611239, 0.15985700842593947, 0.015898879332047318, 0.04954103297824341, 0.039536614166272264, 0.03154281417899315, 0.02867034643948559, 0.0760837693909003, 0.03504935757166917, 0.14261860520608965, 0.04181967109381672, 0.06241676465217626, 0.02038493699904892, 0.04281989463995542, 0.06356829822423958, 0.040204776901631586, 0.01736760969393917, 0.03220755824699037, 0.014353405154730766, 0.03398573258891702, 0.06633041291347434, 0.04928138279806703, 0.017182928878032876, 0.07470730091294936, 0.1102622535320059, 0.028147623581331105, 0.07362000764377656, 0.1702780564946513, 0.03253987186678475, 0.06995757110416889, 0.018570406039455728, 0.04605226857107013, 0.02861620509065688, 0.10827100715569912, 0.22419805187852154, 0.27278555436961116, 0.25237424479376885, 0.10386134377650677, 0.3294106981446666, 0.16925185107656066, 0.23831072443675613, 0.31829730577526555, 0.16665554845765715, 0.29116504555267675, 0.38361806843069296, 0.1641172386946217, 0.12770121857043237, 0.050139412764580026, 0.13320174518852465, 0.11375446533483845, 0.12398144801057155, 0.25222370851664777, 0.42244760259505243, 0.249929535653322, 0.41607298497711465, 0.5785275983714289, 0.29733793689839305, 0.33500611241306033, 0.24604848826364165, 0.12049296705593025, 0.18536231240197537, 0.19655009190882408, 0.3133772746209176, 0.7082827293103742, 27.109090781980946, 158.94262929116528, 134.60753871548562, 147.63413798424506, 116.843367392017, 91.15978948531613, 61.10183923475204, 38.056875044299716, 55.549649730805434, 93.91329334628199, 62.807607420029186, 68.71325738968389, 59.60163070309547, 53.02459255341561, 24.93353443761026, 2.0708893672112496, 0.5801030428659532, 0.19475758406183413, 0.25721405122068625, 0.4535737549585681, 0.3974016755819321, 0.5840509697314232, 6.189316270812866, 4.151205170539118, 12.441166889282966, 13.862599518991287, 18.785978171133227, 39.97547887986706, 66.12424204426428, 91.12696709171419, 113.06333218851398, 114.10304269483014, 110.51027713283416, 99.30748585731753, 107.56131372144146, 110.8156728744507, 113.65317821502687, 113.54729775459536, 105.27805497569423, 97.11164105323054, 93.83123736227714, 105.23052369394611, 106.36623813259988, 93.08124096162858, 86.64684372563516, 108.47659095641106, 112.79035091400148, 117.98069784718176, 111.95625889685847, 120.463926869054, 114.60541202176003, 120.72323476114582, 59.29138691194596, 91.08870044831308, 121.05523986201133, 96.63893268954371, 93.77900708106257, 107.0660517292638, 69.07187969453874, 106.09481796141594, 125.1810633751654, 102.25459006524856, 105.28109089020761, 109.44125867659046, 112.2901467354067, 107.84862733656361, 107.33140791616133, 104.27458716977029, 104.02727388566541, 106.24227554567399, 100.15112492345996, 111.98544917568084, 120.11435739455686, 117.34985520762783, 121.83294388555713, 107.88529365293442, 94.59405991338915, 98.18745305461269, 119.20623456278156, 117.6109830794796, 113.59719814792757, 114.23776826550885, 122.63486462254679, 107.60783303168513, 54.314389459548465, 9.930150816517493, 0.4156682454049588, 0.14549500489186856, 0.41959398636414164, 0.14825479067381353, 0.1643920191113026, 0.27673541177665034, 5.82142883731473, 33.624231969156575, 70.92609390135735, 95.34218926583567, 126.92331744778542, 75.81238654352005, 100.73729961149155, 40.71169991647044, 23.132542871659805, 38.40205930894421, 69.70439326378607, 80.06416520764752, 96.09402133572488, 99.89832816585418, 99.11131243551932, 87.20843299742668, 19.559053797875684, 0.8677463822307125, 0.4266796561498796, 0.2972507560926099, 0.23343645937500462, 0.290337456089835, 0.11920242299956661, 0.1878726599557746, 0.1806073578735513, 0.24723243118534166, 0.5239084711478603, 0.25124356030456485, 0.21170311186823154, 0.4976134530959591, 0.37636009014902577, 0.3006179270244414, 0.1349101365814286, 0.2362342277962354, 0.18190636720147826, 0.16527133483079173, 0.12572192316574435, 0.2504681873946421, 0.14240374818684595, 0.13877218499058677, 0.0944376502546572, 0.15403713039573164, 0.18240276153289503, 0.15299551128860445, 0.24961249782673775, 0.16613546668762164, 0.16601755043431637, 0.2817401722554238, 0.16883725961369855, 0.2244395687575302, 0.13587395179896586, 0.12231892230169428, 0.1200246575078176], [0.09258928693710797, 0.04967553503510933, 0.02079565971789341, 0.021299268682337096, 0.04812606858209737, 0.07870405822271302, 0.05729691861497779, 0.0837485786647566, 0.15738519509473156, 0.09792951731792382, 0.05611825020863645, 0.09699891967278335, 0.057575169409955704, 0.036072019833110036, 0.012969757475319409, 0.022986801416282693, 0.00786634306648686, 0.05853176424880663, 0.047802381112330386, 0.20844740672938286, 0.20117599126552382, 0.3882479361228405, 0.1822970720428613, 0.3073263444727467, 0.17629298051038098, 0.03362736814925748, 0.06321968991429576, 0.12207005863949177, 0.10717685739960402, 0.044898563139741464, 25.662720703309585, 120.71823766154628, 116.98727915363928, 112.97747150544198, 90.1456920562252, 62.16231476876044, 21.32014701443334, 15.970282189307676, 30.000426730801983, 52.167958674892304, 47.58485347993913, 53.63654898058984, 42.76216207012054, 30.611294700253396, 9.329618292470133, 0.19447540323580467, 0.07763581756021708, 0.1356960815047064, 0.08675237111146412, 0.06669097219503696, 0.0577721995632014, 0.4297357340974193, 1.7562614693757028, 1.839373796697586, 6.194636965951612, 7.155733858385394, 31.950807648320353, 56.73873978276407, 96.88612045780306, 102.57359643136303, 105.47819783610683, 98.97470412715789, 97.45043969923451, 98.90526248562722, 111.21363655213388, 97.40566192134735, 100.17650265847483, 98.63048476557579, 103.96704196929933, 91.48272606634325, 88.8309371086859, 77.41532587235974, 85.81667407866448, 75.4435896104382, 80.59904313856556, 99.00973873753702, 114.60833810990857, 107.55290415979202, 107.07620282326977, 102.72866341375537, 109.50433038896131, 105.36358617967176, 117.3186174515755, 74.07744376890122, 33.94673316709457, 97.12824836854013, 81.5741757423647, 96.47322823924404, 92.1971465695289, 56.721528422447946, 108.08161612479918, 98.99796378227973, 90.8309301253288, 90.86697670721239, 100.05401488273375, 104.31886288427539, 105.47761732532133, 103.6069134742983, 103.59738211477958, 91.47699940589168, 92.1847911034861, 92.53846337718349, 100.45468499583583, 104.4764558730587, 101.64002526190974, 103.22063845972862, 97.58756576045867, 95.3704381758167, 84.79125668925624, 81.1549057499055, 88.47139696921073, 94.51581647319179, 95.49403990468672, 102.10332778192337, 100.96926858348232, 89.82787024590277, 48.55525962768063, 8.91414515433773, 0.4249897274759508, 0.18348948789700387, 0.09735004075111882, 0.08247540948251564, 0.07485550828278065, 0.11441388317654211, 0.9345955822256304, 13.552462612428974, 25.028312629269017, 37.70853719403667, 69.11941097628686, 71.57135517366471, 66.81366135997158, 39.941452318622225, 18.997625343261227, 12.70094350461037, 22.770057032185218, 51.87408685684205, 67.9279596574845, 79.00208934660881, 78.16825620589718, 80.58710344376104, 23.399862204828572, 0.6209259071657734, 0.047901064728296576, 0.09239126853043995, 0.13439788422997923, 0.06805078592151403, 0.016008037285158233, 0.076432783727444, 0.05770067376415095, 0.057605502661317594, 0.02185355819341156, 0.0349911617025012, 0.08996994039344211, 0.20150456637624772, 0.06430177378558344, 0.05687863077788104, 0.04440794128083414, 0.047396932908844565, 0.11799108477369433, 0.05887209114828899, 0.05778074910443637, 0.028682356782918497, 0.06790797947154892, 0.02463466994794867, 0.06121503699931407, 0.05853490137885656, 0.09859278092100736, 0.020199708430276766, 0.18106907906551517, 0.037273893042677836, 0.09372704241785312, 0.03949606896287972, 0.10819937793477889, 0.02130135435671095, 0.04739863745447609, 0.06091326347462112, 0.05035147739333972, 0.0630245443373438, 0.042228830993295684, 0.05371015241009094, 0.06881760162932259, 0.01977116267587389, 0.039355702502953435, 0.11488599252075919, 0.18148105050767624, 0.07603799563742454, 0.03579317148955118, 0.06355823948979378, 0.024993559157836343, 0.0779264023707759, 0.022438035399142294, 0.027731762327734503, 0.03623561407890051, 0.0376674822050958, 0.06989292860511812, 0.07565493635352581, 0.08641421224080748, 0.3089943323885241, 0.1660755432901844, 0.2731141754456105, 0.12152746154536163, 0.04996998858968577, 0.060101520540493156, 0.024614224976469434, 0.012418053510989393, 0.049466488792771296, 26.57372255479136, 142.23628197946857, 131.40609233610093, 125.29824026169317, 106.84031148110668, 83.13867584351571, 39.65674707966466, 33.07009127832229, 34.76229982991373, 48.8859821134998, 51.79227798215805, 56.704858349215606, 53.400539967321585, 41.25468930890484, 13.982702493667604, 0.545713049509833, 0.025819516853399338, 0.11480523153178154, 0.07485653484059919, 0.3222577658391768, 0.5992836781567144, 0.9811256177002384, 0.6554628055422538, 0.19693992340997343, 5.5121175896736885, 11.78211848581991, 40.004994715413744, 70.17447363945746, 101.62310415698637, 110.82594163956182, 109.51073169708253, 106.02929084531723, 102.3171361800163, 104.8244877784483, 111.56937983728226, 99.23711069168584, 104.70430635636853, 106.44316365641933, 107.45890848098263, 94.21107968976422, 94.16664708045222, 83.07452940171765, 88.66538955319314, 80.2950829844321, 85.12901982953473, 102.99245065258395, 119.0346073335217, 109.24135115838821, 109.90296086957379, 104.3428207212879, 114.93331432342531, 108.22278222730084, 121.31351224837766, 79.14018815563571, 41.14741248469199, 106.43658191927018, 89.26551218955748, 109.71070197320755, 100.00566774798979, 60.873984829072036, 111.8472013165874, 107.05886594710812, 97.7695402022331, 95.67564564366495, 103.38724505516791, 110.4651463416315, 109.52135347550916, 109.49220242038851, 108.78001766820108, 98.01185638673844, 93.93450552417387, 98.52700479568975, 108.19637683130081, 108.21468645526518, 104.8174745805802, 107.30436709619339, 104.8246446732552, 99.58813928788709, 90.0847541132281, 84.82055679444345, 91.3777320615707, 101.14960347452472, 103.57836646418419, 109.83409189408826, 105.76560558811312, 98.60056492590137, 56.437599812784505, 14.086709041749279, 1.2884419723864526, 0.5637172188970351, 0.38285964138565526, 0.03878756020698817, 0.05982107490361218, 0.20237018444365074, 0.9994707268572623, 16.59143755512853, 30.26374524639499, 37.7850430242477, 53.03775995008407, 61.25267790209863, 36.943118033870576, 21.358274413693337, 28.18270037251134, 26.380441880995228, 33.93937087828113, 60.333941136637044, 77.46987035197597, 88.56098390394642, 93.15074536108202, 90.80727823318975, 27.940527354517293, 0.8047474788561945, 0.06412668822092876, 0.09226071182638408, 0.13446736840471146, 0.03393478391151275, 0.014140584014145838, 0.02743132562646943, 0.08106467389171162, 0.1118380351052169, 0.022342810670154232, 0.12152268881759337, 0.10297237534917171, 0.1631988984562697, 0.06969019109683652, 0.023503657956157, 0.016971073008232543, 0.08691278992280846, 0.04431502247649816, 0.17617425220387598, 0.03264770257256685, 0.057854067549229636, 0.02894758025274402, 0.01664998640696849, 0.05390524053044858, 0.05073787682058831, 0.03252357717663531, 0.030878399528803366, 0.03122346851253702, 0.04480704244586729, 0.03547019648155378, 0.05744178584145923, 0.04578286992205728, 0.020833801320423524, 0.05500307899989909, 0.07424560270362324, 0.2702374540029034, 0.1624345265689396, 0.10058388940148777, 0.26184263188512097, 0.16807426668463216, 0.2238082050556137, 0.1526401384222892, 0.26208661556724583, 0.2618751140131105, 0.15208952038759185, 0.18062997278907608, 0.1434336921140071, 0.16945607479541533, 0.17179806686697469, 0.2000683200575652, 0.14916467330148145, 0.11909701696206486, 0.17779043725421353, 0.25918875009782855, 0.24039883497020892, 0.39054745627987775, 0.4644625609920871, 0.313915527996517, 0.5089415033017436, 0.2548993012357143, 0.2089882494821664, 0.14789255365969675, 0.2651966567481718, 0.15846459765828427, 0.10470702823611999, 46.98966126288138, 174.05796912408647, 138.91834905070644, 150.67504175247686, 117.538128975899, 88.93353846765335, 37.44156106825798, 23.7596219970334, 46.00725266241258, 74.64738768915977, 68.16960903906053, 82.71468331736904, 68.14805953733384, 52.29868342799526, 18.821687429181992, 0.9164046099589718, 0.1712651914286037, 0.2962198162511472, 0.2814899066523198, 0.39800084826927035, 0.38451331877900713, 1.358205615993469, 5.190584726871983, 9.223057300813737, 11.765995583226605, 11.749831495746491, 40.89948338847007, 70.38665033155873, 103.99513398447345, 113.07238501887169, 115.30835566982147, 111.50888904448479, 107.36542271029566, 112.19404082144462, 115.64702879997992, 101.62136262462985, 109.24342216983919, 110.49053192138673, 113.7617023529545, 100.54734706878664, 100.32247758680775, 88.04247010138728, 93.58178246405818, 84.61861748849192, 87.33972257183444, 106.87371438549411, 123.71768982179704, 113.04294370835828, 115.91334988993984, 107.97873235517933, 121.45984803476642, 111.84675416638775, 126.9386225361978, 84.04548860365345, 45.241382429676676, 117.40981255808185, 96.90078227750718, 116.46572159182642, 110.72254011707922, 74.16534408446282, 114.51958271764941, 111.1404686589395, 101.42893898871638, 99.99787792082756, 108.91797527190178, 113.45714599855485, 112.84355394301878, 115.82701852244716, 113.01014484897738, 99.95972110379128, 98.10744454783779, 103.22780855240362, 111.37707387247394, 112.30561656336631, 106.69198313067037, 111.13196496040591, 110.0612912639495, 106.17974512038693, 93.10279830809563, 87.50695674650132, 96.2212787135955, 107.11009210155858, 109.52827253649312, 117.36559175675916, 108.95864240584835, 101.09088559304514, 58.52742687348397, 15.685585775683004, 2.4369948189104758, 0.7071473257195565, 0.25428390280613977, 0.2522934071959988, 0.18620937581985228, 0.3344492584226593, 1.808487583071955, 23.125294331581365, 41.14156815313524, 54.47135879147438, 96.35838908533897, 91.6663714378111, 91.40682820350894, 60.122191982884566, 29.065716112813643, 25.417662782053796, 36.63632200610253, 72.60095380967664, 92.48835902060233, 102.78770292958906, 100.82003024316604, 110.48693118556854, 44.45675934514692, 1.9322671669144786, 0.3342527109048059, 0.14741030131136218, 0.2457472318482976, 0.13272675535371228, 0.13499694966500805, 0.21497089055276689, 0.21396466470774145, 0.1830338647649173, 0.143456690073494, 0.2625507422752919, 0.32854590745222184, 0.36176620712203367, 0.15054936190285992, 0.19615319707701284, 0.14416786481536206, 0.15795102763560512, 0.2475290144643476, 0.332920667865584, 0.11391361244022848, 0.1386775118449042, 0.2320547125512554, 0.12413926978385258, 0.11391588006048434, 0.1318325928502506, 0.14219414653076282, 0.17046619236709612, 0.2713609985526531, 0.14176152135816314, 0.1650495064114371, 0.17727703577087772, 0.24399722655934675, 0.133178471437385, 0.1223449309867236, 0.18264101487734627], [0.033425270324392665, 0.03779469493536219, 0.005021379319875832, 0.10106508454848682, 0.0611739861778915, 0.06215115813838859, 0.06840050505894808, 0.1271838640734073, 0.03211223201135234, 0.08773179154001898, 0.042450383620997595, 0.04327575525929851, 0.06698659020325831, 0.022196357641669533, 0.03334974171593785, 0.09353751226538613, 0.03148832042971927, 0.06728580116384453, 0.09002614060356733, 0.16489204469948046, 0.14892041382770385, 0.20844566004891552, 0.286139294264778, 0.05110683625624065, 0.06382378088610788, 0.11339752198827845, 0.18297833871216546, 0.07280836047063913, 0.17537790380658644, 46.031030070397165, 128.16652836338167, 107.14143183923538, 114.53309136052286, 78.06609415238904, 71.03825015406456, 27.074493515876036, 31.829818217985093, 48.808829092210345, 81.44258806782385, 68.39502765286353, 41.876486962841405, 33.96729030916768, 26.114728758412024, 5.091905247780585, 0.17588419599398492, 0.10113289865154414, 0.05950387236812423, 0.15530060856573044, 0.01363925128844717, 0.08310944683128789, 0.495085975816173, 3.4147387406518384, 16.61238693421887, 43.306622351369555, 73.40588692695864, 100.20375528643208, 112.99189013819542, 111.10426518224902, 103.34425587807934, 100.89086040373772, 93.24392518689557, 95.35369749992125, 94.61082412350564, 95.05187111516153, 101.70547393060501, 104.71533606129309, 95.63148760026502, 99.84128905880837, 97.54507864675215, 96.15892087259601, 83.78449409238755, 78.21479120562154, 76.43048148001395, 78.34351554993661, 94.81506193837812, 105.44342210215908, 105.3862653240081, 105.02070042394824, 100.98219671557027, 104.7675584977673, 103.62985933980634, 109.11425067532448, 98.54406710593932, 111.91243817729335, 49.342447942303075, 79.65372054807602, 81.98607167889996, 97.42054339378112, 57.38938254694785, 37.44194546053487, 108.78111593184933, 102.0192321654289, 102.24376432357296, 89.0093578830842, 91.76788237787063, 96.53552332232076, 99.96153323881089, 94.84793140042214, 99.35738625064974, 93.66317164513373, 91.55044970973846, 93.51323512292679, 105.13744584975704, 103.87612142870503, 102.45484275202598, 106.11810899549916, 99.96924461856966, 87.73795297068935, 90.32460704926523, 99.40855749191778, 105.12316057758947, 99.55329295127623, 94.13624086687642, 91.85840283670734, 99.13991435881584, 100.44474570981919, 79.2915367311047, 42.830611351997625, 9.229493910266507, 0.35922831104647734, 0.17232783198837312, 0.08204380320685525, 0.0795723422760925, 0.09067848745372989, 0.06020079404416104, 0.20299909666420954, 7.22633897296844, 24.34128203699666, 36.762002591163885, 48.2652081981782, 63.96215315788024, 72.0339830460087, 36.62215440504013, 29.633679236135176, 30.324769481535885, 35.2780326720207, 59.62112880522206, 65.33171930620748, 80.32836821771438, 86.9767072123866, 92.50540564137121, 43.036649534779215, 5.750833528657114, 0.6651771068572999, 0.05321612912079981, 0.0227645899529659, 0.05468771124498979, 0.03454061390291299, 0.029885340819976507, 0.031549120997829784, 0.03894575736335209, 0.1190561461713045, 0.08521627289273086, 0.1194462534641066, 0.06888877885836749, 0.06560528004962592, 0.044058578374284896, 0.026156187598263065, 0.13511198542771802, 0.04218558532997005, 0.05773715104066557, 0.06418235983038623, 0.0776084222560448, 0.023690715559848377, 0.11401749396276091, 0.06279740309823426, 0.0781401102581332, 0.09910638924808272, 0.03186243755232183, 0.08588433986709965, 0.0030266498769408153, 0.038642466984569065, 0.10733123943810502, 0.13249211794426366, 0.02504978809625872, 0.057649901286969264, 0.043146213621742306, 0.018897131047842484, 0.03413685492330021, 0.045784344641311515, 0.12144810249728542, 0.06572226933654278, 0.042483179845036044, 0.10365654549170887, 0.06800892687733136, 0.11080209270960863, 0.055027390800176136, 0.12465280150213551, 0.07859230131631897, 0.017124696619688504, 0.048768444797925414, 0.016822693268618277, 0.014722897979100386, 0.07876009755437413, 0.1318626081751239, 0.10317763328672418, 0.2036957770225502, 0.23951545898472112, 0.24947357544254875, 0.06889551277122191, 0.06245434509530183, 0.09815794175430652, 0.17286412417888644, 0.054075235440846414, 0.14518404980340313, 54.117729663848884, 145.69212544348935, 120.27563741130214, 124.96993787827031, 97.64403220145934, 95.37566277288622, 56.35272364462576, 45.176671166573804, 37.424922373987016, 48.54301006563249, 57.955411941774436, 54.7001467212554, 43.53310784985943, 35.76928992425242, 7.016720156515799, 0.08501778717242903, 0.058504851580026655, 0.09044958804283412, 0.18538106623436176, 0.3694085776805878, 1.2324764916012365, 0.9070574792642748, 2.2471506316815657, 20.0725136264678, 51.54554128646851, 85.98599495426302, 112.28322767442273, 118.90806382702245, 116.82222581678822, 108.19803991625386, 104.0766643708752, 97.23624690886467, 99.66952846896265, 98.07803461628576, 100.49208871779904, 106.67875689844932, 108.40194825203189, 99.35045934492543, 104.7253381052325, 103.08133156068864, 105.07984192140641, 88.53737908024942, 82.88449056686895, 79.1952190091533, 82.52032203059044, 99.30269272096696, 109.1072767011581, 108.47837955720964, 108.82743912358438, 103.54104118962442, 108.9522332529868, 107.54417296378844, 112.22493340892177, 103.23137006452008, 117.81663294761412, 57.962064281586684, 85.55866056872954, 90.49410835389169, 105.73241449171498, 65.58947393971106, 45.831102940344046, 116.54434942430066, 104.45773047785606, 108.34952185230871, 92.92597786072763, 93.04560230624293, 100.21509093623008, 102.23741792863416, 97.65543845392044, 101.9270956900812, 98.52479257891255, 95.44049170709427, 98.0255219244188, 108.02983299378427, 106.10354915741952, 102.87914122304609, 109.79899452578638, 106.68728413120394, 91.7011393270185, 95.05348713167253, 106.50313669635405, 111.53454919015209, 106.59809727822582, 100.29425221104776, 97.57889732237786, 104.82219711426767, 106.40071576641452, 84.27570819854736, 49.24516531728929, 11.711278519322796, 1.8316501595320243, 0.6441628247980149, 0.40971660025177464, 0.11473594653990962, 0.07161978271699722, 0.19141983090629502, 0.047066013569072376, 9.946266854962996, 31.2306369504621, 38.577459858309844, 41.77317957724295, 54.96078037446546, 59.679556431308875, 27.204308279099006, 30.6697811618928, 36.734640136841804, 52.31329425688713, 64.78729040391984, 75.54259023358746, 88.30298608349216, 101.94974345545616, 105.69596782807382, 52.11563817916378, 6.8742993858552754, 0.47937596397053817, 0.09211753765421529, 0.01580478266752776, 0.04839766590345291, 0.09808442029621332, 0.059511506434289686, 0.10090422906702566, 0.02775505140063263, 0.015035441742398807, 0.01611966204138533, 0.014526417493940362, 0.06782316587745182, 0.018765509481571855, 0.027160032825063796, 0.022229490944394664, 0.14416473917663097, 0.08704864029442111, 0.008524037210360892, 0.10804470478286667, 0.07396580441103828, 0.005608995092071353, 0.0329205907520748, 0.07613054671955687, 0.06805286201978884, 0.05191716958858794, 0.02342241816222668, 0.08107836388291852, 0.013676084795846574, 0.058087226408984394, 0.02292233128701487, 0.06851128137279903, 0.021816908547113982, 0.06824683548221666, 0.11038806049093125, 0.1258720687380241, 0.11056905642392174, 0.1737113561361067, 0.21338309672090316, 0.1292719592851016, 0.10915781521508772, 0.20475290174926483, 0.15832829529479628, 0.22425933891246397, 0.11556774948633487, 0.22363444099262839, 0.145714964056688, 0.10790981202115936, 0.156236951870303, 0.15655751370133894, 0.14139750702006204, 0.14140821692924346, 0.2481958480371583, 0.2297113721649493, 0.4074779381194423, 0.7676950541715469, 0.47917132656420436, 0.2121165848427242, 0.188871470069693, 0.12767236769920395, 0.22316780151619067, 0.10344626967825236, 0.3473458276881326, 80.90706686819755, 169.65492033189344, 127.5520420074463, 147.74757292962843, 105.1999919645248, 101.10593180502616, 49.1015830347615, 53.059274150479226, 69.31570991393059, 112.61886489006781, 94.61805697410338, 70.4355073744251, 56.22690969897855, 45.73120409442533, 10.36712540734199, 0.9543649407644427, 0.24464234920038333, 0.30910458776258654, 0.4355801882282381, 0.2820443398048801, 0.6278819242312063, 2.045771121498077, 10.269577041749033, 26.660546179740663, 51.05963022478166, 85.61507209654778, 117.75665990767942, 126.62830814238518, 122.84877500226422, 112.86393457843413, 110.10333907219672, 101.85894058596705, 101.2808773594518, 100.7779275217364, 104.14517248830488, 112.19302100519981, 113.29278299885412, 102.25715529534125, 110.34844798426475, 108.45518266001056, 110.45697996693274, 93.84666012179468, 85.16343470542662, 82.19147051534345, 85.9439157670544, 102.4941449011526, 113.0855171142086, 111.5653633302258, 112.26185860172396, 103.71222126868464, 113.59363663581111, 111.07167813085742, 118.62832823107321, 112.3468485186177, 120.85322210865637, 62.41164415113388, 93.85486572019516, 101.49015149762555, 115.5068511347617, 75.45454086795931, 50.48632483328543, 119.7561587056806, 112.15193025527462, 110.7542642470329, 97.38253562681138, 95.49079218218404, 103.00306458627026, 106.47360909369685, 101.56709271092569, 106.27155211664017, 105.6301583013227, 103.17775126426451, 104.35684711702409, 113.57509951437675, 110.78021464809295, 106.9854627117034, 115.01736287147769, 108.4992701007474, 97.51182479243126, 100.57892999341412, 113.68138790130617, 117.43477452185847, 110.09518838697865, 101.26914947263657, 103.99243539379489, 111.48926934888287, 113.02837602553831, 85.65494691171955, 50.61133469304731, 14.097820135854906, 2.2750001953494166, 0.7965813493055682, 0.2755431951053681, 0.30870254481992415, 0.24996469908904648, 0.40666763160017233, 0.713246550050474, 15.618792714611178, 46.54603727402226, 57.24811054045155, 69.89030576521351, 87.80952053685343, 100.54587225760184, 55.34683181393532, 45.55260289099909, 45.823222898667865, 51.60044662414059, 76.77841924851941, 86.19144870388894, 101.20666611579158, 103.76850728065737, 119.65813083033409, 72.83579395663354, 12.506997989070031, 1.0471459718481189, 0.11903782900903495, 0.15822973042245836, 0.16742820941632794, 0.1360263573306222, 0.1136808825897113, 0.18947614326832757, 0.0950756329562395, 0.1878646773196036, 0.20224226308205437, 0.3192105438680418, 0.25021980636783187, 0.14106430473827547, 0.192153436702586, 0.16542029296678884, 0.22524134105732366, 0.23307267486328082, 0.13845576003434198, 0.17843393578885064, 0.17772354245666536, 0.09890642497808703, 0.13285927324285432, 0.2502021710238149, 0.28340457487971554, 0.15748846374692457, 0.13119166837103907, 0.254878341070106, 0.19583067406089077, 0.15255281972067972, 0.1880179715132521, 0.19926144561219603, 0.15717683450108574, 0.1406340391164826], [0.04965057589053627, 0.022751030196706136, 0.06284499248009055, 0.07219782669938381, 0.06673246351701599, 0.06722072199467691, 0.03451712947759417, 0.11080491957404923, 0.030263470328082482, 0.03469095482761341, 0.053722815843479294, 0.05853679361602953, 0.03877199330036679, 0.06822860258961878, 0.06754465461257966, 0.03450777171359908, 0.0218960358535931, 0.03991087109992101, 0.08367030746153287, 0.04762097149186077, 0.076137587067581, 0.09858877428116337, 0.03970842853549027, 0.08724821385957542, 0.07809988298122922, 0.12746857298958686, 0.007899761258158833, 0.17124571747356848, 44.40279929868637, 145.24739142387145, 106.69225769658243, 111.46712364688997, 80.53619107892438, 60.84949747208626, 24.923542199596284, 26.510829310263357, 27.60435473534369, 76.70394128368747, 66.41643508788079, 43.749206912133005, 37.90087061543619, 30.290132991729248, 2.7462048203714433, 0.21130647750631457, 0.16131211582931781, 0.05716794005204594, 0.03633955305802726, 0.14155694523886328, 0.2054612879310885, 0.41533646804671137, 10.092860537190592, 40.95668723506313, 89.58719361212947, 110.10949719336726, 107.44572931720366, 101.27083609181066, 102.63088657009988, 101.25739020685997, 98.57662277836954, 93.83644626986597, 88.71927507462041, 87.93213382844003, 91.02235747921853, 92.16758758791032, 97.16193368357997, 97.35254518447384, 99.17804764163111, 102.94442515219413, 97.10003868226083, 93.95509012283819, 80.26217429868638, 74.03154419314477, 75.8728773363175, 86.25286517604705, 93.8571563843758, 98.70224845024848, 99.75285530090333, 97.51258573224469, 101.81631226693432, 107.95156601936587, 103.04418671515681, 93.63812338921332, 88.0916723128288, 101.25390714214694, 90.24247261785692, 47.153949737548835, 81.76422242195376, 91.55918875048238, 41.046050594699004, 87.40413573480423, 106.97090287362377, 100.37120911382861, 102.72649826542025, 102.17738213077669, 91.09965170583418, 90.13343857180688, 96.89323563729563, 94.23938351292765, 95.2448360381588, 88.93930435180665, 84.08706572748001, 93.64489340013074, 100.12323687153479, 101.1544672135384, 99.40669044371575, 96.81851448551302, 96.59600627037787, 94.72655757780998, 100.27878238308816, 98.9849336685673, 104.32553091356831, 107.32344550471153, 109.41453949097665, 100.7962606799218, 98.93139331571518, 103.35088468367054, 94.43240334910732, 58.7134531236464, 22.43911881600657, 3.6582568864668574, 0.6247972252388155, 0.1448169711136049, 0.03864543557527565, 0.04480318136272892, 0.09809051069521135, 0.16000129342559846, 0.23704582134321814, 3.8728173990403456, 20.52745169208896, 31.36210891508287, 43.68511146114719, 44.700036510344475, 66.7594777384112, 61.959967536311, 27.748601859615697, 15.167241615633811, 36.91800702002741, 58.64514112472535, 67.44801059845956, 72.51135118546026, 76.72694990711828, 85.6228776131907, 76.54230040888633, 16.93850455745574, 0.6672623981871914, 0.05194436954033952, 0.11357825745137469, 0.030080932643144365, 0.12778453829307712, 0.042632298859497236, 0.008483837704144178, 0.038471587242618684, 0.047838490666641344, 0.057847957998033495, 0.02669581610168661, 0.04286607058959142, 0.03618716284812939, 0.033197048901309895, 0.14109366122753392, 0.0437480791081344, 0.04185274693994753, 0.03716533455336767, 0.0594877960130332, 0.11210829560314456, 0.06696170766747768, 0.09136294104879902, 0.024614969996975797, 0.03852526702347302, 0.029169958340184345, 0.07647648904352419, 0.06827491260464154, 0.019526495260276625, 0.02397558726971188, 0.07742161937658826, 0.07806920882074103, 0.03369639650167477, 0.04191603346337234, 0.03683074565243818, 0.028729817845047485, 0.004840654869293494, 0.027402246844083555, 0.055145659453926556, 0.017106346898682175, 0.04429128524216433, 0.06729369953034386, 0.016523595306000883, 0.09103685572382905, 0.020228886804092797, 0.0800857590811868, 0.02920725533077794, 0.05075083519782751, 0.06762373786900314, 0.0825935785448359, 0.04399145375035944, 0.059100438975879264, 0.10539996242451091, 0.12090318415674473, 0.17671589168810076, 0.17266230597611398, 0.09303869709612862, 0.045240437536830866, 0.09321697341698794, 0.03953843745553205, 0.09849581717243118, 53.3748366755824, 167.6436544233753, 120.97598445030951, 126.26796783939486, 101.97537222216206, 74.29587271905716, 52.92425047966742, 36.9361715162954, 19.713716776140277, 54.631462097167976, 51.19385373207831, 50.01591890088974, 41.46310052564068, 39.05419257379348, 3.609326054011622, 0.17071622814382278, 0.08860420480731035, 0.2270098856740421, 0.2819981293812875, 0.12649797789391973, 1.0051590829126298, 1.5111393193083427, 10.727489244553352, 47.79738710772607, 97.64978239613195, 117.10964141353485, 111.15924896732454, 106.80697133464199, 106.19180248629664, 105.25993362549814, 100.9698098705661, 97.67910603554019, 92.83742643171742, 92.0658883740825, 93.67060845898044, 99.80045718531456, 101.70985914045765, 101.74045362780171, 104.32515436603178, 108.2047079455468, 103.1923895497476, 100.74854896914576, 83.68652897496378, 78.13970919578307, 79.0093457314276, 91.19896611859723, 99.7697058031636, 103.60615253448488, 103.60052001091742, 101.2202924297702, 104.89030514993976, 111.15288688290505, 106.81790690268241, 97.41239270856305, 91.0317554781514, 107.8026806923651, 94.43646692460584, 56.116585193141816, 90.39035381809359, 100.1273004470333, 50.32751198737852, 93.45607834477579, 108.5474132722424, 103.29673244107155, 109.13675723537322, 109.0524733451105, 94.65240124733218, 94.07274553852697, 102.80439653704244, 97.81882870581843, 98.33570295764555, 91.7036339544481, 86.4386207826676, 95.03876255404566, 105.12483935202323, 104.87349387138121, 104.09068292187106, 103.0509175023725, 100.32530169333182, 97.93698618488928, 108.1625581556751, 104.8236091675297, 108.54766430393343, 113.6518132302069, 115.33787542773833, 108.50087827251805, 103.08828200063398, 105.87616151379001, 100.38481973832654, 63.74562655725787, 27.51851562530764, 5.13990133039413, 2.09793925766022, 1.2598757181436786, 0.5323698203409872, 0.11122130368265415, 0.12022747928577086, 0.134196357140618, 0.3010510424933126, 4.257183199928654, 25.251073837280277, 38.38882523198282, 36.63056396668957, 45.25722880517283, 48.97562003904774, 36.51452456751178, 32.01555421275477, 25.599986314773563, 51.461622176631806, 69.83749497321345, 78.58059929263207, 82.75717043107556, 89.56698556100169, 101.21654264388546, 90.8702636534168, 21.277718736279397, 0.5168917186317906, 0.020260436220034476, 0.018816996335742936, 0.025259474022013527, 0.023930112290526592, 0.06558604358184723, 0.04079271873999988, 0.010138217983166537, 0.06645658759460335, 0.005393985334047747, 0.1264504957643728, 0.01427531493977914, 0.023202608384552504, 0.035188494460476984, 0.05945708737858842, 0.05464461113836977, 0.013781278243949337, 0.03898286283196461, 0.07949628506696994, 0.06088061663772791, 0.0163120343800514, 0.05777789542691843, 0.06316474991880598, 0.035625302473143224, 0.06019808592334871, 0.024531092945366137, 0.04056818603027252, 0.007116813653884757, 0.04461809452022276, 0.04610983624814018, 0.04897664834354674, 0.01843942224138206, 0.21704421558928108, 0.07506275804893625, 0.10204647382300708, 0.15962995528694124, 0.16273051229936464, 0.18904158755415873, 0.25159582285390747, 0.2403777675522912, 0.15277552148026807, 0.09303721088555553, 0.14119473886826348, 0.14767170583288516, 0.2288946611506324, 0.09712318679498089, 0.22439953300260732, 0.15427772796923114, 0.1419109544686733, 0.14706528595378324, 0.1335711374638542, 0.22534643299877646, 0.2929797852712293, 0.24316332453200895, 0.33792527512677256, 0.19854806453710605, 0.13492403341637504, 0.15752733504820257, 0.19576809999923553, 0.11346407204626069, 80.07406526996245, 188.1290328118109, 130.87216361876457, 145.41024823342602, 107.48553352971231, 94.18126967645462, 40.68997783045615, 41.20889955951322, 51.229072693855535, 115.33297246502293, 100.57473305732974, 68.52213598066761, 58.752617989816976, 51.490102506453, 5.321603167441584, 0.5668985675419531, 0.2712510189702434, 0.3764756162080073, 0.22958087674792738, 0.4790227055068939, 0.9837983452504682, 5.995389386530846, 17.394536964354977, 47.32330591447892, 97.58047411518713, 121.25837941323559, 120.8110958530057, 111.31780685917025, 111.04381361315328, 111.3007837726224, 108.54280056491976, 100.54075748689714, 94.89424674741684, 97.84405739076676, 98.93314269281204, 105.041363470016, 106.59311586810698, 106.45303233977288, 107.31359251083867, 110.88517727390413, 106.83916614901636, 105.21676401938163, 89.6450799511325, 82.04414629167127, 84.84737011694139, 95.70944078506963, 103.48745376833024, 110.10559051267563, 107.68979487880584, 105.25526600499308, 108.89462932463616, 117.23857756583922, 111.35407309378348, 103.73899536748087, 95.95736595892137, 116.17540344115227, 95.88867741246378, 64.11358018075266, 100.44551449437296, 112.74879732439595, 60.438841004525464, 92.65287891510995, 116.8627360559279, 105.99513484585671, 114.06377976940526, 113.0600844660113, 99.59547412010932, 98.55918392058342, 107.89225978236045, 103.34202012708111, 104.38184830450244, 97.20487579222649, 91.23215721499537, 102.03932254545151, 107.79715015042214, 107.73099545509585, 107.21091270446779, 106.94374438255065, 107.33125886609479, 104.42208397773005, 114.19776008975123, 108.80970216566517, 112.67817897181358, 118.96074125843664, 121.30660103213404, 113.07858236374395, 106.42850183671521, 110.18522247191399, 105.09283281141713, 66.8397137426561, 28.400476248033588, 6.445376440402001, 3.520293644359035, 2.2799311049522895, 0.3976276102325609, 0.15633200805994774, 0.25619690096186054, 0.24163667983826131, 0.5810578335677424, 6.809760216743716, 37.74712547179192, 51.76309162570585, 61.62783691959997, 63.28141404736427, 89.4718288606213, 84.88082793451126, 41.59048341935681, 24.129172025188325, 55.075207679502434, 80.63312069062265, 88.87659349749165, 97.75177971009286, 97.4101177338631, 106.91117302063974, 106.64827223747008, 32.09631189223259, 0.9609430619785864, 0.20508968932253702, 0.14098305345302628, 0.18620621953760425, 0.19364415187268488, 0.14730056687708826, 0.15790993467934672, 0.20689984783530238, 0.17616404791272458, 0.15645462809310806, 0.17221964505170623, 0.15795614510293932, 0.09897293673167307, 0.15749281512633448, 0.20053972460089192, 0.15240884115619047, 0.10069298032190531, 0.1686944301810957, 0.18383529998602408, 0.13548917647811676, 0.20241250314058798, 0.23357835418033987, 0.2173713810982243, 0.23758743018392595, 0.14031603601911377, 0.1485916854993951, 0.12371871815693956, 0.14349836525657486, 0.10237371594074274, 0.20524128280099363, 0.14450440724049846, 0.09720993093064717], [0.03893413197910113, 0.06510719266389647, 0.04203046018618249, 0.07990759001263688, 0.13246030997364752, 0.015332771957130923, 0.10883762110625544, 0.051498108002687656, 0.015702669850490507, 0.0076069854361365645, 0.06958925135193333, 0.047844906653007196, 0.02691525432671751, 0.06792931502024013, 0.0489689453294681, 0.06009334255190146, 0.028814464815021045, 0.14132086758411702, 0.21795311762440592, 0.05816567764287034, 0.27548935444604966, 0.2187618919678273, 0.3407401273087148, 0.10264375427317235, 0.21193822425219322, 0.11944879687601521, 0.33675901351436494, 38.50390757283857, 128.64576355103526, 106.53420971285914, 112.47944031992267, 84.27922264222177, 51.54185033613636, 33.81591035473731, 37.526900076097064, 55.99398759103591, 91.81634718371977, 69.81516884219262, 56.3367360638034, 33.28247193367251, 28.543252483490978, 1.47336395277131, 0.16184359698766665, 0.021997442912130107, 0.2734499977480981, 0.1602368961058317, 0.05023440000631156, 0.39446087854523815, 0.5910884985519994, 21.629106229351414, 67.02914853249827, 97.749324306365, 108.94842855391964, 94.90733961905204, 99.9107228555987, 102.24755333315943, 102.43217145243, 93.67474263714206, 88.45617817294213, 85.86324045735022, 92.56646910021382, 95.59111856645154, 102.00234243946691, 89.91544892711025, 92.29714347470193, 91.48059229696952, 104.1744569040114, 96.59536300166961, 98.53049570514311, 91.35673953640847, 77.3104730729134, 72.95732467405259, 79.16835861821329, 84.65477389674034, 95.99944514612999, 93.40983360044419, 91.82204246520998, 84.11803676236062, 91.56660987484841, 88.38810151623142, 91.50634657952094, 73.61562390481272, 88.44223022460939, 92.90777021838774, 116.50614553882231, 64.02395402231525, 55.200864730342744, 64.07440746984174, 58.98194720668178, 109.28556411497055, 98.28452387163716, 105.87003477158086, 100.46785631487447, 101.40322392986667, 81.59594489682107, 81.65117971358761, 89.0094284857473, 88.7156351151005, 89.88890232578402, 86.92962308083811, 86.75390089711836, 85.22601219915575, 91.97618376824164, 95.06253996203023, 100.73162786422238, 104.12568615328883, 96.69870176622945, 95.33388168581071, 99.96849152349658, 104.10463087020382, 96.81377626234486, 101.8566656112671, 102.25245629587482, 101.9148422056629, 103.60481108388593, 101.87873286585655, 100.44031343152447, 80.08362800844255, 38.71613525575207, 13.778225414214598, 1.794302208769706, 2.2974106573289443, 0.5921192238888433, 0.3801476901337024, 0.1393200757522737, 0.022462707260743748, 0.03513452739665105, 0.10883175287275546, 2.283133965346121, 16.25081696817952, 32.742375289240194, 39.01112494930145, 85.76023901662519, 160.59214284343105, 56.72097929062382, 39.074078990567116, 19.632309944398944, 23.568098545074466, 43.36303780155797, 53.29739732127036, 77.1359589792067, 76.44202893780124, 86.98777614101287, 88.47210299584174, 23.30486632162525, 0.5704746046854604, 0.2005304089717327, 0.052680089739301515, 0.03849705583566139, 0.038332910006565434, 0.03650123591444666, 0.04660265677939019, 0.023123067390594273, 0.017537545232522874, 0.024182231826407295, 0.14133284919925276, 0.07660581234602198, 0.05586883113268883, 0.05994636475318863, 0.033644903901844256, 0.09911450211920085, 0.04556603256552931, 0.04576484387319896, 0.07314447388653794, 0.06464901845902205, 0.03856074838568607, 0.11590168721252873, 0.07421908840056389, 0.0721660570331639, 0.04479614484514441, 0.059343246713040344, 0.02475261109911146, 0.003556872017666578, 0.08192801667797951, 0.05503521255788304, 0.032292532719551556, 0.017977308429357026, 0.047127304433454434, 0.055984759387830575, 0.03272563286666428, 0.09096666674820647, 0.05576866130614954, 0.0979699437776881, 0.018100658161265236, 0.017152586050571936, 0.026240658368014043, 0.013079719820750818, 0.04649107224277912, 0.02457174157062846, 0.09208698606779499, 0.04678839862707161, 0.03285685223677466, 0.09881844744086267, 0.03467594716517675, 0.11717492534268288, 0.059209441796185515, 0.19697983659082846, 0.15083145079833848, 0.22253030911087993, 0.09536414932940276, 0.11672784409095203, 0.39865566958342835, 0.1869551011271054, 51.007435244898645, 152.11772088081608, 119.32486272627308, 129.57174101183492, 96.78930851720996, 80.19751010402557, 71.0615647223688, 38.9097003013857, 31.029327184923236, 51.0483887118678, 47.8040708264997, 53.729685660331484, 41.11334669974543, 36.93673241523005, 2.272678642503677, 0.16486982814967632, 0.19308823250955154, 0.12161129454691565, 0.2810162191669787, 0.33037449804044544, 0.6269386554917982, 0.18281307822513967, 23.237154445340558, 76.43466272661763, 103.15657831007435, 111.75151117386358, 103.4252057536956, 105.75041032606556, 104.89855781678231, 103.88837491312336, 99.09061016574984, 93.4610362206736, 93.57959378150203, 98.18928087911299, 100.11096769763579, 106.58852669500537, 94.44513536268666, 98.35918226549703, 96.74751174065375, 106.4252462694722, 101.56412739907543, 106.31084642102643, 96.77797286741196, 81.86418010342507, 76.31496767843925, 83.36731864560036, 87.19162956360849, 99.9940339980587, 96.49690366560414, 94.87770219003, 88.51049515508836, 95.2427964056692, 90.12476228898572, 93.085461431934, 75.18703522220736, 94.2017444487541, 95.57273833982407, 120.1131885282455, 71.31020376759191, 62.63124588997134, 69.3061314859698, 65.62016648630943, 113.4524783780498, 101.88962921019524, 110.01620754118889, 104.09257350429412, 103.0383659178211, 85.6838155561878, 85.2391129155313, 90.16258962692754, 91.9323238249748, 93.34047040631695, 90.05901552015736, 90.54342823643839, 88.50144232473066, 92.65215719899824, 101.73341689571258, 106.12258834223594, 108.05681105582946, 99.08727615110337, 100.35704935750654, 106.15375549562516, 106.37852299597957, 100.37887342514531, 102.48791617731895, 102.44804920688753, 102.9502224153088, 108.57637605359479, 103.6489377483245, 100.90898959867417, 82.19387885062926, 43.649833663817375, 16.090747983224933, 3.158804822352625, 2.670205956505191, 3.3214890476196044, 1.5813464358929665, 0.8203675213360018, 0.03723852276321381, 0.0640849938856498, 0.1655352980859818, 2.1333209977995966, 20.513195837697676, 39.67502924703783, 35.88593336843675, 69.24993176614085, 151.4100625438075, 42.782193614590554, 29.40659557619403, 30.568997821500226, 39.588136980610514, 52.13575209340742, 60.19513630097913, 86.10305416968562, 84.06492787022745, 99.86741988889634, 105.03973960876466, 33.57357063601094, 1.0168999012920166, 0.11295004237082698, 0.08057901245211402, 0.012929978359851145, 0.044390872841881174, 0.042665367044748805, 0.01768407678501981, 0.03747405649553384, 0.05837039165799657, 0.05256977690864475, 0.03993265864048754, 0.1756242930047935, 0.02466539964981137, 0.05756681139070181, 0.06504593627347101, 0.12868063133810798, 0.03624167000394195, 0.017101447766406402, 0.08152539150849467, 0.110449263255202, 0.016821136194912177, 0.023187646687391306, 0.09729880479074295, 0.022272190770074245, 0.041602699671902006, 0.10267488808641512, 0.03792952641003555, 0.0650111252381917, 0.057612784327037876, 0.024760162810825055, 0.06638353345014396, 0.16626462911165532, 0.17193001785105275, 0.10848194180477051, 0.22120952756414491, 0.1720524080578358, 0.13653430426793714, 0.27075024261589975, 0.12349718085099613, 0.12553302886625453, 0.20045732418375634, 0.167731074616313, 0.11835551279927455, 0.13713105611743467, 0.1939002091004964, 0.13549866064661933, 0.1545597249341588, 0.12680776086786102, 0.29282365655226095, 0.44645888190115657, 0.20286087908091086, 0.3848929919542805, 0.31693872545034657, 0.45042632868693727, 0.2952444637494703, 0.22949619338877741, 0.32865705148827645, 0.3338659284335952, 76.03364744494039, 173.77420917634043, 128.1433471556633, 145.6182279894429, 107.395977973938, 82.79645689072149, 55.75841003848661, 58.636555056418146, 79.9754882627918, 126.557352465968, 99.7978448867798, 79.63233578589656, 56.29399791840584, 48.06851310114707, 2.6244419476678296, 0.46582006879391213, 0.5278721487810535, 0.5652362180332984, 0.3226708710914658, 0.5939621249994924, 1.0543062585976817, 5.061937849367819, 33.130942929175596, 77.34833178981658, 105.37012084837883, 121.06891324443203, 105.71196325363653, 108.9420037115774, 110.67833500523722, 109.84599236519107, 103.15203620541482, 99.0466090171568, 97.33075249579646, 103.7659969637471, 101.84696951220113, 110.61010145371961, 96.62801281098398, 103.46417057898738, 102.76593377513271, 113.75991375215592, 105.90653634840443, 110.78349374955701, 101.22858432031448, 87.7654330961166, 81.93996813989456, 87.78421340450164, 90.86947133464199, 105.26538572003766, 101.17189038184382, 98.65583896636964, 92.46601720010081, 99.76238666042205, 95.43249007194274, 97.69761177801318, 80.6144815875638, 99.53257499202606, 101.66865856416764, 128.4187367654616, 73.82253677614274, 70.12109018141224, 78.67021760632916, 69.22498549184492, 118.63248594345586, 109.25096096531038, 114.3556982471097, 107.15444626346712, 108.03075082840459, 88.46906708132836, 88.33502400305964, 95.45207054384294, 95.72595396349507, 97.09924636348602, 94.74414548566266, 97.52025788830173, 94.65031454640051, 102.00546464612408, 108.24976813408637, 112.55029401471539, 115.71154394457417, 105.70582082194667, 104.02445762388169, 112.32718175457372, 111.8784155384187, 102.66329319246354, 103.92298590752387, 105.00552869612171, 104.39763976681618, 112.55359665040048, 107.83347129821779, 104.55762540140461, 84.99145446285125, 44.63609010942521, 19.41477921701247, 6.544844315898034, 6.550858289964738, 4.538898121926093, 2.1565424098122508, 0.625943415347607, 0.10830254699554175, 0.11488946289905619, 0.3073173352787572, 4.670707900677958, 29.364698779198434, 56.17801343241046, 61.24906147679975, 105.12407056746945, 184.29717525359123, 78.67872130486273, 56.791915355190156, 32.131387687498524, 37.699531432121034, 62.42269739027947, 74.2957393584713, 100.54286772204985, 100.19405918736612, 105.22045889208394, 120.93358362874677, 48.31475165582473, 2.2858859983182724, 0.4068770800386706, 0.16414828057731354, 0.10097500026947069, 0.1839057647532994, 0.11803770888476603, 0.13952394707068322, 0.20389664527629653, 0.1752017495492774, 0.11091084655133948, 0.17935848133938928, 0.28197646441478885, 0.14678851370849919, 0.1781984710044438, 0.1821136246285131, 0.23840812485544915, 0.23084305256845492, 0.10377083814913228, 0.19017449369834316, 0.21286865335799035, 0.16603512449129937, 0.1872783289441178, 0.16535894464581244, 0.13439668913281735, 0.16074671229768187, 0.19685782942800753, 0.15948488887759948, 0.13409763905069522, 0.13722051986523215, 0.1629187860676358, 0.1468140397581362], [0.020245545386006276, 0.10007095523178579, 0.027279527219493064, 0.019999903123525363, 0.08586484292942671, 0.0626885611563921, 0.019720372961713903, 0.13069516678731288, 0.04717771684931171, 0.08613416113920751, 0.027823296428147345, 0.10459505682510715, 0.09224773429694677, 0.0378946885616789, 0.07880757968392103, 0.06614386284303281, 0.004890675622699482, 0.05889376377566688, 0.07564623359470599, 0.05514671282482244, 0.07528595776567537, 0.14687630738462173, 0.02995112095959485, 0.18705191931897597, 0.23525967202599973, 0.6537727542942571, 19.951632061312278, 134.97158173591862, 112.34863711941628, 121.02302151341593, 80.36471289973106, 64.7173741555983, 28.895557811183316, 16.85690749076105, 60.60839722233435, 80.74715968101256, 49.77995303369338, 58.80646428754253, 35.506506812187936, 21.01233901516084, 0.892140644211923, 0.07358820733403967, 0.1264662235494583, 0.06532309156271719, 0.0573748795525922, 0.3468450819773059, 0.2711969331627892, 0.5087338934742636, 16.93175611957427, 85.89862808104485, 100.92137644367834, 106.33531416616133, 100.22577547257947, 107.28532006663661, 98.09108826421924, 95.21242941579511, 86.5838033922257, 90.87220130428192, 89.18653134376773, 95.53051794728925, 97.79066608798121, 101.88621674814533, 92.28094408589025, 93.44974763931768, 88.58081540753766, 89.52623997965168, 98.21300337391516, 101.38894650243945, 98.49016589503135, 86.51705249663323, 72.83375432414394, 70.95242869469428, 73.20394762100713, 84.83878012626403, 87.81892638052665, 87.67190025698754, 79.27418416546237, 75.79288451902329, 72.72427312789425, 78.1097815113683, 74.43594840265091, 83.89232004842451, 77.81341506588844, 89.65207745951992, 89.0874993416571, 105.23020990433233, 39.670126284322436, 37.440043111001295, 105.16521623057704, 93.68508984965663, 90.59947890620079, 83.83982304603823, 89.89950841472995, 82.2218845736596, 76.30669147737565, 73.33355842098113, 85.07435767881333, 88.35796202382734, 85.63858278336065, 82.59399983190721, 80.46984026508947, 80.12056889072542, 77.78981024219145, 85.58750567897674, 97.68742930504584, 91.98917465825235, 91.12877138199346, 97.43914327313824, 98.90628230187201, 92.78606691668111, 95.40020112068423, 96.39121147894092, 98.67694131789669, 94.47077197413292, 95.26465185226934, 94.22313705567392, 94.097989912956, 89.54217264729162, 57.465480450660955, 24.782944840769616, 5.712634546141471, 0.8968164158924934, 1.5987995122709584, 0.452699740567515, 0.4943697142504877, 0.19298940716731935, 0.20606652803478703, 0.006132375349425861, 0.047568513621245666, 0.49045947891089225, 12.936580873304798, 31.33520930044113, 57.654028784844186, 35.849859329961966, 40.90200547249087, 52.27132489604335, 24.301607262703683, 24.392994565348474, 15.257492411521175, 39.22550601343955, 47.45900031059019, 71.50138793453094, 83.46513471295758, 82.09386625597554, 93.61782904594176, 50.83089328581288, 2.4206797201787276, 0.1519825898351208, 0.10167069237438903, 0.06720050493435514, 0.0699541696737851, 0.055508980482456186, 0.06808996365796174, 0.0560210949380792, 0.06864331662654877, 0.07662560805798539, 0.032372382063899315, 0.047156649431394, 0.0730185596753032, 0.029345564844627536, 0.02419079285896113, 0.010353693618409095, 0.03433131102112032, 0.013503252487299184, 0.02070664796197126, 0.09589408299014454, 0.01565254854804446, 0.030806553888044534, 0.036808437172083125, 0.11346449339461905, 0.05242205600464537, 0.045384354814286196, 0.07217138134423765, 0.04278212650528839, 0.054522584823350755, 0.04275971843350319, 0.020920798265104814, 0.06922908277521211, 0.01956876799193842, 0.005376382548767593, 0.03524845999275004, 0.04238329730146835, 0.038008697766570315, 0.06464693469986801, 0.04355485641187237, 0.062138406604888945, 0.08375855312953073, 0.049402259981199625, 0.047924192922730605, 0.06449766246782196, 0.008253036479976389, 0.021178745814869483, 0.03848967074807133, 0.029623781165648854, 0.01714492900176875, 0.13407090258213783, 0.05149624640903166, 0.10117565401859822, 0.09930924166955295, 0.2252153247114151, 0.21083891872436772, 0.4226357537892557, 26.7185462674787, 160.74456614832727, 121.13254977810769, 139.34729945275092, 94.14789815102854, 102.85282211918985, 49.53216514279766, 31.733447544036377, 41.58593346995693, 64.31621766859486, 57.93760830356229, 52.20041236569805, 49.591165434929636, 26.140163367794408, 1.1407832440830048, 0.15992580312153987, 0.47179435950613796, 0.2266108457960429, 0.18796702666628748, 2.584990993622811, 1.195259082221216, 0.810947765506083, 21.162216701815208, 97.97224044799806, 104.00777186116865, 113.43821664010326, 105.32266016929381, 109.90778538488574, 99.95357867210143, 100.60977551244922, 91.97141416611211, 95.27809773722004, 92.78815361761278, 102.00264838434036, 101.08784183379143, 104.45082710635279, 95.84546858264555, 101.83728910261586, 90.9302366933515, 94.71264100843861, 100.7719498295938, 106.90102977137413, 102.83626971706268, 92.53206991380262, 74.93539164143225, 76.87525472333355, 79.1280915660243, 90.69389035624843, 87.97917873628678, 92.96148315552743, 82.90547524729084, 79.77855390118015, 74.36249809880411, 79.2227226688016, 77.01340060080253, 87.50984361094814, 78.89100782332882, 93.74332920197519, 92.3685698355398, 107.71593355363416, 47.26182276202787, 45.28393230130596, 107.63063769186698, 98.17321485088718, 95.08745485736479, 88.38326915617913, 93.53224292878183, 86.8139680739372, 80.20810834823116, 75.72463527802499, 89.58759369388704, 94.05052138913064, 92.59870313828992, 86.84250723931098, 84.17426001641059, 82.467252362159, 81.68353142276888, 91.23507545840357, 100.12267989497032, 96.19608925234888, 96.12052086860903, 101.25470730566211, 102.60470867156984, 94.66837313867386, 95.55654679575275, 98.25141122264247, 100.16424917405652, 96.68494993640532, 93.23093429688485, 91.95699553335868, 93.06985824338852, 88.94315611931586, 58.7730456936744, 26.14648818969727, 5.808901767576895, 0.3834610816932494, 2.2386604162954518, 1.9209416907641197, 1.4444802316927141, 1.0611284860680181, 0.10769633396017937, 0.10649018214955445, 0.01314602951864682, 0.35623327498474433, 16.162316529981553, 34.17150066744897, 56.68410116626371, 45.79160467270882, 41.66843660416142, 53.16070272076515, 26.832718618454475, 34.15580334201936, 34.64823730530278, 61.810533077486106, 60.040234058134025, 81.3707459357477, 92.73971234598469, 93.53203896553286, 108.07503438765004, 67.48290400351247, 3.4654316979069866, 0.2415439525559064, 0.03971723088574025, 0.030007792313793497, 0.022118869763348373, 0.06339100632636298, 0.030098608206777327, 0.029252232352812445, 0.014397625664940045, 0.07594855487226479, 0.02555832683649515, 0.06868664655954608, 0.038259181704732685, 0.0326210273910434, 0.04198047677956281, 0.04315544881166951, 0.021888786746609597, 0.008687060720647776, 0.06920054600003266, 0.046321628915686766, 0.06668274441073019, 0.03551777437209122, 0.04476658151214642, 0.044231086053074374, 0.07910546531239826, 0.046103335992102666, 0.02093329507436964, 0.034447216293624336, 0.05394413864480392, 0.06057383672844979, 0.10972919423253306, 0.17077471129596236, 0.12118151156051506, 0.06310835435626007, 0.23292092816723933, 0.1457525330084947, 0.10768334110898357, 0.18288296076559252, 0.17207459396412297, 0.1830085378981406, 0.1261168491515902, 0.13793719511839653, 0.21730606444180015, 0.17042062545735992, 0.16012037413254862, 0.16139417916776674, 0.21946883790435331, 0.17687123899738635, 0.18684064759121788, 0.17321310787191316, 0.26127897503395237, 0.29422035741229213, 0.1601975957953161, 0.35363387737062674, 0.3597126318322074, 0.8050157934907944, 39.28949163806054, 185.25635165552941, 134.6430596997661, 157.55549092446606, 106.75425467952606, 99.62806117150092, 47.86224349852532, 27.768209788107104, 91.59071676192745, 118.9363911844069, 72.53563065682688, 89.34997650884813, 57.726996637159786, 37.32226610183716, 1.3150448352098465, 0.32886959492198886, 0.5175628729404942, 0.2234714328041, 0.17362895571897108, 0.9322283705396037, 2.549884309691768, 3.637758334798198, 23.169897563995857, 98.55008402178365, 108.65160711349981, 115.22418945066391, 108.54464407890075, 115.47496226526077, 106.01196181389594, 104.5277447854319, 97.12503202499883, 101.57993455086987, 95.6982934090399, 104.93438474593624, 103.6402379312823, 108.88461159121607, 102.37935281568959, 106.46589771393808, 95.91680865133964, 99.96896220791726, 106.41007454164567, 111.02888507227745, 107.72064039784094, 97.05242895310926, 79.84442618585403, 80.09313583374023, 84.74026587701614, 94.87313655114944, 97.71097921556043, 99.73250604444935, 87.94635634268485, 84.7113266298848, 80.03740679833197, 84.97774185672884, 83.54883024769445, 93.30398451897406, 84.50242903924759, 98.85533855807398, 99.81405996507215, 113.44690076766477, 53.73653411865235, 53.337911482780214, 114.26578183327953, 107.03978753858998, 95.9883213043213, 94.1676825861777, 97.85268660514586, 94.6153191597231, 85.25293534801853, 81.15893794644265, 96.38603395031345, 100.5205572805097, 96.29384256178334, 89.51495924303609, 88.22762950774163, 88.0252665858115, 84.63974337424003, 94.62890625000001, 105.99446019818707, 100.15360386140885, 104.18958940813619, 106.1558186623358, 107.46054018697431, 95.62629438215687, 97.91881776625111, 102.4355133118168, 103.72333726575299, 99.47646940908125, 96.88484960986723, 94.45163080769201, 95.35245018620645, 93.79833652127175, 62.45428031490695, 29.651571127676196, 9.562868898914708, 5.311448151065457, 4.288181201104195, 3.1057878607703797, 2.420148974464786, 0.8833243205182014, 0.6359366339541251, 0.16965663661399197, 0.2196616775566532, 1.8316668296052565, 21.772982689642138, 52.83079608794182, 81.75661302381947, 43.44962020074168, 56.03710228397001, 77.46779934052499, 36.33116945143669, 38.39768586620208, 28.567847705656483, 60.155908676885794, 64.17004269938316, 94.74030156289378, 104.99751137148951, 103.76806797519808, 120.01791415675994, 84.6417437830279, 5.548661822272885, 0.37904050922201526, 0.19869829437905745, 0.11556531332673566, 0.1488524465070617, 0.19014152127408213, 0.21918780621021025, 0.20271915281491898, 0.15803189587689218, 0.2315785735845566, 0.08670275925748772, 0.09674567398765395, 0.17723335343743526, 0.24651514306183786, 0.10578253907301735, 0.12730188757902192, 0.2037851335180383, 0.12707996722911635, 0.20939780008648673, 0.17862185715667664, 0.13984630154746194, 0.1543336677094621, 0.11890544901571928, 0.20114977573675497, 0.23227441124618056, 0.11767308933720474, 0.24901623627351177, 0.17625179562357166, 0.19206887591750393, 0.12083613614161169], [0.08510833876507898, 0.1688677652348434, 0.019899989936440703, 0.11414841072814119, 0.013428217047945628, 0.09177662852791049, 0.028088429882641763, 0.129759696822974, 0.08168692880820844, 0.03078117147989331, 0.06500809153001155, 0.0790502073904199, 0.04174936337456588, 0.06240011756158164, 0.054153311291649464, 0.10592732202982712, 0.039336734165948246, 0.046018629650314974, 0.056569318948013175, 0.050541631907465, 0.07340706584434356, 0.10078322547938555, 0.10613436495224315, 0.03312690972140239, 0.15991536900401115, 10.78388802466854, 116.17367759827646, 111.24562740325929, 109.62444120837797, 77.90814030554988, 47.773923489355276, 20.12772490901332, 34.385850352625695, 70.51571199970861, 77.82275030689856, 56.831813704582956, 56.09397272909842, 32.78664119781987, 9.510208137573736, 0.38064773104363875, 0.014676094794976375, 0.047547676029705235, 0.03209337284187636, 0.09281040289469304, 2.954022043174313, 3.037424625888948, 1.2498217027994896, 13.17423532086034, 89.04016417841758, 109.7570957676057, 109.94075682855423, 105.25103768994732, 108.64256212788244, 103.60397169666906, 98.61448934001308, 98.09701888791977, 96.46696813644903, 93.05486694458993, 91.61592975739511, 97.65778403128348, 98.79114504783385, 98.13489329430365, 94.22606314382246, 94.77796416128837, 80.05213922069919, 86.43662037387972, 93.54118593277471, 101.98605675851147, 94.01306275398501, 81.99601096491661, 68.44262169253442, 72.50223559717979, 72.62850453776699, 84.25712400867094, 79.50518038965042, 85.35183398954331, 72.83201279178743, 74.85619898765319, 72.36953396950999, 81.3358211517334, 77.78890025231146, 84.18578393997686, 72.57428169250488, 89.69288579879269, 81.41250348860218, 110.17955856938516, 56.11993881963915, 31.375701888915035, 106.33580838480304, 82.13064239871117, 82.68375150619015, 74.88367126834008, 91.75944143725981, 81.95970550660165, 87.26296178756222, 71.45414690817557, 76.90628851613691, 83.92405986785889, 85.78884878466206, 83.44831558965868, 79.13999988186744, 72.76639938354492, 71.3759740706413, 81.31772333575834, 97.93868849354406, 96.73631729618197, 93.07306674218948, 93.69132641823062, 94.48669679703252, 98.21778082078504, 101.24130848915347, 96.78260910895564, 96.67990576836371, 98.06409451269336, 91.94514213069793, 84.7061961696994, 86.59229924601894, 87.80925381568171, 80.38004936710482, 52.67430528517693, 14.100717786819706, 2.014100433837983, 1.7964635573087202, 0.7734290077801674, 0.3805398352203831, 0.6271888291643513, 0.1874257855477833, 0.05531653536543731, 0.0542188041482962, 0.05777112320966779, 0.18637337992268224, 13.484898805618288, 19.087020081858483, 46.19284745185606, 40.337898039048724, 41.23047651783113, 59.36466855387534, 27.553769888416415, 20.241320671573764, 10.371151720323871, 27.05504640456169, 49.504873291138686, 61.396048376637125, 74.07310562749063, 77.88041699317195, 98.98857362808721, 54.442576439149924, 1.0082856409492031, 0.02076105935679328, 0.08022502620494174, 0.05807293503875694, 0.12711519961275403, 0.12965986024468176, 0.05909114249891812, 0.08025860383866296, 0.042727427827494766, 0.05561110000276277, 0.024319782913211855, 0.03473416984742207, 0.09701396563961621, 0.017103127414180387, 0.05265231522160673, 0.025871166501254327, 0.042988560387804624, 0.03189968474720034, 0.010484299160570148, 0.06586583421355294, 0.0398714788588545, 0.035560506756507584, 0.0027802259653746603, 0.09990112119985205, 0.01099219534456009, 0.034926281716193885, 0.05630406483467068, 0.02597227095506124, 0.08000561096254857, 0.10762840494393341, 0.1192600864376272, 0.022909173726915352, 0.05136740957236579, 0.0487278689510159, 0.007248234600880214, 0.029359950060625712, 0.09539597262177738, 0.07967421664826332, 0.09764740543980753, 0.03879309136180147, 0.05995219851273203, 0.03773476770748535, 0.05425322830917374, 0.016970343309484662, 0.05736365636450149, 0.04157258858603816, 0.03949171375303019, 0.05435386927978647, 0.03644166874789423, 0.03593423508948857, 0.022491044853062882, 0.08230538392860083, 0.1366539212364343, 0.1410549125003238, 17.772280823799875, 143.4829838045182, 124.70686451081308, 124.79655342717325, 92.32424705259263, 70.89849610482493, 43.78332368789181, 44.99361807300199, 28.17829555080783, 59.148436131015906, 57.00487652132588, 48.63294609131352, 45.03037460388676, 12.804165578657582, 0.3802413980086004, 0.10016562837746837, 0.14956000531392713, 0.08176971226930618, 0.43072168925596827, 10.390179138029776, 4.636308223970475, 1.16680130602852, 19.10524537486415, 99.68072291343444, 114.25649366071148, 113.4857871455531, 109.67489857827465, 111.17930796838577, 106.55662998076409, 105.08163836694534, 102.64869413068219, 97.36582632987731, 96.96245762609668, 95.6183555049281, 102.25824571424916, 102.42708021594633, 100.45023702806043, 98.96561991783881, 99.06382037747292, 86.2061732815158, 92.38949175803893, 98.72094246648975, 104.55220468582647, 99.59565454913725, 86.95962921265634, 71.54585976754466, 76.96817567271572, 75.21505663471838, 89.22171500421341, 84.77847760723483, 87.06183833460655, 76.17029497700354, 79.15735244750977, 76.32812330799719, 84.00890857942643, 80.56643255295293, 87.19492435455324, 78.23411280109038, 91.3888402138987, 85.0226765294229, 113.30645638127481, 61.34174708397158, 34.26031097289055, 112.35965897960048, 84.72842031909575, 86.60201887930594, 78.64606365080803, 93.46804157380136, 88.69919253933816, 93.04451973207536, 77.04333612995764, 79.41797041123914, 85.80125916388728, 89.9569554482737, 84.47428995563139, 83.03270909094041, 76.62940056093278, 74.99930274101996, 85.70888734632923, 100.24978822277438, 99.57790974647769, 97.04210527481573, 96.45785254816856, 96.94464222077401, 101.06448019704511, 107.5147238085347, 100.21280027204945, 97.57326479881041, 100.14652006087765, 93.28533757117488, 86.24040772837978, 84.90505249269548, 88.18153381347658, 83.99994204121252, 59.985540528451246, 17.069670577203077, 1.606261453801586, 0.3695247472534257, 1.6620582726693924, 2.1388939503700506, 1.7210418947281378, 0.49630169606497215, 0.14170164392600137, 0.04969200975592098, 0.1283522017840897, 0.06589701399207115, 12.718918746517552, 27.15304093976175, 31.92659485724665, 25.725357032591297, 32.81198951505846, 35.907482870163456, 30.072361038577174, 28.95937281270181, 24.819891606607747, 40.59429553247268, 66.30347867165843, 69.89218065815588, 84.5491523127402, 86.44295892407818, 113.37185013678767, 73.97457568876206, 0.9659771176595843, 0.017279643648033662, 0.06431290504312323, 0.017000167112376903, 0.08148750079975975, 0.022590071293375185, 0.014984760238158127, 0.005975992863832583, 0.020784882776018594, 0.07471791123070064, 0.0014248764965750819, 0.14191144476494483, 0.04737693801402085, 0.04615447236104839, 0.0271943248357744, 0.05345866489674776, 0.116694618857676, 0.0518158812736792, 0.034980409658483924, 0.03225691346151214, 0.04066671259821423, 0.035740307592336214, 0.07524302619839869, 0.030950009597525485, 0.04830745521992926, 0.04769912395145624, 0.05912672728300095, 0.03409259036303528, 0.058708604154807914, 0.25552306534542196, 0.2807853202666006, 0.08613706461244053, 0.15159496466719335, 0.18235963078275805, 0.26787722903874617, 0.15323077689015097, 0.13826880393730057, 0.2572124577578037, 0.24384474441889795, 0.11890067628795102, 0.17925381840717408, 0.20408134907484057, 0.20900632915717943, 0.16350233056131872, 0.20024185429417318, 0.18806893168197525, 0.1707257889211178, 0.14007002986486883, 0.1454527015166898, 0.1996859502527983, 0.23370359423420123, 0.2600551648966728, 0.3001986624252412, 0.43104313974899633, 24.560554296739642, 167.18707484583703, 135.51374743061683, 141.90721081149195, 105.33100697302051, 73.41496329153739, 32.41343552066434, 54.11818465878887, 100.1954947748492, 104.12123818551342, 78.63497903270107, 81.30403426385696, 54.69274913111041, 16.685046880475937, 1.2427964926727357, 0.34483149647712713, 0.29134881472395313, 0.1601399859834102, 0.3723194053576839, 6.213161339682918, 5.028304996029024, 4.210788915234228, 18.88676347271089, 101.83082503657188, 120.55370992229832, 117.5310294858871, 113.35473291335569, 114.37171720689344, 109.97329681150376, 110.00604075770225, 108.12742940841183, 104.21819133143272, 102.31486120531636, 102.38648368466286, 108.86063806472286, 106.05546089910693, 105.33588640151486, 102.60340644467263, 103.2442040597239, 89.83704074736565, 98.94742796497961, 103.57420875180154, 109.07211657493346, 106.66274578340592, 91.22708951273273, 76.4385929415303, 81.27637370940178, 80.61605838037308, 93.76022677267753, 90.68599070272138, 93.70951052634948, 81.22729701380577, 83.62186478030297, 81.58722154555782, 90.50158439144012, 83.75648052461686, 92.46368731221845, 81.52062754477225, 95.48734834117275, 91.33854758354926, 120.10213528909992, 65.86367899371733, 38.78788717331425, 113.02114317494055, 90.73467516130017, 89.84567780648509, 82.6423312771705, 96.47817042566116, 91.57145007964104, 95.78637415362944, 80.13139463240101, 83.92895498583394, 90.26783466339113, 93.76286260543331, 91.13912643924837, 87.11467266082765, 82.17764023811587, 78.98658029494747, 92.0653235527777, 106.01420540963451, 105.39441600922616, 100.20308063876246, 101.4639186859131, 100.03895298127206, 104.07252234797325, 114.25943543834072, 107.18914355001142, 102.94844165925058, 105.20302003429782, 94.49141148597964, 88.26651588562997, 86.42146433553388, 90.52839771393808, 86.52678781940092, 62.82801158966557, 18.108133769804432, 5.5038310923884, 5.9304815146230885, 3.9714468679120465, 4.066084099392738, 4.780554857946211, 0.41616093187082204, 0.21473896509457022, 0.14316609760205593, 0.21782861301495185, 0.36640287767494883, 22.212615666850922, 34.35512250469577, 73.93266908584103, 53.66332307938607, 52.26418225995956, 82.07325027834985, 38.26883992841167, 30.25080926956669, 17.32236339199928, 41.802605198275664, 70.1459030951223, 84.02779086943596, 97.36314342867945, 98.7204090241463, 123.8249509565292, 91.26374013962285, 1.859617149156909, 0.05715398576050516, 0.2174599408622711, 0.16095605348387074, 0.19650250252696777, 0.14871249756505414, 0.1441841978099077, 0.12992690317332745, 0.12863252101646316, 0.12582211214448177, 0.1677361767618887, 0.23641775181937605, 0.18057199525496653, 0.09434303073512931, 0.1161376039888109, 0.12473425963112425, 0.22783474786387337, 0.13020695427492743, 0.13171060100918816, 0.16283387288210854, 0.2174664526096275, 0.15855678867909218, 0.09468086784885776, 0.14664772206977492, 0.16649074762338595, 0.19560199681549303, 0.2222814837530736, 0.09555287508954925, 0.11111674800274834], [0.02199630527156255, 0.03996188489479884, 0.029651230095975825, 0.028655423046720606, 0.08927332898301464, 0.047234330746916034, 0.0730962869561007, 0.12997421676353102, 0.05522652386477398, 0.05541803052408561, 0.05828015799183519, 0.0724883349011502, 0.04343813908616862, 0.05481460987920723, 0.06114129337572283, 0.00840361872237296, 0.06362863530915591, 0.030924445243492246, 0.028648756166559555, 0.01621397321052369, 0.016004739276644205, 0.07403644537853618, 0.05162165117179675, 0.05088583521184422, 2.120320547011591, 114.96683489891791, 116.97857149185674, 109.57796896657636, 93.57256489415323, 53.59672515623031, 53.03082519961942, 41.01525606647615, 53.50676951869842, 93.84730339050294, 61.28381759889665, 60.17909380697436, 45.987778094507036, 9.064862228208973, 0.25122877480762623, 0.17611736251461893, 0.2877967408107173, 0.049710863179737524, 0.7015180503649097, 1.1501275555741404, 19.556468955932125, 15.469472004521279, 3.9825432531295286, 89.08999396908669, 106.56857752030896, 111.320874152645, 98.46755735335812, 109.20398666012673, 105.0651801017023, 107.47000094382994, 100.37491967601161, 99.76182968385758, 88.34887781450826, 94.31594817869126, 95.3680847537133, 98.59399887823291, 99.86175598636751, 94.67659442655503, 92.413371147648, 88.04032064253285, 77.47503219112274, 80.54850732126545, 93.28766745905723, 100.68455942215459, 95.85336823617259, 77.44958385344475, 67.55589146767893, 69.91839778038764, 69.7387061580535, 79.05953638015255, 75.1258070238175, 71.67120302877119, 68.21295122946462, 70.80289225424491, 70.66826866519067, 77.4384678563764, 72.71382393375521, 73.89686569090813, 70.71867112190493, 81.34050446171915, 78.09859491163685, 96.48286158038725, 84.61271039901241, 44.48220768282491, 99.78111205562469, 85.27024868995913, 85.43437634744953, 87.69571688867386, 97.762981999305, 97.58920531119071, 101.04172260530534, 92.38184313620292, 73.90376906241141, 77.05389515046151, 85.04639902422505, 80.34031575725925, 78.75207747182539, 74.46634677148636, 73.49583471975019, 75.9477710723877, 90.15652564264114, 88.16934308698102, 94.6634937101795, 98.03539060777234, 97.72786109678208, 94.04251190923875, 85.8455897915748, 85.6633407838883, 91.855845451355, 96.42747771355414, 90.35736668494441, 84.64856870712774, 94.30534208974531, 92.5245781867735, 90.91078958203717, 90.94709504035212, 68.89400020722421, 13.721877624911647, 1.4488910595255515, 2.407199759637156, 1.118624058942641, 0.7748735431701906, 1.325821302110149, 0.034899204338510195, 0.10525248283820768, 0.07148704266235714, 0.048209690909472205, 0.06543629637528812, 6.529952547242565, 30.06402207959083, 61.78718713022048, 59.289759128324455, 84.28156037484446, 77.81905543419623, 55.63795012812461, 35.33444419983895, 19.362978435331776, 13.971995403689723, 30.113751849820538, 51.422563214455884, 78.4117098777525, 75.2765593990203, 102.26291333475422, 31.902415406319406, 0.4366038961996956, 0.022126653216659062, 0.047326724781023885, 0.07352528087193928, 0.05637549104229097, 0.037913519002857714, 0.055718624273375164, 0.035195381590916265, 0.00851213890728691, 0.006821727597965829, 0.0756803857943704, 0.049530951261159875, 0.06021033183881833, 0.05576524455400725, 0.03540002282768969, 0.0567562252493395, 0.04431122651083335, 0.03099181693077328, 0.03118910372347361, 0.06373116085606237, 0.008505629075150336, 0.057619571866047, 0.06688220306269585, 0.07048558954509997, 0.0028047678314314615, 0.020793507010826183, 0.011511503365792094, 0.15817800416581093, 0.05254631546596366, 0.027269527856861393, 0.04237708815884206, 0.007621976819204828, 0.07316217051758882, 0.024759237759656483, 0.009375730672130182, 0.04187311721785415, 0.07267273226452452, 0.02880868851207197, 0.030043786954915816, 0.07971498784759352, 0.042129714537652276, 0.04925461568599267, 0.0066086388054123575, 0.034115565339884454, 0.04960322016549688, 0.0032229807355531282, 0.031985950077913945, 0.07312121545715679, 0.04772117579235666, 0.00822893248104881, 0.08185149215522312, 0.06120457989914764, 4.222034350518258, 146.94662494044152, 127.34760807406519, 126.19749069213869, 105.29855328221475, 82.47230437494095, 70.9815562155939, 44.063820223654474, 45.73229059096306, 76.16103033865653, 64.65571841885968, 54.71102345374323, 55.32185416067801, 13.270401050967555, 0.2888982526717648, 0.3146172951786749, 0.2469234219602039, 0.14278743566284258, 0.3102810230226286, 1.9935013714336582, 31.724071118139456, 3.6245041556896704, 6.122710012620495, 99.83446413470854, 111.03501965922695, 115.66783305137389, 104.26026267390098, 111.07939735535653, 108.92695749959638, 109.6984798677506, 102.59939778235652, 101.23312642497402, 96.2653269306306, 100.31632731037756, 99.08638969544442, 102.44347572326662, 104.03733868752758, 98.74885405263593, 96.37416485817202, 91.71084327082481, 80.5560931851787, 83.8531747941048, 97.57596338948896, 101.69849995643862, 99.39065579445132, 82.25505998057704, 71.73903649853122, 73.20959583405526, 75.74547090838033, 84.43265791862243, 80.39399731543757, 76.80728789298766, 72.36286594021705, 72.96872308177333, 74.44089058906802, 81.06920980638074, 78.37383547136861, 79.37998617849043, 74.63608341832315, 85.0925260974515, 81.07629360691195, 100.44148229783582, 89.1665429453696, 48.21349174745622, 104.22696175113802, 89.57213955540811, 89.23355271739345, 92.8520098040181, 102.96932435804798, 102.25762597976193, 103.82945306839483, 95.60757683169459, 76.80466774971255, 80.86850996940368, 88.48397993272351, 84.20119101001372, 83.092132999051, 79.4901341776694, 77.18035236481698, 79.83988408119448, 94.6987009048462, 90.40902430011381, 98.27088186817785, 100.01231224306169, 101.08632779890492, 96.4301763042327, 87.46009226768248, 88.79472578725508, 96.2384194712485, 99.1481670256584, 88.86877229136806, 84.17606430668985, 96.47783310182633, 94.31664636058193, 93.85011180754631, 98.28115063328897, 80.63392869887814, 20.453509130785545, 0.39073300277513845, 0.615511381578061, 0.8214062139872582, 2.0912376430726822, 3.008716553449631, 0.16204276452622107, 0.15695324407950526, 0.047102601928336006, 0.11466654663484906, 0.12804235752311446, 7.552070242743339, 38.36303172572967, 44.85393854879564, 39.63150270523564, 73.28977692511775, 37.306011799843084, 38.014658574135076, 38.52995603315292, 33.95172242195376, 31.89111701903805, 46.2002803433326, 62.5241534171566, 88.97675514221193, 85.39448584279707, 116.98156033792804, 48.38697033543741, 0.33000732742009625, 0.007818932757682858, 0.05557431629107845, 0.0685367614571606, 0.034982600669947364, 0.011860098269197249, 0.036086295881579, 0.02702756856207646, 0.02371476114457173, 0.06806938653631557, 0.03352679995699756, 0.09564397826550469, 0.004297652227368447, 0.027127646458064838, 0.033943785444623044, 0.02846100716851652, 0.041127771124123566, 0.04302838163810872, 0.09865285753602944, 0.040685389821808186, 0.0011007260224188589, 0.026927199552676855, 0.01761524570024302, 0.034157167744612506, 0.011419973095818874, 0.0458186500585608, 0.0391402670873269, 0.07813706888907379, 0.14683048000499127, 0.3176316366560998, 0.20272143575693333, 0.15206934163166633, 0.2874098357654387, 0.08793311178564064, 0.14777768643633013, 0.24836637920910315, 0.16309550723000882, 0.07446534736382385, 0.16166686050353513, 0.26452587016167184, 0.16121637016054124, 0.14139006064543802, 0.19154312509682872, 0.18521125518506576, 0.16009515451808132, 0.11445049451844347, 0.11756753774299739, 0.19784798274838156, 0.15598641047554632, 0.12789662461727858, 0.10615954626231425, 0.2300959329811796, 5.692729988405782, 166.05104661756948, 143.83536954079906, 140.6456353587489, 120.55733419233754, 82.83613558738463, 73.16885025270524, 57.51230178340789, 77.1992503443072, 130.26896584418515, 88.2724621988112, 89.33543236024919, 71.68785741252285, 16.39413841309086, 1.1572660241396198, 0.3961864762729214, 0.8064601450197159, 0.2842602031605859, 1.6690769863705484, 0.7683770562852583, 31.89500212669373, 26.372916813819643, 3.889497523346255, 107.35666798007105, 111.99351356875513, 125.76346474309122, 105.66659712022351, 119.67924887134184, 109.69872305470129, 114.01271835450204, 103.85787456266343, 107.81960964202882, 98.02256445730887, 104.14706307072794, 102.06757145543253, 107.11905079503214, 107.67528995390862, 105.79764350768059, 101.08819484710695, 97.48215598444786, 83.62661869295182, 90.12115370842719, 101.81466487146194, 109.73035304777085, 103.90614325000395, 86.17426087779384, 74.9840368763093, 79.70264034886515, 78.94272035168063, 88.31404716737809, 84.97691031425231, 83.58690077258696, 75.25391163364534, 77.67828941345215, 78.1504015768728, 88.49360542912638, 82.04938657822149, 83.19681321420978, 78.22629943970712, 90.24222943090624, 86.93517715700212, 105.83026193803357, 93.40846077088388, 53.51614790578043, 110.48389527105518, 96.30444080598893, 93.36219249233123, 98.33760922954929, 107.69515283646123, 109.78227738411196, 109.65666740171372, 101.16291599888956, 82.71163955811532, 86.40673975790702, 96.18228250934233, 88.62781324694234, 85.82567199583977, 82.40629088494086, 81.68674776631018, 85.95955817930161, 98.14007082293111, 97.33424340524982, 102.36030578613283, 103.9517996388097, 107.37874307940083, 105.01610340610628, 91.4533632032333, 96.39722839478524, 102.1357265595467, 104.85526269482028, 89.93007936785298, 84.08756779086205, 99.04450662674444, 100.65645171749978, 98.13996884130664, 101.32474514745898, 78.31775342264484, 16.585793264450565, 6.136815836352687, 8.070508539676666, 5.413761706121507, 4.581679903691815, 4.228075781176168, 0.22917065198623368, 0.34480220127490263, 0.19119905968827589, 0.39731434155856415, 0.2852699070447876, 13.097787345609358, 53.04730307671332, 96.1953910704582, 83.15476540596255, 114.16587906499063, 102.40707612806752, 78.91057260574834, 51.54070108167587, 30.476604430906235, 25.717549554763306, 46.98895915862053, 70.65989832724296, 105.59458240385979, 93.91627434761294, 128.7653801518102, 59.5759823245387, 0.5509803023549819, 0.07831406584309955, 0.1303376182312927, 0.1195461743120705, 0.1140206808885259, 0.09912763286622302, 0.1490018183305379, 0.1587401135193725, 0.1304336550134805, 0.1457922470064894, 0.10693861171603204, 0.16185081353591335, 0.13569347680576388, 0.20605777931069175, 0.09969109819541055, 0.24438433078748567, 0.1940814195381057, 0.12165687677841033, 0.299614351843634, 0.09915559507545926, 0.11532159777538431, 0.16898064062960688, 0.19021878890212507, 0.18166446727850746, 0.13127209228133002, 0.2113102926241775, 0.09584607225992987, 0.24203218039005037], [0.0481690269624514, 0.04414839835296716, 0.048586759385803056, 0.07863079723451408, 0.09955075854856162, 0.012041386273208887, 0.052617067516210585, 0.04799039058026768, 0.12486859314864683, 0.1115499247586535, 0.13839917678025462, 0.034079658798873425, 0.06904310727071378, 0.046756115681942434, 0.05625301273539663, 0.03871633318222819, 0.0601197304504533, 0.03634544044372536, 0.04952235958508907, 0.0234756306294472, 0.10688686247674689, 0.05508374422788621, 0.16911367945853742, 0.3484242956244177, 76.29384963743149, 114.48268105906826, 108.5292056299025, 74.58270780501827, 61.35088620647308, 27.836119744085497, 37.08119330867645, 98.04554170177829, 87.65023308415567, 43.611570942786436, 41.92923107454854, 39.00762227273757, 8.090883781833034, 0.14391766049929205, 0.06298033723367319, 0.25103904547229894, 0.027014418662856185, 0.23219846128936739, 0.1795026284432219, 6.2247803807258615, 23.546907940218528, 1.1674418781072864, 53.00347451240786, 113.49699727950559, 105.03191840264105, 101.14502214616346, 99.81635062925278, 107.53871302450858, 102.93636860386019, 98.72218978020453, 99.18552367917954, 101.10350778025966, 94.95272928668608, 98.5060279600082, 96.71547382108628, 98.56355344095539, 92.93044936272406, 92.78486667140838, 90.80978855010002, 80.24654757591986, 69.29775330328172, 71.53754434277936, 81.78393625443982, 89.20529596267208, 81.34828644414102, 70.71547831258466, 67.8051188684279, 69.53319749524518, 73.69867617084135, 73.82612182248023, 72.53235940010318, 67.60969854170277, 69.24369519756686, 70.3086422335717, 76.1620815338627, 76.40939481796758, 78.20419296141594, 72.43258999240014, 71.03485338149532, 81.44095636183216, 84.7438273891326, 86.93332579828079, 94.156535210148, 42.32530416980867, 81.50969982147217, 93.38471474186068, 86.91055251706032, 92.43810561395462, 90.01381412629159, 92.04409568540513, 89.5748067671253, 93.57756199375277, 76.14340320710214, 70.60448308144846, 77.20118015043198, 80.5140139979701, 76.13883756822156, 72.76335562429121, 69.86951720330023, 72.44192523341026, 82.74122991869527, 94.04674022428452, 93.76007772261097, 92.9655388862856, 86.86451173597767, 83.03974582302956, 72.86144625756049, 77.52347346275084, 88.29023838043214, 94.8273624912385, 84.83766617313509, 86.20953083038331, 93.63777037589782, 94.032023491398, 88.79291365223547, 91.3790342884679, 97.04186993260538, 94.99678534846153, 27.522663531764863, 0.6633675458931154, 1.58359996013103, 0.5934769768388041, 1.594479266674288, 0.4589617432605836, 0.04731461676138063, 0.3347552952266509, 0.40270456683731853, 0.09657546457263733, 0.03231662235433056, 3.489580015020986, 22.498662356407415, 40.70115266307708, 42.78241326732021, 79.27696120354437, 79.95551555387436, 67.5858191520937, 30.30392992881037, 20.364208529072425, 13.338077625920697, 30.933444846060972, 39.33124526854485, 77.41157608647501, 76.51719723978351, 95.34498983813872, 9.194461261072467, 0.5671011824761668, 0.0913320447228128, 0.04586646160591514, 0.04846035487829678, 0.01030250649613839, 0.039120371783933336, 0.03970708405118316, 0.02306821549521579, 0.005420482400128799, 0.05367556737074929, 0.05150223338615991, 0.0604330221070878, 0.019627078774295027, 0.043739315062280626, 0.055517713884792985, 0.06642654162621306, 0.016446975022253972, 0.030748901941302805, 0.083128476455327, 0.009751831004846721, 0.011405565854792875, 0.03473568670151215, 0.0968205820648901, 0.022783914520855875, 0.04462615759562581, 0.0187576245216112, 0.09257006579108777, 0.01039087569581405, 0.013359465444790981, 0.014182101191592314, 0.1112541918372435, 0.0870776137397174, 0.025786155639516733, 0.03417642719502892, 0.019868559264127287, 0.06974248425854791, 0.040062188786724885, 0.0733650152781798, 0.03031778979235359, 0.04197722090588462, 0.0779369973667687, 0.041494815339965206, 0.06313750783221857, 0.08432274624224632, 0.05666597243098002, 0.045356630092306484, 0.04558091765389808, 0.06422035779143054, 0.09808608270700901, 0.12607475262015097, 0.2184808143084088, 103.21683376066147, 128.20142961317495, 123.28950035956599, 85.52091167819115, 80.84391670842325, 45.29860588812059, 56.45320300132998, 50.237928975013, 52.62741727213706, 63.115807656318914, 42.64592263006395, 48.81084126810874, 11.666729219498174, 0.006437077245209367, 0.07427089892688298, 0.03319867683814899, 0.04252029680496743, 0.19924684397635922, 0.15528030723573702, 1.7444317235100655, 2.4968205248155906, 2.2261470748532206, 62.591833914479906, 117.31418517328079, 107.68537828999182, 105.26617803881246, 103.01624375004923, 110.17187856858777, 105.95427943814187, 101.50868077431957, 103.1402926291189, 101.66264949306365, 100.15542384116881, 101.43137870296356, 99.21410991299538, 101.26182248515468, 97.78606907013925, 97.92284996278825, 92.25805313356462, 83.40268273507395, 70.9491103695285, 75.15736641422396, 84.68419951777305, 92.004668020433, 84.36644831011373, 73.51679586595105, 72.33071819428476, 73.56434283717986, 76.35327354554208, 77.73399491463938, 75.16663105257096, 72.46702840251308, 72.63227001313241, 74.38968012409826, 80.82701913772091, 81.11457593979375, 82.2259638386388, 76.38042419187485, 77.27364986173569, 83.28871434734714, 89.49650841374552, 90.96176470479658, 98.5884448020689, 44.9623332485076, 84.70594513800837, 96.69122572868102, 91.73411077068698, 95.5262347190611, 91.16317056840467, 93.27656715146958, 92.69543663147958, 97.16371443963821, 79.28551197052002, 74.60137044229816, 80.10925677514847, 83.53358791720483, 78.26527210973924, 78.09826543254238, 72.8338170820667, 74.64115896532613, 86.35013995632049, 97.53103656153526, 96.4007193042386, 97.39568341162898, 87.61810102770406, 86.69279036983367, 77.05253016564154, 82.0418477827503, 92.50739820541875, 99.38276398566462, 84.04140933867424, 87.11908924964168, 96.88161757684524, 96.2618987791, 91.32191673401864, 97.31303907209828, 102.06410408020021, 104.90649669401108, 36.696789264678955, 1.383505516475247, 0.723112230339358, 0.7141059168404149, 0.7275035688954016, 0.3900984981127324, 0.1385060000804163, 0.43176240437934477, 0.4675275868465824, 0.09154572196665312, 0.2649095269941515, 2.9309516424132935, 26.000611320618663, 36.92064677515338, 37.93490502142137, 75.60750545993929, 56.70350905387633, 42.94313630750103, 21.817103470525435, 27.937254136608495, 29.0225798468436, 53.54321225996941, 46.09366639967888, 87.47342048152801, 87.08670616149904, 115.58863255285449, 15.458653126993488, 0.7297353975234494, 0.15522551662739248, 0.1927101681189191, 0.08463280500784036, 0.06954961396273106, 0.01371709731287293, 0.017865608979557312, 0.02001286150076457, 0.06130031024616572, 0.02911957273740442, 0.019978092600321098, 0.023437341554991664, 0.04014222582261409, 0.03204153741769974, 0.016208005385593544, 0.02576451940131524, 0.052663297092001286, 0.05118796496742195, 0.01971875077053424, 0.034705836085542556, 0.05447606413414883, 0.0537559989419195, 0.04272827435465109, 0.011153844684632796, 0.09793337840106218, 0.0856965180907038, 0.002204180754263014, 0.20670737590520613, 0.1775609019903406, 0.09098986389055368, 0.14380907519690453, 0.1492474414408207, 0.12471523000708512, 0.1252691115763399, 0.0901110231455776, 0.2591951545928755, 0.256510001096514, 0.20144792183512644, 0.2036969567979536, 0.24957374909952765, 0.12014858755132846, 0.21173248367924846, 0.14316721609042538, 0.1922691619444278, 0.14162760918899892, 0.170055860353093, 0.11338824466351541, 0.20307927542636472, 0.13808336469434923, 0.20095155814722662, 0.7006615640655641, 122.14594902530794, 141.32364057725476, 139.23855566209363, 103.36993171322732, 88.94637246285716, 41.887312704517, 51.58217230150777, 126.37199694110502, 122.96401423792686, 58.24896212547057, 62.837935186201534, 60.51797090038177, 16.010310957508704, 0.5038265180924247, 0.14937369273074214, 0.9032255074670239, 0.09706378433733218, 0.4583700169478694, 0.1833002488579481, 11.713329918922918, 44.563879274552875, 4.221801459789276, 64.62751265495055, 121.38386387978832, 116.76266070335143, 110.95457969173309, 108.62012617049679, 115.23223030951716, 110.16834059069234, 105.01758606203141, 107.130519805416, 105.87642823496174, 103.32349085038709, 104.23088412131034, 104.90762633662071, 107.11454791407432, 103.22361161631923, 102.78213316394438, 97.01381714113298, 89.47050309950306, 76.73789331989904, 78.61882671233147, 88.54547485228508, 97.46021424570392, 90.38671385857367, 77.64672217830535, 75.99480029075377, 78.51859446494811, 81.93351191859092, 81.40233670511554, 79.8156673677506, 76.10294003640452, 78.13828929778069, 79.47114206129505, 84.95979309082031, 85.32836252643217, 84.75987772787772, 79.30131127757411, 80.02657321191604, 87.3997034565095, 93.74525900809996, 99.20718300727107, 101.69680549252419, 52.32399840508738, 88.7657630059027, 103.23431184214931, 94.89633344834851, 100.07436413918772, 95.39673374545191, 98.03887367248537, 97.45329518471995, 101.46918250668435, 83.50301696408181, 78.95575831013342, 83.32499627144107, 90.37156566496819, 83.8088127874559, 81.14055771981516, 76.68737319207962, 78.95076905527424, 91.62370389507663, 103.31235131909771, 100.57716492683657, 101.89108833189934, 93.24542353230139, 93.68495648907077, 83.0900933665614, 86.75536786356281, 98.38233209425404, 104.58853367836245, 86.7026904321486, 88.69658808554374, 101.1423392449656, 100.58915953482352, 95.932341237222, 101.37211953440021, 105.42850925076394, 105.67652071675947, 31.55445606477799, 2.4766514522414056, 5.7323223929251395, 2.999659800721753, 4.603208322678843, 1.9089717201648222, 0.21342480254750099, 0.5710386292588326, 0.9342584422519131, 0.2551687650022007, 0.42665406881320866, 6.424008838592037, 39.21962638055125, 62.85498572934059, 57.18916908387215, 106.2448956889491, 107.08247077080512, 90.55587783936532, 42.56450599239719, 29.72398984816767, 21.534986995881606, 50.739152969852576, 54.657871415538175, 105.01261249665292, 97.02009293340869, 131.6064391597625, 18.860256095086378, 0.8983688164622554, 0.3479258788208808, 0.316711442484971, 0.17508208661550478, 0.13840383459483424, 0.14646638905809772, 0.07212014538386176, 0.16127837731713252, 0.2309498605468581, 0.11613389612325739, 0.16317571663568098, 0.1354129047643754, 0.09255004791362632, 0.21225323960665735, 0.1469921552005314, 0.11237172259678764, 0.14195607704741342, 0.25900378582939027, 0.1322445183271362, 0.05801122665645615, 0.10036180051223886, 0.1377325883555797, 0.20244817219434247, 0.20258660428225997, 0.4357826193013499, 0.15118536809759756, 0.21808638627971375], [0.12305890961039452, 0.03990604857643766, 0.023786499533021165, 0.03597153974096141, 0.04657185238395487, 0.07313335028987739, 0.04953726765609557, 0.0473479530774057, 0.01371536499655415, 0.027846955138468937, 0.017644431734938296, 0.12032821984781374, 0.054115458887310765, 0.006796883845386366, 0.042339879268359755, 0.09368028041095504, 0.03420552321439309, 0.11206612246291292, 0.0709141621125802, 0.18314251135433876, 0.032088854838342916, 0.26022820883700926, 0.3655544199770497, 34.325234043982725, 125.93911632414788, 119.01957681102138, 111.99917747128396, 76.32589540173932, 45.435822163858724, 38.50449592836442, 51.228092101312455, 93.11861330463041, 155.50029447001796, 77.35618437490156, 41.17290396844187, 15.35306586373237, 0.24355956052820532, 0.02389915659272623, 0.1342232927920357, 0.1010660804627884, 0.049740051129652615, 0.19135039269683823, 0.063406546419907, 3.1461068843641593, 6.394464075565339, 13.102137254130456, 107.45217769376694, 100.77627228152369, 108.32629357614826, 87.83662411474413, 96.18039977165961, 100.1731921780494, 104.1978342302384, 101.42882916235156, 99.43668873079362, 95.36009880804247, 99.72231572674167, 91.5061975294544, 94.52969381886145, 90.86983219269784, 96.40796784431704, 87.74258136749269, 84.16804698205765, 70.17269288339924, 73.10523725325062, 67.70938950200235, 69.29852208783551, 69.07864970545616, 70.31104272411716, 65.45992197528963, 71.90417612752607, 67.88666494431035, 72.19637701588293, 70.72380942683067, 69.44708578048214, 64.53745895816435, 71.48046601203181, 67.7988430761522, 80.30925058549451, 74.37832878481957, 78.9796063207811, 69.40430056664252, 73.67656184780982, 80.92998135474421, 91.41407674358737, 81.56145941826605, 102.60786225718837, 36.68350027453515, 67.71355505912535, 97.62508715352705, 82.14592395290252, 90.1736742450345, 85.6121067846975, 90.28100598242976, 86.3230912916122, 86.93482414368661, 76.82362848712553, 71.8664429264684, 68.95110207219278, 75.9016518439016, 71.88021044577323, 75.06402969360352, 70.30315091533046, 69.45012953973585, 68.89999358884751, 78.3281712378225, 80.29714615114274, 81.08577005324825, 71.77725607349028, 69.46956880630987, 68.40792440599012, 81.73309449226626, 89.25959725533762, 91.82479596907093, 82.12668864957749, 89.50342747472948, 89.24076203377017, 82.97836857457315, 86.02369677635932, 87.15156647466844, 86.8771888363746, 90.98715812929215, 102.32234508760514, 47.62612465889224, 0.49942218668518534, 1.0119615759580367, 1.1163233436884419, 0.3658677805815974, 0.1819434918222889, 0.2851236761818009, 0.11126792779372585, 0.07463523502191229, 0.13761715422714912, 0.08555365801458398, 1.9965469692983937, 13.493091656315713, 38.395238307214555, 22.779664877922308, 45.55014356490105, 94.82667215408819, 94.42045580956244, 65.45968271070912, 26.774877386708415, 16.179152323353676, 33.63294355330929, 72.10205185797908, 78.35363526498118, 82.83895969390869, 29.631700400383245, 0.6050588779391781, 0.05635462280723357, 0.057511112968166994, 0.11092177096513972, 0.04492240762638469, 0.01699529287795867, 0.09172350799124088, 0.03257124699772366, 0.00640444764529445, 0.09140837006270887, 0.019938263689137755, 0.06882274207929451, 0.06977973145342643, 0.03121373919589866, 0.043715899584875, 0.033656640368844234, 0.042254268942821416, 0.05843505330924546, 0.04170155565765116, 0.08497845621839648, 0.010041768471109531, 0.01883096020338276, 0.007024252516848426, 0.012953251153380882, 0.06027498199874836, 0.06978798988125018, 0.06280263164831747, 0.03185035826097573, 0.08972285405522393, 0.06196106108085764, 0.08589761617082743, 0.050352779742811, 0.006523557559346721, 0.027283378726532383, 0.030018906334354997, 0.014433199915313914, 0.04477250337180111, 0.038378212615967765, 0.01396453605153628, 0.05865659061518889, 0.04908309243018589, 0.019291124321640502, 0.06119557453559772, 0.02673301733128967, 0.05536853741373747, 0.07087047211825848, 0.2198921780913107, 0.10190094010003152, 0.21484658512617313, 0.3116603490085371, 51.95802557852961, 149.67058550926947, 126.99681482007428, 129.29530020683043, 86.49453809184413, 64.75155761165004, 41.897165698389855, 33.91704474726031, 79.79175659918016, 131.14366223735195, 62.199867540790194, 48.03279599835796, 20.32102519466031, 0.10304440293581256, 0.060505497855164354, 0.15056970919812881, 0.05697683175845493, 0.11379594899593823, 0.08732562704432396, 0.056422023222811764, 1.3516803854896178, 2.292284364661863, 15.134851663343369, 117.23440416397588, 102.83103727525281, 112.17449957324614, 92.72655671642673, 100.2035827021445, 101.41355545290055, 109.38674557593562, 102.43013966468074, 101.25420524228005, 97.11441809131254, 102.08022502160843, 93.7259844810732, 98.72943832028298, 93.96411941897486, 100.84016769163071, 94.31022151823967, 88.79343924983856, 74.59346294403076, 73.99421107384467, 69.96446209569132, 73.90376121767106, 72.64442151592624, 72.46186656336631, 70.03616302244126, 75.86187116561398, 71.67884380586686, 76.18021857353949, 75.71452340772076, 72.60174612845145, 69.42679143721058, 75.0356395782963, 71.578964571799, 84.27337046592467, 77.80607238892587, 81.50457720602714, 72.27711508350988, 76.78496176196684, 87.1670441473684, 93.4813540981662, 86.57811595547585, 105.38078185050719, 41.998590346305605, 69.42231993521415, 104.0837089477047, 86.34921427695983, 92.8229058173395, 88.8935616708571, 94.48770876853698, 89.86857660355108, 90.7911180680798, 81.28152770380821, 77.81659218572801, 73.42446327209473, 77.96035489728375, 75.60677589908724, 78.05031053481564, 73.38537293095743, 74.27310728257703, 71.91287594456827, 80.63108890287339, 82.18101347646406, 83.91246534162953, 75.67660977763515, 71.44501563041442, 71.71185447323707, 85.43746717514531, 92.15143526754072, 94.91223473702708, 81.63108148882466, 91.73476972887593, 94.81729768937635, 87.91067846359746, 87.1555123790618, 91.35717099712741, 90.59180675014373, 93.90643704322078, 109.70473212580528, 60.92106503825034, 1.5607189363048923, 1.074320520124128, 1.3296261237513636, 0.5607342563809887, 0.2251257843548252, 0.22785514112441774, 0.06723474906457048, 0.11720844935024939, 0.11444855631599504, 0.11293821397327608, 1.6781638923191255, 16.73515908179745, 40.5103725002658, 19.079669560155562, 53.88890251036614, 74.83675187633884, 58.204152968622026, 32.92916051803097, 20.618070210179976, 28.072913231388217, 44.04931922112742, 80.62566818729525, 86.95904870187083, 101.28874563401746, 46.76465449794647, 0.3671029594636733, 0.05855837814329613, 0.05142088633992019, 0.05946534963685179, 0.07544603183745377, 0.08240296054751643, 0.030047328196345802, 0.05924253679451443, 0.03188954940396211, 0.042596748549371, 0.01197144819138151, 0.07562571776009376, 0.11437202413235942, 0.00652864917121347, 0.05328577800443577, 0.016748729394748807, 0.035858672007077166, 0.0174750343731214, 0.07847554951665864, 0.019545408055907296, 0.004807462194754232, 0.01940130883256995, 0.08652649774786927, 0.041778922877124244, 0.03358122284313844, 0.02654927880353024, 0.07042832447276001, 0.22534442584841485, 0.1473666496214367, 0.13992461105508192, 0.22826748028878244, 0.19324385561048987, 0.11228572922728716, 0.13486984035661145, 0.09462113597340162, 0.08241012346960845, 0.11613290020895582, 0.1955125024241786, 0.28575162313157515, 0.21509881191436322, 0.1922672620463756, 0.12079253807784089, 0.28075106081462675, 0.13740002958764955, 0.15275200258099264, 0.328250841027306, 0.2897644836095072, 0.48460668974345733, 0.38222250138078967, 0.5506410173350765, 66.1000253308204, 163.36486631824127, 145.85330347861014, 141.50767818573985, 106.39569513259396, 71.49956795477098, 59.26122388532085, 72.25831908564415, 118.16380977630617, 175.79063692400533, 101.87779934175553, 70.65042188090663, 26.369284699040076, 0.6891017875844433, 0.15076374394759057, 0.38854143972839084, 0.6950331467293924, 0.16603256575763228, 0.7286398305046944, 0.16096552233061484, 9.360813883043106, 16.06819239354903, 16.766318390446326, 123.42511238590365, 106.28531179120465, 118.68588509098177, 95.53505220720845, 106.5302481189851, 105.31667463241085, 115.86472034454347, 107.33686001070085, 105.76118115455874, 100.14106796633814, 109.63592590824251, 96.34127186190699, 101.19049026120095, 94.49926407106462, 107.16261263816588, 99.76410465855753, 95.17629654176774, 79.53763408045616, 78.80611988805956, 74.2916287145307, 78.27445830068281, 77.23485762073149, 79.00697661984351, 72.72972522243377, 79.08858545364873, 74.55625534057617, 79.98598452537291, 78.78974791496032, 76.68900489807129, 72.61530968450731, 79.27622379795199, 75.69440164873677, 88.69824332575645, 82.00151797263854, 86.78705276981478, 77.52670549577283, 83.09989144725185, 90.80860399430799, 97.34808152721774, 90.31316941784274, 109.29284403401037, 47.96936735030144, 75.90454655308878, 105.056409681997, 93.70660797242196, 97.2296259480138, 93.12332799357753, 96.96392459254112, 97.19314006067093, 96.40984273725941, 85.4827940848566, 82.53136742499568, 79.2023891018283, 82.64001707876884, 78.66547153842065, 82.63464343163275, 76.98064880986368, 76.28018409975114, 76.63364456545922, 86.14139141574984, 87.8599935962308, 90.39806519785236, 79.28333897744456, 75.06385710931595, 73.90284338305074, 90.14658635662448, 98.58056868276289, 98.52515343696841, 82.93395165474185, 95.04077080757388, 100.06450330057453, 93.04710065164875, 93.4817934036255, 96.24977865526753, 94.42882614751016, 96.79647860988494, 113.72667558731573, 58.73631269701066, 0.750271947153153, 4.499768557087068, 5.29421276623203, 2.060647568395061, 0.7556674737603434, 0.5819639010775475, 0.2878313986284118, 0.24321137356661984, 0.16568203456699848, 0.41209337271509633, 4.590109077192122, 25.797671810273204, 61.28004427879088, 31.78162209449276, 63.853032819686405, 124.56849898061446, 133.41046271785615, 94.5999199344266, 39.12991000759987, 24.868774144880234, 51.50771394852669, 94.11439326501663, 101.0522267126268, 113.77328118970318, 66.12639150311871, 0.9906067831381675, 0.2693847062126283, 0.2481214302561937, 0.25187696180035996, 0.18984317599285036, 0.12055832201675062, 0.2079905885001344, 0.13155644879706446, 0.1357958567959647, 0.13196564700093963, 0.10567741648804758, 0.15644465362833393, 0.2046261295195549, 0.11619629398469003, 0.17087477770063186, 0.21071611483010555, 0.12897784280921185, 0.1609963343869294, 0.16151436304132785, 0.20529524603437996, 0.10671145898560364, 0.1504520687364763, 0.17011938436377436, 0.1433478749447292, 0.1882743811415088, 0.1347422407519433, 0.1418289524172583], [0.07569272747083057, 0.056023803058891535, 0.09863293924999815, 0.03396751118763801, 0.08398595866897414, 0.023931372505162033, 0.044064251255364194, 0.023894531336883386, 0.01914378646160326, 0.07576629489419923, 0.01983221030733999, 0.042558490118432435, 0.044672482932407054, 0.08377244996447718, 0.02625909044347223, 0.04472759912811941, 0.07735883847119347, 0.01288829455828114, 0.04954756004735828, 0.006909934482762531, 0.14742471908609714, 0.1510295611355574, 5.13747779592391, 112.15991620094546, 117.75225116360573, 110.84272153915899, 75.69690412090671, 58.80035715718424, 31.670709233130182, 41.025885689643125, 73.574384104821, 41.40635951872795, 85.53419282359462, 74.36089777177381, 23.30427992728449, 0.3668623159248983, 0.008337445005083518, 0.06446866603988795, 0.0894571441195665, 0.08651584146484252, 0.08974023659022586, 0.051583618736795844, 0.10112353705710943, 0.15555452074735396, 0.7130297778114196, 44.26439062241585, 113.72581266587781, 99.63738856777069, 96.35005797109297, 77.490494174342, 83.67110621544623, 92.77917138991818, 98.64156938368275, 95.87816546040197, 95.73185320823424, 93.86980995055168, 98.64426012962096, 90.97529688189107, 89.80370060090097, 92.15788364410402, 89.10257693259948, 88.72216978380757, 80.54440452206521, 68.9945540889617, 67.57337739390712, 68.78781380191927, 70.25861632439398, 66.01559239049112, 68.03101601139193, 68.76493069433397, 73.63575350853705, 68.99765276139783, 70.71107741325133, 69.9364406831803, 70.62624439116448, 68.84462541149509, 68.17344511708906, 72.68903455426617, 82.06808843920308, 78.73317949233517, 81.73316509492936, 71.13955713087513, 76.5757974501579, 88.17068453757994, 95.86768488730155, 83.35843055478989, 100.79601749297112, 48.79124510672785, 47.99734953911074, 93.96574328022619, 76.16364263719129, 85.17906142819314, 84.60926655800112, 90.13345426128757, 79.89271840741559, 82.93287692531463, 75.30145860487416, 77.20391796481225, 66.91044976634365, 70.11914468580677, 68.9034374298588, 69.78866146456811, 67.73792082263579, 70.89317737087127, 66.61476581327378, 71.26045242432626, 70.00104211991834, 66.39537196005544, 66.23491564104634, 69.92968636174356, 77.21350423751339, 83.67685641011884, 86.93146659481911, 86.3713913579141, 83.06466856310445, 90.93360993169969, 83.4325868852677, 85.39944371869488, 75.1564250453826, 81.91776752471924, 85.45888331628616, 91.29010631192116, 85.55393019030171, 102.56581444894115, 59.22325534205283, 2.9172485970681716, 1.0210065002883635, 0.1818371434966403, 0.10871064203280596, 0.1585659357689081, 0.19105469807982448, 0.10279075888496253, 0.18184316494772512, 0.09811055921618977, 0.2608196593580708, 0.49286839642351676, 9.852532994362617, 58.96528497818978, 30.007859622278524, 60.41254935726043, 140.14835726830268, 174.63713061424994, 119.67188266015823, 35.91295457655384, 20.652816526351437, 43.37040401274159, 77.61690432025541, 75.6259641339702, 42.0403165201987, 1.4844862011171158, 0.22671042190444088, 0.14469566875167433, 0.035274886195698095, 0.02970247946289038, 0.02626158022922614, 0.03442113099980258, 0.009058955230660016, 0.04052199475887803, 0.07618710699100649, 0.06287145698743482, 0.042363831007312384, 0.0646347998671474, 0.041051832658629266, 0.0495961185304388, 0.04409645376126132, 0.029863135761491237, 0.006871750745396581, 0.08892852813005449, 0.030828540611471382, 0.07006093934779206, 0.0312892543978148, 0.06801113321055328, 0.019041942732949412, 0.03664002040280931, 0.025429413391036854, 0.046984053652493224, 0.007650761136544809, 0.006274561268172317, 0.018115491538699117, 0.09917313848892528, 0.051799314622316635, 0.044891354252373984, 0.03763097045462459, 0.04474529958960991, 0.02382104435274678, 0.08728742223954009, 0.0227207773845763, 0.06408617749149281, 0.03669569201226677, 0.054846609371804425, 0.03465963715326882, 0.057918725370038907, 0.06692311215785242, 0.04664105693659475, 0.19875941287365653, 0.04764988748056274, 0.14059328323891088, 0.29453236970209307, 11.581303919515303, 142.75417604754048, 125.66401696974232, 124.07623367924845, 90.13392494570824, 91.00964115511988, 53.56053344665035, 57.53587522814351, 57.031791825448316, 49.528180014702585, 81.43027182548278, 63.422748811783336, 30.917153281550256, 0.19920956613796376, 0.0948646600027719, 0.1360051979821536, 0.1088853790274551, 0.06699707794694171, 0.11042174537696185, 0.013660063024520153, 0.09207008616818536, 0.2426153878050466, 0.3153792155846473, 52.981352344636, 116.09527726327221, 105.07689229903683, 98.23190919814571, 81.13618819944321, 86.60205810300766, 96.6183480908794, 102.6031554129816, 102.18494446046891, 99.91869311178885, 97.52834581559705, 100.72693670949629, 92.72845514359014, 91.22273568184146, 94.39302275257727, 93.80345129197644, 94.28223932943037, 84.41465423953149, 70.23229722053775, 69.85487107307681, 71.91537057199787, 73.74188500065958, 69.45820177755049, 72.48944082567769, 72.27922531866258, 75.8957290649414, 71.96942867771273, 72.76575611483666, 72.80363052122055, 75.31055850367393, 73.06618613581504, 71.08584419373544, 76.20792619643673, 86.31672920719271, 82.81750432906613, 84.50573167493268, 74.01924364028439, 81.3156052558653, 90.98347110133018, 97.71080663127285, 86.84496264303885, 102.47149713577764, 53.99140581007927, 49.88431553686819, 93.30163109687068, 80.46183862993794, 86.51558553018879, 86.09345220750379, 94.06276702880861, 83.61142343090427, 87.05675494286322, 80.09993722361904, 77.97574627783992, 70.0962458887408, 74.23983773877545, 71.19918500223469, 74.23275393824424, 70.66959442630892, 73.51255186142461, 69.71684286671301, 73.63181544888404, 72.84160690922891, 69.89509890156408, 68.379149898406, 72.93797954436272, 81.57620753011396, 90.60660193043371, 90.8830270459575, 85.33646614320817, 84.82839369004773, 96.03538190164875, 87.84870501487487, 88.4280312445856, 78.35381569400911, 82.72352433973744, 91.20217461739817, 95.92412779408117, 88.753705639993, 106.87586384434854, 72.1841235314646, 6.453613908060136, 0.401310378745679, 0.9595319280220617, 0.25084619049824053, 0.2948438610521055, 0.03574949298654834, 0.09892424418320579, 0.14893149145908896, 0.07069489242689264, 0.08689300953260354, 0.18293839488779345, 12.02647920577757, 51.227091896918516, 25.20249136032597, 71.15764710210985, 122.4010442918347, 138.62886244250882, 70.70188337756743, 39.994239576401256, 32.68330243326003, 48.85640744240054, 86.66131727157101, 85.36614279593192, 73.06202057869204, 2.5131157665483417, 0.209461416027719, 0.07911024570104577, 0.014706321751638768, 0.04075949733716346, 0.03142636306884308, 0.03855040236826866, 0.03302028943454066, 0.05758785199554217, 0.0583380933911089, 0.020446815835912863, 0.023003768348585696, 0.07588460185234586, 0.024337676811903238, 0.049140434111318285, 0.020182695532698306, 0.03803443449038652, 0.006028845748533645, 0.13511007020790733, 0.012300758746512716, 0.07930889996069093, 0.024881909503751708, 0.031170949354887973, 0.05498056367580449, 0.05307153385553149, 0.08954247865345209, 0.07127847522497177, 0.12009431788277243, 0.14180160307836148, 0.23651303783539804, 0.20812609413218117, 0.18273772581690745, 0.12370049292522094, 0.19760165483720843, 0.15507125716295936, 0.15927737098067038, 0.2592747664499668, 0.17435831738816154, 0.19419558196058198, 0.11963879434211601, 0.19258509660440107, 0.1113386836744124, 0.0969946142586489, 0.15999069076872643, 0.13783591829480665, 0.33507135246069203, 0.23183806288626888, 0.2703156562582139, 0.6581090570938203, 14.74163797593886, 158.3635776273666, 138.60636372720043, 141.2480486592939, 100.35121287069013, 86.97852719214656, 49.227487194922666, 62.92917736114995, 105.07362888705347, 52.34517528164772, 100.00394190511396, 114.51882962257632, 36.256609116831136, 1.3781679061151322, 0.1530554959730756, 0.47761641322605075, 0.21091255509564955, 0.2519507820327436, 0.2858456067981259, 0.3469978705529244, 0.538102486921895, 0.46796520691244836, 1.2154815970889985, 54.52330666203653, 120.08483763664, 109.49525402438258, 103.14564274203394, 86.76307139858123, 89.45727686728202, 102.17185943357407, 107.03020911062919, 105.33488227475075, 103.38825702667238, 103.11640539476949, 102.51486286040276, 97.44325391707882, 91.99366184972948, 98.54900144761609, 99.80616815628545, 99.38246588553153, 90.86625499110069, 76.4011578406057, 75.29876001419561, 77.49189053812336, 77.63139355567195, 73.2819478742538, 74.53996965962072, 76.01019167130994, 81.64886551518595, 76.31798005873158, 76.33406177643808, 77.10818075364637, 77.80077718919324, 75.55894651720601, 73.51290487474012, 81.48473001295521, 92.437909495446, 86.2671975166567, 88.6470877739691, 77.93222365840789, 82.91776795541087, 95.88676329581969, 101.36890319085892, 93.29241352696573, 106.15017829402801, 58.7869583406756, 55.60266448605446, 96.11878718099287, 85.44943824891122, 89.89948488050892, 91.18519075455205, 99.3577471087056, 87.96152022577103, 91.7216690125004, 83.72191659865841, 80.94450196912213, 73.72381856364589, 78.72628396557224, 75.23344470608619, 78.9980806842927, 74.68339504734163, 77.63255457724296, 73.09620795711395, 76.08957259885727, 78.46674857601043, 73.8155157335343, 73.25092977093112, 77.33595278955276, 87.49898649031117, 93.32554186544111, 94.73777555650281, 88.37562837908345, 87.47755465968963, 100.46709537506105, 92.47638794683641, 94.9956557058519, 82.82829084704, 87.50341876860588, 95.09406012873497, 100.36399195271154, 91.2844031856906, 113.64379590557469, 72.85428400962584, 4.498163327094048, 1.8728443619705017, 2.023084622717673, 0.676770529920055, 0.7446025287912739, 0.40294870373702824, 0.3046229734055458, 0.38435703684245387, 0.1812604784725174, 0.41914539591919997, 0.7925177738070489, 17.900289335558494, 89.34204547635971, 41.32747280982233, 73.39808141031574, 152.8157929451235, 191.95359476151006, 160.35033656704812, 52.557446110633116, 36.699409407954064, 59.95324765482257, 103.26072508288969, 98.73006589951055, 100.00476560285016, 6.361685318331565, 0.533706245403136, 0.2560529836844052, 0.14954371828465693, 0.18836804305113133, 0.11200554789074006, 0.12505491339271108, 0.12135244875905976, 0.18273579527533826, 0.2112131679971372, 0.17889755687886671, 0.1303406212959559, 0.24396454524849695, 0.17828009001189665, 0.181168777747981, 0.16765870995098547, 0.20453591500559162, 0.11252078032421489, 0.25897614537708225, 0.21127411795239295, 0.18932632711385528, 0.15423534798525995, 0.12015771931938588, 0.1223838022880016, 0.19198695047488137, 0.23866857942794603, 0.17365114162525824], [0.05296626954429573, 0.033702391139682264, 0.09014781068770156, 0.05489647403479584, 0.06380946270280308, 0.09307772161499148, 0.053756447103355205, 0.028382312701714617, 0.11648852588428606, 0.05696883380052544, 0.11038511105242277, 0.05013832491972754, 0.05893083093988319, 0.027478348103261767, 0.1251136723365034, 0.06009895414594681, 0.04073174963254602, 0.056931667044878974, 0.04020934661609992, 0.05332285665997094, 0.12025970860474533, 0.13021191852467676, 58.90117383772328, 141.26959031628024, 121.58775652608564, 108.28789357216128, 68.64369807704803, 26.438861662341704, 28.9382920342107, 55.2932208584201, 46.463557674038796, 81.17068152273856, 57.50455510231757, 26.186331625907656, 0.7839867412563294, 0.1172323436326077, 0.06885343156154118, 0.07194136344497243, 0.07080607476734346, 0.04466974416807775, 0.04126251832912526, 0.11791577066985831, 0.0982453830299839, 0.2439680998964656, 5.0454835064949535, 83.99034007903069, 110.57953050059658, 103.03809135190903, 93.17573870382002, 79.35150977103942, 75.08004865338727, 82.0100530501335, 93.49830658205094, 97.03170314911874, 96.92776033955236, 96.11662203265776, 97.95790026264807, 87.27982013456284, 92.98617839813234, 89.37116515251898, 87.09205627441408, 85.48644188911685, 75.18108890902612, 66.94569618471208, 68.61617088317871, 66.23362910362982, 68.1654905503796, 66.8831108462426, 68.37761232929846, 67.64693752411874, 69.56816150296119, 68.79672542695077, 70.69762368356028, 67.97027418690344, 71.28717945468041, 64.09232485678889, 69.04764729161417, 77.04944718268611, 81.27056860154676, 79.5695072604764, 78.0907109475905, 69.88248455908992, 68.34709628935784, 76.10101023027974, 82.32882407403763, 77.65130350666662, 95.44217832626836, 69.42693264253678, 42.871439303121264, 83.86781307958788, 70.93298158337994, 86.72283572535362, 83.86243943245181, 86.83942425635554, 80.76315510657527, 76.585815183578, 72.25602842146351, 73.4112056609123, 71.97726557331701, 69.33312523749568, 66.09174128501647, 72.7081443417457, 66.98313913037701, 70.98344679801696, 66.35763875899777, 69.59451983051916, 64.70581100833031, 68.15817140763806, 64.82424697568341, 74.6958681844896, 81.38748661164315, 88.385269564967, 85.57558951839324, 85.6541467482044, 86.5789318084717, 87.95582494428082, 82.74032777355563, 78.57106793311335, 72.12575866330054, 75.41250874919277, 74.54004810702416, 82.10986168153825, 89.36445789952433, 90.69243123454433, 90.23068981785929, 69.761275476025, 10.15007418970908, 0.29953446419489, 0.31303933791575894, 0.1727007329463959, 0.08926914614294806, 0.06927117164577208, 0.10540621370197305, 0.01675793968681847, 0.13374398222133038, 0.08775408469861554, 0.4612904973328114, 6.793889816730254, 49.18461176656908, 63.46824046104186, 107.04360792713781, 98.78980359723492, 139.37725067138672, 45.438171663591945, 33.28162862408546, 44.71985232445502, 64.52591542274722, 73.26799992592105, 68.16997774185674, 14.520025041795547, 0.3498334990393731, 0.1651992919223924, 0.04173045632459464, 0.026303291801483403, 0.039082703240696466, 0.028047850205292626, 0.05041328919751029, 0.05503523554052076, 0.036156029034886634, 0.06940218034170328, 0.09006210077073305, 0.014409047078281162, 0.05271407723006222, 0.054671274828574354, 0.07449021457784599, 0.06032259819368201, 0.041308667465683915, 0.025047813504633885, 0.04106565288478329, 0.039817569251622886, 0.035098789394983364, 0.09090837511804797, 0.024229436249081648, 0.04813359539595343, 0.07816924458189357, 0.04800723685372261, 0.029546235830733375, 0.06125098950560055, 0.08870347448053861, 0.03816507929455369, 0.03714453909666308, 0.06614121983969404, 0.10584759525954725, 0.03140649649374668, 0.10346331513456761, 0.03874085182624479, 0.07280387119540284, 0.030566680267633452, 0.08120105286399204, 0.04391648821652897, 0.08082497264108351, 0.08095752883462176, 0.08686772097022304, 0.019906792797208316, 0.05951241041804033, 0.013826664165413428, 0.20208971965457165, 0.08031184694940045, 80.00380777543592, 154.72358672849595, 132.1050194771059, 121.55171778894241, 80.88337575235676, 47.277410261092655, 40.32223993732084, 45.38603944163169, 42.193379171432994, 72.71418479181105, 61.473228854517785, 34.22928110245736, 0.873733941585787, 0.14498915703546617, 0.08353884677372633, 0.03516174267016111, 0.06336221674216852, 0.17288016606002085, 0.04928439735404907, 0.09218689925487965, 0.09931204555135581, 0.17201928241598993, 7.882405394507994, 92.28012823289441, 113.25089993015413, 106.57133886891027, 96.94797623542048, 82.034238384616, 76.7087265752977, 85.61479753063571, 97.36660295917143, 103.94049536797309, 98.9227484118554, 100.1347529503607, 99.9698486635762, 88.50120698252033, 93.07980537414552, 95.68374141570061, 92.70233215824251, 88.53152690395233, 78.57340566573605, 68.84132277581, 72.6144624525501, 70.69171659408077, 70.76537086117652, 71.23914610955023, 69.77206199399888, 70.47893585697298, 74.30884791958717, 72.15410955490606, 74.13824835131246, 70.20533484797325, 73.72905885019611, 67.89402331075361, 74.71620175146288, 80.78341022614511, 85.2927395605272, 82.01861166184949, 83.06568837934925, 73.74556418388121, 71.1279155362037, 80.12202016768917, 86.40630045244771, 81.88924404882616, 97.95138128342168, 74.9928072960146, 43.49022065439532, 87.01865303900935, 73.00233779415008, 88.30214669627529, 88.71377591163882, 90.65260348781463, 85.76012134552003, 80.71951481603807, 77.82621768213089, 78.2229418908396, 74.14500267274919, 72.14550387474799, 70.92069672000024, 75.15996302327802, 70.97222881932413, 74.57823630302184, 69.65818774315619, 71.40540753641437, 67.93869910701629, 71.8385156508415, 67.10011205365582, 79.97692385027486, 83.85168429343932, 91.55235598164221, 88.33083491171561, 89.63164191092216, 88.02612950724941, 90.26502624634774, 85.52384561108005, 82.62089944654896, 75.2072040496334, 80.17423475942304, 78.76625291762814, 85.40782190138295, 91.32550178035613, 95.47715017872473, 93.30180368115826, 83.49452895502891, 16.977006543067194, 0.6155416573728285, 0.6621962893874415, 0.2668421829660093, 0.35296673736264633, 0.12743851936031736, 0.11253435540223315, 0.06054057702121716, 0.14872617989538178, 0.028898242275200547, 0.7256926596164704, 7.900609114477712, 38.71170297745736, 50.714140015263716, 109.72173952287244, 101.77001260942029, 127.6898584058208, 30.892948335216893, 37.74652927152572, 49.986575649630645, 71.9549237528155, 82.25148277897989, 93.27871661032401, 36.64427265044182, 0.2415322467324234, 0.04363747133362678, 0.014650441383221939, 0.08892845152126205, 0.03787670847809604, 0.021658085113871964, 0.01704159140166256, 0.06361373872946828, 0.010309619622515335, 0.07125628165780537, 0.06575863553030838, 0.016328436322510242, 0.08051397158734261, 0.01431806073073418, 0.07648289353857118, 0.06479600774905374, 0.043484521879544186, 0.03994322682340299, 0.0262197116089444, 0.03073383682227183, 0.017797965331063155, 0.044835747760390086, 0.02120299058245315, 0.056192690972238786, 0.05027183872317115, 0.03641797364839623, 0.09799455818269523, 0.1608137296692979, 0.16318513951714964, 0.1973241011822416, 0.10879928606652445, 0.2318567860751383, 0.19009586243379503, 0.10667791965627864, 0.21352946547971619, 0.16101275931202597, 0.18897844658743954, 0.13237020271199365, 0.11632957796175634, 0.1040166987466716, 0.16771933814931303, 0.24389907537448793, 0.11066739913076164, 0.13425045826983067, 0.1943130998481666, 0.11478735103962884, 0.2791805805698518, 0.2375487427437498, 94.84488764116841, 171.78567732534103, 149.2778934970979, 137.88508692095357, 93.08933673366424, 42.5355157544536, 43.113881003472116, 81.7963937021071, 65.20575238812354, 106.46908267851799, 80.41115376257127, 43.4632896607922, 1.5341209764442139, 0.32645847107614245, 0.33019219975798364, 0.3208753755015712, 0.2616119474893616, 0.46882840414201066, 0.20678030747559764, 0.3781775571405888, 0.3230381029988489, 1.9831624939557047, 9.436892174905347, 96.83711436487015, 117.51271986192273, 113.24133719167402, 102.28137985352548, 86.50977257759341, 81.57233222838371, 90.39634719971689, 103.18408981446298, 107.36044130017682, 103.37991806768603, 102.3034078844132, 105.8404601004816, 91.97056693415489, 94.05817001096665, 97.34016618421002, 97.61452813302317, 94.80599341853973, 83.44334986902054, 73.69518526138799, 76.1194218358686, 73.59328208431121, 76.15335818259948, 73.30471331073393, 75.8395528793335, 74.73779832163166, 76.7213644519929, 76.04215898821431, 76.78074913640177, 73.95905879236037, 77.9100073537519, 71.92581976613691, 77.18766366281818, 85.52484189310383, 89.43695898978942, 86.72647568487352, 85.2146843940981, 79.24224038277903, 76.16299936848303, 84.61546390287339, 90.77569530856226, 87.03133013940628, 102.1739539792461, 83.00052212130639, 49.52032742961761, 89.0228194575156, 76.43522754792245, 91.36470194785826, 93.92296591112691, 96.62325889833512, 92.23895903556578, 86.14996571694651, 82.18348456967263, 80.76174305331323, 79.93912789129442, 75.43693727062595, 73.00775850972822, 79.0838707647016, 75.02890879108061, 75.6169113036125, 72.2034372821931, 76.84826881654801, 73.22217879756805, 76.49742849411504, 72.81484849991338, 81.69950331411054, 88.85005474090578, 97.05365273260303, 91.59103839628159, 90.14693936994, 92.8068397891137, 94.68820464226508, 90.76879193705898, 86.56543885507892, 80.66551946824598, 85.35275966890397, 85.01954647802538, 89.19272084389964, 96.1388304925734, 99.95816784520304, 99.89599827797183, 85.69150340172553, 14.307097215806285, 1.3999015140917994, 1.5219471651700236, 0.6298936711203668, 0.8900852609545955, 0.31386524198516724, 0.28741446293650136, 0.174215150876872, 0.36487263236795703, 0.23697402358295458, 0.546730965856583, 11.336692167866616, 82.88637330455165, 73.16186058905818, 111.93233243880734, 100.44865239051082, 154.5441932062949, 64.19857009764641, 48.16898853548112, 63.10611547962312, 88.84699529217136, 95.86457052538472, 109.66148407228532, 50.64966409437118, 0.7271679610975328, 0.2587418144028033, 0.1472857354148742, 0.19584408059956568, 0.09403162365478855, 0.12938063651804002, 0.14424925399643762, 0.1554146790576558, 0.12383753839399546, 0.16191311180591583, 0.21970827102420792, 0.14869590410061423, 0.1897491923262996, 0.19306943271188967, 0.23100636719215303, 0.22619605515032049, 0.09889099596729202, 0.18356799658748413, 0.12275924665793297, 0.10325493155828408, 0.19207204752151044, 0.15432963808698041, 0.07172972399501071, 0.2445940396958782, 0.2109155888038297, 0.23712002461956394], [0.05447484605434922, 0.01705576977392118, 0.02797008653531873, 0.016612800499123913, 0.02573578344327548, 0.07930045767176537, 0.09041619427021473, 0.035803571133123296, 0.0773118083335219, 0.04154879006467039, 0.07013096744495054, 0.10287770220348913, 0.04312043859352989, 0.04440522549914257, 0.015611730425828889, 0.021061580327730027, 0.027939942890718102, 0.07855409651153511, 0.018087107981104526, 0.29923547539980183, 0.14472674127788315, 5.525332545080493, 96.72123970523958, 109.44241969816147, 101.7528404728059, 81.82432097773399, 79.6745954021331, 69.88538711301743, 60.2672569213375, 83.00030246857675, 61.92143809410834, 58.66421953324349, 38.641319967085316, 1.3273689222912635, 0.19497795691413267, 0.044802499544476314, 0.18335246541086705, 0.11108689355633913, 0.03908182223958354, 0.05788978639869921, 0.04740040711758118, 0.06674952429508971, 0.257265379111613, 0.6661663408721648, 44.427973070452296, 101.23329116452126, 107.19123809568345, 101.77064018864786, 101.31446069286716, 86.67232344227453, 74.90293010588616, 74.12601840111518, 80.44921644272344, 92.62597145572786, 91.4610824277324, 94.06241401549309, 98.4470590468376, 94.89547837165095, 90.2732789131903, 88.03339373680853, 86.18532196167978, 78.1582227829964, 68.97076099149643, 68.24787601347893, 65.93442286214521, 65.54257808193084, 66.12534815265288, 64.79704926090857, 66.30323548470774, 68.43855027229556, 67.63908493903376, 69.43945284812682, 69.57882250508955, 70.7484732904742, 66.05604771644839, 65.17682490810272, 76.74054484213553, 77.59546464489353, 83.70844717948668, 77.89569070262294, 80.24036592052829, 68.73112770818895, 67.33530521392822, 64.34244655793714, 71.8591865416496, 68.53586427627071, 85.07172184605753, 72.57399928185248, 39.681944385651626, 81.80071615403699, 68.8274532748807, 80.28804625234297, 84.44663724591656, 80.83656618672033, 75.71170714593704, 75.26263498490857, 74.79075816369827, 72.82022999178979, 70.0650473563902, 67.813520585337, 67.90132676401447, 67.59831582346271, 69.29848286413377, 70.75310953201787, 67.14116357987928, 68.26117284836309, 64.37295867550758, 62.171128334537634, 69.50853363160165, 81.24218633097988, 85.53571470322149, 85.40022034798899, 83.79386855709939, 87.73449344019737, 81.62704144754719, 81.8045836110269, 78.21963925515452, 75.34855842590332, 71.46712210870558, 70.09892878993865, 71.62863746766122, 77.8364315340596, 77.79621939505301, 89.97008754361062, 88.99097765645674, 90.65251719567084, 70.4771472561744, 4.587608566207271, 1.0619789049510033, 0.04427135546481417, 0.03695087206940498, 0.033744227201227224, 0.030142453333903706, 0.03366468046160956, 0.18765607157782202, 0.007254094694696007, 0.1494079062174405, 0.1370179508962939, 9.894831834300872, 68.08227354480375, 73.58538243078416, 99.67173284099948, 83.51701982559698, 73.75231850531794, 30.918267234679195, 36.12314654934791, 59.41098390087005, 72.41673577216365, 66.96821058950117, 63.9247533582872, 3.2444411948803937, 0.5341151524936, 0.028412732137967984, 0.007763250135711485, 0.09372619972113641, 0.03300179607204853, 0.08845998875556454, 0.04527539029837616, 0.1045033790832085, 0.06255443065216945, 0.06592846190136287, 0.05540917837812055, 0.07177153707391794, 0.11933400626144103, 0.03670941647743026, 0.023881689788052635, 0.03250583458030897, 0.08189014129100308, 0.06688604116319649, 0.06991023453132761, 0.03958603832870722, 0.0135369737625062, 0.032071828534225785, 0.06474352306536128, 0.006950931199225447, 0.05283926748820851, 0.030429539037868384, 0.05908113739062702, 0.04421614350811128, 0.03475195840902386, 0.03592755480278884, 0.07113167745692116, 0.09029371979376001, 0.027204925577426632, 0.09228691969427372, 0.043615733588775324, 0.05460049596525008, 0.024530259824748483, 0.056527973182739756, 0.03201640015768428, 0.03084553052641211, 0.07872815934881087, 0.058898310507497484, 0.0457678048030263, 0.09304940700531007, 0.10903876515165453, 0.40649311677102123, 11.008976178784526, 122.5425555629115, 117.93912072335522, 116.34575197773596, 94.25425714062106, 103.88788853922199, 64.54263256442162, 51.21505414285968, 69.7649154355449, 66.06709311085363, 59.97151413271504, 46.18045276211154, 1.5345389540157013, 0.19069765514183432, 0.11184426340004129, 0.18941378371129114, 0.048926258910327196, 0.12907686733430432, 0.03726830060083059, 0.06414681718113922, 0.07757629252850048, 0.19835998995169518, 1.0905876923953335, 52.72733965227681, 105.14880503377607, 109.63500807362219, 106.48661567318825, 103.65370735045403, 89.7847241740073, 79.09111930478004, 75.81151577734178, 83.49341500189998, 95.23177454548498, 96.30038507523076, 96.01088277755245, 103.80991966493669, 96.01334602602067, 93.0511877613683, 93.86342433191116, 91.66744616723831, 81.60549979056083, 72.69099573935233, 70.4269487627091, 68.1360335503855, 68.52885107840261, 68.4286972784227, 67.93282339649816, 68.65690077504804, 70.82517131682366, 70.85400073759018, 71.25718901234289, 71.1063503449963, 74.091642748925, 69.0589907861525, 70.00748265174128, 81.08060036936115, 83.84787174963182, 87.69488534619732, 81.76204158413796, 82.78447012747489, 72.79800584239345, 68.55131841474964, 67.5334555102933, 74.45022583007812, 72.98951948842695, 87.12407850450086, 77.33585080792828, 41.251786754977324, 82.8073218560988, 71.08936648215018, 82.14039341095956, 87.16861309543734, 85.72503182195848, 80.74927776090561, 80.88497607938706, 78.14764807301184, 76.4660652222172, 72.0477113416118, 71.66932029108848, 70.51090317387735, 71.77552238587411, 70.9385984174667, 73.53250888086134, 71.04626747869676, 71.70659065246582, 68.78642528287827, 67.60146156434091, 74.5504580774615, 85.38966132748513, 89.74601822514688, 88.0393635842108, 83.56799494835639, 89.28513972989975, 86.73293190617716, 86.4172124862671, 80.47227997933665, 77.80373465630316, 74.13044283466955, 74.19112190123528, 74.68843921538323, 80.51447683765043, 81.27192574162638, 91.3850276700912, 94.27375132037749, 93.73129537028652, 80.15009649338262, 7.626004469010138, 0.9540150530876653, 0.116617412516667, 0.13433072896253678, 0.1062035656744434, 0.23908998907333423, 0.1327204274674577, 0.20782837704304727, 0.10752720472913598, 0.14465155740899427, 0.07853119814347836, 7.876623330577728, 60.62240008384951, 76.65348391379081, 107.89370321458387, 87.90903106812509, 44.00223508957894, 36.15891072057909, 50.126098279030096, 68.00029600820234, 82.1077279121645, 79.05608469440092, 92.44059239664386, 7.712833487218427, 0.813952423632145, 0.10104518924509326, 0.0828729554890625, 0.062118932649853735, 0.021916036494076255, 0.06809329614043236, 0.08096149717006954, 0.12622904272810107, 0.08482491687661217, 0.06322484185558654, 0.07419736214703129, 0.03723465401919619, 0.037741015154507854, 0.050039070568257765, 0.02718077274039388, 0.031348687498980475, 0.1077310070996323, 0.05065582880389787, 0.03767557592401582, 0.04169558400228139, 0.0651323586522091, 0.021224320385484927, 0.05795303078728819, 0.10103079445299604, 0.02545122774468074, 0.1522279984407848, 0.17114079407145902, 0.06598848489023025, 0.11086482764972795, 0.13879510634128125, 0.1805725621600305, 0.16286762671605234, 0.0788265633426847, 0.16778080904435727, 0.15873384692015188, 0.10885262110781287, 0.16564953711725053, 0.15831021561978326, 0.14938132296646797, 0.08801994785185784, 0.1821896358723602, 0.11109192675400166, 0.16399653388127206, 0.2703040423652818, 0.5654406715785304, 0.5358881863855547, 13.716827573314792, 144.96546714536606, 132.79370923196117, 130.76429843902588, 100.68801110790622, 103.64413676723358, 86.44091144684823, 86.18569066447597, 110.04545273319368, 88.12110577860187, 82.38641231290757, 59.04743509907877, 2.497418441118733, 0.5360143151014083, 0.28170104048425154, 0.42627758256370024, 0.3332258466511004, 0.22432828682564923, 0.15877386735331628, 0.4602233674978057, 0.23112262869554184, 0.9156629142742004, 1.4822343929160027, 50.7212826513475, 105.48686627418765, 113.83306595586963, 111.69005547800373, 108.86499189561414, 91.96751533016082, 84.20854153171663, 79.92881205774124, 90.02107835585072, 99.95094283934563, 101.80388619822841, 99.57621528256325, 106.75159531254923, 101.70969440091042, 93.86324390288323, 98.68696689605714, 98.11669349670412, 86.97786823395761, 75.08523402675506, 76.346283881895, 70.23010069324125, 71.67367412197974, 71.90848288997528, 71.6006866578133, 72.26633641027635, 74.56053072406401, 74.27761016353485, 75.25278199103572, 75.58331228071644, 79.38621490232407, 73.6857323492727, 74.279798846091, 84.25759469309162, 86.03107083228328, 92.26589787390925, 87.05216576976161, 87.70058847242787, 75.10640698094522, 72.61895748876756, 72.07370096637358, 78.67505781112179, 78.111664249051, 92.73707651322889, 83.49877295955535, 47.18336359147103, 84.83191597846248, 73.45817212135562, 84.85738000562115, 91.53305007565407, 89.9481144259053, 84.99617699653872, 84.09841706675869, 81.12397393872662, 79.96682766945132, 78.29021053929483, 74.02694717530282, 75.86395002180531, 74.90132193411551, 75.19438574391027, 76.87181088232225, 73.09074801783409, 74.76876935651227, 71.76286881969821, 69.95305584323022, 78.71126913255262, 89.03438260478359, 94.90206795354044, 91.02649950212049, 87.16502804909983, 93.99097196517452, 90.00617334919592, 88.62660515692927, 84.58654034522273, 81.7300271987915, 80.8487569132159, 78.01198897823211, 79.45265200830276, 84.77881493106966, 86.66276854853477, 95.58016730893044, 97.77056786321826, 99.1310654917071, 92.51485070874615, 6.663988761363491, 2.523765737010587, 0.5097423716177863, 0.25095600154130693, 0.18412587713570366, 0.3652489653998806, 0.31351376084550736, 0.3651906201435674, 0.09942767886264671, 0.45939387813691174, 0.1976618387045399, 17.38230113060244, 99.66569239093413, 81.14877900769635, 109.52831176019485, 96.19643442092404, 107.17197141339703, 43.735761027182306, 57.554812431335456, 80.31539301718436, 99.36380324825164, 89.78702268292828, 111.32824820856895, 8.834712255385615, 1.0146380420173369, 0.2316956931064206, 0.18077139261989825, 0.2671932963834655, 0.17646418583969917, 0.15282194640847946, 0.15264383096608425, 0.2887854845293107, 0.12730266132782544, 0.24594764044928938, 0.15113682876671516, 0.14450118967121647, 0.2780023679858254, 0.17289318955473362, 0.08176653300442042, 0.13015479900904242, 0.152874086352606, 0.17418806200786946, 0.2081036017907243, 0.1598203587796419, 0.11967516819676084, 0.13303907407868293, 0.20385060339204727, 0.1887934210319673, 0.15590177308167183], [0.02149315404465362, 0.1343283540899715, 0.03036383550704247, 0.06406428269861687, 0.06388871832900951, 0.09543443023557625, 0.020094775452068257, 0.08034019220259883, 0.03077029877702796, 0.0633517443202436, 0.04436568387093083, 0.050746931979853305, 0.07050058188577814, 0.06110393892853491, 0.13273185749928798, 0.023514871568148656, 0.03615025656237718, 0.19512797225146525, 0.05128442692840773, 0.17472210189988538, 0.3249256210702081, 45.41544545081354, 123.53005932223414, 104.45920528904085, 81.98320834867417, 52.72593152138495, 42.24193419179609, 134.06793040613977, 121.24215649020289, 54.655549372396166, 53.21802816083355, 39.19319745033018, 2.722078076293392, 0.4199045890521619, 0.38319705715102537, 0.06633742261798152, 0.0904159031568035, 0.035115172185244105, 0.04100298689257714, 0.12142118216762621, 0.026062069866325588, 0.06725844416406847, 0.106130794982516, 37.98809236095798, 104.19770871439289, 107.12243972286102, 102.49842812938076, 103.15166750261861, 102.61925282016878, 94.98828164992794, 79.99783792803365, 67.07739368561776, 69.57257809177523, 75.40336178195092, 85.07843694379254, 84.40753906003891, 91.66480248974216, 93.09431029904275, 91.68037429932626, 86.89261944063249, 83.00501715752387, 68.62690248797017, 67.22535333325787, 69.35777341165851, 69.49944157754221, 65.23841004217824, 65.15060386350079, 65.49180300005021, 66.29718718990203, 65.32844020474342, 67.38146366611605, 64.78229722669049, 66.88653115303286, 64.34108157311717, 65.16211994232671, 69.73376397163638, 77.70159613701605, 81.4430352180235, 77.75126903287827, 77.06592898215018, 67.22732236308437, 63.93408467692714, 64.25510321894001, 62.307171821594245, 61.80597528334587, 65.5893954923076, 85.98570469887026, 80.69148555878671, 40.42439414608864, 73.40209791737219, 66.79018989686044, 80.49542196335332, 81.34908660765618, 79.41170246370378, 76.03169410459458, 78.1270948533089, 75.22949880169284, 75.32636565546836, 68.0672194880824, 66.83682687820928, 65.08252720679006, 67.85258739225327, 68.76065531084615, 67.41382322003766, 68.15064045690721, 66.19327575929704, 62.28563408697806, 65.36392981006254, 77.55264805209252, 83.61925248176821, 83.02750802809193, 81.77220052288425, 86.59424474162441, 81.40559227235856, 82.30345418376308, 76.88011061760687, 75.14049237774265, 71.44006559925695, 69.45611507661881, 67.4629234498547, 67.67930492278069, 70.62515397225657, 75.05523573967719, 76.17701791947889, 88.59917994468444, 90.96865238681917, 85.82779792047317, 36.0828677300484, 0.33971476458734085, 0.6485159815319124, 0.1343134613407235, 0.09932669315246806, 0.06641983069599637, 0.17655037073118074, 0.1604008235998692, 0.04405304721947159, 0.13643230732169845, 0.08358658171228825, 0.1576771971679503, 7.787596314184128, 36.97214749551589, 50.58259548679475, 34.74355090049006, 39.44270333936138, 35.88084997669343, 26.859065178901922, 47.03684345368416, 64.03672133722614, 68.80605282322054, 75.35747789567517, 20.284509889541134, 0.4206416269223537, 0.03729359682409033, 0.02672260428117889, 0.051728727280973434, 0.03653568688840155, 0.029789035907015208, 0.023733154915633704, 0.0337515969670588, 0.03874780790459725, 0.05672103117009806, 0.0292769578405686, 0.014073584837117984, 0.0804191145805582, 0.06466460834828115, 0.048216149030673894, 0.05619112432243363, 0.08331360926310863, 0.07039663141533252, 0.07804558266915622, 0.01189385784880048, 0.015025663587655273, 0.04177339172231094, 0.0729798492524893, 0.017048545564795216, 0.061344260710381696, 0.02071409816703489, 0.03877830586486286, 0.021019782570581284, 0.010739309720755106, 0.04512173221296361, 0.033786051771453315, 0.023087111053868167, 0.051890678268166325, 0.0638967699130937, 0.02765205662487255, 0.08127706410783915, 0.05508881956038456, 0.024301940725455363, 0.0480513520268423, 0.06272466688026344, 0.02516109301077743, 0.05476833050770145, 0.08428642601375619, 0.04757764538930309, 0.22719397660224672, 0.15653439316778414, 66.07722851537889, 136.28913725576095, 113.83421913270028, 98.4868161909042, 68.69494776571952, 62.59019436374788, 117.33591510403542, 78.92222204516011, 43.9418972692182, 47.97809070156467, 43.25236028240573, 3.742804065827401, 0.6884371909883715, 0.3799239618162955, 0.2813574040849363, 0.03798071257469635, 0.18905862534959472, 0.22976185735915938, 0.8726941457679196, 0.06403941931503435, 0.19217124058594628, 0.9884689075331535, 47.017372808148785, 110.15534185594129, 106.78660638870733, 106.35942889798073, 105.93524809806578, 104.67938361629363, 99.60791587829591, 81.11375224205756, 70.267880962741, 73.83191908559492, 77.65477088189895, 88.76837530443746, 87.18557342406243, 95.4223938911192, 96.1153825636833, 94.68382727715277, 89.88541141633065, 85.74345911702802, 73.6559929386262, 70.84543428113385, 72.78172800617834, 73.43485755305137, 69.27723146254017, 68.25008038551577, 67.62356804263207, 68.86050316595262, 67.8019731275497, 70.42039840452134, 66.67404851605816, 70.99107188563194, 66.6027476710658, 67.41821627463064, 71.28191563390916, 81.72750119240054, 84.3044513271701, 83.36347472283148, 79.93939461246615, 71.09536770851382, 66.40350695579284, 66.0778796288275, 63.65057576087214, 64.29511139469763, 69.12924043593868, 87.88220990088679, 84.3770073306176, 44.05429278650592, 76.97618515260758, 70.16549925650321, 82.4869740393854, 87.4914869185417, 84.23325246380222, 81.58508777618408, 81.1904816473684, 78.66155701298868, 79.53959526554232, 71.88307377599901, 69.43265930298837, 67.58177126607588, 70.29321947405415, 72.66507671725365, 68.76154176650509, 71.92363108358076, 70.60416929183468, 62.73550641152167, 68.69097832710513, 84.31793643582253, 87.27142626239409, 83.30153265307027, 85.86636266400738, 89.1840131821171, 85.82982970822243, 83.66930976990731, 80.7393463196293, 78.75563113920151, 75.57346713158393, 73.31659809235605, 71.55760334384057, 72.19179568752166, 73.09655312568911, 78.0193865683771, 79.33967205785936, 88.97545291531472, 93.27962660020398, 89.27699688942202, 48.88517802761447, 1.7117462451419525, 1.1244454691486976, 0.5584394246820481, 0.15376591994877786, 0.2733827965153802, 0.34212058710475124, 0.20556979662468358, 0.016528214816184297, 0.17078099321694146, 0.0534658124970813, 0.14284135293095343, 6.690009765086636, 42.75749052724531, 55.153207932749105, 44.16595482057141, 26.780315752952333, 25.344104613027266, 46.15278436291603, 63.568225599104366, 72.38149719853556, 81.17356054244503, 89.65951427336663, 44.27480843759353, 0.2810082518525662, 0.03241488845237801, 0.12211168785729717, 0.02604803322033296, 0.03641157298378887, 0.010871454142034056, 0.0565986218111169, 0.03379829768692294, 0.05132966442033649, 0.026631278939725413, 0.013411504839877448, 0.03692341164775914, 0.061653066922219536, 0.08141809323381993, 0.007765990336455646, 0.0872334283626368, 0.03428343052585279, 0.09677710657518718, 0.07102989501530124, 0.0742589479552642, 0.0382449209780222, 0.03156696127036647, 0.07705955856269406, 0.037560547822185104, 0.041277311486943115, 0.13683770572946918, 0.16212531816094153, 0.08905900822531793, 0.10902519007363629, 0.18032010554546313, 0.2968082024205116, 0.13241762355450662, 0.16197499638843924, 0.12311357764467118, 0.13825334428298858, 0.19512987214951746, 0.13710528491966187, 0.1446624818227945, 0.19689815629634166, 0.2601812016819754, 0.2889168532865663, 0.14450619988624128, 0.3641661154406686, 0.2784748910175216, 0.3007842293910442, 0.409050839202058, 78.65335925932854, 154.4258474534558, 131.11469161125922, 112.46232309649068, 74.75340151017713, 56.95983594463718, 143.4358996729697, 137.40316883210215, 75.07557715139082, 76.40347203900738, 64.6044530407075, 5.275942365969382, 0.8713018269308153, 0.5884321346398323, 0.49039754836309346, 0.3952547294958946, 0.37117934395228663, 0.23498838497025354, 0.979524800373662, 0.3212016063832468, 0.4098531171198814, 1.6927140470473998, 46.20623450125418, 113.69976028319329, 112.6086510381391, 109.46253361240511, 111.21987312070786, 108.52718953163394, 103.39978879497897, 86.89177220867526, 73.19327092939808, 78.36292343754923, 82.37322530438824, 93.49156010535457, 91.3527387188327, 101.348828500317, 100.89164487777218, 96.7825149720715, 93.91170086399202, 92.10468061508672, 76.6351350661247, 73.21922133045813, 77.37876153761341, 78.57091103830646, 70.92085361480713, 72.69726368688768, 72.24561845102619, 72.01976837650423, 70.49151097574543, 72.50681692554106, 71.82918825457173, 74.22336378405171, 69.26003579170474, 72.64979516306232, 75.72905971157935, 84.4126695202243, 91.0185920038531, 88.11490058898927, 84.38460888401156, 76.16150102307721, 70.70520954747354, 69.17652853073614, 69.00025721519225, 67.25749323444983, 73.03668991211923, 94.60690959807366, 90.96537328535511, 50.294058092178844, 78.28649213237148, 72.60421722166001, 85.99113325918876, 91.89611250354399, 88.39210233380719, 86.1055644865959, 85.86957900754868, 84.63704478356146, 83.84997414004418, 75.5395935427758, 71.94760461007395, 69.86009567014634, 73.70134338255852, 75.78347867535007, 72.34242254687895, 74.27801809003277, 75.03472958841633, 67.57503263411984, 73.37817145932105, 87.29679615266862, 91.1496619255312, 86.91951121053388, 87.50379531614243, 93.55771480068084, 89.30092334747316, 89.28011909607919, 85.88704139955583, 82.1916352548907, 81.39933216956355, 77.6964892110517, 75.66860029774328, 76.74497712043025, 77.61638656739267, 82.82790645476311, 81.67126224886987, 95.0324240038472, 96.75190479524674, 90.16658259976296, 57.25053848758821, 1.1736019604629087, 1.9620712966688219, 0.5736593854042792, 0.5115182860003364, 0.17955522804010302, 0.5297855912677704, 0.4045062217741244, 0.27425913981372313, 0.18692678651742398, 0.16065464385094183, 0.2119929995387793, 12.65671289736225, 55.87049176616054, 62.35134947684504, 54.51140226856355, 59.82174235005533, 49.34162816693706, 42.346481046369, 66.91473299457182, 85.47938162280668, 94.87301103530392, 104.31903546856296, 56.02105194522489, 0.9111784807135983, 0.12103697375184107, 0.31519943007057716, 0.1730831487164382, 0.1403365365319675, 0.10700830273450383, 0.20307751342413888, 0.15960524129050394, 0.1311288185177311, 0.14959631788153804, 0.1477837844962074, 0.09645997681805203, 0.1501289175282563, 0.20506134406933862, 0.2424917871793432, 0.15668803976187784, 0.1948338557755755, 0.18182333859224475, 0.20404917338202078, 0.09413935859958011, 0.08069691338366078, 0.12987517691668005, 0.2450694432181697, 0.1857134411411901, 0.1642849966282806], [0.06809001728411644, 0.1528327635699703, 0.06963870998832487, 0.019074403793520985, 0.03104952824932914, 0.06569632959942664, 0.03762194976931618, 0.07386587590219514, 0.05871900379838002, 0.03742531798179111, 0.00911562754246857, 0.025834842442324566, 0.04176025714484915, 0.050744618394321976, 0.09877212976496066, 0.03729119130800809, 0.06376503726407405, 0.028521445760082816, 0.22011717811467188, 0.04526491787645125, 1.358327086894743, 91.2226023212556, 113.98345747301656, 91.43507711348995, 66.22092062427153, 31.32252827767403, 37.07277197991648, 105.3676732893913, 147.11318446743874, 81.4324369738179, 67.06174342863022, 12.117523301032282, 0.04876925302068553, 0.17885865493407174, 0.12023543893930413, 0.4703773419943548, 0.23251280248645814, 0.043950916207846136, 0.24191870744670593, 0.20394556765114108, 0.04077959948429658, 0.7475682696507824, 43.117983802672356, 105.6948224959835, 99.02785224299278, 105.1536766175301, 100.84483531213577, 99.79396958504954, 100.52276165254655, 97.77037174470964, 82.4648283373925, 68.96315943810248, 66.99068577058854, 67.40722579340782, 69.05291895712577, 80.6019849161948, 86.27610129694786, 91.45922322427073, 89.77724029171853, 84.58865058037543, 77.45982908433484, 70.87561299723964, 72.99679156272643, 73.17896996774982, 70.97249554049584, 67.23356677639869, 62.99279428297474, 63.380179328303186, 61.849705788397024, 65.5442137102927, 62.613818799295736, 65.2545270612163, 63.75113748734998, 63.676180993357015, 64.72514437090966, 75.7320720918717, 78.97584869015601, 76.58680362086143, 78.08874976250434, 70.47469969718688, 69.29975371206962, 70.67551720526912, 72.27946066087293, 71.8781159001012, 70.66966502897202, 70.6153323573451, 78.81932258605957, 82.13066593293222, 37.18115099014775, 68.82087153773155, 68.2427220190725, 75.55216866154825, 81.43525323560162, 78.88187654556768, 75.71127568521808, 77.87797727892476, 79.1877665058259, 77.0662506165043, 72.8503224157518, 66.49955011183216, 62.50285886949109, 64.22797610682827, 67.1987831977106, 65.46584475424983, 67.1051719111781, 66.88766864038283, 61.97580998943698, 66.5837320204704, 78.39508687296222, 84.8229572849889, 80.68855162589782, 85.65456251944266, 81.50824069976807, 77.25826632591986, 75.35708565865794, 73.712326019041, 73.69021169600948, 71.28540654336253, 68.32755504115936, 66.48215832248812, 68.66430620993339, 71.96336469342633, 68.98412842904368, 73.1693523160873, 77.68363168162685, 84.39334008001512, 91.18420231726863, 77.07395415152274, 16.388257799610017, 0.04169157353199778, 0.8535784134461034, 0.2697648390406563, 0.15561430624896483, 0.18329163802967918, 0.036314865874667326, 0.0819412240337941, 0.11641770105568633, 0.1987041779343159, 0.14384770135004676, 0.4313168169990663, 18.327488399321034, 33.492448176107104, 40.72474571966356, 34.188798319908884, 41.93952729625087, 21.70840478712513, 36.482278762325166, 68.48192384166103, 71.1651780528407, 72.06027077090356, 64.38267830879458, 5.823861687414109, 0.5799436965777028, 0.1431714602175259, 0.0511723137911289, 0.0648101037668605, 0.07567428007361389, 0.005822757084388287, 0.05959511343990603, 0.0869319651035532, 0.016456779032464952, 0.02586912870737574, 0.04183417696866297, 0.08567191134657591, 0.03163133755386357, 0.013413973558213443, 0.0475094405814044, 0.06363591314443658, 0.010503515518540818, 0.052317190059130235, 0.012978299355675137, 0.08436045308987941, 0.0607008541062955, 0.04068351673683332, 0.08024698228485162, 0.06117380231678967, 0.025900463618698622, 0.06929862057609905, 0.06499003483763625, 0.031710267592702186, 0.055942329608144305, 0.0542649800979322, 0.028899849144621726, 0.06970305371308519, 0.03490834376744686, 0.08922628352358457, 0.06318785130016266, 0.028136333360547022, 0.06056933596189465, 0.054241844242618936, 0.013616423783523422, 0.032678794250973774, 0.05305930326182035, 0.014302054281166245, 0.11197967710153711, 0.07468310785630057, 3.812646034263796, 114.1692130796371, 118.92602828241165, 104.76060021308162, 79.67075932410457, 50.64344321527789, 46.60102890383813, 85.11330681462442, 123.50472081092097, 65.0682144780313, 65.52757109365156, 14.000404150255266, 0.2447815320544666, 0.22614586106952161, 0.3593373406798609, 0.4213089814349529, 1.2761680180988004, 0.43897141432089193, 0.6384209038749818, 0.9920262521313084, 0.22732021257040963, 1.7807844954152263, 52.89993178459906, 110.90876640812044, 101.33313117488738, 108.456649626455, 103.20069712977256, 101.64357892928585, 103.77729338984336, 100.43798354364212, 86.82739826940721, 71.9473300441619, 69.47851965504309, 69.74600961131435, 74.37963101171678, 82.52644092805924, 90.02604407648887, 93.18716849050215, 95.18164665468278, 87.49536222027194, 81.45557111309421, 77.55624878791072, 78.69765066331433, 77.84835553938343, 75.09547925764515, 71.14692334205874, 66.4055936567245, 66.16176343733265, 65.05713770466467, 67.96196660687848, 66.49449025430988, 67.07050600359517, 66.36924897470783, 65.99266221446376, 67.76591870092577, 78.52771789796891, 82.99637225366409, 80.45913219451904, 82.20020171134703, 74.38305131850704, 70.91810795568651, 73.41767757169663, 77.34480950140184, 73.74841966936665, 74.56094649530228, 75.13848412421443, 82.13835377846995, 86.71465366117417, 38.49854961518319, 71.01889717963435, 72.2530552648729, 78.27333650281354, 86.33219903515231, 81.45628498446557, 81.3361192518665, 80.1053108707551, 82.09134809432491, 79.42142209699078, 75.16708604751095, 67.20268987840223, 66.05609478489046, 68.23467331547891, 72.20602604650682, 70.70976734161377, 69.11012280371882, 69.3954909232355, 65.83426121742495, 70.12374170364873, 83.65816239387759, 86.83030866807508, 81.96864851059453, 86.67464548541655, 84.07064668593868, 80.47490796735211, 79.64751535846342, 77.72939005205708, 76.86820230176373, 73.66772867018177, 72.23716182093467, 69.42719151896816, 72.88940491214876, 73.10300934699275, 72.14363682654597, 73.26151232565604, 81.26365738530313, 88.8729456932314, 94.54725819249308, 83.74534099332749, 24.828285478776504, 1.177645433814295, 0.6716158000692245, 0.6532746132823729, 0.4927528397210183, 1.0074963865260924, 0.4100545369569333, 0.14585937163041485, 0.40565112485520305, 0.29774442315101624, 0.07665275055314265, 0.19251955012159963, 20.888368583494618, 32.952588835070216, 44.449942265787435, 35.93685357801376, 22.956850105716338, 26.738048291975453, 43.90925922701436, 78.38154685112738, 80.69070892949259, 82.51281461408063, 90.34262641783684, 16.062576540054813, 0.6471826208214606, 0.16843723914315625, 0.0674785488855935, 0.046438150888969826, 0.11164111986515984, 0.07367835290008977, 0.06864610518659316, 0.030118352207805843, 0.052757614006799076, 0.04545471232925211, 0.09277146264550187, 0.040265374456442175, 0.043963204258151596, 0.03269403940066695, 0.05784738726252991, 0.04135445271047854, 0.08223894112292798, 0.07306909083478874, 0.04189858964133648, 0.016312898144186024, 0.06880572726649624, 0.10198498760620434, 0.03650586691594893, 0.07526124376923808, 0.144098166136011, 0.20432755441194583, 0.1242971451832883, 0.12507873106627695, 0.18947617391184454, 0.15094110862382, 0.14730197647886892, 0.1332587880953666, 0.1911967767462615, 0.19275286985981852, 0.1524159351303693, 0.07205837571452703, 0.22052990032299874, 0.19069460611189568, 0.15158347334832917, 0.163181017964117, 0.1311424395610248, 0.15480409166024578, 0.3578776061054199, 0.38806551526631083, 4.769308442069638, 131.8522148747598, 134.13701118961458, 120.0298930752662, 93.26381944840955, 52.8459874276192, 51.21546599172777, 113.32223999884822, 158.36994755652645, 113.79990623843287, 97.5644551554034, 18.813891718464514, 0.49022910095030264, 0.9246976036698589, 0.6304115465571803, 1.2388196996142788, 1.6808550059795382, 0.39122106206993906, 0.8992462016401753, 1.789889297177715, 0.4156947214036219, 2.0598263221402324, 50.737799752143125, 115.21360689593901, 105.50539555088167, 114.05842181174987, 107.51903841572424, 104.38064021448936, 110.16433977311658, 104.79761954276793, 91.88467487212151, 77.2325748012912, 73.99783534388389, 74.06481373694636, 77.34477812244047, 87.42655600270918, 97.33057206676853, 97.70016131862518, 97.26828482843216, 94.85175963371032, 85.26391798450102, 80.15496807713663, 80.72718697209513, 81.11572127188407, 79.3714040325534, 74.84293353173041, 70.27560018724012, 68.85707501442202, 67.71342954327984, 72.12967318873253, 69.5790578472999, 70.49009107774305, 71.30573226559547, 69.63983105074975, 70.5498601544288, 82.488786174405, 85.87638824216782, 86.24939780081473, 86.06276358327558, 77.9274775904994, 74.3620038801624, 76.92675544369605, 78.94565428456953, 78.02976515985306, 78.87691082492952, 79.68824525033274, 85.37159489047143, 93.22872208010767, 42.229139420294, 72.8671964522331, 74.49026538479713, 81.55518362599035, 88.87372232252552, 85.99666380113172, 84.47686303046443, 85.71746949226626, 87.14070935403147, 84.56415145627915, 80.20801421134703, 72.40164249174057, 68.65781076492803, 69.84355895749985, 75.03043067070746, 73.9664799167264, 72.68015430819604, 72.20218996847831, 68.09790026757025, 73.6382246017456, 86.90375897192186, 91.09105387041646, 85.36093388834308, 92.64786612602973, 88.18640539723059, 86.11376224025604, 85.30185514880766, 81.39863398767288, 83.03629413727792, 80.21993037193053, 75.68475261811288, 74.42384396829914, 77.76098866616526, 81.14956348173081, 76.73586153214978, 78.99520950932657, 85.3478959298903, 94.86296192292245, 101.50491529895415, 83.22830984669348, 26.243876718705703, 1.6018148343409262, 1.6472195785853172, 1.2229963680428844, 0.6672018465976561, 1.0715963114653866, 1.0319775535214333, 0.2506506695382057, 0.4662852680250522, 0.8393123854071864, 0.23090263888720544, 1.002384189876818, 30.090190172195438, 51.08866753116731, 58.75291608995008, 58.360043648750555, 60.49853555617794, 33.07640237192954, 53.83435803074991, 88.7649549976472, 97.40506572108116, 93.90991226319345, 111.43108490974673, 17.91268010293284, 1.0945771105827824, 0.4033774065394556, 0.2390497694573095, 0.11391064767996151, 0.34047889132653514, 0.11551138073686631, 0.1623264928498576, 0.17215118743479255, 0.1255956259105475, 0.14935115442400979, 0.21431430723638306, 0.1856452746376876, 0.12606014332343496, 0.09899861599889495, 0.08134215859876526, 0.20532976595624802, 0.2194870554751927, 0.1650652418574018, 0.1263734579627072, 0.14515765041353243, 0.12324720636130342, 0.1913321138389649, 0.10602035574735173, 0.17333686171520143], [0.04620022313188642, 0.023938851438522823, 0.06715827816796881, 0.0683047593901715, 0.08658084402521772, 0.060737059421596996, 0.09117319639171324, 0.047499772551799976, 0.061815944875800805, 0.02145993072659739, 0.04579084872778866, 0.02323695402141781, 0.08890068849488612, 0.02565712153521036, 0.04743960017578737, 0.1288083688386025, 0.15555796814301323, 0.04873808473348618, 0.31649442509778086, 0.49461094001608513, 14.112495683854627, 114.73432463984336, 96.83961683704008, 104.8193573182629, 69.43056475731635, 42.553523355914706, 48.19729628101472, 74.09723604879072, 81.42122683986541, 62.495724078147646, 29.81417102198447, 0.1714340525288736, 0.012006894122028064, 0.0864688036662917, 0.07648998751275002, 0.07377779877354061, 0.451387002943985, 0.28675801751594393, 1.163766862403962, 0.410197550250638, 0.3490891986556592, 55.255326840185354, 115.37105867939611, 101.13134091900241, 97.96550181604202, 94.7738064489057, 96.04503877701299, 99.82490139622843, 95.24188641578921, 93.699916408908, 87.32015778941494, 73.44172954559326, 64.6719648761134, 67.66805556512648, 67.16594511462797, 69.69534827816871, 83.91964327904486, 90.81483271814163, 90.3436383893413, 84.94349172038417, 82.32517626977737, 75.99403935094034, 75.63791951825543, 77.34320917437154, 73.72669758335238, 68.20455735729587, 61.53153096475909, 62.96027783424624, 59.60284663784889, 63.757672156057055, 61.049416757399044, 63.88049725563296, 61.25551377573321, 64.4066910589895, 69.97116150394564, 71.31484785387593, 73.695891288019, 77.13748085883357, 72.91063277952134, 67.89938911314934, 74.07963245145737, 81.19851466148131, 86.31880806338403, 81.80863934178507, 77.61053439109557, 75.09835043261128, 80.08863295278242, 84.44573510077693, 33.22131041557559, 65.65703284355902, 68.67870915320613, 73.09318773208126, 79.7216324652395, 79.58800515820904, 79.97121287930398, 75.2978970927577, 76.24378450455205, 72.55310089357438, 72.63777702085434, 68.07473474933256, 66.32862106446298, 63.22982703485797, 68.59455077878891, 70.9934723761774, 64.00264770753923, 64.53104196056243, 61.33604788011121, 69.92745845548569, 80.96794989801224, 78.43478125910606, 80.05012312243062, 78.93838221027006, 76.49095658333071, 70.56933079996418, 71.80943519838395, 75.06291574047458, 72.82129687647667, 69.53369955862723, 66.00340166399556, 64.33033035647485, 66.49617687348398, 68.3790636062622, 70.28918727751702, 62.95677123531219, 74.62520276346515, 83.52131874330583, 81.88443522299491, 89.64948085046585, 53.73601244341943, 10.617437343443594, 0.14926648638661832, 0.5568983622135655, 1.5772612873584995, 0.2593727644172407, 0.16659482832877867, 0.0811287418248192, 0.2329284205071388, 0.10875355827832416, 0.06805309950704537, 0.1734531691838657, 1.081177068333472, 29.227149101995654, 51.52422712695215, 37.83622603262625, 30.313859408901585, 41.33131281022103, 25.58308089933088, 32.69965087213824, 53.21227404379076, 70.81717752641248, 82.84278008245653, 52.02145030421596, 0.45709739168805463, 0.03912694481832366, 0.14443774226932757, 0.05465063641989424, 0.0347426044754684, 0.06360575609329729, 0.035714563207640763, 0.03438188814588132, 0.053113710826202754, 0.08294997796896966, 0.06100655000116076, 0.03017012634494853, 0.044658972971862367, 0.040931461093526696, 0.015718769188219264, 0.028506945630895997, 0.1128933825079472, 0.03039205627095315, 0.04881378188128433, 0.005582747004565693, 0.030180156351097172, 0.034041162880678336, 0.017716685317516807, 0.07882611901168862, 0.08344216647768214, 0.06148624361582822, 0.020426278933882713, 0.062681884700132, 0.057115489842310074, 0.0499587347580781, 0.06352027983314569, 0.05177983300640218, 0.09004458033990476, 0.019592216028080835, 0.016787309582615574, 0.04110011151961742, 0.030264050639685125, 0.06066402442933572, 0.17683077423322588, 0.04257517934386288, 0.1577780296605441, 0.057039068741423476, 0.26690426673139295, 0.7801466182835641, 22.98505194725529, 138.10199399148266, 106.51041661539386, 118.6517055573002, 73.795182166561, 55.200182237932765, 31.99563837820484, 68.0318397091281, 86.47809551608178, 63.59277571401289, 31.67646335017297, 0.09614375104466755, 0.10674922712027066, 0.10050493638001143, 0.31900373077200306, 0.6488130397854314, 0.8984880810303073, 2.3057694733142853, 1.6231475025415423, 0.18917599001959448, 1.2686630530703453, 65.4834601186937, 123.06014368610998, 103.70468247321345, 103.0013858118365, 97.5841611431491, 100.81537046740132, 102.56554772776943, 98.3528829390003, 96.58173668769099, 89.75428658147013, 77.89435709676435, 68.36297404381537, 69.09273101437476, 69.38376303642028, 72.8546448676817, 88.2153367996216, 94.82278116287725, 94.06528519045924, 89.44661586515366, 85.95025431725287, 81.10086333367133, 81.62719834235408, 82.47839189344838, 78.15656754278368, 69.98710201632592, 65.09648299986317, 64.35901857191517, 64.30357586952948, 66.53817761328914, 64.94604441427416, 66.18677246955134, 64.47552473314347, 66.61155731447282, 73.4847971700853, 76.01693814800632, 75.31652050633585, 80.41062816496819, 76.70871088581701, 70.8424219008415, 78.18913105995425, 85.41877315890405, 87.22801346932688, 85.57669562678184, 81.87161691727178, 79.39378507675664, 82.43585771129978, 89.16110654031077, 34.38500312066848, 69.67544617191439, 73.35340561405306, 76.14722359564998, 82.62529250114196, 83.08273500011813, 84.76245080271076, 79.6747366074593, 78.77595686143445, 78.38765790385585, 76.52039004910377, 71.2926237044796, 66.94997941294025, 65.21961404431251, 70.39919407136979, 72.55764299823393, 66.93969495834844, 66.67204026252993, 62.97286079775903, 72.0993689567812, 85.2548651541433, 82.1411386612923, 81.44785973333543, 83.32420395266625, 79.48877703758978, 76.9767499739124, 75.59129822638728, 76.98291593982329, 76.39413679799726, 73.54526442866172, 71.5208899590277, 68.57596658891248, 70.12301214279668, 70.49628057787496, 73.71744078974571, 64.86628301682012, 76.29298671599358, 85.45383914824455, 85.80578557906613, 97.35263147661763, 64.47865086217081, 15.699573928310027, 0.7013071616811137, 0.7212654681455705, 1.6316964309061728, 0.7813107042062668, 0.8570842769357466, 0.6360046012747673, 0.45477580819879815, 0.5146877143171527, 0.1703150125761186, 0.22983950803116446, 0.9808755053147193, 32.14371177457994, 50.083418969185125, 44.874091686741004, 21.527612939957653, 36.476254001740486, 37.80636502850441, 45.76938052331248, 61.76486492156983, 82.91920354289394, 91.96929608621906, 78.8613860837875, 0.8478018653488929, 0.08406368594977164, 0.05117610592635409, 0.04756442271173001, 0.040918912573326985, 0.016520609478316, 0.014682542382469101, 0.07448186421947134, 0.10748478644076856, 0.05234334430086517, 0.013564267560028502, 0.02136307997599004, 0.04888089884433055, 0.0946985568190294, 0.08426456952527647, 0.004036869673478988, 0.05542359998329513, 0.04661254697449265, 0.029426551829542846, 0.08472445976710127, 0.06723001464119843, 0.046037180469401424, 0.02286661179706214, 0.1324574601265692, 0.10729989112024346, 0.1863245801219056, 0.09708174909915655, 0.13339979423870965, 0.13278254187635838, 0.11519567590327033, 0.17681148413929249, 0.10975802212112373, 0.1903205560219865, 0.12511457632025405, 0.134342220281401, 0.19053231804601609, 0.17965262845879604, 0.12776551632991723, 0.2896526960595962, 0.09028713909849044, 0.31037739688350313, 0.2238752683925052, 0.46029694258205356, 1.0196402284406847, 29.198925687420754, 156.55170932892833, 120.55856581657164, 131.97167458072786, 89.89549975241385, 63.72268069174982, 65.10096234659996, 90.75753473466443, 97.52420379269509, 87.23225747385334, 42.1000934416248, 0.5529962167624505, 0.34833591972147265, 0.2069441277173258, 0.4792897637572981, 1.4145105043726585, 2.515463059948337, 2.2703583153986164, 3.2827218117252475, 3.7585393892180536, 1.1706605505558754, 66.74282335465955, 126.07232001519974, 111.27022850898005, 108.28447326537102, 105.66527135910528, 105.00656420184721, 109.62014229066911, 104.18809890747072, 102.13631491507255, 95.29090819820281, 83.71300497362691, 72.42071305551838, 75.07193719187092, 75.90799823884042, 75.99561614374961, 92.21914322145524, 99.23698517584033, 97.18964130647721, 93.70299939186343, 89.24033057305121, 86.57260894775392, 84.2277297665996, 86.38255442342451, 80.78645398539882, 75.10512828826904, 68.37406650666269, 68.95209835421655, 66.1816498541063, 70.86874100469774, 68.60270930874732, 72.81383652840891, 66.77121346996677, 70.60416144709434, 77.619171450215, 80.62317355986565, 79.99927351551672, 83.9006119389688, 79.19688993884672, 74.42637781943046, 81.73875839479508, 88.22003579908802, 92.00873944067186, 90.71165869312902, 84.13680138126497, 84.0205737083189, 89.20003214190083, 94.72509061136554, 41.19203336777226, 72.05726623535156, 76.43490591356831, 78.60122311499812, 87.25412860993417, 88.37836619346373, 88.76520602933823, 83.20601509463403, 83.83151546601327, 81.51381831015311, 80.04194890299152, 73.85157800489857, 71.95711243537166, 68.60700822645619, 74.31814393689557, 74.99114421106155, 69.9738444051435, 69.66156882624473, 69.3225819064725, 75.97758893043765, 89.50466694370394, 84.03924419033913, 83.72131255365188, 89.13310081728044, 85.36558581936745, 83.38915055797946, 79.84754054777085, 81.82515252021052, 81.38019100312265, 78.43408307721539, 77.04820771371165, 73.69724058335828, 75.96748490487376, 76.11677031363212, 78.76912409259428, 68.49451464991417, 82.47940386495283, 87.39114484479352, 89.08815045510569, 97.25850243722239, 68.98061398536929, 15.982378778919099, 1.0950853026682332, 2.0294709768026107, 4.81338607688104, 1.4051981847132407, 0.5866445757208333, 1.003587376927176, 0.8566485874114499, 0.9341162563331666, 0.1935344634036864, 0.3069467019409903, 2.721916033375648, 46.840391543603715, 68.33885146725562, 57.57609521189044, 44.56886852941206, 57.94439792633057, 42.009251348433956, 50.843146770231186, 75.26614158384263, 94.4713681743991, 105.10219158664827, 87.4345733273414, 1.1354909861280074, 0.2028680496638821, 0.2153122286883093, 0.11872919516698008, 0.11764688146931511, 0.09683429503873472, 0.0746913279797281, 0.1491640757529005, 0.40231625219025924, 0.17154363374556267, 0.13316313435714092, 0.08794246571919612, 0.23497384462145068, 0.1706871321244586, 0.1738999976265815, 0.18600980991557722, 0.22381067185872988, 0.10434850674843597, 0.10443034026050761, 0.16216991979989315, 0.18530891607365302, 0.1353927719737253, 0.13864884483477763, 0.19782074066179414], [0.07826257707370866, 0.013592549610973127, 0.0593664170423102, 0.035685145431348396, 0.018932577936098944, 0.037613396397641594, 0.028706925222650174, 0.06735166940357416, 0.0386556628490648, 0.021506828714102026, 0.12638853457305702, 0.033141250887344924, 0.05833987071509323, 0.1555686320869192, 0.03355822105321192, 0.09146607180516567, 0.05241790763853539, 0.019410080539302963, 0.0987722599999078, 0.1794892372263055, 43.94162270330614, 112.35376757960167, 87.15481419717112, 87.41427898406984, 46.43320245127524, 40.34266371880808, 71.31296511619323, 61.478222031747144, 63.05175927377517, 43.29057593499461, 4.581997615675773, 0.23712992247554565, 0.16412398026835534, 0.23872435062883363, 0.33851632728211345, 0.33263721533360024, 0.5839108062847969, 1.1345536622308916, 1.6701463225387758, 0.7483607109996581, 40.73397113430885, 116.02188187260782, 96.2083976499496, 96.83876960508286, 86.69513594719672, 87.22019226320329, 89.1436049246019, 92.0286964601086, 89.91832010207638, 91.05560348879908, 82.65119583375993, 75.6121495462233, 65.01089296033307, 62.67390558796545, 65.06786538708594, 65.11354923248291, 79.82789731794789, 88.10114875916513, 92.91395971851965, 89.0695191967872, 83.06501373167961, 83.52293475981682, 82.47781138266288, 78.67650908808555, 75.8536498777328, 69.45711920338293, 64.04119676159274, 61.588040551831654, 59.19523392954181, 62.22990112919962, 60.414039857925914, 62.191273627742646, 60.485175963371034, 66.70731805985974, 71.31060384934949, 71.40547813907747, 73.8379438461796, 76.75660302562099, 68.47120792635026, 64.99530938363844, 73.93062160861108, 83.50226386900871, 79.7445861754879, 84.03330572189824, 84.82337305622717, 81.25811115387948, 83.12878362594113, 79.69565068521808, 28.962797041862245, 66.93974987153085, 73.93335942299136, 75.19884155642602, 76.35993373009467, 77.92508494469428, 77.16655346655077, 79.59203735474618, 77.76212615351524, 75.12022941343247, 71.43939095158731, 69.75555666031377, 70.6571291339013, 63.34619199076007, 60.616885231387236, 70.30253902558358, 62.93198185582315, 65.20062977267851, 59.16524348720428, 65.23353453605407, 77.46033899245724, 79.90836081966278, 78.60377265561011, 76.39099890185942, 71.12760174658992, 69.66438508802845, 71.0161828994751, 72.25303957539221, 70.29325085301554, 73.04946114940029, 66.00498630154517, 64.0139872797074, 63.86452144192111, 69.59369613278297, 65.96019283417733, 63.99432443803357, 74.15402412414551, 82.81256998738935, 88.53377834443124, 79.31201934814453, 81.06837826390421, 55.45443419487246, 8.660918897198094, 0.4368549585342408, 0.5157857328172654, 0.8505193937209345, 0.640499085908936, 0.14030855900097278, 0.5609964423121945, 0.14671978029993274, 0.05069440899176463, 0.2107675959386172, 0.2231604317503591, 7.763770366868666, 33.47132621272918, 46.43046463689497, 39.10366150640672, 33.54595322762766, 17.81339510794609, 26.9479892330785, 55.907962168416674, 66.88754312453732, 72.47134300970262, 83.82924049131333, 9.639734606589041, 0.35167949514523633, 0.043253228443885045, 0.06288561046183591, 0.05219436318223035, 0.058672647818081805, 0.014625892095688372, 0.02206368653494264, 0.031089830219805725, 0.0681299917520054, 0.022766233211563482, 0.06853600303011556, 0.06664931999459382, 0.07040985409290561, 0.067205453862346, 0.0488151187047122, 0.023204431673812292, 0.03481640172521434, 0.08705352793537802, 0.04001926104988783, 0.08649757792872768, 0.05079146850133135, 0.027542180464332624, 0.024658416758381554, 0.009882269922884242, 0.05921318413569562, 0.021501797431659316, 0.0314610687670328, 0.04916899003869584, 0.03701920711225079, 0.04578440592834546, 0.003079628926746908, 0.0818863338340194, 0.02654001297008607, 0.053629690195403756, 0.03761983536664517, 0.0903956401312063, 0.07551000784001044, 0.0641747142729019, 0.048358170240516626, 0.07248870262335386, 0.028266717694819938, 0.04447578985784804, 0.08371047345140288, 60.74795907543552, 124.52987147915749, 98.36486185750654, 100.90618118163079, 65.14002523114605, 58.20228984279018, 47.98748085575719, 66.34951945274108, 67.7059535057314, 48.18368173414662, 5.799719499003503, 0.271533613483752, 0.12547047778723702, 0.5756695388305573, 0.16731174873007884, 0.7584659010171891, 1.4492426019522453, 2.461368917457519, 1.700295866016419, 0.7109038531780244, 49.478777762382265, 119.7965120500134, 101.47022585715018, 100.90893468549176, 88.7877675025694, 91.40486701842278, 92.6437319478681, 95.73401835656936, 93.51764386700046, 94.13483665835474, 87.85030534190517, 78.94481489735266, 69.40066060712262, 68.21836410030242, 68.66879340141051, 67.11009840811452, 82.99652130373063, 93.91152827970444, 94.35982381143879, 92.48352666055003, 86.84548039590159, 84.55882487758514, 83.61380823196905, 82.54784922445975, 80.01678297596594, 74.34221944501324, 67.98336705853863, 64.3796580837619, 61.78091526031495, 63.78666239400064, 63.2862699416376, 63.55328529111801, 62.59035125855477, 69.37542407743393, 75.17266365789598, 75.07698920465286, 77.79016325550695, 81.11528981116511, 72.5388313108875, 67.47539658700266, 77.64450211678782, 86.20052506846767, 83.1719296978366, 88.68783335531913, 87.49577799151021, 85.05196094512941, 85.81318316921111, 80.78263359685099, 32.12282515341236, 68.05971991631293, 75.21600584830009, 76.80709961921939, 79.15351636948125, 82.00992753428798, 83.7762257360643, 80.89907307778635, 82.32003796485164, 79.93882979116133, 74.96298943796467, 72.47573606429562, 74.84578901721586, 67.1014456595144, 62.80453228181409, 73.46185914931759, 67.97778160341325, 66.59363992752569, 62.55659534085182, 67.99500865321006, 81.17955392406833, 83.18738383631553, 82.83117771148682, 80.11917252694407, 73.81576676522532, 75.41813342801987, 74.97388578230336, 76.65186005253946, 75.55872686447637, 76.48690085257255, 69.03247556378766, 67.10809799932665, 67.39376421897643, 72.41158177775722, 67.7947481216923, 67.96091541167229, 78.34184462024321, 86.14823202933036, 92.25721374634774, 85.05542832036173, 82.95623071732061, 64.37430012610652, 12.00289007156126, 0.39370260471778534, 0.7645550742745401, 3.2043626616078043, 2.7518231253470145, 0.8865874260663987, 0.3792642375394222, 0.33915662356922704, 0.19305645518245237, 0.10110302888337644, 0.21113646727415825, 7.848869619830963, 35.77081572624945, 52.48561182329732, 39.55897023600917, 31.23823262030079, 29.12311019436006, 35.434362657608524, 65.1461519733552, 76.72838549460135, 80.24311942438926, 100.86771057498072, 21.165703688898397, 0.9331387281417848, 0.1311360503877363, 0.14012886541745356, 0.04092959566943107, 0.06425327658953686, 0.049105519654169205, 0.049234505877980304, 0.028845770998046767, 0.01785956646105455, 0.045663555558290214, 0.023818604362707947, 0.06951817371431859, 0.08035716105012164, 0.030953343995215914, 0.041693289568948175, 0.10419790918428092, 0.03244783789400132, 0.03504235169760162, 0.07139888892491018, 0.04763112215685749, 0.054096835289871505, 0.029659758569792877, 0.013077394743900628, 0.1703895376093926, 0.16740809194743636, 0.11956312017695558, 0.21761940972458935, 0.10119508200835797, 0.10954803742107846, 0.13568167905172995, 0.1272863513159175, 0.14159371745922875, 0.13308248062047268, 0.2491482332228653, 0.1305066938361814, 0.20372263606517546, 0.20830276932927871, 0.16917767844373183, 0.22439565659771044, 0.14451307935580132, 0.1120215897718745, 0.21251898018583176, 0.29170081680340154, 72.06526002576275, 143.66830795041977, 110.80791442624985, 116.20336994048088, 68.62285460195234, 58.68942076160062, 85.15176173179381, 79.69612136963876, 86.09408763147171, 69.63758745501119, 8.926356473276693, 0.44764328447561114, 0.6187624135805715, 0.9707668219362536, 1.3436409975251844, 1.071850407508112, 1.9452503347589125, 3.22872156097043, 7.943254593879947, 2.6823422601146083, 50.333117054354766, 123.89411018740748, 102.23634319920694, 104.58090859074747, 93.1419200281943, 94.012129229884, 96.92666992064446, 99.48678524263444, 98.7033937823388, 99.41972840216853, 93.72500388853013, 84.78633019231981, 73.50021992960285, 70.82150782308271, 72.76970201923002, 71.06260807283464, 89.2904898428148, 97.4092391229445, 98.06422002853887, 98.22181301732218, 91.29532306425034, 88.56507885840632, 88.41626413406865, 85.22736933923538, 85.02156257629396, 78.062360055985, 71.60586418644075, 68.02384591871693, 67.04653247710198, 69.48669387448219, 67.88025579144879, 70.0592657827562, 66.59217296108123, 74.89288099350469, 79.63940389694707, 78.05623331377583, 82.86028954290575, 85.43837716502529, 74.93226159003474, 72.17855376581993, 80.30448098336497, 90.49215501354587, 86.7441341953893, 92.4804279881139, 90.62648834720736, 86.96819566911267, 89.38298717621835, 85.47784405369913, 35.92203878587292, 72.86247391854563, 78.29355239868164, 79.62815453929286, 82.15521212547057, 84.93721592810847, 84.51611811114897, 84.93544301679059, 83.40075292894917, 82.26679571213262, 78.90222580202165, 75.74016001916702, 77.81594891701975, 71.21744755775698, 65.76940090425553, 76.41031265258789, 71.26276662272792, 69.31396838157409, 64.59383910702121, 71.872648116081, 83.8194816343246, 89.08572643033921, 88.28279372184508, 84.26733786059965, 76.99249436778408, 77.74329877668812, 79.23590967732092, 81.80123390689974, 80.7344590463946, 80.49422956282093, 74.24537612545875, 72.18508058978666, 71.0498760592553, 78.23448934862691, 72.34727059641193, 72.00144306305917, 80.86668998964372, 94.23416676059847, 95.94297870512932, 86.25990190813619, 87.86221365774833, 67.88176198159495, 13.420289524139898, 1.060705728107883, 1.92212967863006, 4.580821885216621, 2.847019784873532, 0.8893103476974272, 1.6991391345377893, 1.2115986957665414, 0.4593856350308465, 0.6843958013961393, 0.34336002543568617, 14.017386051916308, 50.91598910670127, 65.37899955626457, 58.92968554650584, 48.27409628898867, 29.239504568038452, 40.36704124942903, 75.13365960890248, 93.12043328439036, 91.28430904880648, 117.31066288486605, 23.00139646376333, 1.2880079376120723, 0.3874947184756879, 0.2574012218223464, 0.14448761459319823, 0.23558000403065837, 0.18721920227812183, 0.11626572453326757, 0.18478992214846998, 0.20647094585001471, 0.11559008861020689, 0.11824755568898494, 0.23198564206400227, 0.1910737123821051, 0.13402029481385985, 0.1713745121753985, 0.24578947393644243, 0.08584288684951683, 0.1463185494104701, 0.09501390159130098, 0.24221553587384764, 0.09903169567546538, 0.18357850731380526, 0.12116943035394916], [0.048689564554801876, 0.07670085321390822, 0.01567439737564494, 0.020436496631572806, 0.020687723675021724, 0.021048263804386222, 0.023711440153419975, 0.0552289255504166, 0.034666516622828866, 0.021620253776951183, 0.036122187100831545, 0.07834398157654271, 0.02226436518192772, 0.06421366601341194, 0.039102977757612546, 0.08895999902198393, 0.005407208011620829, 0.061759480365341714, 0.05878466902480972, 0.8412081159410939, 73.68966256418537, 100.4147081990396, 91.98781751817273, 81.60663727791079, 41.53394245332287, 40.38584509203511, 51.71040242718112, 66.49326647481611, 54.52122388347503, 21.63896510677953, 0.14843632286835104, 0.0445488210196697, 0.06219433485380104, 0.29511729315403973, 0.5145710238045262, 0.8580663403676403, 0.7302978286339391, 2.23643692270402, 1.0514106913920374, 18.55265402024792, 111.41880004636704, 96.53681770447763, 102.03365864292269, 86.65333132590018, 84.23355840867566, 75.83905081595145, 80.56495774176814, 81.52484017033731, 87.55848100108486, 85.40191481190344, 82.35579429134246, 73.40110948008876, 67.4250098197691, 63.51318297847625, 66.4341014431369, 62.16919068367251, 71.78839560477965, 85.2595563088694, 88.0681380917949, 88.52302320541875, 85.1465920479067, 81.11445042394823, 80.40067318947085, 76.56133959370275, 78.3394362849574, 73.97223011139901, 68.12454100578063, 66.76654584946172, 61.08408658735214, 58.788448841341086, 59.17088385551207, 60.559214622743674, 58.232339120680294, 63.494116337068625, 65.08995225352626, 69.52169710589995, 73.31445647824195, 70.18114951349074, 65.13812680398264, 60.57260951688213, 63.99467745134908, 76.66539222963395, 75.45607059232651, 80.74326868980162, 74.11214105544552, 75.99126231285834, 70.89487183478572, 70.12558521762972, 28.950023843396096, 62.10879795012936, 69.83762048905896, 70.8745147335914, 70.10803653347877, 75.78882094352477, 78.06825930072416, 79.01360542543473, 79.14384380463632, 76.7637574288153, 70.88101017859675, 73.19395342180806, 72.70196268635412, 71.69494121305405, 66.10160996837001, 60.10972669047695, 63.38581969661098, 59.541547836795935, 60.25010047420379, 59.19121350011518, 74.49072037973713, 77.56943579643004, 77.52394414717152, 72.30413236925679, 67.06983920066588, 65.37782284521288, 70.89993953704834, 70.96672965634254, 68.84050692281416, 69.22653875043316, 64.66144507931125, 63.89204863579043, 62.94127787313154, 63.525495298447154, 64.20588924038795, 61.170684676016535, 75.88606434483683, 82.98622900439848, 84.71294264639579, 79.7830960058397, 81.26728165534236, 85.29062932537448, 53.856366449786776, 3.9301448002938306, 0.3154545373493626, 1.607271831843161, 1.9718071097327818, 0.4666728472277042, 0.1929745603833468, 0.8444036831778865, 0.5304235892911111, 0.16754257102166453, 0.03057737485505641, 0.08971398275706077, 19.63622054746074, 36.04795863551479, 55.385686812862275, 47.30976197027391, 36.63353712328019, 33.945587835004254, 42.27727082467849, 60.837832343193796, 70.0135858597294, 88.79188599125033, 53.51302569912326, 0.7635374030759259, 0.10013545217413096, 0.014212894095708768, 0.0267405575516844, 0.05240781059969337, 0.04818687298064751, 0.1491328653308653, 0.025298391288566976, 0.015864275140507568, 0.08425716145504868, 0.12722248256567026, 0.061048845715460286, 0.03625544426482051, 0.050694688613856995, 0.048890857987346194, 0.035060059819971366, 0.009020092547871172, 0.027472437734925942, 0.04323997129235537, 0.042848626767555555, 0.09864361851566261, 0.04380614091191561, 0.05423512182108337, 0.07303446366061127, 0.08626045839440438, 0.016468178420778246, 0.03516085783860857, 0.045336466658139424, 0.07981186732649803, 0.06976391173779004, 0.03713979701241178, 0.06345153110282076, 0.12625798552988038, 0.04548222254661303, 0.04009392397898821, 0.013164717275949736, 0.03565601110758801, 0.06211440890066086, 0.07747473991325787, 0.01497397946584369, 0.1183338861371721, 0.018786000418326548, 2.397504396015598, 96.04126545690723, 109.69399267627348, 105.41143125103366, 95.39886751482564, 53.06674626565749, 36.58623726137223, 47.97011260063418, 76.92108369642689, 60.14824436556909, 25.34057644105727, 0.05608563018482059, 0.060712287968565384, 0.584032093324969, 0.42860557054800374, 1.069382256077182, 2.722926533991291, 2.158942655209572, 1.970777364988481, 0.3675906816797872, 27.12873793417408, 117.4898289095971, 99.5479977515436, 108.73314534464191, 91.37647690311556, 88.15861148218956, 78.91591487392303, 84.08165285664221, 85.71007974686162, 88.9153386700538, 87.913604551746, 85.76919771009877, 77.48329270270564, 73.76097909865841, 67.90548447639712, 68.53401291754939, 65.49730608540197, 76.2859421391641, 90.49325327719413, 90.15836915662213, 91.28985528023013, 88.29370575566446, 85.19812414723059, 84.651534018978, 82.07812186210387, 82.73980217595255, 77.05700166763799, 73.3629212840911, 71.52821694650959, 63.85084805950042, 62.17496833493633, 62.634799557347456, 63.916685042842744, 64.05141061352145, 65.81835208400604, 68.79629396623181, 73.88417290103051, 76.8260838908534, 72.91926983864077, 67.69792833635884, 61.722036561658314, 66.20354452440816, 79.5226663158786, 79.05101699213829, 83.03277969360352, 76.26984473197692, 77.20733827160251, 74.84263543159732, 74.65488726092924, 33.023634726001376, 67.1946882432507, 73.97093572924214, 74.85600286914458, 75.96957945054578, 77.28230261033582, 80.25334112105831, 81.17798497599941, 81.90810280461466, 78.2887435728504, 74.25668039629537, 76.19864586860903, 74.19073750895839, 77.15698288333031, 68.2457265546245, 62.425015511051306, 66.89669009177916, 60.70800973523048, 63.582028419740745, 61.95484099849578, 78.49089468679121, 80.20441347552885, 81.63494894581457, 76.83133202214395, 70.18914330390193, 69.66261217671057, 75.40242041310957, 75.00374286405503, 74.80606325211065, 73.56129907792615, 69.54713759883758, 68.09054974586734, 67.23213903365597, 65.9792947769165, 67.88202085802632, 64.91180604504001, 79.7618995174285, 85.62743540733092, 87.4817672852547, 83.06815947255781, 84.78910723040181, 89.57359867711222, 67.1431718334075, 6.346427298361256, 0.34964801383114635, 0.8920322274488788, 1.1266628340367348, 0.4106934542857832, 0.7879073953916951, 0.847227850988988, 1.012083537155582, 0.28821343135449196, 0.07822171394382754, 0.05239704706435723, 21.088164314146965, 42.56725949625815, 49.13547623542048, 31.367088364016627, 31.947795268028017, 45.692188278321304, 51.13714018175679, 70.3578915134553, 81.56771952106108, 96.11004814024895, 73.80456447601318, 0.7812296827473949, 0.10927211553339036, 0.10722263881395902, 0.05242115968177396, 0.10128733431619984, 0.0495918246076232, 0.10448376723234692, 0.07100029337790704, 0.024564833372771263, 0.010423551261004423, 0.078273662365973, 0.03394685362675979, 0.02663514959896284, 0.06265743500402858, 0.023341999997595148, 0.059195246186948595, 0.013129633321847408, 0.05204936189036216, 0.08710406675574281, 0.05015612114220858, 0.023232688826899377, 0.14726877422823062, 0.06869810723489331, 0.22034579407303567, 0.21701838310447433, 0.11988516821856461, 0.10173598604817545, 0.11211538191644416, 0.1962047701160754, 0.12042539044012947, 0.13228510566536458, 0.1028548421398286, 0.1724635827685556, 0.11299216188490392, 0.18043889513900205, 0.13932373765255177, 0.1538602100504983, 0.09766916999773634, 0.17835633108212104, 0.1179200990666305, 0.3185064784221111, 0.22211858281685462, 2.788677715486096, 114.01720554597917, 128.1633512435421, 120.35960751195108, 107.09809749357163, 60.39201967177853, 57.893889565621656, 69.23055525748961, 89.221205096091, 76.17704929844027, 34.59381049679172, 0.3308001671346926, 0.373250937630092, 0.8291973281771907, 1.6612285688038797, 2.429618311505164, 3.603031875625734, 2.557881041880577, 10.786643489714592, 5.017377272728951, 24.973734809506325, 121.56946259160196, 102.7169119927191, 112.39812958625056, 95.01952725072061, 95.0427947505828, 83.44816653959214, 88.13492036634877, 90.61225014348184, 96.42027624191778, 92.37027998893493, 90.77320068113266, 83.34812256597704, 78.6613844287011, 70.93295020441856, 73.30040654828473, 70.16368712148359, 79.35241191617905, 95.04430094072896, 96.40507313512988, 93.05918155177947, 92.96782955046623, 89.12774285962506, 89.37512674639302, 85.83964347839357, 86.58606267744496, 80.65274823096492, 75.18599187174152, 73.84268206934776, 67.5622849310598, 65.90789979504001, 68.28023556740054, 69.0207790559338, 66.83294373173868, 69.75233247203212, 71.75964463141658, 77.89970720967939, 80.90658049429618, 77.28475801406368, 70.81914655623898, 65.36370623496272, 72.27982936366912, 84.51603966374552, 82.57405065721082, 86.99751146378057, 79.11044090024888, 77.35943994214459, 80.38197132848924, 81.24095470674577, 37.82094840080508, 70.01447231538835, 76.93728308523856, 82.20057041414323, 83.00289907763081, 83.43153569006151, 85.85062611487605, 85.68034033621512, 88.23083016180223, 84.11777788592924, 78.97417776046261, 79.25933407198998, 76.08414403853878, 79.024674354061, 72.92005431267523, 63.91519454217727, 70.54036017387145, 65.39130010912496, 68.50440686748874, 66.49198778213994, 82.93862711998725, 86.01986854307114, 85.80645238199543, 80.53442601234683, 74.62445751313241, 72.76862728980281, 77.79479165231028, 78.76920253999772, 78.23047284157046, 80.48715360703008, 71.58755456247638, 72.30495606699299, 71.14167521076818, 69.50767071016374, 73.49143382041686, 68.26638175595191, 83.79290365403699, 88.79365890256821, 89.70453523820447, 87.66877020559004, 89.60227904781219, 95.61935178695187, 68.56098313485423, 6.891227354926448, 0.9812594685823688, 4.989000395421059, 5.0665922318735435, 1.4009547930571342, 1.6115195135916434, 3.2819307186911186, 1.748252357206037, 0.3727892624034036, 0.10271591975563958, 0.2318773325532675, 32.99688808379635, 53.53334749898603, 72.21027005103328, 64.85273515024494, 51.10539643995224, 48.89390137887771, 60.78987352309689, 81.98412618329449, 91.38193684239542, 110.07657281814083, 78.96933755566998, 1.1042388889097399, 0.17778096840746943, 0.18334083619617647, 0.10135946149427084, 0.14646900907879876, 0.20022663978799699, 0.32411991107848387, 0.11769200404805523, 0.12948134643656592, 0.10026345780539898, 0.1730819076540009, 0.18070765410459813, 0.15941264678633985, 0.17640531964359746, 0.18059955909848216, 0.1452685033361758, 0.10769388247882167, 0.13679685792134655, 0.1951282327213595, 0.18437137767191858, 0.14248509140264604, 0.23019063677037918, 0.15229532224757059], [0.03184465856681908, 0.0641719218824179, 0.05921092800675862, 0.03550498453419536, 0.05943289815237927, 0.11191319599146805, 0.04067330478480266, 0.081579324098364, 0.06890826813516117, 0.09240898048324932, 0.043142387012560526, 0.10964902313125711, 0.023339782173054355, 0.0667671519782274, 0.0373259142431761, 0.04641987586153611, 0.02868812734020814, 0.2192812382934555, 0.41152950135930894, 11.137866243239372, 91.45502628818636, 82.68429279327393, 89.10798980343728, 55.19872703859883, 47.459529830563454, 59.792516769901404, 63.89192311994491, 46.461274854598514, 48.87392866996027, 1.8318923658901647, 0.019156124307623795, 0.11860344183420944, 0.3591606195174879, 0.24828796244917378, 0.24515746672066951, 0.5764859434097045, 2.7534715014119304, 1.9599326243323667, 6.294871174520062, 95.88134258024155, 100.1069825695407, 97.85686785174956, 89.50367850642051, 84.0570988193635, 77.73062952103155, 75.0779619524556, 72.50206301289221, 71.46636116889216, 75.69680213928223, 76.33601511678388, 76.82877463679161, 69.43733476823377, 64.45604232049757, 65.29269564536311, 61.872149590523016, 62.04917007876981, 65.1281169153029, 73.56424085555538, 84.24971072904526, 86.31042988069596, 83.40367901709773, 81.53802717885664, 81.79014144405242, 77.94668151486304, 76.98698736006214, 71.51819136834914, 69.80813211010349, 67.09325575059461, 59.5789005679469, 58.97119991240963, 57.96468050249162, 58.21300183573077, 58.94894046168174, 64.24617590442782, 61.932730597834436, 64.57303485562726, 66.0197893265755, 64.31025566593294, 60.80981485305294, 58.694625746819284, 65.47858853493968, 73.14237425404211, 73.6298542637979, 80.68179730446109, 76.94325293264082, 73.10785739652573, 66.10497536197786, 63.23145089610931, 35.80466970320671, 62.79545983960552, 71.80728573952952, 68.2595411423714, 67.26295317372968, 67.48230780324629, 70.5312132066296, 70.87431861508277, 81.78701923739526, 75.38282425172868, 73.01879605939313, 69.45266339086717, 79.58338460614605, 77.2637576441611, 79.01919872530046, 63.997195612999704, 62.41335038215884, 59.62702804996122, 57.56066068526238, 56.113443374633796, 57.98768520355225, 65.08081705339494, 69.41765231470909, 63.134897831947576, 60.541101117287916, 59.9233905730709, 62.971040817999075, 67.15482127281928, 70.14616197155368, 66.50180939705142, 64.6902980342988, 60.477276309843994, 60.85657342787712, 62.51314724645307, 60.06433310047273, 63.364831093818914, 75.5434923787271, 78.6178304303077, 76.54076283977878, 74.9763019623295, 82.26905499735187, 74.37688535259616, 84.22506255488243, 46.031685106215946, 2.336130089336826, 0.8599450943931457, 4.255119542921744, 1.4395547153488284, 0.15984243743361967, 0.9939166506932628, 0.37738045797713343, 0.37254632060085574, 0.14410378922137523, 0.15003312589420428, 3.2704445479377626, 29.351909891251598, 44.00385502846011, 71.12221240997314, 47.87179839226508, 21.666506028944447, 33.01622536874587, 62.900265570609804, 69.51741387767177, 72.46986819851783, 90.14717471215033, 9.100287114420246, 0.7360668384259748, 0.1827619495170732, 0.20924619128627164, 0.06053062170864113, 0.03349326062767256, 0.045485080054570595, 0.0149557082688496, 0.020907790092150533, 0.09091612026696244, 0.08385384680643197, 0.0721747751137422, 0.025493353004417112, 0.10803774104363496, 0.04841065492420908, 0.05775573250326899, 0.06353341058016786, 0.06861816595999465, 0.0631493055862525, 0.005801471810217106, 0.05332691692596963, 0.05176973596756017, 0.01400449711288656, 0.04863223436498835, 0.059429481400236975, 0.07876804188614892, 0.012367382540457673, 0.04955119513455899, 0.04890587714110171, 0.0291851632702615, 0.0732051020848655, 0.07535633826327902, 0.07376935648461504, 0.04608512991258214, 0.027990866670264836, 0.06844073233585204, 0.037106077652424574, 0.034574540106639746, 0.17631558010414725, 0.14736085799672913, 0.17241999236566408, 0.6381302807600268, 19.192341604540427, 115.02527036974507, 92.92234574594806, 99.62235020053004, 67.62125384423041, 68.78561727462277, 51.94810982673399, 52.79391011884136, 51.36471609915457, 50.72507558330413, 2.096212434191858, 0.06688915148016907, 0.5509932952061777, 0.8683838899577818, 0.12726501576722632, 0.29445490289118986, 1.9886310134203204, 1.662765647615156, 0.5933800820381411, 10.455124762750442, 103.04087623473137, 104.34515845391059, 101.47894136367306, 95.35675694865566, 88.77472169937627, 81.23919748490857, 80.07564990751206, 75.02452358122795, 76.3811537527269, 80.20631190269225, 80.41853566323557, 79.77236440104824, 73.91341024829497, 68.65567699555429, 69.23945119304042, 66.88398161242085, 65.76398411104756, 68.23515968938028, 78.50110853871992, 88.72111074386105, 88.6576860181747, 87.261887058135, 83.67725649187642, 84.6147108078003, 81.86197573138823, 78.78511951815698, 75.69826126098633, 75.47479598752915, 68.54990636148761, 63.38083436412197, 61.71389764355075, 61.00747093077629, 60.02927887824274, 61.48467825305078, 66.35559912650817, 66.87218312294253, 68.80429560138334, 69.66727979721563, 66.82080791842553, 62.89451145356702, 61.73068931025844, 70.84172371895083, 75.76672230997394, 79.35487516464727, 84.4901990890503, 79.28870477984029, 74.73309932216522, 70.95209137085946, 69.00904332437824, 37.916195315699426, 66.76810695279029, 75.96143661006805, 74.94275785261586, 74.78669458819975, 72.91955224929318, 74.71868068941178, 74.33056216086112, 85.1587200164795, 77.83281510876071, 75.3331199769051, 74.65251814934516, 82.27029446632632, 79.73823193580874, 83.36131741923671, 67.84963776988369, 63.14620994752454, 63.617219924926765, 61.185268048317205, 60.40008406485281, 61.37530296079574, 69.24064359357281, 72.99081387058382, 66.24657292519846, 61.45341696277742, 61.855750160832564, 66.70829080766248, 69.98739227171868, 73.32273267930555, 71.68611588016634, 69.37460037969774, 63.40355273216002, 64.86764800164008, 65.74704339427333, 63.209438554702274, 67.12630564166655, 78.9861802131899, 83.92071800847208, 82.21470663624426, 80.48805575216971, 84.32337284088135, 79.83747574590868, 91.12353109544324, 59.56712953505978, 3.5062709258448694, 0.9850675384363822, 1.7521383228801912, 2.063949468635744, 0.33207116828810784, 1.4202251525655871, 0.9863318899466146, 0.5147098389364059, 0.5780847995511947, 0.2570261298528602, 2.664477334868524, 32.98375991082961, 43.64479341814595, 45.45636361645114, 33.220565165242846, 28.063158296769668, 44.14575069181381, 69.47291851043701, 75.70433309001308, 77.21115866015035, 102.84409092318629, 18.720088235793575, 0.7725708054438715, 0.1657518711421759, 0.12187205555458223, 0.05873830921407189, 0.07970712778549041, 0.03928935545827112, 0.01568843306402766, 0.026911280245610306, 0.04772446230955182, 0.04349289139011695, 0.03446099821538214, 0.07593962228706769, 0.07639750537853088, 0.0527629689613898, 0.061709224997508916, 0.04814239008532417, 0.04063204711964054, 0.037917789943035574, 0.04437449005162043, 0.007894030920485216, 0.029248509165500442, 0.03479502021124767, 0.2137665850140395, 0.2003864304072434, 0.2210490015004912, 0.1782793086022139, 0.22263282699690712, 0.2163878927427915, 0.15495714070575853, 0.19496568418558569, 0.1962458783940923, 0.2373998765383036, 0.1845839670709064, 0.1797805191768754, 0.24018777774706965, 0.30108462778791306, 0.15926122184722655, 0.35540173250821333, 0.2613287707490306, 0.46902302111829486, 0.7856036157857987, 24.413432075131325, 132.85836558188163, 105.21771323296332, 114.8290341900241, 75.12067656363212, 69.42140210059382, 84.29066027364424, 96.08070881136003, 64.27653112719136, 75.19786096388295, 3.8310711230001147, 0.1440204388552135, 0.5136883985852042, 2.2772467328656107, 1.6558246458730392, 1.8286418241839257, 3.781338656140912, 8.835328067502669, 10.83939544616207, 9.14690742569585, 106.88182584701046, 108.82852169775195, 104.52005693989416, 98.0812744940481, 92.84435333744173, 85.38552714932351, 81.74042932448849, 80.93177780028313, 81.33450323535551, 86.64075620712774, 85.11486007321267, 85.47276850669616, 78.49780590303483, 72.93089574383151, 73.42153718394619, 69.3674381317631, 69.5703580302577, 73.45661886276739, 81.3535737991333, 92.75898687301144, 94.36562107455347, 92.33718302942093, 88.07102495624174, 91.13252901261853, 85.59496602704449, 84.83788582586473, 79.80692832700669, 80.26556322651525, 73.31326407770958, 66.86157703399658, 64.48828812568419, 66.93735722572573, 64.94963338298183, 64.4802668786818, 70.87265553012972, 69.75312479080694, 72.69260391112297, 73.34024213975476, 70.86782317007743, 65.96029481580182, 63.45561827382734, 74.18174743652344, 79.0196615649808, 82.36777320984872, 87.67585400612124, 81.81033380569951, 78.90719936740014, 73.32161088143626, 69.17041747800766, 43.31664400715982, 66.94697487738826, 79.48113626049411, 78.92856059535858, 75.77216655977311, 75.7650278460595, 77.133848744054, 77.24390260634884, 88.34166849813154, 82.33385255259853, 79.36656382776077, 79.17547379770588, 85.32779770512735, 83.86696584763067, 86.82359357034007, 70.71576856797742, 67.26158034416937, 66.17848842374741, 64.12078557475921, 64.01945898609777, 63.632854492433616, 74.45665851716073, 77.29755278556578, 70.0890051934027, 65.72829838721984, 64.46912734739243, 70.61614036560059, 74.86439674131333, 78.49318535097184, 72.32994940973097, 74.48503294298726, 67.795697335274, 69.56879692692911, 69.80385672661566, 67.25785409250568, 70.58760904496717, 83.48566439843948, 87.39593798114409, 86.35327785245835, 84.64726648023053, 90.36455246710008, 84.05685563241282, 94.1432148410428, 61.33918577624906, 4.428923197330968, 3.2999564611142684, 11.520437559773846, 5.213387916165014, 0.45094760555413466, 2.4936632619750116, 2.316344918743257, 1.2467721825645817, 0.616772975171766, 0.3007647707577675, 5.403735637664796, 47.64348899164508, 65.67689964848181, 98.32235120957898, 66.42908865405668, 31.8434190365576, 51.66431457765641, 82.75298918447187, 89.80041365469657, 90.40635708839663, 118.9729319849322, 18.66400226469963, 1.033615265642443, 0.33486861495241044, 0.2996169258990596, 0.3047616659633575, 0.18459381896161264, 0.22428799060083207, 0.23345623976520954, 0.10860440862034598, 0.23261478411093836, 0.1442831304044493, 0.22860328726951154, 0.11938176418264067, 0.13843251692671932, 0.08356530745063098, 0.24994914750418357, 0.18502992217338857, 0.14233009649380562, 0.12892620848311534, 0.17224786773083672, 0.12185083491907966, 0.22473889463130506, 0.07441686165909614], [0.041521076834009546, 0.0913931632174119, 0.036661417238534465, 0.028642179301729607, 0.021777638880115364, 0.06538393426566355, 0.05459675745617959, 0.0893023866979826, 0.053302195268653096, 0.08216094571135699, 0.11775310722089584, 0.15282450514214654, 0.05452984733687294, 0.14381518857854028, 0.020505452205637292, 0.04889974460726784, 0.014172924415869339, 0.23722885507008723, 0.22260679532924008, 32.953357619623986, 101.65532250558178, 82.83422147074054, 85.32056485452961, 50.648428547766905, 30.224796110583892, 50.08146170646914, 57.163277518364694, 54.78876875292871, 21.754739745970696, 0.08442409967462863, 0.4463406285691646, 0.07292888908376617, 0.12246116950747468, 0.32211695887869407, 0.1526821200405398, 2.6321190066875952, 2.0709256491353436, 2.1062639980546893, 67.88722976561516, 105.40791680735927, 93.25983432031448, 94.64523899939753, 86.52824694110502, 79.33958576571557, 75.86825678425451, 72.43490419080182, 68.29149276979508, 64.69333002644201, 65.69926500320435, 68.33700795327464, 67.86645689318257, 66.23898706128521, 65.911586823002, 64.89319832094255, 62.58991979783582, 62.80640717475646, 62.67085790634156, 65.22966707906416, 67.80029435311594, 73.33086767504292, 76.32069433889082, 77.06175558028683, 73.52618602014357, 75.73815961037913, 74.73108322389665, 69.36233120579874, 67.71600261811288, 65.052046468181, 61.58462024504139, 58.74813472071002, 55.627206756222634, 57.386695723379816, 57.405899647743475, 64.39084076112317, 68.28879417911654, 75.63678203090545, 74.07283106157857, 68.69948202563872, 56.79895993201964, 62.239746278332134, 73.10128350411692, 77.67080553116338, 78.93285951306744, 74.82272548060264, 77.7165089884112, 75.14479914019185, 76.76181193320983, 70.5561359467045, 38.87437543561382, 67.36724899661156, 70.3291013163905, 74.3207170117286, 77.09206765697849, 72.05397928914716, 69.34371563696092, 69.83964443206787, 76.45183486323204, 73.60373127845027, 71.58538941414126, 72.45706558227539, 76.14950641509026, 81.88841250634964, 84.09052525797199, 72.82965936968404, 60.92016681548088, 61.06401189681023, 56.02613141459804, 57.71529228456559, 58.34655069535779, 57.78960550985029, 56.42370285526399, 57.9600638727988, 56.92390703385877, 58.549094046315844, 56.95661960109588, 58.94959941987069, 62.36587401359313, 63.964173178518976, 61.66071422638432, 60.593092133921964, 57.52876397102111, 59.25672100436304, 58.58481507147513, 65.0443821568643, 73.46484015064856, 79.81780898186469, 72.98806036672285, 77.33581158422655, 71.74560254619968, 80.56294164349957, 75.26113663950275, 84.21175003051758, 29.597620887141076, 0.8412424979671356, 0.4989861907257188, 0.4121494503511537, 0.15320587903261185, 0.16250571145886378, 1.400277939054274, 0.7869885188917961, 0.24174400875645302, 0.20258542450685657, 0.1158976192856508, 12.53408097451733, 29.327332319751864, 44.20889692921793, 55.06949278616137, 37.774425168191236, 22.366776581733458, 33.424842203817065, 64.77458976930188, 68.08962406650667, 79.76237804658952, 45.626296381796564, 0.2061925035330557, 0.034983964306452585, 0.06834796674910092, 0.03199474285206488, 0.023138944562824986, 0.0534237542700383, 0.06808362811082794, 0.03120112364300557, 0.052513818016215685, 0.019298455783075864, 0.031641773586612076, 0.08984019574258598, 0.035407767976604165, 0.02336582533204027, 0.04679264275417213, 0.0788665454714529, 0.05439377479976224, 0.08798411025876, 0.11673974909729536, 0.03303213698428965, 0.0570855894306254, 0.025120978731842294, 0.051882178522646434, 0.0435648117244484, 0.016813701311607036, 0.05526292836293579, 0.019984152355802157, 0.09586909320205451, 0.05854600965375862, 0.053902310244138205, 0.047269241373625495, 0.06674346453960865, 0.052204115481506434, 0.03413618842680608, 0.028683963652339675, 0.13328694948746314, 0.0672087480404204, 0.06525667940056132, 0.0342815536104383, 0.15576688031996452, 0.13381692911348037, 48.63852762406873, 117.96209796782463, 94.91366247976981, 98.63219491897091, 62.104165630955855, 41.798380805600075, 58.01014077278876, 67.33611322218373, 63.5138419366652, 24.113764955151467, 0.0770919947254081, 0.26886762750725596, 0.4219014738355914, 0.22765004406532935, 0.5550454713163838, 0.5134504823194397, 2.731461366338115, 1.1526502524652789, 3.8575029949988093, 76.64902810127505, 107.99177815837245, 98.72354692028415, 96.16200385555145, 91.47194739310973, 83.51274444210915, 79.73583929000363, 75.90558990355461, 72.83573119871079, 67.05126285552979, 69.3375575157904, 71.5464638125512, 71.99795999834615, 70.11089986370456, 70.09728923920663, 67.14544680810744, 66.48972849692068, 64.91142949750348, 68.37860861132222, 67.14249718573787, 71.03324520972468, 76.79122186476185, 80.72237814626386, 80.76961132787889, 77.8756630805231, 78.64265903349846, 78.5364334044918, 71.34891756119268, 72.4811097114317, 69.27121454669584, 65.41737602603051, 60.31135220681468, 61.099191634885734, 60.42406543608635, 59.82165213554137, 66.13937454838907, 75.42027504213395, 78.14798539684665, 77.51678974397721, 70.62532655654415, 59.13271919373543, 64.26621529363817, 77.5689180435673, 81.14823772061257, 82.1049665635632, 80.93705731053507, 79.5018385302636, 79.20278133884554, 80.34922738229075, 71.7933770148985, 42.360021068203835, 69.16782086895358, 74.5554159533593, 76.65353098223287, 79.34965841231808, 75.89874928997409, 70.93414260495094, 72.92883257712089, 81.1928193799911, 76.27232366992583, 75.09639709226548, 76.89459200828307, 79.53968155768611, 84.72732205544749, 86.62848703322872, 76.93605930574479, 63.78251644872851, 62.74270396078787, 59.21255903859293, 60.58874614777104, 60.4371936090531, 59.08663918895107, 57.91564695296749, 60.701286792755134, 58.99223166127359, 62.12374610285606, 60.0183472325725, 61.835902967760646, 65.4954586490508, 67.59210278910976, 67.08736435059579, 63.306101445228826, 60.78118547316521, 63.53172402228079, 60.47717825058968, 69.20549131208851, 75.74062285884735, 81.30219074987596, 76.93995029695573, 81.33932775066745, 73.74603486830189, 84.02909309633317, 79.19746260489188, 90.42614936828615, 40.536946558183246, 0.7002040563571839, 0.24952979097443245, 0.6971389079286207, 1.0704302643575976, 1.3744325839704084, 0.7897523189744642, 0.8207893599906276, 0.689632349437283, 0.31313399573968304, 0.19112553056930343, 12.503827733378257, 35.10413831280124, 42.5634979432629, 42.03768853218325, 30.30557732428274, 36.466271569651944, 42.91505605943742, 72.28079426673152, 76.75153532335835, 87.4808886743361, 68.76067884506719, 0.5702985883239777, 0.04050053280567931, 0.09138861265514167, 0.06460612519614159, 0.013426020290822753, 0.03659282938667363, 0.025489043759843035, 0.01843774833926751, 0.032958914300486926, 0.011161173273238444, 0.03516610937132951, 0.08223637472838163, 0.041918496436048905, 0.02391005227822931, 0.025440667222644535, 0.056229535970957055, 0.020483561243200978, 0.06949049495761433, 0.08922597708841486, 0.08157743186119103, 0.06381734191710431, 0.08323518484230004, 0.13474627037442502, 0.23702719008489964, 0.09456827590662627, 0.19836023509983094, 0.13104582055201455, 0.2798571281375424, 0.1586360941010137, 0.2067072073658628, 0.16152456733247927, 0.15350109867511258, 0.29651276827339207, 0.22309274022136966, 0.13318000361323357, 0.23157108124465714, 0.20777312678194818, 0.23986269599728047, 0.19609868226032104, 0.36411380695719875, 0.5273985225827463, 57.393724610728604, 135.52121562342492, 106.55315476079141, 109.94734641044371, 70.4376176095778, 43.087055913863644, 72.33680571279218, 78.05635882962135, 81.01259431531354, 35.309952920483006, 0.24654872835643832, 0.6361214756484955, 1.021642659700686, 0.9372841831176513, 1.4716047697490262, 1.4078125670071573, 7.106941044330598, 10.199360732109318, 4.545217060273694, 80.24622594156574, 113.19279393842145, 103.30423985758136, 101.94388343441872, 98.52772651180145, 87.20997841127458, 87.0269213953326, 80.04835021111273, 77.21694023378434, 69.7903480837422, 74.29119725381175, 76.98402204821187, 78.70582488275345, 75.00862229254939, 74.09871085997551, 72.44554165870913, 70.2349252085532, 68.69001342404273, 71.39612720858666, 71.25436490581882, 75.35779168528896, 79.8335769099574, 84.80141562800254, 85.78350651648738, 79.90698014536213, 82.61665544202252, 81.62115004754837, 73.48300856928672, 77.25389680554791, 72.3893419388802, 68.93049393930744, 65.03050873356482, 63.636953369263686, 64.68454391725602, 63.37691983868999, 69.64739338044198, 77.84631590689384, 84.13582863346224, 81.67495712157219, 74.4438402114376, 62.367807742088075, 67.98020562817975, 80.36665839533653, 85.06904678960001, 86.55389139729162, 83.68486589001071, 84.99896187936106, 82.59472154801892, 83.06827714366298, 75.25317422805294, 48.09891931472286, 74.78893818393831, 80.65978496305405, 81.33010233602216, 84.01411748701527, 79.42568179099791, 73.7772177111718, 76.15062821295955, 85.49552609843593, 81.79878634791221, 79.98281525027367, 79.70211475126206, 80.52524766614361, 87.32694348981305, 89.66930450931673, 78.65768955599877, 67.18243475883239, 66.25073063758113, 62.882732575939556, 63.63236419616207, 63.22144492979973, 61.904544445776175, 61.97002841580299, 63.933347271334746, 63.79262047429239, 65.64312411892799, 64.57736515229749, 65.5418328315981, 70.39698185459261, 71.54160791827788, 70.47406427321896, 67.78691122608801, 64.969190320661, 66.6956215520059, 65.62928599696006, 72.53425782726657, 81.22082510302144, 84.77709693293419, 81.50796613385602, 85.73438275244929, 78.26621347858061, 89.416531285932, 82.71863706650274, 92.945676003733, 40.40459794382895, 0.9793591415209155, 2.918365246826603, 4.292601221992124, 0.9767104997750252, 1.475152798718022, 2.443366954403539, 3.485995213831625, 0.5697960346456498, 0.3599011507486144, 0.36058428667245374, 19.59924828621649, 47.0395734233241, 64.61279984443419, 77.86050704217728, 54.379696922917525, 38.185489562249955, 51.05020084688741, 84.02299773308539, 88.03781032562257, 102.96679835165702, 79.62883703170284, 0.6288942634578675, 0.1272709529486395, 0.2385648970882739, 0.1161038501548671, 0.21470115099462772, 0.18030927306221378, 0.15773347398686796, 0.08337365523461374, 0.14373494852935115, 0.07087608754274345, 0.19712896326616888, 0.23321775659438104, 0.1619354968950633, 0.0774592113110327, 0.08420871405471718, 0.18242874723528663, 0.22530815924607941, 0.1644076626267164, 0.18555409485293975, 0.2580879736811884, 0.24218654710679288, 0.25043365215101554], [0.061537127175758925, 0.132838313077246, 0.04802458491476794, 0.05796142328049868, 0.02216529277633996, 0.013762890218546795, 0.032414539882372466, 0.030542132895319696, 0.06612495579306157, 0.036672441243764856, 0.0364598480143374, 0.05040364032010398, 0.05791541203976639, 0.02233991485780045, 0.06193612491892231, 0.0644928897400537, 0.045653232523510535, 0.0383382381480788, 0.046432803595258344, 71.29842881233462, 88.39807218120944, 84.92390340374362, 59.83597270904049, 35.68256631974251, 42.65688565469558, 58.924370734922356, 76.63674323789536, 53.79444399187642, 3.027768731117249, 0.14559435117388927, 0.18372320600094336, 1.1610395893935235, 0.5108445576362072, 0.13954944247680326, 0.12765827934227644, 0.7345236921983381, 1.7267404857181734, 30.922144497594527, 105.72511888319447, 98.39893156482329, 99.45450413611628, 88.3075438776324, 82.05729407648887, 73.96138083550238, 73.47213575916906, 69.15729322741109, 66.01989130819997, 63.18155834751745, 64.53290900876446, 61.759656013980994, 63.344148435900294, 64.29111449949204, 66.68241885400587, 63.65240358537244, 62.179255485534675, 61.5436863899231, 61.769230519571614, 63.98116096373528, 59.95197680688674, 61.284049018736816, 61.8158047429977, 62.00460803124213, 62.00627896093554, 64.19877406089537, 62.68838305627147, 63.3631758536062, 63.1054251424728, 61.350643019522394, 59.749068675502656, 56.777579092210345, 56.60628134204496, 56.01449374229678, 60.75086947410338, 70.70331896505049, 76.41867514579528, 78.87731875142744, 77.35008901165378, 79.3282187369562, 70.3871210159794, 57.279085497702326, 72.92501218857305, 78.36211542929374, 79.97431939648044, 75.3718259257655, 72.32902373037031, 71.89812783272036, 70.54278419863793, 75.5704390618109, 42.36753240708382, 65.43290076717254, 68.72027058755198, 71.4443645169658, 74.74608236743559, 76.10954530777471, 76.5017274118239, 77.18006995416458, 71.8653917312622, 71.89972031501033, 66.83927443719679, 75.08432403687509, 75.01129734900691, 73.77154596390264, 80.5201485849196, 75.02452358122795, 61.86133561595794, 62.00881281206685, 58.024018118458415, 56.716033181836536, 56.06583756785239, 57.05458079614947, 57.53794231722432, 54.97197481893725, 54.585346791052054, 55.6876818595394, 56.88999814371909, 57.62758416514243, 60.793133012710086, 60.833807991397, 58.82508377875052, 56.63999019130584, 57.05027403370027, 58.81720373707434, 57.803443631818226, 66.49467852807814, 70.19723907593759, 73.0385491155809, 74.32188587803995, 71.35371854228359, 69.73403069280809, 71.56930769643476, 78.87847192825811, 81.01887795232958, 78.02319126744425, 22.552777336489772, 1.3054520660831084, 0.17142536509181225, 0.4337697998890954, 1.0566178829439226, 0.5446070024082738, 0.6517601493866213, 1.3198141921912472, 0.2250257792371896, 0.037841001119945324, 0.49957773317733123, 22.78080040408719, 26.291623730813306, 56.010794947224284, 49.621226479930264, 17.368494387595884, 43.92722368240357, 63.13016353114959, 70.81294136662638, 65.28053237545875, 68.68853861285795, 6.429831106816569, 0.5429179317528202, 0.07322324304691247, 0.06371839783124386, 0.06277521719194709, 0.09471462168280156, 0.02046682605249507, 0.08764477927357921, 0.009956158145571188, 0.02473532624031988, 0.02693494853203095, 0.06007083105824648, 0.08883661290089931, 0.03822582240606989, 0.042556770251042424, 0.055725193477325866, 0.023021823125741175, 0.02439518320193935, 0.03750839255630009, 0.1288548090885724, 0.03707584399249285, 0.06156167263285287, 0.06231378328295485, 0.04796799016936172, 0.0631707828612097, 0.041243825783772815, 0.029946384621002985, 0.014768155580837161, 0.06090082603717043, 0.05460413488289041, 0.11371089025370537, 0.06816362301188131, 0.05655731051980008, 0.06454736625234928, 0.03921923160012211, 0.04093770087966996, 0.04378777395393099, 0.05137100252473066, 0.008813701757800677, 0.05223004372730371, 0.7405552556437831, 93.29438255679224, 97.37448692321779, 93.46117742599981, 66.82360849072857, 48.82867236291209, 37.06295428737518, 56.290781574864546, 83.86171771634011, 59.19144491995535, 3.9223446769099084, 0.17232942545125562, 0.39722587372506823, 1.969784882760817, 0.16420342358610324, 0.6330382475449193, 0.7116977041286807, 1.1110513104546456, 1.4868977233286829, 38.022095387981786, 107.91852397303428, 101.06841825669812, 101.34672610990464, 92.846157627721, 86.42547299785, 76.37970247576314, 75.20663922832858, 74.85575968219389, 68.7239654602543, 66.32105873477074, 68.04217907690233, 65.18673281515798, 66.08508894520422, 69.31461165028234, 68.4079557849515, 68.51342047414472, 65.89370865975657, 65.58479455209547, 64.82185432987829, 65.91806657852666, 62.61357561234505, 63.84256401369649, 63.37460564028833, 64.44961355578515, 65.99082654522311, 66.74797734906598, 68.29942380228351, 66.037032065853, 66.00627283896169, 65.83146064512192, 62.55483811901462, 60.17272780018469, 60.44676026990337, 60.04816509062245, 63.55743515876032, 74.68486985852643, 80.77700107328354, 82.58778679755427, 79.87369491207986, 82.18692841068392, 73.28846685348019, 60.56533744258266, 75.14686230690249, 80.42800426483154, 80.57372031673309, 78.80371155277376, 77.59054599269744, 74.28533723277431, 73.01688194274902, 81.91969733084403, 46.19274154786141, 69.84406102088191, 74.85550080576252, 75.74621615871307, 77.58420744249898, 79.31697722404235, 78.74528392668694, 80.15608987500592, 76.07635421137657, 74.60069579462852, 69.83143883366739, 78.38373553368353, 77.14024220743488, 74.65563251126197, 81.22328835148966, 78.71818819353658, 65.18141015883415, 63.87739466082666, 59.97639748357958, 60.358950168855735, 59.50320274599137, 60.296623706817634, 61.82029977921517, 60.47996313341203, 57.602100526132894, 59.22050576056204, 60.8095089081795, 61.48053230777864, 63.212164601972034, 64.76590956411054, 63.83832000917005, 62.05288064095282, 59.993561775453635, 62.32368892238986, 62.17540371802546, 68.46510471836214, 73.65481622757451, 75.52507292839789, 75.98779493762602, 74.58877963404503, 76.11014935278124, 75.1748994088942, 84.04863434453165, 85.05761700291788, 84.55420432552215, 31.84686483875398, 1.3964199202675975, 0.805026886443938, 0.5727824292355969, 1.0763114907087818, 1.7111129049331912, 1.0056138327044826, 1.0083623110286652, 0.46411114113946117, 0.026943379329637657, 0.37007440001733843, 23.485046279045847, 35.700389569805516, 49.3793966693263, 36.80924361751926, 29.657697869885354, 64.87579476448798, 71.30402211220034, 80.82071981122418, 73.69622076711347, 88.93447199175435, 14.927937811420811, 0.6278697281114517, 0.027702821441175, 0.03876964524087887, 0.018796802258058902, 0.08710759842107374, 0.03956081488380029, 0.011913708144528492, 0.032825833336720546, 0.07129232609464277, 0.061497589377986814, 0.030367378663692265, 0.036496773452287724, 0.024562117591079687, 0.035863620935068015, 0.00865701187942778, 0.05845212557863805, 0.025801188199810927, 0.038009532802407785, 0.05413924208692005, 0.07019715744160837, 0.027895854530675758, 0.2053209559451188, 0.1764445739888376, 0.14209464703115726, 0.15485860647693758, 0.24774514318954563, 0.1438873540610075, 0.17394881274911667, 0.17057986449330084, 0.19578680786634647, 0.13079178579632314, 0.12614399930762668, 0.13064540171575162, 0.12022815344314422, 0.1230749591524082, 0.23983559180651945, 0.18863068863509164, 0.09930853686866262, 0.1671511154141157, 0.9813466800316688, 106.76054616128246, 116.48864392311343, 109.429821045168, 83.61166661785495, 53.53632457794682, 60.866908873281176, 82.6766598609186, 94.87220302704843, 74.87570885689028, 6.859799854217037, 0.3258103913357181, 1.3069435473411315, 5.197350815419228, 1.0867480597188397, 0.6617019481716618, 1.535994521071834, 5.80876987787985, 5.766819148294388, 36.7082739645435, 113.50965869042182, 107.11921553457938, 107.0700760810606, 96.31670997988795, 89.50574167313115, 79.99326444441273, 79.98341145053988, 77.59581765820904, 74.04723367383404, 71.1617499013101, 71.44992643787016, 69.2978709743869, 70.55447286175144, 73.80905951223066, 72.49022529971215, 71.6488298293083, 69.55112272693266, 70.43665270651542, 67.19636701768445, 69.88901138305664, 65.58124088471936, 67.59508379044073, 67.64001846313477, 68.6842946083315, 69.40588520419213, 70.18113382401006, 71.49579463466522, 71.7954872500512, 69.53377016129033, 70.11453982322448, 67.26114888345042, 63.58735107606458, 62.55198655589935, 63.228818985723684, 68.2418590976346, 78.55473518371582, 83.87916441886657, 87.17415148212065, 83.38275709459859, 86.13691991375339, 76.41717680038946, 64.37210359881001, 81.7090032946679, 85.00774798854705, 85.18678849743259, 81.2323804055491, 82.01059433721727, 79.51619440509428, 77.95514598969491, 85.75889756602626, 49.36120079409692, 73.6999862424789, 79.91113785774478, 80.0031566619873, 82.88234895275485, 82.47365367028021, 81.52462836234801, 84.52998761207827, 78.05553513188516, 78.94586609255883, 74.40493029932823, 83.94832364974484, 80.73522783094838, 76.2202581282585, 86.0163462546564, 82.48069040236935, 68.74463635106241, 67.01241570134317, 64.72401865067022, 63.28644252592518, 61.189865066159165, 63.51034710484167, 65.66374794129403, 62.63650186600224, 60.19353205157865, 61.87704470849807, 65.03934975593322, 66.0517801777009, 66.37251238669118, 69.16605580237605, 66.93221107605966, 65.38140789155038, 62.09566585479244, 66.78007802655621, 65.75821430452409, 73.8169748552384, 77.10829058001119, 82.1858693707374, 80.61408150580623, 79.6354736820344, 78.86370812692951, 80.05285309207055, 87.14604377746583, 87.68342418055381, 87.73192821010467, 30.845052273042743, 3.2118565949701496, 4.241499602794647, 4.441337989222619, 2.655576986651267, 2.409730914138979, 4.289207881496799, 3.3669608398791286, 0.6564813347593431, 0.11370273141731178, 1.2433687909956903, 37.119244221718084, 44.26301779285554, 78.97446017111503, 73.6082184699274, 26.23038180412785, 63.48335727568596, 80.85370694437336, 93.96988530312815, 82.09741207861131, 106.35551437254875, 15.78941777829201, 1.022424130670486, 0.24385729293909766, 0.4040894392997988, 0.15644189571180653, 0.26024665623422594, 0.12587543952489091, 0.15330672684696414, 0.15832981214888636, 0.18148590750511617, 0.13033798595349635, 0.11860423090477144, 0.19787470389518047, 0.10679577462254994, 0.16806813798123793, 0.18186170427549272, 0.11875872019558184, 0.1483882278684647, 0.1272615453889293, 0.31804379195936267, 0.1330399933841921, 0.12463035512595408], [0.08400282026418755, 0.03042311539062329, 0.017508958661628347, 0.0496810776812415, 0.05497091096795856, 0.047186400455933426, 0.03278777791908191, 0.0231990460757046, 0.06738058922271575, 0.05477258612612083, 0.13990461616025818, 0.044307085805602615, 0.09037300989392305, 0.03007165914882095, 0.06669834962174778, 0.09952252820855188, 0.3243550081406871, 0.49937775358557707, 14.4364736541625, 95.04841942940989, 79.57836397232549, 83.42999812095397, 73.12090319971885, 37.06893982425813, 63.4603996430674, 81.69829522409748, 55.20267294299219, 24.79139558730587, 0.10784884674414512, 0.20341698230514604, 0.21827551806646012, 0.13901232291133175, 0.09770054129823562, 0.10018788323166872, 0.3529935810835131, 0.6753390486682616, 8.662856548063218, 91.72459510064895, 95.51830368657266, 101.92322823309131, 93.85956471966159, 95.27003334414576, 86.163497894041, 79.88886663990637, 73.21358880689068, 73.58446459616385, 70.08807951404204, 69.91906458331694, 65.85607744032338, 64.27613889017414, 62.83710756609517, 64.27621733757758, 62.65690211326846, 67.32520118836435, 61.676521378178755, 60.71137120646816, 61.11974485458867, 58.69783424562024, 61.13301031051144, 63.14346428840392, 58.857411953710745, 57.61014138498614, 57.29116247546289, 59.45876229193903, 59.669444561004646, 59.670338861403934, 56.21999456036476, 56.212926449314246, 55.97647813058669, 57.692840637699256, 58.70914243882703, 58.14638822309433, 58.76884875759002, 68.3835978661814, 75.36907242190453, 76.81438738299956, 75.14359105017878, 76.12582314398982, 74.72246969899824, 60.9948605106723, 52.07652822617562, 64.77373077023414, 67.00666550667056, 66.70622764095184, 64.0798556420111, 67.39938105306318, 71.0332138307633, 77.21614007026919, 48.005331562411406, 71.76955253847184, 63.3102277786501, 73.01616022663733, 73.3213363155242, 74.05112466504498, 73.60522962385609, 70.43744502529022, 71.50208611642161, 63.95672459756175, 69.65454778363629, 72.67938552364227, 74.12792467301892, 67.17251900703677, 75.98577883935745, 75.32218440886467, 63.242064829795595, 60.90236317726874, 61.11967032955539, 55.02330295501217, 56.59407884843888, 54.076207453204745, 54.44875417217132, 53.44394491564844, 54.66948555361841, 55.53241483626827, 55.622178277661725, 55.32915761393886, 55.979023748828524, 54.643354723530436, 58.04295924402053, 54.73415759301955, 55.589442176203576, 56.82627924026982, 60.34956785940356, 59.3634133954202, 66.9778831543461, 72.48991935483872, 69.86302960303523, 66.48264469638949, 66.29882674063406, 71.68993626871418, 76.63246785440754, 80.78693251455985, 76.84022011295443, 79.29722416785457, 36.92066638700424, 0.32118579432848965, 2.5806567745824016, 1.2158506676074, 0.23629798163329405, 0.5412295965417739, 1.9865038630462464, 0.6972555984412471, 0.06900346988151151, 0.24408422350402803, 5.761251834131056, 29.48522536985336, 43.10747577298073, 51.133531601198264, 25.040334693847168, 18.496517058341734, 49.38358576067033, 75.36864880592593, 64.08689237410023, 69.36688115519863, 35.587272336406095, 0.2545790458398481, 0.06128355973370134, 0.0721489502898147, 0.020796073405372522, 0.059437870063007846, 0.05855941619243353, 0.036920960166401444, 0.0407309222575878, 0.022208567167962753, 0.03409544787099285, 0.06171756386456471, 0.061574286270526156, 0.041995024789244904, 0.1112883210542702, 0.013194478834198128, 0.08445124216978589, 0.025247320037094817, 0.019929863535048022, 0.026540445809763287, 0.08634458250936963, 0.01663212889745351, 0.04549623429474812, 0.00782009290208319, 0.04565781755973736, 0.03882607527738137, 0.06615256560185263, 0.005709335851978752, 0.07973263851336895, 0.07031773968089013, 0.06869898823600623, 0.05494592501030815, 0.08644212848476826, 0.07928378759853302, 0.12148940995816263, 0.031211532862676732, 0.12915146897637075, 0.05332378745679894, 0.37713025366106345, 0.7793603669251166, 24.969565330013154, 113.89601215239495, 90.29981766977619, 96.67071957742014, 83.72958875471546, 49.75203752517701, 59.0520360392909, 68.79427786796325, 58.32577390055503, 26.996310872416345, 0.05024435148844796, 0.1626378003387682, 0.8873800512763762, 0.9638055954729358, 0.5166392160519477, 0.6892672012890539, 0.5160998901532543, 0.4847342893481255, 12.709263832338396, 95.59461732064524, 95.73623841808688, 107.04007779398273, 97.74420169091995, 99.31738591963246, 92.32349395751955, 86.8191691367857, 75.66117132863691, 77.89679681101154, 73.72235944194179, 74.57409428011987, 69.79996573540473, 68.01349870620236, 65.06678673528856, 67.01754616152856, 66.17422088499993, 70.87871166967577, 63.415531650666274, 67.23906593938028, 64.37967769561276, 63.46315314692836, 63.89074640889322, 65.24958487479918, 62.96728710974417, 62.29921333251461, 59.77926308108915, 61.78473172649261, 62.007086969191036, 62.19537250457272, 60.221973157698116, 60.86690495091101, 59.95834673604658, 62.1820992039096, 63.28166900142547, 62.02584374335505, 61.07973667883105, 70.35708350519981, 79.39099234919395, 78.94949820733841, 79.51701810283046, 80.99743043222736, 78.98345024354997, 65.35604584601619, 53.96306276321412, 67.56287328658566, 68.22646771707844, 70.2709561009561, 66.78816595385152, 71.2796877276513, 74.65672293016988, 77.15547669318416, 50.499951147264056, 72.85875551162228, 71.26180956440588, 75.73217407349618, 76.21318217246764, 77.54887473198676, 76.68188971857872, 75.3117509042063, 72.45221753274241, 67.69448449534755, 70.64340868303853, 76.73174304346885, 75.5007306991085, 69.76985762196203, 79.24130685867803, 79.19870207386633, 65.06500597923034, 62.10302029886554, 62.413468053264005, 56.763050633092085, 58.81938849726031, 56.95444660802042, 58.23900322760306, 56.132686522699174, 58.4825510363425, 58.43715744633829, 59.82929291263704, 58.10302642083938, 59.98025317345897, 58.43920492356824, 59.60012059057913, 59.698795657004084, 59.733504710658906, 60.52356420024749, 64.7813166341474, 63.79690370252056, 70.73802409633514, 74.21700169963222, 72.90294493398359, 70.61432823058098, 70.99231919934674, 75.59572265994164, 79.67833734327748, 82.31506439947313, 82.7448541887345, 85.60208120653706, 49.40779070700369, 1.3502598746169, 1.44330290777068, 0.35898239682278327, 0.5946139738925043, 1.5509928065922953, 3.0000270326291365, 1.2085193900331375, 0.46772116194328955, 0.256976364781299, 4.957478267531242, 33.29778486682523, 45.862164189738614, 43.919480923683416, 27.62892250091799, 29.536510359856393, 59.627961574062226, 83.02731190958332, 72.989543022648, 82.24632093983313, 59.73996093196254, 0.9140582358644855, 0.03173340153279564, 0.023685937086420677, 0.04014941555778346, 0.012406683808583166, 0.051293064569753986, 0.09698171333800401, 0.06035643246685786, 0.02461311606419904, 0.02868056030673606, 0.017927315446638295, 0.05088395829642973, 0.06985437906076832, 0.03756773755735448, 0.022988260813778447, 0.08052362429518854, 0.01590555578830742, 0.04530395771707258, 0.050670541522483674, 0.069961455169945, 0.01677583167029004, 0.17991196454292346, 0.09054007068757089, 0.08450454656755732, 0.13375528967909275, 0.24140135294968085, 0.14743116954641958, 0.17092385329306128, 0.15965526683195946, 0.21721630958059143, 0.23808213912190931, 0.24297592410397148, 0.2107332905213679, 0.15104264591730412, 0.14018544867154092, 0.3869496009522869, 0.2232460190932597, 0.5064039443048739, 1.0298501579992234, 25.313355192061394, 127.93539093386744, 104.91612219041394, 109.67511038626395, 94.05509487275155, 55.64482604303668, 84.19194990588774, 109.06945720795663, 75.24514905868038, 40.09526414255942, 0.3365661432185481, 0.43572571429033435, 1.1381362570870308, 1.4978563352938623, 0.6525921821594238, 0.4941922576437074, 2.2022184104688707, 4.3609696049844064, 12.455523744706186, 102.41277925429806, 98.31402794007333, 111.81889749342396, 102.37767404125583, 103.67008716829362, 94.51548699409732, 92.2614420613935, 79.8900511956984, 85.10135143033921, 75.7217562583185, 77.60355257218885, 72.74749355931436, 72.03716801058862, 70.7138152276316, 71.37478167010893, 69.13827757681571, 75.36216120566093, 67.3650760035361, 71.20311521714734, 69.16850336136358, 66.38454621837985, 68.64567495161488, 69.10675741011097, 65.50852014172462, 64.88194504091817, 64.5370118079647, 66.28660463517713, 66.75386090432444, 65.19679369464998, 63.4462163525243, 63.941274381453, 62.36396381931921, 65.04957145260227, 66.15769986183413, 65.09899723914363, 63.99606204801991, 74.56937174643241, 83.618177752341, 83.14805815296789, 81.04947243967365, 83.7573120670934, 81.70126053594774, 67.46197423627301, 58.699775818855535, 71.47357048526888, 72.78593278700306, 74.43534435764437, 71.99165282710906, 74.47100654725106, 78.34320960506317, 81.93422578996228, 56.628607473065784, 78.98614098948818, 74.57221154243716, 81.17527069584017, 79.23989480541599, 81.15668650596373, 78.48855695416852, 80.31691489681121, 78.61540640554121, 70.92618019350114, 74.25912795528289, 79.55362950601886, 78.67930181564824, 70.39762512330087, 82.35231122662945, 82.37842636723673, 68.43627529759561, 66.09092543202063, 67.11261656976515, 61.487773003116736, 62.269073840110536, 59.52000617980958, 64.0185058501459, 61.343955378378595, 62.18659816249725, 62.9387479443704, 63.8712247725456, 61.49469990884105, 62.877355006433305, 60.780710866374356, 63.795981945530066, 62.49996416030392, 62.68399784641882, 63.87497455843034, 68.51647207813879, 67.46769305198424, 73.00343605779833, 77.39760460392122, 77.37325452989148, 72.77329491030785, 72.93189202585529, 80.34357132450228, 84.66407775878906, 88.46866699957079, 84.94557842131584, 88.11090761615385, 45.18683795006045, 0.6796918376799553, 6.3472725691333896, 6.207381236937739, 1.2716864650287938, 1.3939315441154665, 5.263790372879275, 1.6981215246262091, 0.5429292085670656, 0.596321920954412, 9.35987545597938, 47.98575501288138, 63.06686039893859, 75.80324742101854, 35.446482781440984, 29.127989622854418, 66.6246109624063, 95.33905136969783, 82.55446234057027, 95.38593153799735, 66.59756229769799, 0.8890503680994435, 0.14429465236683048, 0.13658540233248664, 0.13534309883271495, 0.166209087737145, 0.18843444755240796, 0.18945480005875712, 0.14183682780111992, 0.08264666843798854, 0.12370790099544872, 0.21274312219071775, 0.07585847059324866, 0.10316508476652446, 0.1330840281180797, 0.19482679244491363, 0.1882143351700037, 0.22520302133935116, 0.08368140041467645, 0.1073815254494548, 0.20816743223657533, 0.11064528217238766], [0.03982193212235167, 0.055481351521467014, 0.041821065373838916, 0.015296700707216178, 0.0828459125853354, 0.08594327501111454, 0.03741246302642169, 0.047215213022765615, 0.15261988305757124, 0.017438149154787103, 0.06947976206579516, 0.06516872484597468, 0.07491755374376813, 0.05955751001414272, 0.05895811516130644, 0.016226651965670528, 0.010463871426069209, 0.0675769835229843, 68.7936895124374, 88.08698900284307, 81.11264613366897, 75.4087511185677, 54.48842110172395, 30.848103877036806, 45.849255669501524, 73.09354074539678, 48.91571760177613, 6.28604240955845, 0.17686181611591772, 0.5374982580542564, 0.49317636376907753, 0.68896058225824, 0.46483527808900804, 0.3328304839951377, 0.2764024699647581, 0.975946311748797, 51.87107447654971, 107.35343594704906, 95.16479615242251, 100.7766096053585, 94.65687274932863, 92.5112029044859, 87.51777464343657, 86.68631845904936, 78.17397502160843, 79.675230826101, 78.5506010055542, 79.33263532577023, 75.64213214382049, 73.67016053968861, 61.73860857563635, 64.78764733960553, 62.00380394535681, 63.74672089853595, 63.38122267876903, 61.57584982533609, 59.51592691483037, 60.70868830527029, 58.91892648512318, 58.0695293795678, 57.641014360612445, 58.70647130473968, 57.6473254542197, 58.1435876507913, 56.957486444903964, 56.83132733068159, 54.60293077653455, 58.02724230674006, 54.902788131467766, 57.612098647702126, 58.38832001532278, 60.87068611575712, 56.65555415614959, 61.456005727091146, 69.77719245418426, 75.66219898962206, 74.8985605855142, 79.47631174518217, 74.99833783795758, 72.8271568975141, 60.35241942251883, 56.40603257763771, 57.85134361636255, 61.11908981876989, 64.1263004272215, 67.33713303842853, 69.8722863966419, 73.2169855794599, 50.02053160821238, 68.97157684449228, 67.86550767960088, 65.71636261478548, 73.28426991739582, 74.49685496668663, 69.23841568731493, 67.43188965705134, 60.972718731049575, 65.15615401729461, 67.97796987718152, 73.0310260095904, 73.07746687243062, 72.13449770404448, 74.06683767995527, 71.25319603950747, 61.99577877598425, 61.74381748322518, 64.91992142892653, 55.26741166268626, 52.44594489374469, 54.12157358661775, 55.35041686027281, 51.43817032537153, 54.558047094652736, 55.31910850155739, 54.452433355392955, 52.93406032746839, 55.15631444992558, 55.27014947706654, 55.24463445909562, 55.21656205577236, 59.66877775807535, 56.060087373179776, 59.03997867338119, 62.08419292203842, 62.908408411087535, 66.77456317409393, 64.79418985305294, 62.12856277342766, 64.80910662681826, 67.63813572545206, 74.93732144755703, 77.54816870535575, 79.00089694607642, 80.2309443873744, 87.82964229583742, 74.38695799919867, 4.7680542642070405, 2.060907425418977, 1.0175714233229238, 0.33674559165393153, 0.27356239816834854, 0.39986231935120403, 0.17851538625696015, 0.026992083369423787, 0.07948023552495627, 18.292000755187004, 27.83077355354063, 53.017128282977694, 55.81761037149737, 29.265266695330222, 43.38035506586875, 50.73756440993279, 66.95893810641381, 60.97060065115652, 75.03217220306396, 7.592458398111406, 0.34443049541404175, 0.09191200392501009, 0.06106874867973309, 0.03049311475948461, 0.07309646315632329, 0.07116252781763192, 0.009499043057252084, 0.08711197278312138, 0.046451745119186184, 0.05725632361587017, 0.06760358975659456, 0.04246972734108568, 0.06578017792273914, 0.027565065425850695, 0.020095727316314177, 0.11736818634334112, 0.0028067024428427463, 0.014182611597671866, 0.05614190317329861, 0.06595890623547378, 0.05850857093689903, 0.027542783758572997, 0.04988900543521008, 0.01399163066619827, 0.011416501759911978, 0.07846783501126113, 0.06428703425392028, 0.07265824554187637, 0.034978233968778964, 0.06792178437594446, 0.07132830924444622, 0.04205634246670431, 0.09124454982098072, 0.03540176184727781, 0.09620107740404145, 0.028423989800015287, 0.04973634326409909, 0.30560371916620965, 88.77924811455512, 97.25891820846066, 92.86812290068596, 82.03440312416323, 69.87907209704, 39.88715102595668, 29.470485102745798, 63.1291280254241, 50.156547638677786, 7.12949957578413, 0.2972311748852653, 1.2166047432730276, 2.3349242056569746, 2.716725511896995, 1.5137109232525674, 1.1663141966827455, 0.17220265322154568, 1.789552586213235, 61.70592738736061, 108.99296314485612, 99.20521397744456, 103.44098152652865, 99.33343625837757, 98.66081253174814, 91.6148393384872, 90.5805181687878, 83.55232900188815, 83.05233663128269, 83.90422051952731, 84.48140513512396, 81.14462129531368, 79.27055989542316, 67.20288599691084, 66.3623534479449, 64.85779108539705, 65.61265906979962, 66.39927079600673, 64.36531397604173, 63.86223862248083, 63.65066205301593, 62.30636773570892, 60.956978259548066, 59.593319200700336, 61.70009482291437, 59.735034435026115, 60.751136195275095, 59.16275278214486, 59.73189653888826, 56.86268275783908, 61.24055777826617, 60.449984458185014, 61.52363523360222, 62.36694874302034, 64.09940081257974, 59.20001922115203, 64.64019760008782, 72.25660108750867, 78.31424682371079, 78.78484495224492, 82.9069108347739, 78.94501101586127, 76.96657534568541, 62.262762746503284, 59.66694601120488, 59.95668365109352, 64.44624423980713, 68.15175441003615, 69.1128449286184, 73.19301205296671, 75.16031603659354, 52.31555746447656, 71.27693422379033, 73.36680443056169, 70.36928207643571, 75.69448009614023, 77.87941286640783, 71.91389576081308, 69.40267670539119, 65.63425171759822, 69.9812263058078, 71.74035441490912, 77.51890782387026, 76.2832357037452, 73.81212680570542, 77.74653865445045, 73.67780916152462, 62.404729012520086, 63.884658890385786, 68.63252716679727, 58.709150283567375, 55.240045285994015, 56.61870741075086, 59.58074408192789, 55.58007555623209, 56.31009532559303, 57.29290793018957, 58.05151785573652, 58.5716280629558, 57.2030189729506, 57.14579159213651, 58.71248037584367, 60.762220813382065, 61.97893219609415, 60.292611122131355, 62.142122407113355, 65.73872012476768, 65.96907308024745, 70.00177168077039, 67.07994322622976, 67.20362340250324, 67.29005675162038, 69.22498549184492, 78.77729831203338, 82.45242580290764, 81.9345631137971, 84.21070668005174, 92.12852078099405, 87.50450134277345, 9.836477752654783, 1.0771154540200387, 0.16354860227194526, 0.44405489799476444, 1.6966177859613973, 1.2009075404174867, 0.41677349577507666, 0.20462255954982775, 0.056853388180775996, 16.715851214624223, 33.817773480569166, 46.12440601471932, 27.45908191127162, 30.157398023912986, 55.92547162886589, 54.54042780783869, 75.95665916319817, 68.88848535476193, 91.26018647224673, 18.282447822632328, 0.5747569136081204, 0.1608504559243879, 0.08273524352379384, 0.09157958305290631, 0.05007203533163956, 0.05988849064094886, 0.06716171024186958, 0.08202418369511444, 0.04601187275482282, 0.06713458306847081, 0.05803958340097339, 0.05153828931431617, 0.05241888440063885, 0.04725301946182886, 0.08431749853996501, 0.05157708783724135, 0.03754236089486269, 0.04227567343942581, 0.039745691052127274, 0.09617055646113812, 0.11938089850328623, 0.15917531274739774, 0.15408622130991953, 0.12012238734431806, 0.14241974410270491, 0.16842073760926726, 0.3155148744342789, 0.1474133809848178, 0.19357808445009494, 0.1497032484340091, 0.148872364793093, 0.1943823082312461, 0.10575030975404287, 0.10478299351469164, 0.18722827275914533, 0.13305441115892705, 0.13251873183875315, 0.29525384066566346, 98.67369359539401, 113.27129625505017, 106.82516328750118, 94.77793278232699, 74.48344046069731, 42.52479983914284, 68.19149586462206, 97.78469624057894, 70.86360269977202, 9.989981670533458, 0.4025872328108357, 1.6016090324809475, 3.7689804934686233, 3.87951631699839, 1.1526877601300518, 3.406678515095865, 3.986689933846074, 1.9159727832002027, 61.20723724365235, 114.88978385925294, 100.12383307180097, 107.25160337263539, 104.21218226032873, 101.97556834067069, 95.11947708745157, 94.69933632881411, 85.27954470726752, 86.94560281692013, 88.28699065792946, 86.77249293173514, 84.23956747977965, 83.17786032153715, 70.0108088216474, 70.73694936690792, 67.39192854973578, 69.24888841567501, 69.53785727100988, 69.79870273220924, 68.85894990736439, 68.28003160415157, 66.55136462180846, 64.22411257220854, 64.00025113936394, 67.01647143210134, 64.25759392399942, 66.43619598880892, 63.30865883058118, 63.42670256091703, 59.76323235419489, 66.2952652285176, 62.73920912896434, 64.33134232797931, 67.37131257211009, 68.26948827312839, 63.01825831013342, 67.85366212168049, 76.99280031265752, 81.48727170882687, 83.1995745628111, 86.90917184275966, 81.74919974419379, 80.79565586582308, 63.94801301340904, 63.97445371074062, 64.55937716268724, 67.09775078681209, 71.17451329385081, 74.000455487159, 77.5705026811169, 80.362822317308, 56.660629703152566, 73.69275339188115, 76.70863243841356, 73.32496058556342, 80.38420707948747, 81.06046292089647, 76.40615494020524, 74.63315733017461, 69.32686513470065, 71.51854438166465, 73.66950942624, 80.23672596100839, 80.64891215293639, 77.97233381579, 80.67873001098633, 78.08391740245204, 67.1204456206291, 65.96185591913039, 72.31775083849507, 60.964109128521336, 59.90496720037153, 61.926776439912864, 64.39128791132282, 58.35749410813855, 61.51926963560043, 60.7834251465336, 62.325112742762414, 59.6395129542197, 60.37332565553727, 59.8305872947939, 61.59694825449298, 62.79591091217534, 66.52174288226713, 62.21080310883061, 66.95818501134073, 69.63920347152218, 72.03545785719349, 75.12557168160716, 71.71441185858943, 69.2781336076798, 71.79644430837324, 73.8511073204779, 85.74664408160795, 86.08272844745268, 87.27076730420514, 86.63079338689005, 96.27398752397107, 84.10048807820966, 5.468658218460699, 3.821272061717126, 7.066601918589685, 1.8585880172829476, 2.1040522715737744, 4.40453193841442, 0.7438822835683824, 0.30360205399413265, 0.18980559171928515, 29.72872611015074, 45.720499946225075, 72.65072084242298, 78.66273372404038, 38.975741247976984, 60.88563034611364, 66.47824379705614, 89.1798319355134, 78.10738102082284, 108.30122178600682, 20.342372694323142, 0.8754889570897626, 0.3104751803461583, 0.1400322617302018, 0.28290468718736406, 0.1676940266042948, 0.18612735844667883, 0.14788319206526204, 0.14117166429998415, 0.13440978923632255, 0.22580223999196486, 0.15536813155537652, 0.2675678520914047, 0.17526041656251878, 0.11055558093733366, 0.23071523845916797, 0.18468414072788533, 0.09513223153208533, 0.16812102869153026, 0.1804928124071129, 0.24006267558903466], [0.04940740809205079, 0.02108436952825756, 0.0399153986795535, 0.010298696166325, 0.048158244274917154, 0.05834814829511508, 0.032680280461546876, 0.04081808774161243, 0.04798434614654511, 0.09895140966100079, 0.023116657149887854, 0.1436063836538984, 0.04893423005517933, 0.19182558171451095, 0.05030003075878467, 0.3457351737926084, 0.6081375708022426, 14.743813910791951, 83.50566848631829, 74.16533623972248, 76.89794171241023, 58.93610254410775, 29.048340012950284, 57.80941347922049, 163.30872935633508, 72.14233459964876, 25.62747624612624, 0.4124048640651088, 0.06028693680080676, 2.467934229681569, 0.6634346551952824, 0.34752132310982675, 1.107152964799635, 0.8593973721708021, 0.6924288155090425, 17.66496281470022, 102.4757803640058, 88.57442978889712, 101.09148963805168, 94.37618009505734, 95.91107414614771, 96.60572590366488, 95.8273550771898, 89.89546052871212, 90.89178962092247, 83.08031097535165, 88.4617793175482, 82.28148106605776, 82.80861623825567, 76.94347258537047, 71.78111568573983, 60.75734922962805, 63.71886814794233, 59.656626255281516, 62.79467928794123, 59.22771115456859, 59.75213204660724, 56.541695594787605, 57.679253547422356, 57.606521037317094, 56.637805431119865, 57.30446715508738, 58.17526078993275, 56.07159168489518, 57.79246884007608, 57.319376084112356, 57.43115186691285, 56.219900423480624, 59.520920092059725, 57.786922608652425, 61.383053564256244, 59.76622512263637, 55.588265465151885, 54.995414903087, 62.13980820871169, 67.14880435697495, 72.68097016119188, 72.738903568637, 79.1690097316619, 70.9672160302439, 70.58341995362314, 64.13791848767188, 62.79446355758175, 62.54213748439666, 65.31242908970003, 63.55294404491302, 70.92420331893429, 71.74097414939635, 53.24795976761849, 68.00155116665748, 68.5095137934531, 70.51888911954819, 65.85973308932397, 69.49835115863432, 68.84289172387892, 66.67857493123701, 68.89335693851595, 69.09352333314958, 70.97062064755347, 70.71528219407605, 69.92347332739061, 71.59729772998442, 75.2001908517653, 69.55910867260349, 61.2212714841289, 58.60225000689107, 68.82543717661213, 58.70998574841408, 55.32055585615097, 51.18538141250611, 52.318514931586485, 51.656999357285045, 53.65483114796301, 54.0286369477549, 54.668599097959465, 54.58757469730993, 54.334930912140884, 53.717271358736106, 56.106010483157256, 55.16629688201412, 57.68800043290662, 56.05544328689576, 60.488812000520774, 62.198581003373675, 61.43981418301983, 63.45198615904778, 62.221832813755164, 62.18291505690544, 62.30024491586993, 67.42303294520225, 70.61341039596066, 75.78202739838632, 77.55140858311808, 77.9634771039409, 75.73320957922166, 82.75861386329898, 94.38637041276502, 9.903752284665263, 1.6887132294716376, 2.2093257452211073, 1.751304941792642, 1.2536591291427612, 1.3003741901728416, 0.20676375997643318, 0.17191129466218336, 3.0637861403726765, 29.641510248184208, 32.589522484810125, 73.05234801384711, 30.824240176908432, 18.15086603164673, 49.77923916232202, 56.8609804491843, 62.81301636849681, 66.38037281651651, 49.97296110276253, 1.2021448030587167, 0.09341951940328845, 0.09148741501473612, 0.0615763891818783, 0.05252320259328812, 0.04049117887212385, 0.05405938125125343, 0.05051528997418862, 0.015944982503330516, 0.041881632285132524, 0.04232382206546684, 0.01306476865729858, 0.01199582415152221, 0.0390172946537214, 0.009581842797718221, 0.03827057726260635, 0.017828522663142894, 0.042738402037010084, 0.0159512261199134, 0.05502757083083834, 0.03561249731348888, 0.048670017821413857, 0.04272489973734464, 0.02613554535914333, 0.030293324774491693, 0.08010754662175333, 0.03907472443496508, 0.034847478081862775, 0.03731155775547509, 0.05127351017548673, 0.038822214194243, 0.0327482937474645, 0.04191357049069578, 0.09597632252881605, 0.11184494521829391, 0.3820812041240354, 0.5834906836671214, 24.620139022027296, 105.24685644334363, 81.4427371178904, 91.31525654946604, 69.35381181778448, 50.91821701295915, 56.64432833271643, 118.46110190114668, 62.80852917701968, 32.49093763289913, 0.49283193063832104, 0.12455650425005345, 3.71033517583724, 2.40325826791025, 2.677018132901961, 2.586576121468698, 0.4300778689644029, 0.43454514215550116, 21.732680336121593, 105.73284595243393, 93.15474617865779, 102.46098518371583, 95.67233516323952, 98.01288404772359, 98.77760502599902, 99.60279326285087, 92.98254628335276, 95.42546118459394, 88.22190284729005, 91.81648054430562, 85.34413045452487, 87.83387061088317, 80.34072368375718, 75.54897585222798, 63.82055559465962, 66.16290092468262, 63.643052654881636, 65.60344934463501, 62.98129781599968, 63.25334948878135, 60.45264774753202, 60.12673408754411, 59.04122598709599, 60.675685482640425, 60.72504458888885, 61.61648950269146, 58.6883617216541, 61.398668519912235, 58.597280363882746, 61.05231538895638, 58.316740682048184, 61.940363530189764, 62.06036844561177, 64.62004838451263, 61.63238294662968, 58.34304801879391, 59.12395269640031, 64.09103831937237, 70.35827590573219, 77.1967008036952, 74.58319417891964, 81.26171188969766, 74.45176339918568, 73.18538696535173, 67.08765460598853, 64.32454486047068, 65.00208331692603, 68.26380868111887, 70.11822685118645, 74.90531490695092, 76.03971142922678, 56.83492806649978, 71.71798906018658, 73.55238745289465, 75.43621555451425, 70.08320008554767, 72.98518919175672, 73.11116787695116, 71.0105739101287, 72.99734069455054, 73.52702540736045, 75.22897320408975, 73.61600045234927, 72.22366102280156, 75.21616274310698, 78.17235900509742, 73.05750200825354, 63.56058482200869, 59.50455204133065, 71.51806585250363, 62.52732269225582, 56.99204252612207, 53.9035996314018, 54.47510073261877, 55.43272387596869, 56.966755005621145, 57.30453383538031, 58.21446880217522, 57.846730909039906, 57.70807120107836, 56.683606947621996, 58.136335188342684, 58.945092616542695, 60.968886575391224, 59.73686618189658, 63.65627496473251, 66.26824009803035, 66.34768378350043, 67.9507250939646, 64.95124939949282, 66.77988975278794, 65.81157422834828, 70.18183985064107, 74.95722355381136, 78.9115139745897, 81.99382228236045, 83.82235280929073, 80.31625593862226, 83.52368785488991, 104.14205028164773, 18.045824958432107, 0.9149564586339459, 0.3620116923364901, 1.8728281821935409, 1.6215014553839162, 2.0416309372071297, 0.7224912088244193, 0.3279564794032805, 2.4927741096865748, 33.129197474448915, 35.15269725553451, 46.652949317809075, 21.82173578969894, 27.893339280159246, 63.63457641293926, 65.24474074763637, 72.45393553087789, 74.8859070193383, 73.70361835725846, 3.1444273744860007, 0.17412789346229646, 0.012858284021457358, 0.029710197798727505, 0.07370072266747875, 0.07415876663740605, 0.03911561820836317, 0.09965907572017563, 0.027733045525007674, 0.015364755170359729, 0.03715985319426945, 0.027816361417212797, 0.04730755343071876, 0.07746035278203987, 0.04608550529566504, 0.08002705376354918, 0.031978141726745714, 0.0307964357817846, 0.12827917062226804, 0.046433707579009, 0.23806125556509342, 0.14278625588743918, 0.13644421232804177, 0.2914284265810444, 0.13190615261274, 0.19849171110939598, 0.10041131277478511, 0.1536648269862898, 0.148088718133588, 0.27189557470621606, 0.21090561433905558, 0.15913035870800096, 0.20496239615303857, 0.39523717076067005, 0.16759717776890726, 0.5992445770290591, 1.0663950034687597, 27.299325735338275, 117.35833537194037, 95.5755389121271, 105.03239693180208, 79.37328677023612, 45.277205436460434, 80.9850985004056, 189.0022622385333, 87.14263916015626, 45.824933052062995, 1.0204603102418686, 0.17258197399637393, 8.168811471231523, 2.8964526807108237, 3.659337744597466, 7.621352537985771, 7.559339865561455, 2.478254475901204, 21.52061935394041, 114.4354949458953, 95.89634956852083, 108.12891206433697, 99.64080102982061, 101.47342651121079, 101.76903986161756, 104.19844611998528, 97.41235348486133, 101.26735302709766, 91.20957220754316, 95.71672070410945, 88.5195872091478, 91.09261497374504, 83.844757387715, 79.84571272327055, 66.76530638048726, 71.00103470586961, 66.98517876286661, 68.26067078498103, 64.35161705940001, 66.72369787769934, 63.627367096562544, 64.44553429080595, 63.36195599648261, 64.09342312043714, 63.66229580294702, 65.38289446984568, 62.390808520778535, 64.48599353913339, 62.3137810153346, 64.5731133030307, 61.039767726775146, 66.25793995395784, 64.3727586346288, 68.90363354836741, 63.96254539489747, 60.67548544176164, 60.356204509735115, 67.4137447726342, 72.56989648265224, 81.97419474201818, 77.60261904808783, 87.07853194205993, 79.56895028391193, 78.40398280851304, 71.59557188710859, 68.10230901164394, 70.120697944395, 71.70799486098751, 72.8625209869877, 77.93545569142988, 80.39860217801987, 62.96391779376615, 75.95687097118747, 77.25734849129954, 77.72888014393469, 73.96774291992188, 77.92824637505316, 76.58310090341877, 73.9885393265755, 74.84999379804059, 77.56386603078535, 76.95714596779116, 75.77127225937383, 75.7756810034475, 75.9765063562701, 82.27851575420749, 76.88125594969719, 66.88159681135609, 62.31294162811772, 74.20413632546702, 64.26385794916462, 61.392961471311516, 57.66351307592085, 59.436628357056655, 58.112765665977236, 59.67430830001832, 61.0971127786944, 61.22375434444797, 61.06735767856721, 62.18036551629344, 60.10040321657735, 62.97452780508227, 62.6782907978181, 63.77277720359064, 62.21055992187993, 66.85496391788607, 71.16798646988408, 68.64196438943186, 70.0599012067241, 69.28892012565368, 69.21401854484313, 68.76184771137854, 75.40153395745062, 78.17012325409921, 83.04151873434745, 87.73675272541662, 88.10356493919127, 84.68700009007608, 90.04014107488817, 107.86393242497599, 10.825951522396458, 4.2369717167269805, 9.273179308060678, 3.9347440244690066, 3.9447749958884333, 3.928683227108371, 0.506205711393587, 0.6092312992099793, 6.382133124336121, 48.84011783907491, 47.88047859745641, 100.71643260217483, 43.67871015302597, 27.868428307194865, 68.47946059319281, 74.7459254726287, 83.53531376008065, 86.37172083700858, 80.64739811804988, 2.5824090934568837, 0.23337498847996038, 0.1605108338257959, 0.17433018663958197, 0.16775463948086386, 0.20508674754490777, 0.14871301850484264, 0.1654968711156999, 0.13078907384507119, 0.1838111069293753, 0.06925322220570619, 0.16372952159614335, 0.13174119856088393, 0.13508296601714628, 0.19414442260899853, 0.12632405295247032, 0.11661688391599925, 0.10168972965930739, 0.20558804483903995, 0.1517958329209397], [0.04469730035071412, 0.10198357034354441, 0.029922520982161648, 0.06560370956938114, 0.029339349956341812, 0.06349321011634124, 0.06287921362766816, 0.0768704804021024, 0.06363817693425283, 0.019968650566654342, 0.03058845057122169, 0.03298057543654596, 0.06868191213617403, 0.11047198542303617, 0.050757216710236766, 0.15200460720206463, 0.15660862708764692, 45.895088564965036, 86.29736838802215, 83.16439874710576, 65.54441767354166, 57.00274275195215, 21.867056815854966, 66.03143876598728, 82.5385767413724, 43.55631259179885, 14.866960644721987, 0.06025981728828723, 0.2585118654514513, 1.5497772395610812, 0.6954964767059972, 3.1830534050541544, 1.9808210841109677, 1.0384092600114885, 1.8913704517387577, 71.20138152953118, 97.90956097264444, 85.24479250754081, 92.9473626229071, 93.11686392753356, 97.38910951922017, 92.57869120567076, 87.48437173904912, 86.89170945075251, 88.4780885327247, 89.45682971708237, 88.86597171906503, 83.39772485917615, 82.85313513971145, 75.88407962552964, 74.74228551310878, 66.70378008196431, 63.66548861226728, 60.65685026107296, 61.82024486603276, 60.93257719470609, 57.77991725552467, 57.95379592526344, 57.8286527049157, 55.35194658464002, 57.96468834723196, 55.36592591193415, 57.46523726371027, 56.94800999856765, 55.20412814232611, 55.21333394512054, 56.82109386690202, 58.92764591401624, 56.54291937428137, 57.50617111882856, 60.343978481908, 56.79925410978256, 54.99953339176794, 65.90237709783739, 70.41811558508104, 69.85902094071912, 71.38446992443454, 72.77957070258357, 74.74633339912661, 77.28493059835127, 73.57068138737833, 70.406050374431, 66.62685455814486, 65.90130236841017, 65.86316908559492, 66.6877297432192, 70.87682108725272, 69.67468523210096, 49.214421779878684, 70.08089373188635, 71.50986025410315, 70.59437905588459, 72.3297768254434, 67.4119326376146, 72.39703762915828, 71.54079991002237, 72.43935215857722, 71.37389521444999, 72.52595024724161, 69.12845596190422, 68.34945755620157, 71.3085485273792, 73.6625119178526, 67.14933779931837, 59.93090975669123, 54.94361216022123, 64.03038670939785, 66.49187011103477, 57.82845658640708, 53.6091394578257, 49.89637290277789, 51.0681535351661, 53.97206068038941, 53.76142940213604, 54.69222745587749, 53.92946766268823, 53.6683201789856, 55.83333907588836, 56.04601390900151, 56.48895148308047, 56.014501587037124, 55.794821400796216, 57.38970025893181, 61.09968585352744, 63.18500218852874, 62.40548602996334, 64.70945881259057, 60.84119773680165, 62.91000089337749, 63.95906233018445, 66.48766533021005, 68.15402938473609, 68.77956897981706, 71.38301080273044, 79.0835883540492, 77.42863055198424, 78.01315784454346, 99.59559179121449, 12.616294833921618, 1.68220515933729, 1.2781951480334806, 1.0788052601198996, 0.4647753087262954, 0.4550350217088577, 0.027789870096791177, 0.10632192625874475, 11.820547907583176, 30.81620324042536, 36.62889303699617, 58.57684481528498, 25.016678879337928, 34.17381878822081, 60.404571256329945, 65.06073451811268, 62.496940012901064, 79.83340432566982, 21.998401303445142, 0.7156323929948192, 0.014711388465647977, 0.060259376787730766, 0.052585795807141456, 0.05328513832101899, 0.050588512657991344, 0.04851690365842754, 0.06727360504408998, 0.018463444843467687, 0.11733398051752199, 0.07151192519813776, 0.0554646508047177, 0.07142833734471953, 0.008102202386174711, 0.14027892672006162, 0.04185939275269066, 0.08533613500936378, 0.05252871076546369, 0.043861617168952385, 0.06423885498436228, 0.04257907490095785, 0.05571291308789965, 0.02246216908397694, 0.037523902006327145, 0.031944334266647216, 0.015134626188345495, 0.09380982587895087, 0.08116732967356521, 0.007842251995293004, 0.02881735488171539, 0.035162328727423184, 0.07905765376504391, 0.08996483058698716, 0.03716691269449169, 0.126582576983398, 0.11619914383176835, 63.93986625056114, 97.76353113112911, 94.0542241065733, 74.12997215024888, 69.79911065870716, 35.8047991414224, 68.44979962994977, 81.31890789155038, 46.110136432032434, 17.228000971578783, 0.3911158322326599, 1.1088649568057831, 1.821632426111929, 2.52083842312136, 3.759183148222585, 1.5714748107617902, 0.4520646230347695, 3.1906851116688024, 79.32958372177617, 100.64512391244212, 92.43802716655117, 94.01708710578181, 96.48800773005333, 97.57507693383002, 95.11004770955732, 92.20406563051286, 89.26963067823841, 91.45633635982391, 93.25581781325802, 92.15369455275997, 87.01845692050073, 87.1292168094266, 79.70245991983722, 78.72518570192399, 70.64328316719302, 66.41091239067816, 62.97903460841026, 63.680903527044485, 62.76016243042485, 60.32077373996858, 61.5767833494371, 61.01792796965569, 59.71774854967671, 60.93045911481304, 59.37485887158302, 60.629923189840014, 60.06885951565158, 60.430639328495154, 56.95307770083028, 59.2647030276637, 60.00825497411913, 60.10070131671045, 59.92170003152663, 61.85020785177908, 58.02582633110785, 57.7472125330279, 68.29349317858296, 74.03169324321132, 72.78042577928113, 73.32627065720098, 76.2996155215848, 76.44036585284819, 79.70476627349854, 78.1765559411818, 74.4275466857418, 70.15060209458875, 69.32462153896209, 70.20746077260664, 69.35160744574763, 74.8648831152147, 71.98113303030692, 52.86815274146296, 74.68352056318714, 73.8702484869188, 74.86685998978155, 75.94417033656951, 73.6703880371586, 75.4960552338631, 75.07508293274911, 75.35703074547553, 74.3266397906888, 75.33899568742322, 72.84760813559257, 71.22733977533156, 73.55620784144249, 75.9355018984887, 71.40800414546844, 62.72222134374804, 57.56660699844361, 64.25456193185622, 69.46395981696345, 60.675685482640425, 57.28351385362687, 54.89991695650163, 55.30255609943021, 55.58822624145016, 56.80916201683783, 56.67314598637243, 57.58967837979717, 55.88489863180346, 59.03365581266342, 58.18802810484364, 60.010035730177364, 58.91034826155632, 59.00682287831461, 60.74392687889838, 64.17693038140574, 67.90597085029849, 65.45228119819396, 66.50515125643823, 65.24947112606418, 64.91872902839415, 67.83156348812965, 70.8393467626264, 70.58493398850965, 69.84762253299837, 72.17536095649966, 80.03110747183524, 83.29992448129963, 76.67595909487817, 104.75732895635791, 21.676513956439113, 0.726248839449498, 0.4764568625438598, 0.9116133122194199, 1.842966074905088, 1.2667356984269236, 0.37721210249489356, 0.26486726958424817, 16.43361314650505, 40.8670336200345, 34.33790329963931, 42.40331226779569, 33.012475582861136, 51.8308505704326, 68.99948843063848, 74.76521568913614, 69.11928546044135, 89.91469583203717, 35.57139850431873, 0.6581342460647707, 0.07232080679386854, 0.020273513340901946, 0.05151058757497419, 0.04406222878324409, 0.0590157364645312, 0.06503438366757286, 0.0711269966597038, 0.052981407441679514, 0.07449312571195826, 0.0537037747281213, 0.07569587609219937, 0.07190891196049991, 0.03111519156053903, 0.01839877361611974, 0.06226866453465435, 0.01853261109171135, 0.09059820910014453, 0.04908301199095384, 0.19500446355631276, 0.2778419185309641, 0.15032034757877552, 0.08173538386941918, 0.07911635908268153, 0.1874972462293602, 0.1384703157049033, 0.22939589715773062, 0.13602848705505172, 0.11912824270585853, 0.11691190437563967, 0.13198204128251922, 0.15961673260936815, 0.1518266296554958, 0.18601753208185398, 0.2509752456699648, 0.21637229519265316, 75.78460047321936, 112.44862617984896, 108.68708102933823, 85.13201652034637, 78.00833332923152, 30.978846280805527, 85.64600390772667, 102.0779186679471, 64.40492207004179, 24.90796450645693, 0.8353430693668704, 1.1139908817506607, 3.8732201774274153, 3.4773456521572608, 8.652403431553996, 8.07510849929625, 4.084602099272513, 3.028371305234971, 80.62646050607005, 106.01725701362857, 96.03036126782818, 98.22623745087655, 101.40609510483281, 101.19285937278502, 101.00512689159763, 98.19971438377135, 93.67973189200126, 94.73922683346657, 95.60133241838025, 97.4090979176183, 90.78354004890689, 91.37168376676499, 82.43857199145903, 84.17816669710221, 75.64630554568383, 70.56936217892554, 66.12045303467782, 67.80012961356871, 67.14372880997198, 65.52662188006987, 65.93360700914937, 64.78865146636963, 62.682154332437825, 66.40430711930799, 62.52363174192367, 64.29711572585568, 62.60213405855241, 62.39584092170962, 59.08926325459635, 63.255134167209754, 66.39745081624677, 65.20803912993401, 63.187241861897135, 64.60491588038784, 62.50925233287197, 59.869140271217596, 71.48162703360282, 78.12872655930059, 77.41119953893846, 77.9911768820978, 79.73941649160078, 78.893902532516, 84.40276161316903, 82.84397248298892, 78.28455448150635, 74.03410942323747, 72.12359351496544, 74.47775302394744, 72.97990183676444, 78.62611447611164, 76.0523336164413, 57.43744727103942, 75.40045922802341, 77.15383714245212, 78.32213078775715, 78.22408722292992, 78.1700683409168, 78.37283918934484, 77.22883286014681, 79.11648135031425, 76.8942625291886, 79.10581250344553, 77.18888744231194, 75.10676783900108, 78.22735847965365, 80.09459495544434, 76.15287180869811, 65.41967061258131, 61.940736155356134, 67.54333203838718, 72.52585611035748, 63.11827090478713, 60.83387074931976, 58.00541431673112, 59.46734051550589, 59.07023583689044, 58.726122379302986, 62.53870148812572, 61.2258332006393, 59.58468998632124, 62.769674178092714, 60.406336322907485, 62.91368792133947, 62.6006200236659, 62.592065334320075, 64.3378887637969, 69.17428493499756, 72.99440676166166, 71.91672771207749, 71.39364042589742, 67.40244834653794, 69.0500085584579, 71.93825367958316, 74.66044133709323, 74.58761861247402, 73.64610856579196, 77.46037037141862, 84.94253466206213, 84.73044426210465, 81.82683913938462, 113.78528364243047, 15.88815168026955, 3.190169074843007, 7.953417454996417, 2.216183028874859, 2.541239650980119, 1.3541426533652892, 0.2503102200646555, 0.24385125616625433, 22.105193714941702, 50.58293673299974, 51.10845196631647, 78.14687928845807, 35.010958486987704, 50.99529550921533, 77.62229365687217, 85.92079731725877, 78.53367990063083, 103.0708666770689, 34.94999700976957, 0.8270775322471896, 0.2508555214491583, 0.19503544415197066, 0.12720907602699535, 0.24985300346968636, 0.17133518122136596, 0.23657821659599584, 0.20133316186406922, 0.13617220514964673, 0.3333033134620036, 0.16779936369388335, 0.2759060449898243, 0.18953697064951544, 0.12375778864107786, 0.19882731890726477, 0.14095001974173132, 0.19239031108877352, 0.17689598363734063, 0.10847683199831556], [0.018500418161913272, 0.033994358738944415, 0.06802324506063616, 0.017814403662698406, 0.09580280361396652, 0.08142945431773702, 0.030207551655269442, 0.07973096844169401, 0.01772501843891317, 0.06024151161733655, 0.1252837515165729, 0.03599708877323616, 0.16387357676942504, 0.06955712928526825, 0.07757828435710362, 0.17066195847526675, 3.438995413241848, 76.79262607328354, 81.03721895525533, 80.88522711107808, 63.225732080398075, 49.10916105393441, 43.571994227747766, 53.208390897320164, 22.745281380991784, 32.78455645807328, 1.230600127770055, 0.22175167266639972, 1.0572052578772269, 1.2263287892264705, 3.1687892156262554, 2.1341866158669998, 0.49477359580416835, 0.4709618977240978, 31.459140508405625, 104.10946323025613, 87.26594278889318, 89.53334731440391, 84.97955399174845, 94.20640422451882, 89.44823188166465, 103.13498958464592, 93.72353692208567, 91.97036297090592, 90.83928477379584, 89.52955830481746, 85.83077892180413, 87.32557850499308, 75.19740596894296, 77.33776492457237, 72.33574667284566, 68.9384328165362, 60.609577855756214, 60.168456339067035, 58.76666007503387, 60.932412455158854, 57.49747522415654, 58.8868885655557, 57.373575395153416, 57.69254645993633, 57.705305930106874, 56.79921880845101, 53.12193401398198, 56.16405763933736, 56.0897248022018, 56.876399286331676, 58.542422094652736, 58.209840405371885, 56.12593612363262, 59.52991800923502, 58.497001048057314, 58.21313519631663, 70.2403223899103, 74.50462910436815, 74.22308137339931, 72.16500589924475, 68.48099031756001, 70.81327084572085, 72.23298841907133, 68.12235232322448, 72.66301355054303, 77.00973710706158, 70.8593116268035, 68.38472750879103, 67.37566640300136, 64.61001888398202, 69.81286248853131, 66.62588181034212, 50.63510817866172, 68.68920541578724, 69.94708599582796, 72.34378753169891, 68.21780712373796, 68.82000861629363, 66.55434562313941, 71.02572994847452, 70.57698726654053, 70.48874178240376, 67.71410419094947, 69.05113035632719, 68.96341831453385, 72.45624188453921, 71.73277639573621, 68.73016280512657, 58.01620083470499, 56.212090984467544, 55.60839114650604, 63.69499660307362, 61.259036064147956, 52.911922470215835, 52.073625672248106, 50.8079787992662, 51.58998174052085, 54.51116300398304, 53.84762348667268, 52.869706000051195, 54.077933296080566, 54.114470174235684, 56.007778644561775, 56.118169830691436, 52.995872959013916, 53.834299195197325, 55.74547798402848, 57.6797987568763, 61.99247614029915, 61.19525440277592, 62.44551381757183, 60.23729393559118, 60.02652145201161, 60.405022328899754, 60.79300749686457, 60.342746857673895, 58.995240119195756, 61.04543555167414, 66.4788713762837, 76.38321691943754, 83.33895206451416, 76.1498829626268, 89.36608960551601, 6.490162063029505, 1.1330587488989676, 1.2501291185617447, 1.0177604938226363, 2.368117508388335, 0.3039175290013513, 0.05626934956038191, 1.3270705770100317, 23.108279089773855, 28.263238399259507, 62.53248060903242, 41.42825811139999, 19.44738588025493, 46.46290656059019, 56.24274430736419, 62.42432517390098, 64.6215545746588, 66.6794692316363, 3.108448208339753, 0.34136749203166655, 0.15429395371146742, 0.10517269478089387, 0.0236449207389547, 0.04443498418456124, 0.04152563505715901, 0.053382623009383685, 0.012241077624381551, 0.08644040478693862, 0.06374514579112012, 0.05309431347995997, 0.024146147169953874, 0.02914891198968455, 0.08717103816208341, 0.06147925306351916, 0.05642368563360745, 0.046131137322874806, 0.022087023488336036, 0.05181591191719617, 0.034665574334681995, 0.1047450261971643, 0.02154313170561387, 0.07633470149049837, 0.0761805033130992, 0.016184193457687096, 0.04540564439770195, 0.01103458490463034, 0.028579969131838412, 0.09012102059298947, 0.022387837487903815, 0.1263306872738946, 0.08968265742183694, 0.063515430496585, 0.34278018880755673, 8.129103356792081, 99.47151937792378, 88.74746122667867, 94.71967774052774, 72.41969323927357, 71.49598290843349, 44.869953586209206, 32.138951978375836, 27.153482206406135, 36.439383722120716, 1.091910634310015, 0.2492090299605362, 2.560525699969261, 3.3608598382242265, 3.655793392850507, 2.8981221395154155, 0.6009903381909094, 0.2008662925612542, 36.94178835038216, 107.87623297783637, 91.43761096462127, 93.45046935542938, 87.24861375747189, 99.05286911995181, 93.6584726456673, 106.93098099000993, 94.53561659782164, 93.91700390846499, 92.98316601783999, 93.18148889849263, 90.29553444154801, 89.94438032950126, 80.41485648001395, 78.63741874694824, 74.62279442817935, 74.04757099766886, 64.2592256299911, 63.2290582503042, 61.21036337267969, 62.419135878163004, 63.55741554690946, 61.336879422587735, 61.211704823278616, 59.817635628484915, 61.32551631619854, 59.97536982259443, 59.56812581708355, 60.672602499684984, 58.99982929229737, 59.79078308228524, 61.758765635951875, 63.102954049264234, 58.77883903441891, 62.24026010882471, 61.610213710415756, 60.16288657342235, 73.64192731918828, 77.9853403952814, 78.04491335345854, 75.70724348868094, 71.91017735388972, 74.72723930112778, 74.96362486193257, 70.52878133712277, 73.77520945764357, 77.88539840329078, 74.01787081072408, 72.82899256675475, 70.00580387730753, 68.58716887812461, 73.27188307239165, 70.10265504160236, 53.99853667905254, 72.27814274449503, 72.37285229467577, 74.28146193104406, 70.94820037964853, 71.02463168482628, 70.55728127879482, 73.71335368002616, 72.32322646725562, 71.99606941592309, 68.67132725254183, 70.8420531980453, 70.27824386473625, 73.1884228798651, 74.95825905953684, 71.14328338253883, 61.49978722295454, 58.783334070636386, 58.85958886915638, 64.50480130410963, 63.60068713465045, 55.98076135881486, 56.54780664751607, 52.946564843577725, 55.00242025621476, 56.49546261756652, 57.72944811851748, 54.73371436519008, 56.031795317126864, 58.39769055766445, 59.37421560287476, 58.40291515473397, 56.330789750622166, 58.23928563825546, 59.80570377842073, 61.53346469325405, 65.69030630973079, 64.37856766485399, 65.85153533566383, 63.57360709098078, 63.66807345421084, 61.83452229345999, 63.17131703899753, 62.71968749261672, 61.596010808021795, 64.69915082377773, 70.8617905647524, 77.38120909660094, 88.10591836129466, 76.81754881335844, 97.60352980706, 12.127655763779918, 1.0302063582404968, 0.4544089440136187, 2.1923666423366917, 3.3774333230910765, 1.0397634583134805, 0.25467882113110635, 0.9077511872014693, 37.11365484422253, 38.445299517723825, 55.6713883338436, 34.744496191701586, 35.17796908655475, 63.593795530257694, 63.14960279772359, 72.10528389100106, 68.56341500436106, 86.31515241438343, 7.439895849074087, 0.3958499185260265, 0.12494347824324524, 0.05217286292463542, 0.07069522184470008, 0.049605154537505684, 0.10123396097051521, 0.06549681732130629, 0.018777552383741545, 0.07098193791124129, 0.05673061109959118, 0.006716097000941274, 0.012890034535479163, 0.031603480681716915, 0.05060671107663263, 0.058518890141239094, 0.016422448717358134, 0.06784233339731732, 0.030310437263500307, 0.20674817774805332, 0.13398548377858055, 0.17484450742842692, 0.16524933278560638, 0.2373077927698051, 0.18278465636314886, 0.1375253922155788, 0.19463265044314249, 0.08619838995077918, 0.14472546957192883, 0.14490007633163085, 0.11508344402236324, 0.2400194069430713, 0.23184265941381457, 0.1863532318102737, 0.5108282246416616, 9.281022087220224, 113.61488019266437, 103.56375955766248, 104.40205635563021, 83.6953386183708, 67.53610703252977, 60.51820624259211, 75.94912821246733, 37.76978892664756, 52.612888813018806, 1.517891189263713, 0.39174788541370825, 3.906909905133709, 5.122788029332315, 7.79977870564307, 7.234910822683766, 5.021360439638938, 0.9777767103045218, 37.466428895150464, 113.06460303644981, 98.01933242428689, 98.82654051626884, 94.80768003771382, 104.32703710371449, 97.25587444920694, 111.1498195894303, 95.99894308274793, 96.30367202143516, 97.09142515736242, 100.09238350775935, 92.67248292123118, 94.77142164784094, 83.76426250703874, 83.11471800650321, 78.95199283476799, 75.77673219865369, 66.75969739114085, 66.02269188050302, 64.377771423709, 67.13969661343482, 65.87816822913386, 63.52415384784822, 67.286542307946, 63.6516151889678, 64.97707428470736, 63.563381471941554, 61.72220914594589, 64.01530911845546, 62.26643800735474, 63.60624513318462, 66.32047822398525, 66.13870774545978, 61.68588407578007, 67.33607399848201, 63.79000425338746, 64.58972454071045, 74.9683395508797, 80.9173591675297, 80.92361142558437, 79.92247350754278, 75.80027426442793, 78.280836074583, 79.94021046546199, 75.41649387728783, 79.11876416975453, 83.33578278941494, 77.79709016123127, 75.94563730301397, 73.18242165350145, 72.25631083211591, 76.172467970079, 73.88066630209647, 58.285200903492594, 75.44213833347445, 75.31623809568345, 76.23758715967979, 72.84844752280944, 73.45170805531164, 72.68866585146996, 77.24675024709394, 73.83474319211899, 74.33804604314989, 71.19606279557752, 73.82126592820691, 72.54428340542701, 74.28225424981888, 78.65215116931547, 75.31965055773335, 64.87062508060087, 63.47399850045482, 60.6525513433641, 68.87993458778628, 66.01604738543111, 59.55136552933724, 60.22938251495362, 56.51543924885412, 56.93030834197999, 60.13251173880793, 60.26682938298872, 57.898098268816554, 60.7598634689085, 60.10570626105032, 62.36430898789437, 62.88727860296927, 59.693139599215606, 61.55586534930814, 63.442329283683534, 64.55834557933193, 69.42164528754451, 67.81126130011775, 69.56510989896714, 67.87602747640302, 66.8966979365195, 67.54443030203542, 68.41361968748032, 67.04826616471814, 64.90167848525509, 68.04392845399919, 74.50294248519405, 82.88688321267405, 91.24031574495378, 81.57196352558752, 100.8296557395689, 8.468375628994357, 3.834240643247482, 6.8021419932765355, 3.4676583784241832, 7.165800131136372, 1.4819469567268126, 0.3107859056082464, 1.8148469708619581, 44.899618471822436, 44.45531983529368, 87.2881983172509, 56.102896121240434, 29.3753578201417, 63.88114052434122, 75.2069922416441, 82.82597664863833, 79.52321544770273, 96.34062074845838, 6.468740038333401, 0.4498195257638732, 0.32248961468858106, 0.2821454021238512, 0.12148332722004383, 0.18537483027865811, 0.19763758436085718, 0.10900322633284716, 0.1143686916498888, 0.12301328907450362, 0.11117857895911702, 0.1860862961339374, 0.1217193129442392, 0.11059709524195041, 0.15742219714147432, 0.22917956924967228, 0.08505273610353471, 0.09283821188634442, 0.162215854431833], [0.047946915090564764, 0.06691518314783612, 0.10370982690684258, 0.06873795912871439, 0.03936449336188455, 0.03313163265345558, 0.039161732870965235, 0.0150958257502005, 0.24359988739653943, 0.049339559515036886, 0.043438909004532525, 0.0699312100186944, 0.038191386753873485, 0.15109697687289408, 0.4188132814822659, 0.813468072202898, 27.43574380874634, 93.38574240284582, 79.86787411474413, 78.14580455903085, 70.5988113341793, 27.324185717490415, 40.08902365161527, 69.20939014803979, 43.7902388265056, 17.892111193749216, 0.0452935619039401, 0.17534658613224186, 2.341687842722862, 1.6767867726664392, 2.144190375843356, 3.0454743100750834, 0.852442887281218, 5.044030758642382, 80.82218677766862, 97.8271205963627, 83.83929744843515, 81.19792630595546, 77.11750030517578, 86.44717154964324, 88.12899758738857, 92.4440440823955, 89.01644168361541, 90.11956907087757, 86.25594031426215, 88.04553739486202, 81.80991803446125, 83.14660687600413, 72.07374803481564, 73.20908592593285, 72.44896981023973, 70.08695771617275, 61.25449788185858, 59.73617192237609, 58.85431720364479, 59.7056088139934, 56.78420789780156, 59.74657797044324, 59.33838867372083, 58.24888760043729, 56.70303444708548, 58.110624051863155, 53.61204201175321, 57.68150498790126, 53.19629038533857, 57.187643281875125, 58.58869821794572, 56.80893059699767, 55.590979745311124, 59.396020058662664, 56.1341142654419, 62.94898140814997, 75.64033569828158, 74.87508127766272, 73.79016153274044, 72.98288283809539, 71.62238520960655, 68.86813609830796, 69.33703976292765, 65.10076622809133, 64.79454678873863, 75.94974010221421, 69.78892818573983, 69.06343090918757, 69.0361390575286, 65.90931969304239, 68.89341185169836, 67.19311929518177, 47.208898221292806, 68.55148315429688, 66.20818861069219, 70.54589856055476, 62.589692300365826, 65.32355293150871, 68.43684011890043, 69.37443564015051, 65.76028531597507, 69.29219138237738, 67.90095806121826, 69.42625799486714, 69.86823851062407, 71.51421408499442, 68.94341422665504, 69.93484035614999, 61.74294279467676, 59.672190220125266, 65.63210618111395, 67.39811020512735, 60.94323819683444, 55.08362116352205, 51.89702879997992, 51.04574111200149, 50.111534518580285, 53.81916669107253, 54.735032281567975, 53.89615889518492, 53.43352710047076, 56.92884529790571, 54.23265510989774, 53.35076901220506, 53.06414573423324, 54.939481904429776, 54.22293547661074, 55.28588994856804, 59.7425026278342, 59.14416859226843, 61.22216578452819, 59.91567919331213, 60.85425922947546, 58.19304481629403, 57.81829372529061, 57.21411535816809, 59.32123614895729, 60.87352983413204, 66.34943316059729, 68.08754521031534, 76.52570878305744, 83.15818571275281, 79.86414001834008, 72.70255888662031, 1.5349472482358257, 0.5953745459837299, 2.331561263530485, 0.9656429807505301, 1.334999158017097, 0.03960625921946861, 0.6028120339878145, 14.045441785166341, 25.248141865576468, 41.59980297088623, 74.22976509217294, 27.690646879134643, 15.06510897990196, 33.962238296385735, 54.95190012839533, 60.31055988803987, 71.95261739915418, 38.41633673637144, 0.516960482683874, 0.05372058269718001, 0.042239854998526075, 0.02805029211055127, 0.04758440228479524, 0.018282669160755414, 0.01384554440230732, 0.008121447472442544, 0.07444068699354127, 0.06504686323985939, 0.022072707220251044, 0.06007462319347167, 0.037204240328602256, 0.04569000857431562, 0.04143753494586676, 0.040916208282954274, 0.040126670407311577, 0.04449214966547105, 0.0036192296594831975, 0.04411169508051488, 0.103006933575436, 0.07800765365602509, 0.07671809785308377, 0.003932945297903292, 0.034541069725227934, 0.049461677760606816, 0.0767417086829101, 0.16835160583498018, 0.058413905452095696, 0.0340794749377716, 0.0925693916337144, 0.11255071137941654, 0.3566137755349759, 0.594361961608933, 40.05839778530983, 104.39592961342105, 87.48839609084591, 89.43014975517028, 79.7968086119621, 40.26085484412409, 31.988427100643037, 54.86711809712072, 50.97853522146902, 21.078599614481774, 0.18994408509423658, 0.8265232523122142, 4.024501092010929, 2.878932433743631, 3.0321885068570418, 2.548756383119091, 0.695684137603929, 7.280780980663915, 88.86879582558909, 100.02002362282046, 89.5022507636778, 83.08945794259348, 81.94799330926712, 89.74495134046002, 92.25675875140776, 92.47763526055121, 93.35463016263901, 92.56400585174562, 89.00618076324464, 91.11294069597798, 85.47067396102413, 85.68594932556154, 74.84785218392649, 76.73819142003214, 75.8505198263353, 71.81453427960797, 66.79473984626033, 63.2634731261961, 62.564679345776966, 64.74002192097326, 59.100410630626065, 62.625460393967174, 62.21731032094648, 60.48951018241144, 59.8415542417957, 60.088836146939194, 57.419341610324004, 62.16394647475212, 57.699528278843054, 59.31783153164772, 61.97781432059504, 58.85137150364538, 58.770496153062396, 62.853820785399414, 57.30726772739042, 65.17096096469511, 79.26705329648911, 78.00695265493086, 76.25768538444274, 76.42773582089332, 75.5607037390432, 74.80006987048735, 73.45009203880065, 72.45171546936035, 68.89077601894256, 79.2188238328503, 71.83985710144043, 73.40912680472098, 72.22207638525194, 69.07046764127671, 71.53321404610911, 70.28333510121992, 50.6727707770563, 70.33308644448557, 69.61832077272477, 72.2137374262656, 64.43349261437693, 67.38487612816596, 69.57060121720838, 72.40063052023612, 70.35594601784983, 73.07358372596003, 69.95511900994086, 70.66560929821384, 71.543090574203, 76.42270734233242, 71.67722778935587, 71.13729784565588, 64.73775479101366, 63.06104352397304, 69.68943334394886, 72.61132455641224, 61.763146923434356, 58.958228634249785, 56.240273214155636, 54.39978338056996, 51.98890247652608, 56.51576088320825, 55.72958846246043, 57.20780034219065, 56.095051380895804, 58.530266669488725, 57.470469705520145, 56.03442330514231, 56.88445191229544, 58.37849055567096, 56.27950476061914, 59.39370978263117, 61.87180442194786, 61.277898742306625, 63.279664670267415, 61.73758483702137, 63.83500168400427, 61.36826230633644, 62.006416243891564, 59.86773998506608, 62.933472356488636, 64.04750001045966, 69.15062519811815, 73.95964714788622, 76.27505363956575, 89.73055624192762, 79.52774186288157, 83.79539043672624, 3.8081595782310735, 1.172261122734316, 1.0358081157169035, 1.7631117663075848, 2.2582992334519667, 0.08711542783965988, 0.20846490417757343, 12.482174288841987, 37.66679140829271, 42.42834875660558, 59.29717240795013, 24.939912211510446, 29.017429774807347, 42.87207472708918, 62.44267402156707, 69.19217878772368, 77.0635441810854, 59.15530420118763, 0.9517001192415915, 0.07494235200987709, 0.016169250912724004, 0.02112367175399296, 0.04642839092881449, 0.05078165108458169, 0.036459093417731986, 0.041618435117866726, 0.06060135460668995, 0.049983640276496454, 0.10682009791414585, 0.03495635449766152, 0.032482840451261694, 0.08145565452474741, 0.018014865889844876, 0.045394317787741466, 0.00603251195805628, 0.06622367388298435, 0.18060836910961137, 0.10371454600845614, 0.17689563123689545, 0.16456515498219, 0.21190730494356927, 0.19816197154502715, 0.18033093802871245, 0.07938496483069274, 0.3216790323776584, 0.31502690707002917, 0.19599198153422726, 0.24952160915540111, 0.24646096532383274, 0.42439695928365956, 0.6213174087385978, 1.1652668012726692, 46.20088438833914, 119.9367916968561, 102.43861198425294, 100.6658261822116, 90.52494602818643, 37.52485652123728, 57.89607432580764, 102.43153602846208, 64.85802250523722, 31.417692822794763, 0.49805186989326633, 0.8876859348627829, 7.944372469379057, 5.020050858297656, 6.423350860995631, 9.824564533848918, 3.6838322108791726, 7.3220286253959905, 93.72600801529424, 109.03451673446163, 92.87872114489156, 88.50708269303846, 86.40397840930571, 93.84025881367346, 97.94275991378292, 98.83742901586719, 96.32174630318919, 97.46291283638247, 91.93604223189816, 92.40585588639783, 90.15683943225493, 91.99761559886318, 78.07898306077527, 81.52706023185485, 81.14732773073258, 76.80772719844695, 69.70411085313367, 64.50844518599972, 64.14642218620547, 68.0541266164472, 61.14331045458394, 66.84930786009758, 65.71169107191025, 65.30652200022053, 61.53901876941804, 64.05820023628974, 60.33106996167091, 65.60250405342349, 59.064077715719904, 64.03276758809244, 65.16284950317876, 63.52879401176207, 61.73302704288114, 67.92256247612738, 61.11236295392437, 69.85249411675238, 82.86076022732644, 79.42316362934729, 79.84559505216538, 78.54107749077582, 78.9622223761774, 77.03851945938604, 77.69361803608557, 75.43528987515357, 71.31968021392822, 82.87625358950707, 75.05444342090239, 77.50222990589758, 76.07724066703551, 74.0629937571864, 73.41265693787606, 75.18832960436421, 53.73051720280802, 71.77178828947007, 72.39896743528305, 77.3111084968813, 65.71316588309504, 68.11444482495709, 72.10767653680617, 76.96033093237108, 74.31154651026573, 76.49214113912275, 73.48574638366699, 76.47309410956599, 74.35155468602335, 78.12616132920789, 74.69406389421033, 75.12959603340396, 68.28441681400423, 65.66956481625958, 72.38757687230265, 74.44959040611022, 65.58733624796714, 61.39570320806196, 61.91296577453614, 58.28241994304042, 54.833566142666726, 58.53035688400269, 60.899037007362615, 58.98295133344589, 58.887433775009654, 62.375244555934785, 61.47548421736687, 60.13892089166949, 59.23983912314139, 60.37379633995795, 59.00333981360159, 62.732443040417095, 68.53180854551255, 66.85414806489023, 69.038743511323, 66.4542781153033, 68.91300016833891, 64.4673740479254, 66.29494359416347, 62.06844460579657, 66.78887982522288, 65.77577083341538, 74.61536545907298, 74.93878841400146, 82.73308707821755, 92.20875678523895, 84.87207320428665, 84.15314982014318, 2.4577059140128474, 5.7747751858926595, 9.164730675758856, 3.2595357010441446, 3.6514412779961867, 0.17154815366431592, 1.3412213854251371, 20.844694952810965, 45.00823674663421, 56.211055478742054, 95.54463063516926, 36.41712427139282, 27.096472517136608, 49.988768254556966, 76.67708089274745, 77.88141327519571, 91.93626188462781, 58.54548154338714, 0.8778455661189172, 0.1521049187548699, 0.21086737122987548, 0.12813290145488518, 0.19375635311007502, 0.1626051037061599, 0.19297704250822145, 0.126429803729538, 0.10872557308645019, 0.14598939207292375, 0.2669335312901005, 0.12689992890603122, 0.08778859695960438, 0.20538615002747507, 0.08269890797354522, 0.22271777082595134, 0.2155536076714916, 0.14793789074305566], [0.006821910501457752, 0.06534988931830853, 0.060036200053629384, 0.035370237329193664, 0.016403915135249976, 0.03839618503867138, 0.060020207968210025, 0.07783754383243861, 0.017034033944289532, 0.055204659715415015, 0.028921780326674064, 0.04646916978902394, 0.02077875024218473, 0.02458711504004896, 0.017617685690281853, 0.2719422447825632, 57.87304609052597, 84.34306313914638, 71.52156460669734, 64.46661310811197, 63.51571290723739, 49.78318898908554, 63.36496837677495, 38.177860552264804, 27.892464591610818, 3.3746820255633327, 0.24062063274604661, 0.10901853276957428, 2.9426621237108788, 2.2336022748101145, 1.9299043066078618, 0.5343487786669885, 0.6829439115620429, 35.143012923579064, 98.94282310239731, 89.04633014432846, 86.31557603036204, 77.61596295141405, 75.99462770646619, 70.86099040123725, 78.34142884900494, 79.15895277454008, 82.95333600813343, 82.6456025338942, 81.49591661268666, 79.14711506136003, 71.08094907576039, 68.12292498926963, 69.25229303298458, 72.13541553866479, 71.39554669780117, 67.8748821443127, 63.97711700008762, 58.57747631688272, 58.91169363452543, 58.41612177510416, 56.9242286682129, 56.839885942397586, 57.67343667245681, 58.875611751310295, 57.542460887662834, 56.331021170462336, 56.94513882360151, 54.43178207643571, 56.96526842732584, 57.49880883001513, 58.048764351875555, 56.890790462493904, 53.94647898212556, 57.79366908534881, 53.36749792099, 58.967748226657996, 67.98818372911023, 72.69727937636837, 72.82273246395972, 72.36175198708811, 69.49358940124512, 71.16462892101657, 69.47722527288622, 71.91559022472751, 67.37365814947313, 64.16872870537543, 69.59479439643123, 66.64204197545206, 69.3687403586603, 64.37709677603938, 69.98134397691297, 62.94415297046785, 46.214640140533454, 63.874499951639486, 63.47737173880301, 66.1388175718246, 66.04729298622378, 70.9528523106729, 68.89741266927412, 66.77280595225673, 62.52866414285476, 60.988753380314, 60.38966232730497, 67.75594803594774, 66.06470046504852, 64.78604701257521, 70.91986517752372, 68.68848369967553, 63.0128336721851, 62.49047202448692, 70.89262823904716, 80.50824026907645, 66.4599733967935, 56.944985851164795, 54.227477581270286, 52.09560271232359, 50.5101453873419, 50.911050842654326, 53.110496382559504, 53.33140427066434, 53.85352665378202, 54.643374335381296, 53.598125442381836, 53.672132722793094, 52.340409601888354, 54.27887239763814, 54.43271167816655, 56.12082135292792, 54.8412069197624, 55.90221197374406, 55.41659116744996, 56.931563500435125, 54.20026025464458, 58.12046135625532, 53.00570634103591, 58.05158845839962, 56.39178652917185, 58.97387496886715, 58.11878650419174, 66.82332608007616, 70.4069289853496, 77.08440334566178, 75.96559432245071, 83.52854374916323, 43.8034297573951, 0.3464104649761031, 2.2350547775145504, 2.207848482554959, 0.7504869420682231, 0.36294368426165274, 0.07760322817991819, 6.898455302561484, 25.462883787770426, 25.08761102153409, 70.35898977710356, 78.74276576503631, 22.621057956449448, 27.31630175344406, 53.763880883493734, 65.78816944553007, 66.23486857260427, 78.63661073869275, 18.150552242032944, 0.846157901950421, 0.09160045894884294, 0.07242497176893296, 0.09680690739544169, 0.07579839397822657, 0.037557238322352214, 0.05436302786092124, 0.08457674269354151, 0.04242716349601265, 0.05604878518610232, 0.08244915564935054, 0.06603571421076214, 0.1094609562067255, 0.02894632195332839, 0.07955849906730075, 0.09734381245629442, 0.05894337179920366, 0.046146822973124446, 0.07694377969469755, 0.03503969720294399, 0.0870789390718264, 0.08689166887873605, 0.053939266325605494, 0.07557956096265586, 0.042497471215263496, 0.020220469413024765, 0.08069617027837424, 0.061213508653905124, 0.07736805450892256, 0.06178831974525125, 0.025075469278700413, 0.06839786971648855, 0.6135570606397045, 75.85098266601562, 92.13424744144564, 80.94881657631167, 70.70400930220082, 78.12442764159172, 47.05146997205673, 29.259491005251487, 41.01749573984454, 34.24644539433141, 3.677165162178778, 0.4719324085500933, 1.2505531022625587, 6.0585581775634525, 4.308232357425075, 7.023971638371868, 0.5670472498862975, 0.26552521653713723, 40.7137317042197, 101.99547044692501, 92.36558883420884, 89.6579610147784, 83.79029920024257, 79.91328731659921, 74.67686037863456, 81.4382734606343, 82.52440914030998, 86.32833942290276, 85.23740276213616, 84.33787776577859, 81.45152322707638, 74.93111625794442, 71.09521865844727, 72.74391635771721, 73.9671859433574, 75.345318548141, 73.39459050086238, 68.65158204109439, 63.12747670758156, 61.359142795685806, 60.632613935778224, 60.911623893245576, 58.55298503752678, 59.508658762901064, 61.37524020287299, 59.936691330325225, 59.689291754076564, 59.76875897376769, 59.153323404250614, 59.08474468415784, 61.28971292126564, 60.66703665641047, 59.99365983470794, 58.17245237288937, 59.036730950878514, 56.22937294744677, 60.65484985228508, 71.64841405807003, 76.9394011651316, 75.78963679652061, 75.6056619459583, 71.53904268818518, 73.64900327497914, 72.570892764676, 74.39737581437635, 72.36051251811367, 69.56885184011152, 71.62928858110982, 69.84848545443627, 74.1095366016511, 67.56138278592017, 73.9373916195285, 67.29128837585449, 49.31832144337316, 65.52564913226713, 63.96564014496342, 67.7402820894795, 68.0492550326932, 72.5570232637467, 72.540800340714, 70.70003201884609, 65.36206668423068, 65.09455711610856, 65.69827264355075, 70.23755319656865, 69.50550556182861, 67.22274887946345, 73.45467336716192, 71.23286247253418, 66.56208053711923, 66.3539360415551, 72.96645595181373, 80.99346099361297, 71.59602688204858, 61.194713115692146, 55.734028585495494, 54.14810057609312, 54.42103085979339, 53.19388989479312, 54.5876492223432, 56.65992759889173, 57.29277064723354, 58.00665770807574, 55.33474306906424, 56.481220491470836, 55.766203788019, 56.78336851058468, 57.03766361359627, 59.0576175720461, 58.616770621268984, 59.12818101144607, 57.905570383994814, 59.266228829660726, 57.42385625839234, 60.56892641129033, 55.63303932066887, 60.54735337534259, 58.45460807123492, 61.62450682732367, 61.98863221753029, 67.8922817783971, 72.94041925860991, 78.12037191083355, 80.07896038793749, 84.22923595674577, 55.018498051551084, 0.2143315135711624, 0.6165669281636516, 2.259547772907442, 2.1083065723219225, 1.0139549980240485, 0.050981067601711526, 2.6744796239560653, 26.679465732266827, 32.58027549712889, 59.92067629291166, 50.44091555380052, 23.55431925865912, 39.4002515269864, 61.84351628826511, 73.81682580517185, 73.20931342340285, 89.12755458585679, 32.687728827999486, 0.7169889202041011, 0.03377825682682376, 0.12239130994965955, 0.08069947211732788, 0.081727868546882, 0.05046602285977814, 0.02636220204764076, 0.06096570985391737, 0.03295969187973007, 0.0644251139413926, 0.13365925289690495, 0.02732163524225114, 0.05986813568480073, 0.06104332988240546, 0.05611953723634924, 0.042627503149091237, 0.028379600750462666, 0.15872454661275112, 0.2192032045774883, 0.17215532430958363, 0.2979362209237391, 0.27176374629620587, 0.22137334780587306, 0.3301532212043962, 0.19592307958631747, 0.07962478865538875, 0.1750458506566863, 0.16646660053201262, 0.18179767464678134, 0.2038570691741282, 0.09968516867487662, 0.17184369506374483, 0.8335715676507642, 86.6611211530624, 106.64879783507317, 93.21628816666143, 82.09420357981037, 84.41313235990464, 64.80632566636609, 88.14560490269815, 55.970198415940814, 46.846384925227014, 5.843543650642519, 0.4751092525980165, 0.8723989874124528, 6.522099962157588, 8.531216902117576, 8.874769460770393, 5.461505776451481, 1.2267613531120363, 42.66536581900812, 107.69050090543686, 96.61100541391681, 94.53034493231004, 87.66961743754726, 85.67282507496496, 79.1367050909227, 85.95166637051491, 88.01310723827731, 91.25142389728178, 89.88863560461229, 89.5869347356981, 87.75382288040655, 78.1241766099007, 74.68854119700771, 76.20096791175105, 77.55629585635278, 79.07084065098917, 77.47545580710135, 71.63539963383829, 65.73414271877658, 64.60180151847102, 63.851287364959724, 62.89385249537807, 61.206837161894775, 61.54168205876505, 65.52689252361175, 63.872111228204545, 63.145347026086625, 65.78596507349323, 61.5317859188203, 62.841382949583, 64.00669559355705, 64.97779207844889, 62.772070746268, 61.0075689900306, 62.40893379334481, 59.68428680973669, 64.4830007706919, 75.16525037827031, 79.94259526652675, 80.75612621922647, 80.01515126997425, 76.666349287956, 80.10880962494882, 77.26890379382719, 78.14880124984249, 75.0045116486088, 69.29094406866258, 72.43739097349106, 75.89244996347736, 75.36155716065439, 70.30402168150871, 76.84421308578985, 71.62986124715498, 53.253372638456284, 67.81515229132869, 67.03324348695817, 71.59378328631001, 69.84656349305185, 76.31663860813265, 75.97572972697597, 75.82087455257293, 70.08800106663858, 67.04952132317328, 67.65062455208071, 75.12474013913062, 71.87296975043513, 68.77578781497094, 76.80654264265492, 75.27291159476005, 69.51939075223862, 71.09683467495826, 76.20722801454606, 83.4373172636955, 73.09603537282636, 62.17269336023639, 58.857145232539025, 56.75310742470526, 58.43869893781601, 56.87085305490802, 58.388994662992424, 59.48172776929794, 59.67430830001832, 60.83051320045226, 59.18678514419064, 59.564223058762096, 58.89858899577972, 61.29278413711056, 60.457699760313965, 64.93532849896339, 62.38443466924853, 62.038826788625414, 61.937296236715014, 64.45923905218801, 61.75914610585859, 66.30082714942195, 58.9556477146764, 66.35256321199479, 62.773078795402284, 66.63247923697195, 65.52083638406569, 74.20742327167143, 78.11195450444376, 82.56191484389767, 84.46537833059989, 90.01022907995409, 51.90225731941962, 0.571875135985113, 6.9252347946167, 6.47740210256269, 3.021156595599267, 1.1220579714544359, 0.19104175119390412, 9.80238353052447, 38.105834068790564, 42.78118556545627, 88.48563517293623, 99.16613148104761, 32.75230476933141, 42.781762153871604, 69.98402687811083, 87.81270550143334, 83.04999105391964, 103.43284653079127, 30.324800860497263, 1.2568179854462225, 0.18925192465464916, 0.400828019145035, 0.2494277480629183, 0.20729594593567235, 0.10824348161657972, 0.12857633612809644, 0.16908544145764845, 0.07848290396073172, 0.19735741068518933, 0.20911307584854866, 0.17255845509709852, 0.17027974188808473, 0.15949003698845066, 0.16342383719259695, 0.16647148817296953, 0.14497213456178867], [0.06224366325524546, 0.13415895672815462, 0.02763710833425003, 0.042260493407206196, 0.04542852744400021, 0.10535087151032303, 0.030245021015646, 0.03709786135943667, 0.06145831588054858, 0.061853475523211306, 0.034092843172050295, 0.12326772219591564, 0.10526106302295962, 0.14459425403225806, 0.4510174114857951, 10.810287537113314, 90.12793156408495, 78.42208846922844, 76.57702122965168, 63.083589307723514, 33.25146559746035, 41.86996406124484, 66.175428975013, 38.558683472294966, 26.48872675434236, 0.05259699601259443, 0.18796141890268173, 1.161129558759351, 2.4732764978562636, 4.445845282846882, 2.111810229478344, 1.1746465366694236, 4.444880870080763, 73.20267677307129, 97.08829510596492, 86.45212942554106, 82.99462287656723, 77.24985676427042, 75.56764633424821, 69.00199874754875, 69.80565317215459, 67.95280395015594, 66.97953839455882, 64.55090484311505, 67.57775475901943, 64.96433834875783, 65.13490261570101, 65.47999666583154, 74.11836193453881, 71.62571922425302, 74.2597790687315, 69.65334753836356, 65.55414907393917, 59.13275841743716, 61.43351485652309, 58.02885440088088, 58.2416743616904, 57.19573120917044, 56.881698408434474, 57.25052279810752, 55.70039033889771, 54.86147380644276, 55.21598154498685, 54.2289210134937, 56.18798017501832, 56.44207523715112, 54.99752121586954, 53.95179771607923, 54.870130477413056, 54.17141514439737, 55.21399290330949, 56.09701256598196, 64.63389042885073, 66.85979627793836, 72.43988560092065, 71.65155979894823, 72.16259756395894, 67.8978515440418, 70.90729790349161, 66.45102254806027, 74.5690030436362, 68.11555093334567, 70.72810834453952, 67.12097121823219, 71.45943426316785, 63.91299801488077, 70.52225451315604, 60.38987413529427, 43.28802247201243, 63.107119606387236, 64.70586592151274, 69.29281111686461, 68.50127681609123, 67.57385592306814, 60.54634924857848, 59.75677613289126, 56.275398039048724, 59.24648361821329, 62.84164967075471, 67.13145963607296, 66.52386096216017, 62.05053506358978, 65.59929163225236, 67.20220350450086, 62.732623469445016, 62.02349032125166, 69.32851253017303, 69.41807593068769, 70.06543174866708, 60.19403411496071, 60.46835291770197, 51.0945628535363, 49.45231353082965, 49.90387247454736, 50.090067386627204, 50.9942796153407, 55.1455161648412, 51.30078931008616, 54.9937439733936, 53.468145939611624, 53.707418364863244, 52.631896618873846, 52.93949673252722, 52.50100712622366, 54.66652416413831, 50.84465296037736, 51.602282293381236, 50.277121297774784, 51.76036557843609, 51.43245935440064, 53.49112710645122, 50.289833699503255, 53.91649246215821, 52.49329966883506, 56.730177248677904, 55.13822055632069, 63.49499494798722, 67.58250082692793, 76.92838714968774, 72.26228067951818, 87.16670682353359, 13.5412093324046, 1.8671033603529779, 1.1193315564624726, 1.6360203537248796, 0.20914473060157993, 0.04829066640306865, 0.5487866555490802, 25.542262754132672, 38.538055727558756, 32.35550799677449, 93.87195940940612, 71.29029381659724, 29.804404320255404, 50.39491007404943, 54.34094782798521, 59.392078076639486, 63.35616657810827, 65.92905705974948, 6.8113183782946685, 0.47819431931261097, 0.05261705985533134, 0.06033660228093786, 0.03920297138392925, 0.15846309612595266, 0.020836067025459582, 0.06398415756261637, 0.02732969257199476, 0.048899346241547216, 0.034484417523227395, 0.03386064192220088, 0.02023995868981846, 0.06096930280628224, 0.12262253060696587, 0.04499734251669819, 0.07225104682748357, 0.05181222703428038, 0.07873421910429194, 0.05484602331454235, 0.07363495401917927, 0.027101406031438423, 0.05606369325710882, 0.08658729448554017, 0.08416946737035629, 0.047144403515924374, 0.04263819007563495, 0.0037057877794253614, 0.06308821773517036, 0.1473440500276704, 0.31176729488276667, 0.6273405758603927, 17.824116906812115, 107.7448178875831, 82.37335082023375, 86.93321597191596, 71.20812016148722, 58.480201536609286, 45.04428332851779, 52.903901223213445, 49.13270311970865, 28.55202094201119, 0.05860195705486883, 0.4961838717422178, 3.2020114458376363, 3.511490865099815, 3.5566694601889584, 4.189495348161267, 0.7547952979803086, 5.178124337427078, 79.29804002085041, 101.63169414766374, 90.95895628775321, 88.22461712744929, 79.98341145053988, 79.71698053421514, 73.35180528702276, 71.94606704096641, 69.58986789949479, 69.56879692692911, 68.78916309725854, 70.85513038019981, 70.20720974091562, 69.8278537873299, 70.35422017497402, 77.35572153522124, 74.39402611024919, 76.17751213812059, 73.98684486266106, 68.68165093083536, 61.61412823584772, 64.51864727081792, 61.004897855943256, 60.217148642386164, 61.03068743982623, 58.74016446451987, 59.73763888882053, 58.57178103539252, 58.090376777033654, 59.772371476696385, 57.530109343990205, 59.124658723031324, 58.60215587000693, 58.47147426297588, 56.679723801151404, 57.96735555894914, 55.89810917454382, 56.14708554360175, 58.95196853145477, 67.94535144682854, 71.82634061382663, 75.46493514891594, 75.1228024882655, 73.53527022946265, 72.65072084242298, 74.32172113849272, 70.91314223504835, 78.0361193995322, 73.08979095951204, 72.98107070307579, 71.9463651410995, 73.13152497814548, 68.35920856844994, 72.82274030870008, 64.43168832409766, 45.47526159594136, 63.83387204139464, 68.60736123977169, 74.54698285748883, 72.47098215164678, 70.39050209906794, 63.76745062489664, 61.65965126406763, 60.410078264051876, 61.17113574858635, 65.2862629582805, 69.70883338682114, 69.07402130865282, 64.70320263216573, 67.68132886578961, 70.25938510894775, 65.95376014709473, 66.18636454305341, 71.87888468465498, 72.66791651325842, 73.89244125735375, 62.94640833331693, 62.8488354529104, 55.0152660185291, 54.28102577886274, 53.75843663369456, 54.14346041217927, 54.65278017905451, 57.77919161704279, 54.67056028304562, 59.02603464741861, 54.92629881828062, 57.341678680912146, 54.85639041469943, 56.59135280116912, 54.12171479194395, 56.85020962069112, 55.13900110798498, 55.67542445275092, 52.2543449555674, 54.52371458853445, 52.59281020010672, 57.104281148602894, 53.03240199242869, 58.34123196140413, 54.82706285292103, 59.98977668823735, 56.56719492327783, 66.05709106691423, 69.2619812873102, 81.23744810781172, 73.8247097692182, 93.9691557422761, 18.846878851613692, 0.6545552058566002, 1.5501634704489864, 2.0710474877588214, 1.031476348157852, 0.17990673982327987, 0.06268114925572468, 19.459553072529456, 48.79161773189422, 36.18766953868251, 76.70205070126441, 63.636851387639204, 45.45092721139231, 63.45741471936626, 63.791777164705344, 64.37286061625328, 69.04543507483699, 80.8232536623555, 17.515071399750248, 0.4526417630334055, 0.05630533271018536, 0.09826740805780697, 0.04559711658305699, 0.06633259626405855, 0.025456354788113988, 0.0490465653579562, 0.04770156394149508, 0.02637659109407856, 0.0600250534743311, 0.02032385872406585, 0.02918860300504152, 0.06557977698262661, 0.009606024363048134, 0.11957252773666575, 0.024402493595956795, 0.1455893103153475, 0.2651224994371014, 0.13422589749097824, 0.1657869120038325, 0.18757767013965115, 0.18646440648984525, 0.17366735204573602, 0.21201527737561734, 0.22623377731971203, 0.2494360524560175, 0.2351620877462049, 0.24278172081516636, 0.3119438628275549, 0.5855208166664647, 1.0442979633808136, 20.118252385047175, 119.45915683623284, 96.08845157008018, 95.18652608317714, 85.53249051493984, 49.14745515392673, 57.55316895823325, 95.04450490397792, 59.01260837431877, 42.73267369116507, 0.37376467619211445, 0.47176953825739126, 5.243017990742961, 9.430318282496545, 7.619601690000104, 11.298728527561313, 5.809661726797781, 5.500061694652804, 82.81376238792174, 106.63565789499592, 97.33504356876497, 91.3374806988624, 85.50841500682216, 83.87198648145123, 77.17452372274091, 75.84075312460624, 75.06981126723751, 74.463561888664, 71.31636188876244, 75.01798891252088, 73.82559622487715, 73.48615431016492, 72.2341965090844, 81.0056987885506, 77.81405048985636, 80.16562907926499, 77.43531427075787, 72.04573446704497, 66.0553809135191, 67.97417302285471, 63.444415984615205, 64.30093611440351, 63.75083938721688, 62.58247906161893, 63.38598443615822, 62.91298189470845, 61.51617880790465, 62.17635293160716, 61.175156178012976, 62.04114883176742, 62.221636695246545, 61.29673004150391, 58.941754679526056, 59.701466791091434, 60.38297468616117, 59.181882181475245, 61.748296829961966, 72.21513379004695, 75.88651933977681, 78.22825278005293, 78.33451763276132, 77.7896611921249, 76.87232079044466, 76.2936221399615, 75.81663839278683, 80.51638310955417, 78.18531067140641, 72.98012148949408, 73.68009198096492, 77.29689382737683, 70.36557935899305, 75.6836151307629, 68.92747371427475, 49.50335141151182, 65.62650895887806, 72.51273970450126, 76.10908246809437, 74.67680546545213, 75.01974613435807, 68.77975725358533, 64.13731052029517, 65.44540136091172, 65.72723150253296, 69.82844998759609, 74.52027151661535, 74.4414867893342, 66.94894390721475, 71.54130197340443, 73.35478628835371, 69.18402025776525, 67.9883014002154, 73.65944462437784, 75.75418641490322, 77.45283942068778, 66.1243518706291, 65.74608633595129, 58.91850679151474, 55.94963342912736, 56.74605500313544, 56.68986312804684, 58.0043395873039, 61.45881414413453, 56.823325695530066, 64.0582904508037, 58.41496075353315, 60.08987557503485, 57.03301168257191, 59.075950730231504, 57.02430794315954, 59.576955072341434, 59.578021957028305, 60.04892603043587, 55.82018344633041, 58.52196693420411, 56.39553239268642, 59.484406748125636, 56.102896121240434, 61.7521603645817, 57.35133163390621, 63.302500709410644, 59.287786176127774, 71.07814850345736, 75.89301478478217, 85.09365574006112, 78.77325042601555, 98.87997888749646, 18.39223888612563, 2.9242416927891397, 7.87347415762563, 3.6822284517749666, 1.0074075816139099, 0.16217954186422212, 1.1601132971625174, 31.773183115067024, 55.642747186845355, 50.479562667108354, 115.82907384441747, 91.28825495319983, 41.90270016270299, 68.75265367569463, 72.5665153995637, 76.10566216130411, 80.79119220856698, 94.21206812704764, 13.538995154442327, 0.47299270488081446, 0.18075807801177426, 0.2534125544010632, 0.1949586514984408, 0.3253837722924448, 0.1624658595650427, 0.11348846428576978, 0.14221717513376667, 0.15702574664065916, 0.24807733423527212, 0.1332186144446173, 0.13732611742471496, 0.13381513646773754, 0.34632607273036436, 0.14038430977492564, 0.31320043088447663], [0.06029712960063931, 0.032702485520032146, 0.02027977802490275, 0.08263934463743242, 0.03293927180610838, 0.0074944614842083436, 0.034650478572134054, 0.05465466221193633, 0.026081969000158772, 0.08990402618843703, 0.05460182512779871, 0.10236276854430476, 0.04121076142896087, 0.15894392355074807, 0.24126995354890826, 44.49220188202397, 91.87792839542513, 73.03444631638067, 67.5618613150812, 51.703675562335604, 23.547262914719123, 53.64112246421076, 34.345559766215665, 31.748040722262477, 3.794761987463121, 0.4328568069444549, 1.4279470736941984, 4.073590290161872, 6.012818438391532, 6.4846874148614955, 10.17912228261271, 1.6516289355293399, 17.54138069768106, 92.36245878281133, 90.12469953106296, 88.7342820628997, 85.13469942154424, 80.87565652785763, 79.20668801953717, 71.3648110051309, 67.88640606787898, 67.87631773179578, 65.43578763161936, 67.09043164407053, 66.67324050780266, 67.70295681491976, 72.18269578872189, 72.79043566796088, 71.08255724753104, 79.17491682114141, 74.17362028552641, 69.60422377432548, 65.62289253357919, 56.345584930912146, 60.62297274989467, 58.342836210804606, 59.40295873149749, 57.21695907654301, 57.586979789118615, 55.845772989334606, 57.141755473229196, 54.651399504753854, 54.0534027930229, 55.193604423153786, 57.31413187519197, 54.36564307059012, 53.77987238668627, 53.794432224765906, 56.5910154773343, 53.015433819063254, 54.85190322322231, 58.01135278517201, 61.48592948913575, 62.725763244013635, 70.17267719391855, 70.06321953188989, 72.0247890103248, 68.55120858838482, 66.4637702511203, 64.16570455797257, 72.57510539024108, 65.4412083471975, 66.78655778208088, 69.56613755995228, 67.59418949004143, 67.3703476690477, 71.89052627932641, 60.325896355413626, 41.61186818153628, 73.01761934834143, 68.15373912934335, 70.05234672177222, 62.67004989808606, 59.65099765408424, 55.67766804848948, 56.55935802767354, 57.10808977004021, 56.62438700276037, 57.80595787109868, 61.16561305138373, 65.79879514632687, 68.68515752976941, 66.36167880027526, 68.87827934757357, 61.58065080642701, 65.19741735150738, 67.86320132593956, 67.71093491585025, 68.38288399481004, 59.21852888599519, 63.54278510616672, 56.52266425471152, 51.25287363606115, 51.257545178936375, 49.962558977065555, 52.163243985945186, 50.591895426473315, 52.622396638316495, 53.92640429158365, 54.67604767891669, 53.60304801694809, 52.41240862877139, 53.090437381498276, 52.703228842827585, 52.52330187828311, 52.17647021816623, 50.722612334835915, 52.4587945784292, 50.35227783264653, 52.66234205615137, 53.30590494217412, 56.14526164147162, 58.56255562074723, 56.73130296891736, 55.107959470441266, 53.94457663259199, 58.59896306068667, 56.14900750498618, 65.463071638538, 68.94848192891767, 81.30346944255214, 48.72099937931184, 0.09709504072464283, 0.8742175575706267, 3.1980496068154616, 0.27269907836471835, 0.18039371127322798, 0.034214153194860104, 4.5033222244631865, 72.09689786357265, 33.799750189627375, 40.4712390130566, 49.59344040962958, 17.5971273837551, 22.55499347563713, 33.782958522919685, 54.95127647153793, 63.67609470121322, 68.58980471088041, 61.55868161109186, 3.972975366538571, 0.204191604448903, 0.028431091435073365, 0.013575466807871578, 0.04268803175598864, 0.04271207159505256, 0.026565029571253448, 0.03992696660721014, 0.04992977663454029, 0.05027290358538589, 0.035889464911193616, 0.03354944168559967, 0.01868119767506517, 0.025448488980351437, 0.030898677876159072, 0.0902572233650473, 0.02383218518638563, 0.07553630763845098, 0.04697902811570995, 0.06381443078299204, 0.059729014117751396, 0.02614863205610985, 0.03193100816720436, 0.03220744716424135, 0.07782792176810965, 0.08555067027167929, 0.08740856372300657, 0.04934419051653916, 0.08620726124894235, 0.07596862637588093, 0.10102855747625714, 59.93747972672986, 100.06502889817762, 81.89961479556176, 75.67627245380034, 67.02964275113999, 31.196065179763306, 44.827823408188365, 38.13243558329921, 41.22585988813832, 5.560602007373687, 0.3595408442760668, 3.836873534225649, 7.997295539225302, 11.330528163140821, 17.357113630540912, 5.9336223525385705, 1.2736491210037664, 23.46502846287143, 97.30311547556232, 93.6680353841474, 92.99348185139318, 87.7707753642913, 85.84596633911134, 83.592250885502, 75.11418111862676, 72.19639270536362, 72.91896389376733, 69.43808786330685, 70.50634537973713, 69.59959537752214, 70.79806773893296, 75.98147207690825, 77.88532780062768, 75.36304766131987, 80.54726785229099, 79.4839446775375, 73.76383458414386, 68.43931121210899, 58.68240756373252, 61.954656647097686, 60.7185334544028, 61.83992339718727, 60.188550641459805, 61.006945333173206, 56.37005659841723, 58.1967749903279, 58.79164557303152, 58.00892091566517, 56.894677531334665, 60.75156765599405, 59.26811156734344, 56.68937675414547, 55.98159682366156, 56.27509993891562, 55.87447297188544, 57.54921128672939, 59.07371105686311, 63.73294945686095, 65.27883006680396, 73.49341069498371, 72.39385266457835, 75.43237947648572, 70.92224213384813, 69.85062706855037, 66.71380566012475, 75.60280646047285, 71.98372179462065, 70.8989667892456, 71.81245542341664, 70.5645533530943, 70.32826192917364, 75.24751032552412, 62.977442126120295, 45.35736299330189, 75.04719488082394, 70.84412420949629, 72.12428385211577, 66.59416552512877, 61.6955291840338, 58.395219464455884, 59.75194377283896, 60.587738098636756, 60.08008926145492, 59.33804350514566, 63.2334081588253, 68.29492876606604, 70.70243250939154, 68.52625446934854, 71.41745705758372, 62.06613040739491, 68.14945590111518, 69.65415554661905, 68.8198438767464, 72.6683009055353, 62.16486430937245, 65.43941582402876, 59.83236412848196, 54.66201736081032, 54.43524160692769, 52.256506181532345, 55.07421139747866, 52.24084807980446, 56.113431607523275, 56.634938178523896, 56.034270332705596, 56.188929388600016, 54.24378679644678, 55.89394361742082, 55.20974889878304, 54.521910298255186, 55.77724918242424, 53.92851452673636, 56.96480558764551, 53.960842701696585, 56.61028608199089, 55.12724968694872, 58.934125669540904, 63.15756913154357, 60.57564150902533, 57.74984444341352, 55.96214971234722, 61.09125275765697, 59.69097837325066, 67.89984410808933, 74.83172339777794, 83.1009740214194, 57.20943597055251, 0.4249907387120109, 0.7263614237308503, 4.092836870301155, 2.384572586705608, 0.30519928602922347, 0.054203233411235195, 2.6935112091802784, 73.53414058685303, 44.70572786946451, 40.718724881449056, 51.82044059999528, 22.229187680828957, 41.87686351037795, 40.96569299697876, 63.87589239305066, 73.17365123379615, 74.28991856113558, 79.71650200505411, 10.418467271712519, 0.48038989666008186, 0.09334592133640282, 0.018118841258148034, 0.11354526204447593, 0.06834713171326345, 0.008371682432029516, 0.039998649454285065, 0.038148210038461035, 0.05237917040264415, 0.03225757612756664, 0.03838072155391978, 0.05113949841489235, 0.03494349954229209, 0.08010910178023962, 0.0789743570250369, 0.1470741572519464, 0.2859016844341832, 0.13763117363616345, 0.17203630488966742, 0.14872893781190918, 0.17743629012857715, 0.2168705281350882, 0.19297108234417057, 0.1403997847509961, 0.2622986993482036, 0.2608954101320236, 0.1993154394890993, 0.20828547106394846, 0.3165055486944414, 0.2391751933722727, 67.65511174355784, 115.53507651052168, 93.66706263634467, 89.06626362954417, 71.0907942248929, 32.582034680151175, 71.40827086664015, 50.03299297824983, 52.3328237379751, 8.616010700502704, 0.6137556919167119, 4.136065802266521, 11.617120062151264, 16.152399797593397, 19.287845434681063, 24.10208413677831, 3.808925666155354, 24.24254813501912, 99.36670580217915, 96.33371737695511, 96.27450527683382, 91.99469735545497, 90.23506718297159, 85.69715945951401, 78.93617783823322, 75.75811662981587, 76.9133330929664, 72.6146036578763, 74.24787075288835, 73.9937953026064, 74.65385959994408, 78.99880240040441, 79.6128337613998, 79.53649659310618, 83.17850359024541, 82.12954413506293, 78.08230923068139, 71.54037629404377, 62.05281003828972, 66.2429408104189, 63.80777259026805, 65.02058121465868, 63.435818149197495, 63.388145662123165, 61.38370860007502, 60.90765445463119, 61.83819755431145, 61.87476188905778, 60.995896016397786, 63.434217822167184, 62.827882151449884, 61.021587541026456, 60.65812895374914, 62.459140131550456, 61.04925986259215, 59.416945903531975, 62.37932774328417, 67.308303617662, 68.7555326954011, 76.73183718035298, 75.27076213590561, 79.03761817562965, 77.30883352218136, 73.36326645266625, 69.15919949931484, 78.4386016476539, 73.01066106365573, 75.94088339036512, 70.99421762651014, 74.56015417652746, 73.70809770399525, 79.99914015493086, 66.83378311895555, 48.872406790333415, 76.7963444802069, 77.00932918056365, 76.23914826300837, 72.8664041334583, 66.76678119167205, 62.89977919670844, 61.123008266572036, 63.878904773343, 63.07438350492909, 63.82033201955981, 68.93152944503292, 72.88263490123134, 74.8135785133608, 70.34923876485517, 74.8313311607607, 67.96934066280242, 72.2300152624807, 73.48677404465215, 71.7296463443387, 75.71255437789425, 64.58704556188276, 68.80205985038512, 61.69257563929404, 58.44544149214222, 56.3886917791059, 55.131117143938624, 57.56237476102768, 56.15589518700877, 58.768805611518125, 59.43548694733651, 58.853615099383944, 60.297368957150375, 56.93569375622658, 61.114167244203635, 57.5129097507846, 60.363817830239576, 59.21348864032377, 57.567403239588586, 59.69374364422214, 57.40476608276368, 59.574138810557706, 58.353803157806404, 62.59005708079185, 65.8762776467108, 64.35925783649569, 61.7213148455466, 59.4206956894167, 64.86944836954918, 63.00215698057606, 73.36730649394374, 77.2769917211225, 89.86618395774596, 57.24998151102374, 0.5902698263525963, 4.327338712830698, 9.596498320179602, 3.0455498157009004, 0.23104392082220127, 0.10919179121452956, 6.3790369033813485, 84.35177080092892, 50.79106946145335, 57.535082909368704, 62.149535686739036, 25.99813630503993, 37.78085785527384, 50.21548517288701, 74.11114477342176, 81.48851117780133, 86.92235885127899, 87.04760013088104, 7.773283585425347, 0.5886578547858423, 0.15138502593242353, 0.16605406218478758, 0.17724786314272112, 0.1758717700478531, 0.07880385649660904, 0.23433889562804855, 0.24370199159508754, 0.18085887986085109, 0.0926990213713819, 0.10868182180509453, 0.14524624082109622, 0.11707025474958843, 0.19709323292538045, 0.1618119115911184], [0.10816675791096304, 0.03542967426079897, 0.050114442128688104, 0.09020855379921776, 0.06199317548664347, 0.017923002371624593, 0.08453516710189082, 0.02488830633791945, 0.05428738050883817, 0.06862182786027271, 0.0753685956700675, 0.016495769077371207, 0.06446713386403938, 0.15385348379852312, 2.4131338154115984, 75.85696035815825, 71.94487464043402, 80.2387342145366, 68.06991807876095, 35.556477808183246, 46.955438583127915, 64.15989552774738, 36.06331079236923, 31.443007799886892, 0.3807473224737952, 0.2783653098008325, 4.067635396795889, 4.524716302271813, 0.20536655349837196, 44.85515448354906, 2.866975333421461, 0.8626313050908427, 74.740355706984, 95.07748419238676, 92.42762504085418, 89.19938887319258, 85.74736579771965, 84.5542121702625, 83.36941319127237, 80.90429767485588, 75.98563763403124, 72.21979356581166, 67.84204406123008, 70.78709294719081, 70.77715366117417, 72.8556489944458, 73.69452630319904, 77.38473922975602, 78.2730148684594, 80.40780405844413, 82.20138626713907, 71.8661448263353, 64.30781987405592, 57.67154216766358, 60.9550327639426, 57.04067599388861, 57.605289413082986, 56.49116369985766, 54.63495692899151, 55.0659312740449, 55.27146347107426, 53.41988901938162, 53.42632562883439, 52.884948330540816, 55.50089859193372, 51.61115469471101, 51.88166095364479, 51.35273718064832, 54.689925024586344, 57.89760797254501, 61.21257558945687, 64.049010122976, 64.56926153552148, 68.74067475718837, 69.22652306095247, 68.49897830717026, 70.70422895493047, 70.84031951042914, 68.77924734546293, 62.88600383266326, 64.41095859773698, 70.90517982359856, 64.92267885515767, 66.2995719909668, 72.08516213201708, 64.31358968057941, 72.32317939881356, 58.643901655750895, 50.05811575920352, 71.29356507332095, 65.12867389186736, 64.06444857197424, 55.18858378933322, 56.53533743273828, 60.23964735769457, 62.954013809081054, 60.285229221467056, 59.928830900499904, 57.396646776506984, 57.89603902447609, 60.431741514513575, 64.6790918227165, 67.31012359742196, 63.07942375060051, 60.06133640966108, 66.7600033360143, 68.35413302144697, 65.36261581605481, 66.04424922697007, 57.359545077047045, 59.16818918720369, 62.89180501814812, 49.88049122595018, 54.21019561829106, 49.87318385031916, 51.13910136684295, 47.34470636613908, 51.06015974475492, 52.42060246006135, 53.47137797263361, 52.359178143162886, 52.88914526662519, 51.16858582342825, 53.16758648041756, 51.74237366645567, 51.7670649866904, 50.07602922378048, 53.40664709767988, 49.47953477982552, 56.84911135704287, 56.1090503200408, 58.545865935664025, 64.41902691318144, 62.64093806666713, 64.25333815236246, 61.40063362736856, 61.78950525099232, 63.592603129725305, 64.11191317342943, 71.54145102347098, 71.80254751636137, 72.02000371871456, 4.528671522294322, 1.063600682443188, 0.964589088914856, 2.695046571954604, 0.5507634075418596, 0.052608801427507595, 0.1017144666383824, 29.205550570641797, 76.13522114292269, 30.120261023121497, 66.59114530009609, 54.46430244753438, 14.726627065289406, 26.72968972113825, 43.56030164226409, 53.726041778441406, 63.444749386079856, 71.65053998270344, 48.33450863438268, 2.4050154897474476, 0.16209726402115437, 0.06479141122150807, 0.08442350978692693, 0.052192390505825324, 0.05058804917479715, 0.07018962679731269, 0.05128454184159637, 0.03496144515191836, 0.027822070687468496, 0.013529236274470967, 0.01734912399232628, 0.0257785617929673, 0.05185860599721632, 0.04557236811266311, 0.03181781867639192, 0.09828594738557454, 0.10537328724298747, 0.07148136595083822, 0.05209442318206833, 0.02645203734808151, 0.06221335681696093, 0.05613455639010476, 0.12380052868637348, 0.024392193543814847, 0.009616952607287996, 0.08437843317346228, 0.09255467508468898, 0.21704377125828497, 5.652348697185517, 93.47622363798081, 81.32607013948503, 88.85769551800144, 81.03072351024997, 48.704980419528106, 44.81580526598039, 58.011823469592684, 44.92853418473275, 40.941311543987645, 0.27819088690223237, 0.4936327070238129, 6.243950474646784, 4.868220811890018, 2.3061683293311828, 41.91622841742731, 1.5743312768397795, 1.6690779669630913, 75.44910446290048, 98.80285724516838, 93.47049697752922, 94.65967332163166, 90.91873630400627, 89.60620141798451, 87.50566236434445, 85.58561509655368, 79.5887347190611, 76.40002819799608, 74.77846545557823, 74.51228557094451, 75.0675049135762, 76.78031767568281, 75.39059054466986, 78.4789942156884, 80.85326763891405, 84.39283801663308, 85.51112144224106, 74.63145502151983, 66.70756909155077, 61.60055683505151, 63.83220503407141, 60.50218728280837, 60.82623781696443, 59.65786572425597, 59.62060320761896, 58.45568280066214, 57.944809775198664, 57.67348766326905, 59.708225034898334, 54.719644823381984, 58.28544016807311, 54.668442203152566, 55.20683850011518, 54.65655742153045, 55.57404687327724, 60.19492057061965, 65.93010825495567, 68.02246524441627, 69.01149088336577, 70.34709715074109, 70.85026664118614, 72.24744627552649, 73.76157529892461, 72.30202213410409, 72.53541884883758, 66.88152620869299, 66.26061501041536, 74.38679325965144, 67.3202903809086, 70.16439314811461, 75.69896728761735, 66.29686555554791, 73.82671802274643, 60.93689180189564, 52.26928134118357, 73.52660963612219, 68.34129118150281, 66.82116877648139, 57.11109822796237, 60.08409007903069, 64.2199234808645, 67.19744174711167, 63.388647725505216, 60.520332167225504, 58.786656318172334, 59.030702267923665, 63.8482161491148, 67.52590887008175, 70.35231390307027, 66.56643436801049, 62.500234803845814, 71.13499933673491, 69.92661122352847, 68.34189522650935, 67.76217675978138, 59.28720958771245, 61.03171902318155, 65.35411603989141, 52.529993441797075, 56.143484807783565, 52.24310736502371, 53.080858953537486, 50.847531980083836, 55.20876830623996, 54.36459187538394, 56.4129908623234, 56.0893129533337, 55.48629560778218, 51.79947160905408, 54.33326390481765, 54.37248760654081, 55.31064402672553, 53.41599018343034, 56.789095171036266, 54.251906102703465, 60.08500791365101, 60.249468972606046, 62.83740958859844, 67.38570767064249, 67.35591334681358, 66.79339055092105, 67.59473862186556, 65.37923882084509, 70.29064639922112, 67.51886429325228, 75.34791515719506, 73.80869080943447, 79.2897089066044, 6.429243731883265, 1.3449503337183308, 3.877620831612618, 3.626084870869114, 0.6784866281574773, 0.1112333236021861, 0.028860862930155093, 27.593717267436368, 84.88330687246015, 38.97073630363711, 48.24223095370878, 41.029913963810095, 20.764364811681933, 42.28536659671415, 55.686662043294604, 58.99194925062118, 70.64424022551506, 76.17474294477894, 69.60585548031715, 3.908152561033926, 0.10370926000177862, 0.04877417130515941, 0.02904585401167072, 0.05208916015802853, 0.04419294253532444, 0.019482414561113524, 0.12502950991714193, 0.08487065998657096, 0.05898923748323034, 0.03084719676764742, 0.05244924063463846, 0.02778627905964611, 0.030396585765805458, 0.05788227490660164, 0.1312170871683667, 0.1628159311029219, 0.24297921828204588, 0.17651536051304112, 0.11236472055315973, 0.10905309865671782, 0.19118303312889992, 0.1827246563569192, 0.21803490517120208, 0.12752612917533807, 0.16893251498620357, 0.21024762142089107, 0.22203443571925166, 0.3356642432270512, 6.19652166481941, 106.79551016899848, 91.49975699763145, 98.93169141584828, 89.15353636587821, 51.872510064032774, 62.73167425586332, 90.29922146950999, 53.57559142574188, 55.19069402448593, 0.5010460785800411, 1.2216274608527462, 9.057159673783088, 9.566813822715513, 4.275544305001536, 59.77212436737553, 7.6294424264661735, 1.1622913157747639, 82.70595212136546, 97.30146808008995, 97.36310420497772, 97.14425948358353, 94.26290204448085, 93.18315982818605, 92.42264363073534, 89.54316108457505, 84.32079976604831, 80.1892888161444, 78.6394662241782, 78.04507024826543, 80.47165240010908, 80.08299258447464, 79.43496996356596, 82.57038716346987, 83.65444398695423, 87.54210118324526, 85.9234723737163, 78.82306452720397, 69.80310363154258, 63.695969350876354, 66.49687505537464, 62.88967517114455, 64.41060558442148, 62.46882838587608, 62.925043182988325, 61.6523713450278, 61.79925626324069, 60.844516061967425, 62.17921233946278, 59.07105561225646, 64.01068856639247, 57.08266496658326, 59.27176721634404, 58.79074735026206, 60.25628212959536, 64.23754276767855, 68.06367366544663, 69.52190891388925, 72.3747899455409, 74.61378866626372, 73.93085695082142, 74.22417179230722, 77.4911609772713, 75.56318267699211, 75.1779745471093, 69.5672828920426, 70.26585701973208, 78.48483854724516, 71.35554636678388, 70.66257338370048, 76.99163144634616, 72.13567441509616, 76.66657678542599, 64.61630644336825, 55.153364827556, 74.91544246673584, 73.10297796803137, 70.40121016963836, 62.073178906594556, 63.30466978011593, 66.2218306141515, 70.62478526946038, 66.41548587429908, 63.817841314500384, 64.28643903424664, 62.63374051740093, 66.2899229603429, 72.06819395865165, 76.17843781748127, 70.49601385670324, 66.8454953162901, 74.57116034723099, 73.77870821183728, 70.18607601042717, 72.06786447955717, 61.69985163596369, 63.96616574256652, 67.77175518774217, 54.65198001553936, 58.89987553319624, 55.45348105892059, 56.00003196347145, 54.88370187820927, 57.47379979779644, 56.717370710065296, 57.84515411623063, 60.24370701082292, 58.25433577260664, 55.44580890286354, 59.56872593971991, 57.50872065944057, 57.66521930694581, 57.75801081811228, 61.42885900312855, 57.436596116712025, 65.64919594795474, 64.14230761989471, 65.90988451434721, 71.36975319154801, 70.63678772218766, 72.25678151653659, 70.84139423985636, 69.23825879250803, 74.14530861762263, 67.74670693182176, 82.30477994488132, 76.98497910653391, 85.12348928759175, 6.578401663611013, 3.9274466999115485, 11.342644364603105, 6.935111322710592, 1.2390926720634585, 0.12784675229340792, 0.24616125640609574, 36.37619041627453, 93.3746499399985, 47.36921333497571, 83.89881549342986, 73.25614652326031, 23.475973836837277, 41.57577453121063, 63.256624667875236, 73.108273167764, 83.40806422695037, 90.40593347241803, 73.66224519668087, 3.3108192201583617, 0.21756282647050199, 0.17317224474203202, 0.19292882493426725, 0.13882741992992742, 0.20111153262757486, 0.23902310959754453, 0.1520554294749614, 0.16346430195675743, 0.19506472403243666, 0.0673381632734691, 0.07464923144828889, 0.11947896541847337, 0.10561501862661493, 0.20104522005684916], [0.06353467462524291, 0.05039312959378285, 0.052398567748886925, 0.027143994774368983, 0.1113757853125853, 0.03793033846323529, 0.024546677088965813, 0.024296572364325968, 0.07206920053689711, 0.01266141091623614, 0.09564785467040154, 0.05503648043339772, 0.22632607559282936, 0.24941319239235696, 34.68934374470865, 87.59452758296844, 75.98795183243291, 71.21132866028817, 38.68718424151021, 41.09297783144059, 68.20418865449967, 46.91018227607974, 32.85325873282648, 14.386821350743695, 0.08426071610301734, 0.12913892045617104, 2.285584466111276, 3.512566329971437, 9.405799546549398, 1.8802409715229467, 1.1295139068557372, 28.268912107713764, 72.70938381072014, 86.1228072258734, 90.4650043672131, 93.14382630009806, 89.47724957619944, 90.70356292109336, 88.77821260882963, 85.41770627421718, 82.74348920391452, 79.39245931563839, 76.27201772505238, 76.8185450953822, 70.86610517194195, 76.52160598385719, 80.61223014708489, 79.10940539452338, 74.67365972457394, 87.80434300822597, 80.32246112823486, 73.22348102446526, 64.92260825249457, 57.505410179015136, 57.728232183764064, 56.766188529229936, 59.06620756272347, 55.90843677520753, 54.63821249623453, 55.43898005639353, 54.083444226172666, 56.50358584619338, 53.177812099456794, 53.53595587515063, 55.223288920617875, 50.223051424949404, 50.51149860505135, 50.3544351362413, 56.18885094119657, 62.308560340635246, 65.98153052791473, 67.08178674021076, 67.62399165861069, 70.67954940180626, 70.71458401218538, 67.56809003891485, 64.12738300138905, 65.97039099662535, 69.29183836906188, 67.5682783126831, 65.15692280184838, 63.80822366283786, 68.91789528631395, 62.34765460414272, 68.05425997703307, 67.25871701394358, 68.43432980199015, 52.46326608042563, 52.97474315089565, 71.20811231674688, 61.502646630810155, 59.138849858314764, 56.38273369881415, 64.16184102335285, 65.36274917664068, 65.94957890049105, 61.15120618574081, 57.094926295741914, 53.35062388450869, 56.293758653825336, 57.36100419875115, 61.92681566361458, 60.402323738221206, 60.62517319956134, 58.59283239610734, 65.02053022384644, 63.33034169289374, 65.73610390386274, 62.933852826395345, 55.82199558135002, 53.01466111213931, 66.18462301069691, 53.92438819331508, 50.0398414365707, 53.40210107065017, 53.74986233249788, 50.86602987781648, 48.5274931692308, 52.22128329738494, 53.839751289736846, 51.58728707221247, 54.09142232710316, 50.53307164099909, 49.541300342928984, 51.13130761731056, 52.90742351162819, 52.22071847608013, 57.98885014749343, 58.023641570921875, 61.6469741636707, 63.430813204857614, 63.45032699646489, 63.580730115213704, 68.53870407227548, 65.50070678034137, 70.54589856055476, 69.55943030695762, 69.63806598417221, 71.66673152677475, 72.03819567157377, 73.47717208247032, 75.8684999712052, 14.703964591026308, 0.7488749092144351, 2.4537016643631846, 2.0765584178509253, 0.901024628791117, 0.0996406359838382, 0.04572463957893272, 4.61979014258231, 71.35002366958126, 50.55494277707992, 46.89230803520449, 59.61320953984415, 32.19051349547602, 15.41331543076423, 25.14824498084284, 42.71463078837241, 57.09904870679302, 65.6077600294544, 75.5498936868483, 20.16809590401188, 0.43841593928875466, 0.13020393588850576, 0.027925534692082195, 0.07008963700143561, 0.06352221803559412, 0.03806096028476473, 0.06706484608472356, 0.051931568211124796, 0.03008710156615463, 0.04964778350005227, 0.07874091471275015, 0.06796447079508536, 0.00714158223408665, 0.0626614991004669, 0.08670619899226774, 0.05898867440860599, 0.07929439025540506, 0.02503364279325451, 0.035112467894871394, 0.01816460926596436, 0.10420720949168168, 0.039927460733921304, 0.09215047177408012, 0.048411091594325925, 0.07638314122995062, 0.09833139938212211, 0.16628768835817614, 0.25258879537784285, 46.5045895884114, 101.10662214217648, 85.74534969945108, 84.02488831550845, 58.9161180680798, 52.32388857872256, 56.9864845275879, 42.19898423840923, 43.74905001732611, 16.892791294282485, 0.14549233890589208, 0.7484332748478459, 3.805303602449356, 2.3632743618180676, 5.465924816746866, 2.5130608533659293, 1.1496039191561362, 37.60806960444297, 83.50751984503962, 86.0047987968691, 92.56067183709915, 94.52178632059406, 93.77564168745472, 92.93193986338954, 92.38114495431223, 87.7785102782711, 85.580272828379, 82.04571523974019, 78.62163512937485, 81.32452472563713, 76.43549426909416, 80.07021350245323, 82.24734860081827, 82.39591229346492, 77.61746129681988, 86.58832980740456, 84.8539440093502, 76.92480994809058, 68.7435616216352, 59.85191322142079, 61.033852792555294, 59.7187134527391, 61.433989463313935, 57.940726587849284, 57.219842018619666, 58.997452335972945, 56.351527321723204, 59.65377076979607, 56.41541096471972, 55.830087431015514, 56.742332673841915, 52.491393396931315, 54.49843883514405, 53.7575384109251, 60.95302451041437, 66.47415668733659, 69.18780926735171, 71.03020145047095, 71.03383356525053, 72.92080740774833, 72.77414998700543, 69.42096279513451, 65.7629289934712, 67.51713845037645, 73.23477745056152, 70.56510248491841, 69.50574090403896, 66.66192054748535, 69.59927374316801, 64.98489941320112, 70.75254471071305, 69.5334485269362, 70.55893651900753, 54.57641555416969, 55.48023946823613, 74.91161423344766, 64.20849761655255, 61.79246271810224, 59.57421333559098, 67.25698332632741, 66.71121689581102, 68.25130416500953, 63.78185749053956, 61.89183596641787, 57.20367793113955, 60.15474373294462, 60.57697511488392, 63.94664802858907, 63.561149643313506, 64.61651825135755, 62.764355444139056, 69.98314826719223, 64.94055309603291, 67.41430174919867, 67.65301719788583, 60.793654687943004, 54.87120520684027, 68.79951030977311, 57.06297466831823, 52.12012537064091, 56.92426789191462, 54.88136806795674, 54.39457055061094, 51.56736927647745, 55.63256079150785, 55.5954747815286, 54.344058267531864, 54.99486184889271, 53.41643341125981, 53.51817577115951, 53.486365349062034, 54.85897525664299, 55.88234516882128, 61.12959392609135, 63.71203537910216, 64.48542087308823, 66.08129993561776, 67.58709000002953, 67.53721314091837, 72.3847919894803, 68.67395524055728, 74.87429680362825, 74.12035449858635, 72.40002647522958, 74.2185628029608, 75.16726647653888, 77.97381647171514, 78.51690000103366, 18.304569990404193, 0.5899469049707536, 4.1869163897729695, 3.598560863925565, 4.141776282941142, 0.501546579142732, 0.054230172893092524, 3.68852581708662, 73.2152989602858, 60.99161278816962, 46.157161728028335, 43.89069464898879, 29.2122519400812, 28.92804288095044, 42.93762537740892, 56.94580170416064, 66.6358446305798, 71.58167885195824, 86.29270861225744, 32.302903129208474, 0.5103886740342264, 0.0667751882405531, 0.1361065667362944, 0.15321314154613405, 0.06486276465077555, 0.014718543726860758, 0.06740934816339324, 0.033888389626818324, 0.010074844317240341, 0.022163358404331153, 0.0383361965237606, 0.03952077912887739, 0.036993267375134656, 0.02982272079304582, 0.16292082386151438, 0.13892543321895984, 0.20668319817031586, 0.18299419673219805, 0.23633648521236836, 0.08078692105388449, 0.19191121502268702, 0.1473149080430308, 0.16831982850788102, 0.14429082192720907, 0.1854817455093707, 0.2567434587305592, 0.3841668018890966, 0.4073976214614607, 51.434753940951445, 114.52792167663576, 97.42943932933193, 95.60575685193463, 55.410699767451135, 57.869464966558645, 90.30098653608754, 65.57317649164509, 51.464901278095866, 21.405274214283114, 0.19097622003286116, 0.8520176165526914, 8.249054339624221, 10.095243377070274, 24.987508212366414, 4.860716337157834, 1.3960193482137497, 45.37178554842549, 91.64097801331552, 87.14510240862447, 95.43010527087797, 97.30851265691943, 95.65573569267028, 97.74263274285101, 95.64580425139397, 91.94943320366644, 88.04818891709851, 85.28485559648084, 82.248321348621, 85.24447871792702, 77.7723321607036, 85.87986346214049, 85.60164974581811, 84.74488642907913, 81.73878192901611, 87.85891886680358, 87.07744936789237, 82.04174580112581, 71.5575719648792, 62.75999376850744, 62.29598914423297, 63.10242452929097, 63.932813828991314, 62.40319144341254, 59.52496013333721, 61.900488715018, 60.716670328570956, 63.14234641290481, 60.97427198963781, 59.54254019644953, 61.502678009771536, 54.928467888985914, 57.80180015871602, 57.38877457957114, 62.15589777115853, 70.67223810380506, 71.71573761970767, 74.53890277493385, 72.24809738897508, 77.52414811042048, 74.87887028724917, 72.42123865312146, 69.28585283217892, 69.77884769439697, 76.28650696046891, 74.52177770676153, 73.48172987661054, 70.9558411567442, 73.98784114468482, 69.83598093832694, 73.2793277309787, 70.53784201222082, 73.87180174550703, 57.17572319892145, 58.904123460092855, 77.39536100818266, 69.07013816218223, 63.95119013324861, 61.15812524672478, 71.45815557049167, 71.27140368184736, 70.96356822598365, 66.99868740574007, 66.18655281682169, 61.1416865933326, 63.343901326579434, 63.65682409655664, 67.51801706129505, 67.28338872232746, 68.73068055798932, 65.32936980647426, 73.37286057010775, 68.08024960179483, 70.09582227276218, 70.05522574147871, 63.545052236126324, 58.869994917223536, 71.605346433578, 59.428210950666866, 55.006978050354995, 59.87159175257529, 59.11784164367184, 57.88703718493062, 54.54259687854398, 59.28367160981702, 58.416910171508796, 57.1313415804217, 59.96490101660452, 56.31204474356867, 55.353197820724986, 56.56628885576802, 59.566576480865486, 58.30883710615097, 64.45645809173584, 66.91366610988494, 68.0569193440099, 70.46815718373945, 71.54680898112636, 69.2544738708004, 75.06919937749063, 72.4910254632273, 79.38361044852965, 77.15648081994827, 76.85354832679995, 79.90454043111494, 78.22511488391508, 82.99120256977697, 83.57436487751623, 20.96370162502412, 2.1597665980938943, 11.575523326473853, 9.816318731154166, 5.432046815272301, 0.3289660607134143, 0.24241280351434988, 6.721905989031638, 84.63692711245629, 64.54021246202531, 66.45167366150888, 74.94398163210961, 42.4917499480709, 23.90922707896079, 40.69799907745854, 62.37603295233942, 79.35411422483384, 83.82872273845058, 101.73118114471437, 33.46387763177195, 0.784736771977717, 0.27796869076067404, 0.2805264131917108, 0.23954512190914926, 0.15842705934999451, 0.11125910246083814, 0.22620820530479957, 0.17774482437920186, 0.17067315868071972, 0.1835769751379567, 0.17181898106730756, 0.16541440941153035, 0.18459380363985417, 0.1343756523584166], [0.04279171409566076, 0.09909980855281315, 0.0781252404915229, 0.03948534373193979, 0.042912924527040416, 0.031141765235412507, 0.0714089859637522, 0.04603677061236194, 0.08286239113658667, 0.06362801860837687, 0.07031592405250958, 0.027785668104526498, 0.09202848759389694, 1.259886872383856, 74.50691192380845, 76.75428098247897, 72.63627867544852, 53.514233789136334, 25.639916043127737, 83.72522707908385, 105.87356490473594, 31.40709653977425, 42.785986546547186, 11.730642280270978, 0.09826789069319926, 0.986468866467476, 4.597015390473028, 1.6890229741411826, 2.106254437277394, 0.190099616264624, 14.859180623485198, 75.60264956566596, 60.79094040778376, 95.13021653698337, 89.52693816154235, 90.36975352994858, 81.24802281779628, 87.25877269621819, 86.89218797991353, 88.68191842109927, 83.0460451495263, 84.20231280788299, 78.24960616327103, 78.17193538911881, 77.79596051862164, 79.2452056946293, 77.87792236574235, 78.03689602882632, 84.94649625593617, 85.00057005113172, 75.73274673954134, 76.92107585168655, 63.75022749747, 59.35881637757825, 57.50037385571388, 57.58170027886668, 56.02963409116192, 55.712369257403964, 54.662880282248224, 53.627221584320075, 54.15079524440151, 53.73543193263393, 51.39398482538039, 52.89015331575948, 49.71948185274678, 51.275678296242994, 49.193633217965406, 52.87604847261983, 59.525858356106674, 61.54302743173415, 64.43810924406975, 65.51474886555826, 67.90706911394673, 70.15050011296427, 70.58669121034684, 68.23880749364054, 67.96450045800978, 67.86564104018673, 68.04661135519704, 67.2821335638723, 68.80702557102327, 67.50123716169789, 62.57806639517508, 65.56265277247276, 66.54939559198195, 63.83222464592227, 72.95252369296166, 50.99200856301093, 50.35416057032924, 69.98255991166639, 60.97188718857304, 57.93720822180472, 60.013801205542784, 66.51675362740794, 61.02556874675136, 67.20527864271595, 58.603003101964156, 55.84702814778974, 53.52527918354158, 57.665493872857866, 56.44190657523371, 59.89940135709701, 57.74205853862148, 60.63896033071703, 61.15608953660535, 69.40508504067698, 59.29556031380931, 65.91823916281423, 63.019054551278394, 58.82358151097452, 52.28945801334997, 54.536356387599824, 59.164749268562566, 48.569293868157175, 52.21816893546812, 52.4297062812313, 52.43298146032518, 47.92558585443805, 47.53754185092065, 53.20988924272599, 52.145279530555975, 51.9619793276633, 50.15165644307291, 51.910925757500436, 50.76545638422812, 55.087457241550574, 59.56152054571337, 63.8556255063703, 65.77039326390913, 67.24252546987226, 65.3359790002146, 68.22194914663991, 68.36402523902156, 69.95071026586717, 70.69596059860723, 71.14437380144673, 71.33883706984982, 74.53884786175144, 69.8027898419288, 76.68302720592868, 73.61334108537244, 70.12263559526014, 24.88268679188144, 0.2873906529238147, 1.8417709777432105, 2.870893045779198, 0.6046092762581764, 0.3041709815302203, 0.013065931195723674, 0.11742812506253682, 31.268613338470463, 84.01757701750725, 36.22567338328208, 44.8593004288212, 54.12274637529927, 28.5979675862097, 14.100383404762516, 21.72525332820031, 40.317666453699914, 48.73599067811043, 67.3734934099259, 52.076940075043716, 0.6944826053034875, 0.0608609818042286, 0.05566065056970524, 0.08809769045441382, 0.03624779487689657, 0.03562755477164061, 0.055323479952470916, 0.014494099117244684, 0.027665432520030488, 0.056082152145644354, 0.031427627113918145, 0.052342555230303164, 0.030552785347906813, 0.04223881694938868, 0.028116572122540207, 0.10083107533113611, 0.052568830790058266, 0.06948879424242244, 0.032960576711282615, 0.045839012675588174, 0.034446553627569834, 0.015984627553412033, 0.03809379098275977, 0.0012092456088266185, 0.09695994111919597, 0.09974902210336539, 0.07425271199956056, 2.4276632551224004, 91.97346164334206, 84.61308694654896, 80.63307362218058, 64.8624312493109, 39.85228507749496, 81.01538704287621, 80.5600469343124, 34.88272836131435, 52.01388012978339, 9.698446604513354, 0.1634601650819663, 2.765513668137212, 4.5158399785718615, 3.312155277498307, 1.999803517133959, 0.7023695724145059, 20.475317508943622, 86.9511490483438, 73.06937894513531, 96.7524931507726, 93.4142658787389, 87.55721015314903, 82.89840713624032, 87.63833261305287, 89.55362596819478, 92.73094192627939, 84.70810244160315, 84.87476395022485, 83.07561197588521, 79.81095267880349, 78.65629319221743, 82.85230359723492, 82.97930209867417, 80.14735867900234, 82.97839995353453, 87.06052826296899, 79.64686424501481, 79.51093058432303, 65.38237279461276, 60.85483974026096, 61.091523401198856, 60.067035613521455, 57.89799628719207, 57.41875717716833, 57.59422048445671, 57.13665246963502, 56.35741479935185, 58.29591681880336, 55.04343648110667, 55.862729395589525, 51.91852731089438, 53.3696513022146, 51.44264574973814, 56.17253780364991, 62.55393597387499, 65.321556445091, 67.31152780594365, 67.243270720205, 71.50937388020178, 72.5175485303325, 73.8855065068891, 71.87045943352484, 71.23333315695487, 71.0735514856154, 70.44437977575487, 72.6431820469518, 72.51932144165039, 70.58193729769799, 65.83858366935485, 68.59944589676397, 69.02047311106037, 67.00856393383395, 74.67601314667733, 55.053956277908824, 53.61667433092671, 73.16913266335764, 63.331953787034564, 61.74744567563457, 63.63223868031656, 68.29121820388302, 64.2433439531634, 69.3686148428148, 61.459959476224846, 59.535734884200565, 56.27901838671777, 60.32103653877013, 59.8062176089133, 61.838185787200935, 59.26181616321687, 63.6627939439589, 66.26206628737911, 72.59412888557681, 62.527173642189275, 69.30146386546474, 67.04040573489281, 61.99099348437402, 54.26980780016992, 56.22059860537129, 59.92269239118023, 51.86528898054554, 53.83857457868515, 54.75245152750323, 55.536580393391276, 51.06645122651131, 50.78810807197325, 54.81576642682476, 54.85059707395492, 54.9375795548962, 53.125217037816206, 54.623315334320075, 53.520952809241514, 57.415689883693574, 64.42793069347259, 67.11970037029636, 68.16011690324353, 70.973750698951, 68.55290305229926, 72.49244536122968, 73.93705429569368, 73.69017247230776, 74.5873518913023, 75.74765959093648, 74.90887641906738, 78.49209493206394, 74.67570720180389, 80.07621472881686, 75.62565818909677, 73.7144676331551, 30.277903041531964, 1.1211417302969964, 1.1992212889655944, 2.0322312222373102, 4.400581621354626, 1.916979606593809, 0.11283810160333112, 0.19358151652399572, 29.83464775546905, 91.45757582879837, 46.17879752189883, 40.28023919751568, 41.33910263738325, 23.478782253880656, 22.84694137111787, 36.14393118889102, 51.61329238645492, 56.11280010592554, 73.8026503593691, 67.94382172246134, 2.00442970760407, 0.11654982057910775, 0.055532020576778925, 0.059345326641754764, 0.09702288290305484, 0.09802275787918799, 0.039543033983077736, 0.0638656284389717, 0.07152291089897195, 0.05250468241771864, 0.018102561889757073, 0.03943169842504206, 0.04065229482347927, 0.035016909917636264, 0.13528047880578425, 0.2998800004922575, 0.12441555173286509, 0.12050021424769394, 0.07612516878232842, 0.13821995817124844, 0.17344656550595838, 0.20573539419039605, 0.12942935971002426, 0.13123191863058076, 0.2315610914581245, 0.20099824354533227, 0.3223812285690539, 2.6862357028069037, 101.95728225092735, 96.87299620720648, 93.7606425439158, 71.74740683647894, 38.48232669215049, 92.77122466794907, 128.42708356918828, 48.900828284602014, 64.21642080430063, 16.3406402257181, 0.2590484947206513, 3.5447633506790286, 14.817023969465687, 9.197503059141098, 10.316680785148375, 3.96204813353477, 20.51082084255834, 86.24164719735423, 73.90039582406321, 97.11764227959418, 94.45250157387026, 89.63514066511586, 85.63949277324062, 89.467906490449, 92.59181545626734, 94.34290270651542, 89.2507170092675, 91.54253436673073, 87.70171027029716, 84.36910767709055, 82.67239232217112, 87.14046616708079, 85.59222821266421, 86.15619444078015, 81.5046085849885, 90.4911587315221, 85.62733342570644, 82.59658859622094, 70.89507579803467, 62.331455215331054, 63.07862750945553, 63.12059294792914, 61.03654746086367, 61.02232886898903, 61.90141047200849, 62.18434672201834, 61.92500745096515, 60.701800623247706, 57.15225173581032, 60.13899541670277, 55.585182482196444, 57.82827223500898, 54.56628014964443, 58.66017164722566, 66.1866783326672, 66.98178983503773, 68.22356516315092, 69.51199316209363, 74.13479666556083, 75.8380937576294, 77.1448000015751, 74.20486588631907, 72.89245651614281, 73.25534635974516, 74.3093107592675, 74.36684408495503, 75.36499315692534, 72.21061521960844, 67.73421026045277, 71.18536256974744, 74.44278117149108, 68.2684684568836, 74.9533639415618, 57.441503001797585, 56.28787509856686, 76.21924615675404, 68.32574290613975, 63.91450812739711, 67.04177856445312, 70.70750805639452, 68.5488316320604, 71.35136512018019, 65.55711046341928, 62.2902467943007, 60.33481582518547, 62.95662610761581, 62.31153741959603, 64.2166090780689, 66.43464273022067, 66.18971424718058, 67.20097972500709, 77.10562336829402, 66.17666059924711, 71.37435020938997, 70.5385245046308, 65.33699097171908, 56.8893313407898, 60.788128068370206, 64.19046648087041, 54.17238396982993, 59.21239822141586, 56.67673887745027, 57.85004531183551, 53.01980726180538, 55.30886719303747, 57.64087707765641, 57.514470854113185, 57.574090880732385, 55.089308600271906, 57.61316161001883, 57.89263048479634, 60.848544336134395, 67.4599346037834, 71.0896175138412, 71.40225395079582, 72.28392431812902, 72.4375557130383, 74.61113714402723, 77.16973058639034, 76.69299787090671, 78.34515510066863, 80.37200066351122, 79.44249306955646, 82.10655120111282, 77.55710386460828, 83.38600481710127, 81.50426341641335, 77.38795557329732, 33.09681830867645, 1.610340228484523, 8.821189884216555, 6.254127554355129, 6.802724955543396, 3.1841644164054625, 0.2695738686428916, 0.430795448201318, 40.32553080589541, 100.36777311755766, 50.61954421381797, 62.96072498444588, 71.38316769753733, 38.795531872780096, 21.68815947348072, 33.660529582731186, 60.379954461128484, 68.07914349340624, 85.57327531999158, 78.09049129486084, 2.471384689692528, 0.17430337356223216, 0.18809477948854048, 0.24760064368526785, 0.22186240301497523, 0.16595580374761937, 0.14165212400257587, 0.2346357700204657, 0.18317251135745358, 0.13722825735326738, 0.17609312349269468, 0.14758434116600022, 0.09849071502685548, 0.24550759954558266], [0.027737498411067554, 0.06036385585884414, 0.03767980472935784, 0.04510868956605273, 0.20540660457505336, 0.0128089489167436, 0.062316989360917965, 0.09530643226518747, 0.031069567194208506, 0.13518320096115913, 0.08353141572086081, 0.3677928369612463, 0.7307940697477711, 18.47728567738687, 95.31569757769185, 68.37656897883262, 77.90724600515058, 46.73863349422332, 30.699067538784398, 37.420592077316776, 56.94426805742326, 32.039292397037634, 48.89894946928948, 1.583033667937402, 0.25695063954880165, 1.7229568693907031, 2.1995622304178055, 1.5008605031236526, 1.0757197031090338, 3.464351575220785, 90.25313361998528, 93.49967941161125, 103.82260461007397, 87.35745168501332, 95.36774742987849, 91.603134985893, 93.84150612738826, 87.96602310672884, 82.33730423835017, 78.39974664872693, 81.53495204064154, 84.66288535825669, 84.16323031148603, 81.53146113118818, 80.62195762511223, 80.04880520605272, 80.06063507449242, 79.93805316186722, 81.26704631313201, 71.40211274546962, 79.83633041381836, 75.96874006332891, 65.35411211752123, 56.0736156279041, 57.48602974799372, 57.32058417412543, 55.67203552492204, 51.370160348953746, 51.589428686326556, 51.41629134455035, 54.15241518328267, 53.85229502954791, 52.68335811553463, 48.76973875107304, 49.6842432791187, 48.720689512068226, 50.74263603456559, 51.740687047281575, 59.903598293181396, 60.57491194817328, 64.83027958100843, 65.46930820711198, 68.3180001474196, 68.49553446615896, 70.75383909286992, 67.14761980118291, 68.83696894491874, 68.61879887119417, 68.47025086802822, 65.35947007517662, 69.2558623898414, 64.39802654327886, 65.824110123419, 61.85001565564064, 69.44135912003057, 56.18474814199633, 77.31609775174049, 44.94991894691221, 46.04276972432291, 71.9983914590651, 56.220716276476466, 60.80667303454492, 63.661272064332046, 60.73339139261554, 61.63079830908007, 65.96318168024864, 57.44277384973342, 50.5140285338125, 51.492663814175515, 55.747701967916186, 57.71640623769453, 59.92423780502812, 62.56500882487144, 66.32040762132215, 61.94768267293131, 63.83896327787831, 56.541695594787605, 58.38500561252717, 67.87229337999898, 61.188009785067656, 60.45212999466927, 51.39199618370303, 49.93022687973515, 45.492068952129735, 49.42108754188784, 53.33946474136845, 51.61301389817269, 52.94359953172746, 47.70208920201948, 52.63433241075086, 52.88643098646595, 50.308680688181234, 50.869658070225874, 49.23550451955488, 53.83376575285389, 62.138929597793094, 65.17058833952873, 66.84754279352003, 65.2093021331295, 68.98611314835088, 70.18030228153353, 69.20795456055673, 71.36701537716773, 72.32881976712135, 71.17896910636657, 69.92870576920049, 72.58623707679011, 69.51013395863195, 71.31607947811004, 68.2277464097546, 66.21980667114258, 66.68287384894587, 45.56273045078401, 3.9243722971408603, 1.865433533826182, 2.447645034520857, 3.763317571532342, 1.8181165115487192, 0.11861481057900576, 0.08742271336696802, 4.555041126666531, 63.42814207077027, 70.85283187127882, 30.474957035433864, 52.536284923553474, 139.26954238645493, 71.4111420416063, 14.647657006017624, 15.073913720346267, 52.72903019382108, 59.35472142311835, 65.08369999547159, 7.204757111687814, 0.14056271633073208, 0.13395002922944485, 0.0413815607316792, 0.03929308630646237, 0.053088322672392094, 0.04892533577437844, 0.06390474105794584, 0.13645660763065662, 0.05272948708865912, 0.03880609953475576, 0.012733126322047846, 0.047987081080434785, 0.05801690336797507, 0.02799598605281884, 0.053899242062001466, 0.016121941152960062, 0.03180405590683222, 0.05124836333937222, 0.10791698260413063, 0.012755062292149712, 0.014345028940888663, 0.043938160843906865, 0.14628536248159024, 0.0800290072877561, 0.39715285022412583, 0.8541270549739561, 24.12878174935618, 108.71361978592412, 76.3855468073199, 88.00960063934328, 54.2720906196102, 40.53641703820998, 51.626534308156664, 52.126055994341456, 43.592249347317605, 55.896195057899725, 0.5986032082188515, 0.1907202547356006, 5.260317114091689, 2.3986185942926714, 1.046131916584507, 0.9469239593994234, 5.601200499842244, 100.5592083161877, 93.49449403824346, 103.56736029348066, 90.80254001002159, 100.02143567608249, 91.48808402399864, 94.36318136030629, 88.40144541955765, 83.18821537879207, 79.50048139018398, 86.65552785319667, 86.50748191341278, 87.60159569401895, 83.5414561917705, 83.18373603205528, 80.53375136467719, 81.98236111671694, 81.55295571973248, 84.4757333878548, 75.19491134151336, 80.42183045418032, 79.19250472899407, 66.66931029289, 58.29724650229178, 59.42050349327826, 60.05602159807759, 57.962495742305634, 54.60320926481678, 55.31685706107847, 53.89053421635782, 59.19670481835643, 56.147301273961226, 55.75184399081815, 51.81933056923651, 52.92447013239707, 51.87294152475173, 54.510394219429266, 56.075494443216634, 62.9237291889806, 63.93466126534247, 68.23876826993882, 68.3422560845652, 71.21805160276352, 72.78895301203575, 72.29511876260081, 70.5708997480331, 71.63743926632789, 68.78703717262515, 71.41205203148627, 68.57131465788811, 72.49982726189398, 68.44095860758136, 68.94901537126111, 66.32789150361093, 68.99204377205142, 60.59308036681145, 81.4654633306688, 48.048618839633086, 52.453205200933645, 74.7262587085847, 60.981885310142275, 63.405443314583074, 66.85845482733943, 62.514567144455455, 65.38076462284212, 67.33525030074581, 58.8193061274867, 54.04050603989632, 54.808321768237704, 59.45005855252666, 60.14673425305275, 62.80482253720684, 66.90318553678452, 69.00083772597775, 64.10362128288516, 64.93051575076196, 55.89156666109639, 59.48767800484935, 70.55078583378946, 65.2217125123547, 63.164295996389086, 54.9450046016324, 53.672242549157914, 49.77239462637132, 50.05009451220113, 55.65461235661661, 54.39922640400549, 54.85287597102504, 49.760619671114036, 54.457893294672814, 54.72561859315442, 52.32125274596676, 54.51507752941501, 50.87020720205, 57.249973666283395, 66.03670258675852, 69.3573341061992, 70.75157980765067, 70.66963365001064, 74.25199708630963, 75.03478450159874, 73.08915553554412, 73.26311265268635, 74.57373342206402, 73.77914751729658, 73.69060393302672, 75.89394830888318, 70.2057819981729, 72.30357539269232, 69.26781777412661, 67.62745118910267, 65.32580044961745, 52.66811186267484, 6.44124569431428, 0.17962494204121252, 1.7219999336427259, 4.390995838949758, 2.209781720753639, 1.0170551413489928, 0.10010461713517867, 3.448487303910717, 66.33264541625977, 79.62596585673671, 38.468618008398245, 40.0128786794601, 106.2209221624559, 53.47184081231394, 21.765873393704815, 27.129979364333618, 65.26731006560787, 65.38358872936618, 75.73131899679862, 12.362285083340062, 0.2891467409508844, 0.0732344202697277, 0.10358045763906934, 0.09318249946039531, 0.09739450449424406, 0.01830442414258517, 0.0607803548806377, 0.03865755125579815, 0.02639601525339869, 0.006082688323071888, 0.04245456263062455, 0.03410330410265634, 0.04196256564389314, 0.183714549207399, 0.1842441151459371, 0.07478058488378603, 0.16918498692252945, 0.2833027158293032, 0.2020610220009281, 0.21016909740865233, 0.27489741362871667, 0.16243395966387567, 0.32927896166520737, 0.10409384380064665, 0.5132455384779362, 1.104923465078877, 28.02518779231656, 121.41269330055484, 89.13013550543016, 100.52366379768618, 67.20818119664347, 43.86632888547836, 44.92684756555865, 76.59995925041937, 51.27730215749433, 66.81369273893296, 1.9516814283786283, 0.2832786606684808, 7.007438848095556, 10.023873890599898, 6.360417902469636, 3.5322350552005157, 4.8435373363956336, 101.70846277667631, 97.01627254486085, 109.19416504521524, 94.40059292700984, 105.3036758976598, 95.90372362444478, 98.2332428040043, 90.80603091947495, 84.75291159845169, 80.52490249756845, 89.46535694983699, 88.74846535344278, 92.23455813623245, 87.00457957483108, 88.58222746079969, 84.93377993183752, 85.80432645736202, 79.89650741700204, 87.25372068343624, 82.05085354466593, 83.0416520949333, 81.85183248212262, 69.8011738254178, 63.60940264117334, 62.30932520281885, 61.46262668794202, 61.00880845900505, 56.85157852788126, 57.0353651046753, 56.49052827588974, 62.89136963505899, 59.93656581447971, 59.390971968250895, 53.26539078066426, 55.96672711833831, 54.95695998591762, 57.670165415733095, 59.360502996752345, 64.7584649055235, 67.1964297756072, 70.25700815262334, 70.92019465661818, 75.48183271961828, 77.70409860918599, 75.54970541308003, 74.87160605769004, 76.45934227974185, 73.50879423079952, 73.81710037108391, 72.88148956914102, 76.04945459673482, 70.60416144709434, 72.31200064382246, 69.90936063951062, 70.70652746385144, 63.8380140642966, 81.88302316973287, 51.82157808734525, 57.62030816847279, 76.56113563045379, 65.34796968583139, 65.90751540276312, 70.49671988333426, 66.18008090603736, 66.14176719419419, 71.44349375078755, 63.18614359824889, 56.31763412106422, 59.251284599304206, 62.43060881091703, 64.34973824408748, 66.74279982043852, 69.96408554815477, 71.83482862287953, 69.07979503754648, 68.06931403375441, 58.04180606718987, 61.94646281580772, 72.64897931006648, 68.30627226060437, 67.86673145909464, 55.76258344034995, 56.948374778993674, 52.05603384202527, 53.85930038267567, 59.35486262844455, 59.31970250221991, 58.93603194144465, 53.929820676003736, 58.34118489296206, 59.65675961586737, 55.11351746897544, 57.64119478964037, 54.94813465302991, 61.619917654222064, 69.87758944111486, 72.17446665610038, 72.60901820275092, 74.06353504427018, 78.39525945724981, 78.74648417195966, 74.95483875274658, 77.1021246141003, 78.817761482731, 78.55319761460828, 76.48736369225287, 79.8674818777269, 70.70812779088175, 76.08088847129576, 69.95307153271091, 70.42504249080535, 67.48533587301931, 55.8889308283406, 6.538710709541075, 6.717366826149726, 10.423879161957773, 12.091712144113357, 4.632119622922713, 0.6921032587847402, 0.2883109696690114, 6.058303713798524, 78.94316750188028, 85.88454677212624, 48.313665159287, 67.85944369531447, 150.06126926791285, 84.00898702682989, 23.232082820707753, 26.94938755804493, 76.05940957223216, 76.10759196742889, 93.92614303096649, 14.960098305056173, 0.4460275131127527, 0.30375606831043, 0.1656203798108524, 0.32958034065461933, 0.17724993158011668, 0.18211976865366583, 0.2775501003188472, 0.16334804045336862, 0.21421546657239238, 0.1251743618218649, 0.17895531990835745, 0.1573757875350214, 0.1260377812169252], [0.03806459154152582, 0.03473493210490673, 0.05592167970814532, 0.10475345316433138, 0.04736803990278033, 0.1450732428460352, 0.0695381149829876, 0.047217561082253535, 0.04257439027330087, 0.01774042255185064, 0.017494935422174392, 0.10245090695999323, 0.0706829108117569, 61.58482420829035, 81.672972402265, 69.5853179500949, 58.99537347978162, 32.77303841806228, 23.031639898976973, 42.86556751497331, 39.835913104395715, 42.528153465640166, 30.10597182858375, 0.14694229819841925, 2.0025880322340996, 3.0521244435541095, 1.2926199094903086, 0.5552034692898874, 1.0587686901130984, 73.58569622039795, 103.43316032040505, 81.17604732513428, 84.75513950470956, 83.81207619943928, 90.03835247408959, 84.36081578654628, 91.06060843313895, 86.37452925405195, 90.8336365607477, 82.98076906511861, 76.21545714716758, 73.73607989280455, 76.74946431190737, 76.42972054020052, 82.23813103091332, 82.45832504764681, 85.22115630488243, 75.62036298936414, 74.1237904948573, 79.1103232291437, 78.6201681629304, 74.22590547992338, 63.80498378507553, 56.93953767899544, 58.21157801535822, 56.830280057845584, 55.526562659971184, 51.466274107656176, 53.31975090888239, 51.52126181510187, 53.50081143840667, 49.978766210617565, 52.18395017808484, 48.32721302586217, 49.592142105102546, 47.92077310623662, 49.862079620361335, 52.681298871194166, 60.14367088194817, 57.764812207991085, 65.73555477203863, 62.561349253500666, 65.527877038525, 60.514248571088245, 65.90294976388255, 62.1886456397272, 66.90085564890217, 62.409149523704286, 68.85701225649926, 64.54710406641807, 70.2091395470404, 66.70505092990014, 68.29489738710465, 62.514994682804236, 71.85475426335489, 59.597704410552986, 71.50105061069613, 39.63164783293201, 37.88243939799648, 71.87165967879757, 54.97026466554212, 61.29799696706957, 61.55189591069376, 61.218019839256044, 60.82266846010762, 63.35535072511243, 52.68777862671883, 49.694586569263095, 51.88351231236612, 56.570830960427564, 60.352478258071415, 59.72534225833032, 64.36876958416354, 62.93392735142862, 61.523015499115, 58.03989587291595, 60.02446220767114, 60.05508022923624, 62.65357202099216, 70.30128386712843, 65.3233136669282, 61.38532069421584, 57.03424330680602, 47.952850249505815, 46.88465156862813, 48.48814395166213, 49.45665951698057, 51.82172321504163, 49.60498786741688, 47.46999863655337, 52.84832123787173, 50.34944195901194, 51.96017895975421, 48.75463762590962, 60.395447823309134, 64.71243589155137, 72.0492567554597, 67.60194793824228, 68.23656389790197, 70.52412156135806, 72.26654821826567, 72.24899953411472, 71.33387134921166, 70.12316903760357, 71.75594975871425, 70.49545688013878, 69.81465893407022, 70.63401068410566, 72.28910184675648, 68.55571931408298, 69.33503935413977, 68.11293863481092, 65.48351503187611, 27.868096866915305, 0.6782798457049555, 0.7385492084487792, 1.8139362455375734, 1.8302647048427214, 0.26054009855274235, 0.1323102946363149, 0.16179280535828683, 23.499543359202725, 85.42639040177869, 36.988994075405984, 66.02288015427129, 109.53093190346996, 135.4051919137278, 68.56133614816974, 11.96617276437821, 51.7272097833695, 52.466078419839185, 68.96669741599791, 23.05904353818586, 0.8495405785018398, 0.22557376192942744, 0.047990313971475254, 0.03321330911750275, 0.033245013666249094, 0.0392714902878769, 0.016045542077101287, 0.040313067260168256, 0.049845648689135436, 0.030390876495549758, 0.031573423222007777, 0.07171634809985276, 0.04890876146213663, 0.0642161289860885, 0.036750827360177235, 0.06879957558046426, 0.058281441189108364, 0.02269170817828948, 0.09017552774880203, 0.05522843142370543, 0.10106587361904884, 0.0845854914176368, 0.03110355660018902, 0.06560633725096142, 0.07876644842326641, 0.0262067532317052, 74.33606916858305, 90.41882238080426, 78.25883942265665, 64.91034300096574, 48.44587256831508, 24.090934799563502, 35.82763910293579, 44.29484390443371, 52.881869269955544, 31.249430987142752, 0.3398442028030273, 2.53383862876123, 2.9081229577141428, 1.5893006348802199, 1.3958375708710764, 1.9207730288467102, 86.58429761086741, 105.75684301314816, 88.19680752292757, 92.76272881415584, 86.11773952361077, 93.69334251649919, 89.9570417404175, 93.41665852454402, 87.955032625506, 91.30704310632522, 84.10236297115203, 80.4453411409932, 76.93008945834252, 79.22625280195668, 80.20866532479563, 84.319654433958, 82.92266307338592, 86.53705658451204, 79.84557936268469, 77.91746770181965, 80.48298804990708, 81.60719425447526, 78.52199123751733, 65.51105007048577, 57.52311575797297, 60.24737050456386, 57.79826610319076, 56.068057629369925, 53.40646274628178, 54.892680183533706, 55.13264294593565, 57.85694083859844, 54.11321109341037, 54.5771372702814, 50.50399511091171, 53.02814229842156, 49.43557677730438, 52.960042107489805, 54.9816866074839, 61.62535013691072, 60.43056088109171, 68.6443962589387, 66.28443164210167, 66.97840875194919, 64.85479831695557, 69.3857712899485, 67.07435777110439, 67.92423340582079, 65.87383793246362, 71.98311774961411, 68.66846392231604, 70.01448800486904, 69.15315904924947, 71.83529146255987, 69.51696672747212, 68.67624590473791, 66.87647419591104, 70.2504970181373, 58.40935176418674, 54.443415826366795, 69.34671232777258, 60.7185766004747, 67.05961750399682, 65.2058151460463, 61.60792304623512, 64.95958051373883, 65.84143131009995, 56.73414668729229, 53.75332578536003, 55.77551941717825, 58.28198848232147, 65.18181808533208, 66.28257243863999, 66.55428286521666, 65.48067915824153, 63.5719322389172, 59.22070187907065, 62.727810721243586, 59.136496436211374, 65.9251033106158, 71.49012288739605, 70.65805481326196, 64.48622495897355, 61.12129026843656, 51.81318029280632, 50.82028719686693, 51.60088592959989, 53.48123488887664, 52.47057737842683, 50.40301369082544, 49.299513678396906, 54.19453751656317, 54.050947389295025, 52.99003647219751, 53.68744173357564, 66.19117336888468, 66.23783388445455, 72.49021745497181, 71.29964474708804, 71.0804234781573, 73.26767829156691, 71.54383582453575, 73.73086314047538, 73.43880345744472, 70.36624616192233, 72.96012524635562, 73.59725936766594, 73.09989498507592, 71.71285860000118, 74.21011401760963, 72.82848265863234, 73.0613459310224, 70.53854803885184, 69.25401103112006, 35.930750370025635, 2.5877413105580116, 0.8940141275525094, 0.4967236879371828, 2.0636699997609664, 1.2194859693127296, 0.28068511596610474, 0.08113237308158029, 23.836367091824933, 89.08689529665055, 46.653980901164395, 63.70355129241944, 100.09041447793284, 116.0854870273221, 66.26657701307728, 23.53914164727734, 57.21731601222869, 60.73468185240223, 78.78356625956874, 34.99351570683141, 1.033833570057346, 0.1330774397619309, 0.06946792600736504, 0.05834619477090817, 0.0867384436330007, 0.03411179618729699, 0.05681454369257535, 0.06927682537465327, 0.023640676611854185, 0.022644697192816005, 0.06761938648959322, 0.016459215192064162, 0.08481570849976233, 0.16172868379902455, 0.16924759162770164, 0.19524404989375224, 0.17180722927854908, 0.12095658048506706, 0.22174313844692325, 0.14002961106598377, 0.10262195141084733, 0.1797295436863938, 0.16568879146249066, 0.24832301863258888, 0.23011343042937019, 0.22352429287087536, 83.57326661386799, 103.5266068673903, 89.28990148728894, 78.08276422562139, 52.025168711139315, 35.38013981234643, 59.3007182305859, 58.421620938085745, 63.68842271066482, 38.501279584823116, 0.42665578485015904, 4.603687832432409, 9.240630499778256, 4.503788986513692, 6.960358148620975, 2.016567482102302, 86.25401050813737, 111.75477458584695, 92.21792728670182, 94.02472788287749, 90.18164450122465, 96.7378548652895, 92.86424759895571, 97.18895096932688, 91.02504038041639, 95.3806677172261, 86.77454040896508, 79.39806046024447, 81.50089017806515, 81.58507993144374, 84.85851749297112, 84.1751229378485, 84.0533176545174, 88.29080320173695, 86.99658578441989, 85.55302804516208, 82.20726982239755, 83.49931424663913, 82.83455879457536, 71.8580961227417, 61.97888120528191, 63.370444005535504, 60.814035323358354, 62.056477454400834, 58.388461220648985, 57.44457814001269, 58.58782352939729, 60.27520756567679, 57.349543033107636, 57.26658490396316, 54.50789174725933, 57.24734567826795, 52.73827129794706, 55.18848965244909, 57.265463106093875, 65.21009052953413, 64.31003209083312, 73.35838702417189, 69.057476751266, 71.8738248271327, 68.36837122517248, 74.02588029061594, 69.92743492126465, 71.83041987880584, 68.87110925489857, 77.19027596135294, 70.68518977011405, 73.35156210007207, 73.50062785610076, 75.4600243414602, 72.9415802801809, 74.35677928309288, 68.18409827447707, 71.02746363609069, 60.76715515505884, 56.929476799503455, 72.54791552020659, 66.43399161677208, 68.21183727633569, 69.04312087643531, 63.69579676658877, 68.88206051241967, 68.80504869645642, 60.779141918305434, 55.98499751860096, 58.12603896664035, 61.24116966801306, 68.93966444077031, 67.23822655216341, 70.72752783375402, 68.42331578654628, 66.90362484224381, 62.15881993693691, 64.62675171513712, 60.801444515105224, 69.8200168917256, 74.01162639740976, 72.49814064271989, 67.87303863033172, 62.64304830181984, 54.065511149744836, 53.46814986198179, 53.50063885411909, 55.45402626837454, 55.68387323810209, 55.8503503953257, 52.38670925940237, 56.96926140016126, 56.96102834516957, 56.116459677296305, 56.703199186632716, 69.17871721329229, 71.04334923528856, 75.76949934805594, 73.17022308226555, 73.40085844839774, 77.63425688589774, 77.87823615535613, 76.92423728204544, 75.40165947329614, 73.75709595218783, 76.99433003702472, 76.63178536199754, 76.0390995394799, 74.80270570324313, 77.94973311885711, 75.20359546907487, 75.59077262878418, 73.75344030318722, 72.61643932711694, 38.57096833567466, 2.568425843792577, 6.01508213627723, 10.940723015416054, 7.845759670580588, 1.9074510662786424, 0.22596301120375434, 0.23376180159468807, 33.67120235197006, 95.99354590139082, 53.80022556551042, 76.79446174252418, 107.78698336693549, 141.79415241364512, 82.32449377736738, 22.37703161854898, 71.28998002698346, 69.28790815414922, 94.95854223928144, 42.09009139768539, 1.1873318495288974, 0.23347732250488576, 0.1129100449203003, 0.1555026565948802, 0.24593152195936252, 0.141214948267706, 0.1412476295785558, 0.19443847779785434, 0.12931761812538872, 0.24782955075704285, 0.11979112326497994, 0.12164727003583986, 0.15444007732214468], [0.08459211807818183, 0.08790538706366094, 0.04835912785042198, 0.08300565723930636, 0.10285207656242194, 0.08945343625401297, 0.10878329781154472, 0.07553935666838962, 0.1376269448308214, 0.01724959193398395, 0.13677905403798626, 0.13367958487041537, 4.0672657134071475, 76.78532262002268, 76.10543466383412, 66.24283882879442, 46.898779945988814, 29.145283352944162, 35.154458399741884, 74.6675878955472, 33.98858093446301, 59.01809184781967, 11.179520833876825, 0.504427835825951, 1.6293243775444648, 2.2110631100593077, 1.0023019426772672, 2.0114702394893094, 33.74671974489766, 97.23106938023722, 85.69464129786338, 89.15946698957875, 83.29062061925089, 89.92265039874663, 79.83368673632222, 82.74516797834828, 85.32361645852366, 85.34253012749457, 84.50056199104556, 84.92451529349051, 82.82672189897107, 81.82615664697464, 83.29000088476366, 85.7529120291433, 85.72046618307792, 79.05978741184359, 74.07577283920781, 75.87752926734187, 75.51516502134263, 75.64923947857272, 72.96931928203952, 65.50247969165926, 57.55746787594211, 57.89929851408928, 55.865384840196185, 54.50630318733954, 53.033496333706765, 55.02106328164378, 51.102870433561264, 51.376883291429095, 52.98613371387605, 52.72397033629879, 48.7873698049976, 49.8799499388664, 52.6918500469577, 50.38208392358596, 50.75479930446994, 55.65877006899927, 57.29418270049557, 58.35521913343861, 57.53900135717085, 52.67096734816029, 51.190131402784786, 52.565930197315836, 51.752736568450935, 50.95238870190036, 59.370948268521225, 58.975161506283676, 65.97687075215002, 65.35941908436438, 69.43149828141736, 63.39181307823428, 67.8360349901261, 57.27464145229709, 73.3740137469384, 55.239794254302986, 82.46165906229328, 25.063637495040897, 22.37322299711166, 84.25324086220034, 50.016773977587306, 69.94585437159385, 58.2088323562376, 62.11719966703846, 62.748775789814616, 64.12436277635636, 45.576627408304525, 50.07686076625701, 53.094395053002145, 61.83453798294068, 59.46821520405432, 62.6534112038151, 58.073918511790616, 61.80420237202799, 61.941787350562315, 66.7773166779549, 61.58702073558685, 68.47192964246197, 59.74098074820734, 62.152783409241714, 66.23732397633215, 67.74546746284732, 61.110488060982, 55.9455463194078, 48.74351770647111, 46.16512806184831, 47.99369781248031, 51.67514816407235, 49.6323581664793, 45.518431202057876, 48.061154734703806, 51.55114243107458, 50.905567369153424, 48.65608415296001, 58.147961093533425, 69.68431072850382, 71.03996030745968, 69.38239020685997, 68.49878218866164, 67.12777260811099, 68.49964511009955, 70.22508790416103, 69.58630638737833, 73.27601725055327, 70.01598635027486, 68.40717131091704, 72.69488673056327, 73.35214261085757, 69.85395323845648, 70.91811580042686, 69.48195565131404, 71.34482260673278, 69.65059403450259, 64.952641840904, 23.370265960693363, 0.8207817603984188, 2.237239782848666, 0.8580607632475515, 1.8919553751907043, 0.28217414574277017, 0.14041653143302088, 2.4897730062084817, 66.99561226752498, 63.34907101046655, 40.385178289105816, 76.68608665466309, 105.7079702808011, 57.084763434625444, 20.82828179482491, 32.23465584939526, 57.402385204069084, 57.59702890150009, 47.01718845675069, 5.3497672561676275, 0.267800712176869, 0.07209229808781417, 0.07353501784945689, 0.0024799664219420764, 0.07051928975288907, 0.14618708872266356, 0.21196640096604827, 0.06661208046059455, 0.03534198783698582, 0.07522703794341895, 0.16076817808132018, 0.07188566119199799, 0.04563835509602101, 0.06209442166671638, 0.07171224186857862, 0.15036053655128326, 0.03304838953960327, 0.04887698413503747, 0.02239702671255556, 0.04720150770980024, 0.09057660542067983, 0.048634011688972675, 0.15692967921495438, 0.241267578676343, 5.371277043896337, 93.89306960567352, 82.88994266140847, 76.4032288520567, 57.396360443484404, 50.28887271881104, 36.549437584415564, 56.993733067666334, 43.25737699385613, 68.51300470290646, 10.634466313546705, 0.6559071978253703, 3.6071366360110626, 2.764454873338823, 1.21898292533813, 0.6661181079764521, 39.29439460077594, 102.9226089292957, 87.26414634335427, 95.3746743356028, 85.9023464879682, 91.38278407435264, 86.13611975023824, 87.02809026164394, 88.61397512497442, 87.8540002146075, 85.98476333002891, 87.85684001061225, 82.51090049743652, 84.41110841689571, 83.93161435281077, 87.84304111234604, 88.89043161945959, 84.02560218687981, 79.41775075850948, 77.41636137808524, 80.24711239722468, 79.78286066362935, 76.72490242988833, 68.38921470026817, 58.28215714423888, 60.299408589639974, 58.8493985514487, 58.379580974578865, 53.386580251878314, 56.36694223650041, 55.997831513804776, 55.17282762835103, 54.79895514826621, 53.507185289936686, 49.718026653412856, 50.071561644154215, 54.68201360394878, 53.78079022130659, 53.40336015147548, 57.83551685271725, 60.146279258112756, 57.94843012286771, 61.25137175283125, 56.01242665321597, 53.0910296593943, 52.78360997476886, 54.14847712362967, 54.021384485306285, 60.345814151148645, 62.500325018359774, 67.6090003598121, 65.74495669334166, 70.47892801223263, 67.77868993820684, 71.54689527327015, 64.0752076333569, 72.75870369326684, 62.21051677580803, 78.11460602668025, 53.75043892091321, 47.06032668390582, 80.21046177033456, 57.50426092455464, 70.89824507313391, 59.80885736403927, 62.69569043190249, 66.89904351388255, 66.82193756103516, 50.90557521389377, 52.46424667296871, 56.95613714956469, 65.1685957754812, 63.586484232256495, 66.27447666660433, 61.3683525208504, 65.95721967758672, 62.76862690525671, 66.97253304143106, 64.75653117702853, 67.38005945759436, 63.36549789674821, 62.778405374096295, 69.41165108834544, 70.69403863722279, 67.1762687929215, 58.79230845359064, 53.12362063315607, 48.78117246012534, 52.09636365213702, 54.6911213474889, 51.75871818296371, 48.068128708870184, 52.225503767690356, 51.92469719917544, 54.27436951668032, 53.050609634768584, 62.03435920899915, 71.5849030402399, 71.35788409940659, 67.76497733208441, 70.5264671387211, 69.59722626593806, 71.87330707426995, 72.89426865116243, 71.7346748228996, 71.62205573051207, 71.4460511361399, 71.78396332648494, 76.96977599974602, 73.52539370136877, 73.21690713205646, 73.98670365733486, 72.21183115436186, 71.23855775402438, 75.76496508813675, 68.6549082110005, 31.672429192450743, 2.6908131087979963, 0.6587679539957355, 1.1620027764189629, 1.6121744268363523, 0.9832272113811587, 0.19770417272323565, 2.0647462000769954, 68.93851126393965, 73.30013198237266, 49.604611319880334, 74.73317776956867, 113.07400103538268, 60.934157909885535, 23.894639784289947, 41.26486393713182, 66.4484965416693, 64.84708693719679, 64.56934782766527, 7.25071503270057, 0.2635447873223213, 0.05223735603654096, 0.03179575151373302, 0.11077544817160215, 0.09135963154896613, 0.10075620555829617, 0.11676928178677637, 0.02705543309510235, 0.053946877409133225, 0.04093870445485077, 0.13235678085156027, 0.027775913890030597, 0.21967057949833332, 0.25432419903095693, 0.17738707664032138, 0.27020938454135773, 0.2936543103667998, 0.36664220354249405, 0.1569881164018185, 0.20300939288591185, 0.30611678357085875, 0.1917715418723322, 0.3315777157343203, 0.48894731327891355, 7.0146211981773385, 112.17057720307382, 93.45359940682688, 86.97305156338601, 65.05284663169616, 45.534744339604536, 51.77308582490491, 101.17283175068518, 49.75284161106233, 86.94408093729328, 14.042664747084341, 0.839368217895108, 4.366750198025858, 7.280314708909682, 5.776702540536081, 4.49583589069305, 39.95532966429188, 106.8730946510069, 90.57749794375513, 100.91417497204196, 86.95019983476209, 95.60140302104335, 87.89475364069786, 91.64202136378135, 92.7782770895189, 94.08123354757987, 90.9323077048025, 92.11996216927805, 86.9712237388857, 84.57746398064398, 81.45681842680901, 87.42282975104548, 90.14449181095247, 87.72116522635184, 85.11292242234754, 83.1747224253993, 80.92201109855407, 84.10202564731722, 79.650919975773, 71.61855697631836, 60.34754391639464, 63.485361606844016, 62.77793861204579, 59.97208287639003, 56.518035857908195, 61.469553593666326, 59.29488958850984, 57.626481979124016, 56.43956492024084, 56.69830406865766, 52.8241829718313, 53.04784044142693, 58.47213322116483, 57.03718900680543, 56.159797945330226, 61.472428691002634, 62.23029336621685, 63.90600442886353, 63.48564401749642, 59.79871019240349, 56.458458977360884, 57.35336342165547, 58.12477988581504, 56.74025381765058, 63.26594814177483, 66.40579761997347, 71.5254242189469, 71.06762086191486, 74.37577924420758, 72.15332508087158, 72.9420352751209, 64.9555600843122, 77.63603764195597, 66.68001836346042, 82.56000857199393, 39.45101091938634, 34.48539226285873, 87.12818914844145, 59.593911478596354, 74.6378484849007, 63.52047466462659, 65.07569051557972, 71.17806696122693, 71.02172128615841, 52.97742997446368, 54.291678936250754, 58.78888422443021, 67.25597135482296, 65.26092052459717, 68.55397778172647, 64.21454983372843, 66.37508546152424, 66.34327503942674, 72.15563927927326, 68.82921834145823, 73.8586304264684, 66.76438854586694, 65.75240135192871, 68.7745326565158, 73.75757448134884, 68.68372978702669, 60.26219314144504, 55.49508563933834, 51.835765300258515, 55.07505862943588, 59.18808344871768, 55.35406466453306, 53.26100557081161, 54.52180047189036, 54.25565981095838, 55.96131424750052, 55.01403047192482, 63.9579209204643, 76.73666954040527, 75.43681959952079, 71.50009355237408, 73.63470231333088, 72.515806997976, 73.66488887417701, 75.49203872680664, 75.5653948937693, 75.51854610443115, 74.06131498275265, 75.69702179201188, 79.18920993804932, 80.15335206062564, 77.2304645661385, 77.90053090741559, 76.86183237260389, 76.04798763029038, 79.24718256919616, 70.23477615848665, 29.939396612105835, 2.716101855039597, 5.732949481856439, 7.8374766053692, 8.255820428171466, 0.9434314564831796, 0.23676774674846282, 4.284643713505038, 83.76959693047309, 78.8588208536948, 59.09537822969499, 79.611586447685, 112.01718899511523, 67.29686598623952, 32.472186742290376, 49.24798157907302, 80.029326715777, 74.98267973622968, 79.17865876228579, 8.597389248109634, 0.4143112278994053, 0.09715332469392209, 0.1430461282331136, 0.2500878707055123, 0.18501964127344472, 0.28357415610263426, 0.30019400461066154, 0.16219641112031477, 0.11285899282102624, 0.3122453031040007, 0.30011353473509517, 0.19196367672374173], [0.10045399153304678, 0.045393854304547274, 0.10714353257489782, 0.07693865456648412, 0.17781498271130747, 0.14633860559232775, 0.05643243435770274, 0.06300003718464606, 0.038509979738944, 0.10368083047890857, 0.2581218654109586, 0.4197875921043658, 20.863379163126794, 83.94644875680247, 67.42395077982258, 65.66674463210568, 40.74800929715557, 15.484490759911077, 45.67143894010975, 38.75267605627737, 38.92392281563052, 73.8465024578956, 1.3728565266055446, 0.368943102657795, 1.5895286226464858, 0.3256148244104078, 2.175193279981613, 4.9729240709735505, 89.03723809026903, 93.17026307505947, 91.08649607627623, 74.87485378019272, 75.27768119688957, 77.564085683515, 75.4877241196171, 78.32787313768941, 77.2117470156762, 80.8583039622153, 84.4924662190099, 83.47556821761593, 85.6105770603303, 84.09760121376284, 80.6684769353559, 75.87342646814163, 74.0204752645185, 74.3471851656514, 79.32064856252363, 74.47073982607934, 67.37657639288133, 68.53674288718932, 67.09224377909015, 56.334998453817065, 57.29509661274572, 56.30291738817769, 57.5832417703444, 50.96220639444167, 53.41807296199184, 54.12741399580433, 49.26350632021504, 48.631263394509595, 53.658298523195334, 50.292273413750436, 49.47301187822896, 48.46091878029608, 48.49875396297824, 48.627089992646255, 52.07950530513641, 55.87381401369649, 56.09049750912575, 52.53586522994503, 50.403398083102324, 45.52475406277565, 53.67806334649363, 56.231518483931026, 57.99942877984817, 50.587596508764456, 54.61032444430936, 51.32226428677959, 61.51678677528136, 57.13129451197963, 66.80301604732391, 59.84668470198109, 65.40564421684512, 58.19624939272481, 78.00041798622378, 54.802222482619754, 82.22277887405889, 13.956107843306757, 8.1289307725045, 81.69638110745339, 50.00306921620523, 71.8013237368676, 51.83656546377367, 71.86627818692115, 62.716988901938166, 61.913671801167155, 45.09614490693615, 55.401909735894975, 58.37953782850697, 66.4157682849515, 60.911451308958, 60.973699323592655, 58.15710021603493, 67.41923609087544, 61.96389775122366, 58.8864492600964, 59.32557429036787, 65.94851201580417, 60.81553366876418, 60.62937798038606, 56.26993025502851, 64.34035201226511, 60.6856639923588, 60.53038520197715, 50.47604037869362, 47.190945533014116, 47.17256138401647, 50.81427812576295, 49.38184815068399, 45.526330855584916, 47.39609726013676, 50.497209410513605, 48.2025993254877, 48.46632380639353, 56.75606489181519, 69.93689567812028, 70.22172251055318, 67.37725888529133, 68.5906284086166, 65.44195359753024, 68.42017004566809, 67.06182972077401, 66.97705161186957, 67.90877142260152, 64.59501189570274, 64.86555345596807, 64.36092092144874, 67.22612996255198, 67.1474079931936, 66.89143411574825, 67.78444797761979, 69.73763142862629, 72.55710955589049, 71.65808662291496, 63.31875108903455, 28.22112979427461, 1.3938975910986624, 0.8116769586359301, 2.2842145783285943, 0.9239731296416253, 0.04321091740782704, 0.06599367896635687, 24.88788197117467, 78.61186842764579, 46.40491039522233, 46.548955517430464, 53.797377924765314, 26.834628812728393, 31.701688112751132, 21.91460378708378, 46.407593296420195, 55.516505702849365, 58.112091018307595, 21.500954551081506, 0.6501042963035646, 0.09096557124247474, 0.003383375846052302, 0.06387739937992827, 0.059729730409960595, 0.07474012778050478, 0.11097928118561545, 0.04903603164899734, 0.05510279300412344, 0.024297309723953088, 0.05356577931032066, 0.046449676681790626, 0.11973525247266216, 0.06611485109334031, 0.11910263238654983, 0.15250051123720987, 0.10723269754840482, 0.16352391891902493, 0.12324705314371856, 0.0924778441267629, 0.08482246539525448, 0.04575663524109029, 0.2980127990726502, 0.4895866289734841, 27.619812796192786, 100.68296693986463, 74.99392124914354, 73.77182837455504, 52.43093006072506, 28.020832000240205, 38.43476795381115, 38.92190279499177, 49.7252320474194, 79.46755701495756, 0.8619193336175335, 0.9533856965361104, 2.8607073858861, 0.6638472395077829, 2.19813693915644, 6.630374048986743, 100.61297616650982, 95.68574182448849, 96.45153753219113, 75.48961470204016, 78.97401302091538, 80.41182841024091, 80.04341586943596, 79.388944871964, 82.85014629364014, 83.73087529213198, 88.14394181774509, 84.36080794180594, 86.96386537244244, 87.06408193034511, 85.20896557838687, 78.93646024888562, 76.84406403572329, 78.01651539341097, 81.07517180904266, 79.53185250682216, 71.2440961407077, 71.390102448002, 70.58837782952094, 59.36459795121224, 60.34795184289256, 58.66923232232371, 60.411882554331136, 53.989385789440526, 56.92793923039591, 58.20639264199042, 54.573720885861306, 52.17254392562374, 56.50899087229083, 52.79307857636483, 50.988156795501716, 51.37215291300128, 51.36783830581173, 50.61681424417804, 52.82348086757045, 57.37426573230375, 59.62515315701885, 55.220276540325536, 51.855306548456994, 50.18340802961781, 55.43547345745949, 58.68142304881927, 62.896908021742306, 52.821966832683934, 56.85894473906487, 52.64359704909786, 63.63008922146213, 60.950027819602724, 71.12488746643066, 65.69709593249907, 68.35320734208631, 60.422669072305005, 78.34993254753851, 58.16536857235817, 86.71940757382302, 28.368914896442046, 17.5790766362221, 81.10700576536118, 54.82039482362809, 72.03089221831291, 56.19210650843959, 73.8362572270055, 65.49641178500268, 63.65208587338848, 46.21152185624646, 56.860874545189645, 59.85557671516173, 67.58396779337238, 62.02004255787019, 62.231317104831824, 61.35867995600547, 67.10287340225713, 62.17771791642713, 61.46457218354749, 61.498241809106645, 66.402691102797, 64.36854208669355, 64.78301894280219, 61.76925797616283, 65.3543435373614, 62.437210159917036, 64.94584437339537, 55.97990628211729, 49.52624628620763, 49.45602409301266, 53.21943236935524, 54.1817113660997, 47.564359095788774, 50.983045947167184, 52.26077372027982, 53.3860860332366, 50.229609627877515, 59.396730007663855, 72.01131959115305, 70.77575729739281, 67.51766404797955, 70.14772307488226, 68.52913348905503, 71.64289136086741, 68.87269389244818, 69.95865698783629, 70.2340465976346, 66.55023497919883, 65.3713470120584, 66.17480139578542, 70.16399306635704, 69.91697788238525, 67.9568753703948, 70.32819132651053, 71.64285213716569, 79.15114725789716, 72.2596291572817, 67.28472232818604, 36.66714399091659, 3.157257692467782, 0.4551157060890429, 1.0479956552866967, 1.1456714979102536, 0.3208344664064146, 0.09490054356114519, 26.227096819108535, 83.98563323482391, 58.993957504149414, 47.578546308702045, 60.19026471722511, 37.407256018730905, 35.8970493655051, 35.41208751739995, 53.42206593482725, 65.2829760120761, 68.06258324653872, 32.4451792624689, 0.8426750823855401, 0.1697591545000192, 0.07078102369221949, 0.012239029296794006, 0.08838229211828402, 0.06037443170263883, 0.1717669636972489, 0.11937037245520662, 0.16077729452761913, 0.022947526003624645, 0.04434147932296319, 0.02341561913189869, 0.24292209876641152, 0.3562414568037756, 0.17728575385145603, 0.3556033974934009, 0.2815287932753563, 0.3511238362519972, 0.2661867487815119, 0.3203713509344286, 0.23536081095376324, 0.23240414057527822, 0.4881765981835704, 0.6711779654987398, 31.869198814515148, 114.9126434326172, 84.915831165929, 84.5816687614687, 55.7058463558074, 24.684830673279304, 63.40523542896394, 56.586524363487, 58.781569004058845, 92.6763346887404, 2.399939207300063, 1.0673980270662615, 5.114270112206859, 4.690302100873763, 6.9567270144339535, 6.587754064990628, 101.79583749463482, 99.65903220638153, 100.1892189825735, 78.9698709980134, 82.80671781109226, 86.2003917078818, 82.57375255707773, 84.59453413563391, 84.45336803313225, 90.73685599911599, 93.18963958371071, 88.0157744499945, 86.43655761595696, 87.53089889403313, 90.70392377914922, 82.90534973144531, 81.89800662379112, 80.52361596015193, 82.81861043745472, 79.96884376771989, 73.71001182063934, 74.69312252536898, 73.78752569998466, 61.53075433546498, 63.374260471713164, 61.65684676939442, 61.74975987403624, 56.662163349889944, 61.60363197326661, 60.93935505036385, 55.77279336990849, 54.41222513875654, 61.09114685366231, 54.94159213958248, 55.96110243951121, 54.60224043938422, 55.388004933634114, 54.524173505844615, 57.64152034636467, 62.50145073859923, 63.517866288461995, 57.84699370784145, 55.29730404576948, 52.39924907684327, 57.85419517947782, 62.29332977725614, 65.68978071212769, 56.43710167177262, 62.01442572378344, 55.672537588304095, 67.91495307799309, 65.83442595697218, 73.77583703687115, 65.23240489344444, 69.2724383261896, 61.45626068115235, 89.07695601063391, 57.78636955445813, 92.75121273532991, 18.100577323667466, 9.874532588066595, 94.75797576289024, 53.13949838761361, 76.7671698908652, 58.14766299340033, 79.44381098593436, 70.76171521217593, 69.76130685498639, 46.09742795267413, 60.29420360442131, 64.21924491082468, 72.16321729844617, 63.4564890400056, 63.413550853729255, 62.86382675170899, 72.73123141257994, 67.77910570944509, 65.5294499089641, 64.95821945128903, 73.60168380122032, 65.72902010333154, 68.37738483182846, 64.24390485209804, 71.17923582753828, 63.25774254337434, 65.94874735801451, 56.87990588526572, 53.67763580814485, 52.53084459612447, 57.82515002835182, 57.15420507615613, 51.665738398028964, 54.81392683521394, 54.357037390432055, 57.059440612792976, 51.87913494725382, 61.46248548261581, 78.25945915714388, 76.95496512997535, 72.41489225818266, 73.7932288262152, 72.33451504861155, 78.34087971718081, 74.13773844319006, 73.91213940035912, 75.50641813585835, 70.75276436344271, 70.08742055585309, 70.44517993927002, 74.70561135199763, 74.13148618513539, 72.48682068240258, 74.66474809954244, 77.16566701089182, 83.21887262405889, 75.21656282486455, 67.78935878507554, 38.416132773122484, 2.3192572785962016, 4.753090912295926, 8.698221618129361, 2.3585714399814606, 0.5052429227338684, 0.17846909922457513, 36.689870203694994, 95.5177310205275, 63.66722229988345, 59.030219816392474, 67.46326861842986, 39.97518077973397, 43.167884196004565, 37.90653059559484, 66.85905887234595, 74.43153181383687, 80.11139838926255, 40.32634273652108, 0.9571316213377061, 0.2160238784046904, 0.13149054991381784, 0.3584958084167973, 0.18206317007782, 0.23692064257639073, 0.4404124563499805, 0.21059708008843087, 0.30411600706077396, 0.12249241057302683, 0.21092533344222655, 0.14185469297151412], [0.10490607320060653, 0.05426832790216131, 0.07815041414071476, 0.07166954012767923, 0.19809521464330537, 0.050736091835724736, 0.07409603169728672, 0.047032849622830275, 0.016089855475471388, 0.0962551708723749, 0.08643867342822975, 0.010097395072901442, 59.100002704128144, 75.34193746505245, 67.091671113045, 59.824158530081476, 34.853789114183, 36.86270552296793, 75.22013218172135, 37.699264710949315, 63.81541336736372, 56.355716413067235, 0.08642550437681137, 0.9517714573491005, 1.4120977564204125, 0.16671732578787113, 0.7187196660426356, 40.68600839184177, 101.08519031155495, 80.13011593972483, 81.03444976191368, 75.05608297163441, 78.31419975526872, 70.95613141213694, 72.39337413541733, 69.67206508882585, 75.97842047291418, 78.61910127824353, 77.05689184127316, 77.9905257686492, 79.27979315480879, 70.2975497707244, 75.67709615153652, 82.83811246195148, 83.0507755279541, 78.61529657917639, 77.64817345526912, 70.99367633942636, 67.05091768695463, 64.58986182366648, 60.039292689292665, 54.279660794042776, 56.911590791517696, 56.21517004505281, 57.97965218943935, 49.76074518695955, 52.27933437593522, 50.39620837857647, 53.79488721970589, 52.79892290792158, 51.86385731543265, 49.82181649054251, 47.37333966839699, 48.7910686000701, 49.76726416618594, 48.32334556887227, 50.77730194214852, 53.18969688107891, 52.383069299882465, 48.54472021902762, 46.323964441976244, 52.72839869222334, 62.96247828391291, 67.16632950690486, 66.04129960460048, 58.3825227522081, 55.8476008138349, 52.45959474194435, 56.67635840754355, 57.271527090380275, 62.20262496702133, 60.71282640580208, 66.33677174968105, 60.57810867986372, 71.72674379041119, 58.89195234544816, 67.59491120615314, 13.28233584280937, 7.109534711607042, 65.47398367235738, 56.74216008955433, 58.67689271127024, 56.82951911803215, 70.39976673741495, 56.3383363908337, 52.5341550765499, 45.62806537074428, 55.689948989499, 59.247138654032064, 65.02738652690765, 60.03575863376741, 63.06428732410554, 59.63825387339438, 60.29166190854965, 55.374484523650146, 54.181503480480565, 49.38545673124252, 59.042465456070445, 60.151609759176935, 64.42436525898596, 66.05083880885955, 59.557449125474506, 54.759256839752204, 57.660967457679014, 57.676492198821045, 53.49466116197648, 46.62947000995759, 49.64255632892732, 48.306275413882354, 46.16652834799982, 44.18773574213828, 52.09846996491956, 49.54497952615061, 49.24684801409322, 51.87754638733403, 64.37833232264366, 64.76947499859718, 65.50231495211202, 64.7800575533221, 62.44960877203173, 59.980672867067405, 60.14500448780676, 59.31629788491034, 61.63823512292678, 61.1813299886642, 60.222832156765854, 58.34329905048494, 61.3867288251077, 62.600553343372965, 68.8429231028403, 67.78702889719318, 73.32816123962402, 71.71995024527274, 71.8293216151576, 64.3529506652586, 63.271804240442094, 32.777662892495435, 2.8804967239979775, 0.4110052214274484, 1.6688449536600423, 0.2996029218118037, 0.12610853709761174, 3.5119152165228322, 61.45580568621236, 71.00143478762719, 49.556899609104285, 20.590892107256, 32.39428258711292, 16.453487796168176, 16.28622518431756, 37.977396057498076, 51.13780306231592, 57.42322083442443, 53.66391143491192, 3.8937111295038656, 0.2357222205929218, 0.05699753528460861, 0.09143093901295817, 0.05090490697071918, 0.04671496526908971, 0.27809393081453543, 0.02199075687977095, 0.06905322729219353, 0.08866208274998973, 0.015485345070520717, 0.02553717514890577, 0.034725972706632274, 0.03394378161418342, 0.04987699700699699, 0.028430733288968765, 0.23663748115781816, 0.11150807337535006, 0.07785859592859784, 0.028236583626318364, 0.05639603368998055, 0.03593296721397388, 0.026631045282908508, 0.13531708248680638, 71.35707609115109, 85.49786383105864, 75.6005314857729, 68.28459724303215, 47.517392635345466, 37.2146088077176, 52.13401840579126, 42.924760003243726, 73.96585233749883, 56.062083859597486, 0.1011616882357386, 1.0867959861793826, 3.7274977516743446, 1.3080418109893799, 0.47555067245998695, 45.22444171290244, 108.44414511034566, 82.61362737224948, 83.452237959831, 74.8414038073632, 79.87895088811075, 72.20063670989006, 75.99076809421663, 73.82471761395855, 79.53598668498378, 80.91401730814289, 80.10216512987691, 81.9523863638601, 81.94683228769611, 74.1880859867219, 80.83460500163417, 84.23719836819558, 84.83091185169836, 81.15632564790788, 79.86495587133592, 73.1084849757533, 69.1614430950534, 67.02793259774485, 62.26038579017886, 57.13039236684, 57.5541966192184, 58.18722794132849, 59.0250305206545, 51.91913135590092, 54.76657206012357, 55.312467928855654, 56.16547753733974, 54.81481721324306, 53.47913249846428, 54.15385469313591, 49.92983856508809, 51.57740269937823, 52.47694730758668, 50.69537539635935, 53.59386967074487, 56.6117726602862, 57.09107060586253, 49.73910547071888, 50.28395798898513, 55.988241318733465, 65.84045071755686, 68.72750343814974, 69.6648322382281, 60.81270171749977, 58.95756183132049, 56.56504154205323, 59.45949577516126, 60.505125138067434, 63.2728240566869, 61.85129434831681, 69.4948524044406, 61.78915223767681, 74.62871720713954, 62.05746196931409, 71.3344047915551, 18.88576719068712, 12.27874546281753, 69.33973050886586, 58.286856143705315, 61.848399639129646, 61.91820606108635, 72.95742665567707, 59.509709958107244, 54.59995369757376, 48.45134819707563, 58.81101815931259, 60.594692460952274, 67.0370795649867, 62.92105413252308, 66.2353471017653, 60.85714217155211, 62.01566911512806, 58.758764343877, 55.09654145086966, 52.947117897772024, 62.20819473266602, 60.36152324368877, 67.72996625592633, 66.26109353957638, 64.31384071227043, 59.42330014321112, 61.64451875994283, 61.66300096819478, 57.80449090465423, 50.196179266898866, 52.65053572193269, 51.61432789218042, 48.04809716440017, 45.97557167853079, 53.5987961676813, 53.13214394354051, 51.56045413786366, 53.809694167106386, 65.75457434500417, 67.98284146093553, 67.04893296764743, 65.62685412745323, 65.17270641942179, 62.87946916395619, 61.91280887972925, 62.14849625864337, 63.410875797271736, 64.6663833433582, 61.5696995489059, 61.028286949280776, 65.90055711807744, 66.04005229088568, 72.21269407579976, 70.2985538974885, 75.54350806820777, 74.53104234510853, 73.48318899831465, 66.08954475771996, 68.6568223276446, 42.59992107268303, 5.43211986941676, 0.20562415822379052, 1.5473278419625376, 1.0492855022030494, 0.10654357847787681, 3.177484129705737, 66.90652739617133, 78.34371951318558, 62.85452288966026, 23.38509644231489, 25.409119859818492, 20.777088980520926, 26.985198797718173, 49.30587184044623, 58.133377721232755, 64.56323285256663, 67.87317199091758, 5.728121534470589, 0.38566131685529986, 0.05506993549305105, 0.010065671371956988, 0.08803205970194071, 0.10499110896020167, 0.18111554995900203, 0.025235767431196668, 0.07353171601050323, 0.1086241353843962, 0.07255912908623297, 0.033122891590239546, 0.1542970487066815, 0.1621376981417979, 0.13739935543027618, 0.19283297201318128, 0.38673301257433434, 0.24635522986852357, 0.16620560969796874, 0.16984124848198506, 0.19759161908540035, 0.28535650562374826, 0.1485878550597737, 0.23146310881260904, 83.64875655020438, 98.40560743885656, 84.2972969239758, 79.31824807197818, 47.44557403749036, 52.23578822228217, 101.854751494623, 58.884864622546786, 83.96727654241747, 68.02602675653273, 0.401215598347687, 1.9095407089879437, 5.659387880756009, 6.90078862251774, 3.1884437222634596, 49.20019926563386, 112.17169115620275, 86.72129031150573, 85.52792487605926, 78.70025511710875, 83.22004933511057, 77.24158840794718, 80.5523120203326, 77.02809379946801, 83.87680315202283, 85.72496121929538, 84.59338095880325, 86.34545664633475, 87.35348224639894, 78.29591366552538, 84.85482262026879, 86.54180265242054, 89.09126481702252, 84.7009401936685, 84.18343051787346, 77.47749543959095, 71.98547901645784, 71.38433656384869, 66.60586987772297, 59.8514150804089, 63.74084518801782, 61.0547786374246, 61.98446273803712, 54.768384195143184, 56.42113370280112, 57.327028628318544, 59.5781788518352, 57.138919599594615, 57.64754902931952, 55.3803563117981, 52.56567132088446, 55.51012008420883, 56.7949983381456, 55.3034503998295, 57.0564046982796, 60.337769369925226, 60.520779317425145, 52.07141345547092, 53.39861016119681, 57.98866579609533, 68.36335059135192, 72.11962407635104, 74.58524165614959, 65.36650680726575, 64.07361515106695, 58.077130932961744, 63.6201185564841, 61.67790597484958, 68.71625408049553, 64.93770937765798, 72.83699420190626, 63.0757131884175, 81.09883154592207, 62.48420015458138, 82.04289113321613, 17.9539865832175, 9.214683040495842, 81.66645342303862, 57.10293185326361, 67.05902914847097, 63.28002552832327, 76.7714923427951, 60.36677137497933, 58.869998839593705, 49.27638738386093, 62.11695648008778, 62.3502355237161, 69.14252158134215, 64.14116228780439, 69.99922214015838, 65.1486034547129, 66.80138434133222, 62.87644501655333, 60.37275691186229, 56.24250112041351, 66.569791916878, 64.46374977788618, 72.03919195359754, 70.99859499162244, 68.07595852882632, 62.05092730060701, 64.25484042013845, 60.46067291690458, 61.66144378723637, 52.00185806520524, 55.592634985523844, 55.26744304164764, 52.7191379762465, 49.38235413643622, 58.15355047102898, 55.57965978499382, 54.249356562091464, 56.57815010316911, 70.88367739031392, 71.50974258299797, 73.84989138572448, 69.61555942412346, 67.87478800742858, 66.76043479673325, 66.9032169157459, 65.08668491917273, 69.52655300017327, 68.74360084533691, 65.40915081577917, 64.83763794745168, 68.51306746082922, 69.6713355279738, 76.13825705743606, 75.02118172184115, 80.57602667039441, 79.0105930451424, 76.28319648004349, 66.071745041878, 72.44394133167883, 40.90815574892106, 5.608488263622408, 2.0691468542621982, 6.876002184806332, 1.9959881541229065, 0.22180952762644138, 5.654494233669774, 79.55167616567304, 84.73004418034708, 68.59149917479485, 33.343347118746856, 43.944015349111254, 22.841748153009725, 26.715945736054454, 54.02592266759565, 71.56089813478532, 73.70603453728461, 81.07607395418229, 7.189393678019124, 0.4467290351467748, 0.3799119495576428, 0.24373857995435116, 0.20428220200682842, 0.20089541922413534, 0.4527442349541572, 0.13870893677155818, 0.1679261359235933, 0.16324258078971218, 0.14638382010161877, 0.14428933571663596], [0.018507502559993057, 0.0390152721816013, 0.07118132761529378, 0.0383447345736767, 0.08358904851540443, 0.04846100605303242, 0.16784301538380886, 0.003302962469470297, 0.1611072945618822, 0.0676837225534743, 0.3726605289886075, 3.9274731759102117, 75.57343575262254, 67.89612570116597, 70.28548456007435, 51.43327912976665, 21.776150003556285, 39.8016708127914, 64.86028963519682, 28.87778751311764, 93.32194112962293, 20.137652427919452, 0.21272338776578828, 1.384940736236111, 0.7561945422522484, 0.9480584436847318, 4.121537343148263, 83.56240949323102, 86.11896330310454, 87.2217062980898, 80.5250358581543, 89.03998374938966, 83.96653129208474, 72.85841818778746, 66.9496734680668, 75.17012980676468, 72.65069730820196, 79.17731731168686, 77.44337866383215, 83.0309126454015, 77.99863723016556, 82.40393746283748, 80.40211662169426, 76.386323436614, 75.69178150546166, 77.0036417438138, 75.34819756784748, 71.05978396631056, 61.77831080652053, 59.035083555406146, 56.26789454490908, 58.54636015430574, 55.59642007274013, 54.84989104732391, 54.637922240841775, 53.01900709829023, 51.780832505995235, 50.13441762616558, 54.58897498346145, 53.05113523237167, 52.450620358990086, 50.83149340844924, 48.23051875637424, 47.540824874754875, 48.01313707905431, 47.17815468388219, 50.25532468672722, 52.608503603166156, 51.32298208052113, 48.130059011520885, 49.25725798453055, 56.40990787936796, 66.93720817565918, 67.01585169761412, 67.60655280082457, 63.68743427338139, 57.54983886595696, 56.854061388200336, 60.18123542108844, 57.13671914992794, 59.84291922661566, 61.04869111891716, 64.59208580755418, 63.242296249635764, 64.32085391013854, 65.7769279326162, 48.46997553302396, 12.652364950026236, 9.310144705157127, 56.38668352557767, 48.16956904626662, 56.90764880949452, 64.86685568286528, 64.57905177147158, 52.34509683424427, 48.00699856973464, 52.44423081797939, 61.24595888199345, 64.40092517483619, 63.60255418285247, 62.58806451674431, 61.069558128233886, 54.893970643320394, 53.49844232682259, 48.77805417583835, 48.988861960749475, 50.14184659527194, 48.05844829928491, 49.90529237254974, 53.821178866970925, 58.63745720155778, 63.43955224560153, 63.9801372251203, 56.29200927672848, 54.965636268738784, 56.04389190673829, 50.57778666096349, 48.68656489156908, 46.02054165255639, 47.26599224152104, 44.087903576512495, 50.144388291143606, 50.84033835318781, 48.20340733374319, 46.17596164826424, 55.915053813688225, 59.353442730442175, 59.11874378881147, 57.92886141807803, 59.77896890332622, 56.86605599618728, 57.55491441295993, 57.800450863376746, 56.6127218738679, 56.25394659657633, 55.64620279496717, 54.36763955700783, 60.139772045996885, 60.073272182095444, 68.38153469947078, 68.25928226594003, 73.5148895940473, 73.32600393602925, 72.82322668260144, 70.43833148094916, 69.02795699334914, 65.10288430798438, 36.37337415449081, 0.6091548129916191, 0.5181313714673442, 0.4684656155445884, 0.3308643653027473, 0.06189805800996481, 32.33925761715059, 72.31614266672443, 70.38663464207804, 48.48247220439296, 60.60382766108359, 32.87148794820232, 17.819039398624053, 14.72529345943082, 46.548402463236165, 53.182362048856675, 64.58993242632958, 21.15774912218894, 0.5158000739832078, 0.14941337608521985, 0.18214422218020887, 0.11966464980956047, 0.0783612338765975, 0.05080572539760221, 0.11326215425205809, 0.07991216355754484, 0.11455056858399223, 0.0386956641300311, 0.04351056886896972, 0.029007143588856827, 0.07944506442835254, 0.07858837894614666, 0.08400254447253482, 0.08771381145643611, 0.12694846057603437, 0.11826401125759849, 0.01125119913805036, 0.1958149845802015, 0.19191651635112303, 0.3319782571446511, 5.786545238187236, 91.89022110354517, 77.15628470143965, 78.63747366013067, 61.32548101486699, 34.2854102196232, 28.71891583165815, 54.88523944731682, 37.944632499448716, 102.52499826492803, 22.440479878456365, 0.07423465530718527, 2.2786404000174616, 2.188515119975613, 0.70399631415644, 2.6656204606256177, 98.1473272077499, 89.49926976234683, 90.8093257104197, 84.3963053918654, 92.85709319576141, 86.12523909538024, 78.29465850707024, 67.66235243889594, 78.10403916143602, 76.88974395875009, 82.23394193956929, 80.6106141305739, 84.15949621508199, 79.57662243996897, 84.66963967969342, 83.14571257560485, 81.86373295322542, 77.46826218020531, 79.22050260728406, 77.97980200859809, 73.57688657699093, 64.71325958928755, 61.764453072701734, 59.20938584112353, 59.934714455758375, 58.55364399571573, 58.44086408615113, 55.822846735677416, 54.81464855132565, 56.633392764676, 54.28510896621212, 57.055667292687204, 56.84724038647067, 54.48610298095211, 55.15261173248292, 51.09559835926179, 50.553032582806004, 49.89037952115459, 50.33601176354193, 53.002666504152366, 55.985119112076305, 53.191132468561975, 52.04878530194683, 53.107997832759736, 59.763918768975046, 68.77866683467742, 70.43517005059027, 70.00909866825228, 69.07172279973184, 62.43153056790752, 58.31592875142252, 61.59541460775561, 60.11274691550963, 61.94789448092061, 64.0550466506712, 65.45817652056294, 65.70838059148481, 67.42814771590695, 66.41776084899902, 51.73924753742834, 17.740242904232396, 14.25373827257464, 59.11270726111628, 51.31087372379919, 60.85110564385692, 68.14469414372599, 66.89837671095326, 54.65398434669741, 51.61361009843888, 54.89102102095082, 64.97039841067406, 67.2405642847861, 66.11436551617038, 64.05313645639728, 60.95795492972098, 57.67717469123102, 57.05733430001044, 52.12663650512696, 52.64816268797844, 51.59386880936162, 49.45437669754029, 52.43574280892649, 55.7837446274296, 60.53773572368007, 66.17961806635704, 63.8183355331421, 60.79505889646469, 57.293935591174716, 58.7992863501272, 51.79624349840226, 50.8627546987226, 49.159728250195904, 49.13648428455476, 46.03699207305909, 52.66243227066533, 53.36025330328172, 51.12621245845672, 49.63342897353634, 59.05137315873177, 61.21296390410393, 62.786697264640566, 60.496386097323516, 61.79092907136487, 58.80674669819494, 60.70325974495181, 59.235300940852014, 60.52975762274958, 59.264071526065955, 59.170381792130016, 57.58872132147513, 63.47395535438292, 62.307564058611476, 70.39548350918677, 68.49508731595932, 77.53578970509191, 73.31359355680405, 75.80546748253607, 72.03858006385066, 71.41489967223137, 68.0876079682381, 44.30951749124835, 1.4080848040119296, 0.24575434114423492, 1.3672847997757698, 0.3625379028099199, 0.11524019327255026, 33.07780658045123, 78.74820217009514, 76.4558905939902, 56.72336016931842, 36.87552382869106, 23.847851791689475, 25.852373184696322, 23.564286001266975, 53.825811186144435, 60.752454111652995, 74.3945203288909, 27.699195684925204, 0.41977637657715433, 0.15692958728440348, 0.11858139382374865, 0.0875381091910024, 0.09064669480487224, 0.07701296509513933, 0.10802692388214412, 0.08679504220884654, 0.07083353135854968, 0.05059207879727887, 0.0506513242069031, 0.1057832668565454, 0.21230810682379433, 0.10107565656184189, 0.21062778489243603, 0.2819285073107289, 0.2861238805757415, 0.3263827815892235, 0.12739356532092058, 0.4030759969065267, 0.23211095872665607, 0.6668739609660641, 7.9500584352401, 107.20488009914276, 85.57795078523698, 92.04132649206346, 66.76780100791686, 33.11382962811378, 56.098832545741914, 92.92060421359156, 42.782899641221576, 112.54929773269163, 26.40622558132295, 0.29505946883751505, 3.701207820446261, 8.372818846856395, 3.4686823621872938, 5.3978648301093815, 99.82325400075605, 95.86908909582323, 92.66375956996795, 88.9050228365006, 95.69606550278203, 89.24840281086584, 80.58476571113833, 74.04418206983998, 81.35810805905251, 79.09662631250198, 86.30666440533054, 83.53469402559342, 88.8462108181369, 84.33925844007923, 88.60352593083536, 86.82087144544049, 83.63420455686509, 81.61517235540575, 83.06447244459584, 82.78858077141547, 77.05759786790418, 68.70958605120259, 66.13894308767011, 62.43502932210123, 62.44738478814403, 62.76136659806775, 60.533613312628965, 59.96346150675128, 58.10890605372768, 59.74567190293343, 55.52029471243582, 61.53542195597003, 58.85695303640058, 58.961029206552816, 57.56468895942935, 55.32721211833339, 52.752148643616714, 52.77045042284074, 53.205088261635076, 57.31096652246291, 57.59194550975677, 58.19095027062201, 54.505687375222486, 55.66362204090242, 63.1945296256773, 73.50304403612691, 72.5728068813201, 74.85870145982312, 71.03538682383876, 65.76667485698577, 59.3684301068706, 66.26987180402203, 62.605887766807314, 66.14521103520548, 65.95244223071684, 70.53504928465813, 67.01032115567115, 73.74932181450629, 67.90061289264311, 60.22998655996015, 16.956822026160456, 14.786784456622216, 63.43983857862411, 51.58163493679416, 64.85109167714273, 70.07522198461717, 71.54405547726539, 56.56299406482328, 54.62176207573184, 56.658437098226244, 68.73270450099822, 70.64052966333205, 69.97746867518272, 68.65992100008073, 64.40480439893662, 59.67760309096306, 60.24771567313903, 54.54389910544119, 56.17960591470042, 55.39342957158243, 54.11016733415666, 55.51982795038531, 60.398546495745265, 64.89879162080827, 71.6843351241081, 68.6282439385691, 63.532665391122144, 61.84350844352477, 61.93158134337395, 54.94412991308398, 53.73463569148895, 51.94175558705484, 53.370302415663204, 49.59550357634022, 56.67311852978122, 57.23018138639389, 52.7230054332364, 50.78162439407841, 63.129763449392016, 65.10885415538665, 67.22722038145989, 65.05889492650186, 66.6094627688008, 63.17665930717223, 64.60500217253163, 65.1261596525869, 65.87716410236975, 64.34817714075889, 62.56431848772111, 61.540952497913, 68.96410080694383, 67.36219698382963, 75.69175797124063, 74.8904412792575, 82.63945225746401, 80.02346669473957, 79.66474240826022, 75.01045011704969, 73.9596079241845, 70.00353674734794, 43.44642346905124, 1.728323039508635, 3.7698838643489347, 3.27473365972119, 0.5916886211883637, 0.207830828524405, 41.87041513381466, 88.3904863172962, 84.39575626004128, 67.75393978241952, 80.80843494784448, 44.31987254850326, 27.0775019737982, 25.78364149216683, 64.41026041584631, 71.07427320172711, 87.26222438196983, 33.908807769898445, 0.7089873463396104, 0.30153024581170856, 0.2870686814909981, 0.1792578633514143, 0.2598606704944565, 0.17437201504024769, 0.16976859270324632, 0.30052143058949904, 0.2488151841586636, 0.16443542565309233, 0.09853645047593503], [0.014121885723133963, 0.010941854749445715, 0.08341539170472853, 0.11195143910064814, 0.10046279388329676, 0.06539622997684826, 0.04323928181322352, 0.11762884775957755, 0.08472209255541525, 0.21899544153242342, 0.7814380586627991, 18.84950487844406, 83.63808770333567, 63.26727390289307, 63.69423566326019, 49.68561610867901, 32.61429029126322, 50.95039221548265, 44.394389737036924, 53.8821638784101, 90.50626770142587, 4.165354630639476, 0.109651796369543, 0.7378482686415796, 2.9483179363512226, 1.6813049753827436, 26.04445557440481, 102.98253490078835, 81.39338585638231, 79.42255173960041, 88.17705446673979, 93.72829083473452, 85.16847887346822, 79.3237707691808, 64.36595724474999, 71.41626465705134, 72.51873308612456, 76.43220732288977, 77.09100077229162, 78.7994675482473, 78.21206123598161, 73.27797843563941, 75.44251488101098, 80.7292030703637, 76.44912842781314, 76.38058893142208, 69.252575443637, 61.03180139295517, 56.1243946321549, 55.434481097805886, 53.54301614146079, 55.282069560020204, 53.92626700862762, 55.946754409420876, 53.93026390383321, 50.78034962377241, 51.09480211811682, 49.49388673228603, 53.92362725350165, 51.747406067386756, 49.71429647937898, 50.730472764661236, 46.70465400142055, 47.1036845637906, 48.12790563029628, 49.029062332645545, 48.51572213634368, 51.487972659449426, 50.69389666280439, 48.73046405853764, 50.798023823768865, 59.954004672265825, 66.30177636300364, 66.82300444572203, 67.98878777411677, 63.9816394928963, 60.8600329583691, 58.960276111479736, 62.12358920804916, 61.26246813804873, 60.1266085716986, 61.81402790930964, 67.35825892417662, 60.62303158544726, 62.45186413488081, 61.16603274499217, 41.44565382311421, 24.114353310677316, 18.509447151614776, 50.26582487167851, 49.8112339358176, 62.37701746725268, 61.579693748104965, 56.87391250364242, 46.629093462421054, 50.69460661180558, 56.97132064450172, 64.25322440362746, 61.234595775604255, 59.52623882601338, 60.842166562234205, 61.723570208395685, 60.825461187670314, 56.96424861108103, 54.70740310607418, 60.23838435449908, 55.114611810253514, 56.618428922468624, 52.66721756227555, 47.12324150146977, 47.982958362948516, 54.65766745228922, 57.150066975624334, 60.104490326296904, 54.37136580867153, 56.36891518869708, 52.7143487622661, 49.235818309168664, 46.54721790744413, 47.64862337420064, 42.22508761190599, 47.28957745336717, 48.39569368670064, 48.00051096946963, 49.48203725199546, 51.723675727844245, 53.83544452728764, 57.147854758847146, 55.83380976030904, 55.91547742966683, 55.636596910415165, 55.693824291229255, 55.909546805966286, 57.951065955623505, 54.29926480016401, 57.44964191990515, 56.81979164000481, 60.05792786998134, 61.56442396102413, 67.75275522662749, 68.48563440384405, 73.2839875067434, 71.3349146996775, 76.1742251919162, 65.91004925389444, 73.72852540785267, 60.65615207918229, 64.42061939547139, 20.535559231235137, 0.3195475919112083, 0.7550257372279322, 0.2394912046410384, 0.0636958556940719, 4.863063385409694, 67.27043705601847, 68.14149348966538, 59.81979685444986, 55.58024814051967, 54.935363415748846, 15.14175013188393, 20.198392291222852, 31.964906607904744, 54.01508908117972, 55.58162097007998, 50.4165497902901, 1.273452512198879, 0.13636124500584218, 0.13417928870166504, 0.034524434125952186, 0.048546302282521804, 0.03406466645819526, 0.05810788780030224, 0.03860723077049179, 0.06482637547437223, 0.12800381563964391, 0.08516442406201556, 0.04388742284068177, 0.018255149367295446, 0.02249784579861068, 0.02598201367823828, 0.031158096314738357, 0.07660958149860944, 0.009233416433656409, 0.1559514155791652, 0.0895751063381472, 0.10002977034497647, 0.9064071625471116, 25.006088479872673, 95.77563470409763, 67.78688769186697, 75.34614224587718, 57.11264756418044, 35.94381186269945, 39.85138293235533, 48.95572969990392, 60.95593490908223, 98.21593730680405, 3.242973247843404, 0.290729294741346, 1.5915146902684243, 6.205723545243663, 3.88973948455626, 37.02146737806259, 108.68988944638161, 84.08453187634869, 85.26108603323661, 88.88086103623914, 96.1059610305294, 88.35858960305491, 84.7042271398729, 68.0101490020752, 73.402662738677, 75.29576332338395, 80.70304086131435, 79.44138696116786, 81.35251475918679, 79.1788548807944, 78.0000179044662, 77.57849647152808, 84.11833486249371, 79.78297833473452, 78.08717296969506, 72.66011884135585, 63.266148182653616, 59.46536364093904, 56.38178840760262, 55.476273951991914, 56.76027751738026, 55.94826059956705, 58.35485827538275, 56.652353502088985, 53.097689843946895, 53.93303701954504, 53.90456061209402, 56.60278258785125, 54.56626446016374, 54.56067508266818, 52.72368400327621, 48.976129947170136, 48.27415512454126, 48.65206372353339, 50.295003383390366, 51.082238766454886, 54.80583498554846, 54.19950323720133, 51.472012535218276, 53.042674679909986, 63.30923541899651, 70.83288269658243, 68.3827349447435, 69.72913557483305, 68.96332417764972, 62.64112241806523, 61.00688649762062, 64.24878035822223, 64.23282807873142, 62.964729724391816, 64.24177892746465, 68.8335015696864, 62.858759049446356, 66.6622970950219, 66.75263712483068, 45.570532045056744, 26.9492777316801, 23.809449826517415, 53.53469287195514, 54.310486701227006, 67.14962805471113, 61.80979567189371, 60.084290119909475, 47.34737750022642, 52.33828367725496, 58.99084706460277, 67.77820356430547, 61.062411569779925, 60.73773737876647, 64.89658332640126, 65.21789604617705, 61.25377224337671, 59.900091694247344, 58.72648715972901, 61.39187105240361, 58.88730433679397, 60.78312704640051, 56.68110839782223, 50.778058959591775, 50.87944830617597, 57.5159417429278, 61.35157262125323, 62.796358062374985, 57.73910107151155, 58.55686818399737, 55.57574133719168, 51.127310722104966, 47.90492280837029, 49.978770132987734, 45.285403190120576, 50.12250146558208, 50.7365289042073, 51.79642392743019, 51.198819452716464, 53.95701839077858, 57.36478536359726, 59.00364183610486, 58.53679741582563, 58.482809912773874, 58.71313148929227, 59.242745599439075, 57.778293394273334, 60.461853550326445, 59.19320606416272, 59.39731444081953, 59.30100456360848, 62.534265287460826, 64.91494394117787, 69.84584177694013, 73.23086292512956, 74.78149352535125, 73.18450050969278, 76.59296174203196, 66.94708470375308, 75.00237787923506, 65.02656282917147, 68.4976682355327, 26.756506966006373, 0.36846359290422936, 0.2398567051897126, 0.302695649405641, 0.1002481590295511, 4.149922065196499, 74.05798096810618, 74.74527435918009, 69.92808603471326, 51.1273067997348, 39.27679492581276, 15.462624526792958, 27.587272813243253, 40.19938738115373, 59.92482616055397, 63.74666206298336, 62.27474950974988, 1.8262504041194918, 0.09192521128082469, 0.07709665253998772, 0.03539270668801281, 0.07844787842083363, 0.08501420954182264, 0.14924486738539514, 0.021682149850793427, 0.05588096596540944, 0.010918083041155291, 0.056940461734249714, 0.15633441357602998, 0.09434057159289237, 0.28180219473377355, 0.19008702177914882, 0.11881862827126058, 0.22257933873803387, 0.12501642513539524, 0.30822214640436635, 0.2900964448288564, 0.2861266997793029, 1.1412978100199853, 31.539902110253614, 112.04334335942423, 79.10065066429877, 86.17513948871245, 64.09643942309965, 47.4647936513347, 70.2818367558141, 67.05315343795284, 68.91388662399785, 111.33049964904787, 5.100294707282897, 0.5217432615257079, 1.8728394590077864, 7.953767036238025, 5.799106138367807, 40.78875880087576, 112.98795992328276, 89.06455347614904, 88.47101257693383, 93.3572816848755, 100.37158566136515, 93.84040786374001, 86.75441080524077, 70.14787212494882, 77.35019099327826, 81.39706503960394, 83.04540188081803, 84.01488627156904, 83.71168705724901, 84.3783252469955, 81.93163702564856, 82.47344186229091, 88.86991762345838, 82.15965224850564, 83.57459237498622, 76.95221947085473, 66.11843693640925, 60.50530556709536, 59.153217500255955, 58.421852357925914, 59.71588150147469, 59.236665925671986, 60.482092980415594, 59.14352924593034, 55.882302022749386, 57.402314601405976, 55.748592345945305, 60.34590828803278, 56.02695118996405, 57.04569662770918, 55.51767064679054, 53.13337164540445, 51.85042319759246, 52.74808899048836, 55.466538629224225, 55.07079893542875, 57.93505091820994, 57.38675848130257, 53.07892130267236, 56.68331276985907, 65.17578155763688, 73.56625695382395, 70.9078235010947, 73.19911526095483, 70.24956349403628, 67.35963959847727, 65.409033144674, 69.48005722415063, 68.45257666803175, 65.54646515077161, 68.75933739446825, 74.21182417100476, 66.29883458537441, 70.64096896879136, 66.59312217466294, 54.34910243557346, 30.448339831444528, 27.954543944328066, 58.54428914285476, 55.44793090512676, 68.82638639019382, 65.51791421828732, 63.01011546965569, 50.51411874832646, 54.86465092628233, 62.62538194656373, 70.65036696772422, 64.6468303280492, 64.03754503496232, 67.41238763255458, 68.52228503073415, 64.40809918988136, 62.59745859330701, 61.02765152531286, 65.97960856653029, 61.777479264044, 64.06993596784531, 60.480378904650294, 55.140299412512014, 53.13897671238069, 61.22178531462147, 63.91645754537275, 64.47772518281015, 60.345441525982274, 62.918998810552786, 59.099551631558334, 54.71583620194466, 52.24296223732733, 53.81620530159243, 48.63851193458804, 53.26022109677715, 52.855228531745176, 54.02015286107218, 54.35657062838155, 57.449488947468424, 60.63985463111632, 63.2901373986275, 63.37403297424317, 63.09110849134384, 62.89714728632281, 63.09732544806696, 63.225018209026715, 65.78485896510463, 63.534324553705034, 64.05002601685064, 63.19468652048419, 66.53383947187855, 68.17575147075038, 72.42960114632884, 76.85119490469657, 78.4961820417835, 75.67854742850028, 81.52100409230879, 67.31916073829898, 80.15553289844145, 66.69999107237786, 72.18329983372843, 22.817847190364716, 1.6570612956439297, 3.3481270892004815, 0.7305551116024295, 0.1319169238089554, 6.838645531285194, 85.65205220253237, 80.53470057825889, 75.85881956161992, 73.33322109714632, 74.32176820693478, 22.84761994115768, 33.46221454681889, 47.99399983498358, 72.90208201254569, 70.3154436234505, 74.70645858395484, 2.4895960092544556, 0.20777605323781892, 0.24258960128551532, 0.3342174095732551, 0.17431924690402326, 0.1480965015868987, 0.2340110099964565, 0.15104040894056522, 0.15750409194057988, 0.23504009590514247, 0.14092274701162694], [0.123449407608038, 0.09145546914829362, 0.02575304914986895, 0.04684803857197685, 0.02953322574255928, 0.021293116996305126, 0.047124952543526895, 0.054851209729789734, 0.039786829973661134, 0.037561348384065975, 0.038025302722329096, 40.82702936664705, 73.69161590453118, 64.58766921874016, 57.08966639734084, 31.756760151155536, 79.60962526259884, 69.11296259972357, 34.18634291618101, 75.73401758747717, 58.00006812618625, 0.49898916314686503, 0.09202498657208297, 2.014993018200321, 10.257686376571655, 6.382460151949237, 71.26069561127694, 98.52455723670222, 78.10317623999812, 93.99410201657204, 83.14994873539095, 87.54725517765169, 82.53301482046805, 79.42358724532589, 71.11953735351562, 69.04811013129451, 72.88443919151061, 77.3181373842301, 78.01830399420955, 79.18803322699763, 78.92956472212269, 77.10057135551207, 71.52078013266288, 70.09611252815493, 64.17707550910212, 60.17511652361963, 54.85173848367507, 55.547990568222545, 55.33943422379033, 54.62004015522619, 56.16974507608722, 53.7243983053392, 54.8621053080405, 55.019282525585545, 50.728386063729566, 51.237560702908425, 51.24869238945746, 52.306712519737985, 53.82972571157641, 49.60818459910732, 48.20089701683291, 49.87211696563229, 45.414225593689956, 49.52210818567584, 45.277970298644036, 45.07947483370381, 48.196413747725956, 48.13907654054704, 50.316133191508634, 51.233155881204915, 50.46766611837572, 60.05884570460166, 66.44852792063068, 67.23937972899407, 68.79601155557941, 66.15290672548356, 64.91719538165678, 60.50793355511081, 62.06548713868665, 63.42150149806854, 63.69815018869216, 63.76049234021095, 61.455558576891505, 60.37249019069057, 66.64346971819478, 54.84922032202444, 33.87110987017232, 43.89888455790859, 32.58801433347887, 38.757508416329664, 55.54097737035444, 61.25817706508022, 58.01509080394622, 51.31567078251993, 47.01185011094617, 55.13449038228681, 62.159988803248254, 64.2256893650178, 59.52515232947565, 61.602015956755615, 59.74925694927093, 62.72896782044442, 61.04097973915839, 62.000030625251036, 59.390615032565215, 59.93776998212261, 61.9436308645433, 61.973982164936686, 63.64964223677113, 54.93916419244582, 45.34820033657936, 49.56190063107399, 52.80852879247358, 55.77494282876292, 54.88293701602567, 53.047542341293834, 50.56739238000686, 49.5117845073823, 47.38415364296206, 46.65035270875501, 41.72403227898383, 43.30513185070407, 48.95961676874469, 49.60081838792371, 49.43064635799777, 47.53607096210603, 51.455326772505245, 50.918381752506384, 53.64770812373008, 51.40214335533881, 54.548688319421586, 53.11495611744543, 55.3059293377784, 53.00884031480359, 57.485002087008574, 54.92920137220814, 57.8956546321992, 58.70654190740278, 60.31889884702621, 60.77392516597625, 65.80783228720388, 66.014588263727, 72.7415080224314, 68.84006761735486, 74.47188515816966, 68.73328501178374, 78.52797677440029, 65.81505729306129, 56.03336818756596, 4.543386784292037, 0.5369284724996937, 0.36801846517670544, 0.08408984019150657, 0.021931436776574102, 35.28386523646694, 74.43137491902998, 71.17522716522217, 48.5406134974572, 49.9609508052949, 42.13699510020595, 14.760383963584902, 19.296602126090757, 42.063556563469675, 50.36508829362931, 64.48915496949228, 15.969204518102831, 0.4629184341719074, 0.18172046830577238, 0.062355703614171476, 0.12584076638543798, 0.05481375952161128, 0.035530330553170175, 0.1395892330835904, 0.06302069474552428, 0.033697174080917915, 0.04839868096995258, 0.1343554123154571, 0.046940321523335674, 0.08004209973038205, 0.043022092056250384, 0.02047882107416949, 0.04960477915442279, 0.08076965343207121, 0.011826195048108216, 0.021741456547451597, 0.041826454802386226, 0.02395671086325761, 53.61286963185957, 86.75496778180523, 71.9473300441619, 70.38763876884215, 50.946532603233095, 66.14386958460655, 63.314840485972745, 41.63839517101165, 83.75596277175411, 61.559764185259425, 0.3199783478292727, 0.1016577837928649, 3.7224344620781564, 13.712341362430205, 14.253914779232396, 82.4141356252855, 97.63051571384554, 84.94575100560343, 93.05438057068856, 89.83884503764492, 90.24852091266264, 87.61597510307067, 79.9719581296367, 72.38182667763003, 71.93907737731934, 75.7771401251516, 81.4518605509112, 81.51933316261538, 81.97868977823566, 81.03047247855895, 79.74297800371724, 74.95811785421064, 70.89995522652903, 67.22691443658644, 60.63039387426069, 58.464974895600356, 58.60753736188335, 59.3433661614695, 56.299591218271566, 57.85710557814568, 55.420097766384, 59.36225629621937, 58.35126146193474, 54.756722988620886, 54.187237985672496, 55.03389335447743, 53.428404485025716, 57.6700516669981, 51.437566280365, 50.046482009272424, 52.020854103949766, 48.43070476285873, 49.56341074359033, 47.622723963952836, 47.2422658243487, 50.10854567250898, 50.92045668632754, 52.534088396256976, 52.49069129267047, 53.4508639766324, 63.30178291566911, 69.00577991239487, 68.06234005958804, 70.50836932274603, 71.04071340253277, 66.54228825722971, 64.07736493695167, 65.6619240391639, 64.56512343498969, 68.13395469419419, 64.85977580470424, 64.58294276268252, 61.72037347670525, 70.63004909023162, 57.90913581848145, 39.8238871174474, 50.49716234207154, 39.71088363278297, 39.739799345693285, 58.91169363452543, 64.43391230798537, 59.1997407328698, 53.85276179159842, 48.49991498454925, 56.37257083769768, 63.96422416933122, 66.53090553898966, 60.916471942778564, 64.5074292921251, 63.505475521087654, 64.3917585957435, 63.84799649638515, 63.22361400050502, 62.10605229100874, 64.82850274732037, 64.55649029824042, 64.92087848724859, 66.91947906248032, 58.739050511390936, 49.41312120806787, 51.96754517093782, 56.58645768319407, 57.327683664137325, 58.468348133948545, 56.84103519685807, 55.21551086056618, 52.46705116764192, 50.611609258959376, 49.151632478160245, 46.128457823107325, 47.45282649993897, 51.88790536695912, 50.44817193861931, 50.806452997269176, 49.488724893139256, 51.10371374314832, 54.27551484877064, 57.16542697721913, 54.5061109912011, 57.700489259535274, 56.1625789057824, 59.848033997320364, 56.260689150902536, 60.54996567387735, 57.29073101474393, 62.581996610087735, 60.379703429437455, 62.224625541317856, 63.96219238158196, 68.19147233040103, 68.496946519421, 76.27324934928649, 69.99927705334079, 76.30373401026573, 73.3325856731784, 81.5999770933582, 67.87487429957237, 63.7734636183708, 6.6605488427223705, 0.7247260405171303, 1.226853161088882, 0.1712224743659458, 0.05689844947248217, 35.591532030413234, 81.06173376883231, 76.15539781508907, 60.476633041135734, 40.609475105039536, 35.50501631152245, 23.060745846840646, 30.095485371928064, 51.53087554439422, 56.111721454128144, 74.10492389432846, 21.921089426163707, 0.5582109466195107, 0.1789847683281668, 0.07228758922147174, 0.17829626978885743, 0.03543246282084334, 0.036976195105742064, 0.12569072806546766, 0.039390505877353495, 0.014913500654661368, 0.11992469835545748, 0.2392319451657034, 0.15828680397281725, 0.14300128144602622, 0.15465927039903982, 0.162428290613236, 0.16183933753880764, 0.15115303918719292, 0.10058742872769795, 0.09672960912388179, 0.15329584839843935, 0.06596215444827272, 67.87761211395264, 95.7313197658908, 82.45182960264145, 77.66854624594413, 46.570508941527336, 89.5360694393035, 83.06916359932193, 51.265193800772394, 90.6197104915496, 70.77185061670119, 0.9515650426187824, 0.3225735166380483, 8.229749414228625, 22.666771219622706, 19.069367454897975, 81.66008349387877, 105.69171597880703, 87.22889208024549, 97.34204892189273, 91.3688910392023, 93.58681878735943, 91.30054766131987, 85.24922478583552, 75.4313047470585, 76.679073456795, 79.09908171622985, 85.96587319527903, 85.2663576987482, 87.13853636095601, 85.16468201914142, 83.28101081232872, 76.90315061999907, 75.75450804925735, 70.10619301949778, 66.35767798269949, 58.90650041641728, 60.962289148761386, 60.280275267939416, 57.67036545661188, 61.32677931939403, 57.857968499583585, 60.95928461320939, 62.30417120841242, 55.921576715284786, 55.83460992382419, 57.499605071160104, 57.58876054517685, 60.17439872987809, 55.9169561632218, 52.99656329616424, 55.470778711380504, 50.12772998502178, 54.5745288941168, 50.28797449604158, 50.397389011998335, 54.421270124373905, 52.544874914230846, 54.6136349247348, 55.18971343194285, 55.82576105671545, 67.29768968397572, 73.51590156555176, 71.72903445459181, 74.45878444179412, 71.67816131345688, 70.67723520340459, 66.6479019964895, 68.01238475307342, 69.07921452676096, 71.74264507908975, 68.06842757809547, 68.07952004094278, 65.72177940799345, 72.68182523788946, 61.347022671853345, 44.25450232721145, 52.83700127755442, 45.01340250815115, 44.62633517480666, 60.62630676454114, 70.144302768092, 62.23241536848007, 57.43323464547434, 50.38980707045525, 60.372909884299006, 66.9468415168024, 69.18049796935051, 62.77057240086218, 66.14610533560476, 64.55062243246263, 68.20366305689659, 67.2181518616215, 67.52987830869614, 65.42360082749398, 66.6601868598692, 65.89064136628183, 68.60719650022446, 69.26340118531259, 62.76949767143496, 53.51049577036212, 54.038893945755504, 60.31079915262038, 61.23098327267555, 64.44539700784992, 59.825319551652484, 56.761073758525235, 56.15948415571644, 54.51646604845601, 52.78406889207902, 48.20906339153167, 50.580375425277225, 53.94610635695919, 53.098156605997396, 55.237695786260794, 51.77034801052463, 58.34819416845999, 56.76389394267913, 61.8397625800102, 57.94817124643634, 60.94385008658133, 61.31347463976953, 63.85714738599716, 58.04439875387377, 64.51730189784881, 62.2612722458378, 66.17869238699636, 65.43337537396339, 67.02133517111501, 67.35633696279218, 71.14043574179374, 71.57873707432901, 81.38165012482675, 75.13984910903439, 80.87221268684634, 75.93062246999433, 84.1403393591604, 73.11931071742889, 66.342984784034, 5.3378182457339385, 2.3412987926313957, 2.7564461288913606, 0.21548173330243559, 0.21085434773516273, 45.87058551849858, 87.54928696540095, 84.56083313111337, 67.80090624286284, 70.12169422641878, 59.04684674355292, 26.529888106930642, 32.1483931233806, 60.63482615255541, 66.69129910007601, 85.84234991381246, 26.70235864577755, 1.0247263168134997, 0.3341966026252316, 0.1859364646577066, 0.277421458834602, 0.4269375213451924, 0.10053647621985405, 0.2344181704064531, 0.1378227569042675, 0.05615037227530153, 0.410580808717397], [0.009111999158537196, 0.038069846904686386, 0.07134891700960937, 0.118673125191802, 0.009462459486037975, 0.15259081768172403, 0.10802710008236671, 0.08580156406688114, 0.11738803568145922, 0.15592316225651773, 0.7152420558756398, 55.73957873928932, 73.85732035483085, 61.1227297782898, 38.87374785638625, 20.939988936147383, 86.73377913813438, 66.2273140876524, 41.67192751361478, 94.4157724995767, 29.22570763095733, 0.1285599878117923, 0.1896644630018742, 9.384546183770704, 11.624165619573287, 21.438669273930213, 103.72987193446006, 84.02249566970333, 83.75777490677373, 98.9755827380765, 109.22710510992236, 76.81913345090805, 89.48313313145792, 73.18934855922576, 72.38381139693722, 67.77500291024485, 74.33194283516177, 74.41020196483981, 77.580520414537, 73.31228348516649, 70.63252018344018, 60.72538583509384, 59.8978167195474, 57.08038214714297, 57.727463399210286, 56.23573895423644, 58.64196792725594, 56.775190368775405, 56.21573486635762, 53.85181257801672, 55.57088152054818, 53.373938452812936, 55.04974365234376, 53.589660967549975, 49.97788367732879, 50.385123760469504, 50.454243767646055, 52.936955036655554, 56.2238149489126, 50.51802542901809, 49.45036411285401, 48.068183622052594, 46.005711170934866, 45.68713234316918, 46.40249029282601, 42.71952982871763, 45.2337141959898, 46.92267502507856, 50.75583873256561, 49.16729057988813, 54.257805347442634, 60.21577973519603, 64.7460662934088, 64.71576990619783, 66.83808988140476, 58.947853965144006, 57.96856364896221, 60.828599083808164, 63.31917862738333, 65.50970469751667, 61.01222484342514, 60.86382981269591, 62.835330732407115, 62.89137747979934, 56.43803911824381, 44.91373115970243, 39.09650318084225, 56.93876889444167, 47.280960006098596, 30.92296427296054, 55.04230291612687, 62.90093629590927, 56.13387107849122, 50.87823629379273, 48.326683505888916, 50.87707134985155, 58.49079978081488, 60.82771262814922, 65.07343907510081, 61.114171166573804, 62.656604013135365, 60.86153130377493, 60.78765738394953, 58.86297779698526, 61.52971882973949, 63.0948975009303, 56.804004100061235, 59.4932948389361, 60.0381120558708, 59.5147462814085, 50.927548331599084, 49.20627893940095, 53.22642595537248, 51.60443175223566, 53.14866496670631, 51.8616960894677, 51.57772041136219, 49.697061584841826, 50.64617318491782, 44.14761381764566, 44.4486871073323, 42.44759974941131, 49.907794844719675, 48.927512168884284, 50.823072079689275, 48.561300077746, 49.6551275253296, 49.67663780335457, 49.906473005971606, 50.60543544830815, 53.20761034565588, 51.350623023125436, 53.5309862321423, 52.81132152003627, 56.16352027462375, 53.33804876573625, 57.7894760716346, 56.12810911670808, 61.7391106390184, 59.75246152570171, 65.97585093590521, 65.15553036043721, 69.77371723421159, 70.1591371720837, 73.86947970236503, 71.6216556487545, 76.8756861840525, 74.36631848735195, 72.51546967414119, 21.292737491669197, 0.3883489677982946, 0.696502871090366, 0.09362712156988921, 0.23782968250734193, 8.339272775957662, 67.39294836598059, 66.7032152606595, 61.47462914066931, 51.00550936114404, 41.26395786962202, 18.184072817525557, 13.895656274211023, 22.73563431155297, 51.16768760065879, 60.27921622799289, 50.57261305470621, 1.3731451885354136, 0.13746542285286611, 0.038833299486507336, 0.07882352963450455, 0.04431533274210749, 0.08436343317190487, 0.023565306966643662, 0.06863246882154096, 0.015084281762791498, 0.03602742968547729, 0.0886401343309591, 0.06981848784151577, 0.13817978452049917, 0.1440531354878218, 0.061138416715567155, 0.1352483797217569, 0.08725230476909107, 0.14678834516915584, 0.08494887756364, 0.18877963144933024, 1.4270508121098242, 70.3455517368932, 79.27959703630017, 67.57285964104437, 51.739616240224535, 35.80232020347349, 72.28118650374874, 61.27043839423888, 46.56736712301932, 106.92124566724225, 28.326606250578358, 0.12165580425531634, 0.1780560092940446, 13.112468777164338, 12.272191182259592, 26.98041742847812, 108.9409838953326, 81.37261298394974, 87.36659865225516, 96.91958612011325, 106.44303814057382, 81.02151378508538, 92.40598140224334, 75.93653740421419, 76.56057080914898, 69.42906641191053, 79.37714638248568, 75.60722304928687, 81.89603759396462, 74.96300512744536, 75.5780484599452, 63.76347334154191, 63.53833713839131, 58.25877197327153, 59.92850142140543, 58.2875660927065, 60.34054248563705, 57.84230255311536, 58.276395182455744, 54.86814575810587, 57.713131058600645, 56.186509286203695, 56.67456588437481, 54.36501549136255, 53.442630921640706, 51.64133341081681, 54.834366306181884, 54.36492135447841, 58.06281428183279, 51.1096522115892, 51.86913290331441, 50.292630349436116, 50.37217601653069, 47.765051088025494, 49.11331484394689, 45.58253057541386, 49.02143724503056, 48.86928458367625, 52.750132545348144, 51.334254972396366, 58.11860999753399, 62.52522030184346, 67.2845575886388, 64.30682359203216, 67.77592074486518, 62.157651070625555, 60.03099687637822, 63.1397262696297, 65.6372993992221, 66.77702642256214, 62.305622485376176, 63.68946606113065, 64.0148933472172, 65.1612413314081, 61.26344873059181, 46.795692213120006, 43.811172516115256, 58.43560811012023, 52.36397127951346, 34.675199677867276, 58.06983924681141, 64.72081015186926, 59.80657454459899, 52.79471812709686, 50.94828982507029, 52.70462520660893, 61.62863316074495, 64.20701888299757, 65.70399930400234, 65.6423710238549, 63.96386723364554, 65.32832645600843, 64.32183842505178, 61.48445467795096, 65.85826612287953, 64.71639356305523, 58.19695541935583, 61.91537803219211, 62.21304670456917, 61.257008198768865, 54.3080940554219, 51.08351745913106, 53.9116483349954, 54.93990552040839, 56.75368793549077, 55.02805686766102, 54.0535439983491, 51.7029538462239, 52.578109156700876, 46.64992124803605, 47.94299725563296, 44.58599751995456, 50.61969718625469, 51.88285335417717, 52.18768427448889, 50.921500036793375, 53.11551701638007, 51.977833547899806, 53.118356812384825, 52.4908285756265, 56.39544610054263, 54.83575482522288, 55.5340269304091, 57.32059986360612, 59.441692136949115, 56.87700333133821, 62.08451455639255, 59.768429494673214, 64.69206310087635, 63.380034200606815, 67.68418435127505, 67.94611238664197, 72.86276417393839, 71.77790718693888, 74.70850606118479, 74.05789467596239, 79.63508928975752, 77.0886238159672, 77.59879081479966, 27.420954512011622, 0.18846663856698623, 1.729823346099546, 1.0155061728531316, 0.41007105381258074, 8.300130463415577, 72.70017408555555, 73.7799241465907, 70.0244822040681, 53.38585461339643, 31.313997122549246, 22.229483819776966, 26.5495744828255, 29.159972629239483, 58.915976862753595, 68.06977687343475, 61.7175179912198, 1.5211059393421298, 0.08419477891537451, 0.10910577486239134, 0.08558216414624646, 0.027710265900579192, 0.034447331206812974, 0.051795537808849934, 0.088968173180136, 0.010467066970323364, 0.020052506550846082, 0.12656339414177403, 0.1899462914274585, 0.37602549358721704, 0.23233192912753553, 0.12647338647155032, 0.2770278428591067, 0.24292407527325616, 0.2416828902618539, 0.21869496652676215, 0.3372947541215728, 1.7651236970578472, 86.44267651342577, 88.43281653619583, 80.13421089418473, 52.84012740658176, 37.63036435650241, 89.00635334753221, 89.36059044253442, 56.832813908976895, 117.61583112901258, 34.032299672403646, 0.35245468419405723, 0.3400543253988989, 18.987291859042262, 22.719854616349746, 30.968389241926133, 112.61899825065368, 88.31113676871024, 90.21891486260199, 102.88719777138003, 104.33971420411142, 84.2288201855075, 99.35820210364558, 79.60213353556972, 80.97387267697243, 73.74346179346885, 81.8430228387156, 79.90090831633538, 86.37425468813989, 78.6245612175234, 78.55350355948173, 67.65997548257151, 67.64314851453229, 61.64081996487033, 63.19110539651687, 60.92351259723787, 62.987259818661606, 61.460551754120864, 61.327908962003654, 56.36165488150812, 61.1698962796119, 58.491329300788145, 61.12182371077999, 58.59638214111329, 56.41708581678329, 55.79502928641535, 57.53685582068659, 57.20411331422868, 62.22080515277002, 51.99244829916185, 53.946988890247965, 52.96800844130978, 53.029966200551684, 50.531459546858265, 52.408172468985285, 48.94611597061158, 52.303555011749275, 51.99260127159857, 55.479725637743556, 54.299504064744525, 60.84990932095436, 66.09055672922443, 70.26644537525793, 67.19163663925664, 71.1651074501776, 64.81631986556515, 64.61398047785606, 67.38524483096215, 66.86263607394311, 68.74323214254072, 66.48529621862596, 66.92236592692714, 66.44890446816721, 66.50460212461411, 63.65838127751505, 50.48284569094258, 47.81096243089246, 58.87620010683614, 55.51119873600622, 37.68599533265637, 60.161682405779445, 68.30091430294898, 63.1759964266131, 56.45997693461757, 54.79742542389901, 56.12855234453755, 66.43585082023375, 66.55149798239431, 69.66871538469869, 68.82067541922294, 68.32229122038811, 66.32013305541008, 69.17608138053649, 63.42324695279522, 66.50710459678405, 66.14268502881451, 60.06577653269614, 63.69075259854717, 64.57164241421607, 64.77367585705173, 55.39025637411303, 55.59444319817328, 59.178850189332046, 57.47614929752966, 59.83818100344751, 57.69065587751327, 57.982656724991344, 55.99790211646788, 56.917725378467196, 49.39428598650041, 49.23823056682464, 49.27506162274269, 54.982718190839215, 55.27120459464289, 55.05234026139783, 54.57323058958977, 57.43953397197109, 55.77671966245098, 56.43263409214636, 57.21895948533089, 60.21334002094885, 58.09211438701999, 59.793371846598966, 60.125812330553615, 65.70757650559949, 61.25273281528104, 66.45739247722011, 63.18788905297557, 69.59980718551144, 66.49848322714529, 74.21023953345515, 72.58629198997252, 77.46617547927364, 77.88371178411668, 80.37818231890279, 77.00630111079063, 84.45790229305145, 79.30541407677435, 81.64803397270941, 29.238072902925555, 0.709508408702189, 3.9277634313029632, 0.9136645279584393, 0.42331551892622826, 12.46383426650878, 83.7586848966537, 78.96671741239487, 79.52766341547813, 69.15459463673254, 59.03593863210371, 27.496020832369407, 25.61790958527596, 37.032579452760764, 68.91105467273344, 77.00766609561059, 72.3666706392842, 1.7863929944653667, 0.25376244207784054, 0.14759312053361248, 0.1953931612473342, 0.18912047928860112, 0.21801304102184313, 0.17147660105218812, 0.24442753814641507, 0.12141388134970782, 0.13636571895931998], [0.08050087148383742, 0.023818906967438037, 0.031952156024354125, 0.06970602613423141, 0.06868621755030847, 0.07305794425549046, 0.04494856952899887, 0.11411123248117586, 0.04593971493323484, 0.5205767241216476, 7.0834480081835105, 75.92126369476318, 64.61932274603075, 53.677337708011756, 39.95905983832575, 31.50755236225744, 28.73937491447695, 48.66601559423631, 49.47704015239593, 91.24229261952063, 9.546148815462667, 0.11688601826467823, 0.23641888562950397, 8.44016594271506, 3.851366446864221, 47.09236852584347, 103.69999131848736, 77.54774508937713, 89.5301466603433, 79.39305551590459, 103.90244053256129, 95.59020857657157, 80.56822899849185, 77.92724224828905, 70.9780574614002, 68.57464082779424, 71.34034325999599, 72.3647722121208, 71.4379632088446, 64.62040139782813, 58.28140797153596, 59.323722931646536, 57.28192921607726, 54.24501449831071, 55.46130226504419, 58.397517973376864, 55.24146518399639, 54.609787079595755, 54.98550307366156, 53.75062327231131, 55.295899837247795, 53.25551817494055, 56.90001195476901, 52.73778884641586, 49.14672559307468, 51.32579834230485, 53.01264893624091, 52.90268136608986, 53.29125881195069, 51.49890822748984, 52.3079009979002, 45.22853666736234, 44.63971437946443, 44.63410146774785, 45.31973177386869, 42.299498896445, 45.50755054719987, 49.725094764463364, 53.96917773831276, 52.461653986284816, 60.65892519489412, 63.028283888293856, 61.825653814500384, 65.94081632552609, 66.03324305626654, 59.08048106778053, 53.78350057909566, 51.30402918784849, 55.89392400556996, 55.3799876090019, 60.456099433283654, 53.71854612904211, 61.68485641479493, 52.23913400403915, 58.117829445869695, 41.60936178699617, 43.71412523331181, 47.74191694874918, 44.84697241936961, 33.452604739896714, 48.49694967269898, 64.57077164803782, 54.4993802039854, 58.00804622711674, 59.00084910854217, 55.40981331179219, 51.79687500000001, 56.26850643465596, 52.98430981174592, 57.88134190344042, 57.081551013454316, 57.85264976562993, 59.968050679852894, 58.950152474064986, 58.5707494520372, 48.34391840042607, 58.16767884838966, 62.07536758915071, 60.67663469622212, 56.37192364661925, 48.08568916013164, 48.32339263731434, 52.97596693038941, 52.308740385117076, 50.94443805756108, 51.365692769327474, 52.38818014821699, 48.405217201479026, 48.61350290236935, 45.96695030889204, 44.458696996012044, 43.24264457148891, 46.95271645822833, 49.48766977556291, 47.80348247097385, 48.83442647995488, 49.40259356652537, 48.908327856371486, 49.1472041222357, 50.420068156334665, 49.659140110015876, 51.09448048376268, 55.02732730680897, 51.75112839668028, 53.86249319199593, 53.1218594889487, 55.02612313916607, 59.025497282705004, 58.28716601094892, 60.541528655636704, 61.28597098012125, 64.36546302610829, 69.30813973949802, 73.12056587588403, 71.4423248844762, 70.02923611671694, 71.94165829689273, 74.17975487247591, 78.79021859938099, 46.16869349633494, 0.8568390675129429, 0.6499211093591106, 0.34346381502766765, 0.14943242103101748, 0.07312009696878734, 48.30821306474748, 70.76639067742133, 70.53608479038363, 47.48302482789563, 58.546187570018155, 40.1446154040675, 10.383956297751396, 30.453803693094564, 53.44231713202692, 52.02392924216486, 72.48894660703598, 8.846830418032985, 0.6410146937254937, 0.13952206249438948, 0.06700345945935096, 0.09542367436111936, 0.012525834421056413, 0.05360456251148736, 0.04057211223088446, 0.057723514675613374, 0.0654202391723952, 0.07094646037946786, 0.09703658055514099, 0.07132211925401803, 0.03759556570120397, 0.07062573766996784, 0.15212094531424586, 0.07898492903839197, 0.11103209528711536, 0.11266537941992284, 0.6768936555712455, 7.795459685787079, 91.75358926096271, 70.52273304231706, 64.74399135958764, 46.89567735118251, 38.730212642300515, 31.679677732529182, 51.607942273539884, 60.93065131095148, 99.27248262589978, 9.697968075352332, 0.051903249771003766, 0.347985296600288, 12.733393273045941, 5.691074748193064, 56.51127369173112, 105.72780962913268, 80.14882564544678, 89.97559455133255, 84.35829762489566, 102.98733588187926, 93.30775783907984, 84.98415885433074, 82.19729131267917, 75.18638410875874, 70.32316284794962, 75.76171736563407, 75.25446076546946, 73.30595277970838, 65.50721007008707, 61.65134368404266, 61.50588258620232, 60.323166385773696, 56.87922731522591, 58.170526489134765, 59.98787041633361, 57.07753450639787, 57.97757725561819, 58.37315613223661, 56.87521080816946, 58.007528474253995, 55.29500161447833, 58.99432228457544, 55.09555301358623, 51.50411713507868, 53.96795003644882, 55.855347494925226, 55.31546854203748, 55.05619202890704, 52.09732463282924, 53.02523582212387, 47.24320719319005, 48.58531675031109, 46.91166493200487, 46.83097001044981, 44.14797075333134, 48.91193643693001, 51.63859167406636, 55.76698826205347, 55.58460197141094, 63.15739262488581, 64.72446972324003, 65.5597266843242, 66.84227897274879, 68.37994221718081, 62.62828450049124, 57.1240302824205, 55.352844807409475, 57.629996422798406, 58.43201129667221, 61.07626145885837, 56.19723304625481, 60.69270856918828, 55.405969389023326, 60.086518026167354, 42.222953842532256, 46.193478953453806, 48.66821604390299, 46.75497408836119, 37.31969302700412, 51.620113388184585, 67.0880703772268, 60.35581619508805, 62.29403972625733, 60.752524714316095, 57.46934398528069, 54.97605800628663, 57.58811335409842, 55.26391290849256, 59.59807311334918, 58.73424953030002, 60.52399566096645, 63.69379635780089, 60.26207939271004, 56.81899932123, 49.8549997422003, 59.47866439819337, 63.053975412922526, 62.700765978905466, 61.192289090925655, 50.67772865295411, 49.61958692919824, 54.18996403294226, 56.53445489944951, 54.34210884955622, 53.50334921190816, 53.581584807365175, 50.77424641578428, 51.4896200549218, 47.72969876566241, 48.787565923506214, 47.91568579212312, 48.81373989966608, 51.3243745219323, 51.31826346920383, 52.65221449636644, 51.94878055203346, 51.91504816855154, 51.7381335842994, 54.17680448101413, 51.63347690336166, 56.61496546960647, 56.36592634262578, 55.979400296365064, 56.469904453523704, 57.66656467991491, 59.70858589295418, 62.13250475545084, 61.76899909973145, 64.68657570500528, 65.4339401952682, 65.7267882747035, 72.4710213753485, 75.29953664348972, 72.35727264035133, 72.56063184430523, 76.683239013918, 76.85397978751891, 80.17497216501545, 50.20411029938729, 1.5251351941016413, 1.5738531154009605, 2.4715263853150033, 0.13323891577461075, 0.036130912842289094, 48.35425776820029, 79.19636434124362, 74.78143861216884, 57.59878612333729, 53.76237469334757, 38.42395397924608, 19.534080066988547, 44.13820797397245, 64.35243291239586, 58.520723542859486, 82.69726014906361, 10.892611222882426, 0.4716925310992426, 0.12100676690498668, 0.09598931538001185, 0.04851759313755939, 0.04140537457480546, 0.17275782181851326, 0.026140314256471973, 0.09379782128117739, 0.07717019698071866, 0.2416458422498357, 0.1828088800633146, 0.12646168830894655, 0.25983367355600484, 0.19501852893060256, 0.19203745099084993, 0.24314153699144242, 0.317004302576665, 0.18886541797509118, 0.989373381580076, 9.796938300132751, 106.28579816510602, 80.14134960789835, 74.9349444912326, 50.27011986701719, 44.45505311412197, 36.34771793119369, 70.54945222793087, 64.63482395295175, 110.42017244523572, 12.228305743586633, 0.2264608151369518, 0.3558161247882151, 17.1788203331732, 10.23544555710208, 57.89616061795143, 110.52715116931547, 85.39011632242511, 96.48523853671168, 93.52716738177885, 109.95591286690005, 95.75965496801561, 89.78604993512555, 85.85531726960214, 80.18186769177838, 73.65538104887932, 79.67785096937611, 79.90038271873229, 78.6910375472038, 70.77032873707434, 66.59553050994873, 63.951802022995494, 61.57296688325944, 59.01799771093554, 61.993060573454834, 65.40345945665914, 59.3825702513418, 59.51347543347267, 60.10947565878592, 58.648518285443714, 60.22919424118535, 57.68448598923222, 60.38758739348381, 56.79878734773206, 54.23759729631486, 57.54957214478524, 58.572961668814386, 58.3940702099954, 59.96720737026584, 56.70454455960182, 56.62610500089584, 48.962778199103575, 52.71056367504982, 49.376819672123084, 50.88649288300545, 47.87210041476835, 51.571444619086485, 56.12212357982513, 58.35402673290622, 59.283738290109945, 66.53157234191895, 66.92862602972215, 66.37765853635727, 70.4892046220841, 70.949463382844, 65.01944372730871, 60.28083616687406, 57.94064814044584, 60.75499580752466, 61.062380190818544, 63.27259655921691, 59.02443039801813, 64.32246600427936, 60.53442132088446, 63.723508311856186, 45.20825801357147, 50.8005262959388, 50.25134348100232, 50.22740917821085, 42.70995532312701, 54.539368767892164, 68.79886704106485, 63.81264025165189, 65.73505663102674, 63.66340583370578, 59.95638555096042, 59.16581615324944, 62.97147227871803, 59.838369277215776, 64.87272354864305, 62.1077585220337, 64.40057216152069, 67.20093265656503, 62.898837827867084, 58.419298894943736, 52.22162454358993, 59.98032769849224, 67.53231017820298, 66.12644641630112, 64.99783146765925, 52.46398387416717, 53.382497064528934, 57.647592175391416, 60.16420056743007, 56.973513249428045, 56.669329520194765, 58.6818152858365, 55.937270118344216, 54.24128824664701, 51.83158405365483, 50.687738541633856, 49.10636832637172, 51.200011853248846, 53.37762155840474, 52.21081056902486, 55.01567394502702, 55.70386948124055, 54.65283116986675, 56.34742060015279, 57.5939812198762, 55.459654869571814, 58.91749482001028, 62.18411922454835, 58.178551658507324, 60.775419589011904, 63.08280091131888, 63.293745979186035, 66.74922466278076, 65.5399344044347, 68.58963997133317, 69.39451817543276, 72.00753842630695, 76.71075836304696, 81.93138599395752, 75.77131932781589, 78.37464347962411, 80.34298296897643, 85.33164162789622, 83.93656438396823, 52.61775255203248, 1.5999139556961677, 3.661806876620939, 2.4302726118795337, 0.4082824223704877, 0.23626686314180975, 60.65475963777112, 85.1296474087623, 85.86869255188974, 62.777856242272165, 82.77384050430791, 52.3769151010821, 19.501826417061594, 44.66531961194931, 73.3694794870192, 66.07755799447337, 94.91407825100808, 13.19663695750698, 0.8533433163839003, 0.3047434024272427, 0.2341626187966716, 0.19605181300111357, 0.16245098213755316, 0.29938133854058485, 0.1433863325585281, 0.20141023030925184, 0.1160737812038391], [0.019979800976392244, 0.07468852409792524, 0.05375526349751219, 0.05518197202153745, 0.011355664802625055, 0.058261599511869495, 0.025233432778247425, 0.16391784132968995, 0.09288479003214067, 0.6521540411537694, 20.465697896096017, 73.01363422024635, 62.97481413810485, 45.81841799520677, 38.032540659750666, 27.412464541773645, 38.09195672312091, 41.48796835253316, 68.53137708479359, 79.00904763129451, 1.6006568771216179, 0.03088868425918683, 0.5855802038023549, 13.015374425918827, 6.8007588674945225, 78.00151624987203, 91.39488850870441, 77.60882423770043, 81.56909235062139, 83.25360128956457, 76.96743826712333, 92.37188816070558, 80.66511154174805, 76.59617808557327, 69.43306722948628, 67.67186026419363, 66.67043209075928, 64.26530922612837, 59.38270753429782, 54.69225099009853, 55.807996642205026, 55.61660851201704, 58.60892980329452, 59.61859103172057, 58.89578450110651, 57.84039235884144, 55.94584834191107, 54.90089754904471, 54.91016610976189, 54.63994226148052, 54.25621286515267, 57.518593265164284, 55.83067970891153, 53.4657964398784, 50.90965447887298, 50.078767038160755, 48.313637702695786, 55.36212513523718, 50.878193147720836, 49.29115118518953, 51.281612842313706, 46.25108680417461, 46.56036569226173, 45.152548590014064, 43.67747460642169, 44.09722312804192, 45.30293618479083, 52.49025198721117, 60.05201293576149, 61.37052943629604, 61.60966065622146, 63.12718252981863, 64.0762431390824, 64.9081386289289, 67.22842847147297, 62.20255436435823, 58.30263976127871, 60.009341470656864, 59.057692097079375, 56.384541911463586, 58.09214968835154, 58.12692934466947, 54.03153950168241, 57.40532305932815, 58.60279521634502, 40.71690097931893, 50.49152589613392, 46.959517848107126, 45.18457474247102, 33.28882225098149, 42.5622231729569, 59.51645643480363, 62.2071631493107, 62.12098867662492, 60.36061717617897, 56.66022962139499, 56.56197424857848, 53.38363062950873, 54.990421725857644, 57.72599251039567, 60.70172609821443, 59.39561605453492, 57.75524946951098, 55.27795891607962, 45.628700794712195, 58.06992946132537, 62.02227046412807, 56.0762789172511, 58.27892118884672, 51.76883397563812, 47.38660512431976, 47.66633679789882, 50.67088803937359, 52.29600052679739, 51.72759809801656, 49.56187317448278, 47.349511269600164, 45.21260399972239, 47.6376917285304, 49.61875538672171, 45.443659059463016, 43.50761244373937, 45.32576045682354, 49.78229468868625, 49.46138989540839, 49.48137437143634, 47.22084968320785, 50.580661758299804, 48.95093264118318, 49.04201399895453, 50.75679186851748, 53.52092143028013, 51.97324437479819, 53.116536832624874, 52.17156725545084, 57.025033581641416, 56.13775422496181, 57.0645514611275, 57.328397535508685, 60.4519142643098, 58.18527460098267, 62.07762687436996, 61.544557156101355, 63.41352731950822, 60.51443684485651, 66.19572331828456, 68.51591510157432, 76.45726342355051, 72.22399050189604, 70.34917600693242, 5.8584584632227505, 0.901579215161262, 1.728215664625168, 0.2076768295298661, 0.1669188988425078, 15.042829917323205, 71.79885264365905, 68.65974057105281, 58.442354586816606, 47.63724065596058, 54.14227193401706, 26.269221113574122, 9.861398531544594, 35.93537876682897, 55.13016008561658, 69.23435995655676, 30.614593413568315, 0.46872063089282284, 0.09103995837992238, 0.07586998489475058, 0.04807438829072541, 0.036069265747022246, 0.043416876315830216, 0.027085906157510418, 0.07909265632230429, 0.01206144437028636, 0.08447661500183806, 0.04559290309947345, 0.05337701907621757, 0.0054402450745504715, 0.03132264242477475, 0.09793013784914248, 0.07165617189340054, 0.13772229213387738, 0.15201487278024997, 0.5600041439456325, 25.120570698092063, 85.67443324673562, 70.11593618700581, 55.00352636460335, 47.9010671184909, 30.452303386503655, 33.7262685068192, 46.99416806620937, 77.84062062540363, 82.08505661256852, 2.0075956732034683, 0.15901988882931972, 2.3145550922040017, 11.304602276894355, 9.65512598714521, 85.73672832981234, 91.8484635506907, 83.61339246073078, 81.36980456690635, 87.32575108928066, 78.83578869604295, 92.21738599961805, 84.60867035773494, 78.76426819832095, 72.27262789203276, 71.85116137227705, 69.20458916694888, 67.60153216700401, 60.88998417700491, 60.223957877005304, 57.1417123271573, 56.72909467451034, 61.2460373293969, 62.51857188440139, 62.07557155239967, 61.22592733752344, 57.96585721354331, 58.615444860150745, 57.364965792625185, 56.91510131282192, 54.68570455428093, 58.11351091630998, 58.013227678114376, 54.018105383842226, 51.72875519721739, 53.54404772481611, 51.87971545803932, 56.734507545348144, 55.517148971557624, 51.60571828965218, 52.38088061732631, 50.65221755735336, 49.546630843993164, 47.383526063734486, 45.56459357661586, 46.812546637750444, 49.38480169542375, 54.79035339047832, 62.55665809877458, 65.31450010115101, 64.25106317766252, 65.27504497958769, 65.38174129301503, 67.00482983742991, 68.09775121750371, 65.74856135153001, 59.457773854655606, 61.923171781724506, 62.783720185679776, 60.12512983814363, 58.71868556545627, 59.00350063077865, 57.43705503402218, 59.55362089218632, 59.477958371562345, 43.81503997310516, 52.75165834734517, 47.75412336472542, 47.84733064713017, 39.85739200345932, 44.6443663104888, 60.44483438614876, 66.0227938621275, 64.80509404213198, 65.82533390291276, 61.415573935354914, 57.3984863681178, 56.11698527489939, 57.41821589008455, 61.86180630037862, 63.041819987758515, 62.63454460328626, 60.182329762366514, 54.340155509210405, 49.32875102566135, 61.15184160970873, 64.0574981320289, 61.3515059409603, 62.18991648766303, 53.77056852463753, 50.02620335548155, 52.749332381832986, 54.32375607951995, 55.57807906981438, 54.98691904929377, 50.48322223847913, 49.795618980161606, 49.11959455859277, 49.702199889767556, 51.35662424948908, 48.265251344250096, 45.959897887322214, 47.15059218868133, 51.83592219506541, 52.91422882387715, 51.77763969667497, 49.65364094703428, 54.008781909942634, 51.987568870667495, 53.52548706916071, 54.67800494163267, 56.174024381945216, 55.48540915212324, 56.52871254951724, 55.69713084928451, 60.5617053278031, 57.58641889018398, 59.74249870546403, 60.6273461926368, 62.758883737748675, 60.56173670676447, 65.16959990224531, 63.71627153888826, 66.14172797049245, 62.5346379126272, 67.57304791481265, 68.98186129908409, 78.75059481590026, 74.34194487910118, 73.9121158661381, 8.581179072779994, 0.48466212386565827, 4.052891452466288, 0.6056651292789368, 0.2343678231080694, 13.97752300385506, 76.92135826233896, 75.95710631339782, 66.16469737022155, 53.63753741787326, 44.16747670019827, 23.47528938324221, 21.138031367332708, 42.74040860514487, 63.32485429702267, 77.07021221037834, 38.36147846714143, 0.6123063761380412, 0.2672436130383323, 0.09456281369972615, 0.10377062364451348, 0.046057010655321425, 0.037632966113667336, 0.051176236161301215, 0.09269334465986298, 0.018312772585740014, 0.10566636950017945, 0.2251741245028473, 0.17726339940582553, 0.14044774185505607, 0.08490690360626868, 0.33087199553847313, 0.2499885091017331, 0.3278401566128577, 0.2879913271434846, 0.8518404970245977, 31.50098043103372, 98.68301314692344, 78.980469242219, 64.33639826313143, 54.83663735851165, 39.55052929539835, 55.003624423857666, 61.44157924959737, 78.6187090412263, 93.8669309308452, 2.364553054494243, 0.20372821318526424, 2.989395203128938, 24.576596790744414, 11.750982711392066, 88.14873495409566, 99.09496399664111, 87.55627662904801, 86.5015277554912, 86.5146049376457, 87.40211963653566, 94.73921114398588, 87.03352666670277, 86.33484271264847, 76.09620140444848, 76.82872756834954, 74.34055636006018, 71.13874912261963, 64.93029609803231, 64.06542524214714, 61.086106607990885, 61.954413460147, 65.06630820612754, 65.30412543204524, 63.135419507180494, 65.31977568903278, 60.85201171136672, 60.851254693923465, 59.524305097518436, 59.38648869914394, 57.54401806862124, 63.01513218110608, 61.095002543541696, 56.37301798789733, 56.17180824279786, 56.962350183917636, 52.713340713131814, 58.55666422074842, 57.575789267017, 54.803936558385054, 56.83734816889609, 54.691701858274406, 52.681636195028986, 51.709162958206676, 49.07796644395398, 50.207824783940474, 51.867501197322724, 56.9787613807186, 65.03004197151431, 66.70683953069872, 66.28379621813374, 67.85206963939052, 68.45923685258435, 70.00798471512334, 73.1593345826672, 67.78899792701968, 62.40874944194671, 64.64421410714426, 63.24252374710576, 61.497206303381155, 62.91393110829016, 59.37863611405896, 60.668252591163885, 60.88028807793895, 61.95611576880179, 48.794304555462254, 53.643142484849506, 48.36927260121992, 48.59626016309185, 44.30220619324715, 50.88062501722767, 65.82032111383253, 69.45483638394263, 68.1142879301502, 68.48026075670796, 62.87754720257175, 60.42600700932165, 56.04511568623205, 62.02338833962718, 64.64623020541283, 64.591375858553, 64.84463153346893, 60.681769078777684, 55.37857947811004, 51.41012537863947, 63.54939822227725, 68.01114528409897, 63.37650014508156, 63.57447001241869, 55.926393385856386, 52.673112884644546, 56.14292783121909, 57.588889983392534, 60.694603073981504, 58.02374355254635, 54.51934114579232, 52.579933058831, 52.08335315027545, 53.74468088150025, 56.18315958207654, 51.726656729175204, 47.849876265372004, 52.21886319498862, 53.95250374271024, 56.01353276160456, 54.756581783294685, 52.97267998418501, 56.01209325175132, 55.33762601114089, 54.029480257341945, 58.13806887595885, 60.499041541930175, 61.22934764431369, 60.192100386465754, 59.34741404748733, 64.50833143726473, 62.09297903122441, 62.27079183824601, 63.4425332469325, 67.33794104668402, 65.41621500445952, 68.79886704106485, 68.13445675757625, 70.96236013597058, 68.17925022494408, 73.69788385206654, 74.23978282559302, 85.0388288497925, 78.56293293737596, 79.62917435553767, 8.111708625670403, 1.9262730498467724, 7.7798770896850105, 1.2041421474949008, 0.2629203337334818, 19.18687382052022, 87.21816047545403, 82.23693863038095, 74.9772511759112, 64.3255921333067, 69.90768186507687, 36.710297907552416, 20.928870977893954, 50.601720963754964, 71.5056162495767, 84.52320191168016, 48.71709662099039, 0.8679561064608636, 0.5763326032507805, 0.27439041664042785, 0.28649917172808803, 0.19246350312905927, 0.1508562260818097, 0.13706080585477814, 0.23129744995986265, 0.13314700054545558], [0.0038514507797381453, 0.05474244822717963, 0.05749265407963146, 0.026526692616302642, 0.027643133615774494, 0.04225243033180314, 0.03441071603447199, 0.12355763284910111, 0.12748210210232966, 0.11255402854012866, 26.254335718770182, 63.40172098528955, 57.605159974867306, 49.32094158664827, 34.969510801376835, 41.41802856999059, 49.082241827441806, 44.4318405274422, 89.23916170673986, 45.13608248003068, 0.1308443087844118, 0.1029055111951405, 3.3105851036887017, 5.9494726504049, 20.367864178073024, 93.4168311088316, 82.1981934578188, 79.57054276620188, 75.86596612007388, 92.9602279970723, 80.0533002422702, 82.31602145779519, 83.33484142057358, 74.42117675658196, 69.00908254807996, 62.69350174934634, 59.354211514995946, 56.404416561126716, 56.61032530569262, 59.79758447216403, 61.85502059998051, 63.391958205930656, 64.58988143551734, 62.786410931617986, 62.870188836128484, 65.65894303783294, 58.50747769878757, 57.05041523902648, 54.503494770296165, 55.1800722460593, 55.27513873192572, 54.69763248197494, 54.17644754532845, 51.9840112809212, 48.5132118194334, 49.732712007338, 50.898075642124304, 56.24526639138499, 49.90678287321522, 48.141943793143, 51.926489722344186, 47.216154606111594, 46.412304062997144, 46.106853408198205, 42.05901838118031, 43.16138090625886, 45.03845860881191, 53.073732006934385, 60.56883227440619, 65.44846473201629, 66.32340431213379, 65.77561393860849, 66.44281694965979, 65.6224375386392, 62.645554696359945, 60.40997236005722, 59.10122256125174, 65.25058507919312, 63.98014114749048, 67.65606095713954, 60.373125614658484, 56.578977723275464, 63.34889450380879, 66.78324730165544, 55.35656321433283, 38.778610767856726, 51.54595705770677, 44.41759840134652, 45.31718615562686, 35.933370513300744, 34.086714713804184, 54.95763855595743, 64.0263976589326, 58.796458321232954, 54.82077137116463, 67.25357870901784, 64.66190399662142, 59.536609572748986, 59.575099791249926, 60.321491533710116, 57.1673999294158, 58.1093845828887, 57.71834388855965, 56.489586907048384, 59.64286265834686, 61.74878320386333, 56.997525999622965, 58.909132326802904, 54.798068692607266, 49.27392805776289, 47.48279733042563, 52.02875767984698, 50.13217403042702, 52.223401377277995, 49.963967107957416, 47.362329575323294, 46.77822197637251, 45.203433498259514, 45.62694749524517, 46.94687212667158, 43.911294937133796, 45.0002468785932, 43.480948171307965, 48.21311912228985, 49.056248280309866, 49.25477904658164, 50.460696066579516, 48.888900356908, 51.002026296431026, 53.958120576797, 50.923127820414884, 51.77028917497205, 52.1335163424092, 52.19039070990778, 51.81973065099409, 53.66523719603016, 52.50837725977744, 53.83504052315989, 53.552418062763834, 53.659016316936864, 53.8988261069021, 53.720126844221554, 55.75386401145689, 54.513375220760224, 56.57429441328972, 59.080120209724676, 65.94991622432586, 74.1101328019173, 73.28889831419914, 75.45073616889216, 21.037297056567287, 1.1333146835527113, 2.9802102379260527, 0.18322161759339994, 0.05764997789576169, 1.0690531447049112, 60.455813100261075, 67.79566595631262, 68.67103699714907, 47.146767877763324, 60.57871272487026, 40.58211265071746, 19.76227375768846, 34.8619358770309, 44.30654041228756, 61.00032044995216, 55.74444640067316, 0.5893302348352248, 0.07153012744721866, 0.05703103630953739, 0.052734497303683917, 0.06868163634452128, 0.0441924330868548, 0.052069778133544235, 0.09025510130149704, 0.03938570633650788, 0.018249627788581194, 0.06806446059096245, 0.06471893164299189, 0.033324778740925175, 0.04647218817544561, 0.07099890675876411, 0.06818959339251442, 0.06663926892102727, 0.14282653679049787, 0.1514339176637511, 32.360085402765584, 76.07969607076338, 68.95835845701157, 59.08814930146741, 47.181708351258315, 37.88721292249618, 46.7924758695787, 54.30548175688713, 96.34498242408999, 47.85361036177605, 0.1326020668831564, 0.039030670548879334, 5.632829022022986, 6.870156382360767, 25.220840207992065, 98.61247324174451, 83.41666990710844, 84.9148819523473, 77.46224526436099, 96.55717480567195, 80.29767174874583, 86.64947171365061, 86.10120281096428, 76.12534461482879, 70.24463699709985, 65.57967978139078, 61.426034896604484, 59.6861695474194, 58.80795086583784, 62.28471625235773, 65.06416266964328, 67.87529791555097, 67.43167000432169, 70.37372219947078, 66.76860117143201, 70.38663464207804, 61.47422905891173, 60.19065695424234, 55.9507748388475, 57.646595893367646, 55.93995301954208, 55.84270177348968, 56.1981548032453, 54.10247948861892, 50.0643091817056, 53.017289100154755, 52.91227156116117, 58.6124756259303, 51.163624025160274, 49.21099755071825, 52.16111806131179, 49.471003624700735, 48.37108473623953, 49.99156098211966, 44.98711870562646, 46.41219031426215, 47.29721430809268, 54.5283547524483, 62.762986536948915, 68.63143674788937, 66.16996903573313, 69.4711926675612, 69.7643506142401, 66.00428027491417, 66.1373584501205, 62.90219537673458, 61.28349596454252, 67.96883075468003, 64.37339798096689, 71.13579950025006, 64.52362083619641, 57.935517680260446, 64.30363078271189, 69.79361149572557, 57.239779426205544, 41.379099046030355, 51.745766516654726, 45.01530093531455, 45.15478826338246, 40.13226386039488, 38.58071150318269, 58.62179909982989, 64.04403655759751, 60.28819453331732, 57.61509926088395, 68.1634666073707, 66.63524058557326, 62.33100806513141, 61.9580691091476, 63.77444028854371, 60.87882503386467, 60.753199361985736, 58.70193312245031, 58.77813300778789, 63.05732119467951, 62.66014199103079, 60.89579712960028, 59.09280123249177, 54.70323362658101, 51.08292518123504, 50.28596232014318, 52.90792557501024, 52.54007393313993, 54.72801516132971, 50.24814282694171, 50.286323178199034, 49.274339906630985, 50.33467815768335, 49.64645908724878, 49.791378898005334, 47.414854034300774, 49.11172628402711, 47.13878977683283, 49.76265930360364, 49.858698537272794, 50.366719999621, 52.3629161619371, 50.17864234985844, 54.49832900877922, 55.47186128554806, 54.747203396212676, 54.912295956765455, 53.60224000869259, 55.00930401586718, 55.76466621891145, 55.132219329957046, 55.37652807850992, 57.4490104183074, 54.53153187228788, 56.73677467530774, 56.3809137190542, 57.067858019182765, 57.50458255890877, 57.60916079244306, 58.16159917462257, 62.25011310269756, 69.65848584328928, 75.61782129349248, 75.7453767714962, 78.42415948067942, 24.681580989591538, 0.35824162044352104, 2.9084965634730557, 1.4238472162715852, 0.06807299481043894, 0.8717054633363601, 61.08228229707288, 75.1110589119696, 75.76621240185153, 57.768981687484256, 55.6533807323825, 27.90914643195368, 29.74114041174612, 46.31165604437552, 54.033669348685976, 68.25343008964293, 65.02444082690825, 1.1661223682665056, 0.10539025609051028, 0.0917813016642486, 0.1168776908889413, 0.0727971526043069, 0.06983217017184343, 0.017419058243714033, 0.037029890208354885, 0.023108078880355726, 0.10962808594828653, 0.21258562983524418, 0.14475528571394183, 0.2847597537742507, 0.1654592868421347, 0.2749708354953797, 0.24167938157916072, 0.20137926503535242, 0.269508567308226, 0.3414367770235385, 39.667168817212506, 91.66907787323, 76.47845991196172, 66.33093526286464, 49.82056525445754, 57.182206876816295, 73.50782148299679, 61.587134484321844, 104.84169913876443, 55.34237600141957, 0.5475302100662263, 0.15377068501566687, 8.991655111312866, 14.580687438288043, 26.972906089598133, 104.82014963703772, 87.1771324834516, 88.82258246021887, 81.4583638406569, 101.10760273471956, 85.14239511182232, 91.07328553353587, 87.92277505320888, 84.14384595809445, 73.43803467289095, 71.40532908901092, 63.620047953821, 63.51725047634494, 61.58086653678649, 63.68246070800289, 67.72142333369102, 68.94959588204661, 70.53429618958505, 73.1252884095715, 71.14077306562855, 73.91355145362117, 62.43260529733474, 61.74047954620854, 59.83429001223657, 59.123587915974284, 58.01307862804782, 59.10223453275619, 60.0633172065981, 56.18423431150375, 53.352781188103464, 55.24838816735053, 56.42284385619625, 61.368203470783854, 53.53486545624272, 51.95502888771796, 56.55826760876564, 55.68953321826074, 52.22846123480028, 53.16671963660948, 48.12546983841927, 50.36777119482718, 51.12769903675203, 58.200693438130045, 65.91803519956528, 70.4413438612415, 71.10294572768673, 74.34268228469357, 71.16676269039031, 70.39668375445952, 66.84919018899241, 65.44018460858253, 63.364650664790986, 70.30589657445108, 68.41334512156826, 73.67526746565296, 67.86091850649926, 59.76784898388771, 66.1665879526446, 71.6304260684598, 62.96953070548273, 46.26763920630179, 53.30690906893823, 46.42152947764243, 47.42182408609698, 45.39633958570419, 43.30211947041173, 59.056429093883885, 67.98988603776502, 64.16521033933087, 65.16724255777174, 74.24804333717593, 69.25309319649973, 66.00344873243763, 65.22412477001068, 67.69085238056799, 62.95726937632408, 62.84758421682543, 62.70218979927802, 61.43891203788019, 64.12583366517099, 66.77427291870117, 64.86629478393063, 62.103683179424664, 58.53961367760935, 54.40320760973039, 51.9786847022272, 56.33511612492224, 55.55425459338773, 59.018076158338985, 54.56938274445073, 53.51201372761881, 52.583867196113836, 53.176333365901826, 52.01118546147501, 52.321311581519346, 50.229860659568544, 51.75499585367019, 50.6289618246017, 52.278651883525235, 53.68892438950078, 53.79027451238325, 57.00548841107277, 54.78939633215628, 58.2822669706037, 61.0540412318322, 57.14844703674317, 59.00949793477213, 57.53293345051428, 58.68284686919182, 58.94415909244169, 60.493856168562374, 57.455533319903964, 61.768869661515765, 58.43302326817667, 61.00237577192245, 59.1821567473873, 61.193967865359404, 62.47576313634073, 61.24998715616042, 63.43570047809232, 65.44080826543993, 72.29312619855328, 80.17092427899762, 80.88642735635081, 81.96472614042221, 24.67626617800805, 2.409424233821131, 7.136985419257996, 1.805408399912619, 0.14616263519612052, 1.7477027350856413, 74.73502128354966, 80.28696367817541, 85.97055650526478, 63.709893764988074, 83.45757238326534, 55.349436267729736, 29.130217529112294, 47.71954767165646, 63.57687442533432, 77.2544773163334, 79.5812822157337, 1.9552787321229137, 0.22207525288385732, 0.15681309595463738, 0.146140311394007, 0.20297908644762733, 0.16850946591265742, 0.15234462766637727, 0.16839887345990828, 0.13156507494709185], [0.08404310116724623, 0.048779947608108484, 0.09306667462712334, 0.014049586175279993, 0.029150616535316073, 0.06532502210428638, 0.04182597982787317, 0.09191691454860473, 0.05617315189973001, 0.11321075741321811, 41.68806414450369, 60.47402074260097, 58.0279444110009, 45.05669763011318, 37.28906716069868, 42.1647576362856, 46.81779084667083, 50.73718394002607, 91.88151344176262, 19.771489366408318, 0.09950065639831367, 0.18879631684432108, 5.009611470084037, 3.719878792762757, 44.898245642262125, 94.89315632850894, 80.86751368737991, 78.79877721109699, 78.3260610026698, 84.54985049463089, 78.76115383640413, 81.96733059421663, 78.70644461724066, 73.80086175857052, 65.03329753875732, 63.94762469876198, 59.90657144977201, 62.84311663719916, 64.86067010510352, 66.8870645953763, 72.49586566801995, 71.3564092882218, 78.26636252864715, 83.44085524159094, 94.70942466489731, 75.50772036275556, 65.83759523207142, 62.504529799184496, 55.397881461728005, 55.17157246989589, 54.58145187747095, 55.37490813962875, 53.14529957309846, 52.603714389185754, 49.48069187902635, 49.00642633438111, 48.54166077029321, 55.46425973215411, 48.92556275090864, 47.21623305351504, 49.56268902747862, 47.62315542467179, 43.6212238957805, 46.67107459037535, 43.13029220027309, 44.58048658986246, 44.914256757305516, 53.93293896029073, 58.46168402702578, 64.54336212527367, 63.434213899797015, 65.98824562564974, 64.70664255080685, 67.95478082472279, 60.25454059723885, 60.038951443087676, 64.12733201057681, 65.50655111189812, 63.77875097336308, 62.65789839529223, 65.83651265790387, 66.78957800711355, 57.32615786214029, 67.76220813874276, 51.10540428469258, 45.214608330880445, 49.63596282466766, 39.876988164840206, 42.18187878208776, 41.54960055505076, 34.85894703095959, 53.54000376116846, 57.10599522436819, 58.33862750760971, 32.69252196435006, 30.872830498603086, 57.58304957420596, 56.96617057246547, 67.08640729227375, 55.17505945697908, 50.606533711956395, 60.02442690633959, 61.70958303636121, 58.25838365862447, 63.02665610467235, 55.7392414154545, 58.62538806853756, 53.56029025969967, 47.93472105456937, 49.551337688199936, 52.768924620843705, 49.52681502988262, 52.47398984047675, 49.43678094494728, 47.59354937461115, 45.03883123397828, 44.89251898181054, 44.90145414106308, 44.50531044313985, 48.96937562573341, 45.53614854812623, 46.663535794904156, 44.961180071676935, 46.038764984376975, 50.78973193322459, 49.00799920482021, 48.15401684853339, 48.157872538412775, 49.76958620932795, 51.25085361542241, 51.92630537094609, 52.45293063502158, 52.908627679271085, 49.49473788661342, 51.028113980447095, 52.39077283490089, 52.340460592700595, 52.867085856776086, 53.030021113734094, 52.09197059754403, 53.3002684962365, 54.28889405342841, 56.127442313778786, 57.77065653954783, 64.23505206261912, 67.17260529918056, 70.44267746710008, 70.35036056272446, 72.56576230449062, 78.15367283359652, 38.04640231593963, 0.1473088406266705, 0.7800936662862379, 0.8557876884456604, 0.3497238565356501, 0.2608453999123266, 28.38194108778431, 71.76688532675468, 66.59562464683287, 57.52020535930511, 50.95497746621409, 47.97169723818379, 19.904426336288452, 25.930983366504794, 42.73301493737006, 52.94140692680113, 70.77412559140113, 5.838155784914571, 0.3298762957415273, 0.07930998780554341, 0.024445373452298587, 0.11872976207204404, 0.04553275753653819, 0.06299616461018882, 0.041107891142488494, 0.018390187685708367, 0.07744870824559082, 0.015975811796623374, 0.08602019789959155, 0.01974781423116163, 0.08134441089726265, 0.07954847863725117, 0.1154821698043135, 0.08238818271145706, 0.07217410861724807, 0.14544900897289478, 48.74370990260955, 70.11233545118763, 67.37824732257475, 50.70372612245622, 42.609687774412095, 42.42600710161271, 45.84645509719849, 62.1707086409292, 98.86210856899139, 21.456392503553822, 0.28711783369222, 0.08378953372518863, 10.52465073523983, 4.689093520564418, 49.71925435527679, 96.89346313476564, 83.22293619955741, 82.4931949184787, 83.70227336883545, 89.36407350724744, 81.39732391603532, 85.82644078039354, 81.64655916152462, 78.1309623102988, 68.52292045470207, 65.57236456101941, 61.261499312616166, 67.24012497932681, 65.67581707431425, 70.90547007899131, 74.17841342187698, 73.44522829978698, 79.27453717877789, 83.43851750896823, 92.31248778681602, 77.51889213438957, 69.68450684701243, 66.79013498367803, 56.9651468338505, 58.05258474042339, 56.68013957238967, 57.84870386123658, 55.42437314987183, 54.67474545201948, 51.21494823886503, 51.54640813027659, 50.362895688702984, 57.23423319478189, 51.948066680662095, 49.591145823078776, 52.57421816548994, 52.11903887410318, 45.90795393913023, 50.2251067469197, 47.259335979338616, 47.46344043362526, 47.632121962885705, 56.090999572507805, 61.213630707033225, 67.20884799957275, 66.63662910461426, 68.6020895742601, 68.01118450780069, 68.92780319336923, 59.32332284988896, 62.56968429011684, 65.66424608230591, 67.86597836402156, 66.36782907670545, 65.36385528502926, 67.13369538707119, 69.61431211040866, 60.11115443321967, 69.02578400027367, 53.970377983585486, 47.43357158476307, 50.41444347750757, 42.90965103333996, 42.72482502845026, 45.81635482849614, 38.09311774469192, 57.21807302967195, 58.34712336140295, 60.78673170458887, 38.06648485122189, 33.44817638397217, 58.3279037475586, 58.65070696799987, 66.01649453563076, 57.36724076732513, 52.14159642496417, 61.66154184649068, 62.90497633718676, 60.56535705443352, 62.170202655176965, 58.91489821095621, 60.370827105737504, 56.740355799275065, 51.14778941677463, 51.45610340179936, 56.0841275799659, 53.661110862608886, 54.10775115413051, 52.25801629404868, 50.52412079226587, 48.964915890847486, 46.885730220425515, 50.08457606838596, 49.083245954205914, 50.32911231440883, 48.800027293543664, 49.78873129813902, 48.786899120576926, 48.84886864692935, 52.65061809170631, 52.05655159488801, 51.45010217543572, 49.42947749168643, 52.02505104003414, 54.12178539460706, 54.57500742327783, 54.93009175023725, 54.96892713731336, 55.4554343992664, 54.95647753438642, 55.185100724620206, 54.955547932655584, 54.87310363400368, 56.5100303003865, 54.67001507359167, 57.2895464589519, 58.35532503743326, 60.75966342802971, 62.91531178259081, 69.42616385798301, 70.62399295068556, 72.41744179879466, 73.03027291451731, 76.91983638271209, 79.29749088902628, 42.471020221710205, 0.8908422171108185, 1.411113486655297, 2.474137212960951, 0.5462364407797013, 0.27026233653868403, 27.672758909963793, 80.07494388088104, 72.86328977154147, 65.47490542934787, 55.87179791542792, 38.720602835378344, 21.818107597289547, 35.39619407346172, 49.184843186409246, 61.10424364766767, 79.78984248253607, 7.213542240281259, 0.3952248520668476, 0.14903426981501042, 0.06997578101412905, 0.10328937487135972, 0.011008026551515346, 0.032167633574816494, 0.0824380167309315, 0.06716363312255952, 0.1583356037735939, 0.15348465842825754, 0.2363825424183761, 0.12833120331408518, 0.23664768544896958, 0.16558783639582897, 0.24496047487182004, 0.22289838371497972, 0.13349678096992354, 0.26799725969472243, 56.881502289925855, 85.26839733123781, 76.76346717342254, 60.37360806618968, 49.890858050315614, 59.78519370478969, 65.16912529545446, 67.54603062906574, 108.48511034442534, 24.891341501666655, 0.38046782295550075, 0.23054968685873095, 15.586520433425905, 10.693915717063412, 48.64717252792851, 104.20475329122236, 86.60546272031723, 88.41970797507994, 85.98930543468845, 90.19014819975823, 81.52414198844664, 89.83620920488912, 83.28998519528298, 79.99990893948464, 71.94877347638531, 68.97706816273352, 63.89664957600256, 70.30624958776659, 68.87365095077023, 74.78127387262161, 79.12317291382821, 79.69858461810698, 82.97318320120536, 82.79012618526336, 91.91861121885239, 81.48332580443352, 71.66092641891973, 72.29015304196265, 57.45502341178156, 59.91565958146126, 59.128741910380704, 61.32785797119141, 58.33521896792997, 58.69990525707122, 54.844748820028, 53.880026186666186, 53.07502638909125, 61.73823595046998, 53.25621243446104, 52.81912703667918, 55.643551272730676, 54.320790767669685, 48.63125554976925, 53.86661952541721, 49.923052864689986, 50.30996722559775, 52.0967637338946, 58.3384588456923, 66.11434198194935, 70.51985402261057, 68.22611470376292, 71.94465498770438, 69.47839413919758, 72.31003161399596, 64.52816686322613, 65.25348763312063, 69.78222093274518, 73.14742626682406, 70.81688727101972, 70.26591193291449, 69.29838872724964, 72.97186097791119, 61.557304859161384, 73.62350786885908, 56.778559684753425, 52.52208594352969, 51.85654209506128, 43.3928164359062, 45.26761524138912, 47.58360224385416, 43.47844569913803, 60.15441425385014, 59.40221740353493, 64.17190974758518, 38.216295857583326, 36.256487523355794, 61.73409392756801, 60.209860878606, 70.17673292467671, 58.977981690437566, 54.79703710925195, 65.08455114979898, 67.51295720377277, 60.74584491791264, 67.34636629781416, 62.36855299242082, 64.43814846777147, 60.040947929505386, 53.340068786374985, 54.55037101622551, 59.523312737864835, 55.71146711226433, 57.84713099079748, 55.841689801985225, 53.64190693824522, 52.70784155015023, 49.77236324740995, 53.89346422687654, 51.235725033667784, 51.59451992281022, 50.6953126384366, 54.54591520370976, 50.782102923239435, 51.75857697763751, 55.26421493099582, 56.02590391712805, 55.042624550481, 52.66961020808066, 54.68883068330827, 56.67666043004682, 58.55817825563493, 58.792359444402884, 58.85200300524312, 58.426967128630615, 59.77425029200893, 59.918471920874815, 58.93676934703704, 59.94674436507687, 59.64752243411157, 57.778026673101614, 59.857502598916334, 61.62204357885546, 63.69422389614967, 64.85242528300132, 72.37802982330322, 74.29366834702031, 75.92327979303177, 77.72349865205827, 82.04474249193746, 82.4023606700282, 45.16341355539138, 1.084973922660274, 6.0828631443362084, 4.977759863099744, 0.8421627227817813, 0.3665863710545725, 34.711642419138265, 87.13066808639034, 79.13367702114967, 73.02606813369259, 72.47770509412213, 68.53846873006513, 27.328176729140747, 37.95315580983316, 60.968039343434, 70.41550328654628, 91.48422441174908, 11.609453789649471, 0.8017371823230098, 0.44039440731848445, 0.1881998254647178, 0.19381877395414537, 0.17579298556572007, 0.1995491729147973, 0.22254739287159137, 0.1325173222369725], [0.08787737122827, 0.07222294672242097, 0.13103887979542056, 0.047459388226871534, 0.07810441056086172, 0.010934481153174514, 0.046506194818404414, 0.015012215871754435, 0.23545309390512206, 0.5210494923014795, 35.49282950739707, 53.91173854950936, 46.19231008714246, 56.016035233774495, 36.90866785664713, 38.103566938830966, 47.508249590473795, 60.26928086434642, 80.43590391835859, 5.02884530252026, 0.10075866470053312, 0.2391154691576958, 1.8507567600857828, 4.534897304350331, 69.80074236469885, 88.10085065903203, 79.63781925939745, 75.43263050817674, 80.29827579375237, 93.23202471579276, 81.95847388236754, 83.93220270833662, 81.04014504340388, 76.25695582359069, 72.52378509890649, 71.3316983561362, 70.90749402200022, 74.41391252702283, 75.13437348027384, 77.10945944632255, 85.75371219265847, 87.94318706758561, 84.60065303310272, 84.27627301985218, 78.81543159484863, 74.21874323198873, 70.86186901215585, 66.4960592023788, 60.58864416614656, 53.77645207989601, 53.52448686476677, 55.206689450048636, 54.827753190071356, 48.16738820845082, 47.70352871187272, 50.43859743302869, 48.473195798935436, 51.039543767129224, 50.675488979585715, 49.28685226748067, 46.93110419857887, 47.22434451503139, 42.90993736636254, 46.479247154728064, 43.046082835043634, 45.678334466872684, 41.84030702037197, 46.98873166115054, 56.4883239038529, 63.07373631385065, 65.44895110591766, 63.2497016845211, 63.836849120355424, 61.077853941148334, 53.989648588242076, 54.371244215196185, 64.48616612342097, 62.174815362499615, 60.459790383615804, 60.50226180784164, 61.0423094226468, 65.36719714441608, 63.77388723434941, 62.63292466440509, 52.056637887031805, 51.772509236489576, 45.26182190064461, 46.02135358318206, 45.77410305699995, 43.116414854603434, 41.166690934088926, 53.81457359560075, 62.96550635368594, 63.816252754580596, 57.93517643405546, 38.39635226034349, 47.219312114100305, 57.998295214868364, 59.95644046414284, 57.56481055290469, 58.015549721256384, 61.52784393679712, 60.63743845109017, 57.099684130760934, 55.148175531818026, 57.247278997975016, 52.26756726541827, 49.51030969619752, 49.49065469926404, 51.103792190551765, 51.730720304673724, 54.03796042165449, 51.46087692629907, 47.57595362201814, 46.820618875565074, 46.21833501323577, 44.00865208718085, 44.22687315171765, 49.79739581384967, 50.72409891313123, 44.71407859556137, 45.77315776578842, 42.33201926754367, 43.89521714179747, 52.430549590818345, 47.745223506804436, 48.78729135759416, 47.4462055390881, 49.112644118647424, 50.602450524607015, 50.898499258102916, 49.44364509274883, 54.128637775298095, 53.45990503987959, 54.56294613499796, 53.321708171598374, 52.8785038763477, 53.55161005450834, 54.38736907897457, 55.623617787514966, 59.04637998150241, 60.25348940203267, 63.70057813582882, 65.53441562960225, 71.90232476880475, 68.68547916412354, 74.26349747565486, 72.32721944009104, 77.0719615874752, 66.09683252150013, 55.93584629797167, 3.183821944459792, 1.5307454091887323, 1.8109621083544147, 0.17306863901115235, 0.1854241356974648, 5.45262013712237, 71.57501082266532, 64.55688253525766, 67.86635491155809, 47.78480414421328, 48.74885212990546, 40.47007406911543, 17.017297129477225, 39.87516034033991, 55.81398217908798, 72.23735009470295, 19.528941762062814, 0.49229441270712887, 0.1444531406366056, 0.11152487368352952, 0.04309621489336414, 0.11270327012865775, 0.10680089975076337, 0.020254004911910144, 0.03175955385931077, 0.052839030000951984, 0.015827345872117628, 0.016203431840685588, 0.04824556680696626, 0.07222336807077931, 0.007554126326971117, 0.08237440078969925, 0.09015632958541955, 0.12609055701402888, 0.6106412074258251, 44.68503344443537, 67.30533830581173, 57.203834825946444, 66.94389973917316, 43.383869509543146, 32.51460521451889, 53.06835835979831, 71.32561868236911, 87.89176479462655, 5.447448492050172, 0.3942217365387948, 0.7592429593205453, 3.1666596137708236, 6.755835961910987, 76.17226400683003, 92.36591046856296, 81.3398455035302, 77.15230741808492, 82.39196638907157, 94.95829120759042, 83.06426848134687, 85.7675346251457, 83.94567212750836, 78.41711490384995, 75.40711156783566, 72.65130919794883, 75.50770467327487, 76.51357296974429, 80.934688198951, 80.11932157701062, 84.32990750958844, 89.23944411739227, 86.87375284010365, 85.43969508140319, 83.24144978677073, 78.27298348949802, 72.64686907491377, 71.15558393539922, 60.94792542919036, 55.742642110393895, 55.19422023527084, 57.70661207937426, 57.016478892295595, 51.37190188131025, 51.10043464168426, 53.98138807665918, 50.584156590123335, 54.08449934374902, 51.825170978423095, 51.16822888774257, 49.92306070943033, 50.59493526335686, 46.126214227368756, 47.28469410250264, 45.79859041398572, 48.17020447023454, 45.16786936790713, 50.02420294669367, 57.94486861075125, 64.26598779616818, 66.12644641630112, 66.43790614220404, 66.34594225114392, 63.52384398060461, 55.74901596192391, 56.43151229427707, 66.17165565490723, 65.36260404894429, 62.694454885298214, 64.81393506450038, 63.48729925770914, 66.23620217846286, 66.26930698271721, 63.49352013680243, 58.56056697906987, 55.97457970342329, 47.80730678189186, 48.30974278911468, 47.163422261514974, 44.21791838061425, 43.364634206218106, 56.6796257418971, 66.15308715451148, 65.81173112315517, 61.59580292240266, 44.0198661435035, 47.87692885245047, 61.13341823700936, 62.270591797367224, 60.26263244690434, 61.24393886135471, 62.47569253367763, 61.02032453783097, 59.17998767668202, 57.6934015366339, 61.42663894161102, 54.45679110865439, 52.58363577627367, 49.48707749766689, 53.54233757142098, 55.47791350272394, 57.272864618609034, 54.38557655580583, 52.20737065038374, 49.80880598868094, 48.84874313108383, 47.38160410235005, 48.76563987424297, 52.2931371965716, 53.28505754470826, 48.13347931831114, 48.634738614482266, 45.60697870869791, 45.98033343591998, 52.81034092749319, 51.27714918505762, 50.45583624993601, 51.852203953650694, 51.31068152766074, 52.02216417558732, 53.89851231728831, 52.603498658826275, 57.96697508904242, 55.17380822089411, 56.71947310047766, 56.736633469981534, 54.95193542972688, 58.10476403082571, 58.39578036339053, 59.644768930250606, 60.61755987905688, 63.7188877597932, 66.93909875808224, 69.10994237469089, 73.9735637172576, 70.3796135994696, 76.51829550343176, 76.45412552741267, 76.00172719647809, 64.71784484001898, 59.69801118296962, 5.577952121534656, 0.9383710473775865, 2.414066849216338, 0.7809237991609882, 0.18206352247826516, 4.730546109137997, 75.34822894680885, 71.76865039333221, 75.51685164051672, 56.05671413483159, 46.33449208351874, 22.931748897798602, 24.253295429291267, 48.5672503132974, 61.811533281880045, 82.61096800527265, 22.86127175054243, 0.49037861066960525, 0.2257586342673148, 0.11399111755552793, 0.0951631891451055, 0.08032560588852053, 0.10431456905339034, 0.03428786617493437, 0.05091467076131413, 0.13489579541548607, 0.08911700874206521, 0.18394612226515047, 0.21753229020584017, 0.17137255099031234, 0.18320214363836473, 0.2638433777516888, 0.18304662778973582, 0.34555943322277843, 1.1053076122076282, 54.20445326835879, 80.98199982796946, 66.17193022081929, 71.6038167092108, 50.94731315489739, 56.22485829937843, 68.60390955402006, 75.68579596857872, 99.29782898195329, 7.2092398904985, 0.35528639031033366, 1.7307569927746251, 7.113000125654283, 7.951528833758447, 78.49476214378112, 97.26816715732699, 86.19082896940171, 81.15645900849374, 86.71569701164, 101.17921736932571, 86.07274209299396, 89.21918115308209, 85.9588913763723, 83.29001657424435, 78.02257153295702, 77.20333745402675, 77.23924283058413, 79.28442939635246, 82.76461508966263, 82.67254137223767, 86.18576126713907, 87.74386790490921, 86.11348767434397, 89.83036487333237, 91.70716408760318, 84.15140044304633, 74.59390224949007, 73.32549402790686, 66.94226803318148, 57.23650424711166, 57.4070998930162, 59.64662421134211, 59.01820559655467, 54.334981902953125, 54.201986097520404, 58.819474789404104, 52.70975566679432, 56.274507661019605, 54.30517188964352, 53.47437466344526, 53.11038263382451, 54.750149096212084, 48.318360236383256, 51.174587049791896, 50.31259129124303, 52.27805960562922, 47.53902842921596, 52.87603278313914, 62.41873187403526, 66.86296555303758, 71.56700918751379, 70.47462909452378, 71.162612822748, 66.57449091634443, 59.27441089384018, 58.23367272653888, 69.85788345336914, 67.8537170348629, 65.97658834149762, 66.96522174342986, 66.80033314612605, 70.04320759927073, 69.08905967589348, 69.39203923748386, 59.59861440043296, 58.2126998132275, 48.20140300258514, 51.8458418692312, 47.45798833908574, 45.42973072298112, 48.275308301371915, 61.40525810180172, 69.99112636812272, 70.03067170420002, 59.56909464251611, 38.16096690393264, 49.17483722009967, 61.84171984272619, 64.31493897591868, 62.110959176094305, 63.21032108799104, 66.00580999928137, 65.01478787391417, 62.538293561627796, 59.30044366467384, 63.42935408315351, 58.14838863188221, 55.08016947777041, 51.939880694112475, 54.81064773374989, 57.450575444006155, 60.290920580587084, 56.88298886822116, 54.955547932655584, 52.51345280678042, 51.920519874941924, 50.11421349740798, 50.98850588644705, 55.91799559131746, 55.886083187595496, 50.867645894327474, 52.66303631567186, 47.90733506602626, 50.02828221167288, 57.229651866420625, 54.72584216825424, 53.256541913555516, 53.17878092488935, 55.221578767222745, 56.8445300286816, 58.33577986686461, 55.31896729623118, 61.841559025549124, 58.841138039865804, 61.615387316673036, 60.5010497954584, 58.57602503991897, 61.52565525424097, 60.94796857526226, 63.60442515342467, 64.04768828422793, 66.76960529819613, 68.5018337926557, 71.68358202903502, 78.3850299158404, 73.26752139676002, 81.7458971085087, 81.39884579566218, 79.50063044025053, 66.16026509192683, 62.81134151643323, 5.083427534949395, 5.167101986946599, 7.018452863539419, 0.6344988401378355, 0.2400781658868636, 7.268556914021892, 86.79846686701622, 76.45250166616133, 85.4059156294792, 63.761739653925744, 71.56504015768729, 55.26966310316517, 27.71613051814418, 59.264036224734404, 71.29878967039048, 92.1346632126839, 32.34033626894797, 0.8716255450440992, 0.40786340291942325, 0.3494944591676036, 0.32305765356267657, 0.26515580894004914, 0.25221920391965297, 0.10576313406589533, 0.1080922098950513], [0.10501224532603257, 0.06347720653960301, 0.05490846331081083, 0.02800194430164993, 0.05955493978915676, 0.035220930623191024, 0.04048947815693194, 0.04435612309363581, 0.06701764740770863, 0.9354327018222502, 22.64952651916012, 57.6135342351852, 49.45181146744759, 43.51530813401745, 32.29070259678748, 61.62323597938784, 43.97060509650938, 75.04042486990653, 59.33173633390858, 0.7176681031142512, 0.011001326155007608, 0.5878529721690763, 1.8202265015532895, 18.86204077351478, 82.49510903512278, 84.12055492401123, 79.94411714615362, 73.10817903087985, 81.44561613759687, 84.31261770186886, 80.60121613164102, 76.00001704308295, 78.07881047648769, 75.55467897845854, 74.15608729085615, 74.2719070373043, 74.32787141492291, 75.06104084753221, 76.71972490126088, 73.71858612183603, 74.5334977488364, 67.57124362453338, 66.45801221170734, 65.11174494220366, 68.96160617951425, 70.2701480927006, 70.59774444949242, 67.78036086790024, 62.95322541267642, 55.453677177429206, 54.18557490071943, 52.47580197549636, 52.08756185347035, 50.44846219401206, 50.78966917530183, 50.286460461155066, 48.91052046129781, 52.670351536043235, 49.76810355340281, 47.41870580180999, 47.081519249946844, 46.29400145622992, 43.70986553930467, 43.824940035420084, 45.379696969063055, 44.55640715937461, 42.85379648208619, 46.85398647862096, 52.11767781165339, 58.1660432200278, 65.30847141819616, 64.09390164959815, 62.36984345220751, 63.937485371866536, 61.88337149158601, 58.54594438306747, 61.43520539806735, 63.405455081693596, 57.91668245869299, 57.33537150967506, 62.028699228840495, 62.14031027209375, 58.944982790177875, 62.52588318240259, 55.82445882981824, 47.445319083429155, 50.6188028858554, 47.94894356881419, 48.44534304834182, 46.61793431928081, 42.94691747234714, 51.58844024904313, 59.75647018801782, 60.195340264228086, 64.91636776155042, 64.4071303644488, 59.75111223036244, 60.46557587961997, 56.50972043314288, 62.18915947021977, 60.07164439847393, 58.39305823849094, 59.561622527337846, 58.38963400933051, 55.03214789975075, 51.423987034828436, 51.800730689879394, 49.93634185483379, 50.446100927168324, 55.30330527213312, 51.31718873977662, 49.492325628957445, 48.9861947490323, 48.109776435359834, 43.83140017909389, 44.99726979963241, 47.04149146233836, 51.19064915564753, 54.920356427469564, 52.76804208755494, 48.2755083422507, 46.44496956179219, 44.47212326911188, 44.961803728534335, 48.58257109119047, 49.22242341503021, 48.97649864996634, 51.26999478186331, 47.142241462584465, 49.11277747923329, 48.77752857823526, 51.4890395441363, 52.53488463740195, 53.48627905691824, 55.07068910906392, 56.88329481309461, 55.44771125239711, 58.02191180567588, 59.21815626082882, 61.58034878392374, 63.24807782326976, 66.78639304253363, 67.52700713373, 71.53515169697424, 70.6476369980843, 74.19556202427034, 68.69491638675814, 67.99644424069312, 65.71517413662326, 66.51111325910016, 75.12564228427026, 37.9571174037072, 0.8549397210440329, 1.1378623040453082, 1.473444729082046, 0.15333164002626173, 0.08910261394996798, 43.4881692547952, 70.86897634690808, 67.79383028707197, 51.634610468341464, 52.40215555314095, 41.17765395872055, 17.008960131675966, 31.690170072740127, 60.653724132045625, 64.56647665269914, 24.292152389403313, 0.38218548401228847, 0.07939330752818816, 0.09183046918722892, 0.023719664107287125, 0.058766704262985345, 0.05503486398787749, 0.1111364824276778, 0.06373233297058652, 0.07697278378351081, 0.027169697024228594, 0.04694370380152137, 0.028645802897611455, 0.05570704485439966, 0.03776942169474017, 0.012610671955401139, 0.021396535035643368, 0.09340683298726236, 1.446056043909442, 34.80040957850795, 71.77578910704582, 54.38592564675116, 48.352006327721384, 24.60298453607867, 43.449141671580655, 53.58426378619287, 80.05894061057799, 63.105731087346236, 0.3894885082639033, 0.02828502719621024, 0.6094983881039004, 2.203748134836074, 22.621005004452122, 87.84296266494259, 85.30095300366803, 84.05727924839144, 72.94426318137877, 81.77012951143327, 85.01884045139437, 80.68209540459418, 79.44900420404251, 83.61316496326079, 76.71278230605587, 79.509291033591, 78.29670598430019, 79.01216983795166, 76.46557100357549, 80.23345470428467, 76.63781012258222, 78.93217702065745, 75.76725575231737, 73.21419285189721, 69.96444640621063, 73.21283571181759, 72.83980261894965, 74.55310959969798, 70.3326706732473, 65.44674673388081, 58.21197417474563, 54.959293796170144, 54.41220944927585, 53.05666577431464, 53.06041948256954, 52.699573193826986, 51.89345944312311, 52.369682250484345, 54.2079794791437, 51.76877514008553, 49.976075464679354, 48.735967143889404, 49.22381585644138, 48.90261688540059, 46.98269905582551, 47.99206610648863, 48.7371713115323, 44.72920325494582, 51.05076174582205, 55.10764175845731, 60.21250063373197, 67.19937939797678, 66.41991815259381, 65.29517850568219, 65.46234207768595, 63.97691303683866, 60.735262363187736, 64.31380148856871, 66.0846653292256, 61.97506473910425, 59.40111129514633, 64.064283832427, 62.887549246511156, 63.670317049949404, 66.29517109163346, 57.17792364858813, 49.28539706814674, 53.54636192321778, 47.83013105392457, 46.865373119231194, 48.5640339697561, 46.25548770350795, 56.41198673555928, 60.244954324537716, 62.79237293427991, 64.15703219752159, 64.7134204064646, 62.09553641657676, 62.80075503933815, 60.98956531093967, 65.86126281369117, 60.87683246981714, 62.58112584390948, 63.22228431701661, 61.079689610388975, 56.38664037950578, 54.1656727944651, 52.68185977012881, 51.58740866568781, 54.831036213905584, 57.9192869124874, 53.327246558281686, 52.017986851353804, 51.60236074078468, 51.56014427062004, 48.73830879888227, 49.223313793059326, 49.06690143769788, 55.791381482155096, 57.3806199719829, 54.25843684904037, 51.9569783056936, 51.05701008150655, 47.81861497509865, 49.44039737024615, 50.3715366701926, 51.68045905328567, 51.57130341376028, 52.29340391774332, 50.279282523739724, 51.06215623117263, 52.91975936582012, 53.664448799625525, 54.76004915852701, 57.623826534517356, 58.6417757311175, 59.16187024885609, 60.08818895586076, 61.64062384636172, 64.22230043718892, 64.29469562345936, 68.0144557645244, 70.40850577815887, 69.17179030756797, 73.53909846275084, 72.9025605417067, 76.85945541627946, 72.45072703207694, 69.79053635751048, 65.7412657430095, 69.25331284922939, 76.73740694599768, 46.236107272486535, 1.1402711296273818, 0.31116778511674176, 0.5377359904589192, 0.06658638587161418, 0.1535689893869623, 45.363423055218114, 78.40664217548986, 73.44056852402227, 60.74360132217408, 54.36348184462517, 37.261865523553666, 22.42485707806003, 41.43878183057232, 63.9416273947685, 77.16929912567139, 33.186730800136445, 0.38161263410602847, 0.152481205821518, 0.11230627570541636, 0.13854168445592926, 0.05030748862472754, 0.08030213295452057, 0.1287101257231928, 0.10829117058986619, 0.2556972430958863, 0.1520141986228766, 0.19438034704615995, 0.08605932200988455, 0.17555315408014482, 0.12624084814301423, 0.18398934494583838, 0.1907098052963134, 0.20541766688467997, 1.6499023572091134, 51.020657554749526, 84.55424354922387, 66.39966303302397, 57.04982296113045, 45.902399862966234, 87.8290774745326, 60.30983032718782, 89.67222275272493, 71.21711807866251, 1.0258957347081554, 0.06478555830976655, 2.4119882381731466, 6.8846990600709, 25.08646765062886, 91.90900141193022, 90.3742564109064, 85.7357555820096, 77.98107285653391, 84.69187951857045, 90.16940670628702, 83.9034595797139, 81.05482255258869, 83.86502819676554, 79.83342001515051, 82.87703806354155, 82.03527389034149, 81.10041618347168, 80.32781908589025, 81.34625465639176, 77.4885251445155, 78.8612291889806, 79.8327689017019, 79.37355349140783, 77.82944971515288, 76.23654380921396, 74.92022775834607, 75.19573503924956, 73.0805577001264, 67.30139240141838, 62.29528703997212, 58.2827494221349, 56.40583645912909, 55.05036730920115, 56.7503813774355, 57.08548122836698, 56.61091758358864, 54.77752331764468, 57.494239268764375, 54.0280407474887, 51.550369724150634, 52.70997531952397, 52.099980077435895, 51.46401090006675, 51.00113591840191, 50.656449794769294, 50.4549890179788, 49.831292936878825, 55.00857445501513, 58.66542370088639, 65.11098400239023, 71.01769693436162, 69.22709572699763, 67.04461051571754, 67.42540205678633, 66.85244575623544, 62.49876783740137, 68.70462817530479, 69.27614888837262, 65.19703688160067, 61.63175928977228, 66.19038889485022, 67.56854503385483, 65.89871360409644, 68.07701756877285, 62.39422098282845, 54.28686226567915, 54.42457668242916, 47.17889993421493, 49.21690464019776, 49.81631340519075, 51.371199777049405, 58.44760664047734, 63.0026041307757, 65.33926202404884, 69.07996762183406, 66.65015343696841, 60.6480602295168, 64.06623717277282, 63.00939767591415, 67.923213589576, 65.05394097297423, 64.9628713823134, 66.10121773135278, 63.401128707393525, 60.292932756485484, 57.02119750361289, 56.78852250499111, 55.99850223910425, 57.13313802596062, 61.45152245798419, 56.30611019749796, 55.04271084262479, 54.79383253282117, 54.981984707616995, 50.99965326247677, 52.23240321682346, 52.3930674214517, 58.8092177914035, 58.87066172015283, 58.00225288637223, 55.367035942692915, 53.84714103514149, 52.163549930818625, 54.19713804798742, 53.76007226205642, 55.299018121534786, 54.30354410602201, 56.20147705078126, 52.54151736536334, 55.441721793143984, 54.396115964458836, 56.711620515392674, 57.78349053475165, 62.26610068351992, 61.35928400101201, 64.18351211855489, 63.367180593552135, 63.536442633598085, 66.29311576966317, 67.58387365648824, 69.62564776020666, 73.81757105550459, 73.32485860393894, 78.32144045060681, 74.46974354405558, 80.68456649780273, 73.63080347737959, 69.63806598417221, 65.79538660664713, 69.83645946748796, 79.38018229699905, 46.23342437128867, 1.5977034549559317, 7.895114364162569, 4.44466612031383, 0.3088792659822972, 0.34426480591777836, 55.04478969881612, 84.50716726241573, 78.82735560017248, 67.50733252494567, 68.25907045795073, 60.98761197059386, 27.312261712166574, 50.71775644056259, 72.40768294180594, 85.65510380652644, 45.303606910090295, 0.38599162332473264, 0.27865617806392334, 0.20629983245124742, 0.14686043404283064, 0.16827568652168398, 0.15785247808502567, 0.15769949032654687, 0.17843925243904515], [0.06309266870601044, 0.02384434683218358, 0.05443622756208624, 0.031040011522089763, 0.03390776015998375, 0.0427526167984451, 0.059469965316595576, 0.12057081691079563, 0.24764331478265025, 1.81575610272346, 22.52780164441755, 43.689284863010535, 49.82260096457697, 52.9794539174726, 56.106955774368785, 80.06291789393272, 42.263122835466945, 83.77811631848736, 32.174867160858646, 0.07075824023735139, 0.11865143724266561, 0.3117961304322366, 1.8348843988872345, 41.458256398477864, 89.3563856617097, 83.2423048634683, 80.89890049349877, 74.48385623193558, 79.52006970682453, 83.32522376891106, 74.83812470589915, 79.42201045251663, 77.51825671042167, 77.63002072611164, 79.11306104352398, 76.53463609756963, 78.27371305035007, 76.43800458600445, 70.65849411872126, 70.21992606501426, 71.35429120832875, 72.4084674158404, 75.00389191412157, 77.32945734454741, 75.1643168541693, 70.97047159748693, 73.23050991181405, 68.14386260124945, 63.07435212596771, 57.45554508701448, 52.73964020513719, 54.87246036529542, 52.89932773959253, 48.08400254095755, 48.09261214348578, 48.112549551071666, 50.212598308440185, 51.16144318734446, 50.87016013360793, 51.26451915310275, 47.404848067991196, 47.34083890914918, 42.835816337216286, 44.21228977941698, 40.77199066838911, 44.44804776099421, 42.22144765238608, 44.62293840223744, 47.79140549321329, 54.56076529718215, 61.43905716557657, 63.78683105591805, 64.51516812847507, 65.75698660266015, 64.1216798751585, 64.09545098581623, 63.228889588386785, 60.13952493667603, 57.34540101020568, 54.72278664189001, 56.51994997455228, 62.97514361719932, 61.52807927900746, 66.81253171736195, 51.95720188079342, 35.37018875921927, 44.60345598959154, 45.9016820692247, 43.878099918365486, 45.75598170680385, 46.27498188326436, 48.99850314663303, 62.85798634252241, 55.97505431021414, 58.508638720358576, 57.21317398932673, 62.74442980366369, 61.68604489295714, 58.43026584194553, 55.64848169203728, 60.291379497897246, 57.11905671704201, 56.43736447057417, 53.06162365021245, 50.83309765784971, 51.29545096428164, 47.70374051986202, 48.331464875128965, 53.61876103185839, 54.100953686621885, 54.36444282531739, 49.47281968209052, 46.74628603842951, 45.22321008866833, 43.21130875618228, 46.11047767823743, 47.16522655179424, 49.78025897856682, 58.20252910737069, 51.13649691304853, 50.360914891765965, 46.59576508306688, 45.565872269292036, 46.591705429938536, 47.70212058098086, 48.687812205283876, 48.03309802086123, 49.1625915804217, 46.041510643497595, 49.91649858413204, 48.26137212014968, 53.74268831745271, 53.82111610904817, 57.66330911267189, 55.648913152756236, 61.61001759190714, 60.53951255736813, 65.44797051337459, 64.56251113645493, 69.24018075389247, 67.650585328379, 68.16344307314965, 67.25097425522344, 69.44913325771209, 66.37028448043331, 66.31752075687533, 65.98253465467884, 74.41843894220169, 72.43812053434311, 79.0550962571175, 69.99085964695101, 87.93240054961174, 24.936982200991725, 1.1675411631022732, 2.6081393514910056, 0.28930954995655245, 0.36459524725233355, 15.821555718298882, 72.65923238569691, 64.11990696384062, 62.79710331270772, 44.10380094282089, 41.08200303969845, 35.12169484169253, 35.96965243739467, 44.92174848433464, 56.40445970719861, 45.53222225558373, 0.32012387389136904, 0.050992719799039826, 0.017669716466879173, 0.028459854206190478, 0.15762548623306138, 0.049240948677423506, 0.10530493687838317, 0.043841246891045765, 0.07735301620296894, 0.050105409952060836, 0.06571278516804019, 0.02391675363234695, 0.02308463275943312, 0.11458069882205418, 0.14346539283231383, 0.1502746887384884, 0.15076570513267673, 2.750074483694569, 35.33112979704334, 60.349556092293035, 65.92050629277384, 64.82094041762814, 33.48914554042201, 73.87428068345594, 53.44478430286531, 94.53982137864637, 35.45178582591396, 0.14607606726067682, 0.0373903613898062, 1.1541836540545187, 2.172913892615226, 47.55702426356655, 91.47833301175027, 85.20313693631081, 82.92389469762003, 78.18482429750505, 86.14183856594948, 86.98121793808477, 75.73568067243023, 79.08834226669805, 83.03284245152628, 79.42925114785471, 81.47293152347689, 78.15841105676468, 81.8085059811992, 77.06140256697132, 75.19474660196613, 72.57307360249182, 74.67976293256207, 75.13437348027384, 78.40260213421237, 78.57444901620188, 79.8701883131458, 73.19007027533748, 75.58135109563028, 72.43235465018981, 67.73347285486037, 58.94621833678215, 55.01294789775726, 55.87161356402982, 53.751290075240604, 51.087306468717514, 50.61845379491007, 49.74662073196904, 52.20457792282105, 53.43901057397166, 52.42021414541429, 52.163553853188795, 47.03578441373764, 49.9983702167388, 45.24836032621322, 45.38615711273686, 45.000709718273534, 44.7995941100582, 45.67557311827137, 47.50101673987604, 50.34208359256868, 56.01134800141858, 66.11282010232249, 65.39714836305188, 66.74530229260846, 67.47785983547088, 66.76359622709214, 67.4537294141708, 66.25929709403746, 61.66513865993869, 59.937385589845725, 57.957769286247995, 59.898059906498084, 62.81827234452771, 65.23125956135412, 66.48972849692068, 59.00104914942096, 41.69736800655242, 47.20445417588758, 46.560546121289654, 44.73628705547702, 46.20817607448947, 50.14864406278057, 51.94778819237986, 65.91330482113746, 61.7657043087867, 62.22173475450086, 60.906167876335886, 64.410503602797, 64.49127304938533, 59.72816636485439, 58.10011994454169, 60.278102274863954, 60.81900888873685, 59.882350813957956, 55.181248957110995, 54.77711931351693, 53.13074757975917, 49.33581521434169, 50.832838781418346, 57.069211236892215, 57.437968946272335, 56.60183337426955, 53.7010915817753, 49.0526593116022, 46.88104691043977, 47.580636932003884, 48.38800976353307, 50.26606021388885, 51.8171222748295, 60.41739348442324, 54.44825995352961, 52.23383488193635, 51.6726613813831, 46.45102177896808, 48.992811787513, 49.847053020231186, 50.78937107516874, 51.671994578453806, 51.7407968736464, 50.227911241592906, 52.89220079298943, 51.80038552130423, 56.07480410606631, 56.69121242338612, 61.073931570976015, 60.162808126018895, 65.85152749092349, 62.5118685537769, 68.49232596735801, 68.17985426995062, 69.8966129364506, 70.50063440876623, 70.17586215849846, 69.82269194818312, 74.00386794920891, 68.49076486402943, 68.7900338634368, 64.88715002613684, 75.30822077105123, 73.57042251094695, 81.36028105212797, 73.97735272684406, 90.92290186112928, 33.6079776671625, 0.37671074391372744, 0.7858125432845086, 0.29802585321087993, 0.46325560478914174, 15.817593143832301, 78.45819780903479, 70.12298860857564, 69.54338781295284, 53.405564523512325, 31.49806610999569, 29.045500216945527, 51.14892298175443, 50.14483936371342, 67.0331101263723, 53.15419943101945, 0.1544797759983809, 0.014511359078178724, 0.056186765282144474, 0.03750817422124167, 0.23926154680309758, 0.07220757133778065, 0.059206465544599685, 0.07488467325005801, 0.19757726259769934, 0.11486177648147268, 0.1645466003326639, 0.1117228308031636, 0.19070588292614107, 0.2545730397105217, 0.24135816091250992, 0.2229882611502563, 0.31652721366094005, 3.320665595031554, 54.47032328574888, 70.53792830436461, 69.48619965584048, 70.33896215500371, 80.96245073503064, 107.15029639582481, 58.024998711001494, 102.87804295939785, 41.33490962366904, 0.38342204185262807, 0.22863650484190834, 3.7563634543649616, 3.6934515785786415, 52.16513456836824, 95.41880100004136, 89.45146391468664, 86.3754000202302, 82.84582384171026, 89.42847882547687, 90.46385903512278, 77.20158023218956, 80.47005207307878, 83.54238187113117, 83.75222867535007, 86.05844113134569, 81.44116816982147, 84.09960946729107, 78.467148657768, 77.65670068802373, 77.00208848522556, 79.7562042359383, 80.60519341499575, 79.82739525456583, 82.12126793399935, 81.12909655417167, 78.13604570204213, 79.5123504823254, 74.73400146730485, 69.42617170272335, 62.302417908945394, 56.07029730273832, 58.047979877841094, 55.73291070999638, 55.71729183197022, 55.042906961133404, 53.518650377950365, 56.19256150337958, 55.92849577626875, 54.9993686522207, 54.47015070146131, 49.985646047899806, 51.546482655309866, 48.72454520194761, 48.81009209540583, 46.86512208754017, 49.36995552432153, 49.00244905102638, 50.14817730073006, 54.25735035250264, 58.80779789340112, 67.13156161769744, 68.99914326206331, 70.65701146279612, 70.05374308555358, 70.1633890213505, 70.00727084375197, 68.06335203109249, 64.60934815868255, 62.62183612392795, 61.499112575284904, 64.0116770036759, 66.8972235341226, 68.38258589467695, 71.51360219524753, 62.00251740794029, 49.11040444527903, 48.954682427067915, 47.9804951144803, 45.399253906742224, 47.58301781069848, 53.26028777707008, 55.4670956057887, 69.52256002733785, 63.504369412699056, 63.68205278150497, 63.309168738703576, 69.30221696053782, 69.17943892940399, 63.331612540829575, 61.386564085560465, 67.06219057882986, 64.7236656373547, 61.614606765008745, 58.35097120654199, 58.732919846811605, 55.49808625252017, 53.42301514840896, 52.355240083509884, 59.19188422541465, 60.6277854980961, 59.907277476403024, 56.148729016703946, 51.882261076281154, 50.6724295308513, 50.85045022349204, 52.76909328276112, 50.84006378727575, 53.16685691956551, 60.32665337285688, 56.18902744785432, 53.46656522443218, 53.698271397621404, 50.00690921660393, 51.29554510116578, 53.380841824316214, 52.77884037263932, 54.47541059986238, 53.58032572653986, 52.739130297014796, 55.61938555009904, 55.00913927631994, 59.800573318235344, 59.572016808294485, 63.894021587987105, 61.90508181048978, 67.51835438512987, 66.04657911485242, 74.32288216006371, 72.42663583447857, 73.84965604351413, 74.91820381533715, 72.78781552468577, 74.59590265827795, 78.25794512225737, 71.39429938408637, 69.39998595945298, 69.0833330154419, 79.75263487908148, 77.85348599956882, 86.03312615425357, 77.00894478828677, 95.61176592303862, 30.806999398816018, 3.33921718020593, 10.741200870083226, 0.8233589414627323, 0.6932298370426702, 20.454224963341993, 87.44403408419701, 76.71040534973145, 78.74254611230667, 61.50012062441919, 59.23816819344798, 44.410255724383944, 54.22283349498626, 58.04348876399379, 75.29855605094664, 66.20914566901423, 0.6527108951441704, 0.13936545880090806, 0.18761910017459624, 0.14875653229894178, 0.3402062559560422, 0.14332044899703997, 0.17578281191808565, 0.2758937262960019], [0.020086009490994677, 0.029113398068734718, 0.011963567061860476, 0.021879831178774758, 0.03431985034577308, 0.022053434363295956, 0.028149144265860803, 0.03664789578667091, 0.13658040743922034, 2.441950733623197, 26.503455254339404, 47.07911483703121, 44.897445478746974, 31.59724520098779, 37.43919980141425, 57.36637784588722, 48.23846547834335, 87.03160470531833, 13.947027556357847, 0.29196070447083444, 0.5596290060108708, 0.9840720531440551, 6.041504202350494, 51.673547837042044, 81.28042159541961, 86.74815070244574, 77.25663461992818, 73.58233867153045, 83.16712087200534, 76.22253310295844, 78.75013197621992, 73.5066447719451, 70.37452236298593, 75.1035201164984, 75.52890900642642, 78.10906763999694, 76.51631078412457, 76.7785212301439, 76.63686090900053, 75.93999693470617, 76.27181376180341, 70.79816972055744, 69.21465396881104, 67.42733970765146, 68.64024639129639, 70.69998495040402, 70.79891497089018, 70.40795664633475, 66.93294063691171, 58.53884097068541, 54.37881046725858, 54.039337173584975, 52.513625391068004, 46.37852853344333, 48.439769360326956, 49.7364108024105, 48.661551936980224, 48.92560981935071, 51.5164412221601, 52.569534855504195, 51.37305898051108, 50.51641725724744, 45.93806205257293, 41.90994085804109, 43.747602662732525, 46.00917462379702, 43.95845359371555, 40.85931047316521, 47.04865763264318, 50.66594585295647, 59.41269797663535, 61.76494729134345, 64.21056078326318, 60.97482896620228, 63.47583809206563, 61.21296390410393, 61.249842028464045, 61.12141578428207, 53.15354439520067, 48.71035406666417, 53.69873031493157, 61.46567829193608, 60.883422051706624, 60.33422746965962, 49.859534002119496, 27.334332889126195, 57.796422589209776, 46.91046860910232, 38.433465726913944, 44.78274360779793, 40.4860734170483, 48.26327054731308, 56.19632305637483, 55.32634135215513, 56.269918487918, 60.24074562134282, 64.8389127177577, 62.67194832524946, 56.26808281867736, 50.031004336572465, 54.57196758639429, 55.923561434591974, 56.13932709540091, 52.90961611655451, 51.85488293247839, 50.29980436448128, 50.41963669561571, 53.35907266985986, 55.17428282768496, 51.887909289329286, 49.91969139345231, 46.602401733398445, 44.36195173571187, 45.05401865128548, 42.81618095213368, 49.5790139321358, 49.15849270359163, 44.45409997817009, 48.81310447569817, 52.25425474105343, 50.102422852669996, 48.33607758245161, 45.95596767240956, 44.88161871510167, 45.92060750530612, 48.080284134034194, 48.43243452810472, 49.369759405812914, 49.08752526006391, 48.49372548441733, 51.818098945002404, 52.980654162745324, 58.08416374268071, 61.46449373614404, 64.40489461345058, 64.4640439556491, 67.05860553249236, 65.59341199936406, 66.67673141725602, 63.78361471237675, 68.84568445144161, 65.01955355367353, 67.30106292232391, 65.05688275060346, 70.29136811533283, 68.4098385226342, 75.83781919171734, 72.90107004104122, 76.35522688588789, 69.40978404014342, 76.37353650985226, 70.19825104744204, 86.61906550007483, 8.549032307440235, 1.0405267270341998, 0.5031738111809377, 0.08379408428745885, 2.1082268991777977, 59.3029147578824, 65.70540351252403, 65.52252692560997, 51.08857339428317, 54.83658636769941, 28.583707809448246, 15.362121635867705, 45.78294015699818, 61.5939986321234, 46.54783764193135, 0.9559146447047111, 0.29145493322322447, 0.016245210445636225, 0.11147255753918041, 0.07608252832846296, 0.032986236826306393, 0.027264036921664115, 0.04981687442669946, 0.010757405675136516, 0.041122810704813856, 0.05801264008867645, 0.06893911083499271, 0.012091254766639924, 0.020792371285478436, 0.10293686717388131, 0.10658645641899879, 0.0982520939602006, 3.2909725173827145, 41.96756439824259, 57.40329911631923, 55.100722697473344, 41.51924925465738, 39.54840337076495, 64.27653504956153, 57.61608769816738, 94.52781892591908, 14.284285691476638, 0.32898343558753695, 0.48689934575269306, 0.6345288707844673, 8.466318345838978, 61.37466753682783, 85.66312113115865, 86.8117872361214, 82.27736257737683, 76.90075797419395, 86.30363633555751, 79.42459137209, 79.82172350729667, 74.63262388783117, 72.5570938664098, 75.91017907665622, 76.51893877214002, 79.97643747637349, 79.20700180915095, 79.58890730334868, 79.79636146176247, 78.27299917897871, 79.13196686775454, 74.373535648469, 70.90872564623433, 70.02673364454701, 70.04039918222736, 74.0963888168335, 72.85209532706969, 71.91329171580654, 67.9701094473562, 60.721130063456876, 55.57292507540796, 54.16407638980497, 54.13354073801349, 49.0971899801685, 51.566325926011615, 53.359515897689334, 52.53895605764082, 51.533221121757265, 52.91339728140062, 55.06805327630813, 51.57976396622197, 52.46344650945356, 48.79445752789898, 45.928467935131444, 49.20964041063863, 47.12269236964565, 46.77184028010215, 44.07574030660814, 49.60641168778943, 52.37145516180223, 61.88758019478091, 65.92931593618086, 65.51347409525226, 66.10946255345499, 65.9974318165933, 62.75497313468688, 63.19402756229524, 64.14164081696542, 55.46447938488376, 54.04057272018925, 54.96149424583682, 64.48509531636392, 64.25092589470648, 64.1864852751455, 52.76805385466545, 35.018622798304406, 60.603251072668264, 45.83501354340584, 40.12780020313878, 45.34970652672553, 43.090009458603404, 50.383801921721435, 60.359432620386926, 58.764330187151515, 61.173626453645774, 64.0901557860836, 66.70588247237667, 62.21902439671179, 59.31973780355146, 51.53877127555109, 58.55478932780605, 58.24083497447353, 57.76199202383719, 55.806302178290586, 53.11107297097483, 53.610751551966516, 52.2646450996399, 56.474289663376354, 57.17570358707059, 55.68457534236293, 53.94794202619984, 50.596068828336655, 47.65382443704913, 45.63777323692076, 46.83033066411173, 51.669907877522135, 50.08916524148757, 45.239872317160334, 49.054573428246286, 52.56805612194923, 53.2973777094195, 50.06991424868184, 48.5052062619117, 47.41052766000071, 48.00603366667225, 50.375019734905614, 51.73059871119838, 51.10535721625052, 51.61477504238006, 50.34171488977248, 54.073026410995, 56.121911771835826, 60.18498912934334, 63.00720114861766, 68.67873268742716, 67.27894075455205, 69.71397169174688, 68.31409346672797, 69.20100412061139, 67.05030579720774, 71.9750141328381, 69.43094914959323, 70.5617057123492, 66.16529357048773, 71.9498089821108, 68.9714591733871, 78.47717423592844, 73.26228111020981, 78.19809759816816, 71.77724822874993, 80.3376171665807, 72.23927205608737, 93.96056575159874, 12.950649434520354, 1.3280808324775388, 0.4524788314536695, 0.23828084700770918, 2.099486142396927, 65.16205718440395, 74.08964234013712, 70.72385649527274, 60.51506050171391, 48.349378339705936, 33.31252121156262, 26.482741217459402, 51.25729414724535, 70.75485106437438, 59.63261742745677, 1.2128244364453902, 0.13171797077501976, 0.036853816390277884, 0.021434590453282002, 0.07282594984938061, 0.03207615310055835, 0.07348034215430099, 0.041187533643096685, 0.12303241062909366, 0.13268887996673584, 0.11845096735463989, 0.15870170187084906, 0.06341669708490372, 0.12575311826602106, 0.21887334243905163, 0.1877302135671339, 0.26267025199147964, 4.166706867756383, 61.61037452759282, 71.86079471342026, 64.41892100918677, 42.70068676240983, 61.15070412235876, 75.85874111421647, 64.97259493797057, 104.22460832903462, 17.90137779328131, 0.48421359470775055, 0.9615638383453893, 2.961037937671908, 8.993921260679922, 67.45951883254513, 91.38540421762775, 91.37965402295514, 85.15655486814438, 81.01566945352863, 88.82697551481186, 83.53237198245141, 78.72280090085923, 75.33320626904889, 76.01992699407762, 76.61020448130947, 79.80834038026872, 81.5301981279927, 81.86854962379702, 83.1245788451164, 84.75998755424254, 81.92452969089632, 81.39117363960513, 78.43668753100981, 77.70918200092932, 75.52977192786433, 72.13439572242, 75.19116940036898, 73.99448563975673, 75.67175388336182, 72.12221284066477, 63.398681148406006, 59.7178073852293, 58.566850616085915, 57.736022010926284, 52.26234659071892, 53.0109074038844, 58.44487274846723, 55.018125426384714, 53.61749410629273, 56.19223594665528, 57.70606294755013, 55.60667707074074, 55.877630479874156, 51.63877210309429, 48.01828715109056, 51.05313085740613, 52.95306421095326, 48.300827241713, 46.05250112472042, 54.163405664505504, 55.30290126800538, 64.62856385015672, 68.08197544467065, 69.90065297772809, 66.87481895569833, 68.08602333068848, 63.98929203710249, 67.7745714495259, 67.12679986030825, 57.78591455951814, 56.79801464080811, 58.92609657779817, 66.4629622428648, 67.16119120197912, 65.8003640943958, 59.02869401439544, 39.782035427708784, 62.67813782538138, 44.685841452690866, 42.42429694821758, 44.60297353806035, 48.322035497234715, 53.93047178945234, 62.59232813312162, 62.682330839095584, 64.0230950232475, 66.28778919096916, 70.96631388510428, 65.84814640783495, 63.03102170267413, 53.897637628739886, 59.24906453778667, 60.78346044786515, 61.59384958205685, 58.067054363989065, 57.39430119914394, 57.98200561154274, 56.36633034675353, 59.13413516936764, 61.27439998811292, 56.79360589673443, 55.46351840419155, 53.59207714757612, 51.88425364032869, 49.63617071028679, 50.49022366923671, 53.4937511720965, 52.667978502088985, 46.512551999861195, 50.64483957905924, 54.75568356052522, 56.43525815779164, 53.65568622466057, 50.372325066597234, 50.18847180951027, 52.59466548119822, 52.35446345421576, 53.744335712925086, 53.43877523176132, 54.99671320761404, 52.43120070426695, 57.03806369535385, 58.50366123260991, 64.33254649562221, 66.65371494908487, 73.70506178948187, 70.99544140600389, 73.99559959288567, 68.94281802638885, 73.30031241140058, 69.28828470168575, 76.44390383074361, 69.3981267559913, 73.12201715284779, 66.73406077969459, 74.51344659251552, 70.66469930833387, 84.98024432889878, 77.40411573840727, 84.13592277034637, 73.16162524684783, 84.75749292681294, 74.92459727871802, 99.15419963098343, 10.648984966739532, 2.3726954046756994, 1.3839275389909746, 0.2071769571592731, 3.3004080239803564, 76.85822379204535, 77.47459288566344, 82.51775680049774, 67.60718822479248, 80.04974657489409, 43.60578544678227, 27.426634104021137, 63.759723555657175, 79.74746519519438, 68.58227376014956, 2.9856042323573946, 0.5371646114414739, 0.2545561398109121, 0.3512111396318482, 0.1554129936642224, 0.16068410759250965, 0.18388195474061275, 0.2011655877915121], [0.07094043126750378, 0.030097298196426807, 0.043494094148158066, 0.04647154466158921, 0.07139163407226724, 0.090228533372283, 0.006219942072000836, 0.17011094207484878, 0.10820957456505108, 1.4313449494300352, 24.285782460243475, 43.03646126101094, 48.60176324844361, 25.01232504844666, 32.33659432780358, 54.98016865022721, 58.154609510975504, 75.41148108820762, 3.698350864072, 0.12405008182770784, 0.3266019440226017, 0.5346319247638026, 22.967346368297456, 67.81064941037086, 76.68935791138681, 86.60088923669632, 75.49202303732596, 84.71586873454433, 80.73405111989668, 87.71816069079985, 76.81145345011066, 66.51924041009718, 80.70350370099469, 77.16379996268981, 74.21403638778195, 78.05936336517334, 75.61146705381333, 73.03916100532778, 70.45986529319518, 66.91026149257537, 66.42777858241912, 66.98065234768775, 67.9856106542772, 66.12932543600759, 69.13925816935878, 71.81613460663827, 72.44549459026706, 66.56273949530818, 59.30320893564532, 53.118960857391365, 52.63674074603666, 52.824245729754054, 52.467110003194506, 49.05515393903179, 46.024679753088186, 51.66941365888042, 50.86036989765783, 49.79400296365061, 49.637021864614184, 53.335165823659594, 48.952631027467795, 49.23912094485376, 48.72736930847169, 44.54002341916485, 40.87201895252351, 44.27919756981635, 43.57057825211556, 40.53842529173821, 41.797647322377856, 46.99439556367936, 50.09166379128733, 60.4516161641767, 63.89313120995799, 65.54417448659098, 62.39089089055216, 62.38338347404235, 58.55136902101579, 57.70756521532613, 54.522502576151204, 52.58025077081496, 54.61472142127253, 61.761385779226984, 63.09928271078295, 64.661962832174, 46.545707794927786, 31.883372299132812, 59.75559942183956, 58.41676896618259, 40.29257505170761, 40.110588842822665, 39.80455375486805, 42.1548261950093, 63.972484680914114, 60.1636161342744, 58.14299929526545, 56.05404300074424, 60.975142755816066, 60.872933633865856, 59.37698871858659, 47.389205655744, 51.0235091178648, 52.96623552999189, 54.118121900866115, 51.67068450681625, 51.712908821721236, 51.10608285473239, 52.15345374999508, 52.34121761014385, 52.967529912148755, 52.367434732375614, 48.48459812902635, 45.731874819724794, 43.43946126199538, 41.92778764232513, 44.04843668783865, 51.3624019007529, 46.325403951829486, 47.054580411603375, 45.91739900650517, 50.02563461180657, 51.2514498156886, 47.74917333356796, 47.45664296611663, 44.53591669759443, 44.45579444208453, 47.72952618137483, 49.678901010944, 49.354513152953125, 50.86246836570002, 49.32954726680633, 52.979708871533795, 54.43435907363892, 59.9694666554851, 63.014112364861276, 66.70308190007364, 65.63887619203138, 67.49738539418867, 69.09204852196478, 68.96989022531818, 66.50405299278998, 67.61164403730824, 70.97589231306507, 68.71627761471656, 70.17766644877773, 71.71638873315626, 69.65866627231722, 71.51735198113226, 68.94920364502939, 70.49642962794151, 70.4493768753544, 71.16224411995181, 73.13090524365826, 80.1858606646138, 64.5265273124941, 0.5927199593955471, 0.34845303924333665, 0.17549234202071545, 0.17545337878888653, 33.199172558323035, 70.76906573387885, 63.7994767773536, 55.850554358574655, 44.823014582357104, 24.54356651152334, 43.6810008172066, 42.1782035212363, 54.70976829528809, 45.672576427459724, 2.5974410868460134, 0.3080603792782753, 0.06193021455058648, 0.06529452414402077, 0.07045855430225212, 0.048806270389186765, 0.12340089125979332, 0.04084048432207877, 0.029834853710546613, 0.04138704592121705, 0.06747281088704063, 0.03637405765813686, 0.0010159045280400485, 0.02467766663269891, 0.06374703419785346, 0.09557287764525223, 0.1362442020927706, 2.5357284757398793, 38.44005530880344, 57.24653767001245, 59.632205578588675, 33.900209934480735, 40.15673552789996, 64.30542722825082, 67.87718849797403, 82.4118528058452, 3.712006105530647, 0.17418250020953918, 0.30814562954248925, 0.38595099002122885, 29.28438432755009, 78.85771474530621, 80.11112382335048, 89.11616402287638, 76.39028503048804, 85.41794161642753, 83.10130350051388, 87.2450993137975, 78.35354897283739, 72.19254878259474, 81.85323669064431, 81.12916715683477, 79.23171274123654, 78.08441162109375, 77.50634054983817, 76.14010057141705, 72.81785303546538, 70.68541726758404, 69.72614672876173, 71.49293130443942, 69.24117703591624, 69.58872256740447, 70.7370670380131, 74.19717019604099, 76.40399763661047, 71.79778575897217, 62.51398663366995, 56.48968496630269, 54.77331069207961, 55.60054248379123, 54.57536828133368, 52.9845255421054, 49.58239893759451, 52.8035669942056, 51.60886010816021, 52.37913516259963, 51.089048001074026, 54.17588272402364, 50.076237109399614, 50.38226827498406, 50.86717128753663, 47.552603752382346, 43.73796147684897, 47.30405884404337, 45.82009676964053, 45.37822215787826, 44.23115637994582, 48.58397529971216, 51.51434667648808, 63.6771890424913, 65.63502442452216, 67.15656280517578, 66.5655557570919, 66.12179448527675, 62.346783837964466, 59.16778518307594, 54.175278679017104, 54.974265483117875, 56.202034027345725, 64.23826840616042, 66.28966408391153, 67.45336855611494, 50.48423420998358, 37.20690919506935, 64.11267411324286, 61.24755136428341, 41.753650096154985, 43.049436461540964, 42.592786281339585, 46.600566064157796, 66.21643343279439, 62.83051406183551, 59.34753956333284, 58.14765907103016, 61.96320349170316, 62.71870297770347, 61.846654184402965, 50.26356166408908, 51.23486995697022, 54.82537623374693, 57.84660539319439, 55.15362370398737, 54.63391357852567, 53.05694426259687, 54.566178168019945, 53.722892115193034, 53.67131686979725, 53.684044961006414, 52.72712784428751, 47.83904267895607, 45.88711046403455, 44.28563417926912, 46.84708702948786, 52.763021453734375, 46.785603877036806, 48.60943932687083, 46.643390501699145, 51.52394863866991, 52.75365091139271, 52.83002730338804, 49.03169816540134, 46.56033823567052, 47.73697868470223, 50.61542180276687, 51.06011267631285, 51.00178703185051, 52.881080873550914, 52.62414993778352, 55.50849622295749, 57.87195959398824, 61.76306455366073, 66.07140771804318, 70.2967417624689, 67.61412297525715, 69.84683021422356, 72.86163453132876, 71.82892153340002, 67.74754631903865, 70.4867256841352, 71.2492109114124, 68.2332298832555, 72.4638669721542, 74.24360321414086, 70.53013847720239, 73.75970825072258, 70.58421227239793, 74.07300364586615, 72.97711695394209, 72.61204627252394, 77.33206964308216, 82.82672974371141, 74.74822398154967, 1.334058034323877, 0.43380936066950526, 0.21905478270303821, 0.32435917565899514, 35.08770358177924, 78.43809958427184, 71.94053649902344, 62.53745809678109, 52.108801487953436, 19.86189215413986, 41.408512899952555, 53.43591974627588, 61.31162720341837, 54.98297314490042, 4.076675479450534, 0.22017812806992765, 0.04100964036619952, 0.1271939764340078, 0.07231925163538226, 0.08854500153252194, 0.11387545360072006, 0.04597273715321095, 0.13777337487666838, 0.12940239341508958, 0.14206758880567166, 0.1692425354474014, 0.1422260923972053, 0.11496660795303122, 0.14169102594737085, 0.27660113188528246, 0.25053796268278555, 4.2082928169158205, 56.27150704783779, 70.40393229453795, 71.39153019074472, 40.21064458354827, 49.60467407780309, 74.86140789524202, 75.4319715499878, 91.68093127589073, 5.015099356251379, 0.19716293160473147, 1.1950344039547829, 1.3176250193388233, 29.562941251262544, 78.99546054101761, 87.37049748820644, 94.91059518629505, 82.89202151759979, 88.6704807896768, 89.9328956296367, 86.64973843482234, 76.86539388472035, 75.6412535329019, 83.540875680985, 85.21105227931854, 80.15605849604454, 84.32686375033471, 82.97593670506632, 78.0966886397331, 76.06523036956787, 73.35050306012555, 72.8116870695545, 74.96572725234493, 71.68838301012593, 70.7706895951302, 74.74890647395965, 78.34787722556823, 77.06653302715671, 74.56918347266414, 64.11821249992617, 57.8885002290049, 58.14121461683705, 56.92997886288551, 57.83199848667268, 56.44080438921529, 52.87965705317836, 58.5112000280811, 55.70025305594168, 55.08181687324278, 53.781880640214496, 56.07986396358859, 51.520351825221894, 52.97183275222779, 52.90891793466384, 50.94814077500374, 47.3290325749305, 52.01879093723913, 49.839792713042236, 47.25229532487931, 48.423828847946666, 50.09187952164681, 54.31966504743023, 66.35742695100846, 68.74928043734643, 71.23136412712836, 66.55367882021012, 67.50892500723562, 64.76826298621394, 63.35658627171671, 57.554765362893384, 59.29437968038744, 58.610224185451386, 67.7562226018598, 69.75850628268334, 70.53315870223507, 56.655028558546505, 43.42197925813737, 68.79323451749741, 64.32852214382541, 40.259117234137754, 43.200169224892896, 44.96049365689678, 50.11477047397245, 69.98059088183989, 65.80645161290323, 63.08555441517984, 60.34739486632809, 66.85975705423664, 64.64775600740987, 66.30211368683847, 54.01927817252375, 56.44859421637751, 56.337085154748735, 59.92268846881006, 57.58230040150305, 58.513792714765, 57.36740942924254, 58.77572075013192, 58.784636297533595, 58.68765961739325, 57.57316912374189, 55.166967607313595, 50.624521701566636, 48.902550205107666, 46.827785045869895, 49.06684652451546, 55.95854505415886, 48.7268005647967, 48.21641391323459, 47.87831737149147, 52.970632506955056, 54.69465540301416, 55.77787283928164, 51.97513103485108, 50.66585956081268, 49.8311399644421, 52.79598113029234, 52.70039689156317, 53.42479982683736, 56.84302383853544, 55.370958312865234, 58.6828782481532, 60.53927329278762, 65.15483610091671, 70.14100013240692, 73.78881223740117, 72.45857177242156, 72.25029391627159, 76.80711530870008, 74.4641580889302, 70.21607429750505, 72.18594351122456, 74.95476815008348, 71.26542598970475, 74.36341593342443, 76.72467493241834, 75.26365480115338, 78.49524067294213, 74.81214292587774, 76.25931709043442, 77.42613592455464, 78.16731483705583, 81.18704565109746, 85.80508739717546, 75.07574189093806, 0.8159258661250915, 1.3769129928081267, 0.9078829543244455, 0.38234571896253094, 43.62143570376981, 87.09133455830236, 78.77945561562815, 71.50298826156124, 64.51880024325463, 36.97970982520811, 56.23740988392984, 63.6154156346475, 69.9888749276438, 69.62775015061902, 5.808426670489773, 0.4489958280276868, 0.18908370706823566, 0.36068203949159194, 0.18642460056129964, 0.19102811482885193, 0.2687565447582353, 0.0803938260181777], [0.06212638285491736, 0.1432093509262608, 0.049491953555374384, 0.05866233244418137, 0.03225650743491227, 0.08156862951094106, 0.12125309481615983, 0.05526885788346972, 0.07217002536861167, 1.3016245682393353, 28.144145434902562, 43.17797253208776, 33.752846487106815, 32.620077748452466, 56.225066184997566, 44.57670934738652, 70.61165317412346, 63.09349721477878, 0.4154586743923926, 0.06316083137907329, 0.49013091912192686, 1.0485326522781004, 58.395898034495694, 89.311003838816, 78.88169611653974, 73.39253517889208, 77.46855243559807, 77.73803495591687, 88.8473012370448, 78.06131670551916, 65.58905424610262, 78.95036897351666, 76.46639470131167, 76.89942436833536, 74.51360348732241, 72.8890440540929, 71.43280136969783, 70.16800957341349, 67.01838554874544, 69.88091561102098, 68.44481037509057, 66.13621311803018, 62.23523555263397, 59.51957471909062, 60.12345498608005, 64.98573880041799, 62.70557480473673, 56.50170310851067, 51.253532594250096, 50.90109194478681, 54.97537159150647, 51.02577232545423, 51.07864195300687, 49.22858153620074, 48.272295921079575, 48.35694459176833, 52.23817302334694, 51.4461366591915, 51.01595855528309, 50.91541251828594, 51.77459985979142, 45.72309263290898, 46.577337787997344, 46.02447186746905, 43.82248463169221, 42.97325618805424, 42.863520037743356, 41.84700642862628, 40.937942228009625, 41.88155466510404, 45.69827187445856, 50.85092875265306, 60.8947459343941, 61.353153336432676, 61.6742346363683, 60.20203575011223, 59.923551390247965, 51.079077336096, 51.00669391693608, 53.449671576100016, 57.26162310569518, 59.77756469480453, 60.64480073990361, 59.6140528494312, 47.88594245910645, 32.42801300940975, 28.144747518724014, 39.0027585337239, 47.75884197604272, 43.45924177477437, 38.47479574141964, 40.91338426836076, 51.80548852489841, 59.41112902856643, 54.777244829362445, 55.768980826101, 55.520698716563565, 59.52882759032711, 60.97836302172754, 52.576147971614716, 45.12282094647808, 48.91959290350638, 50.40399820573869, 53.80901167469641, 51.321456278524096, 51.44960011205366, 53.45517466145178, 50.97911573225453, 49.89466667175294, 50.22435365184661, 46.488409811450595, 41.13002854008829, 41.07347972931401, 40.72531054096837, 47.28346247826853, 44.66638257426601, 44.75150585174561, 46.82275264493881, 46.330914881921586, 47.88861751556397, 46.74980440447408, 48.1248422591917, 49.009419102822584, 45.22472412355485, 43.81426726618121, 47.29258983365951, 48.39375995820569, 47.863820291334584, 48.91017529272264, 51.287512087052875, 49.186788682014715, 50.48854097243279, 56.76992654800416, 62.77864856104698, 62.79751123920564, 66.58836041727375, 65.77113066950153, 65.86001549997638, 67.43676124080535, 68.37434107257475, 69.27696474136846, 68.54036715722853, 68.46096269546017, 68.00115892964025, 66.61385582339379, 67.606858745698, 70.28520214942195, 69.89171781847554, 63.67388248443604, 62.513657154575476, 64.86629478393063, 75.13642880224413, 73.0790985784223, 88.33689105126166, 29.74974216953401, 1.4142359384605963, 0.6649893233853003, 0.502122646618274, 7.996243363426578, 68.92155093531456, 62.109048981820386, 60.02525060407577, 45.94728746721822, 49.381149968793316, 29.556198696936335, 33.95214996030254, 58.89454110976189, 61.93317382566391, 3.3865547949267976, 0.1908998563885689, 0.0917863655054281, 0.03684470760485819, 0.04357977725204922, 0.0972461439068279, 0.022784372258390632, 0.01602294727138454, 0.06604611768477386, 0.12371596024041215, 0.009706746730502817, 0.06535737399732874, 0.036559684592629635, 0.08111562639955552, 0.03880552879925217, 0.10159491861779844, 0.0106022336084636, 1.9542996104686492, 47.94350324138519, 55.12299391531176, 45.776499625175234, 34.83411058302849, 58.23692437141173, 55.260174889718336, 77.96917238543111, 69.10390192462553, 0.37003198938985027, 0.1315560657531023, 0.3738732768162605, 1.6708217056528216, 66.09655795558807, 90.3456780218309, 83.66774866657873, 78.08980880245086, 82.285811362728, 80.53490454150786, 91.13361158678609, 79.627087654606, 69.82320185630553, 82.28022590760263, 78.42776021649762, 78.33163861305484, 77.70675797616282, 77.12263861010152, 74.751918854252, 74.42273785991054, 71.1085625617735, 73.30596846918907, 71.63550161546277, 69.64405936579551, 64.8445373965848, 61.83635404033046, 63.36307779435189, 68.19242154398273, 64.4551754766895, 58.72923281884963, 53.57492070044241, 53.3313258232609, 56.28476465902021, 52.59571275403423, 53.3953663610643, 51.89112955524076, 51.3621469466917, 50.906206715491514, 53.25276859344975, 52.99602593145063, 53.618113840779955, 51.16221589426841, 51.70433844289472, 46.68620709450015, 47.939926039788034, 50.429250424908055, 46.56126783740136, 46.49781957749398, 44.56367531130391, 45.534089303785755, 44.17197958115609, 44.15565467649891, 47.78443936378726, 53.666088350357555, 62.19918504838021, 64.00857833123976, 62.7230058177825, 61.01176592611498, 61.48726701736451, 55.18668143979965, 52.56631066722255, 53.10091010985836, 58.08410490712812, 61.37687190886467, 61.94707862792477, 61.351180384236, 50.799985008855025, 36.20856792696061, 31.254671273692963, 44.099419655338416, 48.77697944641114, 46.4944306496651, 42.50655689547139, 45.833777996801565, 55.10949703954882, 62.69478436439269, 55.57889884518039, 58.053200552540446, 58.887272957832586, 60.520296865893954, 61.69102238070581, 54.45066044407507, 45.95843876561811, 51.58589855317147, 54.25451447886806, 55.115663005459695, 52.76116617264287, 55.057859036230276, 54.6020874669475, 53.659334028920824, 52.473581913978826, 51.0570728394293, 47.70619200121972, 44.92114836169828, 42.866477504853286, 45.15496084767003, 49.63725720682452, 43.87421284952472, 45.63309777167536, 46.994285737314534, 47.36297284403155, 48.96076994557535, 50.421437063524806, 49.87351332941363, 50.51221639879289, 47.792754788552564, 46.433622144883685, 50.065768303409705, 49.85504681064237, 49.07125134621897, 50.47078440266271, 53.20394292954476, 53.60822946794572, 54.36971056845881, 58.16061073733915, 65.38595784095027, 65.38785626811367, 67.87455266521823, 69.22808416428106, 67.71723424234699, 69.1313349816107, 70.12946051935997, 72.11085365664574, 72.1281748433267, 69.06868688521847, 69.37383943988432, 70.14835065410983, 71.22879105229532, 73.06804533927672, 73.66230795460363, 65.25893580528998, 66.73308803189185, 67.00650861186367, 78.12374514918174, 77.5681100353118, 91.75844515523603, 37.3361316803963, 1.0052742412494076, 0.5482203020684181, 0.6991287753466637, 7.465830560653441, 74.51907127134263, 68.70838580592986, 68.44728146829914, 52.634304954159646, 41.658567920807876, 41.37402742139755, 45.70453589962375, 63.91998767852784, 71.54474581441572, 5.700637976969443, 0.25160947454071814, 0.08471069316710196, 0.12587934657330477, 0.04320714059436033, 0.07775436966649948, 0.04066417684718486, 0.04429125842908698, 0.1671132247053808, 0.18373480457211697, 0.07216404222192303, 0.14041613306730025, 0.11287479721490415, 0.155654541186748, 0.15383895877147877, 0.2095418859032854, 0.1939919711120667, 4.622811838503807, 64.03750973363077, 64.07004579421013, 49.476012491410785, 45.52469130485289, 75.17183211541946, 63.557603820677734, 85.18413697519611, 75.3826359779604, 0.6667248496124822, 0.2639261458910281, 2.3077201170306054, 1.8280788414901303, 68.23551270269579, 94.01231750365227, 88.60656969008907, 81.955775291689, 86.53484436773485, 85.14154003512475, 94.23509243995913, 77.7721203527143, 76.2008188616845, 84.34481251624324, 84.43897293459985, 81.46340016395816, 80.8651759547572, 79.91713123936808, 79.73049702182894, 76.66901649967318, 73.91291602965325, 76.3596591641826, 74.28962830574282, 72.54308316015428, 69.80276630770776, 66.10717973401471, 66.88831975383144, 70.46234423114409, 67.54836836168843, 63.07912565046742, 56.49650596803235, 55.15390611463978, 61.21723144285141, 56.52182486749465, 57.11466366244901, 55.015607264734086, 53.66291907525832, 53.96620458172214, 57.24303499344857, 56.934646483390566, 53.37565252857824, 52.972397573532604, 53.94223889996929, 49.15683354100874, 49.457114511920565, 54.080361243217226, 51.423186871313284, 50.55799045870381, 49.170295115440126, 47.634369480994444, 48.568917320620635, 47.442946049474905, 49.84096550172376, 57.73751251159176, 66.02434712071573, 65.16173162767964, 66.01846356545725, 64.99191261106922, 66.42706471104776, 58.05576186026297, 54.29999043864589, 57.88635469252064, 60.925438480992476, 63.31021993390976, 67.30088249329599, 63.2761816055544, 57.771052698935236, 42.30701415769516, 38.344494604295306, 45.975085304629424, 53.51391607715238, 46.561271759771536, 41.539155283281886, 48.17527609486734, 58.51028611583095, 64.36305861319265, 59.21453983552995, 60.09183676012101, 60.33913435474519, 64.43177069387129, 65.45466599925872, 57.16879629319715, 49.4714899986021, 54.317205721332186, 57.46137372909054, 57.85908245271253, 57.25297820183539, 57.516875267028816, 60.93017278179046, 56.830064327486106, 55.76066540133569, 55.97655265561996, 51.03916329722251, 47.1230532277015, 45.40258007664835, 46.31956746501308, 51.84932101157404, 44.676914138178674, 44.887463046658425, 47.23852388320431, 47.241238163363555, 50.82421348940942, 54.30288907020323, 51.822695962844364, 54.492994585344874, 50.212319820157944, 49.36165971140708, 51.60329034251552, 52.245668672746234, 51.764719409327355, 52.56193722448042, 56.53215246815836, 55.377163502477835, 58.10057493948168, 61.45382096690517, 67.92470409024146, 67.66367820001417, 71.32696013296805, 72.76204555265366, 68.98969819468837, 73.40853844919513, 73.81418997241606, 75.77472394512546, 75.22157561394476, 73.66283355220672, 72.32656048190209, 74.43580719732469, 73.88276084776848, 77.36339369127828, 79.2020360885128, 69.37278824467813, 69.2842132814469, 71.0465185103878, 82.04536222642469, 80.74204491030785, 95.60438402237432, 34.628617609700854, 2.155095300366802, 1.5607125624533624, 0.6197251715967732, 10.658390810412746, 85.76231002807619, 73.77411119399532, 76.86585672440069, 60.17554013959823, 75.48013825570384, 43.38354003044867, 53.97085651274651, 73.08633142902006, 85.25044856532928, 8.782136805595892, 0.4499300569295884, 0.25831442927160575, 0.16748370482556282, 0.11808398825627182, 0.19159048465230774, 0.10762077470820759, 0.12354627942606328], [0.0680547159525656, 0.12267886871291746, 0.04184379137211269, 0.08341850968258036, 0.040654907183301066, 0.045265511594592564, 0.05098548026815538, 0.09115623520506967, 0.02626621889160766, 2.9507711337458704, 35.86732172196911, 43.7250647237224, 42.81663202470349, 33.494032813656716, 45.35511547519315, 48.68031655588458, 82.54746483218285, 46.20889779060118, 0.05195549313700007, 0.27023904746578586, 1.040791609594899, 12.701601482206776, 85.86211081474059, 75.47092853053924, 80.93297804555586, 78.89851523983863, 78.76935159006428, 92.95702734301167, 74.59012108464395, 63.53311646369196, 79.48214823199858, 75.0950321074455, 75.57720907272832, 72.35165580626457, 73.27604862951463, 70.73476852909212, 70.31828341945526, 63.394868604598514, 63.03984703556184, 61.44152041404479, 61.95566861860214, 60.544274314757324, 59.73514818376111, 55.92338885030439, 56.46878657802459, 54.2987705815223, 50.7429890478811, 53.51927011243759, 53.648029758084206, 49.91860881928475, 48.48377835366034, 52.17245763347995, 52.5555359163592, 50.182470583146625, 47.051764149819654, 47.959608493312714, 49.33680365162511, 48.87738820045225, 52.98320370335733, 51.96046921514696, 48.771284164920935, 48.131416151600504, 42.47308338842085, 47.294723603033255, 40.00006037373697, 39.9643511156882, 42.59305692488148, 41.56880447941442, 44.344720763544885, 42.39638536207138, 41.683957422933275, 45.971182546307965, 48.703893922990375, 51.39349060673868, 55.381925259867025, 56.62657176294635, 53.940928828331735, 50.96472847846247, 50.41307064794725, 48.78589891618299, 52.43812760999126, 58.396874704668605, 59.81678447415752, 60.98188923251245, 40.89359591084142, 22.268519247731856, 15.399677349675088, 33.154975291221376, 26.007016551110056, 48.41722357657648, 47.082284112130445, 38.77090331046812, 50.91837390776604, 59.855149176812944, 53.46555325292772, 50.32548412199944, 56.10397477303782, 56.49821612142748, 55.60793615156605, 51.42816435906195, 47.851103967235936, 47.656868196302845, 46.119346157197036, 47.85555977975169, 49.96242169410952, 50.57568427055113, 50.35159926260672, 51.21017863673549, 48.408790480706, 46.193125940138295, 42.65954502167241, 43.19845122675742, 43.04856569536271, 47.00225207113451, 43.38714468863703, 43.242656338599424, 42.858366043336936, 44.51322578614758, 45.95742287174348, 46.505719231021025, 48.320933311216294, 47.43186927610829, 45.90658110956992, 46.2862116290677, 44.225967084207845, 45.721072612270234, 48.18104590139082, 48.9759652076229, 49.87413698627103, 49.95062712700137, 49.43407450952838, 48.636166357224994, 48.85515620631557, 52.16064345452094, 57.94020099024619, 60.56016775869555, 61.61581877739199, 64.29729615488361, 65.04528430200392, 65.53660038978823, 68.33521150773572, 66.73644558075937, 65.16539119905042, 63.62686111081032, 63.298633252420736, 61.55583397034676, 62.66467625094999, 56.07299981578704, 59.25250837879797, 58.52913310450893, 60.59159378851614, 69.39642444733651, 75.72261917975642, 74.86113332932996, 76.7920926309401, 1.941824757283734, 0.554617320097262, 0.025256706529387066, 0.1529506338580001, 43.53356676716959, 71.52682842746859, 58.8545133221534, 53.01828145980836, 33.48509765440418, 22.260554875096968, 43.33011342633156, 50.173394218567886, 52.16395393494637, 6.65148816762432, 0.28398211324407213, 0.049106864138476314, 0.11902472890552976, 0.03217989098160498, 0.0538339062533792, 0.023780252085998658, 0.028480766491303523, 0.04721240148008351, 0.040898569108497713, 0.05324661942018617, 0.09890181312878286, 0.05703128145767316, 0.03223184706462968, 0.015207063632025836, 0.16498150844727794, 0.19459872806985534, 4.485480343141864, 53.6901677808454, 54.99139055129021, 57.63095348112045, 34.58156877948392, 47.119546628767445, 58.138955331617794, 88.49002822752922, 50.485940441008545, 0.019553509435706565, 0.420450687168106, 0.6822894273265716, 18.97019228627605, 91.19547520914386, 79.34307667516893, 83.36924060698479, 83.8345278463056, 83.64639528336065, 95.45721669350901, 81.55399122545796, 66.88221654584332, 81.51373201800932, 78.83736548885223, 78.73310104493173, 75.86748799970074, 74.75708069339876, 72.94190191453504, 71.9636941725208, 67.4369259803526, 64.87419443745767, 64.47552473314347, 63.70411219135408, 63.38501953309583, 61.87620924365137, 58.65142083937123, 59.07755890200215, 57.458561389676994, 53.647672822398526, 54.761021906329745, 55.33484505068872, 53.32742306493944, 51.94394034724082, 53.52386320790937, 54.44533386538106, 52.89966114105717, 50.3823467223875, 52.02742799635857, 51.69138285421556, 51.129287596671816, 54.463239485217684, 52.65665461940151, 47.895367914630526, 47.275821701172866, 45.20625368241341, 51.80055810559181, 45.09951422291417, 44.3993240787137, 44.15940054001347, 44.510468359916445, 47.16756036204677, 44.60464446775375, 44.15270113175915, 47.240940063230454, 50.4422373925486, 53.32278682339577, 57.58306134131647, 57.33164525801136, 55.964601193704915, 51.87679329226094, 52.87766056676065, 51.3016757657451, 54.26196698219546, 58.39381917830437, 63.89887355989026, 64.17373757208547, 46.45830562037807, 24.92094559054221, 17.429881441977717, 39.985504458027506, 25.497255517590432, 50.6627961897081, 50.90956818672919, 41.59584922175254, 52.784488585687455, 61.50116005251485, 56.87248868326987, 53.094646084693174, 57.637358711611846, 58.18527852335284, 57.92681394084808, 54.41654366831626, 49.52162181177447, 49.748444634099165, 49.071333715992594, 49.84153424539874, 54.76963150885798, 53.80443034633514, 51.891886572684015, 52.90745489058956, 50.580375425277225, 49.314759931256695, 43.98155243166032, 45.82777677043792, 46.26564271988408, 48.020471911276545, 43.99911680529195, 45.34110476893764, 44.776389368118785, 43.99204084950109, 47.35635972792103, 46.3638549466287, 50.25076297021682, 50.14763209127611, 48.26061118033625, 48.56769746349704, 47.82028198242188, 47.57836195730394, 50.66967602699034, 52.71821621925601, 52.68574683896957, 52.397280047016764, 51.98239918678038, 49.94899934337985, 51.96859244377383, 53.05721098376859, 60.65453998504147, 61.77726353368452, 64.80958123360911, 68.99800577471333, 69.8654850067631, 68.07409148062429, 71.50105061069613, 68.214598624937, 67.34475028130316, 66.21915555769398, 67.3429459910239, 63.7325023066613, 65.32259587318667, 59.36342516253072, 62.4491027862795, 60.1184618088507, 64.77766490751698, 71.50680080536874, 82.63451791578724, 77.2858327434909, 84.75556312068817, 3.277526632432015, 0.832703069092766, 0.09925481878341207, 0.15189611383022802, 46.01523076334308, 78.89494588298183, 65.64423022731658, 64.31039294888897, 37.344070557625066, 26.408110280190748, 56.157413144265455, 57.641426209480535, 63.32618790288126, 7.897300104941092, 0.3292722813785076, 0.0962238148936341, 0.06862564297813563, 0.10214841714309109, 0.048218018285209135, 0.035583975860067917, 0.0640792137522611, 0.2257292471345394, 0.18501210296826978, 0.194599095792059, 0.2927465574635614, 0.14302096990568025, 0.17758411445444633, 0.18191523849964145, 0.1810519033742528, 0.45321957718941475, 8.308295857521797, 71.27871497984856, 67.0701765245007, 65.79098178494361, 55.810522648596, 67.95407479809177, 65.59354535994991, 99.46001898857855, 56.713342435898326, 0.1506061443398076, 0.3024721355928529, 2.5821401659519445, 17.118186373864454, 93.34252572828724, 79.08142320571407, 89.5163320725964, 85.47248609604375, 86.03575414226901, 93.46276206354942, 80.21664342572613, 71.28391604269706, 84.10233159219065, 80.30112343449747, 84.0179378755631, 77.92664604802286, 78.8729335415748, 77.70904864034345, 75.64975723143547, 70.57149594829929, 68.46416334952077, 68.23281411201724, 68.18813831575456, 68.92529287645894, 66.01898131832, 63.71518504235053, 61.28787332965482, 60.36205668603221, 56.041354133236794, 57.94164050009943, 57.70753383636475, 56.20457964558756, 54.15422731830228, 56.622884734984375, 56.956345035183816, 55.31679038078555, 53.079113498810806, 55.92953912673458, 54.47525762742566, 54.48179229613274, 57.436309783689445, 53.77463602250623, 49.34988475614979, 49.2179048445917, 45.27924506895004, 52.010251937373994, 47.735295987898304, 45.85025587389546, 48.8086368960719, 47.87005685990857, 52.520650356046616, 48.89725108300486, 47.72000658896662, 50.50191233235021, 54.31324412745815, 56.3682326962871, 60.69361463669808, 58.90326053865495, 59.78617821970294, 55.785321420238866, 56.64748191833497, 54.81751188155144, 57.409645511258034, 60.749386818178245, 66.81075880604406, 65.90781350289622, 50.960347190979995, 29.219384770239557, 20.405703283125355, 43.24031468360655, 26.10064744949341, 57.54207257301577, 52.15407348448231, 46.534407446461344, 58.07085906305621, 65.0278885902897, 59.335529265865205, 57.94360560755576, 61.817236408110595, 60.98139501387074, 61.37558144907798, 56.78830677463163, 52.146542533751465, 52.827313023228804, 52.090421261325965, 53.663895745431226, 55.82576497908562, 55.59025018445907, 56.12895242629513, 56.15347900698262, 54.01579903018091, 53.20739853766657, 46.28336006595243, 49.7106525974889, 50.19301391416981, 51.30904982166906, 44.37351880535003, 44.599874865624216, 44.220852313503144, 44.02276869743101, 47.75687294621622, 47.860909892666726, 52.12043523788453, 51.34326857905234, 51.84177829373268, 52.13558735386018, 49.99676204496815, 49.92765772727228, 54.145829523763354, 54.13865158634802, 54.32053581360848, 54.97322605502222, 54.17419218247937, 54.20772844745267, 52.86137880817537, 58.76611878795009, 65.04184046099263, 65.52067556688863, 67.87615299224854, 70.98979319295576, 72.589398507149, 71.2487559164724, 74.69190659061556, 73.12153077894642, 71.48632603306925, 69.59713212905392, 70.71338376691266, 68.59167175908243, 70.83250614904588, 62.95894815075783, 65.2808226308515, 62.81011773693947, 68.68779336252521, 74.6589586811681, 84.69042039686634, 79.22919457958591, 86.79589379218318, 3.1548434736267215, 1.0935641584857818, 0.24384451459252068, 0.2657624586455284, 55.452524000598544, 84.5177419724003, 74.6476936340332, 72.3658783205094, 49.25462999651509, 31.46873070347694, 62.8542051776763, 64.63090158277943, 75.78722061649447, 13.213741433235908, 0.4979214510850368, 0.2760719183471895, 0.133007587864995, 0.1366868323736614, 0.1342145747114574, 0.15062898908170963, 0.176168920231923], [0.067750318576732, 0.017543470922617183, 0.03392576705664396, 0.017826471462725632, 0.02291380664363744, 0.02475435969479863, 0.12792960470241885, 0.17424363402589677, 0.13363159712283842, 3.96219130004606, 32.673467090052945, 45.789066899207334, 33.78718683796544, 32.624004040994954, 43.07410424755466, 51.75852598682527, 84.90348354462655, 28.674432231533913, 0.4444648163212884, 0.47882637249365934, 0.45069629807145367, 45.181789859648674, 87.42806219285535, 77.48018618552916, 82.1122778615644, 81.17873807107249, 96.3636842850716, 70.77611031070833, 64.30731781067388, 78.78664924252418, 74.10571621310326, 73.46114527794623, 71.8245755472491, 67.14987124166181, 67.2643103138093, 64.8253805406632, 61.88365782460859, 60.2489943658152, 59.3109477719953, 57.507343907510084, 56.11509469247634, 54.55946699265511, 52.84578346437024, 49.74352990427325, 51.587863660627804, 52.38868221159905, 53.71704386126611, 52.21059091629521, 50.7285508032768, 50.803173895805116, 49.996805191040046, 53.478414704722745, 48.35418324316702, 47.69106734183527, 46.99036728951239, 49.16147762729276, 50.81216789061024, 46.66869371168075, 48.97280377726401, 50.18292950045679, 45.93547721062937, 46.17977419207173, 46.63166653725409, 47.12806209441155, 46.77830042377595, 41.8244763343565, 42.87274153001847, 40.76757015720491, 40.7486133421621, 42.87429478860671, 39.30723251834993, 44.334181354891875, 46.9514887563644, 48.52214697868594, 47.069069647019916, 50.26529927407542, 50.91507519445112, 49.12526630586194, 49.333908942437944, 46.637773667612386, 45.533446035077496, 59.25743095336422, 63.28307320994716, 64.37235070813087, 48.83069238355083, 38.2884164779417, 19.135229933646418, 34.16366377184468, 28.291775603448194, 25.31838170943722, 53.250317112092056, 36.6523645001073, 39.58386551949286, 50.01262018757482, 59.60441950828799, 48.01551795774891, 52.639207916875044, 48.23700243426908, 48.9304147228118, 45.76677606951806, 48.842632078355365, 44.93477075330673, 48.224176283805605, 46.594666819418634, 47.19072980265464, 46.1495013390818, 48.973741223735196, 43.82068818615329, 43.24278969918528, 40.74991164668914, 42.45318520453669, 37.87266877389724, 45.76898436392508, 46.6564323825221, 43.95782601448798, 43.073912051416215, 44.4155038556745, 44.682095589176306, 44.4163393205212, 46.29860239644205, 50.711021730976725, 47.353716050424886, 46.091238452542214, 44.28541844890964, 44.78726217823644, 44.53020964899371, 47.28330166109147, 47.65980212919174, 48.62319507906514, 48.60970212567238, 50.80903391684256, 48.97389027380174, 48.391300632107644, 47.4035732976852, 47.408056566792155, 50.55822972328433, 52.85899008474043, 54.872126963830766, 58.99991558444116, 58.29968621653896, 59.2380662118235, 58.0984607819588, 57.828531111440356, 57.3318531436305, 56.4068562753739, 52.721220754808, 54.26535591002434, 56.359654472720244, 55.91623836948026, 58.52601482022194, 66.8077621152324, 68.56391706774312, 74.847044175671, 74.35617523808634, 85.02555554912936, 25.44894172299293, 1.2176696667748115, 0.2852503871244769, 0.54291388680858, 17.83122031919418, 74.73187554267146, 62.648241519927986, 58.79569345904935, 34.6745877881204, 39.677115947969504, 34.56171374167166, 41.408069672123084, 56.79555531471007, 10.717720581639199, 0.2255139917495751, 0.08167110909257205, 0.18941658759309402, 0.06992819163227273, 0.09671196611898561, 0.013608129924133181, 0.056487404996709484, 0.05360274305266719, 0.06575835973865564, 0.11834465733338749, 0.024263741666330926, 0.04268008742421385, 0.05378051375549647, 0.023914985884461674, 0.13021715856607885, 0.2298340381633851, 6.621708552683554, 50.990820084848714, 56.40386350693242, 42.45944138496153, 31.23791490831683, 50.19661857235817, 61.512954619623, 89.91645305387436, 30.49331568902539, 0.45059281491464187, 0.573281612127058, 0.4351821289427819, 51.90572861702212, 90.0466129856725, 79.60354558883175, 84.80846804957237, 82.7474900214903, 98.34746222342216, 79.14100400863155, 65.90254183738463, 80.37749982649281, 78.09159740324944, 76.5345968738679, 74.56293121460946, 70.54491796801167, 68.3077706060102, 67.2252356621527, 63.67911492624591, 62.52927211023147, 62.197957346516276, 59.92423388265795, 59.28964537958945, 57.218100486263154, 56.15381240844727, 52.370572628513465, 54.20091921283353, 55.331793446694654, 54.83089500857938, 53.88943595270957, 53.80621110239337, 53.765873447541274, 53.47541016917075, 54.521341554580204, 51.72351098829701, 52.085659503936775, 49.251358739791385, 50.65484162299864, 53.39126356186406, 50.682227611541755, 52.17295185212166, 51.87892313926451, 46.005052212745916, 45.4881779609188, 47.02415458617672, 46.34597286101311, 51.05740231852378, 45.632764370210715, 44.52537728894142, 45.012653335448235, 42.74558613377233, 46.42030962051884, 44.540384277220696, 45.89937571556338, 49.2073066003861, 51.383308133771344, 49.81596431424541, 52.00966358184815, 52.07372373150241, 51.40383389688308, 50.67353956161007, 49.17012253115254, 47.97440759597286, 60.41030576152187, 66.2740687401064, 63.52464414411976, 54.97018621813867, 44.42646688030612, 21.793571210676625, 38.91912575690977, 30.618190227016328, 25.472848569193197, 53.83373829626269, 38.32119180310158, 41.00546583052605, 54.09415621911326, 61.34877597132037, 50.18173317755423, 54.49100986603768, 49.25618325510333, 49.7955209209073, 48.306420541578724, 51.48024951258014, 47.85452819639637, 51.133763021038426, 50.03425205907514, 50.64053281661003, 49.8108652330214, 51.14712261384534, 46.954736478867076, 45.8476004292888, 44.710105234576815, 45.84521955059421, 40.535703166838616, 49.76426747537429, 45.88861273181054, 44.10955898223385, 43.50546690725511, 45.40665541925738, 43.9891775192753, 44.34720362386396, 46.04043199170021, 51.928168496777936, 49.575958405771566, 49.43459226239113, 47.26093238399875, 46.61418061102591, 47.6643991470337, 50.85966779339699, 51.360428948556226, 50.19463777542115, 49.642564173667665, 53.39514670833465, 50.21106073933263, 51.17506557895292, 50.21315920737482, 50.54330118240849, 51.50274430551837, 55.12404903288811, 56.29343309710103, 61.789246374560946, 59.25894106588056, 62.31173353810465, 59.207483491589954, 60.23654868525844, 57.72880877217939, 57.82117274499709, 54.54611524458855, 58.936996844507036, 57.96333120715234, 58.898722356365575, 61.39800563935311, 71.87569187533471, 72.44856972848216, 81.02760914833316, 75.51694577740085, 93.43595658579181, 28.293779934606246, 2.512037850195362, 0.18750931977504687, 0.5399800152067216, 18.657446022956602, 82.87919536713632, 69.75239522995489, 69.68009810293876, 39.90034195684618, 39.09352217951129, 46.58206816642515, 50.467744565779164, 67.75593234646705, 14.616054469539275, 0.3004649239442041, 0.05937326586835327, 0.17734822066080186, 0.1391150093367023, 0.10980302978667522, 0.025154989205240726, 0.07350455819358749, 0.13616200085849534, 0.17721326661206063, 0.317499348593335, 0.14035588791293485, 0.13038635674503543, 0.19100081145523057, 0.2678237254581144, 0.3566501187461038, 0.43299920736782016, 10.722744157237392, 67.16040672794466, 65.12539871277349, 47.575694745586766, 44.709807134443714, 63.68854038176998, 68.10060670298915, 97.49754736500402, 35.8566842540618, 0.5133344659641866, 1.5291323344553671, 0.6563356554796619, 52.63053163405388, 92.0682417961859, 82.50682907719766, 87.71219868813792, 86.46682262420656, 95.89885988543111, 78.97519757670742, 70.01452722857076, 81.69122711304696, 78.69517172536543, 80.03131143508419, 79.27271719901793, 72.0501353663783, 72.03393597756663, 70.03883807889878, 68.09298161537417, 65.6131846674027, 65.11367474832844, 64.1412760365394, 61.79585164593112, 60.36627323396745, 59.66968382558515, 53.200597147787775, 57.970356172130955, 57.935749100100615, 58.96896808378158, 55.83644167069466, 55.095407885889855, 55.30503503737911, 54.853731047722604, 57.90144012820337, 53.37082801326629, 52.93464868299423, 52.16220455784952, 54.60045183858564, 56.58958773459158, 50.8821508192247, 52.89278914851528, 51.63580679124402, 47.11891120479953, 45.877418287338756, 46.87059379393055, 47.47426617530085, 53.07730528616136, 48.572929905306914, 47.369813457612075, 47.20364616763207, 46.463663578033454, 50.9706041889806, 46.445534383097005, 49.94917977240778, 54.165237411375976, 53.67164242652155, 51.08447843982328, 55.60783809231174, 53.54875064665272, 53.16186766470633, 54.37533524728591, 52.94725518072806, 49.424739268518266, 63.87327224977555, 70.74563349446943, 69.68292220946282, 57.18807866496425, 46.704791284376576, 24.355082896447954, 46.17408675532187, 32.37036593498723, 27.831652164459232, 59.86831657348141, 42.78615520846459, 47.30190154044859, 57.255751317547215, 63.72056261185677, 53.11006492184055, 57.34504015214982, 52.69487419436055, 52.92769824304889, 51.32913627932149, 53.90689834471672, 48.54106064765684, 54.02674636533184, 52.60800546215427, 54.18959925251623, 51.996413815406065, 55.3937315940857, 49.68556904023694, 48.17759421563918, 47.90338131689256, 47.92650761142854, 45.06117305447979, 52.70498214229461, 48.52008773434547, 44.33725649310697, 45.5131281575849, 45.70944670707949, 45.0031376654102, 44.65017926308417, 48.18426616730229, 55.026374170857096, 51.759510501738525, 51.429835288755356, 49.80668398641771, 49.50281796916839, 49.56935313440139, 52.167134977156124, 54.40129741545647, 53.16951628654234, 52.30338634983186, 55.8442432649674, 51.66294567046627, 52.775541659324404, 50.986430952625895, 53.50130957941855, 55.61793819550545, 59.75801167949554, 60.539602771882095, 65.7770573708319, 63.92270980342742, 66.82403995144752, 64.09582753335276, 64.01302629901518, 61.951161815274155, 62.628472774259514, 59.600077444507235, 61.76193883342128, 61.00185801905971, 61.81206280185331, 65.30131309263169, 73.7933700315414, 75.17293822380805, 84.73926959499236, 79.28560610740416, 92.8819453331732, 25.656864604642315, 2.7649662523500385, 0.81344245422271, 0.7106509828759778, 23.618787334811305, 90.78529727074408, 77.92970549675726, 80.75791482002505, 50.891693945853945, 53.044973188830966, 54.45841104753556, 58.26196086022162, 83.25147536493118, 18.713988950175626, 0.29036374822739636, 0.16638360256629606, 0.2619015593682566, 0.19393613862414516, 0.1828934102048797, 0.14588616938600618, 0.14670053617127482], [0.020564494601961587, 0.07942400467131408, 0.05215246200321182, 0.08164125464616284, 0.048378184287538456, 0.0651731298515393, 0.11516545373465746, 0.0854287397176508, 0.21193635499765798, 5.632241647089682, 44.861430275824766, 42.630601852170884, 47.8351556101153, 44.89246014625796, 55.23499719558224, 60.18655023267193, 86.15703382799703, 14.84112693417457, 0.18797404403167386, 0.37145093744320257, 3.892265245799096, 72.06867248781266, 83.81814018372567, 82.06731180990897, 80.42694522488503, 87.38631248474123, 71.60170647405809, 66.73775565239691, 83.08166811543127, 77.80493490157589, 75.26823612951463, 74.2216379411759, 66.84497756342735, 63.27738969556747, 61.93683339703468, 61.120250840340894, 57.50631232415476, 56.472685413975874, 55.5645312032392, 52.05097398450298, 51.84853653753958, 53.145350563910704, 49.16591775032782, 51.95903755003407, 53.733800226642245, 52.3116272495639, 51.69043364063386, 53.29759736214915, 52.03444511659684, 54.50840165538173, 50.70465180181688, 51.16650696723692, 51.645553881122225, 46.500855492007354, 48.01821654842746, 49.44676729940599, 49.90892840969948, 47.61120004038657, 51.601266399506606, 48.32317298458469, 47.618523105498284, 45.405066859337595, 44.10080032963907, 45.571151779543975, 46.23739773227323, 45.163119377628455, 40.721258732580374, 42.31821644690729, 40.7510373669286, 41.28696649305282, 42.24560553027738, 41.201741233948745, 43.055833847292014, 48.593859672546394, 46.55541958347444, 47.695268200289824, 47.77644949574625, 46.40464759642079, 49.78136900932559, 45.47744243375717, 46.04993197225755, 52.38599538803101, 56.09834617184055, 60.48170074339836, 55.16197050771406, 49.34018473471365, 22.724347691382132, 26.138280630111698, 36.55973772848807, 19.476393768864295, 39.09381243490404, 50.98558372066867, 41.885324062839636, 56.749432163853804, 54.9394230688772, 50.530722141265876, 45.66138982772828, 46.13832650646087, 43.66633115276214, 43.87385591383904, 48.516718418367454, 46.25859422068442, 45.69563996407294, 43.5579913662326, 43.14439312104256, 43.62613078086607, 43.205487958846554, 43.23704734925301, 39.99860125203287, 41.51516998967817, 43.99511598771618, 41.188911161115094, 44.44441172384447, 46.0743095028785, 43.397244791830744, 44.36166148031912, 42.44235161812075, 46.47409708269181, 44.37259704835954, 50.98357154477028, 49.564387413763235, 46.76400730686803, 45.02517354103827, 45.457979632962136, 43.683134586580344, 46.18701880978, 47.170655112112726, 48.782357015917384, 47.544229492064446, 48.580468700778106, 49.654954941042014, 49.15068326457855, 46.94633476195797, 49.015514466070364, 47.805290683623284, 49.408018204473684, 50.75337156172722, 49.509564445864775, 51.346328027786754, 49.940256380265765, 49.14234822796237, 51.024905481646144, 48.756430149078376, 51.3517330538842, 52.805434042407626, 51.954158121539706, 56.581668469213675, 58.4119366061303, 62.8341854003168, 66.95161111893194, 69.38071927716656, 76.26953094236313, 72.5669703945037, 79.01395843875024, 78.07028324373307, 45.413566635501006, 1.8097784105808505, 0.19926507686895711, 0.21286194242777365, 11.078707095115416, 73.37169170379639, 62.60238509024344, 61.28042474869759, 39.72854606566891, 45.28242611115979, 36.63797724631525, 40.14706296305503, 53.247681279336255, 8.626075502364866, 0.08498688318556355, 0.05962733509800127, 0.0384031679301012, 0.026835351356215058, 0.026082880644788666, 0.025616570586158384, 0.0914132270601488, 0.042910404097769535, 0.22227592195474336, 0.0948862636822366, 0.11711738447869018, 0.040089817747714064, 0.09320687637814591, 0.09463124067312288, 0.10433103994376237, 0.21905300537905387, 10.684034286006804, 63.36624314708095, 52.113849578365205, 58.47019557029971, 36.47275132517661, 63.57702739777104, 67.8713990795997, 95.17300959556334, 15.7792608007308, 0.28463080585483586, 0.2356955760549153, 5.443800197493646, 78.35257622503465, 84.7550061441237, 87.23358323497158, 81.457045924279, 92.86489086766397, 76.04726591417867, 66.75615941324543, 83.73786495577905, 80.1300218028407, 77.51998255329748, 77.10266590118408, 68.97642489402526, 66.03537682564028, 63.435445524031124, 64.55903591648226, 60.063285827636726, 57.73268015153947, 58.467971586412006, 54.448813007723906, 54.44718914647257, 55.82052077016523, 52.31925233717888, 53.628241400564875, 55.68628157338789, 54.33999076966317, 55.190752860038515, 55.02870013636928, 53.074712599477465, 55.02925711293375, 54.1537997799535, 53.22379796735702, 53.97614386773879, 49.335615173462905, 50.3891755688575, 50.42562223249867, 51.85957408720448, 52.356130461538996, 54.46312965885286, 48.594663758431714, 46.2142361364057, 45.93066838479812, 44.090629623782256, 46.14577900978827, 48.605552258030066, 48.77516338902135, 42.90325364758892, 46.34506287113313, 44.28095086928337, 43.81083126991026, 44.70097003444549, 44.889710564767164, 46.43410851878505, 52.04260364655526, 49.3860411643982, 50.04691346999138, 49.56518365490822, 48.35241817658948, 49.57912375850063, 49.87556865138393, 46.952708613487985, 53.48221940378989, 57.30833853444746, 63.979168399687744, 58.21677907820671, 53.47928154853083, 25.233452589281146, 28.94730564086668, 42.172178760651626, 21.596640771435155, 41.603823400312855, 51.17534406723515, 47.209200243796076, 57.926229507692405, 58.87183843120452, 53.327780000625125, 47.40036087651407, 47.877634879081484, 45.85641007269583, 46.42507922264838, 50.742773317521625, 49.49485555771859, 47.47219124147969, 46.315511734254905, 45.72214341932728, 45.48407123934838, 46.64698731514716, 44.904435142394036, 42.96900041641728, 43.57200207248811, 45.71502039509435, 46.57126988134077, 45.20589282435756, 46.49055534793485, 43.787304893616714, 45.81054187590077, 44.0007524336538, 46.63751479118101, 43.75700850640574, 51.30050297706358, 51.70526804462556, 48.347311250625125, 47.08848537937288, 47.7943511932127, 46.83364506690733, 46.72767439196187, 48.21295830511278, 50.052698965995546, 49.79092782543552, 51.33855781247539, 52.47394277203468, 51.17626974659582, 49.59596641602055, 51.23563481915382, 52.02738485028667, 51.45335774267874, 53.03561833596999, 51.96096343378867, 52.639866875063994, 53.326501307948945, 52.34462614982359, 53.879759465494466, 51.979100473465465, 54.41336262610651, 55.870452542458814, 55.39184493403281, 60.552817236992624, 60.85214114958241, 65.98111475667646, 69.78743768507435, 71.2856654197939, 79.0845375676309, 77.11091856802665, 83.55974228151383, 81.9846204019362, 61.17159858826668, 1.6930166824210076, 0.07613104467670764, 0.29780831488390125, 11.846116858143962, 79.87885675122662, 67.92962274243756, 71.72993659973145, 43.71004204596243, 39.03147812812559, 47.64482259750367, 48.52588891983033, 64.23100025423112, 12.873720968923262, 0.09437369723473826, 0.027804837539611806, 0.02667018854539962, 0.062056105779183496, 0.03100954420534113, 0.06412634348136283, 0.09073747622389948, 0.1388141206435619, 0.30613492453290575, 0.23775212376588778, 0.3886800403556516, 0.11230370164999079, 0.1453416494111861, 0.23613382431287921, 0.2643679947622361, 0.2578198122641733, 14.35258298150955, 80.40647045258554, 57.5658146796688, 65.80015228640649, 68.3404282600649, 75.91694908757364, 75.19132629517587, 104.90226053422498, 18.88107603596103, 0.2956986313145007, 0.6939639944222666, 5.1865466467795835, 81.962035394484, 88.93775893795876, 89.86197917692124, 85.08124536083591, 92.92614260027486, 75.5094305161507, 71.50709890550183, 85.43673761429326, 85.08776434006231, 80.96579259441745, 81.60797872850972, 69.56849882679602, 68.35629032504174, 67.05852708508893, 66.29858355368337, 63.229548546575735, 61.552029271279615, 61.50960491549585, 57.78604007536366, 59.604945105891076, 59.28923353072136, 56.13326703348468, 56.43482277470251, 56.837038301652484, 57.48502954359978, 57.7453847085276, 59.150969982147224, 55.38136828330256, 59.499029344128026, 57.38098475240893, 56.46945338095389, 58.98923889283211, 52.40501496099657, 53.10836261318576, 55.13880106710619, 54.22586940949964, 53.60150652547037, 57.41823942430558, 51.09688881904849, 45.85728868361443, 46.56158554938532, 43.883257835142075, 46.741516436299975, 49.39522343297159, 52.50655335764731, 47.44019646798411, 50.44961537084272, 46.00035321327948, 46.786200077303, 49.280509794912035, 48.554035848186864, 49.18433327828684, 55.4962819622409, 51.16761699799569, 51.88529306842435, 51.44346552510416, 50.06773341086603, 52.96056378272272, 51.42808198928834, 51.44626217503702, 59.95622081141318, 59.44606950206142, 67.39122252310476, 60.81519242255919, 57.66781591599988, 27.649681645054972, 35.65912623559275, 47.14730524247693, 24.49788070494129, 45.88386666390204, 55.05447795314174, 49.532494621892134, 61.33828363110943, 63.15141101037303, 55.42567537676904, 49.07017661679176, 52.700859731243504, 48.592643737792976, 48.1821951558513, 53.73685967537665, 53.15163420092676, 50.08337190074306, 49.913749002641254, 49.411775835098766, 48.703234964801425, 48.90187163506785, 47.31398244057932, 45.301626113153276, 48.076487279707386, 50.09302485373713, 48.54566551023915, 45.81829247936126, 48.403597262597856, 45.813114950733805, 46.35564542585804, 44.526373570965184, 47.490245911382864, 44.636760834724676, 52.71639623949605, 54.83575090285271, 50.81537638941119, 50.929293786325765, 52.0730177048714, 49.38191090860675, 49.70450624342888, 51.646891409350985, 52.67471321167485, 51.846477293199115, 53.363246071723204, 54.340135897359545, 55.09050884554463, 52.56726380317442, 55.20734448586741, 53.363116633507516, 54.98180820095924, 55.8252864499246, 55.85623395058417, 55.63758142532841, 55.234730474410526, 56.23393466395717, 57.80806810625138, 54.98562858950708, 59.374729433367335, 59.740937602135446, 57.19821014711934, 63.89333517320695, 66.09165499287268, 69.18246699917701, 71.577803550228, 74.49796891981556, 85.07270243860061, 78.79287012161748, 86.7692687434535, 83.13280797773793, 61.3733260862289, 3.567601105859203, 0.39275231861299087, 0.34789799322043696, 15.146300081283817, 87.39986035131639, 75.18238329118299, 78.54838878877702, 58.30539326513968, 61.71661192371, 54.396594493619865, 58.215402326276234, 77.36882225159677, 16.47267210868097, 0.12150570464831208, 0.28085362466592945, 0.15276001586068064, 0.17719154035852802, 0.15177830482923216, 0.11176426083810868, 0.13966123002671427], [0.06645834959682918, 0.12635879503983644, 0.052115689782846364, 0.05876593817506106, 0.01372381590396887, 0.035211385167654485, 0.06532614059265583, 0.0825722813005409, 0.25646386728171383, 10.723218764028243, 49.901448449780865, 39.158884556062766, 44.59765872647686, 48.96558661614695, 61.23749440716159, 58.95816195395685, 84.111125546117, 6.110568315752092, 0.21984563058903142, 0.15131515871372916, 15.541706373614652, 83.53017545515492, 78.23549347539102, 81.67982086058586, 81.7231708957303, 79.59138624129757, 64.97454827831638, 82.31122832144462, 73.7326595860143, 77.44882291363132, 73.94827227438651, 67.90757117732879, 63.99661117984403, 66.40513081704417, 63.37488805094073, 62.50384338440434, 61.46735314399966, 56.24150483838974, 56.094819961055634, 52.73287019421978, 53.044851595355624, 52.0633686742475, 51.96719607999248, 51.317035767339895, 48.85134758487825, 53.80004121411232, 51.64498121507707, 49.8109083790933, 49.96667354337631, 50.15807736304499, 48.133569532825106, 49.442923376637125, 50.124282221640314, 47.409786332038145, 45.80291286591561, 46.641413627132295, 49.71221370081748, 47.858450566568685, 48.297163747972064, 47.46850029114754, 49.56222226542812, 48.06552817744594, 45.555999663568315, 47.13489878562189, 49.76196896645331, 51.060861849015765, 46.41164902717837, 40.731417671326675, 42.01826495508994, 41.883492315969164, 42.07823015028431, 40.28962542933803, 40.58550942328669, 42.49777470865558, 45.208493355781805, 46.89091167142315, 48.04237050394858, 47.97465862766389, 47.8341789399424, 48.535706612371634, 47.99051677027057, 44.783916396479455, 53.71719291133266, 58.671766173455026, 57.750993697874016, 47.240559593323745, 34.23282692509313, 34.60194941489927, 37.89867408813969, 30.30955460763747, 39.546026414440526, 49.2445416604319, 59.221427517552534, 57.14866276710265, 52.74347628316572, 46.8280243104504, 45.146241418776974, 45.415351313929406, 44.22941484758931, 45.6511995100206, 46.3523780915045, 45.51386948554747, 43.90942788893177, 44.50888372236683, 40.07105527385589, 40.85408979846586, 40.97800139457949, 40.41507067218904, 40.75637179036295, 40.921001511235396, 45.18323721424226, 47.41473636319561, 48.7392540900938, 46.96352258805306, 44.031778381716826, 47.114016086824485, 45.181589818769886, 43.06354522705079, 44.45349593316355, 46.61688312407463, 48.535439891199914, 49.690111144896484, 43.531680107116706, 44.59037880743704, 45.06441685461229, 46.02234986520583, 45.83512729214084, 47.18614062955303, 47.62757201348582, 46.00882553285169, 48.14984344667005, 49.397337590494466, 48.2066079878038, 48.793998610588815, 49.239470035799094, 50.8590559036501, 49.33277145508797, 48.5231864067816, 49.87645510704287, 49.18795754832607, 49.76948815007364, 53.25327457920198, 52.58157260956303, 52.15651712109966, 55.756064461123565, 55.80137960372433, 55.70144153410389, 63.577341187384825, 68.70008607064524, 70.24218159337198, 72.77930398141184, 74.8840948843187, 74.36242749614101, 78.76762574718845, 74.81794803373276, 61.184911112631525, 0.8661821532633998, 0.20869260083042807, 0.12043472905192645, 2.3456761577437004, 62.615136715673636, 64.5899598829208, 56.73939874095302, 52.53242923367409, 58.75973709167973, 33.635697057170255, 43.15399116085422, 53.55394386476087, 12.204519510269167, 0.2765988336215096, 0.06795887069235887, 0.02467757661736781, 0.05162744279650431, 0.05855472773433693, 0.08949049192691043, 0.02448559306832331, 0.021391553548915733, 0.16564855652470745, 0.003046921999832135, 0.032325734970189875, 0.074016940779984, 0.03961885370494377, 0.055817897777043046, 0.07456861601601686, 0.2566285915071926, 15.734115300639985, 63.99408125108289, 48.117903586356874, 45.67595358817808, 41.33630990982056, 70.4082312122468, 67.13215781796363, 91.73674660344278, 5.906175567257789, 0.31805945079653497, 0.05261716327720112, 17.65405274206592, 87.32038528688493, 79.01717478229155, 84.98850484048167, 81.51384968911448, 82.48688774724161, 69.11985028174617, 83.14383768266248, 75.86956685589206, 80.74104862828409, 76.41146582941856, 72.00949961139311, 67.15523704405754, 69.24258124443793, 65.47564675731044, 62.849133553043494, 62.265559396436146, 60.52308567108647, 56.62551272299982, 57.37804689714986, 57.002625080846975, 55.699903964996345, 55.506487969429266, 53.21358803779849, 51.308763488646484, 54.742390648011245, 52.49678273354807, 52.77589075026974, 52.85769570258356, 53.00241155009116, 51.62434170323034, 52.85090215744511, 52.35227477165961, 49.32642506014917, 49.94907386841313, 49.92181731808571, 51.48982009580059, 48.47144249946841, 49.797223229562086, 50.585137182666415, 49.97554986707626, 47.49916930352488, 45.70298656340569, 47.36985660368397, 48.15504843188871, 50.99198502878989, 50.93787593226279, 41.92095879585513, 45.5845505960526, 46.012751825394176, 44.54415759732647, 44.41174230267925, 42.73728639848771, 44.38701960348314, 47.496411877293745, 48.218649664232814, 49.57022782294981, 49.181418957248816, 50.8279005173714, 50.55548406416371, 50.43329046618555, 45.90999749399001, 54.407808549942516, 60.364920016258, 61.72806916698333, 51.411862988625806, 37.98022408639231, 39.62157126395933, 41.77847477697557, 33.74444477019772, 41.1177005306367, 50.993652036113126, 60.40668933622299, 59.54437586569018, 55.598765650103175, 49.106509531697924, 48.041456591698434, 48.20109313534152, 47.87409690118606, 48.694876393964215, 48.14914918714955, 47.8660717318135, 46.54615494512743, 47.417611460531916, 43.27560817041705, 41.196481335547666, 45.03290845501808, 43.57383774172875, 44.71169771686677, 43.553931713104255, 49.96096649477559, 50.745185575177594, 50.94657182693482, 48.24372145437425, 45.427118424446356, 48.65382879011093, 45.82171278615152, 43.27767918186803, 43.68253838631415, 48.000397220734634, 48.35745057752056, 51.703016604146654, 47.05630233210903, 47.758594866721864, 48.328005344636985, 48.466119843144575, 49.35183025175526, 49.1521776876142, 49.37106555508029, 49.93436105789677, 50.34077352093112, 52.29592992413429, 51.33609848637735, 50.04780777039067, 50.84271138714206, 51.72630371585969, 50.61337040316675, 51.81247426617531, 51.946121185056626, 51.48810209766511, 54.00833083737282, 54.37930860827046, 54.02096479169784, 56.25737082573676, 58.14924763094995, 59.290225890374955, 57.92208748479044, 67.12568590717932, 72.25067830854847, 73.19585184897147, 76.90264855661701, 80.06679319566297, 75.31778350953134, 82.31645291851413, 77.22008597466254, 75.01757314128261, 2.185149971515902, 0.23107629569788135, 0.163556860699769, 2.380347458585616, 69.15016235843783, 73.23298100502261, 67.27658733244866, 59.820400899456395, 52.88133190524194, 41.758925684036754, 50.34819856766732, 63.71000751372307, 17.01227649565666, 0.13911952925545557, 0.0894042227657572, 0.018940346067651145, 0.0696677064162589, 0.04545782647666432, 0.039828359600036375, 0.02704062844596563, 0.12052244611925657, 0.21698769362222767, 0.14881674680979023, 0.14695441770938136, 0.21513319394040495, 0.059378624653383616, 0.15793714612241716, 0.26221810689856934, 0.4884042795146666, 22.092365603293143, 80.51209203658566, 53.70142106086978, 64.44312987789031, 68.27162988724248, 79.59362983703613, 72.05957258901289, 100.7208570357292, 7.530605562271611, 0.5564452058845951, 0.2623651651365142, 19.339497166295207, 92.00385216743716, 81.4680128712808, 89.11488533020021, 85.42271906329741, 86.17974435129474, 70.18840589830953, 84.74687899312666, 76.86022420083323, 83.50120482906219, 79.94096356053507, 74.41574035152313, 71.2688776754564, 72.97237873077393, 70.35681678402808, 65.57809514384117, 65.9147168743995, 61.88543858066682, 58.46348831730505, 59.294254164541925, 60.15352387582103, 58.55307525204074, 58.76674244480749, 54.489091827023415, 53.58814301029329, 57.11678566471223, 56.13662850472235, 54.36775330574282, 54.727152239891794, 55.27182432913012, 51.94536416761337, 56.073474422577895, 56.16945874306464, 52.906540978339414, 51.831164360046394, 51.061042278043686, 54.237554150242964, 52.67487010648174, 52.01457831167406, 50.03496985281668, 51.10600832969912, 49.281615903300626, 47.26014790996429, 48.33457923704579, 49.96235893618677, 52.57662650077574, 51.65542648684595, 47.61795043945313, 48.876842990998306, 49.88471954099594, 47.38482044589135, 48.622755773605846, 46.924981378739886, 48.278661927869244, 51.134386677895826, 51.94245376894551, 51.478366774897424, 51.22464433793099, 53.37147128197455, 54.20621441256616, 54.61751022646504, 49.39431344309161, 57.47301532376198, 64.69549517477712, 62.16782177648237, 54.71518901086623, 38.99899305835847, 45.495414733886726, 50.55382097921064, 38.096400768526145, 45.51112774879702, 51.6906689828442, 63.10181263954409, 63.1251899657711, 56.26139517753356, 51.364994587436804, 50.09033018542875, 50.842024972361905, 48.93732201668524, 51.31661999610163, 52.02337618797056, 52.13774857982513, 48.32155696807369, 50.57151479105796, 45.50651504147438, 44.249697423750355, 47.949033783328154, 47.25150300610451, 47.25374660184307, 44.693921535245835, 52.34338275847897, 51.066639500279585, 51.936385862288944, 49.14154806444722, 47.83532427203271, 49.896384669888405, 46.24771748819659, 44.178259295801965, 44.976367488984145, 48.46309569574172, 52.5432235963883, 55.46046287782731, 48.916831554905066, 51.19907832914784, 50.64282740316084, 52.44862779494255, 51.10127402890114, 52.308712928525864, 51.772544537821126, 50.89869145424136, 53.18065581783172, 53.594458026270715, 54.32049658990676, 53.59269688206335, 54.67216061007593, 55.930017655895604, 53.55533630617204, 55.05845915886664, 54.47155490998299, 55.06040465447211, 55.290894892907914, 59.87718897481119, 58.20735754505281, 61.152712375886985, 59.72736620133924, 62.01237040181314, 60.78797509593349, 71.31324752684563, 76.05834268754529, 79.44685474518808, 76.47296074898013, 84.31785014367874, 78.55844574589884, 88.11315905663275, 74.59876598850374, 83.82830696721231, 6.70115763141263, 0.5625340114197424, 0.18170784317678024, 3.835514432960941, 80.18749237060547, 80.20773180069463, 73.88971913245418, 76.02117430779242, 80.01122889980194, 54.237609063425374, 62.487596927150605, 75.93882806839483, 22.327193983139534, 0.35523852513682463, 0.25203897407458675, 0.11429106396052147, 0.15735845862617417, 0.1611636939548677, 0.1388944832668189, 0.08086542208348552], [0.05623995859716689, 0.08377457202802743, 0.06508922024119286, 0.134175059896323, 0.027902594189189618, 0.008779783214953159, 0.053951994876467416, 0.0645619219229106, 0.23930372760420848, 10.197453479613028, 46.41586557511361, 36.08481714802404, 41.2646835081039, 44.431361998281176, 55.81934405911354, 69.00681541812035, 71.18005168053412, 1.9289669827107463, 0.09869697653958875, 0.35563823917219717, 31.529074407392937, 88.6281035023351, 79.09072706776281, 84.42146347415063, 80.15763528885381, 71.43220516943163, 72.00180392111503, 81.22161742179625, 74.19038449564289, 78.10598465704149, 72.0157204904864, 75.96281728436871, 71.3240340448195, 73.5864963839131, 67.90016574244346, 65.02636671066284, 59.282808688379106, 60.491573349122085, 54.652360485446074, 53.47670847369779, 49.245263376543605, 52.57406911542339, 49.761031519982126, 51.14638913062311, 53.409204483032234, 52.579662415289114, 50.87829120697514, 52.06671837837466, 51.22647216243129, 51.28344458918418, 48.343498706817634, 50.20342780697731, 51.27222268812118, 48.21148741629816, 46.02339321567167, 47.86372223208028, 49.31225353671659, 47.91239100117838, 49.35656063018307, 51.56413724345546, 46.97502297739829, 46.710800355480565, 49.38244435095018, 48.59725644511562, 38.65900985656246, 45.38486273058, 48.28230580975933, 49.717606959804414, 38.947892419753536, 42.96280307154502, 41.58396836250059, 42.872902347195534, 41.94953718493062, 42.591429141259965, 41.36719857492755, 44.29128239231725, 46.22400283813477, 52.41238117218018, 55.41418283216415, 58.18567468274025, 53.080933478570756, 53.33966085987707, 53.11750958042761, 58.32970803783786, 54.143499635881, 60.37120757564422, 37.023291280192716, 39.00479032147316, 41.307343206098004, 43.61639545809838, 39.870779052857436, 48.37586218310941, 58.352551921721435, 55.96084356307984, 54.20827365690663, 48.851939862774266, 52.33338855927991, 49.021625518798835, 43.03360969789567, 46.20009991430467, 46.2197196099066, 44.92450591056578, 42.33316067726382, 41.40092311366912, 41.9083954441932, 40.8499320860832, 39.92675519758656, 39.857572432487245, 40.23470047981509, 44.362277292436175, 50.911250883533114, 48.822682903658965, 52.319526903090946, 45.125935308394894, 44.261123288062315, 52.935688111089895, 48.10421843682566, 45.70721095608127, 43.96921657746838, 49.784350010656546, 48.82952351723948, 46.121487771311116, 44.57615237082205, 44.54052156017673, 44.53306905684933, 43.47383691418556, 48.11437737557196, 47.08949342850716, 46.975419136785696, 46.235424780076556, 50.19892884838966, 46.653874997169744, 47.14363782636581, 49.61294243412633, 51.96536433312201, 48.696888569862615, 52.06416491539248, 50.232551405506754, 49.77068055060602, 48.92009104451826, 51.46029249314339, 50.793497408590014, 50.922374725341804, 52.38145720574164, 53.005361172460745, 52.19998090497909, 60.4000291516704, 69.7487082019929, 72.90054444343814, 71.74132716271185, 72.68755189834103, 73.67212172477477, 74.14557533879434, 74.11611049405991, 76.64518417850618, 68.41279598974413, 4.244640931006401, 0.7105867540644062, 0.19079502491701036, 0.1676262125012375, 38.823902376236454, 70.34220987750639, 57.86687227987475, 54.232184425477065, 42.102705740159564, 20.679733791658958, 40.09214585827243, 48.09720916132773, 19.71094758279862, 0.2725283633316717, 0.11232416385844832, 0.05108708267911308, 0.04358151244119771, 0.08177659939974546, 0.07921261036948812, 0.08157112695757421, 0.079246808534428, 0.03034834903965314, 0.05435294997427733, 0.06707303556463412, 0.03706784986500298, 0.04848085156071091, 0.1399853924709943, 0.03744824699336483, 0.20364781991849024, 18.37413126422513, 60.18807995703913, 48.56486158986246, 42.95675085436913, 43.37209455428585, 66.09070577929097, 73.8435685250067, 77.56334043318226, 1.7822936273390249, 0.03314209358406163, 0.6738925520931521, 37.6022841084388, 88.86168064609652, 82.03335192895706, 85.88125198118149, 79.20154971461143, 73.9663387114002, 76.59306372365644, 81.8126009356591, 77.26869983057823, 80.90607058617377, 74.68123774374686, 75.33926240859493, 76.07224356743598, 76.13828843639743, 70.24181289057579, 68.64740863923105, 61.77716547443021, 59.01951174582205, 57.32849559476299, 55.71398527391496, 52.6608201765245, 53.406584339757124, 52.68871999556019, 53.80203377815985, 54.33760989096857, 53.91586880530081, 52.663361872396166, 53.57037859578287, 54.59217955989223, 54.552908789727, 52.597544500904704, 52.57612443739369, 55.894747703306145, 49.57361282840852, 48.92230326129545, 47.58206467474661, 51.37566735667568, 50.50076307788972, 53.92844000170308, 52.39782525647072, 48.340486326525294, 48.59478142953689, 50.32821801400954, 51.82606135645221, 42.178211365976644, 45.99056689969955, 48.85304989353303, 54.04691911512806, 43.29185462767079, 44.196710125092544, 43.48712982669954, 44.312682843977406, 45.559082646523755, 45.9133707323382, 43.894593484940074, 46.5350232585784, 48.60902747800274, 53.82914912316107, 58.60891019144366, 59.146302361642164, 56.923401048106534, 55.39515541445825, 56.39679147351173, 62.34845869002804, 61.39227897890153, 63.070127733292125, 42.13908180113762, 41.95458527534239, 45.56504857155585, 46.35082483291627, 40.489580015982355, 50.513702977088194, 62.85542111242972, 58.75123731551632, 58.05349473030337, 52.27843615316576, 55.272632337385616, 48.586873931269494, 46.52443678148332, 46.84184674293765, 47.53913433321061, 47.033901676054924, 43.472836709791615, 42.799569714453916, 44.09174749928136, 43.302735282528786, 43.1693668519297, 42.80966981764763, 42.59603792621244, 48.4660453181113, 51.51510369393134, 49.44066409141787, 52.16067875585249, 48.19762183773903, 45.8171393025306, 52.6218867301941, 50.723875338031405, 46.22895286929223, 43.38997663990144, 51.170896099459746, 50.897820688063106, 49.083885300544004, 48.4634526314274, 47.644904967277284, 46.235981756641024, 48.13381271977579, 49.18057172529159, 48.85221442868633, 48.17244414360293, 49.83501134380218, 51.114637544078214, 50.61422940223448, 49.39217967371787, 51.04869465674124, 53.048009103344334, 52.58318078133368, 54.253294621744466, 52.30429633971184, 51.89772305950042, 52.55350020623977, 53.423144586624645, 55.1637355742916, 53.36769403949861, 55.11871853182393, 55.55386627874067, 56.57296080743113, 62.564185127135254, 72.93744610201928, 75.52409233585482, 76.68934222190612, 73.10814765191847, 79.3702273215017, 77.29432859728414, 79.22953974816107, 76.53620504563855, 82.95884301585536, 10.242800981767717, 2.046486954054525, 0.41501422082224204, 0.16785481313784278, 42.38233150974397, 78.63044477278187, 62.667621950949396, 65.58239013917985, 37.94902163167154, 29.194059987221998, 48.68591377812047, 56.74297986492034, 23.925195047932288, 0.24762705839689703, 0.12003893738672619, 0.07146766063787284, 0.025554207198682333, 0.02906590061742933, 0.09671117704842361, 0.03988870434583195, 0.1320756572268663, 0.16065513414721336, 0.12593095791676354, 0.17642192842979587, 0.14398322230385197, 0.12159621027568657, 0.2742030315341488, 0.12327305416786864, 0.3027944441043562, 23.292581458245557, 77.29193595147903, 51.321138566540135, 60.984309334908765, 65.30070120288481, 73.94813891380065, 80.22207983078496, 85.44251134318691, 2.6314894662749384, 0.20407382609142413, 0.7480779939120816, 39.23105224486321, 93.21380138397218, 84.83153943092593, 87.87615376134073, 83.92893145161291, 78.02964748874788, 75.63948846632435, 83.67065906524658, 80.08385550591254, 84.0871520196238, 79.9713933083319, 80.72790084346649, 77.82139316681894, 81.25884071473153, 73.15914630889893, 71.25299207625851, 63.08780585565875, 64.08646875812163, 59.61113852839316, 58.27956053518481, 56.44587601384809, 56.306647562211566, 56.285294178993475, 57.03786365447506, 57.326754062406486, 57.287804926595385, 55.142652834615404, 56.79535135146111, 56.40642873702511, 57.04467681146438, 54.35039289536015, 54.14643749114006, 58.662568215400945, 51.881739401048236, 51.839487629552046, 52.10008990380072, 55.242241813290505, 51.88077449798585, 56.77327232976114, 54.17008546090896, 47.585535972349106, 49.446277003134455, 53.70592394182759, 52.674846572260705, 46.5375727991904, 47.81534371837493, 49.200658182944025, 55.758382581895404, 46.0702576944905, 48.22525885797317, 47.60123329777872, 48.51245087961997, 49.225675059903054, 49.25470452154837, 47.31249978465419, 47.69750787365822, 51.17857217788697, 56.467625556453584, 59.21588913086922, 62.45275451290993, 60.05263659261889, 57.39116722537626, 57.492489891667525, 64.88785213039768, 65.96934764615952, 66.39838434034779, 49.7739282731087, 47.79970130612774, 50.74278116226197, 51.632006014547045, 43.18234597482989, 51.27650591634935, 64.34149734435543, 61.574700570875606, 59.98142988451066, 54.59041841568486, 59.345994149484945, 52.47831621477681, 48.73523366066718, 50.61068750196888, 49.392830787166474, 49.748193602408136, 45.89841473487116, 45.038286024524325, 46.50598595219274, 46.264183598179976, 47.74633745993338, 45.54049845664732, 47.48001244760329, 50.5526795694905, 53.16450349746212, 50.13263687010735, 52.7026326425614, 49.3499396693322, 47.72681190121559, 53.19445079372775, 52.363280942363126, 48.20272484133321, 44.13985929181499, 53.54897422175254, 54.41227612956878, 51.530279344128026, 49.31125725469282, 51.008894366602746, 50.6649495709327, 50.300247592310754, 51.8862775833376, 50.678630798093735, 50.23950576782227, 51.92246929291756, 54.237236438259, 53.260174028335086, 51.19483432462139, 55.00544832598779, 57.26291356548187, 55.63765987273186, 59.08984768775202, 55.77245996844385, 54.34713340574696, 55.993324710476784, 55.45600706531156, 59.0704829462113, 56.112035243741936, 58.433133094541496, 59.136331696664136, 59.626392625993304, 65.59841302133376, 78.24536215874457, 78.00384613775438, 79.63270448869275, 79.34753248768469, 83.11484352234872, 77.74530703021635, 84.27781843370008, 78.92105317884877, 85.00115840665757, 14.333533990767695, 1.7037992780247044, 0.6193831899473744, 0.2627596084869677, 52.31116440988357, 82.49725849397721, 72.51161790663197, 73.24289675681823, 57.63429926287744, 43.09094690507458, 62.175333115362356, 68.50964715403896, 32.9033552446673, 0.3674596500012183, 0.23134457968896438, 0.1509090401833096, 0.16296761651192943, 0.12648555960866714, 0.1541906697375159, 0.17733766396920528], [0.05039444343457299, 0.10861132639430224, 0.016756219819428462, 0.06379688736952602, 0.02386015697172092, 0.02473712463172213, 0.045169260307785966, 0.004032542713121662, 0.2432118485411329, 17.89044026405581, 45.97480681634719, 32.679582065151585, 51.22144760624055, 40.64561974617743, 60.64358480515019, 70.9974810384935, 57.71929310214136, 0.7949588363689761, 0.2651105178219657, 1.4413721210533574, 55.203351513032, 75.85524236002277, 78.44242203620173, 75.45376423866519, 75.97997373150241, 76.11325586995771, 71.62973573130947, 83.39703452202582, 77.23078620049262, 74.79220159592168, 72.89904609803231, 72.86103048632222, 71.12370291063863, 74.4241891368743, 72.23320807180097, 68.8243781366656, 61.21763544697916, 57.20268164911578, 55.65756197898619, 56.0672535434846, 54.083946289554724, 54.934045499370946, 49.93202332527407, 50.02779976014168, 49.69997590587985, 52.08670677677278, 50.65154290968373, 51.015974244763775, 50.843311509778424, 49.83219900438863, 50.49131016577444, 51.05340150094802, 49.504504588342485, 48.331123628923976, 46.19153345784834, 47.387856360404726, 47.22588992887928, 51.1191874934781, 50.91838567487655, 49.77995303369338, 52.695097769460375, 44.11239485586844, 50.9015900857987, 53.35066703058059, 47.984421407022786, 37.36820490129533, 38.204728787945164, 53.2653711688134, 48.90164021522769, 40.83082622097385, 40.519962695337114, 41.88339425671486, 41.4063242173964, 40.49564792263893, 40.62686297201341, 42.19645038727791, 44.18249937795824, 45.929444605304354, 54.347584478316776, 52.32962700628465, 54.7982765782264, 53.53283759086363, 58.166639420294, 57.59958628685244, 59.50887057089037, 50.5385394250193, 43.75434913942891, 45.378414354016705, 43.25813793366955, 44.919944194055375, 35.39905740368751, 40.32437762906475, 53.01647716952909, 59.88831673899005, 52.72959109275572, 58.690130710601814, 50.346598240637014, 53.73262743796072, 44.696255345498365, 45.02481660535259, 44.16955947875977, 41.27664673712946, 42.66906461408062, 40.97187857474051, 40.87628256890082, 41.07005550015358, 40.24587531243601, 41.72628764183291, 43.35595792339694, 48.90727273879513, 46.63491818212694, 49.54454022069132, 49.59381303479595, 53.02216068390877, 41.84322918615034, 47.23935150331067, 54.36967918949743, 43.58238066396406, 42.575170916895715, 47.489567341343054, 45.8074902719067, 45.675125968071725, 46.18268459073959, 46.131705545610004, 42.55093851397115, 45.94132938692647, 46.024040406750096, 46.577161281339585, 46.855814303121264, 46.527366792002034, 45.819124021837794, 48.921095171282374, 48.418447356070246, 46.281100780733176, 47.09789514541627, 48.725466958938114, 48.17200091577346, 46.34891071627217, 51.279828163885306, 49.52051570338588, 52.00977340821297, 49.1552802824205, 52.191363457710516, 52.91615863000193, 53.478787329889116, 59.01157679096345, 68.81461143493652, 68.97177296300089, 70.59618334616385, 67.55826057926302, 74.95957697591474, 72.27626785155266, 74.67995905107068, 74.52650024044898, 74.50825337440737, 84.12442238100114, 18.493514483974828, 1.998954814287924, 0.2864057702883598, 0.24459742580450353, 26.109206061209402, 70.84148837674049, 61.602945558486454, 48.19390735318584, 32.51832754381242, 21.19316420247478, 27.015410853970437, 38.3219958889869, 25.72518248711863, 0.39503762017815347, 0.08033001089408513, 0.07566709416888415, 0.06565775707243912, 0.023251670570443236, 0.006158397919798811, 0.025974145955255917, 0.08560705434290633, 0.03137952445315258, 0.023756237144792275, 0.06197992216555342, 0.033009437799093225, 0.0515107331316798, 0.01694793523769946, 0.0824350443097853, 0.2361136302351952, 26.637996473620017, 61.91644491687898, 38.51424694061279, 41.6231999089641, 49.758658486027876, 69.53988121401879, 80.2809310728504, 61.72040485566663, 0.5121523310099879, 0.3436282481397352, 2.3960428228301387, 64.33187577032274, 76.4413542901316, 83.83599481275006, 77.80487214365314, 78.96055929122433, 76.65519406718593, 75.25400577052947, 86.71193153627458, 78.07048720698204, 78.08090502215971, 75.07483974579843, 75.69826910572668, 72.38685515619093, 76.79828213107201, 76.41118341876616, 69.88699528478807, 62.45283688268354, 59.29987884336903, 58.6658904629369, 55.23293795124177, 57.458243677693034, 56.597958072539306, 54.05182600021363, 51.89003521396268, 52.280397338251916, 53.636741176728286, 52.80723441031672, 53.59120638139787, 52.95129522200554, 51.853647385874105, 51.49723729779644, 52.970357941043, 52.80260601351338, 50.7226005677254, 49.337003692503906, 52.22846907954062, 50.17620655798143, 50.5127812200977, 51.55612384119342, 51.32777913924187, 54.04476965627363, 47.12794834567655, 51.367328397689334, 54.72153932817521, 50.82436646184614, 42.654328269343225, 40.90901867035897, 54.08932385906097, 51.370838918993556, 43.228888819294596, 45.29116515190371, 44.034814296230195, 44.818982385819965, 44.218228247857866, 43.92463099571967, 44.82052387729768, 46.06674717318627, 48.521213454584924, 54.90846772347727, 54.42690264794135, 55.9426280759996, 56.21333045344199, 58.09998658395583, 60.99610390201692, 63.16457448467132, 51.55733585357667, 47.782360507595925, 49.88182483180877, 47.22357965284779, 49.030933303217736, 41.05549566207394, 42.88375162309216, 56.44617019161102, 61.65941592185729, 55.06660592171454, 61.75125037470172, 52.66096530422088, 55.20233561915737, 47.307863543110514, 48.23170331216628, 44.26595957048478, 44.31087463132797, 44.14317761698077, 43.70956351680141, 42.96848266355453, 44.41005176113498, 43.61819582600748, 42.102117384633715, 45.51493637023434, 50.00379485468711, 47.13907218748524, 51.77659634620913, 48.326742341441495, 52.71261507464994, 44.25315695424234, 49.58356780390586, 55.8282752959959, 45.44023090793241, 42.58338043766637, 49.376584329912745, 47.005091867139264, 47.86232194592876, 48.38706839469172, 47.380050843761815, 45.034563695230794, 48.513525609047186, 48.20280328873665, 49.5798925430544, 49.26094501249252, 47.76079923875871, 48.70923226879489, 49.99484400595389, 49.74795041545745, 49.71450436499811, 48.59465591369137, 52.246413923078975, 50.3039816887148, 49.26933888466128, 54.113199326299856, 52.10591070113644, 53.86512902475173, 52.81862105092695, 54.354985990831935, 55.976737007018066, 53.99239032499252, 61.87319686335903, 70.56679694883286, 74.25041244876, 74.40739354779645, 73.18945054085025, 76.83918460722893, 75.2554178237915, 73.6278695444907, 79.57039371613534, 73.75043576763522, 88.47157739823865, 29.567952079157678, 1.8480679753326603, 0.7900559349406151, 0.4101136176576538, 29.311017221020116, 79.05058553141933, 71.35007858276367, 59.73008832623882, 35.40447419689548, 23.057909973206062, 40.34641350469282, 48.866342806047015, 30.210248039614772, 0.39485814109925305, 0.042332436724175374, 0.08595789196870982, 0.06811470063703676, 0.06936270383096511, 0.026589940835331238, 0.028133274754509333, 0.1457015115527376, 0.19737732897122062, 0.28766095938701786, 0.1779655189884286, 0.17185209138739496, 0.12919659155511087, 0.17454561056388965, 0.1876964597331901, 0.47293175492555867, 35.47385700287358, 70.84499497567454, 46.43569707870484, 69.67033924595003, 61.264139067742136, 77.58889859722507, 86.3765061286188, 70.76113470139043, 1.1818888254704014, 0.4414298824004589, 2.470567120659736, 68.54184981315368, 77.51741732320478, 84.97626704554405, 80.02346669473957, 82.69671101723948, 78.20429494304042, 78.50636451475083, 85.48312356395107, 83.2923464621267, 80.65006532976705, 80.55482233724287, 80.43426436762657, 77.59820245927381, 77.48647766728556, 78.17830531827866, 71.8631402907833, 66.03375296438894, 62.09530891910676, 63.238424870275686, 59.71220231825306, 60.9971550972231, 60.270061416010705, 56.67919820354831, 56.802882302191954, 56.15757788381269, 56.925699557027514, 56.47643519986061, 54.97298286807153, 54.7626849912828, 53.14803738747874, 54.4800546861464, 54.605276353897594, 54.74118255799817, 54.21073298300467, 53.97994072206559, 55.846702591065444, 51.85390626230548, 55.21869974751627, 55.99730983857186, 50.532032212903424, 53.585809200040764, 49.15271112995763, 53.784288975500296, 56.639127269867934, 54.106586210189334, 46.5244956170359, 43.28040130676762, 55.754793613187736, 55.897171728072635, 46.8347550976661, 47.27695918852284, 47.64231228059339, 48.03370991060811, 47.52020889712919, 45.912331304242535, 46.79846532883183, 49.08077093862718, 50.901174314560436, 60.10979729314005, 57.58850559111565, 59.469168340006185, 59.71859185926376, 61.81914268001434, 64.05665090007167, 65.52095405517086, 54.81061635478851, 51.37275695800782, 52.430777088288345, 50.156818282219675, 54.410966057931226, 46.108810670914195, 44.960470122675744, 60.7032322883606, 64.29181660375288, 57.086861902667636, 63.6945886765757, 54.12172655905447, 57.305451670000636, 49.066073817591516, 49.208750032609515, 48.301619560487815, 46.727882277581, 48.945551149306766, 45.68604192426128, 45.70166472465762, 48.39732539269232, 47.290012836456306, 47.11334928389519, 49.340345551890714, 52.4888595458, 48.22133256543068, 50.91742469418434, 50.09013406692013, 52.73158757917343, 47.0167334618107, 50.61078163885301, 56.69123595760715, 46.90119220364479, 43.78663416831724, 49.961668599036436, 50.18197636450491, 50.09892017610612, 51.42747009954145, 51.01965735035559, 48.68463116307413, 51.42099426638696, 51.61158615542997, 53.222950735399806, 51.539853849718654, 51.93342055043867, 51.133331560319476, 53.88017915910291, 52.45440936857655, 51.382233404344134, 50.62193293725291, 56.041350210866625, 51.92514827174526, 52.821354942937056, 57.379207918720866, 55.563825176608184, 57.363502748550914, 54.19734201123638, 57.866413362564586, 58.82776667994838, 57.14970219519831, 64.61170942552629, 73.8203324041059, 75.01684358043056, 77.01260828202771, 78.18640109031432, 78.95245567444833, 78.97762944621425, 77.21462603538268, 81.94971130740258, 78.39165087669127, 93.1775273046186, 34.66865324204968, 2.6855738028403255, 1.0105495226960028, 0.4782321946995874, 39.74178406500047, 84.4769807015696, 79.82156661248978, 69.69337924834221, 52.561419471617675, 35.84116343528994, 50.64624378758092, 64.0329009486783, 36.86871459407192, 0.8812925940559757, 0.15068436191687662, 0.15259614965367704, 0.14593847786947606, 0.1829013009104998, 0.06261323556123723, 0.1873828080152312], [0.04345038117119863, 0.045952114066289323, 0.07493417019084578, 0.10778809597174968, 0.010916411054260548, 0.030533116040450912, 0.03760066784677967, 0.05905908938016623, 0.08865233811159288, 20.81027811573398, 53.70705358443722, 51.16520081796954, 56.507504293995524, 49.41426654015818, 59.984238301554036, 77.94988216892366, 39.352429989845525, 0.04873299407922933, 4.939902126789093, 18.804850655217326, 72.4651848885321, 76.85590174890335, 79.85664044657062, 77.00421440985896, 80.31524396711781, 83.62369260480328, 69.0512715616534, 72.58311487013295, 78.34501389534243, 75.36053734440958, 71.88123810675837, 81.93452389009538, 80.76512413640177, 75.44950454465805, 73.84310568532636, 68.63284095641106, 70.63387732351981, 65.98098924083095, 67.21084840836065, 63.07386575206634, 63.1446998350082, 63.70735206911641, 62.562008211689616, 60.735603609392726, 54.44647135273103, 49.662815370867335, 50.72897049688524, 51.02121060894382, 50.90042121948735, 49.246330261230476, 50.667714841904186, 49.11956317963139, 50.257066219083725, 47.81219405512656, 46.20337117102839, 46.61956210290232, 46.853884496996486, 47.245340962563795, 48.28845608618952, 50.82038525612124, 51.91060412314631, 45.84953023541359, 42.823833496339866, 45.799516093346384, 40.18456474427254, 29.630327570822935, 38.70570959583406, 41.61265265557074, 52.08230195506927, 44.490950645939, 41.84369202583067, 41.3798011502912, 44.21530215970932, 43.14803700293265, 42.390078190834295, 42.51650402622838, 42.008823810085175, 41.75966701199932, 45.479764476899184, 42.886077588604344, 47.502118925894464, 48.747557747748594, 50.483430124098255, 53.742841289889434, 47.743207408535866, 42.98287383971676, 49.22627518253942, 43.50897742855934, 46.69280059875981, 45.04352631107454, 47.54812440564556, 41.73523456819596, 50.11492736877934, 54.66971697345857, 57.50131914692541, 53.7861874026637, 51.84606544433102, 53.94295277134065, 47.26019497840635, 41.27012775790307, 41.87265480718305, 41.61027177687615, 39.56538723361108, 40.45997788829189, 41.15607700040264, 41.540190789007376, 40.97426337580527, 43.61236718393142, 46.25738220830118, 50.7356502932887, 48.424507417986476, 50.694335968263694, 47.49510572802636, 44.55681116350236, 40.173527194607644, 43.66380514637117, 50.02106505055582, 45.4547829012717, 44.09794876652379, 50.138575338548236, 47.236480328344534, 44.461513257795765, 44.11821173083398, 44.362277292436175, 43.89414633474043, 44.328815552496145, 49.15785335725354, 45.95510082860147, 47.844530074827134, 47.54392354719101, 48.306397007357695, 47.52593947995094, 49.07247904808291, 46.947021176738126, 50.320337972333355, 48.055988973186864, 49.85210111064296, 49.33974150688418, 48.89106158287295, 49.41500394575058, 50.83732989526565, 50.49163572249874, 51.900123550045876, 52.65909041127851, 58.679450096622595, 62.222327032396876, 68.8416051864624, 68.11904184279904, 71.96868342737999, 72.12735899033086, 71.00869901718633, 70.4795555914602, 76.88877905568769, 70.16562477234872, 74.48829635497063, 79.52814194463915, 40.02014290901923, 0.6253245388788562, 0.13509765958353398, 0.2551299703097151, 14.091295273073259, 71.03371589414536, 59.80153822129773, 54.853640833208644, 28.619395494461063, 37.299128040190666, 27.015630506700088, 41.1048076998803, 28.076721852825536, 0.578582817989011, 0.22641583045403804, 0.09063611513063793, 0.03278322735681169, 0.07259825319652596, 0.0108827730911153, 0.08355746271028634, 0.04282112804151351, 0.018121135691481254, 0.06546057370160857, 0.07864006689839786, 0.01987405402976419, 0.11700711378286924, 0.034125834748509436, 0.087688660789882, 0.03783853814726876, 36.53610937057003, 65.1359106648353, 57.80655799373504, 51.6099230704769, 55.07185013063493, 69.57227999164213, 84.52838728504797, 43.32214709251158, 0.18793773146406298, 9.253454689056642, 25.827726971718576, 76.97485939148935, 78.69488931471302, 84.06559467315674, 81.10189883939682, 83.55322330228745, 86.16301152013963, 70.90266166194793, 74.61288652112408, 81.3757195011262, 74.01666272071101, 75.17201254444738, 79.66532291904574, 81.31932366278865, 77.65781464115267, 73.70472446564706, 71.57468918831118, 73.29823355520926, 69.14141547295355, 68.54781181581559, 65.50802984545308, 64.5782280737354, 66.73057771498158, 66.12450876543599, 64.5897323854508, 56.083625516583844, 51.66007449550014, 52.031872041763805, 52.659298296897646, 53.32403021474039, 51.15822684380316, 52.37453814475767, 52.89419727940714, 52.13571679207587, 49.54312424505911, 48.78085082577121, 49.58965532241329, 48.16914935265818, 48.070588034968225, 48.5664854511138, 53.03130765115061, 51.57399023732832, 48.518236375624134, 45.32456413392098, 47.113145320646225, 43.12747593848936, 33.7245269744627, 41.15199773542343, 41.6414624644864, 53.88282283659905, 47.81919940825432, 45.27071783619542, 44.75015263403616, 46.06071064549108, 45.2693332395246, 45.7641637709833, 45.102361863659276, 46.12237422697006, 44.18744548674553, 45.707108974456794, 46.805180426566835, 49.122199012387185, 52.14329088887861, 53.24827747960245, 55.64936814769622, 49.26789545243787, 47.024111440104825, 52.39981782051825, 45.45338653749036, 48.69383304349838, 46.944220604435095, 48.26551022068147, 44.11268118889102, 52.707668965862645, 57.15650750744728, 59.07281675646382, 56.49435258680775, 54.434947429164765, 54.33806096353839, 50.62464329504198, 42.42142577325144, 45.29869218026438, 43.710410748758626, 41.177657881090724, 43.59033523067352, 44.06450663843463, 43.3431278505633, 45.56724117648217, 46.8145078228366, 47.60604996835032, 51.21674860677412, 50.18198420924526, 48.61663295376686, 48.52145271916544, 46.225305065031975, 43.55707745398245, 44.882038408710116, 48.5381345595083, 47.05036386366814, 44.931711304572325, 51.65563437246507, 51.25063788506293, 47.91609764099122, 47.450790789819536, 44.586660400513686, 48.64372084217687, 46.666069646035474, 52.13089227676392, 46.48212617443454, 50.575080225544596, 50.21663834971767, 49.3442012417701, 50.10963609141689, 51.705405327581595, 50.167781306851296, 51.882261076281154, 50.9741460892462, 51.813352877093905, 51.92352441049392, 51.157634565907145, 53.510770336274184, 53.425658825905096, 53.78477534940166, 54.79092605652348, 56.442589067643695, 60.85952697261688, 68.1836119005757, 72.85833189564367, 72.6697600272394, 74.44029438880183, 75.24387036600422, 73.88387480089742, 72.47254325497535, 77.59806909868794, 73.45079022069132, 77.19010337706536, 83.57059155741047, 50.83441557422761, 0.6445931210633248, 0.06223942295858457, 0.2618946645769381, 15.740691154233872, 79.80578299491637, 67.17702973273494, 64.97378341613278, 33.945246588799264, 48.14816074986612, 38.83529293921686, 52.21406613626788, 35.148574844483406, 0.9228169497463011, 0.08287824149574004, 0.06907708327015562, 0.014647501520812513, 0.047497424492312056, 0.0746203805770605, 0.08204487572994926, 0.13766183247489316, 0.19177592389525908, 0.18537478431338267, 0.18131782781452904, 0.10804248312788625, 0.2433913429417918, 0.13898537193815555, 0.1757818926125765, 0.15821146688634352, 45.543632430415, 73.94210630847563, 65.12361795671525, 75.21485267146942, 67.07933133648288, 76.24825600654849, 92.36775398254396, 49.18379591357324, 0.20519450547233706, 9.368355620291926, 28.021045769414595, 80.59646221899217, 80.15368153972011, 88.42257915004608, 82.02449521710797, 86.18773814170592, 88.41682895537346, 72.47732854658558, 77.75115920651344, 83.48233822853335, 78.02988283095821, 77.7204470480642, 80.08751115491314, 80.13750568512948, 81.96524389328496, 77.16332927826913, 75.75072688441124, 75.43549383840254, 72.21011315622638, 73.43581461137342, 66.57755036507884, 67.95859336853027, 70.56988777652865, 68.30678216872677, 67.9482775349771, 60.867960068487356, 55.914394855499275, 53.88252081409578, 54.90116427021643, 56.93037894464309, 53.77346323382471, 55.99113995029081, 55.609999318276685, 54.53900006509597, 54.605703892246375, 51.971024313280665, 54.20793633307181, 50.651440928059245, 50.64386290888633, 51.63057042706398, 54.75842529727567, 54.256860056231105, 51.42404587038102, 48.97987188831453, 50.11902624560941, 46.87546537768456, 38.691577296103205, 48.15215764507171, 42.74012227212229, 55.59831849990353, 51.11044845273418, 48.27256656462147, 48.69906548530825, 50.28418548645512, 47.79402563648839, 48.79213156238679, 47.828264005722545, 47.8603607608426, 47.70121843584123, 49.62046554011684, 48.815975650664306, 53.81975504659838, 55.329224294231786, 56.86407912162043, 60.06052055666524, 53.95815980049872, 49.178049641270796, 52.70209920021796, 48.17588798461422, 52.621592552431174, 50.99214976833713, 51.42228472617365, 47.6484586346534, 56.0960005944775, 60.77144622802735, 62.35018061053369, 60.706707508333274, 56.5651160670865, 59.13952058361423, 53.34658776560138, 44.36369326806838, 49.03732284422844, 47.13524003182688, 43.60007839818155, 48.040170054281916, 47.12943100160169, 46.41605777125205, 49.35356393937142, 49.70140757099275, 49.30377337240404, 53.786144256591804, 51.34656336999709, 50.2028904422637, 49.35113206986458, 48.94814775836084, 48.87094374625914, 48.06188821792603, 50.387889031440984, 46.887671793660815, 45.54991214506088, 54.44269018788492, 51.90241029185634, 50.092511023244555, 50.17618694613057, 48.5962523183515, 52.122655299402055, 52.28900301840998, 55.29340128744803, 49.64804372479839, 54.00544005055582, 54.48442028414819, 50.11154236332063, 53.6924623673962, 55.49295971470495, 52.995523868068574, 54.58011434924219, 55.71125138190485, 54.89417460656936, 55.72917661359234, 53.155238859115116, 56.67155350408247, 55.42677364041729, 58.5698708411186, 57.967430083982414, 59.82254251357048, 63.83685696509577, 70.38952935126521, 75.28368242325323, 74.40070982902282, 76.40496253967285, 75.79140186309814, 77.35696100419568, 75.39772925838348, 78.95905310107817, 77.79627430823543, 82.53833355442171, 89.06771490650793, 57.34290638277608, 1.1263512507561715, 0.522831290239288, 0.2582750829958147, 19.566565136755667, 88.58108997344972, 73.66372000786566, 74.66066883456323, 44.48441597723192, 66.4498144580472, 50.90792863599716, 67.36445626904889, 42.15613626664685, 1.2513622136846667, 0.2681170452025629, 0.16141129357199516, 0.14322546941618766, 0.1837986503397265, 0.11888706290553655, 0.16158829052602092], [0.09376069666036675, 0.005385487503747666, 0.05909445199875101, 0.05008230090982491, 0.11126170715978069, 0.062015721454255046, 0.030843295464893023, 0.044804207920547456, 0.04532484893476771, 36.753157646425315, 53.26900720596314, 36.096819600751324, 21.35055126682405, 51.76743761185677, 55.79136971504458, 79.76405682102327, 21.977699033675655, 0.08135522805875348, 4.827112901595331, 34.09708546053979, 87.49114959470688, 77.24263960315336, 84.61803697770642, 79.83463594990393, 80.5452125303207, 74.73521740205827, 77.3700068073888, 70.2047464924474, 73.64830509308847, 71.06960558122205, 76.44888524086245, 56.75752009114912, 56.608517093043176, 74.32521989268642, 70.82671673067155, 70.55758722366826, 67.42607670445597, 67.13179695990779, 68.34556656499063, 69.11170744126844, 67.70724004314792, 68.31904349788543, 68.43213327469365, 66.17243228420135, 65.20189669824416, 52.36205324049919, 50.20906033054475, 53.354542332310835, 49.87754552595077, 50.427591262325166, 50.63686540049892, 49.791127866314305, 48.01575329995925, 45.71075285634687, 44.69372149436705, 45.39665729768815, 45.610516686593336, 49.323848062945956, 44.962788243447584, 52.98290952559441, 53.15378758215135, 48.276273204434304, 30.023351023274085, 46.10190729941092, 36.91818352668516, 29.366734489317867, 46.8670165923334, 47.706266526252996, 43.969526444711995, 51.78918323209209, 42.45563668589438, 41.46283772683913, 43.80290023742184, 40.96699522387597, 42.00781576095089, 41.00086096794375, 42.071005144426906, 42.39544007085985, 39.35334782446585, 38.1702236975393, 40.2567167435923, 41.57622168141027, 41.538927785811886, 43.2191966425988, 42.46833732051235, 44.627633479333696, 44.29798572294174, 43.82214730785739, 43.54062311110958, 41.69145699470274, 43.89519360757644, 40.85211292389901, 43.073606106542776, 43.54816582895095, 47.10128407324515, 46.79000477637015, 44.98204708099366, 42.5305147324839, 41.43920152418075, 39.46781827557472, 40.00157833099365, 40.92222921309933, 39.359917794504476, 38.647576147510165, 40.72128618917158, 40.047321011943204, 46.04538594522784, 42.444614825710175, 41.89334530984202, 45.79742939241471, 45.07674486406388, 45.95875647760207, 41.610487507235625, 40.347829480325025, 43.89676255564536, 48.85330092522406, 51.19878022901474, 48.96698690229847, 45.68583011627198, 50.81782394839872, 45.930570325543805, 45.22495554339501, 44.18500969486852, 43.039740362475, 43.456927576372706, 45.3072468696102, 46.9345284277393, 45.19627125032487, 48.68352505468553, 48.23204848074144, 48.85219481683547, 46.06302876626292, 47.28250149757632, 47.023503472728116, 47.73560585514192, 47.869166481879454, 49.295752125401656, 48.4473709137209, 51.327073112610854, 49.73477517404864, 52.49053439786358, 52.38890970906904, 56.96715116500855, 60.19187288899576, 66.12547366849839, 68.47532641503119, 70.2124814064272, 73.06052223328622, 71.48110928074007, 68.34902609548261, 76.42861443181192, 80.75385124452653, 72.9412115773847, 69.06745526098436, 74.45075927242156, 73.58432339083764, 56.05876161206154, 0.2781558613623342, 0.23868842110518487, 0.34150719582553835, 7.520151955466117, 66.70300345267019, 58.36846497751052, 57.53386305224512, 34.468035774846236, 22.649559859306585, 26.242194021901778, 38.24248160085371, 37.91457929918843, 1.6492741651112035, 0.06724561985221601, 0.12345880750686893, 0.036893400153325456, 0.1445355716972582, 0.051640389682424646, 0.06786539264383816, 0.09653503811287303, 0.08348194942359002, 0.07080320193762742, 0.06242445617493603, 0.07880749541424936, 0.0313629558865702, 0.026764250735962586, 0.008226689758650478, 0.28012896677659405, 52.96629436554448, 59.54748630523682, 41.859138319569254, 30.5791038082492, 61.288061603423095, 64.68821917810749, 87.43279257128316, 23.331065793191236, 0.23507502951448966, 5.684724430884085, 38.14193948622673, 93.45596851841097, 78.93869599988385, 89.941893546812, 81.44687129605202, 86.38292312622072, 76.71931697476295, 80.90602351773171, 71.2804800464261, 77.08685090464931, 72.48348666775611, 79.17978840489542, 57.51834223347326, 53.71802053143902, 75.70292103675105, 73.78092042861446, 74.42844883088144, 70.9627680624685, 70.845779449709, 70.61610114189887, 72.02402022577101, 71.05197844966766, 69.2903478683964, 70.92435236900084, 68.72563638994771, 68.41945617429673, 54.937234386321045, 52.526408395459576, 53.08949601265692, 52.76035424201719, 52.17638000365227, 52.443846425702496, 53.73007005260837, 49.59247942893736, 48.930991311227125, 48.62069652926538, 46.40849936393, 47.977521957889685, 50.92421823932279, 48.019008867202274, 54.02191008290937, 53.670834418266054, 52.674124856149, 34.074822087441724, 49.10918851052561, 42.41763676366499, 35.24461800052274, 51.58713017740558, 49.551835829211825, 44.17359167529691, 55.40431807118078, 45.18209972689229, 44.505635999864154, 47.4119318685224, 44.132257738421046, 43.91981040277789, 42.593751184401974, 44.16751200152982, 43.0413838355772, 42.61102922501103, 40.0245673425736, 41.92488116602744, 43.25852624831661, 44.16961831431235, 45.63760065263318, 46.29408774837371, 46.33833992865778, 46.026731152688306, 45.82111266351516, 45.93612832407798, 43.80304144274804, 45.87505702049502, 43.55054278527537, 45.68515154623216, 45.004949800429806, 47.87097077215872, 49.53141989246492, 46.972638176333525, 44.19759265838131, 44.713866787572066, 42.42179055367747, 42.515696017972886, 43.171665360850675, 43.31848752114081, 41.878212805717226, 41.75610549988286, 45.58353470217797, 48.998558059815444, 43.00942436341317, 41.92489293313796, 47.45524267996512, 45.71583624809019, 47.193232274824574, 42.70704100208898, 43.75734583024056, 47.69273042678834, 48.395627006407715, 50.230645133603005, 48.486712286549235, 49.11092219814178, 53.51846602655227, 50.30952399776828, 47.246462760433076, 46.73182818197435, 45.77346371066186, 45.30748221182054, 48.50853243181783, 50.02553655255226, 47.20264596323813, 49.14723157882691, 50.42926219201858, 51.695705306145456, 49.632134591379476, 50.26990805902789, 49.566689845054384, 50.131715113116854, 52.428564871511156, 50.74783317504391, 51.21600335644138, 54.19959345171529, 51.728488476045676, 54.19747929419241, 55.23265946295954, 61.02009704036098, 63.72942324607604, 68.34744930267334, 70.62214159196424, 73.44503218127836, 74.15058812787457, 74.87563040948685, 72.52651506854643, 78.12886776462679, 83.73263251396918, 78.44268875737345, 72.85259739045175, 78.17267279471122, 77.50142189764208, 63.87735543712493, 0.6376987587540381, 0.31934703009263166, 0.39245357496603844, 8.100531831864389, 75.76927969532629, 66.60832528145083, 67.42278975825157, 40.31210453279557, 33.546039519771455, 39.75965046113537, 50.01220441633656, 47.01468598458075, 2.2048549786690743, 0.10532919888294513, 0.06091873717284011, 0.042571471478309364, 0.054504524300535845, 0.03318104149413205, 0.09949206089180324, 0.22175821505727308, 0.1997093925432813, 0.30933747849156784, 0.14755783452382012, 0.20422339709776066, 0.22943135170686632, 0.1407196111376247, 0.15092741097173384, 0.42765421192011527, 61.139219422494214, 72.5381645079582, 50.41804029095558, 31.90795183181763, 72.22868950136247, 71.41154996810421, 94.44069523965159, 28.417548364208592, 0.3821345851305993, 10.833495220830365, 43.837475930490804, 95.63671219733455, 83.79824592221169, 91.59250536272603, 85.52452025874969, 87.75113213446834, 79.3173380820982, 82.85172308644941, 75.81175896429247, 80.28559869335544, 74.66287320660007, 81.06586794699393, 64.84925600790208, 59.189656319156775, 75.94136976426648, 77.10618818959883, 78.21875279949558, 73.61101904223042, 73.11580411849484, 72.8148877236151, 73.62940711359825, 72.73502826690674, 73.22632866521036, 72.54762526481383, 70.5696524343183, 70.60426342871882, 57.549270122281975, 55.27214988585442, 56.78117198328818, 54.89541799791398, 53.98202742299726, 55.73973171172604, 56.57834622167773, 52.95178551827708, 51.20992368267429, 49.03067442678636, 49.44870887264129, 53.44071680499662, 52.63985510795347, 49.27543424790906, 55.51530153520646, 55.98434640515236, 54.46148618575066, 38.52759868867936, 52.00432131367346, 46.42846030573691, 41.822393555794996, 54.81701374053956, 51.834247343001834, 44.27118808992448, 56.93697637127292, 49.6664474856469, 48.29434356381817, 50.87158787635065, 48.27301763719129, 46.65103912353516, 47.569156154509514, 47.163061403459125, 46.01107305096042, 45.803650271508005, 43.98683194191226, 46.3706837930987, 47.74580009521977, 47.85222184273505, 49.74308667644378, 48.91668642720869, 50.126953355727665, 48.743192149746804, 50.11730040273359, 48.118080093014626, 47.37481447958177, 48.425221289357836, 46.19360839166949, 48.67395447146509, 48.97931883412023, 52.78843841245098, 53.5626946726153, 50.0268191675986, 47.34574187186457, 48.52770497722011, 44.56000005045245, 45.546837006845784, 46.45181802011306, 45.85960288201609, 45.137518067513746, 45.20566532688756, 48.21468022561843, 51.62290611574727, 44.523251364308024, 42.63308471248996, 47.84141179054014, 45.84176002010223, 49.42012656119562, 48.59783303353095, 47.44645264840896, 48.52174689692836, 49.053043703879084, 51.13250786258329, 49.184384269099084, 51.2114102609696, 56.34095653410881, 51.64986064357143, 50.356188435708326, 50.10152462990054, 48.8787845642336, 49.01133714183685, 50.53998285724271, 52.77821671578192, 49.65619833238664, 53.04815815341089, 54.420666079367365, 54.79353443268807, 52.058775578775716, 52.96752206740841, 51.47692726504419, 51.96137528265677, 53.702440877114576, 55.032045918126265, 54.6388400754621, 57.384558031635905, 55.08123636245728, 59.31396015228764, 59.074432772974816, 65.30642786333638, 67.03460062703779, 70.85851930802869, 73.69718567017587, 77.48962340816375, 79.82888575523131, 78.44207686762657, 75.79431226176601, 76.63612350340813, 80.9858202165173, 81.7044690347487, 76.24831876447125, 82.40405513394265, 81.08202026736352, 71.29394946559783, 0.8734795391078919, 0.7557318864330169, 0.49012659838603395, 11.293638271670188, 85.0301996354134, 72.22574772373324, 75.69193840026855, 53.9042664343311, 37.12934040254162, 46.69385179396599, 64.55507432260822, 57.651502778453214, 3.274401729145358, 0.4032458232775812, 0.32431572315192997, 0.15222490344557071, 0.23770384490489962, 0.18824822689977386, 0.18179818026481137], [0.04383109239560943, 0.08555370397985944, 0.059216183369919184, 0.01897548077507846, 0.024319729287057154, 0.057350096608241724, 0.05455936087415584, 0.04552240768868116, 0.6035611454036929, 49.25862296935051, 52.60482441994452, 42.275140977674916, 24.73767480542583, 58.262270727465236, 58.56050814351728, 85.99995859207647, 12.080750100074276, 0.06220165099347792, 0.2725066370781391, 40.71281779196955, 93.0804878665555, 73.80811814338931, 84.65174582696731, 74.11468275131719, 81.5619928606095, 72.57109672792497, 76.75954480325022, 72.2013819602228, 76.35929046138641, 71.0819688920052, 79.36126862802814, 60.995413564866595, 38.89031987036429, 56.15727586130942, 70.63248095973846, 71.75406702103155, 71.9462945384364, 71.65824351772186, 71.63433274915143, 67.29779951034054, 67.30325944962041, 68.30497003370716, 65.46454644972279, 65.40398113189205, 68.69753653003325, 56.249792806563846, 50.6215093212743, 51.876291228878884, 49.82451508122106, 49.026775590835086, 49.40992055400726, 48.609353034727036, 49.45150944494432, 44.94507089737923, 44.79793886984549, 46.85650071790142, 46.225336443993356, 47.47623520512735, 47.973427003429784, 51.614057248638524, 52.641294617806714, 46.93692107354441, 38.83723451245216, 40.116562612595104, 38.685940850165586, 36.990504187922326, 40.95874255703342, 46.69065113990538, 43.47784949887184, 45.44348647517543, 47.622904392980764, 42.90760747848019, 41.91829550650812, 41.81579612916516, 41.75328531572896, 41.57187961762951, 42.10840494401994, 42.155653815115656, 41.28180857627623, 40.05474213630923, 41.725875792964814, 40.72192945787984, 40.93552212561331, 41.887218567632864, 44.27891123679377, 43.33337291594475, 44.371832186175936, 42.060081343497004, 45.17545915419056, 39.69900277353103, 42.55890484779112, 40.9572716682188, 42.407422911736276, 38.93080657528293, 40.41335267405356, 41.861346613976266, 40.566776183343705, 40.03398495335733, 40.4096499566109, 42.057618095028786, 41.30262459478071, 41.53375025718443, 42.41292991945821, 40.914902225617446, 40.1199201614626, 46.234483411235196, 43.426156582370886, 40.63085986721901, 41.97071798386113, 51.49715100565265, 46.412708067124896, 41.15342155579598, 43.8064617495383, 38.318701098042155, 41.225934413171586, 45.34703147026801, 48.797826843877, 45.824309395205596, 49.60742758166406, 45.78588585699759, 44.70217812445856, 44.59742338426652, 42.842166654525265, 41.665039831592196, 41.94532455936555, 45.468319000736365, 48.10118252231229, 48.92807306781892, 47.2104004890688, 49.363695421526515, 51.55938333080661, 54.79753132789366, 59.276940822601325, 56.993768368997884, 55.9880098988933, 56.211949779141335, 55.50327554825814, 51.452349693544456, 55.30605093125374, 54.45683425472629, 55.81045596830307, 57.230859956433704, 63.033367280037176, 66.6558644079393, 69.33339195866739, 66.4978870268791, 66.67399360287574, 70.31563189721876, 74.51317202660346, 87.53653141760057, 80.34102962863061, 65.476501834008, 71.05840329200991, 64.75668414946526, 74.19371851028936, 72.13739241323164, 72.45578688959922, 2.5766797363758087, 0.3560257877313322, 0.16989942519895493, 2.6240352469105876, 60.4768919175671, 62.39480541598413, 63.20367659291914, 38.34785999790315, 36.89162123587824, 33.16218852996826, 40.17857920738959, 40.84700207556448, 2.9062757665111176, 0.11665592375662058, 0.0568506877208429, 0.08253684973404293, 0.022103741442063646, 0.034600767126727494, 0.010116813486562142, 0.06324336586159564, 0.09884133048716093, 0.031963229825299595, 0.015834405372339874, 0.034829149428274364, 0.0366822395083164, 0.028648947688540625, 0.06091550811223927, 1.2465720191117258, 59.479703826289025, 59.28491107879147, 46.61472974285003, 30.89058314600299, 65.57285877966112, 65.01878869148993, 93.4127361543717, 12.873515044489215, 0.17060968063531384, 0.1550329834102623, 45.62883023292788, 93.29221740845712, 74.8845185002973, 87.06438787521856, 76.49972700303601, 85.92639846186485, 76.30877033356698, 79.56954648417812, 74.53921656454764, 80.52514568451913, 73.61366271972656, 80.25172510454732, 65.96116558198007, 43.57763851842573, 56.84312582015992, 72.42725556896579, 73.53920044437533, 74.02796699154761, 74.5847317480272, 74.14324545091199, 68.15220940497615, 71.02092896738361, 69.4875567959201, 67.96857972298899, 68.86922651721586, 70.99864990480485, 60.342158502148045, 53.03523002132293, 53.87679023127402, 51.763648602270315, 51.36234306520032, 52.12282396131947, 50.84087179553125, 52.56341595803538, 47.924416988126694, 46.84938161603866, 49.63055779857021, 48.660073203425256, 51.99892020994618, 49.3824286614695, 53.38312072138633, 54.94996247753021, 46.532854187873106, 44.6626288660111, 42.279471274345156, 41.76631150707122, 41.1114521949522, 45.33408764869937, 49.84654311210879, 44.85059668940883, 46.19161190525178, 51.63878779257498, 45.152313247803725, 46.89293169206189, 43.99747725455992, 44.38841988963466, 44.68317424097369, 46.09374092471215, 44.577270246321156, 44.171893289012296, 43.85495793434882, 43.989334414082194, 42.52014006337812, 43.42570550980107, 43.20952407775387, 44.92575322428058, 46.348957784714244, 45.55845114492601, 44.58335776482859, 45.925114308634114, 43.28595538293162, 44.96642035822715, 43.95935573885518, 45.51048055771859, 43.7967421162513, 42.797737967583444, 44.504298471635394, 42.621145017685436, 44.09965107517858, 42.74679030141523, 44.84663901790496, 44.98097627393661, 44.71890311087332, 45.02862914916008, 42.864857565972116, 43.20439361756848, 47.012928762743556, 42.66483629903486, 41.50308908954744, 42.6073774983806, 51.05422127631403, 48.77681862923407, 41.51738612882553, 44.98536148378926, 39.93480782355032, 42.412396477114775, 46.456964169779134, 48.613416610225556, 46.90399277594782, 50.560018324082904, 47.260869626075994, 46.53919273807157, 46.108524337891616, 46.24902755983415, 43.99287239197762, 45.6286576486403, 47.96640988319151, 50.38061695714151, 49.80407561025312, 50.85114056064237, 51.174288949658795, 54.86931854678739, 58.60643517586493, 60.86733248925979, 59.906010550837365, 59.89673414537984, 59.449415283818404, 59.20031732128513, 56.07169758888983, 57.21746506229524, 58.056393361860714, 58.23481021388885, 60.13334328128446, 65.83300605896981, 67.20931083925309, 70.62874686333441, 68.08272853974374, 70.59484189556491, 71.2924668096727, 74.6639322465466, 86.46064881355532, 80.79640896089616, 70.65065722311698, 74.52762988305862, 68.71167275213426, 79.09393556656377, 73.0165603083949, 80.6608832267023, 4.583024786364648, 0.35721055802799045, 0.11634123015908465, 2.5632556696091933, 69.94405008131459, 67.99486744788386, 70.40329687057003, 44.485741738350164, 38.40431859416347, 47.81122130732383, 49.93869527693718, 53.33583654895906, 4.193803581499284, 0.12003244862200753, 0.037866071347267403, 0.07548627443611622, 0.12442252313297604, 0.05324565414940158, 0.048508028529824755, 0.1618658901462632, 0.17771142294570325, 0.13881669469898747, 0.17767094285978427, 0.10957874988596286, 0.23489034103770412, 0.1825032109815267, 0.1259956310593313, 1.858814411586331, 74.77391550617834, 68.65999944748418, 56.322160536243075, 37.98744516987955, 80.4512482304727, 69.5405323274674, 104.80222440535023, 15.551991808799007, 0.41637436396652655, 0.8166145485255026, 46.69772317332607, 98.13657206873741, 78.84428454983619, 91.13231720462923, 78.49426008039906, 88.19784302865305, 78.2702378303774, 85.2651652982158, 75.01030891172348, 83.06815162781747, 76.91749080534905, 85.33161024893485, 65.47491327408822, 47.642853567677165, 59.30511520754907, 74.9703085807062, 76.80697410337388, 76.17158151442005, 76.5044181577621, 78.41233745698007, 70.18742530576645, 73.83072668506254, 70.86841152560326, 71.45752014652376, 70.87378517273935, 74.36526729214576, 61.39817822364069, 55.55644719831405, 55.7421322022715, 53.56203179205618, 51.384943762133204, 54.342524620794485, 52.44798452623429, 54.908499102438654, 49.70063878643898, 49.82201260905112, 53.843516765102265, 50.47566383115707, 54.68323346107237, 51.1691741789541, 57.40802557237687, 56.556710427807225, 50.5513616531126, 48.45658848362584, 47.16471272130167, 46.15708720299506, 45.974924487452355, 48.26345489871118, 51.43691516691639, 44.142389220576135, 47.576604735466745, 55.0028399498232, 50.83405079380159, 49.134978094408595, 48.46983825006793, 48.26897367354363, 47.436081901673354, 49.83121841184555, 48.17016132416264, 47.385789271323915, 46.32484697526502, 48.35862336620208, 45.748399765260764, 44.92967167208272, 48.39255186819261, 47.50153449273879, 47.64943530482631, 48.53118411956295, 47.47128125159971, 50.36696710894185, 44.89511951323479, 47.80729109241117, 46.26229693812709, 51.0839802988114, 44.346124972066576, 45.610728494582645, 47.78311752503919, 46.354449102955485, 47.286019863620886, 45.69012903398084, 48.125603199005134, 48.36808804542788, 46.98698228405368, 46.76905147490963, 46.74510148263747, 45.40665934162755, 49.49918585438883, 44.174799765309984, 42.431404282969815, 43.73910680893929, 52.378719391361365, 52.24729645636774, 44.4137897799092, 47.57555746263074, 43.7099753656695, 46.49782742223432, 47.6992533283849, 49.8660372918652, 48.455207809325195, 53.17212074033676, 48.526363526621175, 48.15241259913291, 49.31719180076353, 48.90941435290922, 47.090983929172644, 47.96216195629489, 49.74508316286149, 52.709626228578635, 53.274118054297666, 51.399813467456454, 52.65828632539319, 56.42601705366566, 62.13794116050967, 66.28282347033101, 63.665912228245894, 61.14268679772655, 61.22130678546045, 60.75127347823113, 56.50601379333004, 60.771010844938225, 60.05826911618633, 61.76288804700298, 62.70290367064938, 69.29091268970122, 71.52945641548403, 77.44951325078165, 73.24228486707135, 74.17758972414079, 74.05460772975799, 77.09772371476697, 80.89560570255404, 83.2191393452306, 78.82689276049214, 80.33043922916536, 71.37831180326401, 84.76249002641248, 78.0717815891389, 84.94385257844003, 4.259203220567396, 0.5521859408866975, 0.2941552705822453, 4.169368195918299, 81.67128578309091, 75.48850859365156, 79.21592127892279, 58.400973581498675, 55.25916291821388, 55.1945810933267, 62.70137786865235, 65.09063866830641, 5.056490167494744, 0.2622185359078069, 0.2045870590354166, 0.1764891756277892, 0.21472231034309636, 0.18677160774748172, 0.14827158332111376], [0.06876985136900218, 0.10726376241373439, 0.005860606137092316, 0.041122971583277955, 0.0347348899700709, 0.030721068051793886, 0.023093628546883984, 0.095957737235773, 0.6088401653593587, 41.441723608201556, 43.69400347432783, 43.735035388700425, 31.21611241371401, 51.637713063147764, 65.90142003951534, 76.24625559776061, 10.922930163721885, 0.19085654177733008, 0.17358030913577926, 47.177393744068766, 88.0567632182952, 70.96150505927302, 79.91719399729084, 71.42351319712978, 77.64960119801184, 72.2302427599507, 76.92684173583984, 70.56237251527848, 75.06380219613352, 72.42435301503828, 75.03713792370212, 74.78591795890563, 71.37362064853792, 59.73001772357572, 62.75204704653833, 68.88537099284511, 69.19195129025367, 71.58112972013413, 73.0058914615262, 69.33158766838812, 71.5679427116148, 68.4077282874815, 64.57942439663795, 64.5108574436557, 67.4783540541126, 59.696167668988636, 49.629604662618334, 51.38971336426274, 52.564631892788796, 50.75151628063571, 49.52859970831102, 48.22099131922568, 46.77555084228516, 44.606880218751975, 48.294578906028505, 46.36319991080992, 46.912010100580034, 44.61366984152025, 49.56661532002111, 48.57087066096645, 52.39484817750993, 47.714950653814505, 47.519498948127996, 51.828920764307824, 43.91783352821104, 42.48266573875181, 35.79206712784306, 43.45029877078149, 43.945690201174834, 45.0152224879111, 46.13434922310614, 43.190633943003995, 41.62602401548817, 40.7915162271069, 41.57646094599078, 40.392415062073745, 42.766519823381984, 43.19477988827614, 41.8245037909477, 40.52472837509648, 41.03964144183744, 41.649118931062766, 42.3966520832431, 42.92981201602567, 43.56521244971983, 45.4860951823573, 42.88458316556869, 43.979348059623476, 43.622894825473914, 41.67465356088454, 42.8773856163025, 42.50650590465915, 41.469058605932425, 38.53821654473582, 38.76877738583473, 39.80491069055373, 39.09139625487789, 39.09370260853922, 40.58275199705555, 42.44836068922474, 40.847088367708274, 41.11997158296647, 39.9232917447244, 41.0098510403787, 45.59681976995161, 45.36346227891984, 41.2552894315412, 39.839266730893044, 42.61264916389219, 51.60249017900037, 51.45515811058783, 34.81799748636062, 45.28773307800294, 44.537870037940245, 42.22682129952216, 40.617202174279, 46.940890512158795, 46.873798370361335, 47.90534250197872, 47.1925066363427, 41.692731765008745, 42.97959473825271, 41.604121500445956, 42.39335336992818, 41.61327631242814, 46.69937449116861, 47.42821754947786, 46.88745998567151, 48.33211598857757, 53.895503859366144, 58.91011684171615, 61.24186784990373, 61.096198866444254, 61.01692776526175, 63.29440101500481, 59.850744355109434, 62.07726601631411, 61.58804447420182, 62.82558364252891, 60.50564289093018, 61.533166593120946, 62.96346672119633, 66.50597495417442, 67.04235123049828, 70.22199707646524, 74.68183394401305, 77.18637712540166, 75.81832501196092, 76.03852687343475, 67.97846409582323, 71.24953254576653, 66.39053175526281, 67.7015761406191, 70.17732128020256, 74.2480198029549, 68.29505428191155, 91.49883131827079, 14.739710130999166, 1.0265370422313291, 0.15974217184608983, 1.1135213004965936, 56.02937913710072, 64.94961377113097, 59.16469043300998, 41.144407949139996, 35.39275807719077, 27.887381199867498, 40.14459186984647, 44.644162347239835, 7.204124139201257, 0.05829705789144482, 0.1493460522784341, 0.010107447104077908, 0.06720946816306922, 0.0900335793173121, 0.020487947096567483, 0.08717360455662974, 0.09455431778464587, 0.020410983988474456, 0.017950288508267655, 0.025573585392727007, 0.06005048759341721, 0.12241060004359293, 0.07764118783656629, 1.300801851095692, 55.33246417199412, 51.310528555224025, 49.41765154561689, 32.90477122029951, 60.556288534595126, 72.38460371571203, 85.66150511464765, 11.539016846687565, 0.13926251190564326, 0.30193590468937354, 50.62393334604079, 93.29505720446187, 74.55943246041575, 83.75114610118251, 76.35681936817785, 82.64098198183122, 74.71326781857398, 78.28813952784385, 71.37905705359675, 76.13406012135168, 73.4119430665047, 76.7476600216281, 75.53538876195108, 74.13762861682524, 60.31849092052829, 65.04537843888806, 69.79125807362219, 72.3833485572569, 71.83605240237328, 74.10228806157266, 71.84490126948204, 72.9011720226657, 70.40585425592238, 67.3677275257726, 67.69002083809146, 67.37809042776784, 63.53436377740676, 51.309528350830085, 52.486706164575395, 52.43365218562465, 52.24751610909739, 50.349712602553836, 51.024403418264086, 51.302683814879394, 46.85910909406601, 50.87940516010408, 48.04208809329618, 48.64043389597247, 47.2439367540421, 52.93215013319447, 49.099464954868445, 53.391428301411295, 46.78534107823526, 49.834379842204434, 55.77792775246405, 47.80558093901604, 46.9660525168142, 39.768146314928615, 45.09730985087734, 46.06403289302703, 44.555199069361535, 49.661085605621345, 46.802062142279844, 44.051892295960464, 44.25259213293753, 43.558065891265876, 42.299455750373106, 44.984749594042384, 43.71304265914425, 44.66853595549061, 44.0352810582807, 43.18506417735931, 44.37103986740113, 45.43675568795974, 45.22763844459288, 43.89349129892165, 46.10181708489695, 45.36327792752174, 44.328748872203214, 46.64038988851732, 43.947816125808224, 43.63639170123685, 45.18123680545438, 43.933707360298406, 41.93176100330968, 40.794171671713556, 42.97502517700196, 42.11115060314056, 41.89990351277013, 42.76779851605816, 43.066408557276574, 43.592802401511904, 42.48182635153494, 43.14677792210733, 43.9113929963881, 48.65016921874016, 45.04667989669308, 43.34109606281404, 41.052718623991936, 42.249665183405725, 52.98046196660688, 53.87651174299179, 38.104837786766794, 48.69969306453582, 45.571261605908795, 43.243738912766986, 42.37293743318127, 47.53154062455701, 48.73091513110746, 50.10116769421486, 50.2739598674159, 44.415978462465354, 45.3821837517523, 44.30060586621685, 45.60280138446439, 44.27660096076227, 48.655668381721746, 51.08489028869137, 49.37809444242909, 50.473408468307994, 59.11809659773304, 64.5173881899926, 64.5805226602862, 63.702190229969645, 64.75853158581641, 65.16503034099456, 63.338406085968025, 64.69781721791914, 64.8273378033792, 65.95889845202046, 62.51147631675967, 66.0792132346861, 64.67115294548773, 69.02086534807759, 71.33682097158125, 72.93152332305908, 75.20836507120441, 74.67326748755671, 74.5529370154104, 76.43455290025281, 70.7570868153726, 75.37999230046427, 68.90325700083088, 72.32727435327345, 73.05155569507231, 78.81756536422238, 70.16035310683712, 97.6761564131706, 20.138095655748923, 0.9723793450863132, 0.2862049020346134, 0.8046114829278762, 65.54744966568487, 71.74721071797033, 69.42199045611967, 49.41875373163531, 37.40555371007612, 40.85582740845219, 50.72299672711281, 56.45741170452487, 8.581990022813121, 0.09996263039929253, 0.13048340476328327, 0.018875874023163514, 0.07949200263547321, 0.0317778863433388, 0.022897707305908687, 0.14155165923218574, 0.2490130340259883, 0.13980379898942288, 0.17015948140573117, 0.16471976684706827, 0.15758572626979123, 0.2044139384862877, 0.2365629101592687, 2.3621385905050465, 70.35178046072684, 57.3143123042199, 56.32165455049085, 45.92262360357469, 72.06220842176869, 77.48716015969553, 92.20207306646532, 12.991714689039416, 0.44043871784402483, 0.7088356609306028, 54.6218522902458, 95.23741491379278, 79.78415504578622, 85.08295551423105, 79.63559135313957, 85.1044971712174, 78.52851806148406, 80.35989622915946, 74.82608302947014, 81.24620283803633, 76.11884916982343, 79.25592160994007, 77.23550088943975, 70.47592347668063, 61.574473073405606, 64.4125863813585, 72.64729269089239, 72.95715993450534, 74.18417146128994, 76.13143213333623, 73.58411158284834, 74.71407582682949, 73.55110876021847, 68.7628439934023, 72.25846029097035, 72.24960357912126, 67.59837858138546, 55.5962396437122, 56.88972357780703, 55.79553527216758, 55.20650902102071, 52.979563743837424, 52.02815363484045, 51.87439280171549, 49.426986786627005, 53.23460409718176, 49.18226618920603, 51.32973247958768, 51.664169449960035, 56.821027186609086, 52.953197571539114, 55.643676788576194, 46.974920995773815, 47.00942608617967, 58.470289707183845, 52.31964849656629, 51.60007792134439, 44.00322744923253, 45.85133452569285, 46.014822836845156, 45.33431514616936, 49.10851386285598, 50.780769317380845, 46.13136429940501, 44.75814250207717, 47.26646684831189, 45.076176120388894, 49.20803616123815, 47.75679449881277, 49.27768961075814, 47.42525615999776, 45.58913192441387, 47.423012564259196, 46.94858620243688, 48.94056973918792, 48.18170485957977, 50.156798670368815, 47.02806518923852, 48.19765713907058, 48.9243075924535, 47.88575810770835, 48.973600018408995, 48.47222697350287, 47.653392976330174, 43.868423431150376, 43.950573552039366, 45.20779125152096, 44.61960438759097, 45.726077556610115, 46.413727883369695, 47.72734926592919, 47.65423628591722, 46.21557758700463, 46.04077716027537, 47.05302323064497, 50.472588692941976, 46.60036210090884, 42.40619128750217, 40.09215762538295, 43.04183490814702, 54.277617239183, 55.1821550246208, 43.950146013690585, 52.12346330765755, 47.48841024214222, 46.26470919578306, 45.07372071666103, 47.55641629618984, 50.259953083530554, 53.034826017195186, 51.05386826299852, 45.87760656110702, 47.8687350211605, 47.66747820761896, 48.90375829512074, 47.159444978160245, 51.940625944445216, 55.38913065387357, 52.1229180982036, 54.63933821647398, 59.21406915110927, 66.73029530432918, 65.37541843229725, 66.68638829262026, 68.02228481538835, 67.89274461807744, 66.0052530227169, 66.91408188112321, 69.01219690999677, 69.37604381192115, 64.3857220680483, 69.1216859509868, 68.72050592976233, 72.35342087284212, 74.1413470237486, 75.37088455692415, 76.7946735505135, 77.98639159048759, 73.83205244618078, 78.52105771341633, 78.78775535091278, 80.48035221715128, 68.98692115660637, 77.44561441483037, 75.25123657718783, 84.3845461260888, 74.8575718172135, 103.61440520132743, 18.58351718994879, 0.9925158129584406, 0.5770579965845232, 1.3914081117799206, 74.61316893177649, 82.14696730336836, 76.39066157802459, 66.90454267686414, 62.98711469096523, 44.060839222323516, 62.977563719595636, 69.01327948416434, 11.071941987160715, 0.3579711301192161, 0.2518410322767112, 0.14395613343484942, 0.1765478579627891, 0.1528066552935108, 0.2384857755274542], [0.026483278413633668, 0.025536137099768368, 0.05081095394768542, 0.06241507925874284, 0.0251556825148122, 0.06244686424672123, 0.09421584481794028, 0.05429192724066877, 1.141569679302554, 45.19875018827377, 47.44112606971495, 35.488805155600275, 25.197260879701187, 57.574745916551166, 62.36016304262223, 77.82640595589915, 7.321720229041192, 0.17450654007975133, 0.12875754656570573, 42.443187082967455, 90.59612135733329, 70.87034133172804, 81.13170885270642, 72.47360229492188, 77.7170894991967, 74.332335072179, 74.76998529126568, 71.65661181173017, 75.414062007781, 71.80759168440296, 74.61996247691494, 69.4024492079212, 67.62989090334985, 73.4730379043087, 72.21159581215151, 68.60066967625772, 71.40560365492298, 68.61329970821258, 68.29362653916883, 70.06219187090474, 68.23846232506537, 66.1675371662263, 67.26340816866967, 65.18892542008432, 63.633391857147224, 52.785665296739154, 51.02275602279171, 51.31462350968392, 49.35987895534885, 48.73606912551388, 47.913253922616285, 48.88797859991751, 48.887076454777876, 48.70530989862258, 44.61359531648698, 44.24951307235226, 48.209432094327866, 43.86496782302857, 45.46647548675538, 46.78705907637074, 51.6014938969766, 48.65783745242704, 45.47485366944344, 55.847149741265085, 61.59435949017925, 50.45803669960269, 42.50937315725511, 43.38076299236667, 47.789150130364206, 43.232101240465724, 46.2143067390688, 44.45139354275119, 43.03813219070435, 41.96905882127824, 42.50079885605843, 41.319231910090295, 40.1578769376201, 41.488293909257465, 41.0048774750002, 41.86987384673088, 43.290826966685636, 42.35630658365066, 43.82190019853654, 43.97506483139531, 43.42483082125264, 45.295118901037405, 45.18091124873008, 45.0290096190668, 44.02962107812205, 39.651495026003936, 42.79012856944915, 41.82693958282471, 42.868175891137895, 40.85073617196853, 40.71258637212938, 39.945323697982296, 39.424350569325114, 40.42609645474342, 40.12192449262066, 38.772429112465154, 40.67179764470747, 39.95104251369354, 43.703762331316554, 45.830785228360085, 46.62059368625764, 42.18274562589584, 44.37648019483013, 40.79774887331071, 43.05992487938174, 44.726685093295195, 46.7016573106089, 47.57718524625225, 43.453903428969845, 45.11445453090053, 44.648869191446614, 41.702537690439534, 43.297514607829434, 44.082573075448316, 48.05143510141681, 45.66892862319947, 43.77214101053054, 42.33485514117826, 42.235046509773504, 41.059225836107814, 42.22970424159881, 43.95141686162641, 46.67975479556669, 46.36118381254135, 54.39848899841309, 59.12225823248587, 60.75811801418182, 61.85320454259073, 60.167475746523955, 60.62490647838962, 62.681154128043886, 64.06985359807169, 64.39041714514455, 62.27241962186752, 64.75356586517827, 64.06042029780727, 64.55261499651017, 61.70103226938556, 66.96002852532172, 66.10917229806223, 68.14274080338018, 65.91398731354745, 65.31853229768815, 59.00904686220231, 57.71517461346042, 62.90128538685461, 71.18653928079914, 77.85857723605248, 74.41206901304184, 67.39744340219806, 73.72221823661559, 72.47605769864975, 87.72417760664418, 45.08919054462064, 0.4474423855783478, 0.284430458540878, 0.2815969444571003, 49.9448416309972, 65.72726288149434, 60.04452905347271, 45.95392803991995, 30.91530976756927, 26.447904686773978, 31.037075827198645, 49.675370877788914, 8.649898017606429, 0.12461470394966104, 0.09634014534493608, 0.03670626402562184, 0.10940677080784114, 0.03840915107678983, 0.09767498460508163, 0.0791888922873524, 0.051417913918773976, 0.05089422770505471, 0.027683650090869878, 0.006346535707463421, 0.029708541133591247, 0.05644221347005618, 0.12926005427875828, 2.7742132400312736, 58.957871698564105, 56.48153820345479, 40.8397731473369, 25.428651302091538, 68.8170825281451, 69.93752325734785, 84.20538010135775, 7.131581373753087, 0.14382170032589667, 0.1497409552816422, 46.142794086087136, 96.66993510338568, 72.16443323319959, 82.08662556063744, 73.42052521244173, 80.49163295376687, 76.42363302169308, 76.7427884378741, 72.31463647657826, 76.85091249404415, 74.26013992678735, 77.31707834428357, 70.3520393371582, 68.9553931451613, 75.16881973512712, 74.86582448405605, 71.39766477769422, 73.1787738492412, 71.14858642701181, 70.73744358554964, 71.1731404642905, 69.6995295247724, 68.58853386294457, 70.15965492494645, 66.36006278376426, 66.48994814965033, 55.317366969200876, 52.951605089249156, 54.21922099205756, 50.18958968500937, 50.299243465546645, 49.53702888181133, 53.28812876055318, 51.69273607192501, 51.39028210793772, 47.7262863036125, 47.097812775642645, 49.114264057528594, 47.254178062562026, 47.55855006556357, 48.57418506376205, 52.74596698822514, 49.378369008341146, 44.75675790540634, 56.207917582604196, 65.09362359200755, 52.25683958299699, 44.195886427356356, 45.835382246202045, 47.396736606474846, 44.03569682951897, 47.787812602135446, 49.73963106832197, 46.43386140946419, 44.53140204952609, 46.35470405701668, 43.118603537159586, 43.43672736998528, 43.447804143351895, 44.641593194776966, 43.98423925522835, 44.2893212072311, 46.16244908302061, 45.43024455347369, 46.79275828023111, 47.26509009638141, 47.03625902052849, 46.2792415772715, 47.35959568331319, 44.32392435689127, 43.23036755284956, 43.70015375075802, 42.57214284712269, 45.28992960529943, 43.8424494958693, 42.79493347291024, 42.474993582694765, 41.53509955252371, 44.525102723029356, 42.85982516504104, 43.02630232226464, 41.510722021902765, 42.982846383125555, 44.252548986865634, 49.00361399496756, 48.852186972095126, 44.37141641493767, 43.566542133208245, 41.195932203723544, 44.653375994774606, 46.7370214000825, 49.037479739035334, 50.50057480412145, 46.292856124139604, 46.3343704900434, 43.33565181301486, 43.19749809080555, 42.64809954550959, 45.47978801112021, 48.75797164055609, 47.058020330244496, 46.31807304197743, 45.23939771036948, 44.25706363493397, 44.631022407162575, 44.453401796279415, 47.53172497595511, 48.20844365704445, 47.99677295069541, 57.43685107077322, 60.8010797346792, 63.85495870344101, 61.61664247512818, 62.282194168336936, 62.705739544283965, 65.1740792489821, 65.89335564644107, 65.89421072313863, 67.70732633529171, 66.14463052441998, 67.3366545092675, 66.77961518687587, 66.71789276984431, 68.68475744801184, 68.18150951016334, 68.87242717127647, 65.92620157426404, 66.13047076809791, 61.55160957767118, 62.93653572759321, 68.34932419561571, 75.79342580610707, 81.0442949110462, 78.5347624747984, 68.06435615785661, 77.2846560324392, 74.77298982681768, 87.17108418864589, 53.867478524484945, 0.17245553884535067, 0.01610939646319997, 0.2150301704363477, 54.87429211216589, 74.2984301044095, 68.72067066930956, 55.052069617855935, 26.946769375954908, 30.664844859030943, 44.59832160703598, 59.615692400163226, 11.007098344064529, 0.25320664528877507, 0.04657264145451688, 0.045703127830018925, 0.043536447319051916, 0.06061461941909887, 0.1127012553174169, 0.1954374411293576, 0.12953754664669115, 0.15671460769109188, 0.14592004579401788, 0.1516524212615144, 0.14692843200698977, 0.180658808338546, 0.25080010264871583, 3.4748973577253284, 73.44726008753624, 62.62606051660354, 48.573267229141734, 38.1998493594508, 81.38332889926049, 74.94187139695691, 95.87934217145367, 10.237182186495874, 0.3855612351288719, 0.21978924651780438, 50.50046105538645, 100.23638156152542, 74.39356327056885, 87.32338197769658, 77.45539680604013, 82.15471006208851, 79.73725134326567, 79.33838552044284, 75.16200265576764, 81.16013034697502, 76.5651442927699, 79.29448635347428, 72.03518329128143, 71.8771666865195, 76.11894330670758, 77.98337921019524, 71.5721788714009, 75.66641161518713, 73.54663725822203, 73.56877511547458, 74.12708528580205, 72.84262672547372, 70.45060065484816, 74.35676359361219, 70.39280845272926, 69.93419708744173, 58.50062924046671, 54.199381643725985, 57.15400503527734, 53.709144207739065, 52.22589208233742, 51.03693146859446, 54.95988999643634, 55.98805304496519, 55.101452258325395, 48.56602653380364, 49.047458248753706, 53.68553153930172, 49.42878323216593, 49.68319992865286, 50.36013826247185, 55.67360055062079, 50.725609025647564, 44.852573563975675, 56.51286225165091, 65.64244554888818, 54.20775590404388, 44.43580996605658, 46.48060821717786, 50.164612031752064, 44.73091733071112, 47.69369140748055, 50.7756192453446, 49.71949754222747, 46.573329125681234, 49.06233972118747, 47.713699417729536, 46.02216551380773, 45.785466163389145, 47.55648297648276, 47.0897993733806, 45.896088769358975, 48.71089143137778, 49.41472937983852, 49.435741516851614, 48.15791568448467, 50.44479870027112, 49.686549632780014, 50.85085814998996, 47.94312277147847, 45.30420311035649, 46.63291385096889, 46.283367910692775, 48.880945790198545, 46.081644335100734, 45.45447695639826, 46.79189143642303, 43.88638788653959, 46.42539301226216, 46.63622040902415, 44.65449387027372, 45.26014312621086, 46.116282786092455, 48.44946545939292, 53.36630552045761, 50.023622435908166, 44.56936667042394, 45.00454971867223, 42.27318371495893, 45.05223397285708, 49.11186748935331, 49.687506691102065, 50.49576990066036, 49.05866838270619, 47.713224810938684, 44.054402612870746, 43.48680034760506, 43.60909984957787, 48.3303548443702, 50.35937732265842, 51.310477564411784, 48.702132778783, 48.10528532151253, 46.693239904219105, 47.454340534825484, 48.204780163303504, 50.01204359915949, 52.2400910623612, 52.12243564667241, 60.10354895745555, 63.03355947617562, 65.64932538617042, 69.6135982390373, 67.08141803741455, 66.70851046039213, 70.28152296620031, 69.57082871467837, 66.788495432946, 68.38460983768587, 71.68231902583953, 69.86808946055751, 70.87990407020816, 68.76164374812957, 72.92135653957244, 70.28748496886223, 72.60088320701354, 69.01289509188744, 71.61941989775627, 65.02334256325999, 68.54216360276746, 71.75701664340112, 81.66524533302554, 80.66611566851216, 77.88707717772454, 71.07368484620126, 81.7082109758931, 79.61302987990841, 94.82954332905432, 54.167398637340916, 0.4866713273429102, 0.7200269184766278, 0.3851793556203766, 64.62209978411275, 83.94163208623087, 75.90419353977327, 66.09711493215254, 52.1931089124372, 43.74900687125422, 57.7034741832364, 73.46509118233958, 14.376968356870837, 0.4173662639673679, 0.20605693661397506, 0.12389235964585697, 0.2940113379830315, 0.25176525085924134, 0.1803329911443495], [0.0165590881595328, 0.00449265607805442, 0.06571689906019358, 0.0552481658486349, 0.06472900569919618, 0.011360054486431183, 0.05167647625409788, 0.11663195286546985, 2.9370881905478816, 57.9429623388475, 48.2548374514426, 49.113350145278446, 35.50966039780648, 52.45952021691107, 71.60342447219357, 41.35703963618125, 0.13071828732086768, 0.11230374761526624, 0.04004187213497297, 42.71207732539023, 87.5246701701995, 73.06170678907826, 77.61659837538197, 73.03349710279896, 74.46186742474957, 73.90950356760334, 74.56029538185366, 71.71661623062627, 73.94545601260278, 73.94679746320172, 73.20269246255198, 71.91045191980177, 77.08044175178775, 71.87926907693186, 68.05710761777817, 65.32760081752654, 67.84677443965789, 66.14454423227619, 67.69804600746401, 66.69679041831725, 66.61242808065107, 63.233984747240626, 59.45736985052786, 57.25131511688233, 52.995912182715635, 48.23782613200527, 50.24416554358698, 48.2107029422637, 49.73745415287633, 49.77444994834162, 50.09363674348401, 48.78638136771418, 49.64523138538484, 46.089947992755526, 44.42303872877552, 45.331949956955455, 45.64310766035511, 44.01834426387664, 46.61074069238479, 45.32699992579799, 50.99977093358194, 51.528549578882036, 45.72595988550494, 44.951699702970444, 52.59514401035925, 55.59934616088868, 47.14429286218459, 50.4194680336983, 52.24685715090845, 50.07512315627068, 46.89330823959843, 46.3507346184023, 44.61304226229268, 43.895111237802816, 43.67535652652864, 40.54392837708996, 41.122729009197606, 40.99889978285759, 41.67912506288098, 45.00531065848566, 41.77975346965175, 41.7335008805798, 42.25762367248535, 43.75463155008132, 43.9341192091665, 44.54089026297293, 41.00246521734422, 43.8061793388859, 42.84983881058232, 43.59753277993972, 41.47300843269595, 41.971239659094046, 41.52246559819868, 42.86563027289606, 41.50727818089147, 41.37123077146469, 41.041414353155325, 38.62777994525048, 40.0942051026129, 41.51300091897288, 38.25039694386144, 42.68260855828562, 42.32561011468211, 46.45707399614396, 45.15629837589879, 43.63707419364683, 44.92936572720928, 44.19324667223039, 43.19694111424108, 50.177175383413996, 48.17944165199034, 45.653537242643296, 45.17418830625473, 44.021031087444676, 41.987199783325195, 41.98241449171498, 39.4203850530809, 43.77317651625603, 44.830180752661924, 42.606404750577866, 42.836600811250754, 39.44091081619263, 42.32975213758407, 42.151303906594556, 44.390039828515825, 43.68846901001469, 46.80204645279915, 43.54401203893846, 55.997474578119096, 58.87820836036437, 61.37656596399123, 49.13122438615369, 51.751438263923895, 64.04917486252324, 60.146138052786554, 61.57141754704138, 61.09723829453992, 65.92613881634128, 63.91235474617251, 64.2617634034926, 65.11778931463918, 66.72721232137373, 66.48449605511081, 64.28895327352708, 56.80781272149856, 59.82454292235836, 60.20843705823345, 64.14844612921438, 70.28083262904998, 75.58775240375151, 68.33031638976067, 62.033582579705026, 72.20689681268507, 79.92928274216192, 70.11652454253166, 76.22548272532802, 78.5994815826416, 76.12415221429642, 0.8377937539931267, 0.056666983667040066, 0.04103412453625952, 42.872235544266246, 70.74167974533574, 62.23925205969042, 51.225044419688565, 38.59193732661586, 40.5104431029289, 33.66561297447451, 51.832074349926366, 13.040278534735403, 0.18095367558060155, 0.15685296317021694, 0.007247757232342397, 0.013297639276471832, 0.0640840477670633, 0.023229921334272912, 0.04365926653507256, 0.02286221062193715, 0.0879075474316074, 0.02728276777141277, 0.026705382624641064, 0.06690038232913902, 0.023339705564261928, 0.14670718581445757, 5.128284250536273, 70.85209446568643, 55.96482476880474, 58.090372854663485, 41.47454207943332, 60.332886019060695, 78.85130559244465, 43.280503288392104, 0.4807040539960708, 0.13578546864371147, 0.20100676244305027, 45.83038514660251, 89.92783577211442, 77.94930165813815, 80.87972010335615, 76.22494143824424, 77.09595080344909, 77.01677383915072, 75.15082390077653, 75.25624936626804, 75.24767506507136, 74.80161528433524, 75.51509441867952, 73.91994491700204, 77.76442466243621, 74.08531988820722, 73.03930221065399, 69.48687430351012, 69.7877436299478, 68.18434146142775, 70.32572807804232, 68.21285709258049, 69.03930048788749, 67.55691912866408, 62.78765040059244, 60.005689744026434, 56.2426580152204, 51.11594761571577, 52.81034092749319, 51.13923080505864, 51.53339370604485, 51.56487072667768, 52.68480154775804, 49.40497836759014, 52.3544869884368, 48.0905842781067, 50.01557765468475, 47.95715308958485, 47.0553844974887, 46.54014195165327, 49.34306375442013, 44.46403534181657, 52.451463668577134, 52.829384034679784, 45.14110703622141, 44.72340206946097, 54.0981609590592, 57.10228073981501, 49.9604840432444, 52.08933084241806, 51.74850040866483, 50.028207686639604, 47.272883845913796, 50.14113664627076, 47.93706270956224, 46.845753423629276, 44.85644886570592, 43.105447907601636, 45.08989264888149, 44.70455900315316, 43.95799859877556, 47.15861343568372, 44.19497643747638, 44.81322042403683, 44.64737869078114, 46.40938581958894, 47.53428628367763, 47.15043137150426, 44.57786644658735, 44.71438061806464, 44.17780430086198, 46.12017377730339, 43.34511649224066, 44.035186921396566, 42.78686907983596, 45.54482875331756, 45.054779591098914, 44.36648991800124, 42.28023221415859, 42.26288357088643, 42.328642106825306, 44.68629644763085, 41.6451887161501, 45.5459701630377, 44.58777827601279, 49.5390449800799, 46.79257000646284, 42.781244401008856, 44.534783132614635, 45.42060336759014, 42.16326321324995, 51.36309223790323, 48.64764321234919, 45.89577105737502, 46.47203391598117, 44.07345748716786, 43.43447985187654, 42.20530317675683, 38.61456940251012, 44.96571433159613, 46.475520903064364, 44.59947870623681, 45.72899187764814, 43.76832846672305, 44.96055249244937, 45.410397360401774, 45.71266697299096, 48.23570412974204, 48.12331645719467, 45.92060750530612, 57.86314602821105, 62.432758269771455, 64.35523740706905, 56.50374666337044, 56.168285954383116, 64.98849622664913, 63.10289129134148, 64.5240052284733, 63.719464348208525, 67.07721325658983, 66.40944542423372, 67.11315001210859, 67.47637717954575, 68.63669272392028, 68.24840945582237, 66.64853742045742, 57.787063813978634, 64.29105174156928, 63.13649031423754, 66.65789619568856, 71.9851024689213, 78.1856087715395, 70.32812072384742, 67.95371394003591, 76.40868094659622, 84.03454519087269, 72.33582512024911, 80.0554967695667, 79.72452717442667, 82.24931763064477, 1.378321368848124, 0.13919276726101676, 0.014480185045319942, 46.46358120825983, 79.68507597523352, 67.1265096049155, 61.67578005021619, 35.93651625417894, 42.810556273306574, 43.586863933071015, 63.725547944345784, 16.75614768458951, 0.23960316073029275, 0.13126757236257677, 0.09671762750874605, 0.09687784713723006, 0.0604160915639612, 0.022710050238416563, 0.12496311307674456, 0.14069244565982975, 0.21970969594774709, 0.2158462992238422, 0.1189807094934006, 0.16480399055346368, 0.14549947884534636, 0.2053535300036592, 5.925691320050148, 86.53023166041221, 61.90468957347255, 65.993281948951, 51.34200557585686, 72.71973102323471, 82.95715639668127, 56.013254273322325, 1.406296693509625, 0.17898535055498924, 0.2999164356339363, 50.33336416367562, 93.58465363902431, 81.84377593378868, 84.18416792346586, 78.78759845610588, 81.07244968414307, 82.59695729901715, 80.59983545734038, 77.1141113773469, 79.8695921128796, 77.70982526963758, 75.01740840173538, 76.20518053731611, 80.23346254902502, 77.44536338313934, 77.46402602041923, 70.50912241781913, 74.45090047774777, 71.04521628349059, 72.93499854303175, 73.22139432353359, 71.89376615708875, 70.58955454057264, 66.84499325290804, 62.722731251870435, 58.53828399412094, 54.08310297996768, 54.679797464801425, 54.95786605342742, 53.783218168443256, 54.828180728420136, 55.16845810797907, 52.80720695372551, 56.11762462123748, 50.2253891575721, 51.01626450015653, 51.18691113687331, 49.78985701837848, 50.39727526326334, 52.55884247441446, 47.862212119563935, 53.64684520229217, 53.27206273232737, 44.942639027872396, 45.214573029548895, 55.20607363793158, 58.042288518721065, 49.63188748205862, 53.36651732844692, 53.62074182879541, 52.72135411539386, 49.764083123976185, 52.46315233169064, 51.43994715905959, 50.315595826795025, 48.56983123287078, 44.2220211798145, 48.68383884429932, 47.598444492586204, 47.918996272548554, 51.9217985676181, 48.449183048740515, 46.61309803685835, 47.39549321513022, 50.06321091805735, 51.008772773127404, 48.45131681811426, 45.50675430605489, 47.7536448355644, 47.790487658592966, 50.27345388166366, 48.208988866498395, 46.15841688648347, 47.49898887449696, 47.061370034371656, 48.500923033683534, 48.83503052496141, 45.60129127194805, 43.72512748164516, 44.85367182762393, 47.33518677373087, 43.438586573446955, 48.72666720421084, 46.35400195275584, 52.52549448320943, 47.96865740130025, 44.87467219752651, 46.805768782092684, 44.80812134281282, 42.68303609663441, 52.07684593815958, 49.40958715254261, 45.68402974836288, 46.64388472034086, 45.46306694707563, 44.306461964884114, 42.6442870017021, 39.99323544963714, 47.035270583245065, 47.65358125009845, 48.330754926127774, 48.824773526960804, 48.312496292975645, 47.741654149947635, 48.42833565127466, 49.01516537512503, 50.0513026022142, 49.331253497831284, 49.38513509688839, 59.57662559324696, 64.09668261005034, 66.89050843638759, 61.53626134318691, 59.80458198055145, 67.3815813372212, 66.89625078631987, 67.19992852980091, 64.9912771871013, 69.54880068379065, 69.8257121732158, 70.30613191666143, 70.01002434761294, 71.96528665481075, 71.5647263680735, 69.69048453915504, 59.47924883134904, 66.92785724516838, 65.44689970631754, 66.25508446847239, 73.37784982496693, 80.20070291334584, 74.7836116052443, 72.66103667597618, 77.7282133410054, 84.68540760778612, 75.23302109010758, 88.00221873867898, 83.18987061900478, 85.6201005751087, 1.344363203933162, 0.24961418322017118, 0.13802181719051254, 54.76015506252166, 88.03504113228091, 76.20356452080512, 71.897413961349, 68.68788749940934, 65.90065125496157, 52.83392221696916, 81.05977258374615, 21.289446623094623, 0.33142756250116134, 0.2693604059036701, 0.13759836975124576, 0.16941668255434883, 0.19216033149390452, 0.12361541886122958], [0.1510163844232598, 0.04301817351651769, 0.0410040172808353, 0.010543839514045226, 0.031096707774145953, 0.08275678591622461, 0.14006290524717302, 0.2805160863264915, 3.627759722932693, 59.26315761381581, 48.63729599983462, 28.50069280593626, 29.532533076501664, 54.06612303949172, 78.06427417262908, 23.91267288115717, 0.6308856630517591, 0.48128263424000434, 0.682891572435056, 33.792321220521, 90.22941896992346, 74.26413289962277, 75.06730095032724, 71.08130993381624, 73.53224215968963, 73.55766696314659, 75.11411051596366, 73.21041953179144, 74.6151928747854, 74.07723980565225, 73.5102141288019, 73.02146327111029, 67.2234784403155, 67.80696238240888, 67.1674434600338, 64.13898929472893, 60.58262725030223, 61.268579190777196, 60.65262194602721, 60.684832449882265, 55.880274157370295, 56.07060716998193, 50.20704815464635, 50.50100234247024, 49.814838594005955, 50.76302059235112, 50.37325466832807, 49.12065752090947, 50.05964548357072, 49.79630539494176, 48.07886423603181, 48.55175302874658, 47.857218942334576, 46.3898955622027, 42.617457989723455, 45.31319318279144, 43.321939206892445, 45.72260625900761, 44.87404069592876, 48.356101282181285, 50.08878084921068, 55.08984988735568, 47.656405356622514, 51.65252393291843, 53.01171148976972, 50.691625610474624, 49.614860473140595, 57.323282764803984, 48.27833244877477, 47.83237464966313, 46.824843268240656, 51.10825584780786, 45.786089820246545, 42.31114833585678, 41.41989561819261, 44.90224645983788, 41.58241902628253, 40.64917341355355, 41.535503556651456, 41.95235736908452, 40.135974422577895, 41.230268632211995, 44.768980010863274, 40.64989512966525, 41.4679995659859, 43.08484369708646, 44.064816505678245, 44.04240408251363, 42.47018867923368, 43.21367394539618, 42.26169117035405, 41.909430949918686, 41.815925567380845, 42.81730275000296, 42.07579043603713, 43.74882251985612, 41.289476809963105, 37.440325521653705, 40.01858965043099, 39.35675636414559, 42.64689930023686, 40.730386087971354, 41.31462312513783, 47.00495458418324, 44.39402103424073, 44.719283580780036, 45.01377121094735, 43.67832183837891, 44.031480281583725, 48.38582892571726, 47.075686685500614, 48.237779063563195, 46.66992925828504, 48.17876308195053, 40.279242915491906, 39.43551363483552, 40.610616514759684, 44.842395013378514, 42.33522776634463, 44.13778435799384, 41.57109514359505, 41.414631797421364, 40.266946285001694, 40.805923092749815, 42.87372604493172, 47.458047174638324, 45.40265067931145, 45.10798654248638, 50.79336797037433, 61.17609754685433, 58.49520852488857, 58.26098419004872, 61.52499629605202, 61.679106220122314, 61.24322106761318, 65.27593927998697, 61.27380771021689, 62.68232299435524, 62.388686518515314, 66.70100304388231, 64.60599453218522, 64.14562594506049, 63.00163138297297, 62.2229467668841, 60.37853456312611, 67.98017424921836, 68.88105638565557, 69.3404051565355, 64.18724229258876, 68.6581402440225, 70.39844882103705, 73.5837350353118, 63.97299458903652, 70.31951504368936, 74.79883040151289, 81.59534085181453, 72.67982482910156, 88.90542291825818, 5.893078773252427, 0.21799002774059775, 0.1352752387643822, 32.567180664308616, 73.10378597628686, 62.47355484193372, 54.19478462588403, 29.59022329699609, 28.289504551118423, 34.612500590662805, 56.81269214999292, 14.003660698090831, 0.2149994196670671, 0.1357776851904008, 0.11215624504632528, 0.052445176538200154, 0.0469396626877208, 0.012367619070104294, 0.05381978342249509, 0.09827552858980433, 0.10572393334680989, 0.016182036920180245, 0.02140590812139694, 0.013784471872983681, 0.11885257362718545, 0.28279449310033555, 6.448250557145765, 72.91803036966633, 55.06054585979831, 39.581719983008604, 40.26138436409735, 60.945477870202836, 84.62459518063454, 28.477470413331066, 0.5643229799405222, 0.32670315955915763, 0.7235805245657122, 37.20418707016976, 92.92709181385656, 76.37876895166214, 80.02449435572471, 72.4075888049218, 77.79358356229721, 77.14849487427743, 76.60368550208308, 74.29427239202684, 75.33557538063296, 74.80035228113975, 74.62919573630057, 75.30562416199716, 69.8731336285991, 68.9119960415748, 69.36064458662464, 66.484158731276, 64.84927561975294, 65.05367817417269, 64.28132034117176, 62.87782569085399, 59.195685002111624, 57.72406662664106, 52.968741924532004, 51.840503523426676, 53.17340335538311, 53.54246700963667, 51.9171231023727, 51.27490166694888, 50.91482808513027, 52.300185695771255, 48.869104154648326, 51.2420988851978, 51.78684157709922, 49.01295708071802, 46.173192454922585, 47.54803026876142, 45.85117370851579, 48.202477732012355, 47.5160982531886, 50.065501582237985, 53.05335137151903, 56.07833423922139, 49.096609469383, 52.22503308326968, 53.83642904220089, 50.189872095661784, 51.64356523944486, 58.5895650617538, 48.2209324836731, 47.797818568445024, 47.6366993688768, 51.976088093173125, 51.23443457388109, 44.953123523342995, 44.022223487977065, 47.49000664680235, 42.545698227420935, 42.31726331095542, 43.912063721687566, 43.951860089455884, 44.96725190070368, 44.38541143171249, 46.50203612542922, 43.60629927727484, 45.76465014488467, 43.60691116702172, 46.92522848806074, 45.5904733750128, 43.79273737630537, 45.3854432413655, 44.38918867418843, 42.41694642651466, 43.77441598523048, 45.72876045780797, 44.58202415897001, 46.09839285573652, 44.34960019203925, 40.66773406920895, 42.04835737905195, 42.35622813624721, 45.22417499173073, 42.98792193012853, 47.222285270690925, 48.94017750217069, 44.27573803932437, 46.17826800192557, 43.2128777042512, 43.840645205590036, 46.36522385381883, 50.16845987689111, 46.37619472319081, 48.582845657102524, 48.30594593478788, 48.966288720407796, 42.02692947080059, 40.507034563249164, 40.625180275209495, 44.8608026965972, 43.74955600307834, 47.667046746900006, 45.59137552015243, 43.678847435982, 43.552005829349646, 43.09404165514054, 44.54155314353205, 48.917192412960915, 47.5230408483936, 49.056554225183305, 53.29944872087049, 61.918751270540305, 60.01261664975075, 63.875531534994806, 63.706202814655924, 64.36104643729426, 64.25632699843376, 67.24863652260073, 62.952103614807136, 65.15509497734809, 63.05366554567891, 67.58310487193447, 64.82028538180937, 66.83664644918134, 63.445306362644324, 65.06148761318576, 60.51511541489632, 69.216473948571, 68.7236124469388, 70.4857764705535, 67.47152128527242, 72.72920746957102, 71.14726851063391, 77.33120672164425, 67.95631839383033, 76.07567956370693, 78.565961007149, 85.32911562150525, 72.99096292065036, 94.09696225197085, 7.32403491773913, 0.22217732643888843, 0.14004989707421872, 35.61867090963548, 84.28156821958481, 67.89469011368291, 66.13123955265169, 34.92574891736431, 30.84708013842183, 44.44590614688012, 68.74548358301963, 18.334885989466024, 0.16120772868875535, 0.0755125972171945, 0.010805589732744042, 0.04726453759377042, 0.02754972643038679, 0.127124001963004, 0.27606912978714515, 0.27030689221236015, 0.2615705787414505, 0.1105920620442879, 0.14098982567027693, 0.17538424701459948, 0.41350294385225544, 0.5186442826544085, 9.389650167957429, 86.903853108806, 62.38958866365495, 40.199230486346835, 40.85001445585682, 69.94266940701392, 90.2106543510191, 35.0137355250697, 0.8189877663408557, 0.4814535944211868, 0.885011368701535, 41.023143952892674, 96.97052201917096, 79.14105107707363, 81.25781305374639, 76.64297196172899, 80.50337653006278, 79.76484913979807, 78.80508438233407, 75.74874216510405, 77.46563419218987, 76.76705221976005, 76.28264734821936, 79.93505647105556, 73.58106782359462, 72.15496463160362, 72.0987335328133, 70.38783488735076, 67.59849625249063, 66.79983892748433, 66.02216628289992, 66.11100796730288, 61.589962513216086, 63.007126623584384, 55.61824806274907, 55.27518972273796, 54.82857688780754, 57.612985103361076, 54.85127172162456, 54.315797590440326, 55.00297723277923, 54.91374723372921, 51.99156184350291, 52.80840327662807, 52.65678013524702, 52.61167680063556, 48.74873838117046, 52.450424240481475, 46.5262528388731, 50.57384075657014, 50.15083274533672, 53.89649621901974, 53.90655317614156, 63.14571180651265, 51.158901491472804, 52.279965877532966, 52.98527079243814, 49.990854955488636, 50.50374800159086, 58.681521108073575, 48.159531700995664, 47.234248499716486, 48.464425379230136, 54.87923037621283, 53.41825731338994, 46.99197938365322, 48.22096778500465, 51.07395472065095, 45.40384307984383, 46.43828976538874, 46.37835594915575, 48.45841238575597, 47.69378554436469, 46.47535224114695, 49.78202012277419, 45.77387163715978, 46.97632128192533, 46.43657176725326, 49.68895796806582, 49.44109162976665, 48.34008232239754, 48.484413777628255, 47.64671317992672, 46.086260964793546, 46.6972367994247, 48.318862299765314, 46.12743800686252, 48.72605139209379, 46.14219788582095, 42.47258132503879, 44.63461137587025, 43.889278673356586, 47.38423601273568, 46.439470398810606, 50.3136581759299, 50.02308114882439, 46.22855278753465, 47.66565822785901, 46.37014642838509, 44.35421289936189, 45.79520540852701, 49.82842960665303, 48.18180684120425, 48.380184635039306, 49.066058128110825, 49.21928159652218, 41.87759699360017, 39.81983923142956, 40.94661851083079, 45.6042448166878, 47.600311540788226, 49.47691463655042, 47.50620603561402, 46.47845875832343, 45.17422360758628, 45.61837711641866, 48.999291543037664, 52.326214544234745, 50.424418064855764, 50.73330079355548, 55.05839247857371, 64.34748288123839, 63.96143928650887, 63.064318703066924, 66.1494158160302, 68.35729445180586, 65.6510865303778, 70.92894154210245, 64.0735641602547, 67.63190700161842, 64.04440133802353, 71.13170454579016, 67.44120920858076, 68.40863827736148, 65.77560217149797, 66.31621852997812, 60.04144999288744, 71.093641865638, 71.56853891188099, 73.4020116252284, 70.51204850596767, 75.49381163812454, 71.57471272253221, 79.90769401673349, 73.65062713623047, 80.38590154340191, 78.5842235626713, 89.1799025381765, 77.27000205747544, 99.3119259803526, 7.177475556250542, 0.2383292790862822, 0.24831292159374685, 40.130020264656316, 94.06099411749071, 74.5942944865073, 74.90315760335615, 45.82960067256805, 43.59327308593258, 53.824242238075506, 82.1247745329334, 22.378631945579283, 0.22764314927401083, 0.23976224654864883, 0.1567606955406166, 0.14096452944701718, 0.14651621541669294, 0.13828046379550812], [0.1169797950874894, 0.030797627048506856, 0.06909783659202438, 0.0732210673572075, 0.027812864225838455, 0.07725615970670216, 0.10622080265273971, 0.1874496568475039, 5.189828199724998, 52.225593982204316, 46.86622035118842, 44.35758613771008, 53.1228949946742, 57.82145907801967, 75.72634543142011, 28.602482234278035, 0.27335062082256045, 0.36032393935226625, 0.5291893910015784, 27.862511411789928, 91.23827611246418, 74.95013975328015, 75.41000627702283, 71.9715153786444, 72.62046367891374, 76.32413033516177, 72.48270219372165, 72.87588057979461, 71.89791602473106, 72.08709193814185, 71.16225196469215, 67.46625746450117, 66.60708581247638, 65.05031278056484, 59.816941368964414, 61.8057164069145, 56.5894857529671, 56.273829090979795, 53.71838923423521, 53.03115075634372, 51.57193491535803, 50.08266587411204, 49.10692530293619, 47.369527124589496, 50.246973960630356, 49.26194129451629, 48.300352634922156, 49.16873401211154, 46.29423679844026, 50.09842595746441, 48.28629878259475, 50.19979176982757, 48.296238068611395, 46.42947619961154, 43.15406176351732, 43.24357417321975, 44.114324661993216, 43.18020828308598, 44.17800434174077, 42.83446704187701, 52.55960341422789, 53.031711655278365, 52.71102259235998, 55.490496466236735, 56.213785448381984, 60.87483598339943, 60.52855345510668, 58.19009127155427, 50.06550550460816, 47.14401829627253, 47.16657976950369, 52.6449384996968, 50.12178759421072, 44.13432090513168, 39.79606966818533, 42.972734512821326, 41.69689732213175, 39.48013059554562, 41.476154173574145, 43.95095402194608, 42.32595528325727, 41.857428166174124, 41.25002168839978, 44.25358449259112, 44.54842905844412, 42.65871740156605, 43.12458907404254, 43.67938872306578, 40.907504635472456, 42.628668123675936, 37.97584279890984, 41.91602053180818, 41.44459478316769, 43.67305017286732, 40.95831109631447, 43.37002354283487, 41.70149041760353, 40.041935597696614, 40.022053103293146, 41.29590557467553, 41.775383949279785, 42.25556835051506, 46.28981236488589, 47.39370069196148, 45.25226700690485, 48.25138968806113, 43.84278681970412, 45.29737034151631, 47.11479663848878, 52.733391869452696, 51.25074378905758, 51.77754948216101, 49.136154805460286, 48.332139522798606, 44.49601834820163, 39.844844341278076, 39.8888337227606, 45.15817719121134, 42.478394277634166, 43.45405640140657, 39.438541704608554, 40.72434956027616, 38.870962973563906, 39.46580609967632, 43.160110058323035, 45.401270005010794, 46.302065849304206, 46.368691229051166, 46.60210755563552, 54.7009547295109, 55.37273514655329, 59.57157750283519, 58.1667100229571, 58.880730444385165, 58.738940685026115, 63.535054114557084, 60.189260590461, 64.05651753948581, 62.938555748231956, 65.34684396559193, 62.34426959868401, 64.46933915538173, 60.22355387287756, 64.48394213953327, 61.56543985489876, 65.1857679120956, 64.3605600633929, 68.73535602323471, 68.1435723458567, 74.32704771718672, 67.15507230451031, 72.10096143907117, 73.80294845950219, 73.81180517135128, 65.82332564938453, 83.11520438040458, 75.97390974721601, 89.97052684906991, 13.00684719316421, 0.10252682627328943, 0.3000908585325364, 21.62377572828724, 76.51641276574905, 59.83723571223598, 59.7074366384937, 34.785061344023674, 37.58027568940194, 33.33007774045391, 52.17862359939083, 23.360356092453006, 0.07758954584959053, 0.1267311750580707, 0.05974317525303172, 0.06697449367493391, 0.009424186690950827, 0.034062299246509234, 0.06879797445670252, 0.14453800785685741, 0.17460544203077594, 0.02878793135976359, 0.039019290312764146, 0.11425623760348368, 0.22081972670651254, 0.2380669399374916, 9.70866535940478, 62.61598002526068, 56.66402255335162, 42.76354666679136, 52.032660438168435, 68.09971240258986, 81.34492889527353, 32.265454299988285, 0.3733846659381544, 0.35849694222692524, 0.771017914577838, 30.478061591425252, 91.9085777959516, 77.62069332984187, 78.65689723722397, 74.70726659221035, 74.89690534530148, 77.8860338272587, 74.62881918876403, 74.54216618691721, 73.67802881425428, 72.34668224088608, 74.13491433666599, 71.35211821525328, 69.99840628716254, 68.20842481428578, 63.0109352450217, 62.79665616250808, 59.71318291079614, 57.87182623340238, 55.21493034978067, 55.72523070919899, 56.22280689977831, 51.98790227213214, 53.74685387457571, 51.82075831197923, 51.56292915344239, 49.49929568075365, 51.83416497322821, 51.53746120391354, 48.4968476910745, 52.08587915666642, 49.94957593179519, 51.189472444595836, 51.34266453404581, 47.95011243512554, 48.284455268613755, 46.56950481476323, 45.15778103182393, 45.76994142224712, 46.81255448249079, 46.582276052044286, 52.659972944567286, 57.10227289507466, 55.46839783268591, 55.55427028286842, 59.22243164431665, 64.21714252041232, 61.70276203463155, 58.6168961371145, 50.020539452952725, 46.80669446145335, 49.67624948870752, 53.64896720455539, 53.07482242584229, 50.1461180563896, 42.37252166194301, 43.72200919735817, 42.14884065812634, 43.045827880982436, 45.03848998777328, 46.06041646772816, 43.80418677483836, 44.988315028529016, 45.02371441933417, 45.37691208624071, 46.35979529350035, 46.030653522860625, 43.817005080561486, 44.96837762094314, 44.145487893012266, 45.95367700822892, 41.239647019294004, 43.59301813187138, 43.78638313662621, 45.50396942323255, 43.62171026968187, 46.859697449591856, 43.40405794882005, 41.53002400552073, 42.33783222013905, 43.30920719331311, 45.222343244860255, 44.454931520646625, 49.243855245651744, 49.28258865110336, 47.52353506703531, 49.39383883630076, 45.03193570721535, 46.626081082128714, 47.23748837747882, 52.03619057132352, 53.86101445844097, 53.32647385135774, 51.159360408782966, 50.0490080156634, 44.22791650218349, 39.8864959901379, 41.26978258932791, 47.17866851437477, 43.99024440396217, 46.071873711001494, 42.4814772605896, 43.5145511165742, 41.37438435708323, 42.147722782627234, 46.131897741748446, 47.680116084314164, 49.19511979626071, 48.99453763038882, 48.26006989325247, 58.72209018276584, 60.627334425526286, 61.22201673446163, 60.14857384466357, 61.2462491373862, 60.4708004766895, 65.39496752523607, 62.16432694465884, 66.0050412147276, 66.15835882002308, 67.33730562271612, 64.46011766310662, 67.40185999101209, 64.435041950595, 68.60604332339379, 64.03162225600212, 66.67204026252993, 66.22295241202077, 71.0777876454015, 70.55814420023273, 75.91085372432586, 68.21815229231312, 74.34383546152424, 73.95221817877986, 76.25279811120804, 70.06155644693683, 87.67179827536307, 77.99233005892846, 94.09475787993401, 15.238021765985797, 0.13047980415003915, 0.18678358936261746, 22.211552704534224, 87.89743654189571, 65.40573050898891, 69.248182389044, 39.42120090607674, 48.90725312694427, 50.30780599963281, 63.51842326502647, 28.128126475118822, 0.023183467677764358, 0.17818693372030414, 0.0374993910231898, 0.08819204950404745, 0.028054149363250024, 0.06959968546946203, 0.24670885605437143, 0.18542834918104834, 0.25564881101731335, 0.18339271567040877, 0.13266926811587426, 0.3152708601086371, 0.40750180941916286, 0.38352632174088114, 12.89896926572246, 77.14672196295955, 64.08280918675085, 52.87970019925026, 64.40012893369122, 76.15974380124, 87.62136443968743, 36.81836312816989, 0.48844855939668996, 0.44294419307862565, 0.7394842034386051, 33.99125599092053, 95.59221683009979, 81.01530075073242, 82.1063550826042, 78.3866459323514, 79.61592458909558, 82.48029032061177, 79.70543307642784, 76.34269099081718, 75.38913142296576, 74.00233822484171, 76.47285092261531, 73.54516244703724, 73.29041234908566, 71.97077012831166, 65.26889078078732, 67.4052018503989, 63.00986443796466, 60.14880134213356, 58.072027929367565, 58.59329915815785, 59.34033809169647, 54.15647875878119, 57.152596904385476, 55.242649739788426, 55.77235406444919, 53.05143725487494, 55.96568376787248, 53.18834366336946, 50.459982195208156, 57.879804334332874, 52.48176397815828, 54.33078104449857, 54.95683839244228, 50.36964216539937, 49.25052719731485, 49.438859801138605, 48.922593516688195, 48.46637479720577, 48.83513250658589, 50.211068584072976, 54.53988652075491, 61.513323322419204, 60.073201579432336, 56.6456776280557, 60.206005188726614, 64.94003926554035, 62.23667898485738, 58.382326633699485, 50.408618757801676, 46.980522140379875, 49.25891322474326, 57.202834621552505, 55.54599015943466, 52.59217085376863, 46.40697748430314, 48.34380465169107, 46.399466145423155, 45.12572742277577, 47.35916030022406, 50.63746160076511, 46.61786371661771, 45.25310639412173, 49.42002457957114, 47.825596794005364, 49.577688171017556, 48.88232254212903, 48.18534874146985, 47.56103292588265, 46.773703405934, 46.62493182766823, 42.041555989173155, 46.721014207409276, 48.17868855691726, 49.9123683283406, 47.85676002502442, 50.71421846266716, 46.278967011359434, 43.009840134651434, 43.514445212579545, 46.62712443259455, 46.48424033195742, 48.909790900445756, 53.739024823711766, 51.38487708184027, 48.06098999515657, 50.76442872324298, 45.54662912122665, 47.659896266075876, 49.71852479442474, 54.492029682282485, 53.81464419826385, 55.02509940055109, 52.404712938493304, 51.63724630109726, 45.444969131100564, 41.439605528308505, 41.266193620620236, 48.475317801198656, 48.403848294288885, 48.112894719646825, 45.33810807812599, 48.401883186832556, 43.09964672211678, 44.52282774832941, 48.56366134458973, 48.90139310590683, 51.88585004498882, 51.1914610862732, 51.7916190239691, 62.557536709693174, 60.95078091467581, 65.39047641138878, 62.9660790197311, 65.30631803697156, 65.30667105028706, 69.65873687498032, 64.9227455354506, 68.94672470708048, 69.14930728174025, 68.79066144266437, 66.73997571391445, 69.10865583727437, 65.6864506198514, 70.64485211526194, 66.61242808065107, 70.54119956108832, 70.65762335254301, 74.00905332257672, 73.30961627344932, 78.98621943689163, 72.43114656017673, 77.56944364117038, 78.88714036633893, 80.64760208129883, 74.64948223483178, 89.0712764186244, 78.89558915169009, 99.30871748155164, 15.889350944949737, 0.1385338703591016, 0.3339328845181773, 26.95244308440916, 97.81667140222366, 73.43018993254631, 80.49563377134263, 51.568608745451904, 60.505085914365715, 53.910832481999556, 80.35421663714995, 33.49298946319088, 0.09835876404277741, 0.2788104988153904, 0.13432409464111253, 0.17737549339090625, 0.2392647490506211, 0.17704711746304266], [0.034437061798188, 0.051739260989932284, 0.06791095955357437, 0.033378389573866324, 0.009422007170806249, 0.014757597931630671, 0.0709171345337264, 0.22371101914153946, 7.361470999256258, 54.09595658702236, 41.91780128786641, 57.27848929743613, 58.04069211406093, 55.85603390970538, 81.31519732936736, 30.80246121652665, 0.29914752850609444, 0.5711662288635009, 1.0094895634439685, 22.405568822737663, 89.24517862258419, 72.57864336813651, 75.62586215234573, 68.35862805766445, 75.62140633982997, 75.46778278966104, 76.64925559874504, 74.95585856899139, 69.88834458012735, 72.71628718222343, 68.14806738207417, 65.25233837866014, 63.661829040896514, 60.49793543354158, 56.29934018658054, 54.24936440683181, 55.57223081588746, 52.74677891885081, 51.042999375251036, 51.48468571324503, 50.17508083774198, 51.96359926654447, 50.699858665466316, 50.08991441419048, 46.03085356373941, 47.071156347951586, 47.786655502934615, 48.27684587047946, 47.455548624838556, 47.05899307804723, 46.2838032937819, 48.12760360779301, 47.60530079564741, 43.40867457851287, 46.03668612818564, 43.548836554250414, 42.83217637769638, 42.87618537102976, 43.556328281279534, 45.337998251761164, 45.600926491522024, 60.2314535264046, 63.53339887434437, 58.523065197852354, 54.64386855402301, 58.371234170852176, 64.82796146023658, 61.06555731065812, 58.27635988112419, 52.282950801234094, 48.38044351147067, 50.09035764201995, 46.56275833806684, 48.76094087477654, 49.41532558010471, 44.33368713625016, 41.20554593301589, 42.39823279842254, 42.39978605701078, 41.926881574815326, 39.94625722208331, 42.32956386381581, 41.16415316058744, 44.08643268769787, 43.00514505755517, 42.3372438646132, 41.93751904272264, 40.808005871311316, 43.17820395192793, 40.27106477368263, 40.26733852201893, 39.94163274765015, 39.46896360766503, 42.49804927456764, 44.30460668379261, 42.164855695539906, 43.46795728129726, 42.45674671665315, 42.76927332724295, 42.0044425226027, 45.029621508813676, 41.595990427078746, 44.99695208764846, 46.631027190916, 47.68785884303432, 47.483169955592004, 47.93451316895024, 46.36308223970475, 47.595298751708, 49.93662818785637, 50.61497465256722, 50.43472605366861, 56.3881387249116, 57.312390342835464, 44.446929885495095, 38.096169348685976, 49.566795749049035, 46.729392390097345, 41.74913152571648, 41.82006759028281, 41.211633451523326, 41.55423287422427, 40.01447508412023, 40.21887371616979, 43.81994293582055, 45.78183012623941, 44.89199338420745, 46.039110152952134, 47.63059616088868, 50.01764474376556, 50.63145252966112, 52.29249392786334, 56.18339884665705, 55.56748867034913, 56.08891287157613, 59.11608834420482, 57.55267081722137, 62.03113109834733, 61.91766869637274, 63.95176279929377, 64.06455839833906, 67.95982499276438, 64.55956543645551, 66.7060785908853, 65.49369358247327, 66.34141583596507, 64.59363122140208, 70.14604430044852, 64.77630384506719, 70.77553764466317, 70.05708494494039, 75.06393555671939, 67.81483065697455, 77.75068852209276, 71.02004251172467, 76.61684113164102, 77.34325624281361, 94.31833297975602, 17.83226170847493, 0.2319920925243247, 0.5042759971993586, 16.62966105245775, 75.96480984841624, 61.323864998355994, 62.34981190773749, 32.259953175821614, 26.413507461547855, 38.03135610395862, 41.90091940664476, 23.9998887431237, 0.059531428550760594, 0.038197588235620535, 0.07161573777275701, 0.07743077412728341, 0.053121459805556846, 0.05342733573108431, 0.07282843963513452, 0.02646693201254933, 0.08133727095780835, 0.02078410711199526, 0.05312234846754901, 0.06751909025854642, 0.10051273515508061, 0.27558266395522707, 10.990061529221075, 68.23253170136483, 46.585284509966456, 51.458445056792236, 56.654761837374785, 65.42608761018323, 84.09428288859706, 37.1750517045298, 0.5754026337977379, 0.4299365104206147, 0.9827430438130134, 24.9000628917448, 92.80075227060627, 73.25952760634884, 78.86626551228186, 71.97037789129442, 76.56771736760294, 75.451552021888, 79.11312380144673, 76.85292859231272, 71.12713890690958, 75.38935892043575, 70.6312728697254, 69.37365116611605, 66.95280351946431, 64.4315706529925, 57.833132051652484, 57.33566568743799, 57.93585500409527, 55.958325401429214, 53.0132451365071, 53.688139915466316, 53.02813837605139, 53.18725324446156, 52.00158742166335, 52.8239554743613, 50.10299944108533, 50.99357358870968, 50.57698257507817, 51.32566105934882, 49.78631904048305, 49.55426769871866, 49.1227206876201, 50.15100140725413, 49.803675528495546, 47.595789047979544, 47.945487960692375, 45.78889431491975, 44.58409124805082, 45.66720278032365, 46.27213032014909, 48.309554515346406, 48.709581359740234, 61.230516510625044, 64.78180300804877, 61.148739014902425, 55.491155424425685, 60.92962757233651, 66.93893401853501, 63.00512229242633, 57.608870537050315, 53.64550375169324, 48.05685973936512, 52.80706574839931, 46.4691823528659, 51.09758700093916, 52.33763256380635, 48.25202511202905, 43.13867430533133, 43.99675161607804, 45.139173307726466, 43.472640591283, 42.23182232149186, 44.84599182682653, 43.369839191436775, 45.487181678895034, 46.01687815881545, 43.860170764307824, 43.09842686499319, 44.59860401768839, 45.48387512083977, 42.36491226380871, 42.119305210728804, 42.87114904772851, 43.52369416144587, 43.722197471126435, 47.698794411074736, 46.194208514305856, 45.89153881995909, 45.24843877361667, 44.77663647743964, 45.69587530628328, 47.470292814316295, 43.88403054206602, 48.291582215216856, 49.54283791203653, 49.717642261135964, 47.705164340234575, 49.07615430893437, 48.15869623614896, 46.94067478179932, 50.52271658374418, 53.196211937935125, 52.097677646144746, 57.7895898203696, 58.62839652645973, 44.4852553644488, 39.48050322071199, 51.677164262340916, 48.72152105454476, 45.68092715355658, 42.97758256235431, 42.12152134987616, 44.96914248312674, 42.53884192435972, 43.887392013303696, 46.533850469896876, 47.954434887055434, 47.30929520822341, 49.53760154785649, 49.1318323535304, 52.38971771732454, 52.09258248729091, 56.77386068528699, 57.27840300529235, 58.14361902975268, 60.009772931375814, 64.33155413596862, 62.185409684335035, 65.81098587282243, 63.06422456618279, 64.94612286167761, 65.16175516190069, 70.60358878104918, 66.96378615594679, 69.57413135036346, 68.90896012706142, 70.39871554220878, 67.33607399848201, 71.8074583238171, 67.47778923280778, 74.07114444240447, 72.57723131487447, 78.26637821812784, 69.14268632088938, 81.15896932540402, 73.04712341677758, 82.35437439334008, 78.86024859643753, 96.05456229179137, 19.306396284411033, 0.22465718369330132, 0.4955921147859866, 17.84145378297375, 86.45656170383577, 66.3047024511522, 72.70742262563398, 35.257699105047415, 32.58430377129586, 48.71966185108308, 54.68841098969983, 28.887195317975937, 0.09773411127107759, 0.02833896936217864, 0.03908607019712368, 0.06144795071093306, 0.02811280871561218, 0.07125774488574074, 0.12959993684724455, 0.18823174068764334, 0.2688561668319087, 0.16452381687779583, 0.19920005132594418, 0.2583324783031018, 0.2561641736857353, 0.4125402164795707, 15.398884050307737, 86.2716454844321, 52.937029561688824, 73.96742913030809, 75.08888183101531, 72.11138709898918, 90.41809281995221, 42.14167056545135, 0.6419859706394134, 0.7247012192683836, 1.4322643775132395, 28.063668204892068, 95.8923722851661, 75.16814508745748, 83.15429472154187, 73.2243674801242, 79.28057762884325, 79.0588068193005, 81.62055384728217, 77.83125400543213, 72.75569915771484, 79.30457468955748, 75.17682921501898, 71.38141832044049, 71.67068527590844, 65.77062860611947, 60.94945907592774, 59.17494743101059, 61.642667401221495, 59.117614146201845, 57.119578392274924, 57.21080095537248, 56.569418907165534, 56.71074190447408, 57.2472672308645, 57.28571038092337, 51.785060821040986, 52.61596787360407, 52.783025541613185, 56.28170521028581, 52.7042329695917, 54.70690888743247, 50.42710096605363, 52.670782996762185, 51.618120824137044, 48.42858668296568, 50.92781897514097, 49.33488953498102, 46.79426447037728, 48.428822025176025, 48.38755869096326, 50.603415427669404, 49.752119894950624, 64.4546655685671, 67.55350666661417, 62.96372167525753, 56.121307726829286, 64.44533817229733, 69.2502220215336, 64.53661172620713, 58.97121167952015, 55.40479267797163, 51.49235394693191, 55.56813193905739, 49.9490071881202, 51.88835251715876, 56.362094186967425, 53.148111912512014, 48.608407743515514, 48.88198521829421, 49.03407904409593, 46.8300796324207, 45.585719462363954, 48.24811058659708, 45.77977480426912, 49.881122727547925, 49.62401920749296, 45.9421334728118, 45.53763120405136, 47.80771863075995, 50.43496139587895, 45.04980994809059, 44.346964359283454, 45.513371344535585, 44.077674035103094, 47.730212596154985, 51.45722519966864, 49.58678414744716, 49.348523693699995, 46.495936839811264, 47.705148650753884, 47.155040156456735, 50.83096388847598, 49.18977360571585, 49.25663432767315, 49.74525574714907, 50.71071186373311, 51.09724575473417, 51.04858875274659, 50.122944693411554, 47.97345053765082, 52.76893638795423, 56.13755810645319, 54.23251390457154, 61.09649304420718, 61.69694515966601, 45.158306629427024, 39.47017954241845, 50.29912971681165, 52.873428329344726, 46.414053440094, 47.459172894877774, 45.79157329374745, 47.829687826095096, 44.47892073662051, 45.91541036482781, 49.14748261051793, 52.11022530832599, 50.74040028356737, 50.80386815532562, 52.18247536690005, 56.17342425930885, 54.58171859864266, 57.51125843294206, 60.81374114559543, 60.23161434358167, 61.418688297271736, 66.09515374706638, 63.79983763540945, 69.04226579973775, 65.52341730363908, 69.34969332910353, 69.31334080234652, 75.92491934376379, 69.23398340902021, 71.7790525190292, 70.73011659806775, 73.5839468433011, 70.27756137232628, 74.34826773981895, 69.58075231121433, 78.78933214372205, 74.59332173870456, 82.51930221434563, 71.3621202591927, 86.46545763938659, 75.76176443407613, 87.80173070969121, 79.66999838429113, 99.94509850778888, 20.47126570055562, 0.2123626216404861, 0.6939433406918281, 21.253025454859582, 94.94435894873835, 73.84633771834835, 82.75193014452535, 49.38959875414449, 40.565403353783395, 54.80274808022284, 71.23900490422403, 38.416152384973344, 0.22826481430280596, 0.1045156901161517, 0.1549845666534478, 0.1328099678240476, 0.09286067358428433, 0.18899522391298126], [0.09382727736186597, 0.08737201366813914, 0.05691283660370016, 0.04852048511947355, 0.08385958480498484, 0.11828781360940588, 0.03965538843805271, 0.21859391952954957, 4.7500471530422095, 46.89907804612191, 49.6647334098816, 40.627161072146514, 29.547912689947314, 60.989569233309844, 78.59585731260239, 41.039382565406065, 0.061197528059804635, 0.27796810853385157, 0.6625243588801354, 19.322450545526323, 87.62334131425428, 73.60285266753166, 73.12051096270162, 71.5938852679345, 74.57658890754946, 74.65642483003678, 71.97952485853627, 70.371337398406, 70.61602269449543, 68.54695673911803, 66.70898114481281, 63.729933154198434, 62.096285589279674, 58.112487177695, 54.39020495260916, 53.03255496486541, 51.194555836339156, 52.41097696365849, 49.35589774962395, 51.02177543024863, 49.96851313498713, 49.29055890729351, 47.43065334135487, 47.300250222606046, 47.453375631763095, 47.30176033512239, 46.37293523357761, 48.65746874963084, 48.63123986028856, 49.30402440409507, 45.27357332168087, 46.938376272878344, 47.3771914359062, 46.05077135947443, 44.459155913322206, 43.8626967706988, 42.79490209394886, 42.64321227227488, 43.71319563158097, 45.221735277483546, 43.93271500064481, 50.99799017752371, 58.46135062556113, 61.06056805579894, 56.54164068160519, 50.34127558431318, 50.785487928698146, 51.83666744539815, 52.581815796513716, 52.69856122232253, 50.30458181135116, 49.345405409413004, 47.81016618974748, 44.91058541882423, 44.846066351859804, 45.556387978215376, 45.07241848976382, 43.73454901479906, 41.28186741182881, 43.01550795955043, 40.41508636166973, 40.90954426796206, 39.69875174184, 42.844123917241255, 43.07388459482501, 40.80748811844857, 41.524885700595, 43.56946037661645, 39.982260657895, 40.6682792786629, 40.56042586603473, 38.93195582974342, 41.23687390358218, 41.46213954494846, 42.02149306574176, 46.59667115057669, 42.637693497442434, 44.41021257831205, 43.17820395192793, 44.470193462987105, 39.58854098473826, 41.53662927689091, 49.40135801992109, 52.24175806968443, 49.145584183354536, 45.14371933475618, 49.33997684909452, 47.728145507074174, 47.63918615156605, 48.74987194615026, 46.64136655869023, 51.70289108830114, 54.839080995129, 55.041906756739465, 49.58554075610254, 53.90267395204114, 53.835315089071955, 49.010289869000836, 43.84248871957102, 41.055962424124445, 39.31837597200948, 39.8458327785615, 40.8802520075152, 39.45638848889259, 42.45145151692052, 45.46748745825983, 46.60440606455649, 46.986225266610425, 46.743583525380785, 49.911878032069055, 48.01394116493964, 50.24270249951271, 49.566387822551114, 51.741577425310695, 49.70524364902128, 50.84824192908503, 54.419167733961544, 57.075898878036014, 60.0259134846349, 62.28173917339694, 57.58931752174132, 62.905141076734, 59.747911576301824, 66.33627753103933, 63.99581493869905, 67.14714911676222, 62.14358545118763, 67.4895877222861, 67.39677659926876, 74.44257720824211, 67.82163989159369, 72.91519841840191, 71.23317626214796, 71.13975324938374, 72.56822555295884, 78.52210106388216, 70.03831248129569, 103.4628055941674, 19.741624439916304, 0.2511261496692896, 0.2669944199583223, 9.515915186174455, 77.16083465083953, 57.994314009143466, 62.0895508796938, 36.89721061337379, 41.198144420500725, 38.901129922559186, 44.86558406583725, 25.593114322231663, 0.21631551275570549, 0.06426043185074964, 0.057483028184862874, 0.056773738019288554, 0.04059292300934753, 0.008714548912980865, 0.05968001513411442, 0.014010239899488948, 0.03141590022301722, 0.021142463890775558, 0.08992061965287694, 0.06819832679485122, 0.10130891501302682, 0.18385895678112585, 7.993506039342574, 60.0365391854317, 53.12246353395524, 44.77340444441765, 36.84066180259951, 70.40944714700022, 83.06688862462198, 45.552916680612874, 0.08950854861928571, 0.30935675326374273, 0.565167392694181, 20.514421578376524, 90.48128220342821, 74.83831297966742, 76.34328719108336, 74.20417554916875, 76.47431004431941, 75.96499812218451, 74.70328930885562, 70.26460970601728, 73.42377293494441, 72.24187650988179, 70.90654480841853, 66.67680201991912, 63.49762293600268, 60.258702231991684, 57.63261264370334, 55.29699417852587, 53.83783325072258, 55.896905006900916, 52.34107640481765, 53.76066061758227, 49.94903856708158, 51.46331271817608, 51.309214561216294, 50.316180259950706, 48.34827223131734, 49.339753273994695, 49.72758939189296, 51.83004648454728, 50.705706919393236, 50.59008721382388, 48.31289245236305, 48.10282207304432, 48.47749079427412, 48.76033290739983, 46.75254614122453, 44.877515915901434, 44.15416417583343, 45.24219043793217, 44.39509576366794, 48.36971582904939, 46.189768391270796, 52.507259384278335, 62.37576230879753, 61.680937966992786, 58.23648506595243, 50.58306224884526, 51.486619441739975, 52.86875286409932, 53.644962464609456, 54.25353388632498, 49.41760447717483, 50.466528631025746, 48.701289469195956, 46.383274601351836, 45.71814260175152, 49.71445729655605, 50.56752966296289, 46.57738093406924, 44.159431918974846, 45.366490348692864, 42.67562281700873, 44.0844597355012, 43.08709905993554, 45.70361806500343, 45.19727145471881, 44.355181724794456, 43.796698970179406, 44.09515603896111, 43.454205451473115, 44.89899089259487, 43.61811737860403, 41.35560797106835, 43.64550336714714, 42.82104861351752, 45.45296684388192, 47.034486109210604, 44.65427813991424, 47.732832739430094, 44.22790473507297, 45.0897632106658, 43.66526426807527, 45.0515083343752, 49.71999960560953, 52.89601333679692, 49.98421438278691, 47.54063267861643, 49.30257704950149, 49.099268836359826, 47.73231106419718, 50.299635702563876, 47.943150228069676, 52.05887363803003, 55.12489626484533, 58.837768723887784, 48.668788709948146, 55.586943626403816, 58.847319695257376, 51.236223174679665, 45.56470732535086, 43.02016381294497, 42.86595582962037, 42.95934354105304, 43.628813682063935, 41.834537213848485, 45.57214806156774, 48.8263189408087, 47.8836400278153, 50.38863035940355, 49.986077508618756, 51.11952089494275, 52.711073583172215, 53.100721836090095, 51.582231137060354, 53.79055692303566, 52.37102762345345, 51.91007852554322, 55.75541334767496, 58.7478679995383, 60.813372442799235, 63.732929845010084, 62.54888396109305, 64.61904425774851, 62.53204522594329, 67.54785060882568, 66.1003783441359, 68.86498251268941, 67.01377284142279, 71.04940537483462, 69.47811172854516, 75.87117502766272, 70.9737350094703, 73.86779308319092, 74.14696385783535, 73.71609933914678, 75.45473698646792, 78.68204747476886, 72.08933553388043, 107.40309315343058, 20.447270601026474, 0.23027371134488817, 0.4012851284876947, 10.434913769845041, 87.09584528400053, 62.34454808696624, 74.81726554132278, 41.830485405460486, 49.98098234976492, 53.22390387135168, 57.69804562291792, 33.7437387435667, 0.25968949580865525, 0.038721864337041494, 0.037051355991993225, 0.052636468692892985, 0.03594292252654991, 0.016219969763750994, 0.2094287040733522, 0.15127066432708694, 0.18437631127815093, 0.16676169760044546, 0.28203992713843623, 0.20610792742621517, 0.21290161046049288, 0.48387314523420033, 14.184842821090454, 74.06800654626663, 62.80816047422348, 58.71914840513661, 42.84059770645634, 80.02542003508538, 89.03393545458394, 51.86495165671072, 0.27845013105580885, 0.502163096060676, 0.8243267250157172, 24.61301011423911, 92.71425616356635, 78.37698905698716, 81.44707525930097, 76.9132624903033, 79.51203669271162, 79.51719853185838, 78.45172589825046, 74.02495461125528, 79.08036416576755, 75.21460948451873, 74.4574979043776, 69.92291635082614, 67.41815351670789, 64.32030477831441, 61.57845427913051, 58.071729829234464, 55.80916550851638, 58.59551137493503, 55.40591055347074, 56.59155676441809, 54.42067392410771, 55.88094096029959, 53.6006945948447, 52.68784530701176, 52.258843914155044, 51.87525964552357, 50.93664430802869, 54.65140342712403, 53.68994028337541, 55.426259809924716, 51.181757142466886, 52.06462775507281, 49.867516025420166, 50.1058510042006, 49.801824169774214, 48.771072356931626, 47.84686780744984, 47.67799800442111, 47.694091489238126, 51.60691069018457, 47.82483585419194, 56.507221883343114, 63.5524223696801, 65.33148004162696, 61.43926112882553, 51.24875906975039, 52.02402730141917, 55.472904636013894, 58.56318712234498, 56.05605909901281, 52.923975913755356, 54.06987282537646, 51.243283440989835, 48.52348842928487, 48.068536635368105, 50.515142486941436, 50.637979353627856, 50.956389519476126, 46.732385158538825, 48.19009873174852, 45.06470318763487, 44.91728482707855, 45.383478133909165, 48.56204925044891, 47.79168790386569, 47.5964754627597, 45.5592748426622, 45.464486845078014, 46.56302898160873, 46.5988519883925, 44.9188067067054, 43.493837079694195, 46.71107492139263, 45.01310440801805, 47.93212836788547, 51.88618736882364, 46.855951586077296, 50.31623125076295, 46.80731419594058, 49.952474563352524, 47.24316012474799, 47.97017143618676, 52.69148918890184, 57.24925195017169, 50.98834506926998, 50.707240566130615, 51.52197568647323, 50.86267625131915, 50.97369501667639, 52.775678942280436, 49.52355161789925, 54.004965443764966, 58.28264351814025, 60.92913727606497, 50.34830447166197, 57.68727087205457, 61.11898783714541, 52.8716750298777, 48.44732776764901, 48.683874145630874, 45.59536064824751, 44.43358598216888, 46.60133484871157, 45.00914281414401, 46.92951956102925, 50.57386821316135, 51.453440112452355, 53.08281621625347, 53.037810940896314, 53.58517377607284, 55.566963072746034, 56.0525760342998, 55.92685622553672, 58.25206864264704, 55.79659823448428, 55.638915031187004, 60.00710571965864, 62.19958905250796, 66.34402028975948, 66.93028911467522, 64.66128033976402, 70.48150108706567, 66.02666916385775, 69.42225717729139, 69.07326821357974, 74.28780832598287, 70.05708494494039, 72.3391983585973, 71.21387820090018, 79.77102295044931, 74.19990016568092, 77.66645954501244, 77.59155011946156, 77.14572568093577, 78.43083535471271, 83.51610199097665, 77.20286676960608, 104.21134287311186, 23.043983597909254, 0.297411481339124, 0.5419756436059552, 13.386997426709822, 100.05861190057571, 71.18177752340995, 85.23545726653069, 56.77879894933393, 65.59886409390357, 62.70180148463096, 73.7114630976031, 40.60236384791713, 0.3403775838594283, 0.14281594945538428, 0.20043961223094695, 0.179672883823514, 0.14337191478379313, 0.11663579862684974], [0.08236192121741273, 0.010950255861145355, 0.09043332399620164, 0.10605544257428377, 0.15426185462744008, 0.03585731220101157, 0.10452492147563927, 0.18760558638361194, 4.81994035743898, 48.10485778316375, 46.33541776287941, 40.95945250603461, 38.81085657304333, 63.199083497447354, 75.04011892503308, 47.41159062231741, 0.06736130678966161, 0.27763115242123604, 0.8241016177400466, 11.796639100197824, 85.11381672274682, 75.68030465033748, 73.79138531223421, 72.8507617212111, 75.26906767199117, 77.28316553177373, 66.66397586945565, 69.82129558440178, 70.05062872363676, 68.3774083660495, 64.4212273628481, 61.964446883047785, 60.426320798935436, 60.14629494759345, 56.183065445192405, 55.71933146445982, 50.834211610978656, 51.40288468330137, 49.57395799698369, 50.9086738863299, 47.63164343372468, 48.13162011484946, 47.26549017813898, 47.80978571984076, 46.361438766602554, 47.25356617281514, 46.97200275236561, 50.33697666660432, 49.10833735619822, 48.502774392404866, 47.997902593305035, 48.40311088869649, 45.45012704787716, 44.98999772533294, 45.02109035368889, 43.04896185475011, 41.31230500436599, 41.266193620620236, 43.844889210116484, 43.36668168344806, 45.06198890747563, 44.3364014164094, 50.2056674803457, 58.857443332672126, 54.66888543098204, 53.37510731912429, 49.68664769203433, 50.638018577329575, 52.20803745331303, 53.24154277001658, 46.16259028834682, 46.201500200456195, 47.0620015359694, 47.75105999362084, 49.16823587109966, 47.99301139770016, 51.18141197389173, 51.16271011291012, 48.118080093014626, 42.89011762988183, 42.485066229297274, 42.61053108399914, 42.81436489474389, 41.580163663433446, 40.86949294613254, 38.977541615886075, 46.290840025871034, 46.24394024572065, 41.4855404053965, 40.901032724688136, 49.210746519027225, 42.303060408561464, 40.927261614030414, 41.82060103262625, 41.85307041291268, 42.59704989771689, 41.00838799630442, 46.102683928705034, 43.20635872502481, 42.76692382750973, 40.752296447753906, 44.1499319384175, 46.07085389475669, 44.556889610905806, 45.76195547657628, 45.31116923978252, 42.75396039409023, 46.52273447282853, 48.39006900787354, 48.93091286382368, 48.709655884773504, 51.898676195452296, 46.398787575383345, 51.126185001865515, 53.72371973529939, 54.57558793406333, 52.79528294840167, 44.61036720583516, 41.51982584307271, 41.655892864350356, 37.4013763858426, 40.0171148392462, 39.97287834844282, 41.141983924373505, 42.59261761942218, 45.73520491200109, 44.359229610812285, 44.478732462852236, 45.13958123422439, 48.90058509765133, 46.52683727202877, 49.546752437468506, 48.67673543191726, 51.49989666477327, 47.745490227976155, 49.84540954712899, 48.75897184495003, 48.258124397647, 49.55428338819935, 54.034775457074566, 51.49133020831693, 55.68757595554475, 59.88164478732694, 61.089852471505445, 63.75984907150269, 68.20151359804215, 64.84724775437387, 67.79572871423537, 64.09744354986375, 70.41318124340427, 67.62194418138074, 73.7207277359501, 68.28656627285865, 78.74246766490322, 70.65346564016035, 82.86181142253261, 68.04432069101642, 113.02250815976052, 22.004979118224114, 0.5176560905191206, 0.13107059583548578, 3.115950231590579, 68.59615110581922, 63.51475192654518, 60.006505597022276, 37.83875596138739, 30.80285933709914, 38.1892668047259, 55.314872341771284, 37.11372936925581, 0.2702788533943315, 0.09531602368599947, 0.06831148564214669, 0.010145560935920766, 0.061661470906748894, 0.058368143189938805, 0.047946505233525276, 0.060099532542329644, 0.04563335637231508, 0.07802549584378159, 0.10875162007587572, 0.024186684712467175, 0.06804178438840375, 0.29180004051135433, 9.873727521588727, 63.70513985233923, 48.67141669796359, 43.07760692411854, 49.28529508652226, 68.40562589706914, 79.91884139276321, 52.65071615096062, 0.041863100618244185, 0.2090847305953503, 0.7826461486758725, 12.064510506968345, 89.25969139222177, 77.06503468175089, 75.81678744285338, 73.29682150194722, 76.98983500080725, 77.93568318889987, 69.7310104677754, 70.49339371342813, 71.71373721091979, 71.65361512091853, 67.38983400406377, 66.9042367319907, 63.68106042185138, 62.006071075316406, 58.39204234461631, 56.23108310084189, 54.76948245879143, 55.03115161772698, 51.1667226975964, 51.67137876633675, 50.41677336538992, 49.85191675924486, 49.95296878199424, 51.850258458045225, 50.05522889475669, 49.14904763621669, 49.257387422746234, 52.312843184317316, 51.49558205758372, 51.9231870866591, 51.71071621679491, 52.28894418285739, 49.44738703389322, 48.69908901952928, 46.31452329697148, 45.56945339325936, 44.64003209144839, 43.53562208913988, 44.698930401955884, 48.170027963576786, 45.3900481039478, 46.81574336944088, 54.27309474637432, 59.604713686050914, 57.28869922699467, 56.296398408951305, 50.18746768274615, 53.64146371041575, 51.62671473718459, 52.77270186331965, 48.77936816984608, 49.316650513679754, 48.67118527812343, 52.05786558889574, 51.75900451598629, 50.97786841853973, 53.822084934480735, 53.286963816612, 49.838106093868134, 46.31933212280274, 45.35019682299706, 45.05309297192482, 44.45093462544103, 44.558764503848174, 43.17323038654943, 41.01231428884691, 47.00694714823077, 47.77698293808968, 43.25824383766421, 43.03284875808224, 50.97291054264192, 46.26932582547588, 43.862681081218106, 43.08234906965687, 43.51942662269839, 43.10968798975791, 43.950608853370916, 46.49090051651002, 45.6621507675417, 45.71137651320427, 46.94663678446124, 45.727520988833525, 47.07061113849763, 46.28661563319545, 47.229435751515055, 47.12239034714238, 46.30017134451097, 49.66330958950905, 50.38608081879155, 50.84527269486458, 50.69667762325656, 54.51991773420765, 48.324349695636386, 51.38541444655388, 55.481973155852295, 56.632404327392585, 54.78634865053239, 47.1020136340972, 44.722233203149614, 42.88215521843203, 41.264177522351666, 42.11104469914591, 42.05167178184756, 42.60680483233544, 46.43372412650816, 49.473682603528424, 45.60520579738002, 47.711918661671305, 47.92056522061748, 50.68136076773367, 49.21604171875985, 53.42941253416, 51.60893071082331, 54.478787760580744, 50.34860649416524, 51.36706952125796, 51.66873508884061, 50.24163169245566, 50.594088031399636, 56.648721387309415, 54.5718381481786, 56.93635271441553, 62.769136813379106, 63.843944687997144, 66.47445478746968, 72.78024535025321, 67.5023981832689, 71.21019901767855, 66.01185044934674, 72.50677770183933, 71.80860365590742, 75.08073114579724, 72.10712740498205, 80.88940835768177, 73.24667792166434, 84.01811830459103, 70.83926831522297, 109.87741839501166, 22.63982845890907, 0.41918875649571424, 0.13999044865129456, 3.673417582627266, 76.38022807336624, 70.28477068870299, 69.62951521719657, 46.08216601033365, 37.151564551937966, 47.442267479435095, 67.64200318244197, 43.83727981198219, 0.5086595829456083, 0.08012911965770107, 0.12445264571015874, 0.05186458148302571, 0.04707443670579984, 0.09333975432861237, 0.2506843927286325, 0.11422819112457576, 0.1796727918929631, 0.1671893278797788, 0.24900964791736296, 0.12515565395475398, 0.3176947010140265, 0.6280396157695401, 16.189868238664445, 75.47672579365393, 57.73813224607899, 56.39938023782546, 53.368647175450484, 81.22673219250095, 85.9958871718376, 59.1295499186362, 0.17938923210866992, 0.6499841124300034, 1.0171615356399168, 15.082125202302011, 92.65200030419135, 82.11375267274919, 80.54076456254529, 77.03330270705685, 81.87447240275722, 82.03783912043419, 72.79846083733344, 71.89197755629017, 75.72345072223295, 75.66115563915622, 69.60664779909196, 69.25277940688595, 66.07859350019886, 65.0864613440729, 61.82345336483371, 62.936884818538545, 57.15611919280022, 59.7497001771004, 54.338959186307854, 55.950288464946134, 54.25598929005285, 51.75166183902372, 52.5959441738744, 55.54142059818391, 51.77279949188233, 50.76644089914138, 51.23808237814134, 55.03902773703299, 55.709819716791955, 53.08933519547986, 54.19547888540453, 54.23299635610273, 51.319977544969134, 52.217768853710545, 49.701662525053955, 48.23882633639921, 48.0182675392397, 45.711921722658225, 48.15438555132959, 49.35480733071604, 50.84522954879269, 50.00579918584516, 56.72146174215502, 62.98267064555999, 59.90852086774765, 60.19626202121858, 51.642918048366425, 53.51438676157306, 55.63901701281148, 57.78063112689603, 50.8211422735645, 51.426658168915786, 52.81885247076712, 55.09254847803424, 55.478305739741174, 52.87018845158239, 54.25540877926735, 53.99896421740132, 53.602141949438284, 48.94568450989262, 48.532996254582564, 50.04194382698306, 48.65550364217451, 48.61280472047868, 46.27915920749788, 42.35414928005588, 49.58157131748815, 49.34898261101016, 46.44153356552125, 45.38185035028766, 53.293055257489605, 47.399372439230646, 46.76969082124772, 46.864655325489665, 46.90177663680046, 45.566480236668745, 45.86094041024485, 52.972272057687086, 49.94954847520398, 48.91595294398647, 47.43803916438934, 46.21181995637956, 51.54012449326054, 49.03461248643937, 49.7987372644486, 50.35427039669406, 47.24094398560063, 50.94233174477854, 52.85743290378202, 53.96816184443813, 53.253957071611964, 56.5800210737413, 50.20806012615081, 53.17990664512881, 56.73550382737191, 59.19806588080622, 58.56900399731052, 48.453913427168324, 47.86471459173387, 46.04639399436213, 43.04043854436567, 44.39664509988601, 45.044389232512444, 47.19824114153462, 49.832344132085005, 51.43143561578567, 49.94895619730796, 49.414796060131444, 51.828312796931115, 53.978826768936656, 50.96111989790394, 54.56488770823325, 53.54118831696049, 57.752797988153276, 53.43804567090927, 53.209830407173406, 53.98912691300916, 54.80338742656093, 54.85665713587115, 59.43671464920045, 57.579452760757945, 59.0969628672446, 66.6513458375008, 66.49658479998189, 70.21306191721271, 76.00874039434618, 69.35076021379041, 72.8679495473062, 67.40933602856052, 75.61586795314666, 74.43820768787016, 81.22477100741479, 76.55068643631475, 83.23786474043324, 77.1169747075727, 87.5114517827188, 74.65915479967671, 114.84963447816911, 23.62824416929676, 0.40095929597173974, 0.5047989594599893, 4.9753279935929084, 85.26805216266264, 79.02302695858863, 79.91799416080599, 56.01988307891354, 49.89758883753131, 61.73145809481221, 79.45823746342813, 52.30062500123055, 0.9124122499938935, 0.12402178253978492, 0.19315782393659317, 0.12302481869776404, 0.1549164154717038, 0.16543772912794547], [0.02367957472620953, 0.05144787944793221, 0.12462123867965515, 0.011301754237783533, 0.05478204348154607, 0.04887419557499309, 0.19257565840117394, 0.2491933864451224, 7.146208382421925, 58.106972325232725, 43.198957212509654, 53.5504254987163, 32.7015551828569, 61.70205208563036, 73.05980051717451, 51.30075008638444, 0.061760031948647195, 0.13899516254182787, 0.32381424199669595, 6.943446359326763, 78.97660962996945, 75.61785267245385, 70.78786173174458, 71.61776465754356, 74.55045023272115, 72.9573089845719, 68.06339909953456, 70.3027900572746, 68.2921987964261, 69.23395203005883, 65.86781317187895, 64.66851711273193, 64.57918120968726, 62.0102366324394, 58.82783336024131, 54.538745111034764, 50.38129552718132, 49.75968222464285, 50.52482289652671, 47.90486789518788, 47.80418849760487, 46.49471698268768, 46.43508126658779, 46.47961193515409, 44.99991347712856, 48.97465513598535, 50.37532960214923, 51.97684118824621, 52.59265330529983, 53.65817692971999, 50.98497967566214, 48.90468005211123, 46.14864626238423, 46.04473483177924, 44.74803847651328, 42.3994291213251, 42.532813241404874, 41.61836362654164, 41.4425394611974, 43.98462364750524, 44.47682619094849, 42.481069334091686, 43.44940054801203, 46.27860615330358, 49.03911144502702, 48.42261291319325, 49.44822249873992, 50.685318439237534, 48.86350693241243, 54.036983751481586, 52.29320387686453, 50.57202077681019, 51.00829816633656, 50.77565454667615, 49.46847369593959, 53.85741372262278, 52.914683818817146, 57.358262462000695, 56.032579791161325, 53.99184903790874, 49.501719705520145, 45.59612551043111, 44.523408259114916, 45.05229673077984, 45.14140121398434, 46.91458317541307, 52.86736042268815, 48.03468658078102, 37.50449549767279, 42.053483916867165, 53.77793081345097, 52.64616227919056, 41.29021813792568, 42.44846659321939, 42.025368367472005, 44.71585542924943, 44.64186383831886, 44.30163744957217, 43.268363552708784, 45.628418384059785, 48.763082488890625, 46.69360468464513, 47.30275661714616, 47.0982873824335, 45.09696468230217, 44.41463308949625, 43.44806301978327, 43.2756866178205, 44.89647665331441, 46.96846477447018, 48.43986349721109, 44.672528928326024, 45.30240666481757, 48.70105804935579, 51.065627528775124, 49.86241302182598, 43.70033810215612, 41.052910820130386, 39.35759182899229, 41.44597545746834, 39.923107393326305, 39.825161887753396, 40.33439536248484, 42.794101930433705, 43.535928034013324, 45.06958653849941, 45.54844517861643, 45.856900368967366, 44.94216442108155, 46.695965951488866, 47.93068101329189, 49.686635924923806, 48.21050290138491, 50.99785289456768, 48.576369823948035, 52.028553716598026, 48.739713007403964, 49.64853009869976, 46.30180697287283, 48.48144846577799, 44.52962521583804, 49.21091518094463, 52.846046263171786, 58.12917294040803, 62.07549310499623, 67.13275401822983, 66.40035337017429, 65.2397201138158, 61.159898158042665, 66.41379141038465, 62.78383393441478, 69.07561379094278, 66.50473548519996, 77.32926122603878, 71.17084980010986, 82.51682327639672, 68.27505019403273, 102.40593864071755, 15.844519234472706, 0.5651661669535022, 0.21386991495326643, 2.5051839986155113, 68.3593419290358, 62.73707143722042, 63.451115392869525, 36.08750789396225, 39.12280267284763, 45.96649923632222, 48.479848138747684, 36.93442213919855, 0.40367700820488317, 0.02666568011796523, 0.16610606423308774, 0.04660573262240618, 0.09440440203874342, 0.05669697983971527, 0.048552116889867096, 0.0669307500544575, 0.11737395498541095, 0.026335662846723874, 0.02720423418307497, 0.08593172240521639, 0.17413282706852884, 0.3531348783402674, 11.232584618753004, 69.54917723132719, 50.140983673834036, 59.06602321132537, 40.06937649942214, 69.13451210145028, 77.27209660314745, 56.99011664236746, 0.06783253513276577, 0.09526598282278546, 0.04853691770544937, 7.593330144882203, 82.47701121914773, 76.9978052569974, 74.15585194864582, 73.01224570120536, 77.15917156588647, 74.0089121172505, 70.07373932869204, 71.66648049508372, 71.29980164189493, 70.9782692693895, 67.9281714654738, 66.3407725672568, 66.62901186173963, 64.67412610207835, 61.726613967649406, 58.0841088294983, 53.169143661375976, 52.41353042664067, 51.78173072876469, 51.29898109743672, 50.42507310067454, 49.40909685627107, 47.96040081208753, 49.14632943368728, 47.64647783771638, 50.96452843758368, 52.29707525622461, 53.85076922755088, 56.001789185308645, 53.82657212595786, 55.051422426777506, 50.764828805000555, 48.13627204587383, 47.84546359892815, 46.19564017941875, 45.158039908255304, 44.57289288120885, 46.11271342923565, 44.35767242985387, 45.85327217655797, 46.61030530929566, 45.03403417525753, 48.02916780594857, 47.729851738099136, 50.89143899179275, 51.18263575338548, 50.95769959111368, 50.485673719836825, 51.96178320915469, 55.609858112950484, 54.73011755174207, 53.33442057332685, 52.60231410303424, 54.197047833473455, 53.694917771124075, 56.517502415564756, 55.44231014866983, 57.82433417535598, 58.12572909939674, 55.466232684350786, 52.69556845388105, 47.59503987527663, 45.7006331413023, 46.20307307089529, 45.56467594638948, 48.06339833044237, 54.99630528111612, 50.14104250938662, 41.339553709953066, 45.03435188724149, 54.86331732042375, 52.411102479504, 43.44453680899836, 44.684347029655214, 43.804363281496116, 46.84520036943498, 47.707553063669515, 46.82861658834642, 46.11903628995342, 48.53475347641976, 51.25983192074684, 48.708726283042665, 47.06951287484939, 48.760517258797925, 48.07553022138534, 46.44024702810472, 46.09278386639011, 44.84360310339159, 47.498514267706106, 50.3884538527458, 51.30913611381285, 46.318669242243615, 47.60823865090647, 49.10439929654522, 53.37811969941663, 53.55666206729028, 47.941024303436286, 41.067906041299146, 41.987070345109515, 43.256365022351666, 42.46577993515999, 43.44614890313918, 43.207390308380134, 44.583098888397224, 47.41053942711123, 49.606105742915986, 47.58902688180247, 47.6478781238679, 47.39306919036373, 50.45822889574113, 51.56189757008707, 51.7503046989441, 51.60918958725468, 53.43352317810059, 52.126718874900575, 56.39938023782546, 51.65806624197191, 52.1403451888792, 48.79222177690076, 50.880299460503366, 47.106618496679495, 52.72933613869452, 54.68078982445502, 59.62659658924226, 65.6213471197313, 69.33081888383435, 69.12662813740393, 66.72348606971003, 64.34097959149268, 70.54497288119408, 66.84364395756876, 72.82494468073692, 68.41946401903706, 78.28615480853666, 73.64797561399399, 83.18978432686099, 69.64981740520847, 100.73874304371496, 16.187916859503716, 0.6998164158674979, 0.32312779657302365, 3.6204658304491355, 76.79040601176601, 68.73832917982533, 72.4952616230134, 45.646441675001576, 42.64649137373894, 48.66408971048171, 59.236332524207334, 43.68047521960351, 0.7990885405771194, 0.055595965935818614, 0.06709136804866214, 0.07238239260210146, 0.041557186388320504, 0.03906778750881072, 0.19697347806105692, 0.1216759830112419, 0.334089748681553, 0.11202024145712776, 0.1306410656581002, 0.22037482880536588, 0.3793078739075892, 0.45455128314995, 16.922040408657445, 83.46759796142578, 56.836681365966804, 70.83017626116353, 43.17525040718817, 80.60578961526194, 82.2991160423525, 63.98106290448097, 0.27051551327590023, 0.36371056891737447, 0.5644938481911537, 10.206172908506087, 87.73904338959726, 79.3432806384179, 79.03313882889287, 77.21081349157518, 80.88601158511254, 76.13222445211103, 72.85805732973161, 76.46447273992723, 73.71441271997267, 73.19432212460426, 71.15279905257687, 68.46932518866755, 71.06429469200873, 67.64488220214844, 64.60050321394398, 60.201690581537065, 57.681324558873335, 55.94462456241731, 54.728630973446755, 53.70968549482284, 52.73719656851984, 51.78178956431728, 52.05664180940198, 51.50700792189568, 50.2348538367979, 53.073037747413885, 54.72797985999815, 58.33642705794304, 57.92235812833233, 57.83910582142492, 57.68991062718054, 53.736530196282175, 49.92683795190627, 50.063132470653905, 48.84946876956571, 46.395971313599624, 47.48554298954625, 47.24350137095298, 46.32506270562449, 48.87177528873567, 49.56195946662657, 48.49889516830445, 49.151773683486454, 51.37842478290681, 53.0287463434281, 52.11082935333253, 54.550308258302756, 55.47636416650588, 52.237733717887636, 59.21754829345211, 58.57817842114357, 53.88809057974047, 56.24880436928042, 57.066163555268325, 54.798994371967936, 61.569299467148326, 59.93602060502576, 59.9168166806621, 58.967697235845755, 58.96292763371622, 54.56261665590348, 48.56412810664023, 47.737041442624985, 47.945487960692375, 48.384326657941266, 50.49992369067285, 55.39233915267452, 53.45258589713804, 43.527173303788715, 48.45615702290689, 57.43109303136026, 53.283872988916215, 45.82045762769638, 47.47670588954803, 46.44742888789023, 49.35051233537736, 50.502504610246234, 50.07531143003895, 46.18264928940804, 47.60178635197301, 53.20928519771945, 50.48828209600141, 50.11661791032361, 53.32394784496677, 52.670441750557195, 50.22650311070104, 48.9511287596918, 47.520785485544515, 49.77719168509207, 50.50617987109769, 52.06225079874839, 48.15473071990475, 49.86991651596562, 52.24890462813839, 55.5960278357229, 55.20156291223342, 50.45261206165437, 44.78059022657333, 44.55777214419457, 45.158377232090125, 46.05426619129796, 45.74630129721857, 47.11156068309661, 49.12263047310614, 49.01952705075664, 53.87946921010172, 50.20059193334272, 50.953824289383434, 50.49655437469483, 53.887106064827215, 53.275082957360056, 55.27539368598692, 55.29806498558291, 57.23343695363691, 55.135518043271965, 59.608585065410985, 55.4680722759616, 54.017485649355, 51.37163908250871, 54.405510041021536, 50.24296922068442, 56.095478919244584, 58.79179854546824, 62.900245958758944, 69.67699158576228, 74.42853512302523, 74.74626279646351, 69.14376889505695, 64.06872003309189, 71.74317067669284, 67.13021232235816, 76.60051622698384, 72.95578710494503, 82.57030087132608, 78.00375984561059, 88.14990382040702, 71.81807225750339, 111.87639159540977, 18.97122386963137, 0.7507662270818988, 0.46562064078546345, 4.616098701953888, 87.82914023245536, 76.3077897410239, 85.67057363448605, 53.48683995585288, 59.90114681182369, 67.81802346629482, 70.5401954343242, 52.42964352330854, 1.3525198952805613, 0.1442247545046191, 0.3279936193458496, 0.09081988430191433, 0.1971217007526467, 0.12234542128299514], [0.06676463920983576, 0.05186794077857368, 0.03323374834332255, 0.048132584159893375, 0.06710059940814972, 0.041080775460408586, 0.1541749649350682, 0.25961025167376767, 5.2460744976997375, 57.30997808517949, 44.12391093469436, 37.39708139050392, 42.062485756412634, 56.00868471207158, 71.05240991038661, 57.059781858997965, 0.6160896860303418, 0.0612134856712674, 0.10392528913554647, 1.7386768710228706, 64.19197267101657, 75.9487202859694, 70.84354369871079, 70.75238781590616, 72.66591610447054, 73.06678233608123, 67.80392646789551, 68.47187472927955, 70.39123950466033, 68.4162006070537, 65.64831341466596, 64.81917142868042, 63.6096066044223, 62.56909593459099, 58.91420395143571, 55.51135170844294, 50.58455274951074, 50.24600905756797, 48.12958048235986, 46.189344775292184, 45.019423346365656, 45.70323759509672, 46.83741054227276, 49.017883577654445, 48.868076493663175, 51.950753504230136, 54.28928236807547, 56.53423524671986, 54.61030875482867, 54.69095268557149, 51.36653607891452, 48.453803600803504, 45.73615804795296, 47.82068598654963, 42.1929673225649, 41.87629476670296, 41.83601986977362, 42.14264723562425, 43.79714219800888, 42.44412060706846, 39.50281366225212, 43.53455912682318, 44.31174147513605, 43.24874385710686, 49.477098987948516, 49.95054083485758, 47.96560187493601, 48.763298219250096, 50.78163616118893, 51.86299439399473, 50.416039882167695, 54.05539535707044, 51.20899408094345, 54.33206758191509, 52.31601638178672, 54.30346958098873, 56.54598666775612, 56.48411912302817, 55.61409427273659, 54.13861628501646, 58.2774503000321, 56.093125497141195, 49.176288497063425, 43.97256235922537, 46.58141705297655, 51.76415066565237, 54.484279078821984, 49.59506427088092, 39.00583759430916, 41.11430375806747, 49.39329754921698, 62.5753285807948, 51.27195988931964, 42.146436245210715, 45.01177472452964, 42.33834997300179, 47.192902795730106, 48.95066592001146, 53.04947606978878, 50.781032116182395, 52.03608858969904, 49.2911551075597, 50.583172075210086, 48.830582557186005, 48.57003127374957, 48.648768932588645, 48.97372945662468, 47.973066145373934, 49.08952566885179, 47.78862061039094, 47.787745921842514, 45.06056900947325, 49.355619261341715, 48.5781741142273, 47.94760604058543, 43.519791403124415, 39.986841986256266, 40.062226018598004, 40.916137772221724, 40.774834386764034, 39.630890815488755, 40.073043915533255, 41.76841389748358, 43.18345992795883, 43.21254822515672, 42.953644337192664, 45.4355985887589, 44.64338571794572, 44.75066254215856, 46.94692311748382, 47.01185011094617, 50.61746927999681, 49.80670359826858, 49.52531276210662, 49.61336605010494, 48.09302399235387, 45.822265840345814, 46.88884065997216, 45.15818895832185, 47.35956038198164, 47.29774775043611, 49.59633119644658, 47.47900832083918, 54.937183395508804, 59.042481145551136, 66.0781777289606, 67.26025458305114, 67.65423313263925, 64.99747453197357, 67.27027231647124, 69.6471501934913, 72.79830394252654, 67.2828160562823, 74.21357354810162, 66.99731457617976, 78.42548524179767, 71.56704841121551, 84.30029361478745, 7.970348856141491, 0.22195983407718523, 0.1688121932168161, 1.6011338128197579, 60.89324758898828, 64.76457203588178, 59.12625120532129, 39.48617496798116, 29.503974299277033, 32.21586573508478, 59.18887576749248, 43.96084623952066, 0.9682144621206868, 0.01854792901975734, 0.02681449652769633, 0.0359689427028981, 0.146130719973195, 0.037817849942873565, 0.034572069473083944, 0.00934472709383455, 0.06494012420936938, 0.04927755618888525, 0.05967691247802108, 0.05289694241758797, 0.24740676215339094, 0.4076211046307318, 11.424277713221889, 70.10620086423813, 48.61237325975972, 46.59856565536992, 45.56126348433956, 64.55650991009128, 76.13810800736951, 63.65315668044552, 0.5435820993396544, 0.09653004321960673, 0.04700659195922556, 1.593699818176608, 65.54466478286251, 79.24592741074102, 73.07094789320423, 74.34819713715585, 75.68237566178846, 76.12332851656022, 70.37973127057477, 72.39643358415174, 72.4308955284857, 70.50509022128198, 70.51457451235864, 67.31973340434413, 66.48977556536275, 66.24705929909983, 61.43915130246071, 58.36943380294308, 51.439464707528394, 51.94381090902513, 51.363747273722005, 50.637320395438906, 47.572862794322354, 49.72635384528868, 49.77781534194947, 53.003133266202866, 51.080465855137, 54.558764888394265, 55.26007683046403, 59.02977266619283, 58.632652298096694, 57.723380211860906, 53.221295495187086, 52.296318238781346, 49.99898210648568, 49.582214586196415, 46.3124091394486, 44.508471873498735, 44.2612958723499, 44.968969898839156, 44.85887289047242, 43.798856273774184, 41.957068135661466, 46.09120707358084, 48.37159072199176, 45.893966767095755, 50.97810768312024, 52.38466962691277, 49.42952063775832, 51.58914235330398, 53.12423644527313, 55.29524872379919, 52.768406867980964, 55.25393832114435, 53.47260567449755, 58.42763785393008, 55.5983655683456, 56.80554951390913, 58.35698812238632, 58.25799534397741, 57.82836637189312, 57.62148487952448, 60.701078907136, 57.218916339258996, 50.67826209529754, 44.37763337166079, 48.13096507903069, 54.30549744636782, 56.13375732975622, 50.90860720603697, 40.403362397224676, 43.58968019485474, 51.12157229454287, 63.45313933587844, 50.73695644255608, 42.94901594038933, 45.70067628737419, 42.983932879663286, 47.82751483301963, 50.80339747090494, 55.106551339549405, 53.84917674526092, 54.60828481181976, 52.1746463160361, 54.5681118965149, 52.89082404105894, 50.11995976971042, 51.11788526658089, 50.519123692666334, 51.83127810878139, 50.31197940149615, 49.013906294299716, 49.11107909294867, 47.596161673145915, 50.7855938326928, 50.04591718796761, 48.57229840370917, 47.378372069328066, 41.75551714435701, 43.46750620872744, 43.371623869865175, 43.280020836860906, 42.84737163974393, 42.94765880030971, 43.19313641517393, 43.773882542887044, 47.13007427030995, 45.1104066448827, 47.990144145104196, 47.20087697429042, 45.576019440927816, 50.59961072860226, 50.48288099227413, 53.38787855640535, 54.10964565892374, 52.206142948519805, 51.88745821675947, 49.94973674897225, 48.22831830670757, 50.12298391711328, 47.19571905751383, 49.372752174254394, 50.09373480273832, 51.134653399067545, 49.488638600995465, 56.14910948661066, 61.963572194499356, 66.87423844491282, 69.35211735387003, 71.07228063767957, 67.66388216326314, 69.3424290995444, 71.47373522481611, 75.01594143529093, 70.78444142495432, 78.1870129800612, 70.16397737687635, 79.9319342643984, 71.71366660825669, 86.01446351697369, 8.549306873352297, 0.17855585102112065, 0.2346106576583078, 1.6457832556578422, 70.13131972282164, 71.50353739338537, 67.65541768843129, 47.352880585578184, 33.58519654120169, 43.758420559667776, 69.12194482741818, 55.1789386810795, 1.4488377398060215, 0.03598772334836183, 0.014123613251403216, 0.040221243961564, 0.10816329519354528, 0.04422497650187823, 0.2363344167749728, 0.08240965615597465, 0.1449785084133187, 0.14151477975951088, 0.1758711265339967, 0.11779824512139445, 0.36923099849973956, 0.6042505632485113, 19.423502568275698, 86.03459312069802, 54.73752690899757, 48.656939229657574, 56.30203485488892, 73.15534945457213, 81.08808425164993, 72.60839846826369, 1.0447507519875805, 0.24477465258490658, 0.1882318785834697, 2.376656263105331, 70.47164024845247, 81.47365323958859, 77.31933762950283, 77.18112899411109, 78.0131813787645, 77.30857464574999, 73.55585482812697, 76.19888121081938, 74.40420858321652, 73.01183777470743, 72.95784242691533, 69.32793201938753, 69.00053178110431, 66.66894159009381, 65.58837959843298, 60.75022228302495, 56.19843721389771, 57.006869085373424, 53.310419590242454, 53.31383205229237, 50.889944568757095, 53.12884915259577, 53.50210974293371, 55.069273133431714, 52.77237630659535, 57.65000443304739, 59.5193511439908, 63.2548870578889, 61.556018321744865, 60.92588563119212, 56.254774216682684, 53.91811240103937, 51.85947995032034, 52.67333253737419, 46.92434987714214, 45.50480096570907, 46.84334508834347, 46.937787917352495, 48.79480269647414, 46.91358689338931, 46.690388341103834, 51.113029372307565, 51.60773831029093, 48.43967522344282, 54.058737216457246, 54.33851988084855, 53.76713252836659, 54.45012307936146, 55.63327466287921, 60.490286811705566, 55.522604988467315, 60.42076672277143, 55.06161274448518, 63.8268353093055, 59.26837044377481, 60.095347281425234, 63.00722076046852, 60.93172211800853, 61.036974999212454, 59.915690960422644, 63.85431935710292, 60.55595513313048, 51.15402206297844, 46.52642934553085, 48.58987062208114, 57.58976074957079, 61.6070052116148, 53.093414460459066, 42.51812396510955, 44.20401357835339, 52.002458187841604, 60.882155126140965, 52.827791552389826, 41.976609383859945, 47.81739904034523, 43.69055963331654, 48.072529608203524, 50.760514197811005, 55.717825274313654, 55.1307092174407, 58.287624928259085, 53.83684873580933, 56.62012730875323, 54.85937533840057, 53.624107222403254, 53.81432648627989, 54.09430919154998, 54.02169435254989, 52.18094172016267, 51.67120618204917, 52.186142783011164, 50.30075357806299, 55.1635512228935, 50.56768655776978, 51.878711331275206, 50.1813683971282, 46.127853778100786, 45.54791565864317, 46.116635799407966, 45.030123572195734, 44.556211040865996, 46.50788830172631, 46.56129921636274, 48.01623575149044, 49.54677989405971, 46.42210214368759, 50.18580852016326, 51.316980854157485, 48.745200403275035, 52.749881513657115, 53.21262705710627, 56.22529760483773, 58.0816142020687, 56.34266276513377, 56.350115268461174, 52.475201852859996, 52.17570535598263, 53.84225768427695, 50.68468301526962, 54.385953103342366, 52.94607062493601, 56.25773952853296, 52.31317266341179, 60.22052188073436, 65.17689943313599, 70.71049690246582, 72.75532261017831, 72.17834195783063, 71.2938004155313, 72.20066808885144, 73.15374912754183, 77.7126258419406, 72.92545149403234, 81.05318300185665, 73.02087491558444, 85.4497677280057, 72.00083117331229, 100.99132014859109, 11.36822900464458, 0.30836975622561674, 0.3673744303805213, 2.7154693728493107, 79.24591172126033, 79.70131458774691, 76.69923443948069, 57.488849932147616, 45.59496056648993, 53.14888069706579, 80.40110465018981, 68.41983272183326, 2.3169776460816784, 0.1722480209484216, 0.13771106128490743, 0.18786783360185164, 0.19177526505964418, 0.09996068453596485], [0.021433791806620937, 0.042579316218654, 0.033637549457771164, 0.04759326975251879, 0.05557537732285358, 0.03414595987828028, 0.23327501400584177, 0.19772867221505414, 12.00752337132731, 55.715432628508545, 45.15876554673718, 37.096208141696074, 37.63619692094865, 58.484963293998476, 67.04187270133727, 66.49176028466994, 1.78404288186181, 0.09970753078138637, 0.12467121059495596, 0.023883704599293492, 45.60452330497004, 79.57570460534866, 66.49216036642751, 71.13142213513775, 69.05603331904258, 70.84663452640658, 67.01616548722791, 67.42674350738525, 65.6482388896327, 65.62851329003611, 65.72277176764705, 65.64406156539917, 61.929286756823146, 64.6071320195352, 59.90931318652246, 54.11433289127966, 49.496357825494584, 50.364335198556226, 48.96423339843751, 47.127567875769834, 46.88385532748315, 45.91339034418906, 48.640641781591604, 50.83862427742251, 50.730970905673125, 55.13252135246031, 57.20064593899635, 58.17513919645741, 57.67075769362911, 55.58771633332776, 52.90880810829901, 47.79873640306535, 44.555199069361535, 45.216016461772305, 42.47699791385282, 43.12549514155234, 42.91748400657408, 43.96538049943986, 42.36451610442131, 41.201011673096694, 41.197607055787124, 42.78675533110096, 44.232972437335604, 43.82901930039929, 46.52839053061701, 47.861549239004816, 50.01256135202224, 51.28142064617526, 50.11049116811445, 52.190280883542954, 52.03517075507872, 50.836910201657204, 51.96894937945951, 50.698187735772905, 52.76505324148363, 52.88998465384207, 54.952904255159446, 53.81094932556153, 53.70802633223995, 57.571023587257635, 54.520160921158336, 56.34363159056633, 54.55690568493259, 42.05801033204602, 43.072574523187455, 45.109473120781686, 50.18463965385191, 50.3036561319905, 45.946769714355476, 39.627411673145915, 45.068433361668745, 59.00615999775549, 47.53856166716545, 44.51134697083504, 41.113460448480424, 42.88320249126804, 55.099385169244584, 56.04855560487317, 53.720232748216205, 52.07351584588328, 53.76747377457158, 52.991421068868334, 50.112762220444225, 50.46170019334363, 51.31007748265421, 48.81119428142425, 47.54296648886896, 48.55266694099673, 49.045214653015144, 51.088675375907656, 50.3241426714005, 45.83529595405825, 47.63356147273895, 42.79691819221743, 41.30535064205047, 42.14782084188154, 39.35091987732918, 39.848727487748675, 39.222285747528076, 41.04222628378099, 40.294383264357045, 38.38917040055798, 41.00022162160566, 42.47935525832638, 44.49405716311547, 44.51002905445714, 42.188793920701556, 44.6297868605583, 43.771172185097974, 44.91975199791693, 46.223826331477014, 48.21460962295533, 46.12783024387975, 49.81063773555141, 48.083029793154815, 48.84868037316107, 47.5135055665047, 46.49478366298061, 45.99786250822006, 47.49780824107509, 43.761327035965465, 46.05555665108466, 47.2016026127723, 48.72920497771233, 51.41128640021048, 59.44224911351358, 63.08701745925411, 68.71082552017705, 68.81373282401793, 70.75696914426743, 69.54414875276628, 73.9745129308393, 71.59754876167544, 74.06245247010263, 72.90065426980296, 76.2144059519614, 69.946882032579, 61.77481205232682, 2.7737234340560053, 0.2006716602632115, 0.25919356112999303, 2.3300018762388537, 60.467023234213556, 65.20424619797738, 56.728463172912605, 44.24408843440395, 32.656167476407944, 32.59142287315861, 59.24946461954425, 45.17455700905093, 3.180843149462054, 0.07381765832824093, 0.07121131995752936, 0.02446548900597038, 0.12441461710559747, 0.06140766214699515, 0.030246920913698214, 0.041624303351366715, 0.07575570755908567, 0.03986780163681796, 0.018263959378424673, 0.1032006542288488, 0.18695553013634297, 0.3260370614307542, 18.62210350651895, 67.04362992317446, 51.82091520678613, 35.69649073385423, 37.062456146363296, 69.19463419145154, 72.43395497722011, 75.12124138493692, 2.0171641726647658, 0.061391842431358756, 0.2437027730047703, 0.1332469443760572, 44.95148789498114, 82.39425705325219, 68.49524421076622, 75.37188083894792, 71.38159090472807, 75.78567520264657, 71.0873503838816, 70.32674004954677, 67.57587202133672, 69.67940776578843, 66.12778786690005, 68.36244844621228, 65.3629139161879, 67.57498556567778, 61.78695178801014, 56.836144001253196, 52.876072006840865, 52.461669675765506, 51.8929652244814, 50.27568963266189, 49.203117509042066, 48.36861364303097, 50.265318885926284, 51.23168107002012, 53.52172551616546, 57.600100117345015, 60.379919159796934, 61.44105365199428, 61.24611969917052, 57.52821483919698, 54.547193896385934, 50.44360237736856, 45.15501576085245, 47.03790249363069, 46.40440833184027, 46.554160502649125, 46.034489600889145, 46.171246959317116, 44.32948235542544, 43.84744659546883, 44.99573615289504, 46.33170327832622, 44.92084241682484, 48.47702010985344, 48.62779994164744, 49.35281476666851, 52.561419471617675, 52.10982522656841, 53.00385498231458, 55.40116840793241, 55.69262012358635, 53.44802418062764, 55.01196338284401, 53.285406635653594, 55.054650537429325, 56.05349779129029, 55.79056955152943, 58.64769458770753, 57.27307642659834, 59.5542759280051, 56.9645506335843, 59.17875997481808, 55.64721476647162, 44.139604337753795, 46.05144992951424, 48.91554501748855, 51.89221605177849, 53.62949655902002, 47.641249318276685, 41.021535781122026, 49.66915784343597, 57.61044340748941, 51.393498451479026, 45.48687181165142, 41.50702322683027, 43.442920792487364, 57.1379154728305, 56.9639701227988, 56.55087001862065, 54.205429938531694, 57.162920582679014, 55.30494482286515, 54.6128975191424, 53.78597559467439, 53.40291692364601, 51.83825208294777, 49.5627910091031, 51.383304211401175, 51.15464571983584, 52.85029811243857, 52.99000117086595, 48.316061727462284, 49.38731201233403, 44.57697999092841, 44.83012976184968, 44.41890847298407, 41.876181017967966, 43.63971002640263, 41.79152842490904, 43.418347143357806, 43.08432986659389, 42.30433910123764, 43.00832609976492, 45.34601949876355, 46.445157835560465, 47.376571701418975, 45.86883614140172, 47.89525416589553, 45.83977922316521, 48.27979157047887, 49.69183306540213, 50.562281531672326, 48.79234729274627, 52.780279882492565, 48.967234011619325, 51.820342540740974, 50.87385892868043, 50.47935085911905, 49.41535303669591, 48.380172867928785, 46.52153030518563, 49.34723715628348, 49.483394392075084, 51.820413143404075, 52.903101059698294, 61.25085007759833, 65.82764025657409, 71.4010537055231, 71.26941896254017, 74.86176875329788, 72.52638170796057, 76.0959582174978, 72.80401491349744, 78.59136227638491, 74.5529370154104, 77.77073967841365, 72.26862707445699, 64.82237600511121, 2.5736801037865304, 0.1388462656928647, 0.24906437723867356, 3.662014517091936, 68.72635026131907, 73.52740979963734, 68.1104753863427, 50.91114497953846, 29.2232326153786, 43.00965186088316, 69.50577228300034, 56.81267253814205, 4.021962092768762, 0.0422145166404305, 0.10167647633821734, 0.02608521721295772, 0.05136358296318401, 0.03595329535704467, 0.1671194913046014, 0.07926069770849521, 0.151681057628124, 0.13859155677979992, 0.1874842380564059, 0.2246825565253535, 0.4453530186606992, 0.6348484213794432, 26.26330617935427, 81.09845499838553, 59.8519681346032, 45.93319831355926, 50.158599038277906, 78.88284144863006, 79.51129144237888, 83.39717572735202, 2.4786378875855477, 0.21788049248918412, 0.43568410039428745, 0.3454423443444314, 51.27654121768091, 86.42251553074007, 70.91335404303767, 80.35535412449991, 74.80616523373511, 77.53547591547813, 73.8454669521701, 75.1334870246149, 71.71480409560665, 72.55281848292198, 68.82964195743685, 71.28452793244394, 66.69156582124772, 69.41353382602816, 65.38571857636975, 59.67062127205634, 56.554302092521425, 57.07914660053869, 55.506774302451845, 52.69998112032491, 51.80899512383246, 53.4232073445474, 54.7284976128609, 54.027534761736476, 54.993449795630674, 61.36097846492645, 63.74334373781758, 63.023506441423976, 64.67344360966837, 59.305703563074914, 57.68850641865885, 54.814428898596, 47.075455265660445, 48.749456174912, 48.3819144002853, 49.48385330938524, 49.82522503022225, 49.87330152142433, 48.97870694437335, 46.73895120620728, 47.96684918865081, 49.48757563867877, 47.46891214001564, 50.138241937083585, 52.34179027618901, 51.85611455671249, 56.21166736848893, 57.316363703820016, 56.43441092583441, 58.547540787727606, 59.21567732287992, 58.61493495202834, 59.01295354289394, 56.70440335427561, 59.93112156468054, 58.24594974517823, 59.40916784348027, 61.19051617960776, 58.917008446108916, 64.13541209313178, 60.826669277683386, 61.47329945718089, 57.25078951927924, 44.218498891399754, 48.554494765497026, 50.37126602665071, 56.47950249333536, 53.708771582572695, 49.26372597294469, 42.41356534342612, 52.99706143717612, 61.30245670195549, 54.63161899197487, 48.34011370135892, 42.60973092048399, 43.40419915414626, 57.48624155598303, 60.030106498349106, 60.20908032694171, 56.26558819124776, 59.60671409483879, 57.68494882891255, 57.572070860093646, 57.062421614123934, 58.400279321978175, 55.1018209611216, 52.04364307465092, 53.91576682367633, 54.55019450956776, 55.6432649397081, 56.58386107414, 51.42244162098054, 54.42740078895323, 46.475622884688846, 46.2273290080409, 46.51519959972751, 45.12211099747689, 45.584291719621234, 44.92428625783613, 47.89957269545525, 46.24196729352398, 44.430244122782064, 45.41051110913677, 49.39724345361033, 49.16185025245913, 47.65768012692852, 46.27581734811106, 50.98739977805845, 50.22474981123402, 52.45192650825747, 52.4665020358178, 53.39477016079811, 51.35861681353662, 57.40747251818257, 54.11987912270331, 54.61134426055416, 53.677322018531065, 52.207139230543575, 52.61765841514834, 54.18197024253107, 49.84456231517177, 52.86141410950692, 53.37841779954972, 55.295993974131925, 57.02314299921836, 65.12911319732666, 68.54419539051672, 73.89689706986951, 73.76082220385152, 79.04348604140743, 77.35344656052129, 80.39620953221475, 75.81465367347964, 81.9697859979445, 76.36866492609825, 81.41884203880065, 72.59061444190242, 71.36594064774053, 4.025300274933539, 0.2436654032358239, 0.5863814704841184, 4.705608169878683, 77.50183766888034, 84.75515519419025, 75.46897519019343, 67.38970848821825, 49.95622042686709, 50.16991507622504, 80.52254907546505, 70.26029509882774, 6.64760600174627, 0.21352044096396816, 0.1518376766433639, 0.10511123154672886, 0.21883925152642114, 0.13972464678508623], [0.1489443464144584, 0.06410955466450223, 0.08095819533111588, 0.11290561693209795, 0.11853067114228204, 0.036533691229358796, 0.08111299871797524, 0.08774934261436425, 10.078949851374473, 56.198362688864435, 45.28628572340935, 47.71515069469329, 47.839105436878825, 56.65109834363384, 65.6882078416886, 72.73717772576117, 6.418119890074577, 0.2381198612913009, 0.5823305201145911, 0.2580333056469118, 21.159757375717163, 77.16545520290252, 68.9677329217234, 73.08790822182932, 71.89247177493188, 71.19582745336717, 67.38551155213388, 67.29608151220506, 66.16614080244496, 64.58167191474669, 65.52085207354638, 65.10341775032782, 65.56910507140621, 63.4454514903407, 58.0153496803776, 53.47030716557657, 49.95755795509585, 47.43411287184685, 46.86498088221396, 46.31720227579917, 47.447190054001354, 47.15825257762786, 49.85991447202621, 50.84683379819317, 53.64976344570037, 59.64460419070337, 58.71841492191438, 60.764699751330966, 60.018900286766794, 54.567892243785245, 50.25459904824534, 46.15458865319529, 47.84384366004698, 44.208638052786554, 44.866392074092744, 41.62636918406333, 42.49236183781778, 43.032938972596206, 43.798644465784875, 43.69648241227673, 41.24796244405931, 43.96416456468644, 44.143134470908876, 44.468514688553356, 45.50822519486951, 46.68150417266354, 49.12033588655534, 51.364265026584754, 51.86380240225023, 49.172562245399725, 50.98721934903053, 50.77699599727508, 51.12676159028084, 52.100901834426395, 52.40364605380643, 52.59952529784172, 56.06283695467057, 53.01402176580122, 53.41176186838458, 56.14812104932724, 56.54103271422848, 57.15984544446392, 59.477868157048384, 51.42649735173872, 45.549759172624164, 46.24970220750379, 40.17645328275619, 42.67556398145614, 45.726650222655266, 42.93288715424077, 39.15970040905861, 45.401073886502175, 37.97038678200015, 41.542140206983014, 42.19744274693151, 50.17089959113829, 54.35247175155148, 53.45370769500733, 56.96601367765858, 54.234255436928045, 55.060357586030044, 52.18247928927022, 51.2869982565603, 49.22268621383175, 50.647518557886926, 49.52814863574121, 49.120575151135846, 48.18809832296064, 49.78528353475755, 48.44862214980587, 48.683517209945194, 44.603616806768606, 44.72595161007297, 44.9759203387845, 42.67376753591722, 39.56530486383746, 41.267688043655895, 39.479958011258034, 40.42406466699416, 39.125371825310495, 39.399035592232984, 40.575774100519, 40.898330211639404, 43.04691045514999, 44.2812019009744, 43.12959401838241, 43.52707132216423, 42.8188128625193, 44.07023329888621, 43.487274954395915, 43.0546885152017, 46.24322637434929, 46.03230091833299, 47.59261585051014, 46.09929892324632, 47.780877851670795, 46.04424845787787, 48.72323120793989, 44.87420935784617, 45.07402666153447, 46.79660220299998, 46.076400126180346, 46.35422945022584, 46.1624373159101, 49.43739283469416, 52.521183798390055, 57.02686925088206, 63.3216771771831, 66.29465333877071, 63.66098180893929, 66.72107773442423, 71.54116076807823, 69.99107145494031, 72.67077199874386, 75.17400510849492, 77.27053549981888, 72.33288334261987, 54.57955737267771, 0.12010886589245451, 0.05010657057526612, 0.2126972948110873, 4.639578009805372, 60.575582673472745, 66.29535152066138, 56.848307271157545, 45.50883316224622, 24.549455950337073, 36.21608318821077, 51.4859644059212, 64.69652283576228, 6.81571045229512, 0.28475252190424555, 0.29872621079125716, 0.03868445243325926, 0.1397968582328289, 0.05097299686542923, 0.17863218402189596, 0.03440986567687604, 0.08391314967265052, 0.046239691981745344, 0.06918988971700592, 0.09607291089430933, 0.12961291437668185, 0.15593822354510908, 16.29105362199968, 66.29857570894303, 53.383618862398215, 51.30800254883305, 46.34718487339635, 64.19169026036417, 67.49669505703834, 79.06058757535874, 6.822674620536066, 0.3167816467823521, 0.4778421640155777, 0.22957071842205143, 20.807308881513535, 80.05080561484061, 70.57565366068195, 75.01077959614416, 72.52842134045017, 76.04323371764153, 69.82682612634474, 71.50822070337111, 69.99730017877394, 66.51217229904668, 67.26763648371544, 68.88024053265973, 67.54181015876033, 66.8272013818064, 60.2596906692751, 57.01767913756832, 52.12860553495346, 49.362004879982244, 47.609387905366965, 50.47557361664311, 48.56546955723917, 51.201671015831735, 51.89123153686524, 52.50945591157483, 56.64870569782873, 60.70842942883892, 60.30808095009097, 62.575630603298066, 62.469997252187426, 57.035678894289084, 53.17973406084123, 49.863452449921645, 48.74142708316926, 46.523385586277136, 47.96040081208753, 45.08869632597893, 44.895429380478404, 44.963282462089296, 45.626206167282604, 44.423395664461204, 44.34146519630186, 45.52115332695746, 45.908605052578835, 46.23511099046277, 47.720387058873335, 49.860479293331025, 51.309496971868704, 52.424983747543834, 54.331471381648896, 53.75035262876942, 53.43807704987065, 53.20048339905278, 53.613053983257664, 55.5401889739498, 57.26683201328401, 56.26868294131372, 56.932540170608036, 56.86544802881057, 54.70938782538138, 57.53806391069966, 58.226973318284564, 59.49349095744472, 60.46874907708938, 52.50919703514346, 44.80101008569041, 48.035729931246856, 44.408298461667954, 47.18329298880793, 47.21830406496602, 43.15199075206634, 45.64284486155356, 48.45540000546364, 43.60392232095042, 43.623604774475105, 42.2792241650243, 52.31664788338446, 56.228992477540054, 56.05378804668304, 57.71841056885258, 54.432915641415505, 57.246584738454516, 53.66985774809315, 55.32263863471247, 53.278114949503255, 52.6408710018281, 52.36366141226984, 51.963465905958614, 49.78450298309327, 51.889568451912176, 51.83852272648966, 51.16087836603965, 48.38724490134947, 47.68183408244964, 47.54195451736451, 45.373754578252, 42.94119473426573, 43.01948916527533, 44.22415494918824, 42.96791784224972, 42.05630017865089, 42.2778787920552, 44.041603918998476, 43.648405921074655, 45.366608019798036, 46.63664402500276, 44.658439774667066, 45.84478808987526, 46.4516415134553, 46.95962375210178, 45.605366614557084, 45.67801283251855, 48.81877230059717, 50.246566034132435, 48.40439742611301, 48.183136524692664, 51.64221594410559, 50.108129901270715, 50.96039033705189, 47.73843780640633, 48.64730981088454, 48.91862800044399, 48.99955434183921, 48.97269395089919, 49.63941843278947, 51.17192376044489, 52.84759559938985, 58.883370199511134, 66.22458411801246, 66.54229610197007, 67.37017508476012, 71.78704630944037, 73.0704144508608, 71.54417314837056, 76.48042894178822, 77.17635939198156, 79.36631279606974, 73.48946479059035, 54.381175656472486, 0.1007450053528432, 0.037393663228759845, 0.18402210286548062, 6.661119547582443, 69.65617164488762, 75.7867342425931, 64.707215216852, 56.076953564920736, 33.994276215953214, 49.22405512102189, 60.85955050683791, 76.13493088752993, 9.993722631085305, 0.3036892347999158, 0.1927362610736201, 0.047056483435294325, 0.06627300228442877, 0.0470887663804235, 0.30923929666319205, 0.2196393997198151, 0.2298387266214817, 0.1498437949245976, 0.1591213648357699, 0.21790514519858747, 0.21765114108641304, 0.26761387865389547, 24.831199799814534, 81.75633061316707, 59.2336457006393, 60.97060849589687, 64.42989972329909, 74.00531138143232, 75.70622367243614, 88.30033456125568, 7.877888785254571, 0.4804661070867893, 1.1066042006977144, 0.25572598671480534, 25.160916197684504, 82.81296222440659, 72.92656544716128, 79.51198962426956, 75.31307666532456, 79.05408428561303, 72.57754510448825, 76.28874271146714, 70.9638584813764, 70.7819232633037, 69.77137950158888, 71.69030497151037, 69.63292767924648, 69.8941889116841, 63.89238595962525, 59.628247907084805, 55.01766650907455, 53.31761321713848, 51.70544847365349, 52.96853403891287, 51.23177128453409, 53.65196389536704, 55.00307136966337, 54.308349009483095, 58.777791761582904, 64.64312368823637, 64.10355460259223, 65.80171731210524, 67.11242829599689, 59.04176727417977, 55.8424860431302, 51.278349430330344, 51.54291329845306, 47.503632960780976, 50.08282669128911, 47.511281582616995, 48.62445808226063, 49.70773043171052, 48.665278188643924, 47.827875691075484, 48.20025767049482, 48.37724285741007, 49.68878930614841, 51.25464654737904, 50.628534286252915, 51.655363728923184, 53.785661805060606, 55.78320334034582, 56.91138682826873, 57.5081636828761, 55.8636825315414, 58.864150585666785, 57.949622523400095, 58.228110805634536, 60.23607015609742, 59.56489770643173, 60.97813552425754, 58.711440947748, 56.910951445179606, 62.242868484989295, 64.21766027327507, 62.17181082694762, 64.41386899640484, 52.23747876382644, 47.180139403189386, 49.10444636498728, 46.99511727979107, 50.08021831512452, 48.781749048540675, 44.0198661435035, 48.2295185519803, 52.541493831142304, 45.961447223540276, 45.45231573043331, 41.593586014163115, 53.3973353908908, 56.525488361235595, 58.873987890058956, 60.15169605132073, 57.99754996453562, 60.638995632048584, 57.81281025178971, 57.06400625167355, 56.13254923974314, 56.23354242693994, 54.71711489462084, 55.825772823825965, 53.617568631326, 55.62497884996476, 56.13246686996953, 53.50317270525041, 49.803875569374334, 48.8767017856721, 50.637893061484064, 48.78320817024478, 43.70191881733556, 44.795377562122965, 46.1507329633159, 44.655270499567834, 44.62571544031943, 43.32467309890255, 46.12085626971337, 47.4194275179217, 50.38072678350633, 50.444186810524236, 48.180924307915475, 48.29921906994235, 49.1812934414033, 49.92184869704708, 49.096809510261785, 49.6677222559529, 53.156188072696814, 52.58947618546025, 52.06931106505856, 51.034264256877286, 55.04750790134553, 53.071951250876154, 53.88755321502686, 50.09561754042103, 52.82654423867503, 51.93737429957236, 51.37214899063111, 51.119858218777566, 52.88719192627938, 55.96865692446309, 56.80540438621276, 61.9866749548143, 71.11282225578063, 72.09190076397311, 71.80644635231265, 75.38576602935791, 79.18281647466844, 76.70326663601783, 81.17854195256388, 80.89020067645659, 84.50743398358746, 74.29253085967034, 59.90852086774765, 0.4349599634447406, 0.1930005154422214, 0.624252567368169, 8.332232121498354, 79.1633850528348, 83.87542247772217, 73.27809610674458, 66.65195772724768, 36.64154660317206, 54.29369111214915, 68.85820465703165, 85.18227777173443, 11.841461985341965, 0.5904881920545333, 0.4709615912889281, 0.16984385318092762, 0.19767437190298112, 0.22051771952500268], [0.020787075702701847, 0.060268811160518285, 0.08013253640984336, 0.06002092809085885, 0.0594640089829843, 0.02093190462478707, 0.11866177176876415, 0.1215311770717944, 19.12214686793666, 59.26080026934224, 47.29533549278013, 24.90222804007992, 26.3064875525813, 54.83648438607493, 60.46496006750292, 79.24268753297868, 6.327082658967664, 0.14033390118950798, 0.32397098358600374, 0.49493450491178426, 5.247359564227443, 64.51457585057905, 69.51155385663434, 69.38355122843097, 70.31474544155982, 69.03094583942045, 65.35736768476426, 64.16173119698801, 63.924274829126176, 65.06449999347811, 67.79844299439462, 69.33282713736259, 66.7051999799667, 62.67046566932433, 56.6034415460402, 50.035660189967004, 45.68237058577999, 46.965209207227154, 47.55694973853327, 44.93633970137566, 48.08949385919879, 49.4198323834327, 50.2467699973814, 54.426428041150494, 58.70907183616393, 58.34723711013795, 59.075358452335486, 59.136888673228604, 58.25502610975697, 52.53672422901277, 46.57668275217856, 44.464435423574145, 46.016678117936664, 45.05030808910247, 44.364026669533025, 45.89527291636313, 44.54933904832409, 42.27315625836773, 42.872596402322095, 42.31488243226082, 42.84670875918481, 42.05526859529557, 40.37575675595192, 44.31303977966309, 45.257875996251265, 44.32657195675758, 49.12305801145492, 50.50473643887428, 51.43465195932696, 50.698897684774096, 51.52184232588738, 51.69137893184539, 52.351000001353604, 53.49680669846074, 51.391125417524776, 54.48226690292359, 52.81115285811886, 51.45865294241136, 53.63612536461123, 53.86536044459189, 55.11451375099921, 54.873711601380386, 57.32061947545698, 53.04433776486305, 45.91096631942257, 46.23723299272599, 36.81990069727744, 40.40133845421576, 42.61568115603539, 41.714320490437174, 43.2407186877343, 46.32044607593168, 45.230278199718846, 43.92417992314985, 44.114630606866655, 51.3956557550738, 54.685535892363525, 56.16568542295887, 52.451565650201616, 54.02906840847385, 53.67497251879785, 51.588593221479854, 55.0876808166504, 50.94992545343215, 49.51722091244113, 49.67919126633675, 48.62807842992967, 47.45595655133648, 48.356885756215746, 49.36626065161921, 49.88961858134116, 46.99838853651478, 44.986746080460094, 42.37389449150332, 42.00926703791465, 40.86537053508144, 39.06123322825278, 39.76706374076105, 40.42004423756754, 39.4337171892966, 39.61506012947329, 39.65269527127666, 41.94676799158896, 42.55420977069486, 42.70693509809433, 42.921480901779674, 43.79387878602551, 42.11386096092963, 43.0919784884299, 40.78647990380564, 43.01039318884573, 43.74162497058992, 44.44704755660027, 45.23680894605575, 45.89808917814686, 46.008084204889116, 46.47886276245118, 45.57081837807932, 44.373385444764175, 45.986209146438114, 47.06832831905734, 45.566876396056145, 47.2501301765442, 45.71090190641342, 47.957251148839156, 46.26243029871295, 50.31310904410578, 51.68410685754592, 60.43310649933354, 59.84328008467152, 62.48029347388976, 63.16415871343305, 67.42517455931633, 65.68677225420552, 77.58355632905038, 71.49286854651668, 86.1184847739435, 34.77349819675569, 0.5451087593551606, 0.16939343944672616, 0.26703949657178694, 4.5320962417510255, 63.72981156072309, 66.32037624236077, 61.46613720924624, 40.771869074913766, 24.271365788675126, 38.63908813845727, 50.968744985518924, 68.57415445389287, 7.803322567093757, 0.08983061964353246, 0.1451052959647871, 0.04489789281280772, 0.0698911742637715, 0.022891373673994696, 0.04047601033122309, 0.02766256735119368, 0.1284566655334446, 0.052195267165980996, 0.07561268660450175, 0.041082931997915434, 0.15259783504711044, 0.17155267358306917, 27.5463193462741, 68.75051990632089, 56.03980479701873, 28.768937818465698, 28.34596314737874, 63.70865037364345, 63.35421716013263, 85.67200922196912, 6.772281479450965, 0.25900997581981844, 0.4574800985715082, 1.200482453550062, 5.433420135128883, 64.34944406632455, 71.30268066160141, 73.69848005233273, 74.32423930014335, 71.52624791668308, 68.6787405321675, 66.0468379912838, 67.32696625494188, 66.07059970978769, 68.9463246253229, 70.95184033916843, 67.94088778957244, 64.72924717010991, 57.339862623522365, 54.58979083645729, 50.07633124628375, 50.18645178887152, 51.90758389811362, 47.63066676355178, 50.26108664851035, 51.4161854405557, 53.54643644825105, 55.603723526000984, 60.70377749781455, 62.41782188415528, 61.96470575947916, 61.573633686188735, 59.303275615938254, 55.04507210946853, 49.852775758312596, 46.32248570842128, 47.06285269029679, 47.29949320516279, 46.01144175375662, 47.831707846733835, 46.9169169856656, 45.852020940473004, 45.63808310416437, 43.690320368736025, 45.70126856527021, 43.55939949712446, 44.03493981207571, 45.80096737031014, 47.3703900460274, 48.0798291390942, 49.72276487658101, 54.49320247096401, 53.9427762646829, 53.68478236659881, 53.47124068967758, 55.2547816307314, 55.99035939862652, 55.432378707393525, 55.5358116088375, 58.05201991911858, 55.22578747041764, 53.96179976001863, 56.922043908026914, 56.48195789706323, 57.23485292926912, 56.69994754175986, 59.42389634347732, 55.48160837542627, 45.46890343389204, 46.3040780252026, 39.484378522442235, 44.17238358528384, 44.13897283615605, 42.54922443820585, 46.92270640403994, 48.52277848028368, 48.601076833663456, 45.01868201840309, 46.51238726031396, 54.88459617860856, 57.38877065720097, 58.35679592624788, 54.16740648208126, 55.799512555522305, 55.496611441335375, 54.18132697382281, 58.3219103659353, 54.21309032747823, 52.88979245770363, 52.84127666104225, 51.666146324526885, 50.37343901972617, 49.723435601880475, 50.891678256373254, 52.62896660835513, 51.07342520067769, 46.57141108666697, 45.31213022047474, 44.363689345698205, 42.283789803904874, 42.46148886219148, 42.1143041887591, 43.258506636465754, 41.97458544085103, 42.215418969431234, 41.58172084439186, 43.36020977266374, 44.23822449099633, 45.31597022087344, 44.43853993569651, 44.95833243093183, 43.71338390534924, 46.76677650020969, 44.8589591826162, 44.363795249692856, 44.69298016640448, 47.98719060036444, 46.67176492752568, 49.486069448532604, 48.39286173543623, 50.08419559847925, 48.31326507752942, 46.790648045078406, 48.15913554160826, 49.56381082534791, 49.40802604921403, 49.7820475793654, 48.12620724401167, 50.07302076585832, 49.776273850471746, 50.80557438635057, 53.43638650832638, 62.56713082713466, 62.31261999376359, 65.37000163908928, 66.32640100294545, 71.53387300429806, 70.50235240690171, 77.99195351139193, 74.22691745142784, 86.15038148818478, 36.1189260790425, 0.4752678327983426, 0.3025003276284664, 0.20500695182671472, 6.143274999433949, 71.27058782885152, 73.72301840013074, 69.46967863267469, 49.621473589251124, 32.121658248286096, 44.40681580574282, 61.87353026482367, 78.71073569020918, 10.409771377040494, 0.07889669103127334, 0.2156804871535109, 0.04565693272818481, 0.12628725774946714, 0.024342966649020394, 0.19801590922138385, 0.11460669218532502, 0.2369841206217966, 0.15493988840570375, 0.18043262853978143, 0.12622596305464545, 0.15133703818484662, 0.2672765548190763, 34.258024231080086, 82.97545033116495, 60.57348420543056, 33.59373554106682, 38.62244552181613, 72.83713540723248, 71.14966115643902, 94.14366199124245, 8.015310004834207, 0.41830640706804495, 1.1970984286838964, 1.2067261314199818, 6.97277392110517, 70.70517032377182, 73.63297647045505, 76.77816037208804, 76.88824561334427, 72.44781663340908, 74.22388938165481, 69.80002064858714, 71.18653143605879, 70.15817226902132, 70.77825192482241, 75.03181918974846, 71.81648761995378, 68.96725439256238, 60.24693119910456, 59.14751829639558, 51.27558415935886, 51.746978529037975, 55.04743729868243, 49.283490796242994, 52.169719819099676, 53.75023888003442, 56.148607423228604, 59.576370639185754, 63.67474540587395, 63.74345356418241, 62.88458393466089, 65.05323886871338, 61.73147770666308, 57.192440340595866, 52.26598655023883, 48.91854955304054, 50.6455534504306, 49.266655983463416, 48.02846570168772, 49.98352404563658, 48.67370343977406, 46.36028558977189, 47.50937138834308, 47.23972020610687, 48.9647433065599, 47.62512053212812, 47.52937155385172, 49.10391684501402, 49.83998883155085, 49.106132984161384, 52.86694857382005, 56.39549709135487, 57.13431865938249, 58.657755467199514, 57.863349991460005, 58.53784861103181, 59.66320014769032, 58.43291736418202, 56.62810540968373, 60.2255738935163, 58.26794639710457, 55.80903607030069, 59.90484560689619, 59.64965620348531, 60.76371131404754, 60.4535145913401, 61.851823868290076, 57.27326862273678, 46.14388450499504, 47.619229132129306, 41.218089672826956, 45.57430144279234, 45.76833717284664, 43.436680301543205, 48.50047196111372, 49.36863760794363, 50.61092284417922, 45.4234706201861, 46.43448506632159, 54.34264621426983, 59.20816598399993, 62.093037866776996, 56.75400172510455, 59.39607497184508, 59.08387784034976, 56.600668430328376, 62.8470350850013, 58.485783069364494, 56.51685130211615, 57.58206898166288, 55.584609816151286, 54.03221807172222, 54.56540153872583, 55.49567399486419, 55.6517372592803, 53.62700193159042, 49.76953129614554, 47.370546940834295, 48.27014646222515, 45.69187448870751, 45.92773837427939, 45.23329450238136, 45.46002711019209, 43.998622586650235, 44.10198488543111, 43.64619370429747, 46.42987628136912, 47.76449018909086, 47.1479759677764, 47.42659368822652, 48.38666831293414, 47.68215571680377, 49.5865370381263, 45.882682108110004, 48.37044538990144, 48.692464136308246, 50.806425540677964, 50.48348503728067, 52.69384261100523, 52.29789895396079, 53.278311068011874, 51.860990062836684, 49.81018666298159, 51.703118585771136, 53.01778331879647, 52.97475884037634, 54.07403446012928, 50.875325895124874, 55.295189888246604, 52.89842167208272, 55.99491719276675, 56.93419541082075, 66.07114099687146, 66.37430883223011, 69.53193449204969, 69.60926009762672, 74.85234722014397, 73.14595145563926, 83.2253602243239, 77.16026982953473, 87.15330800702496, 40.076770167196955, 0.6514657264755619, 0.28301721018168235, 0.4209549262398674, 7.892795753094458, 80.74188801550096, 81.56751555781211, 79.33382772630262, 60.32968536500008, 35.36405024989959, 57.06803844821069, 70.90349320442446, 90.11028874304988, 14.979479716670129, 0.23716255782112, 0.4803531244397164, 0.12110116425901653, 0.18188051939491304, 0.06698573984566235], [0.062161350938221144, 0.003537064096176877, 0.07538726523278222, 0.0437987290112482, 0.08081096855382766, 0.1127546976110147, 0.1358536811124894, 0.08252471490132232, 21.2866440896065, 62.20914394624772, 42.7918073438829, 36.05266547972156, 27.662372473747503, 51.30838694110994, 57.63944933491369, 82.35345655871977, 11.237718020716022, 0.09388776766436716, 0.12230061280030398, 1.2268920170684015, 0.3572158899999434, 31.06809981407658, 71.93298985881191, 67.03934669494629, 70.68369142470821, 65.57493371348228, 66.22012830549671, 67.2644672086162, 69.30273471340057, 67.01349827551073, 67.33552486665788, 67.45342346929735, 63.1545606736214, 57.72041882238081, 51.22301655430948, 52.605797167747255, 47.77452753436181, 46.276668502438454, 48.02909720328547, 48.9033660581035, 48.65336202806043, 50.354784227186634, 53.870577196921076, 57.43760808821648, 59.060473057531546, 58.374234784033995, 60.823998143596036, 57.635899589907744, 56.69875514122748, 50.48957255578811, 44.05097838371031, 46.21158069179904, 45.22321008866833, 43.881896772692286, 44.567534923553474, 43.5537120603746, 45.41147601219916, 45.16657106338009, 43.56114887422131, 42.405693146490286, 44.50386308854626, 43.59999602840793, 39.891999075489665, 42.96914162174348, 42.6072362930544, 46.03386986640192, 46.88817777941304, 49.88365657867924, 52.58742086348995, 51.907073989991225, 50.72338111938969, 50.97109056288197, 52.25729850030715, 54.87809288886286, 55.327333711808734, 53.92214067520634, 52.98496092519453, 52.33747174662929, 52.37446754209457, 54.819963362909135, 53.33236525135656, 55.911398164687625, 56.60779929930165, 56.8940068060352, 45.07600353610131, 45.291729973208525, 40.044947977988954, 36.86030503242247, 45.72821132598385, 45.052563451951556, 44.41411925900368, 38.679084547104374, 42.342315489246005, 42.96788254091817, 48.95145039404593, 54.9515078913781, 54.61881637573243, 54.321132013874674, 55.498039184078095, 52.40541896512432, 51.61313156927786, 52.356397182710715, 49.43602392750402, 50.83825557462631, 50.07080854908113, 51.464258009387606, 50.11624920752741, 46.15378456730997, 48.189588823626124, 46.763838644950624, 46.954132433860536, 45.928836637927645, 43.51006392509707, 44.38533690667922, 42.343727542508034, 38.427252692561, 38.176307293676565, 39.140276831965295, 40.334924882458104, 41.18025056777462, 41.06690583690521, 40.6325190298019, 42.35536913717947, 42.91231824505714, 42.473459935957386, 41.861542732484885, 44.28941142174506, 41.20746004965998, 42.34031508045812, 42.49776686391523, 42.82835598914854, 42.614692718751975, 43.207908061242875, 43.32524184257754, 45.61954598273001, 44.38922005314981, 47.62407325929212, 43.63930209990471, 45.70867007778537, 44.47411191078925, 45.938536659363784, 47.9433738031695, 49.053416329045454, 48.02229581340667, 49.01719716287429, 48.177056850925574, 50.597669155366965, 47.38629917944632, 51.49131059646607, 53.80890577070175, 57.40978671658424, 57.54181761895457, 63.40685929021528, 68.08945148221909, 76.74675003174814, 71.70739081598097, 85.3078406856906, 19.45842146873474, 0.822450974054875, 0.5668474541556451, 0.11116598447364186, 6.2162502061936165, 66.42366009373819, 67.96818748597177, 56.138656370101444, 46.881631343595444, 33.663487049841116, 44.35802936553956, 49.40345648796328, 60.56507464378112, 8.283039715982254, 0.36469992550630725, 0.42002259723601804, 0.07093781890768198, 0.2047470794810403, 0.006376883322973886, 0.05786914415957947, 0.018378361203377287, 0.08169257487621039, 0.0434981084488813, 0.19288079122141485, 0.12756530691178578, 0.11785591622033428, 0.11543457276157795, 27.44092525974397, 71.50029751562303, 50.070600663461995, 38.60148437561528, 33.15361030640141, 60.038935753606985, 60.06752198742282, 89.46127768485778, 12.848023560739334, 0.08620610445617669, 0.14173981042638903, 1.9367940723896029, 1.604059533246102, 30.493533380569954, 74.87047641508042, 69.86214314737629, 73.02020811265515, 67.04948209947156, 68.03296935173773, 68.27476778338033, 72.35901417270784, 70.81192939512192, 69.03611552330756, 68.80326794039819, 67.17848100969869, 61.38679158303046, 53.95962676694317, 54.20302552561606, 50.308002118141424, 49.05995099775253, 49.90046001249745, 51.19566586709792, 49.41595315933228, 52.29880894384077, 55.731694775242964, 58.736893207796165, 62.66468409569033, 61.903171616215865, 63.23002315336659, 61.150719811839444, 58.98061752319337, 51.772670053666644, 47.1488388892143, 48.91482722374701, 47.71710011266893, 46.668505437912486, 47.61997046009187, 45.619236115486395, 47.31346468771658, 47.11906809960642, 46.53430938720704, 45.03036283677624, 47.889594185736875, 46.08270337504726, 43.115042025043124, 44.701017102887555, 43.958987036058986, 48.9973029013603, 49.335901506485484, 52.038328263067434, 54.551955653775124, 55.47807431990101, 52.946564843577725, 54.646300423529844, 55.34449015894244, 59.10415649414063, 57.76701658002792, 57.42330712656821, 54.7869840745003, 56.48234228934012, 55.93341050609466, 56.67697029729044, 54.94226678725212, 59.10542734207646, 57.71912836259412, 59.12182284939674, 45.31822166135235, 44.895880453048214, 41.5607165521191, 40.515110723433956, 45.422058566924065, 43.323951382790845, 45.7977431820285, 41.70236902852213, 44.23773811709496, 41.95732701209284, 50.005614834447066, 55.69486764169509, 56.23926908739152, 56.646689599560155, 55.86847959026214, 56.066072910062736, 54.12469579327492, 54.030249041895715, 52.56537714312154, 54.053885244554095, 52.582906215421616, 53.10144747457197, 53.792118026364236, 48.28025441015921, 50.33488996567265, 48.761799873844275, 49.937263611824285, 48.97414915023312, 46.49920809653498, 46.45748192264188, 45.75725647710985, 41.95724071994905, 41.22296125658097, 42.13744225040559, 43.97598266601563, 43.66781773105745, 43.239055602781235, 42.705134730185236, 45.14563737377044, 44.84887476890318, 45.2640341174218, 44.04278455242034, 46.3513151291878, 43.71245038124823, 45.88371761383549, 45.92863659704886, 46.20074318301293, 45.58264432414886, 47.686211447561945, 47.142202238882746, 47.54042087062713, 46.241135751047445, 50.52644283540788, 46.64302179890294, 49.21655554925242, 46.8524371424029, 49.13793163914835, 49.37720406439997, 52.21154012987691, 51.31816540994952, 52.92879258432696, 50.64875802686138, 53.726990992023104, 51.1843341396701, 53.38584284628592, 55.740606400274466, 59.51957864146079, 58.97517327339419, 67.177531796117, 70.68118895253828, 77.62313304408904, 75.90601351953323, 86.39716917468657, 20.424697360684796, 0.7102846702741039, 0.7113182148145092, 0.25341843795632163, 7.619364386604679, 77.10081454246276, 75.73636316484021, 65.24496040036603, 54.3385277255889, 25.47657874322707, 44.30265726581697, 60.43870372156943, 72.00239227664086, 12.52912505980461, 0.44566846302440094, 0.24475641969230869, 0.11101684247654293, 0.1397000860062338, 0.012893269341739436, 0.14666888141824355, 0.13395654097680124, 0.1878662707824861, 0.1369387527266818, 0.28609149037830295, 0.26112716705087696, 0.25570799897034324, 0.15997898494524343, 34.9354136374689, 84.61735448529645, 56.47989473035259, 52.64295770275978, 42.761291303942286, 70.1716495329334, 66.4946000806747, 99.95674794720065, 13.109045528596448, 0.15336475034634914, 0.24759767126412163, 3.5021494953863086, 1.8087892378530197, 34.39908835195726, 78.3545687890822, 72.67916587091261, 73.73384414180633, 69.26231076640468, 69.11496300851145, 68.9302429076164, 76.04694427982454, 73.22801528438445, 73.3870203264298, 72.94513394755703, 70.99085223290228, 63.640860049955315, 54.554932732735914, 59.82074999040174, 53.51725401416902, 51.40591667544458, 53.477932253191554, 53.824171635412405, 52.1568936686362, 55.02096914475965, 59.43540849993306, 62.15899644359466, 65.2106475060986, 63.33550745441068, 66.37521882211009, 63.72877997736778, 62.20051473186862, 55.575713880600475, 48.46791236631332, 51.20018443753643, 50.71228081180204, 49.78817039920438, 48.646042885318884, 46.689478351223855, 51.74515070453767, 50.245279496715916, 48.13125141205327, 48.20234044905632, 51.372462780244895, 48.96398628911665, 44.319276348237075, 49.35099086453838, 48.40094574036137, 52.88656826942198, 50.978033158086966, 54.7947346779608, 57.663065925721206, 58.69263710514192, 56.373218028776115, 56.88129440430672, 57.53163122361707, 61.811411688404704, 60.651457002086026, 61.73799668588946, 57.92745720955634, 58.93682426021945, 58.38315425380584, 59.43682447556527, 57.79876816657282, 60.611429214477546, 60.55172289571455, 60.65361822805097, 45.69952703291371, 43.42352467198526, 43.448392498877745, 41.977225195977, 48.75565744215443, 45.177773352592226, 47.67053765635337, 42.67530510502477, 47.01618825235675, 42.76941453256915, 50.119661669577326, 61.11963502822384, 58.70094468516689, 59.447877714710856, 60.853431609369096, 59.52415604745189, 57.99521223191292, 56.573788427537494, 53.81105915192635, 59.057923516919544, 56.15109420591786, 57.50398243627241, 57.95091690555696, 51.3347884147398, 52.61261032473657, 51.98339154643398, 52.04627106266638, 50.65573592339793, 48.807797508855025, 48.89085369725382, 47.22719215577649, 44.19351339340211, 44.31944893252465, 44.49945826684275, 45.830267475497344, 46.2384646169601, 46.398575767394036, 44.24908161163331, 46.251333913495465, 49.27206493193104, 46.28211275223763, 47.03604721253919, 50.71875272258636, 47.45325011591758, 48.27895610563217, 47.77882645207067, 48.136891780361054, 48.67702176493984, 49.667526137444284, 49.80480909347535, 50.31352089297388, 49.21285675417993, 55.07135198962305, 49.52231607129497, 53.20824184725362, 50.65221363498319, 50.31823950429117, 53.304069272933475, 55.45918026278096, 52.579125050575506, 55.43140988196097, 53.80091982503092, 58.44726931664252, 53.84155558001611, 56.589870145243985, 60.81928737701909, 62.36620741505777, 63.84794942794308, 69.58316849124047, 77.04667798934445, 82.58872032165527, 79.48716886581914, 86.20447881760137, 24.451792855416578, 0.9116603193744537, 0.9471176877137154, 0.5682417341778355, 9.28932378368993, 86.0308119558519, 82.12620227567612, 73.25737814749442, 67.14834936203496, 47.723670082707564, 63.852338560165904, 69.06789456644367, 84.37312418414702, 16.97492572569078, 0.6558932856686654, 0.5422681053319286, 0.1853556780805511, 0.2982522475142633, 0.13830367625961382], [0.07543951242921815, 0.027179797893510233, 0.06589665393074674, 0.024835419458066745, 0.013850160082051111, 0.14404844702972522, 0.18726689891228754, 0.04977419566843779, 26.35075346116097, 59.58122261108891, 42.55624155844412, 29.890882776629542, 23.889474022773005, 54.963981028526064, 54.86538440950456, 82.23446753717239, 13.316029983182109, 0.45190972005648, 0.23986306371948413, 0.16499586493497895, 0.6626580259011638, 9.376982873485936, 54.71833082937426, 69.24837850755262, 70.41127497150053, 65.91317146055161, 71.02225472850185, 67.6053447108115, 69.49147132135207, 64.84818520084505, 64.16092318873253, 63.8754334757405, 57.367982095287694, 50.27956101202196, 48.81213957263578, 48.50365692569364, 48.39880804861746, 49.097774413324174, 50.75818038755848, 50.29068093146048, 50.58830645776565, 53.04711088057488, 56.63946067133258, 59.84388412967805, 62.02582020913402, 61.57906224650722, 58.886794428671564, 57.1190292604508, 53.91677487281061, 45.864819634345274, 44.78439100327031, 42.46359517497402, 43.73265451000583, 42.67216720888692, 45.66141336194931, 46.292279535724276, 45.509911814043605, 46.11618472683815, 44.48139967456941, 43.993362688249164, 43.13786629707583, 42.622180523410925, 43.54007005691529, 41.46305737956878, 40.87818884080456, 43.17181441091722, 45.42502387877434, 48.30511831468152, 54.26785838219428, 53.20622574898505, 51.91418132474346, 51.5981206586284, 55.364345196754705, 55.489425659179695, 54.44012103542205, 53.50031329739479, 53.61869435156546, 52.12757787396831, 56.553654901443, 56.06572774148757, 56.234876032798525, 55.536866726413855, 55.3701267703887, 57.69076178150793, 47.875528566298954, 44.64486445150068, 42.26479768753052, 41.46524606212493, 43.35087453165362, 42.409313494159335, 39.93368602568104, 35.182377830628425, 45.089414119720466, 44.66580990822085, 45.71684821959465, 55.41733249541252, 58.21756747461135, 55.24286939251808, 52.97065604117609, 52.61231614697365, 53.74812080014137, 52.56560464059153, 53.5439928116337, 52.4199435018724, 49.340804469200876, 50.04697230554397, 51.577171279538064, 47.31559453472015, 47.348934681184836, 46.119440294081166, 47.51208959087249, 45.05972177751603, 43.1032003894929, 40.72762866174021, 39.57458126929499, 38.36697370775285, 40.54434022595806, 40.367743353689875, 41.61173874332059, 39.45330942830732, 40.12168915041032, 40.98413990389916, 41.879232621962025, 43.36098247958768, 44.13545054774131, 43.55271577835084, 43.73883224302723, 42.43210246486049, 42.86172751457461, 42.91019232042375, 43.46348577930082, 41.75412078057566, 42.88599521883073, 43.22879468241046, 43.050181711873705, 43.14997857616794, 43.43933966852004, 45.01218265102756, 47.2065055754877, 45.54539749699254, 44.60605652101579, 45.677887316673036, 49.747377749412294, 49.83285796257758, 49.540943407243304, 49.83081048534763, 50.37341548550514, 48.294327874337476, 47.77945403129824, 49.83888272316226, 53.38417191659251, 53.69259572798207, 60.42624627390216, 64.696448310729, 75.3914770003288, 74.97286596605855, 84.74760070923837, 11.806690173764384, 0.858478740819039, 1.3031180106824445, 0.23628072933323924, 9.73832534205529, 74.2013200636833, 65.86441639930972, 64.1723176740831, 47.875689383476015, 53.9998467506901, 73.04124770625945, 48.18303454306818, 61.81225499799175, 11.669055185010357, 0.13050601967880804, 0.1647214675622602, 0.046381724682906945, 0.04373848385688278, 0.03215429215361515, 0.06492634994849082, 0.03296898069581197, 0.041213572971642985, 0.022917028043359038, 0.08876473853184332, 0.0866044625159233, 0.08814368637338763, 0.06774821183494023, 33.94757255431145, 68.74753890498992, 45.31866096681165, 38.3781171614124, 34.4089727247915, 61.66477780188284, 63.92548291913925, 88.98399583755001, 15.73631182793648, 0.6306284413703027, 0.15323100671652826, 0.6424467265605927, 2.1495105806858312, 9.987690025760282, 54.626296335651034, 70.26631985941242, 71.71186231797742, 66.35157477471137, 74.05580797503072, 67.7562382913405, 71.41355037689209, 66.27898739230248, 66.74416480525848, 65.34481610021284, 61.11223351570868, 53.133281430890484, 50.53758236669725, 51.57257426169611, 50.33376816780337, 49.31952561101606, 52.93097342214277, 51.75608627257809, 53.22895588413362, 54.42329406738282, 61.09132728269024, 61.41206733642086, 64.09856142536287, 63.97163352658672, 63.16359389212824, 58.59087513339136, 56.53383908733245, 48.61221244258266, 45.9164458705533, 45.840218528624504, 45.77380887923702, 45.3616972123423, 47.85198650052471, 47.1851247356784, 49.35270886267386, 46.81298202083957, 46.76879652084843, 43.76647318563154, 47.44888059554562, 44.77496162537606, 44.52769540971325, 43.25574528786444, 43.77110158243487, 44.29885256674982, 47.686839026789514, 50.42900723795737, 56.500373425022254, 54.31386778431555, 54.687500999819854, 53.67037942332607, 57.88193810370661, 57.70406646113242, 55.81321731690438, 55.27052994697325, 57.14382256231001, 54.53748210783928, 60.326504322790335, 57.702697553942286, 58.80633877169702, 57.253291991449174, 58.10022584853634, 57.49036396703413, 48.58760741449172, 43.246402202113984, 43.49930486371441, 42.56984826057188, 43.76508466659054, 42.34354319110994, 42.361554714941214, 38.37572843797746, 47.00673141787129, 43.252226921819876, 46.19656585877942, 58.09485220140027, 61.11024095166115, 57.74197224647769, 55.13142701118223, 55.464769640276515, 55.4711474141767, 55.258425512621486, 56.444071723568825, 56.026092190896314, 52.29860890296198, 52.72321724122571, 53.534892912833925, 49.005296691771484, 50.58971458865751, 49.59239313679357, 49.88124432102327, 47.2489103194206, 44.957116496178415, 44.247822530807994, 42.43560906379454, 41.90229223620507, 42.32071891907723, 44.02079574523434, 43.82439090359596, 43.209900625290416, 42.375906667401715, 43.6474370956421, 45.21510254952216, 45.40709080234651, 45.34426227692635, 45.85250731437437, 46.02635460515177, 44.52504388747677, 45.43468467650875, 44.63183826015842, 47.57108203826412, 44.95538280856225, 43.87697419812603, 45.602671946248705, 45.31556229437552, 46.91534803759667, 47.74857713330177, 48.344534212543124, 49.81191642822758, 47.72378775381273, 49.27536756761613, 49.38726102152179, 52.96078735782255, 51.776094282827074, 53.3565309739882, 54.02679735614408, 53.58383624784408, 52.92256386049333, 50.70647570394701, 53.9524958979699, 57.6019161747348, 56.724740843619074, 62.54781315403601, 68.83464690177672, 78.35619265033354, 77.19608891394832, 87.37667129885766, 12.962332214078597, 1.0810198058043758, 1.3814809605959923, 0.6891883861634039, 12.530728328612543, 84.93337200533959, 73.59295260521674, 72.26758372399115, 54.74446950420257, 41.188852325562515, 75.84720150116952, 55.701241493225105, 73.32904769528297, 15.282067041243277, 0.13458087199157284, 0.2235436289300842, 0.06587761664582838, 0.1112411989860477, 0.0481692414670702, 0.2136427545619588, 0.10444288111982808, 0.21749208591157393, 0.12686792175255476, 0.2022750056799381, 0.2787383333329232, 0.2512988412091809, 0.1850437117560256, 44.57142983713458, 79.34836403016122, 57.70108938217164, 42.350870178591826, 33.74684526074317, 74.73949278554609, 68.48632474099436, 101.41183745476508, 16.65367184146758, 1.011320084573761, 0.20485330523262102, 1.387593974509547, 2.5614442700339906, 10.965736950597456, 56.196326978745006, 73.48158867128434, 74.35903856831213, 67.98335921379828, 76.4901642645559, 71.29424756573093, 75.46251112414946, 71.0076399772398, 69.53519790403305, 69.5682321056243, 64.17121548806468, 55.06329151891894, 52.726512032170454, 53.792882888547844, 54.24485760350382, 54.346541127850934, 55.590458070078206, 53.850965346059496, 54.72215121792209, 58.62697270608718, 63.99427344722133, 63.88117582567277, 65.65705637778005, 65.84518894072502, 64.65030162565171, 60.57728498212753, 58.505230180678836, 51.2788514937124, 46.71366760807653, 46.71911578024588, 50.06472495294387, 47.54766941070557, 49.56529348127304, 48.841369075159875, 50.957781960887296, 51.14456130612282, 49.091263278838134, 48.55437709439186, 48.63250286348405, 47.20422275604741, 47.54660644838887, 46.110148199142955, 45.74999616992089, 44.960164177802305, 51.214257901714696, 53.39768840420631, 60.531330493188676, 58.048462329372285, 56.8911866218813, 57.96048356640724, 61.61141787805865, 61.97349579103532, 61.31955823590679, 58.38429566352599, 60.92323410895563, 57.0452259432885, 63.64727704755722, 60.25812564357635, 62.44816533980831, 60.08843606518161, 61.32540648983371, 62.31141190375052, 49.396572728310865, 47.07124264009538, 45.21190974020189, 42.310210889385594, 44.84491709739932, 43.75379608523461, 44.17060675159578, 39.6504516755381, 48.26031700257332, 45.324497453628055, 48.638606071472175, 59.70879770094349, 66.28360009962513, 61.779550275494984, 60.57213491009128, 59.480860925489864, 59.628844107351, 56.531014980808386, 61.02949111692367, 60.20870770177534, 54.46315319307389, 56.23880624771119, 59.19376696309736, 52.418990365920536, 53.13059068495228, 51.79327426418182, 53.205731530343336, 50.64598098877938, 48.2709466257403, 47.57121147647981, 45.59997335557015, 43.77650660853232, 44.101792689292665, 46.35155439376832, 47.42243989821404, 45.64587293132659, 44.180918662778794, 47.53166221803235, 47.16918814566828, 50.57778666096349, 48.6159896850586, 48.89161071469707, 49.15598630905152, 47.18646618627733, 49.13824542876213, 47.49853780192714, 49.39237186985631, 47.5912194867288, 48.79759542403683, 48.891642093658454, 47.94467995243688, 50.22231009698684, 49.544955991929584, 52.07328442604312, 52.92098706768405, 51.93183199051888, 52.10836610486431, 51.291097133390366, 55.60704969590711, 55.99474068610899, 55.02409527378698, 55.870236812099336, 57.43080669833768, 56.71791591951924, 51.88977633753131, 55.97217529050766, 59.59346825076688, 58.63495865175801, 65.4668684928648, 72.83242071828535, 80.7620725324077, 80.4115773785499, 88.44459149145311, 15.043742848980813, 1.1043514119040583, 2.941783022496008, 1.2762510007427585, 14.669461461805529, 94.10949814704158, 79.82736387560445, 83.3402935151131, 66.20456434065296, 71.58153764663204, 89.72337830451228, 69.38588111631333, 88.39629926989156, 22.27799569406817, 0.36074069118307484, 0.273478833297568, 0.3148356608806118, 0.2312674499567478, 0.15171501064492812], [0.06371397367348114, 0.06911944793236834, 0.07116985927906729, 0.07428091169605333, 0.05677157382090246, 0.02631453988743165, 0.02558295656326077, 0.061174449661085685, 28.717439059288274, 56.32885994449739, 45.86554135045698, 33.02425838285877, 29.343141432731386, 51.569805068354455, 52.22988113280266, 82.53699210382278, 15.855141012899338, 0.4869832170586433, 0.31375909284237896, 0.3791404070873415, 0.5737835529350466, 2.8032042134192685, 27.502096583766324, 64.89125674770725, 67.02444953303184, 74.36459264447613, 70.42264984500024, 66.11637376969861, 64.33946947897634, 60.01410715041622, 59.96589729862829, 53.482497892072125, 48.2468750399928, 47.0702620475523, 47.89862348187355, 46.87461814572735, 49.663882255554206, 49.62834558179302, 52.031675923255186, 53.775769587486025, 56.20053960431007, 57.44822986664311, 58.30503240708382, 59.67983491959111, 63.018034735033595, 59.51574256343227, 57.23447638173258, 54.11800422976094, 45.13701600413169, 43.77028180706886, 45.131403092415106, 44.1492102223058, 44.9227173097672, 49.782573176968484, 52.606581641781716, 55.47116310365739, 54.67369033444313, 51.75402702823762, 46.84965618195073, 44.0105152130127, 43.76734395180979, 42.74893583789949, 45.112418820781095, 41.3325209002341, 42.17131583921371, 43.066800794293805, 43.8946170191611, 44.277456037459835, 49.10406589508057, 49.57372657714352, 48.61342837733608, 52.13463029553814, 52.373322210004254, 53.47783811630742, 54.77857059048068, 52.47867315046249, 55.215534394787205, 55.077043348743075, 53.02926017392067, 54.47850927229851, 55.61292932879541, 56.27465671108615, 55.70599148350378, 58.495718433010964, 55.306811871067175, 47.17254177216561, 44.4878911972046, 44.48327064514161, 47.899808037665586, 42.67914510542347, 38.60333965670678, 41.662568738383634, 46.54632360704484, 40.57384821676439, 49.696477151686146, 53.36168496839462, 55.43283762470369, 53.498681591403106, 53.06368681692308, 52.490075480553415, 52.078332516454886, 52.21962805717222, 50.20625975824172, 52.64854708025533, 52.206801906708755, 50.62658094590711, 50.96565415782314, 49.81304607083721, 49.417875120716715, 48.40177336046773, 47.754601893886445, 44.70865003524288, 42.19973733348232, 42.48170083568942, 41.07141656260337, 37.292142298913774, 39.92332704605595, 42.441637746749386, 43.07472398204189, 40.355991932653616, 41.45132557038338, 41.54169697915354, 43.1568701805607, 43.863214523561545, 43.20437400571762, 41.11873995873236, 42.385371346627515, 44.29512239271595, 42.67679560569025, 44.28453591562087, 43.930679290525376, 43.50042273921352, 44.10763309847924, 43.14168276325349, 42.54653369226764, 41.91148234951881, 43.73040306952692, 44.13237933189639, 45.43704594335249, 46.351789735978656, 46.03727840608167, 46.54463306550057, 50.9202644901891, 50.86668883600543, 51.56958149325464, 51.78023630572904, 50.28738221814556, 49.04314364156416, 50.30125171907487, 50.37407836606426, 53.904772420083326, 54.134842964910696, 57.4701637606467, 67.57200456434681, 72.61028905068675, 75.6046970428959, 81.39590401803294, 10.251985211526195, 0.9780928288255969, 1.0521197823747512, 0.2097764467039416, 19.440823754956646, 74.8190619868617, 67.64340739096365, 62.272552982453384, 50.79473295519429, 40.091369228978316, 34.48406257937032, 51.26015747747114, 55.2071052212869, 15.890487451707164, 0.23026517712541167, 0.22646202555587217, 0.035732558612982114, 0.1029873906724876, 0.030220312764868144, 0.030405909055843953, 0.03608976242943637, 0.04858640698535789, 0.03625186663421412, 0.046004591089102535, 0.030912452137037635, 0.10928331573884334, 0.03900928137403342, 38.24856519699097, 62.52756195683634, 54.662542958413404, 33.9100472388729, 32.08209526154303, 61.16681329665646, 55.09596486245432, 91.18121347119732, 16.701158015958725, 0.5024059152891559, 0.33668798184202564, 0.41208270877119035, 1.648667791197377, 3.00948215107764, 28.900225431688373, 63.74121389081402, 68.91805218112084, 73.67252965127268, 73.58462933571109, 68.78065939872496, 67.35471310154085, 64.09194830925234, 60.94844710442328, 56.21348734824889, 51.73812573955905, 48.99717738551479, 49.40905763256935, 49.99629136054747, 51.22755081422868, 52.66553486547163, 55.556188321882686, 55.88827971489199, 56.9918111062819, 58.975894989505896, 61.60619328098913, 61.034460759932, 65.18860770810035, 61.65983169309555, 59.053895242752574, 56.94041236754387, 47.31664572992633, 45.96466748945175, 45.41519834149269, 45.64343321707941, 48.439290831165934, 52.24676693639448, 55.02433061599732, 57.467567151592625, 57.095345989350356, 54.3689888523471, 47.91071222674462, 44.814063733623875, 46.95837251601681, 45.741480704276796, 45.33492311354607, 42.77248574841408, 44.84861589247181, 44.355899518535985, 45.97425768452306, 45.65354900975382, 51.300455908621515, 53.070166572447754, 52.1619809827497, 53.762221720910844, 55.12044829706992, 56.323855000157515, 57.83366157162575, 55.66429276620188, 58.76332213801723, 54.698769969324914, 55.15933467495827, 56.90420496848322, 57.07789144208355, 55.55707085517145, 59.90314722061158, 58.951811636647875, 57.41872579820695, 46.88013692055979, 43.871808436609086, 45.92153318466679, 46.53627449466337, 43.27340379838021, 40.88222495971188, 43.02341153544765, 47.54470017648513, 41.12859687497539, 51.71303825993692, 56.9421931236021, 56.29617483385148, 57.54753251229563, 56.520730526216575, 55.40646360766504, 57.10040584687264, 54.8965907865955, 54.00891527052849, 55.31566858291627, 54.08731952790291, 52.68918283524052, 53.108566576434725, 52.42220670946183, 52.9881105884429, 49.71242550880679, 50.27493261521863, 48.14328524374193, 44.80259472324003, 44.68278200395646, 43.51331556996992, 41.78639404235348, 41.41694207345286, 45.20299419280022, 46.5642096150306, 44.13889046638243, 44.88125001230548, 43.70070288258214, 46.98087123132522, 47.11560464674427, 46.34429408657936, 42.785202072512725, 45.129461519179806, 47.04653170800979, 45.78342260852937, 45.6815900341157, 46.247235036665394, 45.838645658185406, 45.34446231780514, 44.65214044817033, 46.1962991376077, 43.65319121268488, 45.97432828718617, 47.330362258418916, 48.94287217047907, 50.21663442734749, 47.94736677600492, 50.23947046649072, 52.647064424330196, 54.40882052144697, 56.25757871135589, 54.47387695312501, 53.74068790866483, 53.146825375095496, 53.412075657998365, 52.79442787170411, 56.29961867486277, 56.90132202640657, 60.054036878770404, 71.02538477989935, 76.57691140328684, 79.21315993032148, 82.65011325959237, 11.599085984691499, 1.1408908641146076, 1.5612064133728705, 0.2691687613485321, 23.85248803323315, 84.69051453375047, 73.38960124600318, 70.761762280618, 57.94322906001922, 44.15330517676569, 51.26973198306177, 58.63229144004084, 69.65901928563272, 22.08095738964696, 0.24599953524528012, 0.2920461692396672, 0.03577566638048138, 0.032566700265893055, 0.08865206998081938, 0.10110986238766102, 0.24208620491047061, 0.20041580221826033, 0.0984207941820064, 0.0834758973289882, 0.1462972521661751, 0.19418133272519036, 0.18126642331480983, 49.21500229066419, 72.12488005238195, 64.1687326277456, 46.72744297212171, 39.41275604309575, 70.82195497328236, 61.31289020661385, 102.0270690610332, 17.66836154845453, 0.9042732705993037, 0.8280713015025662, 1.6104777565886899, 2.472951431428233, 3.840774331362017, 31.610938195259344, 66.59490293072116, 71.21403509570708, 77.56021038178476, 76.79192004665252, 72.6356432514806, 70.66986114748063, 67.13272263926845, 65.72130480120259, 58.364068000547356, 53.601196658226755, 50.38634361759309, 51.85070560824487, 52.51322138694025, 54.427545916649606, 55.14191150665284, 57.65434649682815, 58.057856405934984, 60.76235809633809, 61.4230146715718, 66.5573658481721, 63.14425268480855, 68.39313707044049, 65.6416924538151, 62.61228123018819, 59.88977586069415, 50.30753927846109, 48.513827631550456, 49.02384950268654, 47.94504865523308, 50.9923105855142, 56.25691975316694, 58.03093717944238, 59.95080401820522, 57.76619680466191, 57.263113606360655, 50.88370015544277, 46.98929648245535, 49.554918812167266, 48.4483632733745, 49.63348388671876, 45.01175511267878, 46.79377417410574, 47.55009735784223, 47.838834793336936, 49.4169415966157, 54.339727970861624, 53.16327187322801, 53.84975333367625, 58.31740748497748, 57.96213096187961, 60.75886326451456, 59.58823188658684, 56.89346159658125, 63.07377945992255, 58.862420820420795, 59.21934866136121, 60.19433613746398, 62.81098850311772, 58.9909412014869, 60.01922192112092, 61.93972810622185, 62.20818688792568, 49.57971211402647, 46.25916688672958, 49.22374917614845, 48.575032295719275, 43.50864010472452, 42.24104773613715, 46.02435027399371, 49.82115753235356, 42.453510761260986, 52.48216798228603, 57.530034818956935, 59.47882129300026, 60.16021936170517, 59.34030671273509, 59.63319793824227, 59.61681812040268, 59.37805952564363, 56.14292390884892, 58.17140117768319, 58.98648931134132, 56.280783453295314, 57.022895889897505, 55.05127729908113, 55.91836037174348, 52.41824119321762, 50.93595397087836, 51.2140304042447, 46.271388992186516, 47.97173646188552, 45.98378119930145, 42.58320000863845, 44.67168561873898, 48.07911526772284, 50.38161716153545, 44.24233905730709, 46.5376865479254, 43.84889395006242, 48.87166546237085, 50.84784184732745, 50.74487178556381, 45.29516596947947, 47.54584550857545, 50.397039921053, 47.85807009666197, 50.38163285101614, 50.276250531596524, 49.56755668886247, 48.37918050827519, 48.033325518331225, 49.731668656872166, 47.04688864369547, 48.9757533996336, 51.65638354516799, 52.31602422652706, 53.256487000373106, 49.23111538733206, 52.73149344228929, 57.511011323621204, 58.89395275423604, 57.49590627608761, 59.727907488423014, 55.541287237598056, 56.41282612277616, 54.8925389782075, 57.04659485047864, 58.37608222038516, 60.21192404531664, 63.777601718902595, 76.74333756969821, 78.908948744497, 82.22840355288598, 84.5768520908971, 14.075462625872705, 1.371721123014727, 2.593642516482261, 0.6053628616275326, 27.14023832351931, 91.30251669114637, 81.57635658018052, 79.90097107425814, 70.6849701173844, 53.729697427442, 51.00608987192954, 73.74953362249559, 82.61292134561847, 26.920175706186605, 0.36677403195250424, 0.3900366288519675, 0.23168020280859164, 0.1523724673015456, 0.1625060178940335], [0.07132637870287703, 0.04548035329207779, 0.09094142415110143, 0.05186760753032662, 0.04325489468512036, 0.05641552296677425, 0.07610770197765482, 0.34210728781838573, 30.034704323737856, 58.053396671049065, 38.67046317746563, 50.36447248151226, 38.313245081132465, 48.66256783085485, 52.14398907076929, 79.34935246744465, 23.139103035773, 0.3962387847563913, 0.6499151645168182, 0.2481828551859625, 1.2069576738342163, 0.5459971761991901, 11.93044585566367, 50.48478726417788, 68.76718997955322, 65.60929759856194, 65.5728901586225, 63.26746217666134, 61.143973335143066, 55.97700372818978, 52.84304172761979, 48.17813550272296, 48.10527747677219, 46.70561498211276, 47.94802965656404, 50.489490186014486, 54.83211486570297, 54.049076418722834, 56.16103741430468, 56.49966739839124, 58.914604033193285, 59.759055029961374, 59.64122310761483, 59.52948654851606, 59.4648458880763, 59.12049316590833, 54.2297133322685, 46.398218831708355, 44.060144962803015, 43.636085756363414, 44.308132894577525, 44.1361879533337, 48.875348567962654, 54.65345874909432, 56.22003378406648, 58.447343841675796, 59.0964529591222, 56.260226311222205, 50.86853627235659, 44.353938333449825, 42.59160564791772, 43.266778915159165, 44.63828663672171, 40.80284403216454, 41.94794862501083, 42.18250243894516, 43.97855181847849, 43.534088442402506, 46.53396814100204, 52.41449532970306, 48.33486164769819, 50.45649913049514, 50.37918136965845, 51.1525825531252, 51.55741822335028, 53.15545458947459, 51.62898578951436, 53.51262169499552, 52.93473497513802, 53.37485628743326, 52.46696487549813, 53.71418053104032, 54.33293834809334, 55.2703102942436, 55.12196233195644, 50.7106569505507, 43.91990061729185, 46.70483835281865, 44.85643317622524, 45.10876709415067, 37.00860984863774, 44.64189129491007, 47.97592947559972, 43.010314741442286, 55.80636493621334, 57.44029883415469, 57.39008072883853, 52.301025082988126, 54.38364674968105, 54.00445553564257, 54.29288310389365, 50.24865273506411, 51.65628156354351, 51.78831246591384, 54.31264008245161, 50.35501956939698, 49.65053835222798, 49.992082657352576, 49.59304817261235, 49.19176616976338, 47.50667279766452, 45.67110161627493, 41.84686914567025, 42.09082488090762, 40.92190365637503, 41.02279486194734, 42.02441130914996, 41.25881171995594, 43.967388752968084, 40.11676265347389, 41.927846477877715, 42.86987819979268, 43.65025727979599, 41.92693256562756, 41.48477946558307, 42.66837819930046, 42.26669219232375, 42.610001564025886, 44.3701651788527, 46.248227396318995, 47.19982577908424, 44.16125974347515, 43.462815054001354, 42.35325890202677, 42.80162895879438, 43.38705839649324, 43.5165201464007, 44.36763525009156, 41.973879414220015, 43.37994713937083, 45.220397749254786, 47.92663704964423, 51.65741905089348, 52.65359909303727, 53.667104244232185, 52.018665421393614, 52.658588347896455, 50.82470770805113, 51.344045208346465, 51.411435450277025, 52.44374836644819, 56.84805231709635, 64.87648510163831, 68.61922248717278, 73.50946103372883, 73.0615734284924, 80.37163196071502, 9.172727407947663, 0.9369191575434901, 1.5970652117844553, 0.10757575938177687, 31.8213733550041, 75.80352983167096, 64.7698986145758, 63.39939109740719, 49.707957929180516, 33.60671466396701, 32.72021782013678, 53.606899784457305, 53.4146918789033, 15.025651897153548, 0.1968523442384697, 0.19382024484296, 0.11363659504680865, 0.06085578389766236, 0.01215279556720728, 0.02265012109531991, 0.05472465966557784, 0.05674489863937902, 0.01677143432560467, 0.035604786638531, 0.045206227880572124, 0.016336528126210455, 0.30171570037641837, 39.21840652342766, 68.03544828968664, 49.05787998630155, 54.450546695340066, 41.323974055628625, 56.015286061071585, 57.021542672188055, 90.33600545698597, 24.02397797953698, 0.3318391049340848, 0.7201920870331027, 0.3343372870116465, 0.20007915254081451, 0.8884079574096588, 12.747560874108347, 54.19509841549782, 73.32365051392587, 67.19063251249253, 67.55021972040977, 67.27756792499174, 64.06005551738124, 56.77994428142425, 55.55829855703539, 50.52453264113396, 50.975075690977036, 49.33406975961501, 51.55133854958319, 53.79571091744208, 57.10126092357021, 56.59962507986254, 61.139878380683164, 59.05771955367058, 62.03726176292666, 60.8211701147018, 64.52396600477158, 62.03982699301935, 62.7706390811551, 61.304931717534224, 57.4551175486657, 48.02590047159503, 46.488531404925936, 45.96345547706851, 46.8053843898158, 46.17874260871641, 51.68354988098145, 57.03416878177274, 60.44468141371205, 59.77608988361975, 59.82021262568813, 58.89652975143925, 52.7169139923588, 47.28197197760306, 44.58027085950298, 46.78301903509325, 46.88386317222349, 42.55827334619338, 43.773862931036184, 42.82507296531431, 45.69036437619118, 45.993340015411384, 47.243379777477635, 54.639004815009336, 51.32602976214502, 51.97664506973759, 52.77477287477063, 54.171677943198915, 54.50817808028191, 57.1413161677699, 55.45587762709587, 56.53400774924987, 54.83903000431677, 54.51767806083926, 57.05883264541627, 57.908292508894405, 56.94051042679818, 57.38975517211422, 57.2378731543018, 54.44324716444939, 43.1746659740325, 48.530713435142275, 44.021709657484486, 45.39719858477193, 38.407825193097516, 47.8383013509935, 48.25547287541051, 44.2708311542388, 55.97999649663126, 58.89587471562048, 59.62484721214541, 54.06048267118393, 56.04995589102469, 56.23572718712592, 57.9256489969069, 53.44720440526163, 53.860681056976325, 53.62655478139078, 55.616451617210146, 53.76479871811406, 52.62165531035393, 52.661934129653446, 52.98250159909649, 52.04534146093553, 48.9528428354571, 47.239225987465154, 44.660047946437714, 44.288187642251295, 42.1937596413397, 43.339103498766505, 43.24037744152931, 45.63826745556247, 46.24473256449546, 43.84322220279325, 44.78031566066127, 45.11572930120653, 46.51985153075188, 43.92419561263054, 45.04998645474834, 45.677675508683734, 45.17353719280612, 45.25503620024651, 47.79777542237313, 50.925798954502234, 49.16192869986258, 48.024892422460745, 46.40580077325144, 45.97753678598712, 45.754267631038545, 46.63460831488333, 45.99019427453318, 47.784333459792606, 45.70152351933141, 46.88563216117121, 48.44389569374823, 50.48427343368531, 55.24982767720377, 55.761143930496715, 57.53971915091238, 55.54082832028789, 56.250687106963134, 54.408859745148696, 55.48045127622543, 53.8864706408593, 56.176770041065836, 58.047014974778705, 66.90070659883561, 72.12849647768083, 75.56997622213056, 76.90168365355461, 86.27046092864006, 9.853172340700704, 1.2286988814030926, 2.1588999994339484, 0.36344240750035933, 35.7817473719197, 81.8408969140822, 71.98052898530038, 73.90667946107926, 59.61939903997607, 38.65367151075794, 38.177770337750836, 68.3598675266389, 66.32080770307972, 21.0384855347295, 0.15333813645185965, 0.18676486617374807, 0.08123593284718453, 0.13702069349106283, 0.02134587555643051, 0.10202060303380413, 0.17610777109380693, 0.1721050076547169, 0.08528884440179794, 0.14645848303071915, 0.12612677765108887, 0.08916169465068849, 0.43421269063988044, 49.54396363227598, 79.62788781812115, 54.753538024040964, 65.88583254045056, 51.4816851000632, 67.64423108869984, 63.25460072486632, 97.21978864362164, 26.993141597317113, 0.854429567773496, 1.5337135402425643, 0.9578868614569788, 5.002598272215936, 1.1990594911959864, 16.882167554670765, 58.64985973604264, 76.20814584916639, 70.62944504522508, 71.97842659488802, 69.94020615854572, 66.60554039862849, 61.267437781057055, 58.729479928170484, 51.827155697730284, 53.302037485184215, 52.300617156490205, 54.86843993586879, 55.26148888372607, 60.800483534413004, 59.546666529870805, 61.870400213426166, 62.148162857178725, 63.46740107382498, 63.24652848705169, 66.06852085359635, 63.31724882125855, 64.76759618328464, 66.20940454544561, 60.381539098678104, 50.6905940271193, 50.327696338776626, 48.51870706004482, 49.599237672744266, 47.62333977606989, 53.65536459030644, 59.67697943410566, 63.166967130476436, 63.13592157056255, 63.19604366056381, 60.69692903949369, 55.68088046966061, 50.04312053803475, 46.60394322487616, 48.07122345893614, 50.13443331564627, 45.26617180916571, 46.48762533741613, 46.4303469657898, 48.596122880135816, 48.45489794208158, 50.383535200549716, 58.72036041751985, 54.793863911782545, 56.50572746030746, 55.69032553703555, 56.82262359126922, 57.798736787611446, 59.752045754463445, 55.88693041955271, 58.471591934081054, 57.58131980895997, 59.16873831902782, 58.04732876439249, 59.44318655998477, 60.243279472474136, 61.750454133556744, 59.71138646525722, 56.82841300964356, 44.78345747916929, 49.468363869574766, 46.022828394366854, 46.372421403085035, 40.75064512991136, 47.38718955747543, 49.98586962299962, 45.16963835685484, 58.63386038810977, 62.77544006224602, 63.41696331577917, 54.90174478100192, 60.25492891188591, 58.517056126748365, 61.524980606571326, 55.44533429607269, 57.79735611331079, 56.88330658020512, 59.98425399103473, 55.56788482973653, 54.703257160802046, 56.24374843412831, 54.936967665149325, 55.29983397453062, 52.536092727415024, 52.28724187420261, 47.13235316738006, 47.03604329016901, 44.3352403948384, 46.4435653532705, 45.54377755811138, 48.07790717770977, 49.55382839325936, 46.776731475707024, 47.77026391798451, 46.8962029487856, 49.26983702567316, 47.148607469374134, 47.61981356528498, 49.38287581166914, 47.397270048818285, 48.75006021991853, 50.384998244623986, 53.77693845379738, 53.06732285407282, 50.00257891993369, 49.036977675653276, 47.12204125619704, 48.40872380041307, 49.67962664942588, 48.65844149743357, 52.60926062060941, 47.90798225710469, 50.144196095005164, 50.80689230272847, 53.546405069289676, 59.52297541403002, 60.09745359420777, 59.84153462994484, 59.183309924217966, 60.854945644255615, 56.36848372797812, 57.846322982541984, 56.81259409073861, 58.809739466636415, 61.99055025654455, 70.23151274650328, 76.59304803417575, 79.3899646882088, 78.21732505675286, 83.26776104588663, 12.872983563330866, 1.3156360099392554, 3.0419836457698577, 0.6232849676762858, 39.32047444005167, 90.76330846355808, 80.92047352944651, 82.40583589000087, 69.79936953513854, 52.23624713959233, 53.86457204818726, 76.0646027903403, 84.38045117162889, 31.308752913628858, 0.4830151880460401, 0.3349580940219664, 0.20411945428819428, 0.19554113879078822, 0.132270825786456], [0.04004098730342042, 0.049514905549585826, 0.032732232714131955, 0.03971870560499449, 0.10200885124504568, 0.012176094216204459, 0.05872442770088392, 0.25676763646544953, 37.559816606583134, 60.3046331867095, 45.0587058836414, 25.93662569599767, 24.746164775663807, 51.440155044678725, 47.12972910173478, 80.73269397981706, 34.02917354337631, 0.21114923029897675, 0.24506109285979505, 0.10624921685385127, 0.726187123406318, 0.263119210158625, 6.163045706287508, 58.04750919342042, 66.67852786279494, 67.17431545257568, 62.66653937678184, 59.78182438881167, 54.076258444016986, 51.90894103819325, 49.385856813000096, 48.32453796940465, 48.50421390225811, 51.69592888124528, 53.84830597908267, 55.64020941334387, 59.20334931342833, 60.440511934218875, 59.41993474960328, 60.80498641537082, 60.01560549582205, 62.62730390794816, 60.921053271139826, 60.16407897395473, 59.24971565123528, 56.92975528778569, 47.499032020568855, 44.51261781877087, 44.259875974347516, 43.534072752921816, 43.69220310641874, 51.23976507494527, 55.78254830452704, 56.88479315850043, 59.11771612782633, 57.234947066153254, 56.312021209347634, 58.962719748097086, 51.50274430551837, 44.692599696497766, 43.902689256975734, 44.55090407402285, 45.18980326191072, 42.85854254999469, 42.99337010229788, 42.636053946710405, 44.20815167888519, 43.79835028802195, 45.669387540509625, 46.67256116867066, 48.06207256932413, 48.28840509537728, 50.49212209640011, 51.57985025836576, 51.53175023294265, 52.71885164322392, 55.3102792462995, 53.56078055597121, 50.42581835100728, 53.81720942835654, 54.285328618941776, 55.11347824527372, 55.36172113110943, 58.47566335431991, 57.40505633815643, 51.52836522748394, 46.60675556428971, 45.920713409300774, 44.4447333581986, 41.9216138316739, 40.33027295143374, 46.717323257077126, 45.70012715555007, 49.474443543341856, 56.6109371954395, 56.15184730099094, 55.53589397861112, 54.659483509679, 52.564184742589156, 51.771779675637525, 53.01870899815714, 54.22806201442596, 50.02684662418981, 52.17756848181448, 52.11597158062843, 50.658646322065785, 50.38718300480997, 50.59388799052085, 48.76739317371, 46.11028940446916, 46.407934542625185, 43.51333518182078, 42.88865066343739, 39.983335387322214, 40.802236064787834, 41.43665590593892, 42.978712204963934, 41.39469046746531, 43.26186418533326, 41.80956740533152, 43.69583914356847, 46.60237819917741, 48.17275008847637, 48.84820184400005, 43.71756515195293, 42.35573783997567, 43.46054400167158, 43.97408031648205, 46.37186442652057, 48.2941396005692, 49.36734714815694, 48.49720462676018, 48.555471435669936, 44.99939180189564, 44.70430797146213, 42.13232747970089, 44.41907321253131, 44.84819619886337, 45.27862141209264, 43.44674510340537, 46.26383450723464, 45.85568051184378, 48.60603470956126, 51.28165206601543, 54.146343354255926, 56.10145268901702, 56.65806839543005, 53.457002485952074, 56.16610511656731, 57.41814920979162, 62.7756832491967, 63.39310746039114, 68.08615669127434, 68.74915492150092, 74.09961300511515, 80.11247311868976, 83.02627640385782, 7.3565204778025235, 1.0355346529714524, 1.5512971580028536, 0.18717213383605405, 39.05110174609769, 74.30264272997456, 66.44825335471862, 51.87413784765428, 50.069902481571326, 32.081332360544515, 41.785758618385564, 53.308885943505075, 52.64577788691367, 23.710151103235063, 0.21083920983777893, 0.1314244671694694, 0.06688604116319649, 0.07616172649807508, 0.040242173483655344, 0.05604084851520677, 0.0556493507728221, 0.04236318749345599, 0.02491289009940961, 0.062452023848891265, 0.02099893157250218, 0.08469119622942903, 0.2770704067041797, 47.110344748343195, 70.95628830694383, 51.438178170111875, 28.81357046865648, 33.609970231210035, 58.905531590984715, 52.48065002502934, 84.32980552796396, 38.01712966734363, 0.25465573124106855, 0.5722933587047362, 0.138443487305795, 0.6621036846791545, 0.1354746514510724, 6.6534640615986245, 63.07949435326361, 69.98705494788386, 67.88326817174112, 65.49345431789276, 64.22084523785499, 56.3510174136008, 54.32074762159779, 54.038768429909986, 51.61528495050246, 50.91052916742141, 54.354668278847974, 55.55428597234911, 59.207965943121145, 61.0816547178453, 61.89207130862821, 62.933370374864154, 63.11839642063264, 62.1175056119119, 64.98990043517082, 61.804433791868156, 63.188665682269686, 61.910286795708444, 59.219823268152055, 48.58972941675494, 46.94746832693777, 45.6819587369119, 44.81496587876351, 45.75886072651033, 52.20945735131541, 58.69331567518173, 58.480487869631865, 61.97140516773347, 59.95065889050884, 58.989089842765566, 62.03704603256718, 53.97368846401092, 47.285521722609, 45.680817327191754, 47.05270159629084, 48.51932679453204, 45.028605614939046, 43.1480723042642, 43.66780596394693, 47.25315432394705, 43.26923039651687, 46.412480569654896, 49.3887750564083, 49.707903015998106, 51.263263994647616, 51.11487288628855, 53.10627591225409, 53.61483081694573, 55.57776135783042, 58.55252612021662, 54.4137470183834, 53.057705202410304, 55.0976828605898, 57.18359147348712, 55.62273917659637, 56.547155534067464, 57.40608792151175, 59.45835044307094, 54.86760839339226, 46.85271563068513, 44.97757165662704, 45.80060651225429, 42.52268960399013, 41.76399730866955, 49.6227091358554, 46.65387891953992, 51.56818905184346, 59.30178511527277, 59.29239103871008, 57.98020132126347, 54.61922430223035, 54.39369586206252, 53.81418920332386, 54.07746261165988, 55.61851478392079, 52.70728457358576, 53.55737201629147, 55.90629516109344, 53.00786364463068, 50.53319323447443, 52.12492635173183, 52.02089725002166, 46.99708630961757, 48.120790450803696, 46.21875470684421, 44.69711826693627, 42.91970406809161, 43.455240957198605, 42.097088906072806, 44.89134227075885, 43.181039825562515, 46.13900899887086, 45.2146710888032, 47.18728596164335, 49.25513598226732, 52.29008559257754, 50.626875123670025, 44.65135989650604, 45.711690302818056, 45.63770263425766, 47.052136774986025, 49.14476048561835, 52.430726097476104, 52.88785872920867, 50.77248919394709, 50.304271944107555, 46.947825262623454, 46.7811559092614, 45.93162544312016, 46.72841964229461, 48.28902482986451, 48.010238447496974, 47.341768510880016, 49.87248959079866, 48.94770060816119, 51.13268044687087, 54.508684066034135, 57.5715805638221, 58.6989168197878, 59.45861716424266, 56.75133451338738, 58.120751611648075, 60.757215869042184, 66.32773460880404, 66.6346679195281, 72.04565601964151, 73.68132360519903, 76.99607941412157, 82.66343362869756, 90.76010780949747, 7.60669267946674, 1.34843903683847, 2.4059867666613672, 0.16528071174698492, 43.34309647160192, 79.63876062823881, 71.4590028024489, 64.8837257969764, 58.306613122263265, 38.96574704877792, 57.05472984621602, 66.62492475202008, 64.86658111695321, 32.71598362153576, 0.24275244093470036, 0.18627881402930907, 0.02752847515136725, 0.03045813135442234, 0.0050013734125382, 0.1309730268774494, 0.15754431155660462, 0.18798172023267518, 0.16375795877989263, 0.186265560708219, 0.1520402915775776, 0.2336387678740486, 0.5434645508085528, 58.3318418072116, 78.85052111841019, 62.77012132829236, 35.60436602561705, 35.29894674977949, 72.18839107021209, 60.00412471832768, 93.53078380707773, 42.165373448402654, 0.5980652919219387, 0.9830869866474983, 0.46632023227791636, 3.8585958653880708, 1.0701217454287315, 9.353199581946097, 67.66498042691138, 73.19305127666843, 70.99088361186367, 68.5012532818702, 68.26096888511412, 59.58454093625469, 57.98970914656117, 56.61030177147158, 53.233148897847826, 52.864253905511674, 55.94312229464131, 58.18160326250138, 61.94516451128068, 64.5325638401893, 66.0362397470782, 65.17675430543962, 66.57097647267004, 65.59290209124165, 67.18308587228098, 64.37039344541489, 67.04784254873952, 65.76196409040882, 63.89164463166268, 52.16542874613116, 49.457596963451756, 48.38934729176183, 46.627469601169715, 47.022432665671076, 56.63728767825712, 61.84351628826511, 62.603534344703924, 64.44607557788973, 60.96854532918623, 60.569502999705655, 63.98011369089927, 55.680939305213194, 47.577616706971206, 48.78063901778191, 49.322102608219275, 51.17661099280081, 49.290633432326786, 44.825152274101015, 47.800544615714784, 48.57979797547864, 46.45952939987183, 50.88601043147426, 51.61070754451137, 54.07183401046261, 53.955084662283625, 55.12802631624284, 58.1619639550486, 56.5648611130253, 57.38644469168879, 62.50035247495098, 57.036016218123905, 56.220045551177, 58.90933629005187, 57.97845978890696, 58.132930571033114, 60.031789195153024, 61.89362064484627, 62.472319295329434, 57.21378587907361, 48.505661256851695, 45.355947017669685, 46.20990976210564, 43.29094463779081, 44.16816311497843, 49.62191289471042, 46.67096084164035, 52.29097204823648, 61.383230070913996, 61.35998610527285, 59.81054790558354, 58.88384088393181, 57.99359229303176, 57.22782011955016, 57.752366527434326, 60.1426745999244, 54.86311727954496, 57.45994598634782, 58.254178877799745, 57.09464780745968, 54.05628573509955, 56.30305074876355, 56.47530947962115, 50.183451175689704, 50.61610821754702, 48.463821334223596, 46.904749793391076, 44.02219603138585, 46.840924985947154, 46.01537981340962, 45.711604010674264, 46.50311085485643, 48.577173909833355, 48.26636529737904, 49.87762397335422, 50.63089555309665, 53.17870639985608, 52.62860575029927, 47.27267596029466, 49.943629618613954, 50.30348747007309, 50.33527043557937, 52.2560590313327, 56.03205811592841, 56.189431451982074, 55.36185449169528, 52.6694493909036, 49.62172069857198, 50.21929379432432, 46.23694273733324, 50.515468043665734, 51.26162836628576, 51.6433612761959, 50.137453540678955, 52.698235665598226, 52.05612405653923, 56.350899742495635, 57.88298929891279, 61.652814572857274, 61.47100487063008, 63.80594084339758, 58.784016563046364, 62.01834809395575, 64.68699932098389, 69.2025181554979, 71.10447545205393, 75.81422221276068, 76.2922336209205, 81.63833787364345, 84.9696147057318, 82.26277136033582, 9.415789823378287, 1.4542827250496035, 3.2641158036647306, 0.7344017310007926, 46.89256691163587, 87.66403198242189, 77.5914167588757, 71.83506396508986, 68.39777331198415, 47.77675936298986, 65.47455241603237, 75.32562040513562, 83.74600779625678, 41.75198308883175, 0.3428052552044392, 0.42580941091141394, 0.1472226863787059, 0.1313685733945139, 0.1766463462263346], [0.038158644155989734, 0.07509029890981413, 0.1700526887490865, 0.028103403071121826, 0.045335110682513446, 0.046472720606552984, 0.03785493242884836, 0.12053160853083096, 32.7624225231909, 62.88711386342203, 51.142462838080625, 46.71342442112584, 27.828724115125596, 48.18650976304085, 50.927203163023925, 72.61792198304208, 48.00805760968117, 0.3338686863501226, 0.1845426749317877, 0.009255313141752155, 0.02379377736830183, 0.06238511372958461, 5.830078644137229, 61.25664341834284, 63.57076337260585, 65.29875570727934, 59.36491958556637, 54.7225042312376, 49.84723737162929, 51.33704769995905, 49.40321722338277, 52.766606500071866, 54.52297326057188, 60.20301242028514, 59.25970985043434, 59.90164887520575, 61.69405829521918, 64.68594420340754, 64.7734405148414, 62.28679118617889, 59.27583079184256, 60.418209337419086, 58.84912398553664, 59.76187521411527, 54.60349559783936, 47.649309788980794, 45.896943846056544, 44.017587246433386, 44.32284962746405, 45.22654802568498, 49.023425886707926, 52.5570656407264, 55.100487355263006, 59.50993745557724, 58.049372319252264, 54.94638527593305, 60.59875211408062, 57.90850431688371, 50.26187112254482, 47.262921025676114, 41.5651802093752, 43.04673787086241, 44.70639075002363, 41.63018172787082, 41.477295583294286, 43.90730980903872, 42.76991659595121, 46.2258267402649, 43.514049053192146, 43.974927548439275, 48.49855784446963, 45.22345719798919, 48.435399839955, 51.09770467204433, 49.7326414046749, 52.8916948072372, 51.36939156439997, 50.37500404542493, 48.51107412768949, 53.39669604455271, 53.82573273874099, 53.20000486989176, 57.20476442767728, 55.620122955691436, 59.695759742490715, 54.94665199710477, 47.50442135718561, 48.02664964429794, 46.622547026603456, 48.930026408164736, 43.981666180395315, 43.78266080733269, 47.106226259662265, 57.173185425419966, 57.88596637787358, 58.10309702350248, 55.266913521674375, 54.992480970198116, 50.63945024244247, 52.117395401000984, 50.56631765057964, 53.95291951394851, 50.97162792759558, 52.38125324249268, 48.6975710622726, 46.386753743694676, 46.32736121454547, 47.48065571631155, 45.9757677970394, 46.72515623031124, 43.04316459163543, 40.81272448262861, 40.261811902446134, 42.708719776522734, 41.013047772069136, 40.329786577532374, 42.3974444020179, 39.555691134545114, 41.905528191597234, 42.22107502721971, 47.434422739090465, 53.63012021587741, 58.05522057317919, 53.87559390837147, 53.9141272729443, 46.533744565902225, 44.080811931240945, 42.52203064580118, 48.49054836457776, 47.28940094670942, 53.512229457978286, 53.96321965802101, 50.95323985622775, 48.3906416739187, 47.555925999918294, 46.939925609096406, 43.677698181521514, 43.84543049720026, 46.57068152581492, 43.72078149549423, 46.51924748574534, 46.34206225795131, 48.57728373619818, 52.91329137740597, 55.84327443953484, 56.00926522285708, 58.71409246998449, 58.70987592204925, 62.70088365001064, 63.759296017308394, 65.58471610469203, 63.96524006320585, 73.79597448533582, 68.98505410840436, 79.2943137691867, 66.70435274800947, 48.86221647262574, 8.844325004085418, 0.8979346591138071, 2.0374655026581983, 0.16494413867833155, 53.35455409942135, 70.71910258262389, 70.3681916575278, 50.81432127183484, 51.10938941278766, 35.05885454916185, 27.084717173730176, 48.39317552505001, 61.99490800980599, 27.68428675590023, 0.21143211592589656, 0.05257736500953475, 0.0977030234231103, 0.16929752523860625, 0.05680227862490762, 0.05701420535784095, 0.06349090036124953, 0.19543949424499468, 0.05103744401205933, 0.1082385556712266, 0.07418646071586879, 0.09110555082799927, 0.13239693918055104, 43.71683951347105, 68.45403578973585, 63.05783110280191, 51.388493507139145, 29.04310560995533, 55.21951560051211, 57.75216256418536, 80.3081052534042, 52.290403304561494, 0.33146215903182186, 0.4921176915447559, 0.06426194104396048, 0.032727900486920154, 0.2629697004393224, 6.850567085127677, 66.34558923782842, 67.62597637791788, 69.55371933598673, 63.50187870763964, 58.45172512915827, 53.35704872685095, 52.4799753773597, 49.349539587574625, 56.550218905172045, 57.84457360544513, 62.325555970591886, 59.441405803926536, 62.874585813091656, 64.03992983602708, 66.2894993443643, 68.47384375910606, 64.80297596223893, 63.626115860477576, 63.04681708735805, 59.86519436682425, 62.70997962644024, 57.431034195807676, 49.5866782434525, 47.501636474363266, 44.18136973534861, 45.97631692886353, 47.86609134366436, 50.33738459310224, 55.48866079699609, 57.127105420635594, 62.9152137233365, 59.891799803703066, 60.79517264519969, 63.36772972537626, 60.702373289292865, 51.169597794932706, 48.36910393930251, 44.30428112706831, 44.89703755224905, 44.71906392805038, 42.965940967682876, 43.52466298687843, 45.26080208439981, 44.89477434465962, 46.69193375495173, 45.7754562747094, 48.073561191558845, 49.89225833646713, 48.09069802684169, 52.21150090617519, 51.798789116644095, 53.07251999455114, 53.83008656963226, 53.529880123753706, 53.42418793709048, 51.19074721490183, 56.72124208942537, 56.1781781719577, 57.48155824599728, 60.322013208943034, 57.21065190530593, 61.70149118669572, 56.862619999916326, 49.74854269335347, 48.291370407227554, 48.85373630831319, 49.145144877895234, 45.609696911227324, 45.99111995389385, 47.50201302189981, 59.54358746928554, 58.87681984132337, 60.043913241355654, 56.77875188089187, 55.8007324126459, 52.33023105129119, 55.39532407637566, 50.97634653891287, 54.58427598399501, 55.538631792991396, 53.81681719133931, 50.38026786619618, 50.05062795454457, 49.84135381637081, 49.724784897219756, 48.10208074508175, 49.9616450648154, 45.367925936175936, 41.59739463560043, 42.84735202789307, 43.93881428626276, 43.03512373278218, 42.036527510612245, 46.04831203337639, 43.176584013046764, 44.1426637864882, 45.273173239923295, 49.18801246150848, 56.184779520957704, 60.863841579806426, 57.63366383890952, 57.80372604247063, 49.83279520465482, 45.57682744918331, 44.884893894195564, 51.313293826195505, 50.680289960676625, 55.216228654307706, 55.48845291137696, 55.40783251485517, 51.182341575622566, 50.843111468899636, 48.51811085977862, 46.579118544055575, 46.10571592084823, 48.27836382773615, 47.21384825245027, 47.45504263908633, 48.69461751753285, 51.424112550673954, 55.164669098392615, 58.73895245213663, 60.52617257641208, 61.06926787284113, 63.53663482973653, 64.95139060481903, 67.48817566902407, 69.20116101541828, 67.16399177428215, 78.21406948950984, 72.82871015610235, 80.84931388978036, 69.44054326703473, 57.15025524939261, 9.249301879636704, 0.972754299159973, 2.889438747398315, 0.4913486924863631, 60.94519153718026, 75.85454417813209, 78.78285238819738, 55.77385240985502, 61.5885857612856, 37.08341337019397, 31.27499895711099, 61.719130085360625, 74.59301579383113, 36.58328763900265, 0.17996718416050558, 0.07157037770676036, 0.08794754488213409, 0.09453201696517007, 0.05066996695654047, 0.14769501022754178, 0.1405735641357399, 0.40540177855760823, 0.14034723111939046, 0.24098807915804848, 0.11595119947507498, 0.20642331050288296, 0.2910536257249694, 56.118134529359885, 79.26928904748733, 68.09334247343003, 58.409853827568796, 38.86094131777364, 65.5685677066926, 65.21804117387342, 86.21477896167387, 57.242501551105136, 0.5727668010419416, 1.544244981581165, 0.3017518290829274, 0.20354136434053222, 0.7075538426156968, 8.149939967739968, 70.53522186894571, 70.3035431523477, 74.49527032913701, 64.30751000681232, 62.540293970415675, 55.54992429671749, 55.901254915422015, 53.37628010780581, 58.70071326532672, 58.65860662152691, 65.74952233222224, 62.96133295182259, 64.91652073398714, 65.22124182793402, 68.21948589817171, 69.41066265106201, 67.32323215853783, 66.57332989477342, 65.92540925548923, 63.31532293750394, 65.2912090670678, 59.7883943588503, 51.27798072753414, 49.828300168437345, 45.94414564871019, 51.250555515289314, 48.34831929975941, 53.79098446138444, 57.37297919488723, 58.058817386627204, 65.33512784588721, 62.77831515958233, 61.95826522765621, 65.1233708473944, 62.83623679991692, 53.870537973219356, 51.40291998463293, 47.03736120654691, 47.23272662008963, 47.89001387934531, 45.94898585350283, 44.20260544746153, 48.44035379348263, 46.17646763401647, 49.48446912150229, 47.957698299038796, 50.38710063503635, 53.37984554229244, 50.39549058483493, 54.29455795595723, 56.29092278019075, 55.189344729146654, 56.32794995461741, 56.36148229722054, 57.712221068720666, 55.023895232908195, 57.83508146962812, 59.11083236817391, 60.122568530421105, 63.141263838737245, 60.09094638209189, 66.64602710354713, 59.291312386912686, 51.6957562969577, 49.964912399168945, 50.64162323551793, 51.318710619403475, 49.17003623900875, 47.16578352835871, 47.72945557871173, 63.43746162229969, 62.437727912779785, 62.192575854639855, 58.106529097403254, 60.22450308645926, 54.844619381812315, 58.26804053398871, 55.025307286170225, 59.071667502003336, 57.45545487250052, 57.58746224064981, 51.972342229658565, 53.582832121079974, 52.44756483262586, 53.37453465307913, 51.44459124534361, 52.33745997951877, 47.98287599317489, 43.32535559131254, 45.51929412349578, 47.65534631667599, 45.19815398800758, 44.1274606797003, 47.71519776313536, 45.1513248105203, 46.450225537823094, 48.507787181485085, 53.295624409952474, 58.06326927677278, 64.10254655345794, 59.944532148299686, 59.51524442242038, 52.223844605107466, 49.50663443534605, 47.35510849183606, 55.21129823500111, 52.64763316800518, 59.39012473629367, 59.95862914669899, 56.76316438182708, 51.19093156629994, 54.07655262177991, 51.90756428626276, 49.3457741122092, 49.85915353221279, 52.98383520495508, 50.636610446437714, 52.02102276586717, 51.06290932624571, 53.834726733546105, 59.870407196783255, 61.653508832377774, 64.43475953994259, 64.74030825399583, 67.8434874934535, 70.07894039154053, 71.92178756959977, 74.12085656196841, 70.69581939328101, 81.95843465866582, 76.91430584076913, 84.85752905568769, 71.76327674619614, 63.94159601580713, 10.704224686468802, 1.2536348594773201, 4.608912429501934, 0.8369648468590553, 65.07960504101169, 83.30094429754442, 85.38547223614108, 66.43147345512145, 70.82157842574581, 47.26448605137487, 41.09708063064083, 71.53869751961001, 86.99478933888098, 46.436371726374475, 0.2777161575373142, 0.22865843027830127, 0.17699867006271117, 0.29837954068376177, 0.14668389674155943], [0.11987675657315601, 0.04831020930601705, 0.0255266931508818, 0.027248199969049425, 0.1725295122953192, 0.022601330870642297, 0.035038938775898955, 0.5444825897293707, 40.58643510264736, 53.82363819306897, 43.50891074826641, 29.82802679461818, 26.316564121553977, 42.54439207815355, 51.13452003848169, 66.0813940725019, 63.44238419686595, 2.3681305012395306, 0.36895557456920225, 0.030839007287736864, 0.1075432466102704, 0.05488877485115683, 4.021464196905013, 58.59261274337769, 65.20115929265177, 67.0478896171816, 59.14302326017811, 57.739548221711196, 52.35557348497453, 57.46556282043458, 56.02850444855229, 58.80133774972732, 60.53720228133663, 62.27309426953716, 61.114061340208984, 64.82617678180819, 63.25515770143079, 63.43473557502993, 59.57481738059752, 60.543434927540446, 61.60482045142882, 61.1593411814782, 55.582276005898755, 55.82956183341242, 46.48430308988018, 44.377876558611476, 44.30490086155553, 45.06552688537106, 42.047619973459554, 50.447022684158824, 54.75933920952582, 59.87253312141665, 59.04742725433842, 57.77297466031967, 57.30342772699172, 59.830524536871145, 58.6965790871651, 54.24071950297202, 50.59462931848342, 46.95974534557712, 44.78988232151155, 43.91655483553487, 44.9868441397144, 42.0928527462867, 41.95192590836556, 42.90324580284857, 42.41570303517003, 42.91026292308685, 44.024757339108376, 41.832466202397505, 46.40775411359726, 46.18930162922029, 48.44557839055216, 47.804361081892445, 48.67835144842825, 49.319553067607266, 49.6222698303961, 46.94854305636498, 50.6963756007533, 51.21712123194049, 52.1417337079202, 53.24096618160125, 51.781958226234686, 56.019381015531486, 55.95014333724976, 51.96580363858131, 58.08987863602177, 46.647897305027136, 44.92545904651765, 48.00198970302459, 40.79213596159413, 46.68966662499213, 48.61148680410078, 54.38401937484742, 58.765773619374926, 54.54782539798368, 57.689475244091405, 54.22322180963332, 52.80630480858588, 48.162363652260076, 48.42903383316533, 51.24071821089714, 50.778094260923325, 52.55657142208469, 47.17727607296359, 46.18986252815493, 47.31291555589246, 44.6155055107609, 45.13790638216081, 43.716278614536414, 41.42453578210647, 40.52903905991585, 39.396466439770116, 41.42112332005655, 41.303507128069484, 40.26296115690663, 41.80363678163098, 41.65059374224755, 41.441048960531916, 46.36341956353957, 49.25047620650261, 56.79151527343258, 56.097114547606445, 55.7386177585971, 54.91405317860266, 51.684224528651086, 46.692204398493615, 42.391058783377375, 46.66438302686138, 48.7593170135252, 51.1127979524674, 53.34008839822585, 56.86874281975531, 55.086955178168516, 53.64375829696656, 49.57158496302944, 48.187678629352206, 45.392876132842034, 46.295491956895404, 46.20862322468912, 47.65001581561181, 45.28286541661909, 46.115157065853, 50.633809874134684, 55.96874713897706, 57.90686084378151, 62.21030104544855, 61.91670771568053, 66.22822407753237, 64.12479815944549, 70.78803431603217, 67.8485865746775, 73.32733754188784, 71.65187358856201, 77.53677814237534, 64.71085125400175, 73.40252937809115, 4.943925988289618, 0.2976371401981, 1.2174801672658613, 1.5872910330372474, 69.5508324715399, 67.24778144590317, 74.12583797208725, 52.584847788656916, 37.832742967913234, 23.07329939257714, 64.22962350230064, 52.73261916252875, 59.710770653140166, 30.210885424767774, 0.16444869429594086, 0.23585124512112912, 0.04871590648807826, 0.021085558879760005, 0.05698741143268924, 0.17227670328030664, 0.010231989060318279, 0.09193585224209294, 0.07620710188583021, 0.1711527450430778, 0.03830442302710107, 0.09441315076283871, 0.7144841804139076, 50.65513972313174, 62.04166658463017, 55.87557123553369, 26.892742649201427, 25.566944268441972, 51.236842909166896, 55.2837130331224, 75.45963210444297, 67.86004774032101, 3.1054132744189236, 0.6187818415703312, 0.05753540944668555, 0.25382939816242267, 0.07339627932636969, 4.575551200297571, 61.850686380940104, 67.92257032086773, 71.43379765172159, 60.0331816365642, 59.69423394049368, 55.48486002029912, 60.174661528679636, 60.17245715664279, 60.64417708304621, 64.24832144091206, 64.4356930640436, 64.45620313767465, 67.92814793125277, 64.35398224861392, 63.725547944345784, 62.62115363151797, 64.57274852260467, 62.212842741320216, 62.97382962319159, 58.83768243174399, 57.8933168995765, 48.38012579948672, 47.00952022306381, 47.159656786149554, 46.621429151104344, 46.1108071573319, 54.092179344546416, 56.78292528275521, 63.01196682837702, 62.12057682775683, 56.7235758996779, 58.81248120338687, 60.9111532088249, 58.873262251577074, 57.718406646482414, 52.50739666723436, 49.66893819070632, 45.75001578177176, 44.35866871187764, 48.34268677619196, 44.77509890833209, 43.722142557944025, 43.406227019525346, 44.27984476089478, 44.485404414515344, 45.2282738685608, 45.21263537868377, 48.63266760303129, 47.84929183221633, 47.847624824893096, 49.98526950036326, 50.76398549541351, 52.22118131576046, 51.40565387664303, 50.318090454224624, 52.3331767512906, 53.22522963246992, 52.98019916780534, 56.78482370991861, 55.81613556031258, 58.0872820269677, 58.97308657246252, 53.665378401356364, 60.29317986580634, 46.52600572955224, 45.185778910113925, 47.103555125574914, 41.22876244206583, 47.1144671593943, 49.39698457717896, 55.690564801616055, 58.8014397313518, 56.52226025058378, 58.1586338627723, 56.291318939578154, 54.34140674529537, 49.84740995591687, 50.38639068603516, 52.20131451083768, 52.31841687233218, 53.41078519821168, 48.84867252842073, 49.89334483300486, 52.14437738541634, 47.438400022445194, 48.04229990128548, 46.898222969424346, 42.4172523713881, 42.32540222906297, 42.51192269786712, 42.86085674839635, 43.24633552182106, 42.86647358248311, 43.15721534913586, 44.17765525079543, 45.37866930807791, 47.477729628163004, 51.29795343645158, 59.49964123387491, 57.288126560949514, 58.17089126956079, 58.942990226130334, 55.7631011932127, 48.47408617696455, 44.45798704701085, 48.90043996995496, 51.51932808660692, 55.0410242234507, 57.433587658789854, 60.60283530143, 57.81066471530546, 56.97124219709828, 53.86319137388661, 50.972792871536754, 47.977392519674, 48.0371694411001, 50.157818486613614, 50.036052426984234, 49.04753669615715, 49.76440475833032, 52.72650418743011, 59.30755884416642, 61.34840726852418, 66.1389587771508, 64.5994363292571, 67.97085469768894, 67.85586649371733, 73.84516100729667, 72.23437693811232, 77.36059311897525, 75.3320138685165, 79.03408019773423, 65.94512308797529, 76.80145925091159, 5.487246330707304, 0.2568519980676713, 1.8761026258430176, 1.961356689853053, 78.88556357352965, 72.32972191226098, 82.03200263361778, 57.528948322419204, 49.4345530386894, 24.493050306074082, 51.76963413915327, 61.79682831610403, 71.67936940346995, 38.98536282200968, 0.1825951874977158, 0.20538250344895548, 0.12439255377337818, 0.06273282188621741, 0.030360217656820055, 0.3173184905561709, 0.11338179420319297, 0.16965570198672433, 0.2458022829265364, 0.25137161956198756, 0.14241016800365142, 0.10667720719450906, 0.9471026723903995, 62.11367737862372, 72.48984875217562, 60.227770420812796, 37.88636176816879, 37.70420689736643, 59.578127861022956, 63.7748521374118, 78.9913106733753, 75.80545179305538, 3.658499092824998, 0.9861262106607038, 0.33762337519757213, 0.5612073922830244, 0.25157339179948457, 5.534501575654553, 64.77273448821038, 70.78702234452771, 73.07462707642587, 64.6753812605335, 63.122561977755645, 57.613185144239864, 64.96309103504305, 61.84133152807913, 62.6336306910361, 68.78387574226626, 65.89823507493543, 65.5372005124246, 70.8581349157518, 67.00101729362243, 67.1189002067812, 64.73198890686035, 66.07927599260884, 67.57030225569203, 67.0640262480705, 60.63999583644252, 63.24982327799644, 51.222761600248276, 48.961028822006725, 50.11937141418458, 49.44507283549155, 47.130207630895804, 55.90962133099956, 60.00075147997949, 64.11456077329575, 63.83680597428353, 60.03431127917383, 61.43216163881364, 63.292016213940045, 63.37349168715939, 60.01233031672817, 57.209934111564394, 52.98756537898895, 49.258917147113436, 47.495129262247396, 50.250951243985085, 48.29443377833213, 46.72902368730115, 48.8239380621141, 47.01066163278396, 47.52973241190757, 48.63449934990176, 47.35146853231615, 50.82895955731792, 50.244757821483, 52.30270385742188, 52.282001587652395, 52.05783813230453, 55.05320318283574, 53.913778181998964, 53.305783348698775, 55.40109780526931, 56.801921321499734, 58.242698100305375, 59.98100626853205, 59.073522783094845, 60.93779786940544, 63.302273211940644, 57.88434251662224, 63.99935291659448, 45.936183237260394, 46.926197313493304, 50.019841271062056, 41.23690920491373, 48.66354450102776, 52.19157134332965, 58.81941203148135, 61.832768993992964, 58.39874175287063, 63.36073613935902, 61.3691879856971, 58.65393507865168, 52.988922519068566, 52.894773867822465, 55.61874228139078, 55.44586381604595, 56.76436462709981, 51.67440683610978, 51.23143396069927, 55.230294273745635, 50.96032365675896, 50.465442134488015, 49.692896027718824, 44.44740841465612, 45.03275940495153, 44.617097993050855, 46.366643751821215, 46.61689096881498, 45.93884652660739, 44.802190719112275, 46.361850615470644, 47.57507893346971, 53.407886566654334, 54.3355231900369, 62.844195288996545, 60.04306600939844, 61.77910704766551, 62.50261960491058, 59.95057259836505, 50.136029720306404, 46.52489569879348, 52.0283732875701, 54.25295337553948, 56.73567641165949, 59.29945130502025, 63.90310187493602, 60.53870062674246, 58.93247435169836, 56.40321239348381, 53.91303293166622, 50.681372534844186, 49.38149121499831, 52.92273252241073, 52.14713873401765, 51.780875652067124, 52.68746091473488, 57.25171127626973, 62.68066383177235, 65.03064209415068, 69.31505880048199, 67.48515544399139, 72.31843333090507, 71.63560359708725, 77.9436142213883, 75.0315289343557, 80.55373976307531, 77.75061007468932, 80.27482002012192, 67.94936010914465, 76.6856316597231, 7.136731445789338, 0.4504161550393028, 3.2144664420235545, 3.000676920337062, 83.47035146528675, 80.19692174849972, 90.01714814093806, 66.29378257259246, 57.63425219443537, 34.49233093569356, 83.65984116831135, 70.95660209655762, 83.13568699744441, 48.908563198581824, 0.3687825612723828, 0.2674245936495643, 0.26125246839177224, 0.21309412835586458, 0.2679558296597773], [0.05709561752155424, 0.06527554814613636, 0.22610830743947338, 0.10670635684002792, 0.09228478996984421, 0.06638406205081171, 0.04692738229829458, 0.7412244487674006, 46.080467624049035, 53.27864054710635, 57.77712452796198, 44.56724466816072, 23.324776272619925, 36.63813806349231, 50.17468860072475, 59.39186626865018, 77.75468933966853, 10.311432653857816, 0.27495808779231967, 0.41309302552573146, 0.05317701267138605, 0.04555195569992066, 1.6438462176630575, 51.05527639389039, 65.12208430997788, 64.00662891326412, 62.012488072918316, 63.608912344901796, 60.7146659974129, 62.99695984009774, 60.19327709751745, 62.59844310822026, 62.7619118075217, 64.46245931809949, 62.87682548646004, 60.98517617871685, 59.25663078984907, 63.14216206150671, 61.10992323967719, 57.124159720636186, 58.8989027853935, 52.91757460563414, 49.77133950879497, 46.27018090217344, 45.70496736034271, 42.52058329120759, 43.12940182224397, 43.2646490681556, 49.469952429494555, 55.96236152033652, 56.09568680486372, 51.27332879650978, 61.775612215841974, 54.85935572654971, 57.21633541968561, 59.16142309865644, 57.516612468227265, 54.952260986451186, 47.61830737513881, 47.969077094908684, 41.686169639710464, 47.130544954730624, 46.42740518816056, 41.7149402249244, 40.531655280820786, 39.48899122976488, 41.56290131230509, 40.23546534199869, 42.484834809457105, 43.43001619462044, 44.91048343719975, 49.43174069927585, 45.280551218217425, 44.580925895321755, 48.09204732218097, 49.31266146321451, 45.72139816899454, 48.52891698960335, 47.04229947059385, 47.85253170997866, 51.17499105391964, 55.372829283437426, 52.20071831057149, 56.93896893532046, 50.6691151280557, 52.12526759793682, 55.80378009426979, 51.423277085827245, 40.52132768015708, 43.84591294873146, 43.16304399121193, 48.92579809311898, 50.31489372253419, 56.823847370762984, 56.76056777277301, 57.917102152301425, 55.83264873873804, 55.28723139916697, 50.6786935560165, 49.801341718243016, 49.19989724313059, 49.788382207193685, 49.16030876098141, 49.588710031201764, 48.69509212432369, 48.506128018902196, 46.008390149762555, 43.86685840545162, 43.77810301319246, 42.10804016359391, 40.2471814617034, 39.55118040884695, 42.32932852160546, 42.94073973932574, 39.97923651049214, 41.65212346661476, 44.27196864158877, 46.48191436644524, 40.975377328934215, 45.314660149235884, 50.74534246998449, 57.15854321756671, 54.445086756060206, 53.640828286447835, 56.101542903530984, 54.56798245829921, 51.63244532000635, 44.71236059742589, 44.48572997123965, 44.274710378339215, 50.03001982165922, 53.823544056184836, 54.51478727402226, 55.164990732746745, 56.77544924520678, 57.06346888695994, 55.31915949236963, 51.469466916976444, 46.716130856544744, 45.527170242801795, 48.057251976382354, 45.56731570151545, 48.4335288693828, 47.79452377750028, 53.919230276538485, 57.59154542799919, 63.61133636966829, 64.5920269720016, 66.35888607271256, 65.32375689475768, 72.08822158075148, 66.71968137064289, 73.21141581381522, 67.90865375149635, 78.87693435915055, 74.1102190940611, 78.90020970375308, 4.998589119603557, 0.07163829140124783, 1.220414713025093, 4.453553230531754, 74.65760938582882, 67.13816688906762, 73.08087148974019, 55.23690346748599, 46.52689610758136, 26.33643484884693, 41.742843966330256, 57.99643208903652, 64.38278421278923, 35.20659454407231, 0.11749408523281736, 0.076411203030617, 0.07976196435911041, 0.08117754928647511, 0.09248087783494303, 0.1391376702175025, 0.016480010648768757, 0.2722476993597323, 0.1614337093046596, 0.04070490591167923, 0.09556415956467391, 0.06061996671281034, 1.2659979251123246, 58.130020172365256, 59.2637106680101, 64.42796991717431, 39.276896907437234, 27.429124809080555, 43.70382901160948, 57.68543520281392, 66.28354518644272, 82.99670173275857, 11.734160646315544, 0.40369919411117033, 0.345649341301572, 0.05224825746770348, 0.05911264658695268, 1.5834279887137876, 55.69000782505159, 70.15650133932792, 67.77042942662393, 64.88256085303523, 66.1700867068383, 62.90460371202039, 65.92800586454331, 63.14376238853701, 65.74894182143673, 65.92044353485107, 65.80069357349028, 62.15578794479371, 64.74547401551278, 63.51699552228374, 65.24785510955319, 64.06711970606159, 61.25199148731848, 60.20381650617046, 55.01089649815714, 53.317907394901404, 49.13372685832363, 45.81664116151872, 44.19093247382872, 43.399986528581195, 44.93214668766145, 52.97825759457004, 57.29763830861738, 60.88640305303759, 51.245260315556685, 61.65390891413535, 58.52863104112687, 59.64598878737419, 62.025329912862475, 59.85596110743862, 56.416313109859345, 51.397440433502204, 49.90535905284267, 44.18901835718463, 50.64478074350665, 48.356120894032145, 43.380198171061856, 42.588675637399, 40.64134044031943, 43.32606161794355, 42.08944420660696, 44.24947384865054, 45.312981374802135, 45.64873233918221, 52.99820676926644, 46.252381186331476, 47.19033364326724, 50.09856324042044, 52.249571431067686, 49.52308877821892, 49.59691562960225, 49.17543342036586, 50.44632450226815, 55.91877614298175, 55.85735574845345, 55.27701754723826, 57.63200075395646, 54.166582784345074, 55.84464726909515, 58.77493235372729, 52.004219332048976, 39.90278167109336, 46.357245752888346, 44.61753729851016, 50.27601126701602, 52.188154958909564, 58.90192301042619, 59.02537961159984, 59.3629740899609, 56.89242609085576, 56.863333871287686, 52.40086509335426, 51.61094288672171, 51.50663137435914, 52.74451178889121, 50.91227854451826, 51.727437280839496, 50.3010202992347, 49.64129332573184, 48.21955965411279, 45.06871577232115, 46.696177759478175, 45.70703052705335, 44.10695452843943, 40.953827827207505, 43.1512729583248, 43.993543117277085, 42.534468481617594, 44.13281079261534, 46.14011118488927, 48.02147996041083, 44.1225028038025, 48.39998475966915, 53.36412076027163, 61.056045562990256, 57.56603433239845, 57.27930515043197, 58.63658251300935, 56.651659242568485, 54.7082228814402, 46.730090571988015, 48.1418731904799, 48.5345220565796, 53.46838912656231, 57.101927726499504, 57.571094189920736, 60.61593994017571, 61.11466538521552, 60.02659597704488, 59.76893548042544, 54.098976812055035, 48.46492352024202, 46.61506706668485, 48.89754918313796, 48.79011938648839, 51.40088819688367, 51.8775503097042, 57.235766841519265, 59.327970858543154, 66.66875331632554, 65.57741657380136, 70.4063484745641, 66.86065919937627, 74.7453841855449, 68.89357659124559, 77.64853431332496, 70.85137274957472, 82.34166591398179, 76.31878022224673, 80.87073787566155, 5.13784698901638, 0.10080217083375301, 1.8872340672439145, 5.215163278964258, 85.30209049101799, 72.83533896169355, 80.8982023116081, 60.82476692814981, 57.530497658637266, 26.722611804162305, 42.804633494346376, 71.7377499611147, 73.23048637759301, 42.63226493712395, 0.11640944262786258, 0.031024360345796715, 0.1235225536830483, 0.025366101969754504, 0.09786696623890631, 0.3372911994736041, 0.19218322220108203, 0.3307203101294656, 0.20524646155536178, 0.09606268362052019, 0.20422693642397083, 0.1958751531257745, 2.0363162481977097, 74.75727681190737, 68.37901653782015, 76.17213064624418, 60.64231395721436, 36.816947152537686, 51.73259911998626, 64.63831878477528, 71.71256834460844, 91.55678041519658, 13.366660917958907, 1.2580361265328623, 0.7109154364274395, 0.19469260448409667, 0.2362299836691349, 2.2343867488445777, 58.28027440655617, 73.75886101876536, 69.69940400892689, 68.62951478650494, 70.60861725961009, 65.5340979176183, 69.70960217137491, 65.91263017346783, 69.24254986547655, 67.95338446094145, 68.15100915970342, 66.57054501195108, 67.23879921820857, 64.66290812338552, 69.32080115041425, 65.97413293776974, 63.500090106841064, 64.06449171804613, 56.91153587833528, 55.6788133805798, 50.423194285362, 49.71462988084363, 46.41020559495496, 46.53495657828547, 47.89962760863766, 57.47698868474653, 61.39920196225567, 64.08174230206397, 52.8506628928646, 62.180898958636874, 59.67876019016389, 58.94827758112262, 64.23256527992987, 61.87522472873811, 59.20438874152399, 55.352523173055346, 53.77688354061496, 46.13042685293382, 53.224880541524584, 50.788755263051684, 45.944616333130874, 44.40035958443919, 43.69992233091786, 47.160758972167976, 43.79536928669099, 46.38678512265606, 48.11876258542461, 48.67407214257025, 57.314190710744555, 50.25320660683417, 49.384429070257376, 52.37935873769945, 53.65540381400816, 50.47844871397942, 53.80943529067501, 51.30324471381403, 54.21081927514846, 58.756308940149125, 60.420531380561094, 57.56226101229268, 63.815291773888376, 58.240933033727835, 58.67284874762259, 58.83663515890799, 56.11385130113172, 39.84928054194297, 45.11397207936933, 45.41835977185158, 52.49766526683685, 53.65677664356848, 62.45957943700976, 63.715310558196045, 66.19990456488826, 60.86244129365491, 61.05110337657314, 55.925040168146936, 55.50620948114703, 53.42918111431984, 55.28293248145811, 53.1869629890688, 55.9392430705409, 52.127770070106756, 52.69459962844849, 51.80067969906715, 48.698508508743785, 48.56916442994149, 48.621724190250525, 45.00912712466332, 46.06553516080303, 47.04039319869011, 47.414120551078554, 43.63967472507108, 46.72081416653049, 50.46117459574054, 52.57372002447806, 46.851942923761186, 50.982277162613414, 56.2329815280053, 63.158126108108036, 59.987772357079294, 58.372163772583015, 62.990350646357385, 59.54155960390645, 58.713182480104514, 50.21173930937245, 50.869728672888975, 49.14578030186315, 56.85607356409873, 60.826567296058904, 60.60609086867302, 64.87456314025387, 65.86902126189202, 63.03564225473712, 62.12888048541162, 56.260579324537716, 51.952412666813025, 50.2751483455781, 51.049934125715694, 50.878122545057735, 54.291608333587654, 54.19205073387393, 57.98917178184756, 62.79130604959304, 70.65794498689714, 69.85140369784448, 72.63532946186682, 70.40939223381781, 79.15881941395422, 73.06564484873127, 81.83131064138105, 73.12532763327323, 85.92479813483455, 77.14687885776644, 82.77063985024729, 6.019964996845492, 0.15672974558847566, 3.160497815378251, 5.943143415835596, 94.34273012222783, 78.84352361002277, 88.78502184344877, 69.54504305316557, 66.62462665188697, 37.6472697719451, 60.645910770662375, 79.75617285697692, 88.44131238998906, 51.455432676499896, 0.23220192400678513, 0.19279603125347247, 0.15251626200493307, 0.3167411973399501, 0.2614482498217014], [0.11167113519003315, 0.0599604262970388, 0.06736115357207675, 0.09273269093565403, 0.04156795758453589, 0.05653275740182689, 0.0976351403721398, 1.350196871546007, 52.592194387989665, 53.71571025540752, 35.14148712158203, 19.4832363436299, 23.25049246511152, 39.99599679823845, 48.04879534629084, 61.7804681101153, 74.79002075810587, 35.98602441049392, 0.4322850602048059, 0.7366941725054096, 0.12565050078856368, 0.15511876993602322, 0.19822354969238082, 34.88661150778494, 67.6981479890885, 68.81475264026274, 66.48725740371212, 64.81021273520686, 62.38816092091223, 65.66769384568738, 63.584436755026545, 62.69996973776049, 61.7876382027903, 61.891031880532545, 64.23566395236601, 59.93824066654329, 58.83788247262278, 58.677418308873335, 56.92078090483143, 53.37632325387771, 50.212280596456225, 46.66662662259994, 45.69423575555125, 44.87145977635538, 46.108543949742476, 43.87950412688717, 44.62711964884112, 45.11269338669316, 54.16302127222861, 55.33042846187469, 58.448096936748875, 36.42103095208445, 36.797876588759884, 54.82333660125733, 57.715468791223344, 60.249696470076046, 55.2812066385823, 52.336106761809326, 47.89892942674699, 45.51621114054034, 46.69639741220782, 53.935543414085146, 45.23203542155605, 40.72118812991727, 40.030878436180856, 41.25475991156794, 39.441820806072606, 41.0517890222611, 42.05703366187311, 41.22744060331776, 43.89926895018547, 46.78087349860899, 45.56198520045127, 45.491409993940785, 46.17642448794457, 48.43330529428298, 48.8598983518539, 47.82873861251339, 46.91142958979453, 47.87432832102622, 51.167758203321895, 53.99214321567167, 52.47111474314044, 50.6044940794668, 52.482979912911695, 53.83385596736785, 53.76603818708851, 53.954727726597945, 41.78997124395063, 42.44844305899836, 43.96767900836083, 46.838677467838416, 55.04189891199912, 55.79899088028939, 54.94944080229729, 53.781421722904334, 55.793503484418316, 54.69280404429282, 49.44954041511782, 49.20606713141165, 46.54613925564674, 48.70098352432252, 48.440271423709014, 47.851496204253166, 48.246231771284535, 45.25344371795655, 43.55014270351779, 47.469386746806485, 43.94002629864601, 39.57259654998779, 40.05181997053085, 39.99587912713328, 39.533792541873076, 42.249806388731926, 42.85886418434882, 39.39433659276655, 41.59314670870381, 44.17803964307232, 43.10863679455173, 43.48545889700613, 50.792481514715384, 56.76819286038799, 56.05337227544477, 52.36907036073747, 53.518418958110196, 53.516959836406095, 51.75408586379021, 48.60241043952204, 45.21283934193273, 44.80988640939036, 46.77056943216632, 50.60891066828082, 57.00748881986065, 55.30933395508797, 55.92886840143512, 57.924554655628825, 59.74804101451751, 57.65164790614959, 56.52939896429739, 49.16928706630584, 48.98763818125571, 46.01645454283684, 47.36461631713375, 46.084033058535674, 49.19544927535519, 50.52615258001512, 61.40504629381242, 60.02951422045308, 65.85592839025682, 64.66652454868441, 70.35178046072684, 65.84263940011301, 72.11665876450078, 66.19600572893697, 74.60049183137956, 68.33898482784149, 81.67756942010696, 3.5382482938228117, 0.05383470681526008, 1.299055538350536, 8.843718017301253, 78.66273372404038, 63.21415716601957, 76.26232162598642, 51.37996235201436, 41.81807894860545, 26.697747899639992, 41.89858559639224, 48.40710778390208, 72.31451880547309, 37.131760504937944, 0.17240477785948785, 0.06993694801724727, 0.08181867294854696, 0.07249186656648114, 0.05405726684858242, 0.05624190063005494, 0.08515871670697966, 0.09618377147783196, 0.01466786988349932, 0.08571658193344071, 0.05409328447234246, 0.09690490536271565, 2.0295287091885847, 64.61958162246212, 58.114797453726496, 51.03342094729024, 29.170867012393092, 27.182266519915675, 48.256979065556685, 53.101223899472146, 67.38009083655574, 81.63057158070227, 39.55043908088438, 0.5481881263755983, 0.8903606235980989, 0.15879703385214652, 0.21855117182337472, 0.2926418792095877, 37.8422547155811, 70.74891259593349, 71.43871630391767, 68.72554225306358, 67.30249850980698, 65.45996512136152, 69.77746702009632, 66.41059075632404, 66.27835981307491, 64.02005518636396, 62.98777364915418, 65.02115780307402, 61.625103027589866, 60.81146224852532, 61.48971065398186, 58.913925463153475, 54.70289630274619, 53.40308166319325, 48.73756747091971, 48.685654901689105, 47.01862404423375, 47.5940671274739, 45.366839439638206, 47.455517245877175, 47.132078601467995, 54.733659452007664, 56.9801224431684, 61.167778199718846, 38.289946202308904, 39.380882863075506, 56.21515043320195, 60.4913301621714, 61.00913401572936, 57.61991593145556, 55.53163428460398, 48.92448802148142, 47.80209002956268, 49.13202847203901, 56.87867033866144, 45.352613003023215, 42.00789420835434, 40.9055434503863, 42.73947900341403, 41.723306640501946, 43.81020369068269, 43.43340512244932, 43.107499307201756, 44.71121526533558, 49.73624606286326, 47.33757941953598, 47.77486093582646, 49.40724941991991, 49.56771358366936, 50.801683395139634, 50.737493807269686, 47.96480563379104, 52.25187778472901, 52.48011658268591, 56.60829744031353, 55.27343250090077, 56.53230936296525, 55.39375120593656, 55.99087322911909, 55.64768937326247, 57.15502485152214, 41.08126955647623, 42.24637823720133, 43.206535231682565, 50.547180406508915, 58.24450239058464, 57.04688118350122, 57.64335601560531, 56.319454100824174, 58.7363362312317, 55.60788516075381, 51.60738921934559, 50.88280977741365, 50.576970807967655, 49.899914803043494, 51.48398360898418, 51.94442279877202, 50.71073147558397, 48.00974422885526, 46.097953550277225, 48.11445190060524, 45.6339136246712, 42.31533350483064, 40.624988079071045, 42.32005603851811, 41.649318971941554, 45.342222644436745, 42.884987169696444, 43.66638998831473, 45.62656702533845, 47.92112219718195, 44.614356256300404, 45.98044326228481, 52.39175734981414, 57.939083114747085, 59.036068070319395, 54.46682453155518, 58.379639810131444, 57.82673858827161, 54.47214718787901, 53.000011059545706, 49.333136235514, 46.10529230486962, 49.80387949174451, 54.28155922120618, 58.9151963110893, 58.018024736835116, 59.748178297473544, 60.676987709537634, 60.08299573775261, 61.190402430872766, 58.29095502053538, 50.897098971951394, 51.314576441241854, 49.17345654579901, 50.55151070317915, 48.0128978144738, 50.95527556634719, 53.97543784110777, 64.99360315261349, 63.61448995528683, 69.80998346882483, 67.52935271109304, 74.38847203408518, 67.70804020666307, 75.55075660828622, 67.73533205832204, 79.64468340719901, 71.14424828560122, 86.83376035382672, 3.7794019858683314, 0.07444690762748642, 1.7152907194629794, 9.793805306957616, 85.36860604440012, 69.16526348360124, 81.15930664923884, 62.50705580557547, 50.214971342394435, 33.96805517135128, 51.502697237076305, 54.77507575865715, 83.29484893429665, 45.00618534703409, 0.1299100492389933, 0.14683955048601474, 0.056430277820195884, 0.09124813511246636, 0.05743613594301766, 0.1356113675020395, 0.18770753736457518, 0.18896384495160273, 0.11171111731880135, 0.21390852578465017, 0.1586761145341781, 0.1637409363062151, 3.6257279351834333, 82.45398690623622, 68.48545397481611, 53.44442736717963, 31.58570362675575, 35.99121370623189, 57.49851857462237, 61.982309356812515, 72.51317900996055, 91.40799706982028, 44.7606606637278, 1.111149860005225, 1.710576520812127, 0.4120693481977909, 0.5174499822239722, 0.6412391268437909, 39.20915365219116, 72.14710420177829, 75.56061744689941, 72.68460227597144, 71.08918605312225, 67.67863027511105, 72.89699077606201, 69.16306695630475, 67.74662848441832, 65.2062544515056, 64.90863284757062, 68.4612137271512, 63.69524763476465, 64.45363790758195, 64.93662680349043, 62.5977292368489, 57.521864521888, 55.21284757121917, 52.52019536110663, 51.461088734288374, 49.40054216692525, 50.11624528515724, 48.44191489681121, 50.263698947045114, 49.558288128145286, 58.02786204122729, 60.11201735465758, 62.665358743359974, 39.57753873640491, 40.5356913997281, 56.91856868805424, 64.6680974191235, 64.23003142879855, 60.551585612758515, 58.790731660781375, 51.5208891899355, 49.256516656567975, 52.50643176417197, 59.5718167674157, 50.617692855096635, 45.77472671385735, 42.17970186664213, 46.78568624681043, 43.423344242957334, 46.53650199213336, 46.488766747136275, 45.57804730630691, 47.28074035336895, 52.494711722097094, 50.63754004816855, 51.5015362155053, 52.62618957027313, 54.07454436825168, 54.1428759790236, 53.83869617216049, 51.33749877252887, 55.129975734218476, 56.24067721828338, 60.288598537445075, 58.14106948914067, 59.747731147273896, 57.54734031615719, 58.90226033426101, 58.84267168660318, 58.698097044421786, 42.117273422979544, 42.3596719772585, 45.347961071998846, 51.54083051989156, 62.41358180199901, 60.61169593564926, 61.79751080851402, 61.34450451020272, 61.21430143233269, 62.222578064087905, 54.53199471196821, 55.7195471948193, 53.757958104533536, 52.18104762415732, 54.43546910439768, 54.82749039126981, 54.38986762877434, 51.32228389863045, 48.818297693806315, 50.85429414626091, 48.464460680561686, 45.02815454236923, 43.084412236367505, 44.33089440868747, 43.401610389832534, 48.68329755721554, 46.45938034980528, 45.676820431986165, 47.609442818549375, 49.84995165178853, 48.76065846412413, 50.3142543761961, 55.64251184463502, 61.426803681158255, 61.07987788415725, 56.06582187837171, 59.96495985215711, 59.87617700330673, 57.20399956549368, 54.5807497732101, 51.03562924169725, 47.58553204997894, 51.42138650340419, 57.1651327994562, 62.64440544189946, 60.426944455792835, 61.769563921036266, 62.64691183643957, 63.32945131486463, 64.48174953460693, 62.01897567318332, 53.99636368597708, 53.945419942179036, 52.75507865413543, 52.92801595503285, 50.197999246658824, 55.529202415097146, 57.54679118433307, 66.85333221189438, 67.04132356951314, 72.26137853437855, 69.89180411061933, 79.08114079506167, 72.48576164245605, 81.62300925101005, 72.10723723134687, 84.83964304770194, 73.46485584012925, 90.66165631817233, 4.540392054665474, 0.12111995639579913, 2.827596207780223, 10.411743348644627, 96.9767350535239, 72.19767139803979, 91.74748605297458, 65.10306081464215, 62.47996791716545, 36.65380793233072, 60.809308867300714, 65.55660840003722, 96.87576540054815, 53.86183423380698, 0.31547813285743037, 0.2321936655789614, 0.1529941782956162, 0.24241516306515665, 0.23005021285385857], [0.03736224979342472, 0.04704005467975813, 0.019836791513127186, 0.049191704545650757, 0.024476832852909164, 0.02100305887119424, 0.12981857834083418, 3.730516996114485, 56.04652381712391, 52.58873877986785, 32.75222828311305, 34.049397283984774, 41.49731143828362, 46.401301814663796, 49.419287173978745, 65.50566857860935, 69.75802775352233, 53.95426488691761, 1.1610428988933563, 1.1115956618901224, 0.08614193693163895, 0.32169098334927715, 0.17551066684386424, 16.519505208538426, 60.88837992760443, 59.62586310602004, 66.07842876065162, 65.22236362580331, 66.78230593281408, 64.74479936784314, 66.39768615845712, 64.94502067565918, 64.49272432634908, 62.37685272770544, 62.74095458369102, 58.91637694451117, 56.17486769153226, 51.447999785023356, 51.98605875815115, 48.23798694918233, 46.19458113947223, 46.775393947478264, 49.2462557361972, 49.14730218149001, 47.38323580834174, 44.93612397101618, 47.247761064960116, 46.80984804707189, 49.60759624358147, 54.58632738359513, 56.37138235953547, 44.39799831759545, 45.88131320091986, 51.7194317233178, 56.25903783305999, 57.40243227251115, 56.06168377783991, 51.413380945882494, 45.93332382940477, 45.230831253913145, 52.42113590240479, 57.04260187764322, 47.012128599228404, 39.58140227102464, 40.20785185598558, 40.622469917420425, 39.287161750178186, 41.55767671523556, 39.55509493427892, 41.34453512007191, 42.82919537636542, 44.45426471771733, 46.04125176706622, 45.95262973539291, 44.34492472679385, 45.60250328433129, 48.77819538116456, 47.25977528479792, 46.447205312790416, 51.190978634742, 52.83023126663701, 54.170301191268436, 50.71382622564993, 52.94603532360446, 54.03144928716845, 54.5774628270057, 53.331455261476584, 55.041526286832756, 48.47240348016062, 37.986150787722686, 41.97541698332756, 50.71751717598208, 55.922239595843905, 54.87634351176601, 59.28477379583544, 55.26720377706713, 54.3748410286442, 51.33234477812245, 51.56669070643764, 46.77579010686567, 47.094086523978945, 47.37904279462753, 48.72371758184126, 47.21686063274261, 47.82129003155617, 46.17986832895587, 46.953618603367964, 45.30550141488352, 42.9016690100393, 43.44909460313859, 40.9860344086924, 37.447264194488525, 41.72609544569447, 42.241538032408684, 42.356259515208585, 41.22565592488935, 44.50991138335198, 42.01901020542268, 43.601000155172045, 43.259271498649355, 48.10849382031349, 53.15289328175207, 58.06640325054046, 57.87084171848913, 54.89303319684921, 57.79214328335178, 57.23386449198569, 52.78120163948306, 52.43043584208335, 42.71845509929042, 44.347737066207394, 44.59239490570561, 51.95031419877083, 51.78751622476886, 57.48623763361285, 59.17457872821439, 60.546717951374674, 58.66483926773072, 61.56818551401938, 54.27099627833213, 51.87101564099712, 45.46857787716774, 49.05169833090998, 47.09147422544418, 48.40884539388841, 46.348051717204434, 51.95667628319033, 54.40751437217959, 59.8461865609692, 59.56003396741806, 61.39531097104473, 55.97350497399607, 67.18302311435824, 60.91380865343156, 73.19496539331251, 67.96113506440194, 81.1574709799982, 2.155526025641349, 0.1610304099778014, 0.521341770166351, 13.564115974210925, 83.46312645942935, 58.896670956765455, 79.90141037971743, 44.99397500868767, 49.6143505650182, 13.558662899078863, 30.29074292029104, 65.99584717904368, 73.10805351503434, 31.70587916528025, 0.0981134090632681, 0.2083137550301129, 0.1033557870335156, 0.012190530185527619, 0.04788597279618825, 0.07936160680988143, 0.029475656150269414, 0.04498395513022139, 0.017889455381420352, 0.05955742574447106, 0.07048277800241787, 0.1325121894478798, 5.894472195256141, 70.31311373556815, 58.34815886712844, 47.84665599946053, 26.386890257558516, 33.5339625420109, 52.918770928536695, 57.214958667755134, 73.2558641126079, 74.90484422253024, 59.4864659924661, 1.4518262181551227, 1.4134458260190104, 0.226553772245684, 0.08699915867539183, 0.26557510418276636, 18.647051741999967, 62.781437366239494, 64.89757960842502, 68.49112572208529, 68.21641075995662, 67.96474364496046, 67.62903582665228, 68.10247375119117, 66.73844598954724, 66.91645099270728, 65.7417207379495, 63.05798015286846, 62.08638552696475, 59.27267720622402, 55.45011174294257, 52.82028021350984, 49.29787805003505, 47.73052638576877, 50.69429674456197, 52.55355119705201, 51.961861656558135, 49.29961958239156, 47.3156572926429, 50.216716797121116, 48.8357404739626, 52.36316327125796, 58.78081590898576, 56.11217644906814, 47.55859321163547, 46.06405642724807, 53.303771172800374, 59.47689540924565, 59.48387722815237, 58.87658057674285, 52.94399176874469, 47.98884191820699, 46.545209653915904, 55.17934660757742, 60.036225395817915, 48.23906952334989, 42.85289041457638, 41.396836003949566, 42.36728137539279, 42.29673362547352, 41.480323653067316, 43.037045694166615, 43.27992669997677, 45.434410110596694, 45.203162854717625, 49.40153452657884, 47.027500367933705, 48.47110909800376, 48.78352588222873, 51.29479200609269, 49.84063602262928, 49.179014544333185, 53.47722230419036, 55.21317312794348, 55.17858566776399, 53.72008762051983, 54.81338947050033, 55.81919893141716, 58.58272052580311, 57.29003675522343, 57.03101911852437, 49.37808659768874, 38.84148636171895, 43.21541940012286, 52.65433257625949, 59.26693093392157, 56.91061804371496, 59.9002956574963, 56.118616980891076, 55.97431298225157, 53.562561312029445, 53.14667240265877, 51.11755970985659, 49.20558467988045, 50.30655476354784, 49.97832690515826, 50.06266178623323, 50.336596196697606, 47.16956077083465, 50.12488234427668, 47.31277827293643, 44.846815524562714, 44.29640893013247, 41.938954630205714, 39.706286614941014, 45.29181234298214, 44.868776875157515, 44.09306933802944, 43.36861541194301, 46.36130932838687, 46.372060545029186, 46.3471495720648, 45.089398430239775, 49.28565202220794, 56.6605120320474, 60.53153837880781, 58.854289747053585, 56.426974111987704, 60.170578341330256, 58.81382657635597, 55.643888596565496, 55.30018306547596, 46.20065296849897, 46.271377225076, 47.06022077991117, 54.94767573571975, 55.67900165434807, 61.762738996936434, 61.6654916732542, 63.31627999582599, 61.83227869772143, 64.10023235505628, 57.31042131300896, 54.66681049716089, 47.559985653046645, 50.55808067321778, 49.66198775076097, 51.679733414803785, 49.53610320245066, 55.42096068782192, 56.6134161333884, 62.928804735983576, 60.83233318021221, 66.7358023120511, 58.34812748816706, 70.66305975760184, 63.976332526053156, 77.10968694379254, 70.89714680948566, 85.50019371894099, 2.069187794000872, 0.11944276776405112, 0.7068207271156773, 14.26413255353128, 92.24585456232872, 64.54833961302235, 88.61191195826378, 54.20744603680026, 61.80109193248134, 18.577937618378673, 45.93922307414394, 66.52525732594152, 83.63170992943549, 40.088894213399584, 0.029087226590021487, 0.12726526091536208, 0.03333098405311185, 0.1153622234180089, 0.029252366418199196, 0.15902773356966435, 0.20175487794462713, 0.12598112901492467, 0.12046344202732849, 0.15751028193100808, 0.27286124385653004, 0.31850871539885, 9.406746798946012, 82.93244546459567, 66.62990616213891, 46.36955807285924, 45.26199840730237, 52.75867938995362, 63.36233646638932, 66.18735298033684, 78.03185186078473, 82.24620326872795, 62.89695901255455, 2.3537123587823685, 2.1353885771766787, 0.42139996203684044, 1.1687819803914716, 0.4039836272356972, 20.464795750956384, 65.22776472953059, 67.57931586234801, 71.22137777266964, 70.78804216077252, 70.36445756112376, 67.48489656756001, 67.82645656216529, 69.0440857794977, 69.74618219560193, 67.5190447222802, 67.5720202538275, 65.03178742624098, 60.23400306701661, 56.496019594130985, 56.547830181737105, 52.51059732129497, 48.26657318299817, 52.25794176901541, 53.395350671583614, 53.989009241903986, 52.72943027557866, 48.78832686331965, 53.10577777124221, 50.77558394401304, 55.897744394117794, 60.69044928396902, 60.29468997832268, 47.79451201038976, 46.91062942627938, 55.33759463217951, 59.53187134958083, 61.782437139941806, 60.865504664759484, 56.237260833863296, 51.75863189081992, 49.6538802116148, 57.03030524715301, 62.92556878059142, 51.820060130088564, 46.07430558050833, 44.789584221378455, 43.45677460393598, 43.551240967166045, 46.137946036554155, 44.29875450749552, 46.17801697023454, 47.72761206473074, 49.17485290958036, 51.58375693905739, 50.870673964100504, 51.34461787439162, 52.72371930460776, 53.67312508244669, 53.393852326177786, 52.29324702293643, 55.41477511006018, 58.320463011341715, 59.459025090740575, 57.937816189181426, 55.98792360674951, 59.75820779800416, 61.126397194400916, 59.15804986030825, 60.82454335304999, 49.93502001608572, 37.59929133999733, 44.94350979405065, 55.42510663309405, 62.17829842721263, 60.42366143195861, 65.43011980672037, 60.46230854526643, 61.05595142610612, 56.99621200561524, 55.657742408014116, 53.66413893238191, 52.22291108100645, 54.91229987913563, 52.514445166434015, 51.839526853253766, 52.88704287621283, 51.376192954278764, 53.464137277295514, 49.39576472005537, 46.67901738997429, 49.375642961071385, 44.581223995454856, 42.964768179001354, 49.2684288947813, 47.4839073611844, 47.45518384441253, 45.25254157281692, 49.84038106856808, 48.06904262112033, 49.66124250042824, 47.75669643955846, 53.513978835075136, 58.38169120973157, 63.03583837324574, 63.85686105297458, 57.627517484849506, 63.41618668648505, 63.184872750313055, 59.09916331691127, 58.600026023003366, 48.248518513095, 48.248636184200166, 49.70117615115259, 57.19595086190009, 57.147089896663545, 64.56755138212635, 62.829968852381555, 68.09118516983526, 65.95379937079646, 66.76092117063462, 58.50650887335501, 57.39397564241963, 49.27559114271595, 53.857617685871745, 53.22677504631781, 53.34363814323179, 53.25023866468861, 58.08235553003127, 59.130004913576194, 65.98822993616905, 67.82644871742495, 69.88933301741078, 61.860507995851584, 75.49274475343766, 67.56443438991424, 81.7333455239573, 73.27247927265783, 89.46587470269974, 2.9064610985017594, 0.3977252711211482, 1.0365023752374034, 14.925030354530582, 102.14265346527101, 69.42290829073998, 95.78771560422837, 56.2479845939144, 73.37566898715112, 20.80720886107414, 46.35731243318128, 84.8106175084268, 96.38095055857013, 50.29205376102079, 0.18660401835316615, 0.2567070695541559, 0.1732714224847094, 0.2538366759977033, 0.09170321432212669], [0.05227357667360095, 0.03695919178426266, 0.027090814865885243, 0.046060186089767564, 0.0693585133300193, 0.03957915119826794, 0.1991677530590565, 4.382013611255154, 60.53572354778167, 50.29656056434878, 36.58237764912267, 46.05916915401336, 85.41672568167411, 66.18464654491794, 39.519923040943766, 66.73904218981343, 61.47708846676735, 70.87203579564249, 2.879107959808842, 0.8090818204706716, 0.08928383970933576, 0.25691516967790745, 0.12292373339615523, 6.3740829498537135, 58.571094620612364, 60.17319456223519, 69.01423654248639, 62.863391368619865, 67.77811727216168, 62.15961617808189, 66.25725746154785, 64.1331841868739, 64.06748056411743, 58.345868202947806, 58.16190904186618, 53.157600125958844, 49.314453986383256, 46.82050512683007, 46.43316714994369, 47.91661539385396, 51.72488381785732, 54.620412780392556, 55.617020360885135, 50.72143954615439, 46.652019716078236, 45.03903127485707, 49.60373663133191, 50.05074954801991, 54.45266085286295, 57.016977033307484, 55.392798069984686, 47.01217959004064, 57.498389136406686, 56.80948757356214, 59.381209188892, 58.805264042269805, 56.55717326748756, 50.722930046819876, 43.83196107802853, 47.57506324398903, 55.11901663195703, 56.42006289574408, 46.76402299634872, 39.45477639475177, 41.3481907690725, 40.70620467585903, 39.742454790299945, 40.57008666376914, 40.49471832090809, 39.149098242482836, 41.2127277928014, 42.25015547967727, 47.84663638760967, 45.930907649378625, 46.356782913208015, 44.124844458795366, 46.36895402785271, 46.65644807200278, 46.78550974015267, 49.026763823724565, 51.5471298463883, 47.50121678075483, 52.39376952571254, 56.41783498948621, 51.27692953232796, 52.5430667015814, 51.014507278319336, 51.970600697302054, 51.86902699931976, 40.10337952644595, 45.55732934705673, 55.18008793553999, 54.7384722002091, 53.180294959775864, 55.27077313392393, 52.90261076342676, 54.36102251852713, 52.569887868819706, 52.38892539854973, 47.290781621010076, 44.52640102755639, 46.077631750414454, 47.042079817864206, 44.23925215198148, 46.355927836510446, 44.1694418076546, 43.47446449341313, 42.62371809251847, 42.987035474469586, 41.415949713799264, 38.36023899816698, 38.715699872662945, 40.09059652205437, 40.51729940599011, 39.8513593981343, 40.57363640877509, 45.78041022823703, 47.935164282398844, 46.571630739396625, 44.59786661209599, 45.03688573837281, 51.72586833277057, 55.69460092052337, 55.689031154878684, 55.651823551424094, 55.10223280998969, 57.74236056112475, 53.39461718836139, 56.33905810694541, 52.3925418238486, 47.62223759005147, 43.442669760796335, 47.873175144195564, 50.980727826395345, 56.84264336862872, 57.31474768730902, 60.60551820262786, 57.09091763342581, 61.72848886059177, 57.22462731022989, 57.019436359405525, 50.16395699593329, 48.896670572219364, 45.915073040992986, 47.567799014429895, 47.61670312573833, 51.32545709609986, 48.60340672154581, 50.43679706511959, 49.12106152503721, 55.76357972237372, 52.66493866520544, 60.205769846516276, 61.40093172750166, 70.50512160024336, 74.10002877635341, 71.82602682421285, 0.3760682412933919, 0.6467586984076809, 0.6414473801851273, 21.45230539383427, 82.02684079447101, 62.02913068955945, 77.86565319184335, 45.09496035114412, 44.72175859635876, 31.825234928438743, 34.64748813259986, 52.2126893843374, 75.42225976144114, 46.75149494601835, 0.13403425293584026, 0.10877431160019291, 0.018561783719867952, 0.04404073235608878, 0.07854668078042808, 0.03699187309511247, 0.06124335543943509, 0.031751163281320084, 0.03974781694611715, 0.03209213177943903, 0.08924316044055647, 0.20082938244506238, 6.6495676771287, 71.27731077132687, 57.86827256602626, 45.84691401450865, 36.62505303659747, 85.86596258224981, 70.26732398617652, 48.05977406040315, 72.18324492054602, 68.22082734877064, 75.04811271544426, 3.5789240079541362, 1.2064117289358571, 0.07006688419008447, 0.28278416623511626, 0.14350233359202264, 6.4356631809665314, 61.09943874420659, 63.52004320390763, 71.7291207467356, 63.6308305494247, 68.7007999420166, 64.42179218415292, 67.50557530310847, 65.64594038071172, 68.07704110299387, 61.39256923429428, 60.48907479932232, 55.864670968824825, 52.64638193192021, 49.728585673916726, 48.57784071276265, 50.127074949203006, 52.79027015932145, 58.791661262512214, 58.41971858855217, 54.56870025204074, 49.5554797111019, 47.2710560214135, 51.18309859306582, 53.068374049279, 56.28698079816757, 59.1469495527206, 57.0955381854888, 48.81921160605646, 59.966587635778616, 58.629941940307624, 60.82579066676479, 60.634983047362304, 58.42044814940422, 52.35497728470833, 46.869683804050574, 49.6958181934972, 57.18756483447168, 57.21255033246933, 48.794230030428984, 41.52605848927652, 42.36072709483486, 41.47066677770307, 41.87145063954015, 41.63379423079952, 42.80307239101779, 40.88209552149619, 42.6069107363301, 45.06383634382679, 47.46992803389027, 48.461432610788655, 49.823216776694025, 47.13477326977638, 48.58027258226949, 48.566281487864835, 48.95327037380588, 51.71855703476937, 54.434802301468395, 50.80861030086395, 54.78883935559181, 56.39711310786586, 54.86085407195553, 56.0588792831667, 55.69005881586383, 54.4440669398154, 55.29041636374689, 40.48978790160149, 48.37288118177845, 57.01388228324152, 57.02713597205378, 55.36465898636849, 58.32326750601492, 55.45822320445892, 56.86331033706666, 56.07767135866227, 54.838928022692286, 48.161190863578554, 48.5226058959961, 49.15290724846625, 49.06388905740554, 47.127175638752604, 50.64609865988455, 46.314856698436124, 45.85293485272316, 45.24162561662736, 46.040620265468476, 43.83062354979977, 39.54250804839596, 41.21370054060414, 41.382127115803385, 42.8261947631836, 41.97016100729666, 41.855784693071925, 47.999914769203436, 49.78714273821924, 47.8708452563132, 46.217099466631495, 48.5730593435226, 53.342920349490264, 58.956553782186205, 58.34463265634353, 58.07658180113762, 55.040137767791755, 60.32825369988719, 55.47369695478871, 58.889524398311494, 53.58387154917563, 48.87126930298344, 45.53577200058968, 49.67821067379367, 53.69878130574381, 58.88553534784625, 59.336258826717255, 63.86539613046954, 60.892992634927076, 64.00991585946852, 61.225488032064135, 61.87643674112136, 54.32301475155739, 53.08296918869019, 48.93993039284983, 51.25204601595479, 49.98597552699428, 53.39135377637802, 50.15163290885187, 54.03061774469192, 50.58614130943052, 58.48337473407869, 54.936077287120206, 62.76944668062272, 64.73218502536898, 74.72825127263224, 76.17897910456504, 75.8825106774607, 0.35943631923967795, 0.7632270455360414, 0.38810253263481204, 23.95345768620891, 91.13029326162031, 67.4670184043146, 85.7370734983875, 48.62801959437709, 58.32480115275229, 26.440932673792688, 30.994290613359023, 63.22454752460603, 82.3740960705665, 56.86884872374996, 0.1241932176954804, 0.03057839566721551, 0.017359106117979656, 0.05372556226868784, 0.03501199163316238, 0.23993116893595268, 0.1808758870127701, 0.12987183677333017, 0.22044725475772736, 0.18002706159266735, 0.144981894521944, 0.5653881485904417, 12.02100847997973, 85.4633548182826, 66.55540466308594, 53.34325375095491, 56.68359518051148, 92.02642933014901, 79.33213326238817, 54.963388750630045, 78.07829272362494, 75.32329836199361, 80.23383125182121, 4.594890446432175, 1.776335424473209, 0.4601900886383749, 1.752216402561434, 0.32029308739208406, 7.480420306805642, 63.8474512869312, 65.95765898304602, 74.50943008545907, 66.11559714040449, 73.03325391584828, 68.21149995250087, 70.19462677740282, 71.85928067853375, 70.75263100285684, 63.04161602450956, 63.22723434817407, 58.1754372965905, 55.18783853900049, 53.58702513479418, 50.73829789315501, 51.94614079690749, 54.594827159758545, 60.332066243694676, 61.303017600890136, 56.952175555690644, 50.796921637750444, 49.409073322050034, 55.15097218175089, 56.10087217823152, 58.71146448196904, 61.24892027147355, 59.6924178831039, 47.07253702225224, 62.30361030947778, 62.43614719760034, 64.91497532013925, 63.0367640526064, 61.247951446040986, 55.35836358224192, 48.97546314424085, 53.53896825544296, 61.14555797269268, 62.97798733557425, 52.16466780631773, 42.95386791229249, 43.93808080304054, 43.60159243306806, 44.84336383881108, 43.72309177152572, 45.91520640157884, 43.12808390586607, 45.34882399343675, 47.525366813905784, 53.342045660941835, 53.1755018234253, 51.9990574929022, 48.7785993852923, 52.44417982716715, 51.33123866973385, 51.93598578053137, 54.899010888991825, 58.276477552229366, 55.32267393604402, 59.304770038973906, 60.95533478644587, 55.35244864802207, 57.92367212234005, 55.91266509025328, 57.25281346228815, 55.26832557493641, 41.6893663714009, 49.686918335576216, 59.164961076551876, 60.154316194595836, 57.7787797681747, 59.531973331205315, 58.554047999843476, 60.01694302405081, 59.201192009833555, 57.71638662584367, 51.889529228210456, 50.39436878696565, 52.79512997596495, 51.13473969121134, 48.80564805000059, 53.1676374712298, 49.953133521541474, 50.04874913923202, 46.76343464082288, 47.12044485153691, 46.243434259968424, 41.161897797738355, 43.878209744730306, 44.21345864572833, 45.57410140191355, 44.875162493798044, 44.37288338138212, 50.89697345610588, 53.0910728054662, 49.682803769265455, 49.56949433972759, 49.622293364617136, 57.33744252112604, 61.51637492641326, 59.74517768429172, 59.05199681558917, 57.19638624498921, 64.1724314228181, 59.45842889047439, 61.752631049002375, 58.31268102891984, 50.95746424890334, 47.9119634628296, 53.68469215208485, 56.31448838018603, 63.51124532761113, 61.80160968534408, 65.85854853353193, 65.38415747304117, 68.22389464224538, 63.42058758581839, 63.68875218975929, 54.95546556288197, 54.4362888797637, 51.74113419748122, 55.130222843539336, 52.39175734981414, 58.335297415333415, 53.89214238812847, 57.80935072129773, 52.10971932257376, 63.74808196098574, 56.86340055158062, 68.87886770309942, 66.51791464897894, 79.85187868918143, 79.0895660461918, 82.73640540338333, 0.6512810686422933, 1.2540741649366196, 0.9116985624836338, 25.885205384223696, 99.39387213799262, 73.35015789155038, 94.18735719496205, 57.62734882293209, 66.89401503532164, 42.54613753288023, 47.164238114510816, 71.90456836454331, 93.67110267762216, 69.34532380873158, 0.30725571116612804, 0.13227510055707348, 0.08432943418982529, 0.20307234999152923, 0.1916757042730047], [0.1073505295320384, 0.11815103627140484, 0.01229683446112059, 0.09614578883854613, 0.01683589296355363, 0.1859075371776858, 0.34345085281998883, 7.490514036147826, 64.26570930788594, 49.54292812655049, 31.771406281378965, 56.019796786769746, 90.1661668285247, 67.77381835445281, 41.87441202902025, 68.89654190309587, 57.78303161744149, 78.2643856540803, 11.998987313239807, 0.7490321104564975, 0.4315727516528099, 0.053355066826747316, 0.052828645679138364, 2.412825664204936, 63.79579759413197, 67.91561988092238, 70.11037426610147, 62.09088056318222, 64.59085418332008, 61.625091260479344, 62.37192230839884, 57.08808960453157, 59.52882366795694, 54.19756950870637, 53.18236989359702, 46.20567752468971, 46.85866978860671, 47.121292083494126, 53.05299443583335, 52.536712461902255, 56.98025972612443, 56.887852607234834, 55.09607468881915, 52.91757068326397, 48.68785535135577, 46.74138699808429, 51.91946475736557, 52.46791801145, 54.89128381975236, 59.902248997842115, 54.61050879570746, 61.83077642994543, 60.22485217740459, 59.03794688563193, 58.87257975916709, 56.21040436529345, 57.07929565060524, 49.36265207106068, 47.00992422719156, 51.46970618155695, 54.906463392319225, 51.638191592308786, 49.067019108803045, 42.563117473356186, 40.49340040453019, 39.95809493526336, 39.625858414557676, 39.47859302643807, 39.03048969084217, 38.42014143543859, 42.52621973714521, 41.36509226214501, 44.54251412422427, 45.46139209501205, 43.57070376796108, 46.02881785361998, 43.662848088049124, 46.38414536753009, 47.890468874285304, 49.0439163484881, 46.376500668064246, 49.63285238512101, 53.82408926563879, 53.618451164614775, 53.88286990504111, 54.49892520904542, 54.17656913880379, 52.61304178545552, 56.759630326301824, 39.981158471876576, 48.7903311944777, 54.75914309101721, 52.61491667839789, 53.665876542368245, 54.878708700979914, 54.974214492305634, 52.793917963581706, 52.08922886079358, 54.017948489035334, 47.63924498711863, 45.66335493518461, 46.66956447785901, 47.60921532107938, 46.44298092011483, 46.88094492881529, 46.87205683800482, 44.240691661834724, 42.6263774594953, 43.92353273207142, 38.956560857834354, 38.938886657837905, 39.171243944475734, 38.58361797948038, 39.83742321691206, 38.00327977826519, 39.97866776681716, 52.380072609070815, 52.28817932067379, 52.06732242338119, 43.65976510509368, 44.103185130703835, 47.736041238231046, 56.01565476386778, 56.08811663043115, 57.65138510734805, 51.72117717804448, 55.719374610531716, 58.45987189200617, 57.39315978942379, 54.801383095402876, 53.0555949672576, 45.42898155027821, 46.735452452013575, 44.141816554530976, 49.41192488516531, 55.06814349082209, 58.93513371867519, 58.87800831948557, 56.97209727379584, 61.300330777322095, 59.57835143612277, 57.34149825188422, 54.33504466087588, 51.10188984101819, 49.91607104578326, 47.82023099160964, 50.98119066607568, 53.594438414419855, 53.71365101106706, 52.43080454487955, 52.87916675690682, 54.17369796383766, 61.68919455620551, 64.12563754666236, 70.82830136822116, 79.20198902007073, 51.84842671117475, 0.3242847119127551, 1.5661597540301662, 0.30300263615865863, 33.14132936539189, 76.06042154373662, 66.79358666942966, 65.09324312210083, 35.58250665664673, 46.01704682073286, 62.22076592906829, 46.06307975707516, 46.06323272951188, 74.58441795841341, 47.73838289322392, 0.17005420560317655, 0.02720186122572951, 0.11348546888198584, 0.04790650012211935, 0.034924757201224566, 0.03872977802529931, 0.12640540382914967, 0.11486665646155035, 0.12573837873435792, 0.09469163904507315, 0.23373563203119466, 0.39711978586931385, 10.584445307331702, 74.27276995874222, 54.70107240061606, 38.4923561926811, 59.375211884898526, 90.21906391266855, 72.33340109548261, 47.329718989710656, 75.00655912583875, 65.440514087677, 83.8258437187441, 13.543577463396135, 1.243858842119094, 0.5296804227175251, 0.12749824357489425, 0.2645651857939459, 2.923350089019345, 67.31169254549089, 67.83058289558657, 71.79026265298167, 66.3020509289157, 65.99274850660755, 63.19616525403915, 65.54058159551313, 60.489984789202296, 60.20177295131069, 55.80397229040823, 56.07127397291122, 47.4298688673204, 49.88142082768102, 47.335743750295336, 55.765991980029696, 55.22998440650202, 59.11214636218164, 59.29109273418304, 57.61401276434622, 53.40732566771969, 50.40804609175652, 47.04669252518685, 54.99015500468593, 55.79301318814678, 59.93775429264192, 60.10872648608301, 56.33379428617416, 62.69924017690844, 63.45349234919395, 60.896597293115434, 61.04019134275375, 58.76125897130659, 59.30757845601728, 51.766005946743874, 48.63030633618755, 54.15833011750252, 57.68782000387869, 54.8465334984564, 52.422751918915786, 44.12634672657136, 42.052393497959265, 42.112597957734145, 42.57378632022489, 40.79769788249847, 41.42294722218668, 39.221003132481734, 44.42001065900249, 44.00547496734127, 47.59264722947152, 47.49649816943754, 46.3552257322496, 48.704270470526914, 46.713220457876886, 48.63477783818399, 50.12343106731292, 52.10709917929865, 49.101520276838734, 52.422132184428555, 57.60979621641098, 55.80905568215155, 54.46418869879938, 55.16401798494401, 56.92635067047612, 56.67482476080618, 58.31115914929298, 39.101390454076956, 50.321852007219874, 55.96704875269244, 55.6553654516897, 57.20342689944852, 57.0187303327745, 56.88671119751469, 55.595804260623076, 53.566715102041925, 54.54442470304428, 51.92935305256998, 49.1890440448638, 50.057229303544574, 50.76540147104571, 49.206361309174575, 48.020220879585516, 49.92791660370366, 47.29879894564229, 44.005019972401286, 45.049857016532656, 40.327484146241225, 41.409316985837876, 40.53812326923494, 42.327375181259654, 42.38660689323179, 41.31127342101067, 40.943182514559844, 53.08126295766523, 55.09923219680787, 54.124130971970104, 45.23057629985195, 46.541542237804784, 50.08390142071632, 58.643685925391416, 58.58760387666764, 59.55724908459572, 53.7544358161188, 56.16166499353225, 61.23353673565773, 61.032425049812566, 58.21971301109561, 55.365737638165875, 48.070874367990804, 46.81293103002733, 46.23889215530888, 51.36992892911358, 57.018047840364524, 61.65374809695829, 62.548727066286155, 61.15443037402246, 65.00548401186543, 63.04152973236577, 60.45211038281841, 57.55926824385121, 54.52052570158436, 52.124620406858384, 51.9756095640121, 53.44048538515645, 54.285650253295906, 56.743066157064135, 53.98724025295627, 56.973211226924775, 57.54145676089872, 64.42479279733473, 67.81785088200724, 73.90295320941557, 82.87640263957363, 52.48115601078157, 0.29239875354593803, 2.7062586670921696, 0.1389035384260839, 35.599678793261134, 84.92882990068006, 72.2372716472995, 71.95153482498662, 35.88836523794359, 56.93953375662527, 46.90935857834355, 39.81668172344085, 59.02237899841801, 80.00924418049475, 55.90855052394252, 0.2959467212278997, 0.03833179917907523, 0.03903399537047071, 0.050702215427713054, 0.03267211013383443, 0.20730478659031853, 0.18725710830861525, 0.17140003822503552, 0.2485451994523887, 0.41398113593459135, 0.48820240002486015, 0.6762923684812362, 17.02426718127343, 87.82188384763657, 63.93132332832583, 47.180680690273164, 67.52163348659393, 95.23914860140894, 76.76844073880103, 57.72743986498926, 80.2087986853815, 70.62126298104563, 92.52363681793214, 15.959865354722547, 1.74544908827351, 0.6816441361461917, 0.6069267841596758, 0.6926145152218881, 3.68385378391512, 71.74386885858351, 69.74466816071542, 78.46543065963253, 68.8019500240203, 72.0583095858174, 65.21662912061139, 68.56930640435988, 63.643711613070586, 64.66418289369153, 57.92853586135372, 58.260419368743904, 50.15291160152805, 52.70742577891196, 49.68193692545737, 59.62762032785724, 56.965291961546875, 61.34037425441127, 63.958560266802394, 60.24450717433807, 56.94952011108399, 54.25441641961375, 50.604533303168516, 58.92620248179282, 57.78840134220739, 64.03679978462958, 62.83571904705417, 57.237422081731985, 66.09779742456251, 66.97096409336214, 63.90276062873102, 63.83842199079452, 61.71396824621386, 62.53070769771453, 53.521356813369266, 50.72702892364995, 55.98063976533952, 61.580105596973056, 58.31291244876001, 57.254554994644664, 48.91483114611719, 43.26020502275036, 43.473546658792806, 44.83680563588297, 43.79744422051215, 44.34422654490317, 42.136614630299235, 48.03643988024805, 45.537388017100675, 51.22338133473551, 50.74163190780148, 48.31099402519965, 52.417958782565215, 49.14024583755001, 53.42120693575952, 53.796664053393954, 54.222343198714725, 52.42428556565316, 55.925718738186745, 60.63002124909432, 57.43687852736443, 58.091655469709835, 59.907344156695956, 60.40757579188193, 60.95896690122543, 61.77617703714679, 39.96114653925742, 50.618010567080596, 57.989838584776855, 58.81252434945876, 59.78813548241893, 59.75712130146643, 60.00014743497295, 59.84444110624252, 57.463480041873076, 59.28225171181464, 51.65932532279722, 51.182059164970156, 50.779663208992254, 53.096030681364, 50.77654492470526, 53.533908397920676, 53.281554868144376, 50.24819774012412, 47.18670545085784, 47.37077051593412, 42.81550630446404, 43.87916680305235, 43.58761310577393, 43.270042327142534, 45.772286999610166, 43.72731616420131, 42.631951147510165, 56.282258264480106, 58.94473960322719, 57.80735815725019, 47.27102464245212, 50.87245079778856, 53.70717125554239, 64.51681160157727, 59.75137895153415, 61.66108685155069, 54.007303176387666, 59.72181996991558, 64.51892968147033, 65.43735265731812, 60.51640587468302, 59.422751011387, 50.523936440867764, 50.54840418600267, 47.2378453131645, 55.22293590730237, 59.28581714630128, 65.58559079324046, 64.35035797857469, 63.35916326891992, 68.21302967686808, 66.59436948837774, 63.289341157482525, 61.88617598625922, 57.617609577794234, 55.32082257732269, 52.89226355091218, 58.31335959895965, 58.89016766701975, 61.34546156852477, 56.979961625991336, 60.59226843618578, 60.48147716829854, 68.53421688079834, 68.71955671618062, 78.28860236752418, 83.94765684681555, 60.369736686829604, 0.3563818347550208, 3.9875231923595553, 0.40629782563736366, 38.60884666442871, 94.48729299729871, 79.19918060302734, 81.37991643721058, 46.26084173879316, 67.07340071278234, 78.58791059063327, 59.099445727563676, 65.3996390681113, 90.67795768860849, 71.44890662162535, 0.5720899470390812, 0.0901922208046721, 0.20865780511690726, 0.2032582948525106, 0.3084877644094729], [0.03250503784886772, 0.10315114196630255, 0.04671056792440434, 0.07819349126469705, 0.02408763145907752, 0.2370807855960823, 0.2236578526395944, 6.189079457713712, 64.18022909472066, 51.015617309078095, 37.48477774281656, 41.60742805850121, 103.226223914854, 56.351166463667354, 43.153104705195275, 69.87602049304594, 63.80261075112128, 77.62526681346279, 27.801349893693004, 0.8480408234942345, 0.530600402384035, 0.116545821600143, 0.030338102613665888, 1.2151273580328112, 62.73981709634105, 62.71571805400234, 64.951139573128, 55.56406051881852, 58.32879804795789, 53.19315248920072, 56.677974424054554, 50.530388739801225, 50.33030863731138, 47.5010363517269, 49.34725284576417, 47.17678185432188, 51.49210291524088, 52.61860762873004, 56.57576137973417, 57.061437099210686, 58.586976297440074, 57.738952021445, 54.37937136619322, 44.898229952781435, 45.99394406041792, 46.80598059008199, 55.22839584658223, 55.431876644011474, 58.77911752270114, 55.39093494415284, 59.150769941268436, 56.5286184126331, 56.06960304321782, 56.65365180661602, 56.89653673479634, 56.8627376710215, 51.19957254778955, 47.321874249366026, 48.49982477003529, 52.15881955239081, 52.72134234828334, 52.44785116564844, 52.58936635909542, 45.783218645280414, 39.98808929997106, 39.562198346660985, 39.5168008342866, 36.99400294211603, 39.065932227719216, 37.20765836777226, 40.157908316581484, 41.71394394290063, 42.6871741971662, 45.57611750018212, 43.59462630364203, 45.098204151276626, 46.72238311459942, 43.359982275193744, 48.39339125540949, 47.56104861536334, 46.45010002197758, 51.18736220944313, 53.93329589597641, 52.00872221300679, 52.1783451111086, 55.17323555484895, 53.15505450771701, 53.91203664964246, 58.19835178313717, 41.79166570786507, 52.70127550248177, 53.867011762434444, 53.247324343650575, 53.9401404319271, 53.03330021519815, 51.84136644486458, 54.1806209471918, 51.436519007528986, 52.62458924324282, 51.28795139251217, 46.73258127704744, 47.579346472217196, 45.3638937396388, 45.425761284366736, 43.299871952303, 44.98351012506793, 42.00425032646426, 42.766676718188876, 40.57724891170379, 37.049339740507065, 39.86725676444269, 38.04397829117314, 37.818281189087905, 40.120002531236224, 38.03264264137515, 42.89620907075944, 50.94438314437867, 50.11395462097661, 51.24553488146875, 49.50224530312323, 44.511645070968136, 44.87616662056216, 51.00556819669662, 56.39659927737329, 58.061633648410925, 55.73243218083536, 49.529140995394805, 51.542454381142896, 57.14022967123217, 58.12010442056964, 56.50903009599256, 54.85586481709635, 47.09227831132951, 45.54308329859088, 45.939909488924094, 50.71568150674143, 56.552607628606985, 59.55813946262483, 58.38500953489735, 59.055036652472715, 62.733180446009484, 60.79111299207134, 57.22202677880564, 56.32890701293946, 53.373440311801055, 56.21507590816867, 54.651842732583326, 54.36626672744752, 52.90534073306669, 55.43834463242562, 56.855077282074966, 58.3287117558141, 65.79104846523654, 71.87318940316477, 68.04810185586253, 82.41754024259507, 19.980857641466205, 0.8754798866087391, 2.178213259866161, 0.005488973533389189, 47.11204705699798, 67.42111098381781, 68.73272803521925, 57.577409205898164, 32.37433929597178, 42.89879783507317, 92.1779191109442, 58.20454912800943, 38.31751261987994, 76.00676351977934, 68.50734080037763, 0.904722320697, 0.02288804693718351, 0.05832297847636285, 0.023082185108515046, 0.052833947007574385, 0.016070262776807915, 0.1448122826555083, 0.04880856865295961, 0.08090543485577069, 0.14793490300015097, 0.2841661888505182, 0.3809818679526929, 10.474095306088849, 74.56338620954945, 56.93650568685224, 38.85423406477898, 62.00658882817915, 118.16549639548026, 61.883865710227724, 50.57182858067174, 74.06389590232604, 68.80476628580402, 83.36768734839656, 30.764735860209314, 0.8441642960233073, 0.9928615331169098, 0.16503859731939532, 0.08714954173492809, 1.4236873796870633, 67.24601637932562, 64.86789903333111, 68.51827636841806, 59.56489378406156, 60.92726630549277, 54.4610978711036, 60.394165208262784, 52.92041832400907, 52.86841946263468, 49.6862554550171, 50.49224368987545, 48.58910968226772, 53.67771817791847, 54.53785865537582, 59.36650030074581, 58.529568487598056, 63.31124759489491, 59.078978800004535, 56.566473207166126, 47.91479933646418, 48.69186793604205, 49.0715729805731, 57.45825152243338, 58.97918585808047, 61.97876745654691, 56.11019565213112, 62.1649702133671, 59.993667679448286, 59.24008231009207, 58.389728146214644, 59.78969266337734, 57.06909748815722, 51.78845367124004, 50.4691566190412, 49.66432548338368, 56.69632719409082, 55.38102311472739, 55.733601047146706, 55.75513093702255, 46.64379058345672, 41.3502460910428, 41.070992946624756, 42.5685421113045, 39.375391544834265, 41.09482526779175, 39.97033273020099, 42.16916245798911, 41.823499664183586, 44.449691234096406, 47.16498728721373, 47.862922068565126, 48.25600631775395, 48.088360294218994, 47.265662762426565, 51.94320294164842, 50.72780947531424, 48.77976432923348, 53.20030689239503, 56.88362036981891, 53.578870527205936, 53.65724340561898, 57.58422236288748, 56.072427149741884, 56.855277322953754, 59.52845104279057, 42.82531222989483, 53.75595769574566, 56.595377152965916, 56.521769954312234, 56.811346777023815, 55.1271673171751, 54.914735671012636, 55.887063780138575, 54.42500814314812, 54.02425958264259, 54.05621121006628, 47.358995560676824, 47.509602808183246, 47.51392918248331, 48.42687260720038, 45.31616633938205, 47.620499980065134, 45.56643316822667, 43.39930011380104, 42.30017354411464, 39.07452221839659, 42.30468034744263, 40.37743160801549, 39.723078281648704, 42.35057992319907, 40.381899187641764, 44.24455519645445, 53.871216543259166, 53.401214614991225, 55.92738574550998, 50.85283894692698, 46.967578318811235, 47.57170961749169, 53.1204003672446, 57.26672610928936, 58.79710943468156, 57.403848248143355, 51.84966618014921, 51.465187611118445, 61.07666154061595, 61.249912631127145, 58.898310507497484, 57.53094873120708, 52.30652424596971, 48.22190523147584, 48.33985874729772, 53.781237371506236, 60.30873598590974, 62.238789220010084, 60.824245252916896, 61.01797111572758, 67.13423667415496, 64.11956964000579, 62.519360280806026, 58.65729262751918, 57.40993576665079, 59.38130724814631, 58.869520310432684, 56.888527254904474, 58.60696861820837, 57.85940408706666, 60.160576297390854, 62.24162509364467, 69.34709672004946, 75.78229411955803, 72.5580430799915, 83.71518581144272, 19.719874897310813, 0.922051535979394, 3.9610084602909708, 0.06414406309505144, 50.90883470350697, 73.45919193760042, 74.2458781888408, 64.38383933036559, 36.61801238213816, 49.59285205410373, 97.61420649866905, 54.17175639060236, 47.30510611687937, 80.76654403440415, 78.01786468875024, 1.3801102147948359, 0.03786063978388425, 0.06632091342321327, 0.05337498128233899, 0.07203863362871832, 0.29666705838134216, 0.1970094841934981, 0.2601286480503698, 0.1801694773377911, 0.2936941775823793, 0.4358398307475352, 0.5320980736324864, 16.82432632292471, 87.22797424562516, 64.73483654760545, 50.82087555239278, 54.238389615089666, 106.86203356712096, 71.1208160461918, 59.31354830341955, 81.62682963955788, 73.48220056103122, 89.86623887092837, 34.283943253178755, 1.865580745281712, 1.813568400759851, 0.3540569417659314, 0.5530721513975052, 1.9407316417463365, 70.80838357248615, 68.55301287866408, 72.37722965978807, 61.57387295076924, 63.810157391332815, 57.15067494300104, 63.56999851042225, 53.93205642700196, 56.51578441742928, 52.674775969597604, 54.35647649149741, 53.4045054835658, 56.000361442565925, 56.854971378080315, 62.528154234732355, 60.229500186058786, 64.95971387432468, 60.636159758413996, 61.2838097541563, 50.250594308299405, 53.00171729057066, 51.41247487837269, 61.366544308200965, 62.00874220940375, 64.32470960001793, 57.4238758702432, 65.74466251557874, 62.76848177756033, 62.234576594445016, 59.917405036187944, 61.05393532783755, 59.84548837907853, 55.68470478057862, 52.18354617395709, 52.45031049174648, 58.42292708735312, 60.470090527688306, 59.99433840474775, 59.030914075912975, 51.496084120965776, 44.20668471244074, 43.31567518172726, 45.49713665439237, 41.10385064155825, 44.077528907406716, 42.02920444550053, 44.837076279424856, 44.1803656085845, 47.89837637255269, 51.09009135153986, 48.65376603218817, 50.7849701758354, 50.48722697842506, 50.164910131885165, 56.003413046559984, 54.35455453011298, 51.25573304391677, 55.61061513039374, 57.96647302566036, 56.99591782785232, 57.26779299397623, 61.912369574269945, 58.668628277317175, 58.604336707822746, 63.4827140069777, 44.59159081982028, 54.85888504212903, 58.12772166344428, 60.418138734755985, 59.34180898051108, 58.52514013167351, 56.481526436344275, 58.682890015263716, 57.514988606975926, 56.71294627651092, 56.44695466564548, 51.56548261642457, 52.70840637145504, 49.4049548333691, 50.411846868453495, 46.7454231169916, 49.56221442068777, 47.541499522424516, 47.04479409802345, 45.8122794858871, 42.125847724176225, 44.232007534273215, 42.85864845398934, 42.574774757508315, 45.0161010988297, 42.94380703280049, 46.86759318074873, 54.858747759173, 55.80579227016818, 59.76410704274332, 54.044738277312256, 50.83386644240349, 50.60282707214356, 56.04565305094565, 60.9191587663466, 62.4939315549789, 59.33421527185748, 52.68236575588104, 54.42212520107147, 63.14703364526073, 63.54836663892193, 60.59302937599921, 59.36951268103815, 55.8351041424659, 50.50864704193608, 51.73909848736179, 58.12320701537594, 64.04084374827724, 66.17064368340277, 62.217961434395086, 63.933260979190955, 70.16418918486565, 68.80175390551167, 65.25211480356032, 61.99016194189749, 59.72984121691797, 63.159040020358184, 60.75796896411527, 61.04616119015602, 61.00744739655526, 59.5571235687502, 64.03002977371216, 64.86975039205244, 73.68093136818179, 78.87791495169364, 75.47652183040496, 87.70620530651462, 26.866454924306563, 1.083961460859545, 6.73419967774422, 0.33568428408715034, 55.510771197657434, 80.78225704931444, 83.59016418457031, 74.09529055318525, 44.24346869991672, 60.34091118843325, 107.06399640729352, 74.15225905756797, 53.98998198970672, 91.88509064335977, 91.393445076481, 2.5553467004529895, 0.31174657986529414, 0.14845725239044236, 0.13532394663460795, 0.1837646973229224], [0.051694379728888316, 0.03754714511394982, 0.06658273163221537, 0.07684464025641642, 0.0649680634359679, 0.07095534699938952, 0.1090112166298974, 4.281942671345127, 66.48830075417796, 53.38377575720511, 43.28538271688646, 16.454762566474177, 28.46662505980461, 42.272630660764634, 35.764249678580995, 68.33615287657707, 62.04200783083516, 67.8545093536377, 47.36178828823952, 0.30939260617859904, 1.2993428519656582, 0.16362727950176886, 0.09417039282139271, 0.8156287465845385, 58.8046129288212, 66.35727005620157, 61.760616994673214, 56.65902545375209, 54.71756204482048, 52.86494032029183, 50.725232478111025, 50.6191284425797, 47.81727352449971, 48.522586284145234, 50.20778163786858, 51.72244410361014, 54.81385623255084, 57.78373372170233, 59.974593193300315, 61.93795911727413, 61.05863824967415, 53.769207462187744, 49.619084865816184, 45.02324373491349, 48.90842983799596, 54.43816769507624, 55.428507328033454, 61.90923952287244, 55.91966259864069, 56.54226433846259, 59.2820869722674, 58.27894864543792, 56.598601341247566, 56.30446672439576, 52.93250314650997, 48.14820389593802, 50.04636826053743, 48.718371391296394, 49.387621879577644, 54.16778302961781, 51.254066036593535, 51.61888960869082, 48.4615110581921, 50.260631653570364, 41.14259973649056, 41.59582176516133, 37.90959004432925, 39.64571345236994, 40.08072391633065, 40.70868361380793, 38.06453543324625, 40.779125459732555, 40.506944348735196, 44.76907807011759, 43.5882838310734, 45.38048536546769, 45.07348537445069, 47.3510370715972, 49.0642342259807, 49.913784303972804, 47.268726133531146, 52.22642552468085, 51.79257608229115, 52.72163260367609, 52.03715155201574, 54.05271245587257, 52.608754634857185, 54.148430055187596, 57.60630138458745, 44.976175292845696, 52.945352831194484, 55.45715239740188, 52.79816981284849, 55.63473770695349, 50.58183062461115, 53.99603028451243, 52.77121136265417, 51.629346647570216, 49.56280277621362, 50.34717482905234, 46.48435015832224, 46.26488962481099, 44.18913995065997, 46.00036105801983, 45.16265261557795, 44.802881056262606, 42.487878568710826, 41.72304776407058, 40.739227110339755, 37.82500805393342, 38.70062620409074, 38.37166094010876, 38.57636551703177, 36.89588092988537, 39.12524238709481, 43.79804434314851, 48.04709303763605, 49.72430244568856, 52.88407756436256, 51.27653337294056, 43.508702862647276, 45.555925138535045, 48.718516518992764, 55.103499735555346, 57.09004686724756, 57.29710486627395, 57.45087354413925, 51.7009416703255, 49.56068861869074, 57.31040562352827, 57.88274218959194, 55.250635685459265, 51.37487896027104, 49.14441923941336, 47.26376041289299, 46.65039977719707, 54.267328862221014, 56.97154814197172, 59.9089954745385, 60.46463843314879, 58.179567552381954, 62.878296375274665, 60.577936095576135, 59.58703164131411, 59.564846715619495, 59.26204758305704, 57.42563701445057, 60.12023472016858, 59.4934085876711, 58.49492611423616, 57.578138766750214, 61.63388913677585, 68.2750972624748, 70.39798598135673, 76.19558641987463, 61.12675805245677, 0.9758788960114603, 0.05455342752318229, 0.8788044017649467, 0.6640436644515684, 55.76128121345274, 65.36208237371137, 69.9636148637341, 59.439299491144, 51.07492354608352, 51.87394565151584, 59.19331981289772, 46.60033072194746, 48.192420774890536, 78.25551325275053, 64.96859019802463, 0.29026633248694483, 0.02589753716282787, 0.014837576553315647, 0.01820036450461034, 0.07248882519742174, 0.03194941917524463, 0.06886129928452354, 0.015731380910672728, 0.11717363831497009, 0.088488778339759, 0.08262934719002055, 0.2989389687295883, 7.558454390495055, 74.98541755060997, 59.768237298534764, 42.21804695744669, 34.88608198781168, 55.92976662420458, 45.45497117503997, 47.42446776359312, 74.65866842577535, 71.15375611089891, 75.04324113169025, 51.26016924458166, 0.5180004010758092, 1.750293460584456, 0.13445385461372716, 0.06737604632132477, 0.8349660315340566, 63.06851956152148, 69.0089491874941, 64.83587680324432, 58.36831984981414, 56.29343309710103, 54.11335622110675, 53.13294410705567, 53.30202964044387, 52.447094148205174, 51.62370627926242, 53.23598869385258, 54.86049713626985, 57.76953474167855, 59.42497107290453, 62.213933160228116, 63.98053730687788, 62.61453659303727, 54.689011112336196, 50.84406460485151, 47.7024971285174, 52.05393929635325, 57.902907094647816, 57.84154161330193, 60.094382378362845, 56.629819485449026, 60.089569630161414, 61.51830473253804, 58.97656179243519, 60.821809461039884, 58.5072619684281, 56.92669976142145, 52.427780397476695, 51.97033789850051, 51.54121883453862, 50.79959669420796, 56.34853455328173, 53.887761100645996, 54.26854087460426, 53.63894162639495, 52.01186010914465, 43.78897190093995, 43.11366135074247, 40.12437989634853, 40.80243610566662, 40.77637587824176, 41.79235212264523, 40.01507912912677, 43.332721802496145, 42.12114480233962, 47.816194872702326, 47.34050158531436, 49.37623916133758, 45.48376921684512, 48.136173986619525, 51.323472376792665, 50.86213496423537, 47.643959676065755, 52.70232669768795, 55.111666110254106, 55.32882421247421, 54.10855916238601, 55.38522789555212, 55.576074738656324, 55.67475764982162, 59.03393430094565, 45.72336327645087, 56.03734547092069, 56.32234881001135, 56.140762682883974, 57.303780740307225, 54.2583348674159, 56.45845113262054, 57.385001259465376, 55.83985413274458, 51.89660518400131, 53.39277759675057, 49.58485041895221, 47.90730760943505, 47.085669117589156, 47.38569513443978, 46.85606925718246, 47.158103527561316, 46.08225622484761, 44.05778369595928, 44.52563224300262, 41.26025122980918, 40.54664657961938, 39.80551865793044, 40.31512475782826, 39.70265450016145, 41.72668772359049, 46.993289455290764, 52.47988908521591, 53.96630264097645, 55.685359816397394, 54.09097909927369, 47.493230835084, 48.907919929873565, 51.27985954284669, 57.163097089336766, 59.03156518936158, 59.10221884327551, 59.18627523606824, 53.336723004618, 49.33234783910936, 59.71953715047529, 61.00713360694147, 59.032612462197584, 55.109159715714, 50.405465172183135, 49.54460690098424, 50.070157435632524, 56.23600959777833, 58.647302350690296, 61.7988169577814, 62.75651854853477, 61.978673319662775, 63.91309215176491, 65.00584879229146, 62.45659451330862, 62.67884385201239, 61.09203330932125, 60.580054175469186, 64.5400869461798, 62.32836831000544, 60.80062081736904, 61.121584446199485, 65.30017168291154, 70.49995191635625, 73.442702293396, 78.05791993294993, 63.10376205751973, 0.8541248486407342, 0.04267041556416981, 1.5229077781400375, 0.8732283235557619, 61.484741010973536, 74.22187328338623, 76.42480973274478, 66.6378999525501, 51.93154957986648, 58.53722103180424, 69.54729449364447, 60.424626335020996, 49.113122647808446, 83.4524497678203, 75.29505729675293, 1.5269382586402278, 0.0978929136369017, 0.0314600843440501, 0.009792792768548093, 0.05165978319822781, 0.10093920098076906, 0.24123279828458066, 0.22201203530834568, 0.3499232539005818, 0.3038386832321844, 0.2999570382939231, 0.6531470136777048, 10.227631215126285, 90.91744192184942, 68.75543071377662, 58.20117981203141, 24.56999740292949, 41.701502184714045, 56.880435405238984, 51.74020067338021, 80.51405322167182, 77.25142571233934, 78.91740537458851, 56.83361799486222, 1.0053593076525196, 2.815239025700477, 0.4992984175201386, 0.8053190417347417, 1.3570056158688761, 65.12566935631537, 72.59339147998442, 66.51203893846082, 61.15954514472716, 61.81028989053542, 58.96911713384814, 55.58535506648403, 56.72994975120791, 55.02253809282857, 53.23055228879375, 56.831315563571074, 56.95219516754151, 61.0417289118613, 62.8654545353305, 64.4221491198386, 66.74483945292812, 65.10077799520185, 57.806299117303666, 55.889440736462994, 51.237541091057565, 55.49129270738172, 58.90524133559197, 61.81944862488778, 62.18662561908845, 57.95325071580949, 60.202420142389116, 64.46585216829854, 62.29880148364652, 64.07501935958862, 60.001230009140514, 59.31060652579031, 54.011190245228434, 52.315890865941206, 53.94503947227232, 56.350884053014944, 60.58284690303188, 59.57434277380667, 59.31915337039579, 56.998828226520175, 54.923082474739324, 47.20270087642055, 45.204747492267245, 42.554154857512444, 43.20839051277407, 43.26359787294942, 43.42419147491456, 42.36202932173207, 45.51707406197825, 45.93997224684685, 50.21101759326074, 49.67960311520485, 52.940379265815984, 47.5156589477293, 52.72341335973432, 53.96522398917906, 55.214377295586374, 50.13659454161122, 57.38443643816056, 56.91151626648442, 58.781302282887125, 57.216743346183534, 59.41006214387956, 57.68711397724768, 60.708401972247714, 62.058062091950454, 46.05853373004545, 57.211318708235225, 61.42795293561874, 59.44223734640307, 61.49014211470082, 57.71711226432555, 59.74136121811406, 60.592037016345614, 57.51198799379411, 53.93947755136798, 57.491470075422725, 51.356043738703576, 50.90164892135128, 49.29772507759833, 50.41829916738695, 50.222121823218565, 49.901303322084495, 46.94302035916237, 46.87878370285035, 47.566708595521995, 44.1820090816867, 42.96683134571199, 41.932055181072606, 42.31042661974507, 42.415538295622795, 45.290392444979766, 50.0834228915553, 54.76419902616932, 57.11191800332839, 58.00410816746374, 57.77578699973322, 49.623328870342625, 49.49690695731871, 51.66624438378119, 60.06838098649056, 62.76839548541654, 60.68525606586088, 59.366563058668575, 53.56907636888566, 51.84020934566375, 62.01531610181255, 63.249764442443855, 61.7808093563203, 56.144520313509055, 54.08109080406928, 52.72375460593931, 51.74103613822691, 60.74745701205347, 61.166727004512666, 65.5625194118869, 63.60915160948231, 63.41964229460686, 69.29970664362754, 67.73207649107903, 65.96755904536094, 65.37053900380289, 65.96353469356414, 63.9148493736021, 66.99516511732533, 66.74840880978492, 63.36363477091636, 62.74803446185205, 70.66825297570998, 74.48636654884585, 79.29478445360738, 81.30775267078032, 70.7123561059275, 2.0700730239191363, 0.19106528541493803, 2.717696788810915, 1.1316015883799524, 68.78298144186698, 78.62670283163749, 85.12258714245212, 73.44401236503356, 63.571367417612386, 72.57582710635278, 76.93331364662417, 62.03267651219522, 63.343771888363754, 92.57264291086506, 89.73083865258002, 2.4494542277628377, 0.35013981163501745, 0.14375851339390203, 0.11982208853887936, 0.15379737551894881], [0.022401818592521935, 0.03846589520934128, 0.021577774201549833, 0.08617266471828185, 0.0312036344961774, 0.0679086383071638, 0.18819864568931444, 3.2046315891127435, 63.37828090113979, 56.0851199396195, 54.64445690954886, 37.96432279771374, 34.23139133761006, 42.4566408126585, 44.243150987932765, 62.382014566852206, 68.77742736570298, 57.67830041147048, 68.45454569785826, 2.065551756851135, 0.5188627709304133, 0.19432869739830497, 0.11038007785476024, 0.1775513412130456, 46.73533870327858, 71.5939401811169, 61.54438457181377, 63.55770187993204, 52.70009879143008, 53.449620585287775, 51.83683610731556, 52.05886971565985, 51.728421795752745, 54.89797146089616, 54.198330448519805, 56.829103346793886, 58.78643274307252, 61.72366826764999, 60.2946585993613, 57.64067311440745, 56.5039663161001, 50.061006546020515, 46.36032873584379, 44.62477799384825, 56.467923656586684, 52.55096635510845, 66.20694129697739, 77.62615326912173, 54.63336444670155, 59.3987500283026, 53.29234530848842, 57.411583162123165, 53.68182882185906, 53.1714774716285, 49.602579532131074, 50.03534247798305, 53.28475159983481, 48.032717550954516, 46.956470166483236, 54.95323765662409, 50.95098449337868, 52.06860896079771, 51.387814937099336, 53.987977658548665, 45.986283671471384, 45.28550124937489, 39.478989185825476, 41.99921792553317, 39.27073486389653, 39.13059642238002, 39.70438818777762, 40.556868276288434, 41.12759274821128, 45.871322924090975, 45.24683060184602, 44.6291906602921, 44.566016966296786, 47.368154295029186, 47.90444035683909, 48.069462314728774, 48.145571985552394, 50.32276199709985, 50.95718576062111, 52.694168167729536, 49.65799870029573, 53.40607050926455, 51.55722602721184, 53.54069017594861, 57.11969606338009, 49.19069536270634, 56.85998416716053, 55.142346889741965, 51.4105176156567, 57.54178231762302, 52.3209781800547, 50.93850351149037, 50.94864676075598, 54.507954505182084, 48.01855779463246, 48.84358913667741, 50.02627003577448, 45.09388169934673, 43.03603372266216, 47.856736490803385, 44.275012400842485, 45.02667580881427, 42.15343375359812, 42.706103555617794, 38.803933589689194, 38.95609017341368, 37.68121396341632, 37.348851926865116, 38.26384282881214, 40.07148673457485, 36.99870194158247, 44.769368325510335, 52.139270459451986, 54.90886388286468, 50.43113316259077, 53.033492411336596, 46.27998682760423, 47.08086421412807, 44.343312632653024, 48.47543547230382, 55.30651377093408, 56.52833207961052, 57.05369434049053, 57.50852846330213, 25.84455001738764, 43.838793846868704, 59.11847706763976, 60.314184158079094, 58.939597375931285, 53.32172778344924, 47.56628497954338, 46.27885326262444, 48.925676499643636, 51.74814347297915, 56.35311588164299, 60.71082991938437, 58.137480520433, 60.45108272183327, 60.871866749178984, 60.98490945754513, 57.96906571234427, 60.981293032246256, 61.269096943639944, 60.593001919408, 62.669955761201926, 61.78265679267145, 63.94131360515472, 63.39876351817962, 68.95951163384223, 64.42385142849338, 84.04965416077646, 18.03983549917898, 0.625365233469394, 0.19201356436937086, 0.44760320275541277, 2.167485087148605, 62.18138141016807, 57.04498275633782, 69.17505371955134, 69.62921711706346, 61.2017184688199, 46.41962320573869, 50.65735193990892, 26.791621984974032, 50.194147479149606, 73.64104870826968, 68.81536453000962, 0.934592885596137, 0.04575440975567026, 0.12665799067866418, 0.06592835464905347, 0.13525205694379347, 0.018703965808174784, 0.05836029461915455, 0.05262259484058427, 0.08562555536627771, 0.11262503722983022, 0.026717523203021096, 0.2611425807399135, 5.273365859062442, 77.514098998039, 60.08023046678113, 56.0716034520057, 20.363555454438735, 25.968353748321537, 53.18110689040154, 47.04809673370854, 68.13134239565942, 73.50394618126654, 67.0946599591163, 71.48394907674482, 2.176168724413841, 1.2556982713360942, 0.10144422146221323, 0.05904402043069563, 0.19686919817280388, 49.279387997042754, 74.34327848495977, 65.26479190395725, 67.12999266962852, 55.69402040973787, 56.34246272425498, 52.56942502913937, 55.545982314694314, 53.77355344833867, 57.71174646192982, 54.87875576942198, 58.49117632835143, 62.009711034836315, 63.836503951780266, 62.314271311606134, 60.515676313830966, 57.8792042116965, 53.01801473863664, 48.60166126681913, 46.731016251348684, 55.64128022040091, 56.93641547233828, 63.938607169735825, 72.8242386541059, 57.15031016257502, 60.20347525996547, 56.483828867635424, 60.219372626273866, 58.373642506137976, 56.12234715492495, 52.88272434665311, 51.55942647687851, 55.36030515547722, 50.41394533649568, 50.35615705674695, 58.09032970859159, 52.98171320269185, 54.85794759565785, 56.266109866480676, 56.5307717938577, 47.266372711427756, 46.57387433513519, 42.12001123735982, 43.048451946627715, 40.627235597179784, 39.79483412158105, 41.591624829076956, 43.12483226099322, 41.63490426155829, 51.242518578806234, 46.63758147147394, 46.43619914208689, 47.54937171936036, 48.88369929405951, 48.45298774780766, 50.996146663542724, 50.54954951809299, 53.104506923306374, 53.43307995027112, 54.4697545420739, 51.0159860118743, 56.61200015775619, 55.72108084155668, 57.711436594686205, 58.53799373872819, 49.43248202723842, 56.99409392572219, 57.844738344992365, 55.9094605138225, 58.70761271445983, 55.79755137043615, 52.36421446646414, 54.27908028325727, 54.904517896713756, 52.03091890581193, 51.90286136442616, 52.64282041980375, 48.123355680896395, 45.59838479565036, 48.310856742243615, 46.289788830664854, 47.31554354390791, 44.67124631327968, 44.975532024137436, 41.50672512669718, 39.77250406819005, 40.63301717081378, 41.40996417691631, 40.629687078537486, 41.349375324864546, 38.82777767796671, 44.787501442816954, 55.29276586348011, 57.41337176292174, 55.061906922248106, 56.06965011165988, 48.29679504517586, 50.70940571446573, 47.4862450938071, 52.56968782794092, 55.85509254086403, 56.640194154554806, 58.972635499892704, 59.39491395027407, 28.698868597707442, 44.93920695397162, 61.422379247603885, 62.53471243766047, 60.725785916851414, 55.967225259350194, 51.559638284867816, 50.08467020527009, 52.090507553469756, 56.37448495434177, 58.68518460181452, 62.77809550685268, 59.29836873085269, 63.12548806590419, 65.53343503705918, 65.39768180539532, 62.716220117384395, 66.13787620298325, 66.73400586651218, 63.245092899568625, 64.64624197252336, 64.3679262745765, 69.05720218535393, 64.61061508424821, 72.30016293064241, 68.79526630524667, 84.32444757030856, 19.103792136715306, 0.7766511123026572, 0.5921909910055899, 0.804834261296257, 2.7539014912420705, 69.05324843622023, 66.54799922820061, 77.73975295405235, 74.55619258265342, 72.80949054225799, 52.229210407503196, 65.09764402143418, 39.771872566592315, 52.7399657618615, 80.46026968186902, 80.6174155204527, 1.7103477976014538, 0.14956639448721565, 0.10238692329655733, 0.05532538368096275, 0.06941596992434033, 0.1707385825894533, 0.19465929498114895, 0.14225684316648593, 0.13133278176669153, 0.26973395037554926, 0.4090860179595409, 0.4949812056316484, 6.938745398675242, 92.04321707448652, 69.12135647189233, 69.99915153749528, 50.18826000152096, 49.87412129679034, 60.593500060419885, 58.99184334662653, 74.3430902111915, 81.28717591685634, 70.30164472518429, 81.01491635845554, 2.693959830268737, 2.214564806030643, 0.6181562235278468, 0.3161638121931784, 0.5361503110297265, 52.23274838539862, 74.86153341108754, 69.44035499326645, 69.88271205655991, 59.04613679455173, 57.388374497813565, 54.31063575129355, 59.072365683894006, 55.22601889025781, 60.83686351776124, 59.59065198898316, 60.23065336288945, 65.03813774354997, 66.72339977756624, 66.4937057802754, 60.98437209283153, 62.926255195371574, 55.952653654160045, 51.626389180460286, 48.10963523003363, 58.91224276634955, 60.56217601222377, 64.73494637397029, 72.30562286992227, 60.18907231669272, 60.44225346657538, 58.5361502247472, 61.39823705919328, 58.26642059510755, 57.13493447149954, 54.97437138711253, 55.17742856856316, 59.80407991716939, 52.26007946075932, 50.853148814170595, 61.29838135934646, 56.813739422828924, 57.21274252860778, 61.27720056041595, 59.677222621056345, 51.242565647248306, 50.8011499527962, 44.35738609683129, 45.96678949171498, 45.27907640703263, 42.771493388760476, 45.07918065594089, 45.01709738085347, 44.855672236411806, 51.99391918797647, 51.41342801432456, 50.019166623392415, 51.267233433262, 52.508385104517785, 53.986553838176114, 52.908639446381606, 53.44991868542087, 56.12269624587029, 55.96455412526285, 57.8849151826674, 55.85604175444573, 59.92530468971499, 59.75563472317111, 60.54173654125583, 60.117022298997455, 49.82516619466966, 59.95592271128009, 60.442226009984175, 58.845915486735684, 62.85410711842199, 58.99899382745067, 54.533336162567146, 57.41818843349334, 59.982743878518384, 52.91396602507561, 55.49155550618326, 56.37989390280939, 51.493930739741174, 48.93732593905542, 51.723354093490116, 50.60927152633668, 50.04183007824806, 48.624524762553555, 47.78694968069754, 44.271960796848425, 43.41146338370539, 42.033726938309215, 42.67781149956488, 42.82477094281105, 42.30774371854721, 41.58402327568301, 47.81737550612419, 58.71002104974563, 61.818362128350046, 58.539731348714525, 58.85787871576125, 52.78468862656624, 52.278632271674375, 49.49442017462946, 55.16467694313296, 58.842934485404726, 60.876852081668, 63.17121113500288, 60.11622998022265, 29.99656515736734, 47.765921854203754, 60.81036398487707, 65.95584684802641, 63.50840945397655, 58.64656886746807, 53.337052483712476, 53.23175253406648, 54.43261754128241, 58.7916063493298, 61.105024199331964, 66.31627344316053, 60.15031929939025, 65.15986457947763, 66.83594042255034, 68.68182351512294, 64.86819321109404, 68.2186072872531, 67.40724148288851, 69.15275112275155, 67.83897676775533, 66.59093349210679, 70.42479930385467, 68.87425499577677, 75.97768306732178, 71.59036297951975, 89.02769104126962, 24.063301701699537, 0.6535432343521427, 0.8110457021863231, 1.959865086020962, 3.1523039840882827, 76.56583462992023, 71.3695727625201, 84.55807178251206, 82.68677173122283, 74.7874241490518, 64.41350421597882, 70.30695561439761, 37.09188568976618, 67.57094552440029, 89.0296051579137, 95.20995047784622, 3.4745144363372558, 0.3667366775053163, 0.29753736490684174, 0.2152210795470784, 0.23664195511129596], [0.048634930994481816, 0.0576980690652084, 0.0988190449894436, 0.02272014344681896, 0.03586157931074981, 0.07228425673900113, 0.12114722146502427, 3.12335517617964, 69.43227491071148, 54.454880914380475, 46.81102475812359, 75.86365192167221, 38.925036768759455, 32.81972639022335, 62.99592433437225, 63.38007734667871, 75.11167864645682, 49.71202934941938, 80.35375379746961, 7.771371920262614, 0.4266554784149893, 0.6985668345324455, 0.06828008369813043, 0.11549873262523644, 26.881083403864217, 80.74260188687234, 57.66619597711871, 66.44542924819454, 51.79806740053239, 54.92638903279459, 52.675113293432425, 56.685587744559015, 52.11030375572943, 58.20458835171115, 56.09460423069616, 59.152499706514426, 60.9867412044156, 58.604787780392556, 58.19478634865054, 58.70242341872185, 52.152284883683734, 48.234319533071215, 44.14056139607584, 51.088910718117994, 53.83684873580933, 57.871406539793945, 72.62326425121677, 53.72987001172958, 55.199880215429495, 58.79423825971542, 52.698572989433046, 55.408342422977576, 49.688522584976695, 50.9567189985706, 48.33541862426266, 51.89040391675888, 50.224102620155584, 45.436583103672156, 50.10297198449412, 53.51284919246551, 54.913955119348344, 51.13755595299506, 48.9206244868617, 54.045467838164306, 45.44481223629367, 42.5837020720205, 40.01103124310894, 39.76338455753942, 39.43804748596684, 41.312544268946496, 38.390849174991736, 40.63859870356899, 39.03640070269185, 43.444097503539055, 42.066608167463734, 42.03604898145122, 45.15002650599326, 46.23525611815914, 47.24279926669213, 47.97392906681184, 49.359259220861624, 51.278314128998794, 51.12209789214596, 53.084110598410334, 52.144244024830485, 54.13086960392614, 52.56941326202885, 53.607950979663485, 58.67387640860773, 49.97390639397406, 56.288016303893066, 54.49767005059027, 49.43191720593361, 51.78903025965537, 52.666684119932114, 54.21607525117936, 50.58013223832654, 51.35826380022111, 45.68400229177168, 46.86991130152057, 46.631960715017016, 46.39264122132332, 45.21407881090718, 43.1004664974828, 43.135505030232096, 44.48185074713923, 41.779984889491914, 38.463985689224735, 37.117616438096576, 39.49636136331866, 38.72701591061008, 39.387566581849136, 37.088849775252804, 40.64370562953334, 40.28460479551747, 46.51138705592002, 51.13429254101169, 52.042944892760254, 48.93587073972149, 52.571139104904674, 45.762304567521625, 44.87217364772674, 47.89333220451109, 45.859877447928156, 53.29880545216223, 59.64993076939737, 52.89729202947309, 60.00214392139066, 33.91974726030904, 24.244654447801654, 46.194192824825166, 47.79025231638263, 58.45218404646843, 53.96302746188257, 52.76432368063158, 47.95339153658959, 46.88628719698998, 49.27956842607068, 55.060141855670565, 56.68859620248118, 61.72004399761077, 56.60984285416142, 62.68182485334335, 61.477504238005615, 65.05881255672824, 60.492055800653276, 60.239823864352324, 67.1517147556428, 73.06831990518879, 65.01308556525939, 63.572277407492365, 63.849647814227694, 65.22406201208791, 71.35476973748976, 59.978801896495206, 2.2732488570674776, 0.2866017968664246, 0.2854438702906332, 0.5545095774915911, 3.3361927876549387, 69.32244070114629, 52.68770802405573, 66.96710448111257, 74.72748248807846, 49.844523091470045, 45.65065430056664, 39.26729102288523, 34.88612905625374, 54.751925929900146, 67.94503765721475, 70.6238046769173, 1.0637203147334438, 0.21571869961917403, 0.054051318175850384, 0.05241304298021621, 0.04556032521049342, 0.09946753841734703, 0.056324565347524426, 0.08366073136247935, 0.055593797906992905, 0.04482860399049617, 0.07657287822615716, 0.16115704431168495, 4.215709038319127, 78.07585300937777, 61.99490408743582, 45.05683883543938, 59.653170647159705, 52.67978091393748, 37.276076270687966, 67.5424926511703, 68.76340881470712, 84.00775540259578, 55.75926511518417, 87.78342893046718, 8.130770854411587, 0.6720897327027013, 1.1786250457648308, 0.09017489955670412, 0.1548581621459415, 28.12718314509238, 85.11710366895123, 60.42303385273103, 68.47532641503119, 54.811440052524695, 59.2537086240707, 55.28336394217707, 60.331332760472456, 54.76188090539748, 60.62827187199747, 60.63481438544489, 62.28478685502083, 61.88162995922951, 61.13068434499926, 59.70109416592506, 62.35333419615223, 53.80672885525612, 49.74962526752103, 47.19334994592975, 54.17620435837777, 56.372613983769575, 61.188225515427135, 68.72857816757696, 57.399408125108295, 56.34571436912783, 59.468458391005, 55.86282353247366, 59.20060757667788, 52.78508478595365, 53.85005143380935, 49.13611558175857, 53.6612363784544, 54.09288929354761, 47.33858354630009, 52.88765476595972, 55.56748082560878, 56.842533542263894, 55.74585453156502, 54.66382949582992, 56.262528742513354, 46.2024768706291, 46.131203482227946, 41.93378102394843, 42.54474509146906, 41.91737374951763, 41.7398198189274, 40.91497282828055, 43.643216625336684, 40.23853655784361, 46.25136137008668, 44.30398694930538, 44.5348302010567, 47.64761924743653, 49.99169826507569, 49.50259831643874, 49.791802513983946, 52.36750141266854, 52.370039186170025, 52.261962198442035, 54.88554146982009, 53.95190754244405, 57.58695233252741, 55.77983794673797, 57.08854459947156, 58.201976053176395, 51.18286325085548, 57.440895034420876, 57.30134494843022, 51.88005278187414, 54.03103351593018, 54.71653046146516, 54.56073391822077, 54.09361100965931, 52.21710205078126, 50.01094141314107, 49.310947387449204, 49.62249340549592, 51.28703748026202, 47.221751828347486, 47.819925046736195, 46.19405554186913, 45.8125344399483, 43.81809157709922, 41.61480603679534, 39.49125443735431, 41.65719116887739, 40.130263451607, 40.945586927475475, 39.53614204160629, 41.407516617928785, 43.916307726214015, 48.678186708881015, 52.62682891661122, 55.8298050203631, 52.592264990652765, 55.37891680194486, 49.69853247365644, 47.87295549146591, 51.078230104138775, 47.18116314180436, 54.22700297447943, 63.14726506510089, 54.41333516951531, 61.42964347716301, 39.68069707193683, 29.69221668858682, 43.490699183556345, 49.0231042523538, 60.47977878201393, 59.64668696926486, 54.858747759173, 50.56403483113935, 48.88826101056991, 53.08058830999559, 59.14025014446628, 59.841703291862245, 64.90020759644048, 58.69655947531424, 64.82376452415221, 66.36751528709166, 68.5641759441745, 63.72947423688827, 62.453315411844564, 68.96102566872874, 75.20485847227036, 67.51585975770028, 66.78481624972436, 68.22085088299167, 67.69849315766366, 74.39776805139358, 64.61242721926781, 2.7758834342802725, 0.5372577064460324, 1.1301246934360074, 0.6755101007799948, 4.156760227295661, 77.22004675096082, 58.619120121002204, 74.91865881027715, 81.00056048362487, 57.699171343157374, 50.3728114404986, 57.14395592289587, 37.48189480073991, 56.83250404173329, 76.55049816254648, 82.69365156850508, 1.4273847038707426, 0.1413436663607436, 0.11294222827399931, 0.07862008732533263, 0.026250778389493787, 0.2098327694881347, 0.19693053117202175, 0.2620606911518882, 0.1907742026472284, 0.15998961824563243, 0.17350333262114756, 0.26842118210850224, 6.211545323171924, 95.81709415681901, 69.29286603004702, 61.864767689858716, 96.08471747367614, 52.596508995179214, 44.202362260510846, 79.63028046392625, 74.51728267054405, 90.4850947472357, 60.498366894260535, 97.11762659011349, 8.976956029092113, 1.179599141882312, 2.361026353413059, 0.23242335406041917, 0.22205847555831557, 30.27805797515377, 87.7183646540488, 63.338410008338194, 73.0304454988049, 56.89783896169355, 60.416765905195675, 59.9815240213948, 63.56114572094333, 58.0278463517466, 64.31005954742432, 62.125770045864975, 63.74159436072073, 66.71779078821983, 63.62882229589648, 62.07333187903128, 64.60314689144012, 55.65002710588517, 51.70112209935343, 51.51728845411732, 54.64312722606044, 60.126259480753255, 63.09834134194159, 70.1068990461288, 65.07182698095998, 59.81419963221396, 64.56064016588273, 56.07608672111265, 61.16330669772241, 55.39639096106253, 56.95289727180236, 51.469933679026944, 57.61019629816855, 55.77016930426321, 49.05675818843227, 56.00153030887727, 58.696979168922674, 63.321896829912745, 58.562335968017585, 58.176555172089614, 62.27791486247894, 48.973364676198656, 47.59915444158739, 44.4456119691172, 44.35087888471542, 44.75777379928097, 45.82196774021272, 44.053782878383515, 45.610799097245746, 40.94247648792882, 49.39141481153427, 48.371955502417784, 47.71320912145799, 50.658944422198886, 53.5690999031067, 51.50121458115117, 54.21094479099397, 56.69324813350555, 54.21785600723759, 55.72047287417997, 57.27690465988652, 57.838654748855106, 60.811285741867565, 59.54070060483871, 61.26776333778136, 60.6455812915679, 51.732108823714725, 60.9669057784542, 60.51750021596109, 54.767172182759936, 58.67434317065824, 59.160615090400945, 58.71384928303381, 57.502331118429865, 55.99853361806562, 51.51060865771387, 53.531449071822635, 52.201487095125266, 53.30170800608974, 50.97337730469243, 50.57177758985951, 48.82146696890555, 49.17394291970038, 46.12182117277577, 43.5111935677067, 40.48430050573042, 43.180471081887525, 43.055904449955115, 44.53122554286834, 39.45844381086288, 44.51815620545418, 46.54715514952137, 52.25988726462088, 56.787173209651826, 61.680737926114, 56.218025530538256, 58.58564661395166, 51.69867846273607, 50.84793598421159, 52.949898858224195, 49.691448673125244, 56.00347188211257, 68.30606045261507, 56.13045077170096, 66.11893899979131, 33.657070052239206, 28.30291513473757, 51.328520467204434, 50.064505300214215, 64.23191416648127, 60.214595179403986, 57.73329988602669, 54.726630564658876, 51.05169526992306, 54.68499460527974, 62.86508191016413, 61.01462141160042, 67.89394486335017, 58.649185088373, 66.2357158045615, 68.59892814390122, 70.78319411123954, 67.18097563712828, 63.79202819639637, 69.45740161403533, 74.61080766493275, 72.71228636464765, 71.11143373673963, 71.11324587175923, 72.5630872480331, 77.56816494849421, 70.12318472708426, 4.053574925468815, 0.7214367041184057, 1.790582330957536, 1.763651459928482, 5.016181930418938, 86.2815926151891, 66.2588656333185, 78.97185571732061, 88.09164093386742, 64.03567014201995, 62.61517986174553, 57.20687858520016, 46.04378169582736, 74.41247693953976, 83.08806942355248, 96.64622045332386, 2.1353429796234256, 0.35794011888004124, 0.22596065165294757, 0.16720357711517042, 0.22611123389534413], [0.09129051509643756, 0.06272396590981273, 0.09148086496298352, 0.023375491446424878, 0.08945096179001755, 0.12522832505525122, 0.15098013314268283, 2.003965642183058, 69.05650400346326, 55.412017683829035, 49.50169617129911, 36.78179487105339, 18.73191418186311, 43.793867018914995, 51.19961177149127, 54.549900331804835, 76.17038126914733, 50.79474864467498, 75.46220517927601, 26.408074978859197, 0.2396034365219455, 0.8726733694634131, 0.16032187057839287, 0.15791099188068222, 8.050243123885124, 74.52323682846563, 56.38089018483316, 63.576109563150716, 54.707893402345725, 58.18719263999694, 50.48363016497705, 57.82598157082835, 54.53486980930452, 60.67588944588939, 57.133804828889915, 62.43086376497823, 56.106598838683105, 61.12454975804975, 55.97029255282495, 56.8974781036377, 50.65248820089525, 47.14276313781739, 46.81093062123945, 55.811044323828916, 53.29983703551754, 64.16980343480265, 43.40229680461269, 45.60915562414354, 64.74528181937434, 53.16585671517157, 56.1239984727675, 47.149639052729455, 51.021677370994325, 50.746946719384965, 49.271433430333296, 52.93204422919981, 50.8879598494499, 48.33239839922998, 53.370074918193204, 51.928325391584835, 51.30604920848724, 52.92544680256998, 50.44452021198888, 50.70507541779549, 50.683945609677224, 44.350835738643525, 45.78340299667851, 40.97092543878863, 39.66124211588214, 40.570773078549294, 39.34688375842187, 39.076397111338956, 42.28135793439804, 43.158129261386016, 45.86320361783428, 41.79745904860958, 44.82802344906715, 43.85873909919493, 45.316778229128936, 46.498698188412575, 51.007411710677616, 52.16194175904798, 51.500418340006185, 50.96919998045891, 52.51728496243877, 52.36519505900722, 53.921587621012044, 53.15773348654471, 57.84833123607021, 53.83088281077724, 56.089505149472146, 51.851682278417776, 53.95901487719629, 51.28293468106178, 51.44426961098948, 50.68071749902541, 49.79172014421033, 49.026905029050766, 51.21702709505635, 47.861694366701194, 48.00291930475543, 46.36745568244688, 46.82025409513905, 44.477700879496915, 44.9303973105646, 42.945638779670965, 41.773905215724824, 39.357156445903165, 36.54473466257895, 38.45079868070541, 37.10770460867113, 37.32033237334221, 39.16720390319824, 40.840439950266195, 43.89385607934768, 50.88076622255387, 47.7252233412958, 47.518377150258715, 49.56832155104607, 52.11365345985659, 52.031001275585545, 42.88307305305235, 49.51311811324089, 44.56151800770914, 47.242183454575084, 54.92491029923963, 56.62723464350547, 57.72574147870464, 58.86291503906251, 52.55115462887672, 45.68303346633912, 47.93189302567513, 53.16086353794221, 57.79861911650627, 55.071355911993216, 49.439267727636526, 49.677041807482325, 47.200661243930945, 52.352302228250814, 57.477369154653246, 60.02286188064083, 60.84023283373926, 54.148998798862586, 56.94410331787602, 60.66269851499989, 67.92646915681901, 70.84000572081536, 62.912617114282426, 55.03072015700802, 60.76214628834879, 61.73143456059118, 70.93201668031755, 64.48833911649643, 72.43195456843223, 41.71450484183527, 0.366178046190931, 0.315458337145467, 0.36422495099325336, 0.5418294127429686, 5.690622695030705, 76.1840154278663, 56.66373622032904, 69.21602679837135, 73.27322452299057, 60.16688346862794, 48.861977208045225, 32.699068400167654, 38.64990211302234, 64.95158672332764, 66.00853212418096, 61.40794492536976, 0.4642526222573173, 0.17304456852857145, 0.03648130230665688, 0.15506509781604813, 0.09359633249621238, 0.009230791624905843, 0.05261709815972755, 0.07874311338509284, 0.06461293571778844, 0.0615521386686352, 0.12471536790291149, 0.3302215562472421, 3.2576492861393964, 80.10043144226074, 64.32789456459784, 55.987115598494015, 57.61648777992495, 26.818486298284224, 46.39156649189611, 61.6409807820474, 59.02132780321183, 83.5269198879119, 57.60367731894217, 82.38469431477209, 29.73986368025503, 0.09481256602392082, 1.074573758148378, 0.11464300475293591, 0.336979371044905, 9.03052285794289, 77.50139051868071, 60.13442585545202, 67.06044120173301, 57.022644858206476, 62.175497854909594, 54.33568400721396, 61.13910175138905, 57.25536300290016, 62.861700827075595, 58.74364752923289, 64.18281001429405, 57.843008579746375, 62.32873309043146, 60.1409173780872, 59.02735648616668, 52.61397530955654, 49.98172760009766, 48.11035302377517, 57.675119369260734, 56.80385504999469, 65.09353729986375, 44.317652486985736, 46.74061429116034, 67.2358339063583, 54.9038746280055, 57.62734882293209, 50.1015716983426, 52.6664880014235, 52.07679494734734, 51.20559730837422, 54.32194002213017, 53.29204720835532, 51.447717374370946, 55.23991584777833, 54.57203426668721, 54.49353587242865, 55.431272599004934, 53.380873203277595, 53.678302611074145, 52.42997692477319, 46.11554930287023, 46.67405166933614, 42.5542607615071, 42.31045407633628, 40.696277156952895, 39.998667932325795, 40.95001920577019, 44.86796886690202, 46.94228295356997, 46.639703473737164, 43.82306122010754, 46.09965585893201, 46.08116580593971, 46.33322908032326, 48.96973648378926, 54.1889089153659, 53.447514272505245, 54.54094948307161, 51.448984299936605, 53.16484866603729, 54.420450349007886, 54.74048829847767, 57.30667152712422, 59.1691227113047, 54.151069810313565, 57.20629807441466, 53.60851187859812, 56.18927455717518, 53.86370520437918, 55.29344443351992, 53.81751929560016, 51.998751548028764, 51.5884441714133, 50.90115470270957, 49.1922172423332, 50.67245306507234, 48.794712481960175, 48.339344916805146, 45.615243142650975, 46.84583187103272, 45.44879344201858, 43.9793872833252, 41.791551959130075, 38.45343451346121, 38.45547414595081, 39.87884736830189, 39.19424080079602, 40.83450932656565, 43.36428903764294, 45.53331659686181, 53.45249176025391, 52.950110666213504, 52.20324431696246, 52.5823139375256, 57.39734495839765, 54.166508259311804, 46.59585137521067, 52.290128738649436, 46.58977562381376, 51.26509181914791, 56.284937243307795, 59.41110941671557, 57.10483028042702, 64.4912181362029, 62.04758151885002, 49.575228844919515, 51.1270518456736, 54.681154604881044, 60.61495150289228, 58.959581851959236, 54.83933987156038, 52.17972578540925, 52.08108994268602, 55.0070055069462, 60.82828921656455, 63.94632639423494, 63.78692911517236, 54.88072872161866, 58.60912199943297, 61.84954889359013, 71.47160145544237, 74.67016097038024, 67.69413932677239, 60.82532390471428, 65.60487708737774, 65.81322946856099, 74.4525557179605, 67.18423904911165, 76.72285495265838, 45.33123608558409, 0.24922972965625026, 0.6253656011915977, 1.3004831585191912, 0.6959824215981268, 6.352739862857327, 84.09684811868976, 60.41689534341136, 75.02444513382451, 77.63310370906707, 66.31205297285511, 58.08614061724756, 42.70351871367424, 40.057836886375185, 68.34346417457827, 73.45123737089096, 73.4553401700912, 0.8532527341477333, 0.06661109986805147, 0.06106277702436332, 0.134706893455117, 0.029605481240357605, 0.16120104840205562, 0.17404316413787105, 0.17703328191513018, 0.15069082769895756, 0.1517261955286226, 0.2405865571551746, 0.43294181206053306, 4.361698185243915, 98.1970157930928, 67.10499148215017, 69.27428968491094, 44.378821849823005, 25.309144527681415, 60.29422713864235, 67.48598698646792, 66.76939349020681, 87.58168574302428, 64.60714378664571, 87.9301255749118, 33.48653324188725, 0.35814025168938024, 2.234372285104567, 0.42116544720145965, 0.4715820918640783, 9.889371895021009, 80.7427901606406, 61.77169769041, 69.6801765503422, 59.87467865790091, 64.44114515858313, 56.33490431693293, 65.09292541011688, 60.341119074052386, 65.25650001341297, 62.416853058722715, 66.10622267569265, 60.06530977064564, 65.58426110975205, 62.18948502694408, 63.365537120449936, 56.37464184914866, 51.621847075800744, 50.68016836720128, 60.320707059675655, 59.34003214682303, 64.76962012629356, 51.62775808765043, 51.71039066007061, 66.77369240791568, 57.81579909786102, 58.693394122585175, 50.66886801873484, 54.56141248826058, 55.93925091528124, 53.65673741986675, 58.7743636100523, 55.05605082358084, 54.86340361256754, 57.688369135702814, 56.54986981422671, 58.1422697344134, 60.02297170700566, 58.579288451902336, 58.19039329405754, 57.85181037841305, 48.97067785263062, 51.05184824235978, 46.07512535587434, 44.43055791239585, 44.06965671047088, 42.024995742305634, 43.64310287660168, 46.64601456734442, 48.892752124417214, 51.65171592466293, 46.72887855960477, 48.727251637366514, 50.53191061942808, 49.021970687373994, 52.69967909782164, 57.308844520199685, 57.53765990657192, 57.7705624026637, 55.996121360409646, 57.313194428720784, 56.89354396635487, 58.47694989173644, 58.79814101803688, 62.05800325639787, 56.04365656452795, 56.76974611897623, 55.38230180740357, 59.34439774482482, 56.68961209635581, 59.4344828205724, 58.992047309875495, 53.079203713324766, 55.115592402796594, 54.76121018009802, 53.482458668370406, 52.31274512506301, 50.809610505257886, 51.99216588850945, 48.45443510240125, 49.72859351865707, 47.671020107884566, 46.60795973193261, 44.15926325705744, 39.17134592610021, 42.58412961036929, 41.9816025610893, 43.0775559333063, 43.52875401896816, 44.632967902768044, 47.81108794673797, 57.62954535022859, 57.164560133411044, 56.48771593647619, 57.76203909227925, 60.60370214523808, 56.941008567810066, 49.24958975084367, 55.591336680996804, 48.662748259882775, 53.45348411990751, 58.977130536110174, 63.245328241778964, 60.83451009565785, 63.261104014612016, 48.46665328548801, 46.88638133387412, 52.49572369360155, 56.07033652644004, 63.51115903546734, 61.42603097423431, 57.18416413953228, 53.138235384418124, 54.00667167478993, 55.99030056307393, 63.75753095073085, 65.402545544409, 67.73311984154486, 55.21058828599992, 60.481716432879054, 64.71174163203086, 71.6617658061366, 69.30715914695494, 68.89283134091285, 65.39320245865854, 71.93981478291174, 68.11249148461127, 78.62890720367432, 70.78553184386223, 80.63956906718593, 49.44655156904652, 0.8587766570910331, 0.5621421421247145, 2.975224905437039, 0.9271627520361255, 7.086165230120383, 90.63452136132025, 68.23145697193762, 82.06280892895114, 85.18882028518185, 78.07571180405156, 67.39589014360982, 50.38726929695376, 49.969999713282434, 85.41976159618747, 80.63134777930476, 88.9479963241085, 1.7843522588091514, 0.27425337883253254, 0.15601097125439875, 0.414535140077914, 0.24329069431029984], [0.06999705527578631, 0.047946076224287676, 0.16640321441715764, 0.040582216930605715, 0.08699519033994406, 0.02318017541490976, 0.0925079513821871, 0.9818600815150046, 58.01264716732887, 59.53897868433307, 40.6395596842612, 51.801040557123, 41.84093067722936, 41.63963071761593, 45.95792493512554, 50.12146203748642, 72.49984295137467, 54.26144922933271, 67.02686571305799, 47.73944977791079, 0.2236383940063177, 0.41583304623922995, 0.3455798111615643, 0.06762949118931448, 0.8983938215721039, 55.72139463117046, 63.703492456866854, 61.17311654552337, 58.27834852280156, 54.16330760525119, 54.737436694483605, 58.07509130047214, 59.32518205335064, 59.93082738691761, 56.989434149957475, 53.07584224208709, 58.715037761196015, 60.839738615097545, 58.87760039298766, 52.1159049003355, 51.40197861579157, 47.90316950890326, 52.936280388985914, 54.272172989383826, 58.20214079272363, 50.80099698035948, 36.807733505002915, 60.53429580503895, 57.703627155673125, 55.43419476478331, 54.31792743744389, 51.66731126846806, 50.62161130289878, 48.15151437636345, 49.25497516509026, 51.161305904388435, 50.62891475615963, 48.89496826356458, 50.54458771982501, 53.55929005530573, 53.390730119520626, 50.8109833348182, 50.588934036993216, 51.496401832949736, 50.13174256970806, 46.66299058545021, 43.970240316083355, 39.94269570996685, 38.338403163417695, 39.255088529279156, 39.7454789377028, 39.37970222965364, 40.48298651172269, 42.26213439818352, 44.72321379569269, 43.07837178630214, 45.23598917068974, 44.534802744465495, 43.736298391895915, 46.25462085969987, 49.33388540821691, 51.24883751715384, 50.18909938873784, 50.4980174187691, 49.87273670011952, 52.01351927172754, 51.88406536656042, 55.041796930374645, 58.721078211261386, 56.16125706703433, 55.13427857429751, 53.72518277937367, 53.98973488038587, 51.946956649903335, 53.52126267648513, 50.98106907260034, 50.205910667296386, 51.60747943385955, 51.329928598096295, 48.9829078028279, 45.28455595816336, 48.76118406172722, 45.90636537921044, 44.640471396907685, 42.577183092794115, 43.59496754984702, 43.688017937444876, 39.10235143476917, 38.5307522742979, 38.971481553969845, 37.742838321193574, 36.944365347585375, 42.86529294906124, 42.87141184653006, 43.18025142915788, 50.177834341602946, 48.23589240351031, 48.260709239590554, 49.429038186227125, 52.99312337752312, 50.39711444608627, 45.48653056544643, 50.81034006610994, 49.57345593360163, 46.463341943679325, 53.54809168846377, 55.68258670068557, 59.69571659641882, 55.88197254365491, 61.96964402352611, 68.40491202569777, 62.124491353188795, 59.59038919018161, 57.4104025287013, 55.63136839097547, 58.792571252392186, 53.18028319266535, 50.81982827955677, 50.484622524630645, 56.83444561496858, 57.68282682664933, 58.42579826231926, 59.92704229970133, 56.62248857559697, 59.57832397953157, 61.31809126946234, 49.9976053545552, 56.199947326414055, 63.46584781523674, 69.2307827549596, 61.408156733359064, 69.74115371704102, 59.90774031608336, 72.04363992137294, 27.146033625448904, 0.14450690468713162, 0.1203523209739116, 0.8937570284451208, 0.559839649546531, 9.970463956556014, 77.65750869627922, 59.3679476553394, 69.68957454927506, 65.9095864142141, 39.50446498009467, 43.8196526804278, 38.24751007941462, 35.32149645590013, 53.2466693078318, 61.32311190328291, 54.076529087558875, 0.301268887255461, 0.14515976481620343, 0.02818090627120147, 0.07028040055546068, 0.05143924946746519, 0.05584281861721989, 0.075291404650817, 0.13814192445528123, 0.029037078474498088, 0.06880323748074232, 0.03410903060989034, 0.048336888317980116, 1.7409849407211428, 71.7468184809531, 63.45802268674297, 52.77613001485025, 47.951869656962735, 31.85382704580984, 55.295688029258486, 62.85493866089852, 56.60535174031412, 79.01933993062666, 61.26259757626442, 74.72519182389783, 52.52859707801573, 0.2717555644771745, 0.6527775141500658, 0.37049933366717835, 0.03790235710180095, 1.1025697978273516, 60.60111338092435, 66.37842732091104, 63.08302840878887, 62.0972740265631, 58.26038014504218, 58.47594968734249, 60.165906798455026, 62.10922156610797, 64.47724273127895, 61.02338398656538, 56.284705823467625, 60.59634770116499, 62.25387857806299, 62.06442417636995, 55.21179637601299, 54.40274084767988, 49.63591183385542, 55.19424769186205, 56.14871332722326, 59.48322219233359, 52.386795551546165, 38.08950131939304, 63.073520583491174, 60.97832379802581, 58.00853652338828, 55.67456545368318, 54.45182146564607, 52.61097861874489, 50.81987534799884, 51.661706201491825, 53.77689530772548, 52.869674621089814, 49.67437851813532, 52.31565160136069, 54.891366189525975, 54.623601667342655, 55.73485228323168, 51.86973694832095, 53.043745486967026, 53.917645638988866, 49.52527746077507, 46.8753045605075, 40.89608661590084, 39.148227476304584, 41.30426414551274, 41.5147267618487, 42.46238316259077, 42.68789983564808, 44.32629739084552, 47.55862459059685, 44.928946033600845, 47.842902291205625, 47.303211612086145, 46.33085212399883, 50.92220606342439, 52.01009112019693, 53.524353504180915, 53.24332352607481, 51.457272268110714, 51.98062235309232, 52.926556833328746, 53.22048356456142, 56.72100282484486, 59.022194647019916, 57.04770880360758, 62.05128423629269, 54.54987287521363, 56.36547134768579, 54.6782991193956, 55.24849014897501, 51.58448649990944, 53.55914492760935, 52.220439987797896, 52.82179424839636, 49.81901591823947, 48.95318015929192, 49.486638192207586, 47.41051197052003, 46.927676047048266, 45.58535468193793, 45.04046686234013, 44.47076612903226, 42.21146914266771, 41.00924307300199, 40.34624484277541, 38.96835150257234, 38.26478812002367, 44.5222197809527, 47.63900964490829, 48.73856375294347, 53.9052156479128, 53.29172949637137, 54.42257627364128, 53.3773156135313, 55.4731164440032, 51.631315677396714, 47.99932249130742, 54.66372751420545, 51.58926394677932, 47.50838295105965, 56.285203964479514, 56.94352280709052, 61.43082018821471, 58.11729992589643, 63.09071625432661, 70.29502376433342, 64.3971126310287, 61.92525063791583, 60.63989777718822, 59.12407428987565, 63.47060565025576, 56.69762549861785, 51.775811872174664, 53.63368565036405, 57.85969826482958, 60.18457728047525, 62.695541381835945, 61.24319361102197, 58.12022993641516, 60.90699157407207, 66.16668208952873, 53.895660754173036, 60.980084942233184, 64.96040813384518, 71.93104436320644, 65.01769827258202, 72.58549967119771, 63.452119519633634, 76.0938322928644, 28.9625479713563, 0.07506474987753937, 0.5755370362631737, 1.7086522305204024, 0.5421637335131245, 10.784418525234347, 84.64499935027092, 65.10492786284416, 77.53586815249535, 73.71535408881404, 44.21051294572892, 53.50289421696817, 38.46798258443033, 27.542273421441358, 60.57206430742818, 68.77752934732746, 67.94739107931814, 0.5630328265889999, 0.23113739887072196, 0.02006943326353306, 0.11378234327440301, 0.027529702807265907, 0.1457426198307545, 0.2020857053538484, 0.31923796981573105, 0.11157393395420044, 0.3016491733010738, 0.14055859477769944, 0.20248566453735675, 2.633731100828417, 85.4309795748803, 70.6367249642649, 57.46532747822424, 67.72805998402258, 61.83316907575054, 59.38258594082248, 63.41704176318262, 63.463663055050766, 84.96559819867535, 66.93766317059918, 80.23359590961088, 55.75908860852642, 0.4704766882763755, 1.1925677234126677, 0.6854026860767796, 0.17039437928507406, 1.4743228497043734, 65.00327179508825, 68.8437468005765, 68.47917033780006, 64.13265466690063, 60.4823047884049, 61.5700682517021, 64.31986547285511, 66.13595424159881, 66.43699615232407, 61.577057915349165, 59.76724493888117, 64.4651500640377, 64.72782334973736, 65.55799691907822, 56.50003610118743, 57.32421236653482, 53.45255844054684, 58.70545148849488, 59.79870627003332, 60.90337907114337, 52.81294930365778, 41.18065457190237, 65.45494448754096, 64.87064077008155, 59.35560395640712, 58.9174634410489, 57.72274086552282, 55.048394357004476, 53.60058476847988, 55.5397653579712, 55.50188702921714, 55.678174034241714, 52.88181827914331, 54.113093422305205, 60.124937642005186, 58.988375971394206, 58.82049852801908, 54.57711765843054, 57.32914278584143, 60.04349747011739, 52.858064405379764, 48.8625890977921, 41.99252243964903, 42.5773556770817, 43.964050815951445, 44.45220939574703, 44.06411832378757, 46.0091628566865, 46.708266504349254, 50.1706564041876, 49.441142620578894, 51.68297329256612, 48.607536977337254, 49.14998508268788, 55.16965050851145, 53.48855010924801, 56.80067793015511, 55.93276331501623, 53.63664703984415, 56.109042475300456, 55.033042200150035, 55.788726037548436, 60.85250200763826, 60.15122928927022, 56.45186547310122, 63.81738239719022, 58.21044052800825, 60.19699550444081, 59.08318358082926, 58.60269323472054, 56.39976855247252, 55.537329566094186, 56.543158638861875, 55.20015478134156, 54.45132724700436, 52.36544609069825, 53.40046544228831, 51.35072108237974, 51.26098117520733, 48.255606235996375, 48.84715849353422, 48.31868579310756, 43.63958843292729, 42.148777900203584, 43.86333219466671, 43.0029446078885, 40.57666447854812, 47.76129345740042, 48.46254656391759, 51.57669667274722, 57.41858459288075, 55.03934937138712, 56.96897506713868, 58.84492312708209, 58.07871164814119, 54.87741039645288, 51.21405001609556, 56.998275172325876, 56.72770615546935, 50.6486835018281, 57.79019778774631, 60.304590040637606, 64.04242054108651, 61.273548833785526, 66.44699819626348, 66.72653767370409, 62.28218240122642, 63.34647440141248, 61.556163449441236, 61.6332733246588, 66.68731397198093, 59.69121763783117, 54.25020379404868, 56.61836224217569, 60.855639903776115, 65.27174626627277, 64.82449800737443, 65.33837164601972, 59.12179147043536, 59.692213919854936, 63.79398153674219, 57.41580363242858, 64.97085732798423, 68.76045919233754, 76.45653386269846, 68.76961400431972, 76.63635884561847, 68.67880329009026, 78.87185096740723, 33.792336910001694, 0.16786104909354643, 0.7889172831369985, 3.0984902910647856, 0.718061259436992, 12.613511912284359, 92.58960323949015, 70.62342812938076, 86.1580301100208, 77.91518488237935, 52.46391327150407, 61.565522224672385, 55.790597008120635, 47.14778769400812, 71.96389813576975, 78.28796694355627, 84.02589244227256, 1.0218728538001738, 0.39215149117573617, 0.22319496699398567, 0.24059112303920333, 0.08014859361273628], [0.041587914174963395, 0.05366326782912497, 0.131152889000312, 0.06336871699820604, 0.058772894253413525, 0.06866944022476673, 0.30000144075001445, 1.6492161875770939, 62.25503175489364, 58.623505330854854, 45.554340500985425, 49.67989729296777, 21.18027529408855, 36.40792631333874, 25.264543256452008, 48.60377934671218, 70.4235206111785, 55.34605910701137, 63.67733024781751, 63.395758982627626, 3.4481355163358876, 1.3095693290233612, 0.20430708454260904, 0.07934554194610927, 0.03192758949984226, 29.46463488763379, 74.74945560578378, 56.557188956968254, 65.01381120374127, 55.97079853857718, 61.2082923612287, 55.26533280649493, 64.03007291978406, 57.17868851077173, 56.77379400499406, 53.83178495591687, 63.868098643518266, 59.106078455525065, 58.32433439070179, 49.88515884645524, 54.323912974326845, 51.34684970301967, 54.464718218772646, 54.00702861047561, 59.60629047886018, 43.98604354550762, 48.768934665187714, 57.77309625379501, 57.90688045563237, 55.8148294110452, 56.67876674282936, 52.279597174736764, 54.37449193769886, 52.812070692739184, 51.1064790141198, 52.46189325086532, 49.80972774567143, 47.05687107578401, 49.203152810373616, 51.4138908540049, 50.80218153615152, 52.30939542093585, 54.386831714260964, 51.00838445848035, 51.16776997043241, 47.85984693035003, 45.46460059381301, 43.09495556739069, 38.798152016055205, 40.442872431970414, 38.53509433807866, 39.13883732211205, 39.656970654764486, 39.604253999648556, 43.982148631926506, 44.29857015609742, 46.3386497959014, 43.3742557802508, 44.9237096694208, 49.3382078601468, 49.93960526681716, 49.450736738020375, 52.69148918890184, 47.61995477061118, 47.248121923015965, 51.957170501832046, 51.65168062333138, 56.734954695547785, 59.576990373672984, 56.543213552044286, 58.6262039215334, 51.78801044341057, 53.67118350921139, 50.09893978795698, 51.47112215718916, 54.262119954632176, 49.20424715165169, 52.37915085208032, 48.684784135510846, 49.150043918240456, 50.144141181822754, 46.445016630234264, 46.95686632587064, 43.22235807295769, 42.8949813688955, 42.326453424269154, 40.09697429595455, 37.61786768513341, 38.565018100123254, 39.07999392478697, 39.24652207282282, 38.61534210943407, 44.86460347329417, 43.29967583379438, 47.68903555408601, 49.52090794040311, 46.55730232115715, 47.932916764290106, 46.64411221781085, 50.33020273331673, 51.62235698392315, 45.17478842889109, 50.271147528002345, 50.21453988167548, 47.83219029826503, 49.3152266933072, 50.85814591377012, 55.424867368513546, 57.07064682437528, 56.058694931768606, 55.857559711702415, 61.03685732810729, 59.43097229926818, 57.945001971337106, 56.11592623495287, 59.98009627865207, 56.398179992552734, 52.21334049778601, 51.9304983846603, 53.68617480800998, 56.186132738667155, 58.68781651220014, 59.16510620424825, 61.89382460809524, 53.38461514442198, 46.445565762058386, 50.98463842945715, 64.25989635529058, 59.728993984960745, 64.93013528085524, 61.04004621505738, 70.28425293584024, 57.9488419717358, 68.33505461292883, 17.90014813023229, 0.1499047908451288, 0.20056707393978873, 0.8201698093645035, 0.13664670468818757, 14.86535051176625, 77.46414369152438, 57.697178779109834, 75.0246883207752, 53.95746161860805, 38.577244127950365, 38.07614172658613, 50.489756907186205, 47.69624487046273, 52.885983836266306, 67.38777868209347, 52.96937734849992, 0.3618704257232528, 0.04950033838770563, 0.026591132102053494, 0.09885362619834562, 0.06736248656506501, 0.04219454089780489, 0.031173544477731473, 0.06587737915857185, 0.023892185192615278, 0.038708243293747786, 0.07532505889333065, 0.17406020193330704, 2.3726907468611196, 71.8920010905112, 65.79568470678022, 51.59304118925526, 48.13226338355772, 26.3208395050418, 42.93047097421462, 38.0056998806615, 59.579379097107925, 73.41040549739715, 58.45246645712084, 68.86266831428775, 69.27494079835954, 3.7325728083810503, 1.3917893171310427, 0.29677498484811476, 0.10291487278957522, 0.13374680142489173, 34.065714343901604, 75.92276204016902, 58.883758514158195, 67.47716165358021, 57.03694189748457, 64.08055774627194, 57.645505474459746, 65.60483786367601, 58.166192270094356, 60.10287430978591, 57.23271915989538, 65.1696861943891, 60.410042962720325, 59.71868991851807, 52.49639049653084, 56.69833152524887, 53.57428919884467, 57.052043022647986, 56.35959171479749, 62.34423821972263, 45.66269597699566, 50.16729101057976, 60.135673169166814, 60.099391245072894, 56.223359953972604, 57.359152840029815, 53.68487258111277, 54.747191629102154, 53.60143592280727, 53.76129996392035, 54.08735875160464, 52.881598626413655, 49.73037035234513, 53.69366261266894, 53.010530856347856, 55.48435403454689, 54.99160628164969, 56.466370397998446, 53.682687820926795, 54.402407446215236, 50.66139590355658, 47.82400823408558, 46.37339415088777, 39.96384120756581, 41.974361865751206, 40.747373873187655, 41.79213246991558, 41.716101246495406, 41.52343050126107, 46.266450728139574, 45.31077700276529, 48.824216550396336, 45.11656084368306, 47.41706625107796, 51.75561558815741, 52.79105071098574, 51.9300865357922, 57.207882711964274, 49.79469722317111, 50.00781528411373, 53.74720296552105, 55.199256558572095, 59.74213784740817, 60.44348901317966, 55.69851152358517, 59.79150872076712, 54.17200349992322, 56.55196043752856, 52.755819982098, 52.89603294864778, 55.25973558425904, 52.32077029443557, 53.5716494437187, 51.48572906371086, 51.42673661631923, 53.12371869241038, 46.800779527233495, 49.49019970432405, 46.436050092020345, 47.24181867414906, 43.208884731415786, 42.46841576791579, 40.79955316358998, 41.100602919055575, 42.33549448751634, 41.26746446855607, 41.08655298909834, 47.44288329155215, 45.6421309901822, 51.597477389920144, 53.718271563130045, 51.32681815854965, 51.04957326765984, 51.92586998785696, 53.80423030545635, 52.272485917614354, 48.35203378431259, 51.93268314484627, 53.236306405836544, 50.281937968346384, 50.882864690596065, 53.88170888347011, 57.68122649961903, 58.740639071310724, 57.2747395115514, 58.28264744051042, 62.8869059778029, 63.282265201691665, 58.31522664716167, 59.210570396915564, 58.475031852722175, 58.838941512569306, 56.23433474571475, 54.79710378954488, 57.08717961465159, 58.78984520512243, 60.76269542017291, 61.98588263603949, 65.94144390475365, 57.55956242161413, 51.069314556737105, 54.27656996634699, 65.75478615299349, 64.14348433094641, 70.7425348220333, 65.73761793874925, 73.28946313550396, 61.791529194001235, 74.24549379656392, 18.963608587941817, 0.13951179691620413, 0.7131695735358423, 1.6784219107320233, 0.25080617006507616, 17.57507581864634, 85.20821248331379, 63.61327009816324, 82.0944389220207, 61.466933450391224, 39.70885184503371, 42.671300365078835, 54.746579739355276, 36.458497431970414, 61.26019708571896, 74.12296679712112, 62.36640353356639, 0.33499575490432404, 0.043255024920067484, 0.06777783645497215, 0.05181904138636686, 0.05868065726733016, 0.12749785287005286, 0.1747443490932065, 0.19473320714408354, 0.237929136041672, 0.18653978954159445, 0.2227269638810427, 0.5195968057359419, 2.828023991277141, 84.56521049622567, 74.30447055447486, 60.40286502530498, 66.66007703350436, 34.38697607286515, 49.76911552490727, 37.605147438664595, 63.48325529406148, 80.8732952610139, 64.81981861975886, 73.04531128175798, 74.18511283013129, 4.5865475650756595, 2.4289034595412593, 0.6738541251228702, 0.20421936747527894, 0.1965609243920734, 37.399215159877656, 80.97099365726595, 61.49839478154337, 70.20527993479084, 59.6792975548775, 64.31263262225737, 59.336917784906205, 66.27832843411353, 61.544863100974794, 62.93147194770075, 60.4533733860139, 67.14365820730886, 63.75221221677719, 63.01786607311618, 55.150477963109175, 60.38418277617424, 55.58585320749591, 60.93254189337454, 58.6184690075536, 64.98460131306803, 46.975277931459495, 51.39620488689792, 60.874380988459436, 61.871204299311486, 59.63033460801648, 60.74127143429172, 56.352888384173, 59.05470325100807, 56.48970457815356, 55.59687899005029, 54.79648013268748, 57.22802408279912, 51.58630255729922, 54.63950295602122, 56.73439771898332, 59.08790611451673, 59.53669194252261, 59.98158677931755, 56.65839002978418, 57.653514954351614, 53.995893001556404, 50.883154945988814, 48.631534038051484, 44.15336793468845, 44.411024508937714, 43.58782099139306, 43.635587615351525, 43.817005080561486, 42.65302996481619, 50.439307382029874, 50.098359277171475, 52.13408900845436, 49.35951025255265, 49.76476561638617, 53.55534022854221, 55.508362862371634, 55.16485344979071, 58.907453552369155, 52.99196235595211, 52.86411662255564, 56.72187751339328, 59.0341264970841, 63.456626322961625, 61.565451622009284, 57.927139497572384, 63.22668521634994, 57.378784302742254, 58.486551853918264, 53.73069370946577, 56.66858426986202, 58.64817311686855, 53.788709486684496, 58.71718722005045, 55.216103138462195, 54.95466539936682, 56.467390214243245, 50.35390953863821, 52.68403668557444, 47.92449151315997, 49.10109273848995, 45.19815398800758, 43.654505206692605, 42.45870790173931, 43.144275449937396, 44.31100799191383, 42.148487644810835, 42.46450124248382, 49.855274308112364, 47.96072244644166, 55.6905726463564, 58.70945230607064, 54.10837481098791, 55.9038358349954, 53.98008584976197, 58.161026508577415, 57.25967761008971, 50.39538468084028, 54.886835851976954, 54.73817802244618, 53.21005398227323, 53.98152928198538, 55.57197586182625, 62.20453516129525, 60.72331090127269, 60.395730233961544, 62.053410160926084, 65.38865643162882, 63.94603221647201, 59.52638395370976, 62.644982030314786, 61.69687063463273, 61.2822800297891, 57.60544238551971, 56.96077339110836, 61.180859304243526, 60.59527689410795, 64.04618993882211, 63.713137565120576, 66.18999665783298, 58.65468425135459, 53.69097186673073, 56.17707990830945, 68.9453597222605, 66.20771008153116, 73.95596011992424, 68.24991564596853, 74.007170584894, 64.38036411039292, 77.93133720274895, 22.001486247585667, 0.18658157197698472, 0.6407542238312384, 3.584748727660026, 0.43634440689798326, 18.262747718441872, 94.6641291341474, 66.77568497196322, 87.47152205436461, 67.8482884745444, 52.49235045525336, 54.43181737776726, 71.85982196561753, 60.80336255411948, 74.17260831402194, 84.76665558353548, 75.47860853133663, 0.8420024571880218, 0.1888265313520547, 0.138423262584594, 0.18214552452968014, 0.20332728873097128], [0.02978868925222947, 0.057131236779593655, 0.04142484469940105, 0.09337195300406988, 0.03225356948772266, 0.05239821534844176, 0.08515889290720226, 0.9694536246599691, 56.761069836155066, 61.800087805717226, 51.82664186723771, 26.401838410285215, 19.92468930059864, 43.52793424360214, 25.10418107432704, 45.30120641954484, 69.46884709019815, 62.18990864292268, 53.8754056346032, 74.74476445105769, 12.829889462840173, 1.6706433603840491, 0.18125911483601218, 0.09545899867530792, 0.19747673654027526, 10.797409415245058, 76.17612361907959, 57.55687952041627, 66.8686294555664, 53.91342909105363, 60.1284913093813, 57.914678127534934, 64.69734653349846, 56.15524015118999, 58.72515355387042, 62.55025679065336, 60.15661470351681, 57.300909565341094, 55.59006975543115, 52.545482881607555, 54.17012860698085, 53.42165408595916, 56.694483680109826, 57.102194447671216, 53.27332573552286, 45.43229595307381, 53.56084331389397, 56.85618731283373, 60.127204771964784, 56.11550261897426, 59.34286409808744, 55.82588657256096, 56.385718622515284, 54.623374169872655, 57.75356285033688, 54.863427146788574, 52.502913398127404, 46.09388213003836, 50.485065752460116, 48.621528071741906, 48.671754021798414, 50.36335852838332, 51.49067125012798, 48.370064919994725, 52.27570618352583, 43.93416627760857, 41.938993853907434, 46.134827752267164, 41.539853465172556, 37.60248414931759, 38.6215433766765, 39.73591227685252, 42.23617615238313, 41.13994036951373, 42.46532886259018, 41.96659165043985, 45.18874422196419, 41.46383793123307, 45.74383020401002, 50.73999627943962, 48.14604659234324, 50.13849689114479, 51.88366528480284, 43.7435116306428, 42.07110320368121, 49.435776818183164, 52.11936443082748, 57.68712966672836, 58.76406738834997, 56.05071683083811, 59.040327764326534, 55.06639411372524, 55.24079053632675, 50.656253676260675, 51.53952437062418, 49.3857430642651, 50.61192304857316, 48.84255755332209, 49.69551224862376, 47.32944834616877, 45.11181869814473, 45.19407864539854, 42.81032877583658, 44.868745496196134, 44.49212735699069, 40.343318754626864, 38.89628971776655, 38.07602797785113, 39.2127896893409, 38.482416906664454, 40.46643018722534, 41.659117052632, 43.81781308881698, 41.557484519097116, 48.90828471029959, 46.90751114199239, 49.71440630574381, 49.09041212451074, 47.118530734892815, 50.32735509257163, 50.774619040950654, 46.380105326252604, 52.302303775664306, 47.186630925824566, 47.52020497475901, 44.71223900395055, 47.315402338581706, 47.24292870490782, 47.30951878332323, 51.500810577023415, 57.66049677325834, 57.15000421770158, 59.50062574878816, 54.918995365019775, 58.40371139587895, 92.09707906169277, 58.63118533165225, 56.37914473010648, 53.41030274668048, 54.6181966412452, 54.21889935770343, 55.34558057785035, 56.820870291802194, 56.132698289809696, 53.49748134613038, 62.30384565168812, 59.2947954516257, 61.975229478651485, 61.76929327749438, 67.47451797608407, 62.24375101827807, 69.11020909586261, 57.43141858808456, 64.43871328907629, 9.30559181397961, 0.19821233416516937, 1.825648565446177, 1.3212883905056985, 0.27760436998740323, 17.34069851136977, 74.41234357895391, 61.584047578996234, 71.02725967284172, 69.82911679052538, 61.065855410791215, 40.26684430337722, 47.3938536643982, 38.22270893281506, 51.35546715028825, 74.74508608541181, 33.30468431595833, 0.6110615139046024, 0.31655877648342046, 0.1441582274292746, 0.09094692466239776, 0.02786867756156191, 0.04514676413588947, 0.019282471358535752, 0.031490995991794814, 0.04596639777563753, 0.004809280695964493, 0.08455667885080462, 0.05618080128765395, 1.5857578765961433, 68.56143812979423, 65.83429259638633, 58.03492230753745, 32.33103632926941, 25.878580501002652, 46.312891590979795, 17.835450595425023, 54.51732504752375, 75.7512995504564, 64.08182859420776, 61.507047530143495, 81.07391665058752, 13.999200963204908, 2.360457609738073, 0.24352808963627587, 0.045397922231425206, 0.17213778089611761, 12.016860573522507, 78.40346505565029, 60.85548300896922, 70.42138684180476, 55.52248339499197, 62.872840358364975, 59.584529169144176, 67.05322404061594, 57.85106120571014, 60.78235826184673, 62.84498760777136, 60.82117403707197, 58.4913214560478, 58.04081370753627, 52.11685019154703, 56.69424833789949, 56.26804359497563, 57.945272614878995, 58.94716362799368, 54.60068718079598, 47.957929718878965, 55.44296126211844, 56.7909033836857, 61.95791221434071, 59.568380771144746, 60.313662482846176, 57.497126133211204, 57.72916570786507, 56.72323073110273, 60.62450639663204, 56.10299025812457, 53.68814776020666, 46.344803994701756, 51.33073660635179, 51.47074168728244, 53.01195075435024, 52.67635668477705, 55.874833829941295, 51.17641879666237, 55.64022902519473, 46.12626129581083, 46.38064269096621, 49.785314913718935, 43.833832048600726, 39.979016857762495, 39.5566285810163, 41.74981401812646, 44.57569345351189, 43.13603062783518, 44.50971134247319, 42.687166352425855, 47.519161624293176, 45.9695626074268, 47.46635867703346, 51.96856106481245, 50.40795587724256, 51.16079599626603, 52.2806405252026, 47.5240606646384, 45.374542974656634, 50.69780334349602, 53.97601050715293, 59.96071584763066, 59.7506062446102, 55.65398869975921, 59.535091615492306, 56.18062965331539, 57.840262920625754, 54.567853020083525, 53.44185821471676, 51.871239216096946, 53.72439438296903, 49.04267295714348, 52.440653616382235, 49.302137744042184, 47.49562348088911, 47.42305571033109, 44.30573632640224, 47.38993521659605, 44.18248761084772, 43.07654003943167, 40.54883526217553, 41.068835643029985, 41.692747454489435, 40.412117127449285, 43.68177744650072, 44.11141818569553, 46.07389765401041, 43.66499754690355, 51.087294701607, 51.3793190833061, 52.46303858295564, 51.57253503799439, 51.901676808634114, 52.39883722797517, 55.12425691850724, 49.04903896393315, 53.460069779426824, 51.05337012198664, 49.61593520256781, 47.77450792251095, 50.0075367958315, 48.411532217456454, 50.116704202467396, 53.750595815720104, 58.80596614653065, 60.002657751883234, 62.74484165253178, 58.170812822157345, 57.28011708105765, 82.0817461321431, 60.25186946315151, 58.76309071817706, 56.725490016321984, 57.12058251903903, 56.78259972603091, 59.34005568104406, 61.60507148311984, 58.02484573856477, 54.72257091153053, 67.36950043709048, 64.18881124065769, 63.932943267206994, 62.7987075621082, 69.5984108217301, 65.12490841650194, 70.4238893139747, 61.351654991026855, 69.48399528380364, 10.161505937576294, 0.15323210988313923, 1.4348430907534016, 2.217625480505728, 0.3502809863177038, 20.16077676127034, 84.29809708749094, 68.66953865174325, 79.02169335273005, 73.73671531677246, 63.856155026343565, 41.44084499728295, 60.693496965592914, 45.29304396721625, 56.286596405890684, 84.11911149178782, 42.47266369481241, 0.5744271280784761, 0.30557736574161437, 0.049242143774585384, 0.05383889731620589, 0.07067840621476212, 0.1629662528754242, 0.12812137183162475, 0.12077463460305046, 0.1593801953018673, 0.13113980421856528, 0.28098545307593964, 0.24114806896015523, 2.118796706199646, 81.19798906387823, 79.26972835294663, 71.20615113166072, 37.27740987654656, 33.33624370636479, 62.377503841154045, 35.019603390847486, 57.79634021943616, 79.27609043736612, 74.18694065463158, 65.81092311489967, 87.66397706923946, 15.283310432587902, 3.0613979072340074, 1.3019806459065408, 0.2423156788873096, 0.2735202326889961, 12.854613142628825, 86.59393095201062, 61.78937189040646, 73.1625509262085, 57.526394859437026, 65.587242111083, 62.63061831074377, 70.08588298674553, 61.83371036283432, 60.563117381065126, 64.00445984255883, 64.51354034485357, 62.88570573253017, 60.79713775265602, 54.965047913212935, 58.358631595488525, 59.07897487763436, 60.76889276504517, 61.85779371569234, 58.54696419931228, 48.43129704075475, 56.988077009877856, 57.64161056087863, 66.0714469417449, 60.18280436915737, 63.82859645351287, 61.095861542609434, 58.51098037535145, 56.63992351101291, 63.98755834948633, 57.526720416161325, 58.15853188114782, 49.904099972017356, 56.223038319618475, 55.30961636574038, 56.16904689419655, 57.683909400816894, 58.78537762549616, 56.78427457809449, 60.25334035196612, 48.51759702928605, 48.60612100170505, 52.763519594746256, 44.17898101191367, 40.97851130270189, 42.138364007396085, 44.772184587294056, 47.17430291637298, 45.801951885223396, 46.58599838133782, 46.44596584381596, 51.53466847635085, 47.51963623108403, 51.56341160497358, 56.57336481155888, 52.24678654824534, 56.977867080319314, 57.33331618770477, 49.64541181441277, 49.10096722264444, 53.688383102417, 55.06345625846617, 62.85673902880762, 61.757392806391564, 60.00127315521241, 63.16375078693513, 58.16296023707236, 62.25139571774391, 56.211184916957734, 55.800920686414166, 53.21858905976819, 56.0837745666504, 52.20125959765527, 55.05383860680365, 52.32744224609868, 48.544673150585545, 50.1966421065792, 47.76523151705342, 49.789072544344016, 49.408692852143325, 45.14155810879123, 44.3695140654041, 41.62891872467534, 42.958366870880134, 42.92271644838395, 44.54605994686004, 46.62592810969199, 50.02554047492243, 46.34534920415571, 53.86687840184858, 55.41876416052542, 58.310339373926965, 54.15636893241636, 55.704610809203125, 57.32874270408385, 57.42368759647493, 51.65649337153281, 57.61399315249536, 53.02993089922013, 50.56127740490822, 49.50394368940785, 53.205233389331454, 51.98961634789744, 51.46230466904179, 58.455243495202836, 60.752363897139034, 62.242209526800345, 63.54879025490054, 60.882810161959746, 57.025214010669345, 82.01621117130404, 64.74417571098574, 62.13298720698204, 59.06701557097897, 60.55683374404908, 60.98827485115298, 60.14937400817872, 65.89473632074171, 63.62750437951858, 58.58995729877103, 70.57911319117393, 65.16858793074086, 67.04992140493086, 65.75386047363281, 69.76534689626386, 67.28342794602918, 72.52848409837293, 66.12847820405038, 75.08587729546332, 12.079626341019909, 0.13776577528445952, 3.4164008450123573, 3.6153071782281323, 0.48859518862539725, 21.795624571461833, 91.82175220981722, 72.77605625890916, 83.00195770878946, 80.98458074754285, 76.96294323090585, 56.832774685275176, 66.58196695389287, 49.14752575658983, 71.68080499095302, 92.39570479239188, 57.25786155269992, 0.6121576937936968, 0.30281874441331436, 0.2084052106065135, 0.3110087759071781, 0.22089861844095493], [0.04590221109890169, 0.11919765027179835, 0.028218096009485667, 0.02590750396672276, 0.013095133509787341, 0.050860941184744726, 0.10617010295391084, 0.708695007187705, 56.292672157287605, 64.92996269656767, 43.68347191041516, 33.73096358391547, 28.153725824048443, 47.70163420707949, 61.78751268694478, 33.90833708547777, 66.53376886921545, 66.26491392812422, 51.00828639922604, 69.84141734338576, 25.76604573957382, 0.3164884496119715, 0.7413739278431862, 0.14832661907759406, 0.13113598910070237, 0.6935709606735938, 53.762915980431345, 65.097753847799, 64.34916557804232, 55.66757579003611, 61.61621493677939, 56.77404111431491, 61.831451077615064, 57.86779795923541, 62.958151909612845, 61.7203381753737, 61.37104718915878, 56.33545737112723, 56.841992255180116, 52.72438218516689, 56.55742822154876, 55.09507840679538, 58.83589383094542, 55.27216557533511, 50.48951372023552, 51.39776991259668, 55.01867848057901, 54.377755349682225, 60.80195050085745, 56.73455853616038, 59.7000821944206, 57.303066868935865, 59.06937291545253, 57.99585550062118, 57.18198330171647, 53.52368670125162, 51.55753197208528, 46.27542118872366, 50.498829349394775, 49.295163769875806, 51.086337643284956, 48.036757592232, 48.56914481809063, 49.8110495844195, 50.80569990219609, 42.99961451561221, 42.60341198213639, 42.86342197848905, 48.03854227066041, 44.03667742206205, 40.721741184111565, 40.36295413970947, 42.24186751150316, 41.75659579615439, 40.319407986056426, 40.670373824334916, 45.21140767681984, 44.6438838589576, 42.51226394407211, 47.32256066414618, 47.83246878654727, 45.82675695419312, 48.690346056415194, 51.16322002103252, 46.0257270259242, 48.17501721843597, 51.641843318939216, 59.76703313089187, 55.2939151179406, 52.843300604051166, 60.94239096487723, 57.168462891732496, 55.03401102558259, 53.742213710661865, 47.09671843436457, 46.976509555693596, 51.20420486696305, 47.208737404115745, 52.35531853091333, 45.107963008265344, 47.51819672123079, 43.65932579963438, 43.44723932204708, 43.10959777524395, 43.72580997405514, 41.60256824185772, 39.35333605735533, 38.54082884327058, 40.42995998936315, 38.61355743100567, 42.451780996014996, 45.567798153046645, 44.15614497277045, 43.494441124700735, 48.61240856109127, 49.091424096015196, 48.36037666566911, 47.3628394834457, 48.97609072346842, 49.93804024111841, 49.81525044287405, 46.33560995901785, 49.75241015034337, 47.74697680627146, 49.04513228324152, 49.97075280835552, 51.14928383981028, 49.064002806140536, 50.56668243100567, 47.74298383343605, 53.33509914336666, 59.712767139557876, 58.47263528454689, 53.67956169189946, 58.643956568933305, 49.73853672704389, 56.53425485857072, 59.33555672245642, 56.60622642886255, 56.65638177625595, 54.772145748138435, 54.30462668018957, 52.7326544638603, 59.96934113963958, 58.29352417299825, 58.32471093823833, 60.82144468061386, 66.6134871205976, 61.90537598825271, 69.18434189211938, 63.08580544687087, 62.203307459431315, 46.26024946089714, 53.80673277762629, 4.0678511271553655, 0.262703959860148, 1.0577728983856018, 2.826579088164914, 0.6168075410589096, 21.051523493182277, 73.44769939299553, 64.19054885064402, 63.60847696181267, 74.68956885799285, 68.53879820915961, 37.927946736735684, 45.268003556036184, 24.548530270976407, 47.71278550547939, 72.08672323534566, 20.341048894389985, 0.6276996565922615, 0.18011767447235125, 0.06478059406001722, 0.17069690740637242, 0.021185889584763397, 0.053642254037361954, 0.08710833386548104, 0.16115191152259228, 0.04919921603774832, 0.09375403169542552, 0.09226967505509816, 0.06120743357666558, 0.8459154504441446, 66.42404448601508, 73.5527483109505, 50.95983336048742, 36.59680412661645, 31.61003605011971, 55.31608435415453, 58.555228633265344, 40.06262217798541, 72.85255816675001, 72.54918636814241, 57.62734882293209, 79.95411919009301, 27.335609620617284, 0.3548770542106321, 1.6730151685976213, 0.16297572172216832, 0.11925222637552409, 0.9542492921313933, 61.44201855505667, 67.91485109636861, 70.3069713038783, 59.50602685251544, 65.75818684793288, 59.27925502100299, 65.442585099128, 61.06636924128379, 67.71936016698038, 61.845763806373846, 65.13143524046868, 56.082013422443026, 57.4544232891452, 53.22892058280207, 58.740976395145545, 56.541232755107266, 62.5556343601596, 59.396086738955596, 53.239981666688, 53.14569965485604, 57.85265761037027, 56.21889237434634, 62.370000347014404, 59.89730288905483, 62.80381841044273, 58.34463265634353, 61.810089849656634, 60.76130690113191, 60.685118782904844, 55.7571078115894, 52.19345408101236, 48.16556822869086, 53.69091695354831, 53.8992928689526, 54.51271626257128, 52.26804971694947, 53.3692825994184, 53.46543165945238, 51.93190651555216, 45.49525391670966, 46.92789962214809, 47.40581297105359, 49.97350238984632, 44.818041016978604, 43.03708884023851, 42.38615189829181, 42.4624498428837, 42.59695968320293, 42.40774846846058, 42.094704105008034, 47.52289572069722, 45.77021598815919, 45.47988214800435, 48.77625773029943, 50.25999622960245, 47.72474481213478, 52.99906184596401, 51.43818209248205, 47.21956706816151, 48.66978106960174, 54.21070160404329, 61.67230483024352, 56.71404846252934, 54.37532348017539, 62.997532506142896, 57.22431352061611, 57.57628740802888, 55.78562736511231, 48.78169021298809, 49.52512448833835, 51.77587463009743, 49.85371320478378, 53.85437780810941, 48.70256423950196, 48.545296807442945, 46.242292850248276, 45.212984469629106, 45.49182968754923, 44.31593448885026, 42.64949198692076, 42.16587551178471, 41.82042060359832, 43.81264340492987, 41.08154020001812, 44.5096956529925, 46.078984968123905, 46.756488123247706, 45.6495560369184, 53.71214874329106, 52.234329100578066, 52.96349771561162, 49.900020707038145, 51.782778001600704, 52.32146455395607, 53.45161314933531, 47.93498777574109, 53.61013573984946, 48.67530768917453, 51.62988793465399, 51.56656519059212, 51.647158130522705, 51.419193898477864, 52.27465106594948, 49.93720085390153, 55.70859593729819, 62.43001653302101, 60.07964211125528, 57.455388192207586, 55.788259275497936, 51.18150218840569, 59.742847796409364, 61.0143272338375, 60.356028003077355, 60.30802995927873, 57.087093322507805, 58.93990724317489, 57.54776785450598, 61.52509435530632, 61.93354645083028, 61.57888181747929, 63.08757443581859, 68.68991144241826, 65.72324637443789, 69.89399279317549, 64.52133801675612, 64.43616374846428, 52.7249470064717, 60.2034281915234, 4.229515781325679, 0.28923226700675103, 0.7846200814650905, 2.860311471646832, 0.4487716094140084, 22.512979007536366, 81.56531903051561, 68.87496886714813, 70.7463316763601, 80.29867587550994, 75.56501050149241, 43.91519377308507, 56.55277629052439, 29.583227749793764, 52.335400735178304, 83.62660300347113, 27.53153201072447, 0.7515572588289938, 0.18363847667651792, 0.04845721774824685, 0.13356145411249132, 0.032098350498164376, 0.10760220473692303, 0.2148230815486562, 0.3736407844529998, 0.2516681109104426, 0.2107904866457947, 0.16105071130779483, 0.22095195348224334, 1.4017338738326104, 78.28381707591396, 81.39116579486479, 59.22892316695183, 45.75658967418056, 43.05541807605375, 64.34866351466026, 73.34811041432043, 48.81272400579145, 78.75872981163764, 77.9350556096723, 62.665213615663596, 85.39748253360872, 31.91361181197628, 0.709051636438216, 3.2111228665997906, 0.49824051138374115, 0.2847649018851019, 1.2141455397490533, 67.01321586485832, 66.18801193852579, 70.03356641338718, 60.405802880564046, 68.38479811145415, 63.738719263384425, 69.42467335731753, 63.48345533494027, 67.93316856507333, 64.32067740348079, 67.39368577157298, 59.49730350125221, 62.16980257341939, 55.96875890608757, 61.23068909491263, 57.997079280114946, 63.92601243911251, 61.01286026739306, 52.732630929639264, 54.36893393916469, 60.14068988061721, 56.684642453347486, 64.30865926127281, 62.515512435666984, 65.55927953412457, 61.30736750941123, 64.97751359016665, 64.38975426458543, 62.98067808151246, 58.79316745265838, 54.454143508788086, 51.01933179363128, 57.530764379808986, 55.5453468907264, 59.934679154426824, 56.05913031485773, 58.41167772969892, 57.472909419767326, 58.15470364785964, 48.07371416399556, 50.26729576049313, 50.69151186173963, 53.63651760162846, 47.880753163368475, 45.25785246203023, 44.513519963910504, 45.67685965568789, 44.77142364748063, 43.883595158976895, 45.503459515110144, 51.724460201878706, 47.988790927394746, 47.80473762942899, 51.72443666765767, 52.84474403627458, 49.75374375620196, 55.67152953916981, 54.35866909642374, 51.77291324061733, 51.44204562710178, 54.5845466275369, 64.19466341695478, 57.255657180663086, 56.51356827828192, 64.88789135409941, 60.00325395214943, 61.307175313272786, 58.63739836600519, 51.137650089879195, 53.20863408427085, 55.93970591022123, 51.757145312524614, 57.96321745841735, 52.37582075980402, 52.841253126821215, 48.59992757920296, 50.23190421442832, 48.95476871921171, 48.216696323887, 46.00179272313272, 44.405011515463556, 44.53094705458611, 47.40627581073392, 43.16099651398198, 47.4132929309722, 52.11562641205327, 51.40979982191517, 48.930081321347146, 57.13210252023513, 54.364631099085656, 55.643017830387244, 53.170485111974905, 56.95727855928483, 57.317877738706535, 57.11797806524462, 51.27606268851988, 56.35153516646355, 51.42790156026041, 56.06457456465691, 55.72691340600291, 54.42197222863474, 53.09983930280132, 55.14018958614719, 51.841433125157515, 60.469898331549864, 65.56372357952979, 60.366845900012606, 59.180442671622004, 57.5491524511768, 63.84341909039406, 62.35382449242377, 65.0749727218382, 62.63611355135518, 64.70684651405581, 58.96669310908164, 61.85136887335009, 61.27740060129474, 66.22644332147414, 64.72390882430538, 65.10942289906164, 65.67359701279672, 69.57651615142822, 67.37160282750284, 73.40146249340427, 66.49747910038118, 69.05441730253159, 55.53638035251249, 65.67353033250379, 6.1164572642695525, 0.4146451196603237, 2.7765686233197493, 4.30721156058773, 0.7944527893297134, 26.490058399015858, 88.29165043369417, 75.04125641238305, 78.07728075212049, 86.24203158963113, 81.57497590587985, 54.51792909253029, 62.740252479430175, 38.4718539637904, 66.83430871655865, 92.10504931788292, 40.74352995041878, 0.8692997633930176, 0.32301337368065314, 0.19189782380577058, 0.3074566713504253, 0.2234162744735518], [0.07054103132818015, 0.08123806257161402, 0.0853280681035211, 0.022814596342223308, 0.025497968684160904, 0.04341908264905215, 0.10536534291121269, 0.3334534360516456, 57.86016110450991, 56.35892491186819, 49.980299857354936, 43.521466255187995, 72.3506046110584, 48.83092772576117, 59.4859560843437, 43.479610643079205, 61.37893899794548, 67.96702646440076, 53.724814076577466, 64.08089114773658, 40.23940340165169, 0.07680027610472134, 2.437628526841441, 0.2246438690851773, 0.21062848969332634, 0.09142990479426039, 26.69561609145134, 66.07305511351555, 65.20314008958879, 63.75260053142425, 58.20390978167134, 59.521237804043686, 57.33300239809098, 63.411966216179636, 61.42474051444762, 60.67028830128332, 60.05194625546856, 55.43951742110714, 54.71599701912173, 53.88074790277789, 57.20377206802369, 57.98687327292658, 59.37454115959906, 56.96930062386298, 56.61655010715608, 56.53783990490822, 59.5571941714133, 55.29579393325314, 57.53205483959567, 57.10524605166528, 61.32715194456039, 62.65859265481273, 59.50814493240849, 54.09140663762247, 55.18812487202307, 55.657295257814475, 50.10348189261652, 46.34139153265184, 49.07720942651072, 54.05516785960044, 50.46747784460745, 47.32983273844565, 51.261236129268525, 48.58515201076385, 48.98728516794021, 49.77128459561256, 45.12196194741034, 43.75578080454181, 44.757456087297015, 45.22871709639027, 45.03298298005135, 41.65442982027608, 39.76095661040276, 42.033460217137495, 40.89339586996263, 41.25448926802605, 43.0785757495511, 44.7175028247218, 43.42115556040118, 45.903098044856904, 46.45580314820813, 48.764992683164536, 45.577553087665194, 51.26071445403561, 51.10289004541213, 51.516143122027, 54.11775319806991, 57.88514268013739, 51.239788609166304, 57.07176469987439, 60.09624158182452, 58.10246552190473, 55.71387544755013, 50.95179250163417, 45.38531772551998, 46.10004809594924, 50.5257446535172, 49.75574808736002, 44.23415699312764, 45.43577901778683, 45.5165719985962, 42.745962681308875, 43.326928461751635, 44.700609176389634, 42.85219223268571, 39.59429510178105, 39.36586803005588, 38.87158270805113, 39.593663600183305, 43.234187941397394, 47.03615703890401, 43.816436336886504, 44.33426372466549, 47.70174795581449, 47.39418314349267, 51.65205324849775, 47.279520496245354, 48.77661074361494, 47.23036143087572, 50.086447038958156, 48.7183557018157, 47.0238172623419, 49.69104859136766, 51.064980337696696, 57.109254713981386, 54.389447935165904, 55.195098846189445, 55.744513080966094, 53.93466872553672, 55.839285389069595, 53.6678102708632, 59.55448773599441, 56.53334879106092, 61.48481161363664, 37.805608011061146, 35.06118835941438, 60.23609369031845, 58.46134670319096, 62.23679665596255, 60.12148595625355, 57.494239268764375, 55.17302374685965, 54.609139888517326, 57.00399006566694, 56.10894833841632, 59.745518930496715, 58.62867109237179, 61.08278436045493, 58.73265704801006, 64.87376297673872, 63.11766293741042, 62.65237569808961, 47.808263840213904, 38.974815568616314, 1.5023491651781145, 0.47883400272938514, 0.482984391311484, 2.572397243592047, 0.27508565675347085, 41.95900186415642, 69.43705235758136, 67.70593781625071, 63.56607614024993, 73.79384856070243, 62.30410060574932, 38.83572439993582, 47.9314301859948, 45.261531645251864, 57.92950076441611, 72.66382155879852, 21.576058133955925, 0.6936769259552802, 0.25828807584701047, 0.13920318605678697, 0.11625388847483743, 0.15074416274024596, 0.009800882657028494, 0.11711063524407726, 0.0570948590945092, 0.07050779843402487, 0.07628987768604871, 0.08461523861173662, 0.06645107942242777, 0.9267547642511706, 68.09449565026068, 60.83756169965191, 56.75903412603564, 44.39136558963407, 60.81028161510345, 54.375044991893155, 67.90342915442683, 44.86920833587647, 65.19429122248005, 75.01244268109723, 60.33335670348137, 72.00975848782447, 45.471758919377486, 0.09683421076906305, 2.8556178654393847, 0.05110042793075404, 0.25961729968267105, 0.04152971064491619, 29.63366354665449, 70.44812171689927, 70.47056551902526, 67.25027607333276, 59.92417112473519, 62.9217601591541, 60.71270481232674, 65.94266768424743, 62.97584179908999, 61.77623979506954, 62.167386393393244, 58.80338914932744, 57.66425440388342, 57.76225482263873, 59.106109834486446, 60.30659437179566, 61.7700973633797, 58.47263136217671, 58.161579562771706, 58.64262688544489, 59.77191255938623, 58.620543941374756, 57.85603869345881, 62.37842952051471, 62.793082883281095, 64.62829712898501, 61.522536969953975, 53.84402667322467, 56.435211089349565, 57.664795690967196, 53.485490660513605, 49.85517624885806, 51.259522053503225, 56.09928361831173, 52.00476454150293, 52.13651303322085, 54.89273117434595, 52.04767919355824, 51.74948100120791, 51.688488145028394, 47.954842813553356, 45.650740592710434, 48.45066962703582, 47.59513793453094, 47.71841802904683, 43.58565192068777, 41.5625875226913, 45.12173052757017, 42.92375195410944, 44.71614176227201, 45.4508448416187, 46.93296340204055, 45.97933323152604, 47.13767190133372, 49.330163078923384, 50.410725070584206, 48.756826308465776, 53.93116604897284, 51.99900650208997, 52.561509686131636, 55.91938018798829, 57.973188123395374, 54.53728206696049, 56.37819159415461, 60.87611075370543, 58.18130908473846, 55.861070233006636, 53.310564717938824, 46.66202568238782, 48.14281063695108, 53.164052424892304, 49.86038123407672, 47.16898810478949, 46.85395117728941, 46.54910064512684, 45.023796789107784, 45.17231341331236, 45.44367082657353, 43.881257426354196, 42.75324260034869, 42.700376895166215, 40.323828497240626, 43.982662462419086, 45.946824627537886, 48.188035565037886, 45.93050756762105, 44.882148235074936, 51.00077898271623, 50.35129724010345, 56.57744015416792, 53.001348587774466, 51.33667507479268, 50.47157672143752, 54.720052749879905, 50.66321980568671, 48.59877048000213, 51.70326763583768, 52.549530767625384, 60.269665256623306, 57.52116241762715, 58.932894045306796, 58.6774653773154, 56.13003892283286, 58.176876806443744, 58.07752709234915, 60.543736950043716, 59.68347880148119, 62.132312559312396, 40.50947427749634, 39.88311882941954, 61.39333409647788, 59.873113632202156, 63.81362476656514, 63.60165203771284, 60.94564653212025, 59.06192041212513, 58.31788993650868, 59.932325732323434, 58.99314557352374, 63.606186297632036, 61.88363821275773, 63.24936436068628, 61.67843549482284, 69.41423200791883, 67.94259009822723, 66.95057561320644, 53.93526100343274, 44.06641683270855, 1.522045714720603, 0.5283495747754651, 0.8438644185662271, 2.898235888250413, 0.1953748211024269, 45.35560184909452, 76.18294854317942, 73.58881842705512, 70.78232334506127, 81.95371996971869, 68.56663134790236, 45.935504667220584, 54.122169786883944, 38.601351015029415, 62.31238465155325, 82.12156603413244, 26.66653956136396, 0.6649102018244806, 0.3128617280913938, 0.10290226298234156, 0.040835669459474665, 0.052539259796181036, 0.17792126974992215, 0.17983507995884265, 0.2359054381808927, 0.18663136769206295, 0.19775769162562587, 0.21904479291650558, 0.23459346664528694, 1.034046726361398, 80.4918682959772, 72.74426152629238, 64.34840071585872, 61.381947455867646, 85.81454815403109, 63.168273279743815, 70.25196398458174, 58.42771237896335, 72.59132831327378, 79.10102721183532, 65.57166637912874, 77.23372797812186, 48.05526333470499, 0.3087088267409033, 4.35030468048588, 0.9986857625265276, 0.3263366018091479, 0.2568705067519219, 34.29821283586564, 70.8387819413216, 69.39707556078511, 68.51197704192131, 63.807737288936494, 65.10790886417513, 61.939932069470814, 66.24019515129828, 67.33383824748378, 65.4334734332177, 63.780398368835456, 60.949666961546875, 59.02177887578165, 61.43647624600319, 62.4356137552569, 63.559816037454915, 62.31044307831795, 61.4009121156508, 58.960550677391794, 60.834000187535445, 61.71954977896906, 59.97633472565682, 61.721820831298835, 62.95584555595153, 63.58629203611805, 65.52886547580843, 64.93681899962887, 56.87808590550577, 61.192469519953576, 59.83214055338214, 55.639428861679576, 51.520151784343106, 54.74804670579972, 58.45521211624146, 55.73904137457571, 54.963443663812455, 59.729958888023134, 55.94877050768945, 57.37163774428829, 56.4308141123864, 51.59352756315663, 49.8818209094386, 52.567593282268895, 51.99556658344885, 51.645271470469815, 46.44369479148619, 45.192552843401515, 47.378340690366684, 45.838429927825935, 48.00258198092061, 46.27031426275931, 50.184643576222086, 48.511372227822584, 49.06057073223976, 50.460358742744695, 53.7709136932127, 52.52884418733659, 57.05001907963907, 56.335979046360144, 57.871802699181345, 58.83178710937501, 61.82609311995968, 56.24984379737609, 59.806186229951926, 63.12307188587805, 60.436754303593794, 59.720666793084916, 56.61606373325471, 49.25024478666244, 49.81492096377958, 55.42125878795501, 52.19476023027974, 49.5775548104317, 49.21728511010447, 50.55619401316489, 48.105104892484604, 48.99767552652667, 47.63470288245909, 48.477298598135675, 44.42998524635069, 45.27084335204094, 42.51001642596337, 45.95188448506017, 48.397803921853345, 51.733540488827614, 49.08496002997122, 49.723804304676676, 53.64838669376989, 55.563378026408536, 60.12000330032841, 57.74398442237609, 56.05689064148934, 55.33078539756037, 57.92844172446959, 53.656031393235736, 50.28533081854544, 55.92485189437867, 56.984903812408454, 62.439795001860595, 59.29734891460788, 62.60052588678176, 60.135582954652854, 59.39069347996866, 63.60999884143953, 59.33651378077846, 65.44907662176317, 63.116501915839414, 62.54125102873772, 43.995112065346014, 43.68248347313174, 62.59070034950011, 64.12615922189528, 67.15021641023698, 65.73567636551397, 64.63857373883648, 61.58126661854406, 62.22128760430121, 64.22429692360663, 62.25969545302853, 66.60476376933437, 65.51351724132415, 68.05633098848405, 64.70785064081993, 73.37912851764311, 70.32655962051885, 70.98286628723145, 57.718959700676706, 51.970118245770855, 2.0424934909228356, 0.5250273272395134, 1.8933202374366023, 3.8111655846718824, 0.3159112483263016, 49.611185212289136, 84.40828431037166, 78.63765408915859, 78.63049184122394, 87.11265656255907, 74.2113221076227, 53.58944131482033, 66.42475835738644, 60.21846263639389, 74.6680821141889, 92.66343793561383, 36.51344591571439, 0.8895230749922415, 0.45287725846132926, 0.2636777188989424, 0.21935400132450367, 0.1396042330851478], [0.05044272612600077, 0.08216081547640985, 0.012230476882729319, 0.004414743020935285, 0.14904957625173754, 0.012639282466543299, 0.053408110754624497, 0.18609760359169977, 50.70379672511932, 66.56139804470924, 37.4926067936805, 51.84639100105532, 115.49966535260602, 66.75886584866431, 47.2705461132911, 41.646840033992646, 63.9513901741274, 67.88661003112793, 60.39644018296273, 58.66000298530825, 49.370900815533055, 0.1214206459060792, 0.7764431653964905, 0.732241117906186, 0.14094957541073524, 0.2647294963319456, 10.291798249367746, 60.32394693743799, 60.495997782676454, 64.58943036294752, 57.11913908681562, 61.887231103835575, 59.98355580914406, 64.22494019231489, 57.7636904101218, 58.69830885241109, 54.2890509482353, 54.98862528031873, 54.725206744286325, 59.673276716663, 57.217131660830596, 60.481112387872514, 56.59080759171517, 56.976827652223655, 59.206451908234634, 56.956450939178474, 54.65719676786854, 60.667915267329064, 57.75013469880628, 56.36638133756576, 65.60049579989526, 52.307391089777795, 56.034682181573686, 54.73243567251391, 58.25853663106119, 55.440631374236084, 47.70355224609376, 48.07902505320888, 50.79685887982769, 52.784151261852635, 50.26822928459414, 46.94413823466147, 48.76915039554719, 50.66722454563264, 49.051400230776885, 50.99032978857718, 46.12322930366763, 41.80730812011227, 42.112280245750185, 42.335627848102206, 43.834102692142615, 42.51065969467164, 41.294215033131266, 41.76317753330354, 38.64802722007998, 40.9435708292069, 42.76307598237069, 44.92840474651706, 45.04708390082083, 47.70810219549364, 47.22070455551148, 50.12664741085422, 46.68750932139736, 48.81905863361974, 46.58400189492011, 54.60653935709308, 54.50336533208048, 54.18459823054653, 50.29642328139275, 58.08781939168131, 61.01113442451724, 56.52303687987789, 54.11943589487384, 48.53765995271745, 47.523864546129786, 48.98100153092415, 49.04434780920706, 46.20986661603374, 46.44950382171139, 45.54262830365089, 45.13259549294749, 42.06703570581252, 44.95564952973397, 40.250060481409875, 40.550212014106016, 40.81046127503918, 42.54059522382675, 39.3492450252656, 40.66005799078172, 46.13798526025588, 46.512850099994296, 43.289363922611365, 47.04957938963368, 47.97967141674411, 50.631597657357496, 49.00186069550053, 48.148137215645086, 48.1806654314841, 49.37202261340234, 50.37518055208268, 47.67444825941517, 48.01720457692301, 48.2476399021764, 53.55832515224334, 57.25326453485797, 54.87172295970302, 56.07729481112573, 57.840302144327474, 58.61799832313292, 58.11080840326125, 58.00008381566694, 59.3520934351029, 57.6828032924283, 55.28343454484017, 45.870522760575824, 56.778904853328584, 57.792355091341086, 56.44425215259675, 60.22312633452877, 62.04609494055472, 60.3660535812378, 61.03730055593676, 57.4338504575914, 58.370755641691154, 56.88208280071136, 55.94883326561221, 56.19867647847822, 59.07007894208355, 57.39630945267216, 59.403594155465406, 64.0250522859635, 61.57817971321845, 52.87654661363172, 27.40782633904488, 0.16007978679432025, 0.6934337390045966, 0.3512699751844329, 1.6429477497454614, 0.07413871045554839, 49.991604128191554, 66.50856371848815, 68.48836437348398, 58.88218172134892, 75.99238411072763, 60.292662112943596, 37.23480116936469, 44.28284145170643, 41.23150810118645, 50.307021525598344, 65.51948316635625, 16.165537776485568, 0.4640918970108033, 0.2512882232305504, 0.09901130241492102, 0.07051725195901049, 0.10047510491623994, 0.10573502629995347, 0.006530156449204492, 0.03888176603903694, 0.024919030294122718, 0.03592882267830353, 0.022200812442949223, 0.042741282527605375, 0.3801009587703213, 62.409647664716175, 72.13138334212765, 48.59509521915067, 55.12468445685602, 100.39764588879001, 69.32267604335662, 54.402764381900916, 47.18899611503848, 71.61719983623874, 74.7303536630446, 63.840932307704804, 67.81625839971727, 55.36525126426451, 0.06543796644696305, 1.6435569428628491, 1.0129573063984996, 0.17205859804826398, 0.46014565553876663, 11.31317755868358, 65.63277690641343, 66.9515012925671, 72.7880665563768, 56.61134904430759, 65.40161202030798, 61.016045231972974, 66.457776869497, 60.2081468028407, 63.08077696830996, 57.43457609607328, 56.08327250326834, 56.75455477929885, 61.18318919212588, 59.49261626889629, 62.135379852787146, 57.8749405953192, 58.382844386562226, 60.637709094632065, 57.785204610516956, 58.38019678669592, 59.69671287844258, 59.52854910204488, 56.49641967588856, 64.32993419708745, 55.37566123470184, 56.43909423582016, 57.73877551478725, 57.92003216282014, 56.71926129248835, 49.119720074438284, 51.15438684340447, 51.6994825486214, 55.75407974181637, 53.80007259307369, 50.85735359499532, 52.96086580522599, 53.82539933727634, 52.40893340879872, 55.69682882678125, 47.195632765370036, 46.23570326835879, 46.647971830060406, 45.89082494858773, 44.64358183645433, 45.50052558222125, 44.29361620256978, 42.45484044474941, 42.03683737785586, 43.75730660653884, 45.086641004008634, 46.110720865188114, 45.91176256056755, 48.56756802528135, 49.744345757269095, 53.18590394912228, 50.034334428848766, 50.60159544790945, 48.0757773307062, 54.772114369177054, 57.41762361218853, 57.01696526619696, 51.014546502021055, 55.59636908192789, 60.64063910515078, 55.87239803806428, 54.15934993374733, 50.611507277334894, 49.53929601177093, 48.34714651107789, 52.972950627726895, 48.75075840180921, 48.75817168143488, 48.21910073680263, 48.5927104180859, 45.30741553152762, 45.69216866647044, 41.038366671531435, 42.53006758228425, 41.16448656205208, 45.46717366864605, 41.43678142178444, 42.00763140955279, 49.3395257765247, 50.10806322097779, 46.790330333094445, 48.016494627921816, 51.965568296370975, 54.12363675332839, 54.418971615452925, 49.8720581300797, 52.38326934076125, 51.438605708460656, 54.79228711897328, 50.578759408766224, 51.277741462953635, 51.24870807893815, 55.8939749963822, 59.98637207092778, 58.474412118234945, 58.680556205011186, 58.3496807467553, 60.57747717826598, 60.28471539097448, 58.95565555941675, 60.277764951029134, 60.983811193896884, 57.82449499253304, 47.77470796338974, 59.38024820819978, 60.09460595346267, 58.28947628698042, 62.39695879720873, 65.05729067710139, 64.12206818980556, 63.70961527670584, 60.60177626148347, 58.723557149210286, 61.421473180094075, 60.81441579326507, 57.874560125412486, 62.33679356113557, 60.824919900586536, 64.23014125516339, 67.53310249697778, 64.10043631830524, 58.13244027476157, 31.401387529988444, 0.08243304482030292, 1.0373438462134332, 1.0809456484933053, 2.124646431015384, 0.10246350910634765, 56.41870575566446, 72.75645225278794, 77.19704597227036, 63.28156309743082, 84.80594988792174, 66.77841494160315, 44.68792030888219, 53.816754433416556, 33.90755261144331, 56.76072858995008, 77.11651971263271, 20.334208280809467, 0.5503227537678135, 0.19235910066673834, 0.08816912815335297, 0.024495736072440783, 0.07719629759629888, 0.15156980633976, 0.22361712740553966, 0.11466350526578965, 0.10065134344322067, 0.3117337095881662, 0.2841648405357715, 0.1460334880938453, 0.6101579591631889, 74.0804796834146, 85.36628400125812, 54.070288596614716, 69.88454772580054, 119.82482371791717, 78.74126741963049, 62.41991250745712, 52.18153399805869, 80.40524667309177, 78.42222967455464, 73.30393668143981, 70.66218114668324, 61.37195717903876, 0.3266287877434685, 2.9137383209120844, 1.7267912313822777, 0.3349157140379952, 0.4060902770969176, 14.18446627355391, 71.46697305863904, 60.37291380666918, 72.97593239815005, 62.42539990332819, 66.81702675357943, 63.10848851357738, 67.21216632473853, 64.21204343918832, 65.69012195833268, 58.309943214539565, 58.38003596951885, 60.54611782873831, 63.82105765804168, 62.05929763855473, 62.74641060060071, 58.89184251908333, 61.259628342043975, 63.72502626911287, 59.70393396192982, 61.17016300078362, 64.26937280162689, 61.43113005545832, 56.94670777167044, 61.72335447803621, 57.106689483888694, 57.635040590840006, 59.552408879803075, 60.57582193805326, 60.52436436376264, 51.20861753340691, 54.6882737067438, 54.6758907841098, 59.49066292855048, 57.86587599785098, 54.28322230615924, 57.00033049429617, 58.04312006119759, 56.500142005182084, 60.67396748450495, 52.41900213303105, 51.31244267186811, 50.23268476609261, 48.93789860510057, 48.97007772999425, 47.286361109825876, 47.74050097311697, 44.65541954963438, 45.0249146646069, 45.74334775247882, 48.716551411536436, 48.84695453028525, 49.41255638676305, 53.37469939262637, 52.0874834060669, 54.927181351569395, 52.3597429644677, 54.36525867831323, 51.841186015836655, 57.307075531251975, 60.827602801784394, 58.619602572533395, 51.07562957271453, 59.137457416903594, 64.92249842612975, 59.42269609820459, 58.34070636380104, 53.93370382247433, 53.3195508680036, 52.81699326730544, 56.509336040865996, 53.03339827445246, 52.29422369310933, 52.72978328889417, 50.82777107915571, 48.13094154480965, 49.85318368481052, 43.04221145568356, 46.15277259580551, 44.52789937296222, 47.96406822819864, 43.47219736345353, 43.540383846529075, 53.457022097802934, 53.75491434527982, 50.80286010619133, 52.89091033320273, 54.71902901126493, 57.963825425794056, 57.99822461220526, 55.05591354062481, 55.71904513143725, 57.98245276174238, 58.837341185539, 52.90202633027108, 53.16580180198916, 54.325305415738015, 58.9032526939146, 62.42012039307625, 61.14493431583528, 62.40574882876489, 62.46472950904601, 64.6405113897016, 62.01774797131939, 63.090100442209554, 62.72735180393342, 63.18853232168383, 59.52581521003478, 49.65493925156132, 60.293038660480136, 62.905807879663286, 59.999967005945024, 65.33470422990861, 69.0163153986777, 66.0121093257781, 68.46807787495275, 64.08830834973243, 61.5448474114941, 65.04979895007226, 63.93853656707272, 60.979496586707334, 66.85944326462285, 64.42680105086296, 68.77859623201432, 69.12101914805751, 68.1161157546505, 63.4621137188327, 35.509115188352524, 0.28487184775933144, 1.1321878601466457, 2.941551357507706, 3.2733034654971096, 0.24915829961819036, 61.42739595905427, 77.54161834716797, 81.16431159357872, 70.23210894676947, 90.20189962079449, 72.57139482805806, 55.676338365001065, 62.09088056318222, 58.66637683683827, 65.86514596016177, 89.84672900169127, 28.513089456865867, 0.7453216095605205, 0.29847983691480856, 0.29196355431791277, 0.22406188741085992, 0.12983108089575846], [0.0412783993317956, 0.07005891687567196, 0.07805227061673518, 0.04646834241406572, 0.07013987704750992, 0.06320245293599945, 0.01531189414597447, 0.05674463816948476, 45.576356764762636, 67.69340192118, 40.11517017118393, 64.65076838770221, 103.91873405825709, 71.71156421784433, 48.8570781677, 53.996999109944994, 70.29562780933996, 65.77639841264295, 66.63791564203078, 57.24868320649671, 58.663509584242306, 1.5218629567853867, 0.18430485059657406, 0.6053563652019347, 0.11173886502341879, 0.050751114819919875, 0.9915970590326094, 50.39071706033523, 53.02860121573172, 60.666805236570305, 58.802126146131954, 57.75116235979142, 64.09187378421908, 59.70152562664401, 56.184759909106845, 55.8033250993298, 53.847862751253196, 56.55668297121602, 58.114675860251154, 58.54808991955173, 60.5965163630824, 59.71796820240637, 54.11078314627371, 61.57787376834501, 55.953598945371574, 55.33519021926388, 54.42643588589084, 58.096899678630216, 50.21207271083709, 63.050143257264175, 49.4529724890186, 52.481913028224824, 60.60793046028384, 57.68538028963151, 57.74748709893996, 52.52834212395453, 50.23280635956795, 47.43765869448262, 48.97831862972629, 54.23273747967136, 49.86813575990739, 49.70639290348176, 49.78333019441175, 49.82238131184732, 51.04266597378639, 51.92279877201204, 47.8789645625699, 43.365850140971524, 42.138434610059186, 44.16833569926601, 43.443367942687004, 44.39261682571904, 43.2273159488555, 40.91254095877371, 40.39484693158058, 41.20627549386794, 42.61023298386605, 43.968781194379254, 44.760272349080736, 45.500835449464866, 46.71483255201771, 49.98447718158845, 47.85046069852768, 49.70627131000642, 50.34359762745519, 52.74525703922395, 49.71010738803495, 51.67849002345916, 42.39543614848968, 55.89848964445053, 61.83523224246118, 52.29943260069817, 56.897419268085116, 50.497946816106, 49.208753954979684, 51.29424679663874, 45.04800565781132, 49.877824014233006, 47.31421778278966, 47.91916101209579, 44.339013714944166, 43.204405384679, 43.92140288506785, 42.16085880033432, 38.745329456944624, 41.80292291025962, 41.03208695688556, 41.56429375371626, 44.6376080666819, 46.43920760000906, 45.17247030811925, 43.79106252424179, 44.29516161641767, 49.55070226423202, 49.427896776506984, 49.13923778841573, 48.69160905961068, 47.37023315122051, 44.650242021006925, 50.78660188182708, 47.809848477763516, 46.91919980510589, 46.735919214064076, 57.45589810032999, 52.66055345535279, 52.257965303236446, 56.81583004613077, 55.71096504888227, 55.00169854010306, 54.732674937094416, 60.18584812841108, 55.57252891602055, 58.665239349488296, 53.499913215637214, 54.13515283215431, 56.67577397438788, 58.55006679411858, 60.505462461902255, 57.67051450667843, 60.206483717887636, 59.69963504422096, 61.79756179932625, 61.961006964406664, 60.89542842680409, 58.904672591916984, 59.6197912769933, 57.97332148398123, 58.001699832177934, 61.39217699727705, 63.7621005119816, 64.77259720525434, 56.66275562778596, 62.61321083191903, 19.595484772036155, 0.08310788401192234, 0.4888153316513185, 0.05410100280817959, 0.7089235465372763, 0.4268416990676234, 70.67035536612235, 56.25334647393996, 63.98530690900741, 63.25770331967262, 77.79661947681059, 42.14782084188154, 40.19682999580137, 42.96915731122417, 36.503855720643074, 49.818223599464666, 68.62385088397612, 8.635243062050112, 0.42469401753717856, 0.2694512945750068, 0.18970552531461563, 0.09631844973492046, 0.05870093561468586, 0.024552876655493053, 0.053786416462953054, 0.05686069665957363, 0.048440727705676714, 0.019855275299520265, 0.048104361480762886, 0.04335073611488746, 0.12877271510660648, 57.41430136465258, 76.73652833507907, 48.042099860406694, 65.37934080246957, 104.79375208577802, 77.58340727898383, 55.07649813928912, 58.437502614913456, 75.61935101785969, 70.9551586643342, 72.01585385107225, 65.35268829714867, 61.48250918234549, 1.5915991438011972, 0.5292901468853797, 0.9912043930061403, 0.018167579771890756, 0.08625082866919619, 1.3882510940874777, 55.18689324778896, 57.7314720615264, 72.60304051060831, 59.745303200137236, 62.26738722093644, 63.67243905221263, 63.80803146669942, 57.661336160475216, 60.034193608068655, 56.156750263706336, 60.93195353784869, 60.8518861955212, 61.07211551358623, 61.382531889023326, 60.75470947450208, 54.82272863388062, 62.39386796951295, 56.49190502782022, 59.34842209662161, 56.632749495967744, 61.84765046642673, 53.341241575056515, 62.65778464655723, 53.486435951725134, 53.02379238990046, 61.93803756467758, 59.13900283075149, 58.38721782930436, 54.79508376890614, 52.37550697019024, 48.71431958290839, 50.58991070716612, 55.59696135982391, 53.01912869176557, 53.622181338648645, 53.170791056848344, 51.58682031016196, 52.2604089398538, 55.01085727445541, 50.62959724856962, 46.417328619187884, 46.55463510943998, 46.15697345426006, 48.79579505612774, 44.70956002512286, 46.62906600582985, 42.7724112233808, 41.455687246014996, 41.93245134046001, 43.44838073176723, 44.88226982855028, 45.794397400271514, 46.038482573724565, 49.05306331572994, 53.63729423092258, 48.93567462121287, 49.50601077848866, 52.881739831739864, 52.77370599008376, 49.56108085570797, 53.54340837847803, 45.352663993835456, 57.79395149600122, 60.52547047215124, 56.07013256319108, 57.84828024525797, 52.76459432417347, 51.57915207647508, 51.917860507965095, 48.071941252677675, 51.13895623914657, 47.87685040504702, 48.31104893838206, 45.12642560466644, 46.227936975417606, 45.86505105418544, 44.383940542897875, 41.9335574488486, 42.28890849697975, 42.54593749200144, 43.51942662269839, 47.49495667795981, 50.35400759789252, 46.88818562415339, 46.64130772313764, 46.691525828453806, 52.465239032622314, 53.82161425006006, 52.72477834455429, 54.381567893489716, 52.58915847347629, 49.04570494928668, 54.738750688491336, 48.47596891464726, 49.212389992129424, 50.90831695064422, 59.55930048419584, 55.87157826269827, 57.88947297680763, 59.05545634608115, 58.07895875746205, 59.096307831425825, 58.73000552577358, 64.27717047352945, 58.17497837928034, 60.42116288215884, 52.7389027995448, 55.374896372518236, 58.53581290091238, 59.25828210769161, 63.15087364565942, 60.027847213129846, 62.131853642002234, 61.549762141320016, 63.83608425817182, 64.55985569184827, 64.23596989723944, 63.50255727767945, 62.31670710348315, 61.33369053563764, 61.77927178721275, 64.8438274475836, 65.76721614406955, 68.04529343881916, 62.71156426398986, 68.26600520841538, 22.675282762896632, 0.08682183230355864, 0.9557697621564712, 0.3866860054193005, 0.9803027779825273, 0.5008570387238457, 77.46179811416134, 62.5881233522969, 71.11370086669922, 66.4827545227543, 86.13234643013247, 51.655716742238695, 48.288142296575735, 43.56751095864081, 36.73842522405809, 58.219175646382, 81.03326520612164, 10.0603146706858, 0.5090767944291715, 0.16909533931363016, 0.1942495298722098, 0.09834745658501502, 0.06959030855326884, 0.1782800134031042, 0.17011222910256157, 0.2230999720913749, 0.1253038689854645, 0.16011168669548728, 0.27192122332992097, 0.29798800846742046, 0.16618278027782518, 65.8757677385884, 86.30501700985818, 54.83933594919021, 80.99168023755475, 107.77139586787071, 83.26012811353131, 62.95951297206264, 65.40198856784453, 82.77642926862164, 75.28859323070895, 76.10601517461961, 68.77496411723476, 69.31208564389136, 2.198610810502883, 0.5611626527482464, 1.59647673368454, 0.22011222918668102, 0.17816836374901956, 1.5922324840099582, 61.30990136054255, 53.041905895356216, 65.05367817417269, 64.27597022825672, 61.82082537681826, 66.7025641472109, 66.23867327167143, 59.90064867081181, 61.825775407975726, 56.905373834794574, 63.53684663772584, 62.21736915649907, 62.316287409874704, 64.27939837978732, 63.16437836616271, 56.93392084490869, 65.7042032672513, 59.396639793149895, 61.79209793767622, 58.30139244756391, 62.94477662732525, 57.24575711834816, 59.08856507270568, 57.648078549292784, 57.425487964384025, 65.21145159198393, 64.04665670087262, 60.10067386011924, 56.24319930230418, 54.48950367589151, 52.34134312598936, 55.48189078607867, 59.54701562081615, 57.14556017229634, 57.89298349811185, 55.87535550517421, 56.07052480020831, 57.182924670557824, 59.20143519678424, 54.88031295038039, 50.14135237663023, 51.085200155934984, 52.13259066304853, 51.67608561054353, 50.300941851831254, 50.7213257974194, 44.95228805849629, 43.11690515087497, 45.68399052466116, 47.05922057551723, 47.54224085038709, 48.39747836512905, 48.0925376184525, 51.61909357193978, 55.097977038352724, 51.7015927837741, 54.19972681230115, 56.47911025631813, 56.37004090893654, 54.87479025317777, 55.02356575381372, 47.20534455391669, 61.74670434767201, 62.104126407254135, 59.20296099878127, 61.98306637425577, 56.13937416384297, 54.743159432565015, 55.18667751742948, 52.058920706472094, 54.1555844583819, 52.03836748676916, 51.82260967070057, 48.36646418417654, 47.878646850585945, 47.91273224738337, 47.00220108032227, 42.80099353482647, 45.853048601458156, 45.40126608264062, 46.609246269349136, 49.43311352883616, 50.83497647316226, 50.374623575518214, 49.03115295594739, 50.83916556450629, 57.101711996140025, 58.42670825219924, 57.36043153270599, 56.90957469324912, 56.4212082278344, 53.02890323823499, 58.51726008999733, 52.13897235931889, 50.9246850013733, 53.380229934569336, 62.90347406941076, 61.070828976169715, 60.932216336650235, 59.94670906374532, 60.166710884340354, 60.21750950044202, 60.13819133081744, 65.34159975667154, 60.15815619499453, 63.55490522999918, 54.098313931495916, 57.88042014644992, 61.05577884181854, 62.91295051574708, 65.14212369918823, 64.90244334743869, 66.41621543515113, 64.20982337767079, 66.14789393640334, 67.30715828557169, 67.01065063476562, 68.30976317005774, 65.0630134151828, 63.2735889188705, 65.04050685513404, 67.15911234578779, 68.5035204118298, 72.3264741897583, 64.05674895932599, 73.53409351841097, 25.461250120593657, 0.13151751620875252, 2.8464174559039455, 1.2475902418936453, 1.4845921051117683, 0.6374291570917253, 84.22697667152651, 66.01977363709481, 77.42826969392839, 72.86799661574825, 92.52200511194046, 53.33984913364534, 57.9076413954458, 57.11698570559102, 56.656064064271995, 64.59927551208004, 94.81179852639475, 14.69572957484953, 0.6526955120986508, 0.6379689119996563, 0.41276066594066163, 0.23788545370822956, 0.24225325804323922], [0.0879376317043939, 0.07633427248126076, 0.037917529473141316, 0.015197603403770877, 0.06690403656853784, 0.09171366376141388, 0.08989422026300624, 0.2246403910460011, 31.07135734250469, 63.16751233993038, 46.313142622670824, 50.14873035492436, 82.39217819706087, 72.31473845820274, 45.455430092350134, 56.07147401379001, 70.64392643590128, 62.2328938976411, 67.00575551679059, 58.21846177501064, 63.920219098368, 7.459296382242634, 0.15846473555411064, 1.4718795808092242, 0.3083240667418126, 0.39118845736788166, 0.15559817243727947, 34.684115225268954, 50.742843920184725, 48.59237309425108, 57.13437749493507, 59.35723174002863, 66.98715563743346, 58.16398789805751, 59.5674943154858, 54.386188445552705, 56.15136092708957, 55.05261482730989, 60.386748006266934, 57.2112088818704, 62.124718850658795, 52.17077493667603, 52.97972063864432, 60.826979144927, 56.69245581473074, 51.53772792508526, 52.810533123631636, 52.11628537024222, 60.218191992852, 48.08956053949172, 45.16772424021075, 61.6974982138603, 55.432198278365604, 56.872014076479026, 54.92964852240778, 49.277085565751605, 48.977753808421475, 48.43749438562701, 48.358168371262096, 53.94407456920993, 49.220215120623195, 51.09028747004848, 49.666647526525686, 55.783807385352354, 51.03119304103237, 51.40095879954677, 50.37395677258892, 43.55271185598066, 40.047638723927165, 43.34570877013668, 40.912858670757664, 42.17841140685543, 43.31019563059653, 42.48712155126756, 41.18034078228859, 40.46867378296391, 43.187260704655806, 43.18941800825058, 46.06715509968419, 46.08798680766937, 47.6387390013664, 49.55965703533542, 48.57621292914114, 50.16885211390834, 52.035351184106645, 46.790251885691, 51.390878308203916, 56.280618713748076, 51.4822813003294, 49.501633413376354, 55.67258465674616, 56.25933985556326, 53.352204599688136, 56.9656567419729, 48.61509930702948, 48.689294861209014, 46.37166438564178, 50.40610059615105, 47.180033499194735, 44.92692993533227, 44.516673549529045, 44.31573837034164, 42.36040546048073, 41.30957111235588, 41.99064362433649, 42.526105988410215, 43.439069024978146, 44.47141332011069, 44.810231577965524, 42.98137549431094, 43.74782231546218, 43.41062791885869, 47.01852206260928, 50.09138138063493, 47.64946276141752, 51.54779272694742, 47.77573562437489, 50.75323035640102, 47.618962410957586, 50.94631295050345, 46.28052026994767, 50.44324151931271, 47.58283738167056, 54.19527492215557, 54.71891134015976, 56.46293832409767, 58.71066431845389, 56.50645309878934, 58.36523294448853, 60.813458734943026, 54.16992464373189, 65.68775676911878, 55.79455075725433, 51.97195783738167, 55.53723542921005, 59.94964691900439, 55.75124386818179, 55.781473575099824, 58.81052001830071, 59.39384314321703, 60.53269547800864, 60.16600093533916, 59.11731604606875, 64.2758604018919, 63.8561079579015, 59.25361056481639, 60.38809337923604, 62.63457205987746, 63.8474512869312, 60.663259413934526, 69.2003216282014, 59.276980046303045, 62.02831091419343, 10.581034806466873, 0.19079079611166833, 2.0617840751524894, 0.46566777051456515, 0.06974928711931552, 3.895737033697867, 75.81255912780762, 48.18809832296064, 70.8307175482473, 63.36537630327287, 81.00323554008239, 38.319324754899554, 42.40785045008506, 37.1604291085274, 31.730084111613614, 56.62069997479839, 59.6215759554217, 4.230449795722961, 0.41393302561294654, 0.15801637493554624, 0.10967127798545746, 0.12745713529687736, 0.09297655970459023, 0.04993454553186894, 0.11672796666501992, 0.043411647765747005, 0.04188596451234433, 0.030341783666142055, 0.13219694426703837, 0.08718162549719696, 0.13467605075528546, 38.17607979620657, 76.0918789525186, 46.69698969010384, 54.1375494003296, 89.69221115112306, 75.86470311687839, 56.75180519780805, 65.08907364260766, 75.27006395401494, 68.1019167746267, 73.5155563969766, 64.13243109180083, 70.93394648644232, 7.774227896044332, 0.1872756629581413, 2.4524526346114377, 0.3226510140924685, 0.6891229316111535, 0.07804621852213338, 37.069037883512436, 58.4276339315599, 59.53193410750359, 59.52189283986246, 61.76642210252824, 67.19500203286448, 60.998892707209436, 62.178969152512096, 57.73351561638617, 59.01456955940493, 58.68257622564993, 61.260714838581706, 60.966784184978856, 61.61065693824523, 57.37325376079929, 54.80453275865125, 62.26841880429176, 57.77939165792158, 56.43375196764546, 56.522264172953946, 57.2601600616209, 59.856090545654304, 51.0391358406313, 49.25333561435823, 62.891903077402425, 57.28157228039157, 59.54121443533129, 56.599389737652196, 51.36864239169706, 52.019057658410844, 50.98725857273225, 51.277725773472945, 55.52707256809358, 52.13949011218164, 54.86385076276718, 53.47280179300616, 56.08208010273596, 55.798355456321474, 54.647692864941014, 53.95976797226937, 48.654154346835234, 43.551758720028786, 47.61464780376804, 43.94375255030971, 45.86054817322762, 45.657510603627856, 43.47712778276013, 42.68170641314599, 42.72346788837064, 44.05279836347027, 44.547052306513635, 47.23600964392386, 48.92297006422474, 48.23233481376402, 50.81442717582949, 51.66662093131773, 52.70061654429282, 54.84565880990798, 49.23319816589356, 54.69367873284125, 58.33361471852949, 51.17546173834032, 55.60324891921013, 56.9397847883163, 57.830154972691695, 55.636993069802564, 56.575212247910045, 53.49333932322841, 50.08501145147508, 48.82463624400478, 51.133033460186375, 48.77560661685083, 47.17285556177939, 47.69126346034389, 46.060494915131606, 45.58939472321541, 42.6835185481656, 42.22609173867011, 43.77875020427089, 45.23752281742711, 48.45853005686114, 47.789275646209724, 47.38850747385333, 47.80816185858942, 45.93523402367869, 50.68418095188756, 52.27516489644205, 51.72984169375513, 53.80294376803983, 50.54738829212804, 52.73194451485911, 50.28933555849137, 53.65793374276931, 48.83007264906361, 51.06561576166461, 49.440479740019775, 56.571913534595126, 55.7484785972103, 59.24216901102374, 61.12228655046033, 58.48427295684815, 58.94386099230859, 58.39397607311126, 57.53451808806389, 65.54837534504553, 56.372865015460604, 52.629935433787686, 57.18582330211517, 62.757224575165786, 58.13778646530644, 56.55654568825999, 61.910690799836196, 60.6107977128798, 63.45080160325574, 61.873789141255045, 61.52905594918036, 66.17181254971412, 67.34624078196865, 62.007781228711536, 63.71883676898096, 65.50677076462777, 67.97489473896643, 63.557748948374105, 71.8172642492479, 60.83777350764121, 68.0817714814217, 11.042132954443655, 0.21721601846718022, 1.7313632441143838, 1.241736839855871, 0.10480415286316026, 4.080181588088313, 83.52489594490298, 51.82574364446825, 76.41999306217318, 68.93354554330149, 90.5071149333831, 44.62084777893559, 49.88726515923777, 46.98908859683622, 36.45903871905419, 64.23525210349791, 69.08148165672057, 5.626224731245349, 0.4314613011815856, 0.207689194188964, 0.02756439892935657, 0.1175968559278596, 0.08373438305551968, 0.16311521101142132, 0.34592724735698394, 0.2508024621995226, 0.15095725775726382, 0.15619098659484618, 0.19912546500563624, 0.26333368413390656, 0.3950693055747017, 46.05874161566458, 86.81409358978273, 63.453135413508264, 67.55598560456308, 88.58332572444793, 82.18371991188296, 61.21606649891023, 68.12482341643303, 81.39671987102878, 74.765576547192, 78.25872959629183, 68.77090838647658, 76.84826881654801, 8.857666946226551, 0.3108272743561576, 3.98002288514568, 0.7380480643722319, 1.0517920193172272, 0.26746933318434224, 44.31906846261794, 52.333168906550256, 51.69860786007297, 62.61778823791012, 63.7281523981402, 70.31483173370361, 63.304873743364894, 61.84310051702685, 58.83306580205118, 61.606546294304636, 61.672438190829375, 63.091488961250555, 62.426870792142815, 64.76936517223236, 57.457278774630645, 57.2460905198128, 65.74634521238266, 59.80163235818187, 57.59156896222023, 54.73779755253946, 60.28511155036188, 60.18470671869094, 56.615455765878, 51.89762107787594, 65.6218844844449, 60.27823563544982, 61.69985163596369, 58.153040562906575, 54.71546749914847, 54.488428946464296, 53.75778552024595, 54.90379618060205, 59.925673392511186, 55.94252217200495, 58.57994348772111, 55.87947399385514, 61.8634105497791, 58.6911387597361, 58.61106749503844, 57.858713749916326, 51.984862435248594, 47.93009265776604, 52.461642219174294, 49.41562368023781, 51.29758865602555, 49.72087037178778, 46.99320708551715, 44.48967195326283, 46.292601170078406, 46.26967099405105, 47.9234952311362, 50.40312351719026, 50.76389135852937, 52.24642961255966, 52.7653552639869, 53.881704961099935, 56.95092824197585, 56.79782636703984, 50.9400567700786, 57.59513047433669, 59.836533607975134, 54.289329436517534, 58.54057465830157, 62.14113396982994, 59.50448928340789, 61.136136439538774, 58.748122953599506, 57.06680290160641, 52.72676698623165, 52.47771609214045, 56.397395518518266, 50.77216363722279, 48.34029805275702, 49.45858540073518, 50.115970719245176, 47.62157470949235, 45.22018986363565, 46.060181125517815, 47.209808211172785, 49.165835380554206, 51.90863901568998, 50.421033059397054, 51.84721862116168, 52.863485120957904, 49.874384095591886, 55.58847727314119, 56.24030459311701, 55.36871863949684, 56.687031176782426, 53.66176589842766, 57.38551508995795, 55.448652621238466, 54.843995724954915, 53.36685857465191, 54.31678602772375, 52.18959054639263, 60.07253085413287, 57.806585450326246, 60.57390782140917, 63.21793048612533, 60.80294678288122, 58.06699160606631, 56.358081602281146, 60.208641021482414, 67.12421109599453, 55.43954095532818, 53.810855188677394, 59.312775596495605, 64.48196918733659, 60.9085330655498, 60.183733970888206, 64.23360863039571, 63.774663863643525, 65.06710444727253, 63.44047400259203, 64.826286608173, 71.04317665100098, 71.3223474256454, 64.48437360025221, 66.31992124742078, 66.88683709790631, 73.19204714990431, 65.79208789333221, 76.60513677904683, 64.81208370577905, 74.77075407581945, 13.61208067786309, 0.24794139959398778, 5.107468722328063, 2.644628425759654, 0.25986422514242513, 4.612059150972675, 90.93959546858265, 58.53840558759628, 85.0946206431235, 74.14492422534575, 96.1161905719388, 49.466908670240834, 60.59233119410854, 54.31837066527336, 48.4267980821671, 71.86180668492472, 86.63637884201543, 9.510915144797295, 0.6919907970774559, 0.6287878078799094, 0.14198546418018881, 0.3348119244460137, 0.2291808256338681], [0.047105627975636916, 0.037773267456120065, 0.04543503153047735, 0.08604719483804318, 0.017144890697372538, 0.2574428050748764, 0.10656866019651776, 0.5486168904650597, 22.058833260690015, 64.86463562134774, 49.370951806345296, 43.73015596020607, 47.31728115389424, 65.86272193539527, 34.09799937278994, 49.66699269510085, 69.50853363160165, 62.690501136164514, 64.35668868403282, 57.210126307702836, 66.77816390991211, 19.037070658899125, 0.6470806391969804, 3.209694633560796, 0.29846279911937257, 0.9735181807510316, 0.644651405032604, 20.893577491083455, 52.07319028915898, 42.351250648498535, 63.37965765307027, 56.39368103396509, 63.98582858424034, 57.09019199494393, 56.35766975341305, 54.68944649542532, 58.03190208250477, 57.93049704643988, 59.587208147971864, 59.04728604901222, 56.84898976356753, 56.98731607006442, 59.886434001307336, 58.713162868253654, 53.94889516215171, 49.16272494100755, 57.95264274843278, 59.51935898873114, 53.67902432718585, 42.63944679690946, 62.49528477268835, 56.30308997246527, 56.401604221713164, 54.719036856005275, 53.55910178153746, 48.113588979167325, 55.23831552074802, 46.5056094046562, 49.17031080492082, 51.32499425641952, 51.360021022058305, 49.606678408961145, 50.804762455724905, 51.94378345243393, 50.854466730548495, 53.90709446322534, 50.75607799714612, 44.58151817321778, 41.82850068615329, 42.44979235433763, 39.619731672348514, 38.90417368181291, 40.41548252105713, 41.13917550733013, 40.379204519333385, 40.45997004355154, 42.22072201390421, 45.34155584150746, 42.112264556269494, 44.78978426225724, 45.260264719686205, 49.67137006021316, 47.4867275453383, 51.08404305673415, 44.467090868180804, 48.98877566860568, 61.846352161899695, 61.843696717293035, 59.94419090209469, 59.34080877611714, 43.14805269241334, 55.013720604681204, 54.502463186940844, 50.69712869582638, 53.11209278721964, 45.93768942740656, 47.66137107726067, 49.311014067742136, 48.59822134817801, 45.209513172026604, 44.844175769436745, 45.013845735980624, 41.394341376519975, 41.27764301915323, 40.81926307370586, 41.686683470203036, 42.26639016982048, 43.508793077161236, 43.926137185865834, 42.61965059464978, 42.72363655028805, 42.34783034170828, 50.12543539847098, 51.13177437936106, 46.665496979990316, 50.44355138655632, 48.98562992772749, 49.67685745608423, 47.68778824037122, 49.786977998672, 49.0741382106658, 46.55729447641681, 47.41970600620393, 45.36622362752115, 55.47752518807688, 54.79984552629533, 56.40578154594668, 55.41323361858245, 56.25941830296671, 51.77743965579618, 55.2229594415234, 44.38914945048671, 41.66279623585363, 51.017201946627715, 58.81992193960375, 57.59190628605505, 58.702627381970814, 57.181975456976126, 57.548450346915956, 59.59171887367003, 57.237743716086115, 57.31091945402084, 59.10330533981324, 61.51259768393732, 62.7758676005948, 62.112955662512014, 63.13339164180141, 59.422421532292525, 64.99525447045603, 64.69322412244736, 65.55528656128915, 52.516100406646736, 54.16970499100224, 3.2824504327389503, 0.17638546264460012, 0.45015531742284376, 1.629149586923661, 0.21930022195221918, 11.193921815964485, 71.71352540293049, 56.27154234916934, 71.02062302251016, 62.95206439110541, 69.09972067802184, 33.2815658661627, 57.99885611380301, 20.92207351038533, 35.699965953826904, 55.63981325395646, 44.34717224490258, 0.5841904590206762, 0.07622492875182822, 0.06943864612689904, 0.04550093424416358, 0.03363854154163311, 0.015479909676697948, 0.027491754641936674, 0.03737787415664043, 0.04597308189277688, 0.20998710556136024, 0.06465602050264997, 0.1446398975507867, 0.11653655959713845, 0.4510528966784478, 27.830912797681748, 78.91553832638648, 51.34117403338033, 48.15799020951795, 59.8450961420613, 72.92793043198125, 42.630582240320024, 55.122060391210745, 75.5808254980272, 68.55481716894334, 71.72214677256923, 63.86259948053668, 72.00886418742519, 19.87946633369692, 0.6723006826735313, 5.120837140467859, 0.5882181816043393, 1.4678423587353, 0.47758681158865657, 22.141177538902532, 60.008466782108435, 49.53137282402285, 62.034174857601045, 59.09619016032065, 65.32785969395792, 59.44071938914638, 60.686738721786014, 57.59052168938422, 59.74060812304097, 60.14687938074912, 62.115328696466264, 61.57524578032955, 57.81477143687587, 57.34176105068576, 62.78976063574515, 60.947262548631244, 54.74996474481399, 52.918394381000155, 59.706385443287516, 59.0124201005505, 55.0603497412897, 46.55274452701692, 63.86908315843152, 57.852834117028024, 61.0280986755125, 55.73810000573435, 54.94795422400198, 49.91686336455807, 55.12067971691009, 49.79808222862982, 50.96756435209706, 54.44578101558071, 53.330419755751095, 53.9103578752087, 53.398543480903875, 55.42272183202929, 53.32787805987943, 55.9623654427067, 54.845227349189024, 48.63167916574786, 47.52728485292005, 46.408185574316214, 44.06100788424092, 41.68283170269382, 43.98616513898296, 44.43263676858718, 42.83729114840108, 42.53067162729079, 43.83723274354012, 44.784128204468765, 44.34259091654132, 45.80602722783243, 47.43960419008809, 51.77175221904632, 48.36800567565426, 50.6701349443005, 47.125783197341434, 49.160971641540534, 62.898924120010875, 63.22328844378072, 60.326574925453436, 61.98802425015358, 50.31496432519729, 53.5536418422576, 56.423283161655554, 55.68252394276281, 55.46285160126225, 48.65024374377344, 49.269378108363, 51.97217356774115, 50.45471445206673, 46.07222280194683, 45.806290026633974, 46.350205098429036, 43.88172026603453, 42.604573003707394, 43.1508061962743, 43.93404076176305, 45.27756237214612, 46.53272474965742, 47.9776749303264, 46.104802008598085, 46.49410901531097, 44.311682639583466, 54.85943809632332, 53.16313066790181, 50.67046834576515, 55.132454672167384, 53.966867462281265, 54.580369303303385, 51.61015841268724, 52.953550584854625, 52.62882540302893, 49.90435884844873, 48.880941867828376, 46.71753114269626, 59.854290177745206, 57.198716132871574, 59.04674868429861, 58.41212487989857, 59.660980086172785, 47.42056500527167, 56.58694405709544, 48.51952683541083, 45.007428738378714, 52.61992946747811, 60.53628052434614, 59.30981028464533, 60.2678805781949, 59.48194349965742, 58.515396964165475, 60.47742928228071, 60.47149473621, 59.07756282437233, 61.844336063631125, 63.315585736305486, 67.42264070818501, 64.10115411204677, 66.68434081539031, 62.68462150327621, 67.53948811561831, 66.5424608415173, 67.18066969225484, 58.13371896743775, 64.33926551572739, 4.2928797102743586, 0.19835321773444453, 1.6752150053939514, 2.0624239117868486, 0.3327553460915243, 12.249599310659594, 79.82542622473933, 60.4151891123864, 77.99603277637114, 68.72178462243849, 80.08205121563327, 35.57082976064375, 62.47387647628785, 35.19253284700456, 41.79447412490845, 62.766104821235906, 55.137071301860196, 0.5822308061103667, 0.07217472148758751, 0.09734658569458032, 0.02220101737146897, 0.027662963801694494, 0.059005827117230625, 0.09069238428867633, 0.1260667776448592, 0.16175448564031433, 0.31762186137418597, 0.09764559747230622, 0.31752269895326707, 0.31945777576296563, 0.6887767211564126, 30.997173555435676, 91.37392736250355, 64.95746635621595, 59.7456483687124, 59.833807560705374, 82.18655970788772, 45.54375794626052, 61.32157041180519, 81.4239646542457, 75.00868505047214, 75.33948990606493, 69.26522900981288, 76.62146168370401, 22.589249495537054, 0.8333942029745349, 7.257863062043344, 1.6924150888958287, 2.8841531084429834, 1.026934304785344, 28.091238544833278, 62.58257319850307, 43.4164918622663, 64.99075158949822, 59.334191737636445, 67.81858044285929, 63.18793219904747, 60.546215887992616, 58.263572954362445, 62.09867823508478, 61.38835268635904, 63.36240706905242, 63.08051416950842, 60.637018757481734, 60.37236859721523, 64.50705666695872, 63.63692983504265, 58.018044348685976, 53.77333379560902, 62.839005993258574, 60.023336487431685, 60.38327670866444, 50.701925754547126, 66.15930803360479, 60.88121767966979, 61.29099553631198, 58.467614650726325, 57.59256916661417, 53.14635076830464, 58.740086017116425, 50.57662563939249, 54.210576088197776, 59.563901424407966, 60.26839833105765, 57.72069338829287, 58.01721672857962, 58.34562501599712, 57.610227677129934, 59.59768087633195, 56.77299384147891, 52.25729850030715, 49.899381360700055, 51.44502662843274, 49.86348382888302, 47.162833905989125, 48.62401093206098, 49.056193367127456, 44.70454723604264, 45.44504757850401, 47.71409165474677, 47.764654928638095, 48.085398904738895, 47.76730252850441, 50.23095107847645, 53.81184754833099, 51.40024885054558, 56.148870222030155, 49.17973626044489, 50.11964990246681, 67.16528615643902, 65.5099125831358, 62.9690678658024, 63.74679150119905, 56.58488481275497, 60.0400536291061, 59.19021329572124, 58.907504543181396, 58.49497318267823, 52.914758343850416, 51.87786802168816, 55.17708339998799, 52.48915764593309, 49.815195529691636, 49.75831331745271, 49.05098838190879, 46.70747026320427, 45.64312727220597, 45.82544688255557, 46.37576326247185, 48.95492953638877, 49.775489376437285, 51.71944741279849, 48.563747636733524, 51.32584933311709, 49.82017301744031, 56.575835904767445, 59.47281222189627, 55.12226435445971, 57.96739870502103, 58.20074050657211, 58.74665598715506, 55.86502005977016, 57.164615046593454, 57.22568635017642, 54.0485429763794, 52.42074758775773, 49.881977804245494, 63.330918281309074, 59.92979972593246, 61.77597307389783, 60.27763943518362, 64.89646173292591, 50.69577547811693, 55.037486245555264, 45.62011080403482, 47.49967136690694, 54.716934465592914, 64.28540352852114, 61.418280370773815, 63.646582788036724, 63.65800865234868, 62.29116855129119, 62.906764937985336, 63.937987435248594, 62.273800296168176, 62.99272368031164, 65.85035077987179, 70.89812740202873, 67.47152913001277, 70.15469704904865, 65.94731177053144, 70.48797299785, 69.77230518094956, 72.1204242398662, 60.730755559859745, 68.12683166996126, 5.984617087148852, 0.2959918591283983, 2.11839025059054, 3.5486369363723265, 0.5525369317300859, 14.365472870488322, 89.71944024485927, 65.55771843079599, 86.55324028384301, 73.7043086944088, 85.99145489354288, 44.119694386759114, 75.73795564713018, 31.36586262333778, 53.03834438323975, 72.60482911140689, 70.96511363983154, 2.3328693739829527, 0.23058144886407161, 0.29368363621254123, 0.16059623730759467, 0.18869975912234477, 0.15275741116173808], [0.044432203285396106, 0.007882241784940444, 0.022103733781184402, 0.027648019341511593, 0.051914285267553026, 0.05483553174041933, 0.12581422143886167, 0.35626413300633436, 5.265964836843553, 64.50130254991593, 49.287177824204974, 38.353645493907315, 17.330000246724776, 50.27359508698987, 36.64440993339785, 55.85764208147603, 70.72002826198455, 63.39519808369299, 68.36843398309523, 55.45293977183681, 65.39853688209288, 26.93280573814146, 0.3745430521667004, 1.5755052912619807, 0.10791367310429774, 0.946827493607998, 0.17723919102741828, 11.041040574350665, 48.65645285575621, 44.2789779170867, 64.07304640739196, 57.434348598603286, 65.66395582691317, 57.1444187625762, 56.73305234601421, 54.97235921121413, 60.70937864242062, 57.26191336108793, 59.894435636458866, 56.53725547175254, 55.40549478223247, 58.46918752116542, 57.96390779556767, 56.676707498488895, 50.4804059766954, 51.101179892017, 58.11027496091781, 58.18178761389948, 54.76257124254781, 57.94740638425274, 57.043649150479226, 54.942082435854026, 54.7478231306999, 51.732897220119355, 52.22839847687752, 45.9565560279354, 51.61686566568191, 48.55035274259506, 48.374858056345296, 52.195403498988, 51.91216522647489, 50.116131536422245, 51.79252509147891, 51.00931406021119, 51.60260000536519, 50.82831628860966, 50.839957883281095, 46.53055175658196, 41.30620571874803, 44.33675835209508, 39.952940940856934, 37.99473293365971, 39.80435371398926, 37.50693521191997, 43.93004778892764, 39.72203493118286, 41.373352773727916, 45.33595469690139, 45.54288718008226, 43.43576638929306, 43.992813556425034, 47.216229131144864, 47.18052771783645, 43.573543563965835, 48.0587189428268, 54.73954300726614, 60.20906463746102, 54.6617780962298, 50.791210666779556, 53.748116877771196, 56.21928461136357, 40.41747900747484, 56.62633249836584, 51.65853692639259, 45.05314396273705, 47.174632395467455, 45.464643739884906, 47.31648491274926, 45.72421835314843, 43.67631358485068, 43.92534486709103, 45.24818774192564, 40.71418669915969, 40.75838396626134, 43.470196954665646, 42.347489095503285, 43.19520742662492, 37.22878425352035, 41.589189037199944, 44.00316076893961, 41.74334995208248, 49.07424411466045, 50.03131420381608, 53.05630491625879, 53.21483142914311, 48.725647387966035, 51.95536621155278, 52.251893474209695, 50.05860997784523, 52.15132782536169, 45.614905818816155, 47.38762494056456, 49.64909492000457, 44.444909864856356, 48.15222824773481, 49.150491068440104, 52.83525582282774, 55.87802271689139, 53.08921752437469, 40.61911629092309, 32.45299654622232, 34.55954074859619, 56.57917384178408, 58.34468364715577, 64.33736708856398, 57.33174723963584, 57.87124572261688, 54.78194382882888, 56.019028002215975, 56.24698438952046, 58.84454657954555, 49.358129578252, 62.48484342328964, 57.640394626125214, 61.68821396366243, 60.380060365123136, 63.35928094002509, 60.32705345461446, 60.8506545712871, 54.314836609748106, 61.3511097815729, 60.27190100762152, 61.43289119966569, 0.6911012157797815, 0.30567355574138705, 1.1964899710109158, 1.50056742852734, 0.35874414347833206, 22.603138608317224, 69.91608358198597, 62.90990283412319, 65.94855908424624, 60.98070467672041, 49.31890587652884, 34.41138498244747, 61.85398117188485, 25.569531071570616, 37.600209174617646, 58.98893687032885, 37.8107855396886, 0.2697096807101081, 0.17421246956913702, 0.05593304845294165, 0.14915296747799844, 0.015782086355161044, 0.08344095605876177, 0.10093202273691855, 0.03344097512684042, 0.030154270240135735, 0.04515727103177098, 0.02998417956874736, 0.1256261085490546, 0.12940712783846164, 0.4844410921777449, 6.689048784394418, 74.74969879273446, 56.5749063030366, 42.7997422987415, 32.895300657518455, 64.184174999114, 39.0465949427697, 64.1132075555863, 77.88731251993488, 72.13370538526966, 71.19657270369991, 62.57330071541571, 70.61500287825062, 30.059731006622318, 0.5235470002216678, 2.148947475417968, 0.4102575196133506, 1.0006300936783514, 0.4423532022103187, 11.97021378624824, 58.32971196020804, 50.40362558057232, 65.29437441979685, 60.21405781469038, 67.81745080024966, 59.73257510892807, 60.96923174396638, 58.32504041733281, 63.72061360266901, 58.33092005022111, 60.492161704647934, 59.389257892485595, 55.26877272513605, 60.19117862947526, 60.83178404838809, 59.89186256162582, 51.30089521408082, 55.41939173975299, 61.430918247469016, 60.87303953786051, 57.2782108091539, 59.47943318274714, 59.20804831289477, 55.777849305060606, 54.985303032782774, 52.39268695154498, 54.08844917051254, 48.584979426476266, 53.78067255020142, 50.398299001878314, 51.783939023171705, 54.98554229736329, 52.57453979984407, 52.39375775860202, 55.467103450529045, 54.49696010158908, 53.414142747079175, 52.47737876830563, 51.58491403825822, 48.77468093749016, 44.69296839929397, 48.572431764295025, 42.890141164102864, 42.17445373535156, 43.376397394364886, 41.627479214822095, 45.639793257559504, 40.87469008661086, 42.65583053711922, 46.29198928033152, 45.590638114560036, 45.51936864852906, 46.89940360284621, 49.28898995922458, 47.82025452583067, 46.53316797748689, 47.775496359794374, 55.278931663882354, 60.76948896531136, 57.75253518935173, 52.76997189367972, 57.31885440887944, 58.05137665041032, 45.96396930756108, 57.104747910653394, 52.25612178925545, 52.49368013874177, 48.0708469113996, 50.6177830696106, 50.42691661465553, 49.46426891511487, 47.50398597409649, 46.2441598984503, 45.340104564543694, 43.2141524745572, 44.09868617211619, 45.37886150421635, 44.338907810949514, 43.638564694312315, 42.53266026896816, 44.694843292236335, 47.9509400552319, 44.84693319566789, 52.08547515253867, 52.73834582298033, 56.62631680888515, 56.50229146403652, 51.64027437087029, 54.268858586588216, 54.92870323119625, 52.86344197488601, 55.606469185121604, 49.02951732758553, 49.721721526115175, 52.24686891801896, 45.98440485615885, 49.07123173436811, 51.47905318967758, 55.742587197211485, 58.020236953612304, 56.60857200622559, 44.37346781453779, 34.08425931007632, 36.69184315589167, 56.19930013533562, 58.81787838474397, 66.31694024608981, 59.12764364673246, 60.0502831705155, 55.37702229715163, 57.99643208903652, 58.62344257293209, 64.23579339058169, 51.710645614131806, 63.404886338018606, 61.65513269362911, 65.33724984815045, 63.35697458636377, 65.60037420641991, 61.898127448174264, 64.40524370439591, 59.88711649371732, 66.4976752188898, 65.2061132461794, 65.76895767642607, 1.214296060704416, 0.2738690478426795, 1.502129267300329, 2.1806468454099472, 0.23117073901718665, 24.282875983945786, 78.16496141495244, 66.28071323517831, 74.74122647316226, 66.21997925543016, 60.57794001794631, 34.829074259727236, 72.73254932895784, 29.042978132924727, 35.40780821154195, 70.9628386651316, 45.82020659600535, 0.04595161993957816, 0.14752579672682672, 0.0024196283794158412, 0.049504624649641976, 0.10559953598966522, 0.01139666487072264, 0.14787462720226857, 0.11544749666486057, 0.17480523776142828, 0.13057584093222696, 0.17305325596563279, 0.1764278426285713, 0.18447948799979302, 0.5991973860129234, 7.036581568179592, 89.91922224721601, 65.34255681499359, 57.589548941581484, 27.342930724543912, 68.2792785090785, 48.00670439197172, 68.65899532072007, 82.52913167399745, 75.71673562449794, 79.3811942685035, 67.56725849643831, 74.24409743278258, 33.456448662665586, 0.6599778213327931, 3.5705477864511552, 0.9259933341414699, 5.7938035841911075, 0.35380918893121904, 15.11813844403913, 59.535593678874356, 44.00257241341376, 67.6258743962934, 60.59568874297604, 72.33820207657354, 60.68002362405101, 61.80095857189548, 59.213276832334465, 65.7230463335591, 61.64114944396481, 64.78088125105828, 60.69010411539386, 57.62241448125532, 63.01404568456835, 64.22835657673498, 61.118979992405066, 54.87062469605477, 58.39125394821168, 63.16532365737423, 63.33450725001674, 61.291430919401115, 61.39395775333528, 61.01034210574243, 59.33025367798344, 60.244279676868075, 54.397276986029844, 57.65568010268673, 49.991082452958636, 55.50480135025517, 52.226147036398615, 55.305137019003595, 58.406017749540275, 57.21040871835525, 56.736056881566206, 59.22690706868326, 58.74306701844739, 57.703238841026064, 57.37096701898883, 55.82522761437201, 53.647155069535785, 47.653087031456735, 51.48967496810421, 48.64216366121846, 47.057592791895715, 48.29909747646701, 46.8992349409288, 50.66981330994637, 43.431475316324544, 45.10287177178168, 50.83263089579921, 48.3724065749876, 48.26260374438379, 49.66135232679306, 51.75055573063513, 51.587361597245746, 48.278355982995805, 51.3386558717297, 59.25929800156624, 65.57883254943356, 57.30949563364829, 53.74520647910334, 57.304777022330995, 63.7575387954712, 54.265332375803304, 62.7171967875573, 55.496219204318145, 52.462850309187374, 51.90883121182842, 53.2518978272715, 52.73688670127623, 53.968401109018636, 49.244392610365345, 48.58601885457193, 49.91691435537031, 46.12351563669021, 46.58414310024631, 48.64967107772828, 48.608160634194654, 48.86652715744511, 46.45816833742204, 48.55849558307279, 50.99715471267701, 48.06727755454279, 57.18938089186146, 57.18703139212824, 60.13870908368019, 60.69867449422037, 54.29296547366727, 57.91504290796096, 59.923837723270545, 58.46726948215116, 57.29829334443616, 51.71206551213419, 51.51766892402403, 55.71862936019898, 49.93814614511306, 52.142337752926736, 55.138977573763945, 59.0706241515375, 60.540979523812574, 59.185326022486535, 49.13448779813705, 34.25090120684716, 39.510815297403646, 60.28536650442309, 59.894435636458866, 69.52448198872229, 61.786645843136704, 64.9422985507596, 59.83689446603099, 62.91442140456169, 61.46376417529199, 63.59318364051081, 55.13446684806578, 67.51866033000331, 60.126526201924975, 69.06328185912102, 63.370232197546194, 69.42815642203055, 62.252956821072495, 69.39515359940069, 61.510985589796505, 69.61148015914425, 67.18363500410511, 69.62627533943423, 1.563453441185336, 0.9789706430127545, 3.8184001513065833, 2.807118248554968, 0.3797609689495256, 26.54852132643423, 86.09143610923522, 71.63456024662142, 79.93216960660874, 72.77732710684501, 66.18954950763334, 44.67906359703311, 80.28013090933524, 37.103731247686575, 55.06494283676148, 78.71180257489605, 62.90314851268646, 0.6776609692362048, 0.29666512783977295, 0.3449736211088396, 0.26926697382042486, 0.1580789183536845, 0.14186023944808593], [0.020443119461678212, 0.07223622302614874, 0.06897074260538624, 0.10554803189851585, 0.06554464419041911, 0.059848205907450575, 0.0994608581306473, 0.028277170964546745, 0.26782991544854257, 44.26328451402726, 48.71110716173726, 42.06185425481489, 20.455917466071345, 34.23868694613057, 41.38131910754789, 45.68460241440804, 73.47432444172522, 60.357024285101126, 70.49346431609123, 58.82408357435658, 65.03654918363019, 33.74474287033081, 0.16233465934713043, 0.8685822760866535, 1.1745607348219043, 1.7256150106268546, 0.10645953863258324, 2.808540107742433, 41.78556642224712, 45.874464742599, 61.71154029907719, 56.1079442116522, 63.53671719951015, 53.83248313780754, 60.76051850472728, 55.2408258376583, 59.056621290022335, 54.94699324330976, 58.11969649407172, 55.76364640266665, 55.836790761639996, 57.19895147508191, 58.78206714507073, 53.45934021857477, 49.35432487918485, 50.37637687498524, 59.526274127344934, 55.39044857025147, 57.21835151795418, 55.823258584545506, 57.945413820205204, 52.58429473446262, 51.9271251463121, 50.15409615732009, 51.264550532064135, 48.22328590577649, 53.35389121886223, 50.7958233741022, 48.52257059466455, 51.884434069356615, 55.47783113295033, 48.3372974395752, 49.91782434525029, 50.85466677142728, 50.45988413595384, 51.6756933735263, 51.65415171653994, 49.01639307698896, 42.516962943538545, 41.71253973437894, 44.06400457505257, 39.634366035461426, 35.334628551237046, 35.328089960159794, 38.136303040289114, 41.12475295220652, 42.12596931765157, 45.02634632971979, 45.18088379213887, 43.44765117091518, 42.33156035023351, 46.13107404401226, 46.1409858734377, 52.25318393399639, 49.27233557547293, 55.34669060860911, 58.180975683273815, 45.009476215608665, 49.08496395234139, 47.52911267742034, 52.260573679401034, 49.52806626596759, 42.67660340955181, 51.105557257129306, 51.508831824025805, 49.46806576944167, 46.90412221416351, 45.31259698252524, 46.4962153280935, 43.87593869240054, 44.56074530078519, 41.384249118066606, 41.09202469548872, 43.04092491826704, 41.65814822719943, 41.16439634753812, 40.01448292886057, 37.11188977764499, 40.740956875585745, 41.10991854821482, 43.74959130440989, 50.08232070553688, 52.59149228372882, 49.76214547311106, 52.80857193854548, 48.31111561867499, 46.13309014228083, 48.221446314165675, 49.715253537701024, 50.60951863565753, 49.51747978887251, 49.58920032747331, 49.70384728523993, 44.909836246121316, 48.37975317432035, 46.547794495859456, 54.521094445259344, 55.07466247004848, 58.25783844917052, 59.69601077418174, 43.635889637854795, 55.627344039178666, 60.889537026805264, 54.815131002856845, 59.1512994612417, 53.446929839349565, 55.59121900989164, 51.605349586855986, 56.18268889765586, 56.3136136916376, 64.42224325672274, 49.79129652823172, 47.323906037115286, 58.963021770600356, 62.55467337946739, 63.282637826858036, 61.726457072842514, 54.71251395440871, 58.51311806709536, 62.91180910602693, 65.79399024286579, 63.27494605895012, 62.96806766140846, 0.6499416405154813, 0.5199134758403224, 1.233421537664629, 1.0491265236370027, 0.338084560127989, 32.41820512279388, 63.93275107106855, 65.44845688727595, 62.907286613218254, 68.38809290239888, 37.195063637148955, 38.42389122132332, 59.05746852197955, 33.87508323115687, 49.123858174970074, 57.226137422746234, 33.06160326926939, 0.6635100995340656, 0.10546124945845335, 0.24083426402461147, 0.1564160632269998, 0.09581134549432224, 0.054086761233667215, 0.07926180853598541, 0.06362435287765919, 0.09226855656672871, 0.03832074453032786, 0.03788460684459537, 0.074393319777183, 0.31755236187769526, 0.06180423522187818, 0.3665667285601939, 54.44625562237155, 58.73201770167197, 45.40725554189375, 24.35148608299994, 51.229500232204316, 39.26191345337899, 52.38207694022886, 79.42088865464734, 65.20816072340935, 76.02253144787204, 63.65112489269626, 71.65696482504569, 36.71942134057322, 0.0934778723204809, 1.1092693286557351, 1.8134942434487806, 2.202778083662833, 0.3718172806885935, 3.72624455440429, 46.67280043325117, 56.05916953855946, 63.27487545628702, 57.96368029809768, 67.83599576642438, 57.19963396749189, 62.77367499566848, 58.33092005022111, 62.33178077205535, 56.91720762560445, 62.870863483798125, 56.323215653819425, 57.31060958677723, 58.66830272059287, 61.602106171269575, 54.79468760951873, 50.435914531830825, 53.60746068339194, 62.17521936662736, 57.65200484183527, 59.67309628763507, 60.097818374633796, 57.06563795766523, 54.344627011206846, 51.92037866961572, 52.2733292272014, 51.77428607017764, 49.39023810048258, 53.914578345514116, 51.87844068773332, 49.788790133691606, 57.21414281475929, 56.645281468668294, 51.2756626067623, 53.66797501041044, 53.87778259092762, 53.15177932862313, 55.15848744300104, 53.10640927283995, 52.310972213745124, 46.334531307220466, 45.19887570411929, 47.50419778208579, 43.786343912924494, 38.683858071604085, 38.512725060985936, 40.15288376039074, 44.20184058527793, 42.51661385259321, 47.44711552896808, 45.003396541841575, 45.227850252582186, 45.04462065235261, 48.06103706359864, 47.36982130235242, 55.48809989806145, 51.7424403467486, 55.438685878630615, 59.15080132022981, 46.15700483322144, 50.32122050562213, 49.418820411928245, 53.49473568700976, 51.58542394638062, 48.53826792009416, 53.82720754992578, 53.2857165028972, 51.54752208340553, 48.66344644177345, 48.678292612875666, 47.9116928192877, 44.93939130536972, 45.96486360796037, 42.75128141526253, 42.83520052509923, 43.38121014256632, 45.63291342027726, 45.01973321360927, 43.761989916524584, 41.50592104081185, 45.00763662399785, 44.632732560557706, 46.60067981289279, 52.060987795552904, 54.48818575951361, 54.53799986070203, 55.97102603604717, 51.404273202342374, 50.251825932533514, 51.99757483697707, 52.54201158400505, 54.30756061307846, 51.055052818790564, 52.28683002533452, 51.51604506277269, 47.21671942741641, 49.25606558399816, 49.73581460214431, 55.95608572806082, 58.38655887111541, 60.62593413937477, 61.298526487042835, 45.701849076055716, 55.310840145234145, 63.78232425259006, 57.29335508038921, 60.98795713916902, 57.00613167978103, 58.53864092980662, 54.63970691927018, 59.76954737017232, 58.09149465253277, 63.52829979312036, 54.191756556111, 50.407426357269294, 62.53906234618157, 64.45492836736864, 66.48135815897297, 64.70544622790429, 58.98386132332587, 61.94971053831039, 67.39724728368944, 65.89968635189918, 64.68328483643072, 70.41894712755757, 0.8024654561473478, 1.1826855569116532, 1.648781662506442, 1.7581317045034903, 0.21655955772486427, 35.538599644937825, 72.0550932422761, 68.35389767923664, 73.75454641157582, 74.35933666844522, 44.76129608769571, 41.92985080903576, 68.54323833219468, 32.816178606402495, 50.91252957620929, 66.09420453348469, 39.46222889807917, 0.5423669000306438, 0.08593762894311259, 0.05031352922801049, 0.07546329945926705, 0.05543869574584308, 0.0883381884364832, 0.18582360458470162, 0.13828063233485147, 0.16977430771916144, 0.27118826104748633, 0.12410407570461113, 0.20986732005351977, 0.3461787693442837, 0.09709609792597833, 0.6118127703666687, 66.7056079064646, 67.04006056631765, 59.89255289877615, 28.407430610349103, 48.74623198663035, 55.87635570956815, 56.42859797323904, 87.73061813846712, 71.80512059119441, 80.75440037635066, 69.38525353708576, 77.46583031069848, 42.6230199106278, 0.28435761890103745, 1.9405165242571987, 2.409537982556128, 7.665662082933611, 0.2613267482769105, 4.021580151973232, 52.48076769613451, 51.74658629202074, 62.605970136580936, 58.678540106742616, 70.1698060189524, 60.05540186359037, 65.96538605228548, 60.327912453682195, 65.52217391229445, 59.24088639597739, 64.08409964653754, 59.006528700551684, 57.56568524145312, 63.989311648953354, 64.89177057819983, 57.25220941728162, 52.685719382378366, 54.98459308378158, 62.59052384284235, 60.694971776777706, 61.191790949913766, 60.58893834390948, 60.48535639239896, 57.28495728585028, 56.255413563020774, 55.53646664465628, 54.88516492228354, 52.35644032878261, 57.395164120581846, 55.77529191970826, 53.11351268522201, 59.04642312757431, 62.70626514188705, 54.58495063166465, 57.35532068437146, 58.6651256007533, 55.31618241340884, 59.99472279702464, 57.43135190779164, 55.87430430996803, 49.94623407240837, 49.81347360918599, 52.577156020749, 49.67997574037122, 45.17961294420304, 44.24916398140692, 43.74779485887097, 46.50303632982316, 45.24268073420371, 50.94511662760089, 50.04045724868775, 47.324549305823545, 45.75544041972007, 49.39001452538275, 48.97902857872748, 57.06400625167355, 52.95414286275064, 57.12194358148883, 61.021458102810776, 47.8568894632401, 53.389165093821866, 51.39522037198467, 59.46072347702519, 54.6908938500189, 55.619071760485255, 55.95986297053676, 56.061016974910615, 55.89181377041725, 51.77532942064347, 51.46101028688493, 51.5600658232166, 48.55516549079649, 50.232994633336226, 44.87875538487589, 46.53396421863187, 47.618393667282604, 48.38287145860734, 49.17512355312225, 49.11853159627607, 47.322129203427224, 48.63684884963497, 48.37406965994066, 51.5695305024424, 56.462597077892674, 59.5356015236147, 57.22463123260006, 59.23063724271713, 54.267732866348766, 52.057277233369895, 53.40006143816056, 56.91310482640421, 56.92032590989144, 54.431895825170706, 54.70187648650139, 54.849985184208045, 48.52457100345243, 53.17330921849897, 50.44901132583619, 59.6130330331864, 61.47653541257305, 63.58673134157735, 62.08939006251674, 47.67378145648588, 57.944292022335915, 68.13421357062556, 60.63269630555184, 64.87563786968109, 57.90407596095916, 59.90975641435193, 57.329542867599, 61.87488740490329, 60.776592377693426, 65.88984120276668, 53.00761653530983, 55.13711444793209, 62.456445463242076, 68.48389287148753, 68.55757851754466, 67.43322326290992, 59.38005601206134, 65.25681380302676, 66.68945558609502, 69.70018848296135, 61.58169807926301, 70.0046036320348, 1.5355809561667906, 2.37518782577207, 4.082421996901113, 2.5112129267184966, 0.41351835754129196, 37.79064416885376, 77.51720551521548, 74.51386236375379, 78.14335700004332, 82.4397643919914, 51.19048441610029, 50.93170212161157, 73.92471451913157, 50.93263564571258, 70.72816325772193, 75.55944858058807, 53.60584074451078, 1.1276217309697982, 0.37865761847745993, 0.3883000607452085, 0.5263665102181897, 0.31055261651354454, 0.16418036433958239], [0.006148976474745019, 0.07195093188314669, 0.03428267592924737, 0.14802615939369126, 0.05587498281872081, 0.025550932172806035, 0.28824024443184176, 0.1493773546310202, 0.5925376304695683, 23.965981814169115, 59.647789155283284, 43.51524929846487, 34.98219182414394, 34.06757354736328, 37.34106994444324, 35.19217591131888, 75.50500608259632, 59.556790167285556, 69.95643692631876, 60.34104062664894, 60.5914015923777, 53.15990647962017, 1.2139481954997586, 0.18067593806453291, 2.757867252634418, 0.5774426340095459, 0.47580354276203346, 0.32795525366260164, 26.827337126578055, 37.24899230464813, 63.98312999356178, 60.28942223518126, 62.514229820620635, 61.414997346939586, 60.777110130556174, 59.147651656981445, 61.11738751011511, 56.862890643458215, 57.25988157333867, 51.95352269757179, 57.987434171861224, 59.493145788869555, 57.52088392934492, 50.376212135438, 48.60415197187855, 56.57486315696471, 55.09642770213466, 56.62816032286614, 59.9351498388475, 57.14296356324227, 54.59832983632242, 54.444145387218846, 56.45710968202161, 53.09900383795462, 53.80971770132742, 47.33241758038921, 49.65230341880552, 50.55271879319222, 47.4875198641131, 53.34241436373804, 51.67243780628328, 49.48071149087722, 50.86582983693769, 49.887488734337595, 51.44771345200078, 50.04521900607694, 51.3471713373738, 51.69001002465525, 48.01383526094499, 41.34210717293524, 41.763989463929214, 39.22739267349243, 38.56607714006978, 38.09945629489037, 41.23630123753702, 42.26512716662499, 42.78229167384487, 43.867670336077296, 43.2101438122411, 43.6666488647461, 42.94008862587714, 47.58084873999319, 55.08551959068545, 56.160154881015906, 41.639587571544034, 42.43249470187772, 44.58773905231107, 43.714670442765765, 45.61663558406215, 43.99020910263062, 43.56130576902821, 47.77147200799758, 39.67393882812993, 34.01072271408574, 52.09694024055235, 46.92041181748914, 46.32546670975224, 44.88111272934945, 44.95858738499303, 42.68320475855182, 42.65246514351138, 41.37595722752233, 41.35635714377127, 42.49959076604536, 43.03715159816127, 38.38053726380871, 39.333779119676166, 37.86352180665539, 41.39251747438985, 43.92060664392287, 43.45147155946301, 46.05264233004662, 54.12777877623036, 50.59322118759156, 51.664220440772276, 51.71839229522213, 52.971095346635394, 49.938973765219416, 49.35794914922407, 50.01076490648332, 45.534999293665734, 47.358771985577, 48.722952719657656, 50.41870709388487, 53.039195537567146, 49.71108013583768, 52.091190045879735, 52.624675535386615, 56.274366455693404, 53.083761507465, 58.39846326458839, 56.646881795698604, 57.87436400690387, 53.467859606589045, 55.26087307160901, 52.649527672798406, 50.22657371336415, 47.74150509988108, 54.43791274101504, 58.05061571059689, 59.92000556761219, 59.20800516682287, 43.97781049051593, 51.97636658145536, 62.93658671840545, 54.81844148328228, 62.80277113760672, 57.773908184420684, 69.75650587389546, 58.5699414437817, 75.79366899305775, 62.7322429995383, 51.61700687100811, 1.6878276318311694, 0.17516217344710905, 0.5286736606109528, 0.4379653263716929, 0.14594978532723843, 36.044279452293154, 63.98830752218924, 64.36785174954322, 61.06685953755533, 66.71004018475934, 31.90922267975346, 40.174664681957616, 59.85397638813142, 30.564740088678178, 34.25374884759226, 62.37323630240656, 22.64657493560545, 0.3450139479771737, 0.1517802966578353, 0.12526127449687452, 0.032171804923564196, 0.0568134060520078, 0.06628551250023228, 0.05609854642722396, 0.051808871569172035, 0.04672292875306261, 0.19022580626751148, 0.06073637760334438, 0.06093027445697977, 0.2777801412007501, 0.1875548407195076, 0.4719519897574379, 32.03239490908961, 71.74879535551995, 51.033162070858864, 30.696567027799546, 36.84555692057456, 42.599842625279585, 37.61451013626591, 86.83364268272155, 63.612156145034305, 76.81851371642082, 63.274134128324455, 68.12339567369031, 57.88144780743507, 1.1446279022962818, 0.310502115997576, 3.93618623095174, 1.4425523867530208, 0.4098191334595604, 0.0876123660935029, 31.32194188333327, 49.03508317086005, 71.10598948694044, 58.379600586429724, 66.35947442823841, 61.669743522520996, 63.636176739969564, 61.84350059878442, 63.53885096888389, 59.10439575872114, 61.10759335179483, 54.129637979692035, 59.456134303923584, 63.525299179938536, 60.35170555114747, 54.099973094078806, 50.37041094995315, 58.684227543492476, 55.64197055755123, 58.849496610703014, 60.98246582092778, 58.897616247976984, 57.12868221344487, 57.97376863418087, 58.054483167586795, 57.41662733016476, 55.89601070650163, 50.56979679292249, 50.06105361446258, 51.462869490346606, 50.645769180790076, 56.262646413618526, 54.19920513706823, 54.2339220354634, 54.45579090426045, 54.042781014596265, 53.30003315402616, 52.95088337313745, 54.87686518699893, 54.34854545900899, 49.38264439182897, 45.13581968122914, 43.92805914725027, 44.976602831194484, 39.765420267658854, 42.457080118117794, 44.04191770861226, 44.102557551476266, 42.86384951683783, 45.282818348177024, 44.61341096508888, 46.13949145040205, 44.6784830862476, 49.35405423564296, 56.33676744276478, 60.425199001066154, 42.67434020196238, 44.28501052241172, 47.66122202719412, 43.45223249927644, 49.30877439437374, 44.359586546497965, 45.67834231161302, 47.31814015296198, 40.72299634256671, 40.7447458851722, 53.835381769364886, 49.33457966773741, 47.92143206442557, 48.181547964772875, 46.94514628379576, 45.93307672008392, 46.65139998159101, 42.66761725948703, 42.46579170227051, 44.44454508443033, 44.558125157510084, 42.43685245513916, 43.440155521515884, 42.461386880567, 44.33976681001725, 46.561201157108435, 48.055965438965835, 50.348041672860425, 56.41803110799482, 54.37928115167926, 53.71466690494169, 53.38079083350397, 55.86241560597574, 50.810092956789084, 52.62572280822262, 54.29252616820797, 47.87316729945522, 49.81524652050388, 51.25125369717998, 50.7909910140499, 53.24476695829823, 51.89766814631801, 55.4423572171119, 55.45157086464667, 58.46693215831634, 54.09646649514475, 58.73099788542717, 58.288958534117675, 61.08449059147989, 56.49706294459682, 58.34871584369291, 55.36858135654081, 51.270755721676736, 49.50421041057956, 58.02765023323798, 60.59248808891543, 61.85902141755628, 61.974201817666334, 48.63873943205803, 51.93269098958662, 65.33428845867034, 57.60859204876808, 69.1083812713623, 60.71136728409798, 72.02562839754167, 61.15238289679251, 75.59730729749127, 68.50200637694329, 58.224027618285156, 1.8763455676455654, 1.4492525304517438, 1.303105753275656, 0.8348624564466939, 0.25384922451790304, 39.58552468207575, 70.85869973705661, 70.90860797512916, 68.57252274790119, 74.5557140534924, 34.92147353387649, 45.767438950077185, 68.62062669569447, 32.502700821045906, 41.528333463976466, 72.10344037702008, 28.07100695948447, 0.4656213149428368, 0.24747243121026025, 0.11027988887602284, 0.0888299019706826, 0.08410464101020368, 0.07227239003705402, 0.11084290987421429, 0.30149436225333526, 0.16403998638833725, 0.3032147505831334, 0.15233451530577677, 0.20608980178592667, 0.46149525731321306, 0.36344479769468313, 0.7805468839022421, 38.6205235604317, 83.58327650254773, 61.58863282972767, 51.3550200000886, 46.84537687609273, 50.87936985877253, 47.365126225256155, 88.80273526714694, 70.18973950416812, 81.24493983484085, 70.9146248909735, 72.38813384886711, 64.18484964678365, 1.367817016378526, 0.3396255919529546, 5.107267700856732, 2.6124993110856702, 0.6571453797721094, 0.5398052858729516, 37.256574246191214, 52.252015067685036, 61.450408504855254, 61.08119187816497, 70.84264155357116, 63.521518015092425, 66.20190497367614, 63.279127305553814, 64.88756187500493, 59.71550887630832, 62.59321066641039, 55.60946587593325, 64.24920005183067, 64.75158114587107, 62.5289269416563, 56.23411901535527, 54.04846060660578, 59.67345322332075, 58.752170839617335, 59.18648704405754, 64.04095749701223, 61.59342596607824, 59.272681128594186, 60.540210739258804, 62.90275235329906, 59.648801126787745, 58.507748342329464, 52.054566875580825, 54.737291566787235, 55.78750225805468, 54.410860153936575, 58.04845056226177, 58.73149994880923, 58.16413694812406, 58.03434571912212, 56.80178011617353, 56.227690250642844, 55.31390351633872, 59.94062154523788, 58.501884398921845, 52.14264369780018, 50.771241880232296, 46.478854917710834, 49.273006300772394, 44.31536574517527, 48.22913808207358, 47.8808355331421, 47.09651839348578, 45.49289264986592, 49.65903028365105, 48.18244618754233, 46.77453494841053, 46.3535116564843, 51.90195529691635, 58.18598062761369, 60.751614724436116, 42.74249138370637, 44.37163606766732, 48.98680271640901, 46.43270431026336, 51.276619665084354, 47.90054936562815, 50.59622964551372, 52.609397903565444, 41.08048508244176, 45.44549865107383, 57.64459940694994, 52.502019097728116, 50.295862382458104, 49.70855805181688, 48.9833039622153, 48.12421075759396, 47.84631867562571, 46.02446402272871, 44.04617348024922, 48.95911078299246, 49.02381420135499, 46.28300705263692, 49.36050653457642, 45.38119531446888, 48.13482861365042, 51.89200032141901, 50.17247638394756, 54.24113135184012, 60.84640664439048, 56.96414662945656, 56.69515048303912, 57.5808334350586, 61.132245448327836, 55.98156152233001, 55.36977767944337, 56.73721398076704, 49.693927611074145, 51.783331055794996, 53.730022984166304, 53.132312605457926, 56.07129358476209, 54.7641166563957, 58.3332734723245, 58.46137808215234, 59.96963139503234, 58.033270989694905, 62.31641684809039, 60.233489236524036, 64.28371298697688, 57.61313023105745, 61.25680031314973, 56.88857040097637, 57.38382062604351, 50.81649818728047, 61.60489497646209, 63.281676846165816, 66.76374527715868, 61.09138611824282, 49.58476020443825, 57.518522662501184, 68.069031623102, 62.08462046038721, 71.81080018320392, 62.67333684429046, 74.8620197849889, 62.67072846812587, 74.9690612669914, 65.48881415397891, 62.507044038464954, 2.066236210446204, 2.102580157018477, 4.611722317434126, 0.9925389181702369, 0.6557656860639972, 43.69918884769563, 76.44860283021005, 77.14368604844617, 77.65865402836954, 80.48239969438123, 43.42567020846952, 54.41998358695738, 79.94670591046734, 48.06963489901636, 50.11168356864683, 84.0577656222928, 36.77979446226551, 0.5219597886166265, 0.43502250686287885, 0.21805742815617593, 0.24177786984270622, 0.15412343786128108, 0.16752436877258364], [0.054710169112490076, 0.09367718541574094, 0.049746302407114744, 0.0735870658630325, 0.0876126878504311, 0.03710767111530708, 0.231314625651125, 0.0788560577277695, 0.7742708464784007, 9.874049155942856, 62.42719634886711, 43.59903112534554, 42.626855988656324, 38.342160794042776, 33.45321270727342, 31.455716279245195, 71.51471614837646, 58.77060990179739, 63.1464139107735, 63.5867666429089, 60.157242282744384, 58.92246054064844, 5.326679695037104, 0.2718656053466182, 3.1401654741456433, 0.9984453334923714, 0.23756224121297562, 0.30036104242167166, 22.231313605462354, 37.9240204441932, 45.927201009565785, 74.29034217711418, 57.397803875707815, 61.74454312170706, 57.906009689454116, 59.67199410161665, 53.66399772705571, 55.13438055592199, 52.113900569177446, 54.02342804016606, 59.89048973206551, 60.538088736995576, 56.717892385298214, 48.6976416649357, 48.041009441498794, 56.59607925722676, 60.28067534969699, 59.30563688278199, 56.68011996053881, 57.84519333993235, 57.40846880020634, 58.88273477554322, 53.65192859403549, 58.66671808304326, 58.28904482626147, 56.47553305472098, 50.39867947178502, 49.612507051037205, 46.22205342015913, 50.71461854442474, 54.462207901862364, 52.43299714980587, 49.485979234018636, 49.285357844445016, 52.0047959204643, 50.68728354669387, 53.006357454484515, 53.089723510126916, 52.45937116684453, 48.62100247413882, 42.783280111128285, 41.7017492940349, 40.4664654885569, 39.20982045512046, 44.439583286162346, 41.856871189609656, 44.78313976718534, 42.020284975728686, 42.07661413377331, 42.55144842209355, 44.535567606649096, 48.368033132245465, 56.05175625893378, 54.063385225111446, 44.809180382759344, 39.53163131590813, 50.290778990714784, 47.169262670701556, 45.14812807882986, 43.665593747169744, 47.16201805299329, 46.41453589162519, 38.08259402551959, 40.92638300311181, 40.56602308827062, 50.1057804015375, 49.61017716315485, 44.36866683344687, 46.27755888046757, 43.28524151156026, 44.013084365475564, 42.698074463875066, 39.80975089534637, 41.45941742004887, 42.80138184947353, 38.04972064110541, 37.075635310142275, 36.95265331575948, 41.946516959897934, 41.43451821419501, 45.60833192640736, 48.21195025597849, 51.421563010061945, 53.59329308232954, 53.763272916117025, 49.48867782469719, 53.60783330855831, 49.62166578538957, 51.29723172033987, 51.48372081018264, 46.686779760545306, 47.67780973065285, 46.582860485199966, 55.47802725145894, 57.49051693947085, 54.73972343629407, 58.941652697901574, 55.48549152189686, 59.363907614061915, 59.76437768628521, 56.35925046859249, 57.28160758172312, 55.70283005314489, 52.97339385555637, 50.152554665842366, 45.07863936885711, 43.742840905343336, 44.96576532240837, 52.81200793481643, 61.17623482981036, 60.352956787232436, 57.743348998408166, 62.24754787260487, 39.57111781643283, 60.866806891656694, 58.113514838680146, 65.4754114151001, 62.62098104723039, 64.22746619870587, 70.1656561513101, 75.43114785225161, 46.61592214338241, 53.84237927775229, 0.7190018315469066, 0.6642394765250145, 1.4164485229599861, 0.2637463603769579, 1.2273108526583643, 55.13689871757261, 60.84422580657467, 64.06323655959099, 58.19546491869035, 61.90330105443155, 32.63243517568035, 53.555552036531516, 46.799857770243, 33.28294654046336, 42.26789243759648, 59.226597201439645, 11.017346516732248, 0.435437573300254, 0.19508075059181262, 0.1360474707138154, 0.11539391647543638, 0.07124653701940853, 0.05268501951509426, 0.05676242673108655, 0.19041924346839229, 0.02856524492193374, 0.09251778795113487, 0.10773681404609835, 0.05547739850777773, 0.1714531740834636, 0.22514640744174683, 0.8277598407960708, 13.39227693696176, 72.17545509338379, 52.05406088982859, 38.00112247467041, 44.17445459673482, 40.87742790099114, 33.70038870842227, 82.1122778615644, 63.87220144271851, 69.87879753112793, 68.44957997722011, 65.06634742982926, 63.393978226569395, 5.93397879792798, 0.21066340798091507, 3.6205518774447905, 1.0779016440914524, 2.820649935353187, 0.5174471017333769, 29.03573351521646, 41.09345243823144, 59.45086656078216, 75.07478483261602, 57.7285381286375, 64.64978779515913, 61.174305023685584, 61.867423134465376, 57.78947999400478, 56.32164278338033, 54.458716992409, 57.25074245083717, 63.74989017363518, 60.67034321446573, 58.38579008656164, 49.41959704122236, 50.3745686623358, 57.69987344741822, 61.30113094083725, 58.77157872722995, 56.87739164598527, 59.785833051127774, 60.54190912554341, 59.47130210937993, 56.767169121773016, 58.60840028332126, 60.68431861938969, 57.37863525267571, 52.54862862248575, 51.1133784632529, 47.62932923532302, 52.62027855842344, 57.52224106942454, 54.74015097464285, 54.34087722532211, 54.15637677715671, 56.64952939556491, 56.41566199641074, 56.45172819014519, 54.84874179286342, 53.565679596316436, 50.23694446009975, 45.19063872675742, 43.782099908398045, 43.559438720826186, 43.15842736151911, 47.11156068309661, 41.593036882338986, 45.42827160127702, 43.97819488279281, 43.38375968317832, 44.19838497715612, 45.69083506061185, 51.08121110546974, 59.362162159335234, 53.42870258515882, 46.14530440299742, 39.68001065715667, 52.642969469870295, 48.34547950375465, 44.86394843747539, 45.179381524362874, 48.776649967316665, 46.304744828131895, 36.255848177017704, 38.48160497603878, 47.641676856625466, 52.96169342533235, 51.787072996939386, 47.55184673493909, 47.83636762249855, 44.10678194415185, 45.40196034216112, 43.39676626266972, 43.331399963748076, 41.3619072975651, 44.577305547652706, 39.93574134765133, 41.73375975701117, 38.2397477088436, 46.56900275138117, 45.76824695833268, 49.7740420218437, 50.332458096165816, 52.80360621790732, 55.893194444717906, 56.36005847684799, 52.95417424171202, 55.03810205767232, 54.35123228257703, 55.39168803922592, 52.6627617497598, 49.495412534283055, 51.423469281965694, 48.74763619515204, 54.36390938297395, 60.0904364739695, 57.81976461410523, 63.2367657076928, 58.14401518914008, 61.2852414192692, 61.486439397258145, 56.458796301195704, 58.35354035900485, 56.85581861003753, 55.24806261062623, 51.96822374097763, 47.193177361642164, 47.768365490821104, 45.863929256316155, 54.65713008757561, 60.75647846344979, 63.31553866786342, 59.06600752184468, 66.62931780661306, 44.138874776901744, 62.58409507812993, 62.01194286346436, 68.19220973599342, 67.11245183021792, 66.159221741461, 69.84813244112077, 79.26488814815399, 51.881708022086855, 57.45077940725512, 1.1556688840350797, 3.230308895149539, 1.453626095767944, 0.38618072446796203, 1.1965033315843152, 62.28017022532802, 65.64327709136471, 73.0582001901442, 65.08554350945258, 68.65311176546159, 36.53459925805369, 57.29679107666016, 58.70397275493991, 36.95687770843506, 44.89910071895969, 70.98043441772461, 15.212259638694027, 0.497438968910325, 0.2658520909326692, 0.09065865343737026, 0.07548166258681206, 0.07854445912544766, 0.019264148450606776, 0.24035311484288788, 0.30050224774787504, 0.19292985149208577, 0.21997623325836277, 0.19842742101079036, 0.1699947571802524, 0.29997508732541917, 0.31211390370322817, 0.9708477821080916, 15.770208950965637, 88.12673045742898, 59.91062325816001, 64.99406206992366, 52.546875323018725, 48.53767564219814, 41.08852594129501, 89.23665923456993, 68.53612315270209, 74.865094923204, 71.45212296516665, 71.15101829651864, 68.38140918362525, 6.638454131541714, 0.3564558082049893, 5.5097690705330145, 1.9388204668798756, 3.3077301084995274, 0.45178392841931314, 33.06053638458252, 49.50781114639775, 59.23587752926735, 67.26719717825613, 57.612294766210745, 69.745774269104, 64.12478639233497, 64.27587609137258, 61.328124692363126, 59.4395975912771, 55.24419515363632, 58.70183898556618, 65.78049336710285, 64.62062889529814, 62.00472962471747, 51.5471298463883, 52.73843211512412, 60.291332429455174, 65.02312291053035, 63.03472834248697, 60.13514364919355, 61.01170316819222, 63.23731483951692, 62.545051805434696, 56.862227762899096, 61.33084681726272, 62.155846780346295, 61.361158893954375, 54.49747393208166, 54.18341367475448, 49.26276891462265, 55.50219297409058, 59.58557644198018, 59.04261450613699, 56.889919696315644, 56.05814972231465, 63.106707757519146, 61.407223209258056, 61.58519683345672, 59.108110243274325, 57.33079802605414, 54.21678520018055, 49.64094815715667, 49.44786948542441, 46.48075334487423, 46.81668866065241, 50.73078263190485, 44.99100185209706, 47.83969771477484, 45.891593733141505, 46.45089234075239, 46.131101500603464, 48.063135531640825, 54.634498011681345, 62.398931749405406, 54.740790320980935, 47.11065461558681, 40.68747928065639, 55.52022803214289, 51.47088289260865, 49.6321032124181, 48.306130286185976, 52.36481066673033, 47.10652435979536, 37.941545594123106, 41.42711670167985, 51.815674920235914, 55.39017008196924, 54.173654817765765, 49.64918905688871, 50.94691307313981, 47.46528002523607, 50.94590110163535, 46.940459051439845, 45.409769781174205, 44.41135006566202, 48.58280251103063, 43.10645595673592, 47.71611559775568, 42.41590307604882, 50.95191017273934, 49.32106318012361, 52.87058853333997, 53.51440637342392, 56.9760274887085, 60.39281591292351, 60.45772721690517, 56.5606955559023, 58.073738082762695, 55.76296783262684, 59.94552450795328, 54.99700738537697, 51.366351727516424, 54.88328218460084, 51.9737111368487, 57.37319492524671, 61.18698212408251, 58.71998386998331, 66.16183403999575, 61.74564530772548, 63.57717644783759, 61.39723685479934, 58.00990543057842, 60.583745125801336, 60.379240589757124, 60.124545404987956, 55.64637930162492, 48.76789131472188, 48.389551255010794, 48.526967571627715, 58.3227183741908, 66.2077179262715, 66.20586656755017, 60.320997315068404, 64.08952820685603, 46.895783255177165, 67.88931646654683, 63.78890991210938, 71.1575843441871, 68.69235115666544, 70.33212154142319, 69.32025201859014, 78.89546363584458, 55.71970801199637, 61.37240432923841, 1.6098381651024667, 5.98989071384553, 6.69174982655433, 0.4136135669485216, 2.1836391235551527, 65.99559614735266, 73.49971002148044, 76.59865702352216, 69.99076551006686, 77.02427341092017, 44.52064298814343, 69.00511310946557, 64.55630202447215, 49.06317518603418, 57.64138306340864, 82.60903035440754, 21.287718819033717, 0.9658584659618716, 0.43944384542203724, 0.4633524076592538, 0.41874997197620334, 0.2840677618740067, 0.239924963623766], [0.03443518871321313, 0.0661154563028005, 0.021254138442717736, 0.05507056368514896, 0.011138191593119936, 0.026605360270027193, 0.05635008756672183, 0.1453405922098506, 0.08832257556458635, 1.785326845222904, 49.02661085128785, 49.06438719841742, 37.176420611719934, 30.290854707840953, 35.42595701832926, 24.355669290788715, 68.6082241612096, 66.39053175526281, 61.047843886959946, 64.5357095810675, 56.48176177855461, 65.54522568179716, 10.433653708427183, 0.6334732629118428, 1.7216724157333376, 0.17272923141717914, 0.4701278118356582, 0.2952955158487443, 9.552635435135135, 51.083948919850016, 32.333754531798824, 50.75084163296608, 67.06192385765814, 59.48898023174655, 59.93884078917965, 57.214566430737904, 58.66990696999335, 55.41890144348145, 61.08931510679184, 59.09680989480788, 59.45547142336446, 59.32552329955563, 54.4002579873608, 45.95803476149037, 54.094783798340835, 56.27107558711883, 56.095306334957, 57.0858891548649, 58.156696211907175, 59.94636389517016, 57.215068494119954, 59.3102260558836, 57.23800259251749, 57.332374818863414, 59.551679318951024, 58.28498909550329, 53.707057506807395, 48.57024700410905, 49.629051608424035, 48.58240635164323, 54.77618578941592, 51.52120690191946, 51.81805187656034, 47.577353908169655, 49.645847197501894, 51.21155931103615, 54.19727140857328, 52.415052306267526, 52.636799581589244, 49.17612375751619, 45.42955813869354, 42.2218987249559, 42.69011205242526, 41.34882227067025, 42.98405447313863, 42.329536407224595, 43.643965798039595, 42.69746257412819, 44.20833995265346, 44.155203603929095, 46.5712659589706, 56.873069194055375, 57.022162406675285, 52.5447964668274, 41.98648983432401, 41.236689552184075, 53.17474872835221, 58.55798213712631, 48.89820814132691, 46.98541333598476, 52.12520876238423, 51.24963375829881, 41.88030735138924, 40.68325096561063, 44.63886322513704, 51.22048662554834, 55.52832380417855, 48.260293468352295, 45.55030045970794, 41.61038552561114, 44.107695856402, 40.99493426661338, 40.313583266350534, 40.876698340139086, 41.7097823081478, 37.868401235149754, 38.62841929158857, 38.90044743014921, 40.31450502334103, 43.16251054886849, 51.029737841698434, 49.489356394737, 52.87189076023718, 52.63814495455835, 51.922963511559274, 51.214842334870376, 52.0791522918209, 48.76911509421564, 52.53624962222192, 51.06714548603181, 46.25428353586505, 49.45596917983025, 49.82837469347062, 56.454787638879594, 52.31219599323889, 50.02402251766574, 46.3913978299787, 49.81115941078433, 55.03941605168005, 52.110778362520286, 58.29726219177247, 54.15774960671702, 54.3087883149424, 49.78586404554306, 46.406985329043486, 44.6876496653403, 46.74027696732552, 42.19565806850311, 46.33888121574156, 50.2072403507848, 62.111025856387236, 56.43140246791225, 64.14576322801652, 58.07765260819466, 47.00452312346428, 64.74380308581938, 59.093577861785896, 65.38648343855336, 65.95933775747976, 67.71511616245394, 45.76233202411283, 61.319781811006614, 51.86466532368814, 1.0388236829350073, 1.4722184981069257, 0.441919565801659, 0.5469232232820603, 5.13607015532832, 66.13142782641997, 54.38465087644516, 67.19536289092034, 54.46543993488435, 68.47807207415181, 30.68705528013168, 53.922725108362016, 40.02719533058905, 24.847862028306533, 41.63879525276923, 64.96627992199313, 3.793084438770048, 0.11948550014846748, 0.04093456374962003, 0.02087060801474558, 0.05850153441931452, 0.05066242482092592, 0.09868702505745235, 0.016619549733736826, 0.025839090399864702, 0.029879934154450897, 0.05860818151925361, 0.018113432677402612, 0.08187793751036929, 0.08918371201763231, 0.17513926741817307, 0.2080451033168262, 2.9022033656797106, 59.428430603396514, 60.73441905360068, 36.77142804668796, 36.56370716710245, 42.93062394665134, 28.942453668963527, 80.95666916139665, 72.20673207313784, 69.96751369968538, 68.77433653800719, 63.514402835599846, 71.65866713370048, 11.581364716252974, 0.5822691105065808, 2.4950709025706015, 0.40308853010496787, 3.4790006472218424, 0.6892300000594509, 10.928033167316068, 56.60530467187205, 36.651466277337846, 60.24336184224775, 65.38404764667635, 59.37265449954618, 62.75982510659003, 61.031573895485174, 61.97939503577448, 58.49236872888381, 59.50957267515121, 60.54112465150895, 62.697718297281575, 62.0529120199142, 56.51250139359505, 47.905852410101126, 56.79875596877068, 57.70510196685792, 57.96946187173167, 59.715497109197806, 58.770194130559126, 58.06799181046025, 58.296803274462306, 63.16118163447227, 57.53731866036692, 60.874894818952015, 59.34583725467805, 60.800860081949544, 54.89382551562402, 52.45102044074766, 52.42325790466801, 51.306182569073094, 55.93088842207386, 54.44527895219865, 54.78579559633809, 52.409188362859915, 54.57580366442281, 55.66830535088816, 56.41765456045828, 55.56775539152084, 56.76047755825905, 52.11176679980371, 49.65578256114837, 44.48778137083977, 45.593438686863074, 42.89753090950751, 45.30815685949018, 43.867156505584724, 44.28051548619425, 44.726700782775886, 46.901611897253225, 44.31798588845038, 50.1283222629178, 56.98108734623079, 59.2036081898597, 52.19929056782877, 43.80723445646225, 42.443795050344164, 55.85400996669647, 60.089404890614176, 47.43224582364483, 47.839442760713645, 53.351086724189024, 50.88812851136731, 40.98519502147552, 40.91105045810823, 47.05275650947325, 56.69928466120074, 57.84114153154435, 51.17058623221613, 48.41671366845408, 44.108531321248705, 45.85507646683724, 43.16935508481918, 42.10475321738951, 41.99091034550821, 44.26134686316214, 39.77570079988049, 42.44580330387239, 41.37231726800242, 43.06069366393551, 47.049532321191606, 53.67598841267248, 53.095677668048495, 56.06961088795816, 54.46338461291406, 56.55877359451787, 53.05876424235683, 56.371562788563395, 52.11221395000335, 55.0281157032136, 54.66698700381864, 48.63622911514775, 50.52745480691233, 52.29871872932681, 59.1704406276826, 54.22903868459887, 52.47230714367282, 49.2742810710784, 52.728508518588164, 55.6323842848501, 53.19879285750851, 61.34389262045584, 58.07367140246976, 56.871410031472486, 52.69039876999394, 48.1743896392084, 48.3378348042888, 47.71017712931479, 45.864639205317346, 49.39683160474224, 53.102777158060384, 64.09694540885188, 58.83962400497929, 65.23733923512121, 67.0919535236974, 49.36646853723834, 67.71430815419843, 59.860228646186094, 67.86105186708512, 66.77228819939398, 69.84825011222594, 50.068196250546364, 64.17264715317758, 57.435423328030495, 1.0731938192921302, 1.4825027075506028, 0.5410089019325472, 0.46833032441716044, 5.687715728436747, 74.13802869858281, 60.35245080148021, 73.93312408078101, 60.88925853852303, 74.43783114033361, 36.31878260643252, 58.9542317390442, 53.717491011465754, 32.91471442868633, 46.81946569873441, 76.76167072788363, 5.708623432344006, 0.12830288104352452, 0.17643991617425797, 0.0528522220350081, 0.07611222955728732, 0.06222649522486234, 0.1187169224384331, 0.1914657348947179, 0.07529266103501282, 0.13697288960458773, 0.22836842003368565, 0.07259209384961475, 0.12897332289045857, 0.21197826000711611, 0.3043580602013296, 0.36394186618347324, 3.3492736470314766, 76.62941625041347, 66.17607224372126, 55.27567609663933, 43.27552187827326, 54.63529033045615, 35.56252218061878, 83.62273554648124, 76.8618715963056, 74.95907491253269, 74.117797113234, 67.32243199502268, 76.07875470192202, 14.732237035228362, 0.958681938148314, 4.589636431586358, 2.3969282978965394, 6.417942893120551, 0.4962327481517869, 16.11309470668916, 65.86989202807027, 43.897378367762414, 61.989765782510084, 61.39801740646363, 60.19649344105875, 63.384121310326364, 63.015434203609345, 62.42661583808161, 61.24926151767854, 61.263393817409394, 63.19604366056381, 64.42755414593604, 65.62936836673369, 59.72138850919662, 49.78438138961793, 59.56022224118633, 60.09272713815013, 60.18013715744019, 61.858778230605594, 58.97950357006442, 59.71575598562918, 60.02753342351606, 65.11483576989943, 59.905245688653764, 61.12088234193864, 60.92701527380175, 64.10989707516086, 59.49848413467408, 55.54204033267114, 54.42529839854087, 54.424855170711396, 60.315380480981645, 58.68369017877887, 58.16083823480914, 55.736895838091456, 58.47618110718266, 59.020751214796505, 62.25373345036661, 59.410156280763694, 58.0509687239124, 56.13866421484179, 55.54516646169848, 48.297234350635165, 50.047580272920676, 46.75128313802904, 48.5822965252784, 45.92603214325444, 45.97833694950227, 47.51054025465443, 50.18665575212049, 50.13890874001288, 50.710594192627944, 60.20237699631722, 60.00319903896701, 53.015398517731704, 43.54495340777982, 43.086640142625384, 56.45561133661578, 62.396476345677534, 51.154673176427046, 50.846335657181285, 56.99735733770556, 53.242562586261386, 40.39800443956929, 41.572601333741225, 50.028576389435806, 61.87733496389082, 61.48903600631222, 54.579282806765654, 51.54256812987789, 47.5145253827495, 48.997079326260476, 46.14460622110675, 45.65887166607765, 45.857241615172356, 47.448684477037006, 43.43646064881356, 46.82761638395248, 47.53239570125457, 45.968099563352524, 50.739172581703436, 58.87232872747607, 55.48313809979347, 59.56455253785657, 57.85745466909101, 59.97255356081071, 58.683231261468705, 60.37576929215462, 56.968021931186804, 59.404111908328154, 59.13350759014007, 50.290135722006525, 54.09272847637054, 54.22691668233564, 61.81030165764594, 57.41437588968585, 55.56357022254698, 52.59113142567297, 54.5040988153027, 58.76236115732501, 56.64783885402065, 61.83430264073034, 60.334545181643584, 59.56471727740381, 54.618286855759166, 50.445453736089895, 49.54018638980005, 51.14290214353993, 47.75141692930653, 51.43421265386766, 56.832296156114154, 67.55202401068904, 63.50808781962242, 66.77073494080575, 61.68955149189119, 55.162978556848344, 70.10047420378655, 63.451060479687115, 70.91985733278337, 68.51718594951015, 74.94640565687611, 56.73011056838497, 67.18970683313185, 58.93301956115231, 1.5051586853881038, 4.685610946147673, 2.2007443347284874, 0.6857083858020845, 7.451208454947318, 79.4704831031061, 65.48750015997118, 79.14321622540875, 66.44081654087191, 83.3326998064595, 41.376353386909734, 70.66731945160898, 54.622981932855424, 41.984650242713194, 57.10351236404912, 87.78323281195857, 11.75297135306943, 0.8644076484826304, 0.4395760109107341, 0.2539252051182332, 0.14321601589120206, 0.2241492367559864, 0.2569406344405105], [0.044799385397064115, 0.07068749967842333, 0.041018887047445586, 0.016716262588517803, 0.04759255729074921, 0.068599435110246, 0.04066331499827005, 0.009544836920535853, 0.043223396980113564, 0.06806245344060083, 37.50074178941789, 55.54941046622492, 40.58060646057129, 36.392887946098085, 43.68167546487624, 34.43784136925974, 41.42909749861687, 67.8822797344577, 57.7878757446043, 68.20566346568447, 52.266441545178814, 71.60100829216742, 21.641314606512747, 0.07687580471317615, 1.18263358550687, 0.5046469369722951, 2.230773020175196, 0.2624936840466915, 2.94936643492791, 46.65245117679719, 55.71225158629879, 30.248293069101152, 45.212235296926195, 57.79277478494952, 62.50019950251426, 62.277079397632235, 61.17517971223401, 59.081493039284986, 58.97506344702936, 59.914333820343025, 58.98064497978457, 55.88800514897993, 49.135656664448405, 46.13678109261298, 55.95013157013924, 59.55213431389102, 60.745644877033854, 51.9499925644167, 39.74359227764992, 36.74810955601354, 43.291125066818736, 49.5387900260187, 51.44207308369299, 54.51319086936213, 58.04916051126296, 58.4214287419473, 56.75601390100295, 51.130538832756784, 50.69042536520189, 46.57158759332473, 53.67032058777348, 52.117430702332534, 53.33162784576417, 52.82998023494598, 52.21177547208725, 50.86948156356812, 52.42057108109998, 52.634838396503085, 53.17643534752631, 49.57810001988565, 44.68874008424821, 43.27395293020433, 42.59643016322967, 42.827810779694595, 41.81236405526438, 42.404308549819454, 42.076731804878484, 42.274372193121145, 41.1820666251644, 45.209901486673665, 52.283570535721324, 59.79945544273623, 59.95147866587485, 47.11102724075318, 41.97505220290154, 40.10670961872224, 46.000310067207586, 59.26836652140464, 55.80673363900954, 55.62992103638188, 58.049403698213645, 50.462963196539114, 41.98055921062347, 40.82367181777954, 46.65554592686315, 46.239029438264915, 55.267984328731416, 53.34544243351106, 48.59062371715423, 42.95370317274525, 39.9017422429977, 41.769319964993386, 39.74565152199038, 38.80580063789122, 39.807479843016594, 40.45694589614868, 40.121771520183934, 42.32909317939512, 40.92253908034294, 44.59070436416134, 49.20645936842888, 49.81323826697565, 51.517657156913515, 54.392499539159964, 52.39519726845526, 51.30690036281463, 51.324649087844364, 51.037990508540986, 53.0985527653848, 49.08525028536397, 41.417891287034564, 47.911006404507546, 50.89863261868877, 56.654087189705145, 54.9347319141511, 41.623713739456676, 35.38332477692635, 43.28852453539449, 48.26627508286507, 60.248649197240034, 55.318951606750495, 60.81908341377013, 50.804727154393355, 47.122539397208925, 41.62948354598015, 44.67333693658152, 43.54564766730032, 43.156399496140025, 40.18406660326066, 45.906855675481985, 48.07618133483395, 59.3540193188575, 57.56426926582091, 68.34134609468522, 59.56774926954701, 50.552099058705, 62.01235471233245, 57.69769653197258, 60.08431365413051, 45.82326996710993, 54.560706461629565, 68.86027566848263, 44.898355468626946, 0.7227030168137243, 2.292694497493006, 0.7189404219388963, 0.6783579866732321, 11.773548106993399, 67.43476083201747, 55.12759093315371, 64.85168787740892, 54.77266742337135, 63.137753317433024, 29.66352455077633, 51.125843755660526, 32.41553594989161, 34.632143820485766, 45.33630771021689, 53.39181269368818, 1.1797997956314397, 0.08769352544820117, 0.06208241323850328, 0.059830739102776975, 0.0451766224127383, 0.05780982980204206, 0.02331223939695666, 0.030560603275174097, 0.062424199535481395, 0.04081324606593098, 0.02973244882248823, 0.032589640768785635, 0.019035760403400468, 0.038803322466030236, 0.07776253616377231, 0.027064907687505888, 0.10192407595534479, 46.90794652508151, 64.75452292350032, 46.81810855865479, 42.57683792421895, 52.91285599431684, 34.31951915064166, 50.621081782925515, 76.46007968533424, 65.74309356750982, 74.94763728111022, 57.33302985468219, 78.50485047986432, 22.58135964793544, 0.046069547684202274, 2.1377787715004337, 0.1598132341619461, 8.25442994794538, 0.4299601365721995, 3.2172236231065567, 54.6264140067562, 55.51412874652494, 34.530381848735196, 51.7967337946738, 59.14850673367901, 64.46076485418504, 63.79095346696916, 63.64220934529459, 61.444721068105395, 60.27447408245456, 62.52842880064442, 60.78085991644091, 57.63752737352925, 51.68060418098204, 49.40445669235722, 57.716284644219186, 61.13250040238904, 63.216318391984515, 51.92717613712434, 41.45263564202094, 40.54956090065741, 46.740269122585175, 51.24801774178782, 52.63469719117688, 55.919101699706054, 59.22545186934933, 59.19523392954181, 59.14065414859403, 53.02407480055287, 50.57351519984584, 49.453282356262214, 57.47630619233655, 55.11568261731056, 55.34046188477547, 55.05756878083753, 53.79445968135711, 54.17976194812406, 53.58551894464801, 55.18681480038551, 57.67213836792977, 51.26371114484726, 46.82357242030483, 46.47945111797702, 46.06870835827243, 43.035292394699596, 42.494052379362046, 42.446536787094615, 43.068918874186856, 45.20600657309256, 44.37566434183429, 46.19238068980556, 52.500254031150575, 60.839668012434444, 60.816388745461744, 48.23286433373728, 41.28650757574266, 37.624135632668775, 48.226490482207275, 60.405038018380445, 55.80539218841061, 54.945796920407204, 59.593876177264804, 50.680556681848344, 42.98444671015586, 41.215277333413404, 46.06255415947207, 51.15138623022264, 58.304291079121256, 54.04952749129265, 51.47179288248862, 45.63904408485659, 43.63613282480548, 44.172767977560724, 41.9055321139674, 41.54624692855343, 43.83442040412657, 42.1453615157835, 43.95113837334418, 45.11454866778466, 44.101808378773356, 47.17303599080732, 53.242205650575706, 53.340284516734464, 54.81138121697211, 55.446161916179044, 55.57652188885597, 55.3511974119371, 54.5241185926622, 52.86259866529896, 54.225449715891195, 52.418284339289514, 45.02325942439418, 50.16233705705213, 54.61973813272292, 59.20023102914134, 58.45793424114105, 44.60775098493023, 38.131933519917155, 44.6135639375256, 49.062684889762636, 62.247606708157456, 58.11147912856072, 60.71608589541528, 52.179525744530466, 49.05970781080185, 46.96334215902513, 45.40922849409042, 46.80173266318537, 47.24285417987455, 44.0714963020817, 46.272989319216826, 52.16072974666473, 60.96337172292895, 61.27554139783306, 70.1416120221538, 67.75219040532266, 52.0439019510823, 63.17179556815856, 61.9755668024863, 61.970150009278335, 51.5293771989884, 58.72392585200649, 72.70118605706, 49.429748135228316, 0.9838114606757319, 2.324496094257601, 0.1987278194076592, 0.6518823557323026, 12.708819623916382, 77.61593941719302, 62.63993001753285, 73.54364056741038, 62.66559408557031, 69.10316451903313, 35.645209666221376, 60.78722984560075, 39.99549865722656, 31.128208175782238, 49.847943398260306, 65.5826097919095, 2.158709764480591, 0.07232982364873733, 0.02797689322652596, 0.02370936022470555, 0.04138441823963677, 0.02179960836656392, 0.07694630778484768, 0.14614951977085683, 0.19564986198900208, 0.1273152558133006, 0.12084227250588518, 0.13036888994036183, 0.18239412006110917, 0.10968990158289672, 0.2199059217086723, 0.14141930988238705, 0.23252832342780408, 58.71424152005104, 73.14614757414788, 59.816831542599594, 49.4595463814274, 62.690069675445564, 46.780485183961936, 54.40815764088785, 80.2722155663275, 67.2961050464261, 80.08562057249009, 63.010601843557055, 83.85155093285346, 25.803606356343916, 0.20234698730130352, 3.6638018921498334, 2.1035244676374623, 13.809945621798116, 0.6010118499398232, 6.805195068159412, 64.1056256140432, 58.98093131280715, 43.62417351815009, 57.78860530545635, 62.06949580100275, 63.73093728096255, 67.46559850631222, 63.951197977988954, 63.02388691133069, 62.05082531898253, 65.53582768286428, 63.08224393475441, 61.84811330610707, 54.469742774963386, 51.37769914442494, 60.8282107691611, 67.08959225685366, 65.55779687819943, 54.818606222829516, 43.79068205433507, 41.691857076460316, 45.43970923269949, 51.10673789055117, 56.134090731220866, 57.827852541400546, 63.04831543276387, 62.234007850770034, 60.95974353051955, 54.26630512360604, 54.7773781899483, 51.83270192915394, 59.54674105490408, 59.47245528621059, 58.848017877148045, 60.07431553256128, 57.449936097668065, 57.94722203285464, 59.18580847401773, 60.684903052545366, 61.57465742480371, 56.059236218852384, 49.42722212883734, 50.48995694806499, 50.72458136466242, 47.167838850329005, 44.680726681986165, 46.28129689924179, 44.29449481348838, 47.79486502370527, 43.79815809188351, 48.15334612323392, 56.09689097250662, 62.79503230125674, 62.167704105377204, 47.83154702955677, 41.84523743967856, 39.375058143369614, 47.44614278116534, 62.830925910703606, 59.54880814398489, 59.79818851717057, 60.80828120631557, 51.60801679857316, 40.88923815757998, 40.057197540037095, 46.67488713418284, 54.070539628305745, 63.58659798099149, 56.0059194411001, 55.64036630815076, 51.05097355381135, 48.11297708942045, 46.69683279529695, 43.934652651509936, 43.754639394821666, 46.20182967955067, 45.9603528822622, 46.947911554767245, 48.64414445815548, 47.47679610406199, 47.81319818189068, 54.31836282053302, 55.00488350468298, 58.302616227057676, 59.22967233965474, 59.60251323638424, 58.265714568476525, 57.800348881752264, 57.415736952135646, 60.20460098020492, 54.8939274972485, 45.84674143022107, 55.38237241006667, 56.67065920368318, 61.215591892119384, 62.34800761745822, 42.19367334919591, 36.748862651086625, 42.07003631899434, 51.782350463251916, 64.16894443573491, 60.11260571018342, 67.19178568932318, 55.849232519826586, 51.70268712505218, 49.36316590155325, 47.77437848429526, 49.04989796300089, 49.18642390158869, 47.08043667577928, 47.09527892451133, 55.39019753856044, 65.33079362684681, 65.19150633965769, 68.08944363747874, 66.59989218558034, 58.80374608501312, 64.49628976083571, 63.60986940322384, 64.45206503714284, 55.845843591997706, 60.8502152658278, 72.56031805469145, 53.32710143058531, 1.1556194866857221, 6.914139880288032, 2.7588532384364837, 0.5466495766755074, 15.630878517704627, 86.0276113017913, 67.47149775105139, 77.21827383964293, 66.7840160862092, 76.8544190929782, 41.942143517155806, 66.80969192135719, 47.69639784289945, 53.00518074343282, 59.56098318099976, 82.79705309098767, 4.808754248003806, 0.343202579045488, 0.20656938814828474, 0.16316365841175282, 0.1380431757218415, 0.10634339970326233, 0.2819646973042719], [0.025862408201059988, 0.12146489514458565, 0.01874741065436073, 0.03864363143821398, 0.05774504174628566, 0.0853232340887189, 0.015689593687232946, 0.056178303841020794, 0.13278811899644713, 0.10079443334571778, 27.21688928142671, 63.80553683926983, 43.75252915966896, 27.359143841651182, 27.32271678986088, 55.72240660267492, 25.41259115742099, 63.838637721154, 51.46369711045296, 63.18836758213659, 55.43139027011011, 66.11100796730288, 39.791947257134225, 0.06380295861632594, 1.2327449288099044, 0.27020319455092956, 1.3823404499600012, 0.30232293230872004, 0.9326100048999634, 30.707543780726773, 56.957913983252745, 53.41862601618613, 52.313502142506266, 46.91437528979394, 54.01064503577448, 57.055753584830995, 60.32810464982064, 55.72719189428515, 58.596515501699145, 58.28951158831197, 53.69779679083056, 47.40296925267866, 43.91879843127343, 46.28400333466069, 53.90790247148084, 58.4200402229063, 50.56238743566698, 38.260759845856704, 45.66024449563796, 55.23973149638022, 55.80916550851638, 52.4480394394167, 54.69522414668914, 50.16110543281802, 52.037630081176765, 56.6057792786629, 59.818027865502145, 52.29198401974094, 50.556684309436434, 45.393994008341146, 51.7587064158532, 51.458358764648445, 52.498849822628884, 51.48291280192714, 52.416746770181966, 51.65690522040091, 53.23584748852638, 56.61941343738187, 52.721522777311264, 50.65544959037535, 45.241064717692716, 41.314540755364206, 41.84549631610994, 42.41761715181413, 40.68835789157499, 43.15825085486136, 44.28943887833626, 42.888909539868756, 42.7254722195287, 44.38851010414862, 55.88397295244279, 61.05748115047332, 61.124702730486476, 44.382956027984626, 38.07531410647977, 39.802416063124134, 43.199388673228604, 58.09876672683224, 58.02231580980363, 56.91581518419328, 53.92071293246362, 48.66603520608718, 43.20591549719534, 43.64753123252623, 45.41145247797812, 49.225957470555464, 49.55707219339187, 55.68716410667666, 48.30915443358883, 42.91340866396504, 40.447277253673924, 43.3891607869056, 41.33856527266964, 42.12909936904907, 40.68184283471877, 40.72126265495054, 40.63028720117385, 41.75036314995059, 42.391309815068404, 47.63936658059397, 50.528015705846975, 51.08958144341746, 52.41957872144638, 52.361535487636445, 51.74046739455193, 53.23879318852579, 52.14940586397725, 50.914369167820105, 51.967513791976444, 47.774335338223366, 45.5864921692879, 47.79195462503741, 50.60065800143827, 58.23370018313008, 56.429413826234885, 57.78443974833335, 49.43168578609344, 51.16645205405451, 54.60090291115546, 55.47199856850409, 54.256895357562655, 54.87561787328413, 47.62770929644185, 46.21644835318289, 45.10424067897182, 43.955817760959754, 41.517495955190356, 43.787842258330315, 43.839613622234715, 43.97915194111486, 45.7174365751205, 51.88250034086166, 59.97955499156829, 59.10665504394039, 70.57156655096239, 59.98207315321892, 52.856440544128425, 64.44425559812977, 51.06819275886782, 62.92151697220341, 59.30629584097094, 73.18026434990668, 36.81750805147233, 0.378113420259568, 0.6485571664187216, 0.41772123846796255, 0.5351664702738486, 13.730935358232069, 66.54048396695045, 55.952924297701934, 58.26823273012715, 57.179818153381355, 52.51287229599492, 39.99515741102157, 37.14858747297718, 32.3301028051684, 37.033309013612815, 43.264566698381984, 48.63002392553514, 0.25423401516051064, 0.05572957550025275, 0.09698961170450335, 0.05907907661411071, 0.04192801124806847, 0.04643592157311017, 0.03284178711774369, 0.10239858315476488, 0.08325406124875431, 0.02707638368461161, 0.07241089873376393, 0.01888428183813249, 0.03741518263855288, 0.04950792648859563, 0.03483775642610366, 0.09881143773635549, 0.20787023608722996, 34.2939962879304, 76.48281374285298, 49.38443691499772, 37.025985948501095, 44.13534856611683, 59.43280404613864, 31.664115728870517, 69.48349322042158, 57.786102833286414, 73.31075376079929, 60.63228837905392, 72.39917139853202, 44.189469429754446, 0.14223349280655384, 1.7311177282564103, 0.3205876328772114, 6.207584219594156, 0.6034537092331917, 0.7041557830187583, 39.67061658059397, 59.69350437964163, 58.06683078888924, 53.87905343886345, 51.46125347383561, 58.44854016457835, 59.373376215657885, 62.18925360710391, 60.98255603544174, 61.744825532359464, 60.898946792848655, 57.19759041263212, 51.74655491305936, 46.52204805804838, 47.22971031742711, 56.92688803518973, 57.266247580128336, 53.455661035353145, 42.77695332804034, 50.591714997445386, 59.46162954453499, 55.36004627904585, 52.84133549659483, 55.068006207866055, 51.65127269683346, 55.06793952757313, 58.536593452576675, 60.59389229743712, 53.689406841031975, 53.854252292263894, 47.78217223382766, 53.7308741384937, 54.882893869953776, 54.101632256661695, 55.64459854556669, 55.59623572134203, 54.43326473236085, 56.67422071579964, 57.39084166865195, 57.181245896124075, 53.674952906946984, 49.863491673623365, 43.484529295275294, 44.97736377100791, 44.72720284615794, 43.43054963696388, 44.658243656158454, 44.48708711131927, 44.0667345446925, 43.8278700459388, 45.9857149277964, 57.4794872345463, 66.41878066524383, 61.61807806261125, 44.960360296310924, 38.29266440483832, 40.39217579749323, 44.36949445355324, 60.51280121649466, 59.175394581210234, 58.936569306158255, 54.09368945706276, 46.91829373759609, 42.45209086325861, 43.994810042842744, 44.52101169093963, 50.36895967298939, 56.07542776292371, 58.415113725969874, 52.01540593178042, 44.95560638366207, 42.45311067950341, 46.6164202843943, 44.28204521056145, 42.57721054938532, 41.88335503301313, 42.920249277545565, 43.497884965712025, 45.07781567112092, 45.754938356338016, 48.97674183691702, 52.34477912226031, 54.46917010891823, 54.9635221112159, 55.710192341958326, 52.266433700438476, 54.55388153752973, 54.53387744965092, 53.137898060583304, 54.91480235130557, 49.887810368691724, 46.820693400598344, 49.42173473296627, 51.38425734735305, 58.49561252901631, 57.560499868085316, 59.158853946193574, 51.44811353375835, 50.079975128173835, 55.58513541375437, 57.850410092261534, 55.995105466535016, 56.22284612348003, 49.45890311271914, 46.99202645209528, 45.78048083090013, 46.12530031511861, 44.62666073153096, 45.851726762710086, 47.258194569618475, 45.53553665837934, 47.01194032546013, 53.57390480656778, 61.476649161308046, 61.937845368539136, 71.09374384726249, 69.43808786330685, 54.8590733158973, 68.0662702745007, 53.59870595316733, 67.18529024431783, 64.11472943521315, 78.06235221124466, 40.0782802797133, 0.41719046211050403, 1.5532729294030898, 0.6865522469724379, 0.5181116983294487, 15.3780758765436, 74.37849352436682, 62.924776461816606, 69.44945489206623, 65.30593756706484, 58.16703165731123, 42.99860254410775, 46.113933286359234, 37.514548532424435, 42.09095039675313, 51.50700007715533, 60.4309727299598, 0.9475698021631088, 0.05628903035915667, 0.023612208784587925, 0.004412020535974373, 0.016738396783870076, 0.05738657388475634, 0.11154879860940481, 0.19324963191343894, 0.18197142338800817, 0.15254321297810924, 0.2872230635294991, 0.11835603373906306, 0.19956331489787948, 0.23715762421488765, 0.16714541571995906, 0.2518530445353639, 0.3813951264225668, 41.03035719163957, 87.84143294057539, 61.34068804402506, 38.12348865693615, 42.109605189292665, 68.17309210377356, 36.303446139058764, 77.96302995374127, 63.54846862054641, 78.6374265916886, 65.34452976719027, 76.52504198012814, 48.77582626958048, 0.39579034752903447, 2.893361117570631, 0.8013228206865249, 11.870787585935286, 0.42391680601623755, 2.8505315319184334, 48.683285790105025, 62.844391407505164, 59.48687391896402, 58.16165408780498, 59.01478921213458, 61.49580993959981, 61.20340901036417, 64.04737449461415, 63.04388315446916, 65.27255035215809, 64.16686950191375, 59.7295391944147, 53.370141598486136, 49.57435023400092, 48.877168547722604, 58.97321993304838, 60.23198696874804, 55.652282468734256, 48.234013588197776, 49.68456099110265, 55.59897353572231, 55.625100443440104, 52.96237199537216, 56.71178525493991, 54.56247937294745, 57.52965827142039, 61.05721835167178, 62.81976284519319, 57.11912339733493, 57.73430401279081, 51.30158947360132, 56.615455765878, 59.357486694089836, 59.69298270440871, 60.333988205079116, 60.147079421627915, 59.2825262777267, 59.21727764991022, 63.32536812751525, 60.041308787561235, 55.38001898796328, 51.80352341744208, 47.50570397223196, 47.18892551237538, 45.54971602655227, 44.50500057589623, 46.98489950549218, 48.19970461630052, 46.41064882278443, 47.25903003446518, 48.423424843818914, 60.7380864697118, 68.62900487838253, 64.63386297225952, 45.81870040585918, 36.883109692604314, 40.218414798859634, 45.44441999927644, 60.521383362431685, 62.992096101084066, 61.51833218912925, 55.652376605618386, 48.944197931597316, 43.9326169413905, 46.00005511314639, 45.15061486151911, 49.79021787643433, 60.768767249199655, 63.43446885385821, 55.578126138256444, 48.95002657367338, 44.42261903516708, 48.528269798524924, 46.902667014829575, 45.13365845526419, 45.303818718079604, 45.815111437151515, 46.36689870588241, 46.94572679458126, 49.67771253278179, 52.16396570205689, 55.202319929676676, 59.19225685058102, 60.2175251899227, 58.82203609712663, 55.950923888914055, 57.84171811995968, 57.924715472805886, 58.0845324454769, 57.60073554131293, 52.2246055449209, 47.87503827002741, 52.68191076094105, 54.24063321082823, 61.5973561809909, 57.719708873379616, 59.670072140232215, 51.8978681871968, 50.86135833494125, 57.65508390242054, 60.2304337101598, 56.916195654099994, 59.76744497975996, 51.319801038311375, 51.192025907578014, 48.80099219660605, 49.901052290393466, 47.395861917926425, 48.39606238949684, 48.98698706780711, 51.319797115941206, 50.59580995190529, 56.19300080883888, 65.93259503764492, 64.03791766012868, 68.2929362020185, 67.5965586016255, 61.08113696498256, 68.64186240780738, 57.83215930384975, 68.14561197834631, 67.69984245300293, 79.62040393583237, 45.32814133551813, 1.1783812459438079, 3.1914462966303674, 1.7060986449641569, 0.568962101974795, 17.033320011631137, 84.07289028167725, 65.5026012851346, 75.36078053136026, 68.42772453061997, 63.42760862842683, 48.13119257650068, 55.30972226973503, 48.01586312632407, 59.11439780266055, 58.924982624669234, 75.76734204446116, 1.9653790804647633, 0.1983638203913166, 0.28072286877901326, 0.06516941432510653, 0.14587729808784303, 0.11158316531368803, 0.24080116902628254], [0.060435822158451044, 0.012278897469983467, 0.03904911794609601, 0.10267826653416119, 0.026489179205870437, 0.05214011266587242, 0.017764579219323014, 0.08139441345608042, 0.13202354792625676, 0.4108332806537229, 12.468584256787455, 63.054889325172674, 39.098413375116166, 31.941533204047914, 21.049558385725945, 53.59668201015842, 42.52006946071502, 39.26765580331126, 68.24029799430602, 46.988472784719164, 64.803023030681, 58.7366892445472, 63.500199933205884, 5.364630097343076, 1.08798066454549, 0.5151569278490159, 4.281004734577672, 1.0740176396023844, 0.4803372510979253, 23.653570913499404, 50.23919197820848, 52.956943435053674, 64.17202741869035, 63.40931861631332, 62.54086271409066, 56.846667720425515, 56.310769973262666, 55.2616536232733, 53.83798230078913, 50.455455780029304, 47.39706216319915, 46.16938775585544, 44.938485237859915, 48.266784990987475, 56.53902838307043, 57.25971291142126, 52.77066615320022, 66.22853786714616, 70.39461274300852, 62.16852780311339, 59.04858827590943, 58.514020212234996, 59.31576836493708, 58.8923994956478, 56.14378683028683, 58.67386464149722, 57.84836653740176, 51.29989500968687, 49.940883959493334, 45.55709792721657, 49.00058200282436, 54.926808726403024, 51.67669357792024, 51.82364909879623, 50.48820364859797, 51.80610433701546, 52.45424855139948, 54.99006871254214, 54.83455850232033, 51.986356858284246, 47.800238670841345, 40.70097223404915, 40.37661575501965, 42.20624454559819, 40.94406504784861, 41.00912932426699, 42.61411613033664, 41.13377832597302, 42.60196854991298, 46.294687871010076, 54.09218718928676, 58.6059017335215, 57.5935850604888, 45.63650238898493, 40.67613186374788, 42.559552038869555, 45.207387247393214, 54.324924945831306, 56.08838727397304, 56.15294164226901, 48.5025861186366, 45.23651476829283, 42.052377808478575, 42.81068963389243, 42.50866320825393, 46.86461610178794, 54.89590437181535, 53.1794830291502, 53.15984764406758, 48.11967649767476, 42.541740555917066, 40.899503000320934, 40.961703946513516, 40.06264571220645, 41.6411369077621, 38.69488385415847, 40.89084632935063, 39.64528591402116, 42.37267071200956, 48.72343124881868, 50.096292188090665, 48.20378388127973, 50.92655204957532, 50.74300473736179, 49.599457325473914, 51.064482196684814, 50.348633950756444, 51.18288678507651, 54.37518227484919, 45.50599728861163, 46.83409613947715, 48.12012757024458, 49.09646434168662, 53.900281306236025, 53.350102209275775, 54.7582370235074, 54.18696341976043, 51.099799217716345, 55.347439781312026, 58.06055891898371, 52.69356020035283, 50.90709317115046, 45.27456960370464, 43.39701729436075, 43.15357538961595, 43.60801335304014, 47.19145151876634, 57.48391559047084, 53.907443554170676, 51.83238813954016, 43.265759098914366, 45.72947825154951, 47.956827532860544, 57.087434568712794, 58.405398015053045, 75.0299442968061, 59.80968106177546, 60.580320896640906, 58.88920668632754, 66.22880458831787, 60.5803640427128, 71.070970566042, 23.89955451411586, 0.19359659313434557, 0.6704309991290492, 0.2747749927784166, 1.5587322558126144, 36.62757512061827, 61.665146504679036, 58.2619647825918, 57.91124213126398, 46.71986887531896, 46.362329144631666, 40.76042359875095, 54.57777269424931, 30.43399964609454, 31.772626138502556, 49.45383933282668, 39.47029721352362, 0.37721893599917816, 0.01782288042558057, 0.04546608107404844, 0.023165294156980612, 0.020436638357838797, 0.027222626038917133, 0.03497985807517844, 0.0462316480585404, 0.014387013431968949, 0.028130085913524516, 0.0638600245058056, 0.04078539876988338, 0.04584394628182054, 0.05993036117645041, 0.03102442354805047, 0.09768675171559858, 0.37805835385957076, 15.025806830775354, 75.2240780861147, 42.18626006957024, 35.36692142486572, 33.61227658487136, 57.97141913444766, 44.97595564011605, 47.899043175481985, 69.5914682265251, 52.54640463859805, 74.73534291790378, 63.60262870788575, 70.95252283157842, 5.747477450678426, 1.7292474931286228, 0.4455922832412105, 6.625959911654073, 2.3531058622944743, 0.3513613541520411, 32.71494811581027, 52.24990091016216, 55.047519668456054, 66.71419789714199, 63.82519968094365, 62.502423486401966, 59.72033339162027, 59.97394207985171, 57.1250226420741, 56.3343983311807, 52.7471633111277, 49.13859451970747, 47.07922466339604, 47.54764195411436, 51.00459544889389, 60.02692545613935, 59.748123384291134, 57.08432805153632, 67.26392592153242, 70.39874692117014, 62.664468365330855, 60.69384997890842, 58.88500582787299, 60.30668458630962, 61.05873238655829, 57.81991758654195, 60.58423934444305, 60.25463081175282, 53.88554496149863, 52.063050962263546, 48.770609517251295, 51.65052744650072, 57.53810313440139, 56.88793105463828, 54.89627307461154, 53.68189157978181, 52.3524316664665, 54.76957659567557, 56.65655828291371, 56.389943015190866, 54.0331986642653, 51.16293368800994, 42.22767637621972, 43.545628055449455, 44.28020561895063, 43.61420285317206, 42.47944547284035, 42.49713143994732, 43.853502735014885, 44.5618631762843, 48.356517053419545, 57.17414248374201, 60.93566017766153, 59.70416538176998, 44.81384015852406, 40.06419897079468, 42.75568231459587, 43.06366682052613, 59.34049106413319, 56.66144555614841, 55.04833159908172, 47.271154080667806, 45.17857351610738, 40.939636691924065, 41.732292790566724, 42.87686786343975, 46.10513541006273, 54.275581529063565, 57.110149014380674, 55.36185449169528, 50.16907176663799, 44.94660846648678, 43.309050298506214, 41.70810745608422, 43.31067415975755, 43.06907576899375, 42.846744060516365, 44.393460135306086, 44.72891692192324, 46.410233051546165, 51.326504368935865, 53.16899068893925, 50.46402615885581, 53.27551441807901, 54.303391133585286, 54.371032407206876, 54.16319777888637, 52.97176999430503, 53.77966842343731, 56.738284787824085, 47.90670748679869, 50.08676082857194, 50.898699298981704, 50.525489699456, 55.808243751525886, 55.939623540447606, 56.804039401392785, 55.03337560161468, 53.52215697688442, 56.403279073776744, 58.394234949542636, 55.44642079261042, 53.461156275964555, 47.43452079834477, 44.83054161071778, 45.37285635548253, 45.08200868483513, 48.010309050160075, 59.2244359754747, 57.49373328301215, 55.66099797525714, 43.95849281741727, 47.945397746178415, 49.30576985882175, 60.7866414900749, 58.70274113070581, 75.08804244379844, 65.68989838323286, 63.35211869209044, 62.334644102281146, 69.15970940743723, 64.43426924367105, 74.03873782004081, 27.130555952748946, 0.4138706660559101, 1.282540889036271, 0.6534482394495319, 2.7277993434859864, 43.920104580540816, 67.82114567295199, 65.48803752468478, 67.80704082981234, 55.99658027771981, 52.54513771303239, 45.49106090299545, 60.22264780536775, 41.37348613431377, 37.66656783319289, 57.03604759708528, 48.678575023528076, 0.3524197199411931, 0.046391358238554774, 0.039145334758946014, 0.01987163127670365, 0.060408633698018334, 0.03145512392474038, 0.023149618082830024, 0.2386944578780282, 0.10731015669842882, 0.12616359583672979, 0.20631136973538708, 0.37201514587767665, 0.12821433660123618, 0.2485421197789331, 0.206465843704439, 0.4666490985020515, 0.6704325925919318, 20.451900959014893, 86.48320244204614, 53.92208183965376, 43.465470498608006, 31.491545169584214, 71.83713497654085, 53.96676155828661, 50.74299689262144, 78.7722384545111, 60.70756650740101, 77.83417224884033, 68.12438411097374, 74.32580040347192, 7.985965282686296, 1.6505326330661776, 2.461366956272433, 15.332988231412827, 3.799961089126526, 0.38392873240574715, 41.795011489622055, 56.447441039546845, 61.163997034872736, 68.98011976672758, 66.7108952614569, 65.21988861022457, 59.072330382562455, 62.97584964383034, 60.92637200509349, 59.58375253985005, 53.62941811161657, 51.092079993217226, 51.26884160503265, 49.59470733519524, 52.0487186216539, 61.675501561933956, 61.07647718921785, 59.67914066007061, 66.80089796743086, 69.62831497192383, 65.46804520391649, 64.67824459075928, 63.1864809220837, 63.304677624856275, 62.65008895627914, 56.66965899928924, 62.36370102051766, 63.273443791174124, 54.13729052389822, 55.41680297543926, 51.462908714048325, 53.27857386681342, 61.923905264946725, 61.92908279357418, 58.17863402828094, 59.61714759949715, 57.651251746762185, 58.98023705328665, 59.54232054371988, 62.709873722445586, 59.25449309810516, 54.731906152540645, 44.918842008036954, 45.21862876030707, 45.92212938493299, 45.58059684691891, 44.18810444493448, 44.86670194133636, 46.41076257151943, 46.191090230018865, 49.97471047985939, 59.770531885085575, 64.01436382724394, 61.36207280620452, 44.89652372175648, 41.31292866122338, 43.262264267090835, 44.27302375916512, 59.725812942751, 58.64913801993094, 57.33658744442848, 48.13372250526182, 45.512194633483894, 40.77348509142476, 42.95365218193301, 44.187618071033114, 47.164473456721154, 57.78113319027809, 61.9604774444334, 58.922664503897394, 52.8357578862098, 47.93469359797817, 44.73462789289413, 45.39445292565131, 45.32206950649139, 46.330757987114694, 44.28001734518236, 46.168681729224424, 44.661754177462676, 49.300105956292924, 55.479906066771484, 57.90164016908216, 54.65467076147757, 55.78689429067797, 57.94171894750288, 56.563398068951024, 56.183920521889966, 58.555652249243956, 57.6431598970967, 59.94970967692714, 52.627687915678955, 53.32158657812303, 52.71268959968321, 54.920403495911636, 56.86781714039465, 59.16642412062615, 60.3988249840275, 58.18561584718766, 53.698000754079516, 60.58809895669261, 61.92086542806318, 57.46563734546785, 54.83453104572912, 48.96195842373756, 48.91348577314808, 48.74970720660303, 47.373469106612674, 51.580266029604026, 62.07459880459694, 60.92304583518737, 56.62065290635633, 47.52673572109592, 49.836784255120065, 53.658941791903594, 61.95718265348866, 62.43203655365975, 74.54749276561122, 67.70576523196313, 67.08818804833197, 64.36611806192707, 72.14811617328276, 64.85642217820691, 74.48537811156243, 31.159377290356545, 0.41098282101654243, 1.8496614382151637, 1.3088091246543394, 3.085976704474419, 46.2312670676939, 74.47237937681138, 67.42201312895745, 73.71348704061201, 58.51363974232828, 60.584243266813225, 48.757775522047474, 72.07170840232604, 47.910523952976355, 49.18292514739498, 64.60191134483584, 62.520721343255815, 0.8090954874792408, 0.215748515761187, 0.200927717491023, 0.1481876047628541, 0.11287689629581668, 0.15645807548876733, 0.11485435308948641], [0.03932921118253181, 0.027718053184329506, 0.04825007906484027, 0.03487210780862839, 0.032551593012026245, 0.06554796135113125, 0.02131844769352146, 0.0039440224504834346, 0.036591890928966385, 0.06359494276224606, 2.264014126793031, 46.34294086886991, 42.20877839672951, 46.2139537257533, 32.78192650887274, 53.08925282570624, 57.47939702003234, 26.615372242466098, 73.90369061500796, 54.952923867010306, 45.78988275220318, 58.85927900191277, 58.759533128430775, 48.499605117305634, 1.2796029112031384, 0.723088879979426, 2.065326220566227, 3.0187369834992195, 0.5693871275551858, 13.082853901770807, 55.97341083711194, 57.57625602906751, 61.38634835520099, 55.06391125340616, 59.17188405990601, 56.59816595815844, 55.65077627858808, 48.07061549155943, 48.37188489975468, 44.07728179808586, 44.90104229219499, 43.42170861459548, 45.40325080194781, 50.8420681184338, 53.517206945726954, 60.75258354986868, 65.54475891974666, 60.963018709613436, 56.76250542363813, 55.41127635586647, 56.72794149767969, 58.21774790363928, 54.344525029582364, 56.65629156174199, 58.07746041205622, 57.5353378634299, 56.414140116783884, 50.82195420419016, 49.4258532216472, 45.82886718934583, 46.314480150899584, 54.312322370467655, 49.893886120088645, 53.52484380045245, 48.624344333525634, 53.54135305650773, 54.4798428781571, 52.00986754509711, 54.85268769725677, 53.93616314857237, 47.699210182313, 41.885649619563935, 43.31395718359178, 44.50858562223373, 41.56641183360931, 39.90141668627339, 41.842966387348795, 41.947101393053615, 43.24387619572301, 47.21686063274261, 56.00904164775726, 54.88547478952716, 58.71727743456441, 52.037006424319365, 41.70236118378178, 42.46052003675892, 41.18895430718699, 47.67393835129277, 55.08764943768902, 54.53176721449822, 44.7225744493546, 42.67447356254824, 44.433327105737504, 41.59088742348456, 41.39450611606721, 41.84935985072967, 53.37995929102744, 56.85471642401911, 51.48238328195388, 50.54985154059626, 40.946998980737504, 40.395450976587114, 38.434603214263916, 39.05149790548509, 39.708063448629076, 38.53725164167343, 41.718529193632065, 40.7549048239185, 44.215215867565526, 52.67239901327318, 53.08163166046143, 49.5175229349444, 48.615271891317065, 52.3249593857796, 50.056487975582, 51.437946750271706, 50.27749000057098, 49.966022429927705, 50.42114680813205, 44.914880414162916, 44.92876560457292, 48.23998343560004, 48.87585455371488, 51.86948591662992, 57.170369163636245, 57.46297013375067, 54.32475236154372, 59.38190737078267, 54.4420704533977, 56.78829108515094, 53.76381420320081, 51.607349995643865, 44.32656018964706, 42.80035418848838, 41.29911407347649, 43.0318485536883, 54.48132161171206, 59.21612055070939, 56.636044286912494, 58.75722285239928, 53.79711904833394, 48.24904803306826, 43.03264479483328, 49.31079833738266, 55.38987198183614, 59.16718898280975, 61.6638913462239, 61.36241405240951, 56.170588385674264, 62.24715563558764, 62.84322254119381, 71.32822313616353, 13.2956003181396, 2.5622885602135814, 0.6645913866739119, 1.4816502049084634, 7.020548389803979, 50.941378608826675, 56.3174811486275, 59.59732394064627, 44.70631622499035, 47.371205899023245, 46.53975755937638, 45.90530241689375, 42.305821757162775, 29.697692317347375, 49.0708787210526, 49.64123449017925, 31.40262503777781, 0.08576214118229766, 0.10743780226837243, 0.12885666302134915, 0.07140582202062493, 0.03169630180984255, 0.023234356983354496, 0.07264930529580002, 0.06033160738767155, 0.049251198933850375, 0.026958231859269644, 0.062185118816071944, 0.02398659403796398, 0.08397375488834036, 0.03729936163572054, 0.07967502870146306, 0.02392289574227987, 0.09859180032846429, 3.5649652731034065, 60.13177825558571, 46.49316372409944, 46.59538461316017, 42.71919250488282, 60.617065660415165, 60.90477151255454, 31.13491346759181, 80.18354646621212, 59.4318469878166, 53.31532647532802, 64.5221930934537, 65.21622511648363, 56.25511938525785, 3.676927858783353, 0.1775752891215586, 5.433384833797332, 9.585549023843582, 0.37986065231023297, 16.17545254768864, 60.26878272333453, 59.016832766994355, 62.70307625493696, 58.746267672508, 60.74417791058941, 57.26174862154069, 57.88347175044399, 49.92856771715226, 50.24946466568978, 47.23769626309795, 48.179512254653446, 44.908479106041696, 45.76434420001122, 52.004152651756044, 55.00705649775844, 62.54841327667237, 64.65889553869924, 60.677058312200735, 58.692950894755704, 59.06860805326893, 57.70147377444852, 58.44758702862648, 55.99549770355225, 58.544112636197, 60.851399821619836, 58.3734542323697, 56.82433766703452, 53.10064731105682, 51.80962270306003, 47.9775337250002, 47.79559066218715, 58.43666322769658, 56.07342735413582, 55.967844993837424, 51.12869139640562, 53.9804074841161, 57.284404231655984, 54.709662391293435, 59.582909230263006, 55.16929749519595, 50.67581845868019, 46.31100885329708, 44.176478539743734, 42.631700115819136, 45.06648002132293, 44.48403942969538, 43.90084574299474, 42.70699393364691, 46.01971011007986, 49.07416174488683, 58.38415053582961, 59.05157319961056, 58.925441541979396, 53.6241150671436, 41.05465627485707, 42.90259861177014, 41.47103548049927, 50.874031512968, 56.404083159662065, 55.583005566750806, 44.175835271035474, 41.33517634484076, 43.44449366292646, 41.43783653936079, 40.78352243669572, 42.42353600840415, 54.9295033947114, 61.010981452080514, 54.790726015644694, 54.274259690315496, 44.770223402207904, 41.876894889339326, 41.865700444867535, 40.0203743288594, 43.732576062602384, 42.97743351228776, 42.85558508288476, 44.58415792834374, 46.27848848219841, 55.5612442570348, 56.20017482388405, 53.85071823673864, 52.184283579549486, 55.96266354283979, 54.063440138293856, 53.948330340846894, 52.886999730140936, 52.93919471002395, 55.46767219420403, 47.0644804739183, 47.537028020428075, 50.2094368780813, 49.00920729483328, 53.728046109599454, 57.673173873655266, 59.552887408964104, 57.688459350216775, 59.518480377812544, 57.648094238773474, 58.69499052724531, 56.18974524159586, 53.292945431124785, 47.111576372577304, 46.11094444028793, 42.19283396197904, 44.50229806284751, 57.751817395610196, 61.961822817402506, 58.246887191649414, 61.90215964471141, 57.8633225348688, 51.769708664186545, 45.918320763495664, 52.16497375119118, 58.921609386321045, 59.97742122219455, 63.21484750316989, 65.51994600603658, 57.615377749166186, 66.39714487137334, 63.888259626203975, 74.78927550777313, 15.386116735396849, 3.763864987319516, 1.2654302846039496, 1.5151999530292328, 15.830254554748537, 58.460860329289595, 61.71834168895599, 65.04020875500095, 50.1509778730331, 47.36633431526923, 54.75500499048541, 47.37246890221873, 50.899609288861676, 40.23611253307712, 49.464104175567634, 60.7739330107166, 36.418665762870546, 0.1647409261955369, 0.04807274120168821, 0.05447465453236815, 0.0295191795204676, 0.04519803840066156, 0.05898340755412656, 0.1018636392789983, 0.25088757456791017, 0.1514684222638607, 0.13479520807102804, 0.16440727958275428, 0.2524904603318822, 0.2203295683307994, 0.16350625293149104, 0.13134758258538862, 0.14209645499865856, 0.2833771182885093, 5.519713259512379, 77.9162125433645, 58.378066939692346, 61.91030640755931, 46.83300179819907, 68.59661394549956, 63.398332057460664, 39.427221744291245, 85.50730889843356, 66.9518699953633, 55.559545870750185, 70.88577978072628, 68.54680768905148, 62.86564673146894, 5.041171841083035, 1.5203479413063297, 13.562306780968944, 8.580459317853375, 0.4141707273740923, 23.808555526118127, 64.06237363815308, 61.215964517285755, 68.42142520412322, 60.87112934358659, 64.3999759612545, 60.65785438783708, 61.2402557557629, 51.84696758947065, 51.67807817459107, 48.48362538122362, 51.4161854405557, 47.30267816974271, 48.29723042826499, 55.52509569352674, 57.752354760323804, 64.36199957324614, 64.54685303472704, 62.46033253208284, 61.059328586824485, 59.56852589884112, 61.4018181831606, 61.147346573491255, 58.54162977587793, 58.33967478044572, 63.11542326404203, 58.78702109859836, 58.516216739531494, 54.51285746789748, 54.06662510287378, 50.82921058900895, 51.30985782992456, 61.41956298582016, 58.50994879199613, 60.3363141705913, 55.319916509812884, 59.46588923854213, 62.02403945307579, 57.30523593964116, 61.23190110729587, 58.45662809187367, 53.65645108684417, 47.994192031122026, 47.15490679587088, 46.40564387844455, 47.71569198177707, 45.26930970530356, 48.10029214428317, 47.55140350710961, 50.12996573602, 52.83137267635715, 60.30793190002442, 60.77088925146288, 64.08586863548526, 57.41045351951354, 38.89880003467683, 42.78127185760006, 39.96879908346361, 50.54438767894622, 58.69582206972184, 56.97134810109293, 43.10157260587139, 43.09640684435445, 43.72705728776994, 41.12526678269909, 41.95956276309106, 43.6659546052256, 53.91706512820337, 65.30404698464179, 57.579703792448974, 57.11179640985305, 46.246175996718875, 44.1360898940794, 44.13298337690292, 43.89484059426093, 45.49797211923907, 45.13763181624874, 46.02227926254273, 47.67475420428861, 50.65697931474256, 58.431371950334125, 58.704839598747995, 56.41767809467932, 55.75764125393283, 59.39880886385518, 57.738230305333296, 57.829801959376184, 55.370354267858694, 53.83370299493113, 55.27555450316399, 50.93916246967932, 48.878592368095156, 53.21402734325778, 52.982646726792865, 55.13272923807944, 60.13707345531833, 62.54397707600748, 58.015298689565356, 62.64632740328389, 58.70365896532613, 61.14109823780676, 59.67291585860714, 56.916874224139804, 47.27030684871059, 48.35139051560433, 45.08680966592605, 47.26821622540874, 60.3234056503542, 65.83462207548081, 59.903853247242594, 64.6697683488169, 59.75078275126796, 54.29107881361439, 48.68414871154293, 54.52638180025163, 62.546016708497085, 61.769512930224025, 62.619431711012325, 69.09844198534566, 60.013848273984856, 68.44741482888499, 65.98963414469074, 75.32724426638696, 18.995570021290934, 4.500224042323328, 3.078697766027143, 2.7251233064359237, 14.902173722943953, 62.56227101049116, 68.47877025604248, 72.05785459087741, 58.38301697084981, 59.06326970746441, 61.76953646444506, 56.9997460611405, 57.29308051447715, 44.39653527352118, 64.93689744703232, 67.36196948635963, 50.868763769826586, 0.35334254945478133, 0.2950611542309484, 0.24268252775073054, 0.1602291279742795, 0.07853832276117417, 0.14604502537798497, 0.23135179623721108], [0.02631746059764297, 0.06191136878764918, 0.018976446045863054, 0.006207844107261589, 0.07686396865474601, 0.06466767269997828, 0.09548511461264665, 0.017066355193814924, 0.0722578190447342, 0.09413091631065454, 0.18296692400209366, 37.45006084442139, 47.469739760121996, 43.50880876664193, 32.12547863683393, 41.83614538561913, 39.44456254282306, 32.13660443982771, 65.37541450992708, 58.563069451239805, 57.31200987292875, 59.85354884978264, 55.69029415807417, 63.5543639429154, 24.215164107661096, 0.568340283728415, 3.0721719226529522, 4.133169131894266, 0.19431654724382585, 3.1001099847978164, 57.3989531301683, 54.30876478072136, 62.53413977161531, 57.46003227849161, 58.65021667172832, 51.858334618230025, 50.61516292633549, 45.300237594112275, 47.35388863471247, 47.18861956750193, 46.15205872443415, 44.341025890842566, 46.71223202059346, 46.051336180779245, 50.78023979740759, 54.909228663290705, 52.28359799231253, 51.62163526781144, 59.697634635433076, 52.73965589461788, 55.864443471354825, 53.335895384511645, 58.83529370830905, 56.83456328607375, 59.41790296185402, 56.06275066252678, 55.45490095692297, 51.16682860159105, 50.40260576432752, 46.68532848358155, 45.22704224432669, 52.51436671903057, 52.067726427508944, 51.85208628254553, 52.65929437452748, 52.295694581923954, 53.131869377628455, 51.52698847555345, 55.06394655473771, 52.74984228995539, 49.356242918199115, 39.989556266415505, 42.8764207132401, 41.83545504846881, 43.39011392285747, 40.350594751296505, 41.48179846425211, 43.84419887296615, 45.81178526724539, 52.14199258435158, 54.94587536781065, 55.286117446038034, 57.567901380600475, 53.78060979227866, 42.649550822473344, 44.02943280435378, 40.226973410575624, 46.42436142890684, 53.37810400993594, 50.51206734872634, 46.328706587514574, 43.7394598222548, 45.17928738747874, 43.69968306633734, 43.66307166314895, 42.40683063384026, 52.23871038806055, 58.835729091398186, 55.425157623906294, 51.17982341397194, 46.94262027740479, 38.99111693905246, 40.37869461121098, 40.36992026913551, 39.69943031187981, 39.971258409561656, 37.71055329230524, 41.67735607393327, 43.628095888322406, 50.04368928170974, 50.32494283491566, 51.43232599381478, 50.95348696554861, 51.131268393608835, 52.30688902639574, 50.33968702439339, 51.66132573158511, 51.84772460691391, 49.46594768954862, 41.71113552585725, 48.13178093202653, 48.06348462258616, 49.68736548577586, 49.64099914796891, 52.95999896141791, 55.91882321142382, 57.12044523608301, 53.38683520593951, 55.22194354764877, 57.000232435041866, 53.43691602829964, 52.769297246010076, 43.96524321648383, 42.532256264840406, 42.70500529196955, 44.00335296507805, 55.388930612994784, 57.20811413180444, 59.13231126723751, 57.74467475952641, 58.28303575515748, 56.82849930178735, 49.63390750269736, 46.300967585655954, 45.386023752151004, 52.26088354664465, 53.383818903277, 55.52307959525816, 58.969925142103634, 61.20237350463868, 61.03884596978465, 50.03935114029915, 14.828471406813591, 4.244713494854589, 0.37227825111439156, 0.9287127624115638, 37.610407337065666, 51.83454152076475, 57.70836537884128, 54.854390005911554, 49.08535226698845, 72.09342264359998, 51.46189674254387, 50.60786339544481, 41.11031078523205, 26.394062311418597, 43.349674286380896, 49.81153595832087, 15.062039725242125, 0.23039623944749757, 0.041934917530705856, 0.03627343967016186, 0.05475138847325599, 0.05668551150348879, 0.00981793768944279, 0.06567156197683466, 0.02040646215450139, 0.020067284386905453, 0.055009529460221536, 0.10696454379226893, 0.07922842242424527, 0.03313096232652184, 0.0377299260318039, 0.044837816197785645, 0.10353209450840951, 0.007526872749064839, 0.9207475930452348, 49.526489473158314, 55.02853931919221, 41.01751142932523, 34.07240590741558, 53.01360207219278, 41.30622925296907, 35.91055016363821, 72.4938887934531, 65.2025556564331, 52.69901621726252, 69.20676216002434, 59.761761465380275, 71.34619543629309, 27.982496715361073, 0.16607508363742984, 0.741105797069688, 8.95133706831163, 0.18407448795774292, 4.938417509678872, 64.02574262311383, 55.917622966151086, 67.42771625518799, 59.502077025751916, 60.03132635547269, 53.14471121757261, 52.62236918172529, 46.806910191812825, 49.780557078699914, 49.40384088024017, 48.96741051827708, 45.91271177414925, 47.58892882254816, 47.610572461159, 52.29261159896851, 53.601910529598115, 54.17674564546155, 52.929933994047104, 60.56345470489995, 54.0970979967425, 57.451501123366825, 55.64532810641874, 61.340280117527136, 59.163145019162094, 60.68907645440871, 57.97510224003946, 57.39288130114156, 53.162342271497174, 53.24282538506293, 47.72543907165528, 47.726058806142504, 56.654369600357555, 54.181754512171594, 54.90155650723366, 54.45602232410062, 55.28114780302971, 56.16135904865881, 54.611787488383634, 57.18068891955961, 54.86286624785393, 52.33893086833339, 43.108515201076386, 44.18514305545438, 43.73012458124469, 44.31260047420379, 41.33655309677124, 42.25558011762558, 44.64598624936996, 48.44019297630557, 53.871526410502774, 57.65487993917158, 56.790754333619155, 60.04299148436516, 55.11156412862963, 42.262805123482984, 42.95086729911066, 40.72715013257919, 46.17388279207292, 57.13698587109966, 52.09718734987321, 46.31512734197801, 43.31803644857099, 44.38177931693293, 43.859884431285245, 43.09846608869491, 41.86929333594538, 53.36211250674341, 62.64572728064753, 58.16898107528687, 53.880257606506355, 49.73261002571353, 43.17555635206161, 41.958099719016786, 42.5411404332807, 41.30425237840222, 42.09804596439485, 41.45591082111482, 45.157055393342056, 45.18311169839675, 52.977990873398326, 54.09163805746264, 53.7133332990831, 54.10009468755415, 55.51562316956059, 53.85379337495374, 53.81140039813135, 54.88770661815521, 54.009978232845185, 52.61849387999504, 43.8485840828188, 50.10283470153809, 49.21846574352634, 52.570017307035386, 53.221581828209665, 54.06533856545725, 57.23100900650025, 58.676437716330256, 55.31107156507431, 57.624273684717, 57.28569076907251, 55.062499200144124, 53.9311150581606, 45.96717388399186, 44.479336507858775, 45.62132673878824, 46.474163762984745, 56.768451736819365, 61.0575125294347, 61.90510926708099, 60.47784897588915, 60.56291734018634, 58.50197853580598, 51.34487282845282, 46.43657568962344, 48.2808074643535, 54.633513496768096, 55.59077578206217, 57.78440052463163, 61.393232114853404, 64.47134740890996, 65.69689981399044, 52.042180030576645, 21.89791802437075, 5.425499889158434, 0.7761217761904963, 2.230414858748836, 44.26412390124413, 56.301838736380304, 65.69776273542836, 59.872458596383375, 51.422633817118985, 73.19785225775935, 58.52836431995515, 54.88567875277612, 51.874039788399976, 32.919750751987586, 46.283156102703465, 61.575292848771625, 20.551888058262488, 0.13635854837634873, 0.14018636797705006, 0.054044576602116715, 0.05601177547848033, 0.017475467212798617, 0.016188221164948998, 0.07538425450723979, 0.18073451314722339, 0.1788879961015717, 0.21699227482801486, 0.18092502389223347, 0.18649059137509716, 0.10054996702820064, 0.24813434649859709, 0.15518626228215235, 0.1811218625234981, 0.16713308170437816, 1.4241914042542059, 65.58253526687622, 64.00172595054873, 61.78064853914323, 45.963741810091086, 57.75661445433094, 48.38870402305357, 43.02134836873701, 76.31548543130198, 70.06785577343356, 64.82371353333997, 73.65222746326079, 65.78573757602324, 75.58575199496362, 34.62539734378938, 0.45595356113006996, 12.031584170556838, 11.826446171729796, 0.28927841614330974, 10.070828583932693, 69.62807178497314, 57.150137578287435, 71.75086636697093, 60.10026593362132, 65.2463646088877, 56.23500154864404, 57.065273177239206, 49.13930446870866, 54.174815839336766, 52.14780161457678, 52.33054484090498, 48.18738837395945, 51.698305837569706, 49.90806941063174, 56.27472731374926, 57.28201943059122, 54.69524768091018, 55.66550085621496, 62.971040817999075, 57.552019703772764, 58.995365635041274, 56.40815457990093, 65.60373175528743, 60.51546058347149, 62.02647132258262, 60.069079168381236, 58.74828769314674, 55.110932627031886, 57.392100749477265, 50.5098904332807, 50.637712632456136, 57.25899904004989, 58.6785008830409, 58.18017159738849, 59.52019837594802, 57.40687239554621, 59.14674951184181, 56.65103166334091, 61.60933902186733, 58.335207200819454, 57.03372555394327, 46.040600653617616, 45.22233540011991, 46.17999776717156, 46.33088742533038, 43.27907162327921, 44.990472332123794, 47.48674715718916, 52.38259469309161, 58.1686790527836, 61.31167819423061, 61.267367178393954, 61.03395477417977, 57.30371798238447, 44.491197755259854, 43.75312928230532, 40.8972123361403, 48.256731956235825, 60.051146091953406, 54.37032638057586, 45.596168656503, 44.032405960944395, 45.404407901148645, 44.78584620260423, 44.27726776369157, 42.05633155761227, 54.54839806402884, 65.66387345713954, 60.709610062260786, 59.04283415886664, 53.443811555062574, 44.90314076023717, 43.783472737958355, 48.0967463216474, 44.35141624942903, 45.46951140126875, 43.80417108535767, 46.86580457995015, 47.5889798133604, 55.440164612185576, 55.3597128775812, 58.14632938754175, 57.703431037164506, 59.93927224989861, 56.47135573048746, 56.500730360707934, 58.45495323981009, 58.833383514035134, 54.054975663461995, 44.8463919085841, 54.35961831000544, 53.14323248401765, 54.019321318595644, 56.273774177797385, 57.29522997333158, 60.520936212232044, 59.73794483369397, 56.83317868940292, 58.82438559685984, 58.926139723870065, 56.945715412016845, 56.365800826780266, 47.95703149610951, 47.186630925824566, 48.77044477770406, 50.62640051687918, 60.623180635513805, 62.87335418885755, 63.64802229788996, 61.23265812473913, 64.03548579062185, 61.605852034784135, 54.386490468055975, 51.02776096713159, 51.56487857141803, 58.329943380048206, 59.57923396941155, 59.36313098476779, 64.60525712659283, 67.01509860254103, 67.24156056680988, 55.253561773607814, 25.676370551509244, 9.663405129986426, 2.7144326413831403, 2.2256607009518534, 51.55802619072699, 65.5966950231983, 70.39925682929255, 66.77719900684973, 59.37152093456638, 85.93985219155589, 63.96480860248689, 64.43609706817135, 55.583719438122166, 42.44610532637566, 58.954416090442294, 75.24609827226209, 29.86143558256088, 0.5248128226207149, 0.19654033194866874, 0.18449707737853452, 0.15603726339196006, 0.2086306243173538, 0.10612501867956693, 0.20711832078954867], [0.059955117307723536, 0.07674423677306022, 0.024425229170329632, 0.08641932204726242, 0.05800636582857659, 0.008899159823364068, 0.039210394775915536, 0.09039668201078331, 0.049928684959248196, 0.08968682494014503, 0.07653825105197969, 23.158308921321748, 50.98850588644705, 42.390454738370835, 37.1412879420865, 39.576409093795284, 47.44507981884865, 31.17085022311057, 67.96099385907574, 58.03927221605855, 69.94748607758554, 57.06140179787913, 59.923818111419685, 48.76189401072841, 45.09595271079771, 1.1643335223197937, 2.670640359001775, 8.991104018303657, 0.12262246165905269, 0.5620133780664014, 41.90108022382183, 56.23147533785913, 63.97238662165981, 57.662748213737245, 57.15575441237419, 49.87655708866735, 53.00413739296698, 48.12286538462485, 54.068131293019945, 52.94168541508337, 51.608793427867276, 53.28279433711883, 47.27913610396847, 46.78218749261672, 48.096044217386556, 47.19216539013771, 48.49100335951775, 46.56923417122134, 47.50610797635971, 47.80413750679263, 52.531597691197554, 55.62035045316143, 58.23184490203858, 57.352841746422556, 59.89739310356879, 57.055679059797725, 56.8354065956608, 53.248908981200195, 51.288939829795595, 48.530074088804184, 47.51453714986002, 51.25259514777891, 54.88081893613262, 54.91550445556641, 55.02357359855406, 51.87166675444573, 54.30844314636723, 51.939241347774384, 54.83400152575586, 51.595461291651574, 46.631301756828066, 39.6168722644929, 42.86443787236368, 43.09483789628552, 43.39827245281589, 40.876843467835464, 43.370733491836056, 46.50689986444289, 50.18163904067009, 51.14765997855894, 54.832813047593646, 55.96069059064312, 56.01206971753029, 57.346330611936516, 48.17324430711808, 41.353693854424264, 43.36938419649678, 46.59422359158916, 54.39806930480465, 49.875078355112386, 44.60380900290705, 43.308203066549, 43.661596851964156, 43.63925503146264, 42.48468575939056, 43.57540276742751, 53.83163198348015, 53.99826995788082, 57.717622172447946, 53.428027937489176, 44.331494531323834, 45.30341471395185, 41.10294849641862, 39.705713948895855, 40.06003733604185, 37.66719933479063, 39.55690706929853, 37.999686887187345, 44.73661261220133, 48.20938894825597, 53.48404330592002, 52.08277656186012, 51.730167250479425, 50.13384103775025, 51.732932521450905, 53.90898504564839, 53.4757435706354, 54.43170755140243, 47.480439985952074, 43.67999276807232, 49.50361421031337, 46.145002380494155, 48.60845088958741, 51.31310163005706, 56.0755572011394, 55.775158559122396, 55.78942814180928, 59.413290254531375, 55.08239738402828, 53.79123941544564, 55.82375280318722, 54.2807904366524, 51.20552278334095, 45.95362993978685, 42.37037220308858, 41.676861855291556, 50.83643167249618, 60.22140049165296, 58.367794252211056, 58.613181652561316, 58.67496290514546, 58.450611176029334, 58.886849341853974, 54.4586463897459, 47.43194772351173, 47.46901804401029, 48.928582975941325, 54.87352332761211, 61.3030646693322, 55.813668389474195, 65.48577823946553, 54.21141939778482, 18.998615741729736, 0.6860808883943866, 0.4457031208420954, 7.148536309119194, 62.49482193300801, 54.54539745084701, 57.32319255029002, 56.53480006802467, 61.38810949940836, 62.69485496705579, 58.735893003402225, 47.0384673149355, 30.30515959185939, 26.477385220989106, 33.385963670669064, 45.370993229650686, 9.279561004331036, 0.235098104082769, 0.1241982125887467, 0.09644407283274398, 0.06992766303160498, 0.13847161805437458, 0.016497157611733964, 0.028430221925279307, 0.06923231566625257, 0.04858877419704392, 0.08323188300334639, 0.11590143440351372, 0.07182836547614106, 0.06630446551547897, 0.03549154735200348, 0.03755764051851246, 0.08938642654327617, 0.031697020017271565, 0.04462040427531447, 33.23553685219058, 62.78603046171127, 43.002564137981786, 39.17475054340978, 50.28994744823825, 48.65152243644961, 35.400057608081454, 77.37323099567045, 62.27462399390436, 76.15055761029645, 62.69846746998449, 66.66910632964104, 56.23783742227862, 54.236961872346946, 2.035070037649524, 0.9801222876675668, 8.115839371758124, 0.11226490695750523, 1.11265225035529, 46.90951547315044, 59.47454198714226, 66.59535008092081, 61.4233402282961, 59.82746508813674, 54.179860007378366, 56.25661773066367, 51.684079400954715, 57.09638933981619, 55.41119398609285, 54.8886989778088, 54.184700212171, 50.67544583351382, 49.234088543922674, 49.585070071681855, 49.77741918256206, 50.94509309337985, 46.719566852815696, 47.44562895067277, 50.93458506368822, 54.908444189256244, 57.5404251775434, 58.54332816216254, 58.26283162639987, 60.43508337390039, 58.19088359032908, 58.52359471782562, 54.385352980706, 52.73256424934634, 52.1731165916689, 47.64577965582571, 52.71640800660657, 56.76576491325133, 57.588725243845296, 57.59655821707941, 56.4461584245005, 55.85645360331382, 55.06639019135506, 57.44089111205071, 55.27574669930243, 49.82804129200597, 42.303182002036806, 45.24316318573491, 43.31116053365892, 44.84211652509628, 43.399719807409475, 46.13539257357198, 48.52378260704779, 53.06273760334138, 53.97065647186772, 55.710996427843654, 58.568164610093646, 59.55842187327724, 60.40886625166863, 45.97846638771796, 41.235352023955315, 42.52882419093963, 47.146587448735396, 57.89611354950936, 50.822840659849106, 43.595328407902876, 41.56976938247681, 42.69443842672533, 43.992915538049516, 45.15687496431413, 43.55595957848334, 54.02327114535917, 60.854612242790964, 60.76762976184968, 57.35604632285334, 47.91992587427939, 47.15397719414004, 43.53459442815473, 43.88150061330488, 41.793262112525206, 41.02055126620878, 41.6387560290675, 41.51739397356587, 47.4711557357542, 50.250535472746826, 55.96973165389031, 55.02435022784818, 55.36303120274698, 51.41832705466978, 55.456054133753625, 56.53654944512152, 55.18406129652455, 55.821991658979854, 48.20740422894878, 45.44898171578684, 52.31514953797864, 47.35437108624367, 48.818266314844934, 53.52971930657664, 56.7077216794414, 58.191526859037346, 57.82025491037677, 61.17663098919777, 57.75561032756683, 56.56133097987021, 57.23992063153175, 56.24825131508612, 51.88989400863648, 47.07101122025521, 43.748955880441976, 45.15639251278293, 54.6188477546938, 60.14989176104146, 60.946670270735225, 61.65039447046096, 61.09992904047812, 60.65049602139381, 62.39134588549214, 57.565975496845866, 51.214438330742624, 49.39044990847188, 52.087797195680686, 57.716555287761075, 62.25450223492038, 61.328140381843816, 62.2012129137593, 59.828900675619806, 22.13030472878487, 1.140735072474326, 0.4888004389020705, 7.782976742713683, 63.32676841366676, 60.76760230525848, 64.63890321793096, 62.6623502854378, 66.77038977223059, 67.83155564338931, 66.6962020627914, 51.98111264936386, 39.06248446433775, 29.135530379510698, 40.0170010905112, 57.26073665003623, 13.042579004841468, 0.23777656197067232, 0.1383318836169858, 0.08698621945035073, 0.05182323571775229, 0.08268043759369081, 0.04964270433711429, 0.019786009459846446, 0.18055408411929685, 0.23752824223089605, 0.20019507696551664, 0.34916724769338486, 0.15435819784479757, 0.1187776655499493, 0.1612925346219732, 0.24367930007077035, 0.24451424397768515, 0.2434079517279902, 0.29291693541792135, 47.96175795216715, 71.90408983538228, 57.57183159551313, 48.80782496544623, 55.81376644872851, 59.951933660814845, 41.49227511498236, 82.42125864951842, 69.62906022225657, 81.92660854708764, 67.52889771615305, 71.78041750384916, 64.40896211131927, 59.4007465147203, 3.74448063392793, 7.055784021654437, 20.60431641917075, 0.46328456291267955, 3.744109969946646, 57.38880203616235, 58.3641895940227, 71.1100922861407, 62.8919776024357, 65.74531362902734, 55.54720609418808, 57.70876938296903, 52.737600572647594, 60.2579765935098, 57.937031715146965, 57.20871425444081, 58.41166596258841, 53.19321916949365, 54.07427372470979, 52.982097594968735, 53.52123914226409, 53.742374527838926, 48.85461884160196, 51.696701588169226, 52.266755334792606, 57.594663712286184, 60.23295187181043, 62.09113159487325, 60.44852925885109, 62.28475939842963, 61.32428076959426, 60.95661740149222, 57.12624642156786, 55.890770419951416, 54.03570505880541, 52.224648690992794, 55.757880518513346, 58.84747659006427, 61.28475504536783, 62.190987294720074, 58.67279775681035, 58.632636608616004, 58.42708087736561, 59.81930263580815, 58.13755504546627, 51.8393385794855, 44.93717124385219, 47.31052291008734, 45.26626594604985, 47.11365130639846, 44.61942788093321, 48.36220841253958, 52.04523947931106, 57.113659535684896, 55.614992495506044, 60.332670288701216, 62.32306526553247, 60.232995017882324, 62.15339137661842, 49.95305507413803, 42.02437993018858, 43.50042666158369, 48.36693486859722, 61.865610999445764, 51.389725131373254, 46.21368700458158, 41.7280605531508, 43.21840040145382, 44.66910862153576, 44.78006070660007, 44.65626285922143, 56.97542344370196, 63.17141509825184, 65.04148352530696, 62.90824759391047, 53.65208156647221, 49.896043423683416, 46.457085763254476, 47.48740611537811, 46.24468549605339, 43.81428687803207, 44.939661948911606, 42.56492568600563, 51.368791441763605, 54.24380640829764, 60.00984745640909, 57.82721711743263, 57.62230073252032, 54.742716204735544, 58.218198976209095, 59.315129018598995, 57.89637634831091, 57.44036943681779, 50.88682236209993, 47.538451840800626, 55.946322948701926, 48.82801732709331, 54.31446790695191, 54.58265604511384, 60.482159660708525, 60.3804055336983, 60.47259299985824, 63.719091723042155, 60.719969041885875, 59.06167330280427, 61.27537665828582, 58.005371170659224, 53.68920680015318, 49.50431239220404, 47.76429407058224, 48.01106214523316, 54.8583084537137, 64.02398540127662, 61.462618843201675, 62.379876875108295, 62.5193916597674, 62.68367621206469, 65.1021743589832, 60.72353447637251, 54.29416964131018, 54.45163711424797, 54.35504482638452, 60.624357346565496, 67.70469050253591, 65.20295966056086, 65.14215900051978, 64.36249379188784, 32.05700582073581, 1.4583096509018254, 1.0122597986652007, 9.813123960648815, 75.58958807299214, 68.4966641087686, 67.62450941147344, 69.23099456294891, 74.84988397167575, 75.44563708766815, 70.44983187029439, 62.57427346321845, 43.702746437441924, 38.430053264864036, 50.05907281752556, 71.56500877872591, 21.060962677001953, 0.5478953582144553, 0.31541065583305977, 0.23124652043465646, 0.20442875462674326, 0.3730623574266511, 0.08154557792529946, 0.2579008950100791], [0.06481347455372734, 0.02326809741075962, 0.06667652377678503, 0.05454535678689999, 0.11407434534762176, 0.10190540639263007, 0.023379055670492595, 0.05908287641021514, 0.05550031219759295, 0.06425725258586389, 0.2183094710832642, 14.069228999076353, 56.34398852625201, 39.42840630008329, 29.09452396054422, 31.091222186242383, 50.59076970623386, 26.69030127986785, 58.64141095069147, 61.25535295855615, 60.11074258435158, 60.95602904596637, 62.07781907050841, 54.05036687850953, 51.19140617309078, 7.738912836197884, 0.8247997383436849, 5.267621057648813, 0.07601610850542784, 0.6610514475933967, 33.51333479727469, 57.257453626202, 61.99535123763546, 60.47364419506442, 59.57930064970448, 58.295061742105794, 56.18778013413953, 59.504344155711514, 61.51506093240554, 60.60139971394693, 59.160564099588704, 55.87352768067391, 53.250356335793775, 47.77536299920852, 44.70855197598858, 45.490711812050115, 45.01371629776494, 44.198996866903, 48.07820527784286, 51.57658684638239, 55.6468774426368, 57.38337347584387, 57.450967681023386, 57.91811412380588, 57.27741849037909, 59.02379105168005, 58.64218365761542, 54.82145778594479, 49.21407268893335, 50.40754402837446, 47.69875126500284, 46.279731873543035, 55.63618506154707, 55.48391080671742, 53.6309439136136, 54.81321688621275, 53.335962064804576, 56.70893369182464, 54.55043377414827, 54.50070988747382, 42.53128351703767, 39.10056675634077, 39.87468573354906, 40.13293458569435, 41.07891221200266, 41.07846113943285, 46.534478049124445, 52.60429097760109, 52.91902980496807, 53.910812870148696, 53.467467369571814, 57.6243011413082, 57.235602101972034, 56.93155565569478, 51.41282004694785, 42.70901787665583, 44.91604535810409, 46.09388605240853, 48.663281702226215, 48.35161801307432, 42.24382085184897, 43.68511538351736, 42.84118606198219, 45.15389004061299, 44.020372129255726, 46.20163748341222, 54.207744136933364, 55.655404675391416, 56.67543272818289, 54.40778109335131, 45.38749464096562, 45.116874633296845, 45.52461677981962, 41.630530818816155, 40.95802868566206, 39.39514460102205, 38.58013099239719, 40.83493686491444, 41.09484095727244, 46.23894706849129, 51.69916875900761, 52.93706878539055, 51.17068429147044, 53.271356705696356, 53.59585831242224, 52.411914410129675, 51.611182151302216, 52.956209951831454, 42.94848249804589, 47.01241100988081, 47.625277426935014, 47.30358815962269, 52.32175480934882, 54.68847766999276, 55.36606319489018, 56.82827572668753, 59.190299587865034, 43.90836884898525, 51.8438296933328, 58.94100158445297, 56.24395631974744, 54.54368337508171, 54.246626592451534, 48.67094601354292, 43.88909824432866, 41.318537650569795, 44.8994537322752, 56.8574816949906, 57.28023867453299, 59.86319788040654, 55.95554836334721, 62.333612518925825, 56.231824428804465, 59.229162431532345, 55.909417367750606, 53.92890676375359, 47.153204487216094, 56.733668158131266, 54.08031417477516, 62.22026778805641, 45.44433370713265, 30.62346189252792, 6.080465595568381, 0.2826263827662314, 0.5185980722308159, 14.969696344867831, 67.32178872631442, 46.708423399156146, 60.478009793066214, 54.24690115836359, 56.04433513456776, 61.79811093115038, 54.16134249779486, 39.770484047551314, 31.8939293584516, 22.3836878807314, 36.5336343549913, 47.54901478367467, 3.8463411552290765, 0.13843814001208352, 0.1499447040259838, 0.024696822661245545, 0.03858508316860084, 0.051999646614515976, 0.03456437028944492, 0.07719286552239811, 0.009341947152279317, 0.04116676116902982, 0.06262760737069673, 0.025688410481257785, 0.028404513929760265, 0.03484160601792317, 0.04809120392066337, 0.10923679888008103, 0.06967686882783329, 0.05261793319556502, 0.2619473407826116, 18.647746001520467, 70.80244510404526, 40.13380927424277, 38.25397414545859, 45.80570951584847, 57.19906130144673, 31.24468884160442, 65.60884652599212, 66.72162686624836, 65.05260344474547, 65.51704345210906, 68.3747019306306, 56.873335915227095, 59.3906738681178, 12.100249182793403, 0.24211269623089224, 5.654279483902839, 0.3897018484290569, 1.698336642115347, 39.868413863643525, 59.67737951586324, 62.93933629989625, 63.66439819335938, 60.51044779439127, 61.865658067887836, 58.75683453775222, 61.55952099830874, 64.66744238330473, 62.38489358655868, 61.21966723472842, 60.14111741896599, 56.00757860368299, 50.51711543913811, 47.668207768471014, 49.65644544170749, 46.001545613811864, 45.73069026393276, 50.09863384308354, 53.37129869768697, 56.61850736987207, 59.390968045880726, 58.93039157313686, 59.14441570158928, 58.12668223534861, 60.30100499430011, 59.053879553271884, 56.451630130890884, 52.155563985147786, 53.18991261143839, 49.017620778852894, 47.93468967560799, 57.07459272876863, 58.429716710121404, 55.17768744499453, 57.40178900380289, 56.00154599835796, 58.59180081275202, 58.76737394640523, 55.21263968560004, 44.47389618042977, 40.89647100817773, 42.15236686891125, 43.66757846647694, 44.733086401416415, 43.09008790600685, 47.040048030114946, 54.10246379913823, 56.159429242534024, 56.313923558881214, 55.754993654066524, 60.44103753182196, 60.387391274975194, 60.02662735600626, 51.82414723980812, 42.601929326211255, 44.99825823691584, 45.646743697504846, 53.81373813075405, 51.22657414405577, 42.94730970936437, 42.732022577716464, 43.17050826164984, 45.35148728278376, 42.937543007635306, 45.102754100676506, 53.78928999747, 58.11348345971877, 57.96451184057421, 56.96523312599429, 49.59911215689875, 48.93205035117365, 48.88144000884026, 45.951857028468964, 43.800782157528786, 42.66776238718341, 42.15271595985659, 43.02409010548746, 45.168359664178666, 49.17636694446687, 52.842657335342906, 54.090202469979566, 53.94450602992889, 55.437634683424434, 53.794400845804525, 54.887012358634706, 53.47744195692001, 55.55090488926057, 44.198439890338534, 48.84633087342786, 48.50352748747795, 49.682517436242875, 53.33818997106245, 56.20427370071412, 55.31038122792398, 57.048571725045484, 59.7592786050612, 49.0397507913651, 52.453758255127944, 59.604858813747285, 58.33896483144453, 59.1987915192881, 57.32116468491093, 50.68920943044847, 46.13153296132242, 43.51290372110183, 47.064437327846406, 60.314360664736846, 60.103866669439505, 61.350658709003085, 58.18041870670935, 64.69791135480328, 58.47799716457244, 62.25360401215092, 57.88138897188249, 56.97374859163838, 49.84674707535775, 61.38877237996748, 55.96358922220046, 67.00529267711025, 46.19010179273544, 38.71064785988101, 4.582511936464618, 0.865506892723422, 0.651814817420898, 19.267762899398804, 75.18321483365952, 54.881415136398815, 65.46839037249165, 60.98221478923675, 64.27700965635239, 68.90310010602398, 61.33378075015161, 47.48768460366034, 42.31153665050384, 20.25607466697693, 42.64754649131529, 57.595679606160815, 5.95090284462898, 0.26288205998078473, 0.16381075755963403, 0.100443365893537, 0.07736829965705834, 0.031858949937046535, 0.10265154538736229, 0.060587856137464126, 0.13034609116373524, 0.22681490097555423, 0.26716724939403996, 0.12925731168398935, 0.21520977208931602, 0.2552990765581208, 0.14356915178077836, 0.2678712229094198, 0.13677012145278916, 0.14073929959727874, 0.35500636985225065, 28.741804822798702, 82.52757057066887, 52.991119046365064, 39.895458605981645, 45.123648566584436, 67.59804910229099, 34.819664493683845, 71.39074571671026, 71.10326736204087, 72.8538211699455, 71.82161023539882, 72.2995275066745, 64.18245307860836, 65.26305821634108, 14.883580707734632, 2.211153569721407, 12.889016251410208, 0.5249713108904901, 3.4299879352892604, 48.09198848662838, 56.67321266666536, 68.79951030977311, 64.17362774572065, 66.13253393480855, 65.17996280424057, 64.11142679952806, 63.29973151606899, 69.19248473259711, 64.01316750434138, 64.68148839089179, 59.42970537370252, 59.99408737305672, 53.0373873249177, 51.626247975134085, 51.80983058867916, 50.36145225647957, 47.10471614714592, 53.18141675764515, 56.16096681164157, 62.04167050700035, 61.00503121652911, 61.7879912161058, 61.93398575628958, 60.133743363042036, 61.10249819294099, 62.24348037473617, 58.90932060057118, 53.343418490502145, 55.81311141290973, 52.33209417712305, 47.1474229135821, 61.121478542204834, 61.684938784568544, 59.64734592745381, 59.722588754469356, 59.67777959762081, 63.26706601727394, 61.56945243958504, 60.56998937360702, 48.33120599869759, 42.869223163973906, 43.63580726808117, 45.23955460517637, 46.58923433672997, 44.38876898058, 50.676116558813284, 56.995800156747144, 58.48465734912504, 59.80533115325436, 56.91659181348739, 63.62398993584418, 63.58485252626481, 61.81102729612782, 54.29862153145575, 42.409639050883634, 45.08180864395634, 47.713005158209036, 56.63569519596716, 52.443273759657345, 42.711983188506096, 43.79485937856859, 42.94712928033645, 47.278233958828835, 43.59107263626591, 46.106480783031834, 57.334069282777854, 61.48856924426172, 61.71760428336359, 60.090279579162605, 53.56442836023147, 55.139479637146, 54.821587224160474, 49.01719716287429, 45.089433731571326, 44.5650089171625, 43.6546189554276, 44.94013263333229, 46.169607408585094, 51.096123956864886, 56.98295439443281, 58.032039365460804, 56.48453097189627, 59.09791992556665, 57.95635331061579, 58.16832603946809, 56.18167300378123, 57.703344745020715, 46.1687562542577, 51.37137236133699, 50.70312992219002, 50.76508768143193, 54.595984258959376, 59.34225613071073, 59.40317446185697, 60.21600331029585, 61.19476410650439, 52.460979338615175, 54.70218243137483, 61.99613178929975, 60.547094498911214, 60.41952333142681, 60.35137214968282, 51.937848906363214, 48.81984310765421, 45.03409301081012, 49.35962007891748, 63.53015507421186, 62.898339686855195, 64.67263560141286, 60.13011124826247, 67.58213212413173, 60.524148633403165, 67.29279456600067, 59.77309711517827, 61.42237140286354, 51.924312806898556, 65.54653183106454, 59.24872329158168, 72.08713116184359, 51.91801348040181, 56.261493236787864, 9.821666882884118, 0.939716297772623, 1.8614352903058453, 20.210114294482818, 82.2806259893602, 56.73577839328397, 76.37916118867936, 64.54089103206512, 69.87977812367102, 73.46465187688028, 67.75349263221987, 53.38266572644634, 47.25212274059173, 32.636651723615586, 52.622412327797186, 73.63172131199991, 10.016354706979568, 0.6154652324415023, 0.22178571761375476, 0.23564391108530186, 0.19942816166627794, 0.1336808412546112, 0.13787497345718647, 0.1618255479561706], [0.04601370370496185, 0.0435728824607307, 0.10965301444934261, 0.03675572649245301, 0.05120650429518954, 0.05226830981912152, 0.02505312057872934, 0.050190897703531294, 0.12202890439619943, 0.12571676739401397, 0.24924963262052308, 5.290288434874627, 58.740941093813994, 39.78921336512412, 26.41809271227929, 22.3497829129619, 55.573521275674146, 33.359217028464045, 61.376334544151064, 62.22429998459355, 64.47055509013515, 59.697101193089644, 59.59079711667953, 53.26239801222279, 64.81236611643146, 23.952420219298332, 0.20349175248655582, 2.9390368730791154, 0.5690631030067321, 8.297414222071248, 41.85974236457579, 53.07839962743944, 60.90690528192828, 60.86881122281475, 61.976629764803, 60.28670011028167, 62.375632870581846, 61.234329054432536, 57.54908577088387, 55.87819137880879, 59.928238622603885, 60.41430265672746, 59.447132464378114, 49.93509454111899, 46.99083012919272, 43.82940369267618, 42.00949061301447, 43.031299421864176, 45.44481223629367, 52.51955209239837, 54.861250231342936, 55.70818801080027, 56.51752594978579, 55.44905270299604, 59.96461860595211, 60.33672994182956, 59.5081998455909, 55.01286945035381, 50.54607037575015, 49.918738257500436, 46.372778338770715, 45.365752943100475, 52.79915432776175, 55.43270426411783, 57.51107408154396, 54.012684668264086, 53.99516736307452, 53.429420378900346, 54.11402694640621, 50.77681556824715, 39.35012755855438, 38.630376554304554, 40.62520380943052, 42.03597837878812, 41.51902567955756, 48.06446521512924, 50.68309053297966, 54.77143972150741, 53.52734235025222, 52.90772553413145, 55.97749402446132, 55.69000782505159, 55.85406487987888, 57.212001200645204, 53.00975814942391, 42.52118341384396, 44.88581565118606, 43.06279997671805, 51.35741264589372, 49.405629481038744, 41.47270641019268, 41.76635465314312, 44.60753133220058, 44.453919549142164, 45.094803456337225, 47.7784969729762, 53.08941756525348, 56.67450704882222, 56.67904130874142, 52.40272429681594, 52.7065707022144, 45.51408913827712, 46.28200684824298, 44.44900089694608, 40.606333286531516, 41.529623923763154, 39.15843740586312, 38.37361820282475, 41.64086626422021, 45.96580105443155, 52.00712580834666, 51.72190281652635, 50.158940284482895, 54.499768518632465, 51.23732928306826, 51.92159852673931, 52.26974418086391, 49.73506150707122, 44.24897178526848, 48.66470160022859, 46.2189116016511, 53.20344871090305, 49.99141193205311, 54.741410055468165, 57.06088012264621, 53.675886431048, 41.58117171256773, 39.86948859307074, 40.28574620523761, 46.58666518426711, 53.55696801216372, 57.22480773925782, 57.433352316579516, 54.53354404818628, 47.08411585900092, 44.87590382176061, 41.93143544658538, 50.01556196520406, 56.8772308288082, 58.30814676900064, 57.96947363884219, 54.001772634444706, 61.055853366851814, 66.14441871643066, 57.944986281856416, 55.267643082526426, 51.049647792693115, 54.807125445335146, 57.622598832653416, 56.47631752875544, 51.879193782806404, 15.713686616190019, 0.7575811001081622, 1.0291684010336477, 1.8090568170432122, 29.03774961348503, 44.23589460311398, 39.413885685705374, 59.974683407814275, 57.17666456776281, 62.150822224155554, 59.55034571309244, 55.23262416162799, 47.66942370322443, 27.29328332408782, 33.211528024365826, 44.21827139392976, 38.05453338930684, 0.6114685210970141, 0.011893560989729822, 0.06495024423084914, 0.034580481118492545, 0.06481355882339901, 0.11560415398449668, 0.025614297220243082, 0.012864240355068638, 0.047563028431707816, 0.06016355067972214, 0.1093954863327165, 0.022923116527137258, 0.004202708556887604, 0.044069935627762354, 0.02060086079572718, 0.04736530879933027, 0.06006368728835256, 0.11133887519639347, 0.2818045542845803, 7.030193007761433, 70.37095300612911, 43.16108672849594, 26.837209732301776, 40.98172372387302, 60.358377502810576, 39.27055835723877, 65.33024057265251, 69.36454342257592, 70.16402444531842, 66.11485189007175, 65.28576481726863, 58.95527508951003, 69.527753245446, 27.04981004038165, 0.0819331341453137, 4.035248386283075, 1.0606392929630897, 13.022313098753653, 48.45853790160149, 54.77613479860368, 61.913405079995435, 64.69224352990427, 65.93810204536685, 61.82251199599236, 64.65105079835462, 64.35142878563174, 59.90903469824023, 60.066031486757346, 60.10270957023867, 61.842539618092204, 60.88590883439588, 54.37722190733879, 48.86936695344987, 45.87586110638034, 43.37026280741538, 44.10668388489754, 48.36543652319139, 52.66886103537775, 59.03360089948101, 58.693931487298784, 59.578684837587424, 58.0531927078001, 60.53292689784881, 60.34859511160082, 60.630437020332586, 56.73850051818356, 50.82523330565422, 52.44647049134778, 47.924785690922896, 44.87194222788657, 55.6705528689969, 55.95086113099129, 56.0645902541376, 57.11309863675026, 55.38540832458004, 56.22627819738081, 56.74814170406711, 52.82341026490735, 42.379272061009566, 40.64363894924041, 42.20362440232308, 44.623460077470355, 43.99868534457299, 47.89315569785334, 52.58065477494271, 58.981300015603345, 54.810102524295935, 56.18360673227618, 58.46097407802459, 59.2494999208758, 58.018401284371656, 58.57286753193025, 54.07431294841152, 41.50008063162527, 42.77016762764224, 44.32852529710339, 54.22973294411936, 51.197144600652884, 41.82996765259774, 43.877440960176536, 44.95715571988014, 44.41076955487652, 45.47000561991046, 49.341428126058275, 57.00444506060693, 58.15563324959048, 57.23463327653947, 55.43169229261337, 55.67021162279191, 48.84297724693052, 49.44865788182905, 48.59715446349114, 43.1611063403468, 45.06800190094979, 41.95707205803164, 42.65930967946207, 43.404748285970385, 47.5363023819462, 53.790066626764116, 54.04703286386306, 54.08965726052561, 56.28266226860785, 55.3161314225966, 53.05868971732355, 54.37389573743267, 52.29322741108557, 47.26858492820494, 49.56720759791713, 47.906213268156975, 54.4830866782896, 53.438849756794596, 54.81558992016701, 58.74079204374745, 55.619146285518525, 41.51698996943813, 44.89811620404644, 43.346571691574596, 46.85277446623772, 55.66193542172832, 60.39974674101799, 59.81124216510404, 55.98941410741499, 49.71613214861963, 46.57479609212568, 44.47246451531687, 52.697466881044456, 60.13400616184358, 60.12401980738486, 60.10267426890712, 54.92870715356643, 61.47519788434429, 69.60601237512404, 61.80255105418544, 58.64640412792083, 53.91493135882963, 57.254911930330344, 62.13246160937894, 60.04114012564383, 58.14605482162968, 20.076410501233994, 0.8080803290490182, 1.3586510501561628, 1.4528408862890736, 37.07411343051542, 54.184904175419966, 46.98910428631691, 64.50573482821065, 62.925384429193315, 67.71277842983123, 65.1461676628359, 60.042340370916556, 55.248035154035016, 35.555912986878425, 30.174254409728515, 50.18021914266771, 50.67735602778774, 1.1666142580009278, 0.050526287166341666, 0.17508191807616144, 0.08555070091519626, 0.04842853924680141, 0.020601724559861808, 0.0594793307414699, 0.022126515320832693, 0.1956360111193311, 0.2190424333656988, 0.27210309260314514, 0.13783435547544112, 0.15261275843987543, 0.22112185646209026, 0.13855833920740313, 0.23637025436807066, 0.2746660857191009, 0.31669609008296845, 0.601803126835054, 9.442687476834944, 82.17102712200534, 54.057183957869015, 42.014385730989524, 33.35870712034164, 73.46416550297891, 46.27074572347826, 73.6646770661877, 76.28146279242732, 77.55835902306342, 71.59175149856075, 69.99872792151668, 65.2188374150184, 75.6663880809661, 36.4576070539413, 0.34119760437357816, 12.848126522956356, 1.3572103145622438, 16.353768398684842, 57.105120535819765, 51.94546614923785, 65.16943516269808, 67.82221255763885, 74.22823536780574, 62.78879181031258, 66.88337756741431, 63.65781253384006, 63.006569647019916, 60.968604164738814, 64.07908293508714, 64.49493262075609, 64.82119537168934, 55.43690120020221, 53.466627982354936, 48.73490025920253, 44.73228623790126, 45.93779140903104, 51.261141992384395, 56.08272337144422, 60.42665027802991, 59.935322423135084, 61.79836588521158, 58.196253315094985, 64.5302104180859, 63.45669300325456, 62.992060799752515, 60.18325151935701, 52.67359141380557, 55.12932854314005, 50.00326925708402, 49.651781743572606, 58.16527443547403, 60.41105101185461, 61.65998858790244, 60.029094526844645, 59.48463424559563, 59.609193032787694, 59.34601768370598, 54.32879240282121, 45.601958074877345, 42.14027420167, 45.3507734114124, 46.14284899926955, 45.047056444229625, 52.92392492294312, 56.49869072821833, 60.80672794772733, 60.146761709643954, 58.13691962149836, 61.8268422926626, 60.99112249189808, 59.97544042525753, 61.51763400723858, 55.128497000663515, 42.08850676013578, 43.82901145565895, 46.14962685492731, 58.06157089048817, 53.517508968230224, 42.177536718307, 42.77087757664342, 47.40222007997575, 46.38868747218963, 45.993806777461884, 50.32150291627454, 60.19135513613301, 62.82025314146473, 61.0891503672446, 57.22254060929822, 59.80412698561146, 52.20733927142236, 53.65683155675089, 54.08939446172407, 44.97961128911665, 49.47442000912082, 45.80148120080271, 43.819664447538315, 46.57367037188622, 51.173449562441924, 58.91544734278033, 56.5133447031821, 56.26011256248721, 58.580504386655754, 57.70449007711103, 57.06315901971633, 58.34057692558535, 55.112536876432365, 49.84118123208323, 53.211826893591116, 50.200760595260135, 57.69509207817816, 53.82546601756927, 58.23876396302254, 61.549675849176225, 56.4547444928077, 43.39396961273686, 43.0613330102736, 44.6074999532392, 49.768307516651774, 55.25840197840045, 62.61992200728386, 62.26576728205528, 58.900985563955004, 52.39026684914866, 50.33551754490022, 46.709835452418176, 55.331773834843794, 60.484587607845185, 64.87636743053314, 59.710633370184134, 58.64609818304739, 65.26256399769937, 71.5931635518228, 64.6088304058198, 61.59277485262964, 55.675820612138324, 61.3194013410999, 63.19788325217463, 64.20295530749907, 60.34143678603634, 28.576659310248594, 0.6997929429334979, 3.6885326812344217, 2.689000728630251, 37.7891222892269, 59.769198279226984, 51.450031572772616, 72.57050837239912, 69.12648693207773, 74.8029096664921, 73.02975516165458, 66.5673678921115, 63.100027961115686, 40.95933091255927, 48.953721446375695, 63.82814145857289, 64.56180118745374, 2.0620684469899824, 0.2031351079142863, 0.32031698933532166, 0.16618513982863198, 0.1373482114004512, 0.18834959565391465, 0.14736010723056334, 0.13955085207858395], [0.043881474167949734, 0.02300609917109532, 0.04269864973461917, 0.025555524869912097, 0.05806780991054351, 0.048424425354648026, 0.06716105906713395, 0.012996131967332576, 0.0071312381318890524, 0.006221271713354415, 0.03504261216749588, 0.35178852477861994, 47.18218295804916, 49.55075717741444, 39.670436151566044, 25.40634282173649, 47.77452753436181, 36.47967038616058, 51.39220799169233, 70.00406234495102, 57.15890015325239, 62.468271409311605, 63.21576533779022, 54.22353559924711, 61.498885077814904, 31.767954595627327, 0.1164007628516805, 1.527296052344384, 1.5501631027267826, 26.457290918596332, 51.035727300951564, 44.80872538781936, 56.23273834105461, 59.615037364344445, 62.02860116958619, 65.34410222884148, 60.22723305609919, 59.74647991118893, 58.66751040181806, 59.291135880254934, 58.99392612518803, 60.67770550327917, 56.220202445983894, 52.4233873428837, 45.978933149768466, 43.52032092309768, 42.25612532707953, 44.39502516100484, 50.00705042193013, 56.387001237561634, 57.70416452038673, 59.76864914740286, 50.966199367277085, 47.83768946124662, 51.614496554097826, 59.01461270547683, 59.138132064573234, 58.641901246963016, 53.25869137240995, 48.021417202488074, 50.33669817832209, 42.93966108752836, 48.19785717994937, 53.81651516883604, 52.45273451651297, 51.7843508720398, 53.72794412797498, 51.719345431174006, 52.77713021924419, 41.534024823096495, 40.45112902118314, 39.541535300593225, 39.77967808323522, 42.405371512136156, 47.173993049129365, 47.79322547297324, 51.10968359055058, 52.08214113789221, 55.51036719352969, 54.13546269939792, 55.82790267082953, 54.21814234026017, 55.309788950027965, 58.57677421262188, 53.84084955338509, 42.03426038065265, 43.52138388541437, 44.58172213646674, 46.731388876515055, 49.868331878416, 42.908164455044655, 43.45504483868999, 42.16615007769677, 44.70900697092856, 43.3087561207433, 47.270530423810406, 56.27069903958229, 55.70926666259766, 54.55752541941982, 52.200455511769945, 52.27438042240759, 50.36866157285629, 47.83813268907609, 46.12196630047214, 41.779945665790194, 41.31537229784074, 40.261188245588734, 40.05913126853205, 39.134267760861306, 43.50614155492475, 49.91066601968581, 50.187232340535815, 53.73740880720077, 52.500897299858835, 50.818902600196104, 50.94146097860029, 52.99879904716246, 44.414021199749364, 43.70897516127556, 48.00029523911015, 51.37696566120271, 55.14889724792973, 55.40248632431031, 54.62076579370807, 52.03210738397414, 47.97057151794434, 42.96722358272922, 59.04459922544418, 51.30089913645099, 45.975316724469586, 43.90663908373925, 48.594895178271884, 54.679864145094356, 56.493736774690696, 50.224494857172814, 44.19940871577109, 41.687648373265425, 43.69044980695171, 52.86171613201019, 56.998153578850534, 59.89671061115881, 56.865883411899695, 52.57200594871275, 62.617078288908935, 60.86557918979276, 57.23757897653888, 59.272237900764715, 56.63247100768551, 60.41975475126698, 61.8492704053079, 59.38109936252717, 3.6473301437593277, 0.06529824733133278, 0.17575651978052434, 1.4371955322642482, 60.90475190070368, 45.26093544498567, 52.347591461673865, 57.001185570993734, 60.28128723944388, 59.675100618793124, 62.515316317158366, 50.8165374109822, 39.697084734516764, 28.522120714187626, 33.75362703877111, 44.97254317806613, 29.539748276433638, 0.10567386184007892, 0.07629467339645471, 0.10430936731638447, 0.027653818627098398, 0.039973161709044254, 0.09919400672398268, 0.04176435954568367, 0.0305673333575889, 0.05269973606411969, 0.028495519429505355, 0.022137037538472685, 0.06666831131423674, 0.0801964204818491, 0.03762600620487525, 0.024628753833953413, 0.043000511359423406, 0.04043022125598885, 0.05778691228178721, 0.06700539000092015, 0.9005627084162928, 54.44361978961576, 58.188851802579826, 35.52942522110478, 30.782415943761027, 60.28816315435595, 38.63867628958918, 59.477491609511844, 73.54486434690415, 66.40214197097286, 67.51924084078881, 68.90728919736802, 59.44717561045001, 68.5362486685476, 36.90190176809988, 0.02184254759471984, 3.0625979073586005, 1.1525508448962243, 31.40882826620533, 55.98861002152967, 48.10254750713226, 57.74434135806177, 61.211622453505, 65.79384903753957, 65.70878067324239, 62.85689984598468, 59.813858386008974, 60.48625069279825, 60.169884081809755, 62.040215307666415, 61.735568738752804, 60.834125703380955, 56.01666281300207, 47.555871086735884, 44.39313457858178, 45.615152928137014, 46.24520324891614, 53.54662864438949, 57.714801988294056, 58.867268869953776, 58.86667266968758, 53.36866678730134, 49.328252884649466, 52.84857226956276, 61.39124739554621, 60.02746674322314, 61.07397863941809, 55.38391390154439, 50.48477157469719, 52.589468340719904, 43.00826334184216, 51.35913456639936, 54.93771291548207, 55.37359414562103, 54.30042974410519, 55.35917159049742, 53.23469823406589, 55.20807012434929, 45.88873432528588, 41.143211626237445, 41.43059976639287, 41.81849471984371, 44.40885151586225, 49.80679773515271, 50.94964696514992, 53.74030351638795, 55.4074324330976, 56.25192657593758, 56.3876288167892, 58.30269467446112, 58.68876964815202, 57.29453571381108, 58.7652676336227, 54.73257687784011, 42.39170989682598, 45.576733312299176, 45.87417056483608, 52.32442202106599, 52.14630326917095, 43.245633417560214, 43.435911516989435, 44.86656465838033, 44.62805709531231, 43.54478082349224, 46.25823728499874, 57.04591628043883, 58.09669571538126, 58.817780325489665, 55.59098759005147, 54.652446777589866, 53.83952379226685, 50.47532650732225, 50.23159434718471, 43.360213695033906, 43.973287997707246, 41.988749119543264, 41.471466941218225, 41.36671220102618, 46.26255189218829, 53.02613404489333, 54.21332959205874, 53.90781617933705, 55.61652614224342, 54.570567300242764, 52.83664826423892, 55.088222103734175, 45.495740290611025, 44.80323014720794, 49.2771287118235, 53.507118609643754, 56.73235416412354, 57.758732534223995, 55.95075130462647, 50.88914832761211, 48.33929784836308, 43.797895293081964, 58.4383890705724, 53.11310083635392, 46.56923024885116, 43.460975462390536, 49.81131238322104, 55.23153766509026, 57.07926034927369, 53.165386030750895, 46.43096277790685, 43.744715798285704, 46.558898725817286, 55.25772340836064, 58.1653489605073, 63.15212880411456, 61.20791973606233, 55.418701402602665, 61.349980138963275, 64.03694491232595, 59.869999270285334, 61.80832086070892, 59.442602126829094, 61.80065262702204, 64.75173804067796, 59.004367474586736, 5.033922320412052, 0.30586158436152244, 2.0226004551495276, 2.7700471926120023, 62.30325729616227, 46.27705289471535, 55.454944102994865, 63.37389961365731, 65.53470196262484, 64.35891659029069, 68.88910508924916, 57.102057164715184, 47.149548838215495, 37.58495899938768, 37.63381211988388, 53.50947987648749, 35.961180117822465, 0.15138597588144964, 0.02981698279449296, 0.037997934231234175, 0.0985586210604637, 0.007760853238118393, 0.02176866990574185, 0.038992212935080456, 0.08590249615090509, 0.07869910163384292, 0.16684775991785913, 0.18945510649392683, 0.2342427056282759, 0.18536349217737877, 0.10865939841155084, 0.163914623760408, 0.15114200752108328, 0.1819333794616884, 0.22265300575283267, 0.20967941400745224, 1.2524771474061476, 69.02846690147155, 65.39692086558189, 54.89021693506549, 35.76608142545147, 66.06704604241156, 48.27837951721684, 63.84806709904825, 81.5928226901639, 70.28459810441541, 71.92756129849342, 72.63528239342475, 65.2557743749311, 71.7684542748236, 40.66771053498791, 0.18613267509687334, 10.182929923457484, 2.0097419451321326, 39.20950666550667, 59.47001557196341, 48.10295543363018, 58.95297658058905, 61.125738236211966, 69.14070944632255, 67.26268645255797, 64.84902066569175, 63.891683855364406, 62.67775735547466, 62.1450210386707, 63.49863490750713, 64.41102920040008, 62.4990463256836, 57.14501104047222, 50.24495001762144, 46.88069389712426, 47.48909665692238, 48.170098566239886, 55.11674165725709, 61.47088719952492, 60.944340382852864, 61.309010982513435, 54.69452988716864, 48.71963439449188, 52.72404486133207, 62.056822622976, 62.29796209642964, 61.310407346294774, 57.00163272119338, 53.38218327491514, 56.139491834948146, 46.73013764043009, 54.91430421029368, 58.14049290072534, 57.714821600144916, 56.83685002788421, 59.06742349747689, 57.88853553033645, 58.93067006141909, 48.30148619990195, 45.19717731783467, 43.79908769361435, 44.069864596090014, 47.66350484663441, 52.531629070158935, 54.13792594786614, 55.507805885807166, 57.20965562328216, 61.44075162949101, 59.98348128411078, 61.16363617681689, 59.93178052286948, 61.84497540996921, 62.558478078534534, 57.497890995394805, 43.77086231785436, 45.17113277989049, 47.11483978456067, 56.95148521854032, 56.16602274679369, 42.26322089472125, 43.07969754742038, 43.90239507921281, 43.0600856965588, 42.967635431597316, 46.04171068437638, 62.01673207744476, 61.44457201803885, 60.00930616932531, 56.895979758231874, 59.23891736615089, 56.81718718621039, 53.64705701028147, 51.254117027405776, 47.9463351926496, 47.21488375817576, 45.72129226499989, 44.33920591108261, 43.71915371187272, 48.761713581700484, 55.10288784580847, 56.23947305064048, 57.77463382290256, 58.374983956736905, 55.62721460096298, 56.492258041135734, 58.77091584667083, 48.60160635363672, 47.048053587636645, 51.210406134205485, 57.93531763938166, 58.55027467973771, 61.14718183394402, 57.29930923831079, 54.09112030459989, 50.38410002185453, 46.9730382580911, 57.76086238122756, 52.01690035481607, 49.25181765710154, 46.21566387914842, 50.56767086828909, 58.06060990979595, 59.81967526097452, 54.758115430032056, 48.41305017471314, 45.81604496125252, 49.122893271907685, 58.48593211943104, 61.164534399586344, 65.55844799164804, 62.22955596062445, 58.10299111950783, 65.6070775370444, 66.7779521019228, 60.445340371901, 65.21357751661732, 62.551202081864886, 67.82748422315045, 66.84864890190863, 66.93100298604658, 6.874220448155557, 0.1466065525047241, 4.24060236061773, 2.885525938003294, 74.8013642526442, 54.092234257728826, 64.00968051725819, 68.85971084717782, 72.11205390191847, 72.0444243954074, 73.96804886479532, 64.60411179450251, 54.20111925371232, 42.448890209198, 48.24998547953945, 63.26363002100299, 48.91592156502509, 0.6072772234197586, 0.14251758885239402, 0.2080764209911708, 0.19072212399013583, 0.22665282741429346, 0.1454978700607054, 0.10093278116396359, 0.2520560731570567], [0.13428667890689067, 0.018758674062067465, 0.04352320548928073, 0.010382032168338136, 0.09031936841746492, 0.00832608966682587, 0.04895467311143876, 0.006363125820268667, 0.025952402464745027, 0.07849853215438705, 0.14076758356344315, 0.28602119415037097, 24.21324214627666, 51.55167979578818, 39.83361851784491, 40.36236578418363, 40.73319058264456, 41.7777765950849, 36.66778725962485, 71.03588104248047, 56.65058059077109, 55.25902171288767, 50.305311372203214, 58.6772535693261, 54.97509310322424, 43.708343659677816, 0.24290749713057475, 1.7617255761738748, 1.1396680652133881, 8.020868983960922, 39.38473070821455, 48.42296592650875, 55.636400791906546, 52.94862016554802, 58.75914089141354, 59.11589614806637, 58.93833829510597, 62.27673422905707, 60.97851991653443, 61.09094681278352, 61.14604042422388, 60.08407831192017, 55.23752320197321, 49.67315473864156, 44.23537292788106, 44.04106655428487, 44.285245864622055, 46.50034166151478, 49.07521294009302, 58.94524558897942, 57.47112081896875, 55.343235000487304, 54.247858216685636, 52.38377924888365, 49.02214327166158, 53.5947286698126, 56.638507535380704, 57.24129738346223, 56.38920560959847, 50.915118340523016, 47.96887313165973, 45.704147584976695, 44.070217609405525, 51.786645458590606, 52.49610808587844, 55.00383623184697, 53.98034864856351, 52.69056350954118, 48.20297195065407, 41.12987556765157, 38.259406628147254, 41.927579756705995, 41.54538400711552, 46.06171477225519, 48.59645235923029, 50.87503563973212, 53.3890474227167, 56.50376627522131, 57.19192651010329, 56.60588126028738, 56.45630951850646, 56.9122419049663, 55.455661896736395, 54.21424350430889, 53.27283151688115, 42.4142203792449, 45.91626544152537, 43.54812660524922, 46.94533063519386, 47.63439693758565, 42.90514423001198, 43.752929241426536, 43.74896372518232, 46.801112928698146, 43.74399015980382, 49.22238026895831, 56.25863382893225, 55.40166654894429, 55.971732062678186, 53.810498252991714, 54.04815858410251, 50.00946660195628, 50.259098006832986, 51.99052633777742, 47.67145156860352, 43.214736907712876, 42.042893517401914, 39.70937352026663, 40.2501703077747, 40.55760568188083, 46.81624543282294, 51.081062055403194, 53.56016866622433, 51.742452113859116, 53.41598233868999, 54.07410114042221, 53.537960206308675, 42.53060886936803, 45.42331764774938, 46.66386135162846, 53.067903364858324, 55.209968551512695, 52.084325898078184, 45.90709101769232, 48.961350456360854, 53.11401474860407, 56.27322896834343, 54.55821575657014, 59.80193830305531, 55.45075501165083, 50.272841991916785, 44.216086633743785, 54.212933432671335, 57.3360030112728, 50.888932597252634, 43.606848409098966, 43.53458658341439, 42.33405497766311, 46.0298062909034, 54.58018887427546, 58.20694569618472, 58.033161163330085, 57.44834753774828, 41.587863276081706, 61.20554277973791, 62.68736324002666, 60.38886216378982, 59.56966730856127, 61.898484383859945, 58.25102921455138, 35.99903883472566, 0.15112170619108986, 0.0824371740342148, 1.7684430028161697, 18.834666552082187, 60.70650354508431, 56.70700388569986, 63.92634191820699, 53.35532288397513, 61.23885939198156, 57.86967677454795, 59.34127553816765, 53.23647506775395, 32.679829174472445, 38.32259208925309, 40.562712607845185, 42.51306018521709, 15.74683064414609, 0.3373582781322541, 0.2472072728579083, 0.06053197768426711, 0.094763130370167, 0.10979584388194547, 0.01433323214446465, 0.167955722239229, 0.03805270568738061, 0.12596994413123017, 0.014120230015607612, 0.030548535475146868, 0.02465037666561623, 0.019901409114320433, 0.04241534275934101, 0.09846786262407418, 0.05576288883364009, 0.028697810691571044, 0.01984008186076197, 0.1882842789974905, 0.1875537835181721, 30.409673106285837, 61.026098266724624, 34.73140724243657, 42.05432722645421, 54.58449563672466, 42.3321996965716, 43.099674178707986, 76.77585401842671, 62.09478332150368, 62.54362406269197, 60.12884824506698, 64.19271007660898, 61.0669772086605, 48.810347049467026, 0.3665988429659798, 1.6504495278481515, 1.6239545302044962, 9.954706814981277, 47.56322945317915, 48.458239801468395, 56.439506084688254, 53.54090590630808, 59.719615597878736, 61.38508927437567, 62.399241616649014, 61.90360699930499, 63.30259876866495, 60.063627073841715, 60.88122552441013, 62.35124749522056, 58.27857602027155, 51.01833551160751, 47.15561674487206, 45.26437144125662, 46.521393022229596, 47.873010404648326, 49.95289425696097, 59.698556392423576, 60.647922946560776, 59.59886935449416, 54.57918866988152, 55.162260763106815, 50.6894604621395, 52.47192667376611, 59.06766668442757, 59.193845410500806, 57.98064454909294, 51.56819297421364, 49.69273521054176, 48.48448830266153, 46.17222362949003, 53.37105943310646, 54.3062936875128, 57.67062433304326, 57.36488734522174, 57.07618913342876, 49.64756127326719, 43.14276925979122, 39.59369105677451, 43.303896304099794, 44.13317557304136, 46.887106972356, 50.12084622536936, 54.12401330086493, 56.65890778264692, 58.8379648423964, 58.19126798260597, 59.65766960574735, 58.433191930094075, 59.067588237024125, 58.077197613254675, 56.53720840331047, 53.46080326264905, 41.47033337623843, 44.381198806147424, 43.02307421161283, 48.979424738114886, 50.41784417244696, 43.74261340787334, 44.06233364535917, 43.847976115442094, 45.55488963280955, 43.456237239222375, 51.50101454027238, 60.5451411585654, 58.24776972493818, 59.17918359079669, 56.38117651785574, 56.36301202158774, 53.51985454559327, 53.49234304120464, 51.962701043775006, 53.228124341657086, 45.23074496176935, 43.32148421195246, 41.79723155113959, 42.86843868993944, 42.140164375305176, 49.62206586714714, 56.36379649562221, 56.3646476499496, 54.90974249378328, 55.982122421264656, 55.377928364661436, 52.22137743426908, 43.72238966726488, 48.009026435113725, 49.36866506453484, 52.67056726640271, 56.760089243611986, 54.07996116145965, 50.216006848119925, 49.843573877888346, 54.30647411654073, 58.26242762227213, 57.11750738082394, 60.44407736870551, 55.69477742718112, 51.82808529946112, 45.16912452636227, 55.549379087263546, 59.33492522085867, 53.815432594668486, 46.963565734124955, 46.44361242171257, 44.37538193118188, 48.83979620472078, 58.73802677277596, 62.087256293143, 59.994985595826186, 62.43834764726701, 44.1360192914163, 61.801495936609086, 65.27960669609809, 63.717130537955995, 62.31167470255206, 66.08069589061122, 61.62143561147875, 37.66392023332658, 0.5101248333531042, 0.355869505794779, 0.8143715656572773, 22.823095321655277, 66.00943426932058, 59.90357868133053, 67.42821831857005, 60.365688800811775, 65.98542936386602, 62.46407447322723, 65.08442955632364, 58.74726395453177, 41.2552188288781, 41.97548758599066, 44.63261881182271, 54.056289657469726, 19.188293718522598, 0.3213882560451185, 0.2264464433274923, 0.051354152420836116, 0.14232600558428996, 0.013033289146879989, 0.10980198790709819, 0.13914473354816437, 0.029816915761799585, 0.29433830430911434, 0.09830468589620245, 0.12687513063992226, 0.20765205424639488, 0.19138624561169457, 0.18310793014543672, 0.27716399200500985, 0.2089257520293036, 0.13414899758513898, 0.25960602286842566, 0.2615562988625419, 0.3473284528140099, 37.37058185761975, 70.59124900448707, 55.89887403672742, 52.42340303236439, 55.953085114878995, 54.04945688862955, 45.619985288189305, 84.29869328775715, 68.34111859721523, 68.94965863996937, 66.27051507273029, 69.29151673470774, 66.11172183867424, 56.680492585705174, 0.859346442645596, 7.569428201644652, 1.4775731462624766, 13.323470719398992, 57.06301389201995, 46.715130652150805, 57.70368599122571, 55.349852038967995, 61.63229273211572, 65.48614694226173, 64.57436846148583, 65.54067181002709, 65.91024537240305, 64.47020599918982, 65.57876586914062, 65.76409001504221, 61.40360678395918, 56.30074439510223, 48.96833619763775, 48.30778160402852, 49.154182018772254, 49.2007758540492, 52.10745219261416, 62.8871177857922, 61.340958687566946, 61.646283826520374, 55.761112551535334, 54.51873317841561, 49.70789909362794, 53.31431450382356, 59.13097766137893, 61.56000737221011, 59.42886990885581, 54.176773102052756, 53.18573528720487, 51.6135081168144, 49.6918369877723, 56.64686218384774, 56.743509384893606, 62.02673019901399, 61.091990163249356, 61.931428370937226, 52.74594737637428, 46.95153974717664, 42.618670002106704, 46.39071925993889, 46.396524367793916, 50.24923324584962, 53.8680511905301, 57.845448293993556, 61.185891705174605, 62.846117250380985, 60.479845462306855, 61.89132605829547, 61.07492393062961, 62.551978711159, 59.70949980520434, 58.87250131176364, 55.436030434023955, 41.55300517236033, 46.95040225982667, 44.78324959355016, 52.758530339887066, 52.62954711914063, 42.295658896046305, 43.49563744760329, 44.69909514150312, 46.75876702031782, 43.106408888293856, 51.1895195130379, 63.75546386165004, 60.6355635581478, 61.194611134067664, 59.861687767890196, 59.62485113451558, 56.68390504775509, 57.13105132502895, 57.51754991469845, 56.123190464512, 50.08595282031644, 46.25120055290961, 44.864642696995894, 45.947381604102354, 44.85840612842191, 53.2989505798586, 57.143771571497766, 60.19266913014074, 58.56931386455413, 59.6253728097485, 60.55106001515543, 56.473862125027566, 45.78938068882112, 50.65002495242704, 50.74857450300648, 55.421450984093454, 57.85430500584265, 58.52197085657428, 51.70871188563686, 51.62880143811626, 54.37948903729839, 61.42350104547317, 60.2187725036375, 64.27287940056094, 56.95073996820758, 55.268180447240034, 46.59310963846023, 58.58511317160822, 60.3958635945474, 55.65919760734805, 46.925412839458836, 48.90815134971373, 45.506483662513, 50.51981010744649, 61.471071550923014, 64.73749591458228, 61.86718779225504, 64.53357973406392, 46.20586579845798, 63.10074575485722, 64.18139403866184, 67.45499241736628, 62.93241331654211, 70.18304794065415, 62.404426990016816, 44.868529765836655, 0.7234657952381719, 0.8842667312391344, 3.6662408709526066, 25.80565775594404, 74.37593613901447, 68.4340944597798, 76.43489022408762, 66.27451589030605, 72.10547216476934, 69.92402245921474, 70.99781051758798, 67.4285085739628, 44.08903321912212, 49.92181731808571, 54.22117433240337, 64.92062745555755, 27.04064738365912, 0.7031384182553138, 0.401121890472789, 0.20358588937069141, 0.2738680059631025, 0.18544477410614493, 0.23782143940127667, 0.33327175063952325, 0.12350556951376701], [0.052085230126976974, 0.07061473664737518, 0.04725229550874041, 0.04767948145707769, 0.02601542468783596, 0.034177380974494645, 0.01492967468596274, 0.023258569192201383, 0.07800626703688214, 0.049925796807773655, 0.04056663853266547, 0.3393746215489603, 7.766049263938782, 54.181499558110396, 42.25655678779849, 27.792334325851936, 28.2989437349381, 55.911704109561065, 37.264791611702215, 65.97596860701039, 60.037919859732355, 60.88059402281239, 50.77781185027092, 60.556182630600475, 51.49971623574534, 55.269317934590006, 4.940904292368121, 1.5233995453003915, 0.31616442506351783, 0.07593236743442475, 8.379735946655273, 51.32895585029356, 52.64014536334623, 56.619107492508434, 63.7326866580594, 61.77165846670828, 62.99417103490522, 60.52355635550715, 59.270115898501494, 58.636056915406265, 56.330597554483724, 50.35249356300601, 47.526849469830914, 45.155396230759166, 42.782923175442605, 43.77175269588348, 44.25316087661251, 46.333111409218084, 47.67577009816324, 54.63735741953696, 55.697142616395034, 58.924731592978205, 56.78919715266074, 53.2032290581734, 51.970812505291356, 53.79173363408735, 57.02131517471806, 59.69046062038791, 57.43769438036027, 53.397009834166504, 49.96216674004832, 49.00177440335674, 43.26598267401419, 46.61107017147926, 54.02289459782263, 53.61831388165874, 52.47170309866629, 54.76257124254781, 42.363064827457556, 39.09857026992306, 40.13427995866345, 40.84788068648308, 41.9753973714767, 49.958887638584265, 52.92230498406195, 52.60727197893205, 53.980434940707305, 55.01271255554692, 55.74479941398867, 58.33277925368279, 57.47469409819573, 54.40418035753312, 54.6675596698638, 55.995387877187426, 50.632491957756784, 43.0200461418398, 44.74954074428928, 45.79595458122992, 45.76887845993043, 45.36359956187587, 42.028361135913485, 42.376600926922215, 43.30787358745452, 44.356150550227014, 43.71827117858395, 51.486992066906346, 59.050702433432306, 57.796924652591834, 56.04371540008053, 54.86698473653486, 55.660915605483524, 53.308242674796816, 51.68436181160712, 51.985486092105994, 52.44074775326637, 45.08178903210548, 40.73918396426786, 41.58909882268598, 40.80381285759711, 39.65120084824101, 41.73186132984777, 48.79002917197443, 50.54330902714884, 50.558735709036554, 52.057171329375244, 52.805936105789684, 47.16882728761243, 40.22631837475685, 46.82261928435295, 48.04690476386778, 52.25578446542063, 57.65337374902541, 48.28531819005167, 47.71511931573191, 54.335052505616225, 52.7066413048775, 52.08907981072703, 54.902595935329316, 55.17325908906999, 53.60995531082154, 57.01662794236214, 57.08239432304137, 56.44851184660389, 50.67587729423277, 45.989668676930094, 45.13181101891303, 42.08401956865865, 43.52168198554747, 43.35824858757758, 45.263135894652336, 57.012019157409675, 58.186737645056944, 59.72243578203263, 62.682726998482984, 55.11442353648525, 67.23064068825015, 62.42042241557952, 59.35174434415756, 63.68834818563154, 54.41874411798293, 22.376727634860625, 0.46521786239839374, 0.6152221680648866, 2.8637437906957444, 40.00382977147257, 49.705282872723, 52.626028753096065, 51.32329979250508, 58.12033191803963, 56.6344282704015, 60.37174494035783, 58.25296294304633, 50.34642957871961, 26.53994702523755, 62.240569976068315, 41.53081240192537, 45.06036504622429, 6.574087546717736, 0.3913376300084976, 0.1843872203701927, 0.06435549187083399, 0.05970103275631705, 0.10481257983032735, 0.09132850539660262, 0.06795938397126813, 0.05954709121837251, 0.07618894560202476, 0.03688222676094982, 0.023734821156869014, 0.0334964896882734, 0.01570911839559314, 0.0535153170987483, 0.061358073275656476, 0.04239851180764456, 0.03958551738891871, 0.09951805425507408, 0.08619149515946066, 0.37947877280173764, 10.859394631078167, 65.34414929728355, 41.808453452202585, 29.58678141716988, 44.80569339567616, 59.26327528492097, 41.5614539577115, 71.12866078653644, 65.66754479562083, 64.74219491404872, 55.92957835043631, 66.5685602926439, 56.539808934734715, 58.80098081404164, 5.167763396616905, 1.665531776605114, 1.0784858320989916, 0.18042611679242504, 14.230983622612493, 53.09682300013881, 56.48206380105788, 58.92647312533472, 65.2127851978425, 64.99383457245366, 65.82319228879868, 61.03277806312808, 60.81006980711415, 61.025560902011016, 57.94618652712915, 51.52675705571329, 49.8179490335526, 47.4461623930162, 45.48150600925569, 47.219880857775294, 46.34800857113254, 48.46890472596692, 51.57501005357312, 56.52455091476441, 58.38624115913146, 60.02691368902884, 59.00917237804782, 54.45973680865381, 52.25285837727209, 53.15816886963383, 58.45740864353796, 61.0748690174472, 58.030470417391875, 53.79357714806834, 51.57389217807401, 50.03030223231162, 45.33785704643496, 49.23513189438851, 54.534050033938506, 57.35046479009814, 56.24169311215801, 56.17702891749721, 44.38435631413614, 40.835466384887695, 39.441040254408314, 42.86466929220384, 44.62564483765633, 51.42251614601382, 53.75326694980745, 56.83326498154671, 55.20119028706705, 57.21469979132376, 58.58747051608179, 58.297999597364864, 58.020111437766786, 57.14297533035279, 57.14427755725, 58.6243917865138, 50.253641989923295, 44.28673636528754, 45.020741262743556, 45.73204740401238, 48.49632993821175, 48.85346958714147, 40.6217364341982, 43.21308951224051, 43.3410450720018, 44.45319391066029, 42.79147002004808, 52.056049531505955, 61.3786252083317, 60.473710875357355, 57.66484668177944, 54.126645211250555, 58.7009995983493, 56.81923466344034, 53.75011728655908, 58.121908710848906, 53.609323809223795, 48.481699497469016, 44.325391323335715, 43.84593256058232, 42.94144576595676, 41.91801309585571, 43.783955189489554, 50.818647646134906, 54.07785877104729, 54.2384837519738, 54.109457385155466, 54.43363735752722, 50.62436872912992, 43.679835873265425, 46.87373561243857, 48.39957291080106, 54.15389391683764, 58.10754891364806, 51.987925806353175, 49.66677696474137, 54.9285267245385, 55.77763357470113, 52.857781994727354, 58.14304244133734, 53.44600808235907, 57.88522112754084, 58.55885682567474, 61.097281440611816, 58.07182004374843, 52.202506911370065, 48.17125958781089, 46.925303013094016, 43.85394596284436, 45.273439961095015, 46.190466573161466, 49.8324304242288, 57.263803943510986, 61.86938039718136, 61.23763953485797, 65.36572233323129, 56.698778675448516, 67.66582765886861, 63.899155970542665, 62.442438679356734, 64.48146320158436, 57.30745992352886, 24.19578563782477, 0.42877083103502955, 0.8186872147264019, 4.0830645301649655, 46.77491541831724, 56.35457892571726, 59.19330020104686, 58.37800810413977, 63.48506742908109, 63.066260276302216, 65.7319305019994, 69.57581796953755, 54.94061546940958, 40.827296087818766, 64.56124813325944, 41.3755218444332, 57.57150211641866, 9.046044657307288, 0.3157207682248085, 0.15769618082671397, 0.07378520684376841, 0.07293858009600833, 0.01800873527123082, 0.062272023830202326, 0.032039292780081594, 0.017033145282297366, 0.17004177965704473, 0.1860086607836908, 0.17057272455384656, 0.12741059545547734, 0.14606489769874081, 0.13057852223996194, 0.20213113436775826, 0.24902231901163058, 0.22771873150862035, 0.27460109081960493, 0.33689038227162055, 0.713158235434563, 15.768873383921964, 75.80214131262996, 57.07239227910196, 39.21648456204323, 42.04602356879942, 70.31845600374284, 45.549668958110196, 77.14011669158936, 71.56686013744724, 74.4610829507151, 64.67966841113183, 73.94333793270972, 62.55000575896233, 68.5668666901127, 6.992046977243116, 5.769614327338434, 0.592250562002582, 0.2832405707768856, 19.74058108945047, 56.29578651920442, 59.9328827088879, 62.341300364463564, 65.35594778676187, 68.8442410192182, 66.72438037010932, 65.62665016420426, 62.2659477110832, 63.96603630435083, 58.583375561621885, 53.905325474277625, 49.769801939687426, 50.400295488296024, 46.83460212522938, 48.39350500414449, 48.48217018188969, 50.261663236925685, 51.509455480883204, 60.09023643309071, 59.835035262569306, 63.32659582937918, 60.80277027622346, 56.018388655877885, 54.66950908783944, 54.61037151275143, 59.640317040105025, 63.41819494001327, 59.86587685923423, 55.920172506763095, 54.28999231707666, 52.928808273807654, 47.61223162374189, 51.15456335006222, 57.426954930828465, 58.43343119467459, 58.79531691151281, 59.015510928246286, 47.180441425692656, 43.767869549412886, 42.69462277812343, 45.35105974443498, 47.786173051403416, 55.74565841305641, 56.057200508732954, 61.26778687200239, 57.419427902467795, 59.246083536455714, 62.83952766849149, 60.183949701247684, 61.73560011771418, 59.36079717451527, 59.17698706350019, 62.42985963821412, 51.76185215673139, 43.648033295908284, 44.33784092626264, 46.8469968149739, 51.9536482134173, 50.0694670984822, 40.26559698966242, 43.058081365400746, 42.88905858993531, 44.36316767046529, 43.03728495874713, 54.61625114563973, 65.02175008097004, 64.49590144618865, 60.48741171436926, 58.26991542693108, 63.13936541157385, 59.56307772667178, 57.31863867851996, 60.10686728262133, 56.572933350839925, 50.51520916723436, 48.63370310875678, 46.62088001928022, 45.40156026040354, 44.61046918745964, 48.167517646666504, 54.59717665949176, 57.45749842736029, 58.42921464673935, 58.24336490323467, 57.8895475018409, 53.633646426662324, 44.28635589538082, 50.2416120806048, 51.27516838812059, 57.30323945322345, 62.2827942909733, 55.342113202618016, 50.98880790895032, 56.80169774639992, 57.602418238116854, 56.78800082975819, 60.649013365468676, 57.78803263941119, 59.35292105520926, 59.98726637132707, 63.095199523433564, 61.524502077410304, 53.58373426621961, 52.02578060088619, 49.6277258473058, 45.892950873221125, 46.75236178982643, 48.4482495246395, 53.03800705940493, 62.14057699326546, 63.53330081509006, 65.4967059627656, 67.48679499472341, 58.65898316906345, 69.69678386565178, 65.70288142850323, 62.79145117728942, 67.54414004664268, 59.53715085983277, 30.150692732103412, 0.8397825182445589, 1.868156149022041, 5.102869743301023, 52.86539531523182, 62.0701273026005, 66.82520881775888, 62.19787889911283, 69.77803968614148, 67.3313279305735, 72.71636562962686, 71.93339778530982, 64.11024224373602, 41.974503071077415, 73.26619563564178, 51.99034590874949, 69.08325456803846, 13.331167390269618, 0.5820747080349153, 0.28237795577414576, 0.27602561599304604, 0.22064061534981574, 0.18296888518717982, 0.2633742867938934, 0.19956470917790167, 0.15469861667483084], [0.028989987049792564, 0.0663380814535964, 0.036709113872700164, 0.0782336266110501, 0.0069772089726381735, 0.04084667431250696, 0.05351996725244869, 0.03154836640122437, 0.07965648937369547, 0.03968373369125109, 0.10751351473792907, 0.09048335719853641, 0.24459662907306226, 36.6121837400621, 45.62608457380726, 40.89466279552829, 26.299633210705174, 51.350521041500954, 41.20558907908779, 55.59287817247453, 62.585973893442464, 59.64321567166237, 64.99558002718034, 60.32658669256396, 53.273102160423036, 61.369325268653135, 23.965042406512847, 1.7762518289589115, 1.2678934104980961, 0.1429292232158684, 2.3696138926090735, 34.93019296276954, 57.996290883710316, 59.59551180562666, 61.0171042719195, 59.370022589160556, 57.907080496511156, 53.19630999718943, 51.317573132053504, 46.55369374059862, 47.73528029841762, 42.37600080428585, 45.303571608758745, 44.719573836172785, 43.431153681970414, 43.847042591341086, 45.689297491504306, 46.37695958537441, 46.83656723268571, 48.12763106438422, 53.565236368486964, 53.76684227297383, 57.09378488602177, 54.16922646184122, 54.307615526260875, 52.61134732154108, 56.683234322455625, 59.683298372453265, 58.11297355159637, 52.197352916963645, 50.14075617636404, 50.46828585286295, 44.58276548693257, 43.68899460761778, 50.49058844966274, 53.174870321827555, 56.50323283287787, 51.06270928536692, 40.15504106398552, 38.146873827903505, 40.83802769261022, 42.25050849299277, 47.04844974702405, 51.49279717476138, 54.864894113233014, 54.955704827462476, 52.83616581270772, 56.21470720537248, 57.721921090156805, 53.96531028132285, 55.52999081150178, 55.81718283314859, 54.28614054956744, 56.185795414832334, 47.85956451969762, 42.082615360136955, 45.051390663270034, 43.16642115193029, 44.015916316739975, 46.74815308663153, 43.97537469863892, 43.101419633434666, 43.75895400201121, 44.21599641922982, 46.448884087224165, 48.1882316835465, 56.99561580534905, 55.599444220142985, 52.212332448651715, 53.841837990668516, 55.67823679216447, 54.514799041132775, 53.236125976808616, 51.68009427285964, 51.82132705565422, 51.087180952872004, 45.791541914786066, 43.21228150398501, 41.653900300302816, 38.30606714371712, 40.89609838301136, 43.42030048370362, 50.363519345560384, 49.337595970399924, 55.051673458468535, 51.128518812118045, 42.19176707729217, 43.672740305623705, 45.794307185757546, 48.59338898812571, 51.80505706417946, 52.94142261628182, 55.4227061425486, 56.54445302101874, 53.37391099622173, 56.874995077809984, 50.84389986530427, 51.35613003084737, 50.501575008515395, 52.24999896941647, 50.5655017975838, 48.142594906591604, 46.15908761178294, 46.027233216070364, 41.83915776591147, 41.828049613583474, 41.06448965687906, 41.337129685186575, 41.02102587299962, 42.192508405254735, 44.14660969088155, 51.15777969360352, 57.00268783876973, 57.264698243910274, 62.00529836839246, 50.85629847741897, 57.114993141543486, 61.01149528257309, 57.911736349905695, 41.21515573993806, 8.659799060513897, 0.09896781926433887, 0.9235504329685242, 4.78228021052576, 48.033807969862416, 48.017455608614036, 52.760758246144945, 56.92046319284747, 58.39594118056759, 57.00075803264495, 58.885598105769006, 49.28928805935768, 41.26611125084662, 23.713173289452833, 37.49264601738223, 44.88604707102622, 39.19068321104973, 1.1719777314893662, 0.022822042716847315, 0.0682992665397544, 0.06983630704663454, 0.06166851125477303, 0.04125983319095066, 0.01820489208424284, 0.03664860441800087, 0.011963050910121491, 0.0485030259756792, 0.04130310183691402, 0.008581337714267355, 0.020803782165110595, 0.010043205843577463, 0.04147883857630434, 0.03419127780944109, 0.029503248722082185, 0.06359544454983647, 0.019754111473899216, 0.04826384566483959, 0.1001770890528156, 0.8219144060727089, 47.88549923127698, 51.61628123252623, 27.764130523127896, 37.39234316733576, 59.32637445388302, 41.58194441949168, 65.36984866665256, 68.0032064068702, 67.77470481011176, 70.99137783050537, 66.04711255719586, 57.08576363901938, 65.86651094498174, 26.09278701966809, 0.7908180392076893, 2.5020416898112146, 0.4491637851442061, 4.110929783313505, 39.97543965616534, 62.691262075977946, 62.33784083397158, 63.51879981256301, 61.38196314534834, 59.44131558941257, 55.49679579273347, 53.982160783583126, 49.896078725014966, 49.534224387138124, 46.339916721467056, 47.2605715259429, 47.022009049692464, 46.149854352397305, 44.64696684191304, 48.09909582138062, 46.63127430023686, 48.61847254537767, 49.782600633559696, 56.4167445705783, 54.84634130231796, 59.00737201013873, 55.5426129987163, 56.41367727710355, 54.04911956479473, 59.46539894227059, 59.147686958312995, 57.75622221731371, 55.43787394800494, 51.06348199229087, 52.58309056681972, 47.87958037468695, 44.87306010338568, 52.12005476797781, 57.018157666729344, 58.58122218039728, 52.752882126838934, 43.301201635791415, 39.710793418269006, 43.198102135812086, 45.05577195075251, 48.76462790273851, 55.36170936399891, 58.60643909823511, 56.47800807029971, 54.60075778345908, 58.90702993639054, 59.2220550967801, 58.27186876727689, 56.48387201370732, 58.28192964676888, 59.54387772467829, 56.58333155416674, 50.1312836523979, 42.41636983809933, 43.56356505424746, 44.4222620994814, 47.71028303330945, 47.24095967508132, 42.99599024557298, 42.9002098883352, 43.5982152723497, 45.013594704289595, 44.22246048527379, 50.41668707324613, 60.52410548733127, 57.66418772359049, 55.67247875275151, 56.356908813599624, 56.64108453258392, 55.65468295927971, 58.15822985864455, 54.63528248571581, 55.601762340914824, 51.89319664432157, 47.455105397009085, 46.15539273908062, 44.26774032654301, 40.54484228934012, 43.23827897348712, 45.605970659563624, 53.041658786035356, 52.26197004318238, 56.845718506843816, 52.48192087296517, 43.82831327376827, 44.53330832142984, 49.10577212610553, 49.59496621162661, 54.22257461855489, 53.42433698715703, 56.365392900282345, 57.712111242355846, 55.998043321794086, 58.11332656491188, 53.88616469598586, 51.449019601268155, 54.06532679834674, 53.41741400380289, 51.898695807303156, 50.852595759976296, 48.46372719733946, 48.70481567998087, 45.314785665081395, 43.252513254842455, 43.25199942434988, 43.25549817854359, 43.35965279609927, 45.32807073285503, 48.07180789209182, 55.00911181972873, 60.619513219402684, 60.36644581825503, 65.83953288293654, 54.29070618844802, 58.118723746268984, 64.56182864404494, 58.48557910611553, 44.19805157569147, 10.886751201844985, 0.04760882133738168, 1.6746460165708297, 7.254474134214464, 57.08065279068486, 55.00294585381785, 58.832469601784986, 62.88667455796273, 63.86043825457173, 63.88881268039827, 68.98096699868479, 56.2530993646191, 47.21541327814902, 36.54438557163362, 38.97863987953433, 48.591078712094216, 47.90123185803814, 1.6053452126441465, 0.1166122950493328, 0.05440616627193747, 0.01407045728316711, 0.05682119333575811, 0.11168190638624853, 0.019938671630957437, 0.027227195753385464, 0.09777171086640128, 0.1747888588016072, 0.20217389739569158, 0.19339929485032636, 0.25316132352717463, 0.06981167731986893, 0.10605150488235297, 0.18923015243584113, 0.12100425413659505, 0.35997904656875523, 0.1998772883727666, 0.19319743068227846, 0.30160455634036376, 2.04540585077578, 61.59824655902002, 62.932193663812455, 57.02369213104249, 39.144430621977776, 68.01669936026296, 51.439515698340635, 70.06976204533731, 75.8412394985076, 73.29783347345167, 74.89640328191942, 70.80244510404526, 65.84977026908629, 72.04803297596594, 30.7891212355706, 3.8966038775059486, 6.610039991717185, 0.32467397650884045, 5.518808172595117, 49.40711998170423, 59.75731741997504, 66.75779896397745, 65.59783643291843, 66.4562471451298, 62.58720551767657, 59.315164319930545, 54.58972023379419, 51.52994986503355, 54.03367327105615, 48.048944396357385, 49.74690314262144, 50.9687332184084, 47.543837255047215, 48.7917628595906, 49.97810333005844, 49.809453179759366, 48.48952070359261, 52.74812429181991, 58.12632922203311, 58.500225236338956, 63.5507788965779, 56.65809192965108, 57.323675001821215, 58.21553568686209, 61.01475084981611, 63.288238971464104, 64.80201498154672, 57.139492265639774, 54.332808909877656, 55.012057519728145, 51.6977959294473, 47.07166625607399, 55.191753064432454, 59.2930813758604, 61.62316929909491, 55.629591557287405, 45.34603126587407, 42.43670732744279, 47.17371848321731, 46.64452014430877, 50.3535996713946, 59.32248738504226, 61.11521451703964, 60.358667758203325, 57.26569060356387, 63.06475408615605, 61.971969989038286, 59.965516828721576, 59.058354977638494, 61.60054114557082, 58.72997806918237, 58.630228273330204, 50.82669634972849, 42.67138273485246, 45.04999037711851, 45.04628765967585, 50.073416925245716, 49.80976304700298, 43.068781591230824, 42.90548155384679, 44.25252937501477, 46.14724597623272, 46.30420746341829, 52.11269640153455, 64.40135663555515, 61.85338104924848, 58.32379310361801, 58.9590484096158, 59.28280084363876, 60.98004179616129, 61.70103619175573, 57.96405684563422, 56.6796963445602, 57.13249867962253, 49.15175407163559, 48.82921364999587, 46.04564089928904, 41.96563459211781, 45.74257896792504, 48.25497473439863, 55.23594248679377, 53.49674786290815, 60.39431033595916, 56.025770556542184, 45.490802026564076, 50.42699898442915, 49.776438590018984, 52.706292213932166, 56.231079178471724, 56.68354811206941, 57.538558129341375, 60.355223917192035, 57.17338938866892, 63.02136482730989, 55.77780223661854, 54.81674701936784, 55.715181596817516, 56.72490558316631, 54.42491792863416, 52.62081984550723, 50.7655309092614, 51.66299273890834, 47.25686880850023, 46.39159394848732, 44.741805830309474, 46.37191541733281, 46.129242297141786, 46.44149041944935, 49.1639800994627, 56.89417154558244, 62.05259038556007, 65.54693583519229, 68.53695469517862, 59.081261619444824, 60.20642095996488, 65.93902772472751, 59.97214563431279, 49.7748068840273, 16.36030600916955, 0.38134744511015956, 2.262187037737139, 7.470291766428179, 65.09610252995645, 60.420135221173695, 66.65223229315974, 69.54910662866408, 70.60560487931775, 67.69559844847649, 72.63610609116094, 63.199954263625614, 56.128050281155495, 36.16416277423982, 48.25408043399934, 59.0676627620574, 62.061929548940356, 3.489596439946083, 0.3704041855469827, 0.1784491043297514, 0.3123392561270345, 0.16935323515245992, 0.18660158219356693, 0.09806321498246924, 0.11689863573279112, 0.18337477389122211], [0.026338685063585162, 0.034787309536289786, 0.03923436949750589, 0.02206728906340657, 0.050082362196858854, 0.06321770574657187, 0.014316300643728146, 0.04957005238881515, 0.10457447970346098, 0.03894822799690789, 0.03517498833037192, 0.00667530473419315, 0.23545246571302417, 29.889549170770955, 51.56963248406687, 41.98240664697463, 22.010427290393462, 41.903300285339355, 57.67302482358871, 39.18612933927967, 67.2075536174159, 55.22053149438674, 48.50248021464194, 57.8641305431243, 56.50062837908345, 54.915771176738126, 42.91103955238096, 0.1416311178716921, 4.470464039233423, 0.25498747795579896, 1.4695685693333227, 25.86889224667703, 61.07732442117507, 62.261817455291755, 59.81559207362514, 58.02889754695278, 54.44824426404892, 49.132428553796586, 48.2449766128294, 45.936932409963305, 45.4700566107227, 47.58497899578464, 46.81998345159715, 48.474823582556944, 48.85565434732745, 47.94838266987955, 50.05235771979056, 47.28028535842896, 48.59134151089577, 48.306667650899584, 50.86387649659188, 52.64636624243952, 54.35104008643858, 58.665262883709325, 60.298741786710686, 56.442306656991285, 60.16113719632549, 56.919015838253884, 57.48542178061701, 54.2135610118989, 50.28930810190017, 49.84033400012601, 46.385702548488496, 45.04152590228666, 45.638506720142985, 50.48106885725453, 51.447540867713194, 42.212598785277336, 42.938503988327525, 38.15456951818159, 40.81997694507722, 44.610163242586204, 51.31502751381167, 51.061207017590924, 55.01324207552018, 56.69572314908428, 54.59146961089104, 55.59085030709544, 56.14201784133912, 56.773284096871656, 54.178612693663574, 56.56903059251847, 58.8965375961796, 54.90259201295915, 44.67099528158865, 42.50155195113152, 43.46152067184449, 45.8552098274231, 45.57244616170084, 48.65175777865995, 42.58819318586781, 44.009354191441695, 42.646228574937396, 43.04466293704125, 43.16933547296832, 47.39448124362577, 56.08746551698255, 55.922278819545625, 56.06635924308531, 54.87559826143327, 51.16693842795588, 55.024397296290246, 53.790658904660134, 52.09778747250957, 51.32282518571424, 51.81086217203448, 50.65475925322502, 43.70130300521851, 43.580764647453066, 40.027313001694225, 38.68947882806101, 42.41431059375886, 44.88910651976063, 51.21803906656081, 51.39053706199893, 46.39773245780699, 43.263229170153224, 45.087241126645, 47.175612988010535, 49.44751254973873, 52.3719415357036, 54.319206130120065, 53.504835790203465, 55.87939162408152, 56.373308243290076, 53.41764542364305, 53.534249644125666, 52.2640214427825, 46.20939593161307, 42.09693593363608, 43.03594743051837, 45.19209784846152, 40.64009704897481, 40.503151416778564, 42.007062665877804, 44.903560453845614, 43.331243068941184, 47.22352473966537, 45.56740199365924, 46.30221097700058, 44.46878140972507, 43.14227504114951, 48.87027302095967, 55.96134954883207, 55.027978420257575, 61.12391041171167, 57.020095317594475, 58.986685429849935, 51.59058186315721, 29.119389826251616, 8.742018803473442, 0.2817611017775151, 1.2094489917639764, 12.386126229839942, 56.98306029842746, 45.465322309924716, 54.69381601579728, 54.484330069634225, 60.760871518042784, 56.406789595080966, 56.86724839671966, 59.44729720392535, 38.73806130501532, 24.62188839912415, 39.94527270717006, 49.726444059802645, 26.614644642799135, 0.3105097768768188, 0.08560998845965632, 0.07484703535033811, 0.054130232892930515, 0.07186562799277806, 0.09543030102166439, 0.03886050326869853, 0.06929831414092934, 0.03169858092141729, 0.005510970311720045, 0.03449467544053351, 0.09764811790157711, 0.030279676918120637, 0.027602270485893376, 0.008997996656915114, 0.03396600965530642, 0.04516681648730751, 0.11598410295142282, 0.06964321458531965, 0.06484643931710912, 0.03750478045173711, 0.11513509367021824, 36.9098759466602, 61.350658709003085, 39.55099605744885, 32.814890107800885, 56.33011510295253, 56.51252492781609, 46.30690997646701, 75.80829158906015, 63.28765453830842, 55.40654989980883, 62.80330457995015, 62.86399149125623, 61.68873956126552, 47.22848261556318, 0.3923524207165165, 2.306625040308122, 1.1158596459896335, 2.2061348970859282, 31.30935891982048, 61.562243123208326, 65.7384181022644, 62.096838643473966, 60.92000599830382, 56.43610538974885, 51.786559166446814, 50.078123769452496, 48.15396978009132, 48.54606559199672, 49.298085935654186, 51.03915545248216, 51.147173604657574, 51.59008372214533, 51.03372296979351, 51.64217279803369, 50.26491488179853, 51.73272855820195, 51.65819175781743, 52.20964562508368, 53.31958616933515, 58.58883942327192, 60.68080809808547, 61.09381406537948, 58.66446272019417, 62.19880850084367, 58.75790142243909, 58.16532934865644, 55.3641765348373, 52.0912528038025, 51.34525722072971, 47.06544145461052, 46.73777841752576, 46.58709272261589, 53.88103815817065, 54.48449873155164, 46.429954728772564, 43.27198390037783, 39.86894338361679, 41.97449914870724, 45.43761468702748, 51.88162565231324, 53.870079055909194, 57.315955777322095, 59.01369879322668, 57.608140976198264, 57.27178988918182, 57.4980047441298, 58.90417837327527, 57.567760175274266, 58.815352378353, 60.36518281505954, 56.98018912346133, 44.8858666419983, 43.49355466904179, 43.6950703590147, 46.00561703405073, 49.48810515865203, 50.11440177117625, 42.00055545376193, 43.30965826588292, 42.576830079478604, 45.54686054106682, 42.52552939999489, 48.46137377523607, 56.44752340932047, 60.25387771667973, 57.53820511602587, 57.420769353066724, 55.1044411043967, 57.84934320757466, 57.51772249898603, 55.62968569417154, 54.244649717884684, 56.08588872417327, 53.078760485495295, 49.32024732712777, 44.536905134877856, 42.591087895054976, 41.13359005220475, 43.73576887192265, 47.94091839944163, 52.84181010338568, 54.54511111782443, 49.24768347893992, 44.081204168258175, 45.9391289372598, 50.025532630182084, 51.40383781925325, 52.7229779766452, 55.14195073035456, 57.17387184020012, 57.67023209602603, 56.44537787283621, 56.49789056470318, 54.84308965744511, 53.63550170775383, 46.90219240803873, 44.38088501653364, 44.904948972886615, 44.622193151904696, 42.88890561749859, 44.19417235159105, 44.4150645502152, 47.046433648755475, 46.26453661149549, 51.08158765300628, 48.54377885018626, 49.63340543931531, 48.20372896809732, 45.04562477911673, 51.448054698205766, 58.181830759971376, 56.95273645462529, 65.85088422221523, 57.69461747138732, 59.02158275727303, 51.43145130526636, 34.03920304390692, 11.100198741882078, 0.38201942679382145, 0.5738717449768898, 14.939556852463754, 61.71395647910334, 50.763153952936975, 62.695149144818714, 59.489827463703776, 66.59462052006876, 60.9481607714007, 63.91488467493365, 60.70188299302132, 47.52503733481131, 39.01124654277679, 33.00727059764247, 60.69035906945506, 32.448903552947506, 0.17801457925909953, 0.10058732147538856, 0.038074608141135786, 0.08245148455664035, 0.0312509729842385, 0.07020714722814099, 0.019656644022512822, 0.057855779755740404, 0.07395996682105527, 0.09293126858650677, 0.11863698882441367, 0.15004775817355803, 0.12824718645142932, 0.1495057509671296, 0.1488191216823555, 0.09370855671624023, 0.15462665037522394, 0.23260252670414988, 0.21442877609402905, 0.20034392784920432, 0.10762848921360509, 0.5525547662569631, 49.0693058506135, 71.21485094870292, 58.14578810045796, 31.558274492140743, 55.23146706242716, 68.17047980523878, 49.33287735908262, 80.55608534043836, 66.83998046382781, 62.87124787607501, 66.83000979884979, 70.08798537715789, 66.37146119148501, 54.98431067312918, 0.35305590999703257, 12.051882436198573, 0.8643811724839673, 2.9986907301410555, 39.70578062918879, 63.74860363621866, 70.39524816697644, 62.27436511747299, 64.86711848166682, 59.737968367915, 55.08864571971279, 52.52229382914882, 51.50926720711493, 51.08651414994271, 53.09262606405443, 51.834965136743364, 53.651952128256525, 53.40916133696034, 52.792156819374334, 53.25966412021268, 52.5559752218185, 52.985765011079856, 53.63723147299982, 54.205123993658255, 55.95346558478571, 61.06591816871398, 63.591975550497736, 64.0918973184401, 61.10924859200755, 63.49551662322014, 59.82227971476894, 60.642541454684356, 57.592702527200025, 53.8518282674974, 54.392142603474284, 48.928065223078576, 49.50814454786239, 49.150240036749075, 56.561683993185724, 56.9824601757911, 47.95673731834658, 47.37910947492046, 42.43767223050518, 46.02669192898659, 47.819211175364835, 54.43882273089502, 57.82533830212009, 60.48499945671328, 62.04622045640023, 60.0271882549409, 60.15483394745858, 61.39252608822238, 61.35445948570006, 58.2827494221349, 62.604279595036665, 62.72366869834162, 57.89020253765968, 44.57502665058259, 43.62720551029329, 43.15743107949534, 48.80964494520619, 51.310367738046956, 52.89819025224256, 44.38897294382895, 44.73156452178956, 43.700483229852495, 45.810816441812825, 42.22100442455661, 46.15125463854882, 59.28982580861738, 61.46632156064434, 60.867889465824256, 60.732881484493134, 58.0955699951418, 61.282021153357725, 61.432612711383456, 58.44638678335375, 57.176809695459184, 59.38006777917186, 58.50005657442155, 51.06220722198487, 49.15718263195407, 46.33904987765897, 43.380088344697036, 46.58266436669135, 50.83609434866136, 55.79226793781404, 55.25216540982647, 51.50831799353323, 45.22979182581748, 48.5676464726848, 50.76195763003442, 53.88566655497397, 56.85696786449802, 58.409979343414314, 58.18471370204803, 61.87491093912433, 59.89116437973515, 58.032129579974765, 57.439749702330566, 57.23958330769693, 50.40455125993299, 46.28401902414138, 47.43831765267157, 48.05554574535739, 45.10775512264621, 46.680958963209584, 47.38253762645107, 51.43252995706374, 47.890484563765995, 54.086460528835175, 50.3910896855016, 52.60593052833311, 49.397141471985854, 46.87768151683193, 54.38834967151765, 62.000030625251036, 58.3510692657963, 68.40061310798892, 59.569965408694365, 60.577830191581484, 55.9136966736086, 43.22328767468853, 13.79967293431682, 0.5883709088929239, 2.379487478925336, 18.35438605277769, 71.5298721867223, 56.53970695311024, 67.06199446032124, 63.25422809969995, 72.62051074735581, 67.09044733355123, 69.52575283665811, 69.64227076499694, 51.142074523433564, 37.96793922301262, 56.25061258192986, 68.19249214664583, 44.68518641687209, 0.4233879908438652, 0.25124110882320716, 0.12253223182333094, 0.2089751340569027, 0.14203910565664693, 0.2367847998656573, 0.14770685394685115, 0.23038320063102632, 0.17942350688240222], [0.012348352916418545, 0.019208775615439783, 0.01964407251967538, 0.027083910498467666, 0.09594936389476062, 0.03394879565964784, 0.0441831978969276, 0.040088783529016285, 0.08231459230545067, 0.049068739772924495, 0.04054314261602779, 0.1968923646716341, 0.2898201322363269, 13.380236241125292, 54.75864495000532, 45.45291977543985, 31.841304879034723, 30.50456504667959, 57.79707370265838, 52.76784596904632, 54.23720505929763, 56.51203855391472, 55.65775025275446, 58.41236414447908, 59.77141834074452, 53.535089031342544, 52.80226868967856, 9.063858101444861, 2.8899640998532696, 1.4841565994485733, 0.7126233222023134, 16.674054438068023, 55.36458053896504, 63.437387097266416, 60.62032515002836, 60.64569111793273, 59.21261002940517, 59.02876853942872, 57.61507180429275, 57.03608289841683, 55.08966945832776, 55.320540166670284, 54.78465026424777, 56.07338028569376, 56.57049755896292, 57.228310415821696, 57.800466552857436, 54.70298259488998, 53.72993669202251, 54.38637279695081, 55.491316241602746, 56.450755442342455, 54.476681447798214, 57.6486708271888, 59.1300323701674, 57.59594240496236, 58.750766631095644, 57.34319271579866, 56.751624768780125, 56.73751600327031, 50.64158793418638, 51.957205803163596, 48.366193540634654, 44.02357670568651, 43.39146321819675, 46.04280502565446, 46.66363777652864, 42.02860040049399, 38.89636032042965, 39.40855910701137, 42.14695007570329, 47.51546282922068, 53.11445405406337, 51.734160223314845, 55.06355431772048, 54.52301248427361, 55.49696053228071, 54.03750150434433, 57.103657491745494, 56.295527642773045, 57.232071968816946, 57.85200649692167, 56.9134460726092, 47.12308460666288, 44.66272692526541, 44.53978023221416, 44.954068814554525, 44.70334306839974, 48.115032411390736, 51.782778001600704, 45.266705251509144, 44.663774198101414, 43.47812014241373, 42.84065261963875, 43.581156884470296, 45.628681182861335, 53.741946989490145, 57.20874563340218, 56.60617543805031, 55.42963697064308, 54.33517017672139, 54.776515268510394, 54.11992619114538, 54.66602602312642, 51.18822513088104, 52.14201219620244, 50.053577576914144, 49.154429128093106, 43.831392334353545, 40.74802498663626, 39.597817390195786, 41.737336958608324, 43.4343857149924, 45.538796147992535, 45.421768311531316, 42.892494586206254, 43.458606350806456, 44.374224831981046, 46.524421092002626, 45.959595864818944, 48.74524354934693, 52.58603626681913, 54.08942976305562, 56.288341860617365, 54.270407922806285, 54.78013953854961, 52.948506416813025, 50.37290949975291, 45.18841082049955, 41.635163137989665, 41.66303550043414, 40.22920523920367, 44.34899222466254, 50.295697642910866, 50.979264782321074, 52.660282811810895, 55.49991407702046, 54.6160001139487, 51.337275197429044, 54.70244915254655, 50.88603004332512, 53.45483733761696, 47.791346657660704, 52.995661151024606, 53.28514383685205, 60.927756601764315, 56.64357523764334, 61.26653171354725, 35.439728460004254, 16.693746697518133, 10.256177244647857, 0.5275184613081717, 0.7943326667431863, 25.584506680888516, 54.67227828118109, 52.610809956827474, 56.025590127514256, 49.659873593238096, 56.29938725502261, 57.37117490460796, 62.593226355891076, 52.10369456198908, 29.643340033869592, 20.176287774116766, 39.23525702568793, 50.62041497999623, 10.00413554330026, 0.28194496287934245, 0.13488678622149652, 0.0594432135262797, 0.030112386298095508, 0.03938493641814397, 0.05584953720831583, 0.050240471253111485, 0.02591897804860867, 0.05125219377899363, 0.06552936073632971, 0.024595170454572768, 0.0751638510114243, 0.027673087653613863, 0.06793813269224859, 0.08623839506218511, 0.0441274841526343, 0.05579407627303755, 0.011512715699932268, 0.07516498482155223, 0.08954273912334636, 0.06941276767681684, 0.21687763743102553, 20.345112469888505, 66.5841713259297, 42.470376953001946, 30.904607580554103, 45.785336725173465, 62.13765874985726, 56.15644039646272, 61.73554128216159, 67.22074847067556, 59.98254776000977, 66.31290804955268, 65.16048823633503, 59.52704683426888, 60.7073272428205, 10.433473279399257, 0.7721853712874075, 3.2680766620943626, 0.33028287392470146, 22.590420323033488, 56.78993063588297, 67.55458139604139, 61.22833175043906, 64.23629545396375, 61.7397342958758, 63.72241397057811, 60.18544020191316, 60.12568289233793, 56.051211049479825, 57.17268336203791, 54.724743904605994, 58.66893814456079, 60.263609117077245, 60.15581846237183, 60.9651917026889, 58.93199974490751, 53.6537132724639, 55.86320792475055, 58.20524338752993, 59.020821817459606, 57.13642104979485, 58.864864457038145, 60.9302943752658, 59.268899963748076, 61.13668164899273, 57.71865375580327, 58.20330965903498, 59.757360566046934, 51.543721306708555, 53.49758332775485, 50.465014596139234, 46.211717974755075, 44.01356681700676, 49.3219574805229, 48.694268426587506, 43.72542950414842, 42.90750941922588, 41.83363114633868, 43.69319546607233, 49.718301219324914, 54.98717400335497, 54.01823482205791, 57.82435378720684, 55.80598446630663, 57.66509379110029, 57.00997560254989, 60.174218300850164, 57.612702692708666, 60.26550362187048, 58.37201472251647, 59.67805024116271, 47.943683670413115, 43.98743206454862, 44.38035549656038, 43.55690879206504, 46.46083947150938, 49.53529911656534, 55.29646858092278, 45.03391258178219, 44.40696877817954, 45.08039266832414, 42.74854752325243, 43.96376056055869, 45.24610104099397, 55.492241920963416, 59.94484986028364, 58.11902969114242, 57.275916222603094, 57.20505860544021, 55.81567664300242, 56.98288379176971, 56.93407773971558, 53.49250778075188, 54.64373911580732, 52.37398509056338, 50.670797824859626, 45.74149247138731, 42.6257263460467, 41.877589148859826, 44.87537822415752, 45.685092710679584, 47.69080454303373, 51.439762807661495, 45.660452381257095, 45.07853738723263, 45.027393602555804, 48.75565351978425, 47.95000653113089, 51.34951299236667, 54.34483097445581, 56.09539654947097, 56.604112271339666, 56.59634597839848, 55.552807238794145, 55.69831148270638, 53.61339522946266, 47.939706387058386, 45.14736713901643, 42.81412955253355, 41.61098564824751, 46.636581267080004, 52.8706395241522, 52.2248879555733, 56.67575828490719, 57.30587528597925, 59.47263963760869, 55.072873869249904, 57.26693007253832, 53.799837250863355, 55.99665088038291, 51.07736718270087, 55.43440265040244, 58.34604078723539, 61.842629832606164, 59.69744636166481, 63.61235226354292, 38.63015297920474, 20.743542909622192, 10.251621411692712, 1.1314298621108456, 1.4809608483506789, 31.51615215886024, 59.819596813571074, 57.74136820147115, 60.85302760524135, 54.49165313474594, 64.36369795953074, 62.50201163753387, 68.66467491272958, 55.97118293085406, 39.797705296547186, 23.307547261638028, 38.43795684076125, 61.47011841497114, 11.815189949927792, 0.15550236548146895, 0.16910799508613927, 0.06817526754833038, 0.12925841485060033, 0.0692244479432702, 0.04063808772292349, 0.1457356177871266, 0.005648756491756368, 0.05067401190078066, 0.2518512518896211, 0.07820746470843593, 0.18364082090556624, 0.23068419657647612, 0.195209177571439, 0.2229746247852041, 0.15303386165009392, 0.2187952167925335, 0.2008279881650402, 0.23781740977879495, 0.254873576003217, 0.40742376038143713, 0.36266102846111026, 26.680852290122743, 76.97298449854698, 56.39005284155569, 42.50305029653734, 46.130744564917784, 71.4993953704834, 63.42170938368767, 65.61323565821495, 71.39699797476493, 71.42374069459977, 70.20038481681578, 71.97816771845665, 64.35497853063768, 69.2486922971664, 12.216219940493184, 5.955312569295207, 4.9941004572376135, 0.8292062147971123, 28.661413884931996, 60.19150026382939, 69.78432332315754, 68.49653859292307, 67.19625719131963, 65.402545544409, 65.8651538049021, 62.88449372014692, 63.48815041203653, 59.45129409913094, 58.35243032824609, 59.58711401108773, 61.70896330187398, 62.18165205370996, 62.0561283634555, 63.802724499856275, 58.513973143792924, 57.822651478552054, 58.65000878610919, 62.156619487270234, 62.0621923477419, 58.65120118664157, 60.603906108487045, 61.98288594522784, 60.0528327111275, 64.9226749327875, 60.70894718170167, 60.45740950492121, 62.65284246014011, 53.875162447652514, 57.36287124695317, 53.58184760616672, 47.74929884941348, 47.30438832313784, 50.26538164384904, 51.23073970117877, 46.95071604944045, 43.722052343430065, 46.12382158156365, 46.47756053555397, 50.954675443710826, 58.02923879315777, 56.58720293352681, 59.87886774924494, 59.25652096348425, 59.55323649990944, 59.91586354471023, 64.0966159297574, 61.6746307957557, 63.90451392819805, 61.47453500378517, 60.840311281142704, 48.230695263032, 43.82516361051991, 44.401359788833126, 44.8414340326863, 46.8572969590464, 51.30597860582414, 59.9240416865195, 46.744724935100926, 45.34618816068096, 44.449349987891416, 42.52877320012739, 43.58350246183334, 46.544374189069195, 58.06618359781081, 63.257911205291755, 62.65654909995295, 59.35307402764598, 59.87602795324018, 61.33973883044336, 59.66100754276399, 59.84188764326034, 54.79372270645634, 59.24432631461852, 56.484538816636615, 53.667355275923214, 49.495412534283055, 46.63585562859812, 44.500964456988925, 46.91148450297695, 47.59364351149529, 49.98744249343873, 53.195145053248254, 48.43305818496212, 48.913089613760675, 47.881000272689334, 50.30551925782235, 48.228435977812744, 51.294713558689246, 56.382008060332275, 57.95403126747378, 59.211033236595895, 57.10364572463497, 57.92684139743928, 57.52914051855765, 54.414978642617505, 50.261988793649984, 47.20356772022863, 47.540397336406095, 42.44920399881179, 49.09019639415126, 55.815358931018466, 53.76123328362742, 58.498444480280725, 61.271964196235906, 59.24616198385916, 56.90817832946778, 59.19490837281751, 56.91212031149096, 58.88303679804648, 53.26875617427211, 58.56849408918812, 60.961398770732266, 66.08862692309965, 61.041772057933194, 64.42626368614935, 43.718310402285674, 28.213567464582383, 11.433170706995073, 1.2499305485717713, 2.593423108900747, 35.981450926872995, 64.97807448910129, 64.16128796915855, 66.58268082526423, 63.02298084382088, 68.37147774234896, 70.36967431345295, 72.66448836172782, 65.628783933578, 39.11944512398013, 31.686573259292114, 52.256270839322, 71.58378908711096, 19.191561052876136, 0.6214181033353652, 0.41013129896694617, 0.17602072818385017, 0.20933436800635633, 0.16774484887719157, 0.1554902919357823, 0.4046589797062259, 0.09693403202559679, 0.16415048691053546], [0.033469247601685986, 0.007585632650467057, 0.0367645479949011, 0.032611037604510784, 0.07664215555714984, 0.0778945254522466, 0.07293804383446133, 0.019198075282357393, 0.070741884260168, 0.00706761644499737, 0.01250099593533143, 0.05570586124855665, 0.10205087116769246, 2.3890565912569723, 48.470508975367395, 48.88120074425974, 32.98457576382545, 29.006596188391413, 42.89216118474161, 60.60143893764865, 61.89546415882727, 45.580318358636674, 46.27787267008136, 52.22167945677235, 58.94033478152368, 56.364271102413056, 48.32752681547596, 25.995318082071122, 0.656953061059598, 1.4322519975323833, 0.1719982303198307, 8.196535764201995, 50.69328869542768, 58.231056505633944, 66.81530875544395, 62.08228665013468, 63.17290167654715, 59.77479157909271, 60.50940052155526, 59.40553180633053, 57.850586598919286, 59.048619654870805, 59.65803046380321, 59.291171181586485, 59.335121339367284, 61.35645989448794, 58.9237549228053, 57.061386108398445, 56.665618958011756, 58.18681217009022, 55.49995330072219, 57.63246751600697, 61.33100371206961, 57.68796120920489, 58.856949114030414, 59.53668409778226, 60.18745237781156, 55.37492382910944, 59.535738806570734, 56.26697278791859, 52.548942412099535, 47.605238037724654, 49.66152883345082, 45.273671380935184, 45.057937099087624, 44.51412793128721, 45.28005699957571, 42.45801756458898, 40.06232407785232, 39.96156623286586, 45.65912269776868, 50.20633820564517, 55.78671386165004, 54.483620120633034, 53.99077038611136, 54.63840469237297, 56.611513783854825, 57.61873529803369, 56.72419563416512, 56.75427236864644, 57.50171138394264, 57.92427616734659, 52.67271280288697, 45.116019556599284, 45.448707149874785, 44.07509311552971, 45.2331611417955, 43.98011292180708, 51.80446086391326, 45.45192741578626, 50.02024135281963, 44.26688917221562, 43.121604150341405, 42.82215472190611, 42.74747279382522, 44.441454256734545, 51.8955304545741, 57.82044318414504, 56.781646590079035, 56.507221883343114, 52.93764537380588, 54.63250937000398, 54.2116076715531, 53.60444438072943, 51.112331190416896, 54.80720389273859, 50.51907662422427, 49.335995643369614, 49.860765626353604, 41.93443998213738, 39.6463135750063, 39.52752851670788, 44.46037969281597, 42.488510070308564, 42.87138831230902, 43.10191385207638, 42.10010913110549, 45.116572610793575, 47.06177403849941, 46.27549571375693, 48.750013151476466, 53.79634634140999, 54.35476241573211, 53.0894999350271, 55.93600711514873, 54.4512644890816, 54.21664791722452, 51.95986124777025, 47.22183812049128, 42.07431170248216, 41.39542395068754, 44.108970626708, 53.38839238689792, 54.15901260991251, 56.841890273555634, 55.96435408438406, 54.8764729499817, 58.60155574737057, 55.72965122038319, 57.61841758604973, 56.51607075045186, 57.284110053893066, 56.07421575054046, 58.88329175210769, 56.902718390187914, 60.644910566268436, 57.41168122137747, 53.87736681968936, 25.00790453726246, 9.46310733595202, 1.7668886410613216, 2.1702412876390644, 2.5337498851360816, 39.277748061764626, 54.04121206652734, 49.990050869603316, 54.490570560578384, 54.352079514534246, 55.937556451366795, 57.87394431329543, 60.643153344431234, 49.95360028359198, 25.122912353084935, 43.54743234572872, 42.51821417962351, 37.90570689785866, 0.9250523943093516, 0.07295550297825568, 0.02769006416201592, 0.027034216290039402, 0.045701136001415794, 0.025682796971992623, 0.03402394122414051, 0.07650622857674476, 0.026710438804941315, 0.02093288330211034, 0.04084041154372596, 0.062179285056528553, 0.05780707571595427, 0.054064582988259294, 0.07487598581299668, 0.04532019495062771, 0.018477343593633944, 0.057513855562935916, 0.09553423617035152, 0.0183060769772818, 0.05516825521725321, 0.25826693182030036, 0.2633365339809849, 4.518085045199241, 59.80831215458532, 51.779161576301824, 30.269591539136826, 44.19028528275029, 51.366720430312625, 67.70425119707662, 67.7847303882722, 51.46550140073223, 52.56045064618511, 58.29567363185268, 64.60968940488755, 61.36086863856162, 58.17217780697731, 29.7205989591537, 0.30714413812083585, 4.3854094032318365, 0.29476544429217616, 12.381352705340232, 52.12855454414122, 58.70036809675155, 69.75429365711828, 64.65019964402723, 64.06933976757911, 63.550594545179806, 63.28728191314205, 62.475986711440555, 61.720950065120576, 59.687969915328495, 62.85921404438635, 60.69111608689832, 60.22278901069396, 62.44814965032763, 62.607342966141246, 58.89886356169178, 59.33696877571845, 59.366264958535474, 58.54261821316135, 59.47708760538409, 62.853926689394065, 59.6030427563575, 61.065353347409165, 60.61994075775147, 60.65519109849007, 58.77401059673679, 60.60289805935275, 58.18720832947762, 53.603157843312914, 50.295485834921564, 50.97649951134959, 47.4705752249687, 46.86000731683547, 46.95697615223546, 45.52309882256293, 43.823304407058224, 42.402876884706565, 41.40398256240353, 47.18970998640984, 51.932373277602665, 56.94483680109824, 56.608320974534564, 55.734726767386164, 56.35423767951227, 58.12019463508361, 58.63806124656432, 57.85186136922529, 56.598624875468595, 59.173343181610115, 58.73406125653175, 54.03345754069667, 44.727026339500185, 45.90101918866558, 45.177094782552416, 47.19280473647579, 44.909710730275805, 54.700299693692116, 49.75379866938437, 49.741996257535874, 42.92958844092585, 42.867477709247225, 43.03714375342093, 42.33941685768866, 45.07390114568895, 52.64731153365105, 58.69535923004151, 57.77675190279561, 58.05884092084823, 56.68967485427857, 56.000683076920055, 56.42434612397225, 57.09840151571459, 55.13108576497724, 56.72978893403084, 52.72832024481989, 52.2355136563701, 51.51347983268, 43.84334771863876, 40.122752112727014, 41.35873017772552, 45.66197426088395, 44.840712316574596, 45.03090020148985, 45.30811371341829, 44.15006922137353, 46.39062904542493, 50.145353194205995, 48.157088064378314, 51.31331736041654, 53.97828548185287, 55.55061855623799, 54.97373988551479, 57.82894688267862, 56.299214670735026, 56.40136103476248, 55.32767888038389, 48.64929453019173, 43.364834247096894, 42.71184590555007, 45.91307263220511, 54.572206850974794, 57.41994173296037, 58.27089601947416, 57.67562535501296, 57.53321193879651, 61.196074178141934, 58.43624353408814, 60.384108251140965, 60.50359149133006, 59.46141773654569, 59.78997899639992, 60.77589027343258, 60.065603948408565, 60.18647178526848, 61.23973800290016, 54.45852871864073, 28.6827790352606, 12.477809671432743, 1.3415636122226717, 2.4791980510757816, 4.200583888638405, 43.970526649105935, 60.589750274535156, 55.74690964914138, 61.76035811824184, 61.294141277190185, 62.603655938179266, 63.59505461108301, 67.09085526004915, 55.2099960081039, 37.0795851369058, 32.2433066368103, 45.18679088161838, 48.972348782324026, 1.447662744791277, 0.06812769348823255, 0.08340311131530231, 0.030742403600485097, 0.02355969920303793, 0.009207694073988786, 0.006395613215112638, 0.06796827059118979, 0.05021806318132628, 0.05104888553520845, 0.16778111547952698, 0.118396291659484, 0.10862821097215337, 0.21585111025600665, 0.20030882570051378, 0.23038431911939578, 0.14667364648513256, 0.12273704542988732, 0.2726208148223739, 0.21743487446538864, 0.18760707259418505, 0.37625645377462913, 0.6369134267010997, 7.619433028082694, 72.91080536380892, 63.37432322963592, 43.56797772069132, 41.81245426977835, 58.992286574456, 72.9678209366337, 75.61269083330708, 57.139311836611846, 58.83456806982718, 65.71903374887282, 69.75364254366967, 68.73116693189068, 62.22552376408731, 34.37134542772847, 1.3405483312183812, 8.365987058608763, 0.18253201588747964, 16.287138115975164, 57.07815816325527, 57.71056975087812, 73.45963124305972, 66.44394659226941, 66.15290672548356, 64.81742989632392, 67.03570673542639, 64.51820012061827, 63.30924326373685, 64.42024284793486, 64.79097743188181, 62.41496639866983, 64.33495090853783, 66.37445788229665, 63.30675255867743, 62.155548680213194, 63.03242591119582, 62.95662610761581, 61.139588125290416, 61.96784365561701, 69.71914137563398, 59.699807628508545, 63.06897847883163, 61.20763340303975, 62.58464420995405, 60.58856179637294, 64.81098936450097, 60.176214787267874, 55.886459735132036, 51.533181898055545, 54.156541516703946, 50.03546799382856, 48.78447117344026, 48.71457845933976, 47.90894323779691, 48.06929365281136, 46.05400339249642, 44.303178941049886, 50.656893022598766, 53.596379987655155, 60.69307727198447, 59.246742494644664, 58.592808861886304, 60.09557085652506, 61.04090129175494, 63.021137329839895, 61.31152914416406, 58.96559876780356, 62.859363094452895, 62.083161338683105, 55.16317075298679, 45.13150507403959, 47.262956327007664, 46.15207833628501, 46.71706830301593, 45.21347476590065, 55.33602960648076, 54.13743957396477, 53.26102518266248, 43.91587234312489, 43.68094590402419, 43.04453742119574, 42.37227455262215, 43.710500963272594, 54.653713703155525, 63.67809118763093, 60.84619875877135, 60.55037752274544, 59.01018434955228, 59.13562174766295, 59.376886736962106, 59.51483257355229, 57.2484713985074, 59.272736041776604, 55.59286248299384, 55.169069997725956, 55.816233619566894, 46.16751286291307, 44.919497043855735, 44.00467480382612, 47.583378668754335, 47.07370588856359, 46.39512015927223, 47.622959306163175, 46.71441285840927, 48.80871142110517, 51.96582325043217, 49.344424816869925, 53.64941043238486, 57.38378140234179, 57.927994574269945, 57.077730624906486, 61.355185124181936, 58.24517703825428, 58.261647070607836, 55.97037884496874, 51.945999591581284, 47.64281042160527, 46.13371379913823, 48.25456680790071, 57.70819671692387, 60.34195846126926, 61.3831869248421, 59.86859898413382, 58.39038318203342, 63.57743140189879, 60.39952316591817, 62.919269454094675, 64.37572002410889, 62.19918504838021, 62.55634823153096, 64.3430035345016, 63.24022131581461, 64.8239488755503, 62.582581043243415, 55.212306284135394, 35.487342111526, 19.007492065429688, 3.791080107611995, 4.082209698615536, 5.140659818726202, 51.223334266293435, 66.12059424000402, 61.2006555065032, 67.90101297440069, 66.40010233848326, 67.66712204102548, 69.19565400769635, 73.58775938710859, 62.91070299763834, 38.79864623469692, 60.006466373320556, 55.04966520494031, 62.20517058526317, 2.9347239819265183, 0.26180910787755446, 0.21340718252524254, 0.12846267166277095, 0.17653575377358546, 0.10729478897466775, 0.14749633298525888, 0.17238574823544872, 0.12139459891665368, 0.14505750740007048], [0.02939023351627252, 0.036731384048659, 0.025709249988018025, 0.038636499159638925, 0.07705434150392972, 0.08983817327046588, 0.0357421845077507, 0.07833393050297614, 0.018278878940750035, 0.06250674550932261, 0.008845572930670554, 0.013399845939279805, 0.0630567621649994, 0.272572765787763, 39.341839590380275, 50.638642234186975, 30.24636522416146, 27.52154761745084, 40.478224754333496, 58.786707308984575, 63.65294095008605, 61.535343508566584, 54.73775048409739, 57.21497043486565, 58.57904918732182, 56.003377745228434, 52.35348678404286, 45.3551233199335, 1.0532566568543835, 2.8159462780721727, 0.19388387610595073, 4.61591140877816, 40.97600098579161, 62.173250336800855, 50.449772265649614, 52.23010863027265, 56.46689991797171, 62.05392006904849, 61.778267660448634, 63.50155707328551, 60.215917018152055, 60.02599977677869, 57.69868496925601, 57.35678765081591, 56.57903655882805, 57.70245044462143, 57.407578422177224, 59.04428151346023, 57.018863693360366, 62.53405740184169, 59.2546852942436, 57.08213152423982, 54.19920513706823, 55.11439607989404, 52.38473238483552, 53.56487158806094, 57.913964256163574, 54.549547318489324, 55.36385097811299, 54.016108897424516, 53.865497727547925, 49.092957742752574, 48.7928101324266, 45.91248427667926, 43.640561180730025, 42.53260927815592, 40.77477162884128, 41.113119202275435, 39.18383867509904, 40.856894293139064, 48.87498378753663, 52.99827737192954, 55.407773679302586, 52.96923614317372, 53.58074149777813, 55.58556295210316, 56.20570144345684, 55.53805128220589, 57.50367649139897, 54.851463917763006, 57.05623995873236, 52.67916510182043, 46.280606562091464, 46.407738424116566, 46.52555465698243, 43.45761399115286, 41.68325531867243, 45.453143350539676, 51.58580833865751, 48.07941729022611, 45.03576394050352, 49.436274959195046, 44.90141099499118, 44.39400142238986, 45.09463871678999, 41.99504060129966, 47.988500672002, 55.27344819038145, 54.01469292179231, 56.451806637548636, 54.44386297656644, 53.54301614146079, 54.91782257633825, 53.6553842021573, 51.65517545515492, 55.18296695524647, 50.5285922942623, 49.92865008692588, 50.068517884900494, 46.76699615293934, 40.8230403161818, 40.409422459140906, 43.1302333647205, 42.80541404601067, 40.067697724988385, 38.65280858932003, 41.23884293340868, 44.91200139445644, 49.14951439826719, 45.35404859050628, 49.48928971444407, 54.6036603373866, 56.1000249462743, 55.11465103395524, 56.77648082856209, 54.46179605299427, 55.43784256904356, 51.771740451935806, 49.448650037088704, 43.61224559045608, 40.6427054251394, 42.13553205613167, 55.37437861965549, 56.44750379746961, 55.168450263238725, 56.748879109659505, 56.55750274658204, 53.81152199160669, 56.53942454245783, 55.05692158975909, 56.96379753851122, 58.4542707474001, 55.837233989469475, 58.16359566104028, 60.22243599737845, 54.59180693472586, 57.164756251919655, 52.31862475795131, 19.617861893869218, 4.04514035870952, 0.21095055305669386, 1.5901337708196335, 4.697495237473519, 53.36781171060378, 50.09189913349767, 51.5888560202814, 56.85162559632332, 59.24691115656207, 58.153860338272594, 57.0984289723058, 61.95983025335497, 38.737735748291016, 30.79944491386414, 37.3422662673458, 49.530196112971154, 21.985226062036332, 0.18947128627088763, 0.037690832565027865, 0.0959055666481295, 0.06242737113948792, 0.06692157232112463, 0.03941788202932766, 0.05232367882384889, 0.0493256741714093, 0.04844623587785229, 0.022875379673355532, 0.009389932984636437, 0.04602727495254048, 0.017204695351181493, 0.053403793849171176, 0.07990464057412841, 0.04584107728254411, 0.039515577391871524, 0.02366024249744031, 0.024273541846102285, 0.042165881548557556, 0.04682230567860027, 0.014676934618863368, 0.0583207146865466, 0.6186034963015588, 47.15050197416737, 58.72313353323168, 21.863318797080748, 43.63115925942698, 51.67180238231536, 63.32073188597157, 71.07197469280612, 61.99430004242928, 59.519155025482185, 62.79168259712958, 65.77256233461442, 61.685276108403365, 56.78135241231611, 48.60530907107938, 1.4160630275164883, 4.422811164009956, 0.2137161917503803, 7.267343921046104, 46.720837700751524, 64.7668234763607, 51.993707379987164, 52.53218212435323, 59.68676967005576, 62.87580959258541, 63.07661141118696, 63.98752697052495, 62.51954463220412, 62.908090699103575, 59.037672319719874, 58.425613910921165, 60.40764639454504, 57.4073273904862, 60.40956051118913, 61.31607517119377, 59.58805145755891, 63.510092150780466, 60.09245257223807, 59.08866705433015, 55.65040365342171, 57.346209018461174, 56.16608550471645, 55.340685459875296, 59.04938059468424, 55.197365976149044, 55.7673373529988, 56.650466842036096, 56.35474758763468, 49.60968294451314, 51.15815624114006, 47.88082768840175, 44.259232705639256, 45.17596121757261, 43.27739284884545, 43.99737527293544, 42.06477642059326, 43.63108473439371, 50.98647409869779, 54.31161634383663, 56.77614742709745, 55.61847948258924, 55.85699881276777, 60.49273044832292, 57.795320403191354, 58.23435521894886, 58.039421266125096, 59.75308910492928, 58.391971741953206, 56.68219489435996, 48.63480137240503, 45.72767788364042, 46.49140257989207, 45.11734531771752, 43.72648854409495, 47.16761919759935, 54.451880301198656, 48.455278411988296, 48.45072454021823, 48.77442990579913, 44.29957428286153, 43.41846873683315, 43.18293825272591, 43.7090692981597, 50.98090825542327, 56.22350900403915, 58.140379151990345, 60.056154958663456, 57.28798927799348, 57.47301532376198, 57.262721369343424, 56.463875770568855, 55.947680088781546, 56.76454505612774, 52.78319420353059, 54.0249106960912, 53.30796810888475, 47.597534502706225, 42.565863132476814, 44.0153318835843, 45.62348796475319, 46.491885031423266, 43.075210355943256, 42.56112883167882, 44.35626429896201, 45.51660729992775, 51.30600998478552, 47.001306779922984, 50.99307937006797, 53.59255567673714, 57.1361307944021, 57.95555314710064, 58.935000358089326, 55.34921269262991, 56.626293274664114, 54.13223066637593, 50.666365546564904, 43.60070597740912, 42.81966793921686, 45.16306446444604, 57.70473718643189, 58.993600568463734, 57.0398562185226, 58.835607497922844, 59.490117719096524, 57.23973235776348, 58.23268036688528, 60.14733437568911, 60.00321865081788, 59.8134857608426, 59.20479666802191, 60.08537269407704, 64.1887524051051, 56.256982511089696, 56.983903608014515, 52.91202052947014, 22.703106095713956, 4.629240112919962, 0.2915763428374645, 1.2501855026329718, 5.607310081681898, 58.49199610371744, 56.594663281594556, 57.80249441823652, 62.66087547425301, 65.18646609398627, 63.637204400954715, 64.54535076695105, 65.9423146709319, 45.83260128574987, 40.67616324270926, 32.24425192802183, 57.689083007074174, 26.243680600197088, 0.14617939719990378, 0.011709880876174618, 0.061797577917816184, 0.1000150997612265, 0.031929414704321854, 0.07864733707279929, 0.0340676810141773, 0.06094343967795853, 0.08074280205032519, 0.053988529609576355, 0.17872065185539185, 0.14501577092995568, 0.13313645917561748, 0.1876410715762646, 0.15340598119843393, 0.1375617967137406, 0.15532363716873432, 0.15723589988004777, 0.15606496513130205, 0.1631435409428612, 0.25937080323215456, 0.08885870687663557, 0.17837534538440167, 0.8739971081095358, 59.49676221416843, 67.47520831323439, 39.39952588850452, 41.543513036543324, 55.636989147432395, 70.70826115146761, 77.88910112073346, 72.18093072214435, 64.10379778954291, 72.44786370185115, 69.44521088753977, 66.69579413629347, 63.93986625056114, 55.60640642719885, 1.4186031299252666, 8.03793570687694, 0.2101302414291328, 11.301330039578101, 52.861253292329856, 63.2075362051687, 55.36059541086997, 53.67713374476279, 62.468000765769716, 65.42968050126107, 65.80578480997394, 66.5346396353937, 66.05447092363912, 65.4468918615772, 60.76482134480631, 61.691779398149066, 61.492126834008005, 60.06066568436162, 62.58080813192553, 63.31194577678558, 61.427411648534964, 66.03359606958205, 62.34613664688603, 60.60247836574432, 55.67260426859702, 60.569624593181, 58.230664268616714, 55.25335388798868, 60.87350237754084, 55.7356289125258, 59.333673984773704, 57.262721369343424, 58.664188154282115, 51.632347260752034, 53.444199869709635, 50.09109112524217, 46.480317961785104, 46.16277071737474, 45.46351409727528, 45.37553141194005, 44.617082303570164, 45.52865289872693, 53.96159971913984, 56.198021442659446, 61.65221445022091, 57.68520378297376, 60.426214894940784, 64.30990657498761, 61.83636972981115, 61.50778493573589, 60.72553488516039, 62.67601190074798, 59.865449320885446, 56.10811287356962, 47.30254480915685, 44.84158700512302, 46.620781960025916, 47.03944790747858, 45.491923824433364, 48.996365454889116, 56.054529374645604, 51.741259713326734, 53.23974240210749, 52.23416043866066, 45.307293938052275, 44.23097202854772, 44.68688088078653, 43.27526692421206, 49.84208729959304, 55.965687690242646, 58.468006887743556, 60.50556444352674, 57.861961472419004, 57.998683529515425, 60.29676098977367, 57.79763067922285, 57.43738843548683, 59.897145994247936, 55.70165726446337, 55.00764877565446, 56.92562895436441, 49.85230115152175, 45.08620169854934, 46.1593347211038, 48.307805138249556, 49.05351046592959, 44.42437233463411, 44.302661188187145, 45.71306705474854, 48.510783872296734, 52.09415928010018, 50.2896297362543, 52.355396978316776, 57.69736705287811, 61.55290788219821, 60.637018757481734, 60.769018280890684, 57.33675610634589, 58.65451166706701, 55.576176720280806, 55.71276541679136, 46.397720690696474, 44.99343372160389, 47.667619412945164, 60.86259034372146, 60.78792410512125, 58.38732765566919, 61.869364707700676, 60.576845676668235, 56.17305163414248, 59.30151839410106, 59.50915690391295, 61.417460595407796, 63.26275533245456, 61.32716763404108, 64.23960985675936, 66.41117126710954, 57.33821522804999, 58.96661858404837, 55.023557909073375, 30.541884437684093, 7.636060445539414, 0.7714503558893359, 2.7349015301273716, 7.036043222873443, 63.28061780621929, 61.43511126118322, 63.31225956639936, 66.73018547796434, 70.05983844880136, 69.53254638179656, 68.71525779847177, 73.61780474262854, 52.66856293524466, 44.6907248035554, 51.21041397894583, 66.28774996726744, 38.77815577291673, 0.3401863683135279, 0.17267278605891814, 0.18866015237665948, 0.15576369339419951, 0.14477819174287782, 0.1403880789275131, 0.18295282798428691, 0.11101200846174072, 0.20450082817865958, 0.10416547302156688], [0.06492268804821276, 0.04458820943029658, 0.05586728746552141, 0.04212659272936083, 0.059835151769220836, 0.05851816618815065, 0.04623652037773882, 0.09863670840258561, 0.06670292316665573, 0.043718439166343985, 0.09294099024226589, 0.07281840388332644, 0.09004277237240346, 0.21772657010343768, 18.616857336413478, 59.409909171442834, 41.56399173121299, 26.139920180843724, 35.161318625173266, 50.400044456604995, 57.645772195631466, 59.082399106794796, 63.05955302330756, 53.596168179665845, 57.44478994800199, 57.50637115970735, 55.91352801169119, 57.52349622787968, 9.254248969016537, 3.471296131610871, 0.8376458683802236, 1.1663546461251475, 23.333060318423858, 56.5951535778661, 59.674853509472264, 58.933662829860566, 59.69309645314371, 62.37088288030317, 64.04207537251135, 60.06402715559929, 56.88497358752836, 57.269601206625666, 56.84715409432688, 55.90764837880289, 56.981338377921816, 55.64147241653935, 59.51462861030333, 59.27892946427869, 60.49641355391472, 61.08319228695285, 59.77010434673679, 58.178979196856105, 59.50531298114408, 61.87593075536913, 58.747036457061775, 55.885710562429125, 55.18720311503257, 55.17131359346452, 57.554996782733554, 58.27614807313489, 57.624132479390795, 51.247080295316636, 48.559880179743615, 50.0848820132594, 45.02669149829496, 42.15165299753989, 41.746268195490686, 41.52399140019571, 40.56829806297056, 41.99832754750406, 50.69219827651978, 55.662684594431234, 54.27569135542839, 54.771918250668435, 54.29128277686335, 55.657993439705145, 55.72584652131604, 58.71934452364522, 56.502420902252204, 57.04605356339486, 52.769171730164565, 43.84722302036901, 42.086196484104285, 43.72782214995354, 44.12060045426892, 42.2678179125632, 45.009978278990715, 48.68886340049006, 46.23009427901238, 51.55426856010191, 41.364284253889515, 44.976869552366196, 48.39774116393059, 44.46995419840659, 42.24443274159586, 43.11502241319226, 46.01815292912145, 48.470469751665675, 56.992517132912916, 54.553234346451305, 56.25510369577716, 55.58651608805503, 52.912550049443404, 56.050763899280184, 53.071966940356845, 51.519347698457786, 52.052503708870184, 50.70837020874024, 51.845904627153956, 48.93228177101382, 43.82034301757813, 40.685745593040224, 43.53254302855461, 42.49047125539472, 40.6985285974318, 41.529635690873675, 41.7047812861781, 45.73774268550258, 48.33501854250508, 45.5205532043211, 51.09521788935508, 52.8045162077873, 54.75657786092451, 54.47642257136684, 56.44986114194317, 54.34610574476181, 55.227085774944676, 52.62251038705149, 51.07955586525702, 46.27941808392925, 41.488580242280044, 41.77870619681574, 45.21513000611336, 51.93607599504533, 55.32374474310107, 55.2967353020945, 55.40387484335131, 57.05187828310075, 56.170607997525124, 55.72269685806767, 55.76380721984371, 56.25980269524359, 59.456220596067375, 58.69415898476878, 58.186164979011785, 56.631780670535186, 50.57198939784881, 45.765819011196015, 10.469861107487834, 0.10414461244738872, 0.49407354465896086, 0.5853532579156661, 8.112909361239403, 49.46962687277025, 49.704157152483546, 53.45485302709764, 57.228510456700484, 57.00302516260455, 60.18119619738672, 56.642480896365264, 51.14220396164925, 33.15095486179475, 25.322498236933065, 35.661613018282004, 45.06826077738116, 2.9396264543456416, 0.19415655744171914, 0.04029313365237848, 0.09520300273453036, 0.036596479795632825, 0.09242273176149016, 0.07626347829617801, 0.1201386437300713, 0.04633762100110612, 0.0746411951859632, 0.045923473869240096, 0.042960115543176094, 0.036293476699821414, 0.006760670390400675, 0.03354779076612285, 0.04518537113683359, 0.030488575688533248, 0.07447927484228727, 0.06961977229483667, 0.0279000143881046, 0.0637791141296827, 0.04570700040447616, 0.028963514881569053, 0.06266560533174104, 0.16253091575157258, 26.62719818853563, 72.70544575106713, 34.61422251116845, 28.6963955433138, 50.453188650069706, 53.216196413963075, 63.94087037732525, 64.67711494814965, 68.74080027303388, 58.90231132507325, 64.43716395285823, 63.80557214060138, 61.657584174986816, 65.85232765443864, 10.210395339996586, 2.7143036934637257, 0.7319465724210585, 1.7210645709306964, 29.587483521430727, 61.2176158351283, 63.17623569119362, 60.926611269674, 64.08765331391366, 64.1713410039102, 66.8869233900501, 61.984058733909364, 59.74686430346582, 58.32772724090084, 60.86028006768996, 56.28330161494594, 60.61201364763322, 57.69476259908369, 62.3811516454143, 60.85402388726512, 62.8932249161505, 62.924988269805915, 60.33644753117716, 59.72538540440222, 61.59744639550487, 63.11361505139259, 61.003579939565356, 56.85424573959843, 56.33619085434945, 55.9112177356597, 58.02645391033542, 59.323648406613266, 59.83434100304881, 52.93614310602988, 52.78894832057338, 51.38558310847129, 45.10728836059571, 43.659196361418694, 42.03924963551183, 44.597482219819106, 41.393290181313795, 44.86659995971188, 51.96857283192297, 57.76264313728579, 56.07807144041985, 58.38973991332516, 59.04397949095696, 57.857642942859286, 57.49272915624804, 60.10536109247516, 57.72100325553649, 59.05986901252501, 53.40192064162224, 45.158428222902366, 40.6171315716159, 43.57294736369964, 46.49408548108993, 44.42602365247665, 46.76069290407243, 51.26675882647115, 48.68579218464513, 53.07442234408472, 43.92453293646536, 48.54462608214348, 48.340215682983406, 44.432397504006666, 42.71537996107533, 44.406992312400575, 46.37657127072735, 50.6194971453759, 58.84273444452594, 56.76851057237195, 59.41185858941848, 58.08217902337351, 56.17886850910803, 57.43879656637869, 55.58810072560465, 56.214232598581624, 55.437509167578916, 53.213752777345725, 53.36825493843325, 50.05375016120173, 44.16482517796178, 44.731058536037324, 44.97080164570963, 43.98023451528242, 41.9332044355331, 42.88468906956334, 43.391949592098115, 47.65256927859399, 49.307021094906716, 47.952760034991854, 52.083988574243364, 54.26477147686867, 54.790349468108154, 56.41568553063178, 54.98714262439359, 57.83795656696443, 57.57671886874784, 55.41932113708989, 53.39362090633762, 47.655385540377715, 44.56412246150356, 43.12579716405561, 48.52006812249461, 53.50831493254631, 57.988504978918264, 57.47210141151183, 58.00960340807515, 56.58664987933252, 57.64124578045261, 58.18807909565588, 57.181885242462165, 57.632228251426454, 60.053232792885076, 59.49672691283688, 58.99156878071447, 58.80947666783487, 54.054689330439416, 47.21798243061189, 11.092355962722532, 0.17777945155337935, 0.6364287688366829, 0.6238492986848277, 9.602882958227589, 56.002161810475016, 53.80348505512361, 60.638528869998076, 61.54132904544954, 64.18901520390665, 63.63225436979725, 65.06904209813764, 55.67670706779727, 46.573062404509514, 31.921766419564527, 33.45280085840533, 55.24708594045332, 4.03315433090733, 0.09859415221839182, 0.09543420040919896, 0.03756585681150037, 0.04182149438307651, 0.03937120812254087, 0.07614166265533817, 0.040597864276459145, 0.03522319441300727, 0.04906134702445519, 0.029366283692539703, 0.23763938626695066, 0.2618317227930792, 0.11373748882643639, 0.09773104691938048, 0.10796736820691055, 0.18451930925009713, 0.13093720460611005, 0.2546783768001103, 0.18368577494496302, 0.22092385337718073, 0.1745061417140307, 0.2168979847262944, 0.287165729509246, 0.31060002203429904, 33.52952241897583, 81.1013497075727, 57.45775730379167, 38.513293804660925, 46.41611268443447, 65.48402886236867, 66.11220821257561, 73.40562020578693, 73.10227194140035, 66.15296948340632, 69.16326307481336, 73.065229077493, 68.09043991950251, 72.6647315486785, 10.992422796064808, 8.202361464500427, 1.745046677608644, 3.4359666080244127, 39.56074314732706, 62.63252458264751, 66.64307748117756, 64.6948754402899, 67.33643485653785, 67.06025292796474, 69.56243484250962, 64.76304623388475, 59.19792467548002, 59.49432249992125, 61.644287340102665, 59.96472058757659, 61.88096707867038, 58.84581742748138, 62.26673610748784, 62.63152437825357, 65.41943134800081, 66.8470956433204, 62.72448455133746, 60.36727736073156, 63.57641550802416, 64.32347405341365, 62.654697741231615, 59.44578709140901, 61.279632429922785, 60.655395061739036, 61.26380566627749, 62.52699713553152, 62.447910385747115, 54.06678592005084, 53.57260650204074, 53.66205615382041, 48.42318557923841, 45.26193172700944, 45.83294645432503, 47.47522323362289, 44.49635959440663, 47.6296861710087, 55.579204790053836, 60.98663137805078, 59.78569576817175, 62.92671019031156, 61.05732425566643, 60.83637714385987, 61.26596296987226, 64.02638981419226, 62.38321481212493, 58.29059416247953, 53.68080900561426, 45.199350310910134, 41.66660093492077, 43.076014441828576, 46.20537550218644, 45.982694702763716, 47.2963749208758, 54.845313641332815, 51.97483685708816, 55.03459938110844, 48.1963784463944, 50.32549981148013, 50.85070125518307, 43.55036235624745, 42.800052165985115, 43.889619919561575, 46.69210633923931, 49.257242295049856, 61.58179221614715, 57.06810512850362, 62.12645646064513, 60.028082555340184, 57.68803573423817, 62.952499774194536, 58.13448775199152, 58.749480093679125, 58.00687736080539, 56.17291435118645, 57.84126704738986, 52.77640850313249, 47.331287937779585, 46.6453948328572, 49.0774957595333, 44.94956985596688, 44.244935666361165, 44.98005059457595, 47.03952635488203, 49.5383507205594, 52.005521558946185, 48.89104589339226, 54.82480749007195, 57.02127987338651, 56.26854958072786, 56.6474623064841, 57.65579385142173, 57.83272804752473, 60.386748006266934, 56.19218495584304, 55.64582624743062, 50.970835608820764, 47.10853261332358, 44.881061738537205, 49.98494394363896, 56.35280993676955, 60.28611959949617, 59.421813564915816, 58.64673360701531, 60.32825369988719, 60.31784372944986, 59.680517412001095, 59.21430449331961, 58.770445162250155, 65.38275326451948, 61.247880843377885, 62.74432782203921, 59.96227302858907, 55.162798127820416, 51.20444805391374, 17.61055169566985, 0.19464807945393747, 1.1870651283571798, 1.6269219258139211, 10.16911925808076, 60.10028946784235, 61.25466262140582, 63.97919585627895, 68.44368073248094, 68.4272381567186, 72.06021585772115, 69.27103411766791, 66.12417928634152, 45.81078506285145, 39.18902797083701, 47.81707348362092, 65.12447303341281, 9.4716610447053, 0.5795065361645915, 0.3266210655771917, 0.3094084488768732, 0.16897472643083142, 0.2106860228964398, 0.15795769260054635, 0.1778958815961115, 0.2420818535310607, 0.10663144876279178, 0.1851598813288635], [0.023664277865581458, 0.02819567836160141, 0.08411421710925718, 0.04891698158556416, 0.1165715238500026, 0.025339844306149793, 0.026185842861811963, 0.040788332886633374, 0.13142196972283626, 0.06310975246672189, 0.06475056341338543, 0.04784754582590634, 0.06533144192109186, 0.14542763511980736, 2.6089961442255207, 49.35407776986399, 34.65940037081319, 34.629543289061516, 29.278032049056026, 47.104963256466775, 61.09739518934681, 54.60388391248642, 60.047761086494695, 51.504517216836255, 56.57239598612632, 58.33932961187055, 52.98893820854926, 55.57394096928259, 13.664086403385287, 3.8183498959387507, 0.30482295299729995, 0.08924601794851404, 10.439279367846828, 58.58709396854524, 60.65654039382935, 60.04072435440556, 60.07631201897899, 64.23335367633452, 63.45093888621177, 59.74020019654305, 60.74736287516933, 64.3318953821736, 59.1352177435352, 62.05528505386845, 60.58018361368487, 63.49554015744118, 56.52707299878521, 61.63930592998382, 56.733848587159194, 57.53179204079413, 57.60623862666469, 58.503794593195764, 57.04835991705618, 60.65860748291016, 59.370610944686405, 60.0720170236403, 58.966748022264056, 59.3925997518724, 59.74966487576885, 57.602520219741336, 56.8516295186935, 54.097529457461455, 48.50273124633297, 49.151361834618356, 43.74701430720668, 43.88527393341065, 41.512345883154104, 38.75389591340096, 41.063148206280125, 42.0706089850395, 52.76087983962029, 56.07301158289756, 55.56901839471633, 54.309753218004786, 56.95046932466569, 58.66234464030112, 58.55651909305204, 57.56388487354402, 57.046732133434666, 53.15170480358986, 44.045620426054924, 44.11300282324515, 44.8273644908782, 46.02861389037102, 41.24987263833323, 45.98273000409527, 45.70777969975626, 43.12706408962127, 45.382740728316776, 46.51579972236387, 45.451115485160585, 41.00648172440068, 44.06367901832827, 44.87606463893768, 46.062248214598625, 43.22116175005513, 43.618062465421616, 43.21038307682161, 50.48730542582851, 54.73166296558996, 55.91196690836261, 55.49605054240073, 56.17708383067962, 54.13820443614837, 53.905753012626406, 51.709508126781834, 54.235487061162154, 52.16948447688934, 51.7525286828318, 52.00581573670911, 44.573202748452466, 41.25022957401891, 37.66630895676152, 40.61622158173592, 39.80434586924892, 39.85836082889188, 43.52340782842329, 45.28889409957394, 47.36584401899769, 47.19201241770099, 53.81618568974157, 53.30930563711351, 53.66530387632309, 54.12116566011983, 57.07920935846145, 55.593321400304, 54.36998905674104, 54.00876622046194, 51.45722912203882, 50.40996805314095, 43.8445754205027, 42.86090381683842, 39.66798467020835, 42.25899257967549, 47.86874678827102, 51.8490856693637, 54.45803842236919, 54.921419389786266, 55.66928594343124, 55.87766578120571, 56.12788554160826, 56.13793857635991, 55.55329361269551, 55.60687318924935, 55.905373404102946, 56.30372931880336, 60.35637317165252, 40.264267306174006, 3.5199386698584405, 0.5636326427901945, 0.3689157992841736, 0.5731611218183272, 12.25497688016584, 53.62452299364152, 50.5625404081037, 55.90683252580705, 57.47137577302995, 60.34242914568994, 58.176594395791334, 56.65894308397847, 43.452185430834376, 21.358558785530832, 30.57901163255015, 42.177568097268384, 31.86162667889749, 0.12857514103093456, 0.041086042314888015, 0.06524554814302153, 0.07283056169868478, 0.0935380255442954, 0.03304789924333173, 0.06999280348780655, 0.05450844284026854, 0.04387384776266352, 0.025365632740900885, 0.05965122554991996, 0.04017733563218386, 0.03978125285357237, 0.043307796886731545, 0.06114566390733085, 0.03895883065377993, 0.012132031711629562, 0.06207639944829768, 0.0645080506200752, 0.06477831111800286, 0.04548804864527718, 0.039080910594953645, 0.08695388287906686, 0.14836495411732506, 0.21441428171050167, 5.2411489813558525, 61.06010129374843, 39.63810013186547, 20.920620272236487, 42.82193114680629, 54.68898757811516, 66.66301881113361, 59.928615170140425, 65.18477947481217, 60.11220170605568, 60.84579083227343, 65.41062562696396, 57.56319061402352, 61.73419590919249, 14.411960801770611, 2.0399790064942454, 1.074445055377099, 0.05068413958313966, 14.271550736119671, 61.81018398654077, 65.65015692864695, 63.7933421904041, 64.77528010645221, 64.30957317352295, 66.48028342954575, 61.915095621539706, 64.23959808964884, 64.01201040514054, 63.082593025699744, 63.67179970587454, 62.40090470160208, 64.41986630039831, 60.14870328287925, 63.46016430085706, 60.153998482611875, 58.45712623288555, 59.523610837997936, 60.15730896303731, 58.12665870112758, 62.37464443329842, 59.51944920324511, 61.65193203956851, 59.94748961540961, 60.55951272287677, 60.27345426620976, 59.42606541418261, 57.30851504110522, 57.29671262925672, 50.95075307353851, 50.24409886329405, 44.82350095625847, 45.163531226496545, 42.57136621782857, 42.71484651873189, 42.46681544088548, 43.67699999963084, 52.933746537854596, 57.62193202972413, 58.91143868046423, 56.2379119473119, 57.324298658678615, 59.84484903274044, 59.309512184512236, 59.6889465855014, 59.31370912059661, 54.06034931059807, 43.41281660141484, 44.29536557966664, 43.69936927672356, 48.77047615666544, 42.61951723406392, 45.83878294114144, 47.475733141745295, 45.9029568395307, 47.402302449749364, 50.777698101535925, 47.27513920876288, 43.89259307615219, 46.788831987688624, 47.918529510498054, 44.84680767982237, 43.42823151619204, 43.99226442460091, 44.109798246814364, 50.884221830675685, 57.685960800417014, 57.77708530426026, 58.981892293499364, 59.04181826499201, 56.08159765120476, 56.707607930706395, 55.07402312371039, 55.19356519945207, 54.12080480206398, 53.20586096855902, 55.483008661577784, 45.870361943398755, 44.220918993796076, 40.34301280975342, 43.36345357279624, 42.25790608313776, 42.821127060920965, 44.67868704949656, 47.70281876287153, 47.37155106759841, 48.35634839150214, 55.53718443839781, 55.69474604821975, 54.94475356994137, 55.01945118750296, 58.73838763083182, 56.33919146753127, 56.76379196105465, 56.29881458897745, 55.25907662607009, 51.51064003667524, 46.40478880174699, 44.96972691628241, 42.15334746145433, 44.98468291374945, 49.785993483758745, 55.75389931278845, 57.161634045262495, 56.702865785168065, 59.9321609927762, 59.4928986795487, 59.466065745199884, 60.267009812016646, 58.495483090800626, 58.56803909424813, 58.1319539008602, 58.47060349679763, 62.92379194690336, 44.12422472430814, 4.209068465617396, 1.0920012165461819, 0.7030026061880974, 0.5254452435239669, 13.66830393191307, 58.85610580444337, 55.23948830942954, 60.09757518768311, 60.47592701450471, 64.71316545240342, 65.76698864659956, 62.42602356018559, 46.77460162870346, 31.221107552128455, 25.78357873424407, 47.79498269481044, 41.72465593584123, 0.43956464216593777, 0.03682886490658407, 0.04825526164964803, 0.09872888410163504, 0.07175023982962293, 0.038527768300545794, 0.03161326553972979, 0.06372442311276832, 0.08902616603600402, 0.04984530394956951, 0.04693804624220056, 0.18451854316217287, 0.10499189036988443, 0.14525672090390038, 0.21750225955920838, 0.16996757638069893, 0.17473183121652375, 0.14310922323455735, 0.19005668469734732, 0.20294832035658822, 0.2989615836451131, 0.23171599443641402, 0.2835274247392532, 0.2723114378750324, 0.42591960499844245, 5.499035504556471, 71.37445219101446, 48.842616388874674, 49.229483681340376, 42.736015550551876, 61.93864160968412, 72.89611216514342, 66.92986549869661, 71.75680483541181, 66.54765405962544, 66.11232588368078, 73.21922133045813, 65.85184128053727, 69.3965107394803, 16.271937950964897, 9.764071779866374, 3.2142467892939046, 0.1446516340177867, 21.055010480265466, 66.00667292071928, 67.2452397500315, 65.28739652326031, 67.70578876618417, 68.10138333228328, 70.52184658665811, 64.24663874410814, 65.16656398773193, 68.41001110692179, 64.10058929074195, 65.0070058914923, 65.3158611636008, 68.74498936437791, 61.799711258180686, 65.9035930325908, 62.319813620659616, 61.3654342774422, 63.77566406803747, 63.055901296677135, 59.01466761865924, 65.7877968203637, 64.9566779598113, 63.54425991735151, 63.07586616085422, 62.96352163437874, 63.02306713596467, 62.1455034902019, 59.63855589589765, 58.323636208811116, 52.1515239438703, 53.18880258067962, 46.64169211541453, 47.46144002483737, 45.401909351348884, 43.87865297255978, 45.23877797588226, 44.88523121803038, 56.33050733996976, 59.98222612565564, 60.26138121081937, 58.848872953845614, 60.54896939185358, 63.25512632246941, 63.435445524031124, 62.44885175458847, 61.41820584574054, 55.27212635163338, 42.50616465845416, 45.55141833520705, 43.99654765282908, 49.01753840907928, 43.05925415408227, 47.89121020224787, 50.518123488272394, 47.5402404415992, 49.269978230999364, 50.54995352222074, 50.12698473468904, 47.51947541390696, 52.53231548493909, 51.45847643575361, 47.18068461264334, 43.96124632127824, 44.384422994429066, 44.40336019762101, 52.2304851778092, 61.71892612211166, 59.375357012594904, 60.53872023859332, 62.81705248740412, 59.73906270919308, 58.87818482614333, 57.94009508625154, 58.396980608663256, 56.572556803303385, 56.535796350048436, 58.00599090514645, 49.093424504803075, 45.72536368523875, 41.07187155754336, 45.86873023740707, 44.31046278245988, 43.90563887934531, 49.74125492957331, 48.46238574674053, 51.896240403575284, 49.96293160223192, 58.880624540390514, 57.4279276786312, 56.90061992214572, 56.12890143548289, 61.67760395234632, 58.59135758492255, 58.728122788090865, 58.91914221548266, 56.211534007903076, 54.52142392435382, 47.64812915555893, 47.00903384916244, 43.51662997276553, 47.0092103558202, 51.520363592332416, 57.86890798999418, 58.20845973107123, 59.8767771259431, 60.088071284755586, 61.99524533364081, 61.029522495885054, 62.933672397367424, 60.76321317303566, 61.56745203079716, 61.53957182361234, 62.80910968780518, 66.5896547994306, 46.68886646147698, 7.175142236294286, 2.6831230569270352, 1.7097583389089954, 1.2596043391573815, 16.37337632717625, 67.19603753858998, 61.06035624780963, 67.23216256787701, 66.5795821528281, 71.64126749961608, 68.6055334152714, 68.73802323495188, 56.712934509400405, 34.6537600025054, 44.30056272014495, 55.173921969629106, 55.20108830544257, 0.8332473592412087, 0.136454064218748, 0.1764119846085387, 0.2044956800678084, 0.16128867353883483, 0.1077607696154906, 0.17473224490400285, 0.099983942965346, 0.16388443989619134, 0.13051164276417226, 0.09618377913871119], [0.04296117657495122, 0.058625138875457554, 0.09218873786589793, 0.08328649741146835, 0.04607725069828091, 0.05745419646583258, 0.028802868159067248, 0.021516295645626324, 0.00528386211015224, 0.03358064827719524, 0.06225068445107149, 0.021051460306250283, 0.0909458751219415, 0.07063244093930529, 0.24880645075632682, 38.72516062951858, 56.5755574164852, 44.286497100707024, 35.33816652913248, 38.04817130488735, 61.71094017644083, 59.42087219607446, 60.40108819161693, 59.53329909232355, 59.63561411826842, 59.04597205500449, 54.52362829639066, 60.682530018591116, 18.610787468571818, 0.6793421338642798, 1.1321878601466457, 0.1336936042794297, 4.843528020766474, 56.33691649283133, 58.90365277567218, 59.864296144054784, 55.07991844607938, 53.697357485371256, 56.348958169260335, 61.08329819094751, 62.105573761847715, 60.868520967422, 58.74576560912594, 59.947262117939616, 59.3781065940857, 58.67798705254832, 56.864243861167665, 55.12953642875918, 54.20759116449664, 53.78475965992097, 55.621786040644494, 57.33395161167268, 54.913900206165934, 56.879399899513494, 57.15706056164157, 59.75144955419726, 58.86520962561331, 56.94930045835434, 59.24589918505762, 60.1085146780937, 58.21701442041705, 55.29074584284137, 47.586516564892186, 48.24821649059173, 45.05556798750355, 42.79996587384132, 40.886484653719016, 40.56589757242511, 40.36764921680574, 39.84307535233037, 50.293826672338675, 57.83790165378202, 53.45529625492712, 58.6119657178079, 53.399575064259196, 55.44151782989503, 55.40553792830437, 52.38580319189256, 45.309984683990486, 44.62714318306216, 46.413943613729174, 45.794754335957194, 43.793208060726045, 42.42475586552774, 42.2246051603748, 40.905814093928186, 40.46311186205956, 39.383628522196126, 40.208859905119866, 41.86592401996736, 39.5947265625, 41.26389511169926, 39.693393784184615, 39.695441261414565, 47.222681430078325, 46.758363016190074, 43.78850513888944, 44.57036295244771, 43.09781497524631, 46.39098598111061, 54.776691775168146, 57.9640882245956, 54.541451546453665, 55.60770080935571, 53.38986719808271, 52.908290355436264, 52.68487607279132, 52.88807838193832, 48.60329297281081, 52.07236266905262, 44.51830133315056, 42.02139892885762, 38.909990556778446, 39.29259031049667, 39.27786181049962, 38.3040863467801, 42.871933521762976, 46.96908843132758, 45.56283243240849, 55.12873626524403, 52.674595540569676, 53.59781949750839, 54.70441426000288, 54.713263127111624, 52.04800867265271, 52.294411966877604, 51.23575249025899, 54.17789882229221, 57.24301145922754, 56.59807966601465, 53.60792744544245, 53.45521780752367, 43.757942030506754, 40.05396550701511, 41.37605920914681, 44.293231810292895, 46.798375114317864, 51.440582583027506, 55.1391109343498, 53.08070990347093, 55.51280690777687, 54.902238999643636, 53.530099776483354, 55.18989778334095, 52.217945360368304, 57.75157028628934, 53.27358068958406, 49.38795920341246, 4.6792449393580045, 0.5760890485778932, 1.6254211289267388, 0.44161251776160737, 18.51387550753932, 54.369318331441576, 48.79407313562209, 56.48622935818088, 55.753087382162775, 59.46022533601331, 51.04202270507813, 60.683565524316606, 33.71001028245495, 30.82745455926465, 49.008795445965184, 43.92088120983493, 16.579992078965713, 0.15844460276346053, 0.07883454597885571, 0.06559134491028325, 0.04901064732562631, 0.08613226124115529, 0.04469200285271772, 0.022694653786358335, 0.0349676619554239, 0.011239820817154984, 0.04375301271436676, 0.07517079176801829, 0.056177415179028634, 0.07190042370629889, 0.051577332985377124, 0.0602283119224012, 0.048159830076920415, 0.09517872540820992, 0.0883878539166143, 0.03318259282217872, 0.03538057568573183, 0.03536722277321162, 0.02831266956373809, 0.04450135421188128, 0.08335120885843232, 0.08082960747302541, 0.31231884754473166, 45.67534954317155, 62.17835334039504, 37.30600395510274, 44.900650055177756, 50.965375669540904, 65.92915119663363, 65.8970348296627, 64.92516171547675, 66.17985340856737, 63.538348905501834, 65.0549804010699, 60.23167317913425, 65.95452893164851, 20.715533264221687, 1.4438705482790548, 1.3831912365651902, 0.387543656172291, 6.689181654684006, 62.76654412669521, 63.31490716626568, 63.389985253733975, 58.23457487167851, 56.29952453797864, 59.6140097033593, 63.703849392552534, 62.97696751932945, 65.11510249107116, 61.85347518613262, 62.56897041874548, 62.060466504866085, 59.37592183389972, 58.72620867144678, 57.20013210850378, 57.10995289587206, 56.189607958639826, 57.02829307125461, 59.46159816557362, 58.02190396093554, 58.274767398834236, 58.322730141301314, 61.73136395792808, 59.6532137932316, 59.07655869760821, 60.45567189493487, 63.04393806765157, 60.60087019397367, 58.15260517981745, 50.56892210437406, 50.68579696839856, 47.27268380503501, 45.407918422452866, 44.42230916792347, 43.8633204275562, 41.03997876567226, 43.1183603502089, 50.0237165727923, 58.89530597194549, 57.994494438171394, 59.65301375235281, 56.952724687514774, 58.53819377960698, 57.5126547967234, 55.965864196900405, 47.67030231414303, 46.6802490142084, 45.32714113112419, 46.41221777085335, 45.239013318092596, 44.07408114402525, 42.95418954664662, 44.54573831250591, 43.28520621022871, 43.673203145304036, 43.0659653294471, 43.369325360944195, 41.85097586724066, 44.2599348099001, 42.002422501963956, 44.534783132614635, 49.46975238861577, 46.10513541006273, 44.03503002658967, 45.16607684473838, 43.62041196515484, 48.72034826586324, 58.46810494699786, 59.846445437400575, 56.74996168382707, 58.492596226353804, 56.55314499332059, 55.673824125720614, 56.186685792861454, 55.1003892960087, 53.11791750692552, 55.29459368798041, 45.13556080479776, 43.77119964168918, 41.05179294463127, 40.926728171686975, 40.67459429464033, 40.84916330152943, 44.02538884070612, 50.128934152664684, 49.69306076726606, 57.31243741127753, 55.454944102994865, 55.081483471778135, 56.87044120603993, 56.88559332201558, 53.1730071959957, 53.85360117881529, 53.007483174723966, 57.16176348347818, 59.47432625678278, 57.31050368278258, 57.555443932933194, 54.43178207643571, 47.160029411315925, 43.96355267493956, 43.59731704958024, 47.41515997917422, 50.210248808706964, 55.40015251405778, 57.50689675731044, 56.256696178067116, 58.35179882664835, 56.894673608964496, 56.653498834179295, 57.64357566833497, 54.46833072170135, 60.84063291549683, 55.51601540657782, 52.41340491079515, 6.106741063056454, 1.4011713814350868, 2.4265228259947995, 0.5831963220430959, 22.22583209314654, 60.165891108974336, 54.20108395238077, 60.18382810777234, 64.04244799767771, 65.26491349743259, 58.0354400604002, 62.08237686464864, 43.44250109887893, 38.91242634865546, 41.19249228508242, 52.04113275774064, 19.985078111771617, 0.20914207993736192, 0.01388428642624809, 0.027557065552701394, 0.00723161815380257, 0.12029916213284578, 0.04049753740189537, 0.03946242621168494, 0.027015678877491626, 0.0211810938743574, 0.06600805077581637, 0.038928332693514325, 0.18945571936426625, 0.15219851937745849, 0.19078471337354955, 0.17389152469413896, 0.14572709888940857, 0.17273925184722871, 0.27839724034551655, 0.17967849158711974, 0.12175202489860597, 0.10068656816597908, 0.10305358833002468, 0.1787696968043043, 0.2713956257268306, 0.32600543732123993, 0.4708189150739101, 55.31855544736309, 71.48866376569195, 55.729141312260786, 51.18724846070813, 52.526624125819055, 76.19699062839632, 71.9094713272587, 71.53606168685421, 71.63892976699337, 70.47543710277927, 69.40152352856052, 67.08242216417867, 73.76855711783134, 24.606114587476178, 3.4251940634942826, 5.454170453932978, 0.24607546988033482, 10.887830834234915, 71.73443163594892, 66.37139843356225, 68.056762449203, 60.88395549405006, 59.513471511102495, 61.23611765523111, 65.61317682266235, 68.00008420021304, 67.03652258842223, 63.86316822421167, 63.777601718902595, 65.579138494307, 61.606048153292754, 62.4398224584518, 62.788925170898445, 60.33481582518547, 58.337560622922844, 59.227577793982725, 61.55728916968069, 58.71646550393874, 60.693512655073604, 61.986800470659816, 66.507081062563, 62.984110155413234, 61.248178943510986, 62.92451758538524, 64.24552086860903, 62.69019911366125, 61.73445086325369, 50.89057214798466, 53.57086496968424, 50.25538352227981, 46.83280567969046, 46.13825982616794, 45.140440233292125, 43.144298984158425, 43.46856132630379, 51.858012983875895, 62.2889994805859, 58.07431467117802, 63.04753488109958, 57.016886818793516, 59.642952872860825, 58.81245374679566, 54.44888361038701, 47.063260616794715, 45.4975994940727, 45.196012373893495, 46.879219085939475, 44.27808361668741, 45.88474135245047, 44.21144254745976, 46.47407747084095, 44.87064784572971, 45.64146418725291, 44.33222801454606, 46.67864084243775, 43.359444910480136, 46.62337856907999, 44.904038983006636, 46.77789641964821, 54.1208440257657, 48.82449896104875, 43.27519632154896, 46.35269972585863, 43.05733611506801, 48.77787374681043, 59.46244147516067, 63.62423312279486, 60.122819562112134, 61.49947735571093, 58.285965765676195, 58.50057824965447, 60.179333071554865, 58.66535309822329, 54.8960808784731, 57.92436245949038, 47.23474664072837, 47.225427089198945, 44.02907979103827, 44.278628826141365, 43.721095285108014, 41.53066727422899, 45.99187304896694, 51.48539958461639, 50.11667282350602, 58.70441990513956, 57.55568711988388, 57.21792005723523, 59.48668172282558, 59.94403792965797, 56.27928903025966, 55.33375855415098, 55.300736119670255, 58.514808608639626, 61.028271259800086, 60.844857308172415, 58.72667543349728, 58.410406881763095, 49.89402732541485, 46.982820649300855, 45.12964979294808, 48.27566915942777, 50.963465475266986, 59.000178383242705, 59.86271542887534, 57.04075051892189, 60.6507392083445, 60.55373114924277, 59.16809112794938, 62.3583116839009, 57.76025833622102, 65.83280994046119, 58.1977242039096, 57.421408699404815, 6.9241772255589895, 2.7550833504046164, 3.696694398118604, 1.133538626374737, 25.109138950224846, 66.62946685667961, 59.14032074712939, 68.26322032559302, 64.65902497691494, 72.40343893727949, 64.06618618196057, 71.91249155229139, 46.80322708622102, 45.74700340147942, 62.88216383226457, 61.33805221126926, 29.505039222778816, 0.3312752642218144, 0.18960722091217197, 0.14919597565406753, 0.13015829236997714, 0.19774931062373424, 0.2188387459083911, 0.14105425366470892, 0.06087850989593614, 0.1599241790151404, 0.15439090979916437, 0.20225317217409614], [0.0019118121558529958, 0.07418577889761618, 0.01885502302508441, 0.04725458228119439, 0.11043114527579277, 0.025963181321839654, 0.006979832344973881, 0.010659364615416816, 0.08168643085105766, 0.0738919995004131, 0.014303960882487797, 0.1727515092540172, 0.021258160404320207, 0.17629480379964077, 0.3409051732911218, 9.400177809499926, 51.69646232358871, 40.219948445597005, 30.559954797067952, 32.92699929206602, 49.94094671741609, 65.38843677889916, 57.68683156659527, 58.45419622236683, 56.56762246162661, 61.35113723816411, 52.647338990242254, 59.69839557524651, 21.435568640308997, 0.3135962531931939, 1.2838331874339812, 0.3119020037833722, 2.2540424812224606, 44.1317399855583, 62.64064388890421, 58.931450613083385, 56.20119071775868, 51.913404695449344, 49.57799803826117, 49.667561438775834, 53.71605542398269, 55.26551323552286, 56.67449528171171, 56.10415127969558, 56.85157852788126, 52.4165584964137, 49.75428112091557, 49.43197211911602, 49.87052056097215, 51.55013438194029, 51.268621952303, 50.83277602349558, 53.83407169772733, 50.65947001980197, 55.376198599415446, 56.902753691519464, 56.90420496848322, 54.33182439496441, 53.27992316215269, 56.83228831137381, 57.71965788256738, 58.02835625986899, 56.91843140509821, 46.786976706597116, 46.81353507503387, 43.22142847122685, 41.860993600660755, 38.450324073914565, 41.1968735725649, 40.3272331145502, 45.53011986517137, 55.96483653591525, 57.43248155040126, 57.16574076683291, 56.556298578939135, 55.2842660873167, 49.01823266859978, 45.248070070820475, 46.035132869597405, 47.25164813380088, 46.13672617943057, 45.115854817052046, 44.91672785051408, 43.83701309081047, 42.084149006874334, 39.594895224417414, 41.593766443191036, 40.44605347418016, 40.5561936286188, 40.568062720760224, 40.87239550006005, 39.31828575749552, 39.49313717503702, 37.08568442252375, 38.41458735927459, 43.26824195923344, 45.571614619224306, 44.029342589839814, 43.285586680135424, 43.89992398600425, 47.35276683684319, 50.77665867344026, 55.21340454778364, 52.552331339928415, 53.707469355675485, 52.623447833522675, 52.634536373999815, 53.52730704892067, 51.94119076575003, 52.79331784094534, 48.48702215379285, 38.304776683930434, 39.85699192170174, 38.186787866776996, 39.30892698226437, 39.44808483123779, 43.91844149558775, 44.555214758842226, 51.66063147206461, 53.90971852887062, 55.30762380169284, 54.50113350345243, 54.19755774159586, 49.91800085190804, 53.54598929805141, 45.55964746782857, 37.40634210648076, 54.35520564356158, 50.67752861207532, 52.812710039077274, 52.637529142441295, 52.754980594881125, 56.00599396613337, 51.99094995375603, 47.318787344040416, 42.60404740610431, 42.77300350127682, 47.75990493835942, 49.44477473535846, 51.22478946562737, 50.39443546725858, 52.22387206169867, 47.468688564915816, 48.12426959314654, 50.926548127205145, 55.67135695488223, 55.46700539127473, 50.5503418368678, 8.102766602270066, 1.6159133036290447, 2.074573943691869, 0.23825556610620793, 24.357742263424782, 52.09082526545371, 54.209226792858495, 54.600604811022365, 42.63253558066584, 56.61646381501229, 62.740899670508604, 52.70165989475866, 29.43456599789281, 17.583048036021573, 33.71740395022977, 40.169871545607045, 0.9761191411845147, 0.05949267982355049, 0.06480634993603153, 0.03702720123974066, 0.05445102838078334, 0.05747078609983287, 0.027490934927857695, 0.10004246442188179, 0.02066685352474451, 0.08697129605758576, 0.051781782700169476, 0.07861139988827129, 0.017397483292546485, 0.027688664136334296, 0.05275307876628734, 0.022371887537320296, 0.05221261905746595, 0.039512084030936805, 0.028868242272085724, 0.024701436425769524, 0.021979730959320744, 0.029768726916142532, 0.017396962352757974, 0.020554401393559192, 0.15015589914494945, 0.13453251652179227, 0.3695151558326137, 16.66104393620645, 65.84657745976602, 38.43918062025501, 32.51817653256078, 48.74426687917402, 56.19922953267252, 73.71394988029235, 62.99765017724807, 65.21156926308909, 60.45290270159322, 67.3692415606591, 58.71926999861195, 64.58326047466647, 23.899425075900172, 0.9495164009351885, 0.8851482226483284, 0.4566489851042148, 3.5181405082825696, 52.802617780623905, 64.3609130767084, 63.93541436041556, 59.528498111232636, 54.52984917548395, 52.326308681118874, 51.66632283118464, 55.7087371426244, 58.70363150873492, 58.552675170283166, 59.82006749799175, 59.12548242076751, 54.69288249169627, 53.09431268322853, 52.008930098625925, 52.37725634728709, 53.80237110199467, 54.16191124146985, 52.4447250366211, 54.839806633610884, 54.52381264778876, 55.53499183347149, 58.967144181651456, 61.11022526218046, 54.667085063072946, 53.90264649544993, 60.752897339482466, 58.39941247817009, 59.13952842835457, 57.67196186127202, 49.67322141893449, 50.309833865011896, 44.78132370979556, 44.95754795689737, 39.140025800274266, 43.627778176338445, 42.05985776839718, 48.914321237994784, 57.08831710200156, 58.797101589941214, 58.1561117787515, 60.055162599009854, 55.189074085604766, 50.9406372808641, 45.66491996088336, 45.41903441952121, 46.96251846128895, 47.268357430734945, 46.889899699918686, 44.96577316714872, 44.9084359599698, 44.66062061248287, 42.80380587424002, 41.80155008069931, 42.2325675718246, 43.28421777294528, 42.32401763239215, 44.50566737882553, 41.1255491933515, 41.457381709929436, 40.89344686077487, 40.88742602256037, 47.60683836475496, 47.76097574541646, 42.51012232995803, 45.40416079182779, 43.58398491336454, 49.340035684647106, 55.8324839991908, 56.25304837380686, 55.76450932410456, 55.197420889331454, 55.240064897844874, 55.938788075600904, 54.46627539973105, 53.86974957681472, 52.464736969240256, 50.99858245541973, 40.00688137546663, 41.841719073633996, 40.013498413947325, 41.07112238484044, 40.74107454669091, 46.16521827636227, 43.61295161708709, 53.037042156342544, 54.24959582667197, 56.494842883079286, 57.10405757350307, 55.73868443889003, 52.066475191423976, 54.43836381358486, 47.3588425882401, 38.86939794786515, 56.20708996249784, 52.68422888171289, 56.33124474556216, 55.81843799160373, 56.1894549862031, 58.02411225534255, 55.5881634835274, 49.58913756955055, 44.276063596048665, 44.81585233442245, 49.08289294089041, 52.02780062152494, 53.97661455215947, 53.401500948013805, 54.71767187118531, 49.980939203693026, 51.16550676284298, 53.850557419561575, 59.2265893566993, 58.993831988303896, 56.54142102887554, 9.075305538792765, 2.773419695515787, 2.5366874952470106, 0.25834804520972315, 29.236266651461204, 57.88830411049628, 59.03349891785653, 59.604874503227975, 48.51861684553085, 61.94836908771146, 70.63798796746039, 55.846773193728545, 44.89549213840116, 22.9175381506643, 35.39865732192993, 51.799499065645286, 1.9137068789812828, 0.06265639312445156, 0.08041479384466525, 0.014244559382448995, 0.048227490962392865, 0.033981415683463696, 0.032033309633392966, 0.07536152467852639, 0.04876266466453672, 0.07047980558127165, 0.020440830774004423, 0.08169929346730632, 0.06389722956584827, 0.14902933620877806, 0.12117393495094393, 0.1653917791742471, 0.19034729249054388, 0.1129500653534647, 0.23071729157480503, 0.18856981528862832, 0.200011552942376, 0.31070368905221263, 0.1125452644942749, 0.3897072110445269, 0.18855964164099387, 0.31845371028588665, 0.8817738811335257, 20.6663526258161, 76.3099156656573, 53.93844204564249, 43.33369847266905, 45.87220937974992, 65.03918893875615, 78.97548783210017, 70.57391997306578, 68.6824667838312, 67.9692465259183, 70.93239322785409, 66.39435214381065, 69.98206569302467, 26.6797108804026, 2.19510028919866, 2.284994884844749, 1.0551636642025364, 6.724046132256908, 59.909128835124356, 70.5323899176813, 65.34556527291575, 62.13070046517157, 57.709173387096776, 55.50467583440966, 52.68579390741164, 60.42780737723074, 60.971349823859434, 63.1917094415234, 63.45037798727713, 63.755973769772446, 56.51940476509833, 55.12558660199566, 54.04968438609954, 54.779653164648245, 57.73967373755671, 56.724415286894775, 55.6014681631519, 57.11309471438008, 54.981933716804754, 58.36063592664657, 62.70976389608076, 62.99055460960635, 56.41091985087241, 57.90489573632517, 60.91491476182015, 60.82227622309039, 63.1958749986464, 62.41802192503407, 52.10186281511861, 52.31832665781821, 46.55269353620468, 48.087881765057965, 41.50745468754923, 45.97955288425569, 44.45494721012731, 49.98481450542327, 58.36350710161271, 61.9222657142147, 60.27767473651517, 61.728630065917976, 57.49449422282558, 50.657661807152536, 46.073587786766794, 44.99881129111014, 47.20339905831122, 48.324439910150346, 48.91394861282841, 44.28038604797856, 46.51546632089923, 47.47940840259675, 44.170065464512, 46.935073637193256, 43.79571445526616, 46.60098968013641, 47.018565208681174, 47.44456598835607, 43.66549176554526, 44.884736999388664, 42.02398377080118, 45.163476313314135, 50.70083533563922, 48.04797557092483, 44.43477446033109, 45.78698412064583, 43.736015981243504, 48.274594430000555, 55.074136872445386, 60.17449286676223, 55.930174550702496, 57.87330104458717, 56.562288038192264, 56.852653257308475, 58.033506331905244, 57.93216013139295, 55.31411140195785, 52.595850036990264, 42.994095740779755, 45.11270907617385, 42.22129467994937, 42.82144085053475, 41.58389383746732, 47.560060178079915, 48.463068239150516, 55.06340134528376, 57.0921649471406, 59.29031218251875, 57.42941425692651, 57.654617140370036, 52.71437621885731, 54.640287430055686, 50.73661127398091, 39.22124239706224, 55.20745823460241, 55.01079843890283, 59.1076317141133, 58.350806466994754, 58.25294725356564, 57.604571619341456, 55.9408433975712, 53.598843236123365, 47.29592777067616, 46.893802458240145, 52.27123075915922, 54.366027462867, 58.798454807650664, 56.92309902560327, 59.37336444854737, 52.209959414697465, 55.05383468443348, 55.9945837913021, 63.08507980838899, 61.883238131000155, 62.3922166516704, 10.757787592949407, 5.644964835336132, 5.134283515714831, 0.40488699811600876, 31.608049369627434, 62.704562833232266, 64.59467064949774, 65.73770030852288, 54.31702136993409, 69.25652134803035, 73.70495980785739, 63.82057912888066, 41.81283081731489, 29.167360413459043, 45.701170506015906, 62.95550038737636, 3.3876054998367064, 0.21082773384067321, 0.21530492020951164, 0.08741758823875459, 0.16804350059359305, 0.1399374047234174, 0.06396400178932855, 0.23199224574190958, 0.115342159575272, 0.23842303292645564, 0.19670531664404178, 0.2538827332037111], [0.05926865656229277, 0.02990894973458302, 0.014885936811145757, 0.00957581464336404, 0.014045624543101558, 0.0660536406681903, 0.0634913063878494, 0.07283766333374285, 0.04381137329243845, 0.0510262361457271, 0.03518197505224136, 0.05222539740404295, 0.0465651989103325, 0.13778170991328456, 0.07087868458080678, 0.5349916796530447, 46.8940064214891, 55.09689446418516, 32.12467258976352, 28.802913388898297, 40.199289321899414, 59.571730475271906, 64.71303209181755, 59.841260064032774, 59.694445748482984, 58.992062999356186, 54.8270667752912, 58.712649037761075, 26.456018109475416, 0.46794369516353457, 0.9063122902185687, 0.7380761951208116, 1.1096814226719642, 38.75249170487927, 56.790722954657774, 55.86323538134175, 61.50464703959804, 56.64407337865522, 52.98059140482257, 43.521474099928334, 45.676710605621345, 47.966343202898585, 48.50255081730504, 49.18052073447935, 49.82898266084733, 47.976843387849875, 48.812378837216286, 46.99392095688851, 49.99627959343695, 52.734996118853175, 53.51394745611376, 51.91611897560858, 51.40358678756222, 57.83207301170596, 56.886460165823664, 57.314512345098684, 57.239006719281605, 56.58871696841333, 54.79426399354012, 54.0734225703824, 57.33940762858237, 56.54329199944773, 55.230921852973204, 47.82643618122224, 44.78894879741054, 41.56761600125221, 39.28674597893992, 38.955235096716116, 38.68702734670332, 44.332235859286406, 43.34514394883187, 51.582231137060354, 51.5874949578316, 53.07061764501756, 53.26405717480568, 47.83353959360431, 47.73264446566182, 44.896233466363725, 46.54080090984222, 45.79154975952641, 47.04158952159267, 46.80025392963041, 44.73184693244196, 40.26536164745208, 39.272225364562004, 40.31419907846759, 40.70478870022682, 40.827656945874615, 38.99099534557712, 38.95373675131029, 38.972493525474306, 39.672769961818574, 38.858054453326815, 37.98824925576487, 40.1605127703759, 36.932190310570505, 38.93599587102091, 47.34422783697806, 45.96183161581717, 43.24011072035759, 44.97051531268705, 48.88547612774757, 50.3313402206667, 53.91733969411543, 54.13502731630879, 54.37639036486226, 50.98105338311965, 53.83413053327992, 52.99161718737695, 49.42994033136676, 42.913141942793324, 41.58633747408467, 40.15659432257376, 37.16683041664862, 41.17126441770985, 39.0988330687246, 42.1804706511959, 44.83515824041059, 53.96976217146843, 57.009257808808364, 54.73083142311343, 44.43049123210292, 46.70445396054176, 47.24953789864817, 51.49607627622543, 44.6619346064906, 41.88944255152057, 49.69495134968912, 45.719268321990974, 46.73670761046871, 42.89869977581886, 43.575594963565955, 43.7691992329013, 51.894793048981704, 50.698756479447894, 46.739500338031405, 46.07098725534255, 44.420881425180745, 43.732878085105654, 45.017105225593816, 46.18874857502599, 45.266505210630356, 44.766654045351096, 48.958604797240234, 51.50543897382675, 54.223166896450905, 46.91274358380226, 49.30871948119133, 12.325706039705585, 0.9090832608842081, 0.9598285572663431, 0.29973989833266507, 27.464975272455526, 51.01857085381785, 51.87010957348732, 54.151422823629076, 62.89959484531034, 55.73427961718652, 59.34835541632868, 36.45583414262341, 22.461146846894298, 28.034368099704867, 52.05208793763192, 22.57948475499307, 0.26510377624823206, 0.09520647311282736, 0.07161635830397568, 0.04185493029053173, 0.07977251338982776, 0.09817001529999318, 0.031481866138957204, 0.05444135269029968, 0.020740549267840483, 0.015647453105738087, 0.05731086907607894, 0.04567898456908522, 0.03533183717198911, 0.02169182937171671, 0.01361140686522929, 0.07004355681279013, 0.04681501635200074, 0.04099537197860979, 0.07735349883836123, 0.01204713193264099, 0.06742608718453877, 0.04719580035476435, 0.03287831035953376, 0.1374137885267696, 0.0661799072798702, 0.13428431935608387, 0.10429562369902289, 1.695206345569703, 57.349095882907996, 55.37758711845645, 29.165046215057377, 42.2630012419916, 47.531481789004424, 66.87161045689737, 70.95215412878221, 67.26091354124009, 66.59076875255954, 64.91567742440009, 59.53537402614471, 65.2978104160678, 29.974796002910985, 0.44785886161750366, 0.5532560124993324, 0.7849846780300141, 1.4784048113130754, 47.85332402875347, 62.778444597798014, 61.17983556562855, 63.62113445035873, 61.965768721795854, 55.36873432897753, 47.68570153943954, 47.88040407242314, 51.071063933833955, 51.6895785639363, 50.94467732214159, 52.39078460201141, 50.905206511097575, 50.60364684750957, 49.17759856870098, 51.94924731408396, 55.16652045711395, 53.252050799708215, 54.12113035878828, 53.68249954715852, 58.84677056343325, 58.70697336812174, 59.06596829814296, 59.34535872551703, 59.1458159877408, 56.477745271498165, 54.348533691898474, 59.39843231631864, 58.42269958988313, 56.548595043920706, 50.67476726347401, 48.06758349941623, 45.60379766648816, 41.85195253741357, 42.27112054824829, 40.24962509832075, 45.44085064241963, 44.43182876033168, 54.369894919856904, 53.349086315401145, 55.72363038216868, 55.05205785074542, 48.73534740940217, 45.66928948125532, 45.10500946352559, 46.13340000952444, 44.71826376453523, 46.50833152955579, 47.50588832363006, 45.88985612315517, 40.65737116721369, 42.41634630387829, 42.385979314004224, 41.67836020069738, 41.18271381624284, 42.121407601141165, 42.38924272598759, 42.38863083624071, 41.22288280917753, 41.797325688023726, 39.89081451969762, 40.89402344919021, 41.350320616076075, 44.20571980937835, 48.35914111906483, 44.90101875797395, 43.4264233035426, 45.370479399158114, 48.89549778353784, 53.44763194361041, 55.185614555112785, 57.17431899039977, 57.3980470626585, 53.389753449347715, 56.60558316015429, 55.42056060606434, 51.66469504756313, 46.016211355886156, 43.05740671773111, 41.87323924033873, 40.370061474461714, 43.75185451199932, 42.47512302091045, 43.524678676359116, 47.85530090332032, 56.132219760648674, 58.3658605237161, 55.04439746179889, 46.67438899317096, 47.70386603570754, 49.16652571770453, 51.988031710347826, 45.8324836146447, 42.0987049225838, 50.6349983522969, 45.44764810992826, 47.476819638283025, 43.72527653171171, 47.63206312733312, 47.441624210726836, 55.42309445719565, 53.697239814266084, 49.0522474627341, 47.68232437872118, 46.7776140089958, 45.93992125603461, 46.01001793338407, 48.17732357209729, 47.38779360248197, 48.52271179999075, 51.36880320887412, 53.51141752735261, 59.77993380638861, 50.74171035520492, 52.25661993026734, 13.409768746745202, 1.020761045717424, 1.7928474997320485, 0.466399445769287, 31.639279280939412, 58.185721751182314, 56.92194584877261, 59.42517503615349, 68.09101258554767, 61.742593703731416, 65.33557499608686, 42.14358860446561, 35.724406242370605, 20.69231087161649, 56.222822589258996, 27.360699061424505, 0.28209220497838916, 0.11269913325386663, 0.12638985224428678, 0.09808399894785497, 0.07166988486724515, 0.09478487194545808, 0.032744497781799685, 0.08568867335035917, 0.045135383899774284, 0.039682879503215515, 0.04509173987072803, 0.031317036576388825, 0.12419958388613117, 0.13582787927119963, 0.0543790927246934, 0.15724745248594593, 0.17252126918925395, 0.1854192633782664, 0.09467782647979837, 0.19002786446963588, 0.10827036364184273, 0.1569799345827872, 0.15498674234315274, 0.2548478354489611, 0.19273334993950783, 0.27670688266235016, 0.33611834950504765, 2.8819607486647945, 69.97520938996347, 66.48146798533779, 43.553578699788744, 40.66644360942226, 55.44768379580591, 71.59033944529872, 77.93545569142988, 71.18051452021446, 74.07528646530645, 69.68514227098035, 67.03099989121961, 74.78313307608329, 32.4078167253925, 1.3036561108404592, 1.8808636477878018, 1.842367668305674, 3.1593919521377933, 54.780543542677364, 66.37594838296214, 64.11654549260294, 67.85069680983021, 65.06083649973716, 57.33311614682598, 49.0829792330342, 50.33724731014621, 52.79391404121153, 55.454661692342455, 53.02100750707811, 56.33984258097988, 52.672724569997484, 52.731199264526374, 51.56977368939308, 52.828309305252574, 56.66161421806582, 57.74136427910098, 57.24298008026616, 55.89683048186764, 63.82465839385987, 58.92397849790512, 63.521518015092425, 61.976939632046616, 60.02148512871035, 57.02726933263964, 56.84877795557822, 60.85008582761211, 61.747637871773016, 59.392431089955, 52.97842625648745, 50.764773891818145, 47.69416993664157, 45.30947869823825, 44.67310943911153, 41.09643736193257, 48.32134908245456, 45.803289413452156, 58.0899884623866, 53.83930021716703, 58.56623088159869, 57.35701122591573, 47.57192927022135, 46.39624587951168, 44.23361178367369, 47.835806723563906, 44.863607191270404, 47.89206920131561, 48.3049653422448, 47.88359295937323, 43.62424019844302, 44.97839143199306, 44.951393758097005, 44.358621643435576, 45.65140347326956, 42.64520483632242, 45.73396544302664, 46.155934026164395, 43.65802357273717, 44.799888287821126, 41.06239118883687, 44.062125759740034, 43.178545198132916, 45.97687782779817, 51.70494248790126, 44.985816478729255, 44.755585116724816, 44.30909387526974, 50.10489002350838, 53.241546692386756, 57.30254911607312, 59.25445779677361, 61.3826770167197, 55.51474063627182, 58.934447303895034, 57.41659987357355, 53.77615005739274, 46.81238974294355, 46.01763909862888, 43.2284769704265, 42.135171198075824, 45.1360511010693, 44.99217464077858, 45.140479456993845, 50.18927197302542, 57.89472503046836, 61.21683136109383, 57.571666855965894, 48.95514918911842, 48.92994796076129, 50.14851070219471, 53.62484070562548, 47.37157460181944, 41.05370706127536, 53.42250916265672, 45.79967691052345, 48.91113235104469, 45.154474473768666, 51.25871012287756, 51.6956425482227, 58.8397926668967, 55.21959404791556, 51.8136078311551, 48.50452376950172, 48.619696324871434, 48.34853895248906, 49.60774137127785, 50.33772583930723, 49.84211083381407, 50.37021090907436, 54.78846673042544, 56.70192833869689, 60.33426669336135, 54.49489301250827, 58.49492611423616, 16.006754348354956, 2.430678086896097, 4.284359341667545, 0.8952913493398698, 36.05674866707095, 63.77625634593349, 61.84322211050219, 64.80625506370299, 72.65234470367432, 66.48093454299435, 70.26406057419317, 45.79251858495897, 35.85019273142661, 39.4847236910174, 66.59717006068077, 39.56608149313158, 0.2640276678627537, 0.1521208840272119, 0.22409191805749173, 0.158454745767578, 0.1849630273758404, 0.1972566088361125, 0.10185865204661124, 0.17771004398743953, 0.1084586374101139, 0.18344816511436818, 0.30280277914097237, 0.23511429918148827], [0.022261921361449267, 0.0552294809641617, 0.008333432619580099, 0.03618590263349395, 0.033894947339450164, 0.017145373332764835, 0.06219428122764634, 0.02798497928456674, 0.0307452496171238, 0.029922055583747647, 0.05256757057542282, 0.026656081036273992, 0.04316946822068384, 0.04261053813200805, 0.08255476853059185, 0.14996275305747986, 18.237905386955507, 57.32542830128824, 46.38088195554672, 38.26114423813359, 36.47829755660027, 55.35495504256218, 61.06094460333548, 62.97281765168714, 57.425166330029896, 59.43293348435433, 52.73985985786685, 61.176725126081905, 26.210040392414218, 0.2067813033898992, 0.8926086932901414, 0.38613736389144776, 0.4248499623950451, 36.04464423271918, 61.122568961112734, 56.555992634065696, 60.28373872080157, 62.20821434451688, 62.93853221401092, 53.242566508631555, 47.660092384584495, 46.50893165219215, 45.91458274472145, 45.516615144668094, 48.17475049726425, 50.78436220845869, 48.36644064995551, 52.82716397316226, 52.82923106224307, 53.688445860339755, 56.60213931914299, 58.045093013394265, 59.85325859438989, 58.869661515758885, 59.92095085882372, 61.46958105025753, 58.50244137548632, 57.06095857004966, 55.11039526231828, 55.41970945173695, 58.1524286731597, 58.64244253404679, 58.79474032309748, 48.70782806027321, 45.73908021373134, 42.93398149551884, 39.200069442872085, 39.64880035769555, 39.994620046307965, 41.31792183845274, 44.16898289034444, 47.822545190011304, 51.49076930938229, 55.19703649705457, 50.342962203487275, 48.34024313957461, 45.751623953542406, 45.48571471245059, 47.401945514063684, 48.89580372841128, 45.26011174724948, 41.950600147247314, 38.817657962922134, 39.3243379746714, 39.36278112473027, 39.866060441540135, 38.40480104569466, 38.54619856803648, 39.66348178925053, 39.54024484080654, 39.623689343852384, 38.24379167249126, 39.64699214504611, 37.19455765139672, 37.90912328227874, 39.17380132982808, 36.90135263627575, 34.939594884072584, 46.64589297386908, 47.10125661665394, 43.6978905431686, 43.56117633081252, 43.46900847650344, 48.72825184176045, 52.21164211150139, 51.25758832500827, 52.08657341618692, 50.75756457544143, 52.54136831529679, 46.627861838186945, 42.12854631485478, 39.50618690060031, 37.817983088954804, 38.53447460359143, 38.605053732472086, 39.64310899857552, 40.553177325956284, 44.71066613351145, 50.232245460633315, 56.205387653843054, 53.348090033377375, 47.73931249495476, 55.6354437335845, 52.997943970464895, 53.36652125081709, 55.5369883198892, 55.373880478643606, 49.61346018698908, 51.658533004022416, 49.50028804040725, 57.13638182609313, 56.391994414790986, 57.52141344931818, 51.67114734649659, 53.80772513727988, 49.32163584616877, 47.31056997852941, 43.15529338775143, 42.47588788309405, 46.588818565491714, 43.34462227359895, 43.91791197561449, 44.49845806244881, 51.5073452457305, 51.63939183758151, 56.39139429215462, 47.07883634874898, 32.93074515558059, 13.299961013178672, 0.47007810805113087, 0.2495571096698123, 0.5999696639276321, 32.94156697488601, 55.20708953180621, 51.56987174864739, 59.423774750001975, 50.19179797941639, 52.24967733506234, 55.015411146225475, 26.365746721144646, 30.639716194522, 41.34646492619669, 45.23489090704149, 2.83312086616793, 0.23285130609668073, 0.17779944644820306, 0.06818684313686625, 0.02518177355429338, 0.03885412941716852, 0.015100532402885298, 0.07477724474043616, 0.09409208331377276, 0.08667050695587551, 0.022123606101940238, 0.040645989919862444, 0.05490268700786176, 0.03547077104749699, 0.05143506662739862, 0.09981959412295012, 0.039573221677734007, 0.026022371190089374, 0.05515730399037561, 0.004861726596455781, 0.10666315714197774, 0.010387327751114724, 0.029298584502671036, 0.09221582673490049, 0.026427748530442198, 0.05523218525453441, 0.030796669438601505, 0.03616755099726781, 0.22608947699829457, 25.850090365256033, 68.97647196246733, 39.9858025581606, 40.025677373332364, 51.39423977944159, 57.698226051945845, 68.4127724555231, 67.34711939288725, 63.932715769737, 65.62308080734746, 60.000747557609316, 66.35049220054381, 30.256178994332593, 0.8905395817372107, 0.27821481948898685, 0.31132100270159785, 0.9213643244677975, 43.47113440113683, 64.46615419080182, 61.26523340902021, 64.88453772760207, 64.85775186169532, 65.6629163988175, 54.33240882812008, 49.6906328201294, 49.38483307438512, 47.77299388762444, 49.324083405156294, 50.94237489085044, 51.521614828417384, 53.72754796858757, 54.87320561562815, 56.298022270202644, 55.03733327311855, 56.37748556752359, 57.052313666189875, 59.73762319933984, 59.939809614612216, 61.26668468598397, 61.7464493936108, 60.17736404172836, 61.19816087907361, 55.295260490909705, 54.342810953817065, 59.12249357469621, 59.63138188085249, 61.39376947956701, 50.130381507258264, 47.691220314271995, 44.98412985955515, 42.754482069323146, 42.47895909893898, 40.855093925229966, 43.29324314671178, 45.94215308466266, 49.71172340454594, 53.46272130166331, 55.721249503474084, 50.291779195108724, 46.974548370607444, 46.5646489204899, 46.693612529385476, 47.47857686012022, 48.643422742043775, 48.292225483925115, 42.861754971165816, 41.436306814993586, 42.384571183112364, 42.18046672882573, 43.03315470295568, 42.5603953484566, 41.09054203956358, 40.879306716303674, 41.70921356447282, 42.69719585295647, 41.07832385647682, 41.393537290634654, 41.04370109496578, 40.76500100474204, 40.70465141727079, 41.291720405701675, 41.20459279706402, 48.97283907859556, 46.4359010419538, 43.07259805740849, 46.92085896768878, 43.92346605177849, 51.694548206944624, 55.60196238179361, 54.843583876086825, 53.97228425548923, 53.6404085928394, 55.3259216585467, 48.97535724024619, 44.348015554489635, 41.9373974492473, 40.199963969569055, 40.354211176595385, 39.543084636811294, 42.03174221900202, 41.914369213965635, 47.29074239730836, 51.80580623688237, 59.58131282560287, 54.83328765438449, 49.55118471576322, 56.017992496490486, 53.414962522445194, 54.06081607264858, 58.012247085571296, 55.139601230621345, 51.401825643354854, 53.07028424355292, 51.05133441186721, 56.25479775090372, 56.0454059416248, 59.16239976882935, 55.558863378340206, 54.75467943376111, 50.66410233897548, 48.538114947657434, 45.7557620540742, 44.94414521801857, 48.86501704492877, 45.83633145978374, 46.16344536504438, 48.13065913415725, 54.68866202139086, 56.128603335349794, 59.33015169635896, 53.76415152703562, 41.906226373487904, 14.469771635147834, 0.6753107340585801, 0.24236121515352882, 1.12127827780862, 36.42889922665012, 61.19428557734336, 55.21030195297734, 66.00866548476681, 57.30118805362333, 59.94128442579701, 58.922754718411355, 36.15483537797005, 35.990629273076216, 37.0926191729884, 55.9310531616211, 3.0473224818706517, 0.13052152529839547, 0.10620151255880633, 0.07276191255979, 0.020725005343856833, 0.01891697655552097, 0.036741653457283974, 0.06055246287536237, 0.0954907070544939, 0.12754687483632757, 0.030925703542907874, 0.017478606258068356, 0.03352363601387028, 0.11200171745111866, 0.1673870551730356, 0.29816402482890314, 0.10909157925315442, 0.14965732912382773, 0.1560801183504443, 0.1654487454722966, 0.1754400182154871, 0.16459460340199933, 0.14780713485613947, 0.1938185288060096, 0.15875483772927718, 0.15754477120935917, 0.09596342160817116, 0.20960619132364952, 0.3352496364424306, 29.58114693241735, 78.02417185998733, 58.64451746786795, 51.71867862824471, 53.12262827350248, 70.12261990577944, 73.55365045609014, 74.783627294725, 68.90585360988494, 73.99564666132774, 65.76758092449558, 73.50640942973476, 34.91071447249382, 1.609837919954331, 5.312407170572589, 1.7744487644203248, 2.2933966017538503, 51.368720839100504, 66.72041877623528, 65.05454894035094, 68.66749901925364, 69.41985668674593, 68.23082939271005, 58.404291906664454, 53.00522781187489, 52.622663359488214, 48.96125631947672, 50.85816552562099, 52.45529582423549, 56.14146870951499, 54.97662674996161, 57.30426711420859, 59.536487979273645, 56.78188193228937, 59.81458010212068, 58.07260059541272, 63.28010789809689, 64.36112096232753, 63.081859542477524, 64.60140928145378, 63.43917962043517, 62.10442058501705, 58.103230384088334, 53.81532276830366, 60.5261137408595, 63.39170717423963, 65.2796459197998, 52.809854553591826, 51.18288286270634, 45.57639991083453, 44.68058939903013, 45.19725576523812, 44.36308530069167, 46.139946445342034, 47.02022044889389, 51.13366103941395, 54.791832124033284, 58.37371703117125, 51.266656844846665, 47.49255618741436, 46.494665991875436, 45.89855986256754, 48.27602609511345, 49.82447585751934, 49.18292514739498, 46.28732950456681, 43.50306249433949, 42.53536278201688, 44.399202485238355, 46.16774820512342, 45.99790957666213, 43.84757603368452, 42.57322149892008, 45.09621943196943, 44.67732598704677, 42.703000960811494, 45.07049652837938, 42.49636265539354, 43.391898601285874, 44.21948340631301, 43.49544917383502, 41.6722648374496, 53.18406435751146, 47.37526555215159, 44.02289421327653, 46.2296235945917, 44.30925469244681, 52.33507125608383, 55.41150385333646, 56.40392626485517, 54.904788540255645, 53.03637143104307, 57.02134655367944, 50.97506000149635, 45.973787000102384, 44.31771524490849, 42.48669009054861, 42.422492657938314, 41.640262219213675, 43.26119346003379, 44.7037313830468, 48.696206077452636, 54.327635303620376, 61.0957242596534, 57.11163951504616, 50.87793427128946, 55.270122020475334, 55.29094980609033, 55.944581416345414, 59.60818498365341, 58.006744000219534, 54.12638633481918, 52.60295344937233, 52.03393520847444, 57.842706557243105, 56.58149980729627, 61.75663186657814, 57.85292825391216, 56.28563934756864, 54.350294836105846, 53.13135946950605, 47.40519323656636, 47.05508247498543, 52.37323984023064, 48.190424288472826, 50.651762562413374, 49.38799450474401, 58.21502970110986, 58.478491383214156, 62.41400934034779, 54.752930056664255, 45.18246842968849, 18.28791364546745, 1.2661822765104234, 1.0561186387654276, 1.735307800192987, 43.47569611764724, 63.57816096275084, 64.04700186944777, 68.53275775909424, 65.35686169901203, 61.58748357526718, 68.32429947391634, 35.75523214955484, 44.87405638540945, 54.49022146963305, 66.35479896299302, 6.799387018526755, 0.4249775926432302, 0.2979489073397652, 0.19692510726951784, 0.16686668228958884, 0.07533902467619027, 0.10102589915115988, 0.2674978622986425, 0.1847935227617141, 0.3071794394523867, 0.15640886200051154, 0.10888914818004256, 0.09597976992447531], [0.08475179378423961, 0.04433687130409864, 0.05268970031231161, 0.04483316987452488, 0.04684354546630094, 0.05240252076257622, 0.017982356948778033, 0.07460558741924263, 0.04667668768595304, 0.016563724906694506, 0.05692836520592532, 0.04623204259382141, 0.031976389300618926, 0.04580504433702558, 0.06733604120991885, 0.07164810498755786, 0.7852299487398517, 47.667027135049146, 52.78123694081461, 35.61456811043524, 32.04209493052575, 49.02538314942391, 66.5990920220652, 63.48787976849464, 59.613146781921394, 60.01913170660696, 56.302140758883574, 59.108451489479314, 39.81085308136479, 0.09136667189699027, 0.403896507716948, 0.16933665700977849, 0.27396483947673156, 43.61273588672761, 61.47058517702165, 63.246732450300655, 63.2987234669347, 58.58657229331232, 61.988494934574256, 61.1555011810795, 48.984653257554584, 46.20179045584894, 47.18126904579901, 44.908855653578236, 46.66935659223988, 48.82591885905112, 51.38355132072203, 53.156344967503706, 55.747258740086714, 58.706031999280384, 59.70177273596487, 59.25835663272489, 63.26713661993704, 66.44164023860809, 61.74287219201366, 58.310425666070756, 58.48766972941738, 59.68327091586206, 59.262306459488414, 55.081820795612956, 57.36906859182543, 59.0538481743105, 58.967410902823175, 51.445646362919966, 46.55591772448632, 40.91154859912011, 40.596119434602805, 39.554157487807736, 42.140678205797755, 43.35726407266433, 44.42818095607143, 50.905528145451704, 51.785166725035644, 55.089183084426395, 44.37225580215455, 45.94981739597936, 45.870609052719615, 50.51513464220109, 48.45661201784688, 43.30281372993223, 40.64938914391303, 39.41898868929955, 39.05524769136983, 39.55005076623733, 40.19475506198022, 40.64134828505978, 40.95775804212017, 39.6832230783278, 39.64332865130517, 37.59449035890641, 39.94329191023304, 38.50061278189383, 39.39257152618901, 40.371453915872884, 39.44551567877493, 38.295770922014796, 37.80190529361848, 38.72934579849243, 34.07356300661641, 39.43135984482304, 47.32514942845991, 44.41465662371728, 42.252748166361165, 44.89739448793473, 47.688207933979655, 51.762668009727236, 51.920288455101755, 50.226848279276204, 49.145501813580914, 44.348517617871686, 41.889983838604344, 40.3631345687374, 38.863902707253736, 38.434940538098736, 39.87666260811591, 38.6711613593563, 41.51600937689505, 44.26063691416095, 50.48304573182137, 53.50780110205374, 55.90583232141311, 55.69943328057566, 50.799969319374334, 51.93262823166386, 51.249982849244155, 49.93989159983974, 47.41573656758955, 51.71673705500942, 51.311795480789684, 53.97855612539477, 55.281053666145574, 55.80301915445636, 54.43847363994968, 55.41659116744996, 48.78903288995066, 50.229982253043886, 45.69547130215553, 45.515528648130356, 44.51377099560153, 45.053406761538604, 46.27746474358344, 42.49478586258427, 47.17599345791725, 53.05067631506151, 55.92376147547076, 53.95501798199069, 51.37532218810051, 46.32240333864766, 12.06442617600964, 0.41996428262322183, 0.25948537934210997, 0.8152183073182261, 34.73385087905392, 49.619171157959975, 49.6628624393094, 51.59053479471515, 40.173182026032485, 63.327639179845015, 42.85770316277781, 29.68978874145016, 33.38313564177483, 42.55633177295808, 31.11544086087135, 0.07171038027492262, 0.050040215869704564, 0.0200772971560758, 0.01290190889830551, 0.024848559781187968, 0.08731628077164774, 0.05360108447231112, 0.02700795479599507, 0.04088729995513155, 0.029070761445308888, 0.018585172384196234, 0.10281328953081563, 0.05240431340831903, 0.041530564832951755, 0.08952062216497238, 0.09885109810819549, 0.014903270508042507, 0.0456571280806055, 0.07720840944638176, 0.045332502153131275, 0.07573207374662161, 0.07203745385331493, 0.042504733728785674, 0.035239347376890724, 0.07292226242322115, 0.028719718890985655, 0.04103037070543055, 0.03773829554237666, 0.12865035554334042, 1.7435050635568559, 62.611053528324256, 47.8190032897457, 35.206268987348004, 50.700254824853715, 55.0996244338251, 74.1947461712745, 69.19516763379498, 65.87313190583261, 67.59638601733793, 63.13693746443718, 64.46586785777923, 46.5007927340846, 0.3669973006171565, 0.14553589866526667, 0.0712535314021572, 0.5178691855361385, 49.61535076941214, 64.01691729022612, 67.18558834445092, 66.61010603750906, 64.742041941612, 66.88831190909109, 63.981592424454234, 51.859758438602576, 45.982000443243216, 49.355211334843794, 47.744031106272054, 47.74316426246397, 51.986678492638376, 53.37220476519678, 55.78603529161023, 58.40273080333587, 60.7803931543904, 61.92989080182968, 62.60398149490357, 65.12597530118882, 66.2757396697998, 61.729916603334495, 59.678305195223906, 60.62367093178534, 60.9942368538149, 57.06641066458918, 55.316351075326246, 59.434365149467226, 58.8459429433269, 60.43152186178393, 54.48069403248449, 49.25358664604926, 43.903403128347094, 42.64618935123567, 41.2442950279482, 43.37441267505769, 45.309329648171705, 45.38883609156455, 52.873110617360766, 55.11458043129214, 57.658217876188225, 43.74520217218707, 46.87078206769882, 44.27545955104213, 49.12629004447691, 50.962473115613385, 48.40032208350397, 43.55772464506088, 41.02860389217254, 41.16087405912338, 42.52582750012798, 40.33762739550683, 43.94282687094904, 44.11241054534913, 42.704173749493016, 41.12671021492251, 39.18161469121134, 40.856768777293546, 39.48708103549096, 40.23972111363565, 42.43806054515224, 41.902264779613866, 40.276336439194225, 39.059479928785755, 38.876297396998254, 39.28791876762144, 44.41479390667331, 47.34132136068037, 45.53571708740727, 44.5377915905368, 46.125500355997396, 51.06365065420828, 54.829090718300115, 53.971719434184415, 50.9747972026948, 51.52429772961525, 45.14746912064091, 43.61357919631466, 42.25382289578838, 41.65705780829153, 41.13659066538657, 40.78773113989061, 41.916047988399384, 43.26832040663689, 46.87520257888302, 50.75720763975575, 55.191553023553666, 55.744316962457475, 58.4566516260947, 51.34233113258116, 53.83268317868633, 54.73361630593577, 53.099148965651, 48.75559860660184, 52.857170104980476, 53.654038829188195, 56.50044795005553, 56.63357319370393, 58.450007131022794, 56.59576154524281, 56.03042640993672, 50.577668989858324, 52.62686029557259, 47.95773360037035, 48.91184622241605, 45.81297766777777, 47.689721968866166, 47.43223405653431, 45.395366837901456, 50.672833534979056, 55.72722327324652, 58.62975758890952, 57.800827410913286, 55.82351746097688, 56.583005997442434, 15.255035046608219, 0.6007862523678811, 0.49955563920159496, 0.8860803984345929, 38.33259805556267, 54.751643519247736, 54.524479450718054, 58.60743930262905, 45.71964879189768, 67.20691819344798, 47.20904727135935, 36.160107043481645, 30.392302889977735, 44.78504603908908, 37.24375986283825, 0.2166269274969255, 0.03254734888492573, 0.05632695554184818, 0.08190200799295018, 0.03593485562070724, 0.04003868903964758, 0.04464858481960912, 0.03631537532313697, 0.045007876225657044, 0.021864903955570152, 0.020471598780263337, 0.048104384463400617, 0.031964265959217183, 0.1703306714132909, 0.3127910334977412, 0.33662743025249053, 0.09010848739454824, 0.17878069782689696, 0.15191734978748908, 0.13377724575900263, 0.19548956575172563, 0.10066746959402677, 0.12525328419982426, 0.2216106512012982, 0.19070084206759932, 0.1833771181202704, 0.1724286951244839, 0.2205538022662363, 0.2531108076894476, 3.0864579302649346, 71.93976771446967, 64.89825817846483, 49.69525729456256, 45.147626015447806, 64.13235656676754, 79.21956123844271, 74.7609010819466, 70.9664943141322, 71.85846482553791, 68.32853563370244, 71.6926819278348, 53.69448238803495, 0.6957365380179498, 0.895401849862068, 1.4596959636096032, 1.3847443725793593, 57.02346463357249, 65.88691511461812, 72.03014696798017, 66.60612875415434, 69.05533513715191, 68.49624049278998, 68.89719301654448, 52.84675621217298, 49.266318659628595, 51.504532906316946, 49.084634473246915, 51.38967806293119, 55.610034619608236, 56.36673827325144, 59.978550864804184, 61.09370031664449, 62.41678637842979, 62.223593957962535, 64.33663752771193, 65.23417388239216, 67.03696973862188, 63.05578362557196, 61.789179694268014, 60.39422796618555, 63.728881958992254, 60.87768362414453, 58.76385950273084, 62.892758154099994, 61.49726906130391, 61.68462499495476, 57.18984373154179, 51.456436803264005, 47.12768554687501, 46.392264673786784, 43.26053450184484, 45.36485079796084, 46.545978438469675, 46.94118076755155, 55.191678539399184, 57.32466343910464, 57.937106240180235, 42.29458808898926, 45.92867974312075, 43.64966892427014, 52.014637147226644, 52.16876276077763, 50.297980462351155, 46.35118961334229, 42.86156669739754, 43.64570340802593, 45.39306832898048, 45.86081881676951, 46.012649843769694, 47.27560597081339, 44.56045112302227, 42.65011564377816, 42.58010525857249, 44.72894437851445, 41.693461325860795, 41.670393866877404, 45.65962868352091, 44.544036003851126, 42.40243757924726, 41.281294745783654, 41.62796558872346, 40.58851788120885, 45.74665038816391, 52.10786011911208, 47.069324601081114, 43.01674350615471, 46.67158842086793, 51.7208908450219, 54.58198139744421, 54.965973592573604, 52.48957341717136, 52.58218449930991, 47.09367859748102, 46.612956831532145, 44.960823135991255, 44.1696261590527, 44.01949351833713, 43.795989021178215, 43.889694444594845, 46.40204706499654, 49.20992674366121, 54.43877174008278, 57.295845785448634, 58.51747189798663, 57.619994378859005, 55.51587812362179, 54.60107941781321, 54.68646941646453, 52.9616581240008, 49.21231938946632, 55.45951366424561, 55.347106379847375, 58.40231895446778, 57.33124125388361, 60.70023167517878, 57.19149112701417, 58.849743720023866, 55.370479783704205, 56.31351563238329, 50.358863492165845, 51.5998504238744, 48.45496462237451, 49.177394605452015, 51.590342598576704, 47.651839717741936, 53.03122135900682, 60.40204917230914, 62.019144335100734, 61.40780372004355, 59.01227497285413, 53.789674389746885, 17.501021469793013, 1.850874798913156, 0.9368410778622475, 1.2157969801656663, 42.55096204819218, 62.40432500839234, 61.47034983481131, 64.42653825206142, 53.16607636790122, 74.6856386430802, 52.6016394553646, 42.99376626168528, 47.37942718690442, 54.92445922666981, 48.85656433720743, 0.3522692602728644, 0.17690002858158083, 0.12872195412074366, 0.11465348483574007, 0.09153010143387703, 0.1868474504519855, 0.2554060837193843, 0.10657338695901056, 0.19988899419624961, 0.1070863824157465, 0.22368089656435677, 0.29186298229521324, 0.16592528280471602], [0.02942494879056129, 0.06353319224510943, 0.05027442810035521, 0.00661942245055651, 0.017811869826888847, 0.00636697780611294, 0.040556024384474566, 0.014013031332363046, 0.044174453003271934, 0.03821406678687181, 0.06791670521300647, 0.03299138110671793, 0.03839871695926113, 0.024616517494582844, 0.05281091074369127, 0.14342094441094708, 0.11654945285690409, 12.86726474761963, 66.07735403122442, 34.05100153338525, 26.694321709294474, 39.091427633839274, 52.411451570449344, 66.61943343377882, 56.22966320283952, 56.51517645005257, 55.70936472185197, 52.583776981599875, 39.304047553770005, 0.4079876317372246, 0.34256335528146836, 0.1643433878498693, 1.0878685092733753, 53.615101460487615, 60.32093847951582, 62.84341473733226, 64.962361474191, 68.19054665104036, 57.9992954192623, 62.98878169828846, 51.990385132451216, 47.818195281490205, 43.72937933091195, 47.025645086842204, 46.374166857811716, 48.44768470333469, 52.28605731841057, 57.679241780311834, 56.0592911320348, 57.66896909283054, 60.65028813577468, 58.196021895254816, 56.155699068500155, 56.59463974737353, 60.58048563618814, 60.74982612363754, 59.392325185960345, 59.89227441049392, 58.29050787033574, 59.62858130854946, 59.059974916519664, 59.033055690027055, 57.11003526564568, 47.18801160012522, 46.1001814565351, 43.26473143792922, 41.419067998086255, 40.76763291512766, 42.770136248680856, 45.10839839135447, 44.93441381762105, 51.05121674076204, 54.08454641219109, 60.76714731031849, 48.388974666595466, 50.007273997029955, 54.15694944320187, 48.76432980260542, 41.401758578515825, 40.16088931791244, 39.760442779910186, 41.060775172325876, 39.11839785114412, 39.84476197150446, 39.58486180151663, 40.24979768260833, 38.62006464312154, 37.93618371409755, 36.9929870482414, 40.110235829507154, 38.842047260653594, 38.41296349802325, 40.3703321180036, 40.083528411003854, 39.37552098304995, 40.36664116767145, 38.74146984469506, 37.98392288146481, 38.59342390491117, 37.48054158303046, 35.79318500334217, 44.11517973869078, 47.95195594910653, 46.17167057529573, 42.964575982862904, 48.81702292350031, 57.92619028399068, 51.037955207209436, 49.23774811529344, 44.106887848146506, 44.084142023517245, 40.99427138605426, 40.80666442071238, 38.6725773349885, 41.26182017787811, 39.40544082272438, 39.57019605944234, 42.417821115063084, 44.72421400008663, 51.027313816931944, 52.127915197803134, 54.15378801284298, 53.13487783555062, 52.00485867838706, 52.114936074902936, 55.26428161128875, 54.89576316648915, 55.30297579303865, 56.322788115470644, 56.476733299993704, 55.89945454751292, 53.10066300053751, 49.45751459367814, 48.76685580899639, 49.00195483238467, 44.36951014303392, 45.36036360648371, 44.532492468434, 44.55217492195868, 43.22915161809614, 44.39404456846176, 44.35240860908262, 47.18925499146985, 53.94375685722598, 57.322996431781405, 57.89272462168048, 51.075378541023504, 61.79941315804759, 27.027817310825473, 0.31737573264587315, 0.09391412874984165, 0.5488299241950435, 28.212855554396107, 54.78341864001367, 49.74700512424592, 57.161206506913715, 56.93847863904892, 62.87909261641964, 29.79603005993751, 45.607272886460834, 52.93718253412555, 46.623547230997396, 8.992621975560343, 0.40808026708902856, 0.04269816709922687, 0.028327269284355066, 0.016185317691715977, 0.049930787870600346, 0.030337445693270817, 0.09519543378583847, 0.03649801068428544, 0.04870459903031588, 0.06216354578012421, 0.019825177620195096, 0.024688742348864198, 0.04858879717968164, 0.029554021199263876, 0.019842087095903776, 0.059539690809023965, 0.04179117645347311, 0.03146507923731641, 0.09859573802039509, 0.027337897373663805, 0.007468826745847061, 0.02048756022216572, 0.10548154312756755, 0.010767744989284586, 0.028897556626508315, 0.03780884840976327, 0.036151750433829524, 0.058234008855276534, 0.09887549034770458, 0.05823091386006244, 19.83513766719449, 75.24092074363463, 28.345886661160378, 37.645190915753766, 50.67830131899927, 57.26114457653415, 72.5783609574841, 63.95310817226287, 62.98102717245779, 63.43439825119511, 59.07957500027072, 49.59078496502292, 0.3797607544449068, 0.0922013706557693, 0.07240331446331355, 2.7912355911347175, 62.94578075408936, 62.5732458022333, 68.24939004836544, 66.5124390202184, 71.30808568769886, 62.7460575872852, 63.75013336058586, 55.55156384744952, 50.117253334291526, 46.930641358898534, 48.29868954996909, 49.86033808800482, 50.222388544390284, 54.509201818896884, 59.897134227137414, 57.88949258865849, 60.97803746500323, 61.08534566817745, 60.54269359957788, 57.31405342778852, 60.21592878526258, 63.49993321203417, 60.92236726514755, 61.23365832913307, 61.1806788752156, 60.214544188591745, 61.422504763449396, 60.692728181039136, 60.104580540810865, 57.5234648489183, 49.72690689948298, 47.18445008800876, 45.63871068339194, 43.3749500397713, 43.42190081073392, 43.297902922476496, 47.59725601442399, 48.684662542035504, 51.51112248820644, 56.380082176577666, 60.743648390616144, 48.43788270027407, 50.519155071627715, 55.40309036931684, 53.257487204767045, 44.924756942256806, 43.972809468546224, 42.28734739365117, 42.64258077067714, 41.99263226601386, 41.37446672685685, 44.02935043458016, 41.48974518622122, 41.453847654404186, 41.70651497379426, 39.01174468378867, 41.21387704726189, 41.29374434871059, 40.915671010171216, 40.84322483308854, 41.23354381130588, 40.905170825219926, 42.575920089598625, 40.91882459578976, 41.23111586416922, 40.18562378421907, 40.14286602697065, 40.9041117852734, 46.646704904494754, 47.15367517163677, 45.25338096003379, 42.480288782427394, 49.21839906323341, 57.51976997621598, 53.154348481086, 51.21196331516389, 44.970323116548606, 45.10932799308531, 43.24124036296722, 42.04259541726882, 40.84904170805409, 41.52552896930326, 41.155104252599905, 41.588828179144095, 43.62416959577992, 46.35255459816226, 53.65520377312937, 53.28222951581402, 54.91828149364841, 56.9442484455724, 54.34228927858415, 52.35256894942253, 56.91779205876013, 56.02926538836572, 55.27699401301723, 56.9589691008291, 58.42955589294434, 55.85418255098405, 53.62874346394693, 52.43679400413267, 53.56048245583811, 50.608404682528594, 46.42760522903935, 45.61299562454224, 46.56611980930452, 47.05152096286897, 47.0948435414222, 45.08602519189158, 47.70695686340333, 50.05076131513042, 57.590258890582675, 58.75073917450444, 62.80095115784676, 54.25943313106414, 65.17621301835584, 32.68510672353929, 0.24021944782185942, 0.07139403958834949, 0.44822085348348467, 31.176084626105528, 59.90631649571081, 54.986781766337735, 60.50982413753387, 63.07470121691304, 65.50894375770324, 36.15508640966108, 52.497920220898045, 49.17954014193628, 54.10253047943116, 11.078623744749255, 0.4269014539257173, 0.1051780497354846, 0.07366496934405259, 0.023041055763080236, 0.03875060412552088, 0.012732179245851453, 0.0782507716587955, 0.03867506785618682, 0.06909126355763405, 0.03906729721253918, 0.029601827000958786, 0.004816547039926293, 0.02366253884599334, 0.1010304497134301, 0.278702327200482, 0.20230260016697071, 0.21570608981194037, 0.12865374165196575, 0.1484784883477034, 0.11186218985746946, 0.11049319839765949, 0.18349826726461613, 0.23775308903667236, 0.15791237083894594, 0.20389108347796625, 0.11415594903331612, 0.13326562159965116, 0.14864059255248116, 0.22900595840427185, 0.1851687219835097, 25.85333808775871, 84.38721333780597, 46.090269627109656, 40.738658366664765, 51.05354270627422, 66.55456527586907, 77.99698983469318, 70.39060408069243, 66.11091383041875, 70.88510513305664, 63.18743013566541, 53.03044865208288, 0.4217172756550774, 0.3916719507786536, 0.38042712836496295, 4.420222399696227, 69.9157384134108, 64.79002037355977, 72.0456873986029, 70.47290325164795, 73.59932253437658, 65.76897728827693, 67.83693713526573, 58.06660329141925, 53.09734075300155, 49.071435697617076, 53.06397314994566, 51.48252448728008, 52.59359075177101, 59.962065142969934, 62.192450338794345, 60.745268329497314, 61.8670936553709, 63.18445697907479, 61.64322830015614, 58.98896040454988, 61.34590479635424, 62.121510351857836, 62.88390928699125, 63.463992534145234, 63.559172768746656, 63.16733191090246, 62.36875695566978, 64.59749867839199, 65.3123624094071, 60.3040095298521, 52.292505694973855, 50.56939278879474, 49.738160179507354, 45.89067589852118, 46.414265248083304, 45.2428101724194, 49.243427707302956, 49.29665819291146, 52.60675030369913, 58.604693643508426, 63.013935858203524, 48.23041677474976, 51.34627311460434, 58.8923994956478, 56.634706758683734, 46.365663159278135, 46.91429292002032, 45.18864616270989, 45.89808917814686, 42.64589909584292, 43.77143106152935, 45.54730376889629, 42.80022475027269, 43.06995045754218, 44.2345453077747, 40.35785113611529, 45.28323804178546, 44.79239656079201, 43.09119401439544, 45.83918694526919, 44.29061951175813, 43.58126278846495, 45.82189321517945, 44.04567533923734, 45.69563211933259, 44.706469197427076, 43.067479364333614, 42.15857205852386, 50.54816099905199, 48.926727694849816, 44.732215635238155, 42.049075172793486, 50.13384496012042, 59.763365714780754, 53.58957467540618, 50.773630603667236, 49.02448884902462, 46.32829473864648, 46.34681224822999, 45.19757739959225, 44.08820167664559, 45.956312840984715, 43.28315088825841, 45.28570129025368, 44.93806946662165, 48.342447511611454, 56.03803973044119, 55.12756347656251, 57.73365682171237, 57.84750753833402, 58.154232963438965, 55.40835419008809, 61.69255994981336, 57.796387287878225, 57.555636129071644, 58.94185273878036, 62.06748754747453, 58.19785756449546, 56.472450071765536, 56.13012129260648, 55.302481574396936, 53.50886798674061, 48.898451328277595, 49.42364100487002, 50.61652398878529, 49.88686899985037, 48.973921652763124, 45.899458085336995, 50.56635295191119, 51.56258790723739, 61.5229448964519, 63.26933706960371, 67.0485564201109, 59.45398876743933, 69.28695109582716, 32.3727919209388, 0.6792760664416898, 0.5898995300935161, 0.8717723887774252, 36.38977750655144, 66.84664849312075, 61.99360186053861, 67.95250585002285, 67.67688874275454, 74.6200958375008, 41.513342165177875, 61.889921849773785, 67.36790795480051, 65.15758176003733, 19.66077066236927, 0.6409610062837601, 0.20315845827421836, 0.20870072136242546, 0.12842188514168226, 0.11292385748557507, 0.07214671331307582, 0.2890116336845583, 0.15659234005837672, 0.16593139618635178, 0.08367279724728677, 0.08198720463100942, 0.18112979919439365, 0.1704614119784486], [0.03514012749937754, 0.08678664588519643, 0.0394232944405127, 0.049982445179334575, 0.07076017843979983, 0.04855832986293301, 0.08579067029659787, 0.04997947275818837, 0.01855899707504338, 0.02109857279837372, 0.08377688561355875, 0.021218907974299886, 0.03789928508922458, 0.014335344631915853, 0.02015041833322856, 0.03450018361270909, 0.061997687744517485, 1.144417687769859, 44.10019628463253, 46.87053495837797, 36.95662275437386, 34.73106599623157, 46.79317797383955, 58.963206121998454, 66.90644894876789, 59.89997794551235, 56.77542571098574, 52.16023160565285, 49.51604420138944, 0.9873351586922523, 0.3681122343386374, 0.13199736304100484, 3.350282676758305, 62.94218001827117, 57.7414035028027, 61.86379494205598, 60.33523551879391, 68.79765895105177, 61.93999482739357, 60.37509464448499, 57.20022232301774, 50.99904529510006, 45.92303545244279, 46.621229110225556, 44.82588967969341, 48.68826327785369, 50.43844053822179, 53.39202450167749, 54.601165709957, 57.391084855602635, 60.061579596611764, 60.76697080366073, 57.493113548524924, 57.71461371452578, 56.13401620618759, 59.74449911425191, 57.77413175952051, 57.02363721786007, 53.97457491966986, 56.872994669022106, 57.56575976648639, 54.719036856005275, 50.03242423457485, 46.213820365167436, 45.10776688975673, 41.24522070730887, 40.119108230836936, 41.91461632328649, 45.03817227578933, 45.06119266633065, 45.62687689258207, 49.75642665739983, 52.38816053636613, 55.41315124880884, 55.94926472633116, 51.289226162818174, 44.21918530617991, 39.853614760983376, 40.269637030939904, 39.06239032745361, 38.82278842310752, 38.64188478839013, 40.22451016210741, 39.188929911582704, 38.680092596238666, 41.564278064235566, 38.223360046263664, 39.462660358798125, 38.74176794482816, 39.878808144600164, 38.86391055199408, 38.66963947972944, 40.22962101044194, 37.6739771904484, 39.31562639051868, 38.94018496236494, 40.06892934922249, 38.096726325250444, 36.637294753905266, 38.95731787527762, 37.8662556986655, 35.82749397523942, 41.39060728011593, 47.00289926221294, 47.7896757279673, 53.66428406007829, 55.819759830351806, 51.40614809528474, 48.160331864510816, 44.70503360994401, 41.96067671622, 41.38361369409869, 40.877271006184245, 38.71637059796242, 39.73383734303136, 39.2241096496582, 39.933823308637066, 41.15333526365219, 43.734031261936316, 45.880454201852125, 51.7646566514046, 52.13872132762786, 53.403266014591345, 53.037701114531494, 55.17301982448947, 55.16096638094995, 52.33555370761503, 54.220672269021314, 55.451610088348396, 53.52928392348751, 52.08668716492192, 49.61105185170328, 47.597871826541045, 45.0210746642082, 45.27394202447707, 41.76185961692564, 42.786578824443204, 40.45056027750815, 45.637224105096635, 40.57240086217081, 44.21354886024229, 44.86121454546529, 46.07748270034791, 51.20733099599039, 55.906746233663256, 56.365753758338194, 54.40290166485695, 54.50502057229319, 45.86537661090974, 0.295024351367066, 0.10031552880161232, 0.7537118657942742, 28.712798895374423, 54.547335101712136, 51.854961379881836, 52.680196685175744, 55.50220866357127, 50.3593655555479, 32.73588180541992, 44.089347008735906, 36.17031697304019, 31.066115094769387, 0.35206085371394313, 0.00573881778813478, 0.016466450892508994, 0.13035591241092453, 0.08856871961465768, 0.02956070340118341, 0.060130666355572404, 0.1299952382161733, 0.12913882852562014, 0.012647686451072655, 0.07142486696642253, 0.0478138915833927, 0.08432407157435533, 0.009554525059948285, 0.01691936398856342, 0.02937067337634583, 0.021207589025218642, 0.019461117316818526, 0.09464453229860914, 0.07730782467631564, 0.06713798449885461, 0.040063652014660264, 0.016118865309944077, 0.06393430822138345, 0.09010929178686873, 0.12891225036113493, 0.03135982641739951, 0.06198835679359975, 0.05744760044880452, 0.06675690938267978, 0.10458948736589764, 2.864636375058082, 57.45308968328661, 40.65961084058208, 28.91755642429475, 51.0258468504875, 50.862272247191406, 67.00678317777573, 71.40541538115471, 65.00826104994744, 61.45290705465502, 60.50874548573648, 53.56504809471869, 1.2114145895165782, 0.06438553783922427, 0.11721368173077223, 5.785191530181516, 72.87518239790394, 60.68178869062855, 67.34364417291457, 62.88768652946719, 71.01116226565453, 64.28499560202322, 65.6110587427693, 57.875901576011415, 53.4852082498612, 47.36722469329835, 49.73051548004151, 48.20546657808366, 50.85161516743322, 52.88844708473452, 55.702257387099735, 59.569286838654556, 59.84525695923836, 61.256168811551994, 61.394801062922326, 57.94399392220282, 58.72762072470881, 57.67404071746334, 60.89667181814871, 58.57748808399324, 60.39972712916713, 55.658719078187026, 57.89254811502273, 60.03800615187615, 57.55284340150895, 52.90546232654203, 46.466373935822524, 47.60481049937587, 45.31536225349673, 42.622557070947465, 44.022600035513605, 45.047087823191, 46.75484857251568, 45.69725205821376, 50.921982488324566, 55.8203834872092, 57.452520939611624, 57.962884056952696, 53.886745206771366, 48.49774591384396, 43.33307089344148, 41.16969546964092, 40.379706582715436, 40.22522795584894, 41.82540201371716, 42.133284538022934, 42.08778504402407, 41.92800337268461, 40.99909982373638, 42.34481796141594, 43.248124122619636, 41.02601512785881, 41.43378080860261, 40.99011759604178, 41.28355403100291, 42.55562182395689, 40.48970945419804, 40.927438120688166, 41.50617991724322, 42.46396780014038, 38.12611272258144, 39.30414953539449, 40.19983453135337, 39.55187859073762, 40.14328572057909, 44.738562030176965, 48.37117495075349, 48.33333192333099, 54.23871909418414, 59.150110983079486, 51.23999257241526, 50.33095582838982, 46.55570199412685, 45.20668122076219, 43.30441797933271, 43.587060051579634, 40.5575821476598, 41.04666248444588, 40.27098240390901, 41.217113002654045, 43.55452399100027, 45.499250811915246, 48.51451796870078, 54.38797312398111, 52.04755367771272, 55.47164163281841, 55.71191818483415, 55.6644182820474, 55.00586017485588, 55.188826976283906, 56.703701250014774, 58.34915907152238, 55.77167157203921, 53.37305199715399, 52.74249176825247, 51.02114785102106, 46.97350894251178, 47.623849684192294, 44.38989862318962, 46.20188459273308, 42.828312843076645, 46.39868559375886, 42.37334143730902, 46.59930698333248, 46.92394587301439, 50.022873263205256, 54.70043697664815, 58.30588748378139, 57.939134105559326, 58.245690868746856, 58.44431969427294, 51.609436696575536, 0.5424050818527899, 0.19290833974317198, 0.8147133634455743, 32.96051986755864, 59.16440802235758, 57.532458843723425, 58.34902178856635, 62.63168911780081, 55.13591812502954, 41.119214565523215, 49.102049796812, 40.50191194780412, 38.79256656092983, 0.5777051263759213, 0.04655356203476268, 0.021298523661830736, 0.0772584043443203, 0.029222722645969163, 0.031258065043197523, 0.06701764740770863, 0.03092077376711513, 0.023272023611371557, 0.0288193965060336, 0.05553426904483669, 0.02426131699805058, 0.05987247174245216, 0.04134677267903763, 0.12734362404913674, 0.22949380319445367, 0.09223047433601272, 0.17645929819874226, 0.16634465465622564, 0.09276319655679888, 0.1680205639211401, 0.16518024697659478, 0.09652415200346902, 0.20975194721212312, 0.18544791506663447, 0.19993716580492837, 0.2882066591372413, 0.2287280217053429, 0.20838619630423286, 0.24664758434218748, 0.15015740067728106, 3.6736982772427225, 68.1774067109631, 58.31679951760077, 51.71632128377115, 50.395392525580625, 60.24719007553593, 71.84109657041489, 81.3487571285617, 69.38984271018737, 71.97675566519462, 65.34913855214273, 64.72241047889956, 2.069492267985498, 0.6443954090918265, 0.1888862555666316, 8.166550224827182, 77.9645832123295, 63.074069715315304, 72.387129722103, 67.68593372837191, 76.43751036736273, 66.4068409704393, 68.21057427314021, 61.28427259383663, 56.129936941208385, 50.33900845435358, 54.234255436928045, 50.202725702716464, 52.87076896236789, 54.97166102932346, 59.97902547159503, 60.2734778004308, 62.936825982985965, 63.471013576753684, 66.10336719020721, 59.7859154209014, 60.374318015190866, 60.50862781463131, 62.96942087911791, 59.218662246581054, 63.02554999628375, 59.19466126349665, 61.703315088825846, 62.686821952942886, 59.40138978342856, 53.452346632557536, 51.8655635464576, 48.85936490951046, 47.52211516903293, 43.90902388480402, 46.89634807648198, 48.8692061362728, 48.27681449151809, 47.22756870331303, 52.64485612992318, 58.56854508000036, 60.42541080905546, 59.799145575492616, 55.00445596633419, 49.716728348885816, 45.58733155650478, 44.95074656701858, 41.23594430185134, 43.21057527296005, 43.975249182793405, 45.034991233579575, 44.05981548370854, 43.54407087449105, 45.306619290382635, 45.49637571457894, 46.21336929259762, 43.029522588176114, 44.72215475574617, 43.03264871720345, 44.86758055225496, 46.00714675841793, 41.96237510250461, 43.05955225421537, 44.839504226561516, 46.94489132973456, 41.01070219470609, 41.6487737624876, 43.59974107434673, 42.52163840878395, 44.94805582108037, 47.941938215686434, 51.10266254794214, 50.48315948055637, 54.25638937181043, 58.87221890111124, 55.54077732947565, 54.0847856767716, 48.55618138467112, 47.7439683483493, 45.895072875484345, 45.06946102265389, 42.880833379683956, 43.56998989658971, 43.88976112488778, 44.09217503763015, 44.3027239461099, 46.58080516322967, 49.38362106200188, 56.31992870761503, 54.805685935481904, 57.887684376009055, 57.22709055869811, 58.44895985818679, 57.199480995055175, 57.28139577373382, 58.845625231342936, 59.42491223735195, 59.36646107704409, 56.114231771038426, 54.92103891987955, 52.97231912612916, 49.049399821989, 50.176873360910726, 47.1035433584644, 47.427433075443396, 45.1597265274294, 50.07854738543111, 45.03110808710898, 50.617320229930264, 50.500594415972316, 52.81054096837198, 57.59051776701405, 63.46442007249402, 63.70777568509502, 63.823297331410075, 61.93449174204181, 51.97376212766094, 0.782901102737073, 0.42647976848867636, 1.4616838698425603, 37.47193198050223, 67.5502432546308, 62.824242191929976, 64.92129425848684, 68.54495633033015, 64.34360757950815, 44.03898769809354, 53.61315596488215, 48.281689997642275, 51.12059170199979, 1.2362070333573127, 0.18562204685182343, 0.10521266924878282, 0.32518134121933295, 0.18675863021804442, 0.11734497387923541, 0.20547057291673076, 0.20381727856734108, 0.2717858709154591, 0.1369178691698659, 0.15526535319945506, 0.13813657716156977, 0.20117877982556823, 0.11794677424815395], [0.051263393984446605, 0.01333992158423268, 0.024772969885699214, 0.03429430131349833, 0.1045435757165955, 0.054627197959850875, 0.05319250679965462, 0.043694403157719684, 0.04991651948301062, 0.05784060738440003, 0.02994525272609486, 0.05038349986857465, 0.055684330347444744, 0.024548017742833304, 0.08470399755864375, 0.11268579566310491, 0.15625533798048574, 0.24295859519512425, 15.918197035789492, 56.42802138482371, 40.55267134020406, 30.55257093521857, 38.765137426314816, 54.72490864415323, 55.65370236673663, 54.566519414224935, 60.4863291402017, 49.384664412467714, 57.07361213622555, 3.828016822376559, 0.12435103946876143, 0.07998883363700683, 12.738610025375122, 68.44502218307989, 59.53258522095219, 61.684617150214414, 57.10831334514003, 61.29814209476594, 63.5956076652773, 60.136473332681966, 55.899846784530155, 52.37166696979154, 45.27380866389121, 46.80208567650088, 43.84570506311233, 48.79379856971003, 48.444429136091664, 53.14225973621492, 51.704801282575055, 55.05657642118393, 57.99139576573526, 61.09246084767004, 60.560963999840524, 61.68648027604627, 59.82554704912248, 57.53806783306984, 57.65778641546927, 58.02432406333185, 55.33160909529656, 54.36336025114983, 49.89837331156577, 47.24663534472066, 47.45256370113742, 44.350820049162834, 46.27700974864345, 42.22254199366416, 42.141105744146536, 42.15904666531471, 45.311310445108724, 46.53262276803294, 45.08089080933602, 46.18226097476098, 51.525144961572465, 50.40408449788248, 46.17378473281861, 40.79703892430952, 39.95968741755332, 39.57484799046671, 38.25267584093156, 39.25873241116924, 40.58742746230095, 40.05609535401867, 41.04122215701688, 40.12889454441686, 39.16617231984293, 38.875116763576386, 39.36036886707429, 39.04317855834961, 40.146474607529186, 39.34758978505289, 39.61992779085713, 37.33538643006356, 38.540624880021625, 38.41328513237738, 39.35976874443793, 38.36587936647477, 39.080750942230225, 39.52790114187425, 38.41724280388125, 36.849557738150324, 37.06696687206146, 38.49006945087064, 35.23551810172297, 38.41196721599948, 47.58352379645071, 49.19701037868377, 48.379458996557425, 49.95270990556287, 47.82939364833217, 42.55676323367704, 42.89096486183905, 42.07693969049762, 42.84559480605587, 38.60186092315182, 38.50893997376965, 38.98264461948026, 40.48237069960564, 40.00944268318915, 41.53173415891586, 44.218192946526315, 46.07477234255883, 54.27859783172608, 54.23742471202728, 53.47146818714758, 54.046040504209465, 57.5342199879308, 55.98373451540547, 54.120012483289166, 56.813755112309615, 54.10047515746086, 53.55144923733127, 48.96681431801089, 46.23805669046218, 42.26744136502666, 42.796310224840724, 42.71183021606938, 44.1551604578572, 42.83289809380808, 44.67880472060173, 43.10960561998429, 46.91354374731741, 43.764398251810384, 43.960610897310325, 46.276346868084325, 55.41646565160444, 49.09324015340498, 56.16458323694045, 49.71869737871232, 53.92392535363474, 2.49260691865798, 0.2352896260638391, 0.9757288040653352, 31.629312538331558, 54.47504974180653, 51.854996681213386, 54.714883065992794, 58.610188884119836, 40.98531661495086, 33.796824101478826, 32.320283151442005, 46.55359568134431, 12.120413107256736, 0.33615233316536874, 0.047563078227422895, 0.21338488936664599, 0.10255918582721103, 0.09221798710284695, 0.014884041701143068, 0.049388547007355, 0.053107448057421756, 0.0705255946565059, 0.0209015924408431, 0.10531615240559464, 0.03752102534617147, 0.030562725338724353, 0.03166974537194737, 0.05137892387386772, 0.009473268986649571, 0.015448417717350588, 0.0418410181338268, 0.05953405623234088, 0.048596810459369616, 0.056271387354260495, 0.008960566558544675, 0.022028683977682265, 0.04313834589875994, 0.0282536635565902, 0.03944770200178027, 0.06522690922382378, 0.0327728315436792, 0.06568518302012837, 0.05832382500351918, 0.08342909701769391, 0.24118053576638623, 23.760337829589847, 68.45619309333064, 35.32756436255671, 45.40994628783196, 49.07196129522016, 58.81333628008443, 68.708707440284, 58.40330346938103, 69.11817150731241, 54.661985981848936, 65.52060104185536, 4.441642953503517, 0.06867089579182287, 0.07880824618041515, 15.888705715056389, 77.08060649133499, 62.613410872797814, 65.83754816362935, 58.46265677482852, 64.93097074570196, 65.19143965936476, 63.367286497546786, 56.873139796718476, 55.74649780027328, 48.872748036538404, 49.13460939161239, 46.11509038556007, 52.39768012877434, 50.11611976931172, 54.5909793146195, 54.00016446267405, 57.31107634882773, 58.896310098709606, 62.30119805182181, 61.938594541242054, 62.70378228156798, 62.054567260126916, 60.31025394316643, 58.85674122841128, 59.08825912783223, 57.63820986593924, 57.02363721786007, 52.92503495370188, 51.13894447203606, 48.24940104638377, 47.52455488328011, 46.74105359661964, 44.46858136884628, 44.08933524162539, 44.543643766833895, 45.869616693066014, 46.58815176256242, 47.44902180087182, 49.426700453604425, 53.90767497401084, 53.35890008557228, 52.06385897051904, 44.600733864691954, 42.001441909420876, 41.13712410773001, 42.09687317571333, 40.991337453165364, 43.33558121035176, 42.075178546290246, 42.95671947540776, 42.42686610068045, 41.10475278669789, 41.56783173161168, 41.742239921323716, 41.497425187018614, 41.436346038695305, 43.21349743873843, 41.6650672881834, 40.27874085210985, 40.90361364426152, 41.62356468939012, 42.287943593917355, 42.59902677228374, 42.95883755530081, 41.44279049288842, 42.440406122515284, 40.52512061211371, 42.00738822260211, 39.84926093009211, 40.061814169729914, 43.78744217657274, 48.62639965549592, 53.36132803270894, 53.319084105953095, 50.95103940656109, 51.7120498226535, 44.69960112725535, 45.09366596898725, 43.64243607367239, 45.13965968162783, 39.693821322533395, 40.693304000362275, 40.59955150850358, 41.28653503233387, 41.113903676309896, 44.128911956664055, 44.2532903148282, 48.34515786940052, 53.277083366147934, 57.93699249144524, 54.53134752088978, 56.15638940565048, 56.96181281920403, 56.19839406782582, 56.02777881007041, 58.721011530968454, 56.114749523901175, 54.18225657555365, 49.13484473382273, 49.242502027942294, 44.52826023101807, 45.38662779715754, 43.905113281742224, 46.51368948721117, 43.921014570420795, 46.44818198296332, 45.119333959394886, 48.62236353658861, 46.99910240788614, 48.67435063085249, 50.81170112855973, 57.957431962413175, 53.564616633999734, 61.46362689233596, 54.03432438450476, 61.31051325028943, 3.515015114699641, 0.3022474879699369, 1.3453618148642204, 35.110170918126265, 58.280937287115286, 57.13684466577346, 60.83809121962517, 64.92720134796636, 46.323784012948316, 41.49925301151891, 33.87634623435236, 52.72103248103973, 13.574753442118245, 0.39842069509529304, 0.08380775129602802, 0.0854697790477545, 0.09267311993866198, 0.1848251315494699, 0.018034701821424307, 0.06376245554776923, 0.035709897732181896, 0.026577670022004077, 0.033413706227175655, 0.061502752810596466, 0.05393719405777032, 0.01916870155612067, 0.0437174394216028, 0.18743885500777155, 0.23741145978771874, 0.06680763206414639, 0.17330503842282682, 0.3041179376023431, 0.2634114267364625, 0.10108183123051159, 0.07892266141190644, 0.1776122452030259, 0.18974252736135838, 0.1361942838036245, 0.12315151431868154, 0.24058606685890307, 0.10775679361916359, 0.25650558843007015, 0.28013144890146874, 0.3399279208913926, 0.5361853059261077, 33.08916576447026, 77.27863911659487, 53.41289151099421, 44.3234379829899, 51.67797227059641, 66.49235648493614, 69.94534446347144, 63.99848999515657, 76.28804452957647, 60.250112241314305, 70.97437827817856, 4.885938157958369, 0.30215525098385354, 0.14523223673384036, 19.28885348381535, 82.61959721965175, 65.0911799553902, 71.09943912875268, 61.958563327789314, 70.55843445562547, 67.66242304155904, 66.6204297158026, 60.20425973399993, 58.76421643841652, 51.25522313579437, 54.808109960248395, 47.586696993920114, 54.19886781323341, 53.45381359900198, 61.25947536960725, 54.49164529000559, 60.54952244604788, 61.47397410485053, 65.46536230271863, 63.805289729948974, 64.87336681735131, 62.921552273534964, 62.2610604378485, 62.7424019382846, 63.16760255444435, 59.2740108120826, 58.931811471139234, 53.966992978126775, 50.79434071817706, 51.779498900136645, 49.89564726429601, 50.37248196140413, 48.98328042799427, 47.25833185257451, 47.56229592907814, 48.77745797557216, 50.02475207851779, 48.279030630665446, 50.46218264487482, 57.12539526724047, 54.70140972445088, 52.1749875622411, 45.697052017334975, 43.47687282869893, 44.03096645109115, 43.841645409983975, 44.37176942825318, 44.35904133704401, 43.97253098026399, 44.64917905869023, 43.806489206129505, 43.294925843515706, 42.86184126330961, 44.47938357630084, 44.87361707995015, 46.451347335692375, 46.38805989296206, 45.10916717590825, 42.48594876258604, 42.724020942564934, 42.671159159752634, 45.233596524884625, 45.09087716379474, 44.41400943263885, 43.826991435020204, 45.363489735511045, 41.847386898532996, 42.91109838793355, 42.91771542641425, 41.96668186495381, 45.45882686491936, 50.483359521435155, 54.17507079339797, 54.586876515419256, 53.43611586478449, 51.32511977226504, 46.63385521981024, 46.12964630126954, 46.275974242917954, 47.51627083747618, 40.68580835096298, 42.37211765781526, 43.55933281683153, 45.985408982922955, 41.866018156851496, 44.92237998593239, 47.89288897668162, 48.66927116147934, 58.0897609649166, 60.53986164831347, 57.261862370275686, 58.34962191120271, 60.98304633171328, 59.27713301873977, 58.74523608915268, 60.551067859895774, 59.99537783284342, 58.19035799272599, 52.87908046476303, 52.4840703318196, 48.22126588513775, 48.097260152139974, 47.157017031023585, 49.0634693637971, 47.47562331538047, 49.5391587288149, 48.09133345080961, 52.62552668971401, 49.65027555342644, 49.99451452685941, 54.81745696836903, 65.08220949480611, 56.807298891005985, 64.19795820789953, 60.269594653960205, 63.27638164643319, 4.1918419061168555, 0.36013934280603166, 1.928959628266673, 39.68944003505092, 66.39115933449038, 62.325501057409475, 66.09061948714718, 70.09401798248291, 54.59885543392551, 46.64361015442879, 42.10442373829503, 63.82989475803991, 22.546072044680198, 0.42431691841733077, 0.1681326579062208, 0.24823199206542587, 0.1613934743668764, 0.21969753047150953, 0.11552419738783953, 0.13274984524375008, 0.14220931507166357, 0.23801696036131154, 0.10033890214418212, 0.18518258817493918, 0.09897888157396548, 0.13293246528314007, 0.11926390155549012], [0.05725042090841359, 0.019217210243486108, 0.022748209077924974, 0.031662392843094085, 0.01926394160686722, 0.03565321871710401, 0.06012335404633515, 0.028863021382881753, 0.06744523172176654, 0.05569132089975381, 0.04236606415361167, 0.026915861451397502, 0.04012253353252046, 0.05043953536979614, 0.009512662185325978, 0.05406869688041268, 0.011571886415983881, 0.07232633794868186, 0.8221183693216694, 36.58959088786956, 47.85625796164236, 29.748967501424975, 31.82745302877119, 42.82040534480926, 53.38163414309102, 60.513934781474454, 60.4458071339515, 51.92002957867038, 47.04648856193789, 3.4750422402735683, 0.12140775264631357, 0.18417567285078187, 15.367280533236844, 73.28044168410763, 57.31309636946648, 59.32817874416229, 52.51792430877686, 60.5159548021132, 56.301583782319106, 59.36504117904171, 51.85977412808327, 53.67267400987687, 45.897657717427904, 43.993558806757775, 42.5973048517781, 43.92542331449447, 45.23307092728154, 47.64002161641275, 49.141344101198264, 51.788998880693995, 53.342669317799235, 54.69374933550435, 57.464378264642534, 56.55687908972464, 60.47093383727535, 60.29651780282298, 54.8504872475901, 50.40306860400785, 50.12313296717983, 48.21380945944017, 46.47936482583323, 44.43673956778742, 44.97417880642799, 43.99022086974114, 44.09623469075849, 40.66403919650663, 43.86777231770177, 41.66667545995405, 46.672506255488244, 51.75018310546876, 42.174481191942775, 44.43349576765492, 49.726769616526944, 43.955280396246145, 41.99869232793009, 41.9188367935919, 42.69274004044072, 39.60082584811796, 39.30180395803144, 38.645579661092455, 39.81041377590549, 38.15198467623803, 39.01685945449337, 39.60528558300388, 40.60609794432118, 39.26941302514846, 39.97904823672387, 41.21379859985844, 39.97563969704413, 40.33726653745098, 38.217900106983805, 39.0518234622094, 39.448790857868815, 39.37148094177246, 40.19741835132722, 39.082080625718646, 40.149173198207734, 39.36108666081583, 37.14621443902293, 39.04337467685823, 39.07514195288382, 36.76192806613061, 38.8013409030053, 38.00944182180589, 40.46017008443033, 40.7869819671877, 46.39893662544989, 47.85679532635597, 45.69778942292737, 41.274089351777114, 43.34653639024304, 48.41374443423364, 41.0366290615451, 39.84877455619074, 39.03716164250528, 39.522707923766106, 39.77551644848239, 41.57821816782798, 43.25696514498803, 41.438307223781464, 44.56401263513873, 45.34265802752587, 50.671068468401515, 53.564287154905266, 56.568065689456084, 51.974397551628854, 56.48886519093668, 53.64972814436882, 52.983380210015085, 52.366309012136156, 50.05282840421123, 46.328690898033884, 45.84013223648072, 40.82200873282648, 42.09136224562123, 42.011408652028734, 45.18145645818403, 43.58742483200566, 45.311039801566835, 45.14414295073479, 54.36769054782007, 46.88350623653781, 50.2603139415864, 46.29469571575042, 49.84554290771485, 46.91832119418729, 54.72665802125008, 48.977271356890284, 58.545112840590946, 5.458681179631141, 0.4306020876092296, 2.0952740071281313, 37.52306007569836, 52.32453184743082, 53.12043174620598, 54.01822697731757, 57.59237304810555, 37.7057993796564, 31.775820909007905, 37.35989732127036, 29.26021468254828, 0.156447779267065, 0.032844299886135325, 0.053748809206750126, 0.1138023688127437, 0.04031668702561048, 0.04328143197081743, 0.010028669325214241, 0.020085203183454373, 0.036158514990200924, 0.006848389851755553, 0.04781557697682612, 0.013418750116421331, 0.051725850620817755, 0.026437941330274748, 0.012789930784023337, 0.039896054959465424, 0.034562125651826786, 0.010454129660502078, 0.023384521707832333, 0.01047930809774346, 0.048455969024930275, 0.036971223195113485, 0.03627388783159756, 0.044475445118282116, 0.01591836094796177, 0.03532456699758768, 0.019617535233978304, 0.04173572700951369, 0.06437588513137833, 0.08185328480096594, 0.010760716132579312, 0.06622230258559988, 0.16515496607509353, 2.2834271625165017, 51.03538605474657, 45.732000335570305, 30.29160191935878, 48.288907158759336, 47.79369223502375, 62.16505650551089, 63.48615000324865, 67.52041755184051, 56.9834525354447, 57.48717115771387, 4.594031447364438, 0.03340530990352554, 0.4225534146591541, 17.7619198829897, 82.34154824287661, 59.52601525091357, 64.94914700908046, 55.949319639513575, 64.98387175221598, 58.22592604544855, 62.63329728957146, 53.83198891916583, 55.25877460356682, 49.28068630156979, 48.33412816447597, 46.48137307936146, 48.382239957009595, 47.36223151606899, 49.121912679364605, 52.26275451721684, 53.884642816359005, 54.78980818102437, 56.83958391989432, 59.782710844470614, 60.96238720801569, 63.78736842063166, 61.852718168689364, 59.04334406698904, 53.83045919479863, 54.05339887065273, 50.383786232240745, 48.852120291802194, 46.65443981847456, 45.89002086270241, 45.4487189169853, 46.24765473027384, 42.51777095179404, 45.631485677534535, 45.33785704643496, 48.63760194470806, 51.02903573743759, 44.959858232928866, 46.01352845468829, 52.06019155440792, 47.4496768366906, 44.88443889925557, 43.3591389656067, 45.81346404167914, 41.93092161609281, 42.23117120804326, 42.31075217646938, 40.8604871842169, 41.69539505435575, 42.71852962432369, 41.3701521196673, 43.82869374367499, 41.4477248345652, 42.616834332866055, 43.607115130270685, 41.91385538347306, 41.24700538573727, 41.64954254704137, 41.280667166556086, 41.998715862151116, 41.40773627065843, 42.90293593560496, 41.00938427832819, 42.62047821475614, 42.215379745729514, 40.6141701821358, 41.86488851424187, 42.23706260804207, 39.38953953404581, 41.07447993370795, 39.4401930224511, 42.77547459448538, 44.65385060156546, 50.08834938849173, 49.99589520116007, 48.82356543694773, 44.752415841625584, 45.91064076269827, 47.98014210116479, 42.89076874333043, 42.960775206165934, 39.629302255568966, 41.24200828613774, 41.50810580099783, 42.08796939542217, 44.39703341453306, 42.424308715328095, 45.87846556017476, 47.18199076191072, 53.21797324765114, 55.99334432232765, 58.169851841465125, 55.38166638343565, 56.61294544896772, 55.631482139710464, 54.60727676268547, 55.45060988395445, 51.721275237298784, 48.924229145050056, 47.70397978444254, 43.06531029362833, 45.23879366536295, 44.41833972930909, 46.30708648312477, 45.82988700559063, 47.96114998479044, 48.461130588285386, 54.51315949040075, 49.673692103355165, 53.153513016239295, 49.84706086497153, 52.83316912189607, 51.23567796522572, 60.07062065985895, 52.66966904363325, 62.9563162403722, 6.6221022605896005, 0.6124033935127721, 2.575340246961963, 42.69445411620602, 59.68742470587454, 58.03540083669848, 60.307300398426676, 60.7870101928711, 45.06208304435977, 36.46892309188843, 41.299298424874586, 36.050551322198686, 0.0758652274887408, 0.04054732162565474, 0.023871585088331374, 0.06818894221777878, 0.03775975749557538, 0.025004167560367815, 0.044497244150167516, 0.057623559353692885, 0.08247868067795232, 0.06013449679519381, 0.036527033925296805, 0.04926087079389442, 0.05291512934491039, 0.02457747190830208, 0.003608241325221776, 0.11454689136195569, 0.1126847537835279, 0.10191834561767117, 0.09511448127487976, 0.06877843155375413, 0.1809112343095964, 0.13749367617551359, 0.1849088343160768, 0.31765468058086216, 0.1610981168285493, 0.19967484197789626, 0.24884221174063223, 0.15029063868907191, 0.11706624044886521, 0.15762539430251046, 0.167431365698576, 0.24986792686245135, 0.34338313064748244, 3.5871009240227365, 63.15899687428629, 58.76337705119964, 42.750045868658255, 46.6825436007592, 53.94603183192592, 70.26961465035716, 73.2370916489632, 72.82349340377316, 63.13414081450432, 66.26003449962985, 6.820311882803518, 0.21871321474111852, 0.46677369504205646, 20.984737296258253, 87.03370709573069, 63.85773181915284, 68.94858391054215, 57.67610388417398, 69.6625651082685, 60.209711828539454, 67.29989405601256, 56.08646923495878, 60.19537556555964, 50.913302283133234, 50.92043707447668, 48.33914487592636, 51.557932053842855, 49.496765751992505, 51.71060639043009, 56.75946950912476, 58.58747051608179, 58.2113112941865, 58.80837055944628, 63.02022341758975, 61.17929820091494, 64.28208520335536, 64.26941594769879, 58.175696173021876, 53.988922949760195, 55.642413785380704, 54.54341665390999, 50.15453938514956, 47.90506009132632, 47.62271611921249, 47.36360826799947, 47.41205738436791, 44.82704677889424, 47.782984164453325, 45.95385743725685, 51.86543803061209, 53.40955357397757, 46.35631222878733, 48.46961075259794, 54.15132476437477, 47.16127280266055, 46.061067581176765, 48.07818174362183, 48.76467497118058, 44.3457954929721, 43.88810980704523, 42.952679434130275, 43.69459967459402, 42.58098779186126, 44.90451751216766, 44.174003524165, 46.8699779818135, 43.50969522230087, 45.579443670088246, 45.85441750864829, 43.68351505648705, 45.58717466169789, 43.83817411238148, 43.94061465417185, 43.827685694540705, 44.71302740035519, 46.28495254824239, 43.33691481621035, 44.83483660605646, 43.17317547336702, 42.17837218315371, 45.12818674887381, 45.9285738391261, 42.44783509162165, 44.89916739925262, 42.667907514879786, 45.19042299639794, 45.43270387957173, 51.17406537455898, 52.36139428231024, 49.680701378853094, 46.92281623040476, 48.27483761695124, 50.035028688369266, 45.59338377368066, 44.71018368198026, 43.22702177109257, 43.055637728783395, 43.2850806943832, 44.48339616098712, 47.731938439030806, 44.50218039174234, 49.05844872997653, 49.56659570817025, 54.03357521180184, 57.855842574950195, 61.4135068462741, 54.953598514679946, 61.64349109895768, 59.696226504541215, 57.302011751359515, 58.23012298153293, 54.85211895358179, 51.5171354816806, 50.54439160131639, 44.877406089536606, 47.5536863265499, 46.99614494077621, 50.07663719115719, 47.376626614601385, 51.15069589307232, 50.12849876957555, 60.43833109640307, 52.896680139726215, 57.874634650445756, 52.90330894531743, 57.55893876475673, 53.74959953369633, 64.73002379940402, 57.63749599456788, 68.96367719096523, 7.468222716162282, 0.6713082004458674, 3.1297814894107083, 48.92233464025682, 65.21438552487281, 64.97854909589215, 65.6808808542067, 70.32267647404825, 51.45775864201208, 46.15562415892079, 50.40655951346121, 49.74251008802845, 1.0398753684374595, 0.1735584449864203, 0.12285933604524021, 0.2922548822337582, 0.20681372423085476, 0.14464634801110915, 0.10368375693477931, 0.14446144502970482, 0.2475744741217744, 0.12635286551930253, 0.16193278494381136, 0.10174908615168064, 0.2457330898652154, 0.28720185821575506, 0.06586558140453792], [0.0409066551665385, 0.03252926537947309, 0.04714598548748801, 0.018744193085078752, 0.008844361554140286, 0.047715361185011365, 0.025021149814429305, 0.060957838300495386, 0.02037524790202658, 0.03525042500827582, 0.085148788207481, 0.020160262563055562, 0.08487528715763362, 0.026113773140335278, 0.0460327563116387, 0.018616156810293757, 0.040944423301205526, 0.0832217016948327, 0.20533929609002607, 8.132865890379875, 54.79372662882651, 39.345958079061205, 35.80288894714848, 35.98481632048084, 63.055850305864894, 57.36050213536909, 64.50166733034196, 50.930988250240205, 55.2524438981087, 12.923173231463279, 0.031615056270252795, 0.5026388979486881, 10.322729079954087, 76.59613886187154, 59.52818039924868, 65.2420578464385, 53.33095319809453, 54.329082658213956, 53.22650440277592, 54.099223921375895, 51.37598506865963, 51.25993782474149, 47.16435186324581, 43.49910874520579, 42.945230853173044, 44.893950646923436, 47.399376361600815, 46.20300246823219, 44.94411383905719, 46.231773053446126, 47.81770106284849, 48.62822747999623, 48.40842177790981, 47.93162630450341, 49.13768452982749, 46.7010767998234, 47.191125962042044, 45.374044833644746, 44.94482378805838, 46.875885071293006, 44.53672470584993, 45.47300623309228, 45.61160710550124, 44.52707567522603, 43.95447238799065, 42.513377897201046, 42.46701548176427, 42.95835902613979, 48.166054602592226, 47.82888766257994, 41.44938791951826, 46.63238433099563, 43.412863669856904, 43.09190396339663, 43.04919327459028, 39.39287747106245, 41.267829248982096, 41.37245062858828, 39.94816741635723, 38.93441907821163, 40.39061077179448, 40.36205983931019, 39.2776813814717, 39.953984291322776, 39.3143908439144, 38.43917669788484, 38.91980040457941, 37.87313553594774, 39.9704150999746, 40.475106470046505, 40.745773546157345, 38.17612294227847, 39.080335170991965, 38.14461454268425, 38.8509157396132, 39.611883009633715, 38.935321223351266, 38.83059393975043, 38.85688558701546, 38.442604849415446, 39.323408372940555, 36.50407145100255, 36.354609535586455, 37.92605223194246, 39.02257827020461, 39.20291708361718, 39.393956122859834, 45.08645273024037, 43.63313613399383, 40.54421078774237, 42.29455278765771, 49.958820958291334, 39.73491207245858, 39.19676680718699, 38.46099292078326, 39.039687648896255, 40.275857910033196, 40.17656703149119, 42.76324856665827, 41.65905429470924, 41.07248344729024, 41.71284567925238, 45.3021752449774, 49.86328378800423, 53.945153221007324, 55.30065767226681, 53.50971521869783, 52.33194904942667, 52.612853511687256, 48.5952756481786, 48.67231492073306, 44.12473071006037, 43.815279237685665, 42.41169045048375, 42.372502050092145, 42.57387653473885, 42.56446284632529, 44.38474070641303, 46.93016282973751, 47.89541106070242, 48.51158011344172, 47.76903621612057, 46.66639912512995, 43.260675707171046, 46.68542262046568, 48.35959219163465, 55.71738204648418, 51.50912207941855, 56.49600782702046, 5.778343562156924, 0.6200029857216344, 3.57776592816076, 35.20688087709489, 56.7474631340273, 48.43785916605304, 57.89998100649927, 50.35930279762515, 24.826626316193614, 29.84028224022158, 37.32421159744263, 12.429292894178822, 0.07901456131930314, 0.03636978671795899, 0.08743065003786357, 0.03617698537005532, 0.07597893791934175, 0.0684249202810949, 0.07272622052339778, 0.02835243718788749, 0.023525989419149778, 0.04868892870182472, 0.03280661602113997, 0.11431731013280731, 0.04687259935082928, 0.08254440336097633, 0.006213537576953851, 0.04926057585004357, 0.008121737628243864, 0.08745075984587593, 0.024489806551906853, 0.0257286281820627, 0.03690533963362536, 0.10110973981359314, 0.003026332908062144, 0.027610023295687094, 0.05064427619799972, 0.028301072907784296, 0.06671040018479671, 0.061599199449823755, 0.029774742621567943, 0.008438409647844251, 0.05272574474914901, 0.03470351483913199, 0.11622854628630223, 0.12456494653897902, 16.3731498102988, 67.97269036692958, 30.39273435069669, 41.879087494265654, 43.71429389522922, 69.3659633205783, 66.6055953118109, 69.84354326801916, 56.03212479622134, 63.71631468496015, 16.133851889641054, 0.14042198597904176, 0.5141569073161771, 12.561606207201558, 78.74344825744629, 60.69562289022631, 67.48423760937106, 54.46410632902577, 57.15916295205393, 57.01556105767527, 57.060154484164336, 53.545393097785215, 55.189093697455625, 49.69171931666713, 45.3936606068765, 46.174937909649266, 45.78836479494649, 47.88968047788067, 48.27757543133151, 47.16400669467065, 49.168357464575, 49.17634733261601, 50.57243654804845, 50.87684777475173, 53.893864308634114, 50.97217313704952, 52.07774808329921, 50.04489737172281, 48.57283576842278, 47.315739662416526, 46.187324754653446, 47.158444773766306, 46.81106790419548, 45.82947907909271, 46.6218606118233, 45.526550508314564, 45.05573272705079, 43.73375277365408, 46.81991284893405, 50.28926887819844, 52.095112416052054, 45.331365523799775, 49.21166043127737, 46.28799238512593, 46.24909816249725, 44.455684615719704, 44.22069541869625, 42.811693760656546, 44.23704777994464, 43.98569053219211, 42.01708824403825, 43.72611199655841, 41.53173415891586, 42.13171558995401, 42.39345927392283, 42.81334115612892, 42.23436009499335, 40.96738353852303, 40.54642692688973, 42.55710447988203, 43.23469392714962, 41.994224748303814, 40.482072599472545, 40.75510878716746, 40.92551615930373, 42.31004222746819, 42.35673019962926, 41.17939549107706, 41.232516150320734, 41.93138837814331, 41.59479018180601, 41.537213710046586, 40.95893475317186, 39.75896796872539, 40.48885829987065, 42.00437584230977, 41.69563039656609, 42.58389426815895, 49.14816510292792, 47.71786889722271, 43.361264890240086, 44.96381198206256, 50.194006273823405, 43.265657117289884, 41.546682311642556, 39.748679591763405, 41.31600379943848, 41.46520683842321, 42.90108065451346, 42.95567220257175, 42.58227432927778, 40.937816712164114, 43.438425756269886, 47.901114186932965, 52.2061154919286, 55.379124687563994, 56.17529915225122, 57.157566547393806, 54.35722174183015, 54.91755193279636, 51.66429496580555, 51.1854677046499, 47.07811463263727, 46.54104801916307, 45.870663965902025, 44.59618783766224, 44.47348433156168, 46.172784528424664, 48.34258479456748, 49.71948969748713, 51.86912898094424, 52.40711342903876, 51.05288374808527, 50.65841097985545, 47.24325033926195, 50.806727563181234, 52.56443969665035, 60.25458766568092, 55.842548801052956, 63.592101066343254, 7.315087991376077, 0.5866546267943998, 4.154338163714256, 40.403307484042266, 62.8029162653031, 53.084644040753766, 63.32607807651643, 53.67984018018169, 33.182879032627234, 33.37370626388058, 44.660632379593395, 16.480660015536895, 0.1506916244303988, 0.07762116229822559, 0.11689570161604113, 0.07771644065336836, 0.08282086151021142, 0.04259952178765689, 0.02041669900438959, 0.012714148408943608, 0.03377026269933389, 0.018243535474363356, 0.05264487267742234, 0.08210938799405292, 0.03783175443869926, 0.06054910741025402, 0.03980519693164576, 0.1399725221938664, 0.14711115929868915, 0.20944497578086393, 0.13552156667555534, 0.20076337630950636, 0.09864860574804968, 0.15673771290288818, 0.09045970806431386, 0.16812528814038924, 0.1238123647448036, 0.24195351848198524, 0.16027615045107182, 0.268454460967933, 0.2324280884837912, 0.1059225416411796, 0.22848080513217758, 0.11419020848528993, 0.24651376410357415, 0.3150749561046401, 25.977047681808475, 76.68971876944266, 52.83655804972495, 53.618094228929095, 49.63664923944781, 79.88473246174475, 68.33536840254261, 77.9965897529356, 64.46963725551483, 72.69454940672844, 19.947519456186605, 0.29596519926863335, 0.43863120999547744, 14.799400760281472, 83.84859346574353, 65.5550512190788, 73.42265113707512, 59.01842524928432, 60.31612965368456, 59.50243788380777, 59.775991824365434, 56.81317852389429, 59.647087051022446, 54.43636340479697, 50.19071148287866, 49.01573804117019, 47.97919288758309, 52.3341259648723, 50.94540296062347, 50.62721636987502, 50.177850031083636, 54.22667349538496, 52.171092648659986, 52.80529675945159, 52.385830648483775, 53.375742743092204, 53.53981548740018, 50.74668392058342, 49.775881613454516, 47.49438793428483, 49.75224541079614, 48.901593146785615, 50.42802272304412, 48.375073786704775, 49.36189897598759, 47.91609764099122, 48.560609740595666, 45.728827138100904, 47.778987269247736, 52.55922686669135, 51.34396283857284, 45.63834198059575, 52.421292797211684, 48.02024441380655, 49.890214781607355, 47.74222681599279, 45.700511547826956, 44.97457496581539, 47.618570173940356, 46.87361009659306, 44.67341538398497, 46.86720878847184, 44.035492866270005, 43.92254037241782, 45.18519839932842, 43.76157022291615, 44.02096440715175, 42.4670115593941, 43.36468519703035, 44.21152883960355, 45.34242268531553, 42.30084034704393, 42.460414132764264, 43.01386056407806, 44.25175666809083, 46.27640570363691, 45.55201453547324, 43.70472331200877, 44.99995270083028, 44.75026638277116, 45.99769384630265, 44.605899626208895, 43.63618381561772, 41.95263585736675, 42.75313669635404, 45.05647797738352, 43.361464931118874, 42.662494644041985, 50.61393522447156, 49.64487052732899, 44.41370741013558, 46.4728380018665, 52.69059881087273, 44.38951030854256, 43.389858968796275, 41.38872846480339, 43.748904889629735, 45.38649443657168, 44.68248782619354, 46.19799360152214, 44.16245606637771, 43.99217813245712, 45.70459865754651, 49.71940732771351, 54.619981319673606, 58.39067343742617, 59.026332747551706, 58.71335114202192, 57.31286494962631, 57.3725438117981, 54.49164529000559, 55.00417355568179, 49.2353593918585, 50.36275448337678, 49.45842850592829, 47.184826635545306, 47.3907785261831, 48.037691116333015, 50.157281121900006, 54.28995309337493, 55.49987877568891, 55.08236600506691, 53.416119621646025, 55.26768230622815, 50.067549059467936, 56.01729431459981, 56.1278933863486, 65.76635322263165, 61.26496276547832, 69.41452226331158, 8.679130461908157, 0.7381553166816313, 4.8122525119012405, 46.40056048670123, 71.27976617505475, 60.04963597943706, 70.43646443274714, 58.81452083587647, 42.235721157443145, 44.68926175948113, 56.361450918259166, 28.668423160429928, 0.26840947628501927, 0.14426036227133968, 0.1450179772631776, 0.17350699452142562, 0.17974313408617051, 0.1695898184252362, 0.1775867038316304, 0.23104721500027567, 0.12511395578903536, 0.19908097061899402, 0.128694451564262, 0.22910456924188524, 0.07194830420156641, 0.22511910406812546, 0.18045628533488323], [0.015001204315452807, 0.0348844226720112, 0.058971295704043684, 0.052981518524428534, 0.07556390212548357, 0.04720052711725716, 0.056154938159330245, 0.016384762937142965, 0.03063908898301663, 0.025160621866703998, 0.009559122545103873, 0.058742978519970374, 0.045333375493364955, 0.019346140925922704, 0.06446324979826328, 0.007294939629988926, 0.03849165108535559, 0.05367616108889061, 0.07134576838824057, 0.2473108632670295, 27.72500684184413, 54.72380645813481, 44.84255975292575, 32.981492780870006, 46.851833097396366, 56.1409156553207, 63.28923525348787, 53.18513124219833, 53.12246745632541, 21.03563004924405, 0.4707520202763619, 0.9000504713866019, 16.477045551423107, 74.77562565957346, 58.982563018798835, 65.9119398363175, 52.639329510350386, 53.46806356983801, 50.59039315869732, 50.89019167807795, 50.57526457694269, 50.08998109448341, 43.6849820229315, 45.23570676003733, 42.867905247596006, 45.06285182891354, 43.17421882383285, 45.84354469853063, 44.18195416850429, 44.74607336905695, 44.943815738924094, 44.867600164105816, 44.14431902670091, 45.34195200089486, 44.35579753691151, 45.80040254900533, 44.405815601348884, 44.92043056795674, 42.93147510097873, 45.857865272029755, 44.309776367679724, 42.08096796466459, 44.73387872019122, 44.58517774458855, 43.58370250271213, 43.413926632173606, 46.86685577515633, 44.20935584652809, 44.89390750085154, 48.66074392872472, 45.158714555924945, 43.31730688771894, 40.02293563658192, 42.178568301662324, 40.88860665598224, 41.12952647670623, 39.49466689940422, 40.75830944122807, 38.51183076058665, 39.61206343866164, 39.35891366774036, 40.133750438690186, 40.109039506604596, 39.336226678663685, 39.72222712732131, 41.32841810103386, 41.09914379735147, 39.59096108713458, 39.969822822078584, 42.4301177455533, 42.11113491365987, 41.328320041779556, 40.74661293337422, 41.05536622385825, 39.74325103144492, 39.752601961935724, 41.14057971585182, 38.19762145319293, 37.26774515644197, 39.13704872131348, 38.73995188743838, 35.70674773185484, 38.67996708039315, 38.932524573418405, 39.19537436577582, 39.38470717399351, 39.45028135853429, 41.449835069717906, 41.38085234549738, 40.47449065792946, 42.1705666665108, 46.18088030046033, 41.626733964489354, 40.79435994548183, 41.001108077264604, 39.09947633743286, 38.14454786239132, 41.034212881518954, 40.961849074209894, 41.0885847768476, 41.45822501951649, 40.73256692578716, 41.2765565226155, 41.11271912051786, 45.4679738321612, 48.2759907937819, 48.66459569623394, 49.40084026705835, 45.35870836627099, 45.690336919599964, 44.72548877039264, 45.19292154619771, 44.04616563550888, 41.4598096570661, 43.11222184088923, 44.34446580948369, 44.17399960179483, 46.27447589751213, 47.7036738395691, 49.493608244003795, 47.89772918147426, 44.73945633057625, 44.734816166662405, 44.49069961424797, 46.39892878070955, 51.765201860858554, 55.28555262473322, 53.914276323010846, 59.40022091711722, 5.129349664334328, 0.5612075148570923, 3.42181101922066, 41.32355043965001, 54.20428852881155, 48.83639550978138, 56.67998267758278, 36.93282181216825, 28.946089706113263, 25.871786955864202, 30.506626252205145, 2.8561616040045217, 0.09279647541622962, 0.04835970624680481, 0.04366701934486628, 0.05195766882670503, 0.013139940077258695, 0.07880921145119975, 0.016227113533644907, 0.0157435454293004, 0.012176815296463188, 0.07608407582607, 0.05434454598974797, 0.04096719526475476, 0.04636320833777709, 0.049543461476963375, 0.06287153742666687, 0.013309183263880833, 0.026970450961661917, 0.05954205035983075, 0.0598841660746163, 0.01273264751709517, 0.08059758242339858, 0.07358034727193656, 0.03279980932993274, 0.009129050360511868, 0.09720781652797615, 0.04588441487642066, 0.015245818104895373, 0.04661367695418097, 0.039795536562920585, 0.030525549006978833, 0.07042796441143559, 0.0741209601983428, 0.03194159550231791, 0.042021447161753336, 0.7874638611270536, 39.175056488283225, 54.52903724485829, 43.52798523441438, 44.70473158744074, 53.54898598886306, 63.46584781523674, 68.53857855642995, 60.00010036653089, 60.08271332710021, 27.41976603384941, 0.40519404615606036, 0.5212166833300744, 17.594870059720932, 77.94432024801932, 61.6090448441044, 68.32435438709875, 55.78628632330126, 57.67033800002068, 53.62573500602476, 55.98694301420643, 50.6757321665364, 51.39497718503399, 47.08346474555231, 49.91132890024493, 45.00291409031038, 47.73028712118826, 45.42793035507203, 48.94770453053136, 48.33680714330366, 46.768098338957756, 46.62744606694868, 48.68842409503076, 45.21149396896363, 47.13549106351791, 45.76329300480504, 48.040495611006214, 46.811632725500296, 46.91912528007261, 45.41562980221164, 47.16435578561599, 45.2893530168841, 44.363599131184245, 45.68071926793745, 45.867263270962624, 45.17652603887743, 45.178648041140654, 49.060507974317, 46.87805806436847, 46.88018791137203, 50.28738221814556, 46.66428888997724, 45.109975184163744, 43.124043864588586, 45.24542247095416, 43.14263589920537, 42.08373323563607, 42.515958816774436, 41.82878701917587, 41.079904571656265, 41.403986484773704, 42.00928272739534, 42.892549499388664, 42.55910096629974, 41.273944224080736, 42.44970998456402, 43.0503386066806, 44.075018590496434, 42.48721176578153, 41.33016747813071, 45.29607203698928, 44.633356217415106, 43.87294592395906, 41.78668037537606, 42.811305446009484, 42.99738268698416, 40.706942081451416, 43.523568645600356, 41.513824616709066, 39.488371495277654, 41.97311847440658, 41.71251227778774, 40.11058099808232, 40.53485985725157, 41.17736762569797, 40.23532021430231, 41.836298358055856, 41.96990997560563, 43.510989604457734, 44.85103207249796, 45.4643181831606, 44.521074448862386, 48.09992344148698, 43.422112618723226, 43.00298383159023, 42.13772858342817, 41.771936185898326, 40.147886660791215, 42.30404492347471, 42.79642789594589, 42.942249851842085, 43.60503627407936, 43.19426605778356, 42.86133527755738, 43.700875466869725, 49.07066299069313, 51.50667059806086, 50.59187189225228, 51.441849508593165, 48.1444227310919, 48.50547690545359, 47.21288334938788, 48.32084701907251, 46.265948664757516, 44.72043675761069, 44.48888355685819, 46.75705294455252, 46.46220445632935, 48.514415987076305, 50.24569919032436, 52.0966499851596, 50.72034912724649, 48.01435301380773, 47.814755362849084, 46.90046264279274, 48.591023798911806, 53.74578306751867, 58.6815328751841, 58.017224573319965, 63.25335733352169, 5.113644984460646, 0.928431454925768, 4.485501916177811, 46.723959907408684, 61.09720691557854, 56.510638267763206, 64.47854103580599, 42.91533847008982, 38.1693882326926, 31.822844243818718, 42.08974230674006, 4.710872971242474, 0.25463230427234407, 0.010128643799332843, 0.04384955511458459, 0.02090766560286284, 0.08786319094079156, 0.035043588929599336, 0.015004606703446518, 0.005930878903581611, 0.05101232015858254, 0.015661231197056272, 0.0739566266777054, 0.07074179999049633, 0.03230488588733058, 0.10042017641206903, 0.021876759166198394, 0.07765136148420072, 0.10392968648023183, 0.14844707874280794, 0.12953956911881126, 0.16866784693012316, 0.07839344021293425, 0.2429636513754245, 0.18584951367830077, 0.20383186488141938, 0.11838651637757018, 0.20924046094859802, 0.16064558869167683, 0.09651738744709762, 0.09564865906272205, 0.1569509458157324, 0.21878931791551653, 0.16645285691465103, 0.17475462999315033, 0.14601055142139235, 1.2918644855099342, 54.04073745973649, 68.00469690753569, 59.19945047747705, 48.60612100170505, 61.72290340546639, 72.62137366879371, 77.12591771156558, 64.83510409632038, 69.94009633218089, 32.341318822676136, 0.7178846914922038, 0.8868152299715627, 20.15060801659861, 81.66009918335946, 64.70475196838379, 72.04063538582095, 59.92066844817131, 59.71189245100945, 57.07842096205681, 59.40227231671734, 54.52218878653742, 54.15414887089884, 49.000252523729884, 53.24337059451688, 48.64230878891484, 50.98064153425155, 49.41094429262223, 51.63574011095109, 50.636116227796, 48.82090999234108, 49.507818991138095, 49.5645482309403, 47.036823841833304, 49.11612718336044, 47.88562082475232, 51.25718039851035, 48.421440124511726, 50.84513933427873, 46.69629150821317, 50.140662039479906, 48.25068758380029, 46.69798989449778, 46.69741330608245, 49.73195106752458, 46.20142567542292, 47.3615215670678, 52.36257491573211, 47.61474586302235, 49.669342194834066, 51.21779587961013, 49.58015534185594, 48.51366289200322, 45.09097914541922, 48.64289322207051, 45.996105286382864, 46.5491202569777, 44.45183284821049, 44.15108119287799, 43.19481911197786, 44.712544948824, 44.37935529216644, 44.80422642923171, 46.71697808850197, 42.651382569343816, 44.426659076444565, 47.59590279671454, 46.490692630890884, 45.09055160707043, 42.93296560164421, 48.968234216013265, 47.64758394610497, 46.86334917622228, 45.35951637452649, 46.31853980402793, 45.12007920972763, 43.85401264313729, 45.969841095709036, 42.85705597169938, 41.1045095997472, 47.05064627432054, 45.71615003770398, 42.91455791842553, 43.51466878767937, 44.000972086383456, 45.282939941652366, 44.51244131211312, 45.25977050104449, 45.55241853960099, 46.8532726072496, 47.49545874134187, 46.01042585988199, 49.078539109999134, 46.21747993653821, 45.24116277694703, 44.36558385049143, 45.272475058032626, 42.27160692214966, 44.66089910076511, 44.364367915738015, 44.47546120612852, 45.57907496729205, 44.75518895733742, 45.85689252422702, 46.37230373197987, 50.79592927809685, 51.70553868816745, 53.46918536770729, 54.593454330198234, 48.978628496969904, 50.716089433239354, 50.30990839004517, 50.56043801769134, 50.16944439180436, 47.35583020794777, 48.89425046982304, 50.019041107546904, 49.12548203622141, 52.08638514241865, 53.14402088042229, 55.64925047659106, 54.063302855337824, 49.22466701076877, 50.93511066129131, 50.467065995739354, 51.691108288303504, 58.69008364215974, 64.31179323504048, 63.028181906669374, 68.87644367833292, 7.538192897073685, 1.0105044154390213, 6.5255496867241405, 51.997782722596206, 67.1484984121015, 58.754241851068315, 72.43312343474358, 47.33632818345101, 49.118986591216064, 37.86974268574869, 57.1447443193005, 10.044129990762281, 0.4740351360411414, 0.2371017610834491, 0.16049834659263013, 0.1088545976146575, 0.19819034744174252, 0.2112504458355327, 0.12068654981351669, 0.09425833205422086, 0.09826025279659419, 0.23044520778761757, 0.20252380039422743, 0.23767721568865163, 0.16476833682146766, 0.1449437739868318, 0.13217512608295487], [0.10228163983312347, 0.057729061152185165, 0.05133475890503295, 0.027398456624078176, 0.07767550091469481, 0.009979886761415872, 0.0032595781921108645, 0.016080760096590367, 0.0597605501271544, 0.046769656286004095, 0.009820032939915697, 0.10572098390830141, 0.02864849186622568, 0.04623175914128942, 0.035593119119444204, 0.06115864143676816, 0.08948864565501291, 0.08254818783532228, 0.09562578367730303, 0.3199772753061787, 14.9953878694965, 52.137858406189956, 53.861732252182506, 41.25814491702665, 31.999244997578284, 59.33544297372142, 60.92102973691879, 55.7531697519364, 55.82216424326743, 32.69638942133996, 1.158618996700933, 0.6695417242665446, 13.214967173914756, 73.76803152022823, 63.50542453027541, 64.44490671157837, 59.05849226059453, 54.94793068978095, 48.228965497786, 50.89398853240475, 48.34303978950747, 46.82430198115688, 43.827670005060014, 43.47058919168288, 43.03132687845538, 43.915687991726784, 43.83691110918599, 45.77564847084784, 45.05261052039362, 44.004023690377515, 46.7981436944777, 45.66436298431889, 46.07069307757963, 46.27825706235824, 46.85061324027277, 45.81143225392988, 45.22002120171824, 45.426067229240175, 46.26583883839269, 45.54637024479528, 42.33264292440107, 47.526492534145234, 44.58954334259034, 45.36162268730902, 44.27085076608966, 44.416198115195, 43.68984968431535, 44.931444583400605, 43.62078851269138, 44.350835738643525, 40.94848555903281, 40.467026387491536, 41.57521363227598, 43.02248585608698, 41.53555062509353, 41.03138877499489, 41.931968888928814, 39.74314512745027, 40.267907265693914, 41.119218487893384, 39.815606994013635, 39.3736578572181, 42.697627313675426, 42.6906454947687, 40.84087141098515, 38.081162360406694, 39.5767189610389, 38.39605023784023, 40.77772517358103, 42.02650193245181, 41.43155290234474, 41.84917942170174, 40.634115434462025, 38.623618310497655, 36.84680031191918, 38.381702207749896, 39.27012297414964, 39.22558838321317, 39.49563180246661, 39.46938722364364, 39.35369299304101, 37.93488148720034, 39.225760967500754, 38.685391718341464, 40.73539887705157, 39.325757872673776, 39.67906144357497, 39.546312747463105, 39.428982888498616, 40.199014755987356, 44.26524962148359, 44.38592526220506, 40.47828358988608, 40.70356492073306, 41.9578565320661, 40.711629313807336, 40.37559201640468, 40.8186198049976, 41.91642453593593, 41.57694339752197, 39.99417681847849, 41.7346344455596, 42.55975600211851, 40.734912503150206, 42.289630213091456, 41.46247294641311, 44.31205134237967, 43.25000686030234, 44.07574030660814, 42.21739976636825, 44.01252346654093, 42.2678885152263, 41.48247703429192, 41.96527373406195, 40.54849793834072, 43.77915028602847, 44.901312935736875, 45.82626273555141, 47.17458532702538, 44.67959311700637, 44.645586167612386, 45.28515608079972, 44.498077592542096, 43.38052765015633, 48.764635747478856, 53.95461005549277, 57.66136753943659, 56.490779307580766, 51.18440081996303, 1.2913233210002224, 0.5213344770093118, 5.88746193916567, 52.17379123933854, 42.483567883891446, 50.194488725354596, 45.05027671014109, 29.937794323890444, 39.87109676484139, 29.66527981142844, 16.904887883893906, 0.3533963594705828, 0.05659530848084439, 0.01802743547746251, 0.10633354015167683, 0.08761265720691412, 0.0214754497527235, 0.04792021309596397, 0.028933547437191013, 0.04891819966536376, 0.015151538536883892, 0.06041679253441192, 0.08379219971116512, 0.040553124741681164, 0.03633856863504456, 0.05291748506527755, 0.06323452903738906, 0.0547785769336887, 0.057942025934255896, 0.08461176823343962, 0.07006365129904402, 0.061443829157900434, 0.05687299620119795, 0.039327793919871894, 0.04849064599482283, 0.04663591648662283, 0.027218556196819392, 0.05049470136122358, 0.051940611879070925, 0.04220499799797132, 0.03506431160795112, 0.07646040885799354, 0.07369010468884822, 0.045556257283615495, 0.05265403891943636, 0.10351668081937299, 0.320258000565152, 22.161079645156864, 61.90540344484391, 52.76462962550502, 53.16031048374792, 39.83869798721806, 62.52108220131167, 70.55264503725114, 62.87245988845826, 60.6032040042262, 38.21353843135219, 1.053932285116565, 0.5045336172465356, 13.492331697094826, 76.26367092132568, 64.96663685767882, 67.92322927905668, 61.48559216530093, 58.04192373829504, 50.73422647291615, 54.78641533082532, 51.08575713249945, 50.98688986993606, 47.03053236007691, 47.175436481352776, 46.392299975118334, 46.74608991992089, 45.642605596973056, 46.73258912178778, 46.68419099623158, 46.895069383805804, 46.87115077049502, 47.28916952686925, 44.629327943248136, 48.48323314420639, 47.12484967324042, 48.11573451565158, 48.198912297525716, 46.55492536483273, 46.4200468217173, 46.31500967087285, 44.65076369623984, 48.05496523457189, 46.85724989060433, 47.032505312273585, 45.49444983082433, 46.82622394254131, 46.719766893694484, 47.52603753920525, 45.5143048686366, 46.90144715770599, 43.92725898373512, 44.79360857317525, 45.52006290804955, 45.178738255654615, 45.43106825120988, 44.141726340017016, 44.93453541109639, 42.7291553251205, 44.970593760090495, 43.385297252285866, 42.7822014593309, 43.88793330038748, 45.35142844723117, 44.74475937504923, 43.19755300398796, 40.10315202897595, 42.952467626140965, 41.98169669797344, 43.068899262336, 43.880437650988185, 44.1222753063325, 47.09231753503123, 42.8181617490707, 40.44580636485931, 39.82029030399938, 40.6410619520372, 42.396248079115345, 42.18645618807885, 41.30895530023883, 42.29297599484844, 42.02867100315709, 41.04698804117019, 41.59699847621303, 42.00444644497287, 42.18304372602894, 42.7262370817123, 42.144047521775775, 42.122156773844075, 41.948529135796335, 44.05732085627895, 46.61890706708355, 46.08277790008053, 42.97318558539114, 42.7166311971603, 45.161138580691436, 43.911016448851555, 41.052863751688314, 43.798640543414706, 43.435605572115996, 43.15406176351732, 42.79762421884845, 42.9215475820726, 44.76488897877355, 42.60462791688981, 45.24098627028927, 44.05204526839718, 46.12536307304136, 46.64045656881025, 46.6411861296623, 43.600003873148275, 45.5458289577115, 44.84165760778612, 41.64051717327487, 44.71646731899631, 44.94293712800549, 45.21367480677944, 46.71326360394878, 48.59019225643527, 48.89805124652002, 47.75267993250201, 49.314116662548436, 48.2915194572941, 47.37373190541422, 46.48059252769717, 51.2295316111657, 57.79295913634762, 62.07115104121547, 60.36149578709757, 53.774894898937596, 1.361509477419238, 0.45404162017568467, 6.7849879976241825, 60.741043936821725, 47.91682327947309, 54.31488760056035, 49.386092155210434, 37.46754677064958, 48.37454426673151, 33.86834852157101, 28.75283648890834, 0.5169164785935033, 0.03156769096911435, 0.10405919364383144, 0.11813314045749365, 0.028523491214840647, 0.08974852566156657, 0.054361124132429404, 0.06326884977639684, 0.03930208783957266, 0.004969461541247344, 0.06583971827621422, 0.022981402411636327, 0.01724345365449065, 0.07270572001054403, 0.05481889231070396, 0.0766476407466877, 0.27568679062589524, 0.10810086668859567, 0.16951423619062672, 0.18188402807760626, 0.16728842901366373, 0.18707363025075008, 0.16065628327909978, 0.13834619413941138, 0.14688781402524442, 0.07333805664412438, 0.13840596431926375, 0.21063262656811746, 0.15889303999081736, 0.12401502564429276, 0.2867566385576802, 0.196983513812865, 0.3001757717180637, 0.23651922782582624, 0.2577134179732492, 0.49400848847243095, 29.21694897836255, 71.03191944860643, 61.59325730416083, 57.13803706630584, 43.29896588479319, 71.8562682982414, 76.67386454920616, 68.91187837046962, 68.79540751057287, 43.67324629137593, 1.486713371930584, 0.5555457573744559, 15.678399993527321, 79.34819929061398, 67.9446767991589, 72.15070493759649, 64.42249036604359, 62.9017678383858, 54.08017689181913, 59.14871461929814, 54.31215370855024, 53.33053350448609, 49.08136713889338, 50.39782439508746, 49.05178854542394, 48.768824838822894, 48.675527341904186, 50.07083992804251, 49.71638318031065, 49.591181124410326, 49.70767551852811, 50.26047868113364, 46.488841272169545, 50.1925902981912, 50.71092367172242, 50.25581106062859, 50.83099134506718, 50.7871941597231, 47.4238480291059, 49.80168296444801, 45.08714698976086, 50.972188826530214, 47.84512627509333, 50.75574459568147, 47.620994198706846, 49.905476723947835, 48.121539623506614, 49.980566578526656, 49.02901526420347, 48.900306609369096, 45.40657304948377, 45.3524168845146, 46.648756304094874, 48.70925188064576, 48.92144033985753, 45.89171140424667, 48.93818886049333, 44.42035974994783, 47.84515373168453, 48.57665223460044, 45.11050470413701, 45.46866416931153, 48.51663604859383, 48.50827355538645, 45.67596927765877, 42.62780520223802, 44.96487886674943, 43.54960926117436, 47.827691339677386, 45.8768456212936, 47.10104873103481, 48.73319795054775, 44.41963018909578, 44.43411550214214, 41.26538561236474, 43.9703187634868, 44.84133205106182, 44.06302006013932, 43.624997215886275, 46.59898927134853, 45.186779114507864, 43.14767614487679, 43.33177258891445, 45.0607886622029, 44.756765750146684, 45.080596631573094, 44.968899296176055, 44.905043109770745, 43.950287219016786, 46.35684567113077, 49.39065779409101, 48.353998891768924, 44.65249738385601, 44.77186295293993, 47.58420236649052, 44.98789533492058, 45.115752835427564, 45.69895436686855, 45.29880200662921, 45.53525032535676, 45.195247511709894, 45.23288657588344, 47.15535002370035, 45.11225800360403, 47.98897920116302, 45.83079307310043, 49.82691949413669, 48.563877074949204, 50.45059988575597, 47.17462455072711, 50.95713084743869, 47.45974556092293, 45.169595210782944, 49.499758520433986, 46.517505953388834, 49.95560461475004, 51.668503669000444, 51.80087973994594, 53.84154381290559, 48.73371178104032, 49.82544860532207, 51.48769809353737, 50.61777914724043, 50.199246560373616, 55.06234230533723, 61.2412912614884, 65.86547543925624, 63.998458616195194, 60.06461943349531, 2.901031312442595, 0.6780277108473163, 8.724831957970897, 66.2081729212115, 53.46490606184929, 62.22960695143669, 57.39967876865018, 42.12333740726594, 57.44614708808161, 44.49672829720282, 45.814538771106356, 0.9767936049930512, 0.17066954274571713, 0.17136415466666224, 0.20411119586037052, 0.16212850508670654, 0.20536830017883934, 0.14379605170219176, 0.10142281696560884, 0.1375330530948216, 0.14499972904882125, 0.17446727041275273, 0.15209243152170412, 0.06382535136635266, 0.12915056499262012, 0.1324663007812154, 0.12681295494398764], [0.03133095256353338, 0.07002330144807216, 0.1200386539341942, 0.043279861490572655, 0.018889684673218478, 0.040368041729614626, 0.04298224016242931, 0.03608011738246968, 0.1025134886825277, 0.14907819729658867, 0.01236841101349602, 0.07541806962821754, 0.0256481085107812, 0.032924716135547046, 0.14727542387141337, 0.1028141628710493, 0.04990814614199823, 0.06522504763016779, 0.04863283574400891, 0.05391699998008628, 1.1528852269534142, 44.81730361138621, 47.89113175484442, 47.344478868669086, 30.80628944981483, 47.234860389463364, 64.40634981278451, 56.718680781702844, 60.938900055423865, 44.67915381154707, 1.0850583761930466, 0.26647295923002307, 4.106066534596105, 67.29278672126033, 66.31773256486463, 66.26723597126623, 61.45744523694439, 58.40864573755572, 50.62931876028738, 49.91743210823306, 46.65712664204259, 47.184242202389626, 45.74764274781751, 44.70118968717514, 44.55492450344948, 47.71997521000524, 44.84188902762629, 45.98920583724976, 44.215874825754476, 46.09894590993082, 44.63698048745432, 45.46424365812733, 45.54848832468833, 45.410966104076756, 44.05739145894205, 45.50955095598775, 45.436194789025095, 45.85384092023296, 46.26611732667493, 45.5630010943259, 45.57949466090049, 44.30741902320616, 45.032633889106016, 44.24809709672005, 44.829662999799176, 44.983176723603286, 45.8310950956037, 44.60128691888625, 45.587213885399606, 44.42432918856221, 43.3292701167445, 42.00109281847554, 41.31564294138263, 41.45312593829247, 42.5218149154417, 42.25698432614727, 40.92827358553487, 43.38592875388361, 41.05149876686835, 41.21564211383943, 42.102097772782855, 41.62755766222554, 43.92960456109817, 44.48658504793721, 51.51529589006978, 53.80960003022225, 54.97264554423671, 53.171108768832305, 54.10176561724756, 47.36865243604107, 48.701826833909564, 46.39621842292048, 47.83683438454905, 49.64706705462549, 48.42248739734773, 46.96985329351118, 42.57975616762715, 41.94550891076365, 40.00490450089978, 39.51232540991999, 38.54098966044765, 39.64528591402116, 37.9503317033091, 39.41006529715754, 40.05775059423139, 40.01914270462529, 38.03157575668828, 39.42767673923124, 37.93872148759904, 38.415101189767164, 41.647444078999186, 41.10774555513936, 41.474173376637125, 41.62226638486309, 41.3040719493743, 39.63609187833725, 40.16154827610139, 40.837980624168154, 42.456362324376265, 42.19537173548053, 41.10390555474066, 40.03507537226523, 40.273073027210856, 41.42964663044099, 40.93479648713143, 40.863774130421305, 40.147204168381236, 42.10387460647091, 41.74754688816686, 39.763455160202525, 39.37768220901489, 41.155802434490575, 40.24951134958575, 40.07818614282916, 40.66430199530817, 40.91532191922588, 43.015080421201645, 46.5993618965149, 43.49694359687067, 44.09898819461946, 42.49167542303763, 42.9651996397203, 41.87596920997866, 48.66527426627375, 51.230818148582216, 60.18620506409676, 54.66907762712049, 67.44477856543757, 35.97901513499599, 0.05067411532265045, 0.210308387515045, 9.822967148596241, 52.01928123351067, 42.93133389565253, 66.08316698381978, 37.85526521744267, 32.446505023587136, 34.487114183364376, 34.97113858499835, 13.428391179730816, 0.11778592642757202, 0.014750042389477453, 0.059565722476691015, 0.007591213122190488, 0.004745400933203318, 0.050693865069338394, 0.0271804184247289, 0.04520769876938674, 0.06500652871064602, 0.12107908560503876, 0.08420754194019303, 0.006106951764048708, 0.045424382908329855, 0.03755260732084994, 0.07011356958819014, 0.0021127685097106284, 0.06440260627817723, 0.06668676637233266, 0.01276949443103325, 0.03963946913098616, 0.05666360904973361, 0.026064431332352183, 0.06607129133396572, 0.03638760592307776, 0.08366275383459945, 0.041391136830732714, 0.03702723954413687, 0.07102646294140047, 0.06795782881278185, 0.022008411375985994, 0.10858124212151575, 0.011414407467048977, 0.005723915462787714, 0.04126937864648719, 0.13930092355416668, 0.013478749165041073, 2.495723486908021, 55.43635991311843, 52.14009807955835, 53.05835239348873, 42.172131692209554, 55.21390268879553, 71.91418601620582, 64.55951444564327, 65.12550853913831, 48.151561444805516, 1.3599672504971105, 0.6024682750144313, 5.015104259214094, 68.6263612008864, 67.92238204709946, 67.60983190228863, 65.5164158728815, 60.88978021375595, 54.00741692512266, 53.32488136906778, 49.67307236886794, 51.604890669545824, 49.683137170730106, 47.32484740595664, 46.93294379018968, 50.17814813121673, 48.30745604730422, 47.40298101978917, 46.290518391516905, 48.38249883344097, 47.939302382930634, 47.5541256320092, 47.98427235695624, 48.098989917385964, 47.58937597274781, 48.533851331280125, 46.835629786214525, 48.53767171982796, 47.75742992278069, 47.38882910820746, 47.47541935213151, 45.881897634075536, 46.041138018331225, 45.604044775809015, 45.69426321214246, 46.36685555981052, 47.37779940328291, 45.752271144620835, 47.75646894208847, 46.849734629354174, 44.470158161655554, 44.86590177782121, 44.14595465506277, 44.17885157369798, 45.02090600229079, 44.80058254734163, 43.932212937262754, 43.50278792842742, 43.425752578243134, 43.747904685235795, 43.01582174916422, 43.188974780421105, 44.71120349822506, 45.19310981996598, 49.43367835014097, 52.954676305094075, 53.25682040183775, 51.6715278164033, 52.18095348727319, 48.13000409833847, 49.85987524832449, 47.89423434965072, 47.906958518489716, 48.16081039367184, 47.56628105717321, 46.51557222489388, 45.41271940354378, 43.42278334402269, 41.209480070298724, 41.09970469628611, 40.530141245934274, 42.247700075949396, 41.482606472507605, 42.07754373550415, 41.46947437717069, 41.49903335878926, 41.196395043403875, 40.37603524423415, 39.262046813964844, 42.512342391475556, 44.758954432702836, 43.276137690390314, 43.044729617334184, 44.392820788967995, 43.06586334782262, 41.37238394829535, 42.47332265300136, 42.98623923332461, 44.06411832378757, 44.78417527291083, 42.72013387372417, 41.64123888938658, 42.863771069434385, 43.00014403558547, 43.21822389479607, 43.91417787921044, 42.11412375973117, 42.64644430529687, 44.035739975590865, 42.92827836928829, 40.9057121123037, 42.76003614548714, 42.75347402018886, 43.09473983703121, 44.09061001193139, 44.16664908009191, 45.21292171170635, 49.83587034286992, 46.541714822092366, 45.5331479349444, 46.04406410647977, 45.994536338313935, 43.74374697285314, 50.237881906570934, 53.71776557737782, 63.8861729252723, 57.972599767869525, 71.93309184043639, 35.82436392384191, 0.11613309173093689, 0.24124720073755712, 12.078490814855023, 57.660787028651086, 45.977544630727465, 70.98020692025462, 41.40643404376122, 40.80914728103146, 36.6366671746777, 43.115187152739495, 19.964289549858343, 0.1611512526869774, 0.07034078360565248, 0.05569757217721594, 0.05815225578243694, 0.039099093691836444, 0.05372329847887159, 0.046654624353733756, 0.020163631434702588, 0.028886492401661894, 0.023469582365285006, 0.01698267732506558, 0.032218513304307576, 0.11951329381836039, 0.032673822340345195, 0.05709710756256696, 0.029638670084457246, 0.11734305865942471, 0.16198083397842225, 0.17084232621615933, 0.18336144396133963, 0.13255064706167868, 0.13150524348020554, 0.18970675105529447, 0.11349949595187941, 0.2852590285962628, 0.25305082300497644, 0.1284320434675582, 0.18798271614697673, 0.20078617508613295, 0.0931465392932296, 0.2549730755028225, 0.2065945771192351, 0.136095259278532, 0.15149342737370922, 0.3723665963738196, 0.2790619595156562, 4.097185553081574, 69.32769667717719, 59.493734144395404, 61.03434308882683, 47.14492044141216, 60.90388897926577, 77.79225780117896, 71.1058404368739, 74.08627694652927, 58.25830521122102, 1.8172834981833736, 0.45848312216901016, 5.948464601270615, 73.55089695222917, 72.90299200242566, 75.21654713538386, 68.78498185065486, 64.42938197043635, 55.225532516356445, 57.12892147802538, 52.137505392874445, 52.35273368896977, 52.523325412504136, 49.108235374573745, 49.768644840486594, 53.482760690873675, 49.24703628786149, 51.16090974500103, 49.29875666095365, 49.86500178613971, 49.55519337807932, 50.43749132464009, 50.612738901569, 50.166604595799605, 49.18088551490538, 51.42214352084745, 49.874756720758256, 50.110196990351525, 49.296771941646455, 49.10922381185716, 51.27097537440639, 47.66445013784593, 47.992752521268784, 48.42528012491042, 47.66042578604914, 48.85806268261325, 48.18739229632963, 48.948873396842714, 49.35263826001076, 49.87832999998524, 48.74931104721562, 47.79181341971121, 45.89794012808031, 47.04167973610663, 45.830781305989916, 47.15592268974551, 46.78150892257691, 47.2282668852037, 45.23579305218112, 44.65288962087324, 45.71057634968912, 46.509323889209384, 47.78107004780924, 47.137464015714585, 56.066649498478064, 58.00858359183035, 59.101210794141224, 57.228612438324966, 58.938616783388206, 52.079528839357444, 52.40119065007856, 50.29559958365656, 52.49061676763719, 55.5182433128357, 53.328831195831306, 51.017311772992535, 48.81475971591089, 47.44676643802274, 44.82105731964112, 44.95020135756462, 44.54518525831161, 46.191607982881614, 42.588667792658654, 44.59179478306925, 45.131689425437685, 43.12245138229863, 42.26066743173907, 43.13099430453393, 42.068028065466116, 46.008758852558756, 46.47337144420993, 44.10801749075613, 44.69019920595231, 46.85260972669048, 45.727469998021284, 44.484776835287775, 45.21680485817694, 45.09827083156955, 45.53192415545064, 47.24014774445565, 45.11698838203184, 42.75607847398327, 45.295083599705855, 44.346426994569846, 45.58158528420233, 45.68240588711154, 43.99976399637038, 45.54604468807098, 47.56643010723976, 44.688194874794256, 42.76613150873492, 46.00314986321234, 46.91337116302983, 45.009586041973485, 47.23921814272481, 45.72876438017815, 48.072262887031805, 52.49733578774237, 49.86196979399651, 47.4156306635949, 49.735893049547755, 47.98515881261518, 46.639585802632, 53.8866824488486, 56.91891385662941, 67.58935712998914, 64.59699661500993, 72.76874496090797, 43.01258971614223, 0.26865830164282556, 0.3442163891609638, 14.268081399702258, 64.55908298492432, 53.00592207139539, 81.52614239723452, 49.55944130497594, 51.85813065498106, 45.49065297649753, 55.71212999282345, 30.872559855061194, 0.2795524702918145, 0.16438763708837573, 0.16112370416522026, 0.12830848880713025, 0.16038793800098283, 0.15946650276741675, 0.20604412762388108, 0.2536990559629856, 0.10918561654585986, 0.1975614505429422, 0.1504861443273483, 0.12053165449610642, 0.22989575420656513, 0.13425750627873406, 0.16084181445260204, 0.16044093596358455], [0.04562212935378475, 0.07167933839223078, 0.02777274994690332, 0.03976835576336711, 0.05698027915411419, 0.049077499988338644, 0.058414828588044455, 0.04365896009990285, 0.02298400328013926, 0.03331521030275091, 0.06529654661614089, 0.058857577612563494, 0.06272124246724191, 0.05439326152085297, 0.03686541113101187, 0.06664223368129422, 0.12099427201094166, 0.13277508017997589, 0.10331595812233225, 0.11700832420178961, 0.2450356740624674, 17.353387378877212, 55.883729765492106, 27.700037033327167, 32.768902278715565, 34.697098270539314, 59.347974946421964, 64.95156318910661, 55.24405394831012, 57.43983599447436, 1.5345057364433043, 0.049923226582787694, 0.08218793498892939, 34.06618895069246, 78.36825786098358, 65.11409444193687, 65.84550273033881, 59.64601232159523, 56.467319611580145, 48.700540296493045, 49.3606085162009, 47.34400426187823, 49.73607347857568, 48.098432940821496, 48.140237562118045, 44.06375746573172, 46.672843579323064, 44.025039749760786, 46.3164334912454, 44.826878116976836, 45.01181002586119, 45.981933762950284, 47.77684565513365, 46.249992462896536, 45.391675887569306, 43.079313155143495, 46.42953111279396, 44.878527887405895, 45.230439016895915, 44.73665183590305, 44.22157402961485, 46.6085990782707, 46.04631162458851, 44.695168848960634, 44.94676928366385, 44.77188648716096, 47.06047573397237, 44.275741961694536, 45.45496333029963, 44.71064259929042, 43.47751217503702, 41.60260354318927, 40.84670789780156, 43.31260788825251, 43.45946534987419, 42.304127293248335, 41.86826175259006, 43.94331716722058, 43.822264978962565, 45.59287778792843, 45.00784843198715, 43.81367498828519, 44.326120884187766, 44.95081716968168, 51.78369583622102, 58.94588101294733, 62.287206957417155, 63.46488291217435, 63.05117091824932, 60.50169698653683, 57.29755201647359, 59.40805389035133, 60.69173582138554, 65.33148004162696, 64.06544877636817, 56.27654729350921, 45.64703787526777, 42.10334900886782, 43.72297802279073, 43.658568782191125, 41.315525270277455, 39.80914292796966, 39.864668000128965, 39.70614933198498, 39.68140702093802, 39.368335200894265, 40.6790187281947, 39.133236177505985, 38.188215609519716, 40.19613965865105, 41.25552477375154, 42.43626409961332, 41.10163450241089, 42.43561690853488, 41.5439131183009, 40.17925385505923, 40.22784809912405, 41.32380539371122, 41.3296301134171, 41.82170321864467, 41.81027343196254, 41.308978834459865, 40.60169312261766, 40.27685811442714, 39.03272544184039, 42.37239614609749, 40.0204017854506, 39.073565160074544, 40.02627357359856, 40.146156895545225, 38.90739787009455, 39.47028544641311, 38.66003751754761, 39.95662012407857, 39.5878271133669, 41.21040182728922, 42.82406099380986, 40.95820519231981, 40.10049266199912, 42.02947901141259, 44.55101390038767, 46.53065766057661, 46.24820386209796, 57.85551701822589, 56.41441076032577, 63.17794976695892, 58.86740615290981, 68.83423113053846, 7.065494829608548, 0.28661950881923404, 0.2690115294629528, 16.50166823017982, 64.89047619604295, 46.05836506812803, 59.54968675490349, 27.03445396115703, 43.57530078580303, 34.46950274129068, 37.71112988072057, 5.017236557699019, 0.3356748765274402, 0.1826175419433463, 0.08878399032138048, 0.04935271324469678, 0.08781303516438893, 0.03682961184231024, 0.02541199829729815, 0.06230394671400709, 0.050702993006956194, 0.02648705331188056, 0.034189201711166295, 0.12058565603388895, 0.052783002160609736, 0.029460253952551755, 0.057259552676471016, 0.06139995913291651, 0.047344463546910596, 0.018839820010227062, 0.061095312778507514, 0.03625660105758617, 0.07484167273486815, 0.053491066585505204, 0.08725048914071053, 0.022553980891262333, 0.023220938953360724, 0.08272696977421161, 0.031297637314926234, 0.03643992589786649, 0.144222226414469, 0.04387801911141123, 0.047967028729016745, 0.09264928694333761, 0.05463564407921607, 0.038625524950123606, 0.03345617048081852, 0.12897261808956825, 0.40267787633403657, 24.24923381497783, 63.013292589495265, 29.88280269407457, 40.149953749872026, 43.909482802114184, 68.89936600961994, 72.4827806411251, 61.88365782460859, 64.89177057819983, 1.826731384761872, 0.3206485215454333, 0.16535149827118845, 34.63242623113817, 78.39295310358848, 67.30287505734351, 69.60841286566951, 62.66304846732848, 58.578311781729425, 52.34009581227457, 53.07044506072999, 49.38096169502505, 52.28552387606714, 49.72425145487632, 50.601395407030665, 46.39424939309397, 49.72320810441048, 47.12576358549057, 48.28698127500473, 46.676891465340894, 47.87578352036015, 46.72381870208248, 48.19205991683468, 47.46348750206732, 47.6049477823319, 46.35787725448609, 47.070944539962284, 46.48809994420698, 47.42994339235368, 45.48064308781778, 46.24752921442832, 48.684140866802586, 48.71463337252217, 47.05448235234907, 46.57296434525521, 46.32128154077838, 49.53127084239837, 46.08251117890882, 47.43563475147371, 47.13997825499504, 45.980702138716175, 45.68982308910739, 44.54898995737876, 47.161190432886926, 44.54243959919099, 43.98996199330976, 45.14866936591364, 46.243167538796705, 44.453593992417865, 48.11440483216317, 46.82507076571065, 46.120938639486994, 46.82779289061024, 46.74583496585969, 54.5260601658975, 62.90387415116834, 64.60050713631415, 63.381375651205744, 63.1232483925358, 60.37901309228713, 58.12510936490951, 58.68271743097613, 61.977386782246256, 64.22077071282172, 65.14888586536532, 57.41145372390748, 47.11694217497303, 45.335374186115885, 44.960195556763686, 45.90503177335186, 42.7484808429595, 42.49158128615349, 41.6036194370639, 42.19654452416205, 41.54196370032526, 41.416232124451675, 42.21847057342529, 41.428211042957926, 41.3853120803833, 42.33949922746228, 41.94842715417185, 43.64788032347157, 44.190630451325454, 44.26134686316214, 43.52130151564076, 42.47238128416, 42.62029778572821, 42.88122953907136, 42.951055572878936, 43.03580230282199, 43.104184904406154, 42.90630525158298, 42.42114336259904, 42.00241465722361, 41.838157561517534, 43.52503953441497, 42.21639171723397, 42.60023093992665, 42.215858274890536, 42.85363174253895, 40.940546681804044, 41.78833561558878, 42.36193518484793, 43.82125692982828, 41.56259928980182, 44.43955975194132, 44.190453944667695, 44.14715882270567, 43.343951548299486, 44.90525884013022, 46.0406594891702, 49.17186014113888, 48.78632645453177, 60.47828828134845, 60.13143700938071, 66.45051263993787, 61.03568061705559, 69.45045901883033, 6.069451580124517, 0.3193190525616369, 0.46134038497844054, 19.62449069946043, 70.2839469909668, 51.675599236642164, 65.26378777719313, 35.4353157935604, 50.3728820431617, 35.20735940625591, 48.70102667039441, 7.098138265071377, 0.32738865503380377, 0.09756660614643367, 0.04553052822067853, 0.02125940529719716, 0.13717227164776097, 0.022421166143049637, 0.06062346007374506, 0.12834274825910408, 0.034148066620072054, 0.040386753427165176, 0.05079076753088063, 0.10816255208825874, 0.043564581898071116, 0.019487819311419324, 0.05925305135127518, 0.019267618828903765, 0.12421318194678715, 0.13262819048137436, 0.11874337545445851, 0.08418798371548615, 0.15251603217855578, 0.15366085865084203, 0.21129277985422842, 0.1498830799133547, 0.143178784018082, 0.2727104471095147, 0.16006245788547302, 0.1408732577317184, 0.28829895741035866, 0.14801917267182182, 0.19324963191343894, 0.18547710301654954, 0.1882094168855298, 0.3458459807499763, 0.2201045989509552, 0.29351089870737446, 0.42322815425934335, 32.62465123207339, 73.34348986225744, 40.535201103456565, 48.578083899713334, 48.37588179496027, 74.5436566875827, 79.64141999521564, 67.03356512131231, 70.61068042632073, 3.302768065083412, 0.6209972452732825, 0.2830456167219147, 35.78812906819005, 83.65345554967081, 71.71994240053239, 72.03312012457079, 66.56631669690533, 61.99251536400088, 52.17649767475744, 56.66382643484301, 52.997445829453014, 57.69925371293099, 53.85813151636432, 53.59940021268783, 48.02923840861167, 53.35838233270953, 49.21572400677589, 50.67331990888042, 50.27529739564466, 50.724926533237586, 49.54825862761467, 50.18400815225417, 50.00682684683031, 51.22389908759825, 48.07719722870858, 52.21128909818588, 50.15057779127552, 49.3242520670737, 47.59771885410432, 48.465711916646654, 50.29501907287106, 50.659532777724735, 48.56247678879769, 49.065308955407914, 48.20665897861604, 51.0617208480835, 46.77566851339033, 49.2330648053077, 49.054039985902854, 49.147513989479314, 48.050548645757864, 45.34190493245279, 49.603038449441236, 48.52941905298541, 48.03967975801038, 48.99995442359678, 48.14963948342108, 48.409692625845636, 51.74875144035586, 47.63268286182035, 48.38645650494484, 48.02166038943876, 47.4370389599954, 56.06221329781317, 63.27853502765779, 65.55916578538957, 66.09056457396477, 65.71212253262921, 60.77210910858647, 60.243303006695164, 61.51672009498843, 63.678530493090236, 66.87019055889499, 69.15306491236534, 62.832498781142704, 50.02401075055523, 47.072423273517245, 48.53628712315714, 49.025712628518384, 46.103146768385365, 45.86413714193529, 44.450279589622255, 44.9731001546306, 43.746908403212025, 42.019218091041814, 45.50649935199369, 44.43901846485753, 44.20201316956551, 44.80293989181519, 45.338100233385646, 44.704653140037294, 47.05712210747504, 45.85235041956748, 44.83320490006478, 45.36767882685508, 44.85277752722464, 45.69757369256789, 44.10609945174187, 44.80294773655553, 46.41387693343624, 45.495453957588445, 44.702825315537, 44.0502566675986, 43.42474060673868, 46.8722019657012, 44.216588697125836, 44.353934411079656, 44.336907402161636, 46.1212210501394, 42.81288223881876, 43.85277709653301, 44.9167670742158, 46.14113100113408, 44.41077739961686, 47.60752085716494, 46.534352533278934, 45.91741861835603, 47.04419397538709, 47.54660644838887, 48.152844059851866, 52.64925310688635, 51.28717868558822, 64.00766441898962, 63.174878551114, 71.3099370464202, 62.45249955884872, 73.59834978657385, 9.506930016702222, 0.4552213342920427, 0.9174835681915284, 23.512530326843265, 78.12201146156558, 57.11602080252863, 72.9148454050864, 39.37278709103985, 61.0717664226409, 43.147629076434725, 63.07344213608773, 10.18936162994754, 0.5661026941191766, 0.22847129032015803, 0.15871579788865584, 0.20180243668296646, 0.359141314101796, 0.1477842288272035, 0.13620359943278376, 0.2505624008875701, 0.15617313674621044, 0.08951658488161142, 0.14239950405974544, 0.3757748296183925, 0.165348265380148, 0.12764494175151472, 0.12303637896454143, 0.12382726515493087], [0.021830351474965294, 0.015792515684640216, 0.04279360633283373, 0.03616222668619406, 0.04472217522561551, 0.05821153949645739, 0.009100176506645737, 0.030806986727721752, 0.013830283930855653, 0.0755152478814125, 0.05704193391026028, 0.058647512473286166, 0.06622211872449806, 0.050500125263727484, 0.12915583567753916, 0.06260215409941251, 0.03398974688964025, 0.016217462741018786, 0.029843870565415393, 0.09346923850957425, 0.05674176917020833, 0.40672128839838895, 39.87561925765007, 53.397562888360795, 29.85594426431964, 39.8537677334201, 27.208807237686653, 63.97372022751839, 51.3416878638729, 63.99772513297297, 12.550729474713727, 0.12879641786698373, 0.15010138432825768, 1.9516384048808006, 70.4730679911952, 65.04427233049947, 68.32752366219798, 61.2024833310035, 62.23432556275399, 53.916559142451135, 57.160633840868556, 58.58108881981143, 64.86907966675298, 61.49704940857426, 59.607992787514966, 53.39982217358005, 50.15238600392496, 48.025319960809526, 48.847429137076105, 46.58502955590525, 47.8540849685669, 48.633918839116255, 50.023551833245065, 49.05696999642157, 49.107294005732385, 47.97888694270965, 45.820904777896025, 43.95398601408928, 48.46075796311902, 47.71414656792918, 46.544660522091775, 45.25545981622512, 45.536246607380534, 45.295997511956, 46.559224282541585, 44.65365056068667, 46.47141025912377, 45.031049251556404, 44.22579842229044, 43.26391558493338, 43.81764442689958, 42.583156862566554, 40.995099006160615, 44.23355687049128, 42.86096657476118, 42.84395917769402, 44.19190522163145, 42.42703868496803, 45.28246533486151, 47.040620696160104, 43.758530386032604, 42.972687444379254, 43.434236664925855, 45.42549848556519, 47.71541741586501, 49.33503858504757, 54.78120250086631, 56.851354952781435, 57.99721264070081, 61.276333716607866, 56.128583723498934, 58.82456602588777, 60.9065483462426, 57.79483795166016, 52.447160828498106, 47.05334094262893, 45.2324237362031, 44.79689159700948, 43.51999928874355, 43.49885379114459, 45.511716104322865, 43.37076094842727, 42.489094503464244, 40.40101681986163, 41.02512867219987, 40.5415435760252, 42.077457443360366, 40.289354785796135, 40.34965730482533, 40.245298724020685, 40.778913651743245, 44.54440470664732, 41.86945023075227, 42.20413431044548, 41.35001467120263, 40.73089599609375, 42.644126184525035, 40.90462953813615, 41.65027995263377, 43.70835150441816, 44.35353432932208, 41.379204950025006, 40.68625157879245, 43.341566747234715, 40.05193764163602, 40.21913651497134, 40.75153943031065, 39.982017470944314, 39.26260771289949, 40.24061933640511, 40.48841899441135, 40.83032415759179, 38.56155856963127, 40.45882078909105, 40.50365348016062, 41.83121104394236, 41.97257326495263, 42.75809064988167, 43.65563484930223, 43.81418097403742, 44.44736134621405, 48.913517152109456, 56.68636437385314, 57.204619299980905, 61.06498856698314, 61.72051468203145, 71.88669804603823, 30.31978414904687, 0.4049310328498964, 0.10710590999693641, 0.3648059214315107, 34.360962913882354, 51.93530328812138, 50.083615087693744, 43.138878268580285, 29.099650498359438, 39.567846559709125, 38.78488263776226, 30.997465772013513, 0.29091845717160936, 0.028076505724100337, 0.008127630759601392, 0.07505674425873064, 0.06161522217876008, 0.06636642670679478, 0.012309984360340864, 0.047524153299990206, 0.019010404808326595, 0.06675754523565693, 0.019751411013966127, 0.0893350680088324, 0.03611384440333613, 0.016096032059360898, 0.06405688228926833, 0.043780699131950256, 0.08724821385957542, 0.09538643482712009, 0.043957523716193055, 0.045884307624111255, 0.03821287168970993, 0.04456912234966313, 0.0803049291754442, 0.031378076546975685, 0.0233931057230239, 0.05342323333024979, 0.06314943965163923, 0.022009510712157336, 0.06254094750470211, 0.033480110728452285, 0.05105254360504689, 0.047267038870843193, 0.03919386642894918, 0.0714812203941326, 0.03769882286207811, 0.016519874033908692, 0.0630028717099659, 0.03326636070625917, 0.8968922279534802, 52.05779106386247, 56.16288877302601, 32.4854874995447, 47.51257204240369, 39.47563163695797, 76.07581292429279, 56.676350562803215, 71.27886402991511, 12.545315623283388, 0.20741200825620085, 0.07658329702192739, 2.4178239895451457, 71.76413966763404, 68.19214697807067, 72.33940232184626, 63.76990602862451, 63.495222445457216, 57.04846974342101, 60.736286101802705, 59.24458126867972, 66.12665822429042, 63.355182063195016, 62.92279566487959, 55.32772202645579, 51.69530522438788, 50.99815099470077, 51.12001511358446, 47.550324855312226, 50.28192227886569, 49.28104323725547, 51.67746236247402, 51.02405432731875, 50.70806818623697, 50.41865218070246, 48.227227887799664, 45.899152140463556, 49.02184909389865, 48.6702125303207, 48.216794383141306, 48.72249380234749, 48.406915587763635, 46.69759765748055, 47.748149594952984, 48.47097965978807, 48.10220233855709, 46.59953840317265, 47.05127777591829, 45.716342233842425, 45.93450446282664, 45.940250735129084, 45.31042398944978, 47.49652954839891, 46.808173195008315, 43.67020645449239, 46.16130767330047, 44.44624347071494, 47.48305620685701, 48.51639286164315, 44.713086235907774, 44.55393606616605, 46.867295080615634, 47.07063467271867, 49.62686684823806, 54.66991309196719, 58.56018258679298, 60.29832209310224, 59.71527353409798, 62.0864482848875, 56.54429220384168, 60.0135580185921, 63.97586184163248, 60.885218497245546, 56.87690919445407, 49.504743852923, 47.64474807247039, 46.7858313745068, 45.18695169879545, 46.380246531578806, 47.02931642532349, 44.73363161087037, 45.33684115256033, 43.22752383447463, 43.3532161866465, 43.462995483029275, 43.81189815459713, 41.75276756286621, 41.90533599545879, 42.92178292428294, 43.34332004670174, 45.26036670131069, 44.59933357854044, 44.912832936932965, 42.05764947399017, 43.87155740491806, 43.40290869435957, 42.830952598202614, 44.45176616791756, 45.74028045900407, 45.607061078471524, 43.182342052459724, 41.73712907298919, 46.17198828727969, 40.78491487810689, 42.5807838286123, 42.67614449224165, 44.20290354759463, 42.64557746148879, 42.44129257817423, 41.59837522814351, 43.10223548643051, 42.52858100398895, 42.328787234521684, 42.88712093907018, 43.3044062122222, 43.34574014909806, 45.171925098665305, 47.19848040611514, 44.86148911137735, 48.26807545077417, 52.456613740613385, 58.75619126904396, 61.05431187537409, 62.923988065411976, 64.15238418886739, 71.02003466698432, 30.624450329811346, 0.47171790393129476, 0.21305251445981765, 0.618956754765203, 38.79358245480446, 58.01662837305377, 56.639523429255334, 50.71360265055011, 36.97849781282487, 43.083682675515455, 43.891616405979285, 41.739298143694484, 0.32313472200785914, 0.07032296440053372, 0.07727008718516558, 0.02246799326742128, 0.10398073091862664, 0.01771218263574185, 0.004391367763145677, 0.0245128313244711, 0.0414728899035723, 0.07561408088452394, 0.05374209061565419, 0.043988596242401874, 0.03482782409616536, 0.05437383736153284, 0.0543077009910297, 0.05036530144993336, 0.040761427878732645, 0.11704209335749188, 0.18563859435098787, 0.17269644285401992, 0.1431916849387269, 0.22969847124430443, 0.159321972619622, 0.14501874335110188, 0.130881893057977, 0.08873968745671934, 0.2880283751555028, 0.09510736431806319, 0.16117706985002564, 0.23004111172931813, 0.16196771855315856, 0.2115801853999015, 0.18639112251900858, 0.13245972774682507, 0.1949415983812463, 0.10457498532149101, 0.19072417710577289, 0.19440236441310377, 1.782428581387766, 65.78114055818128, 66.14718006503198, 45.852977998795055, 54.11157546504852, 41.308798405431936, 81.25613427931263, 62.54650700476862, 77.29546608463411, 15.491054846394448, 0.14371587294003657, 0.20221085347715886, 2.95382518922129, 74.38786798907866, 69.31723179355745, 76.04087245079779, 66.84791934105658, 68.49537757135207, 60.41046657869893, 65.12199017309374, 62.616795878256525, 71.14734695803735, 66.67285611552578, 67.29936061366912, 58.40474690160444, 54.89992480124197, 55.81486863474692, 56.50143638733895, 50.27890989857335, 53.034331798553474, 52.642043790509625, 54.67991905827677, 54.33993193411059, 53.82496003181704, 53.054155457404356, 51.43762119354741, 48.5079126973306, 51.92200645323723, 51.96568204510597, 52.001050056949744, 51.31875768784554, 51.191010013703384, 47.68713320455244, 51.457201665447606, 50.31562328338624, 49.63832016914122, 49.848657269631666, 49.338294152290594, 46.111344522045506, 48.01219963258313, 46.99475249936504, 47.94458189318257, 50.748197955469934, 49.50375933800974, 47.71321304382817, 48.59926077627367, 45.9635417692123, 49.210303291197754, 50.452976842080396, 47.87227299905593, 47.12915643568962, 49.64476854570451, 49.63108731854347, 51.89827611369472, 56.03105791153447, 59.543936560230875, 61.35530671765728, 63.05157492237707, 64.04287161365633, 57.207168840592914, 61.12665999320246, 65.7219716041319, 62.720036583562056, 57.490826806714466, 49.53720931083926, 51.268221870545425, 49.46732051910893, 47.09546327590943, 47.65277716421312, 50.746923185163936, 49.02309640761345, 47.25264441582465, 47.094776861129276, 46.443894832364975, 45.98668375322896, 47.74439196432791, 45.324160129793235, 44.21411760391728, 45.233596524884625, 45.54535435092065, 48.679916474127005, 45.553607017763206, 47.12975263595582, 45.22239031330232, 45.8213048596536, 46.01954144816245, 45.53935312455701, 46.08188752205142, 47.677405726525095, 47.421608355737504, 45.09296386472641, 46.41400244928176, 49.2912688562947, 43.42467000407558, 44.67277211527671, 44.73606740274737, 45.642232971806685, 46.23140435064993, 44.93956781202748, 44.37526818244688, 45.59638830923265, 43.888643249388664, 44.33331843345396, 45.070790706142304, 46.29789244744086, 45.05733697645126, 48.8096292557255, 49.14348963768252, 49.885107855643, 51.28899866534818, 54.33397385381884, 62.297993475391024, 63.49997243573589, 63.18022474165886, 67.63246397818288, 72.61185799875568, 34.26113467062674, 0.45987479749225807, 0.23635140860513335, 0.7860827578171607, 40.64364287161058, 64.67008606080087, 61.188633441925056, 56.56495917227961, 45.43391981432515, 49.926014254170084, 52.63604256414598, 52.08618902391004, 0.8212334458385745, 0.10516843533203488, 0.12587843492867487, 0.22619738814330873, 0.12349779372133556, 0.23357720504845345, 0.16777892446806356, 0.12652235481167032, 0.09443480040757887, 0.12384913696516907, 0.10993860436663513, 0.1984492851601493, 0.11665664387926941, 0.12461849608488622, 0.12848219924396084, 0.15597593039274216, 0.2995979882055714], [0.047307312113022616, 0.047338499552420074, 0.05438470048829914, 0.005429040559852917, 0.04726803095470514, 0.020828438704953562, 0.09252404688947624, 0.042936864774674184, 0.012124181225625499, 0.042435303180208134, 0.02499280647645074, 0.027422601800231684, 0.04145163096367352, 0.08667658203311505, 0.0153154612428719, 0.03231009145477607, 0.06664631692993064, 0.02907055077112971, 0.026455421541487018, 0.0684978365297279, 0.018385974202124823, 0.1200642642535029, 8.024228984309781, 52.853145753183675, 37.846063337018414, 47.09453759654876, 29.65004336449408, 57.484715753985995, 58.89413318326397, 62.52019182328255, 39.14563478962068, 0.3085396132401882, 0.5523655118961488, 0.30408508775215, 26.54024120300047, 81.08557393473964, 64.46250246417138, 63.842917027012, 61.133853620098485, 64.23011772094235, 64.7112121120576, 66.9846845442249, 65.6116823996267, 66.26108569483604, 63.54349113279774, 61.25281518505466, 57.15074946803432, 57.60170828911566, 55.11474909320955, 56.74400752590549, 59.22879765110632, 61.507757479144686, 60.96495636047856, 60.057049259062744, 58.62451337998914, 53.485561263176706, 48.19241293015019, 45.50358895332583, 45.30551710436421, 45.154686281757975, 45.4664009617221, 48.728232229909594, 47.68442676913354, 45.54803725211851, 43.82544209880214, 46.22654453400643, 45.77366767391082, 44.72698319342829, 44.668088805290964, 43.42032009555448, 42.326449501898985, 42.78512754747945, 43.25271329572124, 45.44301579075475, 42.473369721443426, 42.184396943738385, 43.107318878173835, 47.265341128072436, 47.35882297638924, 46.89037038433937, 46.489127605192124, 45.3416774349828, 45.60203652228079, 49.36192251020863, 58.14915741643598, 57.30423965761739, 55.851123102249645, 57.60659556235037, 61.76320575898694, 64.14975227848177, 56.04289954708469, 58.114028669172725, 63.608398514409224, 61.468894635477376, 55.43759938209288, 50.02063358983686, 49.19314292169387, 47.31739490262924, 47.728145507074174, 46.12157406345491, 44.96347073585757, 45.353005240040446, 43.2863123186173, 40.756862086634484, 40.757254323651715, 42.44810965753371, 43.37990791566911, 40.2095070961983, 41.07023200681133, 41.339428194107555, 43.75180352118708, 42.14796204720774, 42.341370198034475, 42.01842969463718, 43.21024971623575, 42.71739998171407, 41.138881329567205, 41.34308384310815, 41.04976115688201, 42.06916163044591, 43.37620912059661, 42.735403660805, 42.296231562091464, 41.57106768700385, 39.83498742503505, 40.334936649568625, 40.8496065293589, 41.577343479279556, 39.818709588819935, 39.966516264023326, 40.748123045890566, 40.96704229231804, 40.876306103121856, 42.27445064052459, 42.17270828062489, 43.24856342807893, 43.39693100221696, 42.93054157687772, 45.87707311876359, 47.6684509554217, 47.230792891594675, 54.06061995413996, 59.867787053508145, 59.83202680464714, 64.40013677843156, 63.336570416727376, 60.44711328321888, 2.1398340934707276, 0.1377895546536292, 0.10154762034935337, 1.8635892844007862, 51.30665717586395, 48.17014563468195, 60.73031625440044, 33.86520278069281, 39.976702659360825, 36.11887508823026, 43.05407662545481, 6.634846041279455, 0.22554949226398624, 0.0677698997840766, 0.07369272470954927, 0.04156812612387923, 0.04639003290644577, 0.043192397232257554, 0.024835643538784598, 0.018374754844473738, 0.04899835927532085, 0.04416286592341719, 0.04576474045132918, 0.06296721797796988, 0.0982693462602554, 0.0526760601168198, 0.03190748735270914, 0.033620400579586145, 0.026121198447541367, 0.02644266234710813, 0.08374769766364368, 0.040412049650424914, 0.0862034231484417, 0.016661667332593954, 0.021056386251603405, 0.04113922796903118, 0.07557529385291761, 0.04665262486425139, 0.0868205376149666, 0.030029857561232585, 0.00796062024047358, 0.04555886198255805, 0.09559545425638076, 0.06387542670352325, 0.01805715585848497, 0.051739283972570015, 0.09583219074674192, 0.09597764786092505, 0.024608488893136386, 0.04598036738893679, 0.19193980542402114, 12.612606825367099, 64.33361730267926, 36.5045186012022, 57.772335313981586, 37.06648442053026, 64.52520547374603, 68.0776765269618, 66.04743419154998, 42.64910759464387, 0.43189990183999466, 0.07115800789887868, 0.36848531915776195, 29.208056965181907, 80.09733276982462, 66.57886828145674, 67.5872233606154, 65.79917953860375, 66.0320741899552, 67.4358904746271, 69.92857240861463, 69.2232047357867, 70.28217407964891, 64.86017196409165, 63.4039528139176, 61.27874989663402, 57.43140289860388, 57.974380523927756, 57.02108767724807, 60.93422459017847, 61.03618268043765, 61.334435785970385, 62.56846835536342, 59.690766565261356, 55.6993862121336, 49.05506372451783, 48.65854740142823, 46.53389361596877, 46.33434303345219, 46.26633697940458, 49.89908326056696, 48.55726395883868, 47.465585970109515, 45.06983757019044, 48.28075255117109, 46.72392852844731, 46.19840937276041, 46.91457533067273, 46.69208280501827, 46.31708852706417, 46.12492768995224, 46.229439243193596, 46.351762279387444, 44.716345725520966, 45.14039316485005, 46.25460124784901, 48.65369542952507, 50.25712897700649, 50.245134369019546, 47.62738766208772, 46.53102636337281, 48.518181462441724, 52.350709745960856, 58.50021739159861, 60.314650920129594, 56.76366252283896, 60.18759358313776, 62.74820704613963, 65.4543012188327, 57.04114667830929, 59.5168996626331, 66.42490740745299, 61.529726674479825, 55.99581149316604, 48.99004259417134, 50.47713079760152, 48.1494668991335, 48.444174182030466, 46.722277210604766, 46.50419342902399, 45.654788478728264, 44.93253892467868, 43.36443024296915, 42.691124023929724, 45.54565245105375, 43.021870043969926, 45.16887349467124, 44.130547585025916, 43.32333164830362, 44.705151281049176, 44.60074563180247, 44.856601838142645, 45.160605138348, 43.96044223539291, 43.89342069625855, 43.20058107376099, 42.657681895840554, 42.77833007997082, 43.635301282328946, 43.916703885601414, 44.94589067274525, 44.7474971894295, 41.91101166509813, 41.69669335888278, 43.39998260621102, 42.38985853810465, 42.37145869962631, 42.80466487330776, 41.67432800416024, 40.708507107150176, 41.870105266571045, 43.67926320722027, 44.39847684675648, 43.95402131542083, 44.148202173171505, 47.174542180953495, 45.219993745127034, 47.70106938577468, 49.866519743396395, 48.18889064173545, 57.43057920086769, 62.99326888976559, 62.79828394612959, 66.44532726657006, 64.86604767460977, 62.13924338740688, 1.2184448251801154, 0.6583280969531305, 0.556113152734695, 2.0243171049702555, 57.7959519047891, 54.044028328311065, 67.3058246797131, 40.57497393700385, 48.77195096785023, 37.02612323145713, 52.342868927986395, 10.844560227086468, 0.4366901883434865, 0.11512773922614514, 0.06550231017172337, 0.1266094207042648, 0.09673315611097122, 0.09186165662662638, 0.011764083512037272, 0.023629539608654958, 0.046167687377742225, 0.047403896648076274, 0.05412050357629215, 0.017386424813359495, 0.04685005338321771, 0.04817170060930714, 0.01678268815721235, 0.04132567078716332, 0.07337599331813474, 0.17097295952900765, 0.13868554044635067, 0.1258227096930627, 0.1623994244202491, 0.07186925158865991, 0.13482084137297448, 0.20770667631539608, 0.16811899089765164, 0.10537079745723356, 0.104887756038337, 0.11185478178724167, 0.12909022790770378, 0.08393068542523731, 0.1746592673683359, 0.12411687703382586, 0.14830372837041655, 0.18401514678712816, 0.22146100358616924, 0.15069494925199017, 0.15180409134876344, 0.11975526268924437, 0.28688233826429616, 18.689554545187182, 74.92504442891767, 47.832813955122425, 62.534481017820305, 41.6587052037639, 71.58855084450015, 72.11628221696424, 74.93210469522785, 47.98791231647615, 0.5079436584586098, 0.7670405086490416, 0.3425811898083456, 30.575195166372485, 83.87790141567108, 70.87063943186115, 70.71329747476886, 68.71600304880451, 70.3744831392842, 69.77072838814028, 72.42451775458552, 70.60557350035637, 74.53858898532006, 68.63917950660952, 65.07685153715073, 64.17068204572125, 62.96101916220881, 60.05957526545371, 60.68366358357092, 64.81194642282301, 66.40859034753615, 63.92254898625036, 66.46860261117259, 62.98407485408168, 60.03641366958619, 52.85180038021457, 52.113257300469186, 48.775971397276855, 48.44194235340242, 50.27943549617645, 52.349125108411236, 52.706668761468705, 50.624164765880955, 47.395650109937115, 49.19097385098858, 49.13688436631234, 47.959196644444624, 49.00797567059917, 48.91424671296151, 47.42530322843983, 48.246545560898326, 50.354748925855084, 49.25919955776584, 49.303616477597146, 48.50278223714521, 47.535027611640196, 52.587879780800115, 52.90882772014987, 51.60104282440678, 51.252336271347545, 48.90431134931503, 49.72758939189296, 53.8506672459264, 63.99429698144237, 60.850846767425544, 58.91305077460505, 61.68528395314371, 66.95031673677506, 67.31502656013735, 58.57894328332717, 60.64850345734627, 68.10386227023217, 64.00458928077452, 58.95441216807212, 52.79765598235592, 54.85908508300782, 50.63058960822321, 52.14274175705449, 50.53861787242275, 48.84535028088478, 49.37208929369527, 47.644206785386615, 45.003773089378114, 44.63103025190292, 48.46254264154742, 46.17625974839734, 47.799615013983946, 45.696820597494806, 44.20251915531774, 47.02908892785349, 46.98598992440009, 47.11459267523981, 45.93515165390507, 47.325263177194905, 48.48250358335434, 45.724955758740826, 44.64010661648166, 45.26891746828633, 45.60448408126832, 46.60784990556779, 49.32641329303865, 46.51774521796934, 44.58082391369728, 43.86401076470652, 44.727167544826386, 44.79606789927329, 45.23454573846633, 44.6937567956986, 44.51651665472215, 43.75497279628631, 44.792792720179406, 45.92078793433405, 46.90415751549506, 47.228796405176965, 47.5585186866022, 51.266476415818744, 47.51733772216305, 51.50836113960513, 53.22806158373433, 51.20563260970577, 61.07037005885955, 66.356642476974, 64.55162655922675, 69.52676480816257, 65.36641659275179, 63.86988332194667, 3.8430100823602373, 0.3612277392418154, 0.43686053565432953, 3.8781317203275623, 62.727387105264974, 60.35441590893654, 74.38545965379285, 47.58811296955232, 55.53806697168658, 42.45801364221881, 66.03540820460167, 16.004738250086387, 0.4827315822964715, 0.3565607928941327, 0.14048950896868784, 0.2158616056605693, 0.22031666741015452, 0.24778789089572048, 0.1035833151470269, 0.16627498662039158, 0.1284169362136914, 0.16010839251741288, 0.27639205116898785, 0.18997538744682269, 0.2893685080832051, 0.16044277457460282, 0.1353882060896966, 0.13688331860448086, 0.15679409697411523], [0.03790947788905713, 0.05327742381562149, 0.06398427247580502, 0.08440088721052294, 0.025563277679705815, 0.05293922664056863, 0.04996540355345896, 0.04155136028965635, 0.003851964537452366, 0.022896422193415707, 0.004497958364100346, 0.03528278839263705, 0.029060377123495264, 0.04111619553558769, 0.041734439981800896, 0.023151945074900024, 0.033533721561393434, 0.04350147157486889, 0.08124328729125761, 0.030191465724079363, 0.09714269139353307, 0.06107033448173635, 0.4088611864755231, 36.94705217115341, 50.50825088254867, 45.88977767575172, 36.4047021250571, 36.696471552695, 54.30090435089604, 59.08467408149474, 59.54637235210788, 2.0618448718901603, 0.07568983165847679, 0.12080526279826319, 0.6791221134124265, 59.22455756895004, 72.08780580951323, 66.7100009610576, 63.114556420233946, 66.97268209149762, 66.82856636662638, 67.63933597072479, 65.93302649836387, 67.35543481765255, 67.4483008538523, 65.066045407326, 61.64113767685429, 61.82651281356812, 65.33461009302448, 65.68734884262085, 64.55570582420596, 65.70153605553412, 66.74498065825432, 64.60799886334327, 59.673865072188846, 56.275856956358886, 48.93716119950818, 46.78190115959414, 44.12054946345668, 45.24316710810508, 44.28022523080149, 48.57095695311024, 49.11795108549057, 47.76939315180625, 45.81778257123886, 46.985546696570616, 45.935947895050056, 44.96766374957177, 46.34579243198518, 44.813008616047526, 44.405890126382154, 43.05746163091352, 46.022224349360314, 43.200133923561346, 43.381394493964414, 44.71667128224527, 43.99755962433354, 45.61747497127902, 44.44367824062225, 46.78650209980626, 44.305763782993445, 48.96507278565438, 46.150085772237475, 53.199938189598825, 59.84467252608269, 62.89868093306019, 61.83335734951881, 64.14926982695057, 59.99208696426884, 64.7639758356156, 45.49525391670966, 42.93762537740892, 65.82401598653486, 59.43440829553912, 59.38561008822534, 54.42003457776962, 56.00435049303117, 58.2245453711479, 58.31241038537795, 55.99932593684043, 53.137984352727095, 46.15400029766945, 46.05248543523973, 42.872541489139685, 42.43855868616412, 41.45692671498945, 41.46630510207146, 40.86556273121988, 39.885189840870524, 39.88846109759423, 40.67824209890058, 43.15549735100039, 45.41355879076066, 42.85909168181881, 41.390203275988185, 40.3148345024355, 41.58129330604307, 43.035614029053725, 44.69053652978713, 43.819056480161606, 41.95471863592825, 42.670500201563684, 41.84508446724185, 42.20355379965998, 41.322581614217455, 42.179007607121626, 41.293112847112845, 42.066765062270626, 41.891086024622766, 44.176529530555975, 44.35326760815036, 44.7417587618674, 46.642249091979, 44.958132390053045, 46.46321642783381, 45.361097089705936, 43.04910698244649, 42.61963490516909, 43.07841493237404, 44.33513841321392, 48.309503524534165, 57.36232995986939, 59.16615739945443, 64.23615424863755, 60.07957935333253, 66.61171420927971, 11.87554051799159, 1.1901825546256959, 0.36504022176227263, 1.8511095282531556, 6.4626132961242435, 54.782449814581106, 54.22201764199042, 43.897107724220525, 27.529868925771407, 34.687268810887495, 35.31910381009502, 27.934581041336063, 0.19261560222554594, 0.03665841417387128, 0.06845814551437093, 0.04056622867562598, 0.038199288950812434, 0.06709711370809425, 0.0677488706705551, 0.06701243800982352, 0.010192883144613477, 0.11379381927150874, 0.044424396849447684, 0.006643496284772072, 0.04530866915780691, 0.03500745639265065, 0.011101749748171819, 0.021996475726125703, 0.08021570291490325, 0.08593977398930058, 0.038446513184856985, 0.027082349594321944, 0.006052579152427855, 0.048108276190055956, 0.04792005604793949, 0.06551710332954122, 0.014845743050588476, 0.013186765286410529, 0.054891352737022024, 0.018538515714387742, 0.010926334765709696, 0.04339593530242001, 0.024964792556279612, 0.028078085780444167, 0.053846178981926174, 0.031110646743928234, 0.04163267286193948, 0.04075287067661843, 0.033471044077868425, 0.05187998368074337, 0.05189064379420973, 0.038839006841543226, 0.45537320356215205, 48.39435223610171, 50.92783858699184, 48.36437748324487, 53.826936906383885, 45.580887102311664, 61.78992102223059, 66.48840273580244, 64.12671227608958, 1.0719018886166236, 1.307662934545548, 0.2144201805875186, 1.0183381854045777, 65.1008564426053, 73.00059626179358, 69.83817746562343, 66.5253749970467, 69.90154727812737, 68.47236110318092, 69.89409477479997, 68.82273074119323, 69.627726616398, 70.84854079831031, 66.3216314008159, 63.03299857724098, 63.454233677156516, 65.85790526482367, 66.50861078693022, 66.47565503274241, 67.11820986963087, 68.21504577513664, 65.99237195907101, 61.78801082795667, 58.793136073697, 50.463602542877204, 50.86714775331559, 47.6697688717996, 49.09942573116672, 48.51252148228307, 48.89769038846416, 48.87234011004048, 50.208770075152, 50.165070949062226, 49.81233219946585, 47.114027853935, 49.29765447493523, 47.691220314271995, 47.66665843225295, 46.93866260590092, 46.67176492752568, 46.23589546449723, 45.45635969408097, 45.26852915363927, 46.00527971021591, 45.647347742511386, 46.78910655360068, 46.70121016040925, 49.2341277676244, 46.415763593489125, 50.12856937223866, 48.25828521482406, 55.343309525520574, 62.06058025360108, 64.05052023549234, 63.60416235462312, 64.95739967592301, 60.94650945355816, 65.65303594835343, 48.40365217578027, 48.51509063474594, 68.14956572748, 61.858829221417835, 59.587576850768066, 53.999081888506495, 57.64592909043836, 56.400035273644235, 57.80955076217652, 58.32826460561445, 54.80494852988951, 49.0441713025493, 48.37394806646532, 44.8403710703696, 44.153140437218454, 44.339888403492594, 45.17384313767956, 44.32182588884908, 42.53607665338824, 43.65859623878233, 46.82756539314024, 45.212290210108605, 46.09920478636219, 45.05915303384104, 44.053123920194565, 43.663201101364635, 43.1001683973497, 45.211078197725364, 46.75258928729642, 45.94606761009463, 44.19343886836883, 43.791121359794374, 44.293659348641675, 44.08896653882919, 44.13436012883341, 44.26021722055251, 43.46813771032518, 45.0450050446295, 43.79918183049848, 45.63661221534976, 46.182017787810295, 47.60800723106631, 48.608870583195845, 47.33762648797805, 49.680842584179295, 48.84715849353422, 45.23090970131659, 46.54556266723141, 45.778672618250695, 46.92710338100311, 50.89074080990207, 59.849850054710146, 63.49326126037106, 66.4121675491333, 60.52015566056775, 67.76066272489487, 11.214163207238721, 2.1797348943448838, 0.544624898222185, 2.322012988790389, 8.667838938774603, 60.64431436600224, 61.718082812524614, 48.448222068048295, 38.51547464247673, 41.515766189944365, 38.21533879926128, 36.4202307885693, 0.3023377944144511, 0.049407565140075264, 0.03167329618947641, 0.03445779213741903, 0.08476205936242497, 0.060813679705343904, 0.04022943727191418, 0.059616307262331254, 0.050039166329248305, 0.045033858097609014, 0.06812464445829391, 0.02864042879082263, 0.02284711294416939, 0.043519999411317616, 0.16095015460685377, 0.04259184941709523, 0.022717077179902026, 0.05472575134086994, 0.10599904318129826, 0.13785765987009774, 0.09136622756599419, 0.13607604579339105, 0.12092233635485174, 0.1561393216252327, 0.1384249632997859, 0.08682936294785432, 0.19370559212421218, 0.14613727768582685, 0.09985438983647094, 0.10328860112255621, 0.14122502998478953, 0.10906645923011726, 0.12586055443652217, 0.08061082808360939, 0.1000434143709079, 0.12656329455034387, 0.14927073051371884, 0.18094852746975038, 0.19138479004463843, 0.17304919569963412, 0.6142416368088415, 60.66820944509199, 63.201166276008856, 58.28367510149556, 49.57302839525285, 49.954361223405414, 69.73134779161023, 73.09239541330646, 69.16878577201598, 4.915680510382499, 1.59835260721945, 0.3012720128941921, 1.5533060244014187, 64.32511752651584, 76.21071892399942, 73.89112334097587, 68.73536386797505, 74.78269377062398, 72.20491993811824, 70.94520368883687, 71.54336514011507, 72.92458857259443, 74.25099295954551, 70.02161102910196, 66.08209225439256, 67.31111987944573, 70.84704245290449, 70.90368932293308, 69.257674524861, 70.1633027292067, 73.366561243611, 67.91274870595625, 61.96964794589628, 60.77232483894595, 53.63040654889999, 52.575132077740086, 48.549254478946814, 51.70864520534393, 48.79235121511644, 53.47740273321829, 52.11870939500871, 53.88964776069888, 50.987129134516564, 53.22735163473314, 49.88081286030431, 50.09570775493499, 50.98643879736624, 48.999895588044204, 49.39476451566143, 49.034447746892134, 49.371163614334606, 48.34742499936012, 47.76170138389834, 50.007293608880815, 47.15986074939851, 50.53668414392779, 48.975004226930686, 51.68871172012822, 48.98489252213509, 54.10142437104256, 50.354548884976296, 58.093436225768066, 65.07010898282452, 65.95669407998362, 65.99211308263963, 68.8665279265373, 63.18308414951448, 70.15708185011341, 46.923184933200965, 50.05617810833839, 71.46454903387254, 64.301038096028, 62.61288135282455, 57.57170607966762, 62.01131920660696, 62.17463101110151, 60.70677026625603, 60.250590770475334, 59.466795306051935, 50.70275729702365, 50.070918375445956, 47.571215398849986, 47.40230637211954, 48.33171198444982, 48.40801385141189, 45.674110074197095, 44.81737421404931, 45.046668129582564, 48.07685990487376, 46.72370103097732, 49.55127493027718, 46.60846964005501, 46.597059465223744, 44.48605552796395, 44.94539253173336, 48.380478812802224, 49.199606987737845, 48.54137051490046, 46.371123098558, 46.31463312333631, 47.05674948230867, 47.9658019158148, 47.925001421282374, 47.12076648589104, 44.77720522111462, 48.73583378330354, 45.86837330172139, 48.75952489914433, 48.20734931576637, 49.936243795579486, 50.50585039200322, 49.46544954853673, 53.44073249447731, 51.236521274812766, 48.420624271515884, 48.06490452058854, 48.47672200972035, 50.23652476649131, 52.18392272149363, 62.73054853562386, 65.79964630065426, 70.50159931182861, 60.64542047439083, 69.74440928428405, 15.683773640663395, 1.7764919515578979, 0.3321979405178178, 2.9352074140502564, 9.632420366810216, 67.2012621356595, 66.2960732367731, 55.32354862459245, 40.23833651696482, 44.667465148433564, 48.55525962768063, 49.70812659109793, 0.3809713265828548, 0.16469805591529416, 0.16146740185156946, 0.07995324119204476, 0.14971526069266183, 0.15975343333857675, 0.15084497991108126, 0.23832598490820778, 0.08393730442490309, 0.15439003645893068, 0.09676869492977859, 0.09503348279864558, 0.15909980712158067, 0.14200746622537413, 0.21643776506666215, 0.1183270832764045, 0.19257106187362827, 0.2233929700788952], [0.018544698043936686, 0.08087441595571657, 0.0383653155257625, 0.022763680223555818, 0.0637771261315192, 0.03928508451809326, 0.028911386428761388, 0.049082701725344506, 0.042978153083353274, 0.07837611130408703, 0.11349929676901911, 0.043870572736787225, 0.056562983400879376, 0.06818632219707774, 0.02555657824080798, 0.04900486336179799, 0.02322944444454005, 0.03358956554063386, 0.03961091703404823, 0.06743813008670846, 0.07981129276055483, 0.024491126138356425, 0.2035857974401405, 9.486977900228194, 53.350890605680405, 39.770640942358206, 39.37516796973444, 20.064311950437485, 64.62394722046392, 60.33483151466616, 64.36898531452303, 10.024660325819447, 2.046108935629168, 0.3849602851175493, 0.383622266592518, 10.016752827552057, 75.39693693960868, 66.10646586264333, 71.62884143091017, 67.6496204253166, 73.0420478697746, 67.89607078798356, 64.32256014116349, 65.39466942510298, 65.91001787493306, 68.73788202962568, 69.40466926943871, 65.55359994211506, 65.97312096626528, 66.32481636539583, 66.50859509744953, 68.47600890744117, 70.6987690156506, 67.12598400731241, 62.65092834349602, 53.98097230542091, 47.616146149173865, 46.50592711664016, 46.85421397609096, 44.211332721094934, 46.10451175320534, 49.552906636268865, 49.759556708797334, 52.54677334139424, 46.675000882917836, 45.32132425615865, 45.476144129230136, 46.163688551995065, 45.48676983002694, 45.51136701337753, 46.02032199982674, 45.42516508410054, 45.09463087204964, 45.59236003506569, 43.65019059950306, 45.609214459696126, 45.73916258350496, 47.26150112767374, 45.841175586946555, 45.271996528871604, 45.630340345444225, 48.173205083416356, 51.13033094713765, 54.996838723459554, 64.05992215679538, 61.31302748956988, 59.526591839328894, 63.64751238976756, 60.83580840018488, 58.32312630068872, 32.86508075652584, 22.10329724896339, 63.31427566466793, 64.41471622836205, 62.66197373790126, 60.433541882422666, 59.43539673282255, 60.85882094598586, 61.38783493349629, 58.94636346447853, 60.50336791623024, 51.72626841452814, 45.017340567804155, 44.863571889938854, 42.97968887513684, 40.72711090887747, 41.56197171057425, 42.409725343027425, 43.017363240641934, 42.01696665056291, 43.611092413625414, 44.8222928662454, 43.51839896171324, 42.29358003985497, 42.007756925398304, 40.77555610287575, 41.42629300394366, 41.62625935769851, 43.92954572554558, 43.42419147491456, 42.08313703536987, 42.70809219729516, 44.468871624239036, 40.99052944490987, 42.950329934397054, 39.98009943193005, 43.28570042887042, 41.51391483122303, 47.76265451985021, 49.57233021336217, 51.095041382697325, 48.732437010734316, 51.48843942149993, 46.74477592591317, 51.270359562289336, 45.48282392563359, 50.92151180390389, 44.8896203502532, 47.89952170464301, 41.02593668045537, 50.11567261911208, 53.531382391529704, 65.77438623674455, 58.953823812546275, 75.87717625402635, 31.572475433349613, 0.1136178105709053, 0.4923629622545935, 0.42482655074807907, 2.116079974559046, 10.823585352590008, 53.65652561187745, 51.367544128048806, 33.12417684062835, 23.736885978329568, 26.29272395564664, 47.039161574456, 10.692282049886643, 0.6271333031115994, 0.21847658550306676, 0.21734501235187056, 0.1279698626228398, 0.0410249391420474, 0.04108632193698038, 0.04803157163663738, 0.0635554317775513, 0.041552409830112616, 0.025148086753042958, 0.07361910366002591, 0.10465598379772519, 0.040673197532493266, 0.05500137062382795, 0.0316471457781811, 0.055809570401306116, 0.0243667000529146, 0.058266176887217073, 0.06540149300088806, 0.017140905124946468, 0.00779916002835718, 0.04357526882461483, 0.014404378729992577, 0.07797835079292137, 0.12727516643222303, 0.0508024312195278, 0.03464288281036481, 0.06265665359434582, 0.10166378226131202, 0.055732781578215866, 0.016065427804395797, 0.12584701766290013, 0.07069837812694811, 0.04998764308590082, 0.0649069449413688, 0.021192309401568868, 0.02019846545261962, 0.00483057794025949, 0.05711854270268833, 0.08076212278777554, 0.20257866761136442, 15.36116163576803, 63.761453320903165, 39.23260158108127, 43.55900333773705, 29.549589503195982, 66.94500584756175, 67.92118180182673, 70.99028741159748, 12.299671307686838, 3.2353761071158997, 0.3233028936289972, 0.5048662832667751, 11.793856178560565, 77.2219608676049, 67.15824157960954, 72.84949871801561, 69.36331179834181, 74.27710810015279, 69.2602397549537, 67.25131942379859, 67.05265137457079, 68.35929486059374, 71.8839680763983, 71.93011868384578, 68.52651334577992, 66.8284643850019, 68.21760316048899, 68.39874605978689, 69.7054523037326, 72.33201257644161, 68.7199567979382, 65.16808194498863, 55.680296036504934, 51.16821319826188, 46.701327831514426, 47.496074553458925, 46.818339978494954, 49.578986475544596, 50.8849984599698, 51.610025052101385, 51.640866648766306, 48.86275383733934, 47.293582193313114, 46.48465610319569, 47.00691184689922, 47.21689593407416, 49.414113567721465, 48.51796965445242, 48.94055404970723, 47.63558149337769, 47.50365649500201, 47.78495711665, 47.44608786798293, 47.112627567783484, 48.90985758073869, 49.29627772300474, 49.52157082096223, 47.62111186981202, 50.13246820818994, 52.56471426256242, 57.609674622935636, 66.15585634785315, 63.55627021481914, 61.433593303926536, 64.04307557690528, 62.01568480460875, 60.52811022727721, 34.30384535943308, 24.650798228479204, 66.5490504234068, 63.7187308649863, 65.31528849755564, 61.283715617272165, 60.90742303479103, 63.278272228856245, 63.72437123329409, 61.58692267633254, 62.449349895600356, 51.77734944128221, 46.744670021918516, 45.30605054670765, 46.1743103304217, 44.25294514625303, 43.17338728135632, 44.11731743043469, 45.04800173544115, 44.5735518393978, 43.634963958494126, 45.36934191180814, 44.1568039309594, 45.08923761306271, 43.54598499113514, 43.365846218601355, 44.39428383304227, 43.62493053559334, 45.5447385388036, 44.944941459163545, 43.555343766366285, 45.21753834139916, 44.41076171013617, 43.0970658025434, 45.83897513727988, 41.70801331920009, 45.397684958673295, 44.702209503419944, 50.04055138557188, 51.94169282913209, 54.19195267461962, 51.93739391142323, 54.200809386468705, 48.59626016309185, 53.77536558335828, 47.80155266484907, 53.87647644166024, 46.485703376031694, 50.21355536676223, 44.39974769469231, 54.329294466203265, 56.18903529259467, 68.53506411275556, 58.928367630127944, 79.47382496249291, 32.802826858335926, 0.15231141009398047, 1.8301601491628157, 0.9673190585547878, 3.2345786402302408, 12.742202916452962, 61.30049943923951, 57.884009115157596, 39.450430408600845, 31.332249872146118, 29.373514306160715, 53.42414871338875, 14.873779685266557, 0.6373832531033025, 0.2470722728438916, 0.14269092390614171, 0.07676184147356019, 0.1119841127506187, 0.08148786852196341, 0.07711539105061563, 0.059684902775071325, 0.03979728324338794, 0.06876031357434488, 0.12193770928969308, 0.07634565654781557, 0.07375146067070384, 0.05853781251296882, 0.05624427167218059, 0.015828780371755842, 0.04934042902483095, 0.06330517383532659, 0.3204544867959715, 0.12570529905778746, 0.10782181916217651, 0.23262088217081564, 0.23181848167892427, 0.24489454534505647, 0.3221608403949969, 0.18666420222049762, 0.15279445917375628, 0.2542230907467104, 0.2018514663101204, 0.17024159070945558, 0.14452766566987962, 0.19795189491443096, 0.17256334273805543, 0.17759388973636014, 0.33625701141934244, 0.1660230662673712, 0.11247027980824632, 0.2658664320986117, 0.14500060238905493, 0.19506604170366643, 0.34230233380390757, 22.321267281809163, 74.50313860370268, 52.908627679271085, 54.000850877454205, 30.677833787856567, 77.65597112717168, 73.47736035623859, 77.06601527429397, 11.535507305975884, 4.191521252355268, 0.6388044994204276, 0.4251997581412716, 13.24544006778348, 79.47861809884348, 72.49397508559689, 76.56246923631238, 73.95126896519815, 76.459914945787, 72.39821434020996, 65.54073064557969, 71.47633967861053, 71.71331359494117, 75.95928715121362, 76.30265928083851, 73.0601692199707, 70.55004058345672, 73.41336296450707, 69.96825110527777, 72.28428517618488, 74.62753265134751, 70.59598722765523, 69.95632709995394, 58.53831929545249, 54.57081048719345, 49.953898383725075, 51.133139364181034, 49.89105416882423, 50.99883740948093, 53.22422942807598, 55.71187503876225, 56.6783078255192, 52.05498656918926, 48.550360587335405, 50.152664492207194, 48.99884831520819, 49.42324876785279, 50.57616279971216, 51.28331122859832, 51.05115398283928, 51.63534787393386, 49.15924972103488, 49.923609841254454, 50.110801035358065, 50.171131010978456, 51.27421132979855, 52.205844848386704, 52.388886174848004, 50.051938026182114, 52.19281865704445, 56.318077348893695, 58.57336959531231, 67.06349280572707, 64.32242285820746, 62.34358710627403, 64.25920209577008, 63.68489257750973, 59.52477578193911, 32.618291108838974, 23.59263885405756, 68.94332793451125, 66.82138058447069, 66.29263724050215, 64.91331615755635, 62.052766892217825, 64.41346891464727, 65.38063518462643, 61.571331254897586, 64.3229563005509, 56.51920080184937, 47.525849265436975, 48.9035935555735, 47.76214853409798, 45.314158085853826, 46.194032007648104, 47.151584548334924, 48.583928231270086, 47.3928181586727, 47.18320277429397, 49.03793473397532, 46.33288783411826, 46.08259354868243, 44.991645120805316, 44.76564599621681, 46.651199940712225, 47.00037325582197, 46.692169097162065, 48.255872957168094, 45.168343974697976, 47.407538813929406, 48.54029970784342, 45.44712643469534, 49.507501279154134, 43.64512289724043, 49.384911521788574, 46.830103166641734, 52.22111071309736, 56.975796068868334, 56.82729513414445, 55.36376860833938, 56.911508421744074, 51.04858875274659, 56.791789839344645, 50.58309755017681, 57.09649916618102, 50.05684883363786, 52.96667091308102, 46.990861508154104, 56.168556597925004, 58.66669062645205, 71.19482332660307, 62.39164006325507, 77.38887340791764, 37.62207638832831, 0.19233573498504777, 1.1280481661519697, 0.7211129247180877, 7.972660112765528, 14.24713594298209, 68.21231580549671, 62.82330082308862, 45.16188383102418, 36.19971513748169, 38.511120811585464, 63.92879732193486, 23.825319736234604, 0.7556954819348551, 0.2860152186645616, 0.279432746071008, 0.29789007178718047, 0.1964712614614156, 0.15379397408856502, 0.21019566533786638, 0.16740010931126534, 0.11188965410955491, 0.19069385534572988, 0.15130506167488714, 0.20496541453946024, 0.1966702757823852, 0.15860941891949024, 0.1884023331466221, 0.14016465704527595, 0.09826785238880305, 0.10117755391665044], [0.0230525030318888, 0.0865128843654548, 0.012076297857528253, 0.1701250687361725, 0.058682944039784135, 0.08379379317404763, 0.03219997014610037, 0.05479895870291418, 0.1021797578000734, 0.06515423812332653, 0.07823543457855141, 0.036077053030772556, 0.12014951451771683, 0.0368472165428102, 0.07539013806249827, 0.06498752206924462, 0.035891016239240285, 0.0855160584192603, 0.04805633159835012, 0.10593437769960974, 0.06108111333883098, 0.04804534972795556, 0.12408971155603087, 0.29069819157162025, 41.95359683805897, 52.17751749100224, 47.61876629244897, 24.138228777916204, 42.71375609982399, 64.41413963994673, 66.74458057649674, 24.707041094380042, 1.5667086407061548, 0.20642102756086858, 0.11668043090931832, 0.29269112334136044, 25.279893452121367, 77.60424290933918, 63.9851107904988, 75.21078125123056, 59.00038626886184, 68.22287482600059, 64.73534253335768, 71.61412469802364, 67.29521074602681, 70.65213987904211, 64.47422642861643, 66.90426026621174, 67.17849669917938, 69.0468079043973, 63.6487675482227, 66.40989257443336, 64.9296606740644, 58.237775525739124, 57.02475509335918, 55.83968939319734, 47.59062720883278, 45.60358978086903, 45.83153832343317, 48.105097047744266, 47.68874137632309, 46.725434718593476, 46.521604830218905, 46.62459450383341, 48.60638772287677, 46.02891983524446, 47.14294356684531, 46.61171344018752, 45.85801039972613, 47.76031286485734, 43.87730759959067, 44.29508316901423, 43.46610200020575, 44.03978001686835, 43.85941766923474, 43.25667096722511, 46.72150450368082, 47.212518568961855, 48.657582498365834, 52.0444824618678, 49.1319735588566, 45.955210654966294, 45.05188095954157, 47.31705757879442, 57.84817434126332, 59.07915530666229, 55.67708361533381, 65.01951040760164, 60.132229328155525, 59.647734242100874, 47.09200766778762, 47.71195004063268, 57.62702326620779, 61.56813060083697, 61.842304275881865, 63.021866890691946, 61.478257333078695, 60.37529468536378, 65.04804565060523, 57.239402878669004, 56.82210583840647, 51.98775714443576, 45.43391589195498, 43.863218445931714, 42.608667958167295, 41.51866089913153, 43.52010911510837, 42.57475514565745, 42.64465962686847, 42.29838102094589, 43.001081482056655, 43.654144348636756, 41.17632427523213, 41.36256625575405, 43.117944578970636, 42.29638061215801, 42.42757604968163, 42.971930426936, 43.010302974331765, 41.80098918176467, 41.65346883958386, 40.68300385628977, 44.826172090345814, 41.936208971085094, 41.65237842067596, 40.81019455386747, 43.16163978269024, 42.66706028292256, 48.03114860288559, 47.99006569770075, 52.33823660881289, 50.62106609344483, 51.55374296249882, 49.31560716321392, 50.64955426800636, 51.18927632608722, 55.10902243275797, 53.58202411282448, 55.691208070324315, 46.60499442008234, 50.362503451685754, 52.70832007931125, 67.01712254554995, 60.12124276930287, 72.10206754745977, 4.304351172139568, 0.20023934152578154, 0.6523233772285524, 1.5023104317726628, 2.2322171878430153, 14.287277479325573, 66.30452202212426, 42.69532488238427, 25.439445664805753, 28.210527627698838, 35.68991684144543, 41.52787846903647, 0.31112310686899775, 0.08588238634289273, 0.0711277857302658, 0.019793051723090392, 0.049236520689221165, 0.009488929739041675, 0.01361484660000931, 0.009901215277251699, 0.03779971281126623, 0.032537102458938476, 0.08472645925658365, 0.11098852020598228, 0.094819828537443, 0.11108594360731303, 0.007239026702835315, 0.03337261327091725, 0.03524616555941682, 0.09690493600623262, 0.0980981792353334, 0.01883181439141833, 0.03447547727715104, 0.05234287315679174, 0.10513393839280452, 0.07504779635177505, 0.016591396002519517, 0.11780442745094338, 0.050936527249793855, 0.04254528276261784, 0.0463135811620422, 0.042116936191075274, 0.11092571631794977, 0.012722260322451833, 0.13959090315526532, 0.03467188689917807, 0.07759021234608467, 0.04447195941822664, 0.05359248513536108, 0.03131944209247107, 0.15609773837270277, 0.03186729071932214, 0.06033038930787195, 0.13340979934700076, 0.6726797429784652, 52.70685703523698, 53.501337036009765, 43.61981968725882, 33.1435102032077, 53.89391922181653, 73.60730063530707, 72.80717634385633, 28.107437933644942, 0.8654301000698921, 1.1128987468058065, 0.31126988931528987, 0.2307688492921091, 31.516644416316865, 78.67267301005703, 64.98240086340135, 76.77037054492583, 60.96798443025159, 71.0851695460658, 65.39391240765973, 72.3557193817631, 68.399750186551, 71.3590451209776, 66.37204954701086, 69.24834712859123, 68.59605696893507, 69.88354359903644, 64.51267742341565, 68.95857026500087, 64.21037643186509, 62.15845515651088, 61.16429513500583, 57.19430738879789, 50.25201028393161, 48.76261572684012, 47.45287356838104, 50.36506868177845, 49.32635837985624, 49.581057486995576, 49.6200458465084, 48.86281267289193, 51.005062210944395, 48.844397144932906, 49.183082042201875, 49.083116515990234, 47.637628970607636, 50.38693589548911, 45.35028703751103, 46.932241685928844, 45.402674213532485, 46.93494027660739, 44.248932561566754, 43.834440015977435, 47.514619519633634, 48.39378349242672, 50.54061435884046, 52.64384808078889, 49.43861661418792, 48.295241786587624, 46.654243699965946, 50.85227804799234, 60.072005256529785, 60.0621561850271, 58.7030823769108, 66.69544112297797, 60.46382650252312, 58.76595797077302, 45.43038968117007, 38.85820350339336, 58.043022001943285, 64.36531397604173, 63.664017723452666, 65.07458440719113, 62.280040787112334, 61.78161344220562, 66.70418016372189, 56.880125537995376, 58.31925884369881, 53.94576903312437, 47.27832809571297, 46.751161544553696, 44.71902470434866, 42.92692907394902, 44.800566857860936, 45.74665823290425, 43.062784287237356, 44.44982851705244, 43.571299968227265, 45.441470376906864, 43.81911923808437, 43.81851519307783, 43.94330540011006, 43.29897765190371, 44.102898797681256, 43.36150807719077, 45.50739365239298, 43.54108595078991, 45.089418042090635, 43.24216604232789, 47.03187773304601, 43.48215233895087, 43.15159459267893, 42.645161690250525, 45.759664812395656, 44.04802876134073, 50.76890414760959, 51.82712039639873, 55.63483968857796, 52.77372560193462, 54.885286515758885, 50.50199470212383, 56.157413144265455, 55.092893646609404, 59.90382186828121, 54.42951886884628, 58.96872097446073, 50.52191249785885, 53.498540386076904, 56.912540005099395, 67.46543376676499, 62.59121417999268, 73.22497936987108, 4.358659328952912, 0.25813694202130844, 4.078107144563429, 3.9557242922244535, 1.6530212543664442, 16.905387986090876, 73.78242661876064, 48.909704608301965, 35.24483765325239, 31.63881251888891, 38.3597683137463, 51.68521688830469, 1.765557364110024, 0.1868842992811434, 0.11186229710977887, 0.11253417154113132, 0.08401818032706938, 0.041174330117721716, 0.09713817913565906, 0.1279569770239534, 0.03534607108562224, 0.09341691470434589, 0.04129915265366435, 0.02377720114084021, 0.06212006645998167, 0.1896197694323717, 0.05492269722444396, 0.017573329199466015, 0.056241123050811796, 0.07253550293464815, 0.05283380145086877, 0.1111651877422006, 0.21333851040371005, 0.16959873568867484, 0.394811317805321, 0.17168931302524384, 0.2260188436916759, 0.1445255512672086, 0.14240377883036293, 0.13828976410290889, 0.2539769160531221, 0.1368462093054287, 0.30402671185231983, 0.14165655199077823, 0.30752488381920323, 0.15088000545097938, 0.21501886297858533, 0.17199937945171712, 0.11484798689883564, 0.17107817404452832, 0.3008758228632712, 0.13875520848218473, 0.258634592736921, 0.3068486733301994, 1.0934418295660326, 66.20149704717821, 69.37470236132222, 65.97173244722428, 38.82278842310752, 58.29918807552707, 78.83954632666804, 82.55966340341877, 31.00117829538161, 5.655521404358649, 0.6363321804711897, 0.45850414362165237, 0.7191359888642066, 32.977288000045284, 80.59420293377292, 64.66049978809973, 77.53056510802239, 61.41890010526104, 71.91952043964018, 67.87014392114455, 75.28526706080284, 70.6374074566749, 75.82237289797875, 70.2093513550297, 73.10976366842948, 72.2954168627339, 70.70633919008317, 64.3267256982865, 67.77697194007136, 66.90244813119212, 63.91962682047198, 63.12451924047163, 60.20554627141645, 51.54656502508348, 50.336239261011926, 49.56084551349763, 55.38409040820215, 53.20312315417875, 50.97742126834009, 50.23405759565292, 50.74383235746815, 53.58816654451432, 53.12135742556665, 52.21013984372539, 50.46505774221113, 49.79696827550089, 51.60496911694927, 47.285525644979174, 50.80974778821392, 47.248353342856134, 48.81912531391267, 46.477584069775, 45.340598783185406, 50.7646248417516, 51.62170194810437, 55.707179961665986, 58.12476811870452, 54.18755569765645, 51.9831758160745, 47.039746007611676, 52.865289411237164, 61.64111806500343, 61.634877574059274, 58.98276698204779, 71.83651524205362, 60.23341078912059, 64.28814134290143, 44.46787141984509, 44.72104080261723, 61.38171995839765, 65.38160008768882, 67.45818522668654, 68.40262136151715, 64.7964922843441, 64.1108698229636, 69.96650957292127, 59.59932434943415, 62.01282539675313, 56.953548385250954, 51.28547245456327, 49.28066276734876, 46.86395714359899, 46.75295014535227, 49.89280354592108, 49.13442111784413, 46.587586941257605, 47.439576733496885, 47.29613957866546, 47.78869513542422, 46.17298849167363, 44.807929146674375, 48.613506824739524, 46.478195959521884, 47.04802613104544, 46.053136548688336, 49.13644506085304, 46.7196374554788, 45.78294015699818, 43.926505888662035, 51.29997345709032, 45.358998621663744, 45.89613583780105, 45.30787444883778, 49.139990883488814, 47.08974446019819, 54.868279118691724, 52.94471740722657, 58.079276469446, 55.37553571885633, 57.870892709301366, 53.24410015536893, 60.06343880007344, 56.721116573579856, 62.994390687634876, 57.231573827805065, 62.14759019113357, 52.643004771201845, 57.70732595074562, 60.2327714427825, 73.01909415952622, 62.740911437619125, 76.07619731656968, 5.350164886443846, 0.45937451143418595, 4.474820321606052, 7.65547372641102, 6.277019977569581, 18.158773529914118, 81.23956618770477, 55.1463516296879, 38.06821461646788, 42.25632929032849, 49.18350173581032, 63.70068796219365, 3.5262549115765482, 0.2625449506505843, 0.24695306956287355, 0.23539091820918748, 0.23390630109896585, 0.2048066964433078, 0.23806785924300072, 0.22300163704541423, 0.11068539453610299, 0.14324816094050485, 0.1772429142147303, 0.13210161228574094, 0.19837888167990794, 0.3409642233483253, 0.19056409537311525, 0.128446361650863, 0.19357783930195918, 0.19409778317616833, 0.19259099548141803], [0.046906747720054084, 0.030145806883792245, 0.006376983393208996, 0.0230537383486667, 0.019348000604358893, 0.029266236440068292, 0.08287696212890648, 0.030965844634920362, 0.08588571116448411, 0.02239984017045748, 0.055705240717337984, 0.07588699970754885, 0.052976224856871756, 0.02302513262557407, 0.10535391287938242, 0.05458000311327558, 0.024429525008365035, 0.012159653011739496, 0.01380099064385098, 0.07084329897958426, 0.07417149135782834, 0.09494566613988531, 0.12815183148749415, 0.09737576598361616, 8.496034222264445, 60.75123817689958, 30.889677078493182, 35.74205298577586, 23.369132395713564, 50.006348317669286, 67.20772620170348, 63.646406281378965, 1.7424137866304767, 1.208061085593316, 0.402207896714249, 0.1394393096768087, 0.3105303999637404, 35.455363027511105, 72.47275506296467, 63.17708684552101, 68.00525388410016, 62.686504240958925, 71.30875249062815, 69.76080479160433, 68.3546821532711, 63.02309067018571, 68.13865369366061, 66.92020077859202, 69.3845396657144, 66.02718691672048, 67.31887832764657, 67.54562270256781, 58.53574229824928, 54.37291122251942, 53.38974560460737, 49.26010954764582, 47.348514987576394, 47.41226134761688, 48.70709849942116, 47.638487969675374, 45.63341940602949, 47.306937863749845, 46.9887787295926, 47.647003435319476, 50.05103980341266, 49.262631631666615, 47.82160382116995, 46.65209424111151, 46.18280226184476, 44.23117991416685, 44.2418566057759, 46.03106929409889, 42.58323923234017, 45.13234446125646, 43.32497904377599, 45.43746563696092, 50.26364795623287, 58.68746349888464, 58.68318419302664, 61.8847050974446, 55.896857938458844, 51.287190452698745, 47.483609261051306, 45.05438343171151, 48.62332451728083, 59.47884090485112, 61.32368849169824, 67.14441914712229, 59.48961565571447, 64.50480914884999, 55.5820720426498, 39.505594622704294, 37.70775664237238, 46.46023934887302, 71.01308422703897, 62.337534889098144, 64.72730951924478, 59.021873012665786, 63.8717778267399, 57.35796828423777, 61.16188287734986, 46.476642700933645, 45.76331653902608, 44.45148767963533, 41.25532865524292, 42.28063229591616, 43.77079171519126, 40.43899713024017, 43.38391265561504, 41.81211694594353, 43.09902306525938, 41.1596110559279, 41.049137500024614, 41.25051590704149, 41.49794686225153, 42.58891882434968, 44.82874124280868, 40.51606778175601, 43.945776493318625, 42.86688150898103, 44.06975084735502, 42.83897776757517, 42.847297114710656, 43.06831875155049, 41.57433894372756, 41.249449022354625, 43.441547962927054, 41.04188111520583, 46.64363761102, 52.472244385750066, 52.94794944024856, 50.339055522795654, 50.20874654093097, 49.55887648367113, 52.032244666930175, 54.728536836562625, 59.42993679354268, 56.69433070767311, 55.488531358780406, 60.132923587676025, 54.4644554199711, 51.547125924018125, 58.61705695429156, 61.86251624937981, 63.5588276001715, 0.3847011635380407, 0.3979600923916986, 2.9218836128711705, 2.5172872072265995, 0.9491437144817846, 28.899164430556763, 63.75028241065241, 30.114622615998794, 25.236082538481682, 26.624005379215365, 46.245948499248875, 19.04170886162789, 0.12040841393172742, 0.012721157155840868, 0.10242307498570412, 0.10245958673617533, 0.005929522449150682, 0.0668964599589667, 0.04919206077653555, 0.0510036135693231, 0.055293491440674955, 0.045913476421828234, 0.04567402798021513, 0.05754441864067509, 0.046486387615122145, 0.05613192870852448, 0.059212418047771345, 0.05290013700423222, 0.027734905203443863, 0.015321255740409177, 0.029711013682366862, 0.06679375821183767, 0.03319933184332425, 0.027328089533013203, 0.05853466772203965, 0.055522720269378156, 0.015655511393091612, 0.07488599092128777, 0.05441175871378472, 0.061901735232001355, 0.10838428857706248, 0.13610359431514818, 0.14302317623890218, 0.18275825697327816, 0.0228531458865731, 0.20572643096168197, 0.056811406562525424, 0.06831981301788362, 0.02180455920977458, 0.02903195717672427, 0.0807497657895569, 0.1646468046331598, 0.13587534607898805, 0.17732179062741418, 0.04907367720959648, 13.239451589122897, 73.07883970199093, 28.564521535750362, 44.76566560806767, 33.05877131800498, 58.12018679034326, 75.6302708964194, 65.7975870563138, 2.8827594412911326, 2.3048847336922926, 1.4181442126151056, 0.5239090227311658, 1.1010210744796263, 41.67472024117747, 76.106046553581, 63.36734925546954, 68.48346925550892, 63.79830791104225, 71.95395100501277, 71.384548371838, 70.13627759871945, 64.45659537469187, 70.4660391038464, 68.48532061423025, 70.11952123334332, 67.65759068150675, 67.7412626820226, 68.98625435367708, 60.35489443809756, 57.78739329307311, 56.4951527503229, 52.50115617629021, 49.506175518035896, 49.252288341522224, 50.66811492366176, 49.68205851893271, 48.41092032770957, 50.28677425076885, 48.373002775253795, 49.354677892500355, 51.86847002275529, 51.15140976444368, 50.15444132589525, 48.0586483401637, 49.073349814261164, 47.939012127537886, 47.99585903844526, 47.2439367540421, 44.62607237600511, 46.7301494075406, 44.94663984544816, 47.04109530295096, 51.8466498774867, 57.77363361850862, 59.772649964978626, 61.62338110708422, 56.75651596438501, 51.48758434480237, 48.59052173552975, 47.41747809994606, 51.43198082523962, 61.84815645217896, 60.762601283288774, 68.64718898650139, 62.997677633839274, 64.0646093891513, 59.319980990502145, 43.750811161533484, 41.56709040364912, 52.34745025634766, 72.15226604092506, 64.53740404498193, 66.14521103520548, 60.641156858013524, 64.34347814129245, 59.28741355096141, 59.12215625086139, 49.80240468055972, 47.91008464751705, 46.71546405361545, 44.30472435489778, 44.308278022273896, 45.47897215812437, 44.185111676493, 46.703077208611276, 44.98427106488136, 44.64561362420359, 42.990604831326394, 42.75214433670045, 43.17990233821254, 43.604530288327126, 44.33508350003151, 45.69188233344786, 41.94846637787358, 43.73213283477291, 44.63828663672171, 43.96648268545828, 44.732819680244695, 46.04579387172576, 44.224103958376, 42.15273949407762, 43.06939740334788, 46.317190508688654, 43.07229211253505, 49.121826387220814, 53.412287465987674, 55.811291433149776, 52.66208317971999, 53.49923856796757, 52.45849255592593, 55.86350210251347, 56.38191000107796, 63.10909255858391, 59.87266255963234, 59.51499731309953, 64.08544109713647, 56.43561117110714, 55.9248048259366, 62.35997476885396, 64.74495626265004, 66.5417391254056, 0.6864447495149029, 1.2788146373725708, 8.952745199203491, 5.106410662974081, 0.652939128058572, 32.56575292156589, 71.81789182847547, 36.541737971767304, 33.00834924943986, 28.39650877060429, 53.492943163841005, 22.52324777264749, 0.10364619564385184, 0.0665352571635477, 0.08538479691431408, 0.04190041676103588, 0.07457774012319504, 0.020598342281676108, 0.05378377345961429, 0.014856842707001395, 0.05776538521111493, 0.040372741679030086, 0.07940725798928931, 0.035434845354287856, 0.06081099839760892, 0.04478566476234025, 0.05115264831411262, 0.07829291415551017, 0.031165870191949992, 0.020521337038747246, 0.051755988519758954, 0.16769537491904152, 0.11815624566928995, 0.1467011950068897, 0.1286252431811825, 0.17464533988987246, 0.24443164437768922, 0.22161949185594437, 0.12263242080206833, 0.18480623982125716, 0.190034146390615, 0.30004783503470883, 0.31341285174412115, 0.20832182959683482, 0.14186243045954935, 0.24067211385455825, 0.20376725302588558, 0.10794347392455225, 0.09685856470417592, 0.08901791526905953, 0.1998839073724324, 0.2972552300460877, 0.2826748301665629, 0.2260116118216707, 0.2135232601675295, 17.120906537578954, 86.19577900055917, 44.46706733395977, 53.697271193227465, 35.94861676616054, 64.20239048619425, 80.5901393582744, 75.90218528624504, 3.1297932565212254, 3.6068076472128596, 0.8433976565157214, 0.7183995025773203, 1.1751662507172556, 42.06276424469487, 77.02790552569975, 60.69076307358281, 70.70426033389184, 67.65278970041584, 75.3455303561303, 74.8247729578326, 72.04929597916143, 65.30808702591928, 73.38936590379285, 71.15472885870165, 74.03586664507466, 68.5007276842671, 72.54483253725114, 70.22264818991385, 63.03982742371098, 61.570315361022956, 60.09278597370271, 53.879528045654304, 53.88907509465372, 52.44197937750047, 53.08866447018039, 52.61108060036936, 48.93328197540776, 52.89996316356044, 52.06001112538, 51.66437733557917, 54.370283234503965, 53.00174474716187, 52.53839908107635, 50.80278950352823, 51.073417355937345, 50.536488025419175, 51.9390687634868, 50.38317434249386, 48.16263821817214, 48.211322676750925, 48.28412186714911, 49.70658902199038, 55.89661082913799, 63.11058698161956, 64.63461214496245, 65.12942698694044, 59.962112211412006, 54.8870555047066, 52.76808131125666, 48.70245049076696, 51.26305610902848, 62.89844166847968, 63.995163825250444, 70.00602353003718, 66.07209021045317, 66.87971407367338, 59.61425681268016, 34.57089601024505, 40.79523463403025, 48.839298063708895, 74.12819139419064, 67.73721479600476, 69.30113438637026, 62.3375976470209, 65.53880083945491, 59.7309983161188, 62.85856685330791, 49.30023931687879, 50.16680463667839, 48.52418268880537, 46.02273817985289, 47.027837691768525, 48.72708297544911, 45.64753209390948, 49.96356702619984, 46.891449036136756, 47.31559453472015, 44.31738184344384, 45.044330396959865, 45.3524168845146, 44.41206393703338, 46.6522236793272, 48.346977849160474, 45.05359503530687, 46.76256387464462, 46.66677175029632, 48.26329408153411, 47.49882413494972, 49.38113035694246, 45.633552766615345, 45.41963846452775, 45.696040045830514, 48.89245402428412, 45.169050001329, 51.76749252503919, 56.05572177517799, 57.97127008438111, 54.07235176332536, 56.69100061539681, 55.83470013833816, 58.33810975474697, 58.99107456207276, 66.26296843251875, 60.41594220745949, 63.389534181164166, 66.41182238055815, 61.09782665006576, 59.058939410794174, 64.2152205590279, 63.680511290027255, 68.9941147835024, 0.9808277627152782, 2.282005548477173, 8.832977587176908, 8.927521417217871, 3.352802554445882, 35.57902751430389, 79.14420466269218, 42.5594892809468, 39.09553435540969, 39.89629014845818, 62.24836372560071, 34.58442818733954, 0.21598267819612257, 0.09694096512131153, 0.15351010786910213, 0.19354776269005192, 0.1344150599212416, 0.16677446062526396, 0.12206967559552963, 0.11786599027653856, 0.2174917947981627, 0.2037097198227721, 0.12250548003301506, 0.14890564365252373, 0.18065560609102252, 0.21484764232750864, 0.18522178123314537, 0.12596741604108003, 0.15127460201901777, 0.14519166471737047, 0.1407018532195399], [0.12155999729950583, 0.04016806596830007, 0.09199525469974165, 0.02806621524805744, 0.034507112877984206, 0.03993158994783317, 0.11003448027035884, 0.014936186433319124, 0.04694198776457099, 0.013596916312141525, 0.10842492954144556, 0.05295647894062343, 0.1917390750661012, 0.009425715036359767, 0.04861656403649719, 0.016386703054811207, 0.08569285619042574, 0.04023488798749544, 0.026140881161535942, 0.1811913620199888, 0.04469094948182183, 0.09608680772925578, 0.022551902877767722, 0.06527209308959785, 0.3327446515041013, 36.20537904001052, 57.58447339457851, 31.364087750834805, 23.836508297151138, 32.23003725851736, 53.98497312299667, 58.24283146089124, 11.475171446800234, 4.237687058987157, 1.1889492143546383, 0.4416792286980537, 0.3954617570965521, 1.568922941242495, 45.124593857795965, 64.21661300043907, 70.87944907526817, 65.79534346057524, 73.2263365099507, 69.29779252698346, 73.11053245298325, 70.76719868567683, 69.46684668141027, 67.57638977419946, 69.21477948465656, 65.50484488087316, 62.05885441072526, 53.22986195164343, 50.38729283117479, 47.37911339729063, 46.80649442057456, 47.78958159108316, 50.00030002286358, 50.442209935957386, 49.77960002037787, 49.03756210880895, 48.7994271709073, 45.66165654889999, 47.370495950022054, 47.063954876315215, 46.930457007500436, 47.945236929001354, 51.28461345549553, 50.12737697170627, 48.6651252162072, 47.30777332859655, 47.4164229823697, 46.38638896326865, 44.77866042044855, 47.56695178247268, 42.904293075684585, 47.07024243570144, 53.68388806619952, 60.87499287820632, 59.473871261842795, 62.35853133663055, 59.52966697754399, 62.441312959117276, 56.32430607272733, 54.743155510194846, 45.6278927864567, 47.6185074160176, 51.03063214209772, 59.37172489781534, 55.106567029030096, 71.51467692467475, 55.58203674131825, 59.764471823169345, 28.232204606456143, 32.1688247496082, 70.70566454241353, 57.18176757135699, 66.9441193919028, 58.94017396434661, 59.71506172610868, 61.077551918645064, 56.32291363131616, 41.86038171091388, 42.66586788239018, 43.05306857632053, 46.96848438632104, 44.68672398597964, 42.67001775003249, 39.73296265448294, 42.25471719618767, 39.99656946428361, 42.49148714926935, 40.085242486769154, 44.5686645661631, 42.39975075567923, 41.426838213397616, 43.06183115128548, 43.15715651358328, 42.32786939990136, 44.415319504276404, 43.06759311306862, 44.8829052525182, 43.007074863679954, 43.30486905190253, 43.69170496540685, 44.23875401096959, 41.88746567695372, 41.74840980960477, 44.31636202719904, 45.6147999148215, 48.64282261940741, 48.751052579572125, 51.83417674033873, 50.390273832505756, 49.62721201681322, 48.868947259841434, 57.80201196670533, 57.54623813013877, 63.93846988677979, 61.621984743302875, 59.27603083272135, 58.707212632702245, 58.592538218344416, 60.01612717105497, 67.74225111930602, 57.79582638894358, 0.6936801128810453, 0.6138456612825394, 5.2730128457469325, 4.242129633503576, 0.449668545155756, 45.016677687245036, 53.860751659639426, 28.03230493299423, 29.675175951373195, 31.036709085587535, 48.900326221219956, 3.2605344345492706, 0.49232946889054396, 0.07604154262451396, 0.15933787660493007, 0.038331504235224384, 0.046461125865819, 0.04558085636686414, 0.03495253554935898, 0.030777873471379284, 0.150066941015182, 0.0557331454699799, 0.010056579823515589, 0.022541493658096563, 0.04408562510845162, 0.06964840100056703, 0.019284419137083234, 0.05545721975185218, 0.04683385828449842, 0.04201500053187052, 0.1112430759014622, 0.070547052779265, 0.028112059864666195, 0.046824006393792174, 0.07661709682114663, 0.025860508303007772, 0.018533310146942254, 0.06369569864604743, 0.05768613341534811, 0.04523832696459947, 0.004488073435852364, 0.21342302522351667, 0.16044156415568245, 0.05419785164356713, 0.0425983420122535, 0.019022918854569717, 0.08181885680964879, 0.14169612809294654, 0.05405224514223876, 0.045621604583556616, 0.039917643317171646, 0.059071235704205693, 0.07747942837135446, 0.04921502043162623, 0.0929225734885662, 0.4956969769010621, 49.03372603078043, 56.94047120309646, 35.49772462537212, 33.87863297616282, 40.509156565512384, 64.22666995756089, 67.74445549134286, 12.264116983259878, 4.403429262099728, 3.304355399262521, 0.8593630514317944, 1.0390488514977119, 2.2289439699342175, 53.87898675857052, 65.65444800161546, 73.97556412604548, 66.79880342175885, 76.88115396807271, 70.26045983837497, 76.43504711889452, 74.59387087052869, 72.63889097398328, 69.04341113182807, 70.96484691865983, 66.66460344868322, 67.99691492511381, 58.42377431931035, 53.55053140271095, 50.60445877813524, 49.4109207584012, 49.229428768157966, 54.14752398767779, 52.17630547861899, 53.59820388978528, 49.4286734058011, 49.67314689390121, 48.35190042372673, 49.015259512009166, 50.12659642004198, 49.736642222250666, 51.007074386842795, 52.08403172031526, 51.51233842295986, 51.234171775079545, 49.08727815074306, 48.61924917467179, 47.264913589723655, 47.40828798663232, 50.40527689841486, 47.64639154557259, 49.47122719980056, 51.56333707994031, 62.52490258985951, 62.822426134540194, 64.27264798072078, 60.61835612020185, 64.13943644492858, 58.59985736108596, 57.77537515086513, 47.750820729040335, 51.511130332946784, 54.0641853886266, 62.84551712774462, 56.80549067835654, 71.92083051127773, 58.72257263429704, 64.00582090500863, 26.684225528470932, 27.972669216894335, 73.12621408893217, 59.49687596290343, 70.96603147445187, 61.70029878616334, 64.24710158378848, 63.72435162144323, 60.14956620431716, 44.855244698063025, 44.68238976693923, 46.00819795362411, 49.187377037540564, 46.88434954612486, 44.65245423778411, 42.060238238303896, 45.01836430641913, 41.83475686657814, 45.0367445330466, 43.37694260381883, 47.05349783743582, 45.53920799686063, 43.42423069861628, 45.672435222133515, 44.46554937670308, 45.21842871942828, 45.87860676550096, 45.845866741672644, 47.12684615965813, 44.7915179498734, 44.47320192090927, 46.275668298044515, 45.65906778458626, 45.029923531316946, 43.410188613399384, 46.89654027262042, 50.68911921593451, 49.92083280317245, 52.3096856763286, 53.06371819588446, 51.04823966180125, 50.95771920296454, 51.558822431871974, 60.74324830885857, 61.92070461088612, 66.5651870542957, 64.91619517726284, 60.62207060475504, 61.99417060421359, 61.115559685614805, 65.44441292362829, 69.69392838016634, 59.94369276108281, 0.48564915154730126, 2.70255496905696, 15.066001319116163, 4.431301624544205, 0.5805246363724432, 51.79603561278313, 61.96055589183685, 33.12341197844475, 37.8456828671117, 34.69723947586552, 56.313817654886556, 3.875753293114324, 0.4089397258095203, 0.20111154794933336, 0.04603061892632996, 0.03522288414739794, 0.07833049842907537, 0.042478296034518755, 0.043438342099468556, 0.045049773574235945, 0.02481431565097263, 0.040201210762344064, 0.004662244004242483, 0.01750628692999242, 0.05357673053719825, 0.02633346800482081, 0.0783392548140499, 0.017219965398732214, 0.026845540325607986, 0.07456712980544375, 0.02948935380235555, 0.23110985034896483, 0.08736230733413851, 0.1913618227286685, 0.17397449201633855, 0.19688117978793962, 0.14328021405925676, 0.19520389156476145, 0.168741988919435, 0.17876643326974687, 0.2585188828168377, 0.3840174760308958, 0.3337656322025484, 0.40164135937248513, 0.1454479211280423, 0.3638761971266039, 0.17108595749783903, 0.2291530626074922, 0.13614464130613113, 0.10497901243187728, 0.4324676955659544, 0.18791651082856042, 0.19705540350367948, 0.37881129571507055, 0.36574701448121383, 0.5036583771148037, 59.27914519463817, 72.3686553585914, 47.67861381653817, 38.05954617838706, 46.45887436405305, 64.48564444818805, 74.85496736341908, 15.442433145738418, 11.775797586287222, 5.514214586827063, 0.6041534845867466, 1.4570554730392273, 2.9113385658110342, 53.78743079400832, 66.37750948629072, 76.46047976709183, 68.77793727382537, 78.69784678182295, 73.51704689764208, 81.66291544514318, 78.2603769917642, 75.90774720714938, 72.6920469345585, 75.94400559702228, 71.10512656550254, 69.49358940124512, 58.328543093896684, 56.08812055280132, 52.53278224698959, 50.54592917042394, 52.22690405384187, 56.56458654711324, 54.617576906757975, 56.80853835998043, 52.380700188298384, 52.86164160697691, 50.16389031564036, 52.67713723644134, 52.20716668713478, 50.96934903052546, 51.890509820753536, 56.639252785713445, 55.46625621857182, 55.47249670951597, 50.60876554058444, 53.60530730216734, 50.64596137692852, 50.95186702666744, 53.68024810667961, 49.84459761650332, 50.24138458313481, 55.88539677281534, 64.01161032338297, 63.92560451261459, 65.89138661661457, 64.89996833185997, 68.55103600409724, 62.266202665144405, 61.9826231464263, 50.196002760241115, 52.46816904314103, 55.08384473862187, 62.60142410955122, 58.14554099113711, 76.58029248637538, 58.642187579985595, 67.5267090335969, 30.122159450284897, 32.57335643614493, 76.98643822823801, 59.14625921557027, 74.20630147380214, 63.46339241150887, 66.25912450974988, 64.53135182780605, 62.81990797288957, 46.290624295511556, 46.904337944522986, 48.050634937901656, 54.787176270638746, 49.58969454611502, 48.90354648713143, 44.340351243172925, 48.24883622507895, 45.58089494705201, 46.70975308264456, 45.75177300360895, 50.11121680659633, 47.060671852480986, 44.04357294882498, 46.34160334064115, 46.95682317979875, 47.09473763742755, 49.603344394314675, 48.786138180763494, 50.551871561235004, 46.690509934579175, 46.76808264947707, 49.892532902379195, 49.332230168004195, 46.99639989483742, 46.15647531324818, 50.68990761233915, 52.67501131180794, 50.324672191373764, 54.48975470758254, 55.74756860733033, 54.79962587356568, 55.32939687851937, 53.77875451118716, 64.21103539005404, 64.88275304917367, 69.12326274379608, 66.82401641722649, 63.79675073008384, 65.57312550083284, 64.07058315892374, 68.752685054656, 75.33673640220397, 60.51881813233899, 1.3523753804545249, 2.441718823486759, 14.777561983754559, 12.459025440677522, 0.9567118051552004, 56.763572308325, 65.33539064468877, 36.64886182354343, 47.34443572259719, 46.43208065340596, 67.58144963172175, 8.15419573937693, 0.7429607104389899, 0.49779388212388564, 0.2212522599485613, 0.21926228527820882, 0.19982030675295862, 0.14969310542989164, 0.09740216537348687, 0.14586701718789918, 0.15610561375656437, 0.1344258924044909, 0.10089780925022018, 0.17988363461148354, 0.14499117950758628, 0.1325088033392545, 0.21743939438414192, 0.09405162621049151, 0.1014358940864763, 0.18218542238877666, 0.20152241622488345], [0.07681885373688514, 0.03843113013933744, 0.0392205186278349, 0.03217734756969637, 0.06452425337967373, 0.07638963765554851, 0.045497406409272266, 0.060032856079839894, 0.046707584011939265, 0.0573264321522607, 0.13178529458180552, 0.021103274663008993, 0.06055859540919624, 0.0801457897309334, 0.10779988606490436, 0.010117471364567117, 0.08012342762442366, 0.05331705354394452, 0.058910866688576445, 0.06764516534824526, 0.05260522762734083, 0.019156559062520825, 0.022968668115114974, 0.04051268679059802, 0.13143240384036495, 1.7183569097711195, 52.4405163334262, 39.66034781548285, 30.78323768031213, 33.065482493369814, 34.871039698200846, 66.7005088252406, 28.532328682561076, 1.1735561177615197, 3.0546842803878174, 0.6816434007017844, 0.49431262537837034, 0.13838823704469588, 4.516426372912623, 46.53758848867109, 71.45916754199614, 68.76858634333458, 72.39461360439178, 67.56608963012695, 69.50785113919166, 70.16691915450558, 65.1393662729571, 59.35053625414449, 57.8088015894736, 51.18611489572833, 50.56130486149942, 48.16678808581445, 47.16845074007588, 52.05305676306448, 51.67714465049006, 52.22857890590545, 54.552041945918916, 51.20560515311457, 49.874670428614465, 48.08415943576444, 49.747734685097974, 49.32410693937733, 48.413261982702444, 50.429783867251494, 46.7457212171247, 49.301439562151515, 51.708778565929784, 50.88477880724015, 49.35541529809275, 46.741426221786014, 46.28730989271595, 44.004698338047156, 42.842735398200254, 45.61445082387617, 44.4459375258415, 50.65253919170749, 58.246687150770626, 58.99182765714584, 65.43920401603945, 64.59662791221373, 62.693866529772365, 62.76614012256746, 56.84231781190442, 58.3790239980144, 54.876692602711344, 54.121295098335516, 48.79207664920438, 53.47217029140842, 53.98225884283743, 68.45207460464971, 50.94360651508455, 56.60105674497543, 53.63166955209548, 37.56668467675486, 62.36984345220751, 57.61187115023213, 65.45340691843342, 58.567650779601074, 60.019339592226096, 51.50148914706323, 46.38557311027281, 41.77008090480682, 41.62229776382446, 43.52403148528069, 44.74368856799218, 45.29532678665654, 42.67314780143, 43.31417683632144, 44.51916425458847, 40.912623328547326, 43.98083463791878, 40.95444363932456, 45.001505959418516, 42.16266701298375, 42.958743418416674, 45.11889857630576, 44.169575168240456, 43.78730881598688, 43.92975753353488, 43.32302962580035, 44.157611939214895, 43.2316658573766, 42.723589481845984, 42.957853040387555, 42.728668951219134, 42.92563076942198, 40.460091637026885, 41.04567404716246, 45.85449203368157, 44.691819144833474, 48.40129875367688, 48.93704745077318, 49.77061387031309, 50.118359442680116, 49.10965527257612, 56.46128308388495, 62.85267153093892, 61.34994091526155, 63.141671765235166, 62.07263369714061, 59.8538665617666, 64.63452977518882, 60.60757352459816, 69.41294547050231, 48.210377385539395, 0.05551947588701883, 1.736946125184336, 14.920091109891093, 5.259380157916777, 2.126478913330263, 65.54221722387499, 33.22583683075444, 22.44690864316879, 26.86227563888796, 37.50214599793957, 24.051256102900354, 0.052876606613637946, 0.018765505651132237, 0.06498326262038562, 0.027291625663037264, 0.0372177962544224, 0.06007490281556403, 0.04330715720331477, 0.035541657163130666, 0.01506419972546639, 0.003436476991121327, 0.049191218079818834, 0.027867269875001044, 0.03646955817877766, 0.028115930523903623, 0.04107038730815534, 0.06845167207141077, 0.015077436767188052, 0.09657792371487427, 0.02775142205909135, 0.11527397775001104, 0.07145095992112352, 0.061404107499026486, 0.05437641141695842, 0.07312742076934346, 0.045620597177936185, 0.0961788761759958, 0.05533677157795718, 0.043687060204965454, 0.02325545312956937, 0.02753058572359864, 0.05802197103959419, 0.07006914414946111, 0.03312974041628261, 0.07283272206663124, 0.13192355813037965, 0.023853315806557095, 0.0706634215349632, 0.037037539596278826, 0.025332384524987112, 0.033717655441573555, 0.06286455070479743, 0.057564513126928965, 0.11102752940308665, 0.14007032097828004, 0.13809922271438185, 4.911592420070402, 70.46126950171687, 33.21080630825412, 38.99232502906553, 38.36946441281227, 43.675360448898815, 73.35598653362644, 31.328729544916463, 1.4155726086708809, 3.547350398955807, 1.566935157583606, 2.586677367648771, 0.18872399814426902, 5.12022574101725, 51.93671141901324, 72.17986383745748, 71.46988345730689, 73.51445813332835, 69.7773728832122, 70.92896507632348, 74.49057917441093, 67.40041655878868, 62.49982687734789, 59.24330649837371, 55.18001341050672, 53.99427698504541, 49.60879256648403, 50.15292729100874, 54.507060204782796, 51.130248577364036, 51.81220754500359, 55.612031106025945, 54.17103859686083, 51.49928085265621, 50.93271017074586, 53.82332440345518, 50.47805255459201, 49.351947922860425, 51.004736654220096, 48.36100424489668, 50.95504414650702, 52.787379372504454, 53.157631504920225, 50.702180708608324, 49.939146349507, 51.81840488987585, 48.65878274363857, 46.910135207637666, 48.00594737452846, 46.11741635107225, 50.99114956394319, 60.27809050775344, 62.322720096957305, 67.73690885113132, 65.59164301041635, 65.13398478108068, 66.19671960030833, 61.217341269216234, 58.70305099794942, 55.81701417123118, 53.78092358189245, 49.26409859811106, 55.17357287868377, 56.850248844392844, 71.28964270314863, 56.39036663116948, 56.89741534571494, 57.413301160258634, 39.193989769104995, 62.816385684474824, 58.88983426555511, 67.65690034435642, 61.64556603277884, 61.50400377088978, 56.885922801110056, 48.05713822764736, 43.545533918565326, 43.564757454779844, 44.46298414661039, 48.648435531123994, 46.346000317604314, 45.44645570939588, 43.49688868368826, 47.644065580060406, 43.55046433787192, 46.782148268914995, 43.30179391368743, 46.920635392588956, 43.325877266545454, 43.40808622298702, 45.88047773607316, 46.566068818492276, 45.03039421573762, 45.352542400360115, 43.648017606427594, 45.70643824915732, 45.32848258172312, 46.97688610323014, 44.41199333437028, 45.49788190472511, 44.91105610324491, 43.61638761335804, 44.1834682033908, 48.5511685955909, 47.324780725663715, 53.1396552824205, 52.09508103709067, 51.949059040315696, 52.053143055208274, 51.48152820525631, 58.29603448990853, 67.66783591239684, 63.31094165002147, 65.19864897574148, 64.16940335304507, 61.637230996162664, 66.70720823349492, 63.94492218571325, 73.07511345032724, 49.911913333400605, 0.08336779466199298, 3.099184060289014, 10.566054294186255, 1.3858061091553782, 2.3494055963331655, 70.9553155591411, 39.192067807720555, 32.68176878652265, 31.201878132358676, 44.726614490632095, 29.98305651449388, 0.2553228252837735, 0.10215215565216157, 0.15142780428211536, 0.20371233984347314, 0.06099319708864055, 0.09395766552657851, 0.03214643975239127, 0.06738646511709498, 0.016200227677942287, 0.04522228891390466, 0.034284863110271194, 0.04444206666742121, 0.0427616719577101, 0.06990648836137787, 0.038858886823178306, 0.0741410393628382, 0.04365035693251318, 0.054549018687178055, 0.02272167562266752, 0.16780679474674887, 0.19770325341772652, 0.1388686048167367, 0.18532658206118693, 0.1298823628214098, 0.2199221014856331, 0.15132297281055682, 0.15613495492406432, 0.2664713657671406, 0.09003056859176967, 0.18667360978020778, 0.2338703868970756, 0.26304995581027, 0.14566933585991784, 0.13167142327274048, 0.2205444406718016, 0.06510471819990105, 0.18530110197682537, 0.153584755476444, 0.13152408924314285, 0.18132866029777836, 0.06836743304325689, 0.14882791637172624, 0.18948827810104818, 0.334027971351339, 0.23927466222836127, 8.9854803200691, 82.22979991666733, 51.84055059186874, 48.87234795478083, 47.50062450285881, 49.56484240870322, 86.87409800867881, 37.82800866711525, 5.13468457806495, 13.249692897642813, 2.83930717937408, 3.1475726250679266, 0.29874125675809, 6.59752223760851, 50.40317058563233, 75.0301561047954, 73.86605939557477, 77.4438964166949, 73.25683686041063, 76.16198739697857, 74.89361055435674, 69.25412870222523, 65.95077130102342, 62.80761526476953, 57.44018508541969, 56.43269292769894, 53.28785811701129, 52.43569574048443, 56.9282804766009, 56.95525069390574, 56.580919296510764, 58.979625163539765, 58.51650699492424, 56.50856725631222, 53.40066940553727, 56.37682660933464, 54.08178114121961, 51.829222786811094, 54.917124394447576, 50.01089826706917, 54.17626711630053, 56.36044286912488, 56.08341763096472, 52.408133245283565, 53.03464951053743, 52.64604068571522, 50.78642537516933, 47.64576788871519, 50.87230959246236, 48.14563474347515, 55.50152224879111, 63.30557584762574, 65.57762445942049, 70.05895199314241, 68.27725456606957, 67.61868076939737, 68.28913150295135, 60.49507210331579, 64.24022959124657, 58.51982139771985, 58.515632306375814, 52.25150908193281, 55.35783406226866, 58.47425914579823, 71.29946431806012, 55.98123988797588, 61.18782543366956, 53.67105799336588, 35.86290905552526, 64.27815498844271, 61.546302610828036, 69.13785396083709, 64.42658924287366, 64.91230810842207, 56.51762008666993, 49.61289928805444, 45.88869510158416, 45.67105454783286, 46.216675850652884, 49.31787037080335, 49.41178367983911, 48.63234204630698, 47.30553757759833, 50.539602387336, 43.63754095569734, 49.32687221034881, 45.64941090922202, 49.69858738683885, 45.55269702788323, 47.07314891199912, 48.6187941797318, 48.905605731471894, 48.80904090019965, 48.661053795968336, 47.320038580125384, 50.479327324898016, 47.04389195288382, 49.50221392416185, 48.24999724664996, 48.424762372047674, 49.473357046804125, 44.925757146650746, 45.69410239496539, 51.68407155621437, 49.6333779827241, 55.756597903467, 54.394652920384566, 56.403690922644834, 54.98818205248926, 54.00178440155522, 63.0334496498108, 71.09899982329338, 65.56517877886373, 69.2116415885187, 66.09735811910322, 66.23781035023352, 70.88679175223075, 67.60199500668433, 74.27099704742432, 53.17773757442352, 0.23290056555021196, 5.237091289412591, 24.525688348277924, 12.61300886830976, 2.5427254938310195, 80.18662160442722, 42.93637414132395, 34.70853197959162, 41.6970738287895, 56.11658911551199, 43.51083270965084, 0.39703376951717567, 0.21533135024289932, 0.15462868816910252, 0.3471762464652139, 0.17803838927178614, 0.28093829270332094, 0.09867986979623956, 0.15426344809032258, 0.19903575610970298, 0.11007904360491423, 0.13374283308944396, 0.24285741030208527, 0.09360233862553874, 0.1351350140307219, 0.16003687054880206, 0.1442357402054533, 0.07913632333398828, 0.22505873633969217, 0.1898385641435462, 0.27977515672964437], [0.016260618389013316, 0.045718886258621375, 0.016580601823666406, 0.0481345032101437, 0.06865254032515711, 0.04562507879229323, 0.037965233768186266, 0.03943156435965531, 0.016613466995618036, 0.059051551074991306, 0.05722233995554909, 0.0358168167933341, 0.016630748023969993, 0.08623402070013747, 0.030686232118657043, 0.023235034971167485, 0.10591485011841982, 0.09921512776805509, 0.024318392463629285, 0.0883089468604134, 0.07750460968142556, 0.06910067877822346, 0.020492068649600112, 0.037318770473282185, 0.13314534579553913, 0.05601000581537524, 26.464517885638823, 58.64519603790776, 22.588578770237586, 37.168018894810835, 30.512480389687326, 69.2796790215277, 50.776972463054044, 0.6316646825402015, 2.0601901219737146, 1.019238553220226, 1.63686525677481, 0.31200582401887067, 0.2778425620448205, 16.858335233503773, 64.27646836926861, 70.63660729315974, 73.18810909025132, 68.75359504453598, 66.5253749970467, 63.49595985104961, 58.42106396152128, 53.48101131377682, 51.23175951742357, 50.69232771473546, 50.419660229836744, 50.63905408305507, 54.7057282540106, 57.871033914627574, 61.697933596949426, 64.35253097165015, 64.43137061211371, 57.91830631994433, 47.39758383843207, 51.176210911043235, 48.10897234947451, 46.48007085246425, 48.387354727714296, 49.414933343087476, 47.947806081464215, 48.748338299412886, 47.46515450939056, 49.65801831214659, 49.60630970616495, 48.31380244224302, 46.95772532493838, 45.76530518070344, 43.77309022411224, 45.000278257554584, 45.815162427963756, 53.85698226190383, 61.1069030146445, 62.03920725853213, 63.94642445348925, 62.15110071243779, 61.80215881716821, 65.03351719148698, 62.15783542202365, 62.981199756745376, 59.63647311733615, 58.66159938996839, 57.26353329996909, 58.31388127419257, 59.97986485881191, 63.63863998843778, 56.90741738965435, 50.79043403748543, 58.91521592294016, 60.41458114500969, 63.796162374557994, 62.266630203493186, 60.855945848649554, 59.71643847803916, 55.785603830891276, 47.63292212640086, 46.341524893237704, 44.761915822182935, 44.344399129190755, 45.37855948171308, 45.123593653402025, 43.81050571318596, 42.67586992632958, 42.19568552509431, 42.78401359435051, 41.64316869551136, 42.70701746786795, 43.93806511355985, 45.4624629020691, 44.34863921134703, 42.93669185330791, 44.17265422882573, 48.10808589381557, 49.386727579178356, 51.78133849174746, 55.35189559382778, 53.79670719946585, 48.52455923634191, 42.52424286257836, 43.73844785075034, 41.51146334986533, 44.9809213607542, 42.03430352672454, 43.17213212290118, 41.633613801771595, 47.00626073345062, 42.8363811585211, 47.138801543943345, 45.27023538466423, 49.13336992263795, 49.34170269197034, 56.42172598069715, 56.96078908058905, 61.31085057412425, 58.485586950855875, 64.62048768997192, 57.90853569584509, 67.06604234633907, 57.79502230305826, 76.58701542885073, 21.735375004429972, 0.38319527982704105, 3.266622688501112, 19.66798193993107, 1.7311981368449427, 11.892810713860298, 60.797098528954294, 14.356550458938846, 34.15570136039488, 24.55691041484956, 35.943976602246686, 5.1264833923309086, 0.24853352427242265, 0.07586747978723819, 0.039273171850870696, 0.10795144889984401, 0.007853472310553996, 0.05516512957852214, 0.06591639601655545, 0.04570121261020822, 0.03028072262813728, 0.01692731981165707, 0.07467218344250033, 0.08039020242229586, 0.06074334134257609, 0.04513000979298546, 0.04055365717278854, 0.054217256650689154, 0.022397497856628992, 0.06283044063996884, 0.11189572152591522, 0.12028519634998615, 0.02548181188983783, 0.029657747588991642, 0.012082076075697138, 0.12546274796008103, 0.027856542728841308, 0.04489711523356457, 0.006820409926736067, 0.026550577322561896, 0.02394187557060392, 0.035289120109331225, 0.030628503563122886, 0.010998444706802408, 0.04791087448416699, 0.016053351385879423, 0.023296187939723174, 0.03419350329486113, 0.03840869525447488, 0.05607933677252262, 0.02697446909282477, 0.08679599215787265, 0.08346385442681852, 0.05086158469860112, 0.030567467422975652, 0.04300693117622887, 0.08981835457586473, 0.02579565512977781, 39.96817150423604, 63.10968483647993, 27.756458367070845, 48.513796252589074, 32.69339273052831, 77.92965058357485, 54.28341842466786, 0.8586934292989393, 0.5349734774039638, 5.741179595070501, 3.0930136817116893, 1.3728548105685943, 0.5394267158642893, 19.473116628585323, 70.24407217579504, 74.79624948193951, 75.54317074437296, 71.69820462503742, 67.63110683810326, 67.0010486725838, 60.67307710647584, 57.024641344624186, 52.777997063052275, 53.12462083755001, 51.99023216001449, 53.06920166938536, 57.1675842808139, 60.990620428516024, 65.17764468346873, 67.82924928972798, 64.52623705710134, 57.72570225500292, 50.82711212096676, 54.08976708689044, 51.03382495141799, 48.35963926007671, 51.10959729840679, 51.935444493447584, 50.09634710127308, 51.48881989140665, 51.4638618500002, 52.099085777036606, 51.29900855402793, 50.39543959402269, 49.58050051043111, 48.48025214287543, 47.58481817860758, 47.896705442859286, 47.564661118292044, 54.434445365782715, 63.398328135090495, 64.26587796980336, 64.62355498344668, 64.7360211033975, 62.66164818117696, 64.70894105972783, 65.01227755700388, 64.08084407929452, 62.21519224105343, 61.75749871038622, 60.789751929621545, 59.0226927880318, 60.964501365538574, 65.92554261607509, 56.60276689837056, 53.9709428048903, 64.33264455487652, 68.86091109245055, 65.35433569262105, 66.06361789088096, 60.958135358748905, 62.19939293399934, 59.615625719870295, 50.840863950790904, 48.43365046285814, 47.470673284223004, 47.70171657685311, 46.83848919407014, 47.51333690458729, 47.24645099332256, 45.658867743707475, 44.583063587065666, 44.2825904200154, 43.844210640076675, 45.149316556992076, 47.18688980225594, 46.62442976428617, 46.230062900050996, 44.3142282578253, 45.27624445576822, 48.83251628568096, 51.49271872735793, 54.183923582876886, 56.4834915438006, 54.120239980759166, 49.782302533426595, 44.07052747664913, 45.796201690550774, 43.64189478658861, 45.871648480815274, 44.82068077210457, 45.5844093907264, 46.01403444044052, 49.45857363362467, 44.41568428470243, 50.93079605410176, 49.3155247934403, 51.81866376630722, 51.13859930346089, 59.665702619860255, 58.43109346205189, 62.313588819196156, 63.224072917815185, 66.38855488069596, 61.56263928259573, 68.74492660645517, 59.97818608437816, 77.26119241406842, 22.427355627859793, 0.43740222110382976, 2.5930691149926957, 6.804818520622869, 2.3531556273660352, 14.573332994214951, 71.2872108336418, 20.928927852261452, 39.33094716841175, 27.918120814907937, 47.06306842065627, 8.029266288203578, 0.3912779977244716, 0.06203484683928471, 0.0667468736308717, 0.04805592174131063, 0.028110125492657387, 0.05200083405079861, 0.08809726144517623, 0.01295603396776583, 0.045556873984394536, 0.008992715438287105, 0.02486090911852737, 0.05806295291310357, 0.02565777079472619, 0.0162787995706763, 0.05148443333323925, 0.06483819621104388, 0.026420346205873836, 0.07320982884735831, 0.08174431645461629, 0.054587399692184506, 0.09416693776485421, 0.10172948196169831, 0.12222566641867162, 0.16955702986207702, 0.13129502895378298, 0.20245126718955658, 0.12038941495120527, 0.11505633217072296, 0.13767533094411896, 0.21817068659490158, 0.13619491199572242, 0.14394923864353087, 0.24851469383124383, 0.10995959517576041, 0.14047484604581711, 0.07733024806985933, 0.19242913642477608, 0.2115046950958429, 0.10757394375339632, 0.17093218832967744, 0.20776270798617796, 0.12560845788327918, 0.0577534074264188, 0.08677392882565338, 0.2814243908130354, 0.1840908056305301, 52.99312337752312, 78.65425355972783, 40.625858845249304, 54.39724560706846, 42.99964981694376, 82.59471370327859, 67.81596814432453, 1.194968213958125, 7.395021973117706, 4.188671160128809, 5.727410114580586, 1.6401600477195557, 0.48668542336071696, 21.18260714315599, 70.64362833576818, 76.79447743200487, 78.79425864065848, 75.04773616790771, 70.25044994969522, 70.41658586071384, 62.918590884054865, 57.910559638854004, 56.41379494820872, 57.506767319094756, 54.94966829976728, 56.09608688662129, 61.42626239407448, 64.46485196390461, 69.6104524981591, 70.46436032941266, 69.81562383713262, 63.37782198382963, 51.854694658710116, 56.23679407181279, 54.03279073776738, 50.56223446323026, 53.99312380821475, 53.822120235812285, 51.61295898499028, 54.328690421196725, 52.421614431565814, 53.91066382008215, 53.90066177614274, 52.75498843962147, 52.86816843094365, 51.38292374149446, 50.66500056174494, 50.609918717415106, 51.5446352189587, 57.04436694422076, 64.93977646673879, 66.30340022425499, 65.91801951008459, 65.38548715652959, 64.91948212346723, 67.5987002157396, 68.85269764930972, 68.26623270588537, 64.60738305122622, 63.422662519639545, 63.743532011585856, 62.09758781617688, 66.56304544018161, 68.2704374867101, 60.39711483063237, 58.081849544279045, 60.580164001834014, 70.61007638131419, 67.5430731619558, 68.2644990182692, 64.02122405267531, 63.96873097265921, 62.207747582466375, 53.35245170900899, 50.24043929192328, 50.85883232855028, 49.35781971100838, 50.98674866460985, 51.34433938610939, 49.15684138574908, 48.08627751565749, 46.41288065141248, 47.06772427405081, 46.122115350538685, 45.56074965384699, 49.830116225827126, 49.13731974940146, 49.27923502460603, 45.73615804795296, 49.19395877468971, 52.41310288829189, 53.682405410274384, 56.00437010488203, 60.44326543807984, 59.02252804848456, 52.81454178594774, 46.17457312922324, 48.98649677153557, 45.988095806490996, 49.27732483033211, 47.1559383792262, 48.90632352521343, 47.225176057507916, 53.19298774965348, 47.854383068699995, 53.657941587509654, 50.83586685119137, 54.340743864736254, 56.1504077911377, 63.33382867997693, 60.84994854465608, 66.72955789873677, 64.1710703603683, 69.36877958236202, 63.741143288150916, 70.77579652109455, 62.41541354886947, 76.79893324452063, 27.010670669617195, 0.34364430534262813, 5.7830871785840685, 34.8887845008604, 7.230354989728621, 16.010425686836243, 77.558759104821, 21.776359850360503, 52.09032712444183, 37.2481882187628, 62.04341596172702, 15.337585249254781, 0.5409777068322705, 0.37546726063855235, 0.38102311412653617, 0.18114055506885055, 0.12520590932258677, 0.11332278245038564, 0.2929015523724018, 0.07888115476816893, 0.19301793628161956, 0.139032808102427, 0.17135384312320143, 0.1673242359632446, 0.11634370462308008, 0.2026389587310053, 0.13764629621178875, 0.10879360169412629, 0.14145454992690396, 0.10334074872756198, 0.1695123362925745, 0.24066638351688463], [0.07126535213882886, 0.09172382208728984, 0.03910431458104042, 0.07763534258570402, 0.008182224100305429, 0.03074197650646731, 0.03610207729281918, 0.05591339063680461, 0.05957249469394165, 0.04431214581634249, 0.06177559885526858, 0.04160797035682105, 0.0381328844495358, 0.02452366955337986, 0.07802458419915169, 0.013355235681839049, 0.05831923996729236, 0.024240052312492363, 0.035865612763671145, 0.027649612804394097, 0.03195895505468211, 0.08152356055835563, 0.019729091042292216, 0.03643075199497323, 0.028334669693703615, 0.007244420440627203, 2.2481603968528012, 52.48343490785169, 29.41862548551252, 30.68495288971932, 34.13516383017264, 30.672595462491437, 79.89636621167584, 6.092347435412869, 0.5323748458777705, 1.6607584972535412, 0.8201694416422999, 1.7908586129065485, 0.42516476324489044, 3.2999287593749265, 58.977573763939645, 70.9977634491459, 72.23515356740644, 69.43035294932704, 66.79874066383609, 59.62381170641992, 57.02473155913815, 54.97716803704539, 56.89128075876544, 57.407680403801706, 57.94104822220341, 59.825641186006614, 63.647763421458585, 67.72689896245157, 69.0970770005257, 64.24606215569281, 67.83732937228295, 64.8437136988486, 52.94275622214041, 49.09398540373772, 47.86243569466376, 49.96210005975539, 48.80260036837671, 50.0380410686616, 48.656919617806714, 49.43224276265791, 52.54268230930452, 49.24552225297498, 49.69832066566714, 48.493752941008545, 49.44985028236143, 45.01292397899013, 43.18983770185902, 46.43590888669414, 46.723975596889375, 53.49856784266811, 60.268723887781945, 63.59817681774017, 65.68791758629584, 61.11488896031534, 64.38086225140479, 63.346109620986454, 64.18287669458698, 62.36942375859907, 62.991382229712706, 65.68357160014492, 60.82437469113258, 61.144012558844786, 63.91492389863538, 67.05357705393146, 59.19619098786385, 48.24646711349488, 62.0695742484062, 61.71253265873079, 63.54720169498075, 59.8428015555105, 60.001743839633086, 52.437284300404215, 48.17394641137893, 44.65920463685067, 44.16744532123689, 45.16097776351437, 46.49651735059677, 45.80706273355792, 46.70342237718644, 45.56279713107694, 44.096124864393666, 44.70689281340569, 43.80698342477122, 42.24289909485848, 43.05895997631935, 45.25612269678424, 43.076300774851155, 44.67722008305211, 46.990504572468424, 53.25452189291678, 57.723490038225734, 59.49774280671151, 57.637680345965975, 60.211421981934585, 58.7021331633291, 56.91343822786885, 51.076798439025886, 44.056026474122085, 44.51232364100795, 43.9567748192818, 42.46764306099185, 44.677659388511415, 43.621376868217226, 45.32662730063162, 45.264316528074204, 47.02394277818742, 46.225944411370065, 48.15831184387208, 47.59917013106808, 52.329677997096894, 56.234981936793176, 58.910501233993045, 57.49800082175963, 64.75353056384672, 64.4916025284798, 66.17868454225602, 63.945224208216516, 60.988992644894516, 0.572047597698627, 0.028874552921361984, 1.7002866729613275, 4.922484842038924, 0.8098470503764769, 33.59295106703235, 28.062469920804425, 21.64618422908168, 34.9178296519864, 23.490527791361657, 23.678319108101633, 0.45284410217596643, 0.11516624280521948, 0.0684922517487599, 0.024358131359481526, 0.06814667714699622, 0.05234000798795493, 0.10615337159364455, 0.052662462056163824, 0.03811706856433903, 0.04460983609239902, 0.049791007467936126, 0.0003364516018219518, 0.016450179184997277, 0.025514113987165115, 0.04302610635697361, 0.020050679431146672, 0.05862914934574116, 0.02550121498174004, 0.04404686105948302, 0.022994619343549978, 0.07961364207609047, 0.01758505417514713, 0.0762030186371938, 0.02907571037329974, 0.04126011281304302, 0.0014793226047561715, 0.042722743199837786, 0.006370983967151974, 0.025321772292016015, 0.03972465044728691, 0.03650360695657231, 0.02345287207243664, 0.0359820428064033, 0.06440814509386979, 0.032883270778843475, 0.0650473305534932, 0.03167122392164123, 0.02436912472119495, 0.025887036012605797, 0.018415683091828422, 0.03598879587145583, 0.03958724108674834, 0.07232534203438029, 0.03510896687305743, 0.045112600444906184, 0.07515621311481922, 0.12060198902843461, 5.426385854521106, 66.7093655370897, 28.42374767026594, 39.79543032184724, 39.49344704228063, 46.102075961328325, 87.19917620382002, 7.523888013055248, 1.0864323089199683, 3.8101553292043753, 4.379653815300235, 4.434996006950255, 0.7645196503689213, 4.036175781680692, 65.27763374390142, 73.39591626198062, 75.85214368758663, 73.2245086854504, 69.33458435919978, 63.29115721487231, 59.4673522826164, 57.445048824433364, 58.36085165700605, 58.48435532662177, 58.9432647920424, 58.84579389326034, 64.56660609091482, 69.86790903152959, 70.75649845984675, 65.23921805043375, 70.00950659475019, 64.62122117319416, 53.585271835327156, 47.634012545308764, 50.75860400353709, 52.414985625974595, 50.93623638153077, 50.49136900132703, 51.30864973991148, 50.373662594825994, 52.47598240452429, 51.190139247525124, 50.4538123069271, 51.30426060768866, 50.49131016577444, 47.45137130060504, 46.69468725881269, 50.20230600910802, 49.40047940900249, 56.95025359430621, 62.523125756171446, 64.88687938259494, 66.5688270138156, 63.72628142756801, 66.35482249721404, 65.18873322394587, 65.28573343830725, 66.48789282768004, 65.16770931982225, 64.8682128229449, 62.31194534609395, 62.89736693905246, 63.746509090546645, 68.23168446940761, 58.15928889859108, 49.65119731041693, 63.279343035913286, 61.95399376653857, 64.51953764884703, 63.720464552602465, 61.911655702898585, 57.63370306261125, 51.03005163131222, 47.66600339643417, 47.94233829744401, 46.35965801054432, 47.486268628028135, 47.24180690703854, 50.494000911712654, 49.4065708498801, 47.01639613797588, 48.942593682196836, 45.209775970828154, 45.29327146468624, 46.46062374114991, 47.94164796029368, 45.4175909872978, 45.7841560917516, 49.02431626473704, 55.28143805842246, 59.50002170378163, 59.82913994020032, 58.77453619433988, 60.41877023635372, 60.261145868609034, 59.402723389287154, 51.83307847669048, 46.422215892422585, 46.663108256555375, 47.15455378255537, 45.85225628268334, 46.11980115213702, 45.332095084651826, 47.81761869307488, 46.78561564414732, 49.24905238613006, 47.214887680545935, 52.345700879250806, 50.258721459296446, 55.38466307424731, 58.940436763148156, 61.59777979696951, 59.60059127499981, 67.77759951929893, 63.001917715995546, 67.47727147994503, 64.68009202711045, 62.324696971524155, 0.41605343441328696, 0.03586696873929712, 3.8983255528634597, 2.814791630352697, 0.3800649526378801, 36.22769732629099, 37.451288546285326, 25.874193329964918, 35.24401787788638, 27.245226444736605, 37.83159763582292, 0.749084817305688, 0.09551235669923407, 0.04130820398248973, 0.034107126881398504, 0.05622356814602691, 0.051704208636956836, 0.07726954326273934, 0.06157257023357576, 0.04978051972425273, 0.07257360048712262, 0.05228838515317729, 0.027093323803837263, 0.03153991453619975, 0.03234210243869213, 0.011430903255278546, 0.02736328169703484, 0.08847353319006582, 0.030576945845818812, 0.06475503736686322, 0.07645724491486627, 0.029142999706128915, 0.13398775139883642, 0.24475741560661027, 0.08994438370028812, 0.11687569139945893, 0.08913201640450186, 0.11746798461723713, 0.09517032142368057, 0.10400081008312204, 0.13024317491198742, 0.12783031204655287, 0.18996659275745192, 0.12126476233524662, 0.1925439883263842, 0.12392743881190978, 0.19205663383247393, 0.1876578182582894, 0.13965862532777173, 0.13516126020300773, 0.1543193112217611, 0.1431172671577623, 0.15853019010636116, 0.21764784690833863, 0.08853181715934508, 0.21966460401252394, 0.210264184241814, 0.390222420495364, 9.397798891990416, 83.63149027670585, 42.05914781939599, 51.45600142017488, 49.77587376871417, 43.45095772897044, 96.74180076968287, 8.970929307322349, 5.216271838834209, 6.936573386192323, 5.040274598906118, 6.122933097424046, 1.2395528151142983, 5.178160619351172, 66.24651801201605, 78.1226468855335, 79.90726255601453, 76.46967380277573, 72.95169215048514, 65.12217060212167, 61.76857156138267, 60.10724775252804, 61.50240736622965, 63.648387078315984, 62.220550198708814, 63.4651457109759, 66.8839894571612, 74.37036637336978, 71.30384168317242, 69.47981403719994, 72.23436124863164, 68.2527397524926, 57.40186352883616, 50.81186979047714, 52.7385772428205, 53.79188660652407, 54.486346167902795, 54.889063758234826, 54.111669601932654, 52.90485828153549, 54.36143436739522, 53.93247219824023, 54.4813726025243, 54.707003024316606, 53.56526774744834, 50.34379374596381, 48.41841989947904, 52.067781340691354, 52.08110563216671, 58.8231735844766, 65.52278187967116, 69.43024312296222, 68.15697116236534, 64.92065098977858, 69.51851214132002, 67.4327604232296, 67.2109817689465, 66.27246056833576, 67.00977986858737, 68.12850259965467, 64.06441719301286, 63.868667387193256, 68.29379127871606, 70.20713913825251, 64.27689982998756, 54.386808180039935, 64.71403621858167, 64.12251534000521, 67.142591322622, 66.01485498489873, 66.48653568760042, 58.08110821631647, 53.87467215138098, 49.31301839890019, 49.1375550916118, 49.80917861384731, 51.383268910069624, 49.35382673817296, 50.80085577503328, 50.290010206161014, 48.62653301608179, 51.52118336769843, 48.58610122434555, 46.34812624223771, 48.77710496225665, 49.93140359078684, 47.4046637165931, 48.5657205889302, 51.712963734903646, 57.47244658008699, 63.12341313208304, 62.568087885456706, 61.738581119045136, 61.9901462524168, 63.571849869143584, 63.29862540768039, 55.86048579985096, 48.804730215380275, 49.994420389975275, 49.196826027285674, 48.7846633695787, 49.18047366603729, 47.514344953721576, 50.29162622267201, 50.61121309957197, 50.89786775650517, 51.6846756012209, 54.44112908455634, 54.518737100785785, 58.76338097356982, 62.15814921163744, 63.517917279274236, 62.37359323809224, 70.37000379254742, 65.1410803487224, 70.34102532171434, 64.6473990717242, 65.36625577557471, 1.2266240701560052, 0.1191898208532122, 7.590371697179734, 14.45683663891208, 0.9983646184686692, 41.30309920157156, 39.39752547971664, 33.402112068668494, 53.16972809453165, 37.95457178546537, 55.719943354206706, 2.3017274708517137, 0.2937716750367996, 0.22300574327668837, 0.1543674368651644, 0.15403432651392876, 0.17382925706765345, 0.1684809367983572, 0.20319063396703815, 0.17056961423687397, 0.24397073523892512, 0.17926409930711795, 0.09933528865897849, 0.25127012823377887, 0.1394684056961729, 0.10692139772037346, 0.10031061817801769, 0.14069629142120962, 0.0893743529975895, 0.25923226389192766, 0.10642125721900694, 0.31315474140067256], [0.011287672584125353, 0.15011813101028243, 0.009347541509346377, 0.07312465519193681, 0.02007262785017731, 0.07929428300309567, 0.019718672246522, 0.05545498277511328, 0.018387784084845937, 0.07629195378432352, 0.0554114421679368, 0.024263169015607527, 0.03612193429181653, 0.05145703419862736, 0.01917175441649893, 0.19651817668589855, 0.06466109200470871, 0.039728676239329005, 0.025184324627081235, 0.0508096784112915, 0.09010486379866639, 0.046412119221302776, 0.032710789913131345, 0.04153409266784307, 0.08697740943922151, 0.05943655239177808, 0.05784431908039316, 19.12328043291646, 40.77635234402072, 24.24367973881383, 47.38849178437264, 19.130458370331798, 65.38550676838045, 28.277810004449663, 0.8324619046142026, 7.527725561972588, 3.8277106323549828, 1.5508487820625307, 0.43600104629032077, 0.6533605377039602, 42.92293217874343, 73.89287271807271, 69.56751823425293, 73.07402303141933, 66.258057625063, 61.80350419013732, 61.24985379557456, 65.41330068342148, 67.12501910425001, 67.01327077804073, 66.13258100325062, 68.9506313877721, 71.06216876737534, 68.7138771241711, 67.76991951850154, 70.58840920848232, 69.59922667472594, 63.23448288825251, 52.41391874128773, 49.7160929249179, 49.993027948564105, 46.796715951734974, 49.26476932341053, 48.503986404788115, 53.19178358201058, 49.457777392479684, 51.70906489895236, 50.177061634679, 49.76544810879616, 48.21513914292859, 50.54706665777391, 47.82740108428463, 45.42129762711064, 46.51714509533298, 45.047056444229625, 51.0024969808517, 58.32833520827755, 60.86090764691753, 61.70943398629466, 64.95058259656354, 63.209885704901914, 66.10999599579843, 65.13204713021555, 65.76478819693288, 61.23850245629588, 63.80004159865841, 63.05459122503958, 65.15419675457862, 64.54124012301045, 65.34263134002686, 52.07862669421781, 50.75280281805223, 64.6533767638668, 63.182695834867424, 61.60600500722086, 59.92046056255218, 57.35202981579689, 48.935427511892016, 48.12595621232064, 46.88525953600484, 50.218305357040904, 54.76673287730063, 57.922342438851636, 55.03660763463667, 51.813513694270966, 45.72988617804743, 45.222504062037316, 44.58934722408172, 45.54635063294442, 42.3804291602104, 43.64504837220715, 44.604707225676506, 46.375429861007206, 53.5667896270752, 59.7125514091984, 59.24243965456563, 61.5273654076361, 57.672122678449085, 59.666416491231615, 60.747174601401056, 61.119858603323664, 59.06105749068722, 57.35934503616826, 51.14759329826602, 45.366964955483716, 42.33438837912775, 44.688175262943396, 43.961932736058394, 46.33953625156034, 46.7384099191235, 50.128365408989694, 48.61783319903959, 48.2968460359881, 46.64164896934263, 50.69157854203255, 51.15125679200696, 53.57090027101579, 56.578620787589784, 65.60934858937418, 58.87194825756935, 64.4216392117162, 57.807938668035696, 77.1578928732103, 7.803309819390697, 0.3419963889304669, 0.11535987918896061, 2.439252878389051, 2.4431693650061086, 0.06251534867671228, 41.72945299456197, 19.352527280007642, 40.62538423845845, 46.23637007128808, 31.96722668986167, 14.562664147346252, 0.2556783513676736, 0.06362257938411447, 0.027537926761133057, 0.044761261031512296, 0.037994563444367344, 0.030249320684121023, 0.05392763711091492, 0.037559670651511806, 0.026877308076608087, 0.06846157758827172, 0.03673372061682805, 0.036243788237052585, 0.04332815184287968, 0.05212567190849974, 0.013556339507622105, 0.0061674296176211256, 0.03055078202798482, 0.024832311056313977, 0.044245147596924536, 0.08549326730351295, 0.039123597014094555, 0.005014665038024466, 0.020478702330541228, 0.05095115569870799, 0.0530836878404502, 0.029185310742186926, 0.05787881218918389, 0.024151038641350406, 0.03684164325316106, 0.05941908175666487, 0.023459477665563746, 0.021637211133155133, 0.02181280614627946, 0.02999570344634835, 0.0489936440041469, 0.09742953769502141, 0.09017810180422761, 0.05421707662002695, 0.025786004337151686, 0.025512148971639337, 0.06013312932824897, 0.07061122030380272, 0.09247637323794827, 0.040692269291368224, 0.013189452339804942, 0.06156590526863452, 0.06628078573773946, 0.10833241676370944, 35.561208186611054, 49.898330165493874, 28.529088804798743, 58.40521758602512, 20.743533103696763, 79.46981630017682, 27.561687192609234, 0.31272141142718257, 3.7198596712081664, 6.363287116250684, 3.3563628408216664, 2.0433113051037637, 1.175943983177985, 45.81321693235829, 79.712265845268, 72.03432036984351, 75.73001676990141, 66.9975342289094, 63.89696728798651, 63.44194881377682, 67.81529349665489, 69.96875316865983, 69.26065552619197, 67.96420235787669, 72.09230084573069, 71.74111535472255, 69.65919971466064, 69.7333795793595, 72.26410065927814, 70.6537009823707, 65.891920058958, 53.80713678175404, 52.011585543232584, 52.2764475114884, 49.36567229609336, 50.61991683898434, 50.65918368677939, 52.9059055543715, 51.943673626069106, 51.29776908505348, 52.74117777424475, 51.68533848178003, 51.513181732546904, 51.08757711225941, 51.19808596949424, 46.12861864028439, 48.117244628167924, 47.99434500355875, 54.707520777179354, 59.11826525965045, 63.14267981436945, 63.82777667814686, 66.17568785144438, 65.47691760524627, 67.83059858506726, 67.24691067972492, 68.13191506170458, 64.3735078073317, 66.45670214006978, 66.77239018101847, 65.62903888763921, 64.61189377692439, 65.58007594077819, 53.551468849182136, 52.00836527732111, 68.43137233488022, 66.33040966526156, 65.99711018223917, 63.74728179747059, 56.83834445091986, 53.039501482440585, 50.19553599819061, 48.390633829178356, 53.80909796684019, 55.573419294049664, 58.46259793927593, 55.41499868515999, 53.00583970162177, 47.84547928840884, 47.596196974477465, 46.105264848278416, 45.24625009106052, 43.63000216022615, 46.856845886476584, 45.548029407378166, 49.506520686611054, 53.70668095927085, 60.8530354499817, 60.329893250619214, 63.62540983384656, 60.946136828391786, 61.78902279946112, 63.30079840075586, 64.11814189726307, 60.457127094268806, 60.23480715290193, 53.2590090843939, 47.179425531818026, 45.62500592200987, 45.895680842861054, 46.86970733827161, 47.67725275408837, 49.407343556804044, 52.04806358583512, 50.785170216714185, 50.00466169849519, 49.22108588680145, 53.32763095055857, 55.02577404822073, 56.79510031977008, 57.93760830356229, 67.75971351131317, 61.59132749803605, 66.67445644255608, 58.77569329354071, 76.18963226195305, 9.295543682190681, 0.6114063147575625, 0.3642318151410549, 2.138081039151838, 1.1583178322161398, 0.03530158435985927, 47.50041661723968, 24.09185459536891, 50.668448325126406, 57.55510660909838, 39.13443250040854, 28.24558184992883, 0.41694292378041053, 0.03066901429255884, 0.025895960936923663, 0.003845978278531543, 0.07944803684949875, 0.08348214094557109, 0.048906344454735524, 0.05424710726665874, 0.08432712060429397, 0.056587471401379, 0.02390729819214152, 0.051429378424560836, 0.05345625938066552, 0.05733802306255507, 0.022833187380925785, 0.0231966118313252, 0.028693386533808325, 0.043005127039167194, 0.1130263600498438, 0.0516288370765265, 0.03423674129730752, 0.1744016013558834, 0.24558396318987494, 0.19683224209133657, 0.1905487123275957, 0.09405610782484855, 0.1679116262183074, 0.07141765807905505, 0.24601307967978142, 0.12852569771630148, 0.27387027358335836, 0.16566415407484578, 0.17954802681361476, 0.16959236183714482, 0.14871681830094707, 0.1684677447643011, 0.250845730845486, 0.18427304262595792, 0.12761233704945735, 0.11811540552204657, 0.12229436152284184, 0.23546745039282307, 0.20810596134153106, 0.15632719702778325, 0.10393824368234604, 0.13021096857565065, 0.18850190925502008, 0.13587876283113035, 47.44787646878151, 66.92145593704717, 43.02548254689863, 68.13280936210387, 30.198331879031276, 84.69006738355084, 36.8819918171052, 1.6221525688325207, 22.672315489861276, 12.282161847237619, 4.987804072518503, 1.7983082970303876, 1.6094293805860704, 48.971313276598536, 79.46956526848578, 75.68659613209387, 77.48035876981675, 71.33510297344577, 67.8407104553715, 66.52007979731407, 72.64027164828393, 74.9440679242534, 73.0994321453956, 71.48292926050001, 75.68836904341175, 77.9896471577306, 70.76746540684854, 72.34720783848917, 76.66169735693163, 75.13038050743842, 67.86914763912078, 55.72878045420493, 54.8210459370767, 55.970857374129764, 50.67983496573664, 54.815252596332186, 53.68149934276458, 57.85001001050396, 54.68310402285669, 55.080381285759714, 55.0485041833693, 54.69864837584957, 53.19204638081213, 55.66505762838549, 54.75060409115207, 49.405060737363755, 53.05543022771036, 50.32233838112124, 55.26911397134104, 60.68824883430236, 64.90001147793186, 65.19585232580862, 69.71718803528817, 68.32264423370361, 68.2503314172068, 70.10878178381151, 69.38467302630025, 65.75709642902498, 67.78720148148076, 68.01268285320651, 68.94670117285945, 67.67288792517878, 67.92792043378277, 55.767580539949485, 53.91155419811126, 69.90402621607628, 69.42854081430744, 66.98879518816548, 66.1443716479886, 60.34307633676837, 55.843760813436205, 52.458425875633, 50.189746579816266, 56.67657021553286, 60.735568308061175, 61.252564153363636, 59.38608861738636, 56.29557471121512, 50.75613291032853, 49.61541744970506, 48.34813887073148, 47.81808937749555, 47.7941668418146, 49.18647097003076, 48.9488616297322, 51.21539538906467, 57.52542211163429, 63.31643296826271, 62.133740302055116, 63.92934645375898, 62.63488584949125, 65.65510695980441, 65.80305091796383, 67.49147830470916, 62.09823892962549, 65.56689285462903, 55.80930671384258, 50.73585033416749, 47.6904123060165, 49.58661156315958, 50.5729543009112, 50.76720968369515, 52.96248966647733, 56.86096083733344, 52.33859354449857, 52.80243735159598, 50.84308793467861, 58.876294243720274, 56.982609225857644, 60.099391245072894, 61.93118126161637, 73.19681675203385, 65.4455033425362, 70.24181289057579, 58.22551811895063, 81.69329812449794, 10.525807834440663, 0.3451397396143406, 0.40615514942234565, 5.764637820182308, 7.380226302531458, 0.29192190977834886, 52.04682411686067, 30.40824144117294, 58.28063918698219, 57.14674080571821, 51.87695803180818, 42.221231922026604, 0.7815902343680783, 0.29670891742552485, 0.11710813779744411, 0.10067103956375392, 0.12538653753337362, 0.19696247703846426, 0.12102793391433456, 0.13493042258966353, 0.2815049832626697, 0.10637297069713955, 0.212051329473334, 0.10881303734476529, 0.14110136807205217, 0.1661929692472181, 0.18324846131426675, 0.09905228045799079, 0.1677664065913808, 0.12729725274708004, 0.2306433487683535, 0.15999579291430213, 0.10985760589040096], [0.03512788541434753, 0.02088716125956947, 0.05251192194860309, 0.011036028980367608, 0.06457498372201959, 0.01731624349861616, 0.03762907438701199, 0.06983128150985127, 0.045191982475620125, 0.025760870907575856, 0.07023569166419968, 0.0709744762148588, 0.0834993779238674, 0.03196992734897762, 0.08236497024735136, 0.10599530467222776, 0.0768603144153472, 0.08752627313257226, 0.023632096427102244, 0.06743841353924045, 0.0925885591535799, 0.07256909589012785, 0.060843695030217214, 0.02590062258194291, 0.03215686237860111, 0.25214124681247824, 0.1738005594140099, 7.096073627471925, 32.79648634695238, 28.688311538388653, 36.48257294008809, 41.46433999461513, 42.583992327413256, 62.28849349483367, 0.374509405585066, 0.6304168172420994, 5.413386629473779, 4.4239236462500795, 0.7998190820217134, 0.21225123245629574, 12.992864924092448, 77.97097667571038, 68.83398794358777, 76.93972279948574, 68.9029981243995, 72.64683769595239, 70.65795283163749, 73.76360708667387, 68.63208001659763, 71.33857819341844, 69.7824013617731, 73.83672006668584, 68.72064713508853, 74.29202879628828, 69.62218038497433, 69.71208895406416, 66.77541040605115, 60.91942156514814, 51.67362628444549, 49.85741592222645, 49.38848480101555, 50.90428867647725, 52.365614752615656, 53.83004342356036, 55.66693644369803, 57.98644965694797, 56.333786441433816, 51.06569813143823, 49.09467966325822, 47.96782193645355, 49.28858203272666, 47.922110634465376, 44.47869323915051, 43.73404302904683, 46.65704034989881, 50.119320423372336, 57.32751500221991, 57.774265120106364, 59.174343386004054, 60.19046868047407, 62.920234357157064, 63.966671728318744, 66.61839792805334, 64.65390628384006, 64.3132915804463, 61.920732067477324, 62.98673814342868, 63.01685410161173, 62.407258941281235, 59.33128526133876, 46.17758158714541, 62.24658296954248, 63.846847241924664, 59.759835581625666, 59.74335770453177, 54.12616668208953, 49.63821818751674, 47.892892899051795, 50.974275527461884, 56.175275618030184, 58.78004712443198, 59.329143647224676, 59.195630088929214, 61.91874734817013, 58.99295729975547, 46.546798213835686, 44.51679514300439, 45.9193641139615, 44.607845121814364, 44.22326457115912, 44.91162484691989, 42.52788674446845, 51.228468648849, 60.8311015559781, 62.08842908182452, 64.9350578554215, 60.167103121357584, 59.33573322911417, 58.99162761626705, 60.90294761042441, 59.504630488734094, 60.67967453310567, 61.57079781255415, 59.17970134365944, 52.36534018670359, 44.648939794109715, 43.81838967723232, 45.36330538411295, 44.6637624309909, 51.87617355777372, 54.32330108457997, 51.68061594809256, 52.36747395607733, 50.88649288300545, 49.413183965990626, 51.812662539943574, 54.62553147346743, 56.60297870635987, 58.800200262377345, 65.8827809364565, 60.113668672500125, 69.0429953605898, 13.59593718282638, 0.17262407818869238, 0.22729163749083398, 0.6753661375372642, 0.9506845930891653, 2.5231844907806766, 2.896660076033685, 33.19565811464864, 23.041402678335867, 49.97824061301447, 42.98908295169954, 40.007736452164195, 13.43206153761956, 0.11032696497896988, 0.023462783334957018, 0.09924071510472607, 0.05788415182201613, 0.10125574851108175, 0.07947116504393278, 0.033373712607088594, 0.1444492182664333, 0.05708868059539988, 0.03559802974303884, 0.04733659965436786, 0.04189971579058517, 0.027664356166496876, 0.01858600358959408, 0.05155567184931809, 0.05985716530572503, 0.05822874966167635, 0.008374306283170178, 0.06442903631156491, 0.03931008579750215, 0.06334291515691627, 0.028533147753126202, 0.06538725142637569, 0.056197149603958094, 0.045444695729642146, 0.09011649301335697, 0.01776465774333525, 0.0643181604062838, 0.03395698896999802, 0.03498451588975807, 0.027341612900096565, 0.03564508286334815, 0.06727394212277667, 0.01325628010465974, 0.1010420636063622, 0.021988721001112176, 0.018708008837195176, 0.0719282403588295, 0.05216700618245429, 0.05364573207653819, 0.08381663791594968, 0.02850370124853667, 0.05185545354540791, 0.02029367677506901, 0.06859326810245553, 0.032347043705803734, 0.14247061234087716, 0.07700577152953034, 7.742247341140625, 53.22279776296308, 32.98342258699479, 48.561488351514264, 47.916925261097575, 55.957803726196296, 64.07205797010853, 0.1110233542238993, 1.4732862408122709, 4.257169961929321, 4.970127421040689, 0.8711188238474631, 0.4817724402152723, 15.671867286005329, 79.06740465471822, 72.60421722166001, 79.60894277018886, 70.6949015586607, 72.14776315996724, 69.68755060626616, 76.28769151626095, 72.27806429709159, 75.23718664723059, 72.15035192428097, 73.94462447012626, 70.6725440486785, 75.78017603966498, 70.77929527528825, 72.0531948151127, 68.93793075315415, 65.2646859999626, 51.88433601010231, 53.02045837525399, 52.25596097207839, 52.859221504580596, 53.43377813216179, 54.03357521180184, 55.717625233434866, 58.09356958635392, 57.366177805008434, 53.32646992898757, 52.953107357025154, 50.57361325910015, 51.11731652290591, 51.07227986858737, 48.21386437262259, 47.425989643219985, 48.15133394733552, 54.55592117001934, 58.409763613054835, 58.73672454587875, 60.90723083865259, 62.38607029761038, 66.60123363617929, 66.72510993096137, 66.68012818982525, 65.25587635655558, 64.83117780377789, 64.19684817714077, 63.424000047868304, 64.20168445956323, 62.61458758384951, 63.77476584526801, 47.102570610661665, 63.466753882746545, 65.29136596187469, 61.719773354068884, 63.51519515437465, 57.492219248125636, 52.3362087434338, 49.878784994925226, 50.43237263156522, 56.986672801356164, 59.99688402298958, 59.94748177066926, 61.956621754554014, 63.27184346414382, 61.36318675933346, 48.729440319922666, 45.64331162360407, 47.04834776539957, 47.71506832491967, 46.61692627014653, 44.847882409249586, 45.32235976188414, 50.94840749617546, 61.45635481803649, 63.48105484439481, 62.83543663640177, 64.68140602111816, 61.5913627993676, 62.98036821426884, 63.13462718840569, 61.99456284123083, 63.79398938148253, 62.77980958261798, 62.46636513740786, 54.20666940750615, 46.939584362891416, 46.59970706509006, 46.70331647319179, 46.27806878858998, 53.13981217722739, 55.19817398440454, 54.64279382459579, 55.73959835114018, 55.17872295072002, 52.96488231228244, 55.28304230782294, 55.76957310399702, 58.827939264235965, 61.12198452795706, 71.45800652042513, 59.771386961783136, 73.20008016401722, 14.841468180379561, 0.4716172399780443, 1.011808113225045, 2.1742796128795994, 0.7125987461017025, 1.8410899562220422, 3.50655137531219, 40.82599386092156, 28.050634168809463, 57.7850555604504, 46.83587689553538, 48.380208169260335, 21.644430929614654, 0.12656210711406124, 0.021626677424196276, 0.02426694199863461, 0.03521317398295768, 0.08395923752217524, 0.09869790350597712, 0.032251627454834605, 0.0969323696148011, 0.03725816525759236, 0.007953448221087456, 0.13169382368364643, 0.07757382572538431, 0.030903904511022474, 0.02179472647126644, 0.10945362474529013, 0.03442737461638547, 0.07188771430763506, 0.02391224328969275, 0.00573248559263565, 0.02501393326618258, 0.027740668099854263, 0.1366885484106118, 0.15109303918096328, 0.13750938097796134, 0.16175848461927908, 0.2162669427813061, 0.05783316100977602, 0.12795385904610157, 0.16135887783621589, 0.21304482293705787, 0.08316288146400645, 0.13831407973362556, 0.21763390410811673, 0.2215258759115973, 0.2851749734292107, 0.13591164332484046, 0.2335429762399966, 0.24319933066445015, 0.1336119393067014, 0.09714935635847431, 0.1963982226387147, 0.14241228240632242, 0.2231123827157482, 0.21789690209252222, 0.26187192708734547, 0.08404034325071881, 0.34151265037155926, 0.2053742909864072, 11.533501994225288, 77.7019726845526, 44.092579041757894, 59.04092004222255, 52.78257839141354, 59.36575505041308, 76.09955110857564, 0.7399034067507714, 4.947275692416776, 12.091874922475508, 14.096196274603567, 1.6285687084159546, 0.6185924646354491, 16.450308715143514, 83.0462412680349, 76.59395802405574, 82.8364807559598, 75.4217420085784, 75.29477488610053, 76.59139279396304, 80.50505530449652, 72.814817120952, 77.40996791470435, 73.77814339053246, 78.62095263696487, 73.91395153537874, 77.17993659357872, 75.57611865382042, 75.01428619507821, 71.68224842317643, 67.30741716200306, 54.98179643384872, 55.81390373168453, 53.23180352487872, 55.8370457157012, 57.86480519079394, 58.7316882225775, 59.389630517651966, 63.16910089985017, 61.44085361111549, 55.932045521274695, 55.01082197312386, 54.15992259979249, 55.43880747210596, 53.57711722773891, 49.68908740628151, 49.68650648670812, 51.24700184791319, 55.23254179185437, 61.37053335866621, 62.00392553883215, 62.49919929812032, 65.47843164013278, 70.32869338989258, 67.85363858745944, 68.4913218405939, 69.70776650213426, 67.56229277580016, 65.11449452369445, 63.31532293750394, 65.75780637802617, 64.53494471888389, 60.67642288823282, 50.53485239705732, 61.03509618389992, 67.71223714274745, 61.42866680699011, 64.83042078633463, 58.07618956412039, 54.45035449920162, 53.85368747095908, 53.87577825976957, 60.49627627095869, 62.47539051117436, 61.63550907565702, 63.700550679237615, 65.54647299551195, 62.41347197563418, 50.61147982074369, 47.88607189732213, 49.46470822057417, 51.48289711244645, 50.271202441184755, 48.49178391118204, 47.08378245753627, 54.68439056027321, 64.94286729443458, 66.98440213357249, 68.65008369568856, 67.0288033639231, 63.96450265761345, 64.11543546184417, 65.62230810042351, 63.77955898161858, 67.73625773768272, 65.45354027901926, 64.87551235383557, 56.2004219332049, 50.07848070513818, 49.30955886840821, 49.47927590339415, 50.15129950738723, 57.45858492389802, 60.68085908889771, 56.38207081825503, 59.06609773635865, 56.425244346741714, 55.26913358319191, 59.37756138463175, 60.42541080905546, 61.64641718710623, 64.00781739142634, 74.21630351774155, 60.47455026257423, 72.04548343535393, 17.20469424801488, 0.4013612163403342, 0.6144756307044338, 1.5670333394119818, 9.457263984987813, 6.2758447374067, 3.963589870160626, 45.50658564413748, 38.146520814587994, 65.4311631571862, 49.43220353895619, 60.755552784089126, 31.652207413027366, 0.23092120885849002, 0.22171733660563347, 0.16243734577250096, 0.15347658386153562, 0.19532367707260195, 0.24426221637235535, 0.12505862125826459, 0.40222839722710274, 0.14798111342374357, 0.06658870711802475, 0.22543804179276192, 0.22406453807507792, 0.14537307433784008, 0.13470767486479976, 0.19860712991606808, 0.1388988806115043, 0.17576586605320055, 0.13343668903314299, 0.09723174911473068, 0.16647827571197865, 0.1993840196800809], [0.01967717326366373, 0.018066352744015957, 0.033976409298878525, 0.04970533202492422, 0.05329992764839723, 0.08699758819514707, 0.08209423477491064, 0.028352395053051656, 0.07133735674283198, 0.04334228616508265, 0.055493873228589376, 0.005368571324769649, 0.03991800720893568, 0.06407261773523304, 0.045440072389019114, 0.037817554999022715, 0.021348286818172184, 0.06806549480966023, 0.06878594687629132, 0.020809163932778665, 0.04116710207815613, 0.06255381395139041, 0.0565931634346564, 0.012681946860656384, 0.0717090166384174, 0.07156951202740593, 0.03225525488115607, 0.7127865295737021, 24.816065334504653, 44.77582846918414, 33.417409312340524, 45.38421553950156, 22.90567101970796, 70.65785869475334, 11.2392585316012, 2.080891901446927, 3.131253113669734, 2.043842541113977, 1.014984987916485, 0.21605289781526213, 0.14263967262400737, 47.4110964036757, 80.60686434468916, 72.68290781205701, 76.19749269177838, 71.8703966756021, 76.44494718120944, 74.45235959945187, 73.98427963256836, 68.13855955677649, 75.61329487831362, 72.41284478095271, 74.15852700510334, 68.99125929801696, 71.58738982292914, 64.75497007369995, 63.99352427451842, 56.83052324479627, 53.405670427506976, 49.15850054833197, 50.35618451333816, 51.52488608514109, 54.431397684158824, 59.37513343749508, 61.48502342162594, 64.49410107827956, 63.549653176338445, 60.5038974362035, 52.31842079470235, 48.48251142809468, 48.28396104997205, 47.35186861407372, 46.44859383183141, 46.224873604313025, 47.331997886780776, 46.96897860496275, 52.725123513129454, 54.89235070443923, 56.58014266721664, 54.90880504731209, 57.55816213546261, 58.21013850550498, 63.175317856573294, 62.771705965841974, 63.58123217859576, 61.542419464357444, 64.95355967552432, 61.59530870376095, 61.3818690084642, 46.19861725837954, 59.49249075305078, 69.96330107412031, 60.54931063805858, 63.801135939936486, 56.19097294345979, 53.258448185459265, 50.432604051405384, 56.52506082288681, 59.727319132897165, 63.03682288815899, 62.49231161609773, 61.76982279746764, 64.18125283333563, 60.73354828742243, 62.624554326457364, 49.705675109740234, 43.71703563197967, 45.310059209023755, 43.06012099789035, 42.41821727445049, 43.26602189771591, 45.39994032152238, 55.56916744478288, 61.09877978601764, 62.206621862226925, 60.1838477196232, 59.51946881509597, 60.34426481493058, 61.54597313173356, 60.222267335461034, 61.4669216832807, 58.64900465934508, 61.03524915633663, 59.129400868569654, 61.778644207985174, 53.815758151392785, 45.0823107073384, 44.23481595131659, 43.90351687708209, 48.78839354361258, 55.199503667892955, 56.21081621416154, 57.444872317775605, 53.35989636759604, 55.286274340844926, 52.10608328542402, 56.39538334261987, 56.87823887794249, 66.41036325885405, 56.8570698461225, 76.03687163322203, 23.279663132083034, 0.3064564669564847, 0.21113268279981232, 0.5098299507892902, 1.9274962164701956, 1.3765159754022476, 0.8453227435388874, 8.27511162527146, 23.544848695878063, 32.4160340909035, 31.229556337479625, 32.03200463325747, 48.30335717047415, 5.639013619192186, 0.1659403287715489, 0.06247621690554004, 0.025342123417724526, 0.04730327099922204, 0.014050646249445216, 0.01979446515531069, 0.02164124267085666, 0.06067452366433798, 0.020830748460045265, 0.07040862835222675, 0.07912441066676572, 0.1404000145773734, 0.04660013251967969, 0.14826629731443622, 0.03684238635844762, 0.07511006397826057, 0.021540065438696937, 0.029132257238210692, 0.08686257285937186, 0.020388424614324205, 0.04459759783780864, 0.01947067809411355, 0.047114472460722735, 0.017336209665142724, 0.06888857201462792, 0.04292825777684489, 0.06597193739106579, 0.025416414794181625, 0.013265670427391607, 0.005785741631106864, 0.0418939050136795, 0.038650782868987134, 0.010385339752951217, 0.0011023790965179704, 0.040577811925041105, 0.018940587385347294, 0.05037777336134065, 0.05581637709251335, 0.11301466954811928, 0.01597725682997055, 0.04417990371885319, 0.10594812131697133, 0.022798770880927483, 0.04330478999162874, 0.0387177849188447, 0.039154462696563815, 0.1489246426330459, 0.10591218413244333, 2.1350387507869355, 37.48149079661216, 53.88419958852953, 37.528257216176684, 49.44251937250937, 32.259229498524824, 85.62734127044679, 9.47811628541639, 0.42482207679460127, 1.931950558097132, 2.7960152443378203, 1.3666688650846484, 0.48752444285538893, 0.2802213569802623, 55.39182532218195, 81.62886927204748, 75.46258172681256, 79.55686938378119, 75.14839987601005, 78.03186755026542, 77.71899577110045, 74.32182312011719, 69.84027985603579, 77.1178533184913, 74.76672187928231, 76.27963496792701, 73.3214932103311, 72.45338639905377, 67.3572704868932, 66.04850107623686, 60.35880896352953, 56.58260983805503, 51.15457903954291, 53.11816853861655, 53.41395055094073, 59.60298784317509, 60.92091598818379, 64.65440442485195, 67.22284301634758, 65.73912412889543, 58.81133587129655, 54.454465143142215, 49.05681702398485, 48.762156809529955, 48.371308311339355, 50.477511267508234, 47.060197245690134, 49.764600876838934, 50.31257560176235, 52.97996774796517, 57.630172929456165, 60.472624378819624, 59.46469683800975, 59.776721385217485, 60.63586558065107, 67.76118047775762, 65.13159213527557, 67.07253779134443, 64.33891642478206, 66.1418221073766, 61.38725050034062, 62.35057284755092, 47.232126497453265, 58.16026556876398, 72.7114155984694, 65.68245372464581, 67.72787955499464, 59.847516244457616, 57.17926117681689, 51.991420638176706, 57.68646678616924, 62.28111943890972, 66.79873281909575, 66.28532594250095, 64.12226430831417, 64.99579183516964, 63.15804373833441, 62.993594446489894, 50.43776589055216, 46.18475952456075, 46.6604410448382, 46.255346498181744, 45.58016930857013, 45.49298678675006, 46.48740568468648, 59.12544711943596, 64.27277741893646, 63.77967665272375, 61.96583147971862, 61.94698056867046, 63.39214647969892, 65.09700467509609, 62.15128114146572, 61.48050485118743, 61.583121899635564, 62.99381802158972, 63.05345373768961, 65.35164102431267, 55.08234639321604, 45.76597198363274, 47.77936773915445, 47.156016826629646, 50.14413333708241, 56.69553879768618, 58.51806025351248, 60.328551800020286, 56.43864708562052, 57.03650259202527, 55.344666665600194, 57.51403154865388, 58.42139344061575, 69.57960697912401, 59.12307800785188, 78.56286233471286, 24.615075242134836, 0.3956642494566979, 1.1584495993391162, 1.8236811290825568, 2.457368835326164, 0.4582455123384153, 1.2333705468523888, 11.264487216549536, 30.635040729276596, 39.98214690916, 36.25742496982698, 30.73273324197339, 61.826151955512266, 7.2252255101357745, 0.07966335352149703, 0.023821387177092895, 0.05436544869876197, 0.09269401881723635, 0.05945336802171604, 0.047734501891799515, 0.07895488307000169, 0.0163213231961333, 0.009661921010833354, 0.017222211951570168, 0.06555746850227157, 0.03852736610438555, 0.028107478658878998, 0.08280314189652282, 0.06383988022383663, 0.03460911365466253, 0.03882758830103182, 0.021626978113706556, 0.14114134253994112, 0.03343926292032965, 0.02931915396343797, 0.08901901843567049, 0.18106360919773581, 0.22018333746781274, 0.28433644423081034, 0.1558105473316485, 0.2584641841390441, 0.13715080586412262, 0.17624255660320484, 0.10490749046326646, 0.18304434484772145, 0.09458871513244607, 0.10938184230678505, 0.11319542033297401, 0.10845031003437697, 0.21915630467476385, 0.09552540317658456, 0.12678578946619265, 0.2519809199316848, 0.16802508383989337, 0.2326887575609069, 0.15054111879679466, 0.07788439010900837, 0.15020774797566477, 0.16756916959439555, 0.2721212335651921, 0.12556732662262457, 0.23443404374824417, 1.5751088867264411, 54.63685535615491, 67.98073907052317, 46.771000892885276, 64.59549042486375, 35.240848602787146, 88.08625944199102, 14.09977347620072, 5.8129148425594455, 10.37998293676684, 4.946587316451534, 5.723963331791663, 0.7896557918960049, 0.7493087601277136, 53.26539470303444, 84.59890365600586, 79.9290003315095, 83.13543596575337, 79.1479544485769, 83.44789981842041, 80.33094129254742, 77.56894942252868, 72.62040092099097, 78.81176025636735, 76.56866658118464, 79.84223750329788, 74.64519116186327, 78.28435836299774, 70.30102499069707, 69.09968929906046, 63.82139890424667, 59.759427655127745, 53.50088204106977, 56.73367992524178, 56.6381545220652, 61.32479067771666, 64.77930838061918, 66.6750212638609, 71.7256376820226, 68.91419256887129, 63.38236801085934, 57.28684786827334, 52.26636309777537, 51.382268705675685, 52.75656523243074, 52.41372262277911, 50.52401881064139, 50.37288988790205, 51.51510761630151, 56.16941167462257, 59.138473310778224, 62.34432058949625, 58.98197074090282, 61.4846468740894, 62.491942913301536, 67.75722672862392, 66.27584165142429, 67.04535576605028, 66.05065837983163, 69.41586371391051, 64.01768999715006, 62.32065693024666, 51.70729198763448, 57.19880242501536, 69.33470987504529, 66.55101160849294, 67.91798899250647, 63.194662986263154, 59.501241560905214, 56.18346944932015, 61.986698489035334, 66.2580733145437, 69.38379441538166, 68.41718119959678, 65.79029537016346, 67.87302294085103, 66.14091211749663, 65.10537501304381, 52.56434555976622, 48.368633254881836, 48.72515316932432, 48.418019817721465, 47.21987301303495, 47.89399116270004, 48.909010348781464, 61.09679898908062, 67.82540536695912, 67.63640988257625, 62.837844971687566, 63.24641866068687, 65.8378384190221, 67.30049025627875, 65.70438369627922, 64.81604922202327, 65.1196877418026, 66.11343983680972, 64.84754585450696, 67.11552696843302, 58.79261832083426, 48.05755399888562, 48.969285411219445, 49.62130100496354, 52.94775332173994, 59.47356139459918, 61.43146737929314, 62.86893367767335, 60.085302091413936, 58.977820873260505, 58.88002834012432, 60.62989965561898, 63.73291807789957, 73.5099317181495, 63.92029362340128, 81.12371506229525, 28.272185325622562, 0.42998829796429605, 0.8075538734274527, 1.5041751510673955, 5.1636297087515555, 6.012877273944117, 2.186321044160474, 12.12480910362736, 36.421662453682195, 47.968857442179036, 44.72120946453464, 43.34075873897922, 71.65819644927979, 11.236694282101048, 0.5616351757799426, 0.17705056485870194, 0.1506436979698558, 0.22314017638564113, 0.196266409550463, 0.2098391739831817, 0.2627967484295368, 0.09832095760371416, 0.13577387007253786, 0.22404256667340958, 0.2095409512760178, 0.23212822634846936, 0.21324834185502223, 0.19565234411387675, 0.16885641181180555, 0.19622943814723723, 0.11830927939304423, 0.2755956261629059, 0.2601160842084116, 0.12784906587893927, 0.10416434687231818], [0.07575498743643684, 0.025957150294655756, 0.022149515195539402, 0.07687504628613111, 0.0756758735364964, 0.018408152447532744, 0.04681220097887901, 0.006892373353513259, 0.04737105062832275, 0.059889406116018375, 0.03311832570621083, 0.07250884307488319, 0.06656198597122585, 0.09598942263232124, 0.07170656515705971, 0.0620329124672759, 0.0125221093185246, 0.09043481786765399, 0.04574835383062882, 0.020235655190903815, 0.02227039429389181, 0.029489941774837436, 0.05428023673894425, 0.007854662140861394, 0.06330716566392972, 0.18882812481493721, 0.3040937905109698, 0.13616874243222898, 20.413030270607244, 43.851306207718395, 49.51394181097708, 83.59292553317162, 41.415412349085656, 33.52684344014814, 48.92085590670186, 0.410007989454654, 1.9588640236085462, 2.917798464336703, 0.2740597424487914, 0.9351969918897076, 0.09306648310514228, 2.658509203503209, 72.57567805628624, 73.97960416732296, 80.7595229917957, 75.34970375799364, 80.39976319959088, 69.61188808564218, 75.04757142836048, 72.94514179229736, 77.94357499768658, 67.81141035018429, 69.24705274643438, 68.38531586431688, 64.87205674571376, 59.31606646507018, 62.38921211611841, 57.107026807723514, 54.82883576423892, 51.19165328241164, 53.80071978415213, 57.43668240885581, 55.91051563139885, 62.815420781412435, 64.33139331879156, 67.53216112813642, 69.6143356446297, 70.00683938303303, 65.20320676988172, 51.40370838103756, 45.143954676966516, 48.06366505161409, 47.64648568245673, 48.11306730393441, 49.02847789948987, 47.46520157783262, 48.81745830658944, 52.88304990337741, 54.23671084065592, 56.95842389137515, 58.01063891380065, 62.357578200678674, 59.23197084857572, 59.48194349965742, 60.67091980288106, 63.230187892913825, 64.34683961253013, 65.66845870787098, 60.120356313643924, 68.5641759441745, 70.41060032383089, 60.921370983123786, 66.65977893337127, 59.77100649187642, 59.521543748917125, 54.86520005810646, 60.60052894776868, 62.03017011765511, 62.03970147717384, 63.31288322325676, 63.20598686895063, 63.29268693923951, 61.71803574408255, 63.55992194144957, 61.62889203717632, 50.63808525762251, 44.20654742948471, 45.923510059233635, 42.37680489017118, 44.61762359065395, 43.50644749979819, 46.206065839336766, 55.74037890280447, 60.66886840328094, 59.3053662392401, 62.02178016785653, 59.42559080739176, 61.543858974210686, 62.094465609519716, 60.22793908273021, 60.31608258524249, 62.200400983133626, 60.420954996539706, 63.119337789474, 60.8070731163025, 60.69842738489951, 54.44929938162527, 45.370938316468276, 44.7035901777206, 48.520193638340125, 57.022150639564764, 59.03389507724393, 59.34691590647544, 57.86584854125977, 54.45567715552546, 54.41586117590628, 58.119735717773445, 59.712841664591146, 60.35467478536791, 66.3157949139995, 59.7995299677695, 0.9491322538064373, 0.07076678211770712, 0.5178734756285145, 2.372382840802593, 4.010212387769453, 0.144812589090678, 0.19482123064658335, 5.423254822531055, 27.8373239117284, 34.53631639480591, 19.44559335708618, 48.41349340254261, 30.76090958810622, 0.04527830526292805, 0.12207372820064907, 0.05921590374782682, 0.06301249760473449, 0.12408970389515163, 0.029394012244959033, 0.03469123828014539, 0.017279369771600734, 0.019037685199310223, 0.06754640129304702, 0.04784820849196084, 0.009388755124452855, 0.025889137008738135, 0.09256379153098791, 0.03507166605202421, 0.014216965853026318, 0.021386918716973836, 0.049348051599677534, 0.018725155800160383, 0.04962379345670343, 0.013203314700794798, 0.07503926213229857, 0.07148927197821679, 0.006767290347676364, 0.011428894189697121, 0.009461432928219438, 0.04994365048684901, 0.05098833394567332, 0.05459553937637999, 0.03924118001915274, 0.030975874641069004, 0.04841951856149301, 0.02955496540263055, 0.07654590427034325, 0.030180621749511173, 0.057303043487932415, 0.025309558935283173, 0.055577851786849, 0.03327541586552416, 0.03604945088286073, 0.031298510655159914, 0.05821767586073088, 0.06740538748882471, 0.08242883899759862, 0.09115178423422961, 0.03710578270857373, 0.1089103994590621, 0.12178448404395774, 0.20969504220110757, 0.09253107191574189, 27.88352158761794, 62.67128936706051, 50.051275145622995, 83.25342086053665, 40.75237097278718, 53.642448225329005, 46.49783918934484, 0.29763661925831153, 1.6881998892753356, 2.003376796360939, 2.4979428129811443, 2.0371084443984495, 0.20430336135529703, 4.230351736468654, 76.94373146180185, 75.01012063795521, 82.4212900284798, 76.25268044010286, 82.5189099773284, 72.26289256926506, 77.31016712803995, 75.01042658282866, 77.75002171916347, 71.25947183178317, 73.71060017616519, 71.7878935413976, 66.61683682472476, 61.68276186912291, 65.19240848479733, 59.202957076411096, 55.16629688201412, 53.725316139959524, 56.67072980634628, 59.829136017830145, 58.409728311723285, 63.005216429310465, 65.76510198654668, 68.4604057188957, 70.2937529163976, 69.23118283671718, 64.49041405031758, 51.96744711168351, 49.496283300461315, 50.77180277916693, 49.82805305911649, 49.291598335389175, 50.39950709189139, 51.34500226666851, 49.906473005971606, 55.51201066663189, 56.98671202505789, 59.93936246441257, 60.90930185010357, 63.43051118235435, 60.89790344238282, 63.19486302714195, 65.83571249438872, 65.13016439253285, 64.90680110070014, 65.52598253373178, 62.37980235007502, 65.3950930410816, 74.10402174918883, 64.76306192336544, 67.62830626580023, 62.33868022118846, 61.50874591642811, 55.434265367446415, 61.52680450870145, 63.98167087185768, 63.08880606005269, 64.82260742495137, 65.63669535421556, 64.00339688024214, 63.663962810270256, 64.24882350429412, 66.3284327906947, 54.73101185214136, 47.85064897229595, 48.80039207396969, 45.67276077885782, 46.2647327300041, 45.103934734098374, 48.177927617103826, 57.514914081942656, 63.299845264803984, 62.495618174152995, 62.80282212841896, 61.1932030031758, 62.82023352961387, 62.37840990866385, 62.26904246114916, 62.74600659647296, 61.70639022704094, 61.53595147594329, 62.70161321086269, 64.46962156603414, 62.03965833110195, 54.493422123693655, 48.658021803825136, 47.45113988076487, 50.60145424258325, 59.51790378939722, 61.20409934751449, 60.57416669784054, 60.64775428464336, 57.41014757464009, 57.52856000777214, 60.979245555016306, 61.562403940385394, 63.026095205737704, 70.85046275969475, 62.369553196814756, 1.4792927378608336, 0.10023531173506092, 4.030591307147857, 4.306271172338917, 2.415979494971614, 0.10992166616262929, 0.36021803535761376, 10.1447368244971, 33.024764368611, 45.42920120300786, 22.894088260589108, 54.02981365880659, 39.484127490751206, 0.1337388494322377, 0.09772274252628127, 0.06833393967920734, 0.05833060105120944, 0.06525802005442881, 0.05823060742489273, 0.041926528867934985, 0.0658392662843389, 0.026273136665563912, 0.06607672289734887, 0.051475201973751675, 0.03149839257070374, 0.0236954806267374, 0.032928588710004286, 0.028912056755695133, 0.04281999040094595, 0.06289696005443413, 0.06718638593391066, 0.010123900757471641, 0.036023158745299426, 0.024331680258675933, 0.032133519679548285, 0.14228567871595585, 0.13828987135521828, 0.08116662487267487, 0.15201907094207504, 0.18838918707784147, 0.15833393370191898, 0.1417868175814229, 0.154623371518908, 0.17668727064324966, 0.18796757824959295, 0.14152958057820797, 0.13553717954745217, 0.18605142381162415, 0.19191191982357733, 0.13003565701505831, 0.1336684459519963, 0.1931667258782733, 0.18259324163438814, 0.16112961836399572, 0.1486595302459694, 0.11808472370067913, 0.190658584657696, 0.17772879781982592, 0.13595262902878946, 0.19953391244334562, 0.265275226725686, 0.4555897919401046, 0.22225784227973033, 33.221102529956454, 76.97900925913166, 59.27332047493228, 102.87339887311383, 53.23545917387932, 51.123396196673, 59.347629777846805, 0.5189767035265123, 8.410726593386743, 7.287036670792488, 6.571089385017273, 1.159955054040878, 0.27764095834666686, 5.108435096279268, 78.52297967480075, 80.32181001478627, 86.51146704150786, 78.79872229791458, 83.72191659865841, 75.07446319826188, 81.30489718529486, 76.54848990901824, 82.51380305136405, 73.61502770454653, 74.80951493786228, 74.75092257222822, 71.7306661605835, 63.66062487325361, 68.62873815721082, 63.22083304005285, 59.7951094565853, 56.52673175258022, 60.09857539207705, 62.95470414623138, 61.50714951176798, 67.27973307332685, 70.2197927044284, 72.30667406512846, 75.99115248649352, 73.47452840497418, 70.26299368950629, 56.982479787641964, 51.75804745766425, 53.91617475017425, 51.835761377888346, 52.60392619717506, 53.394456371184326, 54.205053390995154, 52.84686996090797, 59.12855363661244, 59.854235264562796, 62.696557275710575, 64.95634063597649, 65.35637140274048, 62.97805401586718, 65.90880978492, 69.76785721317415, 66.83836444731682, 68.69428880753057, 69.55068342147335, 63.38961655093778, 64.32794555541008, 65.08845390812044, 63.57700778592018, 71.20491950742661, 63.60920260029455, 64.19441238526376, 59.3160625427, 66.23787310815626, 66.84454610270839, 65.041279562058, 65.55980120935749, 65.65158467138967, 65.72932212583481, 65.00263637112033, 67.70494153422695, 67.94491214136924, 56.9146502402521, 49.9666186301939, 51.87018409852059, 48.91133239192348, 49.12390132104197, 49.82703716524186, 50.47304368788197, 60.71115155373851, 64.21338096741708, 64.24388916261735, 65.3941281380192, 64.73385203269221, 66.62548172858455, 65.51081472827543, 65.44249488461402, 65.67985711559173, 64.13072093840569, 64.34095605727165, 67.3716655854256, 67.09986886670514, 66.44061257762294, 59.50424609645721, 51.03138523717081, 51.12619284660586, 54.33813156620149, 61.21011234098866, 63.30354405987648, 64.1117758904734, 64.54762181928082, 59.8173257612413, 61.07268817963139, 65.89861162247198, 66.59350656693982, 67.38398967250701, 76.29643055700487, 63.225873285724276, 2.2355526733782987, 0.1778681798567695, 4.715305739833463, 8.58519361865136, 11.092827627735755, 2.0237864818303817, 0.8141552837144944, 11.524536436603917, 43.13626597004552, 49.157602325562515, 31.56978076504123, 64.96113377232706, 51.526768822823804, 0.41396523194928325, 0.16181352037575938, 0.17304328150085865, 0.19298139388763136, 0.25739886227153963, 0.19218945815678568, 0.14789350360872286, 0.15617080783892065, 0.12669393552407143, 0.13492682197641942, 0.2480319205431208, 0.1676249101517662, 0.10508499303532225, 0.24322632760290178, 0.1513154498271404, 0.15201229872482439, 0.10329262308415868, 0.19872994913208872, 0.12950557013673167, 0.1484323238893863, 0.11693061224275059, 0.16071213108877982], [0.038549613297706654, 0.05329731528857543, 0.025184661705767917, 0.1032487798722521, 0.05443218261784604, 0.09568360033294848, 0.05162966828192434, 0.057176926263397744, 0.04688012233424572, 0.03372166974229678, 0.04612826832359837, 0.0429212442418981, 0.03839496312843215, 0.11121597171070115, 0.11810942237535793, 0.10624160960076318, 0.0225653936861143, 0.12704143300652504, 0.023552633957156253, 0.14080060195297966, 0.038636525972716274, 0.011277525749568258, 0.12794211491822235, 0.056719004867538336, 0.04864556812531045, 0.14421179229694028, 0.18551617350068786, 0.20179210981774717, 2.074936272636537, 39.77224126938851, 73.4535986377347, 31.492076650742565, 68.87081899950581, 21.241285800933838, 45.79688026059059, 6.093394708248877, 2.2080678901364728, 0.5438874313427556, 1.6021783890262729, 0.41345017571603104, 0.2553085913701404, 0.07983234485671406, 12.916968041850676, 85.65925367416875, 68.07617818155597, 82.402446962172, 71.33720536385813, 84.96147970999442, 73.67183931412237, 78.42054305538055, 68.45604404326409, 68.47858982701456, 64.12956776157503, 61.45883767835556, 59.82731211570002, 60.98461527978221, 57.5231118356028, 56.84207070258356, 53.32028435122583, 54.315832891771876, 52.8898944393281, 59.94190808265441, 60.461551527823175, 66.05789907516973, 66.76381587982178, 66.71530400553058, 69.9056500773276, 67.92029534616779, 70.16542080909976, 56.57308632327665, 47.26925173113423, 48.70960489396126, 48.522476457780414, 48.84142791071246, 47.44928459967337, 48.55088226256832, 48.166074214443086, 49.32918640875047, 50.8979344367981, 54.67458463484242, 56.92142809590986, 60.58395301142047, 59.24612668252761, 60.06840059834143, 58.922574289383434, 63.10415429453697, 61.17499143846574, 62.7543887015312, 65.76253675645398, 66.49807530064737, 62.2711762305229, 63.44693806863601, 65.66745458110687, 64.720166883161, 56.71320123057212, 59.13855568055184, 65.63254940894343, 64.02398540127662, 66.86462079325031, 63.84136769079394, 64.53970647627308, 62.92350169151061, 67.83447388679751, 62.495567183340754, 60.06240329434795, 49.93681253925447, 46.63330608798612, 43.84583057895784, 43.6878022070854, 43.28348821209323, 42.558002702651486, 47.94120081009404, 58.90870478845412, 61.093202175632605, 61.46658828181606, 59.45949969753143, 61.03556686832059, 63.80549369319793, 61.65137506300404, 62.08267104241156, 61.023493812930205, 60.67640327638196, 62.48187811143937, 61.49817512881372, 62.87073796795261, 60.969337647961034, 58.7981370956667, 53.66534310002481, 43.499249950532, 47.01024978391586, 51.816047545402284, 58.322373205615634, 60.97215390974476, 62.01100933936335, 56.83699123321041, 58.49982515458138, 54.56034560357371, 65.82430624192762, 57.71572374528455, 69.99097731805617, 32.60816158786897, 0.07705795743893232, 0.2911070067315333, 1.5748263534999665, 4.275073130284587, 1.6624253820027075, 0.33583072945475584, 0.06361007682919022, 15.8150641956637, 39.09532254742038, 29.546979165846306, 35.770953009205485, 54.13965571311213, 5.1974577000064235, 0.10833692136070422, 0.022566793711795922, 0.06626148798292683, 0.03820811045326052, 0.0737528472898468, 0.03580029993768662, 0.04441152274188015, 0.0334730435673508, 0.07687917550004299, 0.04914324565400039, 0.03301836272341109, 0.03064773428524214, 0.04742807438296657, 0.023368140832791408, 0.033285930422284914, 0.10926714362276178, 0.04828739137719235, 0.017371645062080315, 0.01910355343903986, 0.048341392914974884, 0.0701193995172939, 0.03974246582196605, 0.10370486265709324, 0.040891038464202036, 0.08203600443178609, 0.09267935589436563, 0.08148431387399474, 0.1093330271842499, 0.10477029177690707, 0.08904698064490672, 0.008071869134812826, 0.03165892054957729, 0.014346145514038303, 0.025062011029090614, 0.012192008735221482, 0.03733502685903542, 0.11801523952594689, 0.10182354223704147, 0.022705015125534227, 0.10226105505059804, 0.08112266674757966, 0.10542817744276217, 0.012171935316385522, 0.03451682304242446, 0.11709087017563083, 0.12123332974771339, 0.07937882846641926, 0.14725066390970062, 0.2715290475997233, 0.2842626546419436, 6.882619713583301, 54.71502034894882, 71.96556122072282, 54.367568954344726, 75.46805735557311, 26.571367171502885, 63.85919486322711, 4.355285110012177, 1.4131772662362745, 0.658874961156999, 3.6719849369218274, 3.305819178781202, 1.0884471814478598, 0.12648935174389234, 17.623464138277118, 91.8855142593384, 71.87370715602752, 81.3194570233745, 72.22142527180334, 84.67518591111707, 75.80159218080583, 81.40747501004128, 72.10023972295946, 71.34355960353729, 65.01002611652498, 65.05038338322794, 62.87563308592766, 64.47348510065387, 59.95330256800498, 61.37498132644161, 55.54183244705201, 57.19562922754596, 55.38176444268996, 60.125133760513805, 62.3947387356912, 66.62396769369802, 68.80475059632333, 68.53181639025289, 72.29402049895256, 72.66479430660125, 70.26172284157046, 59.065552526904696, 49.11856689760762, 51.3564516652015, 50.09728062537409, 50.158528435614805, 51.2637895922507, 49.79135144141413, 49.69080540441698, 51.13157826085245, 54.5748701403218, 58.29922337685862, 59.165267021425315, 60.39644802770307, 61.653897147024836, 61.719024181365974, 61.85061185590683, 64.89646565529608, 64.1081908441359, 64.31701783211001, 68.03800567503899, 70.4222026948006, 62.745692806859175, 69.4674664158975, 66.83141400737148, 67.8553173618932, 59.8705562468498, 62.83355782108923, 67.78661312595491, 66.08350430765461, 69.02727450093916, 65.66212800241286, 64.03020235799974, 65.19037669704807, 68.45187848614108, 65.81649288054436, 61.750811069242424, 53.343438102353005, 47.59264722947152, 46.783752518315474, 46.459117551003736, 46.32077947739632, 44.358127424793864, 49.707863792296386, 60.10409024453933, 63.75782512849378, 62.6470491193956, 62.030534898081136, 62.568762533126346, 65.52679838672762, 63.42186235612439, 64.7335264759679, 64.17251379259172, 63.05271240972704, 63.0198900161251, 63.93930142925632, 64.0202356153919, 63.13112451184181, 60.98144992705315, 54.58183626974783, 44.73575361313359, 50.420405480169485, 55.199609571887606, 62.64988891540035, 63.76626214673443, 63.59032423265519, 60.167491436004646, 60.30333488218246, 58.10210858621905, 69.25249699623355, 61.40989042097523, 69.27374055308681, 33.87100788854784, 0.07224720872698293, 1.0512528159926016, 5.635961034605581, 4.193113244348957, 1.1544737868732022, 0.13177751112849484, 0.05976289818664232, 21.99249421396563, 46.57005394658735, 36.88024244000835, 33.312897759099165, 63.86414881675475, 7.160645156137406, 0.1966685903889518, 0.13089183687923417, 0.0913153823104597, 0.014134303050776644, 0.030403193274152376, 0.015136228269717146, 0.009967028933216729, 0.04420929085162859, 0.08819614807444234, 0.0656422361310932, 0.02580617160175837, 0.05433010523237529, 0.08463079785747875, 0.034587973458392006, 0.040545582606066624, 0.04185534397801084, 0.02113861238373624, 0.026014174049299572, 0.09670751514814555, 0.02957140756470542, 0.07104400635486649, 0.0190366069305568, 0.1675599458957872, 0.2875402852171852, 0.23449264947445164, 0.22264831729473608, 0.10893912009534337, 0.2905500914540983, 0.3015464562321863, 0.20039200752733216, 0.13172872664947666, 0.18599330838168823, 0.19525195592113082, 0.14210316592887526, 0.18315637754576822, 0.2041124062792909, 0.22196700466015648, 0.1999258430254075, 0.1224900586830993, 0.21746298989220975, 0.1385161124410168, 0.2996965377561508, 0.14447489753365517, 0.1439494531481497, 0.29661845776342577, 0.20624294276199034, 0.2657434903085232, 0.20141733960518915, 0.409545915862245, 0.4555651545524598, 5.831461279622971, 70.94305422998244, 83.38278847355997, 48.79995669088056, 84.35562256843814, 35.19636892503308, 58.686459372120524, 7.514699370630327, 4.024325811093854, 3.6904110062506894, 5.008404850959778, 4.594529098080051, 1.2717161279532219, 0.15865469471581523, 16.91151276711495, 96.51481320781093, 71.8707496889176, 84.84864096487723, 72.90802048098656, 88.62038427783598, 77.27259082178917, 84.91980844928374, 73.69567163528936, 75.09112542675388, 69.79907143500544, 67.83425423406786, 65.42286342190158, 65.2398338625508, 62.73117219248126, 64.60111510369086, 57.98962285441738, 59.22805632314375, 58.261992239183, 66.28181149882656, 66.31545759016468, 70.52821651581796, 71.42955364719515, 70.67452876798569, 75.07772661024525, 74.26762380907613, 73.39346085825275, 62.18500568020729, 53.17179518361246, 55.46467550339238, 52.906199732134425, 54.626084527661725, 53.738758102540054, 52.707363020989206, 50.939723368613954, 52.33354153171663, 55.63780107805806, 61.292184014474195, 63.0801062430105, 65.65960591839206, 63.32946700434532, 65.69107509428456, 64.49760375484344, 68.79685878753662, 66.13880972708425, 68.70770331351989, 70.793470721091, 70.19530142507246, 64.23644450403029, 69.62505940468081, 68.29298327046057, 72.56000426507765, 62.1647152593059, 64.6257358212625, 70.27312124929121, 68.98354007351783, 73.22352809290733, 67.85271290809878, 68.74198482882592, 67.36768045733052, 71.64965352704449, 68.245373541309, 65.37581459168466, 55.238154703570956, 51.89831141502627, 48.70035986746512, 47.634808786453746, 48.82088645812004, 46.97135948365735, 53.951342721139234, 64.95864698963781, 66.7425174097861, 65.77383710492042, 63.71123913795718, 64.50437768813103, 68.95005872172695, 65.70841197044619, 67.48520251243346, 66.73818711311587, 65.05131690732895, 67.03711094394808, 66.88794320629489, 65.19540517560898, 64.62609667931834, 64.25169075689008, 59.85762811476185, 47.99311730169481, 51.235846627143125, 57.32744047718664, 63.11934563421435, 65.68953360280683, 67.07541681105091, 62.897280646908676, 64.59428625722086, 60.70138877437961, 74.34230573715703, 65.4432636691678, 71.73413353581583, 35.38505846454252, 0.22698218393470013, 0.9797342794556773, 8.643039753360133, 15.757103331627386, 3.8453233001693605, 0.6410074005684545, 0.13813740453652798, 28.68287709451491, 52.894130599114206, 44.33930789270709, 47.66445013784593, 75.11679341716152, 12.594650214718236, 0.3522081571000238, 0.2769176487720782, 0.38081486078519977, 0.11059379340299677, 0.24697801338568812, 0.12235687429746314, 0.08987133721670798, 0.18771457005172007, 0.3566961146650776, 0.1669257323467924, 0.1215537460220437, 0.12227104946730599, 0.12318382024644844, 0.105917853183083, 0.1809921638379174, 0.16522241245594718, 0.12089726229709004, 0.08328796063940372, 0.19783371819123147, 0.19105129664944065, 0.2008924008377137, 0.06773792327411714], [0.021972365023928787, 0.06643043335286841, 0.05674713561611791, 0.09132584707150537, 0.0379404163498792, 0.034310668782000585, 0.02397255547675154, 0.03641007911233652, 0.045800103069913965, 0.07458718598730142, 0.036364519863479564, 0.012265839501314107, 0.008324475136525449, 0.0213819544672245, 0.019701659348943544, 0.06074391973895892, 0.05869300660466956, 0.02580234307735678, 0.04764849703098017, 0.035879118893776214, 0.017585167173115958, 0.049687907355086464, 0.009740307127245733, 0.05384563122906032, 0.058100767013046055, 0.03543949550798824, 0.045745653370695735, 0.1866972206100341, 0.0472309408078511, 16.354300860435732, 63.21395320277061, 52.315447638111735, 41.45126281246063, 52.666378175058675, 28.0059701396573, 23.62006602748748, 1.7217337027672799, 0.6651817033848455, 2.394341004471625, 3.323847862981981, 0.8444826821646384, 0.2298859023158589, 0.15237965320627536, 17.177445542427805, 75.1230299857355, 75.61054137445267, 80.73340785118842, 77.31501517757293, 73.65881704515027, 74.89047265821888, 68.67646555746757, 68.19411600789716, 62.990884088700824, 65.8473305548391, 62.127515500591656, 61.291399540439734, 63.85491947973929, 62.429639985484464, 57.59889594970211, 53.25346677534042, 56.358548364331654, 60.414773341148134, 63.96641677425754, 65.90680153139176, 68.11208355811335, 69.74051044833276, 70.38832126125213, 70.50983628919049, 65.3091460658658, 58.96207255701865, 48.007277058016875, 47.188466595065215, 47.405310907671534, 48.54368079093195, 47.57630663533365, 49.37068900754375, 46.78559603229646, 47.92939447587537, 48.47794971158428, 51.75187364701302, 54.81034963361679, 55.4091465088629, 60.09192697463497, 61.109174066974276, 59.54243429245488, 61.425713262250355, 58.2992979018919, 63.278809593569854, 64.42871908987722, 65.53897734611266, 70.78231550032093, 61.90230869477796, 67.16338772927561, 63.49041754199613, 63.592889462747884, 64.96952764449581, 66.13008637582102, 65.5257393467811, 63.40287808449038, 62.71225067877001, 67.65910471639326, 65.24143418958111, 60.67722305174797, 59.878193101575306, 55.49539550658196, 50.515213089604536, 44.44400379734655, 43.71248176020961, 44.82569356118479, 45.2021744174342, 45.80925533848424, 46.98032994424143, 55.31127552832327, 62.67291322831185, 62.31217676593412, 60.72277353655908, 63.15178755790957, 66.21235416781518, 61.818683762704175, 64.53670586309126, 60.659713591298754, 64.29468777871901, 63.926396831389404, 60.800463922562145, 61.785520122897246, 62.42007724700436, 62.67617271792505, 59.92801504750406, 48.856772222826564, 45.50976276397706, 51.69784299788937, 56.0545725207175, 59.23578339238321, 60.53475079997894, 54.21595758007419, 59.979139220330026, 60.29314456447479, 64.56249544697424, 55.68412034742294, 77.14934210623466, 10.65507640761714, 0.2699541546885045, 1.7892158752487552, 5.812038192825933, 3.553784311779084, 0.6323783087634272, 0.25641093060614606, 2.019092017604459, 39.68908702173541, 39.89559981130785, 21.681724825213035, 50.070475147616484, 34.89626838314918, 0.11020920194324949, 0.02691737830548758, 0.1113608236154241, 0.04476083968315394, 0.011950045609996926, 0.059909370367325125, 0.028543135624439008, 0.08629654879651724, 0.05244631800920733, 0.02910906584152291, 0.04764294289352913, 0.009657877024203058, 0.04183837896092765, 0.044318745663810166, 0.058332960602016225, 0.028837052917468454, 0.01661721699600739, 0.02139735666494216, 0.02992050425570098, 0.02090553779365315, 0.009064014283789983, 0.022162107765794765, 0.05192117239799231, 0.018501927355124105, 0.05125780537303898, 0.05638047061379879, 0.015060015927789914, 0.035506857619170225, 0.03810541636701073, 0.04631809725035583, 0.03443445326880582, 0.035769855603575706, 0.05877984650132637, 0.001832200418463007, 0.0543820804675981, 0.04337192993731268, 0.0503953397574444, 0.029611872328865915, 0.07568679795029663, 0.09729173379920183, 0.026332048826941082, 0.03893409750514454, 0.01908982131299713, 0.04373313656317131, 0.06287043809049553, 0.00740716528643163, 0.057991591822956844, 0.07541112887162356, 0.05526894981402063, 0.05934949416006285, 0.08716230475974661, 0.038454997608618396, 29.304653175415535, 79.7472926109068, 41.896114503183675, 61.380857036959746, 47.10228035526891, 39.26119173726728, 26.113805040236443, 1.6357281371470422, 1.0223117915372695, 1.967705903995422, 5.400302092875204, 1.166322286571226, 1.10603827622629, 0.2646461153222669, 24.98345052042315, 80.03822265132781, 75.42491912841797, 82.23182385967624, 79.36545771937217, 76.88941447965561, 74.21642903358706, 71.27354529596144, 67.7581210290232, 66.59767212406283, 68.75048852735951, 65.08808520532423, 64.34576880547309, 66.23235041095366, 64.2605592358497, 58.14408579180318, 53.59533663718931, 59.99906878317557, 63.515010802976555, 64.28499560202322, 69.12866776989353, 71.06867205712103, 72.04676212803011, 72.38016359267696, 70.91869631121236, 68.16792241988644, 62.36334408483198, 51.05503712930987, 49.594373933730594, 50.29916109577302, 51.4506277730388, 50.00883510035854, 51.67924704090242, 49.74016451066541, 50.0708556175232, 51.182949542999275, 54.65369016893449, 58.8941998635569, 58.74489484294769, 62.89044395569832, 62.877566814422615, 63.00160392638176, 62.589664843774614, 61.26858703551754, 65.83981529358896, 66.77012305105886, 67.7427924063898, 70.72204436025312, 63.997619228978316, 68.55908470769083, 64.44327892795687, 64.71401660673081, 66.77103304093885, 66.81682279033046, 67.83881987294843, 65.04640217750304, 64.58352327346802, 68.5888711867794, 69.2720696233934, 62.85077702614569, 62.897963139318655, 57.39086520287299, 52.942120798172496, 46.72334017292146, 47.55527096409952, 47.73711204528809, 48.354038115470644, 48.65433477586316, 48.66119107892437, 56.98665711187548, 64.64885034868794, 64.67071756239861, 64.4097505077239, 66.54118214884113, 65.99745535081433, 62.77074498514976, 65.54191127900155, 62.49891296509774, 66.61646812192856, 64.60666917985486, 64.56623738811862, 64.12147198953937, 65.61138037712344, 64.20352405117404, 63.865925650442804, 50.28538180935768, 47.57204301895634, 54.576646974009854, 61.23177951382053, 59.7506493906821, 64.44200023528069, 56.89841162773871, 63.277173965208, 62.8445561470524, 70.2674416572817, 57.80918205938032, 79.92264609183036, 11.871769159070908, 0.40959001188316657, 3.9473549348692742, 4.457077480131581, 1.0267134876020494, 0.3958691013676505, 0.4544253076516813, 4.545022412653893, 42.782119089557284, 49.31724671394595, 25.40758425189603, 52.434628855797556, 43.821692312917406, 0.08397829778973134, 0.024129676279581846, 0.054753644602192994, 0.052564467919329484, 0.025470950678291342, 0.020804094345939737, 0.07141104674026852, 0.06180536903200611, 0.11463277747914677, 0.013969811524504857, 0.03699409091965326, 0.012811351559996124, 0.017320441660441218, 0.013476577305775738, 0.016674152650539915, 0.009781360821498018, 0.040343021298007625, 0.07897491626922162, 0.052108519199875095, 0.05920506743413787, 0.03691086312755942, 0.047240133862942464, 0.04609372924953219, 0.07269638139874705, 0.1731881640490986, 0.15119243142825944, 0.1852779507997536, 0.10394337647143873, 0.19491288540584428, 0.0961020069136735, 0.261108995445313, 0.11903598273713743, 0.15045137925734445, 0.11684834206056212, 0.1690124639219815, 0.13020906867759843, 0.07630677758565835, 0.11533459828745936, 0.25051199230215243, 0.18449009065666508, 0.14496565345794926, 0.13882202667094048, 0.10162462750750204, 0.12541119024277697, 0.14355608232079015, 0.0962157250051537, 0.11836809196299124, 0.18543417144927288, 0.18067664286542326, 0.22697798577287506, 0.34541402973475, 0.15117982162102578, 34.61898426855765, 88.36648925658196, 57.07849940946026, 59.35568632618074, 64.2865292487606, 44.66428410622382, 28.383770873469693, 2.85463236993359, 3.5455640044904526, 5.85048673614379, 8.823924756819203, 1.3298766651461202, 1.0469219064520252, 0.3183771321369756, 24.455117064137614, 83.28897322377851, 74.95618020334553, 84.8494254389117, 82.6543180404171, 80.07586171550136, 78.88859164330268, 76.7196229196364, 71.87765306042087, 68.7762035862092, 71.64898672411519, 68.86875583279517, 66.21921047087639, 69.1183440916, 68.45995072395571, 62.22552376408731, 57.86897074791693, 62.91338982120637, 65.35648907384565, 67.42346440592121, 71.72765378029116, 73.88583598598358, 76.56481481367543, 76.89617664583268, 73.80916149385514, 70.80931709658715, 66.54265696002592, 55.10399395419706, 53.4351509617221, 54.008213166267645, 52.4036499761766, 52.41832356299124, 56.53017167122134, 53.261193844579886, 52.99992868977209, 51.952679387984745, 56.87596782561272, 60.377491212660274, 60.651013774256555, 64.42249821078393, 65.52913611935031, 64.4777173380698, 65.6322826877717, 61.582121695241625, 67.57886086740803, 68.4590878025178, 69.74371110239338, 73.44542441829559, 65.64889000308129, 71.02098388056602, 67.16541167228453, 67.39378775319746, 70.0775283382785, 70.94237173757246, 69.50173224172285, 67.10779989919355, 65.13543213567426, 70.52752617866763, 71.28846599209693, 65.07274089321014, 64.25127498565182, 59.11248760838663, 55.67540091852988, 50.08310910194151, 49.70054857192501, 51.50317184386715, 50.40351183183732, 51.67124148338072, 51.09253891052739, 58.975894989505896, 67.41754947170135, 67.47430616809477, 64.48623672608407, 68.82363288633286, 70.21175184557515, 65.40047061058783, 68.66850314601776, 66.72957358821746, 69.4383938081803, 67.01268242251489, 67.29070002032866, 67.93739688011908, 68.42227243608045, 68.79128902189194, 67.58254789537, 54.818284588475386, 50.18588304519654, 56.79477476304578, 61.561403735991455, 64.73807250299762, 65.36890337544104, 58.7688526799602, 66.90509180868825, 66.70281517890193, 71.96256452991118, 63.16750057281987, 79.04540015805152, 13.06661234747979, 0.4867127573778553, 8.28107656971101, 14.699979462931234, 10.338576436042786, 2.969918183742031, 0.8808322058570002, 4.849860197113407, 57.28743622379919, 52.09844250832835, 35.60887282894504, 64.80625898607316, 54.226442075544796, 0.21961635579505276, 0.29586030651004086, 0.17755167829173227, 0.17803817476716735, 0.15113560302603632, 0.1230434422952033, 0.18045185734668087, 0.1821966838812636, 0.1998903884762718, 0.12675856270136374, 0.13282944177908282, 0.09973779891527469, 0.1281694898141488, 0.17973227095940422, 0.13740873234646936, 0.13186095342520746, 0.1556728813316553, 0.17928721984067272, 0.10372032231140522, 0.14766902452515018, 0.1511546632935924, 0.11922257111197519, 0.17529507438021322], [0.0470944392615028, 0.08306792486579188, 0.0226930009516617, 0.03317540308700935, 0.07891487795859575, 0.05291873761903375, 0.04100419731149751, 0.07132090117421842, 0.017755426383847674, 0.012184475218096088, 0.06871897546995072, 0.12429355223092342, 0.03465291856217288, 0.07115177960405428, 0.05739843675626382, 0.024605941650788152, 0.07116156254684733, 0.01180436441509594, 0.029387222790730097, 0.07192829398498421, 0.017207246423969348, 0.02421062496010094, 0.10529706149452156, 0.07567590418001337, 0.029924405558455377, 0.10152227049993892, 0.15649216640139782, 0.24331304875593035, 0.13487261359489736, 1.1851959963960033, 36.352934683522875, 80.13435209951093, 34.71558832353161, 53.59357549298195, 41.07857488816784, 15.441948733022137, 0.5792233900677773, 1.3174043860166305, 1.6349880349251533, 3.1549341784369562, 1.1451282496413877, 0.7971453738789406, 0.08538809109238849, 0.37813428849462544, 23.77160679909491, 82.23756620960852, 77.18308233445691, 78.27240297871252, 75.67864941012475, 73.35760255013743, 75.34595397210892, 74.46213414592128, 74.18424990869339, 67.6202497174663, 65.03891829521426, 66.69600594428279, 67.21234675376647, 62.972394035708525, 59.25868218944919, 60.66911159023162, 58.267585539048724, 58.93242728325629, 65.26414471287882, 68.41545535672095, 71.34202987917008, 69.33799682124969, 70.86161798046481, 68.12937336583292, 68.5278626411192, 59.55220883892429, 49.233229544854936, 48.30406711947534, 49.714359237301736, 49.040633324653875, 49.35651748411117, 48.867021376086825, 48.760156400742076, 47.90627602607974, 49.9278263891897, 48.09860552510908, 48.926460973678104, 49.12705882903069, 52.4926132540549, 53.35835095374815, 55.50508768327775, 50.08829839767949, 58.553961707699685, 61.92054379370905, 65.91885105256112, 66.71384488382648, 60.369756298680464, 67.24364726774155, 64.98578979123023, 65.83972900144516, 64.14976796796246, 67.66746720960064, 65.23358944923648, 66.46146389745897, 63.0476172508732, 65.76878901450866, 63.600357655555975, 59.52106129738593, 62.06449477903305, 58.08418335453157, 55.33290739982359, 50.305448655159246, 46.449154730766054, 45.56214209525816, 46.1873875125762, 44.7711020131265, 44.82874908754903, 46.87853267115932, 59.164482547390854, 63.41211134387601, 63.1031148664413, 61.1944071708187, 60.87834650470365, 63.3396416325723, 65.51339957021898, 62.912189575933645, 61.697098132102724, 62.82684272335422, 64.30817680974161, 61.60099221814064, 63.103020729557166, 62.23498059857277, 63.30917658344392, 61.55151151841687, 57.99074857465683, 47.014179998828524, 49.49167059313867, 53.25071719384963, 58.41278776045769, 57.31367688025198, 59.24502449650919, 58.27055477326917, 62.216925928669596, 57.65606449496362, 69.79413709332867, 29.33774425137428, 0.2123663754713151, 0.11179190129041673, 1.493302708671939, 2.823985911184742, 1.702735089967328, 0.2709518769575704, 0.20388261054552373, 11.842075836273933, 57.36948044069352, 26.784612709476104, 34.11821919102823, 62.84548574878324, 4.189849342069318, 0.21196883712564746, 0.04000423040481345, 0.053374877860469204, 0.040709919957143646, 0.03624019145424809, 0.03867358547605334, 0.05028178637486793, 0.032043682463887724, 0.03551194444298744, 0.045744929417607286, 0.06865325278692669, 0.03750442422085232, 0.03527172225257082, 0.04258385528960536, 0.0420918314897966, 0.05267393422282992, 0.05318763831089582, 0.04177948212130897, 0.04162051887702077, 0.029474733014320655, 0.039085484139861605, 0.04432775868823932, 0.023410317803462668, 0.02861634107126344, 0.04072243017294715, 0.048479265758707646, 0.07184422349617367, 0.10641166579819496, 0.01151695216615354, 0.05735764257429589, 0.022812600683180556, 0.021350341849029068, 0.007124928440222698, 0.10301835594638702, 0.016667407246366624, 0.02603505377567584, 0.04219498139836135, 0.02173471497371793, 0.09601621272703333, 0.05221958279669766, 0.02801455793932321, 0.04359177035850383, 0.17359131015837195, 0.06623108195321215, 0.03610737096037596, 0.03664070988194116, 0.08626035114209499, 0.06054749096473379, 0.11400337496231641, 0.11105923778227261, 0.388937323324142, 0.2774080676176856, 4.06172659127943, 54.241617725741484, 78.92346935887491, 36.90167819300006, 74.30294867484801, 41.997037087717366, 26.596760595998457, 0.1657098129151329, 0.40841140093341954, 1.2912839747244313, 2.433915513177072, 3.158103453536188, 3.479161954695179, 1.3159149885177612, 0.45116551160331697, 32.510988789220015, 83.25585273004349, 78.34415881864487, 81.37540571151241, 77.3982870963312, 74.7478238997921, 78.28241286739227, 76.18990682786512, 74.85491245023667, 70.8061242872669, 69.91985690209174, 70.11328466476934, 70.09615175185665, 67.36848846558603, 64.1868814345329, 62.39687250506494, 60.5026226658975, 61.05920307097897, 68.73820366397982, 72.72970953295308, 74.57797742659046, 72.3594456334268, 73.25289095601728, 72.09512495225476, 70.60577746360534, 63.500145020023474, 51.60165079178349, 49.46260190779164, 51.638171980457926, 50.16714588288338, 50.076197885697894, 51.20230251742948, 50.70245919689056, 48.63982200622559, 51.998194571464296, 51.69077488683885, 51.81347054819907, 52.02006570754513, 54.34490549948908, 55.48389511723673, 57.07084686525407, 53.993292470132154, 61.47065185731458, 63.26428897919194, 68.14366648274084, 69.44507752695392, 63.63088938497729, 67.3681511417512, 67.83799617521225, 68.14251330591017, 68.93168633983981, 69.40896818714758, 66.3603687286377, 65.54283303599205, 65.13474572089412, 69.53266405290174, 66.90080073571974, 63.034343950210086, 64.55912220862605, 60.85716570577314, 56.35823065234769, 51.902371068154615, 50.29803929790374, 46.78499198728993, 47.078648074980705, 45.796570393346975, 48.26517289684665, 48.36484816766555, 62.645911632045625, 64.35242899002569, 64.48883725750831, 62.507189166161325, 62.821500455179525, 64.69177676785377, 65.64243378177767, 67.1886791721467, 64.08750818621728, 64.86754209764543, 65.82785206456339, 65.73531550745811, 65.46946902428904, 65.72560371891146, 65.26722769583425, 61.998532279845215, 60.10241147010558, 48.97409031468053, 52.747516324443204, 55.877293156039336, 61.05493945460166, 59.99893934495988, 61.925238870805316, 63.823364011703006, 65.8138962714903, 61.55012299937587, 74.79063264785275, 32.022194785456506, 0.27115035501699297, 0.4780255961081674, 4.078448390768421, 1.5171507193196205, 1.0954509411127338, 0.34886721701871964, 0.11203269038589732, 14.95411963232102, 65.06594734807169, 35.6567532016385, 32.018639156895304, 71.99293936452558, 6.970759293725414, 0.3645629796289629, 0.06713706519334547, 0.020368427804280675, 0.11852183814851508, 0.04655610927711091, 0.029027406614454045, 0.09166310195841136, 0.03388765801285063, 0.026927176570039124, 0.04923150664375675, 0.057750488631427295, 0.04234238054543253, 0.04521627895413868, 0.023527050450924906, 0.03799669316879684, 0.036213477968328425, 0.02786455217808966, 0.008923290635368997, 0.018934908758608565, 0.051364157529127215, 0.07145340374160199, 0.03873391873053005, 0.02015814816038455, 0.2290093291911387, 0.14662650143427236, 0.08194887725215766, 0.10976543019135153, 0.2911176093884053, 0.11458325755572128, 0.16454762689048247, 0.14866777335203465, 0.12108977253158247, 0.08374175282135125, 0.26398700391573293, 0.19281942757867998, 0.09761984159629192, 0.2698469943096561, 0.1301971023842212, 0.16208185033211786, 0.15131358057260513, 0.17013744871702888, 0.12347987492478664, 0.22819359876936485, 0.13321335908145676, 0.206919965304194, 0.2147466412955715, 0.1093221104313289, 0.12303883044589912, 0.42169058515179547, 0.32732611161566555, 0.5740338491816674, 0.39378319716741966, 3.5644597776474494, 69.38588111631333, 94.03122332788284, 48.950281527734575, 67.48843454545545, 58.110035696337306, 25.387333054696363, 0.8029672743812685, 2.711689433743877, 4.948453874357285, 11.09935837407266, 5.8873442680605, 1.6014656208215223, 0.5170874081311688, 0.32510111649190226, 29.96690811649446, 87.16496529117708, 81.88365074896043, 83.97523110912692, 80.41258935005435, 77.53038467899447, 80.98017984820952, 80.22258973890736, 79.90609368970318, 75.49443921735211, 72.71867982802853, 72.91096225861581, 75.14533258253529, 71.89091067160331, 66.01167786505916, 66.18634885357272, 63.73079215326617, 65.60752860961422, 70.74983827529415, 76.73470051057878, 77.57604106780022, 74.56632798717868, 75.37258686557894, 76.26255696819675, 74.37327677203764, 66.68636475839924, 55.031371270456624, 53.87148326443088, 55.65143523677703, 54.35142840108564, 53.62519764131116, 52.768226438953036, 52.33902500521753, 53.14764122809134, 53.968330506355535, 52.960755978861165, 53.36954147584977, 52.86650142362041, 55.98332266653738, 58.24687934690907, 61.87630730290567, 56.48891618174892, 66.0070808472172, 68.48280245257963, 69.91606004776494, 71.82741534325385, 63.009280004808986, 68.99638975820234, 68.33354057804232, 70.89535036394673, 70.83635007181476, 73.71352626431373, 67.80399707055861, 69.51648035357076, 66.53897777680429, 71.58861360242291, 68.16744389072542, 66.17155367328276, 68.06056714827015, 64.38206249667753, 60.25295203731906, 53.996908895431034, 55.19374170610982, 50.40793626539169, 51.079461728372884, 48.62016308692194, 50.445026197741115, 51.69612107738372, 66.2720447970975, 68.27211626114385, 67.82481701143327, 64.81619042734947, 64.31895156060496, 67.75634811770531, 70.28762617418843, 70.60617754536291, 65.4980944818066, 65.23232252367082, 69.11439818720665, 69.53957526914536, 67.56651324610557, 67.79757222821637, 68.25576782226562, 66.15150251696187, 62.79770735771426, 53.56854292654223, 56.54220942528018, 57.8431184061112, 63.73012535033688, 64.9873822735202, 65.7542174093185, 66.40496607749694, 70.78553968860258, 65.84939372154975, 75.97511783722909, 34.88024942336544, 0.6913110012969663, 0.34627128212201985, 7.423574866787081, 16.3547097675262, 3.3162612636243147, 1.3076949263772657, 0.41763080944938047, 20.831254951415524, 73.57194439057382, 39.75737548643543, 46.6188011630889, 83.27042041286346, 12.425985355531017, 0.5844473129799289, 0.2084452463614364, 0.179742076884835, 0.19792263035572347, 0.11029111206411354, 0.04905260213079953, 0.2360180990710374, 0.07695344006342274, 0.16992804624380606, 0.19227735908521762, 0.15859901544547853, 0.172523858566438, 0.18870343634438133, 0.08731121693046824, 0.12183736709337081, 0.1164030381328156, 0.08187668878705272, 0.1669378518577545, 0.12157776287846989, 0.10748526907616085, 0.32576332289365034, 0.09394851077588336, 0.14759287538547672], [0.018485550310522802, 0.0136157218554628, 0.03165892054957729, 0.053667098268746376, 0.018441061669540022, 0.10745215109519421, 0.036754592682325074, 0.005356537998699013, 0.00917308509439951, 0.0263784775855921, 0.07688328173131713, 0.04537111681495463, 0.03184122649291831, 0.02538035120514612, 0.03374118200172821, 0.032862996261927395, 0.043331526460186134, 0.02277707910135148, 0.062286161982844916, 0.04068139850372269, 0.015715514272150975, 0.0300652431624551, 0.055425316020245516, 0.05481529169745984, 0.04317195417599813, 0.030152393324721246, 0.008279482792732457, 0.06253199193686729, 0.08507448533970503, 0.20576190083257614, 18.844382262999012, 60.81058363760672, 47.497372857985965, 30.60063369812504, 58.69350394895, 24.81910321020311, 1.2548835215068634, 0.20853647211145973, 0.40674212598992937, 0.9752227570260725, 3.487460219090985, 1.4833178251020371, 2.391124906078462, 0.06601732043970017, 1.1255608931664498, 47.469135715115456, 84.54872085202126, 74.51590984098374, 79.8526474737352, 78.24128289376536, 80.78705803040536, 77.52019436128678, 73.39826183934366, 73.38738118448566, 68.54896499264625, 67.55406364317864, 70.86768980949157, 65.95082621420583, 63.00077238390523, 62.18526063426849, 63.51212001615956, 66.64187723590483, 70.00247770740141, 67.17066764831543, 68.51349892154818, 72.2594722624748, 68.49097667201873, 68.9257792503603, 65.85702665390508, 61.225895958562056, 48.80842508808259, 48.83798799207134, 49.78249472956504, 49.605234976737734, 48.649498493440696, 48.45515289614278, 50.64079169304141, 49.87044211356871, 49.643187830525065, 51.718204021453865, 50.57859859158916, 51.087071126507176, 51.83254503434705, 51.64971159350488, 53.598415697774584, 53.76090772690312, 58.27606570336127, 59.5464978679534, 67.65983427724531, 59.3511010754493, 53.637992412813254, 65.69658210200649, 65.77099730891567, 65.55583961548345, 67.60201854090538, 66.96977953757009, 67.0590840616534, 66.0313367843628, 67.61487607033023, 63.62322507366058, 58.21233895517165, 63.93298641327889, 59.619261757020034, 57.69058919722035, 56.67020420874319, 48.99812267672632, 45.246108885734316, 45.76668193263393, 45.37398599809217, 47.33719110488892, 47.22254022475212, 49.03187074968892, 56.98981854223437, 63.69585167977118, 62.435892243539136, 61.32817960554554, 63.938054115541526, 67.37475641312139, 63.04054521745252, 65.17908419332197, 64.49934920957013, 65.56123679684055, 63.84031257321758, 63.68700673503261, 63.33144387891216, 63.203107849244155, 63.96769154456354, 63.160408927548325, 60.5954102546938, 56.77941083908082, 48.7808665152519, 49.72879355953586, 52.71215223496961, 54.80921999100716, 57.81345744286814, 63.24422605576054, 61.5678717244056, 61.08332172516854, 43.62490307900214, 0.24191792603702317, 0.12413275803649619, 0.14776746682342023, 1.2697729612550428, 2.073434985453083, 0.41702746924373413, 0.17102598813512634, 0.1107084844261408, 39.31532044564524, 42.472036115584835, 19.5710523282328, 58.20965605397379, 26.884748858790246, 0.04037120950318152, 0.06642975919549504, 0.0673683011724103, 0.062094084588029695, 0.0895054153196754, 0.034690851405743635, 0.02618241461835081, 0.04311142556910073, 0.010546935466869224, 0.036007216455595153, 0.03545675163848266, 0.019539723683509137, 0.020184497754540176, 0.024746758187369957, 0.06837055102110871, 0.07194670307780467, 0.013379704530140566, 0.03120991833237631, 0.021145562716429273, 0.039081366417268594, 0.0439864895006101, 0.017902492282671795, 0.02483341422292494, 0.039501538830659086, 0.07959708691604676, 0.06025469216007379, 0.03583747435421233, 0.008363420173766152, 0.020519640153994965, 0.03808351008281593, 0.022294888040050868, 0.06697884505434383, 0.04455414533074345, 0.030159906732038628, 0.06300411277240323, 0.009105310253348322, 0.033390382680320935, 0.03961490452169411, 0.03546652692039648, 0.042742228646191864, 0.016149018530643756, 0.01615582905229061, 0.037141574336396116, 0.048457014734946915, 0.056504159339613495, 0.017029016068385496, 0.023266249223642295, 0.05004865815863014, 0.023330315241530057, 0.04678783555244727, 0.05220164484795063, 0.048729470074777646, 0.03606509822871416, 0.07207009685976852, 27.528413726437478, 74.59076435335221, 36.82822788915327, 47.76805170120732, 67.86065963006789, 28.459807980445127, 3.049137068371619, 0.4205810753328185, 0.4896398567624631, 1.5798534837461289, 3.5254986295776987, 4.972898085271159, 11.489775411544308, 0.06571305329881369, 1.5805993469492083, 57.72571009974326, 87.49318922719648, 76.37498778681602, 82.91814450294741, 80.98631443515902, 82.11652971083119, 77.85524322140601, 77.58604311173963, 76.09099249685966, 69.80626506190147, 68.88865793904951, 73.72728593887823, 69.15475937627977, 65.95154008557721, 62.932801631189164, 66.5035273951869, 67.95291377652076, 71.11175537109375, 68.44888964006978, 70.69829833122992, 73.29937104255923, 70.11053900564872, 71.54107447593444, 69.88683838998118, 61.84077062914449, 51.757851339155636, 50.30957498858052, 51.187817204383116, 52.75705945107245, 51.92459521755096, 51.67428916500461, 52.560105477609945, 53.207390692926225, 50.351379609877064, 52.73887534295359, 52.53245669026529, 53.318354545101045, 53.803206566841375, 52.14968827462966, 56.02980275307932, 57.205262568689164, 58.56805478372882, 60.812980205782004, 70.87381655170073, 62.66203649582402, 54.44920132237097, 67.09072189946329, 65.16247687801238, 65.77089924966135, 68.01815063722673, 67.8273194836032, 67.2422352144795, 67.23657915669104, 69.02648218216436, 64.57721217986077, 59.80737863048431, 65.4065110606532, 62.61989062832248, 61.87975506628714, 58.87729444811421, 51.58688699045489, 47.22824727335284, 47.82640480226087, 48.44780629681003, 48.557134520622995, 49.98486941860568, 49.62063812440442, 59.451517674230764, 64.64966620168379, 65.94082417026644, 63.42279195785523, 66.03241151379001, 66.51784404631584, 64.82426658753427, 65.21786466721566, 64.60929324550014, 67.65140118137484, 65.97056358091294, 64.49247721702822, 64.66437508982997, 66.21665308552404, 66.78141163241479, 64.73593873362388, 63.228564031662486, 57.02713204968361, 50.81762390751993, 52.5521352214198, 55.82656906497095, 56.6296390564211, 64.03725477956957, 64.98217336593136, 66.31956823410528, 64.90133331667992, 48.835214876359515, 0.40551246294090826, 0.30524831565637744, 1.1703722563482102, 2.546791275662761, 1.5994154469620798, 0.15139110867054234, 0.30939416899796457, 0.4894424205826175, 42.224616927485314, 59.99795483004663, 21.47003842938331, 59.317984504084436, 37.66665020296651, 0.15439313145414477, 0.11554015499930229, 0.05038166508799599, 0.0691819913505066, 0.08319792998654228, 0.04355236279567884, 0.05261584177553173, 0.08199095846183839, 0.055291817538560405, 0.05127209291282681, 0.029450603159925634, 0.017962902145940932, 0.017157764804940072, 0.09536642461053788, 0.04205153143453983, 0.040407606340464086, 0.011430790257309715, 0.03563287525227474, 0.020934838741537065, 0.03810079302638769, 0.02767308190795443, 0.022270689237742655, 0.041744219094154336, 0.03548024755512034, 0.15622870876423775, 0.19442867187242355, 0.11438328562484634, 0.1679831941521937, 0.1493173852683075, 0.1536068034869048, 0.14252065320409116, 0.08013249810544715, 0.1004814328024945, 0.11364874520128775, 0.1768530980353394, 0.17839584589725543, 0.09868475743719647, 0.1461318997485984, 0.08239323123087806, 0.20184418847483976, 0.10663692629145038, 0.13941481018499022, 0.15653747284123976, 0.12571151969173264, 0.18739218493142437, 0.09194235632857008, 0.15786049136471364, 0.16972895531404406, 0.17623250552963826, 0.12356442038811023, 0.127173790017203, 0.22942493189006086, 0.16992600844992747, 0.30011267671661995, 31.679593401570475, 86.76125141882127, 61.36530483922651, 45.77281651958343, 74.67354989820912, 42.490628150201616, 2.797827624505566, 0.5504536628723145, 0.9714499272165761, 6.265424470747671, 11.20486915111542, 4.793272162637403, 5.041540543879233, 0.1555336065470211, 2.300879748598222, 53.49412379726287, 91.65536526710757, 78.66891537943195, 86.42573187428137, 82.13494131642004, 87.16677742619669, 83.24152038943383, 79.79865997068345, 79.55171538937478, 75.10305727681806, 73.07416423674553, 76.42395465604721, 72.07474431683941, 69.35717721139231, 68.41631827815887, 70.93859057272635, 72.67122699368385, 76.84518583359258, 70.67652917677357, 72.58236177505987, 76.28401233303931, 71.76255503008443, 74.91727813597649, 72.33689984967633, 65.88071776974586, 56.359728997753514, 52.964341025198664, 55.35336648264239, 54.953229811883745, 55.30953007359659, 54.2962484975015, 55.95379114151002, 55.98892381114345, 53.45602581577917, 57.66398376034152, 55.838736257245465, 57.4493359750317, 58.07313796012633, 55.79759843887822, 58.94510046128304, 58.13036534094042, 61.83274153740176, 62.3186251424974, 72.8716601094892, 63.32236359196325, 55.04455435660578, 67.1577787399292, 67.81429721463111, 68.09638623268374, 71.09234748348113, 70.98897733995992, 70.29897751346712, 69.3707956806306, 72.09670174506404, 67.21635541608258, 63.08684879733671, 66.23566873611944, 63.13196389905868, 64.71035311298986, 61.09714023528561, 52.98049726793843, 49.74195311146398, 50.67261388224941, 50.90899552068403, 52.8634576643667, 54.23376514065651, 53.50394541217435, 60.858797411764826, 68.37334479055097, 66.85006095517066, 63.53712512600807, 67.8867983048962, 69.5376140840592, 66.60453627186438, 66.8698767692812, 69.63704616792741, 69.39124691870906, 68.55323253139373, 67.31179452711537, 68.36323292024674, 69.2476018782585, 68.55864540223153, 67.36477005866267, 66.62213202445739, 61.34998798370362, 54.25915072041174, 55.45781920033117, 59.760192517311346, 59.938742729925345, 66.3268481531451, 69.69257908482706, 70.8456225549021, 68.87984045090215, 50.188012892200106, 0.7894570380449296, 0.48630351320870463, 1.3743450660859386, 7.995969287810787, 6.569141928226718, 0.7114946601852294, 0.7256577872941572, 0.6633383119779249, 55.16324920039023, 54.57722748479536, 31.55509933348625, 72.08148294879545, 46.215691335739635, 0.26093405160692434, 0.2937782633929484, 0.09974469370659321, 0.1752259885712016, 0.18045142833744326, 0.13618925826684122, 0.16638547182083133, 0.1009906437848845, 0.24585600101178695, 0.14683688450003826, 0.16211393409438674, 0.10508156862230071, 0.11503039243360681, 0.16084593600563465, 0.20813508800441222, 0.17484204062531072, 0.1080418089705129, 0.24948924960147953, 0.10683996257402244, 0.0748877146191174, 0.11825616651725386, 0.1285066910749001, 0.08578123209337074, 0.12513359062253468], [0.05326538474389142, 0.0785808329800925, 0.047137466589770013, 0.03393206429938155, 0.08135001866086837, 0.03910830972956554, 0.06222858664489562, 0.06547535153766794, 0.023482153868122448, 0.08403730188165942, 0.04185731282397624, 0.060791359733669996, 0.033536314769017125, 0.04752635197233289, 0.08063056250853885, 0.027095813589591174, 0.04039205092516157, 0.013297814519084511, 0.06222449956581958, 0.0377650779762095, 0.075862362319904, 0.0252525964676733, 0.1054314409773196, 0.05398317082454601, 0.02350466344655762, 0.08051980151644639, 0.03460292749467396, 0.08711849985223624, 0.06513640359644929, 0.026776217029339848, 0.3735402124303003, 40.61431530983218, 62.138431456781205, 36.637828196248705, 40.32088279724121, 66.7156413293654, 4.540613668580209, 0.116298015139276, 0.5670644715428352, 0.5700243288470853, 0.8427822121208715, 25.60809385391974, 20.4314124584198, 0.20152978599071505, 0.13826636777770135, 14.43483998698573, 78.58960505454772, 77.61433909016272, 82.51786662686257, 79.34822282483502, 82.92140007019043, 78.76143624705654, 81.44846377834197, 72.8348212088308, 73.483902869686, 70.78130352881648, 67.80834305670955, 65.64359480334868, 67.1103572845459, 63.316193703682195, 65.54867736754879, 65.32829115467688, 72.23671467073503, 68.4875092967864, 74.92355392825219, 70.86584629551058, 68.22605194584017, 71.19526263206237, 67.91725943165441, 60.9286234455724, 51.52322300018803, 47.43353628343152, 50.25681126502253, 48.86050631923061, 48.627807786387784, 50.473514372302645, 51.208091935803814, 51.128256013316495, 51.25055159291914, 50.99974347699074, 51.84518683341242, 55.537600209636075, 57.98899919755998, 56.74124617730418, 59.19350024192565, 56.73306019075456, 63.958917202488074, 63.10912393754529, 70.35483990946125, 59.11352311411212, 51.34592010128883, 65.33769307597991, 61.91316189304475, 68.56232458545317, 65.5483792674157, 69.2496572002288, 65.62088820242113, 69.8450808371267, 62.07598340126776, 59.82913994020032, 67.88539409637451, 63.04507555500154, 61.31552996173982, 62.20914002387755, 57.49635342628726, 47.37180209928944, 46.5142660756265, 46.45732502783499, 47.64316343492078, 46.47410884980233, 45.52356166224326, 48.45784756445116, 58.28352997379919, 62.37288328909106, 64.56402909371161, 61.92976528598417, 61.912102853098226, 66.52673213712632, 67.28127848717475, 66.03034050233903, 66.64467780820786, 64.79464092562276, 65.50852014172462, 61.59688549657022, 62.56325160303424, 63.9517157308517, 63.27566385269166, 64.09836530685425, 62.797040554784964, 61.21073992021623, 49.59912392400926, 50.39352939974878, 50.971541635451786, 55.39756374974405, 62.01032684695337, 62.52511047547864, 57.91190108945293, 58.17449592774915, 3.524184390421837, 0.1091085251180395, 0.5352875734529188, 1.3677416333267767, 3.474671085996013, 0.22401094256389528, 0.5154999513779918, 0.2204128420881687, 8.947382338585394, 64.15271759033203, 19.190503974114698, 36.17884028342463, 56.48981048214821, 2.8311175156024198, 0.33346992226377614, 0.11836188665080456, 0.03359633392744488, 0.043743042080032254, 0.05729722888058713, 0.0047017865900641255, 0.039382963741738955, 0.027066782687700568, 0.03892803391922386, 0.05378489194798374, 0.034198279853069016, 0.019102484746385488, 0.06715968776974948, 0.02149030802801492, 0.030266544255878658, 0.010169032912310815, 0.02261969208296749, 0.02739888180287615, 0.06503148019433984, 0.020216319131694978, 0.025354097371981032, 0.013495759189789815, 0.10444160175299454, 0.046723353931860584, 0.042491652777478586, 0.005780169777872582, 0.06943781875194081, 0.038857722369533394, 0.015758893043253452, 0.06577810948534359, 0.03914167668910758, 0.12606791145498716, 0.06964383511653832, 0.060766197575797, 0.041298271652551434, 0.031003672141401522, 0.028324423267716364, 0.01768590390471922, 0.09336714197190539, 0.08111824642025656, 0.025920060147801717, 0.06046407931153813, 0.06645071936110336, 0.04199009884389178, 0.06652641650890151, 0.011080369191815057, 0.06312024021040528, 0.011088723380629335, 0.0736010622894091, 0.033029834890077193, 0.055769404411436095, 0.08952589284989143, 0.006013485206846869, 0.09237397792598895, 1.6071005958703257, 59.513110653046645, 60.57248792340679, 28.197424950138217, 67.89297996028778, 66.20934178752285, 7.609700156796364, 0.06933857206135027, 0.1678641747322775, 0.27643112165312617, 3.2164661153670284, 7.01051986986591, 21.683627174746608, 2.0622998668301493, 0.13853092858147237, 18.58686101052069, 82.84265456661102, 78.95920999588506, 84.10197073413481, 80.58395770288284, 82.97273605100571, 82.69659334613432, 85.00258614940029, 75.93105393071329, 76.07000781643775, 73.41128410831575, 71.38536422483384, 67.78185921330606, 68.81523116942375, 66.98409618869906, 66.40535831451416, 66.69819462683894, 76.55545603844428, 72.58461321553877, 75.14902745523761, 72.0575172670426, 70.11155097715317, 71.78411237655148, 68.25907830269107, 63.385117592350134, 53.576489648511334, 51.10591027044481, 52.717725922984464, 50.783565967313706, 51.192433834075935, 51.27311698852047, 53.2719882072941, 53.12014149081323, 53.084522447278424, 51.45480117490215, 55.016501565133375, 57.27016602793048, 57.77925045259538, 57.204258441925056, 60.15302573480914, 59.80049879320207, 65.38385545053791, 67.46774796516665, 71.39837080432524, 61.32829335428054, 52.69277572631837, 64.99999661599436, 64.30901619695848, 69.90929788158786, 68.21888185316517, 73.36325076318556, 67.63524886100524, 72.4841848496468, 65.70795305313604, 63.62078143704323, 69.45813117488738, 65.58624190668907, 64.28661946327456, 63.5647778357229, 59.237348418081964, 50.50617594872752, 48.06604200793851, 47.81159785486037, 47.73692769388999, 48.98143691401328, 47.83100574247299, 51.55806541442872, 59.89101140729843, 65.90696627093901, 64.27156540655321, 63.62340158031833, 63.2764091030244, 68.14445880151564, 69.3484224811677, 69.45415389153266, 67.99926050247686, 66.26741640029415, 66.29149975315218, 64.77433089287051, 63.037395554204146, 67.75219040532266, 65.88391057906613, 66.45438794166812, 64.98753132358675, 63.64880284955425, 50.01687203684161, 53.47875595092774, 54.01245717079409, 58.18764371256675, 64.50321274418985, 68.26514228697746, 60.40649714008455, 63.7767505645752, 4.661987981488628, 0.12640204070316208, 1.6470184345399181, 0.8346337332360206, 0.8087774690601134, 0.16966481843302328, 0.4064842607946165, 0.44600820769706084, 10.91469612813765, 76.70765184587049, 27.596557063441125, 29.990709058700073, 69.63914071359943, 4.77137258937282, 0.33175955436402754, 0.041854501281294136, 0.024260035715997223, 0.03750702891979487, 0.07003896028524445, 0.008023114820506664, 0.09601309474918152, 0.048871644502205235, 0.06517426366166723, 0.032927864756915844, 0.013037154060457985, 0.04600151907652617, 0.03728963231908218, 0.027345521863730207, 0.06395155669099863, 0.056283886078745134, 0.0512153028149999, 0.006004199742399637, 0.03486416730729323, 0.029929752852166855, 0.05314539239231137, 0.050809303028208595, 0.0033076475759322246, 0.03364201575036972, 0.20593584875666326, 0.13551344614355795, 0.11395408486526822, 0.16528256567976168, 0.12402539847478752, 0.20933092061069705, 0.16378376062118238, 0.3366147744799814, 0.1822600393526016, 0.25583763636889, 0.13010088174093154, 0.18038680116015096, 0.13112471228645695, 0.1779452789454691, 0.21134787689774268, 0.23936476949001514, 0.15615619088132537, 0.12874849140644073, 0.19875660899185366, 0.18064002386264263, 0.125825590183658, 0.11474834184252447, 0.19640003060621603, 0.22591684674543722, 0.198729106435372, 0.20706947502349654, 0.22541672922670844, 0.1643858291208744, 0.24400065863324752, 0.24145945305785826, 1.4576171074182758, 68.86306055130498, 76.45351363766578, 52.80554779114262, 53.82681923527872, 86.40417452781432, 10.351540850054834, 0.7725428585563937, 1.2088303604433615, 3.0790635270457116, 7.668345964724018, 43.88683111436906, 36.34549394730599, 1.4555242777832094, 0.17058741812023426, 18.944842007852372, 85.63073804301601, 81.05178663807531, 87.27778834681358, 83.28896537903817, 84.35272001451062, 83.29091871938398, 88.12649511521863, 78.64015656132852, 81.1349565752091, 77.03438528122442, 75.06197437163323, 70.73850262549617, 73.0820168218305, 69.10595724659582, 72.10706464705929, 71.58143566500756, 79.12003501769036, 75.01804382570329, 78.28795909881592, 75.12509315244614, 75.57652658031833, 75.8336301003733, 72.93852867618685, 64.16148408766716, 57.3441223175295, 52.4677062034607, 55.26378739264704, 55.99219114549699, 55.01529739749048, 53.95129565269717, 55.79037735539099, 56.40858211824971, 56.61114508105863, 53.95741062779581, 56.69993577464935, 60.22581708046698, 60.52709433340258, 61.4129969381517, 65.83562620224492, 64.29717063903809, 69.60172914689588, 71.07166090319234, 73.15879329558342, 64.84896967487951, 53.611214391646854, 65.30427840448195, 63.39619828808693, 70.86766627527052, 68.97176511826055, 75.56250802932247, 69.2774668047505, 74.01166562111148, 67.03148626512098, 67.94082503164968, 72.0719829682381, 69.13982299066359, 67.44750069033715, 67.46009934333064, 63.07821173821727, 55.673286761007006, 50.969545149034076, 50.63329996601228, 50.81863980139456, 52.552045006905836, 49.18601597509077, 53.420132206332305, 65.15869571316627, 67.59950037925475, 70.85569520150462, 63.76768596710698, 64.4364030130448, 70.00002230367353, 71.38129280459496, 70.91569962040072, 70.90767445102816, 68.27855679296678, 70.58901325348886, 65.99939300167945, 66.60204948917513, 69.32967355174404, 68.50890974844656, 70.05205646637948, 68.6096989723944, 66.75934437782534, 54.612281707025346, 57.208255337130645, 55.846169148722005, 61.01733569175967, 67.10469338201708, 70.87123563212734, 65.1546399824081, 64.97312838031401, 4.757870320350894, 0.22571997747065561, 1.5997874592581105, 1.9777048835831306, 10.82631532222994, 1.1524368510130913, 1.9256413031008937, 0.7194228121830571, 16.587493611920266, 79.53404118937831, 30.867584328497614, 49.276834534060576, 81.22975241753363, 8.828863020866148, 0.9211868372175002, 0.20188224772291802, 0.17226311288052992, 0.1989158633495531, 0.11888893982095104, 0.1032409044883905, 0.17044397581729198, 0.07635678780535538, 0.11832364354162447, 0.13518385979677403, 0.13444896697277023, 0.15490781996519337, 0.13473986587937803, 0.09040785923359856, 0.17037259174450753, 0.19390281379943897, 0.1129395393053851, 0.08346280488636225, 0.404574801965106, 0.11053789962804127, 0.11389436831157054, 0.16659413884964683, 0.23822502984154612, 0.14380706804654292], [0.10072098083553777, 0.06261848709395816, 0.08613600741110503, 0.041354368440806866, 0.08365697753165038, 0.019294914541645877, 0.054935180627170115, 0.07002391431841158, 0.012848461816658177, 0.05422866369988169, 0.029625861094363277, 0.06103939219047466, 0.055225351750249826, 0.025544958602216457, 0.04286658769894031, 0.013989664693062585, 0.021828493711748914, 0.12182361581512999, 0.06794257600220942, 0.03316668117599141, 0.049061113367638284, 0.015371804136873014, 0.09058974382858123, 0.03915174308443262, 0.11376053275119875, 0.012370331978966153, 0.011823896784335377, 0.05470028657826686, 0.08662630368264453, 0.15486502629374305, 0.38702207286992385, 8.56943549648408, 68.93591465488558, 52.05031894868421, 26.107278216269712, 58.02807777158676, 35.849898553663685, 0.03458757126223176, 0.3206852018352478, 0.7797629001640505, 0.27762275609758597, 2.2658630340330066, 15.580901638154062, 3.5909090551637837, 0.2682846345968785, 1.0352180441541057, 41.65080555023686, 81.15125794564524, 79.62289071852162, 85.72529069838986, 81.95967412764027, 80.65257564667733, 78.1501897688835, 81.56284793730705, 75.09954283314367, 73.37890886491346, 71.47906964825046, 71.48412950577276, 65.69271072264641, 62.69116793909381, 69.4840580417264, 72.59578412578952, 73.84020313139885, 74.81793234425207, 72.08855105984595, 66.22899286208614, 71.1342776206232, 69.260451562943, 68.36818295140421, 61.69043794755013, 51.83167034579862, 48.544120096391254, 50.23955675863451, 52.52486690398186, 50.98476786767283, 51.235081764959524, 51.03439369509297, 52.41110640187418, 52.78359428528817, 51.89446356988723, 62.63816102858513, 61.50448622242097, 61.962666126989554, 60.2670019672763, 62.903081832393525, 60.72078097251154, 64.96571117831816, 63.54627209324991, 71.08180415245795, 53.215160908237586, 48.26228211002965, 67.53480480563256, 65.07449419267716, 66.18073201948597, 66.04782642856722, 67.34405994415283, 67.6215519443635, 62.789941064773075, 57.49055616317257, 69.54949886568131, 63.48501251589868, 67.40466056331512, 63.02731898523147, 62.150943817630896, 52.68796297811693, 46.08736315081197, 45.90210960757348, 47.94261286335607, 46.61530240889519, 47.77173872916929, 48.53704806297056, 49.25976830144083, 57.16810987841699, 61.26497061021867, 66.31282960214924, 64.76903569313788, 66.01082278836158, 64.58423322246921, 67.0215077554026, 66.33608925727107, 67.25304526667442, 65.96744137425577, 64.17122333280503, 59.52117504612092, 65.13326698733916, 62.03250000553747, 65.2463371522965, 63.38533332270961, 66.1764331017771, 61.44603113974295, 62.908141689915816, 47.5603739676937, 57.317685542568086, 60.82569260751048, 66.54258635736281, 58.146603953453806, 71.90141477892476, 10.29462137529927, 0.040701431702942624, 0.2765008050107187, 0.3448840194652158, 1.8887129233729456, 0.9084518818605332, 0.23005116280288468, 0.08313762354514292, 0.7601149512394783, 47.520412860378144, 39.51297652336859, 17.854597645421183, 60.04914568316553, 27.192664723242483, 0.18994091349023004, 0.08029191334161066, 0.09487543119898728, 0.07409891218788202, 0.04715777175020307, 0.048005677864796696, 0.05304362144201033, 0.04055317836783586, 0.05659933427288648, 0.007362704416136108, 0.029001041698539932, 0.12208036252207334, 0.04852048511947355, 0.05928752147742818, 0.013836465302794693, 0.021535608722197435, 0.012935236595841426, 0.03296975827505512, 0.09087325764759895, 0.05042818960763755, 0.03162708576588381, 0.018929165014396274, 0.01791523424007239, 0.025197392171849648, 0.009335517759374794, 0.020383427805838086, 0.011489167114749793, 0.043920835765499266, 0.08254277925457686, 0.01104683943858911, 0.021682358609752792, 0.12327113894805794, 0.12411031166031478, 0.05762835123365926, 0.036789330939251574, 0.02011253528537289, 0.06415763817306969, 0.02959091024803779, 0.05582196570392098, 0.05190948572670741, 0.055745625042266427, 0.0316960068659917, 0.048516248653252284, 0.07414929779066194, 0.013390385711024846, 0.03755436166219654, 0.01668736192157432, 0.08495114518389588, 0.03241870740068055, 0.054007390694272135, 0.03461918771086681, 0.03903347060024258, 0.0164222457040582, 0.1402885487843906, 0.061288681031475147, 0.4186445582778223, 15.085982853366485, 83.16455564191266, 39.90689231503395, 34.278200903246486, 80.60203198463687, 33.262232503583355, 0.31272888844532354, 0.4140296139784398, 0.4343639163961334, 0.451446604584494, 2.002183292661944, 10.778114295774891, 5.810208407140547, 0.3527820182423438, 1.879475128746802, 48.91196389352122, 84.61627975586923, 81.76051185977074, 87.27693327011602, 81.80770581768405, 80.65201082537251, 82.70734064040646, 83.62777971452283, 74.98149518043765, 76.70816959873324, 74.4014472346152, 73.19256490276706, 65.82938963367094, 65.35827767464423, 70.21052022134104, 76.33050026432161, 74.77297413733699, 76.41614129466396, 73.09298376883231, 69.23499538052467, 71.8876080359182, 71.34049231006254, 70.53226440183579, 63.79953953527636, 55.2937033099513, 50.800647889414144, 52.85532659099948, 54.39054619881415, 53.350921984641786, 52.340527272993526, 54.16326838154947, 54.48713848667761, 55.61146236235096, 53.384513162797504, 62.89185600896036, 63.67825592717817, 64.06711970606159, 62.537905246980735, 66.21604119577717, 62.277420643837225, 66.81686201403218, 67.24716171141594, 73.34648655306908, 56.33272347911712, 49.859659517965014, 67.27349650475287, 63.336393910069624, 64.93930185994795, 65.49703544186008, 67.62250900268555, 69.0416774442119, 66.61951188118228, 59.04805483356599, 69.84828933592766, 66.51332547587734, 66.73922261884137, 66.27206048657818, 64.93791726327711, 57.34522058117775, 48.688314268665934, 48.576797362296816, 49.597123515221384, 50.78118901098929, 49.44626915839411, 50.66110564816383, 50.79947510073262, 57.82369090664772, 63.90428250835788, 69.93744480994441, 67.24357666507845, 66.16818827967491, 67.75284936351161, 67.95371394003591, 66.5073948521768, 67.20486287147769, 68.52662317214474, 67.15213837162142, 61.55708128406156, 66.88290688299364, 64.28849435621693, 65.84798951302805, 67.23591235376173, 67.69486888762444, 63.18440206589238, 65.76438419280514, 50.99751557073286, 59.28638196760609, 65.15778964565646, 69.5989756430349, 60.48662331796462, 75.4302849308137, 12.574476484329471, 0.036528290309492624, 1.0216232317109262, 0.7655731131953578, 0.36055597206277235, 0.7377314555548853, 0.11571830108521447, 0.2033534889379817, 1.8201614147232426, 50.352266065536014, 59.13433521024643, 16.04532987840714, 59.26741730782294, 39.350770827262636, 0.2504208738044385, 0.05659350051334309, 0.13654515207294496, 0.025687316890745878, 0.03357419015599355, 0.006477630588286106, 0.04512350570650832, 0.033252061675152475, 0.026318680592662385, 0.0158656943183873, 0.10815080029950028, 0.031442780333060416, 0.02027491719702319, 0.04082859080705432, 0.030059957155777566, 0.01764173702066464, 0.08817114296459383, 0.02970748584747555, 0.07480231113731861, 0.07014283414689765, 0.05382234598660181, 0.07626232150341235, 0.03019148487627747, 0.00579827961759762, 0.008708243051754131, 0.14614271691008923, 0.12777586617777426, 0.1356941969284127, 0.1441401324325031, 0.24578699181156777, 0.11311791521767456, 0.33077951340425404, 0.24418407540407874, 0.22570041158506948, 0.13108550390649226, 0.10803703624274462, 0.1180447722154279, 0.2184671779433566, 0.12938057523100607, 0.13482488631721468, 0.11902099805733851, 0.20324312631160985, 0.17116799019277099, 0.1825648504159143, 0.1242722703083869, 0.0758415860153975, 0.11596026229521922, 0.21032738649556715, 0.15795896430650067, 0.2324594214798943, 0.15194879003590153, 0.23726855374632344, 0.1840787627283604, 0.2963236977736796, 0.33060380347794105, 0.8482975548794194, 23.474455879580592, 94.34269874326645, 67.44988549140193, 41.95393808426396, 75.55103117419829, 51.92978059091876, 0.29901229866570045, 1.1472186277950964, 1.1542661464022053, 5.896794238398153, 9.170800543600514, 30.926580698259418, 9.533767854013751, 0.32346968629187156, 1.7782553020984897, 48.98355499390633, 86.81752958605367, 83.96961427504017, 89.76012306828653, 87.66422025619015, 83.86712274243756, 82.76986322095318, 88.60245120140814, 78.2653505571427, 79.45051823892902, 76.9598759374311, 77.17445312007781, 70.51328013020178, 69.35461198129963, 72.73237674467026, 78.73234794985864, 79.73123442742133, 79.11663824512114, 74.84649504384687, 71.32354767091813, 74.33915215153849, 75.15390688373198, 74.25697849642846, 68.45515758760514, 57.92448013059555, 52.217003991526944, 56.90324398779101, 58.8216007140375, 57.34878601566438, 57.55582048046974, 57.84089834459367, 60.64429475415138, 59.57326019963911, 58.28014496834048, 66.97123865927419, 66.82785249525502, 67.9670343091411, 67.95841293950235, 68.13805749339443, 65.20870201049313, 69.184083015688, 68.39385094181185, 77.29756063030612, 57.95105026614282, 53.024721991631296, 67.9297717925041, 64.78791406077724, 66.56666971022084, 69.84881493353075, 68.90502991214876, 73.10999116589947, 68.04524637037709, 63.40580417263893, 71.03602224780668, 67.87497628119685, 71.12062777242353, 69.98168130074778, 67.97811892724806, 58.96566937046667, 51.19736817575271, 50.57835932700865, 53.446302260121996, 52.41325978309878, 52.548157938065074, 54.31657814210462, 54.839214355714866, 60.69921970367432, 64.4095386997346, 72.70107623069518, 70.1642676322691, 66.83244951309698, 67.55006282560288, 71.50387471722019, 68.75282625998221, 70.9210418885754, 71.01258216365692, 69.65143342171946, 65.05301137124339, 70.19661934145036, 67.15339353007656, 68.202101953568, 68.27152006087765, 72.24803463105233, 66.80852305504584, 69.82477080437445, 54.50728770225279, 64.51118692275017, 67.14340717561784, 73.72804687869164, 63.37512731552125, 78.75781982175766, 12.13238614220773, 0.1383297845360733, 0.7907702353212142, 1.0198133030245382, 9.580049860861994, 2.613362477671716, 0.7448762366848608, 0.5511421614116239, 2.1934210244686376, 64.65520066599693, 51.206346481077134, 30.952227115631107, 72.55970616494456, 49.563999099116174, 0.33402358932841214, 0.19525826848562688, 0.25143200261217935, 0.2076714209491207, 0.17703227067907013, 0.11148061678414384, 0.13364915585806295, 0.17274521201127963, 0.18763486626407794, 0.0921714089570507, 0.19009489716301042, 0.4126747415190743, 0.18138380330656806, 0.1712357889740698, 0.16265175846074859, 0.11127800184993014, 0.1937886513769627, 0.1368012859095489, 0.19688969868565762, 0.17825528408490843, 0.13445981477777805, 0.1483840603501566, 0.11518914117327622, 0.23127169408384832, 0.07087192768531461], [0.04067718118969952, 0.044202545447455305, 0.031093024806449973, 0.06024757520325723, 0.036281541049961126, 0.06305868121524973, 0.08526619118187698, 0.028799307765439156, 0.045541977404706904, 0.059885184971555594, 0.0814418726029896, 0.03270567627623677, 0.007811749246977871, 0.04927435777180138, 0.03724069079203952, 0.01713912588574233, 0.03334125729217645, 0.017921359113027013, 0.06476225391510995, 0.06723895488727478, 0.053354488430364486, 0.04913892874854708, 0.03529945463542977, 0.010658199204162005, 0.10586304725297999, 0.09338326046183225, 0.07926152508345344, 0.05636964962186833, 0.05621076681681218, 0.044370981368927226, 0.10900102766050447, 0.45171632882087465, 43.96339970250284, 59.7693943977356, 46.19063523507888, 38.397305396295366, 67.90110711128482, 6.379044748121693, 0.21393423569538902, 0.6480791888410046, 0.9642766476158173, 0.8607268105110816, 12.392278467455219, 4.146689051581967, 0.6977886117754445, 0.1081351261405695, 3.86755284282469, 51.90921168173514, 76.7964856855331, 77.91829139955583, 79.58461623038016, 79.91401687745126, 82.92208256260042, 74.86161185849097, 79.55846186607116, 78.18997829191147, 70.94846710082024, 70.2713797169347, 69.42464197835615, 72.37987333728422, 75.71283678854667, 71.27780498996859, 76.2107659924415, 73.40274903082079, 70.2429739121468, 67.92605338558074, 74.27046360508089, 71.27957005654612, 67.73806987270233, 57.290621188379106, 51.15716388148647, 50.40879526445943, 53.49263329659739, 52.33657744623, 48.994474872466064, 50.114582200204175, 53.147629460980816, 53.59315972174368, 53.1196629616522, 58.15190699792678, 67.37944756784748, 65.59058004809965, 67.85141068120157, 66.21865349431192, 67.71362566178846, 62.58792331141811, 68.33801208003875, 64.58601397852745, 75.36818596624559, 55.93292020982312, 52.55399442488148, 71.99519864974484, 65.38880548169537, 71.45222494679113, 64.5829035389808, 68.93772678990518, 64.8763164397209, 58.55584052301223, 71.04911511944186, 68.24927237726027, 67.26336894496795, 69.44674061190698, 62.87442891828476, 63.270729511014885, 47.11741678176388, 48.155162180623705, 46.14953664041335, 49.454941518845104, 46.730039581175774, 51.29711797160488, 48.21006751829579, 49.33801566400836, 52.7223111737159, 63.52548353133663, 67.4416563587804, 68.09636269846271, 66.97113667764972, 65.44715858274891, 65.45916888021654, 68.42115063821116, 65.8436199926561, 69.82127205018075, 61.660227852482954, 63.06249087856662, 61.66863349176223, 64.45837613075011, 63.01882313143823, 68.3692184571297, 65.00941030440792, 65.41010787410121, 58.66245054429578, 56.75765345173498, 54.21927590523997, 67.03659319108533, 61.04461577630813, 77.6016306108044, 26.181609092220185, 0.1013772806993896, 0.20235293214359593, 0.16154062453537218, 1.9550594471154676, 0.2401784467961519, 0.14533869231179838, 0.06788944014378133, 0.062166073870274334, 24.1700372388286, 59.79386214287051, 15.242383441617413, 39.78729924848003, 56.571136905301, 5.725015017294115, 0.6300294831875832, 0.17135483903750298, 0.2580587091224809, 0.07280606220686629, 0.05683622781127211, 0.045963540267679966, 0.02032738272851754, 0.05815108749835242, 0.05922751381031929, 0.05853819555693096, 0.079595769244817, 0.047872390057290756, 0.04262748016645351, 0.02636541961692274, 0.005474799949180095, 0.017658550735382784, 0.05225987136063557, 0.04405425763839195, 0.038305108675793294, 0.021518406217857715, 0.059297296759342, 0.06132417771544668, 0.05191208276477072, 0.057290778420264685, 0.03191107455941458, 0.018581866714802962, 0.032479726303849495, 0.027486405433005387, 0.057640168139891285, 0.046344278305168116, 0.01860632981744505, 0.05676022805874387, 0.09849019408706697, 0.07823823079947503, 0.06542044601613475, 0.03145092384769552, 0.03403328366637711, 0.04663326582240482, 0.060569845410364295, 0.022372349105294675, 0.027332647756162672, 0.03047907619827217, 0.020978408077010707, 0.03434197113458668, 0.06944587799690424, 0.051052087782731945, 0.025838431564249822, 0.10959870647639038, 0.043130999115566095, 0.06555191436482054, 0.006346000882331283, 0.019524011220182144, 0.009045627215997347, 0.0546849380067039, 0.03545928355907241, 0.09690941762058966, 0.9269354997142669, 59.896200703036406, 62.89433886927944, 30.57624440039358, 58.939330654759566, 78.62307856159826, 6.291073829896989, 0.22569929309670003, 0.18925085213155518, 0.8963509408697006, 0.6689807027578355, 2.895577011569854, 2.9250342567120833, 0.9165782974131647, 0.2804811527171443, 5.826416621285101, 61.46494480871386, 80.4231091468565, 80.1094921173588, 81.82995350130143, 83.13992315723051, 82.51304211155062, 77.94214725494385, 83.37480252788913, 80.90923201653266, 74.77814382122409, 73.73493456071424, 75.47495288233604, 72.56175364217451, 75.14001384858163, 73.97107693456834, 80.37148291064848, 74.74398782176357, 69.70256543928578, 68.18176054185437, 75.00444889068604, 73.76108892502324, 69.93925694496401, 60.94378732865857, 54.04537370128017, 53.73169391385971, 54.067723366522024, 52.42691355366861, 51.65508524064095, 51.880923548052394, 53.957579289713216, 56.271812992711226, 53.97712446028187, 58.655398122725956, 70.95074992026053, 68.2217530281313, 69.42671298980713, 67.5989120237289, 66.99980920360935, 65.63187868364396, 71.2236213684082, 67.84278931156283, 74.830381947179, 57.044821939160755, 52.70684134575629, 70.86162582520517, 67.3398708528088, 71.85877861515169, 68.01535790966403, 70.32353155074581, 68.79765895105177, 61.84581087481592, 71.48900108952677, 69.70860588935115, 67.7817964553833, 73.10061670118763, 66.02385290207403, 64.76586249566847, 51.306876828593595, 50.065536883569536, 48.31002127739691, 51.87631476309992, 49.210448418894124, 52.21650977288523, 51.59896396821546, 53.35702911500008, 54.98762899829496, 65.11987209320068, 67.39810236038701, 71.04438474101406, 66.34354960533881, 64.85469241296092, 65.21937085736182, 70.33119586206251, 68.99206730627245, 68.68769138090073, 63.83003204099594, 62.83621326569588, 64.7229007751711, 66.58792111181444, 66.05716951431768, 68.29403446566674, 67.20736534364762, 69.40649709393902, 61.795682984013716, 57.044504227176795, 58.576295683460856, 68.89455718378868, 63.80961218187886, 80.7784366607666, 29.326361533134218, 0.12469163449901728, 0.3771684354832096, 0.6955953939787803, 1.4907936175023357, 0.6866778853920199, 0.07489953535578905, 0.24014748152225251, 0.15193780433506737, 25.160159180241248, 79.2738546863679, 23.14702230115091, 30.332771116687407, 71.3464621574648, 7.532730016016192, 0.5961994694605951, 0.047207682378469944, 0.042234147643490184, 0.019781610199941263, 0.041671946359377716, 0.020296718144128402, 0.03419185620582393, 0.06794161839230407, 0.06200625643795056, 0.06177282178654306, 0.0370982597251573, 0.009073471639215226, 0.02740833149742215, 0.0296167733763615, 0.029227368969229922, 0.07638700997396823, 0.028398333515431133, 0.056310086285755526, 0.02889069247870676, 0.062342059588240045, 0.07806335590899953, 0.1105600472299322, 0.020548808951711944, 0.045699278238199414, 0.025278917333531766, 0.19297917223265096, 0.1562987445222755, 0.16141939878223405, 0.11134382412438432, 0.14242555104917096, 0.15429101193383818, 0.14982648133750887, 0.15566442372097125, 0.21808425655528424, 0.17575909383594993, 0.10548608602895852, 0.11306938354767139, 0.17035849572670075, 0.1140541665916962, 0.14139163878656205, 0.09105534142544193, 0.11368730240651678, 0.23303288425649368, 0.2573694138517303, 0.17034317396821516, 0.15682565979659557, 0.22940620870119144, 0.15427688527251446, 0.12083744615196221, 0.1645050936889264, 0.13549912029937392, 0.13724040750774646, 0.23127377784300238, 0.0945880946012274, 0.2673828571794495, 0.17951660188696078, 0.9614312744909718, 73.58070696553877, 75.55623223704677, 65.42353022483088, 53.06278859415362, 89.83322820355816, 11.256151199340822, 0.8453792501841823, 1.086022788959165, 4.105929987084481, 6.099813176739601, 28.59782834206858, 9.634410969672665, 2.060379131186393, 0.25037280944806917, 4.677460751225872, 60.07883018062961, 81.23193325534945, 84.51269780435871, 85.09367142954181, 84.32978983848326, 84.75604949458953, 81.37899075784992, 86.04321449033677, 85.07221606469925, 78.7935604587678, 76.14540361589002, 77.86203676654448, 78.60878544469034, 81.53445782199984, 77.38670825958252, 82.51695663698258, 76.89765930175781, 71.7536041813512, 69.83021505417364, 76.75012327009632, 76.67451566265476, 73.05656848415252, 61.62049424263739, 56.21635460084485, 58.38067923822711, 58.194613764362956, 58.63393099077287, 54.29826459577007, 54.05404998410133, 56.845153685539, 59.34506062538394, 57.60652888205744, 63.70738344807779, 72.64529228210449, 70.43827656776675, 73.02486788841986, 73.09829465804562, 71.1317829931936, 70.03961470819289, 75.31068401951944, 71.6213732381021, 78.60074458583709, 59.97020406107749, 54.187634145059896, 73.13503942181988, 68.64587107012349, 76.57389902299451, 70.72948117409983, 75.64096327750914, 70.19846285543134, 66.90512318764964, 72.98525979441982, 73.33155801219326, 73.59809875488281, 77.03469122609785, 68.84085209138932, 70.18705660297026, 52.201687136004054, 52.73008138902726, 50.48602673315233, 54.43361774567635, 51.95018868292532, 57.88690774671493, 53.78370061997445, 57.34183165334887, 59.30058879237021, 69.77021848001789, 70.83568326888546, 74.3863304199711, 67.68319591399163, 66.55306693046325, 65.37438684894194, 71.03224108296057, 69.43487151976555, 73.65149005766838, 66.09530279713293, 68.0553033274989, 66.966704399355, 71.07013902356549, 68.49040400597357, 72.96813472624748, 69.92727018171742, 71.8304826367286, 65.20214380756502, 62.1707086409292, 59.88411195816533, 74.96727266619283, 66.98175061133601, 84.55819729835757, 28.234816904990907, 0.26281081380382665, 0.5071978258990473, 0.7017331678540476, 7.355874267316635, 1.8844733315129436, 0.15606429097392868, 0.39114911109209066, 0.16108803511146577, 39.433925074915734, 73.98080441259569, 26.728603224600516, 52.185821148657034, 77.66085840040638, 11.704590878178998, 0.9907609200285328, 0.43780193513920235, 0.3407678290480568, 0.24448758411792018, 0.2133828515727674, 0.14460248181656485, 0.1833500752165433, 0.17150994119865282, 0.19605535232732374, 0.15822599191338788, 0.1966585546371437, 0.19373710898141708, 0.1263014073934286, 0.14798816143264695, 0.11094386494087596, 0.2581061146432354, 0.2188465446834603, 0.1492962105980804, 0.10042422901718848, 0.17824368551373485, 0.23581819608807567, 0.2226373469156604, 0.19757347812335338, 0.21703326053196387, 0.10637971993175246], [0.011838019615219486, 0.0613311414546784, 0.007316193303033229, 0.06544477696860991, 0.036734773987723936, 0.08281824148951039, 0.031393712401510246, 0.028322046479931282, 0.03224227735171876, 0.06367663454805171, 0.10665048604771014, 0.01764578579534446, 0.011322014390551036, 0.03823632164107215, 0.038166653605238084, 0.011295012664049866, 0.01571736724731783, 0.03576281142511195, 0.004137977478920573, 0.03768530141021456, 0.056066527782428655, 0.032048357515445644, 0.0896011456666935, 0.024838342083497875, 0.0054563185568117815, 0.07886892800489742, 0.07561722950589272, 0.01858581781327244, 0.030893686813332384, 0.049246989280706456, 0.1458483399643052, 0.6752857289487316, 5.169257819652557, 62.5217293923901, 47.98530786268173, 26.305707000917007, 60.0934253200408, 47.20102602435697, 0.5497040611601646, 0.07142514275807528, 0.21469899062668124, 0.36764001774211086, 1.0912954350633006, 2.779230686926073, 0.5439320483034658, 0.4513246740304655, 0.25690937805319985, 8.775816886655747, 56.55332542234852, 76.54618355535692, 81.59358362997733, 86.7096487168343, 79.92092809369488, 85.43495685823503, 76.900326513475, 79.03183660199566, 78.89358089816186, 76.00785393868723, 70.39249466311547, 73.06223238668134, 76.17899479404574, 82.7924874521071, 75.25071097958472, 71.40166559526998, 68.82877903599893, 72.60295421846452, 71.20730430849137, 69.98681960567352, 69.41030179300617, 56.771130715647054, 52.773949177034446, 51.078159501475675, 52.98787916860273, 52.27580424278013, 51.90752506256104, 51.303448677062995, 53.275404591714185, 51.295105795706476, 55.833935276154556, 63.90964831075361, 69.52663144757672, 68.99474236272997, 70.29872648177609, 68.3076843138664, 71.71943249241, 66.45168150624922, 71.14966900117936, 65.92562890821888, 75.82853886388963, 41.96853714604532, 42.37729126407255, 77.85223868585403, 65.34873062564482, 71.01863830320298, 65.45359519220167, 69.50626650164205, 56.33484155901017, 71.79918212275352, 68.80270311909338, 69.14030936456496, 69.01635462237944, 67.99212963350358, 67.51582053399855, 53.52052134852256, 46.270337796980336, 48.99756570016184, 48.96464132493543, 49.159673337013494, 49.539143039334206, 51.314631354424264, 52.944835078331735, 48.88359339006486, 49.253982805436664, 58.08414020845967, 63.07933353608655, 67.8649507030364, 70.98098354954874, 68.39736538548624, 65.77375865751698, 69.49378551975374, 68.71928999500891, 66.98890501453032, 63.27754659037437, 64.21330252001363, 64.2131377804664, 64.10118549100815, 65.43084544520225, 69.30068723617062, 67.26318851594003, 63.782132056451616, 65.37841120073873, 54.49159822156353, 64.14089948900285, 70.5066042561685, 65.37947416305542, 55.715216898149066, 0.5794606321761685, 0.009140321429097846, 0.128496433157594, 1.4114698094706382, 1.3839171201952043, 0.11397611755397051, 0.19117382475205008, 0.2696797113505102, 20.215986082630774, 67.81475220957111, 19.732324500237745, 28.749445599894372, 57.830119671360144, 27.892990189213908, 0.059001556177052765, 0.005786735630188619, 0.027178553000633276, 0.060412977416549, 0.09527270907476064, 0.04886189603336877, 0.021076003848124417, 0.009234491829580117, 0.03514702995157531, 0.11182085941395453, 0.0554924636268087, 0.06643982559082008, 0.04467928962361428, 0.02772399228096249, 0.008668843149808387, 0.028944891284129796, 0.017154007143671476, 0.02919466276052258, 0.012941854637897304, 0.09609161876142026, 0.0372415105061185, 0.09836960418690598, 0.13693737376841808, 0.017564457901302847, 0.03479565606422482, 0.09318856687675561, 0.06595325250659259, 0.025792027703456344, 0.03263944797518273, 0.054650889228909254, 0.03443023595478266, 0.024238060483889236, 0.008765663256898763, 0.020043443730701844, 0.055488177364872354, 0.04128311843340916, 0.04164488430345251, 0.02693828484494119, 0.06143834013792296, 0.05359228595250076, 0.05185310548591999, 0.015563557859540228, 0.06012365665106524, 0.03175121690747479, 0.037282948201942834, 0.04732737978619914, 0.03881565265117153, 0.035465711036757115, 0.05523512703216365, 0.017300984942384304, 0.016917749458263, 0.020908807073870016, 0.12994829234817337, 0.07305530891303094, 0.03933209933400635, 0.10914048630624049, 0.01537149004082406, 0.5101143532703, 9.09488404950788, 78.75987514372795, 42.89143554625973, 30.676186392384192, 84.44528795057728, 47.181724040739, 0.9631777710972295, 0.2823826135887254, 0.2612209055692919, 0.5655797318585458, 1.503598562652065, 0.6148320760938429, 0.8780808470422222, 0.3407522621414354, 0.08341817260389367, 10.07418122983748, 69.84434343153431, 79.11710892954181, 82.98150647071101, 83.89475191793134, 81.89191910528368, 85.93352148609777, 81.191360258287, 79.59333958164339, 81.29792321112849, 76.69713204906833, 71.46218776702881, 73.67932319641113, 80.95493547378048, 83.00369924114597, 77.76775867708268, 73.22272792939218, 71.26344127039756, 72.89864601627474, 74.0642567603819, 73.53507411095404, 71.3846738876835, 59.62240357552806, 55.609089328396706, 53.38246960793772, 56.15381240844727, 55.29345620063044, 54.041337582372854, 54.30395203251993, 55.189003482941665, 55.26612120289957, 56.505613711572465, 65.59267851614183, 69.83002678040536, 70.99686914874663, 71.74932095312303, 69.64845242038851, 71.56348689909905, 68.73330854600476, 71.04821297430223, 67.5783117355839, 76.21226433784732, 46.45958039068407, 45.57469760217975, 77.79141841396209, 63.35000061219739, 72.95532426526471, 66.05498867650186, 70.79539268247544, 57.84626806935957, 74.4074406162385, 69.56452154344129, 70.81546737301734, 71.3536871633222, 68.11765332375803, 69.11884615498205, 57.40775100646481, 49.19973642595353, 51.96905528345416, 50.797341331358886, 52.70180894482521, 51.768782984825876, 52.86706232255506, 53.75329048402848, 50.787111789949485, 51.72758633090604, 61.34294732924431, 66.08475946610974, 69.94106907998362, 70.56267846015193, 68.10285814346807, 64.08586471311509, 69.70979828988352, 67.35497197797223, 70.72071075439453, 63.97134327119397, 66.22292103305941, 66.80226295225083, 66.5437787578952, 66.9492498520882, 72.39060494207567, 69.30529209875291, 66.44260514167048, 68.1383163698258, 58.84573505770776, 64.23824094956922, 74.65824480979674, 67.82253419199299, 59.241733627934615, 0.749492621229541, 0.10712926801774772, 0.5895173441498511, 1.4917842611189813, 1.3265666750169571, 0.21593300505511223, 0.22438882309342587, 0.42362272018386476, 23.832436876912272, 83.7999011624244, 36.63006582567769, 14.441063807856652, 64.13227027462375, 34.871400556256695, 0.08652493492850373, 0.011736876857016357, 0.04148486002738919, 0.06392155285744418, 0.03007310513977803, 0.040261145651100144, 0.06481077026335463, 0.016191653238849777, 0.02379755226654872, 0.04838550042721534, 0.05176357662064895, 0.05412170250389365, 0.046701432325907295, 0.030121667453298168, 0.04017832388560619, 0.0814902663771664, 0.07456099344117027, 0.05214956236041842, 0.06634407992204351, 0.03849789087149886, 0.03393390291039983, 0.04594655992883829, 0.0567554553309756, 0.022717082925561457, 0.03177718154244846, 0.04087626445858229, 0.1806173016948085, 0.18755257309925175, 0.27248518661625926, 0.1546761856204079, 0.17200638149534503, 0.28222424789301814, 0.151001782787423, 0.1310332107447809, 0.1362058823747981, 0.12072587310667, 0.18619731759592412, 0.11276449587556625, 0.14359328355039322, 0.12083700182096613, 0.13631091302921697, 0.12522274793516244, 0.13050802682916965, 0.14569388131701178, 0.2283709174803188, 0.30968742745537914, 0.1908074202196252, 0.10104234705889419, 0.19245659301598228, 0.17346216305609674, 0.13533989658519147, 0.14828088362851452, 0.17770573857330507, 0.2928771294893757, 0.121310398192896, 0.1647515748176844, 0.30985924565503675, 0.8772467305102657, 13.232664908132246, 93.38185141163488, 63.65499234968617, 42.34667324250744, 73.2830539826424, 66.31693240134948, 1.1056891852809538, 1.1791036974999214, 0.503108540489789, 1.244766993388053, 2.3631478653800104, 11.302135106055967, 1.270829059423939, 0.9384356439113618, 0.5077745368884456, 9.193148247657284, 69.60733813624229, 81.92954247997653, 86.4926867331228, 89.13816851954307, 82.80365836235785, 91.10927720223704, 83.70428162236368, 86.04487757528983, 85.21561791819911, 82.11625514491912, 77.40620243933894, 80.62669584828039, 82.35492352516421, 87.79514112780171, 78.91141983770555, 74.37227264527353, 71.55856824690296, 73.84898924058484, 76.4422329010502, 75.77034658001315, 75.58935273078181, 64.62338632152927, 61.56378461468605, 56.44009836258427, 59.58069309111565, 59.33186184975409, 56.46973579160629, 58.94031909204299, 58.11262053828086, 57.535330018689564, 62.836295635469504, 69.4410845541185, 74.55336847612935, 75.8413807038338, 76.5423474773284, 71.62111436167072, 77.68796982303743, 71.19336420489897, 74.50544495736399, 70.24576663970947, 80.68826137050506, 45.74763490307716, 45.32721957852764, 78.57622977226012, 66.14016686716388, 72.98012148949408, 68.41492975911787, 71.1530500842679, 61.483658436805975, 73.48627982601043, 71.10227892475744, 73.72793705232682, 74.26797682239165, 71.07948995405629, 73.61465115700999, 58.54039815164382, 52.64982185056133, 55.271710580395116, 54.12980664160944, 55.46562863934425, 55.969641439376346, 56.32609859589608, 59.175680914232814, 52.429529774573545, 54.78045725053357, 64.38423941212316, 70.08375706211214, 74.84979767953196, 74.84498100896036, 71.2378046589513, 65.94429154549876, 69.9376723074144, 71.66722574541646, 73.02018457843413, 66.9884813985517, 68.87296845836025, 69.29899277225618, 69.95436591486778, 72.26536366247362, 72.60184811007592, 74.73945356184437, 69.98851406958796, 70.03329969221546, 63.0497431755066, 69.83393346109699, 76.59835107864873, 72.18611609551215, 59.66291381466774, 1.2291505668432483, 0.30081517934318514, 0.5983112980761837, 7.367742869161791, 2.918330926087595, 0.27162765843733666, 0.2924617259733139, 0.467061621527518, 33.630684268090036, 81.87615117719098, 29.660488636262958, 43.32028396667973, 70.68734707370882, 47.103480600541644, 0.2396185437758123, 0.1196186232470697, 0.10495717892603529, 0.20072038345519574, 0.14892683364450932, 0.15491784039524295, 0.1823812038187058, 0.10554148184676325, 0.1496456386221032, 0.3556622943330196, 0.20884448542229592, 0.15163270215834343, 0.08379285088590077, 0.10160962750594463, 0.10960813701873827, 0.20692764150519527, 0.18585922767318067, 0.11060818053421476, 0.12938914009399954, 0.16316192705304394, 0.14008152118373302, 0.1950741775574223, 0.23995873277946828, 0.08514366307926756, 0.11751771138440217, 0.2130905583861374], [0.03888898258728366, 0.0480380182665202, 0.022451667933754867, 0.07131138636219887, 0.012112321226947732, 0.04509182797083932, 0.09019382192843384, 0.010212759295808933, 0.021665424236186573, 0.032523052406407175, 0.017262931439965483, 0.015068892971612515, 0.036892848570019975, 0.01849664134844657, 0.0265658799288494, 0.07479968345573834, 0.032897255713901216, 0.08834530539329975, 0.04915315500130096, 0.013295651278308323, 0.044590710707369356, 0.09983658595311065, 0.021854444940183914, 0.027442273022907398, 0.08635939864982521, 0.1230582967400551, 0.05568880047048292, 0.06437684274128368, 0.055836743539980346, 0.021736289284402327, 0.11997341388656248, 0.24021904945613878, 0.22130337333486927, 29.70231483059545, 66.75437081244685, 42.683408721800774, 21.15303247205673, 75.42554670764555, 25.822080719855528, 0.0660003592530566, 0.35130245731242243, 0.34583283468119563, 0.18414260849596994, 1.4946692869547875, 1.86689461671537, 0.0849760813458312, 0.1598672280388494, 0.0883771516683121, 8.915184582433394, 71.52620869298136, 77.58159514396422, 77.69536741318242, 87.60293714461788, 77.84397817427113, 82.79464475570187, 85.43450970803538, 76.55763687626009, 72.57809423631238, 74.52202873845255, 80.42358767601752, 79.87908424869661, 75.12175913779967, 73.00671515926238, 68.82309944398942, 74.23758629829653, 73.60049140068793, 75.1247166049096, 71.49719884318691, 59.45041941058252, 51.18322018654116, 54.54889620504072, 52.56318061582504, 55.16320605431834, 51.80519826950566, 54.03093545667587, 50.45824458522182, 53.860720280678045, 51.271646099705855, 55.24676038372902, 67.40910853109052, 73.63141536712646, 68.27152006087765, 74.21209089217648, 71.29722072232154, 72.39255828242149, 66.1125220021894, 78.0797596900694, 65.11875421770158, 73.59663178843837, 40.12106549355292, 39.90295817775112, 80.38782350478634, 66.63476205641224, 77.10603913953229, 69.95482090980776, 64.1589149352043, 67.75977626923593, 76.52262580010199, 66.61434219729516, 71.51543001974784, 65.88052165123725, 72.28714066167032, 58.20191721762381, 49.91398826722176, 48.62519156548285, 50.74796653562977, 48.68523520808066, 50.70889188397316, 51.38321791925738, 63.88678089264901, 62.207676979803274, 59.400115013122566, 51.94154770143571, 56.38289843836139, 62.46450201157601, 67.30900964429303, 69.10554147535755, 73.32570583589616, 71.53122932680192, 71.37477382536858, 72.73864469220563, 68.9776643629997, 67.42602179127356, 66.54186464125111, 65.38597745280113, 67.97680101087018, 70.20976712626796, 69.12228999599334, 69.84447679212018, 66.07576939367479, 63.88467457986648, 67.95406695335143, 70.22580962027274, 60.33303506912724, 78.10749084718766, 7.162133205321528, 0.7157747014876336, 3.2824043448894256, 1.3678281706187034, 2.0362157374620438, 0.38611842619795955, 0.32594654048162125, 1.0337929980408762, 13.851332510671309, 66.38287528868645, 26.52816814761008, 32.89058596857133, 50.72686418410271, 45.827627720371375, 4.255853516440238, 0.5694036750543503, 0.018625441795936035, 0.24393238487743565, 0.15042606771232622, 0.05126346293235979, 0.055523559135655244, 0.03237060090947536, 0.0526511469375222, 0.08328294276349968, 0.03304344444205204, 0.01734232113155867, 0.0533242815835101, 0.05695459988689231, 0.062277355802155314, 0.0538875975255524, 0.028391457876310717, 0.07352835288451565, 0.036204840326982166, 0.04748214103822266, 0.04389009265709789, 0.02032561306541245, 0.033284857899190924, 0.012624665508948028, 0.03409031508190017, 0.032369604995173794, 0.03511297734334104, 0.03999902100692834, 0.01928661589420611, 0.04291874296482533, 0.03022014614074461, 0.04069102056805165, 0.03701808862388134, 0.01793440942081713, 0.02330253880861546, 0.03653646063720507, 0.06021715002134443, 0.05183020711786324, 0.035564685766134536, 0.05919840246919663, 0.022540434541541244, 0.0024124254771102703, 0.07840667821226582, 0.04580321721732617, 0.03052712331766323, 0.043999026529490955, 0.012630120054968904, 0.08722442682952651, 0.036841601118325226, 0.04881896063565247, 0.008238856192497958, 0.11336054292417343, 0.07143468055273257, 0.10794780232132443, 0.10166680064773369, 0.03087625256739557, 0.02874510704479631, 0.18712454445419774, 0.048601866639669866, 0.15955307070286046, 40.817192062254875, 76.14585861083, 26.00529855297458, 40.44511995007915, 98.17163805807792, 22.00692069145941, 0.20424714582341336, 0.49217680288899335, 0.5512352564161824, 0.17027206568708345, 0.46722280642678665, 0.6438881363118849, 0.3332841919074136, 0.37960300161953897, 0.0961156815831219, 13.157838832947517, 80.55290037585844, 77.14626696801956, 84.81431238112911, 84.83615213824858, 80.48006196175852, 87.50457194543655, 86.73330060897335, 77.48904289737825, 76.9711958977484, 78.16339246688351, 84.09472219405636, 80.81951956595145, 76.85340712147375, 75.43074777049404, 69.96992987971153, 74.22030433531731, 73.52971615329866, 74.42586791130805, 74.82904834132042, 65.6318159257212, 54.16428819779427, 56.04105995547388, 54.4031919202497, 56.33771665634648, 54.8997365274737, 55.05849838256837, 53.118498017711026, 55.67271017259168, 52.95951650988672, 59.375015766389915, 66.47339574752316, 73.87851684324204, 70.1207842365388, 76.09154947342412, 69.99691578649706, 73.77307568826984, 70.3164477502146, 77.7537715050482, 66.50859509744953, 78.58620828197849, 40.84904170805409, 40.086328983306885, 79.93862582791238, 69.93207116280833, 78.77305430750694, 72.4523038248862, 68.57543314656904, 69.47178886782739, 76.4016991276895, 67.02477901212632, 72.3690083719069, 67.62417208763861, 76.03709128595169, 62.08461653801703, 53.53693254532353, 50.75872559701243, 53.58423240723149, 50.20886421203614, 52.33561646553778, 51.73945934541764, 61.98428623137936, 62.21702006555373, 61.713748593484205, 56.114431811917214, 59.57502134384648, 65.0697716589897, 70.00523121126237, 70.61326134589412, 73.22899587692754, 72.55343037266886, 71.1940388525686, 75.04736746511152, 68.89607906341553, 68.13820654346098, 68.04808616638184, 66.79323365611415, 68.91310214996338, 72.96000757525044, 70.18020029990905, 70.46993793979769, 70.53380197094333, 65.3276086622669, 68.79188522215813, 76.3285469239758, 62.74794816970826, 81.2818964066044, 10.713371653710643, 0.97230390074753, 3.027619190754429, 2.37060968433657, 1.5051546404438636, 0.5301253665839473, 0.3480711903783583, 1.1309786669669615, 22.212696075439457, 65.94286380275604, 42.55233880012266, 24.920121892806023, 47.19886872076219, 55.4393526815599, 6.766957352238317, 0.603640757260784, 0.11055509064106211, 0.19756730345468368, 0.12214065364171421, 0.06944586267514576, 0.03343904458527123, 0.08769965415159542, 0.04446641294165485, 0.020401915422670787, 0.02524186549107394, 0.025737811661055012, 0.04728095485798774, 0.057488417613410184, 0.0176125931208052, 0.05221322426692613, 0.04492102100724175, 0.0778739789741174, 0.07511902720697465, 0.054668861651612874, 0.05833888629211053, 0.028613977690017032, 0.040182376490725626, 0.014680511291859853, 0.12191827363905408, 0.03523903328084177, 0.007937764007252672, 0.179566964507103, 0.2687447776477183, 0.1452348567545414, 0.219602259777246, 0.1577777232253744, 0.18526599982813483, 0.16575242272548138, 0.12740628238046361, 0.14104293088518804, 0.1189410491215606, 0.12472577137692321, 0.13980180716081975, 0.12997153545579604, 0.13148875726807502, 0.11350079064047146, 0.23385849721249075, 0.16752018593251708, 0.20095784006820572, 0.16151381145802238, 0.16150933750454458, 0.21687855673653467, 0.1366602031574134, 0.13762496832397678, 0.15801000108401622, 0.4009071407058547, 0.16282962875500803, 0.19620512251652059, 0.17480983428897398, 0.19881359061166165, 0.11430412575963045, 0.3720044206467367, 0.27802222498482276, 0.4418324769264268, 53.38910625826929, 89.3257676401446, 64.6515057932946, 36.56653911836686, 90.7463873586347, 40.23882289086619, 0.17007531898636974, 0.5784514798752723, 1.2653656880701742, 1.9067378077776203, 2.9634457826614384, 6.037535744328653, 0.33340698047991724, 0.5454816909567003, 0.18979834452752145, 12.679870570859602, 82.7817480025753, 81.86361528212025, 81.00881315046742, 89.06631854272659, 81.50389471361714, 88.53460204216742, 91.37575518700385, 81.30863912643926, 79.77127398214033, 80.84329697393602, 87.05155388001474, 84.43086931782385, 77.24239641620268, 74.00282459874308, 72.28468525794246, 79.48458794624575, 77.21976434030842, 80.03339029127552, 79.21507404696557, 65.63052154356434, 56.33310394902384, 59.25918425283125, 58.324169651154556, 60.08251328622142, 59.70676591319423, 59.73816840879379, 55.439474275035245, 58.74720511897918, 55.210753025547156, 60.77758473734702, 71.9809918249807, 77.07033772622385, 75.8749169688071, 78.11620635371055, 73.77760210344869, 76.45398432208647, 71.14723713167253, 81.5883747223885, 69.73773341025077, 83.81952870276668, 48.09474591285952, 41.71550504622921, 83.89552854722547, 72.05345369154408, 83.69522094726562, 74.55796549397131, 74.13474959711876, 70.77390593867149, 79.24665697159307, 72.39995587256648, 77.3929448281565, 72.17948728992094, 78.72231452695786, 65.53609832640618, 56.38491061425979, 53.939928623937796, 56.245446820412916, 52.788485480893044, 55.17469859892323, 56.37713647657826, 67.06197877084055, 67.80277329106485, 66.19944956994826, 60.51537036895753, 62.942246698564105, 68.18576135943013, 72.31286356526037, 74.58398649769445, 76.30741319348736, 73.89396313698062, 75.39649763414937, 76.50483392900037, 74.30328599868282, 73.68641484168269, 72.78317928314209, 70.25539213611235, 71.47234670577511, 75.93033221460159, 75.19418962540166, 73.77455049945463, 73.1555377283404, 70.20892773905109, 72.5362817702755, 77.0902947456606, 67.0362558672505, 80.62067893243606, 10.066249216756514, 0.9285238144859191, 5.26546718612794, 2.6186608643301073, 4.244282524431906, 0.6972142296933359, 0.37433587134845797, 1.6300154501391997, 24.8336414752468, 81.29940586705362, 34.07297465109056, 44.54456944619456, 64.69407527677475, 66.2011597233434, 9.495844418002713, 0.8593003547960713, 0.20544651775590836, 0.4893676810447247, 0.36147926122911517, 0.25843133428885096, 0.18265877279543108, 0.18107433442867574, 0.13381607109500518, 0.21423949108969784, 0.157063729279945, 0.15026238536642444, 0.14432210895803668, 0.1640181069172198, 0.13824071915399644, 0.16456166162125527, 0.14690569451739713, 0.1416263374830446, 0.1953925177334778, 0.14684785487911395, 0.1804395846181339, 0.13188375220183404, 0.15060622094860002, 0.09337799743779245, 0.14256497905139, 0.12829103732421515, 0.15024150180960857], [0.09883088870875298, 0.05132921242846116, 0.06511341329784164, 0.03134547950579755, 0.055950917453775485, 0.04950449058425523, 0.02523776309023942, 0.0245455471092775, 0.06473157209374251, 0.11126078785427156, 0.0450356622346707, 0.0052167054062949554, 0.010744565083915669, 0.07625298289161536, 0.02093725574893817, 0.015461605920967077, 0.04922515960530408, 0.015915043787249637, 0.021429484477266673, 0.016118013037128315, 0.011579724453059177, 0.06116865037549889, 0.05710279959584436, 0.04489988464141085, 0.043505424588558175, 0.017886346979667584, 0.05588717893847535, 0.010452521833470993, 0.070950030349195, 0.050150103521563356, 0.17277974725490616, 0.017059109917271043, 0.2582009563282613, 2.356577895341381, 55.60453153425648, 60.063309361857755, 31.708995488382158, 26.169277160398423, 84.67986922110282, 16.070802730898706, 0.30000858068946873, 0.391595893569531, 1.215617164008079, 0.39144564840582113, 0.6534497103383464, 0.5253542322785624, 0.04402121243577811, 0.27134374625259833, 0.07061376371571133, 9.830539284213897, 78.06155204772949, 79.87869985641973, 76.44289185923915, 91.2740481284357, 80.33941361211961, 81.32723116105603, 84.27205254954677, 81.90211726773171, 78.4257911866711, 80.46412144937824, 77.89712629010602, 79.22320904270296, 74.56210751687327, 78.90625015381845, 78.98695684248402, 77.42843443347563, 70.38075108681956, 59.54822371082922, 53.521682370093565, 57.26340386175341, 58.12312856797249, 57.38381278130316, 54.32428167712305, 52.15654850006104, 54.226175354373076, 53.52351019459387, 54.38940086672383, 54.93240202626875, 56.04120900554042, 72.02782492483817, 73.61065818417457, 72.28910969149682, 71.80821926363053, 69.12398445990779, 72.5028004184846, 74.29511177924373, 71.03995246271934, 64.6334707352423, 59.171350617562574, 32.898081617970625, 42.291273686193655, 84.4262566105012, 67.30402823417418, 74.83991330669772, 63.54407556595341, 70.23906723145517, 73.42822874746015, 71.33747208502986, 71.4084199167067, 72.0949915916689, 69.09095025831654, 64.28164589789607, 50.949262572873025, 51.08914213795816, 49.28314170529766, 51.22070627827799, 50.17054265545261, 50.29674099337671, 60.60460036800754, 75.07508293274911, 70.5679658151442, 67.06983135592553, 56.75244062177597, 55.45084130379462, 56.73132650313839, 65.4820833667632, 68.87025417820101, 74.09731449619417, 68.75956489193824, 72.46027408107635, 71.81581297228414, 72.80155950976958, 67.34036507145052, 71.72020127696376, 68.4049512493995, 71.2527096656061, 70.44533683407691, 73.18337086708316, 64.19898194651451, 70.87705642946305, 70.69888668675577, 70.02781621871456, 62.55228465603244, 93.50036190402125, 18.174004093293224, 0.3716839507462517, 0.1273788257892574, 0.26899792374141757, 0.09094785928966538, 0.23562034622075098, 0.4337693708798578, 0.9695883335605745, 14.907253192317102, 63.030833428905865, 60.229104026671386, 91.74896086415937, 55.459776463047156, 45.667281227727095, 35.027346149567634, 0.3202835266147891, 0.07224608257773422, 0.11163609432837657, 0.04729627278603373, 0.02737724939511428, 0.0515083161242787, 0.04126534519356586, 0.052880682201395114, 0.02087514325525732, 0.03295219570939099, 0.020857946496577035, 0.04622754565770588, 0.016276738794159987, 0.06279785509010957, 0.05724850568860289, 0.03431014401177245, 0.06651702427094983, 0.02182042297546662, 0.014037434105581094, 0.08304168635438527, 0.01883812121025497, 0.033074290972323186, 0.043528748135412895, 0.027764539399574843, 0.028444607141277486, 0.04971323039142355, 0.022975951696055073, 0.08150271530593596, 0.027055243488341093, 0.047637093812227256, 0.04264421918759904, 0.043059082611674265, 0.07008926927923195, 0.053403242265865694, 0.024504538422690767, 0.04873357247561217, 0.04963810780956861, 0.04642975456531971, 0.05898970479686415, 0.029590063720881462, 0.11868519107660941, 0.08442506494541323, 0.020083370318095532, 0.014979504874997563, 0.020966776947100318, 0.009401679985345373, 0.041042677907934116, 0.04531874704445082, 0.14525730313072283, 0.061764827659053195, 0.06626816826962656, 0.04505920028614421, 0.04328613192023289, 0.07002641176504475, 0.05038916891921432, 0.10601239609381846, 0.014227549357700252, 0.165692146927599, 0.04688468821827443, 0.29444721136843005, 4.42670411640598, 71.98804424655053, 58.468881576291984, 15.645728611177015, 58.36140471120035, 98.85833524888562, 11.823952524892746, 0.714266611443412, 0.794754566684846, 0.7738738290725217, 0.1533677840545293, 0.862906851595448, 0.1544089741524189, 0.41503953236726027, 0.46514545176779076, 0.06493316813101692, 14.51762455125009, 87.83463939543694, 77.3433425349574, 81.4864166321293, 86.88902654955464, 79.17898824138027, 83.14641860223587, 88.55178986826252, 83.24216365814209, 80.24341752452236, 79.39830364719515, 80.77517324878325, 80.69656110578968, 75.53682434943416, 76.95580451719223, 81.50552641960883, 78.13370012467908, 75.30442391672443, 63.83018501343266, 56.493470053518976, 57.542555024546964, 59.20419654538555, 57.61549149790118, 56.80847167968751, 55.67018024383053, 55.598412636787664, 55.4419610577245, 54.614635129128736, 56.937482357025154, 57.713131058600645, 72.3247875705842, 75.17882177906652, 74.51922816614952, 73.4134021882088, 71.34000593616118, 74.07609447356194, 71.81555409585276, 72.78259092761625, 63.95873285108998, 64.49676828999674, 36.847345521373136, 41.820648101068315, 81.75661302381947, 67.79782325990739, 77.14718480263987, 64.13137597422447, 71.70797917150682, 72.35233829867455, 72.1416364177581, 70.91857864010719, 74.0985147414669, 71.64049871506231, 67.9896899192564, 54.176023929349846, 53.76771303915209, 51.91405188652777, 53.875550762299575, 53.679122386440156, 52.4808539882783, 61.47136180631576, 76.68878524534165, 69.92270454283684, 66.38238891478508, 56.782897826164, 58.54664256495815, 59.72274957164642, 67.46075830151959, 72.43714778654038, 76.84537410736084, 67.80163580371489, 72.54626812473421, 69.75420736497449, 75.02619451092136, 70.30841473610171, 75.58445761280676, 68.9685409299789, 72.08178889366889, 69.42191200871622, 76.6167469947569, 65.49076357195455, 70.46014770384758, 73.20674034856981, 73.1111914111722, 62.6747057514806, 96.85718121067171, 21.81545215268289, 0.33338289467557786, 0.08819828545975109, 0.7046512274011489, 0.21260213136913317, 0.3500528146903361, 0.4878767207264901, 1.7062631393632584, 24.930494600726714, 55.50207530298541, 70.48807497947448, 62.010781841893355, 46.06638239276025, 51.41022343789378, 41.93805248506608, 0.4058859461257535, 0.054638658635198116, 0.12379329681636826, 0.03218708454721397, 0.01449210441581184, 0.10484177544112168, 0.056370499979464285, 0.1110531320615161, 0.062306693139215635, 0.05518942988748032, 0.027713410691508365, 0.025645651283764073, 0.018288895540360003, 0.040970002976997245, 0.030591110811538758, 0.06888438917456136, 0.05880083731045166, 0.011543123644866772, 0.040308750354714935, 0.05420092365614349, 0.0013985449773064186, 0.05128359572300988, 0.03821541893205816, 0.033014765940606594, 0.030214364092136105, 0.013901055133300684, 0.03558193040531009, 0.16206792285365446, 0.21736661603133525, 0.14342811499391833, 0.1583099704716475, 0.23496514186263087, 0.08428012111013936, 0.10150068980311194, 0.0872167659502837, 0.18624126039926084, 0.31235804060293787, 0.174257209103915, 0.11487098485832253, 0.15510878014949062, 0.1811833027750254, 0.3016123397936744, 0.29316554627110886, 0.16757122271003264, 0.10996419936418535, 0.13269162256150477, 0.08499089748628678, 0.14954905025660992, 0.21476205498460801, 0.14908746696047245, 0.11290639834178072, 0.11704271388871056, 0.1838730681206911, 0.19958335575797867, 0.13006035568973712, 0.22337021726754405, 0.10612575412397424, 0.37593083576329295, 0.1383945036439165, 0.42668532520051927, 5.497355259233906, 88.25648246272918, 74.83563007846956, 49.60183035942816, 39.61248705464025, 107.85955505986368, 27.616982806113462, 0.5686152786497147, 0.8823699588256498, 2.690939605236054, 0.5140558756407231, 2.3061742128864413, 3.0058762671486026, 0.5070050781772983, 0.7416787695500159, 0.10566531995972318, 13.633120271467394, 87.78531951289024, 82.862548828125, 82.4466363845333, 90.80573281934186, 81.0643539121074, 85.48333537194037, 89.41407588220413, 87.40728932042276, 85.07089814832135, 85.6090316464824, 80.94159157045426, 78.77957328673332, 78.76604110963883, 81.1451861166185, 85.48880315596058, 83.38598128288024, 78.98632926325645, 63.53757619857789, 62.116234763976074, 64.08056559101229, 66.72059136052286, 61.391502349607414, 61.30764599769347, 57.145979865904785, 60.333886223454634, 60.07700235612931, 59.32372685401671, 61.62213771573959, 63.560435771942146, 77.83174822407385, 79.13213160730179, 78.33617287297403, 76.97650678696172, 74.75786516743322, 77.27368124069707, 75.93968314509239, 74.21811565276116, 64.17709904332315, 65.81901104219499, 39.629820008431714, 46.05900441446612, 85.39074390165268, 71.78442616616526, 78.25962389669111, 67.74509876005112, 71.94539239329677, 75.06191161371048, 75.74674960105651, 74.68721543588947, 77.02865077603248, 74.43512470491471, 70.42327742422782, 55.786588345804525, 58.202956645719475, 55.32453706187587, 57.95105418851299, 56.64917245987923, 55.54269144611975, 66.7287185115199, 80.92574519495811, 73.4455499341411, 71.91665710941439, 62.12704481617097, 60.99901430068478, 61.20490735576999, 71.11617195990779, 76.62021436998921, 79.48623534171813, 71.07606180252569, 74.1206604434598, 74.24937694303452, 77.57601753357919, 71.90111667879167, 78.27594095660795, 71.75740888041835, 74.25111063065069, 71.69778885379915, 76.36993577403408, 67.99300824442219, 74.88154534370669, 76.31714851625505, 75.73366457416166, 65.09847164154053, 96.9135456700479, 21.058242513287453, 0.4216789406153464, 0.45105755449302737, 0.9625603042302594, 0.39758136916545134, 0.5508964616925486, 0.5882793460642138, 1.3718498257860061, 26.44304879250065, 77.97822521578881, 72.83537034065493, 90.5898141860962, 69.43891940578338, 59.187302897053385, 51.08713388442994, 0.4220685422901185, 0.12928473763167858, 0.2062319110958807, 0.2042447403073311, 0.10709993451112702, 0.15019213510376794, 0.21360403647826565, 0.21659842902614226, 0.15137051622713768, 0.12162366686689279, 0.11824769358481131, 0.16927376119119508, 0.14218003519119757, 0.17106515054981555, 0.1590660226441199, 0.12081686903031603, 0.09221682264920204, 0.15542512849694298, 0.08829364042368629, 0.31440652906894684, 0.12028460646228445, 0.1637867330423286, 0.09921273757373134, 0.19317686888239077, 0.16550756570312286, 0.20496604273155813, 0.07311700197357325], [0.04044783744780768, 0.030362969827688033, 0.02868812350976852, 0.036470029322851094, 0.02771148589559861, 0.008525775272339102, 0.06284629866000145, 0.041485415441134287, 0.03741679525363349, 0.10770649228605533, 0.0482693231934982, 0.04669510060921312, 0.017805794749649304, 0.017303850111221115, 0.06325250912097193, 0.0757040808938684, 0.048838921056519595, 0.05505602333634611, 0.07468163696748596, 0.0384707483763416, 0.07663550591396709, 0.06520990207190476, 0.07364075330476608, 0.04740416094841016, 0.012810370967453046, 0.09319744583579803, 0.06500925598365646, 0.013148549947917703, 0.077111269497583, 0.05810108493953463, 0.09473165181735832, 0.09529098027175474, 0.0524278246467152, 0.42538888992801793, 12.341704407045919, 73.64305696179791, 57.726569098811, 36.806250849077784, 31.229995642938924, 97.66402059985747, 23.56525678788462, 2.097187878624086, 0.11334850002200374, 0.2904275173862135, 0.10021786791302505, 0.04116069758310914, 0.7219914743496526, 0.11199729712379557, 0.12478420856378733, 0.26071127323854354, 6.070363531189581, 76.85868663172569, 90.0142926554526, 73.66795616765177, 87.07019298307358, 86.89203892984699, 78.10268986609675, 78.14094866475752, 81.59050064702188, 84.74318412042435, 79.18526403365597, 71.7527961730957, 78.29644710786881, 79.37065878222066, 71.81066682261806, 66.66983589049309, 63.32335202924667, 59.97014522552491, 65.00603706605973, 60.913832187652595, 62.7299484129875, 63.549578651305175, 63.02914680973176, 56.58837964457851, 56.531838678544574, 52.81340822096794, 53.66249545927971, 52.657996070000436, 53.6390906764615, 64.8047802525182, 75.7075023651123, 71.25887563151699, 74.18246915263515, 69.30735526546356, 76.57992378357919, 69.96956117691533, 80.04970735119235, 64.73831568994831, 74.10555147355603, 38.83294736185382, 42.858028719502116, 86.6274279932822, 65.32405499489077, 74.01111648928735, 66.9555413338446, 74.11702832868023, 67.4807466999177, 71.12609555644374, 65.8616550507084, 65.51339172547864, 57.04868939615066, 55.89503011395855, 51.366296814334014, 53.13459150252804, 53.377825521653705, 54.117035404328384, 52.61188860862486, 53.193270160305886, 69.7966552549793, 71.76055462129655, 73.17081928253174, 74.65818205187398, 65.00923379775017, 58.65523730554889, 57.70763581798923, 67.53273379418158, 70.92507408511254, 74.11394534572479, 75.60013924875568, 70.14582464771887, 73.41334727502638, 73.84278405097224, 74.31058945194368, 70.64014527105516, 70.28846556140532, 74.67870389261554, 72.40378410585465, 67.84493877041724, 74.94748038630333, 79.05792036364156, 68.26708778258293, 81.56881778470932, 80.81096095423545, 17.515844106674194, 0.1766403707405252, 0.03551195593430631, 0.24549292130095346, 0.5505345004700846, 0.1533651333903113, 0.4652568409519811, 3.4402716544366654, 13.598806396607431, 63.51751327514649, 51.031196963402536, 35.70857555635514, 71.1166661785495, 43.66444057033908, 62.81465984159901, 2.29337576416231, 0.20774504199864405, 0.04708713461314479, 0.025769068048365658, 0.06028366560537008, 0.059239790369305885, 0.02458288623470693, 0.03233733354136348, 0.01410599035631505, 0.01241787922598662, 0.004525629938730309, 0.04467090096084341, 0.05329715441011133, 0.0911587632952198, 0.11885396790720763, 0.09317322979651152, 0.09552551042889396, 0.051008010914008466, 0.055856684808649366, 0.03900654260970412, 0.033755952176908334, 0.03297391813248396, 0.09817709395241353, 0.06200458636627563, 0.030158834208944635, 0.009775144017992482, 0.04575544014392842, 0.052633243462731766, 0.07753457138014418, 0.03519296458351516, 0.025383256593598955, 0.020620185363617156, 0.06271180426401478, 0.04790082341060043, 0.03523986065579999, 0.02161398909295038, 0.0543259377140672, 0.04055791662164754, 0.019546172228611765, 0.005598501123923568, 0.06624511668398496, 0.017203984804631724, 0.049407454057326244, 0.001719832676650596, 0.007680867913164079, 0.01525639490629997, 0.05176471809165613, 0.07491441278327858, 0.02365559808939936, 0.05223397375835527, 0.04354979257069288, 0.09272103107744649, 0.06983981572932775, 0.037389920889249736, 0.062367489876886534, 0.032146401447995056, 0.10250007448297355, 0.07072309978426465, 0.06506013188270793, 0.00823236168211987, 0.1060483945653804, 0.36744340893722355, 21.621059486942908, 88.32255871065202, 47.68690178471227, 21.819815789499593, 68.00365355706984, 107.04742047094531, 19.324688257709628, 3.1989895047680026, 0.11283274664874039, 0.07649808506210966, 0.4377430689431006, 0.037627802681057684, 0.725577072270455, 0.23011041204294852, 0.5674863101974611, 0.30208774331596594, 10.875273366128246, 90.5732068707866, 86.05098078327795, 75.09186283234628, 87.72782541090443, 85.10998848945864, 78.91007838710662, 81.88586296573763, 85.9482382189843, 85.411328500317, 77.52588179803665, 72.64752018836238, 79.80190769318612, 84.44266780730217, 74.19655830629411, 70.77982087289134, 67.1193395122405, 61.39522467890094, 64.18208437581217, 64.74413648728402, 64.52313446229505, 64.18885046435942, 63.48787976849464, 57.21778669664937, 59.088196369909475, 54.17213686050908, 56.528877289064475, 54.37480572731265, 57.66188921466951, 68.86579052094491, 75.20159506028699, 71.33446754947786, 75.38335769407212, 71.32682677238219, 76.12009648353823, 71.764571128353, 80.18915545555853, 65.34523579382127, 70.27011671373921, 36.94415746196624, 43.44667450074227, 84.99975419813588, 70.47255023833245, 74.49011633473059, 69.07777109453755, 78.16667941308792, 71.70894407456922, 73.74394032262987, 69.62186659536054, 70.04140330899146, 62.26915620988416, 57.92109904750701, 52.83371825372019, 53.85468767535303, 54.139479206454375, 55.346820046824796, 54.41639854061989, 55.63325112865817, 69.49181648992723, 72.58446416547223, 74.3970698695029, 75.3554774868873, 67.81266550863943, 60.38434751572148, 60.78371932429653, 68.24951556421095, 71.14824910317698, 73.61012474183114, 76.34533466831331, 71.17105376335883, 75.4669669366652, 73.56062443025651, 74.67515806997977, 72.47675588054042, 72.54200058598673, 74.26786699602681, 73.61030517085906, 67.71893655100178, 76.7439494594451, 79.60113725354596, 68.63620635001891, 80.16048292959891, 86.98381454713883, 21.272247029889016, 0.10127875413144789, 0.04016491351649165, 0.11605953196844748, 0.5178281232233971, 0.26473259132715965, 0.6737859739411263, 6.017237968983189, 25.188931726640273, 50.967854607489805, 79.58103902878301, 41.35536478411767, 78.91946854129915, 45.14271520799206, 72.80642324878325, 4.42251306387686, 0.23684565789036213, 0.021631164784212748, 0.054651934938925895, 0.05584905457292354, 0.0044692587952369885, 0.059268453548992836, 0.04207849006859526, 0.019129813017864383, 0.021595662354581782, 0.012659216074333077, 0.03526397327321672, 0.06405657585409862, 0.04550183439747461, 0.04105244935940831, 0.00426862707113727, 0.1267898420713121, 0.03296421562892295, 0.032433745706634175, 0.07945575135489626, 0.02640295792521248, 0.014762670391299313, 0.018395682451345267, 0.06225872454383682, 0.009207244954943176, 0.03962765222475414, 0.03727125386977869, 0.0318822447556041, 0.14863786527947073, 0.13546850742591968, 0.17411224994688265, 0.10096226788816914, 0.11850673855552751, 0.1487591676414013, 0.13983022902281056, 0.12947089699727873, 0.10694733745748959, 0.18169472775151654, 0.1672665495425463, 0.2122206195828415, 0.19306244599002023, 0.1340825317968284, 0.20835256504435695, 0.14571030624210835, 0.19368434084519265, 0.1186060848375482, 0.13611191403000586, 0.14709053621176751, 0.2216062385348543, 0.18814656703222185, 0.16269131924115843, 0.20406497011501945, 0.2027128249286644, 0.17379436942358173, 0.2202552578021442, 0.09169494057254446, 0.15065103709217043, 0.14468040828022266, 0.22345094761300474, 0.29030871247091605, 0.3243739764776922, 0.566483470461061, 26.747956199030725, 104.75063739284393, 72.44519649013397, 54.40243098043627, 44.668849745104396, 119.70366170329433, 38.050387444034705, 3.077948103027959, 0.14451333982569559, 0.4740935732280055, 0.622059349571505, 2.5655860477878205, 2.331606615935603, 0.290734688000333, 0.9400816910689878, 0.2728287617285406, 8.513238718432765, 87.67374377096854, 94.14363061228107, 78.14430621362503, 88.94772960293679, 85.14451319171538, 80.48664369890767, 86.03486768661007, 86.11766107620733, 87.03494656470515, 76.85694509936918, 75.41492492921891, 81.7488310413976, 87.75362676189792, 77.96163358995992, 73.56708849630049, 69.52408975170505, 68.29895311786284, 71.08139622596003, 66.39444628069478, 68.06070835359635, 69.50039079112392, 69.3262767791748, 63.566515445709236, 64.17777761336296, 59.25908227120677, 58.22909924291796, 58.47819720545123, 59.09735510426184, 71.5398193174793, 78.31652179841073, 76.67230344587757, 76.44351943846672, 74.73281691151281, 78.61054266652754, 74.29180129881829, 83.54674354676278, 69.59211149523335, 72.29626409469113, 41.811732553666644, 46.25218506782286, 87.65184125592633, 72.81345998087238, 80.47325272713938, 72.65955402005103, 76.51752671887799, 74.1490662482477, 75.7971755919918, 73.45454785131639, 74.33712036378923, 63.39176993216238, 61.381449314855764, 57.67000067618586, 59.18875417401714, 59.16101124978835, 59.26959422326858, 58.250789949970866, 58.9578442419729, 74.07725549513295, 76.28553421266618, 77.08656064925655, 82.39186440744709, 73.56165993598201, 63.5314259221477, 64.39654780972388, 73.77083209253126, 75.6213749608686, 80.71323117902203, 77.8396478776009, 74.25455447166198, 76.04917218608242, 74.81768131256104, 78.11663781442951, 75.29636736839049, 73.42233734746134, 74.55441182659519, 74.96400925420946, 71.20673164244621, 76.7447574677006, 81.6439703972109, 70.71489780179917, 85.26756578876127, 83.99241893522202, 21.76122146268045, 0.5023484893383519, 0.18578824196611682, 0.5643660647253836, 1.3405409767743082, 0.48653959086345094, 0.46083976184168174, 4.320614299466533, 26.194809829035115, 79.78567692541307, 65.97897314256238, 45.01984303997409, 83.2255720323132, 52.91435826209284, 81.85490762033771, 5.224262197171488, 0.5501341122773387, 0.2285172096303394, 0.1429988606081855, 0.19132140392978347, 0.13262906382160802, 0.14024745582813217, 0.06936658789674122, 0.14074250184480222, 0.157459796736798, 0.09180052281026879, 0.30905111482547176, 0.1397468939784073, 0.18613658214528717, 0.14965057222833558, 0.13875721563254634, 0.212057167063317, 0.1154339522303593, 0.17940783272347144, 0.1485562309502594, 0.14979197673739927, 0.13371824166707455, 0.1672930561847264, 0.14168776241281342, 0.10549518715349898, 0.13470606608015878, 0.15667003669565724, 0.16409958802884625], [0.06498192196651813, 0.014734978228056384, 0.02256408176054397, 0.04824395419188565, 0.039648976282126484, 0.07519198176000388, 0.03700286262638627, 0.029900112910376444, 0.05365502855349934, 0.027457640746668465, 0.03688983784447755, 0.04781047866169003, 0.050280598938585296, 0.05267180449840042, 0.08733082112045058, 0.01485024860519315, 0.018037413772676262, 0.04428332941907068, 0.05482404425199475, 0.0407076025411727, 0.0509770188270317, 0.012614433447109356, 0.0721229799091816, 0.03066360954225304, 0.007331943113146531, 0.030502767467330542, 0.01884847488855162, 0.019753015968167496, 0.03937528371029804, 0.11127018009222324, 0.10981913295484359, 0.04299871105280134, 0.05684720585122705, 0.1573397967243387, 0.06441612773004078, 22.714178946710405, 63.466981380216545, 67.9949458952873, 32.88948574373799, 18.82583337445413, 97.56964837351154, 40.718458160277336, 7.026933518148239, 0.6830381710202463, 0.5643562587999529, 0.05084370420644841, 0.18644916134015208, 0.07111548235820186, 0.2563659306014738, 0.06479541786135205, 0.23051222515923364, 2.1523773429855226, 57.41433666598413, 96.70129053054318, 74.67543263589182, 73.87172329810359, 85.14522706308674, 84.82533424131333, 79.73387810491747, 75.74915793634231, 76.47031707148399, 80.85946498378631, 81.30535218023485, 74.97626273862778, 70.92025741454094, 68.10770619300105, 67.9415467477614, 68.32386801319738, 70.25342310628584, 70.34633621092766, 70.30773224369173, 65.46783731829736, 65.26992236414264, 61.42727436557893, 64.19239236462501, 60.17520673813359, 57.228169210495494, 54.92345902227587, 53.68166408231182, 55.569277271147705, 72.0917909376083, 71.58946083438012, 71.69535698429232, 72.638930197685, 73.9211530070151, 74.55809100981682, 81.3305651757025, 70.08817365092617, 88.35119201290993, 41.433918091558645, 34.334471225738525, 88.96297977816674, 65.44327543627831, 75.3352851252402, 64.32580001892583, 67.22307835855793, 60.03917109581732, 62.89604510030439, 55.2890121552252, 53.38803152884207, 47.48319741218321, 52.84295935784617, 51.53326426782916, 54.29465209284137, 52.53362555657664, 55.04666851412866, 51.696956542230424, 58.90292321482013, 68.56062227679838, 73.77576643420805, 71.93700636586836, 77.02057069347751, 71.38534853535315, 64.4538026471292, 59.37047758410054, 65.03161091958323, 70.24718653771185, 73.42056443614345, 73.74232430611887, 75.17820988931965, 70.81807182681176, 76.51511838359218, 72.70306879474272, 77.4860462065666, 68.23672079270887, 69.02703131398847, 73.38538862043812, 71.43727287169426, 66.71338988888648, 76.12018277568203, 89.2872578097928, 51.152621776826926, 2.7385856163117195, 0.2359754126518965, 0.019982897886826147, 0.27582018185527096, 0.05462470817409697, 0.04473234887324995, 0.1681494045882456, 4.889345717045569, 16.045237702708093, 67.20532571115803, 51.76853195313485, 11.71292591479517, 26.391730462351155, 25.522199830701275, 57.51953071163547, 9.064952442722937, 0.22432453299482025, 0.028677298687398437, 0.03987602942112473, 0.049139805919220375, 0.06420652990439726, 0.04676358503920417, 0.09082173057381185, 0.04494347121386279, 0.06525386785787922, 0.056846229089123596, 0.09711122050160363, 0.03812971284552928, 0.06790739724472647, 0.024327757888503616, 0.020291652387729096, 0.07318251015197846, 0.03820473966639369, 0.017750753247509563, 0.03102386047342612, 0.051624964502069264, 0.04400292974746516, 0.060706998131448225, 0.02645043047866033, 0.006731364175662279, 0.043112314231092894, 0.05096572286058819, 0.049321747970797365, 0.03811583133234132, 0.01505371198178299, 0.02630909874794945, 0.02393456709180628, 0.06924931515729235, 0.0287973293433747, 0.04054985737668411, 0.05092014828997274, 0.06613316059473061, 0.023064277803284988, 0.08703828278568485, 0.03680075714064222, 0.07168349824965962, 0.03305535327883498, 0.029477508167826363, 0.08171708202890812, 0.0518168120705072, 0.007088181596519727, 0.06684286444778405, 0.11276078034913349, 0.05442182510910977, 0.032796545795375304, 0.06655290016844388, 0.06881803063856018, 0.024669109430584698, 0.01285306025942367, 0.03609976753772747, 0.02071617043487007, 0.08177187263725266, 0.029401496923979253, 0.12796558019134308, 0.11694492276517615, 0.07251380732463253, 0.04490494848259034, 0.13577442165584336, 0.013766150880274514, 38.072693963204664, 70.0743825974003, 47.67028270229217, 23.04086139125209, 59.83115996083906, 110.2050304412842, 33.65642678353095, 10.910639416786934, 0.32992164814664476, 0.4964652098715306, 0.14959619530747015, 0.35661950587264957, 0.44230739015244674, 0.10621915556370251, 0.1371773584715782, 0.4130267742420397, 4.560420657357862, 72.88152879284274, 92.56129157158637, 72.1587771754111, 76.96873264928018, 86.6965558451991, 82.75005525158298, 79.11202553779849, 75.75879912222587, 78.30246402371314, 81.89391951407157, 83.02036146963798, 76.46237034951487, 77.25006857225972, 69.85986032793599, 69.1718844444521, 68.22230215995543, 73.4292564084453, 73.59554921427082, 71.2943652368361, 67.40521753987959, 67.53186302800333, 65.2341385810606, 65.06009517177459, 60.8612802720839, 58.6787832936933, 54.92892288392591, 57.57820152467298, 60.16333764599216, 76.70048959793584, 73.95941965041622, 75.0031780427502, 75.08100571170931, 77.18265087373796, 75.0588756991971, 83.17880953511884, 67.70931889933925, 86.69197451683783, 43.194234678822184, 37.220135427290394, 91.16756362299766, 66.06121740033551, 78.59550429928687, 66.62287727479013, 68.84631203066918, 62.43538233541674, 65.29087958797332, 57.86151039984919, 57.75168403502434, 52.24733175769929, 53.71507090906943, 54.30851767140051, 56.04662579874839, 55.336143355215754, 56.86976263600012, 55.138871669769294, 62.32794077165666, 72.45426500997236, 78.53649616241455, 74.78496874532392, 76.57786061686855, 71.77236095551523, 64.42730703661519, 59.26459712366904, 66.26765958724484, 71.7341806042579, 75.20754137346822, 74.94950432931223, 73.83770850396925, 70.90318725955102, 77.38109142549577, 72.97410457364975, 75.26080716040828, 71.15101829651864, 68.70221199527865, 71.6170507861722, 74.53279172220539, 66.19218534038913, 71.8781159001012, 89.86522689942392, 59.45039587636148, 4.202406810175988, 0.12437654253576072, 0.030283936366979635, 0.4099466104901606, 0.19131840086512028, 0.028941964828259045, 0.5750058002529607, 10.136855802228375, 28.77410750235281, 47.888150753513465, 82.96501682650658, 17.352124375681726, 28.876047941946215, 33.97747278213501, 65.55418829764089, 15.541659305172583, 0.4193225154472936, 0.0662621621403002, 0.007190075120888651, 0.08607886491283294, 0.07904917317172212, 0.025009819374029196, 0.041974482141555323, 0.023142462821617242, 0.07272825831727636, 0.055855210089395126, 0.011688296348908016, 0.05343926755050498, 0.07960749805093774, 0.03159946063533425, 0.07189185118242618, 0.052330906863414475, 0.036545795418562434, 0.01353641547593138, 0.032753748293485374, 0.03248535321965333, 0.019917857022054737, 0.04646246651968649, 0.07206013005587363, 0.023858536695761066, 0.030254562640742912, 0.03213715859718862, 0.055795167948329644, 0.023193467040396026, 0.1483467059029687, 0.16108232009555065, 0.19708413180084, 0.15481235008806954, 0.15786082844340033, 0.18305369112039768, 0.19453250742968053, 0.22850392566573238, 0.10974375756397363, 0.1760224135772836, 0.11874239486191543, 0.1454018026350006, 0.13596405906061973, 0.1538857361001353, 0.21062213116355483, 0.1535662161486764, 0.18519250135267937, 0.09828082225736111, 0.2206410903243288, 0.12359996686779684, 0.16834829633514728, 0.19417881995679873, 0.17015034963767375, 0.1009698291759818, 0.08556644402204022, 0.14168359489450533, 0.1844680120026873, 0.14424453489482403, 0.09608549005802601, 0.18145981455041518, 0.21704796942011004, 0.17572345542571238, 0.18086264901343854, 0.27339799569979795, 0.14359409560359296, 46.89124507288779, 88.01217371417631, 88.25838873463293, 50.68032526200818, 32.59837919665922, 119.32020295050837, 60.49935533154396, 11.917574597943215, 0.8404886061626097, 0.6922003374465051, 0.18873159773647788, 1.6035700949930376, 1.4847235045125409, 0.41781096268565426, 0.43281482532620436, 0.5147615651930533, 3.4739611369948236, 64.40250981238582, 97.8533769422962, 77.15892053419545, 76.85732949164607, 86.92481425500686, 85.57656226619598, 80.18706090988653, 76.58405796174081, 77.65831670453473, 81.08610737708308, 88.02769061057799, 82.15981698805287, 81.30986290593302, 72.89451183811312, 74.6603472002091, 74.05761226530998, 78.82293901135846, 77.32972406571912, 78.27771386792584, 70.78539063853603, 72.88268196967341, 69.02771380639845, 70.60625599276635, 68.5007433737478, 63.27071774390436, 61.163620487336196, 60.0161232486848, 63.50071768606863, 79.97923804867654, 78.85551037326937, 78.97235778070267, 78.91210233011554, 78.15833260936122, 78.51079679304554, 84.25695142438336, 71.00049341878584, 86.90045633623677, 44.87051448514385, 39.62210470630277, 92.75762973293182, 70.12576564665764, 81.31748014880766, 67.99638148277037, 71.56347905435871, 65.21102013126497, 67.33231636785692, 60.18226700444376, 59.006285513601, 53.29167066081878, 56.26340735343195, 58.17323292455366, 60.03364447624453, 60.16633433680381, 61.41513070752544, 58.202635011365345, 67.08897252236643, 77.94900355800506, 82.99437968961655, 79.15123355004096, 79.01417809147989, 75.1792924634872, 69.14784031529581, 66.05696555106871, 71.59212020135695, 77.42385310511436, 78.08826338860297, 79.03524121930523, 74.3945203288909, 75.68482322077598, 79.4789005094959, 73.77916320677727, 78.73887477382537, 71.60070234729399, 70.3850813834898, 73.25995122232746, 72.34889445766326, 67.54947447007703, 74.35898365512972, 88.23370918150871, 55.90048613086824, 3.6632939452125184, 0.28321620918089346, 0.24137694538841326, 0.6083773256790254, 0.5883444941812946, 0.29169119473907257, 0.385288599758379, 6.890758141394585, 28.696999588320335, 85.08989810943605, 61.43037696038524, 21.098421312147572, 42.77961269501717, 39.61335782081851, 81.70526135352351, 18.874764942353774, 0.5850460873015466, 0.25162769211155755, 0.08139302683693748, 0.1719082609540032, 0.15927847414728136, 0.11011077496673792, 0.1304002382582234, 0.2300898808865778, 0.20293969420656083, 0.18885312992478573, 0.17803696434824698, 0.1270243339240551, 0.17912824127462604, 0.13683675578044308, 0.10357820534057195, 0.18564395696645786, 0.13926389086390698, 0.11364164356622966, 0.16302499649745805, 0.2494662669637511, 0.16693492540188376, 0.13731448821002437, 0.13009398694961302, 0.09149491501551482, 0.11012452624497876, 0.16073096152995864, 0.1641617330812639, 0.13928256808750092], [0.02609100117678604, 0.027434516382674058, 0.04250887443401641, 0.03131045779633907, 0.02387126524662299, 0.04867899637188643, 0.05001751285406852, 0.03491312798653399, 0.022378554417481347, 0.014858860391071968, 0.05164454570941387, 0.07169430775027122, 0.04947507663840248, 0.09550718560574517, 0.0773348599191635, 0.038776494066921935, 0.028945791437440825, 0.06262421360119216, 0.07663631030628759, 0.04574907012283803, 0.05306053666337844, 0.03915255130719274, 0.06859299231080279, 0.0352004339407769, 0.022027368221672314, 0.05339279665701813, 0.03614014420177668, 0.036847013529510274, 0.017945073364723115, 0.03769587342356963, 0.038406764712905696, 0.02121976599277508, 0.04187909270366354, 0.03912308373518529, 0.07844275329262018, 0.3038898885490433, 44.65612949863557, 70.2578789188016, 56.52050302874658, 36.23902513134864, 20.357103155505275, 90.73292578420332, 69.92155921074652, 19.67572273746614, 2.5673344442921304, 0.15204698718603582, 0.17844682138773704, 0.40015855022976476, 0.1140468427911401, 0.30403176803262005, 0.09918888925664848, 0.1266310243837295, 0.24704023504689818, 40.08617993324034, 95.9425864681121, 81.24698731207079, 65.45181443614345, 71.8408690729449, 82.01033546078591, 85.64752578735353, 82.95506185100925, 75.53156837340325, 77.22719330941477, 78.64846414135349, 73.6598054824337, 71.78686588041245, 75.13496183579969, 77.18158398905109, 76.29286120014807, 69.0973044979957, 70.96902816526352, 70.34857196192588, 69.12389032302364, 67.10849023634388, 67.13578208800286, 62.68499805081276, 64.90301993585402, 57.19260900251327, 59.95990391700499, 52.15827042056669, 57.02550818843227, 64.34529419868224, 74.64630511499222, 68.8517641252087, 75.199751546306, 70.59448888224941, 81.0322375451365, 69.65504984701835, 84.43572521209717, 43.05165260068832, 37.23893534752631, 92.72863557261806, 68.24559319403865, 78.63714418103619, 61.391467048275864, 63.025259740891, 51.74179315567017, 54.61936942992672, 52.353726048623365, 55.01608579389511, 54.4217800324963, 62.34052373516945, 60.26316981161795, 67.33146913589971, 63.47791694825696, 62.627135246030754, 53.927039715551565, 59.720031369117, 72.7413825065859, 76.65968125866306, 73.98278913190289, 76.98080570467057, 74.5661554028911, 73.25922950621575, 65.0105477917579, 65.30660436999413, 70.95046750960812, 75.57800923624347, 74.76845556689848, 75.28369026799356, 76.22244681081465, 72.30154360494306, 78.90115107259443, 67.42108744959678, 71.59924322558989, 80.04506326490834, 69.97380518144178, 68.0531068002024, 87.0643094278151, 79.40858810178696, 18.49615816147097, 0.05248173042350719, 0.06401898391965417, 0.21376862280791809, 0.1027264304819607, 0.05752631215258472, 0.15561206927222593, 0.12786123135517682, 7.346696901705958, 17.737206989719024, 70.39423619547199, 50.36357818111297, 8.721982356040709, 40.69527695255895, 40.32805288991621, 53.42307006159137, 11.018497732377822, 0.047912146190121296, 0.010403693304397168, 0.042409616252107006, 0.04995898373665349, 0.02572939043954736, 0.08668156926550212, 0.03995913080871105, 0.033738581133225275, 0.04066430325169237, 0.005222511873956049, 0.02880273983933993, 0.02823929557757032, 0.05223305062240651, 0.03372831938547954, 0.02156072683001478, 0.05659692875680424, 0.057462692380912846, 0.03943009730128031, 0.0224215530174514, 0.0499591292933591, 0.025784464500423883, 0.035204532511171796, 0.05981566632286676, 0.029231168765334353, 0.06139079289090249, 0.018995649954904954, 0.04564472128667178, 0.035613600480099844, 0.049006602381386107, 0.024632195483953245, 0.044992757480471365, 0.054101753574345386, 0.004057283043831347, 0.006043440681101094, 0.11521649817305228, 0.018797030169216376, 0.05106026960176326, 0.031000061952058348, 0.07748904277480419, 0.04569414161866711, 0.01825337970419036, 0.02493600297208515, 0.06856859241041445, 0.05463429959490896, 0.03594702109694481, 0.013132957185828879, 0.047152746213419784, 0.05206219386309386, 0.010003192113682387, 0.03328973404882896, 0.025296328596830852, 0.03349560485672086, 0.007263847951582003, 0.017894762455515804, 0.012975816273190563, 0.007027231641263972, 0.04808926188777532, 0.07133422344322167, 0.03619806044885228, 0.02096331614490238, 0.05061539468325434, 0.0254851175592311, 0.009725052401453499, 0.03722300948274713, 0.27808792468520904, 61.254866584654785, 76.8572118205409, 38.728196544031945, 12.292309999465944, 57.70114821772422, 112.8568821568643, 56.232538300175825, 25.434813345632246, 4.55207875659389, 0.09441479019099668, 0.17362978309392932, 0.5464364203714556, 0.4709554319420169, 0.345923999144185, 0.13867309917846035, 0.19225684325060538, 0.8734934512645969, 53.55410075956776, 102.2532093909479, 77.88497478731217, 68.59748471167781, 77.49760150909424, 84.89450916167229, 86.5602848606725, 78.71072784546884, 76.9106109680668, 81.5673194393035, 80.76462207301971, 74.88839380202755, 73.90252174869661, 78.14447095317226, 78.00563473855296, 77.22352981567383, 72.6049389377717, 73.34568638955393, 72.27815058923537, 71.07285330372473, 67.41372123841317, 68.04941977224043, 66.61264773338073, 66.41541527163598, 59.78261278521631, 61.00684727391889, 55.696926886035556, 62.72728120127032, 68.00737980873355, 75.68079886897918, 70.72386434001308, 74.44300866896107, 72.60480557718586, 82.44844851955291, 72.0888570047194, 82.25196915288126, 42.00781968332107, 38.73910073311099, 91.93784652217742, 71.21688273645216, 77.64529443556263, 63.57467397566765, 66.84487558180287, 57.30361600075999, 58.509568322089414, 54.16389203840687, 56.55058368559807, 54.906106456633545, 61.272285830590036, 59.237775956430745, 65.57602805476036, 62.01339021805794, 62.401983353399466, 56.52687688027659, 60.574794277068115, 73.09026164393272, 75.90575464310186, 73.24152392725792, 77.04270070598972, 76.47399625470563, 75.70232483648485, 65.5914939603498, 67.4534313140377, 72.20400210349791, 75.48329184132238, 76.03753059141098, 76.96912488629742, 75.64981214461788, 72.33159680520335, 78.9126043934976, 72.44092110664614, 71.05812088135751, 78.29250120347547, 71.69089332703622, 66.10585397289645, 80.65015946665119, 86.3798636774863, 24.929723854987856, 0.007731426364531922, 0.09061614321845193, 0.09894060782126843, 0.22713644339913325, 0.06055131757391557, 0.2106567736594908, 0.22882094817055812, 15.759522453431162, 22.41737907932651, 45.37476262738628, 77.98830570713167, 11.41407072544098, 29.636318991261145, 42.52985969666512, 62.13330491896599, 21.73092899783965, 0.07965760786206492, 0.02184558513333961, 0.06810636560042059, 0.06423849109259826, 0.050947669998652516, 0.05064878079499449, 0.011122688846362215, 0.019361137097040494, 0.06790670776559461, 0.11018784341192055, 0.03759317550688021, 0.0331474561995316, 0.07650045227379569, 0.04462626101749559, 0.08323353775326284, 0.03974467981606722, 0.07065098792795213, 0.05014309381705619, 0.013362288478791956, 0.01763013078861179, 0.042153792681112405, 0.04033943600652199, 0.021283755401870417, 0.05120906685929626, 0.05952151920346003, 0.06723445029028001, 0.057058052400187145, 0.015012946528112216, 0.05624776120267569, 0.10721462553427105, 0.21617695809372012, 0.14267607712216918, 0.2022290250827228, 0.17387292407933744, 0.17523083024688307, 0.07768783493027573, 0.11628888337121857, 0.1298724496436696, 0.2505512006821171, 0.20286034281936385, 0.17899417588787694, 0.16572384764590573, 0.18188071857777335, 0.2209216470439588, 0.1086276057626932, 0.12534154518958063, 0.17027396558513566, 0.1570770285663105, 0.14549129702631505, 0.1422217410177954, 0.11559696807976692, 0.12492598845593392, 0.11186972816264439, 0.17349682087379117, 0.09525723409869018, 0.14836925953145952, 0.1831928280092055, 0.1935187126359632, 0.11671262192389659, 0.2344322051372259, 0.18703949337284412, 0.06855366901764948, 0.19721160883144026, 0.12946155072460253, 0.5104858139830252, 69.95490720195156, 94.7967758486348, 73.27302055974161, 51.90912146722117, 36.29024344105875, 102.66563092508625, 94.02597519659227, 33.262444311572665, 4.20122568645785, 0.3063416150548766, 0.247319933748053, 0.7486995670103258, 1.448958720411024, 0.9216165206124707, 0.34863735999791856, 0.24069163377486893, 0.6504633157483993, 45.694294591103834, 101.26678820579284, 84.77052304052538, 72.94212156726469, 78.79537259378742, 84.3947756674982, 84.41203409625639, 83.49809046714537, 77.947112975582, 82.34321917257002, 84.17200857593168, 80.08718952055901, 77.44180971576323, 83.62161374861195, 84.6555583707748, 83.91499919276085, 76.01891502257317, 75.76279993980162, 77.68398469494235, 75.82038033393123, 73.7943349346038, 74.73906132482713, 70.1917948261384, 73.16020534884545, 64.09016363082394, 66.66842383723106, 59.63071507792319, 64.00554633909657, 69.5988501271894, 80.46013632128316, 72.16514710457095, 78.23285764263522, 76.28722083184027, 88.5244038797194, 75.82374572753906, 85.8469783106158, 46.83298610871839, 42.40546957139046, 96.40919946855115, 74.95311290987077, 82.93008419775194, 69.51724913812453, 69.82985419611778, 58.766412965713016, 60.41393003156109, 58.85516835797218, 60.00086130634431, 60.48748231703236, 68.4851872536444, 66.32175691666143, 75.24392527918663, 69.19467341515326, 67.22649866534819, 59.91076054111604, 64.06366409793978, 77.13288384099161, 80.0395562571864, 77.67903466378489, 82.10544509272422, 84.17574267233573, 80.66697858995008, 71.0708450501965, 69.16869163513184, 76.73726574067148, 80.32573238495858, 81.41596301909416, 82.35525300425869, 75.7143037549911, 75.0475400493991, 80.7183224155057, 73.35047168116417, 72.74959594972673, 78.5578417008923, 74.0547332456035, 69.02741570626536, 84.60211999954717, 83.14205692660424, 22.98534220264804, 0.13715675070641503, 0.20821663040307262, 0.4500082898284159, 0.46237846475935757, 0.12880311347544193, 0.20425860649876057, 0.36059960843093936, 12.075688281366903, 30.180267403202674, 86.0870901230843, 62.745053460521085, 16.509434523121005, 60.57685744377875, 53.85391496842908, 82.70883114107194, 27.003488809831683, 0.1265734145718236, 0.17927528419081243, 0.14018825255334377, 0.18372657678781018, 0.18714149031908284, 0.22775225551618686, 0.19052969802531505, 0.14178703208604168, 0.1541153020075252, 0.2430278495434792, 0.12461013040475308, 0.16276137032095464, 0.21420425104518093, 0.12633415765219158, 0.2436211999625929, 0.12747955869042105, 0.19595752289939314, 0.2372458162567308, 0.12610390226566984, 0.09795888146806149, 0.19488147580094878, 0.12338047501661124, 0.18633316030665753, 0.10565080259355808, 0.16186346930842246, 0.12631101413599907, 0.14738981612026691, 0.1707747572612378, 0.22327160642993069], [0.0351591992582525, 0.05228636651149681, 0.006627775202955931, 0.056767662942049005, 0.05245951387370306, 0.03265205012153714, 0.03368269884958863, 0.016385553922924786, 0.04884380869747651, 0.06715961116095705, 0.019205808939953006, 0.040215551928286596, 0.04038168192510644, 0.03334365897781907, 0.09667144006779117, 0.08547393890518336, 0.029803093620425755, 0.06225495539124935, 0.053438068622903484, 0.05308106015886992, 0.08741370417297849, 0.041163482312713905, 0.006855028961229349, 0.051641607762224255, 0.060795875821983626, 0.0164440983620983, 0.051339121775761734, 0.09063809163748257, 0.07324766592993852, 0.02178107478445576, 0.09754417509201074, 0.017812101568485943, 0.09217233592343908, 0.04858176066209713, 0.13492486079133328, 0.014219326361443007, 0.0830701465207723, 42.57112695324806, 72.88535702613093, 70.56822469157558, 33.370399705825314, 14.423731834657731, 73.06102429666828, 95.2757364703763, 36.36978910815331, 5.332170032685803, 0.39427487239722286, 0.02000688601495518, 0.0007704698873567396, 0.3721134809236373, 0.15031581233826377, 0.06441657206103688, 0.08197274855187825, 0.025742109414310228, 10.759934110026206, 64.60129945508896, 93.1102978798651, 78.6466912300356, 69.0963395949333, 66.97210942545246, 76.0736007075156, 81.48250995143768, 85.0749146553778, 77.84315447653495, 81.1452724087623, 79.75693379679035, 77.77566617535007, 77.50841156128915, 75.54840318618282, 76.95245481306507, 77.64922465047529, 69.83128978360084, 70.769638399924, 66.69685317624, 68.45778557562059, 65.70565062184488, 70.71950266438147, 66.45336028068297, 71.3048928783786, 65.10512790372296, 64.53132829358502, 52.820358660913286, 59.15543756177349, 60.755839117111705, 73.33737096478863, 67.7874211342104, 78.76885737142256, 69.23444624870055, 92.96325606684532, 40.5614496046497, 28.22187112223718, 92.31358605046427, 70.3562048942812, 73.34579621591877, 57.516934102581395, 59.56416030083934, 57.0243000984192, 63.989829401816095, 62.498414824085856, 68.5596259947746, 67.37328944667694, 76.66869486531904, 75.14380285816809, 77.67228818708851, 71.63874933796545, 70.27447838937083, 56.86678555703933, 63.636153205748535, 74.28179925487888, 76.13998290031188, 76.38842582702637, 76.71114275532385, 79.8250182982414, 73.22125311820739, 75.29667331326392, 71.6648958575341, 76.69284882084017, 74.22308137339931, 78.98618805793025, 71.03773240120181, 70.42559946736982, 74.15804063120197, 72.18006780070644, 81.25129407451999, 71.22240543365479, 55.7715029101218, 61.78792453581288, 76.53745235935335, 43.984431451366795, 3.7290515005588536, 0.21413734092587428, 0.14154240489006042, 0.14900909616581856, 0.20789272842868683, 0.07749656575822061, 0.24591102144650875, 0.44499277347518557, 7.656727904273619, 25.811239288699245, 79.4627481891263, 46.31878299097861, 10.83834425095589, 51.907199505836736, 37.023828644906324, 41.70422430961363, 10.732059786396643, 0.04948093721102323, 0.02283229680371381, 0.045250182175227714, 0.02468861211391707, 0.04322722741973497, 0.07682818468780288, 0.023487202387543458, 0.021139045223413457, 0.01820891787628493, 0.01321715695197664, 0.1314011627748128, 0.04802686019590305, 0.012943300628854383, 0.021671907255245794, 0.027951175654907862, 0.05164656818153397, 0.030334739487678297, 0.06793857702324468, 0.05528526365636818, 0.04407342132781783, 0.1023239738518192, 0.08329425022126206, 0.043073523369046955, 0.07491121819663434, 0.09722218833743565, 0.028961122772025488, 0.012922878640012877, 0.026429004914638017, 0.023449141224245393, 0.018824774043394193, 0.008665446507474108, 0.04322636174038053, 0.04657490141389351, 0.051046709845503496, 0.04410812128034811, 0.012133939270561021, 0.06201076869582457, 0.033211098953841195, 0.07426428758809644, 0.08393505978728495, 0.0649600807997969, 0.030579426055473667, 0.021759821590216413, 0.08723660762752257, 0.11686260661771221, 0.06452912569887216, 0.05211645587077064, 0.028640166405708562, 0.04136257707291553, 0.05177841957418188, 0.033646033881532575, 0.0642936762362238, 0.029078891553405314, 0.05484289767581129, 0.06464454450554426, 0.06746710353200475, 0.0753789761614415, 0.06332530662597669, 0.02739515670034434, 0.021231554170709946, 0.035888380896780765, 0.11916492299567308, 0.08566901553422214, 0.03243409810707935, 0.11186622714083042, 0.04029242502104852, 1.2927841587412743, 58.9823551331797, 77.07961020931121, 51.67692892013058, 11.642886111813208, 40.7458088474889, 111.12683450022053, 83.94691944122314, 37.09582767178936, 12.742452967551447, 0.8858692033156272, 0.34956162975680444, 0.11440858184810608, 0.19084227722017996, 0.2763665864063848, 0.007011037021349635, 0.15059071532901258, 0.0690271649810095, 18.912819777765584, 80.26326471759428, 97.83727169036867, 77.86767713485226, 71.99933282790646, 71.52599688499205, 84.32194509813863, 81.9809804424163, 81.33053379674112, 80.78575580350815, 85.12524650942895, 81.7532084065099, 77.9589585335024, 79.25978122218963, 79.39206707862117, 76.66271717317643, 75.96229953150596, 72.97899969162481, 70.87130623479044, 71.78462228467389, 70.88076699164607, 68.23303376474689, 71.57011570469027, 66.84540117940595, 70.89906877087009, 62.75165873189127, 62.59231244364093, 56.58970540569675, 64.2821518836483, 66.70075985693163, 76.45851073726531, 70.18201243492865, 82.34756515872094, 71.1981338070285, 91.01159449546569, 43.43537415227583, 31.364558435255486, 93.47872611015075, 69.92374004856234, 74.97588619109123, 60.01311086839246, 61.215038837925086, 55.704952055408114, 64.49819211036929, 59.066215407463815, 67.70196837763633, 67.44530416304066, 75.46411145117976, 75.91666667692124, 79.1546852357926, 74.43874113021359, 70.12589116250315, 58.601324327530406, 65.25996738864531, 77.28852348942911, 80.17390528032857, 75.54732061201527, 72.20339805849137, 77.96417528583159, 74.76990684386223, 73.3070981117987, 68.17572793652936, 76.01157234561059, 78.3753808852165, 78.93542474316013, 69.23332445083126, 70.62991572964576, 75.86623284124559, 74.55777722020304, 82.05156741603729, 76.76735031989314, 58.02458293976323, 62.590692504759765, 82.29292654222058, 53.900924574944284, 7.371078844993346, 0.21793529841928713, 0.0634212936124494, 0.06147916879384749, 0.1357828639447689, 0.040331449539911364, 0.3448055414182525, 0.6360609853459943, 17.745412588119507, 25.64509749412537, 67.561947607225, 75.09536943128033, 14.014140290598716, 31.04074912686502, 41.07474665487967, 54.70541838676699, 19.799879481715543, 0.062223495990638776, 0.08538131887513785, 0.06284778870101418, 0.060967977474173235, 0.06716002484843617, 0.025256398178997542, 0.035525630603754715, 0.016599208184127367, 0.05615861538136679, 0.04261483588526326, 0.045650980225013155, 0.018993547043552803, 0.0415837811306119, 0.06524508849026696, 0.03544437548806591, 0.1055559532476529, 0.03624017996292922, 0.01176361428318365, 0.012276547495275738, 0.050084354025461984, 0.04940862617185039, 0.025221225167174014, 0.06490020336763513, 0.03962174951729756, 0.0411454409420971, 0.03168369008738908, 0.0419465046105606, 0.052203249802152, 0.039617103194036794, 0.05079529511051313, 0.10019775044413344, 0.19776087855139088, 0.16541822452939328, 0.25276088936915325, 0.08864562718137618, 0.1550986831106486, 0.11064433988424079, 0.08420275389066628, 0.1423657961910771, 0.2013973753538824, 0.1285642319388928, 0.15298196685410317, 0.22488126441115336, 0.1619386072120359, 0.2473116293549538, 0.21622611029494196, 0.13329681669992785, 0.21702259658805786, 0.07366249488005716, 0.15408439802065974, 0.10794607096261556, 0.15486677297421042, 0.08658323421954148, 0.12151672099266322, 0.19894191033897862, 0.14069872758080884, 0.2763744617902464, 0.18178417617755552, 0.10982538423230571, 0.09466640410884734, 0.20333842764939034, 0.2700382098555565, 0.21138590550230396, 0.18964823725963795, 0.3446492594816993, 0.13529377809214976, 1.2855006850534871, 65.43117100192656, 95.2427807161885, 90.27798575739708, 51.65389284010857, 30.100358916867165, 86.60636486545687, 115.97817097940754, 56.0349920488173, 10.52760329938704, 0.6249402691760372, 0.2808682416235247, 0.15914718199881817, 0.6572380457674304, 1.2708936559577144, 0.38632294103022546, 0.2830982009970373, 0.12389010734735958, 13.851231509639373, 73.6819354949459, 100.72659154092112, 87.67549314806539, 82.35182485272809, 76.36470333222421, 80.21534119882892, 82.11021469485375, 86.73129235544513, 82.84799683478572, 88.34989763075306, 84.03092092083347, 82.03045721976989, 84.34466346617668, 81.907883151885, 83.81353532114338, 83.87934484789449, 78.21780358591388, 77.48270434717979, 77.2240161895752, 75.9896541410877, 73.79926927628057, 77.18116821781283, 74.30329384342318, 79.18513067307012, 70.67306180154124, 71.80882330863707, 60.124117866639175, 65.21547594378072, 69.1033527928014, 81.46464747767295, 72.92346677472516, 84.99256841598019, 73.91199035029258, 93.26341152191164, 44.71145452991609, 33.57352356756888, 95.43569072600334, 75.89053584683326, 77.94184131007042, 60.90863504717427, 63.58854347659696, 61.72702189414733, 69.14707153074204, 67.3719636855587, 74.85591657700078, 73.5026910228114, 82.81693166302097, 83.95417582604193, 85.09081594405636, 80.74281369486164, 76.67416264933925, 65.62256697685488, 72.90852254436862, 82.1382204178841, 83.18827029197448, 78.61773629342356, 75.2399323063512, 82.89668913810485, 78.67017838262743, 82.82800059164725, 74.18713677314021, 81.18632393498575, 79.67825105113369, 84.42052995004963, 71.96804800341206, 75.40204386557303, 77.69666964007963, 75.63107105993456, 85.08194354272659, 76.85258342373756, 63.02441250893378, 67.25142140542307, 81.81628011888074, 50.18132132868613, 6.388500111718332, 0.3089554764090046, 0.2801058309212808, 0.3999948832056215, 0.6771156372081849, 0.28652319624539346, 0.29772471936960376, 0.6077368148872929, 17.421464035587928, 40.70520054909491, 95.17647697079568, 58.34724495487829, 22.83246978636711, 71.20191497187461, 52.852325977817664, 69.83802841555688, 25.82100599042831, 0.14676110308256843, 0.12805921145744864, 0.15317840711964717, 0.11489212888503268, 0.11030236589572123, 0.19814726265688098, 0.10684961528186837, 0.13673008569786627, 0.06828391413775182, 0.11871240251967985, 0.1886357141718749, 0.11767741773397693, 0.13834314510947274, 0.19982084301450562, 0.1156411866747564, 0.19231621506473712, 0.10970916869419237, 0.13011012076129838, 0.1190246293140996, 0.1819924908059259, 0.1561970233676895, 0.15288401485210465, 0.22058550298454302, 0.17342105477807984, 0.14632400395649095, 0.13707580585633555, 0.10043369786393258, 0.157986298323639, 0.18564190385082077, 0.2101153486798848], [0.051999179300882166, 0.0399010077178959, 0.101208902234512, 0.06388853446790768, 0.08837333655044918, 0.02355350538217012, 0.04348135410597728, 0.027115473320948023, 0.02649598781229748, 0.06194788436856001, 0.03281442628752801, 0.014217988580405233, 0.05869060108858732, 0.04258952434024504, 0.04193235496659914, 0.046117263470566085, 0.07097511972871519, 0.03290579376381732, 0.034532788314766465, 0.04837996161152278, 0.04552852107031692, 0.011103956081393746, 0.1151991079771711, 0.03757991452491091, 0.046024237413920706, 0.02715441931579863, 0.0709021728365652, 0.03169841812773338, 0.09281770371261144, 0.17362236736282227, 0.04320413369925753, 0.12810333046100794, 0.055987892687440886, 0.05054414084541702, 0.09442321715816375, 0.05188837617395386, 0.08073553187592376, 0.0480354059066984, 29.44645666307019, 63.38265042151175, 61.01642962424987, 44.808266470509196, 17.068386000971643, 51.30491956587761, 95.65908539679744, 59.424041471173695, 12.389121940059047, 2.9004777679520273, 0.03507149751268087, 0.033789162088425896, 0.06765671795414341, 0.2852671797717771, 0.03956581360750622, 0.23772330353817633, 0.23398724594904532, 0.635526807558152, 25.54781683029667, 59.18527895404447, 79.60451049189415, 84.5399582770563, 73.81209542674404, 67.91791054510301, 74.16469297101422, 83.55140332252749, 84.02611993974256, 81.63766322597381, 87.0936958251461, 81.31236537810295, 80.76447302295317, 74.17651499471357, 74.10020920538133, 72.26536366247362, 73.29919845827165, 69.56318009284236, 70.76803022815336, 67.82540536695912, 71.08139622596003, 69.1099972878733, 74.60501824655842, 75.89255978984218, 78.36042881011963, 72.49703453433129, 62.11254773601409, 58.64281123684299, 65.31193094868814, 66.89710586301743, 78.86767756554389, 73.3898836566556, 86.46517522873418, 45.50528733961044, 39.49267825772686, 89.2782755820982, 75.12904690157983, 79.27971470740535, 67.63494291613179, 74.10570836836293, 69.18743271981516, 76.95838543676561, 76.35511705952307, 77.50987852773359, 76.6737154991396, 78.93680541746079, 75.89160273152014, 77.18096425456386, 77.06698017735636, 72.83165193373158, 62.097623117508434, 62.75361207223708, 77.47129809471869, 80.14841771894886, 80.8455405696746, 83.90209459489392, 79.23667061713435, 80.25278414449384, 76.95458073769846, 77.04727418961065, 75.34314555506553, 82.40528675817674, 75.916501937374, 78.5536055411062, 78.24309502878498, 71.54400056408298, 69.5867927612797, 47.96890058825093, 53.518975934674664, 68.4728317876016, 54.52335765284877, 11.38307321456171, 0.05775047330966881, 0.061169489241775975, 0.43753172060655016, 0.20072433646888505, 0.02179928660963572, 0.034781050597948414, 0.012699045943126324, 1.01931742963291, 20.982758460506318, 48.766918566919145, 68.22653047500118, 33.78105225101594, 13.492590573526199, 43.186923380820986, 39.82882145912417, 45.66785781614242, 9.871777123020543, 0.06576672541878878, 0.09171136549764103, 0.026795472649316636, 0.022394222830752694, 0.01617790196060894, 0.024384042368300503, 0.018770040891643976, 0.05459327941700336, 0.048273548168400605, 0.06699785169574522, 0.11473568607001536, 0.004865599170913019, 0.08606040219385779, 0.008059653862860174, 0.03105420521610687, 0.02160603710029635, 0.044262013022577575, 0.2460517364764406, 0.008839441354446595, 0.016434526093484416, 0.01973535764151283, 0.067278117301964, 0.03713542265036414, 0.03728873216577115, 0.0437567052581618, 0.099150286086144, 0.09706204531774407, 0.05965029092265233, 0.03142182208267191, 0.041974110588912046, 0.0259559590279335, 0.07773114954151454, 0.09998017381275855, 0.07235240025986588, 0.06691081644666773, 0.023407159605994824, 0.012311627618938446, 0.0750984194418115, 0.01192322199893815, 0.024421237852244128, 0.06889804086137204, 0.03356346875549324, 0.034797077157324365, 0.026742679615234657, 0.05942553604742693, 0.06800780072808266, 0.04434895251066454, 0.11092243746163384, 0.03656138530782154, 0.07170595228672028, 0.07333932835007868, 0.022687366374978618, 0.05746518599710638, 0.07137850332524508, 0.03862222311116996, 0.011605037913297214, 0.035109549099879886, 0.07079564831069401, 0.04769744621890207, 0.09968837858327936, 0.035060381576899564, 0.023006217914723584, 0.10891322632350268, 0.024959414619051164, 0.03428897317198496, 0.044777096068907174, 0.04469979779734727, 0.0879659616358338, 0.8053305024100889, 44.593030329673525, 72.29661710800664, 51.17179824459938, 12.679900969228438, 31.267222858244377, 97.8100347518921, 101.33028353414228, 48.533066857245664, 18.87180551405876, 5.358282721811726, 0.36623908807673766, 0.03554312805194528, 0.01744504969176506, 0.23746326265315856, 0.17394104461756446, 0.22059155507914482, 0.3332552031403588, 1.834017064782881, 38.44042401159964, 77.15855967613959, 92.25382481851886, 87.95365195120536, 71.00987572823801, 72.80353638433641, 84.38148667735439, 87.097335784666, 82.69590300898399, 84.11024693519839, 89.22551970328055, 83.20540320488715, 79.20725284084197, 77.73215924539875, 79.55884625834804, 77.98323800486904, 76.65376632444321, 69.78103637695312, 74.19138077766665, 70.369015355264, 73.00039229854461, 70.87258492746662, 77.23347694643083, 76.70020718728343, 79.1044867423273, 68.6096283697313, 63.06152597550423, 58.06390470074069, 67.87599609744164, 67.34494639981177, 79.98073639408236, 77.5357504813902, 88.12553805689659, 43.6263386664852, 38.12005266066521, 89.84408532419513, 74.99301125926357, 79.82574785909345, 64.93450872359738, 70.53526893738778, 70.09195481577228, 75.92336608517554, 75.67041243276289, 76.32937062171199, 76.01614582923152, 81.73652264379686, 75.86911186095207, 78.69673282869401, 75.91419558371268, 74.5850847613427, 62.53948203979, 65.10358248987507, 77.5119338497039, 79.46110079365393, 79.77168190863826, 82.44063515816966, 82.22954104023596, 80.24016195727934, 80.38878840784874, 78.91460480228548, 77.12656882501419, 79.90149667186122, 79.50955775476272, 81.51829765688989, 79.01591177909606, 77.71864275778495, 77.9618061742475, 59.898095207829634, 53.71266257378363, 71.84257138159968, 65.11972304313414, 16.230589305200887, 0.039130250487716935, 0.07550543429510248, 0.2705077911096235, 0.08842566801655678, 0.09152070919592535, 0.03337857726540777, 0.1145042815516072, 2.8863935172557835, 26.28540285172001, 36.05977673684397, 77.45430638713222, 66.13822921629875, 12.276163562651604, 33.10873446925994, 48.072529608203524, 57.6487139732607, 15.567095875740053, 0.07249660865073243, 0.10710643093672492, 0.013516917580648536, 0.03337535586568617, 0.034242889152899865, 0.03065066457155251, 0.029453751781294425, 0.05729802178158876, 0.040184169136468446, 0.027100285627849163, 0.07153231845868212, 0.031138587885746555, 0.02407894593723599, 0.018324593322411663, 0.02007512338159065, 0.05262866608738419, 0.10264137173972784, 0.14349528558311925, 0.01729979559088186, 0.0203356622237592, 0.07945091734009405, 0.04276180985353647, 0.032138146850610935, 0.039510532702890136, 0.042935489646850095, 0.1074531699921335, 0.06740992272933645, 0.037190270715303, 0.021459344669335315, 0.0481031472314029, 0.055983123790112235, 0.15134860611250325, 0.23188548372878184, 0.26615662620432917, 0.171135492743023, 0.2038305778537066, 0.0844405245997252, 0.13763238405508382, 0.11554076020876247, 0.06770655197361786, 0.17491802122564087, 0.11042994251775165, 0.12088708864945559, 0.11661776491711218, 0.12230330942979745, 0.1089778918051912, 0.10720940081462746, 0.15908448536309505, 0.13598480472160926, 0.09038755790360513, 0.17909677038269659, 0.0943144633164329, 0.1558033001398848, 0.19734354449375985, 0.0970581152866925, 0.12547105235318023, 0.19409618971328582, 0.18830447307517453, 0.2468688152129612, 0.16006729956115448, 0.32403441566613417, 0.13485888529929424, 0.23459771077238747, 0.13446385972201824, 0.08022447462163626, 0.258399281170099, 0.19840952519687916, 0.21385607940535392, 0.48858519883886464, 47.862463151254964, 88.0280985370759, 80.63882381685319, 64.984577778847, 31.805121014195105, 66.87861581002512, 111.6995946822628, 78.06070481577228, 22.595521365442586, 4.549365947323461, 0.41666964489606123, 0.14044273164003127, 0.16267685550114802, 0.7348408525989902, 0.5266552334350925, 0.5171366829064585, 0.2508098319653542, 1.0764724304599147, 30.78090975361486, 70.19661149671002, 91.06179298893099, 95.83364655894619, 82.54975549636349, 78.70640539353894, 81.71360815725019, 86.25047253024194, 85.7150690017208, 89.28329621591877, 93.20783938131025, 89.2162472201932, 85.36657425665086, 82.92319651572936, 81.03099807616204, 84.72722007382302, 79.8602568718695, 77.57491926993094, 79.01605298442226, 75.88220473258727, 78.89593432026525, 76.31000195780109, 80.55357502352807, 82.8550257221345, 86.25912527884208, 77.320843819649, 67.54526184451196, 64.73057685359832, 69.71731355113369, 72.01994880553215, 84.91351696752733, 82.84073260522659, 89.16890421221333, 53.908624187592544, 50.925316502971036, 89.10305546176049, 81.66730849973618, 85.64369755406534, 74.06040499287268, 79.82506536668348, 78.50775303379183, 82.00176115958922, 84.11977829471712, 81.15995776268744, 81.86293278971027, 84.93604706179711, 81.52626791308003, 80.63306577744024, 81.71967214153659, 78.21723876460906, 67.29629332019438, 69.249343410615, 84.3278443428778, 85.04560670545025, 84.91150871399911, 87.58255650920253, 88.87620910521477, 85.9536510898221, 86.7454364222865, 85.50284524117747, 83.1410292656191, 88.14300044890373, 82.03819213374969, 86.6331232747724, 83.85996833924325, 81.2627552401635, 82.26497573237266, 65.43079053201984, 66.30109387059366, 74.87544998045891, 61.82615587788244, 13.68341584359446, 0.09427269620280113, 0.11330405160063699, 1.0063915038781783, 0.35624939347467116, 0.4800452490247065, 0.11642344671511844, 0.29018356434760556, 1.6949108194920326, 36.330847817082564, 63.70166855473673, 80.30120972664126, 47.20557205138668, 24.741153947768677, 58.99014888271209, 59.776395828493186, 75.22609418438327, 19.673845883338682, 0.16508728986786259, 0.21389564018576376, 0.21915206054766334, 0.11715277007991269, 0.17004697373317135, 0.13636308361686048, 0.18201643871443887, 0.2280874802700935, 0.1992610319247169, 0.15369441330192551, 0.17856018707877208, 0.1289184709950801, 0.10557625457764634, 0.09206628637208093, 0.1311862904338106, 0.20789612985907063, 0.1579313544977096, 0.35924936314263656, 0.0853898837381313, 0.10061244149842571, 0.17687456381897773, 0.1470885290614059, 0.1375214392018895, 0.2704991496378376, 0.18764975901332595, 0.3004846277256166, 0.2102621924132109, 0.14786287541351012, 0.1263194334422869, 0.1221293232013141, 0.12390416506077014], [0.039379738511577736, 0.06703942728739593, 0.038502200116072936, 0.033565349501347354, 0.028409656294952, 0.005633684669456055, 0.053140171503107396, 0.041620503555262284, 0.10141797528992738, 0.017113404483684612, 0.03411256993610052, 0.06259458132028099, 0.054418940788074854, 0.04788964618778518, 0.05189859195642414, 0.06785639877160711, 0.044426361864973465, 0.013522360635350549, 0.0399714878069297, 0.02731909949122177, 0.03583203129951031, 0.0482894751363464, 0.07129598799492083, 0.05877270656187208, 0.07170088078466154, 0.026911586680780017, 0.07151446094916714, 0.1261647296468577, 0.04790019904894214, 0.08168050899140297, 0.2720046349831166, 0.13415966152904496, 0.07718914999596535, 0.2264800745873682, 0.05021274270069215, 0.1592567019284733, 0.04376497900774402, 0.09435187905065476, 0.13170441101876, 22.902725319708548, 74.7552764031195, 66.4698891485891, 59.920860644309755, 22.319096249918786, 32.90712072003272, 82.58176988170993, 84.07891504226193, 42.030110513010335, 11.517682094727794, 0.26042380640583657, 0.027317923546258, 0.033618454716258475, 0.037902594589057474, 0.09488230300766808, 0.43153852284435307, 0.06944445307336508, 0.21734225443534314, 0.09651493596573991, 9.458389705227269, 33.912906646728516, 76.30049413250339, 87.66563230945219, 74.44682905750891, 68.25175915994953, 84.64896094414496, 88.78564157793599, 87.38702635611259, 83.08506488800049, 86.07194977421915, 88.47987713352327, 83.8791016609438, 75.73296639227098, 75.7027013840214, 70.29925992411953, 72.95496340720885, 74.74637262282833, 75.18794521208733, 73.84389015936083, 78.73017495678317, 81.77371455777077, 82.96260064648044, 80.9958222604567, 77.95112948263846, 71.19352109970586, 67.19703382061374, 73.401046722166, 76.88035380455756, 76.82828041814989, 87.79879677680232, 50.639909159752634, 44.58272626323085, 78.54179136214718, 83.11331379798152, 71.32811330979871, 78.012145873039, 77.04569739680137, 80.82996091535016, 78.79171694478681, 82.61504727025186, 79.52854202639672, 79.44720775850358, 78.72447183055263, 79.44457192574778, 76.91760063171387, 79.96357994694864, 72.97168839362361, 69.08214845964986, 66.49658479998189, 81.2935850697179, 78.01946501578055, 84.05734985105454, 80.71893430525257, 85.71439435405117, 79.01508023661953, 82.29624486738636, 77.30715474774762, 84.3336102270311, 73.73885693088656, 80.90138727618803, 71.65180298589891, 50.55755899798486, 53.608578558891054, 38.75981084762081, 75.40486012735676, 78.83982873732045, 22.126733410742975, 0.41838001279580983, 0.20785655375690232, 1.3428136225669616, 0.40984116614826266, 0.3868743404746056, 0.38986407520790256, 0.05043365947541691, 0.031433493432198326, 3.2914525174325515, 26.40901830888564, 68.95787992785054, 52.83049014306838, 17.932788133621216, 23.896369549535937, 49.44200161964663, 42.50306598601803, 38.61795440796883, 6.310786681790506, 0.15023483684466732, 0.025425931521421, 0.030281837286067106, 0.04185223366103826, 0.013852879694182307, 0.02997188577278247, 0.028769397777655435, 0.060883822715691024, 0.07567542154462108, 0.05249954579818634, 0.026446632597775712, 0.008104461387941434, 0.03962402096799305, 0.13547788434211286, 0.029325276921172778, 0.0660367637512184, 0.06342006787177056, 0.04925941139639867, 0.031791719976031495, 0.03284476336932952, 0.058709603899549094, 0.01987473967845642, 0.008953248503647985, 0.2003926050759131, 0.05747895642754532, 0.044208180024138385, 0.07122200688407307, 0.08142609119174943, 0.06299185536561475, 0.03304593039736633, 0.09048790009992738, 0.09307665675277672, 0.05717332948059325, 0.014261777208547198, 0.023542579053150072, 0.06335355611818452, 0.017870563653207595, 0.04979064740661172, 0.03711949185197873, 0.055900282872420166, 0.016752826049923897, 0.03959938358034819, 0.023553135744746656, 0.03555478407971321, 0.028229257910542434, 0.047883410232081536, 0.059664061353091276, 0.06008750496191844, 0.06699076538244564, 0.021594877114459392, 0.05326207524405853, 0.025418653686140335, 0.03444605950085867, 0.07281001522055558, 0.05163194739349908, 0.07656147883784387, 0.008832037114658424, 0.037748258515831926, 0.10295435696119264, 0.10298732938545366, 0.0361809000793484, 0.03342217149873895, 0.10736056528384648, 0.08192546560519165, 0.19295349296542907, 0.1507814712221584, 0.048041082618217316, 0.03834446644290321, 0.07072424891615106, 0.03512418520967326, 0.013463302917267769, 36.21900143161897, 85.60441893915977, 67.8023261408652, 27.911052703857425, 19.828110741030788, 61.780068028357725, 96.8187576724637, 71.3138045034101, 35.103059661003854, 15.527612316992977, 0.7647983225122575, 0.1279897119609579, 0.023493838624187538, 0.08963812473079852, 0.0994818336180141, 0.22961879810017927, 0.1709130820968459, 0.18309558080809732, 0.6657509986431368, 16.207341417189568, 47.20813728147938, 95.48748954649895, 91.09852206322455, 72.69744411591562, 73.72323020812004, 90.08584453213601, 90.75832705343925, 85.9874854549285, 84.38254571730091, 88.6957016298848, 86.85966368644469, 82.23372228683965, 75.4494966999177, 74.31975995340656, 75.37561493535196, 75.64674485114314, 74.83784229524674, 75.01865571545017, 75.19090267919725, 77.29250077278384, 83.35728522269957, 79.85538528811547, 79.71240705059421, 74.37117438162528, 68.38957555832403, 66.77381007902085, 74.8024703610328, 79.88487366707095, 77.51195738392492, 82.72232409446471, 54.03652483417142, 47.550846530545144, 78.71848629366967, 78.60434532165527, 76.02920732190533, 77.59610006886145, 77.2454401754564, 76.5064577902517, 78.95591520494031, 81.90517671646612, 80.42849063873291, 82.55037523085072, 80.90900451906266, 79.95846517624395, 79.35096063921529, 80.6945057838194, 76.8606948852539, 69.9899967255131, 67.23266463125906, 81.25025072405415, 83.7289454860072, 82.22717192865188, 76.83392863119803, 83.70635263381466, 80.74746562588601, 80.39971613114881, 76.89107756460868, 82.4474443927888, 84.64806664374568, 81.83890435003465, 74.6733694691812, 68.2361481266637, 63.762308397600734, 47.79713215366487, 72.08334999699747, 85.30491459754207, 32.48988643769295, 1.383670378596552, 0.18044802690705947, 0.37656092775925515, 0.34482944336149, 0.06780022154411963, 0.20039632826322512, 0.09526823512128285, 0.13973399305776243, 5.739098287397816, 24.47658811846087, 67.17005575856855, 82.38640446816721, 38.29457459911224, 10.932122238220709, 38.45616056073097, 50.98313616168115, 51.39670695027998, 10.464295264213316, 0.17601513574200292, 0.011553798122481715, 0.020326819653893193, 0.036658881487505096, 0.019542205808383804, 0.045500359678220366, 0.08192836907842467, 0.06055443555176739, 0.05897898339636384, 0.030627568935855266, 0.06267115180831283, 0.009767287786328986, 0.04905449053753288, 0.04221189278928984, 0.05459377737415414, 0.01623921963806835, 0.03501972912119762, 0.09930047762369919, 0.06495040510931323, 0.046052417958215366, 0.03888228314838583, 0.04239178172522976, 0.06626114324336091, 0.0852776518572242, 0.08760963882049246, 0.04115471826686014, 0.04712376510724426, 0.06133285366118916, 0.024440558589694482, 0.04094325118668137, 0.09156376333726991, 0.038004760074639515, 0.1469263635695942, 0.20237251335094053, 0.1774249520272978, 0.17445200994130106, 0.1622306552505301, 0.09490278053788409, 0.14514589862477395, 0.19950041907929605, 0.21053309642499496, 0.10854243976815094, 0.10481171415097291, 0.11756348513787794, 0.115733714774251, 0.13968766006010194, 0.17528767397086467, 0.15347662982681107, 0.17746814406446873, 0.06583583421043812, 0.10861861955134139, 0.12943960996645112, 0.10828332584952155, 0.13626579045047685, 0.12440196899396759, 0.22574847594143885, 0.19054480527918186, 0.114020588957975, 0.1568904861567482, 0.2650767793097804, 0.17045218827984027, 0.14828494389451322, 0.36222438898778736, 0.17558975776116695, 0.2928691315314462, 0.2865413678509574, 0.10483507217178423, 0.2194197776336824, 0.12203905506119614, 0.19320870749652388, 0.4037682033113895, 36.458975961131436, 102.34502423194148, 88.72488406396683, 77.24194926600303, 36.30953757993637, 50.40910905407321, 97.58121936551987, 102.2114832170548, 56.99365462026289, 19.51803953416886, 0.5724872708801301, 0.35108121111989027, 0.11143659737201468, 0.16532486905494045, 0.38096510594890964, 0.6897156385164107, 0.2167347773549057, 0.30353221741895525, 0.46049765761821504, 11.654542415372788, 40.82310699647473, 88.618540763855, 96.71335574119323, 85.92180928876324, 83.53183854010798, 90.03568526237243, 89.2899642452117, 89.89702947678106, 87.82173479757002, 90.11265000989361, 93.81335135429137, 91.37151902721774, 83.56848132225775, 81.0419964021252, 81.33647226518201, 79.55151927086615, 83.27369166958718, 77.40373134613037, 83.70504256217711, 84.25930484648674, 88.65858816331433, 85.93518457105084, 87.2275584743869, 84.98741442157377, 80.22214258870771, 74.21162805249615, 82.47473624444778, 84.31515155300018, 83.73015357602029, 83.38282769726169, 63.2057083806684, 56.07322339088687, 77.08397972968318, 87.05182060118645, 78.03220487410023, 85.5725222249185, 80.75742060138334, 82.67860535652407, 81.86544310662055, 87.84425704709946, 85.48695179723924, 85.57943344116212, 86.98579926644602, 85.15664116028817, 84.79830911082607, 86.89825980894028, 80.0511194044544, 79.81971525376844, 73.164974950975, 89.32200216477918, 88.01956345958095, 87.37812257582142, 78.25625065834292, 88.98952637949299, 85.8267859489687, 89.69249356177546, 83.79919513579338, 89.98161146717688, 83.59800108017461, 94.56955294455253, 71.81758588360202, 73.91780330288795, 74.52916745216616, 58.27959191414618, 85.3328340284286, 80.99952497789937, 25.543145287421446, 0.6990909612467212, 0.1658417179339355, 2.265630388452161, 1.4780256897211077, 1.548231212842849, 1.5251463483418188, 0.22034349580926282, 0.27479282730529386, 6.568028955690323, 41.69452428817749, 82.56987725534748, 63.02729545101043, 30.23571206677345, 37.975207374941924, 64.56867710236581, 64.81106781190442, 70.65404615094586, 12.366580078678748, 0.3076439645261534, 0.16618449631477558, 0.1029932589059876, 0.1748569640180757, 0.12266206074385874, 0.09430881724843095, 0.1273865173120172, 0.21134685033992415, 0.16010114532564917, 0.16268139074165977, 0.1664820448645661, 0.12672465564983507, 0.17580472203272005, 0.2388149941520345, 0.07110939962008307, 0.12982587149787334, 0.1437994071673001, 0.19776932084031645, 0.16574767298035084, 0.16552880166038392, 0.18817783874129096, 0.1684716824562319, 0.14004166928991196, 0.29261681281270524, 0.1708916776002415, 0.07501273250748074, 0.1271283150380177, 0.13467733778299826, 0.13834412570201582, 0.12276495401296886, 0.19246373295543656, 0.25204237550497055], [0.037620838941825975, 0.04740326079509912, 0.059147403996077284, 0.02258754320322506, 0.09730932317794332, 0.005843116349780993, 0.0380532227967295, 0.0749066140082094, 0.07116141699014172, 0.041960236736603325, 0.028299785880071503, 0.04609437276338858, 0.10167496714500651, 0.07269794421811258, 0.047761257512555014, 0.02245910664749963, 0.04676854162807426, 0.016616550499513265, 0.17660773539495084, 0.03448375868761251, 0.08781069093534062, 0.11482056861202564, 0.042300755158066757, 0.07746328689878987, 0.19231187900708568, 0.13415609155931782, 0.03566705809545613, 0.09324081407319154, 0.09094452680719477, 0.10635652278940524, 0.022531287451725335, 0.13824091833685676, 0.11559371220608873, 0.44127743090352706, 0.09412974419613039, 0.08209611169032513, 0.04535852232947946, 0.16711106433743433, 0.16137121185179681, 0.26786530871064435, 8.047200835520222, 59.425092666379875, 77.43163508753624, 77.02613261438186, 48.93018330297163, 50.37603955115042, 48.80904874493999, 92.51389365042411, 77.09333066017398, 22.542569368116318, 2.4751227084667455, 0.04440221094316052, 0.09594541854195057, 0.15507292723463428, 0.5135547622076927, 0.057213223509250156, 0.17918419633661548, 0.04521366659431689, 0.6802051778762572, 0.3842266793212583, 3.9823890549521295, 32.54776493195565, 83.88001165082379, 94.83798426966514, 66.23881447699763, 67.09454228801113, 84.19024759723295, 95.0321965063772, 92.16938403344925, 79.37640113215294, 81.20847748171899, 83.14612834684311, 83.80551799651116, 78.86858755542387, 74.90092969709828, 73.2695374950286, 77.28772332591396, 76.92717905967467, 80.53941526720601, 79.9970926777009, 85.34813911684098, 84.01552169553696, 80.99546140240085, 79.32439834840837, 76.64358385147588, 82.33508417683264, 82.92301608670144, 84.38260847522368, 73.96178091725996, 63.36623137997043, 45.56431116596345, 70.53268017307406, 88.71021439952236, 78.04547033002301, 88.62802505493165, 85.63352292583835, 85.94044054708174, 79.53728106714065, 84.79487311455512, 79.87101985562234, 80.6163094120641, 82.20025662452944, 81.37760223880892, 79.09184886563209, 81.89451571433776, 78.23383823517831, 77.93724429222846, 66.06506916784471, 78.4122197858749, 86.0279643151068, 91.30569381098594, 85.61173023716097, 82.61572976266184, 76.28358871706071, 82.9758111892208, 76.70889131484493, 82.56664522232549, 56.768436047338675, 83.45623877740677, 41.32735513871716, 50.13807719753635, 63.05528548456008, 70.87838219058129, 51.025756635973536, 3.1227832455788893, 0.4716757078084254, 0.04988331340193268, 2.230506544151614, 0.3743596813611446, 1.1153003405178747, 0.1926432273560955, 0.17658487533129033, 0.3389634774817575, 16.37848129195552, 48.4108458026763, 63.33729213283908, 34.78937595121322, 15.415728669012747, 36.96287109005836, 55.43126475426459, 49.7567992825662, 38.98933226062406, 2.4209052564636355, 0.2934853113707035, 0.036594510949667425, 0.0604668487193844, 0.045760871707311565, 0.03797835302388957, 0.04807945979278415, 0.04214678297660524, 0.03918777986039077, 0.02274563119205977, 0.009811909535088608, 0.040956998634482586, 0.05478881186835709, 0.023676780420505715, 0.04330727211650341, 0.03944083019309948, 0.07016951698930034, 0.03643021573342624, 0.10639962289602527, 0.10550934445833969, 0.0482473632831487, 0.006891950568740046, 0.04421624309954144, 0.07094256099193327, 0.022659902122893164, 0.020996045336247455, 0.04174776608124376, 0.0665341463360575, 0.062525357615443, 0.06369637663386042, 0.019544994368428187, 0.02383530507945726, 0.07105170553850551, 0.051558544679034146, 0.012916340079579144, 0.11108412797893248, 0.033247426843210574, 0.014972046051444787, 0.03290185990232614, 0.10914344340562822, 0.02628217458785061, 0.02397933343966161, 0.07553105993616967, 0.052998617606898474, 0.014720481929309187, 0.04297282877227953, 0.06671616882686654, 0.02781128416949463, 0.010239322436973453, 0.01832892746484328, 0.05773325931401022, 0.04686902555066252, 0.14002116877705822, 0.026522785567888812, 0.01015238390649639, 0.038369161287142385, 0.0302242964220744, 0.11013873717597417, 0.15407656860207358, 0.056310346755649776, 0.03856947412714362, 0.0529489751094051, 0.09806349077412198, 0.026192448454939073, 0.10336205363273622, 0.19508222148062723, 0.09463032902849298, 0.424481688608085, 0.1713387511910931, 0.11359062211047258, 0.07061950937514344, 0.04654892337238116, 0.10962052466047388, 0.07280911123680492, 17.639696867235248, 72.96622845434374, 86.23214721679689, 51.795796348202614, 28.455301177117136, 58.18253678660239, 84.44255798093735, 103.91525099354406, 68.05813527876332, 22.40719464517409, 3.4560751290090623, 0.08888584937179282, 0.16008674287267272, 0.19146870731586413, 0.3172130768577899, 0.29870310557946084, 0.6942264255016082, 0.0903047054945942, 1.2019668255121478, 0.33078653076964043, 8.559603095054626, 49.71781092305338, 99.85014577065745, 95.21497895640712, 66.50195060237762, 73.79750420970302, 91.58172668949251, 95.0961389849263, 87.72879031396683, 86.00006057370095, 85.05397704339798, 86.73810943480461, 84.21161666993173, 77.97638170180782, 79.04939313088694, 79.73218364100303, 80.78888585490566, 79.66388733156266, 83.19522073191982, 84.18979260229295, 87.83524344044348, 86.31793729720577, 83.37782275292182, 78.98936517776983, 74.49654902181318, 78.03259711111747, 80.18236975516044, 86.65718309340939, 78.00380691405266, 60.5925626139487, 53.50225487063008, 67.89522355602634, 89.07799936109974, 74.4724186005131, 85.36929638155046, 85.0721376172958, 88.80206846421765, 79.5633020708638, 85.19877526067918, 79.54075628711333, 80.31267089228477, 81.79947668506254, 81.92154084482502, 76.5343850658786, 80.11841158713065, 77.17018558133033, 74.06323694413709, 66.92132257646131, 83.65753481465002, 81.25156079569172, 87.18696194310343, 80.66977131751277, 79.95044785161173, 78.11589256409677, 89.272580300608, 81.50305532640027, 87.87365913391115, 56.70214406905636, 84.05594564253285, 43.98694961301742, 56.45836484047675, 68.83805151908629, 76.76410259739046, 68.83531370470601, 6.73036507060451, 0.582677772448909, 0.43180984054361626, 2.7053756435071272, 1.0403952050593592, 0.6778393145049773, 0.12536893283287365, 0.11276511640678491, 0.5171790322469128, 17.02399653773154, 48.279870017882324, 83.96505648089995, 67.64936154888522, 18.992071267097227, 9.52341377735138, 52.926968682196836, 59.47735432655581, 51.19156699026785, 5.027572983695615, 0.34650454057320473, 0.11637728991768054, 0.0334186360029684, 0.06740755551765043, 0.015646598917702516, 0.0394157063396227, 0.007989990136270683, 0.029318407027711792, 0.040801762407946016, 0.0032603320705088517, 0.05732779578876592, 0.03190813469700515, 0.018219581820190917, 0.03365741028720814, 0.059609358844858025, 0.04849511994830063, 0.035428299132974884, 0.07220541863071342, 0.09377286979748357, 0.03921270070056762, 0.046357156243175275, 0.05907888892256926, 0.031657273460540085, 0.03930651199733538, 0.019746441018557357, 0.09418686371176474, 0.055322794303778684, 0.04840021314580114, 0.058069840043542854, 0.013608257286250593, 0.03559305783241026, 0.1692261411658218, 0.07443168546043097, 0.2885022465019457, 0.1889987938827084, 0.0871444778937486, 0.153810475622454, 0.31309183026033066, 0.2663147161083837, 0.16393638065745755, 0.27851892575140924, 0.1950624257686638, 0.19255604655031236, 0.15273697193591826, 0.16872925653813348, 0.23703984585740875, 0.07914202302814492, 0.16794810732526166, 0.08754012400224324, 0.17657770474831905, 0.15369819777627147, 0.3214207994601419, 0.14525788535754527, 0.18818640360428443, 0.3792924908620696, 0.21645132482292193, 0.20794777950692564, 0.3141969580563807, 0.3155484903723963, 0.05936011979957262, 0.12963525350055388, 0.16814404197277563, 0.28699899813340557, 0.1918409341165135, 0.27616014103254966, 0.3770914589685779, 0.5504803227320795, 0.3288366531412448, 0.13678800194494187, 0.15142737527287778, 0.27185389952313516, 0.26758838324777545, 0.3720454216724442, 16.143252830351553, 85.22595728597334, 102.9443153258293, 97.6663818667012, 67.31522267864597, 66.74846372296734, 59.97633472565682, 102.68498389951645, 97.30155437223374, 36.50150229853969, 4.66992489753231, 0.2271990787478224, 0.5089663858375242, 0.4727108458117132, 1.2217832524930279, 0.3669611719106475, 0.5382954797917797, 0.29935921392133163, 0.8164649468756492, 0.3271187162928043, 6.222461279361479, 41.18857775965045, 92.83747350015949, 100.362681881074, 75.69103625512894, 77.0801358069143, 95.59034978189777, 97.20975522072085, 91.85972075308524, 85.09146705750497, 85.31846246411725, 91.90667152404787, 87.39982897235502, 81.8269411210091, 86.31326183196038, 86.97918615033551, 90.59794133709323, 86.00401432283464, 90.81462875489267, 89.56447524409141, 90.2026762500886, 91.92238453895816, 87.6835967648414, 85.96991323655652, 82.39992095578103, 87.13328822966545, 86.52399509183823, 91.5171487869755, 79.98121492324337, 74.69199288275935, 61.30589662059661, 71.26519064749442, 91.45759151827906, 80.6127400552073, 92.11700470216813, 93.0842141182192, 92.62516344747236, 85.62354441611998, 88.97884968788394, 82.6736004121842, 83.64228463942005, 88.3503604704334, 85.6125774691182, 80.13842351974981, 82.85290764224145, 84.55512216014247, 80.61695268077236, 74.10035041070755, 89.02058370651739, 88.55312347412111, 91.87195854802286, 85.52051159643358, 82.23529123490857, 83.95535253709363, 94.69811254932036, 90.117552972609, 91.35847322402462, 62.15275595265051, 90.34350502875544, 45.34130480981643, 77.22411817119968, 78.60748321779313, 85.19180128651281, 53.65543911533972, 3.2050169619821736, 0.6687274647335852, 0.3681168615097, 3.673771821683453, 1.5394791792477331, 2.3064448564283313, 0.729539953172207, 0.5016703483077788, 0.7453360733005309, 24.884149835955714, 62.41897898335611, 76.79139444904943, 49.97463987719629, 25.439429975325062, 53.10384796511743, 74.9545092736521, 74.01805123975201, 62.67736119608726, 5.162663334800351, 0.4949777122707137, 0.256496625201356, 0.08275031247326443, 0.13723676092922688, 0.11208695239357411, 0.10299425482028916, 0.08476307825936426, 0.10663316479974216, 0.20336153286118663, 0.13168611683912818, 0.21806415440815113, 0.21122547136920117, 0.10625690837661106, 0.15021802887560862, 0.12480542153841066, 0.2654190980378659, 0.11606040530868116, 0.17239178500829205, 0.18738882946631602, 0.1691914527046104, 0.1043135424955718, 0.15758036365432126, 0.1308532413696089, 0.17383109567867172, 0.15321920896249433, 0.15494508248183037, 0.12255632528854955, 0.09725644778940948, 0.160813637738747, 0.12420777336604173, 0.16223995555793086, 0.33439318078660196, 0.21904972652273796], [0.039524755125204404, 0.06807605916213605, 0.04122974125728492, 0.049115053618386875, 0.06202155521379844, 0.027162264056143262, 0.013466360565695553, 0.04758175928145648, 0.02717575486448984, 0.07255205809469185, 0.05511578968575886, 0.05388711872059972, 0.06328349354706946, 0.053914755342468146, 0.09403167728094325, 0.07226423886153968, 0.03327759155522912, 0.07777992635965347, 0.03241741271208852, 0.047964814734915574, 0.048255047145029234, 0.054125237999664205, 0.046379349810341676, 0.03006007781462564, 0.09521914420709496, 0.1737600946498494, 0.15662735027651634, 0.24352478013644296, 0.13695952903118827, 0.12556948699057102, 0.04825839494925834, 0.18144481454885777, 0.07705876949213206, 0.16610093144399507, 0.23364065245034235, 0.09295449637237096, 0.054965169138966076, 0.06443737900906032, 0.024370530492536003, 0.07228413416493325, 0.1458989324108247, 1.8118369194769093, 38.96284841722058, 74.02282868662189, 76.07578154533141, 55.104856875634965, 34.71789467719294, 35.47323726838635, 65.28099913750926, 88.57355117797853, 58.971439176990145, 13.751781775105385, 0.4788338801553173, 0.14731965778816133, 0.2833406525033136, 0.11305164861222429, 0.3761987826756893, 0.2214718973564525, 0.7438135808033328, 0.48474443235224296, 0.34450658326668127, 0.30188065442827444, 4.031989877262424, 37.48119269647906, 76.30284755460679, 99.33660553347681, 83.24344235081827, 67.528395652771, 82.34430959147792, 102.49722788410803, 101.08865768678727, 86.00441440459221, 80.60546798090782, 72.71523598701724, 76.11855106969034, 82.52031418585008, 80.1734895090903, 83.86803273231753, 82.65770696824598, 86.04410879073605, 86.84359765821888, 85.07442828147643, 83.70544264393469, 83.9480333943521, 81.36166957116897, 85.4844493250693, 80.06675397196125, 83.87181389716365, 79.07332743367841, 66.23961464051278, 31.920509299924298, 59.03321258483395, 92.05900853680026, 84.22724339269823, 83.70964742475941, 76.25720685528171, 81.96452217717325, 82.76008867448377, 85.43364678659748, 80.657439385691, 83.60680287884128, 83.62386518909086, 82.74155939778974, 84.71023621097689, 90.62200900047057, 85.21027565002443, 83.55207012545678, 80.79767196409165, 88.03424096876576, 83.56676332412228, 89.06757370118173, 88.9659764689784, 87.03256960838073, 86.43640072115006, 86.18804408657937, 80.49036210583103, 78.62194891898864, 74.7855100324077, 79.43797449911796, 74.03876135426184, 59.0951075861531, 40.506587413049516, 11.017572053017156, 0.24648053120941887, 0.19958458149865752, 0.9668637571796295, 0.11047298899821698, 0.2569772687650496, 0.49326765080613477, 0.2436865932278095, 0.07818871853692878, 4.872700158626803, 40.839314230026744, 67.53747201734974, 45.49932141457835, 22.35137539525186, 16.868123508268788, 56.710514407004084, 64.89033106834658, 44.70894421300581, 19.65329658600592, 0.4194256615254187, 0.14612149627458665, 0.11326093617225848, 0.03836831475998606, 0.12378589640701972, 0.05886972776704258, 0.0569135414045905, 0.04093968887783347, 0.07008568398774633, 0.07231544417839858, 0.050154546831524184, 0.06313912044729918, 0.07894900717562245, 0.019307246642006982, 0.03926366853017, 0.1467892491529065, 0.04648874333548931, 0.09856592187838209, 0.09631232103152622, 0.055691313238874565, 0.03487505341669725, 0.05568474403492386, 0.03774974089596541, 0.06268228689629225, 0.10898041989534132, 0.09040044350249153, 0.02754593237994179, 0.06263012779996761, 0.07695819746943251, 0.027715042458787083, 0.027615244184891065, 0.013545075142305466, 0.03930622088392416, 0.07231935122681242, 0.07540225757346039, 0.05014803125372818, 0.07463865177405458, 0.026085314889168067, 0.03455798494659605, 0.04814317915588618, 0.05986635453037678, 0.04082739954033206, 0.06286074324781377, 0.10576445939800433, 0.06385216061326285, 0.03306370363720963, 0.07617246705077349, 0.06384369917213917, 0.07954405064904883, 0.06599475148945086, 0.07372295453904137, 0.01775340199650776, 0.11410702665847157, 0.027492336868759126, 0.020086766002819906, 0.058479287225993416, 0.04568309846123861, 0.10370334580300317, 0.08015790924189553, 0.04426110903882692, 0.13048901252688902, 0.11454276980892306, 0.21758700420539226, 0.14858071512031942, 0.1355048812805645, 0.00834597539412038, 0.10165390738796803, 0.05272345031581579, 0.21926971633107434, 0.18221713842884188, 0.05244979604838356, 0.00889602652375376, 0.07364372572591228, 0.0553102687662167, 0.07995326417468249, 0.1672576935661416, 5.870214296925453, 52.88270081243208, 87.34537078488259, 75.16325781422277, 50.26932362587222, 19.874608478238507, 57.78619697017055, 95.16856947252828, 96.18685599296325, 52.98991880109234, 12.809196018403577, 1.0763537787622022, 0.22670617777734037, 0.2528620436186752, 0.17598648405363485, 0.4423477783078148, 0.7060145574711985, 1.4123481752411013, 0.4031967630069102, 0.3376760207597287, 0.09030073715914642, 9.908754287227508, 55.130152240876235, 90.4390775003741, 94.6859767360072, 77.21454758797923, 72.56218510289347, 90.02918197262673, 99.81174576667048, 92.9636561486029, 84.39648582089333, 83.61922894754719, 83.91370481060397, 80.2762399181243, 82.4893980641519, 78.90972537379112, 82.3642901451357, 79.20192626214798, 84.32707555832403, 82.65250590539749, 84.3160693876205, 82.12300162161551, 81.32257138529133, 79.90023366866573, 88.53738692498978, 86.74329480817242, 84.06372762495472, 74.49931821515484, 69.61931705474854, 44.95363735383557, 67.68925205353769, 86.65104066171955, 82.55330916373961, 85.21755556906425, 80.16279712800058, 78.00514051991125, 79.68545252277006, 82.40880904659149, 79.99112283029865, 82.82978134770548, 82.84905587473224, 81.9802273473432, 83.15070967520438, 87.26091431033227, 85.32895088195802, 81.17734170729115, 74.76283088807138, 82.95945490560224, 83.79244081435665, 85.89985970527896, 86.00472034946566, 84.30540838549214, 81.88462349676317, 84.46558229384884, 79.56280000748174, 81.06029818134924, 69.95281265627953, 95.28864891298356, 81.2761148329704, 70.15100217634632, 54.16173865718227, 18.939029055257, 0.48066807850714655, 0.34407699180226176, 0.8775241769129231, 0.8971343730245868, 0.1508384375202079, 0.2242999875377263, 0.28736659776299234, 0.06282592838209483, 5.901447150015063, 37.98368753925447, 77.94923105547505, 67.38167547410535, 34.590496093996116, 9.827604370732463, 31.65948929325227, 62.7768599602484, 53.64934375209194, 28.16154310780187, 1.0152157948863123, 0.22890278168262976, 0.0333838977460419, 0.11007616311431893, 0.10332399438465796, 0.030048892930931145, 0.022727325521109086, 0.1054066886764861, 0.03364841258453746, 0.038565352574111, 0.020251166556150686, 0.014845503648112138, 0.07844077678577555, 0.037908807562123385, 0.06772606423304928, 0.07551892510344906, 0.06743934816650807, 0.015038587490937885, 0.06093598564245528, 0.04709093823968884, 0.1251733429249256, 0.02143213131104506, 0.0397547155678753, 0.024217952591096683, 0.1274239790115145, 0.08635806565683696, 0.06014111579485959, 0.0244578683463436, 0.03655963862735418, 0.015518871950916948, 0.038905315581829324, 0.0303918685794117, 0.032440644328392325, 0.09834129723810381, 0.024905556722754435, 0.10085357533347222, 0.13601411524559223, 0.107653065314216, 0.12171413418987106, 0.14546235422453574, 0.14058502481108712, 0.1524731006112791, 0.10334280184319905, 0.19623951986432078, 0.15979011362839132, 0.3231550080160941, 0.1564459866213222, 0.20415955133015112, 0.21440017037093642, 0.2952070786587654, 0.15622950549567902, 0.13319425284862518, 0.19059245594807211, 0.2675135824228487, 0.15844248836078953, 0.12136642986367788, 0.13765852297506026, 0.21014473581266022, 0.20010614947926617, 0.15170359593485633, 0.2302634304449443, 0.18721940146098215, 0.2736203450589411, 0.22151484424548767, 0.31231504774862723, 0.13392470236266815, 0.2055181469768286, 0.19319372281672495, 0.2888403057811722, 0.34704202786087995, 0.1262609809336643, 0.18917851810974462, 0.28203245012029526, 0.18372331325325275, 0.2463836057652389, 0.27224328669328846, 4.670973641257133, 62.85926895756876, 106.22640563595681, 92.90559722531228, 73.31319347504648, 48.50982289160452, 51.675665916935095, 75.50124845197125, 102.65911194585986, 76.70950320459183, 22.311812408508796, 1.3483191594000787, 0.6445165735579307, 1.0120656413416709, 0.3397957554026958, 1.1556231639077588, 1.247743827200705, 1.4192991054827169, 0.4715307333296346, 0.6532423150154852, 0.4208130773998076, 5.960522947772857, 43.54847569619456, 86.97564817244007, 106.58122324174451, 84.27628870933287, 72.4876836038405, 85.16824353125789, 104.45569084536646, 107.11388895588537, 91.0553446123677, 89.9663063787645, 90.6175845669162, 85.9622803042012, 92.02446814506285, 85.73909744139641, 91.1029229625579, 87.41519681869015, 93.35852899859029, 88.46122234098374, 90.96627543049475, 92.11487877753474, 92.96731964234384, 88.16715440442486, 96.59372345093759, 91.3482750615766, 89.90047331779235, 78.64614209821148, 79.25989104855445, 49.36326396080756, 68.04894908781975, 90.15814950389247, 86.69958391497212, 87.60610641971712, 78.52327777493385, 82.78586649125623, 84.68463882323235, 87.93717799648162, 85.81486194364487, 88.83354940722066, 90.85546062838648, 89.29886018076252, 89.95285264907345, 95.29588176358132, 92.15327093678137, 90.59446611712056, 87.34063256171443, 92.90725246552499, 89.70449601450275, 93.05941689398982, 88.62254158143075, 91.61164652916693, 93.43012794371575, 91.70668555844216, 88.25922027710946, 92.74805130497103, 84.36491074100618, 105.97126330098799, 91.43981533665811, 66.7363279096542, 45.20067999439855, 12.114030430393836, 0.4108516361203886, 0.17255915989798887, 1.4709816031878995, 1.1931234742364576, 0.6780473226981779, 1.77129186930195, 1.2376614972468347, 0.1657619835027764, 8.726306769155688, 56.89366555983021, 80.04136054746567, 58.36304426193238, 34.77745979062973, 28.30936155011577, 71.36841958568942, 80.04352569580078, 66.48603362421836, 32.64846198020443, 1.0876971507264723, 0.31139212630448804, 0.20240897913613629, 0.3261467345779942, 0.21721632490234993, 0.2876734619419421, 0.18332341535677835, 0.20088699225696827, 0.2012146633839415, 0.16187800965722532, 0.16665203977496396, 0.14932827903859078, 0.17320809765688835, 0.16783543111335847, 0.1854184972903421, 0.2984029523307278, 0.17309088620447344, 0.1561821306184415, 0.1587115844050723, 0.1440619914642265, 0.1845916432719077, 0.15101833028658745, 0.1452095145660062, 0.22168988001442727, 0.24707011247594513, 0.32622723509707763, 0.27687232701047776, 0.16190727421593282, 0.09187247378811722, 0.07477756649736436, 0.1278930852910684, 0.1190724332005747, 0.14144333439969248, 0.2750828988369434, 0.15735772318176686], [0.031536499699277264, 0.11377747095520459, 0.045918149558166345, 0.048160163325167475, 0.13439008545491005, 0.03719221274819105, 0.07989346335131316, 0.10243855762265383, 0.01504295898015581, 0.15221557249465298, 0.08193505702600365, 0.0824915279724425, 0.07079508906650929, 0.07699326131372683, 0.020609827854880886, 0.005868345061542407, 0.05503834968793297, 0.05691030468311041, 0.08717833131912255, 0.13746344634602148, 0.13778704188523755, 0.03553152565033205, 0.07825932886090972, 0.023716708923119213, 0.029739805181781133, 0.11930069675849331, 0.08493367071834304, 0.08954646231065835, 0.08067733983719542, 0.15912421468284824, 0.20247565942906565, 0.11616137569710133, 0.17713973749308817, 0.07745915002399877, 0.028106245257320906, 0.09116021886227593, 0.07932198474243765, 0.06396126685543888, 0.0772768747241747, 0.12451845266285444, 0.10160568215313459, 0.020849324176989256, 0.2844351469989746, 23.694345912625714, 66.79845040844333, 70.63631703776699, 76.60695675880679, 50.03018063883628, 28.797284787701024, 37.74325409243184, 66.25502955528998, 89.64795112609865, 52.82054693468156, 9.550031961933259, 0.22230124882152005, 0.05441707536397923, 0.8188088694887777, 1.1031832810371154, 1.196528214120096, 1.2332581464321384, 0.9580879442153439, 0.29143529072884594, 0.4138238121184611, 0.40475452619214214, 3.8746486556145454, 34.245276528020064, 82.55192848943895, 92.94948070280014, 78.49457387001284, 60.935887675131525, 76.77863105650871, 99.75152953978508, 92.06580992667907, 98.12515012679562, 94.53626771127024, 81.58502501826133, 85.3849309490573, 85.77687771089616, 87.86001713045182, 86.19789708045222, 85.42716703107281, 78.49399335922735, 79.04902442809075, 79.98032062284409, 78.27261478670182, 87.25249690394249, 77.99450305200394, 77.39462360259026, 60.0961317554597, 35.66987745223507, 10.116583031992759, 3.7125633272432514, 86.47884861115487, 85.00985037895941, 94.12511702506774, 93.0520663722869, 93.14451663724839, 93.72383502221878, 95.77074743086293, 87.75946324871433, 87.72948065111714, 87.86819134989094, 85.65787299986809, 85.98431617982926, 87.75465442288308, 89.31355337942801, 89.02935412622269, 87.23501882245465, 86.4628061171501, 91.12473918545632, 92.84646357259443, 99.58220866418655, 94.28388672490274, 86.48889772353634, 85.38159693441084, 83.99584708675262, 68.55016523791899, 43.36874877252887, 22.588723897933964, 8.930480845512884, 2.2880258963954065, 0.21154257048281933, 0.23515346159617748, 0.7716549320086357, 0.21331825503899207, 0.3774481495061229, 0.31443714194240113, 0.1508326918607758, 0.029147282137625644, 2.126104817275078, 19.665983492328277, 62.490464179746574, 64.41377878189087, 25.95631403307761, 28.62211173580539, 50.76334222670525, 60.16787582828153, 59.32520558757167, 38.367464004024384, 9.470508848467182, 0.07181869744653664, 0.11114652584036512, 0.012539416202344002, 0.15034011264722194, 0.07301378694753494, 0.023620411671037157, 0.056041924868740385, 0.1486641727387905, 0.11077890322814066, 0.06283763803601747, 0.10230754126584339, 0.0438231059289988, 0.122547599547092, 0.04754820463037299, 0.09964285763881861, 0.00927604060815347, 0.08678633178914748, 0.01750852582195113, 0.1578091328302699, 0.04734579653989884, 0.09484898584384112, 0.041775624868610216, 0.1981098622444176, 0.06111659853148365, 0.0264598744275469, 0.02475774580342395, 0.038049281274359074, 0.07521108799283543, 0.02372724454729788, 0.11198496310821465, 0.14643583747167743, 0.03685130362188624, 0.07088466006661616, 0.07402672372277706, 0.06683324238345509, 0.04371450913529243, 0.05979843700544969, 0.021071552877284346, 0.09171387826603267, 0.10854968695991463, 0.023083610032054207, 0.0071395329488891995, 0.07362621295596324, 0.09897041630240218, 0.08863292544359162, 0.0884511404400391, 0.039572999512235967, 0.03450992825110594, 0.07058619987219572, 0.09369108991156663, 0.10013601141831568, 0.022442084173822117, 0.04057973863617067, 0.01007645693232095, 0.029590372071270982, 0.1653974329031283, 0.04279339565865455, 0.03881957885178347, 0.06345088375852474, 0.016358394190789233, 0.0546249648135516, 0.1600739798478542, 0.11200920213013889, 0.06953917218432312, 0.037466981673553106, 0.07057694553007042, 0.09553751502666744, 0.10590748035258825, 0.11916942759266785, 0.07383150153703268, 0.040870603068821856, 0.08837909753163976, 0.05317960587900974, 0.039039748690782056, 0.057769418664036266, 0.04951371811330319, 0.10305779415272898, 0.1815826644099528, 0.8313345909118653, 33.50902411245531, 74.54641803618401, 76.74787182961741, 60.22571117647233, 26.022335367818034, 29.582186360513013, 60.844857308172415, 97.38799556609123, 94.91077561532298, 45.67518480362431, 7.664616771282689, 0.4241729858181169, 0.3383173895699363, 0.5980955677167062, 0.47725258274905147, 0.5577267790513655, 1.1546173211066955, 2.590337674463949, 0.39694738544283376, 0.5584026524616826, 0.18488053502815385, 10.266880412255565, 55.995976232713275, 95.30673103947794, 87.56695332065706, 76.92946187911495, 75.17930030822754, 88.00379553148824, 104.6242900048533, 97.20345589422412, 89.64853948162448, 92.3335744488624, 91.19540460648076, 90.15843191454488, 91.11370948053177, 90.02563614999094, 88.91915121386128, 88.41446768852973, 87.55211891666536, 85.12726260769753, 88.10259219138854, 84.15600530562863, 86.02250437582694, 75.81535970011066, 82.0715165907337, 78.46867838213521, 65.59187050788634, 19.54324076252599, 11.233193566722255, 90.3518282982611, 79.27219160141485, 86.59217373017343, 80.65438778169694, 87.8728432809153, 87.49133786847516, 89.79083522673577, 82.65669499674152, 85.13282452860187, 83.45804306768602, 82.56741400687926, 82.06312271856493, 83.88024699303412, 86.52501490808304, 86.77646237034952, 86.30223212703582, 89.23876946972263, 89.01720262342884, 86.92662639002647, 86.53005907612463, 87.39278439552554, 86.10063014491912, 89.04901304552632, 92.0383611802132, 87.58618077924176, 75.0346040725708, 45.19603590811453, 20.58827784753615, 7.620623957726264, 0.8214152844682817, 0.18564011120507795, 0.7596893127887481, 0.6823721035353599, 0.1595177693713096, 0.27814967137190605, 0.10855140299686503, 0.05117365444499639, 2.5780091747160885, 20.211973497944495, 61.12109414992794, 87.62302752464049, 41.291845921547186, 23.471055184641195, 24.034842944914296, 44.42847905620452, 66.35322217018374, 45.97470483472271, 12.92695047393922, 0.18245698523617562, 0.02290263516648162, 0.04073427389225653, 0.11533821422246196, 0.04706914686868268, 0.05913836798901039, 0.030399830148164785, 0.07268540335879212, 0.060222347927910674, 0.027577855263746558, 0.04248002739322763, 0.05354379641733343, 0.03114863129843387, 0.06084785871808568, 0.017666012431765278, 0.03700278218715422, 0.09505159311717558, 0.09516125860353632, 0.050832860231880224, 0.14052484094375564, 0.04188186977238905, 0.09060304311494674, 0.141089815466154, 0.055668755779944123, 0.06889768846092686, 0.015600513941007517, 0.006936163896875036, 0.06698293596385949, 0.07156617954493531, 0.03717729701630531, 0.10087949974882988, 0.09758827877381156, 0.07746547791025332, 0.018115815210847125, 0.07552195881162921, 0.1275555239689927, 0.10556558297286112, 0.1521685959831361, 0.15060056721971882, 0.19870316669825586, 0.17690339936844765, 0.11304145964283137, 0.25239610894312786, 0.25835307074650643, 0.14521982610946702, 0.2435926861700512, 0.21225916912719128, 0.2232319690407284, 0.16265958787933474, 0.1740092570863424, 0.2413861690870216, 0.16542593137391154, 0.19599325324018158, 0.17981467137653984, 0.17631735742813157, 0.32045963490682267, 0.2126292662034112, 0.14022237410949123, 0.3610900885635807, 0.11325949592696083, 0.1850629865282005, 0.24820712485140373, 0.10323239325155174, 0.18794196026940502, 0.18777564258104373, 0.16800420028307747, 0.21162615067535834, 0.19977975005824722, 0.16063308613675256, 0.16669327062704872, 0.12981174483654961, 0.22083252037484802, 0.22743511043729323, 0.2399682935567633, 0.21582748410442185, 0.1878198611760332, 0.2155245116521274, 0.21723202970479766, 0.6380571653285335, 33.85685205459595, 89.32239440179642, 92.61303547889956, 91.46166293851792, 60.994327068328865, 40.903958812836684, 47.93612134072089, 75.73626902795608, 101.82528664988857, 68.53951992527132, 14.536711785101122, 0.48902352370562097, 0.46010698342034895, 2.5701176110775243, 3.0762786442233674, 5.138374547804556, 5.327965742157352, 3.6177750845109267, 0.5091990314183698, 0.29663669065602366, 0.2875534006424489, 6.330406377392431, 38.730746084643954, 88.48702369197723, 101.55653369042182, 91.60765355633151, 74.1681525015062, 77.82786507760325, 113.4106816014936, 101.12178602526265, 98.73208984251946, 109.7201313511018, 98.41782169957315, 103.29881129726287, 100.3656001244822, 99.87111476159866, 98.7261905977803, 96.11643375888949, 93.03284675844255, 93.47382314743535, 95.12764346215033, 92.53119914762436, 96.56655711512413, 84.05409428381151, 86.19006802958828, 86.26742501412669, 67.47881689379292, 16.50539448184352, 4.921993565174842, 90.18741038537796, 84.98848130626064, 89.89935936466341, 92.8226940093502, 93.19259705082064, 95.58421519494827, 96.89877402397894, 88.18612298657818, 89.63194001105525, 90.53314378184658, 86.45085073286488, 84.80932312626993, 84.60561090900053, 90.56804503163984, 93.3056946723692, 93.77719494604295, 97.26267583908574, 96.44139428292551, 94.69542180338215, 97.45214985262965, 95.86206020847445, 97.12540072779503, 102.77848535968413, 105.77377980755222, 92.40434969625166, 66.16247730870401, 31.0145692671499, 11.415219979901469, 3.7652027606964116, 0.3485728553946941, 0.2441912613088085, 1.463031939441158, 0.6780564544662353, 0.4249113720030554, 1.0238613729034702, 0.6812416641942917, 0.125933937998789, 3.863670922094776, 30.23776738874374, 76.92686527006089, 75.29601435507499, 34.69578819890177, 40.89991092681885, 61.53015421282861, 68.85344289964246, 75.65753136911701, 55.51076335291709, 13.548816769353806, 0.27114162161465616, 0.34105278311237214, 0.13073120356327103, 0.2419764704761967, 0.15886204407340096, 0.12730315928497624, 0.13677408978823694, 0.23447205703104698, 0.13772770071462279, 0.12395655781391168, 0.11199965667460235, 0.1233027017705383, 0.13897309920960857, 0.20344828465773215, 0.220079793023967, 0.06771832674501405, 0.3440505464471156, 0.13137897686852565, 0.25942865819219624, 0.3255504117377343, 0.16147484822619348, 0.19078681245446208, 0.2651081889146759, 0.23513787936779762, 0.1414081862857265, 0.12668435942501793, 0.11547991750581611, 0.17098828128749327, 0.1524233968267518, 0.2588359512869389, 0.16804559967450558, 0.21238656954899912, 0.1664211561963443, 0.25973144678338883, 0.18209246528004447, 0.16760367419450514], [0.15681603773226663, 0.24844475000375704, 0.09518637862657348, 0.033509819618155884, 0.09426250723340819, 0.1015795202505204, 0.02328118027728652, 0.009425758128805507, 0.12094149621383798, 0.08929762163109357, 0.19093834464588474, 0.10029610081185257, 0.13028305744932545, 0.044572159888282906, 0.12726532220239603, 0.05837130330262646, 0.04651443026359043, 0.06664100027973614, 0.06512970798799107, 0.06623099768354047, 0.047391738832717946, 0.059601406852204, 0.05125132809963919, 0.04587057549806853, 0.13030181128171184, 0.04041843499327379, 0.09355369970322618, 0.09556194557057274, 0.08980681729172507, 0.07645820252477162, 0.06620338021387016, 0.11319702145673576, 0.07273493860397609, 0.06732397532511143, 0.14854241072410537, 0.1123035790759229, 0.043744444020933686, 0.06000900776275705, 0.10118352174158059, 0.12359876410975573, 0.13241609137865806, 0.07997165028486522, 0.07316195601297003, 0.24256732344867724, 4.888188127548465, 35.838547214385, 66.2804308245259, 84.64696053535708, 73.53393662360408, 46.779826225772986, 28.48112802351675, 34.78553595081453, 78.9822421535369, 82.52741367586198, 44.83136923082414, 7.561079927029149, 0.49810436223783805, 0.2146959569185011, 0.5247259176065845, 0.4978814306518724, 1.764215668362956, 0.8269153667553779, 0.23091526401619758, 0.31513363843963993, 0.5568548484194664, 0.648752610769964, 1.8211985139116165, 27.03959030489768, 66.88732347180768, 93.0513995693576, 79.43511116889216, 70.16816646822038, 74.15906044744676, 48.16301868807886, 67.75648932303152, 74.09010517981746, 72.11014763001474, 78.31378398403045, 76.77466946263468, 80.49004831621724, 76.49574971968129, 78.28300906765845, 78.5440977158085, 79.68524071478075, 77.28489137464955, 77.37327021937217, 74.60610082072597, 54.58342482966762, 10.991134297463203, 1.6144142227788127, 0.4502079629850003, 0.37568884390977125, 22.617076750724546, 115.41065108391547, 76.39175984167284, 85.34464036264728, 90.99765439187327, 97.7710699266003, 92.86092927378994, 98.61714870698991, 97.75693370449929, 92.76738858992054, 93.99049343601351, 95.56871398802727, 94.29592840133175, 91.87057002898186, 91.36802811776438, 92.44504036441927, 96.53032225947227, 100.09850240522816, 95.23636371858659, 89.53354343291252, 88.64771535319667, 67.47706751669607, 35.220189479089555, 13.269202766879914, 4.788748198939908, 1.3620785888164275, 0.16954782148522718, 0.17210551327274692, 0.12613418572131666, 0.6754882213088774, 0.24567894277072724, 0.650933142150602, 0.3707641855843606, 0.37711192883791467, 0.16400059414727075, 0.47586948761055553, 18.074238607960364, 51.217642907173406, 68.29773718310942, 50.97240455688969, 16.847799747220932, 27.463051349886005, 52.68720596067367, 59.37660040393953, 44.37464452558949, 20.573400297472556, 0.9447183616219029, 0.5090051498864928, 0.2451967976747021, 0.028919106679818327, 0.1294413566469185, 0.07001754812776081, 0.1751160243105504, 0.17849372129046148, 0.04648218945329709, 0.04013521611810692, 0.07579994147583362, 0.1504245048929607, 0.25989125272439373, 0.14500964222656143, 0.08556553237741032, 0.11809404699071763, 0.07938999036747603, 0.1600200012927094, 0.04463962159089504, 0.37466737291505264, 0.09780109033829744, 0.14400251239778536, 0.05488847990730598, 0.07229601618863883, 0.11073734295824844, 0.14549980060227458, 0.0842176466399143, 0.055140484529998035, 0.1122719549664086, 0.27747104004506146, 0.2767235527355825, 0.15613673224804864, 0.06195560653483676, 0.09949243627488615, 0.12908394598672468, 0.037059855737513116, 0.07764147128909826, 0.07742711222700535, 0.04777884689129649, 0.11589207280907901, 0.12151249984820044, 0.03513359659982305, 0.02297728277382351, 0.1250331181912653, 0.10289681609719993, 0.01988003909167263, 0.157301155249438, 0.05483088158671895, 0.06586082399852815, 0.10517929079792193, 0.0767546479079512, 0.0682409366051997, 0.10172320770159846, 0.03279644237350553, 0.0173651811952192, 0.03472685370774519, 0.06138935647604447, 0.07382760214949809, 0.03738357002035745, 0.04468641041087047, 0.061230680514727874, 0.06134372061839508, 0.11054249615558695, 0.024652514050924973, 0.06741112548737757, 0.1766346250810931, 0.13484527957775902, 0.1414984774084822, 0.24150308942602527, 0.05850449917958148, 0.003570905312024538, 0.03255098397212644, 0.09292052803380836, 0.0809275211706277, 0.07588661666358672, 0.03943626047863115, 0.02967767928156161, 0.022260082750430992, 0.13929410537164058, 0.12341446633781157, 0.1584869214603978, 0.12477184390468944, 9.074545579571879, 49.209499205312426, 78.66028616505285, 83.44357736649053, 46.79544118142898, 23.53280309707888, 29.736961126327518, 64.40864047696515, 115.39923698671403, 90.39650409452378, 41.03712328018681, 6.192310510143158, 0.28155051952888893, 0.20125554183558111, 0.8653993952658869, 0.6444648473012833, 0.8240029456153993, 0.4506791377019498, 0.9926342195080173, 0.42533553956497105, 0.324044190948048, 0.09014072437440196, 7.292377468078368, 46.32185028445336, 91.61864403755435, 92.78976178938343, 76.29361429522115, 74.75769258314564, 89.25880493656283, 90.97986252077165, 92.15010166168214, 83.53359576194518, 78.1034194269488, 79.41888040111911, 81.90551404030093, 81.80823926002749, 77.92464563923498, 77.78191843340474, 74.61554588810091, 73.31213443509995, 75.69081660239928, 82.55448587479131, 92.04365637994583, 80.29982905234061, 36.226908929886356, 4.44059273888988, 1.1996205127046955, 0.42921191381831325, 37.48242824308334, 100.0410318374634, 79.67399135712655, 92.24576827018493, 87.30336220033708, 95.81794138877623, 94.80805658525037, 95.68088593021517, 93.87455601846018, 92.76973416728359, 89.36239473281368, 91.36535306130686, 89.45814763346027, 90.53116690727973, 91.39074648580244, 88.40673277454992, 85.92562967731108, 91.08356214338734, 89.34969409819573, 96.64822086211174, 95.85273281220468, 83.79191521675357, 64.71682110140401, 39.01807146687662, 17.336674159572972, 3.706045573757541, 0.9522336228720604, 0.2507689535137146, 0.11107452123636201, 0.8586573312359472, 1.710671147992534, 0.11375612008475489, 0.6016546283518115, 0.3587194141601363, 0.07500358541766483, 1.0184680526295016, 14.60214182253807, 48.28016027327507, 74.17346339071952, 68.05695856771162, 25.016017959963893, 13.422212466116875, 45.00979392759262, 65.965284070661, 56.05479609581732, 25.008698817222353, 1.8549023376357172, 0.45380900523835616, 0.09664994364063587, 0.06128560901889878, 0.041879797504553874, 0.040947430196308324, 0.0810104578493103, 0.046884247717717965, 0.04620851986410637, 0.05441631693693419, 0.0478880220813857, 0.11233917152088498, 0.12566064379268116, 0.05321340950866861, 0.057134239844256834, 0.10943272586671576, 0.04775741558161475, 0.09716115411250822, 0.03860576754255641, 0.05812263499284464, 0.11873993571967849, 0.18759381927309499, 0.04478667216796068, 0.07594057989697303, 0.08870750410302032, 0.014983842847868802, 0.031116689262430997, 0.025912200085698597, 0.1687162483651792, 0.12840892293400344, 0.09278745856136085, 0.05055876163345191, 0.03239243824575697, 0.023519232523657625, 0.07480205066742436, 0.050299019522724614, 0.04379086128826584, 0.1266598369505617, 0.22917385423375716, 0.27934458467268175, 0.2011209861525605, 0.15819427587332266, 0.16630949122050118, 0.23121930899158602, 0.2657092002130324, 0.0903636253168506, 0.23426296099299387, 0.16564748400161344, 0.23377932968639561, 0.12604052381169412, 0.23371378320359418, 0.108237873852974, 0.23191750620401677, 0.1862356679574136, 0.18116922207897712, 0.17839780708234157, 0.32532089179561985, 0.15081792168559569, 0.07026451955279035, 0.11361635500384916, 0.18172321090054128, 0.1474092287882682, 0.23665591323327637, 0.12430583262034964, 0.2070114055588361, 0.2827243807335054, 0.22555225018051364, 0.310991799398776, 0.30425414803528017, 0.11545430718650741, 0.22388533478783024, 0.24742516358533215, 0.2147900938026367, 0.23654067828770609, 0.14825328914148195, 0.16610016535607078, 0.20655667108874168, 0.21356551757743283, 0.14863544444163002, 0.15945683473781233, 0.2531912928867725, 0.455434980892366, 7.03901686976033, 56.03344663496941, 92.97225398402061, 103.40479373931886, 84.61067076652282, 61.41240466025568, 41.2320533106404, 51.151499978957645, 92.93793324501284, 102.27925392889209, 61.62866061733615, 12.987377528221378, 0.8839767209945187, 0.23438231749159677, 1.444182376707754, 3.9170095180311515, 7.433423447993494, 4.164759410965828, 1.621839269515007, 0.6855366595329777, 0.45994346961379057, 0.4211550896927234, 2.874197642649374, 33.03077343971499, 82.41299029319518, 111.99962462148359, 97.63523824753301, 72.28994123397335, 109.57591364460608, 93.17846082871961, 91.5551487092049, 90.30945101091939, 81.77307913380285, 87.06035567868142, 85.36626046703708, 88.6690216679727, 85.73805409093058, 83.44526398566462, 84.16647803398871, 84.99841274753695, 86.26660916113084, 94.19804173131143, 111.02018525523525, 92.73240889272383, 26.760529356618083, 1.7937140983919946, 0.8760696517363672, 0.5234615048093181, 24.28269555491786, 112.78975471373528, 80.16571537140878, 87.91067061885711, 88.51728085548648, 99.02407892288701, 97.30132687476375, 104.76247510602398, 105.63618306190737, 100.2871213420745, 97.79965616041615, 102.65880600098642, 98.0324645196238, 99.28994501790693, 100.88617709375198, 99.43756734171222, 99.39326024824574, 98.71677690936674, 96.53624503843247, 103.84399721699377, 108.65226607168876, 87.76852392381238, 54.26305740110336, 23.095762806553996, 8.197281995127279, 1.2585084044164228, 0.44253963736757157, 0.16685964960244395, 0.13503807326478345, 1.566292011449414, 2.3496134819522982, 0.4989885196330086, 0.9925077230699602, 0.8348980642134144, 0.17132626395792733, 1.6394241130159748, 25.497498704541115, 63.2206133873232, 75.19091836867794, 57.35896456626154, 25.243356573966242, 37.9545247170233, 62.50565159705378, 75.27745369941958, 64.62199780248827, 31.33254404990904, 1.4006430872025029, 0.7147764582787791, 0.3459467366337777, 0.13344269516246934, 0.21537889365948018, 0.2798157593896312, 0.27916988598242887, 0.23809562226937664, 0.21440989968757476, 0.09754327876913933, 0.20819081324002436, 0.22544803157929452, 0.44414039340711414, 0.22360637153108276, 0.14272265526796543, 0.16693141671919054, 0.1569393472445588, 0.2623223561433054, 0.13419799656877596, 0.3801831753263551, 0.19892269685383768, 0.39883677276872825, 0.22854423721230802, 0.21510026748141936, 0.26392108971072786, 0.23621846170675373, 0.2459972369815073, 0.15199455612849805, 0.32229990067501224, 0.2394700912578452, 0.3745010092614159, 0.26488678950455885, 0.11180941406036578, 0.15698701323520753, 0.20165999029432574, 0.21387990473979906, 0.236483819241966, 0.257544357690119], [0.1053130497495013, 0.03552294546558011, 0.05616426144936874, 0.1903331964727371, 0.027806329495844342, 0.06933124059991491, 0.058757748695150505, 0.04787574169195948, 0.11936434334324253, 0.22501582009417398, 0.1498346325130232, 0.14999324335686623, 0.09749554383057742, 0.06618512433863456, 0.06544665388402439, 0.05477229118226998, 0.05092333521573775, 0.03129001474007964, 0.03328004686702644, 0.040306107351376165, 0.0501900933112108, 0.07143573009318883, 0.07315945090545763, 0.08299239625733706, 0.04967676843666742, 0.23029097896670145, 0.09446184331130597, 0.07951929834821532, 0.1222496449707016, 0.06628384242855734, 0.09473688419788115, 0.11058210290127224, 0.07354784982218858, 0.13282502911263896, 0.09447591634647501, 0.15033222194160187, 0.16414984339667907, 0.26250998639772016, 0.14791288563320715, 0.24563113888425214, 0.049323088624664856, 0.08970811452356078, 0.24541540852477475, 0.11944803078809094, 0.38324268534779554, 0.2458515883453431, 9.536468405877391, 48.75994851512294, 76.3254717857607, 84.17925711601012, 70.61571674962198, 42.77909101978425, 22.07799796135195, 38.167591787153675, 69.38295502816477, 78.73954942149501, 44.51203730798537, 6.655836114960333, 0.785534116289308, 0.5770168729847478, 0.5183834450379495, 0.85380143696262, 2.23011038476421, 0.8597983732338875, 0.3186490320630612, 0.2222253907952578, 0.16436937355226086, 0.8913788463800185, 0.5016295311431731, 8.604943733061514, 48.293174697506814, 74.2072977558259, 82.74080630271666, 76.24258425927933, 72.20355495329827, 74.04544507303547, 71.88331696294969, 67.98295128730037, 69.41380839194022, 76.36586435379522, 74.81171930989912, 79.02799267922678, 83.33865396438107, 80.14695075250442, 63.674772862465154, 43.89377763194423, 20.236804062320342, 0.24187963696256762, 1.7183135185510883, 0.7569947057674009, 3.5799634360498, 2.741724002745844, 0.46034986393586286, 35.79138071306291, 99.58194978775518, 109.657561702113, 115.95472305051743, 106.24481724154566, 101.80241923178397, 92.80289388472035, 91.34099514253678, 87.5996894221152, 85.24130159808745, 80.87045546500914, 80.8582333595522, 81.4437412446545, 82.80429378632577, 98.67976542442076, 94.18145795022288, 74.46994750730454, 33.171735578967684, 23.79377603530884, 10.247659817818674, 0.8261376955816824, 0.45684470524710996, 1.0181287063225624, 0.20344825401421518, 0.1495339889680186, 0.47308383870028686, 0.5268813825903401, 0.596558366331362, 1.0366568185629383, 0.5822398153043563, 0.9867852301366868, 0.32251982919631467, 0.13722102548326218, 13.319582669965683, 50.676842197295166, 69.95584857079291, 50.90255891123126, 32.01340671508543, 23.909158437482773, 50.45069794501028, 61.89141235043926, 49.8216046825532, 27.23321810845406, 4.107815911692958, 0.3133943737033875, 0.3378008930913864, 0.16071412291738296, 0.22303008955092202, 0.14619668014347553, 0.23334943178680637, 0.23817483576074724, 0.13300968694590753, 0.07444553633010195, 0.1275710755538556, 0.1793221840935369, 0.1598742147607188, 0.059166939238146435, 0.0371538853693393, 0.09487420545830842, 0.14718963734565244, 0.0675076142614407, 0.18764105625450614, 0.1756197577642818, 0.11710704995259164, 0.02853581948476213, 0.04080507956865815, 0.06203735960767635, 0.01637284643948078, 0.05539989722291789, 0.0682565801206135, 0.054536707654234864, 0.15795033815647327, 0.019214885166635918, 0.06811022668355896, 0.12171493858219155, 0.21500721844213627, 0.05634393971112948, 0.09115180721686733, 0.08974558388393733, 0.03988394693982217, 0.030107621231206486, 0.10138638182393006, 0.06887520378034923, 0.11810265781898653, 0.10390574623259807, 0.10913493216878946, 0.07808219401105758, 0.018078669522618575, 0.07563418303165706, 0.06282073813640783, 0.07755986760340391, 0.06102090265842215, 0.11953326573054637, 0.05977797862743178, 0.14369714975116715, 0.12895738826163355, 0.09094688635800155, 0.02857999019925633, 0.0632637246481834, 0.016681275353015914, 0.029944862021253477, 0.037165158353145086, 0.036827037786884655, 0.03649295067354556, 0.04929541752883985, 0.04735900006527382, 0.015225643179409448, 0.04915191776930325, 0.15536897425209323, 0.10519285055418169, 0.1010713971129829, 0.036294867149403984, 0.12231071750002524, 0.04345996110069175, 0.04806378946429299, 0.11459163089673366, 0.1123334871484868, 0.09651166477030325, 0.06329136510049144, 0.10153305701791279, 0.0900463423421306, 0.09516462172952392, 0.26987754589607643, 0.13371474830613983, 0.0862699808673032, 0.09356754291201792, 0.06375984318794743, 0.6283969191774246, 0.38451423808451624, 18.75959630935423, 65.5345215335969, 93.26841646625151, 87.10367433486446, 47.94702552979993, 23.757046961015273, 28.810485524515954, 68.63931286719539, 103.79927435228902, 98.60558555972193, 41.54872586650234, 4.39760503269011, 0.5001623195505912, 0.09439169264007961, 0.46617853665544146, 1.0036649050251132, 1.7981835166292808, 0.24862592979784937, 1.7963772651649292, 1.0350928960307952, 0.5172379903735653, 0.26533948618077463, 2.0846828722184707, 23.89608713888353, 78.53733554963144, 90.110610377404, 105.05093405323645, 76.31833307204708, 77.94241397611557, 84.98724968202653, 78.6285855693202, 83.80891476908039, 80.7501014586418, 86.70115286304106, 83.23609967385569, 85.05824458214545, 88.49145597027194, 87.94519532111384, 86.54312056879844, 78.81552573173278, 53.75804047430716, 12.454050894706482, 1.5219222826342431, 0.9535689447675982, 1.1921101544172534, 1.685232125943707, 1.722439606824229, 60.55103255856422, 90.91597495540496, 87.41244331482919, 98.25301939441313, 93.33351212163126, 91.60526091052641, 90.4959910915744, 89.31378872163835, 90.68482183641004, 86.77005321748796, 86.3191375424785, 85.00686153288811, 84.04785771523753, 82.90098021107336, 96.39532996762185, 92.66976864107194, 89.94976966611802, 68.34129118150281, 52.31527897619432, 31.651483735730572, 6.544562885838171, 1.7450097828142106, 1.5734014299608048, 0.8069206557927594, 0.19843581733444046, 0.31204020604491234, 2.164104984652612, 1.522918932380215, 0.3595892916763983, 0.9305770526970587, 0.6901035854412664, 0.15071140482060372, 0.6416789225993619, 7.980903954275194, 41.8993700704267, 81.050413808515, 67.077558425165, 43.820943140214496, 17.681462264830067, 26.688069451239805, 64.20672470523466, 62.96819709962415, 35.48871101871614, 6.644518606124386, 0.06030593195088929, 0.05227617754210388, 0.45285749339288284, 0.07335775276465763, 0.1651439190872254, 0.1744943286382383, 0.05273330220652204, 0.07609934395840091, 0.06655990987295105, 0.04861909595708694, 0.04650148337767009, 0.11099008302534781, 0.05279274296856696, 0.060294597680049564, 0.05096626678301443, 0.12118282157086557, 0.10117650437619417, 0.12147053355170835, 0.1256313715730944, 0.04564618068416754, 0.1461831203872158, 0.013375264093009456, 0.07705656315891013, 0.02159675211465407, 0.033516266248038704, 0.09258781604829336, 0.0900187095507018, 0.1985626814947013, 0.09963683618773377, 0.09337244330034142, 0.06610274690413667, 0.146660944747348, 0.01791534149238179, 0.13364422225183056, 0.05608751859155394, 0.08193500339984894, 0.08596304774044022, 0.0561336868803107, 0.08045330508461884, 0.2182627243981246, 0.33395911536870465, 0.21997866941796196, 0.14807384070609847, 0.10448743679350424, 0.20206266142908605, 0.11091665349780552, 0.2638619477229734, 0.11749487430337938, 0.21139470019167472, 0.23542681708931926, 0.20277760532354155, 0.2412477523208626, 0.18521447275434771, 0.15378447459830394, 0.23731686325082857, 0.16451994047289895, 0.11953162630238842, 0.12022348796768535, 0.1385862707731224, 0.14519105184703104, 0.1457967056382087, 0.1879966129819232, 0.23469000904550477, 0.23961466737091544, 0.3322433235664522, 0.1820162088880616, 0.14656023482882208, 0.14554984146548858, 0.18782393676379036, 0.19105973893836622, 0.14531390170656866, 0.1828500955936409, 0.3316204940840122, 0.24413415711493264, 0.1845139159911102, 0.17141879205742191, 0.30526771300262023, 0.11001265442539608, 0.36400140653694835, 0.18484809886543982, 0.20749724319865628, 0.3583742149414555, 0.2035435400302372, 0.57139924216655, 0.32158397618801365, 18.504281390097834, 71.45938719472578, 106.01189121123284, 107.86372846172704, 90.04811917581867, 64.10592371417631, 34.33124703745688, 55.132529197200654, 90.3090823081232, 106.2396397129182, 66.61836654909196, 12.621236039746194, 0.9125044869799769, 0.5385473082142492, 1.174860183269747, 4.418427425046121, 6.072074174880982, 1.7051771331217982, 2.580644762323749, 3.6608257937815885, 1.4688667102206139, 0.7608355641845734, 0.6450082181442169, 10.983701405986663, 69.37932291338521, 97.66839796496977, 113.64296436309816, 116.31230200490644, 110.13050540801018, 101.11329801620977, 97.99086386157622, 96.32250724300262, 99.34675662748276, 108.26235109759916, 105.003873455909, 103.32849579472696, 108.07442249790316, 107.65452492621638, 102.56808157890075, 85.76543223473334, 42.55009912675427, 4.564192996871087, 1.6270171658646677, 0.9012150476055761, 5.716356875434999, 2.7425199987426883, 0.6705560246782919, 38.568061859376975, 102.8615297809724, 116.6837190812634, 112.49947578676286, 102.11223940695487, 99.10979840063281, 93.78346289357832, 92.82616922932287, 95.70111751556398, 92.76610989724436, 86.49569911341514, 85.52412802173247, 87.75231669026037, 85.34597396850587, 105.73189673885223, 103.9233781445411, 96.84012674516248, 62.74905035572668, 39.504398299801736, 14.636358618736269, 1.4100277255619726, 0.5883801019480152, 1.358367536337145, 0.6086553849520222, 0.2424445042326566, 0.6147807175593992, 1.256043194763122, 2.4237766765779067, 2.701753579801129, 3.3632071316242222, 1.7480855338996457, 0.2874378439399504, 1.0021332807598575, 19.551334573376565, 60.36447286605836, 78.70501687449794, 59.40763419674289, 43.43882976039764, 32.99851194504769, 61.074339497473936, 76.29414773756459, 71.85316178106493, 43.75667118257092, 6.7848708168152845, 0.37034216306863293, 0.29166012221286375, 0.3746170562601859, 0.39583327909631116, 0.27012342947625345, 0.24268772182685716, 0.3298590740849895, 0.2682231943453512, 0.23467542273142647, 0.21351392921661178, 0.25769769784904295, 0.409298867828423, 0.13039029443696623, 0.11901690714782286, 0.15006231384411936, 0.24120894230661855, 0.324636162408898, 0.23542022873317045, 0.2978250768876845, 0.1676578366107518, 0.15341177282314147, 0.12825320790251418, 0.13111982464550004, 0.15756007764608632, 0.2087900012491211, 0.2721094970981921, 0.11652421792067828, 0.32235368004729675, 0.16748517571437746, 0.26171395975735884, 0.3581044600615579, 0.4633222544385541, 0.16086283590524428, 0.21438075770293513, 0.11184487627038073, 0.19395691492865164, 0.1946563685252782, 0.29587510732873795, 0.19007675620096345], [0.007730694750564234, 0.05396016903461949, 0.03750501027811439, 0.016987139787224513, 0.03847055685436053, 0.023340665089387088, 0.06419410395826544, 0.14255963175767852, 0.2007594079740586, 0.1320596919545243, 0.06246075725122806, 0.01798138784755382, 0.05819363985210658, 0.09222741764519485, 0.056009998154496, 0.11565400332572962, 0.20176992391146, 0.08484874987193654, 0.06828098002100183, 0.12345062568783761, 0.07082445321664696, 0.05723328352154744, 0.11043308347824121, 0.014454082514519894, 0.035316515413503495, 0.06196497195971109, 0.078247569411272, 0.10666735530380281, 0.2728553603012716, 0.04737413030177836, 0.004144890943632251, 0.04452710625745597, 0.07613054671955687, 0.1355374400173464, 0.10512960999603234, 0.07070655994597944, 0.10303586105545683, 0.06787151368635316, 0.07125697113693723, 0.04800522204248175, 0.09517598281344099, 0.03494726486443993, 0.1485515731356798, 0.15718961284766275, 0.025674538544168877, 0.13318515172408474, 0.34068683823270185, 1.5233240396745744, 16.92125789580807, 47.261583497447354, 80.31778566298946, 84.77067209059193, 75.88418945189446, 36.80460345360541, 26.45171723058147, 31.530768871307377, 72.67384713695895, 83.41899195025044, 50.80602153655022, 9.948251574270188, 0.22906408915596627, 0.07061945574898874, 0.35665664581521866, 1.6579654019686485, 0.6849563938956107, 0.2701302323370211, 1.9325206500868646, 1.339671191188597, 0.674810448000508, 0.4715193032978043, 0.19532098044310847, 2.954643983994761, 15.504525246158725, 20.19551915507163, 22.431954606886833, 33.03236199963477, 38.45967892677554, 28.819756046418224, 22.76404207752597, 19.046043080668298, 16.61264188828007, 17.884582204203454, 16.521487966660533, 11.255225519980154, 4.925902207051554, 0.664844808559264, 0.6958122887919027, 0.520382505511084, 0.6535835612204768, 0.6027630043606604, 1.3453636534752385, 0.13954381939143906, 0.43729671547489785, 0.16061716682968602, 6.909809583617795, 37.556192336543916, 81.86665904137396, 105.95778603707592, 110.28415249240015, 103.1685023153982, 96.30902997909054, 88.01068321351083, 84.44292668373355, 84.43001424112629, 84.5147374368483, 85.10825480184248, 89.89058110021776, 70.78790880018666, 40.47248240440123, 12.974665126492901, 2.8836007896930944, 0.6725401311151443, 0.55746630915711, 0.25225426010306806, 0.46643428744808324, 2.0859914729672093, 1.1040047724400799, 0.23726942708655713, 0.639649463757392, 2.2984971538666756, 0.5687255953108111, 0.48100996822599446, 0.4901928496697257, 0.2196224078896546, 11.335465446595224, 59.01123946712863, 73.1534824063701, 46.98462886195029, 25.375952297641387, 25.192161798477176, 38.10069576386483, 62.913185857957416, 62.88242663106611, 32.75872765048858, 7.9830450780930065, 0.057484453108402035, 0.3226885524007582, 0.08837395708166784, 0.08912840046949926, 0.15067400440814036, 0.1970110929781391, 0.10801508016283475, 0.05809813933146577, 0.12220350349502218, 0.13660083134328166, 0.13367779222467255, 0.2316708718576739, 0.2172181481916097, 0.025024675734100804, 0.08488227387950306, 0.04236575771844195, 0.12731849636522033, 0.05363966082973827, 0.10225064391570707, 0.09574782148364092, 0.09620928986658973, 0.20342412224460035, 0.03747736982580635, 0.028246169301470923, 0.03710754088035995, 0.025150406084233717, 0.03213437769802348, 0.07403787030207534, 0.06623248389411358, 0.06004506752135293, 0.04698447500085158, 0.0075873932162780445, 0.08656749877357676, 0.1020260729015835, 0.06792687119976168, 0.018065058055423924, 0.0886627569073631, 0.07612270197921223, 0.024119709475686955, 0.0371777604994995, 0.05908738100720991, 0.11417558386681542, 0.04239408764988185, 0.007795052839473131, 0.018323731473496845, 0.03687219100914175, 0.030382702337397687, 0.11852891680093543, 0.17492249517911868, 0.11150300953417056, 0.06017954659558112, 0.07419231362761029, 0.03973807996859954, 0.025131885908664237, 0.032431899434736663, 0.07867877732121176, 0.12446497206486042, 0.11774342386953293, 0.031092773912654772, 0.015321184877276182, 0.08432627024669802, 0.04994326361244725, 0.033674367643412084, 0.07548536279148634, 0.06498737651253901, 0.042791779213134325, 0.12910982443680688, 0.12527819737912188, 0.058147820133355364, 0.12844820792276052, 0.10923437038136107, 0.0917679870561246, 0.05489125314559187, 0.07465073298062049, 0.07270650142022679, 0.08428877790368373, 0.08125483989715576, 0.10598452581513314, 0.18286454401189284, 0.18073584614021165, 0.11379913592170324, 0.17302371561527255, 0.11630196049208603, 0.12166847534958394, 0.3130941285241035, 0.23819297672279421, 0.08953974371956241, 0.20994749881567495, 3.8100582505426104, 26.553455668111003, 66.38300864927231, 94.90915959881198, 87.16014077586513, 43.35620111034763, 21.887627686223677, 32.60382540764348, 58.08314392643591, 112.46826156493157, 96.86483767724808, 41.06349337485529, 3.037095391942609, 0.46710354185873465, 0.0936103136008305, 0.2072431777994479, 1.0075488482271473, 1.5945805128543609, 0.25017829972409433, 3.92771145989818, 1.695378929857285, 0.5553163600064094, 0.9010900833433675, 1.2376188414712106, 9.828359426990632, 37.597090890330655, 50.849810877153956, 56.13766793281802, 62.41930454008041, 66.96726137591948, 65.96106360035559, 59.06176743968841, 49.22123885923817, 45.87289971690024, 47.403259508071415, 44.385972330647135, 35.88668646350984, 22.373811352637507, 7.920024846830676, 1.8334907317353835, 0.4505861959149761, 1.2781423186102223, 1.8251142650842669, 5.487316443074135, 1.6977431384786483, 0.6458018239467376, 0.8875058122700261, 25.585146027226603, 68.68557330100768, 101.15508694802561, 112.78011352785173, 112.16005740627166, 108.52800538462978, 105.29274032961939, 99.3395394663657, 95.34496630391767, 95.23966635427168, 89.72815575138216, 91.10835152287638, 90.68016206064533, 91.44686775822794, 73.33117361991637, 41.61209960137644, 9.255583555467668, 1.782288234080038, 0.8669640532424374, 0.3037619212221715, 1.4348346331427175, 2.5078541521103155, 0.810353771573113, 0.9303764602349651, 0.6320672157791354, 0.4526456547600608, 1.0010035155761627, 0.3917086617119851, 0.27542466598172344, 0.5234961932705295, 1.853273573421663, 48.18967119339974, 86.7183485338765, 66.20498795663157, 36.61944012488089, 23.271347707317723, 25.18372674142161, 60.489470958709724, 77.72481656843617, 46.44305152277793, 13.214660248448773, 0.362075645356409, 0.18032110145976468, 0.12002820449490702, 0.12613086856060451, 0.04663194815117506, 0.16885235154580686, 0.04843995778731281, 0.04481265403991265, 0.06947181773402038, 0.071268922108556, 0.08515946747314546, 0.22244274526113467, 0.17276643264678218, 0.09447249959433272, 0.14475793637815984, 0.08675393393082965, 0.0886743554785367, 0.0775418262327871, 0.2069919316038009, 0.08421935501598543, 0.06874644738291541, 0.14815231875306176, 0.011475161112274134, 0.045851178151825746, 0.004722465697165218, 0.029691294579195882, 0.028810419870780844, 0.08855881409779673, 0.12410018397795579, 0.11929080656339085, 0.08674080318380749, 0.05136824460820325, 0.1349673173840969, 0.24466021437077756, 0.17827454353532485, 0.054616790655399525, 0.061505460931408795, 0.04078646746253775, 0.06025474195578887, 0.11717419755915481, 0.12283113634874746, 0.22491354735628252, 0.22688790915473817, 0.1151606273807345, 0.09228615360634942, 0.08927863031145065, 0.20862106354005877, 0.17571132059299177, 0.22537168325676074, 0.35131260031653994, 0.21326248383810445, 0.10362656081035253, 0.14483578623302523, 0.11973534440321308, 0.207394786599663, 0.1807219493052652, 0.2872959950998906, 0.2839903869936543, 0.16522710091404377, 0.08592097419163874, 0.3072050880760916, 0.19448186901788558, 0.09068424843492047, 0.19474480571525712, 0.24157743059819747, 0.17349675958675725, 0.282161581900812, 0.24624172628166216, 0.377423512118478, 0.32137627442998273, 0.17464388432281633, 0.26260381684668604, 0.15984874999811574, 0.21666881718462516, 0.24045405458779107, 0.2087135456742779, 0.153077436731227, 0.22376538074064642, 0.2090463955556193, 0.262466503247138, 0.22584874152896867, 0.261908638020677, 0.18698078039432728, 0.31602331166786535, 0.43354827790491046, 0.20713892855471183, 0.23640478961169722, 0.46483202987620914, 2.638556841881045, 27.80490356106912, 73.83734764591341, 107.80244535015477, 110.02893171002789, 95.52002168470814, 54.29543656687583, 39.776010667124105, 47.292621212620894, 97.61261401637908, 108.65025781816053, 66.20607837553948, 15.322096790036849, 0.686022910860277, 0.2513301588835255, 0.9106520863790667, 3.794099352052135, 4.77667514354952, 0.24859065910981548, 5.244329042973058, 5.534275058777102, 2.7006129055253925, 0.676339436923304, 0.7302193812304928, 3.148460061319413, 22.932711839675907, 35.48314125307145, 43.14025502051077, 52.98727904596637, 61.14710730891074, 64.01572488969373, 47.393080957474254, 33.13164895580661, 29.19865308269378, 30.68109916102502, 25.242483846602905, 19.152309894561768, 9.914039681034705, 2.2259970441941292, 0.7314418124095087, 0.5914173034891006, 0.9554662074773543, 1.094657396597247, 3.5175526430529938, 0.6678055238819892, 0.5208861010689889, 0.30770531284712976, 9.490337410280782, 42.930361147849794, 88.88891758457308, 115.96015945557626, 127.1323327095278, 125.75968357824512, 120.83731297523745, 114.86999942410378, 112.21783391890988, 112.93882046976398, 110.95541907894997, 107.94530591657086, 110.88320824407764, 97.0290594716226, 70.2519561398414, 32.29451317940989, 5.7364624546420195, 0.5166428932739843, 0.6172794512202663, 0.22832070807776145, 1.8941684499863658, 2.8675605020215436, 1.6093233540173502, 1.1078558045048867, 1.450902867701746, 8.633262265113093, 4.141240879412621, 1.0883996227095205, 0.6785082624804589, 1.344635931234206, 16.317001081282093, 72.05461471311509, 84.13490295410156, 54.01322595534786, 35.15705108642578, 38.011112751499304, 50.09741006358978, 80.10827618260538, 87.29420738835489, 52.86402248567151, 15.231715575341257, 0.27555336875300257, 0.4143443535412512, 0.29735368766611625, 0.25190218141482723, 0.18588242481552786, 0.32712276123704453, 0.18651682222562452, 0.08891169717835803, 0.17863218402189596, 0.18330358900129798, 0.33845360000287333, 0.25885994516072736, 0.3205730465631331, 0.09031424328925149, 0.2875324711203575, 0.12001171062189726, 0.18694108171809107, 0.20089463781445258, 0.30064691579149616, 0.13224338451700826, 0.21771751494417269, 0.30419181912176074, 0.1668003084318292, 0.2739318057654366, 0.08424067524291816, 0.1483489428797076, 0.12565793950230847, 0.19005962647497657, 0.13880852820171466, 0.14304133252270762, 0.2102078614576209, 0.21471962903536138, 0.22332517129759635, 0.25484259540755905, 0.27324125411049016, 0.15593967911216522, 0.20999816787098685, 0.1919556174787783, 0.23803592869831672, 0.18013181645543347, 0.18957429445318638], [0.04550377259992304, 0.02999865863051626, 0.03899081482461864, 0.019284367426148346, 0.03527590509263739, 0.04077334054595521, 0.0283171818216121, 0.04454207944593603, 0.04231360628299656, 0.0324716747197653, 0.023459826235569293, 0.028058033429026127, 0.041871270945956635, 0.029073297196338256, 0.017684421524585738, 0.10436413494209129, 0.060327700339257724, 0.03734756388791627, 0.025161196432647207, 0.06985782645642757, 0.05371987023541043, 0.07200855701681107, 0.06177994640423887, 0.09468028562203532, 0.05028749372990382, 0.046419810744062553, 0.025835116318757498, 0.06021733771288588, 0.06136626275556703, 0.058352901870685245, 0.06103801706265058, 0.06971482848448139, 0.02943043972575857, 0.03337396924654323, 0.021158178269322363, 0.017637550350158446, 0.0388616255875076, 0.09374889890633284, 0.010205095543736413, 0.05750172073021532, 0.03127334275162749, 0.0893974582093858, 0.05568499301349925, 0.13972473871563712, 0.12294395811735623, 0.0995522600808932, 0.11865247912224262, 0.11076315246041744, 0.3244226383826425, 1.5910011049239867, 16.70292700490644, 45.7701571526066, 71.96284694056358, 79.97896348276447, 68.04338716691541, 45.94919373912197, 22.510449078775224, 43.23286218027915, 63.334111090629335, 73.96998651566045, 53.11584649547454, 9.911778434630364, 0.38661843646437893, 1.231094959282106, 0.5222877355352525, 0.8800213783979417, 0.836715960214215, 1.1395344594793937, 1.2733011332250412, 2.487411984512883, 0.9293452446018496, 0.610249583278933, 0.7713529095053674, 0.09321269864637045, 0.1375808416595382, 0.27048802604117705, 0.5770405910668835, 4.423670163077693, 2.555162103906755, 0.4321904330243988, 0.8076089091839329, 0.5948927073228745, 1.0321181459772972, 0.6817912250276535, 0.2666973617048033, 0.008191740827544803, 0.18291037139152327, 0.20078798305363427, 0.2825749629447537, 0.8790341668551969, 1.7588075779138075, 2.9875845389981426, 0.3348039264880842, 0.13938315543195895, 0.17651497746907896, 0.12996300123631954, 0.7299401575038511, 4.772537533313998, 7.755377965588724, 7.5885071004590685, 6.266915461709423, 5.34578703103527, 5.859917584926852, 7.975649939429376, 9.217614031607106, 8.72128809652021, 6.677070846480708, 2.2328268712566746, 0.467932571566874, 1.0177848247751113, 1.0340253984735859, 0.10798272826979238, 0.1232229520176207, 0.0821631137401827, 1.8333042965781305, 6.256322610762812, 1.5449229387506362, 0.27288551352197127, 0.40648278990580194, 0.7335651629874784, 0.14321019362297752, 0.4188745685162083, 11.79138312416692, 53.222260398249475, 73.95638373590285, 40.402311202018495, 19.123150994700772, 23.294071958911037, 45.75892740680326, 70.25000279949558, 71.01810486085954, 43.36243375655144, 10.134747528260755, 0.47511283788950215, 0.25547385185716615, 0.06769676136994554, 0.14448908548201286, 0.15971957225232356, 0.02734241920763687, 0.09789913427084686, 0.0945401834624429, 0.052399441089120605, 0.03639057068334472, 0.09151067344411727, 0.028370963109116402, 0.01806076221738852, 0.041685812550807194, 0.037794304230520805, 0.028488335439995415, 0.02344899758275959, 0.025917606751224207, 0.03525771816531497, 0.006211736312721886, 0.07919040914144247, 0.06518744037396486, 0.05005645693369931, 0.017589746463683345, 0.012134010133694017, 0.06905387080604992, 0.014148237232509402, 0.01869425755895434, 0.04676527043263759, 0.01923728557754188, 0.030239543486987392, 0.041571014275353764, 0.0562284711087423, 0.03988930189441289, 0.07545746953016327, 0.03063441010101909, 0.013226688043364595, 0.04128783753502273, 0.01879679268195985, 0.039438516607568155, 0.04683676941861068, 0.05887522061745967, 0.05451049595590561, 0.028830387952527212, 0.012258673706392368, 0.030408624837535526, 0.013839247159569735, 0.003890166469406517, 0.08450617833483605, 0.05754896154206607, 0.010390145039456266, 0.10161265355324554, 0.07382450715428399, 0.10598457944128784, 0.06157049413530096, 0.04184884755241294, 0.012767553355755105, 0.1222589146345854, 0.07088668253873626, 0.1785007539776064, 0.027775530846068458, 0.024393631873892683, 0.045688487889785925, 0.05263139719083425, 0.07627493897152525, 0.03519516708629747, 0.1308167449408962, 0.10908551183679413, 0.03392642206181923, 0.017846994958217108, 0.06849650353673967, 0.09208779046011549, 0.03064675943835849, 0.04283974780851314, 0.01762469347956921, 0.03075961568092387, 0.08496470494015564, 0.041734646825540456, 0.03223157127297694, 0.03942719382804729, 0.09901844235437532, 0.08845861745818008, 0.09591862844723849, 0.11711074249638666, 0.09225976187735797, 0.056830585573709784, 0.08587616570894757, 0.08982125804909775, 0.10317402501260081, 0.1473718590193218, 0.17288283204599736, 0.1918938554703228, 2.8435982523425936, 23.687626892520537, 60.35869521479453, 90.64983429447298, 74.26394462585449, 43.86145730172434, 21.47502572305741, 29.51262900906225, 59.541496845983694, 99.11663901421332, 102.68423080444337, 41.87385505245578, 2.9902238038278397, 0.6118702576045068, 0.8326469301696747, 0.6379140601042779, 0.2011415173089312, 0.9521343378770737, 2.1880687052203767, 2.128960793056796, 4.300604328032463, 2.421334755997504, 1.4568823984553738, 0.779616546726996, 0.5121878162026405, 0.5653599565548282, 1.817514060005065, 3.1868382471223033, 9.71988529928269, 6.3719452581098, 2.2563838910671974, 2.3207051234860576, 2.5044863070211103, 2.345138793030093, 2.037407157401885, 1.0333900970797385, 0.017485462744990667, 0.4250702586385512, 0.9285852240939295, 1.3326990556332374, 3.7317199380167074, 4.081003324639413, 5.660933784900173, 1.174479958511168, 0.34222489763652125, 0.0324979477051285, 0.9580004263308741, 7.957508487086143, 22.48773659429243, 32.21658352882632, 32.65684996881793, 29.421849673794163, 28.413402418936457, 27.00302989252152, 31.980576476743146, 32.117443661535944, 31.72027426381265, 29.016629611292196, 20.22792773862039, 7.3725531658818655, 3.0280734502500106, 0.5936271300719631, 0.057947292788735325, 0.044421723202591946, 0.5461490454692994, 3.18494227144026, 9.208862243160125, 1.785206600062309, 0.1579044188462919, 0.3853399582928227, 0.45097015918262545, 0.25145372886571193, 0.40201321845093085, 2.284034884745075, 40.01076452193722, 92.9566978639172, 75.98362153576267, 35.20749668921194, 22.38664338665624, 30.026665426069695, 57.46376245252548, 83.90363216400146, 60.87292578912551, 16.051279133366002, 1.4941208905750707, 0.11750130178106409, 0.06963647301158599, 0.08592141852263482, 0.062038577687475956, 0.007050209969747812, 0.09295835745550933, 0.05334413858250745, 0.03458126635861493, 0.048214620685264956, 0.20567473534855152, 0.008376730951450525, 0.038635464940941146, 0.1180061843666819, 0.06893871246927208, 0.010158108498510576, 0.03399121394801525, 0.009322298912241334, 0.009416275875522725, 0.07681493902759207, 0.06117205180588269, 0.08738838496708101, 0.03970324595068251, 0.019962324595619595, 0.058248794352215146, 0.08831935033442513, 0.0160116647114797, 0.051767207877410036, 0.023998206015676263, 0.0402895407000136, 0.012623739500169553, 0.05169946655270554, 0.13718111230240715, 0.09429993828938854, 0.051841866976070794, 0.05776282264700821, 0.042672047331448526, 0.01953265269196803, 0.05314475270889459, 0.07206301054646892, 0.034895010007124756, 0.02247910728798278, 0.0565742104194097, 0.08761569091509427, 0.10809635443072166, 0.11478290006878877, 0.06126793154004601, 0.05419160802698424, 0.11676401876273657, 0.09528500478594534, 0.1913240239504845, 0.12356534735449862, 0.17099534461815513, 0.2465408836160937, 0.15365255425774282, 0.19235759913440675, 0.09901098831887208, 0.2128565798123037, 0.1734782815460236, 0.27272754619198464, 0.15537724800167546, 0.12045657787952693, 0.11884386320748638, 0.20798403078750258, 0.17792551387702266, 0.1792841401672171, 0.27091924161199604, 0.27217130507192305, 0.13052587667780538, 0.14887264058474572, 0.1890736559946691, 0.13753676096037512, 0.14408578615515463, 0.13685572411744826, 0.18119667867018333, 0.12563522499535354, 0.2816626441574866, 0.08200106316155965, 0.10289234214372213, 0.1527485398635749, 0.2351618579198276, 0.12004758651939132, 0.13094820562870274, 0.17615756680888517, 0.1932147595911257, 0.26068283605479425, 0.2757662492654016, 0.23886016269605007, 0.2156812379196767, 0.303668764930579, 0.2812355654614587, 0.4899730130789742, 2.5796913812237405, 26.881707060721617, 71.9198420739943, 104.27000584140902, 103.186184360135, 86.97266717110911, 64.118094828821, 37.1248532110645, 55.33537457066198, 83.75775137255269, 95.8526151410995, 70.32122519708449, 13.646480844866845, 0.7117130258871663, 1.5645551369074853, 1.3392993014666343, 2.0278898939009635, 4.337174546334052, 6.1135900116735895, 5.162774632053991, 7.044790598653979, 4.098036462260831, 1.554272520926691, 0.8738228690720374, 0.24500005097398836, 0.10036036792782047, 0.31314634507702244, 0.647173734201539, 5.786785483360291, 4.756386683833215, 0.7157225462217486, 0.9436945617198945, 1.0495300374684795, 1.1539561565845244, 0.8888820126172036, 0.7780923994798815, 0.08810099995424671, 0.3283618012022588, 0.6764761070089956, 0.5788701928911671, 2.9668631476740686, 5.810501604310929, 10.882189485334582, 0.8381641115392409, 0.43174009589898976, 0.317873076926316, 0.21552074249953995, 1.6666003773289344, 7.390601461933506, 12.89139222714209, 13.218381597149758, 11.96369186524422, 11.899405198712504, 11.57589497104768, 14.223727237793709, 15.252692411022803, 14.517644163100952, 12.615755508022925, 8.159323748080961, 2.5362001407531003, 1.2556538995235198, 1.6769620535835144, 0.34672217083073437, 0.3818971285175893, 0.5522365639767339, 3.7082460234242105, 11.82879469087047, 5.237213863480476, 2.9490354849446208, 1.4941776423685014, 1.4302563691331496, 0.50057775371017, 1.3962337302584804, 17.262027532823627, 70.21662342932918, 92.4979845170052, 55.0774081291691, 28.849970063855572, 35.883713306919226, 59.76601331464706, 83.3691386253603, 93.7574811135569, 66.54934067879954, 20.766700583119547, 1.557827536617556, 0.33944602094350323, 0.19920610342054598, 0.20642159446593256, 0.3068371207243012, 0.12946928821263776, 0.21138282582884838, 0.15936479693458927, 0.17836388470905443, 0.14318639893204937, 0.2695022241002129, 0.13765913584539968, 0.11464066052388762, 0.189173324033618, 0.123033904500546, 0.122136355888459, 0.13959574483094678, 0.11666108718923024, 0.09648515812812314, 0.15235467873994382, 0.18230903833623857, 0.2720088637884586, 0.20372329490079036, 0.0920380560320712, 0.1500040451965986, 0.19127114856195068, 0.1259135217556069, 0.14224380435001466, 0.08641842572439103, 0.17204482378738542, 0.07940808536424752, 0.15782921965564453, 0.18925505029338022, 0.1615078206504545, 0.11163172762720816, 0.18002395127569476, 0.12579963512478337, 0.08155497782413038, 0.11254075223640089, 0.159658944053996, 0.12851255164752085, 0.09041274687455547, 0.12446386889824945], [0.041251325784551526, 0.10323943359957588, 0.07841536564932716, 0.05510243677323865, 0.04322767558117067, 0.040200103765293475, 0.07261358261589082, 0.06324275299125622, 0.0049842058609600275, 0.05790794651294428, 0.0057634738491727944, 0.02275328441042333, 0.034627043942530314, 0.03580376648554399, 0.0677012276625441, 0.01956374245515514, 0.07821246726258148, 0.04100921135696192, 0.005029598964498409, 0.07449675696871935, 0.04225340326346698, 0.04807009819834944, 0.07370627680492979, 0.0605181229841565, 0.05349194375617851, 0.042736988604789784, 0.04787483004732959, 0.04975905777105401, 0.009325224410502181, 0.04272948860401108, 0.07140533938523262, 0.051212675133419615, 0.12989751604055205, 0.017752955750291868, 0.10505369834361539, 0.03574527950296479, 0.02491712273519126, 0.029968287074758165, 0.028972640903967044, 0.10527146649697136, 0.05291075498286275, 0.07949001080687008, 0.02270867702581229, 0.07129395020104225, 0.056516336307169936, 0.03155664972690565, 0.145754877237543, 0.013955523027107121, 0.13776586721501044, 0.17357744396694247, 0.26218378615956156, 1.8724721045263353, 15.356921553611757, 44.68925391474078, 73.26268119196739, 78.30375840587001, 64.5079117436563, 40.989215450902144, 33.97508405870007, 24.153153396421864, 52.66057698957382, 90.36829440824448, 66.40932775312855, 19.7293552660173, 1.6246695047424686, 0.6630152067349804, 0.23672700619264958, 0.18274272071017375, 2.5836635164676176, 1.0748202545988945, 3.0551405010684847, 2.0101901984983876, 2.3788118506631544, 0.17522883841827994, 0.1892996825758488, 0.37052210180028794, 0.19692152197803223, 0.6278792276017128, 0.23077677064124616, 0.25462111938864956, 0.3271139359041568, 0.4540607417302747, 0.336429963429128, 0.2583360023075535, 0.16273636521110613, 0.13192582575063552, 0.14113705244756516, 1.6388154101948587, 2.49677590785488, 4.229634923319663, 3.1904654589391526, 2.756430929706943, 0.679617619081851, 0.4425439274599476, 0.27342152992083185, 0.17824316457394632, 0.051325121518945506, 0.07377748467749165, 0.35255985274430246, 0.261002539867355, 0.24623002045817916, 0.08409475847598046, 0.1883547590865243, 0.18154544785859125, 0.22037032420837113, 0.17150254078930424, 0.1512004293861889, 0.05578139368745108, 0.18962588281400744, 0.273971826198601, 0.41618293391600736, 0.12133787010586071, 0.8259611889239281, 2.1279331320716492, 4.514315157167373, 1.8005819234155842, 0.06428606898313569, 0.4741930114405771, 0.264319118352667, 3.435738620258147, 20.608876174496068, 53.52819350457961, 61.773984432220466, 33.80395104808192, 14.015260127282913, 25.65601148912984, 47.90031402341781, 68.64159568663567, 68.30971610161566, 47.7140445863047, 12.509798561373065, 1.253971447867732, 0.18196779213124709, 0.10672737829267018, 0.11186902336175404, 0.05531017683566578, 0.19574646567625387, 0.06885243564723961, 0.019700339762493968, 0.09896346022404971, 0.11804661082644617, 0.08713196001706586, 0.009523149929009378, 0.01833650024397479, 0.016126577900121772, 0.021659994588023233, 0.07357845503476358, 0.08387885957715974, 0.03968309017739469, 0.031317860120907426, 0.026628007744288733, 0.018873428287465247, 0.04670357737209528, 0.0780183405825688, 0.09449022686890057, 0.011129281990560553, 0.045102277410126505, 0.01689923311313314, 0.020153157097557862, 0.024249398585168586, 0.05828783419283648, 0.02970374542318525, 0.017211421603156675, 0.03877429539457925, 0.024269062146965056, 0.030739999999622666, 0.03308995747037473, 0.014608012561145571, 0.06182905264018525, 0.0747249745613625, 0.10357652760801778, 0.033831668476904594, 0.0542556912818503, 0.046086263722710075, 0.012436816919474833, 0.09087470555377584, 0.06466147504867086, 0.10968031016208472, 0.04770814846720427, 0.03146565763369924, 0.05476266911794102, 0.009803714309518617, 0.05102100759564389, 0.0037852306183682937, 0.05836956045259872, 0.008731404762534846, 0.016633486788299297, 0.04346585614726909, 0.08840033348890082, 0.0440045308712269, 0.013036588113003922, 0.0399495278965802, 0.12591930571943521, 0.04071246336905226, 0.017751389100486716, 0.021291527363862243, 0.037888165323003646, 0.04801303230886979, 0.035440797857459516, 0.045548014177550236, 0.020150299589600296, 0.02537373412070015, 0.05489125697603149, 0.06736993293968901, 0.049032622557734294, 0.026886077868121288, 0.02287370577124098, 0.041274986410092925, 0.09626168261973128, 0.025142178299926946, 0.0236789254666937, 0.030680704794283357, 0.030220613454378424, 0.03612396442481587, 0.04708517342805863, 0.031077130397240964, 0.09151801256643188, 0.030090301898458315, 0.14965584291325462, 0.09974758185806776, 0.061318435886454206, 0.0508352542566436, 0.0906870982819988, 0.042019593228976575, 0.04757207593009357, 0.15214732938235806, 0.10289569760883048, 3.4423377629249328, 22.433005802093014, 65.18863908706173, 89.11088451262444, 75.96145229954874, 40.72658138890421, 32.3479123269358, 32.41146649083784, 39.90609607388897, 99.42610617606871, 109.93043315026068, 67.4628528471916, 9.293135346904878, 0.768936423044051, 0.3870881096489968, 0.1574365842726923, 0.27678450269083826, 1.0228354892423077, 0.5720725415214416, 1.63600527711453, 2.7552218591013267, 2.717686982885484, 0.8963413188053716, 0.745871538116086, 0.7680426129410345, 0.2875909389507386, 1.3970031276825936, 2.2101036002559047, 0.4969237288159709, 0.7841850660981671, 1.3934372028996869, 1.8764096738830691, 0.36141809676924064, 0.36142928165293514, 0.195191067252909, 0.663199864568249, 2.3376637360742016, 2.98391172962804, 5.218859622555395, 5.442819604950567, 5.918350604272658, 5.133982473804105, 1.3706302138105517, 1.4668835843763044, 0.9908320742749399, 0.09978325091182225, 0.13999227194055436, 0.5954598575349778, 0.5064987553463829, 0.3343036097864951, 0.33766008613090365, 0.2859630327551596, 0.4477877073710965, 0.451691446285094, 0.4157374078227628, 0.4203886646897562, 0.14374210379056393, 0.2699966878900605, 0.17045388899503217, 0.554411763385419, 0.4297547943649754, 0.36994428764427867, 1.288084791552636, 1.7948192261880445, 0.19914683885872367, 0.6854576605462259, 0.15991582865676573, 0.2020033355802298, 0.7825670271150528, 5.261687492170642, 41.61710062334615, 84.137052412956, 69.84060149038993, 31.38205808977927, 17.90201517843431, 25.73214665535958, 54.02041565987372, 76.22453351174632, 63.07359118615428, 21.376840952903997, 2.071731205909483, 0.271922203922464, 0.06595355128088305, 0.09917021969393378, 0.030910370293103402, 0.07281643503736104, 0.05395849513250494, 0.022900880825135018, 0.12387074830551302, 0.08851272624827201, 0.05033802105894974, 0.04376717768008671, 0.01871381578366122, 0.06020769266591919, 0.04246603862773027, 0.024861041268694307, 0.02678980168345715, 0.05632719302910471, 0.01111417952474327, 0.01054203441937364, 0.011159168995706546, 0.05285671897112362, 0.10654035324771559, 0.07244490537672274, 0.03479574416433612, 0.014936655662172746, 0.10355906080334418, 0.03217743566980766, 0.08626398239885608, 0.06268287678399394, 0.05780596105802444, 0.03941038968942819, 0.02531293163736982, 0.03542321613959728, 0.04432345710454449, 0.051604322262949524, 0.023841638711371252, 0.007767341524032095, 0.03396055510928554, 0.03674486719612633, 0.0712698337531859, 0.06232373476509125, 0.046824017885111036, 0.03622260207550661, 0.049848812632262714, 0.0778993058408941, 0.17603048814400551, 0.15457178315808698, 0.16811845463610467, 0.1427022160421456, 0.1478191624365507, 0.14564721124066463, 0.12670199476903485, 0.19694491830323974, 0.14922085818984818, 0.13724328799834176, 0.12732009748898207, 0.1513666551439993, 0.13789879879163158, 0.19710417266093916, 0.1347343653680817, 0.13141579505416656, 0.13387542758737841, 0.07601659114082014, 0.16571751975965116, 0.09905566656661612, 0.13819260883235163, 0.13864276209665885, 0.11081048903325874, 0.11124767242900788, 0.1517222578366918, 0.16229732022170099, 0.18587281807295739, 0.09615014787883529, 0.18660358934392854, 0.11803862052939593, 0.17459073314262977, 0.3617536126365585, 0.17753085602195035, 0.38928892703786977, 0.18910684292354893, 0.1374469141686155, 0.16301499138916695, 0.2761144209052286, 0.20859092564111759, 0.23774282345848702, 0.164959077392855, 0.2161496087548233, 0.16242318846766027, 0.27232675963351805, 0.12601119796595267, 0.24298117946713205, 0.09873646071120616, 0.3814744318444883, 0.3740556976727901, 0.4818390898646847, 2.657496006258073, 27.504344101875063, 76.71972490126088, 104.94141363328504, 101.38036435650241, 84.64849025972428, 62.53531256029683, 45.15347034700456, 33.27519201463269, 71.91337800795033, 115.61418287215696, 84.07608309099751, 27.68721284404878, 3.2210719585418706, 0.9663507234184974, 0.20306488829514674, 1.5686348921829656, 6.851672703219998, 9.26420884747659, 8.93644186758226, 5.022864668600021, 9.61349198895116, 1.1660916021754666, 0.8566159827093925, 0.7839019200013531, 0.3628452266416242, 1.6109755298783703, 1.8573650958076602, 0.31664764268263695, 0.38715917196485305, 1.2337629064436884, 1.07912223665945, 0.6484972889865599, 0.41949653998017317, 0.37009879225684755, 0.7528734591699416, 6.20309506693194, 9.811619731687731, 14.63372866953573, 13.495876539138056, 11.66044460188958, 8.966946140412363, 1.096805997433201, 0.8347924666539316, 0.5692715402091704, 0.19474168007652606, 0.23587648005735493, 0.5678029190148077, 0.39836434166758294, 0.3281594620596978, 0.2786749625398267, 0.3642525301585275, 0.48619203209396333, 0.3718681795702827, 0.27590635142499403, 0.2098128971673789, 0.19092633238723203, 0.34971089432797126, 0.39851688509506566, 0.9244289826000891, 0.64113573561753, 4.0340574566395055, 8.199067163851954, 10.61587525952247, 5.5391956721582725, 2.068247405752059, 0.9387426306643795, 0.5004953839365514, 6.544101026750381, 32.33217773898956, 74.516553109692, 86.21240200534945, 48.362647717998875, 24.502513024114794, 35.49578305213682, 64.78887111909928, 85.1229872242097, 87.7524814298076, 74.12186068873253, 28.470961240030107, 2.919493418547415, 0.4870285081767267, 0.14049013716078576, 0.2501910167836374, 0.14657400908970064, 0.29952091976038875, 0.20926692162550267, 0.09404578095962925, 0.13642976390978984, 0.24961517913447273, 0.14933595523959206, 0.1446383040879042, 0.1283953325342267, 0.1985596324647627, 0.2343018016507549, 0.11621163872581337, 0.19476788028353648, 0.15541690071263622, 0.16032942420532628, 0.13258890549261726, 0.069011467839441, 0.15402920904659456, 0.20778008286030064, 0.21196830086410048, 0.14200129155670443, 0.1638631732954133, 0.13171263880306674, 0.13892071411734627, 0.15522424492143816, 0.16113887270612104, 0.10609314176103762, 0.08421988361665318, 0.09596880720627886, 0.1183924995242588, 0.105730468076804, 0.14542011213639092, 0.06443157972347352, 0.13306280748257715, 0.11134361728064476, 0.19252330395242861, 0.1691656508633206, 0.10234126445627022, 0.13189314443978573, 0.059401297025502696, 0.1939893204478487], [0.03836183748658627, 0.04509651642893592, 0.01777028082869947, 0.0388153960117169, 0.0560273232329036, 0.08462203381162497, 0.041553555131559415, 0.02041201054629299, 0.044292495661084695, 0.03622081709064303, 0.034266913670205304, 0.032161998998133406, 0.0235526071440789, 0.03204010674850114, 0.03518017091517968, 0.0734862869965934, 0.005972599573132973, 0.027861761702825467, 0.12710766130757908, 0.06451230240805496, 0.04061962117350871, 0.0432004947816172, 0.016384278386530858, 0.07544178771035326, 0.07392716293613757, 0.058334056107747945, 0.11051076479376325, 0.04157394456166414, 0.06674740223153945, 0.07695527101356177, 0.06816350809869266, 0.042254996726349484, 0.010730369474678751, 0.025560245886745474, 0.05415973876933417, 0.12598170358086788, 0.10886713081309873, 0.019609983522264708, 0.1128954432844635, 0.016632012069045056, 0.04429415424144076, 0.022953723654932073, 0.04196120966826716, 0.0989620429613898, 0.0831706419346794, 0.10651684200931942, 0.04645728776531835, 0.059496134880088994, 0.10901497812160563, 0.08255377261629028, 0.06684571429486237, 0.09457219061591933, 0.21383587000591142, 1.9384596088240225, 23.36372736961611, 60.13246467036586, 79.09092318627143, 68.86783015343451, 64.63982105255127, 67.19240542381041, 16.656211576154156, 25.47106977432005, 44.57078656842632, 59.46669724679763, 76.39827882089924, 42.50565082796159, 13.67625653743744, 2.2272727950926754, 0.17911993688152683, 0.07943174982022855, 0.6068936891613469, 2.2815152522056334, 0.5485513746257752, 0.3255375721041234, 0.48098572920407023, 0.5739188134189576, 0.678377169514856, 0.5273111885593784, 0.09991295725828218, 1.7075274908734908, 1.9740442090457486, 1.1876256595696173, 4.835824485748045, 0.7949390406570127, 0.8932573552573881, 0.9990438013788193, 0.9712269649870935, 1.3924808800220492, 0.7820287430959364, 1.9493891707351132, 1.7239347653042887, 2.8761985417335265, 3.5499354860474988, 1.9369171367537592, 2.664089755665872, 1.6612306525630336, 0.41465143222481976, 1.1246484518051147, 0.3984165275769849, 0.4315145596140816, 0.23234840001790757, 0.15041221684265524, 0.1888916028603431, 0.2996289075141953, 0.2557010275702323, 0.6834423590090968, 1.156935564452602, 0.7849949129646825, 0.29492080692322026, 0.46901229588735494, 0.2285018878718538, 1.3197711686934195, 0.9118818720021556, 0.810373812433212, 0.8897813385532749, 0.2093774987564933, 2.78354823589325, 17.626343157983598, 38.806016368250695, 62.270893819870494, 65.13669513886975, 28.057372800765503, 17.159563456812215, 28.00650554318582, 55.05190880067887, 66.64694493816745, 67.33193982032039, 52.245507855569166, 25.069220988981186, 2.2883367442315627, 0.14164837017174692, 0.21634330642559838, 0.03538966531895342, 0.015640872410468517, 0.15671636969331773, 0.043134025162867004, 0.06420270329521549, 0.041911310531319156, 0.054632215835754915, 0.18034883384262362, 0.050359479181708834, 0.014643032355384241, 0.03916455207452659, 0.04931607125927845, 0.020849111587590268, 0.039385560779802264, 0.03357827340462997, 0.002528075067769556, 0.0030875016771812714, 0.06120813837755592, 0.04937733531058316, 0.05561661200537797, 0.02752268735709931, 0.04104154409780618, 0.034558034742311124, 0.05147987127965016, 0.09176964180604105, 0.03995996967498814, 0.031693442386665174, 0.07708265611361112, 0.04789829149001068, 0.02509220638462613, 0.028571938615172144, 0.021240053916229837, 0.06538768043561329, 0.10894830548955549, 0.05756138365775828, 0.027529145478300994, 0.025014735743283265, 0.15760935242137603, 0.03552932697798937, 0.11986967792073566, 0.048436966213968494, 0.038916251486948425, 0.03966212235090714, 0.02407383421556123, 0.08475252156776768, 0.08445265943244581, 0.0346701555404692, 0.012102692459349432, 0.03940166777841026, 0.04684148085934501, 0.02349373903275738, 0.025749917765478456, 0.027678672434581865, 0.04988828148212164, 0.03304840486136175, 0.04488155215738281, 0.003043096827065212, 0.06842105153707728, 0.04780058846658757, 0.029360028584637952, 0.03383975453494537, 0.04204133480426766, 0.11226332115550196, 0.08431623449488994, 0.022833737049011454, 0.01084942911421099, 0.0586324128802986, 0.043444283111321355, 0.03431683195935142, 0.026953832599364465, 0.017062428993202986, 0.0386667941066046, 0.06576048946308513, 0.04543019368523552, 0.012824791615017721, 0.10339540144008014, 0.06458026972869713, 0.05773422458479482, 0.06892662360182694, 0.03596023994407827, 0.02105377772222123, 0.09188067858978625, 0.02599935407840437, 0.014122843333039314, 0.052936752176573204, 0.027977992562697302, 0.07978965843757314, 0.023223645158953244, 0.13298730185676005, 0.03228280723335282, 0.07861018180847168, 0.19629627165775146, 0.07854583808371136, 0.09787265061130447, 0.03716691652493131, 0.11457428666612796, 0.11437132699234832, 3.4508032183493342, 30.475339466525664, 73.55357200868669, 94.04723444292623, 66.78983688354492, 53.85083590784381, 32.32835146688646, 15.800108198196659, 52.816079355055294, 83.86778170062651, 96.23920394528298, 77.63019331039922, 28.707640978597826, 2.7539282123888693, 0.9831552604033101, 0.1539913949466521, 0.07773737783633894, 0.41548977756211836, 0.5579667177892501, 0.9640732972371964, 0.5774914184885641, 0.5924089276982892, 0.6133749768618615, 0.3902031457231891, 0.4985273347025918, 0.09834640704455877, 0.5996569161934238, 1.0625248498493627, 1.343326472466992, 1.0123779600666416, 0.6711441350560035, 1.7723069051581046, 2.6450005606297524, 0.7877995302119564, 2.9615929530512903, 4.193696206615818, 3.3102776879264466, 3.317461018600772, 4.499509680655695, 4.9562000651513385, 4.798888016131617, 2.7390764028795305, 3.8971343780717547, 2.784926458712547, 3.6006512420792736, 0.7517331526164086, 2.099687409016394, 0.35302459232268796, 0.9901188770609518, 1.0689696717646815, 0.22927117804365776, 1.1118578478213281, 1.762038507769185, 0.7375938048766506, 0.2982853425125922, 0.5118462329189624, 0.26818130465765155, 2.008035836681243, 1.0638514689860805, 0.3524026821457571, 0.6443619463712938, 0.7134630771413927, 0.5123156609554445, 0.8667814178812889, 5.058780341379104, 17.040111595584502, 60.7973103369436, 92.08812821295955, 64.45613253501155, 30.65504481715541, 17.953653181752852, 25.21002034987173, 50.65755198078771, 74.95071241932531, 70.38543439680531, 33.844163187088505, 4.819556945754636, 0.21411605900333774, 0.08333379567991342, 0.06658084705592164, 0.05960000108086294, 0.07057208087175124, 0.07608304160737223, 0.05208153375274232, 0.04532214081395538, 0.021409796017612663, 0.06236802230799391, 0.07060366667686932, 0.040638692932383674, 0.026978636611132856, 0.015742518871481863, 0.05958903070178725, 0.009533707578215868, 0.0750108632529455, 0.02161873692286111, 0.057499227114021785, 0.028643669342742335, 0.05087103439314712, 0.04423976582925647, 0.04433741522652488, 0.044249253828198686, 0.019224595331076174, 0.05239243521505306, 0.0461659828321107, 0.033824321693710746, 0.015595894430824106, 0.017544296382355596, 0.029056439431564465, 0.04577203360836833, 0.03243158916912733, 0.053329127089631174, 0.059978777933264935, 0.051344066873312964, 0.013725929349029978, 0.061389616945938724, 0.03317331166697606, 0.10507937761083727, 0.020341082295823484, 0.0750583990086471, 0.08730182469251656, 0.00627347533853965, 0.06987184586544191, 0.039633501306056015, 0.20286667070561842, 0.20433539915229046, 0.11220642380536565, 0.16232160520890068, 0.23469554020031808, 0.13147859894219907, 0.15305100669783933, 0.10536610133825772, 0.1024180417880416, 0.18491966679932612, 0.1428801323016805, 0.16861091127559064, 0.11061997828824867, 0.16870178462516877, 0.09217353102060095, 0.2508010985630174, 0.18307629071416395, 0.1682484291133381, 0.2705158503545869, 0.21351969019780237, 0.14374697610976236, 0.0895854332033665, 0.12036695325326537, 0.18825633211001275, 0.22583613172173503, 0.15423900988553801, 0.1598459307945544, 0.1738656156005398, 0.25920217195826195, 0.15388198226930636, 0.1495094741544416, 0.15642187017346584, 0.1197071600284788, 0.10900583869266896, 0.1431948871862504, 0.16756095713184727, 0.12472183368499241, 0.15030277352179253, 0.17902051399071373, 0.1397001626150262, 0.0918270294524489, 0.1768260704533708, 0.10389240864183634, 0.16618993553903796, 0.3153489397898797, 0.18471006514324298, 0.13844786932872188, 0.19136421292299227, 0.3592093120659552, 0.1621988319581555, 0.381845310330391, 0.3313258260248169, 0.5503657159786071, 3.047210204024469, 36.31965337261077, 84.89123006020823, 107.1683628328385, 84.10141375757034, 92.01721176024407, 97.81174490528723, 24.804884618328465, 37.4852248930162, 64.65817382258754, 79.21308148291804, 95.88189955680602, 54.41036201292469, 19.3179339362729, 5.372750384192313, 1.0633351870121495, 0.15641206424803505, 1.5978402476156912, 5.25960079123897, 3.089527184924772, 2.2576723896688033, 3.2045847658188116, 2.0925339864146326, 2.762564536063902, 0.9869452505823105, 0.9399847962683248, 3.699297626172343, 2.8128870744859023, 6.225887960003269, 10.64039791783979, 3.3016619566948187, 6.8778584464903805, 6.091780652922969, 9.247222042852833, 5.070796032105723, 7.914305540823168, 7.233760587630734, 5.800558395924107, 9.897312733434863, 9.716307117092995, 12.668762418531603, 9.302840271303731, 5.024032554318828, 3.406799618274935, 2.409842456540754, 0.9893821456259297, 1.3030809933139433, 0.45351994494276665, 0.8461704657923791, 1.0549134905299833, 0.9687228993542734, 1.6595304276674026, 3.692924264938601, 3.9151101102752075, 2.0369495884064706, 1.2687307139558177, 0.7907242087587234, 2.923471192198415, 3.4549927999896393, 2.6230450935902137, 2.1802102365801415, 1.440358923808221, 1.057708546999962, 6.887723697770027, 28.619628875486313, 56.397254313192065, 87.4913300237348, 91.2142712070096, 43.343167074265025, 27.719099752364624, 39.56323777475665, 76.99173342797064, 86.16123076408141, 89.9007635731851, 78.00175943682271, 41.12421558749291, 6.574001744870217, 0.22416739303979183, 0.32646165800190746, 0.235582547442567, 0.10898076463490726, 0.41461720341636293, 0.17665659648276147, 0.19750546483743578, 0.19429122037704916, 0.11154119901719595, 0.3269256927794026, 0.1318464283981631, 0.08450763390189217, 0.09281237940153769, 0.10134833023673105, 0.16479588534322478, 0.13121904835345286, 0.1408378031825827, 0.12101481848907088, 0.1778131441002892, 0.13480161256607504, 0.10041459163110103, 0.16385773407115092, 0.18632186817065363, 0.21676266295534952, 0.13433650526548588, 0.1297232770030537, 0.21949396558826972, 0.1219491852867988, 0.13428746031657343, 0.15572756468769045, 0.10516618303353749, 0.08826706483359299, 0.20622431150367185, 0.10597462029827219, 0.23235736324662165, 0.16096444980752084, 0.12453901446274213, 0.10168172404049866, 0.18343399248776898, 0.42697178079716624, 0.12885209713732043, 0.34530469366619665, 0.1595259665120994, 0.09146166679960105, 0.14499335519729123, 0.2510429065554373], [0.06574696035034235, 0.02552945106740921, 0.08285306784654818, 0.002543812428954088, 0.0916069094091654, 0.025494260818607388, 0.025516080917910706, 0.025047175736436923, 0.10319940550553222, 0.0134321853833934, 0.04489621508025354, 0.19463245126028217, 0.03290833717572593, 0.040994544603651574, 0.03890092589802319, 0.031684448514434124, 0.06408233173011292, 0.025643508152795896, 0.06597475659462713, 0.019623964626882828, 0.1244095072991425, 0.10355158378520321, 0.08178608356824807, 0.06583413349524622, 0.13005336896786768, 0.14145053562618073, 0.07235870516348271, 0.10369020739510175, 0.06678906209286183, 0.06682580366971032, 0.09023819374100817, 0.07130179494138687, 0.005582204997359265, 0.14296360524191012, 0.09890242599912229, 0.14781887132313945, 0.07467833512853231, 0.052676362721549894, 0.030927992230581663, 0.025996339522422324, 0.07564138425814529, 0.06562553541434389, 0.06617481279517375, 0.10996703388950518, 0.06342147747355123, 0.04638951579709688, 0.042991831583241304, 0.037402457918130586, 0.055337185265436295, 0.0726508068281316, 0.05743052817941193, 0.09931062062781665, 0.24846653754432357, 0.07140512488061382, 0.13665431960215493, 3.1884905455573915, 35.74596751120783, 74.85635588246008, 66.5315095839962, 67.9216681757281, 77.03606405565816, 49.28749553618893, 32.150462173646496, 16.09860154890245, 32.177648121310824, 55.76809044807188, 64.04439741565336, 81.12786492993756, 62.402501106262214, 33.64547552600984, 20.5410897731781, 13.526927002014654, 5.893598487300258, 1.1226781962379333, 0.26507552292558456, 0.18706002452921483, 0.3621913859200093, 0.3484254907215795, 0.3017161906726899, 0.4180970199165806, 1.6028067036982507, 0.9959701953395721, 0.5151838328569166, 0.654818311093315, 0.9617944001670807, 0.2786174446584717, 0.9069808091848128, 3.334963614902189, 4.7167486817606035, 1.6894684083038762, 2.0259379018698973, 1.7437434701188919, 2.9115555219111906, 1.5273317213981383, 0.5293554788635624, 1.779480429906999, 2.7925419855502347, 5.200181786091098, 0.7061314931319607, 4.455351637255761, 1.6405741029208707, 1.6391182907166022, 2.11004933041911, 0.9423603429909676, 2.736773971588381, 1.7902396138637298, 1.0132099928394442, 1.1210310459136963, 0.5566320087640517, 1.0168129962778862, 0.32701952322836847, 0.7248793806760543, 2.3392140528848095, 6.885864984604621, 20.327589281143684, 32.619640404178256, 59.42627722217191, 63.87823404804353, 50.02257516307216, 23.906200970372847, 11.48307208091982, 29.678657054901127, 61.457609976491625, 67.10548570079189, 63.863568305969245, 44.27274134851272, 22.433184269935857, 3.9295976296547925, 0.062102584333549586, 0.29892882572547086, 0.04611102368442282, 0.013434987349976456, 0.1508446275106361, 0.039090540320161855, 0.0368831882012948, 0.04273349907429468, 0.036911322780314, 0.16154808623175468, 0.07010310482714446, 0.09438784687869972, 0.056245539547695275, 0.027416471181617632, 0.04985675313359788, 0.03111223829159093, 0.07620943845399926, 0.05005562955874109, 0.08211394621720237, 0.03862311177316212, 0.07185709377330157, 0.03305570950971977, 0.04513237317423186, 0.07395622831198477, 0.07694977816314467, 0.059215704564966505, 0.036410220838602514, 0.07312761229132453, 0.067124807786557, 0.01083327136227801, 0.02596942876886216, 0.09608532151868267, 0.04581664290819918, 0.029847543957012317, 0.025116066193027843, 0.08872228959995894, 0.04697777173151413, 0.030964841059739553, 0.04331536583542343, 0.044915072334509705, 0.016296691554147872, 0.04143733959344607, 0.08920079577834376, 0.037683267446775595, 0.00841359127192728, 0.0758404751879073, 0.04254721713462665, 0.029510042006750743, 0.1259559400439743, 0.04623687660862361, 0.07047438933964699, 0.09840010980805082, 0.036468688668983604, 0.059273988534245765, 0.020506222124001192, 0.048157160260504296, 0.06697313769930793, 0.06200897605008176, 0.11446253742061316, 0.040709881652747436, 0.00453129994697989, 0.03685008554208664, 0.015530914853086636, 0.043278199079776966, 0.0600520427519035, 0.07702778889647416, 0.053449544620009205, 0.051306965235140056, 0.11339857918961395, 0.1050678939528523, 0.05123679924215521, 0.060085739129252975, 0.0278587969425585, 0.07690407335758209, 0.057719328005107186, 0.09406890149318403, 0.09907341682382169, 0.06200908330239116, 0.0817673527184994, 0.07503462730035668, 0.04511370361151715, 0.043957052572119626, 0.045383799400541096, 0.08305099432266529, 0.11013697517374832, 0.0362584856338799, 0.026350337260913466, 0.01714396756142378, 0.06924627378823296, 0.0364538342241318, 0.04751919288068049, 0.04315723379653308, 0.08903152865147398, 0.0403851484729638, 0.08611089504894712, 0.03275035835442043, 0.0174525382012249, 0.04075651725513801, 0.03944800843694999, 0.050629992488651514, 0.0829854401789846, 0.10943268756231955, 0.27156753585703913, 5.755895347364488, 42.8393425480012, 88.29644357004474, 77.70696193941178, 72.02249834614416, 47.456831239884906, 18.042849840656405, 17.806762379984704, 21.91267986451426, 67.17038523766303, 97.37400839405676, 103.21520205466979, 78.36620253901329, 36.58498210291709, 14.551700142122085, 4.640261482807898, 1.1925017785641456, 2.102675764791427, 1.1515264934109104, 0.4565185356524683, 0.30447275888535286, 0.28968272670622797, 0.0340657657943666, 0.07425360066155273, 0.7511138471384203, 0.8978131269254993, 0.2685228879413297, 0.6843549842315336, 0.7754953614165707, 1.139247513586475, 0.6933676715820067, 0.453995501682643, 0.260569179250348, 1.54842818936994, 1.3162512091859695, 1.9360149916141265, 1.1597692317539647, 0.7968636986709411, 2.648263727464984, 1.739682591249866, 2.481416641704498, 1.2807506947748124, 2.498898155266239, 0.9411986472625887, 2.541576239370531, 0.5924159144201587, 1.1222756629989994, 0.5367787482757722, 0.7455016095792094, 0.5450650616999596, 0.2697316521117764, 0.8893205826320957, 0.6267774705925296, 0.7362754594895148, 0.33145134187033104, 0.1749429803702139, 0.7164281438435278, 1.2378927945129334, 3.2817887779205077, 5.5478425372031435, 15.532833972284871, 38.72151282525832, 64.66034289329284, 82.00315752337056, 53.17994194646036, 27.174259001208892, 18.617337826759584, 33.04801617899249, 56.86063135823896, 74.3123858974826, 66.96719077325636, 34.30233524691674, 7.411900422265453, 0.10626349673275987, 0.266170630291585, 0.06773289773733386, 0.03558989005884336, 0.013222797274319156, 0.09235067353133233, 0.019473564330368273, 0.02293109341764883, 0.06531929176661276, 0.024582325075302395, 0.01652973550071399, 0.04605901397524342, 0.06291129355949741, 0.04301610507912213, 0.08395019002378949, 0.05230003352006597, 0.06090030509738192, 0.022323869146226395, 0.019305116917577483, 0.043983222135613044, 0.03859613015646896, 0.02042976080349857, 0.05199236877923531, 0.04506936627289942, 0.02680777027572115, 0.022473296511077115, 0.05464497886057343, 0.025937251160822572, 0.005198911099033731, 0.021622816341057904, 0.09028448843427243, 0.024367554240950176, 0.01418103920220728, 0.013729997275907908, 0.06002429121684644, 0.08893723088887431, 0.0013589966458253443, 0.03232442112939973, 0.006107559846338606, 0.048660583448626345, 0.053821855690330274, 0.05958260322410253, 0.009812665089303929, 0.013933101548783243, 0.02585931703628552, 0.04975733024278476, 0.019155656993989984, 0.014602463211744063, 0.18599871696243364, 0.12282888405025007, 0.24554138402304343, 0.32144770446804266, 0.23531121442154532, 0.15413517432828105, 0.10608255442592407, 0.28749101044189546, 0.24720701238801404, 0.1610257215197048, 0.14155634769028233, 0.22028257649752403, 0.12335658073425294, 0.12996606558801668, 0.12947906349455157, 0.24105054596739434, 0.23758255786472754, 0.1964239938364875, 0.23679624521924605, 0.11385105370033173, 0.19595441258242055, 0.23549173538002277, 0.14981094507440446, 0.14874145568859193, 0.3028249956907765, 0.2752202737235254, 0.11095539456413639, 0.28506756790222665, 0.15890350475186305, 0.16023842828168025, 0.13463978415295003, 0.22777546798029255, 0.23967659791871426, 0.1898512199160553, 0.18260283305520014, 0.19738350363989032, 0.19715907052159312, 0.12978010540527682, 0.22099453264907484, 0.11114448804648654, 0.134335279524807, 0.11477272642115433, 0.1691626937639329, 0.1397192535260993, 0.17187167259473957, 0.17008892470790496, 0.35488358127974695, 0.10243763065626545, 0.2517466808879568, 0.14536041856533097, 0.18894711359133645, 0.16326752461252675, 0.5343255508811243, 0.15007149157745225, 0.3838111838746456, 6.308193995106605, 51.85267856044155, 103.03758144378664, 88.20137316180815, 86.67236266597625, 106.77958534609888, 74.47995739598429, 45.64932069470806, 23.81934400527708, 45.081698817591516, 78.74047510085568, 89.06958195470995, 99.78649354750111, 85.49816977593207, 51.42077461365731, 31.953549385070804, 20.244546821040494, 11.281601498203894, 2.709632395736633, 0.847506829567494, 0.28686572947809774, 0.8692383537850074, 1.3604304578996476, 1.7149682270903743, 3.635499049578944, 3.387746460014774, 2.714416216458044, 3.3369184261368168, 3.2594391126786513, 3.7437275388548454, 4.825382646053068, 3.103494009663982, 10.893616330239082, 15.330629906346722, 15.223415840056637, 13.896258358032474, 15.16348300441619, 12.051337226744621, 10.325235474494196, 11.165517972361657, 17.536666008733935, 16.928845720906413, 22.74086283099267, 13.464256351993932, 16.11161401194911, 9.354173310341375, 5.656837849847733, 9.001868963241577, 6.367932673423521, 11.896185913393575, 8.0483692115353, 6.8011658133999, 3.241590367209527, 1.8286236832218787, 1.9689512565251321, 0.2028535859238717, 1.1572323162709515, 5.682141059829343, 15.789017696534435, 39.96959140223842, 61.933687656156486, 88.06651423054358, 86.92524571572581, 68.17305288007184, 39.72984044782577, 18.13725148477862, 45.73853500427739, 83.3538256922076, 94.13016119310933, 90.32703107403171, 79.42623876756238, 40.07014528397591, 10.619367149568374, 0.16116629865381027, 0.6313203106964789, 0.1627933621526726, 0.24953630272178884, 0.33190054518561213, 0.2929643409386758, 0.20214083304087963, 0.14019520863169624, 0.16323833666261167, 0.2442043614123137, 0.1241301456766744, 0.15035065401706005, 0.22342586589436378, 0.18365536125436907, 0.14501839095065672, 0.1096419138353198, 0.1408647541557589, 0.12796937232656827, 0.20910069586769228, 0.1324344774888408, 0.16643741258209752, 0.10371047808157821, 0.166028045838879, 0.1593420747667551, 0.14138289006246677, 0.12896287345117138, 0.14705767103981587, 0.15932998589930997, 0.1507656132021258, 0.1050082233644301, 0.14842493880179622, 0.279970417219785, 0.1572859254215033, 0.09567813812604836, 0.22694829220492996, 0.17794494186678242, 0.1427578187036899, 0.11433742760169892, 0.14882022484896645, 0.2500390709047356, 0.12727168073216755, 0.19187591369113616, 0.24528898869551, 0.25383073115541094, 0.1233252170946329, 0.20991331597249355, 0.22245658080904718, 0.12580968619834992], [0.10066782199447194, 0.021613778418771202, 0.011560189210990024, 0.0509210905781196, 0.02591175958514214, 0.024996370700518453, 0.05559588166614694, 0.049560349885254144, 0.06513605119600412, 0.08875336212616775, 0.03698658708843493, 0.12551016114171476, 0.011755971598529048, 0.034610178516877275, 0.11760187380376363, 0.01637210333419423, 0.21106204949319365, 0.041105688639706185, 0.07969074882566929, 0.03879960310915786, 0.06921193006658746, 0.01997555493407192, 0.13883331880694436, 0.0138435362943358, 0.023425991962393446, 0.07179162389929257, 0.09773978032171728, 0.027988685234900446, 0.25619362210554464, 0.1079659969095261, 0.1122565795817683, 0.10479278411836394, 0.11846926919515095, 0.07262814594733139, 0.13014888481026696, 0.03786365817030592, 0.06854497391970889, 0.11067103804840196, 0.010596295469440522, 0.016372049708039533, 0.060554987135072874, 0.046241840858372955, 0.10801950049015785, 0.05471840838811571, 0.0993347907018277, 0.05144591060196681, 0.11475385001470005, 0.08206543752983694, 0.03416655232168494, 0.07154108250453588, 0.11910817886312162, 0.03441084626941912, 0.026270639218930757, 0.11904532900981366, 0.08492093067616226, 0.26484934312682, 0.0349065434608248, 12.021837080678633, 58.02845039675313, 79.12477324085852, 71.62510733450614, 74.18318302400651, 71.85415021834835, 62.72177811591857, 34.46237187231741, 27.873388144277758, 13.177296730779833, 31.692160675602576, 64.86356089192053, 67.33515616386168, 76.692731149735, 69.81968741263114, 69.33633373629662, 69.47440116636216, 53.563596817754934, 34.40288128391389, 22.181717195818504, 10.23497389208886, 4.390066237218918, 2.312310515872894, 0.7912643313888581, 0.11569539505627849, 0.11733545140633661, 0.38835488199707, 0.224946565745819, 0.3838556476177708, 0.26320038483508174, 0.4266768063028013, 0.7280067967311029, 0.15441925505236273, 1.5506032662045572, 0.6676941040542819, 1.2205265005750041, 2.3575334827746115, 0.42828350718463626, 0.632476490591803, 0.2775414282035443, 0.5397797904668317, 0.46728967058081783, 0.9627552582852302, 0.6518547152799945, 0.7612148083506093, 0.5945667828763685, 0.6907414608905393, 0.42413005425084027, 0.6992730450245642, 0.5341765621016102, 2.1952932207815112, 5.865705532412376, 13.307843016039941, 21.30003506137479, 35.50404356371972, 44.46849115433232, 39.05005447326168, 45.04383617831815, 29.301619222087247, 36.39883425927932, 37.91452438600602, 17.701791909433183, 36.77446003883116, 68.29994155514625, 69.70474627710158, 61.44167730885168, 53.10996686258624, 24.90134354560606, 1.6105770415836766, 0.13122736806831053, 0.4209251100978544, 0.027021273234558683, 0.17200670325227324, 0.15535300897975124, 0.10108318720613757, 0.14729043919472926, 0.00989398149202668, 0.09342146526661613, 0.05344037454755557, 0.07972656343612941, 0.05001354068818112, 0.13130177052751665, 0.12435847818250619, 0.06709762698700351, 0.05782193399124569, 0.12704189265927962, 0.12705977315143233, 0.05834121136896073, 0.0657920905899617, 0.06699658765067017, 0.04294348760477958, 0.0587455602362752, 0.04399056891880689, 0.036413492034039194, 0.048305310173741275, 0.017930178700255293, 0.038433914868942196, 0.04504176029454797, 0.0076526155481265205, 0.0647098611619684, 0.03504478019632159, 0.13664190897778158, 0.07249977259385972, 0.06514303791787356, 0.04167554697262184, 0.03272290942409346, 0.04326111531906551, 0.06615805845226973, 0.07442899649181674, 0.006359972410850348, 0.06145278089529565, 0.04689029215144054, 0.09389202711322615, 0.040393966144972274, 0.014110067859292032, 0.17687496218469836, 0.05813781502506426, 0.09612530364745087, 0.06968504298598537, 0.0987231154595652, 0.0207299925762439, 0.03887604719268219, 0.06154995148761138, 0.0580083538267401, 0.05538399323760983, 0.06778330632275151, 0.038717049474437396, 0.03187400356475865, 0.09009470547279043, 0.08185320819217352, 0.08907134990177809, 0.04401614859459862, 0.06610927397325154, 0.027405039234567555, 0.01606873060095935, 0.057066962002746524, 0.015298276933120384, 0.08059284033914728, 0.14654071490851142, 0.044190364649459246, 0.04975983918073678, 0.034487972171196056, 0.04273613441675421, 0.03036741505286867, 0.07214706571352097, 0.10684121129733902, 0.10933260583589155, 0.12577076893179648, 0.05351498002006162, 0.09441652154970555, 0.03477558073016905, 0.055356747320582794, 0.031094855756589004, 0.03392158804701702, 0.07636487769383578, 0.037612496244330565, 0.05396111515320597, 0.011361080086639812, 0.028483677625415788, 0.037155700997719844, 0.07129215755529943, 0.07062056657647894, 0.1330680781674962, 0.11718476957250988, 0.031229105004439914, 0.038902377634639704, 0.03499111956766537, 0.06193033329421475, 0.1252564404820723, 0.20633122673438442, 0.07013355682213461, 0.10568978880802471, 0.12212851880899361, 0.028682847079190037, 0.17185578393118997, 0.03023510400746619, 17.50290224629064, 71.54803276062012, 90.9879033796249, 81.6954868070541, 73.9183916584138, 59.469454673028764, 30.49843634328535, 18.983663666632868, 26.539229231496012, 27.546466435155562, 66.85735656369117, 119.19801327490039, 108.24370414979997, 105.51644094528692, 86.55303632059406, 66.14560327222271, 46.77765715506769, 27.332587434399514, 14.744207128401726, 3.3092186479799213, 0.7010192964826861, 1.2696432778912208, 1.500582382563622, 0.7655631234088253, 0.19087705761194232, 0.15964929134615008, 0.4065941790899923, 0.4737556978098808, 0.28013322622545306, 0.11748808676437025, 0.1624977901097267, 0.47212736260506416, 0.16856702975928786, 0.8185289103177287, 0.6551194755781082, 0.6210480522244208, 0.39505793682990537, 0.7931453530346194, 0.21088260105781018, 0.30068184940084336, 0.4613616209357016, 0.04057264466199183, 0.6243410658451819, 0.6614799665347223, 0.5627854108329743, 0.5095892766069982, 0.5330131503362809, 0.6391500970048289, 0.36276034409961394, 0.1665941541714053, 0.6569279946627156, 1.5004947421050843, 1.7754235959822133, 2.6098928961061665, 9.899947585598115, 21.25472972469945, 34.17609768529093, 58.19724567474858, 50.30042409896851, 68.85760061202511, 56.35651657658239, 26.995840187995668, 17.23303141132478, 27.20658325379895, 57.12475984327255, 72.8337464794036, 73.19454962207426, 41.356102189710064, 7.559954697085966, 0.23170834887892972, 0.5388500661619249, 0.1689149256074621, 0.09733841153642825, 0.047841194957014055, 0.155726982460868, 0.12032913149244363, 0.034323757394186916, 0.0535934197626287, 0.08401558328900607, 0.027078172499914805, 0.032497897909413424, 0.04073057751802187, 0.1722678932691774, 0.02698165691277433, 0.07798959696364981, 0.08505571618556015, 0.045416388780839985, 0.09494827083882787, 0.0911988373545389, 0.01944135033315228, 0.01852838037114951, 0.006184528700091066, 0.04008397632729142, 0.0038256515718756187, 0.026151669594729622, 0.019609135079888568, 0.02350794230287354, 0.05257405167926223, 0.023047303210102746, 0.04340138218756165, 0.04516611934729642, 0.0619417250216488, 0.01804732311997683, 0.0421959926344214, 0.029241834624460148, 0.050581571901397365, 0.0343960952464371, 0.02405331646572919, 0.04120763579022981, 0.12075886851356876, 0.050392420962452895, 0.030418513117418177, 0.02680786029105225, 0.06488129631766389, 0.06547483825875867, 0.06807880941778421, 0.0328085005974337, 0.07258161376681059, 0.07284319448855615, 0.20679434220637047, 0.18220154087870352, 0.09228646770239839, 0.3353467457477124, 0.1411180381452845, 0.07698167040343247, 0.13141885940586367, 0.16618981296497007, 0.14136018321639107, 0.22297188219043518, 0.17119238243228005, 0.2102162731030295, 0.16690765267177937, 0.10246459695120012, 0.21393133988303525, 0.10572406358175701, 0.2960120838495993, 0.06552930711017502, 0.1344704021128916, 0.2347301367309786, 0.12233771443847688, 0.11913690716028215, 0.19890605742412232, 0.19440873826463378, 0.1304831596151475, 0.2934803164774372, 0.22931312901839135, 0.2839965156970486, 0.4995006953756656, 0.30126312627427043, 0.27421620824644644, 0.24794964270005304, 0.2195675406725176, 0.14567413157032383, 0.14732802346829446, 0.12626140994290191, 0.1291071431290719, 0.31030967471099674, 0.07552850120250257, 0.1295117294836429, 0.15360173198484606, 0.19433692518261172, 0.3194668768875061, 0.16167905662328969, 0.2149858905543243, 0.22691507463253316, 0.2624340824061825, 0.14506892211014225, 0.16160804027270886, 0.22983078995058615, 0.4157994609446295, 0.17372096287867717, 0.143042512298111, 0.31929466032212783, 0.3829841153515924, 0.3694191190504259, 0.15278960217631635, 21.166719582773027, 86.95007431891658, 112.10966279429775, 91.44282771695046, 95.85034801113991, 98.18161656779628, 94.23956394195558, 55.21574228040634, 38.12857597104965, 18.561014552270215, 44.17953406610797, 86.88898732585292, 88.57529271033503, 105.27535638501568, 96.83310570255404, 96.14912279190557, 100.10844953598516, 88.32332749520579, 64.86691451841786, 47.89124550357942, 27.907136217240367, 14.901992313323484, 6.736725684135192, 1.9951377352399213, 0.46110942479102845, 0.2665948284970176, 0.7231078789599481, 1.249711386138393, 1.8677970070031382, 1.0746694884953962, 0.968580652148493, 2.8999004440922893, 1.6403521212839312, 4.23173584284321, 4.454380850638113, 4.471374519409673, 8.114482231678503, 3.499394275488392, 4.490801528576882, 2.8109126514004124, 1.867229734216967, 3.675562628815251, 5.087446493487205, 3.247955148258517, 3.803260537885851, 1.9320472690366932, 1.5021160293009974, 1.307259175565935, 1.427630219728716, 1.0460708746987006, 3.6348170474652326, 11.531547673286932, 24.282340580417266, 41.45787592857115, 59.47812311110958, 81.1635192748039, 63.76504228961084, 73.2746522657333, 46.88450251856158, 50.102815089687226, 53.523051277283706, 24.783897976721487, 59.04763121758739, 87.92472054881435, 104.21404146379041, 84.89489355394917, 89.31527137756349, 51.685703262206054, 10.10162409274809, 0.38123525919452794, 1.1935301749936997, 0.244490985548304, 0.22681677023008948, 0.23826960083698076, 0.26638118189669424, 0.28397984562381623, 0.14525266063790168, 0.22850268460329504, 0.15982884703384292, 0.1321167808266417, 0.1045486931839297, 0.2493493772682644, 0.3559888622933819, 0.22167641218871842, 0.1916798564695543, 0.21704465992027716, 0.17630450247276216, 0.159339010415058, 0.23971726186573508, 0.23623143923619103, 0.12980736281362273, 0.18275336933232125, 0.24918384098958588, 0.1445878342154526, 0.25820349974016993, 0.10859883916113647, 0.14209319146410113, 0.1393278438838259, 0.1455106330855239, 0.11767155716135619, 0.12440466562346106, 0.25711669676726867, 0.20206056234817352, 0.18620646468574004, 0.1436751630277403, 0.14776409603655338, 0.09169507846837083, 0.12610520461514113, 0.13940500425955943, 0.11516395220232588, 0.09191946562139258, 0.12618994926132504, 0.1391998612351956, 0.13129463058806237, 0.12892341992307094, 0.2530367576306866, 0.19791688469629135, 0.18212143872534076, 0.24170499955934865], [0.18801593371937353, 0.0352687306792265, 0.03711400283200126, 0.051916388178905176, 0.04069997613588649, 0.045107651516915336, 0.0826575622082718, 0.07961438518137702, 0.03191075854814582, 0.19746991835774916, 0.08305755969617637, 0.09577828880038955, 0.1186458524616976, 0.10261088910122072, 0.10975184745245403, 0.08042299098545506, 0.12151323529260775, 0.07174515300580571, 0.04951530774574607, 0.037153655542962016, 0.0628422996810367, 0.022455544338651726, 0.13958673563695725, 0.0548355087577816, 0.1289830062418215, 0.05200660269286844, 0.18828872230745133, 0.11895739743786475, 0.2241793440114106, 0.1160030176622733, 0.05863252779348724, 0.10964029738979955, 0.03817615309549916, 0.08509696235940342, 0.08197117807163347, 0.14467061767655034, 0.1185614295724419, 0.09867073036730291, 0.05593360386668675, 0.04814608645955882, 0.04903333884994349, 0.002656412750272261, 0.06969870999455452, 0.2058191429222784, 0.03208258823912231, 0.08433873449722606, 0.10837766191651745, 0.07279452492272662, 0.050656958783586184, 0.010942565295995485, 0.026329576278165467, 0.1589616661470744, 0.06845403162221755, 0.08763300450218302, 0.025563114886021903, 0.12311282687850537, 0.12201217303593313, 0.32287838898839494, 0.30882426086933384, 23.713208590784383, 68.01156105533724, 77.29393636026691, 73.58464502519178, 62.63288544070337, 70.73972640498992, 55.86423950810587, 72.56904925069502, 46.97354424384333, 19.04613721755243, 15.07107686611914, 14.401278226606308, 17.923497999868086, 25.888762973969985, 21.38487985057216, 40.02428885429136, 47.86718176257226, 36.08440529915595, 43.80257075832736, 42.0579985649355, 28.915675647797126, 31.212093945472475, 20.638364553451538, 18.25661313149237, 14.590591422973143, 11.01725826340337, 8.853952461673368, 5.92566680523657, 4.815085443758196, 3.0338378635145005, 1.6352639491519623, 1.224731158825659, 0.16956562536858744, 0.4912460673480265, 0.7099461206986059, 0.5343937020628683, 0.6404912411685914, 1.3866277231324105, 1.8627083445748978, 1.2186285637078749, 4.021616924193598, 4.29355239675891, 4.554363537219263, 6.42381860363868, 12.72330983992546, 19.792062197962117, 34.60971178547029, 44.85611154187111, 60.21398328965711, 55.56053430803361, 52.340958733712476, 40.624093778671764, 31.312130074347223, 21.97516126017417, 15.281030554925243, 14.651895126988812, 18.631048471696918, 27.44911320747868, 40.51070197936028, 60.30946946913197, 63.010229218390684, 68.8883912178778, 67.6583908450219, 42.685130642306426, 10.25835317950095, 0.6243438850487433, 0.5718527049306901, 0.1500980441849078, 0.004565845724315413, 0.15806266196793126, 0.06756948352220558, 0.07091118203055474, 0.02406408383150495, 0.03417927321166762, 0.05709863207753628, 0.08573214884006208, 0.11301620172396784, 0.07495433362501283, 0.10305787076152141, 0.04242721329172773, 0.1104976570293788, 0.020947258942009463, 0.13975548948491776, 0.07004422330928427, 0.037379073084241925, 0.05316172921729665, 0.07870085597518953, 0.15286671658677442, 0.027694291052138133, 0.02614991908382264, 0.051375193025676474, 0.09578044150745678, 0.020953874111235626, 0.019095570802868857, 0.08744556576974931, 0.05820222769773776, 0.04763037139069169, 0.12303495404100227, 0.0390048916902273, 0.03659447647571083, 0.03539341914978239, 0.010645788579788661, 0.030394193656261892, 0.02883718123719577, 0.035309785331088694, 0.013999716724239051, 0.057127214817991184, 0.1034115735561617, 0.21542893452269418, 0.0746929367643691, 0.09392939688217256, 0.11423126313715212, 0.06131222291338829, 0.03672519405823081, 0.07486342197103847, 0.09387839074817397, 0.08815945246286931, 0.03665836054771658, 0.026051156943844214, 0.05649824514083805, 0.056840916269368706, 0.03524136984901082, 0.052627769764512784, 0.033719731539848356, 0.0916099354564663, 0.13199029971034298, 0.09487319422224838, 0.1187067564516779, 0.05608860643640642, 0.12550881282696802, 0.028365294058476726, 0.20310546031161664, 0.09910759966700308, 0.09762399379284152, 0.12113320205600993, 0.06264182213213175, 0.03998707003530957, 0.0342491059564054, 0.06189184886733852, 0.1225156000544948, 0.03520309992675339, 0.15373697714699855, 0.11387555319215022, 0.1749130876194085, 0.1578667426421758, 0.1914129361149765, 0.1533562774139066, 0.04348842509751839, 0.05153629748571304, 0.060102443676441915, 0.0561238962766384, 0.019906139707252867, 0.0600622087386587, 0.10560251607169067, 0.04518221868502517, 0.023598465167226333, 0.05305988548864281, 0.14896959667244267, 0.07263815105562249, 0.14851049550117987, 0.1019664406175575, 0.04979220639553763, 0.04461138742044569, 0.09953977284772743, 0.13926099505155318, 0.08883861239038168, 0.09167083178556736, 0.0737281869195642, 0.09439668753334592, 0.12293144790155273, 0.021634240627228733, 0.03975624008284461, 0.24704257927594647, 0.12516537561051308, 0.33766986141281746, 1.044866216759528, 31.398108428524388, 79.16766043632262, 81.68548476311469, 80.16564476874568, 65.58956415422502, 54.02360062445364, 33.49379354907621, 22.73530875482867, 27.966267908773116, 26.061462971471972, 28.28870438760327, 36.99233201242263, 50.60231716402116, 64.5763021899808, 63.79700568414504, 77.61887335008191, 68.84795942614156, 60.31444303451046, 48.498675515574796, 37.952955768954375, 30.11585816260307, 19.998992719957908, 11.862069137634771, 4.688403673710362, 4.671024141773101, 2.2505045033270314, 3.225456923246384, 1.173866965597676, 2.771696549269461, 1.3794537080872444, 1.2244184723784848, 1.2593903248348546, 0.28040166343412093, 0.21768656499203176, 0.5205917394449634, 0.8080612687814621, 0.37568320550264855, 0.261943786134643, 0.7097606048468621, 0.5990215535125425, 1.436735756935612, 1.9312463700771334, 1.0883206850098026, 1.6010351406951107, 2.137686595801384, 1.7126318427824205, 6.647926655507858, 14.988660024058435, 25.316118501847793, 39.214903846863784, 45.99111995389385, 47.602276648244555, 46.04597822312386, 47.2262272527141, 28.6096425210276, 31.796499644556356, 23.85745179268622, 27.097796317069765, 30.021811492981453, 36.47397510467037, 58.590008289583274, 75.54169593318817, 81.28348888889437, 61.169974727015344, 19.723875714886574, 2.3832889910667174, 1.4020824744816751, 0.07457917270761344, 0.1352181652140233, 0.13187566231335365, 0.16260133455357245, 0.05359517027353568, 0.04464768849673771, 0.0356422291858302, 0.10980848433269609, 0.10406326923158862, 0.10423054452985527, 0.13322910984917996, 0.039346884830944964, 0.22171919053841024, 0.05418004009932761, 0.10964312425424015, 0.15632217149099997, 0.09176883741372055, 0.06596318100609126, 0.03011804194219651, 0.12122238235127543, 0.08998985101859416, 0.07285935894375847, 0.09237438395258882, 0.035490877025069735, 0.053300214931368835, 0.06501854863017797, 0.08889095917824777, 0.0423012646065364, 0.10069279646080348, 0.077784959557316, 0.03728941015358414, 0.06631313763078182, 0.014924830137451571, 0.03629823027539157, 0.04688829649239779, 0.02865570458403278, 0.028373180933657195, 0.02608635676874509, 0.02532845066349593, 0.05797026393514487, 0.11428577795384393, 0.1409875120847456, 0.01734032355729611, 0.04000762417431801, 0.040215885176533656, 0.02746779141166518, 0.1677259571489788, 0.1611579636171941, 0.024084666698810556, 0.08246241663131984, 0.28368456469428155, 0.09654642217942784, 0.3812047382516246, 0.12227469604582557, 0.20411513355230132, 0.19024347225504537, 0.21313597207828877, 0.2340450855873285, 0.3441422931369274, 0.3197685010250538, 0.20581279971426536, 0.2928158118119163, 0.42895916609033463, 0.22638891012437884, 0.29943744682015916, 0.262616656480297, 0.21456216732340477, 0.2516028402192939, 0.2124722181789337, 0.19470734401575981, 0.10807480437741165, 0.3066747713713877, 0.3585133365085048, 0.22939822606502042, 0.3028101948720794, 0.28074747552314117, 0.4231155393344741, 0.3651982503792932, 0.3290616991298814, 0.32139138168384956, 0.2920270783285941, 0.3125506657506189, 0.18400532553993887, 0.22881583070322392, 0.08680790482509522, 0.27330885370892866, 0.3321539670709641, 0.11615215199849299, 0.26738242817021185, 0.18876427904732768, 0.24637116449734858, 0.16401200885734252, 0.14240650610337335, 0.3318642632615182, 0.20510283539131766, 0.24138385550149027, 0.536706552149788, 0.2783239104094044, 0.38622322702600115, 0.2524932795354436, 0.34965607307610974, 0.25510951576213686, 0.35646791239419295, 0.14697232884505104, 0.1153523408837857, 0.5654739504379611, 0.3190824846106191, 0.37263150957803576, 1.4305397603780994, 36.299543380737305, 103.7665617850519, 98.11996475342782, 94.20311727831441, 76.41378002782022, 95.85154041167229, 82.80687470589915, 109.8129032504174, 68.10299934879427, 32.40996814543201, 24.359003305435184, 24.071632815945534, 31.52150227177528, 43.28219382993637, 36.941603998984064, 65.2524874287267, 82.66214709128104, 72.76830565544867, 92.11687134158228, 89.82399494417253, 70.96461942118984, 78.84185268032935, 64.19501250790012, 58.29749361161263, 42.99230713998118, 34.737600664938654, 26.116933130448867, 15.565337673310312, 11.012676935042105, 6.378613287402738, 2.7601270281499435, 1.9590004485461021, 0.4069556806597018, 0.8509102211363855, 1.2754969250771309, 1.4260394534757062, 2.4691026056966474, 3.662337377186745, 4.994290201894699, 4.835539623614281, 10.24492298403094, 11.299299232421383, 15.633932082883774, 18.91869156591354, 27.36113444451363, 40.015534124066754, 58.702235144953576, 70.80169200897217, 89.11601497280984, 92.8850204713883, 88.77346654092112, 72.28918813890027, 53.42725523056523, 39.403526706080285, 22.04282214564662, 23.89155484014942, 30.188586750338157, 44.7488582518793, 56.51647867694978, 95.7468915754749, 87.65035860000118, 101.60181353169104, 91.30311289141255, 74.09376082881805, 22.221574360324492, 2.088306651961419, 1.632612059193273, 0.2681832658427377, 0.2122725909876247, 0.2932993971532391, 0.623403006503659, 0.19763364666892638, 0.17324462472911806, 0.21179127326655775, 0.18976149569836356, 0.5036841176690594, 0.3032649753074492, 0.24921975519147613, 0.1679345475690019, 0.25801127295820947, 0.2261008457430909, 0.1729379290895116, 0.31164242255110897, 0.19099756324243164, 0.12525408859214476, 0.10004029639305607, 0.17486831744111356, 0.21381008348638014, 0.14592611321037816, 0.27556124413686417, 0.12455291129768857, 0.1882081758230925, 0.18240648472020704, 0.14748563839783593, 0.16012314737083452, 0.19356659313123073, 0.16741362310224966, 0.17620201523025192, 0.13196295037144615, 0.12163515818575699, 0.11704142686099776, 0.09103912334408491, 0.14443392715146466, 0.13456194961984314, 0.15381950013820203, 0.16547453199182788, 0.19402695068668938, 0.22593071293686667, 0.29387086810123536, 0.13845186830768663, 0.1813858104569297, 0.21270278000062515, 0.18928570913210993, 0.24489679764355385, 0.21799586533058077, 0.31826509943892883, 0.21356551757743283], [0.12738289371613534, 0.0693065955513908, 0.08781207755448357, 0.1336330373681361, 0.07632619791453885, 0.11213349989585339, 0.20550965872262755, 0.13750018792286997, 0.26454539008198247, 0.3927310826557298, 0.28731769070990626, 0.24198244596200608, 0.2796477103425611, 0.11397067066882888, 0.16082371945583052, 0.1097805680887353, 0.21799845470776483, 0.017956654698918426, 0.08878670993351168, 0.05221915378746006, 0.08328033806455713, 0.09370446580672458, 0.09764987990380296, 0.06792789775758021, 0.07220702741535441, 0.029492372188777215, 0.06267693194170153, 0.12347131772267243, 0.007641596809750604, 0.0432569248181197, 0.01457257046093864, 0.04361269221971593, 0.03936255898987574, 0.1040413591169542, 0.019044219929304336, 0.030413947233389464, 0.04401737816571709, 0.0972549309353194, 0.0625460458198382, 0.05674735395117633, 0.03103218593394324, 0.07050391436824877, 0.017202044686963482, 0.015252833555061972, 0.036318140900543625, 0.09363253015063464, 0.04798422740291684, 0.051177676406598864, 0.038369000408678286, 0.06490093881204244, 0.01979445749443145, 0.03565863878916829, 0.011598657358497863, 0.05746982082904828, 0.06393386389038737, 0.14026987156079662, 0.02328760009409199, 0.1302213414061454, 0.07361318946125046, 0.340541894397428, 1.7015013819740665, 26.62335426576676, 65.64683860348117, 79.56083882239558, 65.52984214598133, 67.39637651751119, 62.96273716034428, 68.33092827950755, 80.89737076913157, 78.34721042263892, 78.24148685701432, 58.853685702047045, 50.391077918391076, 42.94352462214809, 26.789723557810632, 39.00881859564012, 19.502059798086844, 11.961373744472382, 8.81204781993743, 12.892744464258994, 5.6465480019969325, 4.827796864894129, 17.730831177003925, 18.967432898859826, 38.86330258461737, 37.66230029444541, 52.69625879103138, 47.566120239996145, 50.23972934292209, 42.82763035066667, 38.8679466709014, 44.42546667591218, 45.032869231316354, 42.84733241604221, 45.6784168366463, 49.598900348909446, 44.63492124311386, 35.3911812843815, 42.128448255600475, 23.551228430963334, 31.69866788771845, 39.30786794231784, 47.95273257840065, 46.01699582992062, 48.81510488448605, 39.88970448893886, 36.46870343915878, 34.26517078953405, 21.88127148535944, 30.15605265094388, 27.393403783921276, 24.6420140804783, 36.809031809529955, 48.516518377488666, 57.26112496468329, 56.859784126281745, 65.85648536682129, 67.50122931695753, 70.12731890524589, 65.73635885792395, 55.315641126325055, 15.286829779225013, 0.2674877805815589, 0.44873535813343146, 0.03041062624223771, 0.1871424862333844, 0.06413787693506287, 0.07885026610306195, 0.024741684770091407, 0.0334470387127611, 0.0728309600644054, 0.08385088970704425, 0.0559242882375275, 0.031130496082046342, 0.03755194465479544, 0.04402027397807087, 0.05735352102126326, 0.04010905421549275, 0.01742914953689662, 0.08736764696697075, 0.05221934530944113, 0.1358214441326357, 0.026273659520572232, 0.04458141806084783, 0.02758917038238818, 0.04142241620068108, 0.04195757075062683, 0.030880310918174447, 0.0642855327215887, 0.09127473368519738, 0.01806871229482274, 0.03046014425044339, 0.04036141123862998, 0.018442331460274516, 0.04361997005499659, 0.01791861460303828, 0.023750537450635628, 0.012403715217876579, 0.09612263766147437, 0.10264048307773568, 0.0721809651041704, 0.025464703231268836, 0.05336310691951264, 0.04084868912374781, 0.03655005869786105, 0.030273653551815983, 0.030776379599926934, 0.06629393946739935, 0.19621938707367068, 0.15890879075854056, 0.14732079159828926, 0.1168650734208284, 0.06301904765648708, 0.06679099263443102, 0.10996518761760767, 0.0324877817183733, 0.14888088369081098, 0.08018192609832173, 0.1251267188138539, 0.14898200729681602, 0.09214559179400245, 0.11131478173117484, 0.14279895762522377, 0.13629643396744806, 0.19382551552787905, 0.24475828894684393, 0.3383380126568579, 0.30323089971657724, 0.29594377945027045, 0.14460416720999827, 0.12168895287979996, 0.1184356302743958, 0.18256210782114538, 0.017735906463537007, 0.05183580339015011, 0.026777651528978062, 0.04522372532876269, 0.0772729906583986, 0.10166693854356006, 0.06549818861869074, 0.16784232590467701, 0.06191768518258488, 0.10659616275299942, 0.0831963595062975, 0.0021160792065559016, 0.10263677521218216, 0.05847102113729043, 0.033149084136370695, 0.046697203520565264, 0.037506331779783776, 0.03145990048294827, 0.07323227522353973, 0.021595587661009163, 0.042626258256214286, 0.042390659406420686, 0.17439686693251136, 0.03491203248080227, 0.052990780527433085, 0.012608285591517006, 0.046049422554431424, 0.10318760775149831, 0.06410110854513704, 0.006571097145487945, 0.009022363998566665, 0.07493565640141887, 0.08546578772966901, 0.03257614229955981, 0.026808390806939815, 0.15039369283664614, 0.05767557672375153, 0.03975512159447517, 0.08284153056240852, 0.03454328754976873, 0.12552221936564292, 0.1459923185287945, 0.2916767003555452, 2.826263827662314, 34.23286222642468, 78.83028168832102, 89.01231535019414, 76.31156306112968, 67.40127948022658, 62.62237348864156, 51.198874365898874, 33.75521952106107, 27.44941326879686, 20.31056227222566, 13.550606350744925, 19.265776218906527, 22.135356741566813, 32.674010338321814, 52.220816535334436, 31.353056084725168, 34.063749236445275, 30.469699098217873, 24.10532597572573, 29.70116165376479, 27.44475741540232, 35.61252455557547, 33.92737627029419, 38.89614459007017, 37.477231102605025, 37.458941090491514, 37.92546387641661, 30.38567996794178, 28.025442746377763, 26.04324552320665, 23.35268589758104, 22.308472510307066, 18.110051808818696, 13.763023288019243, 20.11876033198449, 27.838843830170173, 29.240649900128766, 27.5970140195662, 32.301959799182036, 34.39859413331555, 41.842323118640536, 51.44579933535669, 62.43897914886475, 67.36603306185815, 70.5777011379119, 65.98182078330748, 67.14734523527085, 47.48118131391464, 50.73732906772245, 40.7624710759809, 32.78219911359972, 24.22391099314536, 23.915877457587953, 23.646983292795, 24.336649717823153, 44.61548982128021, 64.53716085803124, 81.2867836798391, 77.57961042465703, 68.47928016416489, 26.07689749810004, 1.9321751137894971, 0.3427621704195777, 0.11957844959632044, 0.10652867806774956, 0.13190820572837708, 0.09489194805463476, 0.02862693989769586, 0.18848013703621205, 0.08753021082450306, 0.014627649309864689, 0.060178520037762584, 0.020020005270658482, 0.017045544415351846, 0.037442662212396824, 0.02737874901222606, 0.0235666916705668, 0.026516373411962585, 0.12191539314845878, 0.05230817703470107, 0.06554943223994586, 0.049116237224229885, 0.04572559718883807, 0.004121070397236655, 0.028777970301528132, 0.05360198462562216, 0.026160167425029704, 0.024112914275798588, 0.03487573523494986, 0.05680853373280937, 0.0376908746998637, 0.019826068197407072, 0.0555455458590821, 0.025512279206586462, 0.1281559223970098, 0.05125554158322273, 0.14086662341029416, 0.06312339649265332, 0.10409715330047954, 0.02472538050384291, 0.02684488915087235, 0.006229772416484212, 0.022855660570184552, 0.08479663291044774, 0.03431310877203941, 0.041964576624694376, 0.064070533976079, 0.136099518727391, 0.13639927361040347, 0.221196657287017, 0.07106238480416999, 0.08283049123541963, 0.06190104958330912, 0.05151010877002151, 0.08945913594816962, 0.280554911662494, 0.18585856883756577, 0.2590287602957218, 0.22004248454205452, 0.15519729394826198, 0.17496282204745278, 0.3098326164387888, 0.2526137851659329, 0.45215958729386335, 0.4277318013050864, 0.3321891151849301, 0.41369017574094963, 0.31526951179389034, 0.27062013024284, 0.34720885116727124, 0.20801651291549209, 0.31708409829485806, 0.1687809827947809, 0.2137786125944507, 0.2362060204388634, 0.14301252761675468, 0.15024900947126651, 0.2326198556129971, 0.18427068307515115, 0.14325009148207404, 0.13072499825108436, 0.12318423393392756, 0.3507075134304262, 0.14380204250975964, 0.11971055379798336, 0.17354284743628196, 0.17669729107329923, 0.11547647011015685, 0.14023072446786589, 0.12716114956645236, 0.15562788132698308, 0.10521120602084745, 0.14375711911387984, 0.14779395814384186, 0.3311168372390732, 0.08192543496167468, 0.18548226644915922, 0.12514580972492695, 0.11037651554591234, 0.2776584251513404, 0.12054191241341254, 0.17157429258429235, 0.13651596412302988, 0.12124514282350579, 0.1112066024553872, 0.19296585762452698, 0.0897092100292925, 0.23917713923560036, 0.2373014955270675, 0.3019647708823604, 0.24311149102305216, 0.1747572193703344, 0.331828287772594, 0.18469368618342186, 0.36482234635660726, 3.3124957882588912, 41.565635204315186, 95.97572265132781, 116.17927874288252, 96.25674478469357, 84.40152214419457, 85.7859540754749, 89.41699412561233, 103.13087894070534, 111.90590350858628, 109.03506586628576, 90.26499486738636, 71.83503258612849, 64.65901713217458, 40.519460631955056, 57.92784160183322, 31.458346228445734, 27.51652502244519, 23.63796380258376, 27.851042401406076, 24.13257468131281, 24.736537318075857, 40.677740035518525, 45.54943361589986, 74.69991607050743, 69.75664707922166, 86.73274363240888, 78.61726560900289, 79.06485511410621, 68.34725318416473, 63.76712899054251, 68.95653063251127, 72.36293654288016, 68.72620905599287, 76.81532875184091, 85.21940692778557, 85.16541157999347, 81.12481332594349, 91.38949917208765, 68.05313817916378, 79.0049683663153, 87.9960527727681, 92.40535382301577, 88.47972808345672, 82.4933361238049, 69.89768766587781, 56.16724260391728, 52.88424622627997, 33.17740340386668, 39.625521090722856, 39.827907546874016, 45.888236184274, 63.12524095658333, 81.40134042309177, 91.82581578531574, 83.15299249464466, 101.01597616749426, 91.97544636264925, 100.07295208592569, 85.98888966345018, 79.4136558040496, 28.148471809202626, 1.4031891957406075, 0.826616102168637, 0.17416987508054704, 0.23874558658609468, 0.23525668428309504, 0.3362496876187863, 0.15918203899937292, 0.3333393195944448, 0.15400218146462596, 0.1735114991184204, 0.12482056709667369, 0.09040755279842885, 0.14459310490037167, 0.16326674320284398, 0.21623537995882575, 0.14869564363071996, 0.19756831469074373, 0.20461757997831992, 0.1531351537954423, 0.17508021736096951, 0.11443860483385863, 0.1708670555343551, 0.1974104546130665, 0.14593346765445125, 0.0861802260060945, 0.12522054160194052, 0.1746817137445173, 0.11422367120582251, 0.1597166611182113, 0.18306737345072532, 0.14296967265827043, 0.10636808305618264, 0.09616043643965837, 0.1748083174348839, 0.12146821230529778, 0.20299194140299676, 0.18800258846773257, 0.21932046199517868, 0.17020795944957964, 0.12411906038441005, 0.21907794920186843, 0.1785159838055411, 0.17980973777030745, 0.1920658115658068, 0.18118671952716767, 0.15262115476352556, 0.23336188837645516, 0.22130269917749593, 0.23936450902012088, 0.18943969280489031, 0.11615704730032914, 0.2133554869121121, 0.17052279094294195, 0.19811726265376617], [0.03954958786526996, 0.10868553733152729, 0.05393902883834897, 0.09123668209799836, 0.05744918242036816, 0.10370499289204037, 0.20509825418553046, 0.25736867840732297, 0.16717811235256735, 0.06247492604738763, 0.2716385368858614, 0.14863650164296552, 0.20961218213121738, 0.1423841976230183, 0.07026759922624597, 0.24057688912557018, 0.19825385613066537, 0.20417482712336127, 0.11431399297209517, 0.18188998824165714, 0.0690087099229136, 0.06346304157388306, 0.08987632444909505, 0.11863911088796393, 0.19250730803656965, 0.13770246577839698, 0.02942047100664387, 0.02629492037569083, 0.02914164564572275, 0.04140685312449932, 0.043559835983380195, 0.1016515554980405, 0.07721862905929167, 0.05520510021597148, 0.07215432056616392, 0.09020952673088159, 0.059138819980885715, 0.019050467376326843, 0.14160488702116475, 0.08191863210090707, 0.059649386938901684, 0.05111393789129873, 0.013097167473226307, 0.08161343033275298, 0.022992719445497762, 0.05537859997862289, 0.08653886240696715, 0.05522304965603737, 0.04548545160721387, 0.04939176457663698, 0.05588162480102432, 0.06563766258618524, 0.09347410316789344, 0.13811878859996796, 0.09655114128104142, 0.04153456764235612, 0.025952209027544148, 0.06019097279697176, 0.0801477585768988, 0.15954226886312808, 0.1734569996234871, 0.6937245459806535, 1.261885442560719, 12.584443226937326, 31.075540550293464, 79.59072728310862, 98.48993839756136, 85.72027790930964, 80.13152014824652, 64.87384534651234, 66.95068543957126, 76.11916295943722, 82.5875279211229, 71.75487502928704, 68.11055383374615, 50.394337408004276, 48.493913758185606, 47.38158056812902, 52.552582371619444, 42.953040292186124, 35.75324743024765, 39.85765480226086, 20.189629716257897, 21.873799370181178, 8.926605543782635, 14.950311991476244, 23.226938632226762, 20.08005242193899, 53.456590637083984, 64.81720239885392, 36.65648298878824, 24.441641761410622, 19.26145180579155, 36.58145981450235, 51.62689908858269, 30.01431780476724, 14.49241351696753, 15.105732967776639, 19.162823807808664, 41.50554057090513, 58.8454604917957, 10.056068704974267, 12.524630023587136, 15.221250691721517, 21.38840017780181, 22.84973409868056, 31.625005775882354, 35.06373397765621, 50.73078655427503, 42.15245708342522, 65.28520784070416, 66.04364518196353, 63.89422162886589, 64.3644118309021, 69.30329168996504, 72.2215586323892, 71.57024906527612, 55.241888799975, 36.90431794812603, 12.152011721364914, 1.0631143085418209, 0.3797932365728963, 0.1081026057081838, 0.23851609728749723, 0.039225118985820207, 0.11063467185463637, 0.045990740219431545, 0.11003138527514474, 0.0342588774078796, 0.005502630965859299, 0.0788870919495821, 0.0450021956836985, 0.03348682165866898, 0.013785853704077103, 0.018373167127250664, 0.04422894866776563, 0.028942112300184467, 0.08030601702029667, 0.06698364842562907, 0.07689482667633603, 0.02322305527125155, 0.12840819515047536, 0.05699913257793073, 0.03149696573194477, 0.08927984839125026, 0.026561913508621436, 0.057051927527232524, 0.0011326015045333114, 0.04230569259473874, 0.027567195150280194, 0.06532694498497633, 0.021932199034058762, 0.02643955586057517, 0.02720590233953009, 0.02683367170844107, 0.04866601118156987, 0.01855001277891138, 0.021112519429035245, 0.02231915579027226, 0.021014105859062365, 0.030357823632056677, 0.005121896280005815, 0.03412729797644481, 0.03609260844607507, 0.19096273688539384, 0.03613747438536056, 0.0806321483105421, 0.13079978375425264, 0.15131515871372916, 0.049206949695343935, 0.1162734083951481, 0.12201103156492596, 0.008524707537294637, 0.07445638413510977, 0.04321767047287957, 0.07063743583257161, 0.12480401193662999, 0.12696123126173212, 0.1058056366239344, 0.06929036980915455, 0.10482934949498986, 0.1612537858947631, 0.10736887733782492, 0.25801642106906064, 0.2643055432746487, 0.10162370054111367, 0.2565467120298455, 0.20782146692997028, 0.35492734022198186, 0.21800628412635098, 0.15999341804173686, 0.14951030152939981, 0.1408520830614913, 0.08848705464192937, 0.04813694703062216, 0.1450225431472063, 0.09244809693266308, 0.05542366127032907, 0.1061884047944219, 0.1609840923018994, 0.19832887146021091, 0.046041359479028376, 0.06897186875463494, 0.052951047377240275, 0.018759248628010674, 0.03924371577018211, 0.046293816093595765, 0.07162599569006313, 0.18689436567646844, 0.050406926837299144, 0.1043138106263453, 0.02962084130323943, 0.0487619445418879, 0.0954273515831559, 0.08451648987829687, 0.050696040759043354, 0.06404324209377651, 0.025525846623725472, 0.021480387189395485, 0.09306956277859789, 0.03594955684797418, 0.012022892910716756, 0.07603805692445847, 0.09353896017156302, 0.05833921570991797, 0.02713163586093053, 0.01600568156479107, 0.051435085779596726, 0.06548465950594795, 0.04850913935731496, 0.12043456817346236, 0.09526258139240165, 0.03904763939640215, 0.047220725025380814, 0.02191922533506107, 0.34575852415254044, 0.12041763763033575, 0.3624652776746981, 2.8256293842869424, 23.65668135304605, 48.75965433736002, 101.274303467043, 109.49179449389058, 98.66506438101493, 90.49098614723452, 69.34555130620157, 66.55462803379183, 55.443075010853434, 55.17455347122685, 41.24490299532491, 29.645983711365734, 32.392582239643225, 23.222908396874708, 12.884514351044933, 17.949109115908225, 20.085118163016535, 21.318740844726566, 14.145680896697508, 22.451811605884185, 25.482460337300456, 26.9021681047255, 34.755729859875096, 48.633526602099025, 42.37411022186279, 73.20357107347058, 72.86183064983737, 66.45328967801987, 62.73704005825905, 61.057649812390736, 74.59987994163268, 87.56198760001891, 71.07875254846388, 51.00350110761581, 46.22222208207654, 49.45404329607564, 51.273626896642874, 60.23228506888113, 40.989231140382834, 37.05913389882734, 34.49995602330854, 35.39065568677841, 31.20865598801644, 26.738915135783536, 34.78448083323818, 29.17497177277842, 35.36321870742306, 44.186798295667096, 40.7230120320474, 46.46980208735312, 51.37086637558476, 63.43172711710777, 72.72590483388593, 84.01708279886554, 75.164811072811, 53.41351124548143, 23.775391886311194, 3.5370328493656653, 0.1844948710453126, 0.2376773382627195, 0.10719656118101652, 0.03020361587855845, 0.06535785663272105, 0.03725915351101468, 0.08275568274961365, 0.021879664554651228, 0.04994591044622564, 0.0277506789538048, 0.06150523493547113, 0.031021866729603182, 0.02123926867610745, 0.032875077468493295, 0.04747718444935257, 0.0727469508626288, 0.023250341407894608, 0.025477922078402295, 0.025832145812831102, 0.027973614370210037, 0.022744991508642995, 0.07563139447161267, 0.055005346620154966, 0.02865868275083842, 0.036111779796380195, 0.04360064548710662, 0.03123023498412823, 0.019966059274250464, 0.01807245080389323, 0.0521713575618642, 0.0547221468971862, 0.08105143589238006, 0.03558478025238841, 0.07731144827219748, 0.0022570745767875305, 0.006011310474751818, 0.023486729328250213, 0.023893127480762142, 0.06920723394761163, 0.0274665599253269, 0.12213071748133629, 0.10296912713637275, 0.03442439453436002, 0.028889317350882678, 0.06012594725395884, 0.06633612792938948, 0.07327658574908011, 0.08938397506191846, 0.03717187311380141, 0.14748116444435813, 0.08743104840358419, 0.06220491452803535, 0.06536242251674976, 0.07371791368049961, 0.04983197785012665, 0.12629503354189858, 0.3458400052641669, 0.14326562774517845, 0.28124279733146396, 0.17481294460594657, 0.1823135888985088, 0.24773706862282371, 0.34210685880914815, 0.31275370969407024, 0.11270971292810095, 0.3478898114014057, 0.2647117537356192, 0.38120256256191964, 0.2614078003792994, 0.2809304479629763, 0.4082581220615295, 0.28632165383427377, 0.15954105844420774, 0.1779880726169194, 0.3119332601706828, 0.08780044067891375, 0.11294567566965857, 0.13549054011462197, 0.2690487919795898, 0.23433909481090887, 0.2934335544705391, 0.19680392748165518, 0.1750084808877399, 0.1477456792828537, 0.13168009538804332, 0.13629503968742587, 0.2660883524485173, 0.2540988312853921, 0.06459818086436679, 0.16187021088215614, 0.19611573537751553, 0.10615380060288215, 0.12841098371051973, 0.17390750528823945, 0.25202025088571733, 0.2130578004664952, 0.09069136539173704, 0.08297898205778292, 0.24982012297597625, 0.2520070741734197, 0.09673336295471077, 0.2693662588154116, 0.24032427929341796, 0.10546335620024513, 0.20774102769792083, 0.17052133537588582, 0.16670177420300825, 0.2696204161451709, 0.26049906688351787, 0.3141981225100256, 0.15415345318615437, 0.1659543635023217, 0.19243578606795883, 0.1554766708924886, 0.4596190160560993, 0.35029609357157065, 0.5160051403987793, 3.192591138424412, 24.559052028963645, 61.31438855201968, 118.5799026489258, 130.04827760880994, 113.30332632987731, 111.48012238164102, 88.02543917009908, 89.34500294346964, 94.13438166341474, 106.92847067309965, 93.28089744813981, 99.76364966361754, 73.18199803752285, 87.82641026281541, 78.49177329770981, 91.17227831194478, 75.48970099418395, 61.41309107503584, 67.94744599250056, 36.71230223871047, 40.20561218261719, 16.36897836962054, 24.150815663799165, 38.93490152974283, 30.43177370102175, 68.99751940081197, 81.7076147756269, 58.3517635253168, 43.378166383312596, 36.66506905709544, 57.67904958417339, 79.30126420913204, 54.069774766122144, 32.334746891452426, 31.921117267301007, 39.264772861234604, 71.0081498853622, 94.18691788950275, 27.957677918095744, 27.23172760778858, 25.301535129547123, 33.19706232317033, 33.528016228829664, 47.33948176906955, 54.04075707158735, 76.06322996077999, 67.37517218435964, 98.85681336925876, 89.25835778636318, 88.17573655036189, 82.43539487161945, 85.20263487292875, 94.79013919830324, 98.46673365562194, 86.24998615634057, 58.25589687593522, 22.587419709851666, 2.125026165477691, 0.6643126532435418, 0.18873248639847004, 0.32943472266197205, 0.16039550694967472, 0.3537813033307753, 0.13782790501511868, 0.27609805726716596, 0.13782428908011607, 0.18763422275022154, 0.18033202587356492, 0.16508189660887565, 0.1453024869964969, 0.07109013250878743, 0.13562360958706948, 0.2699423875779875, 0.18659908474693376, 0.13638982008541786, 0.16276369922824446, 0.13114558052151434, 0.1398186764169124, 0.20464149724331596, 0.18880396240180541, 0.1308844517916441, 0.2959429827188292, 0.19906295223101494, 0.18176913021072266, 0.09370379931023044, 0.10184575112596636, 0.15808271814978894, 0.16349823965180307, 0.12034103649878695, 0.12771457148295257, 0.1321421230151769, 0.19297560226292382, 0.13860824217479076, 0.07177031899411833, 0.12772570274049236, 0.09893793417441268, 0.20600449023467882, 0.2105721209438578, 0.18117087682889355, 0.16388712120392632, 0.255349439178263, 0.30109544494940393, 0.11785627628165869, 0.17050717807104512, 0.1353075983183038, 0.21599404694091892, 0.11005300427636794, 0.21830743328938562, 0.22543972718619534, 0.20150579211692657, 0.20401623160127672, 0.15048999008872818, 0.16040347426408724], [0.10732644372769903, 0.05968237085448158, 0.09963552617738325, 0.0699135976573152, 0.15803966400844438, 0.07615257174737992, 0.12135779605277124, 0.24979418323886013, 0.31592108489524934, 0.1311320054434961, 0.12603683126789908, 0.1611060075341694, 0.30965494532738963, 0.16277368901477707, 0.1796520309102151, 0.19038447839838846, 0.03494392855152969, 0.04369282118615605, 0.14733645043546154, 0.07530698687919686, 0.03975550463843731, 0.05331797284945365, 0.05067413447484855, 0.0822290126234293, 0.033964021657142913, 0.025868084912578908, 0.06736236399099713, 0.05190331871891695, 0.019811870672950344, 0.06223645436787798, 0.0470600227615045, 0.046638739520623806, 0.06664696044378704, 0.03051450393433052, 0.019651541876937115, 0.04646288403760522, 0.06813064292674104, 0.060867018577071934, 0.05887842286498316, 0.05312486506638028, 0.04628293764507098, 0.049623644069558194, 0.03857142765135054, 0.012058028575753974, 0.07932211497738477, 0.043128857899817734, 0.006193276945381396, 0.01792443878648262, 0.041183362294348984, 0.030152920010169188, 0.0918753006525578, 0.04110822056029593, 0.023708596052001082, 0.10208193603302203, 0.008998824031873336, 0.04468493569161623, 0.12873713798340292, 0.02943942210667076, 0.07443772989415354, 0.13280252144942362, 0.04714786623334212, 0.32339169854117983, 0.09240355658074541, 0.466159874753606, 0.2812914898799312, 4.351523557016927, 20.660355321822628, 29.191530058460852, 39.4705835465462, 68.64003458330708, 81.78799982993834, 82.65585560952464, 78.98326981452205, 77.76047091330253, 80.25949924222886, 81.97211588582685, 79.72408002422702, 71.04937399587324, 70.4509222892023, 61.69761980733564, 57.19382493726669, 59.4292543011327, 61.30636338264712, 61.81723248574042, 69.57472755062965, 48.037640125520774, 43.545981068764966, 50.66323157279722, 30.8100764982162, 66.08903484959757, 78.95049448936217, 56.9570000710026, 52.28248011681342, 30.529448563052764, 19.88681293302967, 36.02490686601208, 52.08689505054105, 52.226429447051025, 38.33312365316576, 50.71061772684897, 42.10619272724275, 63.899846307693, 61.52763212880781, 71.20492735216695, 72.94530653184461, 72.18879115196967, 75.61889602291969, 75.47208955211025, 72.86904781095444, 73.10712783567368, 73.08344456457323, 75.05070147975799, 77.22127053045458, 83.28326225280762, 70.3473638719128, 41.19998401211154, 12.216003229541164, 2.817596615322175, 0.04552380196870335, 0.24459889669331814, 0.032183686947269786, 0.1899586407647979, 0.023716119035417517, 0.11244635488237105, 0.029666369908579418, 0.14888243118841804, 0.031164148409340172, 0.045862481779148506, 0.0967129850159249, 0.12150315357552421, 0.06185316142716235, 0.06069808852888885, 0.04144357171871009, 0.04677424898311015, 0.0477518767659222, 0.03212645826410623, 0.018067930885139975, 0.06848574766228277, 0.08289252903552786, 0.08626123214320791, 0.07265009436636202, 0.08558707476984109, 0.006941116655305509, 0.04164101172899527, 0.015355065115727486, 0.02439190243040362, 0.009750358200812293, 0.04280094162470872, 0.0681724636665275, 0.009619144576361344, 0.09283238961811989, 0.09745540082334511, 0.03667955820058142, 0.07431989024964071, 0.08208147175009213, 0.05584115237598458, 0.04397671038825666, 0.043692089572188356, 0.039310043662666314, 0.04097445777827694, 0.06533255274858206, 0.06148035623013012, 0.0403863818745219, 0.014935544834682539, 0.11419130399102166, 0.1510843057786265, 0.10237668836188894, 0.11627694772135828, 0.09733605198562147, 0.055558002448730895, 0.11756856430081591, 0.0634740004616399, 0.08878713128187003, 0.0032498764067572816, 0.20315974530193115, 0.17659625939784512, 0.054082406023817683, 0.11220958774849293, 0.16977858248977892, 0.004417601486502757, 0.093896723232202, 0.056063586004799416, 0.11824332688364292, 0.23349379339525778, 0.3400072876003481, 0.048071864031014905, 0.11245309645610471, 0.05297037577556987, 0.13874636782753852, 0.039605550588138645, 0.08199959993362427, 0.08757082114536917, 0.026512870474928812, 0.12205864392942, 0.1919577472032078, 0.06917804599769654, 0.06720923833669194, 0.06944305113246364, 0.018776405167074937, 0.009200539770385912, 0.01888933227277331, 0.07930630292262762, 0.029721796369901108, 0.027306708019046534, 0.07276367456201585, 0.07677619030038196, 0.05785678716136083, 0.050510505755101485, 0.036993995158662724, 0.07267758160108521, 0.033458782840640314, 0.029947393941843224, 0.05428800870093608, 0.04095523280181712, 0.0985308273905708, 0.013448548063846126, 0.009194679197765166, 0.05764254684289617, 0.034395585797967455, 0.01315273566081399, 0.059022455055627136, 0.035343554486790975, 0.022998442122292136, 0.016384864443792932, 0.05520437626288303, 0.04753809610021211, 0.035819777723161444, 0.053602306382550355, 0.07319487481107635, 0.06644904162854919, 0.06698046916074331, 0.1064085937856186, 0.11531302525151162, 0.15923960284600336, 0.04569453615394812, 0.10223322307630893, 0.03708825461686619, 0.31797441503693985, 0.07439559505831811, 0.24035591872469073, 0.3320977362173219, 8.850839080349092, 35.75252571413594, 50.66825220661779, 62.74930923215805, 91.24838013802805, 95.58339934195243, 98.75490234744166, 91.82044998292001, 82.75844912375175, 74.58247246280794, 67.96319038637223, 58.19546099632018, 46.64530854071341, 46.1757694521258, 38.20195174986316, 26.33325380663718, 23.10018135655311, 16.535892871118364, 15.745405843180997, 19.12473955462056, 20.33473583959764, 25.290866282678422, 23.79996749662584, 45.36258366800124, 67.63083227219121, 48.34718181240944, 30.74076037253103, 30.017834209626724, 31.489880123446067, 35.37764910728701, 28.608312837539184, 23.930337275228194, 23.54067921638489, 27.318472785334436, 50.375121716530096, 66.63909235308248, 20.208202139023815, 19.570028589617824, 28.296037258640414, 29.565324091142227, 28.43398701760077, 37.74310111999512, 46.896563806841456, 55.207226814762244, 65.42076495385939, 72.48033308213758, 84.7683657369306, 89.6621108824207, 99.30735249673167, 94.93868720146918, 66.26612986287763, 28.695693439052953, 8.673992156982422, 0.5588134594501988, 0.24362689965674955, 0.25862981234827354, 0.10391579730616463, 0.028421092072441697, 0.0058561877249890286, 0.04083841971512284, 0.06818181760008298, 0.017637460334827344, 0.05704137849651518, 0.06759329353489223, 0.037836852753835346, 0.07187257641025128, 0.026008244528765642, 0.012578504881070507, 0.0036492358870624055, 0.040782108422248595, 0.05300478461468893, 0.06502509102105133, 0.055344704418413104, 0.12117532157008687, 0.11376183510067002, 0.02767931594843826, 0.02767234646354712, 0.05390538608715419, 0.07482678764649937, 0.03311586656397389, 0.012562621005570457, 0.06031109921393856, 0.05221598218345354, 0.024872842853167848, 0.039709252080008875, 0.01728608261703724, 0.04823250500785728, 0.05254552639540165, 0.0634241932552428, 0.012599680508907526, 0.08296285590697682, 0.02128455404853148, 0.039382695610965454, 0.0625776890815506, 0.04688833862723363, 0.08746445749796207, 0.06744478739077045, 0.0666166003793478, 0.04788091278544838, 0.06759091866232696, 0.15289530698810855, 0.008735060917153474, 0.09366645252392178, 0.10607966627444952, 0.09882051587825823, 0.10199204327598696, 0.08276699020737603, 0.018744001563097683, 0.011629331518986053, 0.11877909813436771, 0.14959058754386442, 0.23021155097071203, 0.23711800214744386, 0.3490195765851006, 0.10941987857222558, 0.2965871400890812, 0.25288646650170127, 0.1657718966805166, 0.34306986197348566, 0.4417178701729544, 0.2236335829741532, 0.256385435200026, 0.17299025289473996, 0.19888154261054533, 0.15424780457490875, 0.22648862412860318, 0.2412008064528627, 0.22514832266155752, 0.15784336163872675, 0.2606211506551312, 0.17094715768771787, 0.19653550559474578, 0.13993432504996178, 0.12346607768127035, 0.14985471933839783, 0.14251722113019036, 0.2402988604960903, 0.12185991306098239, 0.15917808598568364, 0.12473364676078483, 0.15761853015470892, 0.14773693055875842, 0.1334655245826129, 0.16897610538909513, 0.1356343501397679, 0.14298942240495838, 0.18647977421360631, 0.09455834740712758, 0.1384769347045691, 0.22975595848214245, 0.11207266485378628, 0.12833183150618307, 0.1787438183542221, 0.2180117846376473, 0.09403422069285186, 0.254247467664461, 0.1321522200540189, 0.21441869437694552, 0.2878877520561218, 0.11137402331035946, 0.20050662960256302, 0.19889645068155182, 0.13187409949398812, 0.19944668567228704, 0.21022393398227232, 0.13093429347199778, 0.12827542445231832, 0.24884063359950823, 0.2472588918622463, 0.21393300995471018, 0.21092173282898244, 0.11502208804050762, 0.6418726509136539, 0.1230054826385552, 0.36336589063848224, 0.3023734634682056, 8.968029695172465, 34.35711506874331, 51.42540693283082, 71.69299571744858, 104.58496432150565, 117.75502035694738, 117.7797705127347, 114.3591970013034, 101.47866679776101, 104.57673518888413, 100.59040684853831, 94.35049641516902, 85.06081765697849, 94.41573327587497, 75.1875529750701, 91.2369111276442, 89.01578272542646, 101.57616123076409, 96.40125274658205, 113.99295745357391, 82.85621812266689, 67.17192280677058, 80.73334509326567, 51.24152621915264, 83.65436553955078, 110.11756158644154, 80.57442634336411, 83.23801379049979, 51.988635755354366, 34.87875892269996, 52.77848343695364, 78.30808085779991, 79.64546788123347, 62.21690239444856, 91.13210539663993, 79.39170622056531, 96.57123258036953, 93.90088296705677, 103.88672751765098, 102.66421887182422, 101.8103345747917, 102.21994769188666, 95.27827816624796, 100.23132170400312, 95.6971323874689, 91.97170442150485, 96.31513318707867, 98.10184340323173, 109.81839456865865, 102.12610106314384, 69.20619733871953, 28.30825544172718, 5.83113621319494, 0.3698637258381613, 0.5810077620610115, 0.22357922137504627, 0.4298866534185025, 0.09968470902212205, 0.24644455572049467, 0.08420844592394368, 0.34207131232946153, 0.1084830679540192, 0.14089613311713742, 0.1529889382542141, 0.1981392646989515, 0.24695098580371952, 0.11810276507129593, 0.13544129598284924, 0.14922809005985338, 0.15085159891074704, 0.13477037150052287, 0.18152142334128582, 0.24186878915755983, 0.27419681090020365, 0.3016712672768101, 0.19651149639919882, 0.18421987612401286, 0.12449717074031792, 0.15901304000327665, 0.11646160555462684, 0.12458746952395286, 0.19142310976261095, 0.1372085382500964, 0.21200194744573486, 0.15363315691150006, 0.19438190986552548, 0.1384148509391854, 0.18756846176280131, 0.1345275829155599, 0.1412477368308652, 0.1289186854996989, 0.2067051848937427, 0.257951058447361, 0.07929528657827647, 0.11610080878580771, 0.16269534886364015, 0.17870185205773, 0.10837203883115323, 0.2582789134354361, 0.16580401108630244, 0.2758007232219942, 0.21061603310367755, 0.2223662590427745, 0.27648244954405293, 0.15126013827900733, 0.19252361038759833, 0.27254374637719125, 0.25222761556506157, 0.09950791125095661, 0.3335747230918177, 0.38694313517020595], [0.08101888481647739, 0.03946855108463957, 0.039131234910699635, 0.1221868793870653, 0.045646747589231505, 0.09948990052385677, 0.12363753581960356, 0.18916840574914412, 0.24506726752846475, 0.17504632563119935, 0.16103082366528051, 0.31087566046945514, 0.18538161781766724, 0.195293799643555, 0.21803554868505848, 0.1815921332566969, 0.18557090282199845, 0.18571440641197468, 0.1381302645970737, 0.13782313994822964, 0.05044033210123739, 0.021191650565953988, 0.04812894907269267, 0.039713323837326425, 0.04918670965238445, 0.07194642728615193, 0.01676064397719118, 0.0884153105078205, 0.05293033619020736, 0.12473785258348911, 0.029574157820353587, 0.05335442331289092, 0.09178568368717548, 0.13103048347177046, 0.042466521263122566, 0.05161684780051151, 0.03974633456598367, 0.032507784274076267, 0.06103148616309609, 0.0140584105505578, 0.07379554903074619, 0.04620648590066741, 0.03756246304199581, 0.14314617931602464, 0.049413651708633675, 0.02723969064743048, 0.024539763145449183, 0.05162842338904739, 0.02583241968926403, 0.05190319997528869, 0.026286583423854846, 0.06832745857536793, 0.03846323305380441, 0.11224791512734468, 0.028972148692475694, 0.11245541770251528, 0.10137813105698555, 0.02451366827552838, 0.04978276436187087, 0.17979941090508816, 0.0885195597525566, 0.22138748978895528, 0.04742250109331743, 0.07399973444520466, 0.18238632128604, 0.4495114052007276, 0.05650638865547315, 0.03358517202638811, 0.3024695308939103, 2.426444623739489, 11.591502081963325, 17.67369204951871, 19.95322258241715, 41.15755181158743, 60.74374644987045, 66.49384698560162, 76.12827070297735, 83.5340036884431, 87.80518239544284, 81.63862028429585, 88.68321280325614, 87.80515886122181, 83.41101384931996, 80.93983434861707, 79.60493410787275, 78.79363890617125, 81.13569398080149, 71.39080062989267, 70.07743420139437, 62.991954895757864, 68.27466580175584, 74.88356928671561, 76.12143008939682, 87.72732334752237, 91.59546282983597, 89.73691832634711, 79.33617330366566, 74.16464590257215, 72.23334927712718, 66.06345315133372, 57.91723159051711, 67.30176110421458, 70.88715261028659, 72.423231217169, 76.78114921815934, 78.85753431627828, 85.6716012954712, 90.05139827728273, 77.01916648495582, 72.43429230105492, 53.64973598910917, 23.975552397389567, 18.02144938899625, 11.206333175782236, 3.1122913956642155, 0.5759102742998832, 0.3537966863762948, 0.31889804128196936, 0.06249706981883896, 0.08345154339387532, 0.0387344281789997, 0.10929700573005023, 0.024913581493761272, 0.1570858538991982, 0.04833290849121348, 0.12756449485858604, 0.02915520157154289, 0.06349653493793261, 0.0935863656923175, 0.08082548591999278, 0.015652495879499663, 0.021398436848915393, 0.03160441339376473, 0.06806269092785736, 0.04767569698273175, 0.022084895679126346, 0.03948262795024822, 0.039791909136599114, 0.01739304189780547, 0.06258848709084334, 0.015683533931751887, 0.045410903591302135, 0.09628088844399299, 0.04700218695366094, 0.025045756558557192, 0.0457935223746444, 0.03731914585636508, 0.06809612300487296, 0.01609950626809751, 0.03736983789431472, 0.10026237762142574, 0.03482007128637164, 0.0862109767753751, 0.03390584877061267, 0.045332318292029446, 0.04245491503106971, 0.01819541366139968, 0.03440316240753859, 0.043008103290753025, 0.04283681752220277, 0.05165894433195072, 0.05082500783065635, 0.04964301460272363, 0.05067986481252217, 0.039397270433724894, 0.06892562768752537, 0.047960164581215194, 0.11497200121201816, 0.08510659208461162, 0.07990971207618713, 0.023324738121441296, 0.017738139609836282, 0.04447818388261142, 0.023914556875224077, 0.04514060861941788, 0.04498370998208562, 0.07266117199774712, 0.040800597954301104, 0.03518872045641465, 0.052835965649254864, 0.02150940276952761, 0.09430411346857587, 0.1330929760250353, 0.2947228498035862, 0.19051364082242214, 0.09110184296244576, 0.08123292978252135, 0.20907141598722628, 0.1735024592809139, 0.18593369141942073, 0.1792238030823008, 0.10243256681508596, 0.12422783720877864, 0.1376499734338253, 0.05901941368656774, 0.040154498551161065, 0.021384461489956708, 0.09050580357471782, 0.013659006780794552, 0.01580547406187942, 0.014116937752753017, 0.025921960045853933, 0.04566168630375497, 0.11824928704769382, 0.03353627646462091, 0.09147230776086931, 0.06003487472152037, 0.06525595161703325, 0.05289094777958048, 0.06538714417406628, 0.17542624395460854, 0.03870212608167241, 0.054505937732756145, 0.0185979986112685, 0.02768688106669053, 0.07537941283155834, 0.06566680457082487, 0.10135433636605741, 0.062033843264103904, 0.02782994990176972, 0.02901053735836139, 0.05218154270081751, 0.019228391296740983, 0.06460647759658676, 0.03167820489785123, 0.012426939173301142, 0.10859002915000725, 0.011033515254366062, 0.027208012911761482, 0.056989112147881146, 0.04975758688223939, 0.06326079436187303, 0.048364310435229735, 0.04199405951846031, 0.020613499331257997, 0.29208101091846345, 0.04061694752665297, 0.1986036671986503, 0.019884827141199383, 0.10595092519877419, 0.15483934702652116, 0.49452437208064143, 0.04715325566188944, 0.031169350146346038, 1.1641879043271466, 6.924755284863134, 22.066066111287764, 34.3731261837867, 42.704036466536984, 67.97000746573171, 85.45208192640736, 90.56125933124174, 102.15438135208623, 98.72889703319919, 98.61223789953418, 90.93456699002175, 84.03069342336347, 75.69221296618062, 67.48808153213994, 60.03823364934614, 58.34703706925916, 53.89561760810114, 45.930891959897934, 50.7889513815603, 48.23102866449664, 60.003316710072184, 68.85794578060028, 52.2196319795424, 50.52105742116129, 34.68661769743889, 33.60616160977271, 45.247662144322554, 49.673974514007575, 41.37225843244984, 47.25845736842002, 54.4269379492729, 51.95200081794493, 54.732176796082534, 66.4039933296942, 71.06832688854587, 77.50019811814832, 83.90529524895453, 92.8277930905742, 102.07156442826795, 95.17556698091569, 92.48962986853816, 80.16770009071597, 54.566550793186316, 41.324899734989295, 28.52620586272209, 8.844845698725793, 1.6063763057031941, 0.5672067800356496, 0.3828852287223263, 0.09038632450204703, 0.1182978570220932, 0.0419917842373252, 0.02320740601017831, 0.014460245691870731, 0.07035160076714332, 0.020833249737118042, 0.051634755105741566, 0.02338205107427653, 0.08389717673942929, 0.0660085027676917, 0.06514936580412811, 0.018281767092224573, 0.039515309261098024, 0.053406639865809874, 0.08646915606673687, 0.058764551555918115, 0.014651892162228545, 0.04851054129821639, 0.06373056713792105, 0.045644744269309506, 0.018008438412160162, 0.03574361326172948, 0.021703646277948734, 0.04357903414676267, 0.03886986486313324, 0.10228362400084735, 0.09160314025657793, 0.0632734960996576, 0.09157542319547746, 0.06950439179256078, 0.02505484810699859, 0.10799849435927407, 0.032695521780800436, 0.038733144981726524, 0.03526776157800229, 0.024574078138797514, 0.06804554588011197, 0.046731803881665396, 0.011168792017645413, 0.01406852099593849, 0.02289113427151836, 0.050947669998652516, 0.02448919942722686, 0.04178494432820909, 0.008192253148844166, 0.0644329893252542, 0.06672939916531886, 0.050896594916740735, 0.04770118089753294, 0.0438834008790793, 0.02634429091197108, 0.01946418549895527, 0.11696448098988303, 0.06485041531343615, 0.02243685370851909, 0.076670209696937, 0.03160340024248487, 0.18464972805832663, 0.15911227903298794, 0.12155795950562724, 0.19820000014958844, 0.22107437433254337, 0.18200891573102246, 0.16570114079983006, 0.3714575257993514, 0.362937065261987, 0.15589421945473841, 0.22977809842315414, 0.21907073265362173, 0.1851540130953635, 0.2292492985725403, 0.18591397231624973, 0.16376508339758844, 0.31317211627479524, 0.1957418538269497, 0.20373150736333864, 0.1732134909158753, 0.19540831446647647, 0.15724095606034802, 0.16410351039901858, 0.12873854758518358, 0.13861691429009362, 0.12380461959588913, 0.14525526533684424, 0.13370814462823252, 0.17225113126539415, 0.19348362580903117, 0.1720247369620108, 0.1977384934622434, 0.13446824174494515, 0.18462323673790504, 0.18355999862955463, 0.14041417188221408, 0.13982572442581578, 0.07514243885394066, 0.1019682102806626, 0.13098868571462172, 0.1430329361990575, 0.23152243466146533, 0.24291762481293372, 0.118871427051002, 0.13726354336305974, 0.16390273407582315, 0.08483947254717351, 0.1613447205313752, 0.11538391902802453, 0.15782779473210537, 0.27123955829489615, 0.13201227111201133, 0.15500345838166055, 0.24183226208533012, 0.1789896712908822, 0.1997515427008752, 0.14877861095291955, 0.1914506276408511, 0.2202664426858387, 0.346374336269594, 0.18297760326775814, 0.33998433560613667, 0.11761135031138698, 0.18523618368612182, 0.2664732656651928, 0.5400740908038232, 0.15434949508597776, 0.11099810396591503, 0.6552785767182228, 4.431291818618774, 16.27576618425308, 30.77361022272418, 43.378723359877064, 74.84596944624379, 93.8970547337686, 106.44514053098618, 123.40128006473665, 114.78668828164379, 126.35626039197369, 118.59940467342254, 117.94305878300821, 108.4692325899678, 108.42375663018997, 108.40118731221845, 106.48354053497316, 99.50851517338907, 101.87884269222137, 93.5571107556743, 93.67916707069644, 82.17674593771659, 90.11774909111762, 100.59656496970885, 105.40378262919765, 113.44806178923577, 115.20373036784511, 124.83768340080016, 119.27657050471153, 108.62027522056334, 109.73521678678452, 85.10331261542537, 80.09452435278124, 104.509537143092, 102.72168943958899, 101.0633348649548, 103.95676535944786, 108.08916276501073, 106.57450029926916, 115.49431523969098, 102.4191491834579, 98.76253527979698, 82.31511931265555, 55.143809933816236, 38.995835550369755, 23.116341521663053, 5.342265723213073, 0.8858453013723897, 0.7931137902121391, 0.36832848563790327, 0.15821355064549755, 0.14339069925969647, 0.13837112264046747, 0.37085069223277034, 0.21117823438779001, 0.30011341216102727, 0.19776100112545877, 0.1914744836188132, 0.20353892818093303, 0.23763616869766868, 0.2039234277101294, 0.19438564837459596, 0.07556282960238957, 0.1551668496141511, 0.11396858690967483, 0.11585673317313196, 0.20300651239531659, 0.0807411932656842, 0.23288676064581643, 0.14732433092449942, 0.13659618885046051, 0.1363824196760693, 0.2824806728430333, 0.09524750478205182, 0.1325100903669673, 0.15836569570725964, 0.12719242893640073, 0.25232414264352093, 0.12326190758857036, 0.2147433471174971, 0.1502917265339244, 0.09107250179494582, 0.1639623050728152, 0.09679312547368389, 0.17972712284855305, 0.08459384177601145, 0.11951654203115933, 0.21767272944411925, 0.190535627545849, 0.17092294930931062, 0.2155463451579694, 0.13966369682983046, 0.1187767002791647, 0.12844327431652816, 0.15690893355396487, 0.15810856595635414, 0.1785419541861742, 0.2706117645627068, 0.22659351688719567, 0.15965466928337851, 0.1969898723426365, 0.10947105324556751, 0.14418821211063093, 0.13432086175007207, 0.13814190913352276, 0.18600604076298977, 0.14640001520033807, 0.11431959307482166], [0.07761037578025172, 0.0037318675669901556, 0.06545214673444148, 0.0606911899071307, 0.052484902027513713, 0.1380457191337501, 0.08895036929677572, 0.14161843145566602, 0.17827117274845802, 0.1461325126189378, 0.27939389009148846, 0.2859410919970082, 0.14721081201587954, 0.12516765855252743, 0.20509718166243648, 0.14973003086784195, 0.045083680625764594, 0.13068087158664582, 0.06469439384677718, 0.01187271765252996, 0.020886577117527207, 0.040070431892790144, 0.04933382151648403, 0.03594246287379534, 0.0056067518908680695, 0.036880338354216474, 0.050901907736495625, 0.028060791345553535, 0.02913539245304081, 0.0469106700902264, 0.0418151933098993, 0.03487420688954092, 0.05489661959150145, 0.05642227220138716, 0.028909492276368604, 0.026416984995106058, 0.014232809508910343, 0.059996800151683634, 0.047251180850810585, 0.044305672373382315, 0.06596010133263565, 0.09520562275523141, 0.07547441539504836, 0.02550377371540714, 0.01055611415781201, 0.03720550820411694, 0.022603835978154695, 0.07868087640212429, 0.010444110188062393, 0.02337153268707616, 0.012127246534932527, 0.012708861444656168, 0.13561325207833322, 0.03041125251911581, 0.056195559971515215, 0.12021611054097453, 0.037957890815432035, 0.038004204660894415, 0.03816918935626745, 0.07068988221186785, 0.08714342069241308, 0.3236464687412785, 0.1495097805896113, 0.03931560546099659, 0.035906157967063694, 0.09522525758873071, 0.03005702303902757, 0.1483270174433147, 0.14133122509285329, 0.06801714700075888, 0.26201726928833996, 0.21039990437847955, 0.08284310104265329, 0.15834067527565265, 2.3005779712430896, 8.57762638599642, 14.125660138745463, 22.61129125472038, 40.06246528317852, 46.63579679304554, 49.278391715018984, 52.422524421445786, 69.34086015147548, 68.20096446621802, 78.39485937549223, 67.69163685460245, 70.60354171260711, 80.03516320259341, 89.16422874696794, 96.49887269543063, 92.06186402228572, 91.05960430637484, 89.13467761008971, 84.73414697954732, 74.70203415040048, 74.59269415947699, 82.22387713770713, 70.02683562617149, 67.48636353400447, 75.82349469584804, 69.26144000022643, 65.5839983109505, 57.83385769013436, 51.37670286240117, 44.07159828370617, 30.995763463358728, 23.235985579029208, 14.886357745816632, 7.560004707305663, 4.001833469636979, 0.07534457115276207, 0.28777997880693407, 0.24045589319880933, 0.5283802182924363, 0.12278484165548317, 0.24925962240705568, 0.18186987077276554, 0.008013350551106758, 0.0457777907591193, 0.1397669348385065, 0.07033051802746712, 0.07632238279667593, 0.12490894299961867, 0.14205554590350197, 0.012776309740729632, 0.06284089390969565, 0.014795914776773464, 0.01668668201854152, 0.043622509636465585, 0.058452079613362594, 0.10321813635528089, 0.03690236721247916, 0.06429422781952927, 0.007733628867314228, 0.0523174160550679, 0.05168162819538867, 0.021492966353112174, 0.05477951156095632, 0.030591223809507587, 0.0884310765973022, 0.11399517016064738, 0.033039073910444014, 0.03390175786109702, 0.06869702705092008, 0.024177669772818208, 0.0925041898904789, 0.09272825528657244, 0.015116043768132166, 0.019710161009683244, 0.07231226491351282, 0.014065413551795629, 0.053530746109543316, 0.030850908463640563, 0.018786722456195185, 0.04171205489265342, 0.02340379456478742, 0.053528141410600756, 0.012463830137294869, 0.08155977353453636, 0.03389864754412444, 0.084722084894536, 0.037066869272459904, 0.01611247805187539, 0.08963011145111054, 0.05366766900424996, 0.030460965879742178, 0.012845597605431273, 0.07049897310113715, 0.032106359947412726, 0.036778310764460795, 0.0339280461682187, 0.07262941765328569, 0.021507018320863287, 0.03214966498255249, 0.05806085383219104, 0.02059263301142041, 0.10544444915027389, 0.02780552701874366, 0.04675959755155829, 0.07295816896423217, 0.03263847504351889, 0.1297766273661006, 0.139892021674783, 0.12144352895237746, 0.20939573164909117, 0.1442175379563724, 0.2073110991548146, 0.3080669982779411, 0.14802508687059726, 0.14399318144686762, 0.27343749519317384, 0.19797651698031735, 0.10224810050379846, 0.07308655763946234, 0.060718129388988025, 0.05233928020442686, 0.07216856980155553, 0.06224991836314721, 0.031412581147085276, 0.04567785075895729, 0.03437779340592604, 0.03206145570373103, 0.07542923919015354, 0.023099201836533124, 0.010879259620372568, 0.03279659176065076, 0.022073184109983907, 0.06131380488495193, 0.056838480109769496, 0.016780951052844044, 0.038038663295728546, 0.06829522159551421, 0.010441764043794285, 0.0941910082474351, 0.05248701643018473, 0.04264816454040908, 0.03863999635101326, 0.02443260659704045, 0.08887345406917796, 0.0900450170100216, 0.053880595481924476, 0.06273636121242758, 0.05106430688512422, 0.09650535986668642, 0.04252533000262995, 0.06629163354274727, 0.028735636282832395, 0.06852658014864692, 0.05855208473099817, 0.018453271195833242, 0.07931317473130842, 0.08657832359594685, 0.06354188734305001, 0.08230395900506167, 0.03710716166683743, 0.02636037492794135, 0.14103784406137082, 0.20877207479169294, 0.06517557367201775, 0.06770439160567138, 0.08077183678265541, 0.1448060007345292, 0.04950970764301958, 0.13133454376891737, 0.08555832349004285, 0.120596511499776, 0.2994324212833759, 0.05751064182409356, 0.2717889352671562, 0.7154496350596029, 5.638853292311392, 18.462953336777225, 25.533088330299627, 42.533307460046586, 60.70080041885377, 68.51385193486368, 74.65967255253946, 83.29935181525447, 93.18239104363226, 94.17698644822644, 98.54770706545924, 97.48941236926665, 98.29826785672097, 98.4402027437764, 104.69715195317423, 107.6191294577814, 102.51203090913835, 94.26422780559909, 92.19433030774518, 96.04768245450913, 94.86668817458614, 88.42912950823384, 92.0721955453196, 89.22736321726154, 89.38525430617794, 101.54516666166245, 97.02933403753467, 89.56903303823164, 89.82055894790157, 83.01465834340742, 73.97093572924214, 56.86763671136672, 51.29531760369578, 36.39626510681645, 19.597442034752138, 11.742375070048917, 1.204293036172467, 0.5599962992052878, 0.3731995790956482, 0.3979649340673801, 0.23191139282238102, 0.23247791484238642, 0.1652723307450933, 0.029747513941519206, 0.08952665127693646, 0.23965002998950022, 0.050327862733073776, 0.02744225770114891, 0.09403552304232314, 0.08383392085952145, 0.09036725657361169, 0.09581989503555721, 0.05048500651854181, 0.033340265208314505, 0.05434056616298134, 0.05152673670841802, 0.07379561031778013, 0.05202765095858805, 0.025489495751718362, 0.06333508573833012, 0.020472920281932722, 0.054548857808713956, 0.07927100925195603, 0.12223765569468661, 0.07947982183747715, 0.014505524361025424, 0.05168203422198853, 0.0495455950318325, 0.009248446121120886, 0.033733724135785334, 0.06984362318631142, 0.007665823382746069, 0.037897147703915834, 0.05608160056233887, 0.024871052122644843, 0.023586067949391665, 0.036764394777316245, 0.01965974859382597, 0.1154044961496707, 0.03953307867050171, 0.015128501315390872, 0.05009815126897828, 0.036739462445820534, 0.053418728733255025, 0.03697947013161836, 0.025347359628686984, 0.02542180613794875, 0.14721989781866152, 0.013508943562966683, 0.022478620822150863, 0.005585058674877209, 0.05023732646218231, 0.05581856427353717, 0.11687631193067759, 0.07083704770212212, 0.0083536209516047, 0.11879183051566924, 0.1063212214578544, 0.04583735792567173, 0.050266012624506994, 0.0415778937449138, 0.014532284769830445, 0.30735113507797646, 0.21825434339623298, 0.16454229491852945, 0.13742356380868342, 0.1769088079491931, 0.295423605749684, 0.18128238858715182, 0.19286971359002977, 0.25253313142926465, 0.22959734763829942, 0.3584321311885311, 0.29415793656822176, 0.21839599305343246, 0.20931644154892814, 0.34947880033043127, 0.30942190138082354, 0.25727034336136234, 0.28457138807542864, 0.15538078732788563, 0.12283017107796286, 0.17490714277711608, 0.1350244828650067, 0.17180122314922272, 0.11571732049267139, 0.10852694947032199, 0.07808648410343355, 0.17492156055185104, 0.12204635587911453, 0.12599622860791224, 0.19419250228712637, 0.16162840288973626, 0.17639670881532854, 0.21442581899464133, 0.15593882109369003, 0.11723779817862857, 0.23226397712865185, 0.11069444203448874, 0.26564717773468266, 0.15983456204975807, 0.1151266590421719, 0.1887309235791045, 0.21463064026207695, 0.17614515618451182, 0.14690849839919998, 0.0754813484907631, 0.18827811965057928, 0.16479344918362557, 0.25647949547536913, 0.05638066596621948, 0.1052243137852319, 0.11438940666736135, 0.12504717590467584, 0.15085098604040761, 0.12943798586005165, 0.1448673337337471, 0.18032448756839, 0.22272815897820458, 0.1956257915064212, 0.14346240508940913, 0.16409430202216874, 0.22961616275771973, 0.35018283513284504, 0.21049911276467387, 0.2867396007622442, 0.21081716182731816, 0.13633948810879262, 0.14549978528051608, 0.3002147196281341, 0.176439349269194, 0.3148398590424369, 0.47999223574034633, 0.2950782226699014, 0.20427164531523184, 0.2928724103877622, 3.2874352749316924, 12.887142339060384, 19.64233748374447, 35.26585763500583, 50.70927235387987, 62.27118799763342, 69.18684436428931, 78.14317657101539, 92.9974042215655, 94.76504387394075, 107.66958682767807, 105.5969201364825, 110.23643293688374, 116.50567485440163, 121.44121677644792, 133.75619611432475, 126.6106104081677, 118.37918712246804, 115.03839462034165, 118.49755640952819, 114.90264923341813, 106.23489364500969, 115.14418878862935, 110.82856962757727, 108.68943445144161, 124.67024526288434, 116.57850542376119, 102.01206991749426, 94.23575139814808, 84.78030543173514, 71.42595291137695, 53.394546585698286, 42.8843556680987, 27.122528822191303, 13.466967690375544, 6.891505352912411, 0.5293056525049672, 0.5945274978876114, 0.43480742001725786, 0.7200015456445756, 0.27017858780680165, 0.36738356214857876, 0.3087402669893157, 0.08839103318150006, 0.15246007711656634, 0.3390366235567678, 0.17660108575176808, 0.24188653175388616, 0.2204599871390289, 0.2760463616540355, 0.20013107798032223, 0.2025858228725772, 0.13481422237330867, 0.1136084872808668, 0.17476950742063985, 0.2363875832769179, 0.21765530860472113, 0.1406191157237176, 0.16687124817361756, 0.10003914726116966, 0.13821122476891165, 0.14451254309425432, 0.18924312996527842, 0.23134032024010537, 0.1653183419858256, 0.14355905474193636, 0.1598361248691236, 0.11741503261991086, 0.1651116667856132, 0.06510471053902181, 0.19337113345822982, 0.13080258763605548, 0.17886895115577406, 0.13206913015775143, 0.1355816432905774, 0.1590018091543067, 0.13388639796645413, 0.1555282898968266, 0.2443236259803657, 0.15728348926190408, 0.12171482366900291, 0.13443491692023893, 0.17537203557308645, 0.17015738232481867, 0.15953762637030694, 0.09872611086334913, 0.1953694125216815, 0.32288699981666386, 0.2486539073288441, 0.1682614219645339, 0.2096270902022239, 0.1626971261876245, 0.11989805381745101, 0.25761348946440604, 0.1673033830499457, 0.11097776433152538, 0.26323295889362214, 0.21401378626544632, 0.16560544109632894, 0.1865020520504444, 0.15142014340287255, 0.16347386273405246], [0.07916577175379762, 0.07441427228191207, 0.07735908361932925, 0.05359428161154351, 0.029078889638185505, 0.0037368672483059913, 0.11661984101538697, 0.11480806605710138, 0.06420745687078565, 0.05936747807408533, 0.057225710742415926, 0.016298457386813337, 0.020120355127859983, 0.04858114396131808, 0.04535602871328593, 0.05754081802743097, 0.08483096131033475, 0.07939130803870578, 0.06390863278460118, 0.01422929220772799, 0.0185237608609661, 0.12096413411200048, 0.09172402893102939, 0.05514174474463348, 0.0654982882101209, 0.07229456828246195, 0.013244026528310873, 0.021988724831551797, 0.04937781411553583, 0.04541845721823554, 0.017344738138959776, 0.02144485411624755, 0.003909870729623964, 0.05927817903519158, 0.10591930875013914, 0.06953076819979376, 0.047239114966003165, 0.05865270271897317, 0.1053576513884529, 0.0651691921596085, 0.07176610551053478, 0.07134743079903626, 0.033038813440549764, 0.008495186339132488, 0.0799041732604946, 0.03925577399411029, 0.015244062805938867, 0.027822181770217516, 0.09686081700267331, 0.025112978858692993, 0.057327998802065856, 0.01856256895999034, 0.07693316171606703, 0.037439142038384755, 0.06252918422462479, 0.039872742903929566, 0.043026987358086535, 0.07456337597461478, 0.10447267427920334, 0.05704933431960883, 0.028072635064862912, 0.055780060694462834, 0.05446832664611359, 0.10433203585806394, 0.03780954171933475, 0.03660075456625031, 0.015751259934697903, 0.15290935704063985, 0.12227160871149072, 0.1454109803683335, 0.05384250559032925, 0.08026277901785028, 0.13275500867635975, 0.013097540941089393, 0.1258520278779249, 0.17427450736924527, 0.3060892350491016, 0.23483107647588178, 0.20586285589923783, 0.06040440872311593, 0.17553896613178716, 0.23716743014031844, 0.7708221025043919, 0.9924186117226078, 4.462896806578483, 2.8676105122412405, 5.054992802681462, 7.972622850248891, 6.620907408575858, 12.563855686495382, 18.015791370022683, 24.803919715266076, 22.007683592457926, 25.677590408632835, 19.94392852629385, 14.929070395808067, 15.705810496884009, 9.485617818370942, 5.141915957773886, 7.417297113326288, 6.507840675692405, 3.101095970599882, 0.50628884725513, 0.09084589298694365, 0.13924078565211068, 0.054139226765161565, 0.348511231282065, 0.25460910712999685, 0.3295798197148308, 0.13996800227511313, 0.05093747719881996, 0.06417402862420966, 0.04372560591887563, 0.0912288833229292, 0.08997719524608505, 0.040296056277809605, 0.12561682356341233, 0.08411985551637989, 0.028474932731760126, 0.09255704995725425, 0.062261903808722575, 0.12402266354089785, 0.08430302713907535, 0.05064539085592955, 0.056630893264927214, 0.01706131050483354, 0.029409211429376757, 0.041063837256402745, 0.038558212634656704, 0.03679969610886709, 0.020951549034385432, 0.06379888685900839, 0.041343260165904804, 0.1253590656204089, 0.07497045211493969, 0.03246459989778457, 0.022478325878300016, 0.007969736686772517, 0.04140751579055383, 0.04305270492970463, 0.02949735750594447, 0.07805472975897212, 0.046118136810799765, 0.05748820310879139, 0.06346191159419476, 0.0393128513749088, 0.06779516536381937, 0.04817135203930159, 0.10766936000436546, 0.07197394516439208, 0.030793342701790315, 0.04027467859428256, 0.005181313580608056, 0.07522988012961804, 0.052345914525851134, 0.03654490292613064, 0.0081823619961318, 0.060109296332924604, 0.06471297147894098, 0.06791520368067488, 0.04531670158969299, 0.037506519471325224, 0.08469944699637352, 0.014667096134695797, 0.034689866982760935, 0.047495061111065655, 0.09590781128574764, 0.04039135378515048, 0.01722292824377937, 0.04026112266846242, 0.02453478357394136, 0.026313701021154563, 0.0745846962015475, 0.0660184389280696, 0.051097984110275586, 0.05275207136066691, 0.030687764294505603, 0.015482622585559805, 0.06269709537586858, 0.031267939916541504, 0.02126235090526602, 0.06448407972892446, 0.10641599419496714, 0.09663175671331345, 0.10339612156272897, 0.10978928616931362, 0.0673212863564972, 0.19482233381319433, 0.17787115227791572, 0.03228942240257898, 0.06686011674783884, 0.1264195458122319, 0.03901565905600306, 0.09979711710325173, 0.05087579946003614, 0.03186943385029032, 0.017838598634566993, 0.028694752085533355, 0.08411695204314687, 0.049405619276747595, 0.05544024707388975, 0.03315651901967583, 0.047761368595304034, 0.04858030892548062, 0.10241549071525374, 0.05085208137790042, 0.028540025307466427, 0.02079940205740352, 0.057583381872503996, 0.05092906555341137, 0.05923948776457579, 0.004147246663999414, 0.009551869607680749, 0.011550892734028881, 0.006842801240347927, 0.027080407561433893, 0.028419462220382788, 0.06430976408263368, 0.04112070013258246, 0.04446227989730336, 0.05265720286256364, 0.054595236771649895, 0.023278364904164787, 0.023054322490708965, 0.09018042305063817, 0.031699320196264216, 0.043736545654434356, 0.0069599346475555535, 0.017654812226312298, 0.038059466413312384, 0.06732753763395934, 0.03838065643644622, 0.036104498130659905, 0.018005799239261017, 0.04672081435039159, 0.04540028178223199, 0.02286245385485311, 0.11277106890995657, 0.05075486098986961, 0.08313543253367947, 0.09877769922417018, 0.06452421507527752, 0.06826283139807564, 0.05121882681945159, 0.09807831457545681, 0.06897097243176353, 0.045404947257690856, 0.03476424645932932, 0.017727921912146193, 0.03349070572444508, 0.11658197328928979, 0.14644942787145415, 0.15829938313653394, 0.24895632819783306, 0.7105871217866099, 0.5918037795251416, 1.061369098963276, 1.2730101423878826, 3.439736741204416, 5.227298601981133, 11.957198381423952, 10.059908705372965, 15.759533239949135, 23.06583708332431, 21.492031158939486, 31.72934082246596, 39.69758679789882, 47.990661897966945, 46.78066561298986, 47.576659648649155, 40.34723720242901, 35.77227092558338, 37.846384971372544, 26.970489909571988, 21.543088651472523, 21.248854014181322, 18.001004034473052, 12.121583934753174, 3.8884774619533173, 2.6287690574123017, 0.6031535866279757, 0.11753488707566455, 0.5402005259548465, 0.11308431460131561, 0.18153178085002208, 0.10148054935158261, 0.016507702812011686, 0.22752636683083352, 0.16751405722912283, 0.06968575544775495, 0.11427024935161877, 0.07449062826532511, 0.1822563161652896, 0.09558547979160663, 0.05230607412334892, 0.03144357897972148, 0.061262948138098565, 0.10140092983361214, 0.051847367487367124, 0.022735779301353523, 0.03865802239987158, 0.1641734389047469, 0.013180341639165438, 0.058871110555745905, 0.039957131319228685, 0.0784379958866104, 0.014675295190705408, 0.01722112985237712, 0.07413937695204251, 0.010084166649668928, 0.0890857600156338, 0.08810453161957764, 0.06628568103957562, 0.012524396090978577, 0.024066316977804227, 0.0480464299119288, 0.03884210566719694, 0.06148923135873291, 0.053927652432673404, 0.10767780229329102, 0.03447779086268237, 0.012444953730840598, 0.0066817748255186505, 0.047506403042784626, 0.06328843098374144, 0.03375957577279018, 0.07232292119653956, 0.003914699956376647, 0.04589300272205184, 0.025247752876772035, 0.023914359607583573, 0.04551645901594912, 0.01880739342361208, 0.009115544230406804, 0.039488243374733195, 0.0557647351055376, 0.015000712103961457, 0.015525288894892702, 0.11506424585898077, 0.05584772157993528, 0.07359863379068914, 0.01892770944734014, 0.033800580628937295, 0.041255347746154, 0.023905607053048672, 0.032174114678655906, 0.040774110464319106, 0.03606255098636593, 0.11371546379861333, 0.09909727280178379, 0.03220141805227726, 0.029328299138034065, 0.11832801024279288, 0.17560904785510034, 0.19839785001691312, 0.1964251736118909, 0.18114148969611815, 0.2568804199296621, 0.2604083314297661, 0.24987338140847223, 0.2169456047516677, 0.16476427655546896, 0.2128044858334526, 0.2064956751682105, 0.22802864471750878, 0.20378825915676935, 0.11859701435652473, 0.24946983693347824, 0.14054100539895797, 0.16126311684568084, 0.10753750095083829, 0.12772849130053676, 0.08886557102443711, 0.22889982458324204, 0.14639374860111745, 0.1841641815319177, 0.17303949702651272, 0.12079686647461307, 0.09510741794421788, 0.11779555615278021, 0.23041148459719074, 0.12307394791634814, 0.13604048399194596, 0.18849184285969506, 0.1573684177691898, 0.2063022992543636, 0.23056903823969827, 0.16407904155071706, 0.107577214948833, 0.16838600318278038, 0.13655376290121388, 0.12625323578474984, 0.12377577638553998, 0.1643285563876552, 0.09911258689939015, 0.08327075430462438, 0.20541521540332228, 0.15516243694770723, 0.0790097579480179, 0.14875469368792352, 0.18653625021538428, 0.20128980128755494, 0.11243659492221572, 0.11992501245150644, 0.23328333372069945, 0.12381703022026247, 0.22254052872378982, 0.09205094163095759, 0.17053351617388188, 0.1628059106728723, 0.25443990895104024, 0.13107041197438396, 0.12067751763688943, 0.16575669749609886, 0.2018508381180225, 0.2742864125438275, 0.2787241147410485, 0.20275330501458338, 0.15094719136193877, 0.28405853817539833, 0.4168441597252123, 0.16769607971993186, 0.14186445293166947, 0.20673982738967867, 0.20670432687526752, 0.0766036519780755, 0.2942430029713339, 0.41278043100910805, 0.30570260579547576, 0.3475424671365369, 0.4726688335499456, 0.176690626108358, 0.36510889388380513, 0.3587951955776061, 1.0576228677265107, 1.7735973649447965, 5.491301080872936, 5.428924118318866, 9.992598872030936, 15.559478632865416, 13.527185878446026, 20.023605592789192, 26.86729038915327, 36.00934290116833, 35.78278680001536, 35.068562415338334, 31.58716078727476, 28.232255597268384, 27.402184009552006, 19.523585765592514, 15.3691779798077, 13.360221366728506, 10.411362878737911, 5.981405646570268, 1.5397316818275761, 0.8641268925801401, 0.2245194410845157, 0.18742322681411622, 0.7044597667071127, 0.5927431871814113, 0.5960273754692847, 0.3028155268440324, 0.17072857748116219, 0.748962304524837, 0.41692698915158555, 0.36594543125360246, 0.23621384985744956, 0.15305063897563567, 0.2250026740253933, 0.19394635823705506, 0.180238256711633, 0.34480875898753444, 0.19038455500718088, 0.3159029745767194, 0.16209951631965178, 0.19865090418006146, 0.12871600927845125, 0.30732514937558486, 0.13127557032050627, 0.25031844784896223, 0.11583570405961045, 0.13189631604379223, 0.1057168853379065, 0.1371068477390274, 0.160423407871877, 0.19141076042527155, 0.19046433540361543, 0.16755925641665537, 0.26308504263720206, 0.16014493491140105, 0.08750755760458209, 0.12606244924808704, 0.10300514859057243, 0.290033012748726, 0.16552057387607713, 0.14174144985454698, 0.20498249830017168, 0.12183063318051639, 0.12597206619478044, 0.13977891645364224, 0.1914617052722362, 0.12735637175219675, 0.11782432275433695, 0.12348753580402945, 0.12162536758208468, 0.14283994332917277, 0.3217152836582353, 0.15398666052328003, 0.0628499031036852, 0.1353514645128481, 0.16544670767841801, 0.14144521897598622, 0.12480392766695832, 0.11692068374325192, 0.23324481481986664, 0.13522536644051153, 0.15092102179844535, 0.11597413614752794, 0.14015197062924986, 0.15868296336022117, 0.10259367510556214, 0.1913736358044609, 0.15019080211077968, 0.1475561644521452, 0.24910675722264478, 0.1572503636200582, 0.16564317858747898, 0.2499073957123103], [0.06174217443913222, 0.04541625854589286, 0.08783757296060363, 0.015546740314382461, 0.07497387652796123, 0.023727506932411945, 0.04753220105363477, 0.04040300215203916, 0.029464245270637256, 0.062116718655752565, 0.10429297303480488, 0.030761075078419624, 0.08530799659990496, 0.038367288202167525, 0.07359311029675507, 0.04533115383838454, 0.028719023666194374, 0.07014557674166656, 0.03143672249279916, 0.05213248243014659, 0.06838297696724054, 0.05126299561872598, 0.03983595919224524, 0.042411569776313926, 0.06351324714600079, 0.07625728064487058, 0.04321294754082638, 0.009797374931945196, 0.0779653272982086, 0.01750222474877392, 0.027661571436892116, 0.08590362230015379, 0.054161332232216676, 0.013407335406349552, 0.02516328785268049, 0.039935064156569784, 0.015329721011972476, 0.06366107530230958, 0.04379750710100897, 0.06820202699952549, 0.026252666796227137, 0.08415755470313373, 0.012739229169974645, 0.009162174087137947, 0.0419164203377741, 0.018618437837088303, 0.04857888017150183, 0.006390424884645449, 0.06306605864196055, 0.06303474096761597, 0.047465218155975306, 0.058113621968415484, 0.06288120162583168, 0.03893243509434885, 0.03070387320833341, 0.08031408392613934, 0.011748443827063087, 0.011421877781920617, 0.012790118475564787, 0.04853483777673495, 0.056618268135935075, 0.09472880963115923, 0.007164770757944714, 0.036403057916510495, 0.10804799896094108, 0.04146636283445743, 0.050537655911137985, 0.07289095240975581, 0.056904344519059506, 0.01622412004508078, 0.050101453107931924, 0.08675541248052351, 0.1832282672365827, 0.09101533631403601, 0.05587072720030143, 0.09175949114104433, 0.1120548073442713, 0.04474067624898688, 0.13616028482154494, 0.023834002729985985, 0.06702267294449192, 0.04058263827896407, 0.04991594874750703, 0.14996479085135847, 0.20618862712815886, 0.13812562210425255, 0.20795194702523373, 0.26724490006604507, 0.2839794779016126, 0.45397224325326185, 0.4306664696383861, 0.3345953667115781, 0.6046985714666305, 0.6696984964993693, 0.6411755721895926, 0.4188459168278402, 0.3680804570115382, 0.13098215864550683, 0.17593055963516238, 0.2524431773851956, 0.20122263069835403, 0.10484061864835602, 0.03062947074912729, 0.059929878541058114, 0.12458294960519961, 0.1326878534089173, 0.035058424222253026, 0.0938346394668183, 0.12830087389316291, 0.011931074400162025, 0.05824689445416293, 0.10235389724614159, 0.07997882086783648, 0.0855789159334475, 0.06448279270121167, 0.08988763190685742, 0.03083337079583397, 0.02518442804895101, 0.05878658807506004, 0.01687620642534908, 0.027748735005696936, 0.026291574486681533, 0.020815210281721046, 0.03859120804155546, 0.07091138121341506, 0.024310936512906226, 0.014064264419909208, 0.0607607391993365, 0.01633989699785748, 0.08207582568209018, 0.05556927543253668, 0.04664346245267699, 0.020542412117544203, 0.03376459364869422, 0.04034744545577034, 0.011302668755243142, 0.03472154088799031, 0.04479753529472698, 0.002460512576714879, 0.0669293021482806, 0.03482475974446824, 0.0702095987094987, 0.04650257888340181, 0.01778308598835382, 0.03970854344867891, 0.0409501996041546, 0.07403062311031165, 0.05875363480299712, 0.022161376151827075, 0.030008499029903647, 0.033113583621959534, 0.04403075789131465, 0.03840075475313971, 0.014801930482198876, 0.039002976470416596, 0.028613623374352054, 0.029419388907450824, 0.060172441130083416, 0.0982268053978201, 0.07637260752099176, 0.03973290121423141, 0.03946776584451718, 0.01357002471077947, 0.025453836274062915, 0.012179089619988396, 0.02124376561222298, 0.002576265589243943, 0.0672022516148225, 0.024850390731327, 0.04479091246462157, 0.030475847137671326, 0.06709195793636384, 0.02387425298952768, 0.02658158856173677, 0.03935875919377131, 0.012623841006819521, 0.023486294573353186, 0.034767617246196154, 0.016821511577995076, 0.026867747299313068, 0.04946576867012247, 0.023315989397346013, 0.04725074801113337, 0.06578626832173717, 0.055509298408944766, 0.022737841993089647, 0.016348881293989478, 0.09452375087646708, 0.045923167434070385, 0.006694169649328556, 0.07221061270684004, 0.020181601942186395, 0.029968499664157152, 0.04112339676207593, 0.02578978115061839, 0.04552973148923728, 0.058775207838944854, 0.06333452266370578, 0.07017602873665672, 0.05196645202475691, 0.03815999630117609, 0.036802779612762314, 0.06239851643781989, 0.023694921382552674, 0.056162602869012666, 0.05794285330921412, 0.02882185181783092, 0.1271292420044061, 0.03817308874380204, 0.008516008608914431, 0.01069286180990598, 0.03514685375135272, 0.04117237276307518, 0.048167816543531035, 0.03923618512588643, 0.07047580660230691, 0.04186878116020272, 0.0524037886380909, 0.05173590935526356, 0.044712993661843004, 0.08198207950279598, 0.08603666112908433, 0.031583972252725113, 0.03944934909081748, 0.015572259660750149, 0.06405813867346415, 0.05185659501641508, 0.015291492266940977, 0.04226714688082857, 0.037739157391291474, 0.049434615704681606, 0.02954360240349366, 0.026162161168852643, 0.056900173170311805, 0.03778269416802833, 0.03274847760856633, 0.04152257070546189, 0.07051608750536557, 0.05054659615721434, 0.017418813095578266, 0.05091020446871558, 0.06195164586026823, 0.030430711152392532, 0.060648587757661465, 0.09061024434143498, 0.03666377678934125, 0.05225434786670151, 0.1760621122535198, 0.032388312862284725, 0.04146117641921005, 0.060689270856880376, 0.08591251658095468, 0.03882194989390912, 0.05590641157581441, 0.14302329881297005, 0.11785539528054577, 0.13371813441476516, 0.11293164093888576, 0.0700735108506295, 0.21848850583116855, 0.20585426039272742, 0.30483159446908586, 0.1118073226403325, 0.24859645073452305, 0.4815739927993667, 0.17451675969266123, 0.2556283717914935, 0.6953418495193605, 0.38838880437035717, 0.8353138967387138, 1.1933692352425669, 0.7410581770443148, 0.5335108623389275, 0.22339378213209493, 0.43351181211971473, 0.15790821864239632, 0.10162316427956666, 0.15777433711674907, 0.18008834862660977, 0.11029400021558809, 0.1423359953708226, 0.13780365067143596, 0.07871347344330243, 0.17865643836557868, 0.046246996630103364, 0.027067897345630393, 0.00995609207048772, 0.09376616652814612, 0.08852665372673543, 0.029154695953512867, 0.040887418698759816, 0.11077116574010543, 0.07325731097690522, 0.031497906104871826, 0.08817281303626877, 0.04779001262279288, 0.013355694376983711, 0.06739270107279863, 0.014834378136231776, 0.025785944965337555, 0.03745588872040953, 0.08047031223653786, 0.062428650506321466, 0.07954196688989479, 0.0546188973971913, 0.11499061714857818, 0.019728202380300052, 0.07225844723683211, 0.028144779479912216, 0.058863139410893765, 0.041542151912806496, 0.05198295738908553, 0.03995167677320781, 0.03303285710693848, 0.030116061604912245, 0.03472246019349944, 0.018454408836400798, 0.011397622480627992, 0.0419741565541875, 0.011958886264643122, 0.03274570437028043, 0.013771473276128453, 0.051572027826501485, 0.03172781866704745, 0.020326674097187577, 0.10044660644545671, 0.013546652325819577, 0.05747979912426203, 0.04616344708108133, 0.050923633990028215, 0.07127718819725899, 0.030505351098855178, 0.027857404577756123, 0.07530827390690965, 0.1042115608710916, 0.02877624277325888, 0.04539408796136418, 0.08938765994483426, 0.04537628024756428, 0.04436903167515994, 0.01498606354523931, 0.02463153664833836, 0.0428094758441852, 0.010639880126672647, 0.03692628830791481, 0.050770650061989026, 0.04300535303510485, 0.02654222504896743, 0.018986115990687284, 0.016756892061582016, 0.07971067477257983, 0.0377931397768759, 0.22937423219123196, 0.1715715806330404, 0.22237834791021965, 0.10228698712683494, 0.15837452104014738, 0.09425248680335861, 0.15196178288709733, 0.10650691350982075, 0.16279975132596108, 0.09763772208844462, 0.16849898582985326, 0.11833221606549718, 0.18831890617166797, 0.14433893224885389, 0.23011712297316522, 0.15746857610441026, 0.11714332421580631, 0.20749548119643044, 0.1306800288899291, 0.13985964679910293, 0.19635034214344718, 0.19189863585897032, 0.14909385613376094, 0.22274384845889386, 0.13677318580448627, 0.16544923576856815, 0.14948050070914531, 0.1019993517547846, 0.22178521199572473, 0.12791594535472894, 0.07430544949226803, 0.28456492229334773, 0.1568298119931452, 0.17913938019304507, 0.15870229941943, 0.09842526813548419, 0.13784146477137843, 0.17105909845521375, 0.12509483423444534, 0.15500235521504957, 0.11981281121411633, 0.21630337792298487, 0.15048202277431566, 0.14868968346666905, 0.20761664566253463, 0.18949575511918915, 0.17788003889783738, 0.1177333421524494, 0.13559797628512307, 0.14444062275992287, 0.15617241662356163, 0.0770721300655315, 0.14118614336175306, 0.17216609550579903, 0.15855514925093422, 0.1437284980690287, 0.15697702344867492, 0.12211501267888855, 0.20574051165773025, 0.12278433603745316, 0.14174980021292163, 0.1630929484963417, 0.07340271446493364, 0.11492838016560963, 0.22126329161467093, 0.10500759517233219, 0.08689341555920341, 0.17967412488595133, 0.15193838656188982, 0.14681620012608268, 0.136260841522486, 0.3905942182867758, 0.3488395459228947, 0.1854044319160523, 0.13418808339103577, 0.28895512703926335, 0.1628313754354754, 0.1190089857986858, 0.19307171565390405, 0.2330517146976725, 0.1904165621606573, 0.14944662430113362, 0.1783031186149005, 0.3391501884306631, 0.2741768619706554, 0.3726670560577224, 0.336021056338664, 0.4671184346079827, 0.49867071571850013, 0.3759995998153764, 0.386222338364009, 0.5216478989008935, 0.7533790159129328, 0.8145186545387392, 1.001468622876752, 0.8930923705620151, 0.9382216908758687, 0.2971206743630671, 0.5470456134888434, 0.4105064675452248, 0.26734648332480465, 0.2939398466579376, 0.16180926092690037, 0.1271467471134759, 0.14176648560791247, 0.22215774523154383, 0.2990402455531782, 0.3410396983306254, 0.22700262316051992, 0.07670277609459816, 0.20624424511146164, 0.1707843333602913, 0.2934515728585182, 0.2119380250693329, 0.14685393761723273, 0.20707621659723022, 0.1277303452333135, 0.1438460466001303, 0.2397496214196567, 0.2593801495048308, 0.14107242527027286, 0.324330554614144, 0.11195474093960178, 0.23081731201419908, 0.20184377478736065, 0.17962367033525822, 0.1536160731507886, 0.17272967574817522, 0.24189832950792006, 0.24825998491817908, 0.12614035272910712, 0.1811734968495946, 0.09267328081712609, 0.09383165938479286, 0.2854805199369308, 0.15476122138000306, 0.16625868426936288, 0.19066642939804063, 0.16371761658980002, 0.18857603592257347, 0.12780218895885254, 0.15923090008718355, 0.10177470413186859, 0.19354399353746446, 0.2455761184495303, 0.10567426020579954, 0.1524156899822335, 0.1480373136338688, 0.11667122253246846, 0.2031333918773359, 0.14208042843928262, 0.1904153977070124, 0.14037055083580557, 0.1434887431922459, 0.15432266668686945, 0.07759966587107028, 0.24933250801217174, 0.1523451179626488, 0.18144240903277553, 0.1469789631664753, 0.15500256971966836, 0.15834704912718267, 0.129989140156296, 0.1114189007409638, 0.10082569739390766, 0.0713106049525161, 0.13932867125878412, 0.19898220656379578, 0.15672825937790258, 0.16785403172816002, 0.11433906702985687, 0.1283475286477516, 0.10561979901526244, 0.11808964964603225, 0.13201406375775415, 0.12686408365205412], [0.021200709555658604, 0.05193263307333954, 0.04883944199630811, 0.0625924515958515, 0.05996104299781784, 0.009601145340580373, 0.015101584816171278, 0.03711905518186189, 0.044316129473548745, 0.03396604412926301, 0.01876915414487162, 0.07423029626689612, 0.020965373090979074, 0.042520564935740926, 0.003367533147778182, 0.03343124197976243, 0.023657306465470505, 0.06332318839286605, 0.030358559076463988, 0.04121618533146478, 0.07177044156818621, 0.025948581601222678, 0.04254018827792137, 0.08484937806403445, 0.029728647111163988, 0.005674077134068695, 0.02919329912401736, 0.05983642347517514, 0.021842945960440466, 0.05670701942196297, 0.035250049625192924, 0.02327218640505547, 0.04286862166237928, 0.022489372866168138, 0.05167250791865011, 0.02615339329255925, 0.028380508564652938, 0.09050370449380529, 0.053945303098448825, 0.010551067553610812, 0.032907751118463856, 0.04536620619135999, 0.038146329292606924, 0.028038356460690982, 0.05280544470635153, 0.047598800907332095, 0.03315061631221925, 0.0488561388826178, 0.07987185967184844, 0.029465323539390683, 0.015895664635595056, 0.025714488114200296, 0.054562291160466216, 0.05038700855126785, 0.027516587382002224, 0.01548579993522576, 0.049945799363476616, 0.05700060346674535, 0.014574455994842275, 0.059008887638488126, 0.02092889581446446, 0.05861133780150164, 0.001971457487313948, 0.05451063385173198, 0.07870858580234551, 0.058169301238752184, 0.04642112841529231, 0.020467448498933546, 0.049688129520584504, 0.024562297621741894, 0.023919747120911078, 0.026279489449676008, 0.022036005863018578, 0.030210478111140193, 0.09101149821353537, 0.041666277308738044, 0.03633487226080991, 0.08000367276010015, 0.09704608004540206, 0.1056326769532696, 0.09275064037571992, 0.06010653075551795, 0.017937418231139743, 0.03947969766393785, 0.044003565600442315, 0.03322405350064078, 0.03955627964328855, 0.0322740700005764, 0.031514049492656224, 0.09335967261464366, 0.07597444864410548, 0.04871808600822284, 0.18974715453242103, 0.2359702951845623, 0.12291131511090264, 0.13789604087510418, 0.06649957278803473, 0.031243394459447557, 0.06991762727979692, 0.1205150074055118, 0.06361068969952964, 0.025334663636561845, 0.09409521661338308, 0.027393212752236475, 0.07472493625696629, 0.04826032932126715, 0.033391650555835616, 0.07419697910306916, 0.1226607277508705, 0.024675787802064614, 0.020085400451094877, 0.08414067778616183, 0.043526250688779744, 0.0697660184795818, 0.07143609781539248, 0.0318858434536284, 0.04311990616242251, 0.06047179381693564, 0.021880158681362387, 0.005652369553929256, 0.023957739336295955, 0.020022791915483052, 0.0590104044925782, 0.01678775965927109, 0.06346394172719409, 0.09631799008216589, 0.017464175076794722, 0.041349113077646306, 0.049744655318077535, 0.09641981848906125, 0.06345215546447905, 0.03787663953018285, 0.07492242606296655, 0.02672711270861328, 0.03841320751234889, 0.00968034734063211, 0.04084953565090414, 0.025689255093194308, 0.028060783684674292, 0.02775644951109444, 0.03195030400679717, 0.04389599153411485, 0.06539930965030386, 0.004578336309115853, 0.015844518690550282, 0.03462816626133938, 0.06603605895032806, 0.02254321161026676, 0.03188511758532015, 0.0744423953696124, 0.0741841164868205, 0.02531120602432038, 0.0316840329117352, 0.007345487547647809, 0.059613013084256844, 0.0329828200741641, 0.05883859395379982, 0.06929223140281054, 0.03998938362084089, 0.021495833437168793, 0.03239873165805494, 0.027972329257717057, 0.048490029294043786, 0.022300547514591488, 0.0135483923030176, 0.037515647408943024, 0.018406696880476612, 0.038091684240968, 0.025876033074793317, 0.06440762415408127, 0.08271974556508564, 0.005599576519847277, 0.02467850932941562, 0.016295701385505738, 0.024923776208813635, 0.03803096028164991, 0.05369051757659163, 0.026998886230191397, 0.01965393015604106, 0.04790173505523032, 0.06087518124390514, 0.02308306802484778, 0.007614957538598608, 0.03724278987295205, 0.08582431687823228, 0.04712391449438949, 0.03951996324523803, 0.04856847286705048, 0.02136463704969614, 0.04006377841916777, 0.027570795763524312, 0.05013769672762963, 0.04082444244094434, 0.020711660092215867, 0.0722220044342741, 0.022200375772832383, 0.04023191939678885, 0.01252430894847719, 0.023445054145169356, 0.046814522225289576, 0.008659479640153869, 0.006963481155840019, 0.053197976667433984, 0.019965783482597723, 0.058888144520742286, 0.04269642424919913, 0.04635268995057672, 0.000735270421559577, 0.024373430135329405, 0.03205574834869514, 0.05464708177192558, 0.012277518511719763, 0.040725479202885786, 0.17151807705240865, 0.0631982203002178, 0.04044448198269933, 0.025938494138479717, 0.05265054938894126, 0.038033300680258585, 0.06446430699959879, 0.05444693364082806, 0.04672254570910046, 0.020221990097554463, 0.06383804161281836, 0.027495767027440093, 0.011433172790754226, 0.04638603392748102, 0.04917731741443277, 0.05214120817160414, 0.0648300220528918, 0.07752784512816899, 0.0069726967147641615, 0.028612363159716613, 0.02646670410139186, 0.06103574178151547, 0.04829344730223379, 0.06951719312177551, 0.03189665103902019, 0.09203116124075267, 0.03279700161769025, 0.013728590546956947, 0.028780239837003813, 0.029518503447874423, 0.03209852861360677, 0.02028430943497487, 0.04540213954544837, 0.07819311588161415, 0.067614552474791, 0.050857696802385395, 0.040448082595943444, 0.04843187555971165, 0.1378116945946409, 0.06414619281948095, 0.07357422622942156, 0.05462611394543802, 0.09238327057251046, 0.04134723616223182, 0.1427956328036324, 0.05715652534197416, 0.029380169036167286, 0.018932051250651, 0.08487072893448415, 0.06206466681173733, 0.011219922640931704, 0.11089444460888064, 0.08534015697096625, 0.03887027088973311, 0.09148655699626093, 0.06394085827313604, 0.09727501009981479, 0.16239818335781175, 0.17482602938769326, 0.1483214862885014, 0.06606937611415502, 0.10545564935572686, 0.10197951007754573, 0.0802746840241936, 0.024129952071234587, 0.07146265042284805, 0.11574349005616481, 0.17377676472308176, 0.032257717853832635, 0.060593919723384806, 0.1591981421675413, 0.050953254779620524, 0.02812941558659077, 0.059579439280975255, 0.059695578210296175, 0.10638391809357751, 0.06706977203007668, 0.03095488766238334, 0.0840884305897259, 0.022019483261711655, 0.03164201681952804, 0.03633171597856187, 0.040545927345632546, 0.05287546897307039, 0.044985261310132287, 0.05873496907072202, 0.05632034037262202, 0.0788105980703427, 0.03458538025076832, 0.051615786768736384, 0.030971235978687485, 0.0452495348309317, 0.09120740987841161, 0.05190240707428706, 0.05576308418606078, 0.05010790356825437, 0.041981081989023, 0.07083405229833818, 0.015026431590799364, 0.09414589332957422, 0.07684463259553717, 0.06614198592761833, 0.027579854753228928, 0.052885355337733225, 0.017825829864089048, 0.03808551340273792, 0.02504370344292012, 0.022518828946856723, 0.06341237634901079, 0.03925535264575193, 0.028048196860078364, 0.010727330020839169, 0.027551216471399513, 0.06054225092333171, 0.01272611661754068, 0.023744910534831788, 0.017612441818440155, 0.01073872557871284, 0.024754871058488087, 0.049282282951378056, 0.026044629874729344, 0.07528431067663817, 0.01573926299780367, 0.011080762769486155, 0.05336905176180506, 0.054478136401984005, 0.10522360898434155, 0.05569641155401065, 0.03988027737866487, 0.013839690532955914, 0.04966900413555484, 0.0359887728888181, 0.052248606037709026, 0.018867611764900146, 0.029021990372829383, 0.01960520504883701, 0.03409131099620173, 0.08511438319880156, 0.031612756091260144, 0.10813811388347419, 0.08120366522381384, 0.19981860603776672, 0.11756179974444451, 0.1208848363509582, 0.1317952230813042, 0.09981334284548798, 0.13448520293158872, 0.1929500455697698, 0.08626353040698075, 0.11980014011984873, 0.19833205838597592, 0.09051613043993713, 0.187491056238932, 0.14620037268727057, 0.22977753151809016, 0.09090363303379667, 0.1443746779114008, 0.13263149998120724, 0.07888065681101815, 0.14993485213527757, 0.16502131437582357, 0.1134110817445382, 0.13110608102813845, 0.11274334418797687, 0.06868513736633525, 0.10766953620458804, 0.16410240723240763, 0.11377340302832666, 0.1838197330794027, 0.15866946489099534, 0.1263789048478488, 0.11081410496826134, 0.12262318944258076, 0.15591891812941722, 0.08421100465761078, 0.16332159509822247, 0.3142437507067958, 0.21515435328887356, 0.26138472581102007, 0.14019252732396126, 0.1480377119995894, 0.13039326685811245, 0.11358302251826372, 0.16681501731997536, 0.21572338807727062, 0.11254328032655102, 0.18611582116253916, 0.15712455666113287, 0.16082626286773913, 0.14518251762755457, 0.10328351429873898, 0.17402912940709822, 0.12735333038313737, 0.10899273092828451, 0.11946681526399429, 0.05073961584017642, 0.13895688878913082, 0.15186838144736906, 0.16613062501194018, 0.06931686879045541, 0.21929918007264215, 0.2235973010500593, 0.1439878647966731, 0.15851466916501522, 0.20204560831189158, 0.11693570672744706, 0.1994689788308836, 0.24628015325194408, 0.07777091716566394, 0.23304325708698845, 0.20353590979451136, 0.1870797589541443, 0.17758898677364474, 0.1684526221886758, 0.2816372406819175, 0.24966016381738648, 0.24122195047957284, 0.1632478974399067, 0.15877325448297686, 0.17495847066804288, 0.19346346237486411, 0.21558399071856854, 0.12486172900084527, 0.11318736874888982, 0.18530476387710343, 0.1879083290095291, 0.23942385019073564, 0.2145173818233513, 0.2292323680294137, 0.1659717383764444, 0.1474501991704587, 0.3192117083216867, 0.4475559810957601, 0.3151645577482639, 0.5404889427365795, 0.2872003566834235, 0.20371017947552666, 0.16644262197998264, 0.29490560773880253, 0.16256425589803727, 0.19094720062228943, 0.17008794411536188, 0.22729914515249192, 0.3263686242843828, 0.1843898710344107, 0.3577037960771592, 0.2770760757548194, 0.28724338018125106, 0.21559918990298627, 0.11298142899308475, 0.3078494599509624, 0.19329564315417122, 0.30118366763476406, 0.1599878409216481, 0.1444879976371604, 0.13364033052517524, 0.11179407698012168, 0.07843313122829122, 0.18653321650720414, 0.09849296732535286, 0.13643434511557703, 0.13870545873238196, 0.14880715538897824, 0.15390784539763006, 0.18863937607215298, 0.09597268361117571, 0.104037566981729, 0.15061745179756997, 0.19137495347569067, 0.16063117091694187, 0.12487305944124538, 0.21255305577670375, 0.12650633591317362, 0.22739283770563143, 0.10746773332357408, 0.17624214291572574, 0.15856420441019922, 0.13540944204695765, 0.0725102220331469, 0.13121851209190585, 0.07573909877288727, 0.14511389147129752, 0.1193686870617732, 0.1375458467631571, 0.21134171755083148, 0.17240041115831944, 0.13206422719503605, 0.09935440255268928, 0.128112607785771, 0.15943460286624972, 0.10413928813631497, 0.14267515781666004, 0.05876332581523926, 0.12613747989939106, 0.07809898665835781, 0.165773045812403, 0.19969172655574738, 0.195327369616397, 0.14201609237540153, 0.15507553193357684, 0.1088550802500498, 0.15486343283086054, 0.13759355871908127, 0.19254907515020142, 0.16855227490586622, 0.15655084873639769, 0.11429727693358738, 0.19737207360806006, 0.23570116849676256, 0.19211261953798034, 0.07272443553853421, 0.1712159779403479, 0.08644880111058874, 0.1177845091649121, 0.09711847535424656], [0.09973455836335499, 0.01610945200457448, 0.05399983323689911, 0.05578219041889233, 0.09727648864950865, 0.025709238496699163, 0.03359436125103985, 0.05424776610227362, 0.07388296732378584, 0.05174871068447829, 0.01739197895081053, 0.02253553732448528, 0.02729988600608082, 0.046701643000086474, 0.0339934777378315, 0.022280114034431118, 0.03484095484318753, 0.06696962901661474, 0.03770389436413685, 0.01751740095055392, 0.05053494395988603, 0.025563419405971805, 0.08446426566449866, 0.0441447364526891, 0.025358691984306903, 0.055937583693453384, 0.03084167327371336, 0.04118782475650792, 0.07189184352154694, 0.04311039518084257, 0.027468189777385806, 0.0028122501164269185, 0.03281729911724406, 0.07388338867214418, 0.04013411678193558, 0.033128801958575364, 0.04584504561799188, 0.03880186689897411, 0.07431869515247884, 0.0037526050882954755, 0.09778063579071915, 0.022757241254552238, 0.03551290588333242, 0.06491259100937075, 0.11739643200510934, 0.06806736406419547, 0.021407639480105812, 0.006828890041252899, 0.03351954510435462, 0.03171779632177805, 0.04028756802360858, 0.0740916803178768, 0.057021996472030885, 0.008989924963022913, 0.11128452125816576, 0.14874805936649924, 0.024173975313803362, 0.06498139336585038, 0.0777376919323879, 0.07177832461292706, 0.009592893616025968, 0.062141854000548204, 0.030522467418303414, 0.04283604760383887, 0.03714030263044181, 0.11696553819121853, 0.052894690119090586, 0.14586058204933522, 0.03979089407009944, 0.07334806175241548, 0.007374317351458295, 0.015046192828806178, 0.04777094469435754, 0.04235222477525954, 0.018378409083872553, 0.08217699525337066, 0.0771901076058707, 0.03872972822958424, 0.031630699785666606, 0.13212215876387012, 0.014553087887414282, 0.021111973591389197, 0.005734329470508402, 0.1551030651335755, 0.029448335539669763, 0.04846151167106244, 0.0416859389553147, 0.0991362896597674, 0.16722234626931531, 0.0689333651755606, 0.08839455718595175, 0.07691569491139344, 0.07789225017111148, 0.10556488583285002, 0.07749025319372455, 0.06817664650659408, 0.08439881111224813, 0.05162836593245307, 0.13465616311277115, 0.14401510688326052, 0.06750090333122401, 0.0605573543467589, 0.011879529131786718, 0.05417293846426953, 0.07898115988580451, 0.036437282894527724, 0.07616145070642233, 0.08705963365613453, 0.026831061263839086, 0.1394906375677355, 0.15283973497008124, 0.014597310312843371, 0.07060744349033603, 0.06250382288389149, 0.06352669581951154, 0.028777748136030092, 0.05892551428968868, 0.09890424928838208, 0.07089135567507437, 0.02027772682448549, 0.08416636471426295, 0.10189242120231352, 0.024994985996595314, 0.02134232282368166, 0.037952317525782896, 0.041391075543698766, 0.045662360461128336, 0.00952602275872543, 0.011416978649644843, 0.10578129034970077, 0.013887613163059278, 0.06399441547992249, 0.021362825251755216, 0.03636120653320705, 0.010347735369578004, 0.01823100227592213, 0.03782456087309026, 0.028124187036507556, 0.01453590262005286, 0.008362320837594809, 0.04824110434480733, 0.02370020930445002, 0.054652314152448415, 0.03647903085596139, 0.054715968398076874, 0.020737605574991436, 0.06607635517514522, 0.02084887026989412, 0.01977160700686997, 0.05754805755831542, 0.02043978314876797, 0.019017615610913887, 0.033384131402858806, 0.09475068144139745, 0.022609190932745417, 0.026717973279676614, 0.12532186439080586, 0.03223591882194723, 0.015576586142302522, 0.04587669654058353, 0.047993956719555204, 0.03232393466356782, 0.010959205683320762, 0.05626348132688192, 0.009976283275342036, 0.025047621982652816, 0.018397808345335148, 0.07342090139225607, 0.06855114858837859, 0.05361780434125855, 0.055406569848738374, 0.038155296351760626, 0.061050741783072876, 0.04387219301274708, 0.04845895293739535, 0.031681483754167156, 0.06590795372762988, 0.05312092354400985, 0.06828786715144111, 0.08443870897134466, 0.06436168952214141, 0.011720148369579787, 0.08612151302757763, 0.04352291820630912, 0.05894404212613741, 0.05849743201848, 0.030144092762061668, 0.02389052852747902, 0.042106616986735214, 0.05484066835995163, 0.02812668065270109, 0.02500191143143081, 0.0637980479927313, 0.08848738405973681, 0.015711993140529002, 0.025544311257920442, 0.03264830012114779, 0.058981542130030935, 0.03462829649628651, 0.01586315186408859, 0.0294839222389724, 0.01826236783076198, 0.05022463621571661, 0.01041930043063457, 0.07514051597325072, 0.07865624667535867, 0.056128504295502944, 0.0036625768294587975, 0.013446581133100535, 0.008786632998606131, 0.02068432607507754, 0.03063288558604977, 0.058874688186352296, 0.043179186046003334, 0.04701098547347131, 0.024858878985528025, 0.07316272976177354, 0.01179972000705499, 0.06200052610027695, 0.08216558820417813, 0.04243715328254527, 0.07217028583850592, 0.029866353330773213, 0.024705983157600128, 0.03772767373330651, 0.08950534637176222, 0.0618741101014518, 0.050914145991086006, 0.061685384341305306, 0.02319470810283336, 0.09648514280636465, 0.037820998564242356, 0.01800457541380198, 0.08052711765612326, 0.034017004297986146, 0.05527602080556174, 0.007247790748689084, 0.02909586806180737, 0.05687577326992347, 0.031635340363267934, 0.06381454186574106, 0.04879924153248149, 0.040390829014922344, 0.01985018464526342, 0.04771340766080445, 0.021853144505932447, 0.05843116158259012, 0.10980940363820522, 0.018971868670515476, 0.059664356296942125, 0.046918116464850404, 0.09297065316669403, 0.06010310251205679, 0.05524089567423348, 0.05215657589536521, 0.05514498912699281, 0.06698794617888428, 0.027783231944927288, 0.03752554526492473, 0.1057689103688444, 0.03121363577402888, 0.047722865016229694, 0.086632187237903, 0.046785859045602625, 0.21631341367479295, 0.053633838561513734, 0.04236228734014496, 0.05438504139742544, 0.07974658131359086, 0.05276997100501772, 0.031182777752438863, 0.17917642820506327, 0.08411859147130482, 0.09345139632181776, 0.12242340137280765, 0.09083385774565321, 0.04180129264451323, 0.06929341883909318, 0.036299318120244055, 0.16362727950176886, 0.07572753850610987, 0.03292468166159045, 0.0611796782111689, 0.040322160723829464, 0.04060350268358185, 0.040085929851498336, 0.11059062945986949, 0.0663739650119697, 0.027315044970882517, 0.05024418294910462, 0.028881733080432303, 0.04225232307949374, 0.08084999307269052, 0.013245103839454393, 0.06411242749421828, 0.06468290252791298, 0.08204896663946491, 0.048050532312763315, 0.07006686120744675, 0.012973687506370969, 0.02886173243994915, 0.02744293951940152, 0.02939430910402969, 0.01200924696956551, 0.02796325877669358, 0.13222665315674198, 0.01920134456257426, 0.023504452772378445, 0.030522130339616732, 0.08260133901550885, 0.030867651315225713, 0.03771695616324583, 0.014588573080066954, 0.011488803222985759, 0.009422989678569138, 0.023485254608995976, 0.05772712678017636, 0.012028414489431007, 0.020456543237331416, 0.009735227006697848, 0.04057669726711127, 0.0684893865799231, 0.01959823747916568, 0.081189913945573, 0.013636649462334333, 0.028072945330472245, 0.010842711480724956, 0.016056993176349472, 0.0007907572123053064, 0.06524507316850847, 0.0639764124137019, 0.016164152597587918, 0.10669889514364543, 0.07899923956081753, 0.014801910372390864, 0.04609575172165229, 0.012974615430369252, 0.07065556913373933, 0.06852561487786232, 0.06690075005134268, 0.06262288060820391, 0.023325412278814663, 0.021127015727782444, 0.08574166365208165, 0.03763416887170846, 0.031221758221246065, 0.030948785772066445, 0.045116856063325564, 0.009151811790352148, 0.0784634989536097, 0.05529216993900557, 0.0259168176806622, 0.16023626791373377, 0.09581283936577459, 0.2011573906507223, 0.18383327751390396, 0.19203092392173507, 0.13789168949569428, 0.20056854482860337, 0.11419750930320834, 0.22925532002362514, 0.1076033462079302, 0.1308197173620424, 0.15001003600416646, 0.1351087218931606, 0.09733439723570501, 0.08906009607017042, 0.09812893766549327, 0.21016197279095652, 0.28244990675199416, 0.10829900766933158, 0.11568956512717471, 0.1288175312501769, 0.06803515772785872, 0.12226642229624334, 0.1883423024968755, 0.12326609042863693, 0.09217102591308857, 0.08393581821433, 0.11266017768291697, 0.13938281835327226, 0.14787678757021505, 0.1276633355225767, 0.08787707245397954, 0.11060714631551698, 0.23091063684513494, 0.11284483551618554, 0.170554660200592, 0.1246717008912275, 0.09945407059163817, 0.14389650115082342, 0.14626737473712814, 0.24236791076198702, 0.13526774642448272, 0.15627629814609406, 0.19226615887976464, 0.1479515883951418, 0.2347618527710438, 0.1525970383156692, 0.12793623902384313, 0.13862308895876332, 0.19427975970170192, 0.194039560493923, 0.10198818985372783, 0.16803453736487897, 0.14590535222763015, 0.27366444107986265, 0.19404285467199742, 0.15346389744550953, 0.28770306357933634, 0.13701280278544273, 0.19242051027474866, 0.09101228728409737, 0.17800273553979012, 0.1092357033743493, 0.08232622152014125, 0.2613690056868138, 0.14966623106550786, 0.17562521231030265, 0.1598353587811993, 0.16550185068720774, 0.1301973934976324, 0.13535993744529065, 0.15789778452486763, 0.18602163831312812, 0.09849975486436198, 0.10954662781929779, 0.20020869800881033, 0.1639981886311885, 0.20217693110387172, 0.12778420887526967, 0.36158286695999486, 0.17701149437456362, 0.1539397606205556, 0.11042535365108522, 0.4232823013538315, 0.14300911086461238, 0.20341004154855208, 0.15369844292440724, 0.16386006297844072, 0.3464115374991971, 0.17479380772959802, 0.1662494299272376, 0.22742574884285852, 0.25564275892271154, 0.23577151068997002, 0.36884954800048186, 0.40814777475691616, 0.20195927020282517, 0.3126722898694777, 0.3242591245760841, 0.25606648215363104, 0.14473035721288574, 0.3382649585123985, 0.14694018379574822, 0.2629078618220745, 0.16188354081203862, 0.14195668991775284, 0.2716531844869737, 0.25337080260918987, 0.10565310851821016, 0.23893473369459953, 0.31608355682223077, 0.17119008416850723, 0.18737284887221553, 0.18246587185609728, 0.16443498132209625, 0.12419186171985443, 0.2482618694944728, 0.1840251059301438, 0.14873901952899274, 0.14894060790538788, 0.33919134267395545, 0.1956380335914512, 0.12396870030751153, 0.11620701921562995, 0.06665801509253441, 0.30665151294200654, 0.11991722133731651, 0.14077441706772775, 0.06892183555230018, 0.22611322572394726, 0.0727043180696426, 0.0931845372542739, 0.09515524481333072, 0.20443613971433333, 0.10777207707325298, 0.14795918798735067, 0.10408366249213297, 0.12971834339682134, 0.08375970226141714, 0.13289989122459966, 0.135420780148237, 0.05664502758713019, 0.1342941865685486, 0.09164126079169013, 0.18270953378129393, 0.14844681827291367, 0.1651507372697515, 0.13987614833299192, 0.16167660514193197, 0.16187604847213916, 0.08856036925628301, 0.13382756241386937, 0.13544492723961032, 0.18070740895646234, 0.10823985802069788, 0.11941079125409165, 0.32692881841813365, 0.14858197150451524, 0.12638973733109812, 0.11544561974944607, 0.11828862566260562, 0.09620762745579405, 0.1467122573165163, 0.15614001110436457, 0.17369053386632474, 0.19584371287736202, 0.13351490661021204, 0.16944551810381875, 0.13736379362883108, 0.13497056559689585, 0.19164380437183767, 0.17179500251527757, 0.1713385213647158, 0.2556463901794726, 0.12594250286178243, 0.08878499389656129], [0.03870049048395407, 0.009321512714509041, 0.030688677854355306, 0.010168913211072645, 0.018081452337003524, 0.019997666146786466, 0.06520592607557774, 0.022606773925344312, 0.024559907427418138, 0.09548807937291362, 0.07013945569915157, 0.040728692941728144, 0.007048663429750671, 0.03857296365763872, 0.032118883569754904, 0.050896127603106925, 0.04107317969863934, 0.01594225235749036, 0.027665535941900268, 0.016352851544657064, 0.01711282417208197, 0.010487301267623421, 0.039316842692994305, 0.05385239578543171, 0.015706619033740175, 0.039078891953273166, 0.027960757499620802, 0.06145942670803878, 0.0730311771434161, 0.03298877257733576, 0.08028021517900691, 0.14162520367291667, 0.06902115885168314, 0.03649670450437454, 0.030375495365250017, 0.029882406703226512, 0.06189373344363225, 0.06223471151785024, 0.03019265890602143, 0.05531942734735147, 0.0512434373940191, 0.030162275858944466, 0.02024834352214971, 0.024457341660895658, 0.016273017522067796, 0.014788117916924099, 0.04727451588898417, 0.03395875097222386, 0.02789181533209499, 0.07003537499375882, 0.02416293024115505, 0.020486223398737853, 0.03888765342473503, 0.07249941253253529, 0.07425959912999984, 0.05248632312061326, 0.021391833171008096, 0.04676435878800769, 0.07414846275482448, 0.05325816436520508, 0.050234775389394457, 0.021646678064679428, 0.045878351290499976, 0.0537588794325148, 0.014795527902371703, 0.061711883322606166, 0.036748969596960855, 0.03888512533458491, 0.004039788468470497, 0.038568608447789185, 0.014055289699876261, 0.032565593268842466, 0.010081959358837095, 0.058072659247104204, 0.05074082625909679, 0.06018539184644338, 0.05036849986701723, 0.1629237962826606, 0.034503768904194716, 0.03714203398915068, 0.06379895197648196, 0.0821429962712911, 0.04949894793812306, 0.029282850971926126, 0.03421833603492668, 0.038409089789755886, 0.04100653387966656, 0.08299421954659686, 0.023192919287530166, 0.1585377130897776, 0.04190179571929959, 0.05435484604188993, 0.07290912401531974, 0.0589028419175696, 0.010643173347137148, 0.17211833758459938, 0.06576995064895, 0.029281730568336866, 0.010523506582924917, 0.05218656057672155, 0.01583263475162488, 0.03922211592115703, 0.016701664783120636, 0.038420374264880534, 0.059564581005683834, 0.02969566319558409, 0.04087845930048535, 0.05291543961051972, 0.02698922011580679, 0.02515822592672081, 0.08208583079038129, 0.04577366920608667, 0.06424280799805157, 0.09612428475051157, 0.05075959541324166, 0.039520767637558525, 0.056252997413638144, 0.028061341013639208, 0.030967240830162363, 0.0030869024527829985, 0.05474347478499817, 0.08287092535606316, 0.07211856724273774, 0.024694995541546135, 0.03540317144905848, 0.004977038629623431, 0.02669829822656128, 0.02270056990035359, 0.033026448781451875, 0.0658669373801639, 0.06994204250194373, 0.05584378388800448, 0.03225787107141749, 0.02768214855853829, 0.0552352610975504, 0.02368554446635948, 0.06360850634894545, 0.03287841761184316, 0.07196200185365255, 0.08170750592985461, 0.0227675604588923, 0.028442232268712217, 0.023774897131407936, 0.04355653031398693, 0.030596590255417173, 0.05101165749252804, 0.0327237023250951, 0.02019852099399413, 0.018071343806842645, 0.11361475388008742, 0.0670234926585709, 0.0378272881461007, 0.08460773861095791, 0.04274779427496176, 0.023239794292397076, 0.07861625688571124, 0.037680597630359476, 0.05089246570282886, 0.031075715049800855, 0.02783464410552575, 0.06297362630345649, 0.04883216033058782, 0.03574313445677681, 0.033970724926480365, 0.04126347593903061, 0.004476413577644816, 0.025867876153619542, 0.047435302422532154, 0.03590253820162147, 0.011581814915482557, 0.06112629337416542, 0.017743368159919497, 0.037696394363358136, 0.06645261925915558, 0.019905511515154954, 0.023082437917530056, 0.02805542298442414, 0.016922794147244385, 0.05197397500817334, 0.041802257915297826, 0.08401680902968492, 0.05058651316850897, 0.05937081055655595, 0.05990719467762017, 0.03699803244202368, 0.0806215686363078, 0.11712304586845061, 0.025206556498643853, 0.019601370778775985, 0.02255257703514109, 0.07294536763501745, 0.023108986694546, 0.04830584260484865, 0.014342389767989518, 0.029063521914424437, 0.016351078051112352, 0.03315423224722186, 0.05707703988939043, 0.04741434608736346, 0.047500033021694234, 0.06425657076761127, 0.063030167422708, 0.02592217838091235, 0.038214453661273566, 0.03536095234355138, 0.015109224627996165, 0.026519374561405955, 0.10876327227320402, 0.017667073463540406, 0.016804067755959207, 0.023518631144637064, 0.012472598013588259, 0.00306490519564719, 0.036522927694022655, 0.05535538368407757, 0.009027836739175744, 0.0353181625025407, 0.03414078878479139, 0.04193733453810696, 0.04840103285988012, 0.05936114252695154, 0.03735130239698676, 0.047749249084341916, 0.04062771489242873, 0.03314528050982664, 0.03320123557181608, 0.016648774072828314, 0.027920813675248818, 0.05511887318965408, 0.02017459032245942, 0.025150392677695043, 0.03162946829932832, 0.027121998474843083, 0.017823885915981188, 0.041861062824365594, 0.07564184391089986, 0.03573355069684406, 0.08874796120630157, 0.029537358786910776, 0.034240119745053595, 0.04634969454679278, 0.04806499222233411, 0.025766599330029664, 0.02247877787017534, 0.06150502426129195, 0.036001976414193074, 0.02988391015077791, 0.015430876219104377, 0.05798335637777083, 0.01638248191034842, 0.038537853848068945, 0.048592405453805006, 0.06186327761820248, 0.042487339702464884, 0.03244762721982214, 0.047061980116151036, 0.019758037674511154, 0.045434227138156855, 0.045230263889196425, 0.05373238045121393, 0.05918697243736637, 0.06774943757561908, 0.04324448738066901, 0.11051713864529326, 0.03850836329342377, 0.13387351236756773, 0.08829466698150482, 0.08906566552937993, 0.021244336347726565, 0.006155244031575539, 0.04408622648747217, 0.07937726564705372, 0.10194683642757517, 0.08142441345919525, 0.05025295465583763, 0.040730378335161556, 0.033046796076720765, 0.021056064494675206, 0.08884096428030923, 0.032579026620594725, 0.04921795454837623, 0.028179962067834796, 0.05517290920139321, 0.008976973289053046, 0.020315539009208163, 0.046900251294456186, 0.021902503550893838, 0.09189202435194485, 0.07733233182901338, 0.04349978235099585, 0.08672532054685778, 0.052196952559414415, 0.0585718497994446, 0.030932303390375553, 0.06991041073155019, 0.007368410334757139, 0.04989733664138664, 0.0045437713795822236, 0.0404754204435214, 0.0645686328531273, 0.028311317418551737, 0.03836936430044232, 0.041406883768016295, 0.02212541598466135, 0.07768405811680902, 0.0624326303330881, 0.03237376485260264, 0.008667996622652056, 0.07773110357623908, 0.0385531832674338, 0.051419871273420514, 0.04434694536030293, 0.0842178994489293, 0.03124510666595832, 0.05564331783041839, 0.08016665796599082, 0.029559288053743304, 0.07791396110288559, 0.01650585845533398, 0.04741579399354035, 0.041762949943903, 0.013663225052427622, 0.0804450466567951, 0.02043500276012046, 0.05345726678628595, 0.061101966252129894, 0.0903279026369414, 0.06470657464477324, 0.039878009758408994, 0.05001858154672289, 0.040154375977093176, 0.06511483056050155, 0.058086571403809135, 0.0218899684372328, 0.05050454942149021, 0.020428247779848117, 0.0006580643199530671, 0.059089365174933794, 0.030988997727211927, 0.01723907354678358, 0.07416953017274219, 0.11417930705412743, 0.0628073430890518, 0.044911490873463696, 0.025478736046821843, 0.01347492925912863, 0.07887556232632169, 0.03117036712806552, 0.06647829852637745, 0.061582962216268626, 0.021611206278565432, 0.06809524200376003, 0.143575954641546, 0.0943196190881633, 0.1818080474772761, 0.1126440208885939, 0.11478644705587819, 0.15008639964845874, 0.10274383599960035, 0.16183690137920842, 0.15174678797202726, 0.1436718688496659, 0.209762733730097, 0.07444251794368029, 0.08844904902000582, 0.25697170696671934, 0.2848193554147598, 0.10394368290660844, 0.13776209806242298, 0.10195771487609995, 0.11625506825024083, 0.0991174975229848, 0.07138419535852249, 0.250969760480427, 0.08460234535197098, 0.1761107741584701, 0.19392475455759034, 0.11577244051882338, 0.14139447331188187, 0.13955561714547296, 0.13741941161213383, 0.11731665160867477, 0.11069165347444435, 0.276400447492638, 0.1493819358368074, 0.15522778424764835, 0.11811663126272541, 0.111922565246782, 0.1214368946309532, 0.12835718901647677, 0.1516601127842742, 0.15406075654731644, 0.10403635656280864, 0.162026860540913, 0.14591848297465235, 0.17662762303746518, 0.15091273272710462, 0.07922494438506904, 0.14578823270576616, 0.08285961023742154, 0.14918756400865896, 0.14116139872179878, 0.1054305293326897, 0.0996887999316377, 0.12573530672178154, 0.10691992683155883, 0.19672629213140858, 0.16682561997684742, 0.07216968828992498, 0.11987729283470301, 0.21287049196900862, 0.15513281998855455, 0.13879594903799797, 0.26112560423151143, 0.16057477152395636, 0.21171915374936598, 0.14659360561880375, 0.1695010441565706, 0.14704421853586552, 0.11127062442321932, 0.17224265833295163, 0.1414323486988583, 0.09691652691652698, 0.09435282133880163, 0.15596338187254247, 0.14533997933951118, 0.18481189355013833, 0.2089872842113818, 0.15523587413612874, 0.2673144302060527, 0.17192843970992874, 0.17961096859747366, 0.14517191497068252, 0.1952400509147875, 0.1421789320245866, 0.12882525341645365, 0.12870203583471237, 0.11382567320740032, 0.20249462776607086, 0.2513092293614342, 0.1373912348982788, 0.2576915691456487, 0.17963877758912503, 0.19861541898740878, 0.32819267963209464, 0.18411568816631071, 0.15446652267729083, 0.25575834626872695, 0.21898951201188951, 0.34050294648735757, 0.16914315852186373, 0.1433385899590869, 0.1824532926923806, 0.21025948046195894, 0.11606274187685021, 0.19611250248647508, 0.17032736191345801, 0.09731493860242829, 0.22589358831605605, 0.1295857029336114, 0.25100683913596217, 0.18542015204025855, 0.17808286833666986, 0.4256422811698529, 0.2323317299446752, 0.3059345465754309, 0.19533601108818285, 0.08801091567523057, 0.1328312650683426, 0.09589562282687235, 0.165466963043136, 0.07174269386356877, 0.12419597561200782, 0.16088218728621162, 0.15483764631132926, 0.1685666467153257, 0.14055329344926343, 0.14769006129955092, 0.16123648762943285, 0.11088561927599293, 0.09330118180162485, 0.13680513167092878, 0.15376795774265645, 0.18380988118869646, 0.1231171246317606, 0.11896006342384124, 0.11681841866623972, 0.24893087875698847, 0.13379213850825064, 0.17999068773802251, 0.11850234121084215, 0.2596356551493368, 0.12028618460340847, 0.21033837219640134, 0.1604857980724304, 0.10442659409055788, 0.149494121752439, 0.1422185387702719, 0.12603936701892846, 0.1216523951640533, 0.16004774899732682, 0.18728277225407863, 0.2226520251602896, 0.08818900813498805, 0.1692282708902513, 0.2360938038797148, 0.1287108305240831, 0.22823521266541175, 0.10987026166291007, 0.13280639785432047, 0.11496898282559649, 0.10007062581397834, 0.15866105324558674, 0.22557662709826426, 0.08580487356671403, 0.07356691775062392, 0.1628638269199479, 0.23735054047597995, 0.12665628996347228, 0.19587627161414395, 0.13405870646238327, 0.07130998442129743, 0.15102867247356525, 0.10171425213376362, 0.14760499489643883, 0.21382506816617905, 0.0589471371213515, 0.09564639144246617], [0.050608339013471726, 0.030323012596777374, 0.0833876976262658, 0.10404606289680927, 0.017469564505342036, 0.07037046185183911, 0.023930661958612265, 0.03789034867358785, 0.021705366145338745, 0.05952888513885199, 0.041690374604396285, 0.013363091913502545, 0.07387940501493793, 0.05162103064057808, 0.07194551564152203, 0.04825737988275867, 0.03257441477129056, 0.05316909898312823, 0.006763590143002089, 0.04732076078653336, 0.01928914781479586, 0.06842376348832924, 0.02772626373165798, 0.07368286515796378, 0.015938554068035897, 0.048045449319385716, 0.03581334258459749, 0.047388122897715344, 0.026625111931934956, 0.013058621759316134, 0.07814525836898435, 0.04426334984600545, 0.02421769212120243, 0.05752421690211181, 0.06902949388829932, 0.021801180762028503, 0.015228018051974717, 0.04902452117793503, 0.043029718461536595, 0.040901568342721274, 0.04823739647925381, 0.0064385275454110205, 0.04447310088923381, 0.013944774813529466, 0.08132104521557208, 0.05534727847383869, 0.03414574537366148, 0.005359838880042756, 0.07117463200683556, 0.037652451560021415, 0.009362459156451928, 0.04851561280027513, 0.049598550859598384, 0.09860704547815746, 0.09835604443064622, 0.052522172205029964, 0.06215325721930112, 0.03064815180316087, 0.023193028455059377, 0.025059890880760168, 0.052184503630644856, 0.12527946908507617, 0.03574876903345989, 0.03889801476391093, 0.08593454160877774, 0.0348136744522039, 0.027843647553855856, 0.010523179080337288, 0.0354519980629125, 0.006059835441485649, 0.0517793350492514, 0.0035797146049463342, 0.031962812307380864, 0.05422973239253606, 0.15017305951445334, 0.05287158107685466, 0.03621479180911857, 0.011788435531930338, 0.02919584062070616, 0.014305473906138252, 0.012149212190941458, 0.03379065979031786, 0.03841746313076827, 0.037959085912593914, 0.05935613614236636, 0.05694722246018149, 0.01697986003672404, 0.04619337813628297, 0.019203516421839595, 0.04056985610194745, 0.06638487410401145, 0.09938842451740658, 0.10663085887509008, 0.05140567949462322, 0.07367045453359043, 0.11335512668254877, 0.021452237288617802, 0.06037415591098609, 0.01843174412516096, 0.04383806762616, 0.02445374296287135, 0.059619999806126284, 0.025628429627226248, 0.045607803509600704, 0.015106556726799858, 0.010761307935500819, 0.02559478687603147, 0.029451623972084735, 0.08722318576708918, 0.052782354816313715, 0.03157327383486254, 0.04517749958341161, 0.04823245138170258, 0.05107099100226357, 0.06104468585803144, 0.03204383376625276, 0.0259988235625168, 0.02561494073409948, 0.07280648355522464, 0.1306302178530924, 0.02243313435164671, 0.013129757811135102, 0.07436496686310538, 0.007388167742324332, 0.028161995390790607, 0.03884066159145967, 0.061469650151388305, 0.0257860426415479, 0.04210258353381388, 0.016397864955867973, 0.03315502897866311, 0.08068042717153028, 0.06732802793023086, 0.060466672519161824, 0.025251083444022847, 0.021117899281483506, 0.029783027862469037, 0.055726901853397015, 0.04614578875442667, 0.018905104107914433, 0.04024636398460116, 0.04181714683410622, 0.044574599878321734, 0.0538609300049082, 0.034497973449047536, 0.04031106777068588, 0.027565695533168413, 0.017735416167265466, 0.011472917432265898, 0.03603572641769725, 0.018149195576927835, 0.004947700813758157, 0.03753101513270409, 0.01797956647351384, 0.030937455331666336, 0.03481312286889842, 0.09284750453286594, 0.06596603851404882, 0.06235322148929681, 0.03553051058383238, 0.010702591126544342, 0.08564065495926527, 0.011538153649458002, 0.011440344331335398, 0.040586694714523135, 0.08692759074150555, 0.019797975753223705, 0.0427403747134151, 0.015789974187951417, 0.018766572428566795, 0.02543505179815956, 0.02920424843567514, 0.05901290193921136, 0.02516530266392135, 0.048064816022111524, 0.021755077590745305, 0.0227196320831295, 0.028444614802156726, 0.01727860559889626, 0.07053586023469126, 0.06328728185185502, 0.054072833755203796, 0.044873776364951365, 0.002209934313976837, 0.0150308586213918, 0.03786994392172464, 0.021252458794943748, 0.007226352735738, 0.038340942438451514, 0.09634148599880357, 0.035564233774259206, 0.06408453423289523, 0.03460394639161325, 0.02270475082520035, 0.0364943181404904, 0.05093707500265972, 0.033499868136019476, 0.10770980944676746, 0.04911042644732422, 0.061933301884921334, 0.031089010505726745, 0.04440825920732272, 0.06201538054512874, 0.04718441628820954, 0.014687841795685311, 0.0157111159698557, 0.009990696262027468, 0.026144338133294257, 0.08852617109134313, 0.02798926363128328, 0.0219550073867844, 0.046112195798946966, 0.0724410672762221, 0.0667537454395525, 0.017658841848794012, 0.025401227101082766, 0.07331672109543316, 0.034646640471633405, 0.04740720614790917, 0.016868403819840283, 0.057214173458276264, 0.012790961172281495, 0.08251346873059388, 0.020935175820223747, 0.024101604902816397, 0.09315986922311206, 0.03846573050043756, 0.026353173701453115, 0.06309535384418503, 0.030339514130666375, 0.051690139432227424, 0.047155818225996154, 0.09496838830771948, 0.03350627263106647, 0.047979588740535324, 0.0177169879222469, 0.03735805929247891, 0.05222143672947442, 0.04748679119192305, 0.04267652128492633, 0.032805941863766605, 0.03467532280351847, 0.0378389211912309, 0.03552155501599755, 0.04654971244294317, 0.03981304550243001, 0.09398856185256474, 0.014035692213163262, 0.024874800207814383, 0.037970830040473136, 0.06193760346861617, 0.08454622175063818, 0.028783244816886804, 0.02464696565913337, 0.04423256460276823, 0.07081730561631341, 0.025422758002194668, 0.05078256272921159, 0.030930868890737335, 0.060217464117393385, 0.009392044514477735, 0.02608931386813281, 0.0336897085540958, 0.0773576433740316, 0.07238055399108319, 0.0675293251932148, 0.037782713320226445, 0.03389146163939469, 0.052303094041323474, 0.06030639160364386, 0.09525702725495062, 0.07387382023396992, 0.0115629231872698, 0.057082180339362354, 0.02119548100557539, 0.04915467568583066, 0.029300432689788363, 0.03418351350832851, 0.10437582544381581, 0.0792796660455004, 0.03019509889606026, 0.026205841587075306, 0.018235150642032107, 0.03136826679110527, 0.029035111543752497, 0.057626711805501295, 0.05176934143227916, 0.03977309401717879, 0.08719858668384053, 0.03329253793063183, 0.019852166897767497, 0.050756197813297474, 0.0158224725953093, 0.017926746626354514, 0.03958575870661486, 0.10031900684078855, 0.05637713813132817, 0.02787954451876783, 0.047559535070773096, 0.050161617823065295, 0.09334030591191785, 0.00583611622137288, 0.045928051244587674, 0.05096339395329837, 0.023690587240121058, 0.06608026988443828, 0.04691626636251327, 0.03129904691670691, 0.08156297578205986, 0.027545729366641854, 0.020368565700107047, 0.07011018347956481, 0.01597715340810077, 0.020329726957565835, 0.042090203552957506, 0.05316496210833711, 0.008071923718577432, 0.03295277793621344, 0.03336741919479063, 0.06320223843138065, 0.052508972510094606, 0.04808731985488727, 0.03685332609400634, 0.03849772999303476, 0.03840191154590538, 0.05366857298800061, 0.024605947396447583, 0.03047077180517297, 0.05309352057895834, 0.007811783242129511, 0.033170465650337363, 0.05008626541483307, 0.03131347235232111, 0.0571044351935627, 0.04408118562893041, 0.033778758614414164, 0.010904665011161519, 0.01618655109327407, 0.024357501252163804, 0.043078196505385066, 0.039642813104775645, 0.010667312777631227, 0.050751199089591546, 0.03576188828916319, 0.09587358247729079, 0.04005701386279637, 0.046578873579780904, 0.014068122630217865, 0.05853124330901812, 0.03041299919958317, 0.0506204508635546, 0.06038660867019527, 0.13105752637549756, 0.06080319196166051, 0.2225912284226187, 0.18163638249520334, 0.10117534758342851, 0.19981951002151738, 0.23955426899896515, 0.0940311486802755, 0.13879758846615592, 0.10627442880743936, 0.09499669525652163, 0.06490266250987207, 0.17258470126938436, 0.2501779473236492, 0.23484109690593136, 0.14068924341230624, 0.11186317811089178, 0.16768610525515773, 0.15501378524687984, 0.15929214115585053, 0.11413219264678418, 0.30900297386031, 0.13641741457245044, 0.10946295569620787, 0.23651507562927662, 0.1466505872386117, 0.15653738091068883, 0.17952922701595292, 0.13657699068707807, 0.055812152117610946, 0.17706001838368757, 0.11567356921131573, 0.15667308572559588, 0.17623550859430145, 0.11055405642236434, 0.1828279556526292, 0.07574348079581415, 0.2527177739407747, 0.08389711545239534, 0.1576378049268838, 0.22339511512508317, 0.07185346251654048, 0.08734007546257588, 0.0715726912922917, 0.1775728529619594, 0.08852122216335229, 0.1319193599685546, 0.07991394854240841, 0.1625025858201327, 0.12874472225385328, 0.08007944651669072, 0.1670657272540754, 0.14765344229677033, 0.19031421281397345, 0.22028315872434648, 0.13014073363475262, 0.17729254139046516, 0.1386153514707281, 0.17323921614837262, 0.10433423453040662, 0.10220522256267649, 0.2552361654177789, 0.1361727873764692, 0.10337237283707627, 0.16324376056511558, 0.10335849898476755, 0.1336956267515498, 0.08436118087340748, 0.1376821338048866, 0.1743885012523782, 0.09673999727613504, 0.12584078936807572, 0.20218975541572418, 0.17277657565089966, 0.22934009531332603, 0.168631273892618, 0.0941109367375893, 0.20451808047871436, 0.19645629210337517, 0.15268953577164682, 0.15633646669166704, 0.13194700042086263, 0.17126649377807496, 0.1661041949785525, 0.05924655109523766, 0.12639401976259487, 0.14077791042866247, 0.12362792141615384, 0.18155563682798417, 0.19256479527440765, 0.10200793960041578, 0.17758609096129097, 0.2489484221704545, 0.2721938280568969, 0.23684441682792481, 0.2953598672343839, 0.18149894632158742, 0.2928750150867047, 0.10843464353632544, 0.14298381464135262, 0.20033640486578788, 0.12920517173986282, 0.18146695448986946, 0.2088935916582423, 0.13310883404506793, 0.12278710161485981, 0.18159767973326868, 0.18000916577875617, 0.29069794642348445, 0.16086914846974035, 0.0921763119197661, 0.09559504822978089, 0.18621355865991887, 0.1473318385861574, 0.09926110836527041, 0.14524674643912625, 0.2691995274395712, 0.13186697487629231, 0.15051366220558846, 0.28674462629902747, 0.1271195816356809, 0.1478770633618678, 0.18196131102740767, 0.13320738359564735, 0.23419093340635302, 0.1846754379690655, 0.1579901287632604, 0.11800312001498477, 0.16242726405541744, 0.15307411190963563, 0.08231938801585667, 0.17787466096060892, 0.19785979582417398, 0.2099353026959204, 0.15671488348274462, 0.1561669007905068, 0.15589153814700343, 0.11387363797233951, 0.21549230531579067, 0.14485214987108785, 0.07531202007685939, 0.12382963236661688, 0.13751146473711537, 0.15151225781488806, 0.16915558446799556, 0.1593576110298595, 0.14450975453420994, 0.10781935235906033, 0.092401871187312, 0.12882963543938053, 0.15441289652259121, 0.1385574352236525, 0.1479216496790609, 0.10325526097609151, 0.13337403836269535, 0.16867268860580462, 0.11135241963089475, 0.16436894454302328, 0.1715865193475639, 0.1079459713711854, 0.10431390255689622, 0.1256585370508894, 0.08987108440769297, 0.10606299620121719, 0.15653161992949827, 0.13122998808901157, 0.1406100605644526, 0.08945954963564874, 0.16105955196244104, 0.11848567879848904, 0.12121466018499867, 0.1413372771874551, 0.09988538575388732, 0.1358414237057009, 0.14444950937984452, 0.2054961908969187], [0.021359722595661882, 0.0247337902340317, 0.02366177275806906, 0.018397965393359625, 0.009843685904577857, 0.0673438553067465, 0.02991872884693646, 0.0357216035556649, 0.0332308946658046, 0.04835110690985476, 0.08310311128415408, 0.019280621256198616, 0.030286010550034624, 0.03443076072501079, 0.0566999560913011, 0.01255140164791937, 0.12177951213332916, 0.011394617500745002, 0.05738010427223579, 0.08590574436370405, 0.036858776809587594, 0.060709150838515455, 0.03724408073110446, 0.054698371358456156, 0.037236982926486, 0.03498880598213404, 0.036174177657812834, 0.051453958355611375, 0.0923250555511444, 0.019561974707269864, 0.051129144736595696, 0.049666292184302886, 0.020825558214358265, 0.03750482641701256, 0.05020824576457662, 0.06759631958219313, 0.038078867589994785, 0.017358282573461052, 0.015596416328222522, 0.07678442574556797, 0.06947121252456019, 0.0645261456168467, 0.03854088372580948, 0.013666989416965555, 0.04594891564920545, 0.11053351760511437, 0.0694473565465981, 0.003883219248945675, 0.050693037694380175, 0.015026706424842199, 0.024536683471993576, 0.03967595406838002, 0.05759169775692206, 0.041270248156281254, 0.028045166982337836, 0.046465140166542226, 0.05434557637800613, 0.027379384865203214, 0.02600357139242753, 0.041335063025115, 0.04643021038763466, 0.05447294232585738, 0.049507049317922325, 0.013478676386688267, 0.01962554851366628, 0.021014979199296045, 0.06394013048960798, 0.014735382339436442, 0.009928985964506865, 0.042089184656018214, 0.021248120822072513, 0.046863605478598226, 0.017760084198427298, 0.02232081820106795, 0.029130458846808444, 0.05224332003103149, 0.0907551805158296, 0.043763646014755776, 0.008708308169227696, 0.03738920076660091, 0.062346441611166925, 0.039297173385538404, 0.04988013796748654, 0.014511493143565474, 0.05064812195937961, 0.016398165645378254, 0.06585916158773246, 0.04999525799986817, 0.014182415287641269, 0.054114945608401493, 0.01977231372298012, 0.07636696145298981, 0.029022563023552782, 0.06872891163032863, 0.09510975451238694, 0.007684300465869808, 0.033530067321994615, 0.034715320254045154, 0.01432626649001313, 0.06292750014953556, 0.05997427716670979, 0.03527742960760671, 0.02742097386339259, 0.04598075809377817, 0.06028571872100715, 0.04622300658675452, 0.027896528688049125, 0.029498227015738527, 0.04606515800039615, 0.03817049170573873, 0.057290150228166775, 0.06055122564336466, 0.014190058929905778, 0.03608948280734401, 0.04516362190066327, 0.02978905122877369, 0.05968286498119274, 0.06704645997454083, 0.02243294282966564, 0.06933795153013161, 0.04434919765880031, 0.023988840590801933, 0.04421971730827805, 0.0293625605052277, 0.014635934550765783, 0.051308344193403764, 0.054658936982553814, 0.03448879954615428, 0.07219985683238314, 0.04688166217097352, 0.02247790452994166, 0.03194417913384255, 0.015246216470616, 0.050683603321592656, 0.031893552213366476, 0.03023604054995362, 0.016971819943958716, 0.046803636115885554, 0.05644415550294423, 0.027156771205726172, 0.027449070138015577, 0.012371763605774652, 0.0954304312566115, 0.029955135260318077, 0.031599299756870154, 0.04291636426182043, 0.05233626947888444, 0.03530734534104986, 0.011792958323513309, 0.024316341263212027, 0.030312932794913653, 0.013407054826647285, 0.022230329810671752, 0.031840964107804244, 0.04784893244504929, 0.040801517259810245, 0.018542319340931795, 0.015498475817542885, 0.03056205884223023, 0.04748140176337573, 0.03759537800966251, 0.041480853387545195, 0.042377264359064644, 0.04538849168907731, 0.016986099822867303, 0.09082682505850831, 0.03407669403860646, 0.04443027274382692, 0.04662187792541039, 0.0716116545241206, 0.050740251693153576, 0.04419519483382183, 0.022111601504166762, 0.08033713551178094, 0.029728635619845123, 0.0392425857904938, 0.03931455209010071, 0.03705340527719067, 0.05929962183619219, 0.03352219193813301, 0.012375522224653152, 0.03713026687863373, 0.042952523611846476, 0.013583852597812732, 0.014918478310949381, 0.04607175018698458, 0.03021202752396705, 0.0726814120407066, 0.04406587919220329, 0.12007164934109296, 0.034422379723119165, 0.03070091419372588, 0.014418847258052519, 0.011770514820161606, 0.020446317878762083, 0.04143229107402506, 0.035396866545441656, 0.0761823495849967, 0.016952311514966914, 0.04247011421548744, 0.01863605211368732, 0.037348873898266785, 0.04607726218959978, 0.012241344797545144, 0.045695758064187346, 0.03448541343752896, 0.06744022916762099, 0.03486245510078246, 0.01358755854814644, 0.03495192267901955, 0.058496497391212376, 0.06394067441203422, 0.03543091915367592, 0.009046608766150332, 0.004484922899263761, 0.031472221091990514, 0.050739883970949924, 0.06270011376229025, 0.05045781039722985, 0.029668666257132447, 0.06281237628671431, 0.038818368432863105, 0.04112363424933246, 0.032415907349317305, 0.06059969219589426, 0.041082820915166414, 0.026868233765144984, 0.01612797026492415, 0.03842718095608777, 0.037066980355208924, 0.08913197810010565, 0.027568476432333552, 0.0759841166737099, 0.06631020351403183, 0.014268875970775563, 0.0775407690314516, 0.03600131374813857, 0.040428815484647794, 0.034604406044367826, 0.043400183259960146, 0.0041284162228206, 0.03267741912314969, 0.03013380037079896, 0.09340224412059592, 0.05546134130488481, 0.02857338269090941, 0.03018523168359553, 0.05487106672878708, 0.07027386582546657, 0.032023865684506395, 0.04047458157724431, 0.00803782897550733, 0.08079366262761817, 0.02196555067184231, 0.03679697266629627, 0.026612348907116442, 0.036935818441692865, 0.023570587227661765, 0.047338622126487956, 0.03364182422838865, 0.0736254928333144, 0.01763261099826665, 0.04356506070302379, 0.04733315608914822, 0.012018662190154917, 0.0176109287947897, 0.042492652522219766, 0.11510731532208382, 0.012364654309837329, 0.0695017104848258, 0.051409165194678696, 0.05947903962805868, 0.053051316795209726, 0.10375551639064666, 0.0590060186392117, 0.015434509391085276, 0.058721792358424396, 0.03076002745318317, 0.029774909245691476, 0.029147316611582236, 0.00927022217036856, 0.020136531074381164, 0.043277157200199944, 0.028143745261214437, 0.06720746101270761, 0.02231191625938781, 0.056421801057313724, 0.005583361790124928, 0.06405893157446577, 0.026909669545749505, 0.0327657260781815, 0.027445741485984578, 0.06375309778377414, 0.0114050870498402, 0.040836810930481846, 0.052410940068864056, 0.06510810430852637, 0.06813861024115356, 0.05352460591483021, 0.07344011487739702, 0.06636926123211462, 0.026131180573194742, 0.06760155196271597, 0.032845314952635, 0.02501808163229256, 0.0733431970940963, 0.01830879850463281, 0.036168048954418594, 0.013934537006031363, 0.013383438251161528, 0.03074943628762999, 0.06756746105008549, 0.02109324274164054, 0.06645511670578873, 0.06966107209483463, 0.0363662090873526, 0.07199268367501997, 0.048086266483991384, 0.014717914577152942, 0.032057866581805775, 0.07014805120566199, 0.08453774881819565, 0.010180249397132185, 0.02671799243187472, 0.01792689792871956, 0.009729541676689782, 0.08411316756880091, 0.001663180594351293, 0.022552925605146636, 0.05213529014238908, 0.08361806026509694, 0.01747380863244255, 0.02524704616066189, 0.010893417882823176, 0.03951069741179386, 0.01726308465755034, 0.08712233029185765, 0.05633848899554822, 0.029128773453375025, 0.03288413262775829, 0.027858063413371003, 0.029100062393192804, 0.020643022444639957, 0.008514096261933446, 0.036638760188173865, 0.04347763091866528, 0.022031884309985948, 0.07902607562080508, 0.09674954273167158, 0.014597892539665825, 0.0236010009182557, 0.050668473085088116, 0.13907428410264755, 0.19885800838951143, 0.1619615898497643, 0.1752374952118243, 0.05121188223241799, 0.22686247503565204, 0.0989065628739134, 0.09494804867332983, 0.07663693083750625, 0.14862004607435197, 0.22298277596071844, 0.1143957881797706, 0.11241667663618443, 0.18274508026098052, 0.15586328482435596, 0.1041933433002522, 0.20990436806553797, 0.053668304857227116, 0.18719776713800046, 0.1763440479314135, 0.1258932434082512, 0.14756407047952377, 0.12499718866761654, 0.11204354585178437, 0.18663221038877967, 0.10617996250549633, 0.1870649887789642, 0.199959903294521, 0.15671149737411932, 0.08246030988952807, 0.13898304303086575, 0.14244790549480146, 0.1709791801629528, 0.09440198886178194, 0.11465137809394829, 0.18051441608657762, 0.09985314111315435, 0.17486303143443602, 0.10835526916649073, 0.1825900700303816, 0.14094425876054073, 0.1766353452037419, 0.14434322234122984, 0.1250092085871485, 0.12879620336236494, 0.1466877578246978, 0.13047427299522585, 0.07766328181230253, 0.1183499203574273, 0.12276213480940751, 0.12421822280532892, 0.15459717131189762, 0.15602059331872772, 0.11323956231917105, 0.1735266063722872, 0.13847215431592158, 0.17992675003986205, 0.10491204102553668, 0.16276147757326404, 0.12737167818892386, 0.15369801391516963, 0.18991351818605778, 0.1745603500955528, 0.17020783687551178, 0.11410877333893893, 0.11464974632666958, 0.1842293296489985, 0.2194569482197685, 0.15517164532455707, 0.12014627396579712, 0.08572295578497072, 0.1444667923234163, 0.09849577120715573, 0.12988766414984582, 0.12259963223890913, 0.12088384809753588, 0.1816381138539122, 0.15346814157261005, 0.19516276796498608, 0.15157282472618167, 0.20019694622005188, 0.09723199426286644, 0.21422508863672135, 0.21063455710968665, 0.1671922083703741, 0.08488992709786662, 0.3099493988819661, 0.16704101325763812, 0.13795729726552963, 0.14823877943619607, 0.10642476590170015, 0.30218414782035735, 0.10545681380937177, 0.1399302647839631, 0.3002050362767712, 0.22202099853705978, 0.15823642603091656, 0.22670639228195916, 0.23199512623250487, 0.30279214584058334, 0.13661209283576858, 0.0794405828139955, 0.15197158881252812, 0.10858734784227227, 0.16987193796423175, 0.0946298846974969, 0.12055606971825324, 0.08780124507123425, 0.11774611283814716, 0.15807052203003438, 0.15513455134726342, 0.32344360865892907, 0.2108350116759539, 0.10545767948872621, 0.12867261805842, 0.09214635788192672, 0.1346006370600193, 0.1317872098016162, 0.09584544406783196, 0.14963163453484737, 0.1471105770718667, 0.12989966108674003, 0.1499669818628219, 0.14235657249246875, 0.10477658135876541, 0.17091223940012917, 0.20717943928414778, 0.11757257860153915, 0.1865721337737576, 0.12837796532098325, 0.15681441362586715, 0.10838114761657293, 0.19254625594664007, 0.13392931421197232, 0.14929734440820833, 0.1675471828709687, 0.10817991930150217, 0.09729365667989177, 0.2573099347852892, 0.1729607278661382, 0.12100053094928304, 0.20940558353979744, 0.22370273007019875, 0.09149810194127983, 0.16214404134981095, 0.245327859996788, 0.14829565380369464, 0.09402976206113255, 0.1320300903171301, 0.06885147803733427, 0.16394385767559852, 0.11661767298656127, 0.11545446806497152, 0.09575630207696269, 0.2022517012852815, 0.14312793110166827, 0.08829387025006356, 0.11871959608528884, 0.18688915627858332, 0.16365518042397115, 0.24459258412882207, 0.13682560154026555, 0.09266454741478929, 0.13439906400538262, 0.12506933882832527, 0.1838548505498517, 0.16357196795363582, 0.1346327974310806, 0.1292530215916134, 0.1225538278419164, 0.09993169576891008, 0.1864991868816076, 0.17434946141175686, 0.14970789092683023, 0.16599744828718324, 0.18932326276215816], [0.21163883709138442, 0.03770390585545571, 0.04777971640109055, 0.08149764380387722, 0.053268636787129994, 0.06798015261489539, 0.01737761288701046, 0.06179943185059294, 0.010493322718708266, 0.04533807161234079, 0.06009556420688188, 0.04517689437395142, 0.02449424986186768, 0.025765565111331885, 0.04473286598259884, 0.015632415757394366, 0.0424659735102567, 0.014305922067573956, 0.10044663708897368, 0.05193958915169201, 0.014231647928095153, 0.03492195714986132, 0.05448262950765991, 0.04441558300787884, 0.09609073009942809, 0.0370158976124179, 0.013419175295219308, 0.027471026217925455, 0.04488116145254143, 0.008053458126772555, 0.01545856933995721, 0.01976346157701506, 0.02566826428406902, 0.051902230874064474, 0.06485623758166068, 0.04617830918681237, 0.01665083867978425, 0.043355083663857756, 0.0281703342578464, 0.006421443305894613, 0.06416496197362581, 0.04596910972688948, 0.030427436126516234, 0.11521116620109928, 0.04115787837954779, 0.014745281153028051, 0.043930530608181036, 0.03227207051109403, 0.02894395282642255, 0.061615513292171305, 0.017844357700537772, 0.030619532673529563, 0.028733751706538663, 0.08091209215983268, 0.03794329301003487, 0.029899164876570145, 0.050754669467888536, 0.04461485779874268, 0.02803384037237735, 0.06519052004742046, 0.032165997977098154, 0.07396137642283594, 0.04712631618003211, 0.02323780437901376, 0.0502208057760952, 0.08057362685400633, 0.07473645055846823, 0.04093075629263636, 0.07630191292733916, 0.06681998140148579, 0.02928909458850901, 0.010422756444782981, 0.03575168016757216, 0.02482300500325378, 0.045397680913729054, 0.0633863025465079, 0.010388394528549286, 0.06838598769278297, 0.022282670852878404, 0.0612241879195696, 0.06171281411943417, 0.02209015487272653, 0.07691947938573938, 0.04355327060986911, 0.0320272134887355, 0.054049337838566115, 0.06120330053231409, 0.038703976184009545, 0.039304677216756734, 0.04570919907681885, 0.0397504561190163, 0.026955175168451764, 0.03497374469354268, 0.038247632929274154, 0.05698297961404728, 0.03459967928187501, 0.02348136671278025, 0.014051070470633286, 0.028950253899599758, 0.027363049955437743, 0.06493367374904695, 0.010762712749231969, 0.06467878863575958, 0.04149085083495706, 0.028940582039555716, 0.05288548174224073, 0.08242657137734276, 0.05787580146364147, 0.09506034184127085, 0.03578576724976301, 0.07841546524075732, 0.06222816912697689, 0.03134206466887507, 0.013364716977511924, 0.03033538108631488, 0.05692899339802324, 0.04647419915624684, 0.03013054832756039, 0.014949737571089741, 0.04761799140983532, 0.004789064593252636, 0.10697043500840665, 0.023027398330610127, 0.0070689312433974165, 0.03193452451077681, 0.0309642588329171, 0.07117862332492106, 0.05968435502220547, 0.004000949486526811, 0.03869788961545114, 0.018253331823695092, 0.019547800165450862, 0.017794630933372725, 0.015300331006367362, 0.03302456420515815, 0.011821089072092887, 0.02717473405233074, 0.10007832499761736, 0.06394368896801626, 0.0026417912440299387, 0.03987862645918804, 0.043061346401490515, 0.047032198448094635, 0.035231326436323505, 0.05526436860823343, 0.0476836528058254, 0.028308720380488425, 0.018677708144570072, 0.05231995563653689, 0.06759337014368466, 0.058629222124093966, 0.004066709276934665, 0.052658807816765005, 0.029532386876282193, 0.04370911970674511, 0.040516674278243896, 0.06276585176707276, 0.014099371356649265, 0.05718545665243461, 0.03235606439111214, 0.02611209157734148, 0.09115959833105726, 0.07967838416657141, 0.09280398307788758, 0.0188600332401092, 0.10151152228636127, 0.06841649331392781, 0.07124393232046597, 0.04828831834358074, 0.04980974980900365, 0.018907505793557055, 0.04543119726041633, 0.06156401303146155, 0.03847834413811084, 0.017634711994398988, 0.05773677182714305, 0.054647039637089743, 0.08358629825975626, 0.047938131892512885, 0.07110983629019992, 0.011694737233131403, 0.03292326822937016, 0.01792116376060632, 0.04435930235852157, 0.021256358182478337, 0.028897391917604594, 0.03865644808918719, 0.022086904744707772, 0.03500640685219438, 0.05066430939721966, 0.07500599093374706, 0.03138960808545592, 0.028557672142802228, 0.04497802177924783, 0.10365178042481984, 0.025863375387064395, 0.05593432398933557, 0.026682068653885397, 0.07575497211467835, 0.07276163676813727, 0.02628851013498441, 0.029409201853277705, 0.0634462412657036, 0.026734775503075896, 0.024079223644108545, 0.023607123875990513, 0.053865009423104994, 0.017554148273061843, 0.012753060887447529, 0.04354487045577938, 0.03494306670261487, 0.04161264732359879, 0.02575884268979632, 0.030754913816288598, 0.09568396805515213, 0.027236882935187993, 0.03416759037082234, 0.03978576128100676, 0.043211882678611625, 0.04744975084078409, 0.05287126698080571, 0.024262046696798458, 0.03831885995403413, 0.05829615773813379, 0.020138000047975974, 0.017403577521984136, 0.01756039955052397, 0.04018953941281765, 0.04304107954545368, 0.07314787531692175, 0.03314716508612037, 0.01690663926814112, 0.02947268947478264, 0.03657922366513841, 0.0625121464291888, 0.016031085997970117, 0.0831280627678479, 0.033251866322731784, 0.04085904663248409, 0.05071152339599306, 0.007067197011858826, 0.041332646017713894, 0.01270341934756406, 0.032184610083218546, 0.045966420758275256, 0.027512935057823217, 0.04319943758028169, 0.02209870058352188, 0.03480338206094119, 0.022120382786998828, 0.038703171791689056, 0.060657271364283186, 0.024351204009426218, 0.017043200186303547, 0.023970690052655917, 0.025822759320538853, 0.01350908816206239, 0.03091124171811727, 0.016777601333395127, 0.02878557563939643, 0.06658410292959983, 0.06549224377639833, 0.02487138154045228, 0.07702014333898984, 0.08882878348231317, 0.01453904741098203, 0.03405785210610878, 0.11227599224976956, 0.01628605825375886, 0.03123998919862413, 0.05954285475215124, 0.05698158150358547, 0.022200766477673765, 0.019125369707903555, 0.031742966140530286, 0.03468655365248842, 0.03415427193225872, 0.05429255543276668, 0.037136089146858266, 0.08052423716552796, 0.023904304703577392, 0.024902310425175295, 0.12063129955241758, 0.04630348029276056, 0.07357139170410172, 0.07804624916565034, 0.04207117009847876, 0.05829568276362074, 0.044356172889350884, 0.01541375128116699, 0.11171982007762117, 0.028025930514559153, 0.03086581270420744, 0.029910826649997505, 0.03843713243822417, 0.02448887383985904, 0.05901061133631776, 0.034821017404958125, 0.01296881614478245, 0.04156139987190405, 0.03639673003025594, 0.026099947168521827, 0.05382070655844385, 0.049390845271127845, 0.047452378522364363, 0.016349419470756285, 0.046415639395314845, 0.042725409185814286, 0.02073691035020015, 0.02558016800321639, 0.032254289610371474, 0.07531499249800559, 0.036892913687493534, 0.02592585177250928, 0.023613901838900584, 0.03250200797112719, 0.01765635014782029, 0.041225052799188325, 0.03167924103176883, 0.04139174204019289, 0.045362965639440284, 0.02919409968589823, 0.08076430613835973, 0.022517089927268606, 0.00550404679210436, 0.03020140188445728, 0.03605629204802456, 0.08476393627783946, 0.060470510619662465, 0.08134327708713471, 0.07437898627211971, 0.020360606046573772, 0.025869044437704068, 0.01482741152417035, 0.0386308569220766, 0.03222728501104059, 0.023767249658703807, 0.0515759693488719, 0.0787331006159225, 0.0697178928361785, 0.022367595529724515, 0.041351514763288924, 0.0723433144570839, 0.03155882158617099, 0.004830353859541637, 0.10966042251957041, 0.03605016717506993, 0.033032772837266806, 0.0743983836183625, 0.04385095705548602, 0.025389450414466764, 0.017713948468407317, 0.24545739014302534, 0.17513321532357126, 0.22438502329732143, 0.18159378800661335, 0.12689365464593136, 0.1947267413620026, 0.05516554326600125, 0.22614995197903728, 0.10230479101019521, 0.1331472916588668, 0.1435942641429363, 0.12850666043138312, 0.17377961457016008, 0.12382428507290541, 0.18443422752522654, 0.07926639740265186, 0.11384264971580237, 0.16051834148745384, 0.2242193797663335, 0.15458491390510914, 0.2894202649833695, 0.1333245644045453, 0.16712186617716668, 0.10381890250550163, 0.24663259966238854, 0.10006025298348359, 0.1473750459450868, 0.09762823791994203, 0.14345086780526947, 0.10280201271657022, 0.17198558986908005, 0.10848137489970654, 0.1449355921678005, 0.16228849488881328, 0.10039399918769637, 0.13911986633414222, 0.11359625285671604, 0.21331926627505213, 0.15142067966441955, 0.07626009218755268, 0.1289487161463307, 0.09400801282496223, 0.13876063238468864, 0.18000821582973006, 0.11065976123415655, 0.12210649378117054, 0.1555943879629335, 0.11485760130228535, 0.19442588331237917, 0.1457954186104959, 0.07596601401605914, 0.15295028145755493, 0.0894665593401559, 0.1606680044243413, 0.09830365933838392, 0.11787545912328268, 0.15207812099927856, 0.12772358067694212, 0.2135358546530047, 0.14144520365422772, 0.21083996060394475, 0.11888683307915927, 0.18767390610469928, 0.12705175987174436, 0.09026507576627117, 0.09838487231923689, 0.17230204546884184, 0.14838965279200386, 0.15448493943099054, 0.12205410868890824, 0.07339871548596891, 0.11858864101551234, 0.1340123581429643, 0.11997071725706901, 0.23367295071723002, 0.17405945116714125, 0.12646885889191783, 0.15531827455326436, 0.12102803350576471, 0.18427075968394357, 0.1800047684340708, 0.07899502607723398, 0.17275892498512424, 0.21175512923829018, 0.15454219684245127, 0.21978841914284616, 0.145011143758893, 0.1988304598677543, 0.2020614356884072, 0.08349159447055671, 0.11238534364008135, 0.28504305308864963, 0.1349944675401334, 0.15801563949113892, 0.1982612871835309, 0.2901945653701982, 0.12817449236829437, 0.18124944680640775, 0.22840848643212552, 0.17986321070742223, 0.1005102300475682, 0.1747369946491334, 0.11065603804684455, 0.19427484141722803, 0.15984672752599563, 0.1303249318152666, 0.24478519395474466, 0.1786929041507744, 0.2028147299443522, 0.20432141038679308, 0.16627054331043076, 0.14665631757628533, 0.19463027557057722, 0.08990414876250491, 0.18639623998634278, 0.09117587003856899, 0.17719281206448234, 0.0838123478235737, 0.20722499087212548, 0.18241891066633886, 0.14688329410649117, 0.18669443204998973, 0.1282619259830925, 0.1164617587722117, 0.14649360050116816, 0.08959279530831883, 0.1524963130753848, 0.16078080321031232, 0.12586298293524212, 0.23554617358792215, 0.0931589269349652, 0.19595087325621038, 0.09538292614442688, 0.09069583934521483, 0.10407236269524983, 0.1408804896017236, 0.07047758392629123, 0.15245682890376738, 0.1684480563046471, 0.08794922261468827, 0.12541466062107395, 0.27682338931387473, 0.1472632737169343, 0.11424930450776893, 0.15724938302751512, 0.10788530486846164, 0.1987476151196226, 0.1973601073146828, 0.20861173258914104, 0.16706385799954016, 0.10043424178635883, 0.14393000983663146, 0.1374577619736233, 0.16059406161788972, 0.12829350412733134, 0.09393434581016341, 0.12017187662422658, 0.10763243456641514, 0.1251025027745674, 0.14640517863294772, 0.1453858526844171, 0.21329763195207044, 0.1867011429802064, 0.2813020006062523, 0.10914323656188865, 0.18759630139796965, 0.21366726937553576, 0.14151556116919364, 0.1293837315132541, 0.19906414732817682, 0.11644641403108837, 0.09710019649637323, 0.18744417165796604, 0.20455483737732136, 0.06980646026110457, 0.149503176911704], [0.06297901190156419, 0.02909991300604757, 0.017380441666670868, 0.03241649340657938, 0.05398811592209724, 0.08914920741752272, 0.04405921805770167, 0.034364651167585004, 0.05607934060296225, 0.03925072547468928, 0.06694470051555865, 0.021465879399329427, 0.025056682887577245, 0.03875413579085181, 0.09792963223111245, 0.07337055409387236, 0.052155277376333554, 0.05691438793174683, 0.03865607653654391, 0.028053528832031355, 0.042782490397052425, 0.07483164464393932, 0.02736623688120275, 0.036190472347962285, 0.07847385646234598, 0.08756673023585351, 0.025816404621206948, 0.06278973455811221, 0.026409791429497065, 0.08779982014769509, 0.03129007985755321, 0.07031530352129091, 0.02879449290283505, 0.03321625855601123, 0.0924463655739542, 0.0542532206482945, 0.012422542786225678, 0.028943663628231135, 0.02078812141271849, 0.07802665263654725, 0.0615353498517746, 0.017623063627510302, 0.032452771500233686, 0.03390374968970015, 0.0239177284792306, 0.015038735920473214, 0.012433821515690897, 0.006738587905983291, 0.050508042782424926, 0.015358096908687826, 0.024819467592263417, 0.028218741438561873, 0.05603368559311475, 0.018701148519833243, 0.05758902411006632, 0.06509025445989063, 0.00515261592696451, 0.03808296999082931, 0.03174281100772562, 0.04286837651424351, 0.019565726622879025, 0.0714282454141686, 0.05199926740099346, 0.0178401748604712, 0.05953673370963624, 0.018707051227289825, 0.045373296335099206, 0.12518593741040077, 0.02477121554435261, 0.02143666080589737, 0.022889594434790557, 0.020611005715064464, 0.06636160801375104, 0.03625523742108095, 0.06259825471187792, 0.09339358732705155, 0.07362706331355919, 0.034866431097109477, 0.043878287242184726, 0.009148548255794713, 0.03488002149688621, 0.035786131141527046, 0.038653881694640846, 0.04177478217189351, 0.04439289531400127, 0.014623333362021275, 0.07342684623454848, 0.05517901875258935, 0.03490435627980098, 0.04659061004678088, 0.03960540886187265, 0.056408402179518057, 0.04986033459464389, 0.06496573452867808, 0.07050212172250594, 0.10301247239112855, 0.0407976255331549, 0.06360634215055935, 0.04423820300989094, 0.022533415260935025, 0.011482257001672783, 0.07457891223771919, 0.02525833255100635, 0.07231366685441426, 0.028328820612401735, 0.059063264559353554, 0.06351981251951187, 0.04714312797953044, 0.02543915419899408, 0.08729375778667389, 0.03255959096995573, 0.0909294808403619, 0.03478776918904435, 0.07320715520050257, 0.04535221742586263, 0.024985287323473923, 0.0619019229235428, 0.07971114208621365, 0.07076061510991666, 0.0347980500889882, 0.04291899577384034, 0.051470095997736345, 0.034885464551588224, 0.05873277422881896, 0.05373729873568781, 0.05861522952815699, 0.02406736460304068, 0.05663413381684692, 0.033808034664440545, 0.04468119335210612, 0.023135031768751722, 0.017432690778326605, 0.0369409435699063, 0.06699543851878374, 0.03570304890613883, 0.011119128452734122, 0.08150678323281389, 0.0479175700926252, 0.050178827988284255, 0.04490753402933479, 0.01905597746372223, 0.07039082446886648, 0.007167994072886125, 0.032552883870178656, 0.013622872328626053, 0.045450092819068706, 0.08098483220824311, 0.021964549011881315, 0.018318702106273944, 0.06946096226813332, 0.009158778402413572, 0.038686333179113366, 0.12161848811252464, 0.05581079231154534, 0.026832181667428345, 0.011434207967061912, 0.009225314096247238, 0.015118387039570559, 0.0324689895815907, 0.0101047792028816, 0.035240527152294115, 0.01925621561015085, 0.06271435533680263, 0.02382719220833913, 0.004564916842707223, 0.02370157485617505, 0.0207125430085486, 0.04154607045253919, 0.02718689952856831, 0.0531064712953183, 0.03641893508874121, 0.037599629797642274, 0.017133184873889533, 0.05344096443525726, 0.022914884912390864, 0.0509403461980964, 0.057125740098736943, 0.0607359332723483, 0.04012591581070616, 0.0504990182666769, 0.06954397555560836, 0.038084843075804176, 0.036366768331537326, 0.05535693501212424, 0.0637431041668019, 0.02542361602066986, 0.035669819842423164, 0.017559338518748843, 0.06993571461568918, 0.0453868599217986, 0.026140388950044592, 0.05117260107410051, 0.011894103954546155, 0.01979588433319042, 0.027237652853551893, 0.012193362795627646, 0.07967318242956554, 0.02632060347335233, 0.028238052599913174, 0.03357785588671123, 0.018846379638078715, 0.12533189248173468, 0.05722063924035719, 0.013218922784642108, 0.021055786787802656, 0.02836022064119818, 0.07970166557859029, 0.02130361240086777, 0.02961830555221006, 0.039152987977309574, 0.012524866277442105, 0.05392217107357518, 0.07372997190442777, 0.014686831517235167, 0.0449631788257149, 0.01949367988404007, 0.05753243319509972, 0.07776763830934802, 0.03348325551938146, 0.01411867964517085, 0.04375975045766081, 0.04297861273610785, 0.019346093045427434, 0.07070705024225098, 0.00922347644283887, 0.011472432881653791, 0.03105535243277348, 0.05863654975508971, 0.07562953287795668, 0.051258498682610454, 0.015598909944416055, 0.0824954120382186, 0.046211067106454604, 0.030480204262740673, 0.026498240110794866, 0.021806685103764458, 0.05079944347662311, 0.03716866320539867, 0.006078509792249891, 0.019721171608374968, 0.013818803145700406, 0.06422365579994456, 0.03493268621124087, 0.09201016277074815, 0.05943726102310804, 0.034319084257848805, 0.03316931651845094, 0.038784622259798555, 0.07989164006205336, 0.04775500240465326, 0.057319587156657255, 0.018674655284191814, 0.07510052618360327, 0.02403196559527949, 0.0195688005506752, 0.04042968116400223, 0.02884455100302735, 0.057666667121192144, 0.01363515463327208, 0.029868789490372426, 0.02328083170728097, 0.03612618224935667, 0.021126912305912664, 0.05180907841291159, 0.05896334371138966, 0.038900849289230766, 0.02900108766381539, 0.030373984256819374, 0.05347307118016386, 0.06958130702015854, 0.09126779292860339, 0.06729682516907493, 0.06763265513244175, 0.04577277288321526, 0.07477644800899491, 0.012667763700348236, 0.10505908394172307, 0.07441044950316991, 0.03652612611110653, 0.05820323510335819, 0.030855313469205174, 0.044611724499132366, 0.046061794874408556, 0.016506659017214854, 0.04812185126807421, 0.0420473026291978, 0.0764308148814786, 0.03758029756887305, 0.07597016621260874, 0.065762757083341, 0.0532665262148986, 0.03251274086294636, 0.012594128286676302, 0.023723086605088848, 0.023505276316897045, 0.031460532505485805, 0.01806860504251334, 0.02284169478732492, 0.054101780387422735, 0.027992396930893584, 0.040786632171441475, 0.042637443139908776, 0.05339678031422439, 0.019285625725563978, 0.04321315821500556, 0.019363305125866207, 0.058823122808168975, 0.02844227248832824, 0.11239353311999191, 0.013578655648856394, 0.06168091421826713, 0.028643044981084047, 0.05880986948707893, 0.03503980828569301, 0.011747503454136032, 0.07048838576602359, 0.029109793625050978, 0.03333128282740232, 0.025165785299313646, 0.014761631384552007, 0.07571597057845324, 0.027355184147675193, 0.03998151589785853, 0.05090239037188792, 0.012673537130467595, 0.02591064684243212, 0.07716868012662857, 0.0053536321314412265, 0.024097519738960172, 0.060917059440285935, 0.05216045230026207, 0.024654952125743996, 0.05273305322794665, 0.006332106441409598, 0.04658600968879558, 0.009587248505633927, 0.016486422804694985, 0.022509128358515523, 0.027737946572503256, 0.06189827251458361, 0.06719501208393805, 0.03095296861213302, 0.05106274789619831, 0.017107764161342097, 0.048770091886962616, 0.06842695807497348, 0.04002422913007679, 0.038520915644063104, 0.07614507174660122, 0.0546862097126582, 0.021319520216615453, 0.0574393994775751, 0.17477773520494663, 0.2332345339199228, 0.13304048368046362, 0.1501472576731636, 0.1581341839365421, 0.21691437900787403, 0.13757878854390115, 0.12943479893428664, 0.1298359378931984, 0.17624347590871398, 0.11810821961731681, 0.1647914879985394, 0.13407816509566, 0.19454582203780452, 0.25926777972809734, 0.2105026980561595, 0.10036599867406393, 0.11032499613300448, 0.13175733237256929, 0.07273411122901786, 0.1866368222380838, 0.12516370553883815, 0.1982070788020088, 0.22630532993183983, 0.21671786213353758, 0.2105127184862091, 0.1497309195298341, 0.1296296917022236, 0.1601619114198031, 0.1950123236184159, 0.14014110750248357, 0.13633486093772998, 0.12397673656983722, 0.18533284866040756, 0.20250929068894158, 0.17698762307484306, 0.14881009716660748, 0.1450571856431423, 0.1342994266099507, 0.10943540717445074, 0.1278016450364263, 0.1849255350328261, 0.1868310561704059, 0.11236831350552459, 0.19682856486930003, 0.08105174998842901, 0.08209083334452684, 0.12885612675980215, 0.14913148637260162, 0.11205891357554544, 0.16694293868157173, 0.1629173151788212, 0.27673415539245455, 0.18448498851108938, 0.11960291078374272, 0.29685827392724257, 0.11643221842185145, 0.22170118747218964, 0.12338279626302182, 0.11215259080692647, 0.11684418220313326, 0.18752614306586404, 0.14510587819160956, 0.09083260902233663, 0.14731867719561825, 0.24200141429901126, 0.2007762312648758, 0.21190592598530555, 0.20393594558681213, 0.2365703871774097, 0.15965673772077407, 0.1282564178109169, 0.2855259949161161, 0.11518633729147336, 0.10450544752060406, 0.15740690602650567, 0.19871980612797124, 0.11002171724554032, 0.13227778186480846, 0.09074486897236879, 0.0904915696610847, 0.19240869719895626, 0.10262956632481468, 0.1337629199148186, 0.10559264885922594, 0.11109124493574905, 0.2393822822599642, 0.17526547274281903, 0.1301984506989679, 0.13886737907605787, 0.08825309905073336, 0.1780851819222012, 0.16447160032487687, 0.14943010744548615, 0.15907469475942274, 0.16218211591964768, 0.2104295519811492, 0.09157053555452055, 0.21804123305745665, 0.15952518510241664, 0.20351608343903096, 0.18711794077629046, 0.22544985486855432, 0.18012947222638517, 0.10950591024612227, 0.17143609032275217, 0.18064429863326012, 0.096284075369758, 0.14206153671106986, 0.23475019291283625, 0.15355979633187095, 0.17877486023691394, 0.16610087015696112, 0.13520189350651157, 0.19202487182713326, 0.09136268057890477, 0.15245583298946583, 0.10382247247522879, 0.11491862786633354, 0.13564221020187103, 0.13673932471823308, 0.18407801196219462, 0.14748295709010095, 0.10053509726159035, 0.20687891831321104, 0.1349500650840421, 0.09715422867767273, 0.1406188858973403, 0.08966889082183761, 0.18858311457499383, 0.13048631589739554, 0.15547339203617266, 0.1727521680896321, 0.15839158947910034, 0.25011045497752005, 0.20426452069753603, 0.19118116387436468, 0.18588662297735292, 0.14182446314202202, 0.15439988834963692, 0.15127501570649687, 0.17106049273523594, 0.06660073469843596, 0.08328049894302123, 0.13718256786946328, 0.11249718481614707, 0.18267158178552506, 0.21028416381487924, 0.1579607569522435, 0.15175362147631186, 0.3000766399406618, 0.11075160751539855, 0.23447112240377935, 0.2550064309710457, 0.10198134102768476, 0.11998788528745213, 0.19869101654377677, 0.07731577666896967, 0.09409075032078451, 0.0699214194150221, 0.08191466376545929, 0.1582510736320288, 0.23293580559472885, 0.1279365224763751, 0.17537865457275223, 0.12580846811855032, 0.09621214737454731, 0.08766207753890946, 0.09201933284320178, 0.16250358173443427, 0.16047476640632077, 0.09439883257953391, 0.2481356948133438, 0.15991156920790672, 0.10516599151155642, 0.1490511084275861], [0.07036048738706498, 0.0033994421462393218, 0.0370303230480321, 0.013458235245648653, 0.06653250690789954, 0.030085081009254343, 0.055703666406653585, 0.019384638759337606, 0.043927175143072685, 0.019698165988008824, 0.011005531020102002, 0.06221339512135714, 0.027786639120970524, 0.03845197922219673, 0.09111879648821009, 0.030139013599123687, 0.06715939665633826, 0.03650293279919894, 0.041023636792576125, 0.023113602374289787, 0.07473161654366602, 0.05816143351576983, 0.027198984565573837, 0.02477514749062398, 0.03882736230509416, 0.025360137975263982, 0.021796902160971396, 0.05814726471961026, 0.04194384628546335, 0.0520447883454542, 0.019941347193032987, 0.01755976178232701, 0.07201306927468508, 0.07214598552954775, 0.036346742793196635, 0.016108752949343576, 0.0547739765757034, 0.038217368625825456, 0.011203888420676513, 0.0759490758120533, 0.05979500876198854, 0.041630861063998555, 0.03032710350629303, 0.045773048674868005, 0.052830970755988554, 0.017405215034922285, 0.0902981554428416, 0.03497813054690919, 0.030413039419199192, 0.0177756913246647, 0.06385124130775371, 0.024853774924732508, 0.05608985515972299, 0.08866974362923254, 0.05968889792359645, 0.023402886750597148, 0.0033889685273020263, 0.05382201656879437, 0.08943613798868272, 0.03736654754667994, 0.07095739245414734, 0.04813100601876936, 0.021343761153759497, 0.04514312904868876, 0.08545582858665336, 0.046966778369800705, 0.0432155292571312, 0.006214865781892572, 0.07279251011148577, 0.057390691607349345, 0.03132201614789665, 0.033764030574069875, 0.03121878963053948, 0.02787506865007022, 0.08010589187183688, 0.025363198496521484, 0.0862340436827752, 0.0015444308613246729, 0.08197821075877837, 0.08693557337767656, 0.08234234767094736, 0.020982692423727245, 0.04964725872982414, 0.07066007373073409, 0.04293050241446303, 0.02675464399339211, 0.028119418139178908, 0.1041098167338679, 0.08641615044325592, 0.06507696283440437, 0.06638786950779539, 0.019399416595396977, 0.03830753334407364, 0.012124913797203091, 0.054931905601293816, 0.017064415076146686, 0.07947030702545758, 0.013269685685724742, 0.07005878664072483, 0.0384795890309878, 0.09785594223367591, 0.01864858722734836, 0.008630037923613864, 0.05255895974715391, 0.04266539768826577, 0.015483404952852477, 0.030169959720824997, 0.029604259330118378, 0.05308891639053341, 0.08853996833485943, 0.01014470962071491, 0.07983334843189487, 0.05241988031494041, 0.07703648399441473, 0.07108340625681224, 0.06582320142056673, 0.10786073642872995, 0.056976628745154995, 0.026156787062063817, 0.03983299060153865, 0.15471024588952142, 0.007694603869646428, 0.03880074458016503, 0.05524532366243582, 0.05821062402138787, 0.024191930499528686, 0.029090290941718607, 0.02488727020400186, 0.05507628253150371, 0.08860811185572418, 0.05661143463165049, 0.025025008982347868, 0.012405922508708412, 0.03304881854884086, 0.07271261480186256, 0.0035029873082925, 0.03276051668029639, 0.039902785041880225, 0.023608690525795666, 0.011066610252694979, 0.015647777735496003, 0.034907596831720684, 0.07595396345301021, 0.03569767479935, 0.012967798205453062, 0.005386335946123807, 0.013255877908499492, 0.04747182949476185, 0.02959412590209996, 0.022028754840815262, 0.05799426163937296, 0.03190827450805134, 0.02756473217760363, 0.008300082897016359, 0.019941322295175447, 0.048913652933533155, 0.006562605539652249, 0.0369234039868799, 0.007376492083553346, 0.08612247829836223, 0.0858831677525755, 0.037986983004356586, 0.05861825174501827, 0.015790744106315317, 0.01052007450902414, 0.029794116985172998, 0.01976381972311966, 0.03746802355313013, 0.05662964071117102, 0.03639910107238158, 0.02282781901979639, 0.020808035868310162, 0.05136559777442486, 0.02233300091428382, 0.05385378240457466, 0.020476697095399423, 0.023233479812681194, 0.053482379148443865, 0.008153212350612928, 0.04433700919992501, 0.02826560303689011, 0.02562664272714286, 0.06059896058192658, 0.06645445020929461, 0.013527661963786571, 0.047257700259046215, 0.019547782928472566, 0.005374303577663077, 0.05188706999404296, 0.07184171838866127, 0.0367325293501058, 0.049440978064892754, 0.0775300667831494, 0.06306748356549971, 0.049251654756165324, 0.013904858759844737, 0.04792812295378216, 0.03154926846975521, 0.0292249845205656, 0.07030927440932683, 0.033758522401894295, 0.028129241301587997, 0.04340474148310962, 0.016971274106312665, 0.03588034463445506, 0.07819763580036741, 0.021242649039073337, 0.021789026777109793, 0.06586766516369197, 0.0510906488184006, 0.03558198020102517, 0.04973261624634747, 0.01917905331919751, 0.02165862137541896, 0.05061990311068874, 0.04386308422732738, 0.019585200577914234, 0.05912964990843208, 0.027076048521144737, 0.036640725203699646, 0.029280554623373097, 0.08016892558624668, 0.02946408630739297, 0.024574147086710702, 0.028833337391035694, 0.015934915150395565, 0.038361435290426016, 0.027841977482180924, 0.06833007093518972, 0.08953192962273475, 0.06500603841437448, 0.04686614506006722, 0.006595100595375464, 0.006997314471405961, 0.039724347842556816, 0.01009181795281268, 0.003870933113860027, 0.041642432822094816, 0.05225679168717996, 0.035315492686124585, 0.055081495759828444, 0.029475861078789158, 0.0383579419294913, 0.0543607295971484, 0.06458827534750586, 0.07604283731310599, 0.025581612078953656, 0.02313651797932483, 0.020023287957414024, 0.03919333016740219, 0.020097998767009666, 0.027895209101599552, 0.08208769238403729, 0.01034345868374071, 0.024467599578201774, 0.018669710186640584, 0.049106025272199226, 0.05387644328537488, 0.03689209397341456, 0.03306444291205656, 0.017056183461400292, 0.06467899547949915, 0.032191240574203195, 0.03890892385595268, 0.028343768903024258, 0.027201738651661624, 0.02625581158715631, 0.02560500074328194, 0.0834616327718381, 0.006020407768852648, 0.11991698385005999, 0.09312144225283016, 0.09436438926645825, 0.042358230904585896, 0.04687520021933222, 0.04824766971831841, 0.10172052639386348, 0.03574576213835709, 0.011462619295343758, 0.11592078578448105, 0.013801273138773058, 0.031183547670802766, 0.09042215443426564, 0.03927151710095425, 0.03391778059003334, 0.03597643887323718, 0.03146088682115078, 0.035146443894313234, 0.023020365643465233, 0.025662413287547328, 0.06981625852565612, 0.007459995667299917, 0.06503829837686594, 0.047117916025942376, 0.0852805323478195, 0.058389156981701815, 0.09743546721555534, 0.029158005453345757, 0.08603280004594596, 0.0445580562095969, 0.16690336257940339, 0.05114399918144749, 0.08047993430086682, 0.028668666791711605, 0.04069268680928696, 0.07626242875572174, 0.06400696783056183, 0.012390173656205017, 0.03427752781839621, 0.0265208148067036, 0.011378637864254417, 0.06346221036848522, 0.03667340268410983, 0.023347559880705613, 0.007180596219240538, 0.052514840743594596, 0.04522219698335375, 0.018974764482869257, 0.09585639146426994, 0.07138227247783253, 0.006574471762794401, 0.03970127327427749, 0.07830728596496968, 0.06799629408745997, 0.03311147304972814, 0.05863270782414944, 0.03465950308788208, 0.02589622715247735, 0.03895002830352995, 0.07879314658742759, 0.04854102776716313, 0.06558418198819123, 0.029180631860189384, 0.04275950392888438, 0.004577287247464542, 0.037416335600878925, 0.0800059020759598, 0.06820935080008161, 0.04072879636359792, 0.031235724004105698, 0.07805115978924498, 0.06479698068071758, 0.04141930205326888, 0.057577923496043494, 0.03833994652414995, 0.05704463820063299, 0.018792131036940603, 0.008053515583366878, 0.04888218970248296, 0.08529564726256555, 0.030206063529476527, 0.05626529312482285, 0.1960194381254335, 0.11871985655518309, 0.20917229444509555, 0.1125109207726294, 0.19449498444314928, 0.15131238547544326, 0.15242512818546067, 0.16621624299835774, 0.09009797666822711, 0.1083721231008249, 0.12200653462881043, 0.1842057034974137, 0.20855508804801973, 0.18946763969236807, 0.14582106723420082, 0.16107708005414856, 0.31769816373144427, 0.18842266512013253, 0.16538322963301214, 0.14263703728154783, 0.1715791649034908, 0.14278683811426163, 0.10302625431288635, 0.11326596170904175, 0.1917551475907526, 0.11804122522833849, 0.10648301922746244, 0.18334633670747283, 0.12883003380510116, 0.25084949999807343, 0.13791174567755193, 0.13961391643651072, 0.2456468436866999, 0.17130415466043258, 0.08827432734711517, 0.15819183971372344, 0.11646592629051979, 0.12351431823786228, 0.17979486034281794, 0.143476378533148, 0.1746977096603763, 0.22456022760560437, 0.21142097700747753, 0.19615002547300633, 0.1947498618955574, 0.20600953109322057, 0.16703087025352065, 0.06300841052565845, 0.12618939767801954, 0.07718314386663899, 0.176896657794714, 0.1219153778267003, 0.20497643088381137, 0.17916466109454635, 0.19312714977610498, 0.2271183943676372, 0.1351361784843668, 0.13572021327432127, 0.19487790583122164, 0.10825539428380229, 0.14055125565538484, 0.31200839807429626, 0.12007200174153813, 0.11903094187859567, 0.16117877056521757, 0.2551370489621355, 0.20468327967870623, 0.14213757859843393, 0.12934824632060143, 0.20693360166924618, 0.12883960990415466, 0.1178109085547828, 0.12364914971253566, 0.09995875399439566, 0.18466789966389058, 0.10090413713647474, 0.2162250990588819, 0.17654130025015724, 0.3382081454319339, 0.210492049434012, 0.11025600991542302, 0.0729722956255559, 0.09852525027048203, 0.13985865088480134, 0.08046380048918148, 0.11039691646733593, 0.08461661757000032, 0.24658297248665365, 0.19897279900408563, 0.11836917214696446, 0.13772664351328728, 0.18383119375474993, 0.1774483636742638, 0.18250569310640136, 0.3148582451526196, 0.2980452199136057, 0.15596871384449545, 0.11810849540896955, 0.10768251373402535, 0.16828351594027013, 0.1876032881198391, 0.22622447701231127, 0.10994911509295625, 0.12838020229772215, 0.09021984593522164, 0.08936879886013847, 0.23322583116110296, 0.14019421271739468, 0.17005506362165176, 0.2596841331931853, 0.08305306276006084, 0.1835953918916564, 0.1616899963588484, 0.23260312425273083, 0.14238510160676895, 0.10519458191289056, 0.21599721854492543, 0.18560839516501274, 0.1580195158960358, 0.14318025490689662, 0.18786080091470675, 0.12490779386773226, 0.20883399001773328, 0.11030618867446339, 0.2660256251692772, 0.16756739227041123, 0.17359386889203904, 0.12547576379391456, 0.13314629574456524, 0.15620476085572474, 0.11415084688774041, 0.1167103159992445, 0.09847896323809702, 0.10035161154284593, 0.1047025389608837, 0.11397652358057038, 0.1838746615835736, 0.07934606288589778, 0.106601670925175, 0.15397959719261817, 0.12817093005944646, 0.12967518200316738, 0.17719967621228389, 0.16249909245919797, 0.11737220064406434, 0.1519070842093037, 0.2894533599816984, 0.25796466416889624, 0.11374358688631367, 0.16533677406128378, 0.1323641046521164, 0.16749462923936306, 0.15135884104717165, 0.17366664724484568, 0.12022873566996668, 0.16981351609912612, 0.0911850018066264, 0.24677323808352797, 0.07606123108416796, 0.10141471941624919, 0.1678203851465256, 0.1665190928765843, 0.18026909941146452, 0.10778096369317464, 0.19934692570278723, 0.1791386141051208, 0.07563300325625366, 0.13875758335475, 0.2201022700436654, 0.1805009176173518, 0.11008688834525886, 0.11658720566981262, 0.16126621184089493, 0.2135031580203964, 0.11271875276560746, 0.1283918621559297], [0.02216324540636232, 0.07105076325035865, 0.05425838408090415, 0.027433365335567828, 0.04280937625275504, 0.022903554471990755, 0.017157450708891117, 0.061351936911382986, 0.01230426742920592, 0.05599337021609949, 0.051935099876455726, 0.051024002999427824, 0.024061469556463343, 0.032971164046396176, 0.027159900674896858, 0.0640839558365124, 0.031242388969046936, 0.05509807007207025, 0.026650095974365552, 0.02719825678204577, 0.03978677251706681, 0.022797956912507935, 0.0645070853492906, 0.058276396500126976, 0.031616167097743, 0.05300327925191772, 0.03441788661744326, 0.03135004155938664, 0.09475389134980018, 0.05493407746055915, 0.020620733116483016, 0.08420610935577462, 0.13526124999888484, 0.018332989646061774, 0.004880390413511064, 0.06776419242904072, 0.02391191961754474, 0.03131263923170346, 0.033639736638794986, 0.11298943461189348, 0.025825852400533138, 0.057946319857071486, 0.03617266463416238, 0.07893647397718123, 0.07635019178832732, 0.11154726643355624, 0.030861386631224907, 0.050838073460204955, 0.029874433643154563, 0.05654468539080793, 0.030555976104111444, 0.09899646329182772, 0.029878710328991857, 0.05748823375230836, 0.011794840984587229, 0.00839370362941296, 0.09352694025203105, 0.07694386396436922, 0.023976244190106952, 0.08002783517323195, 0.03011255483743885, 0.04639508908674602, 0.05793592021349938, 0.06484893676374229, 0.036772860048879544, 0.022072335667607766, 0.06272662423490998, 0.045263833862038395, 0.07652728833378324, 0.06479557107893691, 0.05363732426156921, 0.06365829440314444, 0.06129174921361189, 0.1056702076006801, 0.05084911278719383, 0.032121612757985155, 0.08848582124037128, 0.029475466543508154, 0.03744899009865138, 0.06433055570889866, 0.05026580578076744, 0.060691768303513534, 0.06438485602097166, 0.019333437272918322, 0.00462792374403967, 0.04111652878383475, 0.025497953362402417, 0.03387818916610653, 0.024108750587930123, 0.010928580360937743, 0.06578646750459749, 0.04585658673257117, 0.005550222741740366, 0.023357800561033433, 0.048391567843575636, 0.07912506950238059, 0.056744373869150884, 0.058763728011399514, 0.0776935576070701, 0.06102293279142149, 0.06470191683019362, 0.06132153088166829, 0.12057973417423426, 0.05156740831631807, 0.05584090722784881, 0.03224225819952065, 0.023950279555133274, 0.07478384075746422, 0.043655945543920806, 0.015212671395631568, 0.04408466366810664, 0.023476109434399876, 0.041837762260148605, 0.08197572863390369, 0.04784223300615146, 0.033797504785921306, 0.02521894414037947, 0.029103172710165385, 0.0414836994041839, 0.030503273085360567, 0.07922633100421199, 0.0484857545234263, 0.05035234690313378, 0.03646447518540006, 0.027491231786928354, 0.08904220025625922, 0.010786021931938106, 0.009876233150040912, 0.02292241172624692, 0.019908380514431386, 0.07494059000765124, 0.04693258403530044, 0.04199539251144856, 0.030782422118429697, 0.05546237935402221, 0.035058144600160664, 0.021353817972985488, 0.0318256174514611, 0.06925329881449861, 0.051110015521126415, 0.05239489052685038, 0.12823035549973288, 0.009728298699032637, 0.028139951210769436, 0.02409562941700701, 0.0322506966580066, 0.026542345707815503, 0.0356878841956777, 0.07084002778414758, 0.02797474051945873, 0.08052874942340198, 0.004783278714204508, 0.06650397779359933, 0.032757597885304884, 0.03791960940185574, 0.04887164833264486, 0.025994600502834208, 0.044913620597893195, 0.03669842311571683, 0.0499038445583034, 0.039979091229578184, 0.045570157949001565, 0.064362401983911, 0.05394553292482611, 0.02891583739960146, 0.04741605829387423, 0.03847256400472215, 0.03944642263494673, 0.06809004792763342, 0.02527581084699881, 0.016342695134000915, 0.03224807663730556, 0.1125124759311157, 0.055772629641597314, 0.024796912048552788, 0.04651403955874905, 0.007326577146041899, 0.0635814557843391, 0.008633237298307641, 0.03188498160471359, 0.054591126709936134, 0.033605699352319204, 0.014344017704828613, 0.028594570767675197, 0.03003077495152191, 0.07647271989093674, 0.033106064468982725, 0.07000357468402194, 0.04263922812477235, 0.030834290101343108, 0.053152264200992165, 0.05200047015903458, 0.08347160723661223, 0.03749582105346265, 0.03429239375456687, 0.03390157399999519, 0.030496437665856177, 0.01532664133851687, 0.04894923388717636, 0.011471787452577584, 0.011333379304907736, 0.016408136279712764, 0.07794698715330133, 0.05948884172304984, 0.07380188457787999, 0.03444900510892753, 0.02891082335413704, 0.0795256109127114, 0.06392411925199051, 0.06878354902108831, 0.04665825944093447, 0.030345533666531407, 0.030212152013254744, 0.03573853792923112, 0.03854575221456828, 0.02792802639305592, 0.022417351025186723, 0.027687294754169645, 0.02516980917613593, 0.046854354966912544, 0.029477973566240365, 0.058650810481800195, 0.03239825668354188, 0.0662502418121984, 0.02919059483364465, 0.005445743191822042, 0.02145045613419385, 0.06556573459097455, 0.01304778065757766, 0.017481446529047626, 0.05133182478828296, 0.015091690790629195, 0.025695314848675363, 0.07994194139516161, 0.031026344513520602, 0.01857803819040137, 0.060877165411629026, 0.028336990940114184, 0.030132444395172982, 0.011029143765148137, 0.07300041871325624, 0.06332141872976096, 0.016475228344901435, 0.035027340204725345, 0.026117536547263304, 0.058123822429127274, 0.07981617274063249, 0.03320328102657392, 0.03420442770866137, 0.049905005181508685, 0.031442240241073796, 0.02780222517979001, 0.035443601739262386, 0.03411468433877153, 0.016141418938434893, 0.023472527973353866, 0.030970908476099856, 0.06197432206282693, 0.03621622439353697, 0.039181180012923096, 0.029237209368617307, 0.03668203266457685, 0.014368924180856876, 0.02124959362610694, 0.040854971044726913, 0.016727822855295196, 0.03957480747973727, 0.07347933857912019, 0.07909650974456342, 0.03604002034051284, 0.025618614125696403, 0.10369454345275318, 0.05132919710670268, 0.03962387541128744, 0.028302428883410273, 0.02480535625269817, 0.06340283472391386, 0.04076533109670685, 0.024802586844851895, 0.084507817762994, 0.05074451880289182, 0.0315577318260987, 0.07193007896984778, 0.12367175696718118, 0.028905995084994265, 0.024291929871504827, 0.02872456631232654, 0.09021881937740311, 0.013228477816277695, 0.06793991001623292, 0.025267305355819485, 0.04125849253708317, 0.02563009969890118, 0.027608914383416696, 0.0639988204854871, 0.02040488209815756, 0.010363271632682412, 0.04031505525833176, 0.034532098835634614, 0.03787625648622071, 0.036475663899534175, 0.01605145244543711, 0.017749722859251405, 0.0854277897686247, 0.057056773033353596, 0.04739702483939548, 0.0631059794836948, 0.04092928540382174, 0.06594792053463959, 0.02447812945672101, 0.10137820766577799, 0.06818306632339954, 0.02259368722837779, 0.04486385552633194, 0.04623174764997056, 0.10743702085868967, 0.07380450459858102, 0.03392259545263744, 0.03727554779259428, 0.07412806183340089, 0.012443178322076077, 0.05741866147746483, 0.029345752536168987, 0.0401720266428686, 0.05480550492422716, 0.019613354309131543, 0.07891519205464471, 0.03387381863449851, 0.069076148642888, 0.03124417778435013, 0.060528771606303995, 0.06257137651705454, 0.025890100364302917, 0.014903191984030268, 0.03306546563943548, 0.05393791418041914, 0.03823558236622522, 0.04944128450006247, 0.07406905774147281, 0.03016387315226659, 0.03540276925289824, 0.05824677188009505, 0.019866096291450724, 0.042609270256493366, 0.015158912133155091, 0.04347801779306704, 0.03617344221340553, 0.017045843189642314, 0.06260617223057537, 0.01504625220062031, 0.021695868570297476, 0.03745642881239614, 0.10755664548806607, 0.21501815817769498, 0.09153959326325886, 0.08670601513116591, 0.15263138969819393, 0.057697950321580135, 0.10864578502913637, 0.1727079648164011, 0.19225771659083907, 0.23287951345405272, 0.19629657809292117, 0.1416882067438095, 0.23314595883411748, 0.12663804174911591, 0.1673756711064808, 0.18844716461195102, 0.1232408325097734, 0.16554481289800138, 0.1741908046026384, 0.10336977579901296, 0.10548168102339392, 0.08594291494979013, 0.16275331107599122, 0.12897845567955127, 0.12191192277016179, 0.12139340381949179, 0.135213170320757, 0.10826467160856533, 0.1613661250279796, 0.16797271406938954, 0.1307625672028911, 0.24361988229136317, 0.2294996407844367, 0.12769184165423916, 0.10285333294661776, 0.145582921142059, 0.11831540043555921, 0.13663047894595132, 0.13559190886876277, 0.22804983470949436, 0.08613357891238506, 0.1979937999238891, 0.14148638854103704, 0.17971049874059616, 0.21611348004831424, 0.18689304800523868, 0.1576243983882089, 0.148367160450547, 0.20983370411540234, 0.10760056530876506, 0.14210676654211937, 0.20039444368693138, 0.10932872943099468, 0.13064783787535084, 0.08938909252925266, 0.09910569976895087, 0.17244482893616925, 0.1835454582807518, 0.12395096537206443, 0.13375679121142434, 0.2044617270510043, 0.09513046952985948, 0.09567524997457381, 0.14129748658066796, 0.13746729210740136, 0.17905990623178022, 0.062648345370807, 0.21832592665187775, 0.14848844749071907, 0.084532049124039, 0.21105238146358923, 0.14137064797743676, 0.15486211515963078, 0.2801666583024687, 0.13639662294618546, 0.07713726286085383, 0.15875670698381242, 0.1168674176498767, 0.09111178678370292, 0.12587261266045033, 0.14516537257980916, 0.11915869470084868, 0.17387526830838573, 0.21034935789723552, 0.12994395629052194, 0.07060953491036931, 0.12315103168328925, 0.11098027709991702, 0.09647787263196322, 0.10308557250086339, 0.12659370824093782, 0.22103060006854996, 0.18666890600035269, 0.14574487212925188, 0.2555483002816477, 0.20888917899179846, 0.12420143781890794, 0.120730668817076, 0.10138976793255537, 0.16674125837462564, 0.2555880296014009, 0.3538062165100729, 0.223164783129769, 0.16163086969285242, 0.174536723943968, 0.19735929526148305, 0.169233909297374, 0.20695053221237278, 0.11293126555580286, 0.12976121367706409, 0.12700706630224182, 0.24154438156514402, 0.06628084702477341, 0.22382243896924683, 0.16328800980362201, 0.1965530490082118, 0.14381393219434446, 0.07906031209014117, 0.25613178348829674, 0.14657892737417452, 0.15918084390221104, 0.12512507172481668, 0.11149687316989708, 0.16953536489557836, 0.13388711808910295, 0.13770068845441266, 0.11702382982137705, 0.19301294138835323, 0.20436017443576168, 0.12491772236723094, 0.176653899853268, 0.1460854594986285, 0.2007056439235326, 0.14597757899713132, 0.22047740797842705, 0.12053317901107574, 0.06797532626097241, 0.1365879151008783, 0.09311898311059322, 0.23453492220611344, 0.08218097891057692, 0.17038515558646572, 0.18414461564633156, 0.11052995529626647, 0.18163681150444094, 0.13451678107582754, 0.2002901025116444, 0.17880320549011233, 0.16093742222555224, 0.10245106783845734, 0.15902966411123354, 0.11259240954513512, 0.1629016410198904, 0.22326362379375966, 0.1666698436583242, 0.23151924773570032, 0.12313523495029058, 0.20780688061589198, 0.24854300844092525, 0.14442479538340725, 0.18300509050248132, 0.21106148258812968, 0.10286556737076852, 0.1483007253057534, 0.12188386863037465, 0.18836470290778146, 0.1483991676040234, 0.12349547247492498, 0.14172393708459793, 0.19611521443772703, 0.06704341094460219, 0.096206616219734, 0.17991987057030204, 0.13661010100716545, 0.11489321672988516, 0.11463624785744375], [0.009937058616008972, 0.010182030551556137, 0.014997936950455752, 0.09895543162260326, 0.04677416854387811, 0.07742124399350536, 0.013566544756383426, 0.036192441193927685, 0.02517715212889016, 0.05870362841373971, 0.006750095025410937, 0.0448018522001803, 0.05457814918049882, 0.029527663944229007, 0.05960510322643865, 0.0731577118858695, 0.026505554335251934, 0.019031633104708408, 0.027524863046804265, 0.038398215171670726, 0.046936173157225695, 0.02047788261646225, 0.046081812751870004, 0.040185268472639785, 0.010759231837226019, 0.05278880910707578, 0.02541803315492167, 0.06880494585681347, 0.03537194570526481, 0.12410983668580172, 0.04225614968867552, 0.05096529768179021, 0.06958860017719769, 0.05852936639360363, 0.0699158346340541, 0.04455338690369841, 0.028283883809983253, 0.025882383943685604, 0.015131113675212669, 0.002041932668596987, 0.04955002685047446, 0.014353544965776947, 0.031693342795235016, 0.04193053550777897, 0.06933199902695995, 0.060527392648040294, 0.04646400252597467, 0.026290659011612018, 0.012075899491807627, 0.024751975246134306, 0.03591927722276699, 0.028373265203328866, 0.03093360573984683, 0.031072997352889473, 0.011725349148975746, 0.04690746784270291, 0.003351584873011997, 0.05309080862770638, 0.057443103512689, 0.009508281120009, 0.028434647998261838, 0.05640624564201121, 0.04421744968802218, 0.02310506623959349, 0.021573677546374743, 0.007517855894196058, 0.04259146254269346, 0.09575002781686284, 0.023796117766910506, 0.03910057607196993, 0.025885727917475086, 0.013976842296429941, 0.02210873058967052, 0.06579405177504787, 0.04017267398716461, 0.033103337195972284, 0.0350684063479064, 0.015393773623321567, 0.05000455830726893, 0.008972586478076635, 0.012877326094425254, 0.04134684162695081, 0.026397018828579498, 0.034542199704916246, 0.057971734823959495, 0.0360732838781851, 0.024689307338708354, 0.03952884603472006, 0.05661016675613581, 0.03276119083766976, 0.06198541118553089, 0.06611934802945584, 0.01923542589910569, 0.010300318357504664, 0.0629416268108593, 0.03185361604987374, 0.053829014781982674, 0.055260174276848, 0.012233075836012441, 0.07459562827622698, 0.07182206057252423, 0.05542459589759669, 0.023096085773901116, 0.08350906893610956, 0.06256347048967596, 0.0545134645466122, 0.025721015183315165, 0.07300896825449121, 0.046409683061703566, 0.04639818791239973, 0.05134725762951759, 0.09982398380675625, 0.0769458634538516, 0.04773708360810434, 0.03978158227137981, 0.053404130927857854, 0.07297265568688031, 0.005180343521773936, 0.05964544541653126, 0.06450142395953018, 0.020538187142641797, 0.050980826284015374, 0.03428081816603099, 0.10247984210089331, 0.0420824354214053, 0.008715265205190068, 0.03357252391475824, 0.02534192040442459, 0.12072180517979207, 0.021330975146303256, 0.07307616182632985, 0.08940487394049283, 0.03876926219691673, 0.028754382454339537, 0.027559003755149823, 0.07668393033166086, 0.03134104577193578, 0.010632820626450403, 0.017456380132165168, 0.05376049970847465, 0.03860273000393664, 0.03156704745525795, 0.018639899790287018, 0.06352826246931668, 0.05444586494817369, 0.057553638508843805, 0.07479638927766392, 0.039709072049346664, 0.019547484154182098, 0.058061351789341825, 0.015373614019594126, 0.04676432048361148, 0.08478422994695364, 0.06535001189237641, 0.052624004442364945, 0.00736784486610803, 0.030407768734280142, 0.05204666143042907, 0.05038296360702765, 0.051114604387792854, 0.03320813802401385, 0.016449600788614443, 0.016426775198910507, 0.04776740536814736, 0.02055169135752705, 0.07087392717479699, 0.016756095330140764, 0.030467904721116348, 0.014710698986516125, 0.030868455707546205, 0.0506156015269939, 0.045055074902671965, 0.050737704450805346, 0.02199042937718332, 0.03187799871328377, 0.0726074768951343, 0.10172382823281712, 0.02458875255298711, 0.04985575721929631, 0.033958448367493774, 0.03765278097782885, 0.05661274081156139, 0.00953063843846922, 0.019081356041433833, 0.05537946948841695, 0.0327037304129091, 0.032724418617304296, 0.06994997151196003, 0.11992316617960892, 0.07378797242117506, 0.06332873486943784, 0.05981225723160371, 0.012644044660602607, 0.03359842151703854, 0.04335458570670697, 0.036635979289008726, 0.06410437591013408, 0.012652373951559347, 0.02327353088936258, 0.0796349623030232, 0.024074906738655224, 0.026098010881293206, 0.09009347973211158, 0.0662603005466442, 0.03139648755501596, 0.04544499833437224, 0.07268851367576469, 0.052235406342773676, 0.04518827077962699, 0.052975451108068235, 0.10317294482862759, 0.01746271950973859, 0.007846875814720988, 0.05521470695854195, 0.016220569227551742, 0.024339314324841387, 0.041855730852412606, 0.07363754339636334, 0.021695908789913503, 0.046878697410706556, 0.061521525795180956, 0.04007982413074182, 0.013088873613836064, 0.0011804754162327417, 0.045722000406033574, 0.01881165287247108, 0.05846070576338999, 0.021741621256355318, 0.03826521847757601, 0.08789426346700038, 0.04088841078262176, 0.0379987079800377, 0.0064545474015176305, 0.054394364687463934, 0.085411770870128, 0.058605699394378936, 0.05070992610267094, 0.0380677554846531, 0.005306253902569053, 0.07139170302018043, 0.018961616498868794, 0.02258686521541207, 0.021928874212467385, 0.024709886375574336, 0.03830053130044572, 0.044881180604739536, 0.03560953255322191, 0.05481768955266284, 0.08762494525721959, 0.016940766569948005, 0.016177149279223337, 0.041011567077329086, 0.020286188265609167, 0.06874554339916476, 0.010973296913077996, 0.011602165083581162, 0.027753101706865336, 0.003520594163414752, 0.04708075310073553, 0.06048186787313992, 0.048258846941133665, 0.01583853745908146, 0.027217384082295244, 0.020714879576717655, 0.03514214231061839, 0.07239314081567912, 0.0398198790067146, 0.04616812787829869, 0.07893123393577915, 0.058558745865499785, 0.01540615360417794, 0.028464354972745624, 0.029464915597571, 0.06467655165902068, 0.029211166209631392, 0.03325110789568674, 0.06797968530126157, 0.027178604711568164, 0.05847276398731817, 0.07159656259201228, 0.05997038160961482, 0.022781622002742464, 0.06503803790697167, 0.0628271732749718, 0.043380942961741845, 0.05018302615010931, 0.05942561648665898, 0.07852390498643921, 0.014972473145462574, 0.040672546357757626, 0.02609980161181621, 0.07514577899729052, 0.05825123051181436, 0.037735254173317266, 0.058495233346137314, 0.012445420086864504, 0.022729459075978207, 0.019271058563683784, 0.04851677342348042, 0.05211451000744297, 0.09892127942293884, 0.05106512276876358, 0.04320893324010315, 0.053709060734798836, 0.026650561372779553, 0.04289731165514358, 0.03253746252026289, 0.0857663699876397, 0.031280869565483545, 0.0638396427365801, 0.04228478988572475, 0.003509997491604619, 0.019435939837187048, 0.0428497988820797, 0.03833225117095056, 0.0868686096322152, 0.05582140645973625, 0.020987829043259545, 0.03958706488652576, 0.07262105197315255, 0.04266114590028602, 0.025891050313329025, 0.06575100529458254, 0.02071472444391299, 0.041207164646156376, 0.050300187806809143, 0.023403915223635496, 0.06401471680991593, 0.06593419989991574, 0.044144590895983486, 0.08941038977354766, 0.019579280633479357, 0.04370294120763579, 0.06366663327020022, 0.026748155228673454, 0.07354685390788702, 0.018130077852777416, 0.02314788480890134, 0.03687479187764468, 0.0234731963850678, 0.014546812669704519, 0.0036209780157678913, 0.0497926124221375, 0.018273631238468716, 0.018746790123142062, 0.009354239990634304, 0.03272565584930201, 0.04041102309260638, 0.12217636099986492, 0.03046435581880712, 0.04499122530462281, 0.04839386610734848, 0.1517055571199425, 0.11268372722570935, 0.208452049222204, 0.193585500181202, 0.15343711501167667, 0.25434877513156784, 0.11634580370399261, 0.13817509606240258, 0.15635609386428712, 0.1720158196985722, 0.11358519820796867, 0.08153087669803251, 0.15784884682826458, 0.10815961797150875, 0.18692033605710154, 0.26859419540532176, 0.13733547901914966, 0.20439054216108016, 0.16026559375947522, 0.09398281619313265, 0.15727141571621742, 0.13642358924112014, 0.13384890562343982, 0.10489093530322276, 0.10457941330969335, 0.12222003567242816, 0.18088901775979227, 0.15669781504379166, 0.18895865087547611, 0.28500695502565754, 0.10564204620858354, 0.14960187967986832, 0.11731589318162973, 0.24152369719118844, 0.18179415064232965, 0.13953154666289208, 0.1521795663622118, 0.13264864502895263, 0.10933703382409389, 0.08676011626037859, 0.14060776230067978, 0.2298484406163616, 0.11762858728968328, 0.1224316061744767, 0.17245584528052038, 0.13578425822479112, 0.09443509918186935, 0.10252390747829791, 0.12332711699268512, 0.1212377500750365, 0.19119833956562704, 0.13890332392146512, 0.10655546816246164, 0.1561210121238424, 0.18390902828785682, 0.14794429523810265, 0.11534877857493779, 0.16953901147409794, 0.19836333009504503, 0.14767143004123243, 0.12404868754768565, 0.16120089518447078, 0.1719634958933438, 0.13806078042234146, 0.167872678308237, 0.08474767223120698, 0.20023768677586512, 0.22151634577781926, 0.22172524263301205, 0.1699781330722955, 0.12814129011765604, 0.12232043149490511, 0.15005840679570553, 0.2781819696387937, 0.15129931601545504, 0.0832178176290566, 0.16998121274575112, 0.13844578556956785, 0.11889693777888052, 0.1104230400655539, 0.13319625999898682, 0.15905934235742017, 0.19148723132187323, 0.14820997453024312, 0.2643536229527766, 0.12123509174993924, 0.14999057737088975, 0.14490177704682275, 0.09043189141178325, 0.14336368699948634, 0.09797427983533952, 0.1946202704622861, 0.17932572341974706, 0.12989599918646197, 0.13951029538387252, 0.08569609674234545, 0.1627539699116061, 0.23673875798140806, 0.14046787464570615, 0.11453963650931274, 0.21859647826321665, 0.09278726703937977, 0.1496745201368486, 0.18128376754541553, 0.24248483110099073, 0.07932413744950488, 0.1829418729269697, 0.1283805163937711, 0.18937734856961236, 0.22914820561005225, 0.11483143939967118, 0.16915091133165747, 0.11007180407402978, 0.143795806554056, 0.07244261477382914, 0.1571432645282438, 0.21589637073057316, 0.09445533922482884, 0.19197841625540488, 0.16144869398445855, 0.18408935006347396, 0.24273480559068344, 0.1261640478286051, 0.21499031854252662, 0.23482874756859196, 0.12533864937722683, 0.12077736187606089, 0.1345926391020898, 0.16770193263167338, 0.08149627250649276, 0.14244903930492941, 0.21877323006910665, 0.1252472397661017, 0.09811292642787581, 0.13012204108940018, 0.15419799353807204, 0.12508143535664967, 0.10437215588265851, 0.09988671874687557, 0.18064707187154602, 0.1521618850529194, 0.2066983513894581, 0.12463731120430654, 0.1536535501720444, 0.1643066309512623, 0.3082759870636848, 0.2695701607773381, 0.08232880323644608, 0.10602324389882627, 0.24262010690666017, 0.18060254684138685, 0.14136923837565607, 0.16744043617959947, 0.17351293936371806, 0.18528334405874053, 0.09822277577533838, 0.1475167722110787, 0.1915633957833052, 0.13152700037725512, 0.09367565323989238, 0.12778804697577031, 0.07580423922908884, 0.13434122436709944, 0.09416254042016883, 0.05987734023121096, 0.13532062181301657, 0.15133817199497454, 0.06317146850990192, 0.1206627474617093, 0.11756142436136162, 0.1198264092747723, 0.15844256496958195, 0.21983276031190352, 0.09864594742295243, 0.08723771845501277, 0.15339507210639217], [0.022574954463409323, 0.012437200921046878, 0.03716537668820351, 0.03676477399083876, 0.08270977876119076, 0.005893787320312714, 0.03570082342071879, 0.015054436892481341, 0.050735318086921215, 0.019850548537027453, 0.0376031423107751, 0.039983714570201216, 0.05549332930616314, 0.03308042350615705, 0.05526827565664726, 0.13286174004597048, 0.012347106108321779, 0.04726052329304719, 0.11009962838743964, 0.07972575904380891, 0.009554634227477496, 0.019670640448889425, 0.02973380671333402, 0.04332376981995279, 0.054719013597575895, 0.0633738114829025, 0.019556864900814912, 0.011265322926544375, 0.02033951181557871, 0.07468477792797551, 0.07332580689821513, 0.06336653364762183, 0.014606724575822874, 0.05824751115494198, 0.041227917968025135, 0.05777665819492071, 0.056989433904809345, 0.016265806719480504, 0.022609995325065912, 0.03134424801945927, 0.040420733257046634, 0.03917690524230561, 0.020085948203960736, 0.02712259793864383, 0.05442746351623247, 0.05408707532971617, 0.030528362464880755, 0.06578542562502046, 0.05339044093665096, 0.059447986254047964, 0.02238525960203861, 0.09437740510029179, 0.024241630453616384, 0.018687795607313033, 0.07639231130240426, 0.003647039608744484, 0.029240377142184207, 0.04809338344080795, 0.048171417156775156, 0.016298683382751002, 0.038498683772500486, 0.03344203232817593, 0.04489001742894611, 0.0437869887138086, 0.05668744970593722, 0.020644931918791225, 0.040733833391700065, 0.05242344262378831, 0.05707019106334737, 0.040770544325031584, 0.008011349146404575, 0.003308519958555999, 0.062231601200877666, 0.023526092841019555, 0.04778395669775144, 0.047638449787853226, 0.045079739103394176, 0.04333979254888912, 0.04573824147002832, 0.06573694758117199, 0.03492448907045107, 0.014494743588710985, 0.06085519017952104, 0.02082833145264416, 0.026456861786784667, 0.07711075621867373, 0.08974998888950195, 0.026588701688113715, 0.027171483924311977, 0.08437227382655106, 0.05403505029877829, 0.07566416005213415, 0.053664478248045336, 0.07867254136550812, 0.011399687087583927, 0.07721896613797835, 0.06920642955529113, 0.038219287676075776, 0.029779662821261637, 0.039741569499094645, 0.02355120137273785, 0.03475340248476114, 0.07580839142563843, 0.03824873609588512, 0.05126203800882063, 0.056696052873326894, 0.021246757185567292, 0.005202888052970652, 0.026094046376285054, 0.08122713049693454, 0.037975089489332134, 0.042086269691466324, 0.0012445153392505862, 0.025624574289747307, 0.040495503438456405, 0.024779776576906446, 0.10644538132774253, 0.026190879889914108, 0.036886011235295765, 0.06602692718227064, 0.023574842846081145, 0.03949114684796622, 0.04424420530877767, 0.04557545544699796, 0.05047916509811917, 0.08980084946679492, 0.07533462733150491, 0.028504758449872176, 0.015313593903556468, 0.03238346735616365, 0.021387924207374457, 0.02846906449826014, 0.05539059691551713, 0.09513194807955334, 0.024132298215502695, 0.017279501921767672, 0.01995089456378933, 0.011887092334819178, 0.013905867123075072, 0.024182883001142935, 0.04770853917204565, 0.046740292135866425, 0.04724081185075545, 0.043612669237078204, 0.025890510221342408, 0.03637806429798084, 0.04060083669760535, 0.023414791756940466, 0.02589643974187634, 0.0200339863752766, 0.028475147236378926, 0.06250855347682392, 0.03141182272004024, 0.06891993565424796, 0.02783516313009445, 0.012565351151410612, 0.056305964732722896, 0.03667308475762125, 0.03921329441870894, 0.05418446425709033, 0.018598724479576754, 0.0802860834125069, 0.03138704743656901, 0.01728486070679801, 0.042105038845611197, 0.05450109988751431, 0.027929776903962897, 0.05855383524190515, 0.1395421646415226, 0.05051375779834005, 0.037716151770925334, 0.03591654994975656, 0.03497005598018727, 0.04353008112840114, 0.03908896983991708, 0.02875084121290955, 0.017714821808640997, 0.02975695022952653, 0.02742887222989192, 0.01609521809094135, 0.02847609527018522, 0.08940074472658097, 0.008302334237903839, 0.021980066122787616, 0.05487023169294961, 0.01632378042315043, 0.05964703121853452, 0.04796847663519364, 0.04304443501056202, 0.031646193913935174, 0.033489372731456836, 0.05047268782471938, 0.06121385722391068, 0.017880683674687342, 0.056442883796989925, 0.05329163474661689, 0.061916064906625025, 0.07699401974077187, 0.058563089584030455, 0.07930643315757475, 0.005409467970997456, 0.07579824076064172, 0.09081572444448549, 0.05281150829227221, 0.05182378730105777, 0.06900090348696516, 0.08054592511466435, 0.03795252436952245, 0.057751105332206336, 0.0725080386825627, 0.022367402092523636, 0.04154474512043019, 0.04824912145493492, 0.058338978222661445, 0.0444300735609666, 0.02105454381014551, 0.024811161283944404, 0.028514639068875584, 0.09975007164382166, 0.03294969060187859, 0.04779013519686076, 0.025699191253572225, 0.08542471775604833, 0.04363295907575277, 0.018840530556776834, 0.018470584782921982, 0.007092599529818062, 0.06249959024810984, 0.08024623917956507, 0.10787317003574103, 0.029553034861061363, 0.042796712819366686, 0.03269009404785691, 0.005207481228881666, 0.03388701066855462, 0.032313849116044666, 0.02445516405597089, 0.12499692053684305, 0.09640876384031388, 0.050034125470706535, 0.03632228160577436, 0.03210513229151407, 0.06487196536674615, 0.01707834063939029, 0.03673611081115181, 0.04129122364364805, 0.051503374857167085, 0.07567235719292395, 0.04286052411301963, 0.06299459029950442, 0.018184918256837036, 0.06473758588394811, 0.09504774735579569, 0.026100466193090525, 0.05194945253371712, 0.049468936443689375, 0.05767336272965035, 0.04767253687004409, 0.03952819485998443, 0.02036798347328459, 0.017109399759060433, 0.027422511784900582, 0.03920303650140282, 0.027109384837169802, 0.04838489904819478, 0.054544651986009655, 0.010409241696188768, 0.041373275490778114, 0.026451953078409838, 0.06418279267006344, 0.037104353954594944, 0.06201583636744369, 0.061588546997236635, 0.03496298498864617, 0.021487228354559313, 0.023688574344100013, 0.02972111072120888, 0.03534140944060299, 0.06290675831898566, 0.03489247808653501, 0.03888926987025527, 0.035403784319397905, 0.04771561399402638, 0.09725011990315492, 0.01155780093188608, 0.053899552327610796, 0.04041306471692459, 0.05529404685442006, 0.036134475151137, 0.0344390842703081, 0.06888474923588576, 0.04063950115514379, 0.10114041397408133, 0.06700353606814338, 0.10852712567054457, 0.0649391436168263, 0.054832559319273125, 0.023369362743030635, 0.046826220387893344, 0.027342340683624632, 0.04879910746709474, 0.049349817432343006, 0.06240561807287797, 0.07287853412450322, 0.008737169574165057, 0.061136509156635696, 0.014006063762691714, 0.054526863424407865, 0.08663849214151984, 0.029667072794249946, 0.039199470362115296, 0.04424845326631781, 0.013599640712322248, 0.014175814482563687, 0.04723035858102864, 0.037623570045276035, 0.04779893371667113, 0.039435528864663456, 0.05758781752158558, 0.05342933905100631, 0.08009217889799226, 0.07911534784662147, 0.07451037801201306, 0.05522560455926484, 0.023295509951910185, 0.02024514510506584, 0.050986100799374046, 0.030685950581344868, 0.04823692150474076, 0.03640463605763451, 0.013136142196374075, 0.04690371784231356, 0.06480311704499107, 0.034624657578646176, 0.03675824309128427, 0.02599114161585608, 0.019290701058062337, 0.150542359859232, 0.015823858256842342, 0.04257010784180414, 0.033032933715730906, 0.05325975782808758, 0.048482257332051956, 0.05414806358936814, 0.007477275259237016, 0.018889845551682577, 0.05659891292452813, 0.06340829693081398, 0.04696466779756931, 0.03467729547992349, 0.05917582585806808, 0.04903889681783415, 0.08034574634004986, 0.13060243950495798, 0.08576491442058357, 0.1503843465639699, 0.20182512820728365, 0.11269842079209705, 0.14733041366261823, 0.10275002599002854, 0.14253271142801932, 0.13167274094397022, 0.18035488593722546, 0.11164595387996205, 0.11235638551654355, 0.07890485752854617, 0.16604549732179413, 0.23333136743355185, 0.13625128074519097, 0.1182024637537618, 0.22456433383687852, 0.13275896169004903, 0.16778050260918756, 0.1511914048704409, 0.19816099095248407, 0.15403392814820813, 0.07985116763701362, 0.1284307870833624, 0.145634570789914, 0.151095460018804, 0.17934450789565043, 0.12451094500119649, 0.22829452319250954, 0.14135520364488327, 0.11932981576049521, 0.15627962296768544, 0.0987012972754817, 0.22358303649290917, 0.1851917199429966, 0.1583988826361395, 0.16944559471261117, 0.25313726836635225, 0.1180904463774735, 0.14659046465831418, 0.18003325158309552, 0.157729689512522, 0.20308515898162322, 0.10221711990814056, 0.12729729105147625, 0.10543914782183786, 0.15800902049147314, 0.14580366171656117, 0.09285659799652715, 0.15438885668352728, 0.1700735569841439, 0.1022170203167104, 0.2238128628701933, 0.13236192896241142, 0.10721414289887875, 0.1786649266197797, 0.16590254531512338, 0.13112258256202744, 0.12615504629549482, 0.18843452416120038, 0.23637955467547142, 0.1381842431522185, 0.16498579853965392, 0.09547261971860163, 0.12458566155645157, 0.12459123867654032, 0.19976200746192088, 0.1342568321213607, 0.22608524819295253, 0.16155937836775858, 0.20200399441584466, 0.16936893995490768, 0.15908566513849845, 0.1378084923471174, 0.24794132298519536, 0.0814204144802305, 0.14019937615000433, 0.13186317508018788, 0.15226268690199624, 0.3384897899964164, 0.14116486143921653, 0.2781624190749661, 0.18149231200016316, 0.1671109724068834, 0.181804446864032, 0.11008359416718445, 0.17348332240456538, 0.16804022173727715, 0.10641761830136662, 0.1409970881837991, 0.1391204485609647, 0.16292673806028982, 0.09034729232230494, 0.24209305373651369, 0.2687365345416531, 0.1305548348013432, 0.11716195547412481, 0.10411769977860874, 0.14753632277490633, 0.13541914072007905, 0.2057408640581754, 0.13894478459992718, 0.13779749132452473, 0.15810154859096776, 0.15385965846719282, 0.20456718671466076, 0.15528462797162995, 0.22954439564097315, 0.11369485603345018, 0.1276427890444475, 0.1827964387954243, 0.09270312760265605, 0.11842818389977179, 0.17841833823871228, 0.2841197639223068, 0.12851937749092618, 0.29720537304397554, 0.18315337448110505, 0.1603237398329281, 0.15213231405904218, 0.24774305943039157, 0.11055060136582583, 0.17363865439209247, 0.19603164956694652, 0.11991480816035502, 0.19679384576457162, 0.12128686397186211, 0.09704888392720493, 0.14722337585783776, 0.2814271180860458, 0.19022686346884699, 0.18683759856127924, 0.17024290838068531, 0.08568517998942445, 0.19608028082837983, 0.17675513071158241, 0.11633504016865646, 0.15194768686929058, 0.16955755080186552, 0.1365751367543013, 0.20548681398072552, 0.13920237400358723, 0.17736593261361125, 0.20936588486356122, 0.13911258849886157, 0.1837281549289342, 0.10052372085591478, 0.10590633122070182, 0.11630232055341044, 0.17666759750535413, 0.14854789591364323, 0.17857904816346784, 0.08479393628095427, 0.2047529170710233, 0.22583213274277028, 0.10085031945979404, 0.13082268978318862, 0.08531169680457923, 0.17129068683472373, 0.22812969171472136, 0.16902515033800758, 0.17999467139522876, 0.14265959091003866, 0.19492908050456356, 0.10117658864586584, 0.17893108088643322, 0.17103170315104146, 0.1867611889517115, 0.1465628701712816, 0.16544479245860733, 0.16042467957783133, 0.10362125182103726, 0.1611379380788534, 0.23272467176279715], [0.026435817351504683, 0.045354473554799636, 0.07723804172729293, 0.04471529958649509, 0.03655625634916848, 0.007144303761437656, 0.01328356815652261, 0.06209298525185836, 0.033050438824800715, 0.024449334126867117, 0.05103216566626103, 0.036026100522928664, 0.06640802528108321, 0.0960082071082246, 0.002701955240955877, 0.03192156996397722, 0.022171591934297356, 0.06634491495788097, 0.008385382956945369, 0.03338786225105005, 0.03010051193526916, 0.07440665736794472, 0.013705985207531243, 0.09758840134787945, 0.049579260765665004, 0.08245706167672912, 0.03366874838848749, 0.03059188456034228, 0.03017802279622805, 0.010153507182915366, 0.06311041896321601, 0.0295869208451721, 0.10725925015586038, 0.05376592361097855, 0.04548149093264534, 0.058528041061494625, 0.05005216684132334, 0.04174007072804436, 0.07911779932797917, 0.05419452299153613, 0.03822863011831238, 0.055624418441326394, 0.041308556382934895, 0.03394141440249739, 0.017952860648473425, 0.017032804373171062, 0.023405604447508534, 0.041959313600654566, 0.05671952963776647, 0.0268821784805867, 0.05676731820248308, 0.04246796150842021, 0.06304546236811627, 0.05935919666362386, 0.08640560141253857, 0.032404791413536, 0.05918214225300378, 0.07735751313908447, 0.06742538238364844, 0.057322517442967624, 0.05859693534852517, 0.07432247196594555, 0.0504459896605582, 0.10435083565572578, 0.01819555921810529, 0.026204259615511667, 0.04368475428031337, 0.001538350996035602, 0.021396693998887654, 0.052146333299817584, 0.03882807476686374, 0.0413861955636211, 0.042270498515497294, 0.020022464412895423, 0.032946633911060716, 0.06276240054097387, 0.08451945463856382, 0.04482456287669559, 0.0680077700845657, 0.03255048984541528, 0.04127379897381029, 0.03142268584680653, 0.04050931217329156, 0.042011767640830054, 0.022966726082226923, 0.06259115690725946, 0.005767608808744098, 0.04060066815826201, 0.04702236570958649, 0.027324984961700056, 0.006506943027488888, 0.0412293620437624, 0.02783343943226482, 0.07911324876570895, 0.030702170577921697, 0.04054734843873209, 0.048890340877997304, 0.020967441528374632, 0.02541860580564507, 0.05131498234526766, 0.024931894825591196, 0.04252886549840051, 0.01854080057162191, 0.07516958134909792, 0.04520652665486259, 0.018834099248652498, 0.06319160130055201, 0.008791546495030484, 0.04594398970385233, 0.03930301863640066, 0.0614989108796562, 0.04916906664748827, 0.13009248541728144, 0.04394753776010006, 0.07896024568547165, 0.04824182829789577, 0.052923870408126426, 0.07667154268992525, 0.014328951628187732, 0.032502705111138286, 0.02113460574389225, 0.011694485381726297, 0.046112184307628104, 0.0488768998653658, 0.010555304019832084, 0.00839079728335022, 0.02916860427977818, 0.049804685967824155, 0.034745216835290194, 0.06498192196651813, 0.0415828503337839, 0.07233030628412962, 0.029346426693542354, 0.06990082697161744, 0.02141918634034453, 0.021341317333281044, 0.10956430146771093, 0.019724000388035373, 0.048301288212138804, 0.02123935294577912, 0.035543223812935815, 0.03414540446453518, 0.04396203980450669, 0.04651480181623371, 0.10030899407161821, 0.02452489720927852, 0.07688963260020941, 0.06114692029152667, 0.0022250825056671017, 0.03227648700797751, 0.024243388625402606, 0.0062885801983816976, 0.05317373764550975, 0.058841757896927104, 0.02700784945890548, 0.020610053850818547, 0.04834954026004961, 0.021974354937312104, 0.01964562576294186, 0.11638282873337308, 0.04229434683258015, 0.03572065743707842, 0.10624554729269398, 0.048018927355447126, 0.06442248625981231, 0.011467042495496573, 0.06491069111131853, 0.08856399285216486, 0.04716020790980228, 0.06962261448103575, 0.021917997679162412, 0.03793479326451498, 0.03963281565736379, 0.02514085296781794, 0.03944059270584295, 0.0331210414879024, 0.052486177563907645, 0.03529379707610896, 0.06719904936729901, 0.01752898611518885, 0.020218362671232993, 0.01599381390523406, 0.023609628983502908, 0.04827889163167246, 0.03345302568988935, 0.05258389590908924, 0.01687224575078055, 0.015699087431834593, 0.02623841756083552, 0.014742800943373192, 0.04918108656702023, 0.015260622754032093, 0.013355505727832357, 0.04695964226078603, 0.05431892417912042, 0.02272137684837705, 0.05114462354310578, 0.06276207878404567, 0.046106783387761925, 0.013378944187875719, 0.03186952386562142, 0.03133969745718904, 0.028909078588889494, 0.03829855479360108, 0.03188184638988347, 0.010569124245986102, 0.035755916633793426, 0.06307308749866582, 0.054781461254723614, 0.040067233475706274, 0.01803552153550329, 0.020828116948025364, 0.07149979036541716, 0.09648796967080525, 0.0439848960377276, 0.02719946528574632, 0.013689308431029562, 0.11465146236361996, 0.022618722981743278, 0.01630324926677971, 0.031174879385939533, 0.07073137353384687, 0.02943467427676003, 0.030378824017281016, 0.007650855461120486, 0.021425518057038708, 0.0809791018705695, 0.047975256513323516, 0.052457774854114944, 0.05683164660548491, 0.04769451210215207, 0.022347554669625336, 0.03959616218062659, 0.0981162359277087, 0.039896740608157656, 0.04002368520765055, 0.03452353014220153, 0.03481817138831943, 0.017615013958645925, 0.02193086029541108, 0.03951305313216102, 0.044368912931531675, 0.03530697378840658, 0.04176970300895553, 0.019722826358291413, 0.01781848499611501, 0.05888901020009672, 0.026679977233852112, 0.013390991878094933, 0.04659040320304133, 0.017988238588816697, 0.05913529980687365, 0.062009998777460676, 0.039989226572816415, 0.010264746022350606, 0.06916656233971158, 0.03835792277729319, 0.07101352371635937, 0.02489450398922688, 0.010569344496264333, 0.03216080773141115, 0.024247789800527598, 0.06120096396414503, 0.028972784545452848, 0.031241234091501084, 0.06642316317846698, 0.021430198854256063, 0.02698831613205614, 0.016221609191908952, 0.06659620711880346, 0.02261580610197158, 0.012486989932855772, 0.03358429868615443, 0.08176029704871678, 0.05540655835741951, 0.012500910708049854, 0.03570797102105233, 0.010397257208223305, 0.00750703202943588, 0.01669014665117908, 0.041038364832920414, 0.0648859158278473, 0.031743843311203584, 0.050014011832254554, 0.07216363619532316, 0.02660977293647105, 0.017616166920971968, 0.016371812220783006, 0.05062032445904709, 0.031179037328148564, 0.06856878393239553, 0.04684454521104213, 0.06472494543319748, 0.021490235249662114, 0.01651378171969085, 0.07162924390286207, 0.02146201257053162, 0.043779699387209076, 0.07220537266543797, 0.031826161373887336, 0.038251256525156, 0.0074988387190857006, 0.11191927872958685, 0.023197609660846573, 0.08594093078206624, 0.03550824040787355, 0.05442587005334997, 0.022842527907942573, 0.04890053367782985, 0.04493952203061312, 0.048047268778205886, 0.009341142759958823, 0.14081336497779817, 0.024911687341368487, 0.003833354825356735, 0.06384347700664113, 0.060517452657222755, 0.08076742411621156, 0.006285158179384927, 0.05227148525356766, 0.03180425892013215, 0.06501390613735684, 0.02176238989998256, 0.03528445846431198, 0.02401354692635998, 0.017551541658899477, 0.027242703288192713, 0.013695741654373707, 0.03015094924898398, 0.05838093302783467, 0.028968739601212646, 0.041431816099512006, 0.0693539857503868, 0.013059696197629938, 0.05413893948218996, 0.05555883365412874, 0.032086981753368056, 0.06997452462993323, 0.05424864327294692, 0.015001164095836782, 0.08735064747593096, 0.039493027593820326, 0.01748515056416152, 0.03565043781793887, 0.04341944271037656, 0.032088498607458125, 0.02931905437200781, 0.06389562078120728, 0.017255419947867914, 0.08494176060682343, 0.008866169204514836, 0.05074084924173452, 0.21387114069394528, 0.1245690604311324, 0.1575270745783083, 0.16762965989689674, 0.176536780331404, 0.12067885829075692, 0.11342857919272878, 0.17716947702630875, 0.08442669671269194, 0.12986967640538372, 0.17795981929427196, 0.11579297167519409, 0.09543874331058995, 0.19213141933564218, 0.12552342212368406, 0.0737689198144982, 0.11062509575558287, 0.18303594852407135, 0.1340797585585425, 0.10645467397426406, 0.18877411561627544, 0.1807077920004245, 0.16590211630588578, 0.24951255399613614, 0.1708942210121501, 0.1450348311975118, 0.13229056021138547, 0.11105004472718125, 0.17315750521036888, 0.08537718200034673, 0.1804627051516887, 0.11211855352045068, 0.1403174762644114, 0.20367561358838313, 0.2767742064691359, 0.0889344193461922, 0.10061438736175338, 0.18004635168660074, 0.20921596145677954, 0.173194645152938, 0.1175152828856822, 0.1712712435232055, 0.13444352774850785, 0.18712866600723038, 0.14525845226260925, 0.0986787130034739, 0.20657502655540744, 0.14509192006962915, 0.0891683902591467, 0.11563367901309846, 0.1855467863741421, 0.1686199970783726, 0.15863750370279436, 0.1249299414696232, 0.20557166587921882, 0.12417753587567038, 0.1374529969067343, 0.195075020254139, 0.14796930034795117, 0.13117124446697775, 0.16535028785226807, 0.16164724865267355, 0.1405448051950624, 0.212939286664609, 0.08144558046854312, 0.15030951509552617, 0.17086815870096608, 0.13970724126744655, 0.15122715053298783, 0.17405053390370262, 0.24029506069998588, 0.12218581452485054, 0.0865993450485891, 0.1370575576419792, 0.12682980887832182, 0.09689361322671176, 0.210766201658595, 0.17369097819732082, 0.1929608167659852, 0.11946653947234155, 0.09193440433591606, 0.17984428833569252, 0.19611323793088237, 0.08373450562958756, 0.08475334128184665, 0.13816011138260365, 0.1383735128347912, 0.14066736394118878, 0.13987784904818382, 0.09398396532501906, 0.11672991252834759, 0.08327615522449056, 0.146134979422054, 0.14971394302143207, 0.1423232017024871, 0.1264386980103389, 0.14493701709133966, 0.15283772781971963, 0.12938523304558572, 0.19619281914445663, 0.12489082502020944, 0.10756046826680822, 0.13104490124650542, 0.19254826309700168, 0.1565598119651118, 0.3294342630092175, 0.12358426972622834, 0.14922364674989255, 0.23052328746886025, 0.19325035203608776, 0.1642215492263917, 0.12654804173977147, 0.2941253318661644, 0.1366718170503455, 0.16662095192699664, 0.14347332950320937, 0.11598624799761081, 0.19734005113282513, 0.12007519632818238, 0.23521301727141106, 0.15201012303511943, 0.212368076186507, 0.1588578765550929, 0.21615573745821753, 0.12799471451510347, 0.1487906844986062, 0.12166217810684636, 0.22547879767033363, 0.14557469335775222, 0.09295233600442449, 0.21785380198590218, 0.15995436287935705, 0.18419021319958473, 0.18095277159685091, 0.11701908773712574, 0.12131389155383072, 0.19347460129328314, 0.12281183093305557, 0.13838146482744526, 0.09755090900486517, 0.22511401724430824, 0.13870173554506995, 0.21305112017979547, 0.11957796696092814, 0.15153056731627834, 0.17012243339371297, 0.19003756314275727, 0.12437360075813149, 0.10069081995395884, 0.0896874837757599, 0.2071943320333958, 0.11142649267229343, 0.12900016661132538, 0.18645498360837662, 0.11790480795166186, 0.12069581947740048, 0.13869770592258823, 0.16151587989541794, 0.13849590304157428, 0.2475295507258946, 0.09862498725734412, 0.10873829780687248, 0.17931656100817267, 0.18172782274984545, 0.1786804628828841, 0.13360547352462046, 0.12757149690221395, 0.20631754440405678, 0.1631625092798664, 0.2205153599741959, 0.12958905839871976, 0.15688415827049365, 0.07977934689411233, 0.16035701869235885, 0.15763527683673367, 0.08792170473644811], [0.03581536122627797, 0.05107969376108339, 0.06678558405368559, 0.023507302619456768, 0.06620788481086493, 0.07007318143282207, 0.031202117642087322, 0.04764775775613324, 0.03197119330927249, 0.03241320688938422, 0.016434552906561765, 0.020328991513158527, 0.06257239541399383, 0.025535279081293175, 0.022717481291282083, 0.045707689883608016, 0.019645152703648614, 0.023679523015274637, 0.05177238280133856, 0.05265092860246378, 0.03247558942905838, 0.03731225489548618, 0.04434617927237865, 0.038471740460203546, 0.02330056613221044, 0.037477534534710075, 0.010232216013865847, 0.03081411709107699, 0.03452983887625798, 0.05061663574569168, 0.06640129902910802, 0.019793386886557265, 0.014013228600003548, 0.04200138331901643, 0.017939639886120157, 0.03599717304290783, 0.01563538147527124, 0.039063639142700744, 0.011212502121775141, 0.040078353241927205, 0.02805381611500296, 0.05257448068849983, 0.05222083535045386, 0.04817205300975231, 0.05892539937650004, 0.03326257623191322, 0.02926205360000172, 0.015950397787345274, 0.04953396964758154, 0.025218859870707797, 0.06553497616081469, 0.01969493118174855, 0.052899033837621255, 0.09901471916706332, 0.013912990783160974, 0.04277574116243951, 0.02643417792334672, 0.04819413549416969, 0.0702968867675912, 0.021991925163855477, 0.054886970714095144, 0.03858018786676469, 0.04547058184060358, 0.02491335549782361, 0.06958895257764286, 0.05524327437723837, 0.059314365198294965, 0.024193211781582045, 0.06665842111913428, 0.029778188102007396, 0.0631796809724502, 0.046037586496001294, 0.03629472542313799, 0.03824605095771052, 0.08457331061964074, 0.030537511469916474, 0.06906448878468045, 0.01619062285059162, 0.011578641396256225, 0.03915501044942968, 0.016861340489178415, 0.04079662578841371, 0.06954540814002676, 0.041898838619911866, 0.016064927932025207, 0.03533578635523877, 0.00882102077030727, 0.038121010086709456, 0.013733904324321738, 0.047736915068761, 0.04928843080697041, 0.029743551351730863, 0.022109376018746726, 0.07791409899871196, 0.01852711632607445, 0.05449639610765923, 0.028549195379920067, 0.04231014739601843, 0.06005813315090153, 0.042131821279444044, 0.0311138796349687, 0.07030283927076286, 0.0733723697222529, 0.015635810484508836, 0.010528755242816143, 0.05094660513643777, 0.039756875935821764, 0.053516470061074344, 0.03183928446003026, 0.02310825508057831, 0.012298505490405426, 0.03684549284498057, 0.050163475586281675, 0.06019746156169042, 0.011442375421944645, 0.06763158260934776, 0.011125570294567415, 0.04798557571766358, 0.05115637150142462, 0.05877863608240601, 0.027650553177321152, 0.024187247787091522, 0.03220799874754683, 0.031152708801410856, 0.1364633492043903, 0.008271570062084545, 0.020781939083169547, 0.033502940148595846, 0.08079843535538643, 0.05882840115396727, 0.032233409883995215, 0.02890081824584594, 0.008929713325004184, 0.06198540352465165, 0.06371454823942435, 0.038943635299801826, 0.04058192964763411, 0.07840385134782522, 0.044440706861355615, 0.03751850108646097, 0.01199362260634981, 0.020103656326330478, 0.07369618742696701, 0.055902178940032764, 0.04594354537285624, 0.025698248965425358, 0.01627567776238486, 0.03300595209903775, 0.010452902004603418, 0.04821934361731814, 0.023281823791142915, 0.03788496307548016, 0.022079228543706482, 0.016994429113824042, 0.045196264907116854, 0.022559611637505795, 0.032731443643569946, 0.038880885037924015, 0.007259359633955624, 0.020477195052550207, 0.01747621414852479, 0.029651406296198408, 0.031825353151127216, 0.10704292224780207, 0.03315862193102798, 0.04816386352984175, 0.04371979897240958, 0.011950585701983544, 0.030011854495011994, 0.05025764311393423, 0.030695911639580326, 0.040268917613091974, 0.052903461825823596, 0.12361561038321066, 0.029859584943962195, 0.008677945231958743, 0.06242755117015012, 0.013794182037423938, 0.026561202962071668, 0.06429501689009129, 0.008986033236367569, 0.028785979750776486, 0.034040795158474677, 0.009927171293736227, 0.011730127622403446, 0.022783552544311653, 0.06453497094973441, 0.010600419895302866, 0.007002702463538416, 0.0375933517071028, 0.04321650218879504, 0.045847535403745796, 0.0444280510888465, 0.015203925544366002, 0.025194165026468616, 0.027615433791652325, 0.023929815431455934, 0.05893966010321052, 0.024376929241923556, 0.07864641010641091, 0.034054623045507944, 0.025220487807546894, 0.06319648894150892, 0.02931790332490158, 0.03624045958502158, 0.01929740815783941, 0.10407733460587841, 0.0304761823011382, 0.006878813118448542, 0.09124614328386323, 0.06531770596460951, 0.05299987782153392, 0.009456771283200192, 0.04069430325480719, 0.07988022535198158, 0.06134575075139442, 0.025223197843579036, 0.020464543110480713, 0.01411145639365479, 0.011518616492169039, 0.03681243232060825, 0.020588499967068918, 0.026065756664461186, 0.02811016954271303, 0.023818807376007882, 0.09025936075035604, 0.0827857593615209, 0.019946344001519106, 0.03618633930361079, 0.1171014421889859, 0.044824922938020005, 0.024571370017985185, 0.029435361840672074, 0.023775603847518086, 0.043015756509116584, 0.07670138947545521, 0.04779758923236401, 0.033018596380228, 0.06309066155564881, 0.03851356503042964, 0.025580874719326536, 0.04224846199635537, 0.028157647841820316, 0.040375844335123416, 0.021713048091999466, 0.007888319735009705, 0.02599627632016857, 0.06262966814721305, 0.05238937086335594, 0.01328629925997267, 0.05456714432746653, 0.013412811019788346, 0.08101931382571498, 0.01727095046531289, 0.0759058531313654, 0.03624184237372491, 0.023271791869774464, 0.039254709131895535, 0.11076587973342789, 0.025722135586904425, 0.023554223589599136, 0.06761009384307169, 0.05571812248578476, 0.024181597888649955, 0.03620327750761663, 0.05084383061095592, 0.01704776607033226, 0.025327809064859347, 0.024889547400356784, 0.024901159378069065, 0.024635914840825626, 0.028111757259936105, 0.053705590356501846, 0.016684479515759215, 0.015619692952191878, 0.05958103657429738, 0.05192810549370704, 0.029157831168342984, 0.047901987864245335, 0.0437046074488711, 0.028938994322332646, 0.012165290461252294, 0.04136972084280945, 0.02468384321658842, 0.008687234048040645, 0.018370047234179034, 0.029849644953144655, 0.05552742021879362, 0.019321557164432544, 0.02301407606160689, 0.009434083589322625, 0.03569388649456444, 0.03379461280400715, 0.048182008322328336, 0.024834419713325562, 0.047822705424961545, 0.06410304674758546, 0.05129364679657644, 0.11098412286129691, 0.06262797509290038, 0.06881086771646816, 0.037298595547796264, 0.07825957400904548, 0.009004882829744489, 0.003767994118876936, 0.025255513347444997, 0.045702855868805806, 0.038052590774191965, 0.0060540787695396335, 0.049588744934167595, 0.04587538269979339, 0.03883915622868846, 0.013029778548966975, 0.03236731822271982, 0.0634312604163443, 0.00866695761590475, 0.03195256205095399, 0.015163135192837688, 0.11259766490829569, 0.06905119715919418, 0.026568844689116366, 0.0154502812262264, 0.0913331708720615, 0.04036050725487932, 0.010458991445991541, 0.022184584785493153, 0.014519601226634076, 0.04588614240468991, 0.06783801266142438, 0.028433443325000907, 0.021782802312725016, 0.046373826316407615, 0.01260120789670656, 0.008289088577693029, 0.03449533427614839, 0.03164522481271096, 0.05160330719644985, 0.007421747291265357, 0.028755305590288296, 0.06826670780297249, 0.024449050674335133, 0.03914238915087716, 0.04755163287383415, 0.04012160656613208, 0.0181499405974342, 0.041011459825019685, 0.04926352145811243, 0.06994790307456447, 0.04349053566974979, 0.06465231263709646, 0.03033344288386645, 0.050322561404637756, 0.18249984019465987, 0.08727272867315239, 0.147401460656716, 0.15610636452273016, 0.26695544140473493, 0.15091760504630305, 0.11578006309366996, 0.10836311390683537, 0.11457663855605549, 0.15022916779402765, 0.14710789576413172, 0.14714100608421912, 0.1104963316972698, 0.13961353339254856, 0.18033366530172287, 0.10172782721178186, 0.08763978438031289, 0.1329668319874233, 0.11572164888944357, 0.13171613216400146, 0.10516585361573005, 0.13065218925476074, 0.14981367234741488, 0.18930814018653286, 0.08678404884713312, 0.1268003298149955, 0.1333720465340922, 0.09273318889280481, 0.1332588800259175, 0.15587583334455568, 0.1809108206221173, 0.24641579677981718, 0.23415711828537528, 0.19116639369918456, 0.20070602696749473, 0.127978703277486, 0.10503647668707757, 0.07978593525026115, 0.19098876855306088, 0.12798212769050754, 0.07433760986332932, 0.13348081569758155, 0.13039784806389965, 0.1584476211498822, 0.08839431203781598, 0.1574927844828175, 0.17089477259545557, 0.10588971477362419, 0.23160460525222365, 0.23700650571094406, 0.12793076149518454, 0.18873087761382903, 0.1280807155454832, 0.2690090166945612, 0.10323142798076715, 0.08155540683336797, 0.18685492747012647, 0.09559275762688729, 0.11022496803273117, 0.13442057575429642, 0.1513838155135032, 0.20424245736531674, 0.12276180539160006, 0.10339301890663563, 0.13915915132289933, 0.13391313443501152, 0.12384751285876959, 0.2074340869101786, 0.12251563835889102, 0.08726954174738738, 0.09750490542501213, 0.13785456487488362, 0.10288233703543102, 0.09775314855599597, 0.21527403154440466, 0.1090492835388549, 0.15905155890410946, 0.20571072615923422, 0.08584912280522047, 0.14604668012790142, 0.16315271867619408, 0.12988102982842153, 0.2599526316888871, 0.1525508125703181, 0.08581019787778778, 0.19374388119866773, 0.1439241109596145, 0.10227494422466525, 0.08211141812705225, 0.19231609249066925, 0.1113411887819248, 0.13119978890303644, 0.18220557050118524, 0.16690714705374934, 0.14624460660401853, 0.1519489432534864, 0.16463865345764547, 0.13039262334425605, 0.11162467195742554, 0.15193192077980888, 0.1417250402512089, 0.22237261757254603, 0.24485752797655522, 0.11752105918863129, 0.1459663175046444, 0.14843813083585233, 0.18314324679874605, 0.15380184947242662, 0.13601282821787944, 0.1790162545418547, 0.08844889580242096, 0.13231856838589715, 0.13337092804572276, 0.11141488644024057, 0.15478467899224452, 0.13531720506087427, 0.07332024509988486, 0.08769500399789504, 0.11086092826219336, 0.14167326802928604, 0.2162099918050151, 0.11390913848675067, 0.1502636111071033, 0.18441050944309081, 0.13595524904949052, 0.07529159617279807, 0.16281321915166994, 0.16456238174390408, 0.1941583807309789, 0.12928841485371514, 0.12998241390432083, 0.1888002238927349, 0.07782074352425915, 0.19314208849062844, 0.12392780653411344, 0.11775004286919871, 0.18034310350495, 0.1736118106712257, 0.16036415863181316, 0.2333453561990492, 0.13802849747721227, 0.08572780512153141, 0.17010093696655768, 0.10997725350241508, 0.15291029166790748, 0.10812384166544485, 0.2274477202445269, 0.12540263304066274, 0.08155284809970087, 0.30501346374231003, 0.11947353385509023, 0.13997227704573062, 0.17741831770587355, 0.14276837539528647, 0.1579391379510203, 0.11310165117104208, 0.07749479609511553, 0.14845959661949068, 0.14309411598069055, 0.08918522887172238, 0.060619472586099184, 0.12805828449106024, 0.09261862044372866, 0.14233178188723905, 0.15105954581691375, 0.14103058154784864, 0.203603356175365, 0.10392682897227426, 0.12276096269488336, 0.15108073580889933, 0.1306582107058456, 0.22729716864564728, 0.1487294434299392, 0.30344577205757944, 0.08273898203286432, 0.0853701799567188], [0.038320395960322315, 0.045246933962428765, 0.03823929023177874, 0.04451353117943772, 0.0252287213375131, 0.07174777302650676, 0.1602277183724988, 0.01537123435897933, 0.03488345357078699, 0.027995896037487734, 0.03799573172845187, 0.035991737649085066, 0.039478192301166636, 0.012736896432245211, 0.0565052510149056, 0.05804228003046686, 0.01881613640204793, 0.008936656954427882, 0.04284982569515706, 0.005257557523662164, 0.029858437727295586, 0.04174422675503358, 0.03910684267119054, 0.035797044064008424, 0.006759159760774985, 0.022763410177562508, 0.05206219769353348, 0.008120538700642365, 0.027861014767099294, 0.05845411740724118, 0.048328120441686724, 0.055217932188703175, 0.03273039410311369, 0.045032306769562346, 0.02993352966563356, 0.04151032095955264, 0.044529496451779726, 0.03535939335462547, 0.017190716161783186, 0.011874467205827036, 0.04133598616106376, 0.008171352355049984, 0.04930323162566751, 0.010987843965150176, 0.03512751386170426, 0.054912508255051035, 0.04194661952374924, 0.010874691821124044, 0.048372342867115815, 0.07075562021665036, 0.03842621185486356, 0.013023754225052413, 0.03739542906142531, 0.016687813913449645, 0.053786596493615266, 0.035288970722185994, 0.017248280008413622, 0.0672263604017996, 0.028740085338452653, 0.034968362925874616, 0.024523840007943012, 0.03421064068172728, 0.03362053847541252, 0.039430338618976456, 0.07246025011784608, 0.018186255080264904, 0.01942544443262441, 0.026859764663142063, 0.02030269362993779, 0.03261749189527285, 0.045361314719963464, 0.030237519099647482, 0.019987228198818142, 0.034647762790442474, 0.07115118971635258, 0.03821851775771187, 0.047489549108450456, 0.032415991618988976, 0.08589593843827326, 0.06888528549743277, 0.0045322872427923065, 0.05512738442649284, 0.027086697143292236, 0.030682980075418472, 0.021759997790438995, 0.047216086362999295, 0.06878308170745451, 0.05030386119840607, 0.052041015362427126, 0.02743654460045359, 0.05844850581319583, 0.043460240722784114, 0.050171768488062006, 0.049820038369826736, 0.04636944429348073, 0.05700683176156975, 0.03455344970608431, 0.06116265956793101, 0.02131528566561399, 0.016054114600973987, 0.03139559697780398, 0.013319723676109027, 0.04028878227296857, 0.015297223562224498, 0.02886165391593691, 0.012698399556440212, 0.041787966545070374, 0.05831767714792683, 0.03748292013281777, 0.05962497554719449, 0.03676457863841807, 0.01867169626958428, 0.06099580561802272, 0.07594349869196454, 0.05120796752312491, 0.034882882835283395, 0.029051590095003767, 0.0749596809187243, 0.0090447596214231, 0.030620492198654724, 0.0033713374925296636, 0.03864111866982233, 0.04332697206747629, 0.022882688152153167, 0.04373192997469057, 0.05813998688432959, 0.0816940610867835, 0.08963870695762097, 0.07381467824621547, 0.09345128140862911, 0.021772172842775623, 0.048987090121954686, 0.08344886208614034, 0.03362646799594645, 0.0751853627603381, 0.005451503694207678, 0.021253370439573642, 0.042129603454903256, 0.01991215349745847, 0.024087390141381372, 0.010420873783709062, 0.02680222762958898, 0.0032427831507858733, 0.04521046434679339, 0.05808666333436005, 0.0509763753131753, 0.02745741858117042, 0.04629491926020673, 0.029249926428160364, 0.028951364727089965, 0.020031881548704642, 0.06850618688810257, 0.02838138956576586, 0.013594514626498907, 0.026922989899532932, 0.030186698741970525, 0.026450673711576292, 0.07039051037281752, 0.019796859180074067, 0.02685324333968663, 0.04479105419088756, 0.07121460647472451, 0.0364434537327578, 0.027725118430211183, 0.09999937963702026, 0.047802162777271964, 0.01401988686167545, 0.04827030378604128, 0.014172920585429717, 0.018379470115647684, 0.09794350608342117, 0.030107613570327242, 0.06658247882320036, 0.043372048680940946, 0.023496405018733877, 0.056423068932828405, 0.04404678828113022, 0.01718111516487214, 0.028618273528052435, 0.02100887730897915, 0.029962995322421197, 0.0062283857973412645, 0.04381084086133107, 0.06094229820695135, 0.023998483722548813, 0.042279611131356615, 0.05549774197260699, 0.048833776776108055, 0.03252678325459842, 0.014860376287552138, 0.05804428335038885, 0.052237214310274976, 0.04204827173042201, 0.05994063058507539, 0.05505667451108175, 0.050508762905073744, 0.04357421928415856, 0.06372730743380324, 0.04283421665369984, 0.07044900884671558, 0.017515721302779935, 0.02012968799399753, 0.07110386846526977, 0.03423331305384636, 0.050219227634971185, 0.11315166139073911, 0.06727318369573163, 0.01292515392114799, 0.03453675665021424, 0.03019883932035056, 0.022659963409927104, 0.015074135885844308, 0.043155330068041245, 0.0276613186278771, 0.025905738134057294, 0.010908160287316048, 0.04253056238315279, 0.04110174328689614, 0.018046375086170532, 0.015488559766972979, 0.047075168319767526, 0.0250263036709399, 0.020517615766655055, 0.01034503012159539, 0.0962980717961346, 0.07420936674480477, 0.044494072546160994, 0.035821547386266535, 0.0754561135545373, 0.038355310417471394, 0.0146521344375346, 0.011916088762753194, 0.06171804266951739, 0.045617532826239066, 0.011922229915076207, 0.14189322719410544, 0.02260592739818798, 0.03394399994924184, 0.024156089075991226, 0.050240720231686874, 0.06715355906635523, 0.022229094493893847, 0.018977198727248658, 0.0480236119831041, 0.06639705490200751, 0.0226515862384751, 0.09029355125441667, 0.05077995419982941, 0.024305368968916517, 0.0353096436048227, 0.04342099403842323, 0.059954649994089726, 0.04148381048693292, 0.018403272467455076, 0.04618576705275525, 0.04158362408258742, 0.016968374463519263, 0.036703824035583005, 0.03154809444001125, 0.061335404733977014, 0.0332326834811078, 0.04076194881852116, 0.04622174637211908, 0.0330249319273618, 0.1256784400151622, 0.05010894544783139, 0.05439431872218848, 0.015254475856049648, 0.021317281324656743, 0.026847413410582853, 0.04915757532862406, 0.02847453245081969, 0.05040920594887388, 0.06470818342941423, 0.007317696271779677, 0.08081261564286486, 0.05669620609091175, 0.030561384684856863, 0.07997984742565502, 0.06399731895315551, 0.035387052959131624, 0.05303127210467093, 0.04885417769753164, 0.11896437649885494, 0.04904478037309262, 0.04441009781834099, 0.05057103819243851, 0.05011972430492601, 0.06822985131293535, 0.09544408294342219, 0.033323679404753836, 0.047631857601264795, 0.0499530618769988, 0.03613809874701885, 0.014842381839820696, 0.020828457857151667, 0.049029263262186325, 0.04945199440924391, 0.021305985358213226, 0.038246181192657644, 0.00744754865375017, 0.0707952346232149, 0.08716959791678576, 0.05505067987307426, 0.012893934880623655, 0.10399390763092427, 0.0372334206176381, 0.009149184108771866, 0.0184520818443308, 0.04546517325985817, 0.1014604855088457, 0.03569623455405235, 0.018880857425110958, 0.03700027707964182, 0.10105044460825383, 0.04307792454417195, 0.06619109982444395, 0.07707867245640486, 0.04453558302033813, 0.045670293301584265, 0.0191044555075707, 0.10064480105234731, 0.04893653981027104, 0.05661580516325851, 0.040348138765341816, 0.10227175729890024, 0.02354708365014484, 0.043654999425334316, 0.05926925411087371, 0.016351413214579225, 0.059655561607571385, 0.036820173639083104, 0.03401200557428022, 0.036836950964624846, 0.06007082339736724, 0.016815995744940256, 0.03511052203154372, 0.0362072458430644, 0.040964858696585706, 0.040312799129394755, 0.027904275752183412, 0.04289071563811552, 0.03673342950341683, 0.03864404512569308, 0.04698638255978304, 0.03487226102621325, 0.0793358815773841, 0.0456665241489968, 0.035296930375719265, 0.036769083235412836, 0.022634069638086424, 0.02272130407002424, 0.1015918159617051, 0.18041280218430106, 0.1478168948162948, 0.18466941651798066, 0.1085096435441125, 0.1343999220238578, 0.2410415061298878, 0.13008851708183367, 0.0858483030911415, 0.09355742289053817, 0.25412919901071057, 0.16499681488400506, 0.07908306490149229, 0.13856042296655718, 0.18301969213831812, 0.12946731170579312, 0.1210095784476688, 0.11917878152622331, 0.1347919751799876, 0.14397219063774233, 0.11761358728812588, 0.15771571606878312, 0.1335909484975761, 0.16509190171716676, 0.1280491833665198, 0.10107485983040064, 0.13169074401019082, 0.1318049064326671, 0.13507979441313975, 0.17442251555621627, 0.16122893400249944, 0.12118559480915148, 0.10889502407442178, 0.24030924864834358, 0.11343316805939521, 0.11525488683893798, 0.1104844649953227, 0.08558288426889528, 0.1986422473865171, 0.08104083323550802, 0.1481537743201179, 0.14694747695278737, 0.11105602021299063, 0.06617583935299227, 0.1390993351777715, 0.195983738428162, 0.11023618355994264, 0.11732431248791757, 0.18003951818231614, 0.1388013422969849, 0.16462912332386742, 0.09788773488253356, 0.17824046794445286, 0.13221629564800572, 0.14323213438112892, 0.2365410919751852, 0.2378361023241474, 0.13226449790020145, 0.10980774888828879, 0.16787422580584405, 0.14882152719843775, 0.12310243106537289, 0.14003862025997332, 0.13891052514795335, 0.1928069556672727, 0.08064644351120918, 0.1903915723725673, 0.10703716126661147, 0.09253534668635938, 0.10400470947065663, 0.16656884262638708, 0.14553591398702515, 0.10649623424415627, 0.08506638779034538, 0.15071531186901754, 0.15253383606191606, 0.0981722905811283, 0.05065559897752059, 0.17129811788758925, 0.15151161430103166, 0.12585871582550387, 0.13756299181090248, 0.2065654964216294, 0.14570914178846345, 0.1710038788376316, 0.15801305011395486, 0.15894416869888384, 0.13764753727422607, 0.28760298185290833, 0.30904734567288433, 0.2136977749966806, 0.21837797466545336, 0.18996188897759686, 0.16220312205053147, 0.19794869266690748, 0.13307440605375076, 0.10018936944224181, 0.20019987267592262, 0.09196510913992122, 0.16840084996675292, 0.16312443471002966, 0.10807625228358854, 0.13373823656189826, 0.15577258001412117, 0.09881162925833657, 0.16876645776773655, 0.21344744810654273, 0.22691020231333472, 0.14836254860124282, 0.1227076199927157, 0.11166656930600444, 0.08592311923782672, 0.2003294794309524, 0.1552444236773637, 0.2101741076236771, 0.17055810759625128, 0.2499591372907162, 0.20033675726623307, 0.06096010975119087, 0.12377472684508371, 0.13147053969723563, 0.1731463050049159, 0.23705443217148706, 0.12588779652310958, 0.13929062733246436, 0.14793102659525412, 0.12698493402210936, 0.2030586523394431, 0.20496734508102943, 0.2654141337881165, 0.17737013077543629, 0.12459820241577203, 0.24013923841618726, 0.17029078887595286, 0.3218878066587833, 0.09819451479181167, 0.1156521570538321, 0.12231991821599585, 0.294395117389579, 0.15117122611451536, 0.1531048167136408, 0.14219091363972233, 0.1051348653591929, 0.113236689489455, 0.20817074173640823, 0.17973577964209742, 0.1560754452141062, 0.20311563395925109, 0.19098380430331155, 0.3028405319538809, 0.20546111939174516, 0.1450174563233891, 0.14239830896258354, 0.16232655413689154, 0.10364743670628918, 0.14200299227189633, 0.18196472777954995, 0.2338305656467715, 0.1239924643549227, 0.13309083097884733, 0.11275399281012435, 0.1873625373287547, 0.15499420403953523, 0.09261986916704525, 0.23567890598168298, 0.12808068490196622, 0.1427909290237773, 0.10897671969066705, 0.1430783958564843, 0.10393759250761041, 0.1891260257651729, 0.14972635364580542, 0.2038943316907652, 0.1392459644064788, 0.0593103087627359, 0.12144811015816466], [0.03931493130362323, 0.020066794090633912, 0.09133348496811045, 0.04648896167054773, 0.021091873359475887, 0.020148056867201964, 0.022240917145785306, 0.055615650565033, 0.03599146185743232, 0.023696350136531458, 0.01017743306640055, 0.0909538041319578, 0.05977052459192853, 0.07924434173131183, 0.01614424580287549, 0.07268825320587044, 0.01940932977313717, 0.00496616592675808, 0.037774807292847865, 0.009979442430419788, 0.012307999235007071, 0.041339617417824846, 0.021315695522653482, 0.07002621258218443, 0.07449065890884207, 0.09616073521394884, 0.04114124661071166, 0.05307271363093488, 0.0209944786864423, 0.04440774209797383, 0.017142778209921335, 0.059436100399902755, 0.02880664688775376, 0.04627515802219991, 0.04710262874141336, 0.04197519843376452, 0.05056932981636736, 0.022903581285068107, 0.015547482462059108, 0.043026769023028114, 0.06549585971140093, 0.018305810761728117, 0.0552191540989424, 0.008908109645539475, 0.07367842184800295, 0.012026808577619735, 0.04737785348909036, 0.033420727423001687, 0.017232837591079936, 0.01815407172656588, 0.05088071008363078, 0.052379273824513926, 0.037447496227199034, 0.024124918873572064, 0.020664396297727382, 0.07170064329740501, 0.0615366751838836, 0.01749118350656523, 0.044512868513383215, 0.007850185793358833, 0.03590358774207773, 0.029724192309884295, 0.021358412585311362, 0.05739137725604158, 0.016687509393499746, 0.05384650073885437, 0.02741783481812285, 0.05802176419585463, 0.04171775458681007, 0.057385758001116983, 0.02566889439138674, 0.038575568356581276, 0.013263538787742297, 0.033892905715131955, 0.06895581155174202, 0.05582080125027607, 0.04694502530319076, 0.00768033835488642, 0.01873943950950859, 0.09495573253521035, 0.011729805865475248, 0.03270794389649265, 0.08561793279143111, 0.11285913837773186, 0.04673423621082499, 0.07832164245267069, 0.06302095138497892, 0.02447431050841847, 0.033742959325712536, 0.011512825825071384, 0.05741122659415968, 0.05933860038977958, 0.06634889861508723, 0.07266869498116356, 0.06395956614024698, 0.054931514896452434, 0.04882706584589136, 0.03804859945610647, 0.015373216611483406, 0.04177457149771433, 0.05213082768023015, 0.046036490990269574, 0.030333391172931563, 0.018241915198403503, 0.03969939252842338, 0.06553771875558362, 0.08047868557755025, 0.0574467730738463, 0.013287284640565276, 0.041159337777043545, 0.023461611220432867, 0.013320981975524657, 0.036582701704314644, 0.028582813233257304, 0.04133372237124751, 0.04516863594612768, 0.03266676667056257, 0.06101387380171688, 0.014334228058766215, 0.10455527387919927, 0.04304967888240372, 0.02657461716162582, 0.04600728388815638, 0.05779499450938837, 0.01205636329212857, 0.006195114119984811, 0.013237770462799217, 0.04832162018564921, 0.04378031991842774, 0.05162539351130686, 0.016111840283678427, 0.02813425534705241, 0.02480798584949826, 0.044183760971551946, 0.007884697575542715, 0.0622057993595879, 0.05525589184535127, 0.04461091627637225, 0.0778223293262624, 0.031264705110281225, 0.05588612939801909, 0.05550962782675221, 0.05264439770290929, 0.05268455603190007, 0.01601395722959311, 0.06514935814324888, 0.03033882465153452, 0.07248808209213518, 0.053799665953603484, 0.05052079431592457, 0.062204071831318646, 0.06119606866230888, 0.019020997889099583, 0.03410190599219453, 0.02230404853640545, 0.06299044959427369, 0.023134104802363345, 0.026923384434813936, 0.06678449620883312, 0.05455796659413365, 0.04215745458139047, 0.026588458455197757, 0.05002480601110766, 0.04480741016807095, 0.03315472637393302, 0.03593046976734073, 0.02492157562125114, 0.016058802101460677, 0.026716353003716758, 0.018449944459022056, 0.052865820095664075, 0.04825324300796755, 0.011345998688240447, 0.030276524466312224, 0.01696648797200572, 0.04246842116117478, 0.022710222608199524, 0.04689200052751168, 0.04687655236451857, 0.025280478237677487, 0.02803941366202649, 0.019134928569978765, 0.05671148571456152, 0.023103576198580767, 0.03960515988329726, 0.09573881995053062, 0.04604410973467654, 0.04113510641599855, 0.05668201814255407, 0.08651160499862126, 0.020977751156615636, 0.009443923988710008, 0.07572045219281028, 0.03721467827657058, 0.01549424413937114, 0.008840570376525003, 0.02991916934749292, 0.04362080509083406, 0.018129254308258815, 0.0576237049103985, 0.03067748722500138, 0.024924053915686188, 0.03110454293839153, 0.0722206637804066, 0.018419603546780926, 0.0236099852143877, 0.05465606032239814, 0.049627470678739974, 0.0867398762174191, 0.03149808230509441, 0.012573490835606091, 0.08121836645108077, 0.04852173001235051, 0.06208364280962175, 0.05739792730779417, 0.02158052828763762, 0.0434890532896163, 0.019723496685225158, 0.045346579018739924, 0.007439914587584715, 0.08217164795965919, 0.016140792661556796, 0.031570659559820934, 0.02575989606069221, 0.04064850651869371, 0.09270416948223308, 0.02214297471988586, 0.052185453579670964, 0.05542026750082451, 0.03291929223304314, 0.04126288605132892, 0.04131613299250603, 0.030550659453916936, 0.013474555791265542, 0.04652164681183715, 0.0204958071586706, 0.05728442372093278, 0.0289764272935328, 0.005911307751141008, 0.014688950707955707, 0.05222750797627434, 0.024497028845813007, 0.047771569056015824, 0.07976224781164239, 0.05445436086325396, 0.02864251063475686, 0.025329057788175922, 0.03221095584693455, 0.01486253857071842, 0.012326619959616614, 0.06737275214325036, 0.028641445772542108, 0.03255342013172565, 0.004783708202247058, 0.0320593566228185, 0.0504557611120324, 0.05849625990395585, 0.025987755507230762, 0.11593057638815335, 0.018415686922268044, 0.03483484912243101, 0.07566194605803298, 0.008082030333518501, 0.022698428684605226, 0.0410255290297491, 0.011424325432838693, 0.08358831307099712, 0.024652437442132545, 0.016000927031611004, 0.034773374396947124, 0.11094796351127087, 0.03688951225710973, 0.04256921151893274, 0.044740867770967946, 0.023337079797901457, 0.05882668128657726, 0.03280977996426725, 0.02923377537949672, 0.04467781873479967, 0.020032525062561035, 0.02270974763368647, 0.028532176736682176, 0.07708126183358893, 0.03111140134053365, 0.022516293195827354, 0.035024409918414975, 0.017785370845587987, 0.02910231852212981, 0.025314256969478824, 0.015406552927508472, 0.042101262032144496, 0.0766896836519722, 0.06714144721627235, 0.05128458397643221, 0.0319963037562106, 0.03479780111041281, 0.02576394100493241, 0.034985304960320075, 0.030394013625599688, 0.06465788975718521, 0.03619006249092279, 0.02861566116823064, 0.05560026368907383, 0.06418666141408105, 0.023741662322032838, 0.06614934037169141, 0.03733886112909644, 0.04664083094065709, 0.025188923069846728, 0.03150921739307383, 0.042013207886127696, 0.0943148923256705, 0.04804779737887364, 0.05363530561988873, 0.10396992141801505, 0.024171056518811854, 0.014249060149004143, 0.03200265270988307, 0.03500932181674627, 0.06024222407910613, 0.02743957447819412, 0.03655606099674779, 0.008622544626104496, 0.0883064953790557, 0.029673599863364816, 0.004861999036473853, 0.033663604108075944, 0.024504193683124842, 0.0323305000370789, 0.02138637670976741, 0.0171478190684631, 0.03964653246164803, 0.05441293082830887, 0.05068692048230479, 0.01838186797085068, 0.02192940472835495, 0.04067562986165285, 0.007296446429174995, 0.04699244997614334, 0.04495139256299985, 0.05885701836837877, 0.004619097932347007, 0.056380233126542265, 0.024771223205231854, 0.0761884323231155, 0.018832783492642547, 0.04509566224090034, 0.05758554607089009, 0.0336872915466947, 0.020733664052621014, 0.07216341402982512, 0.037326312608896725, 0.09348296680517736, 0.10100650946579634, 0.17041555395530117, 0.09996499761097855, 0.11623544107762077, 0.07797256682909305, 0.13649969241551815, 0.1577806803247621, 0.14902688472742034, 0.17815840460600393, 0.1969972267867096, 0.10480449760272618, 0.20723856595014373, 0.1933407810546698, 0.15541003656483468, 0.11094358914922323, 0.13945172030118205, 0.1253625359987059, 0.09563532913283956, 0.110058780579317, 0.12357418034826556, 0.10790362203073119, 0.2716633581346081, 0.138946040984123, 0.17841357317182327, 0.14387998429517593, 0.13825365071815832, 0.18399728161673393, 0.10511893073036786, 0.1452537025174787, 0.09695791098619662, 0.10881174265617326, 0.19342760946000778, 0.14054644462322036, 0.1990787796075306, 0.1530654857596082, 0.09951407825874706, 0.10510100427293971, 0.1835385481676748, 0.14897682854244787, 0.24497526036875866, 0.056959679049830285, 0.09169445793715217, 0.19133470321614898, 0.17877262326017504, 0.1005008684531335, 0.17511905801873054, 0.15370314670426233, 0.15657527161942375, 0.2630870038222882, 0.07864533758331692, 0.18875733829073368, 0.1861744422105051, 0.11669075011365837, 0.07643026329817311, 0.17979296044476573, 0.11948310995414374, 0.15897468964178718, 0.11361739688342619, 0.10095903499712867, 0.16352678408786175, 0.12544339657911371, 0.13577812952139687, 0.11758996113654106, 0.18652299689429422, 0.2199846142602544, 0.1720443334911139, 0.2044894134685878, 0.2528053531122785, 0.0782393875922407, 0.10982321620348001, 0.15362263086342043, 0.0719104134928315, 0.13881064260438566, 0.21802303080837573, 0.16216860212866338, 0.135577812850956, 0.07596741595696058, 0.16923240776504242, 0.2019068391452874, 0.13161791969210873, 0.08470996538357389, 0.32228758198118984, 0.14648285994846977, 0.13419925295297178, 0.16374459820649317, 0.15622837168555107, 0.11299806842280012, 0.1426274765042528, 0.1915591056909292, 0.21664519103304034, 0.18663723592556294, 0.22502637678577056, 0.13723170474892663, 0.21761560992848492, 0.15808057310360094, 0.11653544876964823, 0.09616788281428237, 0.12683943860353003, 0.22502574859367264, 0.13199935486960795, 0.15620209486974826, 0.15488450024877826, 0.12301203269030779, 0.15321920896249433, 0.20133333040341256, 0.16983530363969265, 0.23245926826230942, 0.13120401770837847, 0.12719613680195424, 0.07712594008133297, 0.1226494892410213, 0.10104431590485959, 0.14099131188085004, 0.10575763355459898, 0.10823920684596224, 0.11659743294360177, 0.16547289256366993, 0.12398846537595797, 0.21960579910345618, 0.1471949999611224, 0.16953772444638515, 0.13704857909150664, 0.13001828214093564, 0.17752406848294122, 0.15024825870510072, 0.14571211420960967, 0.1144393862435414, 0.16464787715625379, 0.22722543217241767, 0.11686300498343284, 0.2275033841931051, 0.11728711891919376, 0.12932855786094744, 0.10114560805020795, 0.20158590959204783, 0.15890336685603665, 0.19398886079509414, 0.1856321745341824, 0.17118266843740018, 0.14292821197980835, 0.1978234679348046, 0.14147423838655795, 0.23236874731317644, 0.08916354858346524, 0.1374691766836951, 0.08341484778230229, 0.1462221755495956, 0.09634224442584861, 0.2082192044584982, 0.13969596445320115, 0.12503708652671308, 0.11860205521506649, 0.0813718751493481, 0.08479972024478259, 0.14008317593364947, 0.16112257035509234, 0.14279895762522377, 0.15644102237157284, 0.24829372343036438, 0.15286248778143238, 0.12505782452682335, 0.12853151998452603, 0.21217368903660008, 0.2249690427655174, 0.14684313577750038, 0.13526046858920207, 0.07937573347120516, 0.21834679488693515, 0.11691380427369188, 0.16982182049222533, 0.21201460321824397, 0.09266300757806148, 0.12964786330778755, 0.14997620556143024, 0.1503740043769921], [0.05911465373731429, 0.0633524069862981, 0.024250400245129585, 0.03170675507956936, 0.03483813563962618, 0.05532510405887039, 0.044706248257669716, 0.03692323161709694, 0.002998057320984381, 0.018970581642802686, 0.04739158561513309, 0.04961701740901317, 0.025134090326666355, 0.010987206196953214, 0.017766113310391386, 0.06731233844954161, 0.031701289042229616, 0.04130407093813823, 0.08933967219725733, 0.08052767690030799, 0.01240751501398101, 0.08303435489294991, 0.03641846394466777, 0.023531353949839552, 0.04736410987172877, 0.06070238628214406, 0.05551517813376362, 0.0406304651480769, 0.018307400394170996, 0.025360547832303473, 0.014479560683661652, 0.06373497214348567, 0.02252903132278833, 0.02881928350806477, 0.054378828424359524, 0.07797210717633848, 0.09509606452118005, 0.07552261764724409, 0.0198689193254517, 0.05651757353916765, 0.09404411854883356, 0.03365213194140985, 0.026692554482348987, 0.08457347149810485, 0.08365624974812232, 0.03740630367951047, 0.08819941160899979, 0.0686007068162003, 0.08853748620998475, 0.042102740581838355, 0.05407594407217638, 0.00737435421943965, 0.03644864014800518, 0.055716237909491026, 0.061737175715426286, 0.03477015299722552, 0.03889735975873567, 0.05617835363673587, 0.0037615149302573335, 0.010151923296131916, 0.02587754226800415, 0.046517364380340424, 0.054155697655533595, 0.029031206410558476, 0.01095917312458398, 0.04824930148559713, 0.012301887768591124, 0.028200278719586712, 0.024393269897348458, 0.02453644789995686, 0.05083009082403395, 0.02046508128724752, 0.017680548950128498, 0.03877332629335504, 0.03822292659371611, 0.026092927887915604, 0.05816770777586968, 0.06226171994762075, 0.06186344615754582, 0.05049256397591484, 0.05582123025951367, 0.03256231824296617, 0.06711289511933442, 0.013317194628348995, 0.03870967970860582, 0.013828317957719969, 0.02870999915044635, 0.03287725315819825, 0.0394130212014481, 0.04311075524216698, 0.021791487834566546, 0.002418770360940647, 0.058908419037658366, 0.0208237923816928, 0.023355425688468164, 0.08802187073254779, 0.09700845746744065, 0.042029100380116896, 0.022838007989189318, 0.06971197097652382, 0.030292614227941925, 0.016515028527787617, 0.01827326543148487, 0.04777238493965519, 0.03778261372879629, 0.014685656529881302, 0.08294209492422881, 0.057702918401769096, 0.007410814258975969, 0.010987262695937628, 0.044555639202195796, 0.07321875377167618, 0.06494579326000906, 0.03480771045771337, 0.06528245059833412, 0.05000846152524314, 0.08526772335772553, 0.05996704146626496, 0.034108750987797976, 0.012497313925245357, 0.046930159367020094, 0.06563071416871202, 0.022498943219562213, 0.02539214704396023, 0.013485195794923893, 0.07885976559332303, 0.016435368790201122, 0.015907096582645133, 0.055893652381435524, 0.0920939115026305, 0.026247204589327017, 0.018178444813876864, 0.026276390624022292, 0.02064016493668239, 0.024485351750627164, 0.02725274670088003, 0.04653428343214816, 0.027912944037046646, 0.04826227518459482, 0.034860700759435856, 0.03431012485957435, 0.03718988767134086, 0.017510008202084613, 0.02548985389782296, 0.06852298719628204, 0.02881360296610623, 0.04858143124428969, 0.041650691249918555, 0.05145438353440935, 0.029583440890776056, 0.04259829604697805, 0.0448326182912194, 0.044219054642223546, 0.032362330990332755, 0.06039790080619916, 0.029908603079797282, 0.026486959466109836, 0.03571285100113, 0.06457237902307703, 0.04989508434288925, 0.030244402399647142, 0.03402497161239867, 0.0316703946314632, 0.055757300222232464, 0.06388668053513093, 0.015753267085059516, 0.025940838367528012, 0.03678373849740432, 0.011514216274653953, 0.03298471997221632, 0.03328378920653655, 0.01904209786575408, 0.11606173064079016, 0.039625135625922875, 0.09232225933022077, 0.06392593488037106, 0.08883911034753246, 0.05039508694842939, 0.03593893503890403, 0.04300610380127065, 0.04228733329763336, 0.09697346257105952, 0.031537813540067405, 0.1262076841967721, 0.06563075247310823, 0.04155421013673467, 0.03148956340737641, 0.09179936601750313, 0.026884164563530398, 0.01860119702835237, 0.026680858234965035, 0.034641668561004826, 0.10331738304587142, 0.011174941788457576, 0.035212124442501415, 0.0420499341412177, 0.039099855949321104, 0.026115244029149897, 0.01455200291539152, 0.07981986528442753, 0.055515978695644494, 0.029007294891221874, 0.04075880402759199, 0.0576395629304311, 0.01415104877519151, 0.009267794629258495, 0.05657633631339958, 0.04042136911002379, 0.04435745608662406, 0.0278377850660153, 0.03363242815999735, 0.028396987115904212, 0.03144402331071756, 0.027581566959739696, 0.05541218527322335, 0.0385313842355484, 0.06055030633785552, 0.05322514980610821, 0.08433692652972476, 0.10126877966667376, 0.04359994068621628, 0.07205767091363668, 0.03262968801502739, 0.06731449115660883, 0.04571265030291773, 0.07214027051363262, 0.031352477718985854, 0.006336713023859287, 0.05292075626071423, 0.045379677847508466, 0.05924133786691293, 0.011486608381082695, 0.023790113552803957, 0.026949140310828245, 0.0327692156086766, 0.03416692770476784, 0.033035392857967846, 0.078235863587789, 0.02352927019068551, 0.04723545306572511, 0.06798827314689275, 0.007724022603548704, 0.04934432841236553, 0.06130937689674958, 0.04769551184689326, 0.044616152487334707, 0.06165413178443428, 0.0387763791537333, 0.01676719977460321, 0.02608214520038136, 0.0729758732561623, 0.032334728842420925, 0.029392319190646374, 0.06306765593528267, 0.12375096279767253, 0.012935936608682237, 0.06599575506463166, 0.040187739106195594, 0.0485826684762874, 0.01160889420838606, 0.07815504131177742, 0.09706772969014223, 0.009415182285010815, 0.007115812951533665, 0.05236170359797055, 0.046180308676294746, 0.022588855128795392, 0.05058234181976126, 0.07491200726719634, 0.03692147727575033, 0.02754754882546202, 0.03961174057856683, 0.07929452815123143, 0.07055059210547517, 0.024032139880282265, 0.044312597808217814, 0.008929219198293023, 0.051729389947027936, 0.12148804632165741, 0.08174708969290219, 0.015920776997752968, 0.05453629396675576, 0.04692128423841731, 0.03403466645508044, 0.044338851641382904, 0.0434411421508318, 0.05166304290234562, 0.033670648286539706, 0.013689513359549306, 0.03880329565295289, 0.01841639172315838, 0.019349502136690483, 0.013182939634838653, 0.0257063637517633, 0.023711260122757767, 0.007944245589897037, 0.03444239377014099, 0.04473267063017815, 0.04005062851994749, 0.06391458911821246, 0.037603567489573074, 0.05889493205975141, 0.012885088480318026, 0.032988056285126556, 0.07832796267804601, 0.07070129692193962, 0.03117438142878875, 0.036378558424692, 0.008255962935847141, 0.015549944477125764, 0.09414588566869499, 0.013419090067937732, 0.03948868770572928, 0.09673525519188374, 0.018353672104797537, 0.04668110035239689, 0.056050719558111126, 0.03737174162280656, 0.05507879146945573, 0.06445479984845846, 0.03932670607501942, 0.024065453213669603, 0.026344861647474672, 0.07218034457295172, 0.009037576589523064, 0.015046763564309767, 0.0977966623500951, 0.01696038799690864, 0.017510320382913756, 0.04296336758641466, 0.029495543792783737, 0.03555094214877294, 0.03645367717610733, 0.06499987140658402, 0.030291172067424467, 0.019161429466499437, 0.06880844687862743, 0.028934074122638955, 0.09219517300446188, 0.0787991986820294, 0.11338882689033786, 0.018672278496406732, 0.005333979103353716, 0.04700392214280944, 0.048939600331528534, 0.06787297691428854, 0.05410014095926478, 0.03565798761443265, 0.08934273654895444, 0.04373639626728912, 0.03940729086377448, 0.01689373834749624, 0.13769377834133564, 0.12594728325042995, 0.1135164954429192, 0.06313357397072739, 0.13379748580196213, 0.10042290368507947, 0.09390666705345917, 0.1549742091447115, 0.215470640349292, 0.1267758456449355, 0.11666665664843975, 0.15915079793382078, 0.14113438646158866, 0.17271367983231622, 0.14260840091493823, 0.16782223907930238, 0.1971880286451309, 0.14918716564293832, 0.11751303824806407, 0.19329613345044275, 0.10617766424172348, 0.22928541195729088, 0.1280228376028038, 0.11996821981043586, 0.18584834922465587, 0.19214940708010428, 0.12121368725333484, 0.12289554902142096, 0.0937588963537447, 0.11882196075373119, 0.15221275329109163, 0.12132611831710224, 0.15146689008801215, 0.15164721186362928, 0.10272485234083668, 0.15630217659617626, 0.1662737762014712, 0.18500716936203743, 0.22528536046945283, 0.2641036331413254, 0.21907834756758907, 0.16160903618701045, 0.17535358817586977, 0.29351007133241624, 0.12491955331736997, 0.13264248568204143, 0.18667967719656808, 0.19745764562920218, 0.17803169366332794, 0.1401227367140593, 0.06517620186411566, 0.07320251270768142, 0.16090673274330555, 0.18522302229558268, 0.12355968596473818, 0.1590897560480141, 0.13797209808422675, 0.10651602995611968, 0.09830125382230168, 0.2688802526362481, 0.13954444758353696, 0.20008744161215522, 0.13437853284901188, 0.07912321556960383, 0.14748520938859833, 0.1688478316270536, 0.1767898498163108, 0.15495403038878597, 0.10610814942347427, 0.1325459586035821, 0.16004899005976417, 0.10718421950455635, 0.09991156297825998, 0.10305396371310759, 0.13042159678955234, 0.14207725683527608, 0.14516981588977, 0.1971120020795253, 0.2402393507861322, 0.08160953094521839, 0.17731590707215572, 0.2117184795919926, 0.16326602308019517, 0.09049576016203051, 0.1676673820662883, 0.17024575822776364, 0.08974680196373694, 0.16826110020760568, 0.11611397783722609, 0.16740306641065306, 0.06262614414276135, 0.10363177020823765, 0.2479035088852529, 0.11654069647192956, 0.09733310254711298, 0.1174605152599754, 0.24548827880813232, 0.08205736296311503, 0.07566206097122162, 0.24296470857676, 0.08304643609951581, 0.13179100959772064, 0.22469337368684433, 0.11103751918961925, 0.13950248128704487, 0.1155044859455478, 0.22515227567524682, 0.12429302363025567, 0.08421239127675373, 0.21304123764557226, 0.15720844328884157, 0.23787938629186925, 0.142394631740547, 0.21864204517295285, 0.1485986109342306, 0.11305901071717663, 0.147358866168126, 0.13537187309515092, 0.11148669952226263, 0.15620068526796757, 0.10471564672526815, 0.0968806280363952, 0.16581018575497214, 0.12320116447705416, 0.05288719011831188, 0.12725419860573547, 0.11759542334344118, 0.11497831377651423, 0.255023637305825, 0.20112884621466362, 0.10758425529685714, 0.1348297433146546, 0.1305021432739112, 0.09880532435471974, 0.2521274725515997, 0.11953400117495369, 0.18735578043326256, 0.21437724902024194, 0.08712182467382762, 0.177100544434882, 0.1411264497906931, 0.0690346113556335, 0.12188818170538834, 0.12483745933540406, 0.11323238407532055, 0.11858897809419902, 0.15139020468679168, 0.19842539853867025, 0.10464797817891645, 0.11465672538765978, 0.15571305498240456, 0.10248316692248469, 0.10016712990979995, 0.1838246207203596, 0.1128417864862469, 0.11797011694720677, 0.07328985439192864, 0.1291801666300143, 0.2033926513526709, 0.13849339027318264, 0.10327052144754319, 0.12332022220136658, 0.1845303102726898, 0.11653023937176313, 0.23882078577674207, 0.05574254919925044, 0.14573629194449994, 0.1767888079367338, 0.1176254922944692, 0.24900491349399093, 0.12795443361204478, 0.18061339464639464, 0.24713238010243063, 0.1554739742629951, 0.16965545683858857, 0.1625459310748885], [0.08716766737521657, 0.04337861022401241, 0.06926056132802079, 0.020311880939369722, 0.04190968259448006, 0.017207495402544737, 0.014396007304200003, 0.020700701204459035, 0.02973605326617197, 0.022841983985516335, 0.0708304057198186, 0.04383038376427947, 0.06883721348018416, 0.04648683577655785, 0.0649711048050273, 0.02230528193796354, 0.10209790130536403, 0.021929883533307624, 0.06461331876175058, 0.0562036115555994, 0.019746054144155596, 0.037681899979830756, 0.015774281834432437, 0.007980166973861596, 0.010265561905989965, 0.013704550707893027, 0.05769557927945449, 0.017554125290424112, 0.055604588255406394, 0.017969385165000157, 0.043218915365756526, 0.05657126098090122, 0.011167040549128527, 0.03637007017049097, 0.10807507250818515, 0.015128209244369742, 0.07004803842714719, 0.009746886864905397, 0.07514805427842564, 0.026660817374865857, 0.0070971845660448805, 0.060365759587335976, 0.02835459181017453, 0.022568808523036783, 0.00592431927572996, 0.1010663485935619, 0.018762699854109558, 0.003181988807139738, 0.04292363443622186, 0.03981246327560756, 0.008214181458066789, 0.021090936816988454, 0.017846600422936103, 0.06706447070164066, 0.057853221022073305, 0.0584075699049619, 0.053472316583558444, 0.019111840595160762, 0.05219072426459001, 0.05744145642365179, 0.04842880354713529, 0.07545596799783169, 0.04594821084831511, 0.048827762985902454, 0.005317973132590734, 0.028141119494853963, 0.03835248738347042, 0.05985836040288691, 0.11843646531023326, 0.04009216580720198, 0.029008066724805586, 0.022422282716199275, 0.08222360404268389, 0.024854506538700194, 0.015338777128847377, 0.0629422703247157, 0.04146549332466337, 0.07493826876124067, 0.03776575596402249, 0.03855057856849125, 0.011464475143340327, 0.0807148475019682, 0.04274879018926332, 0.07844594787926444, 0.013362007899089687, 0.08337115778798058, 0.059102679783057784, 0.05628871626310772, 0.04855450708419085, 0.001076268904838681, 0.03629156148001071, 0.04773155628373066, 0.1364538803576462, 0.010108253411618213, 0.08372824669124619, 0.04363517690029356, 0.014812132858130482, 0.05466440301989356, 0.09365169000962088, 0.0539366539657837, 0.03496346379359884, 0.011877989295058915, 0.047053430574916066, 0.08711024142441251, 0.050202622679212404, 0.06637072446004999, 0.025619414687577276, 0.03939340168970727, 0.051504183079927206, 0.061654813602686896, 0.009355464773703246, 0.02806001759675001, 0.01895518327552465, 0.04823060894024469, 0.01712873007260984, 0.10186479607176396, 0.03213309833118993, 0.07682986242035705, 0.023747821668944052, 0.06868575023667467, 0.022205924164623986, 0.022056759184887333, 0.03754212723804578, 0.026773598923858617, 0.028206487862213005, 0.052574358114431945, 0.030892058876493288, 0.02740327340190209, 0.01689841722949378, 0.05588309185939932, 0.07594210441194235, 0.12346360321727493, 0.07873595812388005, 0.024879166908982783, 0.0037553838328383267, 0.06968870488626343, 0.023775801115158587, 0.03370745881130138, 0.0450967462553132, 0.0475677322115629, 0.09504698892875064, 0.04679111823920281, 0.02137838066705773, 0.0911772873012289, 0.029219009034756212, 0.06302183621653146, 0.039732318987408956, 0.0402572883984014, 0.011014079603727066, 0.021606008371999188, 0.04725015812343167, 0.012348950464999484, 0.09297520372896426, 0.06303695113127751, 0.051011481292305455, 0.015760850397899987, 0.03534964871622863, 0.07625545735561079, 0.04756168011696108, 0.029240980436424577, 0.020073598866621335, 0.049137752803583304, 0.018658898770809174, 0.00608757117597927, 0.029826660400196433, 0.11983190978606863, 0.048417917437731266, 0.057054474769580754, 0.060870017811295495, 0.05253588517887458, 0.08421610680318649, 0.022786787350571925, 0.04054780043060741, 0.020563615516068477, 0.04409039017534064, 0.0661688449702436, 0.04299327182853895, 0.050795436836779125, 0.013777316611770903, 0.08162625464460543, 0.02727730364929284, 0.04266306112009672, 0.04242119567108251, 0.051924474236945954, 0.025187557518121698, 0.020850078773594672, 0.07386653473781002, 0.017777395870296225, 0.034813820008909514, 0.035842519043193716, 0.06613528265828086, 0.04348494322790254, 0.02999141909963181, 0.07419964508904565, 0.05630652780734724, 0.02877837824334781, 0.0786572196070225, 0.019584455557407874, 0.028377559126144456, 0.021908199414610866, 0.043776477987487475, 0.045836538211592746, 0.028242545705589078, 0.011304076441804008, 0.02714968680764639, 0.04725851614268557, 0.025003234848320007, 0.02804154913211542, 0.01978916191165486, 0.06915575283909998, 0.08744544319568143, 0.0429087340260946, 0.038972926671586694, 0.07581330204923308, 0.024665056825465253, 0.07573611102998257, 0.06952578862828594, 0.10971990924689079, 0.08039076932735982, 0.01505591831500492, 0.013644306511137516, 0.026136518290807164, 0.01822913110616707, 0.03510255854757082, 0.03059004977976363, 0.01655552010502546, 0.02586413381410943, 0.045889386787049236, 0.04367364217497168, 0.06327542664122678, 0.04936339251036125, 0.05481164128850064, 0.07584626681261486, 0.033810252488981334, 0.01678265751369538, 0.048344457266672004, 0.007869194828784995, 0.06136939988561696, 0.0707499358442522, 0.03238866143229027, 0.028223006633080305, 0.01785102649591863, 0.04284593013806209, 0.09170345947026246, 0.025400761702668764, 0.022772716230622703, 0.08444092296544584, 0.04404455513483094, 0.05296249273082903, 0.0679490341234111, 0.021364439782055638, 0.03754799930198539, 0.05085146467712137, 0.053932191503624764, 0.03093685395264578, 0.07378583503586632, 0.02931820784485148, 0.03153427804429685, 0.07138126124177249, 0.03862783087477569, 0.09040625044895757, 0.014301269998653762, 0.036179819895375165, 0.1043254245192774, 0.045252369356251536, 0.06643973366026917, 0.05842526653601278, 0.010590673341686207, 0.05413101430261328, 0.02791389015563313, 0.09419332949384567, 0.0941148744295201, 0.044682618275645285, 0.03467377913635104, 0.04399872775520048, 0.04770015050927478, 0.037568040162084565, 0.036191261418524294, 0.06566406963693519, 0.007876472664065659, 0.04593296952906155, 0.0478856587001393, 0.040100485522059665, 0.009652518239172717, 0.02376078387662288, 0.07247552591105623, 0.058018665370200916, 0.03321069675768095, 0.024867079956757448, 0.041120772910935265, 0.06945291834492838, 0.06431419973171527, 0.02698247854207312, 0.045252074412400686, 0.029271261976851575, 0.05296208287378954, 0.004608157239178377, 0.011905418115577871, 0.017276401180894147, 0.041635817652868654, 0.05848943406055051, 0.10447484996890831, 0.05579334082863024, 0.027313422779702855, 0.009793407554107328, 0.053469079862078356, 0.06790914392519383, 0.03920139707324486, 0.055817135519558386, 0.03612227903138246, 0.038760042328748016, 0.008415277622970603, 0.042606443392052766, 0.04764507261795863, 0.02266041731702224, 0.01968455260559436, 0.06460570384778323, 0.05468848882423294, 0.01235297146899205, 0.04403662612481464, 0.029304123318363583, 0.06370415625673148, 0.04077029151601657, 0.05343854359741654, 0.058914091918737664, 0.017514928401778304, 0.04889679133831974, 0.024864339277208335, 0.08914801232036083, 0.04254666555132117, 0.031142845419385744, 0.030394396669561827, 0.08061723257865637, 0.028273509064268683, 0.029573520052156625, 0.021211593749842817, 0.04857964625942612, 0.030069533254831072, 0.0335400877520442, 0.034941657100834196, 0.021432531591985497, 0.023876037974391254, 0.010801847393233931, 0.01201200680131273, 0.11034312177329295, 0.05758841890060614, 0.07557522490500443, 0.048297768038126736, 0.046617771694136244, 0.025412417730436693, 0.01908921418831714, 0.033983618186246005, 0.12372943572700025, 0.11355455469099746, 0.12494509468876547, 0.16111734563544874, 0.21463488438917747, 0.06916143721149814, 0.17258963487561674, 0.15060634352266788, 0.10721592788374233, 0.1304228991390236, 0.15499162998410965, 0.0805643495292433, 0.13706875784743217, 0.12958767944045607, 0.2355238651075671, 0.11422144188996285, 0.2627432448489051, 0.0877473661075196, 0.22091787789137135, 0.09121884757112111, 0.13113559073498174, 0.08692963619626339, 0.0612768066686488, 0.07206487214012493, 0.12049832967140021, 0.1495328091926152, 0.13426614775051995, 0.11203331091711599, 0.09507439189380217, 0.09348734882810424, 0.07969371358593626, 0.14797176715106736, 0.19459687413707857, 0.22726359867280532, 0.16901163654702325, 0.18096355811482479, 0.1514683303333098, 0.17123603412220556, 0.11242822158120333, 0.14879616968814405, 0.18418665855161606, 0.20246753889706828, 0.15223614961629914, 0.11313977170615427, 0.1089660251032441, 0.2192009676007494, 0.08674655650411883, 0.11425206242429634, 0.1480797702266324, 0.14227712917472088, 0.14213711894567937, 0.13076834350584016, 0.15800166604740007, 0.259077575418257, 0.1403470012930132, 0.1608693323308422, 0.16308839793407148, 0.12134542373279411, 0.10996422234682307, 0.1275430290749477, 0.1255494384695926, 0.24100962155047925, 0.16716381715190026, 0.1488345506931505, 0.1722846399512022, 0.16698348005452465, 0.13388998325793974, 0.22315024278096615, 0.2809203356023758, 0.11080121936937494, 0.15663009287128526, 0.1050265864919751, 0.22808850682791204, 0.1465101633220911, 0.13289477375726547, 0.21796960383653644, 0.2457039938458512, 0.1399599736736667, 0.14551939713137765, 0.18350407421108217, 0.1408389829579861, 0.19271628150055486, 0.2046352612876123, 0.129205524140308, 0.12881446689847978, 0.17858510025806967, 0.16244941931818763, 0.12438408850181489, 0.14697255867142833, 0.13837712876979383, 0.15402046032249928, 0.14819641477398335, 0.22024745902707502, 0.1347586350335229, 0.16859637092678778, 0.17279012008540093, 0.2722752172379725, 0.14030105133931484, 0.25853184502451654, 0.20420605286715493, 0.17623400706196987, 0.0779481286243085, 0.14272038764770956, 0.1888010972329686, 0.1735433377325535, 0.19139418228259011, 0.2438818690397086, 0.13011995733024614, 0.14942096035567023, 0.13902381423019594, 0.2651883523550726, 0.22035196874170537, 0.11722879664551829, 0.12358137391387455, 0.11988839344872583, 0.13021695938321853, 0.10909511091848535, 0.14079658765225642, 0.15796535347978916, 0.14657411634201004, 0.14476164424371335, 0.11510459570995263, 0.12241705050391537, 0.12372285503173068, 0.1492361799483338, 0.19273076056232377, 0.18275886984361758, 0.13282332839744707, 0.1032617190972932, 0.11853642446259338, 0.11541700636547421, 0.2114028973324645, 0.1875076803468889, 0.16803223910110612, 0.1532742753624916, 0.14945669069645867, 0.12122678735684003, 0.22484435429496152, 0.1017470023925266, 0.1449774205684662, 0.13302854803060332, 0.14084745589042866, 0.16954838839029113, 0.2937943818828752, 0.1167259212102621, 0.2142779640252552, 0.07558954308830923, 0.11618738438213065, 0.14383058694581832, 0.09742120265840523, 0.22384775051426506, 0.11012153084119482, 0.2739418261954861, 0.12424899655724726, 0.11354720024692436, 0.09486952466109107, 0.18597270061652507, 0.1470090091348656, 0.09667470360234862, 0.1758992266390593, 0.16933363862335685, 0.1035058559970029, 0.08420903581164538, 0.09259042840811516, 0.11097175054131977, 0.3533890050265097, 0.08825984062446703, 0.09402100567615802, 0.18661026963062827, 0.10656121382189375, 0.28384406420011676, 0.1067118650122035, 0.22104054388980712, 0.1024126561899339, 0.12122337826557698, 0.14325894745847872], [0.009260615427798082, 0.04170503369682739, 0.03257872401586464, 0.02630312517735987, 0.1341720721534183, 0.038760624555570465, 0.043251688607157245, 0.035372056788013834, 0.03801227156673709, 0.04390135798002443, 0.04260240993913143, 0.029967662713099873, 0.036932263793724204, 0.037133940270230655, 0.11226020317765013, 0.018953074618513067, 0.02888028134381579, 0.012043300535409682, 0.07480143779708494, 0.03486528196522305, 0.09237567864118085, 0.021424225283666484, 0.06253642758594886, 0.015724553152047578, 0.01739725538138901, 0.01947368498921635, 0.019364142076923482, 0.03403231073471327, 0.0035032513692239003, 0.03649362100047931, 0.02010055175501733, 0.05889520402096453, 0.010407547684266202, 0.0500710585695361, 0.013791594575459679, 0.014331945116751859, 0.03146497964588625, 0.09076300227353651, 0.0790051767422307, 0.03334863471888727, 0.00883123463755774, 0.06093010208719681, 0.019177469432414062, 0.017139097157445167, 0.058801189710896824, 0.05670340348696036, 0.013690891360203105, 0.028276682583495017, 0.06104405766593353, 0.031549699394212614, 0.026486457678519433, 0.048980670305149215, 0.02085070122003315, 0.04630725327578764, 0.029275827860880285, 0.06140336439373994, 0.04203088153454085, 0.02033836651413191, 0.030313651002342665, 0.009693451274576928, 0.08104972751630891, 0.07029369218094696, 0.04379302548665193, 0.006915466595185741, 0.001422219727593925, 0.1351103000342846, 0.01873500577564682, 0.055257002672841476, 0.03962956744456484, 0.024491666230343045, 0.09573351862209459, 0.048650777523195556, 0.023912344796342716, 0.05587268838538759, 0.03689241189990313, 0.02823897382064212, 0.020725430522654808, 0.031092590051552946, 0.04632817896743936, 0.04710248318470774, 0.07154348035973888, 0.029707393916924636, 0.03547257135411905, 0.05151945887313736, 0.03805270568738061, 0.013976148029248563, 0.00453703603031294, 0.013653812704667931, 0.017813641405213746, 0.043447209567192106, 0.05875929619275755, 0.02805943728514737, 0.07988873658882034, 0.034017410324586016, 0.01890378643668467, 0.05898303217104366, 0.11732027520455661, 0.04118382194710355, 0.07107426682787557, 0.03433164043892776, 0.04218171275551281, 0.024446794545398127, 0.03641235056303201, 0.019503311524468086, 0.03058652577531194, 0.02922875941881249, 0.0616642288232763, 0.024917852433939135, 0.018059274091595606, 0.004476394904251661, 0.04149639731152885, 0.03708466166450131, 0.071037617181578, 0.047142223995779796, 0.02509573421951744, 0.038501303793201526, 0.01699176887350698, 0.046629764800590855, 0.05644450024251015, 0.06664823214974135, 0.04337521645450785, 0.03029482247638366, 0.009595595033568962, 0.027717072591786424, 0.022627791547546947, 0.04001285272440122, 0.01972379737473544, 0.04403694788174283, 0.03355584618064665, 0.04000008586914309, 0.0023530558176008205, 0.006916784266415503, 0.07753338394386154, 0.02116330722797542, 0.04029655423496039, 0.05524587907618093, 0.06519994292888912, 0.04757742705424467, 0.018417749614004168, 0.02720991855547313, 0.04822566001225383, 0.023108458093878244, 0.05818261201643656, 0.021448006568055962, 0.030936549432695876, 0.019607620141018304, 0.006310353853604607, 0.0703105767587981, 0.0597578649889798, 0.03933607533033337, 0.06058536252127059, 0.04857652445113467, 0.03447217160775777, 0.03376188935832151, 0.0516580097046831, 0.07533881017157147, 0.02479694077684995, 0.01677544479588828, 0.042449671159228014, 0.044046523980796344, 0.03563148097225255, 0.017860692610303243, 0.06926567113447575, 0.07986369317457562, 0.05681666958656523, 0.05577613066341128, 0.10856356081222335, 0.08775206988737469, 0.059325419847042336, 0.07932702560097941, 0.03677181816930252, 0.06193971787128718, 0.05898999591027537, 0.020634306279281457, 0.015224877091485168, 0.04728832462381932, 0.021201512032759287, 0.04169121347067337, 0.08093724282638681, 0.025978211966914036, 0.03578778206100387, 0.04439865246475224, 0.023720548938839667, 0.07302905507986585, 0.02208299578107413, 0.02921596192003739, 0.015225330040970398, 0.03985687722301772, 0.08737196004198444, 0.04051421896644658, 0.06568533623771322, 0.04225884248772937, 0.027873413900153774, 0.03674380999479083, 0.010829034896056739, 0.01524462205012359, 0.04704977633551725, 0.02220725332717261, 0.044540125921729116, 0.0475738532540779, 0.03792978687992981, 0.02375469347762485, 0.02211091968591415, 0.006342739262993658, 0.04230048319685363, 0.029242367055567525, 0.03524444186158719, 0.057479324149748975, 0.06656942468497061, 0.08940339539079897, 0.019283737318830627, 0.027469856018621116, 0.033639985617370374, 0.0304925401935414, 0.08379960012051367, 0.000804495802214895, 0.028096050542268543, 0.0739619050235037, 0.031113783873978163, 0.07172529600680837, 0.02940609728196456, 0.03890736486702677, 0.03102317865517351, 0.02114688996375809, 0.05849358625710011, 0.011677025280322039, 0.01701789055650513, 0.012724245447785625, 0.02096011772781851, 0.03278390151418505, 0.02257981529128888, 0.06111168790788901, 0.04039583922994714, 0.021582372644315326, 0.026084353448823098, 0.015927292575548976, 0.047227684934172905, 0.034497444848379785, 0.048426394200613426, 0.012117142792821172, 0.052440097375262174, 0.0672024124932866, 0.01669438120218054, 0.04272029171848009, 0.02266587377826293, 0.0018586753398149966, 0.054564459189291925, 0.06694588029096205, 0.0360776505793535, 0.060994633503498576, 0.01886838551370367, 0.099387712055637, 0.03140173717251709, 0.03195771207702497, 0.03053351632139135, 0.05360255153068612, 0.06620926376912864, 0.055361297882853024, 0.004014689512851258, 0.007626529296694865, 0.018095711148494197, 0.021659810726921407, 0.0310744165307692, 0.030107255424222643, 0.05516205756594578, 0.04994070104834053, 0.11075261875145859, 0.060732830616254965, 0.029367193421949784, 0.02259915326571753, 0.08811448310171405, 0.01468691099885731, 0.03918987128042406, 0.035725679143422076, 0.10165779911462339, 0.07189850848648818, 0.020249883358877514, 0.04120171393057512, 0.004650823069706319, 0.027135941275064985, 0.013527597803922911, 0.06450307104856738, 0.019661221397860397, 0.04413141418368586, 0.015418831401714876, 0.014886050766724494, 0.02185929427674461, 0.09204200904576049, 0.01263443791803213, 0.028532238023716117, 0.00930446342775418, 0.07159178220336476, 0.020418349923866413, 0.05775375982686397, 0.10151072555492002, 0.025180605270208854, 0.04372219682761258, 0.06574185820476663, 0.018410799281311133, 0.02151445511938824, 0.01547228039858202, 0.03694279750268306, 0.024440014667268244, 0.12251891721520694, 0.05317660281434656, 0.041269413120443785, 0.04493140532905537, 0.04026095412911908, 0.03482844462738403, 0.0389892673270116, 0.028947624302799665, 0.022919854907799634, 0.0221837344278972, 0.03510959889559496, 0.06739018830440699, 0.06449936318301386, 0.006833393680637763, 0.008868892647085652, 0.03847752825447148, 0.029104488466175336, 0.016245490067728584, 0.0872712271408208, 0.06452901844656275, 0.010020827457699324, 0.047405172184470205, 0.01769742778232021, 0.09015638321157425, 0.04011881034520846, 0.07940010272807653, 0.004806495008749827, 0.08954911297487636, 0.025956964518334118, 0.00493489038724933, 0.11249503976995907, 0.02276453824203101, 0.01993346989395157, 0.055818882200025746, 0.016702597495168447, 0.06807918480086712, 0.05065312834396478, 0.051637463226553895, 0.0279339118635342, 0.06804615108957214, 0.033394370167966814, 0.07276892992517642, 0.06159141982695269, 0.06325039471830092, 0.061947999281748656, 0.039761732933261705, 0.011309922650276173, 0.013791342724054573, 0.01073357459503196, 0.13709566285533292, 0.11282086462503481, 0.20437865247649534, 0.06781273942080236, 0.2556715944721814, 0.07537545981786906, 0.18433583119223196, 0.14806979576185827, 0.18600895189710204, 0.1285986446084515, 0.11180075726682141, 0.16368917940605074, 0.13286627528648223, 0.17248736213772528, 0.20695365785110384, 0.05899537767794344, 0.18347246542332635, 0.14578069440059124, 0.21021293295967966, 0.11124830828198504, 0.25563920427474285, 0.0879998074003285, 0.1322017246556859, 0.15215309036354865, 0.19052948352069626, 0.13745708781624996, 0.10258167816866791, 0.08042210998434214, 0.1571746588113808, 0.13452261866581056, 0.16522976690002028, 0.16943879185184357, 0.1270627762160955, 0.23202322633756747, 0.13027623926679935, 0.08955102819468706, 0.07767330990323136, 0.16012061928068438, 0.22915464074861622, 0.12053474949132051, 0.12798945149106364, 0.12563972959234831, 0.12309244127884028, 0.22178387900273647, 0.09479548226320937, 0.24257401905713544, 0.12890534024805794, 0.1616913599953536, 0.14236412611940216, 0.12644704070783433, 0.11007371163296123, 0.15426452061341656, 0.12036437153696053, 0.12330213486547432, 0.07665209171752776, 0.20437563409007367, 0.15863993986239358, 0.09687649882248334, 0.09298746879663199, 0.10052681585112888, 0.1706404007610775, 0.11687949119556336, 0.1777748090605582, 0.1061240993740578, 0.08424883407931175, 0.20060816689604716, 0.1817917604480059, 0.131833772625654, 0.0980639044616011, 0.13955463655292988, 0.22202006390979215, 0.20339209976936543, 0.11470265235872039, 0.1796491504196198, 0.10692159690323377, 0.14047902888588368, 0.2485145252919005, 0.11934307674246451, 0.14043192980029892, 0.11360019054864684, 0.240693150628959, 0.1726089249695501, 0.13892701136008387, 0.10966873457354885, 0.1424174305171736, 0.1144957779756477, 0.11716912605709608, 0.08320172212176746, 0.16555780574919718, 0.15379662475278302, 0.19848991846365316, 0.1592639337984785, 0.2273665608898286, 0.15445331532147624, 0.1478750408897477, 0.10786918637853478, 0.18456852273835292, 0.11851459095675139, 0.13071914533934287, 0.15171458163569052, 0.18641306327715998, 0.0948330895194123, 0.09996958647764499, 0.10775723795015966, 0.10968168145946919, 0.2431346422001239, 0.07593946906948283, 0.12910568756201576, 0.13959379896761911, 0.07938526360498321, 0.1269677966352432, 0.21256660021120505, 0.19237344183268087, 0.2368361277565841, 0.10665677562956849, 0.15188975530045648, 0.09257262452475487, 0.09364654189876973, 0.1679807273490775, 0.06422627582064559, 0.12431911658495666, 0.21267265742344243, 0.07163319691655136, 0.11883293879368614, 0.08380881615824277, 0.09327056126729136, 0.09223644982182211, 0.17382046237828272, 0.08405488359952167, 0.11403402614016687, 0.10434273044548689, 0.07908246735291136, 0.14822214000648068, 0.1272569258787459, 0.10230218631125267, 0.13530105592743044, 0.17610004892753017, 0.08978345161003452, 0.0923755637279922, 0.11482791539521948, 0.1002612591330563, 0.0935587329008887, 0.1266710754604109, 0.09485292353577192, 0.15674799380283203, 0.20897197777465468, 0.1561825596276791, 0.2763948397290322, 0.1720040679098137, 0.07060055635989675, 0.22049561022750794, 0.14346798220949789, 0.21743645260651268, 0.1168020933325733, 0.2562446588830602, 0.0977687614278928, 0.1886674761772156, 0.30787216679703805, 0.07928263080576736, 0.08609561159485772, 0.11613549724701913, 0.1015893798021059, 0.22296967585721325, 0.13942257831654242, 0.13264562664253096, 0.14668739010249415, 0.16082710556445584, 0.14645059232509908, 0.2267275363086693, 0.2102544855686926, 0.0837400061408839, 0.22082148870873838, 0.09636694310052742, 0.140012358765929, 0.09279528031906775, 0.13763711847845586], [0.06552041282937413, 0.050085116282946644, 0.03365107090963471, 0.045047126740457556, 0.040014381069810166, 0.039605634857810317, 0.06407656691848271, 0.05323045113454423, 0.043961346494935216, 0.04162367132882919, 0.008807506021713058, 0.016563228864763534, 0.04930494000173865, 0.06358956482501761, 0.03315880579212981, 0.03927071653907338, 0.0192021930049504, 0.10054049818145652, 0.06676090836164451, 0.00874440431699998, 0.010305183973433751, 0.0376571208659199, 0.034715174697339535, 0.01983729713115721, 0.034760944620375676, 0.03980727686036018, 0.022217141607055263, 0.007661386297249626, 0.03551813443341563, 0.034809024298503514, 0.023347736080928196, 0.03702510215882813, 0.04074080096137139, 0.08752942175394104, 0.04564096362540319, 0.010637104015557036, 0.06995921053232686, 0.018011341885393186, 0.027859105292948026, 0.06637362793328301, 0.03224682408354936, 0.008839136834496693, 0.02758125286369074, 0.09358356181051462, 0.03810234435443436, 0.037652489864417625, 0.07003661605619615, 0.0549876882935003, 0.020557002262062123, 0.010010473779402673, 0.05658465602825727, 0.018229713332989526, 0.04705125871565073, 0.027660562116051876, 0.05811018606407508, 0.050650818588873076, 0.04509772301741666, 0.09473076315536615, 0.03384356965280829, 0.09314074000764279, 0.014881430298931178, 0.09412369976240782, 0.05273529020468554, 0.05433099006392783, 0.011022716287463423, 0.08078479899033424, 0.07150729036619587, 0.02265869553441242, 0.013206507372219237, 0.05213658100054149, 0.11144864027418437, 0.0013042449403832096, 0.04116094273124491, 0.01850827630879658, 0.02233598099630927, 0.061762468108246406, 0.01947723389152558, 0.05878959113972322, 0.02406391912260123, 0.03929737639883834, 0.040079180616885424, 0.034826008467784816, 0.016517016525951125, 0.10528688784688713, 0.01423395959840667, 0.03934865832448967, 0.027451418197503494, 0.06407180185159368, 0.1142805838777173, 0.023142357484527656, 0.02234037834099464, 0.05617303315610175, 0.018662505129712726, 0.029517620531541687, 0.045627055299137874, 0.010221321285972673, 0.02174454196656664, 0.029132205527275804, 0.02680624576075183, 0.037053953030056534, 0.05007346408561834, 0.03279401770522518, 0.018269886983738794, 0.08265706425112102, 0.022888445302904136, 0.0661629920585021, 0.05699875336440821, 0.0054564018688735465, 0.05819518734971362, 0.033976386316240795, 0.027618634123956005, 0.05166760495593471, 0.08141442367266263, 0.05265478968560215, 0.005937960907636632, 0.05539078077661896, 0.07142904214560986, 0.07200792116383392, 0.03675211438789003, 0.03702517110674131, 0.01291764051383061, 0.013382043971139337, 0.025600162898040107, 0.047904140571312565, 0.07518822026829566, 0.015283074875872944, 0.011922161924772927, 0.09891783202727956, 0.03750217958323417, 0.05671662233409382, 0.0742979265088516, 0.08481881115585567, 0.041120991245993686, 0.019650974971873146, 0.06500232288794172, 0.00984754698771623, 0.04588882371242489, 0.023215741046794483, 0.031964593461804816, 0.09187071944677061, 0.03332935228583313, 0.030070467882098693, 0.12469896596045264, 0.04929713739622985, 0.045710263939033595, 0.03900455078110099, 0.023653435806233077, 0.03350444934180668, 0.024160758381889715, 0.0571700812677943, 0.015998480338302833, 0.05345965315017009, 0.06246338110236872, 0.1258174849734191, 0.024800671625041196, 0.07748198710502156, 0.0539966807850907, 0.022631949489755977, 0.027983127267009793, 0.04726412773673092, 0.14012423824639092, 0.024324695452026302, 0.04667893998445042, 0.052685096123886686, 0.0604184702669661, 0.011635218904684148, 0.027084105850888357, 0.07012098531929717, 0.03919798032110257, 0.04324997640064648, 0.08310164039533946, 0.005839336663484574, 0.026207616995839823, 0.029801655290347916, 0.03346065592561518, 0.025985553004448454, 0.008491825128364707, 0.03224952837392207, 0.0842111885187126, 0.022485379632862828, 0.0373447600061134, 0.05008571383152759, 0.013059746950954921, 0.03328428716368733, 0.0156960824519516, 0.07252827106464295, 0.05126809776430169, 0.03472273598515219, 0.060095924268206286, 0.020370601578765822, 0.03116981554476004, 0.07598027857320924, 0.044238260466485255, 0.042367102202749064, 0.023929631570354108, 0.022630453703083822, 0.018104367942038565, 0.03120801268866466, 0.0502834985813787, 0.022580680970643318, 0.03243713947613874, 0.04735580164818995, 0.021925656643185406, 0.029165978513417706, 0.05150910136440108, 0.04465869718020962, 0.029502944202132286, 0.04992922505123481, 0.06133941903470024, 0.13018872138232956, 0.03960174313115497, 0.024181626616947116, 0.024281451703920483, 0.04353058291599155, 0.04665329902162475, 0.03730140326003875, 0.05676586263542695, 0.03923654518721085, 0.04671133401232862, 0.0617687845031821, 0.024624053884537953, 0.06572760130849577, 0.042973204155362425, 0.02875733955372726, 0.019831976650523084, 0.04358214446373525, 0.07501664721677381, 0.050802006040729826, 0.042896664310847564, 0.05572209848211177, 0.029759918820233117, 0.028562352940019582, 0.0639926266646193, 0.09282749431628375, 0.046702183092073093, 0.04875503059837127, 0.029496627807196592, 0.0824978481978178, 0.03497651410138896, 0.06672907740839067, 0.010674865446954725, 0.04347757729251058, 0.03337347128939244, 0.0395195457273193, 0.015244793462296648, 0.043961997669670856, 0.10011876677914013, 0.051380984650384036, 0.10739893862797369, 0.06156072651426639, 0.0262585120470894, 0.022933569796864065, 0.011959229088989238, 0.050542673787042025, 0.041277575787277, 0.05879819047667327, 0.00857921948115672, 0.039293235693607605, 0.04444253398105503, 0.07267098558405716, 0.08260567507316029, 0.014872765844507564, 0.11974102877561124, 0.025377168109820738, 0.06030890054159588, 0.033885474662266435, 0.01593659479816955, 0.07428897094101676, 0.025360360140762022, 0.06319635104568255, 0.026766593049791072, 0.03743626537822908, 0.023702310300582362, 0.04222471327070267, 0.06769162858085287, 0.025624413411283208, 0.0367260865506626, 0.04985510221412105, 0.05959480700473632, 0.07235489004561979, 0.019770023120086522, 0.02028131786163055, 0.02016161853868154, 0.02176773527847423, 0.02970467430479344, 0.02664536346621331, 0.04441023954460698, 0.03914130130602468, 0.013134140791671892, 0.015718617885854217, 0.06152138406891496, 0.048156275428951754, 0.04415160060049065, 0.033010506491747596, 0.05330302264361132, 0.03331789927136514, 0.028249398362071767, 0.01293291247660114, 0.013503907492474444, 0.04668858503141711, 0.04955510601341244, 0.03323691228644983, 0.012193722856952059, 0.014060285550752475, 0.03091451482877376, 0.01200568178788789, 0.020559484386936795, 0.0417894565860831, 0.047021189764622724, 0.07163210907169888, 0.08013694141540798, 0.06988005066711096, 0.02342561657931055, 0.04915644534893575, 0.029251387740875927, 0.07041153948633902, 0.013962261728011073, 0.0628996949883238, 0.13542033581724092, 0.014828238899128572, 0.047473679597098986, 0.04263741632683143, 0.03767766351360948, 0.05714969183768957, 0.016271990964249257, 0.01652663859028009, 0.007218872844767307, 0.05498277766990566, 0.055715104099363096, 0.1553375952907147, 0.05474274317103048, 0.07311646571202625, 0.07402557459089064, 0.014773806436888635, 0.04859166234851845, 0.10322983451788464, 0.034253947632086855, 0.03681743104431418, 0.030823469109412645, 0.10029949458135713, 0.020464089203385577, 0.051955876180962215, 0.07126359779748224, 0.047730763382729025, 0.053274443733596036, 0.05463474009546542, 0.01651137237316899, 0.04734311906260349, 0.030420146799916704, 0.09323611029333646, 0.04416976454517534, 0.04510534942270287, 0.2294361627390308, 0.19361775248281418, 0.11840784426538215, 0.11599021633305859, 0.249506302718674, 0.09727737731150082, 0.15106665511285106, 0.15653044015409487, 0.12267651682298993, 0.13131828738316415, 0.20376964322020932, 0.1389679817422744, 0.12952075399939092, 0.11869035450921905, 0.2536508537107899, 0.14264742543380107, 0.11857743314918011, 0.14910341691105597, 0.10829066497183616, 0.09541947619929429, 0.16061819338750455, 0.12499966313161197, 0.11465573713423745, 0.13777574974923365, 0.21941734147408318, 0.14854495413601398, 0.10407870590326287, 0.08498290718923654, 0.14362893728238924, 0.1796921585956889, 0.15586595081033247, 0.10002109056879437, 0.16242896477060934, 0.265595696626171, 0.1466352961236431, 0.10464269983311815, 0.13127495745016685, 0.13238999842395707, 0.20565106323169124, 0.18274972275380166, 0.1308970309553608, 0.08954031828550563, 0.23907927916415278, 0.1402079256912393, 0.17973587157264834, 0.18307566252206603, 0.1761374033747181, 0.15756481206945835, 0.17860520240520278, 0.2533623603202643, 0.21089985335786499, 0.1473280847553284, 0.1803429962526406, 0.0971654442048842, 0.12643246205463526, 0.16550252484458108, 0.26645126362000743, 0.21848818407424037, 0.1695380921685888, 0.14356225698945985, 0.1576664566152519, 0.1634242968453515, 0.1330215459869754, 0.1218181612691091, 0.13343079015612602, 0.1739232100906872, 0.09999893530602418, 0.12171162142147943, 0.12213968071005038, 0.09853223699235147, 0.2240040018073013, 0.17251169309020045, 0.2130308648150775, 0.21443622246865304, 0.11671860507058522, 0.17630655558839922, 0.1411975733935833, 0.20405801403666698, 0.19927399413239574, 0.12049976225581863, 0.09432957057029971, 0.0982321220480146, 0.08235282775375151, 0.23744314518426698, 0.14518383529878434, 0.13453443174160298, 0.20841858650167144, 0.14586798245868376, 0.2567640052086884, 0.12088970100927739, 0.0886747844877743, 0.18902750685811046, 0.1674071879636857, 0.29202269630566724, 0.15225127219192444, 0.06521134997808165, 0.07562219375564207, 0.12079465248051191, 0.16976784193708053, 0.16347110481752505, 0.14642655248603514, 0.13730757809694738, 0.1880893402642781, 0.22026602899835956, 0.1932053826749325, 0.1370903462051384, 0.23300329794085797, 0.1266225744339247, 0.06619426376757122, 0.13592976896512893, 0.18640344121283103, 0.16279903120331227, 0.14659731348435726, 0.13722643406400759, 0.0632729598381106, 0.22947575416295762, 0.1851191101295333, 0.14012760903325774, 0.1556642551816279, 0.24815501555079417, 0.12138090126456753, 0.17915965087952154, 0.1478857814424461, 0.09486769371095205, 0.15346480142926017, 0.11677248403429986, 0.09630113614783173, 0.08695365305268958, 0.14942126679083995, 0.2787799472289701, 0.12314553883287216, 0.197555260552514, 0.11892151387949144, 0.11574663867753361, 0.20461171174481993, 0.29566611854299424, 0.13314290963593992, 0.2427874358310815, 0.11777947596724957, 0.31051697810330703, 0.1000286671783655, 0.26688214211213973, 0.25550098669144417, 0.12948007473061163, 0.08655924800663226, 0.13842317065404308, 0.16158724864644392, 0.08247369344556525, 0.1032790250235027, 0.18378133675263775, 0.11613113820672998, 0.1273177226164168, 0.19698918286350467, 0.2752176077375489, 0.14501592414754053, 0.15011002580004354, 0.14677058725107103, 0.05589886177932063, 0.10025242613928934, 0.1744553500846509, 0.26252834186438595, 0.10861036112351764, 0.0867349885764622, 0.16619146771488652, 0.15295460219344786, 0.2095572229835295, 0.09935918294133679, 0.3273632822017516, 0.20804933212216825, 0.16440263708993313, 0.15108064387834844, 0.0989887641081887, 0.11575734858671505, 0.1535590915309806, 0.15247271756731695, 0.11697767302393915], [0.04429505056431217, 0.03328488854270789, 0.0731440908425758, 0.05945596122933973, 0.014799942484035369, 0.05022548274287293, 0.12499531175220206, 0.01853228550434353, 0.03383990392209061, 0.025987380124147863, 0.030911582627243576, 0.040228472001129584, 0.06626991495009392, 0.049163619762346636, 0.04593494986634582, 0.02929264157559843, 0.05503937241531188, 0.00869210828245888, 0.06326119655803328, 0.018903646625638492, 0.038513028768882636, 0.027498988427161693, 0.06318796621335131, 0.0254950154152128, 0.028271113124285496, 0.05821302570703049, 0.0609117734336084, 0.024644956593551946, 0.06287327644625498, 0.042818546325208685, 0.07516444856000525, 0.004948037413639888, 0.043874238467504906, 0.011275134597634597, 0.01922269926346358, 0.08002457163867452, 0.046725679008710774, 0.04859568814056055, 0.11727758112453646, 0.029254434855594754, 0.06800839061578436, 0.020668822370709914, 0.06395916394408672, 0.04056625548870333, 0.04844701728753505, 0.014610225597636835, 0.015208558461088088, 0.04769946486058255, 0.06178888665031522, 0.02494315631807812, 0.04293833949392842, 0.014205501347239462, 0.051542813063509045, 0.03264755318542162, 0.009086247112962508, 0.10430984995177678, 0.0590466098078797, 0.04283017553989926, 0.08952564770175565, 0.04775918141428021, 0.029639330835291938, 0.08042541182329578, 0.0700925711181856, 0.04696295942149816, 0.0583468804196004, 0.04709716270407362, 0.03970549441874027, 0.04448718924616133, 0.041501422848312125, 0.014247273248920759, 0.0617222867966179, 0.021861245885731715, 0.052653567775362925, 0.02159708153246151, 0.04142277243156587, 0.050836276984022516, 0.015719567834880325, 0.03044927154757804, 0.027516311590349483, 0.049265612878145716, 0.01250863095910679, 0.012540419777524809, 0.03347575934904237, 0.08589817541501216, 0.0811430217037278, 0.04505263108219351, 0.03489098038464304, 0.044427323305318435, 0.05390467362538461, 0.0716556279709743, 0.05044343858777035, 0.025939403867889798, 0.027571724645132502, 0.017956223774461016, 0.04106862913636912, 0.029060591628114064, 0.06297510485315035, 0.05239191810570417, 0.06392900689294742, 0.08671125517256799, 0.028066008404317885, 0.058823452225976416, 0.027170334792425557, 0.02979967495306365, 0.029514113764068293, 0.01907653734839011, 0.03373663910033722, 0.009696924525703634, 0.017113373840167638, 0.05773002642296976, 0.025498704128568212, 0.015073682936359079, 0.05557677926375501, 0.06647237666672276, 0.08500267225768297, 0.006275501162294419, 0.040226947486160264, 0.05363805970597652, 0.06367778367993814, 0.0811023424349485, 0.028003129822712754, 0.06993140154067548, 0.04450840222078466, 0.013469462264178982, 0.04520815459170169, 0.002423799728163548, 0.07778515107929707, 0.042129396611163696, 0.06258453790759368, 0.023365266087855545, 0.0417460194007764, 0.04760727383977464, 0.025596133275558392, 0.020357813656089768, 0.03222197985216495, 0.009382302748910602, 0.07321485438414159, 0.05653181894411964, 0.0401871147445373, 0.022371125279835636, 0.0636907727006943, 0.0067303548548220396, 0.04153538352599548, 0.014999198122701098, 0.01694263390926344, 0.026204474120130463, 0.025819076352842876, 0.019507982745586384, 0.03232297322322284, 0.016419849764075012, 0.024735805045272556, 0.006796479734006308, 0.02658600697384006, 0.04464224927247532, 0.07646767903239497, 0.057410548606346694, 0.07086746139271606, 0.009958036018595582, 0.025476960638057322, 0.0366876978847769, 0.05399819380874115, 0.041807609039448926, 0.09264721850594206, 0.021870038659882643, 0.017386227545718995, 0.0675375223340046, 0.05180987897479246, 0.009556543701628764, 0.014593199293519703, 0.031776022834462986, 0.05034904123374051, 0.021189737261363098, 0.047280345818087946, 0.062263244462590066, 0.010660021535811887, 0.03870449712379806, 0.00471988876890992, 0.05010723707176024, 0.036285612807278676, 0.026891174268037565, 0.06267444215594761, 0.03104393389226208, 0.055765999150612665, 0.07650839660557048, 0.0808264205472604, 0.024057539525411786, 0.02781557617709041, 0.07043439954999955, 0.09961109563347795, 0.04778117962902592, 0.11785261438138063, 0.03513286115541574, 0.03092713612732628, 0.05371387559740294, 0.0909936790084166, 0.10135438233133286, 0.01958042593492616, 0.03767723833481151, 0.055880192216605916, 0.04371686868609921, 0.0362460826703858, 0.060894930990593094, 0.008378418260103753, 0.03104041371825001, 0.024857519179462426, 0.07513401954765282, 0.06417864430395347, 0.022747632596761953, 0.09503975705874544, 0.030011009883075476, 0.018765442448878483, 0.019382574152381673, 0.044300087592414314, 0.07557491080895548, 0.07585595016397777, 0.028888735124060226, 0.11733214956738296, 0.033011701588909474, 0.03640086690504705, 0.11472886788748926, 0.05854184979632978, 0.014925661342849415, 0.008155892700738004, 0.01714399437450113, 0.01873472998399408, 0.08062798845311327, 0.021460991758372516, 0.01188343618020055, 0.03834604841446684, 0.016841167478912303, 0.029605305040135022, 0.05375813632722824, 0.013167909947374176, 0.10196876952484732, 0.014464793381311241, 0.0806135323739821, 0.05482635017664683, 0.08412347145138249, 0.046709441775155645, 0.043724747900400436, 0.029801873625406337, 0.02214221437762101, 0.043338796634587555, 0.08157990632518645, 0.028582108432366967, 0.02449941137925752, 0.03851013295652886, 0.01812197647297815, 0.054258008697821256, 0.02328587639626236, 0.03952147243844886, 0.054603230899139765, 0.030695490291221973, 0.04489408152538442, 0.04665603395551444, 0.04001817703547497, 0.039703816686186104, 0.007759632764294023, 0.03682843589734647, 0.0592161872003588, 0.021486387573062413, 0.06735074243718578, 0.021369317846913493, 0.05455591347849658, 0.06253646589034507, 0.102547510647245, 0.05500659534347154, 0.05290600523773221, 0.005780729979667212, 0.05938866040519169, 0.03483556158420059, 0.04263699114803345, 0.048058710301355015, 0.09008572692231787, 0.031623174887030356, 0.03206710177173298, 0.021738145132398894, 0.04579420419289701, 0.008518098113727907, 0.021484633231715813, 0.018113610792845007, 0.06829209595678315, 0.06361543178378094, 0.051433377403525576, 0.015322181749187652, 0.036841807962064786, 0.03996585706068624, 0.022859874053768093, 0.04225969667576494, 0.009602930325443947, 0.027848485399097688, 0.021721021152071415, 0.04944787285621128, 0.027762011309424718, 0.04060339926171207, 0.0578893727112201, 0.010145818532985306, 0.07894087898274584, 0.011022641593890806, 0.013635502245667721, 0.023970810711503993, 0.035001618802667625, 0.04429122778557001, 0.03884404770008499, 0.032070621945745045, 0.04919513278911191, 0.01768470497711772, 0.04001640737236988, 0.0851727897421487, 0.029359183972701434, 0.016261572168479045, 0.023994768196116054, 0.019113181249028253, 0.05692048982206372, 0.06941772426568693, 0.051807373867280064, 0.010115360792335725, 0.06547487656315489, 0.020768986451589776, 0.030218384138518767, 0.07531825603256304, 0.005117626297437857, 0.0433866618080966, 0.018430631382450945, 0.04561745238700702, 0.07056162377158481, 0.03277370105347326, 0.03268484251513597, 0.0374357137949236, 0.0060206883485549164, 0.01228486146447399, 0.02703069228558771, 0.06305314239955719, 0.08532394655048849, 0.054003636863443165, 0.03876816286074539, 0.019093954357348623, 0.014938931900917765, 0.018257962825197368, 0.06428970023989677, 0.03400626757572736, 0.06370992872924094, 0.028271856229572047, 0.024932321919608983, 0.0686278033460821, 0.025943100242124453, 0.04190592110277184, 0.006112334489326684, 0.04380103876633991, 0.019287563928012407, 0.02747740389989509, 0.029446805279041012, 0.15215051630812307, 0.16545829092783315, 0.15923096137421747, 0.15553985782448324, 0.08732023378533703, 0.2284699266836528, 0.34506196636826764, 0.21697085500965196, 0.15462449000727746, 0.1365394677005468, 0.17317858795004507, 0.16097117605949604, 0.20466185986034333, 0.2032843724854531, 0.23704275699152103, 0.16452089042192505, 0.18059018218228895, 0.08576333627945955, 0.12366470895827779, 0.3409608832049755, 0.2136960896032472, 0.1709352220378576, 0.12666640998495202, 0.11685123787291589, 0.12607187212955567, 0.11636536192869949, 0.1789781646502595, 0.19239495358159467, 0.1425531506538391, 0.20031015869350205, 0.2672296089510764, 0.11886758895050134, 0.1515668032750968, 0.09815614910856371, 0.19594472923105766, 0.22658418593627794, 0.1148549582989466, 0.15540833584964275, 0.19921423927430185, 0.12299693309732022, 0.19387809980300166, 0.15346385148023406, 0.14935588884738185, 0.1646926932998242, 0.13070641295804133, 0.1514549237946349, 0.18550832876034323, 0.12351982641003786, 0.14062830877880897, 0.18022543239978053, 0.10838016702402985, 0.10048101911501539, 0.2539647046116091, 0.08215859382142944, 0.12200094984784243, 0.1668492767719492, 0.128008772228514, 0.14039855901031725, 0.20784907673876132, 0.14535707842198112, 0.14478571472629426, 0.20478270256951933, 0.17041559992057664, 0.12004548743847879, 0.1443022979243148, 0.13998435059141728, 0.10183420618094745, 0.2105413548528187, 0.11608138079604796, 0.11141264180262243, 0.1963836516463949, 0.14161933543941668, 0.13510798644875327, 0.09515375860275761, 0.11555785929123241, 0.18073264389268814, 0.10362217878742565, 0.14579739511734055, 0.1676245730730795, 0.15459225302742374, 0.1947542132749673, 0.13830516247018693, 0.20217774315707146, 0.1733772498705695, 0.12405585813065692, 0.15111908617038883, 0.11848325796064832, 0.2106939136020599, 0.17773612162038205, 0.16027238129848437, 0.15732603778521861, 0.11210881654293307, 0.1665261255637292, 0.11269823693099523, 0.15589129299886767, 0.13523181690083397, 0.08452334636521917, 0.10533924995651169, 0.19649217566174848, 0.10958614263443217, 0.19310413649485958, 0.20637636463488304, 0.0969112332489702, 0.17248095764267832, 0.1537126461945234, 0.2740236750293163, 0.16009262642793118, 0.1896080329653717, 0.12496043176900958, 0.13844957004391378, 0.13805425335322657, 0.05512331266917529, 0.11277795604039585, 0.14055470305104412, 0.1783089868484005, 0.13421164825558662, 0.08855832380152519, 0.0944555843729646, 0.12217163423737212, 0.23976454481242165, 0.09512788015267543, 0.27653601441171866, 0.14199124048313788, 0.20736215125408866, 0.1106489593944242, 0.10696289670323172, 0.20805182956880142, 0.10827974055803592, 0.13773762921412147, 0.1883765772706078, 0.09209371998064941, 0.10673474039762251, 0.18086169906441243, 0.14856798273901786, 0.14464297722424233, 0.16314021612126983, 0.1268802404463772, 0.09764420319228403, 0.12087931285702413, 0.12220649123792687, 0.19425460137426856, 0.1360995034056325, 0.1265151689069406, 0.0931918227504338, 0.15165504128221544, 0.12822883098476356, 0.08431459506673199, 0.11304971040977586, 0.14526016829955965, 0.16096861732582893, 0.11188631396620505, 0.17864497769023144, 0.1262532817500253, 0.09871474977943206, 0.238453523225842, 0.09978914978883921, 0.18759458536101928, 0.10854890555023186, 0.11560545633396796, 0.13805033098305428, 0.08541763144274873, 0.13221123946770547, 0.1307209379850857, 0.15415475553562566, 0.2527471917170671, 0.3081837500776014, 0.11728727213677861, 0.1397192535260993, 0.21466303045951554, 0.0746237820074443, 0.14840995412199728, 0.10240729357446395, 0.10347171145821772, 0.15452566466504528, 0.1624378667122895, 0.1821382160508825], [0.013798901139037504, 0.03854851013109569, 0.04654032020499149, 0.04285051517428891, 0.06343922390031718, 0.06351964781060815, 0.018382584263059883, 0.07273897588733705, 0.05168395710267848, 0.036030957520368605, 0.05982006366755213, 0.010916920502730196, 0.07116404467172201, 0.007755446572592783, 0.04745216018730595, 0.0252176609431063, 0.047044452024443496, 0.0722264783877519, 0.08692690126237371, 0.046922540622613126, 0.04841309491424792, 0.011289475763577127, 0.02488746555642255, 0.02657364231474217, 0.04489084480390434, 0.06270326621409866, 0.053759867685937116, 0.010283804374686893, 0.05405218385520482, 0.05030720134175593, 0.05174806334018227, 0.07867875433857403, 0.03558650395021804, 0.017227440501653382, 0.02974952492232044, 0.03787038059184148, 0.054088393000945936, 0.03140899394037983, 0.025017034007056106, 0.0621697549227505, 0.02964133415521393, 0.048617674863987395, 0.04041483054959005, 0.017471290118391478, 0.049170694584327365, 0.02463699310957905, 0.0156994111039826, 0.07192264025610301, 0.040397199036012736, 0.024591315117093827, 0.0637238447163855, 0.06228005243164878, 0.047380485001110265, 0.03760894925724115, 0.013444797105846867, 0.04371912098459659, 0.03871741336620143, 0.06749148044975535, 0.06321699711524191, 0.11957844193544119, 0.02139602367195391, 0.034009266809950915, 0.013703997209367734, 0.03885717078622791, 0.04266691837279547, 0.09432668241882518, 0.055827542824009736, 0.014230783206350623, 0.09151462645780656, 0.009108135202569107, 0.04364053951576353, 0.09140920509854633, 0.0641742124853115, 0.05954320715259641, 0.05071475628703352, 0.03885337482056311, 0.09334413635153925, 0.04934484552171442, 0.04763981342435845, 0.01936383181131415, 0.02340543207772557, 0.0739729673331303, 0.08317785848292612, 0.05097179793782773, 0.013159117173223246, 0.022700709711399772, 0.04926953141787841, 0.04190597855936616, 0.01596565634357713, 0.02949066572792588, 0.06039948660820242, 0.023701059662045974, 0.019955441295619936, 0.01125628404664777, 0.041143000952058265, 0.12909120850024686, 0.02311876580689944, 0.027464608316339796, 0.053729300777758324, 0.05195595662019426, 0.029691773384148558, 0.035983314512357596, 0.020937043159539183, 0.004117117862352321, 0.060557090046425024, 0.03014745780326907, 0.050141013888341766, 0.04409958706087163, 0.06620102066306338, 0.01804841288004912, 0.039749984974942865, 0.05927539813602644, 0.04060055324507337, 0.08711982518434526, 0.030950314117475387, 0.019182075536058798, 0.027634411704756563, 0.045391364518793366, 0.026634180497738625, 0.06237942552674682, 0.0564757030036661, 0.045057365505565564, 0.03776338109145722, 0.03862395063943921, 0.04736995512259103, 0.039895009249448776, 0.0145139676075609, 0.0337570744957174, 0.006369708430758047, 0.049082617455672835, 0.011444228397111499, 0.04972578657250251, 0.03920989298832513, 0.034132652931035526, 0.045801022375423106, 0.08033629281506424, 0.058829010193867076, 0.03871591183386984, 0.04833853540701732, 0.05081682218118541, 0.06370773771777749, 0.043858909048140056, 0.0641360383240446, 0.09006367891185707, 0.08961746333948067, 0.06792792074021793, 0.0434991656502168, 0.02890960718955725, 0.06142362741933716, 0.0668995013280261, 0.06731757083006444, 0.03397946215925678, 0.032019202124267336, 0.05820515415360851, 0.02823220160339148, 0.017795672812949748, 0.027153306573088613, 0.021542034284662337, 0.041807965270333716, 0.04281714438430725, 0.02864089610445644, 0.042922029482020486, 0.041347799236856164, 0.028358786141559966, 0.03986190659024062, 0.013759595082862484, 0.04719645919037923, 0.012359473640249382, 0.07214652179109474, 0.02811881292971873, 0.03294370362475034, 0.023403419181704525, 0.046798208382942026, 0.07382014045311559, 0.07428825081836793, 0.054675664512380484, 0.037602360901092334, 0.06960601335571659, 0.016532976052633697, 0.048022830573421334, 0.03335065336056775, 0.026899809994164015, 0.05482141273997484, 0.025286015138150226, 0.037993774373805335, 0.04714015555838424, 0.030304559453901266, 0.01642044539743614, 0.007401795488887377, 0.02889743405244043, 0.02652181838188441, 0.035679759833240704, 0.03262939307117655, 0.009188587841157232, 0.09778667256356248, 0.036860251528841835, 0.03731321250539153, 0.026328327554848888, 0.02537554208820145, 0.08074256456306866, 0.014973298605200986, 0.05122958269390849, 0.016832732850865974, 0.03595518759421764, 0.058036438610044226, 0.040168414538305615, 0.03583359411887584, 0.06301665746216333, 0.03197078536745281, 0.16247375027066277, 0.05249870310146963, 0.066966955369759, 0.09614525257699913, 0.03425295171778529, 0.005374661723767678, 0.012299461185090966, 0.015250282482274119, 0.057839898753070065, 0.04306783133576955, 0.03236557154225246, 0.02518942294221732, 0.0675059135462488, 0.017121069193367037, 0.02962573085941615, 0.07140163151967911, 0.02051143343710611, 0.017137277698625, 0.08608228932585447, 0.021892963841016737, 0.0074179044027151845, 0.030352010939931198, 0.02639167728052745, 0.02721830147258457, 0.057219156860223705, 0.08575691646265407, 0.12283638405102877, 0.10521917333525997, 0.028335824571249467, 0.03156654375244773, 0.038379174056312734, 0.018012898959099286, 0.017472205593460993, 0.09357989991023656, 0.03298576185179334, 0.0379760509296771, 0.04257411831208775, 0.05228478453993317, 0.0329567615934197, 0.03596639546054987, 0.0254567684755931, 0.05075763805859512, 0.04235600924960548, 0.07625054673201616, 0.007199904986567075, 0.02479492405038928, 0.03544138391472159, 0.06114095629703614, 0.04834647590835248, 0.017854335995751525, 0.07200645793589854, 0.0033380543238543457, 0.018995935322656747, 0.020767896691517487, 0.052546407396514574, 0.06306025935637374, 0.04392768076110271, 0.05059724222988852, 0.035609662788169044, 0.023072103391431516, 0.05209185295708237, 0.029768184908936103, 0.10719351215107788, 0.0263602580995329, 0.08583552474456449, 0.05977341274340307, 0.0615848008272869, 0.04754282286270492, 0.09510446850570942, 0.026447308670368888, 0.007318425970527554, 0.044847729375525835, 0.024684503967423114, 0.06879960622398124, 0.026771360031899907, 0.07015207316726446, 0.03717488766978345, 0.02441962523716352, 0.02516285118256365, 0.035183828985018116, 0.06482091326747211, 0.03549197636124107, 0.035066372384467435, 0.028931894602494377, 0.016036290607805696, 0.025296975941126867, 0.029038363586991068, 0.029657705454155806, 0.03454806410797662, 0.03340912502138846, 0.012620093879259884, 0.028715645218448296, 0.023639772628103534, 0.06799718274945213, 0.022274148124720783, 0.004561220468472569, 0.04066974630639438, 0.033864633240286386, 0.030127016662229455, 0.0599021346668803, 0.009191409917548299, 0.07705796509981155, 0.036914957867514704, 0.06840384520229793, 0.024500466665373217, 0.05680086519268732, 0.058692941487196, 0.0326216172787451, 0.015843043013686137, 0.06698855904922371, 0.04802451596685475, 0.09512807167465649, 0.03950560292709739, 0.07251411375980224, 0.037984301696621606, 0.0731170479388487, 0.035236700543112336, 0.05018148248294189, 0.055835180720614816, 0.02328292695775388, 0.01668061268696141, 0.006701890379190446, 0.026900773349728797, 0.029674206988044807, 0.04692452862077663, 0.04659330667627435, 0.03480990529961644, 0.051211001231305064, 0.011360577341439504, 0.05419477197011152, 0.044303063844000144, 0.05749144749115071, 0.049999682157630884, 0.0587337663126809, 0.05877622290544453, 0.025778977395666224, 0.007920700356349229, 0.031067674957035534, 0.017645326142589894, 0.10716497537589843, 0.02937302718149318, 0.015474011757290893, 0.034410310007872126, 0.13898388572758244, 0.14461385056136117, 0.12280937945169788, 0.09624585524321565, 0.15929143635496018, 0.14177144985766182, 0.13372055525260587, 0.13649471284401032, 0.12066815604245472, 0.20020232415728031, 0.13568328783637093, 0.10639576947376614, 0.18358774633417208, 0.09433867169484016, 0.14014259371305668, 0.11879002254816795, 0.26009089523746126, 0.2038110732551544, 0.165134756675651, 0.13215087173927215, 0.2268587978136155, 0.07385369510419908, 0.12138257133624247, 0.23307670448576254, 0.14745134830234513, 0.09801837585626111, 0.162291988249748, 0.11713950143706416, 0.1207278419526354, 0.1999174313799989, 0.17826194904984968, 0.18399351246414647, 0.10723233748708041, 0.29832502586706994, 0.20378645118926803, 0.16362973098312655, 0.19045708821185175, 0.07723389719162257, 0.15230633859192172, 0.16829234127315784, 0.1144363601962405, 0.15552789153110597, 0.21422337259977095, 0.08405606337492505, 0.09355455006082213, 0.20418625715519154, 0.09283867919997824, 0.14728887637536373, 0.24674746688575516, 0.09856042136708576, 0.14742596014853449, 0.15473756458490126, 0.11166228687450772, 0.11605243799426865, 0.07388200205300124, 0.112043944217505, 0.12381703022026247, 0.1157638373514337, 0.1327948605701808, 0.3533191071642984, 0.28445904894221213, 0.15424492408431348, 0.08772972310262342, 0.10748566744188148, 0.1531158637015089, 0.14165780837497405, 0.1880906272919909, 0.11887569416074023, 0.1659581173331507, 0.1678682962853101, 0.13356681672796128, 0.21333135514249726, 0.15395273814999288, 0.11842998420639385, 0.1509992087319974, 0.06411346937379529, 0.299662217017143, 0.0988318769621753, 0.09816823031512961, 0.15904975093660817, 0.23999856935153085, 0.13676702645757507, 0.21086482781796687, 0.14903992354389162, 0.1030921072308575, 0.17433358806996577, 0.11611942472236773, 0.18970028527321356, 0.3575662066859584, 0.19424931536759102, 0.17868528923680707, 0.12475392510814053, 0.08783389573856708, 0.0980349463380633, 0.11610962645781618, 0.22769179585720264, 0.21994713723899859, 0.24172988209512927, 0.21747242809543688, 0.13013385416519258, 0.14935869272918473, 0.2006084426876999, 0.2821379863927441, 0.03528930013999343, 0.1627599147538985, 0.08655642114219167, 0.15790575183928013, 0.10220097843557598, 0.11934704507791227, 0.1174333114777842, 0.12307580184912491, 0.19484114893261464, 0.15867278971258672, 0.12976553441295702, 0.0950730742225724, 0.13854672531447104, 0.1310326438397169, 0.10647846100431298, 0.09253188396894163, 0.14690074558940627, 0.1628427595020302, 0.1933795757471554, 0.14259730796179465, 0.09568639655387211, 0.1235107406072559, 0.1413989319436012, 0.09355031359460085, 0.1722665296326722, 0.049724242905335087, 0.17023287262887726, 0.11839443006582799, 0.1952755054639232, 0.23050571341187726, 0.09087633732105456, 0.2707366675378815, 0.19835185409793932, 0.15175619553173744, 0.2067135965391513, 0.15103837114668664, 0.21460891400854434, 0.13406492709632845, 0.09778510974419695, 0.20839517485470543, 0.14762921859660458, 0.2532227178134265, 0.13824625030880974, 0.15352383616470522, 0.24840630771171665, 0.14875968858118982, 0.14029665399462948, 0.19625047492163797, 0.16654077316484145, 0.12385203277752285, 0.15321550109694082, 0.08484776927939347, 0.13704629614949226, 0.1088961732063082, 0.1094586656038319, 0.0746573060150108, 0.14916991334288351, 0.15414078209188678, 0.1666095065734079, 0.13931532600714316, 0.0801508688938714, 0.13839107157001573, 0.05216211088061814, 0.130889339432601, 0.19419510698606893, 0.09628871020169989, 0.09317609496534833, 0.16959064580019445, 0.06821596213886816, 0.15399668095332963, 0.24479809487538956, 0.2093716611665103, 0.30756594613194466], [0.03397617564206162, 0.034865622874349356, 0.0384580236559193, 0.08821507044617208, 0.06095094350917686, 0.03958865451896864, 0.017721597856331258, 0.008718379352602267, 0.017200512511114922, 0.03994904143074828, 0.009521805444702266, 0.08074490879211696, 0.06955979527124474, 0.04772392987844445, 0.04053567708920568, 0.06540478717896246, 0.024418989384186365, 0.026209191306524222, 0.02200938239243002, 0.01682191377415532, 0.021900527044049194, 0.045121368321199576, 0.024693955577188925, 0.023024778309909087, 0.018098821465466774, 0.036506686630027915, 0.08462778713193633, 0.0716195299079822, 0.030082631443116455, 0.03643146828718243, 0.02674847890082146, 0.023509449580864563, 0.0785094948725835, 0.028298832100605773, 0.05284133209516445, 0.04089539750449119, 0.042355683662237666, 0.017029912391256903, 0.03900339015789571, 0.04108713399018011, 0.095925806691089, 0.02748631158723466, 0.036220158255028154, 0.03121863066729519, 0.029054662107580134, 0.025941774910015446, 0.03191808043348213, 0.0376565309782182, 0.036738761475369815, 0.02854316435273617, 0.04128633217225152, 0.018413070732006626, 0.06837580638426928, 0.037849968179099025, 0.027277368766766404, 0.0730111669268339, 0.06464465175785365, 0.029935822183746966, 0.020346383624259504, 0.055069874206017104, 0.01764946684782063, 0.030901387912191214, 0.05953915454747696, 0.012445670980659705, 0.06340102292597294, 0.009477717084659925, 0.022039470495656136, 0.09315669761910554, 0.05337955865768656, 0.0671659926733663, 0.0031979265481969646, 0.026100548547542384, 0.047028410143309066, 0.026566515781826554, 0.07425217573801357, 0.03218841754020222, 0.02067307415868967, 0.05302916919331878, 0.07745113674431078, 0.016640061737909433, 0.0583746204633386, 0.016237371450951023, 0.035752339003187035, 0.07818198462407436, 0.06021841023597987, 0.03263999955848821, 0.022771333441919377, 0.07196667498999065, 0.012850060067590208, 0.06690528529185442, 0.07285745904570626, 0.033815097995102406, 0.0892871032438932, 0.04881481609998211, 0.07756377465181774, 0.03296383258496081, 0.027071415604422652, 0.026846444309358636, 0.0298248294500574, 0.03946889965464512, 0.05359700888455395, 0.017759203197314374, 0.0314077701149208, 0.03992432743431099, 0.03801091942155073, 0.045765487387055354, 0.024687359560160868, 0.03120652456287175, 0.03002301256562914, 0.07542626676900734, 0.039788281710277644, 0.018383513144668073, 0.02160847709033518, 0.019504351488825296, 0.030794047502680656, 0.053091184010789286, 0.04457172704860569, 0.11983868966419851, 0.051892084039507375, 0.02733100258234528, 0.036417969817956614, 0.10054560798791148, 0.04245547810569406, 0.06297807344385693, 0.16266922526542218, 0.04538062013565533, 0.018895547161059036, 0.05777177821484305, 0.03044947264565816, 0.03853457882219265, 0.034942729623928186, 0.08581471013566179, 0.02364169550879348, 0.05940816500374387, 0.09844679520615647, 0.012636587752269642, 0.10478759004223732, 0.031054523142595446, 0.03225636187820666, 0.036545255326575814, 0.017107654993812886, 0.05186291141135078, 0.07766968630734952, 0.04392313019883248, 0.05266669469194547, 0.03945029520940396, 0.02037777790739652, 0.05128827268978761, 0.0967449845085221, 0.03123766603699375, 0.027492101296722412, 0.05820608878087613, 0.10124226536361441, 0.09839057967427278, 0.046033085729446144, 0.027279220784323353, 0.006579510706116356, 0.025848959527549245, 0.10317073849540565, 0.01684739194329708, 0.01954666444010312, 0.039340154748530164, 0.03559889542239328, 0.03311123939291124, 0.015937015188917998, 0.01796661192671426, 0.011879553072034352, 0.015318819580809965, 0.03767459150103312, 0.05592657500998147, 0.08454914054562969, 0.11294187587355414, 0.0185207903550397, 0.011219608544882749, 0.06942684837286511, 0.06013143627393631, 0.0266079209189141, 0.04937778730245848, 0.07138808708517783, 0.02769898142545454, 0.04833343326144161, 0.018404745271489508, 0.03842210179314979, 0.040418691632728425, 0.06641986133951334, 0.09293581148789776, 0.04166023670545509, 0.037209480370004336, 0.015648480621166527, 0.046689450710771546, 0.01107598333844855, 0.052172667572214726, 0.03974867113415272, 0.02588855095147606, 0.07315415723790085, 0.058040510367361776, 0.09470237193689232, 0.09253922309125624, 0.03913139195872411, 0.05250433001727347, 0.023964264490191015, 0.06438376817611918, 0.04047277360974301, 0.03471494487096225, 0.07875206129204843, 0.027735600428235148, 0.02244930263728865, 0.06218525671189832, 0.050845749661206245, 0.044252452245282556, 0.03733024647038791, 0.02443148044779176, 0.020182467621540832, 0.0225774921296585, 0.04393816850478611, 0.031350190946531874, 0.07665671122771117, 0.04609764395882526, 0.01739588982966398, 0.022032022205812317, 0.02892354424411972, 0.06133116826775575, 0.0070334067887386255, 0.010916078763623393, 0.026053238787778446, 0.02480584080331028, 0.009475546183004495, 0.04665728650927063, 0.07244919546909871, 0.033495846174417004, 0.019282174499465093, 0.019978136650376746, 0.03988026205690638, 0.06276423915199215, 0.05314673687661848, 0.040865880136768666, 0.04480012850235066, 0.03394102369765601, 0.04169616239866422, 0.05104092588167518, 0.025127105520016728, 0.005529420581766435, 0.04277600163233377, 0.10860271556603332, 0.0609865129715012, 0.04988617474032987, 0.02733390414035849, 0.08124272038619365, 0.0650754459803143, 0.013800468746452563, 0.08761452646144936, 0.027167950343761234, 0.022313871698814536, 0.053455497123180866, 0.057290801402902415, 0.015861188763782622, 0.0416284708696748, 0.08475879582786754, 0.03304312651556346, 0.00859520199047702, 0.060956451681352435, 0.04954169181385829, 0.05900085903704167, 0.1457994635547361, 0.020046174834151904, 0.05190614941379717, 0.0872589850557908, 0.005095692242555802, 0.06415702913316988, 0.05673098265223446, 0.055469281806219975, 0.04694216013435395, 0.023693448578518246, 0.06481466965088922, 0.032283017907532, 0.02952721195235368, 0.02980933915222845, 0.048104139315264846, 0.03678293027464421, 0.0462215893240946, 0.024760710563690915, 0.018362451472409794, 0.04534502386025364, 0.03670557454648999, 0.04266642807652393, 0.079105741104051, 0.013902029022574426, 0.01251093975658859, 0.0881723533835142, 0.011702522601661904, 0.11659569392401366, 0.13747080079009458, 0.03427152168906985, 0.053086399791702155, 0.02890996342044204, 0.01645022323505292, 0.02942213724787918, 0.055792187866304195, 0.06251906420314504, 0.05580517688706037, 0.027811418234881376, 0.02348281078851752, 0.05718767830741502, 0.05200625795330252, 0.03795363136657304, 0.03977245050332239, 0.006249132894745638, 0.042064271476720615, 0.03614418914601688, 0.028738375047161698, 0.09889902456873849, 0.058574837542349295, 0.04665715244388388, 0.04157576785092393, 0.03497596251808348, 0.0420445102387138, 0.026683294394564246, 0.022901932280811093, 0.04051831753684148, 0.04351599660191325, 0.06492735352367163, 0.016163593353403193, 0.05021502947314613, 0.025166683537404866, 0.08013493426504635, 0.07332289576410286, 0.025995136764381203, 0.09675422352888892, 0.035083670649797685, 0.043818930749811476, 0.028556923291856245, 0.015066294018329393, 0.050655568334003614, 0.002800516043451705, 0.04354525349974152, 0.019260272045709917, 0.012577754114904712, 0.04964520561418707, 0.07730287574832478, 0.05420949234957657, 0.034576803896455996, 0.023767247743483995, 0.02501567611621032, 0.029561402456414317, 0.01759647654609815, 0.06786113319497916, 0.10690807545137022, 0.041084061977603746, 0.01958499181895487, 0.018368764036905863, 0.060468430690948045, 0.01097023543421059, 0.07725971435467083, 0.13622788441998346, 0.2695355948901946, 0.2298024140538708, 0.1726261925913634, 0.11447968246835856, 0.12115695844254187, 0.2036279475977344, 0.1880531349489766, 0.2582117122027182, 0.09715455043460093, 0.22999359895625424, 0.14757548518959554, 0.1050661396115057, 0.12693876956379221, 0.15441703339738233, 0.14492914170747803, 0.14570695077700002, 0.15696438299792428, 0.14585659839212894, 0.14967517897246346, 0.1547354042169548, 0.15712800405679211, 0.18652290496374332, 0.07484426211205221, 0.20003059788817362, 0.2111822793320302, 0.08172759275522926, 0.13691197029284893, 0.14502301812171936, 0.08728725370019676, 0.18456657687502523, 0.1616848788915142, 0.16024801970249222, 0.11855220587383355, 0.24640108789167098, 0.13620776695109185, 0.1934917769845455, 0.144855719840815, 0.11234424302294371, 0.1440464245576051, 0.18158506992603504, 0.10134518161536225, 0.19668636362879507, 0.07268189467609891, 0.1931484316986415, 0.1583508336015286, 0.10183253610927252, 0.11895130703886671, 0.20149045503668248, 0.08359841010983914, 0.1419129462972764, 0.19150871242727005, 0.08459064718936721, 0.061737076123996135, 0.19220427429724127, 0.15318959200334165, 0.13116005958328325, 0.0795794822155468, 0.16883905225944135, 0.12082158047105036, 0.25805417388196916, 0.20540435227655596, 0.1817755959928036, 0.14364363084877693, 0.18462556564519483, 0.12036107735888613, 0.16316466964781284, 0.1569928048599151, 0.19597659848870772, 0.17194397597303315, 0.10960713344355745, 0.19950408097957412, 0.08592220759319683, 0.15000746194874087, 0.17566313366255454, 0.13065695432164978, 0.17286407821361097, 0.14558328886426267, 0.14356988722518568, 0.13651953409275702, 0.1578892043401157, 0.14032179700030437, 0.11923887346300388, 0.20819508801064185, 0.15686681403988795, 0.1261857587603792, 0.2915549843061355, 0.20078349377839796, 0.1056612060675698, 0.250716936143656, 0.1185205357990438, 0.1869724606794696, 0.18248778197073168, 0.18329347664069745, 0.1265208456184595, 0.09775142485816633, 0.19726048524100936, 0.08271941614727821, 0.09222682775749315, 0.1750292418704879, 0.09226738445220456, 0.1403236509330811, 0.11363501690568463, 0.10759344069106926, 0.14013911567388043, 0.16550514486528214, 0.1849489773233091, 0.24389305392340307, 0.21343404156786783, 0.2707306001215212, 0.14002038736737546, 0.18776995820864556, 0.06607207274364849, 0.19209650104805348, 0.25059810058484155, 0.15317477586288608, 0.17302889436964067, 0.16869401649361657, 0.15362751850437734, 0.09217677157252066, 0.21844362840056422, 0.1477513023682179, 0.2148670549955099, 0.26275927140828104, 0.13017623414916377, 0.17442847572026715, 0.10161767909002882, 0.09032316055269012, 0.06259204556925163, 0.1306015814864828, 0.12426355222780859, 0.13220445192869634, 0.20979567551084105, 0.20004290126023755, 0.13837696023045049, 0.16094508310479505, 0.13018726581527343, 0.1958162869296728, 0.1183613733718953, 0.05161892772922593, 0.14988727807517976, 0.20025806471465096, 0.13308346121301576, 0.18025566222927264, 0.18294790969981303, 0.17310711194670972, 0.10567828982828126, 0.18363256247774248, 0.1983285497032827, 0.1314779247848257, 0.14711353417125442, 0.30666717177917885, 0.2016530188942148, 0.15606806012651614, 0.05132569608488872, 0.08836258067599229, 0.21600518585933795, 0.1631898586187632, 0.14962205843579385, 0.14728794174809612, 0.18699870685175543, 0.20057030683082921, 0.15787605827133502, 0.0806141222616838, 0.08786999380155917, 0.1528983713398057, 0.19211609757715659, 0.09025855635803554, 0.24225580145514783, 0.11901135301037181, 0.19229776766752044, 0.09483574784450954, 0.07322699687774144, 0.14188769603929213, 0.1460168946294054], [0.03792104198627415, 0.05755530858051874, 0.02516278606509009, 0.04991121432413498, 0.006741499518900509, 0.013484871165165979, 0.04965362492047491, 0.03791317043285217, 0.04737726743182829, 0.00640191859753442, 0.06383057225555663, 0.02426918663625275, 0.10046389704990773, 0.04975996175480466, 0.013292207713088682, 0.020092636151539705, 0.02811794341992467, 0.037219631035001054, 0.00821803296510611, 0.01707904160984101, 0.025958481372424194, 0.058109871968026125, 0.057915603561747464, 0.03243894361320042, 0.03431354544215626, 0.02944631498276947, 0.051298898329297384, 0.07066398844002716, 0.02252395982072959, 0.03348623943184653, 0.06329169068785925, 0.04693164174715358, 0.01681097978425603, 0.15713862203542264, 0.05368458422561807, 0.02649794708216383, 0.06078662147985832, 0.07950488057348036, 0.027767756968856822, 0.02124095406954087, 0.06363665624972313, 0.04828135460434903, 0.015217548502879518, 0.024097452706266797, 0.04000703428661631, 0.04673080030648459, 0.005652910124720825, 0.043323459554343455, 0.04580083468388166, 0.02789732924993, 0.0029293478526655706, 0.09153128887015967, 0.004712635831486795, 0.010755789229616283, 0.0738470761045333, 0.041980806197370255, 0.024817140600193414, 0.0499704405815611, 0.023419156542889053, 0.04217919232624193, 0.0783665122223958, 0.059800107077124624, 0.01922564870197206, 0.013094239102135743, 0.042172389465474316, 0.05661842518395955, 0.021573035947738156, 0.02876014918118956, 0.02388353605995015, 0.016292200363691778, 0.044424393019008065, 0.014516374081253045, 0.05223802253303509, 0.05038332749879168, 0.03245312390067885, 0.04755929375307695, 0.07189348294970489, 0.03292701822975951, 0.08778203924697253, 0.10277146879102915, 0.04871058600744413, 0.04516052690544917, 0.0270849370562862, 0.023208256367774262, 0.048927691494745594, 0.029623689235097943, 0.020265174473846154, 0.005668545500450438, 0.03442375485094325, 0.060977044124757095, 0.03552114515895805, 0.037377276608059486, 0.038896605162130254, 0.0785127507462617, 0.03184478497132659, 0.028133987216278914, 0.05404712767490456, 0.06586220295679185, 0.0200447958758882, 0.10489006962386832, 0.05761461527717691, 0.04594805763073025, 0.029966992386166128, 0.017628998893703667, 0.08199517194542193, 0.0745875766921428, 0.04138885771915798, 0.05078311048207745, 0.01864946056758204, 0.05137706228021172, 0.03910181330396764, 0.08148779957405022, 0.0238789816672403, 0.05332437351406102, 0.0079890895041547, 0.06643128371046436, 0.02321319955010568, 0.024587821756159107, 0.06742934305821696, 0.0393263804876516, 0.03259765787891323, 0.022782577697428006, 0.06019137116269239, 0.040830119152463255, 0.044252000253407225, 0.014718554260569715, 0.00817679062170247, 0.050485607897562366, 0.03851294832965059, 0.057814027963867115, 0.0597183310216473, 0.057855948295083746, 0.06846432018304063, 0.07523829177502664, 0.07113639655853472, 0.048435449359878424, 0.030259812258244045, 0.03746520051912915, 0.03197300510721342, 0.03757935911116581, 0.07205310502960798, 0.027864829884962212, 0.044494589655509884, 0.07185902431487076, 0.04847939599365477, 0.029049176918042284, 0.04927307840496783, 0.06000652180744275, 0.05492748527397072, 0.03363324404363671, 0.028260734548131307, 0.047364197971840064, 0.009160025210510339, 0.03108254855408544, 0.012548404328915621, 0.009142391781713213, 0.023322552855637287, 0.1011046683115344, 0.01715276225079452, 0.0927024381235242, 0.07986220696400251, 0.03949282075008077, 0.04132141899918357, 0.028246874102361264, 0.05256255269951878, 0.04638388888129304, 0.035191788638551394, 0.02279507067625321, 0.017668454337023923, 0.0124836124427196, 0.04598508649055035, 0.03272308945475567, 0.08088881840869304, 0.02251340887479244, 0.041046381943048015, 0.05605230919055401, 0.03182975624147202, 0.02252405941215975, 0.041609000745079214, 0.07938470436079849, 0.07776695649109541, 0.022521018043100353, 0.03370319553200276, 0.06006657160938748, 0.01819373209840588, 0.005486387029034837, 0.038379457508844715, 0.02984812618383477, 0.025340231180551554, 0.022912967777360353, 0.06894899336921592, 0.09730915463859997, 0.05936120381398548, 0.041544059471737955, 0.031712435621527896, 0.06418438613294594, 0.042739631608128555, 0.05835974686628869, 0.03987367370075757, 0.012648982097274594, 0.028433464392418825, 0.030531294666410937, 0.05102798282619446, 0.032487954088156266, 0.0143923559376309, 0.050848653134439266, 0.0805831952921806, 0.05623779822922042, 0.03709834399482897, 0.06733497634770409, 0.024536189345282414, 0.029162492813362233, 0.015958071115516847, 0.08899069616510984, 0.04727183841168881, 0.01030374660096582, 0.051394406510817434, 0.029453893507560416, 0.034032935096371564, 0.012870477268382186, 0.07833438249485147, 0.033555984076473026, 0.05471550491488269, 0.028836614332131805, 0.033529871969573924, 0.09756572514532075, 0.012032593499057958, 0.05606272798632422, 0.018682362128710075, 0.018027387596967242, 0.08915501436398876, 0.03469026534848156, 0.027011001910713893, 0.051641446883760156, 0.06301564239566365, 0.06886047957044455, 0.08831996320476455, 0.03977788206670554, 0.019341588448432666, 0.008405481273638866, 0.04480320434536665, 0.007319068047969092, 0.011920827974174774, 0.05377943357152324, 0.04375173717797284, 0.05864021165536777, 0.06839479770391219, 0.06346099994956486, 0.0354374117488342, 0.07989860380128508, 0.09469916968936883, 0.07525864673117477, 0.028817914125900117, 0.04633587049019914, 0.07024191229814483, 0.035795109691999616, 0.03409476988317986, 0.0763254548092523, 0.036724217296127355, 0.05412315424051016, 0.026803872803406372, 0.03994375159363112, 0.019973023013482173, 0.014089874739217904, 0.02648259851060087, 0.018473049670818354, 0.0385750359254739, 0.01330464419292947, 0.03984039867176645, 0.03318226340437128, 0.027059818948468855, 0.025386372656230966, 0.02662206481721613, 0.07096195833817606, 0.02480099146674958, 0.015683800147305575, 0.022434626307879246, 0.045267794536606926, 0.011734679142283577, 0.036486159304096814, 0.05012798273274976, 0.02828346437684471, 0.09083107684648807, 0.07069357475566287, 0.024480931423304063, 0.031914688579197374, 0.06094304897311715, 0.07935233714599764, 0.03111697271496298, 0.07967971715955965, 0.02592042595478556, 0.09293756582924435, 0.044577572299467946, 0.06050088983629981, 0.020343273307286927, 0.06293700347023626, 0.02136243071647421, 0.03651792513987711, 0.054930430882039576, 0.004611448544423066, 0.028961630305275324, 0.009730838280501626, 0.04725332972743819, 0.032858939826368325, 0.06056481221270177, 0.06401189377591496, 0.012000055829693955, 0.025921220771007003, 0.013492691007653072, 0.06465486370988431, 0.09974903742512388, 0.03311243449007312, 0.029852157721536297, 0.01866688715263961, 0.019900304032489657, 0.041288641927343224, 0.04393848643127469, 0.04271017552743997, 0.04813806551899161, 0.02909351617187983, 0.054855446196011, 0.021257555194860025, 0.03428121653175162, 0.021072964394284834, 0.11360553018147908, 0.03871124252797135, 0.025788444327190522, 0.10296983959814233, 0.03531223681244639, 0.03501709760917771, 0.04081825628095577, 0.05375337509077884, 0.05799875474504887, 0.043290992748112454, 0.03259676921692106, 0.04179328319526488, 0.09511612070303771, 0.02421168790709588, 0.00864809365837925, 0.0535893748183885, 0.04331898943130528, 0.04617367052443085, 0.05469022401338143, 0.04238617396162402, 0.03120377430722358, 0.06569214675936007, 0.009405257615951762, 0.030607748326034318, 0.08471702105335652, 0.05540957291340155, 0.011218639443658534, 0.049719519973281896, 0.20478227356028175, 0.20127688504515157, 0.1264345841181855, 0.17718061594472778, 0.19461886086050542, 0.1253864456028227, 0.19903511259584658, 0.10878632385884562, 0.13999611770193424, 0.19064753766982787, 0.11048713864217843, 0.15119197177550486, 0.2686571984762146, 0.13983093382370088, 0.16867530862650565, 0.11794655974353514, 0.14787298777411062, 0.12964869068274576, 0.09252022411073409, 0.10656176540519922, 0.10122289100000936, 0.19110173587837528, 0.18548666379384457, 0.07665404524173468, 0.16896511968826095, 0.12846502355269848, 0.12189601878485373, 0.12297100868196258, 0.09058268815879861, 0.112067639317003, 0.27207100884087626, 0.2512973856421248, 0.06528956755515068, 0.23586612254861863, 0.1992352760487026, 0.32387718378055486, 0.1195055103650497, 0.22661758736977655, 0.11432228204343589, 0.10379741373922556, 0.18016998295582112, 0.14965912176957055, 0.10097176737843022, 0.11901406496162377, 0.12352534990397193, 0.12021768102121931, 0.12695858825839337, 0.10094315399445834, 0.09768659849801371, 0.12828015887569036, 0.10262515365837083, 0.17716131052903591, 0.13282176557808154, 0.11380715686227046, 0.19203700665985385, 0.12826091474703244, 0.12154001772644059, 0.1677366057711263, 0.11152812189632848, 0.11688394216640342, 0.2380578847782266, 0.10693586146038388, 0.10561764630819521, 0.22071311791096965, 0.11088850742746746, 0.13285916599054493, 0.10404994696258538, 0.10621743186587289, 0.07278951470770183, 0.1061602893676008, 0.30464715114043606, 0.1253524772642601, 0.13927198075238736, 0.0788352431188668, 0.13526103549426602, 0.08557020551374844, 0.24967683389061884, 0.14007965192919777, 0.15895092559437599, 0.19471892726517495, 0.1634459158465747, 0.18575393654886754, 0.0977832941158164, 0.12544043181884673, 0.13454615288684446, 0.09268032116515022, 0.11936914671452777, 0.14054728731993707, 0.1136208366182062, 0.24350435623238165, 0.12543103958089508, 0.18533988134755244, 0.10027845780695639, 0.18543568830336296, 0.0866939492463585, 0.12929380811270208, 0.14180279817552338, 0.18480395687924278, 0.05224075746692477, 0.28763837511501006, 0.12368107259634042, 0.17287006902117885, 0.08528010333858191, 0.1352821335557007, 0.2930038404320517, 0.15501867288783674, 0.22790358852474923, 0.16178134468293962, 0.1290132207495551, 0.20855305025414114, 0.08968534639045116, 0.1813581087175877, 0.11873907770120329, 0.13110312392875073, 0.11903682543385415, 0.17113126393768097, 0.13608113261720828, 0.16403782602039077, 0.1001130900676212, 0.1121291868208397, 0.12103710398678819, 0.12212078898183762, 0.2120858034299266, 0.12360936676662777, 0.1236913075310088, 0.07951970437481519, 0.20431175767894716, 0.07811689013314825, 0.12454544960130608, 0.15153784515155902, 0.12119733893703069, 0.12994617794550237, 0.09861400921738918, 0.1507795406805892, 0.20149374921475688, 0.1741199721131594, 0.10377343518719559, 0.10588713305731935, 0.2473856028049223, 0.14590843190108577, 0.1313432312059787, 0.11722318888191255, 0.10501971468329431, 0.18128595855687896, 0.19329447870052632, 0.137384110280583, 0.1500146784969876, 0.17895994707942012, 0.31780268876783313, 0.2580864108618229, 0.09519794655423011, 0.28720290009533206, 0.2091214262069233, 0.12585114687681198, 0.1709552475761983, 0.12786680081438634, 0.10210476545316559, 0.21040080836223019, 0.05738250212743879, 0.15251906588673592, 0.2110207726758334, 0.15926868354360904, 0.10206436963691827, 0.17798358334168313, 0.22444234199581609, 0.15427133879594265, 0.1692687203326533, 0.12985536588295815, 0.10742854026536788, 0.18810354353439426, 0.12047268870857455, 0.11502340571173739, 0.2747306822528762, 0.08261130581940375, 0.1982030185360101, 0.14439536228535638], [0.03748293162413663, 0.12300771195441486, 0.014581702228996062, 0.04252968521247949, 0.02096593616560342, 0.07381332993146873, 0.025638302585350412, 0.08971028255238649, 0.038741173583172986, 0.04503005830150458, 0.008879149606781862, 0.09409786727760108, 0.040222136453995784, 0.029908491997048262, 0.009619539111642348, 0.05654285061022928, 0.009351896719195911, 0.0213020074466664, 0.0537936368416394, 0.04981320486554215, 0.05236090303608968, 0.04331747640765483, 0.05139839782890293, 0.05850719197863533, 0.09850387641739461, 0.07756029661264151, 0.02445794303991622, 0.04974431823939086, 0.02839657534364491, 0.07444883050817637, 0.030828921740213712, 0.08613338739040398, 0.05107203671228021, 0.048048931189001574, 0.08135386442224826, 0.1287195945699369, 0.04608491157752372, 0.025511312020582058, 0.05372368535327335, 0.039994309566194014, 0.06468975135395605, 0.02325424462586882, 0.05237667678645062, 0.04685154342423043, 0.04921229698905542, 0.024401587696986336, 0.01748509502278701, 0.03998049700091924, 0.0640997257564337, 0.020100524941939982, 0.051453356976590814, 0.041860974724254305, 0.02239552709544378, 0.027051326863828207, 0.022279782701403867, 0.010693180694004462, 0.04860035744645903, 0.024814543562130104, 0.007347704893383648, 0.06423027096917072, 0.024656365557964292, 0.0018353064261910116, 0.03256791068481342, 0.03246445434107896, 0.1539561242586182, 0.012063975333266202, 0.023843134498043407, 0.011050795325108114, 0.03996165123798194, 0.04854969988246599, 0.009318117987394575, 0.06882526250856538, 0.039149207333403255, 0.049210872065516255, 0.050004983486066905, 0.0202569141308026, 0.031992655262471206, 0.024312156507925644, 0.02363825960445308, 0.09046921521545419, 0.051295316868251374, 0.07011017581868557, 0.10083073825244943, 0.017596053282519983, 0.054596087129245845, 0.03404655997010489, 0.04351174864437311, 0.013176313931903532, 0.015204209954507891, 0.06294610076433708, 0.03200934448790166, 0.021783231321962613, 0.06272674297853824, 0.023452868241997018, 0.07871816956227826, 0.10360729369905688, 0.0601669789231833, 0.07563006147862443, 0.04886841161116477, 0.04015842092133338, 0.051037286964034846, 0.0379381257469856, 0.03765398373586997, 0.020050235100150592, 0.039364501022763794, 0.05522483081046132, 0.03816446642421427, 0.02533557336597193, 0.031842034715678424, 0.10404716606342024, 0.0327340828164691, 0.02069418945710265, 0.021874820963749965, 0.027232611995010127, 0.005048433714921797, 0.021215238413142583, 0.006385024922389177, 0.025714987986570886, 0.049505130267672004, 0.003805415119953274, 0.04782797994032022, 0.09468027030027683, 0.10433566711482503, 0.06816581402334475, 0.01785604245660286, 0.019097177672290036, 0.061247680005767656, 0.05417923953744674, 0.07462681571562445, 0.035515085403477, 0.044429092968423525, 0.030397064570758133, 0.03544844724538346, 0.06420846427640607, 0.044276725741163384, 0.00571114860752958, 0.04160081126516865, 0.0572162380652322, 0.08385824415111735, 0.05454110499892024, 0.03164328469504272, 0.03123956018938653, 0.04402368689977354, 0.009497960958059036, 0.07432878453044162, 0.02291701080638074, 0.03182877181848932, 0.07818878748484197, 0.014750702182702241, 0.05701584095555929, 0.0018610086760506217, 0.013279279021756544, 0.04919487231921765, 0.019237023192427812, 0.0064206044396175254, 0.03131647541698429, 0.08299871648271238, 0.04769464999797845, 0.027698014239450137, 0.13453596391745154, 0.025996670855449575, 0.0873505478845008, 0.060763880159826054, 0.006499099723559114, 0.0629735573555433, 0.043027144406111016, 0.04211703195206581, 0.02714073698547098, 0.04679476864816201, 0.024217577208013787, 0.02038916771961076, 0.03943585445203128, 0.02345585598490171, 0.05395151990195436, 0.03178266673198631, 0.03516099190399532, 0.012671458159363078, 0.08704480219392047, 0.014904747142516559, 0.014921885486992617, 0.012597504819202568, 0.07249585788456664, 0.01917498156187996, 0.02387490607948313, 0.0730012154446975, 0.03267588694730113, 0.02574227986887338, 0.026236803030535102, 0.011017889933540456, 0.007602894047815954, 0.021324449992408196, 0.045693115060848576, 0.020989165866687413, 0.04108844017009101, 0.04518069417005585, 0.05837398077992182, 0.058080668696352554, 0.006444763501114663, 0.009396069348909923, 0.0603433208720338, 0.06863447597190257, 0.021995654096826914, 0.048362092610688946, 0.06080064088887265, 0.05486792576829753, 0.02055759214976382, 0.020044767147591038, 0.0588456764366598, 0.03823617225392692, 0.06804983597248793, 0.027229461458421526, 0.039812501580003774, 0.06309162299599379, 0.03283373936409912, 0.025411824012295376, 0.03178967260605386, 0.04940799797975248, 0.08485053485680012, 0.050188561135362235, 0.04296846973199037, 0.031852221769851544, 0.038766098253789454, 0.03246043620991611, 0.02768266375266737, 0.01601691049854121, 0.005428736039903016, 0.04316686352174129, 0.056787811054457585, 0.041508704514032414, 0.04504181392070267, 0.025439351466634584, 0.029636214772659927, 0.04188945021239981, 0.012379415866528309, 0.047952350484387535, 0.04050085073216789, 0.04583026012105327, 0.04818324938476567, 0.07664744156382738, 0.021586574636580005, 0.04301176136059146, 0.08417892855622115, 0.05742111678926214, 0.11435357673514275, 0.02440815307049742, 0.05379296651470566, 0.03154913823480808, 0.011376728390103147, 0.05194163077601022, 0.007763840981023087, 0.0687155893613254, 0.016587446819269852, 0.06957880191264615, 0.047358885152085174, 0.05937037005599949, 0.026395515381028096, 0.04120535284821545, 0.09508369986208216, 0.0910251958656215, 0.03735099213137742, 0.008500005989786117, 0.01106646373837946, 0.015095414935551105, 0.007541945050170105, 0.028781584321310925, 0.0385236352561943, 0.03751211957405171, 0.03550274755745646, 0.05543222230288291, 0.03881475632830012, 0.025018116106249155, 0.06029953511672155, 0.02329470172915007, 0.040790543050294926, 0.03954045226677291, 0.052495121640423616, 0.015055713386485174, 0.04140091211264653, 0.01714910609617589, 0.015525880697814208, 0.044323656287404804, 0.05759055245547526, 0.027382368777668285, 0.01073397200314268, 0.06763730528614215, 0.05777924757210478, 0.07180693033601969, 0.07031606194833595, 0.03227986545572358, 0.04712606720145672, 0.030250197854794325, 0.023980515130284815, 0.013405491049671847, 0.09701425675302745, 0.01449785486329347, 0.024310093816189517, 0.024767218480607676, 0.011791214515875665, 0.014442311573563325, 0.037945587443368095, 0.03939917033177711, 0.048796897303433194, 0.02835049707021925, 0.031182398538916346, 0.028835557130796295, 0.030774165605825764, 0.06219474088040091, 0.01563960549256374, 0.038359972062490644, 0.027370645717206984, 0.010458961760084476, 0.03018492716364563, 0.06886946578179637, 0.046604763521181966, 0.06456189127939363, 0.05206518160599855, 0.059241931585054246, 0.032909719964429256, 0.07796424711423536, 0.027166341559120247, 0.03794775930263343, 0.09166338541094335, 0.023969259383457325, 0.01888165990221164, 0.020678626380920894, 0.08440521560729512, 0.012203686788017231, 0.03814357903695876, 0.06604307631571447, 0.07577548794929059, 0.03433809856012945, 0.06399549183345611, 0.032571668346082015, 0.02087571590598072, 0.062119560841951645, 0.06416193592632491, 0.053949918778192614, 0.017627459056975863, 0.018283082848234523, 0.017205361847675616, 0.03491944438146968, 0.044822820026667855, 0.003524768145589699, 0.03288484125908825, 0.02647793111992219, 0.04933831462215993, 0.018442517236596154, 0.026165085709503582, 0.060454468738528035, 0.030127443756247242, 0.04443781870988108, 0.10317444636095917, 0.15806489894467016, 0.16723797446297062, 0.11954242814212077, 0.11708251981725616, 0.09958634333264443, 0.13996584190716668, 0.13044534551520504, 0.23510461583012537, 0.18043846612976444, 0.19036914131814436, 0.07476484177694206, 0.12585233431309462, 0.10535024331822511, 0.05758194162720635, 0.1183427267918183, 0.16298954194832235, 0.09372374057889947, 0.1620978768914938, 0.1762778426129972, 0.1502356029325916, 0.17371993632085864, 0.15515583326979993, 0.1647518965746126, 0.12096905239647436, 0.1876456527820518, 0.1515277634344755, 0.10075190780504097, 0.13201824659782072, 0.10679945950546574, 0.13758323185386198, 0.11764048463514737, 0.13184491154407302, 0.17721219408896663, 0.18423833884298804, 0.06551157983560717, 0.1618133058711406, 0.17732407356942856, 0.14923875400375936, 0.11950320444039761, 0.12775758731990092, 0.15604261068567155, 0.0934733447408484, 0.11781063276313006, 0.18708921247912993, 0.10451775855354725, 0.0914400018331024, 0.10430628764292887, 0.19077365106392294, 0.10211365207308724, 0.12533689503588025, 0.17403047772184496, 0.1672238478016469, 0.07142120506614447, 0.10779095347970725, 0.09850632023787308, 0.1345396258177296, 0.22908261316197537, 0.12383893267401766, 0.20370665547107497, 0.15840355577247758, 0.16551916427429647, 0.12634233181034366, 0.17842676520587938, 0.14590051055194872, 0.28567541270486774, 0.1081856343174173, 0.17455993640807368, 0.15908823919392404, 0.14775277325703254, 0.13167238854352506, 0.10912642859282995, 0.09454802820278753, 0.10267559288730545, 0.13125335377070213, 0.23332238888307927, 0.10370557511886282, 0.14485994864615703, 0.16341082901964266, 0.2145143174716542, 0.15892768248675332, 0.20676785088594885, 0.16977470608488207, 0.3098498380953266, 0.09259903157550482, 0.1416343354409741, 0.14408521925009068, 0.1473573493140359, 0.07415734171386688, 0.07814147389463841, 0.22188834275209138, 0.12532619278757803, 0.12385346536194125, 0.12382369518520371, 0.12128773731209579, 0.15421429588910074, 0.17449086592082055, 0.15061002074470445, 0.16321495565916264, 0.1464857097955481, 0.19836345266911293, 0.14378498939256515, 0.1379982370042032, 0.1869590234972777, 0.165330691323165, 0.08033819271311646, 0.3030233205326142, 0.19935610343612012, 0.12270892234218699, 0.15513229904876602, 0.1577710889039501, 0.1308685937716115, 0.18104992686740815, 0.17882695421576503, 0.222809165115318, 0.16016678373900153, 0.09087260647286331, 0.06967327587546841, 0.2327368678825517, 0.15123412193309876, 0.14596870769896816, 0.09849132023631565, 0.16598414900081773, 0.3797983846837475, 0.15520641039456093, 0.14966422391514625, 0.10790434981425924, 0.1232336925703191, 0.18375092306204382, 0.1297307540211947, 0.1394189623815398, 0.16686570169704576, 0.16970137614876996, 0.09523472643547481, 0.15601590486063113, 0.06776885024362034, 0.1351861120952714, 0.18410595884967237, 0.13181730173528194, 0.2736468823446382, 0.12495546751926023, 0.09947905271884896, 0.06745998657518817, 0.18936726685252883, 0.15263094536719785, 0.1118222690157352, 0.15607081804304354, 0.0779020254530253, 0.18530962087454336, 0.1596683056484307, 0.20703423497897966, 0.19331507114393098, 0.07947482694421085, 0.1878604331925031, 0.15153297283236059, 0.21038573175188036, 0.16352117632425603, 0.10955818808607518, 0.09978317430302983, 0.13465775657565365, 0.18464389046834362, 0.08276135946113257, 0.10258308010956935, 0.15498950025968014, 0.16260818337961552, 0.09263857703415618, 0.10823575178942374, 0.11192307852569128, 0.08894588768241868, 0.18653877830553442, 0.18580678129388442, 0.08478396947705939, 0.13968960592342963, 0.10586801916360856, 0.19254519874530454, 0.11040218715225497, 0.11653084458122331], [0.0838484995127205, 0.034638902983598174, 0.014193302354655199, 0.03234177302088469, 0.07534244142833256, 0.062452111949002555, 0.014130146066177518, 0.008828992872769314, 0.050831174838446805, 0.015068284889322617, 0.05538954737506086, 0.027095405647771496, 0.13392965129065898, 0.05832732985577276, 0.03580877287012916, 0.04304261938218148, 0.005040912646725173, 0.021063022488247485, 0.028860922301969225, 0.003209298884030432, 0.11754431761801244, 0.05069155531424669, 0.044498818460851915, 0.08910243008886615, 0.020144969532867114, 0.020595427317124222, 0.0396616512068337, 0.07180695331865741, 0.031826435250320265, 0.052261215844942685, 0.014185312057604954, 0.005317080640158947, 0.057808699822353746, 0.0554903147501811, 0.03150154310729235, 0.04422106562302478, 0.012871112163749435, 0.04123313119634986, 0.03737998855931144, 0.026103718236329097, 0.07858985749584052, 0.028264831203306397, 0.02809442643586907, 0.027507248770205245, 0.039483888164883664, 0.06410803781041215, 0.0765554344041213, 0.00745471109703724, 0.05346637940214527, 0.04305086248824674, 0.02575787741901173, 0.02567213685852626, 0.012775451722254437, 0.0628506730220491, 0.010821419982089391, 0.06620105896745959, 0.03390113732987835, 0.03184276058398668, 0.1044476078823209, 0.04231993033881149, 0.05660571961573536, 0.0060186630036051, 0.031044481645127943, 0.0320892627801626, 0.023881504011730996, 0.036979661653599435, 0.049182542134076364, 0.025732046849424803, 0.0032931943696307684, 0.05937372169066822, 0.061754014328001976, 0.011363489433161674, 0.07163135064465385, 0.06420661417406894, 0.11168922252592542, 0.041489268863393415, 0.027359704066428448, 0.04291871232130835, 0.04315844804589306, 0.014740281471712215, 0.03191930617416098, 0.041142422555675434, 0.03016819005771991, 0.032164285770587386, 0.06805984874165828, 0.013636545082854648, 0.06470464410320406, 0.03683571756306676, 0.023188960528181448, 0.02847447307900556, 0.003177866296497204, 0.021937255214359012, 0.02639879615256383, 0.030630085534686526, 0.031030973599803065, 0.04470724034153166, 0.041828630492091186, 0.029763609448808338, 0.06919323752123503, 0.0396323521741696, 0.04687907662422908, 0.02848253615440861, 0.006350371413939303, 0.025931426977378227, 0.057638371663708846, 0.07392252044331643, 0.034014188924864415, 0.04397492157295347, 0.11187969496653927, 0.02412824177994363, 0.028597681084647778, 0.06921624314160117, 0.0660334006252308, 0.02082639325019573, 0.02436656024186842, 0.03261438923917952, 0.03865397362519176, 0.08472861196365088, 0.022509664620062517, 0.007846558845842318, 0.04966854065236065, 0.08473924526403989, 0.08131726074122614, 0.03960173163983611, 0.017811341226221095, 0.06049035995778057, 0.013130499958811749, 0.05461443110459274, 0.08138548853176256, 0.04072337246109401, 0.05211478579909571, 0.04744492831730074, 0.015610970083564041, 0.04317368170426738, 0.03157178762428944, 0.029893200882079623, 0.04346269220414181, 0.019636796599614526, 0.0178503580842047, 0.14658796721168105, 0.0008096245214654764, 0.030864655911441774, 0.013762925650113294, 0.04382330894229874, 0.039163491042751464, 0.04824231093328807, 0.01565353297102716, 0.05223627202212811, 0.05499829095037234, 0.008101245733879266, 0.020825799532054413, 0.06770344931752452, 0.0006603064438452074, 0.11496142153778385, 0.049836156859753594, 0.033270011115218365, 0.020458703605277885, 0.019010182642828555, 0.03205659296063166, 0.07633445634236259, 0.009899467639174434, 0.014612074742364067, 0.041072340832362254, 0.085587166700392, 0.01062953410925524, 0.06514039491453479, 0.09951733413242525, 0.052221210733536756, 0.032704343283248526, 0.05565743300042326, 0.04934178500045692, 0.0171394610492092, 0.0824311449222507, 0.019992010502685464, 0.053567089320671175, 0.04997645820220632, 0.020736161499254165, 0.04617262481441421, 0.014962448884973363, 0.029454537021416812, 0.07145816114761176, 0.01592952667945816, 0.050366971521608295, 0.07329822007206178, 0.06942625082428418, 0.03818594752961109, 0.009143223944720964, 0.027721090722949277, 0.08684420973182687, 0.07002700165274643, 0.01047721763532008, 0.020924427606646093, 0.012819541039906684, 0.013123783282935621, 0.034068918246175015, 0.017064899626758792, 0.12665724757337762, 0.09076191442868403, 0.038098927602292075, 0.034708774032732176, 0.034298897841044014, 0.043352563234586874, 0.059911473278677276, 0.019708331974764026, 0.04867964371618244, 0.038964928713657206, 0.07237843192753292, 0.023086768229522055, 0.018301114642752275, 0.03896928775394636, 0.05559946312719295, 0.07089710899538572, 0.02182386654068626, 0.013802129242028442, 0.03999648142545935, 0.051112907503040574, 0.06893084474628972, 0.05588955381104062, 0.024251110791679353, 0.01493195475514738, 0.025364732587589853, 0.02837381487141454, 0.07620654264164549, 0.02804370566962227, 0.02459990296272501, 0.04571269243775357, 0.031245313509697878, 0.04374978748420554, 0.049902963557190476, 0.06036420825928931, 0.023790927521223505, 0.03242814943434731, 0.010140296954271055, 0.08535930916907326, 0.018175269379430724, 0.04276515382732596, 0.016448924716021267, 0.036208766527594104, 0.018395255357327483, 0.025559092924419432, 0.0068139623392433415, 0.014692767741038434, 0.02604101393972674, 0.029986236514824054, 0.028656547280749487, 0.03338662884949196, 0.07007922586654464, 0.04273497762398855, 0.06374637536223858, 0.0040871820191011555, 0.09471703485976304, 0.07457338108290588, 0.03987159377204315, 0.01427980517262533, 0.04065736249509839, 0.006289465029934242, 0.06794194781011151, 0.03401778187722929, 0.014262888036037405, 0.03771991326263355, 0.1105749169965425, 0.05855825939966787, 0.028950832295982592, 0.030226182913587942, 0.02310378112710051, 0.018880420754994118, 0.028588641247141267, 0.024961195773475116, 0.03982888053982489, 0.061238758911889415, 0.04960457231068323, 0.07231511476059115, 0.05524045900411664, 0.050403816520326564, 0.05051892889182895, 0.05115414601600459, 0.05777205017605617, 0.0380802657004566, 0.01778081836809795, 0.03080438777443863, 0.09138494309398437, 0.031072537700134902, 0.05480956519022585, 0.08195617040919681, 0.06550483826187349, 0.038024295316708666, 0.010953983836506885, 0.04034025572060097, 0.08226304990990509, 0.03550223427854719, 0.005648247043286721, 0.03614113628563862, 0.029261511592795292, 0.03648111461511543, 0.07025277542491114, 0.04933152325271119, 0.03772595769635612, 0.014491400572531407, 0.06838313784570464, 0.01539126468536955, 0.04530587293688328, 0.03540627410515182, 0.03985682359686302, 0.07999004405592719, 0.09783706582722165, 0.05363770730553135, 0.03982988794544532, 0.08615477656524989, 0.041568061006405664, 0.019617585029693383, 0.01530152801874905, 0.030464426681940115, 0.0231569514594852, 0.03500577099921723, 0.03298216123854922, 0.10066940779647521, 0.01781723244235881, 0.02725523457141413, 0.029537738000433293, 0.047404754666551474, 0.05822943531036858, 0.025476579509314992, 0.04072082138830616, 0.031220559293644565, 0.06631831638514996, 0.02635785641389028, 0.021532000448074073, 0.07214125876705493, 0.026208107292111364, 0.06541585714946832, 0.047282119311632655, 0.035783905656107014, 0.07170329396162303, 0.058162827795792016, 0.03607872310244749, 0.07651909119299344, 0.036218472861594735, 0.034858915774572286, 0.039872926765031395, 0.06365387407582133, 0.028023304748198682, 0.040060085875372735, 0.02805665638598223, 0.016115632418903614, 0.03879393022807856, 0.006942485558665208, 0.03271023066894662, 0.0309602138886769, 0.05612406098554212, 0.02198928790617614, 0.012557783160328627, 0.07714225775412015, 0.1780693239021686, 0.1328541864190371, 0.14258616904337562, 0.14669603157428004, 0.12930638727641877, 0.12122183842884919, 0.11251857399099296, 0.19917283988287374, 0.17322830705633088, 0.19305633260838448, 0.09622753042006686, 0.11230567815683543, 0.217610722287528, 0.24682592961095998, 0.05929754190747777, 0.15177255916980006, 0.07847107556318084, 0.10196487779819197, 0.13459979436330258, 0.09573083731435961, 0.22009061018545784, 0.22296403745009055, 0.11851533406203794, 0.15740076200135295, 0.09299217257648708, 0.14287830901242074, 0.16162276448261353, 0.2659240725540346, 0.22094288300121986, 0.12829929575203888, 0.1511723292811263, 0.11646113058011379, 0.12396365178809052, 0.2263622349428554, 0.12542466572936506, 0.2896148819596537, 0.11941362577941149, 0.1439441211761967, 0.11487424839287998, 0.10477319525014009, 0.18228276152043574, 0.11995078364927923, 0.15251223238245135, 0.09532277292061238, 0.2155885106373218, 0.12053196859215537, 0.17914774587317822, 0.19454568414197815, 0.1634615593619885, 0.1005731028835139, 0.18730757818106683, 0.07858038098821718, 0.1305050850515404, 0.14550231337066621, 0.1105027208705583, 0.19416738992496846, 0.11411688621005706, 0.11714952186711373, 0.24469389159592891, 0.1709803752601147, 0.08155301663904421, 0.08283493454538046, 0.1300026539472803, 0.2174635721190322, 0.07607528113669927, 0.0999713254972331, 0.13843579578303522, 0.10671018727964933, 0.10990712581382645, 0.14624030118988407, 0.15955942923263197, 0.07929052917226669, 0.19710397347807887, 0.10862703119674999, 0.2141612888343873, 0.14746552092894433, 0.1533244387997735, 0.12714330737869586, 0.13320024365619307, 0.12861142295502848, 0.14693413170114641, 0.10699873429632957, 0.06691030316775845, 0.13141420159128406, 0.24562858015058503, 0.1446236105215165, 0.16722610010014427, 0.1552178404263912, 0.13207528950466266, 0.12927157624113944, 0.15003154775308025, 0.12125493342717811, 0.09529179998583372, 0.1706683170050383, 0.13156306779673024, 0.2109881832955345, 0.1879980838707378, 0.10328102451298507, 0.19851953542280584, 0.13193621390288876, 0.2192235671945157, 0.2534186984262159, 0.11826117673227865, 0.1824807646053453, 0.21737672839193575, 0.18498901307823198, 0.06921769870865731, 0.14275093923412985, 0.21241379631382806, 0.1339070670186512, 0.09630443798678537, 0.262117259084217, 0.22934974802117195, 0.15098459177440213, 0.14513560240307163, 0.069130985216508, 0.07927667064171645, 0.1287481236842371, 0.20723904092465678, 0.14317726716399193, 0.11570052018449192, 0.1444395349150704, 0.24953362141405386, 0.08295006223864133, 0.09425063287058184, 0.153183892309185, 0.09982442813775233, 0.18913911054691962, 0.24626002046129397, 0.2676960339228953, 0.2132240875113395, 0.1523668442161814, 0.21764901136198353, 0.11323050715990605, 0.06906967519992782, 0.09394268850765883, 0.1767940326563774, 0.10332125178988903, 0.11939465744240631, 0.3091405326079938, 0.05688679344471424, 0.09362725946571558, 0.1131321874357039, 0.10692237831291654, 0.11173708769943445, 0.2951896118540918, 0.1837907596341064, 0.1875281042509502, 0.1893551779850837, 0.17834493169380775, 0.0765138971168668, 0.12136482107903689, 0.07836846574660271, 0.16644409286879724, 0.17497486494962247, 0.08198749574442064, 0.1675833881862702, 0.1589116252838604, 0.17696686209209506, 0.19214527020531316, 0.1764201817493285, 0.11934043373912574, 0.1946561693424179, 0.17423258703802863, 0.10330065934648437, 0.15164407090313975, 0.14602237981894325, 0.15573917858062253, 0.14814969873236072, 0.1350896309820875, 0.15841012880686792, 0.09953181319419416, 0.19202677172518548, 0.11512801501779787, 0.11683918730986696, 0.2747316015583854]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.012692493976153916, 0.051879236745017196, 0.06409333275270558, 0.02997310959824151, 0.06515153383295383, 0.028103832080359423, 0.05571364853230696, 0.08993855377118434, 0.032040252305206754, 0.04720112849627772, 0.07889720431018261, 0.044542933633971604, 0.009045244172035206, 0.08852792543268974, 0.02625442305279355, 0.0798352713125848, 0.03314730298194674, 0.014653814085308584, 0.04278270490167122, 0.03232790682945521, 0.024145631975824797, 0.04296771130494533, 0.05245000289212312, 0.0785892446255011, 0.03183997393916211, 0.04766334381495272, 0.0736825663836733, 0.05985310887016597, 0.036246251209729144, 0.039234729558830304, 0.07393922882094499, 0.026909033692772352, 0.03306270006202883, 0.03322611044671747, 0.028424141102380333, 0.09798001783389239, 0.03610944705865076, 0.04756015560199176, 0.030634538420746406, 0.09629419539123775, 0.031213951785297647, 0.055086908171013485, 0.032465603472965385, 0.0858438291376637, 0.12768076402285408, 0.02219970736111845, 0.016626228105216738, 0.0675776806629954, 0.034122345218014334, 0.03298487702024079, 0.1118035305051073, 0.01358962219749247, 0.030970467975543394, 0.04201665911222658, 0.017723177912675084, 0.025501440977677706, 0.04819265694447583, 0.005843839345259533, 0.044112143241950584, 0.015327576923394396, 0.058433379407130906, 0.06306695879527158, 0.012105641897857912, 0.05433226560032176, 0.05697627634470982, 0.03255866017312773, 0.07854789886022769, 0.013437988499419825, 0.023058585770007585, 0.040858315018516396, 0.03681300305611184, 0.037837396676261584, 0.02566115690335151, 0.02873537389771833, 0.04580068529673642, 0.06813446570548319, 0.07159617954805013, 0.06706268571677708, 0.08447460785147645, 0.035352276397808906, 0.022399127708687898, 0.06438392905458327, 0.05310002466543548, 0.04497088567023316, 0.013948206887430242, 0.006632949648079493, 0.005895636943844898, 0.017968724414165464, 0.03243121378604443, 0.06706507591110084, 0.030852657059327732, 0.01155908987481868, 0.03059617656793806, 0.05855741287251154, 0.016623891537047682, 0.11471362273779609, 0.028233505868082567, 0.0130972737679258, 0.01367552938210147, 0.07704884865351262, 0.016399667177709843, 0.07366281663698536, 0.030828619135483622, 0.021381686336451003, 0.053681581160954894, 0.06861183041286084, 0.010603197921638288, 0.03298563161684621, 0.019721093084362727, 0.04087053412090867, 0.07871195658921235, 0.02735703808045195, 0.04955489150879364, 0.012846253568216438, 0.10694223531191388, 0.09610926176631644, 0.03306663392352001, 0.012552146668425732, 0.055084594585482156, 0.0689392717134568, 0.05239080727821397, 0.03708953781413936, 0.02866457588219595, 0.04900671729457475, 0.05700620356947184, 0.02267142600049415, 0.01255268867563216, 0.017489806463521336, 0.024770516489121704, 0.03941788202932766, 0.04730710526928306, 0.057097551893563046, 0.023051648843853224, 0.07309244119472082, 0.02713653116276668, 0.03529902562619217, 0.0283331815679107, 0.057332848138626546, 0.012616928020912795, 0.033496826766960086, 0.019751422505284992, 0.024018162606103767, 0.06190208763244653, 0.04585135818248795, 0.027684699631326144, 0.06715905191677232, 0.026372053938347007, 0.04693482484247896, 0.06480495565600934, 0.05456817854616431, 0.057563126507786014, 0.015383392174337662, 0.04112771749796887, 0.008801755574231428, 0.0027384013951485676, 0.021853345604012572, 0.006804267017756619, 0.020403681255336252, 0.043352517269311414, 0.06548727186576975, 0.007155245891021144, 0.02961824809561574, 0.039886965326243834, 0.04324077568467587, 0.05564611405134202, 0.039320876145915645, 0.03505658944167438, 0.01498079477554007, 0.02434206075004993, 0.0496257929461858, 0.04469284937987405, 0.04379950276005172, 0.033767883996329004, 0.032885101728982506, 0.05945419156623464, 0.02634114803626172, 0.015450090661855235, 0.018946233453349243, 0.043729118432008454, 0.027622190687144478, 0.046686535746219664, 0.09524159824415561, 0.012889756828606611, 0.014587866363956805, 0.06544781067679006, 0.03440484014009276, 0.009706845364323067, 0.030549508406810706, 0.027883277282178886, 0.03804784868994067, 0.008218085633650904, 0.06849360006350665, 0.026431525343908902, 0.03813311044547347, 0.029847023017223806, 0.0530220675582607, 0.02491551012011065, 0.010301118919385538, 0.03280082056599279, 0.04972647605163436, 0.05272256931470287, 0.07845799844231337, 0.027311224107360168, 0.035809994780368386, 0.018098553334693276, 0.02818849628731128, 0.033321519036807364, 0.007982231580817532, 0.05777663521228298, 0.04116001576485653, 0.0781045331349296, 0.13464255739123593, 0.04368033395299027, 0.062125034540170626, 0.04932765833913319, 0.017666826400184826, 0.022777655582514503, 0.014137629787587832, 0.07045535971560786, 0.09902948934224345, 0.09135735626783102, 0.07054719067509137, 0.02717790182589764, 0.02378973433928144, 0.03573193425132382, 0.08406936266129056, 0.05823926804887672, 0.017125631246956128, 0.04950405391413839, 0.0537825055840996, 0.016739155210915114, 0.03423626249235484, 0.01205518926238461, 0.027137061678654244, 0.08780008827846858, 0.0134351922784962, 0.03796157952878745, 0.023184620640090397, 0.1130513804814508, 0.017720575128952344, 0.016940320323732112, 0.016914037762269858, 0.03588769907852815, 0.03225337413530196, 0.08776113270751892, 0.014295027339680782, 0.023654682614329844, 0.012093418965026016, 0.06046019907620165, 0.03271286218096653, 0.052538558825730323, 0.0378770608785412, 0.0320386856554016, 0.06914794640315157, 0.013642928510483716, 0.05373067207514279, 0.02970309424844961, 0.09900541119878331, 0.02805987587048402, 0.06029600345139062, 0.032753537619306196, 0.023601776582279035, 0.030463499715551737, 0.04003215430965347, 0.08184121891615853, 0.09580597521797304, 0.02857627850326319, 0.025401332438172355, 0.035772280271856055, 0.06318253081952853, 0.07888572831307689, 0.10686461528342579, 0.05243380779340383, 0.024496285740526456, 0.023627595660547097, 0.019305291202580257, 0.022221824319492427, 0.02289252663632074, 0.023981273557329853, 0.029799289993881702, 0.043588399571636995, 0.03483283431119016, 0.036612445067974835, 0.021058178897346222, 0.03754064868835192, 0.11040294557930001, 0.04289920389231655, 0.0359121372833127, 0.07629310291620993, 0.03303803203086699, 0.119446896977963, 0.06401132304041136, 0.043325340300197565, 0.10974653080225953, 0.011018050812004555, 0.0075205994465748875, 0.061353534204705115, 0.029207046571818572, 0.03069371105201783, 0.038481722585856915, 0.01682303226252477, 0.04890283194160269, 0.12038249717724901, 0.03757052994783848, 0.04382160439666721, 0.03224013230553077, 0.0314588145533156, 0.014346635810309842, 0.0323763887037433, 0.038698981290743235, 0.0405157971075706, 0.05129648898277552, 0.09761385844960328, 0.039269253311138, 0.014778049606379243, 0.036888558477644, 0.012660876569908955, 0.03268095078848062, 0.04328445418767872, 0.03099891665061155, 0.01555343209240105, 0.053786523715262456, 0.0883597384897932, 0.054483181090965394, 0.1101366304341824, 0.05298924835158452, 0.02577628651183219, 0.08367257508178873, 0.03785469877203146, 0.07239031395123852, 0.02915639475348496, 0.07800587633204076, 0.014555988487817589, 0.0033582421770739944, 0.03367984134163107, 0.04836635588998756, 0.02165493266206355, 0.04285510404095535, 0.04973521328441078, 0.10751683955952045, 0.0470229211233316, 0.0324520935124207, 0.020205936725101164, 0.07694086089970605, 0.011302824845657715, 0.013312160473076567, 0.09214963673824265, 0.024646513667258046, 0.006555266896142595, 0.02765710514429356, 0.030820349216341015, 0.03892304668683679, 0.06881755566404713, 0.12527685672525438, 0.13131185224460018, 0.15286084835327443, 0.1339591303539853, 0.21986698912036037, 0.09880835040202064, 0.09189933283074249, 0.14996393283288326, 0.10574585878320279, 0.15017718106748598, 0.13514848185643075, 0.10760117051822525, 0.15361720696091652, 0.13934284388538332, 0.2522554092349545, 0.09503797207388187, 0.08145616014277743, 0.16596669751790263, 0.16755701943991647, 0.1709651301104215, 0.12048738993584149, 0.09781399125894231, 0.2487122372633988, 0.1390017355762182, 0.15716525125167063, 0.16036161521990455, 0.19250059710635295, 0.08790233037284306, 0.13717599483507295, 0.21290453691636363, 0.11427482289652671, 0.2635478516740184, 0.09939743371139612, 0.19123656735304864, 0.1836732111030048, 0.1140306476924208, 0.10041798540060559, 0.13276257762505164, 0.2842518374804528, 0.13403201595910136, 0.12846353734212537, 0.23943295131527612, 0.21711192244002897, 0.20977324445641812, 0.16251491983571362, 0.10329119816061952, 0.10750871902752308, 0.12830360882705258, 0.18481301203850778, 0.20281538877996708, 0.17963937513770598, 0.07440280394568559, 0.3598064929246903, 0.10847736059898332, 0.1174633804288122, 0.09333542593184019, 0.14913887146019167, 0.1734535828713448, 0.08070458192378283, 0.09564711922599424, 0.2226346809296839, 0.24281745115595482, 0.27754394097193597, 0.1491426865780546, 0.12309083249419929, 0.13009490625512216, 0.09150668212603177, 0.21841997160546242, 0.13906384998511884, 0.14662797232308697, 0.23213472277406724, 0.1585646487411953, 0.09446342145242999, 0.21287982291992635, 0.14010407481222384, 0.13330046327844744, 0.1087077692030899, 0.15503440833380147, 0.1282686752177054, 0.14698264038851186, 0.15958170706947006, 0.20034686962683357, 0.19581746670507616, 0.09994681834453538, 0.08324553469015707, 0.07515761505572066, 0.07302189215777383, 0.17775622376751515, 0.2736968925643352, 0.1137273075179227, 0.07350638148284729, 0.15800931160488438, 0.24489934105546246, 0.3007553938415743, 0.252654617652297, 0.16294702406852477, 0.1544630446381146, 0.22883823111412988, 0.17506912440782593, 0.20190703832814771, 0.14520916216556104, 0.08784339522882816, 0.10944299144490112, 0.18396783319692459, 0.17802418600167, 0.12310446885925148, 0.165099608561685, 0.10076247981839603, 0.1628344704306895, 0.2471506436385455, 0.11811846221286444, 0.1840254123653135, 0.07571424688062361, 0.3239836393585128, 0.13020917592990783, 0.19538439720148043, 0.2181328571732006, 0.14625854940424043, 0.11645569901673064, 0.15170466845795033, 0.11818262207652293, 0.15306611395170613, 0.14023086236369225, 0.15862314721509335, 0.18516631646742746, 0.2682720401114033, 0.23510722052906793, 0.11193216432847324, 0.16375559922908584, 0.15815370385685276, 0.1391135078043707, 0.07897299338853167, 0.2202981587259039, 0.11280215675792388, 0.20312281986398084, 0.304924076603305, 0.19228040811515626, 0.07177515300892054, 0.16731856691260494, 0.18996616374821435, 0.12109220103030244, 0.1429250710193188, 0.1714696909391111, 0.1363686913804662, 0.14505926940229633, 0.1633263295215945, 0.11951416715859406, 0.14021947829713746, 0.20806710536201156, 0.14442562275836546, 0.20637962816944047, 0.15685155356843627, 0.10909121153095078, 0.11680069139167187, 0.1565492246299982, 0.08586630615736209, 0.17912759776076964, 0.11790740498972517, 0.133452118043938, 0.3085316459257757, 0.15561822861913713, 0.1936289220447502, 0.1881156170800809, 0.20426239097310653, 0.08385928603069437, 0.10276900964879221, 0.18025989103461468, 0.13656462602798017, 0.1010044257066423, 0.19804454558799345, 0.16550416427273906, 0.07224271945174664, 0.11250819349961896, 0.17709605515964572, 0.1345006319423837], [0.07075124585460271, 0.060253558349945856, 0.010347250818965897, 0.05833790953000707, 0.027969994604767814, 0.07510932087297402, 0.07325996164112322, 0.02172367756194886, 0.030714969991916613, 0.017381619526854446, 0.06526559666399995, 0.047057958154548565, 0.027094252685445453, 0.04762610428095345, 0.026007813604308233, 0.04412253522464345, 0.050923411824530175, 0.028969419504245444, 0.05028309638521845, 0.019164777270728545, 0.023497877822768305, 0.05524097228302591, 0.03675081969929799, 0.02937971895951177, 0.049654456125872756, 0.014000052845315828, 0.022209009583739024, 0.03356332702922725, 0.04235111777820895, 0.01435572352831162, 0.03927422522176658, 0.03388115392637349, 0.04723613871441734, 0.05932010319684783, 0.03266217014301689, 0.032572457416644024, 0.05457425745384348, 0.02741936124831198, 0.04808237858777566, 0.05176854853127753, 0.034874739320648294, 0.061657226779648376, 0.013839034570170747, 0.038363204953531106, 0.054339524283404314, 0.03709218081747813, 0.030306354014863892, 0.04638704133310145, 0.05514983080267426, 0.03357417483423506, 0.02507362875246233, 0.08240739619659801, 0.047022480622775135, 0.013264361374650993, 0.029958548182020747, 0.06655250180272326, 0.011153358218800879, 0.012342614917865685, 0.04352770625583587, 0.018425948670013778, 0.07148194817766067, 0.021385277373596065, 0.11162690893416444, 0.041597720100394184, 0.0339373886104553, 0.006113025883678348, 0.02558443319773482, 0.07178360295872535, 0.007329392519163629, 0.07047808188344203, 0.030984835954563274, 0.044402988522403666, 0.007191170626620372, 0.04603327342098759, 0.06488236117987864, 0.044300286775274623, 0.060335499114326896, 0.032335207647373604, 0.05395918844207641, 0.026000512786389842, 0.035622383678151716, 0.011482721442476878, 0.027485974508547978, 0.11406527486659827, 0.01912491388558861, 0.03666879466524528, 0.04357966233886058, 0.0436816631155389, 0.07512962220296746, 0.04164583808291824, 0.05280197815849416, 0.05302422792620717, 0.02865138384813984, 0.06082275401680701, 0.02482969869649218, 0.02594378014515725, 0.02495517049195065, 0.0683304769617896, 0.023393647730230324, 0.07154724951232634, 0.0737213687370381, 0.024443783819855704, 0.010024374444788743, 0.05172773902755111, 0.08732578026190882, 0.054123123596993186, 0.07262040079841692, 0.03143222364146383, 0.044014405744570884, 0.049655195400719686, 0.0371999349144678, 0.03059062434570684, 0.009777730522346834, 0.01916368176499682, 0.10423900214053931, 0.11026865036617364, 0.020902257022117416, 0.02340092939595061, 0.08337321090361766, 0.027900805373886423, 0.06872333451023988, 0.05524083438719954, 0.0150402728843713, 0.04951276050339784, 0.019650829415167534, 0.04056409512075686, 0.02548014373338271, 0.023644395968726566, 0.034512192040922186, 0.019633134699336464, 0.06556443224150328, 0.013629711578570068, 0.012479609633315236, 0.008686489027534283, 0.01999046875073785, 0.0375542467490079, 0.0396360753614816, 0.0910683649201547, 0.09681919544574716, 0.04294293219103448, 0.02557795400911522, 0.07664888947000427, 0.06710612290208379, 0.027696018580407388, 0.037355964042006, 0.0752470021947257, 0.009433090547850777, 0.04024707261593111, 0.021238330218400207, 0.04789761733263732, 0.05906671578545244, 0.03975827404628358, 0.03016535170196045, 0.04623195449371011, 0.08002493169999893, 0.07355434624778648, 0.047049764844198386, 0.06439382691056499, 0.015471096792739007, 0.013524060392932547, 0.021731673604658535, 0.039009177952163646, 0.023785647260205402, 0.04501688158920696, 0.10065287561906923, 0.033499140352491415, 0.04903371040258677, 0.03936424055286954, 0.05347011791121575, 0.018536294059407328, 0.037351785032379056, 0.027687601189339356, 0.028691051880859082, 0.1299232259512909, 0.06275804533112435, 0.052452619082384536, 0.041124178171758695, 0.03127872068885594, 0.023053477878772446, 0.04355802035499965, 0.017399172516419523, 0.02105855236520931, 0.04541908541033345, 0.03740569080917105, 0.04387076042832867, 0.02471611850083836, 0.03529533691283676, 0.034091701701043114, 0.040349307049426346, 0.025024068609420812, 0.025639643239217903, 0.03914846805855632, 0.030274203219901652, 0.016608408900097977, 0.07092798233873422, 0.023612415628327478, 0.032470425996448726, 0.01971714007067344, 0.014984992937365127, 0.06783958314166916, 0.07945150722779575, 0.0053891374339019105, 0.023809587507839167, 0.02537913504056633, 0.014996127067734639, 0.08264282267660865, 0.036127538224982644, 0.010944842492350408, 0.08420910475955856, 0.07409654497619599, 0.027967575682146896, 0.05155446526083735, 0.04627734137278411, 0.048064911783102064, 0.03170705385385983, 0.015078921062541346, 0.04836462070083907, 0.024976986760814345, 0.05763294776120494, 0.009705451084300876, 0.01989533212186108, 0.04359352469985043, 0.1060875186756734, 0.1639017228397631, 0.0475557237833498, 0.0456378877823872, 0.05280858566684108, 0.07729858565594881, 0.02449965652739329, 0.020826017867112835, 0.023445492730506008, 0.09101100791726383, 0.03155081022170282, 0.007390286933044873, 0.028919943630875602, 0.04338399199168048, 0.04357789650619511, 0.021368561335088267, 0.0567089767766095, 0.03296032390226761, 0.06025498710392464, 0.018155090623505173, 0.05778129685730223, 0.032259908865296075, 0.04594848663996785, 0.049875173717737205, 0.029045333071882208, 0.06684513206803991, 0.0385391523671006, 0.021851641058381048, 0.05908202988305881, 0.033145560131919, 0.07974396129288981, 0.016572758998541583, 0.04842706452754717, 0.018119383265354463, 0.03097854254226531, 0.001632943343382419, 0.056533534981070034, 0.12923075907653378, 0.038764880173989845, 0.043662058925556566, 0.08585950329659447, 0.05868922213032361, 0.012156320529268875, 0.042504205128117915, 0.04562312526808632, 0.01986971797211276, 0.010343329406403487, 0.04370706659110804, 0.019581408442689047, 0.005634077289517248, 0.06355711334054509, 0.0496634844720604, 0.04754709380288278, 0.026333774439990524, 0.02845382892466601, 0.01683794033353127, 0.018350674785793792, 0.06022060890832256, 0.015316027190325963, 0.07571474483777439, 0.036039756040178964, 0.061828389974130746, 0.01610466587026754, 0.07293622054520153, 0.047477199771111055, 0.045249232226201606, 0.0027642630870574184, 0.02613379293301654, 0.008371857674642196, 0.07997806244079145, 0.018142825555837443, 0.049357087606744426, 0.0678039753749486, 0.03486768365086567, 0.04346700910959513, 0.03121688398682783, 0.08582272341534977, 0.08075070041682451, 0.052879230464778604, 0.01751756182901802, 0.011507542691223565, 0.008232147177501072, 0.011943609513823065, 0.017238615809248823, 0.029808442829357042, 0.03306928841817764, 0.06072656401703435, 0.07610291392812807, 0.0360333017494169, 0.07654693848904102, 0.018899515496506807, 0.012159630986711672, 0.06744078841180572, 0.03551622687448417, 0.053178786164930755, 0.0465058692310366, 0.063415207043891, 0.06329801091323457, 0.024250513243098414, 0.13634488136777956, 0.04827604178459414, 0.022070581326261166, 0.017024630215018988, 0.011498335271983618, 0.0200880894197091, 0.05171130261113567, 0.014832139244273066, 0.05656988585307714, 0.05346496596992497, 0.031513551535505446, 0.014470532337474007, 0.04775345490704622, 0.008092180040905313, 0.016662406607440883, 0.03475933966617431, 0.023384383812005964, 0.021580371239613143, 0.003939736188547085, 0.04598418633723932, 0.0333195923256778, 0.03777224472874115, 0.052034055453635035, 0.03058480399270212, 0.018661415369640437, 0.03120773498179211, 0.03446351098377378, 0.047676489883733374, 0.04008005778755873, 0.06681712389352822, 0.057718431682235775, 0.2453428446765869, 0.15570634405218786, 0.08680129348630868, 0.20612923999226865, 0.08246014901106397, 0.24489189468083844, 0.20088837121523198, 0.10830869868157372, 0.097268674552681, 0.14620763520079275, 0.09536514524370433, 0.0987356256753687, 0.14888561811418305, 0.11728692739721268, 0.09482725192942927, 0.11632623781840648, 0.12892938008712185, 0.10250623382988477, 0.1909405356573482, 0.08035823357321563, 0.13385089745204296, 0.2169373922891194, 0.12437749248478683, 0.1504654752751512, 0.1390982013676436, 0.07095982095286732, 0.139510877610695, 0.16427312226545426, 0.19440771170681526, 0.10559797317029969, 0.08685563210277789, 0.05729185094335868, 0.1737655185523533, 0.15525637464898248, 0.10703896923411278, 0.11761115112852667, 0.13508397725320634, 0.11573373009600949, 0.17011650387317906, 0.1884227876942004, 0.1780551512755694, 0.09725136862647149, 0.1350789210729061, 0.11768933040119949, 0.11728989215747965, 0.06799725935824456, 0.19998115457354054, 0.32215140219176974, 0.2692027450088532, 0.08634047627809548, 0.14778076610978574, 0.2033459046675313, 0.22831297058972622, 0.0762606667534959, 0.08526784593179342, 0.20243890253045868, 0.19731415736098445, 0.1350283133046281, 0.09998683877769979, 0.19102279817865742, 0.21086983803299167, 0.10676986552895078, 0.31955540600803595, 0.11822764506383289, 0.21724537495643864, 0.10709245749298604, 0.13535085164250868, 0.09822431561206618, 0.16081817297925874, 0.061830385633173494, 0.1329152895918777, 0.1401180788994797, 0.11555273416301898, 0.16418517537174687, 0.17905742410690556, 0.18556558617180396, 0.18774070897169653, 0.2390408215503539, 0.1968939734562751, 0.11787980284181335, 0.10772131608739015, 0.08441987853016585, 0.17133090645074847, 0.23462357390071117, 0.10179501312274127, 0.1355308516611976, 0.17098987475037578, 0.13927199607414587, 0.16296156441732762, 0.1030703809773249, 0.13566772092974957, 0.1454775993742289, 0.15584350443415104, 0.1743217596724149, 0.07827223744243383, 0.12934882854742388, 0.18170908423921756, 0.07475379478907393, 0.09048180970092935, 0.13846178148542682, 0.13953954462082158, 0.11284438352431021, 0.12455795981710958, 0.100004987400626, 0.09677443292833145, 0.136165019244917, 0.10603628271529753, 0.1317826439175875, 0.18734427379263988, 0.11549162332929912, 0.16561795897301168, 0.09356238714028751, 0.0869262730702758, 0.09879342700925567, 0.2457072880239256, 0.19704401943712466, 0.058475682782309676, 0.11735836509615184, 0.12346790097053013, 0.1045637085072456, 0.11025349714703138, 0.21083986867339383, 0.17449636643211688, 0.10953381882920381, 0.10323508988104521, 0.10915534841197153, 0.13997017796481812, 0.1210542873389298, 0.08336492183227694, 0.09561294404369208, 0.19037608207473833, 0.15691694683365284, 0.13146683183168212, 0.1685747519255646, 0.10104828424030736, 0.18435999360536376, 0.14126344163331295, 0.10848150513465367, 0.16083131904803938, 0.22985484511140855, 0.14882842198975627, 0.21959050798848753, 0.2114625296164905, 0.12008411359162101, 0.14751764555131236, 0.2193759114391381, 0.10792537126690151, 0.14562271174884614, 0.15431770243712012, 0.10930679633372253, 0.16838817887248533, 0.12331449186369298, 0.1006488076921913, 0.1549949701274595, 0.1850053920380531, 0.1723905592676132, 0.09948660634578237, 0.158404168642817, 0.13155379813284646, 0.08748199325054885, 0.057849815761249875, 0.11550922802979909, 0.08957892145601012, 0.12795321553224517, 0.16496568107076232, 0.21155662053535063, 0.10084076634337825, 0.1386242840559252, 0.18808057621842433, 0.10010784236533989, 0.2176508652947603, 0.10195079710214369, 0.12125137877920944, 0.24741226266468727, 0.10545836896785807, 0.15608197228322107], [0.06835195040630718, 0.01447210952098812, 0.020036269317290956, 0.045481230462751085, 0.03377225452793702, 0.04676092671410692, 0.04465478247091655, 0.07607238532434549, 0.02877260960127798, 0.09010183009048624, 0.06886796424946479, 0.03788759458750006, 0.010268356211693778, 0.034108739496479114, 0.014346443330718866, 0.01665130216297844, 0.04363671673702137, 0.03107201292990677, 0.0489547343984727, 0.044938702316534136, 0.04114079078839671, 0.004798852802900177, 0.024486018247121287, 0.030346203993465153, 0.03572540718220896, 0.03979709172140687, 0.020507557032209252, 0.018965383736236442, 0.05420209577066764, 0.006319045121105569, 0.013941860806587485, 0.028679621849028815, 0.016125304278947653, 0.019679410240402626, 0.020012426745867538, 0.06584745576424945, 0.030113512447344202, 0.020662375740827094, 0.029156923354152712, 0.027690416562461087, 0.07464648119264072, 0.012657290320813417, 0.03621985565029806, 0.026437073735700502, 0.030714699945923303, 0.03914352679144471, 0.07042900629101262, 0.037390821042560765, 0.027206088115851727, 0.04533274347082742, 0.07141693795640623, 0.03743893136420558, 0.04184269203594135, 0.052160674465760115, 0.0676051372542016, 0.08538724839567177, 0.009480905925644743, 0.03315851084827896, 0.057863812187626484, 0.033103804509606094, 0.10629987058740471, 0.011000646251974808, 0.08227552182131237, 0.013574894157148177, 0.004069507891883053, 0.06401868897580332, 0.016170344503235914, 0.04997817423915671, 0.016464713788140687, 0.06051244627263758, 0.01235047114952918, 0.08983400575215779, 0.05032443832005224, 0.014267806320511287, 0.03855111866047786, 0.06242559764594321, 0.014437656631813416, 0.042955093836832436, 0.1008975257976882, 0.02453669879375206, 0.032303702281487566, 0.018527987751088316, 0.045341224064149206, 0.0500400434999216, 0.07145695838957064, 0.08922334940683457, 0.022362817056296815, 0.013900328307382524, 0.02182370183178254, 0.07114511463911304, 0.09215572713724068, 0.07211343445364507, 0.10357412209193553, 0.03965577148201485, 0.05051641995387693, 0.02799399996987514, 0.02147504372612363, 0.0029918134649990187, 0.058066319869530786, 0.03426296065651602, 0.023057802445105007, 0.03189103561453521, 0.027190446515657732, 0.0036288888311959925, 0.04350057142155786, 0.027144123094096303, 0.01820702946955158, 0.05139049180152436, 0.023469777717705698, 0.0019439783922749604, 0.013958034837888855, 0.03610903337117165, 0.02474365361605681, 0.006432734005483649, 0.04844143250656705, 0.013637917337849016, 0.04064431984818751, 0.03300633897343951, 0.06405728448542856, 0.019996840687048052, 0.03964593491306709, 0.07875975281480821, 0.11863593162307817, 0.034763185427554195, 0.0347410837909387, 0.07562462225436203, 0.01815813965344381, 0.04878197008022859, 0.0031748957905708064, 0.034369780126238064, 0.038088792259053844, 0.037122154007515604, 0.03406804873638096, 0.06647389352081284, 0.08161905341811719, 0.040648989154086004, 0.04642410849731776, 0.01579735927554148, 0.03513277305530445, 0.05123187329680209, 0.0200994007079111, 0.022203987877395366, 0.03726498344011846, 0.02970983199174366, 0.03263895767891119, 0.024019809695140972, 0.05839467281475664, 0.04744736447689995, 0.027711920650495638, 0.016175507935845566, 0.049484537824267344, 0.04890696498595419, 0.10428026363614107, 0.0403870445405764, 0.04258622633173101, 0.020997115944121635, 0.026613208840811448, 0.03634823666464898, 0.09003604612042827, 0.060964545400272456, 0.04494195435977271, 0.019415556152741757, 0.041643344466724706, 0.028592000542689237, 0.046140096721149264, 0.04347844680230464, 0.060803134505066185, 0.06243572149786258, 0.05427885778068055, 0.02482589315472832, 0.06078474073400421, 0.04954268006728061, 0.059034141726912036, 0.03613891463065821, 0.05087595650806062, 0.024590190883064945, 0.0256603142066348, 0.09918589385286455, 0.032541541938459685, 0.06260814873742, 0.030555865021362424, 0.050825823714295705, 0.03332051546162656, 0.05405580362064704, 0.05178323443678599, 0.00849644655376793, 0.02270309990572353, 0.04610460386761735, 0.07983253637869513, 0.00568814873282287, 0.015459890841626594, 0.017054825570554506, 0.014456690086292164, 0.04924407048571495, 0.026021155025509578, 0.020696024237681302, 0.02797222392062747, 0.014467288912724585, 0.00940264429852006, 0.029488631764486916, 0.040943530808773734, 0.07611380003753208, 0.031615192250859354, 0.034536342962735125, 0.027756993433520682, 0.022513022000390678, 0.05212494795541129, 0.03290958206860289, 0.006724636487272238, 0.04930935266818251, 0.0805129680121618, 0.017726071809809056, 0.0392569920739099, 0.01130157995278076, 0.014579442269619436, 0.018214167493786064, 0.044943314165838306, 0.058078810933136174, 0.07509400677536765, 0.028471537047035755, 0.03791748350786586, 0.0587665893497967, 0.03178746818805174, 0.01611412514091259, 0.030611827744231112, 0.009921973387169982, 0.037638370863973133, 0.0637407216333574, 0.07060762735143786, 0.012835943939975433, 0.024970678026757898, 0.030556175286971757, 0.023855706000880852, 0.0369148314630072, 0.036187446300661376, 0.07414928246890345, 0.04072889595502808, 0.024726960560186736, 0.05241479349112319, 0.020659510571990284, 0.03751670844071815, 0.05001313466158125, 0.03358495369132969, 0.049605572055424416, 0.02602090604693419, 0.07630867748371056, 0.010617943198960877, 0.030182661458609567, 0.04233139867503797, 0.011631463158635363, 0.022161462336718556, 0.07198231850540446, 0.030568193291283907, 0.03858718607995299, 0.055136569820704966, 0.01930546357236322, 0.015496613266276977, 0.06972575289828163, 0.067386970735125, 0.05016659739457312, 0.028054065093578353, 0.1292721891114789, 0.011972067764990274, 0.04513006341914016, 0.023175653580936696, 0.022525459437841372, 0.05087763041017517, 0.05839938425549096, 0.02694095466135731, 0.06338797261818283, 0.011718939865879234, 0.02780976540018474, 0.028907165284298604, 0.039062627906640696, 0.009326485582747528, 0.07722011526986476, 0.06120094864238655, 0.06387029391443057, 0.03165762394576544, 0.06538829330595271, 0.027653736272646535, 0.0297077271651717, 0.019262413261458278, 0.024120469817951806, 0.047571432416237174, 0.007784005851605006, 0.023510933876217856, 0.07089462687051104, 0.07477298529157717, 0.032917717922358744, 0.07054700681398954, 0.0233520855451183, 0.045876627592670347, 0.03834909744440548, 0.04774599321066372, 0.01262049416020032, 0.03898953545778509, 0.022220566020076795, 0.06321556070038388, 0.023326678239109538, 0.0604082698062543, 0.03966887158552005, 0.019734365557650888, 0.045638018017334324, 0.029965071420695995, 0.021338521112357418, 0.037860965371252074, 0.005998686782174534, 0.03853431069141915, 0.04068630912731733, 0.02168907911606854, 0.029347933971533374, 0.022135804136914593, 0.03936558503717665, 0.06757805604607829, 0.056752249253012484, 0.018148779974228913, 0.024792800071619214, 0.10139919847490327, 0.03903049051821713, 0.006953162430304915, 0.026150304043004592, 0.04026210709144512, 0.04029117246729232, 0.021512363699354956, 0.057116918596288854, 0.016581616890166077, 0.027780868563680883, 0.04309076417778288, 0.08366416343638013, 0.0064780141110531994, 0.07395510982361532, 0.014081884442167658, 0.04192680465958772, 0.07455128710716963, 0.044130877922138864, 0.06953960119356072, 0.06300037043289312, 0.01866235191212787, 0.026066394432658152, 0.018114861431381395, 0.03668526172517769, 0.04718389534842103, 0.11164507287884913, 0.03798009204347769, 0.07454169568635764, 0.01492892679262666, 0.005583225809518369, 0.012628053532793157, 0.03365903439360761, 0.06451597196921226, 0.024937728585134593, 0.10761951832401176, 0.2243419231907014, 0.10951275907216534, 0.12002655740586982, 0.14410849300123033, 0.12041024488186645, 0.07536955327997286, 0.2688529799061437, 0.11686008618844133, 0.11168169188162974, 0.19455028066952385, 0.106115365971721, 0.1837480732149655, 0.09161856160649369, 0.11743248410282597, 0.2727933684664388, 0.09995156042878667, 0.16129831092492228, 0.14864436170506864, 0.12458682601009646, 0.1889445088923939, 0.14238471856280682, 0.0703816467355336, 0.09333018589043811, 0.1366937271649799, 0.19349680252132878, 0.21667709093420737, 0.12147975725031669, 0.14597112853680888, 0.14747837588431376, 0.1402523281473306, 0.13832356390212813, 0.22601081509022947, 0.16272423037838551, 0.14281472371470544, 0.1471347394849985, 0.13600363516278807, 0.09269759644784274, 0.07652665248080608, 0.09148251205202072, 0.1864122052586848, 0.1253654701154559, 0.11240879359144358, 0.18455353805855398, 0.13028295019701605, 0.13664878844734163, 0.25146851436265055, 0.14001556101345247, 0.12401894801446509, 0.15495646654838516, 0.12544151200281997, 0.14892936173465945, 0.1620115387824274, 0.11545286694120978, 0.08892934784413346, 0.2588308644631217, 0.10871368340186535, 0.09625238997320976, 0.13552282305975116, 0.18480337465242033, 0.17372479331829857, 0.19652421345874188, 0.17296233665077917, 0.119928406221011, 0.10058696141406413, 0.2034983868079801, 0.13229845091700554, 0.12534819483276338, 0.1129626445171814, 0.12227304129590913, 0.059235630511877045, 0.18629076500092784, 0.12084857740950201, 0.14822240047637494, 0.09818933603744354, 0.12815212260090536, 0.1486746221780777, 0.2396207654307927, 0.12545111874539044, 0.24284944298767278, 0.16605849017298993, 0.10743937274861722, 0.18148802190778718, 0.2051717833045029, 0.13133760812061449, 0.283897016197443, 0.11927516304797704, 0.19542830936130018, 0.1119296515600816, 0.15987024642527103, 0.15483173211255383, 0.13207646928006603, 0.14666266078429838, 0.21158413841359078, 0.16577005806949832, 0.12141866173835532, 0.17058078379880998, 0.12316075333904837, 0.10152349624061778, 0.13165106065571308, 0.09839437180949796, 0.21071652851758466, 0.10150034506354602, 0.12733894325191938, 0.1894999686027727, 0.17895021776278175, 0.07444265583950667, 0.1317148298145302, 0.18098413523647094, 0.1062974727322017, 0.1841837474175038, 0.11637044875251672, 0.11274999383115962, 0.1543144389025627, 0.16449554823338985, 0.14958982145594013, 0.1296753811860277, 0.15566005701980284, 0.23069217921264712, 0.07281619755010452, 0.10806360417195868, 0.17645027368299424, 0.21047043043278882, 0.13987473873121126, 0.14845003584219565, 0.2165404668137912, 0.08317875480579753, 0.10795874205688316, 0.14088502484223536, 0.11235358929561992, 0.1334700138578492, 0.128842429107716, 0.16211399538142068, 0.15030298802641132, 0.14521011211458715, 0.15222113429298326, 0.12036782659349904, 0.09524673869412753, 0.1430622160795235, 0.2221483070283167, 0.16102345389944894, 0.16998845993751482, 0.1936953571895438, 0.12638858053833246, 0.0931653850561669, 0.13975791032275847, 0.18059241915902785, 0.11144525416555906, 0.11539112791539201, 0.14464585771483762, 0.1256750922109331, 0.09743546721555534, 0.1509704651130784, 0.22519770468915665, 0.14176051012210308, 0.10397468648490407, 0.0975719994054206, 0.15629636964971022, 0.20927957739801178, 0.13598604578404658, 0.12016911870769917, 0.1243737846192333, 0.1751408302375386, 0.18380931428363248, 0.13089027405986864, 0.1728633121256867, 0.12584275821404112, 0.2041197454016055, 0.08241459742308625, 0.20047995442103958, 0.09805494123288701, 0.15411580762555524, 0.23057866030402724, 0.14165829867124557, 0.11848662108663591, 0.08102471474558115], [0.03440780873079935, 0.10366456643227609, 0.11157161270778988, 0.06007072380593708, 0.06059545572967299, 0.05007542910114412, 0.09290948104594024, 0.03122053631100684, 0.07944407617493023, 0.05179960190528824, 0.026942663037428455, 0.01503815177843095, 0.060240331841933156, 0.08585410237672829, 0.028437294832040227, 0.09121117903099907, 0.06577081632830444, 0.012342717382125558, 0.025533817768577608, 0.04588246518265336, 0.06651909270834538, 0.06745725930217775, 0.07858421908871782, 0.036993455066676104, 0.04744288669298253, 0.013004010224023895, 0.04649902806587277, 0.10419770234054136, 0.050208954395906585, 0.00818048125027769, 0.045687442179769285, 0.009212900599044178, 0.02084039733745158, 0.027777467133297075, 0.09543460643579883, 0.0739781920527739, 0.033034914053015174, 0.022101876017968022, 0.029007936489858457, 0.0294829014268133, 0.09872706081237524, 0.015911612670958763, 0.023459774524634405, 0.027665715972562472, 0.006807293065057527, 0.05727720334224644, 0.01568927576074437, 0.036239693497097304, 0.04459791576429721, 0.02192236054989119, 0.007481686010461061, 0.038470047405890884, 0.0147666234049886, 0.03589738242989106, 0.04919802094058645, 0.032865482217241684, 0.054114539581801624, 0.036809272207920594, 0.02947772075722535, 0.04849870907022588, 0.06781085484450863, 0.05469916808989741, 0.010780502268443666, 0.03727895688385733, 0.024833054161600532, 0.05986016070950897, 0.07435667013088543, 0.03239572859339176, 0.09528243839139901, 0.026365976945887652, 0.11537096448122494, 0.05613137329477937, 0.030318764639237238, 0.03567883286685233, 0.029527344102520618, 0.013897132763128369, 0.033095450320791815, 0.09368548214796091, 0.009871825271646583, 0.06722236142283486, 0.05889021678857746, 0.012010607733241013, 0.04964289202865574, 0.02834785215166067, 0.03399015674667974, 0.03002686407266846, 0.07235601619486848, 0.007506123257635703, 0.04656924768501232, 0.09580483374696586, 0.08846171245339418, 0.014250870989335161, 0.0726085877226245, 0.031469428701506506, 0.031131241102552706, 0.013236436512201064, 0.005251686896137413, 0.018640570117220766, 0.04965035755547786, 0.03125991323031485, 0.046539324290689923, 0.01934520246821546, 0.003416627174198267, 0.017150649763343316, 0.16114809640472935, 0.02905106915521526, 0.008703861028827246, 0.03583223431281025, 0.029562607129675247, 0.019987942575807535, 0.060269895174931136, 0.022240223836213834, 0.023382562437965985, 0.03886928263631079, 0.012401794252406447, 0.05831730559528355, 0.05924729803096383, 0.081644288354343, 0.10555458961114769, 0.07439698933834031, 0.01881886175983856, 0.06572639088957541, 0.03290631087316621, 0.04713819437329808, 0.08842293308266709, 0.07439682079899697, 0.04300193245252294, 0.014692672937657806, 0.07075042614052374, 0.013910935752304092, 0.052417459477099686, 0.036452095204543684, 0.0317617793447308, 0.038454262164211085, 0.019917937461286783, 0.05340100528912679, 0.05282867632265534, 0.028380828406361323, 0.01377325730338212, 0.036114192973341674, 0.03002449494576262, 0.009485586722862096, 0.009421557094150735, 0.035184909168991356, 0.03302175649291566, 0.0249003243422316, 0.040209155094118855, 0.04260453200268169, 0.08425740660318444, 0.06565587249614539, 0.06406080465944064, 0.011379752522184244, 0.05313268682408718, 0.030670644144617745, 0.06568070140577133, 0.049902178317068085, 0.04947378961068969, 0.022264512653853145, 0.03992601665818403, 0.02513435654222004, 0.04394309828057886, 0.07157451458155148, 0.08830117106798195, 0.029224002012802713, 0.040804631407222444, 0.00614692192269309, 0.002344314036177351, 0.0374743705915828, 0.040564255999220956, 0.08490348685412638, 0.040398034071850206, 0.025548463454470042, 0.018977991628250288, 0.05872968689448411, 0.07861419610919491, 0.04198681615713624, 0.01508090139982561, 0.060157150015114784, 0.061783022247254855, 0.04000103964860882, 0.02555476644286706, 0.008368648723849367, 0.01723653396531459, 0.03974139712931168, 0.05875787509965801, 0.007759414908040556, 0.016550745462037383, 0.05637417337106121, 0.059274789096126636, 0.04302844292514267, 0.003000496353413309, 0.021364217616557594, 0.014575066949961888, 0.003314969221866059, 0.029357623068555713, 0.03856273255340996, 0.0177510999022953, 0.041764823028877865, 0.06726137828081846, 0.05462270868461459, 0.03602626523183238, 0.05425281462169463, 0.10065811566047131, 0.08450550417746268, 0.02977959195812864, 0.03684899003635492, 0.07949588670124931, 0.010181409062727565, 0.08250827465446726, 0.020924927479016687, 0.0679490341234111, 0.05875148592636951, 0.06759175369816442, 0.008808163899718034, 0.05658145378073377, 0.06452472835418678, 0.058443392176301255, 0.0291252609402422, 0.043872235147582914, 0.02534576042014505, 0.01643740849929952, 0.06214535502236217, 0.03647180664683542, 0.01818796920199548, 0.04673670301394117, 0.07391513535572637, 0.04495263362543718, 0.054124035241623084, 0.05921613740464372, 0.03495783304735538, 0.04003538720069393, 0.06736412599322296, 0.03187595900418538, 0.039536058752527165, 0.031420653798587383, 0.08062234238511132, 0.0492245352436458, 0.04684618080876047, 0.03307314184043677, 0.06550917431952492, 0.0011774014884365664, 0.03621424788669233, 0.019254943904196544, 0.025957989160932844, 0.039155753554716226, 0.03472149875315447, 0.07377519407459805, 0.09870287541660572, 0.0512639302459936, 0.05685398955979655, 0.014649892672746172, 0.07917923191862722, 0.018830071541390592, 0.028925800373056726, 0.023722971691900206, 0.03390270014924388, 0.01451483041408562, 0.054579662204149275, 0.027996045424632972, 0.028176880479159377, 0.06560798433999862, 0.033841792328823964, 0.053863906256494024, 0.027117152968722007, 0.029186013627857454, 0.024548783830757585, 0.023824604746374874, 0.07242932314834288, 0.05358975786235064, 0.037138908350419615, 0.032568780194607475, 0.013049987948409492, 0.048471248648580045, 0.061140335765817476, 0.04950484681514002, 0.03630411383065005, 0.04747539563404937, 0.049624429309680584, 0.017312621817954125, 0.07513174426651771, 0.14288244588721183, 0.008585895937416823, 0.027741164141785235, 0.07658917291630661, 0.03176293996793609, 0.018548516992239222, 0.019336375220107938, 0.062002770737895084, 0.018915923184625084, 0.026635574777760816, 0.011666900470792767, 0.01990934386999617, 0.03528051311150193, 0.03181100240908563, 0.1134851930903331, 0.06441472578913936, 0.0340107491900844, 0.010127588513217146, 0.01331690351493777, 0.09327034676267255, 0.03556364005611789, 0.053568881966413996, 0.012791227387835183, 0.01754717687295089, 0.01235108114703889, 0.0032411772389746, 0.0369265181342921, 0.06393054672967523, 0.04825433468325965, 0.020383146268525915, 0.06011501134883973, 0.0655176166084505, 0.019125499942850684, 0.039382140197220354, 0.0557241439368696, 0.05061721797251413, 0.01265439355084973, 0.02823337180269582, 0.07296530890368647, 0.040520439600391735, 0.01432291102490478, 0.07483253330593148, 0.046676634059798335, 0.03080643705963608, 0.045111432160821655, 0.023721795746936433, 0.02620487631629071, 0.03361526779049347, 0.07102569685347619, 0.007341935772508864, 0.0763106003644005, 0.021449216986976324, 0.08599531536381091, 0.015528989099566976, 0.02806820707666057, 0.06652175869432188, 0.059431044219602505, 0.05645827833382834, 0.03629986204267029, 0.020031893040023504, 0.013195778310839689, 0.040879206236211524, 0.024100641547251615, 0.03289874192447432, 0.06542957778419219, 0.024800257937562083, 0.037818501117609205, 0.05654463942553248, 0.0379926405636774, 0.0015897906879188434, 0.07883581002393077, 0.03794716558449211, 0.14187969808136264, 0.2483924261985287, 0.1945003777021362, 0.16703784165363159, 0.10089482150731549, 0.11485285155715481, 0.15235060315218665, 0.08538789957040742, 0.16300595155166042, 0.147339177708472, 0.1477460163615404, 0.07312539063634411, 0.11466839290674656, 0.16269413844471978, 0.11402467220661142, 0.2517599495308053, 0.23146925283776176, 0.11417599755429453, 0.08827271856247418, 0.11111988896323789, 0.08012053947294913, 0.18953068872853635, 0.23920821176180918, 0.2021295715483927, 0.11648821944911635, 0.14535344716522003, 0.19349286482939798, 0.15865262627841967, 0.2565320184634578, 0.10054306457600287, 0.12520254619659918, 0.14984212485292267, 0.11561583682534196, 0.1346405502408743, 0.18779936066317945, 0.13192769500517076, 0.12380956852387999, 0.08375701329280293, 0.15386405581187818, 0.1791909838756246, 0.16175500658010283, 0.09493085766030897, 0.12342479320303087, 0.25729013907332576, 0.09826283451289901, 0.15392353487831933, 0.09539081685004697, 0.1380070776588494, 0.2182869021330149, 0.165341860885101, 0.1940281917491267, 0.1560241326449379, 0.15006937717478122, 0.10070800330610045, 0.18880885004276232, 0.12706365721720841, 0.10327973748527228, 0.14755844739415955, 0.10180053661667532, 0.2103651393084757, 0.16576806624089518, 0.17321618754536877, 0.09137178936432447, 0.1614546847920264, 0.14155443247047164, 0.14047984093908342, 0.14726223183735726, 0.1357709589384256, 0.23753634744113494, 0.13126426286274387, 0.20670569051177273, 0.1885794986399912, 0.14789278348607404, 0.1667865648144676, 0.13052535573801688, 0.13511943180234204, 0.12431044446965381, 0.1329002742685618, 0.0976478650925621, 0.1444343101954268, 0.12413414465563914, 0.09496652671406347, 0.08778744016683872, 0.14257729774521244, 0.12342363641026521, 0.09760227520018817, 0.1499869920794041, 0.1432448054753965, 0.15536420918520422, 0.11265178135926686, 0.21500397022933732, 0.19860192051818296, 0.2175136129822462, 0.17220053881887468, 0.17541728072589444, 0.2220524847507477, 0.11978252775846951, 0.18461390578698728, 0.14701055663247264, 0.22075110055025549, 0.21864325559187323, 0.10379144591429543, 0.1008248623580702, 0.13837876819795178, 0.40299564960502815, 0.11806276762076925, 0.10358863945810065, 0.15244417313125827, 0.10134310551708746, 0.0656189164146781, 0.15397555224837797, 0.16880116155070646, 0.11371464408453434, 0.22529256169594106, 0.11313352808957139, 0.11580300742700217, 0.10505463297088301, 0.14394047459767711, 0.22500199986801994, 0.1305120258081344, 0.11438024425578695, 0.1716462129186238, 0.13267309855549567, 0.20724952100746094, 0.17946332813270632, 0.18148483498202217, 0.20061657854145576, 0.08898994539894405, 0.17725083556386734, 0.11977706555156939, 0.15049087875072034, 0.13830617370624698, 0.15572682924328313, 0.1636025655053316, 0.09930052358897463, 0.19122611791376146, 0.10780738606568306, 0.17885479385093336, 0.13575102533063582, 0.13640737882064236, 0.06775109998641476, 0.16561828072993987, 0.15061896865166005, 0.09768573281865928, 0.1412257041421629, 0.15594885684549809, 0.14410326828158673, 0.1506607664088088, 0.14072469796144194, 0.19504790074161946, 0.15012023009119496, 0.1145825987201064, 0.20224217115150345, 0.14675353413387654, 0.2912546165527836, 0.23265485050937823, 0.16314525697981158, 0.10457027388075668, 0.14202171546076575, 0.13062618823061067, 0.18371225094362614, 0.1611624528924304, 0.1598627387636131, 0.13941598996039362, 0.11707973125721179, 0.08018731935730866, 0.07309313067385266, 0.16127126802119518, 0.20277299347423738, 0.22277145826768494, 0.14566291604311238, 0.12510624128363787, 0.1484728805840977, 0.13689905405044556, 0.1856244064026302, 0.12114437161794595], [0.046438189193366036, 0.019656349078661973, 0.06649193489142964, 0.05272166533095222, 0.032632047565834175, 0.019843150042898713, 0.08011669371156924, 0.04996307847660877, 0.10015501039883784, 0.09934963748580027, 0.026527763224176826, 0.05670107457967055, 0.042759411998333476, 0.07934990098639842, 0.02610202901245606, 0.01591112907795656, 0.034639458397343274, 0.022110791366186835, 0.014514496208228653, 0.01161132270710603, 0.009927959406688329, 0.03593513141235998, 0.10075014580281512, 0.031083640229377537, 0.027930004815120372, 0.07588699970754885, 0.024863444869556738, 0.0377561645432105, 0.002712572501378975, 0.045698787941927874, 0.031592383898133715, 0.03242949391865442, 0.12514886641574482, 0.07129925152947826, 0.01040123128933051, 0.023530419322571928, 0.08087334343262258, 0.05532120084089618, 0.01774260781765465, 0.04383853110935419, 0.026494275605786714, 0.05074232396098876, 0.059221660898577784, 0.07938288873241794, 0.022557596826264938, 0.041452144242582784, 0.04408428445458413, 0.02890929309350829, 0.037344775327871886, 0.024690182594161843, 0.09208348504598103, 0.025733910358300614, 0.012984489346103323, 0.03762268521372349, 0.057513840241177436, 0.07938831263492185, 0.047512064432545055, 0.09125493797323397, 0.008924253990933781, 0.016981332840758468, 0.05676962029669554, 0.06932336521605331, 0.06315693582197832, 0.03777104580113965, 0.0439031238126899, 0.04543148837382755, 0.0302928785282758, 0.08050602725556782, 0.027224728950269284, 0.023139486570031415, 0.04360207041064578, 0.013457947005067143, 0.060679591335957093, 0.014415046504338183, 0.07185107998309598, 0.02904421841395238, 0.07751677515766314, 0.032846946719913714, 0.04192204725357794, 0.005177586084051479, 0.03702512131102624, 0.022623231409177668, 0.02255342547751723, 0.02704161286894833, 0.08383317009335564, 0.03469010063957784, 0.00782457260122042, 0.028378480346873406, 0.04348044246134739, 0.04134154029851479, 0.07813657859280225, 0.006378686502425662, 0.09293732068110859, 0.07757151213985297, 0.04412227092430957, 0.07113298746727167, 0.031954383424993967, 0.05364354489551437, 0.032246686187722993, 0.01730454342079259, 0.060181925298586014, 0.08650117088109256, 0.0315231716846146, 0.028463144553825263, 0.08703158717722663, 0.034521480857004086, 0.013070870547615474, 0.042207981910436385, 0.04556975958328094, 0.06998117427311598, 0.0092747756054685, 0.09088094150947948, 0.032233026840033076, 0.008448663734710746, 0.03736048396075926, 0.05225930062513198, 0.012240693622809506, 0.08671516988186107, 0.010765456301610797, 0.02157932744481631, 0.09271067356871021, 0.10090163202896234, 0.04897566009012442, 0.061883613422152504, 0.05770508260015519, 0.03436540576419042, 0.07422031414124274, 0.03855054409453466, 0.008000237041062886, 0.04720325822070722, 0.07733801620141154, 0.017833961887405287, 0.08194462546417791, 0.14797700719246942, 0.0356820504361343, 0.01995089456378933, 0.06757330630094775, 0.05618995220790948, 0.026470348764691624, 0.03480053604430249, 0.03903677626963585, 0.008915963004373254, 0.052192696940995036, 0.02976381437732808, 0.009635717930993246, 0.054535524048391855, 0.055726288983057586, 0.0313188387982307, 0.06744330884107659, 0.04361492919645483, 0.02872902302882604, 0.07522306960797118, 0.06327065391345851, 0.061252379955183116, 0.022636749030601595, 0.06333953287873058, 0.013240551361964356, 0.04615797721330197, 0.05967230828959615, 0.02102425843927889, 0.06374417668989589, 0.06845318892550084, 0.050232503938698964, 0.028617758333923358, 0.028616360223461545, 0.06486103329206667, 0.022638616369917028, 0.09275819400265332, 0.04041340945649051, 0.02663306775502861, 0.03407816492742108, 0.019891080333881324, 0.03060504978132104, 0.020247458690597166, 0.016070973323357683, 0.032677331023038395, 0.07072150632138215, 0.023667064510406028, 0.005677467073133637, 0.0460491314410202, 0.04815968835065442, 0.036958157565564885, 0.022990827208324786, 0.039084426938526096, 0.007819760611446035, 0.06715499165077364, 0.050649500917643316, 0.012781115984844585, 0.008556440814338144, 0.06536042302726738, 0.023770365721335816, 0.09793082732827434, 0.04557930503881747, 0.061010686875951875, 0.020918387003363143, 0.03752050823682258, 0.025653568802461512, 0.01715611963112268, 0.0718559523022944, 0.037570575913113934, 0.02985872309504738, 0.027028507019783703, 0.0450528264346142, 0.03989858688005517, 0.011976125158159243, 0.01874383302375434, 0.04362171673546395, 0.05076573560795477, 0.10673512344158466, 0.012897900343241711, 0.03435564580403509, 0.10817976608391731, 0.0443939563457764, 0.019548690742662838, 0.020741782669398575, 0.05643773951657838, 0.04180019713878151, 0.0371875319509737, 0.07778159643132841, 0.026585763740924098, 0.04670335903703686, 0.07109858245859224, 0.03884018278650699, 0.029735030538793054, 0.03586068681831803, 0.0743301251843091, 0.07154025512957765, 0.017728670763092178, 0.025463337679543806, 0.006556909675935224, 0.072543385979389, 0.021749182544167966, 0.029346110682273586, 0.025880470639094714, 0.046243070429491426, 0.00909545548981236, 0.02048618700956145, 0.03533819570176063, 0.0227212427829903, 0.04798367581961136, 0.017686051376644644, 0.023571816798780235, 0.06876678701730506, 0.07159345227503969, 0.03244634402254897, 0.06277886760090629, 0.014146706014270745, 0.01755621288001778, 0.03452974694570707, 0.044018021679573485, 0.06662054573215785, 0.02448594546876848, 0.04339723382145167, 0.025455004558147445, 0.01765337581145427, 0.03455323137102589, 0.05629290676405353, 0.08302434978465881, 0.05132382299991385, 0.0816235656759912, 0.07690513821979685, 0.06755516533890078, 0.030772045457495317, 0.07550853695119582, 0.06899406232180134, 0.042023910134429895, 0.06832986409145017, 0.04790383413614285, 0.047678910721574104, 0.0007853941778810094, 0.025082618794253757, 0.06339763681734763, 0.0394200730407911, 0.028167750626321764, 0.038938188414660194, 0.021934144897386435, 0.0717408016263958, 0.037240139208734035, 0.0718617515878812, 0.018922252986099453, 0.04456167597503913, 0.026757859647454276, 0.06037696362322858, 0.02594465157017112, 0.04042007059099213, 0.043757793103014274, 0.045225675022529985, 0.07057157525372121, 0.04502066606355291, 0.02613866908265458, 0.049756204093536066, 0.04128471955717091, 0.0454417347998148, 0.07561485463332746, 0.01524971749242996, 0.01034727475921353, 0.054043791361994324, 0.05693612950703791, 0.07612431076385322, 0.08424810629578368, 0.07281599070636496, 0.021073732397428924, 0.040493469475017446, 0.0767743899937599, 0.05653476072174888, 0.03877914473113995, 0.006470221560448409, 0.014036480326115364, 0.042693612706517024, 0.13133754683358054, 0.06041080555728367, 0.0039520386030011245, 0.0892511124332105, 0.022955698246556907, 0.0714863914876215, 0.07786871595007759, 0.08850843615589604, 0.041735412913464734, 0.021243577920681527, 0.027119569976123113, 0.031018327403393005, 0.04466193390168971, 0.04511048221179555, 0.01631777812426369, 0.03628965775151888, 0.04058783235509069, 0.01783042256119511, 0.05197802761329278, 0.02976752415810141, 0.03870112633693122, 0.01642372042331244, 0.06688873013181072, 0.009898696763200626, 0.02339344854737001, 0.01447542955452997, 0.012120039562784858, 0.04406430871195851, 0.06716511167225338, 0.05583833317242323, 0.05682864737126136, 0.012300256958922312, 0.013877459625232846, 0.01522494220895873, 0.07269144013163543, 0.07368995147126337, 0.02331261669525937, 0.03327738854192919, 0.03755772095774451, 0.046027619692106406, 0.039584352935273806, 0.09532698640419592, 0.02141396928158018, 0.14347322225089998, 0.1109147689215118, 0.1017946454005376, 0.18584104074585825, 0.07130492824099718, 0.11070276941022567, 0.19428909065261965, 0.15506042467971004, 0.15607867810514667, 0.1551780957848795, 0.15152267661065827, 0.08251071847494572, 0.14648129712910424, 0.15818482234833703, 0.15547110909415832, 0.17019476741552356, 0.17928162739882547, 0.13492404873813355, 0.10681724806706752, 0.09855056181550027, 0.10049437968841485, 0.17236121810011326, 0.22262993118455335, 0.15000737001818998, 0.1439151783744174, 0.12600827151008193, 0.12811987029929317, 0.10662569544248043, 0.09521264012061781, 0.14950651705505388, 0.09069964680219851, 0.16113194727128552, 0.280183359019218, 0.18565770058381945, 0.1304305753400249, 0.20394500074607713, 0.161613755288624, 0.20242879016985818, 0.09495977747945056, 0.1820731598643526, 0.14460827344127242, 0.14837241581370755, 0.20854964882375734, 0.18573898251258558, 0.14345612316843004, 0.0818108971561155, 0.1052458638385419, 0.1568417169994885, 0.10889418903858432, 0.2849825014991145, 0.18067379301834494, 0.10093514837564961, 0.12334908073347424, 0.21428640631418075, 0.12993715342975434, 0.15031883072468544, 0.21871175917406238, 0.15784103273143693, 0.11382748883578087, 0.13284336925754625, 0.1566020540532566, 0.1363510100711738, 0.11297317822614025, 0.15320682898163795, 0.10321491878599891, 0.09391384529730967, 0.15402589954676169, 0.17337211708147682, 0.1508380238327288, 0.15842344341499193, 0.11739696060577709, 0.08474219470254837, 0.1226198339774724, 0.09447742553968584, 0.19755729834639257, 0.1332119188361591, 0.172156534728504, 0.08602522343637482, 0.13564300693331227, 0.21855284189504964, 0.14474696599908415, 0.1702540013338289, 0.1051524930423306, 0.12887838927488174, 0.18808946283834596, 0.12675533747120252, 0.09473436376861027, 0.1893170574499715, 0.13547121937717163, 0.1942629364108847, 0.3498561752419318, 0.15808216656648344, 0.27087021198484207, 0.13221012097933602, 0.10643824138828825, 0.18747910526731323, 0.09693624601969797, 0.15422705891391925, 0.1762504779523419, 0.08533544553023192, 0.13123600954009643, 0.18294876771828822, 0.11879687903509026, 0.09631103400381343, 0.16975065092405967, 0.19606903465765138, 0.1768674698447989, 0.1738354777015986, 0.14932279384905292, 0.16301293827352986, 0.11761465981121987, 0.23056484007787323, 0.10178574345885746, 0.11711535434569083, 0.07679293698240673, 0.13625498861074448, 0.19853902469959953, 0.21665910318974527, 0.06069033571909513, 0.11635615355184964, 0.18159164296042535, 0.30486018487042, 0.15291937747068945, 0.14697295703714894, 0.1541552611536557, 0.09071309164526964, 0.18459898239422232, 0.18806787448063975, 0.1443638147846345, 0.11271914347044884, 0.117619585756573, 0.15061562850831017, 0.19229458074175543, 0.1868921899867635, 0.18188615780203574, 0.12646472201712672, 0.27399293958179416, 0.09933885862870563, 0.1946691468718552, 0.22593754644115127, 0.19847263552008138, 0.20718086420768694, 0.07731597585182998, 0.19553032162929737, 0.10962351240337857, 0.1265319079280861, 0.1234605924917325, 0.16024736086687735, 0.12788158631132496, 0.09409446584721727, 0.10359218644519007, 0.14691429002390755, 0.11560233835611614, 0.0964365421884483, 0.062344633643665624, 0.13894493781751202, 0.09121752989989135, 0.11111846403969873, 0.15373034282557427, 0.12896471206218968, 0.2424475839061122, 0.22920604524833543, 0.18683962103339935, 0.21158058376562214, 0.11416343371233634, 0.12388869774557891, 0.14829384583619334, 0.2550777537567962, 0.19992513822451716, 0.11155377052003339, 0.14124811987482733, 0.09704601875836812, 0.11624691707472648, 0.10161895845686236, 0.17096413419611994, 0.0958914629694435], [0.033460119664068186, 0.03249035194335926, 0.0809227254602217, 0.027730624687166947, 0.07095049000194958, 0.04780790460626445, 0.059019049794803706, 0.052092343253353914, 0.03532096255390394, 0.06531349248102596, 0.09073678674476762, 0.05911607483041383, 0.020711102763250954, 0.049248762774251165, 0.0947057886890346, 0.028310980339865052, 0.014009925803439993, 0.023911249290610996, 0.012797537079501538, 0.04348747897893191, 0.0526031285464283, 0.05095295217489043, 0.02849908365357307, 0.014692218072952764, 0.09548411869834508, 0.034835952289041974, 0.06644658248631224, 0.04616497542649027, 0.03608235435920858, 0.036623518868920305, 0.028196806426069913, 0.0814960656627532, 0.04188000051785381, 0.0623089952334281, 0.0235474705245466, 0.032103812705064495, 0.025496760180460352, 0.07439086829582531, 0.03712853935036448, 0.009685364258926242, 0.03755591682068283, 0.039125500742586396, 0.02760805253450188, 0.0037817233720899473, 0.019664661132640416, 0.0977316597897199, 0.028459183879256732, 0.01549565278354191, 0.051184774211217324, 0.054030576345300486, 0.030848449321403622, 0.009562790191041367, 0.03859030405780481, 0.019480198651792544, 0.049586687988090905, 0.03552247432150668, 0.023865395097903187, 0.0494663279143072, 0.05488215585149104, 0.03921459293774059, 0.001654149016230217, 0.048618509899824865, 0.04665225714204773, 0.06342086077277219, 0.04354049226329212, 0.0113954046560872, 0.014453421763685203, 0.028248130486557083, 0.06790242533409788, 0.06134229952529554, 0.06168197141960264, 0.07761177006027392, 0.014278037424740053, 0.019721627430689913, 0.029673134464950814, 0.02675264641912955, 0.09816020171368316, 0.05202762031507108, 0.007632380293216557, 0.07548089649888777, 0.07481119009636103, 0.026337078194163983, 0.04270739845871445, 0.041728054638952024, 0.01588882825848076, 0.03813532827001426, 0.07034666716091095, 0.02292087955039836, 0.08548206709805997, 0.03541411501505683, 0.014727981930087893, 0.022902187005045916, 0.019713428374680302, 0.0348676338551506, 0.023985450651736993, 0.028436205071967938, 0.08276171952245698, 0.06889520633605219, 0.028560058506686362, 0.014012102450754856, 0.004153261890619873, 0.04015994160586307, 0.009864014047648638, 0.03468277300858209, 0.010174144633985575, 0.06624551504970559, 0.06306250782443151, 0.14078108203266898, 0.012545959550827261, 0.04707714482661217, 0.05428076533961201, 0.03930651199733538, 0.08549912021525445, 0.004815269109507602, 0.03706241830161983, 0.03853021595146387, 0.04954525029226657, 0.011620998397589693, 0.05484550237475384, 0.05225410654900536, 0.04591185614586838, 0.040040255689452735, 0.060563854602796424, 0.01156220019179126, 0.039905588923683094, 0.038216962599225586, 0.06860771652070746, 0.05502814156634193, 0.02786065470577488, 0.05002994646107958, 0.027152381521920045, 0.040497679128161365, 0.06360875149708121, 0.02925661246051952, 0.02087727489490663, 0.0090976819328423, 0.04862705561062021, 0.016160492612529668, 0.08056545269585426, 0.03554313954326414, 0.046159053566835584, 0.010273106914434222, 0.006661428487859667, 0.04986990303281815, 0.03917487510930627, 0.06017613750431807, 0.006707701634901066, 0.06076926192749412, 0.033205793794965556, 0.029534351891807975, 0.027751159673977285, 0.08434058076912358, 0.04077843120021205, 0.02331843513304428, 0.03095343784098664, 0.01650411177486662, 0.1161259364697241, 0.07123555131857434, 0.06869777781708587, 0.023940475544922298, 0.045506771834146593, 0.03399094198680213, 0.03704489020991229, 0.05154997981604069, 0.03571402694609377, 0.0270758091186684, 0.055880552277930325, 0.02775592091042669, 0.03328116535539589, 0.02891829845705821, 0.00935095155821933, 0.01960441214783538, 0.0429576640618184, 0.04193688254623164, 0.018165517080154632, 0.06165995405265882, 0.0278116193329615, 0.041522383013920444, 0.06019209511578084, 0.015399096019175506, 0.04757676055775054, 0.04460950667459158, 0.06834445040552847, 0.06441998881317916, 0.021746903432593234, 0.025716493349342097, 0.08588836182870212, 0.012744190546894267, 0.03442108503452713, 0.028413833389359138, 0.03390536230478076, 0.08105600177640877, 0.018726345151662827, 0.09657285987369477, 0.008486098621130712, 0.040848091575166875, 0.029854306598163904, 0.02281154922750448, 0.0341617297982016, 0.014882673276588322, 0.12424690513721398, 0.02010009018704295, 0.025983697156451886, 0.07055593939918665, 0.02688007365401474, 0.016936261972953236, 0.06609504772049767, 0.04072440284935217, 0.020951928247907953, 0.04392260159816473, 0.02091835444462636, 0.023615596808433056, 0.010925855960757022, 0.015147196733573032, 0.06616172035254779, 0.017494830085084807, 0.0606880757597185, 0.05858420679766325, 0.01626992061163389, 0.014163281284122458, 0.02020938603598024, 0.09605384296587399, 0.009392272425635208, 0.059509675484150655, 0.05320570266415035, 0.0235127495045984, 0.07756457138325899, 0.05625973132649257, 0.04450668618383427, 0.04148027882160198, 0.025495011584773183, 0.06670969538390636, 0.018055066353671493, 0.04875668917872733, 0.06128417643448038, 0.020550230044811484, 0.002055431856030238, 0.02461311797941885, 0.03872739932229442, 0.04987180293087037, 0.07437752304418434, 0.03312176927143047, 0.025859562184421286, 0.056154313797671954, 0.026108058124420144, 0.028232617206090403, 0.07259714236903576, 0.05455083048511898, 0.045852346435910275, 0.03029091542796983, 0.004646882026140849, 0.03158704235008167, 0.020032502079923308, 0.070931130960103, 0.0395820968063368, 0.1283617012743508, 0.06397525562093624, 0.027674813266663302, 0.029933409006785483, 0.03301902921990522, 0.03538851235662738, 0.018435086183730635, 0.014715126974718466, 0.03969922398908004, 0.04281809050289374, 0.017737678041861906, 0.02284467295413056, 0.042049007174829324, 0.015419623345106602, 0.01950001543117387, 0.009085670631799487, 0.040514150018533396, 0.0313465079788359, 0.12247901169523118, 0.040571074181747054, 0.030315363208853432, 0.05733462163217126, 0.06577704462312883, 0.041230465210373365, 0.036505656241769754, 0.039421126411686984, 0.01820781854011359, 0.02127327148862664, 0.08178169388444194, 0.011472104421456256, 0.06001672226815455, 0.040004195930856856, 0.040796449588191126, 0.07531201241598015, 0.04333156859502197, 0.034556062065906105, 0.021116116211839744, 0.04005810936852809, 0.057752706455968084, 0.04323247895245591, 0.009454264260467984, 0.011943867110887603, 0.051501379198124336, 0.022971523707852732, 0.01776576665560565, 0.02564361923554492, 0.025782740802594253, 0.09884008176384435, 0.04712460397352134, 0.08573247059699028, 0.021869682428997853, 0.03833939877128409, 0.040712206729597626, 0.020220249162746534, 0.0549737110193218, 0.03177105666949384, 0.05113034366419719, 0.028070574288346598, 0.05779125216987826, 0.08897962619460399, 0.032175570245712035, 0.031221428803438624, 0.032819597381016904, 0.03777557721121177, 0.08252145902764413, 0.03231821198677344, 0.01982013867687314, 0.013898673557466077, 0.01805828009251385, 0.0675425478707879, 0.015261842749051511, 0.028010141442439733, 0.023612545863274607, 0.04542548607494082, 0.04828889673996357, 0.04507528047167486, 0.02002865057288399, 0.022614047930185354, 0.09953883055958057, 0.029206673103955486, 0.03967115069709478, 0.08008624937745833, 0.02040728186858037, 0.01741006245626317, 0.08440055779271549, 0.09399339586736695, 0.05085210819097777, 0.027133773246239272, 0.061185262992136905, 0.020496753277257085, 0.08281470982417946, 0.04881202370949811, 0.06783462655279907, 0.03888776450748405, 0.05319778131501329, 0.014369047712534668, 0.02192558961049203, 0.12492221930334646, 0.1626605991153948, 0.09141773165714356, 0.14331070435864313, 0.11745452445240752, 0.1799895386061361, 0.1614729023628658, 0.17716872626014296, 0.11179687320104531, 0.21270921513918908, 0.1737443592038847, 0.12741028902030763, 0.11937567378364264, 0.15495681894883034, 0.14430415185709156, 0.18613353311534853, 0.1358208006187793, 0.18009329755460063, 0.10168671893376498, 0.0991509679043966, 0.07756669344680925, 0.09477737960555861, 0.14017947318573154, 0.16185249892934678, 0.1927342386015, 0.13366876770892452, 0.2194732199272802, 0.17024871532715138, 0.10795591519244256, 0.10286368279447479, 0.08728238138099832, 0.2656615801876591, 0.1489256998343814, 0.1946244226588357, 0.1158489037545458, 0.11360531567686027, 0.0869243961548613, 0.11999546189702327, 0.11806308937769745, 0.15212742641808527, 0.12919772536523882, 0.15239636924478317, 0.07772383340183767, 0.13181216894618927, 0.11126140838549023, 0.21994598810711216, 0.09134377352893354, 0.15538820305899267, 0.12267142233829345, 0.21201137032720352, 0.22160556437748097, 0.19113872260335954, 0.15740951072544823, 0.11957558442748363, 0.10182040893743116, 0.19852624635302252, 0.2008138308601995, 0.1398039828505247, 0.10901491683457168, 0.14731219609177884, 0.08700796102564182, 0.10988307831388329, 0.09779303109333401, 0.17512141756953734, 0.152638238524237, 0.08476443423499024, 0.09765453771838258, 0.11401224626047958, 0.10557949512956605, 0.15008062334550967, 0.15911362734773468, 0.16172538962095015, 0.10946064977155578, 0.13829569362344282, 0.09850964505946445, 0.19122285437920403, 0.1463061847513722, 0.18612277724089163, 0.14100289513026515, 0.3040301745697376, 0.1713671577313254, 0.09380813282463821, 0.10740091513481834, 0.1428961282175395, 0.07572782195864186, 0.17889577955488237, 0.1647186943239743, 0.09261803821690621, 0.16812570182786835, 0.24863359067709218, 0.15108516379710168, 0.1432254540944292, 0.12403107518630645, 0.18318409460686869, 0.18670837485021163, 0.0958681968791831, 0.11752181761567632, 0.1470082430469413, 0.10439827181999722, 0.10200793960041578, 0.12490780918949074, 0.14763775281608105, 0.08589975355613617, 0.08654748089611532, 0.09102746348587737, 0.26510089575763673, 0.13536724592408828, 0.20313184437972887, 0.1141129025528508, 0.2119536839065052, 0.22630715322109962, 0.22440241349320258, 0.2827793858464687, 0.1170084850802537, 0.0726952092842229, 0.09839251787672121, 0.10219481908866476, 0.131684155654042, 0.09610916983576552, 0.1266511571743796, 0.15836758028355338, 0.159526931782884, 0.20200911188317885, 0.07005837295324573, 0.15148673176525101, 0.08108826939977946, 0.17332598326667664, 0.1976572574987527, 0.17630385895890577, 0.14393403945911315, 0.08259321082263224, 0.18652491211410493, 0.15347043983638287, 0.16686989985887082, 0.165720890546518, 0.13612951873050583, 0.07816437226269515, 0.22136536516970207, 0.21754220338358035, 0.12199136608790968, 0.1594423863195604, 0.10210514849712772, 0.17964977861171771, 0.1873603003520158, 0.08999456245932849, 0.09366349542453405, 0.11961372794523356, 0.10417767680220066, 0.1832143244363608, 0.0915256734456747, 0.0994424260551891, 0.11551436081889177, 0.14108171025591512, 0.19394038275124567, 0.18347850219616968, 0.10917853023256026, 0.1274827685988238, 0.17946030974628466, 0.19777445362940912, 0.203846114116811, 0.182132899400688, 0.1026039406837475, 0.1708382199848852, 0.18455867084764666, 0.14689463220777052, 0.09329119967597146, 0.11407512675730452, 0.15908021059247757, 0.1664090213636237, 0.12693610357781573, 0.08094655079466682, 0.14003354875791457, 0.14274623545427478, 0.10649800390726137, 0.18233533047379988, 0.1711836183864263], [0.01111838917788719, 0.05665764505524309, 0.02570663571297642, 0.07294643249723219, 0.06801676395679675, 0.030780717572798173, 0.021713072989857005, 0.048007891858897866, 0.13410674017523566, 0.050443067035127076, 0.04081454841540225, 0.095584039546309, 0.024049999305017056, 0.030456445960988923, 0.021877668895608476, 0.012470384019487088, 0.014602306163719585, 0.031069540381131154, 0.05062307471469526, 0.08034015389820261, 0.08862056078449373, 0.03213048405614832, 0.0318402401547158, 0.049475850387206005, 0.07513782700463649, 0.0398804267658101, 0.09672754834736548, 0.04594970855020708, 0.011815573239038068, 0.06638223110067268, 0.013970039435662331, 0.026547627884053418, 0.08602500127087678, 0.0553779564647665, 0.04424112180488245, 0.02618780787733774, 0.02658500339865925, 0.0836758999033801, 0.050778399041343125, 0.07496944087887965, 0.08327175021892594, 0.0680127113516773, 0.02634963054480332, 0.03251415812560628, 0.05298366357061652, 0.029480549536885756, 0.0632521260770098, 0.0714320911755485, 0.08779933751230279, 0.03140192486405854, 0.06254424551321615, 0.04873344224066504, 0.015042093300801373, 0.013489910108487935, 0.04710734784302693, 0.014062324302240968, 0.016662245728976784, 0.07533279638136588, 0.04371546674519778, 0.015594779772894278, 0.029990492133243434, 0.02635234058083546, 0.017370603182503296, 0.08644887005850192, 0.03823372077256922, 0.02425331137924185, 0.03125209721826738, 0.02571562383954804, 0.05657458963293222, 0.04943329420301223, 0.038284290236450975, 0.08543750376350458, 0.0711352474266483, 0.03553327233079941, 0.021681881720019926, 0.057451817762827685, 0.024699885097722855, 0.03979032716503547, 0.059002896830920255, 0.010300179504068389, 0.06604545118827974, 0.044029103141398206, 0.028602486371152827, 0.07583553392079569, 0.0441876718504054, 0.07325717308107885, 0.0925757808070029, 0.018197097139613285, 0.03418330283414933, 0.03587996542093254, 0.03456333990118677, 0.059131216558237235, 0.026883206953625047, 0.024939592094010404, 0.07766823840117262, 0.026961445598112, 0.03841375909565437, 0.08066552676140301, 0.02331712895313338, 0.022998557035480777, 0.010003036023267816, 0.00691875598521062, 0.03096169052315095, 0.06088738119409931, 0.02339026928248425, 0.03984019948890613, 0.08271946211255367, 0.004475684836506844, 0.025486598024144772, 0.08916347197467282, 0.03549498325634388, 0.01074484087556841, 0.0316282827782655, 0.06010429377877905, 0.025703400906716144, 0.006164543381366398, 0.09049863299174656, 0.00533551367322704, 0.08159456158717794, 0.0876666664055759, 0.07846898414314755, 0.05417589556365725, 0.11034502167134516, 0.09229651877596494, 0.01374674970359211, 0.03974347322758648, 0.02768414996324047, 0.023649653247106942, 0.036616306151113207, 0.0414633865828716, 0.038268053002895853, 0.06547588779921494, 0.021152369407636505, 0.046061706774297266, 0.09437482338398696, 0.05923352377008527, 0.027071243234639688, 0.09797169045815546, 0.017630465952078664, 0.035853523896226, 0.055577522369041565, 0.07620612129328713, 0.007869025331831748, 0.08009536582375727, 0.07493421615612122, 0.07114251760104973, 0.008666456785924252, 0.0800569465143546, 0.03614772081134781, 0.05468748524905213, 0.05503757210868982, 0.0019731161873712535, 0.06246184509608054, 0.02183471626091388, 0.04923873085288271, 0.04019506673719134, 0.1306063465533718, 0.05339022260159255, 0.029922900195684166, 0.017239311034040108, 0.049190846527175563, 0.019219112056758136, 0.04623830919304202, 0.06602048438282744, 0.022739035175031713, 0.07873882329271686, 0.057812955440773126, 0.023557912302954544, 0.03037591288316875, 0.04001843750536923, 0.027610525083277496, 0.016334955730745872, 0.11971814572931298, 0.050470404882705024, 0.07380391471087933, 0.045696930178711494, 0.05249890228432994, 0.017840906474438888, 0.020124160669623845, 0.025137198728419123, 0.03157669633266426, 0.05180414480667922, 0.056661019672549544, 0.057203854253936204, 0.03278917985998335, 0.013427149312901161, 0.018859625298289523, 0.04832720113617759, 0.033651063248755476, 0.046271453987086014, 0.05458880929396518, 0.020625258780895703, 0.040683497584635214, 0.04432616905579644, 0.055982369193506826, 0.01857254342476447, 0.053458155448278116, 0.012563837170150253, 0.03443311261493833, 0.05304927517089152, 0.03599777059148877, 0.030920023000949336, 0.02781661614144762, 0.017317373478304476, 0.07971527896100476, 0.01653920817789772, 0.09015272131129619, 0.021991722150555542, 0.06111649894005349, 0.03182948044981928, 0.11954593682481397, 0.09766374609523243, 0.08345169661146018, 0.022879916829087084, 0.034995271764214964, 0.04701098547347131, 0.04387631456577971, 0.009990355352901164, 0.019594822642243197, 0.07259403205206318, 0.10775718432400497, 0.13369098425872866, 0.017174180153937593, 0.06670136800816943, 0.025378767318362673, 0.05980891325781423, 0.09277339318707105, 0.03988512288478594, 0.0378155823226177, 0.061198937661585316, 0.04281725546705627, 0.09284561229569298, 0.02331688380499761, 0.055305894404169054, 0.10014623869210483, 0.03187341942271638, 0.03879271597871858, 0.05559961251433819, 0.018016390404814196, 0.07462206597049391, 0.038865988458236383, 0.07398396835572298, 0.023456849983983466, 0.02353068745334543, 0.043002530001103885, 0.046514740529199766, 0.03937416139148897, 0.0649826497500462, 0.012503925264031898, 0.021157090424469883, 0.017787908511837165, 0.08163727098895658, 0.036893538049151825, 0.06528234334602472, 0.056675498734318444, 0.007869370071397675, 0.03723038690945795, 0.05344210973670406, 0.01935552550299514, 0.11922709869160769, 0.10932365792893595, 0.03071277131957393, 0.046111713163554675, 0.013161958401812422, 0.008448476043169298, 0.02650106889045527, 0.010067235148932424, 0.041602075310243715, 0.035176987819854295, 0.027999444939796964, 0.061042782129539605, 0.016294868264888084, 0.044606005652777614, 0.04121670627125329, 0.05965899368147216, 0.002910275136180703, 0.014310407512370619, 0.029794162950448455, 0.07145752529463462, 0.06106531277539269, 0.026619643979375402, 0.0071203558529246485, 0.02982991052821519, 0.048130370165792205, 0.02231158684158037, 0.022888449133343758, 0.04564900754860813, 0.027206189622501695, 0.06856730538270167, 0.02240243720852079, 0.06960648066935039, 0.05559711506770504, 0.03786784101037249, 0.04523230551351463, 0.006764953300702356, 0.12125392985199729, 0.05981678481123621, 0.025728398355685418, 0.1015894334282606, 0.06581176372785723, 0.038326436563605265, 0.004131386249942044, 0.020313338421645667, 0.026765428596146168, 0.04821899504731259, 0.06460178913849016, 0.0457489054139343, 0.1170600274757993, 0.03625585412186, 0.058381365867511886, 0.03908831866518144, 0.0269946804074871, 0.03263616528842719, 0.04231647911271261, 0.013214757181553832, 0.02385986011265026, 0.05812735409445821, 0.12266942284881108, 0.013995395988346109, 0.058605013745686704, 0.022908143338657195, 0.012092588717238078, 0.015986729507154275, 0.05169032329332925, 0.030695846522106763, 0.01328215089386269, 0.018747858815796433, 0.01927008946245957, 0.01664071099742526, 0.05819191615427694, 0.009029685883902976, 0.023350731484712135, 0.09701958106410119, 0.027039324181274544, 0.027472422413167455, 0.022715250060202617, 0.04966237747500982, 0.005364008313570653, 0.02136422719265665, 0.020452505953970457, 0.029373084638087504, 0.0474843665236427, 0.04439037871517001, 0.05930339098877965, 0.03118815568966731, 0.04661234779163234, 0.04083678028696487, 0.020616979285654043, 0.06790465464995754, 0.02933145350506229, 0.05644700151958293, 0.0499316037542397, 0.15187507705582728, 0.10409451795802002, 0.08694066020149378, 0.15270320278021599, 0.15588331036269665, 0.0871611939322564, 0.15479485263987897, 0.1303044159806544, 0.24060250710575815, 0.1622502364578747, 0.18611830328741383, 0.3092005632577404, 0.11129894669377997, 0.1254418567423859, 0.2715830414766266, 0.11184873735351909, 0.19197748162813727, 0.13919966205233528, 0.12674617505962812, 0.19807909615337851, 0.16161243761739424, 0.14151258874804745, 0.17936137715174308, 0.1741301917260693, 0.16900536994780266, 0.133895575699787, 0.10551317489796108, 0.15774819819677263, 0.1839198148058307, 0.1764752175058088, 0.14030563254510203, 0.12428347051383988, 0.143952333638745, 0.14649407547568122, 0.1445195911031577, 0.14230260925908245, 0.1463732327665052, 0.14670539316871475, 0.13292365527201083, 0.12146539310173643, 0.17469729597289718, 0.16537523167508264, 0.16020980723682912, 0.12132235682539402, 0.3268094312760138, 0.1854433185390888, 0.21163103831631525, 0.20645044533716095, 0.10279118023332089, 0.16299369414487194, 0.21070615568708992, 0.09745081961755792, 0.15074885119834255, 0.1980187284249452, 0.15083232413857214, 0.17502645331044353, 0.089646122688728, 0.2116730199345658, 0.222927893421823, 0.089234342768548, 0.08735499119446163, 0.12433047766887373, 0.11055071627901447, 0.16662669758642876, 0.09101045633395834, 0.11360539994653195, 0.10089904265177828, 0.15139343757783214, 0.13803386009268223, 0.10387933152096887, 0.09524211918394412, 0.11652159789997725, 0.17679194889722333, 0.14897500525318808, 0.10770773334849267, 0.2071482288621126, 0.0777074621028958, 0.1609372383644504, 0.1107525498035454, 0.08678703659003781, 0.13477106097965472, 0.12453982651594186, 0.1173785285303189, 0.26324969025388845, 0.17089405247280676, 0.13758626556204212, 0.15882651291547284, 0.09531195575912153, 0.09859396835729, 0.15956479184810193, 0.14304997399449348, 0.12939105531381023, 0.16911340366688468, 0.09299570424181801, 0.15566954118830545, 0.1726765552115056, 0.12947515644613775, 0.17254915478969776, 0.17868063142222745, 0.15057614433669275, 0.11847765785792183, 0.09645848294659969, 0.17515507947293021, 0.1741947422945692, 0.13571886495957453, 0.131354630594292, 0.09453291328804148, 0.13805940146407775, 0.07269692532117329, 0.1345934817988065, 0.15601618065228387, 0.10495068250043739, 0.09143312236354237, 0.18437125509785068, 0.1416806377951176, 0.2498501229790911, 0.21890525766197713, 0.10346303934291487, 0.12900275598850944, 0.20987783077984087, 0.1867227773031881, 0.19109761432534267, 0.18566523888899436, 0.13121671944616303, 0.11561906205550318, 0.08163397681088218, 0.1018075463211825, 0.1310563925653696, 0.07098803597111857, 0.20211927532669038, 0.26797847521881907, 0.27649225546948375, 0.209815425257529, 0.16235375025820348, 0.17889763348765914, 0.12362165481693323, 0.10488382600728544, 0.15676870882030458, 0.15738311133557753, 0.19175569917405808, 0.1756589048572125, 0.23865246093801915, 0.16228414350940337, 0.1731325920310713, 0.1330568013532508, 0.1279116935667492, 0.14433839598730688, 0.12228231862067215, 0.1354353664623153, 0.16321153890702034, 0.13644372203177021, 0.11694402644230474, 0.20743572633833657, 0.1297724598477925, 0.11245101269695068, 0.11839399339571116, 0.3142480714426887, 0.14183528030351286, 0.18524816530125757, 0.16206522622416097, 0.1376569754774532, 0.07099150634941555, 0.1311062342457233, 0.19252843674152129, 0.12546696144366457, 0.16283804040041663, 0.14024912589980712, 0.16032588487911612, 0.14514033682644367, 0.17394522745763102, 0.0791491782893577, 0.10178072558295342, 0.20929102275160053, 0.09555079133039522, 0.12376158077630306, 0.0900519960710118], [0.05581891667398234, 0.012434522486141613, 0.016800557158046195, 0.026490720957818053, 0.03421906381845474, 0.018360298765342564, 0.016180866720875906, 0.051802401956651485, 0.02803076835980098, 0.04197904419514441, 0.01900509390379152, 0.02796580984948143, 0.036195321684522976, 0.08831797903704067, 0.013941531388780043, 0.039243673635346275, 0.014500835902928827, 0.032601281474795074, 0.09245449376683082, 0.02011431643979684, 0.02639287046246952, 0.0300288041903367, 0.00782179840532462, 0.07264156014688554, 0.053348758092690865, 0.01656706696526418, 0.05821642330697468, 0.08305413528315483, 0.017183453648261005, 0.04841875247356873, 0.027330575488327492, 0.0488766317345923, 0.07015882240187737, 0.09571402934530089, 0.09403498678077614, 0.12985561103109391, 0.02527496431984248, 0.12259138147196463, 0.05478896508594194, 0.03806185660763614, 0.017036037264211525, 0.02164933255933706, 0.05292782342181571, 0.08092029696150173, 0.04896384701433201, 0.015187324419046844, 0.010704104150194797, 0.018303443550042087, 0.11663061221160236, 0.038052701856940985, 0.08685946254239929, 0.07831160670086261, 0.0221859714046361, 0.04205522397833486, 0.04510392066872409, 0.04732167243116325, 0.024753505506763057, 0.0074765106077275935, 0.005158757079287523, 0.015502441280160942, 0.06349171241444927, 0.02629077967046009, 0.04195171783888533, 0.02957026609369824, 0.02362631437849374, 0.017629521748711987, 0.03458431538855357, 0.045078536345353054, 0.023435954935848716, 0.041264196061679435, 0.011068864466412174, 0.018917210212337877, 0.0849813596916295, 0.023503288318733537, 0.009248629982222714, 0.0241494087892915, 0.00868011038795474, 0.09784019146595271, 0.03579162399194414, 0.03718251024463004, 0.019191845072313182, 0.02396246992922839, 0.023236590129653775, 0.02497087337917859, 0.03829752440534292, 0.030733413558693665, 0.06898837794940318, 0.04625086537412098, 0.012266682198030815, 0.07958755678226871, 0.0703333065875115, 0.03308751364989627, 0.04504617296099182, 0.008521035103307617, 0.08417751129356124, 0.02792824664333415, 0.02292001195582411, 0.0319728940244644, 0.06580214166352827, 0.08992929942905904, 0.048931560238763216, 0.021435544232747728, 0.045377352770658276, 0.046064660043245366, 0.017055296714627938, 0.009860947780731705, 0.012835175936831342, 0.016675297951986714, 0.032993641066094564, 0.059638696181918346, 0.04165023159716399, 0.010223895341398255, 0.05459582282891197, 0.031677547977456165, 0.02875239828661565, 0.11343196530135409, 0.019553233644053824, 0.04008591452973985, 0.03364958469906161, 0.007065735699143262, 0.04006699215801012, 0.027142278737418597, 0.06679103093882723, 0.08602978932040353, 0.06025357367170434, 0.0587143115098438, 0.03693275025955612, 0.01326823203388842, 0.014429061125302988, 0.047753914559800784, 0.04283149704156865, 0.014449628670850109, 0.07325047747262063, 0.026333347345972737, 0.0862437270341381, 0.013204929231095218, 0.04688542366268174, 0.029108085248979832, 0.04874045960605145, 0.011140028288918398, 0.015793727061170486, 0.027667656090230714, 0.046593482876496936, 0.015450463172108417, 0.028650401340376948, 0.0422322707280757, 0.03588722027357548, 0.024277718940509424, 0.035607349202637716, 0.04790399118416733, 0.02764511395305876, 0.010886866873460672, 0.027890133769101197, 0.013106267640156852, 0.02964435445685541, 0.06856153674063183, 0.022043592048688762, 0.08388574670759902, 0.04570104024042526, 0.03799161783629849, 0.07960330754999193, 0.057353651256210385, 0.03839898509003463, 0.04690978142823424, 0.0136628094497287, 0.012977589766735272, 0.02324889924737715, 0.03892424178399867, 0.08022563907528117, 0.034916525586478175, 0.021266374782088305, 0.059415963778813044, 0.04168943614668904, 0.03421351351144333, 0.024809816799637292, 0.04494287749572147, 0.01797054387298563, 0.0956010620199865, 0.06728528788493526, 0.07767563114964193, 0.020393396524952787, 0.010998909147606503, 0.019199789404087973, 0.058428867149256894, 0.027681392046713063, 0.02629771085095502, 0.07074085004147022, 0.013516975037242859, 0.009906467767582547, 0.05900284320476556, 0.031039138181856087, 0.082456395180235, 0.01913270116933892, 0.06062035358721211, 0.09172408255718409, 0.037833976093679667, 0.012199159208384734, 0.020901885469474142, 0.022514893170145732, 0.03573790207625397, 0.03423720861094133, 0.05406384754385199, 0.01270038755460372, 0.004082952256149222, 0.03622593455797723, 0.034403844225791194, 0.07531655531737112, 0.00794993714436949, 0.027154494009371248, 0.04987202509636841, 0.07956339436913691, 0.07094281380094829, 0.018945837002848426, 0.048977943032138774, 0.06866816851881243, 0.07891477070628636, 0.01838841802260328, 0.062340263112057606, 0.02575853625462661, 0.05491526234113882, 0.10938596385981768, 0.07912009759175201, 0.07096087815420282, 0.016744349287041736, 0.005967597018987422, 0.06059794934586652, 0.03006685960797533, 0.07517925703958159, 0.04810857879478605, 0.05614430868938085, 0.028730093636700225, 0.00784753465033587, 0.019123232322594812, 0.020858170577294884, 0.009822482506053583, 0.052691933458610896, 0.05121206226308019, 0.0271352996764284, 0.026455772026712378, 0.048476710855480165, 0.05150367746189718, 0.027939358748675838, 0.03384760693616925, 0.02479071631246517, 0.01759648229175758, 0.06935017063252388, 0.01994805429281006, 0.03217258250280734, 0.09146101562486542, 0.04887178622847123, 0.03502884556749656, 0.0928884442715395, 0.017914623284952778, 0.033824520876571056, 0.11299272878996788, 0.02881923371234969, 0.05342904793759508, 0.009468183120442255, 0.03273542347033659, 0.05370361001921758, 0.03473774364758884, 0.01600487429964086, 0.04834979689950424, 0.03049656407036368, 0.030262273315700795, 0.06512315027535924, 0.03201564173063925, 0.008715778484099336, 0.03421711029424783, 0.08545410488882373, 0.0515682548434744, 0.02930470554518604, 0.011527599830691133, 0.011490558521942267, 0.03455640297503241, 0.03939923161881105, 0.029357703507787762, 0.02520611025242796, 0.08620499362868649, 0.059299169844316865, 0.04666460647938713, 0.03998189511138105, 0.05113681710715737, 0.011480403068896023, 0.03638849841550954, 0.07500209920709172, 0.04293163239415135, 0.035301251111612204, 0.03797025930496954, 0.009488279521915942, 0.052476915560903094, 0.095476764254272, 0.051349873819779006, 0.11231366845388567, 0.02232470418206386, 0.021337504130637935, 0.045349739131427584, 0.032236029904696255, 0.04176504136393628, 0.030443140928963983, 0.01827869891008783, 0.04225329218071796, 0.04479809070847208, 0.031864952235933275, 0.04798875498254934, 0.056378252789258, 0.08899414356076911, 0.014885101775308291, 0.006966376010583895, 0.011156104644009424, 0.024883853451859568, 0.04042038085660146, 0.029516333503828898, 0.02172558895131994, 0.0675622746348381, 0.022130836056725636, 0.06542065285987432, 0.029672042789658713, 0.025563086157724745, 0.05487417321532004, 0.05422132074712746, 0.047757224059633674, 0.020616791594112595, 0.03126141476264644, 0.04915734167180715, 0.06117904618863137, 0.01502920865952488, 0.024747003335505727, 0.046362928715684724, 0.07274429253753155, 0.032985987847731, 0.019659568563163764, 0.034077961914121144, 0.08401224314565621, 0.016252101406515125, 0.05307647129220348, 0.07493152718750701, 0.012587848280917012, 0.025946120543765928, 0.027626911703977856, 0.0167481548288056, 0.04373570678815727, 0.02521739664277242, 0.08628066779384691, 0.019135053059266462, 0.04065966458931085, 0.010713492557706853, 0.0714337382645857, 0.03702427478386991, 0.042448487553385, 0.05834414931615034, 0.06166031794442285, 0.1485333402430819, 0.1308381341157421, 0.18600507549220519, 0.1559290611335347, 0.12782784524343668, 0.08124898698541426, 0.09402953223475526, 0.10411433665262115, 0.11823610267451695, 0.23073812916634545, 0.17403323563837236, 0.17161115673520874, 0.09399860526525206, 0.22764003895703824, 0.08968514720759085, 0.17860875705317145, 0.07048931273241198, 0.10837561646175962, 0.22112823031362028, 0.12098776026358529, 0.111009304171368, 0.16650518071987938, 0.11697283900913694, 0.22019205554839105, 0.20277572074724784, 0.10566530463796471, 0.14641567403751035, 0.09853242851433255, 0.0791006236367168, 0.12086966781005745, 0.13987404925207939, 0.09822351888062493, 0.17308834279256483, 0.22718329733658224, 0.18021709736316435, 0.29366954019473446, 0.0981719151980454, 0.3345440081771343, 0.09789377931625613, 0.15567263618351954, 0.12456369781566244, 0.1315774702497067, 0.14343974420860892, 0.17779731672377358, 0.18390466158668842, 0.11546557633987359, 0.1357152490245719, 0.07565333522976407, 0.22963821076818053, 0.1627999658305799, 0.26849987466008435, 0.16869318911865835, 0.17315638672199943, 0.19291938673104012, 0.11716244577039635, 0.1815017348816318, 0.07339811793738797, 0.11391106902831986, 0.18858905941728624, 0.2116687758074653, 0.09895268902783433, 0.12136272199812437, 0.14502956051259272, 0.15392810076234803, 0.17075370516507857, 0.07247456830115089, 0.11636077306203305, 0.0472786910681715, 0.08158150744894821, 0.17582591202470566, 0.09867823036808161, 0.08396181157760083, 0.19752869262329995, 0.13907642914883553, 0.1238014096874864, 0.21338407731344625, 0.13135348146240558, 0.14630423888804453, 0.18777086219239622, 0.09609824542196528, 0.11050907940032983, 0.1639209056813871, 0.11914635302438853, 0.10538110900069438, 0.1543690609715639, 0.11077306563815764, 0.15561781493165802, 0.14068247119505561, 0.1137383315231531, 0.19568003053146024, 0.15556330011496622, 0.15726297342729184, 0.12986843534294637, 0.17840499298707133, 0.17798594289248992, 0.1218290933437886, 0.14068864586372531, 0.15714044532468244, 0.1558686780833429, 0.15841915332261594, 0.11513125556971758, 0.06345142002007173, 0.1198104823068265, 0.16387923049830622, 0.1312856367158313, 0.1447201835652513, 0.1208864451355992, 0.10233204075766188, 0.12814692852477874, 0.25557044022265946, 0.13867977946516008, 0.11118683738694077, 0.15068868265276955, 0.11535498388712445, 0.1660529896616936, 0.2835432674375273, 0.17704025331524112, 0.15443736537089273, 0.20275057774157296, 0.1510556540902584, 0.12837126971252505, 0.10001824838259529, 0.17884576933518534, 0.14257674616190696, 0.093881010768875, 0.19478899366672964, 0.13622034611480852, 0.10581773315225879, 0.21053055301308635, 0.14356529069764, 0.30149635408193837, 0.14655672614612889, 0.12649168065118213, 0.11729315569203709, 0.17275169311511904, 0.08466603790199564, 0.16583025725858827, 0.12080953756888067, 0.1671895577061561, 0.1112346489342951, 0.1856970162160935, 0.1707120453037562, 0.11023357886100009, 0.14491826325895327, 0.15469935211923816, 0.2697553395503952, 0.12590253605477272, 0.07889566447345481, 0.18820554048063295, 0.20048378486066096, 0.10833148979732107, 0.1413229053779956, 0.13691554026257607, 0.16721545147799677, 0.11422442963286755, 0.12864658639075296, 0.0944793330986173, 0.20886631892813792, 0.17981473266357378, 0.2469220430019402, 0.21294910791179827, 0.19761132286681285, 0.09572581177757633, 0.1991535191454234, 0.18715059144362328, 0.16481436338395844, 0.11598579600573548, 0.1746770406081792, 0.2557613493333901, 0.12336219615873792, 0.22802921162257273, 0.17172155000509756, 0.11642532363053291, 0.21152246833568622, 0.10402731672530213, 0.3000068952960353], [0.07736640741988536, 0.046158693505511175, 0.047180359852650476, 0.016360313241039554, 0.03836998100122137, 0.03311370619602742, 0.02509223319770348, 0.027014780639400406, 0.057564279470112056, 0.03453042110308044, 0.03508686140600232, 0.05140222443808472, 0.04042725649572188, 0.0661804588631757, 0.10103404266579498, 0.0721604569304374, 0.04772454274878387, 0.03062983272567151, 0.021558110639753363, 0.04534782391161688, 0.029450472924978505, 0.02977046593573065, 0.024261657907176885, 0.047369867022479736, 0.036488798476995966, 0.03659007147014622, 0.019751265457260515, 0.1299788286128352, 0.08411046327842821, 0.03989147375367823, 0.05039653485460628, 0.06707613822072744, 0.012991320935168095, 0.06969055115816093, 0.008882868006044339, 0.028908952184381987, 0.046181381199388735, 0.024489800806247422, 0.02439591864634666, 0.05207060933894208, 0.045846210071636785, 0.033048960275106856, 0.05684425641271857, 0.10243392279071194, 0.0514054611595648, 0.03899696651065061, 0.016686877370962215, 0.013833063872410886, 0.05586659798638956, 0.07338841926426658, 0.010306188506224464, 0.03843000782052836, 0.05928535344860247, 0.024098347113918395, 0.03183735583368088, 0.04813043145282615, 0.012957856299415713, 0.026027662942426342, 0.08442870386305355, 0.05680407510109006, 0.040661625774397005, 0.07283156527386558, 0.014570954973028313, 0.048526606161988554, 0.010897224382196945, 0.018248823396260702, 0.03304136834377724, 0.07328527318614145, 0.06175564226484107, 0.005555715592157457, 0.03915011514759353, 0.13106379297471818, 0.0725012741261913, 0.04552711912941548, 0.03368984261948255, 0.047790027944551366, 0.017217050434180328, 0.03533601618161605, 0.0162936540155281, 0.028374276439388915, 0.021168338510418133, 0.013419598558797471, 0.015470819085866455, 0.04441147294616507, 0.060304955188785835, 0.01867696312406371, 0.008285239943483425, 0.06671040018479671, 0.03381782526811285, 0.03418748950465553, 0.034790163213807734, 0.023481839772073493, 0.06978963697028738, 0.026516838810376586, 0.03670540600714665, 0.023478786911695235, 0.010108788715555303, 0.03588612476784376, 0.016344328816499443, 0.04021965432912111, 0.02199536681385531, 0.053621929724730795, 0.05061687323294821, 0.02962011351971136, 0.03197304724204925, 0.03381678721897545, 0.019420055004077095, 0.021074025426059965, 0.0013765784833888195, 0.03093161582646351, 0.06296090541347381, 0.07628716573479676, 0.006870719878333471, 0.02957145544520069, 0.017783978480785605, 0.03316582315751622, 0.03172766161902297, 0.0252657329603549, 0.04039444878036457, 0.02441676772920595, 0.06643679188263994, 0.04186465194629085, 0.04844620906477494, 0.045898426624555747, 0.03287317757044108, 0.012966239216527151, 0.03559972662779112, 0.030969177117390983, 0.013449938513428695, 0.024037253517176838, 0.030586922225812753, 0.057263678059943264, 0.025263505559715054, 0.08349065218240985, 0.020002775953241417, 0.10236361890190071, 0.009557707197663766, 0.01742344601230035, 0.05639134906232358, 0.007571454757013389, 0.03526902945351697, 0.012745110810013309, 0.09394668748662358, 0.04987567550532761, 0.03351085000641404, 0.02118913971278216, 0.011416303534661571, 0.03592487732549349, 0.04962325336471681, 0.04928977529127752, 0.026258563758024288, 0.03199212091614402, 0.02511441335833121, 0.06310052876811355, 0.05482423960441544, 0.042967987096598076, 0.030606108897876357, 0.11614530317244992, 0.06441286419548335, 0.029312186393766638, 0.10724021287094201, 0.019548794164532618, 0.0767459145056144, 0.15255205363275545, 0.06605211615322099, 0.037659204625073946, 0.07317395294986426, 0.06843897799450545, 0.001989407166782316, 0.048458562232553966, 0.011791926977645245, 0.061388092430969404, 0.05021254351783184, 0.029430728923949986, 0.048754750976278904, 0.08631669690892582, 0.055504452902823694, 0.05177085445592961, 0.04246990354130826, 0.06191412670417659, 0.04870454540416118, 0.009042194184486665, 0.018665720783774892, 0.023345301836548794, 0.019994546253714832, 0.027073246554561683, 0.03938246578458817, 0.0354734753378697, 0.06592915138049472, 0.1027791373311512, 0.05554023303932721, 0.03234472628983279, 0.05128893535584212, 0.08593301709380843, 0.10211399681265317, 0.03756298781222394, 0.02279320908259721, 0.02189608373408837, 0.06750959842916458, 0.060595015229116526, 0.020483036472972845, 0.07821509494416176, 0.031031272374093536, 0.045843907977424325, 0.03646081711556162, 0.006527826584304773, 0.025932101134751594, 0.01850371042476787, 0.03447006869640562, 0.05295515743895404, 0.06597752983291304, 0.010461618169961918, 0.08545203645142817, 0.03596820342805117, 0.008720319470270507, 0.04331525475267441, 0.05929698649373266, 0.04311789135118166, 0.01298415418263645, 0.07846211233446676, 0.03207326111864419, 0.0357190792959544, 0.06966567628325955, 0.04298890512737055, 0.06691912083976692, 0.009746944321499718, 0.020202832153788017, 0.0444663861285775, 0.0920349610368571, 0.032508527379362814, 0.013759875662564753, 0.00787994304236265, 0.0632233135101776, 0.00836348433362981, 0.03394653186983159, 0.038190023117368264, 0.04424890525819314, 0.08476132391801766, 0.02748699149026746, 0.03563863623346533, 0.023576746574572982, 0.05633168230434099, 0.04679740399062153, 0.03042467246432939, 0.01122944894427013, 0.08531309108460143, 0.029005226453826315, 0.015050401524340194, 0.02979947385498353, 0.02750641564958759, 0.032830177055251215, 0.061450754592735926, 0.018728940274506327, 0.07023197613776692, 0.026370242140406085, 0.09140242522041644, 0.06330763680800315, 0.024081958577998226, 0.042326089685722705, 0.054712386937030864, 0.060726361003734415, 0.004331970093546495, 0.06253599857671127, 0.04878905639352818, 0.04277087650412033, 0.008541322069152469, 0.04773116174844965, 0.06722531852222259, 0.02071401389736322, 0.06575053798094874, 0.03270171943210787, 0.00768762241463147, 0.019223505571003885, 0.020425978244372436, 0.0489097229024816, 0.03599846390106025, 0.05412777758113319, 0.10169017399030347, 0.06321676728886462, 0.031792888260116024, 0.04182321425046652, 0.06520102311286234, 0.02626356248173022, 0.04936245788309363, 0.019182157890510657, 0.08154817496336277, 0.07053173868165863, 0.045262002911899364, 0.023318666874641375, 0.05070468223082924, 0.031083705346851103, 0.020588869604492382, 0.03483142087896986, 0.03843786788263148, 0.07584612125590925, 0.016320635632221258, 0.04014333281966467, 0.03703999490807614, 0.026842284451929793, 0.025254576804957567, 0.05643485902598309, 0.039184922352433205, 0.07750963521820885, 0.03950608939292931, 0.019092163626825618, 0.013082353247990532, 0.02039444989584867, 0.05404426633650738, 0.011571347281607169, 0.05295504635620502, 0.01180159021920014, 0.05685498547409812, 0.01714715831762841, 0.04180660546426812, 0.07305791361197349, 0.0308218143594962, 0.05953333610969205, 0.05327850783003434, 0.09012197054201558, 0.03260467907473926, 0.019567672486206698, 0.047193793204402736, 0.038174915863501455, 0.10051773004834691, 0.09471168756605157, 0.03210906232256563, 0.04606020141152605, 0.01093101364770724, 0.1029273447009825, 0.043938367687646425, 0.09551388121420339, 0.03343981833407476, 0.02802303087176575, 0.05148308501849252, 0.02622790108885496, 0.05965591017757693, 0.05528282366632935, 0.08706537165468739, 0.04704164048176139, 0.10820885444240225, 0.019095000067365267, 0.054869538383378144, 0.04485548984619879, 0.04543314695418362, 0.08623264174187377, 0.05268465562333023, 0.034443600358621734, 0.015515405403059578, 0.05902750357504814, 0.014794201612652791, 0.04994749241778928, 0.044258469865927776, 0.23542353823300333, 0.15062630777397465, 0.11788120478271477, 0.22646125946794787, 0.09221807903339786, 0.16122475116243287, 0.16232949591452078, 0.07682885884517625, 0.1520972425538686, 0.16856851596986094, 0.11995415443614607, 0.12353314101816186, 0.15314414766767334, 0.12643871333209739, 0.23690844645663617, 0.2431099282036866, 0.10720240643187877, 0.18360289955331435, 0.13904855887015022, 0.1351285022833655, 0.08606497573876574, 0.11197088241216638, 0.1502787490044871, 0.09867050054092562, 0.121251049361402, 0.27363180573428836, 0.1287444004969251, 0.18194571347726932, 0.14912829944683662, 0.15054478069707272, 0.10571663252889149, 0.20065200244707448, 0.1130767762961407, 0.20012721689718388, 0.0891302160978798, 0.1339011221763588, 0.16977910342956745, 0.16897259670640194, 0.0958868817636563, 0.17254351638257506, 0.24587141470082347, 0.11305983043125561, 0.133741193661286, 0.32332927769710945, 0.15370308541722838, 0.10264955355875915, 0.1644973255573742, 0.10237527876010827, 0.17056190739235572, 0.15070930573969119, 0.16394546646023953, 0.1217115831170832, 0.1721962793700157, 0.14716683856902585, 0.06837733856011784, 0.14804298268450847, 0.14540471376911288, 0.15153167048288932, 0.19149870731897894, 0.14789155774539517, 0.22087727523138448, 0.24892930061586444, 0.09092163610001726, 0.1389563678493423, 0.09534475198315998, 0.11353114304403145, 0.15027418312045837, 0.23334071370622805, 0.15313619567501932, 0.15390848891148645, 0.09173158255796279, 0.29924126702450937, 0.10983974072000674, 0.11149206979861183, 0.13869548426760783, 0.16774687134931165, 0.07576915240215679, 0.16164577776385894, 0.07194248193334188, 0.23983900855866172, 0.19765004095050598, 0.09984974734364979, 0.15032411673136298, 0.18272601999342444, 0.20833437811703454, 0.17265197911089467, 0.1281866501836527, 0.12789230388138564, 0.20798579278972842, 0.0779946991092255, 0.22185632027685645, 0.1760408303309833, 0.17082867452934866, 0.10723794525068615, 0.09538780612450454, 0.07046466002300864, 0.07730616226551995, 0.1355864390009834, 0.16151057856698192, 0.15570456672820354, 0.17127132013199792, 0.17417991083235512, 0.15556633382314639, 0.08902402865069528, 0.11235638551654355, 0.19758872327304658, 0.09846166497276676, 0.10989862223786694, 0.13053621886478317, 0.15242272266937842, 0.11835570432125561, 0.20706031261192215, 0.11580601049166535, 0.10315071295706496, 0.08010904049320568, 0.14695423384827955, 0.12487548793996535, 0.1405834773134801, 0.22716339437230942, 0.10829506997740078, 0.10193805705996291, 0.1844223531624002, 0.16625673840603522, 0.11858918493793857, 0.21449639101422605, 0.07140031384844935, 0.25310930615711597, 0.11138771330156635, 0.08143533787299549, 0.214987775130618, 0.124706833683435, 0.09761709134064375, 0.1331583692902519, 0.14270109755377616, 0.14981353445158851, 0.14031710854220775, 0.05206157333187519, 0.17067398605567796, 0.13981403392409125, 0.13428150015252252, 0.13391457468030915, 0.1353175881048364, 0.250796762505366, 0.13837919720718939, 0.14456384034166414, 0.12263008423389928, 0.15185497490869415, 0.20558802951728145, 0.10067543690843929, 0.11678669496529526, 0.11074737104917727, 0.10933123453850709, 0.16935864373320536, 0.13791359961032867, 0.18201904341338143, 0.13438159720070902, 0.14309953988319443, 0.2838910100681167, 0.17307355729562623, 0.14156739467815047, 0.14063713411169668, 0.16246120175046308, 0.14395291586556744, 0.2339093501289045, 0.12950253642855153, 0.05642555871858232, 0.20606616031258337, 0.2668019480282261, 0.14251689937326217, 0.20774139542012446, 0.08181214587943209, 0.13306482995469726, 0.11137377816222369, 0.11981294144906345, 0.14161818630753026, 0.2156911510974169], [0.07910931873465739, 0.10207770722768, 0.047498064175728834, 0.043082973063592954, 0.03853740185619362, 0.03422482096920571, 0.08559013912153822, 0.02239068541976233, 0.01935858985469226, 0.021078587479649052, 0.04697681029116915, 0.07069632501131104, 0.009832098824723114, 0.03293749448212405, 0.019831568708703406, 0.01298986536811196, 0.08105162741436113, 0.08064298845467069, 0.023449939870906454, 0.0744434678927064, 0.06673505289420005, 0.008660070485465469, 0.04020679937375169, 0.019084123534060294, 0.07333617206783065, 0.08042841488795896, 0.02028521916438495, 0.00707425459686126, 0.025885419567085566, 0.011855563986295415, 0.03694519918832568, 0.0377898647509996, 0.029557637134266478, 0.04818947001871082, 0.0386412910396053, 0.06557665134389555, 0.06716527255071748, 0.04640565726966147, 0.0706437177535507, 0.0353352194501748, 0.07660811827067407, 0.05109655152585718, 0.03743687441812889, 0.019299028433799263, 0.030655247692559517, 0.04243521508009684, 0.05665092646414715, 0.019862210310454813, 0.053832718817096566, 0.04215202684844694, 0.05602357706295387, 0.05267744290552313, 0.05154732915182268, 0.05600596087113504, 0.019272862700745463, 0.031145664622947097, 0.04134424075844788, 0.03995387544555049, 0.03096933799585508, 0.015429584403342057, 0.02517472171495038, 0.15298219668048044, 0.024277682551333023, 0.06734495081247822, 0.057918702387401176, 0.07592898898667867, 0.07901651484351005, 0.01850538241166261, 0.006736002838043797, 0.017308111475299925, 0.0699759342317139, 0.064570011811391, 0.035474494234808994, 0.028796739455673005, 0.018567797510073553, 0.020171958810439514, 0.022180061036300276, 0.05367042309033775, 0.024547471905187256, 0.05306530556070709, 0.023942143701377417, 0.04381088299616691, 0.008161869144157298, 0.04000660144693909, 0.02426109291733273, 0.024237081806565967, 0.05979269134601759, 0.00585027304740863, 0.010832481334106097, 0.043764090345751856, 0.013554255748468061, 0.06622291545593931, 0.052370272291403626, 0.019961054804885102, 0.006032047996057138, 0.03150748603436495, 0.03750115302541564, 0.02048802370535991, 0.0901938142675546, 0.08075171165288457, 0.040908482286237904, 0.013675487247265637, 0.004704895949426798, 0.09080091596490915, 0.02283175096606776, 0.04264246867669206, 0.033912440957201105, 0.03246279193028327, 0.035748179145758195, 0.023161639917581793, 0.07481677487732903, 0.013471452177562302, 0.039855088407714526, 0.009068275647868794, 0.023374824949930754, 0.01187107630915219, 0.04703326331030938, 0.06670180467828628, 0.04334707038416978, 0.05268222712461026, 0.013629623478458775, 0.02308482428141419, 0.050893373517019135, 0.045678846673258854, 0.04223998523347321, 0.04974984939420416, 0.024227086274373918, 0.01324318478920407, 0.020215960985590375, 0.04468873548772066, 0.01844851762026308, 0.024699124755458008, 0.037727152793518, 0.031110026212709568, 0.052017756933045965, 0.009042978466999148, 0.06333095269397863, 0.010852740529263693, 0.037309259491702246, 0.042350313385888454, 0.05143580973268517, 0.008076627498432513, 0.020528128408195994, 0.06203362875948511, 0.037791105813436934, 0.033962998929763996, 0.04088096057755813, 0.026829971503766797, 0.0357302297056923, 0.004414497872799515, 0.05883485161428971, 0.019717327762214888, 0.02746647565565523, 0.01496147116526, 0.014604116046440699, 0.060015753166930336, 0.06431862771991761, 0.03441826583096578, 0.0232071532011633, 0.05964926819527342, 0.015454375008571775, 0.025340694663745743, 0.04272612930846311, 0.01776778912772575, 0.06934708329818903, 0.04797859282623376, 0.16820160581940607, 0.03483992828536899, 0.06339030918635188, 0.043665889365177964, 0.016435510516467116, 0.034190630465145075, 0.056641974726751934, 0.02929657543708961, 0.018663897494515105, 0.04152371983734831, 0.025987002825845155, 0.035321939316007404, 0.07663356005063943, 0.06575660539730903, 0.033242071888619856, 0.037583603238266323, 0.04122838145121932, 0.06234327000716041, 0.011646993676080339, 0.018892657094364686, 0.02821365652996446, 0.03127377942174433, 0.02992444386285159, 0.04754429758195916, 0.06926593160437, 0.08020233468062456, 0.06430928144724139, 0.03214955389980347, 0.039935259508990475, 0.004072290706268002, 0.03810803638771176, 0.035793657955383106, 0.0943602447307879, 0.07002998173477189, 0.027679902005700335, 0.006171270112146534, 0.0357747930402477, 0.028979704234628912, 0.06197623728263763, 0.059626392809854406, 0.037145466063051455, 0.03932444228520317, 0.035287446207216674, 0.11007863757831436, 0.04598596366122366, 0.05485081136406911, 0.06178461571013736, 0.044047657790924274, 0.03386284442498319, 0.04163923057457132, 0.04469095714270108, 0.0277889431304028, 0.06908790043164646, 0.01202976088895793, 0.0030761970922486078, 0.02528170589357615, 0.06193579550111487, 0.02496707932873359, 0.03757509583186719, 0.0545025477936912, 0.030506762615855665, 0.024394263896430214, 0.026529435211071567, 0.05166013176823336, 0.028928253769634232, 0.04917002425739362, 0.046625627925799745, 0.0272156048430911, 0.031638245751720764, 0.07218519390951242, 0.06410099363194839, 0.02044745360410983, 0.0449630179472508, 0.0660007729405357, 0.016141769423660253, 0.05426702172225041, 0.06210447274028294, 0.03570505605650044, 0.032902756225197546, 0.010511371750204314, 0.044842293981703064, 0.04087819116971186, 0.024033534160304456, 0.03170081598293637, 0.06997768091218126, 0.08456187292693124, 0.02640404193962534, 0.13937567841381798, 0.005536796093257445, 0.009923127307105931, 0.03233653297948261, 0.005341278484857251, 0.02041301603669361, 0.032511499800509026, 0.036620895017779646, 0.028339881006808534, 0.05817346492662065, 0.026130780292254303, 0.025936057978880503, 0.053476828841432456, 0.029098693011028152, 0.06837808166540439, 0.05383900456851529, 0.06457072427316059, 0.027091655647382144, 0.01956256651019137, 0.021331168583504135, 0.06707721074382145, 0.025909951617640835, 0.08363807048167914, 0.028388623350990877, 0.013536284283374347, 0.033819932009904616, 0.021660990502324798, 0.01945484305671867, 0.05675636314516587, 0.024656543673406688, 0.01562716901272295, 0.05019451746897352, 0.04136007196540314, 0.06438515479526212, 0.01594986152579828, 0.049433730873129064, 0.06294494397157142, 0.04730348167340121, 0.014523347396583808, 0.03623246928797134, 0.04407089706810732, 0.051153697854568886, 0.044141212448237405, 0.04766187675657773, 0.028675956118311134, 0.007403724115236753, 0.039199336296728546, 0.039464858540844534, 0.028927083570329897, 0.019296490767550085, 0.017792939794279875, 0.04271653405721149, 0.055701586477939165, 0.023584288710187522, 0.040218037883600885, 0.010666494978772057, 0.017077871410536672, 0.020803628947525736, 0.042602693391663414, 0.06730897532355401, 0.016644294373691082, 0.005687667533845431, 0.07216178992342565, 0.06463397249218918, 0.04578252518249135, 0.014067325898776612, 0.028974197977673144, 0.02567612243095233, 0.08381700563815334, 0.03350564443896856, 0.028298196247628624, 0.04956097041647281, 0.06445506031835271, 0.04339609235044449, 0.10904267220006836, 0.022406945635955182, 0.026140172530205983, 0.032030138029386444, 0.056461066893872716, 0.04472259274353424, 0.022992924374017506, 0.09161314536486903, 0.07792139215575111, 0.009304180932832102, 0.04644940089013788, 0.04708525003685106, 0.05023843728967252, 0.005223583439440137, 0.04391396012637885, 0.06859411846005148, 0.023946100545506326, 0.04323899069981229, 0.04871902063549046, 0.031281026613508026, 0.06643531333294607, 0.06270451876785486, 0.038488571411899986, 0.048561087779460416, 0.015305027125343202, 0.14869213494802677, 0.12614855753077617, 0.12930926776701404, 0.2127476267877125, 0.06958884532533346, 0.11314894943948715, 0.21678368440799176, 0.09935990306398562, 0.18656085695951216, 0.1327895439199863, 0.13706183241259667, 0.15567134915580674, 0.11448364314292708, 0.13713949840636025, 0.13110724548178335, 0.21585290290174947, 0.1411988604212961, 0.13389030501486796, 0.10279186205157351, 0.1394728643278922, 0.20967696252609455, 0.0868523609073412, 0.18982829856536082, 0.14093224650188801, 0.16428055331831978, 0.16555654936500136, 0.18193268998255654, 0.0776875974430192, 0.10321134881627175, 0.20886319328940686, 0.1123793911369097, 0.2460954954186755, 0.10129153247802489, 0.2151438732060694, 0.16470085979709703, 0.1789111932439189, 0.21519357699059674, 0.13997341085585857, 0.20663718692958358, 0.09368127632525661, 0.11641207030944287, 0.133223210972163, 0.16904603389482345, 0.14998840168118477, 0.08326265675526473, 0.11288168434534343, 0.15444855025458723, 0.10368220943717227, 0.16078630372160868, 0.12561140732178766, 0.11133289971058408, 0.17717392033626958, 0.19390760950984495, 0.1155195395732599, 0.07966104759684495, 0.1351381856347284, 0.11271658473678174, 0.16569442986961336, 0.08873904394286294, 0.21953076845215214, 0.1705486234277487, 0.22929766936407936, 0.08416862467363959, 0.18787367119183465, 0.13343172478339366, 0.13946563245788698, 0.12604621584497153, 0.10285619045457534, 0.15399035306707506, 0.1085750597919668, 0.1947249180727428, 0.1718810954762082, 0.10126034503862744, 0.12772589426247344, 0.11356731005493673, 0.1787868265302912, 0.14002631688790937, 0.22207513030978943, 0.13913475908339024, 0.11257609187234795, 0.06305889571986853, 0.14923279383970847, 0.08245533797889948, 0.1013626407591566, 0.13422408952347695, 0.1799409839534952, 0.21996474193949855, 0.18117057039372383, 0.08095257224575167, 0.19828347308981806, 0.06683871991211368, 0.11422960838723568, 0.20484121636517588, 0.1519549340610543, 0.19770178252891188, 0.1516046020532808, 0.15295731414469982, 0.17996623421147948, 0.11421365843665217, 0.21198875541167878, 0.16861716255305276, 0.12947671926550328, 0.0781102787943617, 0.17392740825251227, 0.14205177675091452, 0.10648244466151922, 0.13666346669197083, 0.13551108659275118, 0.17630365977604545, 0.0780601460005968, 0.17091950191365135, 0.145661705624192, 0.1479372931944747, 0.1690870808858064, 0.14470009673987666, 0.062414726858297666, 0.080523670260464, 0.1474135801676781, 0.14403936122694325, 0.1109443552371475, 0.1189538274681376, 0.2077378560939143, 0.15747815220346376, 0.10699653562398688, 0.1654970856203187, 0.15882236071892325, 0.09692724448658767, 0.1019877378618525, 0.20527522049603925, 0.2576498939625679, 0.09346979775375898, 0.07404161647202508, 0.12579171377564632, 0.08351162766977664, 0.1353121642023325, 0.16509095176814065, 0.1920272773432155, 0.07070092153885672, 0.10239831502399138, 0.13765519815346888, 0.10736548356832036, 0.16122404636154253, 0.06946654704910132, 0.12177923634167641, 0.0961663276557961, 0.16065268266585567, 0.1608580401948383, 0.1731753550590046, 0.16812885811011638, 0.1540009710457056, 0.14564145025947403, 0.20758802461768353, 0.10037302370032958, 0.08579480717138899, 0.09641142216541114, 0.17179472672362484, 0.11333160778327335, 0.1252265707139046, 0.11265470015425837, 0.14828581723474688, 0.0904279843633694, 0.09526321724537881, 0.11076009576959957, 0.09964892505517892, 0.14971319225526628, 0.08275765925645828, 0.20846107373795203, 0.15230590958268414, 0.13055003909093718, 0.12541378728084027, 0.11545403905573393, 0.15758152810796616, 0.1355991254170095, 0.09932156802425463, 0.15851558847052438, 0.20762769265040276], [0.045802340046652866, 0.01627951011722607, 0.06785720316392761, 0.10657804477359019, 0.09664185375215546, 0.0340787050194077, 0.022456915636036186, 0.05182941038642199, 0.07666830979888478, 0.044410852414946404, 0.018034010427072644, 0.06233456724834058, 0.019122943124403397, 0.08882442444202401, 0.04468222374036428, 0.015346939795680586, 0.03219753781694078, 0.07001524986398798, 0.09506374327165466, 0.07339124612870716, 0.026242364828865376, 0.01717906396445488, 0.02411748782070654, 0.06260970772634591, 0.0924406735406768, 0.05386314399900937, 0.03962050079398098, 0.012406100624150807, 0.06227089768095363, 0.023086894634029558, 0.08218988085225706, 0.05016809892690471, 0.038092657172631834, 0.06130704032858053, 0.04880572646676053, 0.02654889767478791, 0.011244831989789683, 0.04183424974701578, 0.057986642894965995, 0.03996413719329623, 0.009402583969096023, 0.012040469840529465, 0.06103013018747011, 0.020838564472092737, 0.028936470062622142, 0.012909568819938409, 0.039934141020621025, 0.04793440104432164, 0.032061237368672606, 0.04459009017615069, 0.06944663642394928, 0.02005659937558155, 0.06844139117146693, 0.018600903999721332, 0.023761423560039654, 0.02805858501233161, 0.028476156557219166, 0.0532976140628659, 0.014133957353600813, 0.0684275326409167, 0.007932872057051189, 0.09429526515305044, 0.0173496468473346, 0.06503685813156829, 0.056592236468268026, 0.049310494139189684, 0.04122200376924969, 0.027330364814148318, 0.013499039961325546, 0.06604614832829084, 0.04010292168165888, 0.022270053384765502, 0.023738944625121453, 0.0659159210420424, 0.023993823992749377, 0.02918210657944362, 0.02187273720459592, 0.016392598101388545, 0.035351069809328166, 0.08558870653711981, 0.03463313817196796, 0.032892069298653834, 0.021501050495933142, 0.03312026773909888, 0.046209450660934376, 0.10167011014756658, 0.1168216209137632, 0.07807753619647796, 0.0334805244159314, 0.004755960018824666, 0.026187572305301027, 0.009999108865045974, 0.026007292664519725, 0.03575901928988676, 0.0816212367687014, 0.01686104554532757, 0.062453797342435974, 0.034515627945262584, 0.06664122244523418, 0.032803681904389974, 0.054802521011762084, 0.020801326853313276, 0.02904094338807608, 0.053066251679293575, 0.030544620765853795, 0.0676224968065658, 0.03335220468861442, 0.050670491726768595, 0.013537713994963035, 0.022274286020547155, 0.019165005181886016, 0.015634088701899015, 0.08366018744005312, 0.04589109516312038, 0.03576281525555157, 0.0012873252900692845, 0.11330032841332498, 0.09035674584729057, 0.005464936088350031, 0.018960302658078652, 0.040512319068394365, 0.04669130464354831, 0.026682882622304945, 0.03500374086621789, 0.030316692371402058, 0.03774463491995008, 0.04034009101169725, 0.02121563677886321, 0.007329067889405716, 0.027831865121580424, 0.0216553176212455, 0.02929737216853086, 0.036145797930657864, 0.0408485435670422, 0.0313731027211273, 0.02254239189618778, 0.05452058150342876, 0.04086329459002422, 0.04097192202724757, 0.061607404251492796, 0.02289253621241979, 0.047696833348562645, 0.06584846700030951, 0.016118152848174496, 0.05507859611703504, 0.03469784195805269, 0.0134983514398036, 0.058269815804857406, 0.02730887221743263, 0.056656411653685, 0.05020416251594021, 0.015498124374707621, 0.06792469551005671, 0.007817668233802843, 0.07157976994471205, 0.0314516190724868, 0.03333205657620584, 0.037149376941904906, 0.06559757320510765, 0.08826489680476728, 0.02007137529642111, 0.030763869384123437, 0.01726673698172935, 0.03435299513981708, 0.014076597477880218, 0.06623945529422452, 0.038577989194422, 0.034647203546257756, 0.02469288496931474, 0.035674109934799136, 0.006607917725153629, 0.035190409680287686, 0.04381554081074653, 0.046843909358064977, 0.018398804259636713, 0.02426413428639212, 0.026012205203334172, 0.02655792793619537, 0.013182651394257143, 0.0443516644619165, 0.03855793684300396, 0.028008182172573386, 0.07229909586209445, 0.11551803038004907, 0.05608846854058005, 0.052438277916442004, 0.035235804220240925, 0.026832704522436666, 0.025005065798459035, 0.008811420731006131, 0.021023777719106407, 0.04950048011397162, 0.06156241190769981, 0.011087678628222597, 0.05606404565755398, 0.033197504723624836, 0.05209308252820084, 0.05973335017540282, 0.035070666307283026, 0.09898563080857839, 0.056634627943558086, 0.026936547740572886, 0.015685212621915967, 0.04504913006037955, 0.04014470411704914, 0.0511175116914655, 0.041931313087022117, 0.06156905389000332, 0.048931330412385926, 0.05463074877737992, 0.035605361204474203, 0.0382007675005063, 0.001863343209298628, 0.020528898326559894, 0.011027897914661276, 0.03316707571127242, 0.020248291811214823, 0.017886841106378747, 0.035315059846447366, 0.033492915888106635, 0.02178846370248545, 0.05502219289360989, 0.06453217472881079, 0.017051872301606402, 0.021606868305694193, 0.053351033373825976, 0.03349454382494573, 0.02008721799469523, 0.044465076118226976, 0.051949100133271954, 0.03208623290242207, 0.03827833007240007, 0.0747021911064944, 0.057178734230899045, 0.062276371379172614, 0.13879628611668465, 0.018991493927915732, 0.10498898689665141, 0.06995511196193195, 0.01918380880998748, 0.0126236762979158, 0.03369019501992772, 0.008596263979862054, 0.016216926479471788, 0.039348286771846396, 0.012483870997394045, 0.03165243178485863, 0.021594813912205642, 0.04416761949898736, 0.05923333607854382, 0.09148547681228769, 0.023590959420788194, 0.0865483925407452, 0.08068289397464645, 0.0345123375976278, 0.0910605967886025, 0.011206091881068725, 0.041305223900464275, 0.030741227655521328, 0.03958821401841218, 0.03880221163854003, 0.07001648326554606, 0.10775899229150628, 0.050869823974226756, 0.027676098379156286, 0.019053116125325044, 0.046546406773549896, 0.015447574063023974, 0.016841751620954564, 0.014729162663101189, 0.05160859320312739, 0.049440840169066386, 0.0897232600818238, 0.014889850562828925, 0.02414231098467304, 0.10007061049221985, 0.025710755350789236, 0.0191867295201988, 0.04297539133638625, 0.05685799619964054, 0.02816851096858661, 0.02998316258702788, 0.026455247256484245, 0.05194609323816915, 0.034493978300522414, 0.022155400666017688, 0.014166476828376613, 0.09118288740395539, 0.09323706790324181, 0.007726985448595858, 0.01975157955330947, 0.05011763671533235, 0.05999676567772704, 0.024395792241839152, 0.023976539133957798, 0.041615393748807336, 0.03432631229741439, 0.03601171339171068, 0.0352511374700454, 0.06485439130976316, 0.0524504472231192, 0.032544656085871884, 0.050863430970498634, 0.019533811399953502, 0.01620048240217711, 0.05152463379706587, 0.062839989925945, 0.04787007264131981, 0.028751291289565065, 0.028113808460353364, 0.029607833130285147, 0.03004074941629604, 0.05468159786335403, 0.033928222368441285, 0.01540984231753335, 0.04990848705112454, 0.04113562735578707, 0.023053117817448034, 0.02105494792152557, 0.007328169172509544, 0.01753873649924513, 0.00390579131142717, 0.03327936887921345, 0.031111301749103495, 0.055242895163715854, 0.009641973038894996, 0.061483144790174506, 0.014995181906758057, 0.03519971381812807, 0.0264110152549561, 0.009145619884704151, 0.027014692539289117, 0.04159937868075025, 0.016399454588310856, 0.060540630647371856, 0.039360486722040566, 0.0428342626189753, 0.046847674680212816, 0.017628037453358694, 0.07435490046778033, 0.042679478384314046, 0.06585175351750466, 0.014391554418140122, 0.03447652298716768, 0.014377559906983329, 0.032694204109570676, 0.007033294269574747, 0.01874893708454986, 0.08055857322629421, 0.046286484632160396, 0.0391747372134799, 0.03312936120276009, 0.06517224118954713, 0.15501652784164877, 0.20905646195094432, 0.16394234082150846, 0.23416269540546403, 0.11237323945087772, 0.18202147957298065, 0.21187263180411633, 0.13422577491691037, 0.12227689471816826, 0.14649156270728958, 0.1934646115067505, 0.19423679749090828, 0.17368268912598012, 0.14145537730186217, 0.14271880950658553, 0.11582215196422993, 0.11955976471184723, 0.13670839008785066, 0.15124780426342643, 0.12536310290376987, 0.13637388545659282, 0.11285103316749297, 0.15128609333788196, 0.12798071808872685, 0.20117407604571313, 0.13257166851432095, 0.06821861280308616, 0.12828785039845014, 0.1492599286739865, 0.21541577313215504, 0.12376881264630826, 0.12764238301784764, 0.19152478495192146, 0.1770989203284825, 0.13693277724087238, 0.08605212078339632, 0.20483390788637823, 0.10351292698854402, 0.10853327735657654, 0.10663439820130026, 0.10233770980830155, 0.1667931531706164, 0.103780705361597, 0.1296061728029482, 0.12333121556308001, 0.17364561047044494, 0.12155756880078586, 0.07314575325337148, 0.14875135354457364, 0.17217341930635516, 0.10559430360914239, 0.17329509460156964, 0.15483142567738412, 0.09903507412321146, 0.11942645009126394, 0.15594582313731795, 0.20099196162435318, 0.24891963258626001, 0.21282414364958965, 0.11597887057089999, 0.31206082913183397, 0.10942020799003302, 0.18990889101499514, 0.12783677782863379, 0.1422234417329873, 0.08858545097492396, 0.25288832043447806, 0.15636245239405863, 0.10889425032561827, 0.13154268985794437, 0.09771132015533025, 0.11753298717761233, 0.10858707971149877, 0.1263957434604245, 0.12215503311205296, 0.17051799523253597, 0.20554761071839642, 0.11768132478239075, 0.1793511268953162, 0.15130654788546025, 0.13232978391310862, 0.09569575048742757, 0.1032832844723617, 0.20033732417129702, 0.2880169757671895, 0.40204931651392295, 0.16748270891126127, 0.1374393758634406, 0.13185068784702209, 0.08444597914574609, 0.11210182982106363, 0.15800445460744444, 0.14940643532862588, 0.15893425552114365, 0.12970164268007203, 0.17332901697485678, 0.082028902796728, 0.22266288828705588, 0.23588755768874, 0.13605718470869527, 0.12491661153974072, 0.16497170252184715, 0.15421958189577828, 0.18230873190106886, 0.13289702605576287, 0.13185361430289286, 0.1969650970591653, 0.14513952477324396, 0.05982190993944964, 0.12058801558469573, 0.10835746783883342, 0.4046416048321032, 0.1348919343323477, 0.15209410159337908, 0.20687386213291079, 0.1674426425128214, 0.23682030038006846, 0.07853289119779103, 0.12557051354838958, 0.10315054441772162, 0.11020026935805237, 0.10930007008174736, 0.2164744453564767, 0.11489477188837145, 0.1489882738960366, 0.08781568582860694, 0.13049397677663835, 0.10745814190276208, 0.14718505613986524, 0.1054404425104299, 0.18435844610775673, 0.11330522371516114, 0.09094348492761774, 0.12696975015945014, 0.13995713914834684, 0.10257849890378215, 0.09824370529742972, 0.25638100721182366, 0.18327794037759307, 0.12065802069921648, 0.12404213749593306, 0.24728985713614574, 0.12227786764983209, 0.12445814622145508, 0.08422624980730396, 0.15148406577927453, 0.13758963634890897, 0.17980834349028527, 0.14753437691157864, 0.16694345962136023, 0.1330758616208069, 0.14715137891471386, 0.11401570131701809, 0.12375400416673192, 0.17457053906494574, 0.1748105544116228, 0.09650598805878433, 0.2357027313161281, 0.2034816554477138, 0.1338036911141488, 0.15573969952041106, 0.16928379694300313, 0.07543270190757129, 0.17901778671770327, 0.19807828410017878, 0.12335478808851012, 0.07442769414234547, 0.12443998227677039, 0.066874320017955, 0.09982209923046251, 0.1444796472787857, 0.14531498955142114, 0.21869731075581045, 0.16582967503176582, 0.09483266817105394], [0.05496323476695726, 0.02258696480684223, 0.07051951191838711, 0.01766320088908317, 0.05460090582228957, 0.028551286799953352, 0.03539948273570307, 0.014610886348471528, 0.05377376452088357, 0.05991158819186592, 0.03714530901502698, 0.031868914825721614, 0.019422056408779278, 0.05379671651509501, 0.020723948142521327, 0.00759784457078504, 0.03777838875389388, 0.1332254326271434, 0.06975611296272086, 0.058540037998388854, 0.017532029399468053, 0.03515611958479689, 0.09051118917282551, 0.027504812610606034, 0.03352431400168327, 0.02142090237729492, 0.05218351537722254, 0.013568917713728885, 0.04493280343951718, 0.048774925901764826, 0.052597865522388494, 0.0009466874666207831, 0.08397669666596959, 0.08784598460601223, 0.051377701963628494, 0.05928503552211389, 0.05135475379985668, 0.014751148428918134, 0.06707515762818438, 0.03805282826144849, 0.027395583794362126, 0.03419711539942411, 0.014258454302175632, 0.026063123237221472, 0.07977025343045112, 0.020368242027959036, 0.03613526422169901, 0.05619019735604525, 0.008252092276609713, 0.055333017747128205, 0.08517630608572115, 0.024687210173015634, 0.017891219298866008, 0.047112947945753415, 0.042323703321838574, 0.0036584473761444494, 0.02475521005239458, 0.023585661922791795, 0.0424074673754794, 0.07201502279889199, 0.0324721037290029, 0.054824898440030315, 0.06069221646494924, 0.04947332229705588, 0.05512965204674871, 0.03754641733042175, 0.03723290733872883, 0.04890516850977175, 0.050193751381049236, 0.08889748624736264, 0.08697058359581618, 0.039479226519864415, 0.02845465246918461, 0.017752026868683678, 0.020968355088224335, 0.044641701519609465, 0.0541511892280992, 0.07156084757298231, 0.043007402320302306, 0.08258931143509765, 0.030650702875948725, 0.042147112394412684, 0.08813555818051101, 0.001659158991852535, 0.04529657645992214, 0.04401750073978498, 0.039854954342327775, 0.05795324146146736, 0.03572477899011105, 0.019209066728851008, 0.015976344227730747, 0.06550385766933042, 0.036070005021869175, 0.07525360587263301, 0.032849356066435575, 0.047430686742788365, 0.08408765684092238, 0.061549415226064386, 0.08430787647563605, 0.049149991058173685, 0.03389487839153698, 0.06406322932772099, 0.023265540592312332, 0.027007204029829274, 0.016668772798091654, 0.04237427661615995, 0.02261660474863264, 0.1140693964196309, 0.04092755787555249, 0.04142736895911155, 0.07250049271650853, 0.045683883701361, 0.06150806563035135, 0.02831867377784464, 0.05781859767833545, 0.008631798968229805, 0.018566845645827633, 0.061567931571194244, 0.01754428489103673, 0.045871893169298295, 0.07396307713802784, 0.021353806481666623, 0.04848545957957545, 0.010401868099917569, 0.02547411462141862, 0.017497938486837575, 0.033462900563233325, 0.024172234378995437, 0.02802259611686872, 0.02335436082625341, 0.042647950035790284, 0.037410923189693884, 0.04214142036113528, 0.011388499331059716, 0.0217808487885181, 0.0641137375045688, 0.016203973847892017, 0.09084258348711076, 0.029364021817943262, 0.03558456191732999, 0.03378653823728523, 0.05896378804238574, 0.01457627545366244, 0.09612370252368913, 0.025606084757694797, 0.0576303277405039, 0.08145924747711228, 0.02156107540002033, 0.015142852057432456, 0.10179572558451085, 0.01503386168605498, 0.05984752025875834, 0.03848210562981906, 0.04047216073940358, 0.028707237403479316, 0.05028326875500141, 0.03819642761241525, 0.029964542820028243, 0.01502856610327839, 0.03318424757209516, 0.028287143514101065, 0.042316444638756015, 0.05250568599289945, 0.055932860761400194, 0.02876001894624243, 0.07598607785879605, 0.0472077474959435, 0.006885162550925969, 0.0451387508562015, 0.043580796148988514, 0.033995795153802445, 0.020130051885761564, 0.038768400348001913, 0.06301697921909152, 0.019540374858244773, 0.030938713631081968, 0.01663645346378607, 0.036984365433454514, 0.05980452740444772, 0.017965181257515665, 0.04023042169489688, 0.03199631141708984, 0.028083975081362074, 0.012703754511030932, 0.006813735864500726, 0.02858016065381948, 0.018353932574691794, 0.027726581658146558, 0.01712572700794666, 0.05530790155453067, 0.06938808432389652, 0.013593150032383781, 0.04448015655901644, 0.14823631263307988, 0.019940581105108705, 0.06127990166386289, 0.01911090213745352, 0.023640259093935453, 0.06003410097271685, 0.05674227478823835, 0.038586209317849535, 0.031164156070219416, 0.027300516113398537, 0.02352700640086926, 0.075146866842143, 0.013558004791247509, 0.05084609823121179, 0.06250393013620088, 0.14885079175714525, 0.055141874979580605, 0.056053894992557265, 0.03579993604592258, 0.07838665267392513, 0.04560591510286735, 0.038976753280768474, 0.04622975965180705, 0.03133131070963798, 0.06930366909552006, 0.02421903469028973, 0.0354052513777729, 0.06538393426566355, 0.006427309145369838, 0.024845685036252105, 0.032792619594763366, 0.019498603914173383, 0.039130671836075284, 0.05970505854835915, 0.033316252182327935, 0.05418708427779136, 0.060343604324565786, 0.021186946786098906, 0.019874858422084682, 0.028535472829976392, 0.058874308972829775, 0.022642954342788266, 0.017015829779988816, 0.02281739256314693, 0.005283718468666438, 0.01702539630294327, 0.00872689537749055, 0.04158727832198624, 0.06456903887972718, 0.09766678746429183, 0.06313699838374892, 0.03272085630845639, 0.10027315647852036, 0.0987627758314052, 0.058229220805749785, 0.012584747540043488, 0.028440788192974947, 0.04708299007747443, 0.02523793354480257, 0.05564309949535997, 0.029598435146674037, 0.025552111948209427, 0.0330885746816714, 0.04487829628370462, 0.008251123175385499, 0.06204685526749781, 0.14035320660519984, 0.0493407967470346, 0.033708627095385905, 0.03347094831687789, 0.09269538245374158, 0.02615310600958765, 0.07596671881694948, 0.04200373903938359, 0.041522754566563715, 0.03850594628602266, 0.01718095045596842, 0.04558138496753189, 0.03792575342700847, 0.026704892328369523, 0.031715241418550574, 0.05302247358486057, 0.006860103336117801, 0.005988782701728445, 0.06095925173271568, 0.027439997741772283, 0.03490891833339007, 0.05874816110477813, 0.04889669557732921, 0.0511487067917422, 0.05217223090209788, 0.09934488007979048, 0.05892811898863124, 0.06393747216451072, 0.06623609982911619, 0.010317572572779272, 0.04302096207656207, 0.030405866921008117, 0.01945768524291775, 0.038792053312664075, 0.035699049927174084, 0.04951803884919613, 0.025737405634455146, 0.050116579513996846, 0.047336860124262116, 0.06397629367007364, 0.024200483871203278, 0.05155807353496071, 0.05937021683841463, 0.05122880511466534, 0.02828980375441813, 0.04193208683582564, 0.06095614524618272, 0.05324907856242311, 0.022791801396036343, 0.04052757187896679, 0.026767441492167213, 0.02042601271832903, 0.017517450746269, 0.021733230678364638, 0.06004873708251023, 0.08311051935438188, 0.06339631148523862, 0.024818831739286264, 0.03680842951120388, 0.029347899497576782, 0.030556194439169862, 0.03554413545756571, 0.01810708563894995, 0.03099624491897562, 0.052626639784824465, 0.04832777953256042, 0.06936126358566747, 0.034292485685117786, 0.024766852673623833, 0.044665247231962225, 0.031548071457373525, 0.052164635140328645, 0.05584724660542223, 0.12507153750066796, 0.028675714800614985, 0.05228830854438486, 0.03194541253540064, 0.07010973148768948, 0.04965247578858849, 0.011322904010153106, 0.03591616307535479, 0.016225843742910414, 0.07648383582671804, 0.05109771214906247, 0.015719827347164674, 0.02896582846710038, 0.05030208770486136, 0.03954228704735156, 0.029587721407052972, 0.012801145353624898, 0.031291190685043414, 0.021204346558079127, 0.02408124037056921, 0.0876109335090845, 0.10764597134003717, 0.1526924469057591, 0.13832544847842188, 0.13331641322903096, 0.08661596149566674, 0.13559033072763874, 0.11036502422704814, 0.1459942031050882, 0.1485571042904931, 0.15836758028355338, 0.0877644039029556, 0.12171229557885278, 0.15157046517537487, 0.1203990140328965, 0.15968018001125706, 0.08917052764445545, 0.3061743320957307, 0.09395159044933897, 0.16099684000495942, 0.14348806903487252, 0.15108170107968394, 0.18444820096896541, 0.14424569934846895, 0.08800292537818033, 0.0641795636094626, 0.12934167328621113, 0.1263118261891988, 0.18860320140036846, 0.13784042289180143, 0.1082238238004427, 0.16311507311559495, 0.26447601315955965, 0.14439387607478327, 0.1931668484523412, 0.17985843031877474, 0.11836901126850037, 0.11362373243055998, 0.16411138578288018, 0.15248227834461198, 0.1343712090484558, 0.1202245145255039, 0.12620744670951559, 0.12564465553770143, 0.14015022394878252, 0.13166316484491672, 0.09185841607470667, 0.1195193995391169, 0.11760730536714678, 0.19015324241932363, 0.14294983098103156, 0.15844912268221378, 0.11161253712470494, 0.17916328213628263, 0.06400511389778507, 0.1380836251642435, 0.09412710119279162, 0.21285904661541988, 0.1617514519321342, 0.11474179945165112, 0.0975606153388658, 0.09695323018897926, 0.22200078913761725, 0.10595519996939168, 0.12004169530325359, 0.17072627921738934, 0.18833093375207918, 0.1840944215655327, 0.1407114293185934, 0.2735656157376305, 0.24602625639207903, 0.21013895950971112, 0.1427983753984013, 0.1322855959616361, 0.10135136394491119, 0.08322501885554484, 0.12970214829810206, 0.1847768986537572, 0.16167049176029621, 0.16884951702048703, 0.11888392960592625, 0.06989724934101105, 0.23775437606438515, 0.19865442818451315, 0.14980507684090447, 0.153606588982286, 0.12950360895164553, 0.2586550319627408, 0.11993618201344244, 0.17263530903766233, 0.14170760409005229, 0.1273154856396779, 0.0924221495346677, 0.1477055209538629, 0.21103753467961667, 0.11743629922068889, 0.14245147546452863, 0.14426465236371563, 0.17760751077965384, 0.13096254679464525, 0.09818434880505647, 0.2131615900584767, 0.07443660374490485, 0.125968772016706, 0.14656378947679075, 0.0890604867750118, 0.21556345956219783, 0.19413109267911605, 0.1819798043898998, 0.21803173356719557, 0.2632591897441495, 0.1949538404662763, 0.10493914521629773, 0.11109627813341157, 0.13457180151054937, 0.0994053780431709, 0.16587916431167435, 0.11837692495675818, 0.19482362084090712, 0.07367230080548795, 0.21591665673880808, 0.11617727202153015, 0.13263756739756755, 0.06595499918705995, 0.13152670926384388, 0.16413850529539972, 0.11875151130821436, 0.12329088869474589, 0.126944063231349, 0.08304557042016138, 0.1846562704492, 0.2102013803537815, 0.10919412778269862, 0.12317437438234208, 0.09577339349855339, 0.1410454283318212, 0.05667676660983313, 0.2371734362696448, 0.16584464438980626, 0.12334312823030258, 0.073376253788029, 0.16403923562217146, 0.13097083586598599, 0.1242040808222467, 0.15171099634420487, 0.15031593491233167, 0.15124469394645385, 0.13851683256366562, 0.10399084327922714, 0.22970080015159425, 0.11969711661579148, 0.16248836722825805, 0.16295218750113444, 0.12496628468075108, 0.08667012391191337, 0.22023668783085965, 0.17891497771826484, 0.09614586544733855, 0.09881121557085745, 0.3047243421596866, 0.1811768982799784, 0.11079083887800095, 0.2559881726460111, 0.14590892219735732, 0.12010948642367318, 0.2299690534991603, 0.1759438589215279, 0.10050997723855319, 0.10901375238092677, 0.11812521910835659, 0.15174029154642937, 0.1611738216372267, 0.11947804611296424, 0.15939179387304092, 0.1958035851918882, 0.08271028437922079], [0.019496156263255307, 0.01690406521271554, 0.06558168454155808, 0.03704129725754742, 0.09490838830148983, 0.021614238071525772, 0.05684358991622444, 0.06963610528938233, 0.04723504703912524, 0.02354167506939942, 0.045360832084571166, 0.05052727925020361, 0.046095759382531534, 0.015431943954148842, 0.02801437216300157, 0.0719828624278307, 0.017222313458220135, 0.046891724735858946, 0.020227216732417865, 0.0284055577245571, 0.02971578449491532, 0.023443269160305782, 0.01284691431905113, 0.06073928873745665, 0.06421722832225985, 0.07016709615145961, 0.008195542538869045, 0.08552177343517543, 0.0300208579433421, 0.027412357289464246, 0.01973693961307647, 0.09579204773950963, 0.08643097424459073, 0.02662422901560222, 0.07064073001064601, 0.02263009747219903, 0.13763391623093238, 0.09087760136612962, 0.015464197213370955, 0.01201613026956517, 0.025450369726205548, 0.030337039666670947, 0.02726578360213147, 0.04927222421693225, 0.012014318471624246, 0.0484175841894842, 0.07824373131077136, 0.027305279265067754, 0.017993585882528175, 0.04274558411130021, 0.01747493478169124, 0.037044863396834944, 0.03430164809669218, 0.03347340362867521, 0.033087391075828386, 0.011170392183797255, 0.03425534957298829, 0.07392353167937649, 0.029262463457041213, 0.025150584199676113, 0.008861046949131115, 0.07107847265057987, 0.07711709942668676, 0.02965987731342114, 0.02096740705441804, 0.06383108936490552, 0.015660220918606128, 0.06749077564886502, 0.018903200379422596, 0.02615748420207491, 0.03281511193622024, 0.02836205350655702, 0.019680904111854976, 0.04091487528996603, 0.08503818809385262, 0.015684572938499192, 0.01204984005345332, 0.019292394112374996, 0.01776137122614009, 0.05914329393436352, 0.039588907327983654, 0.06649005031513591, 0.030333059839904312, 0.010497948932161015, 0.04975711956860558, 0.031149196288278027, 0.05049789977830745, 0.002323976795812468, 0.06261224347737528, 0.01263666436106207, 0.07048200425361434, 0.048669833960312034, 0.031486686747220737, 0.048492224135946844, 0.04259798578136871, 0.06505610992110546, 0.04447403934694106, 0.004401132511350537, 0.03502822503627789, 0.05950136343017221, 0.05672853500131638, 0.013329628235360068, 0.028696355124514912, 0.03881902343803837, 0.07256651417382302, 0.033941272676231406, 0.0574714717485251, 0.02328615027269529, 0.015476715090053697, 0.015421455252855537, 0.012979450402781369, 0.06104916747238848, 0.014190636368678703, 0.07854701785911476, 0.042164004633143064, 0.033966208838166735, 0.029070916578113556, 0.040014875196521325, 0.041311555617158456, 0.02910282988581927, 0.13635533080706674, 0.026288531202402328, 0.034675721169239095, 0.0951787407299684, 0.00669990812668637, 0.042474936738970785, 0.025058917949096333, 0.018445282814002806, 0.029045158786879435, 0.10712947486148727, 0.03408334368178922, 0.009180447199351845, 0.07533294193807148, 0.06475009609975162, 0.011437055898920424, 0.02493367789523496, 0.06482776209351516, 0.034919183911575426, 0.028510184267595894, 0.10938787907962838, 0.05980861831396338, 0.08018472998012459, 0.017758398804993882, 0.03713697397841081, 0.015277036187809803, 0.012055223736341202, 0.013215858432944986, 0.010828055261123565, 0.05032415103708064, 0.010258993659649166, 0.04889364654739057, 0.05169484321208251, 0.040679755245125106, 0.007139255242016648, 0.044283601380283796, 0.016459429696682962, 0.009004921134140705, 0.02200375739184599, 0.06816615876291068, 0.011329515348939646, 0.05883168001028319, 0.05681527913698266, 0.03643401935997029, 0.06414833020478969, 0.02433864016746802, 0.023125099438813426, 0.06519035916895637, 0.046958945120774934, 0.046923302880097786, 0.026840673752068996, 0.05517542963066409, 0.010578004162638419, 0.06173808352961656, 0.02473233849741519, 0.040075193129239545, 0.058389007594556584, 0.038295482781024716, 0.043647507085434856, 0.061110194036436666, 0.07746899425382577, 0.08921688362475365, 0.032654620346523104, 0.058589925644018, 0.07694345793776936, 0.05950024494180276, 0.04438218157438021, 0.014586036371427679, 0.09474287500544902, 0.020536903945368626, 0.028593155420235092, 0.03507514026076083, 0.008445725787521131, 0.013822457385099223, 0.049993208714670716, 0.08688113516977719, 0.05223185169480501, 0.05353165392373359, 0.06805887580999444, 0.059219715035250114, 0.033438665371748715, 0.021854527294635776, 0.06133383042329262, 0.05339329844460853, 0.0572453762194322, 0.056840682612551804, 0.07899761545441805, 0.05291742377824361, 0.0928406403850644, 0.0435080599310177, 0.03665711948527925, 0.04123055331048466, 0.005932973675249566, 0.06397881409934451, 0.054491964289017265, 0.016320938236951348, 0.1162106964376665, 0.09520276524727384, 0.010686919840443279, 0.02608015528699804, 0.05381114961158845, 0.027341934657024763, 0.03572472919439597, 0.10189326389903024, 0.013939739700647132, 0.04016900825644693, 0.06576418200688017, 0.06808686866274766, 0.07219700698530482, 0.010822710840241804, 0.05633124563422415, 0.012501430690228459, 0.008633593529192431, 0.05823818403446387, 0.02920208615250886, 0.05367868534860112, 0.0316251150046986, 0.046647331196694605, 0.06584253747977557, 0.03455122422066427, 0.013272005974525406, 0.020366137201387077, 0.03001525784061561, 0.06053853539689895, 0.05779501366158647, 0.002247643555634685, 0.029855823452253977, 0.04165677398803734, 0.026712262094201102, 0.06968482082048733, 0.02716489939860279, 0.03945298800845781, 0.02940423951874818, 0.014762931818803473, 0.019741024776932695, 0.019377698002743627, 0.023804412583910653, 0.062019436980687806, 0.13372743472216592, 0.03155627434382276, 0.06720029042973634, 0.06668050743399129, 0.03767025544338169, 0.01870893197314393, 0.03138195486709235, 0.04639000992380804, 0.011243864803785279, 0.07883387182148234, 0.06375672521009561, 0.013503672878047632, 0.030939744019340125, 0.025666109661781983, 0.09706486452130542, 0.01283596309217354, 0.013545817289982113, 0.05078430174879971, 0.11844279319648782, 0.047935373975985476, 0.06110458627283093, 0.05106907195201324, 0.014602037075336182, 0.01638190734440521, 0.036873734676309174, 0.03711938843010895, 0.05831165186640236, 0.02667374510858809, 0.054643358584613576, 0.02101553269782134, 0.0269627881671993, 0.05912010062245592, 0.06521085202093087, 0.032917361691473954, 0.03888958396630422, 0.019704723700640664, 0.02280854233240168, 0.056600471913454034, 0.01701690613352243, 0.030852969240156874, 0.02454073990755264, 0.040062816978822795, 0.03649132656714609, 0.010905687738540433, 0.06923056898578521, 0.03965467597628313, 0.052856780258157564, 0.07235796205819615, 0.0689974560913059, 0.018068869342847217, 0.020382112049828136, 0.08146986545574281, 0.009718639287917365, 0.01638866040945774, 0.054764863959844076, 0.002886501273267993, 0.032168300071310614, 0.055768665136589166, 0.10810599947768836, 0.027616061983750235, 0.012975159352795492, 0.05084795982486779, 0.04929797626250694, 0.039161744362284104, 0.018751783101188562, 0.02769208854935583, 0.045873383210311015, 0.039551177497712836, 0.05144995554620701, 0.020220553682696436, 0.024897710067189993, 0.049851394348567536, 0.04325351189641703, 0.03234481055950446, 0.06786357701545762, 0.04068255912692797, 0.05608241261553861, 0.06617245324436696, 0.04148331636022176, 0.016875829127046372, 0.06265088878271562, 0.07952667577492614, 0.06085982884190256, 0.026473179459571842, 0.06896332687427921, 0.050636343357543794, 0.022687963923559557, 0.07455162418585631, 0.029526463101407694, 0.031601061759096, 0.03315076569936449, 0.03088649324772339, 0.01908402394263014, 0.06499565792300048, 0.01891320931815332, 0.10895241938170888, 0.13905536173091781, 0.09036511918830295, 0.11721575016816778, 0.19464628680819468, 0.18135381862521174, 0.14380970338900245, 0.21276461861787305, 0.14951710439016744, 0.10655448756991856, 0.08639804012472592, 0.15775417368258202, 0.12721405559850316, 0.17182884827977227, 0.09965218858973635, 0.15254192595039645, 0.08767483290284873, 0.1765228375311821, 0.13421947767417278, 0.11091113000387147, 0.14700243610047525, 0.114895514993658, 0.10570532507112912, 0.1294903249870385, 0.1533114459485777, 0.14256289529223598, 0.16709060978985604, 0.29130462677248065, 0.10628641808345433, 0.14054007077169034, 0.23548641872982826, 0.1877142176512749, 0.18178523337889105, 0.12334147348038613, 0.11222031297943286, 0.20188499031768692, 0.25794621677167956, 0.17055539564499933, 0.09558240011815103, 0.20966033841813767, 0.14344715993971596, 0.20410555745324782, 0.0892812503321517, 0.21114069607950028, 0.08020408136109192, 0.12268892744736326, 0.16188053774737543, 0.11586309936378272, 0.19421125611951276, 0.09566474690913193, 0.13542868617561557, 0.11210071133269418, 0.1394989419608347, 0.1361558415115841, 0.16251488919219664, 0.09158195792547158, 0.12735946674741086, 0.16504806616613943, 0.19114744068393785, 0.15475703853993647, 0.13139714847408956, 0.1494745558668529, 0.14227777268857728, 0.12606362136261118, 0.08560477140089197, 0.12068445073260416, 0.15930426066681264, 0.21307454714851998, 0.09165616120181738, 0.08498849197020454, 0.16981783683501905, 0.17633914496869812, 0.13925699607258843, 0.18832426878713793, 0.18075715870626513, 0.11093502428622977, 0.11882821969207256, 0.12616634609237795, 0.13724607655838614, 0.37024140718483156, 0.15381245212929864, 0.17826375701735098, 0.16597693245257103, 0.17837399706965495, 0.19205776764260185, 0.08769440644931409, 0.16193702907091187, 0.10640759021043779, 0.20778296335089594, 0.09374051790444121, 0.23403664329840293, 0.15497473008450002, 0.06967721356739921, 0.09931520183360386, 0.12652826901044578, 0.1752428425055358, 0.09431503022149687, 0.15310826410930004, 0.19048656727517807, 0.22078329156483376, 0.21719049241754318, 0.16610221847170786, 0.19542441763464483, 0.10529994198511686, 0.13903974885902098, 0.0995548188145603, 0.14213911077428248, 0.15137393297927995, 0.1073073604775052, 0.14072151103567693, 0.12558395073058146, 0.14860279377429716, 0.13051760292822315, 0.1652411356448166, 0.10477159412637835, 0.08875257305560574, 0.13742665880389754, 0.15627053716490347, 0.11086075206197078, 0.14955283473095587, 0.2180074179364789, 0.11003377546946849, 0.10141077406343915, 0.1507587184108073, 0.07224844978942026, 0.1885082831065501, 0.10043140726103898, 0.1640284031389221, 0.27567548316813284, 0.21606820425198925, 0.16237241216003895, 0.05063694856700398, 0.19225843671348788, 0.12102079397488026, 0.12651201262469255, 0.11877934328250347, 0.19952461213594486, 0.14356101592702253, 0.12820677531342353, 0.27317181590103334, 0.17588226545241573, 0.1961797343627099, 0.21237982797526547, 0.12460289853474787, 0.10019054921764521, 0.1396459695552626, 0.11427169725779565, 0.245184616876706, 0.26687769880217893, 0.14062245586706748, 0.11755004795568606, 0.10653486805817775, 0.21356147263319264, 0.11063970505229889, 0.1776657947489331, 0.15687304999559157, 0.16995565605259713, 0.15437739600818004, 0.3054463034195285, 0.11628237162386218, 0.11887639130075132, 0.16026527200254703, 0.15489887205823777, 0.16954526275156007, 0.1935558832220493, 0.09381102863699199, 0.16192740700658292, 0.10010243378459446, 0.15249841215629734, 0.09462350318508764, 0.1559302409089381, 0.09132721836888984, 0.15509926533747107, 0.12867416555602706, 0.16737144230113876, 0.09699803101079119], [0.09167684557577295, 0.02906131749642232, 0.015646100002941827, 0.018429817414031397, 0.024815309650054383, 0.030001418462263483, 0.03274463950806568, 0.05882222648529757, 0.05262851670023896, 0.024769761892516288, 0.02254768556374456, 0.06565185819542216, 0.04107627086341381, 0.012145849064953867, 0.0726768461566779, 0.009952551786667638, 0.03243064688098046, 0.06294376036572842, 0.04219772782356989, 0.017095035610480175, 0.0013591271201749485, 0.03784896843435784, 0.009403402725565098, 0.06343081225490858, 0.03611575196226759, 0.030404005327352115, 0.014581487724377264, 0.04547103766291853, 0.04264003634753247, 0.020446323624421513, 0.06668257587138685, 0.0438379067476959, 0.04308807520916866, 0.05757496639665577, 0.08391680391204935, 0.07702083281812168, 0.0074868389093617526, 0.07701023016124964, 0.029103942628529285, 0.015576661793485045, 0.06899776252647562, 0.07119898594194843, 0.06290219626539657, 0.07166229293591554, 0.0533625093709317, 0.021512993806672674, 0.0362696705175744, 0.039486630759652586, 0.04236151359134144, 0.052957072658764745, 0.08061506454983065, 0.011968245943858018, 0.008121117097025198, 0.02717807036524098, 0.0588771051937534, 0.03267848781580406, 0.03823411913828985, 0.05575125195807027, 0.03181104454392147, 0.0495353217927679, 0.04488921686706524, 0.04827355199884023, 0.043534578064516674, 0.02897639665001583, 0.0325435146148647, 0.03967788844038883, 0.01882066398168043, 0.05751785454190066, 0.022130732634855856, 0.04307297178574147, 0.06544299964462558, 0.014345634150348846, 0.05226384735696259, 0.015159996147567948, 0.04760408691400963, 0.04876368739191563, 0.08575236590038385, 0.07907952557528213, 0.03615959517417416, 0.019738529245519353, 0.07775582523355562, 0.035557063191287944, 0.11273797391162765, 0.03992955981483383, 0.06435762925614273, 0.06841583447831293, 0.0254430057060334, 0.04348520369779679, 0.048145550198011824, 0.04400397928792142, 0.014055765631999222, 0.03997353709212715, 0.02868487912740919, 0.014436093812447884, 0.02365652122534812, 0.006019352003932, 0.06220126028863653, 0.03524389793916095, 0.04404917081457473, 0.03903483806718742, 0.05005642245974272, 0.03415704517054462, 0.005035763578264104, 0.06077900656589097, 0.03431765550387002, 0.04647507632692014, 0.0258594568473317, 0.013347254960887856, 0.022675208559620286, 0.03329974298755969, 0.01356101360157012, 0.11040358909315641, 0.01776887888779804, 0.05998227512463928, 0.0621941854666558, 0.036672537004755396, 0.04031371460446427, 0.03716174926188204, 0.10064533731389431, 0.06100214499559614, 0.05699712925800874, 0.05095664471868546, 0.010599170214376383, 0.030421353388397448, 0.034719269437294815, 0.0144377255797266, 0.023932387571661703, 0.027120374368443608, 0.058445717253151445, 0.027646929581439304, 0.020557486812674233, 0.04772283437271272, 0.01499171918934031, 0.12012644761031675, 0.059487029925108924, 0.03587628053801675, 0.07343962458112548, 0.023464376797839522, 0.03322704890442472, 0.049924544254017454, 0.043625842118936206, 0.022072444835136977, 0.03088029176597634, 0.007741196379591261, 0.04627121649982949, 0.014860255628704064, 0.026839907664144715, 0.071793025840194, 0.031365813394527764, 0.09217142427880919, 0.036291887067378535, 0.06080598052170488, 0.04319721592530128, 0.07586763300482305, 0.04290188136961191, 0.10609257485597365, 0.06761776238319374, 0.06009294035574121, 0.06292937706495005, 0.04369049610930585, 0.02299143241778497, 0.021302124275074854, 0.004182899917190474, 0.03445747421093045, 0.03013079922135559, 0.03346306527213704, 0.02896404731267643, 0.017593224502859578, 0.019928522881180532, 0.04781256242084408, 0.012058980439999893, 0.033124324174657944, 0.07060427954720874, 0.04086406450838812, 0.03741135985981073, 0.029564721532346263, 0.015334671855183139, 0.04381063401759152, 0.06155906793391032, 0.08465728151702112, 0.01189950104397271, 0.05953381491464473, 0.010981622373595113, 0.06802882984160416, 0.07191217549505734, 0.04379127114530533, 0.06484792552768223, 0.07847671397030354, 0.07687888438663176, 0.03784269034381836, 0.041230403923339425, 0.0214457580999982, 0.03801042146439995, 0.022727210607920444, 0.008643429140530286, 0.006659136927356163, 0.049661312612795064, 0.05062602798364336, 0.05960559352271019, 0.12147770413467962, 0.07858517669862317, 0.018830266893811284, 0.014978178585278652, 0.024122128398307872, 0.04839356733305801, 0.0022030179764354423, 0.042310158887337294, 0.0350071614487998, 0.05537142556521201, 0.03343566996796477, 0.026335689659801223, 0.023534529384285695, 0.03597320598219672, 0.051580937429060864, 0.052961711321146264, 0.06610438633229464, 0.08785508573055269, 0.038636020354686246, 0.04441851329418921, 0.04004053148110548, 0.02265596060052274, 0.043552454726229754, 0.021970072505815376, 0.02285193738287255, 0.053196858179064534, 0.026529134521561287, 0.13111211780098178, 0.010105567315833704, 0.02096478128805757, 0.012519140727818014, 0.08378588714666906, 0.012194126010722211, 0.06735808155950039, 0.07096532146416365, 0.052635606843978174, 0.008680608345105523, 0.040129723267689835, 0.0031511760326177487, 0.03606500629816325, 0.08059658650909701, 0.08399178859807792, 0.06648320914997209, 0.013397420313389552, 0.03529754324605869, 0.047134769960276546, 0.058763567132935415, 0.017601818094150196, 0.0728581102204419, 0.00874670928404216, 0.04205399057677677, 0.06440210832102645, 0.05230229730988222, 0.027613723500361367, 0.04381520756249947, 0.02066943907148896, 0.020587061636991078, 0.06212823678769412, 0.03075440245259914, 0.04433594050727064, 0.08387009553130596, 0.021679006975084063, 0.09249115107400764, 0.01932772991788243, 0.02197669150548116, 0.04146111513217611, 0.0791527559199641, 0.00865576985938054, 0.023843044482712305, 0.030341737700866598, 0.01995485140791824, 0.03294684458523989, 0.03377658675514883, 0.05261691429862573, 0.017460856000862775, 0.045302980954969124, 0.08811492743271013, 0.010457148046923742, 0.0537250719724163, 0.009027729486866344, 0.0787194642508703, 0.01085534044015672, 0.030204617538519447, 0.036899777835295085, 0.05841672082521743, 0.01450060894938126, 0.04061985483032562, 0.07545800579171028, 0.028462631274915995, 0.0493327068585542, 0.035940371453762054, 0.09046847977104688, 0.08585706713699526, 0.026745596495006355, 0.048389736893436605, 0.01736775716586459, 0.04766700954567041, 0.01613078372282607, 0.018355213856745153, 0.037108831738512364, 0.007396312693374292, 0.03809616585532504, 0.015236842427252522, 0.08194624190969814, 0.04932732892132575, 0.07354815625735829, 0.03953494792503696, 0.038067586945309755, 0.041778735185582797, 0.12585968109628848, 0.0793867651373148, 0.10900345615922444, 0.02448890448337601, 0.014599508027576152, 0.06777152389047608, 0.030894535255708525, 0.05088932857277894, 0.04059701774930281, 0.02720041523477243, 0.017521974495461872, 0.020281291048553203, 0.0622324668802321, 0.03335379049061768, 0.07719933896535829, 0.05953914688659772, 0.04276677793372543, 0.013361839359746346, 0.03544154479318569, 0.05566137452279368, 0.08885145968487186, 0.023601782327938466, 0.0072131358038243516, 0.08008647154295638, 0.04390097493606229, 0.019183374055090453, 0.029679613653570417, 0.03309076186269522, 0.01266647379980573, 0.010846196223170528, 0.054041466285144134, 0.02468471081116267, 0.0413622131811515, 0.05965405241436055, 0.09106473366339361, 0.02547132989181386, 0.024056907502874255, 0.05660842007566845, 0.05188152351747117, 0.02130898076199716, 0.048190829824776425, 0.029355669544348796, 0.0187483357055293, 0.023683700109681776, 0.18428769022707017, 0.09270551013610057, 0.1414224355211181, 0.22294559005287387, 0.12597192829895404, 0.1131254228793325, 0.13089304729815454, 0.17061220872546398, 0.13760708783182407, 0.17077037523831093, 0.1659431020098348, 0.2376024914725173, 0.14091635783833845, 0.1512517725988742, 0.11197927873581649, 0.17382277596381404, 0.08999299197908371, 0.24577759957361608, 0.08634212336713269, 0.09597114377444792, 0.28781889607348754, 0.12011983627153021, 0.1462821295905498, 0.180640161758469, 0.11700132215816168, 0.09327596218715753, 0.1823940740958337, 0.12244331965883895, 0.23303150529822997, 0.08340176300055559, 0.15814624216047027, 0.16288495562489957, 0.20873216161083794, 0.20265432645476636, 0.26617822988379386, 0.1840361835615289, 0.11334916651849786, 0.15456076681373582, 0.19269043369398964, 0.18159050915029742, 0.18642786409585707, 0.14065518314319272, 0.17661199484380985, 0.11156302486215869, 0.11250515213055957, 0.16000972039276556, 0.1503029114176189, 0.12617120308981788, 0.10764564192222972, 0.09222806115905124, 0.17312347558477234, 0.08681634711402078, 0.21619523695159346, 0.1688079031244401, 0.17433646856056106, 0.11398654401061997, 0.12593664228916168, 0.1868707854901591, 0.11318295608244597, 0.2135915339233414, 0.16453847980066655, 0.11996092665339671, 0.14130700139268754, 0.21167066038375904, 0.14059251715098658, 0.12100755597554869, 0.10359836111385977, 0.17391282193843396, 0.1279426588406486, 0.12622178787545812, 0.08382278960198165, 0.17822554455168788, 0.18877667434994252, 0.11642025212847418, 0.129391836723493, 0.20143171141464866, 0.14599009687381406, 0.13977828826154434, 0.2237294052517222, 0.11182929404200086, 0.2443950560184256, 0.11550172036814114, 0.1337578790562768, 0.22277740310997735, 0.11116016220541731, 0.18950615859320089, 0.16877183570496498, 0.17196827628199132, 0.12340364151544149, 0.15336167067289352, 0.1240180746742314, 0.23917376844873353, 0.08892577021352707, 0.10939889542397954, 0.2803804581203769, 0.1425244530001956, 0.10726295036053467, 0.15719944941661051, 0.16049237110682074, 0.19281427946782884, 0.12356989791676884, 0.14667271185786496, 0.11906350061537758, 0.15093960709148838, 0.1759626893627067, 0.11052308348758567, 0.2030305522343805, 0.1307882005048375, 0.12464691794687703, 0.1611883006989956, 0.2719097932980907, 0.3408635287515579, 0.1342963469364951, 0.14726423898771887, 0.21266956242822835, 0.16457442464607377, 0.10944407162887436, 0.10120586852633184, 0.2071297814648959, 0.11240536917842205, 0.12340762517264775, 0.11260406174246343, 0.13257051938243453, 0.12842041425286763, 0.09333203982321486, 0.07009733618507463, 0.17239437438547614, 0.09487752261902056, 0.12926550882477916, 0.10213738547698145, 0.14247954492607426, 0.20767045567833609, 0.20821163550980631, 0.2075890971407775, 0.14912397871094366, 0.09449179734914534, 0.16161219246925848, 0.15043392777442932, 0.15143908109636078, 0.15614353510881626, 0.11013425556161713, 0.146397425823154, 0.08669199572215158, 0.10083702783430777, 0.09849813841884175, 0.11920252259099677, 0.21771002260427322, 0.21696918493797704, 0.10118076382505317, 0.2831969650522355, 0.13179939059961226, 0.11229179664364747, 0.16959602373742289, 0.11992937915267483, 0.09586746143477579, 0.20025147635850216, 0.16025267751707187, 0.09440669264163702, 0.259386278208225, 0.20556955147654782, 0.16191609954882055, 0.1321079095284785, 0.11346994027976068, 0.10725261583443611, 0.1144431783787666, 0.19078266025791246, 0.21097696776832306, 0.0642143018663891, 0.07243554378228803, 0.1043266579208355, 0.12210414955212225, 0.10361727582471025, 0.1279931133913417, 0.1729980823133261, 0.19319231321494426, 0.10421788875734615], [0.040984803795694344, 0.035038337396878394, 0.04698927071125758, 0.11410388569798201, 0.04074350908218373, 0.11742154436726725, 0.042763905104009375, 0.039506828667776245, 0.04107393046480514, 0.034329047231304075, 0.015599900113058188, 0.0207606150257972, 0.043726176654379216, 0.051585131760446296, 0.05168466956444806, 0.019913645453691002, 0.029674756656130476, 0.07124452220816767, 0.05010430678544987, 0.16061914333653066, 0.09541268866028517, 0.04070351929253629, 0.006499521550722421, 0.027882901899095987, 0.01635934605503515, 0.04345846339879979, 0.00026819191090556076, 0.02900253365477247, 0.043193404637877984, 0.027054705311574286, 0.031005405415330204, 0.05637249180806741, 0.03539210530899225, 0.0247580771364512, 0.051405832712208076, 0.03501408305319567, 0.09168194006046942, 0.02064276005952589, 0.045054239866834496, 0.030193394350428737, 0.043262356381502845, 0.014591511984866475, 0.039274451217704245, 0.02338859729558951, 0.07036169780598533, 0.005745518663447471, 0.0480693933974591, 0.03511342933521636, 0.043565459068744414, 0.026406623655930165, 0.038055517230062716, 0.031783884811785915, 0.07347157044756798, 0.014424773905756734, 0.03283539794445519, 0.054485406576385426, 0.022767470443561193, 0.02654747275124875, 0.028714549712716576, 0.07187269132343993, 0.05078812069710224, 0.04967908202219875, 0.01490864557244124, 0.03481864636283248, 0.05627033398336461, 0.03720483404674357, 0.03505188949225891, 0.054164002048632795, 0.04207693874054859, 0.05989107618769331, 0.049951801662363356, 0.025633589229396275, 0.06769755810138679, 0.017757113692500902, 0.039610361620303125, 0.017958970199669563, 0.034443343719167095, 0.027653069776152412, 0.1676487814514868, 0.07070994605460475, 0.057810821885904, 0.04777896563492475, 0.0315531333833332, 0.02390148741523585, 0.04177053421435337, 0.06648553039638266, 0.06074678873823536, 0.02508431950944566, 0.10739151523598742, 0.04865054003593903, 0.025601668260811318, 0.06733609483607354, 0.07311569962410197, 0.030029263843091267, 0.04262524318971461, 0.1000436825016814, 0.06646053294741339, 0.016095959281008092, 0.03434289427053544, 0.028073816755486113, 0.05412619177912993, 0.029628915869961345, 0.04204269077989363, 0.03779188339268008, 0.05064961966127158, 0.02941358196098478, 0.0524164597323585, 0.06789699377071473, 0.06808132218617587, 0.010980311405634689, 0.04007135885917852, 0.0072262464410385065, 0.009087285162099909, 0.0270480863119085, 0.05145775049083656, 0.04549074527477065, 0.024616078909246192, 0.021777192633899472, 0.00466938633772154, 0.03598726752604689, 0.023770907728542245, 0.04258964691431292, 0.05559991128862866, 0.023104928343767123, 0.022217643394645666, 0.055753151856122486, 0.07822867768305926, 0.023880877734852896, 0.02196666532977214, 0.017883125579945983, 0.03598042253044344, 0.04127311332511806, 0.044452531428466883, 0.051501245132737586, 0.0531534516372748, 0.03544525648917883, 0.03647138529847707, 0.05941461163362669, 0.04108788475634591, 0.016100578791191502, 0.0392883672048488, 0.04718819310167625, 0.06562237913209586, 0.02940312486081835, 0.07029096490793652, 0.013054864098047538, 0.030123389235907988, 0.14835881009217233, 0.09244010663561283, 0.01784170512109995, 0.02778116159231192, 0.016774554218676303, 0.03929048543795943, 0.06260108540675814, 0.022346911155768943, 0.05234847708995785, 0.005257803150602887, 0.01855269025620674, 0.027184231627372005, 0.02015643786909359, 0.005469034179939979, 0.04839655890640232, 0.06338356378217859, 0.07000226467367142, 0.013673477224074306, 0.018754820639808333, 0.032591031218368205, 0.0040435748580362535, 0.029011707557665727, 0.03187954429567101, 0.02156209429695962, 0.03157833959126184, 0.03151441146920045, 0.03756451615763288, 0.034907202296439684, 0.025192768831226616, 0.024805904005564032, 0.06300338498887516, 0.015456294058822097, 0.03504556543644398, 0.0183379692175696, 0.03675873338755581, 0.07330072517957419, 0.021500834076094533, 0.03988793059702843, 0.03271456289615843, 0.04543126237788989, 0.013185833531972623, 0.05111311434678013, 0.020219163233113867, 0.020043171769488725, 0.04339628770286518, 0.005888057461444048, 0.04989911779581059, 0.013892185750357328, 0.0923474636229296, 0.03849055941006349, 0.015043563232006086, 0.06228122071573331, 0.07133186389241489, 0.03797547253329427, 0.032506776868455836, 0.026181495312841672, 0.022287776828893734, 0.04188286568669062, 0.05202681975319021, 0.08389740656580656, 0.014976676095337158, 0.01961439044304913, 0.042538659932512435, 0.05007665867226259, 0.010727543567848063, 0.019887121574532603, 0.008257682803237151, 0.07409720381181087, 0.07068497924915246, 0.03233534937363959, 0.06861722367184778, 0.029295108378714615, 0.024766822030106862, 0.055483565515568184, 0.025761332475550236, 0.01854088101085396, 0.04488155598782244, 0.022036706833469293, 0.0946550123814133, 0.05488021381860299, 0.03757374368668084, 0.040249826702018904, 0.02480888408758948, 0.03423337434088031, 0.06887052298313187, 0.01950958003890851, 0.007882294932290191, 0.026644610784827705, 0.006589671904822031, 0.043203689368261446, 0.023606612512301055, 0.03139845257054173, 0.026404061091823444, 0.04738863234618499, 0.036293966996092955, 0.02197117184198672, 0.07217587061947392, 0.06468029782897042, 0.012008903187609488, 0.06298969116722865, 0.02948580873048594, 0.04442971733008181, 0.06191390836911817, 0.028478041133512894, 0.014699140634958544, 0.08175531747720896, 0.1023189253323982, 0.06369559139373802, 0.05863826962247972, 0.02296966785985616, 0.015058794017550687, 0.016944566366052436, 0.049360339649982994, 0.030337284814806718, 0.021387489452477426, 0.03846723203276915, 0.02890639345071489, 0.0241634760788011, 0.046645569194468765, 0.02909513453261987, 0.07034063038806762, 0.06501690154114077, 0.02273236446443104, 0.12762089425157155, 0.03963986749670679, 0.1007569793070997, 0.013565324761364008, 0.03490939713834274, 0.0685758319412989, 0.054075017105788, 0.049194290092395204, 0.016840468423681396, 0.06941348779946566, 0.054344775816125256, 0.056335823009571726, 0.02692741022685603, 0.07817603978178195, 0.050959360500377034, 0.03970975386759928, 0.019277947609342875, 0.02786988031960303, 0.09626431030131156, 0.038091845119432095, 0.07032792865028305, 0.02304753686691965, 0.03555505987136595, 0.06056865031320242, 0.021787689953681924, 0.02040938477993252, 0.04894367974972533, 0.017934696703788736, 0.0580672008706437, 0.047843972025739576, 0.06401257559416756, 0.07501538317169874, 0.03467890043412486, 0.03703511109755885, 0.12285971142832311, 0.038430620690867785, 0.021406733581135352, 0.05673647167221193, 0.022652584067996473, 0.057236884134791555, 0.029999072317995375, 0.06949800261927229, 0.03162633116927839, 0.08683190635976293, 0.04588459107664324, 0.014940186369893773, 0.06451327533971879, 0.0446508715920631, 0.05531326800044026, 0.020174032993494503, 0.03287135428118129, 0.01681805269101695, 0.033243795586449486, 0.06054037400791722, 0.019200865757621585, 0.037163622346856905, 0.0339414680286521, 0.01976655082656972, 0.023342042132430983, 0.03261476845270203, 0.06917967776497526, 0.03624685641918932, 0.023366030260560014, 0.04045918320996627, 0.10087229852234164, 0.037291643299883416, 0.07785027621374016, 0.07624086338065325, 0.015381716357003299, 0.019422198135045268, 0.04656054875663212, 0.035237524087630936, 0.03195742479405336, 0.03555933081154381, 0.03400324152842645, 0.023557266873878338, 0.041264640392675515, 0.03425282148283816, 0.08505855837175924, 0.05012386117971713, 0.02228911173710179, 0.0633741332398307, 0.1489336671487939, 0.2245858455857923, 0.23893528527790503, 0.1462652756562156, 0.22697499802997037, 0.2318719086507636, 0.11334347448522046, 0.14471249204249154, 0.14958012278281874, 0.10332841471198106, 0.17866423714064783, 0.09863120789128928, 0.14527912131480633, 0.11522484087054768, 0.15451144607317063, 0.15283242649128362, 0.09346468794730403, 0.24455025011012632, 0.11346658481465233, 0.40177953099050834, 0.16730724413308407, 0.1051035093804521, 0.23240196488557324, 0.1952864451994819, 0.18251589739755278, 0.16930520143960753, 0.10630279704327546, 0.08102891290740621, 0.11115722808866732, 0.10047747978880521, 0.16139604842230199, 0.13338793519764178, 0.2366535383607111, 0.1276874060051576, 0.2800369442951295, 0.08745058364565335, 0.15583441863136907, 0.11583003500897078, 0.1113825881733529, 0.13394094342666288, 0.08348387230427996, 0.1390311073872351, 0.13923438115706369, 0.15463751350199023, 0.09494077083804915, 0.08887483302744166, 0.2825359537476494, 0.21443251460309953, 0.16516069641276715, 0.15447387712136393, 0.16855797460002286, 0.16286888310024816, 0.17595610100655787, 0.14451560744595143, 0.08238298863533043, 0.17400751040587503, 0.09383623292970081, 0.08468770286849431, 0.10402046789925906, 0.16647069144152826, 0.1209289170501213, 0.10991223562028139, 0.12606867754291143, 0.1639872182521128, 0.13763236873332532, 0.1157529359202712, 0.13532166369259357, 0.1514187338010919, 0.20080644577260942, 0.13463290468338998, 0.19031661833005567, 0.1569032491815667, 0.16060877050603592, 0.10404377229391568, 0.08465430143499568, 0.10305190293659126, 0.1766259989310657, 0.15174709440719697, 0.3202081129195229, 0.2575004761738162, 0.17875313398338136, 0.1582859153108251, 0.13287290960790651, 0.15903838219181185, 0.1346749169451575, 0.17162295448924267, 0.10987838985578668, 0.1217730233686105, 0.20996709534477806, 0.1390052442589114, 0.07431479576494425, 0.22312764318719988, 0.12780984983809535, 0.11485004767535195, 0.2119802058704438, 0.15970497061648678, 0.2396193711507705, 0.1013979497515867, 0.1397982371910926, 0.12177874604540488, 0.1584402820275676, 0.10806674513244822, 0.15507614480391627, 0.14810765582707622, 0.11083312693142122, 0.15229576657856667, 0.16897555380578966, 0.13476867078533097, 0.19821886123428423, 0.09407718290364551, 0.18994961624904988, 0.13902980503776383, 0.18333076980085145, 0.09492976981545649, 0.1243307764431642, 0.17463931843878763, 0.16012558353043374, 0.11260812966934136, 0.1455475585234742, 0.1977684934653582, 0.09330231561175278, 0.10412511550971579, 0.07979538877524676, 0.12996468662975297, 0.08913459045992744, 0.20349256453975556, 0.11074783836281109, 0.1548959609241255, 0.19086614851990055, 0.07540412682799563, 0.10404424726842873, 0.17815658131674414, 0.0791405521393303, 0.14495287511137225, 0.15435528671068532, 0.13798006539863927, 0.15935410234716632, 0.18903299204764829, 0.19935386645938122, 0.10142500797707228, 0.15348858079842984, 0.18418282811199466, 0.13500985058565296, 0.1331199576417285, 0.11972455788523921, 0.10157300084228478, 0.1874235485710444, 0.21585291822350797, 0.13193098918324517, 0.11883313031566721, 0.1132738983799373, 0.20971787162125113, 0.1397131401444635, 0.20233676768839362, 0.12774688507159873, 0.11237513168805069, 0.07581659622730748, 0.1019591014952429, 0.18881327803096465, 0.11755285183748893, 0.11693503257007369, 0.12748693611713188, 0.22046726497430957, 0.1452630794336719, 0.17455262792927606, 0.08533752928938597, 0.13024869074504222, 0.21013405654699574, 0.08892508073439521, 0.10287313631946042, 0.15343981164117015, 0.07188739255070686, 0.2072005986326164, 0.1471904340770937, 0.13914447307827013, 0.12604525823506618], [0.024486700065373897, 0.0255186032624014, 0.03965854855074037, 0.03498488361196172, 0.07427091424864146, 0.017370361864807147, 0.026972442790265047, 0.023231512881935607, 0.002051732369563392, 0.023763582012766314, 0.018621180431857225, 0.029247944175656286, 0.022374212614170486, 0.01432711301716946, 0.060561234582095384, 0.015239979557302451, 0.007305944961826167, 0.0465259675477301, 0.05836138629444665, 0.029873903127267, 0.03599745266500019, 0.06618143179483953, 0.008543616502485689, 0.055224443936059554, 0.011261192755022598, 0.08648252430101556, 0.01445020515201313, 0.027668855017832214, 0.0442150901372154, 0.033589400831730135, 0.018415391978417194, 0.010792853521002878, 0.04958593339148549, 0.027466102187792142, 0.007051949468140881, 0.0140797441840292, 0.008040358980877266, 0.03396384545692033, 0.10646578224916613, 0.026518972365245707, 0.015397430735550102, 0.01441370010481126, 0.03286182031696362, 0.0888908749085761, 0.05418032355185959, 0.0082282506627962, 0.05495368548098111, 0.061078098782848936, 0.009740162528150026, 0.012533750024534041, 0.09681366429093385, 0.057234470957830075, 0.03822445876956467, 0.08490861964321907, 0.028825165148103432, 0.01804377230244779, 0.056669075087073355, 0.06609320910947938, 0.06233280141567511, 0.01661464868624124, 0.02363399440993465, 0.015490928893878817, 0.010894555523390732, 0.056674265332760355, 0.06096267997617684, 0.053763939443254666, 0.07569705586760275, 0.028626870949782675, 0.06373941162300688, 0.05212556848662996, 0.043159486095030467, 0.034056024986409375, 0.03454283172745378, 0.013746216314874831, 0.03084544051108101, 0.05843609135838286, 0.06280000013629757, 0.030399443273763024, 0.014619895542461066, 0.028663317582780318, 0.044323851639825496, 0.02005373229152493, 0.04701465503462861, 0.04432545276358724, 0.04337151624983357, 0.07368223696586586, 0.02308708615601063, 0.060597673554213784, 0.02778711218026377, 0.06116846651439706, 0.016969468054031173, 0.023156855698494662, 0.02631661407048664, 0.04967665352347878, 0.05070087860428518, 0.03130625580407439, 0.06139707864232122, 0.05065746823205583, 0.016011346784991123, 0.010329794548001262, 0.030647404867434697, 0.053082906430767435, 0.06777946056137163, 0.051120215981838205, 0.033793839055203626, 0.0011332004895291082, 0.04865188068980652, 0.011507280306109499, 0.015943545130862585, 0.045479127551398935, 0.02131345088503534, 0.06748767299277168, 0.050759419213019075, 0.034291861323459495, 0.028348899776897127, 0.014497857736123186, 0.0654460639963227, 0.026287366748757424, 0.044645332776370554, 0.09748167763914793, 0.05726485400490704, 0.041066533885896206, 0.003359218220970023, 0.09405827585367427, 0.06325255125580777, 0.08686237367651156, 0.05347735744210021, 0.05360551629095309, 0.015347825584843036, 0.021519220186277263, 0.026322767671738422, 0.07184609275070891, 0.0180771699055068, 0.016290991859991225, 0.04478819668293, 0.02081846424017943, 0.021481342884081028, 0.025725971772185257, 0.0408391474986509, 0.027802160062316447, 0.03191855540799518, 0.08376600716503398, 0.07271305913285864, 0.004706691467999331, 0.07460037036047829, 0.036244971842895594, 0.00987125357853309, 0.02830106716212486, 0.041513848794443954, 0.033704540016309875, 0.02606958518886278, 0.05826125860274319, 0.02325695657712077, 0.0199135190491835, 0.029672887401595235, 0.029726789347947608, 0.013617347877082086, 0.03173927168151544, 0.03712169052432141, 0.0076079229362339025, 0.054669279169531605, 0.03726284222437009, 0.020795092812829444, 0.08296928338466153, 0.05907247293620341, 0.06508958030251727, 0.06252799678834216, 0.05069459668330608, 0.03608886610656496, 0.026803258017847137, 0.04415286847600534, 0.0390015821903944, 0.06313275042620879, 0.022968511067090497, 0.01981678129654498, 0.01353047542168849, 0.06957202203451626, 0.007190993468787882, 0.035544231218556245, 0.09930774013722136, 0.06486726158689107, 0.03480731975287199, 0.01185813325367147, 0.03011211242166258, 0.05004387776998263, 0.005807068561308928, 0.0025232080154256116, 0.008620790284757894, 0.06005168269057909, 0.022339924433899504, 0.046218911846799236, 0.03357035205549291, 0.0261362022795384, 0.0553598269940384, 0.027259471037635402, 0.014313453669479538, 0.052311566973766016, 0.02737937145866454, 0.036668063051277594, 0.033746774443575454, 0.03387037123883924, 0.05686931897916141, 0.03642229438428918, 0.0306484793057485, 0.012105371851864602, 0.01479934685067424, 0.039495697410236445, 0.06443570127650615, 0.07513895315388519, 0.02705433950459044, 0.07250883541400395, 0.03525373450810871, 0.05324077799976353, 0.03770402459908397, 0.03158364475013749, 0.04174596194418208, 0.056668580960362196, 0.08263673993848986, 0.02618470905168403, 0.07628162691910421, 0.07081866159193939, 0.0128149799439275, 0.022845121115566264, 0.039610779138221856, 0.05176658351575175, 0.037593788377219634, 0.044439117228912736, 0.039227570467177904, 0.07479554658094723, 0.0369612563912186, 0.0037450964690276213, 0.009972655849020568, 0.026762850710280964, 0.016111621948620005, 0.030372522944103808, 0.032287365456502286, 0.061149057676835414, 0.046758253067251176, 0.06161853167859297, 0.04554614109257537, 0.07779298049788322, 0.030433426934084108, 0.12400679785998599, 0.019109848766557632, 0.06283900167252268, 0.01215414867000354, 0.018626449201556466, 0.01451166455573853, 0.024968567454526504, 0.08142500334689695, 0.022292436558693167, 0.029240729542629375, 0.03905641493357478, 0.05332857933676532, 0.06413413842599239, 0.03883040367415355, 0.027405389719792915, 0.10135183125854501, 0.02551723962589618, 0.02408940112218261, 0.03216377632211774, 0.0035954897917221274, 0.020774525267282323, 0.0723270274278137, 0.03440138891399388, 0.007920881344621341, 0.05068926854179271, 0.005289265424043181, 0.03122201294548089, 0.020555552440665422, 0.03716497832248288, 0.012176282865355813, 0.03753987110910877, 0.026329846324158773, 0.058104926870474895, 0.0653375706244861, 0.10240353208275572, 0.058125258843985304, 0.08318573386678774, 0.043680552288048693, 0.04484523958977192, 0.031324969416844754, 0.020589417357358242, 0.013507553113384113, 0.07168444053780648, 0.06948677943118158, 0.027656787217804985, 0.051263367171369256, 0.012844577750882075, 0.04494916707757981, 0.046579337062975096, 0.024044975683453585, 0.03797327386095159, 0.027368466197062406, 0.020893448926208, 0.013861172595962644, 0.05441742010354515, 0.016691958449120005, 0.034320287015889926, 0.0073547797153643785, 0.026430173198722547, 0.06505834689784436, 0.01466100094764824, 0.02642650363756524, 0.02762438361382773, 0.01789693623000095, 0.051736993369676416, 0.06407975767468733, 0.08934232286147534, 0.023962512064064224, 0.05667085624149731, 0.04461721734954946, 0.09350958069966686, 0.10480958442654341, 0.03628016592213704, 0.0075278772818555524, 0.09883602149784566, 0.034670864171799154, 0.02465625639043508, 0.03097040477328964, 0.08561122952209366, 0.04660325815841075, 0.03958692316025977, 0.040254771799570134, 0.06755224654390928, 0.02850441945596568, 0.042919014926038446, 0.11936242046255259, 0.05591979896229121, 0.05639093920528408, 0.020314188779241616, 0.06148317543369147, 0.014245946959201849, 0.13462922746135345, 0.05510473503701149, 0.021477924216718926, 0.03812517760501754, 0.014956759724525676, 0.02587500651697478, 0.046829970388282696, 0.02395040212920116, 0.0302406006883229, 0.07421820739945097, 0.050483098959610354, 0.0656628362353771, 0.029567268774694497, 0.013302824734109304, 0.024759410129439448, 0.014905149338676807, 0.006168604126170037, 0.0053026293490773015, 0.01716252029573004, 0.19315472894137908, 0.1468081102376023, 0.11579323980596759, 0.14486813046518834, 0.15285496479801594, 0.19209377377504305, 0.10310193613892603, 0.08566333116182397, 0.13891427897878234, 0.1817406623834564, 0.1471710214090924, 0.16359524170477546, 0.1176359264119979, 0.13292570838764792, 0.11700523686745476, 0.16840049756630776, 0.1261166193252129, 0.22605091213218628, 0.12496117487429612, 0.10868041220331386, 0.10623170408390223, 0.1593265538254092, 0.10867180903592419, 0.13367331827119475, 0.15615482724482016, 0.19968346812792365, 0.10777787635883979, 0.1471638048608457, 0.10637100185117415, 0.07719727052796273, 0.10659870616490803, 0.1176315060846748, 0.17662486512093775, 0.16739531360085935, 0.12679599375734407, 0.1539562468326861, 0.1256130467499456, 0.1457499742748276, 0.28496619914808585, 0.18579662296800845, 0.18796820644169085, 0.2762580777127897, 0.09790920832705113, 0.26248164114452177, 0.10107164992199791, 0.08608491700743476, 0.16732975179629941, 0.0843244239748005, 0.1407100350385712, 0.1274212210949871, 0.19688329419061062, 0.16577627870344347, 0.18948895225842155, 0.17673040139338664, 0.11731540288535819, 0.09344385801664284, 0.14394589850018102, 0.25021314140289064, 0.1637260435569671, 0.11435183771555463, 0.13261243971365114, 0.17411249509501844, 0.2180617488920689, 0.15579366275379736, 0.1801325365780823, 0.15480426019958912, 0.23115943155942426, 0.14541199160439355, 0.11865589587438492, 0.17170826604049053, 0.09834611593114753, 0.21441622757382933, 0.12864588158986262, 0.41678336298754143, 0.15227309037600795, 0.14556796710577705, 0.20410404059915774, 0.1911043865425933, 0.15781383661012496, 0.1955503012023626, 0.14866179786622524, 0.21281257572193302, 0.2476349797460341, 0.25656080804765224, 0.14750615423244817, 0.21626444533467296, 0.07569638171022938, 0.19834969372999287, 0.1283263233340075, 0.0899100706221596, 0.14306943262777022, 0.09692480832698847, 0.14142537729874735, 0.13471158191321358, 0.1995221146893117, 0.09363922575909285, 0.17288657055506784, 0.083768910638267, 0.18373998332648508, 0.17764288871999712, 0.12677723992495768, 0.1400728184249132, 0.19449316115388948, 0.1947316290029595, 0.07014603639442114, 0.08282713577031128, 0.23332110185536648, 0.07178973932299884, 0.1472920939446457, 0.27184721923643546, 0.10188610863781745, 0.15991645684886366, 0.0988712692032418, 0.07863543206645597, 0.18896468764831945, 0.11732583700288689, 0.16969532405416812, 0.25000750808225525, 0.1262286750058974, 0.11853715990700069, 0.13979679694579494, 0.10225275831837809, 0.12163539567301351, 0.17513632564054382, 0.130231898097742, 0.1903151934065165, 0.10724823381150923, 0.1678132605288298, 0.15422198741186052, 0.11373051742632544, 0.08654928886361661, 0.2685259216495099, 0.2286928582696184, 0.13858674574763546, 0.17968069792034166, 0.18856719526792728, 0.21855578367267886, 0.19440123060297584, 0.16878551803529265, 0.0829646255700819, 0.20434001100159463, 0.23544941668308553, 0.19979879500404482, 0.08206946715231865, 0.22098898617250307, 0.1282034734744699, 0.14431902928458107, 0.10703294012214869, 0.3145077752490198, 0.08354194176894042, 0.12267929772215506, 0.23385287412712652, 0.11213899274627048, 0.16316224880997213, 0.18105191869601128, 0.1169004743438094, 0.09311945042422703, 0.23086971242821988, 0.14707460158294247, 0.13874474372113907, 0.15136743655368207, 0.1169008497268923, 0.09158332922285603, 0.16078585939061257, 0.2027558637482505, 0.11052856867712353, 0.15017978576642854, 0.21609533908626727, 0.14283882484080332, 0.18337383926395448, 0.09554954260707864, 0.13735476911308306, 0.19700105722633102, 0.1602590207250849, 0.16397398025278123, 0.08184276641376557], [0.04544450420766108, 0.008042646710941148, 0.0559535681179935, 0.12249864652873048, 0.05229692320309339, 0.07311822005337285, 0.0422878963722577, 0.07174666219901654, 0.05252908997898621, 0.07246062550092898, 0.010761899738422325, 0.022969315459410992, 0.04520818140477904, 0.05039112627386086, 0.03457932049528726, 0.0541498638959902, 0.02040272939109033, 0.003824922351932694, 0.04642048873187554, 0.03648534725089708, 0.02326637945858942, 0.028090421711244894, 0.025335044765304175, 0.021146102808415893, 0.020219530955317522, 0.017477732917834676, 0.05126460057292735, 0.07088795424469056, 0.011588319959569604, 0.0832341046583268, 0.07963811858527123, 0.06904678449275033, 0.05026654888605399, 0.03263557923116511, 0.017682224767462864, 0.04746856596020441, 0.027837547578758774, 0.0395740069178564, 0.014729997698938655, 0.011731376345720024, 0.08608307073553724, 0.02649756978386112, 0.041349113077646306, 0.009932553061404297, 0.08368258019007983, 0.030567699164572745, 0.06505606395583, 0.03755391350076084, 0.07941291937904973, 0.033600926624550935, 0.028909846592033585, 0.01589058259982736, 0.009334999692416, 0.008541221520112408, 0.025624377022106803, 0.0335280065454783, 0.014699411638561758, 0.07370770938934819, 0.045174511840506915, 0.037567101704377326, 0.039714128229646914, 0.05319382064044476, 0.016435380281519987, 0.042088552633480686, 0.034642986232234586, 0.047695688047115846, 0.02974659846644969, 0.058866655754466216, 0.05920730058043715, 0.03955909118597065, 0.02938474641151486, 0.011043731994446247, 0.026350308532616305, 0.09164015762507917, 0.011064650982828632, 0.08356117057583987, 0.04897320860876672, 0.049985804474882545, 0.03442021935517269, 0.009466688291380003, 0.027037039324040377, 0.06087641081502361, 0.020084657345808322, 0.01555604157939313, 0.019718965275153037, 0.033417333653497125, 0.04876755613593325, 0.05684066729079332, 0.03533281010365294, 0.09567508143523047, 0.037312963526816144, 0.04540507749263798, 0.006930034714675839, 0.03110587784659959, 0.01805614653764473, 0.009376645189589791, 0.0618343424773024, 0.022178178375226357, 0.09099718003023057, 0.006770657304103577, 0.06621973619105355, 0.0209631763338562, 0.07352802346670821, 0.0635613383154475, 0.03988700363064005, 0.05557856041817896, 0.047860937042822765, 0.03650273744677825, 0.05379148796501179, 0.04507312010372839, 0.04196584066976944, 0.07161657280859447, 0.022127806178985104, 0.022317359314089822, 0.014141453523939897, 0.09511631222501879, 0.03814803000779883, 0.04829535103072563, 0.04853731607117, 0.04034925342327164, 0.10768832834137064, 0.08841285136558356, 0.025209643832978704, 0.024300852880602884, 0.009555988287883661, 0.11227947794982504, 0.029109215228668148, 0.02109889838574154, 0.03404016313593715, 0.043637321946481546, 0.03323102107031211, 0.03286595719175474, 0.012129363810433256, 0.0689842104310951, 0.057445972511965426, 0.052665166346536535, 0.026829621018541437, 0.04094088780543497, 0.058295847472524455, 0.011659092119624539, 0.030281590222711527, 0.04902452883881427, 0.019479053350345745, 0.007633357534124967, 0.04571885178466478, 0.010556842898949982, 0.012132513389411953, 0.04960073037974296, 0.0534547884918509, 0.0203065432217573, 0.025621067522273912, 0.009290636498330822, 0.012463486355338848, 0.021394116113022454, 0.008287589918191155, 0.06957588311765464, 0.025554486820774696, 0.030406791972176685, 0.07519098584570232, 0.06779036199253413, 0.01700535544284409, 0.06743873529616864, 0.04497612954207486, 0.014250749372877182, 0.054897634658001127, 0.019005819772099777, 0.01601721980654064, 0.01816171536883039, 0.06681319386247667, 0.07346863633081799, 0.04318217378890803, 0.08314332323929957, 0.013786191740373691, 0.01195586309017193, 0.022978389770874096, 0.009501438039625365, 0.011451275448404975, 0.01414846418605697, 0.0025200945862208406, 0.056992314395404635, 0.01830090971423253, 0.031208922418074745, 0.045059663769338405, 0.02009581158598585, 0.030788922374467217, 0.07931266145239915, 0.05923739634454251, 0.02690831740056315, 0.015399632280722502, 0.04665626378189172, 0.01947779122049049, 0.011871194095170547, 0.05032325471420923, 0.022054131503307053, 0.03913449078437783, 0.020322575526792678, 0.03850576625536046, 0.025625805776085586, 0.02071478764616674, 0.02741146671225227, 0.01196681623226933, 0.0626531066072564, 0.04151779797769362, 0.05584250835161056, 0.03968562975886368, 0.029146142581838275, 0.028787402759095835, 0.037325695908117684, 0.03474094206467271, 0.01737881181461196, 0.04513831801652428, 0.038081104566733685, 0.03233399722845324, 0.019269060989421223, 0.05519090077629494, 0.058780394254192236, 0.035443199543102134, 0.05139251810408408, 0.011908175074495377, 0.016218016239544077, 0.02812764400826587, 0.053320221317511414, 0.04333526879969624, 0.032119153615748214, 0.03522493343259539, 0.00935604508530589, 0.009294823168837016, 0.05101883956681817, 0.08045345064132445, 0.02771066235108001, 0.020140081891910206, 0.0320959737103793, 0.031597417095796235, 0.08801327522603736, 0.03923810417613676, 0.050359046342031616, 0.01959646590084078, 0.10517654054227377, 0.02688873236277892, 0.023079402294130098, 0.07119214477678461, 0.0464011526726667, 0.02168218432475002, 0.05300730504395981, 0.055911145999186465, 0.06846284163334677, 0.05898850969970227, 0.046635295955404166, 0.054767173714935787, 0.06481321408383309, 0.047145276856158054, 0.05653004928101456, 0.07165495381360093, 0.02592631908614309, 0.06916543619046289, 0.007696176743915966, 0.017507614177321235, 0.045195203875341726, 0.04190982049030643, 0.05370914500447051, 0.009061760070072788, 0.03382891822125643, 0.06319446646938882, 0.058381392680589235, 0.05552596465173749, 0.10114768414848274, 0.039978141280552076, 0.07046565593731019, 0.03432468819101492, 0.03423916979602749, 0.02807628738904192, 0.02869255532841048, 0.03914772495326977, 0.06907275487338344, 0.05282741993845952, 0.05956055521364174, 0.05108163196353182, 0.04227880673903612, 0.07974817477647336, 0.0034632532004897874, 0.04016122480313625, 0.0397396466184047, 0.05246783358856075, 0.06152637130130203, 0.055938974143035954, 0.05106922133915848, 0.07767683390768305, 0.023502386250202695, 0.019225750208622026, 0.02727986621339956, 0.020990169441868222, 0.027644612165468357, 0.009499131157363375, 0.04534453739442172, 0.07563380764857416, 0.006088056684201283, 0.04031900827202105, 0.09032889089036374, 0.055393404627759615, 0.022030687297604257, 0.030333170922653332, 0.096676955900846, 0.03543466532362565, 0.02748999455493064, 0.0593389259771474, 0.0426041221456422, 0.0327820667336064, 0.013129072162442872, 0.004604364625148235, 0.023835161437971458, 0.05491104119667604, 0.038683969797866966, 0.050630214654149554, 0.03974353451462042, 0.01884425948974827, 0.021930048242211345, 0.02238669793211645, 0.02731644691178395, 0.029765239300867243, 0.07158252020036021, 0.05992428609921087, 0.03557026671666292, 0.03741160117750687, 0.11956516563171342, 0.03711512515081033, 0.019191927426765044, 0.1521053477641075, 0.0052117545630842935, 0.023530143530919187, 0.054564581763359814, 0.01471414350934567, 0.05856367181085291, 0.06187687950929808, 0.048681876862481724, 0.04230768442334187, 0.028471301474999038, 0.04061704711808313, 0.03504647708107387, 0.04865910106849286, 0.06065868479650348, 0.044374118498977155, 0.05416054699209429, 0.018911372622354858, 0.05722653428693453, 0.007308643027734493, 0.043324133711716825, 0.03643140316970887, 0.055531013171158494, 0.027350909377057708, 0.07179142471643225, 0.057473823638452645, 0.0483305680926048, 0.17772472223206875, 0.12474653235967122, 0.16124519038825266, 0.2271557794583421, 0.1891826703062942, 0.20925553755894785, 0.14124980526826075, 0.1587100522292237, 0.10500048587639486, 0.1449665727634584, 0.22966333845209694, 0.1434868126506767, 0.10981521824555052, 0.2603096593051188, 0.19960710448363136, 0.111533407903006, 0.1384454178473642, 0.1351407750119125, 0.2610304254677988, 0.1308759328939261, 0.13905032087237607, 0.1394153617682957, 0.08193316478883067, 0.1632056247082449, 0.08560173003183258, 0.18333044804392323, 0.13454763909741757, 0.0934573258423517, 0.13100517192675223, 0.18841102058368345, 0.07680019949592891, 0.09965257163369849, 0.2320363111193142, 0.2123508085646937, 0.13035628013312817, 0.08183997019284195, 0.1926498310340028, 0.15500863713602867, 0.1474034678070776, 0.1376478130658788, 0.21427097730338576, 0.22417246454185058, 0.10430405066618997, 0.1648453593013748, 0.1880474965418539, 0.15847196742411584, 0.15680079258257346, 0.14052500948309898, 0.17896288885704933, 0.11773029312251077, 0.10086763304688277, 0.11253011893601188, 0.1312821280331381, 0.09663430012522206, 0.1138599249984949, 0.12016150379373182, 0.1483395812852729, 0.24180279834376228, 0.1413319452155021, 0.10606189303460622, 0.21408402120634434, 0.14070500950178794, 0.1392787376478795, 0.09960274527510328, 0.2906572211894297, 0.17710337896020184, 0.11269235337573676, 0.16937407274400035, 0.16804471101251342, 0.1470800101636879, 0.16824610020604827, 0.11788495861354376, 0.15853763648098515, 0.22441998755018558, 0.12633103201346052, 0.13856877332493184, 0.31059187085878465, 0.10972594601973411, 0.2723590885439227, 0.14236181253387084, 0.227196320831295, 0.1981669357947765, 0.17460061567685298, 0.10023033982443233, 0.11686865105143479, 0.12339271710164125, 0.08300190340847739, 0.158636829545421, 0.23623943719412052, 0.25630107359780424, 0.12414421871184342, 0.1615787450704844, 0.15566111422113835, 0.16611007853381096, 0.08140942877939633, 0.08900201894463071, 0.13791801227677253, 0.15968756509884713, 0.19210178705473102, 0.15405959209367154, 0.15841808079952197, 0.11957781374334328, 0.18779050468677477, 0.24515457090831574, 0.11868833203709896, 0.10898378302132893, 0.16375383722686, 0.10966098176375513, 0.21041957751637508, 0.10980974071689191, 0.17056717807727476, 0.12336954294193177, 0.11364430955220615, 0.11265813988903839, 0.14337672581595762, 0.15060150184698645, 0.09986365950035472, 0.13189939571724785, 0.18241209248381277, 0.058726611051468126, 0.2689043384405875, 0.1870113166589891, 0.09080537459662846, 0.14964856507797397, 0.11054027450060654, 0.2758911215970593, 0.19707498471102408, 0.08926082642809038, 0.11741065825786322, 0.09925524013177042, 0.1154377137220675, 0.20969193188413499, 0.1121022358476635, 0.10883950568254917, 0.15075847326267153, 0.12064452222999066, 0.19340430506535117, 0.1199127090794425, 0.12720686969377343, 0.13780858427766832, 0.21704986931816225, 0.14884780401424055, 0.13402338980907394, 0.08871177121275857, 0.09848978039958785, 0.09909972428314148, 0.10813472777484887, 0.17680897137090085, 0.1718164836206744, 0.08064110387837695, 0.20724826462326512, 0.08581863250583412, 0.12257801323768594, 0.23651377327980536, 0.19686025026584827, 0.0914727520918654, 0.1259576177765285, 0.13793379368801273, 0.1378717252443875, 0.2157943124973005, 0.16127131398647063, 0.11830734119059579, 0.08808206992163774, 0.1894505559316566, 0.14980827908842795, 0.14673289572519643, 0.10842881360722166, 0.15810380088946513, 0.17671921650969213, 0.12904800114131745, 0.15741764657920407, 0.21535402644545804, 0.0863705835335197, 0.10221880530157398, 0.10125029396506087, 0.12581363921203922], [0.0060252202374319885, 0.035021793728153554, 0.021542547563571605, 0.04927109423724394, 0.023585332504984353, 0.039997814418447596, 0.015540745676374965, 0.02367802531338267, 0.047248365477688854, 0.03463900257502833, 0.0838942809270755, 0.01496698891353463, 0.04573543375778583, 0.03267857974635498, 0.06951366145644458, 0.014780189864517701, 0.03013964370644141, 0.056647141989801204, 0.024514698663786538, 0.04941637898164411, 0.11464856655126619, 0.02891218890586207, 0.04178271884278905, 0.02007839074658771, 0.04232771379212218, 0.038563035158140045, 0.011992865136914678, 0.024749249888343677, 0.023289339113680106, 0.02128581617838673, 0.04439657636647744, 0.023609232533002095, 0.03968226663287609, 0.0501065667448265, 0.12574296760102435, 0.024524454793502248, 0.057102546786829356, 0.017714021246760123, 0.028831868417440887, 0.01956848836984606, 0.03527111321267101, 0.025822129213221134, 0.04395639373650474, 0.027913535839968154, 0.04018556724693026, 0.0286700974609102, 0.020890882531661662, 0.06510425088626724, 0.046813227536697546, 0.04122855382100229, 0.03633905510087648, 0.10961336173838186, 0.0662264930865457, 0.0540115543821406, 0.04918217824231233, 0.01993242992959436, 0.028111954527576605, 0.031119339926649007, 0.011866102483303798, 0.0018822065683179387, 0.05775411222730914, 0.04957770560717872, 0.07662582256260418, 0.04696635319100273, 0.07134389913370533, 0.009561021485546184, 0.10532558294794253, 0.0537519539976793, 0.06599317334832684, 0.027943124070823677, 0.01859300371800219, 0.02118764967176943, 0.037374878752856486, 0.05195766499626541, 0.02396490417360779, 0.008418123639609304, 0.026564824642733704, 0.038010471260115024, 0.08225658412782416, 0.05019668166735961, 0.054445623630477544, 0.01798971713851056, 0.07928882845707479, 0.02443233080538771, 0.055289147722144286, 0.02038479527278293, 0.05244321152267437, 0.018888319121493448, 0.013968574292507144, 0.020757215510633205, 0.03020179067407885, 0.07768182880094937, 0.015457595450683467, 0.0435275492078114, 0.03219616651955632, 0.044283049796978315, 0.0581633985312956, 0.04203538996197524, 0.020065662195725788, 0.060530384221384605, 0.039503511507064104, 0.1073237547590848, 0.0987210393612904, 0.06433712874328898, 0.07121351862987203, 0.009878811035906116, 0.035804720265009714, 0.028754125814884905, 0.005576200304447764, 0.03749557590532688, 0.025453889900217616, 0.009665124215966752, 0.028733590828074564, 0.06568928925140251, 0.016149311559274793, 0.05418487411412982, 0.06659956258391181, 0.037647812897639896, 0.007545222470071168, 0.016926147697132923, 0.05827318659172424, 0.009094251774161333, 0.021669172321356112, 0.012648486055343622, 0.12596437467202065, 0.04801505861142951, 0.02705365385589821, 0.10473133620595741, 0.033517583919268464, 0.015018156883607229, 0.06996494853087971, 0.011314614938812391, 0.02192744162804898, 0.01791853416380623, 0.08739159487548374, 0.006455709461137773, 0.05113464141745241, 0.08986245059678633, 0.03971279140621905, 0.0038027761864566035, 0.021688552430620598, 0.03998807361049037, 0.05206897374122374, 0.10658630320141393, 0.006494710997362892, 0.046196672314357375, 0.023765449352081747, 0.061917838400169734, 0.02353637757140302, 0.027008870271064585, 0.027745276118718812, 0.07749691815866579, 0.018110272564714956, 0.08691825212970858, 0.018487961572264473, 0.022962365126717958, 0.031393095700731205, 0.03400075940355178, 0.08149691602034916, 0.012381439296258314, 0.0646668529858993, 0.08076353238955622, 0.044163241306500095, 0.05567946568912557, 0.03538382389853078, 0.03466760446768134, 0.030354293881945556, 0.0003128588768079006, 0.06194736725921112, 0.05502631827708214, 0.0009404849075625892, 0.048779231315899285, 0.03630890571061642, 0.0451016683702267, 0.07838429312311834, 0.05942225719111101, 0.03014249163829992, 0.049858813910114194, 0.03155748667796293, 0.004162398925531776, 0.02238176049544446, 0.0901113985286605, 0.035280570568096255, 0.029432169169247634, 0.03708305671029995, 0.08290648715750826, 0.019393192131012198, 0.039831730386903214, 0.06767048455414272, 0.010439420772355892, 0.05159362767552657, 0.014729181815299296, 0.028103839741238666, 0.006398449655652287, 0.04944981105865971, 0.01736334832986036, 0.09769339369790209, 0.0737663764025896, 0.040918594646838405, 0.04827072513439963, 0.02685874768142258, 0.026555240882800955, 0.03170296102912436, 0.044648703563237385, 0.08650786648955076, 0.047737933965700294, 0.0069588065830870505, 0.06186550310362251, 0.05412973876621935, 0.054937678073803266, 0.029637354328447295, 0.05831952341982435, 0.03202741650203544, 0.006344475888557011, 0.03353061124442085, 0.0427079615333388, 0.04908452884504392, 0.024120391293939565, 0.03422115906892765, 0.0401346760261203, 0.1017139993247486, 0.042734441362441554, 0.013370469340213366, 0.014474055384315792, 0.02858741933690204, 0.01959796743317237, 0.058235349509144024, 0.0558430714262349, 0.05073810664696559, 0.035656137512095516, 0.023489492990437056, 0.01928139692022195, 0.0369239938745816, 0.014164132599328316, 0.01925318764763013, 0.010740005903156295, 0.023977759128977216, 0.03457576967775822, 0.132381035195243, 0.018258579525976412, 0.015276633991649555, 0.008437741236130317, 0.02045044134701452, 0.10493929843388258, 0.06210980088179631, 0.03602585920523252, 0.0307708963256089, 0.06009201721979245, 0.04847910104980392, 0.01555737648760119, 0.019308209997571765, 0.029042810727391514, 0.004264075072452186, 0.021689762849540963, 0.008519986520461258, 0.02799880525638019, 0.03867029895885818, 0.029151740769344955, 0.036758775522391644, 0.015203337571884116, 0.03451750869111669, 0.005372406073635625, 0.04421217517266351, 0.016605513087744196, 0.016964808324231737, 0.05614118305064979, 0.018166011206865795, 0.04602042995693703, 0.085945718831593, 0.028495128724663973, 0.030551417880961974, 0.1001410446159782, 0.029441592050716284, 0.03952094383778111, 0.04191707534294936, 0.01109731314148033, 0.03155358345998872, 0.05577191717982773, 0.012379735708236696, 0.046708974461521835, 0.028051483377273527, 0.027521181994328098, 0.016054714064774735, 0.020402248670917847, 0.046028653910804185, 0.006065324461463118, 0.04033687727285489, 0.053056177623089285, 0.030903745547778187, 0.044202717817238266, 0.06594517027899142, 0.05260017144704058, 0.037267668578293056, 0.047680856584901773, 0.039443522992153326, 0.014625423824444655, 0.04630601604378993, 0.013585162608163252, 0.01691014028995508, 0.02134639649621902, 0.04269343267585482, 0.05837691872711143, 0.009540410847553324, 0.018909016901987697, 0.055910383741701805, 0.02636389510195342, 0.0359553063378459, 0.016027001791723793, 0.03149808422031422, 0.05447362414410999, 0.023389271452962872, 0.01411059358713007, 0.06849156226962805, 0.019039217375158783, 0.0170430124947621, 0.030850808872210405, 0.07538171875621043, 0.02514727469984322, 0.07121277552458548, 0.018868534900848905, 0.036049619422204075, 0.04364512455199034, 0.006479030135162776, 0.011754129157071153, 0.03945478448464025, 0.05164198314530715, 0.013910268298200062, 0.08346496525430873, 0.04192696553805182, 0.05987461295820052, 0.02247167240467764, 0.034326442532361515, 0.023812151987165697, 0.025896893648971474, 0.043889223147303834, 0.024939900444399928, 0.04389337534385343, 0.08941022123420432, 0.04652927704756299, 0.02515539140140097, 0.015362982634424925, 0.023467946767566666, 0.11448164365344471, 0.023275145419663, 0.03652545578417279, 0.042379206391952695, 0.029097664537989808, 0.028725525837451703, 0.01274717828979896, 0.04514604784368027, 0.029938273665104664, 0.053302800478113276, 0.07200824292076212, 0.13789233300955067, 0.12488503339550189, 0.09147186342987323, 0.15068594005800065, 0.15762689583484205, 0.08652281286495347, 0.13571491194588525, 0.10908482235766227, 0.1954595963921278, 0.19231701179617838, 0.19079278794027146, 0.10666299626351365, 0.14146636300269635, 0.16786938413016259, 0.14273426916089751, 0.10187510761522478, 0.2618526216716536, 0.22001731089286267, 0.08398117061944739, 0.2067695056358653, 0.18857359976297428, 0.12262858270156769, 0.1647820344735538, 0.15618377004659947, 0.191915474471546, 0.13710704692188772, 0.0960151861692148, 0.16940391952953032, 0.13426547359314658, 0.17918606559115072, 0.08750227159790455, 0.1615954457872337, 0.19713133813873415, 0.25479264647489597, 0.07670092216182141, 0.17144744374579, 0.12578132562339306, 0.07532366461330846, 0.1120906219547314, 0.16283960321978216, 0.09228004788559291, 0.15646523074998012, 0.23247082086820758, 0.3078680912092809, 0.17959468156820346, 0.083349148081916, 0.1471032226277936, 0.1777296711600596, 0.10220618017258183, 0.16900880202170343, 0.2627240620072811, 0.22727748018599328, 0.08888745049555456, 0.15576767705140576, 0.0973875330941331, 0.12941020751191726, 0.10125264585498842, 0.1576671767379007, 0.0673897592951694, 0.19450080671137382, 0.23095883909733067, 0.40549821370551664, 0.15369355528345033, 0.2410182170569897, 0.09688864897696242, 0.19100672565400603, 0.20826665594452815, 0.1549214103649701, 0.09844516343887776, 0.1808208512562898, 0.13204571851078542, 0.18292978405952456, 0.1538305930913456, 0.14724157810691865, 0.12135521433646641, 0.11058814733499482, 0.16819199907683557, 0.10082924438099708, 0.10273219912403053, 0.12602754628225682, 0.0979579545016731, 0.14625484153868692, 0.15454369837478285, 0.1270248855073606, 0.10006251294286021, 0.16082037931248067, 0.1858008211298335, 0.11606913105013872, 0.13964172542816208, 0.08851605873074263, 0.208806594713561, 0.1252216830729477, 0.15079231902716622, 0.1266522986453868, 0.18974957537026177, 0.16993167750056715, 0.11040241697863226, 0.10180792936514463, 0.2183117080600031, 0.08268092788996236, 0.25463516944118086, 0.24028182270065432, 0.19612048512264607, 0.1425484928392595, 0.10292599638623577, 0.1251871784728381, 0.13426441639181108, 0.12562050078544887, 0.13509321627357315, 0.1601233618754533, 0.06218944721284413, 0.140512767398069, 0.13487143381949396, 0.1916740954883637, 0.15903378566426618, 0.14029792570058378, 0.10863296837816316, 0.10989118352412217, 0.1195342539839687, 0.12965008496276795, 0.12395170847735099, 0.06187528221597595, 0.09680663926466819, 0.24037039778645963, 0.13610875774775782, 0.08847639069802339, 0.13196393096398923, 0.09866330697531663, 0.20439064941338955, 0.28953091872315256, 0.14027881946775222, 0.08301514140780895, 0.16461871984985568, 0.1786275415290748, 0.17215457354341784, 0.19522123579536715, 0.21301388830667545, 0.1159693864023974, 0.10063240574973245, 0.24499130224989307, 0.25968180428589543, 0.1684780869512789, 0.21006631905273085, 0.10497540415775393, 0.19840348842403582, 0.0904705252258047, 0.15259559807037154, 0.14185794118431308, 0.1403417765733696, 0.10901052715076555, 0.20399498032225719, 0.13010397673614565, 0.17764725542116552, 0.09212347483562847, 0.1646230712292656, 0.10068611617410377, 0.16744530849879788, 0.11693766791253321, 0.07569530918713539, 0.19811714007969827, 0.16698387842024529, 0.11900877129406699, 0.14414341128881902, 0.14426347258831226, 0.11945565336293752, 0.2722960548295129, 0.09361340093516535, 0.2280723576944682, 0.1168537276586698, 0.15837389284804945, 0.08874464404558943, 0.16668087532443387, 0.10423166301822472, 0.21149398518666146, 0.19692257917936773], [0.01601125485444021, 0.041075428166697105, 0.06401219638064504, 0.015205971956733736, 0.12038658042588543, 0.011429005272446141, 0.05426004649169984, 0.09238790540445237, 0.03413880844750712, 0.026536414272061763, 0.05711674239606627, 0.03846386124590232, 0.12088055391946148, 0.03904534113262931, 0.02814273977081382, 0.10904732235376874, 0.019487108764869553, 0.07286721134498235, 0.0756278551454025, 0.00914067670237273, 0.03477930774792068, 0.04402387459131499, 0.03157350366123982, 0.052171242648675564, 0.07509293425227366, 0.0568571841464408, 0.034066233108000415, 0.016312252715109818, 0.03159881329103824, 0.02281854169503335, 0.07075563553840884, 0.033152566005986546, 0.03473593951052716, 0.06512732545454657, 0.0072582392303663645, 0.05845473027758061, 0.015297574047449858, 0.0034805478747828955, 0.06350182860548939, 0.03268534430272637, 0.06043244371070497, 0.036314264495646766, 0.04617234519232185, 0.02255667369031618, 0.043353842601420424, 0.07554803644457171, 0.042650566226051706, 0.03297232083916184, 0.06086257143667149, 0.08338137740089048, 0.0833779989531444, 0.07862401735638419, 0.029179323765058673, 0.1146100553113126, 0.021169386135654587, 0.05604079871949169, 0.017782417576639883, 0.018396444708829927, 0.03548284842362327, 0.03670487357603927, 0.05559396644633624, 0.026420616251867146, 0.04293492274178613, 0.029153276775633136, 0.09936706598607764, 0.05977176948480549, 0.02318432761145936, 0.04479849290463232, 0.030739722292750116, 0.037567262582841425, 0.05956466910579513, 0.05349231530882178, 0.08678731238169056, 0.02831511721465617, 0.03464605824481096, 0.04855617332542616, 0.03492190735414624, 0.09752283188244028, 0.02493603361560212, 0.02036986613435851, 0.06690253503620625, 0.034490707105085734, 0.05032076875889494, 0.062335233744834705, 0.05733978889522053, 0.055911218777539275, 0.024654902330028917, 0.006113461117380329, 0.04228950898733832, 0.04172602067551306, 0.08693652332670267, 0.05414483835920692, 0.02459140321720512, 0.05057759590507035, 0.027185375013598995, 0.046056922555210135, 0.0380372766765856, 0.029548852020994793, 0.03106039903697468, 0.02871047220973959, 0.04516176413744689, 0.00628276223940174, 0.0235886515809163, 0.06030724962211906, 0.03407081431378761, 0.04595791718231575, 0.018554645695633466, 0.07409790095182196, 0.032282014332351186, 0.027798302809617696, 0.049143471649938056, 0.10185069239307797, 0.05332839164522387, 0.06720904681471086, 0.014011617900142747, 0.01687460147114771, 0.057944783850783305, 0.05796856321995297, 0.07295482116000307, 0.03997395077960626, 0.018363717432704665, 0.0614718335019725, 0.0831883232439718, 0.0521094691489012, 0.0714966111005314, 0.043670240744587877, 0.03433950816191012, 0.027171995288001436, 0.06764542581813951, 0.025913579043962305, 0.007819709858121051, 0.07894713026020797, 0.004414449992304247, 0.01602337532301223, 0.05223488157254554, 0.06209021201357246, 0.028083863998613054, 0.021413212769754955, 0.015566043814854517, 0.040395525133898186, 0.051786375397275534, 0.0677196444162438, 0.024617335293442014, 0.038942934329351114, 0.05275015614085621, 0.11988178210993929, 0.015545684070656858, 0.07518599861331525, 0.04170016520806859, 0.04944243363194889, 0.03197105924388574, 0.14731385084169527, 0.052645535343476844, 0.018804285021859313, 0.02853382191049957, 0.028343795716101607, 0.02348317084984193, 0.12226972413519699, 0.06850195808276054, 0.050587750400506684, 0.04339976957248103, 0.02156870180530654, 0.010219041216788034, 0.05007996817209548, 0.020577416590024388, 0.03805565512588909, 0.011527895732151886, 0.045018023060214137, 0.038694108971544815, 0.031100898275091767, 0.018929837256549828, 0.03955323827422915, 0.03210440642320581, 0.02178409891653686, 0.07968561603657662, 0.04040502079371964, 0.02603437578786285, 0.008062200147598501, 0.008431134685393303, 0.047133318223660035, 0.025748542637654373, 0.040745006784075694, 0.03211645124059531, 0.12819553680357434, 0.038162934248365706, 0.09067152371449817, 0.05064712221463842, 0.023383901176613667, 0.061120137857693824, 0.05573249812568388, 0.04700168133563092, 0.01626418644352065, 0.045133721488978595, 0.0589794583708769, 0.02436494762678781, 0.06050215771181449, 0.03263093290790435, 0.05911650000921181, 0.05449894718044708, 0.053168160525420984, 0.017888852087179982, 0.09581290065280854, 0.017404422133920655, 0.02672695757580861, 0.039476273250916315, 0.026442118424681887, 0.038730743296083905, 0.02922810058319761, 0.06525240462994383, 0.06546576777773519, 0.06997467018663883, 0.05729361294558453, 0.04907350867025314, 0.04222483584477056, 0.0584920808943289, 0.02646790685943298, 0.04097590568445383, 0.04359805610992255, 0.056485340389753544, 0.06024158056524973, 0.08537731223529385, 0.07070316617647487, 0.09981685918906044, 0.04730366936494266, 0.04116015749112253, 0.0506869932606576, 0.07192449418887978, 0.022563761918835586, 0.0367517696483241, 0.04328661072518557, 0.032749622910013126, 0.033254880878713824, 0.08291594068249387, 0.028307086697989897, 0.02516529883348173, 0.03692516215866612, 0.067446066757604, 0.08592931688913415, 0.016990236697658416, 0.025054032223359234, 0.08941356137755418, 0.03468666090479782, 0.04544243960070514, 0.06311535256944838, 0.027200340541199814, 0.03724688844334695, 0.055770568865081, 0.019929649030429222, 0.04643472647594829, 0.08316779208760108, 0.043573380417881474, 0.0270040592389001, 0.016372813880744002, 0.03958223087172355, 0.057152396128062284, 0.023926594031734333, 0.048915889910272056, 0.10955288675763916, 0.028472532961337317, 0.044003603904838526, 0.013950543455599297, 0.05875714348569032, 0.03819315641697857, 0.05075967968291333, 0.014729251720822387, 0.016468318231824427, 0.02796209432304867, 0.04250171534236401, 0.03360561508264753, 0.04054341840768053, 0.04689757381716082, 0.02308637943990048, 0.06948445052389177, 0.014371229147899055, 0.04515992935686823, 0.021314171007684162, 0.04494178582042937, 0.02620430366556731, 0.015814239065343096, 0.03830259973784128, 0.04140975659773235, 0.047615965107275594, 0.03446590883897678, 0.03768769160453831, 0.07281654995054969, 0.0073354613719387885, 0.04782761987899581, 0.01558295903622263, 0.1022789968297847, 0.05292632955036337, 0.07778151216165674, 0.009324871052447106, 0.08663567293795847, 0.040122690580544934, 0.03541557441255258, 0.07832970169763412, 0.03742879985140697, 0.002901561364846965, 0.04650934343977321, 0.023828075124671864, 0.04645808832719923, 0.0480277450274556, 0.08493894140326208, 0.02961008542878253, 0.057873874752511906, 0.03281775876999863, 0.05911106078494942, 0.1158718634096365, 0.01343758151521005, 0.0421583011085468, 0.06935254550508915, 0.024823472316887592, 0.03916356765154389, 0.005469004015227961, 0.03971025565518968, 0.01471859448018574, 0.04184139734734932, 0.06589962635189295, 0.029771249260633226, 0.052742690614034096, 0.056809767134367466, 0.06014175547827637, 0.009240312182584838, 0.0032432811079366555, 0.007565578383829205, 0.08117342773344248, 0.02000770381381435, 0.019376951067017454, 0.033033090763755386, 0.05112026960799291, 0.016896879307985786, 0.04809134564692936, 0.036774974451550556, 0.021035631014514836, 0.04493616656550477, 0.05740669135364795, 0.03867705585435033, 0.038887626611657684, 0.02400334071998875, 0.04577871389506806, 0.02003755634500375, 0.04383581532766262, 0.017493460702920155, 0.07614245938677942, 0.009262583316153577, 0.01802932196897605, 0.02684243383907503, 0.03776754860976531, 0.052470480422339136, 0.03650174919335592, 0.01915651692768499, 0.018978686853041573, 0.10281072313626928, 0.2079513188331358, 0.16554695794418936, 0.1611609360383403, 0.13497205180746896, 0.14549111316521324, 0.0912676320501393, 0.2130055226265423, 0.18460448290551865, 0.20264485760802226, 0.11305527220810614, 0.17913288376744718, 0.15064663974748504, 0.17988709732890132, 0.13907860483854048, 0.19900866724070043, 0.1192960236221552, 0.13996882965007137, 0.2208887665502487, 0.09755348306029074, 0.13350199036780866, 0.1340344214751836, 0.10879261344070397, 0.15678202342842856, 0.2088496488549056, 0.17184680538071742, 0.13468530509741078, 0.11205691408606307, 0.1599334180355072, 0.09680840126689404, 0.15652562912193038, 0.14784565375697228, 0.16524257589011423, 0.13492403341637504, 0.11794340346128711, 0.13244074408806142, 0.17454709677446276, 0.15872672230245607, 0.1389179408790604, 0.1529313590858252, 0.16406859211142988, 0.09884774264308716, 0.17418502829968932, 0.11367267012716302, 0.19612996929114868, 0.1457437996061579, 0.16051706978149954, 0.11301508323559839, 0.12962998281563484, 0.21386885775193093, 0.3114257422426055, 0.17045790329575541, 0.17440826632082465, 0.1676531328308967, 0.07827282733013553, 0.1921845398723118, 0.17573831753144342, 0.15477422955295733, 0.305475598621753, 0.10955671719726055, 0.21833625351709707, 0.1955880846587881, 0.07353954542908939, 0.13126239360820863, 0.26842424646019936, 0.18969159783615222, 0.16498765247243066, 0.21691725949846932, 0.24398866169635328, 0.14465748692952818, 0.21623657505598762, 0.19458689967230444, 0.13185267967562522, 0.2115911711007357, 0.169565012498248, 0.11391492245057899, 0.11378667933205444, 0.23982290539049336, 0.2508326000984638, 0.1217076454251524, 0.12320903986091576, 0.2820037984319272, 0.15526043491498118, 0.18789699090824974, 0.17235711186883912, 0.1826673989454585, 0.0873102056944082, 0.1466371806999368, 0.1681629337009884, 0.16731462922067414, 0.1326329402265049, 0.12622178787545812, 0.16525612032461554, 0.1822355398607831, 0.14176181247157438, 0.0969042695097385, 0.14228468280165427, 0.11181545849408835, 0.09636682818733877, 0.08752985076317865, 0.15843449040286003, 0.12229227776368781, 0.10423940816713918, 0.20637461795441567, 0.09471553332743146, 0.1792530829627668, 0.15681481199158778, 0.2261593748605059, 0.1650774839424318, 0.20380494455176018, 0.10937358387896132, 0.31146377084716675, 0.22191155521619707, 0.237140218697248, 0.1871506833741742, 0.12539672650276654, 0.12836552405309293, 0.1255379777942454, 0.18214837437675846, 0.16637139112478302, 0.1333518064911327, 0.1235338994452069, 0.14860991839199297, 0.09859967571232589, 0.20100814140131398, 0.11838740503956234, 0.19511789053438172, 0.11245573179856425, 0.13445163295874674, 0.1306569083563743, 0.12414113903838782, 0.1726214122027159, 0.10400521508868664, 0.15378462781588878, 0.11291673286787926, 0.18473605084563458, 0.11288229721568285, 0.1378325475079398, 0.10757965876931146, 0.16643036457319416, 0.14728014297302694, 0.1350191815365707, 0.09006098994324285, 0.17926877244345604, 0.1483538305206645, 0.21019995543024234, 0.08450397200161412, 0.15589080270259612, 0.10567617542561024, 0.15668874456276818, 0.08565868100812359, 0.198274479217587, 0.10395017933220634, 0.1148073535953318, 0.24357855950872748, 0.1545357617038873, 0.1579348478586443, 0.23242453383582257, 0.34517289589970346, 0.1731095481063089, 0.12519414987294905, 0.16717385290370834, 0.0946331405711751, 0.11140169440618447, 0.11882396024321357, 0.0946943509963251, 0.11900602869929806, 0.15448090980850882, 0.11481825502649431, 0.10573016930251353, 0.17571792427089908, 0.1519406541821457, 0.15997587462827084, 0.12671704839674697, 0.1862156577408314, 0.15934086434783476], [0.04840696621085367, 0.03525565355835903, 0.058448471339239236, 0.07289940235956062, 0.028800317086279396, 0.039375325845133875, 0.05112029642107026, 0.0031715659415274262, 0.04465229268516264, 0.006411656053856977, 0.07687413464150122, 0.0382759551998348, 0.015166491615555942, 0.01644328056323913, 0.07381025791889237, 0.039024691232630325, 0.017158025274834326, 0.020018390740358064, 0.08930566555429852, 0.046669425172430855, 0.048735070177504135, 0.01019164016695633, 0.045339308844338504, 0.02950962065839239, 0.0196179642432159, 0.08796501934768693, 0.07494832749568647, 0.011211110714582667, 0.05192936187790287, 0.022665519462597948, 0.05520407748859256, 0.06851708831926508, 0.04337037094838677, 0.07765827159727774, 0.04877788300115255, 0.055962765003524484, 0.04769591404305351, 0.06419028884040252, 0.028231992844432115, 0.0291020657131148, 0.036035167173512524, 0.06759211375948883, 0.0020112676054028977, 0.032099716049889405, 0.03609466539215177, 0.020103832526553064, 0.01210510659392082, 0.030360474296274687, 0.08035898433938142, 0.0029765242652501915, 0.02627108163470703, 0.020758412523014892, 0.04154801248542724, 0.029463220628038533, 0.02776038337258562, 0.02679674244005113, 0.05249441300909366, 0.030015269331934474, 0.06543300219721372, 0.0421586420176731, 0.041621633534950596, 0.036666278066414024, 0.1044050133937309, 0.019078023558963212, 0.03203228307557443, 0.010836891127720235, 0.01849923647129007, 0.03438006485662153, 0.04252123143223505, 0.025801291621680704, 0.026487503388536074, 0.026633358868439833, 0.031830210148567156, 0.030193198998008045, 0.04314516408128604, 0.025114486136684017, 0.05745594697673956, 0.018694979596822973, 0.03352642840435428, 0.08072451553157262, 0.029038204623746778, 0.043720001985709515, 0.033383418941089225, 0.06898949643777263, 0.07325698921997702, 0.043386232798859, 0.028287403983995322, 0.08334231457763142, 0.027339303145004858, 0.0360686835201998, 0.11629095180861412, 0.05319233442987165, 0.06770412347489788, 0.031190748897291003, 0.048332632699560736, 0.0410834989029794, 0.011804249501907298, 0.08182523066117879, 0.04534701185841714, 0.07508015590569667, 0.08197542985961323, 0.08269401267170906, 0.041345336264179605, 0.005044551564365505, 0.0402261660764775, 0.05041138929945808, 0.016082709790357662, 0.021758377514479142, 0.07327549790422763, 0.014738965715702265, 0.018250091271775386, 0.009388076179029961, 0.02039250211730119, 0.03119377877503153, 0.03739195102224908, 0.03318639261828315, 0.0593202947188289, 0.04228115862896366, 0.0331245118661994, 0.07047591385461631, 0.008988729865861037, 0.028761282991317492, 0.06310037555052869, 0.060058983508497484, 0.025207849272016077, 0.044199569195869474, 0.06315060027484452, 0.04664263507771877, 0.024449855066655625, 0.03513111064450876, 0.053812061256218346, 0.03993026078528455, 0.05091245293677334, 0.04992289716498025, 0.009784460604761638, 0.011673876658953246, 0.04276010913834457, 0.07453293164050387, 0.0712599895233589, 0.02810551364335322, 0.014101999038229547, 0.03056129658474557, 0.052439974801194285, 0.06749550241135782, 0.051416485164795196, 0.060585799191387436, 0.038889239226738294, 0.10454582801509289, 0.03873198818896086, 0.06823686867832177, 0.025523017844065063, 0.04072783492325295, 0.06684235882975402, 0.03223401892389501, 0.05787465233175505, 0.05792053716797983, 0.01681637112802315, 0.03943515731202018, 0.02673460313329293, 0.022072253313155907, 0.09063055333230766, 0.0640316971487576, 0.01925492858243806, 0.05629127116633519, 0.03237722757002039, 0.03528488364310996, 0.030803635093053023, 0.04028070004536741, 0.03167520757884749, 0.07556633062420354, 0.03963766116348486, 0.07683500287032898, 0.006925051312728395, 0.005759932607742808, 0.025261343276548772, 0.06443739433081881, 0.07323582221062915, 0.04605234134942294, 0.08101461770673914, 0.029975453827289805, 0.031388767303959016, 0.09412150875094438, 0.032559648426550056, 0.01783083050301479, 0.024039210871823376, 0.021137421117013982, 0.0059468547096325755, 0.03822380759482903, 0.038696518318066676, 0.05526671283728173, 0.03321107597120347, 0.04607529334363438, 0.0787446838653376, 0.04622179616783415, 0.037638344050895785, 0.03176862817077387, 0.10019349099527444, 0.05167416649900618, 0.039692524550182205, 0.0350541609429544, 0.05590018711142963, 0.020574139648928277, 0.04441305491772871, 0.01947054785916642, 0.016953307429268476, 0.018663265471977573, 0.05894541342352187, 0.01373105351963351, 0.02323553675875789, 0.03450007636039969, 0.021058786022026214, 0.051101370218900904, 0.005697781809665744, 0.018761405165517525, 0.06894755312391827, 0.015634685292870047, 0.023086890803589936, 0.029510245020050677, 0.01612580989697768, 0.0711440880812945, 0.03354266180746979, 0.02369276867548545, 0.03476294794029767, 0.027394957517484025, 0.04008172785923366, 0.026683539542700016, 0.029963234724897533, 0.038368900817248135, 0.009089930080658486, 0.0952638760809937, 0.03479961290835373, 0.048840851598088784, 0.028552972193386768, 0.018314090256969777, 0.041725262248468016, 0.05370386665867222, 0.09711942530327267, 0.04155966468275555, 0.11308446781890047, 0.00904564924102517, 0.04758171331618102, 0.0019554490028249644, 0.056845528118672876, 0.019752671228601568, 0.06584937098406016, 0.049064422867471175, 0.031560374829437465, 0.02442814988054095, 0.027421906575440403, 0.027883118318934596, 0.09193307900380704, 0.055768557884279764, 0.024497046082791303, 0.013742676988664656, 0.00827501075447447, 0.04095920496770451, 0.02696346998545191, 0.03949357917712581, 0.060606835965788176, 0.04608815212944343, 0.0645134745225791, 0.03040961500617766, 0.023914493672970324, 0.04947431821135744, 0.018742896481266907, 0.045077306774234584, 0.08077663249306141, 0.029769224873293313, 0.014618222597956419, 0.022613197572589405, 0.04262322837847375, 0.05617257350334718, 0.024983804943340442, 0.046100164388096145, 0.12174722152732073, 0.054556606788068056, 0.10838960522725698, 0.07683936191061813, 0.0852352871950115, 0.03332662118238307, 0.05473039000325146, 0.06023374731622397, 0.04333736405016915, 0.02452946309330723, 0.016549004527229457, 0.03812456473467812, 0.03237936878576875, 0.042910894394041076, 0.05613105919873042, 0.09660757897842316, 0.10683399474909229, 0.027163966686554977, 0.013139069609854732, 0.01611386850145796, 0.04514302562681898, 0.043473218252221425, 0.03263922580968469, 0.012960257027448427, 0.06510181472666803, 0.030410781375042377, 0.025056418587243365, 0.015426623473514714, 0.012492788260832671, 0.056189140154709744, 0.050310430402356776, 0.010520222938559469, 0.0712411437604216, 0.029695398895250216, 0.034647119276586084, 0.05258021868705269, 0.03865268276703935, 0.07268054636135217, 0.007730003356212571, 0.13231378799724963, 0.027474640237708247, 0.04084786557922921, 0.04763992450710747, 0.06223733153855128, 0.01660596507961952, 0.041292380436413714, 0.09156685833248401, 0.019398593050878377, 0.058340142676306356, 0.028165505988703623, 0.06750251977674424, 0.01445662305359879, 0.04778672610559771, 0.04592871008020255, 0.009868240937770856, 0.026581027402332234, 0.04369049227886623, 0.029832769951392567, 0.04340319398550257, 0.07545976013305687, 0.07058524226229038, 0.03057248912931931, 0.018105773713379618, 0.06299012400690587, 0.004792269234800892, 0.021197110857634295, 0.021188582383817243, 0.03484025004229719, 0.05192673036588296, 0.016446166799493855, 0.029945790902861667, 0.049863548333486246, 0.07076518099394537, 0.09311152907508997, 0.05366576527575812, 0.022752265513484037, 0.04777912651338885, 0.03141684251116409, 0.19403101095268804, 0.162976058800855, 0.18533139309335142, 0.21798160077343065, 0.12806609092700866, 0.15423173205025736, 0.16584286706582194, 0.1798911422731415, 0.10028300836922661, 0.12854206135436413, 0.1971026404850906, 0.2144136075531283, 0.14036675103970114, 0.1982358377426863, 0.15423838169344012, 0.15192292690757783, 0.19098107703030112, 0.13538537156437674, 0.1720008809840487, 0.10234851164803391, 0.19444233888099272, 0.12517275303722392, 0.11813770634152236, 0.11896118957308993, 0.09260652391540428, 0.28711458547942104, 0.1299577305514005, 0.10730401267327609, 0.1708982659563903, 0.11836942495597948, 0.1314360810624015, 0.1465399794641041, 0.1384993810807505, 0.2258119693086032, 0.19598202239121162, 0.13830576001876785, 0.1400197898187945, 0.11593705749199276, 0.16411480253502247, 0.09115319383601028, 0.07669303911708056, 0.24281274737609973, 0.10795847392610966, 0.14582095998189143, 0.1755402071942245, 0.17066335275528893, 0.12838751077651978, 0.11602023165793189, 0.10864242956402803, 0.09281716745106444, 0.11128047631392557, 0.07176635831954979, 0.2494680902530109, 0.31898105456944437, 0.13077197476260125, 0.18399483013537624, 0.0655771799445633, 0.09555330409878686, 0.12320778347671994, 0.1591474731122294, 0.1681979285973695, 0.11127871431169972, 0.2167721624456106, 0.09781360055410093, 0.14060471327074114, 0.06625882199695034, 0.12654493142279888, 0.1813641608121895, 0.12260848821531381, 0.15239996985802728, 0.23653730750083926, 0.16326530295754635, 0.19183267568868978, 0.11650833691800795, 0.15863983261008419, 0.15242347343554422, 0.15517742162750614, 0.09995427238003862, 0.12341690249741079, 0.16164865825445424, 0.15523667086757, 0.11534999665473739, 0.16855382240347325, 0.20903407686179687, 0.16623144218277547, 0.13486987100012843, 0.11239493506089335, 0.41290180997983106, 0.1351676953415717, 0.18001311879244544, 0.2676098337096553, 0.20307043477171854, 0.14783428501217596, 0.19724620536210077, 0.13843447811180545, 0.15721824921427235, 0.11745765775201783, 0.14955819734642584, 0.15020420864945458, 0.17152563067934207, 0.25707633925541756, 0.25150940813604866, 0.23741113803079053, 0.10507760794773217, 0.1181800939863728, 0.16683838300166592, 0.22557543200110236, 0.1188039193831144, 0.16899262224474262, 0.09219896513968708, 0.0633930517811208, 0.10947342811813278, 0.11813471859861767, 0.12778528139836368, 0.18486755749871656, 0.08633357382589772, 0.10804233757118065, 0.1482222319370316, 0.12972107066983177, 0.14503251761198044, 0.11941285203060797, 0.15882957726716995, 0.19332401905088656, 0.08853297395211074, 0.15749915833434752, 0.149872140177796, 0.10892587443513256, 0.14740829416100057, 0.12263045195610293, 0.09542667742578254, 0.21234277996324727, 0.12392598324485364, 0.15724670171978014, 0.1814037828796333, 0.05925169154520958, 0.2028589332175832, 0.12330094742919169, 0.3160249051307479, 0.21862876120834582, 0.16027247322903526, 0.11343872219684625, 0.22559672924539736, 0.12120548245166579, 0.18415037662752215, 0.23402665351187033, 0.13303787898152106, 0.12397359560934768, 0.16864976725511013, 0.19268608231457973, 0.18431891597086386, 0.167056028580954, 0.14276716497636613, 0.1321083538594746, 0.14022802783837243, 0.2137579282204951, 0.1080714489123033, 0.20131995450825463, 0.1310585682550746, 0.15324525595191987, 0.19217703221065385, 0.17403095269635802, 0.10960997562975654, 0.08219381854418786, 0.07690656314333601, 0.07686898653065005, 0.09755287018995132, 0.1213951581608384, 0.15316094031497357, 0.16707890396637304, 0.18300985556937036, 0.1306313823067373, 0.1629849913860521, 0.15401174224192096, 0.17893327189789665, 0.09263188142569796, 0.1489301584661007], [0.051724927484869, 0.009383461456896077, 0.028420054023304296, 0.04266945412382484, 0.05007519544432721, 0.04502835375587306, 0.04938106998921402, 0.057635456699156956, 0.07101529337946447, 0.021322475400783365, 0.06390459933167984, 0.04043383719099145, 0.04128894070163369, 0.0453262968409446, 0.024784767639733134, 0.014890046872859521, 0.05041723071988072, 0.08051000325189483, 0.06488302767637276, 0.02294684993103147, 0.03816447408509351, 0.041949768145118034, 0.04350098893947659, 0.041552842669789834, 0.032264582001634186, 0.03620630738535716, 0.023153881362128644, 0.022954110529333837, 0.01982945239081258, 0.020379819531714725, 0.042937171209843895, 0.04645145783621458, 0.026341094410107024, 0.04255380932121508, 0.03817676979627821, 0.04124476807191968, 0.08121767697194893, 0.02866278515167294, 0.033754868162495476, 0.06599654413519368, 0.06362034240737557, 0.12718770983478717, 0.05665812002975614, 0.010992833112757052, 0.013766531051406938, 0.04643754567950965, 0.056558471143005364, 0.02573069853467807, 0.06395206996990789, 0.012493298666912222, 0.008657721468367645, 0.07772061583255568, 0.039450957875458464, 0.047802653073543505, 0.03396941491612985, 0.029128744725077867, 0.007042380072356713, 0.013960434608311664, 0.017796682133789987, 0.04296148684056055, 0.042944686532381086, 0.06675781336643043, 0.016869365260185256, 0.028152133923985308, 0.049996384149116856, 0.01628021491811641, 0.07227029095614149, 0.027441083671404954, 0.015528131081091781, 0.06316517892804357, 0.028227716158594818, 0.06950846738031796, 0.04078099759475839, 0.030557069694623355, 0.02368464048260883, 0.014590720999084655, 0.00654885713424113, 0.04493012979266144, 0.060426395446542776, 0.10039707120027273, 0.03332785075350154, 0.06140811413887048, 0.036293537986855355, 0.03733260219075507, 0.05793135815991029, 0.07395111850552982, 0.056595055671829375, 0.018413865548228065, 0.04501748679866714, 0.07920737032808604, 0.029201276014528932, 0.08072421675728214, 0.034631667283153346, 0.03400938172313956, 0.05159805566372891, 0.033493854345813874, 0.04672137742501594, 0.01973756780517438, 0.044903902772573695, 0.019191647804672682, 0.12581995943741453, 0.03712960038213961, 0.026957846900087692, 0.013795447997718811, 0.015386028474407091, 0.009663912839436484, 0.020161467236316493, 0.043423495315496004, 0.03222413255923218, 0.01441980486795787, 0.03222247014843649, 0.07333059494774188, 0.0435354782178277, 0.07857507965978115, 0.025872034095828573, 0.05598258369812562, 0.030035610881543932, 0.050787626570391084, 0.021329276346331163, 0.045834937087831, 0.03891686435728785, 0.05190929803516596, 0.02988169424145693, 0.035261318778559085, 0.029446621417939186, 0.021862613352676554, 0.104232429106149, 0.038866379163077766, 0.009976126227317559, 0.02504807014408852, 0.03256163642471356, 0.047545550135715355, 0.0378977146089798, 0.052542814444149696, 0.017844892046864957, 0.05549454355552312, 0.049360450732732014, 0.08441483001074485, 0.018835533748290712, 0.0643057574427897, 0.05159072037185392, 0.009346161593472766, 0.05989859534067012, 0.001167180558813045, 0.0043434355569432585, 0.08040982193403667, 0.07773723994051257, 0.0643958340609266, 0.027433409385623473, 0.02491694078930924, 0.015465228559239017, 0.040441364004847505, 0.03098042711855904, 0.06551184030550142, 0.048208733299566854, 0.05683360779057107, 0.07952345054476492, 0.02488322909020128, 0.0464664769899701, 0.03703410369193843, 0.050340338474920684, 0.017842235636987516, 0.034398676962741924, 0.05308260382603734, 0.041812963994039644, 0.019657821882696404, 0.028988351452074228, 0.04916765321526797, 0.06005567783910421, 0.027472087249700582, 0.026882172734927268, 0.01448882747471573, 0.08634238383702694, 0.04047015741948159, 0.026393759124461683, 0.043662748404688416, 0.009444081994344392, 0.018881803543697444, 0.030486241035584002, 0.0435397376666867, 0.03357551165766293, 0.06051097155338334, 0.02914672672388054, 0.02775961345422172, 0.05806885179012053, 0.009747012311802998, 0.04805463088315822, 0.10352145354714125, 0.018050636450249343, 0.008689878966599222, 0.026801823518208923, 0.008329493970039391, 0.03125004793306993, 0.009125670955155887, 0.04457538894888374, 0.010769760758135348, 0.028226231863241524, 0.019676744254426132, 0.022369196653486263, 0.02621027723615689, 0.006008895861375476, 0.08044117025189823, 0.061870379253260555, 0.08328313428548076, 0.01814145617367279, 0.033584268042637457, 0.020008109840414217, 0.07279584259395638, 0.03381455790311579, 0.040681344877567985, 0.038086321625498035, 0.020507566608308304, 0.017561579325927362, 0.03359520777819618, 0.031150885512151068, 0.034402338863019986, 0.05090220268034647, 0.02962002350438026, 0.09138534912058423, 0.046153997386535334, 0.03791976644988022, 0.015449552485088428, 0.011588939533178366, 0.02304199613600729, 0.0532832422534064, 0.00575097895512778, 0.06557184031173106, 0.049042279096019846, 0.038173502431281155, 0.017239533199538148, 0.030856020185315323, 0.04030878099823191, 0.03334149094899336, 0.015008374898424073, 0.07916339688123235, 0.031052596431465882, 0.015161788793310765, 0.0392157765435836, 0.01566208825792156, 0.059404855503910975, 0.012327356361633828, 0.009873252110405555, 0.06977528048258635, 0.026412476567671667, 0.03701768259728148, 0.01646657921223631, 0.01926173910408491, 0.016919002012019197, 0.04712275770162383, 0.06181524390535009, 0.07351082479280811, 0.054320146089359644, 0.025292318126547243, 0.015867209257257563, 0.0517998279012259, 0.06181896326222247, 0.07224511730694963, 0.07013967020377036, 0.07638632049483639, 0.02773877011702186, 0.048869315594915426, 0.09435150366757186, 0.09701401926577093, 0.06992193269393138, 0.020773567657376972, 0.0662356018719654, 0.03367099685654525, 0.07212833486377232, 0.03339763370252425, 0.063746988232578, 0.058463727980251276, 0.020421557917049336, 0.0522602352523996, 0.026402764488011602, 0.05327574225262769, 0.06471333920114464, 0.09860309246446818, 0.03682596909423028, 0.030419905482220556, 0.01487140125039244, 0.020490875467658043, 0.03487753554157192, 0.03470885447196422, 0.04512200417417673, 0.03878970908361577, 0.020269138978854306, 0.07208053097729722, 0.08403720229022926, 0.1134654356827659, 0.04093897258562427, 0.03333505964086902, 0.08860932993552378, 0.08003014875876327, 0.02916920374357893, 0.013554149453768568, 0.02995814981630012, 0.04710229166272668, 0.019219046939284574, 0.05528406472876669, 0.03785849856813589, 0.062377131093413606, 0.018267081186716116, 0.06016689082307201, 0.02084570249632722, 0.011328949401485584, 0.009587496526599413, 0.027375182872938535, 0.0241238157069611, 0.04254450901381431, 0.04653765421901499, 0.06427901331335306, 0.008844243768121927, 0.028510088506605358, 0.03554588596847269, 0.015456710619130924, 0.0432915558227368, 0.026052250534356124, 0.023176412007981734, 0.022008413291205804, 0.0057608710654500515, 0.020367378263824412, 0.045744128855726415, 0.056656649140941526, 0.04187050102759273, 0.055265602009791526, 0.03152470960612259, 0.032684501606009664, 0.008205606061364374, 0.027378902229810917, 0.016719505055657318, 0.07336100097745657, 0.07719399933252605, 0.03613445982937852, 0.08961084433981488, 0.1540610170172107, 0.02481174542598667, 0.08923491733449121, 0.033645091593385704, 0.0582639437409178, 0.011227201433822272, 0.012976072912645197, 0.020573467406774723, 0.031761886597040205, 0.08063365750375294, 0.041788564093651316, 0.06890027017723169, 0.03408316748156663, 0.03512251513799833, 0.039039047720331344, 0.033224371427129355, 0.02680211846205977, 0.03947955210723224, 0.11553035673475075, 0.10724503156398574, 0.1596406498743642, 0.13164511581342067, 0.13562236852463216, 0.1788618878251122, 0.1531949546188116, 0.14939226270202668, 0.1484907763980089, 0.10555864221626714, 0.2232747933556957, 0.19288560225357934, 0.07978534536255945, 0.1093278177863648, 0.0957540651002238, 0.11685341356262086, 0.21553151369575532, 0.1642935308477571, 0.1852951877780499, 0.1364708875095652, 0.13190820572837708, 0.14310611291758477, 0.08231292223377575, 0.1659771776007068, 0.12979283778657838, 0.13065678578230644, 0.14188351319922557, 0.12427669829658924, 0.11737364855024124, 0.14539944308419384, 0.09359316089220586, 0.10611142061891095, 0.19134081659778474, 0.13624935020362178, 0.11728790798975576, 0.2721115195703122, 0.15730372930486358, 0.16801779068285422, 0.0906536508832247, 0.09125493797323397, 0.2402867563068867, 0.2435145452017746, 0.1357121999946333, 0.10273476551857688, 0.1549600518398708, 0.13224723027838817, 0.10519205382274044, 0.12085872041361949, 0.23356157685479811, 0.11007387251142534, 0.10965903590042746, 0.17915068765080747, 0.07444661651407519, 0.09028151601312623, 0.07081123053907387, 0.10902722786751487, 0.13412575447751632, 0.12050352374752685, 0.1713190474096806, 0.1262803936016656, 0.2749648293660533, 0.17585551366209987, 0.12766410161050099, 0.16532335220085037, 0.18382975350945227, 0.08662425056700745, 0.1846808618715694, 0.15666174762431653, 0.13377606598359923, 0.17858344550815322, 0.08279551932167623, 0.13370272072572864, 0.16293000159484727, 0.30685094095045523, 0.28986438147483334, 0.2491514507921473, 0.11092831335601308, 0.15867121157146272, 0.15361751339608623, 0.1315733027313986, 0.21769650881328892, 0.14079410552738175, 0.1762443186054307, 0.17765787339979605, 0.12056462692036746, 0.1847512500300523, 0.1587540409978359, 0.15982068053657011, 0.1102171539359035, 0.18382858905580737, 0.1240073724259292, 0.23011669396392762, 0.08725521590320334, 0.1641895114293983, 0.16596968526080733, 0.12421011759509003, 0.2362185996025801, 0.10087610597932532, 0.21364362790219246, 0.1723180567064593, 0.29106560734010517, 0.1706208195537329, 0.1311024038061019, 0.12261695348687711, 0.12151260710050985, 0.11054044303994988, 0.24098090857507723, 0.14200863067901906, 0.1152436176855718, 0.08737469497587412, 0.1872125219914221, 0.19921187972349508, 0.16259949594255418, 0.16369264212346848, 0.1075496894097136, 0.19557300804843827, 0.19617593456660548, 0.09992719883279455, 0.07046135818405498, 0.09719552081679145, 0.11946764263895251, 0.12992573871968255, 0.15178368276646062, 0.14121027513136789, 0.1529051435570563, 0.16269180953742998, 0.21263660532572579, 0.16239012411284834, 0.07906294743260069, 0.08407199800375008, 0.1481321553188947, 0.10622755954823188, 0.13333481466097216, 0.15397846338249024, 0.24130065835291342, 0.2316055092359743, 0.12919565692784327, 0.15753841267958765, 0.10923386476333104, 0.18311450317982705, 0.12975456403388133, 0.11379873755598262, 0.08548045831341898, 0.0570259188422032, 0.06592036435200323, 0.14379288009818525, 0.14059501459761975, 0.12692180837714864, 0.14393321208415494, 0.08544427598075521, 0.1433971650417774, 0.07926622120242927, 0.11990304871071732, 0.1710626684249409, 0.13396389542087433, 0.16484712130360066, 0.1897053414535138, 0.2190176427604691, 0.19631545449937546, 0.07644606769205102, 0.15863946488788053, 0.13981391135002338, 0.20767378049992746, 0.1345105604418824, 0.13320384426943718, 0.12799613943864263, 0.11280635491974893, 0.12950475808353196, 0.14027036185706818, 0.18103694933797085, 0.1924710414342342, 0.07459984175981053, 0.15764186519288248, 0.15557869848224426, 0.16809922582920522, 0.17702425739938216], [0.034428703778934096, 0.03928723722516049, 0.03264684838453128, 0.054026247948528304, 0.08913509607795747, 0.05561757344572295, 0.014925258189079263, 0.020026564898510135, 0.07407579165432723, 0.03995156952089841, 0.034015935605331775, 0.026253113042443033, 0.034268472659131216, 0.028567008839379397, 0.024302365904253338, 0.06465957515061864, 0.030995406052698533, 0.03768248986753245, 0.04252421534470013, 0.025546944685160153, 0.04757035606270356, 0.034421199947715767, 0.04892945349697144, 0.03995039740637426, 0.04666686643876376, 0.005990629452430914, 0.1449966800188826, 0.04416638609742926, 0.03643359801161193, 0.06481327537086702, 0.014826947083366255, 0.015076235924366743, 0.041753680280019204, 0.021397507967307203, 0.02599902849103655, 0.03818116714096358, 0.042953668913293275, 0.03347356833757893, 0.017905221470902045, 0.06300084157696655, 0.029878223863159938, 0.0747010266528495, 0.0661233316866621, 0.0639632242100854, 0.043891781880970926, 0.03060695925547231, 0.027240789983601823, 0.021533998022336635, 0.021871680003260414, 0.02475512003706348, 0.03648047876213828, 0.011905345337225065, 0.034293454786342, 0.009870998854298266, 0.06494865842884587, 0.019496759557495677, 0.00937636939793705, 0.04234097094365186, 0.028576617497169686, 0.04219498139836135, 0.0685823819930515, 0.10654419134821623, 0.057927056576215455, 0.044527814888785926, 0.02327216725285736, 0.03172048337517246, 0.03933084678025015, 0.07208896560534354, 0.009331548466317115, 0.03472015809928698, 0.09364280338969924, 0.04777386348934905, 0.03980418952602533, 0.11990658037604825, 0.04688618975060602, 0.04892470758228053, 0.0395002709551444, 0.028293758683327227, 0.012667381613996002, 0.028846717116633253, 0.08188508511070283, 0.05570843147354261, 0.03349573892210761, 0.03317182928684258, 0.027369724496478037, 0.047537785834602775, 0.010022862378748195, 0.04517227869420763, 0.016869438038538062, 0.047709837691077304, 0.07554318710801101, 0.07380969101382841, 0.04850136739532313, 0.01608689071520442, 0.0531743198723322, 0.006326158247482513, 0.02297755856547625, 0.02398020294945567, 0.034014924369271726, 0.013362099829640602, 0.04482453989405786, 0.08157167088000045, 0.05096310283988715, 0.0647180583027582, 0.053390659271709384, 0.018787907977258007, 0.016607838164594386, 0.04798790462495339, 0.032070673656679934, 0.04811623584358923, 0.12468587351782669, 0.029202762225102034, 0.0058986108014059645, 0.03176572278232104, 0.027735544886860638, 0.04488795282199018, 0.027460639980892022, 0.03585286889105074, 0.04207464813765499, 0.07873507712276713, 0.059398163725892385, 0.046297003019360766, 0.045647414085725625, 0.032230161671196265, 0.042122593750396085, 0.010309524819134705, 0.05220297784093888, 0.027008590648972222, 0.0645699735069948, 0.03685293921960458, 0.025337231946327997, 0.0233664573545778, 0.010301979810690448, 0.04343228617442712, 0.05287954456082756, 0.016416252981270515, 0.04949327888748339, 0.06030872434137329, 0.11897645770542084, 0.039861205619789904, 0.030394915694130525, 0.014680358074274997, 0.025303386181833285, 0.02830868207609221, 0.029902893809541583, 0.0064229659056441206, 0.006195393742077174, 0.0482475241616128, 0.007700914518922688, 0.013570773561725454, 0.04081014724027726, 0.08688586193226999, 0.0164799646834933, 0.05748547200534133, 0.028923787477035678, 0.03767598961149493, 0.029449750887109872, 0.020158483323851423, 0.035284197994417725, 0.01950831982427307, 0.024237560611518643, 0.025092574106829784, 0.0824854452343237, 0.06587600020030815, 0.01797436665172779, 0.0850113750165028, 0.019899053393953273, 0.046701160364694176, 0.01588800184113244, 0.035108679590085824, 0.055905239461290265, 0.06933595204064924, 0.032205918818832405, 0.0010002826186997307, 0.04485313412583163, 0.04376726194975838, 0.06017913290810201, 0.005629083832665797, 0.06232177741044472, 0.020330217253837376, 0.10575771782427065, 0.028270019533773585, 0.022206466171830412, 0.04599880712527422, 0.03509641835285771, 0.04962808737951902, 0.005278108789840894, 0.06466948066747959, 0.031044276716608196, 0.04429348774494664, 0.08819886768657355, 0.029329147580410206, 0.05009364667198351, 0.020161279544775045, 0.010629135743534614, 0.04783273351589038, 0.015831230895503635, 0.05438929701584482, 0.02545048463939419, 0.02551148247514521, 0.006491015101933191, 0.01896998792466137, 0.03172896971415368, 0.02674965101534561, 0.04429988074867476, 0.011524927141445299, 0.006399551864653345, 0.008307731327330394, 0.04018689640947888, 0.011409288084494972, 0.02650646597988183, 0.02799923809605741, 0.03075934755015037, 0.046581183334872614, 0.048028204680210164, 0.022237140332318606, 0.08092307786066687, 0.050516082875190244, 0.042768516953313546, 0.041145820155619614, 0.019634262763804967, 0.0227130992683552, 0.026173798044422464, 0.03606164317217565, 0.03038470757253949, 0.03381225963934295, 0.014926472438439248, 0.07602039859780381, 0.04708120509261086, 0.01623094780370593, 0.09004376062582578, 0.028988745987355232, 0.07728714796323931, 0.0323532298657923, 0.05454401996347213, 0.054058994376851674, 0.008555044619096144, 0.02624608227051795, 0.055252869628489985, 0.04185785674640248, 0.06898830134061075, 0.019522101746030876, 0.05727747530345956, 0.05582936994370915, 0.009531669784337282, 0.03431223926224536, 0.04739917754646271, 0.014366701568266558, 0.056780108040378946, 0.0700954516087809, 0.06138326607704644, 0.0447443304883857, 0.04669513891360933, 0.06569085207076804, 0.04544731958078281, 0.07821530944878057, 0.0432263196055447, 0.02476021260654013, 0.010825480248088078, 0.06723877102617296, 0.06850217258737934, 0.051865902984695095, 0.07160613103018654, 0.04417842133871971, 0.06531212884452074, 0.0015573557222171898, 0.04539670798206522, 0.05442053042051773, 0.10865914560253583, 0.060465320373975465, 0.04161930079722116, 0.03094740106814331, 0.025211333056851744, 0.04751956060288414, 0.050581598714474714, 0.018804871079121387, 0.020327049480270476, 0.07852899947113569, 0.02558637523062287, 0.06767575523906177, 0.0601482940387101, 0.025651745513201724, 0.08009089953115872, 0.03121994450808533, 0.016799498041490876, 0.04982854577622587, 0.04556025243214062, 0.031503086774459774, 0.03013915532538968, 0.0033126027283874615, 0.017710903268908302, 0.014863021206110718, 0.0069363563764660114, 0.04849147336978105, 0.03802096666467767, 0.07619872854481782, 0.03571855069528665, 0.03322040692212121, 0.07933741375323265, 0.03160160185108262, 0.011702201802343612, 0.012391938531260579, 0.1243094945206277, 0.03217869971488272, 0.04038227181280813, 0.02421898297935484, 0.03339498686874586, 0.006144023716314546, 0.04805001903385405, 0.025378876485891884, 0.07551992867862986, 0.026839639533371217, 0.06273373736128693, 0.05036728561765725, 0.02185184215646117, 0.022212750008029324, 0.04958184248196983, 0.051396275765352675, 0.06312286023110633, 0.05328557116069621, 0.021237949089657877, 0.027036757786728205, 0.021138045478672273, 0.09227693756862033, 0.027917333720852772, 0.011774870030011141, 0.02167011460950298, 0.06705040532735086, 0.01832688009486564, 0.05088078286198359, 0.04562471107008957, 0.016598003510866436, 0.014375665754590546, 0.06527796132309784, 0.025326213686757033, 0.0361507085542525, 0.027936976215231325, 0.03332959360352928, 0.047434635926038034, 0.026747808573887717, 0.028164833746550065, 0.0269110829779698, 0.0599996576596412, 0.10202044215534004, 0.03571696106284376, 0.021203936701039636, 0.019190738075262597, 0.05332096825323759, 0.0165251370579485, 0.01981385867111385, 0.07407779114380961, 0.01983202070057873, 0.1321557134149536, 0.09178726948917874, 0.15371109869691635, 0.12138244110129534, 0.2142692306229184, 0.15882108901296893, 0.09367436621217959, 0.11064984039553713, 0.08398862465495065, 0.1079989463511494, 0.14470002013108424, 0.12787836108116374, 0.14134616380737675, 0.125026261704343, 0.09481949911963555, 0.14338752765568996, 0.16961013507698813, 0.169172162610677, 0.105178693249341, 0.11121289969812478, 0.11370967217390576, 0.1371157803242245, 0.2002447041412515, 0.0809451871581616, 0.17877766411871682, 0.06285279891603897, 0.18515804271784522, 0.11472919730529671, 0.2820869649369871, 0.15724850968728143, 0.05495571561398045, 0.10018210692871964, 0.18995700133663995, 0.14451979028601802, 0.12975528415653015, 0.08964143423063141, 0.17434854210624773, 0.10570449003529166, 0.2022040199728743, 0.13507320605699094, 0.12674920110692903, 0.2204323160432039, 0.09991054408132069, 0.15118090946587825, 0.11412755781484228, 0.0990856589088517, 0.13791706232774642, 0.1445970119487855, 0.07385731870008093, 0.1129888677068295, 0.20355876985817187, 0.10216305708332409, 0.1164760769555165, 0.17042002790877897, 0.25264403031718347, 0.11298423287488761, 0.09932385862714822, 0.14626878433890883, 0.1845356422446428, 0.13260986565822555, 0.14177589316762265, 0.23049046826218408, 0.2606908952997577, 0.1824891762507539, 0.20258182389361246, 0.16087780526328474, 0.12582578170563907, 0.29972990854613246, 0.16735849541521844, 0.16879788269439053, 0.20914643131677182, 0.2969800206201692, 0.1589766814703903, 0.1965786210231243, 0.15106296256905602, 0.17062106470186866, 0.2371808673225103, 0.24221139899905653, 0.09836817160248758, 0.15248802400404407, 0.18784088262867546, 0.16207385237418837, 0.09339183298570496, 0.10993141846190538, 0.28969516797411826, 0.1490471707356553, 0.1638491079211235, 0.13037642824553675, 0.14723638403079203, 0.10556476325878214, 0.13884994291490124, 0.17499429293938223, 0.1969718845981744, 0.22375909881966732, 0.11887741785856987, 0.08176111676279577, 0.1393262350991849, 0.11774353878272158, 0.16586964949965477, 0.11821236927062274, 0.1862541000328718, 0.17594952797216756, 0.18398441133960602, 0.17074734663530705, 0.16614409283764903, 0.1304739972035731, 0.17073102896251988, 0.14766465782398178, 0.11861693264255602, 0.18980844156636348, 0.25688400522114774, 0.17236057458625687, 0.09832367721584537, 0.07191634301336543, 0.12857644338040583, 0.11000025146190198, 0.09563296192115354, 0.16656793864263644, 0.1083855832656545, 0.2460803728430502, 0.1594145160408751, 0.12965941591368568, 0.11291415115157444, 0.1152184900016554, 0.10625834862190871, 0.10608740376248475, 0.20847653339226402, 0.2159740367243367, 0.19997306468506015, 0.1765661521424209, 0.16801017576888685, 0.10994683981182114, 0.16594864848640659, 0.1983822218232578, 0.2026707667016214, 0.0949078826834598, 0.15072683383139873, 0.1018980366267985, 0.32767244464447426, 0.1414508727048674, 0.06891539275285698, 0.24398095485183502, 0.11449686582050017, 0.15556253402704195, 0.14615163417352786, 0.060985900101161776, 0.1283333713429109, 0.1638199659364839, 0.1362703103692301, 0.0767266933595942, 0.10261402240083103, 0.2758402533588871, 0.11971412376771051, 0.113711288619426, 0.09410509914760629, 0.092208365038518, 0.1395506682174821, 0.24362987207789577, 0.13713116336974407, 0.14838131775538768, 0.0949194812546334, 0.16032658968000643, 0.14480800788489082, 0.2430357249273408, 0.08249690590967095, 0.2464108784953433, 0.22807306249535855, 0.1988571656927947, 0.15943060388728497, 0.10975118095595991, 0.12349595511031729, 0.181326377355764, 0.09393892701595061, 0.13724854336150233, 0.1543811651607675, 0.12005776016702575], [0.03929227042282301, 0.04062039109187261, 0.03462541217525159, 0.021067442815570582, 0.13958820652577186, 0.05115008958044553, 0.0009780431461084876, 0.016974499336473884, 0.07371723952312624, 0.025966755122006423, 0.018352471261976228, 0.05857189576472006, 0.024473565487912106, 0.058970778594694795, 0.02386586432675681, 0.10287476808673914, 0.014256680808630923, 0.10077747981995346, 0.012119885387590096, 0.014326627508947446, 0.02795378035385042, 0.021331247107516375, 0.02148793890110908, 0.04079362272375053, 0.055598903883008234, 0.029101889512892214, 0.017912849791408066, 0.04168762434874812, 0.08411162773207312, 0.08894244794763866, 0.06015516201695127, 0.04816107113935775, 0.002495587194120632, 0.013684174684326977, 0.03290236935079579, 0.018553772355399786, 0.0699147238065639, 0.04436731180776993, 0.05896685239408286, 0.022530687987924587, 0.03979840939263663, 0.028280859677902156, 0.029643429405686837, 0.060052598165648605, 0.055871707792844505, 0.04601456172343704, 0.028318194972891963, 0.048839032139268615, 0.021512446053806814, 0.03410932172330157, 0.08649442164647965, 0.031052613668444178, 0.056447093450133844, 0.04774690868573324, 0.01087515817714795, 0.0688873692565868, 0.11118318314754194, 0.04620760438903686, 0.03046908641173955, 0.07481783207866453, 0.08953251951043645, 0.037361801631989024, 0.08296832577475617, 0.03550862345183569, 0.022794430992836436, 0.03126016029367044, 0.0844519776141932, 0.016475031077260935, 0.04531903815786204, 0.03749990813253868, 0.053647662618107377, 0.04181734601696653, 0.03221285191454715, 0.05184899542420622, 0.03666606356179522, 0.04587095854203067, 0.053443358460020636, 0.0829976439596184, 0.08384639277092873, 0.05154743640413208, 0.035887534369624434, 0.1673970602813267, 0.045113987064049135, 0.024734462476185253, 0.04275187752359817, 0.09703960660244189, 0.019634998208212278, 0.031260263715540214, 0.05279659256038647, 0.09268380686520569, 0.02719434973363194, 0.09505734643748692, 0.03879299943125056, 0.07968520234909751, 0.09221616381358716, 0.03703116574474881, 0.040792511896260326, 0.03334620238972768, 0.05292428026516592, 0.021484924345127037, 0.028570877583397013, 0.014450999010624665, 0.03338193273051612, 0.06188022731352718, 0.04890169047059552, 0.07275481858561117, 0.04221942726402514, 0.02013810155462594, 0.045090391555981296, 0.0379083440789292, 0.023075661869839798, 0.029172674121875918, 0.03236831413702138, 0.006300057631902277, 0.03825717455437107, 0.04578375475360982, 0.07013348021334218, 0.013059971031672774, 0.08136754675257592, 0.056330816624986554, 0.018612690262436386, 0.07620324846357107, 0.025827028345496907, 0.09419620232356173, 0.07441978045408765, 0.00733684320303221, 0.06509207008827118, 0.07264722153664598, 0.03745997196904594, 0.01713410034895905, 0.0618221003922724, 0.03385407271825018, 0.06807648817137366, 0.06499768039512058, 0.03756919695485023, 0.04083980250382616, 0.009202237612748099, 0.027697644602026672, 0.04427538125685627, 0.03758681697710868, 0.046466840881734126, 0.052198699239881775, 0.04026546638699309, 0.03314982724165724, 0.06959665942216112, 0.025273039523932724, 0.014280979202369289, 0.025015875299070633, 0.04894204798244661, 0.06501836476907616, 0.05084260487027707, 0.0811104323234289, 0.05361372109262213, 0.08698704682530896, 0.027032247444074002, 0.019198960113909938, 0.07157817648182954, 0.013958092294483176, 0.009025684032108515, 0.03396836537567358, 0.041028474637817954, 0.04006864307748695, 0.010091262539067577, 0.04432315833025402, 0.01843414581080358, 0.03528172736086192, 0.004500246572969181, 0.03747118366581779, 0.07737075113841603, 0.06901015016821123, 0.0708867438257702, 0.0481380118928369, 0.038150646198060245, 0.07614672649651766, 0.05323262682424919, 0.03303017196876388, 0.07402863894258777, 0.0028488849197709637, 0.11815626099104844, 0.026895517986568234, 0.04916335546201275, 0.09438039284319648, 0.05641196065792634, 0.021696006466123848, 0.03824435407295823, 0.04180455234863105, 0.014819051589696638, 0.11734088296971976, 0.06300495163868032, 0.04888211309369053, 0.0681196648867861, 0.037295312861040715, 0.021845462559271726, 0.03568999476790909, 0.006715538235561502, 0.015897145100508728, 0.038277659745466326, 0.047295725033167875, 0.05648984498674831, 0.005601714383960972, 0.043720101577139674, 0.016317228456178022, 0.055177570846412456, 0.04628453110795348, 0.08160540939218576, 0.05432120712113477, 0.045090996765441475, 0.013629617732799342, 0.029720972825382507, 0.010809843435943609, 0.022021871540815603, 0.02685989106764957, 0.019499513643583464, 0.017073485557170167, 0.056459209130656336, 0.03584653717435656, 0.023007026137483698, 0.05454911061772897, 0.06770849017606628, 0.06548374020043882, 0.024504253054938974, 0.033325357137308005, 0.07796448460149188, 0.021835164422349587, 0.040719063216519934, 0.015260037654379924, 0.02814015613928918, 0.0780163334322072, 0.04835951472482374, 0.061395213218225594, 0.026408971715418082, 0.027064788943877625, 0.06282030912717024, 0.043899262729551525, 0.03354762605721912, 0.05262941302311036, 0.027689186991342617, 0.008624956845456075, 0.07403141218087367, 0.0248594114166354, 0.026318900842940616, 0.02960191510107008, 0.044051151151858994, 0.03532051439246824, 0.054470950497254256, 0.04573114366540986, 0.12365907821203433, 0.06148616700703579, 0.0562689550251009, 0.03557388648210514, 0.03188871436812465, 0.024360510062486417, 0.051498502537968664, 0.05347860999585641, 0.03161739666886147, 0.01718029736601297, 0.03388908676682942, 0.17858880812362318, 0.048571184818302436, 0.0073228726321230495, 0.02057906367906159, 0.06472418700615246, 0.014905533340248852, 0.017934587536259525, 0.058231120703802, 0.0770821887999773, 0.04384780843411723, 0.031997234553038593, 0.021936125234670697, 0.055067905360051704, 0.07631584806668182, 0.07490711962623943, 0.060826814282805695, 0.05439971964205465, 0.06171754088192698, 0.06771215207634435, 0.04164082786789344, 0.02376706771282179, 0.04851556683499967, 0.010479535051291029, 0.04006822172912859, 0.037359085850297444, 0.045425612479448325, 0.034306830681499936, 0.043078261622858625, 0.03870528236392044, 0.03248952839884066, 0.05372400327976193, 0.01053984915356963, 0.015488218857846675, 0.018660566927264297, 0.03470343056946032, 0.0664940569549799, 0.019772129861878294, 0.01261205187127475, 0.01686063377306827, 0.06188377047017698, 0.024224621386477546, 0.026026228442788128, 0.06249773631533308, 0.029851880014663743, 0.048907895782782186, 0.06891916190544445, 0.03517738618557492, 0.033622085973019564, 0.015824926949496713, 0.006966032228627874, 0.02743624774138293, 0.0785335653551644, 0.06148702885595061, 0.011394630907283676, 0.04177929826020714, 0.060625769828836766, 0.04229209453408276, 0.027307353448122743, 0.015555795473647455, 0.023076046829021746, 0.06482653635283632, 0.052919737363774935, 0.059679662733669245, 0.07643178781314243, 0.07327186664746654, 0.021281342224908933, 0.034114370242722576, 0.04060230758641997, 0.052061833801769444, 0.061291228273823384, 0.043139721026584026, 0.05594084722801082, 0.08564980970996042, 0.025273527904984452, 0.03980947170226325, 0.03610373204273563, 0.04925592569634319, 0.03158158014318155, 0.022550544986921935, 0.019954738409949407, 0.07463893522658656, 0.03870758445813291, 0.023099012229771867, 0.045992276225719726, 0.02242950309488562, 0.030782609809971148, 0.0510871937618621, 0.04393043867763012, 0.043633066328062166, 0.021620738327563293, 0.06356191671183033, 0.04220278400387015, 0.06040764544459601, 0.04537926416002935, 0.0503292991479318, 0.09611053347227075, 0.14754821245949115, 0.18389110183042867, 0.12367063847881173, 0.1879702135920525, 0.21174890860434503, 0.09362167468474758, 0.12257379975410239, 0.10786710261938073, 0.12053514785704114, 0.14485276274142728, 0.17902210745359623, 0.12652458412752998, 0.13679875781939876, 0.17338881779822612, 0.2267062543861328, 0.05118922901249701, 0.19247599036222507, 0.15191267665115096, 0.13295334883995596, 0.11376876819638476, 0.1372134412128118, 0.2090187091380358, 0.17816041175636554, 0.1973807610451214, 0.10652025110058247, 0.07578343228106538, 0.2081897407169304, 0.1677048897310611, 0.253838591217514, 0.16211560416606166, 0.23445103557840472, 0.1489044025900864, 0.13177219447830033, 0.1292656773641225, 0.09149262441262122, 0.16082280015032138, 0.08292018480959439, 0.16724995607810636, 0.1346271283804409, 0.10691983490100793, 0.1214910876907168, 0.1277729933480582, 0.1414273691273505, 0.19246249189299924, 0.22036517609751996, 0.13562737873965694, 0.07574607783387746, 0.11678746105321955, 0.13073543236861307, 0.1835573939306121, 0.1520948217160279, 0.15248322829363808, 0.21455469030526378, 0.10824958733733624, 0.138297624165012, 0.2760683330557039, 0.1309339717150696, 0.1236429290785905, 0.13479718457787268, 0.21457088540398309, 0.124812247381816, 0.17082668270074552, 0.1456932224813969, 0.11728817612052926, 0.143805397974868, 0.1553380242999523, 0.22996454890216553, 0.12998963045256753, 0.1469702297641385, 0.22204456340161063, 0.25119564916578035, 0.1223748007548913, 0.1943666493940738, 0.09798773233928988, 0.14086095435965446, 0.20257008742661248, 0.15825645156925724, 0.23606233298778537, 0.1965574157093802, 0.2141565697327737, 0.25060266646887025, 0.16809629937333448, 0.08568162534145579, 0.12779021500459603, 0.30647114520111396, 0.09036737148680034, 0.1471852093574501, 0.20528758515513715, 0.17334386375882935, 0.13949964676172505, 0.22852768971314355, 0.1453505819963832, 0.16150769807638662, 0.27221717841682896, 0.21497780066584388, 0.22509889466868294, 0.15865691637079563, 0.1943696371369785, 0.14883836581101342, 0.15691999586359148, 0.13373537139306146, 0.10437792452472834, 0.16292168187998957, 0.24232212934763203, 0.19518717552625364, 0.18075394113698315, 0.1422843304012091, 0.1957547394258361, 0.11284744021512809, 0.10855078246564635, 0.21484217245972928, 0.08058336383152394, 0.10279251322630914, 0.10520963554060268, 0.13454846647237578, 0.1786749317280708, 0.1463920019206501, 0.1717965653346431, 0.15078772249962055, 0.10693357851836952, 0.15853166099517577, 0.07598865191422163, 0.22848460492828201, 0.0925644503666028, 0.12840871609026386, 0.19016048961108734, 0.19014164384815002, 0.07797954589008324, 0.07807051883109155, 0.09266999429993092, 0.1482124260116008, 0.11858661854339224, 0.14930652214154122, 0.2670238377346147, 0.248445316908821, 0.2703433886410729, 0.22925807794015254, 0.1828644827248589, 0.11724578847567882, 0.21441483329380714, 0.11003182194526158, 0.17196852143012709, 0.1655720549845888, 0.18302146946230244, 0.11458134233591058, 0.15505604265678316, 0.23262713344827776, 0.12218257397293084, 0.190596837970999, 0.1915299330627726, 0.24305587303974938, 0.15280201280068967, 0.28022249079039024, 0.08620814991093452, 0.12934866000808057, 0.14226071957138278, 0.23769370190078215, 0.08463283565135733, 0.09449896793211661, 0.09694662651107197, 0.1276716782200721, 0.14802713998623435, 0.07505482903891995, 0.0774450003800373, 0.11707811481169156, 0.15504781487247637, 0.1765463564304575, 0.15891769270022071, 0.1501146376493477, 0.12205877416436711, 0.13766949335413595, 0.1652489037763688, 0.21715401131058895, 0.11927491789984128, 0.2252221122504242], [0.02675557670543992, 0.03535653584666791, 0.009788669300295655, 0.05948109274369575, 0.02662775302005391, 0.05837928210835784, 0.044323139178055915, 0.03293963186743279, 0.08764623484063534, 0.03652678494672141, 0.018538607644938657, 0.03800533464058273, 0.01865534029240089, 0.04161214553600839, 0.024039749048590183, 0.03994088642479431, 0.01701122367634408, 0.017037508153026144, 0.04520969825886911, 0.021721915559723012, 0.012220121289212859, 0.023507599478527427, 0.05620389500813139, 0.03959317060728227, 0.0836639259491236, 0.05649877757194543, 0.037767154074484305, 0.012544252132366021, 0.05495088159917824, 0.027515710211328925, 0.034820450499894164, 0.002385602105453971, 0.03258977100373276, 0.021274407213974385, 0.06008687676982053, 0.021637766546900236, 0.027474521494079984, 0.030893037553816557, 0.07573280153014968, 0.03965088767149756, 0.002608546858555788, 0.04131159775199429, 0.04861994631468289, 0.011799191406387235, 0.034934708683360974, 0.01929592577770593, 0.010767341835514433, 0.07830606022429082, 0.05071201752270422, 0.03707830313472979, 0.06306150041881108, 0.07721600903859062, 0.025399170155006073, 0.053368021373546896, 0.07164522449696256, 0.05594719809690311, 0.13613331852661026, 0.042091149671543995, 0.00611002138260031, 0.052501579761625304, 0.06953296687213645, 0.054211411399826895, 0.028953975171691952, 0.016552436601130233, 0.016189797390853206, 0.0326241415384556, 0.038237382672847285, 0.11770885032151016, 0.06935810730341943, 0.048351773406348886, 0.030903640210688598, 0.016797726463165977, 0.05855208856143779, 0.034959139227266275, 0.04383727472515837, 0.04429214709107915, 0.06213948295842256, 0.09716152949559112, 0.010131380648442335, 0.004905430954926077, 0.06742922048414908, 0.0741646272100268, 0.04548024220932876, 0.01700644328769657, 0.06945360782406024, 0.008455874537298036, 0.04277541174463207, 0.022897960114923697, 0.03715495406199367, 0.07792903771323544, 0.03871277470381991, 0.14299955008731735, 0.044964239857490026, 0.09974324580041632, 0.11453566817386497, 0.044574304934470885, 0.06803879664549906, 0.02225362079878969, 0.06727691454392287, 0.05391061846767703, 0.011289175074066848, 0.06638973876233063, 0.08041690058645704, 0.040457344598947995, 0.03630258931568073, 0.010619531873793853, 0.0689352803953713, 0.01851357380679298, 0.05875022571173407, 0.025325204365916794, 0.04317172434962085, 0.03799876543663202, 0.0435553620299024, 0.06620540268599026, 0.0038184050983193544, 0.07434829678987304, 0.02078435800579046, 0.05453314151494734, 0.0626041382671364, 0.01335537932332485, 0.042249327675709804, 0.006847270405776198, 0.02412349203481309, 0.026175470031317205, 0.04045560557935988, 0.03297579887833807, 0.07005859511874377, 0.04653552832502512, 0.032557384636733806, 0.13705879870441653, 0.056458347281741525, 0.044568582257676514, 0.04087088269091422, 0.026796104671854167, 0.03428441111839587, 0.0534613385436035, 0.0771917010687532, 0.04551178204917139, 0.044405053129359606, 0.09071647009301571, 0.05377528137497364, 0.05522272789910917, 0.02086471105294843, 0.11642937623565236, 0.0028820589209170716, 0.036898322268238956, 0.024308592283857927, 0.02500146901565454, 0.04071587246031531, 0.04111599252228776, 0.025488492176537553, 0.0024458082372157447, 0.03949474746121034, 0.04805321745093792, 0.009574580284196043, 0.07288682319584393, 0.0358959038801972, 0.05942460908103855, 0.052112414756970066, 0.05085101268524605, 0.021107162559224714, 0.009810207862286799, 0.08907789229265145, 0.015527378399706176, 0.05051117608203523, 0.03316723658973652, 0.054153004856479746, 0.012755103469375643, 0.027484465315337145, 0.0805296840506696, 0.07767027619505122, 0.031635551037447106, 0.056171631215200316, 0.022937340864671335, 0.03779569851054299, 0.059456386408137704, 0.027096114279101455, 0.0349982671679989, 0.03063070032024576, 0.04024033870307669, 0.10219664237792454, 0.04180025842581545, 0.022317885999537768, 0.030538440351524664, 0.04780384817070538, 0.03283879171395975, 0.022587698336029728, 0.02451260724375325, 0.041395308179480415, 0.039054239243869825, 0.07903321556025937, 0.05618009265632399, 0.04469777915566679, 0.01662451398348616, 0.05025521461521426, 0.024937052512541417, 0.04682912003068675, 0.030056444642644738, 0.04850861841752645, 0.017657501194926522, 0.025513273205668218, 0.05822123816957878, 0.04643167361557003, 0.029283278065943913, 0.0033086097344846256, 0.023424992217652263, 0.07522562834163828, 0.036126676376067826, 0.10096626686713389, 0.02228312667519335, 0.05911265807827154, 0.04352231299684894, 0.02898855638059397, 0.046910842460009365, 0.03985208151261172, 0.04084703054339175, 0.012497954566272037, 0.03813815130401523, 0.06819677163636492, 0.05208688487689342, 0.07525801853907686, 0.02136887351591741, 0.05016985326825131, 0.07179422859823512, 0.07683519439231004, 0.01221746009128589, 0.04588267968727216, 0.04523101848580184, 0.031236898033849658, 0.02233269639433392, 0.05989425545257907, 0.06645543846271693, 0.04482512978175956, 0.027603304704591155, 0.026430745849445946, 0.03361322999661488, 0.02841547473273691, 0.061421283190288854, 0.013391017733562379, 0.03344020903891614, 0.037645035828914375, 0.025733389418512106, 0.02850739187711189, 0.07664506669126211, 0.03670159855016297, 0.04794402693909022, 0.06831886306885751, 0.0075570958752876095, 0.06808174353453421, 0.03646888785184391, 0.060301189866637996, 0.11174609689342399, 0.07866981409249768, 0.07118074538847131, 0.07751828435087398, 0.0805393290976363, 0.05826409312806303, 0.02123528118846157, 0.057341187005682345, 0.01834250445808134, 0.0664340109834748, 0.04294011681791275, 0.04171162971385545, 0.03700372064486146, 0.05363652369968834, 0.06616972597135652, 0.0217331349173741, 0.036718816376261176, 0.05548659922374834, 0.01593815570231527, 0.06938757104498726, 0.024484261990554874, 0.07821095806937065, 0.03354716257402494, 0.02275822184709532, 0.020228572708043843, 0.06350780409129878, 0.0014857525961668864, 0.06969253532588482, 0.040564734804173636, 0.050321132650658976, 0.04993690891311534, 0.031308511933011395, 0.007136696508349551, 0.049986394362584244, 0.03302680118189704, 0.013143398964236821, 0.030746578779672424, 0.06059720624057997, 0.09346840347373679, 0.02184260696653397, 0.06473198578122162, 0.035974860732113166, 0.045237043767326304, 0.032638467382639647, 0.010766795997868383, 0.014486480372837715, 0.07866465832076727, 0.02824490142595624, 0.00670119850603383, 0.039651814637885946, 0.011011635783248612, 0.017833818245919484, 0.03503193290183141, 0.020626300660472725, 0.03125859172864547, 0.04486040813067267, 0.033239218211101915, 0.011393570833118453, 0.0196234762458311, 0.04062347076532822, 0.0901897156971597, 0.028319286648184065, 0.11296495810271272, 0.01702527947453482, 0.0989732661494805, 0.03130654691748562, 0.026420646895384117, 0.053910281388990344, 0.09163209838011573, 0.07373075331411055, 0.042749426042240475, 0.033168286130192785, 0.033974440452913125, 0.07074475708988405, 0.051860329695045955, 0.023698746076514645, 0.0145618787463454, 0.030135162092084368, 0.018834085842113824, 0.02454229698125874, 0.07487315894855608, 0.010272359978708049, 0.00846756216619284, 0.05771253280521882, 0.030674717817155105, 0.0657676064199017, 0.06779636812186049, 0.031135937221528544, 0.013063004739852923, 0.029795501689096133, 0.02444735187436304, 0.009290599151544515, 0.04721894770139649, 0.006653594281223993, 0.036185477454695976, 0.021424087387840116, 0.022649197959371155, 0.0359325228829778, 0.028113390942434632, 0.03244920536094616, 0.03573743093218054, 0.16390834183942887, 0.10496303183777679, 0.06288465668237017, 0.12730167307440313, 0.2625288321606575, 0.06413112770044996, 0.11509367129615239, 0.1871416128931507, 0.16154260104221685, 0.16666339319800177, 0.126395728138666, 0.0968182914619965, 0.10998549660848034, 0.11861701691222769, 0.1814537164905379, 0.1738322907758336, 0.10098421630719978, 0.18181984523131003, 0.13866415127150475, 0.14295579114508244, 0.1433472467526313, 0.14346808946180728, 0.20283265640178036, 0.14969502064970233, 0.1676803749174841, 0.11531757581378184, 0.19448897831382292, 0.13149994215176952, 0.14783002556331698, 0.14531932560907257, 0.17563897124942274, 0.12819745202338503, 0.2348302184574066, 0.09779286255399067, 0.1840028434150642, 0.21668683557260424, 0.0816027510670885, 0.1502728654492286, 0.10745391309742006, 0.19607668021513572, 0.11031364270996664, 0.18344240413317758, 0.14706090393085636, 0.22131371552184706, 0.1713113865304378, 0.1855101673713615, 0.1620624376641166, 0.20074338141468265, 0.12509866467406675, 0.1155913066900065, 0.19796574578410198, 0.20757230449347727, 0.12830331771364137, 0.13297495251942065, 0.16397355124354362, 0.17691193358792415, 0.2441909548736388, 0.2356264136371113, 0.13773413585318675, 0.19625632783337948, 0.1787160246843292, 0.2659240419105176, 0.16279279524760862, 0.07345752805591592, 0.10101995430886747, 0.07537555174841996, 0.12624949727567936, 0.22863249054118512, 0.22677986011389764, 0.16863996132967934, 0.09015930966744501, 0.11977779333509746, 0.17456209677602016, 0.08944213645712984, 0.12311026814483828, 0.11644005550131684, 0.21941999213830118, 0.2286268827775794, 0.22252050318544914, 0.08378486058885053, 0.1621479330764663, 0.1790749368768546, 0.15340184432364282, 0.1526882947092095, 0.24415813566696262, 0.1726675000522406, 0.19174307404506594, 0.37240640230236516, 0.1393534005769799, 0.1966455924294649, 0.18707600512331535, 0.23679180190928523, 0.11357649544914884, 0.22231785760771847, 0.21435189150994827, 0.13839746074330422, 0.15786018492954393, 0.11241941923095335, 0.13295944689983322, 0.12764962254873208, 0.18944493284629238, 0.2609255327092063, 0.11591397526283419, 0.10780215368516023, 0.12604644567134882, 0.12293363891301617, 0.10742045803776673, 0.17415934903246744, 0.22660459451858075, 0.15575057796893582, 0.13286373187457362, 0.10950497561885465, 0.11421309153158819, 0.28972553569943676, 0.16897152418330794, 0.16689881201713316, 0.07355762510410241, 0.1578605526517476, 0.18371287913572404, 0.14533337566160387, 0.11051850994267773, 0.16160912811756134, 0.20226857054137415, 0.1567172736770684, 0.09641724443363567, 0.16653226958888193, 0.10317583298010212, 0.10074172649652728, 0.13221350708796134, 0.17790487546834255, 0.13943437607057635, 0.22100338862547952, 0.17555192833946598, 0.15636358620418658, 0.09580844968196847, 0.17011903196332917, 0.12519305436721734, 0.22236431317944683, 0.14547128680973284, 0.15566972504940726, 0.06817784160375595, 0.11050307327100348, 0.1143937120814958, 0.18964644461389513, 0.17699431868330126, 0.17685631560462137, 0.13871596945870307, 0.11738700912364068, 0.1351395952365091, 0.11385277739816135, 0.10177050597004353, 0.11533991493765386, 0.15549980674780187, 0.10755451576363657, 0.11409311450176662, 0.09406773703953913, 0.12709199480952757, 0.11850125336598967, 0.18483915095848424, 0.10113134349305784, 0.14696354947743878, 0.13982765496738497, 0.14238700150482117, 0.07662270458475237, 0.08458339999760352, 0.13472149509095377, 0.14780526560160423, 0.13052042213178452, 0.09899888412966844, 0.1511409196762308, 0.1242670072843471, 0.27540480898272607, 0.11631380421139541, 0.09448137089249589, 0.10215111377258455, 0.3152867028069112], [0.04703901280018111, 0.04714081439399912, 0.03634616822725342, 0.02163922211395637, 0.008469656459055841, 0.029843269186394832, 0.10883189842946107, 0.04335845445072459, 0.05445796913737732, 0.04227427149852438, 0.011264453416750317, 0.03510203760778231, 0.074568462798432, 0.046120435074572606, 0.04399342642676446, 0.055675102818396785, 0.02388422170864238, 0.007220927396819237, 0.0029261846277457214, 0.043194412043498415, 0.08581647213788764, 0.03733035372269731, 0.07064661356590449, 0.013865552703669716, 0.028989724664678498, 0.017545376566328832, 0.031582223657037944, 0.031513616652979005, 0.04843785104552104, 0.015027257050537776, 0.05192782204117506, 0.02129607601091266, 0.051538228027282224, 0.011811672893893576, 0.021993263902503158, 0.023097382377712958, 0.03775651694365567, 0.04528229275057393, 0.02156291784147822, 0.06572163348356563, 0.05305433135119177, 0.04061205222481682, 0.06760493041046205, 0.02661070756373867, 0.08001019216833577, 0.031398079102678646, 0.03247710245270883, 0.07315110054708297, 0.06428887286493856, 0.0612603587609145, 0.024579270299704328, 0.014169209847046484, 0.07019109768612732, 0.07154337310742948, 0.007396073769702907, 0.05046739032672298, 0.041247797949660214, 0.022252056064204346, 0.0504843247002892, 0.01804822327328786, 0.06260761630631263, 0.09473569676159851, 0.00863824655572253, 0.04464461648416135, 0.031345709332174836, 0.024091846857880874, 0.03174786144236644, 0.04689496528777865, 0.018468112234146367, 0.07801818736498395, 0.05129939628644817, 0.0731034115737965, 0.007734288660539015, 0.04001174572735064, 0.03112617151571378, 0.09815081713661071, 0.08573985568458035, 0.13623343089655524, 0.2903422977655165, 0.14617075572811788, 0.13943049966567947, 0.09932758947533947, 0.14895874886743485, 0.043035314733823465, 0.04361339319016665, 0.058652484383914745, 0.04240873525099408, 0.043312067826909405, 0.057457437017752286, 0.021059316537913778, 0.04997077766024778, 0.012025142336384425, 0.10347802402271379, 0.049211094231014295, 0.12713192331214107, 0.013813487453115805, 0.03433534447404166, 0.04933260726712404, 0.034188883784677715, 0.09149474647617148, 0.017243156795419993, 0.03639254719018936, 0.03983808508623512, 0.03167638543903107, 0.06296479714012916, 0.03940393156822651, 0.0267035995549973, 0.02058414092677976, 0.024657438081058285, 0.0625317084843353, 0.037774876240761056, 0.07294388142444434, 0.03203547383177906, 0.04683096247214464, 0.028814505034637068, 0.04425608733248326, 0.04883060134166191, 0.04624806915319735, 0.05920281896608011, 0.05664803448223299, 0.02345191446253129, 0.07746727821687538, 0.02811051428227896, 0.04642179491178644, 0.06335234569926416, 0.01996206221050553, 0.05757552947128012, 0.10178130014889664, 0.055295421982244145, 0.0330543190601372, 0.06771594421156953, 0.030248968283675855, 0.03152052102039658, 0.046645350859410344, 0.022263691024554354, 0.050296751902468746, 0.034372189472759926, 0.09847874873347821, 0.039532810539728215, 0.0566335400987056, 0.00839090453565962, 0.034433855720224886, 0.050309740923224926, 0.036732410606477535, 0.012224956261624974, 0.008858396284913105, 0.03396839601919055, 0.03844236481874701, 0.04141976553646307, 0.01730670953439849, 0.08516589495083017, 0.03663036003408413, 0.07703136652708054, 0.08509239647537471, 0.01952195427410545, 0.01233153728648059, 0.04762779733526611, 0.018780333282906684, 0.09428853124019601, 0.028573488027999, 0.0230320465690907, 0.1427831608922251, 0.009674180332841653, 0.013208427380079464, 0.05184833275815172, 0.06637078574708392, 0.06381080718711019, 0.05215117114505941, 0.1213494303726381, 0.031466306893215064, 0.025344684066611434, 0.051285599042931874, 0.05620088045214934, 0.018206123570581118, 0.08157459733587119, 0.02332813380616567, 0.01650845549339729, 0.03372518225542961, 0.028194895036698833, 0.015845001325942576, 0.03093172882443234, 0.013976234214140043, 0.08360480694400688, 0.026086557866825212, 0.04244298321164904, 0.04566491536435582, 0.0502831768244505, 0.022543315032136538, 0.011680939032005207, 0.09253428182414464, 0.05573479638945672, 0.02453999680226609, 0.056441520160484704, 0.052169063128530986, 0.02030023448770085, 0.06390675203874707, 0.052426108609764814, 0.053008860202446106, 0.04826766078270251, 0.05616356047891802, 0.012520027474590368, 0.026303757199897405, 0.010746419974302333, 0.017454112511909297, 0.09033880406810392, 0.026952991817867564, 0.0982820556589192, 0.07859182634180592, 0.06228360707961744, 0.03710620022649246, 0.1097051467325899, 0.042414304710203604, 0.005750306712974224, 0.047455634396042556, 0.05966607616433214, 0.056482141972669674, 0.05857520909499257, 0.03787041889623769, 0.07835325890130575, 0.028406691534685034, 0.04062446284919016, 0.08333523592521107, 0.016679373539743886, 0.017693836745175145, 0.03150393904727553, 0.043365023654675296, 0.0163472744245683, 0.024245209999442584, 0.0031630721810694427, 0.11011296597820137, 0.03282905473644215, 0.06624478726617752, 0.025923042145046978, 0.03040207861622255, 0.03526497684839753, 0.03036815241249579, 0.04756669033198588, 0.028517891112114155, 0.014731109484038768, 0.08240885176365415, 0.024741679024431976, 0.03375648460801571, 0.05609499944013454, 0.07458988261679489, 0.0783029958725937, 0.024430107235187487, 0.051034915921909195, 0.0080502443879302, 0.06646127605269994, 0.014389557801487466, 0.05703975055967608, 0.03169253265725509, 0.07721470668911934, 0.1594839082850564, 0.19912143538315452, 0.15282801382483976, 0.09815100865859179, 0.013801251113745234, 0.02791032976200504, 0.024540728416233778, 0.06725654426601625, 0.07325911128352727, 0.014972240446255574, 0.030330292347277847, 0.07033250219519101, 0.023174383790202202, 0.04352977086279181, 0.06508773403061975, 0.024317296957897565, 0.018665090676457174, 0.11283168178652564, 0.09160233586425744, 0.10362046275047526, 0.0323313235815975, 0.08803523130594723, 0.03198938406703453, 0.05759525240489072, 0.09807695859983083, 0.030178005559249755, 0.0489907443613535, 0.08406136470336108, 0.10932885966594182, 0.061163758904102354, 0.035932373495832566, 0.0630917838744579, 0.04135853212867533, 0.025231088549199126, 0.06741926900201267, 0.023205203507396004, 0.028856666683549845, 0.005778608394921908, 0.07562459161084506, 0.04085871721467665, 0.010977834068809547, 0.05507046026327918, 0.01998320623721567, 0.02599660190753639, 0.05498458946784658, 0.035921931717424624, 0.037523863701930935, 0.030296197604207747, 0.02476154368430857, 0.05151391239656557, 0.04482332181425826, 0.04275170515381521, 0.017278837340493357, 0.032372849377533125, 0.053715775495455156, 0.03281164538836287, 0.03901423030202428, 0.03769908333197236, 0.044569137671421614, 0.03776644544315435, 0.039594518922029004, 0.05613447595087271, 0.013554829356801367, 0.06879024462954653, 0.07147162897332061, 0.07049092151705297, 0.06937609504788153, 0.01895242152855762, 0.018649121573675546, 0.014376317886936088, 0.006885818513711134, 0.06147211695450449, 0.03213216370392231, 0.02801185747939012, 0.08503396694938983, 0.07490499756268917, 0.055119420942519946, 0.01782203389842424, 0.02310039118803557, 0.12993454873081178, 0.019883197289140477, 0.06485562471132125, 0.041048105640877644, 0.01636076331769507, 0.11772698362267787, 0.06903886314361327, 0.09367093413827882, 0.04194129904311511, 0.050842367383020545, 0.024593362487071467, 0.028937607703189698, 0.1003009578092925, 0.0700340266790121, 0.04843900017740746, 0.05332091079664327, 0.03141074445128682, 0.028783595302112164, 0.05420398417740099, 0.1431185541854751, 0.08509780505612012, 0.13897219522585794, 0.08852004238794889, 0.12423360585084847, 0.08027803948930196, 0.09478825039320415, 0.2226903602000206, 0.1035463207611634, 0.16173024661839008, 0.24779325351119044, 0.14543883532526033, 0.12789799591466305, 0.11479153387969541, 0.18406157171533954, 0.15450626731880251, 0.12601001052967004, 0.1243128423248568, 0.12448211711260582, 0.1327385377859877, 0.19771479070186618, 0.14246336514911345, 0.12280852143322268, 0.14242763480832502, 0.2385337019879972, 0.1677324535745767, 0.06353097442056864, 0.10926604045615082, 0.07768072563433841, 0.1963951736087761, 0.13981139858163175, 0.2962206742696224, 0.13979010133733674, 0.1927057094871998, 0.12288069457656915, 0.2853677211509597, 0.11134295078415064, 0.07013598532085458, 0.13070072858564316, 0.09347283146193913, 0.1547523347600814, 0.11036035109071002, 0.1272319360906559, 0.21291858696889496, 0.14550692521997038, 0.22087552855091713, 0.16757773445738902, 0.1436756992892873, 0.1589084383580954, 0.1694063097238541, 0.11798800510023871, 0.09474589339187069, 0.10029908089387803, 0.25526153824983105, 0.1666774279287746, 0.150284142263474, 0.12496898131024455, 0.11900602869929806, 0.08185158408577405, 0.08105880565821164, 0.1461526607313464, 0.1516281515960732, 0.2502956337505772, 0.08055925504454682, 0.19299496896564963, 0.08466740153850087, 0.10053039348173527, 0.13679932472446274, 0.18706544843171874, 0.2464767773785899, 0.16021360703293355, 0.23353565243944047, 0.2472509245478338, 0.1558481162834552, 0.14005329850460255, 0.12557473469285235, 0.27222624889785246, 0.22672917573682724, 0.2338884818938471, 0.40283314703452977, 0.16737775486563483, 0.2986416040408996, 0.17266440505702652, 0.29477286002328323, 0.1348101467855515, 0.14322315583065634, 0.27918971233790923, 0.1045626896103063, 0.1635698535509648, 0.10497898944923956, 0.1196407248836852, 0.13072797067223058, 0.2835242684570051, 0.2072802411332246, 0.21335193226414345, 0.2606456654687082, 0.19116935079857228, 0.3227704931651393, 0.18700595404351913, 0.11584449874898119, 0.17631587121755848, 0.12491177752493851, 0.21158314249928922, 0.0874945647533863, 0.10690822866895508, 0.21896732610560235, 0.2830830937431705, 0.25482414801034237, 0.10792608372867109, 0.11372874776322035, 0.12952924225359194, 0.1677239346768587, 0.202207543977326, 0.11256122976661691, 0.13660469242642004, 0.18002752124542193, 0.1440367258844837, 0.1661655279777704, 0.11107810652784764, 0.16963635060575702, 0.18485343083739283, 0.1333911374451653, 0.1711383579118598, 0.15221756432325612, 0.1341103254667213, 0.13297602504251466, 0.09501429229614236, 0.1688311309103043, 0.3417670528494543, 0.12458710180174921, 0.10206458414153707, 0.11871828607493833, 0.1701837510711724, 0.2179374587872336, 0.21090351525814305, 0.13765970275046366, 0.16116347945024892, 0.21522785176432904, 0.13753394175681377, 0.15489462793113726, 0.1150895037778443, 0.11794269099951753, 0.1314740943452043, 0.17003108506962178, 0.2206291853179855, 0.10177700239564143, 0.120554200463718, 0.16808408793182145, 0.11962211660800443, 0.11521811461857251, 0.06972474166222158, 0.19870284494132767, 0.2381242126707108, 0.1401394833960841, 0.13111289921066455, 0.1610740616677269, 0.09118625052994297, 0.2823741253345244, 0.09142298702030413, 0.2561302666342066, 0.19760980601272277, 0.1305367244828132, 0.19865816669358363, 0.17526473729841172, 0.20343539905884575, 0.13323457971695932, 0.1574067528089208, 0.14959357528676911, 0.10197797024081792, 0.17567951262237566, 0.15968174283062259, 0.16393849506012856, 0.14068605648654123, 0.16920297466699155, 0.1652014216468219, 0.11042489399833065, 0.24387442266508458], [0.02731409693707622, 0.025540886844898907, 0.05026056573936536, 0.05114361996792498, 0.07785648918680607, 0.05471310705967969, 0.05241969262339896, 0.019259446585971503, 0.06577350529691865, 0.02971015566389167, 0.032682050124651967, 0.027887864233625513, 0.0363920530634782, 0.041673815613912965, 0.04408658271835696, 0.026004814370084676, 0.11066675561690524, 0.08120584857439803, 0.04160954849794508, 0.023941657235545498, 0.04934133683902122, 0.06503027743629872, 0.033867096212962945, 0.01006485740353744, 0.01922947339593403, 0.06505144444564659, 0.044458261766140504, 0.025834723698696303, 0.033132218710717656, 0.04502535835208912, 0.052469817756284634, 0.06074477775743412, 0.006265748384213376, 0.0729587282084169, 0.03839220904234437, 0.04484070051882056, 0.029690009466702902, 0.06087004462437284, 0.04351403541682709, 0.03357329000268252, 0.05071341180272641, 0.05191620814824297, 0.027130869773006248, 0.05583071442801626, 0.024421835400825067, 0.028972966491334864, 0.08464525393660992, 0.06334556199069466, 0.03753529756420082, 0.032460918845308405, 0.004133296681703219, 0.013668378908938218, 0.013784928652908535, 0.047718816241549875, 0.07422055162849926, 0.03760187443526041, 0.041443023965844226, 0.02113200870582894, 0.09522783930503553, 0.0395881642226971, 0.009567275635838028, 0.015438145435895893, 0.035799453410530285, 0.037171386647969484, 0.027670176519501596, 0.07554605227684782, 0.05298025447935347, 0.07717346051527608, 0.089703893379098, 0.1307483945762919, 0.03418987586853966, 0.12493333523912777, 0.02579046105365119, 0.04126363681749471, 0.0057798748340217344, 0.14288975436600948, 0.13432761864556422, 0.22126617210526622, 0.1299380420917465, 0.046818444595461896, 0.1264761060836815, 0.11850085500026904, 0.14260775740108184, 0.07889201789493523, 0.13957617894536065, 0.05655161465608305, 0.16290681977425853, 0.040281512098567146, 0.05699265530453094, 0.09331796678804583, 0.08583414578630079, 0.02354290272529808, 0.05853964729354747, 0.18579334411169254, 0.21211733560888998, 0.05877962816626795, 0.10912888007418764, 0.0852673403137634, 0.022974875342521458, 0.12454916512773884, 0.042664961018148935, 0.11171936808574585, 0.08210176541920632, 0.012942643708459312, 0.03191986924878532, 0.03736028477789895, 0.025858999109796943, 0.05611630434530878, 0.07857305718766106, 0.04962891475447724, 0.07749425983356853, 0.07715496715278396, 0.030129738189580462, 0.022206556187161518, 0.03111022348035007, 0.028983814296342676, 0.04823353922655506, 0.03711782944118304, 0.06996676415926026, 0.028490164474914634, 0.022639256053333803, 0.026948065872514443, 0.1401252035171755, 0.03446915705177573, 0.08790245294691094, 0.047459288635441375, 0.04996412035618579, 0.017241787413255345, 0.017899424100535053, 0.05667763611962719, 0.07070979283701989, 0.04784635455918409, 0.02345014288420639, 0.017566526338698405, 0.02171652230073608, 0.01628559285534486, 0.0539617280235454, 0.0249385885188296, 0.08906709811379833, 0.06667424849564992, 0.059116515330970294, 0.03026031787627407, 0.029283582585893815, 0.026353273292883273, 0.056989533496239496, 0.05614553826049932, 0.028696052519784822, 0.044730755410367445, 0.06134445989324201, 0.03211964008158013, 0.015075615393148075, 0.0470963353291154, 0.03963222576966209, 0.021584824125673023, 0.056153011448200674, 0.03983588258345281, 0.030259205133564053, 0.051014285174108324, 0.07278033697436895, 0.01166014644813033, 0.031119719140171528, 0.02211801174487318, 0.03989355368239265, 0.008548263783356356, 0.007788004351764798, 0.030157681246618592, 0.03997208918595026, 0.01872503897175193, 0.03020361587855845, 0.044252862102322044, 0.022992698378079844, 0.03535445974839311, 0.023671954066582748, 0.06041616817275363, 0.04331157753063787, 0.030947816670842232, 0.036198374544901234, 0.09016200629693848, 0.07390773494637783, 0.058808394767824686, 0.060942842129377596, 0.05921408811944628, 0.04406933807918141, 0.03273870998753175, 0.030184624558915536, 0.041431819929951624, 0.023792565034161654, 0.014383889708457696, 0.0687071623941583, 0.0441603071897501, 0.022142654878177473, 0.00593257530952894, 0.07972117017714248, 0.009341628268180836, 0.10423491123102366, 0.0059290560931267765, 0.0237817095682746, 0.1631852620912175, 0.025814493231835867, 0.031832169418433504, 0.04718966399049086, 0.014201415225773329, 0.028730421139287855, 0.020354260923340917, 0.04818217303123205, 0.049909371882677085, 0.04516229656855426, 0.04491438668581747, 0.05276450496767798, 0.06261554531632893, 0.05307590821757913, 0.064974345356947, 0.030194623921547207, 0.047639484006551006, 0.04793813955339213, 0.04820265439188769, 0.06591029029579894, 0.012272043855890874, 0.04804983900319185, 0.06439591833059827, 0.010592666127899242, 0.027224866846095652, 0.043913370238677155, 0.028361072914013942, 0.030923797899196227, 0.015904786827553426, 0.03737282946765904, 0.03174181509342405, 0.01836735826556481, 0.041413085249763344, 0.044341850875606464, 0.01506811730758918, 0.06304125271497235, 0.03047561348085442, 0.0999328449007965, 0.020199926765335184, 0.007214787202106128, 0.05548151239993111, 0.0051491307057139855, 0.05905694050353862, 0.08499718706814513, 0.05575518198912183, 0.06286016485143094, 0.03895035389089777, 0.09381800769798218, 0.09002639341258234, 0.061830492885482896, 0.06741985888971437, 0.061970598875514926, 0.05809777160926212, 0.046047672043524446, 0.15853051186328934, 0.14793419819926062, 0.1892157959481401, 0.12663924450715705, 0.14071717497802552, 0.11286098464962938, 0.060563352815206015, 0.12764953061818116, 0.05946477124046895, 0.0809710656082438, 0.03364973025576722, 0.15683476092113605, 0.06855317872137794, 0.05482215584526139, 0.0475220580495173, 0.07381308478333297, 0.08128036594679279, 0.16261210574978785, 0.14616726236718317, 0.07468402716180972, 0.026650103635244796, 0.08208521792004186, 0.0723888430624239, 0.033180662280609535, 0.0791656798232467, 0.12159140690440133, 0.03975876434255512, 0.06433027991724592, 0.0370487206495337, 0.028659699732557904, 0.030366181651310577, 0.02958577171328568, 0.03251971226305731, 0.020958411266967174, 0.06497629888115392, 0.06359644429457766, 0.04371390775627187, 0.057825798904823686, 0.05249703686023432, 0.0518102083925999, 0.01146663072323727, 0.03321063930108663, 0.009656113106757402, 0.029308608763160247, 0.023810784520220854, 0.024095012716227965, 0.03471488358392831, 0.05519081650662327, 0.023179907284136263, 0.030223241135958704, 0.009455836655932569, 0.06835554335867206, 0.048442129646578146, 0.06388312971760189, 0.043763450662335085, 0.032056880243603265, 0.03755043929202422, 0.08831411029302305, 0.05797833850186679, 0.015208992258375211, 0.025331162614747885, 0.07734494163624703, 0.0345687867863284, 0.06119503061317148, 0.05232024674994811, 0.03352309975232329, 0.021957232872204437, 0.009034683649999, 0.041875944082294746, 0.03945684526115656, 0.038645132970545566, 0.06318494016605039, 0.05423837003388232, 0.06639784397256952, 0.032326631293061285, 0.08578058857951434, 0.0269929088291622, 0.06560799200087786, 0.11253777215437544, 0.023199898348520362, 0.03851996186459738, 0.04838793658681455, 0.036527612321679635, 0.030565885451412013, 0.05040153740875183, 0.011856404767792312, 0.02454057519864892, 0.037172183379410736, 0.07505649144971564, 0.03508850083416028, 0.057662928612121654, 0.007916453356418999, 0.023584769430360007, 0.04988463873404169, 0.08976335712378064, 0.05769274092369503, 0.0594469711875483, 0.03137157054527873, 0.05320464929325446, 0.023544867740823858, 0.006345588152462076, 0.14024681231427577, 0.1005063459817921, 0.15267769205233744, 0.1279710270764847, 0.19421294151294619, 0.2186111258643289, 0.12074031386404269, 0.16736457815333722, 0.20405579238168656, 0.09657095231476331, 0.10115501560991812, 0.14226899332096501, 0.19313710891912061, 0.07502854456223788, 0.14420178718864918, 0.11346594130079593, 0.24391968313965107, 0.17356553896059915, 0.27593129524780863, 0.0879825167958775, 0.12906208183736573, 0.4219110039693694, 0.1512428093701601, 0.08864434781454264, 0.23228464618084893, 0.15693939320983427, 0.1888236355397009, 0.07750115462488706, 0.09471988470684137, 0.20961360705475654, 0.1392711993427046, 0.13112970717972325, 0.1184517564252019, 0.2283504629327405, 0.1421874509223046, 0.20000565406535903, 0.08076275864075269, 0.13559356361867922, 0.1298955701772244, 0.10124696914346949, 0.13250596881393464, 0.14768715016543865, 0.1207811386895276, 0.18233217419155184, 0.1199722724155553, 0.13340341017371224, 0.13539186798997466, 0.11072894663459833, 0.13304310370116465, 0.09396909555840878, 0.09391253528695914, 0.17399945116091162, 0.13392937549900624, 0.07560686433627721, 0.13412014671391057, 0.2130269118013882, 0.1970402502845372, 0.12294545198880857, 0.31933936921338885, 0.07691220921133796, 0.1236011926084757, 0.22300110078386723, 0.13433046849264255, 0.1368195034803883, 0.0943658295117559, 0.14717086819150757, 0.16333947559037518, 0.23550239932392877, 0.2486935140745294, 0.27311442059374624, 0.14991380003911836, 0.279751070925305, 0.22510301622171558, 0.09590794152069478, 0.15932476117966637, 0.22754496744563504, 0.3082142097334708, 0.272720773974734, 0.20227462263597598, 0.17673346574508375, 0.3336727823461256, 0.254432171463005, 0.33277820615518483, 0.1203002576385775, 0.2190411616597445, 0.3621391693670904, 0.4516729376008434, 0.2662072799378826, 0.1858914340095174, 0.17060372047126296, 0.1812781444600513, 0.1739031079435541, 0.22767442098307997, 0.3337764493640392, 0.2532497760389121, 0.12990415036197633, 0.16983161109589762, 0.12816045763752154, 0.17374973714111314, 0.1976222319588546, 0.28658690411717663, 0.18767718496101518, 0.18133227623278098, 0.04585506987848109, 0.08834575738517508, 0.15839679887698543, 0.14457255842224245, 0.22984727616271666, 0.24988516384074766, 0.21817941999723836, 0.19027675111447612, 0.1671177139806171, 0.10211614185884114, 0.1332939055658156, 0.14811911650242346, 0.08886400820507158, 0.121964683245507, 0.11016943431910008, 0.2359927415607437, 0.15717265166101918, 0.11664797176396656, 0.09938205066587656, 0.2610606399755324, 0.12454540363603062, 0.0795286369600123, 0.11281035389871368, 0.16647709593657525, 0.2594307113078333, 0.0964079594479934, 0.09651920307547816, 0.16977629954776458, 0.15544520000055914, 0.13104232719107983, 0.13886105118980333, 0.11710621491675416, 0.1288647069445541, 0.1948706739612164, 0.1315366071198256, 0.10735770777588892, 0.23214411501201893, 0.1936491774094682, 0.11479065287858249, 0.0750672243415348, 0.1347874859047513, 0.1874770215081592, 0.11011326475249184, 0.16812508895752892, 0.11820966498025003, 0.10280588912146707, 0.17701967619359496, 0.13281939070551627, 0.16793926667061546, 0.1068444824927757, 0.20466418876763315, 0.13807944232417693, 0.12679240846585843, 0.23153839993380734, 0.2400079922329995, 0.17688691315631713, 0.22415651459126706, 0.09501600833309275, 0.15548212543850945, 0.14849515842093577, 0.12335461188828754, 0.09771630738771732, 0.11444268042161582, 0.12162011221892412, 0.0986867109614034, 0.17094518118087323, 0.14434621008413454, 0.16195294837797844, 0.14704628697326108, 0.10213867250469424, 0.24928678788485067, 0.1273416705249298, 0.061765766116760434], [0.0836439157325414, 0.022124557966186155, 0.07385790092690338, 0.05124283601499854, 0.015655617687791105, 0.039265905506908894, 0.0446758920236701, 0.044663933391172084, 0.01932510032108234, 0.025826425051256537, 0.019582741435677297, 0.09005810945264756, 0.030589166863430894, 0.12408244138162945, 0.03752552611272662, 0.015971535110786077, 0.063233264992314, 0.0765151841445796, 0.03813331728921302, 0.050148785850333596, 0.09604317136108877, 0.010269677713363162, 0.07424970893489738, 0.06894273443087455, 0.03068888086765524, 0.018415933985623623, 0.02999139037133465, 0.01623581246202511, 0.03318542734749856, 0.011782956088051922, 0.018254216655247638, 0.042852989638284336, 0.02206409639198213, 0.012384186679076765, 0.04400184190261268, 0.03934104724096195, 0.07446828148057384, 0.0452573565886386, 0.06190182716255227, 0.031122092097516985, 0.055392887518410726, 0.07773574606906022, 0.059907424503997456, 0.07481869009713973, 0.045067294005064235, 0.027886466123163704, 0.015266890310862613, 0.055174115789873954, 0.004071209564684861, 0.013691100119162473, 0.012595963067254953, 0.02941014797186419, 0.035562180658622135, 0.023163687287559433, 0.04448520890887707, 0.09152681491668187, 0.07113383782486762, 0.036631413404980016, 0.00859809588761099, 0.07516275550569258, 0.07507388164559681, 0.057941803768757856, 0.023017852875073592, 0.057722242969659075, 0.025581654213789492, 0.028310526432769916, 0.0030397803845605064, 0.13762400305319217, 0.1632447105141417, 0.04325711634010077, 0.056078141675360745, 0.3817937679348454, 0.2729798342672087, 0.07740734715855892, 0.06961365891320091, 0.4232895945108706, 0.36898477784087585, 0.31270633481683274, 0.07106059981930642, 0.16551928684836434, 0.18620537684088756, 0.15139178282791568, 0.17700303676387957, 0.12236410616746835, 1.1616889868051776, 0.7362382582599117, 0.9825790397101833, 1.668096761549673, 3.9554188376472847, 2.217425194478804, 0.14084924853617145, 0.07123805642608674, 0.3155873463519158, 0.502031053146047, 0.815365212338586, 0.26778557427948524, 0.4236697579824156, 0.16213828036862035, 0.005082466213348052, 0.02507915799205582, 0.0661906095281724, 0.11700634003406572, 0.026146709175419905, 0.1385376088681721, 0.05309636659559704, 0.10572761822972568, 0.02537209277732238, 0.0429473563487972, 0.08062116260970793, 0.034930207916805824, 0.05646821832464588, 0.019930696655665676, 0.03500073780155471, 0.07497743883680913, 0.06751742018687149, 0.040337930643750776, 0.00320258172934935, 0.017020435883633552, 0.04404097750422455, 0.05253916786563012, 0.07726230373185489, 0.039179716784987724, 0.03528606724895297, 0.015494246054590951, 0.0620039007175834, 0.07329355459660292, 0.046010103091717734, 0.022789704230343624, 0.1471703012864436, 0.034507227791172844, 0.07428013028637057, 0.03136065187713793, 0.009007431029702627, 0.07203410604908582, 0.015765993720701626, 0.012328089890821327, 0.04355561100847779, 0.07448002560845307, 0.023064325683780258, 0.03285760683338008, 0.02622270892794815, 0.09048980765885885, 0.03027938580470941, 0.07542312580851779, 0.04639036232425321, 0.05043639057886697, 0.016885636967696974, 0.045465399255795826, 0.04058607801374409, 0.0634583033200714, 0.04519427307851372, 0.017275585297254786, 0.07503579941488082, 0.012682261914315244, 0.03121778030969924, 0.0357698364513776, 0.021385352067168684, 0.06484651592590156, 0.024398481210453377, 0.018881784391499335, 0.05906938560186856, 0.06106311410305001, 0.10231217609778528, 0.06302714903628634, 0.0030473790191594633, 0.03245000975326665, 0.046691982631361297, 0.0232895172291225, 0.033788920770729744, 0.04591924123345845, 0.1191057580252809, 0.03704748724797561, 0.019082869065084287, 0.06400696016968259, 0.07958839947898542, 0.042214225527019276, 0.06048592047825937, 0.04338603361599869, 0.048818696335318594, 0.019821634463545297, 0.03465588332243985, 0.01912325147479292, 0.08050151499769381, 0.052278441331920125, 0.05564456655373497, 0.06318575221925013, 0.0234390307788647, 0.05554438140543719, 0.05373063377074657, 0.06522847970406856, 0.04535135940738744, 0.005717326149028997, 0.07631037053802321, 0.0653591743039508, 0.06765391407234055, 0.004961233756940572, 0.03529489258184068, 0.047109220928001794, 0.03734326613466105, 0.1097116278364293, 0.04329587272819012, 0.05951200822188009, 0.053798103134237954, 0.047891534594518524, 0.015890031016521877, 0.023425091809082418, 0.056141654194723216, 0.01959936171319456, 0.026414273043854103, 0.060370597432577805, 0.021544788370750124, 0.02312930909195735, 0.03641020934728365, 0.015497277847551292, 0.05303127976555017, 0.04819140056028001, 0.0455000609039299, 0.054481534001928185, 0.11425211605045105, 0.01422796400278927, 0.04333295904460453, 0.031549057795576034, 0.03270975952487319, 0.03637871164227686, 0.050996013977114237, 0.043831785705180905, 0.04542470083481843, 0.011335702466538117, 0.026043375405753334, 0.02983258034463131, 0.03180416124392181, 0.0584697264486984, 0.048514268315968015, 0.030122640384962002, 0.02940837256309967, 0.012299278281599045, 0.044694967612984686, 0.05162988661698276, 0.05434823853354301, 0.08200766683946695, 0.048147886766180883, 0.04462069538872569, 0.040194112957725604, 0.02713467148433049, 0.28729406455832146, 0.06966571458765576, 0.04324673584872677, 0.06358099996202415, 0.15930012379202152, 0.05187478194373751, 0.015114575752147264, 0.2970503474916181, 0.3916739426072567, 0.320174987277677, 0.05991796204339593, 0.1630272641177139, 0.07449571508914232, 0.07372650918701003, 0.1713702527265395, 0.25069810570247714, 1.1002889395721498, 0.5799416128185488, 0.5007439947897389, 1.5251094535473855, 2.8844276743550457, 1.3191057140788724, 0.1775153350806044, 0.0423287020455445, 0.1496383148215471, 0.3483779626267572, 0.3668918869187755, 0.10968586429953577, 0.22755642812098228, 0.0734985827077781, 0.09335856178715345, 0.018627378083164656, 0.05128787049362737, 0.05863220603655904, 0.11522839551851635, 0.030037508864376335, 0.052218050620849096, 0.048773546943501125, 0.0666753210187439, 0.0074804727187109815, 0.1124063114665689, 0.08473752156621026, 0.018211049515934243, 0.008916639076966432, 0.013285557112296023, 0.03860875528546111, 0.030808668290715546, 0.0678711076597533, 0.05207338640766759, 0.04666838329285384, 0.028628406956070857, 0.03791131266963579, 0.0593121167302372, 0.05368452293858413, 0.050090394628744934, 0.04815484667497297, 0.02626881976011059, 0.08123669127422957, 0.013202179933056958, 0.01988968222341951, 0.06130866826541963, 0.006987228445077856, 0.03257499699811301, 0.03333059334827047, 0.0657284133616955, 0.06604902881888614, 0.029147180630975676, 0.045321788413510214, 0.012280587651466411, 0.07899629778318829, 0.04427292977549857, 0.07685416272931522, 0.009351547191580458, 0.07086424382343408, 0.027269200354273763, 0.07596469634482939, 0.05110032833932389, 0.02464305861071954, 0.021012734561677904, 0.030623338215293425, 0.03415327218751754, 0.017735364456330577, 0.05725573372816848, 0.08945152103420227, 0.01665452739313966, 0.04065095416961178, 0.061525735448324875, 0.030792189739464276, 0.056383048499663996, 0.05541845953332321, 0.04075778130021307, 0.013576886943361212, 0.08540149763106339, 0.038092396702737584, 0.0415351192256616, 0.046820712215717764, 0.030867124629777767, 0.041078860240597884, 0.05538522663916792, 0.029082737314785202, 0.10227811582867177, 0.019413361310838692, 0.05054951112176623, 0.04764223043175955, 0.052028593246734915, 0.005628188467404295, 0.015280530506354428, 0.013981683972111393, 0.1969563636568285, 0.10320597853992255, 0.12924215846484707, 0.11853486164322785, 0.10436254147920879, 0.09306284418750195, 0.26800446092121066, 0.1475805566916543, 0.11110423778694485, 0.160604955388173, 0.10159726284684674, 0.19316887092446128, 0.11768477217805003, 0.14436364624529116, 0.165628791456261, 0.16172690647504023, 0.1550055268190561, 0.19233409555688982, 0.14594627664454524, 0.11785072214420765, 0.13218327725846923, 0.09564145017535457, 0.1547940559084377, 0.2640236535620305, 0.09575292362921661, 0.22430438488241167, 0.18951611773621654, 0.06049086174537098, 0.12641679555658372, 0.07565694350388742, 0.10760082577865933, 0.23195104553334175, 0.12897817988789853, 0.16832606446358467, 0.1252448265891402, 0.12369883817530448, 0.16797127382409188, 0.11114487875132792, 0.10526514627159604, 0.1646575605076167, 0.16120973583911696, 0.15292152251687743, 0.25723574683070183, 0.08237071590678346, 0.21879613609804263, 0.09539739754531654, 0.06873608987417913, 0.17838251596737295, 0.18217157151910568, 0.11245687326957142, 0.1048271048573717, 0.08602390576514506, 0.14410230301080212, 0.15338174217650968, 0.0688733192040555, 0.21402685572543453, 0.22145504342211833, 0.09805261998647645, 0.1005921095249153, 0.18510630113943932, 0.2143566259333203, 0.11209373993258323, 0.14549632256309833, 0.13038188279155763, 0.1368734820355331, 0.10683973274764516, 0.1020748803632394, 0.30485871398160536, 0.3517241427494634, 0.1688747672784713, 0.1323212803371491, 0.7128938431701353, 0.41601418006804686, 0.18319356345361282, 0.16022385728936042, 0.4797152183469265, 0.5757994060554813, 0.35806796363284515, 0.16833605425011727, 0.26148523654668565, 0.2824206115497697, 0.26337128372923024, 0.24227372791257598, 1.512593292901593, 3.0230591902809762, 2.0990215866796436, 2.3485135022670995, 4.1310922368880245, 7.183021787674197, 4.33196367756013, 0.512388623169353, 0.19371000479065603, 0.3622506198383147, 0.704632044559525, 0.8531707320963183, 0.4283383897235317, 0.4452519869852451, 0.21024098709946681, 0.2667573923545499, 0.11572812999328298, 0.185683180668181, 0.27824445176989804, 0.19749311550009638, 0.2349692327721465, 0.1517288615145991, 0.22102591161045337, 0.23851482558154294, 0.1125682088276071, 0.16010951100578233, 0.11334919716201483, 0.21652125332865024, 0.20072360102447773, 0.21356321931365999, 0.14058470305415893, 0.08541833624363908, 0.2621536942258958, 0.166445946801574, 0.13938827289929315, 0.13308962055992696, 0.1463489784228225, 0.1232670863429385, 0.15296782487102095, 0.200888340571715, 0.0946939909350007, 0.1582237089713735, 0.2916095297663443, 0.17198621806117798, 0.22819275607264813, 0.2237996708361372, 0.099703133436701, 0.18557249628488096, 0.1112320518962318, 0.21080882679070198, 0.18798863034575217, 0.11460912068404498, 0.15703107861261215, 0.11975380712218824, 0.2572748786018741, 0.09008662324518928, 0.19312215488283865, 0.19205107203414365, 0.18599402850433705, 0.09558312024079985, 0.15113119035959244, 0.13376495770869717, 0.17218837334263712, 0.15941912789017926, 0.13699778746212685, 0.12153609535626828, 0.14492272189067257, 0.16160830074260313, 0.15343544494000175, 0.11942138625008446, 0.12576886137286503, 0.1651445779228403, 0.10816914810528679, 0.13322944692786665, 0.16634220317486795, 0.08756723585388354, 0.09098362793485004, 0.18640983038611952, 0.12005212175990305, 0.233755489030192, 0.12437418298495394, 0.10124445637507785, 0.1435412202150591, 0.14247341622268, 0.10207730886195937, 0.22617092746640408, 0.13224172976709184, 0.2434082888066769, 0.14638205809939295, 0.11195018271645231, 0.11061301454901697, 0.16683593152030823, 0.11228255762328064], [0.016358895978379636, 0.028327139049407937, 0.031224761285909244, 0.03139535374488802, 0.07009772688991601, 0.06163923520474665, 0.05120501042373719, 0.026562045658788374, 0.047426048080406846, 0.02469478678258677, 0.010289642922279817, 0.0807718521044139, 0.03152198616355177, 0.016628256322996273, 0.07584483422819646, 0.05918277427554131, 0.09477260687779035, 0.013226011013161513, 0.009955649654711447, 0.061122141177615816, 0.0735937231670945, 0.03590469856956794, 0.008482530566623375, 0.05173962488169632, 0.04368086255365803, 0.013756630322595519, 0.09495390158507133, 0.00963225712879531, 0.04478600567146655, 0.12196662144795542, 0.030933167154510176, 0.017618595419691938, 0.0850417810462175, 0.051129351580335256, 0.026860109402707992, 0.11126737621042038, 0.034482498472977074, 0.01440420731781952, 0.032845200039446354, 0.014643965067432053, 0.03540393753698276, 0.07340424664078221, 0.033986766807614796, 0.02068440651430959, 0.04005422147231237, 0.04752830932697943, 0.011548224832832573, 0.020749514411774375, 0.028120166990124894, 0.09545735924714997, 0.008093422060952553, 0.04396690063238625, 0.0892078897525226, 0.058852460145229296, 0.006809581273926363, 0.03725847552320169, 0.021093313604773536, 0.0443774011857327, 0.06686763207037603, 0.052998383950081565, 0.1378182829507897, 0.03594761864552575, 0.050985706264093045, 0.02688949653548339, 0.04683119995940117, 0.032909907655970703, 0.019252729910095374, 0.5467682283732199, 0.371856106024596, 0.0570918521994064, 0.5244801566004753, 5.849410535827761, 8.949455311221461, 6.040213742563802, 6.304459408406289, 15.359775077912117, 31.645445246850294, 49.06680730081374, 57.98768520355225, 52.516708374023445, 49.835466338742165, 38.01981649091167, 57.29781481527514, 85.44629250803303, 93.13453028278967, 101.63313757988715, 95.27396355905842, 99.65649051050987, 116.49929708050145, 114.62128977621757, 75.52163693212694, 48.85674476623536, 27.826117700146092, 30.028250063619307, 25.58695031750587, 11.777706799968598, 13.849615493128377, 11.96361537902586, 2.1200675541354768, 0.37087024279659797, 0.16375495571522944, 0.18508278224016392, 0.16894035972654822, 0.06394836976523362, 0.011937438675592984, 0.12529259983209834, 0.07090801808742747, 0.03023748462569089, 0.03620861331000924, 0.1454967822158529, 0.008674917269438025, 0.07769358825058707, 0.053043445241787744, 0.06355746191055064, 0.036910146835350224, 0.03238115760107194, 0.04581625986423704, 0.038231223325936065, 0.02809844265181211, 0.11217272359757655, 0.04769843064188477, 0.06047655505338504, 0.01922777459596194, 0.07443965277484349, 0.04774868217927795, 0.062490837693574934, 0.031105762933410948, 0.020501658155192292, 0.050123926297190695, 0.019872757425952344, 0.017596001571585095, 0.021115005384349537, 0.031919765826915546, 0.021505311860011953, 0.03569736070330105, 0.002773555254773988, 0.019024445284758846, 0.03606780634952649, 0.014324143468852968, 0.028152865537952994, 0.04030392017035235, 0.04343543096535629, 0.006179836411554848, 0.03872840289747523, 0.03900391109768422, 0.0413749379015738, 0.02285773092279992, 0.039706291150181525, 0.037647188535981604, 0.04897607760804315, 0.049384398641245025, 0.012578718428079401, 0.021773224298451698, 0.015421659223765377, 0.02503727596523541, 0.039646551613846136, 0.08851235852606835, 0.050954633737884225, 0.027502981660467003, 0.010243344398575925, 0.09800720629432509, 0.06598535159061994, 0.06306790108341845, 0.02098074081474014, 0.04260884890813501, 0.003297060480221145, 0.04895603674794397, 0.02903708422015752, 0.041631240277521075, 0.0930175913738147, 0.03900867233413362, 0.08380970482023493, 0.034197054112390164, 0.03203285189585821, 0.03744481108902443, 0.028031296960468736, 0.11940022690161584, 0.06421375411352323, 0.030280467903902455, 0.045320842294923724, 0.05460173702768741, 0.03987974111711787, 0.0015365861209800408, 0.021764471743916793, 0.002163100007530903, 0.03292139514439529, 0.009390115888128358, 0.046376063293146516, 0.04410354007456092, 0.05099090800109891, 0.03936075102237444, 0.03566201340647475, 0.04868628952892558, 0.0642823841002199, 0.027681018578849977, 0.013961884429708365, 0.03599864776216207, 0.03795445108065202, 0.00411104517913754, 0.0132798258170125, 0.07708854732974883, 0.017399415749335484, 0.028693108826935775, 0.02157853454381468, 0.033802989975459156, 0.03716581718875997, 0.06468284890175828, 0.07875344025031214, 0.08936163593804644, 0.04670578753575683, 0.08084722749528386, 0.03709299670111749, 0.05003889436803518, 0.0778242981722278, 0.024050186996558504, 0.009745717623210963, 0.03608282550328201, 0.02306540586775349, 0.05221680189753252, 0.02071093422390761, 0.015769201713884552, 0.0756011876247583, 0.01765894335544398, 0.07550937198703328, 0.035838006785319704, 0.027859658791473316, 0.042762464858711734, 0.09226383746511514, 0.054875368312481916, 0.06141959779685544, 0.008488313572841787, 0.02380213730277554, 0.0444473794871761, 0.04941031156528381, 0.08131583581768698, 0.09964819727165085, 0.08063471470508846, 0.09041877598651955, 0.08236926800060658, 0.043116385988410444, 0.07332617462041878, 0.03570371923307258, 0.08070073616240295, 0.33245672501863976, 0.43332908482801535, 0.06573445013453884, 0.1912956020884937, 3.5166404468397943, 6.305022268526017, 4.500795727775944, 3.87860240474824, 13.898661790355561, 30.541586337550996, 46.416457853009625, 57.30582429516701, 53.62844144144366, 48.14389321111864, 37.40647938943679, 59.88729692274525, 89.791454961223, 104.34063988347208, 109.9098877752981, 103.26283531804239, 108.76230424450291, 122.93883262142059, 120.32054854977517, 76.7947284636959, 46.426350070584206, 24.65673669692009, 28.262889308314172, 23.505062134035175, 10.35513864409539, 13.053884256270624, 10.27048703162901, 1.5280506183062832, 0.18268083612765038, 0.14237048464917368, 0.13427256756732542, 0.11179757800193564, 0.03874282833308943, 0.04526155858090328, 0.19848498485742078, 0.026353522271458662, 0.01656996277761796, 0.07305239011803943, 0.0840613876859988, 0.033116115542549285, 0.07373750254872345, 0.0755778142821885, 0.0409214559852356, 0.05012887522518154, 0.0444089716690923, 0.05668654955262619, 0.0553735361374434, 0.016820864233699058, 0.024658200338542945, 0.029502314094814564, 0.0396190184138475, 0.007680406823994653, 0.027433901597114823, 0.041866299035328056, 0.06421044461369034, 0.045754340807757074, 0.03306680629330297, 0.05856534188252784, 0.03806579429956694, 0.060787732307348526, 0.03506570588797331, 0.07796980891256564, 0.0800218673483018, 0.013438142674614587, 0.030369485405484037, 0.021698668621660724, 0.027993178340576352, 0.04541194930131878, 0.04989410375034617, 0.0566635171191827, 0.01968853434758081, 0.06241530142424088, 0.0366834192837198, 0.037449683408222856, 0.03895011257320162, 0.01525243040129182, 0.058955066131367806, 0.08103837409327108, 0.07887337131485825, 0.06671325769275427, 0.022020975217944192, 0.08159779447821841, 0.03987450490615541, 0.02878162454092695, 0.02489276113919914, 0.04671414555501073, 0.04222016653887207, 0.024195324269033248, 0.05631498924847092, 0.06466627075907684, 0.06779128895892252, 0.03016285808576692, 0.003974301836288144, 0.03290952844244819, 0.04429781614171882, 0.03175035888899959, 0.053625706538197496, 0.024618520814504836, 0.03266646023539286, 0.05471601819379195, 0.0632958160713315, 0.024813319736671065, 0.010615624825380022, 0.0931686792342413, 0.01785642167012538, 0.17311250520569665, 0.18694226149349444, 0.10705442122754552, 0.1373088344811432, 0.18700302758764836, 0.15770854548581187, 0.10161708154144788, 0.10466248788420232, 0.1640584337855539, 0.08116490117484525, 0.12253962457180025, 0.20267242145153785, 0.08292979155216487, 0.19628248207511442, 0.139283548680044, 0.147344479036908, 0.13210395651478923, 0.1868619141919959, 0.06623054569166514, 0.17576238801402433, 0.10287417819903744, 0.15876580810835286, 0.058113978199300274, 0.1383495955697952, 0.1506624671240007, 0.052426752123621204, 0.18268425287979265, 0.0905154103172883, 0.13072011061012745, 0.21849811257373905, 0.08002588164902504, 0.15341983206810492, 0.13928157217319936, 0.13818580597158403, 0.14651773227078302, 0.2872318275753529, 0.11659613825500974, 0.1931261691835619, 0.09776877674965129, 0.08462693677434037, 0.13125948247409638, 0.1613132802829627, 0.1769804371701133, 0.08961773913113341, 0.12488366209811742, 0.14485193536646906, 0.06442568084645657, 0.2569213903118526, 0.13812533099084132, 0.15456540930655696, 0.10356332791308243, 0.2656846241124215, 0.3139066107330784, 0.20304325397216505, 0.09664600594870507, 0.1419010566126916, 0.12977402266715804, 0.12389628201602929, 0.2336165513242445, 0.16611073736942586, 0.16854390922573306, 0.2632004461221157, 0.1532437544195883, 0.09799643509810972, 0.16144323943843766, 0.17357448686755475, 0.2749427047468001, 0.7898522168397905, 0.4774999065745262, 0.11556113048666909, 1.3741667208171662, 10.60585262313966, 13.376950275513435, 9.571378481003547, 9.164842463308766, 22.558925651734878, 44.30833293545631, 66.10530484107234, 83.11467878280148, 76.96090359841624, 69.38200581458308, 55.37194282777848, 84.70064993827575, 121.50966213595484, 135.01846190421813, 136.33576639236944, 133.77204248982093, 138.7114675583378, 157.65307949435328, 154.75333398388278, 105.45877425901352, 69.35898934641193, 41.95600517334477, 44.03725008810721, 39.13770375713226, 20.05729483019921, 23.671364745786114, 18.7928540860453, 4.027506117859195, 0.6907876713141319, 0.23228774117606305, 0.3006173754411359, 0.6870517975861027, 0.11204600499402131, 0.14331309455296687, 0.408784608326612, 0.19400311003048576, 0.11995182552885626, 0.31101901084184647, 0.2837252286413024, 0.13344749087287536, 0.19309256856720294, 0.16259728960933226, 0.2088013087068835, 0.15275679829139865, 0.12607696661425213, 0.10759442894449157, 0.13764220530227309, 0.12430715795245864, 0.17652371087141577, 0.17774893061047603, 0.16458119686332442, 0.1478217058484593, 0.14687086816035932, 0.11895261704921724, 0.16330923043912457, 0.16585103356309477, 0.16123140080561563, 0.12211590900175995, 0.08850082124192869, 0.0918428338463268, 0.3535063696965095, 0.1597374067792008, 0.15063963770385713, 0.1537773806241251, 0.13147412498872127, 0.1528730291512705, 0.0768024517944263, 0.14793850361339508, 0.16589491507939755, 0.0979512435714564, 0.209500792947027, 0.09695772712509479, 0.16715349028668097, 0.12706216334575607, 0.1073238620113942, 0.13676183238144846, 0.13425465643165574, 0.14049565299384056, 0.2307323375416379, 0.1516802149314073, 0.1136183468324523, 0.13430052977656165, 0.09980050321187704, 0.11723961380700912, 0.2364882931954438, 0.15333611397973954, 0.21995528841451292, 0.11141568317168182, 0.1020036112036436, 0.1329766225910956, 0.15971637000480007, 0.21196117624640468, 0.14503250229022197, 0.1565654503722345, 0.2049203072824786, 0.14163686353112423, 0.19758040355818887, 0.16365404661384322, 0.30577351489374716, 0.24343406000444967, 0.2069996997353531, 0.07999523813205381, 0.18614370676298297, 0.39061962176234494, 0.15000554672893018], [0.022703473373586615, 0.05327879128256633, 0.03624238246571153, 0.029115211781895453, 0.05388931739294241, 0.022173484171470328, 0.019428861184766697, 0.026007131786055626, 0.05552915923838174, 0.02412502038022203, 0.00877398488697626, 0.02123334107079333, 0.05246378481388093, 0.013361509941938906, 0.018181911361734235, 0.02120966320827363, 0.0248991790407848, 0.032020667267422524, 0.03824947537073205, 0.020083450757327582, 0.02979554382393197, 0.02099477363029315, 0.03153953340745742, 0.051776163445244876, 0.03142419120957775, 0.031701524614266334, 0.0376956359363131, 0.0368641815598934, 0.03757568188912926, 0.01798690559582845, 0.039203568932510195, 0.04025105244269775, 0.042631145897171194, 0.07031726470637707, 0.05709911088248896, 0.09343887844513502, 0.01884243045482905, 0.00932822939038517, 0.05759579249687734, 0.038869470327852235, 0.015327478289574146, 0.0450606826662777, 0.010375700451643958, 0.03878666771455638, 0.03199534423108543, 0.021398331511825807, 0.04881093203420601, 0.01822065051284529, 0.06629266010056581, 0.07583998489163576, 0.043500146242759885, 0.02173867181784684, 0.018991878887097684, 0.03345587170652805, 0.05406647522543227, 0.010704938228422356, 0.08333292233967975, 0.027968025758802414, 0.1169506760854875, 0.05281874016227742, 0.17618706119396996, 0.47343752617316864, 0.15894519525670237, 0.05850295551241406, 0.19302722126726182, 0.6005394494821948, 2.2547781707779055, 8.070547273082118, 30.393636495836322, 51.00947487738825, 81.12503297867315, 93.75402942780526, 112.61291073214625, 112.49465127145092, 101.62438284966254, 116.06102712692754, 123.15879914068408, 123.52687435765421, 116.03044832906416, 116.02767913572251, 123.6223291581677, 130.39891396799396, 123.31686281388806, 116.59848597741897, 110.46444031500049, 123.4234179219892, 141.01589141353486, 134.5428196076424, 116.61652888021162, 130.5516432177636, 133.97787278698337, 137.05945937864243, 142.54191306329542, 132.20695403314406, 126.8868943183653, 127.30942772280787, 122.01841708152526, 122.40107567079606, 100.0251619277462, 76.49602428559335, 43.398315598887784, 14.856153534304712, 5.28497068151351, 1.9359159517672755, 0.046062449879583814, 0.3315144062282578, 0.16721880694310512, 0.07661675974245995, 0.07556992357656842, 0.05159802118977232, 0.024039505815674222, 0.06615314016779585, 0.04257510273507045, 0.01592235035082746, 0.025612763129174713, 0.03132513029530885, 0.083590044429706, 0.008376625614360938, 0.03897832759145287, 0.0023352801837327503, 0.034166556152124564, 0.0446494581598428, 0.03271349420350406, 0.05595685080474904, 0.021715216120825182, 0.04235041680775824, 0.034322972154064525, 0.020181870072959893, 0.020168984474073497, 0.01803902255731725, 0.01747036889766253, 0.0917581428262976, 0.024024237683343313, 0.03719302480139079, 0.014565822183935633, 0.026427378893018733, 0.030669799532681227, 0.02112807867477738, 0.010247147067510074, 0.11601149059471585, 0.10096150180024487, 0.05821466130474883, 0.020755815484951583, 0.009126385332145279, 0.06735696307113094, 0.023719687089924852, 0.04045128867390656, 0.033547495822272, 0.04388871369883419, 0.08268447487705177, 0.05917303346758408, 0.02133046761305342, 0.046942420604248206, 0.02692237894441332, 0.018254084505080696, 0.008329806150868535, 0.029678225119207657, 0.04516405090990086, 0.07440521712264708, 0.11599898037891235, 0.03548104428656159, 0.08452702358725571, 0.052907610191933574, 0.049994959225577694, 0.07391659858366174, 0.01316902939335353, 0.023676623372481238, 0.02562253458064891, 0.045330464359252684, 0.029905042686169187, 0.06349958396787125, 0.01938366008201434, 0.07232178738641162, 0.03232870739133608, 0.0779628758168509, 0.019187495608123082, 0.07434232896494289, 0.09575600330267223, 0.030458225200193065, 0.05724824521870864, 0.014952803838006673, 0.020764403330582767, 0.029001267694477594, 0.048188815013535564, 0.06149681945962291, 0.02045041070349755, 0.01921595768972991, 0.039258164188434044, 0.07791743914206183, 0.015455300059740343, 0.04367120218493285, 0.058442829101676905, 0.05886907276186732, 0.022257658082150647, 0.06037350473625045, 0.039747253871492805, 0.00868482948956831, 0.013465677789833038, 0.050872754260537126, 0.031513292980831, 0.013537456397898497, 0.04942994639878312, 0.02986350156847508, 0.009343978242888566, 0.07710090432796748, 0.006253668614062331, 0.008892606898781755, 0.01666750875301659, 0.06375147750781429, 0.06949888362038521, 0.007821324867226424, 0.08339581049738393, 0.01920570551808323, 0.038163845892995596, 0.04782503433225136, 0.03739238769236592, 0.03812799297813927, 0.058510156738902294, 0.052589534316211946, 0.06669602071445796, 0.008954488608475414, 0.09235990489081991, 0.07616007940903788, 0.09447577845064864, 0.04765929120983328, 0.016296540251782825, 0.0443902523106625, 0.03340644371365348, 0.02974490732735684, 0.05837077087151909, 0.06221022734779024, 0.03073627298187104, 0.01616265489569595, 0.04673553472985664, 0.08057885157364993, 0.08247648200560963, 0.08804568840611367, 0.31104665129415454, 0.15750773851909947, 0.1777455291800922, 0.2474170124098178, 0.16549806621286178, 0.9810651886847712, 6.033310371060526, 29.495576504738104, 50.31811398844565, 86.042445705783, 110.25628012995567, 131.34148305462253, 129.72433690101872, 120.93292467055784, 136.73165905860165, 147.84679320550734, 151.9922834827054, 141.71983134362006, 140.16963220411733, 152.21552910343294, 157.21178147100633, 151.36377857577418, 144.05237074821227, 133.18497350139003, 146.85684973193753, 160.11264093460576, 152.84872516509026, 140.2559086584276, 156.48397784079276, 157.1957782007033, 157.8626281984391, 167.20257605275802, 157.13360078873174, 157.9906229819021, 154.86683168718892, 142.1950186452558, 139.81944299513296, 111.28656910311793, 80.76568111296623, 45.032990824791696, 14.171276323256956, 4.668378503091874, 1.7389508240645932, 0.03821683619471808, 0.22885126993060115, 0.14594120514248649, 0.04348418097041788, 0.1328152078654497, 0.022091259954557307, 0.11960486430794963, 0.10890781774275726, 0.05098425452747653, 0.08404437287320053, 0.05074174939504555, 0.01064732554368675, 0.08087159675215522, 0.019120583573596615, 0.04188864582007931, 0.014516542620596387, 0.03809248863328849, 0.07956849651471262, 0.03251548345771528, 0.057647821358254844, 0.07565151194050428, 0.06035098941215585, 0.01884049225238062, 0.06117742974311114, 0.05847556786912103, 0.014713493292219939, 0.04180175612770742, 0.03941494408213804, 0.05645811745536424, 0.054318816926811016, 0.02803131036700741, 0.0369030183872148, 0.03406557810282515, 0.012685060050458679, 0.07052289802701243, 0.03316777668172314, 0.03387924253700241, 0.02595236032990919, 0.03078232061177973, 0.03526164436592691, 0.041827243872948235, 0.03333858364532071, 0.023591558884588942, 0.02655304604089789, 0.05890487971144819, 0.07763007190078497, 0.026831970993249167, 0.03277648961351764, 0.026580399210234324, 0.053534806375542, 0.14525056155698915, 0.0912157142715108, 0.018587470647969076, 0.0458077869317945, 0.030333450544745694, 0.04335001982267826, 0.006983992202402724, 0.10049497723699578, 0.032924651018073486, 0.033758032105622754, 0.04399834088079872, 0.0346026478725816, 0.011731050758352204, 0.038751546413667744, 0.07378123084744138, 0.01183823124700857, 0.012471033279002916, 0.046572005601539734, 0.05263658743652125, 0.017905449382059516, 0.052843454158714706, 0.04654774359697777, 0.17404356250359168, 0.13899954456475475, 0.10973670189419102, 0.11054446500155235, 0.12388086066611352, 0.10398884378974477, 0.07224224447723358, 0.1225714018988994, 0.11134034608520808, 0.1395522003933307, 0.11775905206318825, 0.11269654387668257, 0.16108011376232872, 0.119906319906154, 0.11765873284950373, 0.17383345522947852, 0.2080692044429241, 0.07857786821982554, 0.1580269775924183, 0.19459325820207599, 0.1782526640642074, 0.14539398853817295, 0.129144283071641, 0.13936043326412478, 0.0854593449302258, 0.10886381365238659, 0.17780919108659993, 0.14713688453118648, 0.22293095777352012, 0.10150924700522616, 0.15143123635601613, 0.11547789503369602, 0.19558718067503747, 0.16332246843845616, 0.11480678669026784, 0.257788218798176, 0.06816849533107973, 0.1441097953507016, 0.14861379479688985, 0.1930668739782226, 0.16193610976540274, 0.14752273237512958, 0.22910269998735, 0.14198774712220316, 0.12121813056329567, 0.18553938596479355, 0.16509308149257015, 0.16878760179444668, 0.12198879969336333, 0.143797920956727, 0.13686491717253962, 0.13001720961784163, 0.10625745995991653, 0.12102553605913155, 0.17499725003876995, 0.12656692580710496, 0.1983731666639928, 0.12545508708083822, 0.1841562755045391, 0.28508098976266, 0.38046252162706473, 0.6288177772395073, 0.27182742352447203, 0.24611461697326553, 1.335239893486423, 1.4759112870500934, 4.419699253574494, 12.600004250003446, 46.68803884137062, 77.07669981064336, 111.57882490465718, 132.933376989057, 152.44556826929895, 154.47512811230075, 141.785523199266, 158.9332312922324, 166.2152997909054, 169.89316509615992, 155.52288732221052, 154.41863029233872, 163.96315328536497, 171.36024136697094, 163.58409543191235, 153.07674038794735, 147.66608176692841, 159.36600992756507, 178.19114315894345, 168.87995412272792, 148.630890692434, 166.53370211201332, 173.91426917045348, 177.9132040085331, 186.97483616490518, 177.08657233945786, 175.59770337996946, 179.14617753797964, 169.75327768633443, 166.4553488454511, 140.17036960970972, 108.72122918405842, 65.18039426495953, 24.447107584245746, 9.261315118881965, 3.520656463599974, 0.15764005722538119, 0.39622450487748273, 0.3179728522175743, 0.22955352740903057, 0.20981248347989975, 0.20645809089464529, 0.23722039745940318, 0.1712573007229836, 0.17121475219966906, 0.1354021488899185, 0.1541081620680709, 0.11908934842194281, 0.23062988094264464, 0.09353604903745075, 0.15166037325416842, 0.10623889764951122, 0.19971116986726561, 0.1310216887823997, 0.22262538062228313, 0.18838345674016785, 0.17056222914928393, 0.09200854632522791, 0.11668422304454351, 0.155980879320733, 0.13459486075707022, 0.080210646734603, 0.08729570365000157, 0.20220605776675288, 0.14967594506038776, 0.2392370473112791, 0.1745864277284953, 0.08908234326349151, 0.19693800819016274, 0.148477339215817, 0.14948433114876672, 0.19427280362334945, 0.165592065201171, 0.10418803431093694, 0.09656422606278812, 0.11410950112246698, 0.13836752202722336, 0.0825324600502368, 0.0928649636766603, 0.17613683646965414, 0.11257040749994979, 0.2406014805479396, 0.12432665489013157, 0.11524971574544908, 0.12211802340443097, 0.14621514286245071, 0.17658257706751748, 0.14917915236325036, 0.15349334586531888, 0.09641120766079235, 0.2007943262616473, 0.17490556463599208, 0.10819052195837421, 0.19574467303051105, 0.12258064858014546, 0.1661652215426007, 0.1885345905658699, 0.13722453416595537, 0.05258479606240027, 0.11269030026009969, 0.14636690488025067, 0.20698257000936618, 0.17602575372063345, 0.08732278485812488, 0.1562591224548317, 0.12599733943540242, 0.15647777927017983, 0.0982074233733358], [0.05772739108051023, 0.028953766412732583, 0.05181828295932182, 0.011633587137405432, 0.025072634753380573, 0.02893646431696271, 0.05691431515339402, 0.014033205300239066, 0.06421749262259373, 0.037543092508830374, 0.054314228060144576, 0.06266409996896982, 0.03378954130194841, 0.0328189883411171, 0.07459596535491367, 0.03461936008064978, 0.02440558667595108, 0.02914301311266759, 0.02561004926270295, 0.04145412074942743, 0.019147145757151228, 0.06463784889708604, 0.032541875186706745, 0.05446890504249642, 0.06460667677944706, 0.07610774794293028, 0.03627833880243763, 0.02736290056829251, 0.016240516241880196, 0.13749720017996528, 0.042074506411389004, 0.07797380023065113, 0.07742970926506866, 0.08101417337574306, 0.040010891539315065, 0.05488876719027758, 0.029210673998140042, 0.033717299210688764, 0.05424358326220705, 0.04694063178894501, 0.036923664456774155, 0.06861271141397376, 0.06513785150262617, 0.015865512372505282, 0.0465883041221288, 0.030958179925237934, 0.009402808049813876, 0.04610754947568621, 0.027697998917691653, 0.059965191363927826, 0.09023795625375164, 0.06171838740908331, 0.13170867046761897, 0.056335198647913434, 0.06289725882872459, 0.11105938333897822, 0.0908816233277321, 0.13776042799074806, 1.0575397625084848, 3.394389484197863, 11.732868225343767, 20.772923423397927, 42.93023170963411, 59.288245093437936, 64.23608756834462, 71.75400426310878, 84.0378164475964, 92.24241072131743, 105.08706692726382, 117.86520757982808, 107.6872218039728, 108.87715908788867, 96.80681013291883, 84.82560096248504, 102.3194189994566, 96.53296593696841, 87.12852647227626, 102.12201395342427, 104.61493122962214, 96.24790376232517, 91.45945856648108, 77.34372692723429, 96.8851790889617, 105.51013377404983, 73.33857121006136, 108.85911618509601, 78.66800538955196, 85.3181565192438, 118.4381325014176, 108.01216663852816, 102.40309884471279, 93.70353283420687, 109.32397196369787, 111.07876193138861, 99.52448706473075, 97.90017866319226, 91.64490822822818, 99.99223755251978, 108.91120526098437, 129.28886751974784, 122.74399280548097, 107.49042864768737, 106.36776785696708, 79.05409213035338, 39.856933086149155, 21.468275323990856, 8.964728040079917, 1.1887177945144716, 0.059422827926614595, 0.1739554777140579, 0.031619262092957096, 0.09738923380932502, 0.08579768766198428, 0.013159226340752457, 0.07778119806560778, 0.021504287217413227, 0.03121109427734008, 0.035458291475210464, 0.04964535883177192, 0.05342829334098966, 0.024612206334788955, 0.05574206273341852, 0.04974635603326944, 0.011941643540687379, 0.014838917207183137, 0.0437746393764692, 0.03849295726526649, 0.03151431187777029, 0.025674915842471585, 0.01727930273890736, 0.03943190526878161, 0.062376430122962886, 0.049612941821255994, 0.04089452799469714, 0.0815550544329228, 0.03632195601840654, 0.027683196183774742, 0.04549339976942828, 0.04874794045463205, 0.009858284667584925, 0.004354986247621597, 0.024991709055499207, 0.04009771228377377, 0.04785088213881658, 0.01562154209691911, 0.06579625044739054, 0.0582816442024083, 0.07162617189028571, 0.10615229140967132, 0.01638684861151682, 0.022885459475219253, 0.07196404730841037, 0.0071596968618612145, 0.01885057588468396, 0.09417606187203238, 0.060098165075384805, 0.04730511727111955, 0.049486196404623414, 0.04117440289607452, 0.06059206196016843, 0.04099396237682912, 0.059964222262703606, 0.09198538748727692, 0.029703492614170237, 0.027230497592339115, 0.0753376687005643, 0.021526097740617492, 0.018650071522701653, 0.038657424851290645, 0.061475246423675176, 0.035015465841899, 0.010076136133002659, 0.0076018483377993116, 0.0493599106407454, 0.05819039163930763, 0.03643801450849541, 0.021967391198080395, 0.07625780924553834, 0.09568277295799026, 0.06548947819899167, 0.02497877366089773, 0.02687982659065916, 0.05655086388991726, 0.013202176102617336, 0.04477214714091632, 0.02324627348101668, 0.050119582578660025, 0.036632470606315526, 0.09624519640760076, 0.04911454800035685, 0.04555679737560211, 0.02375395611799773, 0.06511490716929398, 0.07212382260589831, 0.04314262833025667, 0.04468429600819946, 0.0924901934641023, 0.029332282795240323, 0.07634320506645788, 0.09291984621555575, 0.01583271710607674, 0.02551986922269627, 0.052198258739325314, 0.03794110199857143, 0.0133667528561707, 0.19395532146576913, 0.0032679615880272564, 0.04416170913065153, 0.030705964628366694, 0.02413730651530768, 0.06486581368071419, 0.021146903370296764, 0.029329969209708998, 0.04595442382138103, 0.012884548388331408, 0.05141617489918586, 0.06180363767329724, 0.04777627283587091, 0.08133920149937754, 0.012129664499943536, 0.08626352274610151, 0.029861911936032198, 0.07089036742165204, 0.07283331195433294, 0.035390619098419146, 0.07475408590248517, 0.07347244378780166, 0.061913222720425945, 0.039132158046648394, 0.0299526339832453, 0.053937381749311765, 0.04680657023263555, 0.08671280267017503, 0.05782641177516311, 0.6018661299059468, 1.353305962777907, 6.37848335889078, 16.407102827102907, 41.58391737168835, 57.692271894024266, 68.466171603049, 81.47140964385002, 91.68597544393232, 105.82146013936689, 124.63848975396927, 134.68728834582913, 128.35744580914897, 125.78883463336577, 112.1384451466222, 99.22350791192825, 118.53452867077245, 109.13012058504167, 112.43569020302066, 125.28149958579772, 120.390562857351, 113.73922717186713, 110.60467289340113, 110.51121850167553, 112.01987189631309, 118.39020898265224, 105.46653270721437, 131.8879084433279, 112.92732008041875, 121.93660428447109, 143.31061916966593, 135.62679013898295, 121.99850713053058, 124.21200260039299, 122.65255451202394, 131.27788574464861, 118.31772358186784, 113.39193267206993, 109.29402074506207, 123.2636990085725, 127.54497389639579, 156.2539072959654, 146.09879678295505, 129.92768826023226, 124.8744438540551, 94.39570565377512, 46.9552150080281, 26.09835090175752, 10.236197671582623, 1.5142810152422999, 0.05952526920384938, 0.1731571834534407, 0.05169274030073036, 0.12634960198474507, 0.0658275987652521, 0.05907206307916392, 0.029710442946863272, 0.03366251243278384, 0.015143152746942737, 0.0006078995061069427, 0.06881980796254451, 0.056137628402681126, 0.017263423651456833, 0.023804180842313557, 0.04629011971936111, 0.018300672226976004, 0.01455443715977092, 0.05961989638425651, 0.04073472971457147, 0.02778056212851117, 0.018167196727928617, 0.04411099027962454, 0.015341280321139964, 0.03836061557634704, 0.10449872126862889, 0.07043281374799629, 0.06889018079926891, 0.036594522440986293, 0.07099868459326607, 0.016923983498746832, 0.06298196134007265, 0.058526872777410095, 0.06105549918908266, 0.07189441757697253, 0.033147670704150395, 0.04880408320816294, 0.04089099249892658, 0.06226357771083713, 0.01581394507910215, 0.013815958086671609, 0.08438728148898772, 0.08681660758391505, 0.06739225674180255, 0.015036264329307504, 0.018384796341941245, 0.009715862219191847, 0.022598724256479935, 0.0161183865049914, 0.02943406906729985, 0.045753329571697025, 0.08947900060804621, 0.08827435799063214, 0.011420193346097104, 0.1479749847203493, 0.06430080851479884, 0.035515901287116354, 0.03097006769460296, 0.033935358477455956, 0.014775607701120599, 0.036978627434901656, 0.03906841570090863, 0.03768106877443291, 0.044637177770416585, 0.013895162959553063, 0.015230260774373047, 0.02992558916429839, 0.09923052613533313, 0.03554652948232909, 0.22879005950545112, 0.16099694725726882, 0.17912364474708037, 0.10993749353914492, 0.15800407156348228, 0.10458087653762872, 0.1732618310638974, 0.089206924481738, 0.1977003882488897, 0.18113467151359205, 0.16688290803182512, 0.12072620252447745, 0.14048655186930012, 0.10166750544862402, 0.22257245926847383, 0.13791215936503104, 0.12710496467808563, 0.17564437983016815, 0.1118199937346001, 0.12443961455456673, 0.10983920445845974, 0.12150213467858492, 0.12065616676643973, 0.1609717582863185, 0.10000059771681986, 0.22001980833949583, 0.2223139658810631, 0.1203168127986212, 0.13879945772069116, 0.2525035910789044, 0.18110799633206862, 0.1775745383553928, 0.21074553260639792, 0.13927305327548137, 0.14294644487240624, 0.12311304904400341, 0.11643836244700417, 0.16949514527955364, 0.13073769998886894, 0.16515536444081416, 0.1619732190644549, 0.1427305459735855, 0.21959409327997317, 0.10286923693192583, 0.19207813025962925, 0.11842408532937689, 0.11849900106749228, 0.2451515218783771, 0.21806616155851274, 0.28103429884199177, 0.16080049166996635, 0.16963005336301942, 0.16428924075538115, 0.1332085020840168, 0.14980590421586268, 0.18456187309517016, 0.312675139716556, 0.2174594046007241, 1.5651987733379489, 7.90149066717394, 20.08095652826371, 37.931759280543176, 66.97819694395989, 86.36101276643815, 95.60173250013783, 105.94653667942171, 113.88248782004081, 124.95384831582348, 138.80044260332662, 150.37358407051335, 138.50949687342492, 135.3471722141389, 122.39530978664276, 109.41777936873898, 124.60996627807619, 118.240994176557, 110.27506043834072, 128.0418832840458, 130.21015382582144, 123.15216249035252, 117.44968737325361, 99.83709212272399, 124.82577508495702, 134.96802022380214, 102.57675001698156, 135.83232233601234, 106.71346987447431, 113.87282309993621, 148.4929330887333, 141.19901903213994, 131.70689890461585, 123.70043139303885, 138.2812463083575, 138.6577153974964, 127.94374558233447, 125.31421999777518, 118.99092781928279, 128.68914496514105, 138.9507007598877, 164.4262283079086, 161.59289636919576, 150.3235032481532, 148.0070455612675, 114.77031630854454, 63.217283295046904, 35.98971143845589, 16.288716869969523, 2.951956670130453, 0.18863281835952114, 0.3533262164602357, 0.185204069280336, 0.192156623628351, 0.2346036249711629, 0.20642934727572626, 0.32082263800886374, 0.21083013935675546, 0.11581976943078542, 0.12546531435462738, 0.2175005282004995, 0.15425753389154712, 0.0970857480781213, 0.1610279584964437, 0.1272257461002277, 0.15871132393517803, 0.13126196459897105, 0.2667945016536021, 0.16065899523035174, 0.12414239542258364, 0.08485304762519176, 0.17081030374092443, 0.14509340628020226, 0.20098408624049158, 0.20169360623244317, 0.1895371238671003, 0.19414492822702856, 0.21709425645249508, 0.15977624743696184, 0.12269395298414654, 0.22870966623867714, 0.18819509104134577, 0.17149085028757974, 0.1161697107337175, 0.3125379793345928, 0.08535991437853345, 0.13077664789893936, 0.20515246256705255, 0.14235720068456667, 0.19777445362940912, 0.19372413145197978, 0.1705345427317004, 0.09085422802355983, 0.14637393756739556, 0.10564523313434855, 0.17423139194086676, 0.18762579578305447, 0.23088439067284908, 0.2107495775506381, 0.1422959596158997, 0.15063341706991196, 0.1605291280054277, 0.1602601851787298, 0.1992831871874871, 0.16230004749471144, 0.11505815545998274, 0.20475307028860817, 0.13228194938311655, 0.09240371745920951, 0.14810624622529553, 0.22110890957616994, 0.1639026881105477, 0.1466950356599785, 0.15559709991418547, 0.1192675864384059, 0.17206313328877573, 0.15710532785423342, 0.13974108703194127], [0.08310123436873959, 0.08876652351670689, 0.03250339075983052, 0.07391308990096854, 0.04083617890794431, 0.07686240583538048, 0.04674732865345094, 0.04993689742179648, 0.07719271230481325, 0.01557524165799541, 0.03827621950016868, 0.043982321982302015, 0.017861738320319884, 0.06174100615504769, 0.0419486343349901, 0.14030986135044407, 0.024589265831896377, 0.031865394651709546, 0.07907964814935001, 0.059759435469224575, 0.03517261345780665, 0.03370149864725048, 0.06331528236548747, 0.03732609810427793, 0.06196319080528714, 0.004473511540826651, 0.09843727273325767, 0.06627644968008803, 0.013785992557513378, 0.10519380816408705, 0.029237772443241654, 0.02082889644248832, 0.05826816105494096, 0.06028772587136877, 0.03978932358985467, 0.066936350157184, 0.03496654729749407, 0.024162079883559097, 0.057340168108743046, 0.01410704468482084, 0.004779553132867742, 0.0779304090106199, 0.0425930981404118, 0.0231755827178037, 0.0401218785273452, 0.034662092465066144, 0.06601379643524848, 0.009199851248863964, 0.05041153102572407, 0.017284676845696186, 0.03503635322915451, 0.027249054157085, 0.028551179547643954, 0.047302711755037315, 0.03632633804133342, 0.08221737574785948, 1.0945269777890176, 17.66737114998602, 38.69245982939197, 69.06687475019886, 96.09451555436658, 103.17105970075055, 105.90011150606217, 104.76069434996575, 107.22558236891224, 98.87714693623205, 96.13505717246764, 96.40523787467711, 98.03832454066124, 84.91336007272044, 71.81422833473452, 50.426489076306744, 72.75070205811532, 83.25646461979036, 52.955994221471975, 65.56835982107347, 41.44786996226157, 34.166225079567205, 37.33541780902494, 47.43160255493657, 33.586953763038885, 34.160165017650975, 44.85762557675762, 50.9425513975082, 23.139097152217744, 29.609446833210608, 42.03812783764255, 33.34763819171537, 28.610583889868956, 44.80236330339986, 53.74796390533448, 48.74567108769571, 76.70958165199526, 50.23284558326968, 44.45535513662523, 87.13293521634995, 67.23624183285621, 57.439628108855224, 88.06851463933145, 81.95284920354044, 101.18692090434413, 126.60272644412134, 117.28254733547088, 123.18016821338286, 131.65939115708875, 115.60629106337025, 93.12995679916875, 74.88070595648982, 30.926419881082353, 8.565290531804486, 0.8209240076041991, 0.08411190352372586, 0.05685744844677468, 0.017143402571579622, 0.049532165510519865, 0.021450477201611768, 0.0805350696487773, 0.08453058589610361, 0.07133343437265965, 0.04341867662245228, 0.039193651924330386, 0.03640686920393379, 0.04628891696131999, 0.0021524233752936725, 0.01775984479595096, 0.06001874474027465, 0.035392281509214835, 0.04274722353945817, 0.014052541359447905, 0.024011455506326693, 0.013026406804490234, 0.01520401843252682, 0.010832359717648116, 0.04784620517203885, 0.04235091859534864, 0.034441064607592366, 0.014210133306351642, 0.033390183497460625, 0.1250833352547019, 0.016974202477403225, 0.057777171473829984, 0.009377372015507953, 0.03644230460087138, 0.06377277475210928, 0.04758016198813435, 0.03360282652260315, 0.018765812086301948, 0.07957405065216365, 0.04563584232762937, 0.057835800182675166, 0.038754277517117804, 0.04176274310016344, 0.04786495134354599, 0.029620448683178233, 0.02592432534232015, 0.012305693310354988, 0.08792114549226339, 0.02309795119799674, 0.025081626710391818, 0.030866297254819545, 0.013184632689151312, 0.029881816815524816, 0.0019345075106098047, 0.091526408890082, 0.027360460578253674, 0.010051870298001074, 0.005719311753167741, 0.022923110781477827, 0.025039175863287626, 0.028953521264596816, 0.023347617337299932, 0.05369643177536707, 0.05622914526611567, 0.028815776740591374, 0.02922107747215177, 0.0377933542814947, 0.03991427636074443, 0.048757382488298806, 0.02546602856337784, 0.09624889661227504, 0.04047197304786213, 0.041790046473784793, 0.03899987381432326, 0.02945329212853986, 0.051719859813249884, 0.029659722180616473, 0.029837979349277677, 0.0736294994731584, 0.0170255629270668, 0.030818525927081227, 0.027728697976037383, 0.08679757795987592, 0.0508454738695535, 0.006348374318481694, 0.04015289359695969, 0.03373224941653109, 0.04997991708918445, 0.04347416054036829, 0.013448433150657484, 0.026213563753352053, 0.054264470649462555, 0.05653212537928935, 0.04012787316535269, 0.05014428125333883, 0.01969804341394094, 0.08357158171073084, 0.08729931958500417, 0.03158095195108364, 0.02255976102465103, 0.041147528531690764, 0.011845634529186834, 0.015502741012061316, 0.09348384780629028, 0.03802428765582942, 0.048249424059665015, 0.028862611525842262, 0.037735438034419096, 0.05175369025598611, 0.027809495354191433, 0.084218489336631, 0.03548524244838665, 0.042370162724006566, 0.024231041203283017, 0.030358641430915847, 0.0920296443866626, 0.021493730525816643, 0.05246496841972394, 0.05559536838723768, 0.025154525722046534, 0.05562408902351895, 0.03655911002668642, 0.15631976597491773, 1.3485097620756397, 11.56949366292646, 29.943285642131684, 65.97584309116488, 102.33690492568478, 114.18724029294907, 125.05932084975706, 120.88236531903668, 126.40940850780858, 110.99894169838198, 109.74503055695565, 115.32030320936634, 116.37753886561241, 103.69510404525265, 99.49328853238015, 101.32541195038827, 133.09173091765373, 124.12112128350043, 105.12799293764176, 110.2396414356847, 80.29815027790686, 84.64113189328103, 82.94775055300805, 77.54641148351854, 78.3174474777714, 67.24252546987226, 88.18689177113195, 102.03521974625127, 54.14032643841159, 67.34054550047844, 69.9117846642771, 70.63025305348059, 67.28211002965128, 85.83183796175065, 86.50600710222798, 73.333464284097, 109.57286988535236, 86.42776366203063, 91.20120186959544, 119.00222424537905, 98.7820137700727, 92.49079089010917, 118.48539706199401, 108.33176920490881, 123.90888183347641, 139.27390406208656, 132.2491430467175, 144.57268099631034, 148.83676805803853, 132.93210614112118, 112.75691663065265, 90.26522236485636, 39.254711981742616, 12.629756408353007, 0.8181999215195257, 0.01352266324008064, 0.03391731327639953, 0.013807877774290262, 0.09067885517593353, 0.09698444061101445, 0.09536549764414949, 0.021361925098444187, 0.05955515046333594, 0.023982840207135005, 0.03957802887945887, 0.01738261161071639, 0.008904513820344883, 0.04855031658324504, 0.03497954397912949, 0.05195924313738943, 0.022127555285189903, 0.07554605993772708, 0.09263405711540292, 0.07666676230127774, 0.03264105675982372, 0.03690815883718672, 0.03841432217027872, 0.031752526917825305, 0.07993428817679805, 0.07042461660720649, 0.020998588748156063, 0.02400448985187517, 0.0015429527904357641, 0.012355213233780478, 0.053160013180346265, 0.07442573295725931, 0.038802966235145446, 0.09612263000059514, 0.03555103790976348, 0.06123623465217891, 0.023154237593013435, 0.05676385165462571, 0.0961193511442792, 0.010596255249824497, 0.021312803540739323, 0.050402215396564816, 0.03575817276273043, 0.011851655980271679, 0.03887094121666686, 0.02969213344547297, 0.07026715489524989, 0.0443373654308098, 0.016941524996993043, 0.008685748795077445, 0.005551332132815714, 0.025318489605260473, 0.03596890439850188, 0.030059767549016306, 0.04555727618055479, 0.0017655645346929952, 0.027212226395345023, 0.04949676841797848, 0.028932126344091473, 0.0042636379235303935, 0.026890251132088806, 0.06058572641303463, 0.05535649068112816, 0.013642041763711362, 0.06057667891464888, 0.010083810418784138, 0.1440116135223258, 0.19992087877565817, 0.07576582758056541, 0.20928034348593605, 0.11689554839845627, 0.13628785378269612, 0.12231807960497758, 0.12075435625569475, 0.180035411951042, 0.1042666502537266, 0.11588759119472197, 0.1443827677998812, 0.0680651883744905, 0.16561348501953388, 0.13157020773618452, 0.23104793512292449, 0.13342236318895895, 0.0700946472164604, 0.1491187233477831, 0.156147534087781, 0.11459358442094057, 0.1194301273133005, 0.1247329802642907, 0.11069021322914671, 0.16024556822113453, 0.19418646551428304, 0.13650396718613564, 0.2276748040270421, 0.10053014067272026, 0.17629494169546714, 0.19123072976306563, 0.16732310215311666, 0.17359762272286802, 0.16813913901006022, 0.14040333939896477, 0.16075426592461525, 0.17620541666063572, 0.15343371358129287, 0.19609408573277537, 0.11411747609775875, 0.13106083587533043, 0.12737753110066538, 0.12177933593310657, 0.14659383544518104, 0.16052134455211703, 0.2375944322275539, 0.17698227578113157, 0.14333426922319398, 0.18772097454676706, 0.0945852677367868, 0.1902122465112517, 0.127906039837868, 0.1670149356246956, 0.1646373357864157, 0.23513047895844907, 0.6052904816404466, 5.270882998743366, 34.42838061240412, 65.35874051432457, 103.33827034119638, 132.84162490598618, 136.1947964083764, 138.82223529200402, 128.6106191142913, 136.49368101550687, 122.48064487211167, 122.2257221898725, 123.05676260302145, 120.84467918642106, 106.10712635901668, 93.05984050996842, 69.8877013114191, 94.80481670748804, 111.1489409785117, 82.69085099620204, 87.59596317045151, 63.26651688544982, 55.822634927688114, 57.87537205603815, 69.21216718612179, 52.80115081417946, 49.26647163206532, 67.6513776471538, 68.23826620655676, 40.24317279938729, 49.00014661973523, 64.84136419911539, 50.07138905986663, 42.09137793510191, 62.88050466968168, 83.799846249242, 72.05998051551082, 107.72235839597641, 73.98820200274068, 70.5520409922446, 118.12484495101438, 97.99022059286796, 88.69228916783487, 120.00118132560485, 111.24928305225988, 132.2184387330086, 155.59003829956055, 148.8973451429798, 156.4979414786062, 168.0072267593876, 149.457334087741, 133.56399997588127, 108.80661918270974, 53.787964236351755, 18.686969703243626, 2.422037840850892, 0.21583290800692576, 0.20180300358803044, 0.18177135186570306, 0.2936928599111496, 0.21139951122383918, 0.1833699781808161, 0.26915947636288984, 0.20564891818550327, 0.18346979943734987, 0.11060438839898956, 0.09971098583792487, 0.17716924719993146, 0.20804444448121134, 0.13186268478391633, 0.22512970672499752, 0.1294422912741861, 0.17229064608052855, 0.15166720675845302, 0.1623991945938718, 0.1261932204567617, 0.15045330979891364, 0.15799518494356066, 0.10797895911720493, 0.207460823378736, 0.15988673263740155, 0.14500636337024553, 0.13522031026021128, 0.23321968713595023, 0.08777831605966054, 0.11201333134405075, 0.15812563439530714, 0.2456127374523109, 0.1677345679772477, 0.16823428713025587, 0.14183659797474263, 0.10026644554830368, 0.28210041744093745, 0.16713320427844602, 0.20223501589029066, 0.10620355801356417, 0.2303390280013123, 0.08578487101101107, 0.1962489427457894, 0.1337793295181567, 0.17785864972299148, 0.16015996555647544, 0.08651491449845415, 0.08194205906963156, 0.0820722327297253, 0.07792415773315776, 0.25121713027117715, 0.11010103032834108, 0.18036752638797607, 0.1918544479074978, 0.08452066505748419, 0.09015323459020547, 0.14778508684567868, 0.1557108026839072, 0.10830909704729434, 0.10239489827184908, 0.26933460406238036, 0.1318182057190326, 0.09288879667198466, 0.157122289040877, 0.1005167264731661], [0.05244032720163946, 0.012488635106673165, 0.07050328617615086, 0.06235070106002593, 0.03009075005989402, 0.05323520087967477, 0.05178198571346941, 0.07665746199387698, 0.0019448014579886092, 0.0326607758629947, 0.010761183446213123, 0.016551863950406833, 0.037023750013641776, 0.0721411285321078, 0.034549186426785686, 0.02056933627764304, 0.03031917449627673, 0.054711781727570685, 0.03782133181248942, 0.04271765637602057, 0.022649964047295433, 0.031008230364550988, 0.016751316856713067, 0.07128453498045284, 0.03961815273449306, 0.03704081845259474, 0.01148128311239904, 0.05238346432545974, 0.12658852182569044, 0.04705486698977409, 0.060009689581009655, 0.03827186045987952, 0.04364575274408825, 0.02679169583584993, 0.11480715441247148, 0.014221438848894211, 0.039254425679363554, 0.03476395917635772, 0.0800970358954322, 0.09941735965830666, 0.08304250606846425, 0.0393282420813076, 0.022717305091059497, 0.029796512925156185, 0.06841274714397808, 0.08094232198932479, 0.047719478907604376, 0.11393514717178, 0.05645923977417331, 0.045775082638306964, 0.044186591666432164, 0.07680622860789299, 0.048005842573700414, 0.10280549841662569, 4.273334049409436, 22.138388733710013, 68.60497643870693, 91.49824296274494, 98.53259025081512, 91.99089265638783, 86.56292853816863, 89.03821083807176, 78.11630833533503, 79.00785523076212, 69.42649333707749, 71.87135373392414, 71.3539852634553, 53.740915406134825, 44.96541230909286, 33.617673766228464, 26.32577580790366, 24.890049080694876, 20.564369040150797, 19.552360273176625, 32.62563966935681, 20.202865754404378, 58.229111010028475, 43.46965566758187, 39.74610651693037, 58.55617784684705, 36.449103355407715, 51.97395432379938, 36.48797796618554, 32.353346770809544, 57.2235212018413, 50.605513895711596, 71.05289628428798, 70.08456507036763, 47.279567564687426, 54.82257958381407, 49.68062293144965, 71.01849709787678, 32.17452983702383, 39.42506836306664, 34.14137686452558, 29.293407740131503, 31.511055038821315, 29.85537159827448, 22.265581392472793, 38.732562142033736, 39.66696093159337, 66.536467459894, 85.7146453857422, 93.06360598533385, 94.29256300772391, 97.30357831524265, 116.59855658008208, 108.75811515315887, 107.05968964484431, 96.01127501456969, 68.55757851754466, 44.09581891952023, 7.539172509024221, 0.35945963895609306, 0.08035227340916473, 0.023685871968947114, 0.05882503802797968, 0.045832784380763776, 0.028546581104878458, 0.022126308477093137, 0.03677717312389324, 0.038103899512920654, 0.023786014982409055, 0.027116248984971357, 0.060871419752196926, 0.03673182837965508, 0.048592838293482224, 0.012900367146357896, 0.025859301714527032, 0.011133520372001635, 0.01950111668256502, 0.050516596154099515, 0.05509358462727359, 0.030780748216315146, 0.03369448511230369, 0.03134187123167419, 0.07081502267429907, 0.026014357910401402, 0.07547477545637278, 0.049035928227127566, 0.058491333958602724, 0.1345163980318654, 0.04594366794692413, 0.08478737090744319, 0.08504230964688525, 0.027269185032515277, 0.05498263211320004, 0.06780720826598906, 0.02483037668430517, 0.07473877946575803, 0.03682839759295026, 0.011950669014045309, 0.06962887341937712, 0.049364277341913794, 0.015808608319099634, 0.025416368828906168, 0.01124115381014323, 0.01613435943821265, 0.05972695334123508, 0.012740397454059173, 0.02836773021807594, 0.009570337114705434, 0.09168240737410323, 0.09573418511858872, 0.024416156774086338, 0.024010392559331753, 0.006542811742908652, 0.05438989073398614, 0.03869861356853958, 0.0174622387895661, 0.01938631649189178, 0.07845549333480098, 0.015037419206853357, 0.058457675885649464, 0.09423207822105578, 0.051247103124736786, 0.023765709821976, 0.02628498613053272, 0.06868606433272362, 0.11292804032564165, 0.025598400895814263, 0.06935938667025297, 0.04069868144729445, 0.0731091725549871, 0.010073757429997767, 0.08758594372099446, 0.0736802911025382, 0.054781779181212194, 0.05172331486978839, 0.01109680848106021, 0.02692694865888165, 0.017381341819981896, 0.05916036620375611, 0.05500913875538015, 0.010263395792384063, 0.08400120381866732, 0.027031963991542018, 0.020857214882609346, 0.04572313421616151, 0.0225485703952971, 0.025420840867164157, 0.06505355118743836, 0.08237087678524756, 0.0922353926204866, 0.057267880052207946, 0.05626478750679282, 0.02779429616977371, 0.04199692468729712, 0.040458535865670255, 0.024171542984643773, 0.0485745977400051, 0.02005121760791348, 0.03470895406339438, 0.03945647370851329, 0.028483913197452505, 0.03116816079484359, 0.04076768681707402, 0.05482141273997484, 0.04700467673941486, 0.032862283800157814, 0.06318243122809837, 0.018604094755925962, 0.06585726935055948, 0.004294529940272051, 0.07009687653232007, 0.08165304473931752, 0.07347063582030035, 0.059985515676558986, 0.027896360148705786, 0.1787692677950667, 1.5833025954423414, 17.06226710350283, 58.67460989182996, 94.21379396992346, 110.07557653611707, 106.19029629615046, 98.93949693249118, 103.83816073017736, 92.24640369415285, 95.3366038107103, 90.66779090512185, 110.78747887765209, 102.1347616564843, 88.42978062168245, 77.76069841077252, 65.40010975253198, 44.18000082815848, 22.085848585251842, 29.5814371878101, 31.657249619883878, 32.61276645045127, 26.627362928082867, 42.618544486261186, 22.805636852018296, 28.62268440185055, 43.808799482161, 25.722438789183094, 33.95895135018134, 29.851447266917077, 31.496189255868238, 35.03085274850169, 29.563890464844246, 62.27822865209272, 58.89962450150521, 27.33187552421324, 32.21582847256815, 44.658118140312936, 52.42266170440182, 37.79105209535168, 33.24785309453165, 28.0326775581606, 44.434986268320394, 39.12932165207402, 39.006261210287775, 43.074017955410866, 64.11928722935339, 76.76181977795017, 115.62227079945227, 130.2202578513853, 120.85730137363558, 114.43225506813296, 114.13817928683375, 131.23089574998426, 123.0503377606792, 128.90918208706765, 118.18788528442384, 87.79683559171616, 56.58738336255474, 10.308473225562803, 0.06310871441758449, 0.09592373059281419, 0.01415438125766213, 0.08188558306785361, 0.0508354342873058, 0.06666510906671325, 0.08561604821513738, 0.011095396006449817, 0.0167839675240459, 0.10040666262108473, 0.027189257164155285, 0.06274566918070759, 0.025309154823903116, 0.053523502748219244, 0.04968303886632766, 0.044367882543273514, 0.046044201665227456, 0.07351902193359791, 0.07429501537473933, 0.043309382688734806, 0.0255016190931201, 0.01750797232342584, 0.08184589205249664, 0.07353871039325192, 0.030768630620572838, 0.012677400128825778, 0.053056805815187194, 0.01367761218364561, 0.029510009448013963, 0.010129221238105768, 0.07463472940388226, 0.06033567531454948, 0.013375299524575954, 0.03992245817977575, 0.10209817709701677, 0.01623506935673856, 0.04775133667393558, 0.06598354362311863, 0.04170511413605944, 0.020619695067345616, 0.06639342364524642, 0.020668140552457304, 0.0342572303188424, 0.008791544579810674, 0.017303354069290143, 0.07144639403709481, 0.018111536609790018, 0.0627762935454807, 0.017483717979743116, 0.03843514060962104, 0.1024686572171988, 0.029195978516532533, 0.026506757093293053, 0.08965660277153216, 0.034557923659562104, 0.00850962805411508, 0.05340050733197601, 0.0420635360323133, 0.05520113571096332, 0.03826636377902281, 0.04245733586891044, 0.021149990704631614, 0.0938846420256361, 0.18850324224800835, 0.10926245516466518, 0.1820062037797705, 0.1754404165812077, 0.06964522939656051, 0.22578284264572207, 0.13459692919446578, 0.13543912029314426, 0.1456373287064414, 0.19198410062780305, 0.11334803270836992, 0.10430867783725263, 0.12266408321597885, 0.13868668957823707, 0.1061056136724449, 0.09334620478893481, 0.1355074400142316, 0.1574904555755277, 0.12179430529114701, 0.20036954582939226, 0.13287341522593654, 0.08481852004244443, 0.0904477953970913, 0.12220386355634659, 0.10136298549872252, 0.19702031667674744, 0.1596768245461487, 0.13870593370689502, 0.17535542678688804, 0.08885752710123217, 0.18009542727903013, 0.13800879369579977, 0.17506972195640688, 0.10301327678344904, 0.19653576606464004, 0.19317656244722106, 0.1433357247902501, 0.10866593314154495, 0.15144113421199784, 0.12731738553773012, 0.18361644398781563, 0.1333815460243533, 0.11901981828193511, 0.12543647880515746, 0.13725248105343313, 0.17347054405798837, 0.16547966478092058, 0.1804039002426209, 0.15685092537633835, 0.17783951284664293, 0.12633198962336586, 0.2164388988767901, 0.09067849511460913, 0.3159817590588524, 6.928156960395075, 36.87971292003509, 95.38517844292426, 119.33407245143768, 126.74159403770201, 117.02911515389721, 105.65576353380757, 112.98295497894289, 99.36615667035504, 105.25977673069124, 89.29069380606376, 90.6730547258931, 94.27518690786054, 69.64065474848594, 64.75450331164946, 52.25677682507423, 39.20034008641397, 35.38005744257281, 28.283989698656146, 27.852083790686827, 47.393457505010794, 29.585463500791985, 81.4832865807318, 61.84207677841187, 53.81105522955618, 81.9206779233871, 52.989087258615804, 74.08635539393272, 54.466251865510024, 42.903316405511674, 82.00177684906991, 72.50782889704551, 97.35314922948038, 95.03593060278124, 68.13721810617756, 75.7666987757529, 70.56851494696834, 98.74158197833647, 54.55793726828791, 63.42970317409885, 51.72454257165232, 49.72010550960418, 53.65171286367602, 50.4383973921499, 38.4417183937565, 59.516852594191036, 62.82466580790859, 96.18658142705118, 115.76569618717318, 124.62116072254797, 118.55189692589545, 122.92899531702842, 145.48201191809872, 138.95388572446763, 144.43015775372908, 139.79488895785425, 106.38645402846798, 77.86270356947377, 15.029620355175389, 0.7382203422246442, 0.23084476860540531, 0.10824380337350792, 0.11994524483358669, 0.16039195230170605, 0.11301133706564866, 0.24213213954241047, 0.15907775911111988, 0.12732523027807474, 0.259782345665078, 0.19990961728317125, 0.21310909771390502, 0.12642149933643881, 0.11803341879239006, 0.14186223127668904, 0.10796371396751174, 0.18861502979791936, 0.11371131160206373, 0.18092347639462641, 0.12303158325413543, 0.11723327825987533, 0.10685181395421106, 0.19204921810136688, 0.1553040406396312, 0.1374829969098491, 0.11616735118291072, 0.16994424134252534, 0.20204308022174144, 0.14279872779884648, 0.0950657197784993, 0.20159781459839116, 0.16795992040105406, 0.09168368674093678, 0.11207987374115376, 0.20611551169666553, 0.10402835860487916, 0.1915816133541446, 0.1294156927014551, 0.13447726626069317, 0.10921403840785066, 0.1349806166704624, 0.09349662615286727, 0.10983843837053546, 0.09377844691757234, 0.10215746464147683, 0.29339742576403005, 0.09659025773045518, 0.1563235044839882, 0.13761274156070527, 0.12356042140914548, 0.195300740400149, 0.12736499790222416, 0.13279412512577352, 0.11614231542954523, 0.14525992315142386, 0.06548376318307654, 0.1370011429272352, 0.08374363739764498, 0.19394232861457333, 0.12656032979007692, 0.0868188368997747, 0.14177547948014352, 0.19395297723672084], [0.03121827252119059, 0.04301933030928335, 0.08362258784472944, 0.029671789980643702, 0.023201712061681097, 0.04313524324266661, 0.02311735237467914, 0.06427494538647514, 0.027374208026054888, 0.017748520101210283, 0.021085066668268655, 0.050304634947209596, 0.0184175944811995, 0.025791705946528146, 0.01073821900307291, 0.058605921559876976, 0.017455870683695522, 0.06945212161348713, 0.041509390162724646, 0.036622178215052814, 0.10479775602899252, 0.07374755362229002, 0.024249371772091237, 0.009464149667520919, 0.059984837688746, 0.053330846957021186, 0.08127334092052714, 0.006949917569140634, 0.06805643198951598, 0.0386963612700422, 0.033273121432190945, 0.047882981222843936, 0.05311371465664237, 0.02125349492886134, 0.04293733591874761, 0.032620410690264355, 0.013895149553014387, 0.06278953154481227, 0.027010103672622677, 0.04184691701084376, 0.06535492251597105, 0.008859726405071636, 0.050405597674750516, 0.013861758653224717, 0.05978694951702511, 0.0430016030347155, 0.04042670108197678, 0.06834474917981895, 0.05227765609179774, 0.0257324222325077, 0.03530301311383805, 0.1108551519592443, 2.0016056010800023, 15.490353722726146, 35.5504765818196, 53.04258054302585, 74.08615927542411, 91.53627426393571, 82.44451830464025, 83.60302171399518, 86.53371472512522, 50.36780649615873, 52.499846104652654, 43.56906813959922, 43.287885189056404, 22.499539006140925, 21.30885058833707, 51.52086565571447, 60.238451034792014, 40.46100554927703, 68.56724323764925, 112.43206593298144, 164.69812700825355, 124.70939051720404, 145.87985007993638, 144.8455838234194, 123.42874450068321, 156.81094661835704, 168.4943380663472, 102.82761696846255, 141.38068752904093, 137.30462320389287, 125.09166471419798, 175.58080580926713, 125.83428705892257, 115.69167321728123, 100.86202313823085, 139.75880315226894, 142.63317877246487, 123.3512306213379, 113.89554931271462, 110.9053147223688, 122.1656079446116, 123.20914668421592, 152.0611289239699, 118.09269720508208, 109.45184907605572, 118.73002744490101, 116.34631679904078, 81.54965308404739, 62.01020133110785, 35.903580111842004, 29.344975140786943, 26.93559846570415, 45.38801239382836, 47.627219000170314, 60.331015048488496, 76.19163267074093, 88.68533872788953, 103.71282531369118, 107.1847269611974, 112.15161646566084, 94.65299744759837, 51.65273574090774, 10.850130973323699, 0.8979041994579378, 0.11068155643560233, 0.09811089629487646, 0.07220023221546604, 0.04426349540271106, 0.0492192568978475, 0.09554480052282734, 0.05098112505830584, 0.04332627109702557, 0.04877941900744073, 0.14408442251864942, 0.009878682716178798, 0.14968978060830027, 0.029158482343078624, 0.042217489061576706, 0.008666091936550314, 0.018732178911206224, 0.02421436346917143, 0.0290675783499835, 0.020762836680777615, 0.04381189423222696, 0.037664410192519426, 0.03219154317893329, 0.04364087276401059, 0.05297040258864722, 0.010463684692137666, 0.03350084872856256, 0.045894002466793024, 0.05537014619837846, 0.057123537595954635, 0.040384799902958256, 0.03623048512024745, 0.04508833077946498, 0.02648953160631561, 0.03074847293206521, 0.04254608332449871, 0.043400049194573395, 0.054760386175926656, 0.04438507738673399, 0.06361019174237886, 0.07493155783102398, 0.025179758743052522, 0.056532918280290986, 0.0832331393875422, 0.0699912176858033, 0.0715818000777114, 0.030758922371352394, 0.06292163957691481, 0.07892479113633595, 0.041572623059994755, 0.03837595648703076, 0.060342623732022704, 0.036119632197604064, 0.021260939388265534, 0.06548544091563072, 0.05179410905487115, 0.031233864325669505, 0.027432846310999126, 0.016620758237437378, 0.023670343366721948, 0.005948420880632776, 0.04170223747590377, 0.02044598654573483, 0.040142482462068724, 0.015058518225897946, 0.08163271276580711, 0.027950524480172226, 0.017419205715639458, 0.03605721518397331, 0.05876346371106564, 0.07668174698107666, 0.013429363307002331, 0.027123549802889748, 0.06091309493527778, 0.029691576116508054, 0.11357949085293279, 0.03588644269433233, 0.011997571789599475, 0.029201896545747598, 0.06794337273365067, 0.04738739128374765, 0.06179776560935763, 0.062379433187626065, 0.01061470456226098, 0.010771232604559873, 0.012921785049500966, 0.034538093473642104, 0.04578883774698742, 0.08223909434051284, 0.07804938246526065, 0.026390763720677748, 0.012794946744707564, 0.04641730946698978, 0.006688325834881154, 0.03692570608109236, 0.043469931735026265, 0.0553792626446774, 0.02598551470005224, 0.02948826021184364, 0.017206553114397873, 0.03107359107103079, 0.020045876059861436, 0.009635833801791794, 0.07371283451756162, 0.01488029265836362, 0.0010268877151482288, 0.05521420134051193, 0.05420139480021693, 0.03878330075812917, 0.03063782493794157, 0.07990308541564212, 0.03534532798033568, 0.15287964815093627, 1.1280578495033327, 10.36327265924023, 34.687182518743704, 63.74400661837671, 93.20910238450574, 107.44606664103847, 89.81494211381482, 99.3560604895315, 97.63013132156865, 71.22577082726264, 77.92825421979352, 72.26577158897155, 69.19992154644382, 37.65561265330161, 44.385638929182484, 43.58202765064855, 44.98119200429609, 27.51069049681387, 44.41907321253131, 53.96370995429255, 57.46630414839714, 58.7619375413464, 82.93420268643288, 73.26239093657463, 87.98640374214419, 94.03815023360714, 115.00248924378427, 89.7280067013156, 83.12611641422396, 84.43842380277573, 84.26719665527344, 85.14498387613605, 84.22824751946234, 80.49182122753513, 71.88785906760924, 77.76433837029242, 82.19911129243913, 78.48445415496826, 79.71326212729178, 97.71791396602508, 88.02951059033795, 81.30190049448322, 85.18489007026919, 67.59417380056074, 74.36038001891106, 79.62700136246221, 71.53562238139492, 55.456285553593794, 44.89208359872141, 36.31197337181338, 40.23245296170635, 51.47366385306082, 69.91683667705905, 80.59926279129522, 99.99721896263861, 99.55679170546993, 111.64356754672144, 109.35259742121544, 120.34733833805208, 129.50137369094358, 113.94523005331718, 60.019327825115575, 13.132424816008538, 0.8171232309072249, 0.09363892698480238, 0.06432110984479228, 0.11402237394283857, 0.02826956945711807, 0.04914608400975985, 0.008818523323674117, 0.01813197775082963, 0.050319351496235024, 0.03067207289859653, 0.04246687366356773, 0.04320838931767691, 0.04367059697547267, 0.018751273652718916, 0.05119990827816148, 0.09755201983235537, 0.016567455754885753, 0.05621221089254945, 0.03825707113250129, 0.03323537244972202, 0.058982553366090984, 0.060136408184564887, 0.03672942669401246, 0.08962878611900153, 0.09528417741098712, 0.03472910217580295, 0.05855602242292897, 0.06584115852151187, 0.03003938386457101, 0.0257089588746068, 0.08787555559988945, 0.007939445570246468, 0.04771186399363703, 0.0215267967958484, 0.044930830763112155, 0.04822094091064027, 0.018852203821523056, 0.027244373359867645, 0.06214510604378678, 0.05628207811124383, 0.04979666119681732, 0.051725046228497266, 0.0427326065818629, 0.01817441902183477, 0.036069939904395616, 0.03740818059492496, 0.0695367360247239, 0.04845749737033921, 0.03451072881298681, 0.11374363285158912, 0.0554317205152925, 0.017101053231125398, 0.03262077075158877, 0.01810825583825429, 0.028978671931150942, 0.021091706735352357, 0.05506464182549427, 0.025235803820373073, 0.07951968139217747, 0.02792333793495932, 0.09610967545379555, 0.11098528731494181, 0.0870600396827344, 0.18231872168760146, 0.10596460752910185, 0.16111250395976728, 0.07120879186737923, 0.1977465986724823, 0.15967699308549205, 0.12061090629187324, 0.1666120499853165, 0.17743428297821554, 0.1311806520266879, 0.13715894171787849, 0.12883184177260246, 0.1553384533091899, 0.17931702066092722, 0.16115416382108966, 0.22308544706433053, 0.27450097844966, 0.0941468356177211, 0.2241721274631639, 0.14608777308415982, 0.07904269972876196, 0.10877462569624187, 0.16218953165075473, 0.148123329986007, 0.24097117925843886, 0.1640281120255109, 0.2817926339564785, 0.16007244767200562, 0.1431339831962701, 0.16281211598505899, 0.15956753444287086, 0.21627870989182305, 0.19577228283930212, 0.15452057784122808, 0.12254304132394253, 0.1188909546321919, 0.1378311532279176, 0.19824383570061577, 0.13981988683583277, 0.1278786904989712, 0.14377214975895422, 0.06022223301472203, 0.1710233681144253, 0.17440497214275022, 0.2572473913671509, 0.08577816774167361, 0.10877573652373207, 0.15989215653990546, 0.232772245822895, 0.27565525844693184, 4.683839505718601, 25.649233633472075, 62.94614161214521, 81.05311239919355, 100.18338249575709, 113.30211823986424, 103.73956803352603, 107.48889892332016, 111.97191699858635, 75.06442977536109, 74.19771148312476, 61.26351933325491, 61.1254636702999, 29.959198697920773, 32.87675176897357, 71.33031768183555, 77.31969848755868, 65.24856505855438, 98.25907553395918, 165.95116738350163, 236.1712738775438, 176.44634739045176, 209.67480044211112, 205.0908362480902, 183.98757473115, 235.29638136586837, 248.15662507087956, 142.8789544874622, 207.13697987218058, 199.6772280047017, 186.1652432718585, 252.16283982799902, 189.70962247540876, 171.59274378130513, 148.4779182557137, 198.63485028666835, 205.2457384909353, 182.1793620817123, 160.88351218931138, 156.5350784793977, 173.008327176494, 174.98582932256883, 214.80753560220043, 161.88483053638092, 151.70260860073952, 165.22436788005214, 157.05612613308816, 114.05536236301546, 81.32911389873874, 46.62552018319407, 45.32674889410696, 42.14970357956425, 68.53273422487321, 71.40110077396517, 80.74500237741779, 102.86023539881553, 117.44057178497316, 128.28366602620773, 132.91789147161668, 140.9449592713387, 131.45443162610454, 78.82346460896154, 21.750491819074078, 1.8879787047063152, 0.19205444282101047, 0.1673084851955214, 0.327431004374258, 0.22710481928961895, 0.14846353431142148, 0.17980750079356855, 0.1115476877819146, 0.18737678656414633, 0.1285168034355006, 0.19976910143609972, 0.10453725549122019, 0.14472304873408812, 0.104447232499238, 0.14965264066573114, 0.20997426592774932, 0.07476698682313004, 0.19529830424054978, 0.1926476553442978, 0.14182905966956771, 0.1267262720953553, 0.15243363176142016, 0.12451873611538641, 0.1578071103581498, 0.29588181825895465, 0.09150460602775698, 0.09650034965166161, 0.15864933210034526, 0.20289104762336901, 0.08506432701382907, 0.1466552910184668, 0.1203491723525428, 0.12380724727746942, 0.08382491932641115, 0.09857031922306746, 0.14748657302510354, 0.12477250274030433, 0.2210765653440068, 0.19899714527831924, 0.22348949715735453, 0.28497781304101794, 0.12768306994750617, 0.12413358541145442, 0.22454254629631198, 0.14418933059900038, 0.15110276849760165, 0.2580163597820267, 0.26840368466031167, 0.15606966891115712, 0.19365982603161566, 0.1597410380359619, 0.11271178902637576, 0.14774574056988762, 0.15649274862822027, 0.16366273405090456, 0.0888373636670651, 0.1050733868032694, 0.09518536739051343, 0.17426387406885627, 0.07763521235075689, 0.10307675482885492], [0.08317386716484063, 0.002222869708578313, 0.05975136090250266, 0.03797659485210334, 0.058264736641919425, 0.09739708621054889, 0.02659426157122418, 0.024662461702621753, 0.03567748072166597, 0.0112445667318459, 0.018811093628286354, 0.06552701650728142, 0.020577223152823506, 0.028180109539760217, 0.056803140473822435, 0.045000663507849946, 0.010186223925331668, 0.13233698513959685, 0.06514918960390553, 0.02078972828213967, 0.06294191026339127, 0.029122458973659143, 0.15335874421702278, 0.050123301935532404, 0.0417241858949344, 0.022873320812059027, 0.011007178109139206, 0.04594932933668456, 0.04178903906816437, 0.03406557044194591, 0.030330616019425855, 0.03380524993483578, 0.09502742304316453, 0.0724271244760002, 0.03469925539027299, 0.021017041891032172, 0.09066729490915615, 0.029274757253006104, 0.06165148878109552, 0.05461142037905032, 0.008388768107960782, 0.04801369497492429, 0.060299577251557386, 0.01402713884148867, 0.026761981200486906, 0.0421428376237952, 0.03712518388525613, 0.03370405355047795, 0.049038440995519204, 0.22109899639842973, 1.6170526295900347, 14.254612961123067, 37.434355674251435, 75.4312341443954, 100.900085818383, 62.9798073153342, 58.15183639526368, 80.20172272959064, 71.82109248253607, 39.07955461932767, 37.06225218311433, 42.69756847812284, 11.519124546358663, 18.97998840578141, 30.881402838614683, 75.86974728492, 68.34201289761451, 91.46976655529392, 112.97284310863866, 107.39206344850602, 78.98898863023328, 40.99017250922419, 42.69408149103965, 34.02049333818498, 9.98589652199899, 15.101808636419236, 8.23823840387406, 8.093499512441698, 8.809254111782197, 6.679969968334322, 10.929610940717883, 9.395649433135986, 5.968376023154105, 5.90848780447437, 4.55081477280586, 2.791643762780774, 4.103176483223516, 5.424002034048881, 3.025376085312136, 3.109965185003896, 3.5183224081993107, 3.564831912517548, 5.482418383321455, 3.887896460871543, 3.918453930847107, 7.956729896606938, 9.71827026336424, 23.171470434434955, 42.33948353798159, 73.6968561910814, 104.706251851974, 124.5909349380001, 115.27939288846909, 70.47978308893019, 43.19865911237655, 26.40479587739514, 24.749657646302257, 41.510667108720355, 42.72770012578657, 85.50365324943297, 79.12977818519839, 88.8177030317245, 91.70736020611179, 100.05512099112235, 87.79884384524438, 46.22126894612467, 25.348240752373975, 12.764966391747999, 8.526284521625888, 1.7066816072310171, 0.31122009360021163, 0.03819730095264893, 0.01863318119919108, 0.08475066763499091, 0.03849489929815454, 0.10282540904177774, 0.05321198458512945, 0.06444112517901006, 0.05448456771010834, 0.06490846179545888, 0.04311402643760366, 0.0690172134988731, 0.060051701842777194, 0.037509507214229916, 0.037705422709545786, 0.02951604239041767, 0.04164756944162711, 0.041549054365004265, 0.011731256644481854, 0.034182107736987453, 0.07841174971432456, 0.026846574544305765, 0.02930361770033356, 0.032754177302722974, 0.03684034473412941, 0.0139969693414206, 0.026208055581176476, 0.03299676287438601, 0.07215068164852358, 0.019112305993574764, 0.02921845745145073, 0.04290202309587791, 0.0713215753315918, 0.015347506700744553, 0.07395332483875175, 0.058092818850831646, 0.013196722514206364, 0.03801501799194563, 0.007207382483513005, 0.01937721919779095, 0.03130278351055759, 0.04779917503436727, 0.058470159288375616, 0.00981626091449852, 0.031129869805168242, 0.01686793267576685, 0.00483078909324362, 0.026819920430200237, 0.07221851107333938, 0.048997562543879596, 0.07087926680762922, 0.0214176599101554, 0.026425028918311003, 0.01627743401895127, 0.024047304590743397, 0.0728647675245039, 0.0212644231731012, 0.09446360531353182, 0.037139180311632734, 0.06986515791786295, 0.0998511799280682, 0.022199661395842993, 0.015339638020152287, 0.04578117686774462, 0.04357926397313995, 0.033820717250027006, 0.029973856533967683, 0.04512308435814996, 0.0569719594392565, 0.04700713971209142, 0.06531539237907817, 0.01805915151752772, 0.04932779240451994, 0.14033724133285785, 0.01759636546334913, 0.00020099290762323844, 0.08755837987747886, 0.08446047352927347, 0.11038717182893908, 0.1010329548209425, 0.015586200545752242, 0.012587195190961563, 0.05458680597404319, 0.04402576299804834, 0.01907241771057729, 0.026529732070142226, 0.018515151947917, 0.02587554852418121, 0.04831797360712963, 0.03508594210049318, 0.11130797887040723, 0.013080635295820334, 0.037793737325456836, 0.014493456560998194, 0.06734192476517732, 0.0313316707709624, 0.03386181020628541, 0.02435286833544172, 0.034853430585034435, 0.021051010229594765, 0.002582096715360099, 0.06168681309528409, 0.0683301015787067, 0.08317200557118462, 0.019952198828480417, 0.15851975598883244, 0.8764849939653951, 9.926297087823192, 37.12246448762956, 80.2971539958831, 108.11683900894658, 71.5979645329137, 68.97840961333245, 88.41568362328314, 90.88724751626292, 60.59115448305684, 64.95365381240845, 55.19785235005041, 29.859140996010076, 28.648995660966445, 32.177542217316166, 35.844819084290535, 31.399432228457545, 69.60034847259521, 91.40554951083277, 82.9304450558078, 67.54876059870567, 49.798078306259654, 51.13208032423451, 36.933312108439786, 14.664027017931785, 17.174399821989, 9.252694729835756, 10.184575357744771, 10.520028221991755, 7.50280233160142, 10.97142929031003, 9.705195042394823, 7.223528594739976, 8.434371621378007, 4.913667844187829, 3.503939812221835, 4.250507816191643, 4.152399041960317, 3.120556074765421, 3.7785361226527923, 4.983940537898771, 4.751889196134383, 7.264022654102695, 5.269452804519284, 4.599342826874026, 8.723033551246889, 11.282482070307578, 20.301093670629687, 39.53123123415055, 61.33073699089789, 79.90530921566872, 86.71075482522288, 77.96954893296765, 41.68476543118877, 34.46066956366263, 27.036907403699814, 33.05823787566155, 75.50153086262365, 69.17554793819305, 113.39863992506459, 109.5381804435484, 101.22117888542914, 101.19118844309162, 118.09847093397572, 105.13001688065069, 53.3831246437565, 26.320357053510605, 14.290698766708376, 8.125537922305446, 1.1680978945186062, 0.1064136959311943, 0.047914203136197986, 0.003587905760674227, 0.03966330212631053, 0.05432000819353327, 0.15565847887867884, 0.05541140769398021, 0.08266553718356356, 0.03435064708032916, 0.07788611380683799, 0.045161212554141406, 0.08432597147240754, 0.0605080642497107, 0.04151178801792764, 0.046660925426910964, 0.02878883151307462, 0.022972446843801488, 0.06900692493805001, 0.06634772650056309, 0.05140795860619796, 0.046397433315794316, 0.07111714476899755, 0.020681464736680352, 0.04846806555325466, 0.002749411993840289, 0.01567792904097587, 0.057120094030734994, 0.03504612085018908, 0.047104942326944683, 0.05846377011508711, 0.026158483946816097, 0.055102371655765085, 0.03448858504153548, 0.034705307484874805, 0.030239790550342975, 0.08879243261030606, 0.020339230278266535, 0.06394834678259588, 0.024697485327300046, 0.04756259176159098, 0.030547696608869784, 0.03990501818817951, 0.07472037803381681, 0.01036502884685873, 0.03359929868771184, 0.06079613246143826, 0.0506675039838639, 0.07042733621933768, 0.06533535663038492, 0.019578725219734257, 0.028945228362816478, 0.012256867654110876, 0.05527346973277389, 0.038443973603388, 0.07278330173463592, 0.05985857873794533, 0.22982577973556137, 0.18864650068984878, 0.11577690681142193, 0.10383637697105447, 0.21036198302622766, 0.2254169590530857, 0.05676767826380749, 0.13056726074747502, 0.08013840464334335, 0.14363284433080306, 0.15027024542852757, 0.18149214346081982, 0.12135146050563744, 0.20246044492288945, 0.1770917037802358, 0.27699897666611983, 0.10300796779413378, 0.307945711237769, 0.16112865309321112, 0.10262364446516, 0.21440927149547687, 0.12900462524304468, 0.17700034013438612, 0.17031818418012512, 0.12176153971062553, 0.17826187244105726, 0.07367923390120268, 0.11557008605450393, 0.1315518216260018, 0.08649288947063108, 0.15483413762863607, 0.13500706202560855, 0.1891201728534314, 0.08540375759044001, 0.17176101885495648, 0.1828280322614216, 0.18783889080007232, 0.06970748170128754, 0.1840634103263578, 0.1609022128245523, 0.08956285659223796, 0.16723127885451242, 0.2708712538644191, 0.10691290180529318, 0.12025906509088895, 0.11347714150624891, 0.10526314678211367, 0.2147890212795427, 0.13114486039886553, 0.5641440218014102, 4.251030962313376, 22.705902745646817, 63.35983007184921, 105.34177780151369, 127.65211736002277, 87.11057770636775, 82.13841653639271, 102.35095485564202, 102.19616243916174, 59.007611274719245, 55.50562504799136, 54.9087619012402, 19.708039145315848, 30.72825585642169, 47.08459046579177, 114.45073727638491, 99.82982004842451, 133.89548732388405, 151.4373936191682, 151.08307807676255, 118.3654352926439, 62.778424985947154, 67.8903990407144, 50.84045210192281, 16.80503610641726, 26.483105997885428, 14.981145743400822, 11.828134752088978, 14.607876327729995, 11.0255354450595, 17.082351599970174, 15.475996867302927, 9.688093508443526, 10.854509319028548, 7.974966956723121, 4.526256322860718, 7.992328837994607, 10.184646941000416, 6.111384168747933, 4.782955348491669, 6.10848504689432, 6.528709646194212, 8.854250561806465, 7.562801847534796, 7.37898144029802, 14.85491700710789, 16.495639547224968, 35.94572990171371, 65.09199188601586, 112.31005668640138, 157.2514601676695, 182.52293032984582, 170.5316798917709, 98.93970089574015, 64.58405671581146, 37.69620526221491, 38.081162360406694, 64.22235927274151, 63.34948285933464, 114.59220932376002, 107.06300797001009, 115.69958856028896, 111.63318111050515, 129.44953564674626, 122.81579571385538, 70.15602281016689, 36.91172730538153, 22.383778095245365, 16.02148186775946, 3.5260685989933633, 0.4112518710955497, 0.16594371488017423, 0.1566579478282121, 0.13559998343548468, 0.12770441315707662, 0.24135751739865352, 0.13996764987466798, 0.14487038276368572, 0.1497748010461369, 0.20775795824104742, 0.1900976857230548, 0.24022802800661136, 0.1522405776045015, 0.10645721738617267, 0.208597406744957, 0.13374899243635516, 0.12579298548160062, 0.2511948217908221, 0.22937017192523326, 0.14515211925871913, 0.14373985149206656, 0.2095983465833049, 0.07375653217276258, 0.16186634979901776, 0.06041669677342139, 0.12266212969177193, 0.11574295379461781, 0.12754342744066832, 0.20787726877437485, 0.11439490717865768, 0.14262188406240556, 0.10970569065501613, 0.20387983730723783, 0.12345785755784282, 0.1810970412747514, 0.23796955484055707, 0.14952510234809693, 0.15885795316388532, 0.12248371547508626, 0.22873476327907658, 0.08818805818596194, 0.1375249785280997, 0.1788416631039112, 0.2050797914665553, 0.1073230729408322, 0.13159008005694037, 0.11282549179609745, 0.18108878284692767, 0.21631673849638433, 0.12412264567589569, 0.1580221665602538, 0.15181400452650365, 0.16640350553056887, 0.13897896744310856, 0.17743344028149882, 0.17247015580294595], [0.025549497673167818, 0.02612710115499795, 0.02418319709719189, 0.021983149626682845, 0.03704670966873246, 0.057058052400187145, 0.027934610918765108, 0.0370435495560448, 0.030441756225040847, 0.044658076648990956, 0.020825362861937573, 0.021847063683033473, 0.043235030025243766, 0.09844373085445936, 0.017755024187687426, 0.022563298435641393, 0.09508339342691245, 0.049228538053050164, 0.08138504420076648, 0.031941344608522715, 0.14960293688120382, 0.01694777627445517, 0.02497612299667972, 0.052918480979579116, 0.042619907387322, 0.01222401971913754, 0.024538054769378037, 0.08827336207633057, 0.023799743278012164, 0.06863062254964344, 0.10326457660525076, 0.06217436294161505, 0.04694537770363593, 0.007384633682968636, 0.029763936951395967, 0.010842666473059405, 0.012882019340571378, 0.030876246821736137, 0.03258201819393904, 0.044810643059111414, 0.014132563073578623, 0.02914823400187156, 0.027785218027870984, 0.05127276323976056, 0.044769481154939825, 0.055848050997742725, 0.42528353751667086, 0.6163700129235945, 2.8613388874838432, 9.5810196668871, 28.40589108005647, 53.7190285805733, 82.85070327020462, 79.57296679096838, 83.83100555789086, 64.88380424437985, 33.237109722629675, 50.557680591460205, 24.85581267264582, 42.90565806050455, 52.200796757974935, 31.595172228351718, 57.10086868655298, 74.96413477005498, 106.61188833175167, 88.54775767172538, 98.61191626518004, 42.08340375654159, 23.100771673264045, 9.98659078151949, 2.7558330134038003, 0.6700687314714155, 0.1051175747547419, 0.6902055057787126, 0.12519310799337205, 0.3554094240309731, 0.027389548936738606, 0.03325270518900887, 0.03885361613825925, 0.1339922406740727, 0.1974525128401095, 0.23978326800129107, 0.16888420548169844, 0.2607792712027027, 0.06542000934601792, 0.15831329529323887, 0.2521875185231047, 0.1425536869153861, 0.19292220593460147, 0.19979655802730592, 0.09925567680188727, 0.11041539450806957, 0.3250213514172262, 0.268867566220222, 0.2943562614100595, 0.4632591900806274, 0.5989857618847202, 0.8085708704686935, 0.7835827371285808, 0.5733772199000082, 0.7016516560989042, 7.232900117674182, 27.789276838302616, 83.61801301279377, 80.5050317702755, 96.21985097085276, 89.28988579780825, 41.813980071775376, 34.521203502531975, 27.594995960112545, 32.934298822956706, 66.36857432703819, 82.84861656927293, 71.37571519420993, 90.09048077367967, 100.44154505575858, 92.7281491987167, 83.1004798027777, 69.78120111650037, 37.43204147584977, 10.457441902929737, 1.7162266950453482, 0.012765306802917153, 0.14244534676113438, 0.07661144309226545, 0.06908967009475155, 0.04241273806039845, 0.02243881489360525, 0.05122204821917319, 0.04419964963510152, 0.037020685661944656, 0.06955216503551892, 0.03013317217870105, 0.030670383674723488, 0.09757937683213143, 0.09672007899010375, 0.023571947033727364, 0.0892435051801224, 0.01148473912654745, 0.04120145346068087, 0.05366703315127281, 0.02570276122329937, 0.03726103042642917, 0.05278050471397658, 0.009911186869196113, 0.08841523389902808, 0.027569328705149315, 0.057868289971543904, 0.040002759515998826, 0.05259658998599457, 0.03514720615179789, 0.0404912056852012, 0.09165639102819467, 0.016690068127166842, 0.012452362758678295, 0.033204675306596106, 0.032778523576956604, 0.08403347910291727, 0.03459284960803005, 0.06287154891798574, 0.07798452546159107, 0.015062431019971208, 0.04864517742046907, 0.053500485636534235, 0.046054903913529656, 0.038344508577739043, 0.021246284126274047, 0.05337985743197703, 0.07897724517651143, 0.06631929697769304, 0.05737879809232489, 0.11058492976571284, 0.035690301203078804, 0.02207832647517564, 0.05507274320529354, 0.03495078120801238, 0.04008279272144841, 0.02349772652040326, 0.054274050578955686, 0.007439425248923081, 0.02407576667235023, 0.052121274563814365, 0.015051419463669582, 0.051133293102705674, 0.01295851800786031, 0.018187875356224757, 0.03759775671266741, 0.047714778958188916, 0.04620633651352218, 0.010214363292400396, 0.02735036928507109, 0.044076799775563905, 0.04657333859452798, 0.0466054491698742, 0.08320762865966366, 0.04300824501701901, 0.11990763757738376, 0.034520573042813814, 0.02936636030133213, 0.032774267958537225, 0.05624787994630395, 0.04420667466136717, 0.0390386991503258, 0.08723071641138486, 0.0166076619643718, 0.034582584029844696, 0.03225748802745535, 0.0923138170412952, 0.02680927563849236, 0.04770853534160603, 0.031010543950082316, 0.018888219530063293, 0.06918808941038386, 0.0514175768400873, 0.07947315687253591, 0.09766022975165999, 0.05023814234582167, 0.04127704335616962, 0.014231491837680582, 0.07506381525027175, 0.0795781415616793, 0.09009408494157177, 0.17421887406418402, 0.05809091895277943, 0.7611763813803274, 7.201151472906913, 25.455474430514922, 60.35196834994901, 92.99948307775682, 92.89321038030809, 100.85770853104131, 74.57736553684359, 54.95384170163063, 73.97252821153211, 38.461561664458245, 40.86494299673265, 49.19491191064158, 43.48723180832402, 24.011108683001613, 40.257207039863836, 60.42721117696455, 71.9060431757281, 81.62850841399163, 47.94835129091817, 28.564747072035267, 12.776407945540644, 3.4913980335958543, 0.7378236312539347, 0.17994888998087377, 0.6906458531175891, 0.20722578760356675, 0.5134672443232229, 0.049818858594423344, 0.07675513820422274, 0.04501522683929052, 0.08332770528091539, 0.299124545868366, 0.26417543090158896, 0.2211313865958683, 0.7306923332714266, 0.13210274609586886, 0.24771361101058223, 0.4036255270963715, 0.2796928482430597, 0.25999400043679827, 0.1723389249415167, 0.1710613813972281, 0.14477820706463632, 0.42864528454599843, 0.31073234074058076, 0.37312425733093296, 0.9516737045299624, 0.6244132619711661, 1.0710882419540038, 1.1536172392868227, 0.26203933262055923, 0.8707023171647903, 8.933914880598746, 31.430656256214267, 68.83394871988605, 72.25028607153124, 64.19143530630296, 54.230156560097974, 31.09858447505582, 31.5454012732352, 56.126571547600534, 53.256738032064135, 97.14516162872316, 102.79448862998717, 85.4619506097609, 101.64049594633042, 120.56356291617118, 109.52725272024833, 98.12413031055083, 82.07357975744432, 39.06330423970377, 10.436163044744923, 1.4735957403336803, 0.07622603957931842, 0.039716637167598934, 0.09013975910361736, 0.04877337457371816, 0.022663025846404415, 0.08327710517351666, 0.024001954100845803, 0.050014919646444826, 0.0198413573971559, 0.010677492170925102, 0.03732597169977042, 0.04738575951646894, 0.14513099055376746, 0.058291714428172964, 0.03960006156816118, 0.07487043933642488, 0.021156400945338032, 0.041317646016156485, 0.02065196652115593, 0.03274269747517763, 0.008703630244840057, 0.03298342145318466, 0.043261885237429416, 0.024568047111613617, 0.021916159068144137, 0.05901433452362976, 0.030744125383094918, 0.0846053407557549, 0.07267987220397881, 0.016805343292353135, 0.13072651510517444, 0.034458079420390635, 0.030088662470300353, 0.09503624837605223, 0.020982020181573687, 0.06920344947326569, 0.010931589171260355, 0.0631109360725649, 0.03357439316929348, 0.03474461928670926, 0.04041620184697452, 0.05330127213270434, 0.028541827529308297, 0.03909032964598268, 0.00779839058879823, 0.025780890700257113, 0.008695335427839911, 0.018184782276230476, 0.032711896910181934, 0.11689963164709269, 0.08071244964676519, 0.035729306569743546, 0.09471714977295169, 0.02590218731652825, 0.10526186741528012, 0.1848896514744528, 0.11670946564164855, 0.1257006335823286, 0.11114799672917974, 0.14048639865171525, 0.1642636074534347, 0.15046850898333136, 0.10157264844183961, 0.1674065291280708, 0.1065229936953514, 0.11315068079819603, 0.1800881188002325, 0.14851293166077909, 0.14437978005697652, 0.10776249331332023, 0.21436955749748215, 0.20137037841543076, 0.21932113615255203, 0.14436592918730554, 0.2565174321493795, 0.15923846903587544, 0.16395052264053978, 0.12797132585077517, 0.19088766026881435, 0.16084650291069863, 0.07699089410204081, 0.22331715801790838, 0.10498256707984595, 0.21958385834530478, 0.24432256877903016, 0.21962061524391177, 0.11160259330344778, 0.13263517720324378, 0.14055720049767725, 0.15876412271491944, 0.13757339528491422, 0.13270665320657915, 0.23333795578970065, 0.12301479826771444, 0.1287821839533506, 0.11517680715769531, 0.19063341100850414, 0.19844150170683864, 0.1869531705855362, 0.31228051250500066, 0.4322193298609026, 1.0241632115456367, 4.961569789917239, 18.505832687500988, 43.8814260882716, 81.1783693682763, 112.83898045939785, 104.51901358942833, 110.26411702555995, 93.25491566811839, 62.43477436804003, 76.82505622986825, 37.275060376813336, 56.50359369093373, 65.72123419853949, 44.11006496798608, 76.60004554256317, 107.15680753031086, 143.45144794833277, 119.7883221410936, 141.27454819217806, 59.992867515933135, 35.5464522300228, 14.52259909722113, 5.085173479972347, 1.7491258200137847, 0.2835110917447075, 0.8133150997661776, 0.2402556531371609, 0.7740553612670591, 0.2010316603005894, 0.10777511078143313, 0.1829417656746603, 0.22611593767519922, 0.2074873146991576, 0.2506028043646967, 0.27754908908278714, 0.40041506711033087, 0.2031782233426648, 0.2509770996027416, 0.34931504137573705, 0.42909182187530304, 0.33038001387350024, 0.18291073911372693, 0.21055056322966853, 0.2619151038027579, 0.45894124274772985, 0.3806603561726309, 0.4355815978300187, 1.5563469644515746, 0.7934125645026084, 1.4225870322796608, 1.4019714223761714, 1.1690156065648603, 1.3824195102337868, 11.79189205169678, 44.339994307487245, 126.09608957844397, 122.20066608921175, 136.39712795134514, 129.37413984729397, 57.404828840686434, 54.35893973996563, 48.2235957730201, 44.823136175832445, 89.46671408991661, 111.01419187361195, 95.53532677312052, 114.62250571097098, 127.70206482179704, 123.46019406472485, 114.15656735820156, 102.48091866893154, 54.646065081319506, 18.425180912017822, 3.5476882130868974, 0.19614190494100894, 0.17209423645850153, 0.12832799340568243, 0.161819250713433, 0.16219046627802236, 0.2507146532016416, 0.0913563680144087, 0.13657522868485222, 0.12484637659884269, 0.17297332235161336, 0.2002615274320687, 0.11676001978377182, 0.2937676913795933, 0.26811603396650285, 0.11975149353665691, 0.21187002710517377, 0.1540088464295672, 0.11551718768333236, 0.12351654755372195, 0.08541728670318281, 0.15764830033144644, 0.16481827043237227, 0.10465137960930025, 0.1760075055062771, 0.0787758406612181, 0.1661219682183958, 0.17552660147268928, 0.14220888606242596, 0.2800561271367535, 0.17826079991796326, 0.3571729584326667, 0.15198669606639495, 0.1975154393022099, 0.16268237133420285, 0.20075858059910037, 0.17637338909891345, 0.09384888870220992, 0.26527130435551366, 0.1469330744998109, 0.11299413839174856, 0.10726132625413519, 0.190643125003384, 0.1175835949458903, 0.15795249852441973, 0.08293276397331108, 0.16658093149383224, 0.17229695864502462, 0.1796468061905715, 0.20464355035895304, 0.195624427869916, 0.18319584639562717, 0.20113583293653306, 0.24714313597688753, 0.12902276620509165], [0.07520486735889027, 0.03473690095087213, 0.03624647720566681, 0.04031608947702954, 0.03942586849593828, 0.0407651242529673, 0.056460538293204965, 0.017227105338186506, 0.04845944706410651, 0.014977195119905858, 0.060069291221518675, 0.06916028807961172, 0.03936792543578533, 0.050698204957429445, 0.0906227775398762, 0.05076830966338035, 0.012152146307691451, 0.02373211303605668, 0.06430481515464283, 0.03459390680936556, 0.08422440353540644, 0.02489284923931043, 0.03286473528151551, 0.007596632236644867, 0.012604996201492125, 0.09840250766325383, 0.05879831305074115, 0.061780340939519875, 0.040759347950018225, 0.06310775297723951, 0.05198082000377679, 0.04447395890770901, 0.03675201479645987, 0.04448318643675697, 0.03744417523604728, 0.06671527250399513, 0.016632398943446817, 0.09870649901248756, 0.019703143644296837, 0.022220860963927645, 0.039645283738331455, 0.048901705792354005, 0.08952006292078765, 0.06948955266946746, 0.26489760666604967, 2.350339120434177, 7.349004235959823, 16.79434568651261, 26.476704689764208, 51.44262221551711, 82.7010726928711, 81.77325956283077, 82.00712696198495, 74.67755071578488, 61.71836130080685, 27.085789941972305, 15.209723826377624, 13.735706921546692, 40.97476151681716, 58.13444068354946, 69.47795483373827, 67.42019314919749, 99.76783875496157, 96.46087277320125, 58.623026801693825, 27.308019668825214, 7.569913104657204, 2.273672963342359, 0.22781208698307315, 0.13935819628738588, 0.043010317284854195, 0.07897598113143638, 0.09223304073055906, 0.5187411161680375, 0.0232699015478213, 0.05110068457020868, 0.3215840374750476, 0.10066923925713187, 0.1609510739123629, 0.11528700124472381, 0.24643750771159129, 0.10225618273139962, 0.09097065040541273, 0.1949499947048964, 0.03174213685035225, 0.06746668984452564, 0.2625667381911509, 0.22727876721370607, 0.20463668621115147, 0.2657929183013978, 0.040508825707459645, 0.0074037470978744815, 0.40918214667227965, 0.455976911490002, 0.38012994753737606, 0.28984277779536866, 0.4681256563673097, 0.3470437132543133, 0.34164245630944934, 0.2888997848476133, 0.054540124406377156, 0.2490968287231461, 0.2687277704957993, 0.14218421803126413, 8.543343890097834, 37.04876707446191, 72.51576777427428, 99.476759664474, 89.91195017291655, 62.04091741192726, 46.417524737696496, 23.76552320295765, 27.05475222679877, 55.49036310565088, 60.33030902185748, 69.2655663336477, 78.47862551289221, 86.7681469455842, 88.28047167870307, 79.78825784498646, 56.66372445321853, 26.55912937656526, 5.232314823135253, 0.037675752124238404, 0.021620334216183233, 0.07821075888651033, 0.0791727661365463, 0.03420446218261796, 0.019105095190987475, 0.039907113438652414, 0.014388249706356757, 0.06552619679320244, 0.011715415861427545, 0.1143995266888411, 0.015287010652583935, 0.030515580287864132, 0.055717873507209366, 0.08506445724877619, 0.036010047150475365, 0.06443679678223788, 0.04203764226047262, 0.0717241928401974, 0.03535381623453671, 0.03950138944351385, 0.1170847261504781, 0.056523388146512935, 0.05272344648537617, 0.02280645665802783, 0.06122052601929154, 0.05216677252563739, 0.028020401274965658, 0.01172667065064513, 0.01802197901622182, 0.05924231462901639, 0.021294624274296146, 0.03256453989794658, 0.11233809899779097, 0.047309602715916214, 0.0761470559143251, 0.016998495125482162, 0.044407761250171936, 0.023945167833458514, 0.01846544816338968, 0.020536074655190594, 0.036983599345530235, 0.010422107185267154, 0.02139998434652244, 0.04202737285184764, 0.047934278470253756, 0.043884423606458216, 0.030276719818732915, 0.04040281063005809, 0.07946423960909729, 0.05486844287764642, 0.03785476771994464, 0.10803510570117544, 0.08240112193649815, 0.0822640917894821, 0.030272789787681356, 0.030764081973522425, 0.03667121550308601, 0.05660847370182315, 0.035349457194247556, 0.05989907797606242, 0.03991132309179633, 0.06911601585846755, 0.0558979616260096, 0.05644956025325003, 0.07376633043731413, 0.01301635477331377, 0.03561277693558124, 0.03595720623589812, 0.02561092643337625, 0.02240598419561021, 0.00627316938217489, 0.06976867680467906, 0.018259064076588522, 0.0324442909069119, 0.03987762288400724, 0.06177432714931427, 0.051579619757831104, 0.0652949378314999, 0.0839212702046479, 0.05608785567024062, 0.07769019448108251, 0.05017062701705483, 0.04023514462695007, 0.06417314762309675, 0.07507329941877434, 0.04473937006907598, 0.04434024209096547, 0.09244297180444964, 0.01451216347049922, 0.10188269188567516, 0.016230336848586317, 0.04446732458628474, 0.03347927952305444, 0.07112136591346034, 0.06636712384680588, 0.030897189750366157, 0.27794622906273414, 1.6705332888710884, 5.305489580477438, 11.578832826306744, 23.266409443270778, 50.382040777514064, 90.39710813953032, 94.22672994675176, 98.16067895581646, 88.77530221016177, 77.15116993073495, 54.06229872857371, 26.322671251912272, 24.910386570038337, 35.49892487064485, 53.29698939477244, 60.378691457933, 28.81763992771026, 62.760185964645885, 78.90561472985053, 61.23530572460544, 31.360134001701113, 11.200092684838081, 3.4571179891786272, 0.4028125545911251, 0.14209388094323297, 0.0152156122156509, 0.1337320312497116, 0.20626491416365872, 0.24563892233756282, 0.19408076070249083, 0.0984097165506213, 0.2293211882633548, 0.2281934302300215, 0.18345401802610967, 0.28969096981229325, 0.5066829535268969, 0.4699857484909796, 0.3996055266789852, 0.9661321738554586, 0.5459120485090441, 0.6390636209999362, 1.9393921523324906, 1.1751259238489213, 1.0858291219319067, 0.5984498680599275, 0.17307607006401787, 0.40506715135228255, 0.4122355279903258, 0.7013717582148891, 0.24602919816970828, 0.6770594982850937, 0.6069366513721405, 0.5200424850467713, 0.37964881367741093, 0.25203217121381916, 0.08117325919409914, 0.43727039269381957, 0.5951536062263674, 0.13109051412151707, 8.809113887048538, 36.61316433260518, 65.10946604513353, 66.15711150630828, 69.27708241247362, 48.20980864186441, 51.829736617303666, 40.58728625697475, 52.337965965271, 87.02715673754292, 77.41243116317257, 82.78349737967216, 89.01659073368197, 102.57819344920497, 102.51204659861904, 94.83866676207512, 66.09243946690714, 29.548136265047138, 5.130637672639662, 0.03515841784856973, 0.03355351727335684, 0.03010069196593137, 0.0484811733176391, 0.04977763923365743, 0.018336291485015425, 0.04418816214667694, 0.07979646895922, 0.004339970445500747, 0.03974538078651794, 0.040400657922990864, 0.02930654990186374, 0.06475773399635669, 0.0325450889255491, 0.13277652042527355, 0.05559426139018709, 0.035448523854175885, 0.013680595138500775, 0.04213065682579914, 0.04786074552084169, 0.02501360193315533, 0.06063225859355542, 0.025813859294078527, 0.04565120622095081, 0.032005841550867886, 0.01797480523706444, 0.07397934118466032, 0.015201144645200863, 0.03989361113898697, 0.04262158895031579, 0.05151002450034984, 0.03831962604195841, 0.0228750157815915, 0.054866374440250866, 0.01785025657755473, 0.1624748074719983, 0.030942840929774028, 0.055181853277909185, 0.031072562597992442, 0.037349413990253405, 0.021467398168639313, 0.03588057446083234, 0.05018293038911877, 0.09473660074534918, 0.037655048598084724, 0.018290165331094496, 0.04306722995674899, 0.035381085134201476, 0.0681617077920706, 0.1372061020904972, 0.03329289799195624, 0.08266094065601788, 0.042842758534055565, 0.23547944732971732, 0.17600372103193115, 0.10955526929108367, 0.08826854338328685, 0.12328914967515778, 0.11351867113262416, 0.100558623821745, 0.15403771262255408, 0.12080719333983238, 0.15469460237410762, 0.19437728269446283, 0.1611945979417332, 0.19939653755676365, 0.1262753144387276, 0.12802864454926985, 0.176122602556021, 0.25305099154431976, 0.2098736479397743, 0.10840684986643254, 0.14439284951696474, 0.17985976331176298, 0.09255600807767722, 0.16130549682965203, 0.12914550881231987, 0.1365007036515782, 0.22329498743337972, 0.15575733486442797, 0.16724315321733876, 0.14627704276673256, 0.26209427644648864, 0.10945119624657017, 0.1686476834959561, 0.14282400870034773, 0.15789651281891331, 0.1698694558393571, 0.21755213188307904, 0.12804195915739383, 0.15420186994296892, 0.09977211965428245, 0.1329462701875356, 0.22095397595436345, 0.09942986221323091, 0.1621206603463619, 0.1707448185451569, 0.5785624706937421, 4.843765814458171, 12.402107927107043, 24.646968034005937, 39.125944491355654, 69.93698197026407, 110.45960795494818, 109.320355538399, 111.84080000846618, 102.72782402653849, 90.94911898336103, 49.48659896850587, 35.00963272586946, 32.36173868179321, 62.18974782574562, 83.02299730239376, 99.67643184046592, 102.76026202786355, 145.99330071480045, 129.95018697554067, 84.09480848620015, 43.40181435308149, 11.615432462384625, 5.6658441020596415, 0.7880445557736582, 0.49173522980943807, 0.0862159486860037, 0.3061408387316812, 0.390737752520269, 0.9955617785453797, 0.307254730573585, 0.598415179598716, 0.4451834374377805, 0.3347041818403429, 0.3550123146945431, 0.3997469158662904, 0.596801185559842, 0.3103348023949131, 0.3028165687236094, 1.2977202164549984, 0.2757226435407516, 0.3542391174743253, 0.8955502257712427, 0.7734259434284703, 0.8278477264027443, 0.7543609567707585, 0.25691526160845835, 0.4103712683483478, 0.894188121441872, 0.9203109229283949, 0.9210595440480017, 1.4390608644293201, 1.4301167572698286, 1.3734446369832563, 0.9685687624639081, 0.5076553642509446, 0.18364601498169286, 0.35029287600228864, 0.8719527565183178, 0.3397354183177794, 12.97405617852365, 55.5104927093752, 105.81786724828906, 141.12025783907984, 117.31290648060461, 84.07995839272776, 68.86041687380883, 41.48087278489144, 41.82214644647414, 77.43859337222192, 87.67243369933098, 94.90964597271335, 101.48037695115613, 111.93667058021792, 114.08171284583308, 109.25580901484336, 82.50777829077937, 42.2685121720837, 8.018777380066535, 0.19226592905338735, 0.22319962480856528, 0.15028599619625077, 0.20619230435019542, 0.17574554940144863, 0.12421295212040986, 0.20040458669104885, 0.19674812563725058, 0.18882188885923357, 0.21761692759971465, 0.18581625014062852, 0.18869407474994662, 0.10515312889530774, 0.11436323710386792, 0.3822767710493457, 0.15095249269037478, 0.16066993496591048, 0.14893797256292837, 0.09025060436538151, 0.17746671914092957, 0.14032308402801716, 0.19427237461411184, 0.10398698985696801, 0.1567481470204169, 0.13297274618619873, 0.21666936876793064, 0.13335005981066536, 0.14666978540199418, 0.12932743937257798, 0.1306032822016747, 0.15741096629250437, 0.10798374716673168, 0.1880668785663382, 0.19482435628531442, 0.0770973113756026, 0.21871819431262635, 0.11350082894486767, 0.23534786406784292, 0.2700368308972928, 0.11083167902524434, 0.12652251569013442, 0.10415296280576337, 0.1430978698115195, 0.20388952065860072, 0.17563065153456506, 0.11758152650849474, 0.14574569950421012, 0.13273145913356735, 0.1503406029434935, 0.17279509965690876, 0.16111288700372944, 0.13617540739717024, 0.2323012090017719], [0.02874925924134591, 0.03562027693635995, 0.02015959415134163, 0.021632463303244403, 0.023768808647629716, 0.08985531831821127, 0.06598904413441498, 0.024421253174002615, 0.01959566916939953, 0.04538401390515989, 0.02832828626607455, 0.058160728714879484, 0.10917401797468625, 0.015241048249956823, 0.026820056410806797, 0.034369983139538, 0.026430062115973523, 0.006452963993539133, 0.03241896787057481, 0.0357560009034651, 0.008744614033569253, 0.05787576698968488, 0.009115667762084594, 0.07914110372263579, 0.027512264730889472, 0.02890174521223432, 0.04985778735229566, 0.0340240293242518, 0.028240873718694336, 0.04636645272013642, 0.05069241333272188, 0.05293002592459802, 0.06586155944293545, 0.050586137785426075, 0.06544447819431944, 0.03639697900883133, 0.03203614990437224, 0.07721430066251948, 0.03504790200461303, 0.008001847740923686, 0.03787697277842991, 0.014098087201766191, 0.1506581923533832, 1.2160333029685484, 10.208643021122104, 25.862530162257535, 37.45142582924136, 48.580649129806034, 71.26180956440588, 72.47955645284345, 74.37758353448685, 73.937744632844, 56.10598302656605, 30.08367903770939, 28.96128300697573, 21.819443164333222, 45.17323909267303, 57.14213594313591, 48.71218189116448, 38.72583527718821, 45.62004020137172, 74.8416313048332, 33.254960429283884, 9.91481532973628, 2.422294020652771, 0.239532083092678, 0.2620997309925095, 0.033695894714084365, 0.0825912879419423, 0.041643850084754734, 0.11466353590930663, 0.02705722957128479, 0.040713623992257544, 0.03660384190058516, 0.09461344445064183, 0.12073672857255706, 0.10630216885117755, 0.1733973673394611, 0.11056799922258624, 0.08480963342252278, 0.1776959020043573, 0.2800929300006359, 0.17348840922838257, 0.8655566577949833, 0.2766603658035878, 0.9649053300099989, 1.6124682368770724, 0.3735590581932376, 0.04209771121461545, 0.07542359312215159, 0.10732328744545098, 0.08589968460822299, 0.24089527526690116, 0.23803982042497207, 0.15484130821160733, 0.034748989818317276, 0.11868958076041554, 0.051298082445658026, 0.18770344645505954, 0.19922360086873656, 0.32246810293966727, 0.20841631888141557, 0.07786361380450188, 0.143097885133278, 0.15732516444498496, 0.16509063001121246, 3.716529088635599, 26.991880555306714, 51.944662063352524, 97.29163862043812, 70.41430304127356, 43.9212263784101, 32.47206711000012, 22.039890173942815, 31.08747828391291, 41.89721276683193, 48.096938517785844, 43.28959534245153, 60.089569630161414, 74.5453276172761, 75.6324831131966, 63.079219787351555, 40.80905314414732, 13.227962966888184, 0.44955994453160997, 0.04327022410448521, 0.06192734938174967, 0.044237816135489175, 0.0783555418433201, 0.06364272749652305, 0.003817851120989109, 0.05191977811797012, 0.026143451386521903, 0.02690687140960607, 0.02235922984959137, 0.022280732650429975, 0.016748401892161178, 0.05285367377162461, 0.05564660051717393, 0.0363698250223552, 0.019117195549751484, 0.019675895812049992, 0.13090983994545477, 0.015188774240443544, 0.019866893022891977, 0.051318613602028745, 0.007243957915042918, 0.013320413155240879, 0.03679211183841671, 0.0432145448341485, 0.044674363678261164, 0.0547065761601252, 0.03656548387821644, 0.025291387329719243, 0.0451315381383944, 0.09707280119220096, 0.042893193932550575, 0.07431017625476084, 0.061213937663142724, 0.03049790280901136, 0.05119720398778877, 0.09883753835193573, 0.06127103419613935, 0.011185194917714164, 0.03040819391307812, 0.025761066259996548, 0.022689429066714742, 0.021533184053917086, 0.09109356921286353, 0.05368959444064287, 0.017989424109879523, 0.08352802195135625, 0.028416662169019544, 0.06129112485195361, 0.04166949487802002, 0.027704501088948983, 0.040901851795253255, 0.013865090178085432, 0.03574642863485121, 0.043804011187486114, 0.0531879753895825, 0.007988716993901518, 0.03185763992669602, 0.021398067211491928, 0.01355938662234093, 0.05410756435125105, 0.09501993070326506, 0.030504025766746174, 0.004085047985427082, 0.05576901370659471, 0.03854778617800724, 0.02381296020992581, 0.07007130451740758, 0.027032195733139114, 0.07554808240984717, 0.029433764547349948, 0.013643304851176518, 0.038194600492715836, 0.02898309608891366, 0.037168027352421515, 0.04306167198885833, 0.08101150738976656, 0.01639386597690323, 0.004716215377312995, 0.12203246670504733, 0.03767806187933011, 0.02903040201823798, 0.1057379297731865, 0.07841928801949948, 0.027950145266649705, 0.05491233588526807, 0.0248651743130458, 0.08114302936460703, 0.11989312021121865, 0.056575830695369554, 0.008777846927724538, 0.054965640283039505, 0.06554266002269522, 0.11033530001558604, 0.8834680386127964, 6.9513940618884185, 21.156046813534154, 34.59888996616487, 48.519785711842204, 76.05488315705331, 84.47841628905266, 91.57829069322156, 90.35288733820762, 70.41606026311075, 51.95800596667875, 44.550048997325284, 30.407978642371397, 40.74906049236175, 37.52117341564548, 42.07863807678223, 32.657555995448945, 46.53803171650056, 70.9426070797828, 39.54299049992716, 15.59731185436249, 3.6182379241912597, 0.11601658507941232, 0.32694787868568975, 0.1829446308434971, 0.1477249183001057, 0.04695888000330137, 0.2736312235074659, 0.36815921085015424, 0.14973375405515396, 0.3118742714005132, 0.9663644517141005, 0.4265394314162193, 0.6164824746308789, 1.3617397940927938, 1.1809007559091815, 0.7017793782776403, 1.0345163076154649, 1.6902592561898695, 1.5871079073798273, 2.4503149428675255, 3.2331116737857943, 2.8790699618477977, 4.07208826753401, 2.8608561908045127, 0.396436098362169, 0.7503782188700092, 1.5185218328429808, 1.2435552261529432, 0.6910688562258598, 0.5939353425656596, 0.39457033718785933, 0.3227921274881209, 0.6565410283304031, 0.635669545060204, 1.0563787409374792, 0.6350735899421477, 0.19730687952570378, 0.25850196759546956, 0.1529350822731372, 0.06046003436729793, 0.23369199566302762, 0.2317690690078082, 3.5512399192779296, 26.330062958502, 50.32125580695368, 72.69012497317406, 46.987507881656775, 32.35687886514972, 27.672068572813465, 31.845962693614347, 52.03022464629143, 74.27102058164536, 72.01089597517445, 66.35274364102271, 76.04945459673482, 88.0764848955216, 89.91066363550003, 78.3590873595207, 49.565116974615286, 13.957598343972238, 0.30373798863541696, 0.024917904144874024, 0.024713268653760036, 0.022713298451215513, 0.044469982911381996, 0.025245391410745444, 0.04803539824581916, 0.027923023838910366, 0.030721265319434386, 0.048744826307219845, 0.0710588071735636, 0.03329444548956329, 0.05990710274706926, 0.015908580877998426, 0.058677347767497265, 0.021936234402199908, 0.03598895674991993, 0.045752605618608576, 0.0812254221208634, 0.06243937190682177, 0.025104567213284395, 0.03720718976711074, 0.040320276147535736, 0.024971459436440663, 0.04483869336845894, 0.004954338965622048, 0.04787048632879892, 0.03992383713803945, 0.03989649162958226, 0.030505720736278646, 0.045926427138188196, 0.09492324274634162, 0.06068432958976877, 0.02197835391627685, 0.07511937194654057, 0.04186695021006369, 0.07711126183670375, 0.057581095100050016, 0.009869540414412417, 0.03662931815450711, 0.0595289770694029, 0.044826485757385535, 0.05642558936209929, 0.0672345575425894, 0.044485986488120216, 0.0767051969324389, 0.07700563363370395, 0.010771258460027317, 0.047863116562967344, 0.020132003494748668, 0.0181535737694151, 0.016651637326445312, 0.13912421771355216, 0.11186030528117573, 0.14596832465500603, 0.06545792303739056, 0.09094240474364451, 0.15259212003119532, 0.14158348252456035, 0.1384415874077428, 0.07714755142167692, 0.13852478455631964, 0.17103544166011198, 0.1549077739999179, 0.15030542418601053, 0.16844652412879854, 0.219638449770789, 0.1335426236713125, 0.15708222264243712, 0.14383843168616295, 0.11658251721171603, 0.09897692804975856, 0.16449554823338985, 0.09689706828325026, 0.12147697635115155, 0.15125894318184546, 0.11292808629091709, 0.16511788741955835, 0.21318589036743488, 0.11363777482221205, 0.27661841482885424, 0.22794851192062904, 0.1635639853174648, 0.1924435695212695, 0.14624704276361775, 0.15101397890717755, 0.1734516523297756, 0.14562378427194012, 0.2193832505614527, 0.2612471364198193, 0.1582616456453839, 0.18822548941018122, 0.18915941187691307, 0.1259295023497074, 0.23078374204135713, 3.719054114434027, 17.972790425823582, 38.428115613998905, 53.14530741783881, 69.50912983186784, 94.06168445464104, 102.52990122764342, 104.00803858234038, 105.72081212074526, 85.5004055269303, 49.886504219424346, 48.875540764101096, 37.06640205075664, 70.02468616731706, 85.41919677488266, 70.92649398311492, 59.84861843047604, 68.73745056890672, 108.52054503656204, 47.49616084560272, 18.137031832048972, 4.788297126370092, 0.6968731060624124, 0.4819049121391389, 0.3424877270815834, 0.19350717535182355, 0.23921605650215383, 0.300421410150105, 0.36799152952528774, 0.1587579020809743, 0.25750924021967, 0.5385072877810848, 0.4135018100421275, 0.29523928499510216, 0.7111675712850787, 0.7006283464931673, 0.37809763884832787, 0.33329081090707935, 0.7046393990035981, 0.9533263706872541, 1.5840924627357915, 2.6705658339685012, 3.29404128174628, 4.044317641565877, 0.9312138862667546, 0.19543325828929103, 0.302040797447966, 0.43275988150027495, 0.3325041305393942, 0.27389488032748627, 0.2055661653679225, 0.28377913058765475, 0.17037953250110152, 0.21429445023738572, 0.20770695210704881, 0.6504155731489581, 0.4953154957582874, 0.5075213601512294, 0.5597662889669018, 0.5235793597755894, 0.33070103535729073, 0.41959895061389096, 0.3667330309267967, 6.523671361707873, 39.43899277717837, 75.17513475110455, 137.3851102398288, 92.28288173675539, 61.894934638854004, 48.48827338987782, 31.044055684920284, 47.89225747508388, 61.31330597785212, 71.58555415368849, 67.26770708637854, 88.83438094969719, 103.36396971056539, 106.8255869034798, 94.73066822175058, 63.866870941654334, 17.954529831486365, 0.5129330358918637, 0.06786730020276963, 0.12304923391991085, 0.2603959514489097, 0.20801429126051166, 0.1801931188111344, 0.1809619186866668, 0.16206799946244688, 0.16907986433755967, 0.15534375463762592, 0.16852504814103728, 0.08136681896904785, 0.1467625280061076, 0.1778320817937774, 0.1245280211010287, 0.13358587699551738, 0.13196658162820724, 0.17643387940141464, 0.19425349820765758, 0.2366785434705596, 0.11179330323131816, 0.11991302317549145, 0.1246880415466524, 0.08963801747848911, 0.18165945706348266, 0.09735509693141907, 0.13686220522128767, 0.14780016345602853, 0.13455732244878046, 0.09546922594909707, 0.16663759135671202, 0.13513581076216313, 0.16152704945735394, 0.14823156288794934, 0.17504920612179464, 0.12149636603651509, 0.24626490810225088, 0.17467590679805126, 0.11290256790215931, 0.09794834775910263, 0.20438085880971726, 0.14251573491961728, 0.1240671502666608, 0.11512129642670194, 0.13648631652036022, 0.10308032479858208, 0.16933976732675107, 0.22481490587515218, 0.07825475531600176, 0.14465479030003472, 0.11359934019105089, 0.07950281979696405], [0.017470738535085996, 0.034141030102487535, 0.03986940659101933, 0.0657939675053762, 0.018053300521006028, 0.027037025917501702, 0.065981567116274, 0.027951784694807667, 0.051486471127117836, 0.0792797579760513, 0.04026844646901854, 0.02984012822590528, 0.05651482328351948, 0.0516497589377386, 0.025355401636672117, 0.030424343046521952, 0.07888978857907557, 0.045876347970577984, 0.08539839497497005, 0.05513374295626437, 0.06734669749294558, 0.02191403317415426, 0.03406329899125042, 0.012847831709340457, 0.00602347930262406, 0.05551712399709129, 0.040336072880534396, 0.07144601099313268, 0.02563032761005865, 0.06413232279761184, 0.04745664180166299, 0.03773029375400755, 0.0855282851825318, 0.04343605149657496, 0.047634994731314724, 0.022113321371556773, 0.013787969064358023, 0.031632352620363235, 0.0657795956959167, 0.0445055638650252, 0.08934537955229321, 0.9820465779592915, 11.74490107643989, 30.26373544046956, 43.23117948347523, 59.86781058772918, 73.5087706965785, 80.13075920843309, 69.1322135925293, 58.29759167086694, 59.10521161171698, 37.06120491027832, 40.137366863989065, 30.01125639484775, 45.65500420908774, 77.60619624968498, 52.92658428991995, 41.7565526500825, 33.39935856480753, 41.13978347470684, 31.713925907688758, 8.440016892648513, 0.055631795868037216, 0.19845159874568064, 0.1489870175118408, 0.02773044274128493, 0.052313658393799305, 0.0768624977659314, 0.03623433088162734, 0.0417406682766253, 0.025461914671224453, 0.1025967471181385, 0.4719706210157564, 0.44503898389877816, 0.24360411620188147, 0.2492466142341014, 0.7928294183746462, 1.2543023978510213, 0.5742929094741421, 0.693724055684382, 0.8211614948607261, 2.5303793434173834, 1.6888332294840969, 2.718385409924292, 3.514911662186346, 2.51292406070617, 4.073252721178917, 6.7045073355397875, 3.7988976365135567, 3.15267562866211, 1.872466220971077, 2.167222533495196, 2.2967811169162875, 2.1720063542166064, 1.3340827942855897, 1.3699960155833153, 0.19340994347247387, 0.4227229039515219, 0.24031629665724694, 0.12762669353715836, 0.1520900106838634, 0.021142052118516257, 0.11229748867692486, 0.04310364211579004, 0.14193850299043043, 0.07250843704828332, 0.0833045464429644, 0.3431474513584568, 1.9021542730831333, 17.640732372960738, 82.21978218324723, 88.71861611643146, 80.91797890201693, 69.16331798799577, 29.316847824281265, 13.441614470174237, 32.460998181373846, 38.70297570382395, 43.273494012894176, 60.85514960750457, 54.05947069967947, 80.21502740921514, 66.3391016375634, 47.5423663662326, 9.8292851063513, 1.8644291619139335, 0.2950677119435803, 0.063133719527433, 0.04863046087144364, 0.04221139100169943, 0.049048748708540396, 0.09778796725215451, 0.04094990849074337, 0.04593779971342414, 0.024778292281553153, 0.035654773875590295, 0.10889709251181734, 0.12324824824088043, 0.05054116076339157, 0.01614820839266383, 0.005375640401090946, 0.07616151965433553, 0.0744193974101255, 0.0935053289116871, 0.02499614278936098, 0.028317028604027246, 0.02493646070961991, 0.010410466479257712, 0.03854865951824092, 0.0989787973042938, 0.03055896959267557, 0.06308531809237695, 0.030836249371209455, 0.05564403412262759, 0.04636064194323075, 0.05177155542638033, 0.07814987021828852, 0.030450160209570202, 0.02238819946444804, 0.021436785295185064, 0.02909065100304302, 0.033694983069454475, 0.01816764680458413, 0.07260899374922437, 0.02714578167445237, 0.03659261105161521, 0.02169569045485508, 0.02528045525503976, 0.010890094018841704, 0.04349627749874227, 0.01546180510382739, 0.027370015609889265, 0.00879032841523088, 0.05779175778790828, 0.04586975195354993, 0.028827815812321442, 0.09616694818701475, 0.03579086939533872, 0.0288637280989919, 0.04972228555068855, 0.05963509173823461, 0.016506228092757445, 0.06276704686423464, 0.049234689739082134, 0.03487684989287969, 0.07881238305520627, 0.02662337291234684, 0.03743148498958157, 0.03267806263700609, 0.011056605144403877, 0.06468209813559248, 0.009859024900041763, 0.031103049066939184, 0.01644909900102404, 0.08646134963078846, 0.050260672991674755, 0.03287795029820935, 0.035762068319825396, 0.036839804642142794, 0.09237859743617235, 0.016129950602208416, 0.047793425544495546, 0.03549070082484715, 0.056576393769993905, 0.07790455354317542, 0.03843340925091217, 0.06337834672341425, 0.04114982296502398, 0.06159025537330778, 0.046266554854810245, 0.03480912388993367, 0.03156734431432861, 0.025693288546115644, 0.05625773949788944, 0.031527396659517, 0.05982298246254364, 0.09297727216635981, 0.45197351985881407, 8.279606661488934, 24.512758255004886, 44.16679813015846, 63.740739284023164, 79.68933566924065, 86.73964700391217, 87.35634557662472, 78.87312181534307, 80.57121784456315, 58.8853156951166, 56.09021509847334, 31.412966366737123, 48.28499263332736, 49.432352589022734, 54.3582925488872, 47.98735533991168, 37.49036712031211, 51.25020642434397, 36.4083852306489, 10.272587460856284, 0.6123369583679784, 0.24523386100847877, 0.18687060162905725, 0.18303069316091078, 0.08900007308130303, 0.16679480792053286, 0.5917204904460138, 0.4926127988484598, 0.48985941756156187, 0.6609661973291828, 1.5409173407862264, 1.9075497384032898, 2.7692619831331315, 3.031034104285702, 2.3089517412647127, 2.8318409477510764, 4.191876226855863, 4.281723018615477, 6.366944236140098, 10.155577275060839, 8.227835297584534, 7.092952891703575, 8.512053182048183, 8.37043502638417, 16.200014429707682, 10.157098174095154, 10.212870355575316, 9.813406371301221, 5.568653652744909, 4.657601300747165, 3.477015437618379, 3.067288816936555, 1.6871548227725492, 1.4485074026930718, 1.835382172176915, 2.1961453557014465, 1.291986078985276, 1.2700716742584783, 0.6409652350891022, 0.48108734310634677, 0.4295176441871351, 0.18629989676898528, 0.023078088453339956, 0.1436389883559558, 0.18349884949143858, 0.2751934300026586, 1.748941346041618, 17.294589088809108, 55.94372633964785, 61.722907327836566, 53.64113815369145, 34.53663802916004, 40.708240385978456, 23.37447858625843, 39.545508661577784, 52.72054218476819, 57.61030220216321, 75.43630969139838, 67.41002636571085, 92.41896444751372, 88.55431587465348, 59.22609121568742, 12.90554904168652, 1.7728522371861244, 0.17262622323488036, 0.11802892185627453, 0.09392989483932335, 0.03097378896669515, 0.03483027557752306, 0.07467561551640112, 0.14202330892364826, 0.060744701148641694, 0.04218230264321451, 0.07868633860902441, 0.04678043514309872, 0.06627413609455671, 0.05324758469097076, 0.05780652796308841, 0.019240208202973008, 0.018078192632885712, 0.04128006940347053, 0.07126046449787195, 0.04297644853772175, 0.05841100963974192, 0.025256978490600185, 0.06034137117826651, 0.039234239262558764, 0.06432045867005665, 0.022772721976282138, 0.01999372079397642, 0.027570813000502608, 0.06394301864108251, 0.02009413002299205, 0.061266215503095627, 0.05831691106000255, 0.008896757180111544, 0.09157946813971767, 0.03926285647697026, 0.07838638454315164, 0.03887700097214791, 0.04042257952894415, 0.0675947031366729, 0.06135708119179453, 0.009507542802771975, 0.014906420087021206, 0.11372199852860744, 0.015948554388277473, 0.04741969721151456, 0.007819405338171149, 0.051179901892018896, 0.06766683031474391, 0.023264399121305155, 0.021148684524720716, 0.008188802880355188, 0.11580082407641797, 0.11597495586160692, 0.1161001269675551, 0.17706288355252436, 0.10350345048092066, 0.13203171442352957, 0.1547411498763869, 0.14620404990930713, 0.184338451212933, 0.18406425302307453, 0.14252000969023476, 0.17987575922762195, 0.18783437088131907, 0.08848245045350445, 0.16828797457198943, 0.21694113079818989, 0.16715039529146689, 0.10420424473141471, 0.2272903351413627, 0.19886044454911064, 0.2011161138333621, 0.09913655779054088, 0.1580333514439483, 0.21820968047024744, 0.1464996372740115, 0.08538714114336238, 0.20983537418707726, 0.1477713432283171, 0.2562073197576308, 0.16913080918452433, 0.15382178308021638, 0.12850470690717622, 0.18834732803365878, 0.18274534073087478, 0.12741198973549953, 0.15590128278540027, 0.09711937167711797, 0.16910526781312882, 0.24036400861317114, 0.1301987877776546, 0.18746526971940072, 2.2024000652374762, 19.71145945210611, 47.98723766880651, 64.67222375254478, 84.49831055056664, 96.92418313795521, 104.5237910362982, 98.48501190062493, 88.9245327057377, 93.83060193830921, 60.17322986356674, 61.179866944589925, 47.0614210251839, 62.48054842795096, 107.15197517025857, 79.66383241838025, 61.42950227183681, 56.82961717728646, 63.48344749019992, 53.7308741384937, 12.543380914195893, 1.3866687854451518, 0.6497521410065313, 0.35682668669089196, 0.2778985783938439, 0.22320172388947782, 0.42639696970582014, 0.5711572809565453, 0.24306232350007181, 0.32350602950299945, 0.25896496049338774, 1.6470637869450355, 1.934842325506672, 2.2295977800123157, 1.734928801175087, 3.516890988234551, 2.702712844456396, 2.9770909730465185, 3.691861792918175, 4.578736164877492, 11.777510681459981, 8.784985426933535, 10.76804361035747, 14.716978034665509, 14.538639630040816, 24.382945452967, 19.92984329500506, 16.533506108868508, 10.204541202514402, 4.639732943427179, 5.6895249216787285, 4.737104312066109, 4.933873443834243, 4.488088719306454, 3.841407794144846, 2.0949455086262, 1.7632793250583836, 0.7263601367031375, 0.5255972353681442, 0.28773621986469916, 0.19729995409086828, 0.21482412342823323, 0.2211915704631998, 0.21514375063200153, 0.29181453489488174, 0.24636476000230162, 0.4548296182145996, 3.8729304123309354, 29.21352278801703, 122.92439045444613, 128.2567507220853, 113.5196921133226, 99.34852169406031, 45.323842417809274, 20.09967603991109, 45.782289043549575, 54.70057818197436, 64.8316720224196, 86.89818136153683, 81.97443008422852, 110.70275568193006, 105.42414757513232, 75.39870200618621, 19.940000272566273, 2.8391166992725867, 0.4019333001586699, 0.12128045947681512, 0.17651687736713118, 0.13824873243368443, 0.3377867051430287, 0.24366503551362023, 0.24572631764796474, 0.21342366873737306, 0.08290891565622822, 0.3181908195537906, 0.18710706232776567, 0.1777871737196561, 0.14739718588609851, 0.10061419583977231, 0.09223708567479927, 0.3133680815658262, 0.14438229282536816, 0.2365478182271604, 0.11350166398070513, 0.14710362099351423, 0.10736130072825378, 0.1342324552036101, 0.14486544915745336, 0.2088489900192907, 0.1284133968874812, 0.11422360991878856, 0.14920326881110668, 0.15560310604351182, 0.11009559876495793, 0.16867933824898737, 0.24737077134270824, 0.1734428116751294, 0.15492326429774686, 0.10136932870673557, 0.2290174190796191, 0.18881519325077536, 0.14691304896147023, 0.18216227121170492, 0.18811927898035896, 0.15974980208181566, 0.2597379738525037, 0.1914987686060129, 0.15207568483967937, 0.19752143010977777, 0.044902558288266586, 0.14403022945888583, 0.18067602999508384, 0.09229800498653805, 0.1219679774235814, 0.058153615588502544], [0.09216136554436338, 0.02218102439186506, 0.020326356170699, 0.02262624213472009, 0.023346454798874837, 0.05529855528185445, 0.05263330858020533, 0.03668989272667997, 0.04744703888953213, 0.004340181598484877, 0.036472438669372956, 0.0411526000337495, 0.019449151023441268, 0.03319072867593458, 0.06289111863401148, 0.04290307646677379, 0.03322498046702916, 0.038315967972119974, 0.04273781981018763, 0.04982871431556921, 0.06910067877822346, 0.020211259120955102, 0.05184046120472974, 0.027606715711074013, 0.007910288742653305, 0.07359592950031643, 0.01328561361128044, 0.04785658183297323, 0.012281911068355605, 0.11535079338617864, 0.05348206505239491, 0.03235882996851879, 0.04846191769766231, 0.027133790483217568, 0.06520434793445372, 0.09480930248936338, 0.04471014381476468, 0.029320377788897005, 0.06948999700046356, 0.16179407706424115, 5.069469780691209, 24.8020036374369, 51.939362941249726, 75.26374109329717, 73.17452984471475, 78.43249843966576, 71.3237359446864, 49.48151165439237, 44.041870640170195, 27.12764947645126, 16.944566580557055, 25.995735814494473, 29.34212946122693, 48.1431911068578, 54.629504834451986, 64.11794577875446, 50.01690733817316, 32.95568358513617, 18.193788528442383, 3.736115444091059, 0.4009592040411888, 0.12562449210353438, 0.05504018063807199, 0.0675236331599374, 0.1627118810410461, 0.027721552290923657, 0.06687781337888972, 0.10034080204223433, 0.051592907552877744, 0.042438390514542984, 0.3120349966470273, 1.2321438255809969, 0.5803482522887569, 2.1029451825926384, 3.793580128300575, 3.581802047068073, 3.172680206837193, 2.2677940658984648, 2.2694179271498034, 4.903882511200444, 5.469419648570399, 7.779972207161689, 4.631174331711185, 4.419953227043152, 7.225523119972599, 5.4859990169925075, 7.468761551764704, 15.063412554802435, 6.577714758534586, 11.811307784049742, 14.89775811472247, 11.665840802654145, 5.955067421159437, 1.7351918451247679, 4.232467364880347, 1.1950552415463234, 3.675525856594886, 4.149922555492771, 2.321198851831498, 1.944064920948398, 1.1373436931640872, 0.7440351947180687, 0.313788878340875, 0.15069211472667035, 0.06647938637122994, 0.11441312474949707, 0.09973248226508018, 0.2572399756360439, 0.0827936883715372, 0.235731597509115, 0.6417093209681973, 17.714576875009847, 56.384824322115996, 89.31504388009348, 110.67893905024376, 79.58259228737124, 98.14724876034646, 49.62658051521548, 21.587017236217378, 32.85367450406475, 41.567561088069795, 60.98552526966218, 58.20460796356202, 75.04280182623094, 59.21834845696727, 26.235216125365227, 9.478946847300376, 0.7850882531173768, 0.16529614075777993, 0.04502892066093703, 0.03662678240347774, 0.02785360286643188, 0.04536436758034172, 0.04346617407375767, 0.058829102124417984, 0.012404054211783073, 0.0080802223660172, 0.03445501123825389, 0.04999123220782607, 0.024278515671950676, 0.07304836815643696, 0.013477911256373891, 0.02550274141192917, 0.02738789801726178, 0.06674133481517916, 0.038542603593199484, 0.04353548204826732, 0.034237327354569594, 0.025026175351212585, 0.042302589938645406, 0.026692954763289423, 0.040339416854323885, 0.00813493253512969, 0.038384724363324144, 0.02496461827127684, 0.03888774535528595, 0.0914636969326004, 0.005498471587235409, 0.015804193737435968, 0.026102193721359777, 0.025969051470559452, 0.048110183748987415, 0.004577566869556904, 0.05097338373983099, 0.08715968473904556, 0.0358161005011249, 0.05762536349075456, 0.046589955041605624, 0.040926899039937605, 0.03223921300002164, 0.038895130442876014, 0.04164978343572828, 0.019252683944819916, 0.10264144834852028, 0.062277221736768563, 0.09596123059670772, 0.02442525215296736, 0.04285411578753302, 0.01004232292724473, 0.06035582725739768, 0.0382188624972778, 0.018407072263559508, 0.03552770287158989, 0.04461715606251552, 0.0039775646526381495, 0.0415533023225444, 0.04196487922942446, 0.03799674679495154, 0.0800220282267659, 0.027269663837467952, 0.04160349257290364, 0.02035723909014656, 0.03078698225679898, 0.07006739746899375, 0.05329308265279378, 0.01973049872885308, 0.07864519968749055, 0.048464051252531434, 0.007650447519300807, 0.015504850626682803, 0.009863562055773312, 0.06698256058077659, 0.01882924799687199, 0.03016774764194364, 0.08722173020003304, 0.10795705666344975, 0.06012550292296275, 0.03670706075706309, 0.013228778505787976, 0.087545984574864, 0.027870707694561254, 0.07035969065562372, 0.07809090443075666, 0.043187930939658996, 0.03251869336611802, 0.02575097496681396, 3.1106060022307984, 21.92359974307399, 52.18731949406286, 80.89447605994441, 77.66492982064524, 86.09436219738376, 90.6264961919477, 73.0424165725708, 71.88177939384215, 45.432896075710175, 39.49354902390511, 37.442820149083296, 44.36644677192935, 48.328719216008345, 45.89241743087769, 47.07484337591356, 48.62987879783877, 43.881312339536606, 25.258124297665013, 6.065954787115897, 0.1467435596691024, 0.0484835711728421, 0.0979839402040647, 0.11725393965119317, 0.2019952150482324, 0.1946082582036334, 0.46656415467300727, 0.3285704529093158, 1.4632702234291262, 2.616025031574311, 3.411137024241109, 4.154631360884636, 3.6371562509767474, 3.9004338268310796, 3.0229469124347936, 2.4924409533700635, 3.239360009470294, 2.755131644587363, 7.364656944428721, 10.124769999134926, 10.536026589332089, 16.574681189752397, 12.414858571944698, 14.235072693517132, 16.802070794566987, 17.537330850478142, 13.509189063502898, 10.917073084462075, 9.731347445518741, 9.686618697258735, 4.97096827914638, 1.3712671086672814, 3.0208383933190377, 3.549065700461788, 2.1962225773642143, 2.0744802971040053, 2.1407484960171486, 2.4361029699925454, 1.2256790240926128, 1.6623513472657052, 1.637120946280418, 1.2890118192280493, 1.6896848741077608, 0.7548037555909927, 0.28711976423378915, 0.3633268201543439, 0.05476381058894819, 0.1829837932581863, 0.12016131993262999, 0.27337614687219747, 1.4042508097425586, 16.306540120032526, 54.95146866767637, 72.48448294977989, 65.17456562288346, 35.83762153502434, 91.17021514523415, 55.65002710588517, 38.17139256385065, 55.687870133307676, 61.5508133365262, 79.59330035794167, 76.23044060122582, 93.05955809931602, 77.7212707458004, 32.38784597766015, 10.340925935776005, 0.5137752116687837, 0.02797594710793947, 0.00712466413988882, 0.041902826107557745, 0.03385723666137746, 0.06445062466927114, 0.07431300311920143, 0.005764817854674954, 0.036295529815458485, 0.03567469216162159, 0.09331707046517441, 0.017651460591643568, 0.015499456410085963, 0.04495076054046231, 0.05767920798051262, 0.037286587119583166, 0.04893306943197404, 0.06277388036851922, 0.03272754042559574, 0.07521440515354758, 0.011325182164117936, 0.09516520395634637, 0.06682574238267637, 0.04354688526702024, 0.0576248502118453, 0.05009213364833305, 0.0511315081178421, 0.021721808307413614, 0.04757212955624827, 0.044428663959185925, 0.0432427866654771, 0.12281933093383429, 0.03121801205129633, 0.026347435702900254, 0.09486912629537045, 0.019872485464739225, 0.03793395822867751, 0.044797110115929, 0.08110856306889365, 0.07199305905810288, 0.06691642421027345, 0.02428433985539502, 0.01938582044996081, 0.034763162444916465, 0.11057788175680947, 0.015224862727336587, 0.11489228976349677, 0.06960854910674595, 0.07339179771201265, 0.17691311336332755, 0.15418011304591933, 0.19618728798964333, 0.19133326297085132, 0.19005461625995176, 0.11742404947477965, 0.11073391088434767, 0.09502926931506205, 0.16735529316769493, 0.0696212814880475, 0.09100965194163785, 0.11626018571757502, 0.17765395102962372, 0.14969673668665273, 0.12673378741789249, 0.11507602063037696, 0.22849818000630026, 0.12995423719046578, 0.14395299247435986, 0.165409475805298, 0.14262390653452567, 0.1857699631082435, 0.1427745194204392, 0.10641382616614142, 0.13851667934608075, 0.2466756691254916, 0.1436458831472743, 0.13021833834148225, 0.1504931616927347, 0.19750230855518774, 0.278200815401731, 0.1558869722629747, 0.07763184156389007, 0.16386565542028797, 0.1419709697966614, 0.1845366228371859, 0.21065446007395947, 0.20038348862961416, 0.14001203700900078, 0.4879213989742341, 11.421269255299723, 41.70403603584536, 75.66994174834221, 98.73506299911007, 101.4232829309279, 104.7102762037708, 105.029094296117, 75.9471905616022, 72.39847321664134, 50.64848738331949, 31.99662877667335, 38.60313177108765, 42.50010851890811, 64.45654438387963, 71.90061461540961, 86.21230002372496, 73.83375475483557, 56.449331621969904, 31.31636819531841, 7.656338609034016, 0.5281484920171, 0.31076427128526474, 0.2726266064470814, 0.2259624442986904, 0.4329722410728855, 0.1848494318584281, 0.23802503492803345, 0.1890946314820359, 0.9582257787546805, 1.9248696993435583, 3.10171619538338, 3.5177870046707893, 3.871929962788859, 7.37088566826236, 10.220595463629692, 12.465111978592413, 13.677326363901939, 10.173450535343541, 11.841578675854592, 11.302800928392719, 14.888172822613871, 23.22371836631529, 17.93702821577749, 18.498542962535737, 24.221747805995328, 17.059705795780307, 21.53464182730644, 35.33278503725606, 23.592754563977643, 34.747492882513235, 40.129361306467366, 36.727756377189394, 27.403843172134895, 15.391777696148043, 15.296355255188482, 15.639693064074363, 18.853644940160937, 13.062219292886796, 10.077880024909973, 5.454412169994847, 2.8500983551625283, 2.191543434896777, 1.2472862582052908, 0.7818287022171483, 0.24740772742417552, 0.28959664906705584, 0.24433358512338132, 0.378266760418492, 0.27689702568515656, 0.38106049921724106, 1.609326663517183, 30.61458556882797, 84.73319776596563, 124.52732193854548, 140.1268469902777, 110.36455323619228, 115.98278368673017, 62.33720933237384, 33.55293896890456, 50.44596756658247, 65.92993567066809, 91.1941102243239, 90.36507021996283, 114.34992451821606, 96.99892782395887, 45.12599414394748, 14.574256712390532, 1.6065412903985672, 0.3029859354419093, 0.17491800590388237, 0.13766524922703544, 0.2420040343197123, 0.15027648138423122, 0.22256378715317096, 0.169826417019771, 0.0986526353705314, 0.14443288527188763, 0.21350977702006219, 0.10550308551999832, 0.17098034461659772, 0.13517534089905603, 0.13812690913196535, 0.11701131960557354, 0.11905846741771507, 0.1555167066474115, 0.1938928546564233, 0.19542032672512918, 0.13009660697031405, 0.24906370308130021, 0.17379968607377622, 0.1377171287012677, 0.14507541853574016, 0.16925483881946535, 0.21725398578470756, 0.09814547750377849, 0.18417536641561216, 0.23488891611416496, 0.17199934880820014, 0.24555543407557473, 0.09881837083207023, 0.12251034469133425, 0.14193985130517714, 0.12517682862498108, 0.17006488486884103, 0.1370793758260627, 0.21189297909938523, 0.17963916063308719, 0.20894792261383227, 0.1138211762712848, 0.10050114424478623, 0.18291754197449456, 0.15023643030754982, 0.24143864610983481, 0.3216597576054835, 0.1595789797964596, 0.18748350261199861], [0.02564255628854998, 0.040407866810358344, 0.0344129185372543, 0.04246228479690129, 0.006368757045317081, 0.05490985759083302, 0.04096307371172213, 0.07272031398550158, 0.007495758566825141, 0.03731935270010464, 0.08701979708407195, 0.052631791726115255, 0.03501323269559972, 0.022038673764214884, 0.030166726829784534, 0.05279257442922362, 0.03247274341241967, 0.0483655744803048, 0.02712614875617287, 0.0460910824157538, 0.06302696517518451, 0.027308326379786578, 0.04512740509404291, 0.08661345638815435, 0.03306396793754351, 0.054027737989541025, 0.04071886020322, 0.01728697893990865, 0.03678981357464387, 0.07610624641059868, 0.017719682636520556, 0.055053759546529864, 0.016901071724151413, 0.045406877799260045, 0.037260264338504885, 0.031219222470216697, 0.017423842462801167, 0.1437836563995769, 1.255306524615134, 13.503663424522648, 39.55920557821951, 64.8061962281504, 81.36867492429673, 81.89243685814643, 84.87211242798837, 68.64700855747347, 40.21054652429397, 37.96842951928416, 20.983136969227946, 16.341948336170567, 22.206275155467374, 32.08831417945124, 35.1593299834959, 69.91185526694022, 65.77676711543914, 40.89763987448908, 20.275780654722645, 3.388104376292998, 0.17653563119951757, 0.1657094145494123, 0.14496812026106543, 0.17363459412609378, 0.1198935951857317, 0.020601333855020425, 0.022022346515328656, 0.09859399133992773, 0.32718119842390864, 0.8869183147626539, 1.6664738808908772, 2.058995024811837, 4.914245903491974, 4.955612199921762, 2.7740534034467514, 2.0293340615687834, 5.459225898788822, 3.8609598288612985, 3.3598785102367406, 1.1867493775583084, 8.074697140724428, 9.31124100762029, 14.055854697381298, 13.395240287626944, 11.717115986731745, 11.466720700263979, 7.74609616687221, 9.316494041873563, 12.797580899730807, 3.9483107674506406, 10.77003715499755, 13.20921011509434, 4.206076677768461, 3.513303980711968, 14.568469255201279, 27.949352687405003, 34.16614270979358, 33.18312221957792, 28.632047099451867, 19.51179708203962, 11.359884162102977, 6.609776212323097, 3.6331061586256954, 3.9754599428945974, 1.529025204720036, 0.5233358051027022, 0.209440655044971, 0.17108428742616408, 0.06934223396162834, 0.15213735491758393, 0.0828480423097649, 0.06013817018679073, 0.07368400662897095, 0.5053440156963565, 1.4199869911516867, 16.296683203789495, 66.9274728528915, 91.56043606419718, 44.64566853738601, 50.77457197250859, 35.92309782581945, 18.649465960841027, 18.792210817337036, 28.201570895410356, 53.52625193134431, 62.73571037477063, 60.93418536647674, 58.34231845794186, 44.14766873082807, 18.70490474085654, 4.307782265447802, 0.17397714268055656, 0.018444666113223762, 0.06276001417708975, 0.08460362471880452, 0.11060122445586229, 0.056840659629914074, 0.028020136974631783, 0.027689108467330376, 0.08970822943674941, 0.01678631941397344, 0.11967633265040575, 0.07405707612633705, 0.05462283891956172, 0.016170465162083987, 0.04915986210107804, 0.12854540149771398, 0.022251014184627323, 0.02648951819977693, 0.042240774304035215, 0.03099738447476299, 0.052132114707942934, 0.03207134589883349, 0.01442910421774873, 0.035532150011990345, 0.026544584599774212, 0.05904674770370607, 0.03844499633076691, 0.08868723341654386, 0.04290102335113672, 0.01784670959046531, 0.03807991330001143, 0.022085403212376183, 0.03272161090506181, 0.019855085692759004, 0.024265407907566237, 0.021956361447190566, 0.06664713664400963, 0.0504305261758066, 0.012556228959452242, 0.019493337059693954, 0.032876333852689114, 0.08445903328397582, 0.027156568192426237, 0.017512072809040546, 0.06104526042397465, 0.03193052361659225, 0.00523470176924621, 0.02431061284075822, 0.044127825061760606, 0.020276656216611306, 0.07017623558039628, 0.021224165252680262, 0.046853209665465745, 0.03851626932080235, 0.09922674932186643, 0.017765266783235055, 0.0050740617500137425, 0.017373014444244966, 0.053872831180811896, 0.02879175605372556, 0.0428293060301052, 0.0786724494349572, 0.02764163782910234, 0.08105207940623646, 0.09905141477863635, 0.042928621668608925, 0.0359650777893201, 0.02725264519423006, 0.014996682481479742, 0.012207608200579643, 0.021725711525387822, 0.040105070558286486, 0.0509012603921996, 0.11267306328180338, 0.013080398766173711, 0.024439930397596572, 0.04248712136740646, 0.07669074851418696, 0.12216251013019394, 0.02595426214318122, 0.028785460726207787, 0.037622447726466966, 0.026738521673025626, 0.10503370344879166, 0.07531799556266877, 0.6884060571751287, 12.051791241092067, 41.28071031262798, 69.41551854533535, 88.18052184197211, 92.54684155987155, 96.33298781610306, 83.81733217547017, 58.329892389235965, 39.904229025686945, 27.793330607875703, 33.174285119579686, 38.750212807809156, 42.6085542094323, 30.196082399737453, 49.7736027163844, 52.307391089777795, 49.4727804583888, 27.62044037542036, 5.854941077770726, 0.1321054733688793, 0.15452050123243563, 0.19770625648238968, 0.3167257530073966, 0.35993203941372137, 0.1358396157381996, 0.17127864393255404, 0.7380221399568743, 2.086575415826613, 3.2895989523779963, 3.436652042212025, 4.956822251119922, 8.488240472732052, 6.474877076764261, 0.6364427422804217, 0.5654017543119769, 2.5620242905232216, 1.6184345296313687, 1.039112344864876, 0.4004509813122211, 2.1662218388049834, 3.9361774056188525, 9.18550648996907, 16.994996493862523, 18.10006937673015, 18.30175765099064, 17.243280564585042, 10.732228448314052, 11.004310519464555, 5.004396678939943, 3.1816487062361936, 2.228950588933883, 0.5210097783034848, 4.693591498559521, 19.95267148940794, 37.28963590437366, 46.05938880674301, 44.46497671065792, 37.708121422798406, 26.140037851948893, 15.591005663717947, 8.486474425561967, 4.544613015267157, 1.8435779646519694, 1.6203884828475215, 0.485810183228985, 0.15364081779074285, 0.17323901696551233, 0.07259828384004294, 0.5344180943023774, 0.12439584029057335, 0.028004254056741635, 0.05266920362989749, 0.5099428721493291, 1.5792403682585687, 16.250875803732104, 61.90644679530975, 72.3951078230335, 45.02198857645835, 33.86253164660546, 32.8384635525365, 33.0397125213377, 36.25491073054653, 51.059132083769775, 69.6019801785869, 81.9554615020752, 79.7044760181058, 80.48229771275675, 56.73812004827685, 21.651587293994044, 4.07196079050341, 0.09037497873988845, 0.057192573609251174, 0.07395734680035422, 0.0663628337544299, 0.10650707438828484, 0.04657127781801167, 0.06719452178766651, 0.035338115262528585, 0.07276005862701325, 0.009979456794568369, 0.11474988934013153, 0.04572052568677933, 0.08529239138888736, 0.04479349801136602, 0.03839972053444193, 0.015481238839246575, 0.034145151655520165, 0.04760960657750407, 0.01296939262594547, 0.0571135631311805, 0.06481394186736116, 0.029991511030182726, 0.04032932364592149, 0.04475469948844083, 0.07975578969044071, 0.06437098216866294, 0.018074649476235913, 0.011279100060252654, 0.0416954959021701, 0.07103397826393766, 0.008874216958159402, 0.01960591368016697, 0.06257156803903562, 0.02731130263137241, 0.02758780483066315, 0.024781797133806734, 0.015862862665897176, 0.04727719336627953, 0.04765993089325005, 0.038403455213072805, 0.08820635236559377, 0.052640230184601206, 0.039461476262658834, 0.022715387956028985, 0.027303915628562533, 0.08164098651538934, 0.04920369382166574, 0.19357724175337823, 0.14886064364785148, 0.08541047618153595, 0.19806852414002343, 0.0903206171407815, 0.13618720515120414, 0.1567146996216428, 0.18730888053053812, 0.12464706350358264, 0.10032142767862928, 0.13555400283826938, 0.18135132117857858, 0.12542817441205825, 0.17388444604171863, 0.22450960451556792, 0.26399607439675643, 0.188425898011173, 0.173637030285693, 0.07788356273405014, 0.15043906056352202, 0.09280753772585623, 0.21270592096111468, 0.14947372849189466, 0.127464443775675, 0.08513754203675256, 0.1680550531994912, 0.21397617134836414, 0.10968663038746004, 0.12879597353598765, 0.10151996457528684, 0.1583034587242911, 0.24002490745436764, 0.23603899794961178, 0.22964020259678367, 0.2107148890894267, 0.1967747088882231, 0.2241360294001718, 0.23196595360434827, 2.8775309218514353, 27.128981121124763, 64.06590769367834, 91.19603218570833, 105.5492005809661, 106.69464249764721, 108.24786186218263, 94.56990595786803, 60.80462555731497, 56.72249724788051, 37.32866740995838, 31.58162436177654, 35.161287246211884, 47.39797215307913, 50.78234611019012, 92.5589930626654, 93.05397264419064, 63.863693821814756, 34.672050014618904, 7.3300949796553585, 0.5921266396199504, 0.3000816348339281, 0.3357826804201449, 0.5677132560841499, 0.2892943507721347, 0.13788032075089796, 0.1391159746074869, 0.3786856572954886, 1.2577823982123406, 2.259986097774198, 5.573780190560126, 11.79622038718193, 16.99090938414297, 18.961057086144727, 14.309204509181363, 11.076039883398241, 15.744597834925498, 16.897851151804772, 13.279735311385124, 16.062962893516787, 24.99915961296328, 24.307898744460076, 30.782294350285685, 26.916259219569547, 27.62460985491353, 31.861716893411455, 17.974822213572843, 23.593209558917632, 42.12156449594806, 22.05006087979963, 26.515302773444887, 30.418841646563624, 17.527558265193818, 13.439125726299903, 22.618043614972024, 36.53136330266153, 42.684204962945756, 42.49476625073341, 42.91075714172856, 31.886316037947136, 23.949299973826257, 20.22724916858058, 18.9919477124368, 14.640232939873973, 11.443137449602927, 4.087910618512861, 0.7641543183595904, 0.17260970637923287, 0.12130597020469366, 0.3822313573571944, 0.282705626901119, 0.1474322267477551, 0.12955869067340128, 0.8243364083670801, 3.13423436014883, 25.660637924748084, 101.02566442181988, 124.45737823363274, 63.7930872363429, 72.59525852818643, 51.53231505424746, 29.029530286788944, 30.65182847361411, 48.85065724772792, 83.75755525404408, 91.77075355283677, 97.41658179990708, 100.71300445064422, 72.60178535215317, 31.70739516135185, 6.105531011858295, 0.5012007057666779, 0.17257985959370292, 0.15876634436989986, 0.2632653797345777, 0.21743718805092, 0.14364147048083045, 0.1493512463545607, 0.11484856146477884, 0.23483400293175252, 0.07431112620378695, 0.34106645012094133, 0.10011112888253505, 0.16400390364710363, 0.08427086676801405, 0.1305630166203745, 0.17191169302790396, 0.13792738919296574, 0.19945315145436796, 0.13929317074437297, 0.17905900224802956, 0.23203028966822933, 0.18309245516936626, 0.16244802503816544, 0.145827287868146, 0.22976784816672727, 0.2211364121326516, 0.10902052459817742, 0.14160188395650158, 0.11805557405516026, 0.1962077731807386, 0.1356533184767731, 0.11030081839811419, 0.11805218028565569, 0.06897056640516366, 0.08772108929171678, 0.07176360806390163, 0.15598533795245234, 0.15474686489230202, 0.11697024197107363, 0.08841151837259532, 0.1839149271648738, 0.14996961720528143, 0.0815267781276376, 0.06694276231311022, 0.11084071120187161, 0.1244674924941313, 0.13699086202729133], [0.0383868464268744, 0.0474855309772876, 0.03785559892534249, 0.012899654684588315, 0.1389985333286947, 0.022863296551569816, 0.1060676157114006, 0.03200748863990509, 0.03415365523147968, 0.07148422345879578, 0.006108322103823265, 0.036503955526577855, 0.027543660929246296, 0.07493611605417344, 0.06104250250744724, 0.013545341357859153, 0.03644883550042587, 0.02227691944778687, 0.07363917516364206, 0.019905159114709785, 0.030492930898382783, 0.1023360014322304, 0.0027706994226337563, 0.05090328286431971, 0.06186076868025046, 0.03628866183721731, 0.029675511252735893, 0.042492909161674405, 0.01511061411996883, 0.019013898169261315, 0.015485675445938063, 0.07693608817193778, 0.01980934258280022, 0.04023993650691644, 0.04966623855814819, 0.026382909404234062, 0.0744315475646046, 1.1572558504919852, 24.911147509851766, 66.01017167491298, 80.92849869881907, 93.5873757639239, 81.04878994726366, 83.68936092622819, 47.46866503069478, 35.56780561324089, 30.04057218951564, 115.85536941405266, 121.0264104412448, 40.25231584425896, 50.20954278207595, 71.17336796176049, 77.4389071618357, 42.45525621598767, 12.688024197855304, 2.3468202640933375, 0.2325110558059908, 0.1398790594671042, 0.03462711672088312, 0.05652301276343004, 0.12029611310290715, 0.07409565631420383, 0.03744049035313149, 0.1583990664972413, 0.7367935187874303, 2.2156905262700977, 3.506823980039166, 2.69259141337487, 4.684882856184437, 3.9820441315251016, 5.127297284141664, 10.11932574933575, 12.731229105303365, 23.191562775642645, 40.58365021982501, 64.21909978312831, 71.23660441367858, 45.93570470809937, 19.795953189173055, 11.586645207097455, 5.023352513390203, 16.721460203970633, 11.580000712025551, 15.309416747862294, 19.048943673410726, 19.72091236422139, 12.6517677691675, 8.407013089426103, 1.9971522400456092, 2.5474428794076367, 19.969202318499168, 89.93444888822495, 138.48265217196558, 155.02040032417545, 157.21592349390832, 145.66504539981966, 136.2722553745393, 130.04084863970357, 116.4915386323006, 104.37016748612928, 76.90334673850768, 59.69545379761727, 52.64925310688635, 28.409935043704127, 15.577379349739322, 5.996189550045998, 0.5295656933899849, 0.15017333530610608, 0.1267894513664707, 0.041882007668215426, 0.03336380325978802, 0.1097444853475017, 0.0655509261113982, 0.06742094673456685, 1.8634091005209956, 22.778496011610954, 66.0049549225838, 92.71724500963765, 75.33607744401502, 61.19323045976701, 35.845709462319654, 21.036587107566096, 34.25866749978835, 47.47246580739176, 67.64930663570281, 72.52788005336639, 63.287277990771884, 43.257969271752145, 24.402206251698157, 8.152338497100338, 1.216456306076819, 0.1427647134950084, 0.0498164530783411, 0.1416691617980119, 0.04641022315369018, 0.013340411880504222, 0.03786429019284345, 0.06900875588818904, 0.020916163433162917, 0.04653097393231527, 0.01842987678584553, 0.057551347905950206, 0.021994439847466928, 0.05740183052576839, 0.05749433947306487, 0.02038133064014537, 0.04221011546530551, 0.0232996468267013, 0.047126825628501755, 0.014733609803501638, 0.044757438252770135, 0.07759600397079222, 0.05642650483716881, 0.04467145637458852, 0.03227344563891811, 0.02847406705240569, 0.034013549241447644, 0.06662547167751097, 0.07558471673438627, 0.06684235116887478, 0.08744770315505805, 0.007380141534902637, 0.05744146791497066, 0.016689740624579213, 0.03947090680500673, 0.047582107851462024, 0.059572758994275526, 0.04662858885562709, 0.024500658187354286, 0.012891593524405073, 0.019321321592395826, 0.10390060578262615, 0.050250583613711985, 0.020657133784205205, 0.06926080647615657, 0.03252036343779295, 0.029714336588738427, 0.03525626642869846, 0.051978326387583255, 0.06634911311970604, 0.07387013535105413, 0.01357634972420431, 0.01167082379857499, 0.0744532738181372, 0.11993634289190655, 0.04363366004620348, 0.022628082660958174, 0.0946504848017808, 0.04219477455462179, 0.04979823550750172, 0.039168424648983825, 0.028132659968950098, 0.05360511409479284, 0.015598818971475047, 0.006903642985684377, 0.05135695630263898, 0.03247071710985995, 0.03395483626293079, 0.07603804160269999, 0.07243404224995645, 0.024505898228756363, 0.03403178213404552, 0.021706216502934698, 0.03828116842815953, 0.03647061154967354, 0.03685157175265974, 0.026353556745415254, 0.11729568378218722, 0.04376040546283607, 0.06125128827989102, 0.061826643293663386, 0.016829415690153837, 0.08604203906631278, 0.9400023243600323, 23.751075152427923, 70.2037972788657, 86.17777532146823, 99.88989506998371, 92.71095352788126, 90.44070920636578, 68.48438709012925, 55.119381412383056, 47.28105414298273, 107.56123527403801, 91.02480503820604, 29.69438183692194, 31.657102531002415, 35.68397837300455, 54.08298923123268, 50.656147772266024, 20.392994803767053, 3.4275771485221003, 0.33501928912535794, 0.26587001739009736, 0.03843900935363866, 0.21981555397712418, 0.28447452391828265, 0.20806059361465518, 0.7315365621639837, 1.8330884436445853, 2.7266687202838162, 6.357206461891052, 5.9252377959989735, 5.205336270793792, 3.9029382601861036, 2.343215851053115, 5.7663518959476106, 9.942273882127578, 13.145028371964733, 24.395573523736772, 48.737481178775916, 72.6489479311051, 80.24024040468278, 54.09565456451909, 21.55670515952572, 2.4615304700789915, 3.6776549681540462, 7.364248527634529, 9.13591008032522, 9.019151906813345, 9.022405512871282, 3.9447975495169243, 5.4399351919851, 4.870777216649825, 3.0375182724768117, 1.5442845730050918, 26.92681431770325, 103.7365556532337, 145.52200440437565, 162.64340123822615, 165.6315726618613, 152.1215020456622, 148.03299596232753, 139.06553206905244, 126.63404264757712, 116.47814766053231, 93.43452099830874, 73.58244849789527, 61.012264067126864, 40.696673316340295, 22.64756533407396, 9.798756318707621, 1.483147569721745, 0.38410815019761363, 0.5921211237868955, 0.26225913856779376, 0.41394969568617884, 0.1424471240851187, 0.08104704620857393, 0.1080311067222107, 1.8137512812691352, 23.91098822316816, 53.432115047208725, 64.76938086171305, 48.086485401276626, 35.527424812316895, 37.99784729557653, 32.88844043208707, 55.848110721957305, 67.56787823092553, 82.21472232572495, 93.52825780068675, 86.49177674324282, 61.38536776265791, 30.10037656753294, 7.588745874743308, 0.6090780203380893, 0.09157737671968438, 0.03095357573681301, 0.205341502423248, 0.024456138902854536, 0.04617948896221576, 0.12594702278053568, 0.03539023222401738, 0.022134185776174552, 0.041388961141027754, 0.01771887632898025, 0.01936156036061866, 0.02679867681205994, 0.050570072921653914, 0.09175507081372124, 0.03010941196172949, 0.11112967190603096, 0.03469003552210427, 0.0809008000238288, 0.022340033601428715, 0.04362236791019959, 0.04985099981328653, 0.05404441189321299, 0.025808102143327558, 0.019019006060496457, 0.029681201370793487, 0.06488989948505355, 0.014742483974494522, 0.07527145572126874, 0.05019156803046504, 0.040292903826001196, 0.02702696526783609, 0.06376728956257144, 0.05779554226225423, 0.04728470102793748, 0.022470716709992098, 0.0478029748304717, 0.07653778373834587, 0.032917246778285315, 0.035821658469015555, 0.047595491407499205, 0.05842596750646349, 0.04376828084669767, 0.023891662337606954, 0.015728359651421348, 0.03806130885477028, 0.09967574579340797, 0.17375048790727893, 0.16281674315612163, 0.2311979504602571, 0.2203961107279024, 0.10433329224225976, 0.19510537265769898, 0.12571125156095914, 0.20149102194174645, 0.213743694306862, 0.09432625340958757, 0.16683121241869467, 0.169522448653175, 0.16813697864211377, 0.15672101218613887, 0.1361488241461977, 0.18455197523918845, 0.10276202292692277, 0.16456616621825004, 0.1319834355625414, 0.12337534988839781, 0.25481736047133324, 0.11871091630910674, 0.22866742415053232, 0.1459557914565648, 0.10959227133782641, 0.11522874791896152, 0.22702704604354598, 0.13675021848851635, 0.13310029982559143, 0.1677374637896015, 0.17640619298383114, 0.13396366559449704, 0.16917809213121093, 0.16725073748778913, 0.1930900711205698, 0.21843313299600156, 3.8212757389391627, 46.97392079137987, 97.55478259055846, 109.37871256182271, 118.76386965474775, 104.99569923646989, 102.39437549344956, 71.70435490146761, 54.51778396483391, 48.55498506176857, 131.33261065329276, 137.71575035587435, 54.19301171456614, 70.62548345135104, 94.5780566430861, 113.76663669463127, 65.48497807595038, 24.502230613462388, 4.112458772236302, 0.776264820127718, 0.4758418165147305, 0.07933831007610406, 0.32241435421089976, 0.3976712772442449, 0.2581132545826897, 0.32104385355787896, 1.4418195164011371, 2.2306541233293475, 5.848619197645496, 10.40261697384619, 11.322237253189089, 11.7818223468719, 14.961238734183775, 15.620891182653367, 24.131633312471454, 20.732801498905307, 31.080367026790498, 48.88962207301971, 73.10418605804443, 82.24286925408148, 54.66552395974436, 30.70882247340295, 34.48555700240597, 22.96893100584707, 37.622205826544, 26.093624445699877, 32.37926579290821, 46.432319917986476, 40.04091185908164, 29.904240408251365, 23.934696989674723, 16.68893002694653, 7.74790192804029, 26.481892024317098, 99.3754134639617, 151.91350660016462, 169.66638934227728, 176.5376130996212, 159.42751269186698, 152.47027920138453, 139.58105702554028, 125.56380825657999, 114.76650376473705, 87.6170341430172, 68.46811709865447, 65.31738696559783, 43.381123850422526, 27.157924290626283, 13.478005240040442, 2.5942053766019884, 0.47801165330794554, 0.43593222095120343, 0.2522207667390185, 0.39516132805616627, 0.43274967720912355, 0.2640042868593047, 0.2319151313314515, 2.7788641904630973, 37.124398216124504, 99.14697462512602, 125.67775311008577, 102.4913521735899, 82.22381437978437, 52.943085701234885, 32.262814544862316, 48.460844255262806, 69.76578620172316, 94.30123929054507, 110.32644348759806, 107.33777784532117, 81.52662092639555, 41.3846609669347, 11.369810700416567, 2.3824265599250793, 0.43811275233184144, 0.13996168971061707, 0.23973129659650788, 0.16533438386696, 0.13843757310701957, 0.24306836027291515, 0.1940461948153473, 0.13459234798867858, 0.1940509752039948, 0.13260700048938875, 0.20472484760947768, 0.16204550712099, 0.2178361206766098, 0.14909201752274268, 0.0899361482551021, 0.20623875992192378, 0.1313297480585114, 0.16387092610520704, 0.0842390894409149, 0.17507676996531027, 0.13438483009174948, 0.10328362155104838, 0.10893008025783686, 0.07232122048134766, 0.17409190265161378, 0.1763680264834435, 0.18455749107224328, 0.19333753284187088, 0.1662479437166645, 0.14471840624126697, 0.13587016732461993, 0.2039216197426281, 0.09112215195331844, 0.12116200696196287, 0.07727380271159834, 0.10375526358163166, 0.16328021102855284, 0.14866860072699287, 0.13094370103170797, 0.0926263043056092, 0.18724154140199387, 0.16431107426122313, 0.11340727428755454, 0.16820695311311754, 0.1575235812173736], [0.012421765206982533, 0.03384447746699856, 0.03551379071488496, 0.03997070256680731, 0.06897035956142411, 0.05882486182775709, 0.022060581963629495, 0.029745458910662322, 0.0325238261552107, 0.04490834608253452, 0.03948355108619698, 0.06157485700602974, 0.016582729632876093, 0.04231964688627951, 0.043383574473761746, 0.07712363415668089, 0.04541957953704461, 0.03628493098902606, 0.06981200673767636, 0.036189526229375796, 0.027730038629904873, 0.055296601757647536, 0.0849079837902419, 0.07012479277628084, 0.014180753834455485, 0.07980521002243604, 0.032806581547183376, 0.024784290750000267, 0.04788973428789647, 0.01894551716114004, 0.03285593293126553, 0.06120571370927557, 0.04332722870693092, 0.11091875257871806, 0.06857384011269578, 0.07210310758842577, 0.10529723769474415, 41.100014563529726, 83.47062603119882, 95.03738972448534, 97.38404181695755, 81.16621786548247, 47.84813081064532, 32.73183391940209, 24.221890972506618, 34.54023484260806, 21.803530108544138, 35.95263327321699, 66.18802762800648, 85.53045872719058, 97.20365201273273, 72.22559867366668, 19.16995663796702, 1.7411056761780095, 0.3303342937461792, 0.10129710959811365, 0.1688589399019557, 0.08760596159845592, 0.15879107368809564, 0.043238193968371044, 0.26099729982595293, 0.28964028543522286, 1.064693430258382, 1.3364671050540864, 3.471068143844605, 3.967467623372232, 5.180580721747491, 6.3563376568978835, 4.355077714689316, 16.431145975666663, 33.51278566545056, 63.60075773731355, 89.97368043468845, 128.19975868348155, 130.3258715906451, 139.32771898085073, 133.08159551312846, 142.5453333700857, 119.86481620419411, 52.34617156367148, 17.86054199741733, 11.049661943989417, 11.29597012073763, 8.898082067889552, 8.317973325329444, 5.453433048340583, 6.203950633925777, 8.076008192954525, 2.3957035378102334, 43.08720104156002, 142.52408981323242, 141.6952302378993, 120.91840405617992, 114.63282154452418, 110.52223251711939, 111.48171486393099, 118.03768988578551, 120.31054650583576, 123.93801719911637, 128.80692589667538, 133.98976541334585, 133.21167699752317, 131.10659583922356, 118.9285150651009, 109.83350353856241, 82.69056074080929, 42.3293520558265, 9.892058718589045, 0.17242799032359354, 0.32151861356631406, 6.867684798855936, 0.061381963727575165, 0.21358805588416516, 0.0837714693719341, 0.09007886277451631, 0.19525082211100286, 5.6701837143590375, 29.27763588966862, 63.706555827971435, 96.85380012758317, 66.40861388175719, 49.669361806684925, 17.720550644782282, 26.350951540854673, 48.32628734650151, 47.26167371196132, 45.364435026722575, 59.37032068929365, 50.10524695919406, 35.61104974439068, 16.499246166598414, 4.23503210467677, 0.38131321630170273, 0.09971262526608284, 0.03295658156275749, 0.015380416880361738, 0.11112310653251987, 0.012109163029479885, 0.04960403987957586, 0.02178601030590794, 0.02084979532106269, 0.03501189587217185, 0.03259157514079444, 0.013459683151825542, 0.019527619494305506, 0.05763887345129925, 0.014223336831726616, 0.02030854271123967, 0.039186642219823216, 0.05043490819873349, 0.04062265105124924, 0.03541586552596381, 0.03394123820227481, 0.07724204836713691, 0.08549102266589481, 0.15745665577630844, 0.054286587607836535, 0.01694031266285287, 0.02284682566119779, 0.06264196385839774, 0.08286892586658079, 0.00537069961278429, 0.03218654828566698, 0.015378483465962834, 0.03766402714855729, 0.020041913470073093, 0.0317558191806799, 0.03460417621799054, 0.021496695286083608, 0.03385124202336996, 0.059764384397215424, 0.029671581221684337, 0.06881705770689635, 0.03523718700894425, 0.01769210347124646, 0.04328993171633732, 0.07513182853618938, 0.03301544392841958, 0.02075152156213599, 0.03334428333947736, 0.0403785792690131, 0.022219711832041224, 0.05309607165174619, 0.001959695284547765, 0.02387126524662299, 0.05102745039508708, 0.050718640352809624, 0.07770944627061968, 0.05153342082555737, 0.08121313407055794, 0.018451342569483865, 0.10684519495454528, 0.02147791464061987, 0.04035733182043318, 0.014475857606157662, 0.016561780958586646, 0.003928685130836863, 0.12581475770040867, 0.05045682980468677, 0.0983436031627559, 0.05932308327887328, 0.008427786881164199, 0.030577788542535518, 0.04610279206967643, 0.031898240671463074, 0.02351989902015175, 0.03472835524007678, 0.04666810367076148, 0.03148798718147221, 0.03926867491475517, 0.0854620109162023, 0.0685992052838687, 0.0668966361591893, 39.64952599617743, 89.32528911098358, 104.33098300810784, 107.47047162825062, 96.84880302798365, 66.19393471748599, 60.076857228432935, 37.59164271816131, 37.578494933343705, 28.213173266380068, 59.431674403529016, 80.30177454794608, 43.453315073444, 46.220492316830544, 57.23314669824416, 25.896201749001783, 2.487199195931035, 0.3670810187055219, 0.32810271026626714, 0.20475498550841886, 0.2306088441682439, 0.45840335709433405, 0.2869518071172699, 1.533007145889344, 2.6951495341716276, 5.034911247991747, 5.416337722732175, 8.54775949831932, 8.894632343323, 3.3747313003386226, 2.9769419229799703, 7.862163512937485, 21.486998758008404, 39.74778529136412, 64.40415720785818, 99.74184128545947, 138.01502720002208, 140.6300243254631, 146.167265676683, 137.79229933215726, 149.47645956470123, 132.01831940681706, 63.88221133139826, 20.69409162767472, 6.233986673816559, 1.8870891846956748, 2.2741654659471204, 2.129680547983416, 2.1905655389831913, 2.356528375417956, 5.666351558700685, 4.884318219077203, 52.555610441392474, 151.5217402673537, 142.94411290076474, 125.72913615934311, 117.6687752815985, 115.74248360049341, 117.88286609034385, 123.21536756330921, 123.44726593263688, 126.74891318044357, 133.82372363921135, 139.36405581812707, 137.57278780783378, 134.6027377343947, 125.51694377776116, 119.81399797624158, 92.96442493315666, 50.769108110858554, 14.808850730619124, 1.9566297434991407, 1.2373176769864176, 12.316932678222658, 0.9117203193806833, 0.34957492904316995, 0.059446840952601165, 0.07607517388438986, 0.1732684194200462, 5.936433221063306, 30.083877117403095, 57.32995863883727, 65.48933582921183, 44.280691992852, 39.32192179464525, 24.57684390006527, 42.61084095124276, 68.67947009301955, 71.50193706635507, 67.83334424418788, 81.93813247065391, 70.16586011455905, 44.58801361822313, 18.418387366879372, 4.084608963420314, 0.0679099253348766, 0.08220948504223939, 0.03881361485729295, 0.03234938027397279, 0.03144949317849692, 0.01867418605533819, 0.05357433268199525, 0.007444513509155161, 0.03776502051961519, 0.06361176988350288, 0.1201833526213323, 0.045559298652674884, 0.008330224626397174, 0.08212009790323435, 0.06059078259333488, 0.030728575713451833, 0.03894674561677441, 0.0512730045574567, 0.050979642678172364, 0.010272696099784828, 0.07866426761592589, 0.05297841203789558, 0.04329619448511832, 0.07479861093264434, 0.02702844764796957, 0.026944595494217453, 0.036278664389805454, 0.019638190879636717, 0.09845332227527134, 0.038917308688283934, 0.036307672309058334, 0.03296643345346374, 0.01580728490221044, 0.03248752890935829, 0.04811591025622142, 0.024910963388280045, 0.013728290815056573, 0.01950106114119051, 0.025015630150934862, 0.021189898139827197, 0.026802059090245637, 0.0193381582897517, 0.027152649652693542, 0.042237395856289134, 0.19037078074630231, 0.08428906135621571, 0.15147393809691553, 0.1584991482236693, 0.2250816883339036, 0.087626630650653, 0.1883517713436196, 0.15649106323478684, 0.09240226189215338, 0.17662955357903437, 0.14146305350286348, 0.19342115899968534, 0.08867683760341137, 0.24832807481288913, 0.14056340580986393, 0.2499920177844263, 0.06953067626924285, 0.12144452486667903, 0.11986908803303396, 0.19035680730256344, 0.08246083849019582, 0.18155108626571395, 0.15715703878912235, 0.22138183606007408, 0.14987848338580903, 0.12032648848910486, 0.13166003920618566, 0.08997715694168884, 0.12232916489724191, 0.11426316303831917, 0.14997200739960517, 0.24344705285564547, 0.10461205631614694, 0.22399988025426867, 0.19705106744602804, 0.18745616859486028, 1.6023238844448522, 68.15238198926373, 114.1938534090596, 116.31324337374781, 125.15293213628955, 105.48393234129875, 71.56867227246686, 53.95783424377442, 41.23969408773607, 44.706775142300515, 31.176692593482237, 48.27151536941529, 77.30252635094428, 116.30029170743882, 137.75997900193738, 101.85886998330395, 33.04648253225511, 2.946467067926161, 1.0070354467438114, 0.5207539049367751, 0.4393420476586588, 0.4925208376540292, 0.393080112314032, 0.3127560079578431, 0.9252166435603173, 1.1965447616192604, 3.931857160022182, 3.605288954511766, 8.239068965758047, 16.035525914161436, 16.662006878083755, 20.711744254635228, 13.33884641047447, 26.059556699568226, 44.29181975703086, 70.39192984181066, 99.43096991508239, 142.84978774286085, 145.29668777219712, 154.5502179668796, 146.91180998279202, 156.45051217848257, 132.9668426513672, 67.5148791651572, 31.596980441001158, 27.719129170140913, 32.8039918022771, 30.003727405301987, 28.89776022203507, 15.331652664369154, 9.5988929271698, 15.97424868614443, 9.849386272891875, 53.09149249907463, 159.54810204044466, 154.0972783488612, 134.31014460902063, 125.82571275772588, 119.97833744172128, 124.23547406350414, 129.85846627143124, 132.78252263222973, 135.90640806382703, 141.4266106390184, 146.23505992274133, 144.16331106616605, 141.09849652936384, 127.76952958876088, 120.8960622356784, 95.73643453659551, 54.08597415493381, 17.849284795022783, 2.283353372927635, 1.299577336157522, 11.453878860319815, 0.5323907192195616, 0.5204553757944416, 0.2518757360596811, 0.35346346877274976, 0.5145916775349648, 10.161994272662747, 46.35180542545934, 90.69524749632805, 132.79667454381143, 90.63996561111944, 71.18679815723051, 29.030295148972545, 38.01842012713033, 71.5053887521067, 76.04979976530998, 75.46112260510846, 104.66189769006546, 92.7027165505194, 56.14114707516086, 25.219506602133475, 6.016994782032506, 0.6127354466626721, 0.22773029943627698, 0.13834858433373515, 0.14929872336647204, 0.2293894007321327, 0.1697795784040805, 0.13915817073035625, 0.13752291009070414, 0.1889062811049723, 0.17714868540004378, 0.14266279315756214, 0.16732665680108533, 0.07957213543235295, 0.2685286489225203, 0.22910256209152363, 0.1104208413932112, 0.1498186519189227, 0.11487991744351965, 0.17979269997487146, 0.1454929517762315, 0.14781165477489272, 0.19247864102644308, 0.20975596151284634, 0.2694122547343854, 0.09385752251311656, 0.14517373825994231, 0.14948142001465445, 0.1988068337161695, 0.1815403763565325, 0.11820789531714494, 0.11418256292780561, 0.1259509068463118, 0.08110842517306728, 0.13640975369320762, 0.0899195394689037, 0.15556660961479912, 0.1005009220792882, 0.10363094283327942, 0.14319652661440835, 0.09115595175253768, 0.13295800665453558, 0.13246380333458224, 0.13130967655489523, 0.1608646438727456], [0.10630944668645821, 0.03815691279728086, 0.0747751379986444, 0.11879809711488987, 0.01176187813642525, 0.0889992074019486, 0.055378580826424786, 0.04475130571893627, 0.09134833941296225, 0.06102120909359186, 0.013126461717840886, 0.06092712200517136, 0.06854809189756071, 0.05039080068649304, 0.06298965669327206, 0.06710969287181093, 0.058374321689048124, 0.10617946454834555, 0.03419433450025897, 0.026656996511343508, 0.0362100190813503, 0.06197801077618234, 0.058791456563818845, 0.0366906320015269, 0.04408582046087231, 0.04738249215147188, 0.03360109133345466, 0.07573379744445125, 0.09590619484022742, 0.06899727989108333, 0.07106774741963995, 0.035022050367608186, 0.0622855146385489, 0.10506519732335884, 0.054860556002465956, 0.5349861638199899, 31.672176199574626, 72.57286179450251, 85.8711479556176, 95.77400299810594, 91.78400331927885, 38.95095579085812, 23.854551199943792, 8.776086549605093, 60.19406941629226, 82.60360179408904, 56.094584618845296, 59.3102535124748, 47.65594251694218, 37.95841963060441, 21.161881339165475, 3.0942519249454623, 0.17300306188483394, 0.20606758523612254, 0.014698358267665872, 0.0987111951314634, 0.14438141948513447, 0.0563615903769049, 0.0835511195022733, 0.12951346084235177, 1.122621076722299, 1.688022647173174, 2.646025524985406, 7.114659288237172, 8.975291963546507, 12.837433161274081, 7.496424067404963, 18.080767393112183, 58.1148955129808, 84.6278585926179, 113.45794616207, 113.37478406967656, 122.56026114186933, 102.87305370453866, 98.43543314164685, 94.0917141206803, 100.16687716207197, 98.94280741291662, 117.86351311591365, 115.37210202986195, 106.99628060863866, 43.67865916221373, 5.270764347045652, 4.50668320540459, 9.986162262578166, 31.304242187930694, 67.28722480035597, 98.52022694003199, 71.92805551713514, 87.51877092546033, 123.63026019065612, 101.54097757031842, 115.9466508127028, 110.01393256648895, 116.65907090710057, 112.38673117852981, 111.45283052998205, 110.07454887513192, 113.75012351620583, 112.6191786796816, 113.0704002995645, 109.37970884384649, 108.36303049518217, 110.07529412546467, 112.67938706182666, 114.17406897391044, 115.01675098173081, 77.91142725175428, 25.349644960895663, 3.5108252879112, 9.17940818494366, 4.877047615666544, 0.10946984282664715, 0.15611232468678107, 0.06880116904334677, 0.0410807601386501, 0.12068063561474124, 0.8917215634738246, 12.006142697026654, 40.36395826647359, 75.8472328801309, 71.57635227326425, 71.60407558564218, 32.68776020696087, 43.72840658310921, 59.936530513148156, 33.58496904373169, 45.70046447938489, 47.88398519639046, 53.638137540509625, 34.67517614364624, 32.19476926711298, 14.965953423130898, 3.8388597244216554, 0.45562870920665804, 0.044840336627056526, 0.00525636817215972, 0.03216995099078744, 0.05777898710221053, 0.021313272769592946, 0.07231742068524323, 0.08804122977439435, 0.0281186826947716, 0.06163743489812459, 0.018814508465208837, 0.019270014768886953, 0.11544045631683643, 0.014509598033562785, 0.05071610077134064, 0.0746256436011003, 0.02711333593563928, 0.020553430377115166, 0.10509908905312901, 0.04587991027942589, 0.17196556433073937, 0.01733199618155918, 0.028053954010829333, 0.010615593224253145, 0.11590770866361358, 0.02113877134698053, 0.02256465441126737, 0.10415834840387107, 0.027079990043515162, 0.06181672245504395, 0.09994840414653863, 0.07645133837697006, 0.04174660928847809, 0.03523366683493218, 0.02105011582194317, 0.03381692894524144, 0.015012715744125027, 0.05965664945242386, 0.033668028265838666, 0.02364959962095224, 0.014511463457658408, 0.025465063292593248, 0.05305550346571592, 0.043109973832484216, 0.07068776780919683, 0.09572637868264029, 0.013945478656809899, 0.07246234153787937, 0.017905909034814087, 0.08105387971285852, 0.034402277575986046, 0.013839853326639822, 0.014253275547807497, 0.06953139639189167, 0.06374530666958421, 0.03086509832721805, 0.04068070136371159, 0.0241698116259349, 0.17570537575069936, 0.09251523687834702, 0.0550748844210419, 0.04753977000232666, 0.02227892276770886, 0.04341175501805641, 0.047415422440897075, 0.07077126373206416, 0.10493371365291458, 0.08884658736567344, 0.039862473495304585, 0.056494441514293996, 0.047210608834340695, 0.028110640686786467, 0.034133759928086115, 0.060015818284403895, 0.06045047742044253, 0.03153017564346233, 0.09540490520697448, 0.4863498462063651, 31.316160309699278, 87.98822372190415, 100.41186840303483, 108.22940318815171, 105.75682732366748, 55.64145280468849, 39.00855579683858, 18.420448572404926, 48.66009673764629, 65.4642601167002, 31.430422875189016, 29.80624979542148, 38.09192534415953, 41.81078334008494, 31.586115475623842, 5.798158885971193, 0.11778662356758311, 0.11703842379633458, 0.07096394250589995, 0.24269984133781927, 0.21517833184090354, 0.3200604418112386, 0.4560497511298426, 1.6257301381518765, 2.803300801784762, 4.828318540127047, 9.971602424498528, 6.917899472098197, 7.141721681241067, 5.260625510446487, 6.682286127921074, 22.030088170882195, 64.13969532135995, 95.2110565862348, 116.22390747070314, 120.44865315960301, 125.41387957911338, 108.11104959057225, 104.75454407353556, 100.84561978617023, 106.38336320077221, 106.76181700921829, 120.76179950468003, 128.05998110002088, 118.38099925748764, 49.26605586082705, 5.270193642185581, 4.0041363912244, 9.778316847739681, 34.03079740462765, 71.30337884349208, 110.12532003464239, 86.52174365135932, 87.91226310114708, 125.98816164078252, 109.68887006082844, 121.57661699479627, 115.11374335135184, 121.33295151495166, 118.44004661806169, 118.23117256164552, 115.74663346813573, 119.99732171335529, 116.0984230041504, 118.65433354531567, 116.16751947710591, 114.50026896692093, 116.25388222355997, 119.11864803683375, 116.77160370734431, 121.25991698234313, 84.67863759686871, 31.742270915739, 4.079827594180261, 6.3564327743745626, 2.3337722545669926, 0.6055293784987542, 0.24082802806890782, 0.17229242340451287, 0.03515955548913729, 0.15441318763600242, 0.9055480409053065, 13.150623633015542, 44.88777291390204, 51.92532477840301, 45.08354625394268, 40.50390451185165, 27.790977185772313, 42.18901749580137, 58.30855077312839, 47.3453967032894, 64.45354377069782, 67.05871535885719, 75.457561092992, 50.03853920967349, 36.11663933723204, 16.168556040333165, 3.4902512306167237, 0.3310236809474807, 0.09643311777542676, 0.0055060218625341455, 0.05280582391987405, 0.03262586523628524, 0.03264847632137037, 0.024059284290659334, 0.03202488841188531, 0.022672988819859685, 0.035186276635936195, 0.07349897341261949, 0.02752020523222464, 0.03650488249296623, 0.014424688678475158, 0.012083794985477243, 0.05364953570308224, 0.06259378841927936, 0.02618457307107747, 0.08032907626681751, 0.037669343798751795, 0.11273107145942989, 0.05601270244486871, 0.03702743489655756, 0.04542099679970453, 0.09773258675610828, 0.026272619556215022, 0.04561721873019011, 0.07810732935585323, 0.07400519665210478, 0.02305293970200564, 0.08225266941853109, 0.0677987659770635, 0.03836359182793287, 0.08276130583497786, 0.04094149684533477, 0.04104454333202974, 0.03848462222865032, 0.023816309929374727, 0.024669479068008163, 0.015722116992448368, 0.028528514836404114, 0.04636590879771017, 0.15868136989733866, 0.23055705662456252, 0.20364676271715473, 0.3139221469961828, 0.10381397656014851, 0.15643913779527913, 0.08631915605116276, 0.1565751184018389, 0.17266058993916358, 0.1283927584788011, 0.08730248352813144, 0.19505858000728393, 0.16700467004651026, 0.07958665279851806, 0.16236403115814732, 0.14369494341794523, 0.2978466192801153, 0.18728454957806295, 0.1806141147690435, 0.11140637520340183, 0.08174236293040937, 0.15106837114980146, 0.11391926616910966, 0.1018118977005924, 0.20680203372913025, 0.24132000973388074, 0.20172602707339873, 0.12220947131995233, 0.15356756446342315, 0.13700414599189836, 0.13177122920751572, 0.1741947269728107, 0.22284725500691324, 0.16157365824666717, 0.15278839175739597, 3.2322163927939633, 59.265871893975046, 106.54063455520138, 111.14999217371788, 123.1638668429467, 117.4141977679345, 61.88250072540776, 35.67842429684055, 17.986116678484027, 75.60577961706346, 107.74679476214995, 87.95573080739668, 86.57618614935106, 69.75540761024722, 61.838511343925234, 37.16022122290827, 5.852212579019609, 0.5569242253418892, 0.38077370654190745, 0.09697167758619595, 0.42562775614280857, 0.22324255637584195, 0.1978665833631831, 0.2984494385459731, 1.091269571934977, 2.9782975921707773, 6.0249086541514245, 14.184353505411456, 19.01104573280581, 23.459358676787346, 27.63406865058407, 20.728022090850338, 25.761060407084805, 67.73455542902794, 94.29617158828243, 120.86075305938722, 121.33979997327252, 132.99166340981762, 112.4802012597361, 108.75013705222838, 103.99683629312824, 110.7448584033597, 109.0057892953196, 125.64357357640421, 134.0047488674041, 120.01700416687997, 53.33138858118365, 10.709142358072343, 13.460710529358158, 15.10501027107239, 40.62054011129564, 74.16696794571416, 114.32930854059036, 107.35626789831348, 100.56736684614613, 129.46462108242898, 114.4560952340403, 130.87059467069565, 120.03211313678374, 126.67362720735612, 120.81231178775911, 120.7256587859123, 118.95993325018115, 122.7410274936307, 119.13214883496686, 120.15546383396273, 116.91709226177586, 118.30354029132475, 125.27278407927483, 126.49715977330362, 123.47301237044798, 125.51412751597744, 86.22305516273745, 33.219478668705115, 8.835008394333626, 13.80121442579454, 8.383532800982076, 0.21410465961502445, 0.3456911697022377, 0.19419092414600236, 0.08387622423470022, 0.26770960900091356, 1.9874321164623385, 20.700183068552327, 65.23843749876946, 103.1204140570856, 101.32171707768595, 94.03523983493929, 45.29198492726972, 54.42788324048443, 76.53811916228264, 55.983569775858236, 75.64447772118353, 83.9789338265696, 94.75879946062642, 67.39671384134601, 49.797278142744496, 23.438554425393384, 6.213826181427126, 1.7465534806251528, 0.2608284846909585, 0.1131544499507835, 0.13712940136751822, 0.13930585716039906, 0.08326789679666681, 0.2367114392860282, 0.16889868454346735, 0.11379194235609424, 0.22942378275817443, 0.12198754330916751, 0.09996785511893612, 0.19029958053461968, 0.11308342593932345, 0.1103027719223211, 0.14075095945548627, 0.13928645981415627, 0.12907398684370902, 0.26326485879478917, 0.14512365143145287, 0.2928069864790286, 0.18254545306967151, 0.20703069565276946, 0.10252396876533186, 0.19391743075703421, 0.11528081891517486, 0.12728627470712509, 0.2726594256537576, 0.14316798217834967, 0.2312546869319293, 0.24314682299811996, 0.15427440314763977, 0.2368762707638164, 0.19080536710398813, 0.18087015667509648, 0.15238766648596333, 0.09516911866563944, 0.13178855811636295, 0.1380642278180007, 0.06835405714809895, 0.09609413919069114, 0.1290294158482744], [0.013670192622098953, 0.07224227512075056, 0.09656297733947154, 0.2049112674449721, 0.058929689468876015, 0.05390555079605791, 0.07349621549609207, 0.23879800232187395, 0.051133844686011155, 0.11872640660693569, 0.03724461316221184, 0.07033936634299255, 0.05239054680831971, 0.05061660127173509, 0.03978249391600971, 0.020280170644963944, 0.027853777151434656, 0.030816557081115824, 0.06584045372062153, 0.05882927832464057, 0.3207407585315166, 0.3203265501126167, 0.0917953517167799, 0.14896283977695052, 0.301810817853097, 0.1882306988080663, 0.07996873148987371, 0.053776844194339174, 0.14522918770390172, 0.055772173819282365, 0.06971787751442002, 0.033342257036917636, 0.029592720130758903, 0.1285355036417323, 1.7605971593049266, 34.5446200524607, 90.59776090806531, 82.27806860400786, 77.54497589603548, 76.49021917773833, 37.41626962538689, 20.245968680227957, 32.099606683177335, 60.996429458741225, 67.89179540449574, 58.87747879951232, 60.335004098953746, 62.26617520855319, 30.026494802967196, 6.124790829996909, 0.5183995635278764, 0.09537859008677545, 0.07605525559835857, 0.07885107049538244, 0.2678957990100307, 0.21228282592229306, 0.18481409988336026, 0.3484276970548015, 1.3488837355567564, 1.0691502233666759, 3.216436697590736, 10.14512808092179, 8.51865060867802, 7.190696885508876, 12.176413766799435, 14.03924051792391, 45.070092524251635, 95.59873580932619, 109.42647918578118, 108.80260267565328, 104.732861211223, 112.6651410133608, 111.97969113626789, 112.57030594733455, 100.93953701757617, 94.0972525073636, 93.81987033351776, 111.44163608551027, 112.78310237392303, 120.12374754874938, 114.70432635276549, 133.1619413437382, 51.91092967987061, 36.40016394276773, 94.38667635763846, 167.4238447989187, 154.0579761997346, 170.27065400154362, 120.40813507572298, 58.15809649805869, 125.76836770580663, 114.87691848508774, 98.54055266226493, 87.42507334678405, 102.11685995901786, 95.77184569451117, 109.06602121168568, 107.35991570257373, 118.83575885526596, 121.12636812271612, 121.89386613907354, 111.68011619198708, 117.60145956470122, 108.66159346795853, 109.33930843107163, 103.98470832455544, 109.42781279163977, 104.11355033997567, 94.55552654881632, 39.079856641830936, 28.397079475464363, 11.111386322206068, 0.6366183909197008, 0.13288158172320935, 0.17297270948127394, 0.08246267710121409, 0.1670597670900245, 0.10769264141638434, 0.24189302817948405, 2.980052362526617, 29.866471905862134, 47.61753074584469, 66.77848554426625, 83.87471645109116, 106.14488309429538, 138.03347802931265, 29.6999555249368, 25.528148105067594, 38.85685028568391, 56.0060175003544, 53.86805511290028, 61.35290622711182, 46.43575199188725, 29.36604415216754, 10.739900604371103, 2.849556822930613, 0.19269769620751181, 0.10715163778513671, 0.12920216867519965, 0.06243107900504143, 0.05476320154904839, 0.09124603603155383, 0.09837769407538638, 0.09188649319713155, 0.06757506064229435, 0.16196794837953585, 0.13688849735884898, 0.30425089982248127, 0.13020571321249008, 0.036496968804708416, 0.010752527610278659, 0.039374479317977544, 0.16744438919328875, 0.07607472189251455, 0.03932823058998874, 0.03357285333256568, 0.04386250200050493, 0.010698184205759919, 0.12189126137884394, 0.02922905627788315, 0.08577156406376632, 0.14513816113673872, 0.17586870569615595, 0.06774001469415042, 0.04444259526808897, 0.18872361510030686, 0.0825053098942003, 0.015035321083550733, 0.09321760926996508, 0.12639981904818168, 0.08359480183571578, 0.01620016256046872, 0.03251043493829427, 0.03009373397235909, 0.03535588467193227, 0.08520161763073937, 0.09665341401893286, 0.06149812563953381, 0.05698441219846568, 0.10329354238966781, 0.029029427171354334, 0.09573747163578387, 0.05802768605550932, 0.22275590668282202, 0.07536733162499244, 0.11981920804828407, 0.010249354358341907, 0.04946065120278828, 0.053678627892006794, 0.01711766967820304, 0.07108864629821432, 0.020183620583866874, 0.07179120255093421, 0.04287958438057573, 0.04562038267331739, 0.028722607042460192, 0.11554574744114954, 0.1781424699771789, 0.09060459061255378, 0.08686434252247696, 0.20368283013662986, 0.13236494734883308, 0.0379651686507127, 0.054761159924730185, 0.07851603726345686, 0.011746687570496673, 0.05604303952667022, 0.037015399655267116, 0.09996573305538586, 0.045127225063380697, 1.8440715704233417, 35.45514337478146, 104.17221330827283, 89.77367877960206, 91.58178160267492, 86.75703094851586, 64.00727610434255, 32.820657953139275, 30.60302438274507, 32.1833610534668, 61.792509786544315, 61.56403564637708, 50.50479919679704, 60.19970586222988, 36.16950896478469, 9.043147006342489, 0.3063863852331716, 0.24419693035944817, 0.13061949262215247, 0.04922545071871531, 0.8356295249635174, 0.8730735125080232, 0.9137419947693426, 2.1445997732300914, 2.866641441660543, 3.410443255016881, 3.423745973456291, 5.302795402465328, 0.7627285368019535, 5.098030028804656, 7.883252626465214, 16.09711104823697, 48.48053847589801, 104.85055585061352, 117.54143945632444, 114.40198221514302, 110.70511694877379, 114.62625549685572, 116.53558684933571, 117.04613824044506, 103.82766446759625, 99.4295657065607, 97.95534287729572, 115.30972849938178, 116.14745263130435, 121.81126102324455, 117.76487335082024, 138.92868841848068, 57.47583550791587, 42.80502965373378, 109.97503049911992, 178.76904949065178, 166.78269417055193, 180.57288477497718, 127.54112997362692, 65.45626240391886, 134.19947101223855, 118.03240253079323, 101.77655512286772, 92.41465768506451, 108.28873295937817, 104.34503293806507, 113.64577278014153, 112.3722105641519, 122.60612149392406, 128.72788229296285, 125.23967143028014, 116.55720695372551, 117.89584129087388, 110.06117359284433, 110.99605483393516, 110.54720232563635, 111.66710176775533, 107.72269571981123, 102.76346268192415, 52.95264843971499, 24.838126705538844, 7.210666652648681, 2.4473295288701213, 0.16632378642116824, 0.23482885482090138, 0.10747748562285017, 0.08561841542682341, 0.04644642080811243, 0.2514067370324366, 3.102864959547597, 33.273787806111, 44.7286109770498, 59.242427887455115, 58.394219260061945, 96.55199727704449, 158.29925075654063, 50.00355951247677, 42.557539862971154, 59.38611215160739, 75.78814629585513, 77.70349456417945, 80.12656227234872, 55.78876526125016, 35.01446116355158, 11.529385466729442, 2.8697057933576646, 0.22833304209334238, 0.10222884105338205, 0.08423245511949064, 0.18899525455649824, 0.1015285141165218, 0.12754259240483085, 0.052101566951962254, 0.08522099965522367, 0.08081122902372191, 0.07456871560744702, 0.16575170260283256, 0.17005440478603687, 0.11884301284989042, 0.06681690938890943, 0.04491367805448752, 0.1188812176546743, 0.15958210543519066, 0.028301974976315137, 0.06266713367714997, 0.0562727126863695, 0.08502684999257328, 0.02119928271689963, 0.07294592687920218, 0.08011074886927683, 0.06962838312310558, 0.11445237143385796, 0.028079715632503072, 0.08575899256092888, 0.021703000848872528, 0.12334514304154343, 0.08723416380704412, 0.09724873328401197, 0.011816805682986254, 0.04537300522168798, 0.1581134076320356, 0.11003438833980791, 0.02611194410541606, 0.0666779333785657, 0.05834327980635628, 0.10070217337699668, 0.2424486411074477, 0.1952454594955329, 0.20556254943291988, 0.28797177657965695, 0.14224037227611389, 0.14809838616319243, 0.152379515310449, 0.3660889042000617, 0.12583846812166516, 0.3148729233972488, 0.13637506523199622, 0.16335288212905008, 0.1835863214106329, 0.13270912000969534, 0.13431150015563736, 0.1472844483871614, 0.2801376695354139, 0.2742243594219608, 0.11016449305198847, 0.20853812686137616, 0.4894924001587976, 0.44117137369128967, 0.17962868055028303, 0.20142067974853903, 0.36114730000976597, 0.28676233825183683, 0.12077350845380176, 0.20467161982049867, 0.2464542084283406, 0.17322518141759982, 0.13837853837157452, 0.12633313109437305, 0.19263835503689705, 0.14661905505964834, 4.836397642089475, 62.55948612766882, 123.50914524447535, 109.18592022311304, 103.31555981789867, 99.25461230739471, 53.713851051945845, 39.255943605976725, 46.94323216715167, 88.7757101366597, 94.08346145383774, 81.86005377000379, 91.88139577065745, 91.90788745880128, 51.25150865124118, 11.582393357830664, 1.3006677550654258, 0.5014719315353902, 0.25876917906345864, 0.1911947849176584, 0.7199522708692859, 0.6951027075129171, 0.7317884518734871, 1.7036423832178118, 3.6657044868315425, 3.7438292753311897, 9.078846458465822, 25.521364365854573, 26.05979008059348, 23.396339916413833, 26.477906896222024, 24.57219393022599, 53.914829377205145, 113.45465137112527, 123.41667929003317, 120.21047899799963, 114.84959525446739, 116.99788524258523, 119.47688594941171, 121.00771642500355, 108.01186853839506, 101.66384189359604, 100.57974584640996, 118.65268614984329, 120.97420369425129, 123.17496715053436, 123.61894023033881, 145.67919731140137, 64.39041322277438, 50.458628977498705, 128.30787489491127, 170.5629647162653, 166.25995205294703, 178.04670579971807, 123.80312688889043, 74.0109125260384, 138.62446938791584, 128.5805502245503, 107.87299310007404, 98.45986166308003, 112.13339313384026, 108.46549849356376, 118.89690076151203, 118.4200974433653, 131.07295759262578, 134.29985230968845, 133.22123189126293, 123.52909441917174, 123.88297850085844, 113.65011092155211, 113.29921568593672, 113.34898271868306, 118.73884493304838, 114.6827768510388, 110.8047059274489, 51.92597981422178, 42.62254530383695, 17.800382644899432, 2.7193307011358203, 0.2445519967905937, 0.1859466842706165, 0.25696925548536165, 0.34042502002369973, 0.2700559830953998, 0.5033912575773655, 6.005913105703169, 49.163842816506666, 70.493527074014, 91.93605007663851, 111.8037728340395, 116.84667787244244, 145.8950061182822, 42.82210373109387, 41.12614147124752, 69.25777650648548, 95.60625891531669, 98.35318888387373, 97.44912178285661, 72.82862386395855, 46.42391820107737, 20.382390676006196, 5.397437782056871, 0.7386040603441577, 0.270589180290699, 0.23864657738276068, 0.23460546358218118, 0.18556757800040707, 0.2627106401468477, 0.15348732441423402, 0.20577426549167405, 0.19863716056269987, 0.15827543522802093, 0.37325994682408153, 0.32487435446631524, 0.26058465422641847, 0.18684282328092283, 0.3027880089657922, 0.20671857611065914, 0.37798223536341424, 0.1706261208821689, 0.1760780928476203, 0.24704159868340342, 0.16009216677517663, 0.14512749719283274, 0.26270451144345347, 0.10757933701238326, 0.17893606045794103, 0.28171317531697215, 0.25153631314394936, 0.14915548024639008, 0.12828481669026998, 0.2512211598936589, 0.16641485895360672, 0.21061664597401697, 0.20240583817564672, 0.23120066241150905, 0.3015714000550009, 0.2826652693892679, 0.13134747533307922, 0.13052063663640331, 0.21045985841943374, 0.12594372860246128], [0.07246018883081214, 0.015848517669515026, 0.0439451284135782, 0.02894479935357888, 0.09441201695271077, 0.05554552670688399, 0.06668511162241621, 0.2852638702719443, 0.04148259240713331, 0.05267328304809429, 0.1306909992690048, 0.0774452148846561, 0.11809566343623785, 0.05293784002142568, 0.04413329492953997, 0.036224490482239954, 0.09215028791297829, 0.049008732105815606, 0.03230179089211649, 0.09758706069401196, 0.12485291898971605, 0.18425559114304282, 0.26681279583323386, 0.2927911437807545, 0.24050173590019827, 0.02962939467491402, 0.1788187877184922, 0.06763652387645937, 0.05835315851013988, 0.11135647989689343, 0.10900013133763306, 0.08259157139447429, 0.2486962873128153, 3.9257336047387894, 48.92024793932515, 101.60430815912063, 104.89119945033904, 103.58908237949495, 73.74743123208323, 57.9044250519045, 20.437684328325336, 27.712359159223496, 72.44273324166575, 62.986957796158336, 40.370865560347035, 39.62273620790051, 34.69585095682452, 12.363006799451767, 2.0549475065162106, 0.3170460084032628, 0.24840759473942944, 0.13412851239404372, 0.08274537120615283, 0.0837964361773864, 0.11333710829456968, 0.3738362594477592, 1.1336787285343295, 1.5916626371683615, 1.6245460726561087, 3.0117961043311707, 3.4170115090185598, 6.901284802344538, 10.12421694494063, 11.356345203615005, 23.272230240606493, 86.44942299012216, 104.81200679655998, 102.20113600454023, 96.08422325503443, 99.18601789782124, 101.24450129847374, 112.68124626528834, 108.7024724098944, 103.77399075415828, 85.31381837783321, 82.55794540528329, 81.670422861653, 85.49700090962072, 92.16667759803035, 102.91035544487738, 97.79703601714104, 119.95517192348358, 88.82211962053853, 42.06331729888916, 115.27610594226469, 95.6064550338253, 91.27582103975358, 92.67886069513138, 123.32781407140918, 71.47871663493495, 109.92786007542765, 104.22038785872921, 96.42207268745669, 93.847350458945, 100.48314571380617, 105.22067070007326, 111.35554006022792, 113.01237275523525, 119.52801796697803, 118.23158048814344, 117.52963312210576, 108.83446801093318, 109.12782992086103, 110.46610339995354, 112.40246772766115, 108.85053403915899, 106.16373400534354, 109.17973072298112, 111.33693233613046, 91.49012365648824, 58.46267246430921, 29.3844969426432, 14.307542404820843, 1.5445096189937286, 0.30769602786148753, 0.07756183644936931, 0.07291185894920942, 0.13335094847265752, 0.17735444129474703, 0.03791484433496672, 0.15387343272807139, 8.18974418024863, 30.296632359104773, 44.263139386330884, 35.88886730132565, 29.53702811271914, 28.96281469252802, 11.601830663219577, 23.89138029467675, 32.0628442687373, 45.954598765219416, 58.76750730699109, 62.454735309846946, 63.707285388823486, 53.85000044299711, 23.473651793695268, 6.96708893583667, 0.33013327227484796, 0.05455558023024952, 0.02671581291173014, 0.17256724978646926, 0.21478085478226985, 0.024475850345146273, 0.10371468390428251, 0.08510749606836228, 0.18056088698006448, 0.04911826735722923, 0.22474767399891732, 0.12563290374894298, 0.31239177911512317, 0.15257062360404, 0.2273696558850427, 0.10180799065217858, 0.03237057792683763, 0.06806677417649377, 0.009806131316919722, 0.1828016328715509, 0.042865036370893644, 0.08360664555502516, 0.0819087036014084, 0.1128005326515244, 0.05038071896940951, 0.028270915856644995, 0.014605203891293177, 0.08972705987792823, 0.20083528132207934, 0.1356377668919102, 0.04378194785526684, 0.03764650288728937, 0.03111358469111785, 0.06412654266422314, 0.038941030600859274, 0.05955178733734835, 0.06892819408207171, 0.04573450296095783, 0.04773612599819899, 0.03426262357782933, 0.09358206027818304, 0.05274464030780139, 0.08026893070388226, 0.06042703896039917, 0.05715475567886907, 0.06561961355468919, 0.23593447291322295, 0.016065359814092517, 0.03117998344673505, 0.018709027734134468, 0.014993291584804896, 0.05852067512610267, 0.03597650399071074, 0.11138915354686399, 0.09129686596532983, 0.0489053562013132, 0.10073403497376751, 0.0454508972113892, 0.15075099624453053, 0.11310511388845983, 0.1974149285665443, 0.14420351854735805, 0.22912168364611366, 0.18210625486268153, 0.08928416146626396, 0.1433691568672657, 0.12738901475865033, 0.010405497441458847, 0.032360649427338954, 0.07326640444056642, 0.0566572888243583, 0.20671180389340849, 5.073609842408088, 56.45088488055814, 113.75880764376734, 115.79808712005617, 114.06498001467799, 86.11576264904392, 67.2608115596156, 29.744782332451116, 34.919535883011356, 46.070571484104285, 52.95466453798356, 39.02280184530443, 41.13863422024635, 41.12339188975673, 18.60617672243426, 2.507461669944948, 0.28928996874920787, 0.20018046000792136, 0.14871096538920558, 0.3022483153448951, 0.8170630470398934, 1.1444911096365222, 2.3024236915573, 4.872358912421811, 4.235786670638669, 4.359868399558529, 2.322246369815642, 2.799061700221031, 3.8444302255107514, 6.31049495550894, 12.463815635250462, 30.53682850253198, 88.05393126703079, 114.7075270068261, 105.54674517723822, 103.26870318382018, 103.9599895477295, 108.15697270054972, 116.88677234034385, 115.54481967802971, 106.1530573137345, 88.87319672492244, 85.18312500369164, 84.43497996176444, 89.69690230584915, 96.96326563435217, 106.28365655099194, 105.37627112480902, 125.68885341767343, 95.48065677765878, 50.462586649002574, 128.5772946573073, 103.35310474518808, 102.32940535391532, 102.2304282649871, 129.15007052883027, 78.94748995381018, 113.09680569556453, 110.1091520247921, 101.62937210452174, 100.51829015055011, 104.96297097975209, 110.69150632427586, 117.93945020244969, 120.23761395485171, 125.07031133097988, 120.78167807671332, 121.62642325124433, 110.88789155406337, 115.05125999450685, 111.40122782799506, 113.63066381023778, 111.54705370626142, 112.61143592096145, 111.9266999152399, 116.92220703248056, 97.80106036893784, 72.64628071938792, 35.99827005017188, 13.496884588272342, 2.3247782597618722, 0.6787661583192888, 0.28857680217873666, 0.21687608993341848, 0.21513484869032137, 0.06357369531366615, 0.0841089770678551, 0.2357759999652063, 10.058366233302701, 33.94082999998523, 45.7429398259809, 48.16062996464391, 31.312985151044785, 27.870320850803008, 25.87690761012416, 42.38854062172675, 53.709716873784224, 61.352082529375636, 79.60829165674026, 78.65099014774447, 75.17753524165, 63.88649455962643, 25.69557643705799, 6.979144830857554, 0.3337356321994336, 0.11902529581059372, 0.030775098317873575, 0.27646458437365873, 0.14217798207556048, 0.043542599005083886, 0.0458841544065264, 0.054217180041896726, 0.3072918705161541, 0.03335617302406219, 0.20962123729048238, 0.11682954992377952, 0.0996882253656945, 0.19060940181295719, 0.15204789116978645, 0.10885468188432917, 0.012401102858054782, 0.04395126860829131, 0.017617178157032017, 0.01697439782982392, 0.053007335687476786, 0.040034188273092436, 0.04094102953170096, 0.07477836322880561, 0.08014786582920821, 0.025911447404312993, 0.03182384395791638, 0.12688547282690002, 0.03323323506441328, 0.05375730895227002, 0.011786519354509731, 0.03371417740239732, 0.04944644793267212, 0.10455013342922735, 0.053963976491603165, 0.09542228008109717, 0.05784599681294734, 0.011378564128291704, 0.09018713398085487, 0.20468183943340856, 0.13359366044882806, 0.21603054336963162, 0.1785413106723178, 0.1488574567220865, 0.15994245787301373, 0.1200619736506093, 0.36370349026495413, 0.12426078665040194, 0.15869925038949137, 0.2569652105411214, 0.15616078740887104, 0.21576530840848723, 0.22426215811602532, 0.213277866883624, 0.1412861484793886, 0.13054636186890065, 0.27471575886011124, 0.13259858884398015, 0.3247829754987071, 0.2183796294153698, 0.46553398091946885, 0.455211436436061, 0.4738132156912358, 0.491343452444961, 0.1580046078250293, 0.3132307679662782, 0.17230224465170216, 0.10003766105059655, 0.23066695959817982, 0.19864273768278862, 0.2016194948866483, 0.49704348368029444, 14.722943959697602, 81.57656838816982, 132.55555860457883, 130.79287682810138, 127.37293089589767, 98.26480219441076, 85.20851058344688, 31.911638859779607, 43.80755216844621, 109.2448812915433, 90.49938786414363, 58.377231474845644, 62.04459267277872, 56.37028409588722, 22.17218779748486, 3.4527555781026043, 0.6827818073572651, 0.45581030268822953, 0.2616276063265339, 0.3975317879549919, 0.6058882753695212, 0.5319804638143509, 1.9964961010602214, 5.820629654392119, 6.314019695405038, 8.36125962195858, 8.333229384114667, 11.945707798004152, 20.161916209805398, 20.001842321888095, 18.390622869614635, 33.612931620690134, 100.29160853355162, 122.34026324364447, 111.40319685782157, 108.9613566860076, 109.6362240083756, 113.16943230167513, 119.61978573952953, 117.8108984424222, 112.26480037935319, 91.90600472111856, 87.01744494899627, 87.8025544074274, 92.31744566271382, 100.5419106637278, 113.29992171256774, 109.14458628623717, 132.43920541578726, 99.56054933609502, 66.19139302161433, 126.41464879435878, 111.10571645921277, 108.20302917111306, 116.6600436549033, 135.62719806548088, 95.29831363308816, 119.03135961101903, 117.81725268210135, 103.34303209858557, 104.78189083837695, 108.27491052689092, 113.28780158873528, 119.44791532331898, 121.91899284239739, 129.04382136560255, 125.10260812697874, 126.98696967094176, 116.16994350187241, 118.83169527976744, 117.406674661944, 117.86097142004199, 115.33563183199976, 118.05448547486337, 117.54555010026502, 119.26547804186423, 99.71640863726216, 68.17861480097618, 35.96448275350755, 22.50887816952121, 4.157188746236986, 0.8034150987382859, 0.1667708140467444, 0.1821584407720835, 0.5187953551930766, 0.27283127449693223, 0.20734257004674406, 0.617817490091247, 16.741962432861328, 50.09055768289874, 63.52536193786129, 54.28477556474748, 39.995118187319854, 40.56942770558019, 19.686307253376132, 39.61873931269492, 55.70964713250437, 76.66496861365535, 97.46538392959103, 94.85271669203236, 88.71312479819022, 78.1205915635632, 39.108811578442975, 11.333667039871218, 1.410354385452886, 0.21410913356850225, 0.14276704240229823, 0.373135932510899, 0.2558902206440126, 0.11972808955057014, 0.16801825033560877, 0.2385069655194398, 0.4733843596712236, 0.20605831557223875, 0.39954436221911066, 0.3427819354880241, 0.4940656079880653, 0.4252138848025953, 0.3179403700895848, 0.25772349969033276, 0.10424353738105106, 0.19751761499191486, 0.10557158910218747, 0.37239739310837566, 0.16587352590455165, 0.12490582502176686, 0.18676966188415406, 0.2631881887153272, 0.1613841280942002, 0.10527735771310907, 0.24478295697800576, 0.20435435216753714, 0.34088464213475106, 0.19531567911467246, 0.12938350168687682, 0.09860804139245903, 0.12713763066717695, 0.2034950773081472, 0.20201433660282245, 0.2099273200597494, 0.21822745371009075, 0.16733693770102917, 0.20995348962324284], [0.045116446206286076, 0.048158734571188695, 0.0735535801598622, 0.09360430747150414, 0.022492540639735038, 0.05585956912968428, 0.01494205083637949, 0.16070816275333205, 0.042474063398737105, 0.04250220946907517, 0.025045890623943943, 0.035615324177929474, 0.11091542775712668, 0.00933566714652003, 0.03737952124567763, 0.06759994317807498, 0.03266649470934945, 0.04466079243068253, 0.07582557477778004, 0.08937239947338259, 0.07452389946387661, 0.10038135107606651, 0.20201930085257178, 0.2878879052737067, 0.13860453430923725, 0.023274107370525602, 0.2729194358952584, 0.04941797627496624, 0.034142910848341645, 0.04993911141589765, 0.048374855635507454, 0.05336312224127112, 13.786404536616418, 65.13283944899037, 108.42589824430405, 102.75808903478809, 95.31634869114046, 85.34141617436563, 62.402701147141, 37.750306514001664, 64.9954427442243, 69.31178754375827, 60.90862328006376, 42.964803480332904, 49.053169219724595, 29.995790489258308, 6.557607218142479, 0.48202273646189325, 0.051735729324601354, 0.015885960216814234, 0.3726682817984012, 0.04461223394760201, 0.03186046296069699, 0.5882459446307152, 2.6612938411774176, 1.637851365150944, 2.9759228421795756, 4.399749098285552, 4.185047870682133, 4.826496599182006, 7.616197562986805, 14.822987933312694, 36.51227704940304, 67.08416369653517, 87.12480022061257, 103.45140718644666, 90.94252940147155, 94.1991949081421, 89.96329399847215, 95.41784394171931, 98.19520365807318, 109.51425398549726, 109.33795129099201, 105.27133987795924, 86.95718165366881, 87.07927719239267, 87.40404159792008, 95.82587242126466, 97.0288476636333, 96.80462929510303, 106.83420827311855, 115.44148091346987, 100.48426751167544, 26.923258689142045, 88.84112742639358, 94.93091306378766, 96.37522389811855, 79.26777501260081, 101.6286817673714, 56.09807160592849, 113.55802151464648, 109.64199773726925, 91.78272462660267, 79.83048608226161, 89.85149860382081, 102.71129515863235, 105.0544406521705, 111.96710817275509, 113.2228236044607, 114.5827328774237, 118.12130697311895, 112.0053748161562, 112.8212356567383, 106.203397012526, 106.08950707220264, 101.48382079216742, 100.76991804184453, 107.85538950274068, 109.08467600422522, 105.12555322339459, 99.42797322427073, 71.20488812846523, 42.55103657322545, 13.845583296591236, 3.4966299851094527, 0.7582010184564899, 0.1163783930842915, 0.14393652158398784, 0.1400494067779472, 0.05147081995082479, 0.00805982144459361, 0.16354723863544005, 3.0927749074274495, 23.56980673728451, 32.78055564049752, 70.84219440337151, 73.19859750809209, 54.08286371538716, 21.81374396047285, 16.669055377283406, 32.67229234018634, 28.533060204598215, 54.36159518457229, 61.7875950567184, 73.762540201987, 61.21230102354481, 38.16937646558208, 14.451460049998376, 0.738978646695614, 0.06475325238199965, 0.13130379299963676, 0.07625481384175439, 0.06328190008418695, 0.09187417450330912, 0.07809620575919267, 0.03754745537955915, 0.07611763813803274, 0.0329254592408336, 0.043929228258709756, 0.07129924386859902, 0.13077485525319654, 0.10738950042474656, 0.1280787696821555, 0.012451353437838056, 0.035740146713872115, 0.00981896520487123, 0.04424247011962918, 0.020061285918458335, 0.03589878054035287, 0.01855301775879437, 0.05190324594056414, 0.015117329838235053, 0.015451517500614208, 0.05726791452616454, 0.03626971265241023, 0.11102321632807294, 0.07704824344405244, 0.054957937268960866, 0.08476598173259728, 0.027730329743316098, 0.08146461009258225, 0.04103628873464562, 0.059356913721609506, 0.0347919290464732, 0.04213323088122472, 0.058871600852017446, 0.01720389478930062, 0.04605906760139812, 0.05447975284750423, 0.01913190826833729, 0.08663628580829791, 0.03914152347152272, 0.029889602184055314, 0.0998667851390858, 0.057821566269042037, 0.07153817903130286, 0.03970315018969198, 0.06924184580003062, 0.034071465488523245, 0.05002977409129662, 0.019282473273755565, 0.02522071380348456, 0.023095398209989074, 0.02553087599094837, 0.026052166264684453, 0.04904885213041017, 0.03771843471293969, 0.05284732290273232, 0.11107242981632871, 0.21655349030850396, 0.19507944824234133, 0.023940766658333522, 0.12835743416461254, 0.10127468620456996, 0.02870446224997361, 0.05325022003343029, 0.04781528203297527, 0.1377118426945902, 15.13983307346221, 75.60860372358754, 121.51437682490196, 113.72249434071203, 110.56293887476768, 102.86737411252915, 83.77057752301617, 57.85824698786582, 34.6874374728049, 33.593390372491655, 52.47807302782613, 43.3724279557505, 49.84772374553066, 38.44801772025324, 10.2185401416594, 0.599361819124991, 0.08566978162214642, 0.10151084046810867, 0.3672137664210412, 0.7193382973632505, 0.416320645881276, 2.564942288783289, 5.376420742081058, 5.052812945458197, 3.084086367199498, 3.705654807629124, 2.1154894126999766, 1.9735562416814991, 5.648424365828115, 17.198463562996157, 39.132894931300996, 73.77336594366258, 97.18654263404109, 111.73718667799427, 97.5088281016196, 101.78966368398359, 98.72549241588962, 100.25689555752663, 103.44730438724642, 111.26470581177743, 114.97689970078008, 108.4039878845215, 89.58675430667016, 88.7867163073632, 88.95989679521131, 97.57878749601304, 99.96343166597428, 98.56571074455016, 108.40737681235038, 121.8483352661133, 101.75450355775895, 34.821158916719504, 97.69622325897218, 106.98469392714962, 104.6793757715533, 90.444105978935, 108.8538758985458, 66.32877795926987, 120.06755567366078, 115.55417060852052, 95.60926345086868, 82.55712955228745, 93.89525828822967, 104.65664171403455, 111.41640740056192, 115.42601108551027, 119.49448954674506, 118.3969162356469, 122.4180595336422, 116.63027286529542, 115.50663148203205, 107.3000446442635, 108.9203679177069, 105.6854166523103, 107.10897030368929, 112.96996408893217, 112.52659505413426, 109.99351270737188, 105.39958569311328, 79.11080960304507, 46.87897589898879, 15.645843340504555, 3.6415399899405823, 1.4113662343832756, 0.8106292567906842, 0.8786739829567172, 0.22275224478254396, 0.26754345985189565, 0.03786019928332779, 0.2422713990052862, 3.930545617495814, 22.439375731252856, 33.669178408961145, 50.865594494727354, 47.19020420505155, 32.24525801597103, 23.35636704198776, 29.889927679492583, 55.03558389602169, 48.60574837653868, 70.55506121727728, 78.06460365172356, 88.02751802629041, 73.22071183112361, 43.53896002615652, 15.06226133915686, 0.6185344258143056, 0.05328308903582154, 0.056994233445654956, 0.13434545317244145, 0.03056651172829011, 0.10609133379353632, 0.07450634838953134, 0.13455977393013818, 0.05977550799387598, 0.035516280500638875, 0.06760754277028384, 0.08220877258046981, 0.08805681200277421, 0.03481482358409032, 0.0987274285345789, 0.053232703433041616, 0.028611771356795105, 0.013727392576965354, 0.20291127234457002, 0.010935950126769322, 0.007208692972668477, 0.03604929766527588, 0.04260874931670485, 0.015818288797632824, 0.03117984555090868, 0.046470269125195286, 0.03999475772762972, 0.1185848412194079, 0.08310154080390932, 0.025250257984284433, 0.04947322653606535, 0.07228914437995804, 0.08862027733196175, 0.10716862195441801, 0.06532954202303964, 0.008962547853438845, 0.15030389201016198, 0.061274240274102464, 0.16975451200719804, 0.21674069155368114, 0.1160732449422921, 0.12683351674387533, 0.18867303797554588, 0.10618847374233509, 0.14378624577676097, 0.23770289495587352, 0.13573043288723116, 0.18292912522390967, 0.10336622881192355, 0.12877795514800858, 0.17443943077758436, 0.11536092872941688, 0.15483075152001075, 0.1455526759908084, 0.13347465635067032, 0.23511687323691385, 0.11952379688380227, 0.294205587237112, 0.20042249782671853, 0.1881393658057336, 0.308335374199575, 0.4497225083891423, 0.24413564332550575, 0.19062910559436969, 0.3708127862022769, 0.27659840461227203, 0.12369965022850422, 0.14088292576132283, 0.14582083740782353, 0.3391250607467467, 31.14015179295694, 104.5983160695722, 137.09744361139113, 128.25477384751844, 122.81585062703779, 111.17522085866621, 89.76724609251946, 60.61594778491605, 93.94398197051018, 93.7660240357922, 84.67629201950567, 67.80115727455386, 73.71930783794772, 51.88170017734651, 13.299602116307906, 1.6178095244592237, 0.16183143151142906, 0.32430453826823546, 0.66300913931862, 0.4545519266638064, 0.24437899881553268, 2.08413815306079, 6.934264090753372, 7.817300423499077, 10.570669943286527, 12.60410410742606, 11.934186816215517, 14.998621863703574, 16.4291004596218, 21.237388926167643, 44.01756371221235, 81.75365555670955, 103.49341577099216, 119.27598999392603, 101.10053462366905, 110.8027212081417, 104.33681949492424, 107.9586733541181, 103.7502133461737, 115.56759295925018, 119.03326588292276, 115.36275894411149, 92.50364841953402, 91.25159648156936, 90.68447666783487, 99.45215855875324, 100.56439368955552, 100.34578431037166, 114.54030067689958, 129.91263420351092, 105.67847405710529, 41.836172842210345, 110.51183823616275, 117.43218575754474, 111.44075747459166, 99.60571935099941, 112.1062267980268, 75.04882658681562, 123.60962067880939, 122.04313585835119, 100.8280711020193, 87.14471017160724, 93.67773148321336, 110.86019177590649, 114.22588348388673, 121.18577634134601, 123.46706605726673, 123.88743431337419, 128.6075988892586, 123.06081833377962, 119.63596159412016, 111.22788260059973, 114.25702710305492, 110.93787039479902, 110.37124479970625, 116.69592549723964, 120.675915287387, 115.57472382822345, 111.91314420392438, 75.47152473080543, 51.57327244358679, 20.520599311397923, 7.661102817904565, 2.622706053718444, 0.657297003894083, 0.7929364255359097, 0.3239491654019202, 0.806025619949064, 0.166241018281829, 0.4792980987939143, 6.2619159106285345, 39.817532877768244, 52.43358550533172, 100.08087527367377, 98.46092070302656, 75.02457064967003, 32.65057025417205, 29.720040021404145, 56.43831760652604, 54.655769025125814, 87.41778558300388, 95.60802398189422, 100.10349166008734, 84.80403577127765, 55.90807983952185, 24.228276591147146, 2.1730729937553406, 0.20764718192719644, 0.26914868984491597, 0.17271631517477576, 0.09860311544710591, 0.19892770706886248, 0.17917020757111812, 0.25594764659481667, 0.2698967593812174, 0.18229368593423598, 0.1852783798089912, 0.19685960675199188, 0.16319082388954778, 0.30504410725928127, 0.38484071411432763, 0.08729183490598395, 0.1905395652377798, 0.07014375345240678, 0.30815316784766417, 0.10545473005021773, 0.14722660874887822, 0.2095830095030608, 0.18356698535142407, 0.08762835434848264, 0.11189087218935452, 0.12950731681719904, 0.1926215930331138, 0.322125569706963, 0.2262692778341232, 0.1584882084881106, 0.14852264565565895, 0.1746669282475787, 0.22993004430205594, 0.23095920681953433, 0.23286681171626816, 0.12551490322596606, 0.20664242697098564, 0.2442382378203254], [0.037881879571584925, 0.022499096437147068, 0.07822431098189085, 0.06856445553562335, 0.04726776665437126, 0.09382284171278439, 0.043344492498304577, 0.12171091662058908, 0.04690999976329265, 0.053763460638301994, 0.004663536777614706, 0.018205949285578345, 0.04461379676696755, 0.03941619280545462, 0.011335981131020573, 0.037177829447412686, 0.05070242993233185, 0.024677319977913174, 0.058586991527268005, 0.024075759011470986, 0.08220992171235623, 0.0839940408965753, 0.07835928035239059, 0.08987602567480457, 0.16242400052086, 0.06851387074998311, 0.08997912578765424, 0.0679940264672041, 0.031769133788803895, 0.07766210969777838, 0.527743936306046, 46.97798436687839, 103.26551037449991, 108.89826143941572, 94.29846225246307, 84.39467368587371, 72.11424258447462, 41.94923124005718, 22.308352878016812, 24.271406973561934, 67.70319215713009, 68.03455398928735, 41.32893977626678, 33.82589670919603, 14.08087157434033, 2.071022482648973, 0.06091663809192758, 0.035296279200983625, 0.07727591711426936, 0.0033390255797008475, 0.2019820076924178, 0.06507053535671965, 0.44551089406013494, 1.443345440972236, 6.598978417534982, 5.331189930438996, 5.4082517566219455, 4.161431279874617, 7.767592226305316, 15.637939764607339, 40.35771385315926, 65.58912484876572, 83.29990879181894, 79.41333416969546, 95.26858991192233, 102.81763845874418, 95.42048761921545, 83.39190406184044, 88.54871473004742, 89.46267404863912, 100.75160057313981, 103.74411013818558, 107.01466083526613, 84.3535594017275, 77.93605973643642, 80.56951553590837, 88.81880129537275, 84.47043818812217, 96.4452225162137, 94.97587127070274, 105.66959381103517, 102.85279858496882, 114.25760761384042, 41.846068982155096, 64.22701512613605, 85.95030923043528, 71.6602360817694, 85.54740336633499, 95.10978883312595, 55.27037697453653, 109.55000246724775, 100.1108657160113, 98.79462811254687, 88.73369370737385, 82.3836431195659, 96.00371268487747, 105.42620289710261, 106.44248116400935, 111.51724369295182, 110.49638409768383, 110.64135489925262, 106.71732948672388, 105.13728111020981, 101.80153277612503, 97.57130361372425, 94.5276463416315, 102.99895394232966, 111.68500346522178, 104.10149297406598, 99.86262675254576, 102.70024976422711, 98.40097904205324, 67.37924360459851, 37.84082697283837, 11.178312743863753, 3.654874332489506, 1.062919538347952, 0.3573261147304889, 0.10794703623340016, 0.14167475423985912, 0.06457211089230354, 0.02967459769288619, 0.07545827392248378, 0.7799664956908073, 11.71911737611217, 30.516294894679902, 55.48400102123138, 77.95512245547387, 49.357600058278734, 38.38606780575168, 9.865052219360106, 24.708335476536906, 29.256362915039066, 32.31698639931218, 52.00475277439241, 68.68490649807838, 70.49857908679594, 44.40057923716884, 19.599699358786307, 3.036381275423112, 0.2958190909797146, 0.07159423368472247, 0.03239144233145541, 0.047970740425009886, 0.04100894322618842, 0.053826517335349516, 0.04027973477458281, 0.10354292699165883, 0.06130556560932629, 0.11511847722314059, 0.07625803907191561, 0.17303114666813807, 0.09427844186223323, 0.046546552330255515, 0.03016919746334034, 0.04262079221887454, 0.11190813215028857, 0.008544737863684855, 0.042632965355991356, 0.025249656605263873, 0.05754406624022992, 0.029367005730408336, 0.007843046811514445, 0.039674709175503066, 0.04575236430091243, 0.0846207850883084, 0.07166051561193121, 0.05980777944768629, 0.04661361566714702, 0.01622788345200881, 0.03336344319846361, 0.04252356416996449, 0.0466104785370971, 0.047462241904389475, 0.029421993606393377, 0.07379626149251577, 0.03477565733896148, 0.06098791491240264, 0.08110944407000657, 0.03976068339280544, 0.02240994487017874, 0.08127776124785024, 0.06872361796277185, 0.07587513300560175, 0.04593039547363597, 0.02242204139850313, 0.08817096676437125, 0.00837615734311722, 0.11110080571304407, 0.04281884509949915, 0.014228724345054119, 0.025553307045371305, 0.043261088505988164, 0.050607025172681584, 0.06262433234482043, 0.013713815583727293, 0.0923040111158644, 0.058041548416499174, 0.06308675450723499, 0.09161008101317192, 0.13046785317842038, 0.07096755844090255, 0.06327628082926236, 0.0157650581358241, 0.05675760037716358, 0.12752714041139812, 0.36941427737474447, 50.82443706450924, 116.0233723732733, 120.61260823280581, 109.97535213347405, 101.33144455571329, 84.62046884721326, 71.66451146525722, 46.50517794393724, 36.80484664055609, 62.638776840702185, 55.442839668643096, 47.08653988376741, 39.13167899654758, 21.7382049945093, 2.9054579523301896, 0.13824166910302255, 0.05189063613333049, 0.1160312403414038, 0.2791561270433088, 0.5860747901662704, 1.1620769337300332, 1.4871915333694028, 5.08026659488678, 5.233559195072421, 2.382852627385047, 2.428491120376895, 3.930286986212577, 9.3324423989942, 20.1210823751265, 46.731800725383145, 77.06875308867424, 92.892684782705, 89.75975436549034, 103.25401782989503, 106.89389105766051, 103.44524122053578, 86.58852592591317, 92.01763537622269, 95.5749584013416, 104.34988883233841, 110.73535057806201, 109.99392847861014, 88.11199019032141, 80.4090670616396, 82.08263258780204, 89.47325660336404, 88.31549844434186, 99.54300065194407, 99.28644626371323, 110.76341121427475, 105.86966606878467, 118.75840187072755, 48.16490927050191, 69.01094959628198, 101.04589600716868, 77.99846464587797, 95.73157864232218, 100.06203220736597, 60.7498182788972, 110.35105243805917, 107.99013860764043, 103.56081778003325, 91.42330215823267, 85.93239968822849, 100.33054197988203, 107.14467956173806, 111.9027969914098, 114.03391484291323, 115.14079986080047, 112.56104130898754, 111.7128130697435, 108.76364569510184, 101.75415054444345, 98.92353288588986, 98.03887367248537, 107.79420052805256, 115.58136047855501, 108.51768170633625, 104.43545926001765, 105.55856720093759, 107.3599313920544, 74.43826260105257, 42.17015874001288, 13.325738829951133, 3.875857481072026, 1.8518007234219585, 1.4691449533547125, 0.6828499585390092, 0.627953630060919, 0.20998264692964094, 0.08738562705055361, 0.06386016623207158, 1.0928097150979506, 14.043158965726054, 34.14838221765334, 45.43825011099539, 59.49820172402167, 41.0901145012148, 35.462580188628166, 23.5988813061868, 34.40126918977307, 41.14861272996472, 45.65956592559815, 66.36961767750402, 82.44356909105855, 82.7168563104445, 53.72691254461966, 20.881780962790213, 4.156266008653949, 0.1287937825245242, 0.08195925008265242, 0.031914613885624755, 0.058559829879912643, 0.018910755921575814, 0.008391269385033559, 0.0713575125161198, 0.0474014489971582, 0.130199400647994, 0.041199182009985374, 0.09407925134104106, 0.07169392470630907, 0.13224009033893386, 0.008148898317989322, 0.037209373117694934, 0.02544625200361254, 0.06312756018052179, 0.010169657273969103, 0.045801072171138185, 0.024118843796332518, 0.024990912324057955, 0.022929003912835352, 0.007619592849345458, 0.03610750885620233, 0.049271925442641785, 0.12168925165409043, 0.05692931515495143, 0.07702585835490497, 0.024591640704461647, 0.046071627612916694, 0.043617648808586026, 0.042021818714396614, 0.033390601015379356, 0.01954117733534546, 0.02995648357506481, 0.059787815196379546, 0.17416687201588385, 0.16668746368058268, 0.18151082068441377, 0.2251087312376307, 0.1465403318645493, 0.2248801306010254, 0.23326490164524127, 0.31252933786280696, 0.20391719175442574, 0.22942183689484674, 0.1276531159096668, 0.11507553033410542, 0.3262784404139365, 0.1285332666649934, 0.13862316556755575, 0.13451603030966175, 0.1044522273925043, 0.11128016221787661, 0.19785896844921574, 0.06898337539525763, 0.20156219150991211, 0.19898660390848116, 0.16892600323884718, 0.2199443486789542, 0.24952286553959696, 0.25628952099190605, 0.30866295339599736, 0.2288775007811285, 0.1498288715318326, 0.26183711605206617, 2.594133548198208, 79.53921871800577, 143.9703461431688, 135.89026358819777, 121.81746621285717, 113.58489759506719, 97.0547039278092, 60.2916266072181, 37.577247619628906, 40.510439180558734, 93.4445151975078, 96.74358152574109, 63.80273234459662, 56.831637197925204, 27.558298264780355, 3.9484549145544734, 0.39284412658983664, 0.1221345479209577, 0.24324528061814849, 0.4850088859037046, 0.4196990629838359, 0.7333965010700688, 2.5968363063950695, 9.239668538493495, 16.520458344490297, 13.64093755522082, 13.686615517062526, 12.712221299448322, 16.130752236612384, 22.161122791228756, 50.37558063384026, 80.4003829340781, 95.95982920738959, 93.76370983739054, 106.3666303696171, 112.91928706630584, 109.61621992049679, 92.37291582169073, 98.264511939018, 99.60666071984076, 109.44599689975863, 116.66009856808571, 113.55511111597862, 90.56581712538197, 82.8068119479764, 84.13439304597917, 94.42200122341033, 91.8254941509616, 105.12354496986636, 102.80937794716128, 115.82249995200866, 112.93635722129576, 122.5737697847428, 54.72670116732198, 75.93903203164378, 113.99115316329465, 85.8444679937055, 106.32656728067707, 108.6130423699656, 71.5593134972357, 117.4319504153344, 115.03499784777242, 107.15745864375945, 98.31302381330921, 89.3212490697061, 104.14159528670773, 111.08998775482179, 114.85461588828795, 116.28794408613636, 117.6058683087749, 119.00478163073142, 114.97922958866243, 113.34582913306453, 108.535340216852, 101.6257635239632, 102.29466099892895, 113.22673028515233, 120.83548515073716, 112.81143757604785, 105.74695864031392, 114.63287645770659, 111.19262833749096, 75.24746325708206, 43.94434482820573, 15.184874630743458, 8.746675637460525, 6.238522894920842, 1.7135570318468156, 0.88087075540135, 0.46262103883970174, 0.2439425432033116, 0.14099321177890226, 0.2209936133435657, 2.028928954274424, 24.52932438542766, 48.82636600925077, 76.0577464872791, 107.30279030338411, 75.59281226127379, 58.33630938683787, 22.71782478978557, 42.132515753469164, 50.79569393588651, 57.47848703015236, 79.11098218733265, 96.32047545525336, 95.3630719646331, 66.84759770670246, 35.40213646427278, 6.554541885852815, 0.4677951047497411, 0.1998395049163411, 0.10160660145864372, 0.18550480475589154, 0.2441873236168777, 0.16188950097608953, 0.14966082248476245, 0.17772498270196302, 0.19936092979004308, 0.2781945334807519, 0.2351034207329635, 0.34213367188649796, 0.42586141295971414, 0.15234295759470234, 0.145175653479753, 0.16273749902123408, 0.18528288440598598, 0.20955339254390812, 0.23040586151182654, 0.06350450225234514, 0.10246576140484503, 0.185086413496925, 0.09905045716873101, 0.0999665987347403, 0.20281039388670077, 0.32720473264494254, 0.13642475369476503, 0.1967597242084242, 0.21840380715026012, 0.096215671378999, 0.15171985232060956, 0.2787904579552912, 0.1132214749832788, 0.1223771986100943, 0.08135673725196431, 0.18344194448042303], [0.02027996763166401, 0.045463235057409734, 0.08535703388793815, 0.06249353815350802, 0.09045701143482039, 0.009024948587701207, 0.045537032307155674, 0.034535270439641136, 0.07634076124597942, 0.03304963443248022, 0.07397073801727065, 0.04445453091794926, 0.049462328935342456, 0.024099547956739704, 0.04365131837285815, 0.05046667020407416, 0.0186396814552286, 0.02142418506405046, 0.014022565296580716, 0.03591532037863809, 0.02953472727489087, 0.1048700747290446, 0.03976346046153096, 0.13192688295197103, 0.059609872123767296, 0.012393313659084661, 0.07206004578620195, 0.07000433311106698, 0.0331229911816697, 2.103034171365923, 56.0781341983426, 132.3282023399107, 113.47834248696606, 102.65434234373032, 74.96966531199794, 56.562429243518466, 37.509751473703695, 13.583608192782249, 31.340765337790216, 43.92318364112608, 35.2889290163594, 29.672273397445682, 27.444986874057403, 11.402151623079854, 0.569560447287175, 0.05936506872756347, 0.04935457100791316, 0.1621632701567104, 0.10769851731076356, 0.1052698806949681, 0.1735547217991083, 2.1954309940338135, 2.3364877604669143, 3.163115997468272, 6.744361558268148, 7.772157865185892, 9.31933383787832, 24.460486788903516, 46.11884409381498, 63.522871232801876, 80.59764677478422, 85.08946664871709, 86.65763808834939, 95.97198071018343, 104.36977524911205, 93.92076938383042, 87.56343103224232, 79.60138828523698, 81.35617825292772, 82.68605785985147, 90.40295247108706, 96.48245365388932, 89.82241815136325, 75.55045066341278, 80.85227135689028, 87.09595511036535, 93.26215636345648, 91.44717370310138, 89.96879316145375, 90.84580375302224, 107.31767962055822, 105.71721922966742, 112.21976372503467, 77.80261285843389, 38.04724170315651, 97.16671113044985, 84.95822414275139, 104.11619401747181, 67.02066836818572, 39.91472136589789, 102.83910951306744, 107.84435195307579, 98.70500195410945, 97.43191042254048, 87.01924923927554, 77.14866745856501, 87.3262688421434, 104.21114675460323, 110.99251685603973, 114.1099617558141, 113.47793456046813, 106.51520975174444, 103.39542711934736, 99.62139314220798, 97.09997592433807, 97.09009155150383, 100.44758550582394, 104.14608247818487, 106.75590207499843, 103.0706705585603, 107.2102145225771, 103.67234645351287, 88.80303336728005, 53.91524907081358, 25.819946950481786, 10.076129667220577, 3.7568790008944855, 1.4496260136365893, 0.4072015029528449, 0.11715755812943944, 0.020923081207119172, 0.07660641755548216, 0.09041784135925193, 0.18496242982725944, 0.1579865894370502, 7.3775796832576885, 23.41209803858111, 37.313174047777736, 49.339004101291785, 65.12388467788696, 51.22050231502902, 22.292053468765754, 44.01295492725988, 35.16677071971279, 35.096854471391254, 61.315753536839644, 72.00522422790527, 82.40676156936154, 68.83274062987297, 36.53665065765381, 6.681797792834621, 0.4757117347851877, 0.1820504683400354, 0.15392500576713394, 0.06244456598294839, 0.016019222168852727, 0.07916185704450454, 0.16465858706543524, 0.011360264203000453, 0.04178345045675674, 0.0533795471663677, 0.1009213817756503, 0.06604832401799579, 0.061386970112160336, 0.019200363970031182, 0.030685751398484555, 0.06808568888734426, 0.019332100449490453, 0.020115720295918085, 0.03659834905016807, 0.07619915755405542, 0.015098326069663371, 0.030324134915586443, 0.06197074060178092, 0.027723549865186218, 0.05581260027904665, 0.05533486401902572, 0.04942050819555598, 0.10390861906231412, 0.12474539854954328, 0.15406886175755533, 0.03184952130991846, 0.08482557571222706, 0.03362837555487791, 0.051863922647410826, 0.033118344858408935, 0.02618788448613017, 0.015542825605089386, 0.08416936011804689, 0.03041339181964436, 0.03269287877746167, 0.008283934721182431, 0.05721076053657359, 0.08739675064721415, 0.04869872313593665, 0.029807165377743305, 0.01173837551651823, 0.009132097475230694, 0.14462900378050345, 0.028088110040933378, 0.024409231339250843, 0.018885624407219793, 0.028109981851171584, 0.011922170543262075, 0.023647192189650192, 0.04805192659278551, 0.05712460245816939, 0.1381024556054223, 0.09807132019270813, 0.026555633502862146, 0.05077420854039731, 0.06461241477799994, 0.06762376851252011, 0.06598954209156575, 0.10942269777578693, 2.6663534535515696, 66.7471928750315, 147.37992132863693, 128.89431630411457, 115.79227416746079, 88.93500543409779, 77.06646242449361, 64.71342825120496, 32.022430127666844, 35.23909922569029, 36.61498431236514, 43.780640786693944, 41.201549037810295, 36.7750209377658, 16.954250912512503, 0.49674611899160576, 0.05937281387647795, 0.22073346520623854, 0.15916615033582335, 0.26624080394544913, 0.7563871061128955, 2.2521067915424227, 2.563434872896441, 1.7202115779922855, 3.091158155472048, 6.068702407421605, 8.974646733653161, 13.537477197185641, 28.675253968085016, 52.69583909742294, 68.96477545461347, 89.64657045179798, 91.87118191872874, 91.3320521385439, 101.36141930857013, 108.84833751186248, 100.178008848621, 89.94420774521367, 85.74278446935838, 87.28144399581417, 88.15400661960726, 93.17017678291568, 100.21782875061037, 93.52067978151383, 80.43246792208764, 81.72370433807373, 90.58094962950676, 97.9280431808964, 97.2085157517464, 94.45126210489582, 92.96047118402298, 109.32192448646792, 108.77373403118504, 116.01678279138382, 82.77410722547963, 45.59223844159035, 105.9477996826172, 91.76533283725863, 115.15872509248796, 74.75639035624843, 48.199696771560184, 112.6300750240203, 112.7478559555546, 104.60684330232682, 102.53337644761609, 90.61841610939273, 81.02822888282039, 90.93723420173892, 107.95395866517099, 115.08150931327575, 115.83352181219287, 116.88009646631058, 111.66117114405479, 106.34065643433603, 101.57056008615803, 100.86367053370323, 102.5693053583945, 103.56852131505167, 106.69671350909819, 110.9881865593695, 107.38484628738897, 111.26185817103233, 107.0436393060992, 94.39106941223146, 60.425732443409586, 29.69148712773477, 12.821427929785944, 3.279023506949025, 3.091129473140163, 1.9994007387468893, 1.5500738688053624, 0.6025665181298411, 0.24465359537111175, 0.11314935546608702, 0.19427448901678288, 0.07433950976138154, 7.358749854949213, 27.611067871893606, 33.86594803102555, 43.29386288119901, 47.618197548773985, 37.1648221631204, 37.44399686013499, 56.61434965748941, 46.62813640409901, 48.41294819308866, 74.46411102048813, 83.89989806759743, 95.40715940536992, 79.21949063577961, 45.784728757796756, 9.533141255378723, 0.36235854630508735, 0.17184550303124613, 0.15095054682704712, 0.0231727194641867, 0.021528966739893924, 0.07059556146663043, 0.08000230146271568, 0.03128002878398665, 0.03713212081141049, 0.03559185124392952, 0.035288760048006816, 0.06317394297389735, 0.12135984916840831, 0.016462185697990562, 0.07999654048152509, 0.08647127046940789, 0.016220347062053702, 0.032240791141145655, 0.06927114866313434, 0.037016705835178014, 0.07466374115357477, 0.056356193287478346, 0.023941653405105876, 0.020479039409227913, 0.08464172993215822, 0.054275180558644, 0.015925731671403254, 0.07259758670003184, 0.0474275611040573, 0.007689299189575738, 0.05507366634124229, 0.08485136989263758, 0.028446323178227872, 0.03705809373528727, 0.0527979217229351, 0.1500359757412826, 0.21923338844170495, 0.21112198821238934, 0.14464596496714702, 0.188183140069727, 0.11632200135218522, 0.13720585694236143, 0.2830244420516876, 0.1346327974310806, 0.15329843777562344, 0.13425041230455523, 0.16541698346695594, 0.17412819989746617, 0.1633411456620501, 0.158912590554645, 0.17946305234105359, 0.12241079922645323, 0.13229812916007735, 0.10125639968581739, 0.2024701895612863, 0.16305274420207547, 0.3582365336197038, 0.20410860648318646, 0.20053810049449244, 0.20749946485363668, 0.20715622682004206, 0.28837345180011564, 0.15109659382893195, 0.19331399862083698, 7.264802715470714, 95.14626687572849, 164.29043585254303, 140.13247951384514, 131.5348715935984, 101.84769907305318, 83.0458882547194, 59.348665283572295, 24.092156617872178, 45.80740005739274, 67.50675201416016, 54.34607044343026, 51.06682385167768, 48.81325744813489, 23.24926672443267, 1.4041251713229765, 0.26082018029785925, 0.4188614837344616, 0.34760427511026787, 0.26062571653915995, 0.3235774288975424, 1.4274723443292803, 6.193113125139668, 9.792659974867298, 12.521493108041826, 18.89711460759563, 16.856440728710545, 15.163025067698571, 30.814495048215313, 54.529060779079316, 69.75895343288299, 89.74446496655865, 94.64891818261917, 94.3924657760128, 109.56839053861557, 115.17574033429547, 103.67899879332512, 95.01985672981509, 90.87225621746433, 93.30207824707033, 92.69741350604643, 100.65725972575527, 107.54470640613188, 97.30265263588198, 83.70923165352114, 86.19453953158471, 95.4383893166819, 100.0922893708752, 99.61024576617827, 96.58935393056562, 93.87946682591593, 115.94627426516627, 115.91568762256254, 124.63987827301027, 84.80124304371496, 53.893985902109456, 119.07012047306185, 102.03427837740992, 123.94588547368204, 83.91787036772698, 55.3352725890375, 117.63181870983495, 119.29233058806389, 112.44067945787984, 108.17074021985455, 95.89753412431287, 86.16378030469342, 95.88209567531463, 113.61903006030668, 120.87936078348469, 121.87587030472295, 123.55150684233635, 116.08359644489904, 111.34745213293262, 105.02814508253529, 103.27260201977145, 108.80149656726469, 108.53495582457512, 111.34604007967057, 116.52146631671538, 113.35001037966822, 114.09118144742905, 109.84715338676207, 94.81952559563422, 58.837101920958496, 30.639651475414155, 16.345790297754352, 9.570676376742702, 8.184448980516004, 3.9852415986599463, 1.6609554737806322, 0.5271222406337338, 0.38999614876604854, 0.28900314543035727, 0.27143294953050157, 0.48841665949552293, 14.915262672208971, 41.78655093716037, 53.12840200239613, 69.09972852276218, 86.41156427321896, 72.80206941789197, 37.870181991207986, 58.56286156562067, 55.74723128349551, 58.5079130818767, 87.63418274541056, 95.27761136331867, 107.2116187310988, 90.7354361011136, 61.62393416127851, 16.052128326508306, 0.7655922347499479, 0.266230293219128, 0.29162371771470197, 0.20153629773807144, 0.09505312529302413, 0.1681598233840158, 0.2314344111589655, 0.22908806770799622, 0.17965472753970854, 0.19444998443847705, 0.22477500801605566, 0.21861742310706647, 0.2975181514217008, 0.1319576030777347, 0.2284179706006281, 0.2095110278816954, 0.15432902521664096, 0.21261153892884332, 0.1193724255708437, 0.14445415187266566, 0.233908262284052, 0.1972984525585367, 0.16357253485869977, 0.18908690931575914, 0.23541722566850726, 0.14769983658146474, 0.18965784400220842, 0.25602578756309324, 0.22271133568738738, 0.27127758689945747, 0.1404190748449295, 0.140773635658045, 0.12195018120110036, 0.1583354199124921, 0.12121955548683483], [0.008588635659356032, 0.03605381375358951, 0.047754270790685574, 0.04305263215135183, 0.012864618610981251, 0.04444962795523386, 0.10882226870425286, 0.07948657107209006, 0.07848398414470496, 0.07774971185191985, 0.02968921273526165, 0.012893916686035454, 0.14293138358381488, 0.010845941498935705, 0.047744146938766205, 0.04827655889394303, 0.07613505897743088, 0.038214836705235705, 0.024768438475627094, 0.11443956244376399, 0.10371485244362585, 0.008475402118487945, 0.14365256343397403, 0.02777513439556764, 0.07492407315200375, 0.033137830304763014, 0.042069316165702, 0.0929124994323619, 3.6699173575447457, 91.8099537203389, 126.62601747820456, 111.70394851315407, 97.30220548568234, 81.09577994192801, 49.88229159385928, 18.665049537535637, 18.607965323232836, 43.48762012297108, 79.34018981072211, 59.8298930352734, 49.199316732345096, 36.622550564427534, 14.984902393433357, 0.3691611006375282, 0.08549202624107562, 0.17394001805974593, 0.05597791056178751, 0.1388038091001011, 0.04720965888531459, 0.6144843947502875, 2.550423880738597, 2.8357392934060868, 2.9878201263566173, 10.477970607819097, 22.56236949274617, 36.23449871616979, 58.10603880113172, 75.0884033018543, 87.0342170038531, 94.47653785828622, 91.7362916085028, 92.92655052677279, 92.3376537138416, 87.2591963121968, 91.2916595705094, 93.09191765323763, 83.75846524392405, 83.48086341734856, 76.62983202165174, 77.49899002813524, 76.19140517327094, 80.75971911030432, 75.68553709214734, 73.27251849635955, 75.79992909585276, 87.75012016296388, 85.02758733687863, 89.73317638520273, 85.96773239874071, 91.39487281922372, 84.65783334547474, 95.38926555264382, 92.46095734257852, 113.9305760783534, 54.028193719925426, 64.53213237947034, 74.2036734857867, 93.3762659565095, 41.80097349228398, 68.04004530752859, 105.79075582565801, 94.99255703341578, 105.71969032287599, 102.05967964664583, 103.02387668240456, 84.74402350764122, 77.8118618073002, 83.81428057147612, 101.61024662756152, 105.53712752557571, 103.75354736082016, 99.6914545182259, 98.81443608191707, 94.3929050814721, 89.68100886191093, 92.4522183018346, 99.89686119940974, 103.01450221769272, 101.47497976979902, 105.16746767105596, 99.66941864259782, 96.84656727698543, 96.13824213704756, 76.89455278458135, 43.434934846816525, 17.290203878956458, 4.888741181742761, 1.5691877012291264, 1.1442025702807213, 1.0363855621507092, 0.3229782868537211, 0.05316153769531558, 0.06120580180938687, 0.10583397421625354, 0.03024390444249636, 0.04241861012433806, 3.137835095967016, 25.278042093400035, 45.160569837016446, 50.36639444289669, 62.10733098368492, 44.07617961206744, 20.453414993901408, 18.99972185011833, 26.721737115613877, 41.78020454222157, 66.5879838697372, 72.70788546531432, 78.68222790379679, 78.24988072918308, 58.39064990320514, 16.87445813609708, 1.634656104349321, 0.09735802338728983, 0.0247544439644703, 0.05098207500733195, 0.06350509214004682, 0.027011093841264808, 0.05647796296304273, 0.0289071288951222, 0.04216722986330429, 0.06955013490251957, 0.11809460623490235, 0.01712058655797474, 0.07669730622681879, 0.050163023594406345, 0.017967833836953488, 0.02659925646449049, 0.06075880482732769, 0.06537885510272558, 0.020762486195552255, 0.04949304523066648, 0.06959718036194963, 0.08458072635074777, 0.043650299475918856, 0.0652399403794158, 0.006962473271414638, 0.0247604577546759, 0.060077978658580014, 0.07041775245940493, 0.029673551982869546, 0.037577961000704, 0.026209767787687244, 0.06405182227852844, 0.04373571444903651, 0.06745813264241142, 0.01810097034209438, 0.05418065296966703, 0.07724267655923482, 0.06613102320942187, 0.073317694027097, 0.025820846015947963, 0.04383787993461855, 0.06830989984014342, 0.034538422891449545, 0.0764510932288343, 0.12326386111277728, 0.08810103825864293, 0.07099549766750106, 0.015328213733981456, 0.019123586638259794, 0.049915638481897694, 0.01624298879065581, 0.02100253984662554, 0.06256401824254183, 0.07938813643469926, 0.1080167885389059, 0.06821647541777742, 0.22406931846372544, 0.042398224524672956, 0.03659968587359594, 0.03224180620764533, 0.07243703765374038, 0.029802758456958883, 3.628339743421924, 104.92065645033314, 143.43098886551397, 126.27309829958024, 110.42489497892319, 97.32365300578456, 71.75885231264176, 45.92727161222889, 29.405834636380597, 29.42201049097123, 48.22390171789354, 50.53051033327657, 47.965076277332926, 41.147639982161984, 20.536847729836744, 0.5547188727125045, 0.12813401994325463, 0.14625364644152505, 0.05176570634507845, 0.16508586494432342, 0.9022626268767542, 2.7980850300481244, 2.971928643603479, 2.9960693611252696, 2.657774984836579, 14.141918363109713, 27.9660717902645, 42.74308366160239, 62.33893125287948, 80.04256863747874, 90.46946017972886, 98.74955223452662, 95.4830337339832, 97.3466145607733, 93.88248705094861, 96.43941740835868, 96.82224073717671, 98.97541799852925, 89.53742657938312, 88.65394407703032, 80.93214650307932, 81.17931073711765, 80.85424823145713, 84.17626042519846, 78.72051808141893, 76.60220284615794, 79.95229921033307, 91.5449191677955, 89.42399947874009, 92.84771873104958, 89.37726051576676, 94.9049783522083, 88.88146508124568, 99.99253565265288, 97.2279550183204, 117.15140681112968, 59.03676625221007, 71.08269060811689, 85.0852147994503, 102.32992310677807, 50.79619992163874, 73.66186080440399, 110.40250608997961, 96.98142620825, 109.98711139925065, 105.13637112032984, 109.18512790433823, 87.370191543333, 81.13192850543608, 88.5438274568127, 104.37225418706095, 108.84018682664441, 106.21866287723665, 103.53376911532496, 102.50439013204267, 97.25576462284212, 93.87829795960458, 94.58568173070108, 105.07453887693345, 107.66731969771847, 105.08268171741118, 106.33663208253923, 101.18128838077669, 97.79392949996456, 93.0291832647016, 78.95702131332891, 46.18286109739735, 19.72496025023922, 6.076797689160993, 3.151069663224682, 1.7822426365267847, 3.741163044206558, 1.382814321306444, 0.4571341945519371, 0.21151261644497996, 0.12343672119201192, 0.06331708267210953, 0.023270096900241993, 3.6161651967033266, 27.339553563825547, 39.87958477389428, 44.37148701760077, 50.42278635886408, 37.28919267654419, 23.50911590360826, 28.219813839081798, 40.28295740004509, 55.16961128480973, 79.9122675003544, 81.76185331036969, 89.89874747491653, 88.24035367658063, 70.66345983935942, 21.45598653824099, 1.8173520170873212, 0.18741529014322067, 0.055458924297483704, 0.05784793884583539, 0.04623661613872936, 0.05200973982291837, 0.014440892395683596, 0.040663667398715214, 0.04116277368138394, 0.05809879050620141, 0.09600053856810255, 0.05795041842746639, 0.02137676996719693, 0.03164904950667293, 0.04829349709794887, 0.040794308372442765, 0.07246821743225859, 0.009812180538691822, 0.03063583502455825, 0.031163874532907244, 0.032028885475630244, 0.02193443601079766, 0.015181639089038777, 0.028940271773946383, 0.056750548537820585, 0.03920174181281079, 0.05796147307621376, 0.08837921244482841, 0.08828289987098786, 0.017511438871283206, 0.05244128481154481, 0.06363780155116994, 0.010302540970094984, 0.05059859054463525, 0.08697526439303353, 0.1821319494516619, 0.22065912403406637, 0.19573860561415074, 0.2539734073704289, 0.09184661832067276, 0.20303124171351233, 0.376668609077892, 0.15903694194651422, 0.23838711872456536, 0.26393399063137274, 0.1456801070561332, 0.32032857258473674, 0.10845540451907343, 0.10340101686456513, 0.1630540159080298, 0.17226819970434712, 0.2122266716774433, 0.18129043251035676, 0.25567957710835243, 0.29049928450296003, 0.18373970753483235, 0.32464777630183006, 0.13349595359496533, 0.2690264528557178, 0.164767969099264, 0.22058107499634066, 0.1725919944264235, 7.823434520152308, 133.41644040999876, 157.96482947564894, 137.1568439852807, 127.37024014995946, 111.30833825757428, 69.2223104353874, 33.591354662372225, 27.454414290766564, 63.81651163101197, 108.44811454896005, 84.23722190241661, 77.85984808398833, 59.76938263062508, 30.368650997838667, 1.2896742094908993, 0.33429922776356824, 0.4039177436742091, 0.16498054317649335, 0.2512745868654982, 0.43245730741370114, 2.5512944017687156, 8.693358859708233, 11.330659562541593, 9.502599720031986, 19.695985701776323, 34.09355140501453, 43.76125643330236, 63.15487446323518, 80.3630341252973, 93.24249744415285, 101.33652794745662, 100.07477991042599, 99.29702881843814, 96.45673075029927, 98.82872135408464, 101.07982450915922, 102.9264057836225, 95.12215214390909, 92.62757178275817, 85.01502790758687, 86.13682577686926, 85.00648498535158, 90.3633051533853, 82.6698741605205, 79.45547611482682, 83.06702982994818, 95.95528710273005, 93.32866407209828, 97.63213957509687, 94.69742221217003, 99.1325403028919, 93.43460729045253, 103.65161280478202, 100.83537455528014, 127.20786971430626, 63.11886318268315, 79.1557207415181, 95.9723258787586, 115.13496337398406, 59.367316153741655, 75.51773809617566, 116.75893445168774, 102.94455851277998, 116.67320712920159, 110.28865537335797, 114.41379639410205, 89.67700804433515, 84.68186178515035, 91.11654143179618, 107.52832658829229, 113.4931690462174, 111.8239495062059, 109.44667154742827, 108.8395514026765, 104.35203829119283, 100.42078002806633, 101.53049699721798, 111.12315531699889, 113.4798094534105, 109.46934284702425, 110.60373936930011, 101.96180866610621, 99.85020068383987, 95.38537456143288, 80.28621058310233, 47.20582700544789, 22.32460718001089, 9.668227684113289, 7.929098269631786, 5.154917144006299, 5.244786979690676, 1.2373532234661042, 0.29411889672760044, 0.28137545311643236, 0.2852022768028321, 0.1296560910920943, 0.31501428194103703, 6.361984399057205, 42.56178778986777, 69.24708412539574, 73.57506659723097, 83.57979343783471, 59.682882601215, 30.6677552576988, 27.827325790159165, 40.29426951562205, 60.478147076022246, 93.3199328760947, 93.4205573604953, 101.56230741931547, 97.31474922549341, 88.30431184461041, 30.911956141071936, 3.848065282067945, 0.4274738748227397, 0.11062509575558287, 0.19062637832135926, 0.1294465660448036, 0.17090655502773103, 0.2116317277954471, 0.1444542131596996, 0.16855543118811425, 0.19841058239821466, 0.30455135950638407, 0.1310655702987025, 0.3453823749817187, 0.10893872172962274, 0.11517123003760654, 0.1822701363914436, 0.23050791974509918, 0.1386745547455165, 0.12235325070158129, 0.1459522827738716, 0.24568197647890738, 0.14754672624891804, 0.16528259632327866, 0.23260796592841226, 0.15183634365037565, 0.22015424144844856, 0.1699561923141441, 0.14963931073584866, 0.171708312005766, 0.10171406061178255, 0.1385149326656134, 0.1910710617178871, 0.15779892853911848, 0.16726420531349798], [0.025490646798824592, 0.023080651017446673, 0.029624516610056165, 0.018938396373883854, 0.011989183126828604, 0.047565242425808986, 0.056047138097065116, 0.011755083894146787, 0.02739723854427857, 0.10138840429605016, 0.06367327525250374, 0.04352703975934175, 0.01362776284241268, 0.05583605023040887, 0.052958857643628315, 0.046817398885445255, 0.02890134493129388, 0.13382993728643464, 0.03008441451276022, 0.02351460918303459, 0.06042224324999317, 0.09037247363237605, 0.13970805332064629, 0.05194051994852001, 0.010665505767739829, 0.047705110928584496, 0.10459174732527426, 1.6899833419630605, 88.31931883288969, 128.9986905743999, 114.14384318936257, 105.43869172373127, 87.76632739651589, 46.944255905766646, 31.509178184693862, 29.158589993753743, 48.78594990699522, 87.19100198438092, 72.78264584079866, 39.80672282557334, 33.20602493901407, 16.234672492550267, 0.32161474227905273, 0.06322724354122916, 0.03997033867504328, 0.06316117994907884, 0.05663540169236161, 0.31912734671946497, 0.9994382447292729, 3.538407885259198, 3.7610641698683467, 8.777804547740567, 20.845340182704312, 36.56564874033774, 54.01569312618625, 79.57146844556256, 87.3042094322943, 96.1550534156061, 92.49283836733912, 93.55173710853823, 95.6140487424789, 98.71097180151172, 98.88335212584465, 103.371335921749, 98.86373243024273, 94.96514751065163, 93.91202249834615, 86.66516903908023, 80.71638476464057, 70.70619798475697, 73.66003297990369, 74.56232716960292, 73.89781490448983, 77.0276858729701, 87.99350323215609, 89.52270200175624, 92.37496329892068, 92.73158519498764, 90.95162145553097, 82.52426009024344, 80.37503657802459, 76.11806469578897, 85.33627002469956, 91.2943503164476, 100.34656878440612, 44.03337870874713, 83.4460170807377, 72.7527024669032, 46.19535776876634, 108.22978758042859, 101.67502849332749, 101.1720629661314, 93.78961317000851, 102.15770752199235, 98.01484523280975, 86.73409292774816, 75.45689429006269, 73.36811450219923, 81.52315355116322, 95.75731723539292, 97.20487579222649, 101.3670047636955, 91.70364179918843, 87.52773746367424, 84.25453524435721, 88.6459110629174, 92.88812698856478, 99.6435937573833, 96.9114746585969, 95.29110431671144, 92.26573313436201, 92.13062317140641, 91.64237437709686, 91.76221847534181, 64.06904558981618, 35.79562471758935, 10.484930853689871, 3.4847491258575074, 1.3048099005414595, 2.32549580835527, 1.2823164559179738, 0.8032222897295029, 0.024576347674273198, 0.0810804553029518, 0.1030834274546754, 0.05127412687626578, 0.06328763808273981, 2.367220756507689, 23.17844048623116, 35.00094859830795, 41.21837208347936, 59.35489008503576, 97.09142515736242, 55.2999359561551, 15.087555723805583, 25.90279329207636, 43.38605426972912, 45.750984607204316, 69.23177903698337, 84.52557886800459, 79.15486566482052, 71.67309361119425, 34.619913870288485, 8.391541300281402, 0.10447258234865243, 0.04010487903630541, 0.02355136608164157, 0.02547935657804051, 0.026479884644129106, 0.014483337497128355, 0.00598024656703215, 0.07832403264699445, 0.03483553860156286, 0.02690418435621166, 0.028440914597482454, 0.024231311249276324, 0.05175505006205171, 0.04286517809715964, 0.05079026574329023, 0.09652174648738678, 0.08408054754498505, 0.008483162589160907, 0.07389965271877666, 0.029563097425946788, 0.08435086166906743, 0.03240599800201674, 0.047214163482309356, 0.0963299104102677, 0.044210934110226176, 0.05980967168485927, 0.06598922799551679, 0.015394963932433918, 0.06838190444414655, 0.0439845742807994, 0.07909613436148052, 0.05300529406315858, 0.030996740960906592, 0.04829292636244528, 0.028098461804010218, 0.011381345985066748, 0.04757786755480113, 0.0905992586406008, 0.025037149560727903, 0.0449202970541533, 0.043960622541846774, 0.06511139082572152, 0.05473659148499851, 0.06923780085579043, 0.031063059277291742, 0.03849197284228379, 0.056406019646073544, 0.017657051118271008, 0.04617040698987342, 0.08706522609798178, 0.008899718109938887, 0.033182041238873236, 0.12670862909045913, 0.15855977642199687, 0.13761571398185146, 0.025506439701383634, 0.011828327645367433, 0.06000973554628511, 0.12390196638842746, 2.9326105598480474, 108.63800433374222, 146.723630351405, 127.29754294118575, 123.74553080528014, 103.23439028955276, 75.01758098602295, 40.76888807358281, 30.520731095344793, 38.03099524590277, 52.61259463525588, 60.10304689407349, 43.53655953561106, 43.56053698447443, 22.38790442866664, 0.5378827116181774, 0.1883122718502437, 0.02211331945633696, 0.0710269149332758, 0.10477182395275562, 0.7541338883100018, 2.770743658465724, 3.275666203229658, 1.9704630850784242, 10.268821004898319, 25.78638715128745, 45.28937262873496, 60.60576923431889, 84.19395031467562, 92.56523747597971, 98.61947075013192, 98.00580809193274, 98.39187914325346, 101.1567892566804, 104.32350697055941, 101.88353384694746, 105.5386023367605, 103.79950184975903, 99.88403504894626, 97.94917691138484, 94.73637919272147, 84.7520172980524, 75.02875189627372, 76.52848582113944, 77.37894981138169, 75.38387544693487, 83.63637754994055, 92.83777944503292, 95.3829897603681, 96.39413756708946, 96.43067052287441, 95.00452026244133, 86.66247829314202, 82.55232857119653, 79.27445873137444, 89.5473737101401, 96.62263131910755, 103.89754541458623, 53.346124925921046, 91.26804690207206, 78.89362796660393, 54.26967443958406, 109.14356646999236, 103.18328965094783, 106.58451018794891, 98.03719489805161, 106.0684988575597, 101.93968649833434, 90.384627157642, 79.53721046447754, 76.56841554949361, 83.55224270974436, 97.44077497912993, 101.4265698771323, 103.46471186607116, 94.39872587880781, 91.85029137519099, 87.31587456118676, 91.55590180427798, 98.76511619937037, 101.69082780038158, 101.52240122518232, 97.23485054508333, 91.12808888958347, 93.21576256905833, 94.85758043104603, 91.64122904500654, 67.7698253816174, 37.369373767606675, 13.33325997475655, 2.8880401772837487, 1.106541810497161, 2.3349362179156277, 2.2362564936760934, 1.5843065996323864, 0.5166213815250705, 0.30845957237385935, 0.18453878320513234, 0.05275188366912546, 0.1508036418066871, 2.570798142302421, 26.52557546092618, 36.64946586854997, 32.478929296616585, 33.7698656512845, 59.96838408131754, 54.32283432252946, 18.908138428964925, 39.65400534291422, 61.792992238075506, 57.76396105366369, 82.29393851372504, 95.22675391166442, 91.05941603260656, 85.67655917136901, 41.711308110144834, 9.518868730914209, 0.13807783353953593, 0.051649908324883836, 0.061859615717924414, 0.053078849995208364, 0.01956273504953471, 0.020927417264770598, 0.054803616517493804, 0.08119249566187782, 0.052303105532642336, 0.0315583044768221, 0.0464543076832929, 0.0179328466014516, 0.03743188718574182, 0.028665372613637198, 0.034100212937881874, 0.05168364683706915, 0.07574348845669339, 0.03657933474788743, 0.023771047539588426, 0.03763359813620487, 0.11897325545789735, 0.035742889308641036, 0.0912990952811895, 0.061038993824754036, 0.016588115230983785, 0.0863495007938435, 0.10258461994629714, 0.034492166502581495, 0.04222952813330678, 0.037476255167876525, 0.04721533176639388, 0.02642666260080953, 0.1699687714778608, 0.11657170771110444, 0.21239505780320014, 0.17656396113095746, 0.14652022971741616, 0.18311036630503594, 0.1719981077457628, 0.13723244019333394, 0.17647412966095632, 0.14298038256745185, 0.22050484924787478, 0.15853670185371754, 0.10978976880470592, 0.1978669817289037, 0.1509140197548174, 0.10033337098936881, 0.09838312563876953, 0.19402644506865935, 0.15358127743726777, 0.07345123081317834, 0.2327372968917893, 0.3237596658929702, 0.2771516733111874, 0.162294102652419, 0.05961836803884757, 0.1716862639953052, 0.2705831741613727, 6.289162164734257, 136.9991490148729, 158.78598551596366, 137.14581428035615, 138.22678812088506, 113.03256511688234, 73.28179882418725, 45.83646089799943, 42.477809844478486, 73.69192184940462, 115.65728187561037, 104.02081766436177, 64.01952958876088, 57.67539393517279, 29.64084540644, 1.09212881615085, 0.2719714480542368, 0.3069100829382097, 0.424737194252591, 0.1692645987796207, 0.66442952761727, 3.91484510514044, 11.949819422537281, 14.844695310438834, 18.520061085301062, 28.38252159856981, 44.275675281401604, 61.00513712052376, 83.5581184202625, 93.09118809238558, 100.49508540861069, 103.17241684083017, 103.56026080346878, 105.02246549052578, 107.89080066065635, 106.70591538952243, 109.35717090483635, 107.60921370598578, 103.96456303135042, 101.37413563266878, 100.66791288314327, 92.0488888217557, 80.7348983518539, 81.36824346357777, 84.55415725708008, 81.6482771596601, 88.03532354293331, 97.84244137425577, 100.30245780944826, 99.17557654842254, 99.79536594883089, 95.89392554375434, 88.76158960403936, 88.39768778893256, 86.76613869205599, 95.76992373312675, 102.28221924074235, 108.26330031118086, 60.03528794934673, 101.11842847639515, 90.13732171827748, 59.34516260700842, 111.61232979066911, 114.08306214117236, 110.71567596927767, 103.53519685806768, 110.50813551872008, 105.32696693174302, 94.27310020692887, 83.61927601598924, 80.07512430990897, 92.68456382136192, 103.60117112436603, 106.14514197072675, 109.50582088962679, 100.65860902109455, 95.93528301485124, 93.2985245796942, 98.29394540479107, 102.8671544597995, 108.32864699825164, 107.43007906021612, 98.07895245090609, 93.50267610242291, 94.47769887985723, 96.43511849064981, 93.71995972048853, 71.68839869960662, 41.04585839856056, 14.982157714905279, 8.067975178841623, 7.164146361812469, 7.4312112312163086, 7.392654822718713, 3.0626363956159164, 0.7076819938036704, 0.24414629194765325, 0.27203822027771707, 0.11105938333897822, 0.3350244065926921, 3.9972188011292493, 38.532905655522505, 51.314917687446844, 61.681228222385535, 79.26670812791394, 120.88741733181863, 75.06526131783762, 23.344378317556075, 39.74963665008545, 64.47301833860337, 67.82474640877017, 93.2440193237797, 107.70187577893658, 98.38701540423979, 100.54529959155668, 53.46977372323313, 14.722346778838867, 0.6913990094777077, 0.20932948036539942, 0.13100952330616214, 0.13389508540351547, 0.15374609359329747, 0.13274170938999424, 0.11908384024976723, 0.20394743690567635, 0.2501756643816348, 0.10312579211688812, 0.0786654856957255, 0.04995591555451674, 0.1547919568275252, 0.14200650095458955, 0.09269117663103728, 0.1612152363504133, 0.20288753894067582, 0.09223459588904535, 0.18791124014364136, 0.13063536596394357, 0.2567455731332302, 0.0903602775126215, 0.1351101927819752, 0.1866531245891125, 0.14920478566519677, 0.2343609896037848, 0.16230138048769968, 0.09864956335795504, 0.1680222799580905, 0.23953530066195997, 0.14219914142402912, 0.11188282060527033], [0.05031511119957413, 0.035385133908881296, 0.024356817518691384, 0.017367605863499547, 0.00957152838142769, 0.022731200010786136, 0.03668451861989114, 0.017889028287402565, 0.10561203088371024, 0.06103202242464308, 0.028911428563597224, 0.0816313491293019, 0.027475722336901293, 0.044215070985017285, 0.06734948605298996, 0.024143634401562235, 0.029022145505634048, 0.039623327658421574, 0.04108976550220002, 0.0538681618749134, 0.04553820825211945, 0.12068037514484699, 0.030340910325908375, 0.0597272789286029, 0.07491906293697896, 0.053410098752788, 0.5571010997218471, 80.38110840705134, 129.6291252874559, 103.85459546119937, 106.35458084844775, 65.61789935634982, 40.74248659995295, 22.897449731826786, 29.642651657904352, 73.75720577855265, 66.91765908272036, 68.36946164408039, 45.42742829168997, 33.361017396373136, 15.006135163768647, 0.19743596534094504, 0.04866029233521512, 0.046080912598558975, 0.16294308637659397, 0.19027266020496048, 0.19219868185539402, 0.2967146171196815, 3.939676895256966, 4.623682604682061, 15.096190821739937, 37.10358219762003, 56.37021741559429, 76.15385240124118, 92.60595167836836, 101.37456709338774, 100.40634570583221, 94.95701251491424, 93.6522674560547, 97.8980056701168, 94.24059160294073, 91.7295608212871, 95.39063053746378, 99.18895967545049, 95.75742706175774, 96.84627702159267, 98.81282006540607, 91.29987301365023, 81.96632646745252, 72.90997382133239, 73.7043636075912, 71.39586048741495, 74.65189841485794, 80.1621146355906, 88.83862495422365, 92.52860253857028, 91.40154084851666, 92.51208936014484, 95.0327064144996, 84.787381387526, 80.45612765896706, 79.980022522711, 78.84752442759853, 81.80101425417008, 93.2128207914291, 76.03680103055893, 44.86454856011176, 46.76771786905105, 86.29925897044521, 94.66547842948668, 83.01277560572471, 89.48813023105745, 89.95638278222854, 97.17612481886341, 92.82270969883089, 86.1654120106851, 78.61790887771114, 74.61086257811516, 69.87136856202157, 77.63914415913244, 84.92751198430216, 85.19709648624544, 80.49070727440619, 75.32342387783912, 77.8648530283282, 83.75823774645406, 90.7713100987096, 97.04401154671946, 91.98165155226185, 94.51563604416387, 96.17253149709394, 97.92960428422498, 95.84014984869188, 95.08945526615267, 84.47983618705504, 67.95314127399077, 35.77588342851208, 7.979685568040418, 0.7293728847176798, 3.687987226632334, 3.2502793977337503, 2.120055296728688, 1.1148247531344815, 0.19194035700732665, 0.15665949532581916, 0.027086390708122524, 0.06886067109242563, 0.13405938061975664, 2.312398524053635, 18.06557409224972, 35.93735171902564, 60.0215635761138, 81.94257259368896, 70.15125320803735, 43.22045180105394, 19.105400308485954, 16.25441280103499, 28.115900447291715, 50.60962453965218, 64.22150811841412, 83.42973139978226, 74.22809416247954, 72.11681565930768, 61.43236167969243, 14.529027861933555, 0.7594469225695057, 0.027989280868261576, 0.05180072039365769, 0.02539572275934681, 0.035503130601418596, 0.03763436422412915, 0.0250574087558855, 0.0972089886425003, 0.027471851677663868, 0.09817371550466746, 0.09898026053222919, 0.04408493179888014, 0.0457214871271243, 0.034013139384408156, 0.06018637626942608, 0.033541888058666265, 0.07044317125673256, 0.01548667519067925, 0.10866299902479495, 0.03140877560532141, 0.01838232570838544, 0.037125524794382435, 0.03342131348026376, 0.09980696133307873, 0.01953049423924137, 0.053679068392563256, 0.0812684992448457, 0.07482206854488581, 0.04392293101597217, 0.00867958561772661, 0.02073229084001674, 0.021417686723232753, 0.015125505911606937, 0.05445523420348764, 0.053503883236478415, 0.054997758519264965, 0.013942150962388804, 0.05271576645393526, 0.06863941723901419, 0.03599754842599073, 0.07264762756324585, 0.029790537439346797, 0.058953656529587124, 0.12587746199701103, 0.01613171068921445, 0.10742818020404347, 0.09100675612928406, 0.005791625186365339, 0.05810892201900002, 0.05981246790578289, 0.04165488941174361, 0.04522905347027606, 0.12228660871304813, 0.06989064566310375, 0.0635352262085484, 0.01353858829280662, 0.052726648732899666, 0.9980231884025759, 98.25844010999127, 147.4505239917386, 118.11115587911299, 116.35055295882688, 83.94606436452558, 69.22115725855674, 40.422585933439194, 36.69857786547753, 46.999122019737, 56.46303638335198, 54.46353366298061, 50.5085450603116, 43.95618646375595, 20.002499318891957, 0.46149678948906164, 0.17897035055343183, 0.06827036970325055, 0.3671929901165347, 0.6115650481754734, 1.4248036617232909, 2.0118852752831677, 2.518250149103903, 5.86601588995226, 15.170137305413524, 41.23799570145146, 66.49153278719994, 80.34128066032164, 95.04945493513539, 102.97700435884538, 101.3164532569147, 98.32112743008523, 100.34201099026589, 102.1441282764558, 96.543791678644, 95.86730049502466, 97.85999790314706, 102.24676885912496, 99.60572719573976, 100.65091333081646, 103.75885825003348, 95.53600142079016, 85.03237262848886, 77.51533846701346, 77.3973378827495, 76.8923641020252, 79.36128431750883, 84.61725250367196, 93.6676666813512, 95.08863941315683, 95.43322747753513, 94.89591767711025, 97.29508246144941, 88.03537845611574, 86.53551901540449, 83.61496925354004, 84.38425587069604, 84.85648570522186, 97.55562982251568, 81.42945597248693, 54.36841618630194, 54.17500019073487, 89.46171699031707, 101.71173403340002, 85.86900634150352, 93.44358951814714, 95.02053922222507, 99.94214104067896, 97.82233530475249, 87.69324579546529, 82.54657053178357, 79.53990121041575, 73.05670184473838, 79.15248086375576, 88.93214994861235, 87.8746711054156, 84.9003456484887, 79.60687960347822, 80.69392527303388, 86.12153637793757, 95.58068506179318, 100.37832429332119, 93.0557063318068, 96.38526516575968, 100.8370376402332, 103.22908724507978, 98.7272104140251, 98.50864025854297, 88.67238706158054, 71.63581540507656, 40.89201911803215, 11.557841281737051, 0.7757167914702047, 0.43481256812810903, 1.587207069800746, 2.6709977849837276, 1.9484317446908646, 1.1754747696461216, 0.27560448213931055, 0.22202185655553497, 0.09931174677706535, 0.05848284953484132, 2.395459125118871, 20.775374904755626, 37.20612864340506, 43.60503627407936, 83.06177385391729, 72.93991719522785, 31.410565876191665, 25.368566474606915, 34.784951517658854, 45.318064766545454, 61.94551752459619, 74.71018483561855, 90.69323924279983, 85.38856306383687, 86.49943320981919, 73.24546983165126, 19.763850550497732, 1.2092532409775643, 0.053166387031876275, 0.04200624414689599, 0.048359327033282294, 0.06118596779302724, 0.026050680054111347, 0.04807297868894474, 0.029653635612058065, 0.031103715563433307, 0.03718861213494693, 0.08212775112159791, 0.06727900596395617, 0.03336584488410623, 0.024035901371990482, 0.09869712975717361, 0.03650383295250997, 0.03810586069800681, 0.13703373230753407, 0.08932258843654588, 0.014563568927828344, 0.04386849663851242, 0.023620036287954258, 0.057590073650522586, 0.05791286096697854, 0.022790227085351947, 0.028627403380890048, 0.043012347417853536, 0.07638963765554851, 0.01820153470391468, 0.03501937289031283, 0.027473787964892485, 0.11195826494405348, 0.10613199774055712, 0.16844149859201524, 0.12991970194683922, 0.23404520816139637, 0.11491473613967819, 0.1216211847420181, 0.19604334006867102, 0.24935751312202026, 0.25784978162377115, 0.11325859194321018, 0.15107359586944505, 0.17545305703195835, 0.12663083286174845, 0.20603628288353645, 0.13969780306421942, 0.11576039761665369, 0.14700105714221157, 0.10971542763253374, 0.11527685824060634, 0.12183294676604772, 0.1962083094422856, 0.27757240879920225, 0.3206599822207805, 0.17232193311135616, 0.17858680097326157, 2.808161599020804, 126.47896782044442, 159.91431020921277, 131.11875518675774, 134.2851512662826, 93.3831379490514, 64.60059735082811, 34.84699949141472, 51.56756147261589, 103.6902246167583, 94.63088312456685, 95.24543223842498, 70.4362996931999, 57.691134406674294, 26.627194266165457, 1.190415690502813, 0.25861111980292106, 0.17657729106083994, 0.5483402407938435, 0.5165723518979165, 1.0062963251144657, 2.510128881662123, 13.076248630400627, 14.28416802037147, 22.324099233073575, 42.135724252270116, 61.510683567293235, 80.34208866857713, 92.96952401438068, 104.5799279982044, 106.89321640999087, 100.31650773940548, 103.90019693682271, 109.82485078996228, 102.28897356217908, 103.63249517256214, 104.81537219016784, 104.9845204814788, 102.0527841198829, 105.13979142712009, 108.3070190491215, 101.71139670956521, 89.91209137824275, 82.24666610840829, 80.82192790123725, 81.8878790640062, 83.42263190977036, 87.1426470048966, 96.19019000760971, 100.11545488911291, 101.3074710292201, 98.31405147429436, 102.76671040442683, 92.27132643422773, 90.19537279682775, 86.77388929551648, 87.33012060965262, 87.67492832676058, 101.54590406725484, 83.59705971133324, 61.49298975544592, 61.977261266400745, 93.69343665338333, 107.83020788623442, 92.09779293306413, 99.565397385628, 98.47748094989409, 107.4660550394366, 100.92898584181263, 93.0357728465911, 85.0233825560539, 83.81049156188965, 76.74157250312068, 84.80787184930618, 95.08957293725784, 94.30878593075661, 89.73697323952952, 86.02280247596003, 86.31757643914993, 92.54117765734273, 101.18179828889909, 108.32525022568242, 96.24602886938281, 98.68950074718845, 102.63905294479864, 107.906521520307, 103.49441205301594, 105.04125364365117, 91.44768361122378, 75.19589977879679, 41.87967192742133, 13.351660793827428, 3.9114706410515696, 12.079539068283575, 10.105573919511611, 8.589157173710486, 3.879781076985021, 1.7307431419049542, 0.7054474072590952, 0.4237081543091805, 0.2362210510839378, 0.2916653928977828, 5.668207820384733, 32.37963057333423, 55.464471540143414, 80.91063622505435, 92.56740262431484, 84.57764440967192, 64.26921982919016, 30.948863683208344, 30.280878159307665, 46.57216418174006, 71.73762444526919, 88.55842651859408, 104.67237041842554, 93.97471766318046, 97.7019734536448, 85.11945709105461, 30.002423217219693, 2.3261444703225167, 0.18553077513652463, 0.14264892696613266, 0.10607251101323675, 0.09075513455055415, 0.14314458585314213, 0.2503305673599243, 0.13370497302422601, 0.1354136555305412, 0.1297285936532482, 0.12241141209679267, 0.1760671071467861, 0.10647339716313348, 0.09549217794330851, 0.20876642106281174, 0.08507757267403988, 0.16316699855510267, 0.16153558367683044, 0.3474598522147825, 0.10856880085362543, 0.13114709737560443, 0.07420923650985764, 0.15939654361817146, 0.2772001207115189, 0.190115581536966, 0.1597541534612256, 0.17561247992900111, 0.1505880340212776, 0.1141882856046, 0.10241878489332815, 0.15605679863402921], [0.03673512255772948, 0.06203799163021388, 0.04883195348684827, 0.01032742829392514, 0.02010280979917415, 0.024596382788712942, 0.004986440443674163, 0.04728277431680791, 0.07259477515734973, 0.03478026535782603, 0.04731796073517011, 0.02366909272818556, 0.04033201644497533, 0.014251179339724683, 0.03293677435947522, 0.02286508536687301, 0.044156204788915576, 0.09759926447464574, 0.06395263304453223, 0.02503167394728911, 0.04562619728066268, 0.024262676804116177, 0.023530277596305937, 0.05531938138207602, 0.04650178215196056, 0.17268032436409306, 75.91490161034369, 127.0856329702562, 102.23118920480053, 104.37545484112155, 69.14969167401715, 51.83219594340171, 15.799669873329902, 30.55870944453824, 61.87700156242617, 65.43724675332346, 69.30883007664835, 49.64331726874075, 31.198546078897294, 8.891544457404844, 0.17737748521950938, 0.042749291976853725, 0.05580916820514587, 0.09872694589918661, 0.05286252591758967, 0.0346653598300632, 0.7332104336350196, 1.8315349399082124, 5.7135460069102635, 17.46180365162511, 44.98687944104595, 81.50332204757198, 97.1358185429727, 103.63502117895312, 97.52156011519894, 97.83236872765326, 97.86020971113636, 96.57643364321802, 95.3423147816812, 90.11854925463277, 81.89952065867763, 83.09283902568203, 87.49269500855478, 92.60615564161732, 94.90740237697479, 95.81439556614046, 94.7081381274808, 92.88083922478461, 77.59977925208308, 71.2797583303144, 70.31241555367747, 76.08895286437004, 77.17220952433925, 86.60216792937248, 93.2266196896953, 96.63385714254072, 90.91460212584465, 97.06741240716751, 91.45805435795938, 91.15497281474453, 86.80611548885223, 100.22626184648084, 88.75794964451944, 92.4279074515066, 79.05389601184477, 110.49985147291615, 47.40376941619381, 39.88342477429298, 103.66134028280936, 82.76065349578857, 84.32571057350405, 68.1434154510498, 79.86506569770076, 73.71821741903983, 80.74992102961387, 70.55015040982154, 77.63872054315384, 73.42480844066989, 74.04644919979957, 69.38621844014814, 72.71298454653832, 67.48240978487077, 70.92847085768177, 69.51367193652739, 77.86460984137751, 83.41853695531046, 91.33417021843695, 94.46244085988691, 98.81897034183626, 96.4228806957122, 98.22837906499063, 88.31212520599367, 85.11753512967019, 91.84894207985171, 92.12447289497622, 75.65097316618889, 77.500668802569, 62.2302580648853, 20.613786981951808, 1.3972835771499144, 1.1541895376097773, 0.9785364856643062, 1.0049611257929956, 0.805021615759019, 0.5221098192757176, 0.16091851517558098, 0.05140140855444535, 0.13523734805564727, 0.032704588431384296, 0.7680389970060318, 8.377991472521137, 23.7379724748673, 22.60535670864967, 40.48987811611545, 53.4719467163086, 43.52440411044706, 24.656503315894838, 26.419610669535977, 19.918927338815507, 40.189942313778786, 64.31871229602446, 78.6538456332299, 86.3815502966604, 88.02713363401352, 67.96275892565328, 35.82756457790252, 2.9714596752197515, 0.19031821179293817, 0.036840494121274645, 0.022296167406884414, 0.020910856359067465, 0.02578317172705166, 0.008890073062972197, 0.04788037652390138, 0.050541505502957496, 0.00550170591469073, 0.024333287128097108, 0.04600698128342629, 0.06154088483702752, 0.02958872306701397, 0.020909711057620666, 0.03315430502557466, 0.028730566695993467, 0.035200916576169194, 0.04043502462727409, 0.03646734035423687, 0.042356671915659984, 0.0077473346590845584, 0.05409839044835779, 0.013625054721600346, 0.08549281531163762, 0.05547418476893537, 0.03878693584532988, 0.035966648269564874, 0.05056857905020157, 0.05604748666707066, 0.05050114033022716, 0.03182235966256309, 0.008569762125731477, 0.020259139616222634, 0.012515304542537178, 0.023881967494925185, 0.04794100855266856, 0.07822856276987061, 0.01293448391445582, 0.04453222372479016, 0.06643933529454855, 0.020530150880316095, 0.042100733431476745, 0.07015826315769265, 0.01226681913624728, 0.05702898319390032, 0.029439159721556692, 0.08419960526929748, 0.05162692951759504, 0.09219449884708851, 0.06308933622353981, 0.07227773733076549, 0.02062027537894826, 0.0578327817962535, 0.05517842503444803, 0.24480460662274595, 93.4794556710028, 142.75260709947156, 119.27398958513815, 113.73042537320046, 91.47310056994039, 75.75043662901848, 33.50927122177617, 34.3976096184023, 37.35126418452109, 62.20954795037547, 51.619403439183394, 54.308619653024984, 39.105014724116174, 12.391761695185016, 0.27587613691726043, 0.15163755915578336, 0.11921780604508617, 0.06460691426670359, 1.0139482564503148, 0.4253193904315272, 1.55774038645529, 1.2940021772538464, 5.551386888950102, 21.223758689818844, 51.20620135338076, 88.58447105653825, 97.86033522698187, 103.85527795360935, 97.14482430488833, 99.43558262240504, 98.70891647954141, 99.26195498435729, 98.53566538903021, 95.07200071888586, 86.87613764116841, 88.57152723496961, 90.96681671757852, 96.92071576272288, 99.10658990183185, 99.72719515523603, 99.0633261588312, 97.27984797570014, 81.45109961109777, 75.5173223249374, 72.52769962433847, 77.75812533593948, 80.29123906166323, 91.82047351714104, 97.6462757971979, 101.46451488617929, 95.87203871819281, 102.10743842586395, 95.11274630023588, 94.22428238776423, 92.27726490266862, 104.32084760358258, 95.29259481737691, 98.9681145452684, 85.52463792985486, 114.71788206408101, 51.57812049311977, 45.33922987599527, 109.13595707185807, 86.79102220842915, 87.18911140195786, 71.0602468059909, 82.0956156330724, 77.97296923975792, 83.59049366366479, 74.27761016353485, 82.04106330871582, 77.63820279029109, 78.58078756640035, 74.60315119835639, 75.57169422026604, 71.43038518967168, 75.54241764929988, 73.17294520716514, 82.48290261914654, 88.35659703900738, 95.70716581036969, 98.78329246274888, 99.15137552445935, 100.02577381749308, 99.96787178900935, 91.06994367414906, 88.02609028354769, 94.63701771151636, 94.90632764754757, 79.08178406376993, 81.49882701135452, 69.06251307456725, 26.33987084511788, 2.294133026753703, 0.07850728087848233, 1.6855434640761346, 1.6205656023756152, 1.389898857282054, 0.9150226486306038, 0.9922867833125977, 0.5734920105145824, 0.17436568715399312, 0.03369199149611016, 0.5563433468341827, 9.245052972147542, 29.35314936022605, 25.032136940187026, 23.975430803914225, 46.16181758142287, 29.52703391352008, 21.662352238931966, 37.93840377561508, 32.07481926487338, 58.65083248384538, 71.6749841936173, 89.38610938287552, 96.76218140509822, 101.72982400463474, 83.30095214228477, 48.71775950154951, 4.34950206548937, 0.17327615690808143, 0.05633487306054562, 0.040542801706901485, 0.029342450697215337, 0.03011706326487324, 0.023090817004201875, 0.02282341592945159, 0.0402545687862702, 0.0021533642270256796, 0.02220303984358907, 0.027124352279990434, 0.03201188789981027, 0.1078488620659036, 0.044896655580810005, 0.058769362588082595, 0.02274517536974482, 0.01132367775895663, 0.036890856741416844, 0.03580339876334033, 0.0487553600161787, 0.048964850589512825, 0.03919791903406863, 0.03973287823159368, 0.014815529500464759, 0.007085958505124455, 0.08394845100420137, 0.03481736699599893, 0.02043035452163989, 0.04175813891173851, 0.10703050396254948, 0.17969468668583902, 0.24336423875103075, 0.11339509348955848, 0.07995871872070336, 0.09401960373525658, 0.20521093039743363, 0.1653651806015161, 0.16547417959138272, 0.14738330437291056, 0.18088901775979227, 0.09832222164878923, 0.11641149574349965, 0.24722806448417328, 0.08840982531828266, 0.07520914212950776, 0.15505026635383407, 0.24611622575790654, 0.1909544784575701, 0.2014963998789749, 0.08098013608926728, 0.22306857780823786, 0.20755656904751257, 0.1339974653937163, 0.17838041688646042, 1.1360621812843508, 115.24146356890279, 159.78192237115678, 129.85231599500102, 132.06272063716767, 95.46921130149596, 73.03792938109368, 29.13159820341295, 46.8597484404041, 85.43319179165749, 87.87943286280479, 92.32852243608045, 79.43668796170142, 52.018771325388265, 16.741697672874697, 0.9645446558152476, 0.36807276548877843, 0.3137180918166715, 0.32695290422247303, 0.46630904739422185, 0.2694630616855237, 3.801063029996811, 9.320131059615843, 14.59688388532208, 23.56253662417012, 49.39479589462281, 88.93342864128851, 100.13246228618007, 105.97440904186618, 99.97089985878237, 100.9962623350082, 98.36598365537583, 100.29385997403054, 104.53973939341884, 98.13166910602202, 93.2738999397524, 91.31931228022422, 98.13333219097507, 104.64522761683311, 105.16804818184146, 102.65944926969468, 103.27148022190218, 103.20469010260798, 86.56742357438611, 81.2635083352366, 78.53640202553042, 84.30658509654384, 88.5084790568198, 95.49931157019832, 102.10512422746228, 105.52496817804153, 101.55355268909086, 107.62604851876537, 99.08844501741471, 98.10219641654723, 96.63413170845278, 110.40051352593207, 98.70344085078086, 100.50326747279014, 88.57402970713954, 120.62035099152597, 57.37479525227701, 50.78253438395839, 111.68076730543568, 92.9919913507277, 90.66320957676058, 74.58272349449896, 87.65974090945336, 83.59043090574204, 88.61417124348303, 79.7668573933263, 87.29780812417307, 83.52660609829812, 82.22281025302026, 80.35616997749575, 80.85073378778274, 76.42292699506207, 79.3114309926187, 75.83971761888074, 87.82701430782195, 91.90363560953449, 101.04589600716868, 102.23999884820755, 103.49296862079252, 107.12768785415157, 104.19708113516532, 95.87487066945722, 93.53062691227083, 99.36528590417679, 100.77595064716955, 79.6191095536755, 79.58021533104682, 66.31779532278738, 23.775546819933002, 6.328668767406095, 3.820391979909713, 5.75382923887622, 6.083871683766765, 4.002981743504924, 2.940190540206048, 1.3080837313205966, 0.5991085811007408, 0.402247304277074, 0.30161310588159873, 1.3918860280706038, 14.870561380540172, 41.008999886051306, 40.37607839030605, 57.235660937524614, 70.15392826449487, 58.9665009129432, 37.100714945024066, 38.59070178001158, 32.20011938002802, 61.45664115105907, 85.9602092927502, 105.40943084224578, 107.28980725811375, 112.4225659524241, 97.56674581958403, 61.58063119457614, 6.594316190288914, 0.31331561986477147, 0.11320667416458169, 0.22611177015689113, 0.2069323146415334, 0.16252009859008176, 0.13222037123576288, 0.08498285356308184, 0.10610068772709179, 0.17286112111422325, 0.10129694105877031, 0.09781727777613748, 0.12750474000049214, 0.1985179572816818, 0.14952732400307733, 0.13519178114591107, 0.07561837097689991, 0.12221939215857176, 0.13691387019090115, 0.14672687427411157, 0.24834057736781337, 0.06132528088205765, 0.11328954955623036, 0.08458460275564464, 0.1346292734266289, 0.13006404823353215, 0.32057025800308875, 0.14379646538967086, 0.15398431629423173, 0.18699288458353092], [0.028338048141449693, 0.06335248742553015, 0.062425946215948755, 0.07905424467378086, 0.029452359416492047, 0.048500685577070525, 0.04838587964073785, 0.031223102705553177, 0.06377017771404597, 0.0265040451420411, 0.03459078883151374, 0.029275561645326596, 0.028040490015560103, 0.042022385619460575, 0.08531059363796827, 0.04527400367923322, 0.05912896809017947, 0.02420523553155363, 0.07774759744924885, 0.07149615910865607, 0.07880491369794454, 0.027168419572614858, 0.11950972384863323, 0.14016571424661145, 0.41145050237255715, 64.05990646731469, 130.51923659539992, 104.71547726661929, 112.59284388634467, 73.95703484935146, 50.207899308973744, 18.809649675123154, 52.1159755029986, 73.3679654521327, 72.42876175911196, 64.59575714603548, 55.33571581686697, 29.860307901136338, 9.413936503471868, 0.41659272966846345, 0.09505057422023627, 0.25813743231757996, 0.102324724617985, 0.0670116795827785, 2.4636696327117185, 3.904118158163563, 4.290795951120315, 5.449805836523733, 18.1944239524103, 66.57478117173719, 92.23767249814927, 104.7388389033656, 102.0198283656951, 102.96661792262908, 99.84958879409298, 100.86691041146555, 96.64701277209868, 94.49793830994638, 96.62343932736306, 88.8415196634108, 80.51775593911448, 75.43025355185233, 73.2707691192627, 75.42238527728666, 82.65404347450503, 93.0164198721609, 91.92871524441628, 90.12265205383302, 76.68524726744621, 70.55260581354942, 70.37590303728658, 75.21271890209567, 81.16605312593522, 91.48300063225531, 88.74063630257884, 89.82600319770076, 85.23959144469231, 88.53293895721437, 85.95173697317801, 93.0908743027718, 90.67245068088656, 99.20522182218491, 86.88311946007514, 101.03546250251033, 82.7066973716982, 101.99294444053405, 66.75743026118126, 44.392769798155754, 105.3831038936492, 81.31487569501324, 80.66892408555555, 67.66494904795002, 81.84431722087245, 81.20661827825731, 91.68821903967088, 83.19338506267917, 76.70108579820203, 72.67272533908968, 71.85973567347374, 66.93381140308996, 67.90400182047199, 68.60763580568376, 68.06667820099862, 67.95000337785291, 74.52413897360526, 85.67164836391326, 95.157500543902, 96.84942276247087, 94.74869543506254, 90.07121409139326, 82.1584520032329, 76.10007670617874, 83.26470944189256, 89.53500255461663, 87.21930580754434, 80.55178642272949, 83.37885041390696, 94.31428509373819, 96.34131108560871, 47.76989913755848, 4.3763894227243245, 0.9688121332756936, 1.4527668515520713, 0.21970695335297818, 0.030290005698559747, 1.5930500530427503, 1.8572757393121722, 0.06689026996853852, 0.08023218146615452, 0.038777501472542365, 0.057483173741568486, 6.512907887658765, 28.950651422623668, 51.73903180706886, 43.516426009516564, 55.0048795823128, 81.91707718756892, 36.41759103344333, 20.249818486552087, 17.380128137526974, 30.049730923867997, 54.23510266888527, 66.41688223808043, 67.92289979996221, 87.70647202768635, 88.93414251265988, 41.59039320484285, 2.552918263020054, 0.06911177173136704, 0.05304731015536574, 0.04002265864983201, 0.023183391068971927, 0.08389457204048673, 0.05192239813867116, 0.009206030705583193, 0.06392619535026532, 0.07277455301054063, 0.008412469910728115, 0.009239604508864784, 0.01975605733722689, 0.043763450662335085, 0.1027046122978772, 0.030706050813258178, 0.02731450104845628, 0.09915366453389007, 0.07842253623229843, 0.04522765152937463, 0.051784789595272274, 0.01884888857603073, 0.0643449888053921, 0.03516813567388923, 0.09466400625364435, 0.0592779147348577, 0.0478209970488904, 0.046854037040423964, 0.025311207939540187, 0.06146561286802735, 0.06328160897077573, 0.06832385030124458, 0.05759864234395566, 0.04892810901266433, 0.02993432639707481, 0.04496456544485785, 0.07326176194774528, 0.07867451021147352, 0.02822993398313561, 0.04824193555020517, 0.06147115551415951, 0.06185142623801386, 0.0733002808485781, 0.04873887763448781, 0.03430536362312494, 0.09282829870860423, 0.06977236168759485, 0.07831377472968833, 0.11291923031451241, 0.040410705166117805, 0.04882374868517922, 0.10811172215448273, 0.09330339579572601, 0.34687419331842856, 83.35625756171443, 150.57495855516004, 119.76332095361526, 124.27690998200448, 88.66969631564233, 67.55203970016973, 39.10243772691296, 37.85785005938622, 39.507057666778564, 75.11644040384601, 57.31734037399293, 54.76241827011109, 41.31068114311465, 11.518887242963238, 0.47606802695701206, 0.07892764864429351, 0.1951469712319874, 0.11420959817065347, 0.17227808223857036, 4.275725714622006, 5.415372819669786, 2.1369435518018665, 5.424161380337131, 23.787470825256843, 72.62338192232194, 99.40449391641926, 105.78950851194321, 105.49922958497079, 105.2708770382789, 102.85262600068124, 101.56520212850263, 94.51656172352453, 96.55428009648477, 100.5009218954271, 92.7218577169603, 83.78876163113503, 79.97291518795876, 76.52534792500158, 77.87460404057657, 85.45314881109422, 97.64935878015335, 95.81765113338348, 90.33686837842389, 79.1997532690725, 73.28730583190918, 73.53189699111446, 81.9022741625386, 85.78036862034952, 95.09735491967972, 92.54390762698267, 93.0056490436677, 89.68912816816761, 92.6225511489376, 92.37893273753505, 97.23057516159551, 95.28995898462112, 101.75476243419033, 91.93548525533369, 103.71820680556759, 87.07501749838553, 106.15203749748969, 71.08775046563917, 47.498071039876635, 108.67538452148439, 84.76128978113975, 83.72519570012247, 72.6358001462875, 85.973725780364, 85.59592308536654, 98.12850767566313, 89.03841480132073, 79.94809442950834, 76.06835257622504, 75.75937178827103, 71.12393825284897, 73.19651080716041, 69.91265543045537, 72.04558541697841, 70.92601545395391, 78.3656063387471, 89.96592198648761, 98.76742255303168, 99.47469649776336, 98.07766591348957, 92.38684808054279, 86.05463643227854, 80.01833623455417, 85.92403719502111, 93.23957135600429, 94.07127072734218, 82.7571782758159, 86.58864359701835, 97.24062427397698, 105.43831517619472, 58.01657345987136, 7.040397053764713, 0.25628611956152225, 1.1270664704422797, 0.7215919441753819, 0.15340732951318065, 3.096684529896706, 3.5606173257673945, 0.3863206427664526, 0.12137117960880842, 0.054246287552579764, 0.11188468219892633, 6.239723630489842, 35.28942715737128, 46.2892436212109, 30.01282338173159, 47.36465554083548, 48.47925193848149, 26.142171621322635, 32.20385543761715, 33.03220510482788, 49.52430079060216, 70.33199602557768, 76.05893888781148, 76.47184679585119, 96.8394442527525, 104.29419902063186, 56.31115436553956, 3.1570056801842106, 0.046066222862610896, 0.04056524425264328, 0.03912940779100022, 0.028895528408728784, 0.05378980257157838, 0.10112274032566818, 0.027781240116324157, 0.0382198469202605, 0.037600074128638354, 0.0500094919135013, 0.04783370644755421, 0.038175643647029515, 0.03633577624456056, 0.06560843633187395, 0.061061015022137476, 0.027601851052754832, 0.039151214483764865, 0.03954126815041227, 0.08049454359758286, 0.047160958675968076, 0.08901555571825275, 0.03540733513692695, 0.035563617073480165, 0.09670416734391644, 0.06868789528286265, 0.04476318774264186, 0.09775276551203382, 0.04761613364661894, 0.12274478291792255, 0.19627661384161443, 0.16812018599481354, 0.13476007527882053, 0.11844512210377764, 0.14741298261909716, 0.16865494600947828, 0.09799198412726964, 0.23695948323415172, 0.12382633818854248, 0.15974158961926738, 0.13818502456190127, 0.11527045374555935, 0.09903453786166445, 0.19384417742971452, 0.18790816047018577, 0.19551680783831304, 0.23589403879257942, 0.2142817791431181, 0.1824644622543166, 0.13522650025063945, 0.16314478200529853, 0.17879293991192696, 0.2402681250485682, 0.2999516143914192, 103.12676045202441, 165.88327900055918, 131.33290875342587, 139.00495498411118, 102.56772072084489, 76.5476034533593, 29.834063322313373, 71.72873635445872, 95.67894827935004, 99.39337791935091, 86.80795115809288, 85.19722200209095, 49.36396998743857, 16.535655567722937, 0.7625526430145387, 0.507645313177378, 0.4859328492274208, 0.4614736229902314, 0.18677146985165535, 5.949581986473453, 12.105498294676504, 10.463163660418603, 11.834417408512486, 22.178598911531513, 76.04486542363321, 100.51957668796663, 107.58517742156984, 108.2967032155683, 111.22607046558012, 105.75462295163064, 106.01803364292269, 96.57006371405818, 98.44991453232305, 105.23421856664844, 98.44268952646564, 89.3642774704964, 85.83027685842207, 80.54172946560769, 81.40840068940194, 90.67221533867621, 102.83179037032589, 100.01198276396721, 96.07488801402431, 83.90924899808823, 77.25457145321754, 76.2097147972353, 85.93782040380663, 91.09629415696668, 98.24203675793063, 96.15554763424782, 98.60360868515508, 95.01759744459584, 95.63460196218183, 97.97879865092617, 102.61070205319314, 98.65834143853958, 106.90976096737771, 95.1279180280624, 109.23642466145178, 89.28131149661156, 110.68461864225327, 74.74510961963286, 52.63110037772886, 113.62678850850752, 91.15833036361202, 87.4186328149611, 75.29501022831087, 90.13988694837018, 89.09685027214789, 100.88402763489755, 90.3196648628481, 84.29617512610652, 78.3656063387471, 79.60758563010924, 74.78091301456575, 75.59232588737243, 75.57959387379309, 77.42382172615298, 76.42795547362297, 82.29241663409819, 94.84232241107573, 103.17719428770005, 102.21811202264603, 102.87909415460403, 96.11029132719963, 89.97696738089286, 84.98737519787204, 90.37173040451543, 99.05270438040458, 96.34026773514287, 82.3490164356847, 87.34935591297766, 102.5667715072632, 109.4134569168091, 54.85948124239522, 5.541650095293599, 3.0556589893756376, 4.661558972251031, 3.603083601882381, 1.9618936868444568, 6.326497245219446, 4.9743410271982995, 0.5622338275274923, 0.26469064035242607, 0.1776949673770897, 0.47756597399711614, 11.952971046970738, 48.28989951841293, 80.23230152745401, 62.30452422172793, 77.30466796505836, 106.1707942716537, 48.50289206351004, 32.20456538661834, 27.50306933156906, 48.918761361029844, 73.92420461100917, 87.75110075550695, 89.55205702012586, 108.2581933852165, 116.2396675540555, 70.09320212948707, 5.287787923889776, 0.2106677133950495, 0.12676623890236502, 0.07440220639710465, 0.18472278220278604, 0.2751173421500191, 0.1461279314131506, 0.1707193997478293, 0.2474861441841049, 0.21737265280417858, 0.099316373948128, 0.1163787684673744, 0.16711042082357794, 0.20548218680966288, 0.12435871566976271, 0.10124320765176129, 0.11626030063076366, 0.1753228833718646, 0.1858638701660018, 0.16441262687646574, 0.17410481889401713, 0.16018052735636312, 0.15632473022466706, 0.09028339292854072, 0.16923896547767425, 0.22856178062577404, 0.16698366391562647, 0.24454026032359372, 0.19151367667701938], [0.025864308099112204, 0.04571737706541054, 0.10704986300439605, 0.05977951846415958, 0.037373859855917194, 0.021290144575158917, 0.028981345578006683, 0.026330110624492652, 0.042420441074477094, 0.06106217564534276, 0.03050407364724144, 0.040772375275170615, 0.046770395560851025, 0.040317790192221446, 0.0859443781777255, 0.05225247478172664, 0.08467570593160006, 0.12540326123276066, 0.006531355855610943, 0.046777581465580774, 0.10344738816662181, 0.08604163303971292, 0.3363154179626896, 0.4755597735845274, 24.00915926502597, 122.11682934914867, 100.65747153374457, 97.06207798373316, 89.05994861356675, 80.50376876708, 32.13759287711113, 50.43945250972625, 81.06120817122921, 64.32150502358714, 36.871609303259085, 57.06585368802471, 35.36405809463994, 10.223926536498531, 0.1529708585792011, 0.0360970517560359, 0.13434048892269213, 0.019569279355627876, 0.06754725931152221, 0.09394048983531614, 3.686895336835615, 4.916183064060827, 1.26354742434717, 19.248247146606445, 66.6012885493617, 99.9916805759553, 105.77523108451598, 104.1328719354445, 98.46507057066887, 100.64078577103155, 96.34581396656652, 99.81651536880001, 95.87452550088206, 91.88320006093672, 93.10283753179735, 89.61239876285677, 76.59019254869031, 69.71353238628757, 66.56060572593444, 69.58961686780377, 69.4635832694269, 73.44955075171687, 78.56164639995944, 77.64500418016988, 67.19727700756442, 69.67283387337962, 69.51091058792608, 75.86158091022124, 81.64539813995361, 88.70139691137499, 84.19818647446172, 76.44306444352674, 73.36584737223964, 84.10881134771532, 86.10891419072306, 91.13379986055436, 90.48912694377285, 86.4077046609694, 84.23353487445463, 84.48707688239314, 81.82218720836025, 93.59033323103382, 86.27785851878505, 50.1455650021953, 92.37797567921301, 84.48170323525706, 83.1818768285936, 80.52123115908715, 91.16886584989487, 90.97301406245079, 96.15554763424782, 93.36279653733777, 82.0369291305542, 69.2738974478937, 71.4590028024489, 65.5274377330657, 67.15234233487037, 68.1364179426624, 67.52624619391658, 65.8309664264802, 74.8664128395819, 82.73151028540828, 94.43239550436698, 93.24311717864006, 86.80653910483085, 75.53948371641098, 71.3136632980839, 70.35024289161929, 78.68260445133333, 88.76144839871316, 88.1426239013672, 84.94480963676207, 96.41414949970861, 86.09671561948716, 86.06873343067785, 100.31257752449282, 80.25822839429303, 14.783070952661577, 0.5524459817717152, 0.7269184002953192, 0.4521745413301453, 1.4411760025447415, 2.3507293962663223, 0.6661931845930316, 0.04255539895365796, 0.07496742606763879, 0.057136932643310684, 0.016906934211991968, 4.599474226274799, 17.18368407218687, 44.614513151107296, 41.06611744050057, 61.877484013957364, 73.65526337777415, 28.15555168736366, 24.745121425197972, 14.502659728450162, 26.884995968111102, 40.233476700321326, 57.627486105888124, 75.86258503698534, 79.55672817845499, 85.93549836066462, 40.25271200364636, 0.3024655472367041, 0.04831177212538258, 0.011969104919943118, 0.07072666209311256, 0.022791067866848844, 0.037752464338536226, 0.019829877569610556, 0.023274289316407615, 0.025787073029806058, 0.03567967939400866, 0.03466095482449859, 0.0179577061545945, 0.019508911627194574, 0.029033060343335235, 0.029856173937479337, 0.04163604364880631, 0.05266985863507275, 0.04029742374475445, 0.020084772258996964, 0.03105843210622909, 0.049230357511870326, 0.05880074921034037, 0.030070414255943992, 0.029261695453897122, 0.04421783273198432, 0.06226218343081494, 0.047799837700421774, 0.030286860907630577, 0.01321139214034643, 0.005355455420701014, 0.073381585759982, 0.047579392069770444, 0.02277183331428997, 0.06412899797602047, 0.006671445087469634, 0.0495516088220381, 0.029006649462145664, 0.032097862117112644, 0.005780186536045926, 0.03066366508362755, 0.10360304191107712, 0.042973794043064124, 0.020167896629221017, 0.05632766034273852, 0.05152510111069968, 0.058344980521548184, 0.07424945612588237, 0.03778562828477833, 0.09286510923336591, 0.15871895417090387, 0.3426330386390609, 0.4937413689349929, 34.02700447267102, 144.98639691260556, 110.71809999404415, 113.79192029276203, 103.03131349625127, 103.82416571340254, 54.90026212507679, 35.16901431545135, 63.82737267401911, 78.6105348217872, 42.76187181472779, 50.02500311020882, 42.596171286798295, 12.126424139545811, 0.19070430478501707, 0.053121827527760505, 0.14516295174196844, 0.03424625610932708, 0.10167829962747713, 0.22462137674372043, 4.358246499492276, 7.250650803888998, 1.546730170807531, 24.895701216113185, 71.28613610421458, 108.92339598747992, 108.98161965031778, 108.40907127626481, 100.44483200196298, 104.14006556234052, 96.53227559981808, 103.82525613231044, 98.02713794092979, 93.88850396679294, 96.23553260680168, 95.55248322025423, 82.30810611478745, 74.611678431111, 70.29991888230848, 72.55265374337473, 72.2887017649989, 79.41040023680657, 81.31933150752899, 80.3398842965403, 70.44992600717853, 73.77311491197156, 72.15771813546458, 80.36213198015767, 86.8189573287964, 90.75962928033645, 87.05313851756435, 80.86732541361164, 77.0067011925482, 86.99536200492614, 89.85262824643044, 93.4068996675553, 93.14401457386633, 91.16659087519493, 86.44978384817801, 88.86078634569722, 87.37556519046908, 97.13333176028345, 91.32922018727949, 54.10262461631529, 93.55268632211994, 89.01224474753104, 86.82729628778274, 85.78270635297223, 94.43388600503245, 96.75925531694966, 96.55580982085198, 98.91541357963317, 85.17258951740881, 72.55619172127017, 74.65191410433862, 70.32743823143744, 72.64534719528692, 71.11868227681806, 69.8963148363175, 70.24667662958946, 79.09051525977351, 85.21884210648076, 95.41187409431704, 95.6780461342104, 91.21984097265428, 80.91775140454693, 74.54597088598436, 71.09175912795529, 82.74277533254316, 93.9775731486659, 90.93604180120653, 84.53135259689824, 99.69518861462994, 89.3849640507852, 88.97104417124103, 104.87565901971634, 92.45841564670687, 23.61717720185557, 1.8475762081723062, 0.17089500242183286, 0.255322273700468, 1.5450716210949806, 1.9719447604110165, 0.6026685610413551, 0.10427662471850073, 0.11861707819926164, 0.15075064384408537, 0.032732634910292206, 4.485252845671869, 21.001564264297485, 44.70750862552274, 29.80761281905636, 55.059055359132834, 49.98008412699546, 28.501212519984094, 35.97966624844459, 25.518912884496874, 44.47494737563595, 54.50464010238648, 67.64507832065706, 85.20899695734825, 88.15676796820857, 103.64031637868574, 51.678380197094334, 0.19836716053466644, 0.02248380723739824, 0.012744044990188653, 0.004969882889605698, 0.05022317298778123, 0.08597428625028941, 0.03000651869261938, 0.018233888512176853, 0.06457815532602611, 0.01485501271447227, 0.04812364391381702, 0.052959776949137456, 0.009954055234219038, 0.054597607813775546, 0.01765430086262284, 0.024720864415529276, 0.038388275180853186, 0.09254722871006497, 0.04310552669208377, 0.03974174569931723, 0.035695736596901576, 0.05691382485712248, 0.04897806943664628, 0.051175569664807095, 0.10695184205448437, 0.03383492435058279, 0.07769376445080965, 0.03261816605264622, 0.14951336588109695, 0.0917996111656389, 0.15347632339164136, 0.15228847342152751, 0.12373516606467387, 0.18841359463910903, 0.09349621246538817, 0.15455796293193294, 0.16729068131216113, 0.14606760964999277, 0.12278812817267834, 0.11461400832500189, 0.2655927854920587, 0.19251020384892342, 0.23432639307312428, 0.1428106328051898, 0.14773211952659393, 0.25544864756445734, 0.2899761383812274, 0.1849101060220311, 0.32489522270137267, 0.3028639742443639, 0.5048171617090702, 0.5941200003989282, 46.96225174011723, 164.2122708597491, 124.93135744525541, 132.09173048696212, 115.93063969765942, 108.05292790935887, 50.895953639861084, 68.95009010068833, 103.19879870260917, 89.14249097147297, 52.29232134357576, 84.58190410367905, 56.72580380593577, 18.807815967067597, 0.4776659944365102, 0.6595083013657601, 0.3951898571704665, 0.15086296765554338, 0.24596104698796428, 0.3277339155395185, 13.206610564262638, 14.61905312153601, 3.3633024942490364, 24.873269181097708, 73.09358781383884, 109.23933506011964, 113.61413494233163, 113.73508514896517, 106.60306299886396, 107.84767027824157, 102.2235562724452, 108.7503174812563, 102.12377117526148, 94.36438945031936, 100.4005092190158, 102.09517709670529, 85.30256117543867, 78.42652859226351, 75.42478576783212, 78.6645850827617, 76.05238068488337, 83.25620574335899, 85.36434635039299, 87.33638855718797, 73.46357714745307, 79.14814272234517, 76.18982053572132, 83.02342876311272, 91.7557151855961, 99.95550063348587, 90.307097588816, 86.88723010401573, 81.45138986649053, 92.45475999770626, 93.9038404341667, 99.11871002566431, 99.55497172570999, 96.65839549033873, 92.38856607867827, 93.06035826283117, 92.26159895620039, 102.43216360768965, 95.98045302975564, 58.9368321049598, 98.94965587123748, 92.53752200834214, 90.89582966219996, 90.19629847618842, 98.09526166608258, 100.97756047402659, 102.15046682665425, 103.47096412412583, 89.78399461315524, 76.99347496032715, 78.7505869711599, 73.13591803273847, 78.02131637450188, 76.1574060686173, 75.49882442720475, 74.03214823815131, 83.77545695151053, 90.51318676240983, 102.51552966333206, 103.5364127928211, 96.01493066357028, 82.75921006356516, 79.50663951135452, 75.765380859375, 86.74366351096862, 98.882198949014, 94.24448259415166, 85.85846301048034, 103.73561428439234, 93.17714291234171, 93.81480263125513, 111.56225681304933, 93.15198483005648, 19.316443435607418, 3.3705500537349335, 3.1875268682356808, 2.565240143768249, 5.265906981883511, 6.8757442889675024, 1.9681525638987942, 0.3133697669592596, 0.3736719489097596, 0.36065295879398623, 0.3494327431244235, 9.253146782998117, 30.462785920789166, 70.94982424089986, 61.36933703576366, 82.51471304124402, 100.67530262854793, 44.162369774233916, 36.296723196583415, 21.856941023180564, 42.16507534826956, 61.2153918512406, 77.75661130105296, 98.98673011410622, 96.7736739497031, 113.90100925199448, 59.66280006593274, 0.5513920286490072, 0.13442958494828594, 0.05559758238133885, 0.14254510673063417, 0.12763187995240574, 0.13249446217331196, 0.0810293955427985, 0.16017453654879527, 0.11565903652339213, 0.11461714928549145, 0.08240949527751054, 0.16820142195830423, 0.0878459079972198, 0.20998528227210048, 0.09581353650578568, 0.16285334683714375, 0.2681218562347274, 0.2287863516398976, 0.13158413521464796, 0.26964388907917086, 0.17691407863411213, 0.22029158569151358, 0.13797048929958575, 0.09242746618486221, 0.15174740084236668, 0.15696729413203656, 0.17960935981283266, 0.1685220297546156], [0.017456481638815136, 0.06349196139302465, 0.042640285326107856, 0.026433745083669503, 0.044812745970463565, 0.02656531493900524, 0.04864287149581698, 0.02721420673262929, 0.057136856034518256, 0.04374786843395522, 0.05089568710255046, 0.03356826063545962, 0.04907401045784355, 0.055168308843407905, 0.006189811355133932, 0.008678392435784542, 0.0142289359768432, 0.07347533193927619, 0.08448710274552146, 0.033498244029620004, 0.1340637932862005, 0.05568354893776198, 0.07857995963985882, 2.5753681938494406, 91.57636088709678, 103.82134945161881, 119.00735470556445, 91.19730303364416, 55.1080967533973, 32.53807667763003, 26.385264435122092, 120.16443037217664, 81.38642757169663, 24.13140973737163, 73.2407472979638, 36.6434528750758, 12.156477339806097, 0.09826863379848581, 0.0575858525060598, 0.12587909376428974, 0.09562766059271752, 0.27997384929368574, 0.21543481807795264, 0.2391941463875194, 4.509835810430588, 1.7619535639401407, 3.751866702110537, 52.76596715373378, 98.85227126459922, 104.96849367695471, 99.56387550600114, 97.1248515959709, 94.02094671803137, 90.30438330865677, 91.15402360116282, 93.02191119040214, 97.58048195992747, 88.28095805260443, 91.36843604426231, 89.42740409604966, 84.07038780950731, 72.00798557650658, 67.98328861113518, 66.61360479170277, 64.43253163368472, 67.06332806617984, 67.05871535885719, 65.75069512090376, 67.29098243098106, 68.22449084251159, 69.34194272564304, 70.38118254753851, 72.76020203867267, 74.38826807083623, 69.78677088214506, 65.99291324615479, 68.21433974850562, 65.59104288777998, 73.09529012249362, 77.10742765857329, 76.30791525686942, 68.7177053574593, 67.48073885517736, 69.18129028812533, 75.68884757257278, 77.54338341374552, 92.10607697886806, 47.24700796988703, 83.59463568656676, 86.64449030353178, 77.61865369735226, 76.28801315061509, 87.62890323515862, 89.11283785297026, 86.15448428738503, 91.50112198245142, 85.47533373678885, 69.13597122315439, 68.13770448007892, 67.07121203022619, 64.8094400282829, 66.34205125993299, 66.05052501924577, 66.76797359220444, 66.80931537382065, 73.02395789853989, 78.62488285187753, 73.8084162435224, 69.43993922202819, 68.22926828938147, 66.77078985398816, 78.28034185594129, 83.0759963681621, 90.16946946420978, 84.61479709994408, 82.9387761700538, 92.38480060331284, 84.42369922514885, 84.59127856839089, 84.18010434796734, 93.95071275772588, 86.90864624515658, 26.36864535270199, 0.8851826046743702, 0.21463407233597773, 0.8087531381076383, 0.28164416611675297, 0.20461828477921026, 0.06644955490745845, 0.10922994239315872, 0.026946935892826127, 0.014892190003827696, 0.24940750801995878, 3.0630933517409913, 15.465712412711113, 43.15926282636581, 36.034826540177875, 37.74874933304326, 62.8559898561047, 47.97719247879521, 36.163813683294485, 14.085965752601625, 16.553059124177505, 33.89583256936843, 61.809783904783195, 86.84614719883089, 80.48832247334143, 86.41878927907636, 9.944231144843563, 0.5089715033048584, 0.045246121909229026, 0.08419817268487909, 0.10172496204294505, 0.021805681528583653, 0.006817210073237338, 0.03598685000812815, 0.0763479701333469, 0.08677546866238119, 0.0865147995852655, 0.02123085894591866, 0.01597228013129244, 0.024468176059364796, 0.027129824062989607, 0.03355826701848738, 0.15499452579646342, 0.03149693125798818, 0.040171858103525256, 0.05260537701448607, 0.043080931439274744, 0.022612136540814273, 0.031068328046990983, 0.08161523830025427, 0.1018288818698737, 0.040606547883080865, 0.05837431019772926, 0.014673118543390547, 0.026280031456882437, 0.06362215037487688, 0.03475770789889559, 0.04100334695390156, 0.07650360089516448, 0.023720286553725604, 0.05351335974410177, 0.02104615514737464, 0.05335641514149405, 0.043929009923651334, 0.03422103266442015, 0.03312405604388445, 0.034801198710356994, 0.015582006214366806, 0.04167517158953894, 0.016761540300062588, 0.003441349310319751, 0.1286471532958169, 0.0019455914861605233, 0.0901564444986082, 0.058055154138034394, 0.047548599165653994, 0.19891673668978677, 6.119681452551196, 124.8216958199778, 116.03886573545395, 135.18939879632765, 101.65197280145462, 74.83169201881655, 57.62027286714124, 42.790638477571555, 92.25557419561571, 66.04069555959394, 19.159725135372533, 48.25759487767374, 45.056866292030584, 16.30847384852748, 0.1810659534267841, 0.051308451445713166, 0.20387522545793366, 0.1829961885608012, 0.43425982036898214, 0.3308750292466533, 0.49512817193904235, 1.7959373468352904, 0.5979103583001322, 5.938070320313977, 58.03577738423502, 104.59251096171718, 106.72233443106376, 100.44762472952567, 98.32898785991054, 98.02953058673491, 94.58013549927743, 95.57164792091616, 97.33773431470318, 100.08340128006475, 91.02657010478359, 95.44880713185957, 93.16437167506065, 87.308163181428, 74.49940450729864, 71.29570668743503, 71.10270254073605, 67.74876225379207, 70.17080230097618, 70.94513308617377, 70.01286414361769, 69.29197957438808, 71.79388692302089, 72.36326602197462, 73.21016850010042, 76.41432915964435, 76.76334165757703, 75.1425398549726, 68.81267378407141, 71.86880419331213, 69.31013230354556, 78.21665825382357, 80.02717725692257, 81.73321216337143, 72.5744228978311, 70.19125353905463, 70.5288911634876, 79.22119294443439, 82.54398176746984, 93.47893791814005, 51.01035348830685, 87.47094154357912, 89.13048067400533, 82.50937077306932, 80.40702742915, 91.02477365924467, 93.94654720060288, 87.88102534509476, 95.52689367725004, 89.12384402367377, 72.00127047877159, 71.29421618676955, 70.42551317522603, 67.5734950650123, 68.38733196258545, 69.40663829926523, 71.14576232048773, 71.66033021865353, 77.17118970809445, 82.50661726920836, 77.29626624814927, 72.60781011273785, 70.8840068694084, 70.17036299551688, 83.97090865719704, 86.82464476554625, 94.41851815869732, 85.24927969901793, 82.69423207929059, 96.48073565575385, 86.81614891175302, 89.82767412739416, 87.37212919419812, 96.02780388247584, 94.85920429229738, 35.165084100538685, 2.3176613642323405, 0.21772342914294815, 0.8324747748913304, 0.9287150913188535, 0.46959819993184465, 0.2350038446245655, 0.11800151123034379, 0.04822113626306096, 0.08164890020364717, 0.1828634868105573, 3.1009631003102953, 18.35041073060805, 44.400536091096946, 29.398868506954564, 44.19762403734269, 38.31062101548718, 22.58074579700347, 30.366548607426306, 19.904575386355003, 29.24918301643864, 45.02488328564552, 69.08966372090002, 96.7927288240002, 91.40526710018035, 103.6472511291504, 15.116950946469462, 0.3369884108824115, 0.057214296032344146, 0.07723285531204555, 0.03571927847881471, 0.06913408021172208, 0.02985804510723439, 0.04871422109464484, 0.08887742240462573, 0.06829606429223092, 0.07476363135802169, 0.017753719922996337, 0.03895051859980149, 0.004003436638853483, 0.04840536891753155, 0.09136281847473114, 0.056211084743300756, 0.009581433898288636, 0.04947350615815771, 0.03559960405372324, 0.03857663321879603, 0.04356822464615107, 0.0493827477217682, 0.0487831536860716, 0.032458049846031976, 0.061268237975215724, 0.061402299531525185, 0.011135262264419469, 0.1098205502175035, 0.2127397514038509, 0.19453161876768837, 0.16200363275504884, 0.1870001317752946, 0.1066960989227218, 0.14030584704972085, 0.100313215216081, 0.10930598428052281, 0.14936613910380872, 0.27652869061116253, 0.20527168116982908, 0.1443123030326059, 0.16941153444349769, 0.20595297848265018, 0.10157930574590161, 0.10848181156982338, 0.3749142983748067, 0.15675563936031636, 0.14603644519323303, 0.22849393587919975, 0.514768245479753, 0.7482768090501909, 10.79148369450723, 146.188571991459, 130.90395835138136, 147.42650339680335, 119.38982502106698, 81.78639165816769, 51.67421071760116, 38.68469745882096, 160.18219240250127, 106.32639469638949, 31.972363033602317, 111.96036954079906, 59.23330837680448, 23.3408187666247, 0.4061156805724867, 0.24727983670609616, 0.49808612934524016, 0.422751524996373, 1.3332733151412781, 0.4691189046828978, 1.3923891946192712, 22.52214558662907, 7.369554023588858, 5.850621077322192, 56.57586336135865, 107.00898124325661, 113.61957134739046, 108.25625573435138, 103.17026738197573, 104.76633471827354, 100.22522634075534, 101.78253281501033, 101.85957600993495, 106.12982119283369, 90.19132491080993, 97.8055867841167, 98.27641241012081, 91.7076426167642, 79.89232617039835, 76.00142125160464, 74.83450828060028, 72.59278743497788, 75.30786775773572, 75.63657022291615, 73.45392027208882, 72.22281379084434, 75.48152677474484, 74.52762203831827, 77.84941457932996, 78.243346060476, 80.44661198892902, 79.77868726176601, 71.91399774243756, 76.71496314387169, 72.54264385469499, 83.49379939417686, 85.67281723022462, 85.38846892695274, 75.9645745062059, 76.00453561352145, 74.92600148723972, 83.81398247134301, 85.87475653617614, 99.83156942552137, 56.851354952781435, 92.73601747328236, 94.1672589701991, 85.99323564960112, 83.17242391647832, 98.33050189479705, 96.6754578005883, 91.89914057331701, 97.3863717048399, 93.60299464195006, 76.4227230318131, 75.5558870684716, 74.07431371750371, 71.2356081316548, 72.90252916274532, 73.9609964432255, 75.36576194147911, 76.87559204716837, 81.69558094393823, 88.33790302276613, 81.70698719639933, 76.35055142064249, 74.54062077306932, 74.00479362856957, 88.3895920168969, 90.75249056662284, 98.85291453330748, 87.88715993204426, 84.92306401652675, 99.90044624574723, 91.66942304180515, 94.75330029764484, 89.52009754796183, 103.15387187465545, 100.77301671428066, 33.84901123662149, 1.625580720363125, 1.180550071500963, 2.6897942731457376, 3.1001425894998738, 1.7065395438863387, 0.4373473385649343, 0.33851599020342676, 0.4902575994210859, 0.2048532286238286, 0.7941513184097506, 6.214698418494194, 29.219053329959994, 67.59846487352925, 51.94039844697522, 56.65678970275387, 86.16457262346822, 66.82646397621401, 53.25232928799045, 24.444203069133145, 27.11976747358999, 49.46670078462171, 82.58894781912528, 111.05702415589364, 101.03612146069928, 116.13000592877789, 19.13031520382051, 0.6082793277117514, 0.14226880945986317, 0.17115662144797464, 0.18101428845717063, 0.2087099297392753, 0.21009975112974646, 0.12698460460430191, 0.13661125013905187, 0.20823929128387283, 0.12957940569087384, 0.1556267934821306, 0.14979583782053765, 0.10686990895098257, 0.12722442076811868, 0.2006064048938213, 0.3159177447518995, 0.0883591486020915, 0.13562667393876662, 0.11408841072191155, 0.16446530308213927, 0.140933855286529, 0.09564226988943354, 0.16074950085772624, 0.22910628527883561, 0.1658291847354943, 0.1750762030602463, 0.1793120564111779], [0.033195631638649976, 0.04538366150471472, 0.03369825043445153, 0.07770939264446497, 0.01673139282502234, 0.0522987311705947, 0.05433509629520197, 0.047252770483253465, 0.020628568280728597, 0.03163567935717443, 0.039186914181036335, 0.0170781452869696, 0.046676312302870136, 0.03819200728509215, 0.017664771369327942, 0.09993203284759676, 0.05590790161682714, 0.02855135766308635, 0.030283903808242855, 0.06314735206204557, 0.04012485477893103, 0.072520479950453, 0.3011775389313698, 65.92030232952487, 110.97381499505813, 116.21843184194258, 96.99836300265406, 77.87194467359974, 42.348218656355336, 32.30455444705102, 76.45440009332474, 109.40138386141871, 105.68900954338812, 87.04782762835103, 49.59975542560701, 10.409461509796882, 0.35733886243354895, 0.1434932937545161, 0.07748256933184401, 0.08842572930359072, 0.1852302694873464, 0.09343152400106193, 0.2948490091629567, 0.37717186755711035, 2.1836175505192053, 2.512036379306547, 22.292457472893503, 93.91016329488447, 104.8374237552766, 98.43702562393682, 94.5216372705275, 90.5768076066048, 84.25377430454378, 85.61566045207363, 86.11715116808492, 86.15118949644028, 92.25327568669474, 91.5140030460973, 89.72263305417954, 85.96119773003363, 80.1192274401265, 76.46972871595814, 70.65556018583237, 68.86759481122418, 70.28054237365723, 65.1115409789547, 68.339110343687, 66.74388239460608, 64.80258764759188, 65.29202884243381, 68.42865020998063, 70.58793852406164, 72.34363848163237, 68.99055327138593, 69.85760888745709, 68.43141940332228, 68.05592306198614, 67.11373836763444, 68.61102473351264, 64.83335471922352, 67.36485635080646, 64.89513989417785, 70.14919004132672, 75.09598916576755, 88.28870081132459, 83.61288255260837, 96.44103342486967, 38.913807022956114, 72.52970787786668, 91.26292428662701, 79.71823569267028, 83.83484948065974, 82.97541110746323, 86.93105866832119, 79.39633461736864, 89.73171726349862, 80.52488680808776, 69.23852551367976, 65.17418515297675, 65.33872465933523, 66.04026409887499, 65.63256117605394, 63.75429499533869, 68.72057653242543, 66.09716200059461, 65.7106908675163, 63.77930402755738, 67.68457658829229, 65.81972491356635, 71.77564005697928, 72.91845398564493, 81.4422821229504, 81.16613157333867, 90.98546366537772, 76.46157803074007, 81.66962269813784, 91.99857265718522, 86.43969551209481, 71.68093835153888, 83.83834823485344, 86.99045119747039, 86.6600856473369, 60.915240318544456, 22.887832080164266, 0.972462572878407, 0.3352660613675272, 0.3094575091475441, 0.13013563148917692, 0.14949235975021316, 0.20620718177768493, 0.23236493219531354, 0.1512074773950923, 0.03888827012551408, 0.4790287116362203, 0.3498537544040911, 6.735636245819831, 38.02966556241436, 29.02461555696303, 70.90824711707332, 117.63863578919442, 78.10793799738731, 81.32701150832638, 24.476146851816488, 16.486902467666134, 43.46510571818198, 74.0990952522524, 75.40942576623733, 92.6387191587879, 61.14357325338549, 0.8458194136619569, 0.05025791124470773, 0.06378626939089549, 0.0665899328587036, 0.016755149211554278, 0.06270015972756571, 0.02336836682872907, 0.07228233385831118, 0.01910016733041454, 0.026832083991218, 0.05202386648424211, 0.026590664788419684, 0.07844021754159082, 0.05973647964457351, 0.052757935763727275, 0.05574307396947857, 0.028168392224958348, 0.05513570414135053, 0.025401412877404404, 0.05703452967047211, 0.0960813531832349, 0.02898510898493471, 0.030429655866276835, 0.07039147564360211, 0.040344756487156117, 0.07214889666366, 0.013675558110398632, 0.03275940968324581, 0.03855288066270371, 0.022246791124944727, 0.02135182614438236, 0.03465092673356976, 0.024003156858886925, 0.031305579731481216, 0.06227889563888312, 0.024489207088106105, 0.0945249536345082, 0.04888974715985599, 0.039790986000650355, 0.05981935120578255, 0.034787765358604734, 0.029610501031481454, 0.061791510501455885, 0.03992354219418861, 0.0681180714239036, 0.03106182204529403, 0.05902456945829815, 0.057495818022758736, 0.0941421854640207, 0.1084530526291459, 90.83628023824384, 124.99406045483006, 131.64210134936917, 108.25046631597705, 103.16809438890027, 65.92302445442446, 42.98245022373815, 41.324256466281035, 102.6720714569092, 99.6445272814843, 49.784353933026715, 62.27644397366432, 13.525016807740736, 0.41985384338805753, 0.08769645956495116, 0.11540569124683259, 0.07623705592366957, 0.17582827157551245, 0.18370904869610266, 0.4075063140161576, 0.6693941450888111, 2.315150311877651, 1.5352549091462167, 27.515956278770204, 95.02438314499395, 107.56037235260011, 101.2018023767779, 98.72834790137507, 93.64253997802736, 89.36109250591647, 88.01873191710442, 88.5583245369696, 89.35818210724862, 96.18053313224547, 92.66012745518839, 93.75517475989558, 91.36021475638114, 86.09498193187099, 80.72391571537142, 75.51657707460465, 73.5178941295993, 74.80493360950102, 67.78152188947125, 72.55547000515845, 70.38136297656645, 68.16033655597319, 68.51230652101579, 71.69060307164347, 73.015469889487, 75.61468339735463, 71.74380610066076, 72.85260523519209, 70.63980010248, 69.99718250766878, 71.63661556859171, 70.47526451849168, 67.69013066445628, 70.64853129848358, 66.36817424528061, 74.18494809058406, 79.18668393165835, 93.62619938388949, 89.10809178506175, 102.23784154461276, 40.259156457839474, 74.24503880162393, 94.38925727721184, 82.78786690004411, 87.91270240660637, 88.11982708592569, 90.19913042745283, 82.09152852335285, 92.68308901017713, 84.50933241075086, 73.2693099975586, 68.90803444770076, 71.34247702936973, 70.69981236611643, 69.31859677837741, 66.47316040531283, 69.48477191309776, 70.8329454545052, 69.8002952144992, 66.84125131176364, 70.93300511760097, 69.91882139636625, 73.91600685734903, 78.94308120973649, 83.26019871619441, 87.99634302816084, 94.19547650121874, 75.88712338478335, 83.81697916215467, 96.25092398735785, 90.29678175526281, 76.35270872423726, 86.24120004715459, 91.99039059300577, 91.20699128796979, 67.1896440752091, 30.118237080112582, 2.4048188809425604, 0.49330154253590497, 0.652493019738505, 0.33220480466561936, 0.2616979944850168, 0.2604677185656563, 0.25893722811052877, 0.1684281380186158, 0.14737662408621083, 0.6832703875918543, 0.010639149470314866, 6.783296475487371, 44.90365851309992, 29.245664650394072, 67.29052743604107, 103.45962062958749, 51.55774378007459, 49.442891997675744, 28.182135551206528, 31.089443391369237, 55.732655755935184, 83.44303607940674, 86.24733463410409, 103.76227855682374, 79.41008644719278, 1.5051418927408036, 0.08675125262309467, 0.04943332867696882, 0.04225891526608218, 0.04938719869260827, 0.051933736239950505, 0.05009833513008011, 0.04103951779524646, 0.01964967070718206, 0.02275532603474154, 0.06180385600835566, 0.03206261249649669, 0.04775451210838172, 0.012776295376581051, 0.039897613948391336, 0.04063899553711376, 0.018055294264828967, 0.08022715592937124, 0.016879372283696167, 0.014765542263405458, 0.014208423015060685, 0.0034258264537540177, 0.046641114393189076, 0.059895197740725936, 0.03450857227547996, 0.023116023212130514, 0.07897857050862044, 0.10475264877201089, 0.1765317701163792, 0.10134276843840077, 0.15908094603688488, 0.12284743103889689, 0.10401290661144642, 0.13165438547730446, 0.11891924625923557, 0.08496662015996634, 0.1541226411298398, 0.15267991370731784, 0.22391674439272574, 0.11994349049224008, 0.16488703448445569, 0.14573895793047645, 0.18002847119444804, 0.2110258748214091, 0.22057799532288508, 0.09138600029531987, 0.17188840395500585, 0.1395899532062392, 0.2256355699031584, 0.48081673020797394, 108.69464335903045, 140.68432561812864, 145.14289948248094, 125.83609919394218, 106.3865246311311, 66.65023188437185, 48.11382432137766, 102.73626496714931, 128.63353360083798, 123.70399290515532, 124.74704527085828, 71.32295931539228, 19.878307273311002, 0.9578372802465194, 0.2324140537530184, 0.214381447182067, 0.1879305762028502, 0.41107539508131247, 0.3949427478496106, 1.4361345311326366, 1.7803656598252637, 11.645523905754091, 8.522442560042105, 25.99137217767777, 103.6081607880131, 111.96653550670995, 108.97344543087868, 102.08225680935769, 101.2802105565225, 91.79340131821172, 96.25146527444163, 95.0579978573707, 96.10856548432382, 99.03030764672064, 96.50292058144846, 94.84072208404542, 95.43974645676153, 89.63619970506238, 85.99620096145138, 78.45396164924868, 79.33549865599602, 79.91199293444234, 72.0971175163023, 76.4876304134246, 73.90289045149281, 71.48925212121779, 73.66207261239329, 74.29853993077433, 77.02959998961418, 78.41902902049404, 77.05413049267185, 75.82452235683319, 75.44970066316667, 73.93554026080717, 76.11389913866597, 74.07086987649241, 72.3117103884297, 74.29439790787237, 71.56404387566351, 77.55303244436942, 84.6784257888794, 97.77714175562706, 95.39569823972641, 104.96931737469089, 45.998921548166585, 80.15900811841412, 98.54559683030652, 88.20907669682657, 90.59264613736062, 92.12187628592216, 92.99993022795647, 85.03246676537299, 97.97514300192557, 89.59341449122276, 77.37932635891822, 72.69956219580867, 73.26268903670773, 73.1515996686874, 73.76572516656691, 68.86746145063832, 74.09744785678002, 73.18359051981281, 72.4581403117026, 70.25453705941477, 75.19298153538858, 72.91431196274297, 77.13475088919364, 81.5877628326416, 88.9883182894799, 90.30752904953496, 98.33251799306562, 76.9515448231851, 86.55053384842412, 102.31462586310603, 97.43367548911803, 81.06661319732666, 91.08615875244142, 97.72829255750104, 96.38323337801042, 78.88407307286417, 31.652589844119166, 1.7494571377192776, 1.7702271909483018, 2.2697942295382103, 0.6074661713454031, 0.843301190724296, 0.5600048793900398, 0.5544216918849176, 0.3423164298217143, 0.2535547709633266, 0.9629327455355275, 0.803811012977554, 12.745384939255255, 61.37911942697341, 45.51559140605312, 91.57511357338198, 152.18962577081496, 107.42460343145557, 106.11100950548726, 36.7542362982227, 27.78812954502721, 61.431898840012096, 94.03658128553822, 100.11841235622283, 115.40003715022918, 89.91239732311618, 2.1553929102036262, 0.2301629043875202, 0.179283190218191, 0.19687024005238088, 0.14326691477289125, 0.2572269214978141, 0.1421623079166297, 0.20755450061011702, 0.097703866119827, 0.15774007766477524, 0.20639553215474854, 0.10473260025103247, 0.14240647545985638, 0.10925598172170502, 0.11916596487525011, 0.19759374880982986, 0.13559451356770533, 0.1281540761251123, 0.07790685180694827, 0.15495445939802355, 0.14212283906677078, 0.19737608790878328, 0.11022964116906929, 0.13457915595462247, 0.12803122626557467, 0.20488672198787813, 0.19491869235231032], [0.020284238571841872, 0.10741073638200761, 0.07248533949736627, 0.09352326302999452, 0.012813594282394456, 0.04513011321485524, 0.04402216238480422, 0.04676552707209222, 0.10758332066958952, 0.028308638026036566, 0.054588974002868905, 0.016517374672055725, 0.026967896058434443, 0.08537985564720246, 0.11882402919112675, 0.07728402232450825, 0.08433874981898455, 0.05032081855461002, 0.11682201927948384, 0.19095098509663538, 0.39330396320550676, 0.6000366506557311, 18.97241823134884, 113.9817394748811, 110.2228380018665, 102.00734738380679, 83.96868075093916, 46.1930827940664, 29.014591939987678, 38.054274512875466, 86.46747373765515, 70.1882254692816, 45.3429090592169, 45.46478102284093, 9.552970797784868, 0.5113245883295613, 0.024956371334771958, 0.09615374083120017, 0.14613346256796392, 0.19403461156593216, 0.0716492387976858, 0.07150237974260124, 0.04606251499705738, 0.44542420355062334, 0.7219965611734699, 1.4537235421519128, 53.8641131308771, 105.57174636471657, 95.00737574792679, 86.75714861962103, 84.52605739716562, 78.38200969080772, 73.70636401637908, 73.56995967126662, 75.81068423486526, 85.77908992767335, 89.31428294028007, 92.41140996256183, 88.84430454623315, 84.70079114360195, 80.96414519894509, 78.66175313149729, 74.41100997309532, 74.84226672880112, 72.36922802463656, 69.26516625189012, 63.50017247661468, 65.8637652858611, 65.20757629025367, 67.77885467775407, 67.57265567779541, 67.1176528930664, 70.92222644436744, 68.98874113636633, 70.47236980930452, 67.57594262399982, 68.04816461378529, 64.8120915505194, 66.4430836708315, 64.89278254970428, 68.3407106707173, 60.65155506134034, 65.04562947057909, 71.76744230331914, 87.85244695601925, 81.58846885927262, 101.16331608064714, 42.651994459090695, 53.09763100839431, 92.66289664853005, 74.35461413475775, 83.90183571846255, 80.27664784462222, 89.38158296769666, 82.59774177305161, 88.50290929117511, 79.60159224848594, 68.80934761416528, 60.511773555509514, 67.09331850851736, 64.36568660120811, 67.64554900507774, 65.86840937214514, 68.9354439704649, 66.01609445387318, 67.23983472393405, 66.81517539485809, 68.13255833041283, 65.4455739451993, 76.76244735717773, 81.28384190220987, 88.09597907527801, 89.64780992077243, 85.48810497406991, 75.32722857690628, 77.85401944191226, 87.0111220882785, 86.67846587396438, 77.91261965228666, 69.83864030530377, 83.60763442131781, 90.84283844117196, 74.25421714782715, 46.86918958540886, 25.207088378167924, 3.211974511223455, 0.16981158555755693, 0.08093075406166815, 0.23597173542985994, 0.15193683906428276, 0.012290660750060793, 0.14258806894142784, 0.07756049579550182, 0.358302386537675, 0.011214169320620356, 0.028957342128119165, 2.1289269626140594, 36.98717017327586, 33.03778271521292, 31.4610997323067, 137.5880850515058, 146.10477447509766, 95.3794910061744, 16.095398933656757, 33.87547939054428, 56.25913196994413, 86.44187634991061, 76.78209843174105, 100.7105568916567, 18.870287556802076, 0.9015762120965989, 0.0364074973960317, 0.10165732414011033, 0.03077893450315441, 0.03464694690680312, 0.03559885328755744, 0.07545757678247268, 0.03242577839222166, 0.011864234186378459, 0.07723064131794438, 0.02081412243686857, 0.01166947644143816, 0.07738952795344015, 0.03127542459556172, 0.06661591090021596, 0.03540917757838484, 0.062028369565884915, 0.011829135868127548, 0.05692307536880817, 0.03693960291603881, 0.024589419049481233, 0.014874817044924826, 0.030224846090160074, 0.02693178267368386, 0.021123110594588424, 0.02231218630538112, 0.05072054025086184, 0.09911054910551156, 0.01567279050622376, 0.0817074676254584, 0.015561298857773504, 0.031293130802711656, 0.007497495671193446, 0.07359939221773418, 0.19577646567936868, 0.06546657217005569, 0.06543542303505444, 0.029646997460194176, 0.033656100276857615, 0.03880291260899075, 0.0864678000911109, 0.10338780184787127, 0.0473111578744025, 0.08207305244380429, 0.07188540838298298, 0.24997409132699816, 0.3473876560887983, 0.8145540784443579, 31.10662337272398, 137.98714699283724, 120.23763748907275, 114.90056253248646, 92.15508307180097, 68.35177175460323, 47.98833985482493, 36.083177597292014, 52.529565903448294, 85.46851665742936, 54.25603243612475, 57.46432727383029, 14.114951087582497, 0.21557315823531922, 0.06050017737453023, 0.06582603594588657, 0.09786383293929601, 0.06056802978198375, 0.2253840785593756, 0.07173152430163277, 0.22524697946444636, 0.9528400580729208, 1.1772922979247187, 2.3752375908436316, 57.95394497532999, 107.99224884279313, 96.57904594175278, 89.72675938760081, 87.69268881890082, 81.17011670143374, 77.63661815274146, 77.28112589928412, 80.24997572745048, 92.25388757644161, 94.35524248307752, 95.49834666713592, 90.41681412727603, 90.7815553295997, 85.3772666377406, 82.19314144503686, 78.17702662560248, 76.32191027364424, 75.41315201790103, 73.46771917035504, 66.34556570360738, 67.83765100663709, 69.0901344053207, 70.30425702371906, 72.05882733868015, 70.71658442097326, 73.41173125851539, 71.05311593701764, 74.38173340212914, 70.27943626526864, 69.88318274098059, 67.72725197576708, 68.70562445732855, 66.5789310393795, 71.22242112313548, 65.23339333072786, 68.78771182029479, 75.14868228666245, 88.45664885736282, 85.43714554079118, 101.56776735859533, 46.101095368785245, 56.105210319642104, 96.86866591053625, 78.1083773028466, 85.58461096978958, 83.50897112200337, 89.75185471196329, 83.76795737974106, 93.41818040417087, 82.9088955540811, 71.34326934814453, 63.04563645393618, 69.55532750775738, 67.84202052700904, 69.45095323747205, 69.10380778774139, 71.27789128211238, 69.62964073304208, 71.04418862250544, 70.4892046220841, 69.92247704536685, 69.18827995177239, 80.50086621315249, 85.34012179220878, 92.26697260333647, 94.294704621838, 86.67607322815927, 75.64759208310035, 79.08038769998859, 89.04212536350374, 91.19169404429775, 81.411679790866, 70.03141695453276, 85.6917622781569, 94.14940434117472, 81.90221924935618, 58.559386345648, 30.72799501880523, 5.427208571664749, 0.6292974095671409, 0.3869549635677569, 0.28999820171344665, 0.18825512169109238, 0.1005422984880786, 0.1056090354799263, 0.16937473157961525, 0.059694927035560535, 0.0629153921298923, 0.30862474093033426, 1.7023788897260543, 37.757170661803215, 29.68196753532656, 32.924849833211596, 110.51362683696132, 127.47586957869993, 66.46727685005435, 19.636183284944106, 42.83623603082473, 61.07353148921844, 93.06171540291079, 86.37560398347917, 118.05551313584851, 28.919315607317035, 0.7697487213919241, 0.18094553972684568, 0.17107451214425026, 0.07475643013153346, 0.039501538830659086, 0.01996131718999917, 0.04900881637548728, 0.0074074501753784725, 0.032904035592031096, 0.050068756475323634, 0.07109743332670582, 0.08598908706898652, 0.0372337079006097, 0.02996603669148059, 0.02475783198831543, 0.01098724162851971, 0.0956936973717905, 0.005214915633381855, 0.04180270607673353, 0.04461136060736833, 0.020807252543407585, 0.042743852752591335, 0.04166409395815384, 0.02295928162282273, 0.039198083742972345, 0.037276869294263666, 0.11546001454154331, 0.20474055241192543, 0.18178181662674875, 0.20366147160530093, 0.20170525076889223, 0.13005615752791205, 0.1806495386746622, 0.19264298220795972, 0.33634983063224827, 0.22063474711631575, 0.20280803433589398, 0.15988740679477492, 0.2634086075329012, 0.2177921472297561, 0.2686536438282459, 0.24308466262394385, 0.2552530653173885, 0.22150594230380752, 0.2934339528362597, 0.35198629803715215, 0.5552604662314539, 1.089542625892547, 42.79665147104571, 157.00642185826456, 138.33772843883884, 132.28309508292907, 108.11356775222286, 68.74618960965064, 43.46478800619803, 57.71938331665532, 122.16222686152305, 93.14522266387941, 65.61096460588517, 69.74425238947715, 19.576753493278257, 1.809640637328548, 0.10995381887281135, 0.6702487927771384, 0.3684967491895922, 0.6417222525323591, 0.5591946648013207, 0.4614511612922915, 0.45835926107341246, 2.872173699640459, 2.033433551269193, 1.9171455718817252, 60.0532445599956, 114.05049862400179, 102.16268108737086, 94.16881222878733, 95.23032326852122, 86.89498070747622, 82.90565567631876, 84.61895481232675, 83.84787959437217, 95.72926444392051, 98.62180848275462, 98.53830122178601, 93.54596337964459, 93.56537911199754, 87.18175303551459, 88.5022738672072, 81.2523138907648, 80.75153704612487, 80.5199367769303, 78.32673565033944, 69.58413339430287, 72.4536923439272, 71.4199124613116, 74.66214364574802, 75.2717113494873, 73.9083896144744, 75.09139999266594, 73.83059332447668, 77.48635999618038, 73.47761923266997, 73.02455409880608, 72.5842680469636, 70.8497331988427, 72.75686017928585, 73.44106274266397, 67.07409104993268, 70.68764517384191, 79.92908662365329, 94.04839546449723, 91.08553117321384, 105.77566254523494, 50.73832142737604, 60.85866797354914, 100.67993102535125, 82.39580246710008, 92.61687940166843, 88.08199190324353, 94.07865262800648, 86.02132766477524, 98.74556710643154, 86.769621756769, 74.86726007153912, 64.57922827812934, 73.04793142503308, 71.781005859375, 74.50179715310374, 73.0625226420741, 75.62323416433027, 73.65858954768028, 73.95818802618211, 75.32801305094074, 75.01248974953928, 73.12080906283471, 85.44095023985832, 90.08537384771532, 98.74817940496631, 96.7229655481154, 86.84485281667402, 74.7602342790173, 81.05776433021792, 93.25573152111423, 94.85737646779707, 85.97171752683579, 75.44941825251426, 89.6124928997409, 101.34940116636216, 86.99333021717688, 65.40120801618023, 32.044154174866215, 5.263735459696862, 2.36077654746271, 1.211636326005382, 0.6377279313821947, 0.3875055662806957, 0.33581813496928065, 0.32857137221482496, 0.36269050752443655, 0.5277334562232417, 0.20759533309648115, 0.41517721368901195, 3.4510986218529367, 62.478948100920654, 45.375260768398164, 38.38458514982654, 151.60848740608463, 157.74489433534686, 114.72425199324086, 23.622927396528183, 48.906299990992395, 74.8740771508986, 107.68773171209521, 96.84211146446967, 131.5468426673643, 32.829412683363884, 1.283078498898014, 0.34210201713346666, 0.24839162946708743, 0.16145764189141412, 0.14631421335281866, 0.12734699483600356, 0.21727087036255868, 0.16702533909870734, 0.1394503719864353, 0.22231897609608792, 0.24109637334702477, 0.11657572967270691, 0.17618660154121538, 0.1981154087209894, 0.12029523210179423, 0.09811189220917803, 0.3412629057082438, 0.1381790031108164, 0.162940910686889, 0.12098653452290643, 0.1477685546682727, 0.09635485423308227, 0.13000194914638996, 0.0709008475044562, 0.14810249239446657, 0.08961406190909686], [0.06437058380294232, 0.022967241276356003, 0.04366115494180591, 0.03412601860961126, 0.04579929484715385, 0.058143824984830235, 0.017781846841136296, 0.03027919428272834, 0.08998496337763726, 0.04937946120457304, 0.03315094573002669, 0.041820306946793874, 0.03772193573475365, 0.06260604582606785, 0.034712945381479884, 0.017298037419095635, 0.08132814685063017, 0.09018826013010356, 0.01651951397258428, 0.08867732023880368, 0.026486009517083728, 0.12070045430934238, 69.71014345845869, 122.70827570269186, 106.2844959382088, 90.69814220551523, 64.83404505637385, 42.32526102373677, 36.77912765933622, 61.343100301681034, 53.40061449235486, 39.642991327470355, 45.03271233650946, 13.248503438888058, 0.03172420273204485, 0.10957648992658624, 0.1088850572705269, 0.09712412142224851, 0.22931524342106235, 0.08190998296824195, 0.049229633558781884, 0.12299252043087637, 0.12011745373808569, 0.3993286931466672, 0.36308740235624776, 15.625770611147727, 81.49688936048939, 100.6050294445407, 93.26538839647847, 83.53352515928208, 76.57867646986439, 71.8542992684149, 70.93277762013098, 69.82169566615936, 73.35187588968586, 80.98657331159039, 90.05496763413953, 89.72734774312666, 84.93447026898785, 87.82859894537157, 81.46911897966939, 76.61604881286621, 80.41540561183807, 80.08313378980084, 79.3212055390881, 73.79485268746653, 67.22253707147414, 61.83837013859903, 67.14176762488582, 65.55487863479122, 65.93580353644587, 65.94225191300916, 66.75209583774691, 67.55243193718695, 70.85203170776367, 69.10416864579724, 68.42552800332346, 64.68215911619126, 68.7393097723684, 63.55750183905325, 65.30379595295076, 66.305949764867, 69.35884814108573, 61.1237927406065, 73.36133664654147, 73.71213774527274, 92.55936961020194, 60.56642393912039, 50.94386931388609, 91.30773344347554, 73.80743565097933, 80.05273542096539, 78.81386264677971, 85.16141860715805, 79.04984812582694, 86.1512993228051, 79.04958140465521, 77.5245403474377, 63.11249717589348, 64.77452701137912, 65.50003997741207, 68.44719517615535, 65.78648282635596, 68.18097606781991, 66.95687493970318, 65.85057827734178, 65.35287264854678, 62.204605763958355, 71.60866475874379, 86.13821429591026, 84.37581493008523, 87.12163879025368, 78.88404169390279, 77.43016812109178, 77.06249298587923, 77.33541150246897, 84.43286188187139, 86.7262246531825, 81.60942216073313, 69.4100272270941, 72.05073941138484, 84.22030079749324, 85.0363342223629, 85.01272155392556, 74.48551931688863, 34.54522801983741, 1.3446526013074385, 0.6563575962378133, 0.6994613187928355, 0.09918681315837369, 0.1785929603201728, 0.023399102276251204, 0.24599518386587022, 0.1793033230088411, 0.10162966070516456, 0.1488474516137954, 0.16820900622875462, 3.973293078522529, 39.00514725715884, 84.33955654021233, 119.83347646651731, 101.46130638737833, 138.0402872639318, 59.09249920998851, 36.60412719172817, 55.468903818438136, 57.188023751781834, 79.87163174536921, 83.91905492351901, 72.21033280895603, 0.6730586194222974, 0.06568607168212053, 0.04555350702796732, 0.04174936337456588, 0.03753925057789011, 0.02474163305915652, 0.07636188229005184, 0.03065173517942669, 0.019013469160023718, 0.014476398655754185, 0.006124035045955211, 0.028465427495839617, 0.04887377805707436, 0.009609058071228286, 0.050217749085277326, 0.07953877996412978, 0.03913238787302568, 0.03572991944008297, 0.0595621754896016, 0.05690127250648314, 0.024174459864415472, 0.008080984623501859, 0.027600054576572393, 0.014043093580121716, 0.017240912157801852, 0.015825247748815004, 0.03634835923871687, 0.01711320913126392, 0.020766582850727345, 0.0222376765938656, 0.04118697439891197, 0.022798297821634242, 0.022062215646128022, 0.07381002809251509, 0.04477464075710985, 0.09229396770317709, 0.0649800910163791, 0.09781288809233135, 0.023777086227651567, 0.004877577434414097, 0.05984065994139641, 0.013355099701232487, 0.0636493924614643, 0.10026361868386308, 0.08039361917443814, 0.048430381688259305, 0.04077787961690657, 0.3658731431970674, 94.68125420231974, 135.3988847424907, 121.72331363924089, 99.15997335987707, 86.70009382309453, 58.95197245382494, 47.48366025186355, 41.75545438643425, 74.42075314060335, 51.22685263233801, 41.54030453774237, 18.95850362316255, 0.3193889504238483, 0.12383679528870892, 0.347733989117607, 0.022516241484892466, 0.14055176127341487, 0.07287094985405285, 0.13657951877722818, 0.17189798005405935, 0.26648610529880373, 0.6713589461099717, 1.2361379015830256, 19.62755799293518, 86.36504496297529, 103.99509476077174, 95.95176481431531, 86.87318017405849, 79.70333068601548, 76.12084173387098, 73.95516780114943, 72.37741793355634, 75.978530299279, 86.36650408467939, 92.32197992263302, 93.42637031309067, 87.69312812436013, 92.82145454037575, 85.80201225896036, 82.7903772169544, 84.47050879078527, 83.7323030348747, 81.56196148164811, 78.26735881067093, 71.21584723072668, 66.46790442928192, 70.1122413143035, 67.888273116081, 68.80625678646949, 66.75184480605587, 69.64627942731305, 71.37771560299781, 71.76225692995133, 70.87661712400376, 70.64472659941643, 66.96286832132648, 70.2851786152009, 66.86306753466206, 68.7088643350909, 67.9684228281821, 72.43937569279825, 64.9554737921684, 76.78844482667985, 75.6278782506143, 96.4665602099511, 67.6580927448888, 52.246790470615515, 92.66598747622584, 77.77003365178263, 85.22501591713198, 82.4998394135506, 87.66487136963876, 81.82883170343216, 87.38717540617913, 82.00973926051971, 79.40818017528903, 68.03342434667772, 65.88686804617605, 68.08563893841159, 69.59073866567304, 67.9535884241904, 72.86383105862525, 70.07651636677404, 69.64155689362558, 69.97531137158795, 65.76405471371066, 75.85717216614755, 89.98855406238188, 88.48590973884829, 89.46222689843948, 79.47539391056185, 77.34358572190808, 77.94841520247921, 80.01373921671222, 86.27573259415166, 90.51078627186438, 86.27763102131506, 74.89509321028187, 74.08353128740865, 88.28029124967514, 87.75411313579929, 89.91687666985297, 79.66890796538323, 43.92239524472145, 2.018020597677077, 0.6867076708905159, 1.4497477296859989, 0.06976264769271498, 0.298179101439253, 0.1523574672999882, 0.45116808565874256, 0.08912620945803582, 0.21217407208056221, 0.1862402338414423, 0.3366076651840441, 3.943741696496164, 34.549974087745916, 60.38780704621346, 128.10893227977138, 97.36698735144832, 108.87722969055177, 31.854990028565933, 42.36690090548608, 65.96017714469664, 66.7558926920737, 90.47287264177876, 93.48750437459638, 91.42493386422434, 1.623872773301217, 0.015347714502094014, 0.06340805561311784, 0.031546901258069186, 0.08765145956027894, 0.05008395182930174, 0.0467840817216183, 0.04797385074198247, 0.03125429397539026, 0.01183548960984955, 0.021016760353719997, 0.007955779522402033, 0.09920460171997549, 0.01746170635845873, 0.062047288107175025, 0.010485214635639662, 0.03365187147151559, 0.04816510459227909, 0.09250387579442994, 0.04730778708753567, 0.04272961500851859, 0.050322699300464124, 0.05060751929939274, 0.02433134126476944, 0.017951464453231425, 0.07725193090136014, 0.19365984135337416, 0.1586484281165946, 0.20099085845774223, 0.10229516128498702, 0.22018494625245372, 0.21686749442690806, 0.16397761150954232, 0.15716800916819804, 0.20194456131467897, 0.19341355940747648, 0.13538206206454387, 0.15870200830601877, 0.10607221989982552, 0.23317621930712656, 0.14318394745069166, 0.14555235423388022, 0.14462285975535072, 0.14127275726247218, 0.18384948793438174, 0.183538333663056, 0.17288526820559658, 0.7355457147763622, 109.64880697188839, 152.7966203997212, 134.0859576194517, 119.17143529461278, 91.84475298850768, 62.5013840583063, 53.57996486848401, 88.23541933490385, 72.06324392749418, 57.92538227573518, 70.28752419256395, 25.366815136324977, 0.9838191828420086, 0.27192119268640397, 0.9163424649065541, 0.32165179029107094, 0.4589181068924166, 0.14286550002232676, 0.3595892916763983, 0.6070818403555501, 0.638394121441149, 2.1738354044575847, 3.131022429273975, 20.523039025645105, 91.081710784666, 109.78427779289984, 103.82344399729084, 89.77944466375536, 85.11763711129466, 79.98767898928735, 80.5923515750516, 76.57649563204858, 83.2023516008931, 90.47957989477342, 99.40132464132002, 96.91532642610612, 88.79149375423309, 96.75682344744283, 91.63390205752466, 85.6280472970778, 90.58672335840042, 86.250747096154, 86.68100756983604, 82.61265462444675, 73.82695336495676, 69.82691241848853, 74.1147376644996, 71.21339967173915, 72.11335612881568, 71.35880193402691, 73.58517062279486, 77.16939326255553, 77.19379040502733, 74.90988839057185, 76.34591517909881, 71.55372804211032, 74.14850927168324, 69.61216265155424, 73.86390993672033, 71.87520550143334, 77.49396154957434, 68.78700579366377, 83.67154552090554, 81.82553691248741, 102.18564264235958, 72.17219952614077, 59.26892742033928, 96.34547664273171, 84.76163494971492, 86.63144450033866, 88.5813331604004, 90.57191248862975, 84.91717261652794, 90.69596136769941, 88.14649920309745, 83.7986695381903, 71.88028104843633, 71.02237239960702, 72.1066802547824, 75.32784046665316, 71.50514556515601, 75.3703668040614, 74.51767490756127, 73.63355698124056, 73.91829752152967, 69.13368055897375, 80.93639835234612, 94.9118346552695, 92.50441720408779, 91.82139919650172, 81.42084244758853, 80.46428618892547, 81.2446495794481, 82.02713104986375, 89.86886685894382, 95.30205557423254, 90.09639570789953, 78.41902902049404, 79.64021190520256, 92.3404307519236, 95.94617935918993, 97.30970505745181, 84.82029791801207, 45.41746154908211, 2.2984900445707384, 1.7807588774350382, 2.6368175158577585, 0.2649842052450103, 0.3966172628345028, 0.31164085973174344, 0.5083206656479067, 0.3150185107463791, 0.2907750148686671, 0.26575629929861716, 0.6116761002809771, 6.1197427395851385, 71.69967943622221, 97.6713554320797, 123.26724483120827, 105.84970120460757, 145.67033275481194, 80.35224760732343, 52.48539609293784, 76.4969107412523, 78.13147221842121, 103.82858230221657, 104.71110774624734, 100.02237704492386, 1.7922296038558407, 0.26858383789658546, 0.1392383954577869, 0.18976534145974344, 0.23093627014708137, 0.1046724010619425, 0.10198519444994389, 0.156116645422674, 0.18293733768645795, 0.12816768950752674, 0.08848461848233016, 0.11899767834092341, 0.11461542558766181, 0.23586026963687715, 0.1616641332305247, 0.09436825034959663, 0.0962719941631921, 0.10100762795416579, 0.23204910478764967, 0.271317454115037, 0.08269968172234875, 0.13709891106813185, 0.15848545057158317, 0.14477877396970026, 0.13240247033536434, 0.20721671712254325], [0.02308755538486425, 0.030825240687737544, 0.03823450984313123, 0.011928087614867236, 0.009198399512247454, 0.02875045433850779, 0.035134546548849156, 0.023232633285524867, 0.08367817518451522, 0.01926036206104102, 0.04270793855070107, 0.06087405126421683, 0.03275818011212734, 0.049104600348660064, 0.04850786382092103, 0.10114946913334633, 0.05142080207024852, 0.026913990281642448, 0.1271123497656757, 0.133578292725067, 0.6468212724693361, 10.33394705864691, 107.92395253335278, 97.32129173894083, 92.04407999592443, 79.96482726066344, 47.81370809001308, 32.86751262603268, 52.972256368206395, 60.040253669984885, 38.2040580626457, 56.602527633790054, 29.691995074672086, 0.21782993068618162, 0.06993746895703577, 0.03960878347917911, 0.08268622921839838, 0.061022611034493295, 0.06085186918836929, 0.049587205097439795, 0.13354372683792345, 0.09291381710359166, 0.20935221785499206, 0.649792896884103, 7.746831611279519, 53.67008916793331, 96.94598367137294, 97.51695525261664, 93.28546308702039, 92.58461398463096, 83.87483412219633, 71.89399365455874, 66.94528825821416, 64.80680027315694, 68.1617799881966, 78.32374680426814, 90.66862244759837, 88.19996895328646, 85.6577004155805, 85.68206617909094, 87.35658091883506, 82.15389420909267, 85.43797708326771, 84.60452833483296, 85.3266445282967, 78.60528669049664, 72.60165199156731, 60.83672231243503, 64.0759450389493, 62.5215175844008, 64.59613369357201, 60.75426624667261, 64.7781865827499, 64.08413102549892, 69.46546600710961, 66.60732115468672, 64.51605066176384, 63.04129439015543, 67.23997592926025, 63.18646915497319, 64.6486581525495, 71.907588589576, 76.28423983050932, 67.86099695390271, 65.87667772846838, 65.05809868535688, 85.93788316172939, 68.3716111029348, 50.717921180109826, 87.34854005998181, 71.91828097066572, 77.40805379806027, 78.16755017926617, 82.77890820657053, 76.84877087993007, 85.62214020759829, 85.69509629280337, 84.84811536727413, 74.70606634693762, 64.08062442656487, 62.27689896860431, 66.43211672382971, 65.4920893330728, 65.78787919013732, 66.42369931743991, 64.008970568257, 64.15249401523222, 64.104437135881, 75.49572575476863, 81.36118319726761, 80.73159571616881, 78.7169957930042, 79.58986436167072, 80.91229931000741, 79.39144734413394, 81.53172785235991, 81.6318973418205, 83.44446382214947, 83.42814676223263, 71.09930576816683, 61.88968650756344, 76.7508057625063, 81.43125241802585, 82.91097441027242, 80.76597136835899, 88.44077110290529, 40.48941919880529, 0.13716980484464478, 0.4110212173433073, 0.06921526254905809, 0.08307164039222464, 0.14957800838014773, 0.02968893694360891, 0.12538593232391343, 0.05146829569111428, 0.07887753117228709, 0.10648108868589325, 0.09288934825529015, 4.655080197318908, 40.198249893803755, 64.55720416961178, 97.53171905394524, 84.00927728222263, 110.77609615941202, 28.904977383152133, 21.325832489998113, 42.05079709329913, 78.84871682813092, 74.22395998431791, 94.63409162336781, 26.50328463123691, 0.8797088145248352, 0.1665200734691274, 0.047639173740941676, 0.07275665719662944, 0.07270966536335408, 0.038768557396026394, 0.037929154857392275, 0.021168673673885006, 0.03169612752483978, 0.04449490758199846, 0.04426271782346791, 0.053770075807528156, 0.06423328169471314, 0.0565994989817902, 0.0854283260301717, 0.020236589818171436, 0.06391535137569712, 0.035692626279928995, 0.06151232890964997, 0.03585133288476256, 0.0619589964739017, 0.013758163456053985, 0.029530967698402466, 0.0398126854411056, 0.04966557206165406, 0.12634810811329272, 0.003863126677911609, 0.014270713624183931, 0.030647322512982838, 0.018285760325529886, 0.025113141652376905, 0.04385480664730553, 0.10200748760854045, 0.025276274330193, 0.05757938289353925, 0.026150156571079167, 0.02603943005294329, 0.034683458657274326, 0.040505048893992944, 0.024108597370345267, 0.06295552364580574, 0.019950641754774318, 0.05090689496888269, 0.13361924778549902, 0.16981792876556998, 0.8987408900453199, 17.20535320620383, 131.0927341830346, 106.8469795103996, 106.51260529795002, 94.3394196418024, 69.14990348200645, 41.437303097017356, 49.60269720323625, 52.80226868967856, 43.696988398028964, 49.940009270944905, 38.18872944001229, 0.10022513042654722, 0.13841829833484467, 0.28676117379819194, 0.057505723539619684, 0.3743200592937008, 0.38519764980000837, 0.4026330142251907, 0.24600592441856864, 0.10378659657773473, 0.2710267084260141, 1.177926496151955, 11.35403786936114, 56.46909644526821, 95.33610959206858, 101.49055942412346, 96.19644226566439, 95.74058440423782, 88.62430664800829, 74.05776916011688, 71.49360595210906, 69.43593840445243, 71.41566845678514, 83.67963344820085, 92.42475386588805, 93.08469264738022, 86.44758732088151, 89.16820603032266, 91.84616504176971, 85.2347198609383, 88.13823869151454, 87.11666522487518, 90.50214921274494, 83.24958478250812, 77.95591477424868, 62.93601012999012, 67.87160304284865, 65.6626457552756, 68.4248847346152, 64.71437354241648, 68.4014211162444, 67.90517068678334, 72.9523354191934, 68.92074292705905, 68.63085623710387, 65.87749358146422, 69.65373193064045, 66.84311051522532, 68.38027954101562, 75.09746397695234, 79.09412384033203, 73.22189638691565, 70.16721725463867, 69.22838226441415, 87.00228891065045, 71.56667970841931, 51.78315062676707, 92.03505854452811, 76.2552535149359, 79.5734453201294, 82.32867502397107, 87.87424748943698, 81.31413828942084, 87.95430306465396, 88.52492163258215, 86.53856277465822, 78.85640467366865, 65.95119491700204, 64.63526325841104, 68.31743532611479, 68.42937192609234, 70.3762403611214, 68.97992364821896, 65.85108034072384, 66.63371086120605, 67.51803275077575, 79.82549682740243, 84.99155644447573, 84.00696308382096, 82.61521200979911, 82.42423180610903, 84.91956526233305, 82.4190935011833, 82.12657097847232, 83.9718343365577, 85.84838251913749, 86.71507727715277, 73.99603105360463, 65.74008903195782, 80.96803619015603, 86.40615924712151, 87.61191937231249, 87.80742599118142, 93.49654151547341, 50.74007472684307, 0.5438096580966827, 0.25365142061585383, 0.2881813475922231, 0.1376707190948148, 0.4220231592414841, 0.23739506550613912, 0.04555469446424996, 0.1330645541630445, 0.24219888112237378, 0.044527703806036906, 0.2377387938360053, 4.723335321872465, 39.74609082744968, 69.35706738502749, 104.61610794067384, 78.75966333573865, 78.05395833907589, 24.663763623083792, 40.19166423428444, 50.73313605400824, 89.86726653191351, 83.73799047162457, 111.7207048785302, 36.66108785137054, 0.8604280362206121, 0.23172817523441008, 0.08160260551038288, 0.029653509207550558, 0.045224790190977436, 0.04007678659212205, 0.09908021202371006, 0.0553447925185244, 0.04969172247294938, 0.02014257933854336, 0.09342234626772905, 0.03479153068075257, 0.049695422677623655, 0.022603100533747388, 0.06858905461887199, 0.04000578939373936, 0.043658764747482155, 0.04534652539258523, 0.016869591256122918, 0.05546018068167952, 0.00840117968994403, 0.01450933947888834, 0.04591484388877307, 0.032876923740390813, 0.021091647363538225, 0.29129855935612037, 0.10788404082338657, 0.11929862066021851, 0.20807562425972956, 0.17301181060892923, 0.1369158620195043, 0.15356506701679, 0.2678742872611169, 0.1698511156944498, 0.16206023133089467, 0.15946055792512434, 0.11542352577370983, 0.1611279329705623, 0.2141381376573155, 0.27315585062869135, 0.19684213994731828, 0.10097618770575333, 0.3377375529418069, 0.28860067347845725, 0.4723048804988785, 1.1086947014254909, 22.906235841012773, 150.53579761135964, 124.28686495750182, 124.19759181237991, 104.7538145126835, 70.55659094164449, 46.430935321315644, 76.46830097321542, 78.9126043934976, 56.214283589393865, 90.53392825588104, 48.159582691807906, 0.6613809879749053, 0.3382723742435056, 0.548919893560871, 0.1895505610492922, 0.4592936125493819, 0.39682462751384706, 0.392694708801085, 0.40083276889016556, 0.40959938879935975, 0.9996285409696641, 2.9242220809382777, 11.002823941169247, 60.04654515174128, 98.82167677725516, 104.5745857300297, 100.80857692226287, 102.71062835570305, 94.7893233453074, 80.39202828561106, 75.54313936541158, 71.61648596486738, 76.56068848025414, 89.01608867029991, 100.86221141199913, 96.25208500892886, 89.24474716186525, 92.07956175650321, 97.48781204223634, 90.90267812052082, 94.51356503271288, 90.47207247826361, 92.4108765202184, 87.0948019335347, 81.44580441136515, 67.85858077387657, 69.92476770954748, 69.96938859262775, 71.52286683359455, 68.14617679965112, 69.78850456976122, 70.84918406701857, 76.58043369170159, 72.34236763369653, 72.07192805505568, 68.99079645833662, 73.91293956387427, 70.85852715276903, 71.78433987402147, 79.39733874413275, 83.35990536597468, 75.86135341275123, 73.63204294635405, 74.48558991955173, 91.81717088145595, 76.097942936805, 58.98883881107454, 95.78293815735849, 82.2976569206484, 83.4749641726094, 85.38916710884341, 90.46306671634798, 82.08285224053168, 91.02663286270635, 91.90630282125166, 91.6731414487285, 81.46566729391776, 70.1064048274871, 68.53372266215663, 71.51754809964088, 71.36292042270784, 71.86033187373992, 73.97799599555232, 69.14710290970342, 69.35120736399006, 70.96632172984462, 82.20719921973445, 88.90037875021659, 86.73127666596444, 84.98380584101524, 83.20079049756451, 87.85850309556531, 87.36100535238944, 84.20246185794954, 88.21765099802326, 92.01749417089647, 91.58882617950441, 77.1314404087682, 68.40673985019808, 86.03733877981864, 89.016386770433, 93.51025412159582, 91.89732059355705, 98.95442547336702, 51.60254509218278, 0.749880200432193, 1.5064237723427436, 0.5363140086973868, 0.3035683767689813, 0.3395840393439416, 0.32836121897543635, 0.29306736444273307, 0.3377836101478146, 0.49409591442634987, 0.32180893024609936, 0.4061176111140559, 9.482298512612621, 62.377845087359034, 71.6090020825786, 109.16008749315816, 94.69090323294364, 128.91491659225957, 41.98557592207386, 38.3873543431682, 60.15922700205157, 101.63527919400124, 93.91428962830575, 122.5715732574463, 38.84707181684433, 0.9992693989507615, 0.5066842405546097, 0.21837222900602127, 0.30377681397141953, 0.1486696272848114, 0.13573768007899487, 0.20206434682251947, 0.15458589449765223, 0.11002500376273548, 0.1627606808418228, 0.23563539218758386, 0.12973536587049886, 0.1477499387317127, 0.1895660973123966, 0.15088958155003288, 0.12042982608921106, 0.10544695425778629, 0.22521431347535503, 0.08495534334572093, 0.16955249462156527, 0.14411485153100184, 0.19166113328068488, 0.14112318625613568, 0.17292495156007429, 0.10446719675054474], [0.025706490156270807, 0.03963812081623943, 0.01794664192974808, 0.03510743086676925, 0.06877222624156745, 0.007239503113763228, 0.05824543122622756, 0.02295488810857698, 0.015970584204150064, 0.008672475364179382, 0.0472475687462476, 0.10114366218688027, 0.033234311417946895, 0.09732762501845438, 0.018101768988755443, 0.06875612307339907, 0.10829872421679959, 0.05062440004680426, 0.08891213384847488, 0.19831384081513653, 0.1234996093497161, 47.8694998833441, 107.94951069739558, 94.21095417391871, 80.76464560724075, 50.87983269845286, 34.051268254556966, 56.10537505918934, 80.9894915549986, 58.03124312431582, 67.72014464101484, 43.77611829388527, 1.2326145100016748, 0.1967750153233928, 0.1668816363258708, 0.1959305259609415, 0.4419348569166276, 0.1500499185415045, 0.16861887859000316, 0.31960713226468335, 0.09945870542358007, 0.017387374762385603, 0.11301245555401811, 11.09480744408023, 59.20134890464045, 91.22221792897871, 97.37812688273769, 92.25511135593538, 96.99606449373307, 91.85181325481784, 89.22418609742196, 77.06509743967365, 68.74617392016997, 66.17684102827504, 66.28804806740054, 73.71562080998575, 86.78338143133348, 89.56244345634215, 89.34719947076614, 81.61149317218413, 85.41187763214113, 81.75868403527045, 84.15571505023588, 88.06796550750734, 85.20574139010522, 78.4277053033152, 72.18187993572604, 59.363891924581225, 63.27913515029415, 62.2161885230772, 62.04355324468305, 61.11057827549597, 61.63032370228922, 61.34553609355804, 66.86986107980051, 62.89890058578984, 65.43191232988912, 62.88413678446124, 64.44406340199133, 60.78286424759896, 79.41822928767051, 79.82637543832102, 86.08425817181988, 76.22904423744448, 82.43783458586663, 73.28374431979272, 89.23937351472917, 69.29912613284203, 39.76980155514133, 89.4434779690158, 72.66211925014373, 75.55350226740684, 72.83141659152123, 81.55192805874734, 81.27599716186523, 79.12307093220373, 82.54639010275565, 83.74658046230194, 80.16419349178192, 73.34266616452125, 58.78719760525612, 63.55238706834855, 64.94964907246252, 65.27697478571247, 66.20250117394232, 64.34942837684386, 61.0562377591287, 63.53122980363908, 76.60125363257625, 85.2763754321683, 80.06809542256018, 81.30619156745173, 83.8688015168713, 78.83786755223429, 82.04009056091309, 82.54664113444667, 81.9802979500063, 79.85550295922064, 80.88659209589805, 74.24674111027872, 65.3286559351029, 62.63525847465762, 79.35426327490038, 80.68625311697684, 84.05084656130883, 77.80775900809996, 98.08911923439273, 23.25041597889316, 0.7036808085057044, 0.25125230902866014, 0.2961997141040141, 0.13257652551176088, 0.23135862974149568, 0.20744488874991096, 0.15712815727437698, 0.18810106140951957, 0.2973372627410197, 0.20902506766780732, 0.15860246284113777, 8.89830074002666, 24.163322141093595, 34.688288627132295, 70.76203684653007, 88.45835901075795, 75.20875730822164, 19.979004321559785, 45.27478925643429, 65.49992622867708, 81.44672224598547, 87.97406396558209, 79.51446856221845, 1.6050501768627476, 0.04825222028058864, 0.03980463002658179, 0.009213158196108717, 0.022016847919252132, 0.018630934646353126, 0.013085190646140086, 0.054654746481608, 0.01777524890888843, 0.02778384098482709, 0.046106806370399656, 0.02583512206441693, 0.09675474446867743, 0.12088714993648952, 0.05879829389854305, 0.0678771750761136, 0.02607509527625817, 0.06233183614489052, 0.011965168185622222, 0.0911326320361226, 0.09115972856600439, 0.12357700721270616, 0.032891732219967156, 0.05670711135251388, 0.03613573919621206, 0.03404724561879712, 0.04752154094016841, 0.029389639798131202, 0.032150974992903016, 0.012945674543809748, 0.009639868212323035, 0.019122577317419554, 0.03328409181126664, 0.08546540468570687, 0.055812508348495736, 0.03267148960261576, 0.04082979739553506, 0.0433155037312498, 0.03755923781183459, 0.03738181184857123, 0.017791432516288855, 0.07357550559625511, 0.05496960478804766, 0.09136916168274418, 0.19784735455628366, 0.05843654718069781, 66.99273324781849, 122.90927363980202, 110.23618974993306, 91.13368218944919, 73.46290249978343, 52.61525792460288, 50.55186763886483, 63.79512294646233, 52.37637773636849, 54.624244936050914, 46.984032661684104, 1.1724583444095429, 0.22433060041118055, 0.08310108881203399, 0.8264815771291334, 0.633783865599863, 0.5913890501664532, 1.2508031533610438, 2.838855616507992, 0.37656169384717947, 0.19997042934260062, 0.7306730891427686, 15.506391313768203, 62.340798301081506, 94.62093599380987, 97.29691813069006, 92.38396121609597, 100.17804022758239, 93.95752983708536, 93.51173677752095, 81.46161156315958, 73.09926740584835, 68.93480070175664, 69.21857633898335, 76.67038148449313, 89.72330770184918, 91.00298097056728, 88.99619440878593, 84.74950698114212, 91.01809778521138, 86.47843283991661, 89.42479179751489, 89.28359431605186, 88.83790323811193, 83.95242644894509, 75.3337710903537, 62.678945833636874, 64.01343030314293, 64.11943627941993, 66.02062086905202, 64.0156582094008, 65.57473759497366, 63.78538762369464, 70.61349668810445, 66.7900957599763, 68.73871357210221, 67.2614626730642, 67.12509755165347, 65.89454804697345, 82.85053853065737, 85.49740883611864, 87.46816450549711, 80.82363805463238, 85.85199109969601, 77.81128914125505, 95.58110083303144, 73.55696878125592, 41.59533931363014, 94.63051442177066, 76.37674500865322, 77.89520432872158, 76.54251221687564, 83.6787469925419, 82.82207781268706, 79.31716549781062, 84.67326394973263, 87.10310951355966, 84.29047984461631, 77.15317818426317, 62.711230862525206, 65.39658354174706, 68.7095703617219, 69.1065691363427, 69.82069153939524, 68.1521858707551, 63.031351181768606, 67.34804507224791, 79.53549246634208, 88.78345289537984, 83.1683760304605, 83.79625335816415, 85.53222379376813, 83.80758900796214, 85.0611000676309, 84.49672591301703, 84.22616866327103, 84.58703456386444, 84.18121045635593, 78.46544634911322, 68.66947589382049, 66.37567381705007, 82.49616023032897, 83.57475711453347, 87.94523454481556, 82.94586781532534, 103.66177174352832, 28.797704481309463, 0.27321156054254503, 0.28740192973806017, 0.7550324175146319, 0.6606652779925255, 0.8696908359566043, 0.4142433218657971, 0.25166018956130554, 0.22703666810787496, 0.6966304706950343, 0.22380576889601447, 0.27294523773654816, 10.396926595318703, 26.04296115136916, 40.74241599728985, 80.50063087094216, 86.91275688909715, 62.3279917624689, 22.449505252222863, 55.42662851272091, 69.65188057191911, 93.49550600974791, 94.8945370028096, 102.7877970664732, 3.1804244364461596, 0.02014654767399113, 0.04498328863372726, 0.014214434890046477, 0.0657347642305878, 0.04961385729632551, 0.02582370352390553, 0.07628824591877, 0.025599002274834824, 0.053561098513103304, 0.05443417827688879, 0.01419518884616874, 0.03950251559276254, 0.07011556141679326, 0.0336356227466416, 0.05200785907706426, 0.026437550625433365, 0.022738606165794116, 0.07094154975587322, 0.13967915648414245, 0.044159491306110736, 0.023201895922782923, 0.04628344326310101, 0.026281739832953583, 0.07230710914178241, 0.1735489761396762, 0.12877224013209343, 0.15994967442126046, 0.09820281918491088, 0.16908706556404793, 0.1035463054394049, 0.17315975750886625, 0.09709504072464283, 0.2395037684829966, 0.16953657531449873, 0.14147947842796005, 0.17771065685777895, 0.2693724181623228, 0.20081655813320992, 0.1462905412359584, 0.1904430994463544, 0.14409620495092484, 0.11924925395437788, 0.16627602849996861, 0.29073713948169067, 0.18720103067255792, 80.39379335218861, 139.44098134194653, 121.3233966212119, 111.74620812939061, 74.00608016598609, 52.16295765292261, 74.72374839167442, 106.33012879279353, 79.08151734259822, 103.4141368250693, 70.18850003519367, 1.4845631776317474, 0.340737798401425, 0.23411668416473175, 0.7554556044840044, 1.139806573910098, 0.949817258984812, 0.971952480894904, 1.9687089275929237, 0.24165123550882264, 0.3724410294765427, 0.7685177100281563, 15.029131039496392, 68.97587576220113, 101.6544125157018, 102.6029279155116, 98.38869417867353, 105.51803342757687, 101.12257834403746, 96.03470725397911, 87.43261998699558, 75.43325808740433, 74.9128850813835, 74.05676503335276, 82.04005133721137, 93.29272731657952, 96.08524307127922, 92.66401060165899, 90.64648459034582, 95.50008819949244, 90.44499243459394, 91.17775394070534, 93.04792434938493, 90.3061483752343, 87.13491993565714, 78.41459674219932, 66.18230881229525, 68.83637274465254, 69.23355194830125, 69.06898498535156, 68.97247898963191, 71.18435059824299, 66.35800746179396, 72.05545410033196, 70.01801813802412, 71.29412204988542, 71.86674887134184, 70.05313904054704, 68.27963936713435, 85.13033774591263, 87.36044837582497, 92.80432162746307, 83.76679635817005, 90.73676186223184, 82.46789563086726, 101.17763273177609, 79.40981188128072, 46.214997076219134, 99.50275713397612, 80.27727542384979, 81.98731114787441, 79.55790488950669, 88.3642456608434, 87.74448763939643, 84.17694291760846, 87.99877489766767, 92.6780762210969, 88.68625656250985, 79.9817640550675, 66.20638432041292, 69.38414742869716, 71.75687543807491, 71.31949194015996, 72.95546547059091, 70.79409045557823, 66.86893540043985, 70.22401317473381, 84.78491029431744, 93.057236056174, 86.59261303563272, 87.00380294553696, 91.14676721634405, 88.93975934674664, 90.2167889379686, 88.63903122563516, 87.40502219046317, 87.73259501303397, 89.32157854880057, 83.25289526293355, 72.30168481026926, 69.34340184734714, 88.23393667897871, 89.33075689500379, 93.07173313633089, 87.61622613476169, 110.02172239365117, 29.43622712166079, 1.0961926367975052, 1.21486664299042, 0.9491697001841761, 0.9782074355790693, 0.5591291489620362, 0.6105924842338408, 0.5625873924263063, 0.46247643208311456, 0.734732558410014, 0.5813392023405721, 0.3969206336525179, 16.363193854208916, 41.49569934414279, 45.66108388285483, 81.11202639918174, 95.84820639702582, 89.29334532830023, 29.008159252905077, 63.425212060251546, 84.83114719390869, 105.94817623015373, 105.25318714880176, 109.02799775523525, 3.021021518976458, 0.21953596252827876, 0.16325673809455288, 0.1275525132434503, 0.12422778358262394, 0.3221023419210988, 0.10484533008909035, 0.1453224972130791, 0.12705198203724238, 0.1407052699716822, 0.2541346229132145, 0.1752456157438217, 0.17051847020704902, 0.23104885442843362, 0.1520218595021194, 0.19533680781962412, 0.12799210215528167, 0.10375258227389667, 0.2327096257959643, 0.23362290985401601, 0.1377406629223016, 0.18464243490128748, 0.13798996325462096, 0.15941686026992338, 0.18908531585287666], [0.052564268736469175, 0.06503407723240315, 0.02568303828968877, 0.03506871278307611, 0.10265162965703396, 0.08753771082528176, 0.038490674323252136, 0.07324470116967156, 0.0491931984171031, 0.03311171053698467, 0.066824815416288, 0.0749600716235657, 0.03291486807528042, 0.04230170127665324, 0.027169970900661526, 0.04682072753747625, 0.07376964759802626, 0.042826617061490976, 0.14025346195745853, 0.33670446805415616, 3.3274152586537027, 94.20312512305476, 102.08553591082173, 99.41949305995819, 87.05640192954772, 42.2739250429215, 34.89011418434882, 62.32120998444096, 70.38366933022776, 62.9934100950918, 49.756556095615515, 7.447894052151711, 0.1394381299014053, 0.1690839092817999, 0.11621258867483948, 0.13405695978191592, 0.45741050714446657, 0.41490439445741717, 1.698066121147525, 1.4939910846371807, 0.18446657175738967, 1.1404488620258149, 19.67372625104843, 72.07697222309729, 87.37805197315832, 92.30744361877443, 91.08532720996489, 95.36529202615061, 90.53728580474855, 95.72385941782306, 89.55391622358754, 86.65304107050743, 70.76019333254906, 64.72692904933807, 61.01145605887137, 71.92596097146311, 85.28961735387003, 87.40182153640255, 88.9062858396961, 82.34092066364904, 86.84243663664788, 84.33625390452724, 87.01186733861124, 84.18905519670056, 81.10002394645446, 79.54874223278415, 68.93145099762948, 61.558979711224964, 60.17712477714785, 62.30548520242015, 62.63313255002422, 62.671156006474654, 60.481787035542155, 62.64804540141937, 62.91732003611904, 62.70296250620196, 63.093410922634995, 62.43472729959796, 63.26090005136306, 66.83440285344278, 80.10713869525541, 79.75764766816171, 82.24017066340294, 80.78192757021996, 85.24307450940533, 75.6111297299785, 87.00657213887861, 67.12639977855068, 32.22141981124878, 87.96047687530519, 70.77737331390381, 73.61122300547939, 68.5546681188768, 78.1829023361206, 79.54561218138664, 80.89838274063604, 73.40580063481485, 79.24774739050096, 80.94014029349051, 79.78777931582543, 69.1155513640373, 59.48869389872397, 62.79993526397213, 62.977810828916496, 62.60476596893803, 64.2570722487665, 58.95459651947022, 61.816581372291814, 73.81944594844695, 76.51431822007703, 77.14845565057571, 74.40882129053917, 75.51336073106336, 74.35473180586293, 77.50853707713466, 81.00700886018815, 81.13248548200055, 79.46663133559689, 81.2325922135384, 71.79089023220924, 64.20598337727209, 64.14684580218407, 66.1416809020504, 67.26117241767146, 76.24593396340647, 81.00172150519587, 81.4762027802006, 84.81152749830677, 5.6132666910848315, 0.859196289412437, 0.3815328690313524, 1.5352356650175587, 0.5411441011294242, 0.30298124698381274, 0.2094487602552099, 0.24131873802792644, 0.26471494066138423, 0.1992634680843161, 0.1868370316562153, 0.23219438570161022, 27.535991745610392, 44.41697474448912, 70.3308585382277, 71.58772714676397, 94.64553709953063, 68.10801998261483, 47.015909764074514, 68.64182318410566, 62.103416458252944, 80.90733358936926, 100.57905550925963, 30.550139065711733, 1.205663291677352, 0.2457846169390025, 0.27264652473311274, 0.16268362771839867, 0.04584315338081891, 0.14420638371619487, 0.11432162320782101, 0.019740888796326135, 0.046781074826515494, 0.01888044948329128, 0.03137228875270775, 0.0037211035528490624, 0.01686091147994082, 0.08696719748719085, 0.01902396647980617, 0.09734658569458032, 0.02817942963672742, 0.10381049086009303, 0.029591775927392226, 0.06294262655560048, 0.03249442370067681, 0.005831148141183921, 0.08714423274561282, 0.06583408752997076, 0.044229538555467324, 0.013810538014607325, 0.03305317758913002, 0.027668494956507802, 0.08779104078008283, 0.020280141916666782, 0.07824282732702072, 0.010347846452327026, 0.08256303461929483, 0.012761697571183886, 0.029807083023291443, 0.0381700205616653, 0.043943768607512604, 0.0077034277661192805, 0.06521536427880488, 0.03611202877495558, 0.049379196904239156, 0.042115794720068093, 0.14883571514679542, 0.5194831795750127, 7.041161425652043, 117.42162673704087, 113.33813344278644, 109.1267708809145, 93.16304591394241, 47.83781105472196, 38.670678907825106, 45.515352141472604, 47.298540069210915, 65.81649288054436, 53.221295495187086, 9.607242672674118, 0.19060940181295719, 0.09662012749862287, 0.3305535174665913, 0.5939771403228084, 0.5063776521673126, 0.9792826553025554, 2.917098076112809, 4.338893034765798, 0.6755625011940157, 1.4586151054789944, 25.278636332481142, 76.48551233353155, 94.53846423856675, 96.76964959790631, 94.41813376642044, 95.02609329838907, 94.91312119268602, 99.57728216725012, 93.44573897700157, 90.22785786659487, 74.81433945317423, 69.26716666067801, 64.56944588691958, 74.25493886393886, 87.19724639769524, 91.6211151307629, 90.64036569287701, 86.45404354218515, 89.02498460585072, 88.1858797996275, 89.09407323406589, 85.51379649869858, 84.19464065182595, 82.48705248678885, 72.88061095822242, 64.94125520029377, 65.14478306616506, 66.62564646813178, 65.518498651443, 67.87608238958543, 63.399018472240826, 65.34406300513976, 65.4678726196289, 65.27852019956036, 65.19754678972306, 66.07897004773541, 66.3460599222491, 71.38535638009348, 84.80474964264901, 83.3396267121838, 84.64030819554483, 84.02717113494873, 86.8462884041571, 79.06943644246748, 90.36668623647383, 69.6028744789862, 34.1883433249689, 90.97078615619291, 74.28647472012427, 76.25801486353721, 70.09370419286913, 81.96573026718633, 81.890514896762, 84.34493018734841, 74.64927042684248, 81.33024354134837, 84.42166743739959, 83.3892603843443, 71.95304885987314, 61.88618383099956, 66.16494055717223, 66.83623067794308, 65.30248980368337, 64.75980243375226, 63.2238022742733, 63.95515172712265, 74.83934064065257, 80.46829485124158, 81.05748976430586, 79.04622385578772, 80.39719796949818, 79.87590712885704, 82.10528819791733, 83.92016103190761, 83.33709286105248, 82.19274136327928, 85.48641835489582, 77.15502169824417, 65.97296407145839, 68.13940678873371, 67.34828041445824, 71.07213943235337, 78.20966074543615, 85.13113790942778, 85.00128392250308, 92.26727070346956, 8.94159488139614, 0.5131841288699258, 0.5815207345351097, 2.453250836941504, 0.8146879906135222, 1.3800115426701884, 0.14440876882403128, 0.9333388915946408, 0.8425299546891644, 0.2667336742724142, 0.12710674966294921, 0.12772985493704198, 27.15804784528671, 36.412087948091575, 73.77127924273091, 80.62498569488525, 82.14126417713781, 55.70814878709855, 62.218604703103345, 74.62669326413062, 71.14412276975571, 87.55551568923458, 113.4725687580724, 42.679682470137074, 1.329283896953829, 0.44586188490352324, 0.28306743490599817, 0.1712834856082355, 0.017183043791221517, 0.15824921969925204, 0.09848924413804086, 0.12694069244448217, 0.0782030213984751, 0.026567069280351845, 0.08900861496165877, 0.018752028249324332, 0.03745691144778844, 0.057329071325159846, 0.038525845419855854, 0.07646158097251769, 0.05387887944497409, 0.04765642604099647, 0.01595524233585644, 0.014540141959103846, 0.048971297219395644, 0.029685462734872298, 0.06741495592699898, 0.04387241517824512, 0.15435789140962786, 0.08406651281421224, 0.10409788108400761, 0.11369083407184771, 0.2130013704299927, 0.13175236812281993, 0.1291390583519974, 0.12837677788470062, 0.19528727257444015, 0.07055367177893078, 0.19403326325118544, 0.12531716827183, 0.20352581275566933, 0.17534957387514655, 0.14308483099504826, 0.18183918129051888, 0.2112092149834479, 0.18729492240855772, 0.44155365156550563, 0.7412338869706278, 9.099260434027642, 136.7857877669796, 128.1389227221089, 127.93572825770225, 109.79547223737164, 61.81186668334469, 50.01944118930448, 87.11931674711167, 97.5246980113368, 88.40415185497653, 76.15113812108194, 12.858939516928888, 0.4888635339035142, 0.30119059306959955, 0.3878520218835723, 0.9114013816560469, 1.4775677530034896, 1.489147447770642, 6.469965288715978, 8.127565297388262, 1.4886399911295984, 2.9188273510625287, 24.182147556735625, 85.9093047726539, 99.91293507237589, 106.06323503678846, 100.06918661056027, 99.92886774001583, 96.93838996271934, 103.65962228467389, 98.55759143829347, 94.08312413000291, 79.34952505173223, 74.11110554972004, 69.5306008861911, 78.24094556993055, 93.83148054922782, 95.37853394785236, 93.73244070237683, 90.47899938398793, 94.35602695711198, 92.71980239499001, 93.7503973130257, 89.97914821870866, 86.4223272569718, 88.45395811142461, 76.51496933352563, 69.17258262634277, 66.0759812016641, 69.48723516156598, 69.66152175780266, 71.28945442938036, 66.11808392309374, 69.60926009762672, 68.42234303874355, 68.25313983425018, 67.18197191915205, 69.386351800734, 68.96760740587789, 74.00491129967475, 86.20793834809335, 85.19249162366314, 88.43018854818037, 89.68447623714324, 90.70793244146532, 81.34223030459496, 91.51659965515138, 74.30949903303578, 40.41327030427995, 92.38315320784046, 78.82955212746897, 81.00442009587442, 75.47543925623741, 86.16886369643673, 87.6335394767023, 88.88630528603831, 75.32961337797104, 83.54589631480556, 88.30260169121527, 87.27483087970366, 76.02020940473004, 66.62579551819833, 69.27378762152888, 70.5226702843943, 68.60922044323337, 68.68164308609502, 67.29896053191155, 68.47054896816131, 78.54215222020304, 83.79290365403699, 83.60513979388823, 84.63412654015326, 82.19239619470413, 84.61005887677594, 87.0611087737545, 88.80065641095563, 86.35468990572038, 84.58190410367905, 91.15639271274691, 79.77824795630671, 70.45811591609832, 72.5798043897075, 70.03100902803483, 74.36480445246544, 83.87330439782913, 87.72459337788244, 89.1523753443072, 94.99312969946092, 9.38507080078125, 1.5059114127389848, 2.9852159177103355, 5.092775523662567, 2.3815084801566218, 1.0177411271199104, 0.8403100770327353, 1.2534882608921298, 2.110911516412612, 0.3570544293090221, 0.3836676189976354, 0.5093329435875339, 43.65925519697128, 62.942227086713245, 81.69820893195369, 81.67087001185264, 103.9904506744877, 81.21812651234289, 65.29250344922467, 88.68922971910047, 84.92717466046734, 98.99825403767248, 122.2576738172962, 45.12374270346857, 1.4520974745673518, 0.586009213039952, 0.3959980492870654, 0.40624138027910267, 0.1788011983397507, 0.2698663916558989, 0.24008835485625654, 0.21029003204837923, 0.16212585442248853, 0.11339224364248016, 0.2318788340855991, 0.19960552634250736, 0.20900289708327865, 0.2340430784369669, 0.09612695839736732, 0.14307808942131459, 0.16979488484080763, 0.14126800751734164, 0.05978612214206688, 0.10066259727482835, 0.1587188162750775, 0.13747501427367811, 0.20182339684857478, 0.20074860613432624], [0.07823744172891302, 0.022232857900821877, 0.06441831108062498, 0.09017476932175698, 0.02152472261279341, 0.03448213458121304, 0.05976220870751047, 0.054375086084849415, 0.027260744658809517, 0.046193178953422655, 0.043782357712306326, 0.0780952251666496, 0.03379278568430774, 0.12079090631056218, 0.0812485120109012, 0.01947969303376252, 0.017427218995327433, 0.1384057957799204, 0.11362567063300841, 0.32721496757961094, 19.314482250521262, 101.6307370893417, 91.12547659104871, 84.03253693734446, 71.58677793318226, 50.41052502970542, 87.61862662530716, 159.23622654330347, 111.98931663267075, 53.38149686013499, 21.234454993278753, 0.1441914296799129, 0.06390484831025524, 0.14950264065015703, 0.17761252099467864, 0.842094939322241, 0.1622729433039504, 0.45566033331617234, 3.971419656468976, 6.226616049966505, 1.861978661148779, 23.33958714239059, 82.42588704632175, 91.11605505789481, 86.9511490483438, 89.1620949775942, 89.70130320518248, 90.91765372983872, 90.23375711133404, 90.3033007344892, 94.24105444262105, 88.22408368510585, 78.40522227748748, 64.61898149982576, 63.44174877289803, 63.27161596667383, 76.42319371623378, 83.49914166235155, 85.07929986523044, 81.96653827544182, 78.82063265769713, 83.10994055963333, 83.6194093765751, 84.12970973599343, 86.28776642584032, 78.19978421734226, 72.39563342063659, 69.49473473333543, 65.34123105387535, 64.27152618285149, 65.02629610799974, 63.32940816879273, 60.745640954663685, 61.320299563869355, 61.08014852769914, 66.04122115719703, 60.72087510939568, 65.69854720946282, 63.24779149024718, 64.61592597346153, 76.44206031676262, 79.97835159301758, 76.98722270227249, 77.58228548111455, 83.52189925409134, 79.13933307893815, 78.09167585065289, 56.48515855112384, 27.98302035177908, 82.87972880947976, 74.93217529789095, 75.7140370338194, 66.09513805758569, 70.92299522892122, 75.95588253390405, 75.06253919293805, 73.64476711519303, 71.9254824423021, 76.72539664853004, 77.61135808883175, 75.80547532727643, 63.62589620774793, 57.13983351184476, 63.70544579721267, 58.812736157448064, 62.47110728294619, 58.54455978639665, 59.955287287312174, 64.20287293772545, 71.7061278127855, 71.22089924350863, 76.05422419886436, 72.78220653533936, 72.94139985115298, 74.3053726996145, 75.50587684877458, 79.2844529305735, 81.13461140663394, 78.63845425267374, 78.59243700581213, 64.00715058849704, 62.29473398577783, 66.00307218490109, 65.63733470055365, 75.41229694120346, 79.96405847610967, 81.12364445963215, 89.09585399012413, 59.84184449718845, 1.239877881542329, 0.6035806959675205, 1.1552408553900257, 1.2876658333886055, 0.5375270016731755, 0.3516071458016673, 0.3995488668161054, 0.17711367518190416, 0.11658827819290662, 0.026906365791576046, 0.16194078290174085, 1.4495408246594093, 25.3426690255442, 41.65131938072943, 83.46039648978942, 70.08156837955599, 45.381713067331624, 18.92603816524629, 40.16609822550128, 63.43916393095448, 77.23274738557878, 92.50637838917395, 53.98748343990695, 1.3105274905120174, 0.11775306891649963, 0.02668795029392406, 0.02920028967632642, 0.04342862810458868, 0.05176161160512317, 0.02002374569494878, 0.03499424903683605, 0.05692161214087279, 0.06047139162077539, 0.024103830388236432, 0.03394137226766156, 0.036534553078273614, 0.06691522911311158, 0.025419339334832567, 0.07916575643203913, 0.04420331153537958, 0.0464673541606434, 0.01849625638926462, 0.04420092134105583, 0.03546435889157076, 0.05342797924494071, 0.00673132156202149, 0.00942520750310993, 0.02560940766406636, 0.05639430999215092, 0.02498314802294537, 0.06955170538276434, 0.04655508271929237, 0.07860761541392534, 0.026895904860969995, 0.03660330946947779, 0.08377087182335316, 0.09319212152472428, 0.07890630543472306, 0.10598542213800455, 0.05246080473185547, 0.022573707655312556, 0.05012051337548802, 0.04910335162534349, 0.028360268521693446, 0.13861807874373852, 0.22101975226354217, 0.4763020514961212, 30.542757165047433, 120.64524235263949, 101.5900307316934, 98.6654644627725, 87.26721363682901, 63.94836210435437, 64.51860412474602, 120.29393134578582, 85.93044634788268, 57.27107994018063, 25.572749376297, 0.07509543169890681, 0.07843365982895897, 0.5447225897542892, 0.6267619036859082, 1.0439997406736499, 1.3761956893628644, 3.167051115343648, 4.187616532848728, 3.0148702619537233, 1.7081126594735732, 28.442782932712188, 88.0271807024556, 96.62699299473917, 93.56262560813659, 93.25522161299183, 95.5150951877717, 94.80813503265382, 94.93117978495937, 91.71348694832095, 96.45781332446684, 93.66088882569345, 82.67819743002616, 67.61096154489826, 67.17065980357509, 67.46351180538055, 80.372769448065, 86.57111844708844, 87.35034435026108, 86.0817321654289, 83.57855396886026, 85.03989573447936, 87.36905405598303, 86.85670621933477, 90.14731591747653, 82.48532664391303, 76.7164065760951, 73.60046002172655, 69.11574748254591, 68.46206095910841, 69.03549578882033, 67.51069007381317, 64.10698275412282, 66.0566125377532, 64.51638798559866, 69.34724577011602, 63.05475204221664, 68.72144729860368, 65.94819038145005, 66.13058059446274, 79.15875665603146, 81.66765366831135, 79.77885200131325, 79.39058442269602, 85.69515120598578, 81.54709569869503, 81.92819318463727, 62.95151525928129, 29.844398767717426, 83.95203421192785, 79.46678038566344, 79.824735887589, 71.44843593720468, 75.45996942827779, 81.08132208547285, 78.4179150673651, 74.83314329578032, 74.704709206858, 80.16494658685501, 82.00678179340979, 78.78846922228414, 66.56363379570746, 61.414307009789255, 67.60950242319416, 63.08931596817509, 63.03219841372583, 61.71655701052759, 63.352204984234234, 67.7352693003993, 74.14756790284189, 73.89249617053618, 74.36803648548742, 74.74826320525139, 76.27652845075055, 79.9494594143283, 82.1282732871271, 82.84170535302933, 83.47945136408653, 81.54717414609848, 82.8546021061559, 67.4286654687697, 66.09657364506876, 69.83386285843389, 68.74316938461797, 79.02106577350249, 84.35311225152786, 87.719894378416, 93.48622568192022, 68.39870683608517, 3.0171035614705857, 0.20556973533764963, 0.683759396835681, 3.1689426783592474, 3.78168823738252, 1.1154101668826997, 0.15321632847189903, 0.4296382877134508, 0.24935653252947718, 0.08924486881662762, 0.096923437029604, 1.4370260123283634, 28.055333168275897, 38.88644456863403, 87.30117351778092, 72.93305304742628, 38.11372587757726, 27.613105543198127, 50.49004716257895, 69.39684021857478, 86.50302610089703, 97.99226807009791, 76.35792547656645, 1.835132856522837, 0.00033084599283850577, 0.027315531436714436, 0.031516510550112974, 0.026350084451898455, 0.08314523079823102, 0.07161401407492739, 0.04346672948750277, 0.009332385417374392, 0.06009686272591353, 0.060643102568123615, 0.05290079967028672, 0.0679105535269745, 0.023968328586629322, 0.03922424564558653, 0.05181741344952776, 0.01087548184929596, 0.0036428232523312253, 0.06453807360582775, 0.009621077990760247, 0.034689510751876144, 0.05205356388262684, 0.015826115343389253, 0.022713478481877717, 0.13620635734931116, 0.16425951654391904, 0.12124511217998883, 0.2417267717781567, 0.13727429923751663, 0.12656643551083344, 0.1388272207470671, 0.1583134638325822, 0.17567321537963806, 0.13907929431767235, 0.2057654708023033, 0.3547421920924418, 0.19482955036144103, 0.3016965175347944, 0.17700507455775816, 0.13304216907389704, 0.1137636737116883, 0.3036212674792736, 0.3067785916068862, 0.5725534608767879, 40.436239704009026, 139.54763843167214, 116.52856580672727, 111.44482105009018, 96.51353451513477, 72.31817445447369, 109.35966553226595, 179.69491712508665, 130.11853510333646, 76.22023459403746, 36.46185890320809, 0.4282355500805763, 0.19923417288209164, 0.5187527607044866, 1.11578450808602, 3.017499230561718, 1.9914808604986438, 4.460257051452514, 12.957844042008924, 19.11902270009441, 5.520652176872377, 27.194329769380634, 93.76534154338222, 103.01145061369866, 100.79871608364968, 99.36114388127481, 100.5079507827759, 102.05945214917584, 97.1392466945033, 95.47209816594278, 100.04199674052578, 98.3481917842742, 88.32316275565856, 72.63620807278541, 72.50684830450243, 71.66164813503143, 85.40933593626946, 91.32513307755994, 91.38995416702764, 90.16359375369164, 89.02352548414662, 89.35165528328189, 92.95538779227965, 92.98260904127552, 92.81854414170789, 85.23735569369408, 79.67086915046939, 77.75961583660495, 72.6773694253737, 72.75886843281408, 73.64308049601894, 71.11257122408959, 68.93489483864077, 68.8424288841986, 67.24556138438564, 72.24821506008026, 66.06058197636759, 72.10413855891075, 68.78598597741896, 68.4905138323384, 84.46642168106573, 88.22984956925916, 84.04610049340033, 84.0714939178959, 90.4324016263408, 85.47917765955772, 86.11023210710096, 69.34407649501678, 36.14813204734556, 93.0034682058519, 83.51394468738188, 84.40666044912031, 74.82118791149509, 78.68314573841711, 85.07925279678838, 82.7326399280179, 75.15826071462324, 74.3926768149099, 82.1442844021705, 85.65354270319786, 83.91219862045781, 69.20940583752048, 63.33592322564895, 68.72852325439453, 65.93719990022721, 68.23622657406715, 64.92729156248032, 66.42493094167402, 70.87795857460269, 79.85444391927412, 77.774458085337, 82.30812180426814, 79.22586840967979, 81.0521004276891, 83.57567494915378, 86.26191800640476, 87.54559993743898, 85.56441860814249, 86.54607803590837, 86.06506209219657, 71.17749429518177, 69.46163777382144, 75.41953763654156, 73.46919398153983, 81.18669263778195, 88.1549636779293, 91.213392596091, 92.9173251121275, 67.56662307247039, 2.9149508235916017, 2.96714065536376, 4.936389154003513, 4.886609373554107, 5.1278939747041274, 1.396617509665028, 0.9390873089432717, 1.4457971674780694, 0.46339803585602396, 0.2798668114889053, 0.3477335601083694, 2.856131941080094, 43.14660533781975, 58.53884489305558, 93.11084701168923, 82.00278097583403, 54.57646262261176, 29.931999021960845, 59.49267510444888, 81.53292025289228, 98.12487556088357, 108.70728123572566, 90.76059418339884, 2.0404706510805317, 0.21990253560004697, 0.062494970737926425, 0.1387572615978218, 0.11283722826309743, 0.12732266388352842, 0.12910803179106406, 0.14854489284898006, 0.10020908088453355, 0.09387781618223076, 0.1385490082564854, 0.18733898778596234, 0.23326563708964856, 0.23268698023692255, 0.20960795332587537, 0.12779659651700528, 0.13883197049219764, 0.11475028770585215, 0.11496873767746073, 0.13614574447274208, 0.14030552529279264, 0.13400806805058835, 0.11131139562254953, 0.11994780356725378], [0.059926580532544085, 0.06896507355474657, 0.018255312160979358, 0.010514709020724461, 0.01853173966669748, 0.04079474887299923, 0.05221292932307528, 0.008102691724836346, 0.019345625731793624, 0.015505855159473517, 0.01415084288906186, 0.023059641056123282, 0.07532284489922947, 0.0381665118789721, 0.03711463102409917, 0.039838705617453785, 0.028715693098943562, 0.04308304967238538, 0.06235344748523447, 0.054652969157623674, 53.94816560129966, 109.87395101977934, 87.1475342781313, 74.86047437114101, 35.13991817351311, 21.797562222326956, 65.8235296126335, 128.67861732359856, 90.68609268434587, 50.23908215184366, 4.302806248587947, 0.2185899511941018, 0.04542170926147411, 0.10544838684220469, 0.2795856265771774, 0.662789915598208, 0.2160909570633404, 1.0277738758633215, 2.405163068925181, 1.850652081831809, 20.19761173955856, 86.14336044557633, 94.26458081891461, 88.11479860736479, 84.53289801074614, 80.77445937741189, 86.19110353531377, 89.05387678454, 89.59259079348656, 89.45348785769555, 90.09590933399816, 90.72821893999654, 82.3804973786877, 68.87198786581718, 63.48487915531282, 63.19846768533031, 65.35738337424495, 72.33493866459017, 75.353194667447, 76.41377218307989, 72.46010149678877, 76.59204390741165, 76.0999825692946, 80.40794526377033, 83.54599045168969, 85.06784654432728, 77.83434483312791, 78.34598664314517, 73.6293835793772, 71.80325354299238, 69.12797743274321, 65.48094980178341, 60.199388150245916, 61.83172564352713, 59.233335833395685, 64.57254063698554, 63.934582817939024, 64.56319362886491, 64.71714273575815, 61.46281888408046, 61.05992478709067, 64.06621363855177, 62.73542796411822, 67.1172292770878, 69.04603127510318, 72.28635618763586, 79.1864642789287, 57.252644800370746, 22.758880238379202, 62.09455974640385, 75.10978806403376, 76.55575413857737, 69.52106168193203, 68.71354764507663, 75.94013814003237, 76.49616549091955, 73.81926551941903, 76.39707857562651, 73.73623678761145, 78.8533373801939, 75.69232279254545, 70.51893618799025, 61.087695167910674, 62.815075612837276, 58.01532222378639, 58.79784291790378, 57.405934949075025, 59.46181781830327, 58.61089098838068, 63.78196339453421, 65.99442728104131, 68.15406076369747, 64.68374767611104, 66.60215147079961, 71.39346784160983, 75.55269425915134, 77.4129802949967, 78.91629926619991, 77.20405132539811, 75.73829297096499, 59.95854677692537, 62.708591107399236, 59.94415560076314, 67.79749378081291, 80.74296274492818, 80.93915970094743, 86.21669307831796, 85.01178018508419, 79.23539192445817, 49.36701766906246, 1.1548130718931076, 0.2931165472874719, 1.3629367298656896, 0.6793466078177576, 0.07607640728594796, 0.27418957903019847, 0.3938962104580095, 0.01669331442474598, 0.024313690598994016, 0.28948161330434585, 0.030516838587279764, 11.04459326113424, 23.88302564620972, 53.457018175432765, 43.76969345154301, 37.104570634903446, 39.193440637280865, 35.953994335666785, 53.77861330586096, 66.03139954228556, 75.05445126564273, 84.51878532286614, 13.684120889632934, 0.7197185221218294, 0.10489066717244926, 0.03854058112107939, 0.15278626203296647, 0.07044663397415031, 0.04575710255472411, 0.031211594149710673, 0.01681617002994303, 0.044426756400254466, 0.04098036048573352, 0.05254060811092777, 0.01483887124190768, 0.014122253445337617, 0.03629841030605378, 0.04017386908432649, 0.06051255352494698, 0.0983136797684335, 0.0480979569857159, 0.04342246492723784, 0.10155328939999304, 0.07899992903994937, 0.026277478468874772, 0.0984992032810565, 0.06203897222275696, 0.10863881362902542, 0.018443771705572164, 0.02402662787766707, 0.02567374755838706, 0.03275121637289563, 0.027913980170964237, 0.07287791359328455, 0.036713292882327116, 0.04341445547798949, 0.019379134417601654, 0.03842978565503032, 0.023540792153066686, 0.07736695900319085, 0.08603087716525601, 0.03777002307376073, 0.029385273096962806, 0.09528323512284026, 0.11081951354900677, 0.07841862152300536, 73.5054837503741, 122.20612602849161, 99.76184537333828, 85.64071655273439, 50.86970513866794, 34.124275330574285, 64.39956803475657, 137.4542380917457, 95.74931560024139, 54.511057099988385, 5.545082659490648, 0.25957963880031343, 0.07477920592552231, 1.1088602989912033, 0.20776358132641162, 1.3994319328377325, 1.0878153121279133, 3.2079450113158074, 1.466383604753402, 1.2557786799246267, 24.844124009532315, 90.9845458307574, 98.01000502801712, 95.99469123348113, 89.71354884486045, 84.87700754596342, 89.39557013973113, 92.87107252305555, 94.00659868794104, 92.53989896466656, 92.67426367728942, 93.68844739852413, 87.86450432192895, 70.77209380365187, 66.74248603082472, 66.15757434598862, 67.52525775663315, 75.71156594061083, 79.14534999478248, 78.5427797994306, 78.24959831853067, 79.50189344344601, 80.10514613120787, 84.10589310430711, 86.86084824223673, 86.86512362572455, 80.1142224957866, 81.61497623689714, 77.72463613940825, 76.53137268558626, 73.92420461100917, 70.04651807969617, 64.26914138178672, 64.7041557681176, 62.8379116519805, 66.97359208137759, 66.51318427055114, 66.5160789797383, 66.77074278554609, 62.80980786969585, 62.629398453620176, 66.83776040231028, 65.57357265103248, 69.4357422859438, 71.11069633114722, 75.48688473240023, 82.47370073872229, 63.697232354071836, 28.234667854924357, 71.26756760381883, 80.15162621774982, 80.82908230443155, 70.95258558950117, 71.39779029353973, 80.4512482304727, 80.06514580019059, 75.07990744806106, 76.60246956732966, 75.66934554807602, 82.1420721853933, 79.0527428350141, 72.60890053164574, 63.172627110635084, 63.312487063869355, 61.275278599031516, 62.78545779566612, 60.644326133112756, 63.427122254525464, 61.43806480592298, 66.55252564337947, 69.55130315596058, 71.94153278104721, 67.67087967165055, 70.30249980188185, 74.12864638913062, 78.26187533717003, 82.8219287626205, 80.5670601321805, 80.7966599925872, 79.31155650846421, 62.2627745136138, 65.73690014500772, 63.77220845991566, 72.70902295266428, 85.46549643239668, 83.65274952303979, 90.63328973708614, 88.21000237618723, 80.9160255616711, 57.3662954761136, 3.108641875367011, 0.23224047355113492, 0.6717655855801798, 1.4634608261046873, 1.149505124457421, 0.6338013324045366, 0.7582096599282757, 0.6762094471243121, 0.4815339110791684, 0.5397808323464086, 0.28604362520479387, 10.313786075961206, 29.350125212823194, 51.90583452101677, 56.564735597179784, 33.105824070592085, 36.230564578886955, 48.46271130346483, 59.94219049330681, 78.60865992884483, 80.08951156370102, 104.95809939599808, 25.37753497400592, 0.8495247051600487, 0.1273610525494141, 0.1157532959815956, 0.12415708898897133, 0.05223830598556707, 0.12801899950230314, 0.01982626163460795, 0.05904576328072337, 0.02381615671178987, 0.012299137512942957, 0.07305611330535143, 0.04493583331725771, 0.04002158995717764, 0.0448647978144788, 0.00888258168068264, 0.03275955907039104, 0.021151141751737847, 0.04370723513045138, 0.04664356970498639, 0.027361452662115617, 0.07186886854469776, 0.0406955213346068, 0.02995920893285544, 0.15529061877919784, 0.229344891023732, 0.12464946135878564, 0.04490768341648002, 0.1567103329204744, 0.10659260044415152, 0.25958046617527164, 0.14786667520961455, 0.10285606788050744, 0.13518476378052466, 0.1254702402999805, 0.1420248870647723, 0.21172960318865316, 0.21126509343664493, 0.15922372950421226, 0.22911501868117243, 0.14873901952899274, 0.15717694175339517, 0.1968937436298978, 0.16990029853918862, 86.7533125415925, 135.8972140281431, 113.95672259792205, 99.29293386397823, 56.01044977864912, 34.76269206693096, 82.42864055018272, 136.3527580999559, 101.86953883017264, 78.88639511600618, 6.877336280961191, 0.36332510411739355, 0.43875451950776967, 1.500388592962296, 0.927650841974443, 2.2998187474666105, 1.4364367987840407, 6.628886980395164, 9.700752958174675, 11.940457705528507, 25.40747638671629, 96.06931824837962, 104.64773008900305, 102.23666483356108, 92.41032738839426, 89.81301230769004, 94.19087163863644, 98.87456601665866, 98.81318876820227, 97.61120196311705, 96.0842389445151, 97.42409706115724, 90.50414962153282, 77.30085542125087, 71.81570314591931, 70.06511011431294, 72.61007724269744, 78.7517087690292, 83.78283885217483, 83.06210333301176, 82.18077028951338, 83.8886957783853, 84.31199796738164, 88.55430802991314, 91.5447073598062, 92.87990570068361, 85.4765732057633, 84.22309352505593, 80.32265724674349, 78.59635937598445, 75.62159461359825, 74.35346880266744, 67.15850830078125, 67.8284412814725, 64.70625815852996, 70.70793167237314, 68.67361791672246, 70.69051634880805, 70.88588176235076, 66.03107790793142, 66.4394437113116, 69.58435304703252, 70.3364989065355, 75.23630019157164, 74.29218569109517, 80.4587007338001, 87.75278737468105, 67.24602422406598, 32.29398562062171, 75.3049808932889, 85.08420282794584, 84.6437834155175, 75.28723609062934, 76.45952270876977, 85.21471577305948, 86.43397669638358, 79.69350122636365, 78.36365299840128, 80.24398234582718, 85.36709985425396, 81.09494055471113, 76.29764649175829, 66.10867023468018, 67.08710547416442, 64.70752116172545, 65.30725940581291, 66.56006443885066, 66.09593822110084, 63.40090513229371, 72.31228305447486, 72.60301697638728, 77.65394718416276, 72.77112976197274, 75.57284739709671, 78.67956853681996, 81.93533974309122, 86.32422877896218, 85.52029978844428, 85.39527031683153, 82.32236785273399, 65.59174106967065, 69.71578382676648, 65.06149545792611, 74.67605237037905, 88.71913386929421, 85.41084997115597, 90.88074422651722, 90.74141379325621, 81.9935320269677, 59.21554396229406, 2.4593285495235078, 4.865749228385187, 5.144234568841997, 3.793732365292888, 1.637342437621086, 0.9643740939997858, 1.9212885753762339, 1.3077046097286287, 0.6993209101980733, 0.7566814064498871, 0.31422885795754774, 18.05940616515375, 42.24266375264814, 66.45973805458316, 57.54750505570443, 46.50113790265976, 54.11257174707229, 54.549617921152425, 72.7982254951231, 89.10306330650084, 89.64894740812241, 115.43238885941045, 26.365038733328543, 1.124110596795236, 0.24683700724234506, 0.23084617820718598, 0.3027533205045808, 0.16530908764370028, 0.23585026452858604, 0.12905756191861245, 0.14818809505912567, 0.11875511958233773, 0.2006682588328277, 0.15677865264156174, 0.10386931109091929, 0.12799795506702316, 0.1988073699777165, 0.10570115755282103, 0.12735942078213539, 0.1790313005086876, 0.14753705821931362, 0.16842806140982336, 0.1978996017527196, 0.3332429150900533, 0.13953718507001478, 0.15670483240917807], [0.0660777647769259, 0.04807974324531613, 0.024621054650314396, 0.023642174313746156, 0.03188610583874247, 0.030798492727861292, 0.03814907571781547, 0.03731347680572541, 0.07734059025683711, 0.04062974119498845, 0.052632442900850895, 0.044869949755769585, 0.0290114700704092, 0.013116472888918174, 0.06694398805378907, 0.031121410279264374, 0.04722062926439028, 0.02699433566792117, 0.12264835543089336, 2.9617961808558437, 90.72101746836017, 89.39398550218152, 92.10108772400888, 65.10785002862254, 44.13110063922021, 41.66510258951495, 54.930138818679325, 38.85719545425908, 33.597112701785186, 20.815041834308257, 0.07083360030646287, 0.026075033989224224, 0.11500140366655205, 0.331966704538753, 0.43125574446974263, 0.6436907920625903, 0.8276476242369222, 0.9444008334990471, 0.8164988386054194, 10.25821295476729, 81.09876878799932, 95.30543665732108, 91.9151673778411, 87.22767614549207, 79.26467634016468, 71.48662413320234, 75.28498465015043, 80.7641435438587, 86.24949193769886, 89.55709334342711, 90.03947427195888, 84.09337289871709, 84.5101482637467, 68.18703220736596, 62.198761432401604, 62.3582410812378, 62.48148979679231, 63.42805970099665, 66.79312382974933, 66.28292545195549, 68.54906697427073, 68.42170761477563, 74.16254351215979, 76.28834262970956, 78.45309872781077, 81.529248914411, 79.94585083376977, 79.94036736026888, 78.43343196376678, 76.02482995679303, 69.75526640492102, 68.98885096273115, 61.23933007640224, 57.91306211102394, 60.151860790867964, 62.05275904747748, 62.0819571710402, 61.844712611167665, 60.93162013638405, 57.90097336615286, 60.6811728785115, 62.6332776777206, 64.35462551732218, 64.00300856559508, 69.441665064904, 68.77090054173624, 77.18270578692037, 72.12272274878718, 31.596082218231697, 75.99627510193856, 75.61458141573014, 75.97268596772226, 66.31701869349327, 66.35432827857234, 74.11396103520548, 73.9487272693265, 64.31961444116408, 63.94063111274474, 70.92942007126348, 72.36787088455694, 77.14665920503678, 75.04913253168907, 65.96299340648036, 58.65282504789291, 56.95618814037692, 58.17413114732312, 56.5752044031697, 56.08122502603839, 57.37799982870779, 57.68783569335938, 58.043931991823264, 59.4084696615896, 56.98188750974594, 60.67062954748831, 65.7863651552508, 73.27538967132568, 77.42541420844294, 76.40027138494676, 78.02869827516618, 75.78085068733462, 60.65965475574617, 58.73086060247114, 62.072731756394916, 76.31876453276604, 80.66393483069636, 81.94388266532653, 87.2090684213946, 71.44417624319755, 80.96454528070267, 78.32524514967396, 51.40514396852063, 0.8684196815856042, 2.8058125895838586, 3.7782804331471844, 0.3170606253608581, 0.26171585965541105, 0.16303088005271651, 0.3450896987511266, 0.09195854376641013, 0.03888430179006631, 0.06971685095660149, 0.1704574742865178, 20.10848960568828, 30.213027038881858, 36.55072804420225, 27.479815560002482, 35.967228412628174, 19.75096360329659, 47.008261142238496, 71.52207451481974, 70.51509226522138, 87.82986194856706, 55.85792841449861, 0.6755838290818277, 0.036001409509129105, 0.04761828252324655, 0.020208579728439934, 0.061011866651355266, 0.013515630552935745, 0.043737936104016925, 0.062100504404835166, 0.04326044499213177, 0.019126243048137235, 0.04309580886676427, 0.044292273495586655, 0.06825707041688504, 0.045454647211778554, 0.06625422546940465, 0.04143052524135959, 0.032728379291872826, 0.037969064207807664, 0.02868408239596794, 0.08227975062665441, 0.028163267096744913, 0.021972732746132442, 0.06618142413396029, 0.04357336892656261, 0.010387324878285009, 0.044944777393773686, 0.05316326522358483, 0.03368694680712877, 0.011173298529859994, 0.07364690499079805, 0.029565939612145868, 0.009294897862409633, 0.008669709786772728, 0.02305830040225579, 0.04037520848214626, 0.018534966812078512, 0.02182223668862735, 0.11213297129518564, 0.03223694921020539, 0.04106452290509497, 0.0808110451626201, 0.35146888225309314, 5.425081176142539, 109.96450285757743, 99.08608375057098, 104.36785328772761, 79.87578945775186, 60.92129645809051, 47.95658042353969, 44.70618678677467, 42.65898412273776, 42.715544700622566, 25.62491886077389, 0.07049309720675792, 0.09275592638239746, 0.41958460944794845, 0.5748461475295406, 0.9599699464536483, 2.0410619483840082, 2.3301896597108533, 1.5552384045816239, 0.8891313282712814, 12.894888039558166, 89.80727780249812, 99.08132199318179, 97.67714485045403, 92.25830416525565, 84.97498050812753, 75.01392533702236, 79.25361525627875, 85.65719050745811, 91.56533902691257, 94.37044558986541, 92.49841597772415, 90.89186022358557, 87.23290858730194, 71.11258691357028, 64.94811934809532, 63.877818276805264, 65.68387754501836, 65.80229782289075, 70.89559355089742, 69.90627765655518, 72.38443897616479, 71.24925013511412, 76.31244167204827, 78.81983249418198, 83.6213940958823, 83.3865382594447, 82.92175308350595, 84.61194161445864, 81.95192352417978, 77.98044527730634, 73.91855639796104, 70.46737270970499, 63.71462806578606, 61.41894717370311, 63.922725492908114, 64.88177245663059, 64.71051000779676, 63.33718230647426, 63.612426788576194, 61.18847262474799, 64.11649842416087, 67.5060224533081, 67.54472840216853, 66.50308024498725, 70.61287695361723, 71.96946005667411, 81.018932865512, 74.74314058980634, 34.84033930686213, 80.221648370066, 78.21983537366314, 80.94067373583394, 69.21440293712001, 68.41763619453677, 78.21750548578079, 77.80293449278801, 69.8255866573703, 69.27464269822644, 75.33845440033944, 74.9299866153348, 79.36976448182138, 78.03496622270154, 69.05261301225232, 60.80982269779329, 60.42321035938879, 60.80267221696916, 58.660234405148415, 58.436169009054865, 62.538599506501235, 60.36470036352835, 62.04549089554818, 60.29414084649856, 62.46704762981784, 62.77695801950271, 69.3971069397465, 76.21522964969759, 81.28996864441903, 80.2698072310417, 81.35923770166214, 78.88834061161165, 65.43412062429613, 61.526957481138176, 65.3860951239063, 79.02295635592553, 83.03624706883585, 86.60799657144855, 90.07913727914134, 75.45285424878521, 85.19614727266374, 86.42105640903597, 61.30861482312603, 2.3364355439139954, 1.6803848118551317, 6.569969058036805, 1.0328333656634054, 1.1617825108189737, 0.5066579177735314, 0.998447907547797, 0.6190432307700957, 0.38268546363519085, 0.09690913416805769, 0.22021100856363776, 24.523111351074714, 35.5476995437376, 40.329551235322036, 25.838993980038552, 34.62800571995397, 34.77773435654179, 59.5251170281441, 77.55212245448944, 78.54070878797963, 94.87519187311973, 72.48755808799498, 1.2783768028020859, 0.08317612712421725, 0.03287289794834872, 0.05477820538104542, 0.039110703754328915, 0.02166387099292009, 0.014144629915995945, 0.040261168633737875, 0.016968297854726835, 0.0033243686418920277, 0.06347934009447213, 0.02399929194530893, 0.047644417612783374, 0.048375211866392244, 0.07505975498427307, 0.05489158639383893, 0.0667460845603097, 0.03603846901246617, 0.04216898037421127, 0.016643511048788508, 0.016584007084489833, 0.02859613550226054, 0.04407642822292063, 0.15794457717528268, 0.23374582100058758, 0.14197815570139116, 0.20972010859799003, 0.09516788526408135, 0.10475860127518255, 0.19086933544566556, 0.11533271371116562, 0.15156609847420646, 0.1429372211737979, 0.11177749883744026, 0.2287281442794108, 0.12868971714088995, 0.16824207058356655, 0.2961565680321186, 0.16051323934187814, 0.19004176130458234, 0.12976194912147138, 0.49994760042717384, 6.50113195180893, 127.46102732996788, 113.9377461710284, 119.4785725685858, 91.73389111795734, 66.32531842877789, 61.688716027044485, 81.0863034955917, 54.84141480538153, 55.477964493536184, 33.057351420002604, 0.23900141398752892, 0.10823176047133823, 0.4613051755774406, 1.6288932845477135, 2.116679361751003, 2.5369419590119393, 3.9707675624278287, 3.9638239866302865, 4.3509901146734915, 13.377252298016703, 91.741986889993, 105.38154279032062, 102.61591096078197, 97.3809588340021, 89.46718477433728, 81.07382251370339, 84.69283657689249, 88.52277217372772, 95.83519981753443, 99.10793135243078, 96.9184172538019, 93.7141389231528, 93.05982482048773, 77.34513898049632, 70.22538600429412, 67.81194379252773, 68.67731278942478, 69.45306347262475, 76.05981749873008, 74.17088247114613, 76.40424866830149, 75.6783042415496, 81.81551133432697, 83.82187428012972, 88.57689303736534, 89.40409737248575, 85.99129015399565, 89.19720803537678, 85.11093770304035, 81.90980511326944, 77.32134588303106, 75.20523501980689, 66.49195640317856, 62.881273454235455, 67.0246534962808, 69.52341510403541, 65.41252405412736, 66.15370688899871, 65.68094753449964, 65.23050254391086, 67.46240569699195, 70.0768066221668, 71.52167443306216, 71.87704117067399, 74.74832596317415, 77.5147658009683, 83.73595868387531, 77.04068460772115, 39.72353327658869, 81.58863359881987, 82.4662874590966, 84.56142933137956, 73.60626512958159, 71.9358531890377, 81.18129545642485, 82.19825621574157, 72.88464315475957, 73.8514603337934, 77.89254496174475, 81.16317410622874, 83.61048206206291, 81.46161156315958, 71.98631055893438, 65.95927499955701, 61.67672141905754, 64.71568753642421, 62.07044109221428, 61.924101383455344, 66.54417883965277, 63.90248214044879, 63.926216402361476, 64.49801560371154, 64.07871030992078, 66.04691643868723, 73.30690199329008, 80.81618555130498, 84.06487295704504, 82.5894263482863, 85.89632172738352, 82.52229106041693, 68.34676681026336, 63.838182726214015, 69.66084711013302, 82.47191998266405, 86.46588125536519, 87.41027816649407, 90.13886713212537, 77.99695061099145, 85.95791862856957, 87.93275356292726, 61.14402040358513, 1.5223999537767903, 8.654572502259287, 11.156373946897446, 3.2470824208951767, 1.4424572692763422, 0.7511968910694123, 2.1448549724394277, 1.8244419463219184, 0.5730611013789331, 0.13909057113191775, 0.44859841225608704, 35.020532992578325, 47.65713883984474, 50.57847699811382, 40.41916562664894, 49.61695501881261, 32.90616366171068, 65.40453418608635, 90.36361109825873, 89.20045575787945, 108.87948897577103, 80.32369275246897, 1.086166445766726, 0.1357283644498356, 0.22268702005667074, 0.18236897705543428, 0.13515612741391506, 0.09954131268445524, 0.17910299101664176, 0.15445032757857155, 0.12652525828490335, 0.13713243507569836, 0.14955888682555768, 0.21619001223194986, 0.20310250321222892, 0.11293449844684332, 0.15390182394654522, 0.17364095265586532, 0.13429873713081883, 0.10759263629874877, 0.12651988800855415, 0.18388909468006703, 0.11701495086233463, 0.13586451359573873, 0.18507858407833885], [0.04170513711869717, 0.03375069681374777, 0.03770782822562802, 0.04406201427862529, 0.019718965275153037, 0.060047319819850314, 0.03862122719686839, 0.020296802413800073, 0.07591735977198809, 0.038834506074988076, 0.0443033243138944, 0.05476342754498605, 0.025255886815308083, 0.04021559789356205, 0.04530551670599849, 0.027944374709360065, 0.06407134219883912, 0.1322532670512315, 0.4917386925268558, 13.751417975271902, 106.09008758298813, 82.79690404092112, 94.21453137551585, 56.90260856382309, 34.12429886479532, 32.63572604425492, 77.72935082835536, 88.54298806959584, 55.056113581503595, 3.613738475307342, 0.0876250371877705, 0.11496899048647574, 0.5859764244767928, 0.895054781388852, 0.22797894093298146, 1.345997606554339, 0.8557404974295247, 1.4990031382729931, 1.7451682710839858, 58.905833613487985, 98.9415365649808, 89.72973254419144, 84.80489869271555, 77.68855817856328, 71.19165405150383, 67.71688122903147, 65.31262913057881, 67.58883153238605, 71.87901020050049, 79.23214420195549, 84.76555731988724, 83.43208482188564, 76.05267878501647, 63.447777455852886, 62.25680074384136, 61.000802901483354, 61.671743931308875, 61.16755070224885, 60.32773986939461, 61.76191529920025, 63.36604310620216, 64.30064193664059, 64.39269996458485, 70.22252267406833, 74.16193162241291, 76.60329326506584, 77.37338789047735, 80.58503243231004, 78.53194621301468, 69.98864743017381, 71.50942094864385, 62.823261599386896, 58.477459799858835, 57.40273429501442, 58.54864297374603, 59.84786533540296, 62.694600012994584, 59.92428879584036, 58.28110987140287, 60.439511729824936, 73.82496864564958, 73.37573174507388, 74.66459120473554, 71.70215052943077, 70.78397074053365, 68.4793350773473, 75.2434467500256, 69.71339118096137, 41.0520871223942, 78.52289338265696, 68.70212570313485, 68.10919669366652, 60.80233881550451, 68.5259485244751, 70.94528213624032, 72.36314050612911, 72.43226051330566, 70.20305202853295, 72.75863309060374, 68.44376702462473, 68.98528945061469, 73.27783723031321, 70.28055021839758, 58.95166258658133, 58.011913684106645, 57.04729303236931, 54.69658128676876, 56.88908030909877, 59.19831691249725, 55.230686510762865, 57.364628468790364, 56.66039436094223, 61.706221565123535, 60.08506282683342, 66.22242681441769, 66.90057323824975, 77.48944297913583, 77.36966163881364, 77.15259767347767, 73.08950070411929, 59.56289337527368, 56.84683638234293, 63.64118560667961, 78.00969046931114, 82.14659075583182, 82.0734699310795, 78.09085999765705, 71.4448195119058, 85.18514110196023, 78.0833290469262, 89.35333405771564, 53.069919463126894, 0.8503344907395302, 1.041964765998625, 0.9178750084773187, 0.8674847478828124, 0.46812611602006426, 0.5039153230046073, 0.26617611548112285, 0.8174152636239607, 0.3778763313687617, 0.010476466869154285, 3.5220405699745303, 28.44154150255265, 39.84403241065241, 51.30737889197565, 42.04242675535141, 20.08839334211042, 36.00911148132817, 54.868314420023275, 69.63214320521202, 71.61931007139145, 80.6669472109887, 18.25792124194484, 1.0431697916600013, 0.23092908424235162, 0.12706340440819341, 0.05390611770112188, 0.03966013052230401, 0.07718718114999995, 0.032966333862033584, 0.016832845848834804, 0.026799701454658664, 0.05951957334013236, 0.013809784375611815, 0.03683028983012323, 0.034601077392336824, 0.12493626935587776, 0.07383808989318148, 0.049144911895235704, 0.05888675024072009, 0.013613630435429515, 0.021186454574607556, 0.05386823082282659, 0.039445897864718596, 0.08547711817006912, 0.05116917666107897, 0.043811970841019385, 0.034910661183417804, 0.04339183290158549, 0.015208562291527708, 0.0641288600801941, 0.038282754230162794, 0.05066631654758127, 0.0217323113728555, 0.04124073078855872, 0.054887621888830784, 0.05948082078248263, 0.08238227617356085, 0.044447375656736475, 0.08941366096898433, 0.06406885624352483, 0.05789662756386304, 0.23372947268428343, 0.4582996900764204, 21.85609575240843, 124.94548582261609, 90.98334558548467, 106.92523079533731, 67.0286621585969, 45.46895834707445, 44.84992596410936, 85.28156080553609, 92.5545137159286, 60.413023964051284, 3.7917787797989386, 0.14728199690580368, 0.18517408459897966, 1.2382781673823635, 0.8707308156355735, 1.0724990694753587, 3.515552234265112, 2.984181147429251, 0.6273125063988471, 2.916518791067985, 65.35137822551113, 102.16113567352296, 95.92660673203008, 89.66902209866433, 81.77160432261806, 75.47480383226949, 72.06394210938485, 67.25320216148131, 69.86674016521823, 74.44887653473886, 82.12992852733981, 90.4215366609635, 85.11513463912472, 78.61305298343783, 67.9399307312504, 66.3882097121208, 63.46528299393193, 63.91413942460091, 63.98941363057783, 63.14171491130706, 66.21132650683003, 66.56809745296356, 65.3298601027458, 69.01289509188744, 71.572021976594, 77.97111788103658, 80.42044193513932, 82.97676824754285, 84.33266885818975, 81.37327194213867, 76.40589606377387, 74.94460136659684, 67.40393100246307, 61.96680422752135, 60.38434359335131, 63.1766632295424, 61.97798298251245, 65.95615279289984, 63.583295345306404, 60.05542147544123, 62.942835054089954, 77.79005342914213, 78.37080740159558, 77.78969257108628, 75.07593016470634, 74.69451888915032, 74.0475082397461, 77.91379636333835, 71.85328729691045, 44.58672708080661, 80.56716995854532, 73.4337749788838, 71.73320001171481, 63.98955875827421, 70.90448948644823, 75.30961713483258, 76.33289291012672, 74.95850224648753, 72.97186097791119, 73.68717578149611, 70.9273333703318, 71.27738921873032, 75.75300970385152, 72.40336833461639, 62.62131444869503, 60.027490277444166, 59.27520321261499, 58.58898847333847, 60.05671977996827, 59.40049548302928, 59.55337770523564, 61.7885442703001, 62.19620012467908, 64.6253239723944, 65.28930279516405, 69.49432680683752, 71.49794409351965, 82.08832786929223, 79.13625794072306, 81.32556023136263, 75.28454534469113, 62.812635898590095, 60.585702388517326, 67.5667642777966, 81.65398813063099, 86.71196291523596, 85.22271740821101, 83.546429757149, 75.42167925065564, 87.12107396894886, 82.66282173895067, 92.06811628034039, 63.694110147414676, 1.7961270914923761, 1.0111101764825083, 1.4488514681016247, 1.3752502755772684, 0.7193212595678146, 1.3421139697874747, 1.5920445779638908, 1.0685201926577477, 1.108498705490943, 0.19280651133627663, 3.4519514922172796, 32.799981178775916, 37.47986301299065, 45.062267395757864, 36.50216910146898, 28.096610230784265, 54.593203298507206, 60.19339084625245, 75.91048502152967, 79.11120184006231, 95.25283767331032, 29.481940384834047, 1.0532989449078038, 0.23036593300921304, 0.14681080686709574, 0.13605908460674748, 0.023824600915935253, 0.043411981013994065, 0.061226264017844395, 0.047241819256375876, 0.007782757607093382, 0.022684792319553036, 0.04004427382061559, 0.020075491103794307, 0.03698942544419439, 0.055109779725992875, 0.023804538988418156, 0.016863466383168296, 0.09208094929495166, 0.011619129143054447, 0.004398003520984804, 0.009508793441308363, 0.01922996560742538, 0.042332743159345085, 0.1372127976989554, 0.18084931908355606, 0.15734837690909065, 0.1270652123756947, 0.17714722983298764, 0.1436263019399297, 0.23192230191442276, 0.07057467024893531, 0.12541404775073453, 0.13937802264286628, 0.13644399782342298, 0.12634737266888543, 0.22358456866875773, 0.11684639619723444, 0.21485942475978406, 0.2182784138788139, 0.21106805562252, 0.39610680312879626, 0.6785804586064431, 28.417475800360407, 142.15461823248094, 104.37186979478406, 123.18427885732343, 77.27040998397335, 50.05273034495693, 51.42237494068762, 111.02984997533984, 108.29576184672695, 83.03790230904856, 5.8563163588123945, 0.20462881082728987, 0.4183183580396637, 2.006969442290645, 3.8608247522384893, 1.2765564553199278, 4.6807457362451865, 5.319199244822226, 7.028178380381677, 4.023923032706784, 69.58715361933555, 108.63734537555327, 99.42888321415072, 91.97865486145021, 88.13486545316636, 79.75902834246236, 75.39077881843814, 70.93395433118268, 72.91295482266334, 78.28326794408983, 88.82111549377443, 93.50759475461899, 88.69414837129655, 81.23605958877071, 70.22748839470648, 69.19256318000056, 66.36544427564068, 67.79100618054791, 68.0876942603819, 66.00635128636515, 70.93343657831993, 69.23681536028462, 69.66857417937248, 73.77529574978736, 77.1941904867849, 83.62351217577535, 85.73231958573865, 84.43714511009955, 87.90756410168063, 86.07332260377946, 80.4746961593628, 78.86157435755577, 70.20821386767973, 64.32213652518489, 62.20963424251926, 65.49998506422966, 64.31124410321637, 69.40365729793426, 66.14070815424766, 61.72708072969991, 65.76512552076771, 81.71662838228288, 81.45368053067116, 81.12398962820731, 80.41014179106682, 79.95464478769611, 77.74151017588954, 82.46330645776565, 74.90795073970672, 48.66212068065521, 87.20231409995787, 75.79420243540119, 75.96034619116014, 67.18776918226673, 74.87434387207031, 79.32077407836914, 79.40529331084221, 76.80314587008569, 74.54257411341514, 77.38961865825038, 71.44367417981549, 74.72441519460371, 78.06490175185665, 77.61670820174679, 65.1166400601787, 63.22096247826854, 64.71364398156443, 60.61163710009668, 63.45777165505194, 65.69469936432378, 61.45362484839655, 64.4694842830781, 64.83650046010172, 69.11010711423813, 68.12503522442233, 73.77768055085214, 72.58247944616502, 85.15053795230004, 83.7723582790744, 85.41110884758734, 78.39346301171088, 66.01516092977216, 65.0868025902779, 70.16964912414551, 83.66594437629946, 92.47421495376095, 86.57705691552933, 84.5765696802447, 75.78703234272619, 91.2022138410999, 86.22907207858178, 96.47509528744607, 59.6422193896386, 1.0894657719519831, 4.007323807285679, 7.292045047206264, 3.7110225712099387, 2.206481291401771, 1.7011277762151535, 3.971053895450408, 4.023229508630691, 1.4782324721736293, 0.2487101228607278, 6.001915720201308, 48.36613470508207, 56.33104862705354, 72.36763554234659, 56.39605014554916, 27.943390684743083, 51.541744432141705, 72.81902974651706, 89.6521794411444, 90.0155399691674, 106.83504766033542, 29.22608613967896, 1.2749583346228446, 0.3701746962483852, 0.20127074101999884, 0.23173150005600146, 0.18167936002775548, 0.20653306025891535, 0.15187354487997873, 0.10890169670024227, 0.08640898752116388, 0.2233371835562491, 0.12354116195872908, 0.14811856491911798, 0.10065035518979835, 0.1815017348816318, 0.13838154143623768, 0.15254448468406356, 0.21159293310296154, 0.13539677095269004, 0.0987062002381971, 0.13198181145614193, 0.11144095641230384, 0.22706519722217516], [0.01633620636928226, 0.02350288995301291, 0.045006236797499086, 0.06823871495021928, 0.0382382636739602, 0.019272996766132214, 0.03460496911899217, 0.05166849361792688, 0.03774111474593801, 0.02113170610109885, 0.005569257632633972, 0.009367319026721582, 0.04232411317887806, 0.03773012138422459, 0.07220721893733548, 0.03889066798071708, 0.08392107868266684, 0.12104314075963152, 0.4023210325789067, 48.246212159433675, 94.54615992884483, 80.2858889487482, 75.27541406692998, 53.88185793353666, 41.6059846262778, 44.138055001535726, 47.38657766772855, 65.70577613769039, 23.361238625741777, 0.03958502326220755, 0.06779887322937289, 0.5728914588689804, 0.5746012445419066, 0.9039194605523541, 0.3806337269563829, 1.9602439624647943, 1.0983506758366863, 0.9648462493092784, 28.7057464738046, 93.6053559087938, 91.59228570999639, 85.37469356290757, 77.3022674745129, 71.58966479762908, 72.11485447422152, 72.1431661421253, 66.20489381974744, 63.94500455548687, 60.009094361336004, 61.05608086432181, 67.7902138617731, 70.09152335505333, 68.215987143978, 64.18846214971235, 60.56349785097184, 59.36994414175711, 62.3933502166502, 61.32884248610466, 63.15425472874796, 61.43326774720223, 63.087672495072894, 61.95190314323672, 63.98006270008703, 64.97661536739719, 67.37223825147076, 70.25841236114502, 76.87043805276194, 78.13643009431901, 74.36303938588789, 72.56912769809847, 68.98614452731225, 58.26055272932976, 58.97512620495212, 57.93586284883561, 60.33923633636967, 61.99941873550416, 66.64177525428035, 65.45865897209414, 59.226134361759314, 56.40804867590628, 71.08386731916859, 76.31756428749331, 78.22571892892161, 73.38479242017193, 74.96913971439486, 71.6996088335591, 73.97412853856241, 68.77359913241479, 46.41224522744456, 73.75746465498402, 67.25478679903092, 62.635336922061065, 63.104593599996264, 67.24785204856627, 71.15108889918174, 72.87361344983502, 71.8260346689532, 71.16303643872662, 70.30021698244157, 67.83820798320156, 69.038743511323, 71.90279545322542, 70.80863460417717, 60.04795328263314, 57.41483480699601, 56.341788076585345, 53.346164149622766, 56.49155985924506, 54.45215878948089, 54.890526802309104, 60.09151904813705, 62.05956435972645, 65.79871669892343, 68.90419836967223, 68.63210355081867, 70.27909894143382, 72.04067460952267, 73.12452746975806, 78.63861899222098, 69.63220596313477, 57.6638739339767, 58.34257341200306, 68.20500450749552, 79.06412555325416, 77.94484584562241, 75.64163008043843, 76.24666352425852, 77.03931177816084, 77.98499522670623, 81.93506517717915, 74.92158489842569, 90.50020371713947, 53.82687022609096, 0.8189837826836495, 2.131523326519997, 0.7398799951038053, 1.3153502897870157, 0.19588846773389848, 0.7880402043942483, 0.6926137184904468, 1.232238452761404, 0.04097380277310168, 0.04049236247796686, 11.516976068096778, 31.446888985172397, 52.46581562103764, 42.77800844561669, 35.964533744319795, 22.010774420153712, 47.363125816468276, 66.98910113303893, 67.52808186315721, 81.987028737222, 61.655630834641, 1.1503763809319467, 0.07551571519504632, 0.017217324310613256, 0.04989399266759715, 0.05096707500577454, 0.06871422572482018, 0.03872944477705225, 0.03247035704853554, 0.023683311320060206, 0.006892898602546343, 0.087760251706406, 0.022265361096229286, 0.021725025876695593, 0.05962940736583645, 0.04381630689867082, 0.01864793605261272, 0.01691589361026643, 0.02410778148670591, 0.04814980964687082, 0.044084253811067155, 0.04033107032638885, 0.045401032548397786, 0.0834248528905934, 0.020377440828709834, 0.03346223023629958, 0.03107551586694054, 0.03133262838086775, 0.028763608068167686, 0.05957269387680197, 0.026868637876525044, 0.10581756461291544, 0.043035636490751664, 0.07772381808007918, 0.0536799723763139, 0.06312643403127309, 0.04908036898761507, 0.10340510011320153, 0.09275915161255868, 0.13710258829016841, 0.18010166323473378, 0.1545449241154617, 66.11129037795529, 108.2309486019996, 91.07791393033921, 86.84117363345239, 67.1673728573707, 50.20030952269032, 37.8722059342169, 53.645248797632036, 75.6527146985454, 25.187241185096003, 0.025311127500308138, 0.37094679030199207, 1.1049566826512738, 1.0728921645110654, 1.8373958189641277, 1.8748559249985604, 5.156307133936114, 2.5340607329722378, 1.3294024260774737, 33.113919842627745, 100.76718022746425, 95.64543554859777, 91.6863755256899, 80.34026084407684, 76.02359048781857, 77.61204842598208, 76.96050351665866, 72.52097668186312, 67.14597240571054, 64.38281951412078, 65.03818873436221, 71.63784719282582, 73.79708059372442, 72.03770929767241, 67.59735092040032, 63.936948007152935, 63.2996452239252, 65.16302600983651, 63.57597228019469, 66.34678948310115, 66.28636929296678, 65.48676667674896, 65.33607705946892, 67.52706204691242, 66.9081747916437, 69.65661095034692, 74.36658520852366, 79.26376635028471, 79.78328427960797, 78.07714739153462, 75.09969972795056, 72.3808382403466, 61.28244084696616, 62.338036952480195, 59.19529276509439, 61.960398997029955, 66.01025012231642, 70.79691456210229, 69.87749530423072, 61.97635127652077, 59.3433936180607, 72.8596027435795, 79.34474760486235, 80.6572432671824, 77.7705043362033, 79.31638102377616, 74.481385138727, 77.97530697238061, 71.89336607533117, 49.11969261784708, 78.53804157626244, 69.41619319300499, 65.95201076999788, 65.03685905087379, 70.48654525510727, 73.76323838387766, 77.01984897736581, 75.27022869356217, 73.18796004018476, 72.96968014009538, 69.17550086975098, 73.62430803237423, 74.065260887146, 71.54301212679955, 61.17883928360478, 59.92119012340423, 60.452620290940814, 55.799885180688676, 59.504465749186856, 58.15960661057503, 59.09799052822975, 62.69906759262086, 64.88689114970546, 67.25892097719255, 71.93838704016902, 70.47972033100744, 73.35220536878033, 74.05442730073007, 78.28668040613975, 79.91695081034015, 74.38986055312618, 60.84253134266023, 61.079101254863126, 71.2725725481587, 82.20805429643201, 81.27067842791158, 80.20464097299885, 79.04794185392319, 79.42193984985352, 80.83241631907802, 84.8347165507655, 81.21610256933397, 94.03680093826787, 64.99100654355942, 2.1574783853946196, 1.664016638551989, 0.42974492715251067, 1.7390422643192354, 0.386491633591152, 2.3067402599319338, 0.7909555060248222, 1.707760381602472, 0.20482221738465373, 0.11225600501582508, 12.43673853335842, 35.15297574381675, 48.60262616988152, 29.655491536663426, 26.45049345108771, 31.83185196691944, 58.51463602435205, 73.67788760892807, 76.53976655775502, 90.40460771129978, 78.30870059228714, 2.320903448327895, 0.11131489664436349, 0.03527662521528621, 0.0385076699838523, 0.0272105390866918, 0.043960794911629734, 0.047711902298033244, 0.024650658202928402, 0.061634542916210434, 0.021227107030309496, 0.05912142595456493, 0.04426567492285564, 0.009228682967894261, 0.020359577573535424, 0.047873719219839385, 0.02742512414472238, 0.05443765631606502, 0.02541527715361407, 0.033906733602165215, 0.05555624427694467, 0.04122678032745758, 0.032221949208647974, 0.17805165791463468, 0.10904535350780334, 0.16969274999874254, 0.15539898957696655, 0.16260760115279307, 0.0930442588944589, 0.12595004116695735, 0.1576278917491436, 0.26316897523018623, 0.17177532937738205, 0.13203151524066925, 0.1750538639363743, 0.21693330137960373, 0.21878259166354136, 0.2407606736186051, 0.1450865574541592, 0.2896627777766797, 0.34568951495232125, 0.45134036351115475, 77.57590770721436, 122.68794998045891, 105.02329703300231, 98.04785590017997, 76.31127280573692, 58.3649544562063, 60.18569123360419, 64.82850666969054, 86.94053511465751, 36.849577350001184, 0.12402804913900553, 0.46463088583081, 0.9938405321971063, 2.9516968131065373, 2.5609615733546596, 1.7233422422601332, 6.828385101210687, 8.536145360239091, 3.3676957939901664, 35.776122693092596, 103.39874544451314, 100.29809613381663, 95.20793437957765, 84.79455932494133, 79.86112763804775, 81.56028270721436, 80.47503348319762, 75.98735563216671, 72.73079210712065, 67.52251994225287, 68.1448196595715, 75.75585734459662, 77.98406170260522, 75.40330686876851, 71.1999616315288, 67.72935436617944, 65.83090366855745, 70.59352397918701, 67.72300797124063, 68.9133845606158, 68.86546888659078, 70.41256935365739, 67.36339722910236, 72.24557922732446, 70.06161136011924, 74.7370844502603, 78.44081386443108, 84.76929926103162, 85.43874586782148, 83.036819734881, 80.32138639880766, 75.76563973580637, 64.42440448268768, 66.9843864440918, 64.30018301933043, 64.53575664950957, 69.90842711540961, 72.83549585650044, 72.74855259926089, 65.52039315623622, 62.05028403189875, 75.68075180053711, 82.84959716181602, 86.4798370484383, 80.05145672828921, 82.92091369628906, 79.40872930711316, 81.62040479721563, 75.387907643472, 54.07603879128733, 82.29002398829307, 74.16064508499639, 69.05393092863022, 68.50720743979177, 73.06907300026187, 78.07651196756672, 81.07987865324944, 79.6842287432763, 75.01687495939194, 74.77149148141184, 71.45192684665804, 75.417521538273, 76.07990787875268, 77.15094243326496, 62.50024264858615, 63.26810152299943, 63.65946777405278, 59.28051802419848, 63.23528305176766, 61.98878911233718, 62.74986620872252, 66.07829540006577, 68.49761332235029, 71.94194855228548, 75.76679291263704, 75.7600699701617, 77.05488358774494, 79.45582912814233, 81.51726999590474, 84.49800460569321, 77.93844453750118, 63.14916741463446, 65.06240937017625, 74.47248135843586, 86.0120238027265, 82.82017938552364, 83.94363249501875, 80.1450837043024, 81.78931774631624, 83.46788821681854, 89.63473273861794, 82.78009276236259, 98.0852831563642, 61.84665026203279, 0.9777586919165427, 5.446327184477161, 3.0982412205588434, 4.487689618141421, 1.13505793194617, 3.4100274837786153, 4.643324363616205, 3.072030717326749, 0.2412726961436772, 0.09481681781190057, 21.59472469360598, 49.92756751275832, 69.51672354052144, 62.19541565064461, 45.335232980789684, 32.734954164874175, 63.539184370348536, 85.71869327176003, 87.7061660828129, 102.72657671282369, 86.60654529448479, 2.065424034672399, 0.1637074122986486, 0.13374909968866458, 0.19056337525046643, 0.17039787264600878, 0.20468070562328064, 0.1825065204813596, 0.10863609401689422, 0.10782286104175354, 0.10340044229862191, 0.14917349863436916, 0.2596270136775509, 0.10220789620953222, 0.19522102129074836, 0.10610486290627912, 0.12775965575729648, 0.18928524947935538, 0.2081412779948404, 0.10806736566366688, 0.17241450717612622, 0.08184795282901296, 0.16702242796459507], [0.03944218999916508, 0.10173328941868198, 0.051181058684784564, 0.031867658441525795, 0.042551361670297, 0.05679754803197519, 0.01898498792621878, 0.06775153665653161, 0.035658834141588984, 0.07346950201017242, 0.0459918778599991, 0.01544442544165518, 0.011779359305247426, 0.0569819453953495, 0.06184646964914376, 0.03271082438708794, 0.09190817348538868, 0.09544937661097896, 2.7878819646373874, 85.41471742814588, 86.4946008497669, 90.95672053675499, 80.73684384745937, 39.65103610869377, 27.63385292022459, 65.39818779114755, 49.64128940336166, 57.88270296589021, 5.591788772613772, 0.048619754792701815, 0.12780988814249156, 0.357999965668686, 0.6067781018153314, 0.14703985183469712, 0.7677644310939697, 4.270397174742914, 2.760180715591677, 5.3116717261652795, 67.8287080026442, 94.5792333541378, 87.94796451445549, 85.88703355481549, 83.33757139021351, 85.86775118304838, 83.74254042102446, 81.40711415198543, 79.14618938199936, 75.96874006332891, 68.46427317588561, 61.04840870826476, 60.13990932895292, 63.04111003875733, 62.19618835756856, 63.47311204479587, 60.50583116469845, 60.12514552762432, 61.38702300287063, 65.51018714904785, 67.02076250506987, 70.07140944080969, 70.5249374143539, 69.03557423622378, 66.6800497424218, 67.53564419284945, 66.96691620734431, 66.96250746327063, 68.65219393084126, 68.8497244927191, 70.97154632691415, 68.32953976046655, 58.62036351234683, 56.95397592359974, 56.47779233994023, 57.15610350331953, 57.7094675648597, 65.85726199611541, 70.70190691178846, 70.6090408755887, 64.82210143919914, 53.31340843631376, 60.326771043962054, 69.82872455350815, 74.337889148343, 75.55869548551499, 75.08916424166772, 72.03366925639492, 72.74095889060729, 69.17242573153588, 48.68119516680318, 75.66670187057989, 66.11660911190894, 67.07100022223689, 63.77933932888893, 69.92234368478098, 71.80009995737385, 72.99174739468482, 70.2605696647398, 70.13252781283471, 71.53588910256663, 72.0440007794288, 71.89124799543812, 71.3797866144488, 66.18812960963096, 58.16987929805633, 57.36353412751229, 56.95816501494377, 54.128943720171534, 55.16143706537063, 53.30493219437138, 55.671290274589296, 60.6253771628103, 63.50669537821124, 64.91321417593187, 67.02009570214057, 65.3298444132651, 64.84782042041903, 65.45543086144232, 74.16020577953708, 75.51911877047631, 64.34342322811004, 56.86138837568222, 57.25642988758703, 70.50742010916434, 77.24045092059721, 78.43383989026471, 74.49312871502292, 74.68574062470468, 79.64143568469633, 77.37987549074235, 77.96656008689635, 77.37335651151596, 78.1385560189524, 89.3938050731536, 73.08106760824882, 6.734509544987833, 1.097910144636708, 0.5090386738940593, 0.7780770164343619, 0.13893160788762954, 0.1375467967121832, 1.3225372976833776, 0.31889047233327744, 0.27368776079627777, 1.760899181808195, 22.98888018054347, 33.54411755838702, 59.817686619297156, 56.128850444670654, 28.825492512795236, 29.155801188561227, 52.56337673433366, 73.84198388745709, 64.41110372543335, 80.08644427022627, 18.71187871502292, 0.5967348729891162, 0.17366559004351018, 0.0825132925303713, 0.049318365692611665, 0.11197256014472055, 0.03250827073990818, 0.09353753524802386, 0.08213410199049019, 0.0845053279772401, 0.01277797598196494, 0.06393757175594088, 0.03954353194022852, 0.11468412069183205, 0.03199342135039549, 0.03013705432925734, 0.05898055387660862, 0.01694258219832855, 0.041557760954263716, 0.054769464317829385, 0.016064791951418644, 0.12531431076387245, 0.014207660757576027, 0.01914606557317799, 0.06152979954476319, 0.02956411632288608, 0.028838738310901873, 0.07340245399503939, 0.03751904883932683, 0.06926459095050251, 0.04038831241609108, 0.09425672326957989, 0.04560295800347963, 0.023822367769635977, 0.03993295358433839, 0.026093965937053005, 0.02168103902330322, 0.07244826850271033, 0.0901680966959365, 0.16299816809834974, 5.344563741837779, 104.21819917617306, 94.68134049446353, 104.72889961734896, 92.80290957420104, 52.95411540615944, 37.800705048345755, 51.35709493390976, 46.378269657011955, 60.00256753736927, 6.419372106752088, 0.17077566124498847, 0.32236685675959437, 1.732830087984762, 2.8376411526433887, 1.0345666855573654, 2.587256162397323, 6.258141119633952, 0.41788242336723114, 7.2537700687685325, 74.84927992666923, 99.22910121179397, 92.9839583366148, 90.33060827562886, 89.12831552567022, 90.1947295281195, 88.85331030814879, 84.47909878146264, 82.74239878500663, 79.64480107830417, 72.41515113461402, 63.80062603181409, 64.14672028633856, 68.05848829207882, 65.3288834325729, 66.17163996542654, 63.48834653054515, 62.2154236608936, 64.76002993122225, 68.61939507146036, 69.37853843935075, 72.03673654986967, 72.92614967592301, 72.95764630840671, 70.64700157411637, 69.57338610003072, 69.6028038763231, 68.99129067697834, 71.33210628263413, 73.91186483444707, 73.9359168083437, 69.59750867659046, 60.51604501662716, 60.87469477807323, 59.57960267220775, 59.21849750703382, 60.682208384236986, 69.63263742385372, 75.67291490493282, 73.73567981104698, 67.88668847853138, 55.63209010708717, 63.15799666989235, 72.83378570310532, 78.57845767851799, 76.86796695955339, 77.55416208697905, 75.41133203814107, 75.55199607726067, 72.90492965329078, 50.54338747455228, 77.83538033885341, 71.76481431530368, 69.66593050187635, 68.50530116788804, 73.18042908945392, 74.51295237387382, 75.86630344390869, 73.82055990157589, 70.7072413352228, 73.40609873494795, 73.39363344254033, 74.89992557033416, 74.26234429882419, 67.93785971979942, 60.05402118928971, 59.8247076619056, 59.20993889531782, 57.43405834321053, 57.681952138100904, 57.20482718560004, 59.40935611724854, 63.644680438503144, 68.11166778687509, 67.82117705191335, 70.26932439496441, 68.56448188904794, 68.50959224085655, 70.88152793145949, 77.37290936131632, 78.5517620271252, 67.98404170620826, 59.294626789708296, 60.15313163880379, 73.37300962017429, 80.40012405764672, 82.40887180451425, 77.22158432006836, 82.41421407268894, 82.41823842448574, 80.40866697988203, 80.34632482836324, 79.47657062161353, 82.48488733845373, 90.32396378055697, 85.37519562628962, 13.16124737262726, 0.1896647847588024, 0.2324518525312024, 0.6402570021248634, 1.0029760387636002, 1.4480843995848012, 1.355136238759564, 2.238241458131421, 0.2307105193575544, 1.4242112612532032, 28.077214110282164, 38.88200836796915, 49.052027810004454, 36.76415205001831, 25.741983959751746, 39.746326169660016, 59.84527264871905, 82.79305227341192, 70.61458710701235, 90.82179100282731, 28.678417359628988, 0.556653949522203, 0.16989770916200456, 0.09552689704803691, 0.12053151660028005, 0.058390888340410695, 0.028749705487561804, 0.03382776525893039, 0.06686390888306402, 0.07801599635352051, 0.02130429996477981, 0.08160691858539659, 0.01613731462238056, 0.03656523873008067, 0.03871186688962964, 0.060487226658170266, 0.012578167802383824, 0.036543543120065046, 0.022364105999229417, 0.018094560101387963, 0.031613690718527765, 0.08815427370850118, 0.15040506158144246, 0.11202918170320411, 0.20037945900713244, 0.12243410362110985, 0.17634654537804667, 0.14542064839793792, 0.09830277067639175, 0.12700413984637107, 0.12491442818915653, 0.12239743099217454, 0.12013968560964831, 0.12436579432218306, 0.1544627228811864, 0.2068851083036392, 0.1166122031187819, 0.17224903218448165, 0.3332800243891055, 0.23256370136814736, 6.0974901530050465, 118.64014241003223, 110.85917980440202, 118.32756088626002, 103.96420217329457, 56.0846100314971, 41.45696593869118, 91.82659241460985, 73.6694231340962, 86.66462775199645, 9.325757699628031, 0.23881554573533997, 0.41765526297592354, 1.492853474713141, 4.1989820907192845, 1.3197743556191845, 3.4110774532441175, 11.295575922535313, 9.233678098647825, 8.474026783820122, 76.70383145732265, 103.46395877099808, 97.83417301793253, 96.8540511592742, 93.54970532078897, 95.14250924510341, 91.22568530421104, 89.33984110432287, 85.92602975906865, 82.52287941594278, 74.50090285270446, 66.79281004013555, 67.70388249428042, 72.53971776654645, 67.54583451055711, 69.76031841770296, 68.391646569775, 65.13766788667249, 68.1635372100338, 74.04023616544663, 72.94816201733005, 76.99162360160582, 77.66735384541174, 75.43104587062713, 74.71966912669521, 73.53494859510853, 72.16012647075038, 72.16072267101657, 75.23695130502024, 75.55725205329158, 77.11971252195298, 77.20585561567738, 65.23703721261793, 63.91886980302873, 63.28820759250272, 63.982467113002656, 63.022439556737105, 72.15934984145626, 77.30383642258184, 76.79581103786346, 72.82179109511837, 57.782482485617365, 64.95583465022426, 77.02876060239731, 81.06016482076338, 81.24209219409575, 82.40553778986778, 79.224166101025, 77.27219858477193, 75.41908264160156, 56.144543847730084, 82.42885235817202, 74.52222485696116, 73.96123963017618, 70.28312329323062, 75.7618115025182, 79.625926633035, 79.1486918541693, 76.98698736006214, 74.62830143590128, 75.20726680755615, 76.08571298660772, 77.93515759129679, 77.68547519560784, 72.3386178478118, 61.26930090688891, 61.85440086549329, 63.260335230058246, 59.27142597013905, 59.73585421039213, 60.260200577397505, 62.26189982506537, 66.22312499630836, 72.98962931479178, 72.68457874175041, 75.50483349830874, 75.57589900109076, 73.58433908031833, 74.44762922102406, 81.72535957828646, 81.42548653387254, 71.5740066959012, 62.86129682294784, 66.04430414015248, 76.90330751480596, 83.49954958884948, 86.12745131215742, 81.32217130353375, 84.15381662307247, 81.20372356907015, 85.07690721942534, 85.42062451762538, 84.7861183843305, 83.66534033129292, 96.28186364327708, 85.21716333204701, 8.802479197902064, 2.294078358719426, 1.6852279584253989, 4.797199435772435, 1.1024230766680934, 1.5311644899268306, 5.701475893297504, 2.5824220863080796, 0.4596655329148616, 2.9852870106697087, 38.16827427956366, 50.945748129198634, 83.42802124638712, 77.41107402309295, 39.89264626656809, 45.61834573745728, 72.09270092748827, 93.29829708222421, 81.58166746939384, 100.55953779528218, 28.454771657143873, 0.7067553951374946, 0.4025057823427262, 0.155174924180873, 0.30365215614438057, 0.19421755336225036, 0.09994421364559282, 0.1800241198150381, 0.13376740919005486, 0.37679292982624424, 0.0844268499302768, 0.18945893693354823, 0.11861409811723618, 0.1415016643342472, 0.19413052577405207, 0.17270960424455906, 0.17490792418679885, 0.1219171321680469, 0.173904808658746, 0.09058573718873725, 0.1624406399505754, 0.20376087917435556], [0.07618743640881392, 0.06445543570143562, 0.048237354344417976, 0.037316717357645114, 0.02314684484454413, 0.07502247714587758, 0.04974296226376488, 0.056950106781216404, 0.017324228050006975, 0.006019154257486545, 0.07597673158611983, 0.043250363275048234, 0.07171363614860081, 0.0853286579912228, 0.07721719647487325, 0.07653155544352147, 0.132190968781229, 0.8890883660604878, 28.614459191599202, 101.41412811894571, 77.90999950901156, 79.03088738841396, 57.64544271653699, 46.078698635101325, 42.40297494396087, 65.45758032029676, 48.54916818680302, 28.935685619231197, 0.12205903463426138, 0.01907648755267503, 0.4708491295816437, 1.100387734270865, 0.14027802273631096, 0.8216873988989861, 3.347418611088107, 7.0994978566323566, 1.2068875614673862, 31.959887935269265, 87.87077226946431, 92.33257816683863, 91.37223289858912, 89.49800675915134, 92.1275794121527, 87.35702806903471, 88.69732549113613, 87.2227418038153, 87.26828052151589, 82.4602940774733, 81.66576308588829, 72.10743334985548, 62.00599655028313, 60.85296092494842, 62.60780188345141, 60.91622875582788, 60.466650609047186, 59.56687065862841, 63.38402717344223, 69.96930230048396, 69.41001153761341, 72.96590681998961, 71.96542001539662, 71.27473769649383, 73.22337119810044, 69.83365889518493, 68.91517316141437, 66.79015851789906, 67.53733865676388, 69.22239672753119, 65.1487172034479, 56.702559840294626, 55.67652663876934, 55.55538423599736, 56.09366678422498, 55.74612125273674, 58.11229498155656, 67.28065875268751, 73.37788904866865, 73.85535916974469, 71.42137942775604, 59.457593425627685, 55.84297241703157, 62.15507799579252, 70.29049734915458, 75.42073003707394, 73.18035064205047, 71.35482465067219, 74.68496399541056, 66.56275518478887, 47.978879097969305, 73.21456155469342, 66.44638630651659, 66.77953673947242, 65.02978309508293, 69.48057497701338, 74.50485660183814, 70.14970779418945, 64.68476356998568, 68.34697077351233, 70.26936361866613, 72.83734721522178, 72.75081188448014, 66.23459400669222, 62.47298609825873, 57.47140322962115, 56.36274530041603, 58.79573268275107, 55.180962624088416, 52.983109566473196, 52.916091949709006, 55.20051563939741, 60.09665735306279, 64.28960046460553, 65.51078334931405, 67.58410115395823, 68.45651472768476, 68.56411318625175, 74.09065431164157, 72.15480773679673, 69.20366348758822, 62.346701468190844, 55.80972248508085, 55.9385762676116, 70.4250503355457, 77.14839289265295, 74.12150767541702, 78.00409716944542, 70.31802454302388, 79.40287713081607, 79.61953316965412, 72.52854685629569, 71.63697642664756, 74.32330577604233, 76.60046131380143, 80.90197563171387, 91.2782842882218, 23.036564434728316, 0.26908259177880905, 0.44978535824245025, 1.4062097884954945, 0.06458904909630937, 0.4839924710892862, 0.5257024652054233, 0.32871509030942, 0.21879129442236117, 8.926683010593537, 26.12019262006206, 35.902921153653054, 62.90585887047553, 29.332409827939927, 24.44421091387349, 50.70798581646335, 69.45639748727122, 65.304074441233, 69.79704749199652, 58.14042622043241, 0.7368199947860934, 0.15968030258532495, 0.040201245236300656, 0.05791639646274909, 0.06394881792666932, 0.03090298712073315, 0.032176328672757076, 0.03078258874255323, 0.09159784658902115, 0.019847610589837836, 0.09408691988116312, 0.024213011323985074, 0.01774066386954679, 0.028500466442276395, 0.05829848281498398, 0.03211980287526404, 0.03265937775253289, 0.06849496370001186, 0.05537023429848975, 0.07167083481627126, 0.011901209420043857, 0.10828605312253199, 0.04187513202909501, 0.02964119625938756, 0.044320741322852915, 0.06758374041847645, 0.015318689345862838, 0.01415571616587019, 0.03196211325214996, 0.04553408669908682, 0.11256993252543673, 0.05974860681641487, 0.046677813835201726, 0.05236037826586155, 0.07862744176940573, 0.08867345149478606, 0.13162916586283716, 0.20907878575305786, 0.6610291391130417, 41.956620985461825, 115.69773720156763, 89.65863566244803, 88.16369487393288, 67.31620327118905, 63.12799053807413, 30.081606065073323, 38.14807407317623, 57.255802308359456, 31.68278228852057, 0.06047494626874405, 0.11808935853262102, 0.8506167175308351, 1.7474733990046287, 1.7155160105997518, 2.274501564041261, 3.031982827571131, 1.469856618392852, 1.1463346236175107, 38.70303846174671, 90.765104909097, 97.87564031539425, 95.82373080715057, 94.1158837656821, 96.65299830898162, 92.80387447726343, 90.90966778416788, 93.05567495284542, 92.93335191665157, 89.06489079998386, 85.31003721298711, 77.39313310192478, 65.1854148987801, 64.16967007421678, 64.9535204518226, 64.44277294220464, 63.01155497950893, 63.69960146565592, 67.65915178483533, 72.03610897064209, 73.08671582129695, 76.61536632045623, 75.51576906634916, 76.86821799124442, 74.82527502121465, 74.0219186967419, 73.02524443595641, 70.91591927313036, 69.00473656192904, 71.84797640769713, 68.35390552397698, 58.33913349336194, 59.649887623325476, 59.47884482722129, 58.80673100871425, 57.62805092719294, 59.52341079711915, 69.19566185243669, 76.35318725339829, 78.14589085117464, 73.17545552407542, 63.05617194021902, 57.20889468346873, 65.46264017781904, 72.6810956770374, 77.01351042716735, 76.45916185071393, 75.03789101877521, 79.80692832700669, 70.25031658910936, 51.78076974807247, 76.26457306646532, 69.55263676181917, 70.88453246701148, 68.93967228551065, 72.78743113240888, 76.2990193213186, 70.53565332966467, 67.83146150650518, 69.8771736698766, 73.85872456335252, 74.66714074534755, 76.80128666662401, 69.34730852803877, 64.6705920465531, 59.79144988521453, 59.024571603344334, 59.588631968344416, 57.81387321410641, 56.94005935422836, 56.286929807355335, 58.40975969068466, 62.775251788477746, 67.2235490429786, 71.39508385812083, 72.0073030840966, 73.29523686439761, 72.24369648964175, 78.19586184716995, 74.11460430391374, 73.40232541484218, 63.38938513109761, 60.15344542841758, 60.24868842094176, 72.78955705704229, 79.8482701086229, 77.31819229741251, 81.24155090701196, 75.9205105996901, 82.42653815977036, 79.06853429732784, 75.94783383031046, 72.29110225554436, 78.34280952330559, 80.24317433757167, 80.89064782665622, 98.08715804930657, 35.1633111892208, 1.7339621820757467, 0.3350776956687051, 0.926912088067301, 0.7272529662136109, 1.155924205818484, 0.8462200470028386, 0.5980385094881058, 0.21259149806874417, 8.724408341992287, 33.1374462189213, 35.20800267496417, 45.836974728492, 17.515130235302834, 29.944827133609405, 61.649151079116336, 73.36067768835252, 73.68344952983242, 76.97535361013105, 74.07166219526722, 1.58127669124834, 0.22298692815726806, 0.04309555988818888, 0.018439807200564012, 0.05433709578468435, 0.028409233031373833, 0.07155866422239812, 0.027760929210231673, 0.05867883780850999, 0.05638033654841204, 0.12700427774219744, 0.07806978338668424, 0.0135245889936003, 0.05742828354179379, 0.040787926860033505, 0.04790047101015526, 0.04882333882813973, 0.044707654029010765, 0.030768676585848295, 0.03683438840051813, 0.021746673606215947, 0.16963204519162256, 0.16962950177971395, 0.12031802321754156, 0.11340385753541224, 0.11297831867611217, 0.13973474382392823, 0.15820670181945448, 0.18899381431120058, 0.14936430049279045, 0.201427084243586, 0.24477256882575252, 0.17059288798801361, 0.23982037730034322, 0.1905326398029443, 0.193557262180313, 0.2896190494779618, 0.32359480377166505, 1.2506275047217648, 47.209486576818655, 131.6773085440359, 102.62881555864888, 101.28992234506916, 80.19516452666252, 63.26969400528939, 60.952130210015085, 92.75174617767335, 72.60857889729162, 43.87638584260018, 0.2939179978303371, 0.15378309564004022, 0.9974847205223577, 2.1789810638273917, 2.154180652672245, 4.123344575205158, 11.710981399782243, 18.193568875712735, 3.778322843774673, 38.857983850663715, 94.71406875118133, 100.8637176021453, 100.97887054566415, 98.1734109693958, 100.18952492744693, 96.3841433678904, 95.49761710628387, 98.86122211333245, 93.78833447733234, 92.56096993723224, 89.95494719474547, 81.64262110187163, 67.10840394420009, 65.84470256682366, 68.77762348421159, 68.83441940430673, 65.54257808193084, 67.29760339183193, 71.28918770820864, 75.99502778822377, 77.54481900122859, 79.92243428384104, 79.83216485669537, 79.9252034771827, 80.3041515042705, 77.84122467041016, 77.07564861543717, 74.14234330577236, 74.77761037888067, 77.41586715944352, 73.74704683980634, 61.605208766075876, 63.39351146451889, 60.47851185644827, 64.01178683004072, 61.23564304844026, 63.294051924059474, 73.81365653007262, 80.87590755954866, 82.17812661201724, 78.64378867610809, 64.8100087719579, 62.77647556797151, 69.25852960155856, 76.14825910137546, 80.43464091516311, 80.0808431256202, 78.4556168894614, 83.47468176195699, 71.97796375520768, 55.82725940212127, 78.78556666835662, 73.06100860718759, 73.7821912765503, 71.84232034990865, 76.29690124142554, 81.37888877622544, 75.9704972851661, 68.60617668397965, 71.95249188330867, 75.68057921624954, 78.39963682236211, 80.69794962483068, 72.37618630932224, 67.87135985589796, 62.88492518086588, 60.96967889416603, 63.70122140453708, 61.08032111198672, 59.17739891236829, 58.305683520532426, 61.33553012724846, 66.84874303879278, 72.74925078115156, 73.3683184654482, 73.93939987305673, 77.15813606016098, 74.93507785181846, 80.90152063677388, 77.7315708898729, 78.93136901240196, 67.44563364213514, 62.67644336146694, 61.391274852137414, 79.89586414829378, 82.49320276321905, 80.84913346075243, 84.9328464077365, 81.65087376871418, 82.84722805023193, 82.56447222925003, 80.43883785124748, 78.05901035185784, 82.33457426871024, 83.54389590601768, 83.95307756239369, 101.27620973894673, 27.448846486306962, 1.5669270676951257, 1.9041382569459178, 6.0801748498793575, 0.6744312038344722, 2.65586307452571, 3.3940122012169134, 0.8192229246900928, 0.32659462022204555, 14.680416641696809, 43.461854073309134, 50.19288447595412, 87.08195224885019, 41.1100636759112, 38.112929636432284, 68.90221365036504, 87.82105230516004, 84.79393174571376, 87.90557938237345, 81.1539722258045, 1.3458191387114988, 0.35308658415752076, 0.14718373846863547, 0.21787842405178856, 0.12188575320666838, 0.08212001363356268, 0.27997541211305127, 0.0903088576911438, 0.15236923441050515, 0.23315843074552475, 0.2864261482271456, 0.17933862434039194, 0.1382027518364691, 0.15812370385373795, 0.26860133534477604, 0.11675356166257013, 0.17334594751798338, 0.08969225650352818, 0.12731923947050688, 0.12876742909992897, 0.09805459649332109], [0.04381495092304484, 0.15538841756361146, 0.07413442802405165, 0.043037172497039845, 0.027276413072080865, 0.05026314745567018, 0.04340206017537464, 0.041982503082122535, 0.026777802831343105, 0.00428758391682359, 0.031079784891898596, 0.04390400481380282, 0.019248501104753346, 0.04030963135582786, 0.02623582243799202, 0.03920418180284962, 0.049018426948497375, 1.563996444306066, 76.29869768696447, 80.27014455487652, 87.08340352581394, 71.10866454339796, 63.32246165121756, 20.012934784735403, 102.58031937383838, 129.24448982361827, 48.81126880645753, 8.876455099351945, 0.24187288006707547, 0.17136174915058, 0.640298861169046, 1.4240555921869895, 2.3926798807036493, 0.48941876378751575, 2.341593215542455, 3.5547092556953435, 10.367061668826688, 76.27301400707614, 86.75652104039347, 89.28859926039173, 90.63345447663339, 94.22049337817778, 88.95418582424041, 93.35674824253206, 86.15841450229769, 84.77317456276187, 83.85775612246606, 85.21882641700007, 83.78996187640776, 80.85766069350704, 72.60879070528092, 62.045334000741285, 59.65429636739916, 59.952737746700166, 59.74763701038977, 61.0975952302256, 64.25211045049852, 69.12946793340868, 71.43135009273406, 76.56714470155778, 73.36114052803286, 74.3452553595266, 71.05282568162488, 71.37384030126756, 71.6027106008222, 68.23404573625135, 65.43761153374949, 60.39793460599838, 57.153655944332, 57.23946563659176, 54.328211892035704, 55.36335283710111, 57.68860840028333, 55.395504505403586, 57.96995609037338, 68.98841165727185, 71.85960231288787, 72.90332148152014, 71.36826269088253, 66.8960625125516, 57.58836438578945, 59.04015518003895, 63.469354414170795, 69.44090412509057, 73.62551612238731, 68.33394850454023, 70.20099670656266, 67.767699456984, 55.07015566672049, 70.5504406652143, 60.62988788850846, 61.38696808968822, 64.53084584205382, 70.12760131589829, 67.47634580058437, 64.47913331370201, 70.34816403542796, 70.69963193708851, 71.53354352520358, 71.4543116477228, 66.94211898311492, 64.51367370543942, 57.354391082640625, 55.77060860972251, 55.00186720202046, 57.0371497831037, 56.40160029934299, 51.087875212392504, 52.78918366278372, 55.027696009605165, 58.7496683674474, 62.621749831784165, 64.85898740829961, 66.19257757740637, 66.10990970365464, 65.22057110263457, 65.60885044836229, 64.08079701085245, 58.426041449269945, 55.40256084934358, 57.84506390171667, 57.21543327454598, 65.28329764643024, 74.87242191068589, 73.10673559865644, 75.62718791346397, 75.62935306179908, 71.4437290929979, 76.62172840487573, 71.76779531663465, 71.76986632808563, 71.44485089086717, 76.16163438366306, 81.22590065002441, 77.97375371379238, 95.55732342504686, 38.800293630169286, 0.34760436704081876, 0.7012393782215735, 1.1528435517703335, 0.2884249635521443, 0.8894187031734375, 0.2522092907419128, 0.049565195391375216, 0.4326212808730141, 18.762906789779663, 35.5834597925986, 45.24116277694703, 56.534709853510705, 32.22570500066204, 39.84526403488652, 53.4119579868932, 62.207959390455684, 62.475417967765566, 72.79164375797396, 14.077434597476838, 0.5397438762649414, 0.21016555808244214, 0.1157459415375225, 0.00551408350152234, 0.028019529849951787, 0.07319195601608484, 0.03794274525716901, 0.036181742776065104, 0.05856050020684639, 0.04714178732566295, 0.003473313610752925, 0.04440486160737853, 0.08600700586553543, 0.052796879843358076, 0.03905510875366388, 0.09338375841898304, 0.05582493812506718, 0.05360478850742502, 0.03777082746608123, 0.04561736811733535, 0.022813816847760352, 0.08397888767743304, 0.0456088415587381, 0.06465938362863756, 0.03645530894338604, 0.06351832247849915, 0.04467924748877845, 0.040584591803170984, 0.059810326690034527, 0.021762968296365395, 0.01494024861453762, 0.07470574575446307, 0.06522512423896021, 0.06030823404510176, 0.04358227852912199, 0.03861894042441442, 0.018671918435082323, 2.974836345641844, 97.09529261435233, 89.59713289814611, 97.36817975198069, 82.77379343586584, 80.00085815306633, 28.803941049883445, 85.9626333175167, 111.28542377102761, 56.13509485798498, 10.255201555067494, 0.3312006472579895, 0.8841898160115366, 1.9050201773643496, 1.471510387716755, 2.5277501296612526, 2.2110503623562474, 1.098672555338952, 0.596851073205471, 13.437119433956763, 81.26902318769886, 87.21887434682539, 92.09685156422277, 94.97853063767957, 98.07064487088113, 92.66106882402974, 96.1109189064272, 90.29198861891224, 90.67001881137972, 88.2525993162586, 89.60762131598689, 86.21255105541599, 84.60201017318234, 76.00781471498551, 64.40770303049396, 63.95537922459265, 62.84301465557468, 62.53100187547746, 63.428471549864746, 65.607136372597, 71.61776465754356, 74.38476931664252, 78.1391522192186, 78.04129692815965, 78.51235005163377, 72.02684433229508, 73.56642953811154, 73.09753371823219, 71.76513594965782, 66.99749500520768, 62.779515404855054, 60.08485494121429, 58.841475363700624, 57.98365692938528, 58.275763680858, 59.3675083498801, 57.587230820809644, 59.844998082806995, 71.29023890341483, 75.66968287191084, 75.66314035846342, 75.3136807103311, 69.76432708001906, 61.241071608758745, 61.26717890462568, 65.59466323544903, 70.62975099009853, 75.96273883696526, 72.09030043694281, 72.94808356992661, 72.0712455626457, 59.980708168398955, 73.65199212105044, 63.131014685476984, 65.08991695219471, 67.43257999420166, 72.27127859669348, 70.1346694269488, 67.62498794063445, 72.40074034660094, 75.71063241650982, 75.44755904905259, 73.36136802550286, 68.72100014840403, 65.95506237399194, 59.20112532954062, 58.88297011775356, 58.79837636024722, 60.19938030550557, 58.001801813802416, 56.18209269738967, 55.69160422971172, 58.18699259911814, 59.63796754037181, 65.13196868281211, 65.86865255909582, 67.57867259363975, 68.33798854581772, 67.61012215768137, 69.78062060571486, 68.31212443690147, 61.75071300998811, 58.66643175002068, 59.5151149842047, 60.50203431037165, 68.31363062704763, 78.918668377784, 78.03461320938604, 78.38095849560153, 78.68254169341057, 76.09021586756553, 79.39966078727477, 75.42884149859029, 74.2829445869692, 74.09507874519595, 78.41388287082796, 84.35592851331158, 77.15266043140043, 94.72598491176483, 51.109232517980764, 1.3255287178101078, 0.5019580909321385, 0.8043119119059655, 0.9475813854125239, 1.3425030198789414, 1.2172499731663735, 0.1925272722878764, 0.17665388453150951, 27.848622299009754, 46.20721509379726, 40.883868432814076, 47.28009316229051, 47.62611681415189, 62.59209279091128, 59.30588399210284, 71.55719541734265, 69.1459732670938, 85.22226241327103, 24.51587457810679, 0.7547607320931651, 0.1641572591277861, 0.07172082205333057, 0.044926781988432335, 0.04037298299672623, 0.029227416849725192, 0.036731698144707954, 0.030518267341258547, 0.06788469039865079, 0.0463625303499641, 0.09727327874110592, 0.03716725743405762, 0.06478791786057335, 0.03335017455561507, 0.025296420527381763, 0.12030934344135946, 0.01651274367055345, 0.07335485695230384, 0.006008530533196586, 0.017777003250235034, 0.13141076951738329, 0.19214664916357688, 0.16448888326844863, 0.21124902091199355, 0.1113604482323412, 0.18431110187403618, 0.15234580744178067, 0.07184662135137666, 0.1093883463932622, 0.1453973440032813, 0.1344147228425549, 0.12895982442123274, 0.1320648094218585, 0.14758273238135924, 0.09042573206487203, 0.1372370520426381, 0.11854494336031138, 3.561272606734307, 109.69005461662047, 100.94622858109014, 114.40762258345082, 92.16536752639279, 86.64524339860486, 30.554543887415242, 133.61536733565794, 154.488950544788, 71.84527781701857, 15.693671741793233, 0.37845580027468745, 0.7102630972381562, 2.412306930749647, 6.338163354704458, 7.719281373485443, 6.05275797267114, 9.299025766311154, 10.69101708550607, 14.012118308774888, 87.16878567972492, 87.7763137509746, 94.54884283004269, 97.08752632141115, 103.11342439343854, 98.91620589840798, 101.31843797622189, 95.22826794655093, 94.67322118820684, 91.72176314938454, 94.1112083004367, 88.6794787068521, 88.50267394896477, 79.28734763976067, 66.69038126545568, 66.36529522557413, 66.20660397314256, 66.71296627290788, 69.68459313915622, 70.120925441865, 75.66934554807602, 78.10579638327323, 84.45963598066761, 80.96827153236636, 81.7258773311492, 77.39394111018028, 78.540967664411, 77.51508743532243, 75.89694499969482, 72.30972566912251, 65.681547657136, 63.578694405094275, 61.400092340284786, 60.6364853151383, 62.23125826927924, 63.868969409696525, 60.18709544212588, 65.04943416964623, 74.30938920667096, 76.88757881041496, 80.5619453614758, 78.94331655194684, 73.7262268989317, 64.76835712309807, 65.0450332703129, 70.47120094299316, 75.19477013618716, 79.70427205485683, 75.70654530679026, 78.0568608930034, 73.87956803844821, 64.65437696826073, 77.91068200142153, 65.18538351981871, 67.52398690869732, 71.4162411228303, 75.33697958915465, 73.92395357931815, 69.69092384461435, 73.33038914588191, 75.58583044236707, 77.93165099236273, 76.86798264903408, 72.05307714400753, 69.71554848455614, 63.57470535462903, 63.23548701501662, 61.442724581687685, 62.46955794672813, 63.788352935544914, 58.11839034480434, 57.88917095430436, 62.012868542825025, 64.1774049881966, 69.89200022912794, 69.79868704272856, 72.24504578498103, 72.83064780696746, 71.2540981846471, 75.04240958921372, 70.58801697146508, 65.60549682186496, 61.4739074245576, 62.32822318230907, 64.60294292819115, 70.40767423568234, 81.69966805365779, 81.26139810008388, 80.12256145477295, 82.75081619139641, 81.14520965083953, 83.49124200882451, 76.62331304242535, 79.11237855111399, 78.00306166371992, 84.00478224600516, 90.98762881371283, 83.60557125460717, 103.29179025465443, 47.5341058546497, 0.9655977509194805, 4.836125037362499, 4.410478251595651, 1.0922690408845102, 3.6483335350790336, 1.2137838236747251, 0.25055702295034166, 0.9321690446907475, 34.69982824017925, 55.223288920617875, 64.26072397539693, 77.94276698943108, 46.876920577018495, 59.72639737590667, 69.85180377960205, 82.48203969770863, 78.46455204871394, 96.6798508551813, 23.073446481458603, 0.8212430066158696, 0.37591085619022774, 0.22018603409730622, 0.2302117041882969, 0.140419595784718, 0.24415222146818716, 0.10608704370116034, 0.14090710349621313, 0.23823561717665967, 0.1569879172189582, 0.166868643474675, 0.1461586055736388, 0.09301659545951313, 0.11303630387110096, 0.08638909221777032, 0.18810694496477806, 0.20651377016498199, 0.23045001881978205, 0.15068834557408287, 0.10629921175178983], [0.013787464403937903, 0.010204878166287897, 0.01496580913813124, 0.06801672565240054, 0.053112737894538915, 0.011229159746078715, 0.04304085737995563, 0.07066221877692208, 0.04287917835397586, 0.03291945694194686, 0.021660645762758873, 0.04761429503560067, 0.040293275378644466, 0.017154085667683713, 0.144819529847272, 0.23123872165958728, 0.6203252942331376, 17.74257867567001, 97.38328087714412, 78.27372089509042, 75.34524010073754, 52.334008293767134, 30.88044381910755, 40.634986200640284, 55.03393650054932, 43.1020393679219, 32.54975161244793, 0.38231743499636656, 0.03416962816470093, 0.24510463729741114, 1.2931701444810437, 1.6003038638061093, 1.4510185776218292, 1.1431490461672507, 0.8515860945467026, 0.894874903944231, 49.730240914129446, 92.76103435024139, 89.59228484861313, 86.27803894781297, 85.47997782307287, 87.64518891611408, 87.96501897996473, 84.28745177484329, 85.39294827368953, 86.26474995766917, 87.62766376618417, 79.84304551155337, 80.6073114948888, 81.07725850997433, 81.88777708238172, 69.60933854503017, 62.41249922783145, 60.14203133121614, 59.48215530764673, 58.80378923108501, 61.92590567373461, 68.817945449583, 69.19455574404809, 71.60486005967664, 68.31083789948495, 67.75157851557579, 67.63959484715616, 65.51230130657073, 63.87621794977496, 62.72358240619783, 56.532964398784024, 55.66672071333855, 57.770291759121804, 56.01239135188442, 54.297476199365434, 57.763851227298865, 52.68617437731836, 55.1952047501841, 65.14752088054534, 68.6914647010065, 73.2199038228681, 69.06070878428798, 72.16650424465057, 70.06056800965341, 62.221581782064135, 59.41374917184154, 61.01726901146674, 59.39542385839648, 67.42375466131395, 67.87815340103643, 68.2244045503678, 68.90981520375898, 57.85510124698762, 68.32205587817778, 63.34176363483552, 62.02214494828255, 61.84210423500308, 67.06505390905565, 65.75095399733513, 64.55774937906574, 65.76290545925018, 65.20585436974802, 69.48777644864975, 66.30051335980816, 63.82792572821341, 60.866818658767215, 57.84067869186402, 52.59957236628379, 52.175854406049176, 54.15439205784952, 54.19557694465884, 52.04368229835264, 52.225986219221554, 51.93036502407443, 54.569563173478656, 56.15392223481209, 54.838755438404704, 55.97391682286417, 57.28111336308142, 55.366071039630526, 56.845165452649525, 53.57981581841746, 56.38368291239585, 56.70959657238376, 58.05015679328673, 55.32698069849322, 63.637329916800226, 72.67132897530833, 73.47167291948873, 75.69200115819132, 75.6581118799025, 74.99630605020832, 72.54877059690415, 76.92874016300325, 71.56504800242763, 73.51342262760286, 69.32397827025383, 74.8386973719443, 82.30139886179279, 73.4311705250894, 85.29175112324377, 28.409176065075783, 0.5248747838120307, 0.8455767170075448, 0.9532059416655572, 0.1306540431875375, 0.11964768096203766, 0.09141110499659855, 0.07960542961354218, 5.187845931899163, 22.274343967437748, 33.56979731590518, 37.017141003762525, 17.483980732579386, 16.899467168315766, 46.32919296141594, 60.567612417282604, 71.2411072946364, 69.92414013031991, 54.02485186053861, 0.7549650630643292, 0.09909473705075442, 0.061223778062530106, 0.1421515520421728, 0.07273554381343626, 0.010970095623164408, 0.0735508758694895, 0.008716111732346397, 0.04592661866016927, 0.015299389675830402, 0.04471539917792525, 0.04738291349983023, 0.0574684457012242, 0.01592677067815056, 0.03763294696146923, 0.034287406522179806, 0.052823807833896536, 0.09445891685543523, 0.03066612997152392, 0.030839114540046265, 0.035395529722013784, 0.037913714355278405, 0.027783063405583945, 0.05373589679478638, 0.0699250353500247, 0.06761826034034453, 0.035610570602359316, 0.09922268905586774, 0.07998832035809755, 0.10976160741260937, 0.030675623716125568, 0.04240958943902966, 0.010542935530294575, 0.02206609205102488, 0.1599084129256587, 0.28516866086471465, 0.6426198624314801, 25.59008821364372, 113.38439387659874, 86.88138577245897, 86.80515058578985, 60.907042564884314, 45.92332570783554, 42.04419966666929, 55.57891845703126, 49.73516741106587, 37.33984224257931, 0.682772369154038, 0.11386779272147726, 0.5070067635707317, 1.8730877940693211, 2.55099164382104, 3.3367539317377153, 1.9916636184338603, 0.38184233790924477, 1.9183830796710908, 55.52010643866755, 95.83145787639003, 91.59615316698628, 88.50427427599507, 86.6723155975342, 88.69114383574455, 90.84222655142509, 89.02666338028448, 87.87306293364495, 87.3260727236348, 88.10939358126733, 83.37557131244291, 86.18303129749914, 83.7349545571112, 85.38865720072101, 73.43659908540788, 64.95976878750709, 63.65757719162972, 60.926171964214696, 62.000936692760845, 67.66097960933563, 71.65860437577771, 72.92946015634845, 74.03117549034857, 71.55722679630404, 71.12105138840215, 70.0819213928715, 69.02689795340262, 65.50426829245784, 64.15122708966656, 57.677868950751524, 57.89430533685992, 60.318498765268636, 58.17939496809437, 56.83019768807196, 58.50864656509892, 56.46137722076909, 58.798796053855654, 67.01188225899973, 72.11498783480737, 76.69598671697801, 71.54586761228501, 73.77061243980162, 74.30971868576543, 64.53057519851193, 60.768394624033284, 62.444556759249785, 63.330278934970984, 69.95390307518744, 70.71007328648722, 71.38311278435492, 70.8231944422568, 60.9989554651322, 71.94785564176499, 65.70303832331012, 64.46666409892421, 66.78867586197393, 70.18642902374268, 67.4353805665047, 67.04741893276092, 69.50999275330575, 66.10983125625118, 70.85890370030558, 69.96162229968657, 66.416348795737, 63.78900797136369, 59.778451150463475, 55.177911020094356, 55.89088809105658, 54.900756343718506, 56.50089510025517, 53.78850160106536, 55.14456695125949, 55.14617120065997, 58.969513293235536, 57.84704862102386, 57.71755941452519, 57.7670479589893, 59.45316114733296, 57.65018878444549, 59.44720698941139, 57.24228974311583, 59.74644460985738, 59.87971890357233, 60.15984281416863, 56.154632183813284, 65.14389268813595, 77.25640712245819, 76.73435534200361, 78.14979753186627, 78.2822951962871, 79.11392396496188, 77.78639778014153, 80.59516783683532, 74.17857816142421, 77.10305813820132, 70.86743877780053, 76.69067582776471, 85.66609428774926, 76.44167592448574, 85.09140429958221, 37.62686952467888, 0.8731488955597725, 0.48663069403940634, 1.1579412846795976, 0.9962196335677178, 0.8570251349479923, 0.32257682613788113, 0.20594819809400267, 5.476076401049092, 36.88848333974039, 38.74919299156436, 41.69947824170513, 23.54098516125833, 29.493809476975475, 54.752624111790816, 71.41833566850232, 81.457045924279, 76.31328105926514, 75.29923069861628, 1.9447170149895454, 0.08324142845888292, 0.009844661709071409, 0.0896583264693618, 0.05326205992230004, 0.04683618336134861, 0.014391812972814567, 0.06969723910573991, 0.05530236656927774, 0.0599074321648767, 0.06102832988084805, 0.012785743155907239, 0.06565615594867738, 0.06480634993603153, 0.008552535681144125, 0.03168397545514088, 0.04211935319847638, 0.03523651285157089, 0.032041897479024146, 0.03896787815216569, 0.23470218984350083, 0.11589175105215081, 0.1492398724921288, 0.1602254813957599, 0.17430732657592143, 0.2126131783570013, 0.1509114916646673, 0.20888481229063005, 0.17042710656119933, 0.24099118947502107, 0.12671466586330246, 0.11874277024499832, 0.15213142539705002, 0.16706241775424252, 0.359010343710261, 0.39855258479233713, 0.8370701379833684, 30.45639441859338, 127.72041366946314, 101.16142549822408, 98.28857175765499, 72.70242552603446, 44.91448425477551, 61.54986804531467, 77.19623011927452, 54.74812515320317, 52.86122583573865, 0.9447957671457722, 0.19129753263006288, 0.3799565665183529, 3.838043381129542, 5.3396656820851, 5.851079504336081, 6.884972155094148, 4.488264245371665, 1.802958512017804, 59.735873822242986, 98.83815073197889, 93.37583449579056, 90.26616373369771, 90.05841931989117, 91.96415778129332, 92.4986905436362, 90.36448186443698, 89.29147828009822, 89.01066795472177, 89.58454208989298, 87.83758901780652, 89.39588392934492, 87.94226138822495, 91.07188916975453, 76.65039308609502, 69.05443299201228, 66.54657148545789, 64.36198388376545, 65.63950769362911, 71.1709596264747, 75.59252200588104, 75.40012974892893, 77.99546795506632, 75.13988833273612, 74.84058795436736, 76.57118474283527, 70.22526048844861, 72.195263062754, 68.01447145400509, 60.40891724248087, 59.64390993118287, 64.71483245972665, 60.81180741710048, 60.58487869078114, 61.30414332112959, 58.99096865807811, 59.88963857773812, 71.75568303754254, 74.41756817602342, 81.60726485713836, 77.72041566910283, 77.86792032180294, 75.98813226146083, 67.82921006602626, 64.3217795894992, 66.6847958103303, 66.55201573525706, 74.04848883228918, 76.30250238603162, 73.26505814829181, 74.65906066279258, 64.90097638099425, 73.19486341168805, 70.1420670170938, 67.16608631995418, 71.0077105799029, 74.48840618133545, 71.22791244137672, 70.08861295638546, 73.15643987348004, 69.06748663994574, 74.81004053546538, 72.35134986139113, 69.93288701580417, 66.76563585958174, 61.99409215681015, 56.033007329510106, 58.23557507607245, 58.544508795584406, 59.21302187827326, 56.75027939581103, 58.94568489443872, 57.596373865681315, 61.42879232283562, 63.3463998763792, 61.93036933099071, 62.5844677032963, 62.97363350468298, 60.60502006161598, 62.71223498928932, 60.25846688978134, 63.069774719976614, 62.38361097151234, 64.8636785630257, 59.43617336211666, 68.76361277795607, 82.02335772975799, 81.12320515417284, 82.02058069167599, 80.39239698840727, 80.71117585705173, 80.72718697209513, 84.8033925025694, 77.57762570534983, 81.66297820306595, 75.650816271382, 81.18333508891445, 90.98492237829393, 78.4112548828125, 91.26511296918316, 35.62018886689217, 1.4801359248738137, 5.706273932610789, 2.868941176322199, 1.81234278265507, 1.6518317956116892, 0.4339130889744528, 0.4528069622333973, 9.039546270524303, 42.720612402885195, 48.83280261870354, 54.632819237247595, 25.33454775810242, 28.025503543115434, 65.12610866177467, 81.52797022173482, 91.17964452312839, 87.42337103812926, 81.44494933466758, 1.4052109324163007, 0.22319777087578851, 0.13130658155968114, 0.35225657385683834, 0.20342104257114474, 0.13306901279476382, 0.12286113635186227, 0.1799757949887745, 0.09981744907676213, 0.18890375301482218, 0.22950048348115337, 0.10279709443209634, 0.1958209447442524, 0.13203732218713532, 0.08740295595940083, 0.09347095454652464, 0.13607861984881664, 0.24573436157116968, 0.257337789742216, 0.18708812463427746], [0.029681061559747306, 0.07789123893505143, 0.019957197552186348, 0.05231619797526829, 0.039413622580468655, 0.010515712595905268, 0.046393572232655944, 0.07102508398313677, 0.037573992665256226, 0.04833318811330584, 0.07092186129621922, 0.016724247139908614, 0.07800075120382732, 0.05924646682556599, 0.04325777517571565, 0.0643908238459018, 0.08410871659796085, 62.601180922600534, 86.31566232250583, 80.48400002141153, 68.9672936162641, 64.26863931840467, 26.92096802496141, 42.79026193003501, 45.39533545894008, 37.760469375118134, 15.278376090911129, 0.2613754714688947, 0.14354350315707345, 2.4279059517768125, 0.8898734529652904, 1.01496267943613, 1.2076644359096405, 1.7826663750794627, 0.32333298556266293, 23.568308391878684, 88.29667106751474, 86.74109043613558, 90.50945266600579, 83.25264423124253, 86.15300163145989, 82.86718506966868, 89.3066970763668, 81.10357761383057, 79.56369430788102, 76.28840538763231, 83.18886649224066, 89.01877157149777, 84.61255350420552, 80.61164963629939, 82.10109126183295, 75.41060247728902, 64.58355073005923, 56.088916793946304, 60.04448590740081, 57.63946110202421, 60.15993302868259, 64.44051365698537, 64.22632478898572, 59.696473613862075, 59.90671265509821, 57.48920294546313, 56.985637295630674, 55.61820883904734, 54.469997729024584, 54.981898415473204, 55.481475014840406, 55.39894442404471, 57.170529980813306, 55.77217363542127, 56.246854951304776, 54.24719533612652, 54.97336333797824, 58.07299675480012, 64.33773186899, 66.4144503685736, 68.13353107821557, 64.10831635998142, 68.3014948137345, 68.91490644024265, 69.31530198743268, 60.33274481373449, 57.073153218915394, 58.979087798826164, 57.34402818064536, 59.87177218160322, 63.750929601730846, 69.81989922062044, 57.971085732983006, 67.40884965465915, 61.022171974182136, 63.138733909976104, 66.01800857051727, 61.45014570605371, 62.85554270590506, 67.49314138966223, 67.35460327517602, 69.48132022734612, 65.20494045749788, 64.58914010755478, 66.49823219545426, 66.69227184787874, 66.15933156782582, 62.269948528658965, 61.46288556437339, 58.87196786942021, 55.11576106471401, 52.064431636564194, 50.747178139225134, 51.07552759109005, 51.08734177004907, 54.086782163189305, 52.95945767433413, 51.83218809866136, 53.514975117098906, 54.9947206435665, 52.68553895335044, 55.038156970854736, 56.45456798614995, 55.38298822218373, 55.51327366982737, 55.33481367172734, 59.34548424136255, 72.66896770846459, 75.38515413961103, 74.40656200531991, 70.4505535864061, 76.8809421600834, 76.72276081577425, 74.58579863271406, 75.83648558585875, 73.37011491098713, 71.28720298890146, 77.81838078652659, 74.82910325450283, 86.89942867525163, 74.66213580100768, 79.24463302858415, 19.286464760380408, 0.3837071491345283, 0.9846435547355683, 0.314039021369911, 1.0087793080076095, 0.4060218501235209, 0.02792961411027899, 1.8741785806994287, 17.629635987743256, 21.039862286659982, 50.16859323747697, 61.61479896114719, 27.08493290408965, 25.347677892254247, 53.86732555204823, 64.54096947946857, 58.53759757934078, 76.57996300728091, 21.824965861535844, 0.7696102126952141, 0.05437720814839967, 0.04767571613492985, 0.09464917479143029, 0.08590429645752715, 0.06866272929455004, 0.15626966382466978, 0.02679939693470876, 0.010095309398527588, 0.05739602740974196, 0.02062551542035034, 0.02732327658562891, 0.04904144406018238, 0.01143581292126328, 0.03045564348388824, 0.012961033649081665, 0.04918198672033126, 0.042677042224714835, 0.026818690859081767, 0.04324886557315627, 0.030674217944784515, 0.01631353974282261, 0.03158698680870716, 0.08007666561752558, 0.010816202923325042, 0.027931785969544324, 0.027343357665344115, 0.04662909447365711, 0.06460725134539028, 0.03919151070858202, 0.00520812091229844, 0.1375722308312693, 0.032060103558544675, 0.053259118144670804, 0.0275944717108242, 0.4954438920943968, 81.52918615648824, 97.58767558682351, 91.84613366280833, 79.80296673313265, 78.57871655494937, 41.72438136992916, 40.21277443055184, 40.39577261094124, 46.03572514749343, 17.036297090591923, 0.15019703806648332, 0.47445440064034156, 3.4894449383981767, 3.2600691433875792, 3.077321259244796, 4.333241389643762, 0.6019089082556387, 0.6650126124581983, 28.27921617415644, 94.86085168776974, 90.56366766652754, 93.7472515721475, 88.15569323878135, 91.0334264078448, 84.47254057853453, 90.07330079232493, 82.62602990673435, 81.89494717505671, 78.50977697680074, 85.52996450854887, 90.8202769679408, 84.51705947999032, 83.99558821032124, 85.30683655892649, 79.03788489680137, 67.70638496645036, 60.176905124418205, 63.073465670308764, 59.935385181057846, 62.91759852440127, 67.9914471410936, 69.51662940363731, 64.04887284001997, 61.52047772561351, 61.33412591872677, 59.26946478505289, 59.448485682087565, 57.928371121806485, 57.10610897310319, 58.40998326578448, 58.15813572176042, 60.42503426151892, 57.23453521728516, 59.809916403985795, 57.34643259356099, 58.338290183774895, 61.00716106353268, 67.96559872165804, 70.37276514114873, 72.16439400949787, 69.80779478626867, 70.4715225773473, 70.12327101922804, 72.27434589016822, 63.14480181663268, 60.68558554495535, 63.124342733813876, 61.540454356901115, 61.9256232630822, 67.89724749903526, 72.8652431118873, 63.06296548535747, 72.27120799403038, 64.46429106496996, 65.33339023590088, 69.14547904845207, 69.10537673581031, 67.70687918509206, 68.72949600219727, 68.52663886162543, 70.20784516488352, 68.24428312240109, 68.35706695433586, 68.74627590179443, 67.95503185641381, 66.44430745032527, 64.43101367642804, 64.2913459193322, 62.41372692969538, 59.43863661058488, 54.82211674413374, 53.11918835486136, 54.63663962579543, 53.322806435246626, 56.27876343265657, 56.713577778108665, 54.73855849235289, 54.851389392729736, 56.92401686022359, 56.666725066400346, 57.77568501810874, 58.88824178326515, 57.09208649973716, 58.39128924954323, 58.050992258133434, 60.78553538168631, 72.9607371361025, 78.1509271744759, 75.74353325751521, 75.30539666452717, 78.72774308727634, 78.1159160983178, 78.19207283758348, 79.11949373060658, 77.19103690116637, 75.57477720322149, 80.87296578191942, 79.21271278012183, 86.81085371202039, 79.26670028317359, 83.70752150012602, 28.51800222550669, 0.32283876692095115, 0.4150048745495658, 0.7505921719055023, 1.8364434184566623, 1.0496962479045315, 0.052930822656039274, 0.6403637641379911, 19.16126466566517, 30.42777288344599, 51.016613591101866, 46.060192892628336, 26.54813889534243, 39.35322623099051, 61.36246504322175, 70.77949923853721, 65.35845810367216, 85.69370777376237, 37.991253791316865, 0.7437447554642155, 0.1234254980039212, 0.03634648232330238, 0.10137589408024665, 0.02021731313077673, 0.04724072758108378, 0.0765759808822505, 0.0740108733636237, 0.024560252166984063, 0.09200719801048118, 0.02502493428877525, 0.04004251181838974, 0.03751640200554844, 0.03909603317057894, 0.021468826922618096, 0.017429909879161466, 0.03478359784029665, 0.026364891016254985, 0.08667472043945905, 0.21219376054021621, 0.1779941553550382, 0.0877851112595489, 0.14587239512512762, 0.23186832335927796, 0.11539512689435676, 0.14332388107094074, 0.1850892786657618, 0.11334044843791954, 0.22442047784645713, 0.17771551385521892, 0.07920677277950511, 0.21433342879097309, 0.14525580159839124, 0.12154702743094777, 0.20721225849082395, 0.45977493027044886, 91.62866961571478, 108.91955206471106, 107.58800937283425, 91.46606383785125, 84.05821277249245, 39.65428383119645, 59.16910702182401, 70.19960034278132, 62.85085155117897, 25.10263369929406, 0.3251438641980771, 1.292855741996919, 7.339502784513659, 6.185065402138618, 3.280922914704969, 7.056896503894561, 6.252350230370799, 1.553278077513941, 31.080327803088775, 97.53672399828511, 90.42465102288031, 97.84319446932886, 92.51962815561603, 94.89918108909362, 86.36806518800798, 90.99519114340507, 87.08898113619897, 84.35179433514996, 79.85296126334899, 89.20890454323062, 90.35820607216128, 88.55630843870102, 86.5285058175364, 90.12973585436421, 80.65713344081756, 71.62255779389413, 63.87190726495559, 65.61445551533853, 64.14064845731183, 66.77421800551876, 72.19694968192809, 71.57879198751142, 66.86010222281179, 65.24157931727748, 65.87127270237093, 62.64303261233915, 61.37287893602925, 60.719576804868645, 60.25030051508258, 59.93283171807567, 61.011103045555856, 63.33811583057527, 62.56800551568309, 62.632963888106815, 59.20624794498567, 60.053056286227324, 63.72037826045867, 70.37362806258663, 74.43474031263783, 77.60775735301357, 72.43923448747205, 76.49000736974901, 76.81873336915048, 76.58993367225894, 66.68539985533684, 65.30734177558654, 65.95561150581607, 63.32570152897989, 66.45042634779408, 70.42164571823614, 77.25138648863762, 67.13629199612525, 74.85124895649572, 68.23666587952646, 69.65463407578008, 72.17956573732438, 70.47987722581433, 73.257778229252, 73.24645826893469, 71.97100547052199, 74.31763402877316, 71.13750965364518, 70.3172008452877, 71.97397078237226, 71.92575700821416, 70.0274710501394, 67.04965468375914, 66.74316067849436, 65.43309296331098, 60.1966699477165, 57.91651771914575, 55.66932124476279, 58.985328289770315, 56.208596152644006, 59.97627981247441, 59.05271460933071, 59.032749745153616, 58.43942065392771, 60.50658818214171, 58.772139626164595, 61.31565939995551, 62.30676781746649, 61.13655221077704, 60.63333172951976, 61.527012394320586, 64.08651190419351, 78.91818200388263, 81.21438457119851, 78.6792782814272, 77.35469387423608, 83.61063111212947, 81.47252359697896, 80.6917836589198, 81.01521445858864, 79.39337715025871, 78.49541325722971, 86.31937288468885, 82.25764874489077, 93.0224132537842, 81.98131776625111, 89.50174085555538, 26.513578891754154, 1.796837530789837, 5.526138101854633, 2.568659469965966, 3.1518661495177978, 1.5130527005080254, 0.16483803550081869, 3.5283555859519593, 27.692496276670887, 39.12849795433783, 68.35126184648084, 83.84918966600972, 36.737221056415194, 41.490219793012066, 69.36843441378686, 83.16979592846286, 76.25641453650691, 96.93039617230816, 36.05920799316899, 0.9432880448237543, 0.15885665081441402, 0.10903992960529943, 0.17382823050983492, 0.17562075367858335, 0.25521260055322803, 0.22961784815115316, 0.26414248912084487, 0.12555968106514023, 0.1431856022006081, 0.14325879424089386, 0.14761814096521947, 0.1344794725939151, 0.1055565431353546, 0.15871547613172762, 0.1365755504417804, 0.15777832077395532, 0.12512045221463328, 0.22906698496832004], [0.0333523272626823, 0.0304374527261262, 0.07982619317068208, 0.011953993835636686, 0.05289850906739312, 0.01710198594317321, 0.03898365190252662, 0.09717173378674254, 0.05115510745634956, 0.1302786601046401, 0.03149775671772659, 0.028241116951610294, 0.028403426084907788, 0.04478530470101584, 0.10902371918482166, 0.18628492741094482, 7.304630462200412, 90.45481404950543, 77.2830557054089, 85.39047718048097, 57.02967766792544, 24.922812638744233, 27.906534133418916, 71.76151952435895, 49.91921286429129, 36.059682599959835, 2.040222928889336, 0.021140822547397787, 0.28132060122105385, 1.5330224676478295, 0.809361350632483, 2.386746315225478, 2.2246428458921375, 0.8488840105072145, 5.145000411618141, 68.733473285552, 90.50854267612581, 91.44760516382034, 89.34319080845003, 85.19769268651163, 86.71798767582064, 84.36021174153974, 83.75175014618905, 79.03499803235455, 78.5424267861151, 86.11819451855075, 77.21549680156093, 77.85616890076669, 92.33554347868889, 80.8302354812622, 78.58731439036708, 77.93992719342633, 65.82678517987652, 57.08437511997839, 59.75811758349019, 56.59488293432421, 58.48566539825932, 59.732739848475305, 58.70044262178483, 57.74583185872724, 56.68442280061784, 55.66599899722684, 57.60994526647753, 54.869043980875325, 53.94831465136621, 56.41195927896808, 57.494808012439364, 55.22535208732852, 54.784069753462276, 55.17719322635282, 56.86767985743862, 58.65083640621555, 54.43745382370488, 57.5491249945856, 63.59003789963261, 66.51982876562303, 69.02228524607997, 67.6567199153285, 66.44576657202937, 68.36787700653076, 69.9585000930294, 68.80747272122291, 59.805566495464696, 57.09446737843176, 58.68019142458516, 60.97688821054275, 67.2211956208752, 68.95425565781133, 58.54471275883337, 68.6554338086036, 61.561544941317656, 61.2216676435163, 62.716224039754565, 64.52589188852619, 61.998214567861254, 61.93058113898001, 62.35939818043863, 63.47660687661941, 65.76547853408321, 67.70167027750324, 68.84832812893775, 70.17489725543608, 66.94484895275485, 67.99329849981493, 70.75984031923356, 70.30330781013735, 68.85377237873693, 59.198501263895345, 48.220842269159135, 49.69654383197908, 50.75601523922336, 52.3494702769864, 52.114806636687256, 52.47292687816005, 51.72995152011995, 52.09103707344302, 53.6506812803207, 55.55030084425404, 54.34467800201909, 52.96700823691584, 54.30202222639515, 55.81932444726267, 58.986912927319935, 67.71849724554247, 74.33375497018137, 74.86258460629371, 75.67515850067139, 74.87462628272273, 74.38596956191525, 74.1836929321289, 76.42284854765862, 74.3286794231784, 71.25944829756214, 70.7827312715592, 78.72415804093885, 74.22934932093467, 84.24822022837978, 76.71275092709449, 84.96401356112573, 13.595269399304545, 1.464551367586659, 1.0614683839582628, 0.7303822208796779, 0.674848752396722, 0.11992738732407171, 0.09163327049463989, 18.194871102609945, 31.791602565396218, 33.35035247187461, 69.94190062246015, 33.5035288718439, 16.023786260235696, 47.27314272234517, 61.39995113495858, 60.48462683154691, 66.1549698921942, 62.21381548912295, 3.6414892442764777, 0.11946267072832394, 0.13496288939589454, 0.03719669436254809, 0.03809007928676663, 0.024729109436814344, 0.011497495448096626, 0.05275436579400013, 0.0700799153456765, 0.02903479553248373, 0.08315898207647186, 0.156440869153988, 0.01157721743032697, 0.018020517703506257, 0.016413527623479886, 0.05234611370871144, 0.021600322084381215, 0.027187156168022947, 0.01913944657351221, 0.0718146448414172, 0.03924717082672062, 0.08359107098752454, 0.08503084131065877, 0.06140034983775789, 0.01888239534661895, 0.02427469672364814, 0.06919496121906465, 0.015272993158789413, 0.059070902455958633, 0.031702053214934085, 0.02672430116593117, 0.15642035331937576, 0.08175343290091523, 0.1705702271072134, 0.42692811378548223, 11.805263411614204, 108.35862175110849, 84.32771882703229, 96.08150113013484, 68.635343428581, 45.50143557210123, 40.31952173479142, 50.53506420504663, 48.24134842042, 42.910819899651315, 1.8161920986829267, 0.17748268441327159, 1.1705041460452543, 6.008156211145463, 4.59663393997377, 4.914651868804809, 4.214855432510376, 0.6121182862308718, 7.141222559636639, 77.47916636928436, 94.050552768092, 93.10238253685736, 89.82700732446487, 90.5330261107414, 89.55136668297553, 87.42456343866165, 88.53746537239321, 85.3226044870192, 83.84441221913984, 87.20519311966436, 80.45302898653092, 86.560410376518, 91.83778685908165, 82.92672664888444, 85.15304826921033, 81.20155842073503, 67.88414678265973, 60.13692440525178, 62.54045870996291, 59.04973753036992, 62.42751798322124, 64.4370541264934, 60.883759375541445, 60.230284660093254, 59.82526856084024, 59.21589697560957, 59.14108560931299, 57.0462026134614, 57.603504734654585, 58.89556092600669, 58.354713147686375, 56.0306852863681, 56.63975877146567, 57.78730700092932, 60.483536412639005, 60.6495624972928, 56.45084173448625, 60.9562800776574, 67.30584821393414, 68.47352996949228, 72.75710336623654, 69.84294706775297, 72.56307155855241, 71.1393060991841, 73.76001419559603, 71.6742624775056, 61.06117602317565, 60.01314616972401, 60.39792676125804, 62.3790688668528, 69.31550595068163, 69.18875063619306, 62.46163475898005, 73.06284427642822, 64.76675679606777, 64.69749558356501, 65.4366740872783, 68.17213504545151, 65.84561255670363, 66.10282590312343, 65.33269989875056, 67.17095005896785, 69.24279305242723, 70.42091615738408, 72.52692299504434, 72.04747599940147, 70.30432762638216, 71.66787685886507, 73.99169291219404, 72.69961710899108, 72.24551646940171, 62.75571446264944, 50.86248797755088, 52.056010307804236, 52.679427900621974, 54.82319539593112, 56.03848688064083, 54.80048095026324, 55.191964872421764, 54.49954886590281, 55.41959962537212, 57.7154178004111, 55.843815726618615, 55.82522761437201, 58.89108550164008, 58.88696309058898, 63.053885198408565, 67.94714789236745, 77.45232951256537, 77.02613261438186, 79.0323543548584, 76.99193739121961, 77.4995470046997, 77.02080603568785, 79.0202263862856, 75.67609986951275, 75.00741420253631, 71.69892634114912, 81.68765775619015, 75.96747706013342, 85.14407388625607, 79.65626224394768, 91.39946983706568, 20.169670735636068, 0.5487819364474666, 0.1441276758428543, 1.6310834379926806, 1.540663367317569, 0.12658590946586865, 0.13950082653712842, 12.115123791079368, 40.588404132473855, 36.09618417678341, 56.42473443861931, 35.0440985925736, 30.435201852552353, 64.37892067816951, 69.80298596043741, 70.1126806197628, 70.73556084786692, 78.0348014831543, 7.918790771115211, 0.22177926715343232, 0.1816258870906407, 0.04513003660606281, 0.08854423544459766, 0.06854484368476176, 0.05756591889827002, 0.0749521272917909, 0.10385353734055836, 0.007050296154639294, 0.06114256891211676, 0.043598335732014916, 0.048360399556376284, 0.02560374435908612, 0.04267740611647887, 0.02291271113790572, 0.0378760764555585, 0.0343776440187808, 0.03825542404346409, 0.13618585683645743, 0.11861105674817679, 0.20029492886556735, 0.20205087899681062, 0.14867618499744326, 0.13097529449770529, 0.15900516461941505, 0.17271322017956167, 0.1540001130272304, 0.23499892634009165, 0.10419342756992388, 0.20227791681405038, 0.4201056105234931, 0.15525357076717963, 0.2561030398693777, 0.7216740688008647, 13.082849979400637, 124.10170555114748, 98.03928159898328, 107.37773110789638, 77.76973555164953, 40.734535955613666, 37.97157918253253, 103.43106577473303, 71.68187972038024, 56.17676219632549, 3.565512198594309, 0.18029703097718378, 0.9684817961627438, 6.21862078866651, 6.092209662160566, 5.958635797423701, 7.86807599567598, 3.7695585527727684, 8.680894547893155, 81.60854354981454, 94.88579796206568, 98.95144447203606, 95.34919461896344, 95.49550687113117, 93.17485224816107, 92.21799004462459, 90.26658734967633, 89.93411156439012, 87.38157426157306, 89.75444347627702, 84.80611462746897, 91.24069229249032, 90.99454002995645, 84.72515690711238, 86.52627791127851, 85.21248786680161, 71.80670522874402, 63.64515896766417, 65.67117298803022, 62.421148054061405, 66.90074582253733, 67.04049987177696, 65.09086616577642, 62.471727017433416, 63.32873352112309, 61.54661640044182, 62.810015755314986, 60.30625704796084, 60.84664590897099, 62.26415911028462, 61.46697267409294, 59.50586995770855, 59.37429012790803, 62.62815506227555, 62.597537040710456, 63.12720606403967, 60.42553632490097, 63.73079607563635, 71.41459372735792, 71.46974225198069, 74.0618876487978, 74.49556058452976, 74.71062414107784, 74.9180704547513, 79.11545368932909, 75.292099829643, 63.901423100502264, 62.42770233461934, 64.78354454040527, 66.3404901566044, 72.5928266586796, 75.0264298531317, 66.62044540528329, 75.85680346335135, 69.16840922447943, 68.56619988718342, 69.66873107417938, 70.66946106572306, 70.5473655269992, 69.75346995938209, 70.23789052040347, 73.68381823262861, 74.86222374823787, 73.82905575536913, 77.1718329768027, 77.20056041594475, 74.13408279418945, 74.17181599524714, 75.89559570435556, 75.51912661521666, 76.534439979061, 66.32714625327819, 53.383607095287694, 55.51685087142452, 56.764105750668435, 57.44259734307566, 58.96369641826999, 57.753421645010675, 58.365887980307306, 58.282223824531805, 59.53462877581197, 62.21219162787161, 59.47564809553085, 59.25101395576232, 60.6035295609505, 61.47574701616841, 67.3680805390881, 72.96192953663488, 81.12347187534456, 81.36318360605549, 83.08093855457922, 81.60724916765767, 82.31267175366803, 81.55523069443242, 81.74629719026628, 80.81999809511247, 77.87838520542269, 77.61138946779313, 85.44580613413166, 79.46332085517146, 91.28318725093719, 83.16290824644028, 95.62077168495425, 17.277018831622218, 3.9431673144140555, 5.473672968726005, 2.2416921632905162, 2.2419699161283435, 0.2163852420785735, 0.22835225557848332, 24.662957576013383, 48.03762051366991, 48.47834587097169, 91.63776951451456, 51.08267022717384, 25.564430029161517, 64.54814741688391, 78.79134039725028, 79.28177787411597, 83.58257047591671, 87.9036731104697, 5.837369349695021, 0.3624502010643483, 0.28242566773006994, 0.18093662246340708, 0.17035688694205978, 0.14154686352177975, 0.1609018910676241, 0.15316529169438348, 0.24242372792815012, 0.10983813959624499, 0.23906472349359145, 0.2610552467165455, 0.10251143556689063, 0.1039638463407755, 0.16306415891214726, 0.10338582534102664, 0.13358932439117663, 0.15212635389499127, 0.10465465846561617], [0.053458304835423354, 0.02861656323676148, 0.06701089051221648, 0.01423961524250767, 0.04874816262013009, 0.02835292939937884, 0.07152166983653462, 0.044242010466874614, 0.022365260876775272, 0.029652187705881176, 0.07513300831159277, 0.08075559571866067, 0.037271073839116486, 0.10000480353952416, 0.19465056157881216, 0.36356534929044787, 30.15917289641596, 93.02966179386263, 71.35051788822298, 69.994797706604, 57.505786726551676, 24.89829586398217, 51.53445274599137, 64.96285177046254, 35.396688292103434, 19.95931402329476, 0.03912329823980409, 0.19203147550504054, 0.40663386244447003, 1.1630263924598694, 3.248723197367884, 3.842848529738765, 3.152041430434873, 0.3004326869643504, 30.831208267519553, 91.43613615343648, 81.15361136774864, 80.48381174764326, 76.36601340386176, 86.48284942873063, 82.25819003197455, 80.08119613893571, 82.21109021094539, 78.18768762773084, 76.83891788605722, 79.02566279134443, 82.12409988526376, 77.50688968166229, 79.80593204498291, 91.39412756889098, 75.53641642293623, 80.8473527046942, 66.13476184106642, 60.04769832857194, 54.73958223096786, 59.469537042802386, 55.42336510073755, 59.01338500361289, 56.248549415219216, 58.35241856113557, 55.82402344672911, 58.05310249328614, 54.02090987851543, 56.295366825595984, 53.752023558462824, 54.1937687320094, 53.88222663633285, 53.470781772367424, 53.97206068038941, 56.28519611973917, 58.59539370382986, 52.843053494730306, 53.36956108770063, 56.86295732375115, 57.977306612076305, 62.226606338254875, 64.23565610762566, 68.00738765347388, 69.79161108693769, 65.68806271399221, 67.27276694390082, 69.37845214720696, 64.88892685982489, 62.932154440110736, 54.60952820316438, 60.96133993517969, 71.21429397213844, 65.44773517116424, 53.922317181864095, 70.79649094612368, 58.07329485493322, 62.01153885933661, 66.77667340924664, 66.80357302388838, 62.21055599950976, 65.9358270706669, 62.268520785916245, 65.20394025310394, 60.5300518005125, 59.581803121874415, 62.33011376473212, 67.81063372089018, 64.86679684731268, 69.23792931341356, 66.08384163148942, 68.42074271171325, 67.67604935553767, 64.6615941293778, 53.9471967758671, 50.44723056977796, 51.11248416285361, 52.75604355719782, 53.57932552214592, 53.39038887331563, 51.01697444915772, 52.023438945893325, 50.886312453977524, 52.41356180560205, 51.73101448243665, 53.96814223258726, 53.68935192784956, 56.15553432895292, 54.85844573666973, 60.548796807566, 70.2316931755312, 73.81642572341427, 72.33281273995676, 72.2656931415681, 68.11368388514366, 70.43376584206858, 67.61094585541757, 68.93443199896043, 64.68472042391377, 65.03155992877099, 64.68519503070463, 75.37785068635019, 73.43857595997473, 81.33251067130797, 74.94727642305436, 86.8416835415748, 6.179680968484571, 1.0397168801676844, 0.9295384213328363, 0.34882348872000174, 0.2519507667109851, 0.03631773870438337, 1.3969501756852674, 43.225272393995716, 33.81754598309917, 41.02092389137515, 50.465728467510594, 21.183350432303644, 11.076474285894825, 40.86883006557342, 61.78866978614562, 62.88084591588667, 72.7426847334831, 38.348240467809866, 1.1002087761317532, 0.08366683708323587, 0.09381655213092605, 0.026701954381179907, 0.03999128734933273, 0.05029809255633624, 0.08449939079582693, 0.04034157339183073, 0.03427994865623694, 0.06757540538186027, 0.05721148832010166, 0.06408129751141514, 0.05548001469803914, 0.022141463611455216, 0.04775444699090816, 0.05198044845113351, 0.06382196142728772, 0.02788785274230665, 0.0436073717390818, 0.10799296320446077, 0.03400319173271137, 0.061578017118717396, 0.05675109246024682, 0.07276582726908308, 0.05752648069192806, 0.06298186557908213, 0.04813639161687705, 0.027492800351953315, 0.09907125645587522, 0.02159336026036932, 0.05804546312579225, 0.1581186323516792, 0.1779739153120787, 0.24859591447297605, 43.286602574010054, 103.89997728409307, 78.71473650778495, 80.30761887950283, 67.72786386551397, 32.21961159859934, 32.53792174400822, 53.820053146731475, 43.19280693607946, 22.06707808279222, 0.06673387311879667, 0.2543745922946161, 3.174593588036876, 2.046170590385314, 5.602718457098931, 4.433754086494446, 0.6591458498470245, 0.8092597367302065, 37.5674730731595, 96.40674406482329, 85.31656403695384, 88.79416096595027, 84.62450888849075, 90.5759133062055, 84.98199370599563, 87.08623547707835, 84.9913211022654, 83.1572364991711, 80.14851970057335, 84.66797659474035, 84.08171561456497, 79.6368778905561, 84.09615778153943, 91.21772289276124, 78.13195074758222, 84.2188024520874, 69.56497653838127, 61.57681472839848, 58.361392944089836, 62.56145123512515, 57.39027684734714, 60.212688907500244, 59.85649062741188, 61.92726281381423, 58.198751864894746, 59.330445874121885, 58.07120423163138, 58.67319783856792, 56.17205535211871, 58.3787533544725, 57.08426529361356, 56.81610068967266, 55.894304475476666, 57.80042732915571, 62.77032529154132, 56.30410978871008, 55.10892829587383, 57.1794847519167, 60.74046342603622, 65.85500271089616, 67.74156078215569, 71.6988165147843, 71.53282180909189, 68.87440404584332, 70.79467096636373, 73.15890312194824, 68.1723625429215, 66.62098669236707, 57.58869778725409, 62.70968544867731, 73.33363686838459, 67.55320856648108, 57.940048017809474, 72.77367930258475, 60.85219214039465, 66.23616295476114, 70.71692958954843, 71.24858333218482, 66.75185265079622, 68.60775347678893, 63.85197377973988, 69.30531563297396, 64.71744083589124, 65.47681954599196, 63.54586024438182, 68.4704940549789, 68.13448813653761, 71.37642906558129, 69.28014970594838, 73.31326407770958, 68.3990990731024, 68.12894190511396, 56.37335923410232, 53.661667839173354, 54.596607915816776, 53.73512598776049, 55.49096715065741, 55.502349868897475, 52.72748870234336, 53.9440510349889, 53.82060620092577, 55.59574150270032, 54.344466194029785, 56.00027122805196, 54.79665663934524, 60.141572413905976, 57.003766490567116, 63.083785426232126, 71.42679229859384, 76.43248188880183, 73.4634594763479, 75.00582172024635, 69.44494416636806, 72.52116495563139, 69.35416483109998, 69.53209138685658, 65.60395925275742, 67.60895329137003, 65.57494940296297, 79.24055376360494, 73.8872637287263, 84.84088251667639, 75.22765528771185, 95.50959602479013, 9.60250739128359, 0.7435733356302785, 0.8862523698518354, 1.4434150630427947, 1.7238505569196518, 0.12176582214212227, 0.16087372967552754, 41.73633283184421, 44.81949621631254, 32.31126366123077, 35.82990231052522, 22.608620120633034, 24.772909456683745, 50.59440182101343, 67.1295847431306, 71.83037281036377, 80.5378149401757, 59.985415012605735, 2.1724375697874256, 0.18116304741030742, 0.04351807653062767, 0.03331366280514387, 0.08232672713817128, 0.08249100703265398, 0.05566413626976072, 0.048306294596723975, 0.04167066316210455, 0.03739989152358424, 0.014433112772812527, 0.01975980733761624, 0.04549064568334049, 0.046247831665940826, 0.02320324806796928, 0.007992272599480085, 0.014371458016666434, 0.03860372208779858, 0.10583050383795654, 0.15931935259892097, 0.16677184060456293, 0.16483921527622208, 0.1475931971424049, 0.1769156874187531, 0.1894715467407819, 0.1324126439829988, 0.14278925895210237, 0.17128673382103446, 0.21765238214885035, 0.18923620453044293, 0.2096755222807969, 0.28223540213319565, 0.3812434103700423, 0.37269451264892856, 50.6844594401698, 118.53132801671183, 93.36038035731163, 90.99734060225948, 78.81242705929664, 37.19418502623035, 71.47066793134137, 91.42922493719286, 52.204217064765196, 34.26221724479429, 0.2005367675015042, 0.5144352730243437, 3.4578200934394716, 5.691354217067842, 8.033957442929669, 16.373018410898027, 12.821033731583627, 1.3327848574807568, 41.88291180518366, 100.88374522424515, 92.23176540866976, 94.12545434890255, 91.31989279100972, 97.6559248278218, 92.09383918393044, 89.75733818546419, 89.67492134340348, 89.2627743751772, 84.97665928256127, 87.24826074415638, 85.20122281966671, 83.96023981032833, 90.4337901453818, 93.02356643061485, 82.88764415248748, 86.85319177566036, 73.31579008410054, 64.33821824289137, 59.11976752742645, 65.43321063441616, 61.60807209630167, 66.05519263975083, 63.331671376382154, 65.12904651703374, 61.361429537496264, 63.75355758974629, 59.489368546393614, 62.41678637842979, 58.9121368623549, 61.10479670186197, 59.60846739430582, 59.67726184475807, 58.64267787625713, 61.79030541450747, 67.14707851409912, 58.049152666522616, 59.392042775307935, 60.62805614163799, 64.81654736303514, 68.85086198006907, 70.45981038001277, 73.5952668036184, 75.06832076657203, 71.32840356519146, 73.50076906142696, 74.29189543570243, 72.18808512533866, 70.62873901859408, 60.5119735963883, 67.51705215823266, 76.87724728738108, 70.04851848848405, 62.342096605608546, 75.94728469848633, 65.00722554422194, 67.78390669053601, 74.41623457016485, 72.38299554394138, 69.56995794850012, 70.65926290327504, 67.59052599630049, 72.67347843416276, 66.64674881965884, 67.39711392310359, 67.28095685282062, 70.42392069293608, 70.73250139913252, 75.53380412440147, 72.20432373785204, 74.8284835200156, 74.07083065279069, 71.72884618082355, 60.66908021127025, 55.35971679995137, 57.365267815128455, 57.74771067403979, 59.968442916870124, 59.24318490489837, 56.82356888248075, 57.176131125419374, 55.88213336083197, 57.81040976124426, 58.40824957816832, 59.1231603776255, 58.473392301990145, 63.16207201250138, 59.14416466989825, 68.97908426100209, 76.81596417580882, 79.89431873444589, 76.38877884034189, 78.32014606844994, 74.473736516891, 76.45341165604131, 74.74442712722286, 74.80450214878206, 70.88945896394792, 74.18194355503206, 70.88117491814398, 83.36089380325811, 80.14207132401006, 89.12327135762861, 80.99026033955236, 97.07593963992213, 6.922460698312329, 3.0577618700842706, 5.6613980954693215, 2.2171942649349092, 1.7965572038965842, 0.271690140568441, 2.9269991190202775, 54.26756420443135, 52.32976821161086, 56.50287981956237, 65.58763434810024, 28.44115318790559, 20.441869497299194, 56.56980722181259, 80.78108033826275, 79.21215580355737, 93.52369216180618, 60.56687501169021, 1.6664758420759633, 0.22849854772850392, 0.2960855670032963, 0.28681835460086025, 0.16479004775324177, 0.23255663803748547, 0.2850851572809681, 0.11667558157275762, 0.1333492630792241, 0.15855747815822402, 0.1493291217353075, 0.11872173347059758, 0.13844598475242817, 0.113371383068302, 0.13220314957922505, 0.12444110842601908, 0.20977601769470403, 0.16611910304955899], [0.02351856794238331, 0.035404297598307176, 0.040350586416259895, 0.019984397503937927, 0.021188664738269105, 0.011069891981840616, 0.06299848202615976, 0.008607900855431875, 0.06757848505531588, 0.01894319591472947, 0.09829852654929123, 0.019223691347325524, 0.09040986638396017, 0.06376397623229893, 0.037405457152354146, 0.2572786783979785, 70.31550638137325, 80.28250002091931, 83.05025777509137, 69.33840474774762, 45.57443872574837, 34.899084644932906, 86.84573142759263, 52.83224736490558, 36.683508119275494, 4.628221767563974, 0.15084380013567789, 0.2680301708319495, 2.6285837254216595, 6.50277542491113, 5.021028999359378, 3.8256999273453993, 1.7545361167961553, 5.256724223013848, 68.59341329143894, 80.28510447471373, 79.26555495108329, 81.29560901272683, 83.83678713152486, 76.48257840064265, 81.39782597941738, 82.25775072651525, 82.31214615606493, 74.7671768742223, 75.59925279309674, 82.02046302057083, 75.90439750302222, 80.02248610219648, 71.04727945020123, 87.21849779928885, 83.17003911541354, 76.91802424769249, 67.81997680664062, 57.605465919740745, 56.15911545292024, 56.85087642362041, 54.43363735752722, 56.823914051055915, 56.07959724241688, 56.9274724683454, 53.719805209867424, 57.29876010648666, 56.03621190594089, 55.45650128395327, 56.7189004344325, 52.52512185804306, 53.08532653316375, 53.19696895537838, 50.521598708245065, 53.24761459904333, 55.83223296749977, 52.37496960547663, 52.613532081727065, 51.53442136702999, 58.03630690420828, 60.278384685516365, 65.14977232102426, 67.29950181899532, 70.74502944946289, 66.11839771270752, 65.53145424012216, 69.1844830974456, 70.20835507300593, 64.38426686871436, 60.30356630202263, 56.0343683919599, 70.37912722556823, 64.00154159915063, 54.68132326679846, 66.70588247237667, 59.36204841060024, 67.41103049247496, 71.24760273964175, 68.21365725609564, 64.97680756353563, 65.50948112241684, 66.3689979430168, 66.51908351529029, 59.12294856963619, 56.958200316275324, 58.511906054712114, 65.45227727582379, 63.0696492041311, 68.38701032823133, 68.50384989092427, 70.6623145072691, 67.18976174631428, 61.214344578404585, 54.42215265766267, 52.83571866250808, 51.6143161250699, 51.80708492955854, 50.11324859434559, 52.20020055770875, 51.07829678443171, 54.20917580204626, 52.84659539499591, 51.99164421327653, 52.41201246938398, 53.2393580098306, 50.80881426411291, 54.12089109420777, 54.857559281010786, 55.58651608805503, 59.98764684123378, 65.25202066667619, 60.273371896436146, 59.69254339894941, 53.56210239471928, 55.0129557424976, 51.214932549384336, 55.820709043933505, 52.4425716553965, 54.040035355475645, 56.27760241108557, 60.36658702358123, 66.33542245434177, 73.2609239701302, 73.30007706919025, 83.18055106747536, 61.04591408083516, 0.11147978174830638, 2.504466940318385, 1.8722683864255107, 0.323902587256124, 0.47653840494252026, 0.17221621297780546, 17.527997570653117, 69.480543598052, 31.41561200541835, 71.37954342749812, 61.681298825048636, 28.636322482939693, 39.80670713609265, 52.67195578544371, 66.46824175311674, 61.62130225089289, 72.04690333335631, 19.1561028265184, 0.6724247889172646, 0.17843862424694723, 0.09533629437247593, 0.055334971271335125, 0.09207668984609266, 0.11408343881128297, 0.03270016427362158, 0.05457792318456116, 0.03750229449642282, 0.11736586509693055, 0.041416502001905636, 0.02636545026043971, 0.03411257376654014, 0.12396750521034965, 0.06126155385807638, 0.023218558335136023, 0.033665592106239456, 0.017124348049682957, 0.080264947046676, 0.04231182512857261, 0.03239871250585683, 0.025385292472257733, 0.05483454348699701, 0.04600095983234145, 0.019637284980666254, 0.015223013582609355, 0.051162925383616845, 0.0281306202598517, 0.029982549716688456, 0.054346212230983286, 0.03667262127442706, 0.027272404517017068, 0.9927438620117404, 88.28611204701086, 87.65184125592633, 91.83349578611313, 79.44908265144595, 60.394981061258626, 41.55984970831102, 60.42824276031987, 49.70117222878241, 43.48722396358367, 4.90281758769866, 0.3836857293161654, 0.9996365695711106, 2.50855625637116, 4.669438033334671, 6.297453564982261, 4.981889628594922, 1.5294674519569644, 8.77611106441867, 75.63959829268917, 85.93812634868007, 88.93753928522911, 86.10692162667551, 89.45778677540441, 84.82480079896989, 88.66276156517768, 85.50927008351972, 85.29150793629309, 80.61248902351626, 81.11882778906053, 82.07142245384955, 80.8312709869877, 80.85052197979343, 75.04295872103783, 89.0714882266137, 86.53055329476634, 82.5848057962233, 71.6444367747153, 60.18586381789177, 59.30034560541953, 58.363005038230654, 58.16034009379726, 59.47042349846133, 58.21679869005757, 59.336184301683986, 57.72597289854481, 59.06224204647926, 59.77539562409925, 55.839269699588904, 58.7514098998039, 56.94489563665083, 56.353362990963845, 57.61603278498496, 54.873448802578835, 56.42753501092234, 57.81091182462631, 56.330989791500954, 55.153886502788914, 54.32686259669643, 61.28094642393051, 62.135579893665934, 66.65285202764696, 70.81671468673214, 73.70338301504813, 69.11482180318525, 69.53154225503245, 72.6078728706606, 72.71541641604516, 67.55043937313941, 62.7925729751587, 60.09459810872232, 72.8040776714202, 66.44600975898005, 57.13454615685248, 71.43155405598303, 63.0774978668459, 69.6538496017456, 72.51273970450126, 71.39156941444644, 65.78794194806007, 68.1883030553018, 67.73139399866905, 65.11867184792796, 60.330105058608524, 60.23368143266248, 61.17255172421856, 65.84379257694368, 64.83182891722649, 70.22838269510578, 70.18065529484903, 71.74532013554727, 69.75033990798458, 64.50746067108648, 58.23965434105166, 55.30733354630009, 53.80007651544387, 54.41427653835666, 53.98137630954866, 56.57274507707166, 53.77326711531609, 57.02392355088265, 55.13731056644071, 55.36298021193474, 54.172054490735455, 55.64488095621909, 54.934990790582475, 56.897030953438055, 56.17450683347641, 56.94491917087186, 61.70702957337903, 67.98502229875135, 61.93751981181484, 61.48282297195927, 56.31527285422049, 56.43796851558071, 55.180338967231016, 59.02914508696526, 55.74765489947412, 55.59093659923923, 57.9233818669473, 62.18137356542773, 68.78547606929656, 76.0028725285684, 77.9850422951483, 84.29296662730556, 70.66362457890665, 0.3747698141922874, 0.8405192496795809, 2.376100757429677, 1.2721999277991634, 0.5504019979027011, 0.06664681488708143, 13.981370848994102, 82.2074031829834, 36.69670689490534, 52.14712304453696, 38.60108037148753, 31.871267864781043, 53.60106722001107, 63.39613553016417, 72.25047434529951, 66.82578148380404, 79.40769380138767, 36.37204054863223, 0.6168945073600739, 0.09183040790019498, 0.02030469694985978, 0.026046623618552284, 0.07231209637416948, 0.11015267231531682, 0.03666338991493948, 0.027564002478855754, 0.03281112444857436, 0.05380565293073174, 0.04019161168065283, 0.024095644738765496, 0.06835882987586722, 0.08912997861062327, 0.0441503212336571, 0.05802693528934352, 0.02967371860699308, 0.08849005770659255, 0.18423259318355592, 0.12590377711721007, 0.20061316178931346, 0.1011472628001244, 0.11100680672473485, 0.2062271307072332, 0.1260661647745198, 0.16140479714639727, 0.21452223882079127, 0.1346140589204527, 0.10038462227150317, 0.15688532272413855, 0.1227010852627216, 0.1276162134543542, 1.156011601128886, 98.11107666261735, 100.60514711564588, 102.5557888707807, 89.30869748515468, 64.72446972324003, 53.05733257724393, 120.08299412265902, 71.39583695319392, 59.19299817854359, 7.973242094439845, 0.4827568019109388, 1.4195892383014004, 6.578639457302709, 12.495749612008373, 10.089919740153897, 15.444347262382509, 7.9034680320370585, 12.713403894055276, 82.89820317299136, 90.55128866626372, 90.7448027210851, 91.16638691194596, 93.72648654445526, 91.2007547193958, 93.02850861703196, 88.43947672074842, 89.49772434849893, 85.49252940762429, 85.10191625164401, 85.96463372630458, 85.14985545989006, 84.17247141561201, 80.67784355532739, 93.43133603372883, 86.93787574768068, 87.96231254454582, 74.99295634608116, 61.70944575340518, 61.32751672498642, 61.814796693863414, 59.48656012935024, 63.29980211873209, 62.277828570335146, 64.6783269605329, 61.41669965559437, 62.19640408792804, 63.65943247272123, 61.5897193262654, 63.86318391369235, 59.818298509044034, 59.63171135994696, 60.8356358158973, 57.463287845734634, 59.445438000463675, 61.152355440201305, 59.50717218460576, 58.628231786912494, 58.257140267279844, 63.27737400608679, 66.69582551525485, 69.36169578183082, 75.3112566855646, 76.05079604733375, 71.92828301460513, 72.97260622824393, 75.07624395432012, 75.52743419524163, 70.998289046749, 65.70210479920911, 64.05405821338778, 75.12871742248535, 70.11067236623457, 61.2617071982353, 73.26242231553601, 66.99378444302467, 74.73835529819613, 78.35980123089206, 74.49073606921782, 71.34421856172624, 72.71778552762925, 71.53629702906456, 68.44877981370496, 62.523682732735914, 62.69600029914611, 62.80956468274517, 68.7977138642342, 66.34177669402092, 72.70962699767082, 73.88603210449219, 74.33945809641193, 72.44322746030747, 67.9178556319206, 59.96952156866751, 59.58718069138066, 57.066626394948656, 56.64969413511215, 56.361450918259166, 59.147957601854884, 57.016749535837484, 62.3909693379556, 59.095915594408595, 58.29645810588714, 57.61251834131057, 59.60049713811567, 58.30025496021394, 59.79342283741121, 59.64718511027675, 61.16982959931897, 65.84086648879513, 72.52491474151611, 66.89588208352366, 65.08499829999863, 59.65752447805097, 60.30714742598995, 55.92812707347255, 63.333432520589525, 56.12700693068966, 59.79874549373504, 63.39415081085698, 65.67465605274325, 73.52285200549711, 80.60149854229343, 80.83924908791819, 90.03217866343837, 71.10373020172119, 0.24345356460300185, 7.280628498523467, 6.109612728318861, 1.4412648687439582, 0.8599058706914225, 0.23778172540328196, 22.728058253565145, 89.52886796766713, 48.03655362898304, 94.86478190268241, 80.8332400168142, 38.423067523587136, 58.22174087647469, 70.5029486071679, 85.05563228361069, 77.84116975722775, 93.71125990344633, 32.876734118307795, 0.8928081212985901, 0.27005062047992984, 0.15914424022118892, 0.15046884606201805, 0.20904428115294826, 0.22550734210639234, 0.23259918656080003, 0.19448098035589342, 0.18408000379079775, 0.2066709101200104, 0.16646986406657005, 0.1314072455129316, 0.20312663498184375, 0.22422681081919904, 0.14978719634875176, 0.11117959019517708, 0.08963394189073194], [0.04601764905777189, 0.05187431079966407, 0.026977895421066114, 0.05634936361363339, 0.055507984568154624, 0.04249575900875273, 0.09761427979796164, 0.08079180869484141, 0.043328561699919166, 0.09789114397379661, 0.08983969778543519, 0.014817967575283782, 0.19308585763698627, 0.3139717588501592, 0.5033041380586163, 11.62529133981274, 88.3157180970715, 72.70517902989542, 71.69501181571715, 59.69543026339624, 27.60745340777982, 38.28815760151033, 52.22266004931543, 36.493653635824884, 22.652605579745387, 0.04267376336839892, 0.24515047999880007, 0.5657856562925924, 2.857805567402994, 1.1522479643744807, 5.5331821883878405, 0.8038478464849534, 0.2124183162325813, 29.376760067478305, 80.78336315770304, 87.09832422194943, 89.54822878683768, 83.61651466738793, 87.26316575081118, 84.01352128674908, 76.9017856351791, 73.53122234344482, 79.92443469262894, 72.65439218090427, 79.79800885723483, 80.10131005317935, 79.08206647442233, 76.1519225951164, 74.89918816474177, 76.20710249870055, 84.57234920993929, 72.40129732316541, 68.60729063710859, 55.6588210598115, 59.0316044130633, 56.5864537608239, 58.46084856217908, 54.20239010164815, 55.30732570155975, 54.16969322389173, 54.580137883463216, 54.80690971497567, 56.0528584449522, 51.05147953956358, 53.07452432570919, 52.06354125853508, 53.03022899935323, 53.60027097886609, 52.885944612564586, 53.86124587828114, 53.29745223445278, 50.77610954161614, 54.027464159073375, 50.61897154777281, 52.965568727062596, 56.794233475961995, 63.61941645222326, 63.91330395975421, 70.16162395477295, 67.40519400565856, 62.89039296488609, 64.56253467067596, 70.21675678991502, 62.95735566846786, 65.0413344752404, 54.22987807181574, 69.07743377070274, 59.4202720734381, 51.39621665400844, 67.57584848711568, 60.05279740979595, 71.85389134191698, 65.8737124166181, 67.61946524343183, 64.85043664132395, 63.49517929938532, 65.51680810989873, 63.264975393972094, 62.798193731615626, 62.59781552899269, 57.51498468460576, 62.14505634000225, 63.442972552391794, 64.04196162377634, 66.73585722523352, 65.29740248956989, 62.57226520969022, 57.130859128890506, 54.83557047382478, 53.07405756365869, 52.40471686086347, 49.545367840797674, 51.82612803674514, 49.40484500700428, 52.13801137862667, 50.365496220127234, 52.791619454660726, 49.630389136652795, 53.62081635382868, 50.75784306372366, 53.422858253602065, 51.310724673732636, 53.273906246308364, 51.61423375529628, 54.57605861848401, 52.430506444746456, 53.2959891903785, 50.37116012265606, 53.93821062580232, 53.00618487019693, 59.226844310760505, 58.14283455571821, 65.17689158839565, 61.50236814252792, 64.38163495832875, 56.72859653349846, 61.35156477651289, 57.3697667737161, 73.67546358416158, 70.01905364374961, 92.04145200790899, 16.082003058925753, 0.8977830962788675, 0.7789510308254151, 1.7800518702114783, 0.014656143950208303, 0.024614473955044826, 1.1884952000071927, 60.184824389796105, 54.95008407100555, 35.707112512280865, 86.53225560342112, 37.885408632216915, 22.562004712320146, 36.59375644499256, 46.915767731205115, 62.09447345426006, 62.06158045799502, 70.24549207379742, 6.524427398558586, 0.29174880455097846, 0.04638921319236679, 0.14306390147295692, 0.05327116870771974, 0.014376362894601641, 0.02592930108338835, 0.0417872732354989, 0.017441818715944406, 0.062161006198655215, 0.05119888555078257, 0.02942607110937036, 0.0626425460852202, 0.06708123270542392, 0.08268979918812552, 0.05000130243359074, 0.010002279511442589, 0.07692209940644042, 0.033612659261111295, 0.0198364180452641, 0.10148290124151016, 0.04763096510883301, 0.04713747425064926, 0.018241733252521486, 0.07736065409957402, 0.041376975695452387, 0.048980379191737984, 0.04537283668234464, 0.12568471427526207, 0.22249759715651313, 0.3006046277380759, 0.5753072711729235, 19.039682957433886, 103.68989513766383, 79.94273647185295, 81.62850841399163, 68.1121463160361, 44.88931048300959, 40.13028306345786, 47.015894074593824, 46.851546764373786, 27.27864307741965, 0.06298656552849759, 0.5438232638182179, 2.2051508724689484, 3.1523905213802093, 6.651951987897196, 3.8086854209823, 2.406534427596677, 0.25031786562213976, 39.41677647252237, 89.21314070301672, 89.65511337403329, 92.33973257003292, 87.34253883361818, 89.20215806653424, 86.68163514906361, 82.19827190522226, 79.62145513103854, 83.7101024196994, 78.58931479915496, 84.95826336645311, 83.63840149294946, 83.75211884898525, 78.56417240635042, 79.4482118852677, 79.7415816399359, 85.40038508753624, 75.97659264841388, 71.25400404776298, 57.63735478924167, 63.08630751025293, 57.600723774202415, 61.64604063956969, 56.360772348219356, 58.78457746198101, 55.32625506001135, 57.344906791563965, 55.89215893899241, 58.35474452664776, 54.22359835716986, 53.91938717134538, 54.45266085286295, 54.70629307531542, 55.138836368437744, 56.45983572929137, 56.50167172954929, 56.06570812963671, 52.77741655226677, 55.23891956575456, 53.77634617590136, 56.91834119058425, 58.37984377338041, 65.65591104568975, 65.81078190957346, 72.19363920150265, 70.45453086976083, 65.34957785760203, 66.01515308503183, 74.74186189713018, 67.36367179501441, 67.75587743328464, 58.108380456124586, 70.07201348581623, 62.109727551860196, 54.90842457740538, 72.61582743737006, 62.76757571005053, 73.44088231363605, 67.7349005976031, 68.3815739231725, 67.29849769223121, 66.46579419412922, 68.8559296823317, 64.77473881936842, 66.98140544276085, 62.35470702571254, 61.57143323652206, 67.19843802913543, 66.33454384342318, 67.56733694384175, 71.01534351225823, 68.48003325923797, 65.16050784818589, 60.38996434980824, 56.637754440307624, 55.35124840274934, 55.18484184818884, 52.25475288206532, 54.95210016927412, 52.58933890250422, 55.488468600857644, 52.44119490346601, 56.386079480571134, 53.13688216670867, 55.58051878406156, 53.13174778415311, 56.28990296394595, 55.64541439856253, 55.46060016078334, 55.05705495034495, 56.03248565427719, 54.42894228043095, 56.95632934570313, 52.53809705857308, 57.626505513345045, 55.25897072207544, 62.816468054248446, 61.101333248999815, 69.85349039877616, 65.16423409984958, 69.67576780626851, 62.011385886899895, 65.05362718336045, 60.66526766746276, 75.66634101252403, 72.43824605018862, 96.41094884564801, 19.917564315180627, 1.0017813093239263, 2.312060219626273, 2.475891002724248, 0.47300018189895543, 0.04983846278440568, 0.7549482704170289, 57.33441052898284, 68.87855391348563, 35.62345620124571, 65.99505486026888, 35.01126835423131, 33.478311954006074, 49.950709496774984, 52.36432037045879, 73.01230061438777, 67.29130406533518, 84.18997303132089, 15.091836990848666, 0.4784810200573937, 0.10830215629070036, 0.017123911379566117, 0.04196599005691467, 0.07546461713049682, 0.003976328378250342, 0.015282942725706006, 0.12754921140449663, 0.03770901566191066, 0.04899691519958358, 0.07049261457136563, 0.05603540163006514, 0.02550572340917443, 0.029811267778577826, 0.07352854440649671, 0.027514938377745213, 0.20645309600137896, 0.19850087352097037, 0.16470285162570017, 0.20929266217975848, 0.12752854235229955, 0.1154106708183404, 0.23868492774425015, 0.2808542068927519, 0.13996654670805703, 0.21379453190151723, 0.14707130740486807, 0.2542425800235041, 0.4334882166116469, 0.6253042528706213, 0.8573927345775789, 21.116060210812478, 116.3246496262089, 91.18145665814801, 92.2449916408908, 80.0319625485328, 42.07907738224153, 56.62528130315966, 75.00505293569258, 53.68066387791788, 37.356127923534764, 0.16974041598939127, 0.8556635822019271, 1.2105144055620318, 8.336093694933, 4.956429523806419, 14.952736016242737, 8.668913668201817, 0.33221442672994833, 47.577244081804835, 89.30911325639295, 92.3464398230276, 94.90407620706867, 93.28777728542205, 93.55676558709915, 89.42684711948519, 86.27451665939824, 84.31632041931152, 89.89915540141445, 82.50642115069975, 89.51149971254411, 87.69893323221515, 86.88146421986242, 83.43393618060698, 79.15455971994709, 85.17775920129593, 88.2409812558082, 78.7694614164291, 75.55258443278652, 62.24375101827807, 64.84168191109934, 60.775521570636386, 64.14058962175923, 60.50611749772103, 64.12369989579724, 59.563513109760905, 58.8240090493233, 57.84745654752178, 60.97945344063544, 56.824914255449855, 57.52041716729441, 58.31134742306125, 59.079335735690215, 59.55695882920296, 58.55302426122851, 59.09192654394335, 57.33648938517417, 56.43245366311843, 59.1981678624307, 56.731852100741484, 59.16292144406227, 64.2807908211985, 68.09474668195172, 70.69895728941887, 74.18233579204929, 74.05659244906518, 68.27866661933162, 67.83010436642554, 75.4113712618428, 67.68165050014373, 71.38791376544584, 61.4688357999248, 74.75077352216168, 64.47826646989392, 59.293830548563314, 72.65178772710985, 66.29411205168694, 76.90169149829497, 72.58670776121079, 70.56880520236108, 68.41798136311193, 67.98446532218688, 70.91470333837694, 65.49660398114112, 69.41546363215294, 65.83016626296505, 62.932691804824344, 71.04560852050781, 67.98051941779353, 69.69483837004631, 73.53201466221964, 72.49945071435744, 68.56091253219113, 65.47632924972042, 61.6743758416945, 58.21484142734159, 57.69835549016153, 55.6980957523469, 57.75249204327984, 54.61469004231115, 58.55877445590112, 55.521663619625954, 60.04154805214175, 54.358763233307876, 59.86290762501379, 55.58123265543292, 59.82002827429003, 56.463679652060236, 58.02172745427778, 59.452227623231956, 61.32783051460021, 57.08864265872587, 61.09279817150485, 56.47128120545418, 60.72214203496134, 59.51082391123618, 65.81406101103752, 64.93361050082792, 73.26873733151344, 67.64497633903258, 73.74883544060492, 64.16466905224708, 68.56356405442762, 64.05990254494452, 81.57258326007475, 75.18184984883955, 102.24906736804594, 20.631496483279815, 2.2546568224506993, 7.204157479347722, 5.93502018720873, 0.47858401291793395, 0.10969159463720937, 1.705518011604586, 71.73272932729414, 71.16895921768682, 52.76546116798155, 107.04104269704511, 52.22766891602547, 31.148806502742154, 53.94916188332343, 62.65051257225775, 82.67264335386216, 77.49979803639074, 93.58857600919663, 12.444019432990784, 0.6479508537919291, 0.1867849376773642, 0.24128408021023198, 0.16530360245416242, 0.23887678680400695, 0.15023894307594146, 0.24015661329030993, 0.16722355668823566, 0.11484209568269792, 0.13022639758644566, 0.19708854446728385, 0.1666353850234901, 0.13641315512359142, 0.17971811365456353, 0.12449153999407446, 0.11971622284862304], [0.12751476043054175, 0.001092319763565977, 0.02750230941831345, 0.017974655849919204, 0.05929014532856884, 0.07633995685365892, 0.009496077339375212, 0.02904206953732477, 0.022189457104691578, 0.030651407676839063, 0.07466370284917855, 0.07867328447079466, 0.0503737016040231, 0.06044432956485018, 0.16480999668279003, 43.50928337343278, 83.12755200170702, 72.50036070423742, 71.3656033239057, 63.326991988766586, 27.2855366429975, 45.223719996790734, 48.69298581154116, 42.30924990869338, 9.230343103408813, 0.031414820039043986, 0.1380504075918467, 1.2143645796083635, 0.3648519173504845, 23.153027449884725, 5.666006880421793, 0.4061195722991421, 8.447973420543056, 65.38230219194966, 91.32330525305964, 87.06222272688343, 86.89450217831521, 83.16138636681342, 85.89145798836985, 82.18649694996496, 82.05002984692975, 75.02209955646147, 72.27280047632033, 74.45983563700031, 77.6037722249185, 74.20026102373677, 73.95094733084403, 75.78296092248733, 76.78886844265845, 73.03433649001583, 80.1516575967112, 74.35167235712852, 66.37863912890035, 55.88860134924612, 56.19057678407239, 57.147403686277336, 55.76530556524954, 56.3402073614059, 55.07346222477575, 53.427565097808845, 54.325940839705936, 54.46914657469719, 53.926345456031065, 53.18290333594046, 52.90334032427881, 52.0561279789094, 52.52862453460694, 50.997339064075106, 51.51802585970972, 52.365512770991174, 52.00847510368594, 51.475385773566465, 51.004352261943204, 51.71944349042831, 53.46739284453854, 54.199667976748565, 60.697599764793154, 62.721323120978575, 70.95558228031283, 63.79085933008502, 63.97255920594739, 62.344273521054184, 67.01724021665513, 67.98104501539662, 66.84278103613084, 56.53518838267173, 67.5601903853878, 60.85470245730493, 51.73940443223523, 69.12957775977351, 62.87935541522119, 68.79243435398226, 63.51889002707697, 64.80219541057464, 64.79617849473031, 65.55924031042284, 61.47509590271981, 63.626406115870324, 65.57507491880848, 65.6152242998923, 63.95497914283507, 60.199976505771765, 64.0676139247033, 63.97712484482796, 61.73646303915209, 62.31460079070061, 58.737250143481845, 56.26287783345869, 52.261664098308934, 53.73672631479079, 54.9777760044221, 51.758443617051654, 50.19020549712643, 50.582999490922504, 50.27377159364762, 49.64995391907231, 50.491718092272365, 50.778647315117624, 50.984238347699566, 52.67568595947758, 55.64392389789705, 53.39136554348854, 52.962089584719756, 51.89027447854319, 54.138176979557166, 53.09235149814237, 53.98611061034664, 53.23219968426613, 57.29113109650151, 62.82030805464714, 68.83897719844695, 67.1938096323321, 68.86031489218436, 68.75738405412244, 71.70880286924302, 70.2004397299982, 73.02205162663614, 66.14235554972004, 70.64629554748535, 68.96756818217617, 85.96948962057792, 33.91990023274576, 0.10215374911504407, 0.657392795528135, 1.9022073476545274, 0.6414133045942553, 0.17143866437817776, 0.05091624507199853, 13.75399987543783, 83.40964101975965, 36.771792827113984, 43.14310658362604, 46.90598926236553, 16.788499393770774, 13.417769401304184, 44.81850777902911, 59.715089182699884, 58.31512466553719, 64.09325053614955, 45.4011131102039, 0.6870112255696328, 0.13878772125369118, 0.041815790858480244, 0.08969021104877034, 0.03974146224678524, 0.027487278773239063, 0.009705642606281947, 0.03788979325984274, 0.06219911141200893, 0.026618098396988168, 0.04866484672792497, 0.04937759961091703, 0.05238139205762456, 0.06522725396338971, 0.09857912157331744, 0.02522820422816421, 0.059585613949644956, 0.0333700813503275, 0.0665912045646579, 0.03541127282885775, 0.051409682304027586, 0.06377767005394544, 0.020261964565443418, 0.029622394546505906, 0.01992481118518739, 0.03875861357476923, 0.0640980058890437, 0.005885694559002596, 0.026696457700323195, 0.05821602877169367, 0.03509090635024252, 59.108682909319484, 94.5100192100771, 80.15015925130537, 82.41508483886719, 80.23327427525675, 37.41927416093888, 40.65624152460406, 53.28164508265834, 50.43175681944817, 13.975339224261623, 0.19907047521443139, 0.25218898941191936, 2.9737498491041126, 2.7468904997071912, 28.052552207823727, 2.8539716957076906, 0.9487124989109655, 12.923707654399257, 78.06436046477288, 93.0210796479256, 90.47259807586671, 90.0588821595715, 88.01661383721137, 89.98007389806932, 87.7590710116971, 84.85420288578158, 79.8620690068891, 77.50987068299325, 78.81171318792528, 80.44943609545308, 77.3436249456098, 78.49321672993322, 78.42738366896107, 79.27660034548852, 75.36476565945533, 82.61052085507302, 78.0845606711603, 68.82015766636019, 58.539982380405554, 58.33041798683905, 61.0741041552636, 57.49731440697947, 57.770962484421275, 55.97977684390161, 56.20328134106052, 57.75237829454484, 58.56332832767118, 57.10360257856308, 56.09156047144244, 56.14212766770394, 55.39478278929188, 54.33885720468337, 53.21782811995476, 54.45670089414043, 54.39142873210292, 55.81983043301491, 55.403298254935976, 53.65377995275683, 54.44370608175955, 55.29289922406597, 57.17899053327499, 62.8614458730144, 66.48906953873174, 72.56402077213411, 66.88842173545592, 66.13405581443541, 65.40045492110714, 70.53530031634916, 72.70157044933688, 69.73938080572313, 58.304953959680375, 70.50342713632892, 65.66769776805755, 55.58602186941332, 71.86105358985164, 66.08681478808003, 71.50070544212096, 65.40847224573936, 67.37602726105722, 69.01965725806453, 68.36877130693006, 63.925416238846324, 67.49481231935563, 67.50026441389515, 69.10390976936587, 67.420091167573, 64.96994341573408, 66.86491104864305, 67.30349479183074, 66.31962314728769, 63.58902985049833, 62.0911237501329, 58.1890243868674, 54.597623809691406, 57.159476741667724, 58.45168982782672, 55.2923422475015, 53.8286352926685, 52.619596066013465, 52.795616349866314, 50.97613473092356, 52.92296786462107, 55.74849820906117, 54.104519121108524, 55.3481654197939, 57.61520908724878, 55.48431481084516, 56.631070721533995, 55.28907883551813, 56.44995920119747, 56.449437525964555, 56.05396063097062, 55.7513262379554, 60.62276878664571, 66.65969264122748, 71.7064102234379, 71.56550299736762, 72.04207881804436, 72.00061152058264, 76.76462819499355, 73.36623176451653, 76.48988969864385, 68.92798362239715, 74.31189952358123, 70.62322416613179, 88.3844772461922, 38.21615857462729, 0.10465817480918863, 2.620888525439847, 3.6417098775986707, 1.2749417871236801, 0.2951410112361754, 0.14914037299252328, 11.338415068964805, 91.12063638625607, 46.99661170282672, 42.61619498652797, 32.487232954271384, 22.590106533419704, 23.466862170926987, 59.109486995204804, 68.91067028045654, 65.1242337688323, 69.08196803062194, 67.64641977125599, 4.368941332063367, 0.17479774542152884, 0.04155936590846508, 0.02927203955609472, 0.0399622181430459, 0.012038233821400473, 0.024431714104608666, 0.04307991254233545, 0.01990937642873295, 0.0024362342927845256, 0.05363332528260447, 0.027722567357423327, 0.035209328221577796, 0.03512923755953389, 0.06240579044266094, 0.001291919423590204, 0.26531022162206713, 0.16515580877181024, 0.2195207020568271, 0.18128563679995077, 0.23588804798501156, 0.2272711676214972, 0.16511214176012626, 0.14033439148577953, 0.097133980973834, 0.1842316738780468, 0.27198103947504876, 0.18908721575092888, 0.17385462989970563, 0.22191995153984717, 0.2789634099650768, 64.71300071285617, 105.66181967335363, 90.61257962257632, 92.11484739857336, 83.06178954339798, 41.076680383374615, 67.7592271374118, 69.5751747008293, 64.41867782223609, 18.067123428467784, 0.3850495190389695, 0.5690209988144137, 5.510972747879644, 3.615151509161919, 33.69239884038126, 22.323391245257472, 2.754611195095124, 21.714164787723174, 81.98019596838182, 95.23331211459254, 91.40565933719759, 94.36642123806863, 90.71029370830905, 93.78324324084868, 90.69462776184083, 86.89624371067171, 80.6087000139298, 78.64596166918355, 81.589888757275, 84.73624152521934, 79.74660227375647, 82.79059686968404, 81.7305684858753, 81.53758787339734, 78.64793069901006, 87.41430251829087, 79.91835501886185, 75.37126894920104, 61.10991539493684, 61.08548687350366, 64.28688618444627, 60.67051972112348, 61.567985473140595, 59.80967321703511, 59.04661532371276, 60.034868255738296, 59.98726637132707, 61.70002814262145, 59.600438302563084, 60.60483178784771, 57.443711296204604, 57.518091201782234, 57.489438287673465, 59.78311092622819, 58.65330357705393, 59.50617982495216, 57.94927735482493, 56.91807054704236, 58.16223459859049, 59.16625545870874, 60.57161323485836, 65.80835788480698, 69.94550920301869, 76.49038391728556, 71.89305228571739, 66.91045761108398, 65.84903286349389, 73.90082728478217, 74.57654183910739, 70.96080687738234, 62.833946135736284, 74.9610439423592, 67.51527924691477, 58.6591753652019, 74.06595122429633, 70.66220468090427, 75.19460539663993, 67.96165281726469, 69.23668199969877, 71.77807192648612, 70.62371054003316, 68.9294505888416, 68.80759039232808, 71.07967822782456, 72.11913770244968, 70.08344327249836, 67.29700719156574, 71.29446721846058, 69.87416128958426, 69.84887769145351, 66.81323774399297, 65.43729382176554, 61.3861483143222, 58.68127399875272, 59.010392235171416, 60.68408719954952, 58.605266309553585, 55.64858367366176, 57.37836068676364, 56.14242184546686, 53.56389491788803, 56.478780777223655, 58.19601797288465, 57.61754681987148, 59.5521225467805, 61.21033983845865, 59.662458819727746, 61.18134175577472, 57.448775076097064, 60.882312020947865, 59.72927247324298, 59.96228871806976, 59.24944108532321, 62.85209886489376, 69.5338015402517, 76.2501387442312, 73.23798594936248, 74.63550290753766, 76.3998556137085, 79.99516287157613, 75.76740480238392, 77.86107970822242, 74.95611744542276, 77.21713635229295, 74.71212248648368, 92.39312387281849, 40.43230164435602, 0.3921055871873133, 4.691961753752924, 5.980611856906645, 1.7565877615444123, 0.4938397959115044, 0.2888719298906865, 18.1401305044851, 99.29145905279346, 52.41595837377733, 60.180011641594675, 60.429694037283625, 25.273068528021536, 24.896911267311346, 62.00569452777986, 76.56745064643123, 76.31506966006371, 80.30033896046301, 76.65052644668087, 3.4158502422994186, 0.30937685541087584, 0.1379874811297463, 0.18093662246340708, 0.22877614734874618, 0.10408101182791496, 0.16616131449418683, 0.15473722750621458, 0.19723558738347025, 0.13730144939355313, 0.16608515003275487, 0.10368155826243663, 0.10528554719301964, 0.15129364696481537, 0.2162019938470856, 0.13312329778507834], [0.025721258416231123, 0.07467529375947292, 0.0617162921586104, 0.020289953587757006, 0.03590057701653531, 0.06796419500343262, 0.019878633320331573, 0.04330710357716007, 0.05365544224097844, 0.02297842807527031, 0.041936828920076934, 0.03988981900376178, 0.026004571137168718, 0.16544445537992064, 1.9772318702551628, 78.52268941940801, 77.65515527417584, 73.74409721743676, 53.1062602227734, 21.15889837664943, 28.162143230438236, 49.7091934757848, 36.29728801788823, 36.88809502509333, 4.0944470032568905, 0.11171129351902394, 0.6788460153245157, 6.567243010767045, 2.3407535831774435, 8.240653603307663, 2.346632480621338, 1.6725096731416642, 37.19532251358032, 83.16874473325669, 81.8699852112801, 87.7441660050423, 86.82547630802279, 85.26782466519265, 85.1556448782644, 85.69726928587883, 83.30013628928893, 81.1887401150119, 83.12393557640814, 79.18722521874213, 76.61728828184067, 77.42055831416961, 79.20697043018957, 74.39547738721295, 72.38424285765618, 75.31672446958481, 71.74682632569345, 72.82834145330614, 61.7694305604504, 55.746952795213275, 57.5848146407835, 57.534847567158366, 57.487394732813684, 53.73397281092983, 56.659543206614835, 56.568422625141764, 55.87222153140653, 52.85960589685748, 51.713481487766394, 52.18860603147938, 52.12706404347574, 50.99810000388853, 51.50046540844826, 48.506304525559955, 51.0813719226468, 52.40704674874583, 51.15231190958331, 53.665735337042044, 54.42225856165732, 50.4046767757785, 53.74246081998272, 55.58465688459335, 60.96269707525931, 61.675893798951186, 65.14052337215793, 62.54118434844479, 67.65071868896484, 66.37266143675774, 64.03024158170147, 63.81030644139936, 67.86098910916236, 61.83645209958477, 65.31850091872677, 62.812690811772505, 53.084357707731186, 67.61192644796064, 62.28994477179743, 68.10040273974019, 65.70774124514672, 61.950899016472604, 62.279130797232355, 65.37966635919386, 62.24598284690612, 63.32798827079035, 63.592136367674804, 64.02221248995873, 63.91551225416122, 65.65731525421143, 62.652057986105646, 63.25300432020619, 66.9723290781821, 59.32301690501552, 57.49845973906979, 54.18808521762971, 49.20056012368972, 52.46763167842742, 57.64349722093152, 52.85110612069407, 47.53936967542095, 49.800486641545454, 49.35532900594896, 49.62321512160763, 48.9873008574209, 52.51303311317198, 52.50304675871327, 51.720961447685, 51.98694129143992, 52.48377615405668, 52.785520169042776, 52.32890529017295, 52.72069515720491, 50.1072120666504, 51.59481017820297, 60.81930698886995, 66.43727071823614, 71.53956044104793, 72.2284306249311, 71.78713260158416, 73.46291034452378, 72.54651915642523, 72.129320175417, 72.71762863282235, 74.19092578272667, 71.94373715308406, 77.3523953653151, 71.42066555638468, 85.92542571406211, 48.01525123657719, 0.0782131337590756, 0.9801361385372378, 1.3800891320551596, 0.8428447861825267, 0.14635014287646742, 0.031051431977820974, 0.4874896318201096, 52.753878408862704, 72.71996636544505, 37.51023784760506, 69.26779423990558, 33.09531604090045, 18.27486195871907, 25.43425048551252, 32.65361205224068, 58.740407651470555, 61.539509065689586, 73.74857656417355, 34.29445128287039, 0.5093167025235392, 0.028722222083278244, 0.0503143374507706, 0.08128260292353169, 0.03593574811313902, 0.058358965456605925, 0.04748002663555165, 0.0112904908300768, 0.018055807543738235, 0.06880095453872796, 0.03222268082261567, 0.05999769264411542, 0.02093106192807036, 0.07771323840584486, 0.07452995155847843, 0.03199951557983314, 0.023710222073620366, 0.04124739958393959, 0.029860211220840295, 0.03870832373297984, 0.09549473667697561, 0.0437890111859287, 0.049551555195883404, 0.03882657706497177, 0.024960318602801814, 0.017511733815134052, 0.02912361768164462, 0.021298192328803485, 0.21439424085040248, 4.424097211130204, 95.73942338266681, 82.79973599218553, 90.12520943918537, 62.73676549234698, 39.48887748102988, 38.674762095174486, 36.07293236640192, 41.51134175638999, 54.00998999995571, 4.965897144809847, 0.1998750513960277, 3.1868384922704394, 5.73485428287137, 3.0876412603162953, 3.080699890851975, 1.7075245490958615, 2.088436335325241, 51.46639962350169, 86.77887070563533, 85.13196945190431, 87.88557529449464, 89.92136386133011, 89.13780766148722, 87.79761222101028, 87.18623238225138, 84.87459921067762, 81.90260364163308, 83.5266923904419, 81.11473283460064, 80.84374412413567, 79.54154860588812, 82.70475187609273, 76.61353065121558, 76.1045717423962, 77.17729291608258, 77.10592146842711, 77.65171143316454, 64.47210442635321, 57.798846613976266, 60.64619318131478, 58.5562837508417, 59.62235650708599, 57.9845041613425, 59.25872925789126, 57.79468890159362, 57.54437892667709, 55.860336749784416, 54.69160379902009, 54.047542771985455, 55.21086677428215, 53.589429547709805, 51.99680997479347, 51.80605334620322, 55.48081213428129, 55.03871786978937, 54.37784948656636, 56.81439053627753, 58.87479197594428, 53.953715755093484, 56.68207330088462, 57.69396635793871, 66.43471333288377, 63.9498173036883, 67.59772746793686, 67.91555712299963, 73.60736339322983, 67.22877364004812, 65.67757821852162, 67.56722711747693, 71.64586451745802, 65.14071949066656, 70.02671011032598, 65.14226490451445, 55.55681197874008, 70.65554449635168, 65.17070601063391, 70.40652105885168, 68.96239849828905, 64.40812664647257, 63.9615059668018, 68.45816212315714, 66.29265292998284, 67.12168508960356, 66.69868884548065, 67.22168199477657, 68.24174927126977, 67.62685498883648, 66.28880900721397, 65.58631250935217, 68.15868131576046, 63.38197577384211, 60.83823242495137, 56.53550217228552, 51.35099957066198, 55.0680140526064, 58.89504317314395, 56.099628786886896, 51.91805270410354, 51.97545266920521, 51.34690853857225, 51.775203904797955, 52.25876154438142, 54.73311816492389, 54.763088995410556, 54.08245186651907, 55.430503814451164, 55.23315760397143, 55.30267377053538, 54.70164114429105, 55.22121006442655, 53.60762150056901, 53.62389541441395, 62.17570181815856, 70.98458428536692, 75.78017603966498, 72.61271307545324, 74.17200426901542, 76.10846273360714, 75.09469478361069, 76.06523821430822, 74.19338118645453, 76.28693057644752, 75.53839329750308, 80.5578504070159, 76.38996339613392, 86.28926477124615, 52.002881803820216, 0.05341094527994433, 1.6627073023588428, 3.2053697301495463, 2.191660615705675, 0.8355388814403165, 0.1650567382814423, 0.11589635524057573, 50.32616269203925, 82.65027015439927, 44.899622394192605, 51.188923312771706, 33.424567637905, 32.88096243335355, 40.86959100538685, 46.33194646527691, 68.4838536477858, 67.9285244787893, 83.2193668427006, 52.938449459691206, 0.6517771258950233, 0.09212168218988566, 0.06301620930072761, 0.0042352136675148245, 0.021756489107745792, 0.0433074674689241, 0.03925487384079926, 0.03445207329106427, 0.10814932941068565, 0.029755329953566678, 0.01669904859285922, 0.06233066019992675, 0.019141423080356854, 0.01043843060371376, 0.025637373703742222, 0.1218692746554171, 0.2212111516705444, 0.1836325318342255, 0.13666194983788077, 0.10022490826104918, 0.23065563681865894, 0.1598155937127529, 0.1853848507087077, 0.15200017921386227, 0.11284641365730956, 0.15454532248118233, 0.2619468504863401, 0.1404060819937337, 0.41025335209504254, 4.63644354574142, 108.62514680431737, 97.16289074190202, 99.46642029669978, 72.7380249577184, 37.82870684900592, 41.83830661158408, 71.35262812337568, 50.656932246300485, 60.84761081203338, 6.986428672267545, 0.2446481408250909, 2.8103443980216984, 15.129710416640005, 6.827315765042459, 21.91994409407339, 5.402977639628995, 3.7054883520449367, 59.71244158283357, 90.024043667701, 84.56617539928806, 92.41522250636932, 93.67623313780754, 92.70313232175766, 91.1102185710784, 90.96349054767241, 87.14046616708079, 84.9550784018732, 85.59418939775037, 83.89163755601453, 82.01392835186374, 82.61951877224831, 85.6845372722995, 78.85485925982076, 77.28620929102745, 81.80950226322298, 81.56166338151502, 81.39861045345184, 68.16194472774383, 61.22517424245035, 63.09140659147694, 62.4453765346158, 62.86106540310768, 58.276532465411776, 62.37331867218018, 61.574684881394916, 60.705832819784845, 58.355387795356016, 57.76679692729827, 57.621371130789484, 57.13126313301825, 57.251883860557314, 56.55302732221542, 54.831781464238325, 58.09744488808417, 57.703662457004675, 56.26323476914437, 60.901676762488584, 61.73570209933866, 58.58918066947692, 60.00202232791532, 60.82218600857643, 68.90989365116243, 69.62869936420073, 72.91239000135853, 70.8159694363994, 74.33857948549333, 71.85302842047908, 66.73570033042662, 72.26088431573683, 72.9144060996271, 67.17739059079078, 73.15196837148359, 68.84251517634239, 60.46102200784991, 72.86155608392531, 68.83889090630316, 74.00836298542639, 70.40403427616243, 66.72136014507663, 67.35387371432397, 71.22264077586513, 67.94288819836032, 69.77716107522288, 69.15439851822393, 68.02441858476209, 71.08649530718404, 71.04563205472886, 70.72874376850744, 68.82323280457528, 71.39213423575126, 65.83371993034118, 63.90740471501505, 59.5329813803396, 53.350227725121286, 58.609082775731245, 62.16632343107655, 57.831045350720814, 53.24020131941765, 55.413284609394694, 53.8569155816109, 55.463859650396536, 54.602279663085945, 57.87852956402687, 57.32279246853244, 56.841533337869954, 60.642490463872115, 58.78924116011589, 58.352536232240745, 58.15839459819179, 58.9163024194779, 57.22740827068206, 57.044951377376435, 66.56713254990117, 72.8971476708689, 79.09595166483234, 76.25300991919734, 76.53033717986077, 78.68712302177184, 78.28031832172026, 77.13901842794111, 78.03703723415252, 80.05817967076456, 78.80956372907086, 83.86156866627356, 80.0046314731721, 90.52092167638963, 56.46690384034188, 0.19541522457955346, 6.066575502195667, 7.788599950651969, 4.245762728875683, 0.5383065727449233, 0.25621714100482007, 0.7247569291822372, 64.09392126144903, 88.16492649816698, 55.848859894660215, 91.7996535762664, 50.59000092168009, 29.058726449166578, 38.44513085580642, 50.49256532422958, 79.54654570548766, 76.08429308860534, 96.35281931969428, 52.72004796612648, 0.6364403520860981, 0.2024981824140395, 0.2075696385075008, 0.16371321924511464, 0.1137743759599905, 0.13311465631329245, 0.11143832873072355, 0.17630876192162115, 0.15796671711629437, 0.2079180859389805, 0.09797873846705883, 0.21846904719789184, 0.2510552712145352, 0.20223431108940035, 0.25171111908651167], [0.030563062417411038, 0.03118992726799221, 0.06231971280348878, 0.028126288032639894, 0.13066440069627377, 0.027065300307567083, 0.038035047360725945, 0.07246610302958759, 0.04530647814634346, 0.025134438896671902, 0.03059612677222298, 0.021016344751021074, 0.2583765436805064, 0.6213681544027021, 24.889958866180915, 80.38627809093845, 69.64248257298624, 60.99927317711615, 39.674515416545255, 68.41015231224799, 43.61712501895043, 56.3165044784546, 35.981756871746434, 39.488473476902136, 1.3277748876040982, 0.25496780481790343, 0.25863486852857376, 1.8179567975382653, 1.022468686344162, 3.9353245352545096, 2.2732103688101617, 24.959012193064538, 78.65742283482706, 78.78508813919561, 88.12033699404809, 86.50296334297427, 79.7752747997161, 81.0190034681751, 83.36304326211253, 85.03482803221672, 83.3812822834138, 82.27712723516649, 81.63562359348421, 81.49601074957079, 81.29978241459017, 80.05751286783527, 79.02486262782928, 78.53419765349358, 72.1787420395882, 71.94178381273824, 73.12826941090246, 71.17717266082764, 59.25099434391145, 55.08689634261593, 57.70474503117224, 55.15811874020485, 56.36230207258656, 55.006358315867764, 56.48040856084516, 56.49299544672812, 51.86626565071845, 52.68482508197908, 51.998092589839814, 51.039912469925426, 50.64392566680909, 48.18490551364038, 49.219630687467514, 51.22933549265708, 53.01905808910247, 53.48868346983387, 52.0784580323004, 52.096606839087706, 53.67529807552215, 52.51597489080122, 55.099008621708045, 56.96188342186713, 58.69344119102725, 59.6148177116148, 60.30022836500599, 64.19489875916513, 65.26774152632683, 67.32141217877789, 67.58818041893744, 64.78289734932684, 62.903736868212306, 61.51996389512093, 68.95001165328488, 58.779325408320275, 51.529455646391845, 67.02299825606808, 60.93170250615766, 64.44138834553381, 61.47127551417197, 63.63871059110088, 58.90917939524497, 61.998179266529704, 61.37371440087596, 64.4786940082427, 63.1447978942625, 66.37485011931389, 62.35742915061213, 61.78164089879682, 64.35897934821345, 59.770888820771255, 63.295816990637014, 62.04281191672049, 58.99174136500205, 54.74693275267079, 49.390418529510505, 48.91592940976543, 52.66436599916028, 56.23815905663275, 49.140112476964156, 50.40848931958599, 50.30460142320203, 50.88614379206012, 49.09484048043528, 51.52418790325042, 52.16101215731714, 53.3507925464261, 51.601576266750214, 52.75379211671891, 53.95501013725035, 52.36569712238928, 50.873380399519405, 50.16677325771701, 60.39581260373516, 66.21196193079795, 68.51458934045607, 70.18074158699282, 68.61468038251324, 71.3100076490833, 70.85826827633765, 73.86321175482966, 75.03074446032124, 73.37499433948149, 77.0456503283593, 74.59416112592145, 75.00772014740976, 70.44285789612802, 75.02072672690116, 47.87994123274281, 0.28807149058388126, 1.654323726411789, 3.587944723906056, 1.2328334272869172, 0.5658554622242528, 0.17020658049131596, 0.16379683008117063, 12.634430893005865, 77.88702226454213, 56.1252026404104, 35.672152426935014, 52.30643403145575, 21.587678155591412, 14.527607963931176, 20.139329241168117, 38.651929978401434, 61.88705067480765, 62.57323795749296, 76.9949419267716, 8.55986491326363, 0.4529697712390654, 0.10359916550618026, 0.09963574068200204, 0.015200270347357278, 0.06069407805860524, 0.017504390862379825, 0.040617928119196046, 0.0435811868538299, 0.054147098318583546, 0.06765871744362578, 0.017671204592672088, 0.03927140984864485, 0.07122690984678846, 0.04872795322068757, 0.021852998949226835, 0.014164712910930959, 0.03930779136416893, 0.0542176052206947, 0.0787462390238239, 0.01678754898509191, 0.04526653815241111, 0.09746091665639993, 0.013567179651750673, 0.014150024132592785, 0.01769101179595436, 0.15901103285291504, 0.43591199623000243, 0.5329229358223178, 34.63136719119164, 92.47879628212222, 76.2793682467553, 66.03572199421545, 56.58588893951909, 61.33969568437146, 33.654771543318226, 54.0139437490894, 48.632157694908884, 45.04760165368357, 0.3848561584468811, 0.12811601687703403, 1.8249228043902306, 2.773652341096632, 2.789494303926345, 1.0952982138241492, 3.1832203509346133, 38.28985991016511, 88.60860147783833, 86.03263193561186, 87.63701469667497, 89.8374172949022, 82.86374907339774, 85.35844710565384, 89.2093752276513, 88.30294685979044, 84.7656593015117, 86.06699974306169, 83.37521045438706, 83.77071872834237, 83.97606265160346, 84.18742349070888, 81.87342120755105, 81.04243570758452, 75.31426906585693, 75.2607600919662, 75.26685545521399, 72.95735605301397, 61.652136002817464, 56.95058699577086, 58.62587052006876, 59.44400241298061, 60.27794538005706, 57.08559497710198, 56.87282208473452, 60.03719814362065, 53.88052825004824, 55.541251936266505, 53.2400248127599, 54.48450265392181, 53.89419378772859, 52.92086155183854, 52.479896929956254, 54.45476324327531, 54.463314010250954, 52.8208803361462, 55.00486781520229, 55.223606632601836, 55.999349471061464, 56.539969751911784, 56.99341927805255, 61.25450572659893, 62.45962650545182, 63.593956347434755, 64.4292760664417, 67.83277157814273, 68.33185395886822, 72.79766851855864, 68.09335031817037, 65.65201613210863, 67.93717722738943, 66.05132518276092, 70.13636389086324, 62.14721364359703, 53.744888767119384, 69.20228281328755, 66.24684749111053, 68.01872330327188, 65.4336146385439, 64.30839646247126, 60.664542028980875, 63.824297535804014, 66.04338630553215, 66.01148174655053, 64.1776167961859, 66.59218080582158, 65.78306644193589, 63.63594924249957, 67.44738301923199, 62.113489104855454, 64.35881068629604, 65.46171842082855, 61.365916728973396, 57.61064737073837, 49.94338643166327, 51.67013145262196, 54.03615220900505, 57.99601631779825, 50.44808564647552, 52.86886269046415, 53.00695757712088, 53.51025650578161, 51.27864360809327, 54.52252218800207, 54.19623590284779, 54.061749596749586, 53.998371939505304, 54.84925170098582, 56.885636468087476, 53.836758521295366, 53.15857287376158, 54.034653863599225, 62.79824080005769, 68.9764170492849, 70.30358237604942, 73.66842685207244, 70.19482289591144, 74.00372674388271, 70.86051971681657, 74.53647090542701, 75.81805044604887, 74.29358205487652, 77.93348666160338, 77.84393895056941, 76.36513479294317, 72.80895709991455, 76.22811071334347, 51.069797008268296, 0.7360242439373847, 1.1365377686677443, 3.7781009847118012, 2.4103724668102884, 1.11863165853485, 0.5318140695171972, 0.12311191523387549, 10.304677351828545, 81.46248232933783, 66.22746313771894, 35.90094427908621, 33.024760446240826, 26.72282949570687, 24.562215420507616, 35.32491284032022, 46.48185160852248, 68.20352185157039, 65.62455561853224, 89.87071037292482, 15.720581162360409, 0.47651686255008946, 0.12799380287047357, 0.07127562537789345, 0.05376968510268677, 0.05695322475906822, 0.03765473450203577, 0.03205236990094906, 0.08299491668660795, 0.11551891904204123, 0.04538830782797548, 0.029617550955604643, 0.013505910812396438, 0.015253526864633446, 0.06353210823069658, 0.1385279255168092, 0.16254855109558952, 0.16930578366642998, 0.11399523144768131, 0.17735335344989456, 0.1352060303813027, 0.10146471431418773, 0.28194974326798994, 0.15815483766698069, 0.19436894765784665, 0.12448006399696875, 0.2336859742119428, 0.5296736811437915, 0.8824302039800153, 38.13549503203362, 108.96578111956197, 87.535197811742, 78.74148707236014, 52.78230382550148, 83.7974222244755, 56.90060031029486, 79.61368883809736, 57.495541495661584, 56.836755891000074, 1.7281871048673507, 0.44659466332485603, 4.173164069652557, 5.32132173738172, 8.770918826903067, 10.161185283814708, 5.740628992357562, 45.93188039718136, 93.62118659480926, 86.69463388381466, 92.01685090218821, 95.41660447274485, 85.60503082890665, 85.92868912604548, 91.3265843545237, 92.68712905145462, 88.32524161184989, 88.2459234422253, 88.281813129302, 87.28398569168584, 86.75266142814391, 88.1608158542264, 85.33561891125095, 83.28233657344695, 77.44237453706803, 81.01351214993386, 80.75067412468695, 76.64160697690903, 65.14902707069152, 59.737733025704664, 62.330474622787975, 61.36790537065076, 63.073959888950476, 60.851254693923465, 63.03753283716018, 63.4663498786188, 56.943742459820164, 59.249452852433734, 58.68487865694108, 58.30842525728288, 57.784424058852665, 53.46450205772154, 54.509645046726355, 56.75547261391917, 58.25575959297919, 58.94151933731572, 58.84226376010526, 59.07659792130994, 60.56524330569852, 60.463296982549856, 61.25115602247177, 67.04897219134916, 64.40334135486235, 68.07100065292852, 67.10763515964632, 71.33703277957055, 72.7784175257529, 74.64885465560421, 70.48145401862361, 69.23002181514617, 72.7731772392027, 66.07520457236998, 72.78851370657645, 66.19668037660661, 55.66861914050195, 73.56928502359699, 69.2415378939721, 70.16114542561193, 68.42868158894201, 67.43661219073881, 64.78935357063048, 67.88252292140838, 68.61156602059641, 69.67761916498985, 67.76212184659897, 73.47582278713104, 68.74551496198102, 66.04843047357375, 69.48802748034078, 64.94303595635199, 68.18067796768682, 68.02931370273714, 64.15696943959883, 60.71070832590903, 52.39449908656459, 54.80308932642783, 56.382655251410704, 62.37532692570841, 55.779755576964355, 56.29847726514263, 56.973799582450624, 56.318061659413004, 53.785967749934045, 57.11551873914657, 56.950422256223625, 57.41757262137629, 58.502613959773896, 56.880753117222945, 59.83246218773627, 58.795728760380904, 57.687404232640425, 56.784709961183616, 67.07063936418103, 72.50984499531408, 73.96059636146792, 77.15403326096074, 73.67846811971357, 76.01523583935153, 73.82978531622118, 78.79157573946061, 80.12489918739566, 76.73175088820919, 80.43752777960994, 80.7467282202936, 79.55828143704323, 74.71686070965183, 78.41274538347798, 57.47556486437398, 1.3440361763200452, 6.066588249898726, 12.483008773096147, 7.097014015720737, 2.023133774918895, 0.4940278245316398, 0.30418903056171637, 15.723354278072236, 94.10853324397918, 73.00055703809186, 52.47853194513629, 65.69271072264641, 28.51691572896896, 21.746932268142704, 32.93040390937559, 53.55417528460103, 83.656828788019, 76.66550990073912, 102.98721821077409, 15.283506551096517, 0.854264521791089, 0.2654010796498868, 0.19841596033544312, 0.14313694029565782, 0.168811212624273, 0.09953481625885734, 0.12214793147699488, 0.20675562412267734, 0.22326138681702076, 0.2035925083703572, 0.12086356208930094, 0.12542613661817967, 0.2217013406897745, 0.09074905181243535], [0.04620762354123496, 0.08514056042317422, 0.01708302909748689, 0.008562242015144758, 0.05165864938809987, 0.06922129166102217, 0.03307737830665804, 0.0533927200482257, 0.06348675199513955, 0.04044707519032302, 0.02308648477699007, 0.045724888557508114, 0.053762660076421116, 0.1965651838409324, 61.94630592100082, 76.21405293864589, 71.33152577184862, 50.989462944769095, 37.6915023403783, 117.0830398990262, 107.4186178945726, 28.506827392885764, 46.5401380292831, 30.516430216450846, 0.2572411094461718, 0.29462080689207204, 3.4128273206372417, 0.7664073523013823, 1.5669127265291831, 0.8862668335918458, 12.608645231493059, 68.0536323978055, 69.13529657548474, 90.42615721302649, 83.70552109133813, 86.30844516138878, 81.54360478924167, 84.48164832207465, 77.87199174204181, 76.64518417850618, 77.23678742685627, 81.78552873672979, 78.01915122616676, 76.96606543756302, 74.16823879364999, 75.35891348315825, 72.51987057347452, 74.24037902585923, 73.88218033698298, 72.93527310894382, 69.08017158508301, 64.686956174912, 55.622425386982584, 55.38445518862817, 55.73081224195419, 55.238441036593535, 53.99911326746787, 55.528115918559415, 52.26167194304928, 53.825528775492025, 53.629578928793634, 52.07781084122197, 51.68205938031597, 51.99290721647201, 50.30373457939395, 51.29165410995484, 50.97813906208162, 51.95356976601386, 52.49161697203114, 50.72879791259766, 48.746577155205514, 50.6468988233997, 49.377992460804606, 54.49257096936626, 56.97089702852311, 57.923126912886104, 57.283066703427224, 57.36128268703338, 61.15115911729875, 57.47639640685051, 63.04101197950302, 64.70494416452223, 66.2660514154742, 65.36127436545588, 66.94612764543103, 57.93258766974173, 71.29134501180341, 59.339914475717855, 48.72638871592861, 67.70202329081874, 62.11750953428207, 64.7271800810291, 59.67468484755486, 59.187961855242335, 59.38894802524198, 60.025689909535075, 63.0138260318387, 63.9019565428457, 62.11254773601409, 66.3430553866971, 62.176941287133005, 63.481639277550485, 62.64063604416386, 65.05578840932539, 59.75184571358466, 61.55492398046679, 58.2655772855205, 56.2025753144295, 50.25383418606174, 49.95048199930499, 48.87352466583253, 52.90242641202865, 48.387229211868785, 47.308310693310155, 49.41378801099716, 49.11391888895343, 49.9517842262022, 48.68876534123575, 49.55858230590821, 51.332156504354174, 52.87453051536314, 52.343170950489665, 52.5186264130377, 52.133477118707475, 48.98513963145595, 56.08928157437233, 60.950310230255134, 64.30471335687946, 68.66203123523344, 69.09029914486793, 71.4429210847424, 72.08771167262908, 72.64488435560658, 71.11588954925537, 67.87303078559138, 72.7380092682377, 71.97039358077511, 78.55042842126663, 75.67534677443966, 73.19090181781401, 70.89888834184217, 67.31399105441186, 3.353891257316836, 0.6169815962353061, 0.9432424472705011, 1.1796511132870953, 2.123401813930081, 0.2071317120064651, 0.07687335323181844, 0.2807990179186867, 43.830180321970296, 78.11703789618709, 46.75424060513897, 57.91377990476547, 59.02472065341089, 32.05614878285316, 15.179773588334362, 21.76093512965787, 43.05858735115298, 59.896436045246745, 69.9403787428333, 33.035370457556944, 0.5428422422659013, 0.09820700968585669, 0.039060574791003624, 0.08360317517672816, 0.05350548819067979, 0.028569301357492808, 0.06329567817550513, 0.031826115408611876, 0.0766528654663313, 0.04438325026703458, 0.04607977495799142, 0.017352186428803592, 0.023394216550514105, 0.03893590164220622, 0.009513793122624199, 0.060822225416139256, 0.021258824985594522, 0.014678282933610102, 0.03914045477886835, 0.05914625486419086, 0.037018456346085, 0.011437550025631585, 0.01881916819500827, 0.04720277941575454, 0.050837927903499336, 0.013887756804545081, 0.035387164041880644, 0.7528747461976544, 77.67388851411881, 84.1836109469014, 82.20613233504757, 58.21298222387991, 42.81817743855138, 130.76891114634853, 75.39863924826346, 32.00324385396896, 57.00681809456118, 25.117346509810417, 0.2741201101772247, 1.6271398625066205, 4.03784891770732, 1.6523702634919075, 1.2316214149036717, 1.3984643331458493, 22.81369536153732, 75.02737906671341, 74.26906724129954, 90.02128231909968, 84.77530048739526, 91.67878966177665, 86.39157587482084, 89.07451629638673, 78.64749139355075, 79.77265465644099, 79.53934423385128, 83.6658110157136, 79.33012500885995, 81.47389642653927, 78.45739764551963, 79.87571885508876, 75.20074782832977, 75.35270829354563, 75.58991755208662, 75.30093300727107, 73.23821344683248, 66.95713381613454, 57.37042573190505, 57.8604042914606, 57.87714104498587, 58.039013339627175, 56.55270568786129, 57.68254441599692, 54.03207686639602, 56.026676624051994, 56.536490609568936, 54.10281289008356, 55.12936776684177, 52.91057709724673, 53.76098617430657, 52.656944874794256, 53.590304236258234, 55.754064052335686, 56.05344680047805, 53.79569522796139, 52.83252585318781, 53.717271358736106, 54.14604525412283, 56.08074649687737, 59.35527447731265, 61.58236488219231, 59.9314667332557, 59.865629749913374, 62.644668240701, 60.001994871324115, 65.39937234693959, 67.18820848772603, 69.64948792611399, 66.68059887424593, 69.8759263561618, 60.98048502399076, 73.23291824709985, 61.52791061709004, 50.917718871947265, 69.65779550613897, 65.58250781028502, 66.94787702252789, 62.65626276693037, 63.365235097946666, 62.6771140867664, 63.283033986245435, 66.85156714531684, 66.75376676744031, 63.759064597468225, 69.25684298238447, 64.70833309235113, 66.14593275131719, 65.37522623615881, 67.11099270851382, 62.12380101603847, 62.81517759446175, 60.88185702600787, 60.023658121785815, 53.41729241032755, 52.05241741672639, 50.819687074230565, 53.9419682564274, 52.001763928321104, 51.10808326352028, 51.52786316410188, 51.75578032770465, 51.315039280922186, 51.920606167085715, 51.91713486948321, 55.25948847493818, 54.99552472945183, 55.452912315245605, 55.16144883248114, 53.425462707396484, 51.10434524474606, 57.822345533678615, 64.18721483599755, 68.9221549803211, 70.9575277759183, 70.94336017485588, 74.33626528709166, 75.24322709729596, 74.04017340752387, 73.04835504101169, 70.57789725642051, 74.79235849072857, 72.97575196912213, 78.6190071413594, 76.18643160789244, 75.03441579880254, 70.74975982789071, 72.8682319579586, 5.145439717077441, 0.3048187854789919, 0.10687175522288007, 3.0475046269355284, 3.325239568948746, 1.0387724469746313, 0.17943620862018678, 0.09030586994823911, 43.91715888054141, 85.21529628384499, 57.08164907270863, 41.081261711735884, 32.03959245835581, 20.327873652981175, 20.989073476483746, 37.393617937641764, 52.7994445831545, 66.3129315837737, 77.56163812452748, 46.22232014133085, 0.5566295572826939, 0.06043497563129472, 0.09653978785800357, 0.018492222936343283, 0.04526833079815392, 0.008455526924902394, 0.04528644877756315, 0.026036760236527172, 0.07568532706148202, 0.010486607958051947, 0.07128923876030792, 0.032322057748153325, 0.01308169058193603, 0.031005083658402006, 0.19503052586749678, 0.26825681028346865, 0.15351050623482274, 0.08043718659469197, 0.14762623085369989, 0.21203436828669042, 0.15128001059976318, 0.1410725784878577, 0.11769133755156111, 0.19350887606701545, 0.14897109820477425, 0.10381361649882409, 0.1816330117083365, 0.8900815837325589, 90.62553913362565, 95.6924569222235, 93.4758706246653, 74.76465086783134, 49.56661532002111, 121.04290793018957, 136.46347876518004, 45.45083307450818, 64.84791063493299, 38.49223852157593, 0.47044864945834686, 1.5728116035461428, 12.261635103533346, 6.729603640494808, 6.88105910055099, 3.2586161503868722, 29.00605097893746, 75.43860035557901, 78.84854424384334, 92.17320442199708, 87.60107009641587, 93.88620545787197, 88.49736305975145, 92.29422523129372, 82.11653755557153, 81.10754705244496, 83.33031500539472, 87.63628513582292, 82.244155791498, 84.6478940594581, 81.66949718229233, 83.95367376265988, 78.86251572639712, 81.67227422037433, 80.63645470526912, 79.56600850628269, 77.8389810746716, 71.15104967548002, 60.455079617038855, 61.408584271707845, 61.91878264950168, 59.131122789075306, 61.035617859132834, 62.51444555098011, 56.73330730007541, 58.83268925451464, 61.862555473081535, 59.14214857162968, 58.677990974918494, 57.52961904771867, 57.33450858823715, 55.927444581062566, 57.223195645116995, 58.57405208772229, 59.77695672742782, 56.93039463412378, 57.019903121456025, 56.53458826003536, 55.28742751767559, 60.11012284986435, 62.58580523152506, 65.4006039711737, 63.05710546432003, 64.19353769671532, 67.2443768285936, 64.88943284557712, 69.7034832739061, 70.7085043384183, 72.34889445766326, 69.78892818573983, 71.59244968045142, 65.31364110208327, 74.22293232333276, 65.63030189083469, 53.53606570151545, 72.77283991536787, 69.11348819732666, 69.64886034688642, 63.92773043724799, 65.77149937229773, 66.27609268311532, 66.5893723887782, 70.01953217291063, 70.13184532042473, 65.58803835222798, 72.92922481413811, 67.61366013557681, 70.12495763840215, 69.54840844677341, 69.37027792776786, 66.31700300401258, 65.88995887387183, 62.84144178513558, 61.327355907809356, 56.542374164827415, 53.70694768044257, 54.37072646233344, 58.53186307414886, 53.747136285228116, 53.13091624167658, 55.098455567513746, 53.97629291780534, 56.09104664094987, 55.54056944385652, 55.82025797136369, 57.46089127755935, 57.80909576723653, 57.6404534616778, 58.385770474710775, 57.03356081439603, 53.239801237660075, 60.6936970064717, 67.92913636853619, 71.98169785161173, 75.27576708024549, 74.96222065341088, 78.40592045937815, 78.72593095225673, 79.08996612794938, 76.44824981689453, 74.94479748510545, 78.27645870947069, 78.25286173051404, 84.57661674868676, 81.50852311042048, 76.27347684675648, 72.56997493005568, 72.13466244359171, 6.331266847348982, 2.2320664217395167, 8.649933318937979, 7.432225654202123, 6.006719643069852, 0.7251523531252339, 0.23047442638104965, 0.6252291762540418, 53.565930628007465, 91.63492187376946, 63.409789300734005, 77.24177668171545, 75.29579470234533, 40.92617119512251, 25.098634842903387, 37.05422701374177, 62.02151736905498, 77.28031004628828, 88.31545137589978, 53.60738615835867, 0.9013371926642234, 0.17509129499235462, 0.1748429139655444, 0.2090785406049221, 0.1326699882385231, 0.10432936987208744, 0.1913023283404689, 0.07661110601357876, 0.22283400168582318, 0.1510921811624881, 0.1905143149797955, 0.1305999727018418, 0.07843177525266525, 0.11877091631533639], [0.007084380364000437, 0.04893444839023775, 0.04753359916409658, 0.025726450577137933, 0.09256962912097093, 0.04683108504621252, 0.05177141753055396, 0.014330327713621721, 0.029491939349099997, 0.06750317861235912, 0.03282398706482303, 0.012893909982766115, 0.1278196864070431, 8.624380057857884, 82.18611255768808, 67.99309453656598, 67.72051334381104, 39.712166247829316, 37.32592175083776, 3.358871441694998, 45.51541489939536, 33.77838111692859, 61.232175673207934, 7.433896093599259, 0.07969958181943625, 0.5348257143651286, 1.2857102867095702, 2.1356177906836233, 0.24550687942293384, 4.320212256523871, 67.90390768358785, 91.16755577825731, 84.92745707111975, 89.1778079925045, 86.04377146690123, 85.46508066115841, 82.03262236810501, 84.29183698469593, 78.03491915425947, 79.39380076623733, 73.90898581474059, 71.39273828075778, 69.7131872177124, 68.93356907752253, 68.4544986294162, 66.73227217889601, 66.61763698823991, 67.3489393726472, 65.79919130571427, 65.61034094902777, 62.00287434362597, 58.03739732311618, 56.037925981706195, 55.86423166336552, 54.97013522732643, 55.34985596133817, 54.252851393914995, 53.80644644460371, 51.11888154860466, 51.862131472556825, 54.25633445862801, 49.95684800609466, 51.38527716359785, 50.04855302072341, 50.18451806037657, 49.30820957306893, 51.42381837291103, 52.99629265262235, 54.878826372085086, 55.542891486998535, 54.58529580023981, 50.839706851590066, 48.66549784137357, 49.07188677018689, 53.13660367842644, 50.99316173984159, 54.75223971951393, 51.81248995565599, 55.17945251157207, 55.269514053098625, 58.386123488026286, 59.8345410439276, 64.57003424244543, 63.8092670133037, 68.62260357026132, 59.604446964879195, 64.61964045801471, 54.44616148548742, 47.44165558968821, 70.63862339142831, 59.94062546760806, 62.48228996030746, 59.797223614108184, 60.9140714522331, 57.408908105665645, 60.65545781966179, 60.10156031577819, 63.254949815811656, 61.71962038163216, 62.96394917272753, 62.04245105866463, 62.63317177372595, 56.69397377198743, 63.039713674975985, 64.62936401367188, 62.27571441281227, 62.37776271758541, 61.983274259874904, 56.38190607870779, 52.87256148553664, 46.79470377583658, 50.03154170128607, 48.98050731228244, 47.523083994465495, 47.89716436016945, 48.07548707531345, 51.408458371316236, 47.01367793544647, 48.154718952794234, 51.62935449231056, 52.44988295339769, 51.34636725148847, 50.62374899464269, 50.46974497456705, 49.99832314829673, 53.947702761619325, 59.68933882251863, 63.113199280154326, 66.80177657834946, 66.53664788892193, 66.86950806648501, 65.73510369946881, 62.843799129609145, 64.3822233138546, 64.81653559592463, 65.934736651759, 65.28879288704165, 68.05871578954881, 69.27610966467088, 74.727859035615, 72.88294869084513, 81.89908135321834, 38.57933475125221, 0.21862892974768916, 0.5723428173411278, 0.5415294127118203, 0.7653357485128988, 1.0440161655987463, 0.2372233545587909, 0.14430332448213332, 11.709590919556158, 71.65162255687099, 62.24569651388354, 33.42141405228646, 82.37975212835497, 154.9693310645319, 70.7503560281569, 12.670960907013187, 27.514236319449644, 57.06336298296529, 65.90709963152486, 58.050490194751376, 1.0587618259652969, 0.051433748956168854, 0.04255164895326861, 0.022316227419181697, 0.08246466892981723, 0.038335342335725026, 0.037571935719179536, 0.043394280552503564, 0.037130404774460106, 0.015462569276531859, 0.03610170190973628, 0.022922735398394928, 0.020233341605372487, 0.08638457229901707, 0.02530662098809356, 0.015724523466140512, 0.03445716777576074, 0.031562121509904825, 0.013505228994143827, 0.016464334574618166, 0.029905389340954925, 0.0397152160744994, 0.07681012033454834, 0.07249442530014823, 0.08491975090075886, 0.0694786052730295, 0.21656288254645564, 14.705858115226993, 94.94774787656723, 77.35326613149336, 73.77415041769706, 52.26297416994649, 48.099025218717514, 12.503090327785863, 45.887424253648334, 39.326722775736165, 68.50635236309421, 6.51252692745578, 0.15180600656857415, 1.4893917378879364, 2.5787213300504996, 2.1641040040600688, 1.783098326094689, 10.614685800767715, 77.46666969791536, 92.81023656168293, 92.2057600944273, 90.9477226195797, 88.20285581773328, 85.90323294362715, 87.39725589752199, 86.35925554460096, 84.4835389044977, 80.41789239452731, 78.20304762932562, 72.14133047288465, 73.52498577487084, 71.65620388523226, 73.56805339936288, 70.61356729076755, 70.38814867696455, 69.18535386362385, 69.44377530005671, 67.81810191369826, 66.69760627131309, 61.713391657798525, 59.05580935939666, 58.134978048263065, 57.95576103271977, 58.44583372915945, 58.57540530543174, 55.176561724755075, 54.01255130767823, 52.84233570098878, 57.376572085965066, 53.37438168064241, 54.33535060574932, 53.82649760092459, 53.32058245135892, 52.40570137577673, 51.991812875193936, 55.542640455307506, 58.67923828863329, 58.047681777708, 57.04709299149052, 53.12203599560646, 51.834663114240094, 52.359554690699426, 55.20029990903793, 53.01849719016783, 57.24860475909326, 55.514854385006814, 57.90815914830854, 58.039244759467344, 61.484368385807166, 61.40604257583619, 66.83272407900903, 66.78442401270713, 70.53506497413882, 61.81428286337084, 67.65724551293158, 57.833575279481956, 50.45861721038819, 74.75799852801909, 62.64775514602662, 65.04614722344184, 61.36259840380762, 64.2541108592864, 62.03007598077098, 63.78208891037972, 61.338981813000096, 66.02005604774722, 64.63059956027617, 64.23121206222042, 66.0616723952755, 65.40786035599248, 58.704110037895944, 63.82654505391275, 69.47156137035739, 64.81506470711001, 67.53251414145193, 63.96573428184756, 59.914051409690614, 55.495846579151774, 49.748425022248306, 51.6505156793902, 50.34207574782833, 50.259309814822295, 50.21013898234214, 49.7719866998734, 54.16063254879367, 50.14203486904022, 52.46148140199723, 53.737601003339215, 53.804336209451, 52.39655440853488, 53.775824500668435, 52.67776089329874, 53.232972391190074, 58.06134339301818, 62.18901826489357, 66.91161078791465, 69.42128442948865, 68.43991525711553, 69.58030516101469, 68.99734681652438, 65.48253443933302, 64.93771330002816, 67.48172729246079, 67.83975339704945, 69.69162987124535, 70.28098167911654, 71.84177906282487, 76.24601241080993, 76.52484586161953, 83.2456074991534, 48.374858056345296, 0.2843530836605257, 0.5066985817205522, 1.3045912284043528, 2.9337377509763165, 2.6240202928743055, 0.9516642663267352, 0.186212869180787, 10.221934953043538, 75.90774720714938, 69.6523904800415, 38.25134223507297, 58.47059172968711, 117.79593067784464, 56.97100293251776, 23.203067087358047, 39.122967412394864, 64.84718107408094, 70.78080931017476, 70.26748872572377, 2.434605605179264, 0.01702367643555326, 0.08382796069547054, 0.08179726079106331, 0.023874241498208815, 0.03700733657986407, 0.027806260547931158, 0.027549561721483068, 0.03598501905798912, 0.03757120410521184, 0.032866370879233844, 0.019552419675634276, 0.04138862023190145, 0.04708034324369604, 0.1492176406205662, 0.1841230732539008, 0.1544039486156356, 0.10871545306497044, 0.1700046397144756, 0.16364238675563567, 0.19009814537580938, 0.14391412117308186, 0.24005499938803337, 0.18258858381980853, 0.13208842025168482, 0.19541214490609785, 0.39055003033530333, 18.549680863657308, 109.27359304120465, 86.52865486760294, 87.00852547922443, 57.44727280832107, 55.49258708953858, 8.713584561501781, 66.41223030705606, 51.252089162026685, 81.74508910025321, 9.411569353072874, 0.1979260777513827, 2.934186617212911, 3.860014782797906, 8.042153725700995, 3.946299817292921, 15.571847827203813, 78.66998226411881, 99.95986230911748, 95.19124077212427, 96.75818058752246, 92.34792247895273, 89.78798758599066, 89.2114148601409, 90.26234334514987, 86.35074400132703, 83.07204261902841, 81.06306737469089, 77.54578390429097, 79.18607204191147, 76.17107160629766, 75.90443672672396, 73.59580809070219, 73.44993514399376, 72.85103628712316, 73.88010148079165, 72.62881048264043, 69.2379685371153, 64.15483567022508, 62.85719794611778, 60.94776853438347, 61.66707631080382, 61.382143574376265, 61.80184110518425, 58.450626865510024, 55.52746088274064, 56.06981092883695, 61.7907682541878, 56.41235936072565, 56.41375964687717, 56.92847267273934, 57.266875159355905, 55.07121078429684, 55.61389815422797, 60.669566585171616, 59.571248023740715, 61.8102075207618, 61.419849318842736, 56.232820710828236, 55.561256024145315, 56.414155806264574, 59.696579517856726, 55.931390485455914, 61.4896204394679, 58.50226094645839, 61.86470885430614, 60.567698709426395, 64.57263869623985, 66.2677929478307, 69.50346592933901, 70.13841921283354, 73.4796667098999, 66.26391764610045, 70.54143490329866, 60.645855857479965, 55.00811161533479, 76.28749539775234, 66.14970607142295, 66.86030618606075, 65.58257841294812, 67.93643982179704, 66.06329625652683, 67.49519671163252, 66.03875790872883, 71.18084399930893, 69.10113273128387, 66.36537367297758, 69.68852335406889, 68.98396368949645, 61.69727071639031, 68.90765790016421, 73.51515631521903, 67.76016850625315, 70.24289546474334, 68.52831763605919, 62.88233249418197, 60.20688772201539, 52.508204675489864, 54.00322391140846, 54.821979461177705, 54.765767974238244, 53.75005060626615, 52.12147466598019, 57.3829577046056, 51.582678287259995, 56.91374809511247, 55.97865504603232, 57.74239194008612, 56.79910505971601, 56.44163985406199, 57.214566430737904, 54.90829121681952, 60.64200408997075, 65.8533945391255, 69.14613016190069, 73.44982531762892, 74.85223739377915, 73.31136565054618, 71.9440980111399, 69.31626689049506, 68.83546275477256, 71.77157648148076, 72.07459526677286, 71.17239521395776, 73.25887649290024, 76.45591412821125, 80.61048076998803, 79.80046426096271, 87.64980162343672, 48.680579354686124, 0.3657594863926211, 3.2313983334648997, 6.912112014908945, 7.473035464363714, 4.395449199984151, 0.698114903944154, 0.2967940144721539, 14.685482382774355, 86.3113163363549, 73.953473337235, 50.95636206288492, 101.37843455037763, 165.37329243075465, 83.19740941447597, 22.2823554085147, 42.2112298780872, 78.91161595621418, 80.78191188073929, 81.89498639875843, 3.2812639157618246, 0.27404086604233713, 0.15992424030217434, 0.12134818164932153, 0.12533845785524578, 0.14890083262035925, 0.21869101351307285, 0.12541787052947667, 0.18168620885379855, 0.15087427511330576, 0.2214104417831667, 0.15719566494226456, 0.14134838546235717, 0.14134317606447205], [0.05482985119846079, 0.02579191662070732, 0.03736593850678013, 0.02564195490952942, 0.09154972094561785, 0.08138131335257523, 0.07982571819616903, 0.044710419606417424, 0.09051469019463948, 0.07717588135311682, 0.13047142314814753, 0.06951215226323375, 0.1873266690921399, 33.318177269351104, 85.06546174326252, 70.39344387669718, 61.074661131828066, 36.64704968852382, 20.074704270209036, 73.14058565324353, 50.76604866212415, 37.53359163961103, 53.33029423990558, 0.2934277322023146, 0.09980606501020732, 2.865346324059271, 0.4586029689638846, 1.4185487070391256, 0.6179258455672573, 39.19649224127493, 90.61242272776943, 78.33857336351949, 91.10791221741708, 81.86014790688792, 84.36001562303113, 83.6770760628485, 83.82962488359021, 79.10195289119598, 80.96722033716019, 77.21854056081465, 73.21703264790197, 69.2842681946293, 71.42354457609116, 63.43753614733296, 64.40263140586116, 61.14520495937717, 63.06901378016319, 58.283596654092115, 58.468685457783366, 57.55460062334615, 58.0191739912956, 52.82668152163106, 56.81641447928644, 52.560638919953384, 55.46788400219333, 55.246246553236446, 56.61472620502595, 51.02168913810484, 52.41817059055452, 49.025798920662176, 52.779762129629816, 49.49739725359025, 51.987070729655606, 47.84747969719672, 50.56312876362955, 50.23569322401478, 52.093539545612956, 57.0933848042642, 58.62033605575562, 54.59612154191541, 53.87794733047486, 50.54550163207516, 50.0838896536058, 48.27271953705819, 51.47935128981068, 49.47465142896099, 51.1791056202304, 47.40992361499418, 54.17022666623516, 52.70884175454417, 57.9377769654797, 54.699440694624386, 57.86833532394902, 59.566007737190496, 62.419488891478515, 57.73982670999343, 70.43262050997826, 44.97622628365794, 46.597059465223744, 69.31310546013617, 58.913556760357274, 60.30812801853303, 57.40460526558661, 61.43092609220936, 58.06235144215246, 58.602316687184, 58.291653202426055, 62.443701682552216, 65.12031532103016, 59.688758311733125, 58.9546553550228, 61.93212263045773, 58.006826369993156, 56.12734425452448, 58.42351544287897, 60.96331680974653, 59.80757474899293, 59.597351397237475, 59.14536099280081, 56.61816612366707, 49.9635160353876, 47.96768857586769, 48.26399618579496, 47.338116784249586, 45.97225727573518, 49.52305347688737, 50.6095225580277, 49.59452690616731, 47.70410137791788, 49.059154756607555, 50.76040044907601, 47.4898575967358, 48.347989820664935, 48.96905006900911, 50.0978454466789, 52.98494523571384, 56.357477557274606, 57.39649380407026, 62.936916197499926, 57.12019812676215, 58.468901188142844, 57.12040209001111, 58.51993122408467, 56.6248498424407, 59.021500387499415, 57.54084487115183, 63.137145350056315, 61.57532030536283, 65.33294700807141, 65.72130087883242, 72.72046058408677, 70.14057651642831, 81.67826760199763, 33.448858876382154, 0.09202811221081404, 1.2168685226671159, 1.436925256444562, 1.3280333963132676, 0.5655045939549324, 0.07657674697017477, 0.478464717706365, 39.75215088936591, 86.61272694987636, 45.664092340777, 67.42595118861045, 116.9100006165043, 135.26571243040024, 50.25723880337131, 10.886748260067357, 55.72860394754718, 51.32214661567442, 74.69296563056209, 11.622479980991734, 0.4358603312603889, 0.20832970498069642, 0.11314738662012162, 0.06542284387133776, 0.04030872354163759, 0.04670802451249573, 0.09895442804742245, 0.03341865898560613, 0.03361880711670365, 0.014048624734935022, 0.04307504788401627, 0.024597913049341693, 0.06412604470707237, 0.05193827914134149, 0.0340920924058845, 0.07488469623269574, 0.05473051257731934, 0.05955781644931244, 0.09981843733018446, 0.06530617634134908, 0.034681466828671195, 0.04210099007093138, 0.04555445697699343, 0.09132981540695315, 0.17098939977586272, 0.25717133415802834, 46.6577346094193, 96.22752312690982, 76.84992405676073, 70.41196530865085, 52.43778636378627, 29.905770132618567, 52.39280854502032, 46.57726718533424, 46.74883165667134, 55.19163147095711, 0.13992531585597223, 0.3664724384584735, 3.694409127196958, 2.5420579554573184, 0.4189075102969524, 1.9021846714519688, 51.1834986748234, 93.02448426523517, 83.72816885671308, 92.42141985124158, 85.96019360326952, 87.70034528547718, 86.29930603888728, 85.91444307757963, 83.27604509169056, 84.856807339576, 78.97158899614888, 75.9441311128678, 74.08629263600996, 73.77116941636609, 66.14813712335402, 66.32124700853902, 62.93485303078929, 64.84592199325562, 60.41934290239888, 62.257130222935835, 60.43757800132998, 59.328661195693485, 54.95108427539949, 57.730742500674346, 55.69407924529045, 58.423209498005534, 57.659374975389056, 59.68609110001595, 52.99086016993369, 54.06464430593676, 53.10402839414535, 55.28233235882175, 53.440406937753, 54.254667451304776, 50.8573849739567, 53.873303244190836, 53.175513590535815, 54.75395379527923, 60.27267371454547, 59.50203387968002, 56.290714894571614, 59.39390590113979, 51.2779297367219, 52.95864574370846, 51.6326924293272, 53.26585754271477, 50.913086552773755, 51.96627824537216, 52.06905611099736, 55.78119508681759, 56.93443075303109, 61.687625608136585, 56.460545678292554, 61.05498652304373, 62.276722461946555, 63.9703901352421, 60.47336570678219, 71.70220544261318, 50.578202432201756, 50.168385351857836, 72.42309001184279, 60.15217458048175, 62.45696321610482, 59.274179474000015, 64.03571328809186, 61.13099421224287, 62.579301941779356, 62.3341263494184, 66.5113172223491, 65.1128706624431, 61.15220246776458, 61.735333396542465, 64.02749200021067, 60.293415208016675, 60.0823603137847, 59.68788754555487, 65.1855129580344, 62.99330026872697, 62.15359141749721, 61.617956469135905, 58.21972085583595, 52.418229426107104, 49.76048631052817, 52.16142400618523, 50.13980696278234, 46.86109773574337, 50.03220850421537, 51.4896200549218, 51.390666500214614, 50.20718935997256, 51.29385063725134, 53.76814842224122, 51.91011774924494, 50.983473485515965, 51.43128656571912, 53.91110704791162, 56.37384168563351, 59.87422366296092, 59.61566886594219, 64.17773054492089, 58.43600426950763, 61.543807983398445, 61.866069916755926, 59.9110076504369, 60.60757744696833, 61.662275329712905, 62.45533543248331, 64.0777022607865, 64.98960233503773, 67.52371234278526, 69.24090247000419, 75.73462947722405, 72.65294874868086, 84.40055724113219, 44.79317319008612, 0.3061695517070832, 0.30224846856247994, 1.2285665014097769, 4.457369696709418, 1.057951366228442, 0.004940685842396511, 0.2858330123126507, 39.94636312607796, 93.40996696103005, 56.12529285492436, 66.38581706631568, 112.75083695688556, 118.08168318963821, 53.39342086545883, 19.10858331188079, 62.51224510131344, 57.828299691600186, 83.91252809955229, 18.856084654408118, 0.5772241457335411, 0.19165748670216531, 0.018646024663241643, 0.06054611966734933, 0.03058030514136678, 0.04439926916553129, 0.05723170538042342, 0.07914418339609139, 0.028709773154508685, 0.031904884568986394, 0.01774288360930739, 0.032891732219967156, 0.023822337126119003, 0.11510326271696437, 0.1358236657876161, 0.12394512778208142, 0.14415743069783335, 0.16014208506432273, 0.20814926063101138, 0.22133856741411073, 0.09277418225763306, 0.1403948051794883, 0.22996410457116945, 0.26412198860799113, 0.28481527982700255, 0.2702164325502611, 57.399533640953806, 110.74634890402518, 87.55886539336174, 83.31202107091104, 54.636565100762155, 30.18531941598462, 92.96740593448763, 70.24451932599469, 54.60046360569616, 65.3680012303014, 0.4344533648221724, 0.5077382549643517, 6.316752116526327, 6.968061193343132, 4.775397921762159, 7.171901868235681, 53.295051743907315, 100.46009786667364, 88.98542358029275, 93.94530773162843, 89.94610617237707, 90.50895844736408, 90.46754606308477, 89.63181449520974, 86.52593274270335, 86.21734419176656, 82.86222719377088, 79.28508835454141, 76.55550310688635, 77.61574329868441, 70.79853057861328, 71.44424684586065, 68.1322680750201, 69.27135575202205, 64.29180875901254, 66.51516114511799, 66.22597263705346, 62.63486231527021, 58.50346119173112, 60.76952818901309, 58.367747183768984, 60.56740845403364, 61.1439105772203, 64.01057481765747, 56.21641735876761, 56.6329691486974, 55.553874123481016, 59.39244677943569, 58.146121501922615, 58.01117235614408, 54.14539021830405, 56.47997710012621, 55.328078962141475, 59.258454691979196, 63.340488864529526, 62.534963469351496, 60.17393981256793, 64.36206233116889, 55.038357011733524, 54.78814901844148, 54.97619921161283, 56.564751286660474, 53.950024804761334, 56.69456997225362, 54.54627213939544, 58.91320766941194, 60.13063684586556, 63.39424102537094, 60.23153589617822, 64.82221518793415, 66.09102741364511, 68.71913310020201, 64.81469992668399, 72.82776094252064, 55.62353934011152, 55.455038239878995, 74.42435387642153, 66.71802613043016, 65.98611970101634, 63.881826939121375, 67.09455013275146, 63.18371957348239, 64.2625988683393, 62.44938127456173, 70.63483438184186, 70.67249698023643, 63.246234309288766, 65.164175264297, 66.78736579033637, 64.57281912526777, 61.68266773223878, 64.56040090130222, 67.51549105490407, 65.85791310956402, 65.16705820637365, 64.1954675028401, 62.13829809619535, 57.01287031173707, 53.28073117040819, 55.40377286172683, 53.91436653752481, 49.87265825271607, 55.44605208981422, 57.713040844086684, 54.50664443354453, 53.49925817981843, 52.87471094439107, 56.414559810392326, 53.77702474594117, 53.74220194355134, 53.85711170011952, 57.62116324517035, 58.86497820577314, 63.81050648227815, 63.453111879287235, 69.226899608489, 62.590480696770456, 65.12141750704858, 65.75579812449794, 64.42815426857241, 64.07338373122677, 66.0425155393539, 66.50667313606509, 66.59138848704677, 68.67315507704213, 70.28502172039401, 72.5709633673391, 79.99715543562367, 76.36162819400911, 87.35980510711671, 42.88381438101492, 0.33510677636631075, 5.2630720888414695, 7.189679520745432, 7.229031680091736, 2.251516719979625, 0.15163694628544394, 0.6778634003093166, 50.91514579711422, 101.4585058150753, 63.55212426954701, 77.044050001329, 116.97929320796844, 137.53395634312784, 66.02505314734675, 20.89684286425191, 76.20642000629057, 66.22798089058169, 97.94848657423451, 20.894536510590587, 0.7925529525645318, 0.31350772407266403, 0.15142155300465324, 0.20624862713438852, 0.17089141713034722, 0.14078267549555148, 0.15203782477446143, 0.2017253222725084, 0.1507001586498753, 0.11284427627200082, 0.09928794442525796, 0.1079682875124197, 0.093141567382601], [0.0355099679361428, 0.005031695172581221, 0.0275844493655548, 0.04262096458865751, 0.052425384656676365, 0.07888432637217545, 0.027930830274858785, 0.015226447571729942, 0.03404104413705007, 0.0559288885955128, 0.0579936411081543, 0.1473243768897749, 1.263851040313321, 67.8808912154167, 67.85500357227941, 72.99804672118157, 45.25499305417461, 20.16907649655496, 30.181095023309034, 77.34176574214813, 41.61173482095042, 69.73127718894713, 33.75834565008841, 0.160755077977815, 1.106934660384732, 0.8888910218111931, 3.381197817863957, 0.8384843362915901, 10.605218179764288, 75.30729509169056, 87.63728926258703, 85.3652092718309, 85.49491420868905, 83.50385635129868, 81.17964021621212, 81.53539134610085, 82.738719601785, 82.06221272868495, 86.00976451750725, 80.02327057623094, 80.40277557988321, 73.00523250333725, 68.21003298605642, 64.0602869372214, 62.09686610006518, 60.9878041667323, 59.617461389110936, 54.28580322573262, 50.08737271831882, 53.581263173011045, 56.380458724114206, 52.19649391789591, 54.88340770044635, 53.443666427366196, 55.894802616488555, 53.52056841696463, 56.10344525306456, 52.27632199564288, 51.12146639054822, 49.98324947972452, 48.772339282497285, 47.803121612918, 49.20063464872299, 47.607928783662864, 52.86305366023895, 50.855396332279334, 52.24164824331961, 56.99648264915713, 58.52939590331047, 56.22239897328039, 55.49303423973822, 51.411741395150464, 52.3412529114754, 47.825251625430205, 54.185853389001664, 49.021911851821415, 53.04893870507517, 45.4613999397524, 54.40610624128773, 53.32896847878733, 55.91989401848086, 53.7255044137278, 54.79681353415213, 54.15556876890121, 63.69950732877178, 56.003534640035326, 75.46763373959449, 28.513060039089574, 28.874830046007713, 74.67754287104454, 52.02302317465506, 61.533805939459036, 53.5592233750128, 62.616721353223255, 56.95571745595625, 58.307805522795654, 59.11423698548348, 66.7301933227047, 60.874667321482015, 65.75479007536366, 58.95503582492952, 63.12692365338726, 57.5878740895179, 60.34236638776718, 54.15765546983289, 58.23974455556562, 59.12452536244547, 59.81803178787232, 57.20265419252458, 54.52768402714884, 52.151857345334946, 49.75239446086269, 45.77553079974267, 46.20819176397016, 43.38602681313792, 47.68618399097074, 47.11966037750245, 50.83880078408026, 45.08415814368956, 45.93379843619562, 49.39766706958894, 52.17072786823396, 48.662442315009336, 50.67140186986616, 48.93965582693777, 51.50931035318683, 52.488734029954486, 55.7403749804343, 50.55580177614766, 55.60974044184531, 53.63595670269382, 53.64064393504974, 51.04925555567588, 57.00850471373528, 55.68931748790126, 58.29326529656687, 58.91348615769417, 64.09768281444427, 59.787986432352376, 62.719965980898955, 62.21574529524773, 71.9869302934216, 66.31337873397335, 83.7459764172954, 29.921942064839026, 0.10697036606049347, 1.878195332904016, 2.728090334323145, 1.800021024480943, 0.18125100962577329, 0.14921874378717717, 9.198485612869263, 68.93885643251481, 62.29032916407432, 40.67530816601169, 74.37234324793663, 75.49305069831111, 18.888473626106016, 24.13585770514704, 40.27585006529286, 59.53630755024572, 66.73773996291622, 39.351347415677964, 0.718259339130694, 0.17096087066156251, 0.027543028906708764, 0.05561340975785448, 0.05304967736705177, 0.17137108010149774, 0.030464074281494946, 0.041700264799498746, 0.14508375357235634, 0.022375354085177667, 0.03547622942395749, 0.04139270348053786, 0.1388339163555253, 0.020329520113826282, 0.03469707970056803, 0.04174418845063737, 0.004649311482470724, 0.038229338749642336, 0.03662459522245392, 0.09132348752069859, 0.020191463408991694, 0.015078774548225827, 0.08452019008297114, 0.013065067431589049, 0.1612459105109015, 2.2096387993904854, 85.44924213040261, 76.50397100756246, 82.48915487720122, 55.56285242880545, 31.905025743669082, 28.263332536143643, 59.338486732975134, 47.15176497736285, 79.04725936151321, 35.51245312536917, 0.49127389166143637, 1.6898972949674054, 1.898932536282847, 4.183153856185175, 2.0925616881539746, 17.05985680703194, 86.99666423182335, 88.3412213479319, 91.02777035005631, 85.75697560464182, 88.68168307888894, 82.93387320733841, 86.30912765379875, 85.48189193971696, 86.89101911360218, 86.64445107983005, 84.99237229747158, 81.90499628743818, 76.86830428338821, 70.1167755742227, 67.55983737207228, 66.95308593011671, 65.36652641911661, 60.734446510191894, 59.55139298592845, 55.3878088151255, 57.25301350316694, 57.01734181373351, 56.59614985988986, 57.02845388843168, 56.45223025352725, 58.55981780636696, 57.22723176402431, 56.43277529747256, 54.41072287098054, 54.05946285493913, 52.00947530807988, 53.77028611398513, 53.70717910028274, 52.08187441672049, 51.527157137470866, 52.656234925793065, 53.305089089178274, 54.87324091695971, 59.2212902345965, 61.02803199521957, 59.29383839330366, 59.30282454336844, 54.49460667948569, 55.54390345850299, 50.74236146865353, 54.07843535946262, 53.87864551236553, 55.618004875798384, 48.48702999853319, 55.07618434967534, 55.9710652597489, 59.92778362766389, 57.458957549064394, 56.81647331483903, 57.649521981516195, 65.50728851749052, 62.29833864396619, 72.83515853266563, 50.72990794335642, 49.017365824791696, 69.93062773058492, 58.631350071199485, 63.76910978747953, 57.5847440381204, 62.09385371977284, 59.38253102764007, 59.36710434575235, 63.868934108364975, 68.40790087176909, 63.54472275703185, 67.81836863486998, 64.77095373215215, 64.13587885518228, 62.31864867671844, 61.70336215726791, 54.13849469154112, 59.25472451794533, 61.40010802976547, 62.113296908717004, 60.18809172414965, 57.61244381627729, 55.32865947292697, 53.27396508186094, 47.432194832832586, 50.03730758543938, 45.74924699721798, 48.762407841220984, 50.892800054242535, 52.20732358194167, 49.191526905182876, 49.42658670486943, 53.540007683538626, 54.138035774230964, 51.069777396417436, 54.048091903809585, 51.35300782419021, 53.933170380130896, 53.98904062086537, 55.970716168803555, 53.320398099960826, 57.4808757535873, 55.27298535070112, 57.02950116126769, 53.30252385908558, 59.254497020475334, 58.939279663947325, 62.303445569930545, 60.97262459416544, 65.9414674389747, 62.05245702497421, 65.41909010179582, 68.33023009761688, 72.95545762585056, 70.92290109203708, 85.72395709253128, 38.82180783056444, 0.8509438677180199, 0.5736712750888641, 1.527069045170661, 2.001377245591533, 0.6476215585585564, 0.1595859052312951, 7.54165634993584, 74.41249262902045, 71.27598501020863, 49.36230298011534, 71.50551426795222, 81.49301405875914, 26.44688487052918, 32.542387362449404, 51.37989174935126, 65.07860483661776, 72.16500589924475, 51.26407592527328, 0.8134838229706212, 0.10220126188810795, 0.02177416084093913, 0.016763798344219406, 0.07854412970764023, 0.07753205095087329, 0.05371871344264477, 0.040361710012920445, 0.10144285016482878, 0.02264282602306095, 0.035948131924435016, 0.021732600571046916, 0.07122451199158546, 0.15858665078638062, 0.10067783476364228, 0.13987916671941358, 0.11413989949130243, 0.17180960415111435, 0.1750626739475035, 0.14331556135608306, 0.11204881653670343, 0.07990523812270935, 0.27732677036716097, 0.2537019058100639, 0.5285615666258721, 3.4943966855925903, 99.3019082469325, 88.1168931530368, 91.82217582579582, 66.2550687789917, 31.96419469771847, 43.714372342632664, 100.40988368372764, 59.49841745438115, 90.60102432004868, 42.817400809257265, 0.5263098197117929, 2.188573955528198, 3.3333892735742756, 7.504264885379423, 4.400149180043129, 18.81012232072892, 93.05632606629403, 91.04378146509971, 98.27138393155991, 89.00363906737297, 93.59547153595956, 87.74406402341782, 92.46506014177876, 86.82776697220342, 89.3892708132344, 89.99559863921135, 87.5943785329019, 82.56788469129994, 80.56968812019595, 72.70553988795128, 69.98547031033424, 67.42643756251182, 70.17900789937666, 64.63373745641401, 63.086923322369984, 58.149314311242875, 61.202542166556086, 59.403488251470755, 60.207123064225726, 61.074182602667044, 58.339451205345895, 61.255615757357695, 60.42938024766984, 59.450482168505275, 57.74169768056562, 57.59199650056901, 55.44001163974885, 56.92019254930558, 56.73189524681338, 56.72693737091557, 55.46176510472452, 57.597742772871456, 58.36551927751111, 56.74152858795659, 63.25285527013964, 64.87972890177082, 62.81289477502147, 61.66864918124292, 57.47869883814166, 58.80522089619791, 54.473739670168975, 59.37199554135723, 56.99159145355225, 57.13507567682574, 52.20240885211576, 58.207098668621434, 62.64699812858336, 62.498022587068625, 60.950129801227206, 60.38814829241846, 62.60746063724641, 67.13022016709851, 64.72667801764705, 75.08097433274793, 53.144726907053304, 48.93883997394193, 74.74324257143083, 62.40073603968467, 67.64007337631719, 60.3476341309086, 66.34016067750993, 63.394029217381636, 63.49835249685473, 67.0694391189083, 71.8648269099574, 65.95367385495094, 71.17617637880387, 66.54446909504553, 66.06679501072054, 64.84614949072561, 64.80341919006841, 58.33117500428231, 63.795660311175936, 65.22530148106237, 64.85604955304053, 62.912169964082786, 60.407995485490375, 58.89667487913563, 56.509908706911155, 49.27306513632498, 51.878691719424346, 49.344691538041644, 51.000123946897446, 51.68633476380379, 57.16421496483588, 51.635516535851266, 51.18462439506285, 55.89390439371909, 57.34584031566497, 54.10884157303841, 58.65380956280617, 55.24544246735112, 58.08601510140204, 59.64160749989172, 59.37689065933228, 55.55245422547864, 61.838221088532485, 58.937479296038234, 58.785299178092714, 57.59013337473716, 62.24297046661378, 63.79683702222763, 64.6578678777141, 64.95249671320762, 70.11300225411692, 66.22777692733273, 68.86068359498056, 72.37038904620756, 75.15558565816572, 73.8394735705468, 91.40958170736991, 37.771754034103886, 1.0214504022752087, 5.94667011691678, 9.11156588985074, 7.345672672794712, 0.7347821396204733, 0.2041762673686589, 11.343961300388461, 86.54781956826487, 76.76923305757585, 59.20609889491912, 78.45411854405558, 84.83547749057894, 26.507128554005778, 36.53097498801447, 59.804731030617994, 75.49105028952323, 84.63249483416158, 58.1035049500004, 1.0499878516120296, 0.2676861667104306, 0.1637491640905219, 0.1676044556041879, 0.21538765770533394, 0.20353509774131162, 0.06701910297476477, 0.15490700791199363, 0.35439524619329366, 0.13200493198969673, 0.09944474730159968, 0.09151164637578112, 0.15416425502588674], [0.044463647364248196, 0.030118266022914363, 0.10395321304038649, 0.019934661160673828, 0.051076418735207095, 0.039425661652198726, 0.0503050486346887, 0.10953015692892576, 0.04136203698092892, 0.12040669789477704, 0.05379101682093836, 0.5203551714939456, 16.170329932243593, 77.58120290694698, 67.3751094264369, 67.07500103981265, 52.15223781524166, 24.215507315051173, 42.024564281586684, 49.33071221074751, 36.33362093279439, 83.83676359730383, 8.817500895069493, 0.1216800126337236, 1.0637356364919295, 3.4248640941035364, 1.3347250824013066, 0.5065168963084298, 44.59118289332236, 85.23118972778322, 80.18244820256388, 78.44338693926412, 80.11303793999457, 86.94042528829267, 85.01920915419056, 82.28177132145052, 82.75248712108981, 86.2542615398284, 83.9407770095333, 79.29773407597696, 76.88250326341199, 70.74695925558768, 65.01474865021245, 65.07738890186434, 60.0455214131263, 55.95783510515767, 54.54132210823798, 50.75681932510869, 45.99973347879226, 55.21566775537307, 57.1637442804152, 53.19431351077173, 53.36553673590384, 54.87329583014212, 54.5107433103746, 55.35752811739522, 55.095337283226755, 50.82626488900954, 52.55547708080661, 49.149973315577355, 49.866845300120694, 46.20281811683409, 49.891281666294226, 47.25141279159054, 48.21393497528569, 48.490156127560525, 52.76273119834162, 54.63278001354587, 60.648636817932136, 56.459525862047755, 56.79789304733277, 51.017096042633064, 53.03325314675608, 51.03673142771567, 56.703811076379594, 52.95164039058071, 58.11346777023808, 46.86226267968455, 53.76348080173616, 52.42991024448026, 57.89853365190568, 48.90298558819679, 58.2482482540992, 49.250115348446755, 68.45007419586182, 47.53543161576795, 84.09418875171293, 8.343368711010102, 7.412761872814548, 86.70515368061682, 47.77184855553412, 64.57995391661122, 49.342071394766535, 65.87623842300908, 51.561552401511904, 64.31236982345581, 59.46053520325692, 66.93525483531337, 60.75874559340939, 60.137971678087794, 56.37186088869649, 62.10025895026423, 56.00351502818447, 60.61294324936406, 48.81411644720262, 51.91704857733942, 49.423225233631754, 55.685787354746175, 53.38707447052003, 54.9285267245385, 47.4390079898219, 47.37644226320329, 43.810497868445616, 46.97040634770548, 45.0456287014869, 46.19197668567781, 44.71238413164693, 49.258226809963105, 45.899830710503366, 44.30419875729469, 47.8494801059846, 51.945764249370946, 47.336084996500325, 49.201980021692094, 46.254522800445564, 48.21121677275627, 51.18497348600819, 52.28897948418894, 51.86842295431322, 51.31823601261262, 52.278938216547814, 51.78189546831193, 54.51152778440907, 60.32039719243204, 61.41748805199901, 63.86347809145528, 61.62824484609789, 65.10577901717156, 62.561047230997396, 63.4903077156313, 63.18291548759707, 67.20441572127804, 68.15925398180562, 72.3848782816241, 73.31615878689674, 23.41295115409359, 0.10569661465143004, 2.1684936265791617, 1.0910083665963144, 0.47178516645104657, 0.18869870192100927, 0.2904287124833753, 42.89621299312961, 75.41197530684933, 50.83495293894122, 34.870023804326216, 36.017713239116055, 24.822552934769664, 18.348382865228963, 29.574004296333563, 59.87548274378623, 54.034061585703206, 59.18767159984958, 6.704630399903944, 0.1918970577178463, 0.14398619472499818, 0.038700532618789904, 0.04563344447242637, 0.15327240610795637, 0.04541813163086773, 0.06226643904923432, 0.05287722714485661, 0.03416086794928678, 0.05296239313939887, 0.030677939216876705, 0.07173269641615691, 0.029725088632755706, 0.06422149160155846, 0.043266956739488154, 0.0455886704636918, 0.1420276449812997, 0.13340489638428535, 0.029169962170623967, 0.02290072377711054, 0.08090220196473022, 0.016259201126353397, 0.0843579096779708, 0.5612118049494682, 21.843724596884943, 91.71182386336788, 76.3157678419544, 77.87942071114817, 67.09535814100697, 34.0342334008986, 39.18783557030463, 45.79069468282884, 43.142518228100194, 91.5492965329078, 8.335633797030296, 0.05468402253163438, 1.3539326839870023, 5.3099032275138365, 1.6014412285820132, 3.5233778530551545, 55.32675320102323, 86.79129677434122, 86.06669379818825, 81.45308433040496, 82.66981924733808, 87.62843255073794, 89.62414233915268, 86.27053153130316, 87.97494257650068, 89.50921689310383, 88.87637384476201, 83.02712363581504, 80.05782665744906, 75.89431701167938, 69.75854550638508, 68.91561246687367, 62.55538725083875, 59.35004988024312, 59.57726886195522, 56.83765803613971, 51.63608135715608, 58.068372280366965, 60.0538956734442, 56.333625624256754, 56.588548306495916, 56.22358352907243, 56.41102967723724, 57.76119970506238, 57.3707865899609, 53.39091447091872, 54.05250849262361, 51.79585910612538, 51.63333177566529, 49.97957814124323, 50.13668475612518, 47.758896889225134, 51.25535649638022, 50.400134671118956, 55.1750712240896, 59.315454575323294, 63.63366250068911, 59.195484961232836, 59.00882328710249, 53.129821900398504, 55.92200425363357, 53.17796114952334, 60.593001919408, 56.75516274667556, 58.94888162612916, 48.80495771285027, 55.502318489936094, 56.05794183669552, 59.73839982863396, 55.04845319255706, 60.903583034392334, 54.61327014430877, 69.05979879440801, 53.35772337452058, 83.88181594110306, 25.773731623926473, 22.793963878385483, 84.23213066593294, 52.16953939007175, 64.6635357026131, 56.451026085884344, 66.64085741966002, 56.40971960559968, 62.4518366782896, 60.998410255678245, 65.67174173170521, 64.1479048421306, 61.192324392257206, 61.392306435492735, 63.76643473102201, 58.497130486273, 64.09326622563025, 50.63312345935453, 52.396585787496264, 51.702055623454434, 56.434493295608036, 54.66969343923754, 55.32143838943974, 50.42226468363116, 51.96860813325452, 45.23858185737364, 49.94335113033172, 47.22050843700286, 47.07287826845723, 46.058392524719245, 52.3142199362478, 50.24840954811343, 48.15142416184949, 52.337499203220496, 52.63379504603725, 51.98732568371681, 51.34415895708146, 50.823319189010135, 51.9666979389806, 53.11893732317033, 53.70382547378541, 54.85630020018547, 52.98030507179999, 57.729961949010054, 56.03417227345129, 59.106988445405044, 63.79777446869881, 63.07627408735214, 65.1072891296879, 64.48619358001217, 66.34234936006608, 65.77047563368275, 64.48221237428727, 66.34264746019917, 68.43472203900738, 73.31327976719027, 73.7962333617672, 79.46877294971098, 31.817209759066184, 1.1999399407256035, 0.8539075248183743, 1.747636054792712, 1.8302339387516824, 0.321561238698421, 0.06774618936282012, 45.23096853686918, 81.95899163523029, 60.31648658937024, 40.52560306364491, 38.84258854773737, 20.957480745930827, 22.534183340687907, 40.39212088431082, 65.95934560222011, 62.22654750270229, 72.00893479008829, 11.37385662524931, 0.22893462029676284, 0.13591538183391094, 0.028718791924597278, 0.08418383151893655, 0.046896608546376235, 0.014075002099777904, 0.07590513300871657, 0.014394625473106581, 0.02788435746615212, 0.023950882849373648, 0.03803181446968548, 0.04679283810659282, 0.10981493479301853, 0.1764128273052554, 0.22269766867881824, 0.16203674307513624, 0.21000264182446465, 0.1462820223382404, 0.08249957955652669, 0.17129960409816236, 0.19644757402279686, 0.3234842113189159, 0.18907661309405682, 0.8375888714386571, 28.67093151615512, 105.90939183388988, 87.61704198775753, 88.34862678281723, 70.74481764147359, 36.230156652389034, 57.09507926817864, 70.7787069197624, 52.47468802236742, 104.30617793913811, 11.375676605009264, 0.25490466385118427, 3.014066911512806, 9.570135089658923, 7.796282893226993, 6.416606835780605, 57.95296438278691, 91.8996661709201, 92.89555595767115, 82.18778348738148, 86.58767084921561, 94.0907492176179, 90.12014958166307, 88.14877417779739, 88.23304237857943, 92.74804346023068, 91.2388252442883, 85.99912704959993, 85.14348553073022, 81.43733993653329, 72.65575716572424, 73.9559679646646, 67.70944441518476, 61.52299588726413, 61.5856949744686, 59.40661830286826, 52.4659764382147, 61.28286446294477, 65.69357364408432, 59.450293894737, 59.777345042074884, 58.98548518457721, 59.4012721123234, 62.12487574546569, 60.21335178805936, 57.239398956298835, 58.75014689660842, 53.6140267310604, 54.87304872082126, 51.5543979983176, 53.59781557513822, 50.780388847474136, 53.970966339111335, 53.03847774382561, 59.30269510515275, 62.30772487578854, 68.09471530299034, 63.82831796523064, 62.55224150996055, 55.08229148003363, 59.66045841093987, 54.67324710661366, 63.890099217814786, 58.98881135448333, 63.544106944914795, 49.7147475519488, 58.05806821392429, 58.95728726540843, 62.549370334994414, 58.34603686486521, 65.41395964161043, 57.702681864461596, 74.51830248678885, 54.74474014774446, 89.57410858523461, 18.263614562249955, 17.21190944794686, 91.36731424639302, 52.849384200188425, 69.24141237812658, 58.21170745357391, 70.81409454345703, 58.4259630018665, 68.57077337080433, 63.53766249072168, 70.32254311346239, 68.00439880740258, 63.980662822723396, 62.74208030393047, 68.5701536363171, 61.23077538705642, 68.78021224852532, 54.46133713568411, 57.003570372058505, 53.815754229022616, 60.622933526192945, 57.914285890517704, 60.902425935191495, 54.41518652823664, 54.05022175081315, 49.24429455111104, 53.746744048210886, 50.41341189415225, 51.303574192908506, 48.3012390905811, 55.77181669973559, 53.011134901354396, 49.94692048718853, 54.734530218185924, 55.708035038363555, 53.86190483647009, 55.38754601632395, 54.77649565665953, 54.53415201556299, 58.09029048488986, 58.15480562948412, 57.72000305114254, 55.16938770970991, 60.2438795951105, 58.20781646236297, 62.613603068936264, 66.95789475594798, 67.33083371193179, 69.34006783270067, 67.53211405969435, 70.7546627906061, 68.07585654720184, 67.51676974758026, 69.79323494818904, 72.24790127046647, 76.84445627274053, 76.87969484636861, 82.6196756670552, 31.45394729029748, 0.9774637174221777, 9.460319511352047, 4.441937131266441, 2.1814367127033973, 0.4558469523345271, 0.2964473750081755, 58.60003386774371, 86.81415634770548, 65.72872200319844, 48.28876203106296, 49.25383375537012, 33.696313365813225, 27.9892941828697, 43.75991498270343, 76.86022420083323, 71.91766908091884, 84.42662531329741, 13.935361446872836, 0.292963053910963, 0.26751827088094526, 0.21503318882276937, 0.21122188607771553, 0.2433302091254342, 0.17262312823966627, 0.25288289653197416, 0.2153996086769527, 0.14977656304836273, 0.13512867082270885, 0.11405667936008786, 0.1600339287711728], [0.07561501551179156, 0.07525712221620545, 0.021213395971684687, 0.05105517128662718, 0.016367411045658014, 0.037431733968156966, 0.004606960226796688, 0.033258324443933465, 0.06111782044172288, 0.05747963058491869, 0.08460275903945008, 0.025154994950900157, 46.302395328398674, 81.1525837067635, 68.0906831064532, 53.3552130576103, 24.033107296113048, 22.30443246902958, 47.72162652784779, 30.607213474089104, 62.44666699440249, 72.9568696791126, 2.1058246925953896, 0.1222667363922923, 1.3654719293117525, 1.9123811178630399, 1.032683947874654, 11.98532569792963, 80.39643702968475, 78.3552905051939, 85.57098465581095, 86.29341463888846, 84.3843892312819, 82.44404762021958, 79.64655045540103, 77.33558408675655, 73.53013192453693, 78.20212194996496, 78.675426513918, 77.34388382204118, 75.61053352971231, 68.86698292147729, 64.21893504358107, 62.78872513001966, 60.11459435186079, 57.803161221165816, 55.841101446459376, 50.02135530594857, 48.16407380565521, 51.7052915788466, 56.771142482757575, 53.323061389307824, 53.78048819880332, 53.63215984836702, 54.10293840592908, 52.9200456988427, 54.458909188547445, 50.65328836441041, 53.728846273114605, 51.64767196101528, 50.785440860256074, 46.38953862651702, 49.50794842935378, 46.64236676308417, 50.31223043318718, 47.227494178279755, 52.55861889931464, 52.332811970864576, 58.90114638113207, 55.540859699249275, 58.77940385572372, 51.918629292518865, 58.51252186682917, 53.253062771212676, 60.462445828222464, 54.94387495902277, 60.466611385345466, 51.67806248511038, 55.01078274942214, 55.9038358349954, 60.33107388404108, 50.6546768834514, 60.21535611921742, 50.67074291167721, 67.50200594625166, 50.57866134951192, 79.0170963348881, 4.208697801636112, 3.640759928572563, 86.29354799947431, 45.81680197869578, 61.691100828109256, 49.6405755319903, 62.626958739372995, 51.2777179287326, 61.840041068292436, 58.175947204712905, 65.24997318944624, 58.836533177283506, 56.93306184584095, 50.1143939264359, 52.765127766516905, 45.749505873649355, 51.606494918946304, 45.554877865699034, 49.74795433782762, 46.03731370741322, 46.08083240447506, 44.072374913000296, 48.94133460137152, 44.33210642107072, 44.165476291410386, 42.96397978259672, 46.34377633371661, 43.60711120790051, 44.943925565288914, 45.6501090911127, 51.89316134299002, 46.337492696700565, 42.755090036699855, 46.63334923405802, 52.05924626319639, 48.393367721188454, 48.576675768821474, 45.7582135354319, 46.731122155343336, 49.8589103452621, 52.64773907199983, 52.03808507611675, 53.59772928299443, 55.76274033515684, 57.126905379756806, 59.18929546110092, 61.52345872694447, 65.00834734209123, 64.34268974488782, 67.2279420975716, 66.91005752932641, 66.17138893373551, 62.8421478117666, 65.12893669066891, 64.33729256353071, 64.48143966736333, 71.14998279079315, 76.53942138917985, 74.09048172735399, 21.529585892154326, 0.3985702967451465, 0.4626039397572318, 1.7148555815219881, 0.27866745487816874, 0.2920890395199099, 10.911873002206127, 70.02204248982092, 71.50987594358384, 52.601662989585634, 36.07211651340608, 34.786002712865034, 23.705907098708614, 22.440870154288508, 35.92312528241065, 60.13581045212285, 54.04234563150714, 34.69678448092553, 0.3148670704855073, 0.10367086367501367, 0.09916796739543639, 0.14165705760880826, 0.07451652969804502, 0.034527215025117325, 0.007030059463314473, 0.1146792100682374, 0.05190217341747015, 0.03881381787059288, 0.0055011222514534195, 0.0679397261551311, 0.03284241147940198, 0.11130565762399666, 0.07204080165754403, 0.0778862746853021, 0.04406438149031132, 0.14060469794898264, 0.022340393662753127, 0.05084223714807341, 0.03594938447819122, 0.06669008353304479, 0.03091787220910192, 0.10153996713098981, 61.63044529576456, 91.28958855905842, 77.5127261684787, 58.98128824849283, 37.0807461584768, 28.004057984198294, 35.249179717033144, 35.95921108799596, 69.0104789118613, 79.01296215672647, 1.3143187064316966, 0.3867895805066632, 2.750169110874976, 4.03763686456988, 0.7468426924559378, 18.367649547515377, 82.56522532432311, 82.76319519166024, 92.66080994759837, 88.4501612570978, 87.92221807664441, 86.70206285292103, 82.6806999021961, 80.15817657593759, 78.73332854240172, 81.40284661323794, 80.85950420748803, 79.5295383084205, 76.1899225173458, 71.58305952625891, 68.15983449259113, 64.58831640981859, 63.676730125181145, 60.79801244120444, 59.28886482792517, 54.41339008269772, 50.81381136371244, 56.82206269233458, 59.67981530774025, 55.39829723296627, 57.00180138311079, 55.87652437148556, 56.233412988724254, 57.41952203935193, 58.77941954520441, 51.770387234226355, 56.05476079448577, 52.75028551778486, 51.05604125607399, 50.96496774304298, 51.02286977152671, 48.96082093638759, 53.51937209406207, 49.48528889686831, 52.68111451979607, 56.23476228406353, 64.22873312427153, 58.37142244462044, 59.80441724100421, 54.156047298062234, 59.735732616916785, 56.43772140625985, 61.92926322260211, 59.486850384742986, 63.299578543632265, 54.27901752533452, 57.966967244302076, 57.60734865742346, 62.295000706949544, 54.621322770272535, 63.18943838919363, 54.389232204806426, 70.48052833926293, 54.66029936267484, 79.47451529964324, 11.212814892491988, 10.32131016254425, 88.31251744301089, 48.86562108993531, 63.83683735324491, 55.605578807092485, 65.72949863249256, 53.89959489145587, 63.82326595244869, 57.73153874181933, 66.86079255996212, 62.30053909363286, 60.391431316252685, 53.97222934230682, 54.133881984218476, 48.14207323135869, 52.908411948911606, 48.38668400241483, 50.1705583449333, 48.59010204192131, 47.80507887563398, 45.27911955310453, 50.940809865151685, 47.85881534699471, 47.473826869841545, 45.63520016208772, 48.76847182550738, 46.29808072120913, 46.56422922688146, 46.91172768992763, 52.159133342004594, 50.40302938030612, 45.22891713726906, 50.27071214491322, 53.80640329853181, 52.5059179336794, 51.77157179001839, 48.84578174160373, 49.8100729142466, 52.483387839409616, 53.69986387991137, 55.493563759711485, 57.50390791123914, 59.857145663230654, 59.02058255287909, 62.29723645794777, 65.2760334168711, 68.74790760778612, 67.96951324709, 70.02240334787678, 69.17171186016452, 66.80928399485927, 66.00856350314233, 66.37087283595916, 66.84816252800726, 66.23821827673143, 72.7821594668973, 77.59635110055247, 78.93640533570321, 30.12339499688918, 1.1989610642194748, 1.3387006497190845, 1.7052173374160644, 0.37444100925518625, 0.4873962303803813, 10.133528651729709, 71.80688565777194, 78.09808500351446, 60.00999650647564, 39.846750613181825, 23.523101114457656, 31.228697338411887, 38.613400536198775, 43.37709165388539, 67.37110076412078, 60.03063601832236, 47.73134616113479, 0.6578148180438627, 0.1022994896817592, 0.09369864353850003, 0.09696366430650796, 0.1001653296031779, 0.058394619188601934, 0.02502995791033872, 0.13769057609381216, 0.012464608674147918, 0.013951200375994368, 0.018701730746655695, 0.08320006737185102, 0.14302610269477292, 0.1950728905297095, 0.15930827496753586, 0.1829453816096629, 0.23143168388595506, 0.16033481746431322, 0.11105461061120996, 0.14451827343192794, 0.18114029459895628, 0.15682803466916084, 0.16541793341598204, 0.2400462353421796, 75.49469024904313, 104.05645631974744, 86.5311259608115, 71.7872267384683, 37.49916891897879, 35.4111736051498, 67.05673063955, 46.57597672554755, 78.71803129872968, 91.33948110765027, 2.724946309481898, 0.5752347073247356, 5.006899151109881, 8.93500235772902, 6.544837942046504, 19.9081172866206, 89.42409361562422, 86.33425435712262, 96.36122888134372, 88.35006237030031, 92.0714581397272, 90.33073379147439, 88.32646539134365, 84.14191615196967, 81.93174685201338, 83.96692352910196, 86.28690350440242, 83.72947108361029, 81.9461105715844, 72.68323729115149, 73.93333588877033, 68.18995045077416, 67.86171082527407, 65.49198735144832, 65.2445250172769, 56.7167470532079, 53.25185075882943, 59.79004959906302, 61.15379102768437, 58.756771779829464, 59.970992457482126, 60.165126246790734, 58.73130383030061, 59.537574475811375, 61.501697417228456, 54.46457309107627, 59.73621114607781, 57.64992598564395, 55.8038350074522, 51.232116453109256, 54.44804030079996, 52.02079134602701, 56.384149674446356, 51.11353928042997, 56.11199209767004, 57.961224894369806, 66.50471195097893, 60.98966337019398, 62.8089371035176, 55.23907253819128, 65.61845241054412, 60.886128487125525, 67.15581755484304, 62.51456322208528, 68.32381310001497, 57.115616798400886, 61.19931405590427, 61.56109779111801, 67.61622536566951, 56.93716464504119, 66.21465267673616, 55.98810011340726, 77.65339805233863, 54.0674997914222, 88.2622875705842, 5.635554578996474, 5.451979810191739, 98.02809499925183, 49.27157071328933, 70.15268095078008, 56.83613615651285, 71.5493820559594, 56.35081737272201, 67.36321680007443, 60.07187974068427, 69.40350824786772, 64.86784412014869, 62.92080702320222, 55.77882597523352, 57.70074421359647, 50.985144415209376, 58.01756974189513, 52.50183082395985, 55.704595119722434, 52.01517843431043, 50.253912633465184, 48.56291609425699, 55.801579644603116, 50.23521861722393, 49.89544722341722, 47.530163872626524, 51.51060081297352, 50.207271729746175, 50.45473406391759, 50.27923545529766, 55.769023972172896, 53.51846210418209, 48.05967992351901, 53.567640781402595, 57.87042202488069, 56.1468658908721, 54.97805841507451, 52.4418067932129, 51.9952606385754, 57.05051722065095, 57.85002569998465, 58.80816267382715, 61.0635765137211, 62.55342998812276, 62.21663959564702, 63.90759691115349, 69.60329025022446, 72.07909030299034, 70.8924791889806, 73.0636287504627, 73.48602879431941, 70.83286700710174, 70.78687329446116, 71.01596324674546, 69.40635588861281, 69.55411157300396, 75.21005953511884, 83.0548861718947, 80.53903087492913, 28.36128588645689, 2.891320014192212, 4.984512223351387, 4.9639094837250255, 0.8279563883139242, 0.5402349079808881, 14.37059352474828, 80.8228692700786, 85.11889226974981, 67.28704437132805, 52.66367958438013, 49.94006026175715, 32.807688636164514, 37.16272761744838, 54.88830674079157, 78.51486036854406, 71.04152141078826, 55.47472461577385, 1.1247997082048848, 0.20544982725574126, 0.1797368674869499, 0.2913501323951829, 0.25209829992344307, 0.1628767431623513, 0.1434208065151207, 0.19124796674136194, 0.14574819695084326, 0.09774902700296334, 0.10924147201641914, 0.19870220142747128], [0.07799450758724444, 0.030940638426991723, 0.005752601625112396, 0.019187690960543773, 0.10333157865510834, 0.025784364908993728, 0.037862060876983794, 0.05819410333530076, 0.06668981540227129, 0.0420757589651452, 0.23754514213050568, 3.1259834093432275, 69.3432527972806, 71.07671291597428, 69.37321970539709, 46.248572564894154, 22.398810578930764, 43.445211456668, 70.91554272559382, 37.47331265480288, 78.35421577576669, 40.47149004474763, 0.04902258680592622, 0.24047450913536936, 2.5494055353826095, 6.29701671100432, 1.255416350979959, 41.893706167897875, 85.45217606329149, 82.99342263129451, 88.77295663279872, 77.92551640541323, 82.16508865356445, 79.05588073115196, 78.01118096997662, 79.51180135050129, 82.82126195969121, 77.30185954801499, 80.30668535540181, 75.56204518964215, 73.31404855174404, 65.20291651448896, 63.70147243622811, 59.321067487039876, 59.068156980699115, 51.83499259333457, 54.92257256661692, 50.912690393386356, 48.10015093895697, 53.39988885387298, 55.79547251424482, 52.37847620441068, 53.31713861034763, 54.29085131614439, 55.69096880574381, 53.79028627949377, 52.81109402256628, 50.97989236154864, 51.13812861904022, 50.49647200492121, 49.168906596399125, 48.37408534942135, 49.16905564646567, 46.90856233719857, 51.60393361122378, 48.7563556240451, 50.769186558262, 50.20888774625717, 55.139620842472205, 53.10315370559693, 52.572154998779304, 50.89915429392169, 56.43061799387778, 57.836230724088615, 58.317533000823, 58.892980006433305, 58.93478070535968, 53.44194058449038, 60.82238997182539, 58.5782019553646, 63.40938529660625, 57.60074730842345, 64.17206664239207, 55.50346382202641, 69.61173903557562, 55.350365869460575, 66.14994141363329, 7.2746503160845855, 5.000285054406812, 77.6014344922958, 46.06433883790047, 60.094915820706284, 52.95081277047434, 59.39190941472208, 53.610033758224986, 64.90867207127233, 56.91397167021229, 64.7724050091159, 59.069333691750806, 56.35119784262873, 49.60362288259691, 47.25064400703677, 44.84035538088891, 49.98571272819273, 47.23035750850555, 51.90057462261569, 53.79989608641594, 53.377146951613895, 46.30379169218002, 45.20750491849838, 41.19396317389704, 42.577112490131015, 42.69411287000103, 43.24850851489652, 45.21991137535342, 44.784485140154445, 44.158506239614184, 46.81857924307547, 44.45712804794312, 43.0708682921625, 44.4897739348873, 51.05062054049585, 49.28403600569695, 46.93878027700609, 48.369362815733886, 48.83226525398993, 51.428980212057795, 53.25505533526021, 53.02415324795631, 57.7317544721788, 58.87849077101677, 58.97618916726882, 61.77551023421749, 66.08574005865282, 67.90355467027234, 65.68854908789358, 65.5987189662072, 68.87424715103643, 66.53769123938777, 65.1825515685543, 61.27198773045694, 66.17816678939327, 63.093269717308786, 71.44514114625993, 69.52922805663079, 73.64992110959946, 59.993153848955714, 7.201898684424739, 1.418001046103816, 1.377218324811228, 0.5755570771232729, 0.08532282040123979, 0.27719687249871994, 44.859241593268614, 69.50050061748874, 66.37237118136498, 43.7375888516826, 49.877274882408884, 18.441733314144997, 14.121037625497388, 26.35683117374297, 50.01419698038409, 54.86203862774757, 61.58362396301762, 6.584974575427271, 0.3446947038173676, 0.12378673144285718, 0.04002482284821811, 0.07516232649645499, 0.04306086759653784, 0.016338542937451316, 0.0601500483800567, 0.001444508936049627, 0.03778465152267487, 0.04101876064293808, 0.043507198082102884, 0.08952727946903437, 0.05558963421912444, 0.04071481142854018, 0.06730106929617544, 0.07832296012390046, 0.02000336201050349, 0.08810063223204306, 0.025876850873652487, 0.09659175926278676, 0.12887711756892745, 0.3924789477980906, 4.581339638079367, 81.77181613060736, 76.52655601501465, 79.230175172129, 55.249211865086714, 34.614814789064475, 35.07795256953086, 50.97763307632939, 44.55811731276974, 87.91603642125284, 44.41472330401021, 0.11610456261663668, 0.6103426782834915, 4.342621737910855, 4.978472263582292, 2.252935392241324, 46.60023266269315, 84.75641819738573, 87.78671587667158, 89.68955962888657, 79.87096494243991, 85.17125591155022, 82.70183363268453, 81.38611378208284, 84.38262416470437, 86.25131976219916, 80.98642426152384, 82.64358643562564, 76.2365516539543, 77.22847984683129, 68.986662280175, 66.30398857978084, 62.95544939656412, 61.88631719158542, 55.43955664480887, 57.803427942337535, 54.166884806848344, 50.73483836266303, 56.712989422582815, 58.963186510147594, 55.00147496500323, 56.33582215155325, 56.79273905292634, 57.22899683060185, 56.06638669967652, 56.14611279579901, 53.589068689653956, 53.14442880692021, 53.53994884798604, 50.05007490035027, 48.56921149838356, 49.68028560761483, 50.71018234375985, 54.12615883734919, 51.336753522196126, 52.46510567203645, 54.42878930799423, 56.04050690127958, 55.14070341663977, 55.750377024373705, 52.972342660350186, 58.97586753291469, 61.79791873501193, 61.24817502114081, 62.221934795379646, 62.47352346297234, 54.27651505316458, 63.68652428350141, 61.71673743955551, 67.27130782219672, 58.80302436890141, 64.95279481334072, 56.16502646476992, 72.21313338125907, 58.25097822373914, 68.8400754620952, 12.48056415588625, 9.77691165862545, 76.53852708878057, 50.93158052813623, 64.44012534233832, 57.62382261214718, 59.875737697847434, 57.609156870072894, 64.59157197706162, 59.09700993568667, 66.11286717076456, 62.195749052109264, 56.86303184878442, 52.03595130674301, 50.39451391466203, 49.243321803308305, 52.71792596386325, 49.41820852218136, 56.461220325962195, 56.04824573762956, 54.01902714083272, 48.41856502717542, 47.52656705917851, 44.14584875106812, 45.10907696139428, 44.11452078050183, 46.25844909298805, 47.16264955459103, 47.99095999810004, 45.59077539751607, 50.31362679696853, 48.54714424379411, 47.19405989493094, 47.404651949482584, 53.00667516646847, 50.99367949270433, 51.69024144449542, 49.748338730104514, 52.69422308091195, 54.2624141323951, 52.383355632905044, 57.621759445436545, 61.51031878686721, 63.194035407035585, 62.40380725552959, 65.89535605522894, 69.0076155816355, 70.83631084811303, 67.95019165162118, 68.30400513064477, 71.25821667332804, 67.51491838885893, 68.81522332468342, 65.52152279884585, 69.41474191604122, 68.52346174178585, 72.4154100110454, 70.3595075299663, 76.15185983719365, 64.76576835878434, 11.502191674324775, 0.7650060855573224, 0.8558916312552268, 1.441295879983133, 0.13770644943560326, 0.05632585620567684, 44.89003219912129, 76.12593297035464, 72.87842227566627, 47.882800640598425, 41.69893695462135, 17.24780894094898, 21.325024481742613, 38.06441383977091, 58.71816781259353, 63.21702049624536, 72.45659489785471, 11.933224854930756, 0.3959858225237939, 0.20530341253165277, 0.09812358271090255, 0.10193159893876123, 0.04556727362796665, 0.06956521917374865, 0.042845627533332, 0.026998434238316073, 0.0883038447148377, 0.027767052167966485, 0.03522817015407547, 0.2796466378194671, 0.13977137814846732, 0.13950384492355009, 0.15081295743584633, 0.1856228282615062, 0.18704009092142507, 0.21938744872327776, 0.14713607247798674, 0.15287266142906683, 0.226217337072857, 0.5642461259999584, 6.05221325351346, 96.25190457990094, 86.42613195603894, 90.65858117995724, 63.49131576476559, 35.654038921479255, 61.19324222687752, 96.5445996868995, 53.58410689138598, 96.13692422066966, 52.03960303337344, 0.34993462264537817, 0.9692511935868572, 5.741073691075848, 12.008616732012841, 3.9889374519548113, 50.12216021937709, 93.16419909077307, 87.06354064326133, 93.77524945043749, 81.72234719799411, 87.82305271394792, 87.73190467588364, 86.37624725218743, 86.97509904061594, 90.77045502201204, 82.09716104692029, 85.7150690017208, 80.85149472759616, 80.72812049619614, 74.31290365034535, 69.28375828650691, 66.48558647401872, 67.150922436868, 58.31428527832032, 61.96563536121, 55.715628747017156, 53.78009596178609, 59.73361845939391, 62.465168814505304, 58.65836343457622, 59.82998324978737, 60.28271105981643, 60.55202099584765, 58.7932929685039, 58.576162322875, 57.936498272803526, 57.08327685633014, 56.39487735686764, 52.76946983029766, 50.7564780789037, 52.903709027075, 53.286277401831846, 57.63093779163977, 54.59100284884053, 54.99157882505848, 57.1584883043843, 60.40223352370724, 57.99767940275131, 56.73804944561374, 54.89819895836615, 62.11077482469621, 63.519203816690755, 66.5160789797383, 63.93823846693962, 67.09078465738605, 56.30058357792517, 67.93654180342152, 64.11794970112463, 68.99083568203834, 60.85912296848913, 70.46942803167528, 58.843491461969194, 79.53642599044308, 58.5458698580342, 78.20678172572967, 8.738023869452938, 6.476871111700612, 87.85226652699133, 49.087576250876154, 68.62836160967427, 57.85505025617538, 65.51878498446557, 59.70860550480505, 68.69220995133924, 59.72143165526852, 69.72751955832206, 64.76136353708083, 61.462101090338926, 55.06336212158204, 54.26186500057098, 51.49693527529317, 55.95120237719629, 52.58454968852382, 58.94382569097704, 59.90032703645768, 57.96080520076137, 52.641023974264826, 50.244906871549546, 45.08600165767055, 47.52197004133656, 47.19865299040272, 49.209197182809156, 50.91384749258719, 51.27192066561792, 48.660536043105594, 51.64850742586198, 52.099015174373505, 48.56163740158082, 48.37880788310882, 55.3065529946358, 53.14667240265877, 54.164158759578584, 53.19805152954594, 54.9586348379812, 58.4649827403407, 56.52480194645544, 59.01243971240137, 65.31938345201554, 65.71574680266842, 65.10109178481564, 67.03698542810255, 71.58476967965403, 75.31489664508452, 71.03702637457079, 72.32328922517839, 76.08190828754057, 71.34276728476249, 72.56761366321196, 67.56963545276274, 74.99707483476209, 70.07814807276573, 75.90662540928011, 74.6830734129875, 78.89629517832111, 65.43315179886358, 9.15362056224577, 4.932375098428419, 6.151181026812523, 2.166116179958467, 0.2674830308364284, 0.6671210089998861, 53.46418042336741, 81.809753294914, 80.9894052628548, 59.308002071995894, 66.5611627024989, 26.965402595458496, 25.113988960942915, 41.95925681821762, 71.19789846481817, 69.8993899745326, 86.33503098641673, 14.589919717081132, 0.5245675519108772, 0.27685090719211486, 0.21407159526021252, 0.3707819588242039, 0.3887381404638291, 0.1388309592561376, 0.2385293506085873, 0.16979045685260527, 0.18478794564162532, 0.20305292200176947, 0.14567537263276117], [0.05751891557367579, 0.0269077715629171, 0.045309868085408406, 0.042993884698878375, 0.07092638887585172, 0.004811556934709511, 0.051980877460371104, 0.04313452695045741, 0.08320759035526745, 0.1960044074803591, 0.45347021051472236, 15.539975627776116, 87.76474275896626, 68.33832586965254, 73.33122068835844, 30.068528882918823, 20.46469573051699, 49.753653541688, 52.69733352045859, 42.35738915781821, 96.05619399778305, 15.075362055532395, 0.06039164952873703, 0.6185205136576007, 1.0222503819292592, 7.559533532588714, 6.415798337228837, 66.46767693181192, 79.26074612525203, 101.16447710221814, 73.7396021812193, 81.44095636183216, 80.48585922487321, 82.59567860634097, 81.99218273162842, 80.537320721534, 79.28121305281117, 78.66248269234934, 74.84738149950581, 71.23040706880631, 65.87052745203819, 62.09392824480611, 59.0643326697811, 57.57902130003899, 56.09338437357257, 54.80815702869047, 52.54934249385711, 49.86649228680519, 49.85243451210761, 53.81608370811709, 53.524733974087624, 52.57950944285239, 52.94461150323191, 53.97789716720582, 53.30290432899229, 51.822786177358324, 52.12585987583284, 52.253478111759314, 50.93213358233052, 49.09541314648044, 50.768586435625636, 48.50321369786417, 46.3518681833821, 47.29038546162267, 48.05585953497118, 51.55460196156656, 49.225012179343935, 50.38290762132215, 50.77031227850145, 51.60411011788153, 50.65200574936406, 56.119828993274325, 58.43063454474173, 59.834270400385705, 58.94599476168233, 58.54589731462541, 57.63398155089348, 56.54653187721007, 63.53219470670147, 63.70306884088824, 63.210968279069476, 60.79796929513255, 61.9300163176752, 61.46012421577208, 68.45937021317022, 61.27512954896497, 49.3048559465716, 6.1256336492876855, 8.089334935911241, 61.20784913339923, 55.61273713265696, 57.36552276918965, 54.559423846583215, 54.96724444050943, 58.71654395134219, 64.44391435192478, 54.85031858567269, 59.423578631493356, 57.25490408559, 57.67611172891433, 51.72197341918946, 51.059794964328894, 48.57825256163075, 51.05794360560756, 55.33826927984915, 60.46677220252253, 63.84483898839643, 61.10130187003844, 52.3135256767273, 45.95321416854859, 44.16045173521965, 42.0651686576105, 40.534185209581935, 42.020551696900405, 44.29102743825605, 44.4585479459455, 43.889353198389855, 47.14123341345018, 46.21842915011991, 45.757456517988636, 44.60797456003005, 48.9492146430477, 50.38905789775234, 47.449061024573545, 47.367373743364894, 50.79302672416934, 52.32208821081346, 55.11910292410082, 56.45472095858667, 63.09972593861242, 60.036652934166696, 62.28604985821632, 63.81806881197038, 66.17644094651746, 64.68970183403262, 64.29100075075704, 64.29031433597689, 67.05913113009545, 64.84731835703697, 65.89723094817131, 63.523498812029445, 66.577895533654, 63.40206223149454, 68.74716235745338, 67.1072115436677, 73.67370636232438, 74.3889662527269, 43.40594460887294, 0.9212476339551711, 0.22552445651062075, 0.9336287179781545, 0.3454379929650215, 0.2691812026164224, 12.10277028622166, 72.80097899898406, 68.5529265865203, 59.28806466441001, 53.11881180732481, 51.18372617229339, 25.99543575317629, 14.012011424187692, 38.795347521382, 53.45215835878926, 57.585622649038996, 30.195770571308753, 0.1192181890890483, 0.023487026187320872, 0.029917648662963224, 0.026877355957103354, 0.04696559093351807, 0.013063794768024838, 0.081050708108852, 0.09464082443305562, 0.08239333848318747, 0.09394517063253349, 0.06421725896577682, 0.09806473183655932, 0.042531156101294106, 0.030470132121756196, 0.10753560871366533, 0.051019563519906615, 0.021686202455912868, 0.0029014883470916825, 0.02262886790108056, 0.06347307732569114, 0.15311770231252717, 0.36049201904285344, 20.888427419047204, 100.39843036282448, 74.8562382113549, 80.70789675558768, 39.01955020043158, 31.502314036892308, 42.23398746982698, 52.21624697408369, 49.49552628301805, 104.89945996192195, 15.058870450142892, 0.009431497084968274, 1.542473418578025, 5.264563570099493, 9.530385790332671, 7.331932119784817, 70.64948835680562, 82.7516398891326, 96.11986191042008, 76.72552216437556, 84.35858788028841, 82.46744063592728, 84.79352381921585, 85.14631748199464, 83.35420223974413, 82.1338430527718, 81.75519312581709, 78.29321507484683, 71.77353766656691, 67.18503136788645, 66.06478675719231, 62.43355451091644, 61.15197497029459, 59.85271338493594, 57.845809152049405, 56.59505159624162, 53.69665145874024, 53.190336227417, 57.512882294193396, 54.8843490692877, 55.73326764568206, 56.15585204093687, 56.5277398017145, 55.47568559646607, 55.52701373254099, 55.00231435222011, 52.96143847127115, 53.731717448080744, 51.332266330719, 52.13764659820065, 50.872972473021484, 48.02968163644114, 49.1164448953444, 52.47235813448506, 52.46088520173104, 51.92060224471554, 54.570853633265344, 53.81725257442844, 53.78002143675282, 51.490683017238496, 58.614181856955256, 62.10116109540386, 62.893201381929465, 61.831129443260934, 61.94548222326464, 60.02457203403596, 60.364978851810584, 63.88500798133112, 65.63291026699927, 68.61698673617455, 64.36232120760026, 64.83961089964836, 63.632799579251206, 73.01646617151076, 64.79274642082953, 53.201224727015344, 9.621094522937652, 11.758348922575674, 63.03416744355233, 58.09456979074786, 62.65505859928747, 55.8586383634998, 60.43864880838702, 61.84319073154081, 66.8603297202818, 58.36767658110588, 61.623392874194735, 59.00706606526529, 58.887488688192065, 53.48097601244527, 51.84002891663582, 52.09315515333607, 52.44709807057535, 59.40233899701027, 63.47207653907038, 68.73960002776116, 64.20771706488826, 54.02354571127123, 50.05233026319935, 45.258248621417636, 45.943674964289514, 43.18544072489585, 44.27977808060185, 47.04669252518685, 46.72137506546513, 46.867526500455796, 52.43534664953909, 49.03600100548037, 49.14093617470034, 47.700955637039684, 51.19911363047939, 52.685221241366484, 52.05233504695278, 49.663854798962994, 52.64408734536941, 55.136267215974875, 57.9245154319271, 59.87822055816651, 65.98839467571628, 62.632987422327844, 65.75765340558945, 64.83510409632038, 68.49223183047387, 68.08417981670749, 69.06682768175679, 66.46525290704542, 68.86501389165079, 67.44906963840609, 70.92658811999907, 66.83426949285692, 68.4075007900115, 66.76798928168513, 70.41971591211134, 70.08182725598736, 76.35473266724618, 75.67677451718238, 49.65610027313233, 2.1197334172264224, 0.42636240381867657, 1.4844662215440505, 0.6491856036647674, 0.22932210756886393, 9.896807728275176, 78.67898018129411, 73.01383033875497, 66.984982644358, 54.54033367095455, 42.83090552976055, 31.467891316260065, 25.166870355606083, 48.25639855477118, 60.581391703697946, 66.81191198287472, 42.472177320911044, 0.20642608374116883, 0.013398784907504678, 0.013479525786674312, 0.1015590810247006, 0.028528522497283357, 0.005167550811048357, 0.05200292930127152, 0.04132415776351287, 0.11311893411461385, 0.13596638796790955, 0.040449312167061914, 0.23497531551026532, 0.14989305437812883, 0.14451755330927912, 0.2591448072944918, 0.17612232676436826, 0.09303143458260645, 0.1873810919782808, 0.22801876218328554, 0.1928456124639319, 0.35439990400787325, 0.7120484498239333, 26.69754589757612, 114.93552654020249, 86.08773339179255, 92.56609255267729, 44.86801985771426, 30.443736930047315, 66.24523931933989, 73.60152690641343, 55.603849041846495, 117.68972073831867, 18.225844098675637, 0.22859510545048023, 2.186848848096786, 11.04535420094767, 10.534616497255142, 7.168971367420689, 76.2480834222609, 85.96191944614534, 101.9712301992601, 78.8296619538338, 85.78329470849808, 85.83109271141791, 90.89898324781849, 89.96109747117566, 87.23202213164299, 83.39162949592837, 85.12841578452819, 84.55010152632191, 76.91607875208702, 72.02107060340144, 70.59778367319416, 67.32060417052239, 66.76356484813076, 62.12126716490715, 61.73693764594294, 60.01267548530333, 57.37824301565848, 56.07619262510731, 60.04557240393854, 59.745020789484826, 58.688973611400975, 58.18924011722688, 59.23539115536598, 57.926551142046534, 56.10205281165339, 57.76628701917587, 56.99266618297946, 55.50591922575428, 52.78066427476945, 56.15322797529159, 54.641001301427046, 51.35022686373804, 53.22548850890129, 55.192039397455034, 57.1050734673777, 54.97030781161401, 55.65136463411393, 56.32368241586993, 56.832456973291215, 55.62189194463915, 59.81337201210761, 64.70163760646697, 66.44077731717017, 65.14431630411457, 66.77307267342844, 63.06603277883222, 63.40934215053436, 70.00399174228792, 69.57059337246802, 72.06575424440446, 65.14148043047997, 69.60947975035637, 65.78358027242845, 78.33455685646304, 64.7066072494753, 57.53761676050002, 7.056153214746907, 9.323337597231712, 68.66919348316809, 61.234988012621486, 66.57495375602477, 58.04956843776088, 63.63696121400403, 63.53616806768603, 69.78906939106604, 59.33767087997929, 63.01955269229028, 62.97357074676022, 61.60928018631474, 56.59545952273954, 55.74444247830299, 54.76445398023052, 56.64753683151738, 60.05590000460225, 67.13429943207773, 70.77566316050869, 66.30523589349562, 56.122519739212535, 53.49773237782141, 48.82757802163401, 48.840961148661954, 46.7495886741146, 47.66174370242704, 49.366123368663175, 49.76417726086032, 49.89923231063351, 54.30817642519551, 51.83807557629001, 50.7327320498805, 52.123671193276685, 54.6231270605518, 56.186807386336795, 53.79218470665717, 52.795184889147365, 56.326157431448664, 58.60311292832898, 60.292630733982215, 61.623000637177505, 68.44553209120228, 66.96820274476083, 68.54100258119645, 68.52075530636695, 71.75907981011176, 72.28233183583906, 70.99532373489873, 68.70231397690313, 73.3248507591986, 72.11911416822865, 73.01339103329566, 70.12895061123756, 71.82841947001796, 71.00547482890468, 75.22276801447715, 73.89695198305192, 79.29283895800191, 79.09218618946691, 49.86367602502146, 2.099833272157177, 3.0091803737225074, 3.3696824744824445, 0.9470224476629688, 0.4213207791889868, 14.499930739402773, 89.51084859909551, 79.2987068237797, 78.74625667448967, 72.17253684997559, 65.77293103741061, 38.93117527807913, 28.811623011865926, 58.283573119871086, 69.90811332579582, 76.3082290464832, 53.081255112924886, 0.47193721958225776, 0.10583392059009884, 0.09275662352240856, 0.23648532077429757, 0.07645154522070963, 0.13080591245764686, 0.21148935801559882, 0.28551269562975057, 0.2006717675155209, 0.31797472147210953, 0.1903584467307214], [0.044615156573033145, 0.05117227931717231, 0.07448204808057317, 0.03043853865575887, 0.036960804399343274, 0.11661258616274404, 0.033776762955371416, 0.05127870042117373, 0.005284144126269366, 0.04530977615485749, 0.05720386957569469, 45.36350150262156, 76.94832847964379, 63.63359582039618, 63.704273008531146, 25.401694813082297, 52.19317559273013, 44.09529332191714, 39.40410721686579, 63.345517343090435, 79.19051216494653, 2.4107404341620784, 0.0662778592818687, 1.8340102006350796, 6.734460515360679, 15.428199844975627, 20.045431621613044, 75.58985479416387, 80.10384390431066, 65.19562090596845, 75.82739353179932, 87.7727993073002, 76.90960684130269, 79.77231733260616, 74.25988889509632, 80.40867482462238, 78.54953412086734, 75.55341597526305, 68.4296308025237, 66.10149229726484, 58.28000768538445, 56.50847704179826, 54.49443017282794, 55.38860505627048, 50.94499111175538, 52.620007914881555, 51.81981694313788, 53.885874440593106, 50.08113222737467, 53.35749979942076, 52.035621827648534, 52.66815108637656, 54.05443045400805, 53.0840164615262, 52.24781420923049, 50.29730581468152, 50.81356425439158, 51.42423022177912, 49.50683055385467, 51.04344652545068, 47.46515058702039, 48.268550057565015, 47.377728800619806, 46.22830960058397, 47.20725082582044, 50.30565261840821, 52.16029828594577, 54.33893565208682, 50.96046486208516, 48.96315866901029, 50.93775433878745, 56.81898755411948, 61.40659955240066, 61.93940254949755, 60.68495796572778, 57.04702238882742, 56.82223527662216, 62.336569986035755, 61.07670468668784, 65.1357537700284, 66.16838439818352, 62.064573226436494, 61.70592738736061, 65.15722090198149, 59.734697111191295, 62.80774470298522, 35.646802148511334, 18.196971531837217, 21.295549831082745, 52.1876960415994, 59.58243462347216, 55.8814077223501, 54.2778015905811, 53.1222713378168, 57.923283807693, 63.36453691605599, 61.085180928630216, 62.37813926512196, 61.69025751852221, 58.95304718325215, 56.23108310084189, 52.21278744359171, 52.17659965638192, 56.75920278795304, 60.506941195457216, 61.95743368517969, 52.25079128819128, 60.95962585941438, 56.98421347525812, 48.241842639061716, 42.907383903380364, 41.927881779209265, 41.06389345661287, 42.48565850719329, 43.80323756125666, 45.21650283567367, 42.72379344509494, 47.4710851330911, 45.42840888423305, 45.669689563012895, 44.70114261873307, 47.35011139223653, 49.31540712233513, 50.309727961017245, 49.37345427851523, 48.978342163947325, 56.06853615853095, 56.30442750069403, 64.2333262197433, 68.93226685062533, 62.802084722826564, 68.28088668084914, 65.12699119506344, 66.65635078184067, 66.3810396194458, 65.25324444616994, 65.59325902692734, 66.72358805133452, 67.91422351714104, 67.28196882432508, 64.99359530787315, 66.99861680307697, 66.07158814707111, 67.5095525864632, 67.81210853207496, 69.72860213248961, 70.05993258568549, 71.20755534018241, 13.380787334134503, 0.49431048033218233, 0.4657072393644241, 0.25534482732895886, 0.03333966765973357, 0.6539613957847319, 53.00428252066336, 68.6094871644051, 64.13882847755187, 43.68276196141397, 45.48393003402218, 20.40118471268685, 21.452815301956672, 25.114902873193067, 54.26088048565773, 53.69135625900761, 60.206805352241766, 6.4804144828550285, 0.24848336083514078, 0.03126474724511706, 0.005434590388059376, 0.06379518282389449, 0.09454959102215306, 0.013942602954264131, 0.05243428659835651, 0.03689347293167826, 0.06882310214061892, 0.04733955292331596, 0.07005199910171571, 0.03839993503906074, 0.05195570381117925, 0.01946224346606722, 0.027543469407265226, 0.13360741938794815, 0.04216778144660977, 0.02860766704074077, 0.026124940787051475, 0.03143815316199776, 0.13373878814520376, 55.70642294422273, 85.80037270822834, 71.56191795103013, 78.09462547302246, 33.03491154024678, 37.82480016831429, 35.63212463932653, 47.263203436328524, 71.71898534221035, 86.69680687689012, 2.6154624166027194, 0.03306505578239599, 2.77595428209151, 10.736663668386399, 16.707784860364853, 22.68396689045814, 79.79500432168284, 82.24917642531857, 70.70856709634104, 75.71750440905171, 89.79350243845295, 79.38693661843577, 86.3917798380698, 77.96663853429979, 81.6378201207807, 81.38182270911433, 80.14964934318297, 72.65003050527265, 67.93262727798955, 61.677874595888206, 59.475424520431034, 57.6542680494247, 56.7229090967486, 54.834476132546705, 55.23828021941647, 56.41126109707741, 55.846741814767164, 53.426227569580085, 56.5398677702873, 54.73990386532199, 55.356233735238355, 56.28845953172254, 56.00354640714584, 55.62611241494456, 53.74877191358998, 52.241671777540645, 53.48485915891586, 52.13270441178353, 53.20618652528333, 49.38199720075054, 50.79072821524836, 48.239222495786606, 50.491412147398925, 49.842346176024414, 53.260495662689216, 55.226246387727805, 58.35502301492999, 54.3265409623423, 52.44759228921706, 55.44124326398296, 61.653253878316576, 64.60530027266472, 65.44840981883388, 62.34873717831027, 60.367846104406546, 59.871740802641845, 63.08460912396831, 63.54122792520831, 66.9782361676616, 66.79437898820447, 62.699997194351695, 64.51442680051251, 68.05380498209308, 65.14070380118586, 63.00644020880423, 39.012858636917606, 22.655182576948597, 25.106332494366555, 54.18405302109257, 62.86729412694132, 60.91195337234005, 56.75504899794056, 54.89638290097637, 60.32287220801077, 63.484239808974735, 62.31071764423002, 63.272796600095695, 64.78154020924723, 61.02184249508766, 59.46787395784932, 55.60781455809071, 55.41441425200432, 60.34739094395792, 63.217781436058786, 61.37306328742736, 51.69481100574617, 66.12464212602185, 59.68727957817816, 51.10297633755592, 44.087248540693714, 44.50873074993011, 44.43719848509758, 44.14057316318635, 46.436391338225334, 47.63513826554822, 43.66804130615727, 50.42847379561394, 48.08517532963907, 48.19155785345262, 46.12497868076448, 50.04452474655644, 51.104541363254675, 51.67626603957146, 53.0187560665992, 52.806810794338105, 57.94353108252249, 58.526073655774525, 66.52446500716671, 71.04967209600633, 67.07129047762963, 70.63525015308012, 68.19620270882884, 70.1083581678329, 69.37375314774053, 68.28012574103572, 67.99032534322431, 69.12378834139916, 69.3268023767779, 69.35421189954205, 66.417737314778, 69.75274824327039, 69.03634302077755, 70.11822685118645, 70.49339371342813, 73.55220702386671, 73.10157375950968, 75.31834833083614, 17.941925294937626, 0.19859347822925738, 2.04235706598528, 1.4088101973456721, 0.07089333984279825, 0.5328705966953309, 53.94637700050108, 76.6473493268413, 69.68392633622693, 52.08141157704016, 37.07423110162058, 21.347858559700754, 30.55865060898566, 32.70195330342939, 63.186865314360595, 59.81509393261325, 70.85446357727051, 9.917464890787679, 0.23593125534394097, 0.14081512698002402, 0.025904363006233208, 0.029941609978014906, 0.057217927289105235, 0.006843459597157856, 0.045172937529822516, 0.024627744513113174, 0.055699211605373895, 0.023759364698743148, 0.18393401807594686, 0.15689598666804452, 0.11201231244711146, 0.125097063550305, 0.1403242944469375, 0.23790437607995926, 0.16266438358974072, 0.14902074070226762, 0.09194086245711773, 0.12476792153451713, 0.29777126687188304, 67.11663307682161, 96.3235584382088, 82.12053052840695, 84.31741868295978, 40.00759916920816, 67.2745398552187, 62.1439306197628, 57.86685266802388, 77.2216078542894, 95.86415475414645, 3.792134980040212, 0.14651871286332607, 3.2944943155011828, 16.215293042121395, 20.292456611510246, 23.06361702180678, 88.31790677962765, 84.18300690189486, 80.82739568525746, 77.56257164862849, 92.69134952176003, 81.74039794552712, 90.8212418710032, 79.98711416798254, 86.4056807179605, 84.94958708363195, 81.38153245372158, 75.31918771805303, 72.22657926620977, 65.14552047175746, 64.2389077524985, 59.12766325858332, 60.9119180710085, 58.19006381496307, 59.258348787984545, 58.30945291826802, 57.889072895050056, 55.730055224510934, 61.58558514810378, 56.51075593886837, 57.86483656975531, 61.509326427213615, 58.534722482004476, 59.30930822126327, 56.42796254927113, 54.675820181446696, 58.083277287021765, 54.54871969838297, 56.7362412329643, 51.69754882012644, 54.329243475391024, 52.1549246388097, 51.38013101393177, 54.721017652942294, 56.208203915626775, 58.01626751499792, 61.13365750158987, 54.84621186410227, 54.98627578058551, 59.10664719920005, 63.05506583183043, 67.61664898164811, 68.12252490751206, 66.7880561274867, 64.46944898174655, 62.114253967039055, 67.1360880328763, 67.01356103343349, 70.27023438484439, 69.27165385215514, 69.34399804761334, 68.47596968373945, 70.65917661113124, 67.00926211572462, 64.72521497357276, 41.04884332226169, 19.867534483632735, 24.513338765790387, 60.06248958649174, 64.5906815990325, 65.52605313639488, 60.66365557332193, 57.82570700491629, 61.78932089959422, 70.52094444151848, 64.54287182900214, 68.80447603041127, 67.25084089463758, 65.78690644233458, 63.13900455351799, 57.51692233547088, 56.80784802283011, 63.32053576746295, 65.10433558494815, 64.76149689766669, 55.709427479774725, 68.37954998016357, 61.85914301103162, 52.44816495526222, 48.46056576698057, 46.17061938008955, 46.372421403085035, 47.94406414031983, 49.07121212251725, 51.05110299202704, 47.39189247931204, 53.930816958027506, 50.25928628060126, 51.15976049054054, 49.92289204751292, 52.33691869243499, 52.31877773038803, 54.97543434942923, 55.488515669299716, 54.66483754496421, 61.67844333956319, 63.85919486322711, 66.07569879101169, 72.70898372896256, 69.79359580624488, 76.7763090133667, 70.63192398317399, 73.11113649798979, 72.52176900063792, 70.10255305997788, 70.73799271737376, 72.80443852947604, 73.99920032870385, 72.82955738805956, 68.80922994306012, 72.07086901510917, 72.86301520562941, 73.77144398227816, 74.02007518276092, 78.54003414030998, 76.70179182483305, 78.99913972423923, 17.115846680056666, 2.653989162175886, 3.9816195349539485, 1.3981066620157612, 0.2747452379234376, 1.0859068338909457, 67.75373581917056, 80.647947249874, 78.58653776107296, 60.684903052545366, 61.80731673394481, 30.18298560573209, 34.407760712408255, 39.387519513407064, 75.22558427626088, 68.19376299458166, 84.27222513383435, 12.748545389021597, 0.5193650794606055, 0.23363607124455515, 0.1951999998381061, 0.16188959290664043, 0.25224659922382525, 0.057116018442977826, 0.21968067653717535, 0.14053236392717208, 0.1777365965948951, 0.09552205537235546], [0.030695967180954836, 0.02184451069502581, 0.04630629183544267, 0.11060155387366973, 0.09179407234994635, 0.05404659141335757, 0.07831810312646051, 0.12551552375718472, 0.048935792874544866, 0.19622358523549574, 2.4721904916148034, 69.91129829037574, 71.76298649080339, 64.01273212125226, 31.645974766823556, 53.23041108346755, 125.35910760202717, 52.008663377454205, 43.80941921664823, 83.70694098934051, 52.99335087499311, 0.22084352139744068, 0.02029130190250374, 0.8113815551323276, 0.26716136583878153, 2.3371597115070593, 36.48400068283081, 82.93401441266461, 81.9827925774359, 72.58156161154471, 79.26506073244157, 83.4809575542327, 79.42981596915953, 77.76663687921341, 79.19626235961914, 78.78153447181948, 74.1746401017712, 70.87139252693423, 64.24060613878312, 58.395482263257435, 52.971436592840384, 54.146327664775235, 58.641905169333185, 57.50667318221062, 58.895902172211684, 58.17606487581807, 52.97883418298537, 53.95519841101862, 52.681887226720015, 54.75122774800947, 52.67800015787925, 50.0962451196486, 53.55336727634553, 53.65495274143835, 51.97931228145477, 50.763365760926284, 49.046999331443544, 49.937530332996005, 51.81526307136782, 50.45664033582134, 44.12894725799561, 48.43779640813028, 44.80030013668922, 45.282320207165135, 46.9274720837993, 52.036637721523164, 61.48475670045423, 63.266505118339296, 64.4826909034483, 60.46247328481367, 59.99744099955405, 64.0414164143224, 62.48021502648631, 63.76671321930424, 63.40676515333114, 59.27254776800833, 61.72389576511999, 60.36932483796151, 63.844246710500414, 62.44087365365798, 55.790969633287006, 61.74570414327807, 65.8258673452562, 65.5207500919219, 62.760511521370184, 61.0081220442249, 34.59432432728429, 33.94290493380639, 26.02079191515523, 38.25061267422092, 64.21394971109206, 55.28201072446762, 60.504109244192804, 55.116694588815015, 57.794983079356534, 56.290338347035075, 57.337811223922245, 58.30666803544568, 60.83451401802802, 57.78436914567025, 58.42200533036263, 54.33840220974338, 56.554549201842285, 54.88132099951468, 62.64354644283172, 48.85902758567564, 45.45497901978032, 62.7517254121842, 56.07059932524159, 48.61237325975972, 44.39406418031262, 43.810713598805094, 39.67764546794277, 42.913475344257975, 41.79905153089955, 44.264116056503795, 42.63966644963911, 46.94269088006789, 47.23700200357745, 46.25882956289476, 43.14955496018933, 46.066256876914736, 52.85742898141184, 50.56417995883573, 50.594872505434104, 51.88479492741247, 56.54519827135148, 59.26726433538622, 64.17618905344318, 73.25775469503095, 62.98414937911495, 65.03124221678704, 64.90478892480174, 65.62660701813238, 66.56347690090057, 66.85455599138814, 67.00013868270382, 63.77920596830307, 66.49864012195219, 67.23209980995425, 67.6395320892334, 66.26625537872314, 68.10427804147044, 65.74901242409983, 66.43348955339002, 69.77546661130845, 69.35868340153849, 72.92094861307453, 39.75296674236175, 0.7427617727268128, 0.4859672925404964, 1.7453057991881527, 0.28605952919010197, 0.30072346329689026, 18.4127587656821, 73.71435780679026, 70.10460053720783, 60.03881416013164, 60.83777350764121, 49.564724737598056, 13.077905831798432, 18.84264857538285, 43.49637877556586, 55.08277393156483, 58.66000298530825, 34.64453458786011, 0.5704487415571367, 0.19124600555627577, 0.08213775622988902, 0.09172750697020562, 0.05159324080112481, 0.0605554927531029, 0.06503221563874714, 0.01921032694348645, 0.020284495211296508, 0.15664015926661032, 0.03938335444658034, 0.04719267088559367, 0.09430367679845902, 0.14475248183213896, 0.08183336651493466, 0.04093192074628126, 0.032945676301155365, 0.10346284016005455, 0.045903842866180405, 0.1793429450762849, 3.283686224491366, 83.83659101301625, 79.70033399520382, 75.49862046395579, 45.595701894452496, 52.04423927491712, 101.91383023415844, 48.85348527662216, 51.6443810924407, 91.01998836763444, 54.72277487477949, 0.2485270738121002, 0.22189715276322058, 2.5155839179792716, 0.7810810004030505, 2.952908335193511, 40.33238318658645, 84.49396456441572, 85.2346492582752, 74.68102593575755, 82.03220659686674, 84.3501312501969, 83.711208528088, 81.14734342021328, 82.40871490970736, 80.58511872445384, 78.20022352280156, 73.41304133015295, 67.49460835610667, 59.153197888405096, 57.23405668812414, 57.44759052030502, 60.81792239219912, 61.728308431563846, 62.111025856387236, 60.65279060794462, 56.31251935035952, 55.633360955023, 55.372044809402965, 58.1171626429404, 55.45561090592415, 52.908996382067286, 55.116372954460886, 56.48509579320108, 55.50396980777864, 51.85773449559366, 51.42579916984805, 50.75141429901124, 55.51340310804306, 51.818859884815836, 48.406927354874156, 50.17805791670277, 49.453439251069106, 49.06692497191891, 49.89036775404408, 55.39043288077078, 64.78932611403927, 63.75456171651041, 67.32065123896446, 62.007875365595666, 62.825222784473056, 63.640981643430656, 65.01856903876028, 66.63888054509317, 65.35873266958421, 61.669037495889974, 66.15313422295355, 65.07206232317033, 65.0254096523408, 62.730415175038004, 56.44051021145236, 65.1497801657646, 65.9543171236592, 68.20548303665655, 65.58977203984415, 60.61193520022977, 36.62331150424096, 36.54456207829137, 28.360134670811316, 38.07880109356296, 66.8997573852539, 59.096378434088926, 63.450119110845755, 59.92806996068647, 60.42428116644583, 57.82320845511652, 60.30991661933161, 60.906007059158824, 63.64871655741046, 61.15266922981509, 61.217839410228116, 57.48829295558315, 58.739407447076616, 59.75047680639452, 64.05017898928735, 50.81389765585623, 49.50132354613274, 64.95138668244886, 58.10587406158448, 50.833160415772475, 45.60051072028376, 44.257412725879306, 42.703479489972516, 45.74491670054775, 43.8805906234249, 46.739143402345725, 46.05817679435977, 48.790613605130105, 49.530192190600985, 49.74727184541764, 46.749035619920306, 47.158962526629054, 56.67760572125835, 50.92946637061335, 53.06581274155648, 54.53922364019579, 59.743808777101584, 62.040874265855365, 67.24889539903211, 73.83175434604769, 64.55567836761475, 68.17894428007065, 68.82073033240535, 68.32901416286346, 69.68790361958166, 69.41790334640011, 68.41684387576196, 67.2095775604248, 69.65324555673908, 69.05298171504852, 71.14614671276462, 67.73840719653715, 72.12996344412528, 68.82703750364243, 71.23348220702141, 70.80520645264657, 73.49477567980367, 76.33010018256404, 44.8628854751587, 1.3191430991695774, 1.483724525859279, 1.8894890623707927, 0.6109594097060542, 0.27849107079448243, 16.4449615440061, 80.00524336291899, 75.19437789916992, 67.44596312122961, 56.741567811658314, 29.375059720008608, 16.899359303136027, 34.22423301204559, 51.49089090285763, 61.399386313653764, 65.56392362040859, 44.29114903173139, 0.5451438768256096, 0.10043638683254681, 0.00634492835923729, 0.10582193131408385, 0.012639418447149858, 0.05285701774541409, 0.09925402971285005, 0.05078154000183267, 0.06789512451617949, 0.05036721283930445, 0.12204698407121244, 0.11763090087521462, 0.167920037863716, 0.25551177320941804, 0.21961902178102927, 0.2714640220567104, 0.17263153988507488, 0.24955288086447025, 0.2622637657388564, 0.478069722772606, 5.3431624750937186, 98.63376386703985, 89.0382343722928, 85.3150970705094, 44.340586585383264, 65.32097593430551, 129.5887327194214, 72.27217289709276, 61.64233792212702, 98.1794749536822, 65.43176327982258, 0.7608497214894142, 0.2291902025500613, 3.426459518171126, 2.8922341715904976, 3.0532040759440395, 44.60451895190824, 90.38968701516428, 90.5509356529482, 74.8299426417197, 82.34447433102517, 89.41131453360282, 89.82875670156172, 84.23051464942195, 86.42512782927483, 83.86935849343577, 79.79509061382663, 76.87644712386593, 72.05205732776274, 63.93189599437099, 61.76895203128938, 60.0523228030051, 65.11227838454708, 64.34388606779038, 64.6839084932881, 65.32448253323956, 59.289123704356534, 58.989376175788145, 58.56090430290469, 61.385834524708415, 58.83911017448672, 54.29633871201546, 58.963045304821385, 58.648235874791304, 57.392708716853974, 55.58558648632419, 53.734192463659475, 52.635940582521506, 59.20186273513302, 55.89944670277258, 49.09851181891657, 53.18054991383707, 52.090103549342004, 50.93219241788311, 53.778460333424235, 58.92625347260506, 68.64988757717994, 66.12434402588876, 69.84674392207977, 66.49209760850476, 65.65019615234868, 69.94427757878458, 68.85785164371615, 70.26969309776061, 69.39513790992, 64.8714291664862, 68.64759691299932, 68.9419315707299, 69.50607038313343, 67.34601328449865, 59.854737327944854, 67.84126743193596, 69.29768270061862, 73.57261903824346, 69.55432338099327, 63.11916128281624, 40.983473100969874, 36.71289843897666, 30.477204553542602, 42.41085106326688, 69.42366138581308, 61.11773267869027, 66.34599716432633, 60.929023527329974, 62.2402326522335, 61.20910821422454, 64.0208004366967, 66.4595184018535, 66.15438153666835, 65.97828280541205, 64.71005501285677, 61.05464527683874, 60.909713698971665, 61.22000848093341, 67.31213969569053, 54.93399843092888, 50.173484433081846, 68.71350057663457, 61.57383764943769, 54.037003363332445, 49.08484235886605, 47.62916841814595, 45.45966232976606, 49.949528863353116, 47.1035433584644, 50.69267288331063, 49.563375442258774, 51.88864277255151, 50.75658790526852, 53.08051378496232, 49.42408423269949, 50.204043619094364, 59.12800058241814, 54.95333179350823, 56.977969061943796, 57.50084846250473, 62.30442224010345, 64.00878229448873, 70.16948438459828, 75.19147534524241, 66.88775493252662, 70.24406433105469, 69.97648808263963, 70.65211634482108, 72.40033242010301, 72.66372742191439, 70.89808817832701, 68.76683696623772, 73.00908427084647, 73.16675570703322, 74.58649681460473, 69.90842711540961, 75.86791946041969, 72.2609313841789, 73.77815123527282, 75.3705080093876, 77.38531974054153, 81.51311228352209, 47.305510121007124, 1.9042035889241005, 4.928183555603027, 4.184520311893956, 0.9750216742677074, 0.3873424814833749, 22.993859629477225, 89.61556019321566, 83.83895227985998, 77.48125307021603, 79.86100996694258, 67.23785000462686, 21.515131958069343, 33.08311746966454, 60.57238594178231, 72.87604531934186, 75.75533174699353, 52.05506109422254, 0.7700150748414378, 0.1885921850560173, 0.14699494376057579, 0.2578953791770243, 0.08281014394015074, 0.18570594880129063, 0.19158538250673204, 0.14258995351772155, 0.15426073613907063, 0.30089479120027635], [0.06285650295115287, 0.046964468614708994, 0.03837027594507222, 0.06967344441481176, 0.04829119883417603, 0.04469846863479865, 0.04593400757819895, 0.026097895968104565, 0.15552493443171825, 0.4289325675176036, 15.5643335465462, 79.35510266211726, 61.29990716134349, 59.69808570800289, 31.180952287489372, 37.88963694726267, 46.214514624687936, 41.83854195379442, 56.459600387081025, 91.42600074891122, 23.945609023494107, 0.23125600460315907, 0.04673726225812589, 1.685191553927237, 0.37442887442246564, 6.32814464069182, 53.45885776704358, 83.61008982504569, 81.43923051895635, 77.75258694925617, 85.77905854871197, 77.61253479988345, 78.17417114011704, 75.52163693212694, 76.5891178192631, 74.79046790830552, 75.87949045242803, 63.56585256515011, 56.22652138433149, 54.63631014670096, 58.216488822813965, 60.850560434402965, 67.0944324616463, 67.56462266368251, 66.27729292838805, 66.14701532548474, 63.986083538301536, 57.102088543676565, 51.276690267747455, 52.83276119539815, 53.36087696013912, 52.322896219068966, 51.32996389942785, 53.25200765363632, 51.62198828112695, 47.71963004143008, 48.84180053587883, 50.0165190235261, 53.99075469663067, 48.19193047861899, 46.5533995628357, 46.52869647549045, 47.43358335187359, 41.592574042658654, 44.37018086833339, 52.021764093829745, 62.850788793256214, 64.37648488629249, 69.01302060773297, 62.8209238667642, 62.61699984150549, 61.20003577201598, 64.49496399971747, 64.2749111883102, 65.15915463047644, 60.026709725779874, 62.060093879699714, 62.34695642225204, 67.59026711986911, 49.61595873678885, 40.37883581653718, 63.779692342204434, 62.558317261357466, 63.022388565924864, 67.53414584744361, 52.47599809400497, 32.055389804224816, 44.24003662601594, 34.75035229036885, 27.962884864499493, 57.50312735957485, 62.76197848781463, 61.14839384632727, 59.83816923633699, 59.187393111567346, 59.24808394524359, 56.764419540282226, 57.63057301121374, 60.19892138819541, 60.76111862736364, 57.92442521741314, 59.8178082127725, 57.26753803991503, 62.40444267949751, 49.04860358084402, 50.738317505005874, 65.18436762594408, 58.144164239206624, 57.72199561519008, 46.573054559769176, 45.258268233268495, 41.622074188724646, 40.2435964153659, 43.08791883530156, 42.10574557704311, 42.972110855963926, 42.209319683813284, 45.47332002270607, 48.36607194715931, 45.2403586910617, 44.42332113942793, 45.335107464944166, 47.67149471467542, 50.33905944516582, 51.04129314422608, 53.457022097802934, 57.984045244032345, 64.31800234702327, 62.04756582936933, 67.90770453791465, 64.71321644321566, 64.42119598388672, 64.7342481920796, 67.49254518939604, 65.33120939808508, 66.29942294090026, 64.86170953319919, 65.69663309281873, 66.54905826814714, 67.00920720254221, 64.84972276995259, 64.70025693216633, 68.92846215155818, 69.26858655868038, 67.20912256548482, 65.06886166910972, 69.43783683161583, 72.73101960459064, 59.343032760004846, 4.99877150981657, 2.064994780286666, 0.778280305525949, 0.3295578483131624, 0.057039762050994945, 0.8253335484093236, 59.26919806388117, 68.6433058400308, 63.52523642201578, 46.93525014385101, 60.85790311136554, 27.87197412983064, 6.389939131275301, 20.080852585454142, 52.97805363132108, 55.15339620651738, 63.39197389541134, 4.101489128605012, 0.2365018223081866, 0.08723887524777844, 0.01628772066455455, 0.048621846212735104, 0.049209803372861884, 0.09905350619866964, 0.04955086188631193, 0.022595673311321486, 0.052485143345209866, 0.07198611064062965, 0.02827626123513666, 0.03140465788272841, 0.07820525071433476, 0.04840038168514448, 0.015663333150798518, 0.04033861246200339, 0.08690889053527387, 0.1720441189864951, 0.4959684784614271, 18.42843059570559, 93.46007916235155, 67.79637982768398, 70.03665724108296, 33.75898891879667, 52.71853000886979, 47.08422176299557, 42.89434986729776, 66.66957701406172, 97.37032921083512, 25.15121617624837, 0.378547853399669, 0.18796154147674962, 1.036513529477581, 1.5660479664802553, 7.9711240145467945, 58.60691762739613, 84.40993955058437, 84.8399019241333, 79.04504714473602, 87.24474630048199, 81.05418712862077, 82.3831489009242, 78.70195742576354, 78.5072745046308, 79.14764850370346, 76.09007466223933, 67.604764200026, 58.88885367301203, 56.492975834877264, 61.595351849832845, 65.25209911407964, 71.52775410682925, 70.71891430885562, 70.70811994614141, 68.27705844756096, 65.91000218545237, 60.24873156701366, 54.003486710210005, 54.34565467219199, 57.39352849221999, 55.002396721993726, 53.80400280798636, 53.791278639147365, 53.95530431501327, 51.22031011889058, 54.326639021596606, 52.51245652475665, 57.086061739152484, 51.7387572411568, 50.5363860437947, 48.895835107372655, 49.0404881969575, 44.52301209972751, 48.69703369755899, 55.027676397754306, 66.59643265508836, 68.67495152258104, 71.99609295014413, 63.40460784973637, 66.10667767063265, 63.540847455301595, 65.33128784548852, 65.31332339009931, 67.42793590791764, 61.80917201503631, 66.64411298690304, 66.06060551058862, 69.89472235402754, 51.98321503977622, 43.64791170243294, 64.1447473341419, 66.45207374326645, 65.29037752459126, 69.09092672409551, 54.31772347419493, 36.466236268320394, 45.866012034877656, 38.48211880653135, 30.472676177178663, 59.6410858246588, 65.31067186786284, 63.27013723311886, 62.74656357303743, 62.36257137790803, 60.25727056687879, 60.258094264614975, 62.256804666211536, 61.05479824927546, 63.66333523104268, 60.21340670124177, 63.174745190528135, 59.83652576323479, 64.08773568368727, 51.03252272452078, 52.25196799924297, 68.93596956806799, 60.65013908570813, 60.61415526174731, 48.96476684078094, 47.89906670970302, 44.07866639475669, 42.639066327002745, 44.33912354130899, 45.45563405559909, 44.30238662227508, 45.91302164139287, 48.219418448786584, 50.06682734335623, 48.42324049242082, 47.75300156685614, 48.2587480545044, 51.168079837676025, 53.21464707774501, 53.19154431743007, 55.25420896468624, 62.01184480421005, 66.08270414413946, 64.96735857379052, 71.66193839042418, 66.70683953069872, 69.92742707652431, 68.08670582309847, 69.20958626654841, 69.09098163727792, 69.56806736607706, 66.61784095148887, 66.70144234934162, 70.13699931483116, 69.42386534906203, 67.3949017063264, 68.38672007283857, 72.04949209767004, 70.95380936899494, 69.6275697215911, 68.27756835568336, 71.83465603859194, 75.16270868239864, 63.339853440561605, 6.379815984156824, 1.8560004787098978, 3.6504033207893376, 1.1654712548179011, 0.1506417827500451, 0.7771654330915021, 59.617284882453184, 75.98830484574842, 69.78302894100067, 55.207101298916726, 53.3915263606656, 28.947533138336677, 18.421576253829464, 31.094869990502637, 59.96699556227654, 63.054206832762695, 72.51235531222436, 5.963811364866072, 0.3897393560938297, 0.08286979154593523, 0.045583959022957476, 0.024991517533518137, 0.040279964600960096, 0.06154337079234182, 0.030051978350046183, 0.03551724577142346, 0.09658530114158508, 0.18128894629978365, 0.13772039223582516, 0.20230332028961953, 0.23778400834529634, 0.10847527683982927, 0.16328393421586485, 0.21025180426095763, 0.24329962689549695, 0.3044453022941467, 0.6303731195868985, 23.87483769847501, 107.45236596753521, 75.82181592141428, 80.76328062242078, 44.06957434069726, 48.955788535456506, 54.853978157043464, 59.83151689652474, 73.79642163553547, 105.79064599929318, 30.446998380845596, 0.4036594188261417, 0.4604383317693588, 5.138824639781829, 2.1416577504527186, 10.54240926619499, 62.545444042451926, 89.3590764076479, 88.26020871439289, 81.15360352300829, 90.6925489056495, 85.3907831253544, 85.84333050635554, 82.31630386844759, 81.9455300607989, 82.90036047658613, 81.4142999341411, 69.64121956979075, 62.6757255677254, 60.7948588555859, 64.54772380090529, 68.12842415225121, 74.10159772442233, 73.65141161026494, 75.91010062925278, 73.24189263005411, 67.45776945544829, 63.95355924483269, 55.745544664321415, 56.9941488389046, 59.08064580732777, 58.13120865052747, 56.33650856633341, 57.501707461572465, 55.912437592783284, 52.74511191152757, 56.47864741663779, 56.7259410888918, 60.93211827739593, 53.386317453076764, 50.32915546048073, 52.3827947339704, 53.65289349709788, 48.0471008823764, 49.26905647400887, 57.884405274544996, 70.06363530312815, 70.20615854570943, 74.89855274077385, 67.7407527739002, 68.47423599612328, 66.89902782440186, 69.4511728902017, 69.40839552110242, 69.47423642681491, 64.61753806760235, 68.87096804957237, 69.22648383725074, 71.780778361905, 55.31979883870771, 45.926498905304946, 67.88325248226043, 70.18799012707126, 69.36035433123189, 72.14505672454834, 58.64819272871941, 41.40148401260376, 47.16621106670749, 40.21840303174911, 35.651912996845866, 61.779550275494984, 66.35763875899777, 64.597271180922, 66.23347220882293, 65.64934107565111, 62.52227852421423, 61.42084167849634, 63.58613906368133, 65.38700511378627, 68.30362073836788, 64.93393997992239, 66.85414806489023, 62.973056916267645, 67.3267073785105, 51.686507348091375, 54.230474272081935, 68.94367310308641, 62.89943402813327, 63.18812439518591, 52.246719867952415, 49.9779385905112, 45.304014836588216, 44.713619678251206, 47.60805822187855, 48.549929126616455, 48.176315522963, 47.63123158485659, 52.33219223637735, 54.16000889193628, 51.47824125905191, 51.14054479906636, 51.44387345160208, 51.885767675215206, 56.265913747972064, 55.8060589913399, 56.1500390883415, 64.02055332737585, 70.8215235125634, 66.95005786034369, 73.27196936453544, 68.21172744997087, 71.86754119011664, 71.00060324515067, 72.51611294284945, 71.9187359656057, 74.89926661214521, 72.1292652622346, 70.39071390705725, 73.60923044143185, 72.157318053707, 71.87959855602634, 71.73884822476295, 75.8111313850649, 75.83432828226398, 72.65902057770761, 70.24718653771185, 76.02548891498198, 78.17051549111643, 67.95025440954393, 6.722440411967616, 4.907860775147715, 8.236577280106085, 2.1889811465817113, 0.17884016157157961, 1.2935057522789126, 71.43892026716664, 80.83159262134184, 79.11437111516153, 63.72760326631608, 79.51053050256546, 39.53184312389743, 14.64082717895508, 34.13541093949349, 74.37659509720342, 70.48279546922254, 87.51227548045497, 8.041075564199879, 0.4937034016174655, 0.1529935194600013, 0.11450525448327104, 0.2001415733848849, 0.20714766195704862, 0.28995882479413865, 0.2195315651835934, 0.1225781664552708, 0.20728771815136557], [0.0197858945466578, 0.033327777975148735, 0.03094784348391958, 0.05633403036382891, 0.06317993378146522, 0.06487785658288388, 0.06987475699955417, 0.08161931388801144, 0.08603094611316921, 0.05415452554100945, 37.09787122664913, 76.67793596944502, 67.58013956008419, 44.63493693259455, 23.99678222594723, 8.545402153845757, 39.27956411915441, 52.82031551484139, 63.70555170120732, 83.55392932891846, 5.823601340093921, 0.021492027895404928, 0.29312531133332564, 1.038768769752595, 0.885856700760703, 15.855319480742178, 67.94257440874654, 82.76325010484265, 78.64253351765295, 77.16525123965356, 81.33129473655455, 78.81554142121347, 74.87847805023193, 76.62576844615322, 74.2197552034932, 69.83532198013799, 60.94563476500973, 53.00185065115652, 58.03227863004131, 61.97914792645363, 68.85971869191816, 70.7371219511955, 71.84105734671317, 70.54472184950306, 76.73775995931318, 73.45399871949228, 71.42090089859502, 67.49425534279116, 59.546968552374075, 52.55640276016728, 52.64720955202657, 52.937653218546224, 52.580015428604625, 55.08645311478646, 52.63265755868728, 49.37305419675766, 49.119790677101385, 49.38513509688839, 51.923085105034616, 50.248456616555494, 47.84287483461442, 45.62970884384648, 44.889796856910955, 42.58112899718746, 44.095014833634906, 52.73997360660184, 64.40097224327826, 64.6102071577503, 64.56624131048879, 65.07857738002654, 64.13092490165465, 67.04150399854107, 65.7495419440731, 63.43548867010302, 65.18271238573136, 62.20897136196014, 69.21861556268507, 63.751945495605476, 67.27224134629773, 60.44189260851953, 66.46588833101335, 61.51060511988979, 65.57223512280372, 56.51019111756356, 70.27397632598877, 45.95799946015882, 36.621911218089444, 45.86239953194895, 44.71745967864991, 30.379478700699348, 53.24802644791142, 65.62428105262019, 62.42172072010656, 60.596100591844134, 58.761992454528816, 60.60304710941931, 54.14733571390952, 56.43682318349039, 55.355927790364916, 57.05833450440438, 57.30753052619196, 57.65107916247461, 58.86184423200546, 53.93975603965021, 48.56007237588206, 63.87167584511542, 56.938251141578924, 59.27035908545218, 53.92767513951948, 47.6690746122791, 46.39825021066974, 42.30769272773497, 38.856363911782545, 40.753794793159734, 41.61475896835327, 44.96381198206256, 44.14355808688749, 45.325623173867505, 47.32123098065777, 49.41127377171671, 46.13923649634085, 44.19967151457264, 46.980071067810066, 50.60261526415425, 48.24315663306944, 54.949181925865915, 58.09735075120003, 64.85184477221581, 60.38520651478922, 61.373569273179584, 67.2923787947624, 60.92557184157833, 66.24651016727572, 64.31417803610525, 65.42163964240783, 67.8095668362033, 65.63221600747877, 64.6487875907652, 62.057540416717536, 67.84727650303995, 65.90025901794434, 66.15759788020965, 66.2042897747409, 67.97321596453267, 67.2319507598877, 72.31213400440832, 71.87091442846483, 71.11321449279785, 66.95710243717318, 17.124066006752752, 0.6330839676722404, 0.6830377420110088, 1.817929463521127, 0.15766169154836288, 0.13930861507692646, 23.449756714605517, 74.09090534333261, 69.26197344256987, 58.981974663272986, 46.8411446386768, 40.68147413192257, 22.19320385686813, 15.206640843422184, 39.23185240837836, 51.23234002820907, 63.706234193617306, 22.14198554715803, 0.4205352019879126, 0.09705698913744382, 0.02606474925884076, 0.07589773259936802, 0.01795234545434435, 0.11077242212430125, 0.017849442609135183, 0.07410163180001321, 0.04139275710669257, 0.04297114337884611, 0.025714411505407868, 0.034952175488034566, 0.03515398219948815, 0.027207995674783186, 0.041377531109197487, 0.04874860312068655, 0.04449690707148083, 0.14098653149220253, 0.1351287167879843, 45.060588621324115, 86.31406199547553, 75.00787704221665, 57.42126357170844, 35.69034045742404, 17.396431469148208, 37.34317625722578, 62.66126378890007, 71.24983849063997, 91.08043209198983, 6.217382300284601, 0.07122900126682175, 0.6576137965725315, 1.5125522305888515, 0.9575687817508175, 17.8642015687881, 72.9584700061429, 85.17636283751457, 80.5003406155494, 78.95092595008113, 85.37673319539716, 82.05457195158928, 79.83805625669419, 80.55351226560532, 78.14525542720672, 71.44419977741858, 61.8865603785361, 58.18194450870637, 61.97128749662831, 66.60389300315612, 69.2402199775942, 73.27659776133876, 76.44280556709536, 73.8953124323199, 80.0246669400123, 76.77814468260735, 74.44001197814941, 69.60101527552452, 60.75747082310339, 57.617640956755615, 53.900889273612734, 55.638220771666504, 54.98397334929436, 55.313268092370805, 53.8249521870767, 51.666307141703946, 52.20717060950495, 51.70729591000465, 56.037341548550515, 52.100172273574344, 50.01108261846727, 47.777814480566214, 47.19238112049718, 45.351012675992905, 46.08094223083989, 54.67335301060831, 66.08483006877285, 67.2497740099507, 67.90625326095089, 69.52045763692549, 65.25558610116282, 68.5847056296564, 68.62781247785016, 65.42987269739952, 66.26446677792457, 65.22106532127627, 70.1672564783404, 66.89431313545474, 67.7057416977421, 63.55535238019882, 67.97004668943345, 64.62279012126308, 67.08743495325889, 59.272736041776604, 71.54305919524163, 48.61881379158267, 41.37047375402143, 47.450971218847464, 45.72820740361368, 35.42947538437382, 55.23067474365235, 65.43896475145894, 61.9746175889046, 64.1489246583754, 61.28258597466254, 62.95669671027892, 54.6194008088881, 58.34838636459843, 57.579119359293294, 61.27416464590258, 60.46399124207036, 60.12781666171167, 61.933334642840975, 54.44711069906912, 53.28566943445514, 66.26128181334465, 60.16477323347523, 62.14608792335757, 57.458082860515965, 49.50807394519929, 49.59816686568722, 45.29111808346164, 42.744695755743216, 43.12853890080606, 46.09757700274068, 48.12736042084233, 45.671023168871486, 47.98349965003229, 48.28346683133034, 51.1866718722928, 48.95434902560327, 47.1504549057253, 50.74248306212887, 52.57251977920533, 50.26400489191855, 59.15160148374496, 59.69828574888168, 69.42244545105966, 63.69738924887873, 67.38534681258663, 68.98297525221302, 62.31558530561386, 68.96582664981966, 65.97408586932768, 68.26569926354193, 70.14630317687988, 69.83307838439941, 68.1894483873921, 66.43195198428246, 70.03287607623686, 69.70564842224121, 71.14440518040811, 69.3658927179152, 70.60726011953047, 71.23709078757994, 75.4217420085784, 73.37750465639176, 74.95325411519697, 68.99484434435445, 21.682789748714818, 0.1668499356075641, 0.5317096976983933, 1.8325531626901321, 0.7519901904367632, 0.2318445593118668, 24.483732715729747, 81.26776802924373, 76.4428134118357, 65.2436464063583, 53.03434748803416, 38.934524982206284, 24.198886271445986, 25.233187829294515, 49.441177921910445, 59.673351241696274, 70.6864998417516, 29.246394211246123, 0.5504855934169985, 0.15001841700605809, 0.08652858916790256, 0.0628084922209382, 0.04062318731279623, 0.04911533324047924, 0.023096771422593344, 0.038922893469251936, 0.046695269148556456, 0.18195832328450295, 0.13841721048999217, 0.13525899770038743, 0.23455594365875568, 0.1652090978478232, 0.15990183989126838, 0.13557395176781764, 0.14827251794838137, 0.24993992380557523, 0.19081708824922963, 56.72726292763987, 100.9440791222357, 83.93079065507459, 64.03953367663969, 35.28177853553526, 14.829370610175596, 59.144905997860825, 76.59394233457505, 77.19204102793049, 101.92683681364983, 7.91681879951108, 0.18990861522334238, 1.5968943435338236, 5.81855619145978, 3.2074750623395367, 20.71462719671188, 77.22097243032148, 87.85434538318266, 82.98513858549057, 78.54357211820542, 87.32540592070549, 87.99444460099744, 84.44004766402706, 85.78649536255868, 80.13348917807303, 75.82723663699242, 66.98524936552971, 61.00166974529144, 66.70763184947353, 68.84270345011066, 73.33351919727941, 77.98932552337646, 79.70014572143555, 75.47014405650478, 80.38299114473405, 76.77180613240888, 78.13941109564998, 71.13077102168914, 65.35873266958421, 60.44982756337812, 55.68743082784838, 57.710636431171054, 58.979927186043035, 59.80631959053778, 58.05105109368601, 54.04348311885711, 55.49900800951066, 53.76741493901899, 57.56933304571337, 53.090578586824485, 54.22031925570581, 50.253124237060554, 50.953216322006725, 47.40859785387593, 49.782408437421246, 60.56754965935985, 65.8875976070281, 68.60403506986557, 70.45410725378221, 72.24845824703094, 69.18863296508789, 70.93182056180893, 71.24995616174513, 67.21613576335292, 69.47516995091593, 65.71398565846106, 73.0075074780372, 69.1524451778781, 69.68263195407006, 64.48228297695037, 68.54446211168843, 67.44726534812682, 69.42142563481485, 60.31553345341837, 75.19560952340403, 52.19943177315497, 42.26267176289713, 48.31175888738325, 48.00843415721771, 38.471132247678696, 59.93496940981958, 68.5902597058204, 67.87925950942501, 66.04560636704969, 64.8554023619621, 66.4800480873354, 57.298642435381495, 60.84932488779868, 59.34045184043146, 63.6396715717931, 64.33827707844397, 62.00407066652852, 64.12472363441222, 58.23696359511345, 55.21521668280325, 66.61125136959937, 60.50458385098366, 64.26185361800655, 61.13937239493094, 52.09032320207166, 51.111017196409165, 46.24569354518768, 46.397277462867, 46.27789228193222, 50.026368095028786, 51.10911876924577, 48.443691730499275, 51.065427487896336, 53.474970863711455, 56.426719157926506, 53.58244380643291, 49.330229759216316, 53.730073974978545, 53.746622454735544, 53.45589245519331, 62.14191452149422, 63.148786944727746, 71.87452300902336, 67.13861403926727, 69.09266825645201, 67.96208427798364, 65.41693279820105, 70.09011914653163, 68.36836338043213, 69.54201498339253, 72.67310188662621, 72.10328348221319, 69.83298424751528, 69.55238573012814, 75.46221302401635, 73.37382547317013, 72.93298244476318, 74.44887653473886, 74.82279608326574, 74.95823552531581, 78.09653958966656, 78.05908095452094, 76.59084366213891, 74.85306893625568, 24.428788154355942, 2.4809589501350158, 4.59028656444242, 3.6604342922087643, 0.823784028330157, 0.4476975235006502, 29.77254486853077, 88.5973128964824, 81.9271812131328, 73.83967753379576, 64.06309535426479, 54.86125807608328, 31.512931892948767, 26.48831686665935, 57.744153084293494, 69.74105958015689, 81.30584639887657, 38.793468706069454, 0.8051860488710866, 0.3276371433129234, 0.20749463849971372, 0.12350187696997197, 0.15284721198822224, 0.2368518632025488, 0.15174018429411998, 0.10533872901672318, 0.2571964618419447], [0.013198913525669806, 0.015331601757826585, 0.033041471765647014, 0.054626914507318894, 0.023169499979684913, 0.05429596835446935, 0.05727228122733294, 0.06540982037662499, 0.07508332750970319, 0.3852316641038464, 62.152783409241714, 70.4855489730835, 59.067945172709805, 41.19796791384297, 16.718457629603726, 32.07649607812205, 63.05553651625111, 49.355972274657226, 78.89215315541914, 59.67261383610388, 0.4673403243143713, 0.07151705032635121, 0.22833880307453297, 0.7127023211890652, 2.6394489359471107, 28.91376937589338, 75.84109044844105, 81.57647425128569, 76.34120833489203, 77.57858276367188, 81.8408263114191, 77.55424837912284, 72.94367482585292, 65.55362739870625, 61.82017034099948, 55.23215347720731, 59.22087054098807, 64.26853733678018, 68.94156286793371, 70.66873934961134, 74.07443923334922, 73.19668339144799, 71.2117052078247, 75.49884011668544, 88.0775204012471, 71.16612726642241, 70.39994716644287, 68.33897698310115, 66.26562779949558, 61.960740243234945, 52.26391161641767, 51.27680793885262, 52.942214935056626, 53.627566752895234, 51.593339289388354, 48.0562243153972, 48.93181893133348, 49.731190127711145, 50.819239924030924, 47.48435451138405, 48.79447713974984, 46.25364418952696, 45.659063862216094, 44.02769127199727, 43.91079287375174, 49.46573588155931, 59.63034245275683, 65.11909938627674, 62.71574551059354, 63.20306862554243, 64.31065182532033, 55.969484544569454, 62.47288019426408, 57.15902566909791, 59.03602100187733, 66.21338182880034, 65.70069666831725, 61.432616633753625, 62.56783293139551, 63.49885456023678, 63.72341809734222, 61.07504160173478, 61.19572116482643, 59.459291811912294, 69.63943881373253, 48.06568114988266, 41.20028211224464, 48.50198207363006, 44.40671382411834, 39.91532148853425, 56.96374654769898, 62.10798601950369, 61.81264723500898, 63.63730638257919, 60.4278701351535, 54.852318994460575, 57.55937414784586, 49.64456850482572, 56.09726359767299, 53.295047821537146, 52.421057455001346, 57.92491943605485, 54.21143900963568, 52.46887114740188, 65.8454321276757, 57.67054196326964, 58.76496168874926, 55.99796879676081, 51.51066357089628, 48.84757818714265, 43.91045947228709, 39.65354250323388, 40.80892762830181, 40.920020918692316, 42.58502391076858, 42.88796032628706, 41.174661190279075, 42.12835019634616, 49.37682359449325, 48.02815191207394, 44.42035582757766, 44.52438100691765, 47.194546268832305, 49.248793509698686, 49.55537772947743, 49.3104100227356, 58.091816286886896, 59.18725975098149, 65.71670386099046, 56.388530961928836, 67.25406508291921, 67.69093082797143, 61.74376257004277, 69.7055935090588, 63.793204907448064, 65.37270022976783, 64.83087578127461, 66.34770731772146, 65.7597283394106, 66.64288136266893, 66.04113486505324, 66.30283540295017, 69.99475063816195, 71.88300317333591, 71.45092271989392, 70.85604821482013, 69.46622694692304, 72.59191666879963, 65.09698114087506, 29.95128139372795, 0.2842375882450612, 1.5837031674961892, 1.020790892502954, 0.05274462881648252, 0.04306803051862986, 3.660750778452043, 66.89716862094018, 65.32745176746, 64.52475440117621, 49.67244871201054, 68.24502052799349, 40.494447677366196, 14.053555207867777, 26.577462534750662, 47.91147316655805, 58.397231640354285, 56.05503143802766, 1.6326569213021187, 0.0679078339148433, 0.07906287082380827, 0.041205701418221, 0.0037570608471850717, 0.004201346356797243, 0.05241568215311535, 0.0446968138848822, 0.014994618832133712, 0.03689476378983067, 0.028481588120602315, 0.07108800278435792, 0.021632421168408567, 0.06255387523842436, 0.02534484302985572, 0.06693132462040072, 0.05858986435698406, 0.11721325272153463, 0.5975955268067699, 72.47808948639901, 78.14731859391736, 67.13851205764279, 46.2189116016511, 26.771859122860818, 30.41124401553985, 57.136581866971916, 60.81722813267862, 85.52013504889705, 65.82681655883789, 0.2708598851196228, 0.049261184889943375, 1.1097734757969457, 1.5097564386744655, 2.638109936829536, 32.33279747347678, 75.75382555684736, 84.05067397702126, 78.39647539200323, 81.8371706624185, 83.87929777945243, 81.39079709206858, 75.51856179391184, 68.70277681658345, 64.3429486213192, 57.207592456571525, 60.72903363935409, 69.6016977679345, 73.15799313206827, 72.61808672258931, 76.84797071641492, 77.16976981009208, 71.69723187723469, 77.09813164126489, 84.29541418629309, 70.17576017687398, 72.87645324583977, 72.30456382997575, 70.03661801738124, 63.65773408643661, 54.85229546023954, 52.70067145747524, 53.000065972728116, 55.078184758463216, 54.06967670686784, 50.560214442591516, 52.77863248702019, 52.312682367140255, 53.46631811511133, 52.1461542191044, 53.27618122100831, 49.84202061930011, 47.23478194205992, 47.72974583410448, 46.401839179377404, 50.92384169178625, 59.04770182025049, 64.9937718145309, 65.38167853509226, 66.75641044493645, 67.25744616600775, 58.660783536972545, 62.34386167218609, 57.94036180742326, 62.562274932861335, 68.21019772560366, 68.75246540192636, 64.570434324203, 67.21561801049018, 65.51076765983336, 65.6383466720581, 61.78755975538685, 65.69768821039509, 62.88962810270248, 69.5795520659416, 51.14142340998496, 42.65832516454881, 51.13100951717746, 45.35492720142488, 42.02478393431633, 58.55607194285239, 64.84507083892822, 63.0844130054597, 64.24003739510813, 62.07686593455654, 55.70279867418351, 57.564281032931426, 51.8238805186364, 58.08751344680787, 54.15023434546686, 53.94930308864963, 58.73730897903443, 58.093812773304606, 56.535937555374645, 65.89115911914458, 61.327375519660215, 61.254458658156864, 58.643277998893495, 54.30995718125374, 51.9701966931743, 46.07860449821719, 42.561634817431056, 43.48008917224023, 44.029679913674634, 45.98459312992711, 44.72560644149781, 44.83379325559063, 45.25351432061965, 50.486975946734034, 48.58802318572999, 48.43170888962285, 46.61683605563256, 48.34624828830842, 52.17757632655483, 51.26406808053294, 50.92703057873634, 59.38491975107501, 62.78918796969999, 68.27496390188894, 60.02104582325105, 72.31389907098585, 68.84853993692707, 65.88609141688194, 70.91250681108045, 65.15801714312646, 67.53164337527367, 67.4081906964702, 69.62305899589293, 68.50166905310847, 68.8105635489187, 69.43828398181547, 69.40339057676255, 72.7701021009876, 71.77836218187886, 74.76599231843026, 71.75528295578496, 71.95090724575904, 74.41538733820762, 67.29567358570715, 35.76014295701058, 0.7385045302010352, 0.5194372755865897, 2.479754782492115, 1.6861314518797783, 0.10205415002400837, 2.952100081789878, 69.40867793175482, 72.69587516784668, 71.86473277307326, 56.72790227397796, 53.48232530778455, 23.1109364955656, 20.764166731988233, 34.87025130179621, 57.09689140319825, 66.9865123687252, 66.59446362526187, 2.1802997156496975, 0.341441526768669, 0.14524993336489125, 0.016571226822693023, 0.10615458967344416, 0.06896071451445741, 0.014495407212375393, 0.07106757121941737, 0.0325904949568212, 0.12196740285763819, 0.09440116914770297, 0.17713083555140804, 0.09093230770480248, 0.23701980499730957, 0.15159884107209023, 0.1336030986520552, 0.1962279979019396, 0.34963575642435785, 1.135887390663547, 88.5453022679975, 89.10580896562146, 74.76526275757821, 55.97792940755045, 26.489477888230358, 47.73000471053585, 85.48261365582867, 64.3871655002717, 95.62193270652526, 74.27808084795552, 0.8979281014011753, 0.1460176453955712, 1.6660027061739278, 4.248645670952336, 5.3358997164234045, 34.35556573252524, 81.18546885828819, 86.46927802793442, 82.48620525483163, 83.25211078889909, 88.28064426299065, 83.78669846442439, 78.84364128112793, 72.07104159939674, 67.56286544184532, 60.38286485979634, 64.23257312467022, 71.18619411222397, 76.48020928905856, 77.8981617958315, 81.83513887466924, 79.35784047649753, 73.99590553775911, 78.91060398470971, 87.12253309065296, 73.62980719535582, 75.9208086998232, 75.14558361422631, 71.87073399943691, 68.76975520964592, 57.68707475354595, 54.639989329922585, 57.55228250257431, 58.44790866298061, 55.895285068019746, 53.233027304372484, 55.61217231135215, 55.02407173956595, 55.69238478137601, 53.624479847569624, 56.44979838402041, 52.70239730035105, 51.20788797255486, 50.351787536374985, 51.001014324926565, 54.7980216241652, 63.75915873435236, 68.02128068862423, 68.88046803012972, 69.23299497173679, 68.28592300415039, 60.957174378056685, 66.46319758507514, 62.028648238028254, 64.7719225575847, 71.22146406481343, 72.17718878099996, 66.55599301861179, 67.9742044018161, 69.52929865929389, 68.04744289767358, 64.85157412867393, 68.60518824669623, 66.73977175066548, 73.40394143135318, 53.606044707759736, 46.43819170613443, 53.85415423300959, 45.35585288078555, 45.90428652301912, 60.57409217280727, 64.83137784465667, 67.96556734269666, 68.83297597208332, 65.04464103329566, 58.336795760739236, 61.23353673565773, 54.524581432342536, 58.64370161487211, 55.256021099705855, 56.50367606070734, 61.790195588142645, 60.49402483047978, 58.381738278173636, 68.42090745126048, 62.34251629921698, 64.42753453408518, 60.58470218412338, 58.37542718456638, 54.05647400886782, 50.59252692807106, 45.641860346640314, 46.5454371513859, 45.99413233418619, 47.804325780560895, 47.92089077734178, 46.975634867145175, 48.7677893330974, 54.635474681854255, 54.289094094307195, 51.439127383693574, 48.935145101239605, 53.143601186813854, 52.95340153478807, 54.73494991179436, 54.436728185223, 61.94773758611372, 67.51018801043111, 70.99191911758916, 65.91095139903408, 71.75902489692935, 69.61582614529517, 70.35327880613266, 74.11552213853406, 69.67153949122276, 70.8472385714131, 73.15149768706291, 72.61859663071172, 72.77361654466199, 71.73986019626741, 73.52285200549711, 72.44671836976083, 75.80465162954023, 76.16884370003977, 78.08317999685966, 75.68949868602138, 71.9199832793205, 79.0981246579078, 69.84382567867156, 40.302918341852006, 0.9706454736090476, 7.79856865444491, 7.185135945197075, 0.9231443450816217, 0.1592432953897984, 4.196848321345545, 81.03273960851854, 76.95633011479532, 79.74289171157345, 66.4854766476539, 87.77596858239944, 55.12131906324818, 26.70233511155652, 39.67758663239018, 69.06706302396714, 74.47765104232296, 79.14992347840341, 3.548802411363971, 0.4774599780719127, 0.19549912652902066, 0.14672711942224734, 0.2243584400463489, 0.08129697473299119, 0.08044159926113584, 0.1572616557560621, 0.1398852188140154], [0.058083223599580035, 0.03739609555791944, 0.05134365701627347, 0.025208138470207492, 0.08489955682307483, 0.03836434259409866, 0.05589358343352234, 0.1814537164905379, 0.18835672027161046, 4.446274292084479, 75.35367319660803, 63.1329248797509, 52.398472447549146, 36.33087919604394, 29.949467297523256, 32.387136028658965, 54.94903679816954, 55.38619279861451, 88.0629840973885, 30.37779796508051, 0.08389235804638556, 0.09367926151401575, 0.3379930892298299, 0.9276139471800098, 2.5642328300783714, 45.428389272382184, 79.65352442956741, 80.77261586343089, 74.69048669261318, 79.61030775500883, 78.63592824628277, 77.03230642503308, 68.9215587800549, 64.16666161629462, 65.41860765026462, 66.92730811334425, 68.9977861219837, 69.48685861402943, 75.6467056274414, 71.94424706120645, 73.65896609521681, 70.75291341350925, 64.74269305506061, 72.13998902228572, 56.33168797339163, 62.3295920894992, 73.14410794165828, 67.22990328265776, 71.8269681930542, 68.34122057883971, 56.20792542734454, 50.76931207410751, 50.95491863066151, 49.813406928893066, 49.91705948306669, 47.40419695454259, 48.324012371801565, 50.752281142819314, 53.304551724464666, 49.57942578100389, 47.58272755530573, 45.815790007191325, 43.37275743484498, 44.59685856296171, 43.809089737553755, 42.286798261827045, 50.66063496374315, 58.89861645237092, 65.38662464387956, 63.08350693794989, 62.23636519524359, 61.45575469540012, 46.59729480743409, 42.602960909566576, 61.393785169047696, 64.25223988871421, 62.11205351737238, 60.519316273350874, 62.41350727696573, 61.19677628240278, 64.05033980646442, 61.41782537583382, 58.48666168028309, 55.64298645142586, 66.66204606333088, 49.55340477728075, 42.79120722124654, 48.32809948152112, 44.956100602303785, 38.78752239288823, 53.72952876552459, 60.85920141589258, 56.96335431068175, 58.51087839372697, 60.22141225876347, 44.657404268941576, 37.80050500746697, 43.76289990640456, 50.21419863547049, 54.43140552889917, 50.5384688223562, 53.444470513251524, 56.26183840536303, 63.08281267842939, 58.422260284423835, 59.856161148317405, 55.29297374909925, 54.23416914478425, 51.9485059861214, 50.13034620592671, 43.03186424316899, 40.59147927068895, 40.72900149130052, 43.06375703504009, 42.04345833870673, 41.07365231360159, 41.60196027448101, 43.417244957339385, 46.33842622080157, 48.494145178025775, 45.35480168557937, 43.255776666825824, 46.08727293629801, 48.88999469818608, 47.07238404981552, 47.4704340196425, 48.55769149718746, 59.82848490438154, 62.43264059866629, 63.40564727783204, 55.08707284927369, 73.14795970916748, 65.52641399445073, 60.28735514610045, 62.53377499118928, 66.42569188148745, 65.33423354548793, 66.03644371032715, 67.42997554040724, 67.04097840093797, 66.39118286871141, 69.536084359692, 65.9087940954393, 66.12554427116149, 67.72253728681996, 74.55582387985723, 72.94131355900919, 70.48627068919521, 64.40882090599307, 69.26300894829535, 7.717214774700904, 1.8228021504417544, 0.11799418742978766, 1.7649421648633097, 0.42281958424756605, 0.20798220749824278, 36.912668674222886, 75.16765871355611, 67.89369383165914, 54.19538082615022, 64.74725084920084, 48.53231376217258, 15.009250506278008, 27.244302726561024, 38.63586002780546, 51.10189768575853, 70.69079875946045, 9.819318363743445, 0.5609866363867637, 0.13017660187136743, 0.03181170337953635, 0.028984088172775604, 0.035108564676897186, 0.05300308006905741, 0.09130696300417186, 0.08587489400299327, 0.05069216818458611, 0.041250506070472544, 0.06986827589571476, 0.1081705806897052, 0.03132980151642715, 0.031735230567714864, 0.12938943120741075, 0.24856162437748527, 0.5216629142242094, 5.79704346195344, 87.23392840354674, 70.43946112355879, 64.10186798341813, 48.724631494091405, 38.67859032846267, 27.020455022012037, 62.73975433841829, 62.93468436887188, 96.62969158541773, 32.08490367858641, 0.07218222148836621, 0.1901091004331266, 2.4562565982341766, 1.2963057117116068, 4.125085126969123, 52.053566671186886, 81.59488585687454, 83.00143211118638, 77.17653982100948, 82.96780170932894, 81.98320050393382, 81.49127252640264, 72.65460398889357, 68.13081679805633, 68.34896333755987, 71.68744164128458, 72.60795131806405, 73.30261092032157, 77.37912239566927, 74.79639853200605, 75.84753882500434, 70.87821745103406, 66.52473172833844, 73.62613585687453, 62.087142544408, 65.9624207404352, 73.49587394345191, 70.64114939781928, 72.36567435726043, 70.88230456075361, 60.32435486393591, 53.27609100649434, 53.118070479362245, 51.557684944522, 52.944533055828465, 49.197308478816865, 50.819773366374356, 52.77136433509089, 53.00234094742806, 52.851466978749926, 49.94584968013149, 47.39990195920391, 46.556153066696666, 48.53362775618031, 45.2107330291502, 46.17510657156668, 53.31723274723176, 59.842221044724994, 69.22855484870173, 64.10132669633435, 64.81543733227637, 64.88707942347374, 47.63120805063556, 48.67498213245023, 65.21720963139688, 64.69709157943726, 64.72937268595543, 61.3673758506775, 62.814471567830736, 63.89076209837391, 63.93041333844585, 63.30208886054255, 61.10173333075739, 59.49436172362297, 66.33079405753844, 52.31222344983009, 43.75449818949546, 46.97032790030203, 45.80768639041532, 42.20365970365463, 54.956763867409, 61.33566348783432, 60.96590165169009, 59.11846530052924, 62.025004356138176, 47.956305857627626, 39.83315960053475, 47.070073773784024, 50.374266639832534, 56.57658115510018, 53.40498401272682, 52.93148725263534, 60.6251928114122, 63.49745819645544, 59.48626987395748, 61.87429512700727, 56.75230333881994, 57.279889583587654, 54.96105886274769, 52.49128357056649, 45.40959719688662, 42.30123258406117, 43.45592344960859, 45.51788991497409, 43.38106893724011, 43.311113465216856, 43.532056654653246, 46.08240135254399, 48.773229660526404, 50.70011754189768, 47.74355649948121, 45.80843164074806, 48.97915801694317, 48.97017186687839, 49.77537562770229, 50.70530683763566, 52.10070179354761, 62.85147520803637, 66.12386549672773, 68.47252584272816, 59.4567265818196, 75.62147694249308, 67.89283875496157, 62.41806899347613, 66.30511822239046, 69.96999263763428, 68.90018186261578, 70.25164235022761, 69.74934362596082, 71.15921605017878, 69.59971304862731, 70.20753137526974, 66.37706233609107, 68.47785242142217, 71.91304852885585, 79.50873405702653, 74.98130690666937, 72.32902373037031, 68.17556319698211, 73.47159447208529, 12.053538657003834, 0.5418563177508693, 0.6626286081248715, 2.0108967154256763, 0.7102629133770544, 0.2008136010338222, 38.74742792498681, 81.28071185081237, 74.4627695698892, 59.84218182102327, 60.89853494398056, 40.122532459997366, 18.10065577107091, 35.41398594456334, 47.57545548100626, 57.6825051922952, 81.30807430513444, 12.270289813318561, 0.7046979281210131, 0.09461038009894472, 0.09151890122842404, 0.034959606540900086, 0.06120627678389992, 0.008170794068475165, 0.03280899089370524, 0.03703520685854939, 0.21389727961392174, 0.1300300339296941, 0.1431849740085102, 0.12731170116533197, 0.20008993905878839, 0.11693178435727475, 0.24867362643201507, 0.4535193933594612, 1.227105663668725, 8.086818245149429, 99.42077175263437, 79.46543109032416, 71.92287014376733, 51.56520020577216, 42.97562922200849, 44.76007623057212, 77.10781205085017, 69.5654550675423, 106.13636370628112, 38.90142410032211, 0.2519872937832148, 0.2764038795665387, 4.2041645223094575, 3.3918848056947035, 4.395988525882844, 54.691941122854914, 84.02424504680019, 86.26049026366204, 79.1420316696167, 83.87241794217019, 86.36357799653085, 85.22356464016823, 76.54980782539614, 70.57473582606163, 70.75131308647894, 73.39410412696101, 75.02486090506278, 78.5426542835851, 82.08153432415378, 75.72669844473563, 76.39837295778337, 72.87502550309705, 67.19310360570108, 77.24373002206126, 68.25575997752529, 68.90319424290811, 78.5717974939654, 72.27065101746591, 76.28738557138752, 73.68095490240282, 63.37788866412256, 56.79184867489723, 55.372150713397616, 55.45144142643098, 55.79983811224661, 52.900155359698886, 54.791239846137266, 56.14771704519949, 56.78240360752229, 54.72941936985139, 53.27437693072904, 49.638073059820364, 48.380510191763605, 50.37589050108387, 47.99115611660866, 48.840957226291785, 57.148764748727125, 63.69977012757332, 71.99698725054341, 65.38563228422596, 66.72061489474389, 64.56519403765279, 49.97226292087186, 50.69300628477528, 66.64725872778124, 70.12877018220964, 66.93348192399549, 64.22493234757455, 67.95268627905077, 67.37401116278865, 66.64724303830054, 66.40620554647138, 63.98475385481312, 61.663687382974935, 70.32604971239644, 56.53480006802467, 45.53529347142866, 50.63166433765043, 48.064539740162516, 42.46284207990093, 59.46590492802282, 65.76991081237793, 62.949146147697206, 63.872342648044715, 65.82928765204646, 49.53950781976023, 42.795380623109885, 52.58696586854997, 53.06843288483159, 57.28797751088297, 54.8209321883417, 54.61410953152565, 61.47616278740668, 64.69065104761432, 63.734722368178836, 66.11212976517217, 58.90861849631033, 58.80955903760849, 57.447492461050714, 55.269035523937596, 48.738120525114, 45.944067201306744, 46.94635045143866, 48.83768596956807, 48.050317225917695, 46.10081688050301, 47.3583758261896, 48.873403072357185, 53.15787469187091, 54.15512554107174, 50.62160738052861, 48.02203301460513, 50.68409858211395, 51.66030983771048, 53.224700112496656, 52.86856851270122, 54.525514956443544, 67.08916864087506, 68.68500847970286, 70.52096013099917, 62.851875289793945, 76.04459085772115, 66.6344404220581, 65.48007119086482, 67.4492657569147, 73.10355063407653, 70.9478630558137, 72.79983366689375, 74.40079612116661, 74.57516900954708, 72.49184131622314, 73.50506797913583, 70.85730337327527, 74.07606309460056, 74.32580040347192, 84.49224656628024, 80.43048320278045, 76.69215848368984, 67.36191457317722, 70.66862167850618, 10.997160038640423, 4.241526078793311, 5.199537046494023, 3.8942254502927107, 0.8146967546593759, 0.2964697754190814, 46.56171106523084, 88.35338069546609, 81.3039009032711, 66.67971241858699, 84.69891625065958, 65.596847995635, 25.81990380440989, 42.61807772421068, 56.06590424814532, 67.23974058704992, 93.65553086803806, 16.990462233943326, 0.9007459566477807, 0.335725131895273, 0.1389869041140041, 0.16586361272681147, 0.18521701616625633, 0.11163777972180998, 0.32238325104117393, 0.18682241469862002], [0.04447449133881638, 0.017643493277231054, 0.11364070893896204, 0.07662132562648866, 0.057916499884618874, 0.024848416139702165, 0.12981136179258748, 0.1859293553617693, 0.5993245566083539, 14.99680776749888, 81.04685229639854, 53.20452344033026, 44.034488739505896, 24.446425091835764, 33.894832364974484, 47.20191248001591, 45.91621445071313, 60.43564427283503, 85.74498099665489, 13.87719956136519, 0.32138307729075033, 0.15931048130075778, 1.376505924328681, 0.6994497968304543, 10.041540245856009, 65.76997749267086, 77.96009602085238, 83.97888675812753, 75.03971099853516, 77.40711242921891, 78.93358907391949, 76.8895870639432, 74.45923943673411, 75.95600804974957, 73.37991299167757, 75.08571255591609, 74.66549334987518, 82.97840779827487, 76.57211826693627, 76.8745957651446, 69.41301607316541, 67.75056654407133, 70.74242499566847, 69.3078730183263, 73.41782662176317, 74.7424816316174, 69.74386799720027, 69.2699593882407, 68.57076552606398, 69.3672969264369, 62.67196793710033, 53.288473929128344, 50.14306253002536, 51.99066754310362, 47.49198744373937, 46.68479896360829, 45.33174207133632, 49.000409418536776, 50.149703102727095, 49.49358470978276, 46.12097786318871, 46.15358452643118, 43.86557971277545, 43.55367283667288, 42.53055003381545, 41.28052988360005, 46.330542256755216, 50.300675130659535, 55.800383321700565, 63.72875644314674, 60.900645179133264, 64.45394777482556, 60.8479481358682, 65.34682435374107, 61.73716906578311, 60.2551289527647, 61.97623752778577, 55.515791831478, 55.47526590285763, 55.8932807368617, 61.39671910193659, 57.685054732907204, 53.47740665558846, 58.57584853326121, 63.9597918910365, 52.50017166137696, 46.52519772129674, 51.731273358868016, 42.666181672003965, 43.523768686479144, 48.39986708856399, 65.11804819107056, 53.7865404159792, 58.76776226105229, 58.44510809067757, 60.16595778926727, 49.496373514975275, 54.921062454100586, 59.76139276258407, 61.17470510544316, 60.35171339588781, 58.387657134763664, 55.771075371773016, 59.495232489801225, 57.15428352355958, 55.87272751715876, 53.575042293917754, 53.47272334560272, 48.72472170860537, 46.14610456651258, 37.92280450943978, 39.91062248906782, 43.44551740154144, 41.979460946975216, 38.49824367030975, 41.60352530017976, 39.64881604717624, 45.71707963943482, 44.71432570488223, 46.88354153786936, 45.733906607474054, 45.98722504031274, 43.701554036909535, 47.254860554972005, 47.24281495617282, 49.02492030974358, 48.278069649973226, 50.57007528120472, 59.409175688220614, 63.43369614693427, 60.61682639583465, 54.37391534928353, 72.46703624725342, 70.1468836876654, 64.93852130828365, 62.87249911215998, 64.91197470695742, 65.81794415750812, 66.3862406822943, 65.02893586312571, 63.10946910612045, 62.90258369138164, 70.12493410418111, 71.97437870887019, 75.33775621844877, 69.92317522725752, 67.76908013128465, 65.11419250119117, 67.19374687440934, 59.839848010770744, 59.69988999828216, 1.8623261586312327, 0.868466750027672, 4.777979331631815, 1.0269916081620802, 0.07118716520527679, 7.136740271122226, 69.29812200607793, 65.80560438094601, 63.05016679148521, 51.24758628106887, 52.09107629714474, 26.220203253530688, 19.285915628556285, 43.8769075178331, 47.81225289067915, 70.10464760564989, 25.539734786556615, 0.44265350867663666, 0.006727186123645234, 0.07213323016560848, 0.11858854908496143, 0.05615115751542392, 0.09489922588991542, 0.041226439418331276, 0.02555903929826473, 0.022744305859950763, 0.025434950291509592, 0.15573338695591496, 0.07771425730278415, 0.09004767533511886, 0.09727939212274167, 0.18353955940373484, 0.2526139690270347, 0.6223442117052694, 17.64181298594321, 93.53015622785016, 61.643769587239916, 52.48548238508163, 34.615261939264116, 28.029539662022746, 31.715235979326312, 57.5560244437187, 64.02638589182209, 95.74992748998827, 12.95898937409924, 0.0986781231157722, 0.32391760257943986, 2.1851904209583037, 1.3997142209160713, 11.919514209993425, 70.02205817930161, 81.25770322738155, 86.4746359855898, 76.52555188825055, 78.43815449745425, 81.45035436076503, 79.66453844501127, 80.9545510815036, 77.93295321925994, 76.24805988803988, 80.02722432536464, 79.5811253209268, 85.31880763269241, 79.54309401973602, 78.73522696956512, 71.20710034524241, 70.34478295233943, 75.28687523257348, 72.29994327791276, 74.44730758666992, 74.56528463671285, 71.35953149487896, 71.80017840477728, 71.5498919640818, 72.17211323399698, 62.19215223866125, 55.69226711027084, 52.26976379271477, 54.97104129483623, 50.78647636598157, 48.867182193263886, 48.70783198264338, 51.066372779107866, 52.185193569429465, 52.150684556653424, 49.39434482205299, 49.18771043900521, 44.98366309750465, 43.99133482287007, 46.11082284681259, 44.321755286185976, 49.114722974838756, 52.78148012776529, 58.002515685173776, 65.39574415453019, 64.40318838242563, 68.6591600602673, 65.96446821766516, 68.51566406988329, 63.34752167424848, 64.07884367050664, 63.23114102886569, 54.81718632482714, 57.906225419813595, 60.009910214331846, 64.95839988031696, 58.69170750341108, 56.86544410644039, 61.17071213260774, 66.91631763212143, 56.82331785078972, 46.94367931735131, 49.26716589158582, 45.550527957177934, 45.53338327715474, 49.423295836294855, 69.43390661670317, 56.82512214106899, 59.62377640508837, 60.90766229937154, 63.88622391608454, 54.62647676467896, 57.98893643963722, 61.16525219332788, 61.542435153838134, 64.48749188453921, 58.95601249510243, 57.325722479051166, 63.27065890835178, 59.294877821399325, 58.53753482141803, 56.44972778135731, 55.98111437213037, 50.82465279486872, 48.09960572950302, 40.725432134443714, 42.227805814435406, 43.5287618637085, 44.65873395242999, 43.1956349649737, 43.79192936804987, 43.58358483160696, 46.62703421808059, 47.674142314541726, 48.12164160513109, 48.64019855376213, 47.99689062180058, 45.832083532887125, 50.08634505733367, 49.313528307022594, 52.29121523518717, 51.73151262344853, 52.42891004008632, 61.44957304000855, 65.60672844609907, 65.01920054035803, 59.653880596160896, 73.48651516822078, 68.02259860500213, 65.76578447895666, 64.22008822041174, 66.32553808150753, 68.20432985982588, 69.14027014086324, 66.04778720486549, 65.67967276419363, 66.11787995984479, 73.44113334532707, 73.46104329632175, 75.41399924985825, 67.42971666397588, 67.97443189928609, 66.19576254198628, 68.4408252469955, 64.13310966184063, 67.90079332167103, 4.054015211520657, 0.1873675781872965, 1.420396756260626, 1.3367169110044357, 0.13556393133776803, 6.063238055475297, 74.09542391377111, 72.71471038941415, 70.64446772298506, 56.13214131324522, 49.477471613114886, 31.182615372442434, 33.360731063350556, 49.463782541213504, 53.41189130660027, 79.01032632397067, 32.21819170059697, 0.4794658107622978, 0.0790867880888043, 0.12787731154070747, 0.025854113384059844, 0.018823827924807707, 0.017673357299739317, 0.06284468221448122, 0.1344588954722689, 0.1920554847005875, 0.13148480425438575, 0.2814293244192677, 0.21059718734074026, 0.24958213010141928, 0.25174576158244766, 0.21300314775397702, 0.365984256589605, 0.8105815754782769, 22.730621522472752, 107.89330313282629, 68.75062188794537, 58.689597268258375, 35.12759408643169, 48.30887986767677, 66.7377007392145, 64.62781075508364, 73.03581914594098, 101.9862214980587, 16.600129527430383, 0.3520913746568465, 0.8689607235212481, 3.491067573908837, 4.610499028236636, 15.195398349915783, 73.54064387659874, 83.47974946421962, 86.93170193702944, 79.0896366488549, 82.00074134334442, 83.26534486586048, 84.08351990484422, 82.38493750172277, 82.42616945697416, 80.9606856684531, 82.80145399032101, 80.68531959287583, 85.16984385828819, 75.69584508096018, 79.34448872843097, 70.60086665614959, 74.35821487057594, 77.79199108000725, 76.1134284542453, 77.40777138740786, 81.81551133432697, 74.87315931627828, 74.86926832506734, 73.82547070903163, 73.94548739156416, 65.58743038485127, 58.50258650318269, 55.94663673831571, 58.17658655105099, 53.551437470220755, 52.66036125921434, 53.05762283263668, 53.932354527135054, 54.634549002493586, 53.25337656082646, 52.60221212140976, 52.93461338166268, 47.66878043451617, 47.97473315269717, 49.115079910524436, 48.075294879175004, 52.341460797094534, 54.56125559345369, 61.49608842788204, 70.66381285267492, 69.02424643116613, 71.88754527799546, 66.57303963938068, 68.580736191042, 67.24040738997921, 67.47369427834788, 66.06278634840443, 57.282078266143806, 60.71379523123465, 63.13183838321317, 66.84740943293419, 60.652312078783595, 60.089389201133486, 64.67827596972066, 70.06359607942643, 60.31591784569525, 48.40121638390326, 49.90248395550636, 46.46507955366566, 46.82977760991743, 55.03588591852496, 68.82969687061926, 59.23655609930716, 63.02362803489932, 65.52482543453094, 62.37384426978327, 51.02827087525399, 56.14090781058035, 62.2108619443832, 65.64154732611873, 65.73969679494058, 61.90342657027706, 60.168260220558416, 66.40848836591168, 62.427623887215894, 61.971181592633656, 59.76599762516638, 60.38200978309878, 53.73264312744141, 51.153998528757405, 44.21702408021496, 44.17141868222145, 47.9974828996966, 47.495415595269975, 46.295291916016616, 47.830354629024384, 44.33873522666193, 50.243000599645804, 49.063022213597456, 50.43163130360265, 52.367544558740434, 51.29046563179263, 47.330946691574596, 52.667123425391416, 52.72697094948062, 53.56765647088328, 55.74221849441529, 55.5535642562374, 64.0252640939528, 67.95875026333717, 66.84555807421285, 64.0765961523979, 74.6199389426939, 66.43315222955519, 69.05634710865637, 67.23218610209804, 69.25019064257222, 71.43939879632765, 72.60381713990243, 69.66674635487219, 70.87176907447078, 72.3090196424915, 79.42390103493968, 78.53605685695526, 80.0296248159101, 69.19303386442124, 70.67909440686627, 67.48190772148871, 72.62456647811398, 65.48429166117023, 65.85905059691399, 3.1620091536352715, 4.498715890992073, 15.415316820144655, 2.704270270562941, 0.2180127652301904, 9.605382488619897, 84.85745060828425, 75.81322593073692, 79.14571085283833, 67.72967600053357, 70.7806053469258, 41.148918674838164, 34.27745957528391, 57.41829041511782, 63.39887334454445, 88.164244005757, 43.249555787732525, 0.6458663591934789, 0.30436504692319905, 0.25397314690053463, 0.2972622780549911, 0.17013973165904323, 0.15988714632488069, 0.16526460857881656, 0.31664657015954295], [0.04879959010248704, 0.05291618654624589, 0.03614985053577731, 0.021312952927884557, 0.11562050996168007, 0.051708931569010026, 0.10389360373899822, 0.11416992247705499, 0.3690638074711446, 24.15878591998931, 75.06755982675861, 56.29981087100122, 41.93551078919442, 31.063436115941695, 43.767889161263746, 62.78648937902143, 51.62569099856962, 70.07596723494991, 72.69659688395839, 2.218646767639345, 0.07587076630443335, 0.19356840109873205, 1.3962577547757857, 1.6453652780863548, 21.14013179655998, 75.12866250930294, 78.24997486606722, 79.79158401489258, 73.20510864257812, 71.02937775273477, 75.38662895079582, 78.57310756560295, 75.83718376774942, 77.07098883967247, 71.86838057733351, 77.86472751248267, 74.17390269617881, 58.70792650407361, 61.725194069647024, 68.01178070806688, 66.81986654958418, 71.98030933257073, 70.69169305985974, 70.7681243650375, 65.17609534725067, 65.97000660434847, 66.76808341856926, 68.596464895433, 71.0921121412708, 69.14598895657447, 61.613445743437744, 52.224436883003484, 50.69838777665169, 49.70217635554653, 48.315175271803334, 45.26073148173671, 46.76725110700054, 46.73216550580917, 49.97467517852784, 47.787734154732, 47.77620238642539, 46.58777913739605, 44.196514006583925, 42.4572644695159, 42.369776002822384, 44.27281979591616, 42.31104243186213, 46.32044607593168, 50.97519336208221, 53.56382431522493, 62.1935760590338, 61.600447008686686, 64.09785147636168, 59.556523446113836, 62.62869634935933, 59.631919245566095, 56.86850747754497, 49.013584659945586, 53.46468248674947, 50.93156091628536, 53.464580505124985, 46.120989630299235, 58.20387448033979, 57.56690902094687, 67.28590688397809, 44.34295961933751, 45.74908618004092, 55.27717444204516, 47.77748892384191, 44.59982779718215, 43.68949274862967, 64.02360885374009, 54.10959074574133, 53.20077365444553, 56.868844801379794, 63.39970488702098, 63.660879827314815, 63.20297056628812, 59.77127713541831, 55.74586237630537, 57.73673195992747, 61.15534036390243, 55.312534609148585, 58.963578747164824, 59.412239059325195, 56.754456720044544, 56.217311659166896, 53.500430968499955, 48.46500589001564, 45.165492411582704, 37.81235056538736, 40.4357337182568, 38.6864350688073, 41.742451729313025, 41.25826651050199, 42.1177048836985, 42.87581274586339, 45.39236230234946, 45.194035499326645, 45.847918141272764, 46.80766328688591, 43.9229404541754, 45.809051375235285, 46.7122124087426, 51.17341818348054, 46.911986566359, 48.7478833044729, 46.709125503416985, 53.23884417933803, 62.94730263371622, 61.846356084269864, 62.501125181874926, 56.8397565041819, 67.33536012711065, 71.48117203866282, 69.24600939596854, 67.05503617563556, 63.648347854614265, 63.67391778576759, 66.07577723841514, 69.7971651631017, 75.85555614963656, 72.59087331833379, 69.70535032210812, 63.76299873475106, 64.0697673059279, 63.01513610347625, 63.95224132845479, 66.0643082280313, 67.5186917089647, 64.63503968331122, 54.82654902242846, 0.6858636258590607, 1.1888435555081214, 1.1331179521737562, 0.07702539104127115, 0.10480887962565308, 48.33026070748606, 71.45517456916072, 67.31741920594247, 53.64681382333079, 62.11360677596062, 29.685517280332505, 9.975030576029132, 23.33668851083325, 49.908151780405355, 56.367801235568145, 48.28391398152998, 0.4286791456322517, 0.054877229906137914, 0.0936625378146287, 0.01317906801799132, 0.021234584048450477, 0.07189174393011678, 0.015885663357743576, 0.04638550532681327, 0.06213186421401559, 0.023308451092171095, 0.03315560354460632, 0.026363515888430902, 0.15910290211679476, 0.025376007486615452, 0.15353575649280704, 0.15629341255032247, 0.4782921027752661, 29.473583775181925, 84.59538921233147, 63.34023391046832, 48.919867469418435, 42.481783205463046, 43.38495600608088, 59.1132563929404, 61.928215949766106, 76.96209599894863, 80.57385367731895, 1.772269397493332, 0.05188144690867874, 0.5805769754994301, 0.875069140907257, 2.1864095426374868, 24.822772587499312, 75.05976215485605, 79.05167595032724, 82.62259391046341, 76.1812383897843, 71.73702040026265, 77.00521069188272, 80.46902441209363, 78.09719854785551, 80.91558625621181, 76.68515313056209, 79.48865152174427, 77.91223526000977, 63.38769851192352, 64.77047128062095, 70.56364336321431, 68.874647232794, 75.29242146399714, 73.0349640692434, 72.62175021633026, 67.83722739065847, 68.21071547846641, 68.26879793597807, 69.29387015681114, 75.32238052737328, 71.2761732839769, 65.43721929673227, 55.35449612525202, 52.792941293408795, 51.84719900931082, 50.85908336024131, 48.065273223384736, 50.42397483702629, 51.4918871848814, 52.26088746901482, 50.88231948114211, 50.03175743164555, 46.59730265217443, 47.95124992247551, 46.41654022278325, 45.45506923429428, 44.40960853330551, 44.474865005862334, 49.32934722592754, 52.05778321912212, 56.97879275967998, 64.0255896506771, 64.92519309443813, 65.91021399344167, 61.65835688191076, 65.16999213926255, 62.66221692485195, 57.32282384749382, 51.79277220079976, 54.391228691224136, 55.27046326668032, 55.38292938663114, 48.395446577379786, 61.02527064661826, 61.34280612391811, 69.00403053529801, 46.19689533787389, 43.31836592766547, 48.07743649328909, 48.3650678203952, 43.85946081530663, 46.381580137437396, 65.73115779507545, 58.74325529221566, 53.946490749236084, 60.21273597594231, 63.63741228657385, 62.908749657292525, 64.87554373279696, 61.529938482469134, 58.865554794188476, 59.26091401807724, 62.03658319288685, 56.69568784775273, 63.046719028103745, 61.04019134275375, 60.08392533948345, 58.87792987208213, 56.678401962403335, 51.32446473644626, 46.81075019221152, 41.41642432059012, 42.8165888786316, 41.613323380870206, 45.482882761186175, 44.51905050585347, 44.657388579460886, 44.48532204474173, 49.33472871780396, 46.137569489017615, 47.89910201103457, 49.56550136689217, 46.760449717121745, 48.54673631729619, 48.583504615291474, 52.588307319148896, 49.61124797021189, 51.21263404046336, 48.66660787213234, 56.704379820054584, 64.22073933386034, 66.71311532297443, 66.38427949720814, 60.91396554823845, 70.46859648919875, 72.23999377219909, 69.26122034749677, 66.98529643397178, 66.17173410231068, 67.34552691059729, 70.20842567566903, 72.37642165153258, 76.41025773940548, 71.05830131038543, 69.2071936207433, 64.08876334467243, 66.26178387672671, 62.974374832645545, 65.52788880563551, 68.55589189837056, 70.01576669754522, 68.75249678088774, 62.77976643654608, 1.6649711228186086, 0.8550172491419701, 0.9850391012526328, 0.10839955670939339, 0.04388494837668635, 47.93481519145351, 79.7993032393917, 72.3766177700412, 62.925470721337106, 61.03210733782861, 26.564306905192716, 20.79342761347371, 30.25487872862047, 58.011160589033565, 65.0306813178524, 56.46315013208697, 0.22055086048860706, 0.017719789888829957, 0.14006924845518606, 0.033753021890597965, 0.07501192811516023, 0.02965917059731099, 0.02478372767537592, 0.08022901752302725, 0.09420737954637698, 0.1973903371441749, 0.15076107796161406, 0.14213540290872897, 0.28064699543099253, 0.18775837495923045, 0.21906621273486845, 0.3873439830157065, 0.5174878576109486, 34.861555407124186, 95.93906417969735, 71.18602152793639, 61.19483078679731, 43.313914037519886, 65.45108095292123, 81.07323415817754, 70.88004527553436, 84.31947400493007, 88.93026721092963, 3.3508006747691863, 0.1028894922966438, 1.1016126169312386, 6.208132370825737, 4.779664479917096, 26.31869592974263, 79.64787621651926, 80.68957928688296, 88.11885433812296, 75.267333984375, 71.73680074753301, 80.6725718898158, 85.89601578251009, 81.16393504604217, 84.76365104798349, 80.85749595395981, 83.42042753773352, 76.42454301157306, 63.63371741387152, 65.77774378561205, 72.53587384377757, 74.29028726393177, 78.4320120657644, 75.6095294029482, 76.84460532280707, 72.99676802850539, 72.43584555964317, 71.81676218586584, 72.472762907705, 77.44169204465805, 74.36005838455694, 67.56777624930105, 58.74056062390728, 55.53593712468302, 52.94665505809169, 52.92412496382191, 51.09316256738479, 53.226323973747995, 53.168684744065814, 55.48531893760928, 51.977088297567065, 50.525003325554636, 51.927093767350726, 51.814584501328014, 48.628929584257065, 48.936996459960945, 48.03154476227299, 46.36217224982477, 52.79319624747, 55.1214994922761, 61.67296378843246, 67.96748145934075, 67.22792640809091, 69.91240439876434, 65.12727752808603, 67.28028220515098, 66.8131200728878, 62.229834448906686, 54.59676481062367, 57.174044424487704, 57.25886175709387, 58.33616818151167, 52.60571872034381, 63.236271489051084, 63.806839066167036, 72.53333999264625, 52.600733387854795, 46.16610473202121, 50.578739796915364, 49.24181169079196, 46.75120469062559, 49.630063579928496, 69.44859197062831, 60.690182562797304, 56.68042198304207, 63.564734689651004, 67.76725230678436, 64.98172229336154, 63.749545005060014, 65.9409418413716, 63.994410730177364, 62.88536448632518, 66.93290925795033, 58.03334551472818, 65.00520944595337, 63.22725396002493, 62.24776360296435, 62.59911383351972, 59.76330687922817, 54.07824708569435, 50.59644929824337, 43.74821847484958, 46.58877541941982, 46.018513787177305, 49.20418439372894, 47.09296864847983, 49.09378536285893, 47.60242177594093, 50.67564587439261, 50.45434574927054, 50.62082290649415, 52.82653639393469, 48.606893708628995, 52.628260581724106, 49.68405500535042, 56.406365979102354, 52.759938470778934, 54.10184014228083, 50.38350774395851, 58.715610427241174, 67.90611990036504, 69.07124427057082, 68.44186859746134, 68.4543417346093, 74.73298165106004, 71.89865343032345, 71.5977527249244, 69.56391749843475, 69.94267725175428, 72.01820727317565, 73.0540503225019, 75.61226721732848, 78.79205426862164, 71.64711967591317, 71.41693145998063, 65.85945067867156, 66.98175845607635, 64.01042576759093, 67.87085779251592, 69.84592806908393, 74.57396091953402, 69.53026356235628, 62.04323945506927, 1.3677160153465888, 5.573875798333076, 4.70731440090364, 0.2093316100898289, 0.3571180452502543, 60.08123067117507, 85.67367230692219, 81.26241791632869, 70.00690214095577, 81.34832566784274, 42.83969556131671, 19.470351357613843, 38.56755195125457, 68.7593452392086, 75.2038465007659, 68.79132040085332, 0.751892437617625, 0.210301983019998, 0.2279809174398261, 0.14757317160406422, 0.15152725781644547, 0.15188649176589905, 0.13737818076004907, 0.1321679861435006], [0.009566921320173049, 0.04223111393531004, 0.08389599696402589, 0.034637278877198696, 0.00852743193747536, 0.054709027641482895, 0.04147338019984384, 0.11727888347400774, 0.256793683454875, 36.32098697846936, 69.93034531993251, 58.30818599270236, 41.206487301857244, 26.714096338518207, 46.96378930922478, 61.27704366560906, 51.564992320153024, 81.11324233393516, 46.543640705846975, 0.11510635771217848, 0.0153085884765812, 0.21197101281535244, 1.1531906815305835, 5.086069741556722, 46.1638532915423, 75.64265774142358, 73.42195295518445, 75.65103592411165, 75.19414255695959, 73.14332346762382, 68.45972322648572, 71.53813269830519, 73.71607580492574, 73.47601106089931, 70.65173979728453, 61.05613969987439, 53.44604338369062, 63.32219100767567, 69.5729938630135, 68.34476640147548, 72.56198898438485, 70.45035746789748, 68.98270068630096, 62.33211809589017, 59.619438263677786, 61.52670644944715, 65.77004025059362, 68.8008596051124, 70.7621858965966, 69.23850982419907, 60.844198349983465, 50.548019793725786, 50.59216999238538, 51.23877663766184, 48.26377653306531, 45.91839921089911, 48.89700397368401, 49.7710374862917, 51.33616908904045, 48.162202835083015, 46.25111426076582, 44.82768220286216, 45.70510072092856, 43.872396792134936, 44.39240501772973, 43.120549032765055, 44.1540543494686, 42.139077878767445, 46.113576350673554, 47.719402543960086, 54.68939942698325, 62.76397105186217, 61.564953480997396, 59.70147855820195, 59.84227988027758, 52.45756687656526, 49.77031577018, 48.56062935244653, 51.806669158320275, 49.73302187458162, 51.98782382472869, 48.72194467052337, 62.03548100686843, 56.00113414948987, 68.00391243350121, 39.62787059045608, 25.794206396225963, 65.33703804016113, 51.11062888176211, 48.852779249991144, 46.297594347307765, 63.19905211848598, 58.812347842801, 51.78437048389066, 54.07010424521662, 62.64291886360415, 56.86131385064895, 62.2701838708693, 55.587037763287945, 56.535258985334835, 59.10856523821431, 60.33171323037917, 55.308953485181256, 54.86389783120925, 57.08463791877993, 57.78509086178195, 54.29742520855319, 53.98025843404955, 49.52981172069427, 39.66299149297899, 38.044629404621745, 41.308837629133656, 40.2242002948638, 41.41583988743444, 41.82038922463694, 42.52180314833119, 40.83660387223767, 45.35025173617948, 46.13205855892551, 49.151255930623705, 47.57691852508053, 45.128339721310525, 45.90903259092762, 47.70503097964872, 45.86239953194895, 47.423636221116595, 47.5506974804786, 47.735578398550714, 50.559429968557055, 59.53287547634494, 64.81414687248969, 65.118240387209, 64.97204972851661, 59.42251566917666, 59.56510559205086, 64.6301837890379, 65.85577149544993, 73.47276333839663, 72.84461144478091, 75.76898943993353, 70.07835203601469, 67.07709558548467, 66.70687875440045, 68.06683509580552, 68.26640529017295, 74.85325721002395, 67.84204406123008, 70.88068854424262, 68.04428146731469, 79.47210696435745, 68.1735392539732, 72.96216487884521, 42.36085261068037, 0.25405969951421986, 1.4899091230284784, 0.8390723240952339, 0.32506066704950026, 15.285155907753976, 75.9010870225968, 66.63383637705158, 58.409481202402425, 50.00981177053144, 55.5274098919284, 23.44051757166463, 13.862622072619777, 42.236525243328465, 53.50217250085647, 68.56966726241573, 4.293223898256979, 0.2692656561491951, 0.026404256444244135, 0.050294476621333635, 0.06622671525204374, 0.1191934904143695, 0.047728633658299525, 0.09473902158318989, 0.04662431025456998, 0.08126523571028825, 0.07661787056995016, 0.050903026224865075, 0.03073107124486518, 0.09804332733995492, 0.06797569398317607, 0.09221925880880126, 0.1303024701173267, 43.30219791781518, 80.83249476648147, 66.21346027620378, 42.9723697323953, 24.600962554254842, 37.455281519120746, 64.34764369841545, 60.27276392905944, 88.90709384795159, 50.47602076684275, 0.0581582082856086, 0.046693618229079636, 0.8284350400490146, 1.7895393482139035, 6.3548147966784825, 49.02878384436331, 77.863095806491, 76.79287710497456, 77.3432719322943, 75.42018874999016, 73.77610375804286, 68.93689524742865, 71.6757922018728, 74.36198819068171, 73.98631926505797, 71.43925759100145, 62.623142273195334, 56.455783920903365, 64.5808482170105, 71.26822656200778, 70.11836805651265, 74.07418035691785, 72.64707303816273, 72.44551027974775, 64.90805625915527, 63.959074097294966, 63.85600597627702, 68.8733450058968, 70.21288148818478, 72.13139903160834, 69.00203797125047, 64.19638533746043, 53.76115875859415, 54.155149075292776, 52.36403011506604, 51.90243774844755, 49.23700286496071, 52.44490546564902, 51.89635807468046, 52.991864296697806, 50.738831335498446, 49.7734889676494, 47.57791872947447, 47.010418445833274, 45.54757833480836, 47.5988406519736, 46.07033614189395, 46.44547162517425, 46.46870382370488, 49.466210488350164, 48.97204283745059, 56.549591325944476, 64.58510398864746, 65.23322466881045, 63.15945579159645, 63.10995940239199, 56.21762152641051, 53.17525079173427, 51.12458467483521, 52.91184402281239, 52.401755471383375, 52.03180536147087, 52.86241823627103, 64.9040005283971, 60.956817442371005, 71.07059401850547, 41.71587374902541, 26.580892647466353, 54.638581199030725, 50.08730603802589, 49.411493424446356, 48.4792362490008, 64.14830492388818, 61.60275728471818, 53.97556335695329, 55.679668457277366, 63.468322830815474, 59.154198092799035, 60.98581944742511, 57.11740539919946, 58.69923845414193, 60.99483697645126, 62.1032242621145, 58.519338946188654, 57.55163531149588, 60.80938339233399, 60.09159357317033, 57.469422432684134, 55.079914523709206, 49.873309366164676, 42.92403436476185, 41.83975004380749, 44.6483475162137, 42.54554133261404, 42.54735346763365, 43.98791059370964, 43.96472154125091, 43.38910587372319, 48.604873687990256, 48.40016911106725, 51.339946331516394, 49.90906961502568, 47.76815760520197, 46.30517628885085, 50.504108859646706, 48.795712686354115, 49.2061730354063, 48.784086781163374, 50.11502542803365, 52.00181099676317, 61.7171649779043, 67.21156227973201, 66.01676125680247, 67.79237116536787, 64.37360978895619, 64.04339721125942, 67.49356500564083, 71.42676091963246, 76.03831506544545, 73.524852414285, 75.38498155532345, 71.90310139809885, 67.80296940957346, 69.51587630856422, 69.31564715600783, 72.18887744411346, 76.84605659977083, 71.27007007598877, 72.93785402851721, 70.37612269001623, 79.63495592917167, 70.93444070508404, 77.30085542125087, 53.498218751722774, 0.5671684756394356, 1.1138645078866714, 1.0048288683737479, 0.5037127387139105, 16.677166838799756, 81.05485393155007, 72.37826516551357, 65.0571612388857, 56.45814911011727, 44.37164391240766, 19.888368152802993, 27.004275245051232, 49.04163745141799, 61.330815438301336, 77.39030899540072, 5.29890392095812, 0.5267180526448835, 0.07648406565309533, 0.09772488757246926, 0.050292557571083314, 0.1337602386070836, 0.010599194154624018, 0.034918789376294425, 0.147766133830432, 0.1797060094653599, 0.20030055195093158, 0.17481328168463323, 0.145488171387584, 0.12746314908708298, 0.2662352268253603, 0.2970149235859994, 0.3377625580516554, 50.09695899101996, 94.09847628685736, 73.37970118368827, 58.6508717075471, 37.283669979341575, 67.93218797253024, 77.85494512127292, 68.0688198151127, 92.98104793794694, 57.92759449251237, 0.35670460291927863, 0.18254954397918718, 1.5702864551736464, 4.847240544134571, 7.528368340384576, 53.54082353653447, 83.99124222417032, 78.57774380714663, 80.73889916942966, 77.80298156123008, 75.70925174220916, 68.86627689484628, 74.7154486563898, 76.72953082669166, 74.03809455133255, 75.64734105140933, 60.72833937983359, 57.479153833081654, 69.12420411263743, 72.97099805647328, 76.20703974077779, 77.61244850773966, 75.84782908039709, 75.00016566245787, 68.48088833593553, 64.77808067875525, 65.60207259270453, 72.21653799856864, 75.58064506899926, 76.39751003634545, 72.68859524880686, 66.88687632160803, 55.32761220009097, 56.16601882442352, 55.81870471277545, 53.63009668165638, 51.81821661610758, 54.569994634197606, 55.036791986034764, 56.64448130515314, 51.85004665005592, 52.19153211962793, 52.11126081405148, 51.19772511143839, 49.09018462704074, 51.497668758515395, 49.30890383258943, 51.12063484807169, 48.07146272351665, 52.56478878759569, 52.192716675419966, 58.3723638134618, 69.17249633419898, 68.6858243326987, 66.24444700056507, 64.89314340776014, 57.2384968111592, 55.539667298716886, 52.73848702830654, 55.05894161039784, 55.29400533245456, 56.80871878900836, 54.21823647714431, 66.53944061648461, 62.80825853347779, 72.67658495133924, 44.29535773492629, 33.45162806972381, 60.86078997581237, 49.90069143233761, 51.15391615898379, 50.80162848195722, 66.85836853519564, 64.94162390308996, 56.114357286883944, 59.287676349762954, 67.298583984375, 62.495990799319365, 64.81295839432748, 58.89374094624674, 59.54333643759451, 66.56634023112636, 63.46792667142807, 60.14282364999095, 59.27884709450507, 62.969346354084635, 61.1663975254182, 59.11167175539079, 58.11222045652328, 53.2332234228811, 45.81594690199822, 43.32679510116578, 48.1464349069903, 44.83888841444447, 45.77668397657333, 46.321320764480106, 46.01935317439418, 45.98126696002099, 50.78529181018953, 53.694490232775294, 52.31705973225256, 52.64508362739317, 51.29150113751812, 50.290406365548414, 53.580208055434696, 50.19145281084123, 51.75449379028813, 50.45910358428956, 51.65057843731296, 54.722335569320194, 63.14433897695234, 70.48721205803656, 68.55625275642642, 69.91174544057539, 70.03409201099028, 70.34480648656046, 72.74718761444092, 73.47285747528076, 79.08078778174617, 74.2885692657963, 75.37446960326164, 72.87946562613212, 71.11542670957505, 72.1164155775501, 72.88061880296277, 74.05172086531117, 80.37450313568115, 72.69221167410575, 73.91304154549876, 75.57787587565761, 82.58118937092443, 76.28386328297277, 79.4665999566355, 52.274498093512754, 0.5507830806797551, 7.766608691984608, 1.9591417764463734, 0.5056599197128128, 21.228292949738044, 90.98467919134325, 78.5567512819844, 73.19609503592216, 67.21496689704158, 74.48839049185477, 36.26443424532491, 29.2994579961223, 57.98233116826704, 71.14941012474799, 89.43640985796529, 8.281657080496512, 0.9236191970206077, 0.3425830284193639, 0.3120769169782439, 0.26988296979858034, 0.19170833961857905, 0.2715301201228173, 0.2862237477975507], [0.05446646505245759, 0.02109174695496838, 0.042884843574175914, 0.04864418916704674, 0.16063575212272907, 0.021334550861689835, 0.09756728030380704, 0.08307544784920831, 0.05109654386497794, 42.637265959093654, 64.60684176414244, 51.644290877926736, 45.31692727919548, 39.70292514370334, 62.04398470540201, 61.51723000311083, 54.105629151867284, 88.8508705939016, 23.607843922030543, 0.20585412249690105, 0.16941562535301333, 0.3279024548828602, 1.0232751011367769, 11.92532520140371, 70.99948929202172, 68.72924497050624, 75.36951172736384, 69.83241942621046, 71.73997002263224, 69.27437597705473, 69.40728156797348, 72.54931188398793, 71.2672616589454, 68.68053697770642, 70.28892840108564, 61.804418102387466, 71.21020686241889, 76.49330216069376, 70.47926533606746, 67.7551321829519, 72.7645323353429, 68.16661234824889, 68.26337722039992, 60.77734939513668, 53.58036495024159, 55.64848169203728, 60.033511115658676, 63.50409092441682, 67.34658595054381, 63.330118117793916, 56.069022532432314, 51.329426534714244, 49.965379161219445, 51.68763306833083, 49.99705622273107, 45.2425120722863, 46.80501176464943, 48.27874037527269, 51.313984163345836, 49.55880195863786, 48.12128466944541, 46.04273442299136, 44.70857158783944, 42.58681643393732, 41.26028653114073, 42.69573673125237, 44.49699894074471, 40.96166080044162, 40.68518469410558, 45.34818464709867, 47.61403591402116, 50.11496267011089, 55.22108454858103, 53.03752853024391, 51.12082704421013, 50.52142220158731, 51.04924771093553, 48.94746134358068, 49.32096119849913, 47.896693675748764, 52.452279521572976, 54.882109395919315, 60.95329123158609, 60.955197503489835, 62.77462028688001, 42.575190528746575, 8.036739383974384, 37.60465322002288, 59.738117417981556, 43.70773569230111, 45.243347537133005, 59.90250395190332, 59.45377303707985, 52.807540355190156, 51.45949625199842, 60.14395329260058, 60.583568619143584, 61.610182331454375, 57.52266076303298, 50.613217430730025, 54.827380564904985, 58.049744944418634, 59.970176604486284, 59.386371028038766, 57.78261192383305, 57.61942955755419, 54.07445807610789, 48.807903412849676, 44.27891515916394, 41.059849492965206, 39.8241420715086, 40.84253449593821, 39.57391446636569, 39.56108439353205, 44.5816279995826, 40.85613335332563, 46.17036050365817, 49.89150916376422, 48.20464288034747, 50.30216563132502, 47.45843548928538, 45.4638082750382, 44.9908253454393, 47.21608400344849, 46.68103348824286, 47.53667500711257, 47.5767812421245, 47.6334830253355, 47.21876298227618, 47.143308347271336, 58.507677739666356, 62.71068957544143, 63.95552042991885, 67.72103894141414, 64.61552981407412, 64.34291724235781, 66.65116540847286, 67.66726324635168, 68.25070796474334, 64.46236125884518, 65.30899701579925, 64.38140746085875, 71.54763267886254, 71.2675440695978, 70.35609506791639, 67.26765217319613, 71.60040424716088, 70.23384263438564, 73.90300812259798, 68.93355338804184, 77.72346727309689, 69.79037946270358, 77.40373919087072, 21.37394820490191, 0.29669653744466845, 0.5866302958419246, 0.027051840142737475, 0.7303432423260905, 58.3643307993489, 68.29396386300364, 66.14929030018469, 48.31881523132325, 65.79565332781884, 36.755248269727154, 18.152027053217736, 34.908659150523526, 54.13949097356489, 73.10930082874914, 15.041817945818748, 0.7231866940855981, 0.18404873208172862, 0.08708646971612208, 0.1064337597739312, 0.10393976053643612, 0.03948618259821688, 0.07295749480685881, 0.05080215159743544, 0.0218379051018987, 0.04846072643094006, 0.031087501312515912, 0.009392680367454886, 0.03356169143150892, 0.1227401021207052, 0.05963591145231359, 0.05074024786271396, 49.47918176651002, 75.15746055110809, 57.45108142975838, 63.78388535591864, 42.9004373858052, 43.21515660132132, 71.57361445888397, 60.401739305065526, 97.9220497992731, 24.91014534427274, 0.18602402850745187, 0.24698503075107453, 0.8831281407225517, 1.326964918163515, 17.22373539401639, 73.41901902229556, 71.22682202246882, 76.80441671802153, 72.19234481934579, 73.95301049755466, 71.49188795397359, 70.79201944412725, 69.84789709891044, 70.8633908917827, 70.06899326078354, 71.86452880982431, 64.59074435695526, 71.7980367906632, 78.07114616517099, 72.60602151193928, 71.30806215347783, 75.01159544914, 70.44826292222547, 70.27412537605532, 64.68617170087754, 56.469618120501124, 57.37142593629899, 62.0617961883545, 65.11283536111155, 68.65781076492803, 66.5551850103563, 58.20868722854122, 52.5457456804091, 52.86243392575172, 53.62919061414657, 51.44589347224082, 47.480726318974654, 49.023370973525516, 50.85340769060197, 53.01619475887668, 52.003634898893296, 48.166250721100845, 47.48347590046544, 45.917124440593106, 45.006126511481504, 44.704633528186434, 45.214019975354596, 47.11591843635806, 43.7602444617979, 43.289348233130674, 48.55756990371212, 49.430395326306744, 51.27975363885203, 57.95984422006915, 55.24398334564702, 54.051904447617076, 52.27942459044918, 52.944089827998994, 49.099876803736535, 50.71123353896603, 52.9146759740768, 54.04193378263905, 56.583429613421046, 65.43319494493547, 61.646997697891734, 65.8987057593561, 46.20625803547521, 10.691981988568461, 33.0961593504875, 54.16542176277407, 45.78758816565237, 46.49157516417965, 59.82056956137381, 60.76910849540465, 54.31345201307728, 53.357248767729736, 60.13587713241578, 62.11294781777167, 63.337229374916326, 58.215190518286924, 53.309576280655406, 55.8618547070411, 60.940382711349, 62.278110980987556, 61.27298401248071, 61.309081585176536, 60.921170942245, 57.739144217583444, 50.68258062485726, 47.26550586761967, 41.6705782182755, 42.409439010004846, 43.44782767757293, 41.763918861266106, 40.759858777446134, 45.589516316690755, 43.512005498332364, 48.38500915035125, 52.9101848602295, 49.324828655489036, 50.95105509604178, 49.55008645211497, 48.67839851687032, 46.73833539409023, 48.23242502827799, 49.42368415094192, 49.3323988299216, 51.47371876624323, 50.087105997147106, 49.95001523725448, 48.8693198850078, 60.52825927734376, 63.068064566581484, 65.57606727846208, 68.0902281115132, 66.53692245483398, 66.71712398529053, 68.78965731590026, 68.23293178312241, 70.37386340479698, 67.70522394487935, 68.77177915265484, 67.21804203525667, 74.13649897421561, 73.5082607884561, 71.83038849984446, 70.28938339602563, 76.73285699659779, 69.82649664725028, 74.70226164787047, 70.01284845413701, 80.50130551861179, 72.533630248039, 84.97132485912692, 33.28780635710686, 0.514234864423352, 0.4970027584462397, 0.10985767483831414, 0.9999358954448855, 62.76171176664291, 75.81156284578385, 72.64709657238376, 58.69238607345089, 59.25860766441592, 28.41157655562124, 22.86819865626674, 40.9186637786127, 61.09479858029274, 83.10418252022036, 17.341169195790446, 0.8580101401575151, 0.2775373219722702, 0.0910117203790334, 0.15866980196968203, 0.12003027293230258, 0.07066704513084504, 0.07544213244991918, 0.146329305284927, 0.1293851257932763, 0.11538483067265443, 0.1593478510697042, 0.263284225497515, 0.18415492718979237, 0.4138892973142286, 0.1460581101597317, 0.2693374845529756, 60.05162069874426, 87.66866037922522, 69.33816940553727, 63.10981035232545, 58.25438676341888, 95.9553498606528, 78.20283582133632, 68.72486760539394, 103.5276972862982, 31.537940925167455, 0.41633029858912196, 0.5363355817333345, 2.467891819054081, 3.5365538299083714, 18.96786435957878, 79.25287000594601, 74.2776886109383, 80.96515717044954, 75.15947664937666, 76.12148500257923, 73.72050023848011, 71.09971369466474, 72.37471149813744, 74.06463330791843, 72.75048240538567, 72.15112855357509, 64.63303535215317, 75.64395212358045, 80.1601299162834, 76.40286799400084, 74.42200045431815, 78.59377061167072, 73.90485163657897, 74.07205443228446, 66.67448782151746, 60.182953419223914, 61.176850641927416, 66.35803884075534, 69.10887549000402, 73.70931363874867, 69.76762971570416, 62.35355384888188, 54.58124791422198, 54.06857452084942, 56.30069340428999, 55.55593729019166, 49.97021544364191, 50.8782833622348, 53.469518769171934, 56.33248813690678, 56.38718558895973, 50.40517099442021, 51.323935216473, 49.71846203650198, 47.96792391807803, 46.644637815413944, 47.99561585149458, 50.518904039936686, 46.55225815311555, 46.372315499090384, 51.65388499536822, 51.87866426283314, 54.03204548743464, 61.352957217924065, 59.34047145228232, 56.24790614651096, 54.36056360121697, 58.06248872510849, 52.10035662497244, 54.02569517012566, 53.92014418878863, 57.05485928443171, 61.29840881593766, 66.17093393879553, 64.58984221181562, 69.85184300330378, 49.040005745426306, 15.733162164688112, 44.051123511406686, 56.338187340767156, 48.14381868608537, 53.546342311366914, 64.73120051045572, 65.60488493211808, 56.71921422404628, 57.1850545175614, 64.37623777697164, 66.349699881769, 66.50093078613281, 61.12361231157857, 54.66682618664157, 59.904884830597915, 64.26798428258589, 64.58586100609072, 63.67500820467549, 63.790012098127804, 63.52403225437288, 59.88752442021524, 53.91428024538102, 50.215669524285104, 44.327411343974454, 46.12127204095164, 46.68374384603193, 44.44105809734714, 43.631720158361624, 49.44956787170903, 48.20302294146631, 52.17204970698203, 55.004412820262296, 50.903763078874164, 54.16535116011097, 52.162557571165024, 50.940790253300825, 51.30433121035176, 51.80792823914559, 52.409223664191465, 50.517511598525516, 54.82210105465305, 53.1318772223688, 51.72618604475453, 50.618955858292125, 64.02085142750894, 66.9480888305172, 71.37559752310477, 70.2458215528919, 67.81137112648257, 70.94008891813218, 72.59178330821376, 72.57208516520839, 73.91764640808105, 70.20899834171419, 72.6686696083315, 69.64069397218766, 76.62150875214608, 76.33618770107147, 75.20503105655794, 74.87031167553317, 78.48647025323685, 73.85177412340718, 78.2829619992164, 74.06012258222027, 84.54596734816029, 75.16529744671237, 87.46460299338065, 36.24117851257324, 0.8838079365030412, 1.418225724370249, 0.1816850903654291, 1.501315865785845, 70.77501989180043, 81.17725541514736, 81.00258442663377, 65.18674065989833, 83.21675454416584, 54.70414753883116, 30.97131533007468, 51.75465460746519, 69.9019395151446, 92.78537657953079, 25.08034679197496, 1.2788683248143042, 0.3969241883004866, 0.18842199096275916, 0.31312498654569354, 0.26370888335570214, 0.23820019327104094, 0.2012212977053658], [0.03775959278667166, 0.026876118725105643, 0.09531977751682844, 0.010434717950110715, 0.059534895098617965, 0.019398374715819955, 0.02226023788323566, 0.020702945842077176, 0.30977163584001605, 51.735462450212054, 60.538637868819706, 48.102017987158995, 20.250502940147154, 16.79471831167898, 43.91731969771847, 52.387187788563395, 61.3065791130066, 85.96825015160346, 12.032720677314266, 0.19190444280543636, 0.1365002746423406, 1.4252915065134726, 1.7461151557583965, 33.92472082568754, 62.53128428612987, 58.94827758112262, 67.6354528242542, 67.01154493516492, 70.90344613598239, 65.45828634692778, 65.35011522231564, 66.30685975474697, 73.12975991156794, 70.05631616038661, 74.40280437469482, 72.45486121023856, 73.11682393473964, 68.01759366066226, 74.4365995160995, 73.69101185952464, 70.23262669963222, 68.51480114844539, 68.11568429393154, 61.23363871728221, 53.84659190331736, 51.82016995645339, 51.727939344221554, 51.709437524118734, 52.18537399845739, 50.634880681191724, 49.96553213365617, 50.75449728196668, 49.20196825458158, 49.43494919807681, 50.61846948439076, 46.40203529788602, 50.47641692623016, 51.71306179415796, 51.22845295936831, 49.67010705701767, 46.92986080723424, 46.69183961806759, 42.96885921109108, 42.47922974248087, 42.494597588816, 40.08198691952614, 42.92787828753072, 42.82939541724421, 41.87330592063166, 42.87941348168158, 46.00397356094853, 47.046076713069795, 48.5581543368678, 48.569293868157175, 50.63541804590533, 49.18893814086915, 49.09487970413701, 47.764976562992224, 52.05939139089277, 51.99457030142508, 50.841044379818825, 53.63072818325412, 60.46831369400025, 59.59545689244425, 63.59453293585009, 45.97136689770607, 16.74491793878617, 7.236564101711397, 34.338817211889456, 43.11374764288626, 38.32097215037192, 60.998410255678245, 59.03683685487317, 56.43746252982848, 49.12884350745909, 55.51310893028013, 54.75076490832914, 58.50864264272875, 55.67505967232489, 49.45757342923073, 50.906563651177194, 59.45476931910361, 58.606231212615974, 60.00272050980599, 56.26315632174092, 54.484918425160075, 49.99473025721889, 44.14337373548939, 39.55533027648926, 41.29202242820494, 40.57800985151722, 38.78585538556499, 40.097684244955744, 41.341318776530606, 41.61680644558322, 39.7088243884425, 47.60735219524753, 49.554922734537435, 46.43148837550994, 46.20202579805928, 48.70967941899454, 46.1205699366908, 45.01834469456827, 43.51692807289862, 46.960871065816576, 48.563480915561804, 48.774335768914995, 47.673161721998646, 49.582304800710375, 50.05443657598188, 47.824647580423665, 52.80683825092932, 58.190569800715295, 59.743773475770034, 63.81869246882778, 66.51552200317383, 66.34554216938635, 66.35588938190092, 66.33621477311658, 65.87208855536677, 68.76093772149855, 65.21380109171714, 64.84281155370897, 64.06052620180192, 65.306623981845, 65.47958481696345, 70.92911412639003, 70.63288888623639, 70.16137292308193, 70.78303721643263, 72.6435350602673, 73.33108732777258, 78.48647809797718, 65.31844600554436, 2.990637859029155, 0.30639481220033865, 0.37799810870520534, 0.23419559122093264, 23.61700853993816, 73.06454658508301, 63.77871174966136, 55.07207370573475, 56.50729248600622, 37.834005971108716, 19.419568430992868, 30.888437609518732, 47.963581854297274, 68.82273074119323, 26.455302276918967, 0.41248420013054726, 0.07647124900212211, 0.05245397505801051, 0.029886020723009304, 0.07736329710291279, 0.024281564701889313, 0.09836022727071278, 0.004224790083695083, 0.035679648750491684, 0.04273054580534658, 0.021288279151063294, 0.05584614726925089, 0.08429570333851923, 0.05582071315016478, 0.06461841324644704, 0.4137490419370513, 60.91802912373697, 69.55356244117984, 58.387476705735736, 28.59287242735586, 19.123343190839215, 48.612279122875584, 60.13471611084477, 69.48981608113935, 90.673917647331, 12.711976151312552, 0.36488829120512933, 0.3916046269718678, 1.6591931038325833, 2.5146864306542183, 39.288412986263154, 70.8055986896638, 67.25209605309271, 72.73694238355084, 70.43980629213395, 73.35349190619685, 67.67793993796072, 68.41139178122243, 68.61988144536173, 75.431179231213, 73.24910979117118, 75.66554084900888, 75.27524932738274, 73.87804615882136, 71.0848008432696, 74.95910629149407, 76.05555780472295, 75.50308412121188, 73.38332545372748, 70.50363109957787, 64.3215952381011, 56.174793166498986, 55.4084953954143, 54.02779756053802, 53.038199255543375, 55.86218418613557, 51.2719088985074, 52.33301593411354, 53.02145857964793, 52.79368262137137, 51.295003814081994, 52.87005509099653, 49.35844729023595, 53.461442608987134, 53.73154094142299, 51.86836411876064, 53.45837923788255, 50.38222120654199, 47.964225123005534, 46.65034486401466, 44.841641918305434, 43.53211549020583, 42.885395096194365, 45.39477456000544, 45.47549301578153, 45.086833200147076, 45.26364188040457, 49.51310634613038, 48.298681705228745, 51.406960025910415, 51.65404581254529, 52.349733075787945, 52.24498225796608, 50.68079594642886, 51.03059684076617, 54.31303231946884, 53.37139675694128, 51.13222545193088, 54.975242153290786, 63.61817698324881, 62.21978925889539, 66.16248515344435, 51.80013841198337, 19.044803611693844, 8.476840103826216, 34.39974338777604, 44.788281994481245, 40.341286966877604, 61.39240449474704, 62.51952894272343, 58.677845847222116, 49.26851518692509, 56.992089594564135, 58.69796368383593, 61.15511286643244, 59.65099373171407, 53.123812829294515, 53.0941047976094, 59.93969978824739, 61.748230149669034, 61.33287860501198, 59.68458883223995, 55.87129977441604, 51.09726144421486, 45.92597330770185, 41.59297020204606, 42.98741202200613, 43.950844195581254, 39.54840337076495, 42.75268954615439, 43.65972588139196, 43.90880815444454, 43.44208925001083, 50.6617763734633, 51.70314604236234, 50.032694878116736, 48.266569260627996, 51.503497400591456, 48.58285350184287, 47.076490771385934, 47.42344010260798, 49.52459104599492, 50.87558084918607, 51.28062832740046, 50.63724194803546, 51.883327960968025, 51.26395825416812, 49.15995967003607, 53.83118483328051, 60.43777804220877, 62.79533040138983, 66.72721232137373, 68.2559560960339, 65.95736872765326, 67.55536587007585, 69.71713312210576, 67.94810495068951, 72.1662296787385, 67.26042716733872, 65.94362474256947, 65.29351934309929, 67.7486994958693, 68.09520952163204, 73.3422347038023, 72.67893052870228, 72.1765455122917, 74.90733100521949, 75.17791178918655, 77.4101169647709, 76.35087305499663, 77.03836256457915, 8.423057544615961, 0.762100957574383, 0.6412708735273731, 0.32890508011464153, 26.74166471727433, 79.57408074409732, 68.89014059497465, 64.83315075597456, 58.605591866277884, 33.55948932709233, 23.279612141270793, 40.47474168962048, 53.79261224500595, 79.18212613751813, 31.534706930960382, 0.5578002009180285, 0.07848750814915666, 0.10942504966571447, 0.07927952814967403, 0.10877319311182346, 0.07454731111084262, 0.0902888857789578, 0.10645290431115897, 0.16360083414662271, 0.13259391570764203, 0.19736461191167756, 0.15844639540920336, 0.16514687618661314, 0.1481726047612967, 0.21326027750488252, 0.7508471872537368, 70.8837087692753, 78.12247430124592, 67.33889026026573, 30.02423355656286, 27.9775623736843, 63.767211360316125, 69.70871571571597, 77.20671069237494, 99.42417636994394, 15.501902161105988, 0.36487925136762284, 0.8956204607121406, 4.5516316063942455, 4.944586907663654, 38.44489943596625, 74.48726084924515, 73.2929854239187, 82.11743970071116, 79.39411455585112, 80.48947565017208, 75.53384334810319, 75.02025604248047, 70.1137710386707, 81.29638564202094, 74.92417366273942, 78.74201266996323, 78.83208597860029, 77.94341025813934, 73.11518438400762, 79.66329897603681, 81.60269137351744, 76.3564428206413, 76.03429071364864, 73.11132477175805, 69.51022809551608, 59.78003186564292, 57.74270180732974, 56.74669042710335, 56.78248989966608, 58.089035326434725, 53.27063891195482, 55.70245742797852, 54.638934212346236, 53.22236237987396, 53.62287952053932, 57.44569209314162, 51.16593822356194, 56.19384411842593, 56.50091471210603, 53.85845707308862, 55.9092055597613, 53.533469092461374, 51.844163094797445, 47.88040799479331, 47.88920979345999, 46.766533313259, 43.851094399729085, 47.63200429178054, 48.40363648629958, 46.65383185109785, 48.56639915897001, 53.10000796471873, 51.281381422473544, 54.28006087580035, 53.432377846010276, 56.666905495428274, 54.66133094603016, 52.22761400284306, 53.165068318766934, 57.01740064928609, 55.56042448166878, 53.88927121316233, 58.85193240258002, 65.65858217977708, 65.20819210237073, 68.29061415887648, 53.584612877138206, 23.337957397583995, 12.96386488022343, 44.26430040790189, 47.426829030436856, 45.8668984905366, 62.58797430223035, 64.78681187475881, 61.96623548384636, 53.299809578926336, 59.61559826327909, 61.90660369011664, 63.6403658313136, 62.60067101447814, 56.16199055025655, 56.328848177386874, 64.39202531691521, 64.27120847086753, 64.46721715311851, 63.252066873735004, 59.83383501729658, 54.921725334659705, 49.01300414916008, 44.47647317763298, 46.26703123892508, 46.713863726585146, 40.8623581547891, 46.2439755470522, 46.53473300318564, 45.90775782062162, 44.48029748855099, 53.89403297055153, 55.57895768073298, 50.777737325237645, 50.699258542829945, 54.466055747001406, 50.52383838161346, 50.1059216068637, 49.39517244215935, 51.23781565696963, 53.13182623155656, 52.78265683881698, 52.765469012721894, 53.09585025233608, 55.03481511146792, 50.29850998232442, 58.386892272580056, 62.551029497577304, 67.11964545711395, 71.11920787442115, 71.15808640756916, 71.91159725189209, 71.46404697049049, 71.1323791934598, 70.74956370938209, 73.85575140676191, 70.13444977421915, 69.44324185771328, 70.25277199283724, 71.45798298620409, 71.53326895929152, 77.04681134993031, 78.2582510671308, 73.91875251646965, 77.74117285205473, 78.2813459827054, 83.0860141015822, 79.8087953752087, 81.3805518611785, 10.692486993728146, 0.6153663764557531, 0.8124071323583204, 0.4134732809278273, 32.427883571194066, 86.90919537698069, 74.93648990508049, 71.8293216151576, 72.18114253013366, 55.84268608400899, 30.976402644188177, 49.22006999292682, 61.9376100263288, 90.41170720131167, 39.70618463331653, 0.4814485688844035, 0.18432020299857665, 0.21035047638560497, 0.14845815637419302, 0.31410959338949573, 0.1683362534329776, 0.3265532514741344], [0.022425890990322637, 0.06863081407162451, 0.10600826687990658, 0.07491628969869307, 0.04319893579269129, 0.08824103316592594, 0.061339526287009644, 0.07725024550792671, 0.851472958682045, 47.62833295329925, 57.04757936539189, 45.9962700259301, 45.138765381228545, 44.28965460869574, 44.283782820547785, 52.01053827039657, 69.16679320796844, 72.64811638862857, 3.6748377257777802, 0.13953156198465055, 0.2573596998568504, 0.9822655565315678, 9.873961883206523, 62.60502484536941, 74.0854218698317, 64.97778031133836, 60.51612738640078, 59.40863047876666, 62.71101120979556, 63.98627573443998, 65.18760358133625, 71.95078172991353, 72.32619962384625, 73.648681640625, 73.29099285987117, 71.60507186766594, 70.56729116747456, 70.55784610009962, 66.08373964986494, 71.42092443281605, 69.74755502516224, 71.0707587580527, 68.10663930831417, 62.02556525507281, 53.717361573250066, 48.742403753342174, 51.601482129866085, 49.73570477577948, 49.885100010902654, 50.30020444623886, 48.16622326450963, 48.15624083242109, 49.48388468834662, 48.559950782406716, 48.405934995220555, 45.13321914980489, 49.699669961006414, 48.38324800614388, 49.407696570119555, 49.75870947684012, 51.717917688431285, 47.43222621179397, 42.855863571167, 41.825696191480084, 42.86120583934169, 42.24111833880025, 43.539454244798236, 42.64080393698908, 43.59239839738415, 41.10569807790941, 44.794663690751605, 46.962228205896196, 46.58739866748933, 47.13358086924399, 49.43199957570722, 49.50827398607808, 48.14925901351437, 49.19717119586084, 49.9274145403216, 48.44156580586588, 48.09833880393736, 50.18094870351976, 58.90247214225031, 60.30235036726921, 63.933637526727495, 54.947950301631806, 21.36640548706055, 11.763075378633316, 10.622145168242916, 37.533458279025176, 36.55529368308283, 56.73165990460304, 57.64796087818762, 54.78761557609805, 48.109560705000355, 46.68208076107887, 53.65502334410145, 54.057183957869015, 50.00598353724326, 49.23323346722511, 45.07017097165508, 48.254896286995184, 49.971866761484456, 51.57180939951251, 51.93473846681657, 45.13946748548939, 45.35714726294241, 42.83819721591088, 37.85042501265003, 41.09702571745842, 40.12928285906392, 40.310515972875784, 39.943135015426144, 40.898130170760616, 43.54671062961702, 45.81580177430184, 47.74860458989298, 48.91223061469294, 49.120147612787065, 45.77463649934339, 46.124037311923125, 45.534709038272986, 44.64536651488274, 43.003489817342455, 48.040421085972945, 47.312358579327984, 47.47888280499367, 47.984939159885535, 47.19730369506344, 47.90165547401675, 48.02855983857186, 47.38428308117775, 46.54156184965565, 50.314685836915054, 51.60133307979953, 54.53048459945187, 53.39840227557767, 56.97418005235734, 55.64924655422088, 55.12823812423214, 55.762516760057025, 58.72971134801065, 58.82680177688599, 56.37445357538039, 55.35896762724846, 59.70749155167611, 60.00921987718152, 64.09476457103607, 63.76648964420442, 68.90940727726107, 68.58832205495527, 74.11710677608367, 72.27473028244512, 76.84671555795978, 17.241348797275176, 1.241138555830525, 0.23746405938459983, 0.12427443833721262, 5.009557537494167, 61.856479721684615, 66.75169575598933, 62.932174051961596, 55.99244217718802, 49.30141210556031, 16.333024944028548, 27.15072674136008, 48.85405009792697, 68.18086624145508, 33.81613000746697, 0.37633631077985613, 0.059007347801760326, 0.06267202131810688, 0.04595617050184839, 0.003159696127348129, 0.01865782433249537, 0.08090675252700046, 0.029524860062426137, 0.04495067627079064, 0.04910100739629519, 0.0586781406684989, 0.025460371004057028, 0.0250169248395269, 0.03781231878806026, 0.04261239206478481, 1.1938388164966338, 55.83108763540945, 69.30345642951228, 55.150446584147794, 47.71697851919359, 35.871059740743334, 48.137299706858975, 63.58054576381561, 77.09967705511278, 79.75958531902683, 3.459737397009327, 0.19394084240400022, 0.14533237974730231, 0.8458076465514399, 12.338079156414157, 66.63333431366952, 75.25537860008978, 71.16758638812651, 68.55126350156723, 67.8013926167642, 69.37987204520934, 71.31848781339585, 70.32967398243566, 76.45264287148753, 74.41110410997945, 75.77772063593711, 75.25923821233934, 75.38072186131632, 74.20188488498812, 73.81009501795616, 71.36259094361337, 72.39487248082315, 74.02617839074904, 72.85561761548443, 70.34322184901085, 66.16386582774501, 56.01510563204366, 51.26466820316931, 53.336605333512836, 52.32075852732505, 52.05171531246555, 51.56024232987435, 52.38329679735246, 51.082666304803666, 51.90719166109639, 50.16895409553282, 50.21879565331244, 47.25410745989892, 52.28705752280451, 48.834540228689875, 51.15563023474909, 51.98953790049399, 54.84143049486222, 51.03826507445305, 44.413020995355424, 44.82866671777541, 45.05330085754395, 43.16119263249059, 45.220134950453236, 44.791953332962535, 45.882164355247255, 44.85532706783664, 46.612674420879735, 47.801968436087336, 50.16437276717156, 50.38055027684858, 51.85181956137381, 50.86886967382124, 51.21328907628214, 52.22241293999457, 51.564133321085286, 50.03600928091234, 49.2613019481782, 53.2589816278027, 61.062376268448375, 62.3392411201231, 65.88832716788015, 58.14417208394697, 24.713832678333407, 15.28200428332052, 12.673964461972638, 41.606922072748986, 39.596640679144095, 56.9005532418528, 60.44304970772036, 58.18904007634809, 50.09983408835627, 50.56982032714352, 55.84113674779093, 56.7842588886138, 52.57722662341211, 51.164157467503706, 48.10330452457551, 50.530227922624164, 52.35075681440292, 51.465548469174294, 53.82704673274871, 47.9210162931873, 47.427793933499245, 45.06163589416012, 40.46771672464187, 44.22538265105217, 43.27396469731485, 42.45749981172624, 42.97011829191639, 42.94032789045765, 46.860725110577, 47.955580219145745, 49.79463054287819, 51.68976683770457, 50.02468539822487, 47.4009374649294, 48.01331358571207, 48.60613669118574, 48.11263192084528, 46.66089211740802, 49.18818896816623, 50.61437845230103, 49.35981619742609, 49.12716473302534, 50.07502509701637, 50.564548661631925, 49.86294254179924, 50.661352757484686, 49.055146094291445, 51.219859046320764, 52.661243792503114, 56.990465733312796, 55.07581564687914, 59.22769154271772, 57.41015149701027, 58.772492639480106, 58.88489207913799, 60.305441194965, 60.85717355051349, 58.30336147739042, 59.207981632601836, 59.59674735223094, 62.00251348557011, 65.11095654579901, 65.46862179233183, 71.42011642456055, 70.90690566647437, 78.15751675636538, 75.84346740476548, 81.54373814982753, 26.66697886682326, 2.154905800857852, 0.08032545267093567, 0.11535118409102002, 5.8250040777267955, 67.99278074695219, 74.52773186468309, 69.77219535458472, 63.09618403834682, 47.05635332292127, 22.323781521089618, 39.814948035824685, 50.91045072001796, 78.45131797175254, 39.24960505577826, 0.30613513903752454, 0.0859453970746648, 0.020542392965346094, 0.03951715553299554, 0.05544200524567597, 0.0064123421813541606, 0.0645324275378258, 0.08021379535597178, 0.23517713371303775, 0.1710203956932791, 0.09783194835988746, 0.10742281758857351, 0.2172113300090836, 0.08072945679868422, 0.19653126146764527, 1.7039064077600357, 66.29860708790441, 78.21576395342427, 66.89658811015468, 64.95816846047678, 68.67572030713482, 61.26500198918005, 72.77320077342372, 81.63292500280565, 89.29793450140184, 4.422886179339502, 0.2655964627140953, 0.7889563842646538, 2.9636343015778452, 13.282810449600222, 69.46478351469963, 81.70443765578732, 74.54927352166946, 72.98364377790882, 72.64867336519303, 77.78185567548199, 75.77558686656337, 74.23548390788417, 81.13763163166662, 74.49703539571455, 78.2732266764487, 76.71556718887823, 77.33825914321407, 77.01471851718041, 76.183803619877, 73.13039533553585, 77.03946867296773, 76.08933725664693, 77.03544432117094, 73.82984807414394, 69.7558782946679, 60.117645955854854, 55.27960238918182, 55.021902668860655, 55.73901391798451, 55.53469765570856, 54.32063779523296, 54.26959599218061, 52.76157409914079, 54.44647135273103, 51.463187202330566, 52.263001626537694, 49.88706511835898, 54.31688016460788, 51.742679611329116, 55.19741696696128, 53.56331440710253, 58.15768072682043, 51.481139890609256, 46.67174923804499, 46.37486896207256, 48.243537102976155, 46.69932742272654, 49.232339166825824, 49.60144596715128, 50.01925683790638, 47.53233294333182, 50.497782076558764, 51.739612317854366, 51.432188710858746, 52.43508385073755, 55.97020233831098, 53.73427875580327, 54.8291220972615, 54.95853285635672, 54.5135203484566, 51.59869332467356, 51.94577601648147, 54.400740438892, 63.12667262169623, 65.50734343067293, 70.04793797769855, 62.993433629312825, 29.61952340218329, 18.34081857435165, 16.33224145058663, 47.831299920235914, 44.553810550320534, 61.522607572617076, 62.811765132411836, 60.0625523444145, 53.869184755509906, 53.60408744504375, 59.171935050718254, 59.62125432106757, 55.09557654780727, 53.078901690821496, 51.24978280836537, 55.11021091092018, 54.0212119010187, 54.58429559584587, 57.87127317920808, 50.12254853402415, 50.63265277493385, 47.31471592380155, 42.02720403671265, 47.57687930137881, 44.43272306073097, 47.090501477641446, 46.37294700068813, 45.979901975201024, 49.19081303381151, 49.36171070221932, 51.97529969676849, 52.06861288316789, 52.87438931003694, 49.59354239125406, 50.92719531828358, 52.10349059874012, 49.96746978452129, 49.060586421720444, 52.075877112727014, 52.722911296352265, 51.336341673328036, 53.49632032455937, 51.58469830789874, 53.294322183055264, 51.93657413605721, 53.38837277504706, 50.9647951587554, 53.94207416042205, 54.84655311030727, 59.70671884475216, 57.25880684391145, 62.08827218701763, 61.1096525961353, 62.56669152167536, 61.73687096565001, 66.77502601377427, 65.10354718854352, 60.60591828438544, 61.12733071850192, 63.63092468630884, 65.02480560733427, 69.37065447530439, 68.22100777779856, 77.7434007583126, 74.4056284812189, 79.54529839177286, 78.46678779971215, 84.52275476148053, 32.346935656762895, 3.5986579425873297, 0.5798631654151025, 0.27984618840198366, 8.409807778173878, 75.69895159813666, 79.35886813748267, 77.26935878876718, 71.61993765061902, 68.05629176478233, 25.57979199194139, 43.44010845307381, 64.16857965530889, 85.37289711736864, 49.71055061586442, 0.3055518090484604, 0.26011789217591286, 0.19262759916244016, 0.3590812834520494, 0.21112253979569484, 0.09765076090491588, 0.17738825641572478], [0.10844346886921315, 0.05539534666064767, 0.04781407544449453, 0.09157731543265044, 0.026792209114759203, 0.11174110966103692, 0.04490460757346404, 0.11721995599087208, 1.6753938409589952, 53.28965456255021, 45.50367916783979, 47.11755798709008, 20.982882015166744, 19.242296911055043, 42.302668171544234, 51.145443839411584, 76.70161139580512, 56.12715598075621, 0.9399578912604241, 0.06542144959131557, 0.3564991381379866, 1.0455661146871507, 27.220048750600508, 76.81207318459788, 74.4590433182255, 82.39269594992362, 74.27256599549325, 68.09217360711867, 67.05800148748583, 66.60259077625891, 69.005874049279, 74.21709583651635, 75.93664723057901, 70.44433270731281, 71.02148594394808, 72.11405431070636, 68.38570810133412, 64.65744426173549, 68.28743703903692, 66.8562190763412, 67.81041406816053, 68.21302967686808, 65.4649543762207, 59.02333605674006, 50.7546345649227, 50.780459450137236, 49.51902128035023, 50.67129204350133, 51.673602750224454, 49.92600248705957, 48.17567225425474, 51.25228135816513, 49.30448332140523, 49.5348088202938, 46.6012877802695, 46.48094554101267, 48.79576759953653, 49.547450619359175, 49.29478722233927, 49.13221282343711, 52.02412536067348, 56.11472598968014, 51.620238904030096, 42.047388553619385, 43.15575622743176, 42.11306079741448, 39.82382043715447, 43.56291394079886, 41.8728038572496, 40.82304423855197, 43.71109716353878, 42.7307987982227, 46.01159080382317, 47.93702348586052, 48.542260892929576, 48.82508339420442, 46.565229431275405, 47.56425319179412, 46.417489436364946, 48.34142377299648, 46.033293277986594, 50.445171325437485, 53.822849796664336, 60.12138789699924, 58.528109365893954, 51.93358921235608, 28.71066120363051, 21.278446335946363, 24.73884955529244, 33.64087458579771, 45.02103544050648, 52.38812523503458, 59.598029967277284, 56.670627824721805, 51.00189293584516, 45.57669016622728, 49.65141696314658, 44.78400661099342, 44.81348322283837, 44.569158784804806, 50.072918784233835, 43.09156663956181, 43.05343727911673, 43.36131588105233, 43.65215962932956, 42.49578214460804, 42.462528290287146, 40.94444551775533, 41.0344325342486, 40.86173842030187, 39.63453861974901, 40.26922125970164, 41.352497531521706, 42.43718585660381, 43.246006042726584, 45.5540894692944, 46.84898545665126, 51.229927770553104, 51.70076124129757, 46.68019802339616, 46.70122977226011, 44.47188400453137, 44.07001756852673, 46.155024036284416, 46.17644802216561, 48.43379951292469, 49.79439912303802, 47.38996659555743, 47.32320001048427, 50.28478168672132, 48.15458559220838, 48.47950689254269, 48.4123049243804, 48.051333119792325, 48.91254048193655, 48.92109909365254, 49.25532425603559, 49.82585260944982, 49.57541711868779, 51.02012019003592, 53.22255065364223, 54.72542639701597, 51.29863200649139, 51.23236748480028, 51.76686102344144, 54.4334412390186, 55.40111349475, 56.070140407931426, 58.671644579979684, 62.64703735228508, 68.33370531758955, 71.6858099352929, 70.92789819163661, 80.21205425262451, 36.642891976141165, 2.0969978888188643, 1.726307554110404, 0.08908966706404764, 2.821596452305394, 55.01637997165803, 67.56837244956725, 60.280487075928725, 56.94382090722361, 44.96867179870606, 23.190544920582926, 24.262799332218787, 39.8377291617855, 61.24148345762684, 42.44926283436437, 0.27276615702336837, 0.024861357279963074, 0.03150347556408135, 0.048866094195193825, 0.06458519567405024, 0.06761284409871987, 0.04547722765334672, 0.03826948558731425, 0.05935060881799268, 0.03156485644379451, 0.04722863105275939, 0.008500290399928008, 0.059621374933950366, 0.11098441397470814, 0.26863550286619897, 2.440387914257665, 65.31456678144394, 56.717500148280976, 53.19838885338076, 31.072451683782766, 24.971816770492065, 46.74936902138495, 61.97306825268654, 82.63443162364345, 62.34084929189375, 0.6837576195116967, 0.30806371942162514, 0.8328560415294863, 0.7737982621596706, 30.991815597780292, 82.96490700014176, 78.41820532275786, 84.44547622434555, 77.24555000182121, 72.7886470671623, 72.20045628086214, 72.97488120294386, 73.35765746331984, 74.95861207285236, 77.11344457441761, 73.2833520827755, 73.44888394878757, 75.81432419438516, 69.09026776590656, 66.87506214264901, 70.91346386940249, 70.6926187392204, 71.23633769250685, 70.21473284690612, 67.6363863483552, 61.83221986216884, 53.556787583135794, 51.808344010383856, 53.04445543596822, 51.066553208135794, 53.395048649080344, 51.929502102636526, 51.9627441898469, 54.011347140035326, 50.25474417594172, 53.02236072478756, 48.94538640975953, 49.73280614422214, 50.25239075383833, 52.9790146120133, 51.63274734250961, 50.8201499139109, 54.408098805335264, 56.85387703680224, 54.379324297751154, 46.99248536940544, 46.08447236399497, 44.461423043281805, 44.31392231295186, 44.39658626433342, 43.96569821142381, 44.05190406307098, 44.4348293735135, 46.26064954265472, 48.81343787716281, 50.685263526055124, 50.37750651759487, 51.59164874784408, 49.038291669661, 50.69448894070041, 47.97879280582551, 50.032290873988984, 50.378812666862245, 53.61325010176628, 57.558452390855365, 61.388556649608, 60.98855726180538, 53.93806549810595, 32.98711353732694, 26.025596818616314, 28.31747889518738, 37.440521640162316, 47.45386985040481, 54.40235253303282, 61.038379207734145, 58.68749880021619, 53.10990018229331, 49.94619877107682, 51.28441341461674, 46.86673418168099, 47.71979478097732, 46.89140589006486, 49.76239258243192, 45.79615462210871, 46.81278982470113, 46.68718768704323, 46.99243045622303, 44.93089937394665, 43.320064313950084, 43.739185256342736, 43.20768056377288, 44.237428249851355, 42.760957902477635, 41.79534096871653, 43.73458431613061, 45.688210994966575, 44.60441304791359, 46.24099062335107, 48.795104718977406, 52.20520942441879, 52.33159603611116, 48.796406945874615, 47.976611968009706, 47.545794517763206, 47.25465659172305, 47.32049357506537, 47.011952092570645, 50.29233224930302, 50.253853797912605, 50.287998030262614, 50.24529910856678, 52.02187784256474, 50.086023422979544, 50.0758566394929, 52.20825710604268, 49.6059057020372, 49.88533927548317, 49.94548882207563, 50.20032128980083, 49.667149589907744, 51.82844615751698, 52.62929216507943, 55.37540628064064, 55.09918905073597, 52.75290958343014, 54.36157557272143, 54.48620496257659, 56.89657203612789, 58.02008790354575, 57.81873695312008, 61.06836180533133, 65.78859306150868, 70.47589209771925, 75.65808834568148, 75.25400577052947, 80.51862670529275, 46.287788421876975, 3.2233459526492707, 0.9369985855394795, 0.0268388313106111, 2.6719891640447804, 60.92385384344286, 74.11634583627024, 68.72916652310279, 64.15167816223638, 51.45154560765913, 28.710374870607932, 30.672036524741884, 46.79702581897859, 68.37543149148264, 51.62503988512101, 0.11548492772084092, 0.05813069423780807, 0.014929916961268793, 0.019433790960559444, 0.048518635017136415, 0.035767335174304825, 0.10062524282764043, 0.18399121420037362, 0.16895047208714872, 0.17590308772219768, 0.28893104123492397, 0.09385766040894294, 0.16922405740666777, 0.2594110688134547, 0.3389349177239403, 2.9333960144750537, 76.75185695771249, 65.65922544848534, 69.6818474800356, 35.44065413936492, 30.096587557946485, 63.70967018988825, 67.273363144167, 91.82413701088198, 68.85618071402274, 1.178060714756289, 0.2370402442231294, 1.391103147499023, 2.6710735357576803, 32.5978712497219, 85.29508513789024, 81.77982561049923, 90.83589584596696, 82.64891301431965, 75.49109735796529, 76.77757986130254, 74.52690032220657, 75.99390599035448, 79.24879858570715, 80.99293539600988, 74.35000927217546, 77.33718441378686, 79.9995323919481, 73.45182572641681, 70.13734448340632, 75.13608363366897, 72.63261518170758, 74.5370121925108, 73.7800653519169, 70.6659701562697, 65.87324957693777, 54.83947323214624, 56.54291545191119, 54.980737393902196, 55.292997283320275, 56.34818546233639, 56.02003605135026, 53.09114733049947, 56.3009326688705, 53.733780614791385, 55.74533677870228, 52.21105767834572, 52.784845521373136, 53.772808198005926, 55.118710687083585, 53.88507819944813, 53.1618715870765, 57.158174514770515, 58.08790176145492, 57.59697398831768, 48.45488617497106, 49.408375140159364, 47.45123401764901, 47.29079338812059, 48.33478712266492, 46.66135495708835, 47.84731103527931, 48.2436155503796, 49.094973841021144, 52.883755930008434, 55.285403574666674, 52.76565336412, 53.11719186844365, 50.08569394388507, 53.23183882621027, 50.84920290977725, 52.58801706375615, 51.3294186899739, 56.05035205041209, 61.07229594261416, 64.91197078458725, 63.6945886765757, 58.10641142629809, 36.109720276248076, 32.27199092988045, 31.703612035320653, 42.401504055146255, 49.78152982650265, 60.177956319624386, 63.91959936388078, 62.33307515421222, 57.41457593056464, 52.26646900177003, 54.571975431134625, 48.49501594420403, 49.061225768058534, 47.87229653327696, 54.828094436276345, 47.867201374423125, 47.71606460694344, 48.99636153251895, 49.21013070691017, 47.722367855810354, 47.7557001575347, 45.2198996082429, 45.831389273366625, 48.16643507249894, 45.99559145589029, 46.450582473508774, 47.3222468745324, 47.445028828036406, 47.635707009223204, 47.99937740448983, 51.30978330489128, 52.548530563231445, 53.3362562425675, 52.25334475117346, 51.56003052188505, 50.53089864792363, 51.20591894272835, 51.83162327735655, 48.8691355336097, 53.55279853267055, 54.98057265435496, 52.4506046695094, 53.39556247957292, 54.52411074792185, 52.55335115617322, 53.116748640614176, 53.32431654776297, 53.009052122792895, 54.88398821123185, 52.46530571291524, 54.00741692512266, 53.105107045942745, 54.31737830561977, 56.055596259332475, 58.879820454505186, 58.62299542273245, 55.5663590277395, 56.25702173479142, 57.97354898145122, 58.415451049804695, 60.488866913703184, 58.698348076112815, 64.66409267917757, 67.54536382613644, 74.57408643537953, 77.94574799076204, 79.30080921419206, 84.21810427019673, 50.28441690629529, 6.005073718486294, 2.527646677147958, 0.15166886150836945, 3.573490054376664, 68.7622791720975, 79.48247771109305, 76.53267491248347, 72.27784464436193, 63.11727854513354, 35.30508133672899, 37.618946336930804, 56.08717918395997, 77.69237856711112, 64.26148099284019, 0.43301318081155904, 0.1245000282482755, 0.1451197903483145, 0.10514940570799575, 0.1440530588790294, 0.21998288290154552, 0.19279825290845287], [0.017819938647951332, 0.05044185278576709, 0.050827175859482064, 0.028420214901768395, 0.008611647982991511, 0.06932467522640383, 0.005881686003938799, 0.07283705812428268, 1.9656298670076557, 49.068356637031805, 49.01165093145063, 36.46818176392586, 29.51276040846302, 38.51995398921352, 48.781486249739125, 57.845844453380955, 78.60851087877828, 42.01173420875303, 0.11076859168467984, 0.05408843130534215, 0.4752958103293373, 3.70265027207713, 55.999706406747144, 79.99512364787441, 76.7713354479882, 76.06819568141815, 72.09161050858037, 74.35837176538284, 73.19062725190194, 71.58462062958749, 75.40439728767642, 71.17943194604689, 69.82862257188367, 71.58213384689824, 73.41777955332111, 70.32885028469947, 65.8705823652206, 63.89460602114278, 61.74911268295781, 61.026898430239775, 60.059759616851814, 60.070059760924316, 54.37860650400962, 51.79959712489959, 49.8305163075847, 48.73626916639267, 50.07800609834733, 50.05034946626233, 49.1837880688329, 50.217469892194195, 48.781141081163966, 47.30508650502851, 48.016047477722175, 50.15050326624225, 45.98820955522599, 46.279178819348736, 49.31996883884553, 50.52170068986955, 48.51595355618385, 50.15621815958331, 49.542010291930175, 49.49780910245834, 52.9251604695474, 50.17257444320187, 45.754993269520426, 40.801412367051654, 41.93543626416115, 41.66944073092553, 41.12210927471038, 42.44961192530971, 43.16500909866826, 42.382570774324485, 43.08039572931106, 44.90682778819915, 46.55342309705673, 49.86697866070656, 47.2690438455151, 45.010923570202245, 44.03839934256769, 47.069963947419204, 47.14131186085363, 48.820098061715406, 52.61796828239195, 54.211235046386726, 60.46646233527892, 57.269585517144975, 42.14968396771339, 44.39316595754316, 36.077207749889745, 45.601973764358036, 46.90878983466856, 39.20816129253757, 56.75935576038977, 57.044931765525575, 50.32736685968215, 47.14328481305031, 46.08872421326176, 44.53010374499906, 46.107508444016986, 44.05417119303058, 45.42764009967927, 45.53266940578338, 46.042228437239125, 45.477450278497514, 44.23158784066477, 41.52676451590754, 40.532941818237305, 40.30393815809681, 41.91053313593711, 42.401700173654866, 41.01090223558488, 40.0352793355142, 39.46500985853134, 43.834847942475356, 43.81595780772548, 43.419971004609145, 47.82162735539098, 48.51939739719514, 54.08213807690529, 48.121594536689024, 48.386860509072584, 45.519094082616995, 47.05858122917914, 44.50253732742802, 44.479948397605654, 47.6354952012339, 46.86995444759246, 48.02315481247441, 48.63407573392315, 47.47921228408814, 45.86737701969762, 45.83936737429711, 48.58818008053688, 50.26529927407542, 47.08918748363372, 50.780302555330344, 50.50475997309531, 50.473216272169545, 51.15233152143417, 50.23719549179078, 49.19504919359761, 49.49942904133951, 50.88225280084918, 53.702923328645774, 53.85422483567269, 53.915864882930634, 58.22894627048124, 59.138222279087195, 59.059727807198804, 63.946899060280096, 66.46561376510128, 72.81615072681059, 70.86661508006435, 74.64475185640397, 54.60140105216734, 4.527922349591409, 1.2341449698132854, 0.07015702975613457, 0.055220801187979604, 33.748798601088986, 75.27203298384144, 62.43256607363301, 63.084738562184, 47.26806325297202, 23.714304893247544, 19.857944288561423, 35.33771937893283, 62.88235210603284, 48.866362417897875, 0.9190077767256768, 0.08868635241543094, 0.09544574535421788, 0.04842486202476486, 0.02107778308732856, 0.05856271037050794, 0.03592888396533747, 0.0364124195109452, 0.06547243274267643, 0.013569855213826223, 0.05625635670918611, 0.08867921247597664, 0.047688126759303194, 0.049102815363796494, 0.11478676881280639, 2.570287498735613, 58.11179684054468, 57.13058848534861, 48.19975560711276, 35.02101936647969, 33.04789066314697, 58.17816726623043, 65.326063248419, 87.88407694908881, 44.9762890415807, 0.11523293841990734, 0.4276596664661362, 1.4506316112895168, 4.619018416250906, 61.83687571556338, 83.61272565780148, 79.83738160902455, 79.14741316149312, 75.5398210402458, 77.91302757878458, 76.40166774872812, 74.65526380846578, 76.60096337718349, 74.64992154029109, 74.5670340138097, 73.2062618194088, 75.21646868798041, 71.05643426218342, 70.21042608445691, 65.24658426161736, 63.372868030301994, 63.57502698898316, 62.29994681573684, 63.48453398673766, 56.8184188104445, 55.47576796623969, 52.424446382830226, 51.97353070782077, 53.426749244813, 50.874094270890765, 51.76258956232379, 51.84491226750036, 51.386355815395234, 49.350449577454604, 49.93740089478032, 53.498736504585516, 48.45507837110951, 47.98578246947258, 51.097124161258826, 52.494425389074514, 49.43483937171198, 51.427638761458866, 52.073715886762066, 52.25749461881576, 52.796538106856815, 53.116376015447806, 48.196009743598204, 42.664420527796594, 44.39089882758356, 44.86787080764771, 43.77201157231485, 44.19957345531833, 44.780900093816946, 44.78053923576109, 46.575662935933764, 45.44496128636022, 49.73643825900171, 51.01490736007691, 51.228107790793146, 46.98478967912736, 45.785360259394494, 49.124301402799546, 49.06204946579472, 49.732864979774725, 52.84167282042965, 57.499958084475615, 61.177474298784816, 60.47219684047084, 47.109936821845274, 46.39819137511715, 37.2461054402013, 47.04502944023379, 49.992941656420314, 40.80323626918178, 57.74605543382707, 59.112389549132324, 53.8583041006519, 48.566281487864835, 49.26109406255907, 47.86478519439698, 47.6697257257277, 46.89566166170182, 47.50322895665323, 47.24992621329523, 48.30175292107367, 47.4453975308326, 46.04763738570675, 42.1296485008732, 42.9317065208189, 42.76554707557925, 43.32724617373559, 44.93499825077672, 43.515013956254535, 42.63648932979953, 42.07948530873945, 45.702762988305864, 44.53697181517079, 44.63947903725409, 47.465676184623476, 51.26236184950798, 54.07327744268603, 50.11335449834024, 50.27069645543253, 47.09603201958441, 48.53260401756533, 48.17565264240388, 46.783415194480654, 48.87303436956098, 48.80417323881581, 51.265138887589984, 51.43227500300254, 48.4488731814969, 48.263486277672556, 47.98066377639771, 49.581253605504195, 52.19841587928034, 50.037401722323516, 51.78681019813784, 52.04316846786007, 54.41940307617188, 53.575418841454294, 51.67881165781329, 52.38880380507439, 51.2145560018478, 53.79589526884018, 55.78165792649793, 57.30217649090675, 56.75741418715447, 60.58487476841096, 60.64954288544194, 61.3499330705212, 66.31582629296088, 70.47098913500386, 74.39547738721295, 75.24029316440706, 77.22852691527336, 62.72621431658345, 6.788772104247925, 0.3254248039616693, 0.5264485122696047, 0.029325171584083192, 37.4598785369627, 82.3925547445974, 71.24914815348964, 68.86692800829488, 49.66298011041457, 25.305975252582183, 28.777265010341523, 45.35763755921395, 67.58250867166828, 61.51874011562717, 1.192554485413336, 0.06624536183212074, 0.04757363108857986, 0.03502269771190421, 0.034288245388456894, 0.05372154030708536, 0.050932317596649936, 0.14553317139225622, 0.09945344239954026, 0.13908099503286425, 0.11743410820922545, 0.36311479766042004, 0.1664143533355767, 0.12123611064687853, 0.2213594509709266, 3.8529927595969173, 72.64300161792387, 71.3626850804975, 56.390747101076194, 44.944796331467174, 61.78131926444269, 68.11233458980438, 72.32774503769414, 96.4926596610777, 52.920073155433904, 0.2823969547546679, 0.30226510799219536, 1.7201308016815495, 5.921102637244809, 64.41566936431393, 86.67781476051577, 82.38757333447857, 84.50442944803547, 77.35317983934956, 82.97237519294985, 79.21995347545993, 77.92084094016784, 79.72407217948668, 80.3596059737667, 77.05686046231177, 76.30088636952063, 80.05239809713056, 76.10632111949306, 73.18028003938737, 68.4851872536444, 66.04680661232241, 66.63103580474854, 66.77231957835536, 67.15932415377709, 60.17233556316745, 57.93836532100555, 56.47237554673226, 53.96000331447971, 56.19940996170045, 55.531140065962276, 54.61858887826243, 56.806620320966175, 54.25360056661791, 51.50821601190875, 52.05111518982918, 56.51485873806862, 50.394678654209265, 48.38582892571726, 54.685645718728345, 55.21734652980682, 51.940986802501065, 56.83187254013554, 51.842809877087994, 54.55303038320234, 54.30035521907192, 54.65185449969385, 51.94721160396453, 45.78577210826259, 47.48398973095802, 49.525881505781605, 46.920156863427934, 48.596318998644435, 48.89268152175411, 48.196739304450254, 49.042021843694876, 50.1001831793016, 52.54477685497653, 54.174906053850734, 51.35521219622705, 48.954949148239635, 48.37898831213675, 51.97753937013688, 51.97911224057598, 55.450739322170136, 55.358908791695875, 60.17620694252753, 65.88765252021052, 65.15494592728155, 46.79000085399997, 46.50240090585525, 38.52350373421946, 48.523280543665734, 54.15362327329574, 46.17726779753163, 61.33588314056397, 63.40355665453019, 55.381866424314445, 50.370650214533654, 52.32008780202558, 49.195343371360536, 51.24074566748835, 49.75979597337785, 50.10590591738301, 51.059402727311664, 49.49661277955579, 49.20259191143898, 48.868464808310236, 46.426565800943685, 45.657228192975445, 44.86525850911295, 46.855151422562145, 49.50359067609234, 46.961122097507605, 45.38029316932925, 44.124558125772786, 48.305294821339274, 44.7581228902263, 43.54424345877863, 48.01297626187725, 51.326539670267415, 57.93277986588017, 53.571688667420425, 52.59373587946738, 49.87609817135719, 51.88446152594782, 49.31172009437315, 49.28039996854721, 50.87150550657704, 51.222012427545366, 52.94528222853138, 53.904933237260394, 50.45827988655337, 50.21356713387274, 49.38773955068281, 53.34279091127458, 54.32324617139755, 50.65912092885664, 55.00183974542926, 54.45081733888196, 57.712542703074796, 57.245835565751605, 55.10803399547454, 54.0014470777204, 53.76282968828755, 55.67614616886262, 59.35198753110824, 59.551981341454294, 58.97590283424624, 65.17551091409499, 63.49448503986482, 63.72152751491916, 70.28765755314981, 73.3513032236407, 78.01767641498198, 79.34805024054744, 79.23739233324605, 66.34076472251647, 8.68939334346402, 2.716572539460275, 1.1682680273248305, 0.1452595707509787, 50.397655733170055, 87.42132356089931, 80.60564840993574, 76.44430391250118, 64.96869610201928, 35.13407384195636, 31.733035695168283, 52.59339855563257, 77.54567407792615, 76.37161454846783, 2.500993191234527, 0.3785563110103531, 0.2695260034693826, 0.13964760898342057, 0.1505642699738664, 0.17478271477645443, 0.174112954747773], [0.10662705907898565, 0.030860143653567762, 0.04507832184073426, 0.04786430016881035, 0.040600162540231986, 0.11112730469434492, 0.007461221407978766, 0.059845608869387265, 2.1969335069579463, 35.19010882223807, 43.9155154074392, 29.655717072948335, 19.079508742978497, 37.53876916823849, 51.75124999015562, 60.3561495965527, 78.12114069538733, 22.882356451403712, 0.6306060716029137, 1.449073572312632, 3.135636607485433, 16.6877866560413, 82.14564154225012, 74.39900752036803, 78.29861225620394, 78.06381133294876, 72.6262923209898, 71.98622426679059, 74.05368205039733, 68.45678929359683, 72.1012830734253, 76.59901003683768, 72.25842106726863, 70.57277464097547, 71.66317785939863, 69.6331787109375, 66.29728132678618, 64.45609331130981, 60.472428260311005, 57.812304266037486, 54.49000966164374, 51.65841533291725, 50.32546451014858, 51.31522363232028, 51.14375722023749, 52.39439318256994, 49.929101159495694, 49.48897984720046, 49.11266373049829, 46.776621649342204, 47.66036302812638, 49.83232059786397, 47.414198998482, 48.4319559989437, 43.332988523667865, 45.3531386006263, 48.603469479468565, 49.50654814320226, 48.65771193658152, 49.133358155527425, 52.62580910036641, 50.80655105652348, 45.26376347387991, 48.54958395804129, 49.131608778430575, 45.39215049436016, 40.88170328447896, 41.00076290868944, 41.87450224353422, 41.94462637747488, 43.08962506632651, 40.71532418650966, 41.702357261411606, 42.168185787816206, 40.33439144011467, 44.10189074854697, 46.78430949487994, 50.10094019674486, 55.44023129247851, 55.43914479594077, 55.82719272182834, 53.673560465535815, 50.07241672085178, 53.190238168162686, 52.86671715397989, 59.9205860783977, 51.51783366357127, 45.33021234696912, 45.45276288063296, 46.429523268053615, 46.078682945620635, 35.118568712665194, 58.47221166856828, 55.69906457777947, 50.90314334438693, 45.15391357483403, 47.7852552167831, 42.453702957399436, 44.83113781098397, 44.01233911514283, 46.67269845162669, 44.00552988052369, 44.21627882988223, 42.708347151356364, 42.08163868996405, 40.79655647277832, 41.034965976592034, 41.621615271414484, 41.95847234418316, 41.45589513163413, 41.84415094314083, 41.35562758291922, 46.89368870950515, 44.56793892768122, 45.572905079011, 45.232541407308275, 45.24483411542831, 45.40114841153545, 47.7170491218567, 45.93448485097578, 46.81321344067974, 46.560310779079316, 43.13379095446679, 42.31684361734698, 45.31428752406951, 47.82924067589545, 47.638809604029504, 46.693541926722375, 49.523720279816665, 47.76250939215384, 49.78134155273438, 48.78026639261554, 48.34844089323475, 48.188925943067, 47.524437212174945, 49.710256438101496, 49.54976089539067, 49.16232093687981, 50.04694877132293, 51.65377124663323, 52.44788646697999, 52.86266926796206, 53.82801948055145, 55.35306446013912, 54.939411301766675, 55.803450615175315, 55.47417156157955, 59.523289203643806, 60.70888834614908, 65.8147435034475, 68.23570097646406, 71.97555541992188, 72.85878689058366, 75.61270652278778, 60.432047459387014, 16.82223766080795, 0.890809796269863, 0.2927591825925535, 0.47574145899664977, 16.434306425433007, 72.4366927916004, 64.5562235770687, 60.891509979001945, 56.37355143024076, 46.701865196228034, 19.1367773086794, 35.955061220353656, 58.52041759798604, 46.992324552228375, 2.1735735862485828, 0.18359128566038224, 0.13810470790391968, 0.09849380236119033, 0.014279557151659844, 0.038886860523733406, 0.06188344105236954, 0.03716811545253281, 0.05275959051364372, 0.029358852639674183, 0.040836370429925384, 0.06154494510302621, 0.04670233630965795, 0.10315564656329733, 0.1284043723717332, 3.068102953895446, 49.05265538923202, 58.42352328761932, 42.77115998729583, 27.154672645753433, 48.4336426181178, 58.347421461536044, 69.17714826522335, 84.70095588314919, 25.27254096923336, 0.6923613997717059, 0.8930896739325217, 2.0904514530012688, 20.25129722010705, 85.58692516819124, 78.61356289156022, 80.8948604522213, 82.34496854966687, 74.72375623641476, 76.52779548398911, 74.42715444872456, 71.40947895665323, 76.0824260404033, 77.72869187016641, 75.60678374382758, 72.33914344541489, 73.0047147504745, 72.65507467331426, 69.14096047801357, 64.8111697935289, 63.12110285605154, 60.31033631294005, 56.19894319964994, 55.03394042291949, 54.36269737059071, 53.54673847075432, 53.9673577585528, 54.45694015872095, 53.92814190156999, 52.12140406331709, 51.53392322601811, 52.169005947728316, 49.36024373577487, 52.84708569126745, 50.176571338407456, 50.71675623616865, 49.12012015619586, 49.071847546485166, 49.9682895598873, 50.80386815532562, 49.456028015382834, 52.3833477881647, 54.21738140044674, 51.16571857083229, 47.31026403365597, 48.843098840405865, 48.66814151886971, 48.47423914940127, 43.61313596848519, 45.11627058829031, 44.293286723475305, 45.56556240204842, 45.59778859538417, 45.021047207616995, 45.01861926048033, 44.55977647535263, 44.3911341697939, 46.00262034323908, 47.347514783182454, 50.808790729891875, 56.814429759979255, 56.373986813329886, 59.29466993578019, 56.906546623476096, 53.485722080353774, 56.0340859813075, 56.296402331321474, 63.6861438135947, 52.2841824254682, 45.48279254667221, 47.84592251623831, 47.113051183762096, 46.053277754014545, 38.90091811456988, 61.24186392753356, 56.804659135880016, 52.3593036590084, 48.392367516794515, 50.64859720968431, 46.07200314921718, 46.34831059363581, 45.59236003506569, 49.7885508691111, 47.01840831387428, 47.28799673818773, 44.21693778807118, 43.67500351321313, 43.80361018642303, 42.87035280658353, 44.17676879513649, 45.362795475990545, 43.54460039446431, 45.76050419961253, 44.09478341379474, 48.43556065713206, 47.14959590665756, 45.0181132747281, 46.138604994743105, 45.233204287867395, 45.5487903471916, 49.37201084629182, 45.85626886736962, 47.212624472956506, 48.88016523853425, 45.365199888906176, 45.78825496858167, 47.33285296347834, 49.53099235411614, 48.88432295091691, 48.38544453344038, 50.55151854791949, 49.52284166889806, 50.075609530172045, 50.126117890880955, 49.23571632754419, 50.10097157570624, 49.77022163329586, 50.5031321894738, 52.69356804509317, 52.44561933702039, 50.96323013305665, 53.61733328911566, 55.39196652750815, 55.0265428327745, 56.28178758005942, 57.921204951501664, 57.60797623665103, 59.17506117974559, 58.50918000744235, 62.24582987446939, 63.27008231993645, 67.56837244956725, 70.10692258034983, 75.10552052528628, 75.60981965834095, 78.83669868592294, 63.55719589417981, 21.683485969420403, 1.3663836352286802, 0.2084075548355618, 0.31168802010436214, 18.293220612310595, 79.38097461577385, 71.55073135129868, 68.50131603979295, 62.21321536648659, 38.03429788158786, 24.495650837498328, 42.53626100478634, 63.439866035215324, 59.823123024355986, 2.1765491943205557, 0.2598762986881118, 0.055997269603634076, 0.016551274062705137, 0.02904255408793688, 0.05813347130653359, 0.029715799816673803, 0.22150850103747463, 0.16337834689165318, 0.14712517870770347, 0.0750280619268456, 0.22845200022622464, 0.24884040377313094, 0.3102201037108898, 0.24360923366921566, 4.716653073987653, 64.04400517863613, 66.74930311018421, 46.809369517910866, 30.380980968475345, 63.99991381552912, 66.96859498177805, 75.87358336294852, 92.94957483968427, 29.625905098453647, 0.7446650415658952, 2.536502898700776, 7.274506168980753, 20.078565843643684, 87.91292990407636, 83.04708065525179, 84.58843877238613, 86.4566558407199, 78.18101175369756, 77.72989211543914, 79.863386923267, 76.83589766102453, 80.20434287286575, 79.39402826370733, 77.82832791728359, 75.02028742144185, 76.6583162738431, 76.93076410601216, 70.58810326360887, 70.23109697526502, 66.9235897064209, 65.61830728284775, 60.406697180963334, 57.11817418375323, 54.98693866114463, 56.84065080458119, 56.90985318153136, 58.70278035440753, 53.975943826860004, 53.97304519530266, 52.72659440194407, 53.12567203275619, 50.42341393809165, 56.83408475691273, 53.01633204183271, 53.48405507303054, 51.30906551114975, 52.253580093383796, 53.39167148836198, 53.85720191463348, 53.585346360360425, 55.223469349645804, 55.897548275609175, 51.94764698705366, 46.20313975118822, 50.85923241030786, 49.98841916361163, 50.73924710673671, 45.838022001328014, 47.31946199171005, 47.651694590045565, 49.093012655934984, 48.59875479052144, 47.86181203780636, 48.29047218445809, 47.75254264954598, 45.143401622772224, 48.45691404035015, 51.00827463211552, 54.2024254029797, 61.15006869839084, 61.97837914189985, 62.80632088261267, 59.97510310142272, 55.616612434387214, 59.13557467922088, 58.886578698312086, 65.07767131251674, 55.614035437184, 49.99835452725811, 47.92928857188071, 47.69646844556255, 46.556780645924235, 40.55858627442391, 63.967381677319935, 61.32386892072616, 56.828479689936486, 50.78612727503623, 53.107158445542865, 48.24077967674502, 50.80524882962627, 49.62346615329866, 52.23372113320136, 49.961225371206964, 50.31023394676947, 46.97561133292414, 46.18918003574495, 46.22313991669686, 46.73272248237364, 48.860192529616825, 48.16718032283168, 47.65493054543772, 49.01029771374118, 46.729109979444935, 51.84222152156215, 48.46668466444939, 46.102821211661066, 47.24929471169749, 44.12231845240439, 47.83953689759778, 52.00073234496578, 50.50995319120346, 51.41604815759967, 53.31997056161204, 47.994015524464274, 48.08084895533901, 51.1964621082429, 51.59866194571219, 52.148378202992106, 51.004705275258715, 52.69735313230946, 52.03065610701039, 54.43743813422419, 52.62492264470747, 50.80855538768154, 52.83236503601075, 53.017359702817856, 54.832762056781405, 54.964636064344845, 55.088218181364006, 54.6795738897016, 57.97833427306145, 58.17972052481867, 57.2883972044914, 59.18551037388464, 61.98588655840967, 60.887732736526004, 62.45235835352252, 59.37729466346003, 65.72853765180035, 66.87838831255513, 70.88014725715884, 73.22251612140288, 79.61456744901596, 78.31586284022178, 82.84154061348208, 63.17273693699991, 22.30398924120011, 2.347616014942046, 1.3879668448240527, 0.6316222719127133, 24.33644183220402, 85.59458163476761, 80.45163262274959, 73.79655499612132, 77.65180557004868, 66.86618974131923, 28.035933125403623, 51.68612295581449, 69.40453590885286, 77.61773586273193, 4.6070762699650185, 0.42120647887068413, 0.32236072805620014, 0.27149438978202883, 0.1029145127282508, 0.15956543536195833, 0.21533727976343325], [0.04107474251800487, 0.043671336250319596, 0.07874829213946097, 0.05531598761257145, 0.1200887484235629, 0.0860840283454426, 0.04485234888570924, 0.16914657527400603, 3.1435654336406342, 42.84053102616341, 40.272096357037945, 36.826043128967285, 34.311690099777714, 35.382979608351185, 58.41933027390511, 61.58102735396355, 78.73706263880577, 10.217535034302744, 0.38384866089590136, 0.4663097521951122, 1.3343198525328792, 50.30022013571955, 80.35065512503348, 77.7921401300738, 74.6008840683968, 72.43567297535559, 72.23232946088238, 72.72433588581701, 73.02447565140264, 69.45394992828369, 67.42082857316541, 71.51157825223862, 65.48953979246079, 79.83444767613565, 68.32129493836435, 66.63850399755663, 65.71238140906057, 66.4330659374114, 61.22564492687103, 59.9848384241904, 55.6839556078757, 57.3104723038212, 54.5473272569718, 54.528597939398985, 52.04709476040256, 50.1792581619755, 50.11704544867239, 50.1874755274865, 48.676578537110366, 50.78884939993582, 47.97726308145831, 47.740763771918516, 48.82017258674868, 49.510972576756636, 44.94223894611482, 47.74151294462143, 46.27690776701897, 47.76285848309917, 45.6425428390503, 49.991639429523104, 51.78204059600831, 49.79337930679322, 48.944288146111276, 48.89874550604051, 42.15060180233371, 48.18325027342766, 45.69964470401887, 41.22325935671407, 41.64362369045135, 43.525604355719786, 42.54949115937756, 41.562261965967, 42.60775012354697, 44.2927062126898, 39.60628970976799, 45.35801018438032, 42.61149206469136, 44.370518192168205, 47.56556326343168, 49.20625148280975, 54.482941550593225, 60.04101460979831, 56.17615815131895, 61.53115441722255, 53.99787379849342, 68.20389055436658, 45.32979265336068, 39.293453231934585, 52.799248464645885, 48.30025849803802, 38.67122411727905, 45.487860248934844, 61.931177339246204, 51.57238598792784, 57.420051559325195, 54.25858197673675, 55.89441430184149, 47.24861221928751, 45.86339581397272, 42.99390354464131, 45.99083754324144, 41.349355713013686, 40.88565311124248, 40.580912405444735, 42.12067019554877, 40.91525131656278, 41.06144981999552, 40.63180908080071, 40.6447882037009, 41.84560222010459, 45.581620585533884, 46.01528175415532, 47.004056361413774, 43.952228792252086, 46.27679794065414, 47.02819854982438, 43.34961152845814, 46.06979093243999, 48.68725915108958, 43.28867750783121, 47.270318615821104, 46.73418552644792, 42.1898215816867, 43.991758438848684, 43.83538530718896, 49.32147110662153, 46.55871045204901, 47.45814131152245, 47.106587117718114, 48.31953302506478, 45.91505342914213, 48.97457276621173, 47.2925349204771, 49.60682353665752, 48.302564851699344, 52.33501634290142, 52.42355992717128, 52.20728828061012, 53.11279881385065, 53.44223476225331, 56.45699593328661, 61.85028629918253, 60.16194128221082, 59.42140956078807, 56.9397141856532, 59.71775639441706, 58.986720731181485, 63.17794976695892, 66.45131280345302, 69.35786754854264, 67.13608018813595, 73.64865026166363, 72.78604261336788, 67.12819622408959, 73.62478656153526, 25.305243730545047, 0.5917410216023845, 0.38183642371046933, 0.12555923673414415, 5.842946469783784, 66.68629415573614, 64.50481699359032, 62.84047295970302, 54.477767944335945, 47.53171713121476, 27.513545982299316, 37.47810186878328, 52.843233923758234, 64.82990695584205, 5.471831906226374, 0.32498264865529153, 0.14341876872124212, 0.09408187902262134, 0.04842541743850997, 0.10330459703841519, 0.042651194418149616, 0.0471204977422472, 0.020323194142791535, 0.13809785907787664, 0.06296117354424731, 0.0341171128374915, 0.07289600092917681, 0.14942135872139087, 0.1853865514238996, 6.419420646082971, 55.4119510035361, 50.748531356934585, 45.719770385373025, 24.783492011408654, 38.42110633850098, 66.53372964551373, 67.81232818480461, 87.94772132750481, 10.409693910229592, 0.4114060079859149, 0.3826388548458777, 1.370696894103481, 56.303780309615604, 81.72513208081646, 80.89955945168772, 77.41344313467704, 73.4364265011203, 77.38548448008876, 77.07667627642232, 73.96366365494268, 74.0705168631769, 71.44330547701928, 72.65219565360778, 68.584423219004, 80.35915882356706, 73.24602680821573, 68.57139310529156, 67.54295549085064, 69.10361951397311, 64.02749592258085, 62.1503476173647, 58.50864656509892, 59.53547600776919, 59.436542064912864, 58.660461902618415, 54.91172721309047, 53.54233757142098, 52.40738407258065, 51.976197919537945, 52.00367412259502, 53.04308260640791, 51.216536798784816, 50.07482897850775, 49.6300910365197, 50.82286419407014, 48.288840478466405, 49.45219978209465, 49.48439067409885, 49.15842994566887, 46.67456549982871, 50.746464267853774, 54.05264185320947, 51.14644404380552, 49.24447890250914, 49.81130061611053, 43.75024634022867, 46.23991981629403, 47.23115374965053, 45.07085346406506, 41.70238079563264, 45.7909143355585, 44.460673870578894, 42.68077288904498, 44.43276620680287, 47.62956457753336, 42.845461445470015, 47.06453930947089, 44.27056051069691, 44.822528208455736, 48.8302020872793, 52.06717729568482, 58.11076525718936, 61.74962259108021, 60.155908676885794, 64.51736073340139, 59.11606873235395, 66.93199142333, 50.263302787657715, 43.65079856687977, 51.98816899330386, 52.40640348003757, 40.34699009310815, 47.257465008766424, 64.9007567282646, 56.53965988466817, 58.4480655577875, 57.27669285189722, 57.50191142482143, 51.29869868678432, 45.75336940826909, 45.059949274986025, 46.63573403512278, 44.738471815663004, 44.566966179878484, 42.548745909044825, 43.804830043546616, 43.825634294940585, 43.33957418318718, 45.01151584809826, 44.4244860833691, 44.315573630794404, 46.410731192558046, 47.99199550382553, 48.339862669667895, 42.76943414442001, 45.03753292945124, 46.34071688498221, 43.77865214501658, 47.121256782162575, 50.27339112374091, 44.72819520581154, 47.239849644322554, 49.613397429066325, 44.83749205066312, 46.79373102803385, 47.43268512910413, 51.819126605987556, 48.6651252162072, 49.286232532993445, 48.15294604147635, 50.52545439812445, 48.65374249796714, 50.4056965920233, 47.89728987601496, 51.383288521920484, 51.73302273596487, 55.6564558705976, 55.13156821650844, 54.5167366919979, 56.1364951441365, 56.651055197561945, 59.54665868513046, 64.58621401940623, 62.73174093615625, 63.237640396241225, 60.030271237896336, 61.99782625321419, 62.87142438273277, 66.55211771688154, 68.26776243025257, 72.42949131996401, 70.75954221910047, 77.77717236549624, 75.29582608130671, 69.97019660088324, 73.0899086306172, 29.53498651904445, 1.0495114062101611, 0.1591213954792869, 0.18471902837195706, 5.9962076910080455, 73.55013601241573, 70.28477853344333, 71.51577518832299, 61.924136684786895, 45.3772258758545, 23.84222907404746, 46.57807911595991, 59.17362559226252, 76.78034120990385, 6.97055091781001, 0.43496357937974317, 0.09487128666331691, 0.06643321425203355, 0.04420785826721019, 0.057206512579033454, 0.038565049969380906, 0.12235531913897685, 0.142735893267297, 0.2670146446795233, 0.2449050254278606, 0.18617405916654295, 0.2388883547316636, 0.2828426647090143, 0.4614234595529495, 8.959679949668146, 71.39180475665678, 59.18920916895713, 55.852158607975134, 49.69173108377765, 52.341405883912124, 77.10337977255546, 76.71974059074157, 95.29862742270194, 14.174547579980667, 0.5442602403702275, 3.0229226427693523, 5.560722129960214, 58.91045808792115, 82.60266042524769, 85.17024394004576, 80.6115633441556, 78.2598670836418, 75.17619379105108, 78.5754374534853, 76.66322708129883, 75.73428430864888, 73.17704800636538, 75.9630604713194, 68.32220492824432, 78.713622554656, 77.18103485722696, 70.7496343120452, 70.84240621136081, 73.00782911239132, 69.2923012087422, 65.62562642558929, 61.058316615320024, 62.480195414635446, 60.52021449612033, 62.20243669325306, 58.17260534532609, 56.04075793297061, 55.328314304351814, 52.808054185682735, 56.51914981103713, 55.41896812377438, 53.356240718595444, 50.784507336155066, 53.23290178852697, 54.10113411564981, 50.048117637634284, 52.026557230180316, 54.08687630007344, 51.7877790235704, 48.4939569042575, 55.25476594125071, 55.47173576970255, 52.432522543015025, 49.943731600238436, 49.51209045225575, 44.038681753220104, 48.11311437237648, 50.61138960622972, 47.89113959958477, 45.39168373230965, 48.90718644665134, 48.79439869234639, 45.53927075478339, 47.51999316676971, 50.11123641844719, 45.646602492178644, 49.86617065245106, 47.28881651355375, 48.707992799820445, 52.54005432128907, 54.6075709404484, 63.119514296131754, 64.43326119453677, 61.67508971306586, 65.910198303961, 60.15532816610029, 69.26719019489904, 58.489615225022845, 49.35542706520327, 54.26765834131549, 54.05690939195695, 45.94857792700491, 52.52914228746968, 67.9814450971542, 57.84737025537799, 62.48076023594026, 60.048420044683645, 61.48072842628726, 54.85566869858773, 48.20635695611277, 46.324980335850874, 50.789931974103375, 47.687925523327245, 47.69444450255364, 45.466538244678134, 49.27686199065178, 47.4062640436234, 46.910774553975756, 47.930865364689986, 46.860591749991144, 47.595879262493504, 49.35218718744094, 51.04181874182917, 48.420357550344164, 44.549794043264086, 45.60752391815186, 46.96405995276667, 43.29880506761613, 47.32812258505052, 52.502230905717425, 47.60171182693974, 51.87435357801376, 52.34890153331142, 46.74506618130592, 49.473004033488614, 49.96911717999367, 55.303320961613814, 50.63268023152506, 50.90610865623721, 50.36956371799592, 53.90750238972326, 50.177783350790705, 54.121597120838786, 51.689213783510276, 53.74330805193994, 53.49466116197648, 57.95335269743397, 56.69770002365113, 57.602951680460286, 59.058974712125725, 60.09721040725709, 61.75517274487404, 67.53017640882923, 65.19554638093518, 65.53017554744598, 62.22721822800175, 63.142832786806174, 65.77659845352173, 69.36920319834064, 71.66822202744024, 76.77981561230075, 72.03702680526241, 81.66540222783243, 81.69354131144863, 70.20176549111643, 69.9960607097995, 32.14315479801547, 1.3631904581862113, 0.7259457137796187, 0.1864016485670882, 8.074855506420135, 84.46860251888153, 76.84295008259436, 80.98408652890114, 69.97775893057548, 64.55517630423269, 39.89046150638212, 57.12636017030286, 66.2473181755312, 93.61013335566368, 12.360459220024849, 0.6135104824939083, 0.18521854834210488, 0.21393281077184986, 0.12391315127212195, 0.25241112426644374, 0.18385523359381384], [0.02307039501536037, 0.03150654757665771, 0.05710704372294488, 0.04948673266617041, 0.024185757746078798, 0.08593203650126535, 0.13712201627992815, 0.14065817088609742, 5.020429367019284, 41.828434005860366, 42.27971053892567, 46.71125535042056, 37.51006526331748, 45.773914783231675, 59.62056790628741, 64.6880191372287, 69.37108593602335, 2.222450731262084, 0.10406830242925114, 0.4222478068644001, 8.199214252733416, 78.77900062068817, 74.26097146926388, 81.71244713567918, 71.07503414154053, 75.35415172576904, 69.68751922730478, 82.16610062506892, 70.06439624294158, 72.73069012549617, 64.21940572800176, 75.29126828716647, 82.8727783695344, 73.99598398516255, 67.75816025272493, 71.6621894221152, 66.97422750534551, 67.03678930959394, 62.75062322616578, 65.22829424950385, 64.49867848427066, 63.793079391602554, 62.91505290615944, 63.408522375168346, 57.34481265467983, 54.259162487522254, 47.98549613645, 50.49061198388377, 45.9042747559086, 47.84241199493409, 51.24530738399875, 50.08433680380545, 48.358439014803984, 51.8488032587113, 45.973767388251524, 46.855284783148, 45.75908822398032, 48.36669952638688, 46.12456683189639, 45.9408155564339, 52.490146083216516, 49.378886761203894, 49.856129384809925, 51.74485652677475, 40.71249223524525, 40.66546693924935, 46.043224719262895, 52.31702050855083, 43.73614541945919, 42.56318023127895, 39.652820787122174, 42.94257933093656, 41.953302660296046, 43.17821571903844, 42.52700813354985, 42.46778426631805, 42.33558862440048, 41.574601742529104, 40.46787754181893, 42.08858128516905, 41.36169941194596, 46.3068550632846, 48.78394949820734, 52.3065830815223, 51.43629935479934, 50.33731006806897, 44.37633114476358, 43.16518560532601, 46.10381357131466, 50.283522605896, 39.74745973463982, 38.59549099399198, 53.39055753523304, 58.69558280514133, 55.474304922165416, 53.83489539546352, 48.158927655989125, 49.536075745859456, 43.04571413224743, 43.112100247413885, 41.200725340074115, 41.23291623207831, 39.65178920376686, 39.482613455864694, 39.76302762185374, 41.60188182707756, 40.598617984402566, 41.80352695526616, 39.76771485420966, 44.46476098029844, 45.5321281186996, 50.725283468923266, 45.285564007297644, 42.82875999327629, 41.28045535856678, 42.80135831525249, 41.67599501148347, 46.70783112126012, 49.89883615124611, 44.159612348002774, 44.124381619115034, 42.72583307758455, 45.05275957046017, 42.77152084535168, 45.72956846606347, 46.91498717954082, 46.945311023342995, 46.40054479722054, 47.623951665816776, 46.72645845720845, 46.137585178498306, 47.38121971007317, 48.70170916280439, 49.00304525129257, 51.304523406490205, 51.68367931919714, 53.90936159318494, 54.580694860027684, 56.52807320317915, 61.66343242891374, 61.5152923522457, 64.4802119654994, 63.669120727046845, 60.445948339277706, 59.75864710346345, 60.89758180802869, 61.05823424554641, 66.49114839492306, 67.93829118051838, 70.05693589487385, 74.61043896213656, 72.0884176992601, 70.38915280372866, 84.00924590326126, 54.95543026155042, 34.51108770985758, 2.2490265052164755, 0.27059524770705934, 0.08549263911141504, 1.5666223485623638, 59.996632991298554, 65.28221899463286, 67.91844398744645, 49.83147336590675, 74.30878516166442, 32.87731266790821, 24.768020222263953, 50.5704322168904, 69.16906033792804, 14.555228314092084, 0.5895998364975376, 0.10432630552039032, 0.15344741123337902, 0.05752900112119894, 0.07086302574363447, 0.09359221094317975, 0.04099383980276124, 0.04765660224121906, 0.14592315611099044, 0.08532309619289252, 0.06948208331220573, 0.07394920328571912, 0.15499247268082636, 0.21368928674247958, 7.869797425885355, 56.98741020694856, 55.37395500367688, 55.5119949771512, 38.99410970749394, 52.8780214248165, 67.97840133790048, 69.69482268056562, 78.21308105222641, 2.3840219839926693, 0.072879568343201, 0.6481800672988738, 11.770664184324204, 85.18971458558114, 77.57897500068911, 84.33829353701684, 73.31459768356817, 78.38199400132703, 72.41820273860809, 85.397443309907, 70.49857908679594, 75.74368230758175, 68.45344743421002, 73.43829354932232, 77.494887228935, 76.7294131555865, 70.83413001029723, 72.30166912078857, 68.1920293069655, 68.43880130398658, 66.27928549243559, 67.85758449185279, 65.56653199657318, 68.02706226225823, 65.01613324688327, 67.25700686054846, 59.766664428095666, 55.53976928034137, 50.25857633160007, 51.2234950834705, 50.012388767734656, 51.975770381189164, 51.41356529728059, 52.68926520501414, 49.92215464192052, 51.880621525549124, 50.02573659343105, 49.420303067853375, 48.6776924902393, 52.06525533430038, 49.186435668699204, 49.77230833422754, 52.74636706998272, 51.42724260207146, 49.45933849580827, 51.25279126628753, 43.060575992830344, 42.15668539847098, 46.95792928818734, 54.025899133374615, 45.367769041369044, 44.99255511068529, 42.48673323662051, 46.117016269314675, 44.48817753022717, 46.242132033071215, 44.68715152432842, 45.52104350059263, 45.868204639803984, 44.83855501297982, 42.55726137468892, 43.24904587961013, 44.030378095565304, 47.76514522490963, 50.10831033029864, 54.90056022520989, 54.81992021683724, 52.67586638850551, 46.86323542748728, 46.69120027172951, 48.11575020513227, 54.09079867024576, 43.76249982464699, 42.484442572439875, 54.75646018981934, 60.848246236001295, 56.66743109303137, 55.20903110504151, 50.23341824931484, 51.627867914015255, 43.79892295406711, 44.99838375276135, 42.78245249102193, 44.69370188251619, 41.45320438569592, 42.92315183147308, 41.4642733143222, 43.73166999509258, 42.7622522846345, 43.73748687005813, 42.73707851286858, 46.734832717526345, 47.648897940112704, 51.08968342504194, 45.095372200012214, 42.92418733719857, 41.41528291086997, 42.89005487195907, 41.642062587122766, 46.684857799160866, 52.39014525567332, 49.06283786219936, 46.562911310503566, 44.87617054293233, 46.47691726684571, 46.329989202560924, 47.479867319906916, 48.738536296352265, 48.4399615564654, 49.04847022025816, 49.390849990229455, 48.4997659344827, 48.13186722417032, 49.483037456389404, 51.12082704421013, 51.441853430963334, 52.25255635476882, 54.98150617845597, 56.290624680057654, 55.84530230491392, 59.733328204001154, 63.643660622258345, 63.047507424508375, 66.47244653394146, 66.68073223483178, 64.87746177181121, 62.4712053422005, 64.75728427210163, 62.88897306688371, 68.1174885842108, 69.05018898748583, 73.63280388616747, 76.41879281690045, 73.81343687734297, 72.0533360204389, 82.90475353117913, 58.11416595212875, 41.33799652899466, 2.4502168836132174, 0.09497578105618877, 0.0842657722833176, 1.384906660645239, 68.12590599060059, 73.74642710531913, 75.57078423038607, 57.93889484097881, 59.329429980247255, 32.859958141080796, 35.988295462823686, 52.87005116862636, 80.79070583466562, 19.030908615358417, 0.6044545264974718, 0.1895632168218013, 0.20905249361549655, 0.03482954779399499, 0.09055071930971839, 0.03850624122987351, 0.21826952725889223, 0.1689967744412922, 0.2273081237029645, 0.16286332130191788, 0.24683714513817143, 0.26701044651769823, 0.24193810479294872, 0.31006232024200503, 11.611331624369468, 70.87791150616061, 63.649987405346295, 65.87543825949392, 52.06496507890763, 71.74062898082119, 75.32492222324495, 77.28234183403754, 87.04956916070755, 3.8405642394096624, 0.16073589513619102, 1.2050109524880688, 9.532605851850203, 87.84617116374355, 79.03788489680137, 89.42687849844657, 77.1098046148977, 81.92187816865983, 76.15111458686091, 85.13081627507364, 75.60052364103257, 79.11845038014074, 70.75158765239101, 73.93154728797175, 74.3660125424785, 83.18608945415866, 75.04802642330047, 76.09546399885609, 71.07582646031534, 73.3864398156443, 69.00834514248756, 71.08440076151203, 70.37410659174766, 71.13966695723995, 66.31726972518429, 71.07672860545497, 63.15549419772241, 59.91295314604237, 52.664738624326645, 54.95056260016657, 51.1101621197116, 53.32297901953421, 53.38252059874996, 56.04950481845487, 52.330136914407056, 56.692024354011785, 52.21911422667965, 53.33708778504403, 50.991584947032315, 53.513570908577215, 51.87765229132868, 51.46392853029313, 55.205744158837106, 52.75103861285795, 51.40547736998528, 50.8125130591854, 41.919397692526545, 45.36743563990439, 46.57267408986246, 57.51324707461942, 49.44225657370783, 48.67800235748292, 44.290882310559674, 49.204345210906006, 47.33324520049557, 48.93448614305066, 48.54570865631104, 49.66958538178475, 47.92698221821939, 47.23436224845148, 44.955371041451734, 46.60360982341152, 47.05902837937879, 52.425736842616914, 53.55730533599854, 56.34742060015279, 58.41546673928538, 56.27018913145989, 49.08306160280782, 46.9143674450536, 51.31749076227988, 57.70273285527384, 46.88688339725618, 45.72941157125658, 59.04671338296706, 65.1252692745578, 60.97706079483033, 57.73228006978189, 53.58109058872346, 55.24913734005344, 48.70818891832906, 48.10798783456126, 45.9551243628225, 48.04276274096582, 46.1099991490764, 44.69440398677703, 44.64840242939611, 47.30201921155376, 45.29723698093046, 48.3684685153346, 45.09966327298073, 51.89518136362876, 51.093672475507184, 52.16113375079248, 45.63707113265992, 44.49940727603051, 42.70562502645677, 42.621949103570756, 42.12975832723802, 47.735256764196585, 54.62086777533255, 48.57675029385475, 48.07889953736336, 47.41441865121165, 51.13363358282274, 48.2100518288151, 50.36168759868991, 50.51573868720762, 50.741239670784246, 50.50147302689091, 51.73904357417938, 51.309587186382664, 50.221498166361165, 51.83754213394658, 54.07067298889161, 53.74191953289894, 56.459490560716205, 57.349613635770744, 59.57610391801404, 59.01977846699377, 62.17273650630828, 68.08487015385782, 67.4774597537133, 69.01083192517682, 69.61591243743896, 67.18125020304035, 63.9521118902391, 67.3867980895504, 66.17044756489416, 72.82787861362581, 72.17707895463514, 76.17342502840104, 79.531279840777, 79.82072722527289, 72.3555781764369, 82.3597558852165, 64.46852722475606, 43.421367368390484, 3.0690404003666294, 0.555857524516121, 0.2675673617951332, 2.0065352849421965, 78.4730008340651, 79.34804239580708, 84.97647100879301, 66.65654690034928, 92.00985339380081, 45.18125641730524, 43.115842188558275, 62.17173630191434, 91.70971362821518, 26.605179963573335, 0.8255340182973493, 0.35673025154298355, 0.3211977453001084, 0.13704778236006537, 0.1913109544904963, 0.18909722085921996], [0.03682603421170385, 0.07165071734737966, 0.053463583181221644, 0.04301207545664042, 0.04572052951721896, 0.071140096763209, 0.071514866975767, 0.1727598136471164, 5.149223333404911, 54.51925093127836, 39.635895759828635, 56.06398620913106, 51.08781245446975, 45.50172190512381, 62.0457576167199, 68.74806450259301, 55.618789349832845, 0.47912992717277625, 0.11029889551742424, 8.144443746536009, 49.70936606007238, 85.76329062061926, 75.47849870497181, 76.80773504318731, 72.53894113725232, 77.17829704284668, 66.68321901752104, 73.03898057629986, 77.09819439918765, 73.60704960361605, 64.95804686700144, 70.01071468476327, 56.72794934242003, 62.807646643730905, 73.97661532125166, 67.3601887303014, 67.39539592496811, 67.34001990287535, 69.7332932872157, 64.35631605886644, 67.25811296893706, 65.72088902996433, 67.44141317182972, 66.91607444517075, 61.3249554172639, 54.006106853485115, 48.26456100709977, 48.2050782634366, 47.463448278365604, 49.42189555014334, 49.237293120353456, 49.59723334158621, 48.17056925066056, 48.55793468413815, 46.827910561715406, 46.123021418048495, 45.64680253305743, 47.54528853201097, 46.92244752760857, 46.323764401097456, 53.59070431801581, 50.16444336983466, 52.4373862820287, 44.39407594742314, 37.55799270445301, 48.83053548874394, 43.933068013960316, 48.91904769405242, 49.29098644564229, 41.754681679510306, 43.173355902394945, 44.051978588104255, 42.86124506304341, 42.53175027908818, 42.09786553536692, 43.58534597581433, 40.8558548650434, 43.74895195807181, 41.79273651492211, 41.7961960454141, 40.982531732128514, 39.18321894061181, 39.583963578747166, 39.00029528525568, 41.170527012117454, 42.13031138143232, 44.174544811248786, 43.70072249443301, 45.693757226390225, 43.43104777797576, 45.12808084487916, 44.35202029443557, 42.922018266493275, 44.6317558903848, 44.95894039830854, 40.355297673133116, 43.87613481090915, 38.81630866758285, 42.265762590592914, 41.497440876499304, 40.75982347611458, 40.275732394187685, 40.07346360914169, 41.92124512887771, 41.92873685590683, 40.87509016836844, 39.881232169366655, 41.197379558317124, 40.64954996109009, 48.184132806716434, 50.72924898516748, 48.72377641739384, 45.85901452649025, 47.36629116919733, 40.317772357694565, 38.55369029506561, 44.89675514159664, 45.01414383611372, 50.037099699820246, 44.60910812500985, 47.45086923722298, 44.654003574002175, 44.37189494409869, 44.10560523310016, 44.83200073242188, 45.60736702334496, 47.944091596911036, 49.85069690212127, 46.72250078570458, 47.09184685061055, 47.844557531418346, 48.96239380682669, 50.625180659755586, 53.78458707563339, 54.28204167273737, 55.88254913207024, 58.09721346824401, 57.06540261545489, 60.72223617184547, 63.784038328355365, 60.56760065017208, 61.953927086245635, 63.25439676161736, 61.710575396014804, 60.6724024588062, 62.079470388350956, 65.66268497897734, 69.3376124289728, 80.99677931877875, 71.0275028597924, 70.13466158220845, 71.65090084075928, 88.93332665966403, 52.32258635182535, 57.15609565857918, 51.673579216003425, 5.073624060999963, 0.15154120061666737, 0.09489895775914194, 0.05507282747496521, 44.409451638498616, 71.54109801015547, 63.53211625929802, 55.297260899697584, 71.85225179118495, 30.19310728196175, 38.423624500151604, 59.990941632178526, 65.60875631147816, 21.62819035591618, 0.584834830895547, 0.16305416912561463, 0.03420755334739243, 0.044725477064569155, 0.061845799322210016, 0.02028168749905402, 0.02901549203201167, 0.04804842557097155, 0.005851392493387985, 0.041041915650449456, 0.023861692978009105, 0.07961826924715312, 0.10330556230919977, 0.18821577541530135, 8.982629737546368, 70.65381865347587, 46.8148765256328, 62.42051655246366, 54.73403992191438, 50.331406900959635, 69.60669486753403, 74.12182930977114, 62.60210267959103, 0.7381873085133491, 0.34420704288828763, 11.629312749831907, 58.22143100923108, 87.7889673171505, 77.79627430823543, 78.90204537299373, 73.60087579296481, 78.29341903809579, 69.82650449199062, 74.6407824177896, 75.66133606818416, 72.20230763958347, 67.61044379203551, 64.56025577360585, 57.213072007702245, 67.124540575089, 74.15116079391973, 68.94754840481666, 70.45893176909416, 70.96532544782086, 70.6726852540047, 68.40597891038465, 69.64948008137365, 67.8648801003733, 69.80847727867865, 67.9860342702558, 63.560404392980764, 56.08948161525112, 52.2531250984438, 50.30091047286988, 50.254963828671364, 50.840330508447465, 50.85326256290559, 52.096194990219615, 49.66124250042824, 49.4316347952812, 48.6866472613427, 49.143109167775805, 49.14192461198377, 49.64326627792851, 49.02084104476437, 47.95401519344699, 55.13196437589584, 51.53906153094385, 51.591323191119784, 48.341200197896654, 40.62645896788567, 50.677187365870324, 44.67603160488991, 47.38768377611714, 51.951451686120805, 45.130634307861335, 46.00888829077444, 46.051708805945616, 44.83566422616282, 44.62694314218337, 43.801601932894805, 46.01032780062768, 45.39908916719499, 45.4768854571927, 46.17220009526899, 43.91425240424372, 43.670422184851866, 42.51974782636089, 41.20175300105926, 43.4855334220394, 43.237431741529896, 44.11363824721306, 45.87999136217179, 47.30896180675876, 48.259830628671956, 45.712282580714074, 46.44537748829011, 48.058675796754905, 42.90949413853307, 47.19735468587568, 44.48459248388968, 42.44339496858659, 45.500411833486254, 42.10289401392783, 41.46058236399005, 42.097500754940896, 43.38692895827755, 43.85570318468156, 43.25623166176581, 43.44405435746716, 42.92951391589257, 44.63732173365932, 42.93006697008687, 42.21303809073664, 42.857640404855054, 49.43494919807681, 48.95324291721467, 49.10150850972822, 46.77992428502729, 47.29143665682885, 42.049973395562944, 39.411049812070786, 43.6734777112161, 47.41506976466025, 51.639132961150146, 47.267231710495494, 48.60326551621961, 46.470547337685865, 46.3976461656632, 47.509300785679976, 46.625826128067516, 47.35599102512483, 49.96871709823609, 50.65394732259935, 47.95733744098295, 50.71491272218766, 50.75616821166008, 50.60238776668426, 51.62198828112695, 55.64916026207709, 57.82906455378379, 58.32933149030132, 60.54023819585001, 61.70291500706827, 62.810655101653076, 65.55375291455177, 62.99147244422667, 63.77686039094002, 65.14796803074499, 64.4095112431434, 63.29127880834765, 65.51953023479831, 68.4712157710906, 72.7474308013916, 81.32912174347909, 73.50909233093262, 73.75984945604878, 74.70867864547238, 84.39847838494086, 55.304976201826534, 63.372526784097, 54.482494400393584, 5.484150109752532, 0.1171969963357814, 0.07182594463830033, 0.04610869860757263, 48.966076912418494, 77.59650015061902, 72.09146145851382, 63.270231370002996, 68.68791887837072, 26.03098027167782, 41.04052789749638, 63.72836420612951, 75.6266309368995, 27.61199747362445, 0.6449700976091047, 0.27469109082894944, 0.07671512543193756, 0.10100513050753264, 0.037155034501225724, 0.04598689828849128, 0.1745313766502565, 0.22735916048048005, 0.16990058965259985, 0.22110118740989318, 0.12059249719905278, 0.22938437519534943, 0.18289253686464604, 0.42890008538961416, 12.616828276265053, 84.80820132840066, 58.87704733879336, 70.82586165397399, 66.91544686594318, 63.100510412646884, 80.99235488522439, 81.62511948616275, 70.86943918658842, 1.1196571131867747, 0.5590032653943185, 14.784195692308488, 61.877927241786836, 88.93805703809186, 82.64241756931429, 82.53983974456787, 78.56575704390004, 81.43675942574778, 73.28539171526509, 78.300502838627, 76.32414602464246, 74.93780782145839, 69.41824067023494, 67.93314503085229, 65.04254256525348, 72.68497882350799, 76.55531483311808, 74.06413908927672, 72.9164457321167, 72.79670361549624, 74.83700290802987, 70.68636648116573, 74.33840690120574, 70.37045878748741, 71.91362119490101, 72.79549552548316, 66.0016679763794, 59.44453585532404, 52.96761620429255, 53.74525746991558, 51.387995366127264, 54.03603061552971, 53.09381061984647, 55.24501100663216, 53.03768150268063, 50.991177020534394, 50.457930795608036, 52.76339407890074, 52.28585727753178, 54.46041537869362, 52.64122793751379, 50.03291845321656, 57.12330856630879, 54.13559998235395, 53.60131040696175, 48.3670093936305, 44.46735366698235, 53.91067950956283, 46.882235388601984, 47.59077233652915, 52.84474403627458, 46.94935106462049, 49.64157573638424, 49.2091344248864, 46.95353231122417, 48.23304476276521, 47.86502838134766, 49.283773206895404, 47.67582893371583, 49.02087634609592, 47.97309752433531, 46.66927030009609, 46.02613887479229, 44.92207404105894, 44.62238927041331, 46.75283247424711, 46.33258188924482, 45.85663364779565, 48.367997830913914, 49.90914414005895, 51.646201072200654, 48.254931588326734, 49.0365775938957, 50.54852185710784, 47.604022102971236, 51.284107469743304, 50.52081031184043, 44.93742619791339, 48.996043820534986, 43.61759178100094, 45.98858610276253, 46.357210451556796, 46.368067572193766, 47.42842151272682, 44.401912843027425, 47.74920863489951, 47.426742738293065, 46.76949078036893, 45.26175129798151, 45.03535993637578, 46.015446493702555, 51.216540721154985, 49.064253837831565, 50.92059789165374, 47.802344983623875, 48.89308160351169, 44.19664344479961, 41.00321439004714, 45.10816304914413, 49.409355732702444, 55.85488073287472, 49.40244059408865, 51.73379936525899, 50.36332322705177, 50.171774279686716, 50.35832220508207, 49.55050614572341, 50.70237682711694, 52.158525374627885, 53.53592057381907, 52.00874182485765, 53.03060946925994, 52.766124048540675, 53.52008596543343, 57.33342209169942, 58.898220292983524, 60.1092795402773, 61.907949063085745, 64.79250323387885, 62.58251828532066, 66.50387256376206, 70.08830701151203, 65.94964950315415, 66.3161636167957, 69.55613551601287, 66.59342811953637, 66.25574342666134, 68.44556347016366, 71.23279971461143, 75.65582121572187, 82.3510560681743, 74.98868880733367, 78.78629622920867, 74.37981144074472, 84.50830474976571, 64.16794423134097, 66.33007234142673, 58.273704436517534, 6.6482595666762325, 0.5879966289766374, 0.22009378178946434, 0.2237699772681921, 57.05676163396528, 84.02852827502836, 80.67836915293049, 71.85230670436736, 92.46942181741038, 41.86959143607847, 55.59125823359336, 73.89604983791229, 86.28728005193895, 37.85006415459418, 0.7389276558833738, 0.4044297968427981, 0.25191696691176585, 0.32093601902165725, 0.17961250077332222, 0.12437087348512105], [0.11578088280774894, 0.03089728934179631, 0.04700334374642661, 0.07295206324347565, 0.031703480053693056, 0.03193051595571301, 0.16470043078785943, 0.23331845119114847, 7.52312413146419, 49.79207707989601, 36.17435701431767, 44.01258622446368, 47.58053495037941, 55.61217623372232, 54.98819381959977, 74.16830155157274, 39.44754746652419, 0.14455766567299444, 0.2651225300806184, 2.7872078072640205, 60.76781803561796, 77.9615786767775, 77.01819373715308, 73.99312065493676, 73.28645075521162, 72.09702337941816, 75.30654199661748, 63.24775618891563, 63.93849342100082, 65.89281435935729, 65.82436899985036, 36.7971666397587, 50.76072208343014, 70.37957437576787, 67.20552967440698, 72.5368465915803, 69.30030284389373, 67.7516177392775, 67.74664417389901, 67.07658567736226, 66.71422927610337, 65.32049348277431, 66.26951094596618, 66.49274872195336, 65.65139247525123, 55.18190399292977, 49.34788826973208, 52.94295234064902, 49.71149198470577, 50.11737492776687, 48.49017966178156, 49.06047267298545, 47.39798784255982, 48.701983728716456, 44.51134697083504, 47.09025044595042, 47.01479581094558, 47.246121514228086, 46.0504928711922, 46.63083499477756, 53.55495191389515, 49.682376230916674, 41.80222472836895, 40.50535578881541, 34.46241894075948, 44.97605762174053, 52.96067360908755, 48.9934354443704, 46.39191166047127, 47.31132699597267, 42.6386191768031, 41.45339658183437, 39.96672807201263, 44.10283996212868, 42.61561055337229, 40.72966044948947, 42.45291848336497, 42.42703868496803, 38.409460821459376, 41.50960414640365, 38.603398492259366, 41.72182006220664, 41.35589038172076, 42.85955844386932, 42.68715458531534, 44.09349687637822, 42.3496267872472, 44.030625204886164, 43.94097551222771, 42.22261259632726, 42.44888628682783, 41.61116215490526, 43.938916267887244, 39.94291928506667, 39.38134178038567, 42.00390908025926, 39.47339980832992, 42.552903621427475, 41.85834207842427, 41.9747737146193, 39.58436758287492, 40.02251594297348, 38.14808976265692, 40.84029874493999, 39.79551661399103, 42.67426959929928, 41.31793752793343, 43.32492020822341, 44.533535818899836, 45.44454159275178, 42.92832151536019, 47.545853353315785, 47.424585434698294, 47.51184248155164, 41.79714918136597, 43.04654959709414, 43.6610947885821, 50.02976878996819, 45.94646376948203, 45.41716344894902, 46.03184200102284, 44.862450092069565, 41.98362650409822, 41.85616908534881, 45.59551362068423, 49.22949937082107, 47.63944502799742, 45.640146270875015, 46.55481161609773, 48.26531802454303, 50.75533666918355, 52.529346250718646, 57.05019558629682, 56.11802470299506, 55.89079787654262, 55.07630202078051, 56.36534975421045, 58.876933590058364, 61.162463388135365, 61.10762865312638, 63.76186516977126, 62.829572692994155, 61.2169215756078, 61.03049524368779, 62.67115992884483, 63.798374591335175, 70.03926169487738, 66.16267342721262, 82.28835305859967, 79.82722267027825, 72.12091845850792, 80.95940697577693, 48.28232542161019, 59.15880295538134, 73.89843463897705, 52.41675069255214, 10.316386607385452, 0.3466421299644055, 0.1006606360897422, 0.06298749632532559, 28.35672416994649, 74.18316733452582, 62.40368173968408, 59.69379071266421, 38.37271998005529, 25.49864992018669, 23.960335562306067, 41.64438463026478, 63.31846475601197, 25.171002572582616, 0.4142194505660765, 0.14321184837289397, 0.07868194892521828, 0.15555134914334745, 0.028406155273138035, 0.08470208233883304, 0.07759167557402004, 0.04278887190946168, 0.029315888513660723, 0.06958078608037004, 0.055362726636831804, 0.04153162969516651, 0.1514998471905147, 0.2668440215770276, 11.408289151806986, 63.63893024383053, 44.23073276396721, 47.817195077096265, 51.749834014523415, 65.6003192932375, 61.77827550518898, 81.6135641836351, 45.25271023473432, 0.1554756902999455, 0.29023093922484305, 4.2094925718922775, 67.06880369494039, 81.58274219882104, 81.00074875739314, 76.30680914848082, 77.68283936285204, 75.06860317722445, 78.71855689633277, 66.21403294224893, 67.58369322746032, 68.18030142015027, 68.28359311626804, 41.1478792467425, 54.2215665694206, 72.3619794845581, 70.32954846659015, 74.53581979197841, 71.32087261446061, 69.59449629629813, 70.2875320373043, 68.64369023230769, 68.10173634559878, 69.85308247227823, 68.5600653002339, 70.88805475542623, 68.49628756123205, 56.84633431896087, 51.110993662188136, 53.72890903103737, 51.522328699788744, 51.41357314202094, 49.63852805476035, 50.98119458844585, 49.94109968985281, 49.233460964695105, 46.23825280897079, 48.05012895214943, 49.69775584436233, 49.46814421684512, 47.47301886158605, 49.098856987491736, 54.09701170459871, 50.45194918109525, 43.18085547416441, 41.913353320091005, 37.809761801073634, 47.84741693927396, 54.34160286380399, 49.00009562892299, 46.14266072550128, 50.72132971978957, 45.555627038401944, 43.489859796339466, 44.49974459986533, 46.09126198676325, 45.569206283938506, 44.53776021157542, 45.75338509774978, 45.33169500289425, 40.795473898610766, 42.81459631458406, 41.403841357077326, 45.08600558004072, 43.71687089243243, 45.26310843806113, 45.21213723767189, 47.81737942849436, 47.16399100518996, 48.30713441295009, 46.763462097414084, 45.56772755038354, 45.10105179202172, 43.91858662328413, 46.61377268452799, 42.97622934464486, 42.33244680589245, 42.99485668059319, 41.63559852107879, 45.17888730572116, 44.14560948648761, 43.44503102764007, 42.66465979237711, 42.26966142654419, 41.314740796242994, 43.970185402900945, 42.823139236819365, 45.40942461259904, 43.583082768224905, 45.745171654608946, 44.69760071846747, 45.45057812044698, 43.871420121962025, 48.829707868637584, 49.51375353720881, 46.7240854232542, 42.87092547262869, 43.45314641152659, 44.0140845698695, 48.02904229010306, 49.34469546041181, 46.81206418621925, 49.69766562984836, 46.34145036820443, 44.45047963050104, 43.588468182471495, 47.291444501569195, 51.879370289464156, 50.36477450401553, 48.12277517011089, 49.66763988617928, 48.494058885881984, 53.26104479451334, 56.77875580326204, 59.955087246433386, 58.365405528776115, 58.12675283801172, 57.285557408486646, 60.302169938241285, 62.913185857957416, 60.786755238809896, 64.27443265914917, 65.3399327493483, 66.43872983994024, 63.50300835024927, 63.70819145633329, 64.75833154493763, 66.55986832034203, 70.51152290836458, 69.46143381057247, 82.21553033398044, 77.94978018729918, 73.04024357949534, 75.68804740905762, 51.461888897803526, 64.122601632149, 75.32062330553609, 56.1271010675738, 12.000272870063784, 0.7245172968795224, 0.14941414217314414, 0.13795302249491215, 32.65086443193498, 81.5687785610076, 70.03217789434618, 69.35888736478745, 47.47405044494137, 27.84987157390964, 33.56634955252371, 51.0068900354447, 71.50814225596767, 33.16514991944836, 0.46928581991984003, 0.12762724512046383, 0.13215366029931655, 0.01334804115862015, 0.07919022528034064, 0.06966906239188488, 0.161414128097315, 0.1319991250432307, 0.2619694347583479, 0.15268153781371732, 0.18805434536789695, 0.1155132576522808, 0.16686222365786954, 0.397107896184729, 17.524473321053293, 81.0293193017283, 53.50229801670198, 60.66515784109793, 59.38477462337863, 80.98996223941927, 67.31954513057586, 87.4617318184145, 50.29628992080689, 0.6571749814095036, 0.9468592402915802, 6.220510390497023, 70.93297373863959, 83.7340602567119, 85.57748794555665, 79.69607430119669, 80.01112691817745, 78.43378497708228, 82.30281091505482, 71.88556055868827, 71.66988511239329, 72.56056124164213, 69.32238578796387, 47.608995668349735, 58.222764615089666, 72.5344539457752, 74.12970542907715, 76.55424794843121, 74.26932611773091, 71.26846974895847, 74.57049354430168, 69.43781329739478, 71.33558934734714, 70.2007221406506, 71.29053700354793, 74.47236368733068, 72.40348600572156, 59.96023339609946, 54.345842945960264, 56.37187657817718, 53.846493844063055, 55.09592171638243, 53.75150972797025, 54.463290476029925, 51.34584165388539, 52.62570319637176, 50.046160374918294, 50.90600275224256, 52.047294801281346, 53.47754393854449, 50.30209110629175, 51.83530638294836, 59.20266289864818, 55.29675099157519, 44.8885573879365, 44.85532314546647, 41.48173178395918, 48.36053748284617, 56.8324452061807, 50.21818768593573, 46.78241891245688, 53.52216482162476, 48.84492274253599, 46.11887155040618, 47.62656396435153, 49.16814957895587, 48.538875887470866, 47.08923062970562, 48.884989753846206, 49.20792633487333, 42.51160106351299, 46.888848504712506, 43.58055676183393, 47.751514988560835, 46.642872748836396, 46.830632686615, 46.92709553626276, 48.54402203713694, 47.62147272786787, 50.885563281274614, 48.29770895742601, 49.70425521173785, 47.92264015443864, 46.532873799723966, 49.145140955525065, 43.947102254436864, 44.519933039142245, 45.32725880222936, 45.959717458294286, 47.44546421112553, 48.14798816557854, 47.3984153809086, 45.73952344156081, 44.79199647903443, 43.84938816870413, 47.22316388160952, 44.51909757429554, 49.53272996410247, 46.781756031897764, 49.71719118856615, 46.024287516070956, 45.0937444163907, 43.355310732318515, 49.0781194163907, 51.00246167952015, 49.90424509971373, 44.181679602592226, 43.10445554794804, 42.25217550031601, 50.95018040749335, 52.08679699128675, 48.976879119873054, 51.00161052519276, 50.53739801529915, 48.88587620950515, 47.182155501457956, 48.774692704600675, 54.436869390549205, 52.42570546365554, 50.371999509872936, 53.259409166151485, 52.09033889155234, 56.18788996050435, 59.138328183081846, 62.61798043404857, 63.06741345313288, 61.21196369970999, 60.203345821749785, 61.60095691680909, 65.45397958447857, 65.3737828039354, 65.73556653914913, 68.51270660277336, 67.46767736250355, 66.33663838909519, 66.56837986361596, 66.89094774184689, 69.56665531281503, 74.55647499330583, 73.48153375810193, 85.0334159789547, 76.45711437348398, 76.10676826969271, 77.57316204809374, 62.04243536918395, 65.39808973189324, 80.09083732481926, 61.4882319204269, 12.73708716515572, 1.1914670082830614, 0.7019547204817496, 0.1481202196690344, 38.8832046908717, 89.62225175672963, 76.81779200030913, 78.42789357708347, 58.91596901801325, 36.95311615543981, 38.48134609960741, 60.20371452454598, 81.4658869466474, 44.30953318072904, 0.5911834321675763, 0.30581184993347815, 0.17306994136062362, 0.22737800624341736, 0.17390520702446663, 0.1685907018761481], [0.08361586159275425, 0.06687490224477745, 0.035372558575604236, 0.06302055684969791, 0.03691530260708063, 0.046070160554541696, 0.11402120182831442, 0.1700561667882627, 5.137308643710229, 41.74032580467963, 35.3404728827938, 46.15253725359517, 36.47487332743984, 52.09857586891421, 58.213264634532315, 75.75700267668694, 40.785942539092034, 0.12711709951080624, 0.36468619721070417, 3.5572156502354533, 72.97954882344892, 76.18512153625488, 78.25498765514743, 72.75993531750095, 75.79830523460143, 71.40616063148745, 73.73221243581465, 73.29809234988305, 69.53966156128915, 70.15421067514728, 73.64544176286267, 69.23209282659715, 69.15057028493574, 63.71104301944856, 63.18183291342951, 65.63334172771823, 67.44288798301451, 67.37427788396036, 67.98177457624867, 65.22548583246046, 67.36385222404235, 64.09563533721432, 62.66728854948475, 66.61253006227555, 63.49469684785413, 54.45689701264905, 50.67673629330051, 50.842307383014315, 51.00320300748272, 49.49457706943635, 48.40191456579393, 48.26923647234517, 48.22276423054357, 49.38126371752832, 47.87212394898938, 45.199671945264264, 47.29950889464348, 45.74947841705815, 48.179245533481726, 47.60645789484824, 48.86562108993531, 49.175162776823974, 45.99634847333355, 43.1542774938768, 40.20858141683763, 44.41513515287831, 53.536563842527336, 50.20542429339502, 48.69226017305928, 46.791507044146144, 45.70897210028864, 43.5867109606343, 39.91043029292938, 43.211238153519176, 41.57191491896107, 43.02556491667225, 41.18121154846684, 42.21984732535578, 39.87161451770414, 42.54587081170852, 41.0653486559468, 40.87065396770355, 42.08516882311913, 42.43456963569888, 41.98836864963655, 42.39838969322943, 45.77741353742538, 44.08420870381017, 43.8112941095906, 39.30578124138617, 43.30463370969219, 42.250324141594675, 41.13840672277635, 39.788511260863274, 39.01575334610478, 40.75262984921856, 40.232390203783595, 39.645380050905295, 40.720007496495406, 41.03404029723137, 41.94228080011184, 41.15963066777876, 39.97232137187835, 40.119810335097775, 40.818047138952444, 41.706083513075306, 42.23077504865585, 44.5175874617792, 40.844185813780754, 44.91653173200546, 49.1446114355518, 48.90211482201853, 42.23884728647048, 41.043159807882006, 36.42377661120507, 40.29747409205283, 41.92666584445585, 49.254484868818714, 42.713265803552446, 43.09451626193139, 45.277256427272675, 43.85359294952885, 41.13985015499977, 41.66141948392315, 46.01193205002816, 47.41877640447309, 46.068916243891564, 46.958807899105935, 47.085006237030036, 50.13737901564568, 55.55632952720889, 57.662050031846576, 58.99662471586659, 60.84725779871787, 58.53660129731702, 58.171973843728345, 58.35850215727284, 60.280722418139064, 62.0911237501329, 61.18974739505399, 60.89471455543273, 61.849760701579434, 63.76402639573621, 64.81349575904109, 65.30819292991393, 66.98586125527659, 68.2637773021575, 72.40219946830504, 61.037045601875555, 82.78523891202866, 69.07431940878593, 46.84228997076712, 62.11216334373721, 69.54696501455, 65.3122486606721, 62.361280918121345, 18.52709193383494, 0.23688059149970933, 0.2037783919443046, 0.338991608230337, 17.92983066651129, 73.30207747797813, 61.61989019763086, 63.868526181867054, 41.65280595902474, 18.829210535172496, 34.82025677157987, 49.686973248758626, 61.49933615038472, 30.77492029436173, 0.6395296476060345, 0.05508134637268321, 0.10086155796964323, 0.05547776622998138, 0.037165897627992016, 0.05993828252558747, 0.10805740652065124, 0.03942556206076857, 0.03901315777893028, 0.09577330156800248, 0.01374394486417934, 0.014992353127097652, 0.07699278633921378, 0.16048109429257532, 10.89647279631707, 57.80429870851579, 45.17987574300459, 49.871250121824204, 39.7574931575406, 59.99344410434846, 65.4341676927382, 83.62788954088765, 45.31596629850326, 0.23613855873625125, 0.20831487351848235, 4.396113551432087, 77.97722108902471, 78.88287282759144, 83.37899161923318, 75.35998821258545, 80.01093864440918, 74.81415117940595, 75.97776151472523, 74.92210265128844, 71.85783724631034, 73.69555396418419, 77.24853884789252, 72.06762913734683, 71.11452456443541, 64.09874577676096, 64.55887117693501, 65.75534705192813, 71.47349203786543, 70.2479317880446, 70.00818083363195, 69.11107201730051, 70.55761860262963, 66.93297201587309, 67.77140217442667, 69.09813604047223, 66.1539500759494, 55.03019455940493, 50.669126895166215, 53.19599228520548, 52.14003139926542, 51.346881081981046, 49.61212265876032, 49.600096671812, 51.856569551652484, 49.930721098376864, 50.384445190429695, 47.084582621051425, 50.49172593701271, 47.52098944879348, 49.68003065355363, 48.45332507164248, 50.49125133022186, 52.40856862837269, 48.5346632619058, 43.431471393954375, 42.01160084816718, 46.021596770132746, 54.93963095449633, 53.63033986860707, 49.98357503644882, 48.58413611688922, 49.332371373330396, 45.40170538809992, 42.47819423675537, 44.66187184856784, 43.23792203780144, 44.957422441051854, 44.894589993261526, 43.49388022576609, 44.346344624796224, 44.87458198301254, 43.63218692041213, 42.90164939818844, 45.1085788203824, 43.89392668201078, 44.07670128730036, 44.89215812375469, 47.7067058317123, 46.50435424620106, 46.616396750173266, 41.93278081955449, 45.860073566436775, 45.02307507299608, 43.76144078470046, 42.84394348821333, 42.12396106412334, 43.67186953944545, 42.28503711761967, 43.509667765709665, 43.18946507669265, 42.87014884333457, 43.38896466839699, 43.21451333261306, 42.92370488566738, 43.636623121077015, 44.94889520829724, 45.309918003697554, 45.28312429305046, 46.130544524038996, 41.03256156367641, 42.411309980577045, 49.21893642794702, 52.08818158795757, 46.649379960952274, 43.02057566181306, 38.30734975876347, 41.49544046771142, 43.339072119805124, 49.41434106519146, 45.09539573423324, 45.28843910463395, 46.748325670919115, 46.55958514059744, 43.22630397735104, 43.39133770235124, 48.957055461022165, 48.550089943793516, 47.39310841406546, 49.44743017996512, 49.081994718120946, 51.98930648065383, 59.173131373620805, 59.530031757970015, 60.46568178361463, 62.73729893469042, 61.75852244900119, 61.45278546117968, 62.50128207668182, 62.605366091574396, 64.79471937302621, 63.81070652315694, 63.85404479119086, 64.57576090289702, 66.88050639244818, 67.55886462426955, 68.64554943576937, 68.62369398916923, 71.95141715388145, 73.85422168239471, 63.47000160524922, 78.20148652599704, 66.75927377516224, 47.62090006182271, 65.62289645594936, 73.30259523084088, 68.1040426992601, 66.57886828145674, 21.905756881160123, 0.34346887120796793, 0.24284135309919236, 0.40256241156208905, 20.301503558312696, 79.22309921633813, 69.2022357448455, 72.67104656465592, 50.39767142265074, 20.62335560398717, 37.76004575913952, 56.48538997096401, 69.9522949034168, 40.47218430426813, 0.5955678452887844, 0.05208484325257521, 0.07259322765974269, 0.052236727844443054, 0.07658173420256184, 0.0062492774938413456, 0.1868065720003459, 0.17575224500990685, 0.1384760766860939, 0.1522583355225863, 0.18965409017137944, 0.1590428101800142, 0.23913747120288112, 0.37550197974328076, 17.238626672375588, 77.17218599011822, 51.70697427565052, 61.48266607715238, 48.787993461855, 70.46189708094444, 72.7975743816745, 90.14095383305704, 51.11585347883163, 0.5595688834305733, 0.7099957019090654, 5.305261592711172, 82.64761863216278, 81.97130003283101, 88.91682132597893, 78.17187263119605, 84.94983027058264, 77.27233979009813, 79.33746768582252, 78.04549386424404, 74.6607159030053, 77.37433710405904, 78.80653565929782, 72.60299344216624, 73.01379895979359, 65.47263829938828, 67.03854653143114, 67.36153802564068, 71.84798425243747, 72.4566262768161, 71.23099542433216, 70.60438894456433, 73.91908984030448, 69.43308291896697, 69.55196211414953, 72.45883064885294, 68.68870335240518, 59.119689080023, 55.49673303481072, 55.5178746100395, 56.46798249213927, 54.72605789861372, 50.465261705460094, 51.955068111419685, 54.251121628669004, 53.85894344698999, 54.020764750819055, 49.7216470010819, 53.2544473678835, 50.070620275312855, 52.94384271867814, 50.016099329917665, 52.33770316646945, 54.68697540221676, 49.082669365790586, 48.120645323107325, 44.99888189377324, 47.67573871920186, 58.02895638250536, 55.67058424795828, 51.27529782633628, 48.52897582515594, 50.54476030411259, 48.895784116560414, 45.161836762582105, 46.558726141529704, 47.958945612753595, 50.04048078290878, 47.512262175160075, 46.50184392929078, 47.71672356513239, 46.63252553632183, 46.52518595418623, 46.122448752003336, 47.41192794615223, 46.41186867990802, 46.53772969399729, 45.47676386371736, 52.81113716863817, 49.97651477013865, 49.33671343711115, 44.08564821366341, 47.91759598639704, 46.730588712999904, 46.90780924212548, 45.77342840933031, 44.31581681774509, 48.258010648912006, 44.911722906174205, 45.30809410156743, 45.620518730532744, 45.456536200738725, 47.696817536507886, 47.16148068827968, 45.90607512381769, 46.79477437849968, 45.87187597828527, 47.33698714163996, 48.282101846510365, 47.06611610228016, 41.76161250760479, 43.4363272882277, 51.99933205881427, 54.46100373421946, 49.35821979276596, 46.676177593969534, 40.03500084723196, 41.25829004472302, 43.616513129203554, 51.56847538486604, 46.442019939422615, 48.05333745095038, 49.587956936128684, 50.41199984089021, 45.36805145202145, 46.32866344144268, 52.12389476837651, 50.49275752036802, 48.66783949636644, 51.98651375309114, 54.3112947094825, 55.08130696512038, 61.59490862200337, 62.76979969393823, 65.83120176869055, 64.88476522507207, 63.873127122079175, 62.521074356571326, 64.0724031386837, 64.55528613059752, 69.0284590567312, 66.10677965225713, 68.9945540889617, 66.69425656718593, 70.78551615438154, 70.45129099199849, 72.7856425316103, 71.82739180903282, 77.40525322575724, 74.52296226255356, 71.81102768067392, 79.85070197812973, 66.3454637219829, 54.87472357288484, 67.51569501815304, 77.34426821431806, 72.06701724759995, 69.16747570037842, 24.30435488300939, 0.43739422314590026, 0.5253661219631472, 0.4138338325485107, 23.966376012371434, 93.09433383326378, 76.57114551913354, 80.51479062726422, 59.21994878399757, 26.952144984276067, 49.91337245510471, 67.84472696242794, 80.09456357648297, 52.974252854624105, 0.6472990048989173, 0.20786344854822084, 0.1537437187207322, 0.19711512771825637, 0.34164775763788535, 0.2343238343394572], [0.012361975874932063, 0.09576360289488109, 0.016006185267601284, 0.044599509227179715, 0.07452728557250193, 0.1239372677199783, 0.0435964894601174, 0.11772769608444746, 12.20843795807131, 42.61353954192131, 40.09935125227898, 35.896963073361306, 37.163492479631984, 47.37979588970062, 58.01846404229441, 76.68148963682114, 28.449684343030377, 0.03485767088169533, 0.15256723749541468, 4.178679902707377, 69.27540363803988, 73.62689679668796, 76.88511556194675, 70.76402941057759, 77.18510627746582, 74.89276332239952, 73.92578924855879, 67.87266992753553, 74.22991414223948, 71.31185900780463, 72.50203163393083, 65.3127742582752, 63.534622653838134, 61.98297615974181, 61.73734557244086, 65.6918478012085, 62.9226662266639, 62.08823296331591, 61.87143964152183, 62.99481038124331, 65.2771395252597, 63.941760755354366, 64.04186748689222, 62.46608664912563, 59.97964520608226, 52.49154244699786, 48.72267423137542, 48.43443885926278, 50.214241781542384, 49.369135748955514, 47.55310973813457, 48.7007874058139, 47.47194805452901, 48.42302868443151, 46.959678665284194, 45.39502559169647, 44.717114510074744, 45.8830508109062, 46.50254995592179, 45.57379545704011, 48.702007262937485, 50.557488395321755, 51.85784432195848, 47.09844819961056, 47.25317001342774, 41.90113121463407, 40.93629091016708, 44.71682425468199, 48.11611106318813, 50.83368993574574, 46.91996858965966, 48.0539571854376, 42.41064317764775, 43.40361864336076, 42.844174908053496, 40.66427453871697, 42.048671168665734, 42.097041837630734, 41.82921847989483, 41.65239411015665, 42.68979434044131, 41.97310670729607, 41.54667054453204, 43.2365099845394, 43.7483714472863, 44.591139747250466, 43.189884770301084, 43.95306033472861, 43.297259653768236, 40.76586000380978, 43.07468083596999, 42.728206111538796, 42.08433335827243, 40.628337783198205, 42.13928576438658, 41.14161914394748, 38.54482573847617, 41.834411698002974, 40.09086324322609, 40.695229884116884, 41.755485765395626, 41.58338785171509, 39.91966355231501, 40.5364288053205, 39.66544689670686, 48.36534238630726, 49.37849060181649, 47.49278368488435, 44.34037477739396, 44.507165724231356, 49.37377983523954, 45.462239326969275, 47.09229792318037, 43.51529636690694, 40.8938116412009, 42.52987538614581, 41.45829954454976, 48.09555784348519, 45.73809177644792, 45.88199961570002, 44.35468750615274, 41.43329835707142, 43.100901880571925, 41.163486357658144, 44.035806655883796, 45.278307622478856, 47.19623681037657, 47.695821254484116, 48.24613371203023, 58.41571384860624, 57.21357799345448, 63.75973140039752, 63.04230636165988, 58.432227027031686, 61.06117602317565, 60.3996604488742, 61.35388289728473, 62.090959010585664, 60.869599619219386, 61.44315996477681, 63.085444588815015, 64.17602431389594, 64.58943428531771, 66.19755114278486, 67.78010199146887, 68.09720208567958, 67.95524366440313, 70.81032122335127, 62.360229722915165, 52.264154803368356, 66.71775156451811, 64.89070761588313, 71.33973921498945, 70.52540025403424, 72.89398624051002, 56.67263215587985, 33.00255590869535, 1.306604384895294, 0.46448287764383905, 0.5646881893757851, 11.523131247489683, 68.7866606250886, 58.26728743891562, 64.93885078737813, 44.527471834613436, 36.22387693774316, 29.773858862538493, 40.458812944350704, 62.16994770111577, 45.199063977887555, 0.6404370021435523, 0.07107331687884946, 0.03635536128234479, 0.02612715669637246, 0.05014770566636036, 0.03890242743035478, 0.054488926750397494, 0.08237803970733959, 0.024355049770806107, 0.03137615941194517, 0.06983489744485387, 0.059430638193002636, 0.08080195935983812, 0.13983557631652202, 21.168433658538326, 57.56345341282507, 47.20503468667307, 42.412773024651315, 36.497077864985314, 55.33566090368456, 66.54724613312753, 85.10168090943368, 32.630697565694014, 0.06189115938820666, 0.11110633686785737, 4.025727813282321, 72.47513201928908, 73.78464668027817, 79.86972547346546, 74.38695015445833, 81.08125148280975, 75.65490338110155, 76.70258414360785, 70.82900739485218, 75.3916338951357, 73.0655977802892, 75.36905673242386, 66.86527190669891, 64.93446949989566, 63.2059633347296, 64.44744056270969, 66.9571416608749, 65.16381048387098, 62.34970992611301, 63.60494682865759, 64.6141020713314, 67.59051815156015, 65.16194735803913, 66.23078930762507, 64.17692645903557, 62.49405314845424, 54.400128549145116, 50.79985164826917, 51.007364642235544, 52.938916221741714, 51.29591772633215, 50.13289966890889, 49.9156827311362, 49.260827341387355, 50.38637499655447, 49.72323163863152, 46.77988898369574, 46.3533704511581, 48.45814958695443, 47.87750936323597, 48.95028545010475, 48.98819515782018, 51.11157809534381, 50.99510331307688, 47.48629216224917, 46.595753315956365, 43.62227509098668, 44.98973884890157, 48.161987104723536, 51.86299831636491, 49.328488226859804, 46.51960049906085, 50.54102620770855, 47.06561796126827, 44.67054028664866, 46.34229760016165, 42.003956148701334, 44.26054669964699, 44.88793765344928, 42.91669561016945, 44.46231734368109, 43.7476771877658, 43.73791440840691, 44.311988584456905, 46.277539268616714, 45.01958024117255, 47.336602749363074, 46.55721210664319, 45.147590714116255, 47.06195446752733, 45.556333065032966, 46.03452882459087, 45.61059513399678, 45.44870322750461, 43.069114992695475, 43.112045334231475, 41.69868592293032, 42.7017536470967, 45.21750304006761, 42.48694112223964, 42.21909423028269, 44.266594994452696, 42.510114485217684, 44.101094507401996, 42.94857271255986, 42.52271313821116, 52.43877872343987, 51.80377837150328, 48.43800037137924, 44.63830624857257, 45.10616264035625, 49.988658428192146, 47.67980621707055, 48.89582334026214, 45.89316268121043, 41.30907689371417, 42.17577557409964, 42.22578971616684, 50.896824406039336, 47.101805748478064, 46.67295340568789, 46.58875188519878, 43.38292029596145, 44.06529111246909, 43.26050312288346, 47.351970595698205, 47.80614576032085, 47.76150134301955, 48.21594715118409, 50.89210579472204, 59.77369723781463, 61.26289175402734, 66.3195368551439, 66.17548388819542, 62.638043357479965, 63.77607591690556, 61.98361550607989, 63.47170391390401, 63.02241602251607, 63.43342550339238, 63.49650113813339, 65.60423774103965, 67.09318514793151, 67.34757438782724, 67.62823566313713, 72.09370505425238, 70.51406460423624, 71.6343641281128, 70.36663839893957, 65.94193812339537, 54.954959577129735, 66.16421099632018, 68.6984778988746, 74.53709063991424, 73.4175677453318, 77.17311951421922, 62.254761111351755, 38.85205322696317, 1.3489198949067824, 0.3751875159721221, 0.5726976079806205, 12.18732285884119, 78.70656228834584, 65.5569927923141, 74.92422857592183, 50.744503082767615, 35.372353907554384, 39.57234551829677, 50.591342372279016, 68.85410970257175, 55.335182374523534, 0.6975935351464057, 0.10927318805648435, 0.05683453475695945, 0.061745158351597294, 0.019693692034531026, 0.08139397678596359, 0.1643395574102479, 0.2347532419427749, 0.0970539094639882, 0.11880352101739376, 0.31311472096750814, 0.3103378054595763, 0.2987389584943172, 0.28033584115966675, 30.431930595828643, 73.91224922672396, 57.17395420997374, 54.98399296114522, 52.31024265289307, 65.11015245991369, 72.3412379910869, 92.99185799014185, 40.61344454365392, 0.34686567442071053, 0.5311487374767181, 5.561879229161048, 77.3510068462741, 77.05561314859699, 83.43917646715718, 77.77062200730848, 84.44902989172166, 80.75291772042551, 79.85368297946069, 73.52158900230162, 77.3829584736978, 75.27649664109754, 77.8327601955783, 69.30273471340057, 67.81406971716112, 63.27292996068155, 65.07076009627312, 69.97401698943108, 68.81979680830433, 63.75686022543139, 63.75862529200893, 66.92354263797884, 71.17969082247826, 69.54504305316557, 70.49085201755648, 66.59264364550191, 64.03175953895816, 55.82636902409216, 53.20039710690899, 54.12584897010557, 56.06136214348578, 54.83783368141421, 53.79986470745456, 53.037524607873735, 52.727724044553696, 53.135736834618356, 50.58619622261294, 49.0375268074774, 50.01983342632171, 51.1969014137022, 50.78583701964348, 51.07497453689576, 50.07515453523206, 55.00814299429617, 50.82215816743913, 48.971156381791644, 49.56527386942218, 46.85596335318781, 49.74803278523107, 50.68751104416386, 56.89808607101441, 51.823245094668486, 46.674573344569055, 51.58029348619523, 48.593306618352095, 47.16735639879781, 48.487120213047156, 47.31008752699822, 48.70550993950137, 48.5066379270246, 47.720602789232814, 45.96068628372685, 47.168658625695016, 47.343462974794456, 46.65784443578413, 48.949869678866484, 49.070192306272446, 50.55135773074243, 47.857822987341116, 48.90857104332217, 48.77380232657156, 46.92333790563768, 48.416431257801676, 49.333869718736224, 47.768028166986284, 46.11896568729032, 48.60403430077338, 44.89859081083729, 45.03974514622843, 48.17535061990061, 44.89358194412724, 44.10606807278049, 48.16746665585426, 46.76193237304688, 46.0261937879747, 48.11052953043292, 45.83359756777364, 54.507542656313994, 52.79599289740286, 48.84422456064532, 46.58677893300211, 47.227101941262525, 51.69817639935402, 49.82812758414976, 49.70503968577231, 47.325835843240064, 42.873843716036895, 43.07746571879233, 41.322228600901944, 53.11303415606099, 50.029113754149414, 49.38096561739522, 50.95019609697404, 47.78183883236301, 48.53422787881667, 46.695844358013524, 49.37611756786224, 48.40068686393, 51.674297009744954, 51.128197177763916, 54.09481517730221, 62.735745676102184, 65.44895895065801, 67.48652042881136, 67.29756416813021, 65.27222871780396, 66.5833790071549, 64.588598820471, 66.37410486898115, 68.16774983559885, 65.70711758828932, 67.02015061532298, 68.70334948262861, 71.03371589414536, 70.53208397280785, 72.5078602760069, 74.39839563062115, 73.51532105476626, 74.7335700065859, 72.0107312356272, 68.01750736851847, 64.07325821538126, 68.91962897393012, 67.03842886032598, 80.12315765503915, 74.33875991452125, 82.49568954590829, 65.72288551638204, 41.472216113921135, 1.3594080675994198, 0.47795848680600045, 0.7330736409752601, 15.112780486383746, 87.80014607214159, 74.09984834732549, 84.00686110219648, 63.3568843718498, 51.80812828002438, 39.157284229032456, 60.52526258653211, 77.5867412936303, 67.52079409937706, 1.1127351104251801, 0.1892304895145278, 0.13768257813588267, 0.22720747507147251, 0.136741531051455, 0.23339731228207392], [0.05214602303420825, 0.025766850223824866, 0.05712511956751828, 0.04974177099704262, 0.012374438210240295, 0.049949660446614995, 0.0335876579817024, 0.1157168378572791, 12.58226631149169, 46.67449097479544, 44.49471219893425, 33.10913062864734, 32.0142049174155, 48.01760465868058, 60.33822436486522, 80.44091670743882, 17.097654727197465, 0.172249706341855, 0.054923988082596374, 3.2851416689734307, 70.12022725997433, 74.17298486155849, 76.3825579612486, 74.08050321763562, 76.2103972896453, 71.38732540992, 72.11797668087867, 70.8744990441107, 71.05264525259696, 68.43043881077921, 72.5288135774674, 69.61985834183233, 66.82789171895674, 66.71392333122992, 69.20061188359415, 67.63772779895415, 69.25834132779029, 69.9372330019551, 66.49720453446912, 65.8066398866715, 65.00222844462242, 65.16071965617519, 62.58769189157794, 55.63510640974968, 53.621463544907115, 49.31097092167024, 49.774116546876975, 46.736542870921475, 47.59846802680723, 49.33302640914918, 47.603845596313484, 47.947711944580085, 47.08959148776147, 47.69299322558988, 46.75143218809559, 45.635619855696156, 45.19549854340092, 46.1585267128483, 46.12016593256305, 47.29565320476409, 46.07662370128017, 49.00537513917493, 50.82883404147241, 43.73301144569151, 48.67191483897548, 47.31815584244267, 40.53833115485407, 46.85138202482655, 49.28331428958524, 50.028509709142874, 49.10049261585359, 47.015929375925374, 49.149526165377715, 40.727797323657626, 40.72351409542946, 41.337486620872255, 40.39058723757344, 39.452164096217004, 41.81386240067021, 41.50862747623075, 42.82318238289126, 41.97006687041252, 40.42040509562339, 40.64108156388806, 43.34038611381285, 42.25823163986206, 41.91405934672202, 41.856784897465865, 42.36612427619196, 41.37693389769524, 44.783433944948264, 41.11808100054341, 42.57464139692245, 39.21272300904797, 40.77497951446041, 40.21366480858096, 40.60884752581197, 38.58975648880005, 41.11592369694864, 39.73355101000878, 41.5836271162956, 40.20471395984773, 40.254394700450284, 40.01658924164311, 47.875528566298954, 48.15369129180909, 47.98595113138999, 46.28084582667197, 46.149799439214895, 46.511822439009144, 45.91533191742436, 46.56884585657428, 45.05736835541264, 47.23989279039445, 41.75702725687335, 38.96692768219979, 42.689213829655806, 48.514827835944395, 43.36175126414145, 44.809317665715376, 41.67419856594455, 41.17791675752209, 42.49034966191938, 41.923516181207475, 46.39970933237384, 44.55884687362179, 46.846737938542525, 45.512386829622336, 50.06217933470204, 60.87312190763412, 60.97034177472515, 61.32683423257644, 57.246686720079, 62.35549934448735, 62.34604643237207, 62.71571020926199, 63.80632131330429, 60.99210308444116, 61.79371003181704, 62.07849764054822, 65.59831103970929, 63.13179131477111, 67.97409457545128, 66.40112215472807, 68.26970792585804, 67.2590700272591, 67.31562276040354, 62.05968987557196, 69.04665885433074, 61.42342259806972, 61.562560835192286, 72.70194699687343, 72.5878530933011, 70.37612269001623, 68.61501770634806, 66.60685047026604, 47.32999747799289, 4.982623602113416, 0.16799172837167017, 0.47309971204207796, 6.237724692590776, 67.74076846338087, 61.502266160903446, 59.97020406107749, 59.85977365124611, 32.12709073097476, 21.910436268775694, 44.10132200487199, 54.80574084866432, 55.25752336748185, 1.7414623667155544, 0.17516260245634666, 0.04797842428689042, 0.07699486243748858, 0.0380652503771407, 0.0221046645780124, 0.021438667956258983, 0.02922530819271361, 0.0420335743335947, 0.0026947640693716465, 0.03271277791129486, 0.040997042050284725, 0.09764464752328011, 0.29280248188203384, 20.85606002038525, 61.08782460612636, 50.70271807332193, 41.26379313007478, 36.3150014415864, 54.62320943032542, 70.07175460938485, 87.16651854976531, 19.088296813349572, 0.19779803381571848, 0.05424368668407683, 4.361052955350568, 72.67878932337608, 74.0774751478626, 78.970977106402, 75.22812597213253, 78.80810460736676, 74.57296463751024, 75.04364905818817, 72.5268445476409, 74.51507045376685, 70.77873045398344, 73.86542397160684, 69.04881615792551, 68.30467193357407, 67.56546989563974, 74.26523900801136, 69.5956886968305, 73.44650699246314, 74.13195686955606, 68.55624491168608, 66.99209782385057, 68.01481662258026, 65.56321759377757, 66.06303738009545, 60.51081649718746, 54.969095799230764, 51.15525760958272, 51.70281656326787, 49.940366206630586, 50.50284977882139, 49.968250336185584, 49.53904105770973, 50.212421801782426, 50.267527180333296, 50.243137882601836, 47.72468989895236, 46.84089360698577, 48.06342970940375, 48.34522062732328, 48.09012143842636, 49.695979010674264, 48.289393532660704, 49.62709434570805, 51.75064202277891, 42.91947264825144, 47.838034629821784, 49.27210807800294, 44.41035378363825, 48.917761156635905, 48.681681540704545, 49.89414107414984, 49.91090136189615, 49.04244938204366, 50.066533165593306, 45.11483500080724, 43.743825420256584, 45.134074226502456, 43.6875472530242, 43.074982858473255, 45.84208557682653, 44.083875302345525, 44.500536918640144, 43.53741461230863, 43.4151033432253, 43.84400275445754, 46.07885945227839, 45.12925363356068, 45.328282540844334, 42.112029214059156, 44.74716378796486, 44.54031759692777, 47.425330685031035, 44.009777807420306, 45.721107913601784, 43.414962137899096, 42.87411435957878, 42.422971187099336, 44.342367341441495, 41.78109492025068, 43.14930000612813, 42.29153256262503, 43.500199164113695, 42.95765692187894, 43.4969396745005, 42.707900001156716, 50.27276354451334, 50.30645670429353, 47.730267509337395, 46.99641950668828, 46.93838019524851, 47.5040408872789, 49.6641803556873, 46.19904087435815, 45.89166041343443, 46.13010914094987, 41.383468566402314, 40.70978187745617, 42.8964404905996, 50.10806322097779, 45.7229200486214, 46.5285199688327, 44.87713152362455, 43.151002314782914, 43.5577364121714, 43.869992379219305, 49.39689828503517, 45.87378225018902, 48.91384270883376, 47.56475917754635, 53.05079006379651, 62.566950398106734, 64.50633495084702, 61.406442657593765, 58.729515229502034, 66.08998406317927, 64.32803184755387, 64.8005440927321, 64.81235434932094, 62.76574396318006, 64.69007445919898, 64.14652024545978, 67.70545144234934, 66.25801055662095, 69.70210259960544, 68.64449824056318, 70.24035376887169, 68.28481689576181, 68.80934761416528, 64.18009573413481, 72.69931116411763, 65.34001511912193, 66.03602009434854, 73.3349390952818, 75.60366153717041, 70.98051286512806, 73.04715479573896, 69.91975492046726, 52.33523991800124, 6.162545113794266, 0.11628244823265461, 0.44676393811260506, 6.912567500145205, 76.56693289356848, 68.05843337889641, 71.55812109670332, 65.02943792650777, 33.06033634370373, 12.674046831746256, 52.54667135976976, 62.33758195754021, 67.4205618519937, 2.1044239161476015, 0.2713010598334574, 0.011654898745849008, 0.03465954139227829, 0.005093174207309682, 0.015120375995343972, 0.16914466005419532, 0.15030062847560452, 0.1881269092160848, 0.22081928237551646, 0.16000106359922117, 0.1862512195422765, 0.36463949649084004, 0.45650658468084954, 31.324803252373975, 74.65821343083536, 63.70228828922395, 47.48024778981363, 47.91605449491932, 67.27343374683012, 71.83425595683437, 97.04216803273847, 24.378883838653568, 0.34547758438894827, 0.17035032922942794, 5.128447519194696, 79.38786229779645, 79.21028875535535, 82.7812380944529, 78.97176942517682, 81.96784834707938, 76.25833649789134, 79.30084059315344, 74.49872201488864, 77.04030021544426, 73.08804942715552, 76.24385510721515, 72.15090890084544, 68.83647472627702, 70.64381660953646, 76.73831693587765, 71.99992902817266, 75.35344569913804, 77.20872679064351, 72.11636066436768, 72.14164426249843, 70.9339229522213, 69.33251334774879, 68.98174362797891, 61.11243355658747, 59.28898642140051, 53.72208410693754, 54.92325505902691, 52.45682162623252, 52.51357832262593, 54.50609530172041, 51.99914770741617, 52.98436864729851, 53.74326098349787, 52.945584251034646, 51.30019703219014, 51.10942079174904, 51.997712119933105, 50.95240439138105, 50.23224153826314, 53.8835798540423, 52.07618697997063, 52.0716997884935, 54.860881528546734, 43.75545132544733, 49.72959372305101, 48.496871225295536, 46.757453026310095, 51.02136750375071, 51.02500354090045, 50.87194873440651, 49.673943135046194, 50.347974992567494, 52.260659971544825, 48.60160635363672, 43.78069569987636, 48.079680089027654, 47.88696619772142, 45.5477705309468, 46.96090636714813, 46.513709099062034, 48.193958343998084, 46.79793580885857, 44.36635263504521, 47.571199709369296, 47.39583053896504, 46.798688903931655, 47.24549001263034, 44.922136798981704, 47.79126428788709, 48.061437145356216, 50.1987954878038, 47.048873363002656, 49.17588841530585, 47.38627956759545, 45.59937715530396, 45.64942267633254, 46.80265834254604, 44.18397418914303, 46.32500387007191, 46.84558476171186, 46.18422215984714, 45.35185598557996, 46.35404509882773, 45.45773252364128, 50.16207033588041, 50.684369225655836, 49.20120339239798, 48.01559248278218, 46.772699279169885, 49.7104682460908, 50.463175004528416, 48.29719120456327, 47.91573678293536, 47.15272595805507, 42.075104021256976, 40.24369839699038, 44.06468706746256, 52.127609252929695, 47.63988041108655, 48.767542223776545, 48.38346373650336, 47.48573910805487, 48.43710999335013, 47.47596848395563, 51.835478967235936, 49.35367376573625, 51.583298021747225, 49.464033572904526, 54.62154242300219, 65.99779267464915, 65.01803951878702, 67.21677903206118, 66.75862266171363, 69.9156835002284, 66.5905490998299, 67.35881590074109, 68.2314177482359, 64.67578134229107, 69.8502112973121, 65.71973585313367, 72.55608973964569, 68.52986304990708, 74.00172633509483, 70.73864383082237, 73.29188716027045, 71.1583766629619, 70.08639289486793, 65.09596524700042, 75.77477101356753, 66.49524334938296, 72.04320846065399, 74.28430957178917, 74.4814557413901, 74.4289508942635, 79.54676535821731, 72.10111833387806, 58.683156736435436, 6.232803098617062, 0.1581887906837848, 0.6349835592892863, 7.8452458400880145, 85.19099327825731, 76.83451698672387, 79.19331273724957, 79.16094533858761, 44.75281592338316, 32.808392701610444, 65.19911181542182, 70.60950371526903, 80.74246852628647, 3.064920931093155, 0.5389885135716008, 0.20913979699534757, 0.3001096736519568, 0.19554889160058192, 0.1459685544813833], [0.0659654792698641, 0.09552830664981758, 0.10788695961837808, 0.06456929168874218, 0.03413962433114648, 0.053317992001651764, 0.07452134839108876, 0.5119883881941919, 14.47861756047895, 53.57055118007045, 38.177036854528616, 29.079615031519246, 27.110620506348152, 52.895091579806426, 64.61521602446034, 68.60946363018405, 5.1189852914502545, 0.11714022922059221, 0.014204127177025282, 4.1361349340408085, 58.83262257422171, 70.68329918769099, 74.68363038955196, 72.74398696038031, 73.13901670517461, 73.96972763922908, 71.80712099998229, 69.16374944871473, 69.55591586328322, 68.06633303242346, 67.75243359227335, 67.21136616122338, 68.89552993159141, 69.74818260438981, 67.01661263742756, 64.3654473366276, 65.98000864828786, 63.647814412270826, 66.38466388948503, 64.99230877045663, 62.53287284604965, 59.029647150347316, 55.47670541271087, 50.76255383030061, 49.13885339613884, 47.062315325583185, 48.6056463949142, 49.41155225999894, 47.22118700704267, 47.024695873260505, 47.12512816152265, 46.96100050403226, 47.45184982976606, 47.77054632863691, 45.983463487317486, 44.35824509589903, 47.15594622396654, 45.55845506729619, 47.46404055626162, 43.80034285206949, 43.97964615975657, 48.16814522589407, 53.660028288441325, 44.48362758082729, 42.22266750950968, 45.825615544472974, 45.936579396647794, 43.99734781634423, 51.161721675626694, 51.27379163619011, 48.901165608436834, 47.76793795247232, 49.234908319288685, 50.874843443593676, 44.79215729621149, 39.09996271133423, 40.429359866726784, 39.335724615281634, 41.98547394044938, 41.8650257971979, 42.78668865080803, 40.48500260999126, 41.97804497134301, 43.46052046745054, 43.65870214277699, 46.20135507275982, 44.05148436946254, 41.82434297377064, 41.53559377116542, 40.269225182071814, 42.58963661809122, 40.98547743212792, 43.939469322081536, 41.700933441039055, 42.379931019198516, 40.93132518952893, 42.533362373229, 42.44834499974405, 39.70741625755064, 39.045837925326445, 40.21146828128446, 39.83717218522103, 43.516422087146395, 43.75543955833682, 43.911946050582394, 45.70908192665347, 47.655314937714614, 44.47515918362526, 45.66469246341337, 46.53190497429141, 41.811430531163374, 42.10653397344774, 41.993526566413145, 41.58414486915835, 40.25577537475094, 39.763102146887014, 40.486528411988296, 45.05368524982084, 42.653669311154275, 42.69007675109371, 41.11864189947806, 40.5265954232985, 41.217054167101466, 41.73456776526667, 47.00866122399607, 45.23916236815914, 46.53031641437162, 45.217404980813306, 55.25146330556562, 56.21877862561134, 63.904396257092884, 47.4566900345587, 43.51907360938288, 56.54812435950003, 60.47817061024328, 64.56120890955772, 62.96440416766752, 63.11294432609313, 64.24179461694533, 62.30062146340648, 63.90171335589502, 64.9839658891001, 65.13481632355722, 63.768140962046964, 63.36674128809283, 66.22251310656148, 67.39104993881719, 71.46785951429798, 68.29850596766319, 71.0011366874941, 68.27896471946471, 61.23095581608435, 73.05594090492495, 76.96053489562004, 75.1054891463249, 66.49295268520233, 59.00840751586422, 8.534266544926552, 0.1729612488059267, 0.10610585115970143, 2.4944001772711357, 60.563015399440644, 64.56108731608238, 62.0203249685226, 54.17207410258632, 46.15558101284889, 44.29649914464643, 45.25345156269689, 51.887713170820675, 48.66348566547517, 2.4507057089959425, 0.13366912010936968, 0.0922660131548201, 0.034758535273853815, 0.038734937627469344, 0.039367672626770316, 0.017667069633100784, 0.037945380599628535, 0.08487289696330987, 0.03929444611252796, 0.04146488045432395, 0.08304167869350604, 0.10069244406035832, 0.42134302638230786, 24.85926239721237, 65.40750734267696, 49.46561428808397, 32.77116156393482, 33.05196208338584, 62.62688029196955, 68.0554445328251, 75.53917777153754, 5.0218919207972865, 0.1998652607923554, 0.02530138094669148, 4.969508667146006, 64.48111018826886, 73.02212222929924, 80.00986391498198, 75.37585812230265, 75.57932715262137, 75.00798686858147, 75.76696549692463, 70.33492211372622, 72.4474165516515, 71.70922648522162, 70.62509121433382, 69.656203023849, 72.05172000392791, 71.73231355605587, 68.62967952605217, 67.25648126294537, 67.04753660386609, 66.48252702528431, 70.01142071139428, 67.91008149423908, 65.40538534041374, 61.042517308265936, 58.89629048685874, 52.81972323694537, 51.0187630499563, 49.69282542505572, 49.49181179846487, 50.117614192347375, 49.984273218339496, 49.68864417845204, 48.97203499271024, 49.97018406468053, 50.5917699106278, 49.79850192223826, 49.836517533948346, 47.635385374869074, 48.298873901367195, 47.344408266005985, 48.36813903624012, 47.60479873226535, 46.57742015777096, 49.944947534991854, 55.138957961913086, 44.77997833682645, 42.791799499142556, 46.20450081363801, 46.36952277152769, 44.72824619662377, 51.9249717650875, 51.30957541927215, 48.16487396917036, 47.3432433220648, 50.13924998621787, 53.80226519800002, 47.75193860453945, 43.64062393865278, 42.53273479400143, 41.835859052596554, 43.330941046437914, 44.817382058789654, 43.348375981853856, 42.97448781228835, 44.294871361024924, 45.51595226410897, 44.356664380719586, 48.93933027021347, 46.47375583648682, 45.31885316295009, 44.462419325305575, 42.80412358622397, 43.093790623449514, 44.28907409791024, 45.639789335189334, 42.956782233330514, 44.418865326912176, 44.274008274078376, 45.2679447204836, 46.14113884587442, 42.10709879475255, 41.19794830199211, 43.13849779867357, 41.87941697336013, 45.70200597086261, 45.12484881185716, 44.37402086873209, 45.9288993958504, 48.38077299056515, 45.718087688569106, 45.54286364586123, 46.102111262659875, 42.63855641888034, 43.719432200154955, 41.93446351635841, 42.265335052244126, 39.48315866531865, 39.971885988789225, 42.27215605397379, 47.22659987788047, 44.453919549142164, 45.634854993512555, 44.325359944374334, 43.731320904147246, 43.87482866164177, 42.44290859468522, 49.095828917718705, 46.80002250979024, 49.36199311287173, 46.138993309390166, 57.373418500346524, 59.92165688545474, 64.24591310562627, 51.49742949393488, 49.94730880183559, 57.68448206686205, 61.70594699921147, 65.5791659508982, 64.38366282370784, 65.78252123248193, 66.21091858033212, 64.09063039287444, 66.93399183211788, 67.4740472916634, 66.86629956768405, 65.22983574098157, 65.9374980003603, 68.29043372984856, 67.65878308203914, 70.66137313842773, 71.14974744858281, 73.78877301369944, 74.02794345732659, 64.60007567559519, 75.79045264951645, 80.27986418816351, 80.16733138791977, 70.78782250804286, 64.67878195547289, 9.232704370252549, 0.022833078213396574, 0.15633432164547906, 2.561170929862607, 67.66157580960181, 71.71843621038622, 71.64281291346397, 61.867889896515884, 37.07922427884994, 49.35762751486994, 53.77457718695364, 58.4230016123864, 61.231316674140196, 3.1104792606446052, 0.20328613448767893, 0.0025004168996782673, 0.026702383390417504, 0.04604423996962367, 0.040061855538477825, 0.2383356682595707, 0.1702559471971566, 0.2542898170049152, 0.17404207629301857, 0.11043493741101797, 0.15465099664945758, 0.2305113977842754, 0.5631243894177099, 36.947664060900294, 77.00237089587797, 58.63556269676455, 43.42580749142555, 41.8373966217041, 72.90720462799072, 74.83333156954858, 84.92600579415598, 7.14794256033436, 0.33282312955106463, 0.18159446216398673, 6.813707592025881, 70.39214164979997, 76.66658463016634, 83.02003983528384, 78.66587946491858, 78.86027213065856, 76.99248652304374, 77.84983035056823, 75.61213385674262, 74.16797207247826, 71.36070820593065, 72.83050660164126, 73.88462789597051, 75.34214927304176, 74.52166003565635, 73.34068144521406, 71.08004693062075, 71.01546902810374, 69.28620584549444, 74.40377712249756, 71.06226290425947, 69.84210768053609, 64.63502399383053, 60.16921335651029, 56.264340877532966, 54.936277327998994, 51.60917389777399, 52.84917239219912, 52.738420348013605, 51.029114184841035, 50.612680066016416, 51.81322736124839, 52.171626091003425, 51.983579820202245, 53.13574075698853, 51.66828009390062, 49.88326041929184, 52.31256469603508, 50.560798875747196, 51.47992395585584, 50.64928754683464, 48.429524129436864, 51.511808902986594, 58.734916333229314, 45.121455961658114, 42.629546734594534, 45.332789344172326, 46.72592109249484, 46.25044353546635, 52.640882768938624, 52.55040153380364, 50.0876590513414, 48.37997282705, 50.02339886080835, 55.55463114092427, 52.68915537864932, 46.523656229819025, 46.192086512042636, 44.87567240192045, 47.61343186901462, 47.069057879909394, 47.59666373652797, 44.20380177036409, 47.380976523122484, 50.282953862221014, 48.300603666613185, 52.55877579412153, 50.02147297705374, 47.0364276824459, 47.429041247214045, 45.307082130062966, 47.147356233289166, 46.30284247859832, 49.9012601760126, 45.15802814114479, 48.17359339806342, 46.97623106741136, 48.143289166112105, 49.325526837379705, 45.36369369876, 45.28192012540756, 47.34391796973444, 45.83450363528344, 49.473910100998424, 47.201320202119895, 44.43469209055747, 47.397630906874134, 47.86116484672793, 46.3744806474255, 45.361316742435584, 46.464553956062566, 45.41304103789791, 46.35697118697628, 42.75694924016153, 42.625428245913604, 40.494894827565844, 40.76447148476878, 42.118344230036584, 50.94306522800077, 46.300198801102184, 48.27759504318238, 46.429256546881895, 46.602688066421024, 45.94731492380942, 46.69764864829279, 51.94678798798592, 49.36702159143264, 49.34805693164949, 47.88770360331382, 60.44155528468471, 62.43524113009053, 66.98050329762121, 53.53576367901218, 52.4392690197114, 61.41375003322479, 65.01930252198251, 66.86241642121347, 67.91857734803231, 68.18063089924475, 67.46020132495512, 67.01371008350004, 68.8579693148213, 70.0108951137912, 70.50503530809956, 67.07891556524461, 67.55393028259277, 70.99221721772226, 70.18369120936241, 74.64153551286267, 74.62965073124056, 77.659438502404, 77.23721888757522, 69.39813460073164, 79.20281271780692, 79.97310346172702, 82.63199975413661, 77.97223967890586, 66.70795348382765, 10.007560753053236, 0.2778476488686377, 0.26723883264968473, 3.2559060377459375, 78.4209902055802, 79.18681729224421, 80.41708438627182, 71.37111033162763, 71.07786609280494, 59.46448895239062, 65.49314837301931, 68.478440776948, 78.39982509613037, 4.6829491276894855, 0.4124034851068451, 0.24417005599506442, 0.17452507940751893, 0.16606123276775883, 0.10595514634323698], [0.0037981382422825143, 0.042823024109126105, 0.04233479244454254, 0.08609821629380027, 0.027306849745312528, 0.01783001461937543, 0.016370609462741884, 0.03207381270194967, 17.96595569579832, 54.81524082922167, 41.47782510326755, 31.822683426641653, 33.738298416137695, 44.24047200910507, 70.84365352507561, 59.77314026125016, 2.5709822485523843, 0.03257222759026674, 0.04983082488780061, 1.8615152085981064, 47.811899877363636, 71.00965607550837, 72.6034955055483, 74.09987972628686, 73.5467706188079, 72.3490748866912, 70.19332455050561, 68.06786275679066, 69.15657151129939, 66.15860200697377, 69.1554497134301, 70.75272513974097, 68.34999884328535, 64.62007584110384, 62.6374000887717, 62.44627867975543, 60.97117331720168, 60.01010241047029, 56.283172176730254, 56.55268607601043, 51.45429126677975, 47.667223253557765, 50.13250743189166, 47.28599632939985, 45.72026068164457, 46.24587005184543, 47.63127865329866, 46.18779936144429, 46.258872708966656, 47.17170630731891, 45.97100996202039, 46.083052465992594, 50.24734658579673, 47.4374351193828, 46.963585345975815, 45.558745322688935, 40.94185283107143, 43.904199369492076, 43.67487407499745, 47.663857859949914, 45.674643516540534, 51.31066583818006, 55.215424568422385, 46.48487575592534, 43.89291078813615, 44.23149762615081, 42.48238725046958, 44.9058432732859, 48.0804527959516, 49.645133326130534, 54.02023915321597, 49.34866097665603, 47.99250541194793, 48.54688928973291, 47.5831001804721, 43.67686271667481, 41.71242206327377, 39.66010462853217, 41.01232605595743, 40.67316262952743, 42.47717442051057, 43.01315453744704, 42.24084769525836, 43.68995951068017, 42.65688565469558, 43.19837670172415, 42.08716530953684, 43.26206422621205, 41.46293970846361, 42.236933169826386, 41.99574662793068, 42.65346927027549, 42.76274258090604, 41.53127131923553, 43.64029838192848, 40.25927412894465, 41.23958818374142, 39.97778523352839, 40.87585503055204, 40.851579481555575, 41.01739375822006, 43.35560883245161, 44.543600620762, 40.31479920110395, 42.646483528998594, 47.66787436700637, 44.82899619686989, 46.15059960273005, 44.540584318099484, 47.16970589853103, 41.194720191340295, 39.6809559483682, 40.01257665695683, 39.85730178894536, 40.070674803949174, 40.39192868817238, 46.2778099121586, 42.65448516415012, 43.267743818221554, 41.92799945031443, 40.25220209552396, 42.19171608647993, 40.08436779822073, 42.81487088049612, 45.20853257948353, 44.00260771474531, 45.9971486368487, 45.33059281687583, 51.111405511056226, 60.14230197475803, 60.566043469213675, 58.14299929526545, 59.706761990824056, 56.792448797533595, 56.01228544788977, 57.68245027911279, 60.95487979150588, 56.92415022080945, 59.92782285136562, 60.830685784739835, 60.511989285868985, 60.9760449009557, 63.69704408030357, 65.21251063193044, 67.8385845307381, 68.1634666073707, 66.72918135120024, 65.55475311894571, 68.38411561904415, 69.31674541965609, 70.56851494696834, 69.9110786376461, 63.63167778138192, 68.15445300071471, 84.03902453760948, 78.24785678617417, 62.41224427377025, 13.42265667453889, 0.19037306368831666, 0.06814172055812613, 0.23287203643591176, 53.60083187780073, 66.98460609682145, 64.92367905955162, 59.43086247290335, 45.46139209501205, 14.042365666358704, 36.24759943254533, 56.483114996264064, 46.54006350424982, 3.476470473312563, 0.2519595001133219, 0.07799152750521898, 0.06322449711602061, 0.08089134649884316, 0.041012995831307866, 0.03356744475182026, 0.02967101814705999, 0.028931704995733117, 0.05488819262433437, 0.07282658570235775, 0.020410545403137803, 0.014284189110772024, 0.025859326612384572, 29.18314599221753, 64.41979177536504, 49.160049884550034, 39.1142911295737, 31.795577887565862, 50.52269304952314, 77.25658755148612, 67.31272805121638, 3.15938116561982, 0.04760803226681967, 0.09582857481173931, 2.077830981823706, 53.763610239951845, 75.39779201630624, 74.85380634184807, 76.34802541425152, 76.7597879902009, 73.17697740370228, 72.64107181179908, 69.91754270369007, 70.29638090441304, 66.77523782176357, 72.01478696638539, 74.90683678657778, 70.63099830381333, 67.6868829419536, 65.20670160170525, 62.75189015173144, 63.030496105071045, 62.45116595299014, 60.92874896141791, 59.64190167765464, 54.01761508757069, 49.3475744801183, 51.76009885726437, 49.862436556047015, 48.45086966791461, 50.02161418237994, 49.18824388134865, 48.8068090715716, 48.867731325088016, 49.90298601888841, 48.91734930776781, 47.58859934345369, 51.225005195986846, 47.21325989692442, 47.96848873938284, 47.3870522745194, 45.16775169680196, 45.8049407312947, 44.673591890642726, 49.28169827307425, 49.06462254062776, 52.34471244196738, 56.05909109115601, 47.30418043751871, 43.23440759412704, 44.93724969125564, 42.19865083694458, 45.46653039993779, 49.016224415071555, 48.66307773897725, 53.93873230103524, 48.93112467181299, 48.557899382806596, 48.90417014398883, 48.87742742415398, 48.24644750164401, 44.32289669590612, 43.59306127794328, 44.820445429894235, 44.58635053327007, 44.03610475601689, 44.021313498097086, 43.91608807348436, 45.68699506021316, 45.22991341929282, 45.972147449370354, 45.25504404498685, 44.25806383932791, 44.38147337205949, 44.55029218427597, 45.254738100113414, 45.93839937640775, 44.90465479512369, 44.692866417669485, 44.46297237949987, 43.12547160733131, 43.545286809244466, 41.69390847606044, 43.146617104930264, 44.6865592464324, 42.26612737101894, 45.530237536276545, 45.7618260383606, 41.58511369459091, 44.584903178676484, 48.3613690253227, 44.968616885523645, 45.424141345485566, 44.74714417611399, 49.202599756179325, 43.10930359748102, 38.81629297810216, 40.252468816695675, 40.044591042303274, 40.513243675231934, 41.719807886308246, 47.55045821589809, 44.578588162699056, 44.99713251667638, 44.323771384454545, 43.50506290312737, 44.02151746134604, 43.0391598516895, 44.23349411256852, 47.65822533638247, 47.00599008990873, 49.06449702478225, 46.674942047365256, 52.771921311655355, 62.3117962960274, 61.63754086340628, 60.9977787540805, 63.42461585998536, 60.57639460409842, 60.35441198656636, 59.90746182780112, 62.56445969304731, 60.10158777236939, 60.18395754598803, 63.23064288785381, 62.81362825824369, 63.96087054283389, 65.49767871056834, 66.86244780017485, 68.5486904267342, 69.03725301065754, 68.43006226324266, 69.10401175099035, 72.1318148028466, 72.91145647725752, 73.02126715260168, 72.55397950449299, 68.08348163481682, 69.3895681442753, 86.53847648251443, 80.14101228406354, 67.37702354308098, 15.697862794322354, 0.13470568303619662, 0.11003895422383664, 0.2757872707180439, 60.27323461348011, 74.34924833236202, 74.8312448686169, 66.27138583890854, 49.112122443414506, 20.517035838096373, 46.34285849909629, 65.25910838957756, 59.33298364762337, 4.450186366035092, 0.22600957402779212, 0.024860619920335954, 0.03399236691034129, 0.03921722828020011, 0.014418797462337441, 0.10737798612324462, 0.1355559027363216, 0.14674512248846794, 0.2272746763041904, 0.1250313791716772, 0.17980849670787014, 0.11131449827864287, 0.23076121905638328, 38.79015822564402, 78.17955263199346, 59.1956889244818, 46.76174017690843, 48.86615845464891, 59.911949019278254, 80.49823038039669, 73.71374591704338, 4.167623721784161, 0.0923003951808618, 0.21739283156010414, 2.495765897535509, 59.972651620065015, 79.06914618707474, 79.38189245039418, 80.11524231203141, 80.60921776679255, 75.73564929346885, 75.61576597152218, 72.16863016928397, 72.83859452893658, 68.90462983039119, 74.73648040525376, 76.00124866731706, 72.39011072343396, 71.6602360817694, 68.04356759594333, 67.1448584525816, 67.13010249599334, 64.37937959547966, 63.389287071843306, 62.52789535830098, 58.47621640851421, 51.53511954892067, 54.08329909847629, 52.10109795293501, 51.02225788177983, 53.1770746938644, 52.350105700954316, 50.86883437248969, 51.38436717371787, 52.993543071131555, 50.623450894509595, 50.91427503093597, 54.641628880654615, 49.875882440997714, 52.195305439733694, 50.97884116634246, 47.260206745516875, 48.2874245028342, 46.186312783148985, 51.73795315527147, 51.72311875127977, 55.68489305434689, 58.48691271197412, 48.62975328199325, 42.2386040995198, 44.25587907914193, 41.98598384857178, 45.31260482726559, 49.93864820849512, 50.693088654548895, 57.34966070421281, 50.218752507240545, 47.95526642953196, 49.69724593623992, 50.21820729778659, 51.25866305443549, 46.985174071404245, 46.57825562261766, 46.05860433270855, 47.78015221318891, 46.34781245262393, 47.64032756128619, 45.95909772380706, 49.094369796014604, 47.0628095442249, 48.54368471330213, 49.126595989350356, 48.0913059942184, 48.32829952239991, 49.29253185949018, 47.170462915974284, 48.54061741982737, 49.41078739781534, 47.598977934929636, 49.316736805823545, 45.62521772999918, 46.640664454429384, 43.89068288187827, 45.682970708416356, 47.7093965776505, 46.74611345414193, 48.234872587265514, 45.87460202555503, 40.5159265764298, 46.540914658577215, 48.593632175076394, 45.63145822094333, 47.130682237686656, 44.503996449132124, 50.24281232587753, 43.8090975822941, 39.555746047727524, 40.81718029514436, 40.66942068838304, 40.41831447232155, 40.751139348553075, 50.0073524444334, 44.85012208261798, 48.27959937434043, 47.8590859905366, 46.80993433921568, 46.966256480063166, 44.039124981049575, 46.85015040059244, 50.82691992482832, 50.12246616425053, 51.496703855453006, 49.07333804715065, 56.04429591086603, 65.47001031137282, 65.42377733415174, 64.40273730985581, 65.32002279835363, 61.90209688678865, 61.26116591115152, 62.984412177916504, 65.53637681468841, 63.68477882877473, 64.59496482726067, 65.7424581435419, 64.52670381915185, 64.11212498141875, 68.60668659210205, 69.20752309983777, 70.81745209232454, 72.47323359212568, 70.1864839369251, 73.46687193839782, 75.89753335522067, 78.16000353905463, 76.662183730833, 76.43511772155762, 72.79328330870598, 76.66776918595838, 87.85187428997409, 79.55013075182515, 71.0717942637782, 17.191303276246597, 0.45362014924326255, 0.1963564861685999, 0.5444751127112297, 68.7995966019169, 82.69552646144744, 84.2108557301183, 78.47609166176089, 66.50407652701101, 23.097170937445856, 56.959035781122026, 74.02364453961773, 74.82808343825802, 6.691912604916481, 0.4468687389406466, 0.26058722828184405, 0.2055640509652515, 0.22701486524554992, 0.08648587976612392], [0.04877093458367933, 0.06233776949586407, 0.022489478203257727, 0.03933137921135753, 0.019257730549021114, 0.028615753098781553, 0.1021008124394763, 0.04780305143926413, 32.00569533532666, 54.07707429701283, 44.34201432812599, 22.63811634432885, 42.396836434641195, 58.07020402723744, 65.56649669524163, 68.20535752081102, 4.313577077081127, 0.08840889835189428, 0.07435920588191479, 1.2717505712662975, 35.795381530638664, 70.44701560851067, 70.51089532913701, 73.10861049159881, 71.11697212342294, 69.88322980942266, 66.85562287607502, 67.03941729760939, 64.32892222558299, 70.39702107829433, 71.61055534116684, 65.8409841599003, 64.03730969275198, 64.48676624605733, 57.21311123140397, 53.45628076984037, 50.751924207133634, 50.30845319071124, 48.24024623440158, 49.974777160152314, 48.11837034840738, 47.94511533552601, 48.28513383865357, 47.86701310065485, 47.2257879472548, 46.339206772465865, 45.740119641827, 46.691706257481734, 47.961616746840946, 48.1524988912767, 47.54746152508644, 47.73772393503497, 46.3643648547511, 45.75984524142358, 46.758614047881096, 45.16773992969144, 44.65889476960705, 44.781508061193655, 42.35669097592754, 45.019403734514796, 45.74406162385018, 47.74074023769748, 53.39324043643091, 54.13727483441753, 44.18987343388219, 43.12475381358978, 46.673820249495975, 46.09064225227603, 54.32308927659066, 53.61851784490771, 50.97089052200318, 50.81749054693407, 55.35506486892701, 50.779800491948286, 50.426234122245546, 47.78880888415922, 45.55443463786956, 41.13257808070029, 40.95872294518256, 42.437232925045876, 39.863099052060036, 42.394055474189024, 41.365762987444484, 43.4874749952747, 42.742020699285696, 44.47948555792532, 42.89709944878855, 40.69866195801766, 42.56111706456831, 40.414439170591294, 42.74486441766062, 43.49353505719093, 41.07113022958079, 41.01644454463836, 41.62215263612809, 41.30683722034578, 40.924249233738074, 41.60554532081851, 42.32617493598692, 40.365942985780784, 43.10928790800033, 44.92032466396209, 41.73795669309555, 40.76724067811043, 43.19516035818285, 47.17915096590596, 46.94464422041371, 48.6940997646701, 47.03878502691946, 42.92479138220511, 43.12249845074069, 41.651158563552364, 39.793535817054014, 39.08642268949939, 40.848908347468225, 42.56048948534074, 45.24078622941048, 42.66089039464151, 42.85698536903628, 41.30579779225011, 41.80994787523824, 42.12184298423029, 41.32496249291205, 40.20662023175148, 44.9315308755444, 46.14939543508714, 46.35125237126505, 43.750418924516254, 44.96075645569832, 50.79643918621925, 59.351763956008426, 60.89711896834835, 59.50263400231639, 62.55570888519288, 63.728827045809844, 58.364679890294234, 61.06832650399978, 60.961575277390025, 61.00464290188205, 61.268951815943566, 60.798843983680975, 66.96493148803711, 66.97880883370676, 65.29952449183311, 65.86234538785874, 65.73198149281164, 64.72927462670111, 64.80130111017536, 65.39959199966924, 66.46373887215891, 64.29278542918544, 63.85734742687595, 72.47285704458915, 64.12445299087032, 61.55458273426179, 80.24896375594601, 78.46182207907401, 18.37891851702044, 0.24986026598320854, 0.12105065608216871, 0.041887029374559084, 42.64501264018398, 72.05160233282274, 63.929621019671046, 56.19006295357981, 41.4086344934279, 50.4069007596662, 43.25198765723936, 47.51457245119157, 64.40990348016062, 7.030779402102194, 0.20929494512177285, 0.10280112405457806, 0.032377415261561834, 0.18257514663761665, 0.0068692781966209655, 0.027062686032525478, 0.04261190942939251, 0.06609926886496044, 0.06536843630695535, 0.02302431865715452, 0.033332033593568115, 0.02033823436396497, 0.03315420926458413, 43.68413871334445, 62.355632705073205, 48.34348693970711, 35.71194879470333, 48.166325246134114, 65.81249990770894, 71.59425397073069, 75.77196259652415, 5.285294277052726, 0.15241466342441498, 0.07409800820413136, 1.734730721481385, 42.77095602404687, 73.31545276026573, 73.67067829255136, 74.47720389212333, 74.61178825747582, 73.52899443718695, 69.84002882434477, 67.36795502324259, 64.57847518305626, 73.94735443976619, 73.41466519140428, 67.99116473044118, 66.84480497913977, 67.53403602107879, 58.374568185498646, 55.71026294462143, 53.40613718955748, 53.27849541940997, 50.832215124560946, 51.849026833811116, 50.11467633708831, 50.69161776573428, 48.46131493968349, 50.10853390539847, 51.53567260311496, 49.126227286554155, 50.22670707395, 48.657562886514974, 50.176108498727125, 49.28510289038382, 48.1350443440099, 49.13487611278411, 48.14874910539197, 50.74429519714848, 48.66097534856489, 46.23187895744078, 47.211930213436005, 46.36701245461741, 46.515897781618186, 47.96313470409763, 47.450096530299035, 49.88667680371193, 56.19102785664221, 57.354073370656664, 43.61989028992192, 42.84568109819966, 47.255535202641646, 47.74625901252993, 57.005229534641394, 54.30339897832563, 52.74262512883833, 53.06609122983871, 54.88711041788901, 52.15301052216561, 50.51943748228012, 48.23144443573491, 47.46647242576846, 45.94398090916295, 42.63558326228973, 44.32205338631907, 43.00947535422541, 45.94164317654025, 46.313181846372544, 44.76743459701539, 44.692176080519154, 47.72636475101594, 44.73255688144315, 43.49988929687008, 43.93788860690209, 44.002756764811856, 46.42469875274166, 44.07455967318627, 44.049307454016905, 45.81208728974866, 44.38410920481528, 43.63302238525883, 42.746551036834724, 43.698573035578576, 43.41439731659428, 41.99269894630679, 45.994642242308586, 45.80049668588946, 42.592284217957534, 40.70422387892201, 43.54467884186776, 46.25245571136475, 46.07172073856477, 48.84139653175108, 48.39930618962934, 43.8827440046495, 42.64336132234143, 41.53750788780951, 39.111231680839296, 40.01072137586532, 40.74735426133679, 43.20611553807413, 48.53860524392898, 43.51146028887841, 45.2068655721603, 44.26253534132435, 43.10663246339367, 44.29407904225011, 42.93991996395973, 43.08545950920352, 47.18348518494637, 46.85270778594479, 47.5658299846034, 45.706450016267844, 46.75616648889358, 53.698412602947606, 60.09038156078708, 62.87953192187894, 61.657819517197154, 63.03517941505679, 64.35455491465908, 61.560164267017, 64.03357167397776, 63.49824659286007, 63.02692282584406, 63.8509225845337, 62.476178907579, 70.32372766925444, 68.14547861776045, 67.66300355234455, 67.66396845540693, 67.73360621544623, 67.70341965460008, 67.68674958136775, 67.12902776656613, 67.79664654885569, 68.44280212156235, 67.72519665379679, 72.11317569978776, 69.96746663124331, 65.888688025936, 81.03313969027612, 80.00172107450425, 20.912326420507124, 0.3172334241530588, 0.14796962210487935, 0.04436524337037437, 47.14612068668489, 80.37925704833, 70.64760561912291, 66.03485907277754, 42.07383709569132, 51.22617406229819, 54.166418044797844, 56.5812683874561, 76.81344601415819, 9.278241126768052, 0.209436395596112, 0.07277371031382392, 0.0538582640189317, 0.12455780659952473, 0.0811780472436259, 0.09703861068814032, 0.13750806330673157, 0.10366471964986095, 0.15878564978559173, 0.22438330726037103, 0.12722406070679426, 0.1899421239091504, 0.14426456043316474, 54.92694600935906, 73.54348367260349, 60.5199360078381, 33.56140344373642, 54.37818288803101, 78.32311138030022, 76.24324321746826, 85.38093013148155, 6.281683185408193, 0.32437268944997943, 0.13319656643415653, 2.163595566826482, 47.11832284927369, 79.00394855007049, 79.22542125948014, 80.57733674203196, 77.19144482766428, 76.71803043734643, 70.08505928900935, 69.7315360653785, 66.71618261644917, 75.5778915651383, 77.21075073365243, 71.84141036002868, 71.52197253319525, 69.47149861243464, 62.066620703666445, 59.59322898618637, 57.73926188868862, 56.041350210866625, 54.75630329501245, 55.245877850440245, 53.02262744595928, 52.78058974973617, 54.30463060255974, 53.846705652052364, 55.04946908643169, 51.18975485524824, 51.774490033426595, 50.85067379859186, 54.6590442042197, 53.06675411039784, 53.12072200159873, 53.385387851345925, 51.74935940773257, 53.37453465307913, 51.81111320372551, 48.815014669972086, 51.07384489428613, 48.79356714986986, 49.459793490748254, 50.22188648100823, 51.06378009242397, 50.89637725583969, 59.70953510653589, 61.50083449579055, 44.81772722736482, 45.65060330975441, 46.56265243407219, 48.41904747870661, 57.241575871744466, 57.96068360728603, 52.10672263176211, 53.53723849019697, 58.69528862737841, 52.062627346284934, 51.76892419015208, 50.22008219072896, 51.56498055304251, 46.84029348434941, 46.215499139601185, 49.34332655322168, 45.31322456175282, 48.62781170875796, 48.45130897337391, 48.36417744236608, 48.10347318649293, 51.105345449139996, 45.95675606881419, 47.636220839715776, 47.81101734407487, 47.22281871303436, 48.37665057951405, 49.56725858872937, 47.375520506212794, 47.24990660144437, 45.45023687424199, 47.3638867562817, 46.377465571126635, 47.300109017279844, 45.894284479079715, 45.789137501870435, 48.2405835582364, 46.857026315504505, 43.726276736105646, 39.99150960676132, 43.18497396284535, 46.49646243741436, 47.94442107600551, 50.82274652296498, 50.7212826513475, 45.420183673981704, 43.3001269063642, 43.876448600522934, 40.032537598763746, 41.888701223558, 41.81871045020319, 44.05743068264377, 51.4450893863555, 45.721394246624364, 47.17764085338962, 47.63186700882451, 46.79937924108198, 45.99841948478453, 47.290620803833015, 43.803347387621486, 50.33241495009392, 49.81592901291386, 51.261789183462824, 47.53886368966872, 49.259223091986875, 56.46714310492239, 64.15911889845326, 66.02834793829149, 64.12713196969801, 68.9024019241333, 68.1831019924533, 63.54871180749709, 66.28093288790795, 66.8167600324077, 65.53138755982923, 65.76586684873028, 63.66172705927203, 73.45616386782739, 70.04490206318518, 71.5502763563587, 72.06616217090239, 70.83438104198825, 70.09098991270989, 69.40832491843932, 69.78081672422348, 72.66600239661433, 71.49191933293497, 69.12465126283708, 78.5500204947687, 72.20466106168686, 72.04397724520776, 83.44254186076503, 78.20125902852705, 22.882185828301218, 0.8937819722679354, 0.4051053025309117, 0.13915976419323875, 54.63139933924521, 88.75413710071196, 79.32459446691698, 74.13318849379017, 58.320145299357755, 65.28711019023773, 60.93502867606379, 66.56503800422915, 91.79512716108754, 12.978668885846293, 0.34464012771364183, 0.21448361266764904, 0.22005288801606626, 0.46006294868646136, 0.26701519626282877], [0.05086010997934688, 0.05146334293268381, 0.057155456649319786, 0.04122452036808095, 0.06127549282785866, 0.03681319457809291, 0.03052845631065148, 0.08274329510787803, 30.141632057005364, 60.29536462599232, 35.63756104438536, 27.082622628058157, 36.47230025260679, 52.41251845513621, 65.73847301544683, 71.09197093594459, 7.364199988303646, 0.20449592521594417, 0.2745943492458713, 0.8407593722785673, 29.116285270260228, 64.2139144097605, 69.20553053579023, 72.08262043614542, 70.87902545928955, 69.47518564039662, 65.37599502071258, 64.53454855949649, 68.37521968349334, 71.4820114258797, 67.19374687440934, 66.70489403509325, 62.06274147956603, 53.07352804368543, 50.32890050641952, 47.103574737425774, 49.61615485529746, 48.14656042283582, 48.470524664848085, 46.98966126288138, 45.24079015178066, 45.47796018661992, 46.22354392082461, 45.08653902238415, 45.70544588950373, 45.91078589039464, 47.41976876412669, 48.35238287525792, 51.522630722292014, 50.268939233595326, 51.389505478643606, 51.38672059582126, 47.98602173405309, 46.57769080131285, 45.561706712169034, 46.22210441097137, 44.3702357815158, 44.34900399177305, 41.458487818318034, 45.925879170817716, 44.98324732626639, 47.4137596930227, 49.957216708890854, 57.48050312842093, 53.04824836792485, 42.57589263300742, 48.74350201699042, 52.711269701680834, 55.23527568386447, 60.008804105943256, 59.07610370266823, 54.73338096372543, 57.08121761198967, 54.49316324726228, 49.11766475246799, 49.66492952839021, 47.953293477335286, 43.95783385922832, 39.777046172849595, 39.183932811983176, 42.00261077573223, 42.574029507175574, 43.758722582171046, 40.738015097956506, 40.48491631784747, 41.732990972457394, 41.93402421089911, 42.78481768023583, 41.57592358127717, 42.349858207087365, 42.29019111202609, 42.72778249556019, 42.38818368604107, 41.297141121279815, 41.50138285852248, 40.71812083644252, 42.08736927278581, 39.454941134299006, 44.35704092825613, 46.17794636757144, 45.045667925188624, 41.08927511399792, 42.16951939367479, 39.637751040920136, 44.543753593198716, 49.90245649891515, 43.43116152671076, 46.203265267033736, 45.026754256217714, 41.10906347151726, 42.860437054787916, 42.16488315213112, 39.548987803920625, 41.01769185835316, 38.339807371939386, 45.55629384133124, 47.34496916494062, 43.35378493032148, 43.26535901715679, 41.459970474243164, 40.49012130306613, 41.19260211144724, 41.750955427846606, 42.13801099408058, 45.1971733954645, 44.90391346716112, 45.46414559887302, 44.6963494823825, 43.92667455057944, 45.74045696566182, 48.01372151220999, 50.467383707723315, 56.287412258886526, 54.108366966247566, 60.39099593316356, 61.19786670131069, 62.62351097599153, 61.92849051567816, 62.37401685407085, 61.391576874640684, 65.51560001988565, 63.69130565274147, 63.24642650542721, 61.5596818154858, 63.01285720640614, 59.931294148968114, 61.47262873188142, 60.332368266197946, 61.90879237267279, 62.09281429167717, 64.20336323399698, 64.89526933239353, 65.58989363331949, 69.06304651691069, 71.40700001870432, 56.61969192566411, 82.7583549868676, 27.50686618589586, 0.4942917571433129, 0.13143439566896808, 0.2298227613491397, 35.54016467063658, 71.47344496942335, 67.0629358291626, 59.60840071401289, 44.815970005527625, 19.515917531905636, 17.319009765501946, 50.42964266192529, 61.55049954691241, 10.160362566671065, 0.5679587719421233, 0.21205496073009508, 0.15072150185944574, 0.07394272218187971, 0.06349779515256805, 0.041178984101861715, 0.0699350404583158, 0.015313295129265998, 0.045730059650997, 0.04923271323223749, 0.07496692044960876, 0.027877979784182487, 0.0410125361785533, 37.771326495755105, 69.51891222307759, 40.38156578617711, 27.900903571036558, 41.05882183198006, 58.886221762626406, 70.88233593971499, 78.41019584286597, 7.572876945618661, 0.5534242454075045, 0.09446804096261341, 0.9519042663516538, 35.33622103352701, 71.13888248320549, 73.3529741533341, 74.38065082796159, 71.67415265114077, 73.08790822182932, 65.94037702006679, 65.96202850341797, 68.91303154730028, 73.45186495011853, 69.19837613259593, 69.53572350163614, 65.28368988344747, 55.34026968863703, 51.48136738807925, 49.558288128145286, 50.010356979985396, 50.837494634812884, 50.24639737221503, 50.65016223538307, 48.46013822863179, 47.794515932759936, 48.424938878705426, 47.55691443720172, 48.71193478184362, 48.41474463862758, 49.01379646793489, 51.63377892586493, 55.81836738894063, 52.03207992738294, 54.67182328624111, 53.2336627283404, 51.92170443073396, 50.02875681846373, 46.84663987928822, 48.01667897931991, 45.14686507563437, 46.07122259755289, 44.399131882575254, 47.800187680029104, 46.60369611555531, 49.44790870912614, 52.01392719822546, 58.87909873839348, 55.46374982403171, 43.793525772710005, 48.0440688902332, 53.695204104146654, 58.89213277447609, 62.682205323250066, 60.521453965094786, 56.154628261443115, 60.206381736263154, 54.78864323708319, 49.13787280359576, 51.648193636248195, 49.13360134247811, 47.12885441318635, 42.72568794988817, 42.70537399476574, 44.57256732448455, 44.9983053053579, 46.114662847211285, 44.64169517640145, 45.37247980794599, 44.96156446395382, 44.27369840683476, 43.38242215494956, 44.42468612424789, 44.958061787389944, 46.27958674584666, 46.04157732379052, 44.11714876851728, 43.6948860076166, 44.84158308275285, 42.5108911145118, 44.34800770974929, 43.29828731475338, 46.92928814118909, 48.64001027999386, 45.74808989801715, 43.0152294712682, 43.03668091374059, 39.545045821897446, 44.30993326248662, 50.59659834830992, 43.85635822050033, 46.262826458100356, 45.37078926640172, 42.857032437478345, 43.960253961624645, 42.51951248415055, 40.216936065304665, 41.35277209743377, 38.294013700177594, 47.560734825749556, 49.63029107739849, 44.37861788657404, 45.10951234448341, 42.82468857303743, 44.139463132427586, 44.169182931223226, 43.96438029504592, 45.97123745949038, 48.261077942386756, 45.82111266351516, 47.77163282517464, 45.120898985093646, 45.546460459309245, 46.83130733428463, 49.72432205753942, 52.86383421190324, 56.71499375374087, 56.91871381575062, 61.26496276547832, 63.742892665247766, 64.67085484535464, 64.51439542155113, 64.15718124758813, 63.50043527541622, 66.50019338054042, 67.56626221441454, 66.6445993608044, 64.31246003796979, 64.36117195313977, 63.03938811825168, 61.04255653196766, 60.58658492180609, 65.01823171492546, 65.28403505202263, 65.67023554155904, 70.39266724740305, 66.9536978198636, 72.88801639310776, 74.4401688729563, 64.68681889195597, 82.55109694696243, 30.00344499464958, 0.6711065661041968, 0.20652979672435792, 0.32114237246494143, 40.379239820664935, 79.77484333899714, 74.0577220916748, 66.38443639201503, 50.73365380687099, 28.60173306157512, 30.91663552868751, 60.10846760965163, 75.21609998518421, 13.20180566080155, 0.541513845805199, 0.23724215435645274, 0.13074176025486764, 0.016773368697613478, 0.043510603342926314, 0.15659206426672398, 0.18509189868646284, 0.1502258276506778, 0.1455685493325995, 0.1589081166011672, 0.1152277443437807, 0.13390222534296975, 0.19899207377626052, 50.82047154826503, 81.18429999197684, 50.112479809791814, 35.99518314484627, 49.39542347385038, 69.47811957328551, 76.06719939939438, 88.76508051349272, 9.218555400448462, 0.597715710680331, 0.4003644133767774, 0.9950086630640492, 43.09104104195872, 73.20955661035353, 78.30572743569651, 78.1618627425163, 75.5643750775245, 75.18968674444383, 69.55990883611864, 69.53288370563139, 73.57296420681861, 76.9097323571482, 70.9117615607477, 72.99368504554995, 69.83576913033762, 59.0304002454204, 55.856904675883634, 52.56136063606509, 55.0270252843057, 53.73450625327326, 54.331098756482525, 53.71468651679255, 50.08629798889161, 49.75748961971652, 50.61664558226063, 49.73870538896131, 51.58165454864503, 50.4728122680418, 52.26598262786866, 54.26044118019843, 58.70665957850795, 54.76827044640818, 57.67941436459942, 57.71144443942655, 53.79426356284849, 51.17847804100283, 50.583764353106105, 51.32986191780337, 48.0510389420294, 48.73698303776403, 46.707662459342714, 50.87485913307437, 49.88735537375174, 51.20797818706882, 53.54580494665331, 62.122385040406265, 53.042588387766195, 44.114862026706824, 49.700489736372425, 54.70308457651446, 59.16746747109198, 64.51327754605201, 63.158498733274406, 55.9130024140881, 60.66818983324113, 57.59470685835808, 51.33887160208918, 52.343578876987586, 51.078818459664625, 49.72730305887038, 43.36637573857462, 44.62003584830992, 46.928993963426166, 48.58295156109718, 48.76164297903738, 46.35763406753541, 47.778967657396876, 47.90839802834296, 47.51389388115176, 47.428770603672156, 45.72978027405278, 47.683626605618386, 48.57989211236277, 48.573679078009825, 46.73521318743306, 45.95296313685756, 47.91437964285574, 46.24395985757151, 49.39842800940237, 45.350706731119466, 49.39239540407735, 50.95835854930263, 46.31327990562686, 41.98752141767933, 43.28935607787102, 39.68958124037712, 46.240508171819876, 52.57189219997775, 43.87144757855324, 49.45556909807267, 46.51920433967344, 42.15246100579539, 45.20414736963088, 41.98702327666744, 40.71315119343419, 40.98230423465852, 40.610334104107274, 48.35821936207433, 52.382798656340576, 48.40165568936256, 47.6116354234757, 46.22150036596483, 45.637851684324204, 47.345157438708895, 46.271655713358236, 47.90320873260499, 49.961241060687655, 48.97722428844821, 51.06042254355646, 48.53760896190521, 48.44121279255037, 49.877000316496826, 52.67936122032904, 54.98329085688437, 60.228680410692775, 61.47821026463663, 64.72952565839215, 68.3429228874945, 68.01911554028912, 68.72907238621866, 66.9863005607359, 67.25658324456984, 69.71007285579559, 71.46691030071628, 67.90355467027234, 68.46899570957308, 66.78625183720743, 66.0895839814217, 65.75624135232741, 64.96612302718624, 66.56008012833135, 69.13786180557744, 69.17530475124236, 73.87413947812973, 72.85812793239471, 77.87646324403825, 77.72971953115156, 72.81240094092585, 87.56125803916686, 30.33267697980327, 0.8536849303110954, 0.6996946998180882, 0.3590119678166605, 46.821775974765906, 85.6398771655175, 82.62115832298034, 73.81320153513263, 68.94124123357958, 27.369636181862127, 31.750213715337942, 69.33016777038574, 89.19594503218129, 18.158059658542758, 0.7866149131328829, 0.48459271629971845, 0.25435971486712655, 0.25110076151547894, 0.17739357306591927], [0.07795139981974518, 0.06907997142163015, 0.050251299905921185, 0.049249387135909456, 0.07041576829168104, 0.02097023008841901, 0.061054012978509556, 0.12292884320261017, 27.322720712231053, 59.327347201685754, 41.669287758488814, 44.93843816941784, 39.826067955263206, 54.923827725072066, 63.28033147319671, 69.28640196400305, 11.017032727118462, 0.4818838906864967, 0.16403306095350176, 1.0136170613188897, 19.448897953956358, 61.85808789345526, 66.6775551149922, 71.75428667376119, 71.43145207435855, 67.15617056815856, 68.17361770137664, 70.46334051316785, 70.05389213562012, 64.43247672050231, 63.65329396340155, 59.32195002032865, 49.732598258603005, 47.96740224284511, 48.939526388722086, 46.74281081845684, 47.05480006433303, 46.404882938631125, 47.70389349229875, 48.509783667902795, 45.43711262364542, 47.406722960933564, 49.29798003165953, 48.38390696433283, 47.07352545953567, 48.54415932009297, 52.307406779258486, 58.537236721284934, 58.250468315616736, 58.65846149383053, 55.92369871754801, 54.57602723952263, 52.32169989616641, 48.74744792138377, 46.21449501283708, 45.63330173492432, 44.24884234705279, 43.812831678698146, 42.532166050326445, 43.97037759903939, 46.004914929789884, 43.984054903830256, 50.04104952658377, 55.91467726615168, 59.71607761998331, 52.067408715524984, 47.52561000085647, 51.08720056472286, 59.945265631521906, 61.22640978905463, 64.82795753786641, 63.68745780760243, 59.58909873039492, 56.210929962896536, 50.863346976618615, 51.7338974245133, 45.04641317552136, 46.27895132187874, 43.69467812199747, 45.94480852926932, 42.59430423859627, 41.784848628505586, 42.33871867579799, 43.06329027298958, 41.34182476228283, 42.70229493418048, 41.125706088158395, 41.69778377779069, 40.078484242962254, 41.5034068015314, 40.58627428547029, 41.172009668042584, 43.36401054936071, 41.970616002236646, 43.18409927429692, 43.69336020561957, 40.93560057301676, 46.29205596062445, 43.61905090270504, 40.28174538766184, 38.38760145248906, 40.47080362996748, 39.09278477391889, 39.89592929040232, 45.550610326951556, 45.78042199534755, 42.808559786888864, 43.082396138098936, 42.890478487937685, 45.09504272091774, 46.348479255553215, 45.28395191315682, 45.67261957353162, 46.59441971009778, 47.145897111585064, 55.031634069258175, 49.227149871087846, 41.97035712580527, 41.51189481058429, 40.57946112848098, 39.74075248164516, 41.23585408733737, 40.71946620941162, 42.612166712361, 43.89421693740353, 43.93811610437209, 45.39814779835363, 42.82135063602079, 43.54727152855166, 44.418865326912176, 43.56658920165032, 45.03050796447262, 45.704649648358746, 47.15410663235573, 48.17901803601173, 51.2874650186108, 53.79235336857458, 55.63998976061421, 56.93667042639948, 60.54590209837883, 61.11011543581563, 62.44922437975484, 58.76355748022757, 57.74978168549077, 53.661773743168006, 54.76072772856682, 55.615314129860174, 57.9839667966289, 60.669017453347486, 62.16624106130293, 60.096147444940385, 64.13358034626131, 68.02106888063493, 64.70310457291143, 73.86538474790513, 71.72177022503269, 60.2440639465086, 34.403606922395774, 0.32384482422663324, 0.18348781782532894, 0.2546321510547592, 25.373808722342215, 74.19554633478965, 63.90370984231273, 62.94003055941675, 35.81957863223168, 29.750993405618978, 31.75443614682844, 44.69907945202243, 62.55932138812158, 18.67855033566875, 0.49944486288774403, 0.07676072298519074, 0.051628542132675655, 0.011872141171366939, 0.036230082924087206, 0.02685035135777247, 0.10511242664389073, 0.09591209371724436, 0.006318143531379681, 0.06705449623686653, 0.007435864376490035, 0.006897542531782341, 0.0274686896497564, 35.7621512105388, 68.93042333664434, 47.172977155254735, 44.360653431184836, 41.62714581335745, 63.23438875136837, 71.35946089221586, 76.47378444671631, 12.205990399083785, 0.5523179531578095, 0.06543750679420848, 0.9245608722971332, 24.48565467711418, 66.54920731821369, 69.94353232845184, 73.86769894630679, 72.75947247782062, 69.39409455945416, 70.93575077672159, 74.35617523808634, 71.37058473402455, 67.17246409385436, 65.68290479721563, 61.39413033762286, 53.31230232792517, 51.43797028449274, 51.475048449731645, 49.02991348697294, 49.23980343726374, 48.29016623958465, 49.560712152911776, 50.406853691224136, 48.94576687966624, 49.894529388796904, 50.49998644859561, 50.61136607200869, 49.069941274581424, 51.78815164873677, 54.02180025654455, 58.773261424033876, 59.76369519387523, 58.37010060587237, 58.03959385041268, 57.46316625225929, 55.07093621838478, 52.44413668109525, 48.61720561981202, 47.56528477514944, 47.90028264445644, 46.564695988931966, 44.40043018710229, 44.658404473335516, 48.43412506964899, 45.60096963759392, 51.80866956710816, 58.83496422921458, 61.41504441538165, 54.9565520594197, 47.66304592932425, 50.31974569443734, 60.39149799654561, 61.50254464918568, 66.73693979940107, 64.06542916451731, 61.072233184691406, 56.4225967468754, 52.33554194050451, 52.36741119815458, 47.03502347392421, 49.42749277237923, 45.96252979770784, 46.29810817780034, 46.24581906103319, 46.17879359952865, 42.601109550845244, 46.71563271553286, 43.0764929709896, 45.048021347292014, 44.39178920561268, 43.57122152082382, 42.39317294090025, 45.76436773423226, 44.95513177687123, 43.06414927205732, 44.22487274292977, 45.03601497219455, 44.03828167146252, 45.91887774006013, 44.75669906985375, 48.1199824425482, 45.548935474887976, 41.43972319941367, 38.50431549933649, 40.67595143471995, 38.745737383442545, 40.91370198034471, 47.7900718873547, 47.72623139043009, 43.89420124792284, 43.769156086829405, 43.41951208729898, 45.441827312592544, 46.91355551442793, 46.487158575365626, 44.76242180793516, 47.84858188321514, 48.660304623265425, 56.57296080743113, 49.25064094604985, 43.53975234493133, 44.25532602494763, 43.545322110576016, 41.50210849700436, 43.789799521046305, 42.33131324091266, 44.798378175304784, 46.0410281919664, 45.7682155793713, 47.295845400902536, 44.44869495207264, 45.98931958598476, 46.7317928806428, 46.69799381686796, 46.005358157619355, 47.839874221432595, 50.10456446678408, 51.600729034793, 52.17721546849897, 54.886337710965066, 58.58930226295226, 59.407496913786865, 64.02675851698845, 62.660102767329064, 64.01287724894863, 60.67246129435878, 59.44299828621649, 55.00727222811792, 57.11472642037177, 56.80964446836903, 61.430223987948516, 63.7480035135823, 64.81287994692403, 62.82698392868043, 67.30352617079213, 70.19607805436658, 70.03042067250898, 76.51980169357793, 76.77240233267509, 61.815565478417184, 34.697502274667066, 0.37015698429557586, 0.11448130657475804, 0.3842711124208666, 27.809486850615475, 83.89001369476318, 71.2814292600078, 72.75525985225555, 38.82707557370586, 23.097561213278002, 32.24004714719711, 50.60878515243531, 76.7278128285562, 25.23879485745584, 0.2516434275575223, 0.2572376160852371, 0.07521353181331389, 0.08826107402602512, 0.07607984702072798, 0.1491941063995323, 0.39882142036672563, 0.21233731009546788, 0.17957923723564995, 0.17084889925054966, 0.08545916106912398, 0.10868165326575119, 0.28009452346351843, 50.131824939481675, 77.35139908329134, 58.06478723402947, 64.29540557246055, 56.7175393719827, 73.47495986569312, 77.04190838721492, 86.2684997435539, 13.790765231655492, 1.0246557754374321, 0.3647754924191583, 1.1408936833181689, 30.888231685084683, 73.80522343420213, 72.56757443951022, 77.04474818321967, 77.85722794071322, 73.69097263582292, 74.14199813719719, 75.74649072462513, 75.09581658147997, 71.99337082524454, 68.19465729498094, 65.07387053581976, 54.46664018015708, 52.546949848052, 55.12012666271579, 52.42997692477319, 51.78085996258644, 51.774364517581084, 53.532049194459, 53.44163463961694, 50.2385094857985, 52.70354263244137, 54.217871696718284, 53.66189141427317, 53.143773771101436, 54.54240468240554, 56.20423055464222, 62.986816590832134, 61.27789089756628, 60.136151698327836, 60.6917985793083, 60.31984413823774, 58.970015356617594, 56.43232422490274, 50.66562814097251, 50.35394091759959, 50.40768131133049, 47.626077590450166, 48.27885804637786, 47.43255961325861, 51.83117612715691, 47.25645303726197, 55.5663590277395, 61.30983468024962, 65.17374976988762, 55.785552840079035, 49.663854798962994, 52.67158708264751, 62.117015315640366, 64.78767479619673, 69.54581968245968, 66.21036160376765, 60.59218214404199, 58.28795832972373, 53.750183966852006, 54.247093354502034, 46.801830722439675, 49.877329795591294, 47.83417109520205, 50.25406560590191, 47.97699636028659, 47.734652719190045, 46.73708808037543, 49.37656079569171, 46.19589905585013, 46.62038580063851, 45.70057430574971, 45.55646642561882, 46.20103343840569, 49.985932380922385, 48.9579576061618, 44.82785478714974, 47.262222843785445, 47.68737639150312, 47.83931724486813, 48.65487606294694, 46.56686505963726, 51.867822831676854, 46.835645475695216, 40.898185083943034, 41.1374222078631, 40.60392102887554, 39.41306983270953, 40.71707356360651, 48.732703731906035, 46.7780533144551, 44.27389844771355, 43.938010200377434, 44.201683690471036, 44.17257578142228, 45.60622169125465, 47.29418623831965, 45.147661316779356, 50.98855687725929, 50.28280088978429, 60.13067214719711, 51.77156786764822, 46.69103553218227, 46.75594291379375, 46.955524875271706, 43.66986913065757, 46.03076727159562, 45.741947466327304, 46.76199120859946, 47.41031977438158, 48.39155558616885, 50.51966105737994, 45.56531529272757, 46.60031503246677, 50.90245300723661, 47.99808694470314, 49.59316976608769, 50.56704328906152, 53.72263323876166, 53.637992412813254, 55.19796217641523, 59.13543739626485, 62.569747048039595, 62.82022568487353, 68.07052996850783, 66.2000379254741, 68.1821527788716, 63.29534630621634, 63.05948634301463, 59.042590971915956, 61.58312974437591, 59.31173224602977, 63.666351533705196, 66.13906860351562, 70.09225291590538, 65.99374478863132, 72.5785727654734, 74.05489798515075, 73.90121167705905, 80.96245073503064, 78.59849314535819, 69.00789014754757, 38.33071531787996, 1.1334805262665595, 0.41460497665309143, 0.6091366720295722, 33.736600029853086, 91.39266844718688, 80.20270332213371, 79.43277343626946, 54.854958749586544, 41.96591700277021, 46.358583281117106, 62.50527112714706, 89.6302612366215, 32.07491928531278, 0.5077726063468765, 0.35199996504572134, 0.10117864176150292, 0.14048907995945023, 0.19233916705894857], [0.09405465991867167, 0.05202220407344642, 0.016132681705658476, 0.015860920633009125, 0.10287423182519213, 0.022202170333795013, 0.060742720811357426, 0.06141669815406204, 28.688637095112956, 61.43307555106379, 40.860675457985174, 34.481234550476074, 32.98799607061571, 54.2060104493172, 65.08224479613766, 73.10427235018823, 11.677210773191145, 0.4770870464703729, 0.19150609240656902, 0.4667607634778946, 13.594393730163576, 57.411869495145744, 67.48595560750654, 72.20225272640106, 67.57451488125709, 69.1032115874752, 72.3787436946746, 68.37787905047017, 69.28168727505592, 67.54133947433965, 57.53465929339009, 49.81863544833276, 50.78863366957634, 49.10680763183102, 47.91912571076424, 45.941388222479056, 47.01781995834843, 47.40498535094723, 49.21694778626966, 49.05880566566221, 52.09530853456067, 50.65176648478354, 50.33394467446112, 50.813070035749874, 55.257040915950654, 56.59285114657495, 56.51528235404723, 57.45703951005013, 64.7939976569145, 60.10283900845436, 56.40440871638637, 56.81598694093766, 54.1139720332238, 50.112479809791814, 47.54325674426171, 45.79732741079023, 45.0827774693889, 43.546871446794086, 45.11882405127249, 43.04332933118267, 43.249838198384936, 44.48400412836383, 44.03332771793489, 51.992722865073915, 59.69736791426136, 59.58393689124816, 55.76647443156089, 47.60355534092073, 52.12343977343652, 58.84628026716171, 55.0656488633925, 57.98743809423139, 59.27068071980631, 56.93084178432342, 50.6669186007592, 49.25972123299876, 49.5367072474572, 47.005138935581336, 44.99458689843455, 45.334683848965554, 44.15561153042702, 43.67492506580968, 44.40481539695494, 42.325202188184186, 40.98742685010357, 41.62384710004253, 41.30440142846877, 39.58682690897296, 40.73513607825003, 40.68790681900517, 41.8659750107796, 40.28818199711461, 43.07130367525163, 40.97892315156999, 44.55838011157128, 44.35729195994716, 46.81137384906892, 45.828537710251354, 44.359923870332786, 43.38498346267208, 37.98736280010593, 37.89172757056452, 42.5143624121143, 43.28355881475633, 48.04197826693135, 48.39350892651466, 51.78107569294592, 51.69168487671883, 55.595062932660504, 58.48992901463663, 59.80478986617058, 50.797988522437315, 44.38807079868932, 50.65847766014838, 55.94578558398832, 54.885517935599054, 44.53757586017732, 41.81732585353237, 39.58249268993255, 39.864648388278106, 39.90198935231855, 41.419479846954346, 41.05885713331161, 42.52867121850291, 44.09287321952082, 43.31264318958406, 44.53363387815414, 42.65312410170033, 42.2007885286885, 43.958637945113644, 44.558674289334206, 45.47444182057535, 44.28338666116038, 44.306924804564446, 44.918567442124896, 45.67467489550191, 46.01163002752489, 46.03444645481725, 49.25548507321266, 48.24192500883534, 49.42063254694785, 50.835874695931714, 47.91544652754261, 49.15355051717451, 50.772991257329146, 53.59903150989164, 56.694589584104484, 58.571180912756155, 59.240270583860344, 58.990411681513635, 62.57570512833134, 65.42735061337872, 63.89104843139649, 68.60125803178357, 68.17819118499756, 77.45058013546851, 70.43374230784755, 30.3251068053707, 0.7247228535913652, 0.3136821776147812, 0.5082513193690008, 16.392903847079126, 74.16357901788528, 66.17085549139208, 58.774579340411776, 50.03222419369606, 33.6765524648851, 32.18477506791392, 46.89028801456575, 65.20723896641886, 23.14810879768864, 0.47435459470556635, 0.2370621696595223, 0.048553350291425185, 0.11728092126788632, 0.054442091965146606, 0.0843154913896034, 0.030308788259243293, 0.03457194306857644, 0.023477545849257903, 0.0981812384880839, 0.01264939099670418, 0.023493151060275497, 0.10135832768414291, 37.98562126774942, 70.32833253183674, 47.395238261069025, 41.06137529496224, 39.825146198272705, 61.89832356668288, 71.36549349754088, 80.22568056660315, 13.177636996392282, 0.4852346366932316, 0.25765565494375847, 0.4726927354931832, 16.798905441837928, 64.6380599083439, 70.94363474076795, 75.09342393567486, 71.69311338855375, 72.66917951645391, 74.01907890073716, 71.48905600270918, 74.28846728417182, 67.68421573023643, 59.36635517304944, 52.147240715642134, 51.89152179225799, 52.62086299157912, 49.67777921307472, 49.73773656352874, 49.513663322694846, 48.51766763194915, 53.406996188625214, 52.38415187405002, 54.58947312447333, 53.71367454528809, 54.438242220109515, 53.54363979831819, 57.37421081912134, 59.386174909530155, 58.89350168166622, 61.61182972692675, 66.48097376669607, 60.49007892608643, 58.8560155899294, 60.38355519694667, 56.71217356958697, 53.307901428591826, 50.3897992257149, 48.554404550983065, 46.85068776530605, 45.45046044934181, 47.16546189400458, 44.861983330019065, 46.93109243146835, 47.29182889384609, 45.79417774754186, 54.62861837879304, 62.49714005377985, 62.89540967633648, 55.610097377531, 47.03251315701393, 53.27900924990254, 60.23275183093164, 58.14700011284121, 60.39944079614455, 61.56406702533845, 57.45598831484395, 53.78784264287641, 50.83365855678436, 52.00024989343459, 48.428508235562234, 46.72453257345384, 45.48529894121232, 45.34741586254489, 45.17388236138129, 46.05521148250949, 45.786176112390336, 43.26586500290902, 43.57037821123677, 43.816510861919774, 42.91017270857289, 44.988566060220045, 42.814710063319055, 45.175098296134706, 42.251234131474654, 44.638078751102576, 42.394624217864006, 48.12661517050959, 45.262598529938735, 48.743541240692146, 49.234888707437825, 44.247485206973174, 43.60299271921958, 37.50936315905663, 38.21256176117928, 40.78655442883892, 44.88479975731143, 48.65819438811272, 49.17162087655837, 53.04613813277214, 52.40081802491219, 56.85610494306011, 59.51571118447089, 60.949400240375155, 52.013381988771506, 44.847152848397535, 55.22047658120432, 57.90172253885577, 54.28843905848842, 47.731565813864435, 43.43611155786822, 43.442348126442205, 42.59805794685118, 40.167086662784705, 42.16926443961359, 43.19379537336288, 44.92777324491932, 45.33507608598279, 47.55227819565804, 48.67733947692379, 45.36834562978437, 45.77265570240636, 46.830228682487245, 46.12542190859395, 47.08375107857489, 46.74113204402309, 47.15349866497902, 47.907460581871774, 47.18974136537122, 48.944288146111276, 48.70055598597373, 50.767272441617905, 51.01796288644114, 52.24685715090845, 51.938221531529585, 50.09647261711859, 52.04277623084284, 53.05907410960044, 57.484072485277736, 58.6602226380379, 62.21176408952283, 61.35548322431503, 62.420877410519516, 64.36618866459017, 68.34374658523068, 66.02773604854461, 72.90736152279761, 71.06130584593743, 79.85012931208458, 73.98022390181019, 32.88420034993079, 0.895172881503259, 0.13194612708062897, 0.4737518673702594, 17.23562409800868, 82.18164890043198, 73.06905731078118, 70.23013207220262, 54.31102798831079, 30.48861865074404, 37.0201769182759, 55.780077211318485, 76.09196524466239, 28.816384769255116, 0.5466040404092881, 0.19765091429073967, 0.0723886821839598, 0.11426182238445168, 0.03182640077636367, 0.26767587048872826, 0.058924277057690974, 0.10276999790221454, 0.14096975416666077, 0.24535565366668088, 0.09762447642823381, 0.25250184439843704, 0.2698266470143872, 50.32792383624662, 81.72365726963167, 55.84624367375528, 46.21656994665823, 48.11036871325586, 70.79508673760199, 77.43795010351366, 90.11487791615149, 14.8983415672856, 0.6732044825630804, 0.5257649779800446, 0.5225985220843746, 21.44817709922791, 69.79361149572557, 75.25824977505592, 80.74989749539284, 75.55569879470333, 74.41303391610423, 77.73693669226863, 73.86251357293898, 77.89041903711136, 71.87271087400376, 63.681546795752745, 55.042189167391875, 56.266003962486025, 56.20858438553349, 53.85331092342254, 54.114772196738954, 52.81512621910342, 51.95495436268469, 55.45019411271619, 54.368216145423155, 58.16530581443541, 56.035913805807795, 55.60485316861061, 55.84556510371547, 60.937880239179066, 61.29884027665662, 62.84264595277848, 63.929821060549834, 69.23810189770114, 62.46303504513156, 60.58374904817151, 63.09613304753458, 56.98295439443281, 55.19134513793453, 52.95034993079401, 51.05619815088088, 50.3717916242538, 50.10268172910137, 49.94905817893244, 47.54140146317021, 49.97904862126997, 51.66998632492558, 49.85981249040174, 58.72536536185973, 66.58858791474374, 65.65113752119004, 58.3005020695348, 48.32079602826027, 53.32770547559185, 64.4566620549848, 61.545929985661665, 63.99761138423797, 65.5408130153533, 61.34721486799179, 55.136412343671246, 50.98870592732584, 52.72572363576582, 51.39646768569947, 50.079422073979536, 50.72402438809795, 47.44756660153789, 47.69217737259404, 48.41055946965372, 48.055753630976525, 45.48646780752367, 46.641339102099025, 48.47132090599307, 45.51965105918146, 47.954595704232496, 46.326368854891875, 45.819551560186575, 46.10323698289933, 47.19393437908542, 45.802293131428385, 51.267280501704064, 48.72298409861904, 52.85188274998819, 50.658481582518554, 46.53518407575546, 45.337621704224624, 38.2268548780872, 38.81869739101779, 42.52716502835674, 45.16162887696297, 50.984022617340095, 50.7716654962109, 54.085087699274865, 54.85484892322172, 57.9413894684084, 60.75393676757813, 62.91661793185819, 53.093398770978375, 48.22762404718707, 58.91286250083678, 59.866484826610936, 58.99192179402998, 49.415560922315045, 45.89888541929184, 45.741821950481786, 45.29563273152998, 42.1825534297574, 46.556408020757864, 47.30805181687879, 48.26625547101421, 47.99838504483623, 49.26099992567494, 50.1134878589261, 47.912555740725615, 49.23988972940753, 50.29556035995484, 49.618280779930856, 49.54282222255584, 50.617331997040786, 49.654084174863755, 51.07198176845428, 48.92887715370425, 49.97815432087068, 51.571797632401996, 55.53618423400387, 53.44709850126698, 53.67362322345857, 56.38082742691041, 51.72937100933444, 55.13857749200637, 55.532430525748964, 60.49351492235738, 60.880044890988266, 65.57988374463974, 63.17544729478898, 64.41841502343455, 68.7464092623803, 72.3407437724452, 69.65414770187871, 76.7584857633037, 74.38513017469838, 85.1239364377914, 75.42822176410307, 41.97242421488608, 1.2321304650075975, 0.4910392848955047, 0.543347186138553, 21.918675207322647, 91.58839471878545, 81.8138639388546, 76.14121452454599, 69.06248169560587, 49.68575731400521, 48.34739362039874, 67.06593251997425, 87.75064576056697, 37.86715392143496, 0.5780974859672209, 0.4533222023277514, 0.19817862629650101, 0.30049121608176543, 0.26748560489185397], [0.032468495454879544, 0.03777781418795067, 0.08350989631106777, 0.009349976711335682, 0.13063098394101666, 0.049895375456300475, 0.08220753151803248, 0.09739147078606392, 36.06455026134368, 59.15914420158633, 44.36379132732269, 38.98411550829488, 26.81986697258488, 55.02349122878044, 61.34944277424967, 70.66388345533802, 13.358653399252123, 0.5864835133956325, 0.23258692915401152, 0.36858834266181917, 6.298388069675815, 47.031881655416186, 65.43636422003469, 67.38395829354563, 69.78659829785748, 68.09893577329575, 67.97952313576975, 61.07572801651494, 64.23338113292571, 55.33264460102205, 50.755379815255445, 50.11513917676864, 47.69090652465821, 48.18650191830051, 48.6637366971662, 46.53601169586182, 48.40250292131978, 49.015192831716234, 50.95746424890334, 53.74796782770465, 56.41690538775537, 61.09579878468668, 62.97500241187311, 60.16450651230351, 58.40989697364069, 58.25741483319191, 60.514946752978915, 58.39940071105958, 54.93694020855812, 48.20720026569982, 51.18071771437123, 55.47726238927534, 55.06343664661531, 51.032805135173184, 49.97927219636979, 45.90534556296564, 45.1297321627217, 44.15302276611329, 46.23324786463092, 41.58986760723976, 42.43816644914689, 43.79189798908849, 44.581690757505356, 45.28641516162504, 53.965137697035274, 55.850585737536036, 57.4291043896829, 53.46854209899903, 51.96843554896694, 52.33747566899946, 53.41943402444163, 53.52776596623083, 54.57423079398371, 53.43473911285401, 51.388866132305516, 51.05311909029561, 49.983629949631236, 45.00524005582256, 43.24189932115617, 42.52359174912976, 40.98855257034302, 38.081515373722205, 40.24806791736234, 44.13095158915366, 40.978499535591375, 41.732951748755674, 41.65002107620239, 41.241074762036725, 41.88568099852532, 40.79798421552105, 41.35870664350448, 40.47795018842144, 45.01316324357064, 43.85131797482891, 45.65796167619767, 45.33951620901785, 47.44245967557354, 44.04565964975665, 40.99662480815765, 41.135833647943315, 41.30276972247709, 44.39688828683669, 45.26640322900588, 45.858061390538374, 47.59868767953689, 48.28576141788114, 49.513400523893296, 52.38366550014865, 59.21620684285318, 57.08399465007167, 53.17113230305334, 42.83544763442009, 47.00909268471503, 54.51661902089273, 56.29944216820502, 53.07256706299321, 42.90207301416705, 40.98095493931925, 40.93914247328236, 39.59320860524332, 41.87455323434646, 40.53809581264373, 40.65259764271398, 41.696155994169175, 43.61468138233308, 44.025400607816636, 44.83787252056984, 42.5859692019801, 43.673422798033684, 43.20301294326783, 45.14248771052207, 42.997378764613984, 47.06970507098783, 47.04617477232411, 44.86562721190914, 43.562117699653875, 43.86728986617058, 44.24779899658696, 47.00647254143992, 45.74754861093337, 47.446283986491544, 46.665159656155495, 48.63595847160586, 49.47518487130442, 50.53027106869606, 52.32146847632624, 57.178394333008804, 60.95953956727059, 60.60837368811331, 60.504195536336596, 59.734697111191295, 64.99381888297297, 66.45987141516902, 66.15631134279313, 72.57779613617929, 73.20309254430956, 76.21459422572967, 29.33855422081486, 0.5389560927306453, 0.2625124072355609, 0.5753592425777067, 8.477763822001796, 72.81821389352122, 64.41434360319569, 58.84854739712131, 40.393172079517, 29.256486469699492, 35.48630268343034, 43.74488446020311, 61.80081344419911, 32.12644353989632, 0.09332198108876906, 0.13574057589134864, 0.03187381778843701, 0.03823803767802254, 0.03465439711186675, 0.04783796589641322, 0.06728781597508539, 0.07685122095168599, 0.017682935314012632, 0.0651185077825381, 0.04287446691324154, 0.05261609841498637, 0.2362058978647955, 46.084817532570135, 65.88822518625568, 50.85751048980221, 40.223604094597604, 32.98747439538279, 64.35551981772146, 67.6917153020059, 80.0430550113801, 15.098185346972558, 0.5880109701425799, 0.9116166830062867, 0.39818461744054673, 7.2186761325405495, 54.89215850830079, 68.99009043170561, 70.61719940554711, 71.07160599000993, 69.38802273042741, 69.6063026305168, 66.04572403815486, 65.3924689754363, 58.76958616318242, 52.87005116862636, 52.44331690572923, 49.339361036977465, 49.44950511378627, 50.839275390871116, 47.59397299058976, 50.94761125503048, 52.80412397077007, 53.84334418081469, 56.234750516953014, 59.17497096523162, 62.8770019931178, 62.8977591760697, 62.28372781507431, 59.650107276055124, 60.39913092890094, 63.5580901945791, 61.65466593157861, 59.47881344825991, 52.882849862498624, 55.67707184822329, 58.54603459758144, 56.464750459117276, 53.81177302329771, 51.95712735576015, 49.071729875379994, 46.69575806586973, 48.20888688487392, 46.05698047145721, 44.72732051726311, 44.971339010423236, 45.23637356296663, 46.85374329167028, 48.75532404068978, 54.060733702874955, 58.43118759893603, 59.45150590712025, 54.2800961771319, 52.83395359593054, 54.88410195996685, 54.95172754410775, 56.00361308743877, 57.04161736272997, 56.38950370973157, 53.85000828773745, 55.98222832525931, 52.11132749434441, 45.89664574592344, 46.36132109549738, 44.731395859872144, 44.46591023475894, 42.24744904425837, 41.629742422411525, 44.13141835120417, 44.96235678272863, 44.27757370856501, 45.02385562466037, 44.63657648332658, 42.8947695609062, 42.79803606771654, 44.109213813658684, 44.45311154088667, 48.051509626450084, 46.461753383759536, 47.05527859349405, 47.73879866446219, 49.42031091259372, 45.15383904980075, 43.99698695828838, 44.100137449079945, 42.86394365372197, 45.413264612997736, 45.466750052667436, 45.92158025310886, 48.757112641488355, 49.37948296147008, 49.497852248530236, 56.61531848292197, 60.881080396713756, 55.59963641628143, 52.5730336096979, 45.0224631832492, 49.93136044471495, 55.992944240570075, 57.944292022335915, 55.64567719736407, 43.81990371211883, 41.19661469613352, 42.83370217969341, 42.92964335410826, 44.431342386430316, 42.983415126800544, 43.131041372976, 45.92961326722176, 46.214106698190015, 46.156863627895234, 48.4090885808391, 44.99754436554448, 46.271781229203754, 45.785250433029674, 46.87270010671308, 44.626174357629594, 48.19316602522328, 48.39521515753962, 46.02042790382139, 46.325658905890684, 45.838214197466456, 45.904843499583585, 48.915411656902684, 47.591705860630164, 49.07139647391535, 49.1655098238299, 50.83240339832922, 51.545376546921275, 53.85361686829598, 54.62459794936642, 60.13532800059165, 63.561651706695564, 63.46850718221357, 62.927667248633604, 63.15689056150375, 68.30181644808862, 69.1808666721467, 71.52469465809484, 75.86412260609289, 75.16684286056027, 78.60778916266658, 33.49167154681298, 0.5578364828421224, 0.09870018644799149, 0.5248571944332893, 10.101568198973133, 81.5855819948258, 72.76090806530368, 68.18204295250678, 48.18129301071168, 30.77729921187124, 43.272129028074204, 51.833070631950136, 73.29288344229423, 40.289707799111646, 0.1677130715500924, 0.06235765330793877, 0.052532395648379485, 0.045216202345346256, 0.05075141359421034, 0.17993712287035682, 0.1951997087246949, 0.2526293367507958, 0.09423421560636452, 0.2556945311446344, 0.16813256597566992, 0.2285984455938301, 0.4079773661590392, 58.15729241217337, 77.95766415134554, 60.50376015324747, 56.36227069362518, 43.425058318722634, 72.72344943015807, 75.30521623549923, 87.36240956091112, 17.658818421825288, 0.8001663956430651, 0.9589136644236503, 0.6374250508604512, 10.36537406906005, 61.19716851942001, 74.4830717579011, 75.530470109755, 73.0466527323569, 72.55536017879363, 73.83484517374347, 66.45949486763247, 68.59638644802955, 62.04948779075377, 57.47212494573286, 54.26690916861258, 52.9679064596853, 52.74545315773257, 52.400041395618075, 50.78222059434461, 53.647872863277314, 55.950406136051306, 57.41416408169655, 59.664776940499586, 61.18049844618767, 64.2798416076168, 67.7576111209008, 66.28942089696085, 62.71672610313662, 65.77142484726446, 63.79868445857879, 63.92460430822065, 62.28032712013491, 56.45650563701507, 57.92605692340482, 60.3734354819021, 60.056107890221384, 58.39954191638578, 54.500890316501746, 50.54841987548336, 49.17576289946034, 50.618010567080596, 50.7126691264491, 46.53350922369188, 48.190996954517985, 48.210640184340946, 49.78315368775399, 51.29513717466786, 58.49891908707158, 60.008023554278964, 59.75433641864408, 55.96935118398359, 54.68552804762318, 55.77880244101248, 55.459152806189756, 58.843095302581794, 59.467454264240885, 59.711610040357044, 55.38974254362045, 58.10635651311567, 54.004949754284276, 48.529336683211795, 48.644470014879786, 47.899470713830766, 46.80358794427688, 44.88963996210406, 48.738763793822265, 48.1053755360265, 48.20206196077409, 47.588528740790586, 47.546186754780436, 46.07889083123977, 46.426848211596095, 44.45610038695797, 47.06002073903238, 45.474720308857584, 50.98633681574176, 48.501264279888524, 50.480076497600926, 51.9312632468439, 53.24968168812414, 48.439804661658506, 43.68573904037476, 43.642294868346184, 43.7272887076101, 45.97517944151356, 47.58092718739664, 46.90312593213974, 51.946317303565245, 52.07315106545725, 52.6390863233997, 57.055969315190474, 63.132085492534024, 60.04007324095696, 57.72212113103559, 50.21549693999752, 50.52437574632707, 56.68945127917875, 60.36104079215758, 58.8385178965907, 47.53398426117436, 43.87250269612959, 44.795644283294685, 44.94744785370366, 48.20119903933618, 46.38576530641126, 45.792899054865686, 48.36446377538866, 47.33916013471542, 47.82209411744149, 51.99627653245003, 47.839870299062426, 49.01608713211552, 48.78227464614376, 49.9360437547007, 49.73258649149249, 52.77078382430538, 52.64964926627375, 48.29683034650741, 48.61005513898788, 49.00342964356946, 50.02443436653384, 51.151770622499534, 49.742345348481216, 52.86071984998642, 51.10392555113762, 53.756208727436686, 53.545267581939704, 57.13841361384238, 58.842954097255586, 63.20653600077476, 68.87649074677499, 66.45390941250709, 67.23517494816934, 66.01924803949171, 73.9358462056806, 73.82637285417127, 76.05471841750607, 78.81243490403699, 81.14802591262325, 79.93579387664795, 36.05056701167938, 0.9813737689006714, 0.6089056199116092, 0.8456119570520617, 12.501154638105824, 89.33881344333773, 80.77689909165906, 75.36066286025509, 61.123702526092536, 42.684848231654016, 46.65537334257557, 63.07517974607406, 84.99511011185186, 49.82841391717234, 0.29836994926294974, 0.31683548744167056, 0.19180682788212455, 0.17413016108255233, 0.18466635216628352], [0.10043637151078832, 0.10696105809221346, 0.05543250575541489, 0.0638192226629584, 0.04947046478909831, 0.055935687625840794, 0.05986736576643683, 0.19375803850350842, 34.37687204730126, 55.86089764871905, 51.51122839220109, 45.07214784622193, 29.42728411766791, 55.673839815201305, 57.56889374025407, 72.81374239152478, 15.877579912062615, 0.634698574581454, 0.7186692881007349, 0.1388854587510709, 2.956491665494058, 35.05519497779108, 65.7035796103939, 64.52036134658321, 70.12564013081213, 63.835150734070815, 64.02093379728257, 58.747095292614354, 56.146677617103826, 52.65993372086556, 53.203915472953554, 51.22823330663866, 51.78432341544859, 46.67413796147993, 47.39882330740652, 46.75473482378068, 49.40518625320927, 49.927030148044715, 54.13159132003785, 58.014533827381754, 62.74750886424896, 56.94657441108458, 60.32491184050038, 63.29751537692163, 66.62849410887688, 66.68961248090191, 61.19333636376166, 57.24846747613723, 55.39082511778801, 61.23541555097027, 57.940777578661525, 55.157236206916075, 55.881239060432684, 51.83513379866078, 48.857486094197924, 46.3128484449079, 44.75026246040098, 44.189649858782374, 44.67178760036346, 41.92469681462934, 41.13595131904849, 43.68344053145378, 45.91025637042138, 44.84541131604103, 46.70201816866475, 46.77994389687815, 50.81121083228819, 50.22636582774501, 50.36236616872972, 48.51268622183031, 50.90912495889972, 54.426977172974624, 56.40300450786468, 55.13239191424463, 51.81569453208677, 49.98872510848507, 47.79775188815209, 44.21527470311811, 43.444113193019746, 43.619580422678304, 42.19117479939615, 43.19177535272414, 45.915896738729174, 49.17037356284357, 46.10568061951668, 46.18346122003371, 45.98214949330976, 40.618120008899325, 44.449604941952614, 45.94130585270543, 43.93581759545111, 43.51837542749221, 44.86031632269583, 42.449890413591945, 38.63015690157491, 41.214739968699796, 45.601334418019945, 41.76711559295654, 42.639207532328946, 39.9887208015688, 43.07509268483808, 43.772505790956565, 46.35988158564414, 46.54319355564733, 47.923079459897934, 49.0644617234507, 55.376841868123705, 54.300876894304835, 45.162087794273134, 42.794615760926284, 45.29841369198215, 46.71696239902128, 54.7613396183137, 52.85370272974814, 51.99694333537933, 44.918485072351274, 41.87248222289547, 41.68748363371819, 40.998358495773815, 40.75390854189473, 42.23781962548533, 40.07977862511912, 42.51136572130265, 43.625067818549375, 44.5598235437947, 44.07293973430511, 44.12934341738301, 43.50028545625749, 43.08307863050892, 43.84031180412539, 42.106204494353264, 44.097689890092425, 45.64012665902415, 42.17621880192911, 45.9712766831921, 45.035756095763176, 46.09601982178227, 45.418704940426736, 47.229102350050404, 45.5086370437376, 46.14018963229272, 45.15857727296891, 47.30726734284432, 48.52308050278695, 50.59932047320951, 49.50935656024564, 55.095372584558305, 57.98461006533716, 58.948477622001406, 59.957440668536776, 63.6337919389048, 60.974307290969364, 63.71182357111285, 65.35255493656283, 70.13454391110328, 72.16501374398509, 82.22893699522942, 33.65203372893795, 0.3837954637504393, 0.40218972510868506, 0.42449535561665414, 7.884132708272627, 73.44710319272934, 66.64641149582403, 57.37169265747071, 49.655029466075284, 31.69322952147453, 41.96055512274466, 54.81686861284318, 59.59070690216557, 25.929559546132243, 0.47895562684824394, 0.21413438382648656, 0.03153227663959467, 0.07187165710474215, 0.04104390747905259, 0.060970681764545946, 0.0904799021419979, 0.06556513704239361, 0.06098488503466211, 0.03394036869248075, 0.017995328732555913, 0.0578178200990923, 0.11392631417801304, 46.34844787659184, 65.79556311330488, 62.83398928180818, 47.15579717389999, 29.903787374496464, 65.27181294656569, 62.68212295347645, 80.61559554069274, 17.74534590782658, 0.5320318836358287, 1.0668713262965603, 0.45924948588494335, 2.737049763241122, 40.64280348439371, 69.68726819561374, 68.34289935327345, 72.26012337592341, 66.46543333607336, 67.84940242767334, 62.327246512136156, 56.92297743212793, 55.19839755950436, 54.676494829116336, 53.385972284501605, 52.36141781653128, 50.41269802278089, 51.06634532251666, 48.868052959442146, 51.20660535750851, 53.01668505514822, 57.132184890008745, 62.463564565104825, 63.55285383039906, 59.632236957550056, 62.870777191654334, 64.58835171115014, 68.819333968624, 67.78935878507554, 61.10603224846625, 60.49083202115951, 59.082846256994436, 62.568625250170314, 61.461065584613436, 57.95715739650112, 59.53973570177632, 53.82434814207016, 52.659192392902995, 48.92688066728654, 46.82271342123709, 44.93319788286763, 45.9165439298076, 44.1545368009998, 45.5218279746271, 45.51992562509353, 47.84152161690497, 46.59069738080425, 49.12568599947038, 47.86120407042965, 53.376762559337, 50.68513016546927, 52.099030863854196, 49.59834729471515, 54.70508106293217, 56.57913069571219, 58.422260284423835, 57.046555626776914, 53.42600791685043, 52.201169383141306, 49.44605342803463, 46.958043036922334, 47.41062179688485, 47.32035629210934, 45.61729846462127, 46.96604074970369, 50.23495189605221, 49.11773143276092, 47.96156183365853, 47.96771211008872, 48.90425643613262, 44.26868954012471, 46.74273629342356, 45.06368337139007, 44.46254091878092, 46.41947807804231, 46.859611157448064, 41.506940857056655, 41.965556144714355, 45.11966343848936, 47.620637263021166, 45.2380641045109, 42.88630508607434, 42.47786083529073, 43.93221685963292, 42.510522411715606, 46.48530329427412, 45.91897187694427, 48.43745908429546, 51.34872459596204, 58.48024860505135, 56.784678582222234, 47.444891545080374, 44.968899296176055, 46.527292266968765, 49.4177496048712, 54.63824779756608, 56.7934960703696, 54.759629464918575, 47.31473161328224, 43.565789038135165, 43.44592532803936, 42.992703299368586, 42.00392476973995, 43.06953860867409, 42.774721499412294, 44.39222066633163, 45.11691777936874, 45.97206115722657, 45.499074305257494, 45.327333327262636, 45.654321716677764, 46.59232516442576, 46.70258691233974, 44.74563406359765, 46.1475597658465, 48.44490766525269, 44.50707550971739, 46.92009802787535, 47.0790599238488, 48.49720462676018, 47.124198559791814, 49.528536950388265, 47.96045572526994, 49.876400193860455, 49.50774054373465, 49.601595017217825, 51.238415779605994, 51.99150300795033, 52.9180335229443, 58.09663687982867, 60.359287492690555, 62.29320426141063, 62.898210248639515, 66.76056031257876, 63.52707993599677, 67.28702868184736, 68.61591985148769, 74.04782202935989, 74.65834679142122, 85.61447589628159, 34.8032493745127, 0.2740032970905304, 0.32645577444664897, 0.5000333716311763, 7.411914640857328, 78.92655234183036, 73.38903642469838, 64.86490234251946, 59.06901205739668, 34.57349654166929, 45.53792538181428, 62.2454180256013, 69.8207699867987, 36.823579880499075, 0.5152338430766137, 0.19678287538549594, 0.12951853234441052, 0.10425312114098381, 0.04165197827763135, 0.13612426336734526, 0.17695696423611335, 0.13761787434979794, 0.19682579163101413, 0.2074283412507465, 0.15636012348676884, 0.23254730708656773, 0.8360178396105767, 59.56363470323625, 75.106242241398, 67.73553602157101, 58.11320104906636, 44.630665471476895, 73.422329502721, 69.83343924245527, 88.3639475607103, 20.96388989879239, 0.7714802026748658, 2.0930279599082087, 0.464689537522293, 3.6038805784717685, 49.131624467911266, 76.17859471228816, 70.98156406033424, 77.58329745261901, 69.6841302994759, 71.64668037045386, 65.5532390840592, 59.99373043737104, 59.022465290561804, 58.2682680314587, 56.68684682538433, 55.92624825816001, 53.288187596105764, 53.68127184529459, 52.245688284597094, 55.420097766384, 56.070391439622455, 59.77699987349972, 64.68949002604332, 66.14789393640334, 62.524388759366936, 66.70917726332142, 67.55137289724043, 69.24061221461143, 69.97131055401218, 67.15369947495, 62.60821765468967, 59.79468191823652, 65.27268371274396, 63.48351417049285, 62.61014746081445, 60.05193448835804, 56.59330614151494, 54.769937453731416, 51.30870857546407, 49.46928562656526, 48.35056681786814, 50.27838430097027, 47.539644241333015, 47.88489518627044, 47.951975560957386, 51.99185602126583, 48.76596543096727, 53.45056979886947, 52.08726767570742, 54.73355747038319, 50.98425795955043, 55.18316699612526, 50.28045139005108, 55.229654927407545, 58.48397093434488, 60.21197111375871, 59.00132371533302, 55.417116765053045, 53.74313154528218, 53.05026054382325, 49.097484157931426, 48.563735869623, 49.739729127576275, 45.41653586972145, 47.36253746094243, 51.37275303563764, 52.13640320685602, 48.17346003747756, 47.99090116254745, 50.24270249951271, 44.50023881850704, 48.02488065535023, 50.49434215791764, 48.1721656553207, 47.1130080376902, 48.574643981072214, 42.45888440839706, 45.07270874515657, 46.81192690326322, 48.71126405654415, 46.19081174173663, 43.325214385986335, 43.21107341397194, 45.3792655083441, 47.02795928524387, 49.87597657788185, 47.38356920980638, 50.19472798993511, 52.64240464856548, 60.441782782154704, 60.412486599337676, 50.60097571342222, 47.529857927753085, 50.07176952977335, 49.53349874865625, 57.96598272938883, 59.46275526477445, 55.806145283483694, 50.12690236491542, 46.98064765622539, 46.061424516862445, 45.26414002141645, 44.02957400967998, 47.64534035036641, 45.06221640494562, 46.94462068619267, 48.85410108873921, 48.52458669293312, 48.978306862615774, 47.30608278705228, 49.29501471980926, 49.77596006085796, 49.57443652614471, 46.60129562500985, 48.30886810056625, 51.476723301795225, 47.57641646169847, 51.42565404215167, 49.055142171921275, 51.24091825177593, 51.465473944141024, 52.90909836369177, 51.29585104603922, 50.64931500342585, 51.6941402804467, 52.828705464639974, 55.35094638024607, 54.699836854011785, 55.835543447925204, 60.88802299191875, 63.35254623043922, 65.03345443356422, 66.42661756084811, 69.48825497781077, 68.49655428240376, 71.51925825303601, 72.86707878112793, 75.91836114083567, 80.84156328631987, 84.92642156539425, 40.574248298521965, 0.6695274443876359, 0.8335417821522683, 0.5322537426987003, 10.077428952340158, 89.35856649952551, 78.64269041245984, 75.38946090206024, 69.68577769494826, 49.80432271957398, 60.08713383828441, 71.71584744607249, 82.47090016641926, 46.59632990437169, 0.5271337013090811, 0.2938736566612798, 0.2290954527955863, 0.2757703554966758, 0.11955729790873106], [0.03254336139727985, 0.06519282597207254, 0.00927845857316448, 0.01880883941456916, 0.07365182327527194, 0.0951316876096591, 0.02238896555237232, 0.1628854459211711, 42.39254928404286, 53.64233839896418, 40.68273713511806, 42.68525615815194, 34.4895342857607, 57.06726181891657, 57.20438788014074, 74.7187905157766, 18.10394075609023, 0.4808684258211044, 0.4938017979504601, 0.3330989518473226, 0.7903862720535648, 18.425331923269457, 66.94240923850768, 64.80828292908208, 71.87295406095444, 62.37749991878387, 65.34087411818966, 56.8018703306875, 59.058727602804865, 55.89981932793894, 54.84965962748374, 49.76306723010156, 48.61244386242282, 48.281348751437285, 49.034534039035925, 46.96131037127587, 48.71073061420072, 50.27674082786807, 53.57434018965691, 55.6579424488929, 58.13746090858214, 56.49788664233301, 53.723496160199566, 49.558680365162516, 47.75773586765413, 57.418070762388176, 60.75497227330362, 53.927647682928274, 59.689860497751546, 57.451787456389404, 57.91126174311484, 54.971947362346036, 52.663577602755645, 49.847923786409446, 48.78869948848602, 46.659593812880985, 44.06795047944592, 44.25724798633207, 44.59831376229563, 43.495115772370376, 43.55469265291768, 42.228641279282115, 43.37144736320742, 44.97082910230083, 42.378668016003026, 43.58954683426888, 44.3337812731343, 46.34891071627217, 50.3320776262591, 48.74519255853469, 47.533709695262296, 53.40861220513621, 53.00924431893134, 53.061215723714525, 56.43196728921706, 52.8895414260126, 51.91469515523603, 46.886338187802224, 47.74161100387574, 45.296562333260816, 46.490476900531405, 44.407062915063676, 46.40596551279868, 47.31393144976708, 45.16569637483166, 46.99788255076255, 50.01788400834607, 49.605391871544626, 44.94453353266562, 41.98072002780053, 44.41249539775234, 48.671377474261874, 51.2167799857355, 44.384030757411836, 42.16122750313052, 43.31018386348602, 42.43975500906668, 43.68143620029573, 44.16140094880135, 43.65400706568072, 45.24956449385613, 46.26351679525068, 48.28753040682886, 47.408484105140936, 48.15236945306101, 53.007981315735854, 50.74161229595062, 45.330027995571015, 46.58581402993972, 46.997368720269975, 46.922918212029245, 48.095706893551736, 51.73803944741526, 50.734359833502005, 44.794110636557306, 42.47716265340006, 41.44991743949152, 41.69157074343774, 43.15304586964269, 42.12598108476208, 41.42116254375827, 40.65886559024934, 43.53139377409413, 41.34590794963222, 43.064659180179724, 43.36098640195785, 42.783566444150864, 41.39564752578735, 43.30482590583063, 45.36196785588419, 46.217385799654075, 44.52350239599905, 47.43775675373693, 46.87448870751166, 46.98453864743633, 43.871333829818234, 45.94591856002808, 44.96779318778746, 47.69597422692084, 46.9903516000317, 47.56470426436394, 45.76520319907896, 48.956682835855794, 48.58276328732891, 49.64836143678235, 48.955310006295484, 51.645216557287405, 55.376182909934755, 60.64636576560236, 60.11277437210084, 62.09752505825412, 60.99969679309476, 65.4054049522646, 61.63844300854591, 73.88781286055043, 69.72448364380868, 86.25669340933524, 23.631425211506507, 0.39175554629295106, 0.11856299239180743, 0.29182645522298356, 2.2294210282064255, 67.59640955155896, 69.78257394606068, 57.6023554801941, 48.85135935198877, 39.28467888985911, 40.42235451359903, 40.73991352511991, 62.97521029749225, 30.409143586312574, 0.039455726772787116, 0.03662128572262103, 0.019771130117137107, 0.07433862109938938, 0.04870813835652606, 0.04860921725330334, 0.0430428377172399, 0.01178644944898664, 0.026700533288080367, 0.07621462486924664, 0.05655638738385132, 0.04953016985147711, 0.7932034531427968, 50.92550085436914, 64.25688005262806, 49.407625967456454, 36.653498065087106, 36.47697964022237, 66.22361921495008, 62.07048423828618, 83.46121234278526, 20.440573153957246, 0.49556658873634957, 0.613423332331642, 0.2287564282455752, 1.178811358348016, 23.555109616248842, 72.60218543391075, 67.69031893822455, 75.9112459613431, 66.25630824796616, 68.90752453957835, 58.96271582572692, 62.443631079889116, 57.69133444755309, 55.11764772476689, 53.31354571926979, 50.91628328446419, 50.505677807715635, 49.608063005631976, 48.60226138945549, 51.470161176496944, 51.97313454843337, 55.56986954904372, 57.03493364395634, 61.06087792304255, 60.05162462111443, 55.67425950880974, 54.53163777628253, 52.848686018297755, 63.41678288675124, 65.00335808723204, 55.11867930812221, 60.84980341695971, 61.18468361516153, 59.21164512634278, 57.56372405636696, 56.40505198509463, 52.17222621363979, 49.17176600425474, 48.23870082055369, 46.416599058335834, 46.483040086684696, 46.33198176660846, 45.497430832155295, 44.91795163000784, 44.026789126857636, 46.70976877212525, 46.50113005791941, 43.58098822255289, 43.5454946948636, 47.38178453137798, 50.26515022400887, 51.66296920468731, 50.12951858582036, 52.5742377773408, 56.37585386153191, 53.93872053392472, 55.803540829689275, 57.34960186866022, 52.64442466920423, 54.50186698667465, 49.01577334250174, 48.43176772517543, 45.617220017217825, 47.809401327563876, 47.559342384338386, 50.74255366479197, 47.54421380258376, 46.655334118873846, 47.215295607043856, 50.02209663391114, 49.216932096788966, 45.75163179828275, 42.719667111673665, 46.053564087037124, 48.80415362696494, 51.361691951751716, 46.138981542279645, 48.87412871083906, 45.9408155564339, 45.12716301025883, 42.52493319972869, 46.971838012818374, 44.79607966638381, 46.216707229614265, 46.79980677943076, 50.536519404380556, 49.04832901493196, 50.781836202067716, 54.71052531273135, 52.53253906003891, 47.29738689238026, 50.43925639121763, 49.61718643865278, 49.972015811551, 48.67116958864274, 54.30926292173324, 52.52925603620468, 45.627665288986705, 43.10761305593675, 44.16362885505923, 45.204763181747936, 43.80895245459772, 44.737197045357, 45.818923980959006, 43.8097212391515, 44.49177042130501, 43.58186291110131, 44.946078946513516, 46.15722840832126, 45.05367740508049, 44.595081729273645, 45.321575287849676, 46.29711581814674, 49.63600989310972, 47.51851051084457, 49.72913088337068, 48.84314198647776, 48.33746217912244, 47.08555536885416, 46.94703294384865, 48.543021832743, 49.362754052685155, 48.66279532832485, 49.56649764891594, 48.66254037426364, 52.065137663195216, 50.336502059813476, 51.57446484411917, 50.07184013243645, 53.81980995978079, 58.182132782474646, 61.91891601008754, 61.58820529137889, 64.15760094119658, 63.77982962516047, 68.00780342471215, 64.80545882255801, 77.447677581541, 72.77989233693769, 89.37191824759208, 24.782964452620476, 0.6950724930051835, 0.35056572587740037, 0.3989377125136314, 2.930985227707894, 73.7295844477992, 77.49452637087914, 65.80754203181114, 57.9389811331226, 48.1198686938132, 49.03488312998126, 49.8255584316869, 72.12083216636412, 40.775740454273844, 0.14150022408894955, 0.09160197580293303, 0.0543026716238068, 0.04284238698141229, 0.014604600597052805, 0.09907842703884649, 0.14040485625305485, 0.1525489126722659, 0.10580958197674445, 0.1508363231175369, 0.19415877909669954, 0.1720861618917796, 1.0055894404649734, 67.37448184720932, 68.59808875668433, 55.868220713830766, 54.453202139946725, 51.49329139340309, 77.25715237279093, 70.05907750898793, 92.35117804619574, 24.22584472164031, 0.6818371290160764, 2.741863492035097, 1.2220340390359203, 0.9035775401899893, 27.097592353820804, 77.90584179662889, 72.69646352337253, 80.58345563950078, 67.39418783495503, 73.09643545458394, 62.687480911131836, 64.49905110943702, 61.29805972499233, 58.60448575788929, 55.269980815149125, 53.78812897589899, 54.17079933228032, 54.64280951407648, 50.78178913362565, 53.215553145254816, 54.754247973042155, 59.77956902596259, 61.747120118910274, 63.74771718055972, 62.44699647349697, 59.86766938240298, 56.38625598722889, 55.22747016722157, 61.69733739668324, 64.5733094215393, 56.71010648050616, 61.940363530189764, 63.90228209957, 61.42499154613864, 61.21308941994945, 59.76158888109269, 54.86022257035779, 52.742503535362985, 51.72844532997378, 48.79060183801959, 48.93614530563355, 49.85690209173387, 48.0134508686681, 48.15461304879958, 47.10064864927723, 48.51039555764968, 49.97613822260211, 47.63619730549474, 46.40807967032156, 49.14443885126422, 51.89621294698408, 53.2211660569714, 54.23506344518354, 54.63576885961718, 60.087608445075254, 56.00873178051364, 59.67403765647643, 61.3481209355016, 55.66928986580142, 55.56675126475673, 50.142999772102606, 51.49044767502816, 47.95719231328657, 51.61919555356426, 52.69969086493216, 50.701196193695075, 47.3386384594825, 45.38259167825022, 47.61700122587143, 50.85802039792461, 49.61176180070447, 47.1104428075975, 42.059132129915305, 44.780864792485396, 49.28986072540284, 54.838214151320926, 48.071690220986646, 49.15118925033077, 45.817500160586455, 47.079271731838105, 44.61844336601996, 48.52402971636865, 44.784132126838934, 47.4680531409479, 48.08136670820175, 53.110155136354514, 50.70249057585194, 51.371607703547326, 57.13226725978237, 55.607559604029504, 50.4296975751077, 52.018736024056714, 50.904221996184326, 50.666412615006976, 51.26195392301006, 56.67380886693155, 54.00196875295332, 50.027348687571866, 46.061067581176765, 47.31458256321569, 45.885839616098714, 45.999917830190356, 47.24924372088525, 48.223466334804414, 45.91948570743684, 46.608697137525006, 45.491300167575965, 46.78674136438678, 49.74633832131663, 47.9729288624179, 46.248925578209665, 46.008998117139264, 50.61042862553751, 53.48996216251005, 50.26219275689895, 54.1011929512024, 52.22849261376166, 52.04332536266696, 49.27871727174329, 51.081438602939734, 52.24935177833804, 51.721310538630334, 51.78817126058763, 52.99268014969365, 49.87989502568399, 55.72414813503143, 53.900387210230676, 54.88036001882246, 54.595564565350934, 57.5572011547704, 61.52035613213817, 66.13141998167961, 66.93211693917551, 69.2505907243298, 67.5504707521008, 71.51285694491479, 68.81661968846475, 80.31761307870188, 76.52980373751733, 93.22068906599476, 29.867452498405214, 0.8544114268114491, 1.0782181303347311, 0.6364450711877115, 4.230813595556444, 84.41759601716073, 86.07373837501773, 74.36062320586174, 67.80798219865369, 54.96863295955043, 55.445204857857, 60.54521176122851, 83.94040830673711, 54.433515764051876, 0.25943503204372625, 0.23451063721891374, 0.09649877917141685, 0.1407644732464706, 0.14032838535645317], [0.04086636660260059, 0.03743055036231395, 0.07192535220735496, 0.04237757462467398, 0.04010411677882075, 0.012539448761080783, 0.08939920488985316, 0.3155271931281013, 47.91211643526631, 49.09742140000867, 49.933588350972826, 34.7664693094069, 29.65338718506598, 57.25157007094353, 55.72208889069096, 78.93089832798128, 14.65119988687577, 0.13175653564112802, 0.3388027215917265, 0.6670832561869776, 0.38831342131860797, 6.22787562108809, 53.523749459174375, 64.52107914032476, 67.31244564056396, 63.836951101979906, 63.00352981013637, 62.847097842924065, 63.68009159641882, 61.898519685191495, 59.42385319740542, 53.774432059257265, 53.48628297928841, 47.84226686723771, 46.97450522453555, 45.371350165336366, 47.26000278226791, 48.32712281134821, 51.61564973092849, 52.783590362918, 59.28708014949676, 60.752560015647646, 62.492303771357385, 59.12854579187209, 54.310753422398726, 44.38974172838273, 47.72589406659527, 62.17963987781156, 59.43325511870846, 58.02851707704606, 56.352292183906805, 55.939478412751235, 52.460281156724506, 47.614420306298044, 46.05371705947384, 44.10264384362006, 41.991177066679924, 43.313482576800936, 44.18249153321789, 44.45277029468168, 43.13018629627843, 43.22408391583351, 41.48653276505009, 44.4742178147839, 43.55224901630033, 44.11191240433724, 48.02516698837281, 43.652504797904726, 47.7929626741717, 50.152754706721154, 53.629669143307595, 50.835800170898445, 49.499354516306234, 54.20694789578838, 53.905964820615715, 55.36833424721995, 55.75131054847471, 51.33400394070534, 47.82089387216876, 46.420913665525376, 43.90305403740176, 43.46990277690273, 40.662493782658736, 42.13475150446738, 45.07783920534196, 43.44123025094309, 49.071016004008634, 51.31579629836544, 40.45832264807917, 41.29932980383597, 46.047272605280725, 51.1119899442119, 48.368743081246656, 57.70737694155786, 44.413483835035755, 39.026175083652625, 44.63680398079657, 48.00897936667166, 45.598392640390706, 45.42072888343565, 47.47572137463478, 45.13587067204137, 48.23886163773076, 49.084881582567775, 53.02952297272221, 51.65503424982871, 47.9499202389871, 50.54755303167528, 50.70513425334808, 46.052387375985425, 45.82337587110458, 46.493897207321666, 47.18981589040449, 39.337650499036236, 40.45163892930554, 39.12720357218097, 43.930267441657286, 40.47740890133766, 41.315842982261415, 41.86164471410936, 40.62836523978941, 41.671154806690836, 44.10272621339367, 42.26168724798387, 43.933495552309104, 43.023191882717995, 44.78410074787755, 40.81145755706295, 43.487663269042976, 43.48573738528837, 45.24695219532136, 45.748631185100926, 49.70165075794343, 47.401349313797496, 47.996816096767304, 47.19067488947223, 48.489438333818995, 46.336500337046964, 49.92944240570069, 52.567181433400805, 55.99710979769307, 54.369643888165875, 55.633282507619555, 52.68053793138074, 53.79056869014617, 50.17155070458689, 49.96477903858308, 49.53881356023973, 53.997422725923606, 54.9138766719449, 57.51317647195632, 57.65304426993094, 61.286759376525886, 61.909372883458296, 74.31146021812194, 70.2272452077558, 90.607496230833, 17.434541217742428, 0.4387082171536261, 0.8609040526132431, 0.30973881663333985, 3.842697273338995, 63.19714192421206, 72.9707548695226, 56.66095918224704, 52.406089690423784, 25.32448491742534, 27.647489040128647, 46.25306760111163, 55.049712273382376, 19.820705306145456, 0.6768285074541647, 0.15013608811122758, 0.07414118491954381, 0.026022941925592964, 0.03374829129766553, 0.025631783177114786, 0.02491617087094534, 0.03809919573306557, 0.015346227333911005, 0.05197029778613679, 0.045012633631666826, 0.02089374578527866, 0.5665461058097502, 59.49564826103949, 54.19813040764102, 53.50326684213454, 42.31489419937134, 35.56098461151123, 64.50238120171332, 62.494668960571296, 85.64048121052404, 16.956043435681252, 0.2410949637452441, 0.3562243883648227, 0.8142256412294604, 0.46438046701012126, 7.63938122218655, 60.94086516288019, 66.9395851319836, 71.7197149030624, 66.78302764892578, 66.09075284773304, 65.93384235135971, 66.41958082875898, 64.71579344041886, 62.99959175048336, 55.63259217046923, 56.10415520206575, 50.22578139458933, 50.09229921525525, 48.644403334586855, 51.31336835122878, 51.65147666008242, 54.74312805360364, 54.831204875823, 61.28899904989428, 61.90038673339352, 63.622942663008175, 58.980088003220104, 56.06145628036992, 48.21610404599098, 52.485043079622336, 61.58805231894217, 62.545910804502434, 60.424469440214104, 58.389763447546194, 58.05196500593617, 55.02715864489156, 49.65371939443773, 48.87801577967983, 47.80985632250386, 45.418830456272254, 45.22465352089175, 46.097937860796534, 46.741175190094985, 44.25354134651923, 43.86500704673029, 44.556446383076334, 46.28906319218297, 46.3106244610202, 47.62895661015665, 50.30023190283006, 47.49084211164906, 51.67535212732131, 53.370514223652506, 53.97465336707331, 52.598113244579686, 54.569959332866055, 56.26727481042185, 55.23587972887101, 57.24067372660483, 58.08840382483698, 52.65157515002836, 50.34511950708205, 48.36367537898403, 47.443589318183164, 46.257425354373076, 43.648456911886896, 42.11542990899856, 45.49377126078452, 44.57395584352555, 49.94373944497878, 50.19297861283826, 43.35407126334406, 43.1326417000063, 47.48640591098417, 52.21982417568084, 50.64630262313351, 56.9404084451737, 44.59272046242991, 41.00128066155219, 46.90987633120629, 48.30589102160547, 47.64023734677223, 47.64492850149832, 49.25204515457154, 46.88053700231737, 49.15457817815965, 52.194375838002856, 54.522981105312226, 53.608700152366396, 49.49582438315115, 52.91597820097401, 54.573681662159586, 48.789538875702895, 48.30800125675817, 47.62681107367239, 49.59648809125347, 41.51953951005013, 44.349156964209776, 43.03353517286239, 44.86880825411889, 42.715583924324285, 43.05441787165981, 43.59472044052617, 42.47912383848622, 42.84982312110163, 45.38052458916941, 44.99433586674352, 44.23243115025182, 44.356287833183046, 47.022613094699004, 45.16236628255537, 44.403838726782034, 46.0578316257846, 48.356422916535415, 48.70554916320309, 52.68536636906286, 50.08193631325999, 50.130895337750836, 48.899467222152225, 50.33104212053361, 49.244086665491906, 52.41438550333823, 54.32439934822821, 57.83024910957583, 57.475890421098285, 60.297976924527084, 56.3901077547381, 55.77231876311764, 51.32290363311768, 52.79192932190434, 51.86672849039878, 56.640876646964784, 55.743387360726636, 60.63724625495173, 58.982170781781605, 63.89472369224795, 66.17684102827504, 77.03127091930759, 72.23811103451636, 93.66658410718365, 18.633554866237027, 0.5856544836874932, 0.2047142909178811, 0.2518128862063731, 4.8985520101362665, 71.32860752844041, 80.28928572131743, 64.83936771269768, 62.855942787662634, 29.985321683268396, 33.69645064876926, 53.8672588717553, 66.89980445369598, 34.54265886737455, 0.620186417814224, 0.12302110317133128, 0.05946223548943958, 0.07822781966458406, 0.05179496324290672, 0.16555460350167367, 0.1762993390401525, 0.1382336405015761, 0.14531235420896163, 0.08697989156409618, 0.10181087114277387, 0.18536908461922602, 1.4262725893528232, 73.70747796950802, 63.79497389639578, 63.570241697372936, 46.813703736951275, 46.087135653341974, 74.84061933332875, 67.59480137978831, 95.42106813000095, 20.75952852925947, 0.30005730388145296, 0.9109098596438285, 1.8821566816299193, 0.4515113236923372, 9.372507449119322, 64.60441773937595, 71.76050755285448, 75.18796874630836, 71.69003825033866, 70.45973193260932, 69.28147546706661, 70.99813999668245, 68.3260331615325, 64.95971387432468, 59.2820869722674, 59.18707539958339, 53.55628944212391, 53.541721759303925, 50.9948601261262, 53.66702579682874, 54.649277502490634, 56.55849510623563, 58.19402148646694, 65.27162075042725, 67.70181932756978, 65.71204016285559, 59.324079867332216, 55.548743663295625, 51.37462400620984, 50.08567825440438, 64.89031537886589, 65.55121514105028, 63.324540507408884, 62.46280754766157, 62.77256888727989, 59.37625915773454, 52.19443859592561, 50.1768498266897, 50.09379756066107, 47.849213384812884, 46.976721363682906, 48.870194573556226, 47.89620337947723, 46.24169664998209, 47.20022978321199, 47.9334423618932, 48.92158546755391, 48.59786049012215, 49.20471783607237, 52.45570767310358, 47.525009878220104, 54.336441024657226, 55.80871835831673, 55.84369413314327, 55.39111537318076, 54.20821482135404, 59.08792572636759, 58.804197157582934, 62.12948845278833, 60.62445932818998, 56.53555708546793, 53.463097849199855, 50.86577884612545, 50.6618469761264, 48.79525376904396, 43.95327998745827, 43.520489585015085, 47.536953495394805, 45.3224225198069, 51.2832720048966, 49.14608232436642, 44.950377864222375, 43.08037219509002, 49.731935378043886, 52.820342971432595, 53.348501882245465, 59.00774855767528, 46.7759273898217, 43.64670361241987, 48.25087585756856, 51.71099862744732, 49.36411119276478, 48.66210891354469, 51.30304467293524, 50.84814386983072, 52.448180644742905, 53.0386777847044, 59.43906022656349, 58.34052985714328, 52.92572136848204, 55.44974304014637, 55.94839788252308, 51.87170990051762, 51.26520164551274, 50.45882901837749, 51.82144080438922, 43.277957670150265, 47.88874303140948, 44.324308749168154, 49.032447338104255, 46.2623949973814, 44.46966394301384, 46.47353618375717, 44.256165412164506, 44.41322495860439, 48.235657061299975, 46.55057153394146, 47.87204550158593, 47.38794265254852, 50.20887990151682, 46.40391019082839, 48.27561424624536, 48.37148481799711, 51.35409432072794, 50.44553218349334, 55.81793985059185, 53.55233177062004, 53.58438930203838, 52.93164806981241, 54.9337552439782, 52.09187646065989, 56.17988048061248, 57.120005930623705, 62.15572126450078, 59.299635656418346, 62.63471718757384, 59.15511200504919, 59.02286537231938, 54.316123147164625, 56.02709631766043, 56.08192320792906, 59.74060812304097, 61.14541676736648, 64.12271145851382, 63.240676310754594, 69.13117808680381, 69.24422079516997, 80.36010019240841, 78.32198958243094, 96.6059612458752, 22.79468951686736, 0.8007873558709699, 2.636694451493602, 0.5934774058480418, 7.0915815330320795, 77.91344335002285, 87.92016275467412, 72.90836564956173, 74.22127708312004, 43.189241501592825, 44.281076385128884, 65.89416365469656, 80.63829037450975, 52.808450345070135, 0.7010971310157931, 0.2105522945883774, 0.15851886732684028, 0.2207547164852581, 0.11317448315000343], [0.04323651240537724, 0.08973911044097717, 0.030577784712095896, 0.05504000443784941, 0.04568308313948013, 0.014219036205641687, 0.17516346047482184, 1.4353732235970036, 45.70360237552274, 56.71306394761609, 45.983875336185584, 16.4197563932788, 35.46874223216888, 51.3541139325788, 60.81563172801849, 78.96381485846736, 12.659619373659934, 0.37803494221260475, 0.11716114342092507, 0.5822569143868263, 0.18117505966896014, 0.6333587174454044, 37.298276885863274, 65.61017228711036, 67.71402574354603, 62.56179640370031, 65.6598138040112, 64.6825788097997, 67.41954988048923, 63.40494909594136, 60.698039070252456, 55.01880399642452, 52.22959087740991, 46.8867382695598, 48.77654798569218, 47.75946563290012, 49.04409677751603, 47.989112561748875, 51.72229897591376, 52.44221471971082, 60.187758322685, 54.03008430234848, 60.91107476142145, 55.604437397372344, 58.0640184494757, 46.98728038418678, 42.29069317540815, 62.15320310285015, 55.852499854180124, 58.52231210277927, 52.46608234220936, 50.87096421949325, 48.96866567673222, 45.93484178666146, 43.94961649371732, 44.2188048362732, 43.800335007329146, 44.772412084764056, 45.064028539965236, 44.75790715986683, 43.71895367099393, 42.60516920397359, 43.43402485693655, 43.539426788207024, 43.112865109597486, 43.19529371876871, 46.59386273353331, 45.655447436917214, 49.72480058670045, 50.9746559973686, 50.95044320629489, 52.52617305324924, 50.790124170241825, 52.53289207335442, 54.16136210964572, 53.509075872359745, 50.30207149444088, 49.49600481217908, 52.06586330167709, 51.63402995755596, 50.7914734655811, 52.29543962786275, 50.17911303427912, 41.896436137537805, 44.897908318427305, 43.81380442650088, 47.239257366426536, 60.24182819551038, 44.49399832756289, 38.91096722695136, 45.087688276844645, 52.9136836144232, 42.42381841905656, 38.34222355196553, 42.48274026378509, 39.310162528868645, 44.75778948876166, 46.72670948889948, 46.10877144721247, 44.719287503150206, 47.40276921179987, 46.972948043577134, 52.289454090979795, 50.08564295307283, 50.1860164057824, 50.18946416916386, 51.48602716384396, 47.35889357905234, 48.34302802239695, 48.13370681578114, 48.044590565466116, 45.88374899279687, 43.050844592432824, 43.057920548223684, 41.72943338271111, 41.70241217459402, 40.737160021258944, 40.18253295652328, 40.19115040379186, 39.968944211159986, 41.62121518965691, 40.72557333976992, 43.35534211127989, 43.92742372328236, 44.386690124388664, 42.62760908372941, 43.79600078828874, 43.03164459043934, 43.93690801435902, 41.76464057737782, 46.307761130794404, 47.668666685781176, 50.72468726865707, 50.89886403852894, 51.21297920903852, 49.94776771914575, 47.721120542095555, 47.17232211943596, 51.882759217293035, 55.13072098455122, 59.27235164949971, 58.00555159968715, 62.20691211761967, 57.9529094696045, 58.347915680177756, 54.545887747118556, 53.507597138804776, 50.615590464684274, 53.73913465007659, 49.79104549654069, 55.51248527342274, 54.49941942768713, 61.80838361863167, 61.06365496112455, 73.4687311418595, 69.3167846433578, 89.17055945242606, 15.63022642366348, 0.7084152318777577, 0.39199392221147017, 0.483859631443216, 6.429942404070209, 71.70686521837789, 66.07639697290236, 61.628848891104425, 44.454256872976984, 30.72037385356042, 29.61039604679231, 38.38254159496677, 55.01261841866278, 41.73215942998087, 0.6540563294003088, 0.10709171438769949, 0.04072830606732638, 0.018357489137880264, 0.04522055372475617, 0.054952168626891035, 0.021760945824245294, 0.03297104147232829, 0.037417147654078664, 0.021919840120620305, 0.05335293710231782, 0.1371357139320143, 1.6772736368640777, 59.465014549993704, 58.54305751862065, 55.19400058254119, 24.36039378566127, 35.67531777966407, 60.99546063330866, 65.36278055560204, 87.12155249810989, 14.695622690262335, 0.2739520611301545, 0.12725765366227398, 1.8823758440632976, 1.0734774556852158, 0.5396319661409624, 41.842378031822946, 70.0726959782262, 72.01275517863613, 65.40862521817608, 69.70789201797979, 67.1324323838757, 69.55437829417568, 64.4546224224952, 64.56184041115546, 58.62914177679247, 54.10909652709962, 49.891979848184896, 52.92326596475417, 50.26231042800411, 51.52957723986719, 50.035981824321134, 53.93936380263298, 54.495473523293775, 62.29746003304759, 59.329983034441554, 63.97850551912862, 58.21774005889893, 59.77699595112955, 48.776955912190104, 44.70515520341935, 64.52859047920474, 57.17870812262259, 59.42648118542087, 55.21475776549309, 53.03919161519697, 50.67395141047817, 50.344742959545506, 45.74762313596664, 43.53440223201629, 45.11261886165988, 47.73622558962914, 46.87461422335717, 46.09832225307342, 44.12487191538657, 45.52860583028486, 45.38612573377548, 45.75451866272957, 44.25827564731721, 46.490747544073294, 48.84851171124367, 47.69438174463088, 52.560085865759085, 53.76059001491916, 52.78194296744562, 54.01539110368299, 54.03334379196168, 56.46902192023493, 55.31557444603213, 56.808389309913885, 55.02877073903238, 53.99007220422068, 54.760755185158025, 54.42046603848858, 53.017806853017504, 54.03499510980422, 49.74054498057212, 42.171398208987334, 46.58525705337525, 44.622428494115034, 48.6846350854443, 59.95128254736624, 45.81803752530006, 40.169510687551195, 45.90660072142079, 49.4843828293585, 44.270984126675515, 42.266296032936346, 45.788086306664255, 42.87761311377249, 46.93599931655392, 49.255622356168686, 47.336583137512214, 46.4314805307696, 47.951744141117224, 50.52629378534133, 53.4021246048712, 51.87991157654793, 53.06340440627068, 51.9083095365955, 52.26235051308909, 49.23585753287039, 51.818130323963786, 51.03704913969963, 48.05595759422549, 48.18404651457264, 44.58609557920887, 46.68490878997311, 44.199612679020056, 44.30042151481875, 44.44924016152659, 43.20679803048411, 42.76856730061193, 43.357679843902595, 45.380783465600786, 44.488503086951475, 44.78194344428278, 45.150250081093084, 46.60979932354343, 44.91764960750457, 46.65098813272292, 45.8966379011831, 45.287650708229314, 44.092182882370494, 50.354870519330426, 51.30136982087166, 54.527829154845215, 55.16669304140153, 55.00704473064792, 53.05028015567411, 50.546223348186864, 50.530298525287265, 54.42197615100492, 57.58702685756069, 60.831344742928785, 61.38536776265791, 65.60666568817632, 63.663056742760446, 60.97598606540311, 56.67442075667843, 56.43646624780471, 53.37494257957705, 55.81089135139219, 53.55643849219046, 57.37413629408806, 57.61107490908716, 65.02695114381852, 64.89553605356525, 76.89404287645894, 72.68790491165655, 92.70177518167804, 16.689704695055564, 0.621388501697971, 0.618260350198515, 0.6181924441649068, 7.853487230116322, 79.12331411915441, 75.69375838002851, 67.90013436348208, 54.93530065782609, 25.857282030966978, 38.065559171861224, 56.548795084799494, 63.189238348314845, 55.85564167268815, 0.6745811119194954, 0.08128910701000884, 0.08803527727122269, 0.03825925448308549, 0.044043176176567236, 0.22739505936061183, 0.13138351210903737, 0.09409745359012196, 0.1380653003410947, 0.14829914716462936, 0.2060623145512035, 0.3472820585293155, 3.186657818094377, 71.44744749992125, 74.17181599524714, 64.16892874625422, 26.57527385219451, 49.91092097374701, 68.41179970772036, 74.4306218239569, 97.50820052239203, 18.535256347348614, 0.5138960390562012, 0.372402326714608, 1.728122018037304, 1.2206827825115574, 0.6395510367808804, 46.48274590892177, 71.76543404979091, 75.5911256420997, 72.0423298497354, 72.159389065158, 71.71563563808319, 72.81164000111242, 68.08064968355241, 67.5579781686106, 61.73883607310634, 55.47616804799726, 51.99156968824325, 56.37677169615223, 52.67433274176813, 54.42030129894134, 52.25171696755194, 57.674232913601784, 57.46354672216601, 67.21011100276824, 60.75565476571361, 65.34980535507202, 58.69784209036059, 61.56595368539134, 49.26285520676644, 46.66770527439733, 66.61509529236825, 60.47961796483686, 63.4252042155112, 58.562461483863096, 56.15006262256254, 54.65464722725653, 52.868246878347094, 50.75252432977, 47.56406099565568, 48.58581489132297, 50.7314141335026, 50.48628953195388, 50.13677497063914, 45.9404899997096, 48.82493434413787, 47.13531455686016, 46.94252221815048, 47.12666965300038, 47.65410684770154, 51.749351562992224, 50.048239231109626, 55.0987458229065, 56.35412785314745, 56.8767640667577, 58.99892322478756, 56.62416342766055, 58.76305149447534, 59.74837441598216, 61.59921146208241, 57.87851779691635, 54.5505004544412, 56.85398294079689, 57.42687256105485, 54.1288770398786, 53.95519448864845, 51.199725520226266, 42.41871933783255, 46.22144153041225, 46.27833550976169, 49.346582120464696, 59.19942302088584, 47.37690510288362, 41.158991321440666, 47.330558376927534, 51.111938953399665, 45.063863800418, 44.76028803856143, 46.10253487863849, 43.5291305665047, 47.20969446243779, 51.8997940709514, 51.48589772562827, 48.30807970416162, 51.54552559698782, 54.32103787699054, 55.712369257403964, 55.73216153729347, 56.516290403181515, 57.19053014632195, 57.32152162059661, 52.0968617931489, 55.82544334473149, 54.63056779676869, 51.32991683098578, 51.78193076964348, 47.30292920143374, 50.33278757526029, 48.271311406166326, 47.261152036728404, 47.501636474363266, 45.58975165890109, 45.81351895486155, 45.40757717624788, 47.48918294906617, 45.70614014902423, 47.12919958176152, 48.70681608876875, 50.22931152774442, 48.07963302058559, 48.42569589614869, 48.184226943600564, 48.07068217185236, 47.26114026961788, 52.67790602099512, 53.709732563264915, 57.262109479596546, 58.38843376405778, 57.35792513816588, 56.785741544538936, 53.03116252345424, 52.39821357111777, 56.892288807899725, 60.715889776906664, 64.01956096772226, 63.9710412486907, 67.96803059116488, 64.15616143134334, 64.60593961900281, 60.45617395831693, 57.62751356247933, 55.79622560931791, 59.446398981155895, 55.60712029857021, 61.060791630898755, 60.46139463301628, 69.13579079412645, 66.44632354859384, 80.49371965469854, 75.9735018207181, 96.81872629350232, 19.891172647476196, 0.9107633836327061, 1.091320807895353, 0.6920280595940929, 9.904107259165857, 85.66825159134405, 80.35638178548506, 80.93534715713994, 61.958316218468454, 48.38066316420033, 45.319155185453354, 55.612886182723514, 78.39695392116424, 69.45842927502048, 0.9574751964499875, 0.17034789306982873, 0.2283554731477653, 0.17469640731090502, 0.13725989678454015], [0.016974801941203977, 0.02502198676548658, 0.023124988356064406, 0.05150073568426794, 0.10565926786512138, 0.04788827489040071, 0.06403739684291425, 0.7770116639233405, 45.091343925845244, 52.663950227922015, 30.736500678523896, 30.882034340212424, 44.47624568016299, 47.62318680363317, 63.475791023623565, 75.71352712569698, 19.47699977505592, 0.3891659546042643, 0.3941026251883276, 1.4274746732365702, 0.12972352215118949, 0.1533097452333858, 10.163498501623831, 51.71908263237246, 62.24739882253832, 64.1619037812756, 64.45169241197648, 68.6867892357611, 66.27067196753718, 64.42129012077086, 59.751994763651204, 56.332374388171786, 50.68755026786558, 48.3311903092169, 48.89119102108864, 48.20669035757742, 51.207715388267275, 52.82121765998102, 53.372498942959695, 54.50924496496878, 58.115723133087165, 61.0895190700408, 61.5040429945915, 58.023092439097745, 51.840970285477184, 50.20297673440749, 54.48457325658491, 58.52461845644059, 58.294418473397535, 52.92402298219743, 49.703074578315984, 47.517667201257524, 45.80013582783361, 44.16385635252922, 42.941908605637096, 42.41174928603634, 44.106550524311686, 43.516445621367424, 48.87123792402206, 44.983914129195675, 44.876229378484915, 43.12307503915603, 44.79159247490668, 42.74414270154892, 43.506635773566465, 43.066800794293805, 46.48271452996039, 46.89324940404585, 51.66599727446034, 53.97319424536921, 52.6477861404419, 49.48647345266035, 54.110186946007516, 53.844603261639996, 52.314537648231756, 51.389470177312056, 52.85743290378202, 53.09802324541154, 55.728823600276826, 54.98011765941497, 56.694766090762236, 55.21327903193813, 50.04442276493196, 44.48794218801683, 43.82514399866904, 44.18885754000756, 41.74121618270874, 61.10554587456488, 44.062521919127434, 44.321021802963756, 47.594930048911806, 51.23932969185614, 41.65160571375201, 39.92389971210111, 43.909929952313824, 40.4967854099889, 47.02550780388617, 48.656986298099646, 48.06526930101457, 46.32593347180275, 50.15121321524344, 48.540888063369266, 51.747300163392104, 48.98298625023135, 49.72529872771233, 49.36163225481587, 49.09653102197955, 48.29648125556208, 48.70121102179251, 47.71142836539976, 45.072532238498816, 41.474871558527795, 44.768211226309504, 43.927486481205115, 42.46357948549333, 39.92914784339167, 43.92627839119204, 41.28117707467849, 42.98166182733352, 42.28629227607481, 42.578571611835116, 43.00267396434661, 43.01659837845833, 42.93114954425443, 44.605472087860115, 46.4662209633858, 44.34018258125552, 42.61432401595577, 43.04132892239479, 43.44656467437745, 44.174121195270175, 45.98660922819569, 50.145321815244614, 51.221867299848995, 54.441682138750636, 55.66418686220723, 54.70606557784542, 49.83695291703748, 53.14642529333792, 52.246829694317235, 55.81651995258947, 53.84510924739223, 56.20555239339029, 61.89780973619031, 64.18539877860778, 59.195841896918516, 59.37827917837328, 52.877158503378595, 51.88310830823837, 50.65381788438367, 54.366058841828384, 54.7730988840903, 61.81653822621992, 64.32076761799475, 73.06515063008955, 69.16815819278841, 89.63607418921687, 11.99040222552515, 0.6544975960446943, 0.17422199970291508, 0.22221673400171343, 11.566384203972357, 74.6058419442946, 66.76005040445636, 60.95747247818978, 47.81391597563221, 30.1893457289665, 35.79900580067789, 36.018909562018614, 56.975446977923, 47.980322530192716, 0.3255342932478074, 0.0511507292638623, 0.06053475858343225, 0.04144544097324533, 0.051911014072116346, 0.04726836037251258, 0.05212518544266782, 0.036759465001523495, 0.031823323018127875, 0.04732100210422951, 0.0710180206524749, 0.038541860487912936, 1.5921122388493631, 56.77013443362329, 60.472287054984804, 36.565040772961034, 29.660294478939427, 46.9699788093567, 56.054329333766816, 67.16068129385671, 83.38463198754096, 21.510348627644202, 0.4503994236790365, 0.2731986289783832, 2.1306145623806985, 1.3715577317822365, 0.6547646849386154, 11.062351792089402, 57.86751947095318, 66.13052568128033, 66.90893573145713, 66.99506313570085, 70.52554145936044, 69.87227855190154, 66.05798536731352, 62.86393265570364, 59.24885665216754, 52.13547752749536, 49.83020251797092, 50.930607780333496, 49.88637085883848, 53.64224818445022, 53.20964605577531, 55.64459462319651, 56.24655292880151, 60.70746060340636, 61.900743669079205, 65.74567056471302, 60.70791167597617, 52.09939564428022, 52.496723897995494, 57.62103772932484, 60.493675739534446, 60.94510916740664, 54.67951897651919, 51.74472708855906, 50.83306627888834, 48.9075747612984, 45.801579260057025, 44.331082682455744, 43.676431255955855, 45.81722951704457, 46.46991583608812, 48.67001641181208, 46.97204197606733, 46.57262702142039, 45.641860346640314, 47.01077145914878, 45.763724465524, 45.4308956669223, 45.939642767752375, 47.26415264991022, 50.11471948316021, 53.214792205441384, 55.53204613347208, 53.626637151164395, 52.4355153114565, 57.74957772224181, 55.94471477693128, 54.51290453633955, 56.11999765519173, 57.05440428949172, 56.82861305052235, 57.53015641243228, 55.97252830382317, 57.32999786253899, 56.74904777157692, 52.41572303156699, 44.96831878539055, 44.74646168370401, 45.31860997599941, 44.4212422832366, 61.13353590811453, 47.50748080592002, 44.9922138644803, 50.60490200596471, 49.09806466871693, 42.156850138018214, 40.996165890847486, 45.36094803963938, 40.941970502176595, 49.58473667021721, 48.06768940341089, 50.168903104720584, 47.62487734517744, 51.76656684567852, 52.35688355661208, 53.06382802224929, 51.95768433232462, 53.50136449260097, 51.58148980909779, 53.08520886205858, 51.28244046242007, 51.836279130751095, 49.1497262062565, 47.488339639479115, 43.52002282296458, 48.67859071300876, 46.716770202882834, 44.97265692680113, 42.63614416122437, 45.844403697598366, 43.05837554316367, 44.078705618458415, 43.71686304769209, 43.189990674295736, 44.47272339174825, 45.302842047906694, 45.16883427096952, 46.033469784644346, 46.246658448250066, 46.52771588294737, 44.65627462633195, 45.66055436288157, 46.117192775972434, 46.18473991270989, 47.97922426654447, 51.225342519821666, 54.23604403772662, 57.07830329095164, 57.359227365063084, 53.9777010486972, 54.630434436182824, 57.352131797421364, 56.82833063986994, 57.85046892781412, 55.57145026422317, 58.57623684790827, 63.11262661410917, 65.4289548627792, 62.346399445687574, 63.37230713136735, 57.67029877631896, 53.64761398684595, 52.649476681986165, 55.86674982501615, 58.045693136030636, 63.80316772768575, 68.1833138004426, 77.25820356799711, 73.23500494803153, 91.38239968207576, 13.315018011677651, 0.6872010928007865, 0.257780711136518, 0.3639990776296585, 13.812372588342237, 82.6435785908853, 73.74095147655856, 69.87353371035668, 55.73699781971594, 32.93389874119913, 40.29023339671474, 45.27778594724594, 66.07003488848287, 59.73020207497382, 0.1478819663245832, 0.027541255413164056, 0.025342454750751777, 0.05271022380780309, 0.09447150368003115, 0.14391592914058318, 0.1977050613852278, 0.21446514994867388, 0.13604120411459478, 0.17159960412931058, 0.19621526552063806, 0.47497751611855726, 3.1999519563490346, 72.8057642905943, 71.00247813809302, 45.78807453955374, 44.76130393243606, 61.693101236897135, 66.10124911031416, 76.53470670023273, 89.23498046013617, 25.72349979031471, 0.45027727862038924, 0.6077331376652564, 3.197051118458471, 1.1818963024885425, 0.3738831746722422, 14.103583078230582, 62.24329994570825, 68.22771503079322, 69.4683999399985, 68.05366377676687, 72.45966219132947, 73.3208264074018, 68.82990867860856, 65.38282778955275, 62.2836729018919, 55.14588879000757, 53.9569164091541, 54.365399883639434, 51.28453108572191, 56.224838687527566, 57.05967987737348, 56.98411541600382, 58.6703815767842, 62.20085990044379, 64.24808217633155, 68.69767773535945, 62.473044933811316, 53.835330778552645, 54.53702319052912, 59.62301154290477, 64.53497609784527, 62.83332247887889, 58.34850011333343, 54.547495918889204, 54.91674392454086, 52.67639983084894, 48.633330483590406, 47.013626944634225, 46.18588132243003, 49.61211873639015, 47.177950720633234, 53.86379934126332, 50.23779953679731, 48.90918685543922, 49.202658591731904, 48.9693913152141, 48.03740086094026, 48.719136253479995, 47.94353854271674, 51.82815590212422, 52.20005935238254, 56.543393981072214, 58.82850800791095, 56.348816963934134, 55.61117995169855, 63.67716550827027, 59.56737272201046, 57.35331635321341, 58.10621923015964, 59.67663818790067, 59.21100185763452, 62.204001718951815, 59.442794322967536, 61.17506204112884, 59.944124221801765, 53.69167397099157, 45.78500724607899, 43.274619733133626, 46.06315035973826, 46.95645839937272, 64.06705694813883, 48.31302581294891, 46.21999417581866, 51.827524400526485, 50.11585697051018, 42.81143880659535, 42.2012121446671, 48.34917437645697, 43.40917664189493, 52.32307664809689, 52.03422154149702, 52.95923802160448, 49.66670636207827, 57.49684372255879, 54.095960509392526, 56.63091774909728, 55.19857014379194, 56.40842522344282, 54.42345880693006, 55.44491460246425, 54.167912467833496, 53.507452011108406, 53.51775215518091, 50.47380855006557, 45.22601066097137, 49.093279377106704, 50.18707544572892, 47.37652855534708, 45.00476544903171, 48.90747277967392, 45.246144187065866, 46.25246355610509, 45.7739971530053, 45.2857679705466, 47.90855492314985, 48.002931071865945, 47.994070437646684, 48.81778778568391, 50.249327382733746, 47.88705248986521, 47.5548630376016, 47.3690446730583, 48.5490858170294, 49.14670205885365, 49.556989823618245, 55.26578387906475, 57.98565341580299, 60.05161285400391, 61.50841251496346, 58.882103273945475, 56.71270701193041, 61.45558211111254, 59.07563694061772, 60.96124579829555, 61.242742538452156, 62.25119567686512, 67.66863607591199, 68.3768984579271, 64.04674691538658, 66.35868995420395, 59.8951808867916, 57.67744925714309, 55.813668389474195, 61.46627841457244, 60.2857038282579, 65.83484172821045, 71.71046595419608, 80.39510342382616, 77.01031761784708, 93.5848811364943, 16.069771147543385, 1.0522492205904377, 0.36681365401994803, 0.42572223010563087, 16.695221508702925, 90.16449589883128, 81.75433020437919, 78.51241280955654, 65.99689837424987, 47.6357501552951, 49.51167468101748, 53.916629745114236, 77.26473039196384, 74.60344145374914, 0.9147470408389646, 0.19116469298399266, 0.12745817717645438, 0.20383105282821964, 0.14639453001080022], [0.07444757412398055, 0.05881345860900418, 0.05122548795395321, 0.03884790112234412, 0.04832512120746317, 0.056188979276245644, 0.041825137131156466, 1.025397777557373, 47.807659795207364, 49.714896602015344, 39.63181257247925, 21.4433467003607, 29.49178553396656, 49.59642925570088, 60.153637624556026, 77.84830062620102, 23.55656481558277, 0.20805201342990323, 0.05381868025588413, 1.046495226121718, 0.5360732732280609, 0.7785814700107422, 0.8426908331532633, 19.887601329434304, 56.349185666730335, 54.22046046103201, 64.82466274692167, 62.27559281933693, 67.39466636411606, 60.10882062296714, 60.45569542915591, 49.23897973952755, 48.01325867252965, 46.04817475042036, 50.147082959451986, 48.15461304879958, 53.82909813234883, 54.037164180509514, 57.73016591225901, 56.93039463412378, 59.78405229506954, 59.59877129523986, 59.390042366520056, 56.667725270794286, 60.31291331014326, 60.58411382859754, 58.6957004762465, 56.42448732929846, 54.42560042104414, 51.10152113822199, 44.93373524758124, 44.5089582474001, 41.41000340061803, 40.57951211929321, 43.583812329076956, 45.17440011424404, 49.10770585460048, 50.07151457571214, 51.55233483160696, 47.52499026636924, 47.32093288052467, 43.00431351507864, 45.287348685726045, 45.65278022520004, 41.9236966102354, 41.79539588189895, 42.7391299124687, 43.91507217960973, 50.66626356494043, 55.05831795354044, 54.855527493261526, 52.03368417678341, 52.70109899582402, 55.72074744009203, 53.441564036953835, 52.32403762878911, 50.34466451214206, 51.224326625947036, 53.5191132176307, 51.038347444226666, 55.687481818660615, 55.44945278475362, 55.942475103562884, 52.92644308459375, 46.2434656389298, 46.610211172411525, 42.998159316278276, 44.786320809395086, 47.356689207015506, 43.969777476403024, 47.51209351324266, 49.88456656855922, 39.52792467609529, 42.34600251720798, 41.20708742449361, 49.62983216008833, 46.868789503651286, 49.540480567562966, 49.6906759662013, 52.530401368294996, 51.812015348865145, 50.531012396658625, 51.80883038428522, 46.60540626895043, 47.11865232836816, 51.03557825088502, 51.53513916077153, 46.22574437049128, 49.12241866511684, 48.36813511386995, 47.88866458400604, 43.23305829878777, 46.02882569836032, 42.521257938877234, 42.25059478513656, 41.95061975909818, 41.95046678666146, 42.64852708385837, 42.03533118770969, 42.457221323444, 42.61679118679416, 45.309580679862734, 45.056987885505926, 45.33240495189544, 47.78142698349492, 49.06314772944297, 49.772426005332704, 49.360396708211596, 46.49412470479166, 43.17560734287385, 44.178506405122825, 44.902062108439786, 49.61528016674904, 47.898847056973366, 55.66290816953106, 55.369354063464755, 57.538413001645, 52.62309874257734, 52.69446234549246, 54.68477495255009, 60.51410344339187, 61.35753462391516, 59.116829672167384, 57.0586718282392, 61.83842112941127, 60.84883851389731, 64.28199106647124, 57.551462727208296, 58.312351549825365, 52.44843559880411, 53.83449923607611, 53.83371476204165, 63.13335634046986, 63.96119217718802, 74.32867157843806, 68.16064250084662, 86.65285279673915, 12.290894023833737, 0.7318667767028655, 0.47418102982544136, 0.6705954935281508, 20.319934775752408, 76.32704073382963, 64.42255704633652, 61.697792391623224, 53.43401347437213, 34.43369542398761, 41.22673065431657, 54.56746862780664, 56.81907776863345, 49.24922497041764, 0.6817855253334969, 0.05479879782445008, 0.04487706671258615, 0.0192172983435974, 0.04189151481935575, 0.04782019265656991, 0.08140673214990286, 0.09089237154130975, 0.055573366342052344, 0.13686053514961274, 0.10823926813299618, 0.22972609637485397, 3.0855788290500645, 61.121066693336736, 58.48780701237341, 46.57819678706508, 35.13474456725582, 45.22429658520607, 54.00471048970377, 69.96481510900682, 81.7089326920048, 26.621428382012155, 0.4280737829544852, 0.07495254097927002, 3.2316221537128573, 4.445763893665807, 2.131116870910891, 0.9013148228968344, 20.836552112333237, 60.53923799145607, 55.432217890216464, 66.46952044579291, 64.31434669802266, 70.5889348060854, 62.274063094969726, 62.17792580204626, 51.402555204206905, 51.111656542747255, 49.13013396724578, 51.752007007598884, 50.758447108730195, 56.72256785054361, 57.03241155993555, 61.674560193092596, 58.656719961474025, 63.05675245100453, 61.38737601618613, 63.56501317793324, 55.53717659365747, 62.25687134650446, 62.326144326117735, 60.36997595141011, 58.24558888712237, 57.1172288925417, 52.36701503876717, 48.6475843767966, 46.76149698995775, 44.45488445220455, 42.71374433271347, 47.01094796580654, 47.287361314219815, 51.939876771742306, 51.99741794217018, 55.59278795796057, 49.97027035682432, 49.87960477029124, 45.315334796905525, 47.92659390357233, 46.41623035553963, 43.885607334875296, 42.65488132353752, 47.40694653603339, 46.98864536900675, 53.37088684881888, 57.07003101225823, 56.80946796171127, 54.09528586172289, 56.28849091068391, 55.99973386333835, 56.92114568525746, 55.44770340765677, 54.8909661077684, 52.48503915725216, 56.53523937348397, 55.03073584648871, 56.80418845145934, 56.33661447032806, 57.21009885111163, 52.98317232439595, 46.6495172439083, 47.62908212600216, 46.30357988419072, 47.2200495196927, 50.90679507101736, 43.66317364477342, 48.95117582813386, 49.27977238931964, 43.071236994958696, 44.60609574471751, 43.51024043175482, 49.0126472134744, 48.47907543182374, 52.14001178741456, 51.12262741211922, 52.902277361962106, 54.85185223241007, 53.24854812314434, 53.18805340797671, 50.47196111371441, 52.11867017130698, 53.6453821582179, 54.10109881431826, 51.102474274173865, 52.93337391268823, 49.31945108598279, 50.65609285908361, 46.83724972509569, 48.06211179302585, 45.59358381455945, 43.72051477432252, 43.13494020892728, 43.64040428592313, 43.2221305754877, 44.142083275702696, 43.61905090270504, 44.69781644882695, 45.90900513433641, 48.43654124967514, 47.62115109351374, 51.42816435906195, 50.82540196757163, 54.573877780668205, 51.55811248287078, 49.23543783926195, 45.6505758531632, 46.867848134809925, 46.615969211824485, 51.43762511591758, 51.49034569340368, 57.82393801596857, 57.92817500329787, 60.563015399440644, 56.209415928010024, 55.710317857803844, 57.24801640356741, 62.5502646353937, 62.998713139564764, 64.34033240041425, 59.955377501826135, 64.17641262854299, 64.58792417280137, 67.84263241675593, 60.52315627374957, 60.651311874389656, 56.420984652734575, 56.74172078409503, 56.050481488627774, 66.00494707784345, 68.34330727977138, 78.81941672294371, 72.13245022681453, 88.09626933067076, 14.275174025566349, 0.7448773398514718, 0.4738563311196143, 1.3103714537236, 24.81448461932521, 82.96248297537528, 73.69039996977776, 70.14083539285969, 60.4943621543146, 40.8520854673078, 42.29720038752402, 59.94126481394614, 66.09273756704023, 61.257627933256096, 0.34683683887124067, 0.17532345027692858, 0.051985623375062025, 0.05907042748144558, 0.06189190249349322, 0.17832427796336914, 0.16462107940066248, 0.15569272300889417, 0.1551146483829906, 0.2596555734353681, 0.25928129351908163, 0.3778357593522918, 4.981228709220886, 76.99676190653156, 65.06729664341097, 58.480115244465495, 31.705928194907408, 46.53002615897886, 65.80709488161149, 74.96100471865746, 92.84203913904007, 30.56822903694645, 0.5022993984241639, 0.19134421802816853, 8.172080766770149, 6.0742393232161005, 1.8731582741583548, 1.8386664217518223, 25.508287183700073, 63.5830403912452, 59.444422106589045, 68.07462492296773, 66.12356739659464, 74.02100086212158, 67.23397470289662, 66.64828638876638, 54.04232994202645, 52.77428257849909, 49.774834340618504, 53.844709165634654, 53.11140637243948, 60.26206762559953, 60.375157402407744, 65.54127193266346, 61.911404671207556, 63.44511808887605, 63.54161623985537, 65.45912181177448, 58.513596596256384, 63.106142936214326, 63.032614184964096, 63.689336622914965, 61.304319827787346, 60.82078180005474, 57.01792624688918, 49.5638539714198, 49.640834408421675, 45.653250909620716, 46.092356328041326, 48.220736365164484, 50.5503418368678, 53.97078591008341, 54.995230551688906, 58.28043130136306, 52.774914080096835, 53.718612809335035, 49.80276553861557, 49.59457397460938, 48.262007544117594, 45.578357173550515, 46.073332832705596, 48.06908184482206, 47.82547127815985, 54.48698159187071, 60.84002887049029, 59.73204951132498, 58.24749515902612, 57.61150244743594, 60.52433690717144, 58.84881411829303, 59.9270030759996, 57.49727910564792, 55.31002821460847, 60.668644828181115, 57.98330783843995, 59.372038687429125, 58.86795136236376, 58.24398856009207, 53.77618143635412, 46.91325741429483, 47.48539393947971, 46.98823352013865, 50.348061284711285, 52.63718397386613, 47.40676610700546, 49.66534529962848, 53.36381873776836, 44.31072558126142, 45.20968967868436, 46.80470189740581, 50.58638057401104, 50.96252018405546, 54.00757774229973, 54.37358587018905, 56.46868067402994, 57.4874496459961, 56.679029541630904, 55.9901632801179, 52.22704525916807, 54.707560000881074, 55.97114762952251, 57.894803477871804, 52.38677201732513, 56.35329631067092, 52.95429191281719, 52.32128804729831, 49.27905851794828, 50.15698694413709, 48.247977226011216, 45.46442800952543, 46.07013610101516, 44.57122979625579, 46.88382787089194, 45.48546368075956, 46.550398949653875, 47.31778713964647, 50.24428321469215, 50.81713753361856, 50.80495465186335, 52.938414158359656, 53.279683897572184, 54.68615170448057, 55.05692551212927, 50.95515397287185, 47.10411210213938, 49.90291541622531, 51.11946990413051, 54.91816774491341, 53.24755184112057, 61.584153482990885, 61.410490543611594, 63.858096599578865, 58.679469708473455, 57.63824908964096, 60.44134739906558, 65.19025510357272, 66.30409840614566, 67.09942171650549, 65.52768876475673, 69.15448481036772, 67.32862933989495, 69.88981154657179, 64.12991685252037, 65.20876869078606, 60.70937864242062, 58.10890605372768, 60.14219214839321, 70.26299368950629, 71.05200198388869, 80.03733619566887, 75.81832501196092, 93.3696920641007, 16.22734844684601, 1.0491830302822975, 0.7911841679484614, 2.220814367455821, 28.2179997428771, 91.5832721033404, 81.06377340132191, 79.0693187713623, 70.40298308095625, 53.497700998860026, 58.130965463576786, 72.34586638789024, 74.87610109390752, 76.47922085177514, 0.8665509173466314, 0.2489458327932704, 0.1906791158140667, 0.10007362887864152, 0.21647360265976], [0.05084063602431167, 0.021892230311829238, 0.026310506434510314, 0.05511889617229181, 0.06648517799593749, 0.03251955138459321, 0.20538693143715783, 5.885311990014969, 61.74492359161378, 39.38494251620385, 39.512097912449995, 21.909843990879676, 28.97293636875768, 52.58802490849649, 60.104455024965354, 77.0742993200979, 33.98313668466384, 0.575584533714479, 0.01488181908855275, 1.5406631221694331, 2.675728653707812, 1.88445151332886, 0.08442999089076635, 6.647828596253549, 46.61733027427427, 61.692352064194225, 69.25070055069463, 62.28288450548726, 60.49110658707158, 55.14351575605331, 50.71286916732789, 48.44990868722239, 50.56981248240317, 50.37147391226984, 53.98508687173167, 56.47324631291052, 55.07763562663909, 56.829370067965606, 59.47282791137696, 58.87877318166918, 60.047690483831595, 59.01762508576917, 59.38435100740003, 60.40830535273398, 59.329751614601385, 54.353275837436804, 54.97095892506262, 53.80093159214143, 49.61313463026478, 45.2377660043778, 42.42743484435543, 43.61142189271989, 42.91939027847783, 42.74888876945742, 47.99546287905786, 53.89695121395973, 55.01320677418863, 57.08926631558327, 56.702810871985655, 52.21848272508191, 48.7054197249874, 43.44694122191399, 42.596563523815526, 43.52779696064611, 41.69801912000103, 41.49378130512853, 44.36059459563225, 44.308493752633375, 48.39559170507616, 51.6659737402393, 52.160466947863185, 53.82909028760849, 53.82532873461324, 51.85714614006781, 54.734867542020744, 54.003824034044825, 51.75073615966305, 51.533848700984834, 54.08315397077992, 55.111650420773415, 55.95015902673045, 54.42095633476011, 54.2006407245513, 55.98262840701688, 49.888857641527736, 43.6607260857859, 46.94970015556582, 39.00883036275064, 44.95475522933468, 44.7721924320344, 51.22165941422986, 43.242064060703406, 42.99269153225807, 43.9692283445789, 41.69710913012105, 46.851766417103434, 54.78660752696376, 52.88436389738514, 53.71185848789831, 52.2009301185608, 54.03953329209359, 50.70888011686264, 52.41772344035488, 48.13932757223807, 49.728801404276204, 49.675849406949936, 50.5490670665618, 47.44056517078031, 50.97342045076432, 50.26358912068029, 48.081409854273645, 44.3987710245194, 44.00606724523729, 40.677469391976636, 41.51156140911964, 40.12473683203421, 43.45968892497402, 40.076197501151796, 43.145208974038404, 42.318341962752804, 45.11410151758502, 42.363013836645315, 44.76239435134396, 44.61789423419584, 48.08847404295399, 51.42825457357591, 52.95782204597227, 54.672431253617816, 53.5660679109635, 49.90330765324254, 44.76836419874623, 44.39458585554554, 45.697801190037886, 47.66794496966947, 52.495405981617594, 56.139903683816236, 57.15742926443777, 55.83650835098759, 55.18174317575271, 51.76970474181637, 57.46985781577326, 60.713591267985684, 71.07483017829158, 69.3151137136644, 64.2666232201361, 66.54712846202236, 65.27614324323594, 60.74203237410515, 61.060273878036014, 57.2903387777267, 54.80808250365719, 55.87839926442793, 61.30086029729536, 68.60252103497906, 73.06065559387207, 72.81064371908866, 88.88250058697116, 12.304709592173177, 0.670816678433649, 0.4083323406596338, 0.7024860790660304, 30.042790289848085, 74.97248941852202, 67.53463222134498, 66.01232897850775, 53.80501477949081, 33.04024204131096, 20.49001462997929, 46.78244636904809, 54.147641658782966, 66.48987754698723, 3.237064442326946, 0.057555274106562145, 0.02368087133002137, 0.017729090196230722, 0.03231349671559949, 0.046570703252068454, 0.060078039945613955, 0.16955295427431985, 0.03716865937495905, 0.09588139657411845, 0.11152867347963395, 0.22004749475707933, 10.816023022897783, 73.24351649130546, 48.49348229746665, 46.37141335395075, 27.625617904047814, 37.233593079351614, 56.68618786719538, 64.84162307554676, 83.23467977585332, 38.4797183159859, 0.7809326244938759, 0.07902273547745521, 4.318134380925087, 5.242574272617217, 3.7037465745402924, 1.485131185862326, 5.226026773452759, 53.527032483008604, 65.14804647814843, 70.95279739749047, 63.93133117306618, 63.81438570637857, 60.32768887858237, 54.16333898421257, 50.9325611206793, 52.34812098164713, 52.29051313092632, 56.496431442999075, 58.37130477351528, 59.180760383605964, 60.515711615162516, 62.91951264104536, 61.79498087975287, 62.74606150965538, 60.43775843035791, 60.34079351732808, 59.860938595187285, 61.82040176083965, 58.26602443572014, 57.31865044563048, 56.72607052710749, 51.893204489061915, 47.5801113344008, 46.48354999480709, 45.87525313900363, 46.95585827673636, 44.45525707737092, 50.0859018295042, 56.455179875896825, 58.1376648718311, 58.77945876890614, 60.682047567059925, 54.903117610562234, 51.61062517473775, 43.984341236852835, 43.54231365265385, 45.484867480493364, 44.86115963228288, 44.312592629463445, 46.13484736411802, 43.65011215209962, 50.53770396017259, 53.44785159634006, 55.12901867589643, 54.10483291072231, 56.89885485556818, 55.52270304772162, 58.25397099218061, 56.33072699269941, 55.31384860315631, 55.36186233643563, 55.430288084091686, 58.43002657736502, 57.81209638041835, 56.17181216516803, 55.46596988554924, 56.685124904878684, 51.396518676511704, 43.35207477692635, 47.63245144198018, 42.92867060630552, 47.59065466542398, 44.626923530332505, 52.22772382920789, 45.9783330271321, 45.078898245288485, 42.029428020600356, 43.964050815951445, 51.70873149748772, 55.299983024597175, 54.66290381646926, 55.593313555563654, 52.07037402737526, 55.62439049443891, 52.96776917672927, 56.230416297912605, 52.584243743650376, 54.025793229379964, 51.65189635369086, 54.090449579300426, 51.4414337373549, 53.00266258178219, 51.95637426068706, 52.73640032737486, 45.979952966013265, 45.1795619533908, 43.445713520050056, 43.36504213271603, 42.12225875546856, 45.34135187825849, 42.63863094391362, 44.88032433294481, 44.31642870749197, 45.49186891125095, 44.39432697911417, 47.94280898186469, 48.230581514297, 52.11856426731233, 53.29602056933988, 57.0519135844323, 56.56155847734021, 56.85804651629541, 52.414891489090465, 46.805019609389774, 45.40976585880403, 47.07332541865688, 50.71022548983174, 54.12721787729571, 56.801791883284054, 60.48313240851126, 58.707832367189475, 59.4439043537263, 56.69944547837781, 60.1925475366654, 62.871224341853974, 71.56125114810082, 71.55832505995228, 68.42044461158015, 69.17068419917938, 68.10525863401352, 64.96720560135381, 63.75112179786929, 61.67373649535641, 57.56870938885597, 58.18941662388464, 63.24418290968865, 70.5707428532262, 77.41156824173467, 75.44708836463191, 90.12705295316636, 12.849138494460815, 0.8274356323865153, 0.45214956686381375, 0.6404313637364296, 33.706727258620724, 85.507842340777, 73.34883997517248, 74.44773904738888, 63.265704954824145, 44.66703761008478, 31.146780598548155, 54.854299791397594, 63.118141466571444, 80.22116199616464, 5.286971090301391, 0.06980072992343096, 0.0274292801717116, 0.011209485650573288, 0.03576383415249086, 0.32533563132728305, 0.21091859186849288, 0.23037593811750415, 0.12440212221155245, 0.2913561998115432, 0.20666565475684984, 0.38294856887190576, 15.199714918290416, 89.46500393652147, 55.818430146863385, 56.048437933768, 29.296608394192113, 44.56804483167587, 68.32304431546119, 71.50515340989637, 90.9227292768417, 42.89529908087946, 1.6546756365606863, 0.19110133751265465, 6.493926067506114, 8.527529874155599, 5.527669787406922, 1.021935305287761, 9.227312091858156, 57.90248740103937, 66.47709846496582, 72.39743771091585, 68.28006298311296, 66.96940299003356, 61.60402421028384, 56.5749063030366, 54.37018909761983, 55.968649079722745, 55.40083108409759, 59.817153176953724, 59.74698589694116, 61.81505164792461, 62.28553602772375, 65.45762738873883, 63.21183120050738, 66.0504073481406, 63.32602316333402, 63.06176131771457, 63.366470644550944, 64.53086153153451, 60.870493919618674, 58.46105252542804, 61.184177629409305, 54.45765010772213, 50.22376921869094, 47.65154946234919, 48.42288355673514, 49.36190682072794, 48.144697297003965, 52.524533502517215, 61.05076997510849, 60.563619444447184, 63.141891417964814, 64.15067403547226, 56.09296467996413, 55.907605232730994, 47.68328928178357, 45.17577294380435, 47.791362347141394, 47.18827832129694, 47.39905080487652, 47.77996393942064, 47.3229411340529, 52.02721226599909, 56.58294323951968, 56.12798752323274, 58.99034892359088, 61.06329410306869, 58.57445609185004, 61.59447716128442, 59.896098721411924, 58.09883732949534, 55.683002471923835, 58.48093109746134, 60.69366170514015, 61.58834649670509, 60.34855981026927, 57.920204747107725, 59.07716274261475, 52.5796506481786, 44.13916503229449, 49.70405909322923, 45.53878438088202, 49.76623650520079, 46.38784808497275, 54.82622738807432, 50.174112012309415, 46.257068418687396, 41.21815243074971, 45.403423386235396, 52.8639244264172, 58.1942097602352, 56.94674699537216, 57.76750295392929, 55.541679474615286, 58.613185574931485, 56.1853051185608, 60.49618213407455, 55.018427448887984, 58.37121455900131, 55.14920711517335, 56.96934376993487, 54.67704003857028, 56.85425750670895, 54.48476937509353, 55.106767069908884, 49.32675453924364, 47.27439395843014, 47.4330146081986, 45.96475378159554, 43.08718535207933, 49.360988986107614, 44.81475407077421, 47.25333867534515, 47.783623510791415, 48.78592637277419, 46.36385102425852, 51.297388615146765, 50.34027537991924, 54.593991694911836, 57.41874148768764, 58.34448360627698, 59.242745599439075, 59.27653681847357, 56.60347684737175, 48.63970433512042, 48.84658582748906, 50.36337421786401, 54.24977233332973, 58.4277476802949, 60.71079461805282, 62.99510063663606, 63.872060237392304, 61.54720083359749, 57.226921896780695, 63.6882265921562, 64.67102742964222, 72.45828151702881, 72.47335910797119, 67.56830184690415, 72.0067382627918, 70.70684125346523, 66.74312929953298, 66.21301312600413, 65.97079107838293, 61.07232339920537, 62.68788883762976, 66.69646093922277, 72.45688515324747, 79.95763363376741, 79.64785268229824, 95.7854014058267, 15.761987663084462, 0.9487693732784641, 0.8820755359145903, 2.32967582921828, 37.731514438506096, 91.61356064581102, 79.84879570622599, 81.94658910074543, 74.44096903647147, 48.31200207433393, 34.690908770407404, 69.58046990056192, 70.7586871424029, 96.7885083536948, 7.239278872166911, 0.3593865541681167, 0.1993680544077389, 0.06863234624747308, 0.15407171160463365], [0.04992834021968227, 0.0681460642766568, 0.07129843947627852, 0.06342251169224901, 0.047310315177685795, 0.0933471700597194, 0.1988087642577387, 6.816176724049353, 59.91329046987719, 49.91840485603579, 36.16847345905919, 41.70131783331595, 45.72512834302841, 45.96467925656227, 65.7334602263666, 72.5720694757277, 46.959431555963334, 0.2584080452159528, 0.04041640102983483, 2.28246642697242, 2.9625610430394453, 3.698572723134872, 0.6122563046313102, 2.9571913182735448, 48.568011253110825, 64.9035337663466, 66.38519733182846, 61.14747601170694, 60.29616478950747, 52.5491032292766, 50.94803879337927, 47.48979483881305, 52.13375560698971, 52.32016232705886, 59.20190980357509, 55.96687616840486, 59.71220231825306, 60.39574200107206, 62.088954679427616, 59.46321418208461, 62.47604946936331, 59.18434935231363, 62.80490490698046, 57.32049003724129, 57.183603240597634, 54.79149872256864, 52.828807446264456, 46.97279899351059, 45.895072875484345, 43.90383851143622, 42.35711851427632, 42.457503734096406, 42.29228565769811, 47.884428424219934, 53.5276992859379, 53.04691476206626, 58.51427908866637, 56.19965314865113, 58.3503318602039, 54.26927435782648, 47.861266828352406, 43.52989150631813, 42.78327226638795, 40.44846965420631, 42.82386095293107, 39.83137884447652, 41.768500189627375, 42.40925073623657, 46.10952061991538, 49.36151458371071, 52.928286598574736, 51.38876415068104, 53.52600089965328, 53.74860717404274, 55.00239279962356, 55.97642713977445, 53.27355323299285, 49.30822134017945, 51.52965568727063, 54.085103388755556, 54.44659294620637, 56.64589728078535, 54.77805283761794, 55.48647603681011, 54.45370420332878, 51.32594347000123, 43.75402750507478, 36.065044479985396, 39.98908165962466, 50.725942427112216, 50.26966879444738, 43.2889756079643, 42.51730811211371, 43.67200682240148, 48.24998155716927, 47.44575838888846, 50.351375687506895, 51.774490033426595, 50.971616160485056, 51.63050374677105, 51.68694665355068, 51.757106088822894, 49.84943389892579, 51.37390229009813, 50.59129530383695, 48.340505938376154, 50.30108697952763, 48.14417562177105, 51.995044908215924, 50.73242610500705, 49.199767804914906, 44.375597661541356, 42.803597988620886, 40.06196714216664, 40.61187951795517, 42.39771504555979, 45.04396953890401, 41.97417359198294, 43.97397833485758, 44.64862992686611, 45.8393124611147, 44.99003694903466, 45.722104195625555, 44.43254655407321, 49.160116564842966, 52.56731871635684, 55.418807306597316, 56.74239543176467, 58.09618972962903, 56.15489498261483, 54.8798579554404, 48.16073586863857, 45.836202021568056, 43.787767733297045, 46.49516413288732, 49.53458916756415, 54.953582825199256, 54.73837021858462, 54.592760070677734, 53.7881132864183, 53.972484296368016, 55.44291811604654, 58.582912721941554, 63.27401253484911, 70.57737950355776, 66.08199811750843, 65.15208259705575, 64.98948466393256, 64.01625048729682, 61.31601633564119, 62.008353894756695, 57.72736926232615, 61.71651386445569, 66.9767770459575, 75.32835037477555, 70.6491667224515, 79.08530635218467, 6.56648354184243, 0.3463166958141712, 0.45495819841181084, 1.351805778761064, 45.52760562589092, 74.35172727031093, 70.21071633984967, 70.65670551792269, 50.23453612481394, 34.93948898007793, 39.981052567881925, 48.864314940667924, 58.010132928048414, 65.88339282620338, 4.3600552024379855, 0.2320207288909343, 0.02589587283681237, 0.10175938237338297, 0.025083628115093997, 0.022184588615932775, 0.08510996287147846, 0.10301549843842946, 0.03493792625264295, 0.04792180655884647, 0.18158505460427654, 0.34356883036032804, 9.775490780030529, 74.53114432673301, 55.987476456549864, 51.32626510435536, 33.70566037393386, 43.5887505931239, 56.558420581202355, 70.34428088895737, 80.08766020497968, 51.186052137805575, 0.27071745405274056, 0.05456172425540225, 2.4835263865609325, 5.806908713233087, 2.3104427322264645, 2.450639028703013, 3.5098260641098027, 53.10545613688808, 68.6818862730457, 69.86758739717546, 64.52536629092309, 63.02203947497953, 56.313409728388635, 53.61142227726599, 49.00191560868294, 53.79836243967856, 56.32552200748075, 62.4326523657768, 59.80904563780754, 62.157560856111594, 62.4419052370133, 64.87614385543331, 59.80800620971188, 64.41492803635137, 60.66485189622449, 65.27964984216999, 60.811717202586514, 59.62135238032187, 56.96085183851181, 54.67587117225894, 48.676492244966575, 47.728553433572095, 45.01080982146725, 44.68137779543477, 44.98806399683799, 45.27206320916453, 49.85753359333162, 56.4455073110519, 56.78904025785385, 61.909639604630016, 59.24166694764168, 59.09846905739077, 56.850001735071984, 50.99492288404896, 47.528626303518976, 43.91223238360497, 43.86308508534586, 43.86445007016582, 41.83247796950802, 43.40078276972617, 45.10053796152915, 46.67005869650072, 51.14858565791961, 56.642602489840606, 52.96580799164311, 56.458176566708474, 54.513018285074544, 57.892508891321, 56.64530500288933, 56.41300655180409, 53.61151641415012, 56.074600142817346, 55.430578339484434, 56.26586275715982, 56.73478995600055, 56.57203512807047, 57.945892349366225, 55.57367032574069, 49.73045272211875, 43.60349086023147, 41.98342254084926, 43.32603416135235, 50.4663795809592, 51.41823291778565, 47.27297798279793, 43.674046454891084, 44.12055338582685, 50.36904596513318, 51.851843095594845, 52.043337129777484, 53.82608967442667, 53.092022019047896, 54.75040405027328, 54.7186367742477, 56.37271596539406, 53.06486352797478, 53.648598501759196, 51.80774388774749, 52.546875323018725, 52.9972065648725, 51.1548496830848, 52.06428650886782, 52.61784668891661, 51.981508808751265, 45.77342840933031, 46.80109331684728, 41.886594910775464, 42.676701468806115, 44.287897386858546, 47.23005548600228, 43.09625387191773, 46.619444431797156, 47.04959900148454, 46.980451537716775, 48.16488965865105, 48.352751578054125, 45.75169063383534, 51.19545798147879, 54.60317396348523, 58.858357244922274, 58.857360962898504, 60.56745552247571, 57.10730137363557, 56.728192529370716, 49.40436647784326, 47.90461686349685, 46.87277463174636, 51.41514993483021, 51.50720011803412, 57.31901130368633, 57.917388485324004, 58.90730842467278, 57.221877728739095, 57.00232698071388, 59.66214895248414, 63.009193712665194, 64.23819780349731, 71.44063826530211, 67.48238625064974, 67.98452023536929, 66.30682053104525, 67.67189948789536, 64.33420958057528, 63.4701467329456, 61.01690423104071, 64.68288867704331, 69.81404704432335, 78.09788888500583, 74.6102193094069, 80.7915138429211, 6.498130848330836, 0.42312914505600935, 0.721166979882025, 1.9805275192183835, 50.57646482221542, 79.53958742080196, 77.0025356354252, 77.31053583083614, 60.73516430393342, 38.165234442680116, 37.258268710105654, 64.75383650872016, 63.67216056393039, 78.85247445875599, 5.223324260404033, 0.20219882589674767, 0.041058306101589434, 0.04846127801424554, 0.06620991494386427, 0.1907402496304243, 0.3125030150817287, 0.23030297590359566, 0.15398056246340275, 0.3096689187711285, 0.29341412648077936, 0.6760503459841974, 15.543494974413226, 86.58273650753884, 68.6717430237801, 53.33588361740113, 56.492650278152965, 65.97949089542513, 60.97411901720109, 79.33152921738164, 83.14078607866841, 58.72993492311048, 0.47257340963809724, 0.18544589259451438, 6.076651090575803, 12.0563490352323, 10.592547943515163, 2.677965875594847, 5.483755911550214, 58.83838453600484, 69.0026577057377, 75.25663375854492, 68.12818881004088, 67.52921150576684, 57.41330900499898, 56.97074405608639, 51.261271430600075, 58.22366283785913, 60.01373060287968, 65.88465582939887, 60.577645840183386, 64.41938777123728, 65.64983137192266, 68.02867043402888, 61.809485804650095, 68.44476330664851, 61.100599765777595, 69.83619274631624, 63.104805407985566, 63.43753614733296, 60.71158301445746, 56.332947054216945, 52.20085951589769, 51.062254290426935, 47.86037252795312, 47.005515483117875, 47.80660075526084, 48.15082403921312, 53.525067375552275, 61.65071218244491, 58.69883837238435, 65.48887298953149, 62.51884645031345, 61.470714615237334, 58.09926486784413, 53.87632739159369, 50.06798444255706, 45.517756554388235, 44.83681348062331, 47.96220117999662, 42.37911908857284, 45.24308473833146, 47.4513909124559, 51.34505717985092, 54.05144945267708, 59.32551153244511, 56.183547896723596, 58.626250989975475, 60.04792974841211, 62.34301836259904, 62.38453272850283, 57.85722717162102, 55.52225589752198, 57.57118832680487, 58.266730462351155, 60.10774589353993, 59.33885151340116, 60.54222683752737, 59.1304716756267, 57.15752340132191, 52.1100958701103, 44.342328117739775, 43.773560908532914, 44.2736787949839, 52.64286356587564, 54.42175649827527, 49.99516171793784, 43.70023612053164, 44.78053531339092, 51.8062690765627, 54.016571737104854, 55.86552604552239, 56.584288612488784, 56.97524693704421, 58.82465624040174, 58.40428406192411, 59.264389238049915, 56.590172167747255, 57.54583804838119, 56.71308355946695, 55.422145243613954, 54.11738057290354, 52.81419661737258, 57.51989941443167, 55.308878960147986, 53.39102429728354, 48.24878915663689, 48.177500078755045, 43.55853657568655, 45.59096759365451, 47.77696332623882, 48.84930795238864, 47.02472332985171, 49.8842998473875, 49.05738576765984, 50.045120946822635, 50.150989640143614, 49.96273156135313, 50.3157409544914, 53.346772116999475, 57.44396232789563, 60.710269020449736, 60.26240102706417, 63.65635733450613, 62.55129229637885, 59.79321495179207, 53.04791104409003, 50.44591657577023, 47.228741491994555, 53.11786651611329, 55.4495547663781, 60.98317184755879, 61.16979037561725, 59.90681855909286, 58.24827178832024, 58.90348411375477, 61.97750053098125, 67.39447024560744, 69.28437802099413, 74.65210237810689, 69.55261322759813, 71.16378168905936, 71.16133413007184, 70.71180697410338, 66.33327299548735, 67.69763023622575, 65.08238207909369, 67.13034568294403, 73.49243794718097, 82.20419468418245, 76.69582197743078, 87.24695067251884, 8.10749403892025, 0.5261028533981693, 1.2687358620666689, 3.5307372000909623, 54.69032510634392, 88.85812697872039, 83.4888336735387, 85.48065247074251, 70.68681363136538, 51.61199015955771, 54.243296500175234, 69.01036124075614, 73.26063371473744, 96.38302941476145, 7.807041954609656, 0.3205856410486083, 0.3194617594201719, 0.14949756914809828, 0.17841138216035982], [0.03362384797524541, 0.01712549526634957, 0.08602737614344205, 0.052234870081226674, 0.02336286823265255, 0.03812380630763308, 0.2785934507846832, 6.9061250071371765, 61.30485327013078, 43.22883390611218, 28.065727449232533, 29.009367342918154, 38.55272539200322, 48.24968345703618, 64.83821453586702, 68.0328046121905, 54.943831812950876, 1.0430413340368578, 0.14249083706207816, 2.3439924803472336, 3.5699888487016005, 1.59180470051304, 3.2268893238036864, 5.731861514429893, 52.67823942245976, 61.751289598403446, 66.68287384894587, 59.55791196515484, 56.617593457621915, 50.990510217605106, 50.162607700594016, 51.81783614620086, 56.519196879479196, 57.50883048580539, 61.74764179414319, 61.78453953035417, 63.42629071204894, 60.66972740234868, 60.7110103484123, 58.491399903451246, 59.415930009657345, 59.18280393846574, 56.68379522139027, 52.80005647290138, 53.71836962238435, 47.52672003161523, 45.55087704812327, 46.45689748948621, 46.07489393603417, 42.7725249721158, 44.331525910285215, 46.78306218116514, 50.37014422878143, 52.73620420886625, 53.19971853686918, 56.39715625393776, 58.027473726580226, 57.73301747537429, 60.8308466019169, 54.866294399384536, 47.395948210070216, 40.70290596254411, 41.56271303853681, 42.50486635392712, 42.42444599828413, 41.71426165488459, 41.297874604502034, 41.92994102354973, 45.19105057562552, 46.75239709115798, 50.91250604198825, 51.07369584421958, 51.29846334457398, 52.24656297314552, 52.504639241003225, 54.872644716693515, 53.57811350976267, 50.802765969307195, 53.974139536580736, 52.016488505947976, 55.906016672811205, 53.698090968593476, 54.60043614910495, 56.42402056724795, 55.801363914243645, 58.56302630516791, 48.82925679606777, 37.058321968201675, 36.915539849189024, 45.810726227298865, 50.99473461028069, 42.89533045984084, 43.978065444577126, 48.45820057776667, 53.835601422094534, 53.7773463802953, 52.25578054305046, 48.946539586590184, 51.373266866130216, 50.92256299911007, 52.10345921977874, 51.94778819237986, 51.590770136925485, 48.35650528630903, 51.48561139260569, 51.29237190369637, 51.255423176673155, 51.09686528482745, 49.41791826678861, 49.165235257917836, 44.891934548654866, 43.292682247777144, 41.22846434193273, 41.846680871901974, 40.43957764102567, 39.91085390890799, 41.891658690667924, 41.30714708758939, 42.662757442843535, 48.46497451105426, 53.73942882783952, 53.30377509517055, 51.619972182858376, 48.12657202443769, 44.21985603147938, 52.37329083104288, 51.712481283372455, 60.7210986844955, 60.16360436716388, 55.02524845061764, 54.53045322049049, 53.35602498823597, 49.74931540027742, 45.152623115047334, 45.22084489945443, 45.39278591832807, 46.74136346386325, 48.73401380354359, 50.75147313456382, 51.378828787034564, 53.03403369842037, 54.82057917502619, 61.946831518603915, 61.45009079287129, 61.27386654576948, 65.479620118295, 65.13913485311693, 65.17200823753112, 65.38885647250761, 67.62787480508128, 65.18284574631723, 66.8552698627595, 66.98166431919222, 70.07370794973066, 70.3984723552581, 76.7873622525123, 84.62228882697322, 2.68373764330341, 0.21392917951508877, 0.16754660064414625, 1.5502491497224378, 49.42281730713383, 72.15820450936594, 68.42969356044647, 72.53462653006278, 46.57924013753092, 38.88167104413433, 39.728444084044426, 32.26864907049364, 56.21225572401478, 69.67764269921088, 9.627187925000346, 0.4361367970705033, 0.1605196591586836, 0.06729544621081122, 0.12038088839260802, 0.05499302792633253, 0.032858694678232554, 0.05941541219550756, 0.0343621613818311, 0.02582911401987076, 0.07558913706170936, 0.27546946680353535, 10.458514671171866, 74.0975498384045, 52.53262142981253, 39.8981571966602, 25.86602303289598, 44.01393159743279, 54.62427631501229, 68.446959833945, 72.89198583172214, 62.99530852225519, 0.9599999158132462, 0.12150212701770569, 1.264883604261183, 3.2961260214928663, 2.044040375659543, 3.552137406602983, 6.100301511826054, 54.78419134693762, 66.13917842988046, 68.44515554366573, 62.36510130666918, 59.27645837107013, 53.55657969751666, 52.198137390998106, 53.84299508986935, 59.70474197018532, 60.96811779083745, 63.03805059002292, 63.51380663533365, 65.27606479583248, 64.1344471900694, 62.358731377509336, 61.19079859026017, 65.06119735779302, 62.77335728368452, 59.54957692853866, 56.52626499052971, 56.41714465233588, 52.3688389408973, 47.54958352734966, 47.535298255182084, 46.51155571783743, 45.109229933831, 45.68502995275682, 48.38219288856753, 53.37463663470361, 56.12582629726779, 56.37841516925443, 60.12792648807649, 59.227169867484804, 60.23778030949255, 63.56957489444364, 58.1634230767527, 49.77568941731607, 42.865802857183645, 43.22476640824349, 44.5208744079836, 44.99365729670371, 43.463026861990656, 43.74701822957685, 44.79237302657097, 46.28281093412831, 49.1550253283593, 53.04851116672639, 50.700647061870946, 54.27560114091443, 52.86652888021162, 53.942250667079804, 54.759754980764086, 55.10806145206575, 54.47872500265799, 56.52349971955823, 55.153419740738414, 57.44802982576432, 56.90641326289023, 56.42859405086887, 57.235335380800315, 58.31032368444628, 58.53817809012629, 48.42024380160917, 40.13671967291063, 38.18965119700278, 46.42689135766799, 51.318357606087964, 47.67460123185189, 41.349610667074884, 48.79362990779262, 55.893217978938935, 55.08568433023269, 53.73230188123642, 52.50607090611612, 53.24661831701956, 53.53571661057011, 55.24310865709859, 55.70994523263747, 54.41122101199243, 52.05311167624689, 54.06095727797478, 54.72243755094467, 53.01535929402998, 55.47463440125989, 52.26739468113069, 50.852721275821814, 47.33963474150627, 44.51463391703945, 43.38428920315158, 42.90544233014507, 40.71705395175565, 42.61818362820534, 45.28186128985497, 43.425411332038145, 45.931492082534305, 51.077445630104314, 56.26760036714616, 56.55882458533011, 53.765944050204375, 51.633731857422866, 47.99555309357182, 53.67674543011574, 55.76914164327807, 64.00058061845841, 62.776236303391, 58.79403037409629, 59.80728057123, 54.77585238795127, 49.89016771316529, 46.781363794880534, 46.6747223946356, 48.21908896969211, 50.427555960993615, 52.45606068641909, 55.943671426465436, 52.94805142187303, 54.710031094089636, 57.244478425671986, 64.32827503450456, 64.18142149525305, 65.59748734197309, 69.29622357891452, 68.22525178232502, 67.1391474816107, 68.73871357210221, 70.38206900319746, 68.29175164622646, 69.79357227202385, 70.46608617228847, 73.09056758880615, 73.75385607442549, 81.54818611760294, 84.93760032038536, 3.096557543162377, 0.2285236907341788, 0.3055571103768964, 3.0366232366331163, 56.56213506575554, 78.99614303342759, 75.20563510156448, 79.09466512741582, 57.803039627690474, 36.428416775118926, 31.819147409931308, 44.90010876809397, 59.40002087623843, 86.44641060982981, 12.58663877364128, 0.6217083587281166, 0.09032814778507718, 0.05924295814287278, 0.09401689944488388, 0.21895010444906451, 0.11945989749003803, 0.2498346480030206, 0.2254020816255962, 0.1547083613132277, 0.4918440142946859, 0.55276675810737, 16.925839224169334, 91.33114214866393, 60.872274675676906, 42.099050091158965, 43.6728265977675, 56.51844378440612, 62.84059455317836, 77.30888059062343, 79.35291397956111, 69.4498549738238, 2.0188857254482087, 0.26346143695615953, 6.576667975994849, 13.078267670446827, 6.194265321377785, 7.514645438040457, 8.432823265752486, 58.927473329728656, 68.18132123639508, 72.77143570684618, 65.81545737481886, 62.98606349575905, 56.27804956128521, 53.67827123211276, 55.96305577985702, 63.57529763252505, 63.08677427230343, 67.60872579390004, 65.79808519732568, 68.48073144112864, 66.48833213313934, 63.6742276530112, 62.3032533737921, 66.98508462598248, 65.29803399116763, 62.46092480997886, 57.61928835222798, 59.436487151730454, 52.73858116519067, 50.649801377327215, 52.67932591899749, 49.69950522145918, 46.7657409944842, 49.07796252158381, 50.68873090128745, 57.953580194903964, 57.22469006815265, 59.35341527385097, 62.296353924658995, 63.23927210223291, 62.904097726268155, 65.92813138038882, 60.038272873047866, 53.77958605366369, 46.335107895635794, 45.31814713631907, 47.75268385487218, 47.955203671609205, 45.38566289409515, 45.45861113455988, 46.60617505350421, 48.877435268894324, 51.48712150512203, 53.9764537349824, 54.713474935100926, 56.642355380519746, 56.957184422400694, 56.831299874090384, 58.63451934629872, 59.19631650370937, 55.964118742173724, 59.55703727660641, 58.318270406415394, 59.66528292625182, 58.196594561299975, 61.7658180575217, 62.3689099281065, 60.26068695129887, 61.78327260478851, 49.58495240057669, 41.3030364436488, 41.226114842199514, 47.80064659733927, 55.320006724326845, 49.602540308429354, 44.154136719242224, 50.81638051617531, 58.15031843800699, 57.20867503073908, 57.69977538816391, 54.94999385649159, 56.37841516925443, 56.06642592337824, 59.37248975999894, 59.095539046872055, 57.81861535964474, 54.41129945939588, 57.07168625247095, 57.514200210571296, 55.92715432566982, 56.896317082066695, 55.154510159646314, 52.76040915519961, 50.26427553546045, 48.80828780512656, 44.80701131205405, 45.43818343070246, 43.409188409005445, 44.21859302828389, 48.3044122880505, 45.73415371679491, 47.05863614236155, 53.21540801755844, 59.04809797963789, 59.97174555255521, 55.93791338705248, 55.2092311459203, 50.89063490590742, 56.455850601196296, 58.29292405036188, 66.44353082103115, 66.44956342635616, 61.85743285763649, 60.01897873417024, 57.56134317767236, 52.48746710438883, 49.60141851056007, 49.15954389879781, 49.6068980616908, 52.06087012444773, 54.00160005015712, 57.21229145603796, 55.801509041940015, 57.13605626936882, 59.306986178121264, 67.87984002021052, 67.07315752583166, 67.80236536456694, 72.36040269174885, 68.89411003358903, 69.9017983098184, 73.72195151544386, 73.15723219225484, 71.35213390473398, 73.10021661943006, 75.10235125018706, 75.47418409778227, 79.6183172349007, 81.50049009630757, 89.25548661139705, 3.7117050636199216, 0.32066856240553243, 0.5778732979970594, 5.4714122126179365, 59.12082656737297, 89.36890586729973, 80.95223688310193, 90.89822230800506, 62.86568203280049, 61.64024729882518, 60.38133121305897, 50.23113150750437, 70.50757700397124, 98.62306364120977, 16.181735204112147, 0.7667243288409326, 0.4667534396773385, 0.19776762012512455, 0.35387295809003616], [0.08466568550155049, 0.11323279010192042, 0.06679470816086377, 0.05879428725869906, 0.11647723374828217, 0.03499340250967972, 0.11463217226968658, 6.3108229637146005, 66.39428154114755, 37.449864725912775, 64.78716488807433, 36.7710397320409, 28.94128872502235, 47.34231764270414, 63.39798296651533, 66.18775306209442, 68.84462541149509, 3.715679895493292, 0.25970705454387977, 0.43282717466354376, 4.093836339250688, 0.29035489225099165, 3.987872038156756, 4.707790478583306, 50.64073677985899, 64.53947897880309, 63.96612259649462, 59.56235993293024, 53.346340656280525, 51.19702692954771, 55.50759015544769, 58.89626695263771, 57.83229658680578, 61.09196662902833, 63.215341721811605, 61.361857075845045, 57.222179751242365, 61.168903919958304, 63.79331865618306, 59.35821233257171, 56.181335679946415, 55.385918232702444, 53.042906099750155, 50.97253399510538, 48.57052157002111, 45.705006584044426, 45.15758883568549, 44.84860804773147, 44.45936772131151, 43.846407167373165, 45.31855114044682, 50.289421850635165, 51.23906297068442, 50.0911303489439, 55.66052729083646, 56.660178630582756, 56.6568563830468, 57.26830290209863, 59.9905768517525, 51.71433264209379, 45.20857180318525, 43.805332106928674, 43.54524366317257, 43.0353629973627, 41.1902133880123, 41.03111813145299, 39.81750149880686, 43.08780900893673, 43.75167408297139, 44.60263621422553, 47.34128605934882, 49.176429702389626, 51.509314275557, 51.40210020926691, 55.86381196975709, 53.8046343095841, 52.380429544756495, 49.70110554848948, 50.16431393161897, 50.648765871601725, 51.84964656829835, 55.902541452838534, 54.559400312362186, 56.586783239918375, 53.345375753218136, 57.82745638201314, 51.47991218874532, 38.28610227954003, 44.34377939470353, 46.721888895957704, 45.63651807846562, 45.472778735622285, 48.015106108880815, 50.808810341742735, 54.38901647444695, 52.53688112381966, 54.820194782749304, 52.118144573703894, 53.126770296404445, 51.55781830510786, 49.22080347614904, 53.52567926529915, 50.76119669022099, 50.383217488565755, 51.27951829664169, 51.18550300598145, 51.805668953926336, 49.31367735708914, 47.515992349193944, 48.99238032679404, 39.17032610985541, 40.711095871463904, 40.313991192848455, 41.080692968060895, 38.979165477137414, 40.75175516067013, 38.686764547901774, 39.94085611835603, 46.50537798481603, 53.16902991264097, 55.19633047042355, 57.66707066566714, 54.634462710349794, 52.60747986455118, 49.52651300737935, 50.415059289624615, 50.28535435276647, 54.51280647708524, 57.38886871645528, 57.10698758402179, 56.592223567347375, 56.134322151061035, 57.809582141137895, 53.743374732232866, 48.05583600075015, 46.029284615670484, 44.660651991444254, 45.834476178692235, 45.56652730511081, 46.93157096062937, 50.75055137757332, 50.14897746424521, 53.33613464909216, 59.680603704144886, 63.68369625460718, 65.84613030956638, 65.17364386589297, 66.6891731754426, 67.00146444382207, 67.03997427417387, 68.54315988479122, 69.23490908838087, 70.17357149431783, 67.32820572391634, 77.1861025594896, 74.68867455759357, 64.41596746444702, 2.448103706682882, 0.2967436365302532, 0.4451780135352766, 1.6386055633906396, 49.528552639868956, 68.9117685441048, 68.0761311131139, 75.77069959332867, 40.28870759471771, 68.1849298169536, 40.14400351432062, 37.47950215493479, 57.48826549899194, 70.63809779382521, 8.905266869452692, 0.19176175126865988, 0.14557213462408514, 0.117628104654291, 0.09884405776017136, 0.12186958875146606, 0.03728069973388507, 0.04347296161276679, 0.04740834378847673, 0.09845192799524916, 0.09731358262680231, 0.2346119600077791, 11.473530915475662, 78.14863651029526, 46.783854499939956, 60.65654039382935, 31.534236246539702, 36.41304892878379, 53.84699198507494, 70.51470002820416, 72.19032087633687, 75.0478930627146, 4.996256780239844, 0.40184330014932546, 0.7965836782128581, 3.6724695947862442, 0.8012638625598724, 4.232123176897726, 5.03564178943634, 52.26871651987876, 68.92095473504835, 66.4472492279545, 62.04760505307106, 56.16698764985608, 54.472476666973485, 56.5324152669599, 59.60394490149714, 61.46924372642272, 64.0443346577306, 66.89591346248504, 61.73918124168151, 60.68449904841762, 61.52871470297537, 65.73125977669993, 61.56972308312694, 58.009077810472064, 58.086595612187544, 54.61101478145969, 54.051904447617076, 49.48365326850645, 46.8367672735645, 47.94271092261038, 47.2836232954456, 47.19423640158869, 47.66954529669977, 47.694624931581565, 52.99570037472633, 52.77439240486392, 56.04835164162421, 59.75274785872429, 59.774007105058246, 58.3068484644736, 60.09167986531412, 60.79298004027336, 54.670081753884595, 45.907514633670935, 44.49331191278274, 45.12897122290827, 45.39013439609159, 44.259801449314246, 43.8444616717677, 42.78837134761196, 46.06774737758022, 46.315547035586455, 45.25043133766421, 49.27968609717585, 51.9551504811933, 53.12618978561894, 55.2000488773469, 56.404349880833784, 55.29494670129592, 55.67333382944907, 53.37216554149505, 51.77178752037787, 53.18617851503434, 54.898355853173044, 58.4869009448636, 55.57558836475496, 57.114514612382465, 55.57928323745728, 60.791301265839614, 52.13498723122382, 40.07831950341502, 47.024484065271196, 49.106580134361025, 49.02217072825278, 48.11309868289579, 46.842423331352975, 53.8006531038592, 55.86216065191454, 54.67631047771823, 56.99069323078279, 54.7601785967427, 55.544268238929014, 52.66795889023812, 53.1389178768281, 54.89077783400013, 54.26264555223527, 51.58469830789874, 52.41112601372504, 52.589268299841116, 54.2391074088312, 53.107197669244584, 49.333854029255534, 49.387229642560406, 41.85159167935772, 43.06558093717022, 42.21758411776635, 45.218028637670706, 41.15359806245373, 42.548428197060865, 40.42890094941662, 41.320851848971465, 48.77371603442777, 56.11088598928144, 56.5337331833378, 59.957370065873675, 56.65906467745381, 53.5050436758226, 52.387560413729766, 52.13214351284889, 54.303959877260276, 60.10259582150368, 59.50240650484639, 59.21118228666244, 57.957126017539736, 57.50579457129202, 62.396421432495124, 54.86648659552298, 50.0132320773217, 48.05250590847385, 47.65680151600992, 47.760967900676114, 48.76040351006293, 48.58873705710135, 50.730900303010024, 52.41846084594727, 57.132930140341486, 62.92145813665083, 66.08524584001111, 67.99921343403479, 68.62844790181806, 69.29412118850216, 68.08945148221909, 70.18467964664583, 71.57785061867007, 71.5128412554341, 73.23670725668632, 70.90736066141437, 82.1088340205531, 76.14499568939209, 66.42802961411016, 2.7024748056165637, 0.26916278586272274, 0.686875842511654, 3.38184378320171, 58.00102910687847, 75.56609307565998, 76.31053540014452, 80.44918506376206, 49.086878068985484, 58.00637921979351, 32.22676011823839, 46.47109254713982, 61.4838820119058, 85.5071206246653, 10.75046354724515, 0.2804390485248258, 0.20085596569603492, 0.11159829555019257, 0.04473711010969935, 0.14183030073200503, 0.25300225303057705, 0.16196696778699277, 0.1976147855842306, 0.17042974190365884, 0.21077467459103755, 0.26358918977841256, 18.107198284518336, 93.18488567106186, 52.988153734514796, 86.08905130817045, 51.73021431892149, 45.16371950026482, 62.80471271084201, 77.1345704601657, 76.66226217823645, 85.1046540660243, 5.977900518525032, 0.6078561407423789, 2.912429720163346, 9.28084263878484, 2.1161505772221476, 8.135260497370075, 6.977163543624263, 57.94310354417371, 73.23895085242488, 71.39423662616362, 64.74334809087938, 59.56771789058563, 56.01579596919399, 60.701000459732555, 64.55583526242164, 63.82958096842613, 65.7415363865514, 68.71846629727271, 66.25677108764648, 62.61714104683169, 65.24365425109863, 69.16202360583891, 64.81488820045226, 59.24742498705464, 61.32621057571904, 58.03181579036098, 56.396932678837935, 54.603350470142985, 48.41866700879989, 50.83296037489369, 50.17906988820722, 50.23031565450853, 49.17675525911393, 49.447900864385794, 54.775942602465236, 55.056717626510135, 59.01287509549049, 62.617364621931515, 61.39192596558602, 60.521438275614095, 64.09651394813292, 66.32363965434413, 56.649007720331994, 48.46737500159971, 47.53044236090876, 46.89518705491097, 48.77647738302908, 47.01427413571266, 45.24881532115322, 44.80904309980331, 47.3509664689341, 48.52580262768654, 47.22185380997197, 50.94742690363238, 53.82728207495905, 55.505507376886186, 57.60777619577224, 61.211402800775346, 58.59586046588037, 58.088678390749045, 56.18673286130352, 54.96626777033652, 56.46274612795923, 57.310872385578776, 61.36741507437922, 58.831669438269834, 60.63554002392677, 57.09840936045493, 62.3148988908337, 53.047660012399, 40.942288214160556, 48.21775144146335, 51.436770039220015, 52.50393321437221, 51.84435529093589, 46.8693111788842, 56.91625841202275, 58.992227738903416, 57.28272937959241, 59.08427792210733, 57.54254717980662, 58.11247148821431, 55.07436044754521, 54.88779683266917, 57.125481559384255, 54.95350045542563, 54.24611668432913, 54.40904801891696, 56.948143359153505, 56.865098937865234, 55.10867334181263, 52.12256116251792, 52.747673219250096, 45.91827761742377, 46.28870625649729, 43.52560043334962, 47.13130197217388, 44.139604337753795, 45.625974747442434, 43.12078045260522, 41.62968750922911, 51.46912174840128, 57.333818251086825, 59.9044612146193, 63.95306894856115, 59.415467169977006, 57.4039266955468, 54.54558180224512, 56.12710498994397, 55.82125425338746, 62.28979572173088, 60.68327526892386, 63.35055758876186, 60.79630621017949, 62.04981334747807, 64.69394583855906, 59.043606865790586, 52.931247988054835, 50.66444358518047, 48.74901294708253, 50.82651592070057, 51.155995015175115, 52.59730131395402, 54.92366298552483, 57.564426160627804, 60.6106565075536, 65.43285762110065, 68.36444885500016, 70.67485824708017, 71.14481310690604, 70.07917573375087, 72.01556359567951, 72.11419551603257, 76.23316272612541, 73.46554617727958, 78.34234668362525, 72.67162707544142, 87.91575401060044, 76.00151538848877, 67.16075189651983, 4.120621960009299, 0.3714230211992418, 1.2207104842508993, 5.7337873981845, 64.83832828460201, 85.9480970136581, 83.29790838303106, 90.37771594139838, 55.104413647805494, 82.00936271298318, 53.99277863963958, 56.225391741721864, 73.13936187374976, 99.5236869012156, 13.439843520041435, 0.48383625043976697, 0.23948620974777207, 0.25858004727671224, 0.17408177496925478], [0.01439239519963702, 0.016822541966253234, 0.04072896490294126, 0.022352846421962305, 0.04049550726889603, 0.05144101146969104, 0.09236202695437017, 12.54830741113232, 55.842995951252604, 42.03826904296875, 41.24737408853347, 18.519358981040217, 32.70607767566558, 42.55670832049462, 65.48149893360754, 62.910404897505245, 77.29462669741723, 11.229969378440611, 0.36553456297805237, 0.0684086868779794, 1.0631968008895074, 0.2678854721448114, 4.376679678117076, 3.1882054382754914, 43.42737643949447, 67.9440256857103, 61.04655734954342, 59.3664179309722, 57.41375223282845, 60.22775865370228, 58.53094916189871, 63.62486462439261, 59.68687949642059, 63.60571561321136, 58.60543104910082, 56.936913613350164, 59.79150479839694, 60.192061162764034, 59.53162424025997, 58.01083503230926, 53.926576875871234, 51.65107265595467, 46.68051965775029, 45.52944521750174, 45.18687717376217, 43.510879778092914, 44.38072419935658, 44.01722638837753, 42.152555142679525, 47.50650021337694, 54.06870788143527, 59.260098165081395, 61.59923891867361, 62.37758621092766, 55.54802194718392, 52.70480955800703, 58.40482142663772, 56.50200905338411, 52.26710442573794, 47.585002530005674, 45.912547034602014, 43.21103419027021, 44.47191146112258, 42.87610692362632, 42.19534820125949, 38.867628958917436, 40.20769496117869, 42.189225381420506, 43.58724048060756, 41.59875177568005, 43.37053345095727, 46.764517214990434, 49.58814913226713, 49.881389448719645, 51.17029597682338, 51.03360137631817, 49.95504763818557, 48.44025573422832, 47.64366157593266, 52.5242942379367, 55.646618566205426, 53.94687121914279, 53.410345892752375, 53.89274251076483, 57.87264600876839, 56.617840566942775, 57.0629511340972, 41.363535081186605, 44.64802588185957, 46.68055103671166, 42.64089807387322, 41.03890795861521, 51.32808508411531, 56.34799718856812, 53.272925653765284, 55.080773522776944, 53.49831681097708, 54.791294759319676, 49.1233443444775, 52.57424562208114, 51.134504349001, 52.82743069433397, 52.428498191218225, 52.66251071806877, 49.42074237331268, 49.15266798388574, 48.34278875781644, 49.28690325829291, 46.980145592843336, 44.19802411910027, 38.006394140182, 40.144874280498875, 40.92293523973034, 40.20723604386853, 38.90649964732509, 39.7829532623291, 39.37171236161263, 41.84395482463222, 46.37844224129954, 54.05649754308886, 57.413650251203975, 54.71285912298388, 57.99009746120822, 56.01144606067289, 52.16506788807531, 49.296520909955426, 49.09696640506868, 47.714362298288655, 54.029586161336596, 56.34067804582658, 55.73413056711997, 57.735790591086115, 57.68121473250851, 56.22163411109679, 54.20626932574857, 54.494830254585516, 50.930933337057795, 46.57536483580067, 45.034952009877856, 44.525706768035896, 47.03567458737282, 50.337255154886556, 50.27878438272784, 56.71650386625721, 60.189829334135986, 63.44836188900856, 65.49969088646674, 65.6258107769874, 67.84544867853965, 68.79692154545938, 68.63077778970042, 69.54512934530936, 71.36175155639648, 65.99501563656715, 77.64578865420434, 55.048374745153616, 38.44098883290445, 1.00028651856607, 0.13614375264413897, 0.9652846354630686, 3.2652947210496475, 60.06414874907463, 67.56628574863558, 71.80686212355091, 70.43163207269484, 42.9220300336038, 72.89643379949754, 49.99834668251776, 33.023995584057225, 49.906563220485566, 78.34670051451653, 7.073961265625493, 0.4416239477934376, 0.1862237476293118, 0.05606096215365876, 0.08618957227877072, 0.013541338548454787, 0.06935655214493314, 0.05070646721569281, 0.07476038314522275, 0.08207912752104383, 0.02510846660081898, 0.11268771854379486, 16.760168114016135, 70.12292585065289, 49.767272010926284, 52.52447466696463, 25.447698331648304, 41.61221335011144, 50.40084462012015, 72.80408551616054, 67.62763946287095, 83.84161164683681, 12.140057317672238, 0.38998943783583184, 0.2809923172237412, 4.090677360373159, 0.5390532939664779, 3.010043295160417, 3.460753045735821, 46.981694929061405, 69.16924076695597, 63.099168962047955, 63.83138133633522, 58.68558860594227, 63.3694241892907, 61.041807359264745, 65.67908048629761, 61.96555691380655, 65.53059916342458, 61.02456854235742, 60.207821246116396, 61.40841168742026, 60.262251976997625, 59.79170876164591, 61.221408767084924, 56.676762411671305, 54.170360026821015, 48.03859718384282, 48.05425136320053, 46.04436220661287, 47.48864950672273, 48.89086938673451, 44.892491525219334, 45.680209359815045, 49.24036433619838, 56.39702681572207, 60.94233605169482, 64.59875383684712, 61.88692123659196, 53.95562987173758, 52.71641585134691, 58.96721870668473, 57.46501368861045, 55.79764942969046, 49.49187455638763, 45.619039996977776, 44.03945446014405, 46.602174235928445, 45.85735928627753, 44.157243236418694, 40.65288397573656, 41.9817163098243, 43.37651506547005, 44.103793098080544, 43.30478668212891, 46.0659783886325, 50.806335326164, 49.958224758025146, 53.09984322517149, 54.61711014470747, 54.46545954673521, 52.44909847936323, 51.44144942683559, 51.508725920031154, 54.55803924991239, 55.46636996730682, 54.52721334272816, 56.565229815821496, 56.260457731062374, 59.16336859426191, 58.79757227436189, 59.55309137221306, 43.879158958312004, 43.85894306244389, 50.36683767072616, 45.38152479356336, 43.98555324923608, 53.487804858915275, 59.44355134041079, 53.49887378754155, 57.564853698976584, 55.11663575326243, 56.45437971238167, 51.7644723000065, 53.98767955841557, 52.98472166061402, 57.02698299961706, 54.01333970408286, 54.55405019944715, 51.25933770210513, 52.83113733414681, 50.57476643593081, 52.34991350481587, 48.9056331880631, 44.70484925854591, 40.111032070652136, 40.90969724039878, 43.17426981464509, 42.216948693798436, 42.21901970524942, 43.25023828014251, 40.45578487457768, 45.06516602731521, 47.35369251620385, 58.26707170855615, 58.02694420660696, 59.02889405527423, 60.42597955273044, 57.8364739110393, 53.180844091599994, 52.49908124246905, 51.90972943459788, 53.28646567560012, 57.70417628749725, 58.82422085731261, 57.672181514001664, 59.641383924791896, 59.36552363057291, 60.48164975258612, 57.475196161577784, 56.71554288556499, 53.48028175292477, 49.50756011470672, 47.276072732863895, 47.62004498512515, 48.037118450287856, 51.543799754112, 51.8912511487161, 59.10751796537831, 61.90973766388432, 67.0108389085339, 68.29408937884916, 68.88191930709347, 70.21913374623945, 71.53441429138184, 72.05757218022501, 72.09243420631655, 75.6153658897646, 68.3065782054778, 78.33338014541134, 58.651997427786554, 43.18063189906459, 1.2442657880244719, 0.2293898450631288, 1.1599654728366484, 5.285414889935525, 67.51931928819226, 73.23307514190674, 79.01054597670033, 76.49466714551373, 51.30267204776887, 89.29529866864605, 53.192736717962454, 38.557090990005, 61.50928720351189, 86.37684345245363, 9.994206063209042, 0.4632427651555308, 0.14158306883708124, 0.0866210713021217, 0.03114515708969726, 0.12209334771238989, 0.18486426332064215, 0.19480347272849854, 0.1516882128893368, 0.16389925603664693, 0.13144809332105423, 0.23797268047928813, 26.35257147973584, 81.49484188325944, 59.16237231223815, 60.0420226589326, 28.816461255473477, 51.46403835665796, 58.496463683343705, 79.144314489057, 70.99912843396588, 92.86474181759743, 14.880304548048205, 0.44860126210316537, 0.3922759651416733, 4.901052521121118, 2.2340513861948446, 7.651594992606872, 5.477338423652034, 49.92941102673931, 73.10635905111991, 65.73867305632561, 65.74687080998575, 63.58756288405388, 65.38798570632935, 63.42546701431275, 68.5431363505702, 63.80856098667268, 68.76564456570533, 67.6058703084146, 60.408356343546224, 62.91164436647969, 65.35219407850697, 64.94722112532585, 64.67194134189238, 60.418923208790446, 57.57070979764385, 51.1347867596534, 50.665702666005785, 48.94631601149037, 51.83252542249618, 50.645698578126975, 48.49807539293843, 48.09322011086249, 51.42895275546659, 59.39438835267098, 68.33473297857469, 67.58929437206638, 60.36532009801557, 56.074811950806655, 54.07838044628021, 62.645464481845984, 59.22156480050857, 56.72235604255431, 50.71310058716805, 49.04201792132471, 46.23749186915737, 49.07629551426057, 48.871143787137925, 46.574737256573094, 41.247883996655865, 44.7349730614693, 46.94904119737687, 46.65493403711627, 46.72856084762081, 46.77484089328397, 53.561278696983095, 53.186421701985026, 56.283901737582305, 56.33937974129954, 58.655653076787154, 55.46801344040902, 53.45879108675065, 52.90709795490388, 58.23135460576704, 59.84826541716053, 58.51171778094385, 59.47752298847322, 60.579340304097826, 62.54704436948223, 61.964442960677616, 61.678502175115774, 44.450605146346554, 46.12895988648938, 49.90624550850161, 49.848943602654245, 45.08355017631285, 54.80321484227335, 59.60061873159101, 55.4651540325534, 61.3322941718563, 61.67312460560953, 61.335165346822436, 55.3211049879751, 53.891918813028646, 54.52467949159684, 59.930058602363836, 58.57322446761593, 57.38513069768106, 55.25449529770882, 54.970700048631244, 53.62535061374788, 54.101220407793605, 50.36404886553365, 48.66363471554172, 42.2661469828698, 44.4444352580655, 45.745763932504964, 44.111245601407944, 42.716615507679606, 45.294373650704664, 42.607334352308705, 48.11331441325527, 52.248073085661865, 60.114347242539935, 62.6357566156695, 60.87824452307917, 64.31497819962041, 61.10775809134207, 58.07381653016614, 56.140225318170366, 56.676440777317175, 54.48469092769008, 58.8701557344006, 61.626193446497766, 60.29559996820266, 62.28072720189249, 63.79749598041658, 62.155329027483546, 60.92850185209706, 60.893169141584835, 56.758006465050485, 53.42607067477319, 50.54352083513814, 49.12732162783223, 51.10119558149769, 55.119083312249955, 54.779245238150324, 63.05502268575854, 66.05644779820597, 68.84163656542378, 70.82379064252301, 71.67751804474862, 71.47187602135443, 73.15178009771532, 74.15964880297261, 75.169431624874, 75.9317050441619, 72.23557718338506, 83.98385247876568, 57.31133130288894, 49.33476401913551, 1.8747203580794798, 0.22663388972080525, 2.3664816348783435, 8.842295177521246, 76.78840560297813, 82.82837713918379, 85.71521805178735, 83.84435730595743, 60.240588726535925, 85.84186353991109, 64.83633964292466, 51.2782709829269, 69.34715947797223, 102.24759255686115, 12.970248537678874, 0.9395069412646756, 0.3728755851907115, 0.15180922413785614, 0.3035422684925218], [0.06742264744975875, 0.07477622584349687, 0.06938754806234952, 0.010432001210809236, 0.12245903212216594, 0.12050597522888454, 0.019201137718834707, 19.017598052178663, 56.435528801333525, 41.60103459512034, 33.27190506842829, 16.063652250074572, 19.903926234091482, 36.04414216933712, 69.82076214205834, 59.88721063060146, 72.02034104254939, 28.43082754842697, 0.13525804775136133, 0.4308760406509523, 1.8706256487677175, 0.23730500420976072, 2.106342935754407, 0.7759606525782616, 30.719642331523282, 64.47262610158613, 58.51996652541622, 60.00634085747504, 58.26111755063457, 64.07644317996117, 62.16219709765527, 63.162409336336204, 59.13128360625237, 57.97345484456709, 58.71228425733505, 59.4264066603876, 58.16434483374319, 53.91642578186528, 54.526526927948005, 54.448997359122004, 50.12008528555594, 47.741979706671934, 45.26503039944557, 46.13412564800632, 47.68676057938607, 45.65754198258924, 44.89978321136967, 42.872290457448656, 46.318524114547245, 49.17341339972712, 58.924802195641306, 40.64325063459335, 48.95845574717368, 63.42483159034484, 45.30546611355197, 52.779993549469985, 57.818925226888354, 57.70830262091852, 52.951020656093476, 47.811382124500895, 44.24000916942474, 41.761490914129446, 44.942819456900324, 44.40978111759309, 37.303458336860906, 38.361117609085575, 38.73349566613474, 39.071960910674065, 42.8961149338753, 44.40277968683551, 44.83517785226145, 45.7142476881704, 47.058216448753114, 50.78380915426439, 51.15621859027494, 51.038825973387695, 48.46777116098712, 47.52331541430566, 50.68906822512227, 53.12399718069261, 53.178208258844194, 52.81054881311233, 53.37174192551644, 53.70082093823341, 56.81695576637023, 55.98568785575129, 57.13740164233793, 44.20000491603729, 41.08874167165449, 47.096063398545795, 40.68826767706102, 43.334220147901966, 52.917107843583636, 56.03004986240018, 53.913935076805856, 54.49453215445242, 54.030958990896906, 51.29350546867617, 50.44188830160326, 52.60261612553751, 49.20703203447404, 49.66335273558094, 50.59727299597956, 51.837455841802786, 50.428552243017386, 50.254818700974994, 48.10365361552085, 45.92252162195022, 44.79132183136479, 42.96750207101145, 37.8477224996013, 39.680324446770456, 42.04319161753501, 38.211075182883974, 41.17094670572589, 40.684855215011105, 41.570855879014545, 40.98317892320695, 43.080650683372255, 53.24031114578248, 57.857537038864635, 56.97710614050589, 55.155545665371804, 54.96771120255994, 56.42780173209406, 49.14292481637771, 51.58997781815068, 45.41300573656636, 48.03867170887609, 55.42775815533054, 57.852402656309074, 60.46672513408046, 57.76351782583422, 57.20748655257687, 55.66695997791906, 56.238566983130674, 56.06068357344597, 56.53278004738593, 50.17212729300223, 48.71275063483946, 47.75737893196845, 49.07886466672344, 45.890240515432055, 51.52503121283747, 56.324549259678015, 61.467360988740005, 63.20826968839092, 66.89651750749158, 67.4949456799415, 69.48579172934257, 66.08577928235455, 72.09364229632963, 74.60501040181806, 72.75802904559721, 60.66446358157743, 75.62198685061547, 48.35686222199471, 0.20568428080408804, 0.06759265768191508, 0.6022555477196171, 4.832327202443154, 65.58390025169619, 63.59089297633018, 75.87689384337395, 67.95512599329795, 46.28039867647233, 36.48585988629249, 40.20221541004796, 59.18836193699991, 51.76473117643788, 70.85882525290214, 5.354766807248516, 0.4854531862562703, 0.138894927597815, 0.036642582966916026, 0.09347991777523872, 0.046656443812553926, 0.08891779523823531, 0.0387252121412706, 0.014663838345797793, 0.12794406078155005, 0.04445771401327464, 0.07378186670041854, 26.327740915359993, 66.46308775871032, 48.75694005720077, 44.24129178447109, 19.710041515288815, 27.496026715924664, 43.71309757232667, 76.3888886667067, 67.38773161365141, 78.45172589825046, 31.79195361752664, 0.1281910551892173, 0.27451155046301506, 3.5975390864956767, 1.0286806788175338, 2.0860054464109483, 1.429266828683115, 33.100473957677046, 68.47134913167646, 61.633536123460345, 62.58440494537354, 62.05857200007286, 66.26125827912362, 65.89537958944997, 64.71276929301601, 62.80339479446412, 58.36753929814985, 60.8119172434653, 61.77456494300597, 57.76102319840462, 57.96505705002816, 58.32320082572199, 56.085437651603456, 52.59498711555235, 50.251304257300596, 46.95247327127765, 49.53970393826885, 50.57994788692844, 49.12001032983103, 46.7702321083315, 43.83728373435236, 48.594695137393096, 51.46703896983978, 62.86416407554381, 41.92828186096684, 47.374504612338164, 63.44652229739774, 46.46084339387956, 55.22278293486565, 58.93572207420104, 59.10128924154467, 55.74462682970109, 49.455349445343025, 45.73890762944376, 44.057650335373424, 46.53566652728666, 45.21100367269209, 39.30217266082764, 39.56508913347798, 39.69101290549002, 41.83587866444742, 43.8325455111842, 47.1934127038525, 47.12354744634321, 48.194436873159106, 49.537558401784594, 52.193038309774096, 52.160804271698005, 55.12383722489881, 49.99160805056172, 46.781897237223966, 52.35305140095373, 56.459565085749475, 55.29775904070947, 56.697084211534076, 58.35140658963112, 56.146234389274355, 57.44381327782908, 58.70396491019957, 59.46907028075188, 44.62618220236994, 42.28844957966959, 50.10423891005978, 43.549621028284875, 45.90292153819915, 53.636764710949315, 58.14906327955185, 52.98718490908223, 57.32140394949145, 55.049018013861875, 54.53186527375252, 54.35087926926152, 54.76331649288055, 51.09251145393618, 51.77700427270705, 52.61899986574727, 52.46137942037275, 53.53286504745484, 52.396742682303156, 51.26421713059949, 48.094655698345555, 46.55851825591057, 45.35747674203689, 40.64995788758801, 42.43019619295674, 42.65986273365636, 40.25819939951743, 43.207511901855476, 43.16220460399505, 43.815138032359464, 45.205445674157914, 43.80346898109683, 55.44160019966864, 57.629443368604115, 59.82008318747244, 57.579491984459665, 58.05707193190052, 58.477510790671076, 53.13292841757498, 53.77564014927034, 49.099159009995006, 54.50089816124209, 57.54141361482682, 59.15714379279845, 63.14861436044017, 60.87848771002985, 62.21115612214612, 59.2205253724129, 60.637014835111565, 57.459290950529045, 58.49665195711198, 52.439049366981756, 51.5932059288025, 51.25997312607304, 51.728406106272054, 48.47572572769658, 53.129500266044374, 58.87649428459906, 65.09575343901112, 65.86243168000253, 69.60543186433854, 69.81494918946298, 69.5729781735328, 69.47879422095515, 74.42732703301215, 74.40627959466751, 76.96601836912095, 64.17449458952873, 76.12717243932909, 49.47043095865558, 0.223114206005008, 0.016697416825580503, 0.8222506880279511, 7.116420922740814, 72.76197494999056, 70.60474195787984, 82.65280400553058, 75.80460456109817, 50.92922710603284, 57.84831946895969, 46.56586485524332, 51.53818684239542, 59.96230048518027, 83.70136337895548, 8.679763924690986, 0.6639487921230255, 0.1553111039702931, 0.06007105322374452, 0.10923666098425466, 0.12294538304089539, 0.14530670048008043, 0.14385157775494362, 0.08831289221322344, 0.19392184342347807, 0.30973648772605006, 0.33020657156744315, 36.37235433824601, 82.40447874992125, 59.04257920480544, 47.51985196144351, 26.80535420294731, 35.78439497178601, 50.140716952662316, 85.08355955923759, 71.77157648148076, 86.6240704444147, 35.594061959174375, 0.19293530603810666, 0.5782662704586983, 6.875251050918334, 2.6262050530602856, 5.302552215514645, 2.3594375483451353, 36.853731140013664, 71.61368539256435, 64.56242484431114, 65.7040189158532, 66.03365882750481, 68.34770817910471, 68.20396115702968, 68.8287005885955, 64.53049675110849, 61.42531318049277, 62.104471575829294, 62.834973796721435, 61.86785067281416, 60.9651917026889, 59.593232908556544, 59.24530690716159, 56.27950476061914, 53.204641111435436, 50.72588359155963, 51.882653313298384, 53.237785139391505, 52.84778387315812, 48.803443677963756, 45.625974747442434, 52.19488966849543, 55.97974154257006, 64.4184503247661, 45.20117029067009, 50.14369010925294, 65.26581564257222, 46.417795381238385, 56.54869310317501, 65.51969889671572, 63.03209643210135, 58.46285289333713, 53.18200903554117, 48.68920856906522, 44.93334301056401, 50.724573519922075, 47.42416574108986, 39.58222989113101, 41.1447335058643, 42.34808529576948, 42.94107314079039, 47.01959679203649, 50.04348924083095, 48.704733310207246, 49.41097567158361, 53.27689901474984, 55.1622764525875, 55.036956725582, 55.3878519611974, 52.29609466368153, 51.0952296564656, 56.59533008452385, 59.38608077264602, 56.52948917881135, 59.162666490001065, 60.462657636211766, 58.7091463611972, 63.785430769766535, 61.15204557295769, 63.66143288150911, 46.71706438064576, 42.90526190111714, 50.600720759361025, 47.55009735784223, 46.32769853838029, 54.386541458868216, 60.79796537276238, 58.0205625103366, 59.13659449546569, 58.2643731178776, 58.06915283203126, 58.46400999253797, 57.636629150759795, 54.6803818979571, 53.68258191693214, 55.91861532580469, 56.277876976997625, 55.77702560732442, 56.77955204440702, 54.01182174682618, 51.08510601905085, 49.83734907642488, 48.02311558877268, 41.10965182704311, 44.36943954037082, 46.88587927049207, 42.71431307638846, 45.8943001685604, 44.75425935560658, 46.63070555656187, 45.576592106972974, 46.79619035413189, 59.52911000097952, 61.978904739502944, 62.107283915242846, 60.84302556130194, 58.753261258525235, 61.239361455363614, 56.09835401658089, 56.518749729279556, 51.90972943459788, 53.80298691411173, 61.801339041802194, 63.3942331806306, 67.36712348076605, 61.80375522182834, 62.23605140562981, 62.37952778416296, 63.00181965674124, 62.571331685589215, 62.69139935893398, 55.44648747290335, 55.24044929012176, 54.65402749276931, 56.33108000601492, 50.91944471482308, 57.320054654152166, 62.06883292044363, 68.94642660694738, 68.79874936995968, 72.60685305441581, 72.96485562478343, 73.78895344272738, 72.46826787148753, 77.55486026886972, 78.95524055727067, 79.1989609502977, 66.83822324199062, 75.1165266959898, 55.37265669914984, 0.2940452297128016, 0.14076954474852932, 1.4473506712144422, 9.269042188121427, 84.40675458600445, 77.63493937830772, 89.16118498771422, 82.53730589343657, 64.4679271021197, 59.0508161821673, 55.84052093567387, 81.46993483266523, 69.00778816592309, 97.22458177997221, 11.033546886136456, 1.1265707809117533, 0.332529901737167, 0.11775244838528096, 0.26854960908812864], [0.04888855972357335, 0.0393450308981682, 0.05265391634536847, 0.06134069457109417, 0.10036124126805414, 0.040627335678906216, 0.16408956759879667, 24.711612616815877, 62.184480082604196, 39.490422894877774, 31.51295150479963, 23.198987822378836, 50.10391727570565, 39.371716283982806, 68.70240026904692, 64.15663211576401, 70.67468566279258, 45.424788536564, 0.2556592911001175, 0.13338254193865484, 2.164852931614845, 0.09070766774276573, 0.8593610902467083, 0.4594784848872693, 18.86084641179731, 60.074876431495916, 60.44386163834603, 62.70079735786685, 62.87144399458363, 62.745963450401064, 59.05744891012869, 56.7821329639804, 58.66933038157802, 62.74998387982769, 61.59461052187028, 56.01056744975429, 54.78381479940107, 55.44501266171856, 51.48361882855816, 49.71397876739503, 48.1908243702304, 50.406520289759484, 52.19702343786917, 51.771775753267356, 52.16271446597192, 48.87534464559248, 45.54464047954929, 45.6185261664852, 50.42839142584032, 50.79978104560606, 54.987774125991336, 47.71447996939383, 34.83591487330776, 40.334567946772424, 50.16165456464214, 55.77825330918836, 56.54846168333485, 56.34056429709158, 50.85476483068159, 48.03494153484222, 41.89054865990916, 42.96305018086588, 47.15440865485899, 38.95602741549092, 42.023030634849306, 39.66865931787799, 40.30014914851035, 38.85388105146347, 41.642117500305176, 43.23992244658932, 42.330442474734404, 45.09491328270205, 47.90813130717124, 49.187573156049176, 50.08233639501756, 51.19088842022804, 51.110193498672984, 48.95777717713387, 49.12033980892551, 51.84876795737974, 52.01376638104839, 52.69075962804979, 53.95049941155219, 52.830360704852694, 56.541036636598655, 57.6999322829708, 55.90969585603284, 47.939333761892016, 42.715638837506695, 48.18157542136408, 42.02951823511432, 45.63496481987738, 54.45452790106497, 55.2924559962365, 53.84675272049443, 54.48278857815651, 51.00723912639003, 51.33827540182298, 53.05867010547269, 50.92603429671257, 48.72512179036295, 50.01200829782794, 46.35900297472554, 50.59458225004135, 47.985300017941384, 47.50897522895567, 45.374005609943026, 45.5470331253544, 42.88559121470298, 39.14820394208355, 38.130631293019945, 40.24412985770933, 39.86852761237852, 40.007367749367994, 39.99886405083441, 42.39935067392165, 42.07877143736809, 39.86642914433634, 42.13959563163019, 46.71275369582638, 54.86247008846652, 54.16630037369267, 57.08819158615605, 52.59637171222318, 57.771390022770056, 57.220414684664824, 55.359442234039314, 49.445280721110684, 45.622942755299235, 54.073822652139974, 52.766394692082564, 57.6404966077497, 57.4558824108493, 60.89708758938698, 59.971671027521936, 62.012809707272446, 57.58938027966408, 55.92175322194254, 54.38003032438217, 52.36231211693057, 49.2493583310035, 51.45851565945534, 51.72244410361014, 47.98411546214935, 49.29262991874449, 54.232902219218595, 59.81143828361266, 62.25977782280215, 60.66805647265527, 66.9799933894988, 63.87871257720455, 68.13682586916032, 66.44091067775604, 72.01484972430815, 66.22287396461734, 71.7446219536566, 27.806819638898297, 0.24958453561750152, 0.09567491289588714, 0.2956687845289707, 11.59915364557697, 69.96321478197652, 59.317929590902025, 72.90572981680594, 59.51713500484344, 46.39741082345286, 46.85279407808858, 39.14977289015247, 42.80550426052463, 60.62998594776277, 52.30032297872728, 1.907772087762433, 0.08179693903413512, 0.07746707903401506, 0.12052990781563906, 0.01776123333031372, 0.08769725629639241, 0.04671392721995231, 0.03179255501186896, 0.060331500135362155, 0.06910320686837358, 0.03517213465285397, 0.0815069287895195, 32.75920029609434, 73.14339407028692, 46.62282943725587, 40.840204608055856, 18.144329401754565, 43.89760586523241, 45.982357378928896, 72.07286942389705, 68.8321130506454, 76.85366599790513, 49.77837624088411, 0.4458603220841577, 0.12023415191159134, 1.6514373522612358, 2.030132018750714, 1.6432779642843431, 1.5666126652110008, 21.474470707678027, 63.04150619814473, 63.58932402826125, 66.0301757627918, 64.63482003058157, 66.54803845190233, 63.4270045834203, 60.073448688753196, 58.17674736822806, 63.875872781199796, 62.721962467316665, 60.17718361270044, 57.40863746212375, 57.722489833831794, 52.55473183047388, 51.534629252649125, 52.64305183964392, 51.3337254524231, 53.479410986746515, 54.692807966663, 53.39438184615105, 50.48190432210123, 46.90493414478917, 48.4483201273026, 54.44592614327708, 53.75065857364286, 56.96761400468888, 50.79148915506179, 38.3760618394421, 44.58378530317738, 50.83540793388121, 57.62827450229276, 60.2965570265247, 58.910128608826675, 54.296189661948915, 48.94396258938698, 43.66998287939256, 44.634317198107325, 46.017588107816636, 41.10732193916075, 43.63164955569852, 40.32851572959654, 40.8016320197813, 42.66917051807527, 41.6238941684846, 45.20303341650194, 42.8039784585276, 46.82375284933275, 49.24817377521146, 51.50865923973822, 51.38315516133463, 51.19139440598027, 51.75937321878249, 50.14334886304794, 52.76525720473259, 55.06159705500449, 54.54573477468183, 55.87336294112667, 55.934649975069114, 56.96189911134782, 57.87208118746358, 59.16967968786917, 57.1720753946612, 50.20443193374142, 41.2636205457872, 49.71716373197494, 43.67249711867302, 46.09459600140972, 58.449932605989524, 56.92834323452365, 54.481423593336544, 56.93968672906199, 54.19405898740215, 54.66583382698798, 55.1651672394045, 54.01796025614585, 51.63643829284176, 50.8398009884742, 49.83756088441419, 53.09873319441273, 50.79108122856387, 49.32990028012184, 46.505597637545684, 47.95947121035668, 45.16915982769382, 41.1087026134614, 39.68598442692911, 41.697473910547075, 41.093201406540416, 41.68624808711391, 42.25912201789118, 44.630269312089496, 43.27332927334694, 41.71597180827972, 45.04975895727835, 50.17692435172297, 57.675370400951756, 56.90236929924258, 58.17033821536649, 54.90067397394488, 60.67867040634156, 57.33833682152533, 58.77935678728166, 52.74802623256561, 49.03775822731757, 57.45448604706795, 55.41206082990093, 60.26711963838147, 58.90809289870724, 62.98918570241621, 62.82122196689729, 64.84009335117956, 61.01879873583394, 58.886578698312086, 57.33681886426864, 57.176397846591094, 52.73905577198152, 54.34326594875705, 52.906591969151656, 52.190578983676055, 49.97813863138999, 56.335661334376184, 60.93024730682374, 64.7340246169798, 64.62167224576397, 69.75546252342963, 65.15847213806646, 71.24903832712482, 67.65387227458339, 74.50100483432894, 67.1092825551187, 73.16269997627505, 29.181188729501542, 0.22510237270785918, 0.22852624946784592, 0.38386159246006324, 14.530180058171673, 78.58265461460238, 67.49105468873056, 78.43798975790702, 68.5060856419225, 53.80084137762747, 55.67940958084599, 50.78586839860486, 51.76047148243074, 63.52220442987258, 69.69858031119071, 3.6007343472972995, 0.3081784793926824, 0.02592156934101255, 0.07204270921647549, 0.04528813800143619, 0.14886623608969873, 0.11415762676587028, 0.14798554141194592, 0.21958571227808155, 0.1584394393308509, 0.11990628926263702, 0.29261809984041803, 42.72849636693155, 84.17214193651753, 57.57071372001403, 46.69906854629517, 34.30304519591793, 63.651862298288655, 55.47558361484159, 81.55681533198204, 75.18355215749433, 82.32923984527588, 54.25578140443372, 1.2067177963833655, 0.2620336022828856, 7.54704813803396, 3.506623694012242, 1.7334995875435493, 1.926612089718542, 24.874416474373113, 66.05658115879183, 65.82992307601437, 70.34742662983557, 67.8200238750827, 68.65254694415678, 63.67765580454181, 59.68514580880443, 61.09604981637771, 65.40350260273104, 66.76784023161858, 62.45794773101807, 61.766786882954264, 62.11353617329752, 55.011790798556426, 54.56438172248102, 55.625508369938025, 55.850503367762414, 58.431481776698945, 58.32370288910405, 56.84702857848137, 53.964231629525464, 49.7580740528722, 49.97984878478512, 55.97052397266511, 55.15717344899332, 60.83010527395434, 50.509564876556404, 38.914677789134366, 47.73820638656617, 51.51745711603473, 60.55492747214533, 61.67388554542296, 60.975178057147616, 58.79917652376237, 52.82488899846231, 46.097757431768606, 46.24410498526789, 50.97207507779522, 44.088848867724025, 44.51560666484218, 42.95895914877615, 42.98656479004891, 44.04538900621476, 45.073140205875525, 48.71476281073786, 46.70032370475031, 49.16438410359044, 51.75733358629289, 53.86899255937146, 54.825670411509854, 55.32177571327456, 54.04413030993555, 53.9237763035682, 54.62905376188217, 57.002840811206454, 55.53787477554814, 59.22448696628694, 59.67426907631659, 59.98869411406979, 61.92795707333473, 63.0533282218441, 59.61304872266708, 52.4382217468754, 40.68962089477047, 51.20317328360773, 47.25153830743606, 49.25752078333209, 61.06685953755533, 58.98979979176676, 59.32257367718605, 59.8201027993233, 55.67411045874319, 57.32614609502978, 59.84782611170123, 57.996953764269435, 54.69023881420013, 55.099742104930264, 51.24503281808669, 56.25736690336659, 54.12975957316738, 53.00455708657542, 50.28628787686748, 50.52263813634073, 48.273594225606615, 43.58321220644059, 43.727594652483546, 45.795146572974424, 43.83250236511231, 44.642079568678334, 44.25107417568084, 47.021773707482126, 47.30978550449495, 43.170343522102606, 47.033791849690104, 52.745209970781886, 58.92532387087422, 60.53800636722196, 60.27652548205469, 57.99538089383034, 62.83042384732155, 59.53667233067175, 62.33951176366499, 54.52753497708229, 49.4288577571992, 58.53886450490644, 58.22004641256025, 63.01375150680543, 63.79619375351937, 65.92424038917788, 64.85838728566324, 66.83228477354973, 62.91140117952901, 62.719699259727236, 62.54326320463612, 58.0586330352291, 55.643108044901204, 55.78102642490018, 56.918368647175456, 52.7643354477421, 54.46709517509707, 58.079978573706846, 64.50746067108648, 66.94764952505788, 67.56444223465459, 72.33271075833228, 69.70287138415922, 73.7105844866845, 73.424651545863, 78.15422981016098, 69.39515359940069, 73.65989961931783, 33.310991487195416, 0.4832001829579954, 0.3560983209360031, 0.6856019302241264, 16.434711410153298, 84.67807277556389, 76.01541626837947, 85.38306390085529, 78.37483175339239, 61.84593246829126, 66.60231621034684, 50.57206392288209, 63.98085109649166, 78.47292238666166, 87.33413711670907, 6.266472233879951, 0.9748392227676608, 0.24401499979919006, 0.18139871137757457, 0.182846249832261], [0.014904671491334036, 0.03682442925750248, 0.1321156929817892, 0.06253792528784083, 0.06551055327778862, 0.09052578314778306, 0.1776959173261158, 28.036692104031964, 56.51520782901395, 39.802804377771196, 28.872537420641994, 46.99404647273403, 99.01062519319596, 50.188601247725956, 60.3968128081291, 66.66079090487573, 61.251356063350556, 63.997230914331254, 2.366624311093361, 0.12097086036397565, 1.320012394459017, 1.6568350239146141, 0.9142637925763285, 0.8175770613935687, 9.357001339235614, 48.515059255784564, 60.38248046751946, 65.4169680995326, 58.72064282817226, 55.73158102650797, 65.74547836857458, 62.94547873158609, 65.03115200227307, 61.15153958720546, 57.79293560212659, 58.17910079033145, 54.19813825238136, 50.4305761860263, 50.085109510729396, 53.050303689895145, 55.672859222658225, 54.2986568327873, 55.788635823034475, 55.5210909535808, 55.18330820145146, 50.885669185269265, 48.49890301304479, 48.4222363656567, 51.40112353909401, 50.448058189884314, 57.85583865258002, 52.04804789635443, 54.144888154922, 55.74699986365534, 54.87843413506785, 59.27579549051101, 57.36411071592762, 57.12286533847932, 48.76555750446935, 47.36691482605473, 44.95486113332933, 48.46529614540839, 42.693622573729485, 40.457828429437455, 40.48578708402572, 39.958542085463, 40.19818321351082, 39.633279538923695, 39.27674785737069, 39.25034246137066, 42.73633718490601, 42.239125774752715, 47.434387437758915, 49.5307570119058, 49.17543342036586, 48.54613619465982, 51.25665872327743, 47.75760250706827, 49.29043731381817, 51.85063892795194, 48.06223338650119, 53.03283737551782, 54.00841712951661, 54.4119897965462, 55.38457285973334, 54.585750795179806, 57.9125992713436, 51.784688195874615, 45.565589858639626, 47.487661069439305, 43.436676379173036, 50.761082941485995, 56.474756425426854, 52.724746965592914, 54.2746283931117, 52.061415333901685, 53.80636799720026, 52.81703249100716, 51.95135754923667, 51.832733308115316, 48.08976058037051, 49.52681110751245, 47.719853616529896, 48.65704513365223, 45.60673159937705, 46.00294197759321, 43.57028799672281, 43.30676747906593, 40.67929329410676, 41.51110249180948, 36.3883654532894, 37.79639828589655, 40.168459492345015, 40.60334836283038, 38.82376509328043, 42.68076112193447, 47.637468153430575, 40.501456952864125, 42.00945923405309, 44.22540226290303, 49.29800356588056, 57.04954447284822, 56.20011598833146, 58.51961743447089, 52.796271385685095, 57.27683405722342, 59.062293037291504, 53.48588681990101, 48.31130389244326, 50.27618777367377, 52.87768017861151, 54.595576332461455, 57.18009271929341, 58.022555074384144, 57.06499468895697, 56.21848052547824, 59.402099732429754, 60.73992998369279, 58.150259602454405, 60.38679115233883, 57.12565022130167, 55.644371048096694, 51.50221478554511, 53.917963350972826, 51.161521634747906, 48.615715119146536, 50.69803476333619, 54.48865252156412, 58.4536902366146, 59.383880322979344, 59.93522828625095, 63.868938030735144, 62.02214102591238, 70.21015151854485, 66.13388323014783, 72.0307823919481, 16.53813058330167, 0.32843454891154844, 0.11217485332200605, 0.6057919321521636, 18.384470631999356, 73.37770861964073, 55.36792239835186, 72.03792895040205, 48.37955705581173, 44.85940633281585, 48.937176888988866, 32.25613867082904, 29.308399038930094, 68.37929894847255, 56.80160753188595, 6.745856471600072, 0.4221327098146562, 0.18516352790738308, 0.07948799599562922, 0.04941712591737028, 0.06445740454740102, 0.05038953664141798, 0.09975212475945873, 0.10619418109737097, 0.08498513650509619, 0.10328547548382513, 0.19098187376174236, 38.092674516862445, 65.1568208202239, 51.54897336036929, 34.54518487376552, 38.75266821153703, 100.96929211770335, 54.904768928404785, 69.59231545848232, 72.46223526616251, 69.51182842254639, 67.50217853053924, 3.3873191668141276, 0.04998022352435416, 0.5438937439072518, 1.6817211143432127, 2.9339676999276687, 1.3374062675622203, 10.61240396191997, 52.52535327788323, 61.37995096944994, 65.77293495978078, 61.71585882863691, 58.2888134064213, 67.08025701584356, 65.36716184308453, 66.54941912620299, 63.80296768680696, 59.675810567794315, 60.87058805650281, 56.63322802512877, 54.72074308703023, 52.77900511218656, 54.66072297865345, 55.71773505979969, 57.68921244528986, 60.095967015912464, 58.67091894149781, 57.46814766237813, 54.47897603434902, 50.771285026304184, 50.08069684428554, 53.373122599817094, 54.33924159696026, 58.27969389577066, 54.071535910329516, 53.86218724712249, 56.367569815727975, 56.532607463098344, 60.07994413375855, 59.27441873858052, 56.91625448965258, 50.02366950435024, 47.898792143790956, 46.73604080753942, 51.65133545475622, 44.408400443292436, 43.415177868258574, 43.37318889556393, 40.80488366465415, 40.768731178775916, 42.189939252791866, 40.75228075827322, 41.895094686938876, 44.58696242301695, 46.64973297426778, 49.09826863196589, 51.67748197432488, 49.5842424515755, 49.2878956179465, 53.56435383519819, 50.432870772577104, 51.688468533177534, 53.65238358897548, 51.54158753733481, 55.65537721880021, 57.70413706379553, 57.28667920635593, 56.1433239906065, 57.17834334219656, 59.030737569255216, 54.45069574540662, 45.8630310335467, 49.47413759846842, 46.079487031505955, 52.055547468123905, 58.334634534774295, 56.500785273890344, 56.5599306937187, 55.13273708281979, 55.629928881122225, 54.86614927168816, 52.340656711209206, 52.79990350046466, 49.71041333290839, 51.073107488693736, 49.87923998986521, 49.68066607752154, 49.83044178255143, 48.29687349257931, 45.62686512547155, 46.28126159791024, 42.34215074969877, 43.81847989174628, 38.228690547327844, 40.11575068196943, 41.72809585448235, 43.45404855666622, 40.545724822628884, 45.71420061972834, 50.745589579305346, 42.54316045391945, 44.586252474015765, 45.91194298959548, 51.26502121648481, 57.800717584548465, 58.93637711001981, 60.87922119325208, 53.79503234740227, 60.01363254362538, 59.87563179385278, 57.267392912218654, 51.553723350647964, 56.32206247698877, 54.511590542331824, 56.023683855610514, 58.68170938184185, 60.162070720426506, 58.60304232566588, 58.13142830325712, 62.614713099695024, 64.78646670618366, 60.28661381813788, 61.44268143561579, 60.69609357464699, 59.14338019586379, 55.63738922918997, 57.05721662890527, 54.055595397949226, 52.62592284910141, 52.23009686316214, 57.6663960179975, 59.838530094392844, 62.09916853135633, 62.350208067124896, 67.42043633614817, 65.70674888549313, 74.07228977449479, 67.14219124086442, 74.12047216969152, 17.950395653324744, 0.3395168687547407, 0.14546149620606055, 0.6855199894597453, 22.296075859377464, 79.8163341706799, 64.65706771419894, 75.33104112071376, 56.917282150637725, 51.05242483077511, 59.184290516761045, 33.662149521612356, 35.64913988113403, 75.01791830985778, 69.87581652979698, 8.038449537369514, 0.5258395643003526, 0.25713735049770725, 0.06503740971487376, 0.21328197311489813, 0.16746112055355505, 0.13063173470718245, 0.27141257159171567, 0.1266652072269109, 0.12869573859197478, 0.3302989004840774, 0.31252201406225083, 50.169938610446074, 79.09130757854831, 57.18564287308724, 43.007251370337706, 58.22760874225248, 106.79612205874537, 64.3857652141202, 76.62641955960181, 80.28814038922711, 73.39837951044883, 75.03803222410141, 4.5648916690580315, 0.290529161932007, 4.576783805124221, 6.537929177284242, 4.4221943713003595, 2.357134136461443, 14.180846906477406, 56.761340479696955, 63.391589503134455, 69.20281625563099, 62.1693201218882, 60.59326079583938, 69.54943610775855, 66.03995815400155, 70.52834203166347, 66.80897020524549, 63.715753786025516, 64.55316020596412, 60.42428116644583, 56.2468941750065, 54.72792494681574, 57.0038253261197, 59.331120521791526, 59.14148961344073, 63.277966283982806, 61.00943603823262, 59.909328876003144, 56.74501557503977, 55.88507513846121, 54.293444002828295, 58.232837261692175, 57.290821229257894, 62.56084719011861, 54.33549181107552, 55.65086649310205, 55.24172013805759, 58.39974980200491, 63.53028451242755, 63.611301068336736, 60.707562585030836, 51.46769400565855, 51.44999234907089, 49.72070955461072, 52.89145946502686, 47.53036783587548, 46.6328275588251, 45.466232299804695, 43.596273699114406, 44.4687068846918, 44.401571596822436, 43.64558181455059, 44.99179024850169, 47.9637622833252, 48.5470461845398, 51.97320907346664, 55.96184768984395, 51.81550625831851, 52.69190496014011, 57.85407750837265, 53.21107379851803, 54.54675851329681, 55.62397080083048, 52.49167580758372, 57.85037479092998, 59.798576831817634, 61.05960707510672, 60.17886630950436, 59.03648776392783, 62.57535603738601, 56.058557648812574, 47.59072134571691, 52.417052715055405, 49.540817891397786, 55.18988993860061, 59.92615976641255, 57.584944078999186, 60.012157732440585, 56.70808253749725, 59.0752290141198, 58.43156022410239, 56.36926820201259, 57.50356274266397, 54.07934927171277, 55.532108891394834, 51.531118731344904, 53.76734433635589, 53.19919686163626, 50.484002790143414, 48.34152575462095, 46.65116856175084, 43.87611912142846, 45.76760761199459, 38.950767517089844, 42.01442887706142, 44.48742835752426, 45.89717918826688, 43.53001702216364, 46.65420447626422, 52.745190358931026, 46.15137230965399, 45.54281657741916, 48.88993978500367, 54.80886305532148, 62.80222985052294, 63.28051582459481, 64.12087971164335, 57.95720446494318, 61.52188585650537, 60.80198972455917, 56.51540786989274, 52.84854873534172, 57.391280974111254, 57.363663565727975, 61.19349718093873, 60.767053173434356, 61.92580369211013, 60.35601231359667, 57.95957357652726, 64.88370226275536, 66.37975308202928, 63.53190837367889, 65.85525374258718, 62.82603079272855, 62.56267893698908, 58.18767116915796, 59.27710556214856, 57.465833463976466, 55.574376352371715, 55.29999479170769, 59.220180203837735, 63.715330170046904, 64.3248547277143, 65.92070241128245, 70.94979286193848, 68.78618994066792, 78.84002485582906, 71.84119855203937, 78.06094800272297, 21.574700993876306, 0.46554332719214503, 0.4015466096180101, 0.9860103168795187, 26.56755070532522, 88.65495604853477, 70.82681871229603, 85.73806978041127, 65.56597894237888, 58.80687221404045, 71.1726305561681, 40.81656056065714, 49.58864727327901, 84.47803189677578, 88.58822084242298, 13.371397179941978, 0.8277144883909534, 0.29751113405631435, 0.16626842890775975, 0.312466488009499], [0.04869238758880285, 0.11348658737035529, 0.03578543783195558, 0.020769831063526294, 0.09629382766903409, 0.029940562352778453, 0.11225184515839624, 25.01146016582366, 62.736616442280436, 39.089839073919485, 28.91332026450865, 64.50595055857013, 96.22527168643091, 56.992215110409646, 48.30337678232501, 68.19434350536716, 55.60526109510853, 75.44968497368598, 6.298948478314185, 0.0783485244779337, 0.3508641324456661, 2.463232533585641, 1.2447140413907267, 0.08301011587102568, 4.122581674206642, 43.410498480643, 56.324851282181285, 55.76547422716695, 60.41775826484927, 62.19447035943309, 64.19783661442419, 61.222707071611964, 60.69987081712293, 55.975740724994296, 55.32105007479268, 53.93512372047671, 54.98231810908164, 52.7142075569399, 54.65236833018642, 55.78228158335532, 55.70230053317163, 57.14356760824881, 57.73312337936894, 57.01780857578401, 53.20821831303259, 53.36370106666319, 47.45621542776785, 49.28127073472547, 52.24018912161551, 54.51259466909594, 57.00689261959445, 55.467158363711455, 57.52033087515063, 54.62500195349417, 57.49342341576853, 56.68305781579787, 58.90546883306196, 54.40853418842439, 45.89704582768102, 44.2939535264046, 45.90452578759963, 47.23260110424411, 38.619409607302764, 41.77379146698983, 40.81976513708792, 40.51151390998594, 39.47210150380289, 41.181493959119244, 40.054608775723366, 40.209075635479344, 39.11684067018571, 44.35197714836367, 47.5735648985832, 49.183438977887555, 47.10466123396351, 48.85402264133577, 49.338184325925766, 47.86105894273328, 48.55258064885294, 48.73315872684602, 54.22174699844853, 52.65740379210442, 52.69723153883412, 54.679871989834695, 53.8960059227482, 54.787035065312544, 55.30783953205232, 50.1398697207051, 48.0290226782522, 48.19852790524883, 46.14651249301049, 50.19034278008246, 56.23620571628694, 54.88170931416174, 52.56332574352142, 51.27844356721448, 50.238360435731956, 49.5841718489124, 50.18054077702184, 50.8352392719638, 47.642300513482866, 47.02011846726941, 49.82573886071482, 47.36685991287232, 46.30791018086095, 45.8508324623108, 43.62677404957433, 45.046024860874304, 40.44379418896091, 38.8052358165864, 37.89473995085686, 37.67547553585422, 40.06605817425636, 38.45516820107737, 39.978291219280614, 39.47570223962107, 47.600966576607, 45.04530706713277, 38.66257921341927, 44.236737912701024, 47.54545327155821, 51.332348700492616, 55.626932190310576, 55.49939632415772, 54.63518050409133, 51.005827073127996, 54.510107886406686, 58.45458845938406, 55.363078271189046, 50.575099837395456, 50.95363601561516, 51.38277469142791, 51.78085996258644, 55.36241539062993, 57.76998973661854, 58.358098153145086, 56.5201460930609, 58.12129289873185, 62.19743959365353, 59.421817487285985, 57.33347308251166, 58.09482474480906, 59.30226756680397, 55.44872714627174, 54.862685818826, 54.5896613982416, 50.89478477354973, 51.285303792645855, 51.63570873198971, 55.13672221091486, 57.47424302562591, 61.02987158683039, 63.8763826893222, 64.98207530667706, 70.10806006769981, 61.90865508971676, 7.063691519921826, 0.28604963133412026, 0.13941916156440012, 0.9032484288177184, 22.993534072752922, 73.63849132291733, 58.30540110988002, 72.94504765541323, 58.99639329602642, 47.18679958774198, 45.09720394688268, 63.95823471007809, 48.958781303897986, 62.23497667620259, 63.444341459581935, 4.788665829166289, 0.2924472009462695, 0.14856311041981946, 0.0754395047683389, 0.10825278958485973, 0.05852614499388203, 0.12975736791568418, 0.02942786950077261, 0.046463025763871214, 0.10133394310551305, 0.06184959528787483, 0.07387313841571731, 34.15994536492133, 71.51667733346262, 46.449009603069676, 36.300841685264345, 72.92673018670851, 98.58899393389302, 61.71388587644024, 56.71599003576464, 72.62630016573014, 59.19588112062024, 81.4628824110954, 7.05003627846318, 0.1271800029902689, 0.2908907247887504, 2.258178375421032, 2.7399650648716958, 1.3511730514226423, 4.9056421845189995, 45.97994119890275, 58.94897968538346, 57.68401138244137, 62.240409158891254, 64.07683933934858, 65.08328030186316, 63.28474806201074, 62.29001537446053, 57.85275566962458, 57.6550054550171, 55.17442795538134, 55.448813438415534, 55.671913931446696, 56.902071199109486, 57.33323774030132, 59.48359873987014, 59.117257210516165, 60.25047309937016, 59.70245915074503, 56.381066691490915, 54.71141961313064, 52.24038131775395, 51.21302235511042, 52.9801050309212, 56.5575223584329, 57.7392069755062, 57.223164266155614, 59.756054416779556, 56.53496872994208, 58.972423691903394, 57.23780647400887, 60.46098278414819, 55.99281480235439, 49.52724649060158, 46.077400330574285, 47.849609544200284, 48.95733002693423, 42.807579194345784, 40.61413488080425, 43.39340086906187, 43.408796171988214, 42.678380243239864, 42.91378521150158, 41.119932359264745, 42.103953053874356, 41.646753741848855, 45.80363850439749, 48.35949805475051, 50.559771214762044, 48.15915123108895, 50.36344089815694, 50.49595817442864, 49.753826125975586, 48.84623673654372, 50.69723067745086, 55.686430623454434, 55.5325952652962, 57.43199125412972, 56.92018078219507, 56.59773449743948, 57.075632156864295, 57.99474939223259, 53.886266677610344, 48.07453786173175, 50.245546217887636, 48.233464456373646, 51.22368335723878, 57.838070315699426, 57.58227686728201, 55.88422006176364, 54.133058286482296, 53.6307595622155, 52.672955989837654, 53.095336421843506, 53.24599073779199, 49.872293472290046, 48.588917486129276, 52.353016099622174, 48.43851420187181, 49.89512558906309, 48.54362587774954, 45.490645131757184, 44.78659537530715, 43.55663422615298, 41.14922854208177, 40.00682646228422, 40.817031245077814, 41.95795459132041, 39.76371011426372, 41.274626716490715, 42.44908240533645, 50.28558185023647, 47.26511363060244, 40.65376258665516, 46.36363529389905, 48.373877463802216, 53.47415501071561, 57.4596792651761, 56.948355167142815, 56.01037917598602, 54.60930855043473, 56.2898676626144, 60.119199214443086, 55.39965045067572, 55.08283276711741, 54.093057955465014, 52.64126323884534, 54.091575299539876, 58.37743151572443, 59.22373387121386, 60.53788477374662, 57.28492590688891, 60.89384378925447, 64.11994226517217, 61.961379589573035, 58.38331899335308, 61.86261823100429, 61.40002958236202, 58.97230209842805, 55.46974712802518, 59.88178599265314, 54.94534192546722, 53.98263931274415, 55.71382445673789, 58.76759752150505, 59.42089180792532, 64.57395269024757, 66.02528848955708, 66.66858857677829, 72.5625930293914, 64.52817863033664, 8.162244933266795, 0.3196244764952891, 0.1223799565266217, 1.2817386417619645, 26.064136066744407, 82.39752046523556, 65.2105612139548, 79.9043207783853, 64.76601939047536, 52.81211383881108, 56.313445029720185, 46.2177505800801, 50.53231070118566, 68.96198272705078, 78.95653493942754, 7.950136392347275, 0.49343156297841384, 0.15819642091951064, 0.1499671810456822, 0.0816631724216765, 0.42424113699986093, 0.2818499373332147, 0.21797364878077663, 0.15197857553439756, 0.22855081024669835, 0.2810779045666418, 0.3068023403325389, 46.245128723882864, 83.31838315533054, 56.06329194961056, 44.21370575504918, 73.42896615305256, 99.53420669801774, 68.94355543198125, 61.781531072432, 79.57212740375151, 65.81561426962575, 87.65870540372788, 9.025371805314096, 0.15352680858585144, 2.0612324918470075, 6.359898188421804, 7.3483869529539545, 2.2300395369529724, 7.071500468638636, 50.61818707373835, 60.4174130962741, 60.586027945241625, 63.506738524283136, 65.85619511142855, 66.67008692218413, 66.00670429968065, 66.9947571908274, 59.682925747286895, 59.62196427006876, 60.03942212750835, 59.78728825046171, 57.02349601253387, 60.82840688766972, 59.45867207742507, 62.460497271630075, 61.75706332729709, 63.87124830676664, 60.46070037349578, 59.670017227049804, 59.80187946750272, 53.88064199878324, 54.29047476860785, 55.8899506445854, 58.98517531733359, 61.500807039199344, 58.70420025240991, 61.88605047041371, 59.00063337818269, 62.24095436834521, 60.69924323789535, 63.080522014248764, 59.952933865208784, 51.140054502794825, 49.59360514917682, 50.431831344481445, 52.03624548450593, 44.32160231374925, 43.22147946203909, 45.6385184872535, 46.244505067025464, 45.74871747724472, 45.204606286941036, 45.31333438811764, 44.67579626267956, 42.76734744348834, 48.76845221365652, 51.2501750453826, 54.103216894211315, 51.17661491517098, 52.60426744338005, 53.14598598787862, 53.96780883112262, 52.11969783229213, 53.21060311409735, 58.88843790177376, 56.384169286297215, 58.70076817850913, 63.89938346801266, 58.110537759719364, 60.580983777200025, 60.108875536149554, 56.41910191505187, 48.36621707485568, 51.8715569280809, 52.99679863837458, 53.400892980637096, 62.14770786223873, 59.00032351093908, 59.12154043874433, 54.93278641854563, 58.11865706597605, 56.097581309656945, 54.76560323469101, 56.335657412006015, 52.38767416246476, 50.80555477449971, 53.78988619773619, 52.10935061977756, 53.998136597294966, 53.05721882850894, 48.30237657793107, 47.772142733297045, 44.58338129904963, 44.44950296032814, 43.147974245009884, 43.491981798602694, 44.17262284986435, 41.29204596242597, 45.21676171210505, 44.20927347675447, 51.98374455974948, 50.03053757452196, 41.59745347115302, 49.052380823319965, 52.214238720555464, 55.831605388272195, 60.89782891734954, 59.131769980153734, 58.443633279492786, 56.50384080025458, 57.69106380401119, 58.651358081448464, 55.4386309654482, 58.89687099764424, 55.928640903965125, 55.850166043927594, 57.48271142282794, 61.49326039898781, 62.21320752174624, 61.334027859472464, 57.484162699791696, 61.60801326074908, 68.75979238940825, 64.82353310431203, 61.20959066575574, 64.6969856754426, 64.35022854035901, 62.69059527304865, 59.3267313895687, 60.585867128064564, 55.96070235775363, 56.67384024589293, 60.440178532754224, 61.19184978546635, 61.82856813553841, 67.93123875894855, 70.4123967693698, 68.88857164690572, 76.05325929580196, 68.02612089341687, 10.971720526295325, 0.5184456513774011, 0.42060031946147647, 1.8807034434810763, 30.76985651446927, 87.5491379153344, 73.72217901291387, 87.80407628705426, 72.59367389063682, 64.34651013343566, 66.67389946599161, 73.96311452311855, 67.89080696721231, 79.40623467968356, 93.9179531220467, 10.903714472247708, 0.5965523602020356, 0.44238261998661105, 0.31121037960533177, 0.3454501277977421], [0.10466379789455284, 0.04386475812944193, 0.04150405052989241, 0.04805068169990855, 0.060982663379681695, 0.07193487468025378, 0.25066786055122653, 33.22699392995527, 55.31278956320978, 49.05920574741979, 26.79189851207118, 44.60737051502351, 78.45644843193793, 39.40192637904998, 56.716162620052216, 70.58513010701826, 50.06203420700566, 74.64509702497914, 18.737931097707442, 0.48151659749207965, 0.08726688342229014, 0.7947816555538486, 1.3034014019273943, 1.4940155994507576, 4.7114828998042695, 47.480545889946725, 62.21255248592746, 59.3836606702497, 63.9711549974257, 59.64396484436528, 60.39716582144461, 58.25399060403147, 56.955807670470215, 55.97979645575247, 55.29439364710162, 55.32765142379269, 54.510268703583755, 53.614105178463845, 55.55110493013936, 58.16913012535342, 59.104846831290956, 55.559494879937944, 57.4639154249622, 54.6113952513664, 57.519907259172015, 47.33600262672671, 51.62755804677164, 51.7871279101218, 55.12752425286078, 56.412155397476695, 55.33825359036846, 57.82762504393055, 58.38569202730733, 55.33532750221991, 54.34174799150037, 54.12036941897485, 53.726328111463985, 49.48679508701448, 45.392158339100504, 44.66717097067064, 48.690467649890536, 48.757328371847834, 48.15253419260825, 45.41969337771016, 38.480847958595525, 38.715986205685525, 41.21120199080437, 39.13382845540201, 40.167157265447806, 40.180022639613, 40.97631869777557, 43.27026982461253, 45.06498559828728, 47.180606165239894, 47.68743130468553, 49.537307370093565, 45.271004169218, 50.06356000900269, 47.13322785592849, 50.34696694343321, 53.20553148946455, 52.4921464920044, 54.19716550457863, 51.38639896146713, 52.56359246469314, 55.99545063511018, 55.314299675726126, 52.90130461415937, 49.40329959315639, 50.47851539427235, 44.410914682572894, 49.54938042548395, 56.675440572923236, 53.54968024838356, 53.531809929878484, 52.916346903770204, 52.16360876637121, 51.745425270449736, 51.178603556848344, 50.50203000345538, 47.167642731820386, 49.02818372172695, 49.3164465504308, 47.2614501368615, 46.30449771881104, 45.97393605016893, 47.04089918444234, 44.255686883003484, 40.38972039376536, 40.44918352557767, 36.61232886775848, 39.79072740001064, 39.409959393162886, 39.54885836570494, 38.764050929777085, 38.45581146978563, 44.701781965071156, 50.81999694147418, 40.61448789411976, 42.148899493678925, 45.70043310042351, 49.01990359829318, 52.97499418258668, 56.83055070138747, 55.81629245511947, 56.31874415182299, 52.725837384500814, 53.027804974586736, 56.69250680554298, 58.754418357726074, 52.63873723245437, 55.28705097013905, 53.882414910101126, 53.515818426685954, 53.53559501709477, 56.88695046209521, 57.28884435469105, 56.978502504287235, 55.40985253549392, 64.88177245663059, 60.85982899512015, 58.97460060734903, 58.7246044220463, 65.17736227281632, 58.75580687676707, 58.18493727714785, 58.17362123920072, 60.28679424716581, 60.17973315331244, 57.940793268142215, 59.59379380749118, 63.122169740738414, 67.02919560094034, 66.90146753864904, 69.31342709449031, 53.82872942955264, 3.998028280273561, 0.15948832095150026, 0.07791002341095479, 1.3018990115773295, 36.168128290484034, 70.12868389006584, 61.426376142809474, 73.69140409654187, 70.30906584955031, 48.445798043281805, 47.57029756422966, 58.069639205932624, 35.687535962750836, 57.93548630129907, 65.1281012258222, 3.3364776497887028, 0.18061370108156435, 0.11305332634477847, 0.08090393332343909, 0.11416939387638723, 0.08880036928120161, 0.05419363049910434, 0.05378466212160645, 0.010718554483666536, 0.02001401637831042, 0.0837343141076065, 0.20224471456341206, 40.498817197738155, 66.94408016820108, 54.14833591830347, 28.880409617577833, 71.70924217470231, 94.29434376378214, 43.744052917726584, 64.32614518750098, 73.77000055005475, 57.9274768214072, 79.88292817146548, 20.346989324015958, 0.36101862788200384, 0.043648468525779825, 1.527242855198922, 1.2081819436242505, 1.4910652416367687, 5.51697495483583, 49.382683615530695, 63.34744714921521, 62.737240099137836, 66.67397006865471, 61.477288507646136, 63.52406363333426, 60.68296932405042, 59.017170090829175, 58.11066719793505, 59.27593669583721, 57.2609249238045, 57.33867022298998, 55.551897248914166, 59.52885112454815, 60.20846843719483, 61.50783592654813, 57.17622133993334, 59.8482693395307, 57.74298421798214, 59.467042415372795, 52.61237106015606, 53.03601449535739, 54.60991651781144, 56.15966066237419, 60.134119910578576, 58.49074879000264, 58.2830043761961, 60.459696246731674, 57.636295749295144, 58.050027355071045, 55.38215275733702, 57.27683405722342, 50.937726882196245, 49.52699545891055, 46.46864498815229, 51.133296258987926, 50.741404410331484, 51.09593960546678, 47.49203843455161, 40.219183583413404, 39.59190637834611, 42.07550802538472, 42.05518622552195, 39.98594768585698, 41.28322062953826, 42.45460902490924, 46.12895988648938, 47.28172879065237, 49.90619844005954, 51.60407873892015, 52.03517859981906, 49.05123549122965, 53.8114356994629, 48.401690990694114, 50.97830772399903, 55.43596375373102, 55.80063827576176, 57.050850622115604, 53.90762790556877, 56.593772903565444, 56.522868217960486, 55.117286866711034, 54.327011646762976, 50.65572415628741, 51.77592169853949, 47.07590633823026, 53.69678089695593, 59.19144884232552, 57.56659523133309, 56.28248968432027, 54.7427789626583, 54.76696037477063, 52.71737683203913, 53.66220912625713, 54.01417516892957, 49.731401935700454, 50.565882267490515, 52.006968913539765, 49.195202166034335, 47.087971548880304, 47.40345170420986, 46.70252023204681, 45.98244367107269, 41.63159378113286, 40.92830888686642, 38.289071513760476, 40.824872063052275, 42.223530430947584, 40.88264857569049, 40.74671099262853, 40.759694037898896, 45.70884658444313, 52.571299922081735, 44.5923399925232, 45.27300457800589, 49.18035991730229, 50.70778185321439, 58.01179993537165, 57.83434014166556, 57.30127042339694, 55.42651868635609, 55.366659395156375, 56.86677378992881, 56.14132750418879, 58.26709916514736, 55.9541755337869, 57.900522293583045, 56.963385689643125, 55.75324427696967, 56.71524870780207, 59.54434056435863, 57.44286798661756, 57.618370517607666, 57.87040241302983, 66.14366562135758, 62.197886743853175, 63.78881185285507, 60.90823104304653, 66.0584403622535, 63.66434720254714, 60.96137523651124, 60.82482184133222, 62.67880462831067, 63.58941424277521, 60.9715537871084, 63.164598018892356, 67.09068267576157, 71.30639122378442, 69.93332632126348, 71.98702443030574, 55.87543395257766, 4.709459447091626, 0.4670503447132726, 0.36389023185737673, 1.752464492474833, 40.851901115909705, 78.08878898620605, 67.47764802748158, 80.3046614123929, 77.92233144083332, 53.24093480263987, 60.90895275915823, 64.65252168716924, 41.463708493017386, 64.03841972351074, 76.18786719537552, 5.24552095320917, 0.3958722576498986, 0.1768249672867598, 0.0991433070251538, 0.04920160240163246, 0.15619402030302634, 0.29837387163312207, 0.1438117565046395, 0.1898689931558986, 0.17382703541267305, 0.1818097635142265, 0.27671978358299504, 56.00732364962178, 78.74040449819258, 65.49532528846495, 41.45805243522891, 57.929347791979396, 84.84461661308043, 54.4221212787013, 72.55905505149596, 83.35128399633592, 64.72528949860605, 86.65195065159952, 25.33798375437337, 0.4920464147242808, 0.10751187530977112, 1.9576173227640892, 6.636515990380318, 2.9721240266676876, 6.825681117273147, 54.13261898102299, 66.99832654768421, 64.36300762238042, 70.03569233802058, 64.27972001414146, 66.78978197036251, 64.5531209822624, 61.677305852213216, 60.840899636668546, 62.15774520750969, 61.069597351935606, 61.80122137069703, 58.49882102781727, 63.46354538394559, 61.228057184527, 61.95571568704421, 61.41712327157298, 61.5926807157455, 59.38857540007561, 62.92817715675601, 54.64204072952271, 56.16978037741877, 58.64673360701531, 60.0447996970146, 63.1157958892084, 60.45083953488258, 61.32451218943442, 64.29473876953125, 58.93034450469479, 59.64737338404502, 58.27498705156388, 58.81865109166792, 53.6685751330468, 50.75050823150143, 47.80345893675282, 54.39983044901202, 53.60743322680074, 53.84754896163941, 51.07686511931881, 42.45947668629308, 42.29141881389003, 45.462309929632376, 43.95547259238459, 43.44348169142201, 45.39645333443919, 45.485542128163004, 49.38842988783314, 49.55940208127422, 50.34544114143618, 54.888887251577074, 54.63784379343833, 51.12045049667359, 56.63549907745854, 51.4639324526633, 55.15301965898084, 57.705290240626184, 57.99273329396402, 58.96709711320939, 56.32863636939757, 60.178921222686775, 60.845818288864635, 58.936820337849284, 59.9896276381708, 53.493511907515995, 54.873374277545565, 49.846586258180686, 55.90676976788429, 60.63381025868078, 60.3110658737921, 58.579288451902336, 58.49036047535559, 56.971850164474986, 56.92048280469833, 58.69279792231899, 56.29360568138861, 52.190649586339156, 54.628026100897024, 55.4420316603876, 53.630579133187574, 49.84883377628942, 50.48251228947794, 50.976781922002, 49.137990474700935, 44.471460388552764, 45.56411504745484, 40.600559557637865, 44.274016118818714, 45.879348093463534, 44.31959406022103, 45.149944136219645, 43.494088111385224, 47.437937182764855, 58.71340605520434, 46.49793724859915, 48.60363814138597, 52.47455073941139, 53.56713871802054, 59.37329776825444, 60.633931852156124, 60.353211741293634, 57.47080310698479, 57.91318762686945, 58.6081963200723, 57.38793911472444, 59.82483317775112, 56.51471361037224, 61.800550645397564, 60.19150418619956, 56.933913000168346, 58.60516040555893, 63.305069861873505, 60.842429361035755, 57.53705586156538, 58.19229172122095, 69.69213977936776, 63.94761685402163, 64.70604635054066, 65.79950901769823, 67.48147626076975, 65.16010384405813, 63.19210560091081, 63.61677277472712, 64.43293956018263, 67.06507744327669, 65.75198950306063, 64.73504835559477, 73.03036705140146, 72.37817102862944, 73.63221553064162, 77.4752361543717, 60.966050701756636, 5.498864881453976, 0.3995933918462646, 0.8427941630924902, 2.670937723690464, 45.646994729195875, 86.87707901000978, 75.66724315766366, 89.80468119344404, 83.87893692139657, 66.56427706441572, 67.2443768285936, 74.32369016831922, 53.636635272733635, 75.01161898336103, 91.59591782477595, 8.103983517616026, 0.7514914978415735, 0.4378159698699752, 0.18785041276245348, 0.280667771735499], [0.028977101450906168, 0.10489192355664508, 0.042218952289512085, 0.05790878154878175, 0.043236926092856356, 0.08702174294739963, 0.29144837551059266, 32.96689371908865, 62.16164796583114, 52.98283107819096, 38.69855519263975, 20.280864046465968, 37.57244271616782, 43.665695728794226, 53.32252010222405, 66.9834372305101, 54.420022810659106, 69.30849275281354, 31.983084832468343, 0.2817464848199199, 0.11644452945479464, 2.0934138230739103, 0.5498244901818614, 1.6464007838118462, 6.255079709714459, 52.72427235880206, 63.959431032980646, 60.358271598815925, 58.440926844073886, 60.671213980643984, 58.16885948181153, 58.15588035891133, 55.18917606722925, 56.738233797011844, 57.664101431446696, 57.150153267768125, 57.82257303114861, 60.18857417568084, 58.702878413661836, 58.17067946157148, 55.52443281296761, 56.75605704707485, 55.245183590919744, 51.63221390016618, 49.69209978657384, 53.18450366297076, 50.59625317973476, 67.43340369193785, 62.42709436724263, 53.155242781485285, 59.045250338892785, 56.646972010212565, 54.72172367957331, 53.83950025804582, 52.81498109140704, 50.703016173455026, 47.61643640456661, 47.06209567285354, 47.230169234737275, 45.15483533182452, 53.22409998986029, 52.894275726810584, 52.542113565629535, 46.81253094826975, 40.34619777433334, 39.93415671010172, 40.410101029180716, 39.7697348748484, 39.050689897229596, 39.38174970688359, 39.87481909413492, 40.729205454549486, 46.19645211004442, 47.50594715918265, 46.10870868928971, 47.100754553271884, 47.15207484460647, 45.986028717410186, 51.42757992590628, 50.819561558385054, 52.090833110194055, 53.403658251608576, 51.93065135709701, 52.39336944395497, 53.68967356220369, 54.40831845806491, 52.80230791338029, 53.89874765949865, 48.78619701631608, 46.88249426503336, 44.02978189529912, 46.15401206477996, 55.17942897735104, 52.37451461053664, 51.76577844927388, 51.16461638481387, 53.117305617178644, 52.21608223453645, 52.83763670152234, 46.8523233936679, 47.17056097522859, 50.092173699409734, 47.78085823981993, 47.608426924674745, 46.65313366920718, 46.29170686967912, 43.461618731098795, 40.88784963853898, 40.055452085310414, 39.09070199535739, 39.56439095158731, 38.92819819911834, 39.25843038866597, 38.44254993623303, 38.44539757697813, 37.972371501307336, 43.787089163257235, 52.20930437887869, 47.20554459479548, 40.11517801592427, 44.09822725480603, 47.592364818819114, 48.719242157474646, 52.33798165475169, 57.089913506661695, 54.704775118058734, 57.83998835471369, 55.60334305609427, 54.791561480491396, 51.12517695273123, 55.067166820649184, 56.187289837867986, 53.08393801412275, 54.5362897073069, 54.82882007475823, 54.305905372865745, 59.223082757765255, 56.4783493165047, 52.19212831989412, 53.234419745783654, 60.427069971638346, 59.11120499334028, 76.00408846332182, 76.72561630125969, 60.28682170375701, 68.18920520044142, 61.36837605507144, 62.883752392184356, 62.01364124974897, 66.51566320850004, 65.28543926054432, 68.94000960934547, 76.84446411748087, 62.70588859435051, 75.31999572630852, 34.56266295525336, 0.538803120293925, 0.29114662879897707, 0.09754891717626203, 2.083832943631757, 43.571013635204686, 70.74417437276533, 64.86842070856403, 70.58760120022681, 68.85402341042796, 52.85131792868338, 43.42069664309102, 41.1381596134555, 45.28393230130596, 57.52885418553507, 71.95191921726351, 4.660877460433591, 0.3022716350613102, 0.19729607768597143, 0.09267184823270767, 0.048524614333385424, 0.07675396608969859, 0.0736753881398228, 0.034336022461854646, 0.052494309587223884, 0.059114128967086156, 0.1980589633627284, 0.24416559736334512, 42.517049235682336, 68.54590554391184, 59.56174412081319, 36.0398942424405, 34.34216299364644, 55.355288444026826, 47.574270925214215, 63.520576646251065, 71.66316216991794, 60.73951421245452, 76.38691963688021, 36.64974827920237, 0.3261918111914589, 0.17614117252730555, 1.7280601181330222, 0.5569223867308709, 2.1608780997414745, 7.074657486331079, 55.88566349398706, 64.61933451314127, 62.88386614091935, 62.01436688823085, 61.62533444743003, 61.2293751009049, 60.708131328705825, 59.06327362983458, 57.898545419016195, 59.76443259946762, 59.1079572708376, 59.45242766411074, 61.27999328797864, 59.44277471111667, 59.707401337162146, 57.22044214125603, 57.283329502228774, 58.235837874873994, 54.4439257344892, 53.67462342785251, 54.56663316295993, 54.59380342114357, 60.58518071328441, 61.27537273591565, 55.606218153430575, 60.2749369221349, 57.56273561908353, 57.30623222166493, 55.46173372576314, 54.31810786647182, 52.24719055237309, 51.22000417401714, 48.99604774290516, 49.38306800780758, 45.194674845664736, 52.98449024077385, 54.969829282452984, 55.015909287237356, 48.68795341061008, 41.130075608530355, 41.44759147397934, 42.121031053604625, 40.55324008387905, 41.81268961198869, 41.210958803853686, 39.66529000189997, 42.6490330696106, 47.93465045190627, 49.75178649348598, 49.143803427296305, 48.87576433920091, 48.735755335900095, 48.87936899738927, 51.894938176678075, 51.728421795752745, 53.65545088245023, 55.56739845583516, 54.90822061415642, 54.095748701403224, 57.24887932500532, 55.51459550857545, 55.595721890849454, 56.562107609164336, 49.677826281516786, 48.94668471428656, 48.55423588906565, 49.29170031701365, 57.37970213736258, 55.694863719324914, 54.548900127410896, 54.00289050994381, 53.478767718038256, 53.274051374004735, 56.37743457671135, 50.92321803492885, 50.18516132908483, 50.51180454992479, 50.14168970046505, 49.29852916348366, 48.42020065553727, 48.866664440401145, 45.20310009679487, 42.306806272076024, 40.78903336678782, 39.06894068564139, 40.62347404418453, 40.65260548745432, 42.18298096810618, 38.4945095739057, 41.01012560629076, 39.489654110324004, 44.410753865395826, 55.66313174463088, 49.512847469699004, 44.21756536729875, 45.833460284817605, 49.45886781138759, 53.01984648550711, 56.550501315824455, 58.449807090144006, 57.81982737202799, 58.53519708879533, 58.90717898645709, 60.986054789635446, 52.64397751900458, 56.423942119844504, 59.33872991992582, 55.471437669569454, 56.940102500300256, 54.77859412470172, 56.42634261038996, 60.46701538947321, 59.43651853069183, 55.09857716098909, 56.84409464559248, 62.468914678019864, 62.51465343659925, 75.02042862676805, 77.85154050396335, 64.33002833397158, 67.48561828367173, 64.99525839282622, 65.36237262910413, 65.09505917949062, 70.56834236268075, 67.89360753951534, 69.4530713173651, 78.40096258348035, 64.28805112838745, 77.67085259960544, 36.03804680608934, 0.44645119037839676, 0.4809922562731851, 0.28888152131149847, 2.5528829616885034, 50.26745265530002, 76.4071669117097, 70.37736215899068, 78.66850745293402, 73.571152071799, 62.32159437671785, 46.64472018518756, 50.5936683377912, 51.17666590598322, 63.06305962224161, 84.46117354977517, 6.4318761325651606, 0.38277095904754055, 0.11730747387534189, 0.03805385864970665, 0.13121448246942413, 0.2011222578585148, 0.16314370948220455, 0.1165392715483904, 0.12387733666166184, 0.13637888034985912, 0.37897441115590835, 0.33434405922889715, 50.91695793213383, 82.37084834806382, 68.23434383638444, 53.21884793619956, 33.272273771224484, 49.1986499294158, 60.123921748130556, 65.25579006441178, 79.47082042694092, 67.12421894073486, 83.85883085189327, 40.651636662021765, 0.6732381291447148, 0.15267452044833094, 5.404181316975625, 5.716671645641328, 3.8633083480019725, 8.442230090018242, 61.703334700676706, 68.56525851834205, 67.11369129919237, 64.34010098057409, 64.80121089566138, 62.6472766168656, 64.52953184804609, 60.32858317898166, 60.326151309474824, 64.10638263148647, 61.20908468000351, 63.27779762206539, 65.1761463380629, 61.81882889040055, 60.71067302457748, 58.91230944664248, 59.84064032954555, 61.08543980506159, 56.895724804170676, 56.00287175947621, 58.44280565938642, 56.29063644716817, 62.14386393946987, 62.71515715506769, 58.13468387050014, 62.982168582177934, 61.98454510781073, 58.612452091709265, 58.935945649300855, 56.688262801016535, 54.846917890733295, 51.66594236127792, 52.66584865508541, 50.972153525198664, 48.11457349408058, 56.662928212073545, 59.768519709187174, 56.89461477341191, 50.65748137812461, 43.52433350778396, 44.77967631432318, 45.06476594555763, 42.80838720260128, 44.28357493492865, 43.931232344719675, 42.138611116716945, 43.56119594266338, 51.984572179855846, 51.645247936248786, 52.09534383589222, 51.2650369059655, 52.15983544626544, 52.12870751657794, 57.29180182180097, 55.689439081376605, 56.19255758100941, 57.55864458699381, 58.41231315366684, 57.47434500725039, 60.93493846154983, 59.03795080800211, 58.09567197676628, 58.57747631688272, 53.66134228244905, 50.7193567675929, 50.58389379132179, 52.08818943269792, 60.2442757544979, 58.99590692212505, 58.66337230128627, 56.5538667094323, 58.30170231480753, 56.66302627132785, 57.868111748849195, 52.15243393375028, 52.94355638565556, 55.30336018531553, 54.03225337305377, 54.36193643077728, 51.140380059519124, 53.03949756007041, 47.60872110243767, 44.735118189165675, 43.13295156724992, 44.805112884890654, 43.905807541262725, 42.300455954767045, 44.068291725650916, 39.618409833600445, 42.86794054892756, 40.20310971044725, 47.12005261451968, 56.87592467954082, 52.427266566984116, 44.78665421085973, 49.02412014622843, 52.28759880988829, 55.042706920254616, 58.38404855420513, 61.88853725310295, 60.25420719577421, 62.362387026509936, 60.32151899030132, 64.97959636872815, 53.389431814993586, 56.94391896647792, 60.51775124765212, 60.62119199383644, 62.64650390994165, 59.41339615852603, 58.87613734891338, 64.38081126059255, 60.9762998550169, 55.57681214424872, 57.68209726579728, 65.05233280120358, 64.3870948976086, 72.68757543256207, 77.49757797487321, 66.38250658589025, 69.65129221639326, 69.25864727266374, 68.81272869725382, 68.257415217738, 72.10409933520903, 73.64096241612589, 69.27034378051758, 80.05945836344074, 70.64124353470342, 81.761610123419, 40.72825624096779, 1.0082451915068011, 0.7225259585726647, 0.5164476940708776, 4.180258166405463, 54.88727123506608, 86.50769372140208, 79.56345896567069, 85.08836838506883, 83.11631833353351, 70.92740397299491, 62.6013142831864, 56.6241987289921, 61.3033196233934, 75.11251018893334, 97.48837686354115, 9.871562373253608, 0.5230574393945356, 0.37847299128770834, 0.2225870609043106, 0.19697320226940418], [0.07300814087953299, 0.05185136263589225, 0.05354176628433409, 0.07632511773056562, 0.06162855593908218, 0.08985333415048738, 0.18892560184242266, 9.137997761849435, 65.56881089364329, 51.23419530930058, 41.53173415891586, 28.95791369099771, 27.331183225877826, 47.475195777031686, 53.312004227792066, 69.66309855061193, 60.69938444322156, 61.94233648238644, 51.249806342586396, 1.1135322095886355, 0.26889955805193994, 0.6305139571908982, 0.47034482922284837, 0.8485420901448497, 8.067381430056788, 58.25262561921151, 58.87658449911303, 61.01396245341147, 59.19105660530829, 60.21676817247945, 60.82787344532629, 60.20959415743428, 59.96675629769603, 58.455514138744725, 58.847001983273415, 60.00296761912685, 59.642062494831706, 55.415010452270515, 55.43827402976252, 55.45863505332701, 54.72753270979851, 54.59814156255415, 54.31968465928109, 50.977444802561116, 51.87312979852, 53.49032694293607, 55.34682396919497, 79.05345670638546, 56.695911422852554, 54.671740916467485, 56.183728325751524, 54.73850750154065, 59.459805642404866, 53.32210825335596, 47.92690377081595, 46.34114834570116, 46.5995031018411, 50.318623896568056, 43.93691585909936, 44.70670846200759, 49.373195402083866, 50.796239145340465, 47.753334968320786, 44.6614953010313, 39.78778954475157, 38.12466929035802, 40.901377893263295, 41.82025978642125, 40.23708920325003, 40.81374037650324, 38.718641650292184, 40.51322798575125, 43.740754204411665, 46.89397504252773, 47.166771965642134, 45.8496557512591, 47.00262469630088, 48.66384652353103, 49.98084506680889, 50.53424835205079, 49.57411096942041, 51.60199596035866, 52.5494013294097, 54.04096887957666, 51.650311716141246, 51.60446313119704, 55.98806873444588, 53.09880379707583, 50.801659860918605, 45.24389274658696, 48.65637833072294, 47.229827988532286, 51.69847057711694, 52.37256127019083, 50.34679043677546, 53.48356869912917, 53.34534829662692, 53.18313083341045, 53.48704391910184, 50.11913214960406, 48.63567213858328, 49.094722809330115, 44.5601765571102, 47.767726144483014, 45.852342574827134, 43.67359930469144, 43.08292958044237, 42.11141732431228, 38.22989079260057, 37.674930326400265, 39.232589813970755, 41.08860046632829, 36.151956358263575, 39.85153590479205, 38.44286764821699, 38.475003627038774, 40.28654244638259, 50.16851479007352, 53.152477510513805, 44.283822044249504, 44.12646047530636, 46.81755942683066, 45.987491761484456, 50.652296004756806, 53.780245011852635, 56.276464923735595, 56.610121342443655, 57.347370040032175, 59.827794567231216, 55.31753563111829, 51.32431176400954, 54.57837673925585, 57.65873955142114, 55.93467743166032, 51.83529069346767, 52.71377609622095, 55.07142259228615, 58.548894005437056, 58.80400496144449, 53.03747753943167, 52.556555732604004, 54.628790963080625, 62.90343876807921, 55.519325887003255, 62.78352014480099, 61.11349651890417, 64.42022715845417, 64.69986077277892, 69.5184023149552, 59.73495990999284, 77.5891496289161, 77.92864645681074, 66.80725220711001, 66.33373583516767, 72.18204467527329, 13.06165643276707, 0.07499272229089853, 0.20764056292753066, 0.1600818552317158, 4.4188137785080945, 51.74347193010392, 66.99685958123976, 67.59382078724524, 69.92343410368889, 72.12355429126372, 43.924901639261556, 77.0007941030687, 51.227731243256606, 33.46429732538039, 66.91198733545119, 73.27475424735778, 4.3388121358809935, 0.31052770333424695, 0.23291591795221453, 0.06003011348507097, 0.08680495538658674, 0.08022830506125767, 0.04639538403059687, 0.06545641384417973, 0.09862966039368222, 0.04304577566442951, 0.13058075921670084, 0.33703069893583176, 16.898947454267933, 75.21431138438564, 56.43501104847078, 42.62900152514058, 27.401881987048736, 31.897586968637285, 52.779122783291726, 59.67587332571707, 76.28900158789851, 66.97932658656951, 66.96697112052672, 56.47880823381486, 1.4686284262326457, 0.3970737593068231, 1.152232887764131, 0.398717783992329, 1.3202224864113716, 8.849961450023036, 63.00565573476977, 62.544930211959354, 65.17525988240396, 62.27445140961678, 61.98467062365625, 63.15505489226311, 60.080654082759736, 62.72391580766248, 60.41769158455634, 61.446450833351385, 61.378401633231874, 62.78568921550628, 57.38704089195498, 56.10280982909664, 57.85132792688186, 57.131522009449625, 58.564010820081165, 56.595577193844704, 54.497419018899244, 54.97092754610124, 55.82630234379923, 55.89334741715462, 71.87136157866448, 57.05065842597716, 58.03815826292961, 58.370131984833755, 58.1902010979191, 60.45915495964789, 57.790911659117675, 51.14213728135633, 47.940102546445786, 49.59099285064205, 52.49086387695805, 45.62278586049234, 45.896002477215184, 53.3363268452306, 52.48610211956886, 51.52714929273052, 45.16182499547159, 41.390987750022646, 41.042826406417355, 41.639924895378854, 42.6888882729315, 40.88662193667504, 41.393858924988784, 40.271613905506754, 41.64822855303365, 44.88499195344987, 49.09502090946321, 48.997326435581336, 48.67295818944132, 48.17765305119176, 50.82763379619968, 50.7672449850267, 51.869544752182506, 52.00734938344648, 54.102004881828066, 55.506072198191, 56.68732927691553, 55.151085930485884, 55.25487576761554, 58.26139211654664, 57.16011216563564, 51.997480700092936, 48.351967104019664, 52.29354120069935, 51.98063804257301, 56.16729359472952, 55.81269171930129, 53.94903244510774, 54.9535200672765, 55.338900781446895, 55.34494123151226, 54.34379546873031, 53.00635353211434, 48.631600718344416, 51.589362006033625, 46.98010244677144, 49.39259152258597, 47.40119634136077, 46.16573210685484, 45.401748534171816, 42.83087415079917, 39.235496290268436, 40.54019035831575, 38.676052554961174, 41.895078997458185, 39.096024651681226, 41.79527036605343, 41.30890430942659, 40.16394092190651, 43.12001951279179, 52.595332284127515, 53.27119981088946, 46.37894038231143, 45.07650559948337, 49.82952002556094, 48.93385464145292, 52.155226661312966, 54.87381750537504, 57.58797999351256, 59.60828304290772, 58.75537933841829, 59.67182543969924, 56.693895324583984, 56.00176172871744, 57.28389824590376, 59.51864511735978, 58.131647955986764, 56.03201104748634, 55.317190462543124, 58.8447936888664, 59.16143094339679, 62.20045197394587, 56.492987601987785, 55.16082125325357, 57.626591805488836, 66.42210683514996, 56.58679108465872, 62.33267115008447, 61.08727547430224, 66.64764312005812, 65.98758666746079, 71.41382494280415, 65.11713035645025, 74.24662343917355, 78.65872506172427, 72.60857889729162, 67.78096491290678, 75.26560029675885, 13.126115683586368, 0.046397827851075324, 0.3517357566423955, 0.4148941595227488, 5.072212988330472, 56.39974501825149, 76.20483536874094, 73.52846883958387, 78.13118980776879, 79.14009401875158, 54.576858781999164, 79.05524530718404, 57.96463343404955, 33.24475442209552, 71.93207202419158, 84.51568665043001, 6.943270833261552, 0.27700262324463937, 0.2762788233737792, 0.03891944607359268, 0.08577385466665992, 0.27373924190478943, 0.1457507250409934, 0.21625155973578655, 0.34826081246137625, 0.21481281597047083, 0.27561300103702857, 0.38518468759232954, 22.812575524853123, 88.40807422514885, 65.57752247779601, 56.32744004649501, 40.13263256319108, 38.367550296168176, 61.80517511983072, 66.59502844656667, 82.9197605194584, 72.58316978331536, 73.89709318837812, 62.61632127146568, 2.775654956217735, 0.49139652701635517, 4.34418676360961, 3.5017077384456514, 2.9261528676556003, 9.423119752637803, 67.66835366525959, 66.41863161517729, 66.59393802765878, 62.913507492311545, 67.09849603714483, 65.79480217349145, 65.52357812081614, 65.79060131503691, 63.87687298559374, 64.32532933450514, 65.37794051631805, 64.10387623694636, 61.97780647585469, 58.05228271792012, 59.89398456388905, 58.933588304827296, 61.43362076051774, 59.544289573546386, 58.12302266397784, 58.57065923752324, 58.27921928897981, 56.73904180526734, 77.55709601986793, 62.34636414435602, 58.24234900936004, 61.13424585711572, 59.62759287126603, 64.02591520740141, 60.57973646348523, 53.040819398818485, 49.98679530236029, 52.28211533638739, 55.58106007114534, 48.368672478583555, 48.134895293943345, 55.8623646151635, 55.60455506847751, 54.3925936760441, 47.52423324892598, 43.26271533966065, 43.0149588277263, 45.96465179997106, 45.18596326151202, 44.99702269031156, 45.02909198884041, 42.75663152817757, 42.87175309273505, 48.21143250311575, 51.38898380341069, 52.059689491025864, 52.377024927446925, 50.87245079778856, 54.85655515424667, 54.16136210964572, 54.62715533471877, 55.113948929694395, 56.21741756316155, 57.99936602192541, 61.09092720093266, 57.72323508416453, 58.62849458571404, 63.75707595579086, 62.78068427116641, 54.39357819095735, 50.883582484337595, 54.915335793649, 55.3549236636008, 59.070043640752, 58.93056415742444, 57.90277373406195, 60.597206700232725, 61.84036662501674, 57.80532244713076, 58.537644647782855, 54.74637185373614, 54.166794592334384, 55.45912927196872, 50.59692782740439, 54.06436581765452, 50.59395074844361, 46.5717327210211, 47.928515864956765, 47.20008465551561, 41.447399277840894, 42.58047003899851, 40.901499486738636, 44.30999994277955, 39.107062201346125, 45.81116161038799, 44.73931904762022, 41.73252421040689, 44.197067060778224, 57.10632470346267, 55.92262791049097, 49.07364399202409, 48.757026349344564, 53.17852989319832, 50.81241892230127, 55.10533540479599, 59.88475914924376, 58.640995179453206, 63.011617737431685, 62.532790476276034, 61.50212103320707, 57.56239045050837, 57.49227808367822, 57.970214966804754, 60.33503155554495, 60.58860102007466, 58.14694912202897, 58.263718082058816, 61.06143882197719, 61.450353591672844, 64.51600751569195, 58.58242634804019, 57.9205342262022, 59.667836389234, 68.02215929954284, 61.07337851678172, 64.03457972311205, 66.43853372143161, 70.70180493016397, 68.60642771567069, 72.57505047705867, 67.13794723633798, 75.76358441383609, 79.22561737798875, 79.09670475990542, 70.75983247449322, 80.78461047141784, 16.205696963494827, 0.10762042996864166, 1.1762490700329504, 0.7925802865816701, 6.536974080147282, 62.38407773356285, 85.08689357388405, 78.82979531441966, 83.99244246944305, 83.5706150916315, 62.19371334198983, 93.66660764140468, 69.97871598889752, 49.50190797928841, 83.85448486574235, 98.4273373696112, 10.681854428783542, 0.5525445926093286, 0.47521537109728784, 0.4320548048182842, 0.3428222929998752], [0.046355769624032324, 0.0725620708638622, 0.023217878432103226, 0.03553954276045965, 0.06409838510256621, 0.10880824163435929, 0.3438124769637662, 8.460251419774949, 69.14341588174143, 49.37757276719617, 35.190183347271336, 22.842242371651437, 33.99571180343628, 46.476646623303814, 48.48297819014519, 64.57270929890295, 66.6035399898406, 54.30577201227988, 65.94061236227712, 4.190312181749652, 0.6375069303377983, 0.23147599441149544, 0.620389890766913, 0.44388320236917467, 7.129134305061833, 59.69252378709855, 62.91069907526817, 65.72698831558228, 59.91051735416536, 62.888867162889056, 58.862781678476644, 59.494126381412634, 61.987835976385306, 62.1151678792892, 59.013730172188055, 60.10231733322144, 60.22383628352996, 57.4375767092551, 51.88691692967569, 51.27866321994413, 53.4870360743615, 51.68263204636113, 52.25621592613959, 50.660713411146595, 54.194176658507324, 53.04031341306625, 56.423067431296076, 33.42905482938213, 50.038633346557624, 59.97986485881191, 55.8297775637719, 55.62739110762074, 51.423241784495694, 50.2845855682127, 46.9747954799283, 47.28206611448719, 49.830257431153335, 48.79076265519666, 43.9202771648284, 47.1570287981341, 52.89167911775651, 50.697242444561375, 49.31988646907192, 43.55131941456949, 39.684748880324825, 39.59202797182145, 39.28353748013897, 40.15397810166882, 40.35295994051042, 40.32053762866605, 39.275535844987445, 37.68614830509309, 42.21323813161543, 46.54853582382203, 43.89524852075885, 44.12323628702472, 47.46850813588789, 46.5330816853431, 50.51334211903234, 51.52791415491412, 51.34600247106245, 53.32574036813552, 52.8208803361462, 49.30185925575995, 51.031040068595644, 54.500211746461936, 51.29987932020619, 50.206361739866196, 50.16489836477464, 48.26233310084189, 50.19688529352988, 53.44171308702039, 50.84545704626268, 52.969220453693026, 52.85737799059961, 51.750704780701675, 49.538327186338364, 52.78583788102674, 51.04978899801932, 47.456152669845096, 50.07416217557846, 48.23008729565529, 46.81324481964112, 47.32931890795308, 44.237553765696866, 47.04193469016783, 44.615811455634336, 40.582359760038315, 38.84826029500654, 38.09939353696762, 36.43085256699593, 37.08437827325637, 36.66654386828023, 38.48379758096511, 39.77022124874977, 39.49908741058842, 40.30868030363514, 48.63240088185957, 49.30595813259002, 47.69386791413831, 44.1957099206986, 45.455516384493926, 49.07092578949467, 47.02938310561642, 51.56073654851606, 52.054817907271854, 55.56825353253273, 57.845448293993556, 58.43268594434185, 57.38575827690863, 56.021169616330056, 52.64176922459757, 54.23859357833863, 57.859694342459406, 56.521393406775694, 56.745796126704064, 58.322710529450454, 56.66517180781211, 57.667776692298155, 54.310843636912686, 51.0654470997472, 53.93724180036976, 54.44759315060031, 51.811372080156886, 54.81427984852945, 56.610050739780554, 63.14697873207831, 59.2974312843815, 62.987675589899865, 71.53615582373835, 76.02455539088096, 49.84713931237498, 64.969896347292, 71.76189607189548, 55.28841203258884, 1.9461747883789002, 0.03947984322064346, 0.3794025010879963, 0.6701037876548306, 5.1311470904657925, 61.350388065461196, 66.94582170055759, 71.17265409038913, 69.9925619556058, 58.79630927116641, 54.65064640968077, 52.24219345277356, 25.963211521025627, 49.05172970987136, 57.88594284365254, 69.08889493634625, 2.482659052456579, 0.06554169475191063, 0.03662222801076789, 0.02471260407248572, 0.07872885648882197, 0.10255685691992122, 0.014919535512284888, 0.0026604943230913412, 0.1316053864936675, 0.11937537500935218, 0.1371970469312322, 0.34282967808746523, 10.698951059772122, 80.13694086382466, 55.98306379010601, 43.89549955244988, 20.29422167808779, 28.13632030640879, 55.317170850692264, 55.18915645537838, 71.72645353501844, 69.93664464642926, 59.94204928798061, 69.56889890855359, 5.265385306650593, 1.0929392758877048, 0.38993532138486064, 0.43344384479907255, 0.5327423842203233, 8.011853906416125, 61.79234504699708, 64.91586569816836, 67.72765205752465, 62.6491318979571, 64.89411615556287, 61.97437832432409, 62.148735523223884, 63.650022706677845, 64.86847954411661, 61.8306391469894, 61.43908069979761, 60.52603921582622, 55.82469809439875, 51.467274312050115, 52.69348959768973, 57.40690769687776, 53.6112222363872, 54.46030947469897, 54.021866936837476, 56.33233516447006, 57.32589898570892, 56.9385806206734, 35.957775500512895, 52.316141897632235, 61.69920444488526, 56.72098321299399, 58.43617293142504, 54.54842552062004, 50.65042111181444, 51.59590844185122, 49.401993443889005, 51.405395000211655, 51.00506613331457, 46.79625703442482, 49.305950287849676, 54.31056122626028, 53.51601846756474, 49.92955615443569, 47.95938099584272, 42.39387896753127, 40.64308981741629, 40.372218778056485, 41.13370772330992, 41.157940126234486, 41.3650804950345, 41.21559112302719, 40.01096064044584, 43.975080520876, 46.46476576405187, 46.90068229552239, 48.28216068206295, 49.11867672397245, 48.941546409360825, 52.44287367789976, 52.963129012815415, 50.69501846067367, 53.743625763923895, 55.71739773596487, 50.67673629330051, 55.0346189929593, 55.09340747710198, 53.81920591477425, 54.5552465223497, 52.19555647142472, 50.757678324176425, 51.87078814352713, 55.37972481020036, 54.062122221915956, 55.04674696153211, 56.7976341709014, 54.89798715037685, 52.01744556427003, 54.95885449071085, 53.169096592933904, 49.96552821128599, 49.42264864521642, 50.92206093572801, 49.90023643739762, 48.00508445309055, 48.156519320703325, 48.08839951792071, 46.46547571305306, 41.99649187826341, 41.10311323596586, 40.151361880763886, 38.555600489339525, 38.61468315124512, 38.62775641102945, 39.792249279637495, 40.97316118978685, 42.06863211047265, 42.21326951057681, 52.23510965224236, 53.49816383854036, 47.17547178268433, 45.576231248917125, 49.28771911128875, 49.532918237870746, 50.1274436519992, 54.57960836348995, 54.868612520156375, 58.973651393767334, 58.00578694189749, 60.095127628695586, 59.02099832411736, 58.04589317690942, 53.583275348909446, 55.16206072222803, 59.70806814009144, 57.23669644325011, 59.5706832024359, 60.93912755289386, 61.08365512663319, 60.30168356433992, 56.26581176634758, 53.439206692480276, 56.385126344619266, 59.336596150552076, 54.61526663072648, 57.741764360858554, 59.640066008413996, 63.04578550400273, 63.33494655547604, 64.97648592918151, 69.05202465672647, 75.2850866317749, 54.55847463300152, 67.41814567196754, 72.83826504984211, 59.69639124408845, 1.8874246699194757, 0.04258007464569904, 0.44898522537081476, 0.7033941077609217, 6.289205801102423, 67.27642259290143, 70.64996688596665, 76.95886396592664, 75.1834031074278, 69.25204200129356, 60.10944035745437, 70.95544107498662, 41.27747435723582, 49.635429382324226, 66.55178039304673, 81.79718602088191, 5.117363881680274, 0.14148502490453183, 0.0976819943095888, 0.02573709153840619, 0.08550874994046266, 0.2488954854948867, 0.14660757906254263, 0.25558246780307065, 0.2945885392687013, 0.3248250184039916, 0.3641493840804023, 0.6070295625155973, 15.079822771010862, 93.77357852074408, 63.52628761722196, 51.333117485046394, 30.77087436952899, 46.75477012511223, 61.88684671155868, 61.38667391192529, 74.73642549207135, 78.61948567052042, 66.86905307154503, 79.0835883540492, 7.2850544029666535, 2.3001560713014295, 0.8560779438384118, 2.1801310537322878, 0.9977445162592397, 10.1893743776506, 66.31504181892642, 67.74062725805467, 72.95293161945959, 65.54420194318219, 69.6274128267842, 63.57305403678649, 64.28477594929358, 64.96365977871802, 67.36875518675774, 64.21262787234399, 63.72091954754245, 65.08508459214242, 56.41207302770307, 53.12661732396772, 53.89181683140417, 59.77663901544387, 57.45170116424561, 57.94127179730324, 55.93736425522835, 59.53069856089931, 59.70561665873374, 58.81787838474397, 44.679459756420506, 53.83844514046946, 62.8337029487856, 59.951663017272956, 60.222992973942915, 57.358882196487926, 55.628132435583304, 52.3248887831165, 52.52999736416725, 54.20100158260715, 52.79612233561855, 47.90842940730434, 50.67617931673604, 58.08375581618279, 56.119989810451386, 53.96816184443813, 48.355732579385084, 43.84071580825314, 43.37912344163464, 44.10491881832, 43.9295849492473, 44.75116068317045, 45.43411593283377, 42.89818986769646, 41.44433590673631, 46.88388278407436, 48.45446648136262, 47.57324718659925, 49.96929368665142, 52.10465946505147, 51.17244151330764, 57.72507859814552, 57.13468736217868, 53.790639292809274, 56.89518743945707, 59.88109957787299, 55.150493652589866, 57.24422739398096, 58.066768030966486, 54.287364329061205, 56.63478912845735, 53.98322766826999, 51.83351385977961, 55.865757465362556, 58.29463420375701, 57.08463007403959, 58.951454700962195, 59.08437205899147, 57.37516787744338, 55.20100593566895, 58.76965284347535, 55.089630234626036, 54.33015738764117, 53.333592953220496, 52.98577677819037, 54.229513291389715, 50.43850721851472, 49.06967063103953, 51.05599811000209, 48.72478446652813, 44.14857872070805, 44.263170765292266, 41.52326576171383, 39.53719715918265, 39.579452853049006, 40.945645763028054, 42.22141235105453, 42.5218855181048, 44.690207050692656, 43.33809937200239, 54.7933893049917, 55.5488181883289, 51.273909307295284, 48.27579859764346, 51.202792813701016, 53.0170419908339, 53.16791988188221, 56.73923007903561, 57.49983649100027, 62.422273774300855, 61.15643470518051, 63.990064744026434, 62.10793502869145, 58.82903752788421, 53.524926170226074, 57.5733809317312, 61.40801945040303, 58.24341981641708, 61.86101398160381, 63.44021120379048, 63.60819455116027, 62.93529233624859, 58.00182927039362, 55.39002887664303, 57.44635105133057, 62.268344279258486, 55.66185305195471, 58.41329766858009, 60.49833943766933, 67.03202755220475, 64.83176615930373, 66.61263204390004, 67.4851397545107, 76.1501104600968, 61.626456245299316, 68.507121147648, 77.2442634644047, 63.53495213293261, 2.805077880620957, 0.1620184642172629, 2.877643935142025, 1.481256864724621, 8.696398696591778, 72.27658164116644, 79.84489687027471, 80.87121640482258, 84.59832314522036, 71.19136379611108, 71.9923274747787, 71.49702625889933, 39.355085434452185, 68.65317452338435, 77.31872573975595, 94.37885515151486, 7.564270284868057, 0.40700339261562596, 0.29366001006095643, 0.1601579737278723, 0.12906451799696492], [0.041508742818428625, 0.028108507131917343, 0.021983143881023414, 0.0600374564378252, 0.047586152795702226, 0.13719286409116563, 0.20445504676430457, 6.200823034009626, 70.08494946264452, 53.72314706925423, 47.32841676281345, 41.52715675292477, 51.07499022637644, 43.1801063014615, 43.19730981703728, 63.84808671089911, 70.17594845064225, 49.7752187328954, 74.9618205716533, 9.703380946190128, 0.23011013625129578, 0.05525100803483398, 0.2934392235211788, 0.40158647683358967, 3.8703274294253323, 61.24390748239333, 60.87878581016295, 65.02537827337942, 60.064199739886874, 62.905039095109515, 57.91202660529845, 62.58287522100634, 58.58648207879836, 59.82080490358415, 56.41357921784925, 58.51338871063725, 55.00543655887727, 45.6237546859249, 46.4819614348873, 50.978621513612815, 52.46742379280829, 54.756691609659505, 53.829196191603145, 55.48576608780892, 54.50327119519634, 58.09665256930936, 40.895933643464126, 35.111473145023474, 61.74837919973559, 55.73400897364463, 56.68427767292146, 52.82084895718483, 49.880640276016734, 51.15262962156727, 46.819657894872854, 46.711192592497795, 50.39183101346416, 49.80101616151872, 45.238625003445534, 46.56290738813339, 50.44292772969892, 51.37992312831264, 50.80755126091742, 48.82966080019551, 45.19787942209552, 39.98130359957295, 40.75266907292028, 40.891226799257346, 39.37051996108025, 39.4092062980898, 40.54528551716959, 41.44901529435189, 42.313984209491366, 44.69248594776277, 44.40752575474401, 46.02258912978634, 47.02095000974594, 51.695544488968395, 47.59850725050896, 47.239171074282744, 47.58248829072522, 49.29064912180747, 49.215955426616055, 52.653842279987956, 51.77343099348007, 55.81617870638448, 51.673669430517386, 52.27546299657514, 50.086129326974195, 46.6418529325916, 49.602289276738325, 54.82088511989963, 52.26432346528577, 51.40439871818789, 49.51629523308047, 50.52986314219814, 53.29015270356209, 48.9827234514298, 46.635439857359856, 48.44758272171021, 49.55531889392484, 48.385519058473655, 45.46435348449215, 45.93966630197341, 44.85985348301549, 45.06460905075074, 43.65910614690473, 41.146584864585634, 38.99588261881183, 37.2395315477925, 37.906444303451046, 38.20532498821136, 38.73775536014188, 37.631874469018754, 38.32790690083658, 43.64158884171517, 45.494865602062596, 49.189208784411036, 50.482657417174316, 46.81189552430184, 42.12100751938359, 45.56792759126233, 46.765815519517474, 43.93533906629009, 49.268726994914395, 50.88310787754675, 51.375279042028616, 53.17516842196065, 60.58835391075381, 55.95732911940544, 51.31097962779384, 53.443858623504646, 53.01198213331161, 62.31946452971428, 52.46689427283503, 56.41830175153671, 56.76302709887105, 60.96240289749638, 61.49028332002702, 55.54209524585355, 50.54189305151663, 57.12053937296714, 47.586285145052024, 53.326446394766535, 59.687742417858495, 60.04830237357848, 58.273704436517534, 64.33957930534118, 65.22697241075578, 61.36187668769591, 46.08369181233068, 60.60039950955299, 63.53524238832536, 74.53296430649297, 33.198337093476326, 0.06633284141219432, 0.03147002433486764, 0.2015780648517032, 0.661400415964665, 4.036449367000211, 66.90339734477382, 65.03774942890291, 72.17258391841766, 69.46063364705732, 47.759520546082534, 49.492247181554, 37.423886868261526, 19.31101291410385, 38.973489807498076, 63.14289162235876, 58.527109161500015, 0.7411513946229412, 0.07780988805837209, 0.024236016944351218, 0.03785479453302199, 0.030392895137230237, 0.013542995213591045, 0.036843730842754725, 0.10928041226561032, 0.03730378579348326, 0.06161288944103065, 0.15320194134068105, 0.24111886568848165, 8.79823225159799, 80.2424055530179, 56.870715771951986, 52.01455085508285, 35.17787102730044, 51.02889453211139, 51.59142125037409, 49.45504350046958, 69.83143883366739, 79.4293531294792, 56.135287054123424, 79.95017328569966, 10.167465979053128, 0.33418100507509324, 0.16736467008388814, 0.07362918537710944, 0.44228998463480707, 4.679650904670839, 63.74309270612655, 63.85689635430614, 68.91892294729911, 62.84456006942257, 64.20976061974802, 60.33574542691631, 64.99155175301337, 61.105020276961795, 60.28851616767145, 59.39146618689261, 58.75173153415803, 54.09074375706335, 48.95816549178093, 46.89493210084977, 54.25342798233033, 54.517721206911155, 57.62725860841813, 56.14704239752985, 58.2618510338568, 57.86384028773154, 60.8227429851409, 42.885791255581765, 38.1500901714448, 62.20736319018949, 58.30673471573861, 58.577225285191695, 55.74685865832914, 52.01864973191292, 52.606487504897586, 48.80021948968211, 49.73461827924175, 51.658462401359316, 52.565859594652736, 46.245873974215606, 49.235139739128854, 51.65821921440863, 54.33916314955681, 52.07909345626832, 50.19659503813713, 45.14326433981619, 41.668770005626065, 41.2625301268793, 42.219160910575624, 41.51030232829433, 40.96104891069474, 43.15703884247811, 42.97990852786649, 44.71791075121972, 48.528375702519575, 49.44892460300077, 47.463699310056626, 48.261015184464, 51.90380273326751, 50.40476306792229, 50.14562776011806, 49.742953315857925, 50.94606191881242, 52.49805750385408, 54.0000154126075, 53.37684100674045, 56.89008443586288, 55.414406407263975, 53.62903371933968, 53.75887201678369, 48.101904238424, 53.94604752140661, 57.991391843365086, 56.180696333608324, 52.20868856676164, 53.305853951361875, 53.08646794288389, 55.53205005584225, 51.87267872595018, 50.30713135196317, 52.069471882235625, 52.55873657041981, 51.458060664515344, 49.13028301731233, 47.164900995069935, 46.63309427999681, 46.863388399924006, 44.71031312019595, 41.669358361151914, 40.93166643573392, 39.512454848135675, 39.86680961424305, 40.432101603477236, 39.45787114481772, 39.113196788295625, 41.156924232359856, 46.74514070633919, 49.4182595129936, 50.086019500609375, 52.04106215507754, 48.366283755148615, 43.522893997930716, 47.37080973963584, 50.12824381551435, 46.543272003050774, 50.26163970270465, 52.513739139803, 54.71203542524769, 56.02522534708823, 60.542670065356845, 57.88406010596984, 52.316765554489635, 55.470923839076875, 53.13577605832008, 61.27643177586218, 56.61427121008597, 60.52233257601338, 57.7109266865638, 63.37882611059374, 64.36604745926397, 58.085026664118615, 50.755411194216826, 57.84706038813437, 53.31755830395607, 54.20736366702665, 60.78439789433634, 59.85911469305716, 60.20735056169572, 62.86576048020394, 65.6037631342488, 61.5426940302695, 50.118590862520286, 63.49770922814647, 66.58709741407826, 77.0515731073195, 34.89382082416166, 0.0811389078115744, 0.06445208023632727, 0.352024816937985, 1.2503909367707469, 4.90463903834743, 72.53604642806515, 70.43531910065683, 77.80974372740715, 77.11334259279313, 51.33748700541835, 55.43488117956347, 48.178767004320704, 23.332493535933956, 46.538918172159505, 70.72216987609863, 70.06682811244842, 1.853321499882206, 0.1415500044822693, 0.061959528905009074, 0.030757501278252854, 0.026185517274444143, 0.1800721535278905, 0.16134222308474203, 0.2771134608455243, 0.12504277089911123, 0.2342886862254912, 0.21599268330441368, 0.32686921677762465, 10.230240571883417, 95.69569679998583, 64.30695695261802, 64.89479472560268, 56.47826694673108, 71.69924797550325, 57.640979059280895, 59.40665360419982, 75.4259781683645, 83.7933115805349, 62.26792850802022, 89.58564819828158, 11.190282837037119, 0.7017570085102512, 0.47564523835336014, 1.0689901416340182, 0.8059270091114507, 5.6772405485953055, 67.20107386189123, 64.38908746165615, 70.99759086485832, 65.58883459337297, 67.01058787684288, 62.074179110988496, 67.80520516057169, 64.9838246837739, 63.53599156102827, 57.85856077747961, 64.28713329376714, 57.415274112455315, 49.816478144737985, 52.69866712631718, 58.80361664679743, 58.96936816553916, 58.88771618566206, 61.38288097996866, 60.5025520632344, 59.91992319783857, 61.786469336478945, 42.455832804403, 37.7508399563451, 65.57021902453515, 60.76941836264826, 61.84084907654793, 58.56129261755175, 53.38727058902864, 57.43508992656585, 49.673625423062234, 51.93074549398115, 55.22151208692982, 55.1495248271573, 49.54598365291473, 52.37625222052298, 55.949535369873054, 56.749608670511556, 57.42911223442324, 52.029267587969386, 49.459362030029304, 44.07695624136156, 45.59554892201578, 43.81754636764527, 43.21492518148115, 44.18063625212639, 46.695911038306456, 45.631642572341434, 48.16894146703905, 50.564368232604004, 50.660356475460915, 50.78074186078964, 50.93662469617782, 55.517631423088815, 54.28707015129828, 52.957955406558135, 53.515979243863015, 51.85308256456929, 54.0609258990134, 58.92494340096751, 57.29685383458292, 59.90872483099661, 55.8388735402015, 58.514377147920676, 53.84591725564773, 49.8075351407451, 57.116475797468624, 59.46006844120642, 57.81247292795489, 58.873317164759484, 56.21073384438792, 56.4503945842866, 59.903833635391734, 53.83578185112246, 52.68951623670517, 54.670615196228034, 54.56795892407818, 51.9538325648154, 51.677968348226244, 50.40754402837446, 47.98453515575778, 49.78566400466427, 47.94296587667158, 44.78167672311106, 42.23190861363565, 43.51712811377741, 41.42601059329125, 42.03632746973346, 43.352565073197894, 41.6638199744686, 44.612446062026486, 50.191652851720015, 52.00608245788082, 54.015253820726954, 55.76201469667497, 50.23282989378899, 45.73544809895177, 50.664600479987364, 50.64182327639673, 50.263946056365974, 53.64846906354351, 55.297919857886534, 58.11479353135633, 58.57008657147808, 62.050303643749615, 62.57257115456366, 53.357805744294204, 58.379188737561634, 50.417981455402995, 58.01258440940612, 58.302478944101644, 61.50379588527065, 62.32159829908802, 64.58802223205566, 65.02880642491003, 60.26675485795545, 53.589143214687226, 60.060116552537494, 52.62031778212517, 55.66033901706819, 62.07896048022855, 62.598737285983184, 60.1425608511894, 65.17164737947526, 66.37101404128536, 66.86775084464782, 57.66022220734627, 62.37837068496212, 68.6245333763861, 78.1320527292067, 39.517859874233125, 0.49233958125114446, 0.1805504222190188, 0.4150628214401584, 1.720638013174457, 6.915091055054819, 79.74235826923002, 77.6161982936244, 84.09827586143248, 84.54124481447282, 59.64847164769327, 66.08119795399328, 54.63794185269264, 28.039198498572073, 58.400922590686434, 80.12368325264224, 84.9165685715214, 3.580928829408461, 0.27412838392680694, 0.13605338491259084, 0.11810647293684945, 0.10361155314791588], [0.08837732020765544, 0.08364948519175092, 0.045156416843735406, 0.039995477850278544, 0.1505574671130988, 0.04774805015674041, 0.11961984132686931, 1.2018512381661324, 65.30278790381648, 57.898219862291896, 45.65953454663677, 27.57682950265946, 21.658671094525246, 42.865234113508656, 39.940671766957934, 63.05683874314832, 68.77545049113613, 51.68531102518882, 74.99908308829032, 24.37611464531191, 0.20593894375187738, 0.06023969981939562, 0.19718081209688418, 0.2206939044258287, 1.4950826067116953, 55.74902772903443, 65.60477902812343, 63.75487942849437, 57.15183988694222, 63.71847198855493, 60.21872151282526, 60.07021273336103, 60.9208728421119, 60.69491686359529, 53.679067473257746, 53.062196316257605, 42.350677982453384, 49.419926520316835, 54.393605647548554, 57.36431075680641, 58.3741484918902, 54.30918839669997, 56.347475513335205, 57.153397067900634, 56.83842289832331, 52.367913261536636, 42.5721703037139, 52.77950325319844, 59.5629757450473, 58.479542578420336, 57.264380531926314, 51.85070560824487, 47.34837770462037, 45.86401947083012, 48.516773331549864, 50.02637593976913, 49.498319010580744, 48.25817931082941, 45.198314805184644, 44.66495090915311, 52.539152176149436, 51.12620853608655, 50.14803217303369, 52.3211625314528, 52.71662373696604, 40.675994580791844, 40.211852673561346, 40.84727664147654, 38.521158156856416, 40.03090589277206, 41.588808567293235, 39.80279653303085, 40.43343128696565, 43.594940093255815, 46.683685010479344, 46.786870802602465, 46.87303350817773, 48.632616612219046, 48.63303238345731, 49.339557155486084, 48.254986501509144, 51.3831159376329, 48.36783309136668, 50.894294477278194, 52.67244608171525, 52.57747765510313, 54.00856225721298, 54.254126164221, 54.291659324399895, 48.66120284603488, 48.935784447577696, 53.65731400828208, 52.576308788791785, 49.11180473143055, 46.95482669338104, 48.78829940672844, 50.3344153588818, 46.85892866503808, 45.562702994192804, 49.88396644592286, 47.11821302290886, 48.46251126258604, 45.80488581811228, 46.30867112067438, 47.172706511712846, 47.33843057386337, 42.37574192785448, 39.30036052580803, 38.22508196676932, 37.88008205352291, 39.05456127658967, 40.85706295505647, 38.44410711719144, 39.167376487485825, 37.43473614415815, 48.06859939329086, 52.28596710389661, 50.05125161140196, 52.23342695543843, 48.14627016744306, 41.367473140839614, 46.104037146414484, 49.749817463659475, 45.752961481771166, 47.05832627511794, 46.680292160280295, 48.67676681087863, 51.7013103731217, 55.13262725645497, 50.74251836346042, 41.75416784901773, 37.655549895378854, 48.205494034674864, 52.38357528563469, 54.24461049418296, 58.08767034161476, 56.66972960195234, 58.479044437408454, 56.34789520694364, 54.77780572829708, 55.137620433684326, 57.456247191275324, 50.58666690703362, 56.12546151684177, 56.109058164781146, 63.04403612690588, 63.47948589632588, 62.170575280343336, 53.601804625603464, 53.23008944911342, 61.04236433582922, 67.45432561443698, 55.24437558266425, 65.6129297133415, 14.693481076148249, 0.14619049015304736, 0.04146710593974398, 0.11341214660675296, 0.7915347297826122, 4.61044313446168, 68.254410682186, 65.89416365469656, 75.45592154225996, 69.58762430375623, 65.5799739591537, 43.93165203832811, 41.32935162513487, 37.012771483390566, 48.41559971532514, 65.37438684894194, 61.96390951833418, 0.5448569922197251, 0.012802144140756179, 0.08262411480949772, 0.028587915378833012, 0.047214891265837416, 0.03898963504921525, 0.05689258123898218, 0.006295464455991263, 0.07991128255643191, 0.06765035942437188, 0.17087010456429375, 0.111653208732605, 2.615750220514113, 79.14235330397084, 63.703476767386164, 51.207856593593476, 36.55711758521296, 33.04707088778096, 50.22359271203318, 48.64794523485246, 66.08741098834624, 75.20354055589246, 58.465300452324655, 82.53038683245259, 25.94612567655502, 0.14510742568921658, 0.13867492246772015, 0.36381227475020195, 0.31872432318425953, 2.061770837153158, 62.02787553110431, 65.95098310901274, 68.50261826669016, 58.90077767833587, 66.64754113843365, 62.02421988210371, 62.83869220364479, 62.23188192613664, 60.83636537674935, 56.135714592472205, 54.96456153931157, 47.458121699671594, 52.24632370856501, 57.6373508668715, 57.93135604550762, 58.53819377960698, 57.70792999575215, 57.32113722831973, 59.11681398268669, 57.689153609737275, 54.1781694658341, 43.448121855335856, 52.81706386996854, 60.16764048607119, 59.71994507697321, 58.99905266300325, 54.73669536652104, 50.612648687055035, 50.06041034575432, 50.73296346972066, 50.3832959359692, 50.607443701836374, 50.39887166792347, 46.74002985800467, 46.166096887280865, 55.382850939227694, 54.35118521413496, 52.27097580509802, 55.92808392740066, 54.17314883201353, 44.99444177073818, 41.5987164743485, 42.20258889659759, 41.4194013995509, 42.606977416623025, 41.056962628518384, 41.05763335381785, 42.7729211315032, 46.378124529315585, 49.19004032688756, 48.5177029332807, 48.71230740700999, 51.091366121845866, 52.4146169231784, 51.72057313303794, 50.15930114253875, 52.25177580310453, 51.72668418576641, 54.52648770424628, 53.81093363608084, 54.73603248596192, 57.160633840868556, 55.19967625218054, 55.96608777200022, 51.781546377366595, 51.33348618784259, 55.75494266325428, 53.63878080921789, 52.588307319148896, 50.38464915367865, 52.89094955690446, 54.39910481053015, 51.6656050374431, 49.15328379600279, 51.42281424614691, 50.237952509234034, 50.29184195303148, 48.76446708556145, 47.125281133959376, 48.2737942664854, 49.37119499329598, 45.13295242863317, 41.037354700026974, 40.734218243629705, 39.66471733585481, 41.53904153454689, 42.90904698833343, 41.08738845394504, 40.208467668102635, 40.180622762249364, 49.48612828408518, 54.745783498210294, 51.108267614918375, 53.37051030128233, 49.5195351108428, 44.60520144431822, 47.85220223088419, 51.195199105047415, 47.90773907015401, 47.206403593863214, 48.84615044439993, 50.911552906036384, 53.22309194072601, 57.55593422920474, 54.55586233446675, 45.5597847507846, 38.912806818562174, 43.89319319878855, 52.62926470848822, 52.86652495784145, 56.65131015162314, 58.193813600847804, 60.46474041477327, 57.91723943525746, 57.164434617565526, 54.00162750674833, 59.136547427023615, 54.05692508143764, 56.60826998372232, 57.41402287637034, 62.814597083676254, 64.39107218096333, 61.90590550822597, 55.83078561290618, 55.82469417202858, 61.672383277646965, 69.48949444678523, 57.61026690083166, 70.08346680671939, 15.645160848094573, 0.12305961441128485, 0.39593336082273917, 0.0865540998957811, 1.4478410900600496, 5.9234364474973376, 76.72183513641357, 70.28685738963466, 81.08999836829402, 76.19576684890255, 70.75025404653242, 50.34917131547005, 49.15866528787921, 24.865585257930142, 49.07709567777572, 73.65435338789418, 74.62077832991078, 1.2078367750490866, 0.11277846165842588, 0.08604677348968484, 0.01592034224285594, 0.030120370849486322, 0.2601155326251061, 0.13796886519318627, 0.11197556320938373, 0.18920660289304872, 0.2110248176200736, 0.233917853704864, 0.2865889878763307, 4.217054901584502, 93.8620436576105, 68.6943123417516, 67.31365373057704, 33.73848668990597, 30.766981417132964, 58.39806710520099, 53.987224563475586, 72.64679062751033, 81.205245448697, 63.40413324294552, 90.4227133720152, 29.43812947119436, 0.20219663488528422, 0.2797499064716601, 0.5728761983975288, 0.6115405333618964, 2.5828552630639847, 64.80128542069467, 68.51668388612809, 71.38542698275658, 60.797753564773075, 68.36293482011365, 65.07343907510081, 65.83029962355091, 64.41372386870846, 64.15450226876044, 56.645795299160866, 57.911520619546216, 51.43147091711722, 57.75537498535649, 58.066007091153054, 57.20314841116629, 59.72325947976882, 58.23564567873555, 59.7325711865579, 61.79470631384081, 61.077316576434725, 55.53805912694624, 43.40201439396028, 54.85800643121043, 61.781436935547866, 63.170677692659446, 61.17855687295238, 57.61589157965876, 51.64197667952507, 52.74684167677357, 54.76311252963159, 55.60874023745137, 55.46504420618857, 52.346379449290616, 47.66682709417036, 49.16919685179188, 59.648679533312404, 56.66175542339202, 54.9215841293335, 57.59556977979599, 57.33879966120566, 47.081589852609945, 42.973366014419064, 44.810408084623276, 43.125361780966486, 45.20604579679428, 43.954319415553925, 42.17844278581681, 45.10720991319226, 48.37897654502623, 50.992526315873675, 51.21636029212706, 51.752756180301795, 55.22255151502548, 54.94545959657239, 53.89194234724968, 53.05957225061233, 57.59562861534857, 53.40896129608155, 59.75142994234639, 56.327973488838445, 59.57164810549829, 58.053380981568374, 59.76036510159893, 57.77483778615152, 54.6952869046119, 54.17918535970873, 60.48778041716545, 57.3350537976911, 57.12603853594873, 54.86891062028947, 56.520177472022276, 57.852975322354226, 54.91455524198471, 49.83240296763759, 54.001439232980054, 51.790481536619126, 51.928113583595525, 50.158920672632036, 51.48917682709233, 51.435095187156435, 53.225272778541814, 46.843011686878825, 44.22093076090659, 43.527710668502316, 43.18919835552093, 41.316803962953635, 45.40547086346535, 43.1479585555292, 43.32859154670469, 40.57858643993255, 51.836318354452814, 60.03525657038535, 55.308788745634025, 57.09975865579421, 52.34829356593471, 45.44247450367097, 50.23753673799577, 52.852431881812315, 51.43906462577082, 50.643133348034276, 52.13381836491247, 51.710076870456824, 55.99164985841321, 59.3268451383037, 54.968111284317516, 46.34514131853658, 41.3382593277962, 46.43389671079574, 60.8240609015188, 53.83577008401194, 57.83881556603217, 60.85549477607974, 60.96339917952015, 60.7422088807629, 59.127274943936264, 57.68892218989711, 60.088730242944536, 52.37127865514448, 58.960209431186804, 59.890697617684644, 64.87723035197105, 66.81725425104942, 63.31499345840947, 59.298819803422504, 59.4204838814274, 60.82224484412902, 70.04299579128143, 60.8562792501142, 76.0329806420111, 19.699560942188388, 0.21782167225835786, 0.38342458526453665, 0.4012516657671621, 2.160200265146071, 6.960717535788014, 82.90913874103178, 76.5368640038275, 86.3248328239687, 82.58872032165527, 78.96459933250182, 57.80474585871543, 61.69159504675097, 48.70099529143303, 68.90383751161637, 80.28397483210411, 90.44729094351493, 2.7304481690929783, 0.2745958201346859, 0.3335118425949928, 0.10448488572071638, 0.16117634972737682], [0.03078979379948109, 0.03329498558154991, 0.048279167423325206, 0.012642358309559286, 0.044331933867426655, 0.04964388794295731, 0.05688131208561602, 1.1445546030036866, 55.28346984617172, 57.19597439612112, 39.67600199484056, 26.673811635663434, 30.268846288804088, 34.02459613738522, 30.77443195927528, 64.09245429500457, 67.23317453938147, 51.31513341780632, 71.16027509012531, 37.37688510648666, 0.3692009678531078, 0.381483257177376, 0.23342496805614044, 0.21245954708466608, 0.25586265680049697, 42.922928256373254, 69.9237871170044, 61.25017150755852, 63.87591984964187, 57.99911499023438, 53.525871461437596, 58.859533955973966, 56.338097126253196, 56.98837118764078, 59.38239374468404, 53.77047046538323, 60.347418400549124, 67.58826671108123, 58.93830691614459, 55.45456363308815, 56.52535500064973, 57.18377974725539, 54.21503190071353, 55.761897025569795, 55.69097665048415, 54.12082049154467, 53.78082552263814, 57.19685692940989, 59.39302729022119, 57.69968517364995, 56.75441357397265, 52.533790296123875, 54.766850548405806, 52.646997744037265, 53.15521924726425, 53.04851116672639, 52.44513688548919, 49.24809532780802, 45.69518104676278, 48.31836415875343, 49.04529310041859, 49.58236363626296, 50.5103728848119, 49.94057409224972, 53.58671134518039, 48.580468700778106, 40.2390346988555, 42.50190104207685, 39.84553467842841, 39.39886693031558, 39.13793517697243, 40.835791941612, 42.16357700286373, 42.81149764214793, 46.641464617944536, 45.10280116911858, 44.927679108035186, 47.46156946305306, 49.242949178141934, 48.58691315497122, 49.00951323970672, 47.25120098360124, 49.241984275079545, 48.13527576385006, 51.75176774301837, 52.43913958149572, 53.08447930120653, 55.25246743232974, 53.960489688381074, 51.26767666109147, 50.68085085961127, 54.1180669876837, 51.2174036425929, 49.505073332017474, 50.667008815273164, 53.33795070648194, 53.53952130963726, 49.737909147816325, 49.501398071166015, 50.72529523603378, 48.330754926127774, 47.54955214838828, 46.62819131728142, 46.26905125956382, 45.26813691662204, 45.419916952809984, 41.44186481352776, 38.78005420008014, 37.71428738870929, 39.511760588615175, 39.49596128156109, 36.884823768369614, 37.714134416272564, 37.82353324274863, 41.17865416311449, 46.91347706702448, 46.94104740696569, 51.83263524886101, 55.23880581701956, 48.79641871298514, 44.35087888471542, 46.653906376131125, 49.953094297839755, 49.41151695866739, 47.34667539596558, 47.18352048627792, 48.94251915716356, 50.79042227037492, 52.490357891205825, 54.50513039865802, 56.04655127371512, 48.163026532819195, 36.646759433131066, 33.147542399744836, 50.7446756670552, 54.311306476593025, 50.549247495589725, 57.31574789170296, 58.07945689847393, 52.42455228682488, 56.66952956107355, 49.526862098324685, 44.37232640481765, 61.377742675042924, 64.860999584198, 66.1361111364057, 59.07946909627607, 60.652100270794286, 57.84316547455327, 68.46885450424688, 56.64878806760235, 68.74242413428523, 52.3172950744629, 58.00575556293611, 6.708513546374537, 0.07689568469481123, 0.18210835394359406, 0.6683914892135129, 0.5148819329277162, 4.653690697685366, 72.28939994688957, 63.59530172040386, 73.29140078636908, 70.80755987474996, 69.10498449879309, 35.26101350784302, 38.577671666299146, 29.48538422584534, 45.347859090374364, 68.81105776756041, 57.89787469371673, 0.2813733387137613, 0.1181504540445824, 0.030394498176211794, 0.033229071376544815, 0.08686348450400176, 0.035576889546768325, 0.014533722142298377, 0.03364077851837201, 0.02557916442803558, 0.03635185259965159, 0.03491125490155912, 0.03816175830340193, 1.9719568952437372, 69.38766187237155, 63.05352041798254, 45.55213220657841, 24.622262985475604, 42.9077761403976, 37.60588876662716, 39.74289801812942, 72.3428540075979, 73.53738046461537, 56.95690201174829, 78.31678851958245, 41.53519368940785, 0.35270041455664947, 0.36494170285521016, 0.3969238512217999, 0.1291907079998524, 0.20906344867281376, 48.40212637378324, 69.86686568106376, 65.91536014310776, 65.21646830343431, 59.774207145937034, 57.50853630804247, 63.19788325217463, 60.64443988184775, 58.19054234412409, 60.45553853434902, 57.58133549844065, 60.68476576958934, 64.88734614464545, 58.79793313241775, 58.246887191649414, 58.05847614042221, 58.39765133396272, 55.48898243135022, 57.81309658481229, 59.141717110910726, 55.65750706580378, 55.29275801873977, 58.266589257024954, 61.15634841303672, 60.20485593426613, 58.7041727958187, 58.116295799132324, 55.053689556737105, 55.817665284679784, 54.63587476361183, 56.993768368997884, 55.00766446513515, 52.39248691066619, 48.263803989656516, 49.805260166045166, 51.87003897082422, 53.66868103704145, 54.273938055961366, 54.09949848728796, 55.170372224623165, 51.75629415819722, 42.178258434418716, 44.23048957701653, 42.115700552540446, 42.74284831939205, 41.12163466791953, 43.973142870010875, 41.433863178376235, 46.515933082949736, 49.78829591504989, 47.76011674634872, 47.64635232187087, 50.85791841630013, 49.78214956098988, 51.09582193436162, 52.211242029743815, 48.2211874377343, 52.61612869078114, 50.40772053503221, 53.92745548678983, 54.55228121049943, 55.015199338236165, 57.39013956439111, 56.78577684587049, 53.34754482392342, 54.033492842028224, 55.17643228653939, 53.4975480264233, 52.20539769818706, 55.030728001748365, 56.08507679354761, 53.783841825300655, 51.0908366018726, 52.74958733589419, 52.29755378538563, 48.96440990509526, 48.73254683709914, 50.38411963370539, 49.49040366757301, 48.03081520142094, 46.341222870734434, 44.44761630027525, 41.30241278679141, 41.13260161492133, 41.13507270812988, 40.84538605905349, 38.509218462051884, 40.47044277191162, 39.93149734312489, 45.78901983076527, 48.5843518472487, 49.340325940039854, 54.44943274221113, 55.24027278346401, 50.64483565668906, 44.98129398592057, 47.62750925556306, 51.812003581754624, 50.986662372466064, 49.69228021560177, 50.084419173579064, 50.89853455943447, 52.337538426922215, 57.29226858385148, 55.3415483813132, 58.87840055650281, 51.745378202007664, 44.2414173003166, 38.732189516867365, 49.563461734402566, 48.62442278092908, 48.77852486025903, 57.59766824783818, 57.22319956748717, 55.02417372119043, 55.668187679782996, 53.64059686660767, 48.09550685267295, 60.80353906077724, 65.12118608720841, 67.11611532395887, 62.44361539040843, 62.717541956132465, 61.15639940384896, 70.16116111509263, 61.389235219647816, 67.87339164364722, 56.01028896147206, 62.417461026099424, 7.729389321419501, 0.11823693771035441, 1.8825924324412502, 0.4787121334623906, 0.6126171626871633, 5.7884426847580945, 80.89047524236864, 69.35385888622653, 81.0854954873362, 75.6502357605965, 78.47619364338537, 42.51776702942387, 51.53538234772221, 32.04043576794286, 51.54425082668182, 77.22566358504757, 68.06357952856249, 0.34014683817663505, 0.03471341652555331, 0.03335620366757916, 0.013570056311906347, 0.053520783136088046, 0.1065570692862234, 0.0962114655562947, 0.18712498878519382, 0.18947710853911218, 0.12311076610198907, 0.16441409776528038, 0.14195797694546564, 2.7306663509338134, 82.72278693414505, 69.19841535629766, 57.8618634131647, 32.005550207630286, 45.58824154638475, 46.41622251079929, 44.56837823314052, 75.92229920048868, 82.59103452005695, 65.5300735658215, 86.63542962843373, 42.80837543549077, 0.7147977861665911, 0.6137563660740852, 0.49929599668229785, 0.4689921018096709, 0.32327261783422967, 51.41454588982367, 70.34107239015641, 68.22713452000772, 67.31347330154912, 63.07239878562189, 59.52122995930334, 65.16602270064816, 62.00021497664913, 61.36883889475177, 62.65177165308307, 59.88469246895083, 64.85521801056402, 66.7803212135069, 59.44246876624323, 59.67303352971231, 62.207120003238806, 60.47086323461225, 57.563088632399044, 60.598167680924945, 60.66422823936709, 57.242787884127715, 58.21234287754182, 58.71549275613601, 64.69806432723999, 63.344772092757694, 62.84070437954318, 58.54403418879355, 57.166446793463926, 58.139814330685525, 58.13890041843538, 58.20703198832851, 55.630658441974276, 54.76465402110931, 50.86048364639283, 52.94624713159377, 55.01641919535976, 56.39993329201975, 56.589866222873816, 55.33781428490916, 58.62149707732662, 54.701507783705196, 45.53839214386479, 48.32606769377186, 43.65495627926242, 42.78790066319127, 44.321061026665475, 47.64962357859458, 48.250848400977354, 48.45313287550404, 54.4621176873484, 50.88005627355268, 51.98432114816482, 54.41430399494787, 53.80433228708083, 52.025831591698434, 54.76045708502493, 51.934110887589, 54.426122096277055, 52.39636221239644, 59.35740824668639, 56.65428723058393, 58.12061825106221, 60.29272879323652, 58.19815958699873, 57.37722712178385, 59.45271007476315, 58.32588764929003, 55.680700040632686, 54.24344555024178, 55.98529169636389, 58.27465365009924, 58.42428422743275, 55.19767192102248, 55.534372098984264, 55.79422520053003, 53.02941706872756, 52.071790003007465, 52.73874982710808, 52.38728192544753, 52.65335982845676, 49.469968118975245, 46.70322625867782, 44.23354902575093, 43.2736744419221, 42.62675008466167, 41.61468836569017, 40.158382923372336, 41.5682122015184, 43.23011259878836, 50.68933102392381, 50.75894132737191, 51.740992992155014, 57.70627867790961, 59.97273398983864, 53.68356250947522, 47.39572071260022, 49.042669034773304, 56.00658232165922, 54.75346742137786, 51.87863680624193, 52.38763886113321, 54.890903349845644, 53.25423163752402, 59.15242125911098, 57.80794259040587, 59.98978845534786, 46.732997048285704, 46.57986379438832, 44.535547994798236, 52.032625136836884, 50.892709839728575, 50.579485047248106, 59.22009783406412, 58.5696158870574, 54.52450690730926, 58.04928994947865, 50.48825463941021, 50.897487286598455, 62.965671093233176, 66.37268497097877, 68.84268776062997, 63.15263086749662, 67.58774895821848, 61.834710567228264, 74.06932446264452, 63.878547837657315, 72.71475745785621, 59.53142812175136, 67.98883484255883, 9.429432807430144, 0.15720337178678284, 1.7873321569735006, 1.458398394526974, 1.3883685200445115, 6.581087996882777, 86.47590683352563, 74.17072557633924, 87.03420131437241, 84.94275431479178, 83.5457629542197, 47.97674925096574, 57.25883037813249, 41.74984147471767, 64.65956234162854, 84.02309971470987, 83.1136275875953, 0.5649568717325888, 0.1633155889688961, 0.1327897584246051, 0.21789943018267233, 0.21096068073905286], [0.03885366976441395, 0.005673265080868958, 0.12724978593929162, 0.08534897464297472, 0.02185976350559823, 0.030873435279054028, 0.12741113937790358, 1.3791215323632764, 56.68827064575688, 55.99555653910483, 49.1768729302191, 50.84786538154849, 31.634509678809877, 43.846669966174716, 29.459363222122196, 44.50584388548329, 73.79437415830552, 58.043253421783454, 66.34148643862817, 50.15839507502895, 0.9728274758785003, 0.5229520869831885, 0.26708242813906363, 0.218593429233278, 0.046903055176259055, 27.00729350889883, 68.23354367286929, 57.17131837721794, 57.49912261962891, 55.18392009119834, 64.1019150518602, 57.45401928501745, 59.376729842155214, 53.10992763888452, 54.78627804786929, 57.11396940292851, 64.04222050020772, 53.51607730311733, 54.33384441560315, 57.86171436309815, 58.974200525591456, 57.17854730544552, 56.3557085683269, 54.46790710572274, 58.315438455150975, 55.15616147748886, 55.98740977625693, 53.86561147628292, 58.97699717552432, 58.167372903516224, 55.58795559790827, 55.45548539007864, 52.784398371173495, 52.469659543806515, 57.08761892011089, 53.059807592822665, 55.909009441252685, 49.29054321781282, 45.96891933871854, 47.29724568705405, 50.3759571813768, 51.217999842859086, 51.66939012465939, 50.5246973806812, 54.791596781822946, 51.53844571882679, 41.81902031744681, 40.55997479346491, 38.171157221640314, 38.19129859247516, 42.40236697658416, 41.13486090014058, 42.754615429909, 40.75474400674143, 45.00911143518264, 45.52723692309472, 45.23018406283471, 46.458442903334095, 48.71208775428034, 50.04981602391889, 49.19250357535578, 48.092639600076986, 47.96217764577558, 47.91197522994011, 48.32105882706181, 51.02428574715891, 52.47413104580295, 56.15856632109612, 55.17130967109434, 50.87346669166319, 51.532134625219534, 52.42335204155215, 54.68215873164516, 52.63771349383939, 53.07318287511026, 49.59740200350362, 48.37149266273745, 47.65113369111092, 47.693201111209014, 46.803736994343424, 48.33328485488892, 45.252259162164506, 48.20015568887034, 47.93569380237211, 45.23003501276816, 41.47662878036499, 41.16103879867062, 37.726093722927956, 39.5043041629176, 39.27366095204508, 39.99993485789145, 36.44747557178621, 38.13812694241924, 38.659664892381244, 44.786979767584036, 50.84272707662275, 49.500150757451216, 51.52701200977449, 52.2798050603559, 47.415081531770774, 43.55210388860395, 47.41699564841486, 49.82718621530841, 44.75063900793753, 50.20543213813536, 50.96251233931511, 52.41445610600134, 50.66537710928148, 50.70149429382817, 51.79191320173202, 54.190269977815696, 57.65379344263385, 66.77118209100539, 62.49926597841325, 51.57293904212214, 79.22298154523297, 46.16377484413886, 44.85315407476118, 50.62340382606753, 54.1715249707622, 57.62587401174731, 45.45796786585162, 62.51958777827602, 66.29104475821218, 56.92402862733411, 55.91323383392827, 58.608655237382465, 58.496342089868364, 56.93421502267161, 56.46390714953023, 57.99406297745244, 60.51485261609478, 56.96492325875067, 50.58842805124099, 1.6833222993919927, 0.028690165134086728, 1.944463164094956, 0.20814728412416675, 0.28365811933913543, 7.286960184574128, 73.61529442571825, 63.043310488424, 70.3087834388979, 70.23155981494536, 73.77098898733817, 39.56269648767287, 35.77990778030888, 31.15428605387288, 45.735977618925034, 63.044169487491736, 45.20837176230646, 0.12721501320840853, 0.1362905350904311, 0.06185008941458599, 0.08213609381909333, 0.02099668693488404, 0.06045355709389814, 0.025698649246365796, 0.09178702434104297, 0.057923930937484394, 0.021166949976055373, 0.014779907369595623, 0.10968380352301944, 1.7000162745675735, 67.42413905359084, 63.44121140818443, 53.39049085494011, 41.49167891471617, 39.01181528645177, 46.36251349602976, 30.770790038570283, 54.694651480643984, 77.66828736951275, 61.32751672498642, 74.28376828470539, 53.48311370418918, 1.4985192158529836, 0.8473658081023925, 0.10284481404889977, 0.10045688734540056, 0.043128635734319694, 32.61553760497801, 71.14142417907715, 61.026776836764434, 61.20366396442537, 60.16621666569864, 66.05934250739314, 59.232249336857954, 59.47483224253501, 55.41850136172388, 57.73290764900946, 58.74093717144382, 63.830730222886615, 55.39603794774702, 56.22982402001658, 58.8226911329454, 61.42347358888196, 59.494981458110196, 57.92854370609407, 57.06474757963612, 59.56041835969495, 56.54598666775612, 58.412117035158225, 55.88462798826156, 59.22052929478308, 58.23928171588529, 59.60833011134979, 56.81570060791508, 55.38328632231682, 53.667908330117505, 59.0418339544727, 54.538101842326505, 57.37076697811004, 50.88137811230075, 46.6992764319143, 48.19662555571526, 52.184228666367076, 53.63406612027077, 54.85441746250276, 53.05241392504785, 57.00714365128548, 54.01473999023438, 43.77182329854658, 40.6735784007657, 41.01719371734127, 42.67978837413173, 43.02732213850945, 41.44357104455271, 44.187653372364665, 42.81429429208079, 47.50300538155341, 49.14933789160944, 47.94804534604473, 49.342447942303075, 51.06171300334316, 51.10678495899324, 51.520810742532056, 49.08497571945191, 49.42631998369771, 49.22312944166122, 53.03969367857903, 53.77381232477004, 55.40817768343034, 57.25313901901246, 55.98536229902699, 51.66378113531297, 52.74701033869098, 53.995838088373986, 58.15282875491727, 53.37096137385215, 54.21921706968739, 52.58669914737825, 50.646930202361084, 50.43153716671852, 49.74171776925364, 48.59521289025584, 52.07506518210135, 46.631517487187544, 49.72240401852516, 49.242576552975564, 47.68004940402123, 43.75621618763093, 42.5163745880127, 40.56188498773883, 41.6207915736783, 41.1010383021447, 41.35693765455677, 38.07203892738589, 39.46648074734596, 39.62224591162897, 47.1607550497978, 53.0074792523538, 51.989981128323464, 54.71795820420789, 53.18347992435579, 49.13899460146504, 45.40209762511715, 49.5657523985832, 50.24808399138912, 46.84649475159184, 52.0341823177953, 51.159360408782966, 54.52995900184878, 52.57641861515661, 52.7178906625317, 55.30751789769819, 56.78892258674868, 62.13547791204145, 68.19284515996134, 61.834106522221724, 54.62213077852803, 70.22256189777006, 49.77041775180448, 46.28388958592569, 51.2867707590903, 55.33511569423061, 60.13248428221672, 50.20942118860061, 60.284338843437936, 69.32642582924136, 61.380343206467174, 59.06128106578704, 60.59366479996712, 61.43038480512558, 60.11489637436406, 61.23888684857277, 60.700702359599454, 64.82013240937265, 58.487834468964614, 55.95349696374709, 2.0523043193163413, 0.11927709358954623, 3.3683674998821753, 0.36622496141541394, 0.4479972477401457, 8.579511084864217, 80.14569559404927, 68.38675929654029, 76.28282777724728, 74.88371049204181, 80.01637504946801, 41.02528948937693, 47.70825124556019, 31.525046133225967, 53.830000277488466, 71.34014714148738, 57.022315379112, 0.12820712771386872, 0.11548779288967771, 0.0865011785419718, 0.18297887497371246, 0.030312666579359965, 0.12098314075340187, 0.16505689149902714, 0.1718918666724236, 0.23619527988616498, 0.25573683451981316, 0.13441394143287214, 0.3496576052519583, 2.465012554199465, 80.64090267304452, 70.05661426051971, 63.541557404302786, 63.82717263314032, 47.47563508249099, 59.03252617005379, 40.95952310869771, 55.96822546374414, 87.35380388075306, 67.97334932511853, 79.77347835417717, 58.195574745055175, 1.851109037956884, 1.1940375090606752, 0.540930331955033, 0.39989605786338933, 0.1749504573883549, 34.65124184085477, 75.93309356320289, 63.28744273031912, 64.72537579074984, 63.689642567788404, 64.72672900845929, 61.545184735328924, 61.87990019398352, 58.34955130853961, 60.92249278099307, 61.819640821026226, 63.772275140208585, 58.125654574363466, 61.41602108555456, 60.353835398151034, 63.372526784097, 60.17509298939859, 60.13794422149659, 58.130663441073516, 62.50646745004962, 60.91436562999603, 60.33768700015161, 57.221183469218595, 63.4161513851535, 62.53137450064383, 61.95816716840191, 57.28735385402557, 57.6980338558074, 57.82235337841896, 59.957350454022816, 58.703215737496656, 60.26383269217707, 53.380983029642415, 51.90195529691635, 51.25418763006888, 54.31835497579267, 58.009470047489295, 57.60209268139255, 56.21523672534574, 60.567737933128114, 57.831618016765965, 45.51814094666512, 45.49992545958489, 42.15035077064268, 42.519955711980025, 46.04434259476201, 43.840947228093306, 46.028315790237926, 44.657282675466234, 50.08923976652084, 50.02805079183271, 50.13006771764448, 51.27493304591025, 53.72315491399458, 54.69933086825956, 55.04372673649942, 53.27997415296493, 52.686041016732496, 53.821814290938846, 53.37422086346535, 54.56645665630218, 57.7633648533975, 61.492017007643184, 55.52719416156892, 55.390727058533706, 59.306393900225245, 56.60249625482867, 58.53212195058023, 57.03714586073353, 59.91676568984986, 55.54557046582622, 54.363132753679835, 53.69658085607714, 52.35360445514802, 51.92321846562048, 53.76607741079023, 50.27629367766842, 51.53239350165091, 51.427995697144546, 49.89150916376422, 45.66574365861955, 45.39628467252178, 41.65542217992967, 44.68884206587269, 44.30950180176766, 44.36841972412602, 39.35249274776828, 41.49567973229193, 44.1666922261638, 50.787774670508604, 57.67815920614428, 55.24519143566009, 57.825503041667325, 56.796920299530036, 52.42405022344282, 48.04470823657129, 52.859900074620406, 53.932048582261615, 48.908316089260964, 54.21309032747823, 54.810655578490234, 57.57939392520536, 54.333291361408854, 57.420447718712595, 57.4812719129747, 58.75581864387759, 64.20050774851154, 69.20421261941233, 59.62505117539437, 55.16682247961722, 77.98431273429625, 52.36730529415993, 51.12067407177341, 54.057917441091234, 55.02789605048395, 58.24568694637668, 48.99877771254509, 59.46013119912917, 64.97457573490759, 63.82084977242255, 61.70735513010333, 64.20708948566069, 64.26656830695369, 63.474437805914114, 63.72499881252166, 61.40654463921825, 69.97362475241385, 64.19839359098866, 60.70696246239447, 3.028145523801927, 0.3370708419430641, 5.446997909776626, 0.7381615679590934, 0.5208714534678768, 9.55190783546817, 86.69302571204402, 72.39293482995802, 84.88611528950354, 82.24192004049979, 87.06498407548474, 54.5126848836099, 53.57847044544836, 43.26259374618531, 65.65195729655605, 77.61878705793812, 70.97877133277156, 0.2751623574764498, 0.21561198357132175, 0.2074776313477947, 0.20843585412348473, 0.12927991127775562], [0.03645407554182795, 0.02693631408375598, 0.034371454028352615, 0.03520910222564013, 0.05796000218739914, 0.06308099352604439, 0.013552584719183225, 1.0627599469115658, 52.43609189987183, 64.72745072457099, 52.46433688748268, 57.90140874924199, 34.23472535225653, 49.72057227165469, 59.29781567665839, 51.87109801077074, 67.43009321151241, 63.381014793149895, 60.89765241069179, 65.96276590901037, 3.97914084215318, 0.8181594720771237, 0.22844983985827816, 0.5635400380819076, 0.21364332146702275, 12.605854465115456, 64.11879693308185, 49.91236048360025, 57.91159514457949, 59.605462858753825, 61.633289014139486, 55.47439513667938, 58.832987354647734, 50.12037161857852, 59.065787869115034, 56.78844405758766, 52.376471873252626, 58.66802030994047, 59.8770320800043, 56.967394351959236, 56.03654530740554, 53.25605553965415, 58.24247452520556, 56.798332352792066, 56.22907484731367, 54.42559257630379, 57.71244464382049, 56.789471718572806, 58.87697673613026, 55.627830413080034, 57.87723125949983, 53.80298691411173, 61.70806900147469, 65.58370413318758, 57.19029088174143, 54.44485141384987, 55.393351124178984, 49.56765867048695, 47.680720129320704, 48.29535553532262, 53.55863501948696, 51.77066180013841, 52.9679064596853, 47.956596113020375, 50.928564225473714, 47.454787685025124, 43.64413053758683, 39.832096638218054, 40.25144115571053, 40.716281244831706, 38.06550033630864, 39.63003573879119, 39.675260666877996, 40.42056199043028, 43.590982421751946, 43.8253205053268, 44.8388688025936, 47.46299720579579, 48.20133632229221, 46.9264954136264, 46.511406667770885, 47.28565508319486, 48.378470559274, 46.10089140553629, 46.45866255606375, 51.06138352424868, 55.82444314033755, 52.57535173046974, 59.800467414240686, 49.206631952716464, 48.611902575339045, 55.00859798923616, 53.77722478681996, 51.33879707705591, 51.387775713397616, 47.8657304856085, 47.636813117611794, 47.814092482289965, 47.502224829889116, 48.48468834354032, 49.051066829312234, 46.441400204935384, 45.24548915124709, 44.954355147577104, 45.13661200000394, 39.60307336622669, 40.602057903043686, 39.140331745147705, 39.32655803618893, 39.25044444299514, 38.557047843933105, 37.323674232729026, 37.10258983796643, 40.04085694589923, 51.83788338015157, 48.45395265087005, 50.60719659251552, 50.06005341006864, 49.394968478910386, 45.259923473481216, 46.58170338599913, 47.562288084337794, 49.43918928023308, 50.38970901120094, 51.05720227764499, 54.156490525891705, 52.982650649163034, 59.15704181117397, 54.50243180797946, 52.45702951185165, 55.284489662416526, 54.88833811975295, 56.399729328770796, 53.88279930237801, 49.26331804644678, 43.404144240963845, 60.63277867532546, 57.99731854469546, 44.82420306051932, 52.09370428516019, 44.228697053847775, 50.478221216509425, 55.68044116420131, 49.18687105178834, 53.8975787931873, 58.849963372753514, 59.4997981286818, 59.508776434006236, 60.520508673883256, 60.513271900915335, 57.22606682008313, 56.922793080729825, 62.822139801517615, 37.06193839350055, 0.5810851675848807, 0.010201282341093307, 3.2961775026013775, 1.4284909348334036, 0.6268564082922474, 9.4393358115227, 75.67806105459891, 62.47834797828429, 71.12145147015973, 67.93771851447322, 76.14178719059115, 47.45785890087005, 42.927148726678666, 35.93769296523064, 40.9623158362604, 67.53606780882805, 31.241756869900613, 0.16167495039201554, 0.11647466735373582, 0.04790504838550284, 0.06931010423408401, 0.054724441330519416, 0.10318952297130901, 0.04890034981672803, 0.11814753524959089, 0.03639127165379544, 0.03959759859548461, 0.05653350433755306, 0.16247655415246565, 1.1139015252551725, 65.046378643282, 68.88981896062052, 61.04834202797183, 50.01522856373941, 36.29878636329405, 57.22070886242775, 57.483699860111365, 54.34010844076834, 73.83878323339647, 69.02963576778289, 64.5985890972999, 69.62982900681035, 4.551130523604732, 0.9146644872042441, 0.16377861251033124, 1.7676308270423644, 0.15240966853114868, 13.776614300666319, 68.72159634867023, 51.797879126764116, 63.754942186417125, 61.8710042584327, 62.86867872361214, 57.10375162862963, 61.272321131921586, 53.63236381161598, 61.52449031029979, 56.61056457027313, 54.6652925399042, 61.077391101468, 62.936437668338904, 58.4209188338249, 59.26020406907605, 53.815703238210375, 60.32996777565249, 59.28240468425136, 59.77346581797446, 56.68914141193513, 59.61749276807232, 57.2624271915805, 59.74641715326617, 55.44706013894851, 60.00543086759506, 57.29868950382356, 59.20837386961907, 64.78108129193707, 60.25770987233808, 56.18941968487155, 57.55999780470326, 52.42597218482725, 50.36398610761089, 52.278828390182994, 54.35335428484025, 52.40156327524493, 54.47675989520166, 50.79468196438205, 54.632732945103804, 49.50430062509353, 45.291392649373705, 40.58452098600326, 42.59518677188505, 41.54059087076495, 40.618049406236224, 40.89274475651403, 41.917683616761245, 42.6264206055672, 45.86022261650332, 45.74660331972184, 46.56176597841325, 47.94284428319624, 48.99027401401151, 50.39214480307795, 49.19300171636766, 49.0349772668654, 50.91683633865849, 47.43534057371078, 49.475369222702525, 52.3448379578129, 57.817603388140284, 55.19058027575093, 60.92525805196455, 52.67777266040925, 52.63833715069679, 55.62209590788811, 55.06983010999618, 54.48116471690517, 53.43943418995027, 49.50796804120464, 49.493380746533795, 51.07455092091715, 50.19712063574022, 49.30360471048663, 52.3205388745954, 48.1537462049915, 49.06728190760459, 49.24211763566541, 47.390209782508116, 43.02465884916244, 43.4518559517399, 40.23067612801829, 40.21714002855363, 40.684474745104396, 40.82809232896374, 38.54075824060748, 40.31328516621744, 41.964042109827844, 52.16782923667662, 52.42374820093955, 53.23000315696963, 53.14678615139377, 52.502466247927764, 47.53539631443639, 47.039922514269435, 49.984273218339496, 50.12338007650068, 49.47480832376788, 54.28617977326917, 54.303693156088556, 56.90826854398174, 60.12833441457441, 56.912610607762495, 53.509542634410245, 57.33959982472082, 56.96986544516779, 58.89282311162641, 55.132235019437736, 48.33090005382415, 40.16431354707287, 59.1115423171751, 62.326485572322724, 48.24824786955311, 53.77431831052227, 47.208776627817464, 53.005627893632465, 58.81272831270772, 51.07582569122315, 57.92326419584213, 61.140090188672474, 63.05918824288153, 63.839681071619836, 62.407102046474336, 63.063797027834006, 61.31398454789193, 61.30559459809334, 63.31527586906188, 43.73541585860714, 0.2903103672208325, 0.22417888435865604, 7.502412055769275, 1.4972781534156492, 0.8046522388054479, 10.03580181829391, 81.8485455359182, 67.29659142032747, 77.70493799640288, 76.78527555158063, 79.50998137074133, 49.666172919734834, 49.6476750220022, 33.49678239514751, 48.23548055464222, 76.42670815990817, 41.283648167887044, 0.11412564259503158, 0.06767201672999129, 0.048891202726912115, 0.11087114021422402, 0.030461040573314797, 0.22541950246499431, 0.15766281003673233, 0.24599196629658823, 0.20623972519270836, 0.20074414750260694, 0.3065593678864741, 0.37239907850180903, 1.6650319195562795, 76.34269883555751, 79.71178731610699, 67.8401848577684, 67.92958351873583, 52.50665926164197, 65.49894955850417, 71.51441804824337, 64.5539564471091, 79.78613192035307, 73.72283012636247, 69.64362006033622, 78.90782694662772, 6.804564056857941, 1.5065825057606546, 1.9313413649797442, 2.3840165907336823, 0.32836308822997157, 17.197755575180054, 76.22715365502143, 56.20834512095298, 65.98619814841979, 59.230558795313684, 65.26375247586158, 59.39342344960859, 63.2005936099637, 56.86768770217896, 64.83067181802565, 56.89573264891102, 56.436885941413145, 63.1234602005251, 65.22923169597503, 61.260683459620324, 62.73960136598157, 56.4341010585908, 62.055798884361025, 59.881817371614524, 60.580218915016424, 58.59207145629391, 62.9183594642147, 60.20955885610273, 61.99009526160456, 59.60097566727669, 61.760511090678555, 59.896063420080374, 60.21451280963037, 64.63387473937004, 63.43738317489625, 58.301227708016675, 59.72277702823762, 55.0159602780496, 52.29833041467975, 53.28202555256506, 59.136904362709295, 58.10541906664449, 60.40536357510475, 54.66041311140984, 58.6687812497539, 53.1936937762845, 49.3791260257844, 43.777891205203154, 44.85307170498756, 45.35749243151757, 43.23513323260892, 43.00627862253497, 44.66472733405329, 43.76284107085198, 50.565615546318796, 46.856261453320904, 51.78334282290552, 52.241907119750984, 53.58334202920237, 53.596897740517896, 52.708021979178156, 51.40943111911897, 54.99939218644173, 50.95630714970251, 52.382496633837306, 56.80732634759719, 59.7164894688514, 56.171921991532855, 63.659134372588134, 57.797085469768895, 55.39765396425801, 58.31727020202145, 57.57090983852264, 58.747589511256066, 56.17699753853583, 52.794345501930486, 52.391894632770175, 52.198831650518606, 53.96061912659676, 53.01966213410901, 53.728724679639264, 50.076750939892186, 53.43543337237451, 51.82191933355024, 51.208405725417606, 43.80774828695482, 45.68348453890893, 43.16884125432661, 42.17948613628265, 42.97065957900017, 43.94261506295974, 41.50969436091762, 41.83781239294237, 45.52965702549104, 57.78941723608202, 55.92601291594967, 59.32234225734588, 58.34864131865963, 54.064710986229684, 48.730028675448516, 48.247177062496064, 53.016214370727546, 52.57389653113581, 53.76572047510455, 56.397842668717914, 57.63560933451499, 60.08433326598137, 62.16361307328748, 59.29711749476772, 57.01816158909952, 58.470007296531435, 58.48163712409235, 63.38567849128478, 59.0565977558013, 46.815912031358295, 51.07123259575137, 58.760658848670225, 59.79170876164591, 49.47794621990573, 55.68424194089828, 49.689879725056315, 53.63070857140326, 59.85292519292524, 55.350424705013154, 61.49250730391472, 65.28566283564415, 66.37741534940659, 63.95544982725575, 65.8801451037007, 64.97249295634609, 64.31172655474755, 64.90476146821054, 69.22915889370826, 49.12001032983103, 1.0144340174813424, 0.29325839612753163, 13.737061119848683, 3.7416594691814917, 0.6834860566642977, 11.76060232423967, 89.20018119196739, 71.73822064553538, 85.05997042502128, 81.51974893385365, 87.0097884824199, 62.57519522020894, 65.97721592072519, 50.84435093787409, 60.07165616558444, 85.74588314179452, 52.61152775056901, 0.16904655483461198, 0.2569629735643825, 0.21653337283961235, 0.20802864774821267, 0.16218012409104457], [0.13336482998584548, 0.07677530929926904, 0.11244931964263802, 0.07774119295420186, 0.08801394172253148, 0.05907092160815674, 0.07656779140233994, 0.2660738887085069, 51.092758563257036, 63.96161187079645, 44.07443415734076, 29.790779967461866, 26.839784768319902, 45.71380053797076, 51.61980744331114, 53.57066885117562, 63.34613315520748, 66.26789492945518, 57.30658915735061, 70.22467213292276, 12.189232072522564, 0.6566614573520999, 0.21777555376531618, 0.43936362069460655, 0.06224554400109957, 2.6199140616001624, 55.25412267254245, 47.87033534819081, 64.37571610173872, 50.95453031601445, 60.50534086842691, 51.50597633854036, 53.178008217965406, 49.66278791427613, 59.440370298201046, 54.37810444062757, 58.8525874383988, 55.99807077838529, 60.63934864536409, 56.03813386732533, 62.10467553907826, 54.464271068573005, 57.11138063861478, 56.99279562119515, 56.89295168845885, 53.42242287051294, 54.147182741472804, 55.71890392611104, 57.26930702886274, 56.54901473752914, 54.626013924998624, 61.1008115737669, 64.31782976273568, 46.68288484696419, 52.32946618910759, 55.494630644398356, 57.09825246564804, 49.14568616497902, 46.561169778147054, 46.890413530411266, 52.07046031951905, 50.37747121626332, 52.771329033759336, 47.99707497319868, 53.34652893004879, 52.054570797950994, 43.344630118339296, 39.76532220840454, 41.1825490766956, 39.06839547618743, 40.72062723098263, 41.26208689904983, 40.535628641805346, 41.303040366018976, 42.627283527005105, 42.20606411657026, 47.540107081013346, 46.89399073200841, 45.88220750131915, 47.50784950871622, 51.55426856010191, 47.498427975562315, 47.43457571152718, 46.849789542536584, 49.222996081075365, 51.777788746741514, 52.3595311564784, 54.63395280222739, 52.57057428359986, 47.58495938393378, 50.865931818562174, 54.28068845502792, 52.51718298081429, 50.892031269688765, 50.29642328139275, 44.60184781782089, 48.509673841537975, 48.23001669299219, 49.3956470489502, 46.84483951137912, 47.38514208024549, 45.67320792905746, 46.07808282298427, 46.80697687210576, 45.13828292969735, 40.841440154660134, 39.91344267322172, 40.136958937491144, 41.118645821848226, 39.25809698720133, 39.90540181436847, 37.49552895945888, 37.1909333813575, 44.01521029010896, 50.23622666635821, 48.877596086071385, 50.45743657696632, 48.21854376023816, 52.18132611243956, 46.82252906983899, 47.15731120878651, 46.23593861056913, 50.414647440756525, 52.49951270318801, 53.984322009548066, 53.25424340463454, 54.72631285267492, 59.03031395327661, 56.090415139352125, 55.151242825292776, 56.50489199546076, 56.28444302466608, 60.57050712646977, 56.671608417264885, 49.59753928645965, 33.78584146499634, 53.8778414264802, 66.71433910246819, 64.96205552931755, 57.684603660337395, 47.45445428356048, 49.04550490840789, 46.5284062200977, 57.29517113777899, 56.81159780871484, 61.224146581465206, 62.43793579839892, 66.66163029209261, 63.46201565957839, 64.58763783977878, 67.09783707895588, 61.27407443138861, 59.379259770916356, 26.312061240596158, 0.07246047994422336, 0.21976785734295848, 2.6549016035372213, 0.8127891344408836, 1.248836452441831, 12.598046006694918, 75.87074356694376, 63.18937955364105, 69.4573074771512, 65.6713181157266, 70.40248886231454, 49.49611856091408, 42.81562789793938, 25.963833216697942, 44.542345462306855, 69.74425238947715, 22.216485085025912, 0.3173350993423693, 0.11120243493707911, 0.06576802010738081, 0.03992761395150616, 0.03536829529630561, 0.0577322519083898, 0.03146622836920283, 0.02596622652133867, 0.18851925348562582, 0.07028798482591106, 0.05141068587920839, 0.045209177319080605, 0.5746654733534783, 61.14780156843124, 70.16408720324117, 54.506989602119695, 37.4438674219193, 34.571194110378144, 56.0632291916878, 57.929081070807676, 60.67938427771292, 68.64359609542355, 72.06099248701527, 62.40714519254623, 77.51507174584174, 13.495575497227332, 0.8615951864950119, 0.43053366063583287, 1.2512178214326983, 0.06027136989418538, 2.6654054657105477, 62.4868752110389, 50.24055696302845, 67.52677179151966, 52.04052479036393, 64.62738713910504, 53.848902179348855, 57.694409585768184, 51.78358993222637, 61.4235951823573, 55.550489118022305, 59.53456601788921, 58.39478408136676, 62.052464869714555, 59.08120278389224, 63.48441631563249, 55.27760590276411, 58.23577119458107, 59.0587511370259, 59.760106225167554, 54.59267770090411, 56.46044761903825, 55.0402593612671, 58.84999867408507, 57.40273821738459, 55.7871021762971, 58.42049129547612, 66.3542184522075, 50.50649366071148, 53.202362214365316, 57.50497871829618, 59.32007512738628, 49.88467639492404, 48.24506290497319, 50.13568847410141, 57.01304681839482, 52.60187871994511, 55.75805310280093, 51.4305373930162, 55.785482237415934, 53.91308784484864, 45.688928788708104, 39.7913981253101, 44.20912442668792, 39.967249747245546, 41.98221445083618, 41.84732414061024, 42.18723673974314, 43.59173943919521, 45.98409891128541, 43.543557043998476, 48.15921791138188, 48.09081177557669, 47.680594613475186, 48.5338277970591, 51.68373423237955, 48.816371810051706, 49.8104259275621, 47.38957828091037, 51.44760362563595, 53.37769216106784, 55.01293220827657, 52.97097767553022, 54.30796461720621, 50.48195531291347, 53.57510112947034, 55.28118702673144, 54.71564400580622, 54.05811748197002, 50.29921600895543, 46.20024896437123, 49.44890891352008, 50.89426702068698, 51.283464201035045, 49.055075491628344, 48.653299270137666, 48.05699309995098, 47.533278234543346, 50.0549151051429, 47.562342997520204, 43.297832319813395, 43.348556410881784, 40.749335058273815, 42.24643315038374, 41.13036978629328, 39.75729703903198, 39.8398825430101, 39.50303331498177, 46.242488968756895, 52.496210067502915, 52.57833665417087, 53.17780817708662, 50.235724602976155, 55.44577752390216, 49.78757027656802, 49.3306141514932, 48.748946266789595, 53.1874885866719, 55.44201989327708, 55.10109924500989, 56.40913909481418, 57.708722314526966, 62.490558316630704, 58.814477689804576, 57.450253809652025, 59.86349598053963, 59.82346819293115, 63.03407722903837, 57.89557226242558, 51.54710238979709, 37.8317702201105, 54.25524796209028, 64.74514845878848, 65.56126425343176, 58.5984060841222, 53.0088677713948, 52.898033357435665, 50.66899745695053, 60.41533424008278, 62.51380620464202, 64.76240296517649, 65.17549914698448, 68.33244231439406, 64.20120985277238, 65.063040871774, 68.42639876950172, 64.12849303214782, 63.628685012940444, 30.358178269478586, 0.11253489166378014, 0.26992507399089877, 4.277890862957124, 1.4281228449075454, 1.0554328368556116, 13.97860263624499, 83.05923215804562, 67.99129024628671, 77.42279406516784, 71.83020807081654, 80.4151467354067, 57.53383951802408, 51.682887000422326, 24.758739894436253, 50.15582592256608, 81.0281425906766, 28.623802277349657, 0.26161225392453136, 0.1700592617834768, 0.04434997523804346, 0.02573195300365408, 0.08515146951521597, 0.31581818396526, 0.09263991768802367, 0.1556422378146841, 0.21433770356159057, 0.20080664495546974, 0.15108091967000117, 0.18858362019302385, 0.7971700725536194, 74.36175284847137, 81.33142025240006, 59.843735079611506, 41.4147965369686, 43.04568275328606, 62.437425890276515, 61.762433052062995, 67.68652208389776, 72.61473701846215, 80.31773074980705, 65.30561593271071, 85.61977109601422, 14.842592920026473, 1.3165284717275252, 1.1441990156327526, 2.2287343682781344, 0.17834626468679599, 3.4528673656525153, 70.80627333733344, 54.07361868889102, 68.22398877912953, 53.53699138087612, 67.15491540970342, 56.438188168310354, 61.5402150923206, 53.789980334620324, 63.90201930076846, 56.83537129432925, 63.86850657001619, 60.943959912946156, 65.98123242778163, 60.714618928970836, 65.3705664603941, 58.43676520932106, 60.25856887140582, 61.48546272708524, 63.1452097431306, 58.91951484064902, 57.655887988305864, 59.857604580540816, 61.44988290725216, 57.97542779676376, 57.32823671833162, 57.14406182689052, 67.12337955351799, 55.22909795084308, 56.25335431868031, 61.01202088017618, 61.7757220422068, 51.57648094238774, 50.512687083213564, 50.49105521171324, 60.33225059509278, 57.04129572837584, 61.56974661734797, 55.44928412283621, 59.91678530170072, 58.19610426502844, 48.537185345926595, 42.75532145654002, 47.524919663706136, 42.369807381783765, 44.71489444855721, 47.013787761811294, 44.794969635625044, 46.273958144649384, 48.07504776985415, 45.740339294556655, 51.716921406407515, 51.48631741923671, 50.771214423641084, 52.61284566694691, 55.42008207690332, 51.35202723164713, 52.94229730483025, 50.18745199326546, 52.469286918640144, 57.016867206942656, 56.731189220182365, 56.008225794761415, 55.07573327710552, 55.23216132194766, 57.57895461974606, 58.519338946188654, 57.205905837397424, 59.079696593746064, 54.88068949791693, 49.610938102968284, 55.59289778432539, 51.52707869006742, 55.82936963727398, 53.01433163304483, 53.56845663439844, 51.663879194567286, 51.312827064145, 52.08796585759809, 50.23457534851567, 44.820747452397505, 44.28702269831012, 44.0525669436301, 46.46137683622299, 44.460065903202185, 43.510773874098255, 41.42911318809756, 41.137257468315866, 49.03696983091293, 54.60281702779955, 56.7427170661188, 56.14606964972712, 54.48402020239062, 57.7068042755127, 52.32338259297033, 53.416868794348936, 50.4898706559212, 54.89866572041666, 57.855328744457616, 59.58850253012873, 57.84323607721637, 60.87715802654144, 61.43101238435315, 61.409992402599705, 57.59827229284472, 61.373267250676314, 62.0395798836985, 66.46727685005435, 58.37325811386109, 51.77285440506474, 39.90651968986758, 58.45691050252607, 65.62305335075625, 64.42403185752131, 62.60398149490357, 55.90236494618078, 58.430779672438106, 54.82718836876654, 61.975821756547504, 65.55750662280668, 67.65261711612825, 66.60121010195824, 72.56339319290655, 65.85879172048261, 70.12433790391492, 71.62215771213656, 69.83667912021761, 67.38833565865794, 35.20753591291366, 0.261617922975171, 1.1009376015393966, 10.787254398868932, 1.30057594708858, 1.4861264872935511, 15.849546732441073, 90.95908180359872, 71.7704939073132, 83.19683674843081, 79.28038935507499, 83.68461485831969, 65.95517220035677, 63.26010381021808, 38.11919366159747, 63.32554855654317, 91.08106751595774, 41.26161621462914, 0.5601700479465147, 0.3787937063363291, 0.1849192377900885, 0.13647287933816835, 0.22780316971963455], [0.103377727791667, 0.08009200269776968, 0.012064913790973445, 0.04764688824633918, 0.06604589551927582, 0.018983122502123157, 0.035213625974833004, 0.3565489951400988, 49.29099821275281, 60.90767014411188, 45.416673152677475, 31.97288274765015, 24.415379531921882, 47.787079118913226, 53.24762244378367, 62.86420722161571, 64.01614850567233, 67.9877208894299, 55.24948643099878, 71.28397095587947, 18.20849741658857, 0.430768788341553, 0.6160200026727493, 2.294520115660083, 0.1022527429966196, 0.09498467533698968, 37.05150096647201, 50.73057082391555, 56.17418519912228, 50.82768086464175, 56.9238874220079, 49.67256638311571, 53.47414716597527, 50.93924483945293, 56.89813706182665, 53.10553066192135, 55.517199962369865, 60.29242284836308, 62.42240321251654, 54.742551465188306, 60.89890756914693, 54.397418191356046, 54.54222817574778, 58.151259806848344, 56.98884579443163, 50.63661436880789, 54.197616577148445, 54.54166335444297, 57.29352374230662, 56.10246858289165, 57.709938249280384, 56.88273783653014, 37.38931117519256, 48.95048549098354, 55.56777892574188, 55.03393257817915, 53.191556084540586, 48.44462133223011, 47.32211743631671, 48.811755180358894, 51.140305534485854, 48.898580766493275, 50.26008644411641, 48.88800213413854, 48.98592410549041, 51.40017824788248, 46.34201126713907, 39.55184721177624, 41.894133706246656, 38.4900184600584, 38.8550381506643, 39.21180125205748, 40.599116125414454, 40.08742724695514, 41.15990915606099, 43.542933387141076, 44.35934335954728, 43.0548571771191, 44.94423543253253, 46.120436576104936, 48.69133449369862, 46.099314612727014, 46.019188434846946, 47.36139605122228, 48.58190428826117, 53.1782357154354, 53.853463895859264, 52.27254475316694, 43.19563104260353, 45.83066363488474, 46.67338878877702, 51.06939692651072, 55.368067526048236, 49.00452006247736, 49.49741686544111, 45.89108774738927, 49.45172125293363, 49.48731283987723, 48.993231481121434, 47.10480243928971, 47.88562082475232, 46.96667225130143, 44.44267803622831, 42.88189634200066, 40.178634120572, 38.2093846413397, 40.2323470577117, 38.173883268910075, 38.75917934602307, 40.14812200300155, 41.17103299786968, 39.863883526094504, 40.42146413556991, 44.285281165953606, 48.413669909200365, 48.75453956665532, 49.25836409291914, 49.316701504491995, 53.06218454914709, 48.083029793154815, 45.45502216585221, 45.90429436775946, 52.27518058592274, 54.66031505215553, 56.07689080699798, 55.7629599878865, 55.65891519669564, 60.55284469358383, 55.828643998792096, 55.70704660108013, 56.42622886165496, 56.517451424752515, 56.986135436642556, 56.28248183957992, 56.683214710604766, 63.36730218702748, 57.95084630289386, 57.14383432942053, 55.308522024462306, 58.46928165804956, 55.361850569325114, 54.56067900503836, 55.01326953211139, 56.25852400256742, 59.20414163220314, 61.926564631923554, 61.636940740769916, 60.010408355343735, 59.89466705629903, 65.52094228806035, 60.83809121962517, 59.05344417018276, 66.01804779421899, 24.247759003793043, 0.3041120234035677, 0.062175535056139195, 5.268267758430974, 1.320500116675131, 0.8536662990527769, 22.60336022223196, 75.17773136015862, 63.099667103059836, 66.38027867963238, 70.76526887955205, 62.17499186915737, 42.27574110031128, 44.20664548873902, 34.465380330239576, 46.254930726943485, 69.26775501620385, 21.72111326648343, 0.31142037962713554, 0.20329180353831863, 0.0981318794431225, 0.07277999223480303, 0.08395768236368896, 0.07383798264087209, 0.09581505335987577, 0.04872642487527863, 0.04554541713948693, 0.11479505022326786, 0.05266684790953033, 0.008287040250105484, 0.5079702876748577, 60.59937577093802, 66.28060340881348, 52.49259756457422, 31.686000593246956, 30.929718594397272, 60.116394719769886, 54.55614866748933, 66.47928714752197, 70.24781411693942, 74.96043989735266, 58.62989487186555, 76.13250686276344, 20.451693073395763, 0.4810077925362895, 1.1989255177397882, 1.3655339517901022, 0.12359005369005666, 0.23291666871838032, 41.555790055182676, 54.395562910264545, 57.54823069418631, 54.57863169331705, 60.24797847194057, 52.25429004238498, 56.91410110842798, 52.940108622274096, 58.47012104526643, 55.54449181402884, 58.76533431391562, 59.93172560968707, 64.8728019960465, 57.845377691330455, 62.18313078726492, 55.15506713621078, 55.404118030301994, 60.05957526545371, 59.13874787669028, 53.620537865546446, 55.11444314833611, 56.50257387468892, 58.24516919351394, 58.145427242402114, 57.812916155784364, 58.52652865071451, 42.71789812272595, 51.099053967383604, 58.047375832834554, 57.29890523418304, 56.18559537395355, 50.96524230895504, 50.41462390653549, 50.90271188366798, 55.259123694512155, 52.19736076170399, 52.95113832719865, 51.88218655124788, 52.89328336715699, 54.63627092299923, 49.10689000160464, 41.975734695311516, 44.149072939349765, 40.41080705581173, 42.51777487416422, 39.58731328287433, 41.18285502156904, 41.474122385824884, 43.329709422203806, 45.51994915931456, 45.9441731053014, 47.82344733515094, 47.343784609148585, 49.160438199197095, 47.90076509598763, 47.800219058990486, 49.892623116893155, 51.79886756404754, 51.84623410624843, 56.11156848169143, 56.15144721923336, 53.34534829662692, 49.40952831699003, 49.80094555885562, 51.49195386517433, 54.12575483322144, 56.286306150497936, 50.53092610451483, 53.38942004788307, 48.99533779390397, 52.789834776232325, 50.59142866442281, 51.802495756456935, 49.9157964798712, 48.93175225104056, 48.72158773483769, 46.67655806387625, 45.998223366275916, 43.21139897069624, 42.10046606679117, 40.033824136180264, 39.90034980158652, 40.32241644397859, 41.07105962691769, 43.39877059382778, 41.83258779587285, 40.931132993390484, 47.3328019726661, 51.870917581742816, 53.29061554324243, 52.62186711834323, 50.77654884707544, 54.75884891325428, 51.82570442076653, 48.775371274640484, 48.6312202484377, 53.37118887132215, 56.095647581162, 59.39379607477496, 55.8039056101153, 59.43621650818856, 63.595270341442486, 55.69385174782046, 60.30624528085033, 59.55812377314414, 58.42559037670013, 59.345492086102894, 57.46835947036744, 58.5542715749433, 64.28841198644331, 61.99571209569132, 59.938864323400686, 57.313139515538374, 60.019841655608154, 57.58463813412575, 54.7819830525306, 59.32034969329835, 60.983132623857074, 61.890027753768436, 63.646814207876886, 65.30594148943501, 62.69649451778781, 63.02420854568482, 67.13258927868259, 64.21375751495361, 63.77668388428227, 70.03990496358564, 27.85305653848956, 0.24249065336921524, 0.8687447480136349, 6.802139051498906, 1.3040302068956438, 0.7184596864446517, 24.25349743135514, 81.30858421325684, 68.67603409674861, 71.86378355949157, 78.44724655151367, 71.27944454070061, 51.1576267211668, 45.33857876254667, 24.099875842371297, 53.19263473633797, 77.99441675986014, 28.176222578171764, 0.4520121613337148, 0.3058090613734338, 0.12436290617070853, 0.029573816911227284, 0.022517268042711, 0.19646209904984122, 0.1909565775384826, 0.16818525750310193, 0.19497619491190682, 0.21113573182975093, 0.20724521559332648, 0.1434721344060475, 0.8768836661211906, 71.34702697876962, 79.35569886238345, 61.01686892970916, 43.16469530905447, 36.461294081903276, 64.48298508121123, 64.036627200342, 75.26421177771785, 75.06440624114006, 78.46267715577157, 63.4770893281506, 84.05863638847106, 20.613675194401896, 0.5476149700341687, 1.8993360501143242, 4.38756670682661, 0.29741908093133285, 0.40172618062746146, 52.282429126001176, 58.72056438076881, 59.885167075741684, 56.614275132456136, 63.5473507450473, 57.039369844621234, 58.69876384735108, 53.43782994054979, 60.13451999233615, 57.12522268295289, 60.14036824626308, 63.043671346479854, 67.11742539559641, 60.79493338061918, 65.14325726416804, 56.51934592954574, 57.69465277271887, 62.97490435261881, 61.1020863440729, 55.088277016916585, 58.8598124442562, 58.90298597274288, 60.702341910331484, 63.602475735449026, 57.301760719668486, 60.50340321756179, 47.59471431855233, 51.83878944766138, 60.31312511813257, 58.86917514185752, 57.51086619592483, 52.69669025175033, 52.78849332563339, 54.481815830353774, 56.68541516027143, 54.993057558613444, 56.717429545617875, 56.80884430485388, 57.580456887522054, 57.29510837985624, 54.06270273270146, 42.96081835223783, 45.893951077615064, 41.27463063886089, 44.23716937341998, 42.10196441219699, 43.0856320934911, 43.48407822270548, 44.712815592365885, 48.59420091875138, 50.086737294350904, 49.526465938937285, 48.97382359350882, 51.527749415366884, 52.91968876315702, 51.59173896235805, 52.70636281659527, 52.68547619542768, 53.304802756155695, 56.54430789332236, 59.24576582447175, 55.60203690682688, 50.71233180261428, 54.6542981363112, 54.325987908148, 57.48656711270733, 61.419763026698945, 54.75921761605048, 55.289216118474165, 50.623062579862534, 55.69552659988404, 54.71911530340872, 55.77253057110695, 53.33615033857284, 53.245508286260794, 51.081191493618874, 48.9695756666122, 48.75196649182228, 45.75715841785554, 44.7175028247218, 42.27131274438674, 42.83363157703031, 44.53632854646252, 44.77697380127446, 45.321967524866906, 43.710932423991544, 45.36392511860017, 49.44284492923368, 55.92536572487124, 55.074368292285556, 55.67079997831776, 54.59811018359277, 60.22296551735171, 56.11856991244901, 51.21142987282046, 48.54845431543166, 55.37911684282365, 59.25712108612061, 61.07568487044304, 56.76713774281164, 60.88156284824495, 63.131406922494214, 57.53801291988742, 61.147291660308845, 61.250497064282825, 58.31378713730843, 63.364258427773755, 60.49511524938769, 58.31761537059661, 66.69534698609384, 62.91605703292355, 62.81073354905652, 60.7507674924789, 63.70131161905105, 57.849143166695875, 55.874892665493874, 60.163372947323715, 63.86006170703519, 62.8763783362604, 65.19046691156203, 65.77654746270949, 64.46900183154692, 64.8412779069716, 71.16586838999103, 66.68463891552341, 69.77978121849799, 75.14950598439863, 32.475138325845045, 0.6216457846664614, 2.3065372772755164, 11.74675831871648, 2.020149218939966, 1.0517664013370391, 25.832682886431297, 87.58349003330355, 71.94223880767822, 76.91638469696045, 84.37896067096342, 75.44593518780124, 58.23957197127804, 62.9433096608808, 47.48735904693604, 63.96115687585647, 89.47935981135215, 37.238401905182876, 0.6481994952886336, 0.3989664867760674, 0.17693267924891365, 0.2507043263364223, 0.194088023216013], [0.14832962214225723, 0.015005142007383608, 0.01983939621206974, 0.036237981290586536, 0.15657482728842767, 0.011542075062020412, 0.06266504991799593, 0.11329739429657498, 43.21608620305216, 64.74834911284908, 42.209707998460345, 38.168266434823316, 48.66281101780553, 44.61417190490231, 50.19112725411692, 63.22581052780152, 65.25516640755438, 68.46707374818864, 60.61175869357202, 68.97212597631639, 25.40225963438711, 0.23083336921709202, 0.8925038924620998, 1.2782653829743786, 0.358407738949022, 0.07406201739344867, 21.342031878809777, 55.3574182910304, 52.663863935778224, 49.13087137283818, 51.02416807605375, 54.424427632362615, 56.094761125503055, 55.07678054994153, 53.336001288506296, 52.739738264391505, 59.03593470973354, 58.00222542978103, 58.24826394357989, 56.37582248257053, 59.77833740172848, 54.606845301966516, 51.054660581773334, 59.20329832261609, 55.33315058677427, 48.94226812547254, 49.15718263195407, 53.32117080688477, 55.62133104570451, 56.85960369725382, 54.82989088181527, 40.97014488712434, 53.39832382817423, 60.37676557417839, 55.35391953683669, 56.02760230341266, 50.611542578666445, 47.99811047892417, 46.72370887571766, 46.938105629336455, 51.095378706532145, 51.25646260476882, 49.859761499589496, 47.55785972841325, 52.2374983756773, 51.9735973881137, 52.11257088568903, 41.559233896193966, 43.41101231113557, 39.20676492875622, 39.56545391390401, 41.02132789550289, 41.09022432757963, 39.51492594134423, 43.53758719659621, 42.31887932746641, 46.6233197335274, 43.75201532917638, 44.601887041522616, 46.555337213700824, 48.404256220786806, 46.25759793866066, 48.084096677841686, 49.813359860450994, 54.28004126394949, 53.125166047003965, 54.05417942231702, 46.518914084280695, 40.740192013402144, 41.613295924279, 43.88193207402384, 47.74408994182464, 53.739664170049856, 50.92976839311662, 48.794653646407596, 47.1312980498037, 46.4620554062628, 46.79928902656802, 46.41291595274403, 44.93132691229544, 46.000455194903964, 44.37737841759959, 46.02419730155699, 44.58646820437524, 41.055323077786355, 40.09019251792662, 41.321318611021965, 39.73449237885014, 36.055972037776826, 38.83674029381045, 40.2926613438514, 40.519695974165394, 42.14063898209603, 47.697284298558394, 50.67837976640271, 52.36293185141779, 47.940671290120775, 48.22004602801416, 51.900551088394664, 47.81783050106418, 43.64626430696057, 52.00605107891945, 55.61206248498733, 56.98564514037102, 51.59877961681735, 56.67401283018051, 55.64084875968195, 55.02136922651722, 53.669885204684356, 55.0295473683265, 57.88267943166918, 57.25942657839868, 57.138633266572036, 58.73695204334875, 62.26917974410519, 53.655372435046786, 55.55191686076503, 60.932232026130926, 61.17008063101, 59.65917187352335, 58.37048499814926, 59.75459921744562, 53.6750509662013, 54.54982580677156, 57.302619718736224, 58.52877224645307, 57.20407409052695, 56.93301085502871, 60.704887528573316, 59.86569250783613, 65.65925290507656, 61.526588778341974, 68.24048626807429, 20.680335875480406, 0.43889921819490774, 0.46633632012432624, 2.963467355697386, 2.119206103586382, 0.49858325912106427, 28.997619844252064, 74.43597193687194, 65.64130021679786, 66.8595217120263, 73.17835023326259, 59.2742814556245, 45.02278089523316, 42.57060920038531, 43.51206433388495, 50.738584226177586, 61.373549661328724, 12.241121107532132, 0.36415428704311775, 0.15683420933783054, 0.15220017412737494, 0.038275740695216005, 0.08589255999052718, 0.08386490145517934, 0.04234579729757482, 0.06476658231188213, 0.010639976845273088, 0.05874611948045993, 0.02556200980419113, 0.04573112068277213, 0.050099963066919204, 52.79953872003863, 72.98070984501993, 49.99851534443517, 40.184290178360484, 48.871692918962054, 53.03660677325342, 61.107946365110344, 72.85271506155692, 71.65925548922631, 73.53521531628024, 65.13440055231895, 73.7368094536566, 27.71033717739967, 0.1925248054847602, 1.764707803245514, 1.2852436472331326, 0.31564664155725514, 0.13352671968600444, 25.709387102434714, 58.798796053855654, 53.94796556042087, 52.77375305852583, 55.9178622307316, 58.312763398693455, 58.063669358530355, 55.530700760502974, 54.70067231885849, 54.62389584510557, 62.53548906695459, 59.87202321329425, 59.69129608523462, 58.833026578349454, 62.03977600220711, 56.63963717799033, 53.71721644555369, 62.082502380494155, 59.52084164465628, 52.01690819955642, 51.25556045962919, 54.89471981602331, 56.714989831370694, 58.46368051344349, 55.880540878542014, 43.98686332087363, 52.71402712791197, 62.43351136484454, 56.424063713319846, 58.78334191537673, 51.311920996635195, 50.37288988790205, 48.23707695930235, 49.266644216352894, 54.816448919234745, 54.37262881186701, 53.478042079556374, 54.16977951603552, 55.149493448195926, 53.7863286079899, 52.32282169403569, 45.26398704897973, 44.63373668732182, 39.58951373254099, 41.65362965676093, 41.40762644429361, 42.668786125798384, 42.03159709130564, 42.94116727767452, 43.662346024667066, 46.083480004341375, 47.04192684542748, 46.310471488583474, 48.35028440721574, 49.84764529812721, 47.56221748167469, 50.33014782013432, 52.17312835877942, 56.011042056545136, 54.95576758538523, 56.08207225799561, 48.990521123332364, 44.292945477270315, 44.73636550288047, 46.61758915070565, 51.50872199766098, 56.089465925770426, 53.278828820874615, 49.22751465151387, 50.30679402812835, 49.47968382989207, 48.213550583008804, 48.20430555651265, 47.337371533916844, 48.471544481092884, 47.21158112249067, 47.98419783192296, 46.92245144997874, 41.09778665727185, 41.67673241707587, 43.17470127536405, 41.436557846684615, 39.59414997408467, 40.15611187104256, 41.63447672320951, 43.04808324383151, 44.529166298527876, 49.83714511317592, 53.66271511200936, 55.526135121622396, 50.17630069486557, 51.74493497417819, 54.472653173631244, 49.09196538309897, 46.755476151743245, 52.24000869258758, 56.177001460906006, 58.637468968668294, 54.27870373572073, 58.643870276789514, 56.64282606494043, 58.09408733921667, 53.8086861179721, 56.52670821835918, 59.90305308372744, 59.839667581742816, 60.696117108868016, 62.846544788729766, 62.73787552310575, 55.8845809198195, 56.029194785702614, 61.292113411811094, 62.27373753824542, 63.667065405076556, 60.37677341891874, 61.61153162679365, 54.93108410989085, 56.68110839782223, 58.57372653099799, 61.70942614155432, 60.28667265369047, 58.30705242772257, 64.36483544688072, 62.85743328832812, 68.6014384608115, 64.81202879259664, 72.61575683470696, 24.512634700344456, 0.4325139366330639, 1.140726614863642, 5.013100908648584, 3.154138917884519, 0.622631096311154, 32.22296522509667, 79.97886934588033, 70.234556505757, 72.17849885263752, 77.03593853981265, 65.53592181974842, 50.62311749304495, 55.33781036253899, 41.31154406455256, 55.373331346819484, 73.29191069449149, 15.799699291106194, 0.3238601766286358, 0.15362851441867892, 0.06391172777981528, 0.03278079119721248, 0.015789335462144546, 0.28573584172033495, 0.16091405654386168, 0.12719854997891572, 0.19900725763891974, 0.2455390704375121, 0.11643661576653681, 0.18576092327073698, 0.28235524892807007, 65.10273918028801, 84.14265355756207, 59.04816073756064, 48.39749405460973, 59.60852230748823, 62.614940597165024, 63.334483715795706, 74.96356994875016, 77.27925100634175, 79.60080777445148, 71.31760920247724, 80.90630592838411, 33.330995575074226, 0.3278297071735705, 2.7242942154407506, 3.772397613333118, 0.6905317366603883, 0.14802769156953982, 30.488589232967747, 65.19716631981635, 59.730578622510365, 58.22429433945687, 60.10137596438008, 61.16546792368735, 60.06046564348283, 57.98848144469723, 55.782897395472375, 54.53510907388503, 61.353086656139745, 62.416656940214104, 62.43572358162173, 60.84507303853189, 64.61684380808185, 58.91145829231509, 55.37167610660676, 65.57743618565222, 61.92651364111132, 54.621283546570815, 53.846117296526515, 56.87235924505419, 61.379237098078576, 60.41888398508872, 58.53633849851547, 50.376298427581794, 55.683841859140706, 65.1625867043772, 59.748601913452156, 59.77604673754785, 54.20149972361904, 52.46881231184929, 50.77647432204216, 52.28046794091502, 55.68529313610446, 56.175703156378965, 57.01991096619637, 55.85466108014507, 59.5581590744757, 57.545261459965865, 56.926087871674575, 49.44382552177676, 48.2161864157646, 43.21375239279963, 45.09686270067769, 44.97702644717309, 45.64965801854288, 43.89933170810823, 47.99840465668709, 45.411075930441584, 51.241981214092625, 46.97790199710477, 47.75105607125067, 50.94292794504474, 52.855805120160504, 51.654681236513206, 54.40323506632159, 55.070751866986676, 57.98142117838706, 59.353015192093395, 58.12019071271343, 54.014312451885594, 48.09920172537527, 50.615802272673584, 50.88894044199298, 52.755325763456284, 59.5981986291947, 56.088971707128714, 51.771763986156834, 53.60877859976984, 53.10464028389224, 50.06436801725819, 50.098629920713364, 48.59780557693974, 51.68606804263208, 48.68996166413831, 52.15498347436228, 49.892893760435044, 43.79813455766247, 43.041395602687714, 46.21302412402245, 44.96588299351354, 40.81201453362742, 43.4449133565349, 44.929750119486165, 44.69581996240924, 46.40979374608686, 51.29711012686453, 56.60495950329689, 56.9238168193448, 53.00691835341915, 55.44895072137156, 58.51482037575015, 51.40111961672383, 49.22179583580264, 55.438458381160615, 59.68957808709914, 61.81301201543501, 57.6604026363742, 59.15950113727201, 60.1541083089767, 57.064759346746634, 54.32891791866672, 59.907646179199226, 61.010032238498816, 61.88256740570069, 61.534253089658684, 64.08282095386137, 67.03958988189697, 57.96336258611372, 58.621155831121634, 63.88374105576546, 64.5428639842618, 65.60550466660531, 63.98571875787551, 65.91190845735612, 57.84884898893295, 58.12573302176691, 60.29971453451342, 64.56474688745314, 62.79393795997866, 60.26580172200357, 66.52037789744716, 67.50470453693022, 70.78892861643146, 70.85740535489975, 77.61481761932373, 26.88008123828519, 0.7439772784709932, 1.6976570914829932, 7.01456775588374, 3.500046124381404, 0.6412929368595923, 34.11566180567588, 87.73932580024966, 77.0384096330212, 77.25870563137916, 86.17817540322581, 72.20353141907724, 62.12673887129753, 61.31629482392342, 61.57166857873241, 67.19858707920199, 84.48010290822675, 23.42356901015005, 0.5640678420182198, 0.30645855071563877, 0.1837441202012762, 0.18852452417054485, 0.17123698407123167], [0.04303490487678398, 0.03543845362841122, 0.06546443478474695, 0.017186791876391057, 0.050694738409572074, 0.008640861788374043, 0.05935961801198222, 0.058770124845567255, 43.73813013876639, 61.18842947867609, 42.699274709147794, 44.28567340297084, 89.17314037199944, 56.314747256617395, 38.093819848952755, 61.01075003224035, 66.40690372836205, 62.7931966320161, 60.705868121116396, 65.00998297045308, 40.04622274829496, 0.02274721699406303, 1.1644491096658092, 0.48556270618592545, 0.04491565073089254, 0.3859419501837223, 9.90343947564402, 55.0475981158595, 48.644756347902366, 51.5276199771512, 51.4947779716984, 57.235853133663056, 54.356609852083274, 58.78703286570888, 51.72031425660657, 57.21142461222988, 62.77469481191328, 59.77818835166193, 59.1082553709707, 54.58256975297005, 57.89156360010947, 57.720956187094416, 55.09383501545076, 57.67679422132431, 56.02295821712863, 46.093638943087676, 47.18801944486557, 52.02086587106028, 52.48240332449637, 57.44416629114459, 48.280725094579886, 58.37571743995913, 59.18097611396544, 55.401231165855165, 57.12662689147457, 52.05718309648576, 45.78144573396253, 49.26882113179853, 46.03497989716069, 50.160564145734234, 51.86661474166378, 49.599951544115626, 48.99753039883029, 50.65688517785842, 53.416551082364975, 55.218762505439024, 51.50795321310721, 46.36292926726803, 41.03951592599192, 39.853504934618556, 40.18603171071699, 42.019198479190955, 38.961973728672156, 39.28661261835406, 40.32939041814497, 41.04967486473822, 42.85847194733159, 43.72331142425538, 45.61516469524753, 46.22631311416627, 46.94829202467396, 47.2112084973243, 46.87663816636609, 49.323455825928725, 50.11396638808712, 53.230693494119954, 47.99461564710064, 33.810607310264345, 42.95030640017602, 37.67976660882273, 40.5905653584388, 47.83640684620027, 54.8541428965907, 53.26939944298037, 51.34704582152828, 48.71794777531778, 48.36815080335064, 47.768738115987475, 46.444483187890825, 44.68682988997429, 46.36490614183488, 43.99973653977917, 43.76468850720314, 40.511686494273526, 41.72994329083351, 38.20519554999567, 37.508947387818374, 38.297987061162154, 39.20330147589407, 40.35833751001666, 41.728331196692686, 42.83709502989247, 47.852727828487275, 48.258904949311294, 48.412301002010224, 48.55795037361884, 48.5617668397965, 49.39951058356993, 50.5249091886705, 45.40561599116172, 45.65563178831532, 50.21738752242058, 55.35839888357348, 52.18943757395591, 47.707941378316576, 57.50172707342333, 50.833038822297134, 48.494898273098855, 57.73442952863632, 51.904936298247314, 56.132039331620746, 58.1911071654289, 58.36252258669946, 58.040719570652136, 55.379767956272254, 57.43949867063954, 53.407329590089866, 52.812066770369015, 53.908353544050655, 58.26449078898276, 59.52240274798486, 63.784093241537775, 63.324960201017326, 58.22154868033625, 54.73549512124831, 56.72623134428456, 56.0563728886266, 59.53763331136396, 62.763916138679754, 65.77607285591864, 66.48509225537701, 61.28135435042843, 70.76050712216285, 15.140615586311588, 0.25019988808180055, 0.33219524388832433, 4.763332711112115, 1.5632359947889083, 0.40488252416253095, 39.604803131472686, 64.55256400569793, 67.94346086440548, 64.84543169698408, 75.27576708024549, 53.706320101215, 44.203986121762185, 33.498386644547985, 27.297225306111, 47.318383339912664, 58.00134681886243, 6.740816225928645, 0.32986906387152215, 0.18065802692886324, 0.06624769840028978, 0.11515657477561506, 0.07694708153365121, 0.06623191698904961, 0.09318101324982221, 0.020151502347641417, 0.015099027997723993, 0.02586412998366981, 0.06621525457669651, 0.10064108552591455, 0.09897615430095504, 52.22975953932732, 75.16750966348957, 46.59640835177514, 40.44643394408688, 75.63236544209143, 60.99439374862179, 44.184303668237504, 66.79477906996205, 73.45684636023738, 68.54458762753394, 66.21666093026438, 71.55897617340088, 42.821801708590606, 0.1081238340045656, 1.2806667315383113, 0.40169366785595495, 0.4281376134003363, 0.5767094572224926, 11.525378765598422, 58.85397987980997, 51.33576900728288, 56.51459593926707, 56.44211053848267, 60.23443452773556, 57.329986095428474, 58.580880934192294, 53.09012359188449, 59.457989585015085, 62.85363251163114, 61.89413839770902, 62.06476150020477, 57.72695741345806, 59.13072270731772, 60.66121978144492, 57.8695277244814, 59.8560630890631, 57.190981218891764, 49.33994154776297, 49.74146281519244, 53.930377652568204, 55.460706064777995, 58.58987885136759, 52.218372898717085, 57.90063211994787, 60.57022863818754, 57.57552646821546, 57.77300211691088, 54.21076436196604, 48.96143282613447, 50.453855452998994, 47.46807667516893, 52.35774255567982, 55.040141690161924, 52.53760676230154, 51.31756528731316, 52.96142670416063, 57.44961838568411, 57.700559862198375, 52.85561292402206, 48.57857419598488, 43.27465895683535, 41.93971557001914, 41.212637578287435, 43.44043400979812, 41.12399985713344, 40.18021875812162, 41.536197816171956, 43.05329215142035, 44.71696153763802, 45.930903727008456, 48.61721738692253, 48.700936455880445, 49.1684280672381, 49.37108908930133, 49.771119856065326, 52.474170269504675, 51.9047676363299, 54.92000733652423, 50.89604777674521, 40.228879682479366, 44.81166716544859, 41.06385031054097, 44.88826321017358, 49.419926520316835, 56.71819048543131, 55.1938436877343, 53.443509532559304, 52.526941837803015, 50.149432459185206, 49.342408718601355, 49.03220415115357, 49.62758071960942, 49.890571717293035, 45.362442462675034, 45.784305141818145, 43.60423218819403, 42.440782670051824, 42.197995801125806, 39.721172009744954, 40.06004125841203, 41.17999561371342, 40.62035183752737, 42.65482248798494, 43.849309721300685, 50.250288363425966, 50.925885246646025, 53.27026236441828, 53.17707861623457, 52.021854308343705, 51.22054546110092, 52.66178115721672, 48.76062316279258, 46.74003378037484, 52.12088238808417, 57.32786017079508, 54.55707434685, 53.76774834048364, 58.52820742514826, 53.47374708421769, 51.17881928720782, 54.92376888951948, 54.28422251055318, 58.326632899622766, 60.25761181308378, 61.214772116753366, 60.36166837138515, 57.91058317307503, 59.868265582669174, 56.07963254374843, 56.007119686372825, 57.39788624548144, 60.30363690468573, 62.298115068866366, 64.18841115890011, 63.53017468606273, 60.72285982870287, 56.75974015266665, 58.54565412767472, 58.08215941152265, 61.69023398430117, 66.80918985797514, 68.604796009679, 69.72519751518004, 66.41763533315351, 76.14729419831308, 18.307978530083936, 0.4022461398234291, 1.1508873922209586, 6.150163171752808, 2.0259811705158604, 0.45933096699656983, 44.23940120204803, 71.84321465030794, 74.11321578487274, 72.68855602510514, 81.17756920476114, 57.875897653641246, 51.67579927752095, 41.881919445530066, 30.288928824086344, 54.66347648251442, 70.17520320030951, 8.958653269275542, 0.4755384763402324, 0.290207588864911, 0.011586648930284766, 0.10094136900959477, 0.03196089517235035, 0.13490095884809572, 0.1269161240047505, 0.15149987783403168, 0.15377033261522172, 0.12306156027461253, 0.13682760869062718, 0.15189827419817448, 0.22726375189039016, 61.23921632766724, 84.70216397316226, 56.696284048018924, 58.434137221305605, 99.1701558328444, 71.04012504700692, 50.740149251876346, 73.17645965083953, 79.07654377721971, 74.28547843810051, 71.17616853406354, 76.98468885114117, 49.593197222678896, 0.18253635194513107, 2.484718051648909, 1.085702135197578, 0.2936209395768181, 0.5807960766457743, 13.350295809007461, 63.95279830501926, 57.042507740759085, 59.747997868445616, 60.08888321538126, 63.27830360781763, 58.300105910147394, 59.86016981063351, 54.91006020576724, 60.63206872632427, 63.48175694865566, 64.98238517392066, 61.90601925696097, 59.808469049392215, 62.57084138931767, 64.40302756524855, 60.6336376743932, 62.53097834125642, 61.25874188638503, 52.17898837981686, 53.09589732077814, 58.21714385863274, 55.61183106514716, 61.398919551603264, 54.81048299420265, 62.485545527550485, 63.05079437071278, 59.28751161021572, 59.21046841529108, 57.48271142282794, 49.86383684219853, 53.067169881636104, 52.62585616880848, 54.65465899436705, 56.63802900621968, 56.06515507544241, 54.26487738086332, 55.58066783412811, 59.33309739635837, 61.71859664301719, 57.59816638885006, 50.69279447678597, 45.014771415341286, 43.69903587525891, 43.25872236682523, 46.86403951337261, 43.95105992594073, 42.69081415668611, 45.346803972798014, 46.60733607507522, 45.820214440745694, 48.19388774133498, 52.35361229988837, 51.981116571734034, 52.71495280727264, 52.47721402875839, 52.20067516449959, 55.05590569588446, 56.521836634605165, 55.93101786028955, 55.15801675858037, 47.272526910228116, 47.60396326741865, 46.440988356067294, 49.64039902533255, 52.897040997782064, 61.45819048727713, 59.3484103295111, 57.66126555781211, 53.134007069372366, 52.106306860523844, 53.683790006945216, 52.33442798737557, 48.81116290246287, 52.93433881575062, 48.382200733307876, 47.72678052225421, 45.59033609205677, 44.47316269720755, 44.151857822172104, 43.546232100455995, 41.376423989572835, 44.61507012767177, 44.37634683424427, 45.22151954712407, 46.804486167046335, 53.2624529254052, 54.963439741442286, 55.31243654989428, 54.742716204735544, 54.40383126658779, 56.00797084070022, 55.08195023382864, 51.47536223934543, 49.86971647508683, 55.083887884693766, 59.27432852406656, 56.83983102921517, 55.02001600880777, 62.06184717916674, 53.55080204625284, 54.055881730971805, 54.36667073157526, 56.571556598909446, 59.88690076335784, 61.77905605685327, 63.765179572566865, 61.59214727340206, 59.2791961854504, 62.374903309729795, 60.01143993869905, 57.90572335643154, 59.379702998745834, 64.15266659951979, 65.60461428857619, 66.9606247255879, 66.82979014612013, 62.24712033425609, 57.9393066898469, 59.830116610373224, 57.82105507389192, 65.14814453740274, 68.47095689465924, 72.21050539324361, 74.02072629620953, 67.63087149589293, 79.59402991879372, 21.759862361415742, 0.3951927989480957, 3.5268069851783017, 10.869920311435576, 2.556501348172465, 0.710123853097039, 47.40756627052061, 78.42417517016011, 81.21564757439398, 77.23907024629655, 87.62057212091263, 65.11232937535932, 61.27432546307964, 49.24755404072423, 42.93365201642437, 63.29595427359305, 83.24006126772973, 14.326925777619886, 0.7487872074688635, 0.4818574146878335, 0.22142585547220325, 0.3016514409213297, 0.16111198301997878], [0.06532176623060819, 0.04537300139124836, 0.06801186865496059, 0.020848012251418926, 0.091098127436013, 0.051529391203075654, 0.11306511643793314, 0.19194501482190626, 31.767336822325188, 62.5265186063705, 45.28657205643193, 63.03605410360522, 106.4102549706736, 72.79438157235423, 35.42842811153781, 55.15916601304085, 67.856337178138, 62.64502909875686, 62.612320453889915, 59.02654063317084, 54.29717809923234, 0.7247485328585871, 0.17353530913110704, 0.17070752538500295, 0.36392577833706335, 0.08085724792533344, 2.8089735296464737, 48.261701599244155, 49.94145662553849, 50.571891338594504, 52.37145516180223, 59.025242328643806, 56.16679937608781, 59.202082387862674, 54.077776401273674, 58.23482590336954, 64.77215397742488, 59.28955124270532, 56.13267475558866, 56.63858206041398, 56.01209717412149, 56.799332557186005, 55.33728868730607, 57.780380095205004, 53.491178097263465, 42.920162985401774, 46.16803061577582, 53.286579424335116, 54.55617612408054, 55.36770274562221, 55.69303981719479, 56.26236008059595, 55.09132862091065, 56.56095835470385, 52.03939122538413, 49.73629313130533, 47.04860664183094, 50.254677495648785, 47.935838930068485, 49.992027744170166, 50.73892155001241, 49.75250428722751, 50.63912468571817, 50.103050431897564, 49.6888755982922, 51.05169134755289, 52.72544514748358, 49.90748105510589, 40.623132797979544, 43.40767437411893, 42.14817777756722, 40.17069524334323, 40.7840911803707, 39.61258903626473, 40.21742636157621, 39.80193753396311, 42.53178558041973, 41.76556233436831, 44.90801234399119, 46.42824849774761, 47.31352352326917, 46.11946775067238, 47.33432777466313, 47.010312541838616, 53.90920862074822, 47.897387935269265, 36.414892442764774, 41.508635320971095, 46.44493818283082, 43.87335385045698, 41.351109012480705, 44.449283307598485, 54.75990403083063, 54.49601873274773, 50.70951161846038, 51.702643978980284, 43.78983090000768, 48.90570379072621, 46.586625960565385, 45.52565228554511, 46.36079942026446, 45.60966553226594, 42.80517478143015, 40.449646365258005, 41.78966922144736, 41.23575602808307, 40.41886360414567, 40.670875887716974, 37.19225522010557, 39.434493818590724, 41.33900065575877, 45.6426565877853, 51.375141759072584, 50.919785961028076, 51.111330986022956, 48.38106716832807, 50.35552555514921, 48.95956970030262, 49.44603381618377, 47.62736805023686, 44.27084292134931, 46.25795879671651, 53.544016345854736, 54.32993381254135, 57.34673853843444, 53.96943269237396, 57.909669260824884, 45.628081060224964, 50.63014638039374, 55.09574128735451, 53.12891975525887, 58.109933714712824, 55.75424840373378, 58.66776535587927, 52.86852144425916, 50.57635891822077, 47.950171270678126, 50.588506498644435, 53.15614492662492, 57.03665164209182, 56.07163875333725, 59.48308490937757, 57.61787629896595, 63.673078398550714, 59.7251186832305, 55.919619452568796, 55.342913366133175, 62.194250706703436, 65.78141904646351, 64.55733753019764, 67.27567734256868, 65.86245521422356, 67.70527101332142, 11.702559090429737, 0.22763862935525758, 1.792428541568018, 2.97499593707823, 0.8331979006048172, 0.22843025865093355, 50.192100001919655, 64.08701396757557, 70.5290323688138, 61.493731083408484, 70.74668468967562, 38.56575158334548, 52.89854718792824, 47.65179657167005, 31.165050998810802, 52.72231901845625, 46.33896358551518, 1.2773827271115397, 0.2797622558089995, 0.09273004027143603, 0.05997573273376592, 0.048395827292434634, 0.02148366604571141, 0.07493138929168064, 0.05459074366597399, 0.01927019671476897, 0.06719704987781663, 0.06644256818558901, 0.10963032292502542, 0.08660582615242851, 0.2742659426744907, 39.70859296860234, 74.22950621574157, 52.064357111530924, 64.27793141334288, 95.27204944241433, 73.98670365733486, 45.20266079133557, 65.16657575484246, 73.11976571236887, 67.57955120455834, 67.6464040817753, 65.54312329138479, 58.63669626174435, 0.7844410007519107, 0.19779498478577984, 0.17771474776729462, 1.6717152706077023, 0.13092893085652782, 2.6715863856577107, 52.40415203955866, 51.98897307918918, 55.16009953714187, 55.89332388293359, 62.38180668123307, 58.358917928511104, 60.677913388898304, 55.00435006233954, 58.4489010226342, 65.2958845323132, 61.73587860599641, 59.11337798641574, 57.958804791973485, 56.902734079668605, 57.47541581430743, 57.2748532602864, 59.9884234705279, 53.14731959373721, 46.96802546901088, 48.42742566139468, 54.971198189643125, 57.337187567064845, 58.02332778130808, 57.08861520213466, 59.658289340234575, 58.46581036044706, 60.76283662549911, 54.82790616250808, 51.15805033714541, 50.075805648680664, 50.866692758375606, 49.46528873135967, 51.07735933796052, 53.73392182011759, 55.973461827924176, 53.56597769644953, 54.78125349167855, 51.99353871806976, 54.3260310542199, 55.762250038885306, 50.838636044533025, 42.58931890610726, 43.45466044641311, 43.549244480748335, 42.36705780029297, 41.282898995184134, 42.776004114458644, 41.75348143423758, 42.996433473402455, 43.51138968621531, 43.03783409057125, 46.09328985214234, 47.86815451037499, 48.097985790621856, 48.42118124808035, 48.67525669836229, 48.73588085174561, 55.23904508160007, 50.95643658791819, 42.95754317314395, 46.350436518269206, 47.91896881595735, 45.04021975301927, 42.75235222231957, 47.18396763647757, 56.025394009005645, 56.383008264726215, 54.271694460222804, 54.883486147849794, 47.636726825468, 50.28336963345928, 48.2757358397207, 49.25670493033625, 48.79823477037492, 47.219025781077725, 43.49562960286295, 44.39621756153722, 42.703122554286836, 42.13592821551908, 40.41468235754198, 41.546270462774466, 40.24913480204921, 42.25648226276521, 44.712156634176935, 48.974757117609826, 55.49907861217376, 53.37906891299833, 53.91644539371614, 51.5701110132279, 55.47716433002103, 51.586279023078184, 53.31371830355737, 48.17061631910263, 46.04238925441619, 50.15977182695943, 54.60149126668131, 57.670416447424124, 59.342530696622795, 57.12887833195349, 58.41309370533113, 47.86062355964415, 48.26158785050916, 55.30963597759124, 54.79919833521689, 58.853936733738074, 59.469878289007376, 59.86093075044694, 57.687137511468705, 52.663718808081846, 51.20603269146335, 53.78970576870827, 55.74606633955433, 57.96366460861699, 59.29100251966908, 61.51338608034196, 60.58486300130045, 65.38588723828717, 63.83401324672084, 58.44357836631037, 56.148874144400324, 63.3825013714452, 68.70877019820675, 65.90983744590514, 70.66436198449904, 67.71202533475815, 72.47363367388326, 14.685263710637248, 0.29428434107572804, 3.2766678785124137, 1.8935628115169465, 0.958531846202189, 0.3298160505871619, 55.49385793747441, 70.06233307623094, 76.11110641110328, 69.93560129596342, 80.37618191011491, 43.627707573675345, 58.09138482616794, 56.06252708742696, 33.38569694949735, 60.56000301914831, 57.3725438117981, 2.297599421393487, 0.1394329205035202, 0.05090053643911116, 0.07460960938084511, 0.02820144508845143, 0.04129398156017546, 0.20134289118070758, 0.12434921617950163, 0.18047537624595628, 0.10815522062682337, 0.18391200070900304, 0.27315627963792893, 0.21438811214700823, 0.3362404945636949, 45.604809637992616, 86.99169066644485, 60.189939160500806, 78.59663394189651, 109.65513767734652, 83.63793080852878, 46.347322156352384, 66.58298677013767, 80.74726166263704, 73.87988967280235, 73.97606618942754, 68.9488898554156, 67.96037412458851, 1.0871505929577736, 0.4622980255273081, 1.028507849381816, 1.586271339366513, 0.1582403177575719, 3.9573148133293277, 58.097684152664684, 57.29836786946943, 60.60068976494574, 59.37420383576424, 65.4131398662444, 60.03672745919997, 64.14593973467427, 56.2548291298651, 61.713697602671964, 67.06502253009428, 64.97665851346909, 60.88655210310414, 62.79066278088478, 60.215881716820505, 60.62505552845617, 56.64177879210442, 62.36400304302093, 56.1870897969892, 48.250899391789595, 50.874439439465924, 59.21829354378485, 59.27073563298872, 60.35474538803101, 58.93269792679818, 61.91403265922301, 60.47060435818088, 61.846905216093994, 55.75021228482647, 53.6085158009683, 51.69204573477469, 53.82166524087229, 51.9416339935795, 53.48714197835615, 55.86259603500367, 60.417448397605654, 58.33715269642492, 56.98688853171564, 53.70107589229461, 55.24814890277002, 57.92921835376371, 55.33138944256691, 46.14148401444959, 47.988896831389404, 45.92690290943269, 45.4344375671879, 44.42356040400844, 45.33020842459894, 44.88326611057405, 46.01736061034664, 46.760453639491914, 45.96513032913209, 50.99711156660511, 50.18770302495649, 51.964144475998424, 50.04429724908645, 48.761819485695135, 52.21932995703913, 58.707581335498446, 55.28146551501367, 49.92589266069474, 47.34252945069344, 52.76071902244322, 48.9956594282581, 50.54842379785354, 50.56822784485356, 60.539245836196415, 59.13807715139082, 58.020950824983665, 57.92479784257951, 49.249064153240575, 54.82461137156333, 51.26671568039925, 51.616089036387784, 52.767485110990464, 51.072311247548754, 47.53548652895036, 47.254519308767016, 45.499556756788685, 45.29261250649729, 44.55299077495452, 44.646813869476325, 43.20200489413354, 45.28982762367495, 46.72089653630411, 51.318000670402284, 58.97512620495212, 58.10945126318163, 57.713739025977354, 53.53164126796108, 57.95248977599606, 56.521460087068625, 57.63687626008065, 52.62812329876808, 48.80742880605882, 51.43748783296155, 57.82217294939103, 59.9852777296497, 62.4003634145183, 60.13317854173722, 59.80480555565127, 52.53354318680302, 55.65886028351323, 54.25098826808315, 58.225078813491336, 59.59351924157912, 60.383084512526, 61.041289606402, 58.02627740367767, 54.401379785230084, 53.88459574791693, 55.25155744244976, 58.62864755815076, 60.080599169577326, 61.373157424311486, 65.33077793736612, 62.23886374504336, 68.27213195062453, 66.67936725001182, 59.53574665131108, 57.40675472444104, 65.21529159238263, 72.12460548646989, 69.85392970423545, 72.3244502467494, 69.90236313112321, 76.6417246480142, 16.218003399910465, 0.28916092889924205, 6.4343972359934165, 6.744433631820064, 1.3123971127694654, 0.4989501845932776, 60.296360908016084, 74.8099228643602, 81.40120706250592, 74.34787550280171, 83.01825907922561, 50.25033935423821, 69.99509580673711, 70.5794583597491, 48.821361064910896, 70.81913086675829, 75.05452971304618, 3.857832474093284, 0.5413364811289696, 0.17817211757984855, 0.1935269250985115, 0.2528503990822262, 0.22528721440222957], [0.08311326961003004, 0.005802932165322766, 0.010702971297676766, 0.07594709930520865, 0.028413170723304636, 0.12014786742867962, 0.11382372734407264, 0.22701305727804863, 20.71476055729774, 68.1744021754111, 42.70550735535161, 49.594750481267134, 100.29264403927712, 79.8567424281951, 35.53665807170253, 55.71154163729761, 68.51393822700747, 61.494456721890366, 66.04897960539788, 55.092662226769235, 60.986984391366285, 3.67529786882862, 0.2400316183845843, 0.8146264584314439, 2.0490024190756584, 0.17933202066248466, 0.19374406505976954, 35.17469390746086, 48.10954893788984, 51.69587004569269, 50.89857770550636, 55.462792765709665, 56.84041154000067, 54.09359924254879, 52.69524681952692, 60.06099516345609, 58.16982046250374, 59.082383417314105, 57.99261562285885, 55.98108691553916, 54.32781181027813, 57.34916256320093, 55.34987949555921, 58.9905450420995, 48.287075411888864, 41.86723801397508, 52.414573777106504, 56.05412929288803, 56.27600208405526, 57.21020083273611, 55.90565189238518, 57.94723772233533, 57.04603787391417, 55.02943754196168, 51.093652863656324, 48.54600283407396, 49.57868053067116, 50.26860583213068, 46.163653250663515, 47.62744257527013, 51.75974976631903, 50.503343997463105, 49.78072574061733, 51.033746504014545, 50.260670877272084, 52.233987854373076, 52.74437058356501, 50.7076955610706, 44.547515146193966, 42.0718131526824, 40.13288359488211, 41.17415128215667, 38.94072232707855, 42.455346430501635, 39.65582532267417, 39.45095600620393, 40.697959853756814, 44.79315750060543, 42.34510429443852, 44.420167553809385, 43.071468414798865, 47.39673268410468, 45.222668801584554, 49.85565870038925, 44.512551138477946, 35.83586431318714, 45.324948526197865, 48.98089170455933, 46.43623836578862, 45.62853997753513, 40.014961458021595, 48.01698100182318, 51.81969142729237, 53.66619033198203, 54.577733470547585, 52.88615249818372, 48.91265030830137, 46.573058482139345, 46.35567288244925, 45.213235501320135, 44.772431696614916, 44.06942136826054, 42.94689393812611, 41.575672549586145, 39.34516968265657, 40.180705132022986, 40.94930533439883, 39.80362023076704, 39.865934925694624, 41.54456815411968, 38.9884614944458, 46.71993947798207, 52.05183690594089, 50.44959575899186, 50.382236896022675, 50.68986446626725, 49.62632948352445, 48.60023744644658, 49.83162633834347, 46.279731873543035, 44.250658404442575, 48.08619514588387, 45.06953554768717, 52.062674414727, 52.183267685674856, 54.4764421832177, 56.14504983348232, 54.57432100849768, 37.26646254139562, 48.980679896570024, 56.02859858543643, 57.376838807136785, 54.20428460644138, 59.10947130572412, 58.21846177501064, 56.48449174819454, 49.12953776697959, 46.44398896924911, 50.15958747556133, 51.54124629112982, 53.596740845711004, 56.301889727192545, 59.973808719265854, 59.788186473231164, 61.26773195881998, 60.826853629081484, 57.944095903827304, 59.634825721863784, 67.09139654713293, 59.24601293379261, 67.760984359249, 65.02736691505679, 65.24909065615746, 9.43966725180226, 0.19940569996833804, 1.0552881994555074, 1.4003147112746395, 0.7796126243568237, 0.5143389298069863, 56.58663418985183, 65.29386451167446, 67.03740904408117, 56.51004598986719, 65.6361226881704, 39.8981571966602, 53.307854360149754, 24.482636413266583, 28.953914834607033, 57.07029381105977, 40.723714136308246, 0.2194690524089721, 0.09562029848776518, 0.02773989626627055, 0.07967893574987689, 0.04287356675993051, 0.05232658229708191, 0.11196316790676887, 0.02287431289592097, 0.057373136702564456, 0.05981701080717387, 0.10167847582769972, 0.04016505141231803, 0.14275070940775259, 0.24717541892201672, 27.02963140703017, 80.6478766472109, 48.84328711417414, 52.46746301651002, 93.32897001697172, 81.26709338157409, 39.05571053105016, 60.77489399140882, 74.79049144252654, 68.48047256469727, 71.0933437655049, 59.76956305965301, 67.16212472608014, 3.857126447462267, 0.24583946883438096, 1.16383709734486, 1.7928200431408423, 0.6413174516731693, 0.1265754676874607, 41.49182012004238, 51.39379262924195, 56.58342569105087, 54.47289243821175, 57.87645070783554, 59.786099772299494, 56.621547206755615, 54.5099353021191, 62.86490540350638, 60.51199320823916, 63.554732645711596, 59.87604756509105, 58.39551364221881, 56.332197881514034, 58.90014225436796, 57.628125452226215, 60.96481123278218, 50.41283138336674, 44.20410379286736, 54.05842342684346, 57.5719218100271, 57.17698227974677, 61.520218849182136, 58.95637335315828, 59.17501411130352, 59.156516213570875, 57.17781774459347, 55.1384166748293, 50.793956325900176, 49.421067930036976, 51.03486045714348, 46.245893586066465, 48.467708403064364, 54.73695032058224, 53.88526255084623, 51.938703983060776, 56.46516623035554, 51.72604091705815, 53.737189154471125, 52.34948596646709, 52.51359793447679, 46.49071224274174, 43.12638551958146, 41.04458362825456, 41.79510170413602, 42.594637640060924, 43.14833902543591, 43.295137651505016, 42.685742532053304, 43.39085525082004, 45.81617047709804, 43.76015424728394, 46.67083532579484, 45.18978757243003, 48.905958744787405, 47.02076565834784, 50.332473785646506, 47.78245856685024, 42.51390349480414, 47.8327472748295, 50.186236058512044, 48.23013436409735, 48.08938795520414, 44.08099628263905, 48.39953760946951, 51.87513805204823, 57.48531587662236, 57.867629297318004, 54.88131315477433, 51.22673103886267, 49.588439387659875, 49.28146685323408, 46.360889634778424, 46.791954194345784, 45.611622794981926, 45.24483019305814, 44.904697941195586, 40.801769302737334, 43.92739234432098, 43.22196975831063, 43.23440367175687, 42.59861100104548, 42.19993345199093, 41.057315641833895, 47.90686438160558, 55.65694616686914, 52.66883357878655, 51.80975606364589, 52.94653738698652, 52.890192539461204, 52.43750395313386, 53.97459453152072, 47.884499026883034, 45.047895831446496, 49.944606288786865, 47.398234951880674, 53.491535032949145, 54.28661123398812, 56.95782769110895, 57.62268120242704, 56.51375262968002, 40.93112514865014, 50.15763413521552, 58.42745350253198, 60.80713979659542, 55.69069816220192, 60.710916211528165, 58.32846464649324, 57.36630724322412, 50.34211889390023, 47.11658131691718, 52.76369217903384, 54.683884574520974, 57.355818825383345, 58.57896289517803, 61.71023022743964, 61.57683041787917, 62.27398856993645, 63.12025562409432, 59.28299696214738, 62.49521809239542, 69.72455424647178, 64.15439244239562, 72.09649778181507, 68.2927949966923, 72.94940148630451, 11.580456687558083, 0.3762111626565457, 2.134198137829381, 1.4202452547127202, 1.0046746701963487, 0.8184701360521779, 63.209171833530554, 69.04501145885837, 74.20901575396138, 60.55556681848342, 72.10601345185312, 43.03353517286239, 63.17381951116747, 34.2192006111145, 31.257773868499267, 66.62775670328449, 50.66522021447459, 0.232433634960363, 0.044218499228478446, 0.019038160173823277, 0.07736705093374176, 0.033342061684496944, 0.03418063301773321, 0.2866518070861217, 0.19089354382407284, 0.09636044667492952, 0.18521494772886077, 0.19069642940115547, 0.24985114953690962, 0.17083304123051707, 0.36805805660063223, 32.91343573601016, 95.43862465889224, 56.25909666861258, 67.20982859211584, 100.82034403277983, 88.3860226600401, 48.903942646518836, 67.14890633859943, 81.14683351209088, 73.33466452936973, 77.65702232237786, 64.24089247180571, 74.43830966949463, 4.195941273243197, 0.4509959916674322, 1.7669844939824075, 5.363534285176185, 0.3591523151243887, 0.2816550139217608, 49.3049265492347, 56.105994793676565, 63.365666558665616, 55.77543704740463, 61.02503530440792, 62.386297795080374, 59.11345251144902, 55.03918855421005, 65.21103582074566, 62.02403160833544, 64.59727902566233, 60.32460981799711, 61.88957275882844, 58.27607747047179, 61.59652856088454, 60.06882813669021, 64.00536591006865, 51.38129595787295, 46.41753650480702, 57.36657396439583, 60.808614607780214, 60.56441176322199, 64.04899443349531, 58.469399329154726, 60.718188285827644, 63.43782248035554, 60.54792996375792, 55.50298921523556, 53.85544077042611, 52.34574010295253, 54.63572179117511, 49.59609193186606, 50.31366994304042, 58.489654448724565, 58.668561597024244, 56.31124458005352, 58.657469134176935, 56.51636885058496, 59.93712671341435, 56.378305342889604, 56.48659806097708, 49.09689580240558, 44.949754207364975, 43.36516372619137, 45.36225811127694, 44.92980895503875, 47.63051379111506, 46.34380771267799, 44.68400186108005, 45.39111498863467, 49.61875930909188, 47.04362130934193, 50.86209966290382, 48.683054370264855, 53.065212618920114, 48.71135427105812, 54.558639372548754, 55.48195354400143, 47.57290594039425, 54.34585079070061, 53.55672090284286, 50.65374728172056, 50.78296584467734, 47.65333021840742, 54.84020279299829, 53.981490058283654, 58.839710297123084, 60.412380695343025, 56.45953762915827, 53.97867379649993, 52.29746749324184, 52.613590917279645, 50.035907299287864, 49.34728030235537, 49.575224922549346, 48.60657991901521, 46.41231583010766, 43.20952407775387, 46.30659226448306, 45.033885125190984, 44.71638494922269, 45.54365988700621, 45.61942438925467, 44.27947998046876, 53.31422821167977, 56.21762544878068, 56.70292462072065, 56.37815629282306, 58.808637280617994, 56.042405328442975, 55.87357474911598, 55.18133132688461, 52.01061279542985, 49.24442006695656, 53.76029975952641, 48.477479027163604, 55.67312594382994, 57.32713845468337, 58.717724584764056, 59.99096516639956, 59.47058431563839, 44.663523166410386, 54.350832200819454, 59.68991541093396, 60.24993573465655, 58.319427505616225, 65.23779030769103, 62.58957462926065, 62.34353611546179, 52.53311564845424, 50.08357978636219, 56.18876072668261, 57.14690162289528, 60.41454192130797, 61.36805049834713, 64.00183577691355, 63.70257462224653, 65.92365987839239, 64.5080804055737, 61.51529627461588, 64.2882864705978, 72.90351760002875, 64.72990612829885, 74.9210593008226, 70.23762379923176, 78.7066956489317, 14.193499492060754, 0.2618852876607449, 3.5363988962865647, 5.754072916123175, 1.301320339402845, 1.5828404912064153, 67.08627393168788, 75.23609622832268, 78.64879362044796, 69.03152635020595, 77.14458034884545, 50.90665386569116, 71.70475498322519, 37.51720789940127, 44.60086330290764, 76.46152311755766, 66.04941891085717, 0.9165241809621935, 0.1856575320444761, 0.127132268051707, 0.20123044479518168, 0.16122879610667307, 0.2195782965469745], [0.11748519861289572, 0.06732759892099327, 0.12499869019994814, 0.07431160883917924, 0.1055795947209962, 0.11713449122203935, 0.1520460372370097, 0.5304853666213252, 9.370424670557822, 59.9862269432314, 51.828885462976274, 57.74484342144382, 75.30351392684445, 83.12349627094885, 41.395945625920454, 58.45937375099429, 62.984965232110795, 60.45067087296517, 68.36357808882191, 56.63256514456965, 65.19300076269334, 9.388868635700597, 0.31186158498448713, 2.248353328435652, 0.8367049285481054, 0.5883638608840205, 0.5026054965151895, 19.149183765534435, 45.543754023890344, 46.8461888067184, 51.82682229626564, 52.74852045120732, 53.94294884897048, 51.25394052074802, 57.18754130025064, 58.864542822684015, 58.81466596357284, 57.132271182152536, 53.142404863911295, 55.59048552666941, 55.46465196917134, 56.13150981164748, 54.7519886878229, 57.792606123032115, 43.38553651686638, 48.355140301489065, 58.670377654414025, 55.345819842430856, 56.99965584662653, 56.04597076292961, 58.66063840927617, 55.72386180200885, 53.98459265308996, 54.366647197354226, 50.13300165053337, 47.95362295642976, 47.84842106603807, 52.153014444535785, 46.98997897486533, 47.449296366783884, 51.39645199621878, 50.4935263049218, 49.48854054174116, 52.6745641616083, 48.60723887720416, 52.171237776356364, 51.010431935710294, 50.997625397097686, 43.94259545110887, 41.68996257166709, 39.87472887962095, 39.74218414675805, 40.50939975246307, 39.96821857267811, 38.4864765597928, 42.76513914908133, 40.83037907077421, 42.0730173203253, 42.357475449962, 44.69909121913295, 45.42216839328889, 47.95980461182133, 40.76259659182641, 38.42854315234769, 42.74276987198861, 53.00536901720109, 48.14354804254348, 44.091982841491706, 42.75905947531424, 43.33321602113786, 42.49618614873579, 45.98671513219034, 55.80749457882297, 52.243405465156805, 46.890809689798665, 47.70732556619952, 45.352361971332186, 47.31464139876827, 42.450015929437455, 44.43700236658896, 42.7052249446992, 41.94242200543804, 42.33982478418658, 39.316273581597116, 39.56074706969723, 37.89119020585091, 40.25555964439146, 39.71482953717632, 38.774496201545965, 41.20205502356253, 40.86285237343081, 46.12593181671635, 51.43045502324259, 54.17720064040154, 52.24084807980446, 49.83180284500123, 48.24554535650438, 51.69678395794284, 52.20041628806822, 48.03954247505435, 44.8961236399989, 47.94628027946719, 42.436573966856926, 47.832096161380896, 48.83659947303034, 53.06563231252855, 53.94207416042205, 57.25248398319368, 56.00753937998126, 53.524412339733495, 58.55425196309244, 53.84242242382419, 56.68636045148296, 56.241308719881125, 57.56910947061355, 54.059682507668775, 49.161328577226215, 47.631392402033654, 47.421820163726814, 47.36482812512306, 50.430536962324574, 49.99824862326346, 56.351884257408884, 59.12373304367066, 60.358648146352465, 59.837369072821836, 62.79020386357462, 60.1101581511959, 65.3632708518736, 58.43836553635136, 67.99536166652557, 64.60047967972295, 63.026181497881495, 10.024269069394759, 0.3921299794268224, 3.338331214843258, 0.1642757576079138, 0.9841973238414334, 5.030401502886127, 67.58688603678058, 61.50453721323321, 65.75746120945101, 60.165549862769346, 68.20807180097027, 42.341852649565666, 54.422411534094046, 31.386223646902273, 34.109707647754306, 50.64818536081622, 36.1025188046117, 0.20634516953460633, 0.07249310762891847, 0.038154679650981585, 0.0617940194394079, 0.05530099144145366, 0.018199156000909787, 0.04973233662425511, 0.11891205269362658, 0.08155773574065778, 0.08345741162737531, 0.023922325006776282, 0.11713570164095972, 0.14705944836380022, 0.5079919832848734, 12.97075060106093, 77.11176579998386, 57.67777873623756, 58.99451448071388, 80.34621500199842, 91.06542510371055, 42.22695858247819, 64.12815178594282, 67.70180363808909, 66.51992290250718, 72.89884213478335, 61.23299937094412, 70.2034285760695, 9.980389514277059, 0.3279559891070089, 3.4020837035871323, 2.562712911636599, 3.871101607238093, 0.8389958378768737, 23.901964810586747, 51.10976988269437, 50.88951310803814, 57.693499595888206, 56.405773701206336, 56.364502522253225, 55.98393063391409, 59.46464584719751, 61.58669125649237, 60.143090371162664, 59.356435498883656, 56.24625482866841, 57.4564354650436, 59.186287003178755, 59.04841961399202, 57.47304670272335, 60.531954150046076, 44.35517388005411, 49.83176754366968, 59.60802024410617, 58.534024300113806, 58.872760188195016, 57.096279513451364, 60.34530816539642, 58.606356728461485, 55.94598170249693, 57.09010178042997, 51.696646674986816, 49.77630522943313, 48.25802241602252, 54.29582488152289, 47.55038761323499, 49.966591173602694, 56.201343690195394, 54.866670946921076, 52.81621271564115, 53.15074382289764, 51.77917334341234, 54.412962544348936, 54.633960646967736, 53.13346185991841, 45.611783612158995, 42.56982864872102, 40.1936528759618, 40.465245631433305, 41.31461528039748, 42.49713143994732, 39.59653869751961, 43.64337352014358, 41.919401614896714, 44.92069728912846, 44.59588973752914, 45.40187405001733, 47.51039904932822, 49.29481860130064, 44.284481002438454, 41.509611991144, 47.63021569098196, 55.090308804665845, 49.70154877631895, 46.20083731989707, 42.405446037169426, 44.48182721291819, 45.293726459626235, 49.91620440636912, 56.794606101128366, 53.53953307674777, 49.74123924009262, 50.861566220560384, 47.54999929858793, 47.90565629159251, 45.97403410942324, 46.27997113812355, 45.84270531131376, 42.87714635172198, 44.2755066194842, 41.03191829496815, 40.76902927890901, 39.853901094005955, 40.785326726974986, 41.23170814206524, 41.057048920662176, 41.36709659330307, 43.30233127840104, 47.83386122795844, 55.438423079829064, 54.814095497131355, 53.755906704933416, 52.08833848276446, 51.06564714062599, 55.05008097617857, 54.11347781458209, 50.857553635874105, 45.996497523400095, 51.05668844715242, 44.77274940859887, 50.28302838725429, 51.081615109597486, 55.68662674196305, 55.60740270922261, 59.789574992272165, 58.23715971362207, 57.00098160774478, 64.41083700426164, 54.36454872931204, 59.18245092515023, 59.04857258642874, 59.94703069809945, 56.82379637995074, 51.14088604527136, 49.335685776126006, 50.83324670791627, 49.861032347525324, 53.33287515947896, 52.81634215385684, 57.897188278936575, 60.56896171262188, 63.94421615908223, 63.83676282821163, 66.10743076570573, 60.293340682983406, 68.8183141523792, 62.39285992037866, 72.27482441932925, 67.55671516541513, 71.36081803229548, 12.571792602539064, 0.3492936215573742, 3.1154457167271645, 0.42543090218978546, 1.201929440421443, 5.450795744695972, 77.73225338228288, 66.62498750994283, 74.57025820209135, 61.93653921927176, 73.8797249332551, 45.62141303093203, 63.3984261943448, 31.62470767574926, 34.31163910896548, 60.06235622590589, 45.459548581031065, 0.05179610088347428, 0.14818106237198078, 0.015457006520591678, 0.06353563606558789, 0.07342764296598973, 0.07604021729240495, 0.1720186695456505, 0.21005613008333793, 0.2633358291800945, 0.215474363536604, 0.20649726863109297, 0.23762728207774703, 0.3452076456479488, 0.726673742455821, 15.101454642511184, 89.28046426465436, 66.939161516005, 78.97353449175435, 81.49945459058209, 96.25200656152542, 55.58759866222259, 72.15530195543843, 73.85721837320636, 72.8524326509045, 78.57662200927734, 66.04913650020477, 76.1487768542382, 11.568026696482013, 0.40367225845975263, 4.635761053331437, 6.688279019248101, 4.265705039424281, 1.0113849262556722, 30.984918109832275, 57.86004343340474, 57.230703061626805, 59.307770652155725, 59.15901868574081, 58.531843462298, 58.26609503838324, 61.2331444986405, 63.81895134525915, 62.224150934527, 62.19747489498508, 56.73404862803798, 61.31097608996976, 60.90171990856048, 61.411937898205174, 58.139814330685525, 63.45235878421415, 46.606916381466775, 52.61168072300573, 62.2211620884557, 61.09130767083938, 60.54244649025702, 61.06907567670269, 62.587754649500695, 61.229551607562655, 58.443582288680545, 61.79805994033814, 54.64450397799092, 53.09764277550482, 51.38016239289315, 57.650981103220296, 50.53584867908109, 52.635246323001006, 59.852183864962676, 59.05616237271217, 55.910331280000754, 58.5817870017021, 53.613340316280244, 56.94881408445297, 58.15386818301294, 55.899493771214644, 47.58519080377395, 46.40515750454318, 44.11405401845133, 44.45624551465435, 43.77627911106233, 44.773184791688, 41.82326039960308, 48.5305683074459, 44.892828849054155, 45.47866621325093, 48.11361643575853, 47.86045882009691, 50.694457561739036, 52.66398160688339, 47.46484856451712, 44.83202818901309, 50.52329709452968, 58.835285863568714, 55.224606836995775, 48.35047268098401, 46.50617814833119, 48.74763227278187, 45.999937442041215, 54.414354985760106, 62.30939580548195, 56.041385512198175, 51.92794492167812, 54.32337560961324, 50.86741839685748, 50.079069060664025, 47.58556735131049, 49.389371256674494, 47.25552343553113, 45.05778804902108, 46.812272071838386, 41.622611553438254, 42.74780619528986, 41.507729253461285, 44.06124322645126, 44.09245352591238, 43.229908635539395, 44.19595310764928, 45.471813832559896, 52.08087421232655, 57.66752173823696, 58.7305546575977, 57.96877153458134, 58.534491062164314, 53.92350566002631, 59.4649870934025, 55.985781992635424, 54.66141331580378, 47.55720469259447, 53.620114249567834, 46.199864572094334, 52.89675858712966, 53.58332633972169, 57.838627292263894, 58.76061570259833, 60.21383423959056, 59.642439042368245, 57.586622853432935, 59.37930683935843, 56.269016342778365, 59.17399429505872, 60.049753650542236, 63.85430366762223, 59.64242335288756, 53.179914489869155, 52.1847071955281, 52.9324717675486, 52.09149599075318, 56.35650873184205, 54.54210658227244, 62.16902594412527, 63.44184683215234, 67.52098237314533, 67.2893036565473, 67.03531449840915, 63.410577697138635, 71.50759312414354, 63.499446838132805, 75.22020278438445, 68.86364890683082, 76.86402105516004, 14.07388779424852, 0.6704364536750702, 9.485429544602672, 4.012793797639109, 1.395787928373583, 7.4657192633998015, 80.90787487645304, 70.94372887765208, 79.48021842587379, 69.51124791176089, 82.4731045384561, 55.36614164229363, 71.73753030838506, 46.59088957694269, 50.99581326207807, 70.9765983396961, 57.798293559781975, 0.41269410822180014, 0.30001345300866716, 0.15533001102026434, 0.1549436422365327, 0.13174458466950925, 0.2153165953894777], [0.10660159431638257, 0.013919702670987577, 0.10210515615800697, 0.0554904947808433, 0.054823446703413804, 0.03096791690275554, 0.3355325373911089, 0.1539038617404238, 1.9834065389248634, 52.652081135780584, 51.347092889970355, 35.650897102971236, 34.95935186263054, 60.89608738499304, 37.70484624370452, 48.21143642548592, 68.48691309652021, 58.93600448485344, 66.64332851286858, 56.65947652632191, 66.17487984318888, 20.26012843655002, 0.311314475632483, 1.8776791735041527, 0.2251544207214348, 2.4920156213545033, 0.07350571498635315, 3.707175461515304, 48.18995752642232, 45.07425808137463, 48.9795502539604, 48.977769497902166, 53.89112257188367, 51.83167426816879, 59.66241567365585, 57.77797960465955, 57.75078973462505, 56.35913279748733, 54.234506468619074, 53.4426466111214, 56.31947763504521, 53.899049682001916, 56.22417972933862, 50.92480659484864, 43.41683310847129, 52.71218753630116, 57.60686620589226, 55.302712994237105, 51.42571287770426, 55.39309224774761, 55.15389042515909, 54.67779313364337, 53.56380470337407, 52.86563457981233, 51.50256779886062, 45.738036863265506, 46.32450180668985, 49.8398397814843, 47.411500407803445, 45.925396719286525, 54.44935821717786, 50.80591171018539, 51.34324504483131, 51.20520507135699, 50.58070882674187, 53.457057399134484, 50.3522386089448, 50.71728575614191, 45.49469694014519, 41.76822170134514, 42.70678212565761, 40.52731321704003, 40.38483312053066, 39.70937352026663, 41.345829502228774, 40.24282763081212, 40.768609585300574, 39.10782314115955, 45.564538663433446, 45.027142570864775, 49.092757701873786, 47.514705811777425, 46.88465156862813, 47.24827097308251, 53.2043626231532, 58.36925337391516, 49.93421985257057, 42.76746511459351, 45.357735618468254, 42.79423136864939, 44.09755260713639, 47.211486985606534, 61.28641028558055, 56.47996141064552, 44.79358896132439, 48.08009978263609, 50.44994877230737, 43.163875533688454, 42.954675920547984, 46.50487592143398, 44.717275327251805, 42.95853945516771, 40.83153616997504, 40.94099383200369, 39.49392164907148, 38.46864154261928, 40.207094838542325, 40.67029537693147, 41.496570110321045, 41.22430662955008, 41.676218586583296, 48.411618509600245, 49.72431813516925, 49.79809399574034, 52.07240581512452, 47.53234863281251, 50.26445596448837, 49.173719344600556, 51.95233421940958, 48.032239021793494, 44.356452572730284, 45.680421167804354, 45.00715417246665, 46.244163820820475, 46.44764854061989, 50.699235008608916, 53.95639865629135, 52.442026445942545, 59.48144143627536, 51.57359800031109, 36.98381654677853, 54.28032759697207, 54.92105460936024, 56.1961857734188, 57.43447019207863, 59.82467236057405, 50.087392330169685, 42.14033303722259, 47.248478858701645, 47.14142560958863, 48.707992799820445, 50.01751922792005, 54.326015364739206, 53.39932403256817, 57.86840592661212, 60.459107891205825, 60.504179846855905, 57.444425167575965, 68.28579748830488, 59.101532428495354, 66.8297116987167, 62.282339296033314, 72.90052090921711, 15.204071690959317, 0.2969942698555608, 1.52583300827011, 0.213714950687943, 0.9575020401708542, 10.518679907245021, 67.09725656817037, 61.070275921975416, 61.51969717394922, 60.356992906139745, 62.042694245615316, 41.71729364702779, 53.4270041988742, 24.808961922122588, 42.151931485822125, 56.46660966257895, 33.58551817555582, 0.13063700539210152, 0.12840713794913985, 0.12026522443780016, 0.03272097888252428, 0.04130946036668555, 0.11362418442243531, 0.11002485054515063, 0.03390256225341751, 0.0660428311675787, 0.032491278909747644, 0.09079490983558279, 0.0492553013346849, 0.192633114995495, 0.19700612872838977, 3.05330605756852, 67.15115777907833, 56.15355745438607, 44.375083831048784, 44.90777700178085, 74.17682878432736, 40.914976750650716, 51.94153201195502, 74.50715511075913, 65.7663179213001, 72.37441339800435, 61.607848521201845, 73.01451283116495, 22.722478681995025, 0.41690449681012864, 2.5333939300429438, 0.7376254289861649, 5.632424527598966, 0.2892286204282315, 5.5494938550456885, 54.71845634521977, 47.66369312040268, 55.69856251439741, 52.99061306061284, 56.924216901102376, 53.24714783699282, 61.013954608671135, 59.91727559797226, 59.965516828721576, 58.156394189403905, 57.88180082075058, 56.422212354598514, 57.89956915763117, 56.71711967837427, 59.195002509701645, 52.80801103961084, 45.39548058663645, 55.3780185791754, 58.76986857383483, 58.846978449052386, 51.21088466336651, 56.15729547316029, 56.913218575139204, 55.915002822875984, 55.39929351499004, 53.63153619150962, 53.782115982424834, 49.53466369259743, 49.141716726364635, 53.40650981472385, 48.19617840551561, 48.57460083500032, 54.62165224936701, 54.94009771654683, 55.07261499281853, 56.00356601899671, 52.659604241771085, 54.09332467663673, 53.721993892423576, 51.0725034436872, 46.599463878139375, 43.59992150337466, 43.71489401786558, 42.5119540768285, 41.31524285962505, 40.19820674773186, 44.131814510591575, 41.631201544115626, 43.38767420861029, 41.50577983548565, 45.802685368445616, 47.41637983629781, 51.401543232702444, 51.467917580758375, 50.741529926177, 49.02875246540193, 53.969228729125, 61.51638277115361, 52.97819875901746, 44.519599637677594, 45.84489399386991, 47.131007794410955, 48.26469044531546, 51.271395068014826, 64.13493356397076, 56.464001286414366, 44.122063498343195, 50.01116498824089, 53.178294550987985, 46.708321417531664, 46.96471106621527, 47.61303963199739, 47.107971714388945, 43.31339236228697, 41.91584010278025, 41.70598153145083, 42.012514760417325, 39.05221569922663, 40.54960012435913, 41.67766986354705, 43.07665378816667, 42.26771200856855, 43.30746958332677, 50.343334828653646, 53.83062001197569, 52.83398105252174, 56.17588358540689, 50.23408112987396, 51.462155618975245, 53.19965577894642, 52.5614155492475, 49.403648684101725, 47.22067709892027, 49.76593840506769, 46.56356634632234, 47.80448267536779, 49.53409102655227, 52.46238354713687, 55.54441336662539, 55.39630074654856, 58.97694226234191, 57.31275904563166, 41.85072875791981, 53.82533657935358, 55.60854411894276, 58.181387532141905, 59.00315153983332, 61.81556940078736, 53.29937027346704, 42.93202815517303, 47.811742982556744, 48.922644507500436, 52.23918107248122, 51.481571351328206, 57.86273810171313, 56.09327846957792, 61.44556830006262, 63.52722114132297, 63.336448823252034, 60.60309810023154, 68.81149707301971, 61.77117601517708, 69.13111532888105, 66.08995268421789, 79.55574758591192, 18.663525696723692, 0.4747511831022078, 2.188603618452626, 0.4177384601245004, 0.8969639337831928, 10.753266080733269, 74.74614512535834, 64.47925490717735, 69.98432497824393, 64.70128459315147, 72.3868316219699, 44.21185439632785, 65.04573145220357, 30.82819196485704, 43.4781240647839, 65.72185785539689, 40.621101010230284, 0.10062477551400663, 0.07271047741655381, 0.04450329241432971, 0.08078888989984989, 0.033721922551311796, 0.05375621727697792, 0.17392852674088172, 0.10569472241425708, 0.24050562762685362, 0.10531197722640731, 0.19899095528789107, 0.21025745798983883, 0.4900358016452482, 0.24064674102250608, 3.3711570405190994, 81.17150522047474, 66.33934482451409, 53.32433615961383, 42.76464100806944, 78.04329733694755, 50.19565759166595, 61.90809419078212, 80.73229389805948, 72.72082928688296, 77.06543476350846, 67.7499468095841, 75.73267613687824, 27.124054624188332, 0.525807143459397, 4.487162059353245, 1.599095773793036, 8.233277586198623, 0.3259868060629214, 8.392552291193317, 63.64006380881033, 54.83940655185331, 59.11266803741456, 57.53996233786307, 60.180670599783625, 56.700790851346916, 63.53046101908531, 63.49808185331283, 64.89981928179341, 60.821166192331624, 59.62668680375623, 58.992419935041866, 62.1515949310795, 59.74959819547592, 61.78073483128702, 54.22619104385377, 47.88436566629718, 57.72517273502966, 60.45764092476138, 61.33843268117597, 51.24985733339864, 58.24648710989184, 59.63675552798856, 58.04624226785476, 57.19981831888999, 56.64788592246271, 56.73471935333745, 50.266193574474705, 50.94782698538996, 54.986711163674634, 51.76360545619842, 48.48941872196813, 58.51607945657546, 56.856261837867, 58.12740395146032, 60.38286878216652, 55.24588961755076, 60.22114161522158, 57.45268175678869, 54.4444081860204, 49.99059215668709, 46.85999554972495, 47.18838422529159, 44.44045012997043, 45.14369972290532, 43.49331540446128, 46.78896927064466, 44.793785079833, 45.35857108331496, 42.84652048541654, 48.59659356455649, 48.26397265157392, 52.447090225835005, 53.57989818819108, 51.43169841458721, 51.30772798292099, 53.854252292263894, 64.8407248527773, 55.843439179082075, 46.1301758212428, 50.30340902266964, 49.04860750321419, 49.975471419672814, 55.09488228828677, 69.89836231354745, 58.68375293670162, 45.83362894673502, 51.63880348205567, 54.97261024290516, 48.88874346210111, 49.66019130522206, 50.86071898860317, 49.786299428632184, 47.18510904619771, 43.88599172715218, 45.723473102815696, 45.62249168272942, 42.87975472788657, 44.150783092744895, 44.982753107624674, 45.56352669192899, 46.095780557201756, 46.900474409903254, 53.9440510349889, 55.238495949775945, 55.87705389145882, 58.34194975514566, 52.20975937381868, 55.44609523588612, 54.14487638781148, 56.67189082791729, 52.263248735858554, 48.85574848421159, 50.944485126003144, 48.25730854465116, 51.86287280051939, 52.43848454567694, 53.56651113879297, 59.27137497932681, 56.3677933908278, 63.37642954241846, 54.624331228194706, 41.17386887150426, 57.39350888036913, 58.35808638603457, 59.39248992550758, 61.629829483647505, 66.26838130335655, 54.26248081268803, 45.67122320975027, 51.97018492606379, 52.06914632551132, 55.024311004146455, 56.09969938955, 60.24981414118121, 58.72734223642657, 63.140263634343306, 66.24333304743614, 64.36492173902451, 61.207182330469934, 72.02796613016437, 62.661487363999896, 71.58188281520721, 66.85471288619503, 84.6849290786251, 19.786814066671557, 1.0273515469124241, 7.2799386516694105, 1.611057777077921, 0.9409384225164691, 13.856710080177555, 79.93466423403832, 68.82968118113857, 74.44562096749583, 71.70753202130719, 75.07866013434626, 52.12002338901643, 71.01510032530754, 40.77487753283593, 61.118540686945764, 74.30738879788306, 53.406584339757124, 0.2656062992830431, 0.23809073462841973, 0.20717347912009687, 0.1494026968195554, 0.1532921864981613, 0.1634700782597065], [0.06578401602323979, 0.02297376068459163, 0.0657524302181217, 0.04151107172571844, 0.048188454952211156, 0.05126591441371749, 0.011273755639370893, 0.009819967822442132, 0.10707669140350436, 36.0602827225962, 52.16679373095113, 42.337412526530606, 23.24296151438067, 36.3502674718057, 41.73076306619952, 45.12264051745015, 71.92370953098421, 53.83135349519792, 67.35711359208631, 56.57265878492787, 66.85349695144161, 40.67582199650426, 0.0676240902694483, 1.3456935002919168, 0.8827224205578528, 6.120487499621607, 0.10844954394645269, 0.4700302735211388, 31.957156004444247, 43.91760210837088, 44.34905890495547, 49.08061404382029, 50.84267216344034, 55.868044207173014, 58.96513592812323, 60.117787161181056, 56.232428473811, 54.027091533907004, 53.54886439538772, 53.807219151527654, 53.5242985909985, 53.10723689294631, 55.448778137083984, 45.05404610787669, 42.33983262892693, 54.271141406028505, 56.99279169882498, 54.519898122356786, 52.484937175627685, 55.61755380322857, 57.5795155186807, 56.97161874463482, 54.51405379080004, 55.270247536320845, 54.509590133543945, 52.399347136097575, 48.55457713527065, 48.826162046001805, 48.28288632054483, 46.20053137502363, 50.24730343972483, 51.22540920011459, 50.353995830782004, 50.826135450793856, 51.57290766316076, 50.0517850537454, 50.828955634947754, 47.68659583983883, 46.051944148155954, 42.36941122239636, 43.34200605269402, 41.11670424861293, 40.94417095184326, 39.68298773611746, 41.63026409764444, 37.487554780898556, 40.295002998844275, 40.85670994174096, 44.52136862662531, 46.753193332302956, 51.06576873410133, 52.22785326742357, 54.674451274256555, 47.279410669880534, 42.19064135705271, 44.87911624293174, 44.32265743132561, 49.42744570393717, 42.52379963474889, 46.62869730303365, 45.25324759944793, 46.18682661364156, 55.21764070756974, 42.86808175425376, 47.93394050290508, 52.13568149074432, 46.23929615943663, 42.033193495965776, 47.83118617150092, 44.44741625939646, 43.57791700670796, 39.60048067954279, 41.71728187991727, 40.142465945213075, 41.32609213552168, 39.567026784343106, 40.790339516055205, 37.531481404458326, 40.401456125320934, 38.24067731057444, 45.26592077747468, 50.02732515335084, 49.94908955789382, 48.20426633281093, 49.044712589633086, 50.77350116545155, 49.985865700629454, 48.37561899615873, 52.23223455490605, 45.347639437644716, 45.830392991342855, 49.03919773717081, 47.309287363483065, 49.350163244432025, 55.16233921051026, 52.220800845853745, 56.907083988189704, 52.547604883870775, 63.726312806529386, 31.21931306777462, 35.20128757722917, 59.70645996832079, 56.37167261492822, 56.18616019525836, 55.25011793259652, 55.24781550130537, 44.76217077624413, 44.87944964439639, 46.307792509755785, 44.72441404096542, 52.453844547271736, 49.761313930634536, 51.73781194994527, 49.82458176151399, 57.28510633591683, 56.157562194332, 63.884521607429754, 60.284523194836034, 69.81920888347011, 58.44382155326105, 65.72466235007009, 59.817972952319735, 74.95666657724689, 25.45333673877101, 0.675691020104193, 1.2337212312606074, 0.1088564209039173, 1.1266440802043485, 16.29849926117928, 69.59715566327496, 63.07423445486254, 59.71909000027565, 59.25352035030242, 59.16766751197077, 44.10539734748102, 51.06026957111975, 21.58218291498, 39.870194619701756, 54.532073159371656, 18.8377534574078, 0.30807928632824655, 0.15344658385842078, 0.20716390302104337, 0.0963844788531142, 0.08956393677621119, 0.04676883657192511, 0.0999092034274532, 0.05416720812659591, 0.08563617334490822, 0.13901563241116463, 0.0652992892109098, 0.03139909799961794, 0.02830102694250884, 0.06860481304747444, 0.17534889971777318, 46.515136841804754, 64.32368586140295, 48.65565661461123, 36.84344668542185, 53.40224227597637, 46.38446307951405, 52.474954743539136, 75.90338553151777, 61.91487204643988, 75.17429536388767, 62.69656904282109, 71.81780553633168, 45.5499239121714, 0.04754335146337267, 2.538336116460062, 0.502152401473253, 4.575575224814877, 0.389174749293635, 0.37290129510145037, 40.82738630233273, 48.0635356133984, 51.730182939960116, 53.13880020572294, 55.02280481400029, 56.76841251311764, 63.77918243408204, 60.365473070452296, 59.092832611453154, 55.54656282547982, 55.94270260103288, 56.336226155681, 55.54104797301754, 56.731585379569765, 57.25788508692096, 47.047747642763206, 45.739790162732525, 58.39390547044816, 59.002249394693685, 55.342360311938876, 53.800441295869895, 57.33792497265724, 58.888128034530155, 57.70589428563272, 55.840681752850934, 58.62291305295883, 56.87168459738455, 53.866070393593084, 49.59130664025584, 50.6428038689398, 51.514731068764966, 47.45528974840718, 54.91575548725744, 53.040784097486934, 54.50040786497055, 53.33040014390023, 53.62674697752922, 53.44001862310594, 53.2760400156821, 52.52620443221062, 47.95465846215525, 45.86576100318663, 45.29264388545867, 44.32016280389602, 41.15995622450306, 39.630243624410326, 42.852184387945364, 39.42824156053605, 41.50111613735076, 43.417033149350075, 47.36904075068813, 48.80106672163933, 53.795663849000015, 53.99425737319454, 55.612050717876805, 46.080518614861276, 41.50882359473936, 46.324725381789676, 47.0022677606152, 51.576155385663434, 44.35849612759006, 47.27796331528695, 46.79648453189481, 50.1942612278846, 56.759963727766475, 44.50650284367223, 48.50713214566631, 52.47941447842506, 47.097028301608184, 43.14198478575676, 50.11026367064446, 48.28580064158286, 45.38514121886223, 42.00892186933949, 41.85622007616105, 41.08621174289335, 41.40087996759723, 40.82590364640759, 41.018064483519524, 39.99006225216774, 43.049648269530266, 41.70884486167662, 48.449418390950854, 51.860115374288256, 53.228606793188284, 49.56876477887554, 52.4545858752343, 53.24983073819069, 52.742201512859715, 52.75884412950086, 55.07302291931645, 47.15811529467183, 48.48994824194139, 50.52032786030924, 49.86809653620566, 51.05539798736573, 56.94014956874233, 54.511017876286665, 58.728118865720695, 54.02297696759624, 63.467016681548095, 35.529099664380475, 38.613027911032404, 61.34430446932393, 59.02705054129324, 58.95704015608757, 57.38153388423305, 57.02000118071034, 47.20468167335757, 46.680582415673044, 47.98388011993901, 48.55160005630986, 53.960324948833836, 52.636301440577355, 54.05803511219641, 53.68963041613179, 61.19859233979256, 60.28444082506242, 65.84840528426632, 64.89596359191403, 70.55505337253695, 59.76230275246405, 68.63136614522627, 64.13285078540926, 80.95202507511263, 26.61402883068208, 0.5777912346586105, 1.3363531111709535, 0.18371264930934678, 1.187680205029826, 17.647880892599783, 77.87208587892594, 67.52597947274485, 68.12458022948235, 64.72519928409208, 67.41532941018382, 48.58308884405321, 61.250320557625066, 23.406185065546346, 43.6090684706165, 67.34137704295497, 23.305644912104455, 0.5466554602307658, 0.2540214257615228, 0.20891505744188063, 0.16572240740060806, 0.13180856833294516, 0.04273645234324279, 0.30596319826379903, 0.14085148551291035, 0.19412611310760822, 0.26086396988361116, 0.12963919119248468, 0.09900375644886687, 0.15025159884845057, 0.19667450458772723, 0.18440618870719788, 57.22843593166721, 73.71667200519194, 60.64371424336588, 35.72342564982753, 53.19239154938729, 56.80756168980753, 58.01971135600921, 82.54653130808185, 66.79346899832449, 79.34546932097405, 67.09942956124583, 77.61475486140098, 50.89774224065965, 0.15906616053994627, 2.562422165947576, 2.250530489029423, 12.137433252026959, 0.22277527338554784, 1.1090868158686547, 50.270206159160985, 55.457834889811856, 57.679524190964244, 57.4040404442818, 57.001679789635446, 57.56139809085477, 65.83503000197872, 65.0487163759047, 61.55555155969436, 58.40859474674348, 59.23834077773556, 57.40070250726516, 60.03035360766996, 56.80918555105887, 60.148240443198915, 49.07706822118452, 46.03130463630923, 61.321793986905014, 60.43490294487246, 55.65681672865345, 55.81109139227099, 58.891638555834376, 59.75330483528876, 60.941182874864154, 57.60230841175203, 59.216132317819905, 58.777148492874645, 56.547277127542806, 52.273819523472945, 52.05996405693793, 53.05388089149229, 50.26705257354244, 56.882106334932395, 58.243910112688624, 57.76942491531373, 56.885193240258005, 57.877894140058956, 56.08151135906097, 57.08316310759514, 54.34093998324487, 50.268743115086714, 48.037714650554044, 47.70191269536173, 45.99205347799486, 42.87680902788716, 41.93109420038039, 48.40317756898942, 40.17809283348822, 44.12325982124575, 47.437223311393495, 49.88564914272678, 53.46767133282077, 54.79766861084969, 58.38970461199361, 59.18934252954299, 47.68513671813473, 42.50905544527116, 44.957865668881325, 48.95836161028955, 53.87584886243267, 47.9285825452497, 49.44284885160385, 49.378867149353034, 50.554954544190444, 56.73111469514909, 44.93048360270839, 50.97742519071026, 56.53687500184583, 53.312608272798606, 47.14944293422084, 52.55024071662657, 51.220518004509714, 49.84610380664949, 44.81867251857635, 44.25400418619956, 44.43692784155569, 44.691493588109175, 43.31704016654722, 45.23686778160834, 42.08665147904427, 45.19218414060531, 42.95865712627288, 50.5775866200847, 55.132897899996856, 56.682096835105654, 51.57943448712749, 53.565750198979536, 57.30319238478138, 56.31585336500599, 55.918529033660896, 58.715747710197206, 51.33721243950629, 50.85050513667446, 55.403494373444595, 52.31901699496854, 55.56358591202767, 60.56020698239727, 58.48315900371921, 60.85013681842435, 54.95139806501327, 66.31903479176184, 34.23126974413472, 39.45020683350102, 63.71168628815682, 60.19517160231068, 60.844496450116566, 59.93309843924738, 59.821628601320334, 49.83521922942131, 48.654193570536954, 50.94061374664307, 50.90921125104351, 58.30036870894894, 55.55828678992487, 56.6003389512339, 55.967205647499334, 64.45440276976555, 63.1809699919916, 68.80253837954614, 65.74432519174391, 73.68013904940698, 64.15603591549781, 69.51651957727248, 66.78691864013672, 85.52786211813651, 30.862728434224284, 0.8700923273159612, 3.840233289426373, 0.49819935714044883, 1.234594816642423, 22.467681515601374, 83.77597470437327, 72.80710574119323, 74.81823828912552, 73.1940632481729, 71.7488032002603, 54.913343229601466, 66.00992064322195, 32.69024502846503, 54.061996706070445, 78.0432188895441, 32.5843116160362, 0.8048808394420532, 0.47974108147525024, 0.40161151258695515, 0.2710442671612386, 0.34425594994137365, 0.2218939505156971], [0.020325756706898252, 0.028333903605779334, 0.046253071707342906, 0.07193770154469437, 0.050110898972038305, 0.055583735342107476, 0.1503003373621933, 0.29664352416030826, 0.603048847086968, 21.942478110713346, 56.94802961041851, 47.05567083051128, 32.03442669683887, 26.49408078962757, 39.662371758491766, 43.05740671773111, 81.11644298799577, 51.195195182677246, 66.72070903162803, 58.775155928827104, 65.40774268488731, 48.93599233319683, 1.393058939326194, 3.1443016134923507, 0.41156210606136634, 4.659508553243453, 0.7890963638501783, 0.16718964963670702, 15.992351405082212, 45.631642572341434, 41.69870553478118, 46.13154865080311, 52.468055294406035, 60.925171759820756, 60.30866930561682, 56.45131241890692, 54.60619026614774, 53.43697094148206, 52.55287654938237, 53.82510908188359, 51.50251680804838, 52.558622821684814, 49.5668153608999, 43.39643286120507, 42.60439257467947, 51.982187378791075, 57.29775990209272, 56.09226257570329, 56.94421706661102, 54.9825220723306, 56.99896550947621, 57.03516506379651, 58.6489732803837, 56.58297854085123, 58.682074162267874, 55.8048116776251, 56.42415785020398, 51.0340642159985, 49.095491593883885, 45.4729473975397, 50.33631770841537, 52.165887663441325, 48.48489622915945, 50.00032747945478, 50.925818566353094, 52.917111765953806, 51.54408608713458, 49.47882090845416, 47.47704321338285, 45.901831119291245, 43.802260891083755, 40.676955561484064, 41.83321145273025, 41.70169045848232, 40.662195682525635, 40.18632196610974, 40.806064298076016, 45.73869582145445, 43.25340755524174, 50.850399232679806, 53.00247823038409, 52.57229228173533, 48.103069182365175, 39.87295596830307, 42.34155847180275, 42.19269275665283, 44.02442393764373, 52.8190250550547, 49.12024959441155, 51.787629973503854, 47.34715000275643, 41.40931306346771, 44.141765563718735, 40.940593750246116, 43.21907897149363, 42.39122352292461, 49.88694744725382, 53.5885940828631, 54.4762578318196, 46.954006918015025, 43.972232880130896, 40.374556510679184, 41.652496091781124, 40.101712519122714, 40.194884500195904, 40.33664288059358, 40.618480866955174, 37.30563132993637, 39.433956453877116, 38.0498500793211, 44.04765613617436, 52.49509611437398, 49.219917020490094, 49.755222489756925, 52.306049639178866, 50.42470832024851, 51.778573220775975, 49.216900717827585, 52.3412960575473, 43.57586168473767, 46.851158449726725, 45.13927136698077, 50.560394871619444, 52.638905894371774, 54.42347841878092, 55.95831363431869, 56.21245576489357, 55.9541755337869, 55.143398084948146, 40.31686629018476, 53.87336992448377, 57.06311195127426, 55.0502888617977, 55.84569454193116, 57.19380140304566, 47.36187850275348, 44.72454347918111, 41.63442181002709, 44.066636485438195, 46.435065577107096, 51.28273071781282, 49.408943883834354, 52.99713203983923, 52.167346785145426, 54.04720544815064, 52.70856326626193, 62.15491325624528, 59.1230191722993, 67.77101778214978, 55.24381468372961, 64.5649233941109, 59.70921739455193, 79.29440006133049, 25.192446170314668, 1.4219008626476413, 0.220505676622833, 0.2576039286871111, 1.1361053273562463, 33.090009074057306, 68.64867164242652, 59.72906066525368, 51.463085220706084, 63.77611514060729, 54.001027384111964, 45.09505841039842, 48.171137994335545, 30.376525155959595, 39.014074571671024, 57.01556105767527, 8.18959120781191, 0.3047818293975246, 0.28200986584828747, 0.13244132631488387, 0.056331372038731654, 0.12871620846131157, 0.004653993716102935, 0.0791350746106717, 0.09633386342395699, 0.03585137118915877, 0.16432870960524007, 0.11081443438606878, 0.05249240585873204, 0.21903429751194295, 0.31893990032615205, 0.6198843953109557, 28.6050945328128, 67.06144532849713, 50.41829524501678, 31.27173750631271, 42.50760809067757, 45.4570500312313, 49.99118051221294, 85.00806962290119, 57.19565276176699, 73.17324330729824, 65.53770649817683, 71.52718928552443, 53.91302508692588, 1.5770504599617374, 4.054923240215548, 0.3740680776536465, 6.342249974127739, 2.0785247510479343, 0.3146368763860195, 22.795511253418464, 49.42559042284566, 47.48563712643039, 51.56359203400151, 54.96561665688792, 61.366705125378026, 62.03268043456539, 59.956715030054895, 57.71456272371354, 55.863604084137954, 54.470401733152336, 55.15981320411929, 55.17136850664693, 55.741586992817545, 52.38997267138574, 46.39737159975114, 44.26652046941942, 52.99349992505966, 60.294446791371996, 59.02757221652616, 58.598578668409786, 58.42765746578094, 57.16581529186618, 60.16561654306228, 61.411863373171904, 58.17140117768319, 59.11645704700101, 59.054373771913596, 57.01399210960635, 50.56869460690407, 49.41665134122295, 45.67624776594101, 51.96638022699664, 55.433802527766076, 50.90098604079216, 54.23320816409204, 53.860147614632886, 54.773624481693396, 53.85092612235777, 53.02086237938174, 50.70029404855544, 47.1341613800295, 46.15519269820183, 42.147793385290335, 42.29576087767079, 44.110421903671764, 44.08775452644595, 42.35498474490258, 42.31534919431133, 45.19233319067186, 45.908554061766594, 52.71302300114786, 56.46969656790457, 55.30720018571424, 49.367472664002456, 40.86602557090021, 42.272893459566184, 42.36737551227693, 44.868937692334576, 54.851663958641794, 49.906045467622825, 52.324614217204434, 51.565470849314046, 43.49098943894909, 43.74374305048297, 40.91838529033046, 44.49122128948089, 48.30665980615924, 53.58779784171812, 53.41727279847669, 56.320183661676225, 48.16172822829216, 46.5634722094382, 42.19808601563977, 43.92667455057944, 40.95684805224019, 41.43374550727106, 41.93193750996744, 43.70970472212761, 40.47858561238935, 41.4155613991522, 40.32450314491026, 46.662359083852465, 55.13212127070273, 52.81811898754489, 51.756486354335664, 53.571421946248705, 52.564522066423976, 53.51841503574003, 53.41960660872921, 53.221511225546564, 47.75752798203499, 49.713594375118134, 48.2494245806048, 51.42223373536141, 55.31045967532743, 55.6364635498293, 58.1877927626333, 57.532654962232044, 59.11378591291366, 54.93477113785283, 43.395213004081484, 55.580546240652765, 59.08313651238719, 59.14270947056433, 59.428124658523075, 58.418126106262214, 51.18208662156136, 46.37992097485451, 44.652167904761534, 45.8726369180987, 49.22018374166181, 52.69925548184303, 53.942674283058416, 55.26376778079618, 55.9357286268665, 57.121308157520915, 55.503181411374, 65.04383694741034, 63.104711271101436, 69.19545788918772, 59.03238496472759, 66.73670445719074, 65.0448920649867, 83.52535093984297, 32.816117809664824, 1.8441395990310179, 1.408299308630728, 0.21894376124105147, 0.8097451913260645, 38.29892058526316, 76.14276778313422, 64.2747268369121, 58.691927156140736, 68.41864032130088, 64.63049757865168, 46.30953404211229, 60.7405379510695, 37.85865806764172, 44.58679376109954, 69.45162788514169, 10.783911558889574, 0.4797621642149264, 0.13995182249815236, 0.10215556474342462, 0.05883056535235336, 0.04256414384731362, 0.035576548637642015, 0.15215281457189592, 0.10571186746200247, 0.16616364340147666, 0.312347223441447, 0.17705928293928025, 0.30570377024912065, 0.504034802077278, 0.7293172360908601, 0.7801491310519557, 34.52201543315765, 79.29086992817541, 62.134987615769916, 47.27687289637905, 41.14625538549116, 55.46884890525572, 57.394379646547385, 93.32603608408283, 61.566985268746656, 77.63356654874741, 69.71780776977539, 76.69801850472727, 59.36252693976126, 2.070373820681726, 5.300831275601541, 0.9375700871309928, 14.046030140692189, 3.851071288508754, 0.3186442516744137, 28.91003724067442, 58.07006282191123, 54.14238176038189, 56.24176763719129, 57.55548315663492, 65.29010688104938, 64.95268106460571, 60.71197132910452, 60.985556648623565, 59.825817692664366, 56.35124883344097, 59.050902474311094, 56.517769136736476, 58.738211124174065, 56.0100693087424, 48.50141332995508, 45.97105310809228, 54.65771452073128, 64.779645704454, 60.00163009089809, 62.68162089009439, 58.83710976569884, 60.473047994798236, 60.898785975671586, 63.947809050160075, 60.30410366673624, 63.002113834504165, 59.36161302751111, 59.51189471829323, 53.61716462719826, 54.036379706475046, 49.06233972118747, 55.4880645967299, 58.97297674609769, 54.87723388979512, 57.15814705817931, 57.06527709960938, 60.67284568663567, 57.55522035783338, 56.406291454069084, 52.976319943704915, 50.27587006168981, 47.91031606735722, 44.23738510377946, 45.13693755672824, 47.313907915546054, 45.34270509596794, 45.235608700783025, 45.20507697136172, 51.381323414464156, 46.06917119795277, 54.36542341786047, 57.730314962325565, 58.391136277106504, 49.99293381167997, 39.986896899438676, 43.20178131903372, 42.276007821483, 47.67697426580614, 58.549698091322384, 52.77162321152226, 54.68457098930113, 54.58618617826893, 45.11627451066048, 43.771776230104514, 40.85494095279325, 45.6955183705976, 47.67935514450074, 54.58329146908176, 55.58038150110553, 56.20992583613242, 52.095539954400834, 49.6203439466415, 45.78267735819663, 46.49744695232761, 44.342316350629254, 44.274937875809215, 44.61245390676683, 44.7327765341728, 42.26503695211103, 44.724296369860255, 42.533558491737615, 48.63264014644008, 58.037244350679465, 53.94145050356465, 55.243755848177024, 57.26069350396433, 55.551057861697295, 58.85443879712013, 57.60538354996712, 57.69176590827204, 49.172236688675426, 50.20949179126371, 52.19446213014665, 53.41387210353729, 56.07642796731765, 57.158225505582756, 60.17680706516389, 59.72325947976882, 60.209817732534106, 56.385718622515284, 42.703334362276145, 57.935788323802335, 61.832141414765395, 60.75772185479442, 63.52593068153628, 62.733764879165165, 54.27565997646701, 48.27874037527269, 47.14302593661893, 49.16989111131238, 52.53264104166339, 55.48243207316245, 55.30907115628643, 57.933376066146366, 59.62501195169265, 58.71008380766838, 58.92084060176727, 67.65494700401061, 66.09783664826425, 71.75536924792875, 62.47042871290638, 69.1704410122287, 67.35825892417662, 82.28104960533881, 37.32539615323467, 2.040521519318704, 5.211062931245373, 1.2615386805226727, 1.3416354406264521, 42.21288119592975, 82.12581788339924, 69.81506686056815, 65.80270967175885, 76.36409144247733, 68.37546287044403, 56.94759814969955, 63.852338560165904, 44.67779274909727, 55.76512905859179, 79.91568780714466, 15.893816563390917, 1.0044170807926887, 0.7275261838109263, 0.3163025353945071, 0.22362363915289604, 0.13800243516602825, 0.10972036889964536], [0.025201103867842786, 0.07316473691213517, 0.08679235324023232, 0.023919161063649004, 0.015597762727749445, 0.059327901971917, 0.0668759671069922, 0.05970083740389636, 0.4139986027392649, 7.1620488743628234, 61.28611610781763, 47.28804772899997, 53.97617916907034, 33.070279552090554, 42.587722501447125, 32.96048456622709, 65.53229362733903, 51.07280546619047, 57.29306874736663, 64.6712157034105, 55.39710483243389, 62.84700370603993, 2.7244199764344, 2.980469604653697, 0.5049188675418977, 1.171485106310537, 0.658657759908707, 0.5373196063503143, 8.770012759393262, 39.552266905384684, 43.23116379399454, 49.303200706358886, 58.74831907210812, 60.02735299448813, 59.174731700651115, 56.54092288786366, 51.743624902540645, 49.621238247040786, 51.2465899990451, 52.9672553462367, 53.670865797227435, 49.879840112501576, 45.770164997346946, 42.77125020180979, 46.131454513918975, 47.72876131919123, 55.84103868853662, 54.649952150160274, 56.48539781570435, 54.95942323438583, 55.49653299393193, 56.18580325957268, 58.18519615357923, 55.03941997405022, 55.82207795112364, 55.26354812806653, 58.30253385728406, 53.3503963870387, 47.84868778720979, 45.471617714051284, 48.467810384688846, 51.66737402639082, 48.91964389431862, 51.23992196975216, 50.799447644141416, 49.7582584042703, 51.89537748213738, 50.49515408854331, 49.23094280304448, 46.02609572872039, 43.266045431936945, 40.86802205731792, 41.94867818586288, 40.74670707025836, 38.98823007460564, 41.07384058736986, 40.033251470135106, 44.157168711385424, 43.77922088869157, 54.17368619672714, 55.464055768905155, 52.24253469897855, 48.56849762701219, 39.95784390357233, 38.531619118105986, 41.40452777185748, 42.56718104885471, 51.62638133571994, 54.677514645361136, 52.683456174788944, 49.01805616194203, 43.37895870208741, 42.4154245468878, 41.0640307395689, 42.787696699942316, 42.79254082710513, 50.188197243598204, 54.02602072684996, 54.43146044208158, 50.960296200167754, 44.844175769436745, 41.34097753032562, 39.79566174168741, 40.11486030394032, 40.592381415828584, 40.31537186714911, 39.246196516098514, 38.92634291802683, 40.93627129831622, 39.347703533787886, 44.36177522905412, 50.871152493261526, 52.88955319312311, 52.21179900630828, 50.78118508861911, 50.04228115081788, 51.84838748747303, 51.28879470209922, 50.93623245916059, 44.8590023286881, 46.19097648128387, 48.39403452411775, 53.403195411928245, 55.828287063106416, 57.02027966899257, 54.93214314983737, 56.36465941706012, 52.24158940776702, 50.8573143712936, 54.21268632335048, 60.386724472045906, 53.10296543182866, 54.31504449536724, 50.87860107421876, 44.64906530995523, 41.25158279172836, 43.67861601614183, 40.75036664162913, 45.81030653369042, 44.63163821927963, 51.103898094546416, 50.72793106878958, 53.370055306342344, 50.33728261147776, 52.30538283624957, 47.64369687726421, 56.083888315385394, 56.376697171118956, 58.87438797181653, 51.99937912725633, 63.5928737732672, 60.05049890087497, 73.7024808699085, 23.962726246926096, 2.6557147599035695, 0.5388277576815698, 0.5482309047252901, 0.5930777530997031, 49.4992603794221, 64.04575847810315, 57.80354169107253, 55.13747138361777, 65.59987214303786, 48.48424119334067, 57.15560143993747, 40.589380802646765, 23.87247447044619, 44.762433575045684, 55.9172817199461, 3.189414263732972, 0.11280167412253157, 0.09803931303923169, 0.06089954667033688, 0.04590694935271337, 0.05005336193848522, 0.017384067177772522, 0.007849101778945976, 0.085596758121204, 0.06031438573113373, 0.07499541892039199, 0.1739142775054901, 0.078611706323441, 0.12569718618666934, 0.14283906998893908, 0.5687229599683516, 10.755917602969754, 73.70975294420796, 56.09254890872587, 50.95124729218022, 37.446711140294234, 50.74755860913185, 35.867333489079634, 76.07956271017753, 55.12442558042465, 70.23968696594238, 69.33824000820037, 63.452900071297925, 64.74550147210398, 3.8441468342658016, 2.9646553435633263, 0.3129407270781456, 5.8852011830576005, 4.929574526125386, 0.6143645173118961, 10.650792198796427, 44.769368325510335, 45.90417669665429, 52.802758985950106, 57.63630359403549, 64.87193122986825, 61.262020987849084, 59.487046503251605, 54.88122686263054, 53.137019449664706, 53.4843296389426, 53.202668159238755, 54.6018325128863, 51.422488689422615, 47.84585191357521, 46.17676965651974, 47.01024978391586, 49.83788644113849, 57.002644692697835, 57.76560844913606, 57.99045831926408, 56.96242863132108, 56.34216854649206, 57.85805086935721, 59.91884062367102, 56.13281988328504, 58.40913211145709, 56.608175846838186, 59.59224054890295, 54.7414335896892, 50.505768022229596, 47.480514510985344, 50.41875808469711, 55.015873985905806, 51.67473631520426, 53.391463602742846, 54.621499276930294, 54.48253754646548, 55.637314704156694, 54.61946356681086, 50.21852893214072, 49.23293144472184, 44.419794928643014, 41.92397509851764, 43.52921685864849, 42.26509186529344, 40.317411499638716, 41.90409652648434, 42.768692816457445, 45.914731794788, 47.16264170985068, 56.75782603602256, 59.43250202363538, 55.81836738894063, 48.98996022439773, 39.6046030905939, 38.78144271912114, 43.66281278671757, 42.79815373882171, 54.92203520190332, 56.34398852625201, 54.85349962788244, 52.26253878685736, 43.014527367007354, 42.65328099650722, 41.41237251220211, 41.96970601235667, 44.08641699821719, 52.310936912413574, 56.02125983084402, 58.40168353049987, 52.14086294174195, 45.81963785233037, 42.858354276226414, 42.09759096945486, 42.70635458730882, 43.45089497104768, 42.62499678519465, 41.78440932304629, 40.878985081949544, 41.35827126041536, 40.23601447382281, 45.992716358553984, 55.08780633249591, 54.77425990566131, 53.71332545434275, 53.09199848482686, 53.89434676016531, 53.9292166309972, 55.06833568696053, 53.37316574588899, 47.05938531506447, 51.532256218694876, 49.66482754676573, 55.97865504603232, 57.52279804598901, 58.278815284852065, 57.301086071998846, 58.96009568245181, 52.6144342268667, 50.84606501363939, 56.240665451172866, 61.48261508634014, 55.97714101114581, 56.1886626674283, 52.27713000389838, 47.415187435765425, 43.51641816477622, 45.37610015561504, 44.188508449062226, 48.80242386171895, 45.823881856856815, 52.82220217489427, 53.57052764584942, 56.46666849813154, 53.445929634955625, 53.71404324808429, 50.849477475689305, 58.81680365531676, 60.126592882217906, 61.57619499391126, 53.587593878469164, 66.41335210492535, 63.050606096944506, 77.29608581912133, 29.796875330709643, 2.285397663231819, 0.7050144756513258, 0.49679370837346204, 1.2206435588098343, 57.20837300823581, 69.10498449879309, 64.25526795848724, 60.85214114958241, 73.24143763511412, 51.359201246692294, 59.72305551651986, 51.45138086811189, 26.123977707278346, 51.56237609924809, 63.600640066208385, 5.3132338100864045, 0.291391593073645, 0.2029319567185256, 0.05366453953507928, 0.07820309034638828, 0.16590991508095496, 0.030059909275282296, 0.19432975459964047, 0.2658839601903193, 0.18236284835204003, 0.10844703883894029, 0.20759946997127227, 0.11515031583727368, 0.2114235817064201, 0.3651148693696145, 0.7652756872196352, 12.114060828762671, 87.0669609500516, 61.65161040521438, 73.2423476249941, 45.13587067204137, 58.56865882873536, 43.07024855767527, 77.7745443774808, 61.25806723871539, 69.33394893523186, 75.07583602782219, 66.53088200476863, 73.25305569556453, 4.767781169183793, 4.643125303329961, 0.6309544271038425, 10.433611542947832, 5.744053711814265, 0.8393585345437451, 15.385093977374417, 51.3444649019549, 51.204954039665964, 57.39834516279159, 61.393730255865286, 67.13495054552632, 64.0730542521323, 61.363884941224136, 57.33978025374874, 53.47294692070254, 57.01755754409298, 58.058546743085316, 57.087289441016416, 55.41605772510652, 51.32180929183961, 49.169781284947554, 48.88645279792048, 50.82941455225791, 59.28693894417056, 59.65273526407058, 60.82572006410169, 58.562692903703265, 57.2520564448449, 60.77945963028939, 61.49269165531282, 58.19209560271233, 60.098143931358095, 57.324337882380334, 61.87799392207977, 56.49694135112148, 53.36867463204169, 49.453317657593765, 53.23517676322691, 58.9574755391767, 54.367533653013176, 58.30469116087883, 58.999484123722205, 55.74753722836895, 57.65428373890539, 57.25910494404455, 55.80567067669284, 52.05104850953626, 47.21313830344908, 44.35001204090734, 45.60083235463789, 45.21267852475567, 42.802158478767645, 45.76551698869275, 44.865054545863984, 49.724835888032, 49.81896100505706, 60.27423481787405, 61.867619252973995, 59.344209471056544, 49.93633793246362, 39.897164837006606, 38.40103949269941, 43.35322403138684, 43.238428023553666, 57.227012111294655, 58.66157585574735, 59.93760916494555, 55.8835611035747, 42.43551884928058, 42.77415667810748, 40.746126559472856, 41.924124148584184, 44.72004059822329, 53.000991652088786, 58.8949647257405, 60.484583685475016, 54.18666139725716, 48.97125836341612, 46.496572263779186, 42.88146880365188, 44.90292895224787, 44.77374176825247, 46.06302484389275, 43.15987079374252, 42.976429385523645, 44.859755423761186, 44.0642556067436, 48.48520217403289, 55.981537988108975, 57.78041931890673, 57.41676069075062, 56.398219216254454, 57.639465024394376, 57.17565259625835, 57.7715822189085, 56.47896905099192, 49.80613877696376, 53.35462470208445, 53.5519552230835, 58.2891389631456, 60.76667270352764, 63.38609426252304, 60.47559361304007, 60.03830032963907, 53.805077537413574, 51.507619811642556, 58.4435744439402, 64.49712130331224, 58.49904068054692, 58.37130477351528, 54.748615449474705, 50.22540876942296, 47.068143967659246, 47.09927581971692, 48.304345607757575, 51.983234651627086, 49.60379546688449, 55.43485764534243, 56.59844444644067, 59.97318898477862, 56.818850271163456, 57.21187960716986, 53.81020015285861, 60.7846724602484, 63.759064597468225, 63.94667548518028, 57.38615443629604, 67.27152747492637, 67.54057853452622, 77.53931199350666, 37.94417750450873, 2.399101536120138, 1.7490005493164065, 0.7063538424911038, 2.2538892636376042, 62.926219894040024, 76.19455091414913, 69.27872196320565, 66.93999305848153, 76.8952117427703, 60.88296705676664, 70.1585723507789, 55.960714124864154, 36.908279542000066, 60.92666226048624, 79.71730216856926, 8.168962972779429, 0.4721250949848083, 0.40318202347524706, 0.23665464152732205, 0.21442868416347813, 0.24668086320161822, 0.07165423369095211], [0.026464007471898393, 0.048704327069102764, 0.01757312235572646, 0.029798211725128275, 0.04732027049026182, 0.08233036605581161, 0.017201742082233393, 0.1123402517048582, 0.08526873459378559, 0.23853138840246588, 42.31688676341888, 50.96060998978154, 44.63677260183519, 41.77857675860005, 41.678521017874445, 37.76891031572896, 53.20436654552337, 60.4069717468754, 47.005444880454775, 69.37456900073637, 50.96986286101803, 67.29722684429538, 10.036615710104666, 1.3334048371161185, 0.022164787158309933, 3.222408261029951, 3.4261194977068135, 0.22683440557410642, 1.8729902251112847, 41.00063739284393, 51.66800552798856, 56.448755033554576, 59.32409555681291, 57.677939553414625, 58.20747913852815, 57.53562419645248, 54.054599115925456, 49.11605265832717, 48.40982206406132, 51.07930483356599, 47.83269628401726, 46.6865248064841, 43.46196782204413, 42.155744029629616, 41.613268467687796, 48.247208441457445, 53.442987857326386, 54.64427255815076, 55.92160417187599, 57.95139935708816, 56.849644799386304, 54.60988513885006, 57.069230848743075, 54.526597530611106, 56.46537019360451, 53.99470844576436, 55.846110313169426, 57.76712248402258, 51.2377489766767, 47.58595958832772, 48.272903888456284, 53.98449067146548, 52.99732423597767, 51.39571459062638, 51.5605051286759, 53.60478170456425, 52.41013757644161, 50.09595878662602, 49.23881892235049, 48.28858552440521, 41.76681749282345, 42.106934055205315, 40.31807830256801, 42.08573364442395, 39.55983707981725, 39.100001935035955, 39.899628085474816, 40.737948417663574, 48.26997780030774, 55.68040978523993, 55.03733719548872, 52.12337701551376, 46.83917168648013, 38.02121677706319, 38.02549216055101, 38.94088314425561, 43.99975222925986, 50.03192217119279, 57.538161969953975, 51.28042828652167, 44.57224569013042, 41.59013432841147, 40.06788599875666, 40.24445149206346, 40.655770840183386, 43.08885628177274, 45.35990076680338, 52.546337958305116, 60.21263007194766, 55.02664873676916, 46.42096857870779, 42.445183569385165, 39.715802284979056, 39.04530840535318, 39.26867954192623, 37.92575020943919, 42.10896976532475, 38.74796136733025, 40.171173772504254, 42.88248077515633, 46.29601755449849, 50.12721223215903, 52.04602003097535, 50.75153589248658, 49.9838613694714, 51.49615864599905, 48.48251927283503, 50.31139889071065, 47.02618245155581, 43.11062151385892, 48.93678857434181, 49.12104583555653, 53.73177628363333, 52.59734053765574, 31.519509707727742, 43.01202097246724, 47.24766692807598, 45.33550362433157, 58.57659378359395, 57.26273313645394, 52.97429992306618, 54.105891950668834, 47.12741098096294, 42.12355313762542, 44.87939865358415, 49.87822801836076, 44.2629668020433, 40.539390194800596, 41.83361545685799, 45.19850307895292, 45.227799261769945, 49.498052289409024, 51.18580895085489, 52.1736696458632, 51.79692599081224, 51.42120215200609, 48.68888693471109, 47.18738794326783, 49.97354553591821, 51.71034359162854, 64.42881322676136, 62.99301001333422, 71.1104609889369, 10.243972789856697, 2.203983231898277, 0.5323337222779951, 0.7120782966094633, 3.1242435930236696, 59.750296377366595, 62.88124207527407, 49.69535927618704, 53.70855977458339, 57.706000189627375, 50.03790378570557, 52.243546670483006, 38.701155724064, 56.94517412493306, 40.65127188159574, 44.69173285268968, 0.7181605444319787, 0.13535788432965357, 0.04344673076223943, 0.04274186475442783, 0.017574911171029654, 0.015219909011296209, 0.03568314977230565, 0.04319039391233556, 0.02268029155299789, 0.02391472924500704, 0.03726538946671832, 0.07123162894840203, 0.0324887125152013, 0.01993355607884305, 0.09423352612723267, 0.06443631414684557, 1.0772033396267122, 54.0067461998232, 61.40614847983084, 47.24051252488167, 43.112743516122144, 53.709716873784224, 37.86476519800002, 60.52021057375016, 62.27159592413134, 51.18226705058929, 77.10869850650911, 56.21445225131128, 73.29445239036315, 11.472130629324145, 1.9042468575700637, 0.12304541880204795, 4.206743970994027, 4.790807933576645, 0.5457867778116657, 2.6395585171638, 45.50184742096932, 54.15722400911393, 58.43748300306259, 61.62592672532605, 61.129444876024806, 59.191311559369495, 59.232033606498476, 54.15259953468077, 50.18134878527734, 50.24931169325306, 52.33524384037141, 51.04801608670143, 48.229024333338586, 45.31755093605288, 45.83063617829354, 44.74840717930948, 50.72393417358399, 54.35619408084501, 55.56407620829921, 58.206023939194225, 60.80824590498402, 58.818423594197924, 55.37700660767094, 57.218025961229884, 55.61374518179125, 57.01018348816903, 55.06103223369968, 58.315399231449256, 59.22642069478189, 52.37991963663409, 48.662206972799, 50.4069007596662, 56.185458090997514, 54.87188769925026, 53.73869534461729, 52.649814005820986, 57.39124959514987, 55.30290519037555, 52.11440655492967, 51.368022657209835, 51.58262729644776, 43.755655288696296, 43.601462994852376, 41.8568084316869, 44.007306714211744, 40.97260421322238, 41.15871675552861, 41.323601430462254, 43.77647130720077, 48.98309607659617, 57.992266531913515, 57.81885070185508, 55.65137640122445, 46.79746512443789, 37.86376891597625, 38.509944100533765, 37.39913671247421, 43.14302421385243, 52.60167083432598, 57.102496470174486, 54.988115372196326, 48.009791297297326, 40.89438038487589, 40.7711983496143, 39.53724422762471, 40.97877802387361, 41.898201204115345, 45.15439602636522, 54.11889460779006, 64.45724648814048, 54.0416709838375, 49.355725165336366, 45.454112175972234, 41.139524598275464, 41.42077422911122, 41.32296992886452, 41.71269270681566, 42.679698159617764, 40.60273255071333, 41.69685809843002, 46.0447819002213, 49.461837045608036, 51.10690263009841, 54.194306096723004, 53.92682790756226, 51.96673716268232, 53.182715062172186, 51.977158900230165, 54.059141220585, 49.746824695217995, 45.407153560269265, 50.00801532499252, 50.37538451533164, 57.225870701574514, 54.51796439386184, 35.743516029850134, 43.54219205917851, 46.84867951177782, 45.357590490771884, 59.20812283792804, 60.308139785643554, 59.86375877934118, 56.65500110195529, 49.00246866287724, 44.83794312323294, 46.07598827731225, 52.347893484177135, 46.7799791982097, 42.54094823714226, 43.004756742908114, 47.97472138558665, 48.5017781103811, 50.74779787371236, 54.38292895593951, 53.70996006073491, 56.05514126439249, 53.74040157564225, 52.02674550394858, 50.61289187400572, 53.78311618681877, 54.494669437408454, 66.96446080361643, 64.47910193474063, 77.22960164470058, 18.08741973292443, 2.557505229788442, 1.3633929505463571, 1.206492872968797, 4.218014901684177, 66.37590915926042, 67.2793016126079, 61.5199835069718, 65.87883503206315, 63.31789208996681, 56.56417469824515, 56.053133010864265, 47.73557055381037, 45.8235719896132, 46.82285070419312, 55.53172842148812, 0.7808398972115209, 0.12039277041631362, 0.06430565785135954, 0.08202444416500869, 0.09358824260773198, 0.05376478980085062, 0.017738574364733313, 0.17252807205002155, 0.15382257981165764, 0.07671956108101914, 0.1550617423509398, 0.18086977363113435, 0.13739854337707644, 0.14616888647358264, 0.2852097538209731, 0.13698044323152112, 1.4255516086855244, 70.1690843028407, 68.59365647838962, 59.03752326965333, 53.280574275601296, 58.58113588825349, 48.923177949843875, 66.19586452361077, 71.1627697175549, 58.62905548464868, 80.40866697988203, 61.64838229456256, 79.10310606802665, 15.021434368625766, 2.4424883434849405, 1.3092981951852, 11.764113826136436, 10.433182043413963, 0.43879999448695495, 3.7141984653088356, 52.45225206498177, 58.210730783401004, 62.83826074292583, 63.69811880973078, 63.995960066395426, 62.508099156041304, 64.50629964951547, 58.1622895117729, 54.89815973466443, 51.90625813699538, 57.59854685875678, 54.625617765611224, 51.57233107474543, 48.69263672059583, 48.802502309122396, 45.12779451185658, 52.3980684434214, 55.86523971249981, 58.76556181138562, 60.69978452497914, 63.51462248832949, 62.008820656807195, 56.92169873945175, 60.003034299419774, 57.35388509688839, 58.825554463171194, 59.35194046266618, 60.16751889259585, 63.310506266932336, 54.53626617308586, 53.17465066909791, 53.371071200216974, 60.88800730243806, 57.658931747559585, 58.31519134583012, 57.51408253946612, 62.60352649996358, 57.37367345440773, 57.61052577726303, 55.41901126984627, 56.626630598498934, 48.474501948202814, 46.78725519487935, 43.45164022138042, 47.19152604379962, 43.36641103990617, 44.22451188487392, 44.25663609658518, 45.998584224331765, 51.8471440961284, 61.60379279044367, 58.96305707193191, 57.713127136230476, 48.93526277234478, 38.24884760764338, 38.23032225331953, 37.65533024264921, 44.75470258343605, 56.37566951013381, 60.248633507759344, 57.64342661826842, 48.95655732001028, 40.49918590053436, 40.87533727768929, 39.672660135453754, 42.083560651348485, 41.61256244105678, 46.55537643740254, 54.125252769839385, 65.84620875696983, 58.79361460285803, 52.804704481555575, 47.29156609504454, 44.13813737130935, 44.11173589767949, 42.20335375878119, 40.87991860605056, 45.02895078351421, 41.73392841892858, 43.25901262221798, 49.21712037055723, 53.05658732691119, 55.09129724194927, 58.14213637382754, 57.49590235371744, 56.94622532013924, 57.806475623961425, 53.92840077800136, 57.90464470463415, 52.25721613053353, 48.10994509727725, 53.81209073528167, 52.7111324187248, 58.58365404990412, 57.0586718282392, 35.78844678017401, 43.06984063117735, 47.80412181731194, 45.92032901702389, 61.70538217790666, 62.00870298570203, 60.90137866235549, 60.97938283797234, 51.33929914043796, 49.285236250969675, 48.001522940974084, 52.87043163853308, 48.9304147228118, 45.97054712234005, 43.43934359089021, 50.196983352784194, 49.03872313037996, 54.149893099261874, 58.08974135306574, 58.32868822159306, 56.93467786235195, 55.20392025670698, 52.46232078921411, 52.35052539456276, 54.69520453483828, 57.14098276630525, 67.06805844460764, 69.80183278360676, 77.46870933040496, 31.554361927893858, 2.529079813149668, 2.5087984627293003, 2.016903580196442, 5.696663145096072, 70.75505502762334, 74.2399004966982, 62.26672826274749, 67.49519671163252, 70.25252880588656, 64.03121432950421, 62.69973439555015, 54.27545993558822, 77.81614503552838, 55.30991838824365, 70.26826535501789, 2.8760355182232398, 0.47001835319303703, 0.1562868088724152, 0.23838967745823247, 0.21510250445815826, 0.1625661557960895, 0.1627016920716532], [0.05529692734501535, 0.07297098561520539, 0.10351035293311843, 0.04943539711436437, 0.017408409621566534, 0.03634148359959645, 0.07311231351547665, 0.1093278714125195, 0.09625281132156811, 0.14576077611455995, 29.512564289954405, 60.340067878846206, 43.17898842596239, 40.42197012132214, 38.99184649990451, 46.14016217570151, 42.98551359484273, 69.43625219406621, 53.550778512031805, 62.83503655464419, 52.92695691508632, 70.63161803830054, 31.49555971545558, 0.578572215332139, 0.29635188980929317, 3.676314498147657, 6.040137746641713, 0.33508664357566065, 0.5040758643900195, 31.909838491870513, 57.15220858973842, 56.69760588676699, 62.41594699121291, 58.243890500837765, 58.28975085289248, 52.434538641283595, 51.0600773749813, 45.03198277565741, 45.33260107040406, 45.64342929470924, 44.40508604049683, 43.98206233978272, 43.097877733169064, 41.071138074321134, 42.93424037195022, 46.42941736405896, 51.916060140056, 51.075751166189875, 57.678010156077725, 56.72471338702787, 56.89894507008215, 56.32052883025139, 56.704611239894746, 56.020349840964045, 54.86689059965072, 50.650409344703924, 57.39999255826397, 59.3152976805164, 52.36508915501257, 45.61103836182625, 44.732658863067634, 49.94585360250166, 49.4523056860893, 51.32511977226504, 53.32458719130486, 52.176317245729514, 51.94315195083619, 50.832505379953695, 48.36591505235242, 45.63261924251434, 40.617496352041925, 39.75461021546395, 39.94701816189674, 39.73693993783767, 38.73940275561425, 38.21482889113888, 39.45978133909164, 41.767574510266705, 49.26176871022871, 57.08748163715486, 57.83165724046769, 51.605945787122174, 47.207403798257154, 39.5507058020561, 33.667534935858946, 38.523209556456536, 41.28242438839328, 51.010428013340125, 54.86400765757407, 49.34546424496559, 44.09137095174482, 43.14625232450424, 39.48292724547848, 38.74179540141937, 39.02166828032463, 40.3673432719323, 43.42295985068045, 55.34862825947424, 60.75705505186512, 54.55177914711737, 50.08993794841152, 42.30693178792154, 39.51878947596396, 39.201869810781176, 39.04499069336922, 40.83668624201129, 39.83936086777718, 39.813269261390936, 37.10001284076322, 44.53745426670198, 49.31517178012479, 50.89729901283018, 52.401790772714925, 52.421292797211684, 49.4348079927506, 52.53051903940017, 48.807048336152114, 48.72745952298565, 48.70401551646572, 43.21485065644787, 45.26972155417166, 53.585718985526796, 55.184025995193, 54.735867746414684, 52.3397231871082, 47.25137749025899, 46.53111657788677, 54.69554578104327, 58.36600565141248, 53.548993833603404, 53.67666698271229, 46.9891905784607, 40.8172038293654, 39.51220381644465, 42.63079404830933, 43.575720479411466, 40.63663751848283, 44.562616271357385, 43.42451703163886, 41.16820496897544, 43.455719486359634, 45.38862428357525, 45.75149843769689, 50.78116155439808, 48.387892092427904, 50.13539037396831, 48.70141890741164, 50.59683369052026, 48.7177751910302, 56.68678798983174, 60.98639211347027, 61.83953508254021, 63.17545121715915, 0.5476722121238708, 0.9678963211274917, 3.230960008598143, 1.3935567126158745, 11.944028042977857, 65.28798880115633, 60.78191503401726, 46.5350232585784, 43.61782320084111, 64.30798853597334, 53.23203886708906, 48.847021210578184, 36.45714813663114, 37.784321308135986, 51.105490576836374, 41.95378903419741, 0.15824180396814502, 0.03379321852398496, 0.06214276947561772, 0.02289105957794574, 0.023932971713703968, 0.0346294762716899, 0.044062577353249636, 0.016357913470616745, 0.016092419954797915, 0.07392954546958208, 0.03262550900540045, 0.034138210898926186, 0.07879018948803987, 0.044423423917783846, 0.06254966941572006, 0.03451769255221852, 0.17037588592258193, 37.476144606067294, 72.19740467686808, 45.26170422953945, 41.633398071412124, 48.89525851895733, 52.94121080829252, 52.67665086253997, 75.52046806581559, 52.63447753844723, 68.99512675500685, 56.96578225781841, 76.18360750136837, 36.686787220739554, 1.2994502268491255, 0.3618199558508012, 4.150864414630398, 10.153618051159768, 0.470551764892955, 0.2689294048374699, 37.751326330246464, 59.872458596383375, 62.01945420234435, 63.54554645476803, 59.742914476702296, 59.7468525363553, 55.5501086481156, 54.45787760519213, 48.471932795739946, 50.14113664627076, 47.898078272419596, 45.74981574089297, 46.24718796822333, 44.77187864242062, 43.69888290282219, 44.98764038085938, 50.61361359011743, 52.96441555023194, 53.088225164721095, 59.47994701323971, 58.65418218797254, 59.294591488376746, 59.33561948037917, 59.038452871384166, 56.745831428035615, 56.80877370219077, 53.09424992530577, 57.265431727132494, 58.38393480547013, 55.81693572382773, 48.85241054719495, 46.55561570198306, 52.87150244559012, 53.637027509750865, 53.9144959757405, 55.61784013625115, 57.04006018177156, 55.213322178010024, 55.14618689014066, 50.27554058259534, 49.476993083953865, 43.542188136808335, 42.53539808334843, 43.059277688303304, 41.12480394301876, 40.903641100852724, 41.356384600362475, 42.11679881618869, 44.07998431113459, 51.884649799716094, 58.032200182637865, 58.818494196861025, 55.82207402875347, 46.667866091574396, 38.19630353681503, 34.79300022125244, 37.59105828500564, 40.30637787234399, 52.377844702812936, 56.2164605048395, 53.66176197605749, 45.101557777773955, 42.54975788054928, 40.03232186840427, 38.8990746005889, 38.9439582824707, 38.85952534214143, 44.99251196461339, 53.74664991132675, 62.78057052243141, 55.25982187640283, 50.747640978905466, 43.78533194142003, 41.9557737535046, 40.95970746009581, 42.075484491163685, 43.3890195815794, 41.185306502926736, 41.0825913952243, 41.39434922126032, 44.98803654024678, 52.169649216436575, 53.060466551011615, 54.25143149591262, 53.423215189287745, 52.24857122667375, 53.85850414153069, 52.495315767103634, 51.74992815140755, 50.54335217322073, 44.74261776093514, 48.71227995041878, 54.44924054607269, 56.058981264791186, 54.83580581603512, 54.813420849461714, 47.97275627813032, 48.13830775599326, 56.958266996568256, 61.67077510587631, 54.54349117894327, 55.43968216065438, 50.2028198396006, 45.13016362344065, 42.4705966057316, 43.95035389930972, 44.98923678551951, 43.73790656366656, 45.49481853362053, 46.24504243173907, 44.9861498801939, 43.812729697073664, 47.6674585957681, 48.3021177014997, 53.000336616270005, 52.82448107196439, 53.43050687543808, 53.65482330322266, 52.06484348543229, 52.68091447891728, 57.65637043983706, 66.25804193558233, 62.62176159889468, 69.55040885556129, 3.3142351142821775, 1.3841490303316426, 8.621485348670713, 1.5727805923069678, 15.527155360867901, 69.02767458269673, 67.96050748517438, 51.52800829179826, 49.048776165131606, 70.26982645834647, 57.671130318795484, 55.76030062090967, 49.60952212733608, 49.21881483447168, 56.487606110111365, 51.639333002028934, 0.3970369564429407, 0.05685758251216143, 0.022096228034746264, 0.029168491281809348, 0.06386862001231601, 0.03845506655653158, 0.03269526131090618, 0.12390709917752013, 0.24943376951400312, 0.16217203420256415, 0.14135394726068745, 0.0744960674895875, 0.1401228439663687, 0.17162295448924267, 0.18923085723673144, 0.3566036631743754, 0.2398068788311174, 45.77937472251154, 82.62959141885081, 55.08295828296293, 53.857562772689334, 55.90231395536854, 60.080532489284394, 53.462136868507635, 81.53022950695407, 63.49411241469845, 75.97373716292843, 61.81593025884321, 80.18120088884908, 41.7795338169221, 2.2122488915920258, 0.8654261776997197, 9.946398254363768, 14.187028561868976, 0.6239495642723576, 0.6673267495728309, 43.61650528446321, 61.17492868054298, 62.177882655974365, 66.58290047799387, 63.08985725525887, 63.1886068467171, 60.01909640527541, 56.52502159918509, 50.50336753168414, 52.989883499760786, 50.25278299085556, 48.72482761260002, 48.16681946477583, 47.82717358681464, 46.698299761741396, 48.14978461111746, 53.36741947358655, 55.89375926602272, 55.71943736845448, 62.86971422933764, 60.91606793865081, 60.351819299882465, 62.01024055480958, 60.19688567807598, 58.70832658583119, 58.05359671192785, 55.260818158426595, 60.791709192337535, 62.20885369085497, 59.513361684737674, 51.73076737311579, 50.105345018448375, 55.657299180184644, 55.85280972142374, 60.56481576734974, 59.501614186071585, 61.854714655107074, 57.70885959748299, 58.7779055103179, 53.48967582948747, 50.2603570876583, 46.11756147876863, 45.12235810679775, 45.045652235707934, 43.218247429017104, 43.55757951736451, 43.14155724740798, 44.59618783766224, 46.61848737347511, 55.65921721919891, 62.454056739807136, 64.81548047834828, 59.30982205175585, 49.198944107178725, 38.18826267796178, 35.43262112525202, 37.98712353552542, 39.77564588669808, 55.179126954847774, 59.76084363075995, 55.95418337852725, 45.04723295088738, 43.3118155694777, 39.943146782536665, 38.77669272884246, 39.253343074552475, 40.79922760686567, 44.08808008317025, 55.858610906908595, 66.2782342972294, 60.15062132189351, 54.19753028500465, 48.00248784403647, 45.4859108309592, 43.627068227337254, 44.70624562232725, 45.223468965099705, 43.42099866559429, 43.16430307203724, 42.461053479102354, 48.99176843704716, 55.06171864847983, 57.08170790826121, 59.16271355844314, 58.57523664351433, 54.93451618379163, 58.842487335205085, 56.258943696175855, 54.47098616630801, 53.16116556044548, 47.96762581794493, 50.10292883842222, 57.578829103900546, 58.76483617290374, 57.374504996884255, 51.1567912563201, 48.5247592772207, 49.60959665236935, 58.75415555892452, 62.63994962938371, 59.025865985501206, 58.79649754493468, 51.659674413742565, 46.254652238661244, 42.78307222550915, 47.25803767481158, 47.37002918797155, 45.98318892140543, 48.08061361312867, 50.07167539288921, 46.09234848330098, 46.449633259927076, 49.544814786603375, 50.4188169202497, 56.06958343136696, 53.963000005291356, 54.09660770047096, 54.83025173987112, 54.24000170923049, 55.8066120455342, 59.569588861157825, 70.34959177817069, 64.72871372776648, 77.47040379431941, 13.799442495069197, 1.5564534813165667, 10.634533974432177, 2.540974400697216, 17.736022433926983, 74.27651974462694, 73.88056432047199, 60.929541280192716, 57.04717143889397, 77.37778094507034, 63.26420660941832, 61.990067805013354, 51.45674667050762, 53.86144591915993, 68.31845514235958, 64.95141413904005, 1.1680031447641313, 0.27363367498882357, 0.1273812389662189, 0.14280159296768327, 0.14969794710557308, 0.1671936945809472, 0.16104845900929746], [0.050664941419757185, 0.09058476425707342, 0.07430977788904021, 0.04533964975346481, 0.07180298498320965, 0.06008106982335449, 0.09654616170953359, 0.07367083757755256, 0.10340037335070873, 0.3444448978670182, 14.246147505698668, 65.83684213699834, 37.20400664114183, 33.08693393584221, 30.210299030427013, 39.05386701706917, 32.72015113984385, 59.424045393543864, 65.8273970696234, 63.113524836878625, 55.371833001413655, 59.39998557490688, 54.674106105681396, 6.2466368079185495, 0.6126041698359674, 1.5317999138947458, 3.843573432776236, 0.06508708285588412, 0.2138290824669023, 19.9009766117219, 58.43936181837513, 60.21654459737963, 59.2191368533719, 54.93207254717427, 56.77340176797683, 46.59930698333248, 48.276269282064135, 44.08500494495515, 45.26129238067135, 45.18952869599865, 41.081724551416215, 42.398279866864605, 41.73549344462734, 41.543513036543324, 43.82217868681877, 46.02171444123792, 48.702058253749726, 49.017456039305664, 53.97810505282495, 53.36089657198999, 55.97800393258372, 54.449687696272335, 56.35444556513141, 55.416744139886674, 55.6412959098816, 54.993842032647905, 56.22045347767492, 56.688831544691524, 52.988173346365656, 46.19895850458453, 43.29565148199759, 49.188075219431234, 50.23623058872838, 49.80231054367558, 51.29727094404159, 51.92634067227764, 53.27989962793166, 51.786880800800944, 49.031235325721006, 48.391779161268666, 44.5547793757531, 40.57435812488679, 40.41095218350811, 37.57221129632766, 39.36032964337257, 38.737037566400346, 41.09636675926947, 45.79158506085796, 48.89738836596089, 54.39244854834772, 55.161888137940444, 52.842002299524125, 47.86950772808444, 39.28832277174919, 37.88153333048667, 39.87827470225673, 39.112800628908225, 44.37296967352591, 54.06870788143527, 51.74175785433862, 42.99588434157833, 44.68160921527494, 40.02790135722007, 36.846168810321444, 39.4046720381706, 39.47771441551947, 42.69127307399627, 52.06916201499201, 57.68862016739384, 60.377863837826645, 54.78813332896079, 41.89443180637975, 39.249561909706365, 39.19121273102299, 38.357642389112904, 40.98872907700078, 40.278152496584006, 39.87542313914145, 38.146481590886275, 38.91838050657703, 43.463226902869444, 46.988547309752434, 51.00983181307393, 49.7337043669916, 50.92703450110651, 51.218603887865626, 48.335104834648874, 51.33323515615156, 45.76480703969156, 44.78910176984726, 47.40854294069352, 51.19012748041461, 53.564306766756125, 56.74943608622397, 56.11429452896119, 51.91164747361214, 55.72346172025127, 53.14968086058094, 54.968381927859404, 54.93193134184807, 48.809899899267386, 45.836433441408225, 41.96039430556759, 43.84559915911767, 41.393411774789136, 43.689841839575, 49.968391541511785, 55.12977177096952, 53.9237763035682, 50.91482808513027, 44.84056718887822, 42.511200981755415, 43.802390329299435, 44.86688237036429, 49.895564894522394, 47.96362892273934, 47.39541084535661, 49.67427261414067, 52.910941877672755, 63.55927475037114, 60.60253327892673, 64.87126834930913, 46.4439065994755, 3.6935040402796964, 0.9253593197753354, 1.5056623422330426, 0.18040970718908697, 35.87226783075641, 64.56296613139492, 56.61481641953992, 54.95501841268232, 53.056010738495864, 60.48608595325101, 58.86751597927463, 46.381195745160504, 35.52967233042563, 29.616273718495524, 53.337962473592455, 33.38044097346644, 0.1823774499878768, 0.04373004156795721, 0.03331847766774797, 0.09528407781955697, 0.06496867630630732, 0.01727723621673161, 0.06595007324170682, 0.02298397072140248, 0.08553742461146847, 0.11966918505007222, 0.02583070173709383, 0.04590032652260796, 0.04877702115223773, 0.021720636192889466, 0.116022506939067, 0.07089743841319315, 0.4493218750482606, 16.500220875586233, 72.72994487516343, 43.695470440772276, 38.128277870916556, 46.2242107237539, 43.93804942407916, 35.888475064308416, 66.94612764543103, 69.39759331364786, 68.11868882948353, 60.58120342992968, 63.94032516787129, 60.53049895071215, 9.253772401040601, 0.6071464368893255, 1.897959665906045, 7.7920942921792316, 0.9809510109405365, 0.15560255446020635, 23.89819149048098, 60.55065601102768, 62.27922493411649, 64.31615883304228, 58.94791280069659, 60.33548262811477, 49.967124615946126, 49.36771192858296, 45.76773705021028, 47.777151600007095, 46.95954922706851, 44.57262223766696, 44.83779799553656, 43.364171366537775, 43.266437668954175, 46.50094962889149, 49.34637815721574, 49.06857628976145, 49.1118125761709, 53.63310906194872, 54.617521993575565, 58.59333838185957, 57.29453571381108, 58.72252556585497, 57.0687170182505, 57.59993930016795, 57.8013490861462, 57.66760803038075, 57.33746997771725, 54.584793736857755, 48.3047809908467, 45.9548419521701, 50.35289756713375, 53.36884721632927, 51.97629597879226, 54.94181963705248, 53.722943106005275, 56.95602732319986, 53.7324038628609, 52.358397591498594, 49.35516034403155, 45.98065899264428, 43.496453300599136, 42.74942613417103, 40.5120591194399, 42.1222391436177, 39.75821879602248, 43.982019193710826, 45.64001683265933, 52.61759173485541, 57.56832499657908, 56.063315483831595, 54.42698894008514, 49.78073358535767, 37.76209323636947, 37.451147340959125, 39.645434964087706, 38.67140062393681, 46.1256415613236, 57.16438362675329, 55.24167306961552, 44.140569240816184, 44.35564064210461, 41.41443960128292, 36.181429047738355, 39.24265853820309, 38.687960870804325, 40.92099366649505, 52.338907334112356, 59.10880058042465, 60.491592960972945, 57.11773487829394, 45.97302213791878, 41.234653842064645, 41.42897590514153, 41.27772146655668, 42.6618984437758, 43.040803324791696, 41.5948058712867, 39.84850783501902, 39.67848093278947, 45.162656537948116, 49.607337367150095, 54.27378508352465, 53.65148144383585, 54.415335578303186, 52.20773935317994, 50.69393588650612, 52.24448803932437, 46.93408519990983, 46.692275001156716, 49.00496329030683, 51.43722503416, 55.18387302275627, 57.56967821428853, 56.31091510095904, 52.15865481284357, 57.951579786116085, 56.634138015008745, 57.026818260069824, 57.099287971373535, 52.213383643857895, 46.11809884348224, 44.585507223683024, 44.073249601548724, 43.18268329866471, 43.764413941291075, 51.57806557993735, 58.586050618079405, 57.96457067612679, 54.04279278170679, 46.8218897235009, 44.46082684301561, 46.00674275429019, 48.414081758068455, 51.38004864415815, 51.959257202763716, 52.55255099265806, 51.29071666348366, 58.55306348493023, 64.06040460832658, 66.48856747534968, 66.99496899881672, 54.27234165130123, 8.126986257491573, 1.21447489626946, 1.5243320888088596, 0.7142199720105817, 45.68961128111809, 67.30138455667804, 62.66934779382522, 56.910563130532545, 54.98554229736329, 69.40913292669481, 61.66240476792859, 50.11928119967061, 44.948612797644834, 27.54744310532847, 61.63566597046391, 42.587793104110226, 0.30125748786714773, 0.10423221460153019, 0.024319491799800627, 0.07194402943094892, 0.0797576512840967, 0.09632094718155362, 0.046527082205659924, 0.15265193617632314, 0.2633341744301781, 0.2374722871689066, 0.12568633838166154, 0.2506498421632475, 0.07856918078276419, 0.2795781189155194, 0.22596766901833398, 0.19101241002640418, 0.5950231874181379, 21.174207387431977, 87.28684117717128, 52.177423354118105, 45.116568688423406, 42.921873138796904, 56.2955629441046, 44.88331317901612, 70.02643554441391, 77.16443538665771, 73.15650263140279, 66.21650403545749, 69.52034781056066, 66.64587805348059, 13.825052630516792, 1.2520139400036105, 4.97963720752347, 11.278366523404276, 1.203623291465544, 0.20627709496165478, 26.537972111855787, 63.511370843456646, 64.45822708068356, 67.50740312760877, 60.30616683344687, 63.766069950595984, 51.18979015657979, 53.85042798134589, 47.562750924018125, 48.48391563661637, 49.544026390198745, 46.496607565110736, 46.83127203295308, 47.62102165529805, 45.67049364889822, 49.94992894511069, 50.19863859299691, 52.36380261759604, 51.92844306269, 57.92436638186055, 57.34288284855505, 63.834068159903254, 59.12957737522741, 60.80946183973744, 60.12970724413472, 59.26850380436067, 59.9289446492349, 60.96328150841498, 61.81070566177369, 58.19098949432374, 51.07306826499201, 47.655244335051506, 53.157043149394376, 55.49946692682082, 54.04464414042812, 58.663070278783, 56.243736667017785, 62.03521820806689, 56.26479979484313, 54.08582118249709, 52.314859282585886, 49.617927766615345, 45.46421620153612, 44.6816994297889, 42.12216854095459, 43.06646739282916, 40.8086020715775, 45.219691722623764, 51.25160278812532, 54.88192112215104, 59.677897268725985, 60.570107044712195, 58.88114621562343, 53.63265406700873, 37.86997410558885, 37.958019548846835, 41.69150406314481, 38.52848122196813, 45.899693427547334, 59.613613543971894, 59.033698958735314, 45.41256250873689, 44.99113913505308, 41.407767649619814, 35.514214269576534, 39.85648201357934, 39.89118714486399, 42.29890269617881, 53.902921061361994, 62.57319481142106, 63.27511079849736, 60.21851362720613, 47.14600301557972, 45.417151681838504, 44.15076348089403, 45.04261632119456, 46.28881608286212, 44.87715505784558, 44.49482202529908, 44.09362239222373, 41.736768214933335, 46.73487194122807, 50.83238378647835, 58.34241651719617, 55.86329029452417, 58.629977241639175, 55.5208634561108, 53.62936712080433, 54.73084711259412, 49.26675404271772, 49.009897631983605, 52.07771278196766, 53.25763233246342, 56.46516623035554, 61.49710432175667, 60.75531744187879, 54.494438017568285, 60.76384075226323, 58.72663228742538, 59.346970819657855, 59.903174677202784, 54.90506702853788, 49.36354637145997, 46.38809519429361, 48.32643247419789, 44.79633462044501, 47.12032718043174, 56.30705548870949, 59.04606226951846, 60.16205110857564, 55.445926573968705, 49.88772407654793, 45.22959178493869, 50.360895279915106, 51.663043729720584, 55.038870842226096, 53.894911581470126, 56.44797055952011, 55.30491736627395, 62.653356290632686, 66.81476746836017, 71.73577308654785, 66.98751649548932, 62.32474796233639, 12.941249474402397, 1.686506528527506, 4.330235383202953, 0.6770723072751876, 51.327269231119466, 71.09254360198975, 68.29308525208505, 67.545057881263, 65.13141170624765, 72.96793076299852, 71.49553575823384, 58.80534641204342, 49.17187583061957, 43.053284306680005, 70.35371811159196, 58.960562444502315, 0.6463926309539426, 0.2817156574418468, 0.09871213741961027, 0.23428540736917527, 0.16276530801288544, 0.18509520818629574, 0.1412198359086629], [0.020237016912189223, 0.03287453354606706, 0.03291096868774584, 0.0919633701203331, 0.05562909923854375, 0.055448846410839796, 0.04171615346304832, 0.3143234851379549, 0.04637911232308515, 0.15537634401792483, 4.3457915033063585, 62.00828329209359, 44.59019445603894, 29.280330557977003, 19.7339738568952, 44.05372404283093, 40.146533443081765, 52.17577595864573, 65.72797283049553, 58.150290981415786, 59.27636423418599, 58.02989382897654, 59.279635490909705, 38.61669532714352, 0.08739669702105946, 2.467811655613684, 7.290224086853766, 0.47429738325938103, 0.13658498864500754, 9.558305221219218, 58.356262483904445, 57.32164713644213, 58.644580225790705, 53.07500677724039, 50.20776202601772, 49.078841132502404, 45.57611750018212, 42.3724942053518, 40.95874255703342, 41.80541361531904, 42.61010354565036, 42.67637198971164, 43.78442587391023, 41.47967253961871, 42.431976949014974, 43.51338617263302, 43.30351191182291, 45.87152688733993, 49.47017992696455, 48.9856142382468, 49.368955319927586, 50.400224885632916, 50.66012113325058, 53.31399679183961, 57.84397740517893, 55.63056822746031, 56.52970883154101, 56.18368517967963, 53.70996006073491, 47.846201004520545, 44.34716832253241, 48.47107379667221, 55.37437861965549, 49.47108599447435, 49.20428637535342, 51.47078875572451, 52.77857757383778, 51.27237173818773, 49.55026295877273, 47.86498915764594, 43.97474711941135, 41.847033885217485, 38.9620247194844, 40.128008088757916, 42.20171420804916, 42.62105480317147, 47.17808015884892, 49.29233574098157, 50.07442889675018, 52.98967561414165, 54.415213984827844, 55.16045255045737, 48.662375634716405, 43.8999592873358, 38.512999626898, 41.22583635391728, 39.1719852724383, 40.70265493085308, 53.54365156542871, 48.3292212793904, 40.82434646544918, 44.944509998444595, 45.76549345447172, 40.53137287016838, 36.71248659010857, 40.266212801779474, 41.02045712932464, 53.88764735191099, 57.85707027681413, 56.13398090485604, 57.237335789588194, 43.48698077663299, 38.224725031083636, 36.14589237397717, 36.87026785266015, 41.17619875938662, 40.646525813687234, 39.008096879528416, 41.07788847338769, 42.031408817537375, 43.50642788794733, 48.80359665040047, 49.56017086582799, 49.564728659968225, 49.23831685896843, 52.926615668881325, 51.75656087936894, 50.32961830016106, 43.13499512210969, 45.93644211369176, 47.62612073652206, 49.014106335178504, 53.69201521719656, 53.084836236892215, 53.259836704500266, 55.69254952092325, 55.46520894573581, 51.81153289733395, 53.06832305846676, 49.313720503161036, 43.18024358441753, 43.577999376481586, 41.56266597009475, 40.57951996403356, 39.53742465665264, 48.31502622173679, 56.119491669439505, 55.870558446453465, 58.57243999358147, 56.218919830937544, 55.45832126371322, 50.372430970591886, 44.89576670431322, 43.59504991962064, 44.33682503238801, 44.60480528493082, 45.514065604056086, 50.76795101165772, 56.48236582356115, 63.251902134187766, 63.889346122741706, 59.28438548118838, 39.468477233763664, 14.636934226559056, 0.2689831229227205, 0.25522118073797995, 2.16027797710511, 56.4125790134553, 57.14410497296242, 59.00039019123201, 52.03915196080362, 46.26086135064402, 58.66767121899513, 58.49345522542154, 46.18010367116621, 35.37999076227988, 43.34590881101547, 51.42208076292469, 31.02706397733381, 0.1824156930970569, 0.05409570147974357, 0.046749914200195385, 0.02300568739883602, 0.09932162931128856, 0.08904747860205751, 0.03166011947717878, 0.023946722991944804, 0.00889101343589925, 0.05469421916190655, 0.08235212295286118, 0.027217142764599096, 0.11960388371540655, 0.07048585767587347, 0.16258000666576047, 0.049143804898185116, 0.21533343400205338, 5.644872169340811, 71.08534213035338, 49.55945699445663, 31.290090276348977, 28.432306281981933, 50.575135138727006, 43.856785758849114, 57.013086042096546, 72.80691746742495, 63.89662211941135, 64.05607431165635, 63.330043592760646, 64.50476992514827, 41.56801216063961, 0.013228844580871445, 1.2326392699633877, 9.386112190062, 3.7936512212599482, 0.29897148150109476, 12.71510326093243, 60.89245527021347, 60.39770318615822, 59.657002802818056, 56.608874028728856, 53.790529466444454, 50.09486052297777, 49.009881942502915, 44.28300619125367, 43.565181070758456, 44.38285012398997, 44.553253573756066, 44.35302049882951, 44.37678613970357, 45.295636653900154, 45.56126740670974, 47.13039590466408, 46.00165936254686, 48.20036357448947, 50.92757578819029, 51.370415303014944, 52.25684350536716, 52.259753904035016, 52.43459747683618, 56.23797078286448, 59.158457786806174, 58.79250849446943, 58.97497715488557, 57.963543015141646, 53.77417318282589, 51.24245974325365, 44.62411119091896, 49.6976460179975, 56.11429845133136, 53.20420965071648, 52.683173764136534, 54.99440293158255, 56.15619720951204, 54.19933849765409, 52.08115270060878, 50.92739928153254, 46.59877746335922, 44.5563797027834, 42.78831643442954, 42.45704873915642, 45.420379792490316, 44.8036890645181, 47.63740931787799, 49.91448640823365, 51.404163375977554, 55.46848804719987, 56.662108436707534, 56.886189522281775, 51.88706597974224, 42.45068665473692, 38.16142974361297, 40.77130817597912, 39.10765840161232, 40.18048155692316, 57.041833093089444, 52.84564618141421, 41.53135761137932, 42.7413970424283, 44.899849891662605, 40.480523263254476, 37.988900369213475, 40.39549412265901, 40.72124304309968, 53.535889194857695, 61.3806373842301, 57.90098121089321, 57.81720722875288, 46.971465387652, 40.028313206088164, 39.145050356465006, 42.01631945948447, 42.152535530828665, 42.179439067840576, 41.901605821424916, 42.423575232105875, 43.93471148706252, 46.37832849256454, 51.64060384996476, 52.659514027257124, 50.31817282399824, 50.97898629403884, 55.1737533077117, 53.62274223758329, 51.59892866688391, 44.17374464773363, 47.19198496110978, 49.64752597193564, 50.92774837247787, 56.93768239790394, 55.870593747785016, 56.50987732794977, 55.96000809823313, 58.339721848887784, 53.068044570184526, 56.92651148765319, 50.30342078978016, 47.876258127151004, 45.38993827758297, 43.95305641235844, 43.36129234683129, 42.19301831337714, 52.21010454239384, 59.13435482209729, 59.73875284194947, 62.100153046269575, 58.28447134264054, 61.006647233040106, 53.76859557244086, 50.215704825616655, 45.16321351451259, 48.035000370394805, 47.055239369792325, 49.514612536276545, 53.15401900199152, 60.88968607687182, 63.41747322390157, 69.08785943062075, 59.95848009663244, 44.76090385067848, 17.894152787423906, 0.7408657357577355, 1.3554123981345085, 4.367411607696164, 62.707151597546, 61.47148732216128, 63.964710543232584, 56.68470128890007, 49.79187703901722, 67.81843139279273, 58.79297525651994, 59.01860960068242, 34.21330136637534, 33.50958501138995, 66.67707658583119, 35.89330742436071, 0.1527717523276806, 0.10355557510328871, 0.024155652405874386, 0.034007190711676114, 0.08623949056791683, 0.03691545582466549, 0.034446511492734, 0.06424559655809595, 0.15874002158882158, 0.20213805980259375, 0.20240684941170678, 0.11848459095363656, 0.278477679577566, 0.21415022652476065, 0.29209265545491253, 0.11060489401701959, 0.3708422039785693, 7.797612576715409, 83.42537756889098, 57.578130922009876, 41.69102553398379, 30.782490468794304, 60.498990551117934, 50.18973089033558, 65.02246002997121, 79.11805029838317, 69.08896553900935, 70.7321640752977, 69.72886100892099, 70.42600739386775, 50.18560063454413, 0.11969546952675428, 7.863956526402505, 18.572797352267852, 2.6606920025041028, 0.19451485676390512, 16.827778008676347, 63.556446721476895, 61.21339144245271, 63.82945153021044, 58.87073232281593, 57.523209894857104, 52.584082926473315, 50.6979759277836, 47.28026966894827, 44.61685088373, 46.57757705257785, 46.80596097823113, 46.667046316208385, 48.127085854930264, 46.344180337844364, 47.69167138684181, 47.83453587562808, 46.93788989897698, 49.96927407480056, 54.8093847305544, 53.65383094356906, 54.98094527952133, 55.612313516678356, 54.128374976496545, 56.72862791245984, 61.293894167869325, 59.327951246692294, 64.34615712012014, 61.39338116491995, 56.71624891219601, 53.59469336848105, 47.19200065059047, 53.75334539721089, 59.90823453472507, 56.136659883683734, 56.24964767886747, 58.33876479056574, 60.10336852842762, 56.583147202768636, 55.44563631857596, 54.22110765211044, 49.056785645023474, 47.49703161178097, 44.3397315086857, 46.08021266998784, 49.38482915201495, 49.84571156963226, 52.36110010454732, 56.12537130232781, 54.97243765861758, 58.6685537522839, 61.123439727290986, 63.78550529479981, 54.669171764004616, 44.273957283266135, 37.82825969880627, 40.861491310981016, 38.816108626704064, 40.20671436863561, 59.13503731450727, 56.47533693621236, 41.013730264479115, 44.4490401206478, 46.91337116302983, 40.494785001201016, 37.44750738143921, 41.438675926577666, 40.75969796026907, 54.794589550264426, 64.00778209009479, 59.86002468293714, 61.70986936938379, 48.946625878733975, 42.69332447359639, 40.73153926480202, 43.484921532292525, 45.071626170989006, 45.04155728124803, 43.31782856295186, 46.86012891031081, 48.046928298088815, 48.96801064091344, 54.02372614029915, 57.09127849148166, 54.61444685536047, 54.48490665804956, 60.165122324420565, 57.509818923088815, 54.81324434280396, 46.69065506227555, 48.467014143543864, 51.662067059547674, 52.191618411771714, 59.949654763744725, 57.97962865521831, 56.992140585376376, 59.42239407570132, 62.52968003672939, 55.09656890746086, 59.58525480762605, 52.668053027122255, 48.9839276190727, 48.419753505337624, 44.082816262399, 45.88001097402265, 45.81700594194474, 54.638647879323656, 61.07629283781975, 61.80659894020327, 64.23319285915744, 61.60761317899151, 63.38043820473456, 56.784251043873454, 51.41474593070246, 48.39190859948435, 51.17224147242885, 49.53565605225102, 52.417103705867646, 56.775280583289366, 61.46194811790221, 67.9675599067442, 72.86685912839829, 63.270074475196104, 52.178705969164454, 23.442090442103726, 0.9230893093251413, 2.481245283157595, 3.9785926909215994, 72.94658522452079, 65.01600773103776, 71.88796889397406, 60.906430675137436, 57.47756135079169, 70.53617108252742, 70.2851237020185, 60.05375839048817, 50.86417851909515, 61.929843733387614, 70.6569016364313, 48.34047848178495, 0.37730378789767144, 0.2543116811542742, 0.11733028797372697, 0.18449618871654236, 0.2032224266158958, 0.2068632901195557, 0.21184004242381743], [0.08103684957830176, 0.012449284042832593, 0.05492592628504481, 0.015757749657026462, 0.043900588061660535, 0.06529368910818331, 0.015258087003002725, 0.08485655630788497, 0.0036166627861319053, 0.13360167372851603, 0.27312563612095775, 47.05605914515834, 49.891230675481985, 44.89592359912011, 32.151025033766224, 40.05889592632171, 48.16563490898379, 48.714825568660615, 69.19750536641767, 56.60041739863735, 61.3314861636008, 57.796622630088564, 56.22297163932555, 60.176854133605964, 6.151088851113474, 2.988337879219363, 5.075622508602758, 1.8061071946736307, 0.07425520178531447, 4.777982763705715, 58.00564573657129, 59.26456182233749, 61.5439844900562, 53.06282781785535, 51.871509859638834, 44.76600685427266, 45.98286336468112, 43.90427781689552, 50.45407510572865, 48.408539449014974, 51.1362890274294, 47.470720352665076, 47.78013260133805, 42.840009350930494, 43.92356018866263, 41.27343431595833, 43.2510619778787, 42.13354341445431, 44.91749271269768, 41.860903386146795, 45.04279282785232, 45.90167422448435, 51.962595139780355, 52.40969827098232, 56.28345850975283, 55.717927255938136, 58.561610329535704, 54.39762215460501, 53.75830719547888, 45.691474406949936, 45.42479245893417, 44.64108720902474, 51.91977854697935, 51.982061862945564, 51.91724469584804, 51.352050765868164, 50.92645006795084, 50.907791353041134, 50.42784621638637, 45.476897224303215, 43.353600578923384, 39.936317936066665, 41.35362717413133, 40.50023709574054, 42.83907190445931, 45.40432553137503, 50.63957183591781, 48.41583113516531, 54.04703678623323, 52.37733871706071, 56.64985102991904, 51.212029995456824, 52.70826124375867, 42.17432429713588, 42.176497290211344, 41.82107171704693, 41.10004594249111, 42.08087775015062, 50.61706527586907, 44.20606105558334, 42.683902940442486, 42.98990272706555, 42.56181132408881, 42.41722099242672, 39.245804279081284, 39.95706335190804, 43.024152863410215, 55.80337216777187, 58.34807257498465, 55.623174559685495, 56.210306306039136, 49.520747123226045, 42.648334887719926, 38.59349842994444, 39.572949563303304, 37.411696141765965, 37.817873262589984, 39.65042421894689, 44.173230817241055, 43.852859466306626, 43.88888251396918, 45.345219335248395, 51.064031124115, 50.97759777499784, 50.472482788947325, 49.49003104240664, 51.187907418897076, 48.06230006679412, 42.38515561626804, 46.15496520073184, 47.548524487403135, 48.48941087722779, 53.276059627532966, 53.87095766682779, 57.84529924392701, 53.30426146907192, 57.37188877597932, 51.619097494309955, 52.80526538049021, 49.7117430163968, 44.76129608769571, 40.498974092545055, 41.34618251554428, 41.07609595021894, 40.4246961685919, 52.43146742543867, 56.50793967708465, 54.26592465369932, 55.540487074082904, 56.95132047899308, 56.76202689447711, 57.247196628201394, 55.73706450000886, 51.830560315039854, 47.05095221919399, 45.58492714358915, 45.73474599469093, 51.27818076841293, 59.979496156015706, 63.41488053721767, 64.28191261906778, 62.081098171972464, 26.11653304869129, 1.730674132704735, 0.29651779381017535, 0.9003558033897031, 11.318790470400165, 60.89526760962702, 55.126445601063395, 58.93426295249694, 59.99107107039421, 63.17996978759766, 61.9398771562884, 60.84545350843861, 38.61088237454815, 36.39335863051876, 38.808887543216834, 50.64162323551793, 24.041275631996896, 0.12155770669661223, 0.09238584462793605, 0.037364161182795806, 0.020883409343960307, 0.039566579695430495, 0.075230983296229, 0.0421904270056515, 0.05492478098359801, 0.03678591418710928, 0.05949982742388403, 0.01584636017439827, 0.08099301402727443, 0.019599702622320865, 0.0813024522616498, 0.0864809538207708, 0.08132834603349048, 0.1495575844760864, 1.223409932947928, 58.381149922647786, 56.78924814347298, 39.80924883196431, 31.815336827308904, 52.832514086077296, 50.33248163038685, 55.68455965288224, 72.92745190282022, 62.336307187234205, 65.2007435214135, 65.18563062913957, 59.13186411703787, 66.61358910222208, 6.254132457317845, 1.1589199160375905, 6.786016148905601, 7.33614670653497, 0.14209745091296014, 7.049691109888016, 63.02556176339427, 60.96698422585765, 63.839128017425544, 55.35659851566438, 54.575219231267134, 46.50091432755994, 48.278952183262, 47.223748314765196, 52.42770587244342, 50.952239651833814, 53.67139923957087, 51.276839317814, 51.731846024913175, 45.48790731737691, 46.45165720293599, 42.25398763533562, 45.25511857002012, 44.21892642974854, 46.313232837184785, 45.14353498335808, 46.62610853871992, 47.07342740028135, 51.77175221904632, 54.913970808829035, 57.88357765443864, 57.397717583564024, 60.61277458744665, 56.50404868587371, 56.89338707154798, 48.60062576109364, 49.17711611716978, 46.60898739291776, 53.35323226067328, 53.36959246666201, 54.036662117127456, 54.334966213472434, 55.283489458022586, 53.1683748768222, 51.521383408577215, 49.279905749905495, 47.7026814799155, 41.59684550377631, 44.3577391101468, 42.557202539136334, 44.68818703005391, 48.077024644420995, 51.93346761888074, 52.241765914424775, 55.57907927420832, 54.70240992884482, 56.77434705918836, 55.14043277309787, 55.59722023625528, 42.550801231015114, 40.55122398561047, 40.57141634725755, 39.80009009761196, 40.48663431598295, 54.25097650097263, 47.470669361852835, 42.06898512378816, 43.29507881595243, 41.81821230919131, 41.024905097100046, 40.13840629208473, 38.78008557904152, 42.59351191982147, 55.52488388553743, 58.77560307902675, 59.50787036649643, 58.187855520556056, 50.9556991823258, 43.18206356417748, 41.43686379155805, 39.92636296056932, 39.11325562384821, 39.03587510508876, 42.025650778124415, 44.38270107392342, 45.696804908014116, 46.72254393177648, 49.09557788602768, 51.49558990232406, 53.457696745472575, 53.47821074147379, 51.922657566685835, 51.782550504130704, 49.19733593540807, 43.72234259882281, 47.19314598268079, 48.61338915363435, 49.65051874037712, 56.23274618579496, 57.55026640430574, 60.27736486927156, 55.01032775448215, 59.42214696638046, 54.98154540215769, 53.48708706517374, 52.052660603677076, 47.24228151382939, 43.482548498338275, 43.40142211606426, 43.63554054690946, 43.82209239467498, 53.90965184857769, 60.74312279301306, 58.417290641415505, 59.39081115107383, 59.411246699671594, 62.05573612643827, 58.58860015869141, 59.33393678357525, 54.494406638606904, 49.126796030229144, 47.76582771731962, 48.05378460115003, 54.9875662403722, 64.2035593525056, 66.69274253229942, 65.65101985008486, 61.286014126193145, 32.876769419639345, 0.7724723784673599, 1.0580588636859771, 0.5091864062893776, 13.274366567211768, 65.03081075606808, 61.02541185194447, 65.69560935420375, 66.84275750190982, 66.44610389586418, 68.89218807220459, 63.515101017490515, 49.75958416538854, 39.58097081030569, 40.764079247751546, 62.75575368635116, 30.965065033205097, 0.06319212990121977, 0.02348893374625233, 0.0829995591794291, 0.06176888026417263, 0.06952975696373372, 0.019073798584060806, 0.016162921111249638, 0.12164050547946846, 0.08535391591008633, 0.11956230046287661, 0.1409294732636021, 0.1493110114167775, 0.12746973744323178, 0.17856542712017415, 0.22403755645838477, 0.21186261137406673, 0.45273758531097447, 2.3463010403417774, 75.5286422852547, 63.33015341912547, 60.422986784288966, 45.3647292044855, 55.822368206516394, 60.96441899576495, 61.64039634889173, 79.94656470514114, 69.42645411337577, 70.54097990835868, 69.91139242725988, 66.6710675147272, 71.46010891083749, 8.470366231856808, 5.52914705007307, 17.257269697804606, 7.0865496223972695, 0.26248905687562885, 10.416136403237621, 66.00554327810964, 64.66974873696604, 67.42888512149935, 58.943378540777395, 58.04291217557846, 50.72235345840455, 51.97552327186831, 50.24279663639684, 54.73256118835942, 54.67259207079488, 57.072353055400235, 52.84848205504879, 53.971931242173724, 47.480761620306204, 48.57739356256301, 44.98426322014102, 47.9499476955783, 46.43910561838458, 48.999558264209384, 46.72951006120252, 48.22132079832016, 49.55289486915835, 56.018941710072184, 56.301089563677394, 61.276247424464074, 59.6196069255952, 63.376990441353094, 57.85621127774639, 59.22922911182527, 51.13146058974728, 50.22360840151387, 48.17388757582634, 55.22297513100409, 58.6424974472292, 58.20537282574562, 57.69709640933622, 57.024535440629535, 57.44837891670966, 56.51873011742869, 51.17787399599629, 49.98649327985702, 43.30965826588292, 48.46693177377024, 43.73466668590423, 48.800078284355905, 51.21588568533621, 54.947114836785104, 54.29651521867322, 59.31414058131557, 58.70808732125067, 60.191849354774725, 57.53017210191297, 60.30926942825318, 44.21526685837777, 42.02140677359797, 40.508568209986535, 42.271344123348115, 42.32612002280451, 55.49580343307988, 49.48067618954567, 42.06339966866278, 42.66768786215013, 41.9494979612289, 42.0478396261892, 38.80992304894232, 40.70657730102539, 42.537527930352, 57.20641574551983, 63.42526697343396, 61.58966833545316, 64.13483942708662, 53.1879553487224, 47.97497633964785, 44.71856970940867, 41.666632313882154, 43.62252612267771, 41.159850320508404, 44.3293176158782, 48.361149372593054, 49.41237203536495, 49.21606917535105, 53.12679383062547, 54.05028058636574, 55.849267821158136, 57.11041965792256, 53.76199422344085, 54.7705924895502, 54.222292207902484, 45.64442165436284, 49.968407230992476, 50.629526645906516, 53.39910045746834, 57.69693166978898, 58.7061849717171, 63.792400821562744, 58.24783640523111, 62.561941531396684, 58.137154963708696, 56.491226457780414, 54.52374596749583, 50.3785224114695, 46.04683329982143, 46.4989923661755, 46.65739728558449, 46.96924532613447, 56.986990513340125, 61.516068981539824, 60.64852306919714, 61.29080334017354, 63.23948391022221, 62.558215279732984, 62.64511539090065, 62.85815108206965, 56.54792431862124, 51.625922418409786, 50.5930446809338, 51.88709735870362, 56.16617179686024, 65.60212358351677, 69.89730327360093, 68.99493848123859, 62.41592345699188, 45.714314368463334, 2.541224696943837, 0.9403907002941255, 2.4411495895155015, 16.781852937513783, 74.59937787825062, 65.98520186639601, 72.89856756887129, 70.41747231637278, 77.73443422009869, 73.63581626645981, 74.53097174244543, 51.93227914071853, 49.31645439517114, 52.58556558239845, 70.15466567008727, 42.26247172201834, 0.23628989174481363, 0.21740974678147226, 0.17120986455871215, 0.18505262901946423, 0.15384769217381555, 0.16558423578258485, 0.17367636123972555], [0.036964156034012, 0.06508768040446505, 0.05175568591502886, 0.03881364933124954, 0.024030864343888337, 0.013299303602487331, 0.023149849824427117, 0.02809139464290873, 0.094824087986302, 0.09352488713639398, 0.2114244090813783, 33.3141254609631, 58.486034101055516, 38.69356986015074, 25.239469505125477, 33.156638376174435, 52.994558965006185, 44.18447625252509, 64.3100046342419, 59.75643880905644, 64.22115118272843, 58.29685426527455, 56.28383897965955, 53.45136211764429, 21.88496831924685, 0.6725378634948885, 5.875207474154811, 7.214616969708474, 0.09312495093552337, 4.23261151198418, 42.69889031687091, 57.7328174344955, 58.30216123211769, 57.04338635167768, 53.000615104552246, 50.80326803268925, 55.43023317090927, 55.78341907070529, 59.43804433268886, 57.12615228468373, 60.92324979843632, 56.49618825604839, 58.38722175167453, 53.30288863951161, 51.07072660999914, 46.499980803458925, 42.494609355926514, 40.849622218839585, 42.16541267210438, 43.24303680850614, 44.472225250736365, 45.62064816874843, 48.937121975806456, 52.53053472888086, 56.94124783239057, 58.777219095537745, 55.3518916714576, 58.181387532141905, 52.68317768650671, 47.770412968051055, 46.10010300913165, 43.87582494366554, 50.210033078347486, 52.91631552480882, 54.8667101706228, 52.9802893823193, 51.9416339935795, 52.72334667944139, 49.831077206519346, 46.960494518280036, 43.440924306069654, 42.530844211578376, 40.36718245475523, 42.639744897042554, 42.76042053776403, 48.31313171694356, 50.231625726146085, 49.62711003518874, 52.810180110316125, 53.49984261297411, 52.9628622916437, 54.71082341286444, 54.67775390994165, 43.332972834187174, 40.500433214249156, 41.731971156212595, 39.684799871137066, 41.554989891667525, 49.688522584976695, 45.77334996192686, 41.94328492687595, 42.229661095526914, 40.0703453248547, 45.545872103783395, 42.0996541361655, 41.45851135253906, 44.053727965201105, 54.75641704374745, 54.70565372897733, 51.66194546607233, 52.508636136208814, 50.14617296957201, 48.007351583050145, 40.755861882240545, 41.04190072705669, 37.52888087303408, 38.17403231897662, 39.389994528985795, 41.75008466166835, 40.917169355577045, 48.95788308112852, 48.93560401854977, 49.72460446819183, 49.62834558179302, 52.374263578845614, 52.53355495391354, 51.51829258088143, 45.857065108514604, 40.9025114582431, 48.20853779392858, 46.89552830111596, 48.87424638194423, 52.2159057278787, 55.48569548514582, 54.796891981555575, 55.71937068816155, 55.7616695280998, 55.24958056788291, 53.71487871293099, 50.09327196305799, 46.43923505660027, 43.99754001248268, 42.4410415464832, 40.85221098315331, 43.13188468256305, 48.57049019105973, 56.44942575885404, 58.017565819524954, 56.7468394771699, 57.70079912677888, 57.85743897961032, 56.715805684366536, 58.254465210822325, 59.071867542882124, 53.798358517308394, 46.339563708151545, 44.68992856241042, 52.16286351603847, 60.94461494876493, 62.70316254708075, 58.4637079700347, 50.876145670490885, 15.09960916734511, 0.48844855939668996, 0.9467767479438937, 0.4895901529779358, 36.5677236741589, 63.46236082815356, 54.17544734093451, 58.88960284571494, 58.1242189868804, 57.85687023593534, 64.64496327984718, 50.69053126919655, 37.524954580491595, 47.18763897495885, 52.23753367700885, 52.37664445754021, 14.562995587625812, 0.2440600764126547, 0.33972628654972203, 0.05109704182212872, 0.03353922973356901, 0.04587218811314914, 0.041419983871521494, 0.03439886465428337, 0.013833512991456496, 0.028020908808215495, 0.01858909666958836, 0.02603479330578158, 0.03170357198424397, 0.02909183077844641, 0.04335499173330684, 0.02053149919506283, 0.20748176822258582, 0.1057478123074097, 0.19705734936700714, 43.080278058205884, 65.07772230332898, 41.479178320977, 37.37702631181286, 42.58567894658735, 54.690921306610115, 49.271402051371915, 70.43702140931161, 65.38094112949987, 69.34663388036913, 65.96094592925041, 62.2992290219953, 61.635210975523925, 25.860702337757235, 0.4542612422618174, 1.6921531481127587, 12.595897528433031, 0.09743671593887192, 5.179561886095232, 50.40553185247606, 59.83780053354079, 62.20541769458402, 60.06923606318813, 58.66033246440273, 53.63808654969739, 58.74118428076468, 56.09027393402592, 61.531985959699085, 58.93067790615944, 62.04513003749233, 57.63238906860352, 60.11425702802597, 55.91282198506018, 53.53189229965211, 46.40335321426392, 44.66406837586434, 42.71077509849302, 44.47380988828598, 44.58042775430987, 47.087006645817915, 47.87925874033282, 51.24400515710154, 54.463686635417325, 57.792680648065385, 59.40973658715526, 56.969732084581935, 58.49930740171864, 54.34005352758593, 49.707887326517415, 46.82312134773501, 44.97004855063654, 51.428627198742284, 54.628771351229766, 55.971837966672844, 55.41457899155156, 55.243893131133056, 55.76350519734045, 53.02354920294977, 48.07715016026651, 45.91932881262995, 45.03688966074298, 41.66634990322975, 44.47717528189383, 44.28464966435587, 51.01209894303353, 54.69196073470577, 51.129824961385424, 54.390836454206905, 57.518550119092396, 56.22678810550321, 57.97767139250233, 54.957505195371574, 43.83425958694951, 41.72388322891728, 41.08899662571569, 40.05040791726882, 41.882954951255556, 53.10980604540918, 48.29592035662744, 42.511573606921786, 41.949278308499245, 41.35571387506301, 46.61176443099976, 44.17304254347279, 40.726871644296956, 45.22218635005336, 55.41845821565198, 56.524507768692516, 53.880685144855136, 55.388648202342374, 51.86113911290323, 50.30228330243019, 42.961202744514715, 42.41267888776718, 39.54640688434724, 39.8464564354189, 39.81497549241589, 42.621737295581454, 43.51174662190099, 50.39718504874937, 52.31562806713966, 52.873110617360766, 52.55539078866282, 54.903505925209295, 53.17378774765999, 53.14079669214065, 48.71415092099098, 43.17550928361955, 49.54732118114349, 48.84437361071187, 49.72982122052101, 53.18627265191848, 57.96461774456886, 56.55343132634317, 57.93620801741078, 56.11484366078531, 57.00887733890165, 56.01647061686362, 53.11075918136105, 50.22702870830413, 44.323328156625074, 43.643628474204775, 42.117147907134026, 44.717577349755075, 52.40862746392527, 58.25213532293997, 60.53584514125701, 57.65945734516267, 58.423331091480875, 61.07675959987026, 58.80243601337556, 60.617544189576186, 62.88312089058661, 58.182368124684984, 49.66827923251737, 45.87874797082717, 57.003621362870746, 63.055544360991455, 65.74598435432681, 56.06791250167355, 50.418444295083326, 17.265967553661717, 0.6897747805041652, 1.6943116774482114, 0.42590226076783677, 37.87958391251103, 67.92190351793843, 60.62973099370157, 65.19925302074802, 65.50125591216549, 64.77518989193824, 70.870772792447, 56.51543140411378, 49.495694944935465, 49.46843447223787, 57.876242822216405, 60.806665189804576, 19.64890157022784, 0.537992783131138, 0.3321421693169302, 0.14531563306527753, 0.053178590812510064, 0.007936390315843447, 0.05975724062732151, 0.07829984725122491, 0.14137584205356338, 0.16255225896114306, 0.14859209918687422, 0.0997290501911794, 0.10910282542388286, 0.13190984515653503, 0.1596401289345757, 0.15230581765213322, 0.3935099182830703, 0.22846712280184994, 0.2579300369947188, 52.89203997581236, 74.69948460978847, 53.44807124906971, 36.6075082748167, 47.71355429003316, 63.27828007359659, 55.34619246759723, 75.07447104300223, 73.39941501617432, 75.68530959467735, 71.13179868267429, 68.17817549551687, 68.3472296499437, 28.389589709620324, 1.313235519393798, 17.033227835932088, 18.583162215448198, 0.2019268493618696, 7.595668367801174, 55.09368204301404, 60.03737072790823, 65.2736682276572, 63.35717070487238, 60.116861481820386, 56.087987192215465, 61.798679674825365, 57.82029021170832, 64.36442359801262, 61.10007809054468, 66.38897849667457, 60.00330494296167, 63.5401100497092, 58.69694386759112, 57.45246994879938, 51.07335459801459, 47.823239449531805, 45.499482231755415, 47.29883424697384, 45.7444695503481, 48.96424516554802, 49.5516554001839, 54.024130144426906, 56.132647298997455, 61.52634166902112, 61.82891722648375, 60.611860675196496, 61.651492734109205, 56.67915897984659, 52.97682592945715, 50.631829077197665, 47.90848039811658, 56.01304246533302, 57.364020501413655, 60.264173938382065, 61.16743695351386, 57.56655600763137, 59.65418261866416, 56.96067925422423, 50.95385174597464, 49.81927871704102, 46.410307576579434, 43.729967686437796, 48.36360085395075, 47.49427026317966, 55.0195021783152, 56.784341258387414, 53.569425459830995, 57.33247287811772, 59.352422914197376, 60.22316163586032, 60.42101775446246, 58.82356582149383, 45.50352619540307, 41.593519333870184, 41.11968917231406, 39.738073502817464, 39.5360832060537, 53.4924332557186, 50.73198287717758, 42.00505441234958, 42.52968711237754, 40.54615628334784, 49.25513205989715, 44.26760304358698, 40.74100394402781, 45.20345311011038, 58.85960848100724, 58.497444275886785, 56.793131289943574, 57.536953879940896, 56.13737767742526, 53.39774331738872, 44.72750879103138, 45.0361640222611, 42.10792249248874, 43.64684481774607, 43.67294426887266, 45.164460828227384, 45.553359908442346, 53.74566931878367, 54.87897149978146, 56.27884972480036, 54.39715147018433, 59.241341390917384, 56.89339491628832, 55.89738353606194, 50.08643919421781, 45.429722878240774, 54.0859898444145, 51.622360906293316, 52.779695449336884, 55.645496768336145, 61.52213296582622, 59.70911149055728, 60.31612180894422, 59.359255683037546, 59.343887836702415, 59.43540457756289, 55.078757424508375, 51.36768141100484, 46.70528550301829, 47.39985096839167, 44.246892929077156, 48.657562886514974, 54.92225877700314, 61.75111701411586, 62.89847696981123, 58.67332335441344, 60.78710825212541, 63.62901841440509, 61.723962445412916, 62.315212680447495, 63.612552304421705, 58.378012026509936, 51.88135893114152, 49.826746909849106, 60.5195673050419, 66.174267953442, 68.07574672083702, 60.219537365821104, 54.42298812250937, 20.814910434907485, 0.6124716059815499, 5.366874673674184, 1.0743762913250154, 46.85610063614384, 76.58351667465703, 64.65087821406703, 70.25813779523297, 69.8926591873169, 71.10536190771288, 74.81891293679514, 62.78715618195073, 49.99387518052132, 57.669981064335, 61.7685950956037, 72.4655379018476, 28.166161698679772, 0.7015116765133796, 0.38407995816200013, 0.27204300066636455, 0.18517416120777208, 0.15898095624100778, 0.1332166992248066, 0.20099252852941715], [0.04896901427738128, 0.060660174837516206, 0.07006578868435276, 0.05369323718872282, 0.01289038502070452, 0.047191000813918735, 0.07069027291670923, 0.03768997454655267, 0.06436312210655983, 0.1525378350408808, 0.1701140217483044, 13.376152073183368, 58.972776705218905, 43.42834526492704, 35.611728314430486, 31.77582875374825, 53.4419523516009, 51.22100437841108, 60.04035565160937, 57.50203694066694, 60.853702252910985, 55.31224043138566, 55.021545733174975, 57.65707254409791, 32.39943462033426, 0.07299036763968968, 1.8559201926954332, 12.230648379172049, 0.16962530361788888, 3.008243907843867, 30.021464363221202, 60.1636867369375, 59.06833348735687, 58.110612284752634, 57.1177113440729, 57.19136561116865, 58.55678189185358, 61.2595538170107, 59.649530687639796, 58.21879909884546, 56.17132579126666, 58.37965942198231, 58.18784767581571, 57.54078995796942, 55.04738630787019, 50.9456108462426, 44.60369917654222, 43.202667774692664, 41.17732840199625, 43.469412480631185, 45.4295777505444, 48.01514925495271, 50.81573724746705, 53.22795567973968, 56.82328647182834, 54.845690188869355, 57.24987560702909, 54.32329323983962, 51.71627421532908, 46.86287456943143, 47.94007116748441, 43.36275146853539, 46.342038723730276, 52.202808933873335, 54.361673631975734, 52.01125214176794, 51.48471316983623, 49.538056542796475, 47.92777845936437, 43.55859541123913, 41.75280286419777, 39.972886193183164, 39.38162419103807, 43.3629632765247, 44.35165943637971, 48.28857375729469, 53.54924094292426, 50.34369960907967, 53.87849646229898, 53.0778818745767, 54.289109783787886, 57.27436688638503, 55.926715020210516, 47.88311443021221, 40.7704766335026, 40.88238185451877, 43.01581390442387, 42.88178651563583, 49.08289294089041, 43.49426461804298, 43.30674002247472, 43.583243585401966, 40.56564654073408, 42.59981909105855, 44.68622976733793, 44.54147861849877, 45.525848404053725, 55.69310649748772, 54.8151937607796, 53.503082490736446, 51.47904926730741, 53.0055376791185, 48.3235966005633, 47.87818008853544, 42.04117159689627, 41.117951562327725, 40.19044829953102, 39.81766231598393, 38.987810380997196, 38.66156724191482, 44.649618364149525, 49.26891526868267, 49.94577123272804, 50.854949182079686, 50.52322649186658, 47.9628836724066, 51.41073334601618, 43.99492771394792, 42.8278382362858, 49.08616027524395, 44.341708383252545, 48.669110344302275, 50.05534656586186, 51.926379895979366, 54.5751956970461, 57.63111822066769, 54.691352767329064, 52.336436240903794, 54.976258047165416, 54.83182853268039, 49.80767634607131, 48.4124892757785, 42.78772023416335, 39.74501609802246, 42.41347512891216, 47.35144892046529, 53.89308767934, 55.97447379942864, 55.434763508458296, 54.17132885225358, 54.52345963447325, 56.247102060625636, 56.94387189803585, 62.37568778376426, 59.42650864201208, 56.78934228035712, 43.82712087323589, 48.97282731148505, 59.51476589325936, 63.176169010900686, 60.077139639085345, 47.03279949003651, 0.7531649403033719, 0.05824364624136399, 1.8599368223259527, 1.3729686818776594, 55.09282696631647, 50.47016859054566, 57.06639105273832, 57.96644556906916, 59.203545431936945, 54.49742294126942, 61.07643796551613, 43.501215057988325, 35.44230545720747, 56.81575552109749, 40.139810500606416, 53.70488451373193, 7.325476879073728, 0.5186655492551866, 0.17493125922497244, 0.0981812921142386, 0.033389754488223025, 0.04577058570219144, 0.04477528427096625, 0.03982729473782163, 0.02483931118472209, 0.07492298530715127, 0.03168515331532446, 0.029460861077231747, 0.010737855111308878, 0.033837532879964966, 0.11944688165620451, 0.021193561955325065, 0.09777942537179879, 0.062146783776340954, 0.18326122433908526, 18.338749524085753, 73.85133481794789, 43.86745852808799, 29.937600166566913, 44.92565516502627, 59.66789522478658, 58.483586542068, 68.26300851760372, 61.87618178706016, 65.7549822715021, 61.878511674942516, 61.845618678677475, 63.57996917540028, 37.25923361316804, 0.24337658808837015, 1.2568400487784417, 14.938610580659683, 0.3109903897969954, 3.254109592207017, 36.047146704889116, 62.953786311611054, 63.62243275488577, 60.69414023430117, 59.62554931640626, 59.58537247873122, 61.321209553749334, 63.585217306690836, 63.21248231395599, 61.86894501409223, 59.6682600052126, 59.95955090368948, 62.7134705358936, 60.36187625700428, 57.45999697716006, 51.902602487994784, 48.59045505523682, 46.05385434242987, 44.97853263731926, 43.4437523349639, 46.581381751645, 48.905566507770175, 53.336197407014915, 57.12843118175384, 58.484567134611076, 58.2435021861907, 60.69518358476701, 56.671380919794885, 53.426584505265765, 49.32997480515511, 50.25765849697975, 44.695506172795454, 49.459036473305, 53.872252048984656, 54.537992015961684, 54.614223280260646, 54.70656371885731, 53.72137808030652, 50.139206840145974, 46.82012857929353, 44.170022318440104, 42.46781564527943, 43.50178380166331, 44.6024126391257, 46.254361983268495, 50.166730111645116, 56.921706584192094, 53.694721652615456, 56.433822570308564, 54.81524867396201, 59.739902096409956, 59.48996474665981, 57.649498447295166, 49.89571786695912, 41.1453571627217, 40.62746701701995, 41.44568127970542, 42.98534493292532, 50.603737062023534, 45.34506636281168, 42.99301708898237, 43.38780364682598, 40.07329102485411, 42.78809285932972, 42.76355451153171, 42.90684653866676, 44.43464109974523, 58.13309531058035, 56.586496906895796, 56.23796293812414, 56.64250835295647, 54.620538296238074, 52.46861619334067, 50.63923451208299, 44.03974863790697, 42.69443058198498, 42.61281390343943, 42.1426119342927, 41.02843130788496, 41.39408642245878, 47.07218008656656, 51.95969258585284, 51.44032762896631, 54.15654936144429, 52.62302813991424, 51.360232830047615, 53.00018756620346, 46.89113916889314, 44.147413776766875, 50.707617113667155, 46.42971546419206, 48.92267980883199, 53.25594179091915, 54.46342383661578, 56.472669724495184, 57.52469647315241, 56.551646647914765, 56.014234865865404, 56.759877435622684, 55.78945559840049, 51.50131656277565, 50.551318507040705, 45.112438432631954, 41.28444440903203, 43.608362443985484, 48.57629529891476, 55.606269144242816, 57.94400961168351, 58.58238320196829, 59.548055048911806, 57.25910494404455, 59.32264427984915, 61.48589811017437, 64.76580366011589, 62.83712325557586, 60.16861323387393, 46.564539094125074, 51.89743672647784, 62.53206876016433, 65.90844108212379, 62.57080216561595, 50.334062345566295, 1.0596036646635303, 0.28172978410317057, 1.6059139563191323, 1.925968821010282, 64.97154766513457, 59.69728162211757, 62.063463195677734, 65.659217603745, 62.77028999020977, 59.68072529762023, 65.8956463106217, 48.65933187546269, 43.847313234882975, 51.622910038117446, 45.183374497198294, 63.640024585108605, 10.762207123541064, 0.559888556599617, 0.19521893753159433, 0.11017212328771431, 0.09667222913835319, 0.09900604705176047, 0.026616453223170775, 0.03919209676584409, 0.14012906460031388, 0.11798218283201418, 0.1297893903909191, 0.15721627270742772, 0.1336329914028606, 0.1930157452701561, 0.14031580619273648, 0.201101282371148, 0.20026022508259744, 0.3331576341823224, 0.4686915501952172, 23.338543791924756, 82.87322551973405, 56.65902153138192, 46.60097791302589, 47.108509079102554, 69.94900795721239, 62.922246533055464, 71.84411679544758, 66.5597741834579, 73.5714501719321, 67.76848393101847, 66.67351507371473, 70.58915445881506, 42.63626183232954, 0.2178227907467273, 8.18292563000033, 22.313548057310044, 0.51302423099837, 4.815459049517109, 43.21247762249362, 62.05243741312335, 68.7491863004623, 61.76873237855973, 63.911597728729255, 61.05339404075377, 63.667763586967226, 65.55388235276746, 67.6521699659286, 62.93721429763302, 61.899072739385794, 62.64165978277884, 64.99802758616786, 62.85572313493299, 61.12900949293568, 55.271620365881155, 50.56511348293674, 47.68296372505927, 46.593972559898134, 46.77370732830417, 49.93099174191875, 51.61689312227311, 54.75720151778191, 58.045677446549945, 60.320475639835486, 60.366704694686405, 64.06392689674132, 58.355634904676876, 55.84209380611297, 50.588934036993216, 53.25592217906829, 46.88728740138393, 51.74152251212828, 55.351468055478996, 59.22458502554125, 57.14725855858096, 58.569470759361025, 55.525617368759654, 53.901065780270486, 47.03101088923793, 45.92689114232218, 44.00221940009825, 45.24587354352398, 47.83364157522879, 49.04094319189749, 52.54298433180779, 60.59941891700991, 56.7161508529417, 60.995095852882635, 58.225977036260794, 62.02660468316848, 60.58548665815785, 60.44148468202161, 51.959900471471975, 42.47953568735431, 41.596100253443566, 42.28698261322514, 42.82685764374272, 52.64775476148052, 47.666313263677786, 42.763597657603604, 44.744998639629735, 39.49443547956405, 43.542772569964015, 44.38519177898284, 42.769139966657086, 46.766011638026086, 62.32026861559961, 60.04314837917205, 58.60008878092612, 59.08020650186847, 58.92153486128777, 55.28212839557279, 54.28373613665181, 47.800862327698745, 45.199114968699796, 45.991021894639545, 46.23010996849307, 43.909070953246086, 43.56158817968061, 48.99923270748508, 55.348047748688735, 55.141189790541134, 57.28111336308142, 55.80861637669226, 53.51486529073408, 57.41143018968644, 47.58282169218987, 46.499588566441695, 53.541204006441184, 47.65934713425175, 52.03482558650356, 53.924937325139204, 54.987311286311, 57.78220007496496, 60.51978303540138, 58.86519393613262, 59.028258631306315, 59.63060525155837, 58.84461718220865, 53.68354681999453, 54.03645423150832, 46.771000892885276, 44.30400263878607, 47.40825660767094, 51.65517545515492, 57.10061765486195, 60.878444563957956, 60.576559343645656, 60.64624024975685, 58.68236049529045, 61.69064583316926, 63.39207195466565, 68.76615447382774, 61.689021971917924, 63.124648678687315, 49.599155302970644, 55.13346272130167, 64.75661746917233, 69.09604933954054, 61.62347524396835, 54.87622584066084, 1.3312850411861175, 0.13802269053074623, 7.750925585146874, 2.2570144120723974, 66.91944768351894, 62.2577303455722, 68.64798915001654, 68.77209294226863, 70.84434386222594, 65.9022751162129, 73.7843172011837, 54.553285337263546, 50.23523822907479, 61.339483876382154, 51.42818397091281, 75.66620765193817, 14.775097754693801, 0.6700769439339639, 0.3481603323692276, 0.15094792680634608, 0.17400315902646513, 0.2137540977808737, 0.2669972698054006, 0.1479238866557998], [0.017945420019508853, 0.06587963911794847, 0.019292800138974865, 0.01857817417100793, 0.040203953357112986, 0.041255447337584156, 0.06540215183650294, 0.08694455958902837, 0.047712024872101126, 0.030970111744658604, 0.09557634802354921, 3.1690958959441033, 53.94891869637274, 48.18859646397252, 45.76577194275395, 19.22254385486726, 50.21026057581748, 46.70583855721259, 56.76828307490195, 61.39009421871555, 63.44082309353737, 59.706405055138376, 58.22668306289181, 50.280098376735566, 57.8112962169032, 2.028819740779938, 0.540385245075149, 12.503370777253183, 0.24450137370055725, 2.331814011258464, 18.856416094687678, 58.220928945849025, 59.34892416000367, 60.0655843365577, 58.72793059195242, 60.93313024890039, 60.72689986998036, 59.4505919948701, 55.04266377418272, 56.47499961237754, 52.083753232033025, 54.613513331259455, 53.52218835584579, 52.720416668922674, 55.50580155464911, 54.65980122166296, 46.06194619209536, 42.49049871198593, 41.19215888361777, 44.7991979506708, 46.27633117860364, 51.77990290426439, 54.464879035949714, 55.69134927565052, 55.81741817535893, 58.063720349342596, 56.062797730968846, 58.009807371324115, 54.77613872097385, 46.485468033821356, 46.88181961736372, 45.554324811504735, 43.719039963137725, 51.96713332206973, 50.89674988100606, 52.912742245581846, 50.96470494424143, 51.016201742233775, 48.64928276308122, 42.228033311905406, 41.616316149311686, 39.78453789987872, 40.81960039754068, 48.363522406547304, 50.31858075049616, 52.46457615206319, 52.84641496596798, 52.849827428017896, 53.31638551527455, 51.466156436551, 57.29677538717947, 56.383310287229484, 57.06907395393618, 48.90751984811599, 43.32578705203149, 42.446572088426166, 43.98991100249752, 41.6134802756771, 44.72646151819537, 44.43117764688308, 41.813532921575735, 43.3473640103494, 42.365382948229396, 43.39780176839521, 42.99558231907506, 43.742699700017134, 45.72554803663685, 57.225972683199, 57.090839186022365, 55.53518402960993, 51.00292844157065, 51.805974898799775, 51.58638884944301, 50.966732809620524, 47.613490704567205, 43.17451692396595, 41.89721276683193, 39.7213210598115, 38.04446466507451, 36.87186425732028, 40.95620478353193, 47.53701233094739, 49.61808073905207, 49.422028910729196, 50.47747988854685, 48.65291487786078, 47.53900097262475, 41.95566784950995, 45.045063880182084, 45.494171342542096, 45.074995486967026, 51.20922157841345, 53.105824839684274, 55.618055866610625, 54.02955870474539, 50.1158961942119, 50.20822878806822, 49.405343148016165, 45.08165567151962, 52.056994822717485, 52.050518989562995, 51.43472648436024, 45.581369553842855, 44.06902128650297, 40.09350692072223, 41.77626648256856, 46.139354167446015, 52.976229729190955, 54.02908409795454, 57.238398751904896, 56.8637849438575, 56.53008537907755, 49.79277133941651, 61.38876453522713, 58.249970174604854, 58.92587300269835, 50.40233512078562, 46.746811636032604, 58.74731102297383, 60.1618863690284, 68.38403717164071, 37.711424058483495, 0.11237450349595278, 0.4933385905479232, 3.5372051885051117, 6.1023161392058105, 39.48689276172269, 43.989173596905125, 58.763243690613784, 56.34926803650395, 60.02731769315658, 60.5596500058328, 61.144028248325476, 45.707093284976104, 37.71858238404797, 46.754122934033795, 47.68099861760294, 47.377948453349454, 0.4865734825932211, 0.11822793617724411, 0.1585138571118155, 0.09415081927492734, 0.054696318242819085, 0.041956176470604636, 0.025533348539723985, 0.02673539028863513, 0.019489163795726436, 0.056162101081422264, 0.03441497165289137, 0.059057354191017736, 0.04172454212581919, 0.042261221190734256, 0.025070282863453034, 0.06960674113924466, 0.019222833328850327, 0.09760631248354913, 0.34177851352480154, 5.8769396908821605, 63.32217139582481, 52.77723612323884, 38.711651986645116, 29.854502793281313, 58.56707026881557, 49.226416387865626, 63.17163475098149, 66.17648017021918, 69.26687640528526, 64.86609474305185, 64.19784445916453, 56.27476653745098, 62.13095541923278, 2.9803943441760157, 1.2302841318230475, 15.253646527567218, 0.6096644759658845, 2.4498270980773436, 25.95512163254523, 58.039044718588556, 62.48916979758971, 63.725206698140795, 62.08941751910795, 63.59237170988514, 63.271498295568655, 60.261161558089725, 57.18370914459229, 57.676562801484145, 53.44609437450286, 54.09052018196353, 54.66698700381864, 54.569139557500044, 60.1466558056493, 56.516933671889774, 48.99081530109529, 44.41140105647426, 43.759993430106874, 45.21236865751205, 48.67771210209016, 55.56783383892429, 55.753711039020175, 56.44287932303644, 58.638426026990345, 58.7578857329584, 56.80006604040823, 59.53365602800923, 54.930903680862926, 47.5756476771447, 49.3707243088753, 45.89856378493771, 45.642570295641505, 53.22875976562501, 54.69952698676817, 57.28596533498457, 53.6202476101537, 52.34895252412366, 51.33619654563166, 44.27283548539685, 44.488573689614576, 42.9873884877851, 42.75791414322392, 48.54092336470082, 50.99312643851004, 56.522424990131015, 54.60540579211328, 54.34085761347125, 54.035242219125074, 54.452684387083984, 59.10188544181086, 57.16989847921557, 58.16276411856375, 50.09217762177991, 42.22715862335698, 40.937530379141535, 43.19789032782278, 40.08956493869905, 47.36649121007612, 45.74797614928215, 41.19854842462848, 43.36308094762987, 40.883829209112356, 41.96202993392944, 43.79612238176408, 43.17404623954527, 47.329416967207386, 59.36367227185158, 57.5163535917959, 57.71944999694825, 53.70532381919123, 53.61893753851614, 53.286583346705285, 53.0155828691298, 48.316100951164, 44.89726112734887, 44.04187848491054, 42.55197794206681, 40.16331334267893, 40.16050100326538, 44.135666278100786, 49.533310474887976, 51.45875884640602, 51.129185615047334, 52.21234029339206, 51.647821011081824, 51.135708516643895, 44.15470546291721, 47.748271188428326, 48.53463188294442, 44.65400749637235, 54.537407582806004, 52.99349992505966, 56.08949730473181, 55.26197133525726, 51.72231074302427, 49.10225376006096, 50.626659393310554, 47.626932667147734, 54.020654924454234, 54.44862865632581, 52.89565640111124, 48.37084154928885, 44.70453154656195, 43.14906466391779, 44.937308526808216, 48.11049815147154, 56.37756401492704, 57.04541813942694, 59.6073220622155, 60.657320945493645, 58.03427511645902, 54.56125167108352, 62.47078957096223, 61.43397769620342, 61.588911318009906, 54.42222326032577, 48.251860372481815, 62.16906516782699, 62.96173303358017, 71.94829494722428, 38.892108471162864, 0.13262659701849186, 0.7374030796270217, 1.6480913253561145, 8.027396788520198, 47.41501877384801, 49.661050304289795, 64.65530264762141, 63.742696546739154, 66.85439125184091, 68.21266881881222, 67.48946220644059, 53.245237642718905, 47.09862470626832, 44.93819498246716, 54.61128542500158, 55.3267571233934, 1.3899154047812186, 0.17595417046498868, 0.19918442313228885, 0.013749476976602549, 0.03802935532744854, 0.053925656773630655, 0.03386506991040322, 0.03570108006017343, 0.17617247487989166, 0.30167417841092237, 0.07989196181898156, 0.1053812545574, 0.14501246143012278, 0.18447326736584788, 0.1777581083438089, 0.18348001905025976, 0.18914346192632953, 0.35068005683922, 0.633607236368041, 7.133411159438472, 77.72283184912898, 62.171912808572095, 59.39028555347074, 29.73217191234712, 67.40361721284928, 57.91201091581776, 70.4995753688197, 71.78178248866912, 76.47557304751489, 70.32093494169175, 71.56522843145555, 60.61227644643476, 71.5078833795363, 3.5315292737176343, 2.4902657539613786, 29.229706487348004, 0.9609640221441946, 3.883735806711259, 34.19578798355595, 58.79443045585387, 65.41247306331512, 64.58497847280195, 63.29377735814741, 65.73409172796434, 65.00529573809716, 61.57709713905089, 58.286377614544286, 59.523646139329486, 53.518328743596236, 56.295386437446844, 56.81893264093707, 54.19199189832134, 61.80507313820624, 59.55729223066761, 52.09080565360285, 48.05565949409239, 46.65640100356072, 47.6588725274609, 51.42116685067454, 56.160354921894694, 59.13029909133912, 57.67056549749067, 61.448568913244436, 62.06953502470448, 58.222909742786044, 62.58163182966171, 59.991655503549886, 50.535201488002656, 51.66068246287685, 49.150149822235115, 46.70144942498977, 57.18308941010506, 57.252625188519886, 58.15956346450314, 58.90177788272981, 57.5254770248167, 55.10831640612695, 45.845917732484885, 45.467714955729825, 45.31794709544028, 46.01905899663126, 53.93682210676132, 54.704578999550115, 57.96570031873642, 57.505967155579604, 57.882196980137984, 59.60543932453279, 56.84053705584619, 64.10073441843834, 61.095626200399096, 62.70635143403084, 51.435059885824884, 43.50030899047852, 41.98071218306019, 43.26120522714431, 40.4133330622027, 49.1100122082618, 47.25334259771532, 43.17562695472471, 42.452604693751184, 42.75599610420966, 41.56708648127895, 42.846512640676195, 43.79232552743728, 48.82015689726799, 61.38394001991519, 61.05329598149946, 61.99317824456, 55.54127547048754, 56.55432562674246, 57.34882131699593, 55.78363872343495, 52.89413452148438, 46.90806027381651, 47.232734464829974, 44.797087715518096, 42.04717674563008, 42.01121645589029, 46.00595435788555, 52.64323226867184, 53.94009336348503, 53.71569456592683, 56.14891336810205, 54.37154231532928, 51.93089062167753, 46.06006737678282, 50.41961708376485, 50.650354431521514, 48.910559684999534, 56.97562348458075, 56.17238090884302, 57.619358954891084, 57.48951673507691, 52.28855979058051, 49.69855993024765, 53.16277373221613, 49.361165492765366, 58.5022178003865, 56.784019624033284, 56.2043325362667, 49.89714168733167, 48.624438470409764, 44.275353647047474, 47.54291549805672, 51.562638898049634, 59.10187367470034, 60.05393489714592, 64.09183848288752, 64.89089196728122, 61.81196866496917, 56.99639635701334, 64.88502017913326, 64.63560058224586, 65.185344296117, 56.919702253034046, 52.745908152672556, 64.91710516714281, 67.17537449252221, 71.71551012223767, 43.705331279385476, 0.15385867787464974, 1.38654719196981, 7.7103408209739195, 7.763159457714328, 53.40346213309996, 55.531214590995546, 70.5739042835851, 69.41561268221948, 71.39648022190218, 71.85581330330142, 73.23454995309153, 58.853721003378595, 54.814825057983406, 56.886134609099365, 62.099815722434755, 67.1141541388727, 3.073974006598996, 0.449160659505475, 0.49740559812034335, 0.21076306069810546, 0.16575064540149706, 0.16898713705520477, 0.17653276603068077, 0.1642207218514335], [0.025261569272486434, 0.08060381071822298, 0.07601763302039716, 0.03402513249086277, 0.0368557162883301, 0.04347164777197665, 0.0553413029880293, 0.014235645949449992, 0.031698067642508015, 0.006580898761674161, 0.028651950753203807, 0.18692162308481433, 35.469554162794545, 46.63762069517567, 31.42898140415069, 27.555330991745, 42.154837962119814, 62.06613040739491, 63.38651787850165, 63.08722142250308, 61.06458456285539, 56.99570209749284, 61.84039408160795, 52.99358621720345, 61.01522153423679, 13.62887626694095, 1.9186186670295655, 11.781546800367295, 0.8701653201733867, 2.8620446689667243, 23.401178160021384, 57.00876751253682, 51.873486734205684, 61.411294629496915, 57.48490010538409, 58.89241126275832, 56.40178857311126, 58.59646843325708, 56.86423601642732, 57.86473066576066, 56.37865051146477, 58.223674604969645, 59.62060320761896, 59.38490406159432, 57.64546232838785, 52.962054283388206, 44.850600611779, 42.684385391973684, 45.08062016579413, 47.029759653152965, 48.39399530041603, 55.98608793750886, 55.9981688376396, 54.93326494770666, 52.81969185798399, 55.169058230615434, 58.04927033762778, 54.19020721989294, 55.411429328303186, 50.338471089639974, 46.76077919621622, 47.24014382208548, 42.69143389117333, 47.06468051479709, 51.030059476052564, 53.53872899086245, 49.609424068081765, 52.085965448810214, 47.4912186591856, 42.93916294651647, 40.34228324890137, 42.506564740211736, 44.30190809311406, 49.171365922497166, 49.778199734226355, 52.98340374423612, 50.41006219002509, 49.306150328728464, 51.48270099393783, 53.39188329635128, 54.75271824867495, 54.752357390619096, 55.169874083611276, 49.89334483300486, 43.02464315968175, 42.62738550862959, 43.07432782265448, 42.39315332904939, 48.01726341247559, 45.88304688853603, 41.60454511642456, 43.519830626826135, 42.35045440735356, 42.209158866636216, 42.54330165924565, 44.12274991312335, 47.58144101788921, 56.28148947992633, 55.868718854842655, 53.90418014218731, 54.42392556898056, 53.10868424753989, 51.849685792000066, 51.69607008657148, 50.93254543119862, 48.82176506903864, 42.82983472270351, 42.44198291532455, 39.21955970025832, 38.735398015668316, 39.946504331404164, 43.75002276512885, 47.66671726780553, 51.95002002100791, 48.03857757199196, 50.728331150547156, 45.52892746463899, 41.81002632264168, 45.54653890671269, 49.15346422503072, 51.51979092628726, 56.92943365343156, 53.55543828779652, 53.96462778891287, 53.81945694646528, 51.981846132586085, 53.435143116981756, 54.4533472676431, 53.24332352607481, 50.40374325167749, 54.92110560017248, 53.37133007664835, 47.563806041594475, 43.37369880368633, 40.21581818980556, 41.12762804954283, 41.53400128887546, 46.821101327096265, 53.28905051754367, 55.65883282692202, 55.39015439248855, 61.17204573846633, 53.8735778101029, 50.59336631528793, 64.25397357633038, 59.04165744781495, 57.406805715253284, 50.258258619616115, 56.036321732305716, 59.36151104588663, 66.42057711078276, 20.80171165927764, 0.13954841591898473, 0.29721082758999645, 1.0333664402846368, 32.75503670015643, 40.04919590488557, 45.09730985087734, 60.54254062714116, 58.182403426016535, 59.09753161091959, 61.65814899629163, 57.99447482632053, 41.075931210671705, 31.645003980205907, 28.884661466844623, 50.33064988351638, 27.363905599040372, 0.17794858844530198, 0.1127056066968268, 0.03086563075832542, 0.0462413122577052, 0.04074971822481002, 0.08065525352233842, 0.06803018581723014, 0.05424961620461076, 0.05184363280873626, 0.04009045360069122, 0.13425551445013092, 0.038091071370628574, 0.010693592466263762, 0.06904446324633975, 0.03334855427965522, 0.02592730350912579, 0.06919201944143542, 0.047182451272683765, 0.034111470599929174, 0.28527802757678494, 45.6919607808513, 54.644727553090746, 30.966133879077052, 30.748361925924982, 55.16516331703433, 59.898522746178415, 70.12607943627143, 67.09173387096774, 65.88978628958425, 62.826830956243704, 66.94790840148926, 56.46989660878336, 66.29266077472319, 14.733495135461132, 1.4165310153076727, 8.29000682600083, 0.09838157814116248, 4.996207260316418, 29.909425781619166, 56.723454306202555, 53.686480752883426, 63.30321850315217, 59.84780649985037, 61.58571458631947, 58.585768207427, 58.48953285524922, 56.05687495200865, 58.01780508410547, 57.682446356742616, 59.32733935694541, 59.684686891494266, 60.746962793411754, 59.752579196806884, 55.004965874456595, 48.75669687025009, 43.98151713032877, 47.58194308127127, 46.87133119952294, 52.67158316027734, 56.84738943653723, 58.129376903657, 56.34343547205771, 54.05031588769729, 56.203763792591715, 59.85806742022115, 56.5176240090401, 57.82961368560792, 52.61543835363081, 50.145239445471, 49.125458502000384, 43.74946971093455, 48.799740960521085, 54.31103191068096, 55.552807238794145, 52.74952065560126, 55.04232252797773, 49.49447508781187, 44.595830901976555, 41.792156004136615, 43.13599140413346, 47.42457366758778, 49.68543567965108, 51.50263447915354, 56.39073925633585, 53.8775590158278, 54.2236218913909, 54.11734134920182, 56.935289752098825, 56.16008035598263, 56.98112656993251, 57.192993394790165, 52.4097571065349, 42.60083498493318, 43.464756627236646, 43.22886528507356, 42.147832608992054, 48.581096280005674, 46.9940072490323, 41.28921793353173, 45.02118449057303, 43.322774671739154, 39.995577104630016, 42.196501378090154, 42.51202860186177, 47.53904804106682, 60.18518524785196, 56.59659701008951, 58.25397491455079, 57.23489215297084, 55.87501033659905, 54.41263698762464, 54.86576880178144, 53.15617238321612, 50.57080484205677, 44.127766624573745, 42.77730634135585, 41.47500491911366, 40.2138570047194, 42.25626261003556, 46.18840340645083, 49.82941412156629, 52.70272285707536, 51.749010316787235, 53.488950191005586, 48.31701094104398, 43.12571087191182, 45.846882635547274, 49.94233523645709, 54.34601160787768, 59.48552070125457, 54.6262021987669, 55.385949611663825, 53.69774580001832, 53.11087685246622, 53.865336910370864, 56.65616604589648, 56.646634686377745, 53.949432526865316, 56.62371235509073, 54.442219503464244, 49.06520305141326, 45.86511773447837, 42.06122667558732, 42.66975102886077, 45.05478351346908, 49.912854702241965, 55.366357372653106, 59.539802382069254, 56.865903023750555, 62.98712253570557, 57.06162145060878, 52.43074963169714, 65.34174096199774, 60.37083495047785, 61.60440075782038, 50.849297046661384, 58.95870716341081, 62.295012474060066, 68.88486108472271, 22.439854260413878, 0.23405708252422272, 1.3375815484792957, 0.6223966121192902, 36.22406128914126, 41.97160836189024, 51.38887397704586, 65.45627809339955, 63.552685168481645, 65.15516558001119, 66.87750185689619, 62.65465067278955, 48.34742892173029, 41.26545621502785, 32.085688152620875, 56.8570698461225, 33.133210059135195, 0.020830359670423695, 0.05713500593218112, 0.02477903347161989, 0.04569534820714786, 0.0800872835961561, 0.016919567001863353, 0.011297535008540558, 0.07985244700384718, 0.13668882420226453, 0.15316679322671506, 0.2007641883627061, 0.10378163232798539, 0.08988257572655717, 0.10636439817326684, 0.1230727604800655, 0.1559601336597435, 0.12214740287632712, 0.1484307304265038, 0.11749938656125339, 0.4155416876798676, 56.241649966086115, 64.16604580417757, 45.96337702966506, 42.15074300765991, 59.1546138640373, 70.96894187311973, 76.50042518492668, 73.92934291593491, 71.33000389222177, 70.2065037142846, 70.34217065380466, 62.41959479547317, 73.81201697934058, 18.133019247362693, 2.1729607159091584, 25.778707150490057, 2.5351724797679536, 7.587057294384127, 36.03851749051002, 57.95767514936386, 54.0307197263164, 65.1661168375323, 62.01271557038831, 63.79300094419911, 61.26177387852823, 60.89465571988014, 59.25571295522875, 60.07798687104256, 58.16308575291788, 61.73687881039035, 62.18984196262976, 62.18256596596011, 63.24357101994177, 57.49123081084221, 51.32720255082654, 46.3449255881771, 49.94233131408692, 49.93578880063949, 54.55782744192309, 59.25698772553475, 61.020501044488725, 60.05220513189993, 56.124837859984375, 57.209945878674915, 64.140311133477, 59.41815791591522, 59.443512116709066, 53.39924558516472, 52.98846752412858, 51.23631338919363, 46.57291727681314, 50.21808570431125, 57.218739832601244, 60.36237832038634, 55.55261896502588, 56.866456077944854, 52.58755030170564, 46.723865770524554, 44.961227140119, 46.490818146736395, 49.750084184831195, 51.18418901197372, 54.78973757836127, 60.04676480447093, 56.70397189355666, 54.49164921237577, 58.19178965783889, 57.96054240195983, 58.69516311153289, 58.257512892446215, 60.632719839772875, 53.40003398156936, 44.08363211539484, 43.1182191448827, 43.878958917433216, 42.56934619718983, 54.535120840995546, 50.02355575561524, 41.37611412232922, 44.67372917359875, 43.35139228451637, 41.59267210191296, 41.679517299898215, 42.328465600167554, 48.34805650095786, 62.545408741120376, 60.636359799292784, 60.158116971292806, 60.77439585039693, 57.99336087319159, 59.034977651411495, 57.79994487762452, 57.098597634223204, 54.3285099921688, 47.71697067445325, 46.43823092983615, 44.259413134667184, 42.71277942965108, 45.82378771997268, 46.394316073386904, 51.15705013275147, 56.049120426177986, 55.97077500435614, 55.408895477171875, 50.510616071762584, 45.16230352463261, 49.22285095337899, 51.54957348300565, 55.10219358628797, 61.631308217202466, 55.911970830732784, 58.174240973687944, 56.93519561521469, 55.051069413461995, 56.976203995366255, 56.524064540863044, 55.24030416242538, 55.67778964196482, 59.65843446793095, 56.31964237459245, 51.033032632643184, 48.21708856090423, 44.9072317923269, 45.39255842085808, 48.1418731904799, 52.47109905365975, 58.32113373664118, 60.15919170072002, 62.58419705975441, 64.76294425226027, 58.72260401325842, 54.51594045085292, 65.85178636735486, 64.42882499387188, 65.23941809131254, 55.67227871187272, 60.81359601789906, 65.14623042075866, 69.90454396893902, 26.501427388960316, 0.18216499848471535, 2.189589849402828, 2.395705008699048, 39.25384906030471, 51.23837655590427, 59.11215028455181, 71.97583783057429, 70.47456633660101, 71.45641403813516, 72.99111197071691, 69.18332207587459, 53.2328272634937, 45.36456446493826, 40.02308468664847, 66.13248686636648, 43.79089386232438, 0.301573391883604, 0.27130464512494307, 0.10482800884112235, 0.14577401411389151, 0.26662277538449536, 0.16395291283486352, 0.1542057003825903, 0.21590896521604833], [0.034748143291160945, 0.03398398973888928, 0.024736019549891356, 0.0790042650976008, 0.04166468001541592, 0.10908748834363877, 0.03147461320153408, 0.06905219307349575, 0.0035896584262034947, 0.09049094146898679, 0.08909153631858288, 0.31679745883710925, 16.272895009286945, 55.83789294765842, 31.195457212386597, 23.210396036025017, 34.89526425638507, 50.731296462397424, 47.991426760150546, 65.208494124874, 57.957286834716804, 56.565104299975985, 50.60131303725704, 50.432011773509366, 58.13646462655837, 28.624029774819654, 1.368054319773951, 7.915393998545985, 1.7037067346034513, 6.233891066043608, 32.38329406707518, 56.22004947354717, 52.138470295936834, 49.30055702886274, 57.3582193159288, 57.812272887076105, 61.21745894032141, 61.41156527303881, 60.16425548061248, 60.52881233153805, 61.204554342454486, 59.02198676140078, 59.60272112200337, 57.0377734399611, 54.26285736022457, 47.99309768984395, 41.66824833039315, 42.679678547766905, 43.42213615294426, 46.55134816323557, 51.58206639751312, 55.64286485795052, 58.38415838056996, 54.310129765541326, 51.358608968796275, 49.8815659553774, 52.972770198698974, 62.391820492282996, 57.04578291985297, 55.782108999067745, 46.60844610583398, 48.52461022715415, 42.88421054040232, 44.049342755348455, 48.6933349024865, 52.932534525471354, 53.26020932966664, 47.57036816689276, 42.58526709771926, 42.700039571331395, 37.769471214663604, 43.07568104036393, 48.79029981551632, 47.916874270285334, 52.84822317861742, 53.31361632193289, 52.9498557121523, 54.65457270222326, 55.33040885002383, 55.00502863237935, 56.30468245475524, 57.30864840169107, 54.17927949659286, 50.35749850734588, 43.365740314606704, 42.82034650925667, 43.054963081113755, 40.72634212432369, 48.17790016051262, 45.25275338080622, 41.45320438569592, 45.03468921107631, 41.0441521675356, 45.462278550670995, 42.11223317730812, 43.890333790932935, 49.872548426351244, 54.80019853961084, 56.2997285012276, 54.45915237549813, 55.621119237715206, 54.09266964081795, 50.04942378690166, 54.511767048989576, 51.12738132476807, 50.18909938873784, 45.56782953200802, 40.35757657020323, 38.181994730426425, 37.83727722783243, 35.62229910204488, 40.217151795664144, 44.21675735904325, 48.967908659288966, 50.24120023173671, 51.868015027815304, 42.74959087371827, 41.93349469092585, 44.407972904943655, 49.17630026417394, 55.821630800924, 55.826039544997684, 53.4646079617162, 51.4290782713121, 54.889259876743445, 52.7249195498805, 54.58704909970684, 53.05694426259687, 56.487268786276545, 56.87622670204409, 56.080628825772195, 51.21679567521619, 46.85262933854134, 41.848693047800374, 41.326358856693396, 39.42883776080224, 43.27743991728752, 42.25195976995653, 46.760524242155014, 50.614213712753795, 54.589857516750214, 54.79528380978493, 58.5647560704139, 57.52128793347267, 60.528494619554095, 63.44354914080713, 61.10312184979839, 54.98103157166512, 59.373744918454086, 58.714178762128284, 66.22208949058287, 11.07121438749375, 0.08134015910928288, 0.6792636864608335, 0.6313773076380453, 52.885823019089244, 63.3263094963566, 59.74174561039094, 52.53775581236809, 62.555002858561856, 55.80538434367026, 67.11544067628923, 48.53268638733895, 42.19497557609312, 29.828066018319902, 30.00660054145321, 55.94230644164547, 11.86924413327248, 0.19723869770044283, 0.055288462073452053, 0.07153989506825324, 0.07882429572242884, 0.1325917246961786, 0.032182518663185264, 0.06250150163748092, 0.046227005565719265, 0.07143252018478609, 0.01015137458565615, 0.08529926319756816, 0.025756626780475342, 0.08502368604944599, 0.013693659810439475, 0.018699488024257364, 0.029787174313359206, 0.015052150120027365, 0.08205600698748905, 0.11914113596562417, 0.18217906385900515, 21.95814209599649, 66.18998096835229, 34.738169408613636, 30.34576200669812, 47.004142653557565, 53.445321667578916, 61.32294716373567, 70.1050869111092, 67.05352214074904, 59.576276502301624, 58.92988558738463, 55.98942195215533, 62.353063552610344, 29.694507352767456, 0.7974464770766997, 4.414168221335258, 2.330551253211114, 8.424368596846058, 36.859540170238866, 55.8930532393917, 52.05021304468955, 51.260808590919744, 60.06620407104493, 60.42915275019985, 64.49171627721479, 63.59743941214777, 62.75802081631076, 62.03900721765334, 62.775734240008944, 62.09860371005151, 62.37323238003639, 58.42322910985639, 57.545708610165505, 50.87845594652238, 44.02443178238408, 44.96703224797403, 45.6494422881834, 49.88453126722767, 53.18388392848354, 56.91368533718971, 58.01793059995098, 55.44846042510002, 52.89585644199003, 50.80834357969223, 54.991453309212964, 62.90533327287244, 57.96708883777742, 57.030368005075765, 49.14829061877344, 50.68427116640153, 44.763253350411695, 46.54587253447502, 51.52784355225102, 54.48098036550707, 53.69416467605099, 51.152963023031916, 46.56499016669489, 45.59556853386664, 41.019488303892075, 44.23766751443186, 51.151307782819195, 50.54563891503119, 54.198691306575654, 54.94260411108694, 55.67245914090065, 55.36233694322648, 58.21528857754123, 56.91376378459316, 57.73809694474744, 57.881212465224735, 57.01065809495988, 51.95255387213923, 43.56579688287551, 41.85194077030305, 43.43167535720333, 42.25466228300526, 48.97448255169777, 48.03167420048868, 40.7482603288466, 44.33998254037673, 41.8235977234379, 44.2027231185667, 41.10055977298368, 44.53589708574357, 51.08971480400332, 57.75164873369279, 56.81674395838092, 56.93101044624083, 56.910547441051854, 56.34258039536015, 53.217227997318396, 56.067665392352694, 53.23770276961788, 51.253316863890625, 45.073873689097745, 42.6323002384555, 42.17204932243594, 39.96353134032219, 39.893438585342906, 42.98262280802573, 47.069983559270064, 52.49568446989983, 52.362551381511075, 52.168362679020056, 45.26332416842061, 44.38800019602622, 45.78655658229705, 51.421347279702466, 56.549508956170854, 56.82240786090974, 54.27990790336363, 51.814333469636985, 56.73437026239211, 55.07239534008888, 56.919725787255075, 54.7625869320285, 56.41333210852839, 60.045996019917155, 59.020021653944454, 53.79398507456626, 49.832630465107584, 43.768552041822865, 43.479536118045935, 42.081756361069225, 44.889761555579405, 44.6476532566932, 47.30662015176589, 53.6784791177319, 57.30993493910759, 58.57550728705622, 60.57457462433846, 58.948783566874845, 61.201812605704035, 65.34166643696447, 64.84759292294903, 56.77897545599169, 62.209849972878736, 61.333439503946614, 67.10078670132545, 13.617868135052344, 0.170309282238445, 1.1891233921051025, 0.9210877973706493, 59.79901613727693, 62.49066814299553, 65.48600181456536, 57.775422219307195, 68.22908786035353, 62.225751261557306, 76.91010890468475, 50.9588723797952, 54.44019163808515, 36.32379147314256, 25.889982831093576, 67.27510467652353, 16.976522130350915, 0.23909887569325589, 0.013559826165287486, 0.01929393777954242, 0.0807697760061391, 0.0637385765871694, 0.0187320850654355, 0.040359335140355175, 0.09120997627295795, 0.11565915143658077, 0.22212610580027106, 0.16567005295186274, 0.16247750410149175, 0.20066298814790867, 0.20019302384987955, 0.16553333690089567, 0.1775289867674151, 0.20719693673233833, 0.21752380195163915, 0.3314411375791796, 0.47023129499247, 30.005372839589274, 77.73286527202976, 45.184209962044996, 33.1578190095963, 46.917623012296616, 63.43051510472452, 60.28844948737853, 76.61767267411756, 70.5393325128863, 67.06584622783046, 65.34335305613857, 63.67498074808429, 67.47414927328786, 38.17235354454287, 2.160505964871376, 16.63886881643726, 3.587876572724312, 10.48749118081985, 46.677048360147786, 56.03330150727303, 52.33828367725496, 52.32149985528762, 62.159929967695675, 62.536618709564216, 66.61447555788102, 65.84934665310767, 64.83788897914272, 64.21514211162444, 65.58264509324106, 63.247716965213904, 66.93389769523375, 61.119125120101444, 59.80569593368038, 53.838347081215154, 46.23533456556259, 47.36404365108859, 49.641207033588046, 51.715230864863244, 55.67841329882222, 58.12679990645378, 60.61737552765877, 57.31682262113018, 54.82314440511889, 52.594351691584436, 55.427958196209325, 67.21654368985084, 59.09622938402238, 59.30934352259482, 51.24667236881872, 53.73607520134219, 47.12073118455949, 48.8661035414665, 55.23051784884546, 57.493592077685946, 59.10673349134384, 52.59498711555235, 50.30979071894, 47.90662903939524, 42.34344513185563, 48.99061133784633, 55.28380717000654, 52.6078603344579, 58.79411666624008, 57.841263125019694, 59.60105411468014, 58.88857910709997, 61.89599367880053, 60.862790384600245, 61.9224500656128, 60.34542975887176, 61.12522048334922, 54.30981205355737, 43.32376310902257, 42.6948385084829, 42.6457735799974, 41.35202684710103, 52.294835582856216, 49.83176754366968, 41.83527069707071, 45.613187820680686, 41.73110039003434, 44.71948754402899, 40.82192636305287, 44.10400882844002, 52.33318459603095, 57.83446565751107, 62.180240000447924, 59.43690684533889, 61.2550901597546, 60.34401770560973, 56.70571734828334, 60.69832148090486, 58.03747577051963, 54.48474191850232, 51.04939283863191, 43.745108035302934, 45.79225186378726, 43.40683890927223, 41.97808419504474, 45.68627726647162, 49.41893808303341, 54.919783761424405, 53.713498038630334, 56.478474832350216, 47.4939250946045, 46.37297053490916, 47.895034513165875, 54.15860076104441, 58.54099042953984, 60.18367513533562, 57.42564878156109, 53.87035754419143, 58.381098931835545, 58.061582657598684, 59.430870317643695, 55.9296646425801, 58.475392710778024, 58.374623098681056, 61.75212506325015, 55.99208916387251, 51.37739319955149, 45.505220659317516, 46.65616958372055, 43.673614994172134, 47.711310694294596, 46.23158477967786, 51.214418718891764, 55.46708383867818, 60.178870231874534, 60.694387343622026, 63.886875029533144, 58.12635275625414, 63.29633866586993, 67.57626425835394, 67.08044528961182, 58.356870451281154, 64.37175843023485, 63.2892313311177, 69.7982712714903, 15.67891872698261, 0.37159275563974536, 3.003371588645443, 1.103703117659015, 63.44147420698597, 73.70128846937611, 73.60231138044789, 63.1830253139619, 74.2855647302443, 68.51313021875197, 77.76268313007971, 58.60397977213706, 55.94138468465498, 43.867317322761785, 40.669738400367, 76.35517981744583, 22.648290972555838, 0.334040780341433, 0.1361929967759117, 0.1409763272010511, 0.1741334092953513, 0.23584929925780143, 0.11419534127438262, 0.14880508695158268, 0.14217145500644562], [0.02730675398432199, 0.042738118584478096, 0.06843817360218495, 0.09426030856106551, 0.009683294863920779, 0.061181436382955125, 0.04553717403342167, 0.012199004075580068, 0.0524399939533924, 0.13552132152741955, 0.05993482746904897, 0.15458679848140286, 4.86775012746934, 49.864935105846776, 32.626016216893355, 32.6851479084261, 31.06946872126672, 48.256728033865656, 47.78377648322813, 61.47366815997709, 58.45830686630742, 62.373299060329316, 52.63007271674372, 56.51444688920052, 52.416691856999556, 43.32066051421627, 0.2651927037344825, 3.7050274735496895, 0.5846004079907172, 4.285825817815719, 28.760426275191772, 34.52627512716478, 55.34032067944927, 58.978001302288426, 65.37759534774288, 62.31049406913019, 63.47699126889629, 59.121967977093114, 59.40537098915347, 55.32530976879982, 56.38998223889259, 55.34975397971369, 54.27094136514972, 49.963343451100016, 44.27700104251985, 41.83975004380749, 42.705636793567294, 42.53764560145717, 41.7873550230457, 44.680350134449625, 50.67570078757502, 53.92455685523249, 58.921754514017415, 57.47957744906026, 57.50950513347503, 53.04673433303834, 45.75867637511223, 47.886566115963845, 58.518679987999704, 57.55669516901816, 51.42620709634597, 48.290550631861535, 44.442117137293664, 42.37928382812008, 45.655055199899984, 50.277548836123565, 49.44779496039114, 46.01219092645953, 42.383978905216345, 41.50926682256883, 39.53933092855638, 46.46824098402455, 50.159548251859604, 50.61015798199562, 53.55064122907577, 52.23772195077712, 54.24581073945569, 53.20324867002426, 53.26036622447353, 54.20620656782582, 58.208079261164514, 57.18794530437839, 56.19207512947821, 48.08949778156896, 41.82187580293225, 41.92723458813083, 42.72484071793095, 44.175388120835834, 46.12759882403959, 45.928389487728, 41.621309326541045, 44.260138773149066, 42.293913441319624, 42.52176392462946, 43.53435124120405, 45.72208066140452, 50.90303351802211, 56.85077051962576, 57.31913681953185, 54.91406494571317, 56.92690372467042, 52.90303437940536, 51.326469067604314, 53.910118610628196, 51.173214220231586, 51.95436992952901, 50.748496055603034, 43.12615802211147, 41.661921547305205, 36.91887386383549, 36.876782909516365, 40.580951629146455, 44.72751663577172, 45.72535191812823, 48.624007009690814, 44.86191664972613, 42.165071425899384, 42.371144910012525, 47.428095956002515, 51.96014365842266, 56.95659998924502, 53.50859342082855, 51.345720060410045, 50.04101422525222, 57.57732683612455, 52.64422070595526, 52.31803640242546, 51.13628510505923, 51.96203031847554, 52.23880060257451, 51.70175752332134, 47.8753795162324, 44.6939411470967, 39.69215823758034, 41.390654348558, 40.39899287685272, 40.86635112762451, 41.96774090490034, 42.65378698225945, 43.410808347886615, 49.258760252306544, 56.85526555584323, 58.021299915929, 58.4324662916122, 55.52654304812032, 51.093809758463216, 62.62721761580437, 57.076400941418065, 60.79091687356273, 58.464178654455374, 55.25918645243491, 12.006086803251698, 0.07947936984560183, 1.7539929911013574, 5.121872646193351, 56.92452676834599, 51.16760523088517, 57.06707746751847, 57.560484178604625, 59.82078136936311, 58.72796981565414, 52.889604183935354, 47.01388974343577, 34.13879986732237, 23.891894125169326, 38.33109971015684, 49.64508233531829, 3.039982011241298, 0.22729303177085616, 0.05325513831790417, 0.09092243283145851, 0.011012198857872958, 0.08704788186737607, 0.01915310783642194, 0.022711946306029157, 0.03756496048862896, 0.021433284273371104, 0.05931462566818922, 0.04621880459448984, 0.03660562305500911, 0.04393257989337848, 0.04599775375437833, 0.05058783083973874, 0.0666854870054991, 0.053825410338298935, 0.09948775547766879, 0.03727074825174866, 0.32433438505376544, 7.97178493392083, 61.897339051769634, 34.92885151217061, 24.227362678897, 45.04825668950235, 51.347822450822406, 50.59073048253214, 69.88393583605367, 62.79629530445222, 66.29935233823716, 60.113280357853064, 60.21864698779199, 58.34195759988601, 47.37047241580102, 0.363366105143101, 1.850211428057763, 2.587804068480769, 5.818860665444405, 34.73673382113057, 37.60141726463072, 55.02791958470499, 59.84013042142315, 66.91689029816659, 65.4837582188268, 65.35820314961096, 63.62031467499272, 60.82023266823062, 58.449344250463675, 57.47892633561165, 57.50312735957485, 58.84873567088958, 51.740651745950025, 48.25888141509026, 44.13476021059098, 44.419453682438025, 44.774643913392104, 43.11257485420474, 47.50435859926286, 53.054053475779874, 56.86835450510825, 60.16999390817458, 61.79803248374694, 58.56997674511325, 54.832424732946585, 46.64427695735809, 51.719612152345725, 59.42404931591403, 57.648914014139486, 53.73292161572365, 50.52446203847086, 45.69979375408542, 44.35832746567265, 46.281155693915586, 52.83511461750154, 50.982371299497544, 47.8081226348877, 45.153097721838186, 43.8498313965336, 42.29592169484785, 48.351272844499164, 51.97048302619688, 53.72864623223582, 54.832385509244865, 54.25365940217049, 57.94331142979284, 53.49701458407987, 56.75248376784786, 57.134110773763354, 57.84793115431263, 58.708103010731364, 56.853014115364324, 50.47831535339356, 42.49182839547434, 42.57934431875906, 41.657806980994444, 43.3417393315223, 48.21323679339502, 46.174243650128766, 41.217042399990945, 43.939324194385165, 41.8681989946673, 44.35085927286456, 41.81209733409267, 45.33094583019134, 50.54330510477866, 58.07082768409484, 58.91261146914575, 57.65602134889173, 57.15959049040272, 56.65278888517811, 52.45571159547376, 57.686192220257176, 53.7666343873547, 53.01781469775785, 52.25274462853709, 46.86925234333162, 43.5041372237667, 40.95905242427703, 38.824220088220414, 43.75209769895, 46.76408183190131, 50.195806641732496, 51.36106045015397, 49.16570201996834, 42.251143916960686, 43.97879892779935, 48.70913028717042, 54.43540634647493, 57.39290483536259, 56.02219335494503, 51.78333890053534, 53.05539884874898, 57.80799750358828, 54.3027517872472, 53.9111658834642, 54.0716653485452, 54.59976150143532, 54.514904945127434, 54.91150363799065, 51.30903413218837, 47.595592929470925, 43.23228951423399, 43.53980725811374, 41.64503182134321, 43.05124075182023, 42.93053373213738, 46.34098360615392, 44.7240061144675, 52.45347976684571, 57.851567191462365, 59.682882601215, 60.52142650850358, 57.935874615946126, 52.89643695277553, 64.64886603816863, 61.339746675183704, 63.95400247266216, 61.167707597055745, 57.89663130237211, 13.874516660167327, 1.1546393844389147, 1.4250425585815985, 6.242443303908072, 64.29187936167564, 56.708086459867424, 63.588551321337306, 62.94318806740546, 67.72477303781818, 65.92855499636742, 63.93920337000201, 49.39987536399595, 51.4326633176496, 26.714051231261223, 35.83538970639629, 60.024940736832164, 4.677529883000159, 0.2387650758628884, 0.0520436238918093, 0.07218070463427613, 0.06448263948362681, 0.07601193332624051, 0.05274376696756771, 0.041487495369848706, 0.03055455309579209, 0.2530892959405338, 0.16756068134019453, 0.20351236025171898, 0.12123525262840333, 0.07690925211195024, 0.13155696973685296, 0.15140649171606188, 0.18618705201773875, 0.2320403560635544, 0.24620483148722883, 0.22091286767634655, 0.5553563804395738, 10.83495238134938, 73.03656439627372, 44.47966990932342, 42.98569402387066, 45.756370021450905, 62.785147928422504, 59.0916637451418, 74.67015312563989, 69.79321925870835, 73.78619209412606, 64.62252340009137, 67.7948893270185, 62.88463492547313, 57.27392758092573, 0.7973229224162718, 12.666438414204507, 2.332443306522985, 6.401738111049899, 42.339020698301255, 40.057676069198116, 56.79540234227335, 62.29524389390023, 71.19701200915922, 68.80585670471191, 70.19981999551096, 65.16464202634751, 63.62887328670871, 58.94930131973759, 60.622203965340894, 60.55677098612632, 61.072625421708636, 53.139643515309984, 50.181897917101466, 45.987334866677564, 46.47565426365022, 47.64402243398851, 45.77144369002312, 48.9987620230644, 55.590383545044936, 58.425292276567035, 64.60149557359757, 63.57672929763795, 62.19044208526612, 54.90586719205303, 46.51494856803648, 51.85092526097452, 61.4956412776824, 60.62654210675148, 57.626325084317116, 53.19274064033262, 47.81105656777659, 46.61075638186547, 48.28499655569754, 55.19393782461844, 54.24479484558106, 50.47414979627056, 45.94059590370425, 46.00743701381069, 44.30230033013129, 53.05901527404786, 56.473109029954486, 56.126230301395545, 58.93724003145772, 58.29100601134762, 61.6245029049535, 57.87562701009936, 59.85154059625442, 57.33190021207256, 61.603302494172134, 62.001046519125666, 58.62274439104142, 52.203848361969, 42.03805723497945, 44.864642696995894, 42.56307040491412, 45.29009826721684, 50.70918213936591, 48.604842309028875, 40.61246002874067, 44.78292795919603, 41.96504231422178, 42.15650104707287, 42.92236343506844, 46.45264171784925, 52.763111668248335, 62.41668439680531, 63.68540640800231, 59.62818122679188, 63.17993448626611, 59.260325662551395, 58.0959818440099, 60.09901861990652, 55.62437480495822, 57.54921520909956, 57.13374207096716, 50.01011379303471, 46.19018416250906, 42.36362572639219, 40.37648631680397, 46.77480951432259, 48.267942090188306, 52.476256970436346, 54.608539765880955, 50.727268188230454, 46.22867830338017, 45.24344951875749, 51.39720116892169, 57.05487889628257, 58.42067956924439, 58.20115627781038, 56.61041552020658, 54.39573157218195, 61.60600500722086, 55.60701047220538, 56.75443318582351, 56.16658756809851, 57.39433257810531, 59.359381198883064, 56.29323697859242, 53.44902438502158, 49.16055194793209, 44.56337328880064, 44.59738416056479, 43.35428307133336, 45.517772243868926, 46.57215633699971, 49.201336752983835, 47.01743164370137, 54.74264560207244, 60.03949273017145, 64.66380242378482, 63.07716838775143, 60.61057413777998, 55.11673773488691, 68.25590118285149, 63.22440631927983, 65.61900938710859, 63.69802859521682, 61.90540344484391, 17.313210541202178, 2.1943506261994763, 4.389918658041186, 6.387724463016757, 69.07663360718759, 63.318653029780236, 70.19410902454008, 69.15132338000883, 69.94806658837103, 68.3648410920174, 65.0304969664543, 60.080544256394916, 45.44960929501442, 35.08192200814524, 50.73492073243665, 69.16600873393398, 7.880372135869919, 0.5982698680412385, 0.22761109615525893, 0.15793864765474874, 0.21317124276632266, 0.20069949989837987, 0.1032391348252854, 0.10870721761978443, 0.3386585132008599], [0.054174271457257776, 0.0618264134672861, 0.10837555517472568, 0.03521124727182812, 0.017234693439076507, 0.07184761726567823, 0.04518548221958261, 0.05745379426967233, 0.08067902523062884, 0.03596469091491834, 0.07967812369667715, 0.10639040685829618, 0.6989503075038234, 46.66961154630108, 46.67634233351677, 41.94233571329425, 25.237129811317693, 45.47624218848444, 64.27195764357045, 59.83228568107852, 61.68173813050794, 59.821291277485514, 60.919911861419685, 59.26918237440048, 49.34424831021217, 55.112270155260646, 3.326121121644974, 1.7188123950073797, 1.2802291421159622, 1.0923186833820036, 10.846168398857118, 47.51866740565146, 65.65480885967132, 59.53166738633187, 59.35435664269232, 53.19672969079787, 55.22639936016452, 52.03352335960635, 52.181114304450254, 48.271864460360625, 47.72871817311933, 44.36175953957343, 42.80115042963336, 41.58655712681432, 42.098481347483975, 42.72247160634687, 42.25259127155427, 43.046863386707926, 44.14615861831173, 43.577269815629535, 43.95826924231745, 48.44465271119149, 52.79651849500595, 57.372751697417236, 56.146924726424686, 57.619586452361084, 53.327497589972715, 50.52410902515535, 55.17805614779073, 56.93932979337631, 51.31192491900537, 48.187235401522734, 45.77646824621385, 44.275028090323175, 44.51331600066155, 43.89668803061209, 47.568512885801255, 43.8242575430101, 41.206040151657604, 40.063206611141084, 42.68720557612758, 46.27626842068088, 49.943017728867076, 53.42882810100433, 54.809749510980424, 54.10502510686075, 52.32310802705827, 55.208991881339784, 55.81822226124426, 55.843121467098115, 56.77946575226323, 57.11443616497902, 49.015604680584325, 41.49154163176014, 42.983701459823116, 42.69267728251796, 43.610751167420425, 41.95103553033645, 45.39505304828767, 45.06461689549108, 43.40012381153722, 43.764837557269686, 42.47094177430676, 46.135200377433534, 42.45293417284566, 42.81855398608793, 45.13752198988392, 54.236914803904874, 57.09130987044304, 55.66728161227319, 53.41782193030081, 53.429636109259825, 53.366007420324514, 51.6250281180105, 51.78848897257159, 50.939095789386386, 52.43062411585162, 44.66226800795525, 44.117729279302786, 37.49874138063, 38.255519559306485, 38.19516212709489, 41.13167201319049, 45.46310617077736, 44.8453014896762, 42.77662384894587, 42.2252288172322, 42.73855724642354, 46.44290639508156, 53.91204057201263, 56.527594674018125, 50.198105150653475, 48.177857014440725, 52.36760731666319, 52.300170006290564, 50.309531842508626, 47.07851079202468, 46.05902794868716, 46.59212512354697, 46.600424858831595, 46.88928388780164, 41.31905148106237, 41.102246392157774, 39.53680099979524, 40.67930113884711, 37.98029861142559, 41.872458688674435, 39.28614977867373, 42.43931178123721, 41.86405304939517, 43.40832548756754, 46.64770903125886, 53.816734821565696, 54.66193891340687, 60.841025152514064, 56.28694157446585, 59.73080611998036, 60.75849456171836, 63.14521758787094, 60.8458653573067, 39.15982200253395, 5.006728528007384, 1.388275241178851, 1.3369120489205084, 16.563137654335268, 59.53123984798309, 49.07449906872165, 61.17948255231304, 55.430288084091686, 60.05094212870444, 45.78495625526675, 48.63542502926242, 46.404851559669744, 33.27926735724173, 30.450091169726466, 49.45536121245354, 37.1913452302256, 0.2000364507999151, 0.04041438238815435, 0.028188283697912292, 0.10344919613412312, 0.015393261302022204, 0.07796037837021774, 0.059240024026122794, 0.05946040070886093, 0.07774631808241529, 0.016983786237335975, 0.026111440402605844, 0.03007360309692881, 0.03148274522485032, 0.050211329268471855, 0.030645683084824876, 0.07662735473845275, 0.058293250434461145, 0.04837852519666476, 0.031784202738274495, 0.06572131172663744, 0.10310863174738423, 1.4474842769484368, 56.395599072979344, 53.23720855097617, 42.8218448546625, 34.18513090379777, 55.01921584529262, 62.86276378939229, 64.32221105021816, 66.8221023005824, 68.82073033240535, 64.749553280492, 66.15075726662913, 55.87008383966262, 60.32340957272438, 2.955067845121507, 0.922252863885895, 3.0007134474092916, 0.8716422151173315, 13.899931657698847, 49.494894781420314, 69.17918789771296, 61.07576331784649, 62.87452697753907, 57.24894992766842, 58.81763519779329, 56.247439384460456, 54.88197995770363, 51.648174024397335, 50.99646437552668, 47.9505713524357, 46.51597622902163, 43.63252816661712, 44.33178086434641, 44.86021041870118, 44.293694649973226, 43.750528750881074, 44.57913337215301, 44.92441569605182, 45.58391124971452, 49.29003723206059, 54.70287276852516, 59.48832911829795, 56.66689372831776, 58.22788723053471, 53.544710605375236, 52.7605660500065, 56.79066019673502, 57.50289593973468, 53.18317005711218, 48.423420921448745, 48.546398993461366, 44.48456502729847, 44.49753238308815, 46.20359474612821, 48.8001920330909, 46.94631907247728, 43.06736169322845, 41.355066683984575, 44.084318530175, 49.24205880011282, 51.900049025012606, 57.726557331700484, 58.87890654225504, 55.981020235246234, 55.17462015151978, 55.98464450528545, 55.32835745042371, 56.74817700539866, 60.02073595600744, 58.95165866421115, 54.91562212667158, 43.8140280016007, 41.91080770184917, 42.84361793148903, 42.95067902534239, 41.706193339440134, 47.15047059520599, 46.8063336033975, 42.16076858582036, 42.91428335251347, 44.47291558788669, 46.58072671582622, 42.86140980259065, 43.286512359496086, 47.428684311528365, 58.17144432375508, 58.64270925521851, 57.71221322398032, 54.4172183159859, 53.425694127236646, 54.24519100496846, 54.340920371394006, 53.349211831246656, 53.84499157628706, 52.42466995793005, 48.68979692459107, 45.23037233660298, 40.63695915283696, 40.059511738438765, 39.05254125595093, 43.384049938571074, 48.49503947842506, 48.14718015732304, 45.33276188758112, 44.23251744239561, 45.32012401088592, 47.74451355780325, 53.70790473876461, 58.245635955564445, 51.42633261219148, 51.884787082672126, 53.71038759908369, 55.36595336852535, 53.03644203370618, 48.31794446514499, 48.54193533620527, 51.34664573977071, 49.36025158051522, 47.20998079546037, 44.744300457739065, 43.459481039354884, 41.91318073580342, 44.0021409526948, 41.69149229603429, 43.736384684039706, 42.137669747875584, 44.1747409297574, 44.366470306150376, 47.196346636741396, 47.92014160463887, 55.721928073513894, 56.31265271094538, 62.933225247167776, 59.14284675352035, 62.34017856659428, 63.103275683618364, 65.55878139311268, 62.465380622494614, 41.481896523506414, 5.496272194770075, 3.794313366374662, 0.942596236784612, 18.958113347330404, 69.17069988866007, 56.310593466604914, 67.26387100835001, 59.58987143731887, 66.11722100165584, 52.628507691044966, 52.01301720834548, 52.273909737986905, 40.5364994079836, 24.00480935650487, 56.495093914770315, 46.182461015639774, 0.8698697940957162, 0.10389101436181415, 0.08394071351616614, 0.02865537899666496, 0.03749601640588334, 0.038355049947577144, 0.058095032844932816, 0.035530269266136234, 0.07391937182194765, 0.15238500049998685, 0.15387548584370844, 0.23166895663786322, 0.1100217861934535, 0.17029725465803378, 0.15272293720514546, 0.2540096280074889, 0.18859161815095335, 0.2076108540378271, 0.13798400309057007, 0.36227694261939297, 0.4621773820009924, 2.4201867272776942, 68.83363493027227, 63.076634945407996, 54.496685535677024, 36.11561167624689, 60.31549815208682, 75.54439452386673, 71.30834456413024, 72.98596582105084, 74.29468031852477, 70.67839622497559, 71.86843549051594, 60.75105774787165, 69.85378849890925, 5.022753371346382, 5.651143058653801, 5.742123415393214, 1.3548013664061025, 18.22362207597302, 53.43326037929904, 69.17958797947054, 64.52964167441091, 65.07407057669856, 57.68548227125599, 61.09882685445971, 58.566352475074034, 59.139948121963016, 55.17924462595294, 53.76271593955256, 50.90609688912669, 48.37525813810287, 45.60239738033664, 46.10946570673297, 48.23688084079374, 47.21913168507238, 45.7723536799031, 47.14129617137294, 46.72721547465171, 48.125018765849454, 53.53530476170202, 56.83702261217179, 63.79024744033814, 60.62538892992082, 59.86356658320273, 56.551203420085294, 52.45951237217073, 59.58539601295226, 61.49332707928073, 56.04218567571333, 52.59908599238242, 50.44801112144224, 48.132235926966516, 46.8910881780809, 48.110537375173266, 51.69245366127261, 49.18647097003076, 47.08602213090467, 45.34201475881761, 47.201343736340924, 51.47682528341971, 54.994500990836855, 59.97147098664315, 62.18213450524115, 59.74995120879143, 57.116581701463275, 58.968854335046586, 59.4215036976722, 60.142156847061656, 64.17565953346991, 63.243065034189534, 54.97913706687189, 43.041015132781, 41.13397836685181, 42.6493311697437, 42.35628697179979, 42.47924150959138, 49.63464098591959, 48.63134968665339, 42.594174800380586, 42.98488601561516, 43.011962136914654, 47.12744235992432, 42.371788178720784, 42.49669997922836, 46.63166653725409, 60.92136313838344, 62.038469852939734, 59.56911817673714, 58.06798788809008, 57.25418629184846, 56.837214808310236, 57.72148178469751, 56.76590219620736, 57.50683007701751, 55.28638808957992, 50.277709653300626, 49.105560318116225, 42.688609784649266, 41.87971115112305, 41.765217165793146, 45.541039743731105, 50.01550705202165, 50.234049750912575, 47.19369903687508, 47.60252375756541, 47.15787603009132, 52.26594340416693, 58.648914444831114, 60.26787273345455, 53.45253098395563, 53.01160950814524, 57.089803680296875, 57.313461149892504, 54.74434398835706, 50.52858052715179, 51.07760644728138, 50.40203702065253, 50.85402742508919, 51.264958458562056, 45.68619097432783, 45.377218031114154, 43.264339200911984, 46.51152826124623, 43.36004111074632, 46.789883182894805, 43.51050323055637, 48.83738002469463, 46.65640100356072, 48.397737241560414, 51.100693518115634, 58.226381040388546, 58.95718528378395, 65.79600241876417, 60.514927141128055, 66.22294456728044, 65.41485786437988, 70.08399240432247, 64.27335400735178, 48.89638031682661, 8.919159904603037, 6.070365492374667, 2.9953760821973128, 19.324894182143673, 74.63407516479492, 57.61989631960469, 73.50182810137349, 65.27970867772257, 70.90189287739416, 58.572906755631976, 60.64635007612167, 57.604873641844726, 46.36488260761384, 43.19585069533318, 63.765136426494976, 57.86348727441604, 2.056457986754756, 0.3253653861822621, 0.16416231530808634, 0.12143017603985726, 0.22107152448546505, 0.14501836030713974, 0.15611402540197297, 0.12729720678180456, 0.19744534225713825], [0.040445937549755465, 0.04067915769654416, 0.06884895760806338, 0.019867239677677714, 0.04245939664542676, 0.05322994551651421, 0.06021235431093843, 0.0895017993846728, 0.058867961934377114, 0.06722813006490469, 0.07007000982881555, 0.1032447885541666, 0.04898435135762538, 26.731413602828983, 50.76497393269693, 38.64824687280963, 31.52315162843274, 40.84447606917351, 58.81589758780695, 61.09001721105268, 57.62478751520957, 58.397251252205145, 55.99172830581666, 58.89112864771197, 53.687073030779445, 60.308857579385084, 14.160376056548088, 2.196800146372088, 1.3577387313688956, 0.05470267294215099, 4.019663583847785, 37.47182607650757, 66.9325013314524, 58.47523973834131, 60.85589485783731, 55.25562101794828, 51.814423684150945, 46.230937588599424, 43.47860259394492, 40.54763893927298, 43.48655716065438, 42.064588146824995, 42.69848239037299, 42.79803214534637, 44.43349184528474, 43.98440791714577, 44.66709252326719, 43.15190838229272, 45.50985297849102, 42.168774143342056, 44.712137022326075, 42.75384664535523, 47.20559166323754, 51.14599689360588, 56.036286430974165, 54.43093876684866, 60.0452390024739, 59.45264731684039, 57.59444405955654, 56.40054125939646, 54.340222189503336, 47.15324763328799, 47.11797375832835, 41.983614736987704, 43.86181423741002, 43.72928127165764, 46.41786598390149, 40.84798659047773, 40.90252714772379, 39.542817915639574, 44.22783413240987, 49.479632839079834, 51.331654440972116, 53.71713407578007, 54.457669719573, 56.60860338518697, 53.24473165696668, 55.08115007031349, 55.05687059894685, 57.25461383019724, 56.62289257972472, 50.52827458227835, 48.93948716502036, 41.62661237101401, 42.5806700798773, 42.307233810424805, 45.001706000297304, 43.43683327397993, 44.93649659618255, 45.52167500219038, 39.30120775776525, 45.287740922743275, 43.35824074283723, 44.68176611008183, 42.0871143187246, 42.738117940964244, 49.07531492171749, 55.23807625616751, 55.84938941463348, 54.02324761113813, 53.84862369106662, 52.39575424501973, 52.50354097735498, 54.95202564424085, 52.31770692333099, 51.0091846219955, 51.51726884226645, 50.61958735988986, 45.77552295500233, 41.689986105888124, 37.22722315019177, 38.784690441623816, 40.158261329896995, 41.280349454572125, 41.76803342757687, 41.504356015113096, 40.07747619382797, 42.959563193782685, 45.80113210985738, 50.83794962975287, 57.98051118850709, 52.46908295539118, 51.639266321736, 53.13245381078413, 52.445364382959184, 48.731354436566754, 44.2183929874051, 43.980152145508804, 40.12368563682803, 40.9076968316109, 40.80769992643788, 40.926763473018525, 39.75897189109556, 38.22679212016445, 39.59190637834611, 40.14323080739668, 40.23062121483588, 40.115154481703236, 41.50856079593782, 43.58138045957012, 45.38432536586639, 45.1919880220967, 48.92273079964423, 52.27731827766665, 56.854830172754106, 56.22887088406471, 63.062604627301624, 60.207731031602435, 64.02993171445786, 46.82957756903864, 10.81524835478875, 0.5329710461439625, 2.9202183215848865, 0.5749310913585848, 29.517457446744366, 54.07602702417682, 50.02639947399017, 55.79504889826621, 55.535509586334236, 56.59494569224697, 52.2876262664795, 60.58881675043414, 38.52231917842742, 35.54752303707984, 31.98465378053727, 51.90049617521225, 18.685675321086762, 0.36374044634642144, 0.10567694917441377, 0.04560077465289543, 0.08023349913738428, 0.013454842433753996, 0.03541068677159567, 0.051337352112656644, 0.038551222082347646, 0.016426309800496506, 0.028118194313719872, 0.05241211601382783, 0.05004069084421762, 0.07771945137891077, 0.032414428799623446, 0.012102641706024448, 0.08643197781977155, 0.10680758769834235, 0.05208455980004323, 0.05918053346836279, 0.04173589937929665, 0.02422845565653857, 0.07183900643740931, 36.12501359754993, 58.60345809690414, 37.65901334824101, 37.622350954240375, 53.10282030413228, 64.45315545605075, 69.90448121101626, 63.8064899752217, 65.79486100904404, 61.96916549436508, 65.14876034951979, 58.09153387623449, 65.20314401195895, 15.947461839645142, 1.1575796911793372, 2.6307888329029083, 0.01945506139177709, 5.821200359252192, 40.71365717918643, 68.52126521448936, 60.09827336957378, 63.56533481228737, 57.06099779375138, 54.373346605608546, 48.58020590197656, 46.02757446227535, 44.88872212748374, 45.73309859921856, 43.65770586075322, 45.07616827564855, 43.87297338055026, 46.82936183867916, 45.4198149711855, 48.060013324983665, 45.31133790169993, 47.10602621878348, 42.85826798408262, 46.90313377688008, 44.74493195933681, 50.08335228889219, 54.076725206067486, 57.61102391827492, 56.300877755688084, 59.99407168357604, 60.01981419901694, 58.81800390058949, 58.68292531659527, 54.825435069299516, 50.16771462655837, 49.44910110965852, 44.5424239097103, 45.29741348758821, 44.69608276121078, 47.301226892778956, 43.69419567046627, 45.184476683216715, 43.42589770593951, 47.203030355515025, 51.40756014854678, 53.991699987842196, 54.79686452496437, 56.835026125754084, 56.704501413529925, 55.62132320096416, 56.983993822528475, 57.1204883821549, 58.30833112039874, 58.617535483452585, 53.35607205667804, 50.278941277534734, 42.122450951607, 42.12760102364325, 40.94452788752895, 43.435895827508745, 42.666966146038426, 47.91341866216352, 45.90329808573569, 41.845712046469416, 44.68112284137357, 42.05325641939717, 44.19452928727673, 42.57031502262239, 41.65424939124815, 49.826994019169966, 56.54692803659747, 58.05919785653391, 56.358034533839074, 55.875563390793346, 53.28446918918241, 55.18652846736293, 57.0600603472802, 54.134466417374156, 54.13041460898615, 54.74323787996846, 52.232599335332075, 47.1020842367603, 43.08823654728551, 40.62904380982922, 41.24640918547108, 41.9158479475206, 44.11787048462899, 45.38043045228528, 44.10720163776029, 41.47302804454681, 44.27218437194825, 47.39968622884443, 51.99686488797588, 57.4211694348243, 54.09128112177695, 52.67348550981092, 54.73538921725366, 53.4131190084642, 50.696583486372425, 46.735828999550115, 45.87670049359722, 42.538159431949744, 43.36137079423474, 43.47329954947195, 42.26296594066005, 43.66973577007171, 41.34649630515806, 40.65114244338005, 42.28906539178664, 42.6048985604317, 42.892423983543154, 45.28991783818891, 47.53862442508821, 46.58957166056479, 49.22960919718589, 51.49891214986002, 56.90012570350402, 58.59723721781085, 59.05236944075554, 65.98659038543701, 60.81847544639342, 64.1308896003231, 48.00035799703291, 12.315296069268259, 1.0461798430450502, 6.95400587012691, 0.021219425083648775, 33.475279961862874, 57.56499882667296, 55.753816943014826, 63.06156519920596, 61.23422707280805, 59.20004275537307, 56.86015282907794, 62.82476386716289, 48.17890036490656, 41.51822159367223, 25.7155805249368, 63.15731417748236, 23.206634483029767, 0.2961997447475311, 0.022327525300845023, 0.08335941366010136, 0.08104549105008764, 0.03959564890171732, 0.05003900162034458, 0.0947554158647695, 0.025364158021646644, 0.02279485234119479, 0.13662310918011975, 0.12465781937803953, 0.19224760423023857, 0.24462465256933244, 0.14061441194386254, 0.135659278640824, 0.14339500467383093, 0.12579063359167308, 0.1431886971958222, 0.18590767507351216, 0.15083518930740897, 0.21261284127831462, 0.2496359094737038, 43.56075663720408, 69.05234629108061, 50.0550288538779, 44.45330373702511, 56.39028426139586, 73.13620044339088, 74.64131586013302, 71.03265685419883, 71.34612483362999, 69.07483716164866, 69.57593564064273, 65.38469091538461, 70.06703207569738, 20.481483474854503, 4.076432537647986, 6.2624571977123145, 0.172339691029441, 8.603954315185547, 47.3911472289793, 68.35309751572149, 64.59467064949774, 65.21501702647056, 61.52278407927483, 58.33040621972854, 52.616905320075254, 47.27954403046639, 47.14985870545911, 49.500919542004986, 47.932932453770796, 47.471630342545055, 45.27341250450381, 48.45212874873992, 48.13527184147989, 50.37031681306901, 47.92364035883258, 49.86139712795135, 46.21869194892145, 48.94701027101087, 47.98011464457358, 52.38061781852476, 56.27794365729056, 59.82650018507435, 57.420122161988296, 63.18527283207063, 58.88503328446419, 58.75460270912417, 61.59412807033908, 59.07751967830043, 53.04646368949644, 51.82742634127217, 46.37763423304404, 47.50683361484159, 48.430842045814764, 50.23386539951448, 45.77586027883714, 46.61442379797659, 45.43759115280644, 50.38502570121519, 53.82799986870059, 56.77473537383541, 58.95663222958965, 58.59470336667953, 61.3483327434909, 57.87252441529305, 60.195179447051025, 61.9492280867792, 61.07382958935153, 61.63040607206283, 55.44247488821707, 51.28379368012952, 42.15910550086729, 43.20598609985844, 41.06867482585292, 44.606327164557676, 43.60893118766047, 49.372238343761815, 48.71630037984541, 40.435827855140936, 45.65433348378828, 43.690924413742565, 44.873785741867565, 41.58516468540315, 41.558410198457786, 50.59361342460879, 59.17768132302069, 62.0909119421436, 60.03193824521957, 59.235689255499075, 56.730581252805656, 56.61996649157617, 60.97056927219514, 57.33994107092581, 55.82188967735537, 55.48430696610482, 55.83920694166615, 50.988478429855846, 47.978165226597945, 43.501540614712624, 44.3185075636833, 43.177117455390196, 44.49617524300852, 47.04673959362892, 44.69682801154352, 43.58836620084701, 45.74559527058756, 48.34680134250272, 53.284371129928104, 61.137807369232185, 55.84534545098582, 54.920403495911636, 56.38560487378029, 57.65132627179546, 53.728203004406346, 48.186294032681374, 49.948724777467795, 44.06257683230985, 45.44583989727882, 44.64366812859812, 44.36790197126327, 43.96730246082429, 44.57485798866519, 41.99398548372331, 45.73724454449069, 45.85189934699766, 44.94392948765909, 45.86936958374516, 51.15696776297785, 48.70746720221735, 51.704742447022475, 54.433539298272905, 60.90054319750879, 61.94851813777801, 63.1596754443261, 67.22232526348483, 64.26765480349141, 66.09283170392438, 54.7835127768978, 18.18197238829828, 2.5290856967049264, 9.07072126865387, 1.8421412740022907, 36.27908822028868, 65.93681550795033, 60.69565819155786, 68.74971974280574, 68.11505671470397, 66.2437645081551, 64.47275161743164, 73.26846276560138, 52.68162835028864, 51.816369179756414, 46.94315764211839, 70.33139198057114, 33.54450195066391, 0.34659579696674503, 0.16324038977824873, 0.1478671501841276, 0.15874823405136987, 0.07427846787557488, 0.11801078089422758, 0.18862282857298854, 0.12530851147828564, 0.15274245712545612], [0.09204332671699025, 0.04742182693594406, 0.06314965798669765, 0.05907778575595829, 0.08339280743272075, 0.05417551251969511, 0.029997212639559182, 0.035466201333028656, 0.0765317393046233, 0.05508264106127524, 0.16537118673084245, 0.2008848472107803, 0.30806424036141367, 12.392115689093067, 60.22609164637905, 52.35623244316348, 25.3106624849381, 29.043162484322828, 50.30475047326858, 63.42400397023847, 50.77915722324003, 58.30672294862809, 55.61844025888751, 58.8396514615705, 54.15464308954055, 57.985810310609885, 32.01781153678894, 0.11766911334087772, 1.895296621707178, 0.17943700535162804, 1.6293877483375612, 33.760240154881636, 66.38872746498355, 63.68226851186445, 60.31283094036964, 55.22835662288051, 59.45871522349697, 54.26517940336659, 54.6393931296564, 47.44557403749036, 47.83360627389724, 47.4153325634618, 47.87055892329062, 44.097391789959325, 49.08573273689517, 48.19496639313237, 52.83461255411948, 49.87416444286224, 52.826242216171764, 47.04186016513456, 48.1747426525239, 43.73139150681035, 45.97343790915705, 46.794197790084354, 53.274906450702304, 54.87595911948912, 57.958212514077466, 52.548197161766794, 56.57124673166583, 55.36313318437146, 56.93476807686591, 48.71466082911338, 46.59747131409184, 43.48380365679341, 43.720020555680804, 41.46463025000788, 43.190932043137096, 41.55353076996342, 42.07311537957961, 40.89654945558117, 47.98446063072451, 50.35823591293828, 53.13583881624284, 53.484423775826734, 53.33752709050333, 55.95107686135077, 55.140652425827525, 55.719535427708784, 54.88365088739703, 54.90140745716711, 55.71580525367491, 51.92526594285042, 46.04814337145898, 42.466988025173066, 44.486812545407204, 43.447360915522424, 43.668229579925544, 42.002759825798776, 48.50354709932881, 47.33225676321214, 41.42906611965549, 44.265532032136, 43.494405823369185, 41.95160427401143, 42.388775963937086, 42.89166304372972, 48.89423085797218, 51.35940520994125, 54.16235839166949, 56.550324809166696, 54.24816808392925, 53.82489727389429, 54.49557158254809, 53.46727909580354, 51.7939999026637, 50.10410554947392, 51.24974750703382, 51.47655856224799, 47.48162454174411, 42.25252459126134, 38.64086497214533, 38.623924255371094, 39.673197500167355, 39.90190306017476, 40.16522353695285, 40.956871586461226, 40.1471806341602, 43.88117505658058, 45.720605850219734, 48.82261622336603, 55.90480858279813, 54.80785108381703, 53.006431979517785, 53.753321862989864, 52.776859575702304, 50.5271763186301, 48.210750010705766, 41.992836229262814, 44.22171131257088, 42.03101658052014, 41.353391831920995, 38.27453913227205, 40.5817674821423, 41.31093609717585, 42.263907309501406, 40.62408201156124, 44.40029290414626, 43.84837619719967, 44.38219116580102, 45.20951709439678, 46.8131624498675, 44.02070553072038, 50.35808686287173, 47.005127168470814, 57.023915706142304, 52.612841744576734, 61.97239752738707, 54.52755458893315, 60.46666237615771, 20.61099229320403, 13.448445277829325, 1.5353590971039188, 5.307779264065528, 0.6780136148295095, 36.5414555611149, 61.440637880756015, 51.724570028243534, 50.70065098424112, 53.97250783058905, 63.40919702283798, 58.699152161998136, 51.617367729063965, 36.47166090626871, 22.516501295951105, 40.93678512880879, 51.66050595621909, 4.300151784573832, 0.17841053946364313, 0.2134669373833364, 0.047512064432545055, 0.02329639478346273, 0.07569864166960602, 0.0355175024108781, 0.03055498593546931, 0.027583365351141944, 0.025558989502549655, 0.026509823360209985, 0.04118047797331407, 0.030173389879505963, 0.017689065932626688, 0.011077180350830239, 0.0034573006973181285, 0.0629462999471974, 0.027461980634759513, 0.04784504837927319, 0.1013977735513641, 0.16355289236432122, 0.2107115795895938, 0.314019869171804, 16.95101103475017, 71.2109991811937, 48.12214366851315, 31.773381194760724, 45.164578499332556, 55.87618312528057, 71.14853935856974, 55.49494835638232, 65.99177575880482, 58.80095335745043, 65.48221672734907, 57.960209000495176, 63.33589969142791, 35.33040808093163, 0.14808315633525773, 3.1700615344509004, 1.286256721904201, 2.3944363670964397, 36.68877978478709, 64.69123548076999, 65.8201563742853, 62.83952374612132, 57.44987333974531, 63.61882809669741, 55.71192602957449, 54.601444198239236, 51.056566853677076, 50.2914850173458, 47.83334347509569, 47.89377935471074, 48.3912221847042, 51.25084969305223, 49.90553163713025, 54.21509073626611, 54.00261986640192, 55.69163168630293, 50.42755988336379, 49.029544784176736, 46.03269315535023, 48.95054040416595, 47.4133909902265, 55.11498835779006, 56.93161841361754, 61.33030945254911, 55.01781163677093, 57.150404299459154, 58.889524398311494, 58.971046939972915, 50.32523309030841, 48.99955041946904, 46.20595209060177, 44.78976857277655, 42.63325729677754, 44.95400213426159, 43.949255635661466, 44.79431852217644, 43.25161895444317, 48.87905520777549, 53.70098567778065, 57.26509832566785, 55.104786272971864, 54.84948312082599, 59.18773435777234, 56.399784241953206, 55.44459296811012, 58.152130573026604, 59.3373296337743, 57.12985107975622, 54.465647820503484, 48.58496765936575, 40.73351613936886, 43.89790004299533, 44.044247596494614, 44.549099783743586, 40.63271514831051, 49.818811954990515, 49.63654725782333, 42.75802396958874, 43.33254921820856, 43.475813788752404, 40.877447512842, 43.11688553902411, 42.46835693236321, 47.30574546321746, 53.391051753874756, 57.44562149047852, 56.52093841183571, 56.31515910548549, 55.93649741142027, 56.16639929433023, 56.46191066311252, 54.60401727307228, 53.27528299823884, 55.25117305017287, 54.4102051181178, 51.481716479024584, 44.557175943928385, 40.777756552542414, 39.91629423633699, 42.1836869947372, 41.99096525869062, 42.60003482141803, 43.610755089790594, 42.38342585102205, 45.179091268970126, 47.86988819799116, 51.44155533083024, 57.31822682965187, 55.74739210067257, 53.85269118893532, 55.10975591598019, 54.853531006843816, 52.98452161973523, 50.64781665802003, 44.7380756562756, 45.38257598876954, 44.206963200722974, 43.56598123427361, 42.547110280682965, 41.84190342503209, 43.3955228713251, 43.70000470069147, 45.08278139175908, 45.89866184419202, 46.206156053850734, 47.7159430134681, 48.74305878916095, 49.635327400699744, 47.930296621014996, 53.72010723237069, 50.15833623947636, 58.815462204717825, 55.50357757076141, 64.76658813415035, 56.012862036305094, 61.28363324749855, 24.82901700081364, 15.982216000556948, 4.260916315740155, 6.891891216078113, 0.38267388038577577, 44.13241855559811, 64.14653985731064, 57.46190717143398, 54.76795273442423, 60.76683744307488, 67.34495424455213, 65.67207513316986, 54.89982674198767, 51.098551904001546, 28.780669627651093, 37.55644729060512, 63.189967909166896, 5.342820738592456, 0.11402949856053438, 0.09227987934624957, 0.1607087449801545, 0.03111639048814053, 0.1278960883557316, 0.0065211635345833446, 0.0022659006278826707, 0.011943365323297199, 0.04538095338390239, 0.13436023866938007, 0.14642178741914613, 0.14080699112626816, 0.19658262000208904, 0.2252716321738497, 0.1335908412452667, 0.15214775839159567, 0.11149114283222346, 0.29287657790607025, 0.27984122415223434, 0.228923833778789, 0.39126558710009823, 0.544991149537025, 23.420182043506255, 81.6840099519299, 63.46626358647501, 35.45606513177195, 41.21038221543835, 64.98928462305378, 76.91769476859801, 64.57828298691781, 67.70673013502552, 70.95407609016665, 69.97508387411796, 65.6539459382334, 66.8698061666181, 41.11287601532475, 0.3352849684174984, 8.225979035900485, 0.6621759420921726, 3.6485978047693934, 41.018684218006754, 65.14778760171706, 70.89948454210835, 65.19961387880387, 60.33447850135065, 65.53481178898966, 58.59981029264389, 59.30224795495311, 53.87175783034294, 52.08347474375079, 51.33139556454074, 53.426568815785075, 49.36357775042134, 54.75994325453236, 52.43957888695502, 57.7864166229002, 55.29850036867204, 58.98985862731934, 52.526977139134566, 53.769293754331535, 47.72639220760715, 49.13887693035988, 50.16459634227138, 57.18602726536413, 58.731617619914395, 63.08048671291721, 54.35294635834233, 59.55843756275793, 61.263660538581114, 61.12234146364274, 52.58223941249233, 50.25091986502371, 49.1290121693765, 47.52256231923258, 45.685873262343875, 47.87965489972023, 45.97876841022123, 48.05553790061705, 47.082531221451305, 53.256753721544825, 56.495341024091175, 58.55639357720652, 59.01368310374599, 58.1396064450664, 62.69705149435229, 60.12314511883644, 60.2226125040362, 59.90660675110356, 62.08539708968132, 61.95664921114522, 54.80505051151399, 48.944131251304384, 42.58537300171391, 45.31247931142008, 44.06603636280183, 44.79601298609088, 42.36102519496795, 51.8721374388664, 51.76228361745035, 42.09454721020114, 42.69955319743003, 43.9283101789413, 40.93529070577314, 41.516358467840384, 44.26243335969987, 48.16716463335099, 54.50483622089509, 59.61382142959103, 60.18359668793217, 58.769817583022586, 58.32583665847779, 59.79396412449499, 58.59404048612041, 56.42049435646304, 58.90977951788134, 57.125854184550626, 56.69480139209379, 53.33339291234171, 46.89978407275292, 42.64261999437886, 42.92437953333701, 43.111190257533906, 42.747672834704005, 44.67073640515728, 45.00606375355875, 43.24282107814666, 46.701924031780614, 48.69602957079488, 52.960297061551, 58.1152367591858, 58.229381653570364, 57.620374848765714, 57.4824054779545, 56.774923647603686, 55.9221415365896, 52.77925614387759, 47.195350354717625, 48.73488849209201, 47.29223682034401, 46.042852094096524, 44.475774995742306, 44.45955599507978, 45.93863864098826, 44.888977081544944, 46.23274972361904, 47.4917717133799, 49.109823934493534, 49.852152101455204, 52.60375753525765, 52.02532952831638, 51.427317127104736, 54.677785288903024, 52.17075924719534, 60.66160417372181, 57.694531179243526, 65.79245267375823, 59.766825245272734, 62.45726131623792, 32.64482986542487, 18.766321213014667, 7.196754986240018, 10.65667183168473, 0.5696688640502192, 48.994298365808305, 69.68810758283063, 62.15345021217101, 61.393977365186146, 64.06510360779302, 72.9321038338446, 70.29342343730312, 67.39287776331749, 47.754586204405754, 33.12299228483631, 53.72442968430058, 71.756467511577, 9.245127497180816, 0.3843481808660492, 0.30821123731232464, 0.27230337863006904, 0.12956819016366236, 0.1810503099113703, 0.10616149212564192, 0.14708161894832888, 0.16175005765211198, 0.12879981929736753], [0.02842459692469528, 0.04630813044646094, 0.02417352906758747, 0.03636954156982322, 0.030042283507364414, 0.03509336932291908, 0.016679363963644833, 0.03272328480717636, 0.07067264523357153, 0.13253886462940326, 0.058188836480821335, 0.0948082146445109, 0.1376166486091191, 3.0654931068420415, 50.33472130375524, 43.071256606809555, 35.03136657899426, 29.66428941295993, 41.75299506033621, 67.41789464027651, 61.21050065563571, 39.14337158203125, 56.3479148187945, 58.583571680130504, 58.75441051298573, 54.025506896357385, 43.27365875244141, 1.203898102525742, 1.9092058366344822, 1.4658358212440246, 1.0465733058029607, 25.984211890928208, 64.04247545426892, 54.380497086432676, 62.737851988884714, 59.8316502571106, 61.58503209390948, 59.429783821105964, 58.899075369681086, 58.21154271402667, 57.21166779918056, 52.77406684813961, 51.89137274219144, 49.32342836933751, 53.36517980021816, 54.08707634095223, 59.002551417196955, 56.6408178114122, 57.962099582918235, 56.34796580960674, 56.610086041112105, 54.55338731888802, 52.122549395407404, 47.43853730540122, 51.05518225700625, 54.36301116020449, 58.720313349077784, 53.516532298057314, 55.69570702891196, 61.00845936805972, 56.03310538876442, 51.595508360093646, 47.75828107710808, 44.786109001405784, 43.36270047772316, 41.421813657206876, 41.07346796220349, 39.74742835567844, 40.81805498369279, 43.967796679466005, 50.691656989436, 51.95360114497524, 52.848387918164654, 54.83766894186697, 54.018819255213586, 51.33450208171722, 54.07639572697302, 54.52257710118448, 51.815012039676795, 54.499215464438166, 52.34564204369822, 48.158123570103804, 43.98525514910298, 44.45419411505423, 43.41754305747248, 42.25115568407121, 45.265010787594704, 42.323150788584066, 49.5628616117662, 51.23567796522572, 42.401217722123675, 44.68189554829752, 42.66271429677164, 44.30734057580271, 44.69580035055838, 42.52803971690517, 43.80506930812713, 51.86534389372795, 55.57394881402293, 55.40658912351055, 54.92658907367338, 53.88011247880998, 53.771737390948886, 52.65659970621909, 53.54763277115361, 52.12975478941395, 49.89213674299179, 53.830890655517585, 51.564368663295625, 47.9130107356656, 37.967327333265736, 37.33815954577538, 38.914591496990575, 38.62926260117562, 38.976149174474905, 39.37940020715037, 40.87750634839458, 42.68806457519532, 47.21373450371527, 48.819564619371974, 54.718785824314246, 54.90827160496866, 50.63276260129867, 54.057917441091234, 53.873891599716686, 52.25029706954957, 47.33365312699349, 45.41072683949625, 41.619936496980735, 40.43940113436791, 39.92913999865132, 39.44619817118491, 41.49429905799128, 44.70942274216683, 47.76620426485616, 51.47917086078275, 48.79780330965596, 49.98663448518323, 46.5302615011892, 49.530921751453036, 49.18935783447758, 49.48871312602874, 48.676507934447265, 52.062748939760276, 54.154042966904186, 56.52561779945128, 58.350790777514064, 55.961176964544485, 50.77989462883242, 16.604073470638646, 9.18840806330404, 3.5361763017792858, 4.07728418227165, 2.702617236683446, 53.58687608472763, 49.44414323376071, 55.5673788439843, 54.769878618178836, 59.834964659906205, 55.320112628321496, 53.01377073411019, 48.89598807980938, 30.565446115309197, 32.79821611219837, 45.36578039969168, 32.372321236518125, 0.22497599884386987, 0.08052072082195552, 0.025914153609905514, 0.015660470854791424, 0.1112680963330692, 0.031870636608331435, 0.030950367743630084, 0.012408127884320434, 0.07178303605366139, 0.14163704739222605, 0.02948025842347453, 0.056276060490598606, 0.036477004553401665, 0.006090095435689774, 0.033377317050772334, 0.048025940890393914, 0.07950992143202214, 0.051423916217660716, 0.1103620671276604, 0.10235513830857892, 0.06295868758893301, 0.11228486354793273, 0.2786581086054925, 5.679515523295249, 60.69956487224948, 47.41072377850933, 25.117336703884988, 45.0348892519551, 47.27524903512771, 72.99732500506987, 62.30197075874575, 45.43438657637566, 64.04793147117861, 62.05947806758266, 64.6125135114116, 59.69286895567372, 51.25095951941706, 1.2825263027221927, 2.6198240922343348, 2.623454736125085, 0.8951826874286899, 30.22527071737474, 61.04017565327307, 57.48655534559681, 64.42229424753498, 64.27910812439458, 65.08252328441989, 62.609327685448434, 59.763757951797984, 59.96436365189091, 59.70875063250142, 56.19306356676164, 54.262692620677335, 52.28402160829114, 56.031885531640825, 57.57929586595105, 61.438355061315725, 58.628624023929724, 58.86071458939583, 57.410245633894405, 58.92530425902336, 53.96198018904656, 53.33311834642964, 50.28553870416457, 52.47778669480355, 55.93291628745295, 59.78197343887822, 55.37678303257112, 56.73682958849015, 60.87191381762105, 57.873085314227694, 53.516206741333015, 49.96789732287007, 45.693616021064024, 44.15734914041335, 44.990829267809474, 43.73293692065824, 42.500453687483265, 42.41058434209516, 46.41494774049329, 53.76825040386569, 53.0231765777834, 55.63332565369145, 55.997941340169604, 56.20719978886267, 54.7233828421562, 57.16549365751205, 55.927589708758944, 55.2173073061051, 56.88456173866027, 54.00456536200739, 50.62905988385601, 45.38760446733045, 42.519528173631244, 43.133033937023534, 42.676666167474565, 44.40315623437205, 42.18152969114242, 50.78895922630064, 51.89669539851528, 41.08482322385235, 44.635046758959376, 42.58314901782621, 43.927168769221154, 43.092151072717485, 42.24407972828035, 43.59635214651785, 54.458285531690045, 57.596067920807876, 58.517377761102495, 55.66021350122268, 55.580954167150686, 57.60588561334918, 55.47895685318978, 55.50898651922903, 54.44281570373043, 53.599608098306966, 54.97568930349043, 52.90337170324018, 48.7112287552126, 41.481304245610396, 40.10394827012093, 40.50332007869598, 40.44182515913441, 41.49606020219865, 41.48876851604831, 40.78417747251449, 46.8688012707618, 49.156872764710464, 51.156975607718195, 57.12077471517748, 56.16802707795174, 52.77580445812595, 55.35437060940651, 54.942317778064364, 53.15071636630643, 51.451247507526034, 46.98541333598476, 43.83474988322104, 42.54492944286716, 42.088997056407315, 42.15441042377103, 44.126342804201194, 48.70130123630647, 50.41186255793418, 54.20967394305814, 53.382018535367905, 52.39706039428712, 48.35175921840053, 52.89373051735663, 52.09088802337647, 51.222334061899495, 52.56482016655707, 56.47068108281782, 57.057106802540446, 60.40780328935193, 60.25359530602733, 58.88031075077673, 49.94856003792056, 20.98754571330163, 8.787802669309801, 4.593594103090225, 3.9434624727695224, 2.2337319581739368, 60.88503414584745, 54.277554481260246, 61.77921295166016, 59.74665249547651, 65.40290248009467, 62.328211415198545, 60.03235009408767, 54.499250765769716, 41.62650254464919, 23.84064247531276, 49.14903586910617, 40.81760783349314, 0.5669528678540261, 0.11522762943059207, 0.04540441482658348, 0.07003834741490503, 0.11336549951304352, 0.017550379120474382, 0.08285198766257494, 0.051452207844704397, 0.06698125057042607, 0.03494243468007734, 0.17642324610102564, 0.1838777565787877, 0.13811095918138183, 0.0997240552979131, 0.1662121367670836, 0.1407935233005593, 0.12084156770499484, 0.11609834198269153, 0.16834429735618253, 0.34748782974577724, 0.19403646549870893, 0.309154168973046, 0.5264497992973174, 7.008133107616056, 69.67949405793222, 56.99062262811969, 48.24047765424175, 43.1370347545993, 54.91335107434181, 78.28577826100012, 72.21585550615865, 48.76470635014196, 67.213405793713, 67.53347904451432, 72.16190722680861, 64.34667095061272, 58.19575125171293, 1.5152162553802615, 7.16471657637627, 4.410787628542993, 1.9416307225342722, 37.617628420552904, 61.982685904349054, 58.03085088729859, 67.53997448951968, 67.59972787672474, 68.32244027045466, 67.04259441744897, 62.622071466138294, 62.791670830019065, 61.993170399819654, 59.07524862597066, 58.55505212660759, 55.12263697962607, 58.69479048636652, 58.465261228622936, 65.33093875454318, 60.93314986075125, 60.48625461516842, 60.326790655812914, 61.54142710470385, 57.87572899172383, 56.53612582914291, 51.40555973975889, 53.56038439658381, 58.97981343730804, 62.84621923200546, 58.56763116775021, 57.72643181585497, 64.4884293310104, 61.58178829377698, 58.02768553456953, 50.13207989354288, 48.26593383666008, 45.89828529665547, 46.590638545251664, 45.29814304844026, 45.43952095893122, 45.217746227018296, 49.1178765604573, 56.6533144827812, 56.36417696552893, 59.230872584927475, 60.66570305055188, 59.53489549698369, 54.37150309162756, 60.00709003017795, 59.598618322803134, 57.08920748003068, 61.09331984673778, 55.074638935827444, 51.5096123756901, 46.27663712347708, 42.08069339875252, 42.70796668144965, 42.63475564218337, 45.64780273745137, 42.05636293657365, 53.771047053798554, 54.70876416852398, 42.09895595427483, 46.264007091522224, 42.13435534507998, 44.6091002802695, 44.046828516068004, 41.26639366149902, 44.2154747439969, 54.447714744075654, 59.27954135402557, 60.29931053038567, 58.848013954777876, 57.83243386976181, 61.09805806990593, 59.779820057653616, 58.70572213203677, 57.60527764597247, 55.21493819452102, 57.84366361556515, 56.401368879502826, 52.61566192873063, 42.16999007809547, 42.76985383802845, 43.08873861066757, 43.08527515780541, 44.72299022059287, 43.83125505139751, 45.42188206026631, 48.83631706237794, 52.096787268115634, 53.00706348111553, 57.674836958608324, 60.06572161951373, 54.969272305888516, 57.633455953290394, 55.99310898011731, 57.20022232301774, 51.13630471691009, 50.95236516767933, 46.24645840737128, 44.740982132573286, 44.88962427262337, 44.45066790426932, 45.382995682377974, 50.253712592586396, 52.54474939838533, 58.12233232682752, 54.91211552773753, 56.24761196874804, 50.00287702006679, 57.00222107671923, 53.15146946137952, 55.47199464613392, 54.00495367665445, 59.349434068126065, 59.130024525427054, 62.25382758725075, 61.26153461394772, 60.30420564836072, 49.21325291356733, 29.344680963024018, 10.504153409311849, 7.061678853727157, 9.708619271555255, 2.5958137935207737, 67.31985892018965, 56.2968377144106, 69.69672895246937, 65.05803200506395, 70.8041395679597, 68.7051773071289, 65.95238731753442, 60.22427166661909, 44.71825984216506, 43.70816323064989, 57.47738484413394, 50.38527281053605, 1.2722614599812416, 0.2775450747820639, 0.17944287358512803, 0.1180381149113659, 0.2752673421655932, 0.10380840710093898, 0.13560873215957997, 0.10773070832534183, 0.1174404897216347, 0.2170642870928972], [0.019743192805758408, 0.023093952219031995, 0.05899919279580636, 0.07013092914055433, 0.08575588224395629, 0.0546409109336955, 0.05563061992307344, 0.05807186251566295, 0.024852844127904505, 0.04303334205741844, 0.08568932452509481, 0.012552229980487498, 0.038125575970738165, 0.05462821302635055, 34.10997436892602, 61.408239103132686, 39.83494427896316, 23.817431849818078, 40.967034447577696, 54.47897211197884, 70.24788471960252, 59.78080849493704, 57.372524199947236, 56.041028576512495, 57.297928564010135, 52.50991090651482, 47.98309564590455, 8.093179348976381, 3.2132152059385857, 3.2929359088020944, 0.27290438992842553, 15.185755202847144, 50.67186078717632, 52.87939425437681, 57.304133753622736, 59.361820913130245, 61.025564824381185, 61.02564719415481, 59.06290884940856, 59.54418366955173, 60.456366154455374, 59.14338804060414, 54.386200212663226, 54.09057901751611, 56.241293030400435, 57.06756384141984, 56.65878226680141, 56.254519262621486, 54.470731212246804, 56.9923641604762, 55.478639141205825, 57.05814623063611, 54.65080330448767, 53.39899063110352, 51.20622096523162, 55.72445800227504, 54.08306767863613, 56.55577298133605, 50.62871863765102, 47.2750646837296, 57.362094617659054, 55.49724686530329, 49.092796925575506, 46.09609826918572, 43.37482060155561, 41.47211413229666, 42.22640160591372, 40.48128028069773, 38.77487667145268, 42.214222646528675, 52.96814572426581, 54.70613618050852, 54.06516990353985, 53.9895034605457, 53.992790406750096, 54.39130713862758, 54.147700494335545, 54.51532856110604, 54.77304789327807, 53.363336286237164, 46.351405343701764, 44.13565451099027, 43.179239457653416, 44.14325214201405, 43.17478756750784, 44.511448952459524, 45.351263707683934, 46.266948869151456, 51.53017736250355, 53.990915513807735, 46.37376285368397, 41.754148237166866, 44.3639168431682, 43.39069835601315, 44.543894798524924, 44.7251396794473, 43.60891942054995, 44.1086882160556, 51.76984594714258, 54.7564091990071, 54.405529652872396, 53.302751356555575, 52.62626801767657, 53.37845702325144, 52.28778708365656, 52.62298891621252, 51.898091762296616, 50.99237726580713, 52.34825826460316, 51.82814805738388, 44.31855070975519, 40.07740559116487, 35.93157406776182, 37.63933089471633, 38.52622978148922, 39.80686403089955, 39.21462928095172, 42.326575017744496, 45.750360950346916, 47.78242718788886, 53.327493667602546, 53.67350947472357, 52.26166802067911, 53.281735297172304, 54.67246263257919, 51.83550250145697, 48.93693762440836, 44.66215425922025, 41.75403448843187, 40.005453632723906, 40.38671978058354, 39.63084374704669, 41.4214135754493, 51.22853140677176, 53.357950871990575, 53.68050698311099, 52.14713481164748, 53.81036097003568, 50.69783864482757, 49.145835215045565, 49.630636245973655, 52.72536277770997, 50.9712984485011, 58.61704518718105, 56.39444589614869, 60.39920153156404, 52.846371819896085, 61.06033271358859, 44.425894214260964, 5.304876710138013, 0.33033217934350817, 1.2562980262502548, 1.1092240988246858, 5.9693021928110435, 53.63400728471818, 47.32603588411885, 56.43295572650049, 53.000901437574825, 56.60119402793146, 54.20160954998386, 55.90891922673872, 38.4530108974826, 35.169488922242195, 45.4418194678522, 54.01263759982202, 13.47790620019359, 0.2792504477885462, 0.14892979074389706, 0.0785380393086422, 0.09026936585864714, 0.08185280982645289, 0.04421622011690371, 0.012970873090859144, 0.022199441145564762, 0.04349335870375076, 0.015365907175075865, 0.044759652246871305, 0.00887781757140352, 0.044488744404647625, 0.06620511157257904, 0.03694752426517587, 0.052500963060846256, 0.07571350377533706, 0.03314290563726137, 0.046716317414276065, 0.06933855673959179, 0.09262137836025608, 0.025610342291333986, 0.025770291873824694, 0.26891359278271276, 41.54853367036389, 68.86799489298176, 35.10349504409298, 31.964053492392267, 53.22751637428038, 60.655273468263694, 76.00954055786133, 57.468496753323464, 64.47440685764437, 60.441884763779186, 64.65651073763448, 56.931543888584265, 54.13353681564332, 7.722568809986115, 2.2094588606588306, 1.2580955749557865, 0.335834805042513, 20.599384038679062, 53.31772304350331, 53.650473394701564, 56.008582730447095, 61.219961412491344, 64.11046974120602, 63.300770944164654, 60.239219819345784, 61.427748972369784, 63.05750554607761, 61.48323482082736, 57.43543117277084, 56.13924080325712, 59.35915762378324, 59.91383175696097, 56.165842317765765, 58.576476112488784, 56.4518537059907, 58.52195516709359, 56.950281050897416, 59.38172301938457, 57.28654584577007, 55.20060585391138, 53.423505444680494, 58.649016426455596, 55.919160535258634, 58.27368874703684, 53.221883850712935, 50.52295977069486, 58.659395017931544, 58.00506130341561, 50.56712565883514, 48.66238347945675, 46.00955509370374, 44.10807240393854, 43.078901306275405, 42.526372709581935, 41.19553212196597, 43.996857520072695, 54.04649942151962, 54.04734665347684, 57.65607626207414, 54.84581570471487, 55.13451783887802, 57.69913211945565, 56.47081836577385, 55.024311004146455, 56.53361158986246, 56.239327922944106, 48.64668223165697, 44.07249258410546, 42.83101535612538, 45.46141955160326, 43.79399253476051, 44.41688452997516, 44.99983502972511, 45.54530336010841, 53.7721610069275, 56.26613732307189, 46.13605937650127, 42.03861028917375, 45.627414257295676, 44.24508079405754, 43.62830769631171, 45.02840557406026, 42.212135945597005, 45.51409306064729, 53.53319060417914, 57.39394818582843, 57.0498308058708, 54.89449624092349, 53.82188097123177, 55.023275498420965, 54.457532436616965, 53.880634154042895, 53.97011518478394, 54.65875394882695, 52.43293831425329, 52.87415789019678, 45.161852452062796, 41.797863052737334, 40.0892746833063, 39.86882963488179, 40.26268659099456, 41.46136291565434, 42.32488447620023, 44.27010551575692, 47.63665230043473, 49.786205291748054, 54.77734288861675, 56.30929516207788, 52.78566921910932, 56.57534168612573, 55.8926845365955, 56.29692008418422, 51.692692925853116, 46.79636686078964, 44.55782705737699, 42.21894910258632, 43.565573307775686, 42.57026010943998, 46.14881100193147, 52.12851139806932, 55.36927561606131, 56.241669577936975, 55.005656211606926, 57.425185941880756, 52.314557260082616, 51.68646420201948, 51.41397322377851, 55.25620152873378, 53.578391998044914, 62.03218229355351, 57.8850563879936, 63.49421831869311, 56.63793879170572, 61.39133368769, 44.457002532097604, 7.257233031334416, 0.637098329682504, 1.8182884829659618, 1.0347245609568012, 7.153969772400395, 59.048239184964096, 53.46297233335434, 63.190642556836536, 58.185839422287486, 63.47903874612624, 63.75103158335533, 62.53495954698133, 49.56996502414827, 44.868435628952525, 38.85772497423234, 64.22412041694888, 16.115808006255858, 0.2967162412260809, 0.15412155328498733, 0.08755808110318838, 0.07608585315005434, 0.0309134480513392, 0.04309501213532302, 0.016691493050706004, 0.021298552390127894, 0.0730431127932764, 0.0660112606842191, 0.3655173719650315, 0.12404561553510929, 0.16975212181287427, 0.11885902408750788, 0.1692554210462878, 0.2608189545571804, 0.2596068808869008, 0.1300235221823377, 0.14165863574993226, 0.15695849944266582, 0.3286116377961251, 0.10974573407081828, 0.18303516711438858, 0.48087158210335246, 50.19961134079964, 78.03834730579008, 52.547318550848196, 32.48315368929217, 55.71698980946695, 67.90029910302931, 81.55564646567069, 69.96994556919222, 69.80264079186225, 66.9719760648666, 69.74311490212718, 63.03943910906392, 62.79926846104284, 10.071366929238843, 6.9203833130098165, 9.286693834489393, 0.753119036314949, 26.262282440739295, 55.74044950546757, 53.983910160679976, 59.70725620946577, 64.91597552453318, 64.91779550429314, 66.03519639661236, 63.360171318054206, 64.71823707703622, 65.62655602732013, 64.76025350632207, 59.19327274445565, 58.663580186905406, 61.00390941865983, 63.0929284711038, 58.66236817452216, 61.07428066192135, 59.424880858390566, 60.97513491107572, 58.885798146647794, 63.88708683752245, 60.5276160086355, 56.95777277792654, 56.318061659413004, 60.117842074363466, 58.62716097985545, 61.29176824323593, 56.201681014030214, 51.598077512556515, 60.3400835683269, 59.98353227492302, 52.09672843256305, 50.57608827467888, 47.93766283219861, 46.268870830535896, 44.791957255332704, 44.9735826061618, 44.687806560147195, 45.90633792261924, 56.905393446645434, 57.701626746885246, 60.176175563566154, 58.3168661978937, 59.60394882386731, 59.93325925642445, 57.96558657000142, 58.105976043208955, 60.80649260551699, 57.885707501442205, 47.70236769030171, 42.886646332279334, 42.928329360100534, 44.7785976625258, 41.97813518585698, 45.50869587929019, 45.63680048911802, 47.067751730642016, 57.17715486403435, 59.70418107125067, 47.94701376268941, 42.698309806085405, 46.002965511814246, 43.454401569981734, 43.75891870067966, 45.496897389811856, 42.010730081988925, 45.90270580783967, 55.06190299987794, 58.8205377517208, 58.52747786429621, 56.211518318422385, 57.1126397194401, 57.58057455862723, 56.746329569047504, 57.897898227937766, 58.77803494853359, 57.85675256483017, 56.05279176465927, 57.535330018689564, 47.99455681154805, 45.69531440734864, 41.07269917764972, 41.30538594338202, 42.64126285429924, 45.08922976832236, 43.59443802987376, 45.35247179769701, 48.7169671827747, 52.257627979401626, 57.608372396038426, 56.700241719522786, 55.47239080552132, 57.2721036787956, 57.87211256642496, 57.50233896317021, 53.44915382323727, 48.793676976234686, 47.13011349401167, 44.66975973498437, 45.364078091036895, 44.65607458545316, 47.86110208880517, 54.71733454735049, 58.020931213132805, 59.92896033871559, 57.98797938131518, 58.91810670975716, 56.94688427832819, 54.227748224812174, 54.14209542735931, 58.868535795519435, 55.283744412083784, 64.46532657069545, 63.35001630167808, 65.92300876494377, 57.51765581869311, 59.589236013350956, 47.99638071367818, 11.41449139964196, 1.0376564100865395, 6.235858624981296, 2.4717823199687468, 6.857312581231517, 67.174072265625, 57.196841239929206, 68.4544829399355, 61.1586469219577, 70.8278855969829, 65.84547919611778, 70.84663452640658, 51.63964679164272, 51.54167775184878, 56.0646608568007, 71.53784244291245, 24.119879930250107, 0.4329609336151231, 0.2916169454974513, 0.19836685409949673, 0.23369659219057332, 0.1914346776902676, 0.08316970730741179, 0.08263799632268568, 0.07245602131250405, 0.16873941486400945, 0.14911705327610816], [0.048532485886807405, 0.019075328844689557, 0.01866893452261725, 0.02904197952199367, 0.031072675595961274, 0.06150280643675116, 0.01409759690549465, 0.05859072237545925, 0.04973567293716535, 0.030280251484063846, 0.08943708027682959, 0.10420818242334551, 0.1636932549938079, 0.1954629058919607, 13.568590417984995, 58.54567373952558, 41.28326769798033, 32.75598199136796, 30.045071148103286, 51.192135733942834, 65.81205275750929, 61.01535489482265, 57.04984257298132, 56.93991422653199, 59.71082948869275, 51.45707222723192, 60.98476432984876, 15.26320142130698, 1.195253688962229, 1.3793107867240908, 0.07590897877009646, 4.146542943293049, 44.60096920690229, 61.86233189798171, 60.74033398782054, 60.1804470246838, 60.82721840950751, 60.52805923646497, 60.36835601252895, 59.92040172699959, 58.71974852777297, 60.35250571466262, 58.930062094042384, 61.558799282197036, 57.47085409779703, 59.132268121165616, 55.28270106161795, 52.65210859237179, 55.11039526231828, 58.309339169533025, 57.85248502608269, 57.2243998127599, 54.3513068076103, 56.32663203823952, 54.4971562200977, 51.71129672758041, 54.57588211182625, 60.19171599418887, 52.96893412067045, 54.295154156223425, 58.23370410550026, 56.00577823577389, 52.133390826563684, 44.97486129883797, 43.72471563277706, 41.353654630722545, 41.24703676469865, 40.33915711987404, 40.8165095698449, 42.54322713421237, 53.74015838869157, 54.51497162542036, 54.017626854681204, 54.27819382759833, 53.46765956571026, 53.007734206414995, 55.969578681453584, 54.978901724661554, 54.228477785664225, 45.3470040136768, 43.73024617472003, 43.89287940917477, 43.136097308128114, 44.88718455837619, 42.78339385986329, 43.34041357040406, 48.37987869016586, 49.32541701101488, 55.8596581797446, 57.11894689067718, 48.557597360303326, 47.67017679829752, 41.93167471116589, 44.295726437722486, 44.148488506194084, 45.52870781190934, 41.78932013050203, 44.48491019587363, 47.53510998141381, 53.726673280039144, 51.29667082140523, 55.28619589344148, 52.631826016210745, 52.27222704118299, 50.01274178105016, 50.77312069554483, 50.96659160429432, 52.71813777185256, 51.44815667983025, 51.21462268214072, 45.59371325277513, 39.27815206589238, 37.26197927228866, 38.628627177207704, 38.48400154421407, 40.34910032826085, 40.484767267780924, 43.21663533487628, 45.5708223004495, 48.7724373417516, 52.57652844152143, 55.04977895367531, 50.286962524537124, 52.71463509528868, 55.85579856749504, 52.88668986289732, 49.52068044293312, 45.75896270813481, 42.57493949705555, 41.07326399895453, 42.68434224590179, 41.055107347426876, 40.728087579050374, 48.499208957918235, 53.77372995499642, 54.105997854663485, 53.33647197292697, 56.45728226630919, 56.23307174251926, 54.23725605010987, 52.277851720010084, 53.79658168362033, 55.54318174239128, 58.91456088712139, 56.77466869354249, 60.40629709920576, 55.04665674701814, 55.857649926216375, 33.63055090750418, 1.0325497292703198, 0.4487093111440059, 0.4961577021787244, 0.6713233383432512, 8.050392664247944, 56.55547095883278, 47.397270048818285, 56.35684605567687, 51.34455511646887, 62.00847156586186, 52.00954591074298, 49.63207183345672, 29.34376116721861, 22.97237288567328, 39.92888112221995, 44.40851811439761, 2.8821686342839272, 0.25382887722263414, 0.06739042579166352, 0.019881090547348705, 0.014781544882533772, 0.02735934592032385, 0.021069220139554912, 0.05005421612652079, 0.03539813059051672, 0.03194250906216762, 0.04238740736318212, 0.031131978462179823, 0.023778693097072746, 0.03968647628602001, 0.027205348841004798, 0.08896071914463274, 0.06961711396973941, 0.020369908269194346, 0.040875513692416494, 0.032049847556458365, 0.009093551761320522, 0.07352342693916253, 0.1471610316225598, 0.13484665853602273, 0.1796905651328064, 18.732359370877667, 71.6171213888353, 35.88788670878257, 29.19416981358682, 46.48015322223787, 53.21975400370937, 73.42447111683508, 64.92879775262648, 62.53367693193498, 60.47285972102996, 66.79321796663346, 57.3881862240453, 64.74111626225134, 16.879051231568862, 1.2882299192490116, 1.452522193712573, 0.04696842162839828, 6.79382166554851, 48.83511289473503, 62.40432893076251, 64.02840199009066, 62.13010818727555, 62.142424429616625, 61.3950599393537, 61.499257702981275, 61.062678290951645, 60.56681225376745, 61.983023228183875, 59.78920628947597, 63.16608067481749, 61.0260590430229, 60.672265175850164, 56.69899048343782, 54.30283023465065, 56.40726812424199, 59.44729720392535, 57.5200092407965, 59.03548363716372, 58.718348241621456, 57.67625293424053, 55.2160599923903, 53.76209620506533, 55.902149215821304, 61.12207474247102, 54.41611220759731, 55.69064717138968, 58.91936971295265, 58.09180451977638, 53.563275183400805, 48.72012469076341, 44.32534425489364, 44.734820089032574, 42.40897224795434, 42.22860597795056, 41.74863338470459, 43.62569932014712, 54.13860451790595, 57.611973131856615, 57.86292637548139, 55.730855388026086, 55.30742768318423, 55.43461838076192, 57.60427744157853, 57.36369102231918, 56.530983601847005, 47.39838007957705, 43.599415517622425, 44.15279526864329, 42.67774089690178, 43.870721940071356, 42.82233515093404, 43.86889019320088, 47.18175149733021, 51.54633360524332, 57.926657046041186, 57.974313843634825, 50.17187233894102, 44.821531926431966, 40.619159436994984, 43.839237074698175, 43.210602729551255, 45.357590490771884, 40.85769053428404, 44.06618541286838, 47.70093994755899, 54.94838176235076, 55.653569006150775, 57.21569607334753, 56.23535063958938, 55.50092997089509, 53.12747240066529, 53.62106738551971, 52.89149476635841, 55.673879038903024, 53.498752194066206, 55.28650183831492, 47.48710801524501, 40.720027108346265, 38.8544576398788, 41.08403482744771, 40.12898083656065, 42.258094356906035, 40.474588717183764, 45.13772987550305, 48.49150150052963, 49.42036190340596, 55.17767567788401, 56.417434907728634, 52.70915162178778, 55.352542784906205, 57.11094133315548, 54.91926208619149, 51.266386201304776, 45.706806951953524, 44.66632766108359, 40.693978648031916, 42.79282323775753, 41.61036591376028, 44.33968051787346, 50.8401422346792, 56.7015714030112, 58.97440448884041, 55.66900353277884, 57.88223620383971, 58.96674409989388, 57.74968754860663, 56.26827109244562, 56.68978860301357, 58.77726616397981, 60.92536003358903, 58.61900637226721, 61.55779123306275, 55.96878244030861, 55.38312550513975, 37.292887549246515, 1.3628767911464938, 2.0661974770407525, 0.14228940190326783, 1.2762816442597298, 9.179779829517487, 61.75629846511349, 54.08859429820892, 61.49319764106505, 57.028567637166674, 67.63670013796899, 59.377157380503995, 52.91929260376961, 40.806672265452725, 27.110634234643754, 42.207766425225046, 54.80354039899765, 4.32963231878896, 0.34523029120699056, 0.07722356266552403, 0.0226355864921765, 0.013050887144110616, 0.015470855475042858, 0.016438210976400202, 0.04005310298394292, 0.045917188117821375, 0.006830070295461244, 0.019452343694865704, 0.16720860265195372, 0.08162088436825622, 0.26697860790356515, 0.08769964649071617, 0.25936222304740264, 0.12390978814613436, 0.10216855759462042, 0.1600321514471885, 0.1437089168616841, 0.1359329865344109, 0.279136760340583, 0.18914117898431518, 0.23797672542352832, 0.3064822381542575, 21.761621544438025, 79.30305280993062, 51.17381042049777, 44.64164418558921, 42.97771984531034, 64.51110063060638, 76.73973683388003, 73.45849375570975, 67.5667485883159, 69.87992717373756, 71.23753009303924, 64.82085020311418, 73.85573571728122, 21.004504080741636, 4.006466279106756, 6.74696748295138, 0.27848046813761035, 8.765074495346315, 53.67583544023576, 66.41404244207567, 64.56038521182153, 64.06336599780668, 65.36937798223188, 64.6651085730522, 63.489005488734094, 62.657082542296386, 62.55554806801581, 64.69551086425781, 63.31584853510704, 67.79234763114684, 62.55294361422139, 63.83980266509518, 57.68439577471826, 58.00389635947443, 58.166572740001065, 62.94208195901687, 61.122710166438935, 62.062659109792406, 60.76850052802794, 59.762279218243016, 58.98000171107631, 58.20851464425364, 58.28588731827275, 64.56948118825113, 54.96793870002993, 58.87765138379989, 61.06076025193738, 61.6108295225328, 57.186344977348085, 49.80831961477957, 47.910025811964466, 46.53570575098838, 46.336531716008345, 45.33845324670115, 44.45046394102035, 44.778354475575114, 58.06825068689162, 60.694277517257206, 61.173700978679044, 59.43137630339592, 59.55289133133427, 59.43450243242326, 61.83911931130194, 61.28712807932208, 57.24572181701661, 46.33802221667382, 41.59874785330988, 45.55738426023915, 42.70817456706878, 45.183154844468646, 41.885861427553245, 44.18491163561421, 49.1988617374051, 54.46645975112916, 59.29178699370354, 59.20167053899458, 54.28295166261735, 49.08171230746854, 40.516981694006155, 45.219672110772905, 44.33255357127036, 45.619145900972434, 41.99244399224558, 43.508938204857614, 48.8472173290868, 56.228831660362985, 55.74654094634518, 58.304989261011926, 57.12957259147399, 58.557362402639086, 55.67989203237719, 55.43084113828598, 56.62395161967124, 58.29046472426384, 58.55782916468959, 59.42466512803109, 49.015157530384684, 44.3505415608806, 40.62563919251965, 43.54414147715415, 42.7358429662643, 44.160679232689645, 43.197105853788315, 46.74503872471471, 50.19421808181271, 51.08508640719999, 56.36940156259845, 58.85896521229898, 55.7269290954836, 56.005821381845784, 59.925944036053075, 55.868789457505756, 54.72857998263452, 47.556671250251036, 47.820423187748084, 44.41640207844396, 47.49085387875957, 45.476465763584265, 46.51598799613215, 53.352816489435014, 58.16723954293036, 60.49414250158495, 57.70248966832315, 59.80362884459957, 62.47258993887133, 60.32395085980816, 58.943378540777395, 58.042021797549346, 62.119760974760986, 63.15794960145028, 62.72158591978012, 61.26340166214974, 59.03611513876147, 55.21841733686386, 44.45159358362998, 2.48967690813926, 4.24970422060259, 1.8060457850656204, 2.2574730842344226, 10.877422824982675, 69.81849501209875, 58.93192914224441, 66.29128010042253, 60.278314082853264, 73.5203024648851, 62.497277336735884, 62.92816931201566, 40.6499735770687, 34.417927495894894, 53.6199063639487, 64.19498897367909, 7.15513373574903, 0.47850268502389237, 0.19048881957367544, 0.21354636537932584, 0.12059325562609781, 0.13681276190665462, 0.15077826897463492, 0.1316210300090813, 0.10674554223735487, 0.13505776172443745, 0.1006184169842351], [0.07071281122344156, 0.07208090636038011, 0.05959554627958325, 0.025954085942958633, 0.04781853024577422, 0.08854911542467533, 0.03503046967389603, 0.05449809299241151, 0.03556120006607906, 0.04303305860488646, 0.09444616149149596, 0.047837885457181165, 0.08107643334134933, 0.12902310328377833, 0.8078395935796923, 47.636848418943345, 56.75339768009802, 42.92809009552003, 25.96495305338214, 42.87307493148312, 64.34760447471373, 61.96339961021178, 59.89674591249036, 56.96940260548746, 60.74916324307842, 51.83153306284259, 56.23939852560721, 22.164513680242724, 0.8429946329805159, 0.5249684916869287, 0.04355235896523922, 0.36758390946253655, 28.244495353391095, 69.7219733268984, 58.35888654954972, 64.00313015907042, 59.92882305575956, 64.42757375778692, 59.611664125996256, 60.94709388671383, 56.395469634763664, 61.58480851880966, 58.27156282240345, 60.3404365816424, 54.46414555272749, 59.298572694101644, 55.70417150374382, 59.18431405098208, 58.998534910140506, 57.071176344348544, 55.423090534825484, 58.248118815883515, 57.84449123567151, 55.257946983460464, 54.82758452815395, 56.943040355559326, 53.89856330810055, 55.910813731531945, 57.0410603861655, 60.21258692587576, 56.3812667323697, 57.50214284466159, 50.22177273227323, 46.543248468829745, 44.95074656701858, 44.561600377482755, 40.812646035225164, 39.82869986564883, 40.19661818781207, 40.71561836427258, 48.769640691818736, 55.03253229202763, 53.62103600655833, 53.94517675522835, 53.21527857934275, 55.04263239522135, 56.16041767981745, 50.94985485076905, 46.720280724187056, 43.517975345734634, 43.04520422412504, 45.2584800412578, 42.46057494994133, 44.25355703599992, 44.599376724612334, 44.93089152920631, 50.349037954884196, 46.79724939407841, 52.43936707896572, 53.05326900174541, 46.39586933197514, 51.51441335678101, 48.112926098608206, 42.89430672122587, 42.12526329102055, 43.27997769078901, 43.93404468413323, 43.339585950297696, 42.296780693915586, 46.86726762402443, 51.171876692002826, 53.91321336069415, 54.6437430381775, 54.655015930052734, 52.857872209241314, 52.00394084376674, 51.8737809119686, 53.27180777826617, 50.51597402941797, 52.65438748944191, 44.47583775366507, 36.31351094092093, 37.96867662860502, 38.5547258007911, 36.14609241485596, 39.91809460424608, 39.74706357525241, 44.33048648218955, 43.546569424290816, 48.69570793644075, 51.362680389035134, 53.92394888785578, 51.75647850959532, 54.97281028378395, 53.15521924726425, 51.97752368065619, 47.05509816446612, 44.05258263311079, 42.559230404515425, 43.47904582177439, 38.94503301189792, 39.52442592190158, 40.45861682584209, 43.92591361076602, 51.65997643624583, 54.211595904442575, 55.523922904845215, 54.6377065104823, 55.81658271051223, 57.15045136790122, 55.085158732629594, 56.00371899143342, 54.736436490089666, 56.850268456243704, 56.95402691441198, 59.171362384673095, 57.07177646698491, 60.31829480201968, 31.936028157511068, 0.3781407236331894, 1.251971897098326, 0.24736381526435577, 0.20355990366829982, 21.778676009947254, 55.37907369675175, 50.949564595376295, 58.74238844840758, 56.073745066119784, 55.15061916843538, 54.74081777757215, 45.02156496047974, 27.414547320335146, 30.64275210903537, 46.80747501311764, 20.349532981072706, 0.2739037363038909, 0.05953851869449981, 0.06341781557327317, 0.03598897590211803, 0.011312089721491982, 0.08794149278753227, 0.02665776834492722, 0.0551426257457464, 0.11049598695770388, 0.10599492928914486, 0.03779164973586317, 0.06039977772161365, 0.025105982560724504, 0.051768843475128376, 0.017672784649015918, 0.00810242550928266, 0.06503189388181894, 0.011453102568104383, 0.014952544325722322, 0.012586760436064534, 0.01805123591405009, 0.04581810613613456, 0.12948271007307116, 0.25898166121013705, 0.20014482159768382, 1.66448830356521, 55.57919694531349, 58.76694248568628, 35.591586943595644, 41.21970961170812, 51.74967711971652, 68.74411859819966, 67.86165591209166, 65.96957514362951, 63.44513377835674, 67.47510633160992, 59.061579165920136, 61.87506391156105, 26.657810326545473, 0.9507294551980112, 0.2831992020289744, 0.10328741368627357, 0.8912435246090736, 32.217364080490604, 70.91825700575306, 63.47159016516901, 66.64648994322746, 63.81033782036074, 64.2989278608753, 62.88158724384924, 64.06323263722082, 58.98927419416366, 62.32835262052475, 58.85715699964955, 62.57186512793265, 57.496839800188624, 60.75542726824361, 60.517049143391276, 62.33888026206725, 60.634983047362304, 58.201034684335035, 57.45119517849338, 60.86394748380108, 60.0879849926118, 56.26663154171359, 56.99833793024863, 57.79808567416284, 56.75093835399997, 58.695959352677875, 59.85985602101972, 60.52440358746437, 58.13156558621315, 59.83994999239522, 52.1416356486659, 48.092549385563025, 46.04378561819754, 44.17578820259341, 42.61990554871098, 42.37534576846708, 41.903939631677446, 41.47919008808751, 51.04483896686185, 57.53280793466876, 56.49448986976378, 57.632596954222656, 56.24802381761613, 56.76388609793879, 57.3019136921052, 52.371357102547925, 48.50889721224385, 43.850043204522905, 42.132303945479855, 44.780401952805065, 43.28304890663394, 44.2220486364057, 43.253795869888805, 44.93315865916591, 52.55888954285653, 52.3010721514302, 53.952711628329375, 57.21876728919245, 49.65208768844605, 53.259699421544234, 47.18188093554589, 43.411773250949004, 41.98669379757297, 43.449192662392896, 43.622000525074625, 43.278581327007664, 41.86774007735714, 48.93062260843093, 52.264013598042155, 56.1142082368174, 55.263120589717744, 56.79438252602854, 55.46120028341971, 54.97557163238526, 53.764822252335094, 55.68987446446573, 52.08909550020772, 54.68148016160535, 44.48528282104, 38.901702588604344, 40.27918015756915, 41.566188258509484, 40.03832309476791, 41.00478726048624, 40.95566741881832, 45.73869189908428, 46.441415894416075, 50.063450182637865, 54.760147217781316, 56.161209998592255, 53.67889881134034, 55.69980982811221, 56.056929865191066, 53.619098355693204, 48.21494694679014, 45.220025124088416, 45.22264134499335, 45.49416742017193, 40.91803619938512, 42.22555045158633, 42.65754069051435, 47.95016342593778, 55.174208302651685, 56.872810317624, 57.54555171535861, 57.52441014012983, 58.695065052278586, 59.516232859703806, 57.64453272665701, 59.23844668173022, 55.595663055296875, 58.874274223081535, 59.90880327840006, 58.93782054224322, 58.617213849098455, 62.72154277370822, 35.41602165468278, 0.48599781348339977, 2.493767449932714, 0.14847470387335748, 0.7277401368464194, 23.585633500929802, 60.09043255159932, 54.97760734250469, 64.36348615154144, 62.549903777337846, 63.14884185791016, 59.18544761596188, 49.8249347748295, 40.79880399088706, 24.58328050951804, 53.98078403165264, 27.581212751327026, 0.1695227857318617, 0.036304351317906575, 0.047081588136573, 0.14050227199350634, 0.02853464737023798, 0.046886350629070116, 0.02675070821668112, 0.06093593967717983, 0.08214648963222582, 0.04705554114714746, 0.03071955502814343, 0.13177017200618021, 0.16461574742870946, 0.13936296135427492, 0.1668577037391163, 0.1932211334426557, 0.3256253657802459, 0.23165584121259952, 0.12755432887183082, 0.17145210156036964, 0.18531038696246763, 0.20577598152862442, 0.29534947908213066, 0.36412581921585147, 0.6047843733141499, 2.0947383584514743, 66.10709344187092, 69.56183079750308, 54.06801362191477, 38.138158321380615, 55.69798984835225, 75.72042265245992, 76.38908478521532, 72.3497809133222, 68.52724290663197, 74.19422841841175, 63.50216504066222, 66.136777939335, 29.764150996362012, 1.8665672213800493, 2.5852498700541835, 0.2796957900206889, 1.6659818685823873, 38.206458553191155, 73.12358610091671, 65.88321239717546, 68.89516907353556, 65.60026045768493, 67.82433848227224, 64.76843164813134, 65.76393704260549, 60.12774213667839, 66.10510872256371, 61.04132098536338, 63.832867914630526, 58.43010110239829, 62.60949634736585, 62.32438710428054, 63.537438915621856, 60.96076726913453, 61.10116458708241, 58.19673968899635, 63.13799650438371, 61.739083182427194, 60.136685140671275, 60.27191669710221, 61.588864249567834, 58.329484462738044, 60.81848329113376, 61.015382351413855, 61.97600218557543, 59.85793405963529, 63.21119577653947, 52.718737894488925, 52.317746147032715, 50.04432470567765, 47.2375903591033, 45.42942477810768, 43.97600227786649, 44.99604209776848, 44.9883738640816, 53.51715203254454, 58.99729151879588, 58.70971902724236, 58.98661874955701, 57.82063145791331, 61.52567094372165, 59.88752834258541, 52.02178762805078, 49.37732565787531, 44.55670525950771, 44.00748714323967, 46.75835124907955, 42.23163404772359, 44.042015767866566, 44.391765671391646, 44.84843154107371, 55.98674689569781, 53.653948614674235, 55.67280038710564, 56.61066262952743, 52.10576557344007, 57.35292411619618, 48.9399500047007, 43.554257269828554, 41.64930328246086, 43.61999619391657, 44.76698744681574, 42.485242735955026, 42.16572253934799, 47.940031943782685, 53.56474214984525, 58.33375984622587, 57.73089547311106, 60.659086012071185, 55.450955052529615, 57.55132936662244, 56.16332023374496, 59.79489372622583, 54.593277823540475, 57.385679829505186, 48.189392705117505, 41.36564531633931, 44.077956445755504, 42.93429528513263, 42.389026995628114, 42.93999056662283, 44.832922489412375, 48.206615832544145, 48.602167252571356, 52.922744289521255, 55.71061988030711, 57.747557701603064, 57.02342540987077, 58.94921110522363, 58.30714264223653, 56.53994621769075, 50.35700428870417, 46.950637602037006, 47.837834588943, 48.29947010163338, 43.37896262445758, 44.89539800151702, 44.43724163116948, 48.373026309474824, 58.026351928710945, 57.647898120264855, 60.49475046896166, 58.44606514899962, 62.14004355092203, 61.890368999973425, 58.65578251500284, 61.18430706762499, 57.96963445601925, 60.803280184345866, 61.88788613965435, 61.627440760212565, 61.80378660078972, 64.29212254862632, 41.01926865116243, 1.2305118744411778, 5.055550759838474, 1.1171445899432706, 1.4803854856760272, 27.0588138411122, 67.88408402473696, 61.61826633637952, 68.01115312883931, 68.8473004679526, 68.01900571392429, 67.12755295538133, 55.12425691850724, 44.72747741207, 45.10915148642756, 61.19046126642535, 40.21355105984596, 0.3830607854310544, 0.14910038320287583, 0.213281053809389, 0.1761628374938042, 0.19234675132939894, 0.13309366550416718, 0.09904374623851431, 0.18351262375231714, 0.19317453997510095, 0.23687504502313755, 0.2223927810067131], [0.030228864221322923, 0.012388153099304727, 0.03579116050874995, 0.05955917625537804, 0.03657444710693052, 0.05877210518285152, 0.08044395881194262, 0.06141321245400656, 0.13206451830844726, 0.026192352693948536, 0.006947393788235083, 0.09808782172659714, 0.06867951428097102, 0.23842917695160837, 0.20536086912597382, 19.76709827300041, 51.646036332653416, 40.67990518385365, 28.928370398859826, 31.687477365616832, 62.348752867790964, 60.61284911247992, 61.00660408696821, 56.194318725216775, 62.032888320184526, 52.64315774363857, 59.44120576304775, 29.28770853627113, 0.21649822472564637, 0.11484058648948708, 0.12619430064073495, 0.04207257970025943, 23.09711994663362, 74.39641091131395, 58.02222559528967, 60.775058730956054, 54.66755574749362, 59.88417471608808, 59.12644340145973, 61.96285047838765, 60.62171366906936, 60.368061834766024, 59.9036963524357, 60.98571354343046, 59.34927717331917, 59.492471141199914, 58.227008619616115, 61.442383335482695, 56.17376550551384, 58.226490866753366, 56.75910472869874, 56.5185300765499, 54.05685840114471, 54.30869810042843, 48.52644197402462, 50.69579116759762, 56.054851008999734, 58.09387160885719, 56.769471553064164, 56.77154256451515, 56.9976907391702, 55.53399555144772, 51.150554687746116, 46.041459652685354, 42.79501584268386, 41.35539224070888, 40.53490692569364, 42.24530743014428, 39.34737405469341, 39.554530112974106, 46.909903787797504, 52.96696509084394, 53.82507378055204, 54.69697352378599, 53.438904669977006, 51.60684793226181, 48.53182738827121, 45.11410151758502, 44.01683022899013, 44.0500880056812, 44.85049863015452, 45.55852959232946, 43.33109009650446, 45.72934489096365, 46.15080748834918, 45.198738421163256, 43.302625456163966, 41.95126695017661, 43.10285522091774, 41.812673922508, 43.93676288666264, 39.03279604450349, 44.657337588648645, 48.24620039232316, 44.614677890654534, 46.0768315868993, 44.689053873861994, 43.25348600264519, 44.00900902286653, 44.36555639390023, 45.661876201629646, 46.22709758820073, 51.297369003295906, 54.23502422148182, 53.484902304987756, 52.70617454282699, 52.6339440961038, 53.10296543182866, 51.36622621167091, 52.30901887339931, 43.438296318054206, 36.4955363735076, 36.95598733040595, 37.61449444678522, 38.23782182508899, 38.58503003274241, 38.37804263637912, 40.69854820928266, 44.35868440135833, 52.22685306302963, 54.381477678975756, 52.64046307533018, 53.75787573475992, 56.11588701125115, 54.16886560378536, 49.886810164297785, 47.049873567396595, 46.63778543472291, 43.57416329845306, 45.732000335570305, 41.6827924789921, 40.88852820857879, 41.000484420407204, 40.78039238529821, 44.43372718749508, 53.848808042464725, 53.20561385923817, 56.142539516572036, 54.44975045419509, 56.1129177770307, 55.40747165679932, 57.96111114563481, 54.434590493479085, 60.34738702158774, 56.52278977055704, 56.112360800466234, 54.82608618274812, 63.90638097640007, 44.16007911005328, 0.886341174764018, 1.3583779551329151, 0.21417282611852695, 0.550965225744632, 28.664749860763553, 53.25716949278309, 51.03573514569191, 53.267720668546616, 54.951268626797585, 52.086981342684844, 54.58216182647213, 37.00447567047612, 26.18545105380397, 39.659304465017016, 38.22721573614305, 3.927942389442075, 0.20033547023852027, 0.1784276079025961, 0.05736098271764575, 0.06566157219030204, 0.010864118850159069, 0.03042067540058446, 0.05398564528854144, 0.02770533612478645, 0.04289911579220526, 0.061313245640767206, 0.03844626037584197, 0.02358756182084401, 0.03328681908427708, 0.031629129305421826, 0.04379237431191629, 0.005175865737856516, 0.03314964721099504, 0.08329902294903033, 0.04482806772894917, 0.04545883388228474, 0.07237955041590237, 0.029597889309027986, 0.08243598659793216, 0.0925566286088959, 0.1271988640749647, 0.11679037984821106, 25.844404889691262, 63.32772154961864, 32.72402840275919, 31.57383453461432, 46.20944692242531, 65.02018897764145, 69.51191471469018, 64.26651339377126, 62.26111927340108, 66.78383565718129, 58.523167179476836, 64.43873290092715, 34.702883766543486, 0.21737548732949843, 0.07122078114339421, 0.0656758827127276, 0.1334472304029811, 25.32824843160568, 76.50449660516556, 59.98526988490936, 63.86313292288012, 57.10869773741692, 63.751286537416526, 61.686719540626775, 63.87311143259849, 61.31025829622823, 62.38801187084567, 61.752650660853234, 63.00967616419639, 61.499489122821444, 60.3256727803138, 61.13834473394579, 62.125483712842396, 60.01414245174777, 61.10357292236821, 57.89854934138637, 59.03864506752261, 55.5786282016385, 56.35546538137621, 50.319926123465265, 53.57100617501044, 56.75681014214793, 60.06723173203007, 59.93263559956705, 59.10243457363498, 59.06297945207166, 57.18891805218112, 52.03234664855465, 48.20597648620606, 45.13976166325231, 44.10110235214234, 42.60998195217502, 41.66583999510735, 42.205593432149584, 42.92320674465549, 48.93880467261038, 55.441447227231926, 55.39066430061094, 56.90887258898828, 55.76294037603564, 55.14846970958095, 49.079621684166696, 45.70807387751918, 42.98993410602693, 44.10698590740081, 45.03704655554987, 45.640875831727065, 43.56019573826944, 43.32128417107367, 45.78313235313662, 49.168498669901204, 47.7208459761835, 43.78462199241885, 47.59679709711383, 43.979081338451756, 47.08525726872106, 44.98613419071321, 48.03527101393669, 49.686420194564334, 44.44978537098054, 46.10538644175376, 44.527048218634825, 42.92302631562756, 45.646743697504846, 43.28509246149371, 46.68797608344786, 49.37226580035303, 53.045973393224905, 56.576710593315866, 57.08389659081736, 54.775946524835405, 54.85821039445939, 53.464168656256895, 55.088116199739524, 54.6407385026255, 45.33335024310697, 40.567862679881436, 38.394206723859234, 37.9217807708248, 40.31519143812118, 41.47060794215049, 41.54551344533121, 45.377037602086226, 46.477372261785696, 55.354735389832534, 56.102621555328376, 53.73128990973196, 54.606472676800145, 57.88777851289319, 56.04834379688386, 52.01357810728012, 51.26298942873555, 48.444354611058394, 47.36840532672021, 48.180924307915475, 44.984749594042384, 41.88304124339935, 42.63413198532597, 42.98454476941017, 46.69860962898501, 55.580918865819136, 55.00511884689332, 58.862424742790964, 57.51335297861407, 57.192648226215, 58.19380183373728, 57.665442882045625, 57.953670409417924, 59.80534684273505, 59.967587840172556, 58.516679579211825, 58.522080682939105, 65.28034410169049, 46.97798436687839, 1.2933401547132002, 2.2048047233012418, 0.0802948704409984, 0.41263852088201436, 33.50687857597105, 59.154555028484715, 54.44920524474114, 59.30939843577724, 60.29826717991983, 57.62497186660767, 57.59866452986195, 48.75139382577712, 33.811568290956565, 36.149853967851215, 50.21598331389889, 5.45986524512691, 0.23370195480604328, 0.006272130375427585, 0.018770556085773053, 0.09834603166147586, 0.03699149005115032, 0.03438948390765056, 0.02161615329133647, 0.058382756317094456, 0.04608468175114644, 0.008281543569248772, 0.03728855213510894, 0.17520987008127475, 0.10982280251600089, 0.11204480989685944, 0.10539973259813364, 0.16299015481866178, 0.14857492349561185, 0.21412073213967586, 0.1621595163258814, 0.19626052599520455, 0.12564834808149647, 0.11273753724151081, 0.18245183712532445, 0.19643084266253058, 0.3784116429667319, 0.26431148811694116, 32.67329058339519, 70.16723294411936, 51.65281811068135, 40.47884448882073, 42.58842460570797, 74.41876057655581, 71.29679710634294, 72.70313939740582, 68.39729478282314, 73.37400590219806, 64.23693480030184, 73.12342136136948, 38.84874274653774, 0.5956239229248417, 0.392578661802315, 1.0982342304721957, 0.18689974361369688, 30.02328630416624, 78.2670214868361, 63.485542035871944, 65.8410547625634, 61.1830166078383, 65.77589634926089, 65.10508868002123, 66.59090995788574, 66.12277507781982, 63.51238673733127, 62.44636104952905, 64.01668979275611, 61.935366430590236, 63.22663422553771, 63.01886627751013, 64.55785136069021, 61.28732027546052, 65.55310180110317, 61.96055196946668, 60.38576741372386, 58.73335915227091, 58.44377448481899, 53.681636625720614, 56.60967026987384, 61.71546266924951, 62.602463537646884, 63.82913774059665, 59.11307988628265, 61.65297539003434, 59.0936053183771, 53.76755222197502, 51.65419486261184, 46.714181438569106, 45.8644901552508, 45.58935942188386, 45.839469355921594, 45.562436273021085, 43.686947130387836, 51.84087222622287, 56.57245874404908, 58.893548750108295, 60.01790400474303, 59.508262603513664, 55.241492640587595, 48.688702583312995, 46.059216222455426, 42.623557275341405, 43.211010656049176, 44.45965405433409, 46.963801076335294, 44.405909738233014, 44.64072635096889, 47.32608687493109, 52.588911364155436, 49.34158502086517, 45.57482311802526, 48.635330892378285, 43.39267130820982, 49.674998252622544, 45.388184978115945, 51.19334774632608, 51.87314548800069, 46.433912400276434, 47.43404619155392, 43.857903634348226, 42.76995581965293, 45.889722762569306, 45.247054176945845, 45.590492986863666, 49.32002375202794, 54.787301786484264, 59.280023805556766, 58.950795742773245, 57.49164658208048, 59.4415234750317, 57.78531051451161, 56.1397664008602, 58.05258081805322, 47.251797183867424, 41.567988626418575, 42.02712951167938, 41.9196016557755, 42.95899052773753, 42.196430775427054, 41.84002068734939, 44.52527530731694, 48.64372084217687, 57.37151615081295, 58.11078486904022, 55.840014949921645, 57.90621757507325, 61.21102233086864, 58.85135973653486, 54.18787733201058, 53.78782695339572, 49.67500217499272, 49.742992539559644, 51.787092608790246, 46.86108596863286, 45.342116740442094, 46.282689340652965, 44.315675612418886, 48.66771005815076, 59.070851649007494, 55.51576437488679, 61.48275236929617, 58.81604271550333, 59.5685298212113, 61.55557901628556, 61.61914102492794, 57.51578092575074, 63.59918094450428, 62.135097442134736, 61.643287135708725, 60.879797781667406, 69.3378399264428, 50.528713887737645, 2.167491461000135, 4.136081491747211, 0.35090577698523, 1.511542587991684, 36.302485158366544, 64.20757978193222, 62.92163072093841, 62.495100421290246, 66.86343623745826, 62.37239691518969, 67.43408618434783, 49.70458076846216, 40.16526276065458, 51.74301301279376, 62.027663723115005, 11.48263865901578, 0.6242309943322213, 0.3836507037762673, 0.17876168352461633, 0.1620489085513738, 0.1748681642235287, 0.12528408093438034, 0.17591571285118981, 0.12772507454839446, 0.13366800162100023, 0.13383097916601167, 0.15087882567557598], [0.04340588295411679, 0.032101485712994496, 0.01956895568347987, 0.014539504190906884, 0.08970089797531405, 0.04227474264259781, 0.08574776937283816, 0.07871332022571757, 0.017463274923483693, 0.013989686718090408, 0.024282832577403997, 0.05330564266431236, 0.08735508312501254, 0.105680963475137, 0.07164403706067993, 2.134017218505183, 51.300149963748076, 48.14386183215726, 36.577964982678814, 25.23302701211745, 50.999947440239694, 63.2649322479002, 63.7713808398093, 56.892018164357836, 58.32231829243322, 54.48737382888795, 55.121707377895234, 36.88325874267086, 0.28977088810455415, 0.3632454003297514, 0.33721118925079224, 0.1405890084682934, 16.77923475542376, 71.64002018590128, 56.00661762299077, 57.55704033759333, 49.92728510210591, 53.1428010232987, 54.140051872499534, 58.458098980688284, 59.02046095940375, 59.982794869330625, 60.69917263523225, 59.02950986739128, 57.38884518223425, 60.015566272120324, 58.71449255174207, 55.21953913473315, 52.68130279356434, 51.00785493850709, 49.30936274989959, 47.59806794504966, 45.7638656708502, 46.699637289970156, 41.36006770595428, 50.29164191215269, 51.98683538744527, 57.105206827963556, 56.924428709091686, 59.056927234895774, 58.2318135230772, 56.28221511840821, 53.24585345483596, 49.508850574493415, 45.11145784008888, 41.31658823259416, 40.27989795131069, 40.442994025445756, 39.76086639588879, 40.58845120091593, 42.82061715279856, 47.14810148362191, 52.26219754065237, 52.80218631990495, 51.054358559270064, 47.185917054453206, 43.00567457752843, 44.74568113203972, 44.96127813093124, 44.053727965201105, 45.10075369188863, 45.57520751030215, 48.60063752820415, 44.5145986157079, 40.92419824292583, 39.38125548824188, 39.36644461847121, 39.70109339683287, 38.50103639787243, 39.23826156123992, 38.56734406563544, 40.19308805465698, 37.52309929940009, 37.92570706336729, 41.585458863166075, 45.86500398574337, 44.472264474438084, 44.959379703767844, 42.76890070207658, 43.596901278341974, 45.678444293237504, 44.76397114415323, 47.42451875440536, 51.91475399078862, 53.25353737800352, 51.33545914003926, 52.11993317450247, 51.90916853566324, 51.83502397229595, 49.85792190797868, 43.884826783211004, 39.18366609081146, 37.96143593326692, 36.86794580951814, 38.38939789802798, 39.73161335914366, 41.90805027561803, 44.407313946754705, 45.678373690574404, 51.03051054862238, 55.100793300136445, 54.86126199845345, 55.609999318276685, 53.566393467687796, 52.65263418997488, 46.94338121721822, 48.85627800418485, 50.68359259636172, 47.09192922038417, 46.35269580348846, 45.745014759802054, 43.24724551170103, 42.19703089806342, 42.02910246387605, 41.92669722341722, 44.60613104604906, 51.9826659079521, 54.42833431305424, 55.42097245493243, 56.11627140352803, 58.9845516604762, 55.6778210209262, 56.08912467956544, 54.07270869901104, 52.341245066735056, 51.37330608983194, 53.97532409237277, 59.44383767343337, 56.01761594895394, 3.5290378332138066, 0.2117331731583803, 0.28393669955192075, 0.5940337082551372, 32.2102665516638, 53.71974245194466, 52.1670251507913, 53.235114005304155, 57.388178379304954, 65.66471676672658, 51.40587745174285, 28.527031521643366, 29.245215539009344, 41.39975424735777, 18.725189278202674, 0.08347107863594448, 0.05588335232929357, 0.10058184394672995, 0.030370768602757208, 0.06373701759824349, 0.030327965355207844, 0.03747586446303514, 0.043643868167794524, 0.06683833686815155, 0.055621771607548005, 0.04782536758049842, 0.03289506087199815, 0.051939516373339205, 0.02510946443034036, 0.026539863582940835, 0.06383317695449918, 0.03502363616961145, 0.03960473087405966, 0.07145227759235329, 0.06734083692032485, 0.01718785673860581, 0.035327953106213006, 0.03113933673669254, 0.026490512198858687, 0.037584426782784924, 0.03468179241603902, 0.08825810926575815, 4.085968309833158, 63.15897334006525, 47.46031822696809, 32.221449229025076, 46.39236273304109, 55.66397113184775, 70.12188250018706, 70.37226307776668, 61.132959319699204, 65.08948156910559, 61.13321819613057, 61.60878596767303, 42.786665116586995, 0.17310942553224104, 0.4066220953339531, 0.34982452048890056, 0.0423272694611261, 19.315141208710212, 73.85848137640184, 57.969269675593225, 58.68238402951149, 52.483227022232555, 55.88420044991278, 55.345015756545536, 59.88736752540835, 61.70487619215443, 64.74788235079858, 60.40093129681003, 59.765864264580514, 60.39029382890271, 61.556736115486395, 58.77861545931909, 59.3663747849003, 54.95005661441434, 52.414820886427364, 53.05857204621839, 51.30444495908676, 47.71244818164457, 49.150545981622514, 45.06730371905912, 51.854020011040475, 54.51456762129261, 58.73772082790252, 60.63973696001115, 58.116562520304036, 59.08390137457079, 59.369610740292465, 56.12213926930582, 50.18463965385191, 45.18579067722444, 44.18586477156609, 42.92277136156636, 41.689307535848315, 42.01635476081602, 41.31285805856028, 43.88170065418367, 51.48673711284515, 55.03829033144059, 53.28885832140523, 54.30073176660846, 48.150580852262436, 42.53127174992716, 44.36888648617653, 45.04876659762475, 44.80603856425132, 45.04471871160692, 45.52704080458611, 47.03738081839777, 48.75025241605697, 45.044471602286066, 44.81442459167973, 42.51884175885109, 41.798325892417665, 41.36775947386219, 39.91190902648434, 40.738356344161495, 41.11424884488506, 40.38363287525792, 44.3191586771319, 44.09467358742991, 46.3889894946929, 43.96563153113089, 44.436088454338815, 42.771081539892386, 42.70974743750788, 45.18616330239081, 43.93607647188249, 49.28221602593699, 53.454056785952666, 55.90451832740538, 55.222877071749785, 54.55599177268244, 54.01645014362951, 53.47591223255281, 51.35589468863703, 44.64970857866349, 40.72393378903789, 40.47078009574644, 37.19968026684177, 41.26688003540039, 42.14719718502414, 44.00076812313449, 45.20548882022981, 48.84708004613077, 54.055599320319395, 56.388448592155214, 55.53247367182086, 56.448127454327, 55.54745320350894, 54.21275300364341, 49.35962400128765, 51.46981993029195, 52.60121583938599, 49.218183332873934, 50.99771168924148, 47.14807010466053, 44.78115897024832, 43.97772419837214, 42.67150040595762, 43.92154409039406, 47.01565481001332, 53.94725168904951, 56.858395607240745, 59.23208067494055, 57.95080315682196, 61.05641818815663, 56.795602383152136, 59.58846330642701, 57.60432058765043, 55.75063982317525, 55.331789524324485, 58.1058701392143, 61.84153156895792, 58.15028313667544, 4.0710642837709, 0.14680432576325633, 0.19893956610993033, 1.087244852415977, 35.70106421747516, 58.78142387636247, 57.65698232958394, 58.691895777179354, 63.12569202915315, 70.95646873597177, 55.1545689951989, 42.387975800421934, 24.22414045180044, 44.46776159348027, 27.32421317408162, 0.1708166163054205, 0.04082418197105008, 0.06357641875623696, 0.05428590578958393, 0.090665586533085, 0.026356552149199193, 0.03101675883836804, 0.012401249372370303, 0.09134543593972923, 0.06772895238452381, 0.10742259542307547, 0.043659910048928954, 0.18761257310548138, 0.07570971930099112, 0.08009511301474226, 0.2225651507896762, 0.22732084076250755, 0.12997938019614066, 0.24562674153956676, 0.1479562768532384, 0.10739918377610946, 0.09822758680750286, 0.13131349167275813, 0.32665639755225956, 0.18120490645449008, 0.206508974454576, 0.3207699005161563, 5.718037120757565, 73.1176240982548, 61.06733022197601, 49.59575068566107, 39.141543757530954, 62.96473756913216, 74.45452474778699, 75.71787311184791, 67.78418125644808, 71.32748573057114, 67.15923001689296, 66.2347665909798, 48.18680394080378, 0.32031674418718586, 1.2809294077657885, 0.5573504153759249, 0.17679435441330557, 22.983998790864025, 78.41782093048096, 63.729964533159816, 61.7299440599257, 56.79320581497685, 58.09653097583402, 57.876686050045876, 62.90836918738581, 66.57413790302893, 65.3861657265694, 64.48882941276797, 61.225221310892415, 62.442795615042414, 65.1469756710914, 62.57713287107406, 60.75263846305109, 58.71477888476465, 53.331098325790904, 56.325635756215746, 52.59667765709662, 50.06347763922907, 49.50378287223078, 46.84510623255084, 55.40802863336379, 56.23959072174565, 62.38331287137924, 62.28826207499351, 62.273584565808704, 60.44608562223373, 61.66217334808842, 57.318309199425485, 52.46799645885345, 48.642653957490005, 45.765112984565, 45.67188609030939, 44.62855523632419, 45.301786930330344, 44.73389833204208, 45.16236628255537, 52.69456432711694, 57.952223054824344, 55.025624998154186, 55.280379018475934, 48.69518626120783, 42.58713806829145, 46.14361778382332, 45.268234975876354, 44.99302971747614, 45.510786502592026, 46.28508983119842, 50.17479842708957, 51.389403497019124, 48.54887793141027, 47.578475706038944, 44.20809676570278, 43.55455536996165, 43.34417512339931, 41.87713807629001, 43.586095148517245, 44.23490616583055, 42.75057931100169, 43.82179429454189, 45.06826469975133, 49.56282631043465, 45.144919580028905, 44.91209553134057, 41.95492259917721, 43.63230851388747, 44.453005636892016, 44.206053210842995, 47.87266915844333, 53.374118881840865, 58.204709945186494, 56.22393654238794, 57.07036833609305, 57.197896357505556, 55.169160212239916, 54.78394031524659, 46.46903330279935, 44.10088662178286, 43.54068586903234, 38.61234541862242, 42.49110667936264, 45.528794104053134, 46.09745148689517, 46.07254443630096, 50.930341059161776, 54.8856669856656, 58.40446056858186, 58.99690320414882, 57.30302372286397, 57.73039733209918, 55.04987701292961, 52.49111490864908, 54.374437024516446, 54.97101383824503, 52.737349540956565, 52.47870452942387, 51.06925572118452, 47.82942110492338, 46.21286722921556, 45.534728650123846, 46.59225456176266, 49.464606238949685, 56.259708558359456, 59.09122051731233, 61.30004052192935, 60.31559621134112, 63.36120290140953, 59.384841303671564, 61.68350711945565, 60.67902734202724, 57.541998047982496, 57.50586909632529, 60.733128593813994, 65.38712278489145, 60.33019919549266, 5.4755473713721, 0.6354666849778545, 0.6820861382349845, 2.3030289623045155, 39.43200703590147, 64.7894359404041, 64.93161793678038, 66.59189055042883, 68.32080856446298, 74.94293043690344, 64.08378585692375, 42.883292705782004, 42.97093022254206, 54.65750271274198, 41.50324598435433, 0.27249952778220177, 0.12944716359338454, 0.17750326153491774, 0.10056797009442123, 0.18084774094243206, 0.16270547654599915, 0.09370025998402028, 0.12917143322767752, 0.24723662934716673, 0.31217393435297475, 0.15428413246427813, 0.14505113354854046], [0.01817053687127848, 0.016639592509055813, 0.026415826287120584, 0.05210170484778862, 0.016232845786538337, 0.04593454767018557, 0.013425186212595194, 0.22219286270199284, 0.07302996672449574, 0.07367747955985608, 0.047191027626996083, 0.01966389887515576, 0.02275481275583227, 0.03641960924611457, 0.11628641656810239, 0.10401364205585373, 25.604426437808623, 54.75203967863514, 32.17455729361504, 25.108119133980047, 36.91201756077428, 52.42103784315048, 57.812555297728515, 60.876000927340606, 58.663387990766964, 55.487801797928356, 53.65700806340864, 44.27181566915205, 2.0397703854307054, 0.43956648077695604, 0.5136207070562148, 0.22254547765178068, 17.63629028874059, 69.33472556452598, 56.685179818061094, 57.08166868455949, 47.70871408524052, 48.53912299679172, 47.45230090233588, 48.752009637894176, 50.55046343034314, 54.52908431330035, 56.316786889107, 58.7631848550612, 57.20374853380265, 54.18025616676577, 51.47278916451239, 49.83517216097925, 44.7474697328383, 44.76447320753529, 43.676435178326024, 43.45734726998114, 45.466448030164166, 44.802104426968484, 47.80805595459477, 50.364868640899665, 54.55956505190942, 57.54346109205677, 57.76978577336958, 52.846705221360736, 51.08405482384467, 59.017350519857104, 54.547868544055575, 48.31764244264173, 42.116716446415076, 42.013777763612815, 39.66668244331114, 40.752723986102694, 41.16557698095999, 42.644534111022956, 41.88528483913791, 48.804090869042184, 51.041908956343136, 52.90253623839348, 47.71456233916744, 42.936103497782064, 45.68235881866948, 46.287772732396284, 45.68991722599153, 45.58648824691773, 46.74129286120015, 47.45413657157652, 42.46299112996748, 37.643229730667606, 37.313570207165135, 39.71695153943954, 39.23107577908424, 39.35441863152289, 38.068253840169604, 39.15940230892551, 38.803717859329716, 39.17834735685779, 38.97435665130615, 37.92447936150336, 37.32898512194234, 36.542071373231956, 43.623373354634936, 44.182291492339104, 44.37220481134231, 42.74853575614191, 45.58731978939426, 45.37827707106068, 45.397932067994155, 46.435924576174834, 50.72298888237246, 52.690712559607725, 54.03601492604902, 49.70281177951444, 47.268408421547186, 43.237310148054554, 38.29999531469038, 39.500546532292525, 37.89496352595668, 36.44616157777848, 37.28312476988762, 40.77702699169036, 42.41482834662161, 40.4786209137209, 47.43969832697223, 51.33176426733694, 52.59100590982745, 52.249445915222175, 52.86126898181055, 49.58529364678168, 49.54947848473826, 48.300387936253706, 49.061920027579035, 45.39414698077787, 48.291370407227554, 45.7547696944206, 46.530716496129195, 46.69228284589706, 41.90331205244988, 40.227954003118704, 40.99118055835847, 40.909430519227065, 44.68968537545974, 48.125512984491166, 50.95246714930381, 52.29079554157873, 55.59424315729449, 54.650681711012325, 53.859614172289454, 47.50234250099429, 46.697283867866766, 46.601421140855365, 57.33193943577429, 54.98273780269008, 63.95270024576495, 6.66277184601753, 0.2908994275475702, 0.21890588585407506, 0.4832947488513685, 34.041999693839784, 54.35955555208268, 50.953714463018606, 57.49336458021595, 50.80049099460725, 52.43605659854028, 38.13875059927664, 23.72435792799919, 30.67661589191806, 44.64951638252505, 10.483418779988444, 0.16258207510315603, 0.049512584303175254, 0.016150161916870746, 0.037222545999552936, 0.08822273132541487, 0.008438071611547663, 0.05672147550109414, 0.06943667728093363, 0.00602300480691596, 0.05761850700383225, 0.06464367116531057, 0.01940302869995996, 0.047320010020367564, 0.02867099952944104, 0.06888772165703197, 0.0037453375473212934, 0.03153201042404098, 0.042475097617434884, 0.017853516281672546, 0.07281300296346027, 0.04242546661126037, 0.06607686845405449, 0.0746908453443358, 0.007423351766661771, 0.03362675527891806, 0.06426098726449475, 0.021976678098942486, 0.03914243894659224, 33.92307343021516, 60.76599021111766, 26.950434830880937, 35.62294237075314, 51.239533655105106, 57.6672314828442, 66.26928344849618, 63.34194406386345, 64.67961742031959, 61.07819518735332, 59.761408452064764, 50.319373069270966, 2.151972358265231, 0.4534460021363151, 0.5746815918434052, 0.1605140207515609, 19.112125212146392, 74.06184058035575, 59.41214884481123, 59.83073634486045, 52.3219273936364, 49.62985961667953, 50.66546340142527, 50.53797460371449, 53.988554246964, 58.83343842721755, 59.89223518679219, 61.61397526341101, 58.866931546118956, 56.39918804168702, 54.015344035240915, 50.48390080851894, 47.45550940113683, 45.960235211157034, 44.78995292417465, 44.40940457005655, 48.3169795620826, 48.22933812295237, 47.42520909155569, 49.94107223326161, 57.10712486697782, 59.28338527679444, 60.08251720859159, 53.2342863851978, 52.44606648722003, 60.96397576793548, 55.65949962985132, 50.71416747185492, 45.54746458607335, 45.290427746311316, 40.67834015815489, 42.884630234010764, 42.689766883850105, 43.183428548997455, 41.708613441836455, 49.49957809140606, 54.01081762006206, 54.37207183530254, 49.487155945070334, 41.733324373922045, 44.93077385810114, 45.59020273147091, 45.07728222877749, 44.958167691384595, 46.222845738933934, 49.18114831370693, 47.6942797630064, 42.8836614085782, 40.07669171979351, 41.40885806852772, 43.15669759627312, 40.84283259607131, 41.549267153586115, 41.40269602498701, 41.283393213825846, 39.22572174379903, 40.5063206918778, 38.59715407894504, 39.63313048885715, 41.05666845075546, 45.03408516606977, 44.5983333741465, 44.69704766427317, 43.34902317293229, 44.88958504892165, 44.57447751875847, 45.17036399533672, 46.31621383851575, 52.32552812945459, 55.74031222251154, 55.54532335650537, 53.35767238370834, 51.151590193471606, 46.390370168993556, 41.53130662056708, 40.92350398340533, 40.245588979413434, 38.52729274380592, 39.15436598562425, 43.17523079533731, 44.49956024846723, 42.82567701032085, 49.41280741845408, 53.15984764406758, 54.39455486113026, 54.55004545950121, 54.077548903803674, 52.38286925900368, 51.16518120611868, 50.8878461007149, 50.9037003209514, 46.63074870263377, 51.384924150282345, 48.935431434262185, 48.34823300761562, 48.277983357829434, 45.93872493313205, 42.33859708232265, 43.41140847052298, 43.147150547273704, 46.63549869291244, 52.093876869447776, 54.981733675925966, 54.14366045305806, 57.85195158373926, 56.41273983063237, 58.270099778329175, 50.530659383343114, 49.40271123763054, 49.57631141908708, 59.88774799531507, 58.835125046391646, 66.67750804655014, 7.467290662950085, 0.3127046187798823, 0.3752758612315501, 1.774568764432784, 39.97503957440777, 61.26326830156388, 56.05350171366046, 62.00818915520946, 56.64703476813532, 57.534474941991995, 44.10832735799974, 33.328497025274466, 29.108787659675848, 54.39521774168938, 14.316778605984105, 0.16261337745574214, 0.007799494234214147, 0.08703373988429386, 0.006429079766084831, 0.01845321182401911, 0.04258232694419642, 0.05839868328504025, 0.04165602322187155, 0.013704804474517945, 0.02134119858965278, 0.0696046190756944, 0.027275507173110402, 0.12262313581642606, 0.12194962961779487, 0.12004875863391547, 0.1617865540808247, 0.101395214817697, 0.17701938508018372, 0.09954221666820588, 0.33272212851912747, 0.2767199980876138, 0.1507525437421376, 0.26151462367946104, 0.11305398518039335, 0.11368240710468062, 0.19083247129474917, 0.1385799888521433, 0.16801296432893123, 42.75899279502131, 68.21514775676113, 42.89912339179747, 34.28000127115558, 51.61769328578826, 63.297597746695246, 67.66301924182524, 70.59188442845499, 70.88232809497465, 67.85566253046836, 66.3364658048076, 57.09993516245196, 2.0370671369375724, 0.7048094092357544, 1.115906959579837, 0.32437152499633454, 21.767363894370295, 76.50801889358029, 62.2077868061681, 62.26206064224244, 54.019356619927194, 53.27716573592156, 53.50832669965683, 52.9653412295926, 55.84348232515397, 61.32607721513318, 62.13991803507652, 64.60182505269205, 62.263425627062404, 58.972419769533225, 57.712860415058756, 53.671936604284475, 49.44504930127052, 49.85913392036192, 46.23005113294048, 47.801878221573375, 50.9380877402521, 50.84851649499709, 49.66678088711154, 52.60017248892015, 60.02108504695278, 62.125770045864975, 62.44709845512145, 54.950048769674, 55.542695368489916, 62.7691093567879, 59.14856556923159, 53.12704093994633, 46.6344710319273, 47.98972445149576, 45.237930743925034, 46.502675471767304, 45.88916578600484, 47.04892043144473, 45.227085390398585, 53.72157812118531, 55.522212751450084, 56.93125363319152, 49.31662697945872, 42.20883330991192, 44.61500344737884, 45.000348860217684, 45.96559316881242, 46.528488589871316, 46.8146215715716, 51.609381783393125, 49.42658670486943, 44.68575908291725, 42.10266259408767, 44.678212442705714, 45.21816199825656, 44.93523359298707, 44.36517200162334, 44.78674834774387, 43.544769056381725, 43.37998244070238, 45.15357625099921, 41.817898519577525, 43.36041765828287, 43.23178352848176, 47.884871652049405, 46.58096598040673, 46.06452318929857, 42.77941265413838, 46.21959409406109, 45.593191577542214, 46.99760406248031, 47.36498894230012, 52.84486170737974, 57.06060555673415, 59.76103974926857, 55.01139071679885, 52.01708862858435, 45.83155793528403, 43.5258436203003, 43.66589969204318, 42.09089548357072, 41.5473844159034, 41.83782023768271, 46.63037215509723, 45.666233954891084, 43.45499384787775, 52.42760781318911, 55.04720587884226, 55.399823034963305, 56.67668788663803, 54.6424957244627, 55.89511248373217, 54.69259615867369, 52.58603234444895, 54.20638699685374, 49.21277438440631, 53.54035285211379, 50.78824143255911, 51.97622929849933, 53.28346898478847, 49.13775121012042, 44.65651781328263, 44.975677151833814, 46.06899861366519, 49.31473247466549, 55.23397737933744, 57.42440146784629, 57.12357920985068, 59.78972404233871, 60.22411869418237, 61.74144444927093, 53.140337774830485, 53.51539873307752, 52.1739245999244, 63.44388646464195, 60.4334673573894, 67.71891301678073, 8.616290169377482, 0.41968211711895087, 0.9267688602689774, 3.203885848483732, 43.527138002457164, 66.37406564527943, 61.809054343931145, 70.49859477627662, 62.11836853334981, 64.0491944743741, 48.09439682191419, 37.002930256628225, 42.647621016348566, 64.57460380369618, 22.07583477420192, 0.39367450461272274, 0.1316153916019586, 0.18935618922114375, 0.19886301860453623, 0.12479714778882843, 0.12898551901021313, 0.229710100458995, 0.2378604945636565, 0.12701345547553033, 0.11675078076340499, 0.14842798783173486, 0.13186973279281972], [0.044378151951898495, 0.027009373973874796, 0.06712105395572801, 0.0417268518809109, 0.06484314513903472, 0.03880202394699858, 0.00900331522232943, 0.023010575039792928, 0.06021264542434966, 0.0688850250275385, 0.09696933335714764, 0.023338648362926418, 0.07257039823959913, 0.08593610442814328, 0.09681498962304286, 0.10705357086994957, 5.218207528514247, 53.159361270166215, 46.88416911709694, 33.188778277366396, 28.904720467905847, 51.807896860184215, 64.37240954368346, 62.33923327538275, 56.17845273786976, 55.93230047533589, 53.02181159296344, 50.69691688783708, 5.2579033855469, 0.2112423559470523, 0.14353320693537114, 0.2870882933418597, 13.072430203037879, 70.18533860483478, 59.36971664428712, 59.278925541908514, 52.24453118539626, 51.5309775260187, 48.06727363217262, 46.33912048032207, 42.792815393017186, 46.10451959794568, 46.163621871702134, 48.594004800242764, 47.50460178621354, 45.77757435460245, 43.93019291662401, 43.73734566473192, 43.55442985411614, 45.22431227468675, 44.2047352944651, 45.959344833127915, 45.72356723969983, 50.71185719582343, 49.77514028549195, 52.734246946150265, 55.16460634046986, 56.34681263277608, 57.46912433255104, 56.51524705271567, 46.4266207141261, 56.76733778369043, 55.97068871221235, 48.01172502579228, 42.72116545707949, 41.19774433874315, 40.16232490539551, 40.58543489825341, 41.570483253848174, 41.22330250278596, 42.685467966141246, 47.17495010745141, 49.47293343082551, 54.237640442386756, 45.73878603596842, 45.89494343726866, 46.601507432999156, 46.07885552990822, 47.9586906586924, 48.78789148023052, 45.834185923299486, 39.49267041298651, 38.71255413178475, 40.91960514745405, 41.616837824544604, 38.90444040298462, 39.23111500278596, 38.83663438981579, 38.554674809978856, 38.18526990952031, 37.63922499072167, 37.67568734384353, 37.829710975770034, 38.2696008682251, 39.35382635362687, 35.175835317181004, 35.88352895552112, 38.58563015537877, 40.85747088155439, 45.643876444908884, 45.88199961570002, 43.489698979162405, 46.387624509872936, 44.68476672326365, 46.156216436816806, 51.517974868897475, 50.62035614444364, 47.30876961062032, 44.8837407173649, 41.99551128572033, 40.42452358430432, 40.22787947808543, 37.47653292071435, 37.95833333846062, 38.8559599076548, 39.29470054564938, 40.39052055728051, 41.00892536101803, 47.3542102690666, 51.70475421413299, 51.13279419560587, 49.64932633984474, 51.78817910532798, 51.79778498987998, 50.20674220977291, 48.71262119662378, 47.88853122342018, 48.45898112943096, 48.15960622602894, 46.087669095685406, 44.57258693633541, 44.74890532032136, 41.446685406469534, 41.14942466059039, 39.849088345804525, 37.395524209545506, 40.09569952564855, 40.01569886361399, 45.88972668493948, 47.269016388923895, 48.84704866716939, 46.347694781518754, 45.06518171679589, 41.2349009513855, 45.71922517591908, 49.75282199921147, 58.960315335181456, 54.72532049302132, 65.66899215021442, 9.360169633742302, 0.3382807092801217, 0.3289717604075709, 0.7205104118873997, 32.12252901446435, 51.416714960528964, 53.08465580786429, 51.986576511013894, 48.20607454546037, 47.5340077953954, 32.44075286772944, 23.92014695752052, 32.3024893191553, 33.724036678191155, 0.46136634003731514, 0.0694610848422012, 0.052023897127759074, 0.015719009548305504, 0.016193302243106788, 0.006834994325594556, 0.09227178945776918, 0.08736105094994269, 0.05437217495073715, 0.06964491530051155, 0.034995011294320706, 0.04536146793754832, 0.059369891251046816, 0.05040365947230209, 0.06294277211230609, 0.06822968277359201, 0.028880158769747907, 0.08297007245522353, 0.026774089220130158, 0.02982670253503227, 0.03548842554371204, 0.02168719070933519, 0.05356815035244631, 0.06026364389746901, 0.0546145306960229, 0.00413701412335579, 0.043336149800809166, 0.16219448057874558, 0.1338716124695155, 8.159797864575541, 63.76155922489782, 38.53083464407152, 27.88249392663279, 49.844256370298325, 52.379111628378595, 68.7109588807629, 65.95305412046372, 61.5660870459772, 61.383108477438654, 59.30850805774812, 53.996767690104825, 5.987859906688814, 0.5207101459945402, 0.2939460979353997, 0.4323502389654037, 15.350207436469296, 74.16877223599342, 61.8816731053014, 61.04010112823979, 55.78945952077066, 54.78803919207666, 50.00769761300857, 48.31168828472015, 44.75434564775036, 49.39667078756517, 49.381401000484345, 50.809720331622714, 49.625215530395515, 48.060711506874334, 45.95246499584567, 46.80048534947057, 44.38459165634648, 47.55644767515121, 47.04052655927597, 48.99951511813749, 48.601865230068086, 50.86145247182539, 50.650456413145996, 54.215945812963675, 55.75127132477299, 57.90498595083914, 60.07288778981855, 57.093263210788855, 48.40551922398229, 58.54148464818155, 59.07964560293383, 50.63431193751674, 45.96957045216715, 42.52791420105965, 42.5506051125065, 40.861546224163426, 44.03801495029081, 42.717549031780614, 44.976104690182595, 49.24811101728871, 53.02465923370854, 55.71130629508726, 45.41359409209221, 47.59659705623504, 46.82915003068986, 44.36077502466018, 48.159853335349794, 49.3357289221979, 47.808405045540106, 45.019321364741174, 41.060735948624156, 41.52454445439, 41.7828639091984, 41.223526077885786, 40.570749544328265, 38.681343832323634, 41.460951066786244, 40.41004219362813, 41.401401642830145, 39.608588218688965, 41.46746220127229, 40.63490383086666, 40.63021659851074, 39.58477943174301, 38.80502793096727, 41.40167620874221, 43.538422661442915, 45.508648810848115, 43.98213294244582, 43.34100977067025, 44.867153013906176, 45.362901379985196, 44.296656039453325, 53.570672773545795, 52.22929669964699, 50.24832325596964, 47.68012392905451, 43.784033636893, 41.48551294880529, 42.11910124747984, 40.29891360190607, 40.23189990751205, 39.646219438122166, 41.14108570160405, 42.52296416990219, 44.094642208468535, 50.54135568680302, 52.6938622228561, 53.00451001813335, 51.8699134549787, 53.52835432175667, 52.82850934613136, 51.77959303702078, 50.70067059609198, 49.67241341067899, 50.56811801848873, 50.367331889367875, 49.014910421063824, 47.45567414068407, 46.47549344647316, 43.96634932487242, 43.20418573194935, 42.09399415600685, 40.224706280616026, 43.50508251497823, 43.84639540026265, 47.923663893053615, 49.84779042582358, 50.57463307534495, 49.14609016910676, 48.04234304735738, 44.88557638660554, 48.52733627442391, 52.60013326521843, 61.46596070258849, 57.029030476847005, 68.11704143401116, 11.12307204354194, 0.32805953355085465, 0.41666048248448684, 0.8633783327475671, 36.93489282361923, 57.75074266618299, 59.73555611025903, 57.585822689917784, 55.352064255745184, 50.02539534722605, 45.81153423555436, 29.094653398759906, 32.809132068387925, 45.05348913131222, 0.3328347128004797, 0.03340314953557907, 0.024889721685359557, 0.03072195288334643, 0.011825282445868418, 0.07479533207632842, 0.017996336138176344, 0.04399115114562935, 0.039248442532674926, 0.04978119388162609, 0.049746582029207106, 0.02680828738507004, 0.028270203394875414, 0.1507542444573295, 0.1287667549425556, 0.21449415403748714, 0.14270218539862864, 0.16302988413841496, 0.12363513796440057, 0.11469306859878764, 0.1365146311300416, 0.12533360851868508, 0.18322624476446261, 0.17464950740818055, 0.10758974048639498, 0.2921694174649254, 0.14619269648626929, 0.2940862307385091, 0.5187473674454998, 10.888978127510319, 72.9341983795166, 58.532172941392474, 46.697158352021255, 41.06048099456295, 63.76799191198042, 76.39110872822424, 73.47699165344238, 64.5363175484442, 68.09281687582693, 65.83446518067392, 63.593152261549434, 6.313797591194031, 0.7303800758334899, 0.47092757698509, 0.3984927992907263, 16.811125586109778, 75.30960929009223, 64.95087677432646, 67.24175668531849, 56.78926775532385, 55.704273485368304, 54.11592537356962, 53.07091966752083, 47.83007614074215, 51.63007620842227, 50.17449640458631, 53.56483236435921, 52.24009498473137, 51.00252051507273, 47.28987947587044, 49.35539960861207, 47.47625873934838, 49.976361797701934, 48.44858292610415, 51.30983821807369, 50.164270785547075, 55.432641506195075, 53.462799749066754, 56.60190789930282, 59.97909215188796, 61.268543889445645, 62.866317456768414, 60.07423316278766, 50.50996495831398, 61.43517794147615, 59.892835309428555, 53.43775933788669, 48.06804241672639, 45.48759745013329, 45.09800803276801, 44.47963068562169, 45.7490312668585, 46.558741831010394, 47.59772669884467, 52.99624558418028, 53.42919288143035, 57.70352909641882, 45.98985695069837, 47.16724657243299, 49.089251102939734, 44.58715461915539, 48.985790744904556, 51.427768199674546, 51.35685959169942, 47.32780879543674, 44.05402214296403, 44.88907121842907, 45.282300595314275, 44.51655587842388, 43.79916221864762, 42.242997154112786, 42.83429053521926, 42.16732678874847, 42.44244575500488, 41.358435999962595, 43.479826373438684, 43.65445813825054, 43.222134497857866, 40.71759523883943, 41.12507850893083, 42.90970986889255, 44.946757516553326, 48.030046416867165, 47.55453748087729, 42.9904479365195, 45.68097029962848, 44.30295928832024, 46.09049712457965, 56.09285093122914, 54.663825573459754, 50.24293784172305, 50.10905165826121, 46.670545070402085, 44.55092368587371, 45.49467340592415, 41.5860354515814, 42.14016045293501, 42.798553820579286, 43.76292344062559, 44.202130840670684, 45.01874085395567, 51.85508689572735, 55.12399019733552, 54.607684689183394, 53.869137687067834, 55.63414150668729, 54.88733007061867, 53.47863827982257, 53.23103474032495, 53.94801262886294, 54.34441912558771, 52.66320889995944, 51.11065241598314, 49.74316120147706, 49.39882416878977, 47.23698631409676, 45.534246198592655, 43.85081198907668, 41.65066042254048, 45.25488715017996, 45.81815519640523, 51.626993225466826, 52.740471747613725, 53.12643689493979, 50.211139186736084, 51.949113953498106, 47.21698222621795, 52.487149392404866, 55.178165974155554, 65.09777738202003, 59.948936970003196, 70.72062446225074, 12.072007136960185, 0.45162828999661636, 0.5134331993758678, 1.796255058819248, 40.2388072013855, 63.889620688653764, 63.37617851072743, 65.35223722457886, 61.62065505981446, 61.079014962719334, 44.90820061775946, 38.560417159911125, 45.142205299869666, 56.51550985151722, 2.491394170830327, 0.21386361771052886, 0.17345375141068814, 0.08908000669532246, 0.16339156956922624, 0.17483966575274545, 0.1653200427010175, 0.264655553525494, 0.10565674743585049, 0.12567998751276924, 0.1499645150597057, 0.15266652249040144, 0.2587660534247275], [0.033287454937254234, 0.06290707241503463, 0.07559988527528702, 0.05436825258056483, 0.0016392482469992473, 0.02204197368794872, 0.08258014902352326, 0.112506301262446, 0.03798212983735627, 0.021916038409296065, 0.05950080035554786, 0.08413408943001302, 0.0784787824076991, 0.04575103896880343, 0.09082972853174133, 0.058870321485183896, 0.08486096131344957, 28.860772271310132, 51.66822125834804, 35.76449678790185, 25.90093016624451, 40.715445779985004, 61.43221262962588, 61.60519699896536, 59.3085825827814, 54.91840308712375, 53.24716744884368, 51.729755401611335, 9.45549205426247, 0.3226137209323145, 0.3104931680906204, 0.2649215086092872, 8.768851737822256, 69.21787815709268, 57.81921940465128, 60.49265592328964, 54.66397854589648, 56.2757981208063, 52.539262002514256, 50.73525805627146, 44.260036791524584, 42.5735588227549, 43.056528106812515, 43.94627463433051, 43.35331032353063, 42.82761073881581, 42.451992804004306, 41.77136744222334, 43.58271798779888, 43.37892732312603, 44.67617673258628, 46.48278513262349, 47.10244901718632, 49.807080145805116, 52.4079292820346, 53.209171448984456, 53.33889992006364, 57.70297604222452, 58.6324954032898, 54.42702031904652, 49.75900757697321, 57.46415468954272, 52.85623658087946, 45.98628759384156, 43.722111178982644, 42.21634857116207, 40.8796283506578, 42.270037974080736, 42.95300499085457, 43.18569567895705, 43.580713656640825, 47.38894285694246, 48.29097032546998, 54.50341240052254, 49.63100102639968, 46.93629741668702, 47.23092625218053, 47.55033662242275, 47.692522541169204, 39.88577035165603, 37.84823240772371, 38.359015218673214, 40.27677182228335, 38.71519780928089, 38.493062219312115, 39.01017181334957, 38.61945667574483, 38.38315348471365, 38.885146264107, 37.84796568655199, 39.22973825085548, 38.54782242928782, 38.318395153168716, 37.605790707372854, 37.19361628255537, 39.31608138545867, 39.547026618834465, 38.66456001035629, 35.35027880822459, 39.64154397287677, 42.7930546575977, 44.6726740560224, 44.39136951200424, 45.579710391259965, 47.164434233019435, 50.78745695852464, 53.1200748105203, 47.904852205707186, 46.122986116716945, 44.505404580023985, 39.90671580837619, 38.51688669573876, 38.52346451051774, 38.021314836317494, 38.07283909090104, 39.33631297080748, 38.572360777085834, 40.9181381810096, 46.302697350901944, 51.541387496456025, 51.67554824582992, 51.35140357478973, 48.593275239390714, 50.61073064804078, 50.70869184309437, 46.40746778057468, 46.41847787364837, 47.786314256729625, 45.46704030806019, 43.09253546499437, 42.75305040421025, 40.70263924137239, 41.91125485204881, 41.255148226215, 41.0148520623484, 40.272684712563795, 40.09693507225283, 41.55731585717971, 40.16959305732481, 41.845680667508034, 42.57253900651009, 41.803993717316665, 42.80577098169635, 43.79513786685082, 51.646558007886334, 50.37829099162933, 59.53536618140436, 55.24975707454067, 61.06006599241688, 9.492471179654522, 0.2796795796002111, 0.366691202526131, 0.34865568482106735, 30.84292046485409, 51.94312057187481, 53.75231381385557, 49.675261051424094, 59.548537500443004, 42.226413373024236, 23.484612857141805, 23.839210810199862, 43.70409181041103, 17.977813020829235, 0.05756714846938849, 0.04165925994335164, 0.03282425136515691, 0.017866604893858877, 0.0036563538014888768, 0.02940061975330595, 0.05558314162396616, 0.0027963643257070576, 0.03361925144769973, 0.12745140495920373, 0.051927695636667555, 0.07137489505112171, 0.015279017482703973, 0.04114289753018849, 0.03468226356011245, 0.023568024663555048, 0.022181089509338624, 0.06980180244652495, 0.10540632861516169, 0.04561271413319534, 0.10381460475224642, 0.013519939797509824, 0.03928406179071434, 0.057790420964480414, 0.03798914337230306, 0.0497905554760608, 0.05716106441292552, 0.03370139905582032, 0.04504141172454242, 0.10996930150976104, 38.9760511152206, 58.46846188268354, 20.83431047777976, 39.22127769839379, 53.48068183468234, 64.98612711506506, 68.5608889979701, 62.31707580627934, 62.21241128060126, 58.30767216220979, 57.478922413241484, 10.431036506929706, 0.35836253976148946, 0.3255349674051808, 0.3435885647852575, 10.067849543786819, 73.86982487094018, 62.16988886556318, 64.10998728967482, 57.95210538371917, 59.21323760863274, 52.794898556124785, 52.012354327786355, 46.112521233097205, 45.144848977365804, 45.70732862718644, 46.19867217156195, 45.392605489300145, 45.56837474146197, 44.84430128528226, 43.65161441987561, 44.33822139616936, 46.6290307044983, 47.73062444502308, 48.37677217298939, 49.60007705996114, 51.48363451803885, 53.94453740889027, 55.80657674420265, 57.12588164114184, 58.84504472055743, 59.31869445308563, 56.719779045351096, 51.483493312712646, 60.19688567807598, 55.57966370736399, 48.00878717053322, 44.03830520568356, 44.52444768721058, 43.778299131701075, 43.2961457006393, 44.96600458698888, 46.45072760120515, 45.23030565631005, 48.406899898282944, 49.476851878627656, 57.17991229026549, 51.22819016056677, 45.56942985903832, 47.47740014906853, 49.11214990000571, 50.22533816675986, 44.18669631404262, 39.58408124985234, 39.84378137896138, 40.74628345427975, 42.447697808665616, 42.060861895161295, 42.176336473034276, 41.13693191159157, 41.0544248550169, 40.955106519883685, 40.86495476384317, 41.070636010939076, 39.432316903145086, 39.65522912240798, 39.01470607326877, 40.3910186982924, 40.93437679352299, 41.13078163516137, 39.512152825632405, 38.83121367423765, 43.4817091111214, 44.55400666882915, 45.047095667931345, 45.32445822992633, 44.74278250048238, 46.44797017497402, 54.400740438892, 54.76706235639511, 50.612789892381244, 48.009901123662154, 46.28119099524714, 40.78554245733446, 41.84383715352705, 39.936819999448716, 39.68809466208182, 40.392128729051166, 40.72922898877052, 40.905708189933534, 43.68103219616798, 49.1062859565981, 52.57210400796706, 52.9532564070917, 52.17379516170871, 52.39760560374106, 53.433734986089895, 52.84664638580815, 49.31518746960548, 49.201368131945216, 49.85292480837915, 47.85824660331973, 45.41171919914984, 45.66474345422561, 44.93013843413323, 43.91824537707914, 42.56174072142571, 43.455433153337054, 41.44200601885396, 42.53511567269602, 43.652006656892844, 43.20879059453165, 43.58913890777096, 44.606939054304554, 45.40960111925679, 44.883309256645944, 46.44464792743806, 53.90577654684744, 54.01265721167288, 61.573684677000976, 56.327895041435, 63.12011441876812, 10.426171787323492, 0.35101756453514105, 0.36774117199163286, 0.6361985747371951, 34.322594288856756, 57.26743605829055, 59.39231734122, 54.059537379972404, 66.79956436157227, 47.472701149602095, 34.724813738176906, 21.106419024928925, 49.008007049560554, 23.43586956301043, 0.11428927131477865, 0.05112660132468708, 0.0564440252679971, 0.013882992695265961, 0.06128058348211551, 0.03794745286746371, 0.028416340412091345, 0.03294290306286947, 0.016837549628689885, 0.006615954945089236, 0.0215512809659084, 0.008994152810755036, 0.06611652882589449, 0.18909115344285968, 0.15145061838050045, 0.14294183302310207, 0.1604102924466133, 0.1072757363679909, 0.21644393973533185, 0.16916825556226317, 0.2410332170585471, 0.15903724838168393, 0.08515051190531062, 0.185243982461191, 0.17596287322380852, 0.13399038674129596, 0.17616366486876242, 0.17764250567603498, 0.22670245459002836, 0.29851109330211917, 48.2701817635567, 67.61890826686736, 47.61497728286251, 38.01392116854268, 54.65826757492558, 72.1713601389239, 74.30916170920096, 70.73157571977185, 68.98686624342396, 66.01815762058382, 64.43112742516303, 12.042720760068587, 0.6411723239767937, 0.5489766453543018, 0.41585373061318553, 11.237000226974489, 76.56064925655242, 64.52845711861887, 67.32975113776423, 59.615178569670654, 61.93627249810004, 55.79479394420501, 54.801936149597175, 49.69551617099393, 47.411127782637074, 47.365534151754076, 49.14461928029215, 47.64840372147099, 46.614792500772786, 49.80767634607131, 47.0445312992219, 48.04540249609178, 49.68359216567009, 50.213351403513265, 50.44555571771438, 51.90975689118909, 53.91762210476784, 56.96070671081544, 58.049046762527965, 58.39448205886349, 61.41951983974826, 62.216714120680294, 57.7264984961479, 50.60392141342164, 62.30709729656097, 57.65604096074259, 49.50202957276375, 46.58673970930038, 46.39053098617062, 46.78518810579854, 46.49373246777443, 47.984958771736395, 47.82408275911885, 48.78550275679558, 50.53965730051841, 53.17600780917753, 57.01985997538413, 53.5583879101661, 47.60203738366404, 47.87133163021457, 49.1702990378103, 54.01294354469546, 46.15924058421966, 43.24958716669391, 43.15612493022796, 44.952982318016794, 44.29766408858761, 44.02238430515413, 44.23961301003733, 43.93621375483852, 43.1081739548714, 43.826293253129535, 43.480179386754195, 43.50069730512558, 42.23280291403494, 41.21888199160176, 41.536393934680575, 42.422684854076756, 43.7880148426179, 43.86930596443915, 42.4599552154541, 40.964983047977576, 45.63477654610911, 45.261923882269095, 47.20272048827141, 47.96153829943749, 45.055618978315785, 46.83331951018303, 54.940391894309755, 58.28980576607489, 51.65365749789823, 49.780965005197835, 47.870001946726155, 44.77178058316631, 42.62087045177337, 42.74518212964458, 42.40885457684917, 42.29743572973436, 41.168958064048525, 42.64480083219467, 45.99507370302754, 50.64173306188276, 55.69271426047049, 53.65792982039913, 53.87537033327165, 53.58291056848342, 54.99297911121, 55.69731127831244, 50.68176869423159, 53.12363632263676, 54.475861672432195, 50.40743420200963, 48.35159840122346, 49.291778764417096, 46.863713956648304, 46.73895905094762, 44.490126948202814, 44.858402206051736, 44.01768138331752, 45.13027737217565, 46.73129866200109, 45.80712156911051, 46.91124523839643, 46.6697645187378, 46.94804883772328, 46.44724061412197, 49.43122686878328, 58.47833056603709, 55.65183531853461, 66.8346695746145, 58.400742161658506, 65.03404671146025, 12.141923385281718, 0.417525916690788, 0.6449830291732666, 1.2848088770143449, 41.509741429359686, 65.17427144512054, 64.09249351870629, 60.466132856184444, 69.53265620816138, 54.85526077208981, 35.58164373520882, 34.62818222661173, 58.90958339937272, 33.580321035077496, 0.1184394070878625, 0.08538247566790351, 0.13642594879192693, 0.0830710964697984, 0.15111160915224783, 0.18780101541309588, 0.104803103322704, 0.11672752233402384, 0.12382970131453007, 0.25336326430401496, 0.13879165894562198, 0.16409698332990372, 0.12748072314406597], [0.03558549271415799, 0.04715243977825007, 0.0067603328329090395, 0.04237917574843572, 0.10275371853382358, 0.06248229581321921, 0.0262267806852657, 0.06870419763389134, 0.05118157579413345, 0.034365018889788664, 0.06125519149786523, 0.049392434903570724, 0.0313965124528735, 0.017094926442950964, 0.04972222043321498, 0.0924680918274868, 0.14325956032881815, 6.97856382977578, 51.89196109771729, 40.23626550551384, 29.813445383502593, 30.97841678127166, 50.856176883943625, 60.36457484768283, 57.22491756562264, 55.051975480971805, 52.33820915222169, 53.70659858949723, 7.760435371629654, 0.408135149627924, 0.45920275452156223, 0.38115034600900066, 7.6106032825285395, 68.53290680916079, 59.04442271878643, 61.31610262778498, 60.191453195387325, 61.13013521317513, 58.32377349176715, 55.57977353372882, 54.87215442042197, 46.77540179221861, 43.529703232549856, 42.7604244601342, 42.35460819736604, 45.04713881400324, 43.96426262394075, 43.58118041869133, 44.988636662883145, 45.39594734868696, 46.42547145966561, 50.73923141725602, 50.51915114925754, 53.074944019317634, 54.91874041095857, 56.7902797268283, 58.89439598206551, 58.00719507278935, 55.49072396370673, 48.74054062751032, 55.71545616272957, 57.98292736853323, 52.32263734263759, 45.586060708568944, 42.52512931823731, 41.12858510786488, 41.12295258429743, 40.991549261154674, 42.03350336320939, 44.038826880916474, 45.517415308183246, 43.646621242646255, 50.25636411482289, 52.423344196811804, 53.772737595342825, 52.20064378553822, 48.442750361657914, 44.06289846666398, 39.924107597720244, 39.38734692911948, 39.94809289132395, 38.796904702340406, 38.85184141897386, 39.35406169583721, 40.230609447725364, 38.66909034790532, 39.01142697180472, 39.200175346866736, 37.99256386295442, 39.020236615211736, 40.37089301693825, 37.68117081734442, 38.14526173376268, 38.1321531726468, 38.76929906106765, 37.30081858173494, 37.97667826375654, 38.36837399390436, 37.66530875236758, 36.66335105895996, 38.01288958518736, 39.97303132087954, 44.53003314233596, 44.61987503113286, 45.67697340442289, 50.84542174493113, 53.934629501835, 48.792594402067124, 46.04685683404246, 42.8113603591919, 42.693493135513805, 40.34321677300238, 40.95716968659432, 39.348637057888894, 36.8562767582555, 38.064041214604536, 40.161791463052076, 36.94874663506785, 41.76188315114668, 47.93643513033467, 50.49628765352311, 50.345135196562744, 49.48224905998477, 47.53944420045423, 48.804447804727864, 47.82621260612242, 47.66714872852449, 45.06456198230867, 43.33420838079145, 40.822197006594756, 41.9973861786627, 39.843381297203806, 40.40973624875469, 39.70607480695171, 40.33787450482769, 39.743172584041474, 42.026792187844556, 40.06621114669308, 43.73550999549128, 40.79241444987636, 44.278165986461026, 40.83103410659298, 45.631764165816776, 50.86238991829657, 56.10163704041512, 51.29261901301723, 61.487043442264685, 51.34328819090321, 55.97157516787129, 7.341476227006606, 0.09176201923119445, 0.3655291697190654, 0.9563568306546059, 43.796236130499075, 50.69291214789114, 52.71290140767252, 57.94328005083146, 58.128670877025975, 34.49804975140479, 40.70897779157085, 36.23082345531833, 39.083830002815496, 0.9774734620605746, 0.1733238841857641, 0.030962039093156497, 0.08987740463306827, 0.03764439231505798, 0.07384910623753264, 0.01692827167590299, 0.005057113491103895, 0.022559590570087877, 0.033047730703988386, 0.04651794660716288, 0.016230045735175093, 0.013171829444716775, 0.021365169480803515, 0.06602771625283264, 0.04396462918169076, 0.015607955527581997, 0.03624746545908913, 0.18662621958121178, 0.1052054680222946, 0.04724906644813957, 0.04008846943296733, 0.012036264975435071, 0.12663741355701802, 0.009850880427796756, 0.08135445430994996, 0.044673662707810445, 0.029235759547220606, 0.026961941640042973, 0.013287540322410004, 0.07067869732817335, 10.050637202878153, 62.87705690630021, 33.67214372081141, 27.76667614136973, 50.33222275395548, 53.95362554057952, 69.10769877895233, 64.65840132005754, 62.36184181705598, 57.81681891410582, 59.481982723359145, 8.21973511288243, 0.44481691033128773, 0.586408498066087, 0.42627651004060624, 9.050143534137357, 72.08070631950133, 61.70955950214017, 65.19462462394469, 62.78346130924841, 63.55439924424695, 60.08261919021607, 58.97995072026407, 56.80391780791744, 47.71480552611813, 44.83753911910519, 46.18251200645201, 44.69906376254174, 46.905644093790364, 47.640802168077045, 46.829459897933475, 46.6865248064841, 47.312762583455736, 47.359336806881814, 51.65620703851023, 51.1859776127723, 55.12818321104973, 56.2707539527647, 58.530906015826815, 60.036974568520826, 59.51770374851843, 57.45261899886593, 50.67380236041162, 57.33262192818427, 59.74025118735529, 54.93859937114101, 48.11953921471873, 45.60673159937705, 43.03654755315473, 43.04238011760097, 43.183518763511415, 44.27537325889834, 46.78295627717049, 47.7222344952245, 45.00099997366629, 51.197532915299945, 55.463126167174316, 54.91757546701739, 54.31218508751162, 52.099297585025916, 47.60270026422317, 42.75792983270461, 42.00084570915469, 40.77903132284842, 41.76307555167906, 41.80678644487935, 42.72432688743838, 42.92289687741188, 40.01350625868767, 39.95851855124197, 39.5872034565095, 40.75875659142771, 41.96619941342262, 42.0192769265944, 40.572267501584946, 40.37775324236962, 41.45443600993003, 41.626106385261785, 38.6880785419095, 41.5008415714387, 40.96535175077377, 40.97324748193064, 38.7502912552126, 42.28320929311937, 42.468913908927675, 46.21958624932074, 45.79449938189599, 45.71904474689115, 50.17934445411929, 57.13836654540032, 50.606427807961744, 47.11685980519941, 43.521536857851096, 44.45440592304353, 40.44883443463234, 42.77092464508549, 41.235281421292214, 39.46497455719979, 40.808311816184755, 41.07717460201633, 41.801444176704656, 44.41220121998941, 49.10776076778289, 51.45642895852366, 51.6014232943135, 52.06167813270323, 49.31612491607667, 51.734128844353464, 50.12961272270449, 50.18568300431775, 47.60148432946975, 45.63060314424577, 43.26419407321561, 44.33879798458469, 40.92017781349921, 41.95001963646182, 40.67398240489345, 43.864646188674435, 42.055460791434015, 44.76341024521859, 41.89706371676537, 45.25177278826314, 42.98639220576133, 45.92850715883317, 43.46123826119208, 48.60624259518039, 53.122506680027136, 59.250845293844904, 54.63739664323869, 65.53228186022851, 54.20938761003556, 58.31169651400659, 7.766696945313485, 0.07755815156645353, 0.5263090842673855, 1.1318643871814975, 47.577616706971206, 55.76093604487758, 56.08628880593085, 63.662272268725985, 59.8976755142212, 42.802566405265566, 50.23132370364282, 32.43057039476211, 48.975027761151715, 1.3427978105122045, 0.022960877000925042, 0.006727832031526393, 0.1681912176671528, 0.01034544189385469, 0.04399066084935781, 0.04573849044860371, 0.07259423123492349, 0.007011395167454236, 0.08882086979405535, 0.01342270313011062, 0.02794832963826916, 0.018938819637462016, 0.0048865435359578945, 0.221221172100594, 0.1270785576273357, 0.16182953161337685, 0.14544107230199924, 0.28064016192670793, 0.23139425282997472, 0.13847892653317223, 0.21173698827624324, 0.15458454618290549, 0.24698545976031214, 0.10445248786239855, 0.12921588164904427, 0.18518966682735952, 0.1810406112382489, 0.13626246562888547, 0.26835146810739274, 0.6518634793258483, 13.266855228331782, 72.03453217783283, 53.21620425870342, 40.86519402842368, 43.11352014541627, 63.274479296899614, 72.84436041308989, 70.97701411093436, 68.4693879465903, 64.25472274903329, 66.72259176931074, 10.152158929455666, 0.7706504375223191, 1.0542799051730865, 0.7559364625523168, 11.089690712190444, 73.32760426305956, 66.26701631853658, 67.9652770873039, 66.27353529776296, 66.2364532101539, 61.69028889748358, 60.974825043832105, 59.903241357495716, 50.448768138885505, 47.57429838180543, 48.05825610314646, 47.040652075121486, 49.431834836159986, 51.157332543403875, 49.614142679399066, 49.564477628277196, 50.61001677666941, 49.806260370439105, 57.316579434179495, 55.56868499325168, 57.6120319674092, 55.58908916288807, 60.67174742298742, 62.6094178999624, 60.92564244424144, 57.03341960906983, 53.94523559078094, 58.72616944774505, 62.0802430952749, 55.9463543276633, 49.53474998474122, 48.332822015208585, 44.961501706031065, 45.40583564389137, 45.059239325984834, 46.59171719704905, 48.79717573042839, 50.01185924776139, 46.42133335913382, 51.53119325637818, 56.256464758226954, 58.43931867230324, 54.605809796241026, 51.32721039556688, 50.29772158591978, 46.28605473426081, 44.70283708264751, 43.76253120360836, 45.91748922101913, 45.245253809036754, 45.54609567888322, 45.80253631837907, 42.82686156611289, 42.398601501218735, 42.01586054217431, 42.8302465715716, 46.60059744311918, 46.1608212993991, 42.51484878601567, 44.595772066423976, 44.81402058755198, 45.07696843916371, 41.47638951578448, 44.106981985030636, 43.24913609412409, 43.17705469746744, 41.28014549132317, 44.419740015460604, 44.41903006645941, 48.15820593987742, 46.938854802039366, 46.49772151823967, 53.64447216833792, 58.41328982383975, 53.143475670968336, 47.923769797048266, 45.71897806659822, 45.60751607341152, 43.3172558969067, 45.25151783420194, 43.89251855111892, 40.46197437470959, 43.76968952917284, 43.14744080266645, 41.863594132085005, 45.65563963305566, 51.400648932303156, 53.88258357201853, 53.78602658548663, 53.64989680628623, 52.346948192965606, 53.82361073647776, 52.54535736576204, 54.796001603526456, 49.284541991449174, 48.57201207068659, 45.238515177080714, 46.56040491596345, 42.86117446038031, 44.16019285878828, 43.42823151619204, 46.7715068786375, 44.73824824056318, 47.031136405083444, 44.2679403674218, 48.28716562640283, 46.247176201112815, 48.82271036025017, 47.07563569468837, 52.1576585308198, 55.84037973034767, 61.629488237442516, 59.264067603695786, 67.39903588448801, 56.573537395846465, 61.0548766966789, 9.540076005843378, 0.3416708322061647, 1.1390170743388515, 1.437575757022827, 53.97158215122839, 60.66978231553109, 65.2755391982294, 68.06726655652447, 70.88621908618559, 44.91457446928948, 57.37019823443506, 49.025065437439956, 60.15245306876398, 3.7531566716009572, 0.5055731679162672, 0.12952372642053714, 0.21693831159462854, 0.1927675481044477, 0.10852478910237552, 0.12982277650265925, 0.12366912928560089, 0.10052213505391153, 0.15194555714486108, 0.14484917744994164, 0.12115898091466197, 0.07718090688990009, 0.110386727497943], [0.12616100645954573, 0.06023642862395895, 0.03642432834772814, 0.01793158638681616, 0.0392419231244393, 0.03192841687480048, 0.0712667923841265, 0.02338231728983022, 0.02098748813413324, 0.05989577996754839, 0.05660563917650331, 0.05282237524947813, 0.0689580638502394, 0.024017013474217346, 0.012416533784069603, 0.07494514823080071, 0.07130427706626154, 0.16976364377525546, 31.926518371028287, 50.1834943217616, 41.98233604431152, 30.273666881745864, 33.688609830794796, 64.85253903173631, 61.461532346663944, 55.31377407812304, 48.740564161731356, 55.91498321102512, 9.052265536400581, 0.750368841953816, 0.8389715069243986, 0.37149524796874295, 7.514866561658922, 68.52634860623267, 60.24199293505762, 65.40575404320994, 60.82762241363526, 63.275632473730276, 61.16002759625835, 61.53772438726118, 59.13672393368137, 56.58448080862723, 49.67420593384774, 43.773490305869814, 44.50646361997051, 45.713345543030776, 44.640110538851836, 46.08862615400746, 43.5122408405427, 43.44782767757293, 46.87264519353067, 48.59994326868365, 50.18799328034925, 54.56458568572999, 53.635050635184015, 58.67377050461308, 57.31708541993172, 56.825024081814675, 50.921860894849225, 57.48540216876615, 57.765490778030895, 55.15150562409432, 46.90790337900962, 43.93478208972562, 42.866465737742764, 40.73410841726488, 39.85450121664232, 41.76811971972066, 41.8385733327558, 46.12502574920655, 47.597518813225534, 41.79439175513483, 49.55682116170084, 49.910234558966856, 48.212926926151404, 46.98533488858131, 42.48270496245354, 38.94402888513381, 39.85041410692277, 38.57802075724448, 38.92907681003694, 38.474077947678104, 38.029724397966945, 38.17551497490176, 38.27822223786385, 40.07679762378816, 40.225353471694454, 40.65443331195463, 38.869625445335146, 39.60605828992782, 39.64800803892074, 39.960993566820704, 40.17013042203842, 37.7635915817753, 37.62673616409302, 38.16460294108237, 39.32348682034401, 38.45699602557767, 36.79736275826731, 37.87214709866432, 38.21678223148469, 37.608767786333644, 39.088168144226074, 41.13069534301758, 47.502185606187396, 50.86681827422112, 51.46026895892236, 48.17680189686437, 45.45556737530617, 41.23998042075865, 45.08802167830929, 41.67849748365341, 40.02258654563658, 39.75424543503792, 38.321552661157426, 38.04905776054629, 40.39946748364357, 39.7459456997533, 39.372614506752264, 42.78547271605461, 48.7088910225899, 48.88169104053129, 49.376278385039306, 47.574604326678866, 48.543265019693685, 47.164595050196496, 46.24922367834276, 43.811356867513354, 43.86978057123, 38.36425550522343, 40.624646832866055, 39.36513454683366, 39.635954595381214, 38.66648981648107, 40.73080185920962, 38.04498241793725, 39.4076334276507, 39.72507084569624, 41.15785775646087, 40.65121696841332, 44.13565843336044, 44.09523056399438, 52.142945720303445, 54.00740123564198, 58.82337362535539, 53.62004756927491, 59.85443922781176, 48.98456696541079, 49.131055724236276, 6.0757121732158055, 0.3858721442520619, 0.10460945927808363, 1.4156434564821183, 41.681678525863155, 52.62854299237652, 52.80396707596318, 57.50675555198424, 48.355850250490256, 30.5811297124432, 27.04664468765259, 36.66476703459217, 23.323415210170133, 0.13467205177632072, 0.039694543191862684, 0.0562284519565442, 0.01050894612431406, 0.05720426411097569, 0.05722553454219334, 0.03195591751606234, 0.06339570244533882, 0.007704512738142043, 0.021734942884875402, 0.029174652543940374, 0.07490220134176555, 0.11604834708475298, 0.06803242279396904, 0.041347577071358124, 0.07585204311556394, 0.1109685865981925, 0.019596624864085067, 0.03223053705427916, 0.04081905301239702, 0.031590369086892854, 0.046859223455671346, 0.00979531032498926, 0.028283020045848626, 0.007559952904440223, 0.036612816620618105, 0.07276677721810919, 0.06562895216648618, 0.024734879994103988, 0.03966592214701157, 0.06156002171337605, 0.2701545632894962, 40.61964973326653, 53.80885085751934, 31.70078988998167, 42.17273181484592, 46.47652502982847, 68.93211780055877, 65.7415520760321, 61.596367743707475, 55.62991711401171, 60.56681617613762, 10.748800462292088, 0.9775259237616294, 0.59839611933116, 0.6138334651627849, 8.376552943260439, 71.55703067779541, 61.423803067976436, 68.13198566436768, 63.74819570972074, 65.88777019131568, 63.656071001483554, 63.1571965063772, 61.021548317324736, 59.692715983236994, 51.13542610599149, 46.20924688154652, 46.8822471557125, 46.289628013487786, 47.86629922928349, 47.42679765147548, 45.14198956951019, 46.02706063178278, 48.33501462013491, 51.70418547045801, 52.0292793550799, 56.28587076740881, 56.73985765826318, 61.22091454844321, 61.70544101345924, 58.83461121589907, 54.353668074454035, 55.05243047591179, 60.39407499374882, 56.83898379725795, 49.39146187997634, 44.56968046003773, 44.85205188874276, 42.92383040151289, 41.88475924153482, 44.57881173779888, 45.57003782641503, 47.503174043470814, 48.503774596798806, 44.03225691087785, 52.6775961537515, 52.312525472333355, 52.48154432542863, 49.46987005972093, 46.54616278986777, 42.10228604655112, 41.140881738355084, 41.516193728293146, 40.53336935658609, 39.84622893794891, 41.020539499098255, 40.781553406869214, 42.56615338786956, 40.890179526421335, 42.08512567704724, 41.86663396896855, 42.25062224172777, 41.03252626234486, 41.85276839040941, 39.08788965594384, 41.526305598597375, 39.885758584545506, 42.30667291149017, 40.66552185243176, 39.49374514241373, 40.09425609342514, 40.831740133223995, 39.68152469204318, 39.92266024312666, 39.50043278355753, 41.79581557550738, 44.08725638543406, 48.14827842097129, 51.39973109768283, 54.710874403676684, 50.346739445963216, 48.58587764924573, 43.66729605582453, 46.819104840678555, 42.634414395978375, 42.17747003801408, 41.58394482827956, 38.83827001817765, 38.893018461042836, 42.541960208646714, 40.48049580666327, 42.67369301088395, 44.574881522886216, 50.91600479618196, 51.19406161769744, 52.2550666716791, 50.666377313675426, 50.942488639585434, 49.828637492272165, 48.14864712376749, 45.04546396193966, 46.487876369107155, 41.86581419360253, 41.5724483613045, 41.222368978684955, 41.45476941139468, 40.974200617882516, 42.72634298570695, 39.84274587323589, 42.65859973046088, 41.24218871516567, 43.16041992556664, 42.59464940717144, 46.83295080738683, 45.98888420289563, 55.24296745177239, 56.71795122085079, 61.41140837823192, 57.50808131310248, 62.35929227644398, 51.64371821188158, 55.38152517810945, 6.182809548993265, 0.3927376710118786, 0.2732828373630201, 1.803845335398951, 46.7180214389678, 59.394768822577696, 56.598640564949285, 63.775966090540734, 52.88592500071372, 42.557947789469075, 29.360692078067412, 38.56782259479646, 30.759911344897365, 0.04421201046375979, 0.030913252698918505, 0.0594807441736902, 0.04788986835328322, 0.031843068934376204, 0.02421120144126396, 0.05190003603216141, 0.012200141716147623, 0.03261688285537305, 0.0202536391049263, 0.03583112731575966, 0.03455125869462087, 0.07039945827977312, 0.018059276006815415, 0.23311133165994, 0.205030087682028, 0.19648923388411924, 0.10461790922788844, 0.13485543790363497, 0.1189280562703648, 0.20210994437577265, 0.2240716014057398, 0.12436232394388608, 0.22998678077372814, 0.1323798554198396, 0.1601898123420054, 0.11451167430007651, 0.15739314708738558, 0.18019820563495162, 0.15420593020896758, 0.15611935737392596, 0.3397137533512808, 51.08240350600212, 64.03357951871811, 51.67070411866712, 43.0249059584833, 47.3422666518919, 77.72756222755679, 73.05964362236762, 68.37354875379994, 61.808234568565126, 68.93995469616306, 12.727868614658234, 1.0462682189479953, 1.9869017384706007, 0.82992842120509, 10.26403473269555, 73.42761685771328, 64.16225287222093, 72.1125324310795, 67.27099403258293, 68.55539767972886, 67.61038103411275, 65.95140672499134, 63.07898052277104, 62.17773752827799, 53.93768502819923, 49.399479204608554, 49.92022483579574, 50.47762893861341, 51.273250349106334, 49.98073524044406, 46.917356291124904, 47.81326093981343, 52.282538952366004, 54.749917676371915, 54.63687889037594, 59.61490008138842, 58.51007430784164, 62.739005165715376, 61.40164167650285, 59.42827763095979, 55.02326373131045, 57.328291631514034, 60.334239236770145, 59.853203681207475, 51.971596979325824, 47.93053588559551, 47.61112943772347, 44.64648831275202, 44.613728677072835, 47.89657208227342, 47.099828873911214, 49.633381905094275, 53.045647836500606, 45.240260631807395, 55.21987645856796, 54.5874374143539, 55.241202385194846, 51.201886746191214, 48.79916044973558, 44.133810997009284, 43.17719982516381, 44.42113637924195, 43.907250973486136, 42.59099768054101, 43.16430699440741, 42.76042838250437, 44.05898394123201, 43.599952882336034, 45.54876289060039, 44.4513072506074, 44.97947792853079, 43.64661732027608, 45.06651140028431, 42.09864608703121, 45.70813663544194, 43.3971231983554, 44.04538900621476, 42.40495966326806, 44.536230487208215, 41.72099636447045, 43.470679406196844, 42.65972152833016, 42.60886015430574, 42.9611909774042, 43.0330527213312, 43.95508427773753, 50.8513209896703, 53.97745001700617, 58.20485507288287, 54.19578483027797, 50.64049359290831, 45.64782627167241, 50.09007915373772, 47.333249122865745, 44.254690600979714, 44.00474540648922, 40.302133867817545, 41.92717967494842, 44.77666785640102, 43.13109628615841, 43.08875430014826, 45.956026507962136, 52.073908082900516, 53.04926426179948, 54.829106407780806, 52.18573485651324, 54.05205349768362, 51.51378185518327, 51.233046054840095, 47.726149020656464, 50.38682214675411, 43.459571253868845, 44.9545394989752, 42.67739965069679, 45.021851293502316, 44.076301205542784, 45.95809751941312, 42.29133644411641, 45.336660723532404, 45.65382749803605, 45.439830826174834, 45.247069866426536, 48.7898212863553, 48.88047118340769, 57.50859122122488, 60.17976845464399, 64.2706593390434, 59.20201962993991, 64.63096041833201, 52.66307553937359, 54.07902763735864, 8.04676741361618, 0.4836864342852947, 0.9187566224605808, 2.8245034188993516, 51.40785824867987, 63.37546463935607, 65.42097283947852, 67.2549593833185, 58.77924303854666, 43.40026501686343, 40.23899939752395, 52.73630619049073, 42.793599867051654, 0.2762415608571422, 0.21391326020802223, 0.18778857414520558, 0.14562577610054325, 0.18824684794151014, 0.18143686255620373, 0.16287190148666983, 0.2759524086310018, 0.12812405313935973, 0.12193324299709452, 0.15065941809406205, 0.2308354989415215, 0.18720001943649786, 0.1732662896956167], [0.04931844996228334, 0.056075345454437125, 0.0529228093763513, 0.055921921025841474, 0.06354551476937148, 0.06637473109989397, 0.05958665199878235, 0.04090741359358353, 0.07183915199411493, 0.060696858957770376, 0.022452774930805452, 0.059940308828147194, 0.04628382247662352, 0.05008963237126028, 0.047511888232322476, 0.04949600999093345, 0.14118664897978306, 0.1880095598678435, 6.406205690676167, 53.75538110733033, 39.693754642240464, 38.31495131215742, 30.03242542666774, 47.77190346871653, 55.91264547840242, 59.094974225567235, 54.77197316385085, 59.22915066442182, 12.889372206503346, 0.5579843071679915, 0.7313731709314931, 0.30271103245116054, 8.863492646524984, 63.47239817342451, 57.81711309186874, 63.49227282308764, 61.116893291473396, 65.54495503825527, 61.00372114489156, 60.940343487647276, 63.49119024892008, 63.05909018362723, 58.281847276995265, 50.24117277514551, 43.40260274948613, 44.806093477433734, 42.71620365881151, 43.08433378896406, 43.44965550207323, 43.210598807181086, 44.09716821485951, 44.905074488732126, 45.812204960853826, 48.23449996209914, 53.054708511598655, 55.19844462794643, 54.043408593823834, 55.910013568016794, 59.36730046426097, 60.37285104874642, 52.66043578424762, 47.88136897548553, 43.1816085692375, 45.36367800927932, 42.92452858340356, 39.6743820559594, 41.56613726769724, 42.10599660873413, 42.63619907440678, 49.86458993727162, 47.220076976283906, 40.032784708084606, 45.2086071045168, 49.30601304577243, 45.00445950415827, 41.48929803602157, 42.3152119113553, 39.80228270253828, 39.89715699226626, 38.87737604879564, 39.52692447170135, 38.52653572636266, 38.12100187424691, 39.87596442622524, 39.491842792880156, 37.93444218174104, 38.92794324505714, 39.373112647764145, 39.11979421492546, 41.4946363818261, 39.24771839572538, 39.589223477148245, 38.59067824579055, 38.24634513547344, 37.73794320321853, 36.99363423931983, 38.482809143681685, 37.03433667459796, 36.81125971578783, 38.21038876810382, 36.35208352919548, 37.470633675975186, 38.2864474481152, 37.544982202591434, 40.6740608522969, 45.408506777978715, 49.149635991742535, 44.104487357601045, 43.39271837665189, 39.643061930133456, 45.31172621634699, 45.731357066862046, 39.85225369853359, 39.07917414942096, 39.73380596406999, 37.14458273303124, 39.82465590200117, 39.66020268778647, 41.694473297365256, 40.64125807054582, 44.02746377452728, 45.50873902536208, 50.126725858257664, 45.51568162056708, 46.755456539892386, 44.92645532854142, 45.312110608623875, 42.31693775423112, 42.22715862335698, 39.61904525756836, 39.25084060238254, 35.8711774118485, 40.19086014839911, 37.04324437725929, 39.624309078339614, 38.51303885059972, 41.51262437143634, 39.60498748287078, 44.0116762345837, 40.45880117724019, 44.25543977368263, 41.4796607725082, 52.45537034926876, 53.930711054032855, 60.43931561131632, 54.204088487932765, 62.689249900079545, 51.77786719414496, 55.84888342888125, 5.240770962930495, 0.3870971801300203, 0.14712710924927266, 1.6865625448765296, 42.73153228144492, 51.55419403506864, 53.900512726076194, 60.92418724490751, 38.37731307552707, 36.70037823338663, 39.48475899234895, 36.68397880369617, 6.965854860121205, 0.4725760756240737, 0.17796109100022625, 0.08073362431699231, 0.08167666323002308, 0.04024333793730025, 0.03875436561722909, 0.08303094580168686, 0.036984817425329844, 0.04600730687079411, 0.07863680336384044, 0.06852926911726114, 0.016112615947701758, 0.02201528318466679, 0.05708553197403109, 0.03227213945900721, 0.04989643648807561, 0.010525067487070638, 0.02681651133893719, 0.03310401901422489, 0.07705936704071299, 0.06809986917482269, 0.05777834741879375, 0.06413441421764512, 0.03385791464919045, 0.08670667396678079, 0.130018956298309, 0.030237507608328617, 0.0962608092794976, 0.09210148045132238, 0.036725695845821214, 0.1245759858659679, 0.15959682964509533, 9.805917586049727, 65.47472892269012, 34.403818730385076, 34.10276897491948, 45.40081501007081, 53.6197651586225, 66.3864681797643, 63.4735905739569, 59.568380771144746, 65.91886674204181, 14.314027063308226, 0.45128989363870314, 0.7170210958969209, 0.7484612830223576, 10.256471422410781, 67.06771327603248, 60.47764501264019, 66.88544073412496, 63.26225719144268, 66.2076473236084, 62.90533719524261, 63.472049082479174, 63.36410153296686, 63.739429212385616, 60.4263678673775, 52.058316661465554, 45.63158373678885, 47.39704255134829, 46.49968270332583, 46.26740386409145, 46.19723658407889, 45.64724968325707, 46.677032670667096, 47.64182982906219, 49.74087838203677, 52.5059885363425, 53.82017474020682, 57.02934034409062, 56.124661353326616, 57.65326784503076, 60.534323261630156, 61.728524161923325, 54.90700075703283, 50.34711991586993, 45.57623909365746, 46.40199999655447, 44.180824525894664, 42.0194181319206, 46.017195870799405, 44.90105013693533, 44.17224237995763, 50.53568786190402, 48.63951998372232, 43.63162994384766, 48.3636361552823, 53.7315683980142, 48.19364847675447, 46.16259421071699, 43.95879876229071, 42.86157061976772, 40.91766357421875, 41.20342785312284, 42.196320949062226, 40.27495968726374, 40.464551371912805, 42.26750412294942, 41.805994126104544, 40.20179179406936, 42.15819551098732, 41.860597441273356, 41.92025669159428, 43.32641855362923, 41.829810757790845, 41.81241504607662, 40.67604949397426, 41.550675284477975, 40.89112089526269, 40.05647190155522, 40.59421708506923, 40.79270078289894, 41.48656414401147, 39.19959483608123, 39.080660727716264, 39.568026988737046, 39.08488904276202, 41.46117464188607, 43.30175468998571, 47.70836891666536, 49.782624167780725, 46.282548135326756, 44.63275609477874, 41.65629294610793, 48.15200075026482, 48.32587157526324, 43.03301741999965, 41.39956989595967, 42.1676758796938, 39.65176959191599, 42.905987539599025, 40.15888498675439, 42.71206948064989, 42.63920360995878, 45.88702417189076, 47.783658812122965, 51.270983219146736, 47.99558055016303, 48.91880842947191, 47.27852813659176, 48.17221272376276, 42.96156360257057, 43.61421854265275, 40.67742624590474, 40.869536092204434, 38.04449996640606, 42.54365467256115, 38.99694558112852, 42.65205329464328, 41.59979512614589, 44.28816410803026, 41.45372213855867, 46.19647956663563, 43.71852613264515, 46.26369330190843, 43.83846044540406, 54.79432282909271, 57.389355090356645, 62.797322965437374, 57.14056699506698, 63.608720148763354, 53.202362214365316, 62.418939759654386, 5.962948933724435, 0.2882191616921656, 0.12118525006958555, 2.3294664727103327, 47.21580159279608, 58.552902667753166, 59.833858551517615, 65.10179781144666, 46.00170643098893, 47.12636763049711, 32.342952489852905, 43.8910751188955, 8.781607285622629, 0.5765681906092552, 0.07903011290416603, 0.06188926715103369, 0.07482818958740081, 0.06570709313476278, 0.048563336247518185, 0.08345803215859399, 0.026663875980903546, 0.02161467091120299, 0.04708382128287227, 0.02913621025189998, 0.07329523999003634, 0.08839824206886754, 0.02246347526388784, 0.15814411243604076, 0.12664132060543185, 0.1847470059029518, 0.12307590144055507, 0.16361218756966053, 0.25833722804823234, 0.19383391185152918, 0.17379948689091593, 0.15186640494052442, 0.1335089770896781, 0.2032022018946948, 0.2694124998825212, 0.14485293128077062, 0.13605985069467177, 0.2873923076737312, 0.10440312115655792, 0.3125247106917443, 0.38938214461649623, 13.14079809573389, 75.90446026094499, 51.05714344209241, 53.186366788802616, 45.09584680680306, 59.278297962680945, 68.01952346678704, 70.72895557649674, 64.82811835504347, 74.8457968619562, 16.797238434514693, 0.6442844795603907, 1.5816647607472636, 1.0278243150922561, 12.644194652957301, 69.75509382063343, 63.24420644390968, 67.95223128411078, 66.40571917257002, 70.44751767189273, 62.719291333229314, 65.4257502863484, 66.3003093965592, 66.97312924169725, 62.83582102867865, 54.529131381742424, 47.72157945940572, 49.86172268467565, 49.25556352061611, 49.5036377445344, 50.620363989183986, 47.59816600430397, 49.16524310265818, 51.1436983846849, 51.369772034306685, 53.07890953556184, 56.34195281613258, 62.6213615171371, 58.84661759099653, 58.05571086945073, 61.41194574294552, 66.0023896924911, 58.08355185293383, 53.03138217618389, 46.84177221790437, 49.67496295129099, 46.89228842335363, 43.40892953257407, 47.089254163926654, 47.30606709757159, 46.57838113846318, 53.871506798651914, 50.69785825667843, 43.98576113485521, 50.33758855635121, 56.357744278446326, 49.44974045599661, 47.27705332540697, 48.44527244567872, 45.62750447180964, 43.90432488533759, 44.507899207453576, 44.606236950043716, 44.2997625566298, 43.58877804971511, 46.18719531643776, 44.48878549760388, 43.03869308963899, 45.160765955525065, 45.36057933684319, 45.4650830453442, 45.74671314608666, 43.83061570505942, 43.99363725416122, 43.826387390013664, 44.9647415837934, 44.197121973960634, 42.34986212945754, 44.70933252765287, 41.256866224350475, 42.17807016065044, 41.99185955908991, 42.00361490249634, 42.91828024771906, 43.062427351551676, 43.55555949672576, 44.99087241388137, 48.74551027051864, 54.046503343889796, 46.31890850682413, 47.56231161855882, 44.08057266666044, 50.20752668380738, 49.52708567342451, 44.13878064001761, 43.97074237946541, 43.58496158353744, 40.94183714159074, 45.27118459824593, 42.443512639691754, 45.84512933608025, 46.19090195625059, 47.50609228687902, 49.30203184004753, 55.032791168459006, 50.31869842160133, 51.587326295914195, 49.75710522743964, 51.97626459983088, 45.418297013928814, 47.76649844261908, 43.42324226133285, 44.069629253879675, 40.962664927205736, 45.222092213169226, 40.02224529943159, 45.424372765325735, 42.9515850928522, 46.31089118219192, 45.02495388830862, 48.83613271097983, 46.58721039372106, 47.74653750081217, 47.21473863047939, 58.41344671864664, 59.363978216725016, 66.28597705594956, 57.70851050653766, 64.23096495289957, 55.568724216953406, 61.10736585432484, 7.723172854992652, 0.39038173614009736, 0.8587564936568661, 4.043587100121283, 55.09707097084292, 65.75703367110222, 65.34304711126512, 70.50632184551608, 51.22411089558756, 52.895272008834354, 51.6806669389048, 55.790028264445645, 14.02405506180179, 0.9103250587659498, 0.33112434490073117, 0.1912485183246674, 0.1560807771860592, 0.2573438878020933, 0.16572432262041878, 0.15837049141766565, 0.18709737897640277, 0.11655728993636948, 0.2146739242297988, 0.20201855008640598, 0.129061269784166, 0.18373779231502166, 0.19131749688136965], [0.017107601367658185, 0.024186182924876773, 0.03692824566256135, 0.07927498524828304, 0.034620807986826665, 0.03654404107721583, 0.062396164547892354, 0.04783647585540049, 0.04429384780627105, 0.07708771995479062, 0.09226964441158118, 0.030174372387268854, 0.023290074558087417, 0.06944521150041012, 0.04019088006668514, 0.053127983044232094, 0.044203012761089115, 0.05674669511556145, 0.1283558177190923, 29.364402640250425, 52.81338076437674, 33.56267821404242, 28.4643598910301, 39.87736471237675, 45.34198730222641, 55.96348331820581, 54.628010411416334, 59.606976893640336, 19.540551977772868, 0.39948377998605855, 0.5315537834840437, 0.6161995123951667, 6.481028824083268, 60.51586850996941, 59.06416793023387, 62.37671544474941, 60.85286678806428, 63.91555540023312, 64.26772148378434, 60.35752242611301, 59.99343625960812, 64.35331152331445, 61.064039353401434, 53.71607503583355, 49.324063793305434, 44.172073718040224, 43.88311662981587, 44.13750979208177, 42.41800938883136, 43.041179872328236, 43.70089900109076, 43.370553062808135, 43.526569258782175, 46.716185769727154, 49.506532453721576, 53.019783727584354, 53.614418968077636, 56.4517831033276, 51.63646967180314, 45.748831225979714, 46.91191204132573, 43.5143236191042, 44.64435454337828, 40.87280734892815, 42.06339966866278, 42.87053323561146, 42.602466690924864, 41.706636567269605, 42.440515948880105, 48.00225642419631, 46.6389621457746, 43.50008933774887, 43.59068824398903, 45.71559306113951, 42.90018243174399, 41.37925986320742, 39.80842513422812, 38.618805562296224, 39.126438709997366, 38.91158696143858, 39.59982564372402, 37.94460112048734, 39.371986927524695, 38.72734931207473, 39.61784501229563, 38.54151918042091, 40.364126928391, 39.39244208797332, 40.60732564618511, 41.60228190883514, 39.239614778949374, 38.843384788882354, 40.29164544997677, 37.56545697489093, 39.11573456179711, 38.539895319169574, 39.46622971565493, 36.554324857650265, 37.60498662148753, 38.27795159432196, 37.44115314176006, 39.092282710536836, 38.352625677662516, 37.67022740456366, 38.23533504239975, 40.26552638699932, 44.626935297443026, 45.42544749475295, 40.51875460532404, 39.156946905197636, 43.77032103077058, 45.67762059550132, 40.066505324456, 38.69992017745972, 40.04118250262353, 38.619209566423976, 40.14014390207107, 40.13338173589399, 40.141857977836366, 38.33889345968924, 40.880710924825365, 41.524273810848115, 44.99863086208221, 42.98545083691997, 46.291553897242395, 43.573598477148245, 42.7833781703826, 39.422887525250836, 38.77101705920312, 36.39438236913374, 39.449665546417236, 37.35866177466608, 38.80260390620078, 40.19733205918343, 40.76526772591376, 38.88111406756986, 39.85466595618956, 40.35675287246704, 41.82778289241176, 40.334583636253114, 41.75926300787157, 41.027242829722745, 50.01089042232883, 50.838247729885964, 57.526030079011, 54.8734684144297, 62.35168680067986, 55.15514558361423, 62.74497501311764, 2.3509130122200137, 0.2555913697447508, 0.06765525472620804, 2.038380640649027, 46.67303577546151, 51.14970745578889, 52.74640237131427, 52.15792132962135, 32.84282718935321, 31.88377630326056, 44.20121300605036, 31.200840665448098, 0.16604359742374192, 0.06040309105188616, 0.0371404979828625, 0.0557193827004202, 0.014976195375164671, 0.025623174264065685, 0.06459700108896341, 0.0400725003301857, 0.01114037590131404, 0.039286582219985225, 0.05480395359618049, 0.0028086937926409226, 0.019499927331062577, 0.0025267461446234056, 0.03422027040693549, 0.021962603148553642, 0.021493600290869514, 0.06991010429638048, 0.012716510832580108, 0.021038524911648804, 0.044409913957239165, 0.020336089317776987, 0.03937562844986397, 0.06238100366787084, 0.035265513109944524, 0.058845956058752154, 0.024056223769401832, 0.10548331279067263, 0.07693971942869887, 0.08045132091689496, 0.03474392980757741, 0.054966475318876974, 0.03503351104295543, 0.194041199922081, 40.130843962392504, 56.06204463589577, 29.77112497052839, 43.691779490440126, 47.02723756913216, 50.87717333147603, 63.0381251150562, 61.383889029102946, 66.54394349744244, 21.45672590501847, 0.7847061897477796, 0.894443565799344, 1.0220054789416253, 8.07309534280531, 64.58686513285484, 62.285904730519945, 67.0315804020051, 65.15603634618944, 66.70873011312177, 65.20661923193163, 60.74043989181519, 61.124436009314756, 63.928907148299686, 64.20427714624714, 56.12979181351201, 50.741918240824056, 46.52160090784873, 45.996513212880785, 46.518306116903986, 43.81263163781936, 45.315530915414136, 45.95997633472566, 45.88062286376954, 46.19558526623634, 48.7246040375002, 50.918009127340014, 56.66425789556196, 56.89651320057531, 59.155570922359345, 54.64200935056133, 48.75060150700231, 50.086627467986084, 46.39836395940473, 45.10438972903837, 43.79340025686449, 44.517685521033506, 43.10011740653746, 45.15351349307645, 43.360056800227014, 45.44854633269772, 50.28766070642779, 46.8963873001837, 45.15622385086552, 46.1766480630444, 47.65714276221491, 45.002059013612815, 44.225967084207845, 42.79143079634636, 41.3643156328509, 41.705530458881015, 42.52752588641259, 42.61143715150895, 40.16193266837828, 42.00560746654388, 41.25444219958398, 43.138360515717544, 42.10882855999855, 42.17309659527194, 40.94475930736911, 43.091025352478034, 42.45928056778447, 42.000567220872455, 41.463300566519464, 41.06891016806326, 40.28080794119066, 42.01754716134841, 39.371276978523504, 40.80000031378962, 40.128435627106704, 40.44097792717719, 40.043359418069166, 39.26258417867845, 40.2650753144295, 41.06103404875725, 39.252554678147845, 40.55988850132112, 42.43821743995913, 47.915662257902085, 48.353477216536, 43.349089853225216, 40.50268857709823, 46.82068163348783, 47.904001051379794, 41.84559437536424, 40.15215419953869, 41.00403808778332, 40.1199907641257, 40.9154042889995, 40.996648342378684, 41.26434618426908, 41.85973059746527, 42.35954646141299, 43.34251988318659, 47.28889888332736, 45.15430188948109, 49.02102931853264, 44.74966233776462, 44.86142243108442, 42.11242537344656, 40.776791649480025, 40.40924987485332, 41.09843384835028, 39.92349178560319, 39.78101561146398, 42.48359141811248, 42.229072740001065, 41.70913903943954, 42.6819456777265, 41.45043911472444, 43.08887981599377, 42.982826771274695, 44.16879853894634, 43.23868689998504, 52.38812523503458, 55.18147253221082, 61.125004752989746, 58.41661599374587, 65.56514739990234, 58.93916591521233, 67.84371499092349, 2.270897151001038, 0.28222933471683537, 0.11602063768453176, 2.8077835805954474, 53.57003734957788, 56.97344656913512, 61.70912019668087, 56.37409663969471, 42.83067410992038, 39.06838763144709, 43.736388606409875, 38.39472055435181, 0.1542567065165889, 0.07448854450617107, 0.04464142572795672, 0.039015919525897315, 0.0672732143392486, 0.04286882084523959, 0.032399153006413293, 0.04584744347319488, 0.0502846630350236, 0.0683718916749762, 0.08153560346052532, 0.10071911924188176, 0.02918007644644428, 0.027388120182759823, 0.10580827196639393, 0.10024108037713075, 0.10752021800726654, 0.13315455417238897, 0.11254383190985649, 0.1435398412567954, 0.15552937774167908, 0.1418192843876539, 0.13152378280797314, 0.08700892629642641, 0.24295709366279267, 0.1829853101122764, 0.13052952325632497, 0.15261357049307517, 0.14404515285165082, 0.1335003356178922, 0.13127501873720077, 0.118526189527925, 0.13497903852933837, 0.3737653503494878, 50.94811331841254, 66.68807491179436, 47.1637438958691, 41.50314400272985, 50.872792043993556, 60.804688315237726, 71.66233847218176, 66.4504498820151, 73.87290785389563, 24.373545492849043, 0.8334840497662945, 1.9899223312254877, 1.34737448105889, 10.80596802696105, 65.61243157232961, 65.02765324807936, 69.88530866561398, 66.6820187722483, 70.21447397047474, 66.41072411690989, 62.31477337498819, 62.563863492781124, 67.88452333019626, 65.40551870099961, 58.60404645242999, 54.007161971061464, 48.01740069543162, 47.6478781238679, 50.125439320841146, 45.73261222531719, 47.481848116843935, 49.63312695103307, 48.15649186411212, 48.99176451467699, 52.353475016932336, 53.775753898005334, 58.23896400390133, 58.57987288505801, 61.27407835375879, 55.19025079665646, 48.38317740348078, 51.84488088853898, 47.56091133240731, 47.796124104530584, 45.1188789644549, 46.855594650391616, 46.89134705451227, 45.95669331089143, 45.379728348024436, 47.48910450166272, 52.04981296293197, 49.17749266470633, 49.1225088796308, 48.40338153223838, 51.1503585692375, 47.06851267045545, 45.185104262444284, 47.16961176164689, 43.19429351437477, 45.92036431835544, 44.40750614289315, 45.73815845674085, 42.19843118421493, 45.857688765372004, 42.506709867908114, 47.43118286132813, 44.87517033853839, 45.34591751713907, 44.5052751418083, 45.552555822557025, 45.86944410877843, 43.13927835033786, 42.9187705439906, 45.31424830036779, 42.79658086838261, 45.895465112501576, 42.89837029672439, 45.985408982922955, 42.59702244112569, 42.805935721243586, 43.41378150447723, 42.10753025547151, 43.826348166311945, 42.53835947282853, 42.490432031693004, 42.237454845059304, 45.73505978430472, 49.7384229783089, 50.48960785711966, 46.50193414380474, 42.92656429352299, 48.8264326895437, 50.70344763417398, 44.06552645467943, 42.102117384633715, 43.87671924406483, 42.00261077573223, 42.24212638793453, 41.86783813661145, 43.836832661782545, 42.387352143564534, 43.18791574047458, 46.23110232814666, 49.45687132496988, 47.61387117447392, 52.361178551950765, 47.295362949371345, 47.96050671608218, 44.73942495161488, 43.20980648840628, 42.73725501952633, 45.803042304131296, 42.67285754603725, 42.69809015335576, 45.30669381541591, 44.85601740498697, 43.98335279956941, 44.99675204676967, 44.397276601483746, 46.438066190288914, 45.58157743946199, 46.375484774189616, 45.81122044594058, 56.02662955560992, 55.51436016636511, 65.13754237082698, 59.22200410596786, 68.75685845651935, 59.018829253412065, 65.36562819634715, 2.989540085677178, 0.3544396792929019, 0.23286344092940134, 4.15054670264644, 59.59126387873004, 62.61070443737892, 64.05519177836757, 61.90135948119625, 47.46100071937808, 45.479482066246774, 55.18879559732253, 50.425022109862304, 0.9628954217318566, 0.3246690429026081, 0.10537504924521332, 0.2821035430796685, 0.20238645615116244, 0.15279372372934896, 0.1811937215707956, 0.11690221336339751, 0.14458979540053876, 0.09902878454135311, 0.16620216230230947, 0.12561407330776417, 0.15829562930570495, 0.15142242634488692, 0.2046148527053095], [0.02860315478286676, 0.02943360941454528, 0.0579119416614694, 0.02047521088482632, 0.04699549900608198, 0.051151165933979136, 0.04631459239810225, 0.032450044227223244, 0.05661816088362567, 0.047923959265913696, 0.0424467868381931, 0.07231291608824846, 0.047010131285435734, 0.03668167260325244, 0.04253246994208425, 0.11307396475345859, 0.03584131245471297, 0.11887857465133553, 0.16172476142885225, 8.67230063484561, 52.449392657126154, 35.82578774421446, 31.225983058252645, 35.6116694788779, 50.71890961739325, 62.44494115152667, 53.83531901144213, 57.93640413591939, 31.30001779525511, 0.08699204171857527, 0.21595915929684717, 0.32580950267372594, 1.6442315905324876, 50.52416001596759, 64.6141020713314, 62.02608300793556, 63.889691291316865, 62.0041451915618, 65.25789637719431, 61.78575938747775, 61.434573896469615, 60.67851351153467, 62.12959827915315, 57.350041174119525, 51.13227644274312, 48.067073591293834, 45.1351724901507, 43.42337169954854, 44.276691175276234, 43.80850922676825, 43.65359521681263, 43.89584472102504, 42.65676013885006, 41.81708658895185, 44.384634802418375, 45.54502487182618, 45.2012252038525, 44.00183500782136, 44.86698435198876, 43.84688177416402, 43.37410673018425, 43.143283090283795, 44.87322092056275, 44.65278371687859, 42.654669515548214, 40.185984642274924, 44.120741659595126, 42.86055472589309, 41.86456687988774, 47.460153487420854, 44.22915204878777, 43.289450214755156, 42.250716378611905, 42.86151962895548, 41.30938283858761, 41.519617957453576, 41.010659048634196, 39.43747481992168, 39.48019335346837, 40.43578078669887, 39.14980819148403, 39.22044223354709, 40.84767280086395, 37.76097536087036, 39.49055625546364, 38.12061748197002, 38.90159668460969, 40.29511674757927, 40.2511901240195, 39.84483649653774, 39.553357324292584, 40.17387628555298, 38.49661588668823, 39.84126713968093, 38.58759134046493, 38.42983753450456, 36.641593671614125, 38.488284772442235, 38.29715551868562, 35.87459771863876, 37.94406375577373, 36.37588839377127, 35.74060563118228, 38.893873537740404, 38.8463108770309, 38.770354178644, 38.98162872560563, 42.02826699902935, 42.274925247315444, 42.38384554463048, 43.039399116270005, 45.043400795229026, 40.09364812604843, 39.48729284348027, 41.321636323005926, 39.09421643903179, 38.4512968217173, 39.265121952179946, 40.32919429963635, 40.64487449584469, 39.67629225023332, 40.12231672963789, 39.713523387908936, 40.071710309674664, 41.39172907798521, 39.98301767533825, 40.782910546948834, 37.12843433503182, 38.31719490789598, 37.94820185630552, 37.6964053030937, 38.783070502742646, 38.97363101282428, 39.4256841751837, 41.749868931308875, 42.60058395324215, 45.171270062846524, 43.20263247336111, 45.049131378050774, 46.011771232851096, 42.52733369027415, 45.71740911852929, 45.75339686486029, 49.03471839043402, 54.04815466173234, 57.02600240707398, 59.0233164448892, 63.18004431263093, 60.945709290043006, 1.2602623167537874, 0.2959658734260067, 0.07489220389435369, 3.6466952100876844, 54.433845243146344, 49.48014274720223, 57.51696940391295, 46.74339132924234, 37.51911809367519, 35.01229209284629, 39.0876974598054, 10.580634724709297, 0.5068144142147034, 0.018181896039975748, 0.05508998784446909, 0.10449402514965304, 0.03187051977992299, 0.057821344103543997, 0.03929876684842091, 0.07426434887513038, 0.039517396850691694, 0.023050643353452607, 0.03279753787923725, 0.026555547317970666, 0.013593553186153934, 0.05468442089735501, 0.05653186873983472, 0.030884191153510928, 0.023733968884053252, 0.030185051652933323, 0.031118878358674627, 0.0258843700266293, 0.010910714232933619, 0.028759668461017074, 0.020259572455899853, 0.04401658143427584, 0.011554845747718168, 0.037323765366548495, 0.030787987747199597, 0.038095901554991166, 0.06465883970621132, 0.043146412804602616, 0.043648981804689096, 0.0794715634096534, 0.0653978847267647, 0.2566525700592226, 13.987275977288524, 64.85848926728772, 31.856239303465816, 32.40596928904134, 47.79882269520914, 54.29045907912716, 70.13575200111636, 59.990839650554044, 63.09905913568313, 35.274420169092, 0.20063885637829382, 0.21749662115208565, 0.4506255728342841, 2.056664401485074, 56.841819670892534, 65.94411111647084, 66.17633112015264, 64.72082584134995, 64.02585637184882, 67.81119854219499, 63.914202182523674, 61.44755694173998, 63.60638633851082, 63.5966000249309, 59.757286041013664, 52.230516556770574, 51.146153788412775, 47.106944053403794, 45.869397040336366, 45.27922937946935, 45.78806277244322, 46.545605813303304, 45.92934262367987, 45.04428332851779, 44.835189619371974, 46.111952489422215, 46.748074639228086, 48.32712281134821, 46.794554725770034, 47.19338132489113, 45.566409634005645, 45.1708346797574, 44.622910945646225, 45.9857580738683, 45.93402201129545, 44.19940087103075, 42.682777220203036, 45.75975894927979, 45.38740834882183, 43.63477960709603, 49.38389170554377, 47.63724457833075, 46.60599854684646, 45.07038277964438, 46.27036133120137, 42.57047191742928, 44.32575610376174, 44.59278714272284, 42.087549701813735, 42.07166018024568, 42.36355512372909, 41.44120585533881, 42.82372366997504, 42.246150739731334, 40.7504843127343, 41.71120612852035, 39.68273670442643, 41.609455923880304, 42.10273711912094, 41.53012206477504, 44.614815173610566, 41.773273714127086, 40.83504669127926, 40.62053618892547, 42.32695548765121, 40.68408250808716, 39.81956074314733, 40.76134143337127, 41.39250178490916, 39.047567690572436, 38.52835178375244, 39.42589206080283, 39.30431819731189, 38.36709922359836, 41.285389700243556, 41.608793043321185, 40.1460745257716, 41.5014926848873, 43.01357030868531, 45.39726526506486, 43.360731447896654, 45.76126513942596, 47.64350860349594, 43.82222575526084, 41.815262686821725, 42.12855023722495, 40.87042254786338, 40.60940842474661, 40.072381034974136, 43.630488534127515, 43.77454542344616, 40.63387616988152, 42.17865851617629, 41.545023149059666, 43.744249036235196, 43.91085955404466, 43.418672700082105, 44.39546446646414, 40.342212646238266, 41.12840860120712, 39.35451276840703, 39.70736134436823, 41.61552775290705, 41.22050977522328, 42.06738087438768, 44.70994833976992, 44.87951240231914, 47.62381438286074, 44.19591388394756, 47.75945778815977, 46.73520926506289, 46.28156362041351, 48.376109292430264, 49.116617479631984, 51.744017139557876, 57.50007183321061, 58.5324239730835, 62.66014591340096, 64.07011639687323, 63.7855209842805, 1.4390331626899782, 0.10298999537143017, 0.6239718727527127, 4.29571166153877, 63.06056891718219, 53.89208355257588, 64.47355570331698, 50.020433548958074, 46.09420768676266, 34.44112439309397, 45.99270851381364, 15.009874163135407, 0.5236400952262263, 0.05191521989482065, 0.05896571092307568, 0.07250913418829441, 0.030075928173779003, 0.006561479869208509, 0.017856933033814835, 0.02250035665178251, 0.02565059446609549, 0.01933465726793774, 0.07029573763570479, 0.014964834291247592, 0.07638320251698456, 0.06385686056267831, 0.05056244268592808, 0.1030215198895143, 0.06494109714103323, 0.11721915925943083, 0.10519277394538927, 0.15366415282891643, 0.2167354208687621, 0.10362374926767043, 0.09368400359826703, 0.14327103632592386, 0.15662299889710643, 0.1781837621162976, 0.19137038759166197, 0.09651778581281824, 0.11192196003732183, 0.1619433876006834, 0.23872595941347463, 0.14208965213789096, 0.18471732765676516, 0.4086177543767037, 17.79481484043983, 74.51159523379418, 45.69203530588458, 44.56647980597712, 49.670358088708696, 63.88878130143689, 75.85729768199306, 65.72900441385084, 69.40793268142208, 43.09745411719046, 0.3832761174248111, 1.010990360331151, 0.7479953177032933, 3.7840534265964263, 61.23804746135589, 69.8272575870637, 67.60732158537834, 68.0945505634431, 67.59740583358273, 69.53981845609604, 65.95619986134191, 61.96318780222247, 65.6644735797759, 66.18288932308074, 62.80085702096263, 56.16293976383825, 53.76879561331965, 49.04789363184283, 48.560343019423954, 47.918937436995975, 48.028014629117905, 48.86337357182657, 49.45693016052247, 47.2547624957177, 46.439615526506984, 48.87309712748374, 49.16929491104619, 49.38673934628887, 48.50290383062055, 49.29216315669399, 48.00166414630029, 46.831903534550825, 46.65402012486612, 48.46664544074766, 50.15252328688099, 46.294907523739724, 45.53343426796698, 47.98994018185524, 47.02978710974417, 46.33064816074987, 52.20608803533739, 49.95440829184748, 48.87581925238333, 47.100201499077585, 48.85064155824723, 44.80568162856564, 47.52133069499847, 47.13511451598137, 45.72643056992562, 45.08444055434197, 47.76752218123406, 44.84573295039516, 45.757280011330884, 45.421411375845636, 41.922229643790956, 43.41810787877729, 43.021211085780976, 44.02675774789626, 45.74496376898981, 44.10367542697538, 47.53880485411614, 43.74441769815261, 44.15778844587265, 43.33371023977957, 44.11018263909125, 43.10412214648339, 42.73200688823577, 42.97651960003761, 44.53586178441202, 43.169347240078835, 40.20146623734505, 42.109142349612334, 40.83500746757754, 39.67863782759636, 44.19149337276336, 43.329015162683305, 43.28442958093459, 42.527337612644324, 46.32272497300179, 48.160884918705115, 46.788282855864495, 48.10760736465455, 49.95061928226102, 43.70869275062315, 42.43767615287535, 44.78176693762503, 42.948439351973995, 42.61718342381139, 42.32326061494889, 44.858884657582934, 45.235341979611306, 42.15812098595404, 44.110457205003314, 43.23570589865408, 44.86294038834111, 47.614486986590975, 46.01825491074593, 46.84518075758412, 42.98401524943691, 44.011366367340095, 41.35128159676829, 42.04935758344589, 44.76887410686862, 43.10258849974602, 44.62333456162484, 46.72817253297376, 47.691628240769916, 52.58252182314473, 47.22732943873252, 50.71245731845979, 50.142893868107954, 47.63284760136759, 50.39440801066738, 51.86967026802802, 54.315389663942405, 60.225275793383204, 62.05231189727784, 66.53997405882805, 64.99965536978938, 64.42929960066273, 2.3421729908835505, 0.4656852986062727, 0.7287784617754721, 5.709531951335169, 70.63142976453229, 59.6143784061555, 72.72854851138207, 55.53308163919757, 52.363441759540194, 45.75591894888109, 55.926291404231904, 21.836752583903653, 0.7009623608281536, 0.11812999183612487, 0.11309868641077511, 0.2417122773946293, 0.15918893379069146, 0.13900745059213332, 0.17036070205992268, 0.18227445712733656, 0.14825261498410858, 0.09832740806403661, 0.2198216826805184, 0.12253973948498889, 0.11492146239165338, 0.14656775781223852, 0.12014352371014896], [0.010203147765188929, 0.04249094797658824, 0.0454995246423829, 0.010956491816848999, 0.06908351074784033, 0.0486227233834084, 0.056492361585579576, 0.04318749426954216, 0.027051049156955657, 0.059028533963306304, 0.0037497542836072467, 0.016673957298119223, 0.028510571141997655, 0.02493888920833988, 0.021829173614781712, 0.08567404873188465, 0.03968466831851871, 0.02824747548138182, 0.0442712711951425, 0.2418294122382518, 22.479060311471265, 48.443389707996005, 34.28124074013003, 32.15378442118245, 39.06908581333776, 52.439657334358465, 56.160747158911924, 55.418760238155244, 46.644637815413944, 1.6390337146097615, 0.07799155814873596, 0.3943646579019485, 2.6989436918689362, 45.43502984508392, 64.96547583610781, 62.34046882198703, 62.03865028196766, 62.565448130330736, 64.95300662133002, 66.42105563994377, 61.92726281381423, 63.082020359654585, 59.123709509449625, 56.96813175755163, 52.87570330404466, 47.42720165560323, 47.24441528320313, 44.53776021157542, 44.1418557782327, 44.14022014987084, 44.95391191974763, 42.22005913334508, 42.82796767450149, 43.174320805457334, 43.23949098587037, 43.847332846733835, 43.01322121773997, 43.404034414599025, 44.38197151307137, 43.312078368279245, 42.60248630277572, 44.25879340017996, 45.539117782346665, 43.773913921848425, 42.84518687955795, 41.96897252913445, 43.73316441812823, 42.5622231729569, 42.505246823833836, 46.09163461192962, 43.426980280107074, 41.03017284024147, 40.88999909739341, 41.743502924519206, 41.24332620251564, 41.74656629562378, 39.72524735235399, 40.003778780660326, 39.88994375351937, 39.961028868152255, 40.37429763424782, 40.60778456349527, 40.35608214716758, 39.975827970812404, 41.931945354707786, 42.2965375069649, 42.7905325735769, 44.31201996341829, 44.45641809894193, 43.07105656593077, 44.05988216400147, 42.678572439378314, 42.00384632233651, 42.53739456976614, 40.3360741369186, 39.296167512093824, 39.023551018007346, 39.21874384726248, 38.38422429177069, 36.94805237554735, 38.17474619034798, 38.76776541433027, 37.800779573379025, 37.53373676730741, 39.61656631961946, 39.73047194942352, 39.26347455670757, 41.09600982358379, 38.48876330160326, 40.32243605582945, 43.77492589335288, 42.13297074840915, 39.08423792931342, 39.38280090208977, 40.79409714668028, 39.75477887738136, 40.93591436263054, 39.10804671625937, 39.717084900025405, 40.94431215716947, 40.08720367185531, 39.864240461780184, 40.071675008343114, 38.935944880208666, 38.83294343948364, 38.74637280741046, 39.77044874621976, 37.610532852911184, 38.608579943257, 40.222031224158506, 39.98388059677617, 42.281703102973204, 43.41480132072203, 44.39558605993948, 45.252937732204316, 45.738036863265506, 47.38262391859486, 47.50560199060748, 48.50994056270969, 49.19611607828448, 49.93163501062701, 49.16132073248587, 50.105807858128706, 49.5747777723497, 52.87041202668221, 54.27198863798573, 60.05234633722613, 61.30952089063583, 57.00820269123201, 0.6368100354748388, 0.11902453738354868, 0.33776825774581204, 9.966907347402266, 61.414197183424434, 44.41146381439702, 63.39091877783499, 34.459677204009026, 39.66685502759872, 43.302252830997595, 38.97749846981418, 3.000966685433542, 0.22626564657736212, 0.06213388285569607, 0.13550075972753187, 0.03796782314537033, 0.11390925339993932, 0.058783424131932764, 0.06227114665952902, 0.022838515522439155, 0.044516066930467085, 0.06347300837777796, 0.015885996605990636, 0.04889670706864807, 0.037915905366741845, 0.025951161402307694, 0.026141624266822493, 0.007932414319516431, 0.02872634172109106, 0.028674106015973998, 0.029102199778501547, 0.051530521182763966, 0.050185408683553825, 0.01852187436945256, 0.04336136941527648, 0.01938863773830235, 0.04242021890897905, 0.04288245721029178, 0.0574220399252109, 0.03148026309997565, 0.047009786545869806, 0.07051972642300591, 0.1349090487365761, 0.04096417687833309, 0.08656392880384961, 0.062039684684526544, 0.5471059199302428, 32.57318777422751, 52.74021679355253, 27.658230450845537, 41.273944224080736, 46.97605456075361, 62.845819150247884, 64.1878737941865, 64.3157862078759, 52.57879949385121, 2.0540525932465834, 0.469235779056626, 0.5106326577163512, 2.565109234663748, 51.06889094075849, 66.74017183242306, 67.08742710851854, 62.75423572909448, 66.06809723761775, 66.319379960337, 69.07508034859934, 63.25311414657101, 65.36578116878387, 61.59191977593207, 58.71074276585733, 55.191733452581595, 51.383284599550315, 48.29121743479083, 44.89062447701731, 46.737437171320764, 46.339296986979825, 45.787101791751006, 44.88255223920269, 45.9595448740067, 45.29713892167615, 46.12626129581083, 45.61259946515484, 45.02197288697766, 46.070520493292044, 45.170873903459125, 44.20210338407948, 45.62002451189103, 46.32207778192336, 46.14110746691304, 44.660114626730646, 44.25059956888999, 45.122205134361025, 47.07744782970798, 45.27684065603441, 45.87844987069407, 47.718661215997514, 45.60580199764621, 43.67900825315907, 43.30811285203503, 42.46508959800967, 43.825277359254905, 42.915114894990005, 42.779820580636304, 42.31296047087639, 42.33656529457339, 42.48190087656821, 42.23517987035936, 41.5049365258986, 41.142999818248136, 42.68808810941635, 43.692281553822184, 43.03933243597708, 44.988315028529016, 44.96340797793481, 45.144558721973056, 44.19247788767661, 45.386812148555634, 43.7612368214515, 44.3041556112228, 42.75811418410271, 42.170594123102006, 39.85778424047655, 41.1826628254306, 39.686815969405636, 40.814356188620295, 40.62622362567533, 40.92506116436374, 40.187000536149554, 40.276085407503196, 39.76961328137306, 40.698367780254735, 41.99116137719924, 41.19752860838368, 42.377259885111165, 41.769837717856134, 43.43400916745586, 45.78585840040638, 42.92241442588068, 41.141340655665246, 41.58238764732115, 41.916797161102295, 41.49727221458189, 41.469325327104144, 41.31420735389956, 41.53624096224385, 42.27190894465293, 41.40121729143205, 41.021053329590835, 41.99097310343097, 41.40197038650513, 41.36388417213194, 41.97543659517842, 39.76588702970936, 40.52892138881069, 41.79874950839628, 41.51617019407211, 41.15010715300038, 44.05484191833004, 45.08088688696585, 46.008421528723936, 48.02273904123614, 48.717869327914336, 51.40243753310173, 49.177892746463904, 51.45489138941611, 51.12733033395583, 53.40924370673395, 50.534703346990774, 54.05846657291536, 51.53817899765507, 56.97429772346251, 55.246281854568, 63.214290526605424, 62.56085503485895, 60.55224849331764, 0.6918775386387302, 0.0907928873634627, 0.7044718402527994, 10.710304360235892, 67.86651180636498, 52.25279169697916, 69.0841410236974, 40.97862112906672, 49.15096567523096, 40.55168290292063, 48.87335600391511, 4.964820944493817, 0.2692874743332786, 0.1272386163773556, 0.13189292993516694, 0.04377720194057592, 0.044741653011090336, 0.022739594419216438, 0.02253695841758482, 0.044190835793532675, 0.13386839490023353, 0.055758208036422736, 0.02953406843927599, 0.011727629218160385, 0.010908045374127406, 0.04998873476119292, 0.05444012311918121, 0.17063460913636994, 0.08633589507230828, 0.08051451550976885, 0.14287317622332804, 0.1813722813441869, 0.19255684328175363, 0.12090753553615463, 0.17879755176123113, 0.1876657855727019, 0.12163846768558988, 0.11925449399577996, 0.12083003042085518, 0.15375239083603506, 0.11052979441780238, 0.1760829804885772, 0.276059691583918, 0.11849603630722531, 0.12372752050718955, 0.19986222708417525, 0.5956717268113167, 42.81602405732678, 63.99731328410488, 47.663269504424065, 46.8088399979376, 53.26455531581756, 65.73542141145276, 72.21278036794355, 68.8050800754178, 61.59161383105863, 2.7186808134278944, 0.7503723353147508, 0.49400671114844663, 3.9976232955532693, 55.18837590371409, 68.17982289098924, 69.72406787257042, 64.88720493931925, 70.7369258326869, 69.52617645263672, 72.47401806616014, 66.6015709600141, 68.2945365290488, 63.186441698381984, 60.959221855286636, 58.01791098810012, 54.018340726052564, 52.97818699190694, 48.96035025196691, 48.523543342467285, 49.07154944635207, 49.388747599817094, 46.3237016431747, 47.499016331088164, 48.00792817146548, 48.160865306854255, 46.798331968245975, 45.43737542244696, 47.18460698281565, 47.4559957750382, 47.61801711974606, 47.980483347369784, 48.432234487225934, 48.2916332060291, 46.203033847193566, 46.3058783931117, 46.254969950645204, 50.54186167255525, 48.29279030522993, 47.772146655667214, 51.881955131407715, 47.76798109854422, 46.32385069324125, 45.442698078770796, 45.65429818245673, 46.30058711574924, 46.88436131323538, 45.58222855291059, 44.80451668462446, 44.95621042866861, 44.68007556853756, 45.157055393342056, 44.45358222530734, 45.84237975458945, 45.78534849228398, 47.73213455753942, 47.1362010125191, 48.63308729663972, 47.666030853025376, 48.42122047178207, 48.23445681602725, 50.07248732351488, 45.37877521207256, 45.86343111530427, 47.535600277685354, 45.249136955507346, 43.455307637491536, 44.186743382484686, 42.89806827422112, 44.345701356087964, 42.37806789336666, 44.50222746018441, 44.35331467659243, 43.29340788625902, 41.68282385795347, 43.90680382328649, 44.394440727849165, 43.521199534016276, 46.0163604059527, 43.90317955324727, 44.07505781419816, 48.51542795858076, 44.63708639144898, 43.36729749556511, 42.7751608048716, 44.46178390133766, 44.114614917385964, 44.13240286611742, 42.90643861216884, 43.21183435378536, 44.33339688085741, 43.890298489601385, 43.971397415284194, 44.14339726971042, 43.976994637520086, 43.00303874477264, 43.59790932747626, 43.34481446973739, 43.40461492538453, 43.97105224670903, 45.45142927477437, 43.278114564957164, 48.06702652285176, 50.23667381655786, 49.303902810619725, 49.68905210494996, 50.80755910565777, 53.580478698976584, 53.821406364440925, 52.942732687919374, 55.37749298157231, 55.56324858819285, 53.35427168876895, 56.129987932020626, 54.437638175102975, 59.61930490309193, 57.94672781421293, 69.34058558556342, 64.84577294318908, 61.53617505104312, 1.3548702530322538, 0.45311011854679356, 1.4139746105478657, 12.521006734140459, 75.60611694089829, 53.33304774376654, 77.69719523768272, 43.67592134783345, 54.20033870204803, 50.63069158984769, 61.666660539565555, 6.560621069323632, 0.5131890931196752, 0.24072570936574092, 0.27214979332300926, 0.12991455383598804, 0.1862612246505676, 0.14177958571141766, 0.14291338051759428, 0.13014850176630482, 0.19670266597982378, 0.30046691577280726, 0.19052583694217667, 0.0936729719321574, 0.14338317627628006, 0.09796618994685913, 0.1349553970559951], [0.011128986089099801, 0.04801273736501894, 0.09097228983357068, 0.021829788400340947, 0.061370698404648615, 0.0662065364961182, 0.027761151375729713, 0.038728012192633846, 0.07151192519813776, 0.06049373840552665, 0.03353545292010231, 0.03375004946945175, 0.075987464477939, 0.10013562837435354, 0.04942687055576713, 0.007703896994972903, 0.07139045429686386, 0.052040096056917985, 0.08419038157068914, 0.16406635513469098, 3.0449921036920244, 49.751864940889426, 36.087405912337765, 26.46861284009872, 30.158474714525287, 54.07638003749233, 65.8857697825278, 52.77371383482411, 57.17164785631242, 6.17061980309025, 0.30116684434394686, 0.37292017150790463, 0.31149303540587425, 33.206997686816806, 66.68898490167433, 59.91416515842561, 63.55769795756187, 59.61588067393149, 59.08858076218636, 64.176298879808, 62.058485707929066, 61.32984661286878, 57.55399265596944, 56.262042368611986, 52.424646423709014, 49.95076833232757, 46.31780239843553, 45.90678115044871, 43.6989378160046, 44.09572478263609, 44.48252539480887, 44.646213746839955, 42.37108607445994, 43.43590367224909, 42.90367726356753, 45.20083688920544, 43.377789835776056, 44.849592562644716, 44.06305536147087, 44.53122946523851, 43.57854066356536, 44.54219641224031, 46.09067755360758, 44.93891669857887, 43.35183943471601, 40.76439695973551, 42.89602471936134, 43.88332451543501, 42.641780607161984, 41.915028172154585, 43.457876789954405, 39.53687160245834, 40.846178377828295, 41.51585248208816, 41.58268182508407, 40.58123011742869, 42.6701864119499, 42.64565983126241, 43.48032843682074, 39.42633921100248, 41.455777460528964, 40.08533270128312, 42.035903853754846, 43.07850122451783, 47.89255949758714, 53.33669947039697, 53.161910810778224, 52.14807225811867, 54.609414454429384, 50.629193244441865, 50.29374822493523, 48.93354869657948, 47.625061696575536, 47.536223934542754, 48.20785137914842, 47.14984693834859, 41.5927230927252, 40.87257592908798, 39.71732808697609, 39.2055921400747, 38.0535331849129, 38.44547602438158, 39.0532119812504, 40.31746249045096, 37.574882430415, 38.315123896445, 41.29251272447648, 38.50546475379698, 37.253985481877486, 37.51089288342384, 40.61372695430633, 41.40937974376064, 40.62130105110907, 38.19379321990475, 41.03245565968175, 38.89335970724783, 41.11193072411322, 40.244016108974336, 41.35661209783247, 38.629839189590946, 40.63319759984171, 39.6767197885821, 42.95161647181357, 38.33179396967734, 39.88191466177664, 38.8739675091159, 41.25373225058279, 39.5433670474637, 41.44369656039823, 41.351285519138465, 42.21700752935102, 42.96895334797521, 45.886176939933534, 45.01519110894973, 46.96743319111486, 48.07783265267649, 49.16177964979603, 47.607838569148896, 55.070355707599276, 51.51768461350472, 52.72327999914847, 50.74251836346042, 51.82844615751698, 49.91606712341309, 55.24706632860246, 55.450276482489805, 59.52208895837108, 60.97517413477744, 56.13395344826483, 0.07611540116129384, 0.2676106917281305, 0.5556146440006072, 25.937021855385076, 56.06007952843943, 42.60406701795517, 47.77215057803739, 30.049799565346014, 35.86374452037197, 44.19005386291012, 25.93624914846113, 0.6656064838171006, 0.0415418301558783, 0.06969664155715896, 0.06345798922402245, 0.09238421286065733, 0.16663434314391307, 0.02409082030006234, 0.0030332396695044853, 0.03034396127106682, 0.040545877549917474, 0.039769075886015935, 0.06493454708928062, 0.01855591165592834, 0.03320435354966791, 0.020606776909722437, 0.04173598364896832, 0.016993203373145194, 0.09537904207865078, 0.14098728225836832, 0.04268024447223833, 0.006392172522722714, 0.02640874763470023, 0.061890060052035324, 0.031154269705556577, 0.022815605663063548, 0.0029162671407609577, 0.03126302163206762, 0.02241920495796348, 0.13741000405242368, 0.050318156399073145, 0.10297159393948895, 0.044329807973436774, 0.05427111263176607, 0.038090638530951355, 0.11999032144705135, 0.4131813707851595, 6.398113350714407, 62.51230001449586, 35.717491103756814, 34.78746967930948, 41.38133871939875, 56.503119084142874, 73.80314457801082, 56.8759992045741, 62.49948955351307, 6.409259746151586, 0.2911422161325332, 0.4442479215081661, 0.38954915178398936, 37.16478293941867, 65.81003665924072, 64.64075849902245, 63.86240728439824, 61.52420789964738, 62.07369273708713, 66.2948965257214, 65.69790394075456, 63.38348588635845, 60.40397505606375, 58.05201991911858, 55.970198415940814, 53.2837906191426, 49.19366459692679, 49.17884588241578, 47.16659938135455, 46.575396214762044, 46.94474227966801, 46.22881950870637, 44.93731244917839, 46.55432524219636, 44.335860129325624, 46.173227756254136, 45.01312009749874, 45.19676546896658, 45.46458098196214, 47.5750946229504, 45.95169228892173, 46.428915300676906, 48.485104114778586, 46.249192299381384, 45.39706522418607, 43.9779987642842, 44.99530861454625, 46.66883491700696, 44.373459969797445, 44.58995519145843, 46.07132850154754, 42.635445979333696, 44.88702374119913, 44.63745117187501, 44.3422104466346, 43.139752957128714, 45.42418449155746, 42.38071549323298, 44.90765148593534, 41.801997230898955, 43.83710330532443, 42.17208854613766, 43.61786242454283, 45.23378087628273, 49.10448951105918, 53.18976356137184, 54.229799624412294, 52.853910615367276, 55.50715477235856, 52.275655192713586, 51.30744164989841, 50.48051188069005, 49.32330677586217, 50.12374093455654, 48.722470268126465, 46.69795459316623, 43.6912735046879, 43.57311994798722, 42.27773366435882, 40.45741265819919, 40.561233874290224, 39.77860727617818, 41.47636205919328, 41.76223616446219, 40.24222358580559, 41.26013748107418, 43.86779192955264, 40.61613136722196, 40.49992722849692, 41.322671828731416, 42.71236758078299, 42.600560419021114, 42.177246462914255, 41.5066506016639, 42.499649601597945, 41.422084300748764, 43.06279997671805, 42.033177806485085, 43.26040898599933, 42.563599924887384, 43.24614332568261, 40.54524237109769, 43.30251170742897, 41.88034657509097, 42.55013050571565, 42.00581927453318, 43.01325259670135, 40.76881747091971, 45.33868466654132, 44.52315722742389, 45.1870576027901, 45.847114055387436, 49.68284691533735, 46.2669567138918, 50.72545605321085, 50.62022278385778, 50.657002848963586, 48.77866214321506, 57.12973733102122, 52.35772294382895, 55.82194851290796, 54.0411336191239, 54.797197926429014, 53.13545050159578, 57.38012575334119, 58.00147625707812, 64.80563140684559, 62.04526732044836, 58.24685189031786, 0.07088895015899213, 0.12831342241336263, 1.4909065082188577, 30.10119438171387, 61.8796334728118, 48.46201312157416, 54.408200786959746, 41.52515634413689, 37.03491718538346, 47.026500163539765, 34.24367620098975, 0.6735939616637846, 0.038945922072255806, 0.06551434541301382, 0.024904627841146245, 0.039074203495176575, 0.09284277777037314, 0.028342943443285844, 0.04383362431619917, 0.04085596312858886, 0.039322833500562177, 0.008087276120580012, 0.06733822456050305, 0.03254416962003997, 0.06881626863633433, 0.040537033064831654, 0.03011547363243036, 0.10612307281623926, 0.22973286859210462, 0.16411196800970262, 0.18860264981706298, 0.1764318875728115, 0.16574172813805843, 0.197424826422526, 0.1903680534732919, 0.1318541812079568, 0.1911108829681912, 0.14641123072754952, 0.1253872346733847, 0.3093163651083746, 0.15549989867835276, 0.1876392942522803, 0.12344684121349167, 0.2240258199913848, 0.15434590979449211, 0.26388091605997854, 0.7314772363151274, 9.688217063103954, 73.1659241645567, 49.729440750614295, 41.03912761134487, 44.279130889523415, 67.1534013748169, 81.8670512783912, 62.56830753818635, 71.023054892017, 9.25184847847108, 0.4729901614689058, 0.7903676407952464, 0.4972567932019311, 43.43403662404707, 68.06004155066707, 67.50819544638357, 69.2656369363108, 65.93062600781842, 65.0888265332868, 70.31593784209221, 66.92518218871086, 66.40431496404833, 63.4523509394738, 60.60233323804794, 59.20403572820849, 57.074596651138805, 51.51771991483627, 50.92907413359612, 49.771174769247736, 48.53192544752552, 50.55674314498902, 49.39578433190623, 44.98470644797049, 47.57310598127304, 45.403070372919885, 49.729546654608946, 45.94450650676605, 48.49442758867818, 47.97904775988671, 50.826410016705914, 46.64029575163319, 48.6142324632214, 50.772602942682084, 48.76826001751808, 47.681555594167406, 46.288149279932824, 46.233291010702814, 49.2234589207557, 47.80542012183897, 47.23030259532314, 49.5847955057698, 45.748878294421786, 46.720959294226866, 46.87330022934945, 47.94324436495381, 46.93822330044162, 47.78612990533152, 45.90433751383136, 49.64665520575739, 45.70171571546986, 47.47993400019985, 45.80181067989719, 47.831033199064194, 47.013250397097686, 53.20884196988998, 59.42246075599425, 56.45857664846606, 55.59858522107525, 59.49805267395512, 56.30025409883069, 53.26419838013188, 52.66125163724346, 51.89282009678503, 52.766147582761704, 51.468525548135084, 50.62711046588037, 47.09081526725523, 46.403992560602006, 44.122475347211285, 42.6596313138162, 43.18708027562788, 42.90563844865368, 43.61741135197301, 44.01539071913689, 41.955463886260986, 42.99492728325629, 46.63270596534976, 42.333851014414144, 43.02700442652549, 43.53034257888795, 44.89548037129064, 44.12384033203126, 43.60526769391952, 44.429530251410704, 44.35434625994775, 44.84931799673265, 45.162119173234515, 44.469122655930065, 46.56577856309953, 42.682781142573205, 45.25636196136475, 43.84707789267264, 45.97502646907684, 45.163084076296904, 45.017732804821385, 43.8390488009299, 44.95388054078625, 43.41123196386522, 49.2167006769488, 46.396057605743415, 46.47330084154683, 47.948731760824884, 51.32180144709926, 48.69195030581567, 52.65497192259758, 53.462725224033484, 54.63582377279959, 49.62565483585481, 61.21326200423702, 54.27332616621449, 57.927872980794604, 55.70998837870937, 57.318305277055316, 54.43265676498414, 62.428761374565866, 60.29285038671186, 68.68366702910393, 63.893503835124356, 61.67534074475689, 0.3331517812705809, 0.6942612978239214, 3.01633894443512, 30.935080474422826, 68.4542711319462, 52.68031043391074, 60.93547190389326, 42.73264623457386, 46.027676443899836, 57.18977705124886, 47.070752343823834, 0.6263137728937211, 0.1238086032530954, 0.16847961912712744, 0.10612917087611654, 0.2395620984175513, 0.3059590307454909, 0.11381943725169667, 0.1606098430291299, 0.13757275177105782, 0.19026590330946833, 0.09113744306828707, 0.14757298774296237, 0.17010688180885009, 0.14460847262413273, 0.09191021894014652, 0.13682782319524597], [0.020516491532626174, 0.04653559344249868, 0.06399012921798615, 0.042110550848226395, 0.011732682525630922, 0.035079648688195214, 0.026569298596211502, 0.03011809556835121, 0.08611146195401108, 0.014570388067964346, 0.04286153534907968, 0.049946193898757624, 0.09401908279546807, 0.024296484264214675, 0.024489720367015372, 0.0054305612443826135, 0.041969142508723085, 0.06840137073830252, 0.02584976966552917, 0.02918130601756275, 0.22963050392366227, 30.295479182274114, 48.52217051290697, 29.763913692966586, 31.295242309570316, 35.87396229467085, 64.31449182571905, 54.61086965376332, 59.632613505086596, 15.87890273140323, 0.36208349009675367, 0.23661512671218765, 0.4251674292308669, 13.50665815414921, 69.06303082743, 61.92514081155101, 64.16053095171529, 59.55813554025466, 58.671981903814505, 56.55734192940497, 59.64988370095531, 56.84756594319498, 55.01835292385471, 52.80668135612242, 53.44205433322538, 48.8527714052508, 49.00627336194439, 44.810141363451564, 44.98065856195266, 44.270215342121745, 44.69071695881505, 43.0013442808582, 44.7106739782518, 45.59103819631761, 45.43145656585694, 44.58271841849051, 46.63682053166051, 44.56823310544414, 42.939555183533706, 45.12195802504017, 47.02725325861285, 44.70990519369803, 45.42243903683078, 44.003525549365634, 43.399810021923436, 43.15834891411566, 44.07213564841978, 43.67967113371819, 43.06204688164496, 41.82242493475638, 43.40131621206961, 41.69464195928266, 41.2686215677569, 42.743448442028416, 40.91743607674876, 41.97238106881419, 40.74056071619834, 41.76783338669808, 42.88281417662098, 43.50090519074471, 41.998182419807684, 43.869066699858635, 43.387560459875296, 42.95071040430377, 49.945728086656146, 56.91679185436618, 58.89848309178507, 58.75490473162744, 58.498519005314, 58.248334546242994, 53.12369908055952, 51.980222271334746, 58.60481915935394, 57.49098762389153, 58.55504428186725, 54.8610854917957, 44.48929148335611, 41.32997528199227, 42.76717485920076, 39.94932843792824, 40.84429956251576, 38.13377703389814, 37.89471641663582, 39.369955139775435, 40.07968056586481, 38.86444791670769, 40.51755828242148, 38.50497445752544, 39.41622734069824, 39.159818080163774, 40.3044637556999, 41.81465079707485, 40.2488955374687, 39.303455275873986, 41.05625660188737, 41.11444496339367, 39.53633031537456, 39.08388099362774, 40.165764824036636, 40.32759005023588, 39.400459412605535, 39.61814311242873, 38.46218924368582, 39.41972609489195, 39.373026355620354, 39.2166571463308, 39.854595353526456, 40.29848998592746, 41.27759202834099, 43.57768950923797, 44.865442860511045, 46.41427701519382, 46.066955058805405, 49.09021992837229, 50.00072363884219, 48.70949506759644, 48.29457106128816, 49.744808596949426, 48.64441510169737, 51.780161780695764, 53.260056357229914, 53.0016270760567, 51.175175405317745, 51.43595810859434, 52.37107469189552, 58.8876259711481, 54.25761707367436, 67.60884346500521, 34.32889361535349, 0.3953602351248265, 0.1478989887982607, 0.37131181587615325, 40.490972457393525, 47.51823986730268, 60.43385567203645, 32.71173961700932, 27.66334914392041, 47.20368931370397, 38.95675697634297, 3.585341250704181, 0.28697089802834297, 0.06472566555584632, 0.05117800199396668, 0.06725513466423558, 0.021493565816912922, 0.04730084633094169, 0.020623579133121718, 0.03962404395063077, 0.04631095731090154, 0.03626977393944417, 0.034213865911888505, 0.041853608788862344, 0.06936952201349121, 0.052784358136235714, 0.02651955267684835, 0.023698713517777865, 0.05455578324354945, 0.004792316157686254, 0.1413881607473858, 0.0631953934357772, 0.028258959139366786, 0.022613153522533756, 0.019665825586285324, 0.032353586096677094, 0.052109281457359755, 0.038835628393797145, 0.021749243831201907, 0.09668444824074546, 0.02225668515048681, 0.028019960774409196, 0.05680973649085049, 0.035351709492744944, 0.06204548780055297, 0.03278385937934922, 0.02807678343097289, 0.03925095913150618, 0.39112952988474603, 42.03185204536685, 53.63146558884652, 28.93512668148164, 38.888272393134336, 48.49699674114105, 68.18972295330417, 60.493032470826186, 64.0695554979386, 18.10623142027086, 0.5396350917796935, 0.13391636732605197, 0.5765461272770359, 15.082640993979672, 70.17143772494408, 63.047483890287346, 65.85363772607619, 62.85473469764956, 61.73616886138917, 60.340158093360166, 61.397366293015025, 59.05285581465691, 57.88987698093538, 56.21376191416095, 55.88964862208213, 51.452620337086344, 50.81286999487108, 49.2271420263475, 47.62510092027726, 47.03197579230032, 47.35556348677605, 46.237715444257184, 47.073490158204116, 47.26410950383833, 46.27249117820494, 46.33405670042961, 48.76478479754541, 47.67579363238427, 44.50544772609588, 45.75119249282345, 47.63449891921013, 46.531520582014515, 45.64371955010199, 45.4442552597292, 45.65605540429392, 45.806003693611395, 45.930927261229485, 47.01653734330208, 45.0494255558137, 44.101329849612334, 44.943282296580655, 43.590943198050226, 43.99371570156467, 44.343653878858014, 43.76702231745566, 44.439653888825454, 42.189029262911895, 45.51660729992775, 45.191893885212565, 44.823489189147956, 44.50751873754686, 45.061784944226666, 44.422877911598455, 44.35012578964234, 53.20561385923817, 59.97451082352669, 61.55725779071931, 60.23359514051869, 60.33670640760853, 57.82739754646056, 55.38850699701617, 52.699522203014745, 56.39885464022237, 56.90634266022713, 59.46218259872929, 55.72567785939863, 46.12504928342758, 43.15407353062784, 44.11567395733249, 42.51644911304597, 42.00057898798297, 40.25665398566954, 41.70728768071821, 42.05397421313871, 41.813191675370746, 42.19964711896835, 42.08015995640909, 42.08551006932413, 40.55742917522308, 42.60776973539784, 41.94921555057649, 43.53283328394736, 41.132103473909446, 41.93473808227047, 44.85324036690497, 42.71718425135459, 41.004493082723315, 41.760529933437226, 42.59159780317738, 42.50299538335493, 43.185730980288604, 43.222848369229226, 42.443512639691754, 42.349748380722545, 41.133142902005105, 41.37575718664354, 41.714202819332, 42.240110289665964, 42.91769973693356, 45.324944603827696, 45.860379511310214, 47.82966429187406, 47.86969207948255, 49.34060442832209, 53.06503611226236, 51.11517490879182, 51.15140191970333, 52.9554803909794, 50.53347564512684, 55.36817343004289, 54.89554743612967, 55.013418582177934, 53.12043566857615, 53.710089498950595, 54.84710616450156, 62.79660909406601, 58.13837482083229, 68.92065663491526, 35.09281050774359, 0.3103211966733779, 0.3068587550472829, 0.5434964200662029, 45.80780013915032, 54.864886268492675, 63.86237982780703, 40.309641284327355, 33.442186924719046, 42.67963147932484, 47.878921416498, 6.3683759012529935, 0.2646823053158099, 0.0947644020761213, 0.07421266858375843, 0.017133977774891163, 0.09209849270841769, 0.06181942674541666, 0.07650511774925456, 0.058697223918692726, 0.0546377967862833, 0.04577789418098908, 0.06923179472646407, 0.04097356528584515, 0.03700473954180076, 0.03850686942197142, 0.05154541393201198, 0.037308612147406224, 0.16415836229439706, 0.17293625901783669, 0.2873006222709533, 0.10173065407622246, 0.13927771109006098, 0.1528161547837719, 0.14369630705445044, 0.13459525912279083, 0.20083609337527908, 0.16520169743847463, 0.13322183201389928, 0.19484574546016034, 0.17175714245005963, 0.10313161438511265, 0.1387560971441769, 0.11664841609496264, 0.15408738576356443, 0.21741262727206756, 0.10811513124574577, 0.11652758870754512, 0.7715975060578316, 53.87849646229898, 62.11467758301766, 40.44642609934653, 46.991661671669256, 50.233226053176395, 76.0020645203129, 67.19976379025367, 72.74571280325614, 23.234114608457013, 0.7295055711461652, 0.272913460409449, 0.49772723247447326, 19.440717850961995, 73.52219304730816, 65.95500746080953, 71.12504436123756, 66.29451997818487, 62.53952126349173, 62.31514600015456, 65.98610401153564, 60.30372319682952, 60.11288027609549, 57.9974126815796, 59.24738576335292, 53.99314342006561, 53.908498671747026, 49.889893147253225, 50.76920224774269, 49.935106308229514, 50.8412326535871, 48.67917514616444, 50.19186073733915, 50.35495681147422, 49.7782075789667, 48.44996360040481, 52.26093453745688, 49.13546839068013, 48.631122189183394, 50.18443569060295, 50.621113161886896, 49.62834950416319, 49.41132084015877, 48.9441430184149, 47.289961845644065, 48.79754835559476, 49.58376392241448, 50.66348652685843, 48.138331290214296, 45.897853835936516, 48.651228258686686, 47.599530989123934, 47.23162051170103, 47.6142987128227, 46.57125026948991, 46.6087834296688, 43.57409269578996, 47.30782431940879, 48.33813682679207, 47.53798115637995, 45.00363580642208, 46.022079221663944, 47.82356500625611, 47.77733987377536, 54.96471451174829, 61.49828495517854, 63.29470303750808, 61.1930617978496, 61.868619457367934, 61.891400583328746, 58.07506384388093, 54.63687889037594, 60.3238881018854, 58.95694994157361, 63.45606542402699, 57.58957639817269, 48.05110562232233, 45.88760860504643, 48.48457851717549, 44.8151659196423, 46.81200535066667, 43.35706403178554, 43.13392823742282, 42.54657291596936, 44.49876792969243, 44.64050277586907, 45.11364260027486, 43.4026341284475, 43.820252803064164, 45.35335040861561, 45.14897138841691, 46.76534483509679, 43.78011518909086, 42.54547465232111, 45.98979811514578, 44.82016301924183, 43.391627957743985, 43.56444758753623, 44.949448262491536, 44.22351952522032, 43.644322733725275, 45.37389186120803, 43.86377150012601, 43.180008242207194, 44.185601972764545, 42.70268324882754, 43.74160143636888, 44.58025517002229, 46.62093101009246, 47.62151979630994, 49.16903995698499, 51.64162366620956, 50.420138758997766, 54.43566914527647, 56.069736403803674, 53.72071912211757, 53.291627514746885, 54.51008435218565, 54.70501830500942, 57.08691289347988, 58.7760776858176, 56.01819645973944, 57.01566696166993, 56.63192972060173, 58.04969395360639, 64.44627954113868, 62.08370654813705, 68.48994901103359, 38.05456476826822, 0.6939556593856504, 0.7232998912372898, 2.302049840650251, 50.37841650747484, 59.646663435043834, 70.53315085749473, 43.62309878872287, 40.46262156578803, 56.68277932751564, 58.51918205138176, 9.741552472114563, 0.341146644204855, 0.2077909766305839, 0.12665000038161395, 0.1395637836427458, 0.1774718059647468, 0.20356990877659092, 0.22713560070241653, 0.20866483780405215, 0.2688805897149348, 0.12199335025563357, 0.13111553455312408, 0.16763565070446462, 0.19339561762828983, 0.19330797716975215, 0.16714434319686505, 0.12111593443419665], [0.05567920521923131, 0.03233431898538144, 0.04475072732255344, 0.0336665497161448, 0.08806449586465474, 0.01924662227411905, 0.04999138542541093, 0.010541639884092636, 0.020875698669002424, 0.03669498721137643, 0.12386945361692099, 0.013686198114056983, 0.0819867373173756, 0.0294702303325457, 0.032192604210708416, 0.05348540902618439, 0.03660295706903262, 0.06536073712331635, 0.09706532417405998, 0.0732164478470241, 0.3900096012699989, 4.813115923635421, 52.26766140230241, 50.73515607464699, 50.84741823134884, 28.44434991959603, 57.52135853613577, 58.74583228941887, 64.44499692609234, 33.7034010887146, 0.0974187281944098, 0.1797608153954629, 0.09922615177328549, 2.152632542194859, 49.1472041222357, 66.51390598666283, 63.73065487031014, 62.81633861603276, 58.41634927257415, 56.23748440896311, 55.821811229951926, 54.53555622408467, 53.35968063723657, 52.45719425139889, 52.44387388229371, 50.296678235453946, 49.872940663368475, 50.81505475505706, 49.86371132635301, 49.105026875772786, 44.91292315144693, 45.682825580719985, 45.309008013817575, 43.27873429944439, 47.042350461406095, 46.56607274086245, 46.80363109034877, 46.18104504000756, 45.08969653037287, 44.137572550004535, 44.67273289157499, 45.46369060393303, 45.21954267255722, 45.724488996690326, 43.812474743012466, 42.75288958703318, 44.41353090347783, 43.870223799059474, 43.32142929877005, 41.89634984539401, 41.463139749342396, 42.053731026188025, 44.432075869652536, 43.8291173596536, 43.02858121933476, 40.93629483253726, 42.57188397069132, 44.14882975239908, 45.182248776958836, 46.20193558354532, 44.60710379385179, 42.39497723117952, 44.14656262243948, 42.17948613628265, 44.82150446984076, 50.873101911237164, 53.7926044002656, 56.09181150313347, 56.032862201813735, 62.142710762639204, 55.692506374851355, 56.68905511979134, 60.55301335550124, 57.86584854125977, 56.34383163144512, 46.74072411752517, 44.53372017029793, 42.5736568820092, 43.078866004943855, 43.38284969329835, 43.8085170715086, 42.791105239622055, 41.810132226636334, 39.91687474712249, 41.238254577882834, 40.11983386931881, 41.198909282684326, 40.10831779049289, 40.15522541538362, 39.150828007728826, 41.54554874666276, 41.336917877197266, 41.495067842545055, 41.200811632217906, 40.83333653788413, 40.844091676896625, 40.198320496466856, 40.07486781766338, 41.540834057715635, 40.624305586661066, 41.53276574227118, 40.96443783852362, 40.161344312852435, 40.73378678291075, 39.49383143455752, 39.817030814386186, 40.674421710352746, 41.44840340460501, 43.227947450453236, 45.74426558709914, 43.9693695499051, 46.32618450349378, 46.44029801891696, 48.55526747242097, 49.069082275513686, 49.41166993110411, 46.33071091867263, 46.47157499867101, 49.86678254219794, 50.32169903478315, 50.70252587718349, 53.086193376971835, 50.18634980724704, 53.82293216643795, 52.97290355928483, 61.53015813519878, 53.21141112235285, 72.95490064928609, 8.407298441856138, 0.48052690382446017, 0.5199728629762127, 2.0721567830731793, 56.52186801356655, 49.143552395605276, 60.215771890455684, 28.2769686560477, 37.920917849386896, 45.22091550211753, 21.22253687151017, 0.5814541155292142, 0.019343986303635666, 0.08139964583660327, 0.04221721326992397, 0.06470365584978173, 0.01940154823504629, 0.04095787580515589, 0.021236077919902823, 0.10205932111749727, 0.07786077927918204, 0.031019143287032366, 0.04369228875504867, 0.05277133464152294, 0.0429534773913122, 0.022797953082068313, 0.033645466976468606, 0.017026911241813533, 0.03076016534900954, 0.020505919519271103, 0.0071744301690599855, 0.04172210596621998, 0.07535100629132602, 0.026485544118669727, 0.009576249398261068, 0.016920990010182706, 0.044988360135786, 0.03667765064164996, 0.029017160188466794, 0.05386782479622672, 0.05887743461156084, 0.006133597259665089, 0.03444078881593962, 0.040522998334058834, 0.02909408882260323, 0.045717177882550225, 0.09403803581071478, 0.10978190874260281, 0.444022354579741, 9.034183409906204, 65.28022643058532, 46.55706305657664, 55.46794676011609, 34.70609618771461, 65.38294153828775, 66.22582358698692, 69.79186211862873, 38.69551927812638, 0.14277151635577603, 0.7182568876493363, 0.4084645980788816, 2.166603534452377, 52.26056975703086, 65.97599214123142, 67.61406021733438, 65.30332526853009, 62.152104839201904, 57.74381576045867, 58.92184865090155, 56.91998858605662, 55.427263936688824, 54.63724759317214, 55.37947377850933, 52.14595025585544, 53.00517289869247, 53.22854403526553, 52.930020286190896, 52.09937995479953, 50.01746431473763, 47.069179473384736, 46.58300169052617, 45.66308429164272, 48.39433654662102, 47.729604628778276, 47.358281689305464, 48.34366736873504, 47.638236937984345, 46.316637454494355, 47.67647220242409, 47.80775000972133, 48.782086372375495, 48.89756487261865, 45.00326318125571, 44.47360592503702, 45.994426511949115, 44.61298734911027, 45.43976806825208, 44.64347593245968, 44.104055896882095, 46.352487917869325, 45.77141231106174, 46.66967430422383, 44.893519186204486, 43.052570435308645, 44.12249495906215, 45.215212375886985, 45.70523015914425, 45.72969398190899, 45.89320582728232, 43.82597946351574, 46.41924665820214, 45.21840126283708, 47.60606565783101, 53.49029556397469, 55.50740580404959, 59.358188798350675, 58.34501704862041, 64.52758635244062, 58.340416108408284, 58.0923261950093, 64.4639027503229, 61.118183751260084, 60.30969696660196, 51.099230474041356, 45.50770744200676, 44.07964698729977, 45.619573439321215, 45.21884841303672, 45.1802562129113, 44.410451842892556, 43.02528642839001, 43.071613542495236, 43.064157116797666, 41.43484377091931, 41.709652869932114, 44.33156905635711, 41.78278546179495, 41.708221204819225, 43.23610205804148, 44.40480362984442, 41.505611173568234, 43.629527553435295, 42.92400298580047, 42.045654866003225, 42.646836542314105, 43.24721413273966, 42.63898003485895, 42.83228228169103, 42.550087359643754, 43.87559352382537, 43.32499081088651, 42.83646352829472, 42.28580982454362, 43.342210015942975, 41.8639628348812, 43.6336225078952, 44.6558000195411, 49.86626478933519, 47.56347264012983, 49.90506095270957, 49.54761928127658, 51.74102044874623, 50.38439027724728, 51.49644497902163, 49.02683834875784, 50.08870632417741, 52.11276700419765, 53.69927944675569, 52.70533515561012, 56.23543300936299, 51.658019173529844, 57.73493943675872, 55.84713797415457, 66.00065600487494, 56.98915566167524, 76.28911141426333, 7.4520017543146695, 0.2638865238235843, 1.27803175680099, 2.529213664031798, 62.146790027618415, 53.735333873379616, 64.67265521326374, 36.34159118898454, 40.00897199876847, 46.976242834521884, 32.77482309649068, 0.7768479049686463, 0.044862480398507855, 0.05691356821766785, 0.05051223328337074, 0.07519292404815074, 0.023025287758378733, 0.022369667797559695, 0.05352956633413992, 0.05395455744057413, 0.049261334277088606, 0.05039633950218559, 0.04226988564515787, 0.047215285801118424, 0.009057517858192084, 0.053944456571292494, 0.03248146915387723, 0.06362012407231717, 0.10727006731735123, 0.0824902409447297, 0.17402025810893507, 0.10363252863528268, 0.1644093633419083, 0.13821281823179415, 0.15993910240790538, 0.11714121747401454, 0.17834718399230512, 0.12503597569922287, 0.28695251191816024, 0.16173585438199584, 0.31390946058015673, 0.09965485457571284, 0.10600651253855999, 0.14454188426175427, 0.21759944547328258, 0.18107661737069009, 0.2266246660221969, 0.2763820920259722, 0.4936108581962124, 14.297959073897331, 77.35896141298356, 58.668914610339755, 61.14318493873843, 42.05834765588084, 70.24080091907133, 72.10471906969624, 76.2744103708575, 45.73311428869925, 0.3915595503584031, 1.4427071978007595, 0.6192294207792128, 3.4010403531212963, 53.92885185057118, 67.43923233401391, 69.80528446935838, 68.56304630156487, 65.9659351841096, 62.73372173309327, 62.808913569296564, 59.51352642428491, 58.037244350679465, 58.210891600578066, 58.11446405226185, 55.47588171497468, 56.639625410879816, 57.86174181968936, 56.99133257712088, 55.88830324911303, 51.286515805029104, 49.801926151398696, 49.351861630716634, 47.256504028074204, 52.83928017462454, 51.184985253118704, 51.74455842664165, 49.26753459438201, 50.75125348183417, 48.25896770723405, 48.085398904738895, 49.71798742971113, 50.564513360300374, 50.69387705095353, 50.54309721915953, 47.96331905549573, 48.82431853202082, 45.70681087432369, 48.435529278170684, 46.604151110495295, 47.53853813294442, 47.47602339713804, 49.41031279102449, 50.93851527860088, 48.50721451543993, 43.816793272572184, 47.26454880929763, 46.90350640204645, 50.0049441091476, 50.75128486079555, 48.38014148896741, 48.04919935041859, 50.10037929781022, 46.62358645469912, 49.03973510188442, 52.40359898536436, 55.851268229946015, 60.59534357440088, 59.08492511318576, 64.98481312105733, 59.24055299451275, 61.482964177285474, 64.7749976957998, 62.54057245869791, 61.544898402306345, 51.35972292192521, 47.6875921218626, 47.441541840953214, 46.64083311634679, 46.2819323232097, 46.56738281250001, 47.45964750166863, 47.14813286258329, 44.69805179103729, 46.90709537075412, 43.77972295207363, 45.024098811611054, 46.60432761715305, 44.2908509315983, 44.705276796894694, 46.13570636318576, 47.02526853930566, 44.24613198926372, 46.99384643185524, 45.57036730550951, 43.88358339186638, 45.71729929216447, 44.82566610459359, 45.21481621649958, 44.89162860378143, 45.41411184495496, 46.690619760944, 45.46643626305365, 45.8322718066554, 45.689175898028964, 44.978795436120805, 44.91164838114093, 45.88577685817596, 49.62933009670627, 51.86932509945285, 50.150397362247595, 51.43461665799541, 51.387579594889, 53.88962814884802, 54.51749763181133, 54.506044310908166, 51.37040353590443, 53.47091905532345, 56.083150909793, 55.43641874867102, 54.90045039884506, 60.33922456925916, 55.77963006111884, 60.25915722693167, 58.20160735038019, 67.54016276328795, 58.1078117124496, 77.8277317170174, 10.762008063254818, 0.6334608829309863, 2.4691003993634255, 3.119722080807532, 69.91077269277265, 59.443425824565274, 72.44497683740431, 38.8152535500065, 51.3316426738616, 59.62552970455539, 45.22120575751028, 0.7941857617228263, 0.13552113766631774, 0.1831303152345842, 0.10204981396635694, 0.1872022104479613, 0.11714713167278998, 0.1006848904334249, 0.14923841692507267, 0.2129263857439641, 0.11912345465633178, 0.1528921813493775, 0.15555954628413723, 0.14969059266149998, 0.13157550906462054, 0.15555914791841663, 0.0857712729503551, 0.11528120962001624], [0.04464990249083889, 0.039157952227058916, 0.03937272497663095, 0.06537522384596449, 0.08490616816186136, 0.08912796379938241, 0.04978269924439731, 0.04254381953468246, 0.02960399694500431, 0.04307523940599734, 0.030966292796356064, 0.020711455163696123, 0.059327281440698335, 0.031138225909202333, 0.0900328285511463, 0.04214953323225341, 0.10549424486535211, 0.04410899462058179, 0.015754010190346068, 0.2627021825361637, 0.03405954899086106, 0.24085620478276284, 22.560100401601485, 46.46530705113565, 38.703756255488244, 47.218884575751524, 29.088465859813077, 60.157650209242306, 54.23700894078901, 47.14005670239849, 0.94624612480402, 1.082388712994514, 0.1786187008744286, 0.2802815714911107, 20.599858645469915, 69.05560185832363, 61.46818468647619, 64.67928009648477, 62.30447323091569, 57.612867432255904, 55.24754093539331, 55.074599712125725, 54.59818863099622, 55.38414924375473, 51.890427450979914, 53.88902802621165, 53.33324778464533, 56.95854548485049, 53.02564374862179, 53.72299017444734, 48.26600836169336, 47.7497067759114, 49.882978008639434, 54.616866957756784, 59.51478158274005, 60.83152517195671, 57.46766521084694, 51.1155043878863, 45.57686667288504, 44.67945191168016, 46.588963693188084, 44.179220276494185, 44.880308643464126, 45.14746912064091, 44.389467162470666, 42.77004211179672, 43.87808030651462, 43.15295565512873, 43.84748189680038, 43.38222603644095, 44.03863468477803, 44.13804715679538, 42.784609794616706, 42.99502926488077, 43.409564956541985, 43.551994062239125, 43.23861629732194, 42.68565231753934, 44.1006826585339, 43.07597521812686, 44.01610459050825, 44.703044968266646, 42.026686283849905, 44.670724638046764, 47.71846901985907, 52.26724563106414, 52.71607068277175, 56.18374009286204, 58.039723288628366, 64.2103881989756, 62.739417014583466, 59.183902202113984, 59.66232938151206, 54.562702948047274, 49.22708711316509, 47.86963324392996, 46.679099759747906, 46.63549477054227, 46.13958950965635, 44.9179712418587, 45.363540726323286, 45.34249328797864, 42.88388890604819, 41.31529385043729, 41.34384870529175, 41.11098151053152, 40.82812370792512, 40.77841943310153, 39.19513902356548, 39.40208719622704, 41.317149131528794, 41.895063307977495, 41.773865992023104, 43.56809931416666, 41.63413939937469, 41.143748990951046, 40.034871409016276, 40.144446742150095, 40.39679242718605, 42.5878676291435, 40.21902668860651, 41.27738414272186, 41.616602482334265, 43.18813147083406, 40.587921680942664, 40.77595618463332, 40.78476582804034, 41.37210153764294, 42.631366714354485, 43.95261318452897, 45.05326947858257, 47.52441367795391, 47.114090611857755, 47.85743859506423, 46.686799372396166, 47.700061336640395, 46.824451031223425, 46.571630739396625, 45.27054917427802, 48.17999470618464, 46.91930963147072, 48.200139999389656, 50.53837076310189, 53.11257131638066, 56.32115248710879, 57.1831129443261, 61.92659208851477, 40.26148242335166, 0.33393080075902326, 0.29811962237281187, 1.3209498409302005, 10.948979604628779, 57.417290210723884, 53.84541911463584, 39.513404061717374, 21.883116960525516, 44.45689270573278, 36.85878315279561, 6.961674103813787, 0.16776061496667324, 0.1222524565133837, 0.05472796533497111, 0.07783396620183222, 0.04489303581536778, 0.15244164504110813, 0.048571518066549496, 0.025415876617414818, 0.056529106992867686, 0.07366986464588873, 0.04957901944796886, 0.013016283910180773, 0.04541409817794639, 0.053708581929846164, 0.059634586120204586, 0.06582189907109545, 0.021435994309403246, 0.05487819134648289, 0.029692121954154105, 0.04729409326588915, 0.02750229026611534, 0.031644912631881815, 0.05366079336512954, 0.051613350609137174, 0.05564730148762465, 0.026575909934998043, 0.00672411602628868, 0.01806021254930285, 0.04651227372608358, 0.027428504507688266, 0.035694235064569986, 0.025449297203111555, 0.03770534227031373, 0.016614227337882887, 0.047473595327427315, 0.013313350782188918, 0.0920007781936757, 0.03630802087906388, 0.15722882122762744, 32.1798328814968, 55.3577713043459, 40.02591663791288, 65.06535507017567, 43.240585327148445, 68.33599598177018, 60.86839152920631, 54.45918767682968, 0.5795539723288629, 1.6025016168432853, 1.0139749775971136, 0.22100816901412704, 23.868171630367158, 70.05839501657795, 65.00038493064143, 70.12411825118527, 63.46542419925813, 60.66291424535937, 59.449446662779785, 57.67393481346869, 56.45279507483206, 56.78447854134345, 54.94295712440245, 54.79647621031731, 55.42574990180231, 56.719069096349905, 55.854315911569905, 55.279767128729056, 51.01899446979646, 49.252680578539454, 52.07153504894626, 55.3679733891641, 61.086443931825706, 61.64087487805275, 58.11668019140921, 52.965478512548636, 46.66938012646091, 48.81612470073085, 47.84699332329535, 47.084582621051425, 46.06132645760813, 47.5868695782077, 47.487606156256895, 45.963247591449374, 45.176761381087765, 45.17484726444368, 47.97083039437571, 45.17114846937118, 46.06273066612982, 44.86821597622287, 46.23291838553644, 45.35472323817592, 44.58498162607993, 45.622370089254076, 44.56219657774895, 44.63853374604256, 46.28380721615207, 45.33517022286692, 46.32894977446526, 45.74123359495594, 43.44051637957173, 46.93235935703401, 49.4291558573323, 52.9297927887209, 54.65127398890834, 56.77935984826858, 57.990540689037694, 63.660868060204294, 61.14171404992381, 59.329288774921054, 61.80021724393291, 57.09508711291898, 51.95276175775836, 49.24181169079196, 47.10610074381675, 46.96672716448384, 45.59694136342695, 46.01629764802995, 47.35754428371307, 45.133827117181596, 44.450310968583636, 43.3027195930481, 42.641506041249926, 43.49929701897406, 42.81507484374508, 42.51273070612262, 42.18689157116798, 42.92557585623957, 44.18122853002241, 44.981093945041785, 43.38497169556157, 43.73583555221558, 44.216678911639804, 41.96421077174526, 41.88741076377131, 41.19486531903667, 42.23905124971944, 45.36417222792103, 43.36436356267622, 41.38631228477725, 42.824264957058816, 43.919057307704804, 42.435789492822465, 41.94816043300014, 42.6482250613551, 42.49642933568647, 45.35878681367444, 45.05704672105851, 47.69813153051561, 49.37105771033995, 49.24061929025958, 49.63398595010081, 50.46730133794969, 50.60279569318218, 49.01791103424565, 48.708636068528705, 48.18314829180318, 52.27850283345869, 50.955252032126154, 51.560301165426935, 53.644036785248794, 54.7865879151129, 58.83037897848315, 61.05313908669257, 63.763390971768295, 41.70666010149064, 0.40211330017735886, 0.07682069234790341, 2.4380575360790377, 12.312315067937298, 64.67076070847051, 60.33824789908625, 46.62488868159633, 27.11490373457632, 43.63527774810792, 47.03535687538886, 9.24269562767398, 0.23681596432241703, 0.036634110034473484, 0.026629693137722153, 0.07457027842681255, 0.06410362897440791, 0.02575093474719794, 0.04369372900034632, 0.034606440007806785, 0.03327974809273597, 0.026592415299326665, 0.06300778616400016, 0.08678516733550257, 0.031263251458444906, 0.05438476943621232, 0.04226587900531389, 0.025931331216387694, 0.03443936006196084, 0.18497785883805445, 0.11393214410711681, 0.14308239483544904, 0.17513793442518483, 0.1271901153508694, 0.13732289985543297, 0.14363397814093098, 0.15479891290587766, 0.09471574783205025, 0.10340499286089214, 0.12951307779838964, 0.17790564155626684, 0.10955041995452297, 0.19467814074408626, 0.11736620217561723, 0.12785383094582828, 0.16522198344670957, 0.17366966563126734, 0.11828664149488173, 0.27300180566887705, 0.17017656516644264, 0.19165220069548777, 44.342598761281664, 64.34397628230434, 52.764072648940555, 61.11874072782455, 40.97090974930794, 76.64970274894469, 66.98443351253387, 59.644968971129394, 1.3032838533962927, 2.8108584736624076, 0.7650910906734005, 0.38215027461128853, 24.19536594421633, 72.04857426304972, 68.10572147369385, 72.42142692688974, 68.24285537965837, 62.74129582989601, 62.450620743536184, 61.11972132036763, 59.26646809424124, 59.92830530289681, 56.378285731038744, 58.43608271691107, 57.30795414217057, 61.05039734994212, 58.969124978588475, 61.275102092373764, 54.535960228212424, 51.65390460721908, 54.15973824839438, 60.22319693719188, 65.04732001212336, 64.14325683347641, 61.667425401749156, 54.865278505509906, 50.35053237791985, 50.22028223160775, 49.773904738887666, 49.167372949661754, 48.47669847549931, 50.185698693798436, 49.33849811553956, 47.81661456631076, 48.57012148826353, 47.422267313926454, 50.52383445924329, 49.26458497201243, 48.474568628495746, 48.918792739991225, 48.88517802761447, 49.058958638098936, 48.95925198831866, 48.9247037518409, 47.62037054184945, 47.32059555668985, 47.76646314128753, 47.081228994554095, 47.78700067150978, 47.79635552437075, 44.51211967775899, 49.2744222764046, 51.85586744739164, 57.301046848297126, 56.238174746113444, 57.77917200519193, 61.424414957723315, 66.08828175452449, 64.753036345205, 63.37527244321762, 62.70421374228693, 60.3905370158534, 52.610845258159024, 51.42417923096688, 49.750849047014796, 49.6802189273219, 49.250990036995184, 48.41122235021284, 51.88166095364479, 49.016279328253965, 47.363023834843794, 46.27439352773851, 45.45388467850224, 46.49208114993188, 43.49568059367519, 44.271341062361195, 43.232062016764, 43.858103675227014, 45.35892409663047, 47.48414270339474, 47.51592566890102, 47.324533616342855, 44.99012716354863, 45.75303208443427, 44.31022744024954, 44.358233328788515, 42.19432054027435, 46.50230676897111, 45.230835176283314, 44.78852125906175, 46.26668214797974, 47.840517490140854, 47.42538952058362, 44.91102472428353, 46.514066034747714, 45.5762194818066, 47.635954118544056, 47.69492303171466, 49.62736498924994, 53.18909283607237, 51.43665629048502, 55.02769993197534, 51.92750169384865, 52.86336352748256, 50.82154627769224, 52.52382747588619, 49.90095423113916, 54.65227419330228, 53.316212930986964, 53.56816245663551, 55.575443237058586, 59.29938462472732, 61.4853411336099, 64.04413853922199, 63.50334959645426, 44.80814095466368, 0.3837619703863898, 0.35216001613486203, 3.340605208950658, 12.908556519016145, 71.92520787639003, 63.590159493107954, 50.36971669043265, 32.61639856523083, 54.98038438058669, 59.52032781416371, 17.18240930188087, 0.39277971391716315, 0.30408916333990715, 0.12632528635402843, 0.19976816680883208, 0.1644777290282711, 0.3177322393223163, 0.28543869153626505, 0.13084050898830737, 0.1580414413324287, 0.14663535741067704, 0.2653149407236807, 0.2266200082076173, 0.136615387013843, 0.11569570915232744, 0.13204597898067968, 0.24536944324931792, 0.11864561497444108], [0.02254083290726187, 0.05614107962878001, 0.02159011587800999, 0.02032768916368725, 0.008082954427077165, 0.04904952628778354, 0.020083414368151177, 0.06137775407443124, 0.07731854990725556, 0.07556825350489348, 0.017140303745925907, 0.025718852900148883, 0.002272355876254639, 0.03534366173910038, 0.02638621124318771, 0.030033816320581302, 0.04885834138540011, 0.06747576032554911, 0.034953014354311654, 0.10480096593739525, 0.06788442226787729, 0.05286910661285924, 2.7099746225341677, 51.28289937973023, 44.62250694151848, 27.066248693773826, 17.942341066175892, 43.43712745174285, 55.650917483914284, 62.84538376715876, 12.417963127936087, 1.969846905239167, 0.977547558084611, 0.4360673895045635, 2.8433104484312, 51.45182801831154, 67.23650855402794, 61.98575712019398, 65.5041741555737, 63.3561901123293, 62.5582701929154, 61.13645022915256, 59.085486012120406, 57.80886042502619, 56.71370721632435, 56.41653668495917, 60.19960780297557, 58.38469182291339, 58.43421566870905, 56.02340928969845, 55.54711195730395, 56.04842224428731, 58.313598863540165, 60.222906681799124, 63.04704458482804, 64.89926622759911, 62.361606474845644, 52.22611957980741, 49.61045172906692, 45.32787853671659, 43.82496356964112, 44.11343036159393, 45.905039618092204, 45.19077600971345, 47.62377515915902, 42.55148764579527, 43.9341192091665, 45.40323119009695, 46.37526512145997, 44.8318987507974, 45.54755480058732, 43.969189120877175, 44.006035866275916, 44.70049542765464, 42.90819583400604, 43.406427060404134, 46.18868973947341, 44.28714821415563, 43.59610895956717, 46.561593394125666, 42.923085151180146, 45.4203680253798, 46.1461712468055, 48.58031965071156, 51.408678024045884, 56.694660186767585, 55.59395682427191, 60.77070490006478, 57.30790707372851, 72.51642673246323, 67.24472199716877, 59.306731224060066, 63.04157680080783, 57.132145666307025, 52.83041954040528, 52.60878601381856, 53.312698487312566, 55.28761579144386, 57.69149918710032, 56.264136914284, 51.56112878553329, 43.61443035064205, 42.921265171420195, 42.52615305685228, 41.41566730314686, 40.445614168720866, 41.116115893087084, 41.836902403062396, 40.86839468248429, 41.02646227805845, 41.435938112197384, 42.47952392024379, 41.896169416366085, 42.965482050372714, 42.67501484963202, 42.740239943227465, 40.31246146848125, 41.19062915925057, 40.75131193284066, 43.49453918395504, 40.780608115657685, 41.52927091044765, 42.519618388145204, 41.55737469273229, 40.979640945311516, 39.87878068800896, 40.580304438068026, 42.68770763950963, 44.35871578031971, 46.78338381551927, 48.20034396263861, 51.14580861983761, 51.65835257499449, 50.1057804015375, 51.14883668961064, 47.80404729227866, 48.418125721716116, 47.7482476542073, 48.180300651058076, 47.22408171622984, 47.23438186030234, 47.81351197150446, 51.95165957173994, 56.04870857730989, 57.90810423512613, 59.18824426589474, 62.04916223402947, 5.572118086199607, 0.322133016081587, 0.39772462760729177, 1.183025454801898, 22.649083291330648, 54.2093405415935, 45.01272393811134, 38.300677807100364, 48.7775089663844, 45.96204342380647, 17.163085745226955, 0.7203392372015984, 0.10401680599898101, 0.05612381966784597, 0.11439271616719424, 0.048974150896913586, 0.04667304493787308, 0.09599339862864825, 0.005451411284851812, 0.0657904435009245, 0.04406697469793501, 0.05434806233332042, 0.05927824798310476, 0.044702030943646553, 0.03550135327743427, 0.061822092731393156, 0.03166343472267111, 0.045889670239581216, 0.015389739212790325, 0.015848462128140513, 0.014281182215669224, 0.06804522412318377, 0.020702830928888534, 0.053411853094134605, 0.047189549077302224, 0.07169013257108389, 0.04457813537409229, 0.031732499464264805, 0.026451049094659188, 0.04196447703326422, 0.1102195134867103, 0.05505292068025278, 0.043039240934435403, 0.011032957925401148, 0.006968988370405691, 0.08133598393009556, 0.06178386494397156, 0.03569927975355137, 0.06750447330095115, 0.19553792122150623, 0.19117759390463754, 5.391043338083453, 64.5148661059718, 42.787182869449744, 35.36339521408081, 32.61521204825371, 53.96192135349397, 62.65575678117814, 67.29222974469586, 12.706628980175143, 1.616600821575811, 2.793176428925607, 0.7880440654773867, 3.4950446121154295, 54.539345233671135, 72.31282434155865, 66.86731938392886, 67.56818417579898, 64.98495040401336, 64.47916469266339, 63.02729545101043, 60.76821811737553, 61.12021946137952, 59.60258776141752, 57.68931442691434, 59.6806154712554, 58.43762813075897, 61.45681373534664, 58.508572040065644, 58.616194032853656, 57.96958346520701, 60.63832882911929, 64.57291718452208, 65.20429718878962, 65.77264470438804, 63.04001177510908, 56.23086737048242, 53.51855624106623, 46.92809181828653, 45.00496941228067, 46.86020343534408, 49.41185820487238, 47.24983992115144, 48.64255589823569, 44.9626862618231, 45.331220396103404, 47.88871949718845, 49.689613003884595, 46.28626654225011, 47.58250005783574, 45.192195907715835, 46.04783742658554, 48.12995310752623, 45.10948096552203, 45.95084505696451, 48.20210902921615, 46.792322897141986, 45.65664375981977, 47.18703100758214, 45.85603352515928, 48.02508069622902, 47.256806050577474, 49.69282934742589, 53.198102520358184, 56.32838926007671, 58.96119394610005, 59.09279338775143, 60.993828927316976, 69.06812206391366, 58.43266241012081, 60.80379401483844, 64.06776689714002, 60.238470646642874, 53.49632424692954, 55.1029113800295, 54.358606338500984, 57.71055798376761, 55.86667922235305, 55.113238980693204, 51.26851212593817, 45.50778588941021, 44.29584018645748, 44.57469324911795, 42.79580031671832, 42.46282246805007, 43.95746123406195, 43.48059515799246, 44.22684569512644, 41.54065755105788, 43.26040506362916, 44.23997386809319, 43.758244053010024, 44.553041765766764, 43.70841818471109, 42.936938962628766, 42.92715264904884, 43.728488952882834, 42.79015210367019, 44.27024672108312, 42.598807119554095, 42.91391464971727, 43.605114721482806, 44.62883372460642, 43.23953413194226, 41.225098948324884, 42.348787400030325, 44.664429233920195, 48.61891185083697, 50.3963456615325, 51.58918942174604, 52.8454343734249, 53.38277947518134, 52.98172889217254, 52.82296703707788, 52.52755764992007, 50.98490907299904, 50.19230396516862, 51.24887281848539, 51.0117341626075, 48.950261915883715, 51.297082670273326, 54.67248224443006, 59.26485992247059, 61.09380229826897, 61.965513767734656, 66.44945359999134, 5.521744066669095, 0.4831574965388545, 0.47914803749130624, 1.5238658170546255, 26.626141109774192, 62.03934846385833, 50.8393342264237, 39.48925402856643, 48.09236111179475, 47.98284461421352, 27.32663719884811, 0.7429182998115017, 0.02994954473369064, 0.05610715725549287, 0.04967055929404113, 0.04680075945572988, 0.06178114533184036, 0.02427038364863444, 0.017542264334136443, 0.02077506344404913, 0.0514887732213303, 0.031773948651408, 0.06013127539547221, 0.07217200953633555, 0.023252817787109845, 0.05524605910684313, 0.09598491803532648, 0.010677218294492172, 0.04299907111412576, 0.12461110333641692, 0.10142616476983794, 0.20141306483457166, 0.11971415441122749, 0.15320868291441472, 0.1378369295308667, 0.2182156865995738, 0.1810927971476509, 0.20039340180735435, 0.19875426476280536, 0.12845927023238715, 0.15645957702109892, 0.11741707041378945, 0.0798993622283301, 0.12935995214408444, 0.10786917105677629, 0.18621826243977394, 0.2027155981669503, 0.15575632362836794, 0.23677200619732183, 0.3143266720637199, 0.3033896024909712, 8.423384081932808, 77.32387188942202, 54.81770800006006, 40.57683706283569, 30.21147966384888, 58.72718926398986, 66.26335282479563, 80.56809563790598, 15.248900459658715, 3.575843966776325, 3.8868300664809445, 1.0048615956498732, 4.27608706297413, 54.676051601286865, 71.03173901957851, 68.60022252605808, 70.0931001478626, 70.42810193953976, 67.89218764151296, 67.34846084348618, 65.85872111781951, 64.31154220334946, 63.68895615300825, 61.2289357954456, 63.3146482898343, 62.75243928355556, 65.71655088855375, 62.19263861256262, 61.897374353101185, 61.834871384405325, 63.57285791827787, 66.91670202439832, 68.8679870482414, 69.24340494217412, 66.00868901898785, 56.96389167539535, 56.004495620727546, 48.596605331667014, 47.84862110691686, 49.220768174817486, 52.81396911990259, 50.3407774433013, 53.297813092508626, 47.804325780560895, 49.31344593724897, 50.105380319779925, 52.66119280169087, 50.751704554403986, 51.42348104907621, 48.33771321081346, 49.160830436214326, 49.71684209762081, 47.78741644274804, 47.593059078339614, 52.37278484529065, 47.50386045825097, 47.78880888415922, 49.738960343022505, 47.12166863103067, 49.246208667755134, 49.13561351837651, 51.56446280017976, 56.638256503689675, 59.907344156695956, 61.575057506561286, 61.61714846088041, 63.26135896867322, 71.97839521592664, 57.62515621800577, 63.763536099464666, 67.078719446736, 60.40994490346601, 55.726058329305346, 57.267196793710035, 56.83114690165366, 61.29775770248906, 59.69087246925601, 58.9263750660804, 55.27877869144563, 46.94939813306255, 47.48584501204952, 47.04930874609178, 45.24230418666717, 44.38125764170001, 46.32752595409271, 46.074191831773334, 44.92950301016531, 45.27612286229288, 45.27854688705937, 45.97911750116656, 45.96126287214218, 46.856575242934696, 48.24978543866066, 46.65676970635691, 44.484972953796394, 45.93485355377198, 44.5427926125065, 46.907797475014966, 46.16151948128977, 45.319131651232325, 46.09180327384703, 46.0801891357668, 45.33091052885979, 43.92344643992763, 44.211348410575624, 46.77691190473495, 50.98867454836446, 53.61268920283164, 53.96008568425333, 57.939169406890876, 56.37408879495437, 54.59596464710852, 56.225446654904275, 54.34627440667922, 54.08155364374961, 53.06642070893319, 53.88538806669174, 54.27392628885085, 52.156791687011726, 53.77999005779144, 57.09305532516972, 62.62779812658987, 63.45192732349519, 65.25230699969877, 69.07624137017035, 8.531415962403821, 0.4206544665559646, 0.818006928649641, 4.019124993393499, 28.045356619742613, 68.12203853361069, 56.00768450767764, 49.2335747134301, 60.36258620600547, 56.248368986191295, 43.45802976239113, 0.952820691370195, 0.2788731035205626, 0.09958852668322864, 0.18361803745069813, 0.16884420037029252, 0.1259175283954509, 0.26901529861554024, 0.1425549739430989, 0.17681174460918675, 0.15707918893425696, 0.06597500940364215, 0.15001135367539623, 0.2392205304556316, 0.13719283344764865, 0.23881972857540656, 0.16693075788357567, 0.1314250187527749, 0.16281239177671172], [0.0340263735533001, 0.03651530511917607, 0.050832611253304835, 0.03297108743760375, 0.03908265344498139, 0.058054426354506326, 0.0644935715583063, 0.07911317981779575, 0.048848650373157956, 0.03909986361020035, 0.057004870576483596, 0.02270889919131033, 0.005469686312285523, 0.0684074534764213, 0.10794001886801374, 0.05781365258078422, 0.06902697345902843, 0.09338564299527677, 0.026749555254355076, 0.05602455765549695, 0.10125773267880564, 0.08675764179638318, 0.25351502632181494, 18.008842891262425, 47.17037662383049, 47.1532319438073, 18.467640569133145, 33.65607769258561, 50.25593265410393, 65.36732658263176, 36.29118873227027, 2.156984902197315, 3.1233689044752433, 0.011309084741608992, 0.17619824607766446, 16.07751488685608, 72.37232669707268, 59.62593763105331, 71.8218691118302, 58.899165584195046, 68.34938695353847, 57.74961694594353, 65.86212573512908, 58.50433980264972, 61.94317194723315, 57.82792314406365, 63.5258993025749, 60.286974676193736, 62.21741622494113, 59.96433619529971, 63.88107384404829, 59.553314947312884, 62.539940957100164, 61.28554344177247, 67.01122330081078, 64.62245279742827, 62.271697905755815, 57.75394724261377, 49.87671006110407, 45.873378246061264, 47.90566805870303, 44.98898183145831, 46.29973988379202, 44.32717207939395, 44.66191499463974, 43.43193031126454, 44.39290708111179, 42.58749108160696, 44.662075811816806, 46.89602644212785, 44.05245711726528, 44.80938826837848, 45.00471445821947, 46.96971208818498, 45.58395047341624, 43.241479627547726, 44.098658715524984, 43.958222173875384, 42.571750610105454, 44.78314368955551, 44.29689530403384, 46.55125794872161, 48.3310059578188, 51.41841334681357, 58.95410622319868, 63.24592444204516, 58.97246291560512, 64.30273648231261, 59.09979481850902, 70.75423132988715, 93.17215365748253, 63.95154706893429, 61.854514614228286, 58.849551523885424, 56.64680334829516, 57.145289528754454, 60.53747292487853, 59.624819755554206, 61.4388257457364, 62.39929652983143, 61.30481012405888, 47.652357470604684, 45.1042995145244, 43.826242262317294, 41.65485735862486, 41.0753506998862, 41.11464892664264, 41.37255261021276, 41.928277938596665, 41.29428171342419, 40.71479074416622, 42.3586953070856, 43.81360438562209, 41.83180332183838, 41.991404564149924, 42.642776889185754, 41.12731818229922, 40.45051713143626, 42.49205981531451, 42.60190579199022, 40.41743978377312, 41.146031810391335, 41.27459925989951, 41.49469129500851, 42.53727689866097, 44.03193527652372, 41.60518446276265, 46.16144103388633, 54.262512191649414, 54.49385750678278, 56.01619997332173, 57.87011608000725, 54.423819664985906, 57.0116896783152, 55.57997749697778, 55.2399472267397, 53.86807080238096, 53.81906470944805, 49.21914039119598, 49.62544302786551, 47.67452670681862, 51.984882047099454, 53.299044716742735, 57.73852840546639, 54.1959652593059, 66.60397929529991, 22.996403286533972, 0.3537047251818642, 0.2477006488029034, 1.0266071545981592, 1.2718049941524383, 33.99415462247787, 62.647013818064046, 36.60931648746614, 51.976248910350186, 62.25355302133868, 41.52843152323077, 8.109081127951223, 0.37225952792552214, 0.04891570987960985, 0.06032863879696496, 0.1136681731910475, 0.049800686988859415, 0.04506596867295523, 0.07023268093865725, 0.02386531082823152, 0.024802694097161296, 0.014925465032818818, 0.013142705654665349, 0.032270599622279406, 0.055307453393094966, 0.037143976022038734, 0.017497013435669003, 0.04539348658234362, 0.018374090263199423, 0.03631739779525707, 0.02539763031827827, 0.059855564181963285, 0.006048963696230204, 0.12047223671669922, 0.011502072823444202, 0.05624345578854123, 0.07415446888415084, 0.06133002296630895, 0.07650686442972192, 0.06573878619219027, 0.06109412534222488, 0.031104960456310265, 0.03277997914401274, 0.006053570278679893, 0.039868065937151836, 0.03015786319250061, 0.09710329915246657, 0.15820631877549235, 0.07137920046525617, 0.09396336522073516, 0.09852518132256885, 0.08851165372517802, 0.266353755949005, 27.07928861341169, 53.96228221154983, 38.085402442562966, 28.071310943172826, 41.30559775137132, 58.128615963843565, 73.93075496919694, 37.82724380493164, 1.8262196380284526, 4.872140240284705, 0.4175621986148819, 0.3753012953506362, 17.313742022360525, 71.48533759578582, 62.119709983948745, 75.74086604579803, 61.70466438416512, 72.86802799470964, 62.0936889802256, 67.43762416224327, 62.786732565972116, 64.06075762164208, 58.367582444221746, 64.47565024898898, 61.302040930717226, 65.16424194458993, 63.471813740268836, 65.47756087395453, 61.671386995623195, 63.575293710154874, 63.785038532749304, 68.76931590418663, 62.93424898578275, 63.87820266908216, 60.013620776514855, 53.08409883129982, 47.81289615938741, 48.65603708451795, 47.33630857160015, 49.322796867739775, 46.90246305158062, 46.224822613500784, 45.845690235014885, 46.947699746777936, 44.7792919220463, 48.37041401094007, 48.893014923218765, 47.15132567190355, 45.76165345407302, 45.51764280565324, 48.19860243028211, 46.06548024762062, 45.23756204112884, 46.31421735209804, 46.0331363831797, 46.699943234843595, 49.36000054882419, 46.660362597434755, 48.741191740958925, 49.361043899290024, 54.304014790442686, 58.82578196064119, 64.69393014907837, 60.138097193933305, 66.31884651799356, 60.677521151881066, 75.43443479845601, 72.26456349895847, 56.544904093588556, 64.22783490150206, 57.02633188616846, 60.33509039109754, 58.59914741208477, 61.52136810364262, 60.31963625261861, 61.31550642751879, 62.553735932996204, 60.83058772548553, 47.0675124660615, 45.08645273024037, 45.506683703391786, 41.54023393507927, 45.87226429293233, 43.980403177199825, 44.323771384454545, 43.888835445527114, 43.49913620179699, 44.625205532197036, 43.84545010905112, 44.82812150832146, 42.56606709572577, 43.04192120029081, 43.26006381742416, 41.81633741624894, 42.484854421307965, 43.599309613627774, 43.600717744519635, 41.887999119297156, 42.70581722259522, 43.07974461586245, 42.44383819641606, 45.55123398380895, 45.815433071505645, 43.47559021365258, 47.064672670056744, 54.4347591553965, 57.872834282536665, 59.465061618435776, 59.95850755322365, 57.04410414541922, 58.125956596866736, 58.26957025835591, 58.24074475995956, 56.946860744107155, 55.597286916548214, 51.60721663505801, 51.26131849904215, 51.575366989258804, 55.10657095140027, 57.700665766193026, 61.460532142270004, 58.272468889913256, 69.08158363834505, 23.879970119845485, 0.5357964396957429, 0.9810573439444266, 1.644025666098441, 1.2073331182041478, 36.46375340800132, 70.08884045385545, 41.5716128964578, 62.9971638033467, 63.76557965432445, 48.12116307597007, 14.873762034600782, 0.48620609746825316, 0.10869899749635689, 0.11758925633565073, 0.05465679959724507, 0.07063394247163689, 0.036810034465405254, 0.0321546598758188, 0.0382565540231524, 0.03679410749745946, 0.03234294896584845, 0.0627265208130402, 0.0337060492095207, 0.03896575608861543, 0.02330237409971174, 0.0298114956897353, 0.08181815200875844, 0.027861725313649065, 0.003649913396070441, 0.1141694398416627, 0.1440440037197644, 0.11502198844907746, 0.1719787257212785, 0.1285721226445129, 0.14808312569174076, 0.1431059903435169, 0.1379462809211785, 0.13512929901480675, 0.23420389561403185, 0.16053418418572796, 0.21287194753606475, 0.1334004990396, 0.2175120195193637, 0.17009327608731487, 0.11638196305401864, 0.2842745136830115, 0.3249361624400462, 0.22661653016844105, 0.15879635969477315, 0.25901316274558345, 0.2505788104909082, 0.3536515586799191, 38.49791811358544, 61.112939542339696, 61.32952497851465, 31.986101135130856, 46.86568298647481, 63.255165546171135, 80.30645785793182, 42.704369868001635, 7.531150281429292, 9.97447261887212, 0.26418437880854456, 0.31042964407993906, 18.005393166695875, 75.62131220294584, 61.60615797965758, 79.10929556815856, 63.08502881757675, 76.2780503303774, 64.76759618328464, 69.58748309843003, 66.4874456774804, 67.77037451344152, 61.07458268442462, 69.89189824750348, 63.97388104469546, 69.11456292675388, 65.90145141847673, 69.56734564996535, 64.01939230580484, 67.6344173185287, 67.76185512542725, 70.41165151903706, 68.34238944515106, 65.76715730851697, 61.87684466761928, 55.68413995927381, 52.01078537971743, 52.42112805766445, 48.50747731424148, 51.833713900658395, 47.849248686144435, 47.118169876836966, 47.16327321144843, 48.24436864545269, 45.571116478212424, 50.9351969534351, 51.28950465110041, 50.434223990286554, 49.43332925919564, 48.67525277599212, 52.35183154383014, 49.6738999889743, 47.658025295503684, 48.74993862644319, 47.87405375511416, 47.9049071188896, 49.79379507803148, 49.095150347678896, 49.51243954320108, 51.27454080889302, 56.68561520115022, 64.96479334369783, 66.88156543239471, 60.80345276863345, 69.58356857299805, 61.66392664755545, 76.20773792266846, 71.73402370945101, 58.158975108977295, 66.40509943808279, 60.14643223054948, 61.99302527212328, 59.384464756135024, 65.47130861589986, 61.809038654450454, 66.77603798527872, 65.45626632628903, 64.40220386751237, 50.226259923750355, 48.67344848571285, 48.02713601819931, 45.45777566971318, 46.23490310484364, 44.29284741801601, 46.36243897099649, 45.61234843346381, 45.99394406041792, 45.796248758992846, 47.3067456676114, 48.034325722725164, 44.3658584164035, 45.51593657462828, 46.5805031407264, 43.76363731199696, 43.60750344491775, 46.58326448932771, 45.51214756504182, 44.6422129292642, 46.46196911411901, 44.437120037694136, 45.582381525347316, 48.106740520846465, 48.64494854404081, 46.08668458077216, 49.5888041680859, 57.76933470079976, 59.29577996653896, 61.36512833256876, 63.063353800004535, 60.37196851545765, 60.63790521314068, 59.51800184865152, 60.04575675533664, 60.44172394660212, 57.7722058757659, 53.19674930264873, 53.54756609086068, 54.592799294379454, 57.43825135692474, 59.49520111083985, 63.52170236649052, 59.23117068506057, 71.12248697588521, 26.970740941263017, 0.3177827704818018, 0.7977053535080726, 2.8934493708995084, 5.543724538818483, 39.865617213710664, 77.14833013473019, 48.01565131833477, 65.48637443973173, 68.10801213787448, 58.35900029828472, 25.16086716805735, 0.5392042439310782, 0.3015820027118729, 0.29725326886100156, 0.2375164751203791, 0.09540525760741965, 0.15213522519315445, 0.1794356723586398, 0.13962027496628224, 0.18113736814308554, 0.19090393197632607, 0.12182595238329903, 0.175472576952269, 0.17119126394391063, 0.16739277018895074, 0.14394510176873979, 0.0987991420251708, 0.13253868076830141, 0.1410005049359414], [0.024388749978595206, 0.030353947227159818, 0.03210573367053463, 0.0544973039218495, 0.017894021265449065, 0.028657832393242468, 0.010984223242098046, 0.038896103374539845, 0.04460485269045157, 0.029416747819331866, 0.03656992718817727, 0.02050353507060678, 0.02516294502833438, 0.012883906789694824, 0.041210680989728826, 0.08207550392516198, 0.03154798335726223, 0.005113393182851254, 0.023800428926704392, 0.06619378113217893, 0.027117601130157713, 0.07024329891728778, 0.06981285709527231, 1.808080882314713, 50.41387081146241, 36.76190845427975, 31.686369296043154, 23.89634797649999, 42.7071233718626, 56.74846333842124, 60.25841197659893, 2.662835332655138, 3.753883045527243, 0.17467072804368314, 0.24145439687755801, 0.1979824158573343, 48.74827554149013, 69.61108792212703, 60.28533512546171, 69.37993480313209, 64.27675862466135, 67.18845951941707, 61.504141053845814, 65.21323627041232, 61.68533886632612, 64.65912695853942, 63.79384033141598, 65.3829219264369, 60.119748346267215, 63.01863093529979, 63.535924880735344, 68.67557910180861, 61.19752153273552, 63.57338351588096, 64.95590525288736, 65.24584293365479, 59.73448138083182, 57.14223008002005, 50.63644962926065, 45.09845518296765, 47.957898339917584, 46.772805183164536, 45.29200846149076, 46.659899757754424, 47.7321659365008, 48.19236586170812, 46.772361955335064, 45.360100807682166, 44.912009239196784, 46.08737099555231, 44.84119084573562, 44.64231491088868, 42.22348728487569, 44.75620092884187, 44.726006523255386, 43.397546814334014, 45.10947704315186, 46.06079693763487, 46.96364025915823, 47.08507683969314, 47.60440257287795, 46.82561989753477, 48.78990757849909, 53.331329745631066, 58.41052455286826, 59.60208569803546, 60.56525115043887, 58.03335335946853, 59.88665365403699, 53.46966389686831, 70.14820944878363, 77.99158480859573, 64.36915789881061, 62.08265535293087, 60.487454860441154, 59.179889617427705, 60.787877036679184, 58.87492925890031, 60.33256046233639, 57.986775213672274, 62.59909814403903, 48.7899624916815, 42.326041575401064, 41.56514883041382, 40.07185151500087, 40.540323718901604, 41.42529672191989, 44.66973227839316, 42.79586699701125, 41.73099840840986, 43.449122059729795, 43.29430218665831, 42.036401994766734, 41.82657480239868, 42.489969192012666, 42.30610416781518, 42.18932344067482, 39.7843143247789, 40.73839164549305, 41.88870514592817, 42.02589004270492, 39.802820067251886, 41.30118508492747, 41.991690897172504, 39.78070966659054, 40.41640427804763, 43.529683620699, 46.24588574132612, 57.96023645708638, 58.94084076727591, 58.794406921632834, 57.7552180905496, 59.000962857277166, 55.07385446179298, 61.127393476424686, 58.57509543818813, 58.94117024637038, 54.26421842267437, 55.4960976108428, 50.65533584164035, 49.85025759666197, 52.30714790282711, 56.77588070592573, 54.817272616970925, 61.79102320824901, 49.20972670278242, 0.933164100973837, 0.25948461325418565, 0.13217267460159718, 1.7189477167783247, 2.218452855463951, 48.9393969505064, 52.70533907798029, 24.242489299466534, 32.06989472912204, 35.360571107556744, 46.26628598859234, 4.799532755728691, 0.5856405102437543, 0.0665495753468525, 0.07748563368354114, 0.027062272345046365, 0.04632388887506339, 0.03864719374706188, 0.03694448289611647, 0.0589304747089984, 0.09756556426685664, 0.07000413392820666, 0.0505637526962786, 0.06657184552281134, 0.14236861539463844, 0.0443928110443296, 0.04315220442931018, 0.016891656503562006, 0.03482128170529201, 0.012136656967472407, 0.04239394209317623, 0.05564069397927773, 0.03592373202404669, 0.045522920967590426, 0.06575456760343044, 0.0978109269072452, 0.0248241005089855, 0.02678057032396957, 0.014654994818321882, 0.0681786383351972, 0.03856079052052191, 0.042935240668274706, 0.07145387871611504, 0.03762674547972218, 0.016583775342892737, 0.11816521655888328, 0.054477891253848235, 0.046504187668042804, 0.044591120564408844, 0.07881413739655288, 0.03652701477309869, 0.07068694043423861, 0.08383761340331647, 3.2754970510159773, 63.33754708690029, 36.70372009277344, 28.397002989246, 33.443045923786784, 48.70459602725122, 62.94070912945656, 66.56478697253813, 2.5039889014536336, 3.3201985878329126, 1.5167263678966032, 0.4596135308665614, 0.15296353477864497, 53.68489219296364, 70.12236102934807, 62.726010353334495, 72.50398497427665, 64.87609286462107, 68.8824684389176, 65.26755325255856, 68.51808809464978, 64.3214383432942, 64.82010495278143, 65.12765015325239, 67.85654898612731, 64.59680834124165, 63.59347781827373, 65.20061800556799, 69.91376153884396, 61.463313102722175, 66.30669501519972, 67.51909179072227, 67.18388603579614, 61.72852023955315, 59.067125397343794, 52.801029220704116, 48.25119356955252, 48.48734378814698, 49.59320114504907, 48.050901659073375, 48.602077038057395, 50.02184560222011, 49.7862837391515, 48.52740687708701, 46.92311040816769, 46.04510353457543, 47.71424854955366, 46.76203435467136, 46.31985379803566, 44.91634345823719, 48.33454393571424, 44.6932900336481, 45.71488703450849, 46.84032878568096, 47.904087343523585, 48.32076072692872, 48.89316789565548, 48.144391352130526, 48.89616066409696, 50.87526313720211, 53.52176081749701, 60.481504624889745, 59.05980625460225, 62.19226206502607, 62.431024582155295, 61.085361357658144, 61.1799846156951, 76.82582501442202, 66.41961220772036, 65.24855721381404, 61.922803078928304, 62.126221118434785, 62.0656636453444, 65.81922285018429, 63.61002629803073, 62.534806574544604, 59.06714893156483, 61.89013365776309, 50.13706522603189, 45.369286998625725, 43.490326558389974, 42.002336209820164, 43.55051532868416, 45.40670248769945, 46.6328981614882, 45.08242053370322, 43.48784762044107, 45.038964594564135, 43.91595863526867, 44.41448796179987, 43.579446731075166, 44.60072209758144, 42.92013552881057, 42.15088813535629, 40.345370154226984, 44.18077745745259, 41.94136688786168, 44.78775639687815, 41.3034482925169, 43.46737284814158, 42.89873507715041, 42.40020967298939, 43.543647258512436, 45.83901436098161, 47.78730269401304, 59.01805654648812, 60.896632594446984, 64.31774347059189, 59.17490428493869, 60.922351575666866, 58.01757758663547, 62.02228615360876, 58.86033804185929, 60.71230865293934, 56.2720718691426, 59.033930378575484, 52.364226233574655, 53.379092447219364, 54.159840230018865, 62.69501186186268, 58.30457348977366, 65.15144325071766, 49.90350769412134, 1.3909376725073785, 0.6794202135455224, 1.877016783241303, 2.867110900340542, 2.5517508675975185, 55.0038323094768, 58.77687000459241, 28.82639858030504, 45.126284399340236, 40.14054790619881, 52.92205395237092, 6.416901503839801, 0.704383893359092, 0.14831846790207973, 0.08437426565515418, 0.09266740492274685, 0.06373697163296804, 0.013803951573678324, 0.06352338248923903, 0.09038229487956533, 0.02458963355410003, 0.04369734876578854, 0.09696207850450471, 0.06795396006876422, 0.16770239228442793, 0.007755583510809248, 0.09394457308395256, 0.0316443897768735, 0.018189388379875212, 0.0597651313329416, 0.16912916975636638, 0.1416265366659049, 0.1933873285569491, 0.16037223319853508, 0.1522518544187469, 0.2091503996522196, 0.15341483717483861, 0.10848670687165954, 0.1273705367179167, 0.13366372685038275, 0.21038358670569238, 0.09547739244636991, 0.16025033328802357, 0.13870294596399033, 0.11468854868003439, 0.25970374504404686, 0.16045230470838087, 0.1307800186858062, 0.07846588914793345, 0.1543878760909842, 0.14385790564119816, 0.1807202332683148, 0.18825594906605062, 6.294278896624043, 75.105787246458, 49.35022600235478, 45.56593502721479, 36.58353474832351, 55.013810819195164, 68.6989172043339, 73.41478286250945, 4.553575631110899, 11.144625467638816, 0.9389366654138412, 0.6975929222760663, 0.5321486967225229, 55.707874221186486, 70.1922498210784, 62.540646983731186, 75.78655381356516, 68.14820858740038, 73.10273478108068, 67.01152924568423, 71.78423004765665, 67.91297620342624, 68.1543274848692, 67.17813584112352, 71.6318851901639, 67.90578257653021, 67.15061649199455, 69.94306164403116, 75.31054281419324, 65.0258058117282, 67.47019552415418, 69.4357422859438, 70.47148335364558, 65.00846109082623, 62.14211064000284, 54.769521682493156, 52.84173950072258, 53.30292786321333, 54.07802351059453, 48.87462292948077, 51.75361517936953, 52.69494087465348, 52.9679064596853, 50.32815133371661, 50.47471853994554, 47.94189114724436, 51.33701632099768, 49.7256282068068, 50.067180356671734, 49.618280779930856, 52.967851546502885, 49.38686093976421, 48.59294183792607, 48.770609517251295, 51.10607893236222, 50.30497404836839, 53.59872948738837, 53.127519469107355, 53.0331237085404, 55.01754491559921, 55.90674231129309, 62.22374693039925, 62.70739086212651, 64.64845026693037, 63.052939907197036, 62.83756648340533, 62.11150830791843, 79.47377789405085, 67.36386791352304, 65.06875184274489, 66.07688334680373, 61.80635967562276, 63.989386173986624, 63.91715180489325, 63.67267047205279, 65.2482081228687, 62.889463363155244, 65.75103244473858, 52.178811873159106, 47.00716287859025, 46.30659618685323, 44.080811931240945, 45.41792831113262, 45.4998666240323, 49.41807123922533, 46.253989358102125, 45.86233285165603, 46.75454262764224, 46.61081129504789, 46.26104177967195, 44.75867986679078, 46.188756419766335, 47.6398019636831, 44.214360790867964, 41.18596938348586, 45.48180410938878, 45.61820845450125, 48.01219963258313, 43.54300398980418, 46.52014178614463, 47.59332187714116, 44.152995309522076, 44.72617910754296, 48.72592587624827, 49.38333865134947, 61.24702968905049, 64.4575838119753, 66.34702482531148, 62.493676600917695, 63.41108760526104, 61.82493602075885, 64.71707605546521, 59.233653545379646, 64.69424393869215, 58.96385723544706, 61.15148859639322, 55.31958310834823, 55.11764380239672, 58.98817200814525, 63.99781142511676, 60.61124878544962, 66.0980406115132, 54.69888371805991, 1.9495675160038857, 0.7509556653038149, 1.991686049488283, 5.718335220890661, 3.9289406326509293, 59.99013362392303, 64.68403008676344, 35.609257221221924, 46.839214832552024, 44.45950500426754, 64.65363956266835, 11.065312200976956, 1.0593624388979328, 0.33508468239057454, 0.23319808345648552, 0.24888690531013474, 0.10149145844362437, 0.10911555780518441, 0.15769173751675314, 0.1995131667823561, 0.18425886999935875, 0.20489844313311964, 0.22370797011160085, 0.13459132143086003, 0.20695010320313517, 0.25658475595616526, 0.18413234291778457, 0.10494655328652552, 0.08683143138524987, 0.08909472324434789], [0.08850539478683665, 0.06135382531811634, 0.010321389605862, 0.04808770289884941, 0.02814389081792005, 0.02861754765974418, 0.036933125642639016, 0.056587785497427955, 0.002864322309652644, 0.021000885096709096, 0.15011810036676546, 0.01465026614060926, 0.03577770800479958, 0.07789729102965325, 0.03452362973363169, 0.01998587605363179, 0.053361095938711404, 0.05269219009806553, 0.06577271622635665, 0.026730274736520745, 0.052201541426080855, 0.04257340585031817, 0.10458479890780104, 0.1082989770258146, 17.1860747568069, 46.90651878233879, 34.05821477213214, 29.618825220292617, 29.080850578123524, 56.986935600157715, 67.34158100620394, 12.007668499023685, 4.341414138194054, 1.7682919915645354, 0.31237468003265323, 0.1028816169127822, 1.845653511343464, 61.38202198090092, 63.73129029427806, 62.43792795365857, 64.37174274075416, 63.704896665388546, 68.07431113335394, 66.54450831874725, 64.46634638694026, 64.6561538019488, 65.89895679104713, 66.12664253480973, 62.7030566430861, 63.265689265343454, 64.1745573474515, 65.44471102376139, 65.44467572242984, 67.34765283523068, 66.94702194583031, 64.26462281134822, 57.62297145781979, 53.474186389676994, 48.907684587663226, 48.13209864401048, 45.68508094356906, 43.9580221329966, 46.60938355230516, 46.36243897099649, 45.84015184833158, 47.29142881208851, 45.63828314504316, 46.3971362575408, 46.28890237500591, 43.89880611050514, 44.755710632570334, 41.673527840645086, 42.127848132964104, 43.85611503354965, 42.654665593178045, 44.90477638859903, 47.31837157280215, 51.40780725786763, 51.80158184420679, 54.69448281872658, 49.857023685209214, 48.306793166745095, 46.54466836683212, 45.94268260463592, 54.74794864654542, 62.12800187449302, 63.12075376510621, 63.85343290144398, 56.28718476141653, 51.95165564936977, 18.131970013341597, 27.3361175675546, 85.66510585046585, 58.53332219585296, 62.68966959368799, 60.262624602163996, 60.067690649340236, 59.60286624969975, 61.558465880732385, 58.5059009059783, 57.623187188179266, 45.6645591028275, 43.568534697255785, 42.653720301966516, 43.5061768562563, 39.92927335923718, 41.92384958267212, 38.90197323214623, 41.029200092438735, 41.556754958245065, 41.66383174157912, 42.19916466743716, 42.512946436482096, 40.866453109248994, 44.29202372027982, 39.58005297568537, 42.245225060370664, 41.38760666693411, 42.573209731809555, 40.47312959547966, 41.03143192106678, 39.24091308347641, 41.188550303059245, 39.72783611666772, 41.52572901018205, 41.204898741937455, 43.10622453689576, 44.36150066314205, 54.18179765824349, 55.932276941114864, 58.62279145948349, 54.272812335721916, 56.93547018112675, 56.16444203161425, 55.90950365989439, 57.631973297365256, 60.465152263641365, 56.07175642444242, 54.36533712571668, 51.77212484421269, 55.763516964450965, 51.65390460721908, 63.41246043482135, 52.9089375465147, 66.72259961405109, 15.446940929658952, 0.10660907133452355, 0.5667495174754051, 1.858062787402061, 2.8947709644994433, 3.411808239836847, 61.3258340281825, 37.57044622975011, 35.30736023379911, 34.58029008680774, 36.647135980667606, 34.345932391382036, 0.20930720252856133, 0.12522759727172314, 0.04669740270342558, 0.06686770867916846, 0.054901350184433886, 0.07656847322059256, 0.025936770440650084, 0.023573188096164696, 0.023803772900493878, 0.05002973578690041, 0.08915280803076683, 0.041185610762406746, 0.010156222006997034, 0.03193255374959159, 0.008431675734989827, 0.02003168236584433, 0.032626052927826686, 0.11602022399705265, 0.03387912762381377, 0.06685761164032644, 0.05661628396821119, 0.04746866555163457, 0.04680066752517897, 0.08525164317219489, 0.07510568195533368, 0.012495538516480838, 0.043295531819063815, 0.03770878583553337, 0.03130284288237172, 0.12088944820026237, 0.0047769173116032635, 0.027259373361425056, 0.02294748578400862, 0.008847737129056647, 0.07971023810246299, 0.03792574193568961, 0.030994419714496024, 0.08553794555125699, 0.060254676838315306, 0.07419072782560703, 0.029208379564806822, 0.049691979112404014, 0.09037026729915412, 27.648761849249563, 53.203001560703406, 32.266123064102665, 41.34649630515806, 38.42523659429243, 65.15225518134334, 73.20521846894296, 13.92671654301305, 3.6901021195996195, 5.236120993091214, 0.8780069348792877, 0.848511814350082, 2.2967936194712117, 66.7926453005883, 62.832016329611506, 63.357735526177194, 65.80747142914804, 65.88369092633648, 70.51313108013522, 68.46857209359446, 66.75210368248725, 66.98721055061587, 68.70997044347948, 67.93425113924089, 64.73836275839037, 66.06716371351673, 66.50764588386782, 65.75367612223472, 67.35624282590805, 69.67044907231485, 68.67456713030415, 66.27291556327575, 60.83583193440592, 55.665814645828746, 51.451192594343624, 49.648588934252345, 46.36809895115514, 46.79060882137668, 49.06786634076027, 47.46568795173399, 48.84793120045816, 50.63235075243058, 48.14517190379482, 48.595695341787035, 47.34760499769642, 48.091588404870805, 46.865420187673266, 43.894452279613866, 45.218687595859656, 44.33028251894059, 43.95190323552778, 45.99374009716896, 49.35734118184736, 53.938893118212306, 54.60512730383105, 56.93064958818498, 51.54928714998307, 50.00805062632407, 48.428735733032234, 49.94615170263475, 57.13726828175207, 63.08425218828263, 62.752180407124186, 66.75479442842546, 58.36989664262342, 53.79742499320738, 28.42761708844093, 33.190790453264796, 74.08878726343956, 53.67164634889173, 65.06085218921785, 61.26178956800892, 63.12101656390775, 60.72389533442836, 63.63074817965108, 58.83826686489967, 58.33588969322943, 47.61525969351492, 45.56401698820053, 43.37029810874693, 44.561153227283114, 42.7062879070159, 45.80682739134758, 42.17898799527077, 43.278185167620265, 44.77729935799876, 44.2040841810165, 45.18817940065938, 45.47471638648741, 44.302967133060584, 45.31908458279025, 41.40708123483966, 45.40419609315934, 43.12006658123386, 44.108515631768014, 42.10400796705677, 43.0748063518155, 41.734057857144265, 42.49133025446246, 41.69925074423514, 44.93899514598232, 44.30075883865357, 44.25180765890306, 45.57328162654754, 56.40761721518732, 57.7041684427569, 59.76624473448723, 56.04923809728315, 58.56779982966762, 58.52264158187374, 60.658999719927394, 60.3586716805735, 61.05688102783696, 57.36970009342317, 56.28344282027214, 53.25909929890787, 57.949920623533195, 52.15010404586793, 66.0325684085969, 55.12836364007766, 70.43246361517137, 17.8602909657263, 0.0931988554375787, 2.4240409462682666, 4.253275048348212, 2.181519082477016, 4.933114955502172, 66.79204910032212, 44.32184942307011, 41.85100332383187, 36.992288866350734, 41.480005941083355, 42.21676042003017, 0.43290831869648355, 0.028974096471023177, 0.03811494267034916, 0.057140720948096246, 0.016702097622797858, 0.06263045721777505, 0.030018923571333293, 0.07922843008512452, 0.05148879237352841, 0.025155429705797185, 0.033604983060110005, 0.025759036126997203, 0.024153078350448803, 0.04077856143515918, 0.019630108652035558, 0.04111126575979494, 0.06269709537586858, 0.11162667144690791, 0.04627965495831544, 0.1476166241111294, 0.20534088955290858, 0.1745765451942721, 0.15716990906625025, 0.19520974447650297, 0.07460345003393389, 0.07218501770928984, 0.1351837678662231, 0.14599136857976838, 0.18705262411986628, 0.2542156750156034, 0.15347269213488027, 0.10587394868414249, 0.19035484611747727, 0.12391230857540524, 0.17038003811913152, 0.09665285477474814, 0.1270792394455883, 0.2729630109763915, 0.12642397380043424, 0.22080461945264573, 0.1257831565735321, 0.19747324317934054, 0.20467545026012007, 35.635905804172644, 67.61705690814604, 50.03213790155227, 47.09642817897182, 44.10872351738715, 69.06538424953338, 83.43643080803656, 14.549291806836283, 11.74692403885626, 6.836470086728373, 0.5364906992162428, 0.9774665366257391, 3.3569279072746157, 69.80134640970539, 62.29776597792103, 64.44862511850172, 67.86665301169118, 67.93898936240905, 72.91930906234249, 72.09285782229516, 69.2893123626709, 69.49288337461411, 71.64989671399518, 72.31688791705717, 67.21882650929113, 70.34250013289913, 67.78190628174814, 68.28946098204582, 69.49300104571928, 72.61971058384066, 69.24233805748725, 69.56754176847397, 62.23220356049077, 58.027454114729366, 53.58404021109305, 53.24717137121385, 50.267460500040364, 47.750467715724824, 52.55362572208528, 51.110550434358665, 52.314820058884166, 52.33381609762869, 51.52226986423616, 50.74490708689536, 50.22724836103378, 49.372540366265085, 48.26356080270583, 46.877971772224676, 49.07763696485951, 49.55890786263251, 47.74761223023938, 50.26237318592687, 52.63144554630403, 57.50143289566041, 55.768741561520486, 59.88883841422297, 54.27466369444325, 53.401218537361395, 52.6648170717301, 51.26393471994708, 60.46472080292241, 63.92239601381364, 65.197044726341, 70.73505878448486, 61.21850229078724, 58.30073741174514, 36.99827048086351, 37.836579045941754, 74.49849451741865, 57.83278688307732, 66.2060313070974, 64.46140420052313, 64.76017505891862, 63.6096066044223, 66.90966529230919, 64.9112686803264, 63.56471115542997, 49.56368138713222, 47.47864746278333, 46.617487169081166, 49.013443454619384, 43.99867749983265, 49.252041232201364, 42.558822478017504, 45.08805305727067, 47.15075692822857, 46.06473891965805, 46.42869957031743, 49.15770430718699, 45.266007069618475, 48.795371440149125, 42.4551816909544, 47.21334618906821, 45.83518220532326, 47.01328177605906, 42.86159415398875, 46.796249189684474, 44.70729289516326, 46.136231960788855, 44.19325451697073, 47.49722773028959, 46.3649453655366, 47.44953955373457, 48.07050566519461, 58.54581886722196, 59.07912392770091, 62.765516465710064, 58.010183918860655, 59.963151639507664, 58.19879108859647, 63.10350710345853, 60.718455006999356, 64.5964474831858, 59.24031372993224, 60.20688772201539, 57.40937879008632, 61.103329735417525, 52.755215937091464, 70.56516524284118, 56.805302404588275, 73.31456630460679, 18.730541352302797, 0.16707741775579993, 1.825212201764507, 6.527244640934852, 7.467539243159756, 3.953635875255831, 75.65347563835883, 49.59039272800569, 49.45385502230737, 47.546763343195764, 49.34057304936071, 54.992037742368645, 0.9042157220744318, 0.18925544865910085, 0.14682327877850304, 0.13317905366420746, 0.25929060914824087, 0.1449331253646843, 0.24637835040207834, 0.21154733554970837, 0.10053207887516868, 0.11798589835844694, 0.18774601030013255, 0.24767475503106273, 0.08888795611358459, 0.11095538690325715, 0.1210333654777177, 0.19857539855424436, 0.1759150999808504, 0.306734066576727, 0.08929133971011446], [0.043327515989902525, 0.04334938013926149, 0.05013606496035092, 0.038003507520883315, 0.06243936807638215, 0.020584512479423035, 0.04624996522080995, 0.026690035968297915, 0.05465160935155807, 0.007548382103953872, 0.16558932260640208, 0.051555200705244664, 0.0231924596347756, 0.046729835035699996, 0.030087526744952606, 0.06849430486439698, 0.06275465922249902, 0.05400715703745523, 0.08635442673919663, 0.06985311501569326, 0.04831274888748604, 0.1193205614183699, 0.037061295982810764, 0.051763565129330086, 0.14101420258802755, 31.79460317857804, 32.99132224052183, 23.231682738950177, 32.9212922434653, 32.65376110230723, 74.81708511229485, 32.03713705462794, 0.4855655253894868, 4.057287939133183, 0.5209278375391038, 0.06569975401244818, 0.029390235431492332, 1.932816176164535, 58.361200747951386, 69.5423601519677, 63.97319070754513, 63.63598454383112, 63.60423295728622, 61.42064163761755, 64.09676890219411, 61.553021630933216, 64.84984436342793, 63.91012291754446, 65.84073312820928, 65.40206701524797, 64.26533276034941, 65.07309390652564, 64.32500770015102, 67.75626182556152, 63.71183533822337, 59.54778048299975, 54.07668598236577, 47.582292172216604, 49.078213553274836, 49.39840055281117, 44.22612397901474, 44.805254090216856, 45.70274729882517, 47.11195684248402, 47.37217864682598, 46.031779243100075, 44.523408259114916, 48.469740190813624, 47.49379565638881, 46.51269712755757, 46.00095725828602, 45.45701865226992, 44.05463011034074, 44.36450127632388, 45.74289275753883, 46.868165846793886, 54.38336433902864, 55.27432287892988, 57.95279179849933, 56.5309561452558, 54.82462313867385, 50.82408012882356, 50.33107742186516, 48.5015231563199, 48.90620585410826, 58.52038229665449, 62.770078182220466, 59.1717153979886, 57.04471211279593, 61.62707990215671, 24.4716537767841, 24.155946123984553, 71.12717028587096, 70.64818612990841, 60.48299512555523, 60.02794919475433, 59.78639002769225, 58.67375089276222, 58.51321612634967, 55.66133137672178, 50.036052426984234, 42.99994399470668, 43.48951462776431, 44.4778028611214, 42.88749356423655, 41.20673048880793, 41.56403095491471, 38.699778972133515, 41.221121664970156, 41.780730139824655, 42.08733397145426, 41.63033862267771, 42.20007465731713, 43.11489297497658, 45.04973934542748, 42.71942392472298, 41.538092320965184, 41.86865398960729, 43.80683829707485, 43.59645020577216, 44.32897244730304, 40.39701992465604, 41.274603182269686, 40.27461844105875, 40.35442298458469, 41.30746087720318, 41.775329036097375, 43.74393132425124, 52.83022342189666, 55.94549925096574, 56.098150053331935, 56.89721530483615, 59.238897754300034, 57.37362246359549, 56.91545432613742, 55.62801476447813, 57.074008295612956, 52.97406458085584, 56.10038188195998, 52.037594779845215, 55.049567145686, 53.64828863451558, 58.62826316587387, 54.01075093976913, 58.72293741472306, 4.470596419226739, 0.12509052115943164, 1.2612236651682085, 1.3669312961639897, 2.314180015556274, 10.407739589291236, 72.0073736867597, 26.253945442938036, 35.631395078474476, 33.024740834389966, 47.25302880810153, 9.201144979846093, 0.28746048949899217, 0.052418911213716196, 0.03421129951734216, 0.14279713433596397, 0.04493269618720778, 0.08420738106172893, 0.023937570156469464, 0.015043515351510819, 0.041333036722555276, 0.0579116007523431, 0.02985413422838094, 0.02409284660262206, 0.11806559448520984, 0.01853188139296347, 0.014459945959970357, 0.05550514621239516, 0.13398146947785733, 0.023126943795491132, 0.08405114509045117, 0.03031806175356671, 0.036442645509997686, 0.037310849124145125, 0.052199120588240125, 0.04791971130837356, 0.03394206940767265, 0.02461721271937413, 0.01585288149785371, 0.0401497986017456, 0.023821469531544757, 0.02300673310885266, 0.08332343817117714, 0.030514323903668313, 0.057378564435507984, 0.029017412997481805, 0.016115551979671565, 0.02468842825281524, 0.0951455231575716, 0.13212441106236752, 0.05551788242413633, 0.0161157549929715, 0.12434466561723141, 0.04366437251108789, 0.034302402693297596, 0.64197892263051, 48.6513537745322, 34.135971838428134, 32.13151124215896, 40.902248659441554, 41.34237389410696, 83.72092031663465, 35.00857760829311, 0.23814832911856715, 4.586348995085686, 3.022621846006763, 0.9313323541033653, 0.37401034526767274, 2.1396649412570463, 63.553646149173865, 68.11224829766059, 64.23080413572251, 63.444070816040046, 66.75512390751993, 63.645229570327274, 66.42471913368472, 62.866031123745834, 66.3391722402265, 65.37834059807562, 66.60652099117156, 64.4726300239563, 66.67362490007955, 64.02584068236813, 66.39800779281124, 68.24765636074927, 64.90984485995385, 60.917609430128536, 58.399957687624045, 50.00610905308878, 52.345489071261504, 51.7387140950849, 47.486252938547445, 46.09339575613699, 48.916796253573516, 49.83182637922226, 49.21978365990424, 47.64835273065875, 47.60775619937528, 51.1611686214324, 49.21033074778896, 47.96397016894433, 46.786921793414706, 45.697397185910134, 45.51254372442923, 45.33412295003092, 48.63027887959635, 47.97196003698534, 53.17235216017693, 54.64197404922978, 60.14403958474437, 58.21537094731485, 58.81862755744689, 53.96163109810122, 51.93314990689678, 49.379118181044056, 52.025294226984826, 62.16493883440572, 64.6501878769167, 62.6570237067438, 58.749817417513945, 63.34873368663173, 21.55599521052453, 23.781783388506984, 75.11876244698801, 66.98141328750118, 63.02471060906688, 60.93149069816836, 62.18853973573255, 62.33729562451763, 60.05406433536161, 57.75226846818001, 52.6003646850586, 44.97923081920993, 44.64509587134085, 46.758684650544204, 44.31088639843849, 41.3674456842484, 42.5823998451233, 41.197430549129365, 43.857778118502715, 41.81129324820734, 43.38242215494956, 43.25915382754418, 43.4550997518724, 44.16220895705685, 47.75858702198152, 44.68615524230465, 43.99062095149871, 43.34898787160074, 44.37730389256632, 46.6279245961097, 47.10816391052739, 41.88856001823179, 43.17012779174313, 41.712822145031346, 40.823146220176454, 42.74118915680916, 43.539709198859434, 44.401500994159335, 53.874679996121316, 56.127512916441894, 56.74564707663752, 59.121285484683135, 60.639940923260106, 59.222494402239406, 62.13068477569088, 56.117118635485255, 60.56252902553928, 55.82023443714265, 58.77802710379324, 55.14930517442765, 56.93847471667875, 56.784996294206195, 60.949329637712054, 57.06975252397599, 64.87232346688548, 5.029371390419622, 0.15053259989907666, 2.558799857093442, 5.212422522806353, 1.881337273986109, 12.288752409719653, 79.81479660157235, 33.12873071239841, 45.4940144477352, 37.68565016408121, 54.46646367349933, 14.32391731969772, 0.3053788876821918, 0.16944950176102502, 0.05171940782137456, 0.10970870138055856, 0.023619229980413953, 0.07673128988713988, 0.054957420159611976, 0.011738308483824856, 0.05039796360858506, 0.05348977955779242, 0.0053036932536821456, 0.024547780255576777, 0.0450684316456318, 0.07021964978306525, 0.08202196204013402, 0.04648499333509996, 0.031830962829952764, 0.016962996526290814, 0.05727006340279214, 0.1407595396402382, 0.14675702749481126, 0.2535563644262091, 0.13256164808427134, 0.11533624537649656, 0.10277006685012773, 0.20400360647228458, 0.0987846093372472, 0.11845274467862422, 0.22886447728641574, 0.23967935583524166, 0.24714952515017605, 0.3246474698666604, 0.12710262810991657, 0.25414888747036457, 0.15820961295356675, 0.14052546913585356, 0.20484187520079075, 0.2074211093807413, 0.17704724003711056, 0.18318409460686869, 0.29100989742625144, 0.15082591964352518, 0.16129832624668078, 2.9042091677265787, 59.58306220269973, 49.88256223740117, 38.67694685536046, 46.350048203622144, 46.40401609482304, 91.12370367973082, 45.524032346663944, 2.4090719559500298, 16.921505005128925, 3.6533664263063863, 0.528378502255486, 0.20068908110260966, 2.6214670750402638, 64.74991806091802, 71.98703227504608, 64.14083280870992, 66.73252321058705, 68.98127294355824, 66.84912743106966, 66.97073659589215, 64.31504095754316, 69.09339781730407, 66.51685560903242, 67.95364333737281, 67.61980256726666, 68.03567578715663, 66.74324697063815, 69.75641173701133, 71.34839196358958, 66.78886413574219, 65.60677159217097, 59.15037378188103, 52.42361876272386, 54.46458093581661, 55.910990238189704, 50.51791560265326, 49.641242334919596, 51.57828131029683, 51.97113806201566, 52.81188241897091, 50.75220269541587, 47.97592947559972, 52.24624133879139, 52.73627088915918, 52.0148567999563, 50.55170289931759, 51.318675318071925, 48.32305923584969, 48.3484055919032, 51.70489934182937, 50.33532927113195, 58.05967638569494, 57.88220482487833, 63.73452232730005, 60.791069845999445, 60.65397516373665, 56.70092421193277, 57.23274269411641, 51.51415055797946, 53.120086577630815, 62.810961046526515, 67.93835393844113, 63.65812632345385, 59.249256733925115, 66.3022784263857, 30.35130039338143, 30.70756143139255, 79.0135269780313, 64.38651046445294, 65.81890121583017, 63.96920557945006, 64.33211503490325, 63.836845197985255, 62.49034258627123, 58.10456006757675, 57.793610249796224, 46.911864972883656, 48.66316795349122, 48.792872890349365, 47.73656291346396, 45.204143447260705, 48.18175192802183, 42.87033319473267, 46.12487277676983, 45.54673894759148, 46.14594374933551, 42.93190656169769, 45.013382896300286, 46.92846836582307, 51.20510701210269, 46.3786462045485, 46.316939476997625, 44.8147972168461, 48.71761437385313, 49.20163485311693, 50.729315665460405, 45.08994363969372, 44.782523955068285, 44.60365210810016, 43.32859154670469, 44.603259871082926, 46.68585015881447, 49.07815471772225, 59.80879852848669, 59.73323014474685, 56.909508012956195, 60.70744491392567, 64.4598783985261, 60.244009033326186, 64.82515304319321, 60.320801196559785, 61.49515098141086, 56.252130539186545, 63.39822223109584, 56.984641013606904, 61.218780779069476, 59.98725460421655, 65.3168103771825, 59.09305618655298, 67.77656401357343, 6.521362066268922, 0.22811118303047073, 3.7881608836112486, 6.032889696859545, 5.805991368909036, 13.29580428138856, 92.6336593012656, 34.9910524583632, 52.8549421987226, 44.139643561455514, 66.64052794056555, 22.138753514136038, 0.41071692721978315, 0.3236758558740539, 0.13066254676349703, 0.1860366689582025, 0.11510118661868958, 0.18491484044540316, 0.1978169408656897, 0.0857417249391156, 0.10354147908548195, 0.22660261801173612, 0.10917616302087423, 0.11210012144499248, 0.33103477390062425, 0.19195500460843887, 0.1544994797797934, 0.11546850279574433, 0.29065535193489445, 0.22464480371244494, 0.16426857170318404], [0.03488548370378633, 0.04717789687997392, 0.04999275289235577, 0.02095026009145283, 0.13046466625265538, 0.039401947400502624, 0.012014069493048856, 0.019676998978660955, 0.05845027164586129, 0.04905874998639188, 0.031307012315899614, 0.06330361484640068, 0.08453190356733338, 0.032048652459296494, 0.04747335400973116, 0.04486537621086163, 0.03452475205244076, 0.02480764877081158, 0.013573987300567811, 0.03080212206940257, 0.03328443655083257, 0.08412907921498822, 0.05193865835486401, 0.05532298582575976, 0.08404179115689571, 7.589210675608728, 44.153246341213105, 25.1664565455529, 30.88567626091742, 36.82688251618416, 54.28206128458823, 64.0851390746332, 1.1836203067533433, 2.268298335613743, 2.4709120440867642, 1.441010527553097, 0.41435143219367154, 0.19818912170106368, 1.6617112654832102, 52.65771365934803, 75.826020702239, 65.03350542437646, 67.26161172313076, 62.96198014290103, 65.01535269521898, 65.61365535182338, 72.318386262463, 66.84104734851469, 64.32677276672857, 65.4925129490514, 66.07715791271579, 60.55963039398194, 61.92654894244287, 60.42337509893603, 54.94558119004773, 51.634198619473366, 49.93349029171852, 48.5976839834644, 46.572348533138154, 46.968147062486224, 48.461467912120206, 45.789384611191295, 46.898564215629335, 46.378140218796275, 47.43668594667989, 49.78338510759416, 47.80515340066726, 47.72214035834036, 47.23744523140692, 47.0340899498232, 45.859736242601954, 45.58150291442872, 43.34804258038921, 46.005334623398326, 46.030045555483916, 50.063006954808394, 59.11243269520422, 58.10776464400753, 57.202889534734915, 58.62913000968195, 57.95796932712678, 60.312560296827755, 51.1732965900052, 52.44654109401088, 47.14107259627312, 51.801303355924546, 53.03751284076322, 61.17222224512408, 55.87868951982068, 66.4867945640318, 43.316055651633974, 52.1127317028661, 15.439118742942812, 26.77218467958512, 70.1883666746078, 56.13770323414957, 65.49371319432413, 58.960993905221265, 56.186077825484745, 47.880451140865205, 42.663506615546446, 39.91452524738927, 45.907816656174205, 43.225786224488296, 44.84928661777128, 44.04808367452314, 43.650688740514944, 39.44975968330137, 43.1643226838881, 41.29438761741885, 41.688060222133515, 41.80502137830181, 43.070558424918886, 44.17567445385841, 43.62894312027962, 42.22316565052156, 43.836244306256695, 42.70232631314186, 41.08554493996405, 40.99877818938225, 42.75156382591494, 41.38954039542906, 42.3803860141385, 39.84767237017232, 41.57520578753564, 41.06142628577448, 44.050609680914114, 42.58971114312449, 54.243935846513324, 54.940019269143384, 57.90305614471436, 57.486661249591464, 59.7917244511266, 57.09048617270685, 61.01042839788622, 53.56691906529089, 56.912916552635934, 57.4407930527964, 55.401854822712565, 53.99953688344648, 56.48003201330862, 58.22731848685973, 59.6789719981532, 56.49938498773883, 52.07994853296588, 1.0121898088724384, 0.04362486535683275, 1.1820616549061191, 8.61380240609569, 1.7899727701179444, 28.795094143959787, 49.23525741023403, 21.874558348809522, 33.40010381514026, 25.54710884248057, 43.97242899863951, 1.353165370322043, 0.07604171882473654, 0.08660368110624053, 0.012092266002699975, 0.0530673127110687, 0.08896751434452112, 0.023226211553499587, 0.02553371051626821, 0.016257165247694622, 0.03515920308869212, 0.01386385486130753, 0.033119402059744445, 0.008540661318317778, 0.03816969114385786, 0.05103234952736286, 0.06725953200892096, 0.055648113540824384, 0.02896397261910381, 0.0244549150773955, 0.04527962293415781, 0.016233801481223876, 0.03605058469298867, 0.08345792490628459, 0.02014987441080232, 0.068642535216866, 0.05403781970662456, 0.04976334403299036, 0.12680920877403792, 0.05380128239912372, 0.04751724701735282, 0.08726374246180059, 0.11948343171107194, 0.038097111973911524, 0.01608128103637888, 0.0431061587146213, 0.019712941908848383, 0.032149672643431736, 0.039136019129786766, 0.06907851585457403, 0.007506463209152102, 0.020691337694804517, 0.09510469833208669, 0.04989690380170942, 0.053847898849316185, 0.0683784953528835, 12.92083255706295, 52.978991077792266, 22.1800737227163, 44.58902558972759, 43.31383951248662, 66.64223024922033, 69.62513000734391, 1.3269389324611234, 1.5989793284285454, 4.958267154232149, 2.438783664857188, 2.852467957042879, 0.6187345279801277, 2.4230110789498975, 58.62001834377166, 75.89051231261223, 66.65090653204149, 65.68942769881218, 63.51230828992782, 65.06901856391661, 66.2846512948313, 70.26969309776061, 68.88187223865141, 67.59891986846924, 68.30532304702267, 68.2167245495704, 62.64470746440273, 65.27880653258293, 62.443858577359116, 59.65957587765109, 55.87641846749091, 52.51876761836391, 51.13104874087919, 49.22278427308606, 48.21893991962556, 50.99476598924207, 47.50164824147379, 47.932791248444595, 47.662249688179266, 50.41870709388487, 52.50263490984517, 48.9363649583632, 49.29950583365656, 50.245067688726614, 49.3134145582876, 47.93713723459552, 46.6872622120765, 44.54012540078933, 46.217781959041474, 46.376288860074936, 52.790960496471776, 60.39946433036559, 59.78846103914323, 60.78762208261798, 63.108868983484086, 59.23352018479378, 59.887057658164736, 52.597003213820926, 54.08215768875615, 49.67303706753639, 54.71317683496783, 55.78573326910696, 62.255047444374334, 58.696814429375436, 69.63710892585017, 45.506566032286614, 53.44228967543572, 20.777942096033406, 30.718838245637958, 71.15548979851508, 57.38264391499182, 67.30331436280282, 59.37907149714809, 58.68933446945683, 51.18661695911039, 45.309596369343424, 42.16498905612577, 45.26660326988467, 46.634172931794204, 45.47150788768646, 44.60613104604906, 44.904305704178356, 42.33487867539929, 44.367074351156916, 44.33214564477244, 44.227536032276774, 43.27416473819364, 45.26788980730119, 43.33715015842069, 45.724492919060495, 44.327560394041, 47.081464336764434, 43.22214234259821, 43.91658229212607, 42.725087827251805, 47.17341253834386, 43.29221156335647, 43.70003215728268, 42.21062975545084, 42.1542025381519, 43.29771464870822, 45.13300341944541, 44.850628068370206, 56.95259132692891, 57.44622945785523, 59.281647666808105, 58.684478575183505, 61.114292760049146, 59.37363901445943, 63.467801155582556, 56.72187359102311, 59.93316904191048, 58.60476032380135, 57.91996156015704, 57.738642154201386, 60.00715278810071, 57.975757275858236, 63.03284168243409, 58.53573445350894, 56.83483785198581, 1.291940113709819, 0.08977820390775319, 4.228272880277326, 4.460229594861308, 1.2205674403136777, 30.620973148653587, 56.986311943300315, 29.135167560269757, 42.020822340442294, 29.37563434723885, 55.01640742824924, 2.2778220955402624, 0.11869346482619164, 0.03474052454675398, 0.022424711214919246, 0.03821346540785125, 0.014686337390524006, 0.0600482659384368, 0.02786159890914156, 0.058469979257713404, 0.06833439933196192, 0.07721682875266961, 0.030774165605825764, 0.04664345096135813, 0.04235671405049582, 0.05002195999446896, 0.04379669887824886, 0.06469594134438424, 0.06259173147320267, 0.014339873169158256, 0.015436551973013388, 0.13058915554035094, 0.10183904019574966, 0.2474999644102589, 0.16359203945725195, 0.2927411642045744, 0.18957342111295272, 0.1509804702213695, 0.18218289429862655, 0.23164151536841548, 0.14081178683667414, 0.15404741129567548, 0.24073424358521742, 0.17884203082611486, 0.1251033837756803, 0.20938296862427266, 0.19188394229258263, 0.25162835094717245, 0.19493720103656093, 0.09501497411439497, 0.1478148876659332, 0.20253402000713736, 0.18809919215498433, 0.12657682366308667, 0.25233309055047654, 0.26184434792207134, 21.506612570055072, 70.96034403770201, 37.77406431013538, 50.96013930536086, 48.49679670026226, 69.19330058559295, 79.60173345381214, 1.1417228968874102, 8.772246549206397, 10.51420154110078, 3.6639134345516085, 1.517077787749229, 0.21782246898979912, 2.6384171074436558, 57.051615484299205, 77.36305636744346, 67.90536680529195, 68.82631578753072, 63.63665919150076, 66.66491723829701, 69.5744529847176, 74.79771644838395, 71.1681119857296, 69.296553058009, 71.25234880755025, 71.39774322509766, 64.85775970643567, 68.97204752891295, 66.28712238803988, 60.62263934843002, 57.57144720323625, 54.851444305912146, 54.32847469083725, 50.19757563068021, 50.384092177114184, 53.792345523834236, 50.292218500568026, 51.60175277340797, 50.52454833061465, 53.525338019094164, 55.35936378663587, 52.36375162678381, 51.323115441106985, 51.6900178693956, 52.15899605904856, 48.709318560938684, 50.0161228641387, 47.55190557049167, 50.386123964863444, 50.12732205852386, 55.279786740579915, 63.695004447813965, 63.090771167509025, 63.197349809831195, 62.8719578250762, 60.82089947115991, 63.37515869448262, 57.7936141721664, 57.16308924459643, 52.222758108569735, 58.35638015500961, 56.91716055716238, 65.24301882713073, 58.81682718953779, 72.00807186865038, 50.0145931397715, 53.64509974756549, 27.188887480766546, 32.95546785477669, 73.50024346382388, 59.74398920612951, 69.78843396709811, 62.06735810925884, 61.519312781672326, 52.99679863837458, 46.43297103143508, 44.00724787865916, 48.93631396755096, 49.27324948772308, 47.43782343402986, 48.1982062708947, 47.68346186607115, 44.830165063181234, 48.903911267557454, 47.64607775595881, 46.98965341814103, 45.11805918908889, 47.71855531200286, 46.59013255949944, 46.18585386583882, 45.26973724365235, 49.08811753795993, 45.949146670679895, 47.00222853691348, 44.73189007851386, 48.93224646968227, 46.01151627878989, 46.56033823567052, 45.047413379915305, 45.37753182072794, 45.54200856916366, 49.266604992651175, 47.510351980886156, 59.531459500712735, 59.64249395555066, 61.81307869572794, 60.85824435757053, 65.59226666727375, 61.42793724613806, 66.10615207302955, 58.09958650219826, 62.12087885026009, 61.216682311027284, 60.2460329763351, 60.137293108047984, 63.23483197919784, 61.39493442350819, 66.29091924236667, 61.85844875151112, 57.68686686792682, 1.9957721786152933, 0.15135818221155675, 8.349884748458862, 20.382402443116714, 2.6539200304015993, 35.63508210643646, 63.855350940458244, 33.55841852003528, 51.14387489134266, 38.38454592612482, 67.9298423951672, 5.022329755367772, 0.29295925411485857, 0.20569684464604626, 0.07307688960985792, 0.15382285560331038, 0.24751574582149907, 0.09620698394193765, 0.09508985154811414, 0.14136292581116, 0.15143224759207619, 0.17625846058851288, 0.11673532110909302, 0.0742762538814737, 0.18780948834553843, 0.17246246428018616, 0.22754407878364288, 0.2626398536226442, 0.15965938838499208, 0.11788069916468476, 0.1638285767647528], [0.11152670463366855, 0.0557445103843366, 0.03691778856239492, 0.014719887253557964, 0.040617989406229994, 0.024609798903486902, 0.028060469588625337, 0.01224805189732222, 0.052653345609864885, 0.062345909180059556, 0.023590070758796027, 0.08117866011396532, 0.008019790956525193, 0.04389400353595134, 0.009396890020598809, 0.04459538001326784, 0.09402693519669195, 0.06679604881473127, 0.04685015680508749, 0.045175607346238635, 0.03678200330825583, 0.10557343537408499, 0.06793791052675055, 0.04758289309158441, 0.0500566331339219, 0.49182280898094183, 28.763552404219105, 37.33977948465655, 33.390329268670854, 39.011007278196274, 31.93931510371547, 64.29892001613494, 16.23762505669748, 1.5457172187105304, 2.054101868021873, 1.7625692534831263, 5.8479872057514815, 0.5315182370043571, 0.18054726593677076, 2.324249230084881, 56.01123033031341, 63.58053791907526, 66.1099567720967, 66.91035562945952, 68.88400600802514, 69.80046779878678, 67.64169723756852, 66.02455892870503, 63.63231712772001, 60.687895820986846, 58.28969593971007, 57.02695554302585, 50.9374640833947, 49.170475544468054, 50.88377075810587, 50.04759204003119, 48.94936369311426, 49.68571024556314, 47.23244028706705, 45.119581068715746, 46.512210753656205, 46.29739430642898, 50.25912938579437, 48.157174356522106, 46.73609179835166, 47.94606454910771, 47.2701774104949, 46.68366932099866, 48.74859717584426, 49.57607999924691, 46.381635050619806, 44.35478948777722, 43.04079548005135, 45.47664619261219, 49.08759978509719, 58.56033163685953, 61.52358424278998, 61.81625189319734, 63.192286029938735, 59.934106488381666, 69.12450221277052, 61.34779145640712, 58.07954711298789, 57.38308322045111, 51.524109455846975, 48.40135758922946, 49.44548076198947, 57.69593931013539, 59.23505775390133, 62.09224162563201, 65.60620284849598, 50.828755594068966, 23.830938531506447, 38.468978866454094, 66.70644729368149, 57.988179422193966, 57.678261187768754, 50.59412725510136, 48.54745803340789, 44.170947997800766, 45.29031791994649, 47.7100202345079, 47.77584545073971, 46.54586861210485, 44.337166278593, 43.638439178466804, 43.4648625312313, 41.04916495661582, 42.63381035097184, 41.09196978230631, 43.62423627607284, 42.390792062205655, 43.69354847938784, 44.04728351100799, 42.62386714258502, 42.07873613603654, 43.342064888246604, 41.44486150433941, 40.02628926307925, 39.74579664968675, 43.3403782690725, 40.99425569657357, 41.18517706471105, 40.57239693980063, 42.47447975220219, 40.427328078977524, 41.85770665445636, 43.31569087120795, 54.1467434360135, 57.96655147306381, 59.84853606070242, 57.145069876024806, 57.50262921856296, 56.173687058110396, 59.716493391221576, 58.43367830399544, 59.15477468121437, 58.258297366480676, 57.780183976696385, 59.035762125445956, 58.4897917316806, 57.54519477967293, 56.97122650761759, 61.0599640107924, 34.46953019788189, 0.08881440401197442, 0.2674258193902431, 0.34702603194502096, 3.8746197281345247, 0.10904532286428636, 45.233129762834125, 32.1539903456165, 32.52479945459674, 30.07824459383565, 34.821923778903106, 32.84883233808702, 0.08958855884209757, 0.0649648075622897, 0.007794792369578875, 0.0983545199156769, 0.028095945205178954, 0.10141154015136343, 0.0397971147040446, 0.14322582181663285, 0.045611224092182615, 0.023952162216207194, 0.0426013297551582, 0.039581330718412515, 0.03062895938543783, 0.09403227482952418, 0.04336832932406857, 0.06744743805498847, 0.028418472051740657, 0.10389101436181415, 0.043672956526279456, 0.05118585056475094, 0.08915901334295351, 0.06363625405356288, 0.01871070355146883, 0.014160521452375239, 0.004114980477043578, 0.054599741368644664, 0.024658667652176756, 0.0505013088695705, 0.030200566848619815, 0.11370486114174129, 0.03180998159692653, 0.018346419167374412, 0.04217899314338162, 0.09790933090111903, 0.051352409570808374, 0.029426682064489975, 0.05948975719811936, 0.016108260737852226, 0.06196655776171435, 0.11085528985507066, 0.0342007466561852, 0.08382071350370685, 0.023976226953128656, 0.030877436173238584, 0.035756617604244145, 1.4716741466714491, 47.684877841703354, 37.03220682759439, 33.71324231547694, 47.388731048953154, 40.20512580871582, 76.45305079798545, 14.581579777502245, 0.9313437534916786, 3.1617897460537576, 3.1443052907143874, 5.927718204836692, 4.147362228362791, 0.22295464521213887, 3.576723803435603, 60.59313135762369, 60.59486112286968, 67.0854502339517, 66.06707742137294, 71.42756892788795, 70.06718897050428, 70.35364750892886, 67.50322188100508, 67.07209064114478, 63.56902576261952, 62.62526819782873, 60.15200984093451, 55.363631325383345, 51.61170774890531, 52.814596699130156, 52.7281202039411, 51.25803155283774, 50.86483355491392, 49.84422891370712, 47.5189458939337, 50.35161887445758, 48.40469160387593, 51.36013869316348, 50.606157164419855, 50.033051813802416, 49.257834572945875, 48.813661452262636, 48.86971996676538, 51.11300583808653, 52.378025131840865, 48.72569053403793, 46.23393427941107, 45.76922755087576, 47.92790005283971, 51.172523883081254, 60.318710573257945, 64.28258334436725, 61.04441965779951, 64.73813526092037, 62.23777332613545, 65.64779173943305, 61.76679865006478, 60.594547333255896, 57.54346501442694, 53.25769116801601, 51.11893646178707, 52.34562243184736, 57.847072155244895, 61.79463963354788, 64.72784688395839, 66.98751649548932, 55.27247544257872, 22.322257680277673, 34.15632893962245, 69.22576212113904, 61.65858045701058, 61.04460793156778, 54.50458911157424, 52.57496341582268, 47.62030386155652, 48.49836564833119, 48.44757487696987, 49.70073292332311, 47.84513804220384, 47.352378522196126, 45.66708903158865, 45.032849619465495, 43.551919537205855, 44.62699413299561, 43.947165012359626, 45.11841612477457, 45.44043879355154, 45.65627897939375, 45.70595579762613, 44.49769320026521, 44.49209990039949, 44.17665896877166, 43.070291703747166, 42.93430312987297, 44.1055856212493, 45.5304414995255, 43.520081658517164, 44.17843972482989, 43.522556674095895, 43.62527178179833, 43.26871656602429, 44.45640633183141, 45.718805482310636, 55.61645553958032, 60.64372601047639, 61.42598390579224, 59.69717571812292, 59.54809427261353, 59.629444229987364, 61.84643453167331, 59.69407704568679, 62.130606328287435, 58.62112052979008, 61.82724629679034, 60.519990921020515, 61.004831175650324, 58.927438028397106, 60.521881503443566, 63.64500599522745, 37.164025921975416, 0.1770239816077294, 0.2631435717546171, 2.2698859149409882, 1.909031658884018, 0.08599068053186902, 48.91623927700905, 39.56645411829795, 38.5716429833443, 34.139250939892186, 40.02099014097645, 40.707169578921416, 0.02659128915007797, 0.03461405875221376, 0.10762123436096216, 0.060039815988631985, 0.00626522840203477, 0.09893359811676126, 0.07715731904271149, 0.10022072542098262, 0.013440962835785844, 0.09976491076691497, 0.07059998179395353, 0.09644814075962191, 0.04431881461172335, 0.025312891417753794, 0.05408849259237609, 0.05822242560586142, 0.0596121282527043, 0.1110573915103751, 0.06236444467738752, 0.09966394037849481, 0.23867515246233634, 0.24995904536016528, 0.15484140014215825, 0.10045430562909573, 0.13000793995395785, 0.10375019207957292, 0.11226303770296997, 0.20151489324146704, 0.2053389590113394, 0.16775974162643956, 0.12330775795083855, 0.21856088581825459, 0.09360591625614513, 0.17805919621980962, 0.13884197560048875, 0.21343136026013285, 0.18145249074985906, 0.19817634335448667, 0.20764157416359072, 0.2182180308286221, 0.1981100614272779, 0.20844084901675103, 0.199282237238461, 0.18902188377274623, 0.30871054277785365, 2.698027082989293, 66.24482354810162, 52.62493441181799, 48.06858370381017, 53.9349119124874, 43.200404567103234, 81.43061699405794, 18.77681943678087, 3.2186996600320263, 10.1435963953695, 7.207208593045512, 13.353120896124071, 2.77472339330181, 0.30876380121034963, 3.613141784744878, 63.23065073259416, 66.13706819472775, 69.36684977623725, 70.5548886329897, 75.051635003859, 74.45144176483154, 73.80575687654557, 71.85651932993244, 70.81704416582662, 65.43317141071444, 63.547103635726444, 62.48621625284996, 57.862279184402965, 51.56450986862183, 55.817837868967366, 57.33880358357584, 55.29539385149556, 53.59178689218337, 51.732810927975564, 50.68888387372417, 52.62728783392137, 50.79113221937611, 54.84215221097393, 52.82874861071187, 51.64790338085544, 51.57696339391893, 51.85571839732509, 52.20027508274202, 53.27257656281995, 55.42954675612911, 51.89130998426869, 47.454944579832016, 48.77151166239093, 50.704553742562574, 55.11714173901466, 64.81077755651167, 66.08178630951913, 63.696859728905466, 71.34558354654621, 67.57345584131056, 68.56056736361596, 65.52219744651549, 65.340289685034, 62.054335840286754, 56.248353296710604, 53.61956904011389, 54.975956024662146, 61.088711061785304, 63.80765099679271, 65.71616257390669, 70.99544140600389, 57.80919774886101, 28.098681242235248, 41.79115579974267, 71.15425032954063, 64.07030859301167, 63.58751189324164, 57.021256339165475, 53.69512957911338, 50.71766622604863, 50.64674585096298, 51.754807579901914, 51.802837002661924, 50.855929774622766, 49.03334556087371, 48.585281448979536, 47.083515736364554, 44.60791180210729, 46.735848611400975, 46.885761599386896, 48.122304485690215, 46.71738993737006, 47.877403459241314, 48.713076191563765, 46.12686534081736, 47.23989671276462, 46.396183121588926, 46.73875901006883, 44.316032548104566, 46.79797503256029, 48.516216354985396, 46.018921713675226, 45.57165384292603, 45.813919036619126, 45.45108802856938, 45.605829454237416, 44.923584153575284, 48.36558165088777, 57.60302620549356, 64.03942385027486, 63.02500870919997, 62.10366748994397, 60.39438878336261, 61.135704978819824, 64.55189720276864, 62.43794364313926, 63.88129349677794, 60.53904187294745, 64.99851003769906, 63.42911089620283, 64.648077641764, 61.61847029962848, 63.89567290582965, 65.2361076108871, 39.85737631397863, 0.22561456377227462, 0.7059581733999715, 10.098001783893956, 12.720852475012503, 0.3298530066686292, 57.673495508009395, 44.741476351215, 47.71433091932728, 44.27350228832614, 49.78177693582351, 54.252827859693966, 0.26986767868361167, 0.08040560078957389, 0.12578061316162348, 0.1534779628197993, 0.11629212392313827, 0.254430057060334, 0.13804280799963783, 0.19389815598485932, 0.121560885961498, 0.1222123824540646, 0.13199584618691476, 0.20587529716712816, 0.14175093402304959, 0.17639108572996434, 0.11868051027939205, 0.15972907174258463, 0.2707548697869624, 0.3092401546816672, 0.15023221682396629, 0.33958376355228886], [0.062426325429471276, 0.08969197305099619, 0.06547428667545319, 0.010947807252617374, 0.08290779716785877, 0.06645896246716862, 0.019191676532969843, 0.026255261919070638, 0.05637443001051584, 0.03904493510602944, 0.038031749352211916, 0.048447959575681925, 0.06517100012710979, 0.015720574282890847, 0.05539305222731444, 0.03514510707088536, 0.0401686979908376, 0.008560971266800358, 0.0304643519883675, 0.03930394560278904, 0.014246121244204622, 0.05794819294204635, 0.09923167526721956, 0.08779634210851886, 0.0812652969973222, 0.06689045382964035, 7.630440179378756, 41.51325195066391, 43.29131726295718, 47.69082415488459, 25.578391705789876, 61.1215256106469, 49.059158678977724, 0.10575792466801022, 1.7986834962521832, 2.6666385608334697, 4.670248002775254, 3.97566611247678, 0.6968055064639738, 0.5243776233926897, 20.992346694392545, 68.88388833691998, 63.74652085765716, 72.17509423532795, 66.76483569606658, 67.36725684135192, 65.23910430169875, 63.36743554761333, 57.1239871363486, 55.85852853713497, 52.310368168738584, 49.04057056673112, 47.09695377657491, 48.50197815125989, 48.18528206117692, 50.666396925526286, 51.31640034337198, 49.538554683808364, 45.734369447154386, 47.22304621050435, 48.72698883856497, 48.519695497328236, 48.56337108919698, 47.24577242328275, 48.94834779923963, 47.6659288714009, 47.36026248624248, 48.23688476316391, 48.850767074092744, 48.6080547302, 45.7287996815097, 46.02142418584516, 44.735463357740834, 46.07837307837702, 51.13511231637771, 59.67475545021796, 60.16844849432669, 61.1357363577812, 63.057595760591575, 63.570869276600504, 70.00248555214175, 62.848651101512296, 59.66375320188461, 56.83264132468932, 57.368315496752345, 54.124844843341464, 55.14588094526722, 53.3157265570856, 61.463528833081654, 58.20080326449487, 74.42702893287905, 43.0292558670044, 51.01127916766752, 69.26543297306185, 58.56588179065336, 57.99707535774478, 49.644756778593994, 49.202740961505526, 46.67744451953519, 50.16930710884833, 50.65027990648824, 54.045048144555864, 53.543341698185095, 54.83154612202799, 46.614812112623646, 44.30451254690848, 41.050757438905784, 43.71987150561425, 42.15225704254643, 43.3777976805164, 43.35218852566135, 44.443591948478456, 43.64805683012932, 43.75869512557984, 43.36709745468632, 44.43743774967809, 42.49113413595384, 42.125879103137606, 42.25790608313776, 49.29649345336422, 50.57252676256242, 49.6806856893724, 39.55205901976555, 42.15398680779242, 39.56115499619515, 42.47482492077736, 41.53897877662413, 43.916668584269864, 49.04645412198959, 57.82429102928408, 55.28947499490554, 60.158454295127626, 55.35639455241542, 60.54918119984289, 55.36889906852476, 63.380461738955596, 55.93677589970251, 62.59914129011093, 60.76549207010577, 63.98595802245602, 57.817262141935295, 65.81650072528471, 56.88274175890031, 63.55782347340738, 10.918824422744013, 0.23885708302259448, 0.49310193066635444, 3.3305426134217173, 1.8253865020890392, 2.1540914187508244, 56.05448230620354, 20.79315108637656, 39.5289719489313, 27.485271576912176, 40.928399101380386, 13.736984633630323, 0.09184982822907549, 0.09849796987949841, 0.028177144779493252, 0.12288903727406457, 0.0651239853111967, 0.0693900301872242, 0.03717289584118032, 0.046222443512130174, 0.010106229024278301, 0.09876180289974136, 0.06260372074921766, 0.06652264735631405, 0.0302792230110255, 0.11908375598009556, 0.038023667124610756, 0.02748857537705091, 0.026094938868716843, 0.032780021278848576, 0.051696065122321735, 0.035446026407542734, 0.03600784847813268, 0.06382942695410983, 0.016011151432570432, 0.05076229587317475, 0.036370188914119236, 0.08826711079886845, 0.01649037007272484, 0.060041895917346405, 0.02228064263509887, 0.00682196029717283, 0.07719337114042814, 0.05302132828341377, 0.10603164788335563, 0.024068651630753474, 0.03361293505276403, 0.09063331890971431, 0.030376449144715746, 0.016567980525113882, 0.009706744815283006, 0.11994964217827206, 0.0681918993171665, 0.08642592572516973, 0.06048321235744704, 0.04910315244248317, 0.04908743231827694, 0.09027326524618173, 20.551319314587502, 51.333490110212765, 46.86961712375764, 54.745830566652366, 31.731804070934174, 68.56867882513231, 49.651993551561915, 0.047166325121877656, 0.6540836634174471, 5.927021493834834, 11.252607337890133, 9.276002433992202, 2.057482215666002, 0.6182343644961235, 24.581476219238777, 75.93368976346909, 62.43162862716183, 74.51157169957315, 68.22252965742543, 72.51576777427428, 68.76752730338805, 65.10059364380376, 60.23130447633805, 58.42853607669954, 54.18250368487451, 51.97594296547675, 49.528870351852916, 50.62057187480312, 50.256850488724254, 53.907984841254454, 53.82182998041953, 51.73227748563213, 47.603720080467966, 50.43306689108572, 50.67463782525832, 50.28759010376469, 49.601167478869044, 50.28562891867853, 51.13532412436701, 49.3831935236531, 49.36354244908979, 49.94552412340718, 49.29498334084788, 49.20077977641937, 49.462590140681115, 46.456085558860536, 47.10985445207166, 48.33990973810996, 52.48489795192596, 62.73316867889897, 61.92667053591821, 64.42617739400556, 65.07857345765638, 65.37624213003343, 70.30125248816707, 64.57174047347038, 59.5836466358554, 58.63829266640448, 59.156908450588105, 56.54371561542634, 56.23606451096074, 56.736860967451534, 64.30801207019438, 60.538018134332475, 71.58174945462135, 45.73340846646217, 54.15737305918048, 71.21645127573322, 59.50680740417973, 61.08850317616617, 52.00843980235439, 50.22199238500288, 48.55010171090403, 51.33934620888003, 52.72335060181157, 54.86942052841187, 56.04709648316907, 54.19527884452574, 47.006601979655606, 46.21520888420844, 45.07573289255942, 45.581134211632516, 43.94402711622177, 46.72779206306704, 45.30049647054365, 45.56498189126292, 43.77856193050262, 45.10784141479, 46.89249630897276, 47.680720129320704, 44.94193692361155, 43.5874758228179, 44.57962759079472, 51.55047170577511, 52.81633823148666, 49.89936567121937, 42.37407099816107, 44.45133862956878, 42.06659247798305, 44.30674045316635, 43.96165424777616, 46.38307456047305, 52.90430130497102, 60.25636057699881, 58.198410618689756, 63.059745219446, 57.41974561445175, 63.28662687732328, 58.92973261494791, 62.77538122669343, 58.666667092231016, 64.11386259140508, 61.77216445246051, 65.2180019501717, 61.010212667526744, 67.88453117493661, 58.5266855455214, 64.70401064042123, 12.138087307253192, 0.5509433462735146, 0.7311539472110811, 2.52853435854758, 1.052438352377184, 2.153232909979359, 63.40443134307862, 27.76531704010502, 44.47087987776726, 29.623526180944136, 50.59112664191954, 20.150390325054047, 0.1061088159199684, 0.07281212196234735, 0.026188550982624296, 0.04363510029150113, 0.004497870742794006, 0.02895701079509191, 0.010044712163958578, 0.06692427661149733, 0.015687828812177385, 0.021986487854812897, 0.07470412930894284, 0.06238755755006306, 0.04294702310055014, 0.09952907826030448, 0.05168219510045263, 0.014726945796170303, 0.02029698052924247, 0.004028683545203099, 0.02153114434481869, 0.03775093599312729, 0.1515155213494455, 0.2881455559644007, 0.273275513562464, 0.11395223093249145, 0.18950799720421915, 0.15741924004208657, 0.08765944985732918, 0.11368003223211536, 0.14200478491763915, 0.17748262312623764, 0.24912137418024002, 0.32221290373033096, 0.12516438735709076, 0.10753371647649235, 0.25250929077306106, 0.16106695237178958, 0.08530355328994413, 0.09988117993118302, 0.08163171685150555, 0.1830249168579617, 0.1273059095406244, 0.20780829021767264, 0.3230902582647339, 0.15470805487805797, 0.19509020411679823, 0.1948140600636121, 29.730697101162328, 66.6601868598692, 53.20306431862616, 66.6576216297765, 36.52700554940009, 74.69993175998812, 59.29124962898993, 0.39865775334258235, 6.455776604913897, 8.197522730596605, 11.216460735567155, 7.57710918303459, 2.3164241015911102, 0.869196004444553, 26.77274557851976, 76.75164514972319, 65.5271278658221, 76.22945216394241, 71.32847416785457, 74.06972454440209, 71.93102867372575, 67.28693454496323, 62.208010381267925, 61.83729933154199, 55.863372664297785, 55.45322610485939, 53.871169474817094, 53.321041368669086, 53.56453426422612, 56.00326791886361, 58.32981786420269, 53.27496528625489, 49.472984421637754, 52.72560596466065, 54.759311752934615, 54.070892641621256, 52.6644758255251, 51.91680146801857, 53.31344373764531, 51.54615709858557, 52.37853503996327, 53.602498885123964, 52.04663976546257, 51.89403995390862, 51.003705070864775, 50.0379979225897, 49.942095971876576, 51.189507745927386, 55.43818381524856, 64.82250936569707, 64.9080680262658, 67.21539051302018, 69.70367154767438, 66.12410083893808, 69.1804430561681, 66.25743004583543, 64.55232081874725, 61.44018288581603, 62.469228467633656, 58.069784333628995, 57.13254967043477, 59.61378220588931, 65.51956553612986, 63.77643285259124, 71.58516191667127, 50.967823228528424, 54.988742951423895, 71.21191701581402, 62.9016266330596, 63.016732508136386, 52.70635497185492, 53.75680885007305, 52.209139639331454, 54.20638699685374, 57.0969973071929, 58.94459447553081, 58.039009417257006, 57.8487430849383, 50.50495216923375, 47.07438838097357, 46.31604125422817, 47.919976865091634, 45.97235925735966, 49.94255488918674, 47.89299488067628, 50.02865875920942, 48.5586917015814, 47.10957204141925, 49.22507493726669, 49.44638682949928, 46.133811858392534, 45.622781938122166, 46.70357142725299, 55.62403355875323, 56.06330763909125, 53.25221553925545, 44.38867484369586, 48.16123008728028, 45.02584818870791, 47.406805330707186, 46.63212545456425, 48.37152011932866, 55.08358978456067, 62.197565109499045, 62.046314593284364, 65.00808846565985, 57.504974795926, 65.32603186945762, 59.761122119042184, 66.09501254174018, 60.71749010393697, 67.63473110814249, 61.26633559503863, 70.05700649753695, 62.08120799833729, 70.20241660456504, 60.349230535568736, 69.56696910242881, 14.244760947842753, 0.6705176589950439, 1.630696594234436, 10.207748720722815, 4.842255701941829, 3.046193329557296, 71.24229969516878, 31.35911222427122, 56.5998996457746, 39.598390056240945, 62.376774280301994, 26.261429325226818, 0.3206046706726474, 0.16575026235753493, 0.11731800758430075, 0.2069312267966809, 0.23157806796652658, 0.1385667968180872, 0.08923169976520924, 0.22887852733894704, 0.12910322075889957, 0.25715981219564715, 0.21851236180913067, 0.15003749259537266, 0.08810296880021211, 0.24163442753976394, 0.151346200596421, 0.20482007233846575, 0.10468740872437916, 0.06927458839791437, 0.16813805116520775, 0.14042218516190208], [0.10431610889011815, 0.015774355570395148, 0.017862753386819558, 0.06103294556059184, 0.08094658909906303, 0.05081450859565408, 0.07506574579184094, 0.009690885837640493, 0.014275603180360651, 0.0827035045010909, 0.13979261410572838, 0.08329673234613673, 0.058932393759248726, 0.02218356971899348, 0.019146617156483473, 0.027008851118866476, 0.09348484372059185, 0.05077890082893353, 0.07503772229557076, 0.03316496130860141, 0.06786281858841259, 0.05041441534675899, 0.08103085877073389, 0.04888005231717422, 0.1824302640893767, 0.040512502929496194, 2.201753854751587, 43.50167397529849, 50.68885249476279, 46.2982689949774, 42.20014525998024, 29.919657284213653, 77.6610388294343, 3.300477891199051, 1.7047331698479193, 1.2608884250925434, 7.686394260775659, 8.08483450643478, 1.5129906780296758, 0.3392728544290989, 4.594799741621941, 57.867825415826616, 63.39525691924557, 72.90743997020107, 68.3403419679211, 67.71862276138799, 60.60894243178829, 57.22621587014968, 49.97200404444049, 51.97267170875303, 50.53952786230272, 56.82183519486458, 58.43263103115944, 57.609258851697376, 58.00646943430747, 53.47726937263243, 51.42256713682606, 49.3943722786442, 49.2737986195472, 47.14055876578055, 48.079162336164906, 48.8580273812817, 48.89827874399001, 48.900553718689956, 48.86056123241302, 47.26114811435823, 46.162602055457334, 46.25852361802132, 48.50335490319037, 47.73592748949605, 47.25963015710154, 46.17753451870334, 45.088813997084095, 45.5084252357483, 52.12929587210379, 61.42369716398178, 62.38560745793005, 61.36709736239526, 59.19355123273788, 59.03455011306271, 64.00212210993614, 62.663221051616055, 63.13187368454472, 65.38946443988432, 60.933463650365034, 58.6422150365768, 56.602437419276086, 58.761337418710035, 61.452918821765536, 60.491467445127434, 59.49551097808346, 51.41374572630852, 63.57414053332422, 57.47415673348212, 58.03461636266401, 52.29916195715628, 47.38918604389314, 47.79968953901722, 52.29396089430779, 52.90765100909818, 53.87407595111478, 56.20934924771709, 58.202423203376036, 54.84027731803156, 47.734260482172814, 45.83042044793406, 44.2020288590462, 44.036183203420336, 43.57531647528372, 42.8273283281634, 43.51475900219333, 42.489631868177845, 43.624836398709206, 43.062729374054946, 42.20950403521138, 46.21543638167843, 46.659260411416334, 46.499231630756015, 50.74339305200885, 56.06859107171336, 57.03396089615361, 56.821137012973914, 48.88497014199534, 42.44103762411302, 40.188479269704516, 41.445328266389915, 41.94945089278683, 41.661423406293316, 49.285518661622085, 56.22455235450499, 57.32591075281943, 57.683944702148445, 57.388350963592536, 58.587721547772816, 57.31134699236963, 59.53156540470739, 59.84620617282007, 56.961314678192146, 63.75539325898694, 63.127037402122255, 62.0606626233747, 59.412262593546224, 60.85252554185929, 36.78182625001477, 0.01129067373356872, 0.43631428432080055, 0.84720658438821, 0.904457254275199, 1.5919986126884338, 13.28570515878739, 35.421595342697636, 26.11826281393728, 59.15436283234627, 40.0863838964893, 37.84879330665835, 7.698262862620815, 0.5196025054300986, 0.17755498779156517, 0.052328087659853126, 0.10048836589820924, 0.06685713666581339, 0.05326619679709116, 0.028350317039557045, 0.020521930756888563, 0.07227759177405989, 0.07762447945893773, 0.06210597044217491, 0.06416586595737646, 0.07904426254812749, 0.023010778053092863, 0.026710007880483905, 0.10088726788038209, 0.11216606629351455, 0.02096637858137969, 0.021866899614612904, 0.044030263764603485, 0.10489501089097993, 0.054561482937706095, 0.025534034188416217, 0.13271770019444729, 0.06457027228128526, 0.05922355696619038, 0.06563525707010301, 0.06341090929063578, 0.03323997280770733, 0.060712755282199195, 0.0646312911844542, 0.08052598384599532, 0.0403017291588889, 0.01149302532505845, 0.01611139212224272, 0.06224500773955257, 0.01881378451212039, 0.04676636593836931, 0.03447392977954399, 0.03044957606752794, 0.1098680476688089, 0.010474543988464341, 0.0412113206731456, 0.17734043720749118, 0.08147493695780154, 0.06644583938102569, 4.634390675252484, 56.09119176864625, 52.480528431554, 56.93542703505486, 46.21137280617991, 39.02343334690217, 84.2830430307696, 2.34123015115338, 0.8745394370728924, 3.371017060933575, 7.712730525001404, 9.53346779269557, 3.698840670047268, 0.5792061071242056, 5.349072506350856, 67.09760173674553, 65.02048315540438, 73.838226256832, 68.0797161594514, 70.87720547952961, 63.38472927770307, 60.44672104620165, 52.177458655449655, 56.703093282638065, 52.16017277010026, 57.40383648103284, 58.06643462950184, 61.393392932030466, 58.63633148131832, 55.51621152508644, 53.2211935135626, 51.002669565139286, 50.52938069066694, 49.761835605867454, 47.87912537974697, 50.86040127661921, 51.14011333834741, 50.93189039537984, 50.1445451859505, 49.29245733445691, 48.797971971573375, 50.60297219983993, 50.106706080898164, 49.91312926815402, 49.775418773774184, 49.336670291039255, 46.69239659463206, 48.2059843309464, 54.130245947068744, 63.20445322221326, 62.34250453210647, 65.12788157309255, 61.252603377065356, 62.67513328982938, 65.81714399399297, 60.43260835832166, 66.26012079177364, 64.57778484590592, 63.12382105858096, 60.357059586432676, 58.63076956041398, 60.18285535996961, 63.531327862893384, 63.49749349778699, 59.43736576264905, 53.98901316427416, 69.12671442954772, 61.79551824446648, 60.94581911640783, 55.31179328118601, 51.00974552093014, 51.52559603414228, 53.633693495104396, 54.11566649713824, 55.81492354792934, 57.358313452812936, 58.17957539712229, 58.72012899767969, 52.495562876424486, 46.56671600957071, 46.34670634423533, 45.012472906420314, 44.33419312200239, 44.76377894801479, 46.00888829077444, 45.01073921880415, 46.36900894103512, 45.48061563122658, 45.285901331132465, 48.38746847644929, 47.064864866195194, 47.78876573808732, 52.01429982339182, 59.38613568582843, 59.88135453193419, 59.06485042264385, 51.568702882336034, 44.81916673721806, 42.443151781635905, 44.345662132386245, 44.60785296655471, 45.480407745607444, 51.499276930286044, 57.825040201986994, 58.858643577944854, 60.43459307762885, 57.910041885991255, 59.802997343001834, 58.814077608047, 61.27534920169462, 62.00687123883156, 60.57197801528439, 63.5700338117538, 65.08763021038425, 63.265010695303644, 61.43594280365975, 62.29846023744153, 39.027547913212935, 0.05767384153460303, 0.557418505270635, 1.2397947763243031, 2.344780876751869, 1.3808228604255186, 14.155037710743567, 46.794464511256066, 29.826736334831487, 73.40583985851657, 44.09500698889456, 50.57601767201578, 11.338498419330968, 0.60226087969157, 0.14570102125646608, 0.09373356182608875, 0.055592422779168815, 0.052966851771118185, 0.07330542129855003, 0.04595847642650047, 0.06970958078220006, 0.07845224512200202, 0.014468763631978824, 0.08145086647522065, 0.050976850287688356, 0.04296290410322048, 0.039874884119677934, 0.04778805526814634, 0.05484330370241115, 0.08194578225694357, 0.033797420516249635, 0.012543214083228622, 0.04896147214176674, 0.25283092512719096, 0.14840331980057303, 0.15128088393999686, 0.1759542623955396, 0.17916826170779046, 0.14851895311186392, 0.14269449387586888, 0.19891347315522934, 0.13934056094336894, 0.15514742162439132, 0.2992753426153814, 0.19489399367763152, 0.22918661725857567, 0.10649202076057274, 0.08825388812129537, 0.13088216884962975, 0.1749226790402205, 0.16529584964436872, 0.20990873476670635, 0.2275716273054, 0.27227653490920223, 0.12171359792832406, 0.15189727828387292, 0.3410544378622886, 0.2817907034149093, 0.27249119274558564, 5.461047839733863, 69.85117620037448, 59.54454844997775, 62.79612272016464, 57.662410889902425, 40.765718798483576, 90.60133810966246, 4.601753613641185, 3.6968181979271675, 5.514385209929559, 14.12656032270001, 16.354762719523524, 5.485650906639715, 0.49248044949866115, 5.676334971381772, 69.73859633168867, 69.86300606881419, 78.25902769642492, 72.34737257803641, 75.27224479183074, 63.71942120213663, 62.42783961757537, 53.77807986351752, 60.47771169293312, 55.00005506700086, 62.20175812321325, 63.2253319986405, 63.78969830851402, 62.435731426362075, 59.18848745284542, 56.466978365375155, 52.80529675945159, 54.075940732033025, 51.42917633056641, 50.99606821613928, 52.69566651313536, 54.63737703138783, 54.673521672525716, 53.81725257442844, 52.400825869652536, 50.8485008055164, 52.006360946163056, 51.64616969323928, 53.63420732559697, 52.33280412612423, 52.17937277209375, 48.953580241049494, 49.53596199712446, 56.09123883708831, 67.05960965925648, 63.78836078028526, 66.07918970046505, 62.12842156810146, 64.18033499871531, 67.5957113696683, 63.56336578246086, 68.29938457858178, 68.4010131897465, 66.18572911908551, 62.68587273936119, 61.34450451020272, 62.86277947887298, 66.57842113125709, 63.62114229509908, 60.29194431920206, 58.15170695704799, 66.18923571801955, 62.499752352314616, 63.00433389602169, 56.50683356869606, 53.057081545552904, 53.78554805632561, 56.31253111747004, 55.91854472314158, 58.11753919047695, 59.005512806677054, 61.04101504048994, 60.32051878590738, 53.75652251705047, 50.25916076475575, 49.30428328052644, 48.62177125869259, 48.47615326604536, 46.75424452750914, 47.01561558631159, 46.733852124983265, 47.94333457946778, 46.94481680470128, 48.12525018568962, 51.80240946431314, 51.98165393644764, 50.11719842110911, 55.413692535892615, 63.333679629910385, 64.83197012255269, 60.84322167981056, 54.601102952034246, 47.22190872315438, 46.73123590407833, 47.011293134381695, 46.95441092214277, 47.56151537741385, 53.16439759346747, 60.430082351930686, 62.58014917373658, 62.81251038274458, 61.022423005873165, 63.52948042654223, 62.614371853490034, 66.03354115639964, 64.76204602949082, 64.49442663500386, 67.94404137519099, 64.71964128555791, 61.96768676081012, 62.28088017432921, 62.537599302107296, 41.74887657165527, 0.14107614845758484, 0.6590283626029569, 3.2156757577773067, 8.766086466850775, 2.4083487689495087, 16.505945574852728, 51.60747551148938, 37.83174668588946, 74.5278730700093, 44.94350979405065, 66.15141622481808, 14.170127068796466, 0.8078828009386217, 0.2446151224355544, 0.18797065792304857, 0.24890706874430182, 0.1508572066743528, 0.2247544002508925, 0.18284545310081976, 0.22434579959559828, 0.1554335248205931, 0.0841071691003538, 0.11937715999421575, 0.15301348371130807, 0.26568254035326744, 0.16095666635421016, 0.18236425795382072, 0.14781888664489792, 0.22990879302303638, 0.13352653582490262, 0.050237138770640864, 0.12364850619867926], [0.06216339256253935, 0.02650631659273659, 0.011041629083094098, 0.11016789448237228, 0.036322764241166657, 0.01993695367878724, 0.02714862577587126, 0.04651242694366844, 0.03611103286065402, 0.13014742924321082, 0.016692952448201757, 0.012333017751394261, 0.04940761110535072, 0.02976907357092827, 0.11339616601265247, 0.07967219417614323, 0.004570555249829927, 0.08000421668252639, 0.023775667049771836, 0.028739763581524455, 0.06538289238608654, 0.07030545929146391, 0.05183891753756231, 0.08703354836231278, 0.06595768049479493, 0.1722792007269398, 0.13708389574481597, 21.252382186151323, 62.45289179586596, 32.82567074221949, 61.193967865359404, 22.310123828149614, 61.68387582225185, 20.17205749788592, 1.0688675675661334, 5.820578173283608, 8.930856412456883, 15.996656206346328, 4.472208023071289, 0.497967079281807, 0.35102681887726633, 39.68075982985958, 65.5631430687443, 75.20566648052585, 68.38144056258663, 69.79880471383372, 58.12414446184712, 59.34856330194781, 57.310550751224646, 65.47555262042631, 65.06200144367834, 67.32661324162638, 65.32138778317359, 65.51337211362778, 61.01121679429085, 60.629334834314164, 57.88225581569057, 52.803315962514574, 51.159631052324855, 50.045442581176765, 48.4016360775117, 47.879023398122484, 49.357639281980454, 49.92326075030912, 50.8089711589198, 54.60224043938422, 50.89023482414984, 49.90302524259014, 46.74105359661964, 46.756425365324944, 47.865189198524725, 46.59793415377217, 44.23360786130352, 46.0473196737228, 46.408895523317405, 60.674724501948205, 62.104573557453776, 59.650083741834095, 59.649942536507886, 58.54344975563788, 50.287476355029696, 69.90246511274769, 58.81336765904581, 60.27732564556984, 61.81536935990857, 63.421164174233716, 63.88192499837568, 64.48117686856177, 62.913166246106556, 64.58354680768906, 56.66648187944966, 56.8251770542514, 66.17578198832851, 58.06245342377694, 58.57625253738896, 51.79403912636542, 50.72666806559409, 53.21425876309795, 57.278626580392164, 55.67364761906286, 54.31549164556689, 57.093314201601096, 57.44969683308756, 56.00258542645363, 54.397006342487956, 45.83051850718837, 45.0435027768535, 44.30765828778667, 42.6937206329838, 44.1746977836855, 44.93026002760857, 43.44324242684149, 42.23192038074617, 43.24897527694703, 45.383081974521765, 46.97748230349633, 46.54034591490223, 50.39285475207914, 57.337191489435014, 57.84965307481828, 57.29914057639338, 57.25346849810693, 56.65122778184953, 46.94094542534121, 41.81844372903147, 42.15753655279837, 41.99039259264546, 42.523717264975275, 48.00053058132049, 61.03600225140972, 58.77967449926562, 59.45029781710718, 58.52479888546852, 55.91750529504592, 53.87623717707973, 57.13664854726484, 58.367480462597264, 61.32654789955386, 59.345648980909786, 66.48475493154218, 58.421581714384025, 67.0138277546052, 42.57196634046493, 0.6244787165234167, 0.03917200611002984, 0.16551303557090222, 0.24644987237068916, 1.795342494883845, 0.3958650870669273, 17.890783471445886, 24.891168917379073, 38.818481660658314, 41.8614132942692, 37.84507097736482, 36.02622086001981, 1.2180826188095155, 0.10101101406279112, 0.03657813965072555, 0.02267439267598093, 0.047107547025887236, 0.08218818013706515, 0.03821980861586429, 0.08346141060634006, 0.0589148503457827, 0.11464956246556775, 0.01776325963287344, 0.05964260323033218, 0.08113984243884202, 0.12323353169185501, 0.038044742203407714, 0.08016484233761027, 0.056321527808904655, 0.021394345939399737, 0.02004119526264408, 0.0872179993518418, 0.03708450844691646, 0.04220904677265114, 0.034167663149175145, 0.043039547369605115, 0.06347289346458931, 0.028846832029821894, 0.06733993293657418, 0.07635982151353553, 0.04880193433153534, 0.0726270734242374, 0.04359498792778581, 0.06973990254224309, 0.03684676072049526, 0.04378051527084843, 0.03598798764869571, 0.09103511670424093, 0.04054081370873798, 0.018031030345047196, 0.005088918588890304, 0.06069044680184415, 0.06998148070828569, 0.0627216178503248, 0.04074158237105416, 0.04579933315155007, 0.0316860189946789, 0.03540075444165738, 0.02264569693755719, 0.167071488235266, 33.238447250858435, 64.82646703720093, 36.16024432643768, 69.13262151902723, 26.06794664936681, 73.85870887387183, 19.138136409944106, 0.8304223334116321, 2.6442011325590076, 8.658700796865649, 6.0748306205195775, 5.37462184506078, 0.5177304929783267, 0.43205958520693166, 44.72255483750374, 70.47671579545545, 77.16123473259711, 70.12438497235699, 69.91145518518263, 62.17668633307181, 61.337040239764804, 59.35319954349149, 63.50029407009002, 66.10238659766414, 69.04573317497008, 67.39896528182491, 68.10166574293568, 65.18186123140397, 61.60846041094873, 59.243745803833015, 56.79647314933039, 53.4847689444019, 49.27427714870822, 51.834890611710094, 50.339930211344075, 49.39329754921698, 52.075245611129276, 52.19048092442175, 54.91237832653908, 51.95562901035432, 50.87627903107674, 50.475726589079834, 48.428268970981726, 48.64248137320242, 48.72711827678066, 47.62986660003663, 49.00079773318384, 49.66770656647221, 63.30839210940946, 64.49540330517677, 62.5000661419284, 62.422234550599136, 60.00628594429263, 57.194381913831165, 68.71072353855257, 57.22506269331902, 66.68045766891973, 63.431166218173125, 66.68453693389893, 66.85217903506371, 66.79039386010939, 61.54922085423624, 67.43594538780951, 56.131635327492994, 57.566614843183956, 68.394651105327, 61.77785188921037, 59.93100781594554, 52.452118704395915, 51.52146577835084, 53.967173407154704, 59.02005303290583, 56.91954143585698, 56.396057990289506, 59.68457314275927, 58.35086922491751, 58.25650092094176, 54.63399987066946, 47.493383807520715, 47.43321857144756, 45.92815022314749, 46.010810252158876, 46.433641756734545, 46.659652648433564, 45.37519801047541, 44.503176673766106, 43.24906549146099, 45.58741784864857, 49.087238927041334, 49.836176287743356, 53.181699168297556, 57.66967119709138, 59.7212080801687, 60.22357740709859, 59.533346160765625, 58.007187228049006, 48.84553855465305, 43.81103915552939, 44.76519100127682, 44.78597564081992, 45.141154104663485, 51.5933471341287, 62.970452462473226, 59.133052595200084, 61.89627608945293, 59.95891940209174, 58.291547298431404, 58.18232497861309, 60.72196160593341, 59.89767159185102, 63.9676836998232, 61.491789510173184, 66.55361606228736, 60.15076644958989, 66.48278590171569, 45.76604258629584, 0.8370722217425224, 0.4217546913892992, 0.9665876590917188, 1.8341357164805936, 0.5638808552776614, 0.5549114365731517, 23.305523318629113, 30.53404361970963, 45.76617986925187, 49.42355471272623, 40.89856163147957, 49.27073524844263, 2.3595022674529784, 0.15426079742610455, 0.07000596487834569, 0.018387242077639507, 0.03931220020017317, 0.047872979944992455, 0.021010901696319063, 0.05927810242639915, 0.07076273717346691, 0.05837684977919825, 0.024577435519125675, 0.018958259118540634, 0.06847065573017444, 0.022421487899977836, 0.03570935764019528, 0.045348655117014726, 0.022248587601127166, 0.045299709759532444, 0.04566278180948669, 0.05332686713025455, 0.012813825066381646, 0.13247259802395298, 0.10351465834725289, 0.19917356000552255, 0.31999109553233274, 0.10155308255625349, 0.0909835130216614, 0.14830333000469595, 0.1529504040316228, 0.09403011446157772, 0.1910511281100973, 0.22221425187683877, 0.1923165521434238, 0.3597845828100559, 0.09436185351542889, 0.23727011656568897, 0.2588269114494324, 0.07626658095227135, 0.14961640470691268, 0.15674767204590384, 0.14692974967821953, 0.236260213498627, 0.18205065220113725, 0.11129227406795948, 0.22625260776089084, 0.11580213408676848, 0.23248626520076107, 0.2643584033414241, 40.87246610272316, 78.24311071826567, 42.203259621897054, 80.89038110548451, 33.552150572499926, 76.3889592693698, 25.104600767935477, 1.6113537934518631, 14.343239895759092, 22.09429148704775, 34.43422494396087, 9.097799351138454, 1.6384882600076738, 0.4945580799493098, 46.808267331892445, 74.1178677158971, 81.09053181063744, 73.54591554211032, 74.67791157384073, 63.44624380911551, 65.75925373261975, 62.9692796737917, 68.59117754044073, 69.44680336982974, 72.19924819084906, 68.64041113084363, 72.61104214575984, 70.67900026998213, 65.90236925309705, 62.71095629661315, 61.27670241940407, 58.21067194784842, 54.05821161885416, 53.28910543072609, 52.92933387141074, 54.00356907998362, 55.568065258764456, 56.59973882859754, 59.9821751348434, 56.94575855808874, 54.59818470862604, 52.00231306014523, 51.49822573507986, 51.04842401319935, 50.636590834586855, 49.35203813737439, 51.606902845444225, 50.90275502973988, 64.38878936152305, 65.65908032078897, 65.00004368443643, 64.12364106024465, 61.28180934536842, 57.82394586070892, 67.31144151379986, 58.80156524719731, 68.11519792003017, 66.36913130360266, 69.95758225840908, 68.57762182912519, 69.33566693336734, 66.73956778741652, 69.07930866364511, 59.160881811572665, 57.51298427581788, 68.85802422800373, 63.21043483672604, 64.82712599538988, 54.97580305222542, 55.491869295797045, 57.323765216335175, 62.55544216402116, 60.24531910496374, 59.349575273452274, 61.30116231979863, 61.7539018969382, 59.693084686033195, 56.23116154824534, 50.2467699973814, 50.379063698553274, 49.0705257077371, 46.23982175703972, 50.6669186007592, 50.21524198593632, 47.804659182025546, 48.10803098063315, 46.870197634543146, 50.62650642087383, 52.03120916120468, 51.92725066215762, 56.71153814561906, 61.981313074788744, 60.58516110143354, 63.10799037256549, 62.679993106472885, 62.534896789058564, 52.51135433873823, 45.32639588079145, 46.3668437927, 47.753460484166304, 46.68458323324881, 52.29559652266964, 64.66724234242594, 66.1377820660991, 63.583311034787094, 61.96951458531042, 60.717725446147305, 59.044210910797126, 62.591708398634395, 62.618878656818026, 65.26397212859123, 64.21259257101244, 70.97691212930988, 62.335020649817686, 68.00639921619047, 48.41439554768224, 1.1311903523821984, 0.8393520994051811, 1.1905833718276795, 4.139245863883726, 5.907664106738183, 0.7111792158215278, 24.95967899599383, 37.054489812543316, 54.27937838339037, 50.21189228180916, 48.23337816422986, 61.721805141818145, 2.713545205131654, 0.219863128037222, 0.13301190860088796, 0.12692347078794433, 0.16674285183750814, 0.2675203546400993, 0.10463419625715864, 0.21355100787214695, 0.12555792672379365, 0.23213371153800721, 0.10761022567749025, 0.18983755290748613, 0.21326642153003525, 0.3265830369726304, 0.09081275968421852, 0.17004112082142986, 0.18848906962140916, 0.17481113663844525, 0.1429535235248266, 0.21136283093402464, 0.13399760328954266], [0.06209685016543635, 0.07686461216860241, 0.11518849765941983, 0.02929463531942137, 0.020952213615659746, 0.050166455668307124, 0.03186584472836506, 0.013750129108948093, 0.018538714897248055, 0.015275924402709692, 0.15950345884888403, 0.01471885207725028, 0.050172308580048626, 0.04807508926117613, 0.11789143971738317, 0.026919146053372856, 0.03278611933872585, 0.0794418698417083, 0.05539527388229486, 0.08795797899966279, 0.01087530660668328, 0.02197534510595424, 0.020435295788751497, 0.026353039636066364, 0.09148779039781901, 0.11911678969139054, 0.11842220075308316, 5.421833453639861, 65.65662491706111, 40.610471387063306, 41.81434092983123, 48.97613386954031, 33.53087955905546, 48.16065742123512, 0.3399357043447033, 1.9168947853388327, 3.0711258755576227, 4.683336952040273, 4.057213414099909, 0.16876454254792583, 0.40971948074236997, 19.530216532368815, 66.94243277272871, 71.60046700508364, 71.67445859601422, 70.19337946368803, 66.70913019487935, 69.04064978322675, 69.34739482018256, 69.61628898497551, 68.58452520062848, 70.09262161870157, 66.62636818424349, 65.91601910129671, 65.35417879781416, 63.4308720404102, 59.86721046509282, 61.02491371093258, 52.311415441574596, 49.956946065348966, 48.951156216283, 47.91244591436079, 49.229381699715894, 54.438603078165364, 62.297063873660186, 65.41989026531097, 63.30314005574873, 52.76327640779557, 46.43809364688012, 49.23872870783652, 46.27315798113423, 46.958713762221805, 43.557657964767955, 45.804273928365404, 46.21491862881569, 54.88051299125918, 62.72717529727567, 64.07729433428857, 59.75361862490254, 59.913655250303215, 46.15997406744188, 54.372299332772535, 73.32845933975713, 63.633874308678415, 63.27740146267799, 59.57669619591006, 60.7719914374813, 62.03705387730753, 62.4516954729634, 60.55833601182508, 45.6630725245322, 56.168246730681396, 66.85701139511602, 57.78809931970412, 56.78057186065182, 55.16313937402541, 58.471611545931914, 54.26874483785322, 56.81841488807433, 52.9806580851155, 59.374301895018554, 57.131737739809104, 59.91218436148859, 57.56850150323684, 59.88007191688784, 47.62016657860049, 43.07266866007159, 43.712246417999275, 42.823515784355905, 43.36061377679148, 43.74534337751327, 42.70284798837478, 44.95021312467514, 43.9896442813258, 47.02167564822782, 48.30185882506832, 51.346704575323294, 52.534304126616455, 56.97428203398182, 59.01344776153565, 60.884759579935384, 58.758964384755785, 59.206487209566184, 52.81282771018244, 45.48715029993365, 41.74644470214844, 43.312988358159224, 42.66289864816974, 48.06293549076204, 59.26944125083185, 59.04704678443171, 59.90883073499126, 63.245096821938795, 59.12287796697309, 58.47375708241617, 57.484731443466686, 60.44589342609529, 61.22091847081339, 65.69794316445628, 62.46884407535676, 60.07357812696888, 52.17456786863266, 1.2043572649840386, 0.0967127322069099, 0.24589159345674902, 0.8743067914920469, 1.521889310209982, 0.7229683283836611, 0.34582287553818, 12.544498789695002, 34.06591830715057, 39.423671999285304, 22.930217212246312, 54.105036873971265, 17.27860935272709, 0.11360239688186877, 0.08950346179546849, 0.05040055681620875, 0.029424858775230187, 0.008940295872068214, 0.031804121024305784, 0.17113564596060785, 0.07115122035986955, 0.0751007636708598, 0.034887295501727256, 0.023994385152153914, 0.0354091890697037, 0.03263933689243371, 0.05076301216538395, 0.07423237236517091, 0.041555366929500334, 0.02296944760957793, 0.029321302840065573, 0.05117027599725032, 0.1078968421526013, 0.04564811888661596, 0.0523276356679778, 0.06428416142420423, 0.021992440357984557, 0.01956052105543354, 0.06175650411375588, 0.030820169185678807, 0.03295451312536194, 0.06374478189935608, 0.06514039491453479, 0.09328843409856481, 0.05397843640117396, 0.04279131956037976, 0.06580511408467447, 0.03340967660469394, 0.0931772364363555, 0.039674375927256006, 0.02528562251808903, 0.03369268480568163, 0.008188594121395821, 0.10669741659395157, 0.0146162326845731, 0.1405212709740285, 0.05323433520032033, 0.018807272764764005, 0.07518795979840141, 0.1943422877980817, 0.25652887750296827, 9.391192640027693, 78.8076731466478, 37.338567472273304, 55.195491083206676, 55.24880786095896, 44.63405832167595, 48.453336838752996, 0.38711332926346415, 2.5619752608960678, 2.026427462697029, 4.75046145339166, 4.1194163214775825, 1.347243449380321, 0.687085505454771, 22.998368393990305, 71.8636501989057, 71.76346501996441, 73.58339771147698, 72.17227797354423, 69.68995894155195, 71.11028840464931, 71.80909002980879, 72.77129450151998, 72.19822052986392, 71.80800745564123, 67.56809003891485, 70.50649442980367, 69.15425731289771, 66.44647259866038, 61.96434882379348, 61.54385112947034, 53.99758354310067, 52.26902638712237, 52.10352590007167, 51.77497640732796, 51.470894659719164, 55.40032509834536, 60.32765357725082, 64.60763800528743, 63.34551342072026, 53.980329036712654, 48.9017931876644, 51.745731215323175, 50.31368563252111, 50.543544369359175, 47.03505877525576, 48.476298393741736, 48.60355184924219, 58.15153045039023, 63.12068316244311, 63.766105251927534, 59.866716246451105, 62.05721485999323, 47.52999128833894, 63.33693127478323, 69.1409840122346, 59.9258420544286, 63.7634184283595, 63.42092883202338, 64.6726316790427, 62.92953429683563, 63.36535276905183, 63.006106807339584, 47.481616697003766, 55.13274492756013, 68.61683768610801, 59.73941572250859, 59.775360322767696, 56.24157151868267, 59.16281161769744, 56.79802248554846, 57.81227680944628, 55.486856506716826, 61.29708697718959, 59.80960653674219, 61.709645794283965, 62.24943845502792, 59.77326577709567, 50.09301308662661, 47.03914196260514, 44.80781932030955, 44.86431321790142, 44.75044288942891, 45.0923127512778, 44.485828030493956, 46.27671164851035, 46.63008189970448, 49.65972454317155, 50.54987899718746, 52.92988692560504, 55.23852340636715, 57.340239171058904, 60.81193293294599, 62.31236896207256, 62.65525471779608, 61.56314526834796, 56.57845997041272, 46.564911719291445, 43.75982476818947, 45.47373187157416, 45.18819901251024, 50.75470908995598, 60.908536987919966, 60.47331079359978, 62.46801253288024, 64.64453181912823, 62.61520339596657, 60.82663005398166, 60.28857500322404, 61.66347165261546, 63.67225077844436, 67.39850244214459, 66.31501043996504, 58.430179549801736, 58.14521935678298, 1.0981536993095953, 0.0736845888557934, 2.7498950352591853, 2.675228306362706, 1.6160377163079478, 0.5027948121630377, 0.510280471775801, 19.180486240694602, 38.874387202724336, 46.43174332957114, 22.61496259320167, 59.42290006145355, 23.757396051960608, 0.08695068063154336, 0.05982120896899893, 0.038017247307805285, 0.10363174722559991, 0.014409402351556046, 0.03788317426017696, 0.04191675741646079, 0.043862011704233386, 0.032761202328988624, 0.02815165128859301, 0.016621028283430685, 0.021225720411166552, 0.0823764845488533, 0.05222701001912356, 0.09650394260402649, 0.045308328248680606, 0.05304493528280047, 0.03260544899310316, 0.030148392430536693, 0.0738132150182801, 0.04294896130299857, 0.20761457722513907, 0.15172941309790458, 0.16270521607610489, 0.07302092688698923, 0.12580481387915152, 0.129278440388941, 0.07558209671368522, 0.2321467963197539, 0.16995781642054358, 0.14338490763498893, 0.24210394750679695, 0.20536664542892288, 0.14136510150086495, 0.14104411066059144, 0.21124957249529902, 0.18093720469022953, 0.1547142142249692, 0.16376485357121115, 0.10448837142077186, 0.29991674206910596, 0.14056863052950752, 0.2491436673388366, 0.14725101631014578, 0.1614562782549089, 0.23020954382035042, 0.3268899930821311, 0.28988344174238945, 8.752837681001234, 89.2486930662586, 52.89072205943447, 60.68230252112112, 63.5466133394549, 47.96220510236679, 56.13743259060768, 0.3123444348814026, 5.294312786671424, 7.413682649212499, 14.008476388069893, 8.579985691655068, 1.8795381318176947, 0.5127561308683888, 24.599071971831787, 75.86452268785047, 76.4095046443324, 76.61186756626253, 75.42234605358493, 73.25924519569644, 75.97824004388626, 75.88628399756648, 72.93219797072872, 73.99965532364385, 77.4964875559653, 71.47290368233958, 70.31138004795199, 72.50907621076031, 68.61384099529636, 64.91608535089802, 67.5427201486403, 56.869986211099935, 55.201786487333244, 54.57105759651431, 53.1704576553837, 54.74450480553412, 58.8140070053839, 65.08260957656368, 69.4237555226972, 67.49836598673176, 57.20817296735702, 51.57191530350716, 55.89469279012373, 52.98722413278396, 53.462419279160045, 48.83948633747716, 50.34744155022406, 50.48384589533652, 60.00112802751603, 66.32669910307854, 66.87410508432697, 63.3357035729193, 60.750512538417695, 53.1586552435352, 63.79708413154849, 66.81262585424608, 62.063643624705655, 65.0933764826867, 63.401693528698345, 66.14086504905455, 63.712102059395086, 65.48192647195631, 60.93013748045891, 46.19498514359998, 53.63595670269382, 70.95564503823557, 62.13571325425179, 61.16575817908011, 58.99290630894323, 65.0269982122606, 60.34899127098822, 61.68184795687276, 56.8101582988616, 64.55532143192907, 61.37190618822652, 64.13807538247877, 64.8717821798017, 62.765304657720755, 53.136340879624896, 48.478545911850475, 47.194938505849535, 47.847326724759995, 47.02770433118267, 47.41234371739049, 46.14147616970924, 48.68948313497728, 48.198700489536414, 52.30713221334642, 54.043530187299176, 55.94906860782255, 58.01088210075133, 61.85941365457351, 64.80528231590026, 65.27647272233041, 63.23096452220794, 64.82374491230135, 59.309512184512236, 50.516503549391224, 47.185811150458555, 46.153490389547045, 47.61846819231587, 53.30912913045576, 65.05314473182925, 63.54094551455591, 65.55927561175439, 65.84818563153668, 65.20614462514078, 64.59976973072176, 62.32066085261684, 65.71850030652939, 65.44848434386715, 72.35840228296095, 67.32623669408983, 60.747551148937596, 57.60608565422797, 1.972986639988038, 0.16555900084635905, 2.1410027146339417, 4.643148837550994, 7.383214658306492, 2.2669608073849834, 0.6681516117626621, 23.33883404731751, 48.65744913777998, 52.7486224328318, 33.4244970352419, 72.15330154665055, 28.863767000936694, 0.13533978933288207, 0.14910349351984842, 0.17399016617526933, 0.22063237224375049, 0.10434270746284917, 0.09484267327934505, 0.23744239441810117, 0.20776768755768577, 0.24961053664165161, 0.1150936023482392, 0.1702502628247584, 0.15679602751568442, 0.12808558020380237, 0.1256403348018085, 0.1876770623869473, 0.1080508641297779, 0.08553919427457356, 0.14715174663691752, 0.08502477389429847, 0.20396954620317106, 0.10748432678801399], [0.03467437285449236, 0.021202383457773158, 0.03317507366920191, 0.010644287047457072, 0.031062132310903365, 0.06783124044417374, 0.01404284172871661, 0.02658336397050129, 0.04737953122164454, 0.046004296145251686, 0.019496815098870187, 0.019016297939684124, 0.028666799452396172, 0.020201311469258323, 0.05296089160706728, 0.05562065694961817, 0.005354416413953709, 0.021562488832240625, 0.052409476840928684, 0.061587267630403085, 0.040684665868719744, 0.01940194085510748, 0.024136013741935455, 0.05153122981409392, 0.06658496094807502, 0.009476002005319442, 0.05955058840974685, 0.15056808509172934, 19.577751736487112, 65.4010981898154, 26.805875878180228, 54.360477309073175, 28.5067371783718, 49.575566168754335, 5.442312148309523, 2.777247928803967, 1.2438453589716267, 3.0452664244559506, 1.7198396882703229, 1.6052399215198334, 0.34968138462112797, 1.9666449028638102, 53.24593974697975, 68.1751552704842, 76.56997665282219, 68.30992790960497, 74.02825724694037, 67.99281212591356, 70.10623224319951, 71.58041584876277, 72.4730453183574, 67.60097519043954, 70.3702626689788, 65.74541168828165, 67.63238553077944, 66.04940322137648, 63.36114798822711, 61.413377408058416, 54.508668376553445, 47.51560795691706, 51.158109172698, 50.28763717220676, 50.8088574101848, 60.62718537545974, 65.91709383072393, 65.54879896102413, 66.4994873539094, 60.80124055185626, 51.5645843936551, 49.99175710062827, 46.933100684996575, 45.44314130660027, 44.86946328993767, 45.306348646840746, 46.04206369769189, 49.40307209568639, 59.92379457719865, 64.56373883831886, 62.091668959586855, 60.54271713379891, 58.95795014596755, 46.97091625582787, 50.60668276202295, 64.5203927255446, 60.278882826528246, 64.37025616245886, 59.99527977358911, 61.06496111039193, 56.44691936431393, 55.011382872058505, 39.60023749259211, 57.73418241931547, 66.43947509027296, 60.888929059428555, 60.87287872068344, 56.49696096297234, 59.05413058496291, 58.87583924878029, 58.382342323180175, 58.26173336275163, 61.59227671161775, 61.287794882251376, 62.43455079294021, 59.51092981523084, 60.85249416289791, 54.82245799033873, 44.67179152273363, 43.58840934691891, 44.2664106430546, 47.323639315943566, 43.8569151970648, 43.77683216525663, 44.46901282956524, 47.22184596523162, 47.84467520252351, 48.77792473762266, 51.9786140995641, 53.937469297839755, 54.85591580790859, 58.94046029736919, 59.754238359389774, 60.71454440393756, 57.931665912751235, 55.26070048732143, 50.849728507380334, 43.935597942721465, 41.25614450823876, 43.07033484981906, 46.14015825333134, 52.442046057793405, 60.30579813065068, 62.35679764901439, 61.96633746547084, 60.56993838279479, 63.6508503267842, 58.14505069486557, 63.079364915047925, 61.09524180812221, 61.066851692814986, 56.78179564014558, 62.85828836502568, 6.1172324226748565, 0.3125315441960289, 0.5794815310547429, 0.8822880180612688, 1.1719861891000503, 0.5466443672776222, 0.27499865980878957, 0.3728394871277194, 23.09934000815115, 45.93517911049628, 28.002781252707205, 37.21966082049955, 47.854453671363096, 2.9693303185124553, 0.17916366518024476, 0.11933092658798541, 0.09375065324767944, 0.01709273351626771, 0.03683496296646134, 0.05872498311462903, 0.01346115404064016, 0.05661250332430486, 0.02899939460950273, 0.016798764512303378, 0.09094084192427898, 0.027090431821923104, 0.04089882191751273, 0.022177611470162388, 0.04850774124685315, 0.022416274671653108, 0.02432230717292236, 0.048891853901647755, 0.10186473478473003, 0.035886917668845386, 0.04609492817713369, 0.02468604763459054, 0.026944271822069443, 0.07742820007185783, 0.044185174403772245, 0.03573363113607611, 0.0401419959962368, 0.033285953404922644, 0.04169628880317173, 0.037552132346336885, 0.05272607416695645, 0.006236558040273526, 0.06253444341822498, 0.018324597152851282, 0.015800324035808444, 0.09181831903274983, 0.03926942951136059, 0.020250676259879145, 0.010534245220403518, 0.05209066935123936, 0.10067847827749868, 0.02258625809073208, 0.003215817813461106, 0.006058893153338784, 0.08546984799566769, 0.11680978485533308, 0.059845965100272056, 0.08616344868055276, 0.1604332137973078, 34.091488238303896, 69.80624152768043, 31.131047971786995, 67.45812246876379, 32.133862703077256, 62.32569325354792, 3.124816994513235, 1.3413818348799984, 2.221515245975987, 2.313733355652902, 4.431662482600059, 3.3499465786641647, 0.38060513655504874, 2.5011422413010753, 60.053695632565415, 72.21383156314974, 78.5232150170111, 70.93918677299254, 78.03886505865282, 69.95380109356296, 74.20132790842365, 72.81528780537268, 76.13664104092506, 68.48284167628135, 71.02946404487857, 67.69370786605343, 69.22620142659834, 67.31504224961805, 66.60028442259758, 62.90594516261932, 55.743920803070075, 50.73727807691021, 54.73031367025068, 50.14065811710973, 52.35799358737085, 60.95505629816363, 68.70715418169576, 70.83200408566383, 70.48857704285653, 63.95603426041142, 53.51069581124091, 50.163839324828125, 49.410834466257405, 47.39220234655565, 47.07822838137227, 47.33066820329236, 46.90363976263231, 50.972365333187966, 63.24228056015507, 66.77223328621157, 64.86524358872445, 62.774808560648275, 58.596656707025346, 49.375337016197946, 60.71106918396489, 66.27257823944092, 61.13692091357324, 62.294373127721975, 59.950580443105395, 62.1321282079143, 55.981130061611054, 57.88819428413146, 43.36972936507195, 58.06901162670505, 67.90772807213568, 63.66153486313359, 62.321488472723196, 58.16760824572656, 60.17476351030412, 58.780643324698175, 60.75542334587344, 59.53036123706449, 64.62843048957087, 61.243048483325595, 61.91037701022241, 60.78482543268512, 65.10566134606638, 56.795943629357126, 46.86163117808681, 45.71804846486738, 44.310792261554354, 48.027622392100675, 46.51516037602579, 44.57829790730631, 45.85617473048549, 47.24656081968739, 49.86619026430192, 51.677411371661776, 54.23349841948479, 57.40877082270961, 59.559021995913604, 60.87849947714037, 61.45677843401509, 61.5210739258797, 62.36280672011837, 57.34857813004525, 54.087723532030665, 45.464930072907485, 44.19522354679723, 45.124503643282004, 49.49078413747972, 54.87549235743862, 62.44332905738585, 64.30798853597334, 65.4049381902141, 64.20921148792391, 66.30896214515933, 59.55740990177278, 67.12109673407771, 62.40754919667398, 65.36895828862345, 57.28817362939158, 67.206235701038, 6.6997097865227735, 0.2347047945424434, 2.4764256708083616, 4.260669696715571, 4.0557655692100525, 0.6909614813423927, 0.3438793411177974, 0.9099680005062012, 25.275300356649584, 53.51649699672576, 37.149458239155436, 35.35924142406833, 61.11498701956965, 4.008402459083065, 0.1645090313808572, 0.05323269577216237, 0.039318612356099396, 0.03859081733671408, 0.02893968954712393, 0.04370067741781954, 0.05081148254835317, 0.041539482096390384, 0.06213440379548458, 0.1128112348998266, 0.013336144770765978, 0.03355544015404678, 0.05999065612653091, 0.06438526204757153, 0.06565037198484906, 0.039350577374739994, 0.03535443293531576, 0.03240276511097628, 0.019674055285811908, 0.03916471295299069, 0.06398434525415783, 0.08663017242666214, 0.1365698201041068, 0.18237106081458831, 0.10329168845689106, 0.09946727028657353, 0.3177037102080161, 0.18623407449453108, 0.09200808667247334, 0.11660407492590528, 0.1558905115891849, 0.0716267770997459, 0.13647220518079498, 0.15236508221395556, 0.13879417171401365, 0.2036023909045804, 0.1675347416030784, 0.1323851720700341, 0.17012722910411898, 0.19328281884231877, 0.15711252908072165, 0.1626267380291416, 0.134150039464716, 0.1096924220121676, 0.1121490897851125, 0.19887383576602707, 0.12874297557338593, 0.15703374459858865, 0.3203901660538489, 38.686301708221436, 84.11613049045687, 40.11958675999796, 71.33240438276722, 40.256277438133, 62.98298835754395, 6.298826394542572, 5.5623410882488376, 7.5930982347457645, 6.338572752091193, 10.449345150301534, 4.225134493843202, 0.8372236620033942, 2.386386437762168, 60.281491202692834, 75.95796923483573, 80.79564802108273, 72.82099877634357, 80.90469775661346, 74.96875532211797, 75.94534704762121, 74.87408499563895, 78.5825369434972, 68.57509582273423, 74.66282613815801, 71.86151642953196, 72.24223736793765, 71.32007245094546, 70.0401952189784, 66.07373760592553, 59.536040829074004, 52.356024557544345, 57.93482734311012, 53.5119156683645, 57.51502783067765, 66.70206208382884, 71.27007007598877, 71.25819313910701, 72.91529255528604, 66.97050909842214, 57.61957076288039, 53.92212498572565, 49.998609481319306, 50.509404059379335, 48.53275699000205, 49.37673337997929, 51.66788393451322, 52.76283710233627, 63.205445581866854, 70.83275718073692, 67.20201523073258, 64.61309794456729, 59.806562777488466, 55.0819423890883, 61.98552177798364, 64.05133216611802, 61.40501883722121, 64.1458926662322, 60.7955531151064, 63.631450283911924, 56.21841384518532, 57.80957037402738, 41.397781295161096, 55.53440347794564, 70.45161262635263, 66.02284093056956, 66.02498254468365, 62.37871585353729, 65.08180549067836, 62.04161167144776, 64.10222491910382, 62.049683909262384, 67.16989886376166, 64.36273697883853, 66.10364960085961, 64.18240993253647, 65.15523226030412, 58.88394286555629, 50.376459244758856, 48.56361427614766, 48.40830802917481, 51.873235702514656, 49.20972278041225, 47.74992642864105, 49.656076738911295, 51.214559924217966, 53.027679458741225, 52.876570147852746, 57.793002282419515, 60.52324256589336, 61.695795905205514, 63.558298080198234, 62.741252683824115, 63.82722362395256, 63.38424682617188, 59.438875875165394, 56.99843991187311, 48.33837609137259, 46.579369575746604, 47.23369936789236, 51.13108404221074, 57.19886518293812, 63.60859855528801, 67.15903389838435, 66.49216821116786, 66.56503800422915, 66.93531759323614, 63.032492591488754, 68.52652903526061, 67.487422573951, 68.53613884218278, 61.12599711264334, 67.35061814708095, 7.712084314515514, 0.3173622494984058, 1.1798190397600974, 4.868713559642916, 7.528378146310007, 4.15950539612001, 1.2291435801213788, 1.484800971323444, 36.86540411364648, 58.97209421280892, 42.61047224844656, 47.87181015937559, 69.21010401941115, 4.812615821438452, 0.34242542881158095, 0.2607424376953033, 0.13424386991368187, 0.16752492035588912, 0.14469871778161297, 0.1760204830357144, 0.10721431909910134, 0.12840423447590682, 0.20248609354659436, 0.191462425394885, 0.16749847500074297, 0.11783130947620639, 0.14288615375276537, 0.11149464385403741, 0.26589762719888843, 0.1269698344291218, 0.11497865085520091, 0.16097753458926756, 0.15417354001152903, 0.19905536796056456, 0.2831821029465045], [0.08703050699325339, 0.006533708224343437, 0.04207099389825617, 0.08393491423057933, 0.018613389317667293, 0.06450968238735391, 0.03778914079791115, 0.052933254985198866, 0.03144261562415669, 0.15788076205119012, 0.06773644472442328, 0.05566030583013931, 0.07485609050960311, 0.02318527947570528, 0.0048059027270233685, 0.045805170741533084, 0.035143712790863174, 0.06880259396688593, 0.028323613129736438, 0.0163451983262935, 0.05813246773135278, 0.04667654212924742, 0.06103891338552199, 0.05525842759638064, 0.09013196798942744, 0.166249000918, 0.0879867226185818, 0.08682848960762063, 1.0365428246798054, 46.705787566400346, 38.569418999456595, 43.29773426055909, 52.28573960642661, 29.36248460123616, 28.602931345662764, 0.9832551582686364, 0.5176082253456116, 1.7434398541527412, 1.617473916661355, 2.1012507186781977, 0.2220233121225911, 0.31465749947294114, 11.941074498238104, 64.04833939767653, 67.80722910358061, 75.7356414487285, 70.44854533287787, 75.93808281806209, 75.10315925844255, 70.3650459166496, 65.71258537230953, 68.96104920294978, 66.53292948199858, 70.15792908207064, 69.51084783000331, 67.03384753196471, 65.45324610125634, 63.27902532392933, 57.13507959919592, 49.01856607006442, 51.955319143110714, 49.12696076977638, 59.47569908634309, 68.14794186622866, 68.09166369899627, 69.48257538580125, 63.25702474963281, 59.299921989440925, 56.997420095628314, 53.82236734513314, 50.88583784718668, 46.19058032189646, 47.43917272936913, 45.864921615969756, 47.24010852075393, 46.20921158021497, 52.41519351159373, 64.71780561631726, 64.57237197506812, 63.91960720862112, 62.78111180951519, 65.45439143334666, 58.187824141594675, 53.61563098046088, 55.543032692324736, 58.45940512995566, 59.54912193359868, 59.676881374851355, 56.21140849205756, 57.15363633248114, 34.45133040028234, 62.644268158943426, 65.22731757933094, 60.98581552505494, 60.356612436233036, 60.047615958798325, 58.70674194828157, 59.50426570830807, 57.93301520809051, 59.05112997178109, 62.29379261693647, 62.45757118348153, 61.502603484738266, 59.95680916693903, 59.046191707734145, 55.47304976371027, 43.364116453355365, 44.98068994091403, 43.29483170663157, 44.724814122723, 43.673438487514375, 43.873467599191976, 44.54902525871031, 50.67026046014602, 51.06240726286366, 51.77125015566426, 51.85408276896323, 53.36943949422529, 56.71908086346042, 58.777454437748084, 60.40413979561099, 60.90624240136916, 59.80187946750272, 60.44162588734781, 55.94446374524025, 51.03142053850236, 43.91307569319203, 42.76990482884069, 43.181483053391986, 52.160502249194735, 55.20044111436414, 61.395424719779726, 61.71454483462919, 60.57184073232836, 60.636481392768125, 65.61191381946688, 64.21627959897442, 64.26853733678018, 57.154181541935095, 63.38359571272328, 25.553767065848074, 0.12793740347748803, 0.1508089584568816, 1.6584389055928879, 4.127024248723061, 3.7143987513357595, 0.2813769852922809, 0.18949702682514347, 5.080439669470634, 42.65321431621429, 40.431462257139145, 25.65735293972877, 52.14651115479008, 19.085504085786884, 0.05780146029146929, 0.04959279370884742, 0.09561821472861114, 0.024837279136502938, 0.0730948007455276, 0.062519914560741, 0.0693936997483815, 0.04693337310586245, 0.01902369451859305, 0.025837925946219795, 0.033453784116934386, 0.014478387611527598, 0.034892244429718104, 0.061070625595147573, 0.07192161369828448, 0.0615602094049175, 0.05529233847834891, 0.10012350120251218, 0.05092818072185882, 0.03190183553904776, 0.06789270367833876, 0.024036188654962088, 0.04706822756317355, 0.03445798748983972, 0.027372497734763933, 0.020742581316059636, 0.027261819097123323, 0.05421817595619829, 0.04712193415710523, 0.039617283224699, 0.04291857825592161, 0.040230831551936366, 0.04453040809640962, 0.004136723967554469, 0.02290424395112261, 0.08056794248160817, 0.034240537262972326, 0.03360425144614231, 0.07446757667968351, 0.05261813237842533, 0.027733710106281985, 0.053904796199452494, 0.06823458573630742, 0.06383482021309676, 0.03301477743192546, 0.02093652221975067, 0.058051951890510906, 0.05774915563843905, 0.08439002408375663, 0.05466317727921471, 3.9958148377556957, 66.34526760347428, 34.74514730515019, 51.045945075250444, 52.33079979496618, 40.12096351192844, 31.26761313407652, 1.5290255724422395, 1.6557575978579062, 2.594498818920505, 4.1937270952809245, 4.459850595843408, 1.2755698566475224, 0.8587385978429549, 16.381339719218595, 70.46592927748158, 71.20568829198038, 78.68187489048128, 72.94181562239125, 79.15685038412772, 77.261364998356, 72.26017828910582, 68.85725544344994, 69.66244743716332, 70.43582900877922, 72.17791049711167, 70.26494702985211, 68.69578715293639, 66.21819065463158, 65.50314649458855, 58.36144393490207, 52.610150998638524, 53.67921652332429, 51.29442330329649, 64.31768855740948, 71.03679103236045, 69.046596096408, 69.65690120573967, 66.14923538700228, 63.98019998304306, 59.90005639291579, 56.18486189073133, 52.98299189536802, 49.59180085889755, 48.96802240802396, 49.63314656288394, 50.07353067398072, 49.18922055152155, 56.287663290577555, 65.11269023341518, 65.44099261683803, 63.13888296004265, 64.91790533065796, 63.46253341244113, 55.38344321712371, 56.59243145296651, 60.85213330484206, 63.00619309948337, 61.5691190381204, 59.41872273722003, 58.35705088030908, 56.49044590611612, 37.00371865303286, 63.87076977760562, 66.99005034662062, 63.87158170823128, 62.56731125616259, 58.99369470534786, 62.08576187010735, 61.93284826893961, 60.685295289562596, 62.16551542282105, 63.97003712192659, 64.75023577290197, 63.908977585454146, 62.842073286733324, 60.829669890865205, 59.01040792465211, 45.31420123192572, 46.70585816906345, 44.61426996415661, 45.51866262189804, 44.35795876287645, 45.8493733406067, 47.144892984820956, 51.85994671237085, 53.12369123581917, 53.11853331904258, 52.92979671109108, 56.260277302034446, 58.501778494927194, 60.54039116828673, 62.83056505264775, 62.529778095983694, 59.919503504230136, 60.822499798190215, 59.22580096029467, 50.560928313962876, 45.38996181180401, 45.51015107862411, 44.93116609511837, 53.66329562279486, 60.311630695096916, 64.40201167137393, 64.1570714212233, 63.22351201888054, 62.28612438324959, 67.27493993697628, 66.84576988220215, 66.73276639753773, 61.01651591639365, 66.55442407054286, 29.26344083201501, 0.12514587867284013, 0.4156340472400189, 7.2471711712498825, 4.5446414524509064, 1.4413237042965428, 0.2990041168466691, 0.19384341134179026, 7.991186937978191, 49.993781043637185, 49.89203083899714, 24.777410376456476, 56.177970286338564, 26.287805303450554, 0.13748265983116242, 0.1340952182128545, 0.03873458522702417, 0.06223443189575788, 0.04448067749880495, 0.015906402315463752, 0.04505711269655055, 0.06474808128851076, 0.05588971851994434, 0.018709736365464427, 0.02665591632737027, 0.04064652618140944, 0.03027323794911706, 0.010846950819775944, 0.008085610836954608, 0.012188715514756981, 0.04872705306737654, 0.030589525009535497, 0.01331539144889722, 0.01457283380366261, 0.06202757666488329, 0.0355151045556751, 0.18741122987722197, 0.12248931557781274, 0.06176131897635999, 0.13770913074333824, 0.10810452858887373, 0.18178344073314823, 0.21883051812408433, 0.13865391633683635, 0.12135769646134108, 0.19726909606927828, 0.16319895974330365, 0.1339011068546003, 0.12918860891893988, 0.17596376188580068, 0.1075048196399885, 0.09213286707358015, 0.10235410408988115, 0.09628581438934612, 0.10437938775266371, 0.06547964163004391, 0.19542090895195163, 0.19777888161761148, 0.12192892226120158, 0.18034207694713147, 0.27260595271664284, 0.2775601820359307, 0.19942112897913303, 0.19378650633077468, 6.228676274899514, 78.05641374280377, 50.6122995961097, 61.63022564303491, 63.776554446066584, 45.48116084068052, 35.6737135302636, 1.9567830836580646, 3.3081610789222107, 6.555856370156811, 9.815583286746856, 9.484668604789242, 1.345297218330445, 0.4807936556396946, 14.425188014584204, 72.08223604386853, 73.8043918917256, 80.27661646566084, 75.71477443941178, 81.41620620604485, 77.48141780976327, 72.3537503519366, 70.67872570407006, 72.22168414823471, 73.13520416136711, 76.54775250342585, 73.9433850011518, 72.90731445435556, 69.18311026788527, 70.26891646846649, 60.47435806643579, 56.019616357741825, 56.265933359822924, 54.0656445103307, 67.0976488051876, 73.90810720382198, 71.71009725139987, 73.87734797693068, 66.31017023517241, 64.38390993302869, 61.80711669306602, 60.17619125304684, 57.73876374767673, 53.23757725377237, 52.63531300329393, 52.6248755762654, 52.38914505127938, 51.28155008439095, 58.36967698989376, 68.15111114132789, 68.5657605817241, 68.64358825068321, 68.04552878102949, 66.09721691377702, 63.157863309306485, 65.21804901861375, 65.80423547375587, 64.79135790178853, 63.34726279781711, 63.512049413496456, 59.78739415445636, 59.9988373633354, 32.31094398806172, 60.631060677189986, 72.13716491576164, 64.36439614142141, 65.1268696015881, 61.173536239131806, 64.45209641610423, 63.348247312730365, 61.10828761131533, 65.14590094166418, 65.89129247973042, 65.47432884093254, 64.38845988242858, 64.04953572057909, 62.47054638401155, 61.4777474249563, 47.43785873536141, 48.45967538895146, 48.69402131726665, 48.70839288157802, 47.24012813260479, 48.21386437262259, 49.7783213277017, 55.98698223790815, 57.938404544707275, 57.10858398868192, 56.8169165426685, 59.463476980886156, 61.777691072033306, 63.30271643977012, 66.72077178955078, 64.1047195465334, 63.079635558589814, 65.01339151013282, 62.0568932256391, 54.809106242272165, 48.164183632020034, 47.87419496044036, 47.1110664644549, 57.4625700519931, 60.8363300754178, 67.76347898667859, 66.84573065850043, 63.741802246339866, 64.43660697629376, 69.02745492996709, 67.7503861150434, 68.68260014441707, 63.58564092266945, 67.02451229095459, 29.84026655074089, 0.16399638066368719, 0.3147759673095519, 5.459072926352102, 13.66595737395748, 9.240384371049943, 2.057034084873815, 0.36634958859893585, 9.618352786187204, 59.80045172476, 52.12054506424935, 37.75767664755545, 66.83770548912787, 31.942429465632287, 0.2184026580183737, 0.2171871675959518, 0.17706916547350346, 0.09824302347917711, 0.1428390393454221, 0.17371619781178815, 0.15034498496642038, 0.08434005216845582, 0.1235605669658511, 0.1034320817298947, 0.13317185243771923, 0.13131724550358712, 0.18284906903582235, 0.15250478600782735, 0.1539917933123727, 0.16887194807490996, 0.17806219928447278, 0.10943915334440048, 0.21575390902017394, 0.14971544455376365, 0.1419572568228168, 0.10274536051456967], [0.027013037789372668, 0.022845320298426577, 0.06621582914263972, 0.015062866732478144, 0.032492508480866114, 0.05000521331244419, 0.08709022354695105, 0.05908378422440541, 0.04810409718042901, 0.09725398864717254, 0.03440484014009276, 0.02956706384617475, 0.06526617122994316, 0.10872723549724587, 0.03903907453340869, 0.11281400813811249, 0.00892534183578626, 0.06761441457896464, 0.05100838629709137, 0.12673880529379652, 0.007154447723165035, 0.06524193986889816, 0.06033135840909616, 0.058122926106255864, 0.15246677272502454, 0.1180430178740813, 0.09143731286448818, 0.1085526517201816, 0.11150084150534485, 17.792533982184626, 56.64390079436764, 31.6182553768158, 57.53795800670501, 45.699766297494214, 23.705677640053537, 1.0099751406138944, 3.4447767417277064, 0.6162585318088531, 2.9107305984343252, 1.4078291145063218, 0.42242097337880447, 0.08165654576113147, 0.12179422868235458, 30.51405522131151, 73.4289739977929, 65.9606792080787, 77.18655755442958, 68.34312685074346, 70.78583778873568, 66.3073225944273, 70.0852632522583, 65.98186785174956, 72.54056499850365, 70.37940179148029, 69.37212928648918, 68.43113699266988, 68.99921386472641, 66.94474697113037, 56.015925407409675, 51.65811331041398, 51.465171921637754, 56.188772493793124, 64.67606767531365, 64.5490691738744, 67.54818008792016, 69.97317760221421, 69.0110751121275, 62.33550702371905, 58.90043643213088, 56.49190502782022, 54.15685138394756, 48.07284732018748, 46.14038182843117, 46.21564818966774, 46.12613577996531, 46.47436380386353, 45.53684280764672, 53.55410468193793, 62.57971379064745, 64.73469141990908, 63.08666052356843, 62.28093508751162, 67.07467156071817, 65.94255785788259, 60.44897640905073, 62.584079388649236, 61.01720233117381, 62.99229614196285, 61.38439893722535, 62.622165603022424, 56.622618013812655, 61.957386616737615, 61.594371257289765, 61.229888931397475, 63.80577610385034, 61.71347402757215, 63.009927195887414, 63.89109157746839, 63.118800424760394, 62.720287615253085, 59.82492339226508, 60.99421724196404, 59.842609359372055, 61.410647438418486, 60.751830454795595, 51.155638079489435, 44.049146636839836, 44.65741603605209, 44.30318678579023, 44.85350708807669, 43.47290731245472, 44.165103666244015, 44.29357697886806, 49.09143586312571, 50.960684514814815, 53.84031218867148, 51.002355775525494, 55.36236832218786, 56.74266999767673, 57.0517998356973, 57.57083139111919, 59.46756801297588, 59.63727328085131, 60.13027991017988, 58.0677447011394, 52.010640252021055, 47.04641795927479, 46.078004375580825, 44.63822387879895, 57.460824597266416, 59.17005623540571, 63.61578041507352, 58.529819519289084, 63.24704231754426, 59.76549948415449, 64.01115140607281, 63.85384867268225, 65.89233583019626, 53.07552453010313, 55.3682557998165, 3.6983994034028824, 0.23891947322314788, 1.4911644040576875, 10.197454460205572, 4.493863919088918, 1.592568091807827, 0.3550288928372245, 0.07706231647922147, 20.39350667307454, 49.61298558019823, 25.475282399885117, 35.70076611734206, 48.69810450461603, 2.404700719541119, 0.06291863651225163, 0.041300569916324276, 0.07400112872522685, 0.0522987847967494, 0.08753496823051284, 0.03307331037978011, 0.008840981191174399, 0.07565911153271314, 0.06465974368996198, 0.066728993138719, 0.03014158765454927, 0.03501751512709645, 0.01603840884091633, 0.04257102331687366, 0.07378150663909412, 0.007383962398424986, 0.02337623838215105, 0.03904765088772101, 0.05387137178331614, 0.09060868152206944, 0.057429880835115917, 0.010357589175504063, 0.10004641743557108, 0.05868637994412453, 0.030889620801674265, 0.04598526269077294, 0.022954566351648782, 0.04256695922043535, 0.07202560247312631, 0.04147398540930402, 0.010458841101236401, 0.14368254811533038, 0.05467296405244739, 0.011199761121984453, 0.03778700341260241, 0.05030079684670895, 0.032901488349682866, 0.09391148574650289, 0.04297174858830629, 0.048964616932695916, 0.04106341207760476, 0.08690596407940311, 0.016820925520733, 0.03023082349118927, 0.0261104483187439, 0.13177947231358098, 0.0816533818180042, 0.13464764421505315, 0.03964306591379066, 0.11472796390373861, 0.10075004621138496, 25.869539437755463, 61.892667508894405, 36.15621212990054, 67.88683752859792, 44.8624736262906, 33.476597878240774, 0.689650367825262, 1.1392525391232584, 0.7303721698061113, 2.9072372374996065, 5.079109985982218, 2.8191356553185374, 0.5341557857971038, 0.06370811693130002, 39.13174567684051, 78.31310933636081, 66.96821058950117, 77.93314149302822, 69.88060966614755, 72.7905454943257, 67.75412021144744, 70.48484294645249, 68.69281399634578, 75.7139664311563, 71.61250868151265, 73.24849005668395, 70.2607265595467, 68.53500919957315, 68.18152519964403, 58.681819208206676, 53.19388989479312, 55.5768435232101, 57.01393327405376, 66.86522483825684, 67.77919984632923, 71.09856836257443, 72.46637728906447, 71.6187217158656, 64.81482152015933, 60.351250556207475, 59.09304834181263, 56.7964574598497, 49.40975581446002, 48.28153702520555, 47.3701782380381, 47.74735727617818, 48.01504335095806, 48.659037697699766, 55.78565089933334, 65.16277890051565, 68.71041759367913, 67.02488883849114, 67.48959556702646, 68.83247390870126, 64.3477496024101, 61.60803679497012, 62.61290488704559, 62.92642777965915, 63.97412030927597, 63.0528457703129, 63.52270649325464, 57.57484397580547, 63.933598303025775, 61.59342204370807, 62.97266860162059, 63.50007833973054, 63.25411042859478, 64.17478092255132, 66.43169310785109, 62.599270728326616, 65.67202806472778, 63.756405230491396, 61.94426628851122, 62.05967418609127, 61.82313173047958, 63.65731047045801, 53.99675592299431, 46.33149147033692, 47.44955132084508, 46.62024459531231, 46.44773875513385, 45.87526882848432, 46.08568437637822, 46.14647326930877, 50.54296385857367, 52.885164060900294, 55.17198824113416, 54.51612087988085, 55.77050270572786, 57.9969302300484, 59.631507396698005, 59.83305054326212, 61.237768973073656, 61.08475731265161, 63.6720036691235, 59.59065198898316, 54.58739819065217, 46.873053120028594, 49.964755504362046, 46.279018002171675, 58.70439637091852, 62.61899240555302, 66.71710829580984, 60.87580088646182, 65.20281845523466, 61.21023785683417, 65.01152838430097, 63.96560876600204, 69.52445845450126, 56.24860040603146, 56.73150300979615, 4.532714015053165, 0.6552213959155545, 3.2973752963927487, 7.575216149130176, 2.841380152010149, 1.2848784990849034, 0.40550973566789783, 0.05862462942698791, 24.916925161115586, 57.28847565189485, 35.05582255701865, 34.20903774999803, 60.364280669919914, 3.7652981233212257, 0.038799867409491734, 0.08196461269812239, 0.04116262812467833, 0.08128549873588548, 0.06691833943008416, 0.06267875140052169, 0.043016668153746475, 0.0033276597077342416, 0.0687041363468574, 0.04989353301484258, 0.020145561335788622, 0.0690249969521838, 0.030053010653524153, 0.06869358731614006, 0.022824425250291828, 0.024932331495708036, 0.05852600709805566, 0.009060179056119054, 0.004455111545300292, 0.034034448120022015, 0.11866108995051154, 0.08650300183123158, 0.10978725603631428, 0.15240404544578445, 0.26654644238372005, 0.1178681276618473, 0.1709288481863276, 0.18087556525584192, 0.17363917533188097, 0.13177878283444913, 0.1827782365463434, 0.2220562232598182, 0.14996587869621095, 0.08435032540752042, 0.14615984663607615, 0.3681005898021883, 0.16960877144048292, 0.2051118445853072, 0.09522019374755122, 0.12715119808431596, 0.21373359726801996, 0.16629591614248293, 0.13759913583917005, 0.28487656686094504, 0.10325917568538459, 0.23853403906668388, 0.21608397034147095, 0.30100480142620306, 0.19185700664116492, 0.19528097533170255, 0.1592485047876835, 34.170629901270715, 79.70368369933098, 43.68590770229217, 72.9768031643283, 57.55177259445191, 33.947066568559215, 1.7648465570903595, 7.4169406679368794, 3.0296666679843782, 8.082352136411975, 5.999457864992081, 4.202820129932896, 0.2988136061016591, 0.20491511320635197, 37.37084857879147, 81.17832229983422, 68.79007308713852, 79.42376767435383, 70.96521562145603, 75.3113272882277, 71.58503640082576, 72.36998111970964, 69.3771577650501, 79.77973061223184, 76.75930946103989, 75.68753750093522, 72.20130351281935, 72.2590486464962, 71.64303256619361, 64.23316540256624, 58.63554308491369, 59.21175887507778, 62.13094757449243, 70.61097852645382, 72.61449383151147, 73.68224928455969, 74.44834309239542, 75.76047005191927, 68.97941374009656, 63.18368819452102, 62.43728860732048, 59.30341289889429, 53.97926215202578, 50.846908323226444, 50.077213779572524, 51.735944901743245, 50.66016820169265, 50.15730857849122, 58.31157492053125, 67.18844382993638, 70.6270210204586, 69.493267766891, 68.47708363686839, 69.68280453835764, 67.87084994777557, 65.1735261947878, 68.22644418285739, 68.67412782484486, 68.45494577961584, 65.4174348615831, 67.31154349542433, 49.159049680156095, 63.00882108749882, 64.5763139570913, 63.82480352155624, 68.13943816769508, 64.49716444938414, 66.20096360483478, 69.5109341221471, 68.47550684405913, 67.385833186488, 64.69189836132911, 64.0811853254995, 65.12840324832548, 66.0829787100515, 65.0557021171816, 55.970786771466656, 48.80663648728402, 49.35205382685508, 48.70884787651801, 49.7338181157266, 48.42082431239467, 48.38544061107021, 47.97006160982194, 55.15648311184299, 54.50505587362475, 56.679186436437796, 57.06386896871752, 58.69750084415559, 61.63319095488518, 59.86804200756935, 61.63745849363266, 64.03047300154164, 65.0202399684537, 64.40753829094672, 62.975386804150006, 55.65771887379309, 51.3339804064843, 51.99386819716423, 50.85952658807078, 61.70241686605639, 64.06063995053692, 70.64722122684603, 62.43408010851953, 69.21373613419073, 62.206621862226925, 66.1862547166886, 65.83968193300309, 71.49340983360045, 55.99073986853323, 58.99565589043402, 5.056064100034776, 0.43857831928518515, 3.5240603454651374, 19.28993017442765, 13.420123804000117, 3.5941222117793177, 1.1313158682277127, 0.2018442344401152, 33.17899588615664, 62.63703530834567, 40.20118382669265, 48.23680631576046, 69.28401716293828, 5.362837083878056, 0.2296171586720213, 0.1886922667824453, 0.23599358425746042, 0.26477975169977835, 0.24368075563782648, 0.17725048316342218, 0.12027440217113304, 0.08850831358182816, 0.14087004016243643, 0.19466289559439307, 0.09917180549593703, 0.17938740881941012, 0.1324875827037519, 0.2699033477373662, 0.1879113167524338, 0.10687685736845579, 0.22580573335289958, 0.20918495021760466, 0.17283222427771938, 0.14104807899603922, 0.18862391641784101, 0.33501328299603156], [0.013301794345851147, 0.07017829635691258, 0.04350219169751771, 0.036679305391566414, 0.05754909560745282, 0.019505554246866418, 0.050762150316469135, 0.005325709663016061, 0.00480561496524681, 0.01716535482104988, 0.05242207898728309, 0.02979666231230142, 0.039930915790459806, 0.0905757244195669, 0.046848053893735336, 0.037644836646054065, 0.07483574321433421, 0.08271720215317704, 0.027822036213511904, 0.00044756915397761813, 0.05322279408574105, 0.025538969709868395, 0.07175811521348453, 0.007789581056473958, 0.049931086644890814, 0.0562435400582129, 0.0733515551133502, 0.0463819851528012, 0.0783725260126014, 1.3411699043166254, 50.32505266128048, 41.503018486884336, 39.373395058416556, 67.80961390464537, 30.672393460427564, 3.0004229468684045, 0.8158080724458542, 0.2393094426201236, 1.8737495714618315, 3.753893832045217, 0.8222642937494863, 0.44210443813954636, 0.15688870883276387, 0.9745550960783036, 41.79401520759829, 76.13671948832851, 64.71769578995244, 76.08013537622269, 69.64125879349248, 72.15956164944556, 72.6050958325786, 74.96879454581969, 69.420131252658, 72.02990378102949, 69.98618418170561, 69.94763512765208, 69.88892509091285, 68.24745239750033, 55.72381865593695, 50.91596949485041, 51.448215515382834, 61.96973816041024, 64.31825730108446, 70.86004118765555, 69.13067602342176, 67.00040540387555, 65.3067808766519, 63.51918812721007, 59.15393529399749, 59.04448939907936, 57.89580368226575, 53.50353748567643, 46.78311709434756, 48.85910603307909, 47.71128323770339, 47.70635674076696, 47.92650761142854, 43.95693563645886, 50.704279176650516, 56.51423115884104, 60.21951383160007, 63.56714694730697, 61.13006068814186, 61.885344443782685, 62.17830627195297, 60.45896276350945, 59.75396379347771, 62.8876708399865, 63.3526913581356, 67.05443997536936, 61.34446136413082, 60.245013160090295, 65.3995684654482, 63.137772929283884, 62.68757504801597, 65.64033923610565, 62.656678538168634, 61.94711392925632, 62.324540076717255, 61.486666894728145, 61.924548533654985, 62.49976019705496, 62.858970857435665, 62.5625063527015, 57.08099011451968, 44.645484185987904, 44.16172650552566, 42.25554481629403, 45.94749535283735, 44.007663649897424, 44.50042709227532, 43.38194362578854, 46.28263050510038, 49.3138381742662, 54.180091427218535, 52.73459211472542, 54.20343737448416, 54.19676542282105, 57.578864405232096, 56.414975581630586, 62.26156250123055, 61.11674816377702, 63.414692263449396, 60.26377777899466, 60.10362348248882, 55.001580868997884, 51.05379766033542, 42.864469251325055, 48.99080745635494, 56.99280738830567, 64.9075149720715, 60.798506659846154, 61.8988452419158, 56.78912654999764, 64.12581405332013, 59.494514696059696, 68.78274609965663, 53.04571059442336, 63.02298868856123, 33.82032694355134, 0.08937600774750595, 0.29964312610606997, 3.0905526395766967, 11.001338343466482, 0.91087848068245, 0.3084839033263345, 0.4222403604897761, 2.766816140182557, 44.29338086035944, 43.694234894168, 24.113584526123542, 53.64819842000162, 17.696557506438225, 0.014518746080988599, 0.03287099038941726, 0.017212894407191107, 0.03786812063246485, 0.04165064911508272, 0.034889268178132274, 0.029635450599955458, 0.041181945031689066, 0.05476711242790184, 0.02420917130826462, 0.03175417783730213, 0.043510465447099946, 0.004683005944600389, 0.027893297712228475, 0.03973002838451536, 0.01752852646243428, 0.025569663022554694, 0.04724630087073292, 0.04856815494056191, 0.053082504234607183, 0.0035479269835406975, 0.025742674404154384, 0.05211811445112671, 0.021547109617160696, 0.10732485026481653, 0.04258082158142521, 0.08321878289984119, 0.016476155311289816, 0.038899041321729465, 0.08640321121821481, 0.033273749624288855, 0.021584638349351384, 0.053013992991538784, 0.06501387549383987, 0.042934505223867395, 0.06225125518657508, 0.00578907315596758, 0.035449040963524775, 0.11774006074354534, 0.060776011162107034, 0.05211209300004187, 0.024388577608812242, 0.025164278021322626, 0.05685042342050903, 0.038535980763094085, 0.06365044583236018, 0.04240857437252999, 0.12349269157575986, 0.02871137044783081, 0.04807176827002437, 0.011997248117451467, 0.13683681706747702, 2.638143276976001, 64.75127520099764, 39.90582543034708, 53.232509551509736, 62.427011997469016, 32.75086722066326, 4.745928174065006, 0.6990908386726534, 0.5492019977781081, 0.6633689554948962, 4.341685272032215, 3.026747443983632, 2.5783425761807353, 1.4217460515999025, 1.7082646513177504, 52.289705122670824, 75.23763379743023, 65.6449637105388, 75.20149307866251, 71.53646176861179, 73.52167529444542, 75.3260204868932, 76.83648601655038, 70.36097449641075, 75.9214049000894, 71.94640436480123, 71.55888203651675, 72.20465321694651, 71.1460368863998, 56.43380688082788, 52.60115700383341, 52.601910098906494, 63.28459508957402, 68.74833906850508, 72.12720209552397, 69.39004667343633, 69.13078584978658, 68.10470165744906, 66.80454577169111, 62.247998945174686, 62.39678621292115, 59.704655678041526, 55.950319843907515, 49.00974073717671, 50.429266114388746, 49.43185837038102, 49.810669114512784, 49.79124945978965, 46.924306731070246, 52.50190534899312, 60.60069760968609, 63.96690707052908, 65.82014852954497, 64.3577947924214, 67.29372024536133, 66.08446921071699, 63.71363178376229, 63.27565993032148, 66.61553459782755, 65.95532909516366, 67.25024469437139, 62.80670527488955, 61.25172084377658, 66.91391714157598, 64.48314197601812, 65.68541903649607, 67.52500672494212, 67.17002437960717, 66.54283738905384, 65.36955056651946, 62.989585784173784, 61.09469659866826, 64.53156363579535, 65.55076406848046, 64.84661233040595, 58.683144969324914, 47.37362600141957, 46.93790558845767, 44.71009738983647, 47.42167111366026, 45.336872531521706, 46.58631609332177, 45.525938618567686, 49.32416577492991, 53.887337484667384, 54.5102765483241, 55.05640775926652, 54.85984994519142, 57.01498839163012, 58.66807522312288, 59.78429155965006, 62.23223101708197, 61.98124639449581, 61.99844206533125, 65.13842490411574, 62.38662335180468, 59.09831608495405, 52.08756577584052, 45.40320373350575, 47.89051594272737, 61.582317813750244, 68.22823278365597, 62.23758112999701, 63.63833404356434, 60.47786858774001, 64.74346576198455, 62.53033115017799, 69.22898630942069, 56.11885624547159, 63.44242342056767, 38.733974195295765, 0.13127667348711722, 0.7103528827428819, 3.6800468785147515, 4.12492823216223, 0.8612638075024852, 0.349591966838606, 0.49413057224404433, 4.704497648823646, 48.82377724493704, 57.56430848952263, 26.726679302030995, 55.77038503462269, 26.88943805233125, 0.04544713188924136, 0.02699536988661895, 0.06526802516271991, 0.0678539089858532, 0.011779633181680356, 0.03542946741705941, 0.019062627106904984, 0.019565155887375438, 0.060374718985610434, 0.03419889272340844, 0.02093464147389656, 0.049106381503084016, 0.057328925768454234, 0.07180833227692113, 0.06224896458368148, 0.041099464175321405, 0.06406882176956823, 0.04321860893058681, 0.02939399692320055, 0.023756317584024324, 0.08055001602418001, 0.035990622991155234, 0.060805421277520165, 0.14356371255651598, 0.17976953347604122, 0.10067995682719255, 0.2003287439865451, 0.1215459242643368, 0.11544241750192259, 0.228337699907922, 0.07103053852915764, 0.22433850643855913, 0.13409183210422917, 0.17697335851769294, 0.15587903559207916, 0.14688586816191673, 0.14973905538358998, 0.13839124010935908, 0.16493851559296732, 0.18748440659574925, 0.18617946774728839, 0.09931830448969718, 0.18167194429664843, 0.18018366528614876, 0.2009522476263585, 0.19484433585837965, 0.11091820099541258, 0.2657663810157007, 0.13048178065688382, 0.1267683609659153, 0.1496944077793629, 0.17933182147962434, 2.9744982863626177, 74.21254588711646, 53.67301525608186, 54.72369663176998, 80.6130224658597, 42.86043313241775, 6.568413838263481, 2.9094440610178056, 2.1129724767900284, 7.186901502070889, 12.105022707293111, 4.519573584679635, 2.788160698067758, 0.9123855901341286, 2.1945697886328546, 50.34722581986458, 81.59356009575629, 69.1522333698888, 76.91019519682854, 75.6046264402328, 75.84160035656345, 78.06755327409314, 78.91816631440194, 74.84505161162346, 77.40598278660929, 74.8788232188071, 74.18930976621567, 76.06532450645201, 73.48562086782148, 58.73210399381576, 56.06329194961056, 56.00331498730568, 66.72788696904337, 72.37699431757774, 75.81509297893894, 72.40875767123315, 72.07699575731831, 70.97202485607517, 69.49616247607817, 64.13562390112108, 65.3670520167197, 66.11009797742291, 59.577653254232104, 53.04633817365093, 53.63831796953755, 51.12154483795167, 53.30076271487821, 52.62939022433374, 47.424938448013805, 53.27776193618775, 61.33284330368043, 67.52110004425049, 68.75589355345696, 67.70320000187044, 69.47910801056894, 67.3173721375004, 64.19544396861907, 64.02050233656361, 67.89999315815588, 70.03233478915307, 70.67142225080921, 65.2641054891771, 62.81888031190442, 67.18179149012413, 67.29262198171308, 64.77766490751698, 71.25600445655085, 67.35941210100728, 68.41005817536386, 68.4025429141137, 65.25305617240168, 65.27627660382178, 64.71931965120378, 68.12276809446274, 68.15321353174025, 61.49531964332827, 50.04404621739542, 49.21473164712229, 47.15731905352685, 50.41602419268701, 48.446492302802305, 50.280918152101584, 48.01849895907987, 50.71910965827204, 56.712687400079545, 59.246777795976215, 58.7259497950154, 59.18476120118172, 60.09966188861478, 61.20716664098925, 62.70315862471058, 67.30135317771666, 63.61440758551321, 64.52142038652974, 67.00215478097239, 66.08843080459103, 61.633214489106216, 53.154921147131155, 49.23471220078007, 52.87283212907853, 63.33102026293355, 72.02198059328141, 64.91843092826106, 68.31303442678144, 60.99084400361585, 68.14572180471113, 63.24862303272371, 70.65357546652518, 58.65082071673486, 66.63724099436115, 39.49151331378568, 0.14789255365969675, 0.6506303229158925, 9.207311926349517, 26.500244794353364, 5.4109748621140765, 2.111323855576977, 0.9645982819699472, 5.043477214151814, 60.0910601308269, 56.67853532298919, 38.38086282053302, 69.17680309664819, 34.23956555704917, 0.11903852614904605, 0.14467555128278273, 0.13120882874054293, 0.18275957464450793, 0.16711829620743954, 0.11936322485487308, 0.18208854290987217, 0.08601345632585787, 0.22078140698854, 0.09329976453896492, 0.14128761936820325, 0.17506222961650741, 0.15940654872646257, 0.18005456414914903, 0.12222738245562201, 0.1251933531415078, 0.08650363768420874, 0.11552716214810649, 0.11023645169071614, 0.14782357510299454, 0.14446631734890325, 0.11305795351584112, 0.1604646234022033], [0.03426485289368899, 0.023435351641608343, 0.02779181404489904, 0.03937515730579053, 0.01699377410864878, 0.0860950906550692, 0.060254937308209564, 0.046405281886578574, 0.06181714380340231, 0.08437644900573839, 0.07266936913853692, 0.040375522578195225, 0.05102832373532076, 0.0872472792323078, 0.04613454258369823, 0.019458049134681785, 0.043048943437996416, 0.07827923182518252, 0.010538559253027123, 0.027758046804416566, 0.01585205508050539, 0.029978709700967998, 0.07396746682183397, 0.007605324940560687, 0.03571051826340056, 0.03998981263007849, 0.05977251259009204, 0.0610066112881947, 0.10334072574492424, 0.34541234434131657, 13.424289361123117, 61.00109707924628, 32.96696432175175, 63.832479599983465, 66.16429728846397, 14.748935545644454, 0.04361779819573126, 0.3370700452116228, 0.283589355287052, 3.5186428168127617, 3.106832191828759, 2.922064777343504, 1.1240322719658575, 0.09232694012743813, 0.03212633377481853, 47.53279578301215, 75.58281021733438, 65.46826093427597, 72.26876043504285, 69.56128166567895, 71.99971722018334, 69.66107460760301, 74.29464109482305, 70.76706532509097, 71.83620145243984, 72.40234851837158, 68.50890974844656, 70.89873929177561, 59.23682674284905, 53.172073671894694, 54.47860340918265, 62.626637105018865, 67.17618250077771, 67.52829367114653, 71.66638635819959, 67.69912073689123, 66.68270126465829, 65.67954724834811, 61.38358308422951, 58.794783469169374, 57.562515966353885, 54.82763551896619, 50.39269393490207, 47.7625996066678, 48.29095071361911, 46.910723563163515, 46.4884372680418, 46.43126087803995, 46.73912379049486, 47.78530620759534, 50.87833435304704, 49.83429355006064, 51.38200982924431, 51.28217374124835, 52.96490976887365, 53.54995089192545, 56.791126958785526, 61.01608837804487, 65.45230865478516, 61.347614949749364, 53.75454564248362, 59.281275041641734, 60.37374534914571, 62.32786624662338, 61.14747993407711, 61.5152217495826, 63.11131654247161, 64.01310866878879, 60.39202751651887, 63.16828504685433, 63.35972416785456, 64.65571841885968, 60.674347954411665, 57.14397161237655, 46.058361145757864, 42.10632216545844, 44.212168185941636, 44.60141635710194, 45.961784547375096, 43.36028822006718, 43.84125709533692, 43.74960699389058, 45.670689767406834, 51.49076930938229, 51.17200613021851, 54.315032728256725, 54.76651714694116, 56.32602014849263, 56.03204242644772, 57.53004266369728, 59.717066057266734, 60.98420735328429, 60.73439551937965, 61.96687483018445, 60.93287921720936, 59.24893117720082, 52.202130363833525, 51.19907832914784, 48.272558719881125, 56.48713934806086, 62.733890395010675, 65.3114837984885, 62.293945589373195, 64.11585907782278, 62.4466944509937, 65.31441380900722, 60.40870151212139, 59.083293407194084, 57.96758305641913, 4.455655130647845, 0.025278580254845084, 0.5427532534926169, 1.255031836129004, 1.5161690236099306, 0.44261505106283777, 0.4165545784898343, 0.21079500656454794, 15.619593858718874, 58.80992381803451, 19.63684420431814, 32.601118972224576, 50.23479892361549, 2.9846130984444774, 0.11138682463957418, 0.08817277473187254, 0.0076286178438984345, 0.024718686810604507, 0.013666015527691814, 0.00810105995755763, 0.012209544487808262, 0.008099009714750274, 0.015414324889500296, 0.09037299457216456, 0.000934535337071265, 0.03858946519152772, 0.06487613288505424, 0.05365241619367754, 0.02404258740434964, 0.02010844246063742, 0.011177597240725113, 0.05861289295998793, 0.0783682129375877, 0.02618586967488931, 0.019080932777855667, 0.05758069290388977, 0.019840030149827083, 0.05555183544094044, 0.046670639421790845, 0.03925902220690924, 0.023720849628349947, 0.0055296791364408794, 0.09349444280228308, 0.059116063339094964, 0.0275438045707321, 0.03265479654674569, 0.018503855981473482, 0.040724050448907, 0.026249424329087622, 0.05186331360751102, 0.02634854461517065, 0.05723033791347858, 0.08190034558215449, 0.040204332570635506, 0.03838222308625137, 0.0445234788311345, 0.07019747153765733, 0.05592602342667599, 0.06734631444898344, 0.06569051499208135, 0.06699353862073153, 0.13510899768481333, 0.012902760213511366, 0.007386216612142181, 0.10884758791015034, 0.05937346505121358, 0.39191452485899775, 23.0100296005126, 64.89291591029014, 35.31349089837844, 83.50818664796891, 61.734639137021965, 20.313908053982644, 0.09054793841055325, 0.3925875790657536, 0.437495653187075, 2.6614536777619393, 3.7011823250401408, 7.531279229348706, 6.228437500615274, 0.35833266233244254, 0.5323533341288567, 56.53635724898308, 77.04171226870629, 69.6963994733749, 71.85403254724318, 70.10641267222744, 73.13109351742652, 72.88527073398714, 75.41556819792717, 73.06194213128859, 73.544064183389, 75.03305865872291, 71.28314725814327, 72.35404060732934, 62.00212909329323, 56.2029871632976, 57.76363941930956, 63.50721313107399, 68.70675409993818, 69.6901236810992, 73.78974576150218, 72.13593329152754, 69.23497184630364, 67.16046948586741, 62.225394325871626, 58.93271361627887, 59.352164037766, 56.56735574045489, 52.427764707996005, 49.92680265057472, 47.96521748265913, 49.20904813274261, 49.555365962366906, 48.72346262778006, 49.46236264321112, 49.97128232832878, 53.342010359610285, 51.79084239467498, 56.44338530878867, 55.73261653223346, 55.468582184084006, 55.84087394898938, 58.342161563134965, 62.705366919117594, 67.53231017820298, 63.79330296670238, 56.47787863208402, 61.16284385804207, 63.29869208797332, 66.0342393382903, 62.56353793605682, 65.1070341756267, 62.62953181420604, 64.85387655996507, 62.42041064846901, 64.15648306569746, 64.71664851711643, 65.15656586616271, 63.25476154204338, 61.09479858029274, 49.91336853273454, 44.59717627494566, 47.8450595948004, 46.93520307540894, 47.534580461440555, 46.33915578165362, 47.73904969615322, 47.18674467455956, 48.4430641512717, 51.88866238440237, 53.84676448760494, 57.23090702487577, 57.14920405418643, 58.42511969227945, 58.234190479401626, 59.89776572873516, 60.67175919009794, 61.49202485238353, 63.24847398265716, 62.65284246014011, 62.701550452939934, 60.95431497020107, 53.35169469156573, 51.99972037346133, 51.766609991750414, 58.94630855129611, 66.13238488474201, 66.14857642881333, 64.27691551946825, 65.64969016659644, 65.62076268657562, 65.42246726251417, 63.43267240831929, 59.971812232848144, 62.54782884351669, 5.312808232922708, 0.01887545459002497, 1.348243408626126, 2.7232812633437495, 1.0721275474755996, 0.4697354522443587, 0.305147651703127, 0.2740738691101151, 18.688750459301858, 66.42229510891822, 30.23433727602805, 30.40062027592813, 61.74198965872488, 4.4682606477891245, 0.06702114076864335, 0.13638480987039306, 0.05282355885532114, 0.054667888719949036, 0.04056249016655549, 0.022517882828270237, 0.04744534583521947, 0.05326615849269494, 0.015902265440672636, 0.05006712470804492, 0.03975288078729664, 0.042844551179798386, 0.04635727881724316, 0.06609824996802115, 0.017195954287965453, 0.022709778277203444, 0.034819025576355, 0.036692344208037665, 0.07332910107628954, 0.04557681908350318, 0.08238361682742834, 0.05114949586230421, 0.03444779085956755, 0.2754177711904049, 0.18922184804274192, 0.08390106080520539, 0.20427915297688978, 0.1356455350234624, 0.2264847783672233, 0.1536743111547924, 0.12572036800725808, 0.14996184907372923, 0.1480653984171729, 0.12470539343813736, 0.10664611168566251, 0.1435118637258007, 0.2354750040197565, 0.19408635314433806, 0.1565828712116326, 0.10491025604067311, 0.1932038964643594, 0.07729929045683916, 0.12147787267402296, 0.12016125864559606, 0.1144556732728116, 0.12781985494638645, 0.13928229229584818, 0.14115458053927268, 0.11436509869752393, 0.17864531476891812, 0.1387735639488505, 0.16622189672723894, 0.5713404679009991, 26.67911271895132, 84.99284298189225, 43.21610581490302, 77.40355091710245, 81.3768805226972, 26.317081874416722, 0.2188400329361039, 1.5114843653094385, 1.9820040464401247, 7.925802498094498, 10.552031820820226, 8.123412978264595, 2.889028124270901, 0.22514210202761237, 0.48280782336669587, 52.910730069683446, 79.76013445085096, 72.89281737419867, 73.35435482763475, 73.5430286776635, 75.92030663644114, 74.04937528794812, 78.12474927594586, 74.54098163112518, 76.93954237045781, 76.44111110318092, 74.48176953100389, 75.5781033731276, 65.63120795834449, 59.69031941506171, 61.150609985474624, 66.50420988759687, 72.18945011015862, 74.2025673773981, 75.69975960639216, 73.13623966709261, 71.01879519800987, 73.2422613328503, 67.50585771376088, 62.78547740751698, 63.206818411427165, 59.8675242547066, 55.708019348882864, 51.19400670451503, 51.507513907647905, 53.13268130825412, 52.58224725723267, 52.0818587272398, 53.221366097850186, 52.99566899576495, 55.418042444413715, 52.42647424820931, 56.253040529066524, 55.12628086151616, 57.29854829849736, 59.43262361711072, 61.179172685069425, 66.27488459310224, 69.20056481515208, 66.79038601536905, 55.77753551544682, 62.46741633261404, 65.82584381103516, 69.11895598134687, 66.5065868439213, 68.83042643147131, 65.40810746531334, 67.06248867896296, 64.07417997237175, 66.78896611736667, 66.9644529588761, 68.73984321471184, 64.57641593871578, 62.01055826679353, 50.3645940749876, 45.61035979178644, 48.98457481015114, 49.98797985815233, 49.93423946442143, 48.62794899171399, 50.14329394986553, 48.18433284759522, 49.47188615798951, 55.513744354248054, 55.99623118677447, 61.0903545348875, 60.41126674221408, 63.077548857658144, 58.612134379725305, 63.6882540487474, 63.88217603006671, 65.76824772742488, 63.490095907642, 65.07029333422261, 65.20540721954839, 64.71354592231013, 57.10144135259814, 56.85458698580342, 52.07811678609541, 63.55234784464683, 68.85001474811186, 68.89315297526699, 68.41350201637515, 69.33712605507144, 67.05773476631411, 68.75485804773146, 65.48455445997178, 64.34829088949388, 61.846226646054184, 6.920932444833941, 0.0929979948447116, 2.202517000898238, 7.587203402673045, 10.24320988885818, 2.045664972355289, 0.7486066558668691, 0.4030507466485424, 26.35864919231784, 71.16116939052459, 32.353990039517804, 46.878167890733295, 70.64193387185374, 7.709689707525316, 0.4819945750697967, 0.24642138922166443, 0.13298644383828487, 0.24054871241171516, 0.07951864717347969, 0.12010875864014511, 0.18580894166183087, 0.25471059845820554, 0.1585900981820399, 0.2143669681202981, 0.14572519899135636, 0.1263581591868593, 0.15625667097347398, 0.14479351350136344, 0.08912304551490853, 0.1364200039496345, 0.1469540653089362, 0.2132198587059975, 0.16328656955832438, 0.1156974558327948, 0.11769242539641359, 0.2271859020355248, 0.12701467355532994], [0.053716024474030545, 0.03759000390287369, 0.04700116039584241, 0.06027074170208747, 0.03544717936986878, 0.02847207905424218, 0.028514146857384234, 0.0657759108130009, 0.01420212768754291, 0.0336912483908236, 0.03045621996505126, 0.006573551978480312, 0.07557980611079163, 0.0198386013958483, 0.025516251372473858, 0.07899524058185278, 0.008848288712362129, 0.09275395753643206, 0.013555740043821355, 0.0034974571110891, 0.026994257143908934, 0.03359719960679931, 0.018320699680536505, 0.06901499184389269, 0.07266448915845926, 0.0851042248729256, 0.1128014442961543, 0.05435600283465559, 0.08131687003638476, 0.10180967604561199, 0.2757297834802059, 43.55260595198601, 42.08545123377154, 19.432698565144694, 57.75623398442423, 49.01610282159621, 1.5857717274658143, 0.047341966100277445, 0.10962148993125848, 0.09022914624262242, 1.4633720824795386, 4.394981457341102, 10.616241020541038, 1.0589123469206596, 0.11399656444066956, 2.5049891058475744, 67.81301067721459, 71.03123695619645, 69.72970039613786, 70.94490558870378, 68.63866959848713, 72.3154523295741, 74.75015378767445, 70.93537422918504, 73.08764150065761, 72.3172095514113, 72.04276915519469, 68.80501731749504, 59.88628102887062, 51.29081864510813, 57.76685184048068, 66.91150880629017, 70.20611932200771, 70.9051170656758, 71.47062870763963, 70.08989164906164, 65.77874791237616, 60.85975447008687, 59.70609126552459, 60.65228854456256, 59.09164021092077, 56.234197462758715, 50.98971397646012, 47.887507484805205, 49.32556606108143, 50.071796986364554, 49.97250610782255, 49.780125617980964, 48.216131502582186, 49.87380358480638, 47.74471752105221, 48.10206113323089, 49.17986962103075, 53.1128772612541, 58.45461591597527, 61.51498248500209, 62.5606079255381, 62.526122446983095, 67.67413523889357, 59.10463110093148, 53.66377807432606, 59.64456496700164, 57.44320923282255, 59.96975691087785, 60.92227312826342, 62.993967071656265, 62.81479712455504, 65.49701190763905, 65.67633482717699, 64.06591161604851, 60.50930638467113, 59.66038388590659, 55.13382357935752, 49.113044200405, 43.329889851231734, 45.61351729977516, 45.26191995989892, 45.506526808584894, 43.96752211355394, 45.059270704946215, 45.49776031124977, 45.224822182809156, 45.34502321673978, 50.58568239212037, 52.618187935121604, 58.352183218925234, 55.020212127316384, 59.66607132265645, 56.0816917880889, 60.40483797750166, 61.399417692615145, 62.59737230116322, 61.35202369382305, 61.63033939176991, 61.27049330742129, 62.18675505730414, 55.61081124890236, 51.211084704245295, 48.89815715051467, 56.648399752955285, 59.01522459522371, 65.35968188316592, 63.39554325226815, 66.55669120050246, 65.64917633610388, 69.98688236359628, 54.026840502215975, 65.11616545338785, 6.889686844041271, 0.36504546180367475, 0.34758245692618434, 0.6969218292543966, 2.7091455315389945, 0.38983845722771465, 0.12984321572847907, 0.09779962711036207, 1.1524156456993473, 44.84767452363045, 44.38528983823715, 24.339377726278, 53.49585748487904, 21.259742513779674, 0.03678226377815008, 0.02628815773453924, 0.037434392293254216, 0.02511917459478061, 0.04946985191875889, 0.07596928521149582, 0.032364188753549135, 0.03253044515487648, 0.12313132790187675, 0.03181850240986434, 0.0738691087932356, 0.04086093886965706, 0.04470138742979016, 0.08303475325867053, 0.025859832230414596, 0.026395869696693077, 0.03960518286593499, 0.06063187938003291, 0.012938189864789527, 0.06491649805778457, 0.04320001597666452, 0.018549459280386087, 0.031514045662216605, 0.029942151985221335, 0.00883630135156695, 0.02023061816280167, 0.0019347811476402587, 0.0653662069910957, 0.03206408530053112, 0.05999007773014808, 0.04177872752470355, 0.007776442648572548, 0.006332685316597382, 0.023121426047216502, 0.06189132409711039, 0.023319019275086544, 0.027953201957467585, 0.015590382428208907, 0.03826450601580643, 0.05368978979306356, 0.011134312315393361, 0.05542651877828664, 0.0339505959662699, 0.07383456588872979, 0.04401460875787082, 0.061965975534891894, 0.027960581299398216, 0.07181351869216851, 0.02626813028097874, 0.07987113954919962, 0.07493204046641627, 0.037065639701341434, 0.1246065374523882, 0.11546481025194931, 0.8045517280697824, 62.2693484060226, 39.04972891653738, 38.6867880821228, 76.71622614706718, 46.44555791731804, 2.8570100617024208, 0.2338481090602375, 0.0888456297557681, 0.8698747583454656, 1.968487313678188, 6.861351151620188, 9.723398762364543, 3.0482158016773964, 0.3163506763596689, 2.8331235627974234, 74.74266990538567, 68.81148138353902, 71.15687047281574, 71.13523467894524, 72.21874237060547, 71.85677036162346, 76.52202175509545, 72.86815351055515, 74.03309745173301, 75.7026150918776, 74.88065104330741, 71.88032027213805, 64.88990745236798, 52.259396968349336, 60.19606982508014, 68.28062780441778, 74.66828607743787, 73.47700734292307, 73.77958682275587, 68.94515575901156, 67.58792154250607, 64.06777866425054, 64.70221027251213, 62.71305476465533, 61.2541840922448, 57.3285505079454, 53.225912124879905, 50.03444817758376, 50.36083644436252, 51.20633471396662, 52.83440074613018, 49.51560097355997, 50.600434426338445, 49.052788749817886, 49.73271985207835, 48.014945291703754, 50.822016962112926, 54.405086425042924, 58.963951372331195, 61.254603785853234, 63.6233074434342, 64.20335538925664, 69.3573341061992, 62.10085515053042, 55.41288845000729, 62.00073272951188, 58.75557153455673, 61.92257558145831, 63.8582338825349, 64.7673176950024, 65.33183697731265, 69.4600139125701, 68.3736821143858, 66.08794443068966, 64.05689408702236, 63.36401524082307, 57.83397536123953, 51.61616356142106, 46.5417108997222, 48.5238375202302, 47.223461981742616, 46.08866930007935, 45.333703256422474, 45.37679441513554, 47.03360749829201, 46.20439883201353, 48.02153487359324, 54.62776330209548, 55.54553516449467, 59.69901138736356, 56.4238440605902, 58.5291644834703, 58.61129107013826, 63.57674106474846, 62.81818605238392, 64.48465208853445, 62.88286593652541, 62.4637802954643, 63.99606597039008, 64.08946544893327, 59.31677641407136, 53.4776419977988, 51.872757173353634, 60.73598800166961, 62.697302526043316, 67.27582639263522, 64.35420974608391, 68.78412677395728, 67.031737296812, 70.48307787987494, 58.45484341344526, 67.16287782115322, 9.35487247282459, 0.5517715792502127, 0.8665647069292685, 1.6966328625717473, 3.1615107674752516, 0.2642726014939047, 0.29873699730923103, 0.12488370040251363, 2.979921698570252, 50.057958864396625, 56.65294970235517, 21.432328762546664, 54.19311369619062, 30.953023356776086, 0.03830998099499172, 0.032675434955425804, 0.03109675948508084, 0.04084102441406539, 0.021947907666946133, 0.029985694507617625, 0.1187199638074925, 0.08904547145169589, 0.05624187764741721, 0.04244806620502665, 0.031589861553643024, 0.015576976847143905, 0.04306781984445068, 0.03811716815576919, 0.04934704802449673, 0.04828945598414829, 0.04591348025226786, 0.05448661699530579, 0.030054192344147353, 0.0696491824102498, 0.036101372491928845, 0.017425937713274074, 0.021911010957292972, 0.027816434195565603, 0.09926280141958307, 0.07633826379934627, 0.16438457273667859, 0.22706689793736706, 0.17193037025149793, 0.29122526006352517, 0.11796886822389019, 0.1414627777112107, 0.0973429850813362, 0.1355990028429416, 0.22718936475294255, 0.12656262805384974, 0.12104783687860736, 0.08857521604025557, 0.13585092319596198, 0.2264297272889845, 0.2944369764337617, 0.2668162891941686, 0.1311083792919113, 0.17825329225630532, 0.19593323791219344, 0.08963554301449368, 0.13622690382744038, 0.15928078773281268, 0.1416968328938369, 0.16094710557691513, 0.1696506151629071, 0.14696920320631998, 0.17233408326583524, 0.22579540648768026, 1.6826727794062708, 72.85947722773399, 56.44058081411547, 36.18899922217093, 69.73056331757577, 69.02533685007404, 2.981123414731795, 0.4559419472371379, 0.4781919904053212, 3.1018446530065233, 7.118796408176423, 11.82276894969325, 19.393618029932824, 2.7413035736929987, 0.21170749389115842, 3.0560254858386133, 70.41251444047498, 72.67393342910275, 74.43706235577984, 73.45156684998544, 72.23648717326503, 74.28727488363944, 80.5950423209898, 75.89332857439595, 76.5316786304597, 80.13224186435824, 77.18548282500237, 74.72696473521572, 65.66622687924293, 56.3809137190542, 62.80865077049502, 71.44728276037401, 76.5954642142019, 74.59330604922387, 74.68166135972547, 74.6727026662519, 70.90820004863124, 64.67274935014787, 67.40048716145178, 67.25082520515689, 65.83304528267153, 61.71605494714553, 58.39129709428357, 52.641506425796024, 54.46509084393902, 55.560185217088275, 56.149890038274954, 53.27214510210099, 53.45925392643098, 54.167932079684356, 52.58795822820356, 51.62727563611923, 54.954194714946134, 60.17786610511042, 62.577576098903535, 67.34668008742794, 66.63441688783708, 65.86001549997638, 72.5913518474948, 65.96553510235202, 57.701242354608354, 65.03913794794391, 62.471962359643754, 65.15504006416568, 68.15957561615976, 67.37135964055216, 68.05433842443651, 70.6139438383041, 71.7862775248866, 66.66192054748535, 64.99010832078996, 64.60532380688575, 59.36965780873453, 55.373880478643606, 49.15107942396595, 52.71532151006883, 49.96657940649217, 50.05832756719282, 46.625131868547015, 48.66334446014897, 49.90490405790268, 48.51121925538587, 49.13062034114715, 57.67865734715616, 58.79694469513432, 63.69664399854599, 59.44833270965084, 62.540309659896366, 61.73284661385321, 66.11805254413237, 66.81293179911953, 67.20272910210394, 64.94637389336863, 64.17119587621382, 67.78262799785983, 68.56643522939375, 62.06423590260168, 56.884244026676306, 55.604154986719934, 62.81823704319616, 63.68600653063867, 71.31045479928294, 67.68714966312533, 70.82650492268225, 69.78433901263823, 70.6625420047391, 60.280118373132524, 69.48305391496228, 8.633913378561697, 0.6348696879802213, 1.1132972351005002, 4.812705545656143, 10.112890120475523, 2.4932778891055816, 0.7345559904652258, 0.46791936421105945, 3.1382756271669945, 61.963070131117306, 57.94266816108458, 38.095902627514256, 68.4507017750894, 38.7459413466915, 0.12064063050333532, 0.11724830890494971, 0.1164225274096093, 0.1924935337756911, 0.15477999053414793, 0.1539362366161039, 0.2247408864599082, 0.16714183042847341, 0.2081250675743626, 0.1599654711542591, 0.16196013428270817, 0.10332867518187532, 0.21454257079430167, 0.12366143776284111, 0.0809163362869332, 0.08418210016022767, 0.18689517772966818, 0.18644079566001895, 0.08567989398274692, 0.1580978713689312, 0.21654006844807058, 0.12089317138757437, 0.1402630840217875, 0.16484747370404584], [0.006304525839720643, 0.0441033408917006, 0.02022206670634689, 0.09438708079077544, 0.07000084741101151, 0.025464283798130292, 0.05015863391060022, 0.04468975821509958, 0.03209737565128073, 0.05090074328285071, 0.04757733895413337, 0.03206351648024734, 0.03930129876901065, 0.08393401790770792, 0.040999355635816054, 0.023748040004002473, 0.005210451256003111, 0.00722357327298772, 0.04386327574930845, 0.04615621521107612, 0.023492547766035123, 0.02094823570411292, 0.01789407106116414, 0.03141268648417487, 0.042453287094230616, 0.035623551962236245, 0.04188167058952874, 0.04421523952436063, 0.051317790057510144, 0.008767357268821328, 0.18963660804494736, 8.334694389374025, 52.39222018949447, 34.192916808589814, 32.48073750926603, 77.22737373844271, 17.35055934998297, 0.09857736723197084, 0.28711786433573694, 0.9402163999695933, 2.0826398076549655, 10.073482067354265, 17.235806488221694, 3.860843138348672, 0.3100848738704958, 0.36459748422907245, 15.16260733527522, 77.25082166733281, 66.04035823575913, 72.6607228863624, 75.14767815989833, 73.0210788788334, 72.89669267592892, 73.82113256762105, 73.89809731514224, 72.07194374453637, 71.4361196948636, 70.96076765368062, 59.93086661061933, 55.06799836312571, 62.02125457025344, 66.70947536345452, 70.49977933206867, 68.70673056571715, 69.91131397985643, 72.21062306434878, 67.48950927488266, 63.05070023382864, 59.326044974788545, 60.5075530852041, 58.20197213080622, 55.297915935516365, 53.29502036494594, 49.3554231428331, 48.490705259384654, 48.894493656773726, 49.54640726889334, 49.12833752170686, 50.27678005156979, 48.69939104203255, 53.12488755872173, 54.95681878059141, 60.16187067954772, 62.41170690905664, 62.78259054307015, 61.52085427315005, 64.40420035393008, 63.33515444109517, 67.59718618085309, 59.196481243256606, 53.14721368974256, 65.34631836798884, 62.99177838910011, 66.4354899621779, 64.78165395798223, 66.71044026651691, 66.32810331160023, 65.78693389892578, 63.220793816351126, 62.128107778487674, 57.2277573616274, 50.60820071927963, 48.41599979708272, 45.68230782785724, 48.03640457891649, 47.03439589469664, 45.987189738981186, 46.44364772304412, 47.98726120302754, 45.9355870369942, 46.15383555812221, 44.676553280122825, 45.40964818769886, 46.97550935129966, 53.3597473175295, 54.44306673542146, 58.54783104312036, 59.31212840541717, 60.25364629683956, 58.366390043689364, 61.06580834234915, 64.855900502974, 65.31717515760853, 58.378623916256814, 65.10825011038011, 60.906007059158824, 61.394993259060776, 54.45101737976075, 52.257737805766446, 49.919703160562825, 58.075185437356275, 58.565618991851814, 63.48373774559268, 63.59415638831354, 72.20459045902376, 57.13151416470928, 68.91485152706024, 13.89663294438393, 0.5657745020524149, 0.2811604888448792, 0.3545806088274525, 1.0914916761459843, 1.2167881140785834, 0.12578641244721028, 0.3394047134826261, 0.15899197258535894, 17.55669363083378, 59.01633462598247, 22.510837393422282, 40.47152534607918, 46.27558985064107, 2.731063000617489, 0.12502632299137692, 0.16786327074852683, 0.04363952061882423, 0.10823856333210584, 0.05750800648163404, 0.040753912556195454, 0.0062174905906431386, 0.019767772736808947, 0.06100943815263529, 0.03166806763939319, 0.00643393867874458, 0.042437160943424514, 0.07938475798695319, 0.050391509317823, 0.05125597442289995, 0.09544330919461866, 0.01472831613594486, 0.05421127350400052, 0.005446175552694308, 0.027053228677100232, 0.01836517108454099, 0.0322587329203323, 0.07408552863184484, 0.06313804792420519, 0.0240314484859306, 0.029111387087933482, 0.020912151047659498, 0.04433200281533984, 0.07388551073569445, 0.05552684565285041, 0.016374344141372753, 0.05950753426840229, 0.0229506861163123, 0.04690364506396075, 0.056463564340505874, 0.019464767725777724, 0.03719319717117375, 0.04459405085071922, 0.041700559743349595, 0.03235484248087291, 0.042904352003167716, 0.026526644735807375, 0.015477952322051411, 0.05291576902832716, 0.014293455901826102, 0.028607234201063553, 0.08207595591703731, 0.03140145563520491, 0.05703943646362713, 0.04145770221047344, 0.05054492225509979, 0.05478288234782316, 0.029806816807737755, 0.022070937557145957, 0.08468824679092055, 18.455561630187496, 65.12984275817871, 24.455623049889844, 54.48665211277624, 86.63921863802018, 18.378798884730188, 0.11364485347463239, 0.2323253714149037, 0.36992366455735703, 1.7686869252112605, 3.1170632041269735, 12.079052694382208, 7.828563019152611, 2.560431072788854, 0.623311504961983, 19.449792254355646, 78.58986393097909, 69.2195333973054, 75.4518501220211, 73.93302209915655, 73.99530149275257, 75.31291192577731, 75.82562062048143, 74.92176532745361, 75.4272960847424, 74.25836701546946, 72.17103850456976, 62.786999287143836, 57.08698741851315, 63.6314542062821, 69.26861793764176, 72.41984228934012, 70.65160643669867, 71.33877431192707, 75.46575884665214, 70.83200408566383, 66.39699582130679, 61.21391311768563, 60.880033123877745, 60.58637311381679, 57.78156072862687, 55.36854213283908, 51.518422019097116, 51.316004183984575, 51.94468167520339, 51.5718250889932, 52.27304289417883, 52.807791386881185, 51.746711807866255, 55.99598407745362, 56.780238459187174, 61.80831301596857, 63.38949887983261, 62.818382170892534, 64.11352526757025, 66.30548692518666, 65.41874101085048, 67.82069067801199, 61.511326836001494, 54.2066341061746, 65.78563559439876, 63.784787501058275, 67.35964744321763, 66.0840299052577, 68.12199146516862, 68.44491235671505, 66.04479835879418, 64.87774418246362, 65.35906214867869, 60.92095913425569, 55.39871300420454, 49.67828127645677, 46.96744495822538, 48.43745908429546, 48.469469547271736, 48.55762089452436, 48.57589913952736, 49.18282708814068, 47.4985299571868, 48.16723523601409, 47.79764206178727, 47.48172652336859, 49.04098241559921, 55.18594403420725, 58.337278212270434, 61.062038944613555, 61.25668264204457, 61.554774930400235, 60.31620810108801, 63.45027992802282, 66.66316786120015, 66.14697610178303, 59.99658200048632, 66.8923754845896, 64.39721069028302, 63.25366720076531, 57.31936431700184, 54.438834498005534, 55.141083886546475, 60.090636514848285, 62.54516947653986, 67.31858807225382, 65.89021775030321, 72.9924612660562, 60.23781953319427, 69.31571775867094, 20.196884139891594, 0.7539241027928169, 0.5495195871879978, 0.991859551398985, 2.1191722731436453, 0.33111910485932905, 0.1420379565247605, 0.12827689534113293, 0.20666268233570362, 22.484206461137344, 68.3885871210406, 31.361534287852628, 37.04299726793843, 60.82838727581886, 3.8187024189579875, 0.16018805033977956, 0.14301016806594788, 0.04346044373608405, 0.11764596216380598, 0.015334348183035132, 0.06523058644586033, 0.010434207544031163, 0.022634102196823207, 0.03507430139448374, 0.021867556535007975, 0.02460118232955856, 0.059015521959912394, 0.016137808749091723, 0.07483088621689428, 0.03844450986493499, 0.05628515778469944, 0.009773299661314776, 0.05092336585925472, 0.05126392258511436, 0.032473731665842, 0.04799725089762961, 0.06271083133235093, 0.048700917977839715, 0.10201351672050454, 0.1904653466396755, 0.12876177537104777, 0.14541848802999144, 0.23857459576139528, 0.16736442493575235, 0.1901925427298392, 0.20309130300677594, 0.12711595803979905, 0.1699471524766376, 0.06646918974095775, 0.16473989963771837, 0.11304392644594755, 0.07391677478388434, 0.13404830298837156, 0.11498039753566827, 0.14247516290314738, 0.10689109894296817, 0.12169597024518637, 0.160903086164786, 0.20217700771266417, 0.08294680636496314, 0.16637997130953497, 0.17102974196595533, 0.1714621526339362, 0.14107542833493603, 0.1542020844475877, 0.2350670009130432, 0.24693528100127177, 0.15715831049507664, 0.11967576574534179, 0.47826449296647505, 26.31417932048921, 76.88391531667402, 47.71177353397493, 47.69837863983647, 92.88270627298664, 29.848232884560865, 0.3088143323698352, 0.6084209620471924, 2.6603752711126885, 5.759323989191364, 25.754300202092818, 36.14743778782506, 10.799801080457627, 2.0394795171676146, 0.38001788419581234, 17.41051866162208, 77.84127958359258, 73.8078514222176, 77.75054731676656, 76.49796978119882, 75.51068567460584, 77.14195236083, 78.78424090723838, 78.31840453609344, 77.99950015160346, 79.24628042405652, 78.02894146211686, 66.82458123853131, 60.43781334354032, 68.21642644943731, 72.72454769380631, 76.39281103687902, 73.37062481910952, 73.19504384071597, 76.6053250528151, 74.02465651112219, 70.3714080010691, 64.92769948897823, 65.1054769946683, 61.136222731682565, 61.77506700638802, 58.99944097765031, 55.09114426951255, 54.395990448613325, 53.87205593047604, 53.171948156049176, 55.983405036311, 56.990681463672274, 54.29284388019193, 60.24484057580272, 60.724981830966094, 66.16957679871591, 68.37107766059138, 67.39192070499544, 66.272170312943, 69.15850131742417, 68.29642711147186, 68.54083784164922, 63.5354345844638, 57.24127777161137, 66.4498850607103, 66.44778267029794, 69.99482124082505, 70.38661895259735, 71.04426706990888, 69.92616407332882, 68.31104970747425, 67.79106109373032, 67.79704663061327, 62.64735506426904, 55.88138811049923, 53.06185114768244, 48.62884329211328, 50.50877648015177, 51.48039071790634, 51.02430928137995, 50.39176041080106, 53.789690079227576, 50.027203559875495, 52.52766747628489, 50.5697811034418, 51.59027591828377, 51.38599103496921, 55.40513784654679, 60.22166721282467, 62.48143880598007, 63.97681105521418, 65.00854738297002, 61.7030954360962, 65.39724249993601, 70.01133441925049, 70.10643620644846, 61.14713476550195, 70.6949721613238, 66.67507617704331, 67.17177375670403, 58.224317873677904, 58.25306884704098, 56.87668169698408, 62.91200914690572, 63.045526627571356, 69.41110980126166, 68.19308050217168, 76.81796458459671, 62.82238691083847, 73.77460541263704, 17.50938004063022, 0.557763428697663, 0.5387894532853558, 0.9513568505644799, 6.656781896468132, 5.386331590913958, 0.4137500838166283, 0.7619734805437827, 0.21514275471769997, 32.28824719305962, 72.24459863478138, 36.74966281460178, 54.182605666498986, 67.7905668750886, 6.214475333690644, 0.47840588215378027, 0.3208674081871587, 0.25976190643925823, 0.21565148306469764, 0.11688954993000916, 0.24506755864187596, 0.09088383732183326, 0.12969344553928222, 0.1034545970539893, 0.1413334161043167, 0.15748207457363605, 0.2046508435159922, 0.12330258685734966, 0.1901189829673498, 0.17604110612263604, 0.15479391801261133, 0.08820282070026284, 0.1263910933067241, 0.11977150375323913, 0.18658364041438028, 0.12245418278560524, 0.10138267395837654, 0.1625561200442814, 0.23129999337177123], [0.04035963391464564, 0.028553562081088463, 0.04481145128187153, 0.026777387228644183, 0.11826848521107629, 0.033005795051013274, 0.046528729294697126, 0.04895304900503928, 0.05277239567329807, 0.055243508034055276, 0.08635858659662547, 0.018253320332376227, 0.024579668665424954, 0.03952567060027392, 0.03855519424823504, 0.07933352202657731, 0.033674440421764894, 0.05427286697311267, 0.04155176631625622, 0.08236346871501977, 0.04144864322076883, 0.0924516822241487, 0.03141221917054105, 0.05816534439462328, 0.07588851656163893, 0.019824114673200156, 0.04787281140564911, 0.019247574138364965, 0.012993020692750091, 0.06991820184574013, 0.24157050516336198, 0.22435749009732278, 38.2820975395941, 58.12879247050132, 28.84365112550797, 40.92694782441662, 63.62825747459166, 2.784656305466929, 0.08673306569577226, 0.3929041572395833, 0.4747486703338162, 1.966479060149962, 5.886995667411435, 6.27795595315195, 2.254256250396852, 0.01352623704024741, 0.17931404823978103, 40.43156423876363, 83.62152745646816, 64.93208862120106, 74.4719792950538, 72.3913658818891, 76.79826644159134, 72.67862458382884, 77.95196886985534, 71.84938846095916, 73.62417467178838, 73.24517957625851, 64.00629158942931, 55.30025759050923, 66.84191811469294, 69.6293818566107, 71.97783823936217, 71.60629564715971, 74.74572935412007, 68.94306905807989, 65.69146340893161, 60.773831029092115, 60.76116569580571, 61.189261021152625, 62.36543078576366, 56.300893445168775, 54.37608441998882, 49.48897984720046, 50.49018836790516, 49.27837602553829, 50.196771544794885, 50.95477350296513, 53.28749725895544, 51.163463207983206, 57.19613913566836, 59.82224049106721, 62.96049356460572, 61.92027707253734, 65.1245750150373, 63.141228537405695, 67.23456305842247, 64.85531606981831, 69.15399843646635, 57.614095134119836, 51.618705257292724, 71.4678987379997, 65.54358613106513, 66.56047236534857, 62.09463427143713, 65.73448788735175, 60.88401040723247, 61.70983014568206, 53.954155060552786, 54.07011993469731, 50.394090298683416, 50.073291409400206, 47.50710818075365, 47.717802216929776, 47.47552917849633, 47.297143705429576, 46.180558666106194, 45.69826795208839, 46.40746385820451, 47.5577812810098, 46.00617793298537, 47.97771023165795, 47.23406807068856, 48.796297119509795, 50.513326429551654, 56.289126334651826, 57.870425947250865, 59.96028830928188, 61.502576028147054, 63.666763382573286, 63.25478115389424, 68.07642136850666, 64.81275835344869, 61.86572474818077, 61.73037552064466, 67.09409513781148, 62.04583606412334, 58.189785326680834, 52.91252651522237, 55.91518717427408, 53.18481745258455, 57.924444829264, 61.021089400014574, 66.51108972487911, 64.19516548033684, 69.69869798229587, 38.70898477492794, 0.07326992844501812, 0.2613319270312786, 0.5156409115560594, 1.5409362171926808, 1.7232400154875172, 0.3344140490216594, 0.24327154211219282, 0.1531240455205402, 6.513209419865762, 53.70149166353288, 31.23913868781059, 17.476706697094826, 54.43525337403821, 20.048700917151667, 0.05815552697787362, 0.06549723866966463, 0.12250468330157381, 0.07613282966157121, 0.036211018826091484, 0.024399630342339797, 0.03394369734451175, 0.018057607850360296, 0.053529470573149385, 0.013692657192868572, 0.02325774373246297, 0.04576040056323813, 0.11268056328258208, 0.03844777339949243, 0.06877179723232985, 0.06077223051820071, 0.017041723551829497, 0.16516952174565486, 0.04621117818920363, 0.019028365739711353, 0.015637073571973994, 0.0676441541121852, 0.02990931171112724, 0.03345690209478621, 0.01770696366175769, 0.07872553932810984, 0.016463076275202538, 0.0637329190278486, 0.03900594123068356, 0.08787671239265511, 0.021663608607806025, 0.05262408488159699, 0.047403651499940504, 0.07108570452058507, 0.0712325559147904, 0.017238617724468632, 0.03874008573832051, 0.034045012472497846, 0.04685489505889916, 0.023683047019726327, 0.05053633057902898, 0.029697685667704192, 0.0639107816612288, 0.01380455774074841, 0.015429786459032088, 0.0372890807357767, 0.11156867859103989, 0.04275058666544576, 0.03541161373798405, 0.07123145274817944, 0.028393934255525954, 0.029342942908706687, 0.05321350526965914, 0.05653024846387487, 0.0975312128843319, 0.13323447246464992, 1.4387731830919943, 55.28145374790315, 56.35053103969943, 27.352822942118493, 65.99916550420946, 62.75645579061201, 4.178750505370479, 0.19305852361984793, 0.3002892446614081, 0.052240527640547485, 0.8757708161588639, 3.5569501548044147, 9.285310218411109, 8.62386622736531, 0.44113833997999474, 0.18367975349387816, 48.04310790954098, 78.87764038578158, 70.661788909666, 76.46910898147091, 72.3146443213186, 76.38033789973106, 75.37966282136979, 77.7659857657648, 74.69665265852406, 74.00465242324337, 76.02318256132065, 64.54186770223802, 56.73801414428219, 69.14621645404448, 72.12015751869448, 75.20221479477422, 72.68421788369456, 73.83463336575416, 71.36554841072329, 67.8911207568261, 63.81385226403514, 63.758080082554976, 63.92490633072392, 65.04291519041985, 60.13690479340092, 56.46498972369779, 50.76052596492153, 53.22329590397497, 52.218090488064675, 53.05593621346259, 51.539861694459, 52.57717171022969, 51.93806855909286, 58.95417682586178, 60.92656027886176, 63.46315706929853, 63.094073803194114, 68.2966624536822, 65.1550792878674, 68.91645969883089, 65.90586016255041, 70.78293523480816, 60.376938158465975, 53.4882833880763, 71.37471891218617, 66.0379263662523, 67.2125820959768, 65.80294501396918, 66.18985545250678, 64.68444193563154, 65.43890591590636, 60.74450738968388, 58.03928790553924, 52.67115954429873, 53.04217261652793, 51.71224594116212, 51.88660314006191, 49.93499255949452, 48.64774519397367, 48.459039964983546, 47.83959965552054, 48.3963644120001, 48.55169027082382, 47.86451847322526, 48.57272594205795, 48.26935022108017, 50.461307956326394, 53.46870683854627, 58.621579447100245, 58.77054714387464, 61.43817855465797, 63.963141595163655, 64.29453088391212, 66.97175641213694, 68.65767740434217, 65.8397525356662, 64.00129841219994, 62.64287179516208, 68.2412628973684, 64.06928877676687, 60.46807835178991, 53.609449325069306, 57.64583495355422, 56.74877712803503, 61.95181685109293, 63.54102003958918, 67.88014596508395, 66.44043999333536, 68.75852938621276, 46.51263436963482, 0.061051959862872485, 0.25041276859419964, 1.25383306174509, 1.0685459332120035, 0.6889223391490599, 0.14709211435289155, 0.2013811955769216, 0.19754968343242524, 10.540149000383193, 58.843503229079715, 48.340596152890114, 16.660373210906982, 60.335113925318566, 27.106249024791104, 0.0689281021515208, 0.010343717238415154, 0.0689333115494059, 0.012694147768460456, 0.052596153315877726, 0.018843604484573007, 0.06483013696608043, 0.03095095188567235, 0.01836061669183114, 0.009979238459509949, 0.042557344816985636, 0.047331734996048674, 0.05346203951405422, 0.05232246074404928, 0.04225944769718955, 0.008218178521811722, 0.09421118700336065, 0.06270546105600174, 0.03654363505061596, 0.017071374984938773, 0.011548076403297244, 0.04053571539360189, 0.015793571928365818, 0.0452006584213626, 0.01784312238375987, 0.20687994487102956, 0.09321816851414981, 0.14344653174761804, 0.14870661400979565, 0.2312613825403875, 0.21113115062396373, 0.10386809301111968, 0.13970616874435257, 0.14144048455261415, 0.1505690963277894, 0.12155192273278391, 0.12951968147629692, 0.14703758421444124, 0.13243672978733817, 0.12356488770174405, 0.19615724202125304, 0.1534546584251427, 0.20200996990165404, 0.12791096578322111, 0.24933505142408036, 0.1439152396614513, 0.19424939197638344, 0.14490557684292718, 0.19932743642599354, 0.15585488850070586, 0.15832245770481326, 0.16139831604255786, 0.1435491109206792, 0.21479341862422807, 0.1452521090545962, 0.5120834750273536, 2.610055184172046, 69.0050111278411, 74.66306148036834, 45.67296474210678, 49.63468805436165, 84.606395383035, 5.5763321826534895, 0.4302966023885435, 1.2179629865192598, 0.8928341070009816, 4.591365706536078, 11.783810988549265, 16.322363941900193, 10.52382899868873, 0.26963944576921006, 0.6808470369827363, 44.95770877407443, 85.75214324458953, 75.31482604242142, 77.14883219811225, 71.4725742032451, 82.07425440511396, 78.5040738505702, 82.19185490762034, 77.3085589562693, 78.02305790685838, 79.11181372980919, 67.6987834130564, 60.50500354459209, 72.52682885816021, 76.00634774854107, 78.55190323245141, 73.57805544330229, 78.25297155687886, 74.89009611068234, 71.08537350931476, 65.1319412262209, 65.99023034495693, 68.48855264725225, 68.69973305732974, 63.2004798612287, 60.794066536811094, 52.65813727532664, 56.810632905652454, 54.909158060627604, 56.600476234189934, 55.62638698085662, 57.226651253238806, 55.22541876762144, 61.88791359624555, 64.07791799114597, 69.62116056872954, 67.24595362140288, 71.38705084400793, 67.3873786003359, 69.57844595755301, 70.07186443574967, 73.18472800716278, 63.58830028964628, 56.2771160371842, 73.08178147962018, 70.64924516985494, 70.43702925405195, 68.42482197669246, 69.4378839000579, 65.91241836547852, 68.54879240835868, 61.31887966586698, 59.26140431434878, 54.05611315081197, 56.71744915746874, 55.00369502652077, 55.7680316125193, 54.17084247835221, 52.49025983195151, 52.47207964620283, 49.152734664178666, 52.594943969480454, 51.725691826112815, 49.71100953317458, 51.071970001343765, 53.117964575367594, 56.010834170926, 58.64299558824109, 61.79619681450629, 63.11852585884833, 65.10996418614542, 66.15060821656259, 67.51312978806035, 69.07910470039614, 73.29767657864478, 69.03034963915425, 65.14470461876162, 66.42901020665323, 72.12904560950496, 67.49646755956834, 63.550523942516705, 56.946464584719756, 60.009890602480986, 58.83897681390086, 64.9401726261262, 66.28423552359304, 71.3183936765117, 68.38577870399722, 72.3286001143917, 44.15815322629867, 0.15741003166523673, 0.7353320681760389, 0.7694675977672301, 6.664323633716953, 5.394855881890943, 1.244341048502153, 0.6923379268377059, 0.47736320584531755, 12.849600353548604, 70.23697268578314, 43.977265281061975, 29.85389678708969, 71.9306521261892, 35.99474776175715, 0.19287999448997362, 0.169981871581366, 0.14639449936728324, 0.20632419404723953, 0.15870832087051484, 0.06712102331221104, 0.15935658447204099, 0.12783642542818863, 0.15846959255155058, 0.12026275763468397, 0.14852368753523598, 0.18852950374205268, 0.18768745053920055, 0.10265106275196999, 0.1344840537997023, 0.18053847124740002, 0.18582273124446794, 0.21734036985904942, 0.13129072353964852, 0.16856083976885966, 0.16383789239391205, 0.11504086485553174, 0.24556798259577445, 0.18682995300379493, 0.14266121501643814], [0.019835309132993705, 0.07295810767719824, 0.039030682040198196, 0.04467438283045927, 0.026710327722192295, 0.013786290374193943, 0.0325788427594929, 0.02658328353126924, 0.014239085684230011, 0.03256018851853667, 0.060588825238688346, 0.07138789556319676, 0.07938974521934025, 0.04907579544270712, 0.06703633229218184, 0.0772528195633523, 0.06615815038282065, 0.019047828203427698, 0.05271469010040165, 0.05027172764042213, 0.1746135778845318, 0.019102611150892995, 0.07004098275736456, 0.017133290210979122, 0.06311888040433969, 0.05239903123208112, 0.11211795597186974, 0.07558268660138692, 0.008401427710909517, 0.11904131470909042, 0.12234338348911655, 0.6010858846768257, 20.448843471465572, 50.03826464376142, 51.00410907499252, 30.360698392314298, 59.921931451366795, 37.302677785196614, 0.1074399090101642, 0.15306738565766043, 0.28004043765606423, 0.4065265794915538, 5.85235966790107, 10.342475271994068, 6.651693111465824, 0.5611613044334997, 0.14788552097255184, 0.8915739842960912, 63.950880266005, 73.27025136639996, 69.51964962867, 71.3390096541374, 77.49644833226358, 78.09777905864101, 75.4870024035054, 77.6042115303778, 72.26362997485747, 75.98621814481675, 62.8335617434594, 61.71293666285854, 70.67934543855729, 72.08239293867543, 73.70190035912299, 68.331712753542, 72.54597786934146, 68.93262770868117, 68.39991492609825, 66.18662341948479, 60.91293396488313, 60.40590486218853, 57.26838527187225, 57.33369665761148, 53.73676553849251, 52.311952806288204, 52.05026795787197, 51.32663772952173, 50.458860397338874, 53.22578660903439, 51.877342424085064, 53.516206741333015, 55.80458418015511, 56.74534505413425, 61.373977199677505, 62.43004006724205, 62.92413711547852, 63.67818532451507, 66.10456743547994, 64.10058536837178, 71.38308925013389, 49.481040969971694, 46.03350900834607, 74.7099651828889, 63.464074903918856, 68.65329219448951, 59.606141428793634, 59.72274172690607, 57.0564046982796, 57.61611907712875, 55.34863218184441, 56.47385428028723, 52.15480696770453, 52.64542487359817, 50.56567830424155, 50.51857848321238, 46.27318543772544, 47.1861014058513, 46.53063412635557, 48.03669091193907, 47.35898379356631, 48.42441720347251, 47.52048738541142, 48.464676410921165, 45.338794492906146, 47.51553343188378, 48.64047704204437, 56.09418453708772, 56.72837688076881, 62.41582539773757, 60.81380782588836, 65.58795990482454, 63.17311740690663, 68.7047536911503, 65.70619190892866, 65.0001338989504, 59.442335405657374, 65.39073136544997, 61.45627637063304, 65.89822723019508, 55.042565714928415, 57.23202490037488, 53.89545679092408, 62.22170337553948, 59.91104295176845, 71.3526673470774, 60.83107017701673, 70.52920495310138, 2.6607113692068287, 0.16774826562933384, 0.18466402325899373, 0.7334093100601627, 1.6302146329995126, 0.9225086146785367, 0.19938708403177802, 0.23392873215338877, 2.3561736460654967, 31.193376395010183, 50.75001793522989, 16.116920978792255, 46.361905528653054, 46.64427695735809, 2.843285933617623, 0.2245856617246905, 0.19729171098480303, 0.03251202457073716, 0.07501970390759169, 0.0905554460722112, 0.018169134930377046, 0.03024349267023706, 0.024932002077900597, 0.02025795601037962, 0.0846166328917588, 0.09428562776696298, 0.05148436438532607, 0.024620137260025068, 0.06937721353625098, 0.07134431282118445, 0.05411979111452257, 0.032585680094217105, 0.09866601126568933, 0.00837795956495909, 0.024517437428115837, 0.03704902325426379, 0.053961701210468054, 0.06819730789791192, 0.021997146053059448, 0.05166456741731494, 0.027788960367381096, 0.06251213876830955, 0.04146445910596559, 0.030387812143852635, 0.04693633786612942, 0.013528222165581201, 0.04269024575008981, 0.012940753386506151, 0.03734220127244631, 0.03773953277437437, 0.015652660588403384, 0.007392323290508602, 0.07314002291569788, 0.03269688541730566, 0.06878883502776585, 0.04931069332205, 0.03523260197271744, 0.057138284788497036, 0.03229925514108712, 0.05617289142983575, 0.12821343261748552, 0.009468322931488436, 0.039535901704502684, 0.02093847957439721, 0.10052746702586451, 0.0393442073536496, 0.03416576325112293, 0.028591642396584637, 0.02831520339954765, 0.041580165195609295, 0.06004291864472532, 0.24624592444348722, 27.66011122734316, 65.62751700801235, 37.47133185786586, 37.993893546442834, 82.44531062341507, 35.106197557141705, 0.5393898823568898, 0.2749554830933771, 0.1421503722667694, 0.7435118034482003, 0.4434213432813845, 3.369988419355885, 7.426082732216005, 2.0067125270443578, 0.6323303210158503, 2.2604808067121813, 73.86344709704, 73.31540569182366, 74.07458043867543, 74.99351332264563, 82.78860430563651, 78.37407865831929, 79.74191896377071, 77.57521737006404, 75.9086807312504, 77.56100270055956, 66.77682245931318, 61.41953552922895, 71.95496297651722, 73.30044577198645, 76.25403758018248, 70.78607313094601, 76.6591085926179, 74.47970636429326, 70.43910026550293, 67.01618902144894, 62.74921509527392, 62.26105651547832, 61.44057120046308, 59.69821514621858, 57.027332090562396, 53.982200007284845, 52.47266800172868, 54.75776241671655, 52.02199943604008, 55.56415465570266, 53.99224911966632, 56.90755467261038, 60.98519579056771, 60.26113410149852, 64.47793306842928, 63.51382624718451, 63.82682354219499, 65.14324941942769, 68.5833171106154, 65.50275033520114, 72.18168381721743, 52.644408979723536, 48.36280461280577, 73.5990793474259, 64.33824962185275, 69.95068673164614, 62.49372366935977, 61.59347303452031, 59.385676768518266, 58.88234253852599, 54.68153899715793, 55.93342619557535, 52.85526383307673, 53.83218503767445, 51.763201452070675, 50.7549758111277, 49.189459816102065, 49.864095718629905, 49.504590880486276, 50.53427188627182, 48.2857104270689, 50.561904984135786, 49.07111014089277, 49.525501035874896, 47.83921918561382, 50.71512845254714, 51.70179674702307, 61.36172763762936, 61.00458798869964, 65.76743971916937, 63.98136492698424, 66.99937774289039, 63.849769407703036, 69.59087987099925, 66.97891081533125, 65.28738867851996, 63.35343268609817, 68.35706695433586, 63.14391143860356, 65.18196321302845, 59.42066431045533, 60.090365871306396, 55.77935941757695, 63.82801594272737, 62.46329784393311, 72.31236150187831, 61.85480879199121, 73.50920215729745, 3.988480005533465, 0.18611419705613969, 0.403420583254868, 0.43781213943035374, 0.9412721304162857, 0.9014630149449072, 0.44724357044023855, 0.6968409303695925, 6.458452151667688, 36.00125497387302, 67.26251386827039, 22.14525680388174, 41.2587607291437, 59.537911799646196, 3.0618063240282, 0.07914134887077155, 0.08222163519671849, 0.05069346287317815, 0.04442998163041569, 0.06650650588374946, 0.030207120730812033, 0.05182563740339491, 0.07235033948334955, 0.028390935021302396, 0.02546127690302749, 0.06639127859905844, 0.042156880015447255, 0.024957646871165886, 0.03246420536250357, 0.06649441701630432, 0.02078216699432702, 0.062440697238930774, 0.08453286883811797, 0.0502610215616803, 0.026934529098892407, 0.01994146785188106, 0.03614939471346237, 0.04385698616745011, 0.026469203463244825, 0.03357605174964955, 0.16352234077790093, 0.14940614421521464, 0.16964840882968518, 0.12119241299167757, 0.18133452853127835, 0.17651275581409856, 0.1729478422672518, 0.1479902298700425, 0.15029019435807583, 0.1494753066330187, 0.1230106920364403, 0.12459750527576094, 0.2685374436118911, 0.22863250586294362, 0.2721457177352521, 0.18673851274915282, 0.19537197125534858, 0.14903610842602869, 0.21374492004754084, 0.14202523946521745, 0.3240986444777058, 0.14374856957264487, 0.11135034353261995, 0.11491002469894387, 0.23743572945315994, 0.12065825052559377, 0.22100328137317013, 0.10833839224951883, 0.16964332200586799, 0.4186798596093732, 0.23366695990966213, 0.6631592925517791, 33.68469138299265, 75.74252128601074, 64.07996546837592, 44.110700391954, 73.24983150728288, 53.22485308493338, 0.41990636637614626, 0.548530230599065, 0.5712470664612709, 1.9500296202398117, 12.38016716895565, 25.44302482758799, 17.455157195368123, 3.447617518325006, 0.5580569935902473, 1.5599215919933014, 67.36924940539946, 79.46012804585119, 78.02424246265043, 76.21449224410519, 80.63316775906472, 84.66860417396792, 81.70452394793111, 80.4082198296824, 77.85632579557358, 83.06165618281211, 67.80260070677727, 66.11335354466593, 76.2811803817749, 76.769805723621, 79.0125620749689, 71.06222368055775, 77.33531736558484, 75.94297793603714, 72.78074741363525, 72.69120754734163, 67.22300775589483, 65.38101565453314, 62.75791098994594, 63.78485418135121, 59.85541982035483, 59.611526843040224, 58.08985510180074, 57.01734965847385, 55.55536854651667, 60.051895264656316, 56.51999312062418, 60.014103228046054, 65.3780189637215, 61.3572875145943, 66.8936934009675, 66.4359135781565, 66.80384758980044, 69.11440603194698, 70.0623958341537, 68.3321834379627, 73.61285471147107, 53.59212813838836, 48.86054162056216, 74.89494416021532, 66.59264364550191, 73.54827680895406, 65.75557847176829, 64.45878797961821, 62.13621531763385, 62.67889876519481, 60.29661586207729, 59.88592801555511, 57.542174554640255, 57.12570513448408, 56.305631668336936, 55.08225617870208, 49.99243174829791, 51.98925156747141, 52.09861117024576, 53.23112495483891, 51.52677274519398, 53.87037323367212, 52.04674566945722, 54.03762309781967, 50.50240655099192, 52.48652573554747, 52.83061565891389, 62.91670814637215, 62.972786272725756, 69.96429735614409, 66.90127926488077, 71.22029519850209, 67.17296615723642, 72.88798501414638, 68.0243872058007, 69.79598060730966, 64.96847644928964, 71.87346396907684, 64.79378192655503, 70.25539213611235, 61.819982067231216, 63.40165038262645, 59.26145530516102, 67.41039506850704, 64.42576554513747, 76.87494093371977, 63.22659107946581, 74.93887470614526, 3.9264087427046994, 0.39793710975397023, 0.27905616789094867, 3.931806414358078, 6.52684897184372, 2.6643358843941845, 0.46397756604898366, 0.5631793026001223, 5.364246685658732, 50.07910043962541, 64.0730817087235, 28.92436173654372, 57.5594957413212, 66.05785200672766, 5.557556777231155, 0.6009897253205699, 0.3211275103592104, 0.21084480227962618, 0.2622835614508198, 0.18407565241138782, 0.20146823848687834, 0.13685644424009707, 0.20640743716109186, 0.11152129605292313, 0.21199580342058214, 0.20836692153205796, 0.18431382914704664, 0.17169450710137046, 0.19789339644053291, 0.13749755258041044, 0.18387718967372374, 0.12110014536207724, 0.3254823218430242, 0.12475005636412291, 0.0992482917142972, 0.14320864612537046, 0.08704359943587935, 0.12200766077805912, 0.10495914777200069, 0.10259283240884544], [0.0114543761892785, 0.045001697726547725, 0.06311725246750059, 0.035631132402247, 0.030953252064665, 0.04187754903649611, 0.06864114093684381, 0.006578794413907153, 0.008476665205953103, 0.03299422712335664, 0.03448783044493006, 0.11932787755804679, 0.0179806504879267, 0.04901541622295495, 0.05656503268607682, 0.025317867158821998, 0.04261030830563076, 0.047872244500585144, 0.02986031081227045, 0.05845844197357374, 0.029690629997921568, 0.05346029666402648, 0.07139165705490498, 0.0501615833491087, 0.06593904923647642, 0.029918278770280943, 0.05235738669251723, 0.023062577088093086, 0.03145420461923125, 0.027430795110581864, 0.05809529714526669, 0.010208690411321098, 0.2071904862720159, 36.76343425627678, 56.971493228789306, 47.84134118787704, 30.940242313569595, 67.68993454594766, 14.245545421877216, 0.2052072531753971, 0.13037368565076782, 0.06633152374096456, 0.1786508612454899, 3.728116260420892, 7.761118354335909, 1.5450992002602548, 0.2749004473368968, 0.006818255304449028, 7.316503967008284, 81.19983257785921, 60.616924455088956, 79.54475710468908, 72.67016010899698, 77.30224394029187, 76.66950287357454, 79.22182052366196, 72.77261241789788, 76.49479266135924, 63.494383058240345, 67.60150863278297, 73.59550999056908, 77.3834526923395, 72.7353734354819, 72.59650584190123, 74.21311855316162, 71.24648878651281, 65.4128456884815, 60.076072754398474, 61.3557146441552, 60.316502278850926, 62.63866309196719, 56.48143229946014, 54.9675464630127, 50.576794301309896, 53.44667488528837, 49.79055912263932, 52.33271783398044, 51.77697681611585, 54.47865439999489, 55.75827667790075, 64.14693601669805, 61.72438213902136, 63.9259575259301, 60.90717984784035, 64.65650681526431, 62.57889793765161, 69.25095158238565, 64.71729963056504, 70.04322328875142, 42.74653142498386, 46.242951808437226, 76.95643994116014, 65.69226357244676, 68.80094589725618, 59.612644718539336, 64.03649776212632, 64.76534474280574, 66.73373130060011, 65.78387052782121, 67.68558071505639, 65.41295943721649, 57.60831356048585, 52.27545122946463, 47.68692924130348, 47.78216046671714, 48.337795580587084, 46.04373854975547, 48.506732063908736, 48.45477634860624, 50.512789064838046, 53.22473933619838, 54.4811176484631, 51.95265193139353, 49.099861114255845, 48.083759354006865, 51.78989710346345, 56.72253647158223, 59.41043084667575, 63.33493478836552, 66.0387892876902, 68.45086651463663, 67.2358339063583, 69.15272758853051, 64.68506167011877, 62.62786088451263, 62.31311029003513, 67.32287130048199, 61.664899395358184, 63.22364145709623, 59.40160551378804, 60.78959895718483, 59.62690645648588, 68.35568628003521, 62.004376611401966, 76.92658285940848, 15.448837395637268, 0.11186186043966202, 0.14989035774863538, 2.17405996014995, 2.6149216198152114, 0.350940925099196, 0.20455384146301978, 0.44293947397701205, 4.4509061209617125, 31.87185229793672, 63.712741405733176, 18.129163557483306, 33.94653312621578, 54.65844800395351, 15.339923962470024, 0.542929882724439, 0.1630281068144306, 0.015451268522038817, 0.09154064280371513, 0.08098971984920003, 0.023872738050657417, 0.011978004946403447, 0.07252852387365795, 0.0846360149162431, 0.054212591175230286, 0.018851544985908176, 0.029952825505226374, 0.08595163303036844, 0.05064860842521152, 0.017606429943454363, 0.047395381580797896, 0.02770772057345077, 0.0664896519494153, 0.04014533230914705, 0.02931214234371099, 0.014542103144190004, 0.020537635559336315, 0.030515693285832965, 0.0948197749112883, 0.01687270731875493, 0.037230160913520285, 0.03416664808267548, 0.07072824023423657, 0.08938519314171807, 0.08530923766234229, 0.009516926422234505, 0.030045449365711505, 0.030872169318759156, 0.012105476231344286, 0.08932088772135396, 0.02883157921924947, 0.040158524343203154, 0.04522002129364879, 0.016427648539144187, 0.06023730196419263, 0.03765392244883603, 0.03037159597771543, 0.051283519114217455, 0.0325952715150291, 0.04773373580387524, 0.030325098271151225, 0.04593898331926716, 0.10744330277966876, 0.07856301377497374, 0.08057721214549196, 0.020247433792739626, 0.09533180509723964, 0.11403024166582093, 0.0728769559833792, 0.05025803381877561, 0.0733419636925382, 0.05047074962227095, 0.033591576521435094, 1.1719063933818572, 49.733096399614894, 64.94940588551184, 31.981986568820094, 53.13905908215431, 78.52367001195108, 15.314841385810608, 0.3540391378825711, 0.20979256519386846, 0.42139067705119815, 0.22902357842653032, 0.2796620821520206, 1.9985736089368022, 2.2315476882842282, 0.40108027657674206, 0.15315954603495138, 11.576436258131459, 90.27023515393658, 64.062667815916, 83.6845285661759, 70.5655574798584, 83.45891383386429, 78.00553275692847, 82.1301560248098, 76.27619112691572, 77.91946811060753, 67.56561110096594, 69.13777551343365, 75.10786610264933, 80.1360857871271, 74.36349438082787, 73.32143829714867, 76.60681555348059, 73.03172419148108, 67.45916581922963, 64.55160694737589, 63.63962450335103, 63.44854231803649, 63.24081359371063, 62.59141814324164, 55.978647201291984, 53.072967144750784, 54.661789863340324, 52.03782619968538, 54.096674380763886, 53.212827097985056, 55.875673217158166, 56.27999897926085, 61.95512733151836, 60.90010781441966, 63.85243269705004, 64.63809128730529, 67.73636756404754, 64.97126525448215, 70.62551483031243, 64.90045078339116, 71.75070947216403, 44.342755656088556, 46.26294020683535, 75.85883525110061, 66.05313731778052, 70.93065954023793, 61.562776565551765, 64.47536391596641, 65.3298326461546, 68.38952848988195, 67.13821395750969, 68.15742615730532, 65.18218286575811, 59.28755475628761, 53.705010029577444, 51.247966750975586, 48.29185678112892, 49.642532794706284, 47.79440218402494, 49.418463476242565, 49.36094191766555, 50.74587198995775, 52.147703555322465, 55.05453678869433, 52.6412122480331, 50.81527048541654, 51.593727604035415, 54.707285434969016, 58.60294426641157, 61.61953718431535, 64.4317118583187, 68.2856955066804, 68.60452144376694, 70.5836945195352, 68.62749084349602, 66.55676180316557, 64.49341858586958, 64.12541397156255, 69.2998400042134, 63.60095777819234, 64.04862573069911, 61.51698289378997, 64.89208436781361, 61.27201518704815, 69.8606526467108, 64.60357050741872, 78.94389706273233, 20.161702440631007, 0.12049711925247986, 0.31820160607176445, 0.8451331214558694, 0.36040204967702594, 0.927959728625513, 0.5057899707988386, 0.785013605510035, 8.149913982037576, 34.904219027488466, 71.48674964904785, 30.307320817824337, 23.413478712881766, 67.05033717616912, 19.461033767269505, 0.4285879811692623, 0.04216395866786761, 0.08135007228702307, 0.06802944271194358, 0.10628917599998175, 0.03655430282496157, 0.0806315890663574, 0.004169140499265444, 0.0321901680511092, 0.030950775685449763, 0.029260483119756948, 0.02475864595673498, 0.029752731000283555, 0.0346884650418595, 0.056586900665875406, 0.04148861385821816, 0.021682912108278083, 0.042586578732176174, 0.07948419619952479, 0.011047414004532321, 0.04622730050957011, 0.05052462475554598, 0.020181383607127977, 0.08577387764929764, 0.013526798199651944, 0.052180136929476456, 0.13009436999357518, 0.14722860057748136, 0.2013650157999608, 0.20396409165715018, 0.12023995119717815, 0.1607962628646243, 0.19700514813584669, 0.16386502722819007, 0.10973246542796974, 0.11622322963610773, 0.11810364607240885, 0.15156634362234225, 0.09072596192239754, 0.13049229138320492, 0.10403755932084977, 0.08159574902346058, 0.16428347977419056, 0.14260170530648003, 0.1392381043443757, 0.12021637867174803, 0.14362276261371953, 0.24604689480075914, 0.11957750730817357, 0.1436181967296908, 0.21740369468687043, 0.19822267635214716, 0.16934468561122495, 0.17461713253250047, 0.18013705649683553, 0.17988599416229034, 0.18117266947463637, 0.10952516203565944, 0.9391707205964673, 60.45424415219215, 77.61207980494346, 66.02465306558918, 44.59369713260282, 87.26031811006608, 26.357876485393895, 0.5298137220163499, 0.31590481318773767, 0.6442646838484273, 0.9859525844935448, 8.08321358696107, 17.818755026786558, 4.079908002768794, 0.7155918822653833, 0.17832820033354146, 9.467586682688806, 89.20788472698581, 70.0705857430735, 87.72075729985391, 75.97751832777455, 81.82636845496394, 82.36615719333773, 85.75060567548199, 79.56469843464514, 80.65847489141649, 70.15726227914134, 72.84188931988132, 78.6077420942245, 81.29232206652242, 76.03337287902832, 72.84626668499362, 79.61509304661905, 77.71893301317769, 70.27732603011593, 65.92446788664788, 68.20042317913425, 68.37437245153612, 70.38181012676608, 65.7129030842935, 60.54570990224039, 56.700084824715894, 56.919439454232496, 55.49314798847322, 56.4596043094512, 53.45852436557893, 57.93614918185819, 60.93871178165559, 66.33868586632514, 67.90466862340128, 70.76195839912661, 69.42564610512026, 71.15146544671828, 68.49601299531999, 73.35273096638342, 68.99729190334197, 75.15548367654124, 47.322854841909106, 49.21901487535047, 76.97439655180901, 69.75246583261799, 72.75923713561028, 65.71949266618299, 67.5141574490455, 72.72153531351398, 72.08376576823574, 73.1475047142275, 73.95615623843285, 70.89222815728957, 63.73163154048305, 58.38520173103579, 54.37904188709875, 54.00624413644114, 53.76575185406593, 50.29018279044859, 52.41098088602866, 53.04315320907101, 54.10007507570329, 57.57525974704374, 58.19416269179314, 58.52181788413756, 55.089720449139996, 55.327765172527684, 57.741317210658906, 61.683973881506155, 63.597682599098455, 69.93229081553798, 70.9928212627288, 70.67259111712056, 72.89947755875127, 74.48079678320116, 69.40717174160865, 66.18071633000528, 67.14013591889413, 70.59839556294104, 66.34192574408748, 67.63622945354831, 65.35960735813265, 67.29751709968814, 64.69658167131486, 73.21436543618479, 66.97822047818092, 82.81104026302215, 19.09452945955338, 0.14651837578463942, 0.6461248679026481, 6.010868039823348, 10.466526112248822, 1.2849009301393264, 0.49283517885112, 0.6160157125803732, 7.350164767234557, 52.09024867703838, 74.56520618930941, 30.698634116880356, 47.52320166557066, 73.57240723025414, 27.569692750130933, 0.8974642811282989, 0.3194952527842214, 0.1480582584777186, 0.3270574292588619, 0.28527208273449256, 0.17389570753420555, 0.1726135214970958, 0.10751612709775087, 0.27342799570291276, 0.18205731716607848, 0.13103155599486443, 0.11194069854794972, 0.19394977498919735, 0.28148371666189165, 0.16568350545581312, 0.2722636646320743, 0.11532339042112713, 0.25719207981901787, 0.1497180339309477, 0.138057516887784, 0.1408029921473034, 0.24442439718592554, 0.17665360873985678, 0.21742178968364195, 0.11166820107328315, 0.2294169952191653], [0.04363880815705465, 0.07009784180310465, 0.013935604741075828, 0.055795792309987935, 0.036143718001943444, 0.012987782566567824, 0.012602108050017588, 0.025955937960515582, 0.06300216307863593, 0.07377147088728606, 0.066639828165212, 0.029260310749973983, 0.11640250953214785, 0.08190226846284444, 0.014656978986045767, 0.060868140895881, 0.11417793575674297, 0.04376916567825022, 0.041153346969475674, 0.053862921833511324, 0.0355974666684145, 0.040856579829367905, 0.029591883179701628, 0.03649827881505893, 0.013308515809776803, 0.04474954371671042, 0.06769663113499842, 0.08924281570099055, 0.04416172445241002, 0.1618701495951222, 0.1367753921377082, 0.27896889515461465, 0.7069404206929669, 9.829998977722662, 48.039444415800034, 52.24939100203976, 46.6323451072939, 46.32200717926026, 70.38141004500851, 6.085954952624537, 0.5248280218051327, 0.2663750531933, 0.2647511919419612, 0.063903515317267, 0.7868536261300888, 3.8194785579558346, 0.9367571146257463, 0.09609804623910496, 0.0719558731502583, 17.38533704511581, 90.9147511759112, 58.38055764475177, 81.03117066044962, 72.65490993376702, 77.03167100106516, 77.06943558108422, 83.19849983338388, 71.64729226020076, 72.0659189839517, 70.1041926107099, 78.99196963156425, 76.78278092415103, 75.879239420737, 71.91388007133239, 75.49972657234439, 71.75577717442667, 70.56039564071163, 64.35966184062343, 62.275761481254335, 57.47607085012621, 56.867307232272246, 55.77333465699227, 52.94699630429668, 50.526376155114946, 52.54942486363073, 51.01585657365861, 53.033661073254, 51.02485841320407, 54.927573588586625, 62.095626631090724, 70.63459119489117, 67.64803578776699, 68.55421312393682, 63.44379625012798, 67.03095282277754, 65.48222457208942, 73.7835091929282, 64.31975172412011, 71.20901446188651, 43.052931293364495, 43.63907460243472, 76.92008741440313, 61.908251085589015, 70.49959890304073, 67.70422766285559, 66.75719491897091, 68.44295901636924, 72.71842095159715, 70.41565233661284, 72.41650827469365, 67.94322552219515, 60.81504337249264, 49.95245887387184, 49.88501371875886, 49.21877561076995, 51.11692428588868, 49.16914978334981, 50.558131664030014, 50.476565976296705, 61.925293783987726, 66.3993884671119, 69.21342234457694, 65.0600794822939, 57.733864707331506, 51.6965917618044, 52.566773506902884, 53.383367830707186, 60.481194757646136, 61.02895375221007, 64.11214851563977, 64.25795870442545, 69.90667773831275, 66.82905274052774, 66.66898081379553, 63.73791909986927, 62.67950673257152, 69.22463247852941, 68.47837801902526, 61.06015620693084, 62.23929128339214, 64.22525398192867, 68.93139608444707, 58.60662737200337, 73.80984398626512, 28.102531048559374, 0.08945522123887654, 0.034423881255450754, 0.2521213744917224, 0.9505435103370298, 0.7042193989599905, 0.09720992326976792, 0.6056564878071509, 6.474398057306967, 21.443538896499142, 64.28358354876119, 16.203089567922778, 23.63876396609891, 52.70721004855249, 39.880875233680975, 0.22665393058090444, 0.03509868597311359, 0.12280635340439698, 0.04399602346482777, 0.050745208282023675, 0.020709470995972236, 0.05639783782704223, 0.026289159394500237, 0.04807782036462619, 0.06674100539737171, 0.049481841194773876, 0.03879137149441146, 0.014118196052168647, 0.02401325006728932, 0.03974973216592785, 0.02793729031128028, 0.031250088152685956, 0.0055281378632982174, 0.09488152159798531, 0.06948570690808759, 0.05452300234126949, 0.025451340742649573, 0.016766644360858108, 0.0118935571592902, 0.03876116081711747, 0.046556798756242766, 0.10754663271889572, 0.03389057297740252, 0.023269342303636576, 0.07034842150225755, 0.05584283010853876, 0.07875484219121356, 0.02322374091994378, 0.01510261233159972, 0.024121479138792045, 0.014752798390785053, 0.03654543918767764, 0.011034553303503463, 0.032947177833486954, 0.037187118263494585, 0.03561920441326595, 0.022188288820607048, 0.09081868920475246, 0.03950435037334119, 0.054019368478968266, 0.03772020437604478, 0.09731506883737542, 0.048136322668963866, 0.03138238770676957, 0.06564769067711408, 0.04682965629223374, 0.07545739292137085, 0.07286721134498235, 0.1152927469041559, 0.07685177253499147, 0.10877143110959761, 0.1211692235102096, 0.16059413822668214, 0.2973452300554322, 1.0200708311411644, 16.510532786769254, 64.24180638405585, 48.28706364477835, 33.68364803252682, 75.05576918202063, 63.37881042111305, 10.89110307155117, 0.21069576753483665, 0.23011582062369396, 0.4704608149345844, 0.25471599171719245, 0.6944746992761089, 1.7848920750041164, 1.646178434452703, 0.38071441133656814, 0.27669686223230056, 24.399293891845215, 93.88244782724689, 63.58756680642406, 87.74494263433641, 71.74423756137972, 79.8097602782711, 79.83877012806555, 83.6474778575282, 73.84017175243747, 73.45348881136987, 72.32552497617661, 81.21101917759066, 77.6526528020059, 74.78116404625678, 69.69745066858107, 78.43118836802822, 75.12776036416331, 74.86001937620102, 64.37815973835608, 64.01248501193139, 59.82959101277014, 60.46681534859442, 57.989505183312204, 57.359615679710146, 52.38195142438335, 54.194961132541785, 53.458963671038234, 54.703759224184104, 54.66846181500343, 57.08897606019051, 65.21109073392807, 72.96420451133483, 70.0182613249748, 68.78210283094838, 64.32705517738097, 68.35112848589498, 66.977812551683, 73.51213609018635, 65.83008781556161, 71.8958136343187, 45.09945146499142, 46.14420613934917, 74.2033753856536, 64.82327422788067, 69.7761804826798, 69.05939086791008, 67.76322795498756, 67.32613471246535, 72.49187269518453, 67.88858690569478, 73.09673355471703, 68.44907791383805, 62.276259622266224, 51.142443226229766, 51.196446418762214, 50.84070705598401, 51.96104972593246, 50.01020792991885, 53.41086756798529, 53.655729370732466, 61.86586987587714, 65.59088599297309, 69.71496012903029, 64.83822630297753, 58.06139830620059, 53.78066862783125, 54.83475462082894, 55.72479532610986, 63.30874904509514, 64.58081291567895, 66.78388272562336, 66.48493536057012, 71.1754781969132, 67.93906780981249, 68.0680118068572, 64.96032576407156, 66.45502336563604, 68.5719108581543, 70.57593607133435, 64.17159988034156, 64.97010031054097, 63.78659571370771, 71.81072958054082, 62.69116401672364, 75.59981761440154, 33.261801042864406, 0.06557177136381788, 0.14205815060244453, 0.6072128720341191, 0.7214472454882438, 0.4800242275720643, 0.6805691002838073, 0.9089518614834355, 11.616709193875714, 29.09738729077001, 67.47010138727003, 36.703884832320675, 16.240596252103007, 54.89317047980524, 49.55546402162122, 1.0964918400972121, 0.1115350549920432, 0.15324058281558176, 0.047091064644196344, 0.05876844711301308, 0.048573065564156546, 0.00835949493076412, 0.059138904250557386, 0.0691007936914121, 0.08986314773679742, 0.010116912120382392, 0.024414182182461507, 0.048559459842621326, 0.02914047736163822, 0.08107509268748184, 0.06792017559130346, 0.03554255348600207, 0.05712876231559823, 0.04903282940147385, 0.07889967111329879, 0.05233682106218992, 0.028720697568308924, 0.06636181485749061, 0.045290516704441085, 0.05802440336875378, 0.027469959440490896, 0.06590226935523172, 0.21167435292755404, 0.23476136247477225, 0.14094111780005117, 0.1524887594484514, 0.16371790770321124, 0.09056532094555517, 0.16531549213874727, 0.11142371943400753, 0.21010849985384175, 0.15793052712275138, 0.13937334950652816, 0.08816535900076551, 0.19471220101319975, 0.15926137506481142, 0.174314190723723, 0.18935105643205105, 0.21984552333672203, 0.21459869439563445, 0.11510980510783773, 0.24843047012484845, 0.14445557679620483, 0.12384935146978787, 0.20964097171541185, 0.10640146150704353, 0.1290514485369767, 0.15918916361706872, 0.1782571533394437, 0.24768866718776766, 0.25905244773434055, 0.317289624363184, 0.35352944426478883, 0.6240828022841485, 1.2155460710487058, 17.823457948623165, 77.99220454308295, 66.677641407136, 59.95924103644587, 61.46603130525159, 86.29054346392232, 13.108060033090654, 0.5929432280601994, 0.4989162009329566, 0.7481458999456898, 0.4900102143085772, 5.262996092919381, 9.701622743760387, 4.231894698835188, 0.338333630633931, 0.3264311370590041, 21.601169147799094, 96.79269744503884, 72.19250171415268, 88.40114731942454, 73.45472828034433, 81.96757378116732, 83.7003827864124, 89.12211818079795, 77.03873126737534, 78.94406964701992, 73.92425952419158, 85.3949486824774, 79.18629169464111, 75.86317339251119, 70.84981949098649, 80.60603280221262, 78.15728141415504, 78.34331943142799, 70.05271542456843, 67.52052737820533, 62.16251088726906, 61.444113100728686, 61.01780245381018, 58.215010089258996, 55.737739147678504, 59.418765883291925, 57.05036032584406, 57.46260535332465, 57.95519228904479, 61.571617587920166, 70.08629091324346, 77.1111225312756, 74.20945505942069, 72.06963739087506, 68.72754266185146, 71.15596048293575, 71.73619670252647, 77.18877761594712, 70.98353309016075, 72.4243059465962, 47.83795618241834, 47.17889208947459, 76.14697256395894, 67.1560372075727, 72.06085128168907, 72.98698563729563, 70.25518032812303, 72.87178562533471, 75.46037735477572, 71.93605715228666, 77.52286157300396, 71.40227748501685, 64.69203956665532, 53.49864236770138, 52.73179546479256, 52.401045522382184, 54.94796206874233, 54.6432605866463, 54.28162982386928, 58.55796252527545, 69.55211900895642, 70.9461921261203, 74.13924463333623, 71.91411541354272, 62.86163414678266, 55.43703848315824, 57.701983682570926, 58.47400419173702, 65.0130267297068, 66.51753025670206, 67.94681056853264, 68.71645019900414, 74.72282271231376, 71.3678155406829, 70.07333140219413, 67.15908096682641, 66.93564707233061, 70.07668110632127, 74.75306418634231, 65.06229954381143, 70.19447772733628, 69.2692219826483, 76.38331890106201, 62.67322701792564, 78.98221077457552, 29.198749180763002, 0.2156023615069928, 0.24891010245248196, 2.2267837245618147, 5.829067162929043, 1.6834340869419038, 0.5963116247327097, 0.8133207381733003, 11.200371173120315, 38.06378233817316, 80.24886177432153, 25.79497321959465, 37.23706045458394, 68.12782795198503, 59.12183069413709, 1.5777148114096735, 0.2149850325358491, 0.2347079814682084, 0.18772874267831927, 0.21919232612896353, 0.09465399348447401, 0.15559660961791394, 0.21078618123166024, 0.1290352840817744, 0.22949394109028004, 0.12978217384267238, 0.07678601154757124, 0.17475913459014508, 0.11444470289373591, 0.21147852553234947, 0.24888840684246635, 0.18392531531712702, 0.21403600281525045, 0.20157006689377371, 0.12074825053493823, 0.12529637664556503, 0.1369323329098763, 0.19965322297667304, 0.10825020020767566, 0.16140075220215708, 0.14680408061512057, 0.19599879971675335], [0.06923608481884003, 0.027328913077531804, 0.015350411131587482, 0.05442297041055657, 0.07268322766908715, 0.03927438226979106, 0.09207805348259789, 0.056886222709210656, 0.031152088270192186, 0.028948087785993854, 0.0774055008866614, 0.009703294546794026, 0.054734208951553995, 0.048962475716947555, 0.023160391194265217, 0.04116761152662578, 0.08464753687862428, 0.03409335645095956, 0.06281938599122149, 0.028630636271930514, 0.1037359428441813, 0.07640491344875867, 0.052579732221220775, 0.02566858604099722, 0.04289647278886649, 0.017595153129208955, 0.11953397819231595, 0.03312423990498627, 0.09076066570536745, 0.049044213468028654, 0.04681073775094363, 0.1344576390880731, 0.032465469407578634, 0.16874614111598463, 25.54474953682192, 53.66804169070337, 40.50148048708516, 21.083579063415527, 66.50151914165866, 71.99713630060997, 9.27014143236222, 0.7156500436605946, 0.10519669631556158, 0.10621622144695252, 0.1583854607757061, 0.6843117155855702, 1.138621527821787, 0.29238830410665084, 0.12490153492939089, 0.21136102296652334, 25.29071919379696, 92.73062029192525, 59.03263207404845, 76.37036723475303, 73.54508399963379, 78.26362471426688, 77.41250961057602, 81.6610013284991, 72.63947148476878, 77.5207591825916, 75.84599341115644, 78.78961455437445, 73.5000708795363, 78.35627109773698, 76.04235510672294, 70.97253476419758, 64.85390009418612, 57.53291383866341, 58.05833101272584, 61.1102331069208, 57.845307088667354, 55.50422476183984, 53.46944032176849, 53.94778120902277, 56.40114138203283, 53.924011645778535, 53.259126755499075, 52.22973992747646, 58.234833748109885, 70.48515673606627, 73.28507792565131, 69.30212282365369, 72.53519135136759, 66.31597534302743, 72.73852702110045, 69.61732449070101, 73.89262168638169, 64.65400434309437, 64.45088832609116, 33.64285538273473, 38.999291158491566, 78.75976531736313, 65.76704355978197, 78.69426173548545, 60.72773925719723, 66.12175526157503, 70.43266757842034, 71.1041695071805, 71.76508888121575, 70.13536760883947, 69.07829669214064, 59.22184721116097, 49.02381812372516, 51.5058429779545, 49.14745123155656, 52.97473922852547, 51.49555852336269, 51.397424744021514, 53.85677045391452, 67.44445693108344, 67.75019784127512, 70.48343089319044, 69.48721162734493, 67.01443179961174, 60.067525909793, 57.87428163713025, 56.03853787145307, 59.46244931990101, 60.45890000558669, 66.84620918766146, 67.97698928463844, 67.45903245864376, 67.12428954339796, 69.1298758599066, 65.83280994046119, 66.76675765745102, 68.41396485605549, 63.89623772713446, 67.44217411164315, 68.63871666692918, 63.50484794186008, 62.86088105170958, 72.99714457604193, 36.019031155493956, 0.1284196405040641, 0.19024832925248533, 0.07199916477885938, 0.4080166817913133, 0.4007532796071422, 0.02840045366376158, 0.12224776039440786, 8.823295216406546, 20.44806488098637, 64.86040730630198, 54.96353387832642, 38.524849107188565, 35.860347747802734, 54.52903332248811, 6.855922591301703, 0.15722911234103865, 0.016862265540346984, 0.17798643318876145, 0.09870302863419057, 0.0651322360781412, 0.043433986889619025, 0.007398163274516382, 0.035348587684453495, 0.042849277942291195, 0.04483377508398506, 0.020764068167115894, 0.05888923619603438, 0.050716977942013935, 0.059081076103593075, 0.013144631408185009, 0.042195245698695226, 0.01684624281141066, 0.019299292734133142, 0.032438208168793115, 0.05034694981370723, 0.06525945263884722, 0.09028909262269737, 0.04943942290640647, 0.017755238692306222, 0.028965225172860008, 0.0531530571019938, 0.042366891528569886, 0.06249005628389217, 0.07639190527580439, 0.036637024999025374, 0.022413838512053894, 0.00801195148303504, 0.0299684728510798, 0.051043660815564856, 0.015966843779859765, 0.03229761571292916, 0.021999722023704843, 0.04947349083639922, 0.08291260820002326, 0.05162049054859146, 0.040907118649732684, 0.06018932570793456, 0.019545507647337455, 0.05728395640729897, 0.01427108038877768, 0.03558877157047391, 0.05778012091233846, 0.04615353007290152, 0.007573933530253389, 0.020502700034769315, 0.05962638514897516, 0.13817259861576942, 0.02077675649836179, 0.05616392054024243, 0.034139846496644526, 0.02978456578397703, 0.07103777806004209, 0.03261640021998075, 0.027645588927571813, 0.025884220639484066, 0.06780908518140355, 41.19926229599984, 66.56397111954229, 37.53878485771918, 29.31080149066064, 95.87667495973649, 53.28413186534759, 15.620624461481649, 0.9364031207176947, 0.13145495746885577, 0.1289901308595173, 0.13763118895792192, 0.6851514705246495, 1.2922833210998967, 1.2955447718981774, 0.5747558104415094, 0.41291734624293547, 36.119585037231445, 93.14319872087049, 62.86413269658243, 81.71250204886161, 75.93331321593254, 80.86355993824621, 81.45693609791418, 82.87338241454094, 74.40695424233714, 80.20659431334465, 80.1142930984497, 78.53979879809965, 75.49782030044064, 78.98615667896887, 76.58463847252631, 74.62303761513003, 67.54294764611029, 62.806379718165246, 62.736279118445616, 65.31925793617003, 60.100246321770456, 57.90312282500729, 55.79207966404577, 56.681932095558416, 56.322129157281694, 55.770377189882346, 54.78049647423529, 54.963443663812455, 57.29649297652706, 71.98627133523264, 70.91999069336923, 70.52802824204969, 72.39834770079582, 70.53893243112873, 73.05789424527076, 69.17804256562265, 75.83325355283677, 64.4068322643157, 67.47400022322132, 36.56309919972574, 40.0841599126016, 80.83088659471082, 64.82973437155447, 78.28211476725917, 65.9713480549474, 68.96723085834135, 71.59336751507175, 74.00860617237707, 73.75751956816643, 73.06817085512223, 71.4801836013794, 62.62882578757502, 51.16054888694517, 54.61320346401584, 52.05415502671273, 53.84443459972259, 53.2645357039667, 52.08959364121961, 56.58565359730875, 67.0466266139861, 70.12206292921498, 71.23735750875166, 72.61070482192501, 68.96017059203118, 61.88094746681952, 57.46365262616066, 56.68237532338789, 63.06695061345255, 62.32575601147067, 68.21029970722815, 69.17428493499756, 71.95923836000505, 69.51989281562068, 71.42759246210899, 66.80658540418072, 68.4483640424667, 69.49461706223028, 66.9249782254619, 65.73049099214616, 71.19312886268862, 68.15384895570817, 64.10888118128624, 74.8504017245385, 43.13309277257612, 0.4249975109292615, 0.1525838462816131, 0.06351579438834902, 0.6313047437898575, 0.3656154925063733, 0.21473403148833783, 0.4323811276305107, 15.216332039525433, 28.29327394885402, 57.3313275460274, 59.248668378399266, 21.088072138447917, 34.566965795332386, 62.73388255027033, 10.754951719314823, 0.41340298469989534, 0.10774033805055004, 0.0947596216874738, 0.06726726949695619, 0.05296668323177484, 0.03448438687971042, 0.049334392251987616, 0.03786435147987739, 0.048569920773227374, 0.0501951763045884, 0.0348644852337818, 0.13244731712245172, 0.038457104350410165, 0.040258031503687945, 0.023860484474308552, 0.106994804265278, 0.04847529742325987, 0.02770848474615524, 0.022987680502175804, 0.026336365732394403, 0.07143219842785789, 0.016463074359982725, 0.057575192392593434, 0.024581842439910098, 0.01544615775797396, 0.06421547015047362, 0.039152003554326874, 0.25910644161124385, 0.12814311340691584, 0.09441824524753517, 0.13959897772198723, 0.11941708083595, 0.11543462638773265, 0.16584861272525403, 0.11356691935009534, 0.16363100268908087, 0.1335633846540605, 0.16017004727355896, 0.1448577269911766, 0.17681111641708883, 0.12757184930265913, 0.10315600662462174, 0.15527929599967696, 0.19247545410067807, 0.1543617065274908, 0.19361505585332073, 0.10537971472067219, 0.2327927616575072, 0.07189069438966052, 0.12624559788814477, 0.2269008866841755, 0.30445520015012834, 0.08040743940059217, 0.22588808780475972, 0.12705184414141601, 0.1212931995189959, 0.2079854097457663, 0.15830154350448042, 0.2668309674387978, 0.15353105271295195, 0.1257106923167744, 49.65593161121492, 81.95066052098429, 57.53947204159152, 33.854569235155665, 80.058485615638, 88.86093539576378, 18.524020717990016, 1.0949197051025208, 0.2287671841200321, 0.21023783081721878, 0.4665275969572606, 5.020706384412704, 3.9979383109077333, 1.4630587831620248, 0.39064367692316737, 0.3086133721855379, 28.220262950466527, 100.27122789813627, 71.9075022974322, 85.73140175111833, 77.23907024629655, 85.00530042955953, 83.23067111353721, 86.74663666755923, 77.63116605820196, 84.3353674488683, 80.48466682434082, 81.14721790436776, 75.86136125749158, 79.33110560140302, 80.40568597855108, 76.89856144689745, 69.45482069446196, 62.739683735755186, 64.7201943397522, 67.32565618330433, 65.1217116848115, 60.555853151506, 61.253654572271536, 61.713697602671964, 61.575453665948686, 59.37992265147548, 58.397321854868245, 56.96229134836505, 60.02926711113223, 76.22097199962985, 73.96905299155944, 74.39322594673403, 77.0974648383356, 73.53275991255238, 77.23029198185091, 72.41405287096578, 80.09593640604328, 63.91184091567994, 71.37320487729966, 40.79150838236655, 41.867681241804554, 82.23559717978202, 69.13909342981154, 81.1923251613494, 65.17253775750437, 72.95595968923261, 75.46280922428255, 75.88213412992417, 77.05342446604084, 76.2510173551498, 74.6251949187248, 64.76749420166016, 55.630697665675996, 59.73126503729052, 54.867600548651914, 58.39301901478922, 58.42051875206732, 56.54095426682503, 60.89636979564544, 70.39345172143751, 69.64789544382404, 75.55950349377048, 75.49771831881615, 74.41268090278872, 66.20319151109265, 62.492637172822036, 59.60445480961954, 66.88150267447195, 65.42172201218145, 72.70437886638027, 72.13260712162142, 72.18613962973319, 69.77322301556988, 72.10793541323754, 69.68144739827802, 69.82377452235069, 69.0011279813705, 68.47422815138295, 72.01744633336222, 73.27336572831678, 68.87660057313981, 67.82662914645287, 78.94289293596822, 40.1805325477354, 0.7974959970001252, 0.3576905580778276, 0.2520551538515476, 3.268540482367239, 1.0071597981356806, 0.29833035783902295, 0.28502356381185595, 15.069646181598788, 36.24096670458394, 80.95902258350004, 66.12305748847224, 47.27706901488766, 49.40861832711005, 73.0433814756332, 13.432046828731416, 0.46728277578949934, 0.16909147823049178, 0.39390748727225494, 0.321397265239108, 0.16950853649647007, 0.17882402775989426, 0.1621254560567679, 0.15963504211075846, 0.15252787589786515, 0.15406530710958666, 0.11173094367428173, 0.14772156283499735, 0.14936342715255677, 0.17410298028299886, 0.14537282918970432, 0.2460796527204014, 0.12290138661140397, 0.12605857284319016, 0.09047151347922702, 0.1700404466640565, 0.14656708365486515, 0.18187457455262063, 0.1584546691587856, 0.11646784151033049, 0.14929743633875925, 0.15827692143859404, 0.11944022435214251], [0.07636284756083643, 0.02194716073121996, 0.039322979057267796, 0.045846776976700754, 0.017448430054730946, 0.045391686275721564, 0.04474302813891442, 0.04305267811662728, 0.015599167541480594, 0.04773896435395845, 0.0597277079378405, 0.024545842053128347, 0.04963286393772691, 0.02321496538277115, 0.016315531571425738, 0.06647652120239313, 0.0472960161465791, 0.03008772592781292, 0.07029659565417998, 0.03260233101525134, 0.04858002547294863, 0.05683830390954691, 0.009765533444982384, 0.0214687024333304, 0.076693621343903, 0.031621499069695996, 0.07366945095840963, 0.0356103177933443, 0.040249198509920994, 0.05941616679211298, 0.030997409372620528, 0.048257613539575576, 0.0687499177612124, 0.09475888624306648, 0.527091168107525, 35.54966465119393, 45.761347509199574, 36.29047878326909, 21.292717879818333, 68.48197875484344, 77.59701790348177, 22.91138787423411, 2.4993499632804625, 0.012851987736329678, 0.01105595971532767, 0.09768259951904898, 1.0776557605112753, 2.6006787582751247, 0.6988703892115624, 0.231301311043001, 0.05183181973294385, 33.2868649882655, 94.6095532755698, 61.386497405267534, 68.57574693618282, 80.70486868581465, 79.8237003818635, 76.69604163016044, 81.42135235571092, 79.15136691062682, 80.78157455690446, 74.71044371204992, 78.46186914751607, 76.50264524644422, 73.98359714015838, 69.98215982990881, 65.5346627389231, 60.90396350429904, 61.80446517082953, 54.816197887543716, 54.98639345169068, 55.04787268177156, 54.413162585227724, 53.501325268899244, 55.50993965518091, 53.32930580262215, 57.608639117210146, 52.847972146926395, 56.19020808127619, 70.27154445648193, 75.01835761531707, 71.68211506259057, 75.84248681222239, 66.43162250518799, 72.2424570206673, 63.950519407949145, 77.1245527267456, 51.00879238497827, 60.99668441280242, 41.97328321395382, 40.211797760378936, 79.1266324443202, 63.74244159267795, 67.22059942060902, 57.236869027537686, 73.99370901046261, 66.87096718818911, 75.58845058564218, 67.77985880451818, 69.89728758412024, 60.270665461017245, 52.285351291779556, 50.24556975210867, 53.27503981128816, 51.72292263277116, 52.98124251827117, 49.753080875642844, 50.790787050800944, 55.35773208064418, 67.06305350026777, 72.02986455732777, 73.12448824605634, 71.53604599737352, 70.01664530846381, 63.86083049158897, 61.38427734375001, 60.82304893001434, 65.75486460039693, 63.140122429017104, 61.65745081440095, 65.24377976694416, 70.05710063442108, 69.57134646754112, 68.16314497301656, 69.21512465323173, 64.91343382866152, 68.66596929488644, 71.83701730543568, 73.0626638474003, 66.54281385483281, 71.35131020699778, 78.55059316081386, 32.8742826369501, 0.9546784852300921, 0.08514124990230607, 0.0882154688118927, 0.11166195745670027, 0.40361103271284415, 0.0233467880471219, 0.10664175264537336, 10.91906859028724, 14.37802641622482, 70.66604860367315, 36.90854234080161, 84.75824602188604, 70.6895749799667, 48.980699508420884, 27.704069229864306, 0.5426288408137138, 0.16682646267356413, 0.0850983183350294, 0.17275771456620387, 0.06429214406037523, 0.0737430949905707, 0.04258239972254923, 0.09355982074574118, 0.01704237855700476, 0.03210278997768558, 0.07075596495621628, 0.061575542654721975, 0.07271505862234101, 0.030290875208353808, 0.07843611897119591, 0.0778026408666084, 0.02638978695857429, 0.06823649329523887, 0.08641217444692889, 0.028469328798594016, 0.008000584653458528, 0.008749392506996951, 0.02726801291799113, 0.07925552661500632, 0.02428423643352524, 0.05862089474835704, 0.011494830419730035, 0.06013754582513244, 0.07504614926273785, 0.0934125480031775, 0.06296011251247217, 0.058067258327238025, 0.02943150458797332, 0.027588639866500616, 0.06440835959848858, 0.04401771141396415, 0.020711526026829116, 0.04083740464862316, 0.028800217494849237, 0.013286334691539168, 0.039702770976169456, 0.055638579576606714, 0.04665684600871417, 0.01452783092616066, 0.05503120591803905, 0.0763262055754181, 0.015205350467905164, 0.015682425019481493, 0.0456559827791587, 0.07727558003558267, 0.046236868947744376, 0.028793707662712664, 0.03511539818118176, 0.07359982888785101, 0.04482275107875467, 0.03844110843455119, 0.019693063842433117, 0.07599311054594095, 0.08081611666467883, 0.07173296454693041, 0.06204568315297366, 0.10440880552895608, 1.7642722975823188, 54.76712903668804, 51.15518700691962, 21.923270263979514, 36.52653878734958, 106.78627690961285, 63.35154210367511, 22.84304253516659, 3.122010538654943, 0.15075344772588822, 0.09035078568323966, 0.17400133573720533, 0.5168302477367464, 0.3625534390730243, 0.6226318317555612, 0.5327165823790335, 0.04662718691472565, 44.900387256376206, 101.21119253097042, 62.3515965861659, 76.02356695359754, 80.79241598806074, 81.87317802060036, 82.54165187958749, 82.82284659724083, 81.22437092565721, 80.24198193703928, 74.64220231579196, 78.4857406923848, 77.99916282776864, 76.49252553139964, 74.99927136205858, 69.92539528877505, 61.6193175315857, 63.72973311331965, 57.3235926320476, 58.932525342510594, 57.96200936840427, 57.9257902022331, 54.07501113030219, 57.2543510313957, 56.01713349742275, 59.384888372113636, 54.369855696155184, 61.15890972075924, 73.95729372578283, 78.21712893824424, 72.57647037506104, 75.87381870515885, 67.70344318882113, 74.95245395168182, 65.78808315338628, 75.64559951905282, 56.440631804927705, 61.261052162416526, 40.62126967214769, 40.51727587176908, 78.80579040896508, 65.26031255722046, 67.31042169755506, 58.89819675876249, 73.13029335391137, 69.3347647882277, 74.86554207340365, 69.70086313063099, 71.49572403200212, 64.45665813261463, 53.822410491205034, 49.13134597962903, 53.38353649262459, 53.96795003644882, 54.847027717098115, 53.94314496747909, 53.20721418626847, 58.74697369913901, 69.74170284886515, 72.9781916833693, 74.27440166473389, 72.260295960211, 70.6715791456161, 65.79167212209394, 63.6322622145376, 64.82944019379156, 65.29559819929062, 65.72268939787342, 64.02312640220889, 68.99030223969491, 69.86224512900077, 72.54476193458804, 68.47829172688147, 69.10520415152274, 65.41081390073224, 67.44104446903353, 70.87835865636026, 75.1383036951865, 66.091411805922, 70.75458434320265, 81.93727739395635, 40.39306225315217, 1.4960182145718606, 0.027821760421859163, 0.11197550958322902, 0.21037021081053445, 0.026139766503606113, 0.1299344261567439, 0.29926921391198713, 19.571305321108913, 17.64803582622159, 58.61537033511747, 60.40584210426577, 84.70743563867386, 66.05360015746086, 52.027879068928385, 38.30856961588706, 0.44484773770936076, 0.12071828883621963, 0.06149463227859909, 0.11443099758077054, 0.042759695450865456, 0.05382058398437597, 0.016973507252611944, 0.11753219044617108, 0.08307527164898573, 0.025123859222437588, 0.03635309749252854, 0.06347268279041014, 0.03972771479898403, 0.05188753347723715, 0.11172751926126019, 0.021375691698443507, 0.03096212144760836, 0.060242093844159, 0.018114183443568407, 0.03303460761784546, 0.04635824408802775, 0.07607558757186898, 0.05294568476177031, 0.057756579030425324, 0.024844162436502597, 0.06905559450387955, 0.02976879969449534, 0.052565291463848085, 0.18050606572820296, 0.2228516523515986, 0.21771028307416748, 0.13546954930549668, 0.11028291492332375, 0.15442248794340319, 0.11286827780666853, 0.14504937154631461, 0.14401645519800726, 0.17159378186108606, 0.1417657195199882, 0.08800713120088463, 0.2410101118467508, 0.1446026503559082, 0.1537652457914045, 0.3481793619932667, 0.1560414921973021, 0.1625549862341535, 0.0940047492904048, 0.10347731156094421, 0.14020809423058264, 0.15511959731098146, 0.11103880621733205, 0.17387205073910375, 0.1462378190650094, 0.24008452441663514, 0.19535029096709144, 0.11470016257296647, 0.14209990239431783, 0.20143471447931183, 0.19950660906972426, 0.14931479589112345, 0.1196162943397799, 0.25685541481981355, 1.3546160344154605, 65.40432237809705, 66.7306875413464, 53.68159347964872, 39.504343386619325, 81.77474221875592, 91.30935730472689, 37.23447561264038, 3.9877146530535916, 0.14532913153450336, 0.17871864470503024, 0.24441172609165793, 5.981834165511593, 5.555823579911263, 1.8614481605829734, 0.4353583904524004, 0.2069406037128741, 36.7898278851663, 104.78885696780299, 72.45534758413993, 79.33096439607682, 81.1879477962371, 86.39333309665804, 86.91100751200031, 85.65352701371717, 83.54714362852036, 82.66708143295781, 73.45101771816131, 80.69935383335238, 83.86857401940131, 81.56769598684004, 75.8409413983745, 72.00261977411085, 64.76138707130187, 68.59939098358154, 58.48064868680893, 59.938440707422075, 60.88723851788429, 59.70383198030534, 58.1509264053837, 62.067722889684866, 58.869994917223536, 65.16486560144733, 59.563528799241595, 65.49023797435146, 78.0907815502536, 82.07993399712348, 75.22290921980336, 78.723569685413, 69.43429100898005, 75.87843925722184, 67.52596378326416, 76.09606804386263, 57.42967705572806, 66.95962844356414, 46.41696776113203, 45.14338201092136, 77.82547243179815, 66.8226828113679, 69.20366348758822, 62.93280947592951, 75.34691103043096, 71.80650911023541, 78.8254963967108, 73.50233016475555, 75.5853440684657, 66.21385251322101, 55.67307103064753, 53.24595935883061, 54.83509194466376, 55.21160417987455, 57.00328011666575, 57.75908162516933, 55.36419222431799, 62.34016287711359, 73.55052040469262, 77.77460713540354, 78.09686906876104, 77.72451062356272, 74.30145817418253, 68.00433604947983, 66.98499833383869, 69.05284050972232, 70.19388152707008, 70.27924014676002, 65.5019070256141, 70.20778240696077, 74.53292508279124, 75.39075528421711, 69.74782174633395, 67.52740721548757, 68.00774851152974, 70.32685772065194, 72.54384409996771, 74.56930898850965, 70.22974767992574, 74.07548258381506, 83.72404252329181, 36.91009559938985, 1.9068151520144556, 0.17028282156154034, 0.2319694010000075, 1.8493081797515194, 1.5452236129391579, 0.25674148222371457, 0.420599767878171, 19.295066518168298, 27.79810413237541, 85.23482184256278, 48.85570926050986, 88.94437205406928, 81.76765057348436, 62.689446018588164, 45.124844889486994, 0.4981756697018301, 0.2823485992848873, 0.22914492675373632, 0.20757749856960392, 0.13433633672614254, 0.17025392472503648, 0.28382319596505934, 0.19005104629022462, 0.1762848446566251, 0.10482662222197942, 0.11726571442258936, 0.18442711822928923, 0.14454217537516548, 0.15478751351756437, 0.25067820273820435, 0.17975195941905822, 0.12680851929490605, 0.16339751441151867, 0.15336568497361677, 0.08704941404322464, 0.20150308016567461, 0.19513106724667936, 0.18476277199243346, 0.23172523345678087, 0.14999149667639888, 0.1465350918231472, 0.16140115056787768, 0.15206302906717026], [0.04002950747587508, 0.009691818549688305, 0.025634190608416835, 0.05071591307979919, 0.00741030433170137, 0.008939021293284192, 0.04579343810497273, 0.026267538478057233, 0.07072601091837691, 0.07604048542317844, 0.03937508835787735, 0.05400046525943664, 0.14557555137622744, 0.04628261588814278, 0.055718769830080776, 0.0577523157511267, 0.07053728515823042, 0.019292825036832405, 0.07630550587970404, 0.018313048377392754, 0.04774669801155406, 0.029046736928003452, 0.04890270936753481, 0.024687313594885414, 0.10009369272137843, 0.03047221396569043, 0.032289223219718666, 0.028146581701754082, 0.020918019281159488, 0.037089158600616845, 0.031446572468285604, 0.012746522327013796, 0.024173758893964753, 0.03680265703869443, 0.04636220476259628, 0.6427257051390987, 40.2222587216285, 62.009032464796505, 40.36259720402379, 18.780127956021218, 58.451019102527255, 93.09208239278486, 44.28963891921505, 6.021275068483045, 0.3662140523233722, 0.12853429322281193, 0.077527561675637, 0.9894050056895903, 1.4738206637482492, 0.8463208641736739, 0.13417984028497051, 0.14763117978169074, 21.760974353359593, 82.90032909762475, 69.77191294393232, 64.82613363573628, 78.84961897327055, 84.56774434735699, 85.0349457033219, 78.32293879601264, 77.76768807441958, 81.201534886514, 82.34591776324858, 76.82324409484863, 74.83029565503521, 67.67011873183712, 61.38171995839765, 58.19749670643961, 57.714178331436656, 61.20884149305282, 61.68284031652636, 57.61034534823511, 53.15926713328208, 56.34837765847483, 58.84635086982482, 61.75827533968034, 59.60677685276155, 54.46915049706736, 52.79826394973263, 60.06580006691718, 75.46338973506805, 71.38176348901564, 75.1824931175478, 71.05466919560587, 75.22246991434406, 64.58078545908775, 67.9607585168654, 54.79301275745515, 86.61620216984903, 38.650717966018185, 33.379558440177675, 86.32402481571322, 60.48605457428963, 72.18551205050561, 72.3766726832236, 74.9282999961607, 70.8576250076294, 72.18247613599225, 65.05990297563615, 60.77538821005053, 52.18134964666059, 52.28336657247236, 50.64823635162846, 53.736706702939934, 52.67569380421793, 56.33167620628112, 54.94198437659971, 57.18699216842652, 56.85550089805358, 64.89194316248741, 70.33413763969176, 73.48448338047152, 73.03722335446265, 75.03691827097248, 71.32771322804113, 66.38947271531629, 59.89959747560563, 64.68863887171592, 66.16673700271114, 70.20324030230123, 67.46232724958851, 69.30016163856753, 72.85139714517902, 72.83064780696746, 68.2961368560791, 70.78847362149146, 67.27930945734825, 64.23965300283125, 59.74599745965774, 84.28783616712018, 65.50221689285772, 17.337097775551584, 0.11496816311151752, 0.19921987768142455, 0.07523010995599531, 0.29780184910182034, 0.30970976657925114, 0.06555784388535446, 0.3959445763499506, 13.114047531158695, 24.551564224304695, 67.00856393383395, 42.36074670668572, 14.686669880344024, 28.10015997579021, 46.02784118344707, 44.048966207811915, 0.2536525850694987, 0.0707010058085284, 0.021564109108200478, 0.050735218495491057, 0.0063035639205707185, 0.06599124280675765, 0.07943230140353404, 0.03594379586678359, 0.015909690747878725, 0.03393445832414493, 0.10863974825629305, 0.050433609679701834, 0.062059357822422063, 0.013395090448489834, 0.03733172118964215, 0.03810639312911419, 0.0850424245600739, 0.04138473233568572, 0.05619830639672376, 0.031419790034452756, 0.051787432598611044, 0.03309926926909435, 0.029620442937518802, 0.015607747726232536, 0.0356285545163818, 0.059616207670901096, 0.0739849029829906, 0.07346868995697269, 0.03686061159016625, 0.030864665487540827, 0.03054482377915373, 0.02604432343955963, 0.017012656260762486, 0.030406926037563436, 0.03763884966892581, 0.09102158759149814, 0.06046246669645752, 0.050776491482411666, 0.019368581556444688, 0.03397987201629627, 0.04056946539710607, 0.08279566487838184, 0.08258852236453565, 0.046374504304220604, 0.015407514367853443, 0.14325522427116671, 0.06419902607317894, 0.05356479871777758, 0.03668120912005825, 0.09294579361355113, 0.01460103062732566, 0.02850143554350061, 0.030019503882935936, 0.04218221454310321, 0.045771524159898686, 0.04907594099941273, 0.026618862569692637, 0.06694191195551427, 0.0348947495372305, 0.06121790216815087, 0.06513585967402305, 0.1360465207647893, 0.045538039712776104, 0.04927978167430528, 3.0084145309463626, 61.780315137678585, 58.91511001894551, 24.131923567864206, 29.943368011905303, 93.91556832098192, 91.55025359122985, 40.001746992911066, 10.82555144063888, 0.8099190013543253, 0.15096847328447527, 0.09018305073221845, 0.7393632841206367, 1.0018375708210854, 0.6583448896004308, 0.2573150216091064, 0.09566157530512541, 32.281606620357884, 90.43078560982981, 68.92620286633893, 68.67083303390011, 82.62930116345807, 85.98663037823093, 85.82879420249694, 77.33327773309524, 77.91588306427002, 79.84142165030204, 83.3382381931428, 81.97246105440202, 76.06468123774376, 66.91754141161519, 63.75813107336722, 62.39497015553137, 63.58517808298912, 63.29778209809334, 62.47271545471684, 60.47859030385172, 54.75382435706354, 57.95592184989684, 60.960986921864176, 62.18583722268382, 60.5042935955909, 55.83217020957701, 56.3520097732544, 62.984569072723396, 75.69196977922994, 71.19132457240936, 75.75383340158771, 72.20029938605525, 74.88848009417134, 65.45044552895331, 70.54227429051554, 54.48133730119275, 81.7157183924029, 41.55692754253265, 35.48103886265909, 85.33367341564548, 60.56450197773596, 72.67247430739864, 70.536571164285, 77.9479915865006, 71.60780968204622, 76.1221125818068, 69.2631030851795, 67.07842134660291, 55.606614312817975, 54.17117195744669, 53.795201009319676, 55.82166610225555, 53.29008602326917, 56.7640547598562, 55.62391196527789, 57.86695464964836, 58.705016105405754, 65.78749479786043, 70.81383566702567, 73.4940618084323, 73.00371062371039, 77.53397757007231, 70.8055986896638, 66.1029592637093, 61.57749329843829, 67.62887108710505, 64.87388457021406, 72.10599776237243, 68.20646362919962, 73.29336197145524, 73.82520398785992, 71.45448423201039, 68.93979780135616, 68.21189218951811, 69.50876112907164, 65.61300816074495, 57.20776896322928, 86.59466051286267, 73.59641213570872, 23.478899924985825, 0.33049137241417365, 0.03296958207483253, 0.10139202023105276, 0.16364617122998162, 0.14184208316428049, 0.08418343315321593, 0.4658160544931889, 19.71093777687319, 24.216436916782012, 59.60561583119055, 66.7822039511896, 14.232386850541639, 37.724579688041445, 53.368427522720836, 54.518862616631296, 1.0689852386713028, 0.01869174287534289, 0.06592428672217554, 0.0502477759014695, 0.01889580188529386, 0.05262244928387865, 0.059578075644470034, 0.01974535891936431, 0.031105895083577886, 0.04661686387994597, 0.04073980887750945, 0.06172335548927227, 0.0020816670158021753, 0.05502531853234095, 0.0506503934100751, 0.011425795364043406, 0.06889116139181199, 0.057405048095050364, 0.09988334796000874, 0.024896951640144955, 0.07153241805011226, 0.06678199876219997, 0.006067284210134419, 0.02669214654052931, 0.01513588161493141, 0.09237184820155944, 0.03531454273709848, 0.0545095268546814, 0.09736772206041122, 0.27212319475027824, 0.15698560363342687, 0.13258634675895015, 0.2259220561433223, 0.16436362789282877, 0.1684559163667502, 0.24808375405207758, 0.1739928474830043, 0.14945439243268582, 0.10975734796375038, 0.14086902892637637, 0.1255254369349249, 0.3167716263523025, 0.16600647280293127, 0.1389635997193475, 0.16623436863864624, 0.2693224079426258, 0.08764022105042973, 0.22070599329327384, 0.19957027097623195, 0.18167211283599177, 0.1044013285108151, 0.08928429170121109, 0.136651040745839, 0.23807624024489235, 0.0990519050749079, 0.14382792095984184, 0.15213625175097298, 0.1823009024824827, 0.19064398302185923, 0.05891262102992304, 0.1477238457770117, 0.2210414172300408, 0.14878771207746, 0.12926181628098413, 3.1442121344227947, 77.90199002911969, 79.1240515247468, 56.13173338674731, 34.092382538703184, 73.40070939833119, 106.32335093713577, 61.10863670226067, 11.52355682465338, 0.4011024624830292, 0.40773261638899005, 0.20275263085721001, 3.4866151934669865, 5.235183056323759, 2.4559023591779896, 0.48795017323667006, 0.2897957706403348, 26.264482890405965, 88.39437730850713, 77.98160629887735, 74.9270683719266, 82.2050105371783, 84.74759286449802, 89.43342885663434, 77.11357793500348, 76.7300485795544, 79.64156904528218, 86.30537786791402, 83.46280482507522, 79.54511796274494, 71.62447975527856, 67.76291416537377, 63.82011236683015, 64.108261446799, 67.5099918919225, 69.24808040741952, 64.2525105322561, 58.34723711013795, 63.80086137402443, 63.14596283820368, 67.18659247121504, 66.45462328387846, 58.26079591628044, 59.448109134551025, 64.0418557197817, 76.85365815316477, 72.96383580853863, 79.68246367669876, 76.4045467684346, 75.86833523165795, 65.97620394922072, 71.63234018510389, 58.91112096848027, 83.74547435391335, 42.95979853599302, 35.66315843212989, 89.27211746092766, 65.05111294407999, 75.58935273078181, 74.62998805507537, 80.16872775170111, 76.92547675101989, 79.67109664793938, 74.02551158781975, 67.96352771020705, 58.05993526212631, 56.293138919338105, 59.10505079453992, 60.65517148663921, 57.38084354708272, 63.564483657959975, 61.35134904615341, 62.944294175794056, 62.1434481682316, 69.4681332188268, 75.08111553807413, 78.35150149560745, 73.55951832186791, 82.02805672922443, 76.81001001788725, 70.6877314659857, 64.23840961148663, 69.85252549571376, 70.03809282856604, 76.5085288017027, 71.9276632801179, 74.96284823263846, 77.12798872301656, 74.13437304958221, 70.992734970585, 69.02619977151194, 68.90611248631632, 65.78683976204165, 59.40877168409286, 87.24324011033582, 72.03874480339789, 21.560872677833807, 0.41644125876407473, 0.3154674689135244, 0.22229335811589995, 1.1938298685896782, 0.6794112043515329, 0.1447956891910684, 0.495798223081135, 21.279005273695915, 39.4664885920863, 79.55252339763027, 58.62057532033613, 22.452990278120964, 42.17911351111628, 59.68345918963033, 65.72317577177479, 1.5690536051988604, 0.16701950150872433, 0.2007254549572545, 0.2208649105722866, 0.11152875008842639, 0.09948264567121383, 0.2500127940889328, 0.133446786071985, 0.1388505404634822, 0.1055625032994055, 0.2238810140519373, 0.310004894291201, 0.16536763208287378, 0.1592969368662565, 0.088781577144419, 0.21741271920261845, 0.1981982381473626, 0.13174919651881342, 0.1495630237003488, 0.14906024019564354, 0.17991686750563884, 0.17228572779605467, 0.07581038325424157, 0.09451291073233851, 0.08138397167767249, 0.15428759518169588, 0.1571381470609096, 0.24593162921167191, 0.22977074397908104], [0.011037287279783238, 0.02525925951739473, 0.042630912240354285, 0.034565990565404776, 0.01684283372014761, 0.03545573657198298, 0.03523331060404739, 0.07806940800360135, 0.0513693630965727, 0.006685771410458632, 0.03671842184098017, 0.10228861123323442, 0.03885448947849293, 0.05677168107321186, 0.009034818672995654, 0.015507608543210214, 0.04916365423630323, 0.04778872176464047, 0.01932439168975238, 0.03784436424593291, 0.006939266552968372, 0.04707131106706877, 0.04043550343222676, 0.06767822204217797, 0.023695907720755187, 0.03785917272550925, 0.0030182762965259534, 0.026980758674683112, 0.09288125836680974, 0.0760798700033657, 0.08248905350844707, 0.053002773633887695, 0.034359947387729926, 0.046838902973479805, 0.04041915511592262, 0.07346138147817505, 3.0870712909006306, 50.348951662740404, 67.35192037397816, 50.69332791912941, 21.71886770955978, 40.13506051032774, 89.45285243372764, 69.04443879281321, 10.959936745705145, 1.495896375948383, 0.027699259132327094, 0.08908234326349151, 0.7850711540349069, 0.8850467313201198, 0.27176359307862097, 0.030197314805381244, 0.18926470300122616, 9.202583509106791, 66.23144042107367, 80.91988517392068, 69.89920954550468, 66.26611417339694, 75.12924302008845, 84.02732018501528, 82.85581804090931, 77.51809197087442, 82.36790657043457, 76.80199269325503, 72.56910416387743, 70.59070771740329, 73.57014794503489, 72.52835073778706, 67.21590042114258, 56.50692378321002, 58.08414805320002, 56.300461984449825, 57.25315078612297, 59.97750359196817, 65.4121082828891, 65.18561886202905, 64.48311844179707, 56.114973099001, 56.79593578461678, 54.80391302416402, 64.20015473519602, 70.00954581845191, 74.64147275493991, 71.40281092736029, 79.70693926657401, 70.75089731524068, 77.59628834262972, 69.35270570939588, 78.56710633923932, 40.139633993948664, 30.813702729440507, 86.40872447721421, 67.94264501140964, 79.54012870788574, 69.42973321483981, 74.15872312361195, 66.27512778005293, 65.00369148869669, 59.345970615263916, 55.48196923348212, 51.95831191155219, 53.59830587140976, 52.79397679913429, 59.21783070410452, 58.24542806994531, 64.8925825088255, 66.98245663796702, 71.62765687511813, 69.7175645828247, 70.60785631979667, 70.83487526062997, 77.30396193842735, 73.53616452986195, 74.50297386415544, 72.0005173836985, 70.35807194248324, 68.36932828349453, 69.19232783779022, 65.26230119889783, 68.67775993962442, 69.32723383749686, 74.1501723566363, 74.37072723142563, 72.34915333409464, 76.82391874251827, 64.67997827837544, 63.80582709466258, 86.73040589978619, 66.96096989416307, 25.771270336643344, 1.074376781621287, 0.3363534159237339, 0.06796299990627074, 0.13899039747493883, 0.1157873715724676, 0.2638808854164616, 0.07606761259657722, 0.29607346281409264, 9.840755097327694, 45.64616318671934, 66.1476036810106, 32.86573383115953, 19.810379666666833, 44.717004683709916, 55.994662238705544, 42.94671350909818, 1.2290702808287837, 0.1411818226258601, 0.011204287744007044, 0.03913371320513468, 0.009480538203441089, 0.03190145824074505, 0.045042231438621405, 0.05063350500178434, 0.030152263089774117, 0.048811414669598305, 0.06286067046946095, 0.0510732701138383, 0.006405691580561501, 0.0532940709062161, 0.05194801228841947, 0.1273743288531419, 0.021054254611954096, 0.014370452526265816, 0.10570088176116829, 0.04035480373028306, 0.02981630672189978, 0.08619612233052332, 0.020066763447116942, 0.051363690215493404, 0.04542530221383899, 0.05831817893551723, 0.04771595490315268, 0.04211182638462033, 0.035335338193803065, 0.02285226680067999, 0.10463194395866125, 0.02679586143893821, 0.09580827348174588, 0.02597633696671936, 0.040934215179614486, 0.04145848745059583, 0.04754725085090726, 0.04105693097376535, 0.013679041895234298, 0.008909427316769237, 0.045682531556174646, 0.05871967029487414, 0.03438755719652099, 0.04453109757554147, 0.06559198076326041, 0.021600080766685067, 0.06128147980498691, 0.03257633382154088, 0.03585396439678246, 0.014147092888672507, 0.032282481645984996, 0.024492432318267324, 0.0470083539614514, 0.052997667657872366, 0.02584511759660898, 0.07540703030122865, 0.028014498567509077, 0.013455009057877526, 0.08452980448642085, 0.05794913523019322, 0.02388394208655002, 0.01888160053039751, 0.04134138708092994, 0.08997126572555111, 0.12348603427169785, 0.2122539597293062, 7.389629204427043, 69.89411046428066, 66.7363985123173, 29.16179653136961, 23.818030011269357, 73.40380807076731, 100.06302064464938, 55.03016318044355, 15.117640303027246, 3.6131427653374213, 0.08327561130206432, 0.13224946725512707, 0.5477233867972129, 0.9894661088624309, 0.29359302333285736, 0.16871995623073271, 0.2606388013209066, 15.55421285090908, 78.01032589327905, 83.46737046395579, 69.2574627168717, 71.54981351667836, 76.13587225637129, 83.64443409827449, 82.43657942741149, 77.98106501179358, 83.81331566841372, 78.77523514532274, 76.10877652322093, 74.65917833389776, 73.7740876597743, 70.79245874958654, 65.8725357055664, 57.064469091353885, 61.62079234277049, 58.391897216919936, 59.38975211112731, 60.36850114022533, 66.30821689482659, 66.86319305050758, 65.44373043121831, 58.72079972297915, 57.9967458786503, 57.92454681088848, 73.5533994243991, 74.71605270139634, 77.63024037884128, 71.6853706298336, 78.89635009150352, 69.93000015135735, 74.92419719696045, 67.96204505428192, 79.55122901547341, 39.401777328983435, 32.4688821454202, 85.34984142549577, 69.00185754222255, 78.97459353170088, 71.70323310359832, 75.4022164498606, 68.691817714322, 68.14777712668142, 59.99407560594621, 56.258033706295876, 52.47721010638822, 55.28610567892752, 53.5952542674157, 58.04623050074424, 58.63946937745618, 65.08669668628325, 65.96111066879766, 72.2439867450345, 69.4435634920674, 71.04320802996236, 72.88037561601209, 78.61555545560776, 72.42276053274833, 74.64732493123701, 72.96099601253387, 71.82846653846003, 69.31632180367747, 69.99945748236873, 67.85905930303758, 69.86544578306138, 71.21668661794355, 74.66902348303026, 75.4983223638227, 70.22387196940761, 76.02970154054704, 68.32459757404943, 61.48913406556653, 83.43623468952795, 74.70026908382293, 34.19998491964033, 2.5425727665424347, 0.28521934524178505, 0.05922771682361922, 0.11947106705197405, 0.03743268774762269, 0.08604907175345768, 0.13352166350570419, 1.0018446801170227, 16.838641012868575, 44.4293615894933, 73.03926298695227, 59.23623446495303, 18.914455406127438, 36.82685113722278, 55.75182437896729, 57.67904566180322, 3.6775863266760305, 0.13482821113880605, 0.03384107986705438, 0.02872357614368441, 0.026633477612068097, 0.060700562992884274, 0.11606257333750687, 0.038528725910451145, 0.042737578492491476, 0.03934342977440646, 0.07955432388811343, 0.04444451814877891, 0.05024891354203705, 0.053995910866726796, 0.014400014901653895, 0.008337348286483076, 0.027296649284600735, 0.08107571321870051, 0.05536946438012585, 0.022108604185163014, 0.041173901108484116, 0.008638857510842143, 0.016004496043728247, 0.0031330080180909606, 0.022779346721607353, 0.03943445251112984, 0.02242436839057313, 0.02007590479127342, 0.055554443970322616, 0.09394245868128154, 0.14322923856877512, 0.10825939326276703, 0.2607420393295827, 0.12517263812403526, 0.10997733011120751, 0.11449963139790682, 0.1220659677299761, 0.3116103387888401, 0.14905993376047383, 0.12434159360465505, 0.10166653251696019, 0.15592274856903862, 0.1959226046118044, 0.1387437478068375, 0.20332394858762143, 0.06602275966396255, 0.14256464197270333, 0.13175547843979252, 0.20509431649359966, 0.14554153707238937, 0.09236624809883295, 0.12102951205545857, 0.16115396463822934, 0.16106568066583526, 0.1090652488111969, 0.1741243541360863, 0.12033005079795277, 0.14077962646561284, 0.19580044423139867, 0.30477419916179876, 0.18826595417434172, 0.11027638019332964, 0.1674146343383097, 0.2954922778712165, 0.3799090384235306, 0.27181663700649816, 6.493257793688006, 79.23181472286102, 90.19710648444392, 67.40977533401983, 37.418073915666156, 56.49854560052195, 102.50941861060359, 86.94881916046144, 20.4017299221408, 2.8084231720816706, 0.21600933805588754, 0.3262789307102081, 1.5832619008518036, 5.9110520539745215, 0.5285421386361122, 0.16635363320669821, 0.2060997762507008, 11.736834722180522, 73.85885007919805, 85.76682859851469, 77.43311774346137, 73.92427521367227, 74.94128304143106, 82.90278450135263, 83.25993983976304, 76.35087305499663, 86.58720800953527, 83.04668841823455, 81.41237012801632, 76.8919091070852, 79.42889813453921, 79.509063536121, 72.8199318916567, 61.344226021920484, 62.780888234415364, 61.50694947088919, 64.24206918285739, 65.69122022198093, 73.9872920128607, 70.93280899909236, 69.93467561660275, 63.841536352711344, 63.66852844915083, 63.7356480475395, 74.53609435789048, 79.30667707996984, 82.99759603315785, 77.39096010884931, 83.7082745951991, 73.58187583185011, 76.82092989644697, 68.04035125240203, 76.8577923313264, 43.7527919584705, 35.22304104220483, 84.27992082411244, 71.60525229669386, 81.71847974100422, 74.32088175127583, 77.72756222755679, 72.0222237802321, 68.6532372813071, 64.05443868329449, 59.692551243689756, 57.42587627903108, 58.16684338354296, 56.29260939936484, 62.20461360869869, 61.91582518239176, 71.49894822028376, 73.6568872390255, 79.57533590255245, 76.0075479938138, 78.24307933930429, 78.18573428738502, 82.60854398050617, 75.36061579181303, 75.85627002100792, 75.91858079356533, 74.48897884738061, 75.47751811242874, 74.05793389966412, 71.64083603889712, 74.25880632092877, 75.63369120320966, 79.69849048122283, 78.41403976563485, 72.4597563282136, 75.455717579011, 70.44640371876379, 66.4156113901446, 84.58700318490305, 72.24910936047955, 30.79669729355843, 2.5240067176280485, 0.33464194485737436, 0.33156328263782686, 0.5268728636926221, 0.22986658157840853, 0.35191587923515233, 0.35399807556982965, 0.60159879586389, 17.496673522457, 60.34742624528947, 72.93470828763901, 48.51197235045895, 30.26566916896451, 59.73317523156444, 72.91613194250291, 66.51482382128316, 3.7916459095093513, 0.19962175208474361, 0.20485931136194738, 0.17042611064689775, 0.08959137038477967, 0.14276042340263245, 0.18055409944105535, 0.19029853865504268, 0.14192232321346962, 0.14791398879981812, 0.2264776537495275, 0.1358173685448785, 0.09477955529526358, 0.17733015630754734, 0.12446542405673575, 0.23916650593521135, 0.20468013871821666, 0.18391573921807353, 0.25442705399567084, 0.079546800904697, 0.11903616659823926, 0.2927699384670104, 0.10572779442994826, 0.15304838667713827, 0.1567530193396153, 0.1492340349021458, 0.21242902614176276, 0.141780826773855, 0.14914421875390316, 0.13257506994470475], [0.00992125901018059, 0.03751398116770772, 0.04365540928237381, 0.028539276456520445, 0.03729196122637199, 0.022226547251545617, 0.017420446778076793, 0.08130212284384236, 0.034529000009980895, 0.03617407806638268, 0.06447579065758376, 0.009214382979177661, 0.03608937555503461, 0.017211909984208403, 0.03869711586664762, 0.05978572377634626, 0.01287627655396899, 0.07988726570000572, 0.011239560347260728, 0.06988139132097845, 0.029250535468060165, 0.024803454439426144, 0.0208797934089577, 0.06426118261691544, 0.04601124839316453, 0.05512040919594227, 0.00624368361557924, 0.03419303598122732, 0.016947431534889246, 0.03360032907597, 0.04802039824426175, 0.043568952429679134, 0.08235295798869864, 0.01681532158756689, 0.028876353227984042, 0.153232355031275, 0.10973036634705721, 2.127840220928192, 34.02550220489502, 64.28276769576534, 58.31791347072971, 29.121331399486913, 28.91260639313729, 82.78495650137626, 84.38685247975012, 33.72437792439615, 7.370090407709922, 0.11197581601839875, 0.18468570354725086, 0.2646124380971155, 0.1825206777862003, 0.3351875220335299, 0.08514675041360241, 0.3709578526116187, 0.8675312647415746, 32.56687471943517, 72.50596184884348, 89.18846899463286, 81.51504208964687, 76.15917897993519, 79.7285044577814, 89.31178831285047, 82.60054234535464, 80.41884945284936, 76.61477012019004, 74.42408715524982, 73.2274426183393, 74.55841264417096, 74.22894139443675, 77.65619077990132, 73.38454923322125, 60.66705626826133, 60.08380374600811, 61.175105187200735, 71.10848411437004, 70.73297992829355, 70.84107260550223, 63.73079215326617, 60.15300612295828, 57.5409350856658, 59.60068148951377, 58.60860424657022, 73.50566417940202, 72.77536592175885, 81.62648447098272, 73.86976995775777, 83.48659792254048, 65.07434122024044, 85.88595882538827, 41.41364336013794, 29.93997516170625, 94.04892106210032, 68.80406810391334, 78.4972567712107, 68.98752520161291, 71.06626372183524, 63.82202648347425, 64.60906967040032, 56.65229074416622, 59.3732036313703, 56.91449334544521, 60.932412455158854, 61.96434882379348, 62.78114711084674, 63.66695557871173, 67.89450968465498, 71.36998853375836, 73.80474490504112, 72.05854492802774, 75.89877282419513, 72.0932343698317, 80.25433740308209, 76.68714569460961, 79.83498111847909, 79.81724416055988, 77.04031590492495, 71.51830119471397, 73.39460619034307, 72.31166331998764, 73.81128741848853, 71.31334950847011, 72.36159509228122, 72.84375636808335, 75.22318378571542, 59.94898011607509, 68.06793335945376, 78.64846414135349, 40.19741050658688, 6.41100618147081, 0.07924844030170672, 0.0550115289497039, 0.25162865738234214, 0.0397782153149526, 0.10542024843274586, 0.07264496157726935, 0.07018666203704572, 0.5447642649373701, 16.65618019719278, 59.67480251866003, 57.3801100638605, 25.970818957974835, 31.637408310367217, 47.417862492222945, 54.274244000834805, 34.30545745357391, 1.2551921630097975, 0.09292922313174895, 0.10880639536246177, 0.047105248762114395, 0.054553312609993646, 0.07629821272266489, 0.03522766453604545, 0.08326728392632739, 0.040035888988284335, 0.004548929545337394, 0.04402158015798177, 0.08257156883877131, 0.025333384269728296, 0.061967672419644175, 0.028605931851592277, 0.04284480781925302, 0.048390070141683665, 0.020938950718470642, 0.013063656872198468, 0.02826741100439141, 0.05280591201998534, 0.050094711534198255, 0.024030035053710305, 0.05067016230896116, 0.057225599659666906, 0.026703971107640577, 0.012522231892592484, 0.05108466567171197, 0.03469769640134708, 0.013364305205252624, 0.028341813463597532, 0.060134810891242764, 0.03397962303772088, 0.0665608138567017, 0.040009462785336285, 0.043013224588526834, 0.00825261417400813, 0.02554133692155442, 0.04739013387851658, 0.0358258719525991, 0.03754810272385517, 0.057352777915976705, 0.057346710499616406, 0.016435788223339666, 0.0182353823836292, 0.09611002019336147, 0.019464503425443848, 0.008488161312866836, 0.060028979674943035, 0.05018742349479468, 0.04815780377436069, 0.025097381308554642, 0.0074734859968415435, 0.026072513559953343, 0.006150952023979758, 0.02685013685315367, 0.05470046660892906, 0.03291941863755065, 0.03744518647210733, 0.022576166797549497, 0.00989982482766913, 0.0370387691673973, 0.014790180608660225, 0.07402038051476402, 0.022147927478316332, 0.023290779358977755, 0.06875623798658771, 0.06341645193676795, 5.418506303141195, 52.21394454279254, 70.5401954343242, 42.00683909077799, 21.060856773007302, 53.08462050653274, 96.58923625946046, 72.13661578393751, 30.245227736811486, 9.41790888386388, 0.25059961743893167, 0.1114302465031224, 0.046404960129650376, 0.3164295527723528, 0.5247718828820414, 0.29565759964527627, 0.7156941703250332, 2.3718731778283275, 44.23795384745444, 82.45660704951133, 86.54079068091609, 79.96682766945132, 75.17311080809563, 81.63768676019485, 87.82061299970074, 83.49932993611982, 85.15198138452347, 78.25399137312367, 77.37559226251419, 75.84773494351295, 77.14101883672899, 79.86899591261341, 77.38276235518917, 74.02737079128143, 61.33032906439997, 62.0086637620003, 64.95406566127654, 73.08989294113653, 72.04797021804318, 72.23038396527691, 66.80198054159841, 60.29829071414087, 56.02461737971152, 60.37702445060977, 60.1526923333445, 75.71338592037078, 74.87483024597168, 83.95291282284646, 76.69853625759002, 85.07612274539086, 66.52641834751253, 81.2472148095408, 44.493441350998424, 31.921597757647117, 90.41015394272344, 69.09708484526604, 76.96443373157133, 70.43076130651659, 74.49181079864502, 65.93326968531456, 67.69221736538795, 59.08117532730103, 62.45588848667761, 58.75291608995008, 61.47949680205315, 63.390271586756555, 65.5374986125577, 66.19209904824534, 68.6762615942186, 74.25694711746709, 76.24733817192816, 73.88454160382672, 77.08772951556791, 73.64983481745567, 79.54698501094695, 74.39856821490874, 79.58326693504088, 78.12981697820848, 75.67592728522517, 71.13970618094169, 73.80909873593238, 71.00561603423088, 75.85852930622717, 73.70644246378254, 72.2239512781943, 72.75442830977902, 75.1337694352673, 63.72981548309327, 65.09874620745259, 83.1370912059661, 51.30835163977839, 11.343226836573693, 0.052770874988768375, 0.05339184670799202, 0.35826267253968025, 0.11266412303572702, 0.0756397754735043, 0.031547372402142615, 0.025122863308136022, 1.0985411559381792, 17.44051890988504, 50.59364872594034, 79.67285386977657, 43.827415050998816, 23.09947336873701, 43.59567357647804, 57.90220499038697, 49.033271035840436, 2.2063555304081213, 0.17702514606137432, 0.047300919109294494, 0.035871503979808865, 0.03179568639625946, 0.07024267072518987, 0.029159792353429144, 0.019945687081124035, 0.009666336550106926, 0.018399851884873166, 0.026009050836305947, 0.023170572502778906, 0.03742695357950945, 0.030069699878954602, 0.018438470377136144, 0.013988229235814465, 0.06984872533188713, 0.015969866954330957, 0.06024037780720861, 0.07120367440004503, 0.05867700302793134, 0.009011159005064157, 0.012153630603044745, 0.057807914582231355, 0.06948679475294006, 0.046499487718627344, 0.03549355450236509, 0.02755046953567334, 0.0380088011884401, 0.031161235360008095, 0.07739488290803087, 0.1594856090002483, 0.08507817788350006, 0.09883807461348273, 0.12808124414615094, 0.12777917567760716, 0.08673682718748048, 0.07064421571070148, 0.1635303540575889, 0.28603388056639706, 0.11016133676974044, 0.20215937236864723, 0.15970700841036536, 0.13558401816314267, 0.18069527412374176, 0.1723602221858117, 0.12609923679021098, 0.08057440060280985, 0.17274908841617648, 0.1239365705799672, 0.10557243179890419, 0.09370022167962405, 0.08971603587269784, 0.130304308728345, 0.09430806648226515, 0.1116772102672727, 0.15655472514129457, 0.08155326944805923, 0.10712079508530517, 0.13075343543483367, 0.12025332709233608, 0.08741168936173763, 0.1198372724015386, 0.17719055976598494, 0.11012429641860147, 0.18545367604782506, 0.2054821561661459, 0.2025193724060251, 4.237802278610968, 57.671232300419966, 89.4153545748803, 71.907133594636, 42.94910223253312, 46.82535317636306, 95.5608614029423, 99.09256350609564, 48.92256213772682, 13.38116192048596, 0.18770718496413002, 0.4206658659442779, 0.5658492722338246, 2.371146803902042, 1.5851718499775858, 0.20856078774217637, 0.5667504980679482, 1.6203178801844198, 36.206371399664114, 79.62023135154479, 93.248624186362, 85.02287264793151, 74.7063958260321, 79.54582398937595, 89.68255427575882, 87.11223294658046, 84.55329433564218, 81.79359312980407, 81.29974319088845, 79.23757276227398, 80.78722276995259, 84.14990994238084, 84.68050464507073, 80.95794785407283, 68.21765022893106, 66.78028983454551, 68.2284289021646, 75.75286849852532, 76.71393548288654, 77.35070090140067, 71.68297013928814, 65.13044288081508, 60.394518221578295, 60.269010220804525, 61.67673318616806, 79.83443198665496, 78.98065751598728, 87.73902770011657, 80.6183490445537, 88.6934188104445, 66.44280910491943, 85.9366201585339, 45.81837877150505, 34.586420751387074, 97.07007961888468, 74.00173417983517, 80.50776958465576, 73.76118306190737, 77.22117639357045, 69.55345261481501, 73.17086635097381, 64.35917938909223, 69.20775059730776, 63.649116639168035, 67.70184286179082, 71.78164128334292, 72.20474735383065, 71.9051645648095, 72.72715999234107, 77.0134162902832, 80.58340857105871, 76.2566420339769, 80.79742877714096, 75.95003035760696, 86.07579369698801, 77.07228322182932, 82.56180501753285, 85.02038586524226, 80.70442938035535, 74.60488488597255, 78.91486367871686, 76.67795950366606, 78.2516928642027, 79.12981740890011, 74.1649518474456, 74.3868403280935, 76.05442031737297, 70.82055860950102, 74.07006971297726, 79.57440237845145, 44.98604789856942, 9.531842950851688, 0.20180211492603828, 0.2703904570831407, 0.619980983676449, 0.2757670153533259, 0.26230685052371794, 0.22978629556394395, 0.4409632122805042, 1.1040345579385757, 27.867883097740915, 74.56071115309193, 68.34058515487179, 41.45940173056818, 44.40459182185512, 59.72524027670584, 70.43961017362534, 52.30350009856686, 2.1194034478356762, 0.25301204363424934, 0.18574668935710387, 0.14785769665914197, 0.19905797265950712, 0.1971046476354522, 0.08116743692587461, 0.16039114024850631, 0.14999194100739496, 0.13848966708587063, 0.1919027114467275, 0.21900212181912315, 0.16098511885971795, 0.1563305678146501, 0.09120032356511201, 0.13554891601445215, 0.18294309866764855, 0.13670881909708824, 0.20263460735159539, 0.12945824122476962, 0.09814664961830263, 0.11500564013277331, 0.13169348660495975, 0.1495736876442548, 0.15392114468399556, 0.1321747736825097, 0.10721864749587352, 0.10239610869076946, 0.1455797188945355, 0.17778945666167045, 0.13421877287328243], [0.013859038083483616, 0.07081061000785521, 0.039960023301142844, 0.031203157606444536, 0.039477035508400975, 0.06330620039314513, 0.0322605753617902, 0.014935664535920708, 0.04838056682098297, 0.0673138399818732, 0.03501638131696851, 0.03494104040005515, 0.017155230969130512, 0.027714822208508853, 0.02107267519609342, 0.049939253142163645, 0.03093538880949059, 0.08008287092971225, 0.027470147132032344, 0.04528938289431315, 0.017962800639290965, 0.08706677359558883, 0.025807845503872922, 0.05302035535174993, 0.05977089614457181, 0.028682102058683673, 0.03997084429307331, 0.03638878186804153, 0.04065712500784186, 0.07701611371650811, 0.014897417596301005, 0.020696037644219976, 0.08763040746411971, 0.030322392065558704, 0.06630221321698158, 0.0890067074027273, 0.027165067937946128, 0.10905033307931117, 0.42318041165990217, 27.78748627631895, 63.05516781345491, 61.9284434472361, 36.02480096201743, 30.979689590392578, 53.3505807384368, 73.10462536350374, 79.14956262034755, 24.875069549006803, 1.3048076942082376, 0.2037636217691245, 0.12129876897820543, 0.6311712606299309, 0.669481601686247, 0.2079462166875601, 0.02202342095364246, 0.10873548626419037, 5.2676744999424105, 36.4668442356971, 81.4473419804727, 96.99246375791489, 88.81572615715766, 75.08419852102958, 89.83396560915055, 81.04666402263027, 80.11820762388169, 80.27606733383672, 85.55677783104682, 84.99376081651258, 80.35755849653675, 75.57523219816147, 77.96037843150478, 67.49068598593435, 61.67310891612884, 66.00275055054696, 75.83581878292945, 76.83858840696274, 76.6092081992857, 70.7456962523922, 65.98350740248158, 60.46128088428129, 66.68038706625661, 64.11250937369563, 63.71713446032617, 66.1038221851472, 76.9726550194525, 72.96475364315894, 79.24524491833103, 71.92210920395391, 76.6154996810421, 35.13550158469908, 37.2588570656315, 83.3470792155112, 70.50333299944478, 72.49627359451787, 69.04934175552862, 70.09309230312225, 59.799055360978656, 62.120710188342684, 61.78870508747717, 61.664558149153194, 61.694811390292266, 65.36220396718672, 63.95751299396638, 64.5797577981026, 68.10141471124464, 69.88752872713151, 74.50804156641807, 78.49942191954582, 79.74464893341064, 77.56191269043954, 78.79886350324078, 81.20399813498221, 77.06277539653163, 76.25433568031558, 74.30726328203755, 77.06718414060532, 76.69806557316934, 75.80421232408094, 70.24282486208024, 67.80731539572439, 80.189006405492, 80.69468621284732, 74.20048852120676, 67.53119622507404, 82.58939496932491, 60.18180024239325, 16.179811281542626, 0.24768168046589822, 0.26801818921681375, 0.3704976176302279, 0.07789034261218003, 0.6358891977898536, 0.266140875436606, 0.10565123160279567, 0.012415225688938894, 2.653224790288556, 37.330703120077814, 72.39545299160865, 40.42232705700783, 17.33095338267665, 36.830746050803896, 57.090678368845296, 59.02537961159984, 24.17289664668422, 0.3455256027800422, 0.11252220524775405, 0.044654533492341164, 0.05788839594911664, 0.04748862980294132, 0.09256917712909561, 0.0014650215387284277, 0.04798624987503694, 0.041544687663835865, 0.02326779289080972, 0.0775496096860978, 0.09981035510258329, 0.039491698431271705, 0.03867744655919172, 0.029266615653590813, 0.030883359948113084, 0.028559133455517794, 0.00329681174104823, 0.02506167203518412, 0.05372333295282818, 0.04674215755996205, 0.02735995879066327, 0.005997087573632599, 0.0269601930443558, 0.07135634040159565, 0.006819039108156557, 0.07044274224749497, 0.0707141595381883, 0.06252158846285555, 0.0291813328306401, 0.034459669052833514, 0.03214450154994284, 0.010676157262717045, 0.02032286089454447, 0.028684201139596202, 0.0854871922262734, 0.033592832905630914, 0.03257726078792926, 0.0237317223312153, 0.052779286634176976, 0.06353255639213228, 0.029792234324099078, 0.018898448719072248, 0.01789690750170379, 0.024730557342991236, 0.03130592638626695, 0.03299200929881584, 0.045630916382276246, 0.06287372077725108, 0.05050271464091155, 0.009388855673492917, 0.024154740761244492, 0.018417921983787132, 0.05704577967164017, 0.04035468881709441, 0.04418826939898633, 0.060539830085490985, 0.011149829426299662, 0.04254180089300198, 0.044886164006686984, 0.035699773880262534, 0.07530075858437246, 0.014921104077309852, 0.026645348144454822, 0.07021592659575325, 0.029474913044982863, 0.062313296817122936, 0.060857741252308896, 0.017261251792191498, 0.31082059406945783, 1.697331412184623, 42.43562083090506, 78.50033190942581, 57.03402757644654, 26.059817537184685, 47.280497166418264, 84.89257151080717, 89.1887435605449, 69.11384121064218, 25.436209709413593, 2.704595336990972, 0.18751422273776225, 0.1538656186312437, 0.09777247695432556, 0.2591673915664996, 0.40927046128819067, 0.46900181580455075, 0.05481981927709234, 9.795080077263618, 51.025686033310436, 88.58581250713718, 96.08560392933508, 84.57741691220193, 75.23408797479446, 91.14009134231075, 80.76997218593475, 83.15943302646761, 84.89000628071447, 89.20246401140767, 86.1955044346471, 77.3750352859497, 79.11856020650556, 79.15517160969397, 68.51910006615424, 63.04391453343054, 68.65279013110747, 77.23299841726981, 77.1062195685602, 77.68159989387759, 72.10708033653998, 65.80687522888184, 63.64517857951503, 68.50510504937941, 65.18337918866065, 68.57024777320125, 69.97453474229383, 78.03218918461954, 74.7202496374807, 78.54839663351737, 72.46652633913102, 79.74489996510168, 38.05794192898659, 35.849773037818174, 83.55593758244669, 73.32905554002332, 73.95569339875253, 70.67008864495062, 68.45904857881608, 63.206371261227524, 63.97284946134014, 60.2454524655496, 60.9980337081417, 61.52648679671749, 64.02094556439307, 64.9073463101541, 66.28668308258057, 70.76319002336072, 71.22805364670293, 73.68301022437312, 79.93770799329205, 78.97936313383042, 78.97900227577456, 81.6278180768413, 81.8151661657518, 75.88655856347854, 75.3731595316241, 78.06054792096539, 80.07875642468854, 81.77529919532039, 75.73928140824842, 74.7245014867475, 71.27458080168694, 77.62688282997378, 81.21265088358234, 75.1808378773351, 68.26482065262334, 80.67945957183838, 69.87880537586828, 23.85696149641468, 0.8714232978320892, 0.38015357368896086, 0.8501533875542303, 0.2515645051795629, 0.35393412254991075, 0.038074792002237616, 0.030330368956070275, 0.14650654738708851, 2.308791414383919, 32.66039775263879, 76.56360672366235, 68.1834550057688, 26.113428492699903, 21.59035517323402, 57.984457092900435, 66.09946835425593, 37.80752605007541, 1.6833898377033973, 0.045879201648095926, 0.04549713444805915, 0.026419545643992966, 0.013492717820730422, 0.045527850743383176, 0.03822834666578039, 0.0364506128244102, 0.03952482407311759, 0.02911097340045437, 0.053839506356105696, 0.07233482620288288, 0.005946196831627599, 0.052162375180952014, 0.01917435336978205, 0.01813473375213723, 0.041751167511627565, 0.07492102412206512, 0.04424679085552212, 0.029005226453826315, 0.029865395720867865, 0.021923990401950096, 0.004606094547442251, 0.07156187413080085, 0.06265298403318852, 0.07950434431193337, 0.08073042206946882, 0.09278511433231254, 0.021410135011519157, 0.036463264766479694, 0.009262966360115718, 0.05584497515472674, 0.06930871761494106, 0.2199676837171278, 0.121135255171647, 0.20348488833875428, 0.11183500905791599, 0.15627744727798049, 0.12551587615762988, 0.09308643969556979, 0.16857338828905938, 0.16485668208089568, 0.138457874437013, 0.13834144439428084, 0.10958119370644132, 0.11582641141308893, 0.11198533849129755, 0.11352397246106018, 0.12420260993343209, 0.11236537172789536, 0.10156333281268036, 0.21348297926447085, 0.1562363083564466, 0.13037612181036703, 0.13356853276491165, 0.10110523521659837, 0.1555963338262612, 0.049170403470916134, 0.26934257137679285, 0.12885082543136614, 0.14923739036725414, 0.1364688650374451, 0.16516933788455304, 0.14419109260122623, 0.12764498005591093, 0.14256942236135084, 0.11702893196695274, 0.2631052060713691, 0.11052021065786963, 0.31028332128640146, 1.14714888315047, 44.68900680541993, 94.71873637168639, 79.54132895315848, 51.8899332323382, 53.302480713013686, 69.78621390558058, 82.22696796540292, 97.42699961508475, 38.40892345674577, 2.524409741163254, 0.5765629812113701, 0.4180871527041159, 2.60000852327193, 1.9274153175853916, 0.6088171827216303, 0.28851134762648617, 0.13249276145812006, 6.992873616756932, 41.91393775324668, 81.49706978951731, 96.75329331428775, 88.86897625461702, 75.66311682424238, 90.37420149772399, 85.63125579587876, 85.92854792071928, 87.2806752112604, 93.40986497940557, 92.31986968748032, 85.01970337283227, 81.99412038249355, 82.29593107777258, 74.24721963943975, 67.5253205145559, 73.79919867361747, 82.92257678124213, 83.3599445896764, 81.37731198341616, 80.34571293861636, 72.41628077722365, 71.675705909729, 77.23173541407432, 76.0834615461288, 69.24553871154785, 74.21341665329473, 79.11892106456142, 77.87477662486415, 79.67781174567439, 77.04801943994339, 74.58364917385963, 45.84881636404222, 47.38588733057822, 78.2491982367731, 78.24190262825259, 75.4370157180294, 75.06249212449598, 74.52327605216735, 65.78250946537142, 66.16253222188642, 64.52459358399915, 65.54987761282152, 67.50854061495873, 68.89635362932759, 67.04089210879418, 68.29023761133995, 75.03662017083938, 76.62550956972184, 78.82784197407385, 85.63976733915268, 86.83807496101626, 84.83150805196455, 86.98882733621906, 84.89788240002048, 76.45858918466877, 76.26564779589253, 78.2477234255883, 84.4361880517775, 89.5024468821864, 79.52782815502536, 75.6287411720522, 73.56624126434326, 83.40979791456654, 83.66471275206536, 77.11127942608249, 74.30763198483375, 87.86672438344648, 64.05908669194868, 20.0824313394485, 0.6820946571327026, 0.3716028373568289, 0.7903892138311941, 0.8814515726220225, 1.1376029373176637, 0.6646980261129718, 0.39835962256596935, 0.3101537911401641, 5.384420416047496, 50.83670623840825, 82.50274196747812, 50.58694931768602, 28.06665901214846, 51.41686008822534, 70.38352812490156, 78.57643373550908, 39.96257820437032, 1.3427777083650714, 0.16513918466385336, 0.11391649293082376, 0.21734075290301155, 0.051699596787652666, 0.16011818312108517, 0.1140571007084462, 0.15955101758722337, 0.149422814288447, 0.15534568517919511, 0.18119770522800185, 0.16277166654265698, 0.1807423732093265, 0.1193055997212087, 0.10583524592220785, 0.10525127241928732, 0.25041670628613044, 0.13477348181749546, 0.11276186053310672, 0.11445158236329595, 0.14506466266128326, 0.08013642813649871, 0.12247188707753537, 0.24334473415247856, 0.22043096772845716, 0.17662627472271844, 0.3333249477849853, 0.2067257313718719, 0.116253022795483, 0.07863530949238809, 0.11217404126880631, 0.24923763568362883], [0.027171506906949708, 0.016568754273917408, 0.060758651609742836, 0.03935740704858496, 0.029800033099168254, 0.02122025628904662, 0.029548712209948612, 0.05252846561732793, 0.04546826059419302, 0.10999612224799012, 0.06770190181991748, 0.042989357119245876, 0.03553227641649785, 0.0574307733275477, 0.02276076908944355, 0.06489785147770759, 0.03975711342307829, 0.057368697223043254, 0.07266741561433, 0.05721257999539376, 0.03042554388934326, 0.05400885775264713, 0.050478215149093064, 0.03703078270078667, 0.04419486158557477, 0.02517272988634725, 0.009551645526962896, 0.058493754796443455, 0.03462707458604728, 0.05949187926166962, 0.014203444401162767, 0.02458807648039393, 0.03070981996584564, 0.07050173101766456, 0.05141167030219109, 0.026108081107057875, 0.02266038092784584, 0.04667959115918606, 0.08240239364245246, 0.06838340597647814, 15.669521708642284, 45.473437693811235, 67.66852624954717, 36.89502585318781, 31.83863178376229, 36.712314005820986, 61.8130551615069, 89.62106720093759, 40.92999942841069, 6.210090614134266, 0.13043126481915676, 0.05086781299342552, 0.6394656639425986, 0.6706819082460096, 0.2746639713164299, 0.0762527913696343, 0.27381532975742895, 0.0672608113757545, 2.022030730881999, 20.415283672271237, 80.60788416093396, 105.78869265894737, 77.12604322741109, 82.53015149024226, 91.38822047941147, 87.63950147936421, 76.83690178778865, 77.5357347919095, 85.40182851975965, 88.41207504272462, 86.80976329311248, 75.86219279996811, 64.42141955898654, 71.96516113896524, 76.7534415952621, 78.43212973686957, 74.13252169086088, 71.08804856577228, 65.58502989430582, 69.18980183139925, 73.39178992855933, 71.56826434596893, 72.46812666616133, 69.87255311781361, 71.22945785522461, 74.33886189614573, 76.3753015764298, 77.72449493408203, 76.03868376824164, 46.700119741501354, 50.877483198719645, 81.13895739278486, 83.24320700860794, 73.44915851469963, 72.24933685794954, 68.70573428369337, 72.42883236177506, 70.60022338744133, 67.60241862266295, 68.72808394893524, 70.61678363430885, 68.7700689992597, 70.48284253766461, 69.3445707136585, 70.3459204396894, 71.50767941628733, 74.9377215293146, 80.54513408291726, 79.25834563470657, 78.29057139735069, 80.60590728636711, 80.13195160896548, 81.89286047412504, 84.4848019076932, 82.38124262902045, 79.74315843274518, 79.26308385787472, 79.55464147752332, 82.35266423994496, 88.14819366701188, 68.60470971753521, 61.58644022480134, 72.93244900241976, 75.33701096811603, 30.671934543117402, 0.9010163550415348, 0.40468092046437726, 0.08191713822945472, 0.6323705253101165, 0.6909552913519644, 0.41250712148124175, 0.2796292629453444, 0.18887309417609247, 0.025682059612365502, 11.320561420532966, 56.79207224999705, 59.17901885124945, 24.546300403533447, 23.397381305694584, 48.11003138942104, 53.70795572957685, 56.07767920340262, 15.031907096985849, 0.10371935704062063, 0.033278905396019264, 0.11587488179605816, 0.07215574548970308, 0.0444293572687574, 0.02101521094089314, 0.07993123148598018, 0.05268103968832762, 0.08079515649907051, 0.017096200064125083, 0.02555258692272248, 0.031194397391030387, 0.061738700230395606, 0.04017185427308564, 0.06778132215502762, 0.08381702095991181, 0.03004435385997978, 0.043351149802366575, 0.018957596452486132, 0.028834620588308865, 0.014202960808160565, 0.03087298137195889, 0.03887723462896482, 0.026537758756368875, 0.009333303765273623, 0.050983392678561716, 0.09334111796511758, 0.047447406611735785, 0.03726854957940598, 0.021964725212103898, 0.028045147830139727, 0.02610321453351888, 0.03825917787429306, 0.047322201031831004, 0.004489235016667555, 0.003949392248027688, 0.011887009980367317, 0.05603379667586377, 0.03210532189827533, 0.022632949234497164, 0.043003981737720395, 0.022916612440660115, 0.014281884143729846, 0.07019039288523697, 0.04568753411032019, 0.044410224222848495, 0.028977310209865534, 0.06242759330498596, 0.006660873552919516, 0.057163454607249274, 0.038600592618627895, 0.0670437710059266, 0.06835307655555588, 0.09963294446107843, 0.030503487589979367, 0.0659110717054817, 0.03660282300364587, 0.023025860409102133, 0.027360265225832982, 0.05294917812270503, 0.06103320986092572, 0.07427957104218584, 0.05538263343154423, 0.04033504632271586, 0.046244188917860876, 0.009139106222127956, 0.05638712408742117, 0.09401232589997592, 0.0817542679367527, 0.009166626973197827, 0.01646728784356627, 0.06718531341081665, 0.05840929360279153, 26.836644910996963, 63.927624533253336, 72.22795209577008, 32.411544938241285, 25.8712907760374, 52.240710796848425, 94.50508486840033, 91.05637227335285, 36.751965245892926, 6.9506855837760435, 0.1302770666417576, 0.08312576450407506, 0.2764895281964733, 0.14583171585634833, 0.4941840145376421, 0.018639288835167404, 0.6728699166447886, 0.04451908914732837, 5.504186557185266, 31.150581375245128, 91.37803800644414, 100.75241642613565, 79.026062873102, 84.28112891412552, 93.76256450530022, 87.51622922958867, 77.18381189530896, 82.48025109691005, 92.04350732987928, 92.72860419365668, 87.02271661450787, 76.61231471646217, 64.78321898368098, 74.51519596961238, 82.44048610810312, 81.99333590845909, 77.15787718372961, 75.05452186830583, 70.18213795077416, 68.56547032633136, 70.86861548885223, 70.72686103082472, 70.26639830681586, 70.82309246063232, 74.10908945145147, 78.9847054020051, 80.12642106702252, 77.71091568854548, 73.88507504617014, 46.06093029822073, 53.120816138482866, 80.54808370528683, 79.37352211244645, 73.83601404005482, 72.8180883776757, 71.99559088676207, 70.24525673158708, 69.65566173676523, 69.68278884887695, 69.7274568003993, 72.0180582231091, 71.67472531718593, 72.62277003257506, 71.01964242996709, 71.04068202357139, 75.11300440757506, 78.77900062068817, 81.81387178359493, 81.63443903769218, 81.01968596058508, 79.92890619462537, 78.9581117322368, 81.35279716983919, 81.30129644947668, 79.88270067399549, 76.56641514070573, 77.70139217376709, 79.99463727397304, 78.81581598712553, 86.19127611960135, 74.57900508757561, 66.11146296224287, 70.32912485061154, 81.06224367695471, 44.98771098352248, 2.805674816331556, 0.21379345937842326, 0.2159770244672414, 1.1190932724745044, 0.7205903914666946, 0.7371999131095025, 0.18336205683167905, 0.4511956648240167, 0.15089195642259814, 8.396145182271159, 58.83681558793592, 84.10688938633089, 48.431053853804066, 14.720330680570296, 26.615297717432824, 61.37261221485754, 64.27298922692576, 27.238748650397024, 0.6393175331815597, 0.09139712389198043, 0.03640704157371675, 0.014914514763551134, 0.01843152004444311, 0.01307942296168016, 0.08635889303179518, 0.1136040286491475, 0.014922449519226869, 0.09646418264075633, 0.03801057085154518, 0.03982829065212319, 0.02911222212377095, 0.06464908740693523, 0.10887803990514049, 0.08760813728816087, 0.03815343092766501, 0.02980680148597927, 0.016628760025806485, 0.014534596440141961, 0.09363043873060135, 0.01914491644129157, 0.04537190971595626, 0.03304069035596425, 0.04022617373735674, 0.05131246574643639, 0.03752420078061762, 0.02109173546364952, 0.06487417936084733, 0.02739310741514689, 0.019274412113572323, 0.04592782524865001, 0.04944730212070769, 0.11985143736725855, 0.12111749725356219, 0.17867868555889976, 0.15503875971321138, 0.10456356295053998, 0.13082863462548103, 0.14843164973201292, 0.15243355515262774, 0.17416026833797657, 0.2720477504114951, 0.21206125797283268, 0.11726006069370817, 0.20050099119544032, 0.12219206580231268, 0.15394532241888587, 0.16547807131803807, 0.17094219343796854, 0.13052930875170615, 0.1827547023253095, 0.17790922684775246, 0.15849476620074243, 0.2435190038334939, 0.11338905671671515, 0.18852162835819108, 0.12091518875451819, 0.1465912001027215, 0.18593770572014395, 0.22497875676039727, 0.1609963497086879, 0.257072723320415, 0.19602446366221676, 0.20046371335704483, 0.106084224497599, 0.1293810961707946, 0.2282627305436519, 0.15534871888737525, 0.059805002378960775, 0.23035195956547416, 0.14346805881829033, 0.29871309536599344, 26.07362231900615, 74.43537573660575, 91.6449474519299, 48.30757764077956, 47.61154913133191, 51.533895769426906, 74.51429382447274, 105.20868393682666, 59.85711428426928, 10.45799986008675, 0.19843382550583732, 0.35477246788720934, 1.8025873577402485, 1.6151219654467799, 0.6625542669526993, 0.539054274559021, 0.48073337984181225, 0.13054355798709777, 3.1113054098621493, 23.112630959480043, 85.5700275974889, 106.85545182997181, 79.18222811914261, 80.75582027435303, 93.10162944178428, 92.49299526214601, 79.2221264685354, 85.43712985131049, 94.90140899535149, 98.79190598764728, 94.65504492482832, 84.12122172694053, 70.59065280422088, 80.55694826187627, 83.9706733149867, 86.10172056382703, 80.78558321922057, 81.33055733096215, 72.7969232682259, 71.10997461503553, 74.28538430121638, 75.75532390225318, 76.76513810311594, 77.40253110085764, 77.23579114483249, 82.58650026013775, 84.71981463893768, 84.83299070788969, 75.17408355589836, 58.14939275864632, 61.83835052674817, 81.8959669913015, 86.47348280875914, 79.49502145090412, 80.87247156327771, 76.99807982290946, 81.10349916642713, 78.20339279790079, 78.82087584464782, 76.19669252826323, 80.31896237404116, 79.08029356310445, 81.30476382470901, 77.33646269767516, 76.71336281684138, 76.52785039717152, 82.48876264018398, 85.37153997728902, 84.60232396279612, 83.80242716881537, 82.01093950579244, 82.14684963226318, 83.27792782937327, 85.8257818222046, 86.96300245100453, 79.24363674656038, 80.21859676607194, 83.17720920808854, 84.18744702492991, 87.47899809191304, 73.2172679901123, 69.15960742581275, 78.71401479167324, 83.90633075468003, 36.4293267649989, 1.4642910202664714, 0.36677623828572614, 0.1782841809214123, 1.9501214282166575, 2.151294768817963, 4.400983664297289, 2.499918952103584, 0.9256704127596271, 0.2960292442191032, 16.861208369654996, 75.28572205574282, 68.90390026953914, 36.17614953748642, 34.034249090379284, 60.420582371373335, 71.24495121740526, 78.19099810815628, 26.337060466889415, 0.5163553957977604, 0.17660686205471718, 0.28068297091991673, 0.1316623221482, 0.21386778522883693, 0.1090419290947818, 0.27161552360461605, 0.18168522826125547, 0.18888458549495668, 0.2050897812530879, 0.14736090396200457, 0.13599185273051262, 0.14335666963409993, 0.21864878674668653, 0.19347161355037845, 0.22511728077886567, 0.18054472252486214, 0.16011982254924315, 0.10168820514433807, 0.11585632714653209, 0.18032185222593047, 0.11029694965409656, 0.14699593967487737, 0.14499412128521552, 0.05848966388692779, 0.1638091947402685, 0.15379454099362896, 0.10125045484352498, 0.12521354721919184, 0.11829362821675117, 0.12203980582736193, 0.10313616494738287, 0.17688469150133673], [0.05204828170638892, 0.07123260954094511, 0.09791621037067906, 0.06214015711579592, 0.06687630418567889, 0.048938861056681604, 0.04165129645937874, 0.040800165114623886, 0.047445460748408115, 0.05028506140074423, 0.03316005068500677, 0.04947251024385614, 0.11765770629168519, 0.0267619084221341, 0.1253900615378253, 0.015690674828816087, 0.04147118152750116, 0.07134503294383326, 0.039416422631831906, 0.04214585984065648, 0.06150117083903282, 0.039437202766778014, 0.06225324701517821, 0.035857737379809546, 0.02659458907381181, 0.00573700120214433, 0.08217308054407758, 0.08847504238327665, 0.07592977039636144, 0.11005588476696324, 0.01646030112169683, 0.05003186551132991, 0.026587793873923442, 0.004964090786093185, 0.053726837805081765, 0.07994201800395405, 0.07132598033715641, 0.02097342275984345, 0.09575871525392418, 0.022994370364974585, 0.1971716190417928, 4.392101457042079, 29.693918997241607, 65.61505956034507, 75.97809883856004, 65.41821933561756, 24.874226239419755, 46.17811895185902, 84.56334344802364, 75.80494188493299, 22.146729653881444, 0.42010564116701005, 0.11792779058939028, 0.18494349213377123, 0.07983546283456587, 0.15410566462143777, 0.06620737153195566, 0.4084637094168894, 0.040922666404155955, 0.22013012500059223, 1.7395840416992865, 33.32034241768622, 94.58567388596074, 84.03998944067186, 78.60673796746039, 77.84487247467041, 84.92500951213222, 92.26776492211127, 86.87301543451126, 80.58263194176459, 71.35374207650462, 82.43164508573471, 80.04406698288457, 77.87537282513034, 79.68774318695068, 82.87444929922782, 77.77268517401912, 80.35165140705725, 75.35470085759317, 74.11946019818707, 78.24171435448432, 80.69684351644209, 77.24656197332567, 77.34989289314517, 76.44183281929263, 78.05743355904856, 78.28415439974877, 88.47442503898375, 60.51875537441623, 54.61465081860943, 36.030535467209354, 57.598958707624874, 87.45478137846916, 67.25196269250685, 80.77847588446834, 77.62597284009381, 74.20576018671836, 67.96194307265743, 74.70796477410101, 70.96847118869906, 76.22125441028227, 69.08008529293922, 71.57371644050845, 67.57659373744842, 70.62712300208308, 74.22743520429059, 81.31344010753017, 78.99081645473358, 81.23576933337797, 83.77498626708984, 84.89022593344413, 82.12275058992448, 80.65310124428042, 74.16395556542182, 75.10496354872181, 75.0653632994621, 77.59102452185847, 71.49920709671514, 64.37072684687953, 57.35325751766082, 68.89773430362825, 79.27552561606132, 53.03432003144295, 8.636110886450737, 0.2460334269750503, 0.11404494289308788, 1.2628038900513805, 0.7574069223576977, 1.396507560726135, 1.1299606893331775, 0.06973885300178682, 0.13985315037350501, 1.6632781297929826, 31.474180836831373, 70.46514480344712, 35.556854355719786, 16.259884507425372, 28.324164575146092, 60.78084422696022, 55.492885189671675, 34.664166050572554, 8.430946411625031, 0.3590858186925612, 0.15134784002457896, 0.05213800209364103, 0.08745299682261483, 0.15260567978745507, 0.034208491805099675, 0.02590968923252677, 0.055579996833036986, 0.014792785307602778, 0.02622331605262814, 0.04559241280320191, 0.0453969914345972, 0.04777261859647209, 0.06722423067737011, 0.0285212638142008, 0.06443013181729663, 0.05396865728882052, 0.031459611284756855, 0.07996286325637372, 0.015400206846665713, 0.024406347018215927, 0.04832544296439137, 0.08524787401960743, 0.034442137130686355, 0.03860346161790433, 0.036827087582599734, 0.053562600045434894, 0.03792254351860574, 0.04294201671596497, 0.016517292317603866, 0.03780746179062032, 0.04507465227957695, 0.04484917728170272, 0.003623610964202653, 0.06456787442608226, 0.0603114094795479, 0.04625767972620745, 0.05712558305071247, 0.024920120054195007, 0.047918780511545564, 0.028784097089702566, 0.04508583716327145, 0.02806102691759025, 0.06359722187382079, 0.03187935277368994, 0.02428590267476055, 0.1217721806718938, 0.04746148730778406, 0.07282630224982578, 0.0245778338848463, 0.04439840731661647, 0.06932770893458398, 0.017027460909899206, 0.022035818171477126, 0.04724512492576915, 0.01564933672442191, 0.018576356627407576, 0.020331693888311426, 0.0891224479663276, 0.015517769741915889, 0.03148073998970851, 0.004938173074004871, 0.10094871579278862, 0.040499046595106204, 0.04605792229995132, 0.04842512632509874, 0.026634546304722468, 0.05679320431344452, 0.06092535617250589, 0.03796108157163666, 0.02236865081584021, 0.08277419909474351, 0.11139536651992991, 0.03539865919118447, 0.10589803448848187, 9.055742717558338, 52.107714991415705, 76.5519102158085, 64.79320141576952, 43.71063432385845, 25.959363675886586, 80.30783068749213, 105.3926117189469, 78.49424439091837, 16.016993695689788, 0.8910694081456432, 0.1915464499184201, 0.17707507967227892, 0.44795244691833375, 0.10569523569316634, 0.1262096147383413, 0.2643222439913981, 0.10499775094250519, 0.2780691708528227, 4.61788583186365, 47.22443080717518, 100.11047347899407, 81.39885364040252, 80.91879475501277, 83.66109632676648, 88.69045349859422, 91.55187745248118, 82.52171839437177, 84.52874814310383, 77.59837504356139, 85.0094424524615, 81.24322183670537, 80.16096145875993, 79.53553953478414, 86.58038308543544, 80.34510889360982, 79.5238273374496, 74.42232208867227, 77.88495125309115, 82.61490606492566, 84.3332572137156, 80.03321770698794, 78.21335561813848, 74.285580419725, 79.01485273914953, 74.92477770774596, 88.00632938261955, 63.75240441291564, 56.22492497967136, 43.95331528878982, 61.42255183189147, 89.71831060224964, 68.26748001960017, 79.19725079690257, 75.43332869006743, 76.3535245772331, 70.94317974582796, 72.7848659023162, 68.67733632364582, 74.04166390818935, 68.44032318361344, 71.85922576535133, 67.61999084103492, 72.71651467969342, 74.63755822950795, 81.90120727785173, 81.14172658612652, 82.86569456900321, 82.08071847115794, 86.79716464011901, 83.61557329854658, 82.44257280903479, 78.50719605722736, 78.377122417573, 80.30739922677317, 82.66830521245157, 73.8498600067631, 71.16214998306768, 62.08403210486136, 67.30116490394839, 77.88062880116125, 68.48055101210072, 15.193426378311651, 0.07275815106808178, 0.13712017766890988, 1.355950743440659, 1.4554210704180504, 0.7348373592380555, 1.0456471361460224, 0.0964081203264575, 0.3166325354287702, 1.8736113079132575, 29.439261074989076, 82.08180889006584, 59.43982508874709, 23.21788384068397, 11.485067586744986, 50.5581198969195, 65.7180884576613, 44.87739432242609, 15.950901758286262, 0.4118334544041465, 0.11907221103507666, 0.02881169732239458, 0.09340751480551497, 0.07667369539699248, 0.04113818608945416, 0.028013962305962082, 0.04989316529263893, 0.03762204553030672, 0.01340679435675303, 0.08639482255544394, 0.10322448722417317, 0.07155268107570949, 0.09165764741239049, 0.06137371296063066, 0.07682514331874347, 0.030467515931494778, 0.05108775683648644, 0.034188282405657154, 0.040442800419705535, 0.054287794196317275, 0.10419559559874958, 0.012911338483043497, 0.02761844834763437, 0.08466814464378743, 0.017661327804108302, 0.07381443309807971, 0.045933364064342556, 0.07670826894501526, 0.04598533163868612, 0.03311225062897129, 0.1463267312295014, 0.03872847184538841, 0.016808218037288998, 0.19997910145790349, 0.17658870577091174, 0.21623536463706725, 0.1498997193430701, 0.22936698499946828, 0.13736941671419528, 0.19254688413873797, 0.1615710535477246, 0.19080470826837326, 0.2543998272308419, 0.22455333281428586, 0.14804002558512075, 0.18294939591038614, 0.12868780192107926, 0.19394579133199108, 0.24241625091000912, 0.13030977859612436, 0.14493936132038795, 0.12387882287223494, 0.16457957275692495, 0.20165016904713648, 0.11253794069371878, 0.13243017207470634, 0.11331737386964022, 0.18479122449794125, 0.15567677305831065, 0.23813863044544575, 0.16930772952975767, 0.2155019733453951, 0.22184055418737475, 0.24859134858894735, 0.20639134931468195, 0.13097235272007604, 0.25964644166731066, 0.14219166440588815, 0.2498876766091393, 0.22067361841759375, 0.1178274637148265, 0.11324942953163579, 0.12368216810207214, 0.21448319898016993, 8.34228515625, 61.129664528754454, 94.43964404444542, 88.79331373399305, 79.89074937758907, 38.246050957710516, 62.97199003158077, 93.97476473162251, 94.59472671631845, 33.800534663661836, 1.0911317986826743, 0.2753976996867888, 0.9466580349591471, 1.8545490791720731, 0.3279598501901473, 0.202368299867357, 0.3630173819199685, 0.13931079076663141, 0.25311341238839014, 2.633323174330496, 35.85883371291622, 99.83780599409535, 87.46741141042402, 82.8133701509045, 79.96907910993023, 91.89106049076204, 98.06268245943131, 84.05410212855186, 84.81586563971736, 76.48233521369197, 90.90367440254458, 86.99940204620363, 85.51934273012223, 89.79934677000969, 90.74396333386822, 85.9640375260384, 86.45198822021486, 86.11868089245212, 88.17219072772612, 94.59893149714317, 92.08672400443785, 87.88439858344294, 84.15563660283243, 82.65990349554247, 83.8340336276639, 82.27559751079929, 90.29770743462348, 64.08102450832244, 64.32874179655506, 47.32107800822104, 59.987733133377574, 94.4395342180806, 71.94253690781133, 83.93101815254458, 82.9704689210461, 81.05952939679547, 74.08221337103075, 75.91999284682736, 74.59419250488281, 80.09479107395296, 73.2824577823762, 75.20018300702496, 72.45967788081016, 78.1849027449085, 83.11897770051034, 89.0071927347491, 88.64593459713845, 87.07682963340514, 91.67063113181823, 91.45944287700038, 85.66194442010696, 82.09388979019658, 80.34214358175956, 77.01723667883104, 83.6614336506013, 79.85172963911488, 71.98775399115779, 69.59997976979902, 61.7908114002597, 81.21817358078496, 86.8181336310602, 62.322504366597826, 9.595048023808388, 0.26563292849929104, 0.18963021887165887, 3.730081858173494, 2.4012720777142436, 5.4200061194358335, 7.03622414219764, 0.7522124172218385, 0.4822498968532009, 3.4461544742507324, 44.28457513932259, 81.65195634288173, 45.599604652773955, 26.91229566451042, 38.53508649333831, 76.74440445438509, 76.37390521264847, 52.05407265693911, 13.640850282484486, 0.6023021258654133, 0.399042513341673, 0.14399212424553212, 0.2041862877987085, 0.2275093596789145, 0.16419519580179648, 0.09304232069201047, 0.2184184087860969, 0.10582059066021636, 0.12363171355137903, 0.17130813831763883, 0.2378205813828015, 0.14982766111291226, 0.28442629102256994, 0.18637445244577625, 0.16299357157080405, 0.1820890485279022, 0.18714634731652277, 0.185459605568359, 0.1327431343135334, 0.11929714977140389, 0.19836526063661422, 0.1330570005361111, 0.14865350879488454, 0.1730340578022503, 0.09208832672166248, 0.22734014617819942, 0.1231686517055477, 0.20985461831573518, 0.21710429220430313, 0.10358935958074947, 0.20312983722936725, 0.16321212113384279, 0.07705356775512619], [0.08868636007631019, 0.09043903901211678, 0.07110686386905371, 0.05613917590028817, 0.03179672253017705, 0.02142981006463449, 0.05081648127205911, 0.043161259588575175, 0.02920588977905291, 0.08512089494615795, 0.0516537502558241, 0.04670096118183387, 0.041636346253536405, 0.007576143215109985, 0.04978643392302817, 0.04343424352907366, 0.0554104232709975, 0.055966070672917756, 0.033913287484357436, 0.11912647304275345, 0.05934004446551685, 0.060839619442460045, 0.11559643181821994, 0.19315509666358271, 0.05792475065156337, 0.09113116880818721, 0.057268757222881245, 0.1753036392432067, 0.03656127805551214, 0.010649035834977704, 0.08501992455773777, 0.055280536893875375, 0.012306158708768987, 0.028573888308939435, 0.06364143663837064, 0.1193637304729031, 0.09139277251257051, 0.12862881315090965, 0.0201453066115538, 0.02645788068372396, 0.13185133136087848, 0.1647491539798437, 1.6648676703053138, 21.187274763661048, 67.76827212302916, 71.03089178762129, 60.46605048641082, 27.315809495987434, 26.263135556251775, 49.22404335391138, 84.55304330395114, 58.834701430413034, 8.389374190761197, 0.08921360476843773, 0.23064652037236, 0.7017832393607786, 0.3869976499868978, 0.42417647917905166, 0.2827142377293879, 0.2718132968631483, 0.03541786118500656, 0.37893717928278836, 7.300502167594049, 56.609493763216086, 103.2279105340281, 92.32634159826463, 86.53864122206166, 76.41661197908464, 83.68969040532266, 92.2502789958831, 92.38146658866637, 84.51537286081623, 84.08607729019658, 83.00988089653754, 88.27552949228595, 84.06736758447464, 79.69787859147596, 75.61564045567667, 74.68779594667497, 75.56585773344963, 79.20497002140169, 77.14194451608967, 82.30665483782369, 81.13357590090844, 77.94007624349287, 79.85386340848862, 74.54424504310855, 79.3315056831606, 74.61652648064398, 63.27968428211828, 52.352659163936494, 66.99165067365094, 92.50061250502064, 85.53282783877465, 80.05621064093806, 76.63721392231604, 82.50195749344365, 86.25927432890862, 80.89329934889271, 78.920284394295, 76.39536057749103, 81.04747203088577, 81.57510926646572, 82.52905322659402, 84.25456662331858, 85.10364993926018, 76.94140941865983, 80.51049170955535, 77.4412448944584, 74.26381126526864, 81.9159475449593, 81.64914008109801, 77.88717131460868, 88.52687497292796, 80.94598462504726, 75.3780468048588, 55.71155732677829, 53.34253987958355, 70.87456964677381, 80.41232262888263, 59.69194327631305, 14.472093678289845, 0.10084790628283255, 0.04108072183425388, 0.7224378891048894, 1.1502811408812001, 0.2351453410641801, 2.6397556162649587, 0.4890367923484695, 0.3098002568848672, 0.05857031379315642, 14.697942772219259, 55.02780583596999, 65.85902706269296, 24.612982657647905, 22.102036206952988, 50.046548689565356, 68.81404661363172, 47.49126964999784, 17.761084418142996, 0.5998039437878517, 0.3432630693479892, 0.1759946199073907, 0.0640184361667883, 0.07659547781992344, 0.027171780783382636, 0.00911524449850643, 0.04538255450766414, 0.034025592143617334, 0.019233510679294987, 0.0373595608248105, 0.04052498250178272, 0.02841320902770085, 0.012158454084137996, 0.03326592403614233, 0.04415339707667309, 0.1073333998060515, 0.06862065574574856, 0.05771445951634838, 0.011940714659079189, 0.07565464524011459, 0.030752686415648753, 0.08418594592160757, 0.08611559116792294, 0.10771889524954943, 0.05992547736593312, 0.021561634644205054, 0.026247116489215728, 0.0480091865474899, 0.010875056670497983, 0.08552124483450767, 0.06253728943486368, 0.03650909597654978, 0.04551237193687309, 0.05217378223014455, 0.05219361241606455, 0.019331175398321885, 0.008728933171369135, 0.01432011001593163, 0.05712785067096834, 0.012217589368623112, 0.08442198527195761, 0.08952571664966884, 0.0300418698198853, 0.05735995615982721, 0.020210855009575045, 0.03848282192202826, 0.025543610287469723, 0.05957030368247821, 0.03292341378607577, 0.09745299530726287, 0.05567761558678843, 0.0075333165061179435, 0.034488366706477064, 0.058389992017539284, 0.08479490155173887, 0.06391984065093341, 0.03739780393399058, 0.019719331082136884, 0.06202417523449948, 0.09465846743795181, 0.042950198534996285, 0.09436383768315278, 0.08719658719435816, 0.03335015157297735, 0.03336250857119599, 0.10992902826758162, 0.057244537353155114, 0.014747900216119185, 0.027010756762578126, 0.020895304774204572, 0.0551338731912115, 0.011984482219803238, 0.03979542548017156, 0.02618657256055984, 0.09946836579230525, 0.03193985265229018, 0.14721986717514454, 3.7291483340724825, 36.36474886248189, 84.22994982811713, 78.91275344356414, 40.885562896728516, 16.920693074503255, 42.26502518500052, 82.8354452502343, 115.5152371621901, 56.88871945104292, 7.837170170199487, 0.2112825908848355, 0.14131452437610398, 0.46578397073092004, 0.5852832068358699, 0.22923350183954164, 0.9138982154188618, 0.5325714546826579, 0.3111797360883605, 0.27432290897254025, 15.349188600817035, 74.33442961785101, 105.3692893059023, 81.36428186970373, 81.79407165896508, 78.54561175069502, 91.94772305027132, 92.41092358866047, 89.06968393633443, 83.94627617251489, 83.806333849507, 84.70718460698282, 89.73146623180759, 86.97353793728738, 82.63643987717168, 84.41130453540434, 80.665543002467, 75.86700947053971, 77.70012917057161, 80.82422641015823, 82.37962661250945, 82.97620342623803, 81.55088470828149, 81.83499766934304, 79.65052773875576, 83.02461331890476, 66.06176653215962, 63.82861606536373, 53.94256053432342, 62.49024452701692, 88.82878764983147, 80.66731591378489, 83.91810570993732, 79.93913573603477, 83.57979343783471, 79.71076749986219, 82.95146895993142, 83.2972651143228, 82.89766188590758, 82.74086121589907, 83.53213664024108, 81.54454615808304, 84.78368651482367, 87.34350373668056, 81.69827168987644, 82.32128527856644, 83.42846839658677, 82.00240442829748, 83.55504328204741, 82.56101269875803, 83.9961608763664, 86.84786519696637, 87.69357527455976, 79.19594857000536, 61.44920433721235, 57.65033391214187, 69.77893398654076, 78.1754655222739, 72.3618539687126, 26.734837831989413, 0.8308347951500648, 0.054452844009163885, 1.236487727972769, 1.3521445734846977, 0.41535234138850247, 0.6694612543909781, 0.44593144568704796, 0.35655705438506224, 0.32149271979447336, 12.483938374826986, 54.50173754845896, 78.76416621669647, 37.59824406716132, 14.600172792711566, 26.34792150989656, 65.76573741051459, 59.62547479137298, 23.472084806811427, 1.8823932495809372, 0.44130323274481686, 0.12654025828646076, 0.0333343931443749, 0.023023901139235785, 0.03288882491629451, 0.03195329366492168, 0.07303331452872484, 0.007800211005228302, 0.040362533557439045, 0.08247422970711224, 0.001957629001774495, 0.015428003389388325, 0.05392414758041982, 0.07673164228758506, 0.058600941988369154, 0.02066190268153385, 0.02827440155670047, 0.037347422161650275, 0.03087608785849185, 0.03394392717088904, 0.02645039791992355, 0.07618009728649933, 0.044155404227034706, 0.011578337833916229, 0.028603825109800505, 0.020981497326565367, 0.04604697107307373, 0.11446948583808639, 0.03761739920704596, 0.039571486488585515, 0.03434138507732461, 0.0745158632015509, 0.02102106002219502, 0.007107315121233584, 0.06592997875545295, 0.14611918268905533, 0.2037367627264992, 0.15349293217783974, 0.1786253045523359, 0.10961865540593864, 0.16051722299908439, 0.1829095899818405, 0.15127460201901777, 0.1447569098203413, 0.2252056413600522, 0.20958143136193677, 0.11609844157412169, 0.17782213797252025, 0.09227037219510925, 0.2756015710051983, 0.09604110292369321, 0.11962722641445937, 0.15250970429230123, 0.15124356013632592, 0.23864918208170324, 0.17513168314772268, 0.18137111689054197, 0.21482354120141078, 0.40863828553307446, 0.1891333955310045, 0.13370022327909548, 0.2369406527929729, 0.36886563584689175, 0.115568952244376, 0.14956843228109423, 0.1616839289424881, 0.13758968231418442, 0.15013757432180067, 0.1557573195426695, 0.13329605061200359, 0.202878805538339, 0.18778391633062594, 0.20792796847320374, 0.11788865881821803, 0.24126482075981556, 0.21966612086661402, 0.32332808259994755, 3.46322413894438, 39.69233082186791, 96.15663805315572, 91.14309587786275, 72.8386337526383, 42.02318360728603, 42.97528405343333, 62.97703812199255, 103.55566378562682, 78.75963195677727, 16.72479029624693, 0.4297936503444949, 0.5000775289391318, 2.7224614879777356, 1.347898117476894, 0.3539715382841326, 0.8990610535106353, 0.2627649711024377, 0.17748660678344388, 0.519051534994956, 8.867449337436307, 65.3062984251207, 110.18002925380584, 91.89838747824393, 86.71734440711238, 72.81051820324313, 88.89000800348099, 96.3145212973318, 101.00685273447345, 85.61294617191439, 87.77072829584922, 94.29819553129136, 95.3983497619629, 91.57870646445983, 90.0764779121645, 90.06222401895832, 82.29535056698708, 76.16016741721862, 77.87488645122897, 81.61397995487337, 89.20238556400423, 90.91075820307579, 85.9897368954074, 87.10400381395894, 82.89124488830566, 82.09235222108903, 77.47825637940439, 75.00808100546561, 70.71350143801781, 76.89149333584693, 92.77473911162346, 90.75994306995024, 87.8355650747976, 85.59666833569928, 91.1212404312626, 94.02574769912228, 93.6310003649804, 91.87750477944651, 90.06775456090128, 92.54137377585135, 96.55638248689714, 95.16859300674932, 89.37143187369071, 92.05483513493692, 84.70068916197746, 88.62166297051215, 87.41542431616014, 81.05410868121733, 83.95121835893201, 88.90681928203952, 89.62053375859415, 97.02942032967844, 95.5529695941556, 88.06962074772005, 76.84000830496512, 67.1634740214194, 79.74726123194542, 84.8304803909794, 64.19032135317403, 16.19543408193896, 0.3261465507168924, 0.09532807424904839, 1.8799130858913546, 2.2014371233601726, 3.8972314567335196, 10.635828356589041, 2.1745455986069095, 0.7475832849740983, 0.8331211692383214, 20.315484846791914, 69.45086694532826, 76.93036402425459, 36.142495601407944, 33.06905969496697, 61.978924351353804, 82.62306459488408, 68.8801150168142, 27.211125358458492, 1.2540516113081288, 0.581806822409553, 0.39445962216104236, 0.13228340495017268, 0.12819448726311808, 0.10864390045284264, 0.11014543278443237, 0.1797460145767658, 0.16164157960203387, 0.10649760554154074, 0.14118732313715643, 0.16306801999528564, 0.10301349128806785, 0.170450885930369, 0.13264279211721114, 0.1384191257098029, 0.17139364905174703, 0.17973194920247604, 0.13456545830253633, 0.10802905360657362, 0.1607706142409194, 0.09289012200409368, 0.18726763435669486, 0.145543513579234, 0.2011011751188386, 0.18510642371350722, 0.1866650449172143, 0.1116194932030574, 0.18399148999202639, 0.08773199838375853, 0.23518497845338238, 0.15393327951671618, 0.15768138000801687, 0.18040043752520316, 0.2678143485419212, 0.2402615213706609], [0.03597787145765559, 0.017140453133071144, 0.007634946687762896, 0.09154866374428235, 0.010243687222922042, 0.265994951008789, 0.07135434857299251, 0.13011154568483754, 0.16918158549214565, 0.03491100975342336, 0.07661184911886532, 0.054661702559960466, 0.08656386751681568, 0.028897118041171666, 0.0658498612803317, 0.06038188190770246, 0.21189388308313586, 0.06925345203208347, 0.131298721497578, 0.043145367094585975, 0.024593856613782626, 0.04146446293640522, 0.062473171706041025, 0.3103618299768817, 0.03709005492348825, 0.07671894821067972, 0.14647063318519823, 0.027867223909725587, 0.009714388457547513, 0.08453924268964799, 0.28135801695527574, 0.023892562490917986, 0.06540465694401534, 0.09683221127958068, 0.13260678598476996, 0.09196050495149628, 0.08439557056032843, 0.058676930249578534, 0.041560269892215736, 0.07998871872381819, 0.09442206036539809, 0.06806579358395069, 0.16672644223417007, 0.0988572191507105, 9.804100548067401, 42.527482740340695, 68.75362642349737, 82.95612089095577, 54.448530597071496, 28.296725634605657, 26.57480120658875, 62.18022823333741, 83.72525061330488, 45.33420139743436, 4.486983101214133, 0.25495150246687476, 0.6856530436104344, 1.806925376576762, 0.7412647143487008, 0.19123100555471836, 0.1448884930822157, 0.08069043227982137, 0.11052480718541531, 0.03399235541902242, 13.94710796494638, 64.89296690110238, 106.27268960399013, 111.8737949863557, 98.05522995610391, 88.87132183198007, 75.76130943913614, 88.94851407697125, 87.8102893214072, 90.51415166547223, 85.72284313940233, 76.60961612578362, 79.29467462724256, 92.66404198062037, 86.401640676683, 82.45807401595577, 83.23484451540055, 87.05312282808366, 82.90981338870141, 83.56420593876993, 81.20528467239873, 85.16041448039394, 74.73884951683783, 89.21001065161921, 54.80932589500181, 32.887395120436146, 35.16439768575853, 22.726608937786473, 80.70842235319077, 84.97790659627607, 84.85530899417016, 96.6162770794284, 82.62161331792032, 67.85498788279872, 82.09518417235344, 79.26732001766082, 80.34954117190453, 76.53560100063201, 72.93222150494977, 71.70986190918954, 66.53573005430161, 67.83223813579929, 79.8004093477803, 77.36207577490038, 75.47274066555885, 71.73195269800001, 66.89588208352366, 67.94169579782795, 57.52501418513637, 35.27730311116865, 34.905540866236535, 49.10944738695699, 81.22449644150274, 77.75059438520863, 50.84087179553125, 11.296286852129045, 0.4304705043473552, 0.06588918457348501, 0.7726471690881638, 1.2576240325166335, 0.3218592162574491, 0.3634852777806021, 0.5155418717092084, 0.3815419395123759, 0.12332746173225104, 6.406507713179435, 43.4901382846217, 69.16930352487873, 52.31664788338446, 27.7513788976977, 42.204703054120465, 61.16886077388641, 54.93707749151415, 27.097319749093828, 6.918479002291157, 0.30282205391314726, 0.09602111568974872, 0.1797035426622437, 0.04251639741743284, 0.03777257031610897, 0.017658935694564736, 0.04753770922581035, 0.07113893230956408, 0.04899459395317301, 0.041393278046481075, 0.036177782101496574, 0.04158906330684981, 0.06489891633992234, 0.09194617910731225, 0.015422053759046381, 0.0033944822057345586, 0.13268933961949042, 0.1323004121020917, 0.0850902667509452, 0.13917897767837972, 0.06886206537244782, 0.03251583585816045, 0.04552362959892039, 0.08795295346287951, 0.03327963317954733, 0.31093811195704246, 0.04405195937461911, 0.0982330336926445, 0.1256028577805527, 0.05603119963780046, 0.06587554054755358, 0.09243944779999795, 0.08586156407311078, 0.029407102772365176, 0.0366992236775977, 0.08078256967447459, 0.10089740322362031, 0.010449174986851793, 0.04639940982263896, 0.007539730098459029, 0.10583526890484557, 0.036497819162304365, 0.07047749199574033, 0.07325146572604295, 0.15266546528906594, 0.1329674908230382, 0.0621821578862446, 0.03604291998330624, 0.08252861428885691, 0.05953370766233533, 0.08849483809524006, 0.07847977832200066, 0.06440812211123205, 0.08270148968985004, 0.022676736905029225, 0.07998959972493111, 0.07607999257743359, 0.0261762744236377, 0.04757002664489612, 0.05932644640486087, 0.19975364178178773, 0.12454871313586352, 0.04221023803937339, 0.13271961541425797, 0.01227845409659729, 0.0496190820159691, 0.030833899396501725, 0.18228887490207152, 0.05623007606294367, 0.03665934114025966, 0.042628636959219174, 0.011192379864834009, 0.031070467347519535, 0.025989471544181148, 0.04008563107720787, 0.04824318044308213, 0.029862815919782848, 0.047862928871425896, 0.10220540642377832, 0.10432796027030676, 0.1619844805569418, 16.584104684091386, 56.474646599062034, 85.3506023653092, 69.84941897853729, 29.229171083819484, 20.464264269798033, 44.214839320028986, 97.02564700957268, 94.23266841519265, 44.32419500043316, 2.3613631869516065, 0.4390811181116489, 0.5574652059904991, 1.2414858081648428, 1.6184113631325385, 0.45226622673292316, 0.8229319546972552, 0.18810778766149477, 0.6244388186643202, 0.061239582456408016, 26.477953964664092, 88.31147409254505, 113.59679806617, 100.57894568289481, 87.05197749599334, 84.81368480190154, 78.50040251208891, 96.45115313991424, 88.13030765902612, 91.34149720591884, 90.06653862614786, 80.99581441571637, 82.38528267029794, 86.28146709934359, 87.25427766000071, 91.05614477588286, 93.01425472382577, 88.78029146502095, 86.57551934642177, 86.89076808191116, 82.34403502556586, 83.17913901421332, 73.83817134364959, 86.15993638192454, 74.49157545643469, 58.42369194953673, 50.646518353492986, 41.81985970466368, 85.88613140967585, 82.52836288944368, 83.0504068251579, 88.1932617002918, 86.52173580661898, 79.30256643602925, 84.04589653015137, 77.5513772041567, 77.41585931470318, 79.029749901064, 75.41092411164315, 77.90766177638885, 73.98558970420592, 74.239531793902, 81.78782724565076, 86.91093690933721, 84.0873089144307, 77.68069774873796, 80.018446060919, 84.84075700083088, 73.10283676270517, 54.53796848174065, 44.24537889419064, 51.40842699235486, 82.62021695413898, 89.8387352112801, 67.11449146270752, 22.9823866967232, 1.805994916827448, 0.16202811692510882, 0.9161310859264866, 1.669597926159059, 0.8308361434648115, 0.7510436734845563, 0.7799431453308752, 0.3804509383776496, 0.19977377457243783, 4.351390686727339, 41.32628040928995, 75.43338360324984, 69.85952300410118, 32.881084026828894, 28.631517579478604, 54.25738565383419, 68.34221686086347, 37.8050628016072, 10.311284584383811, 0.2384086917605131, 0.17823049347967873, 0.19879184903637057, 0.19320242557554476, 0.0022824818827962925, 0.054144823037448435, 0.01951547891592547, 0.014522841778553784, 0.005924343694782546, 0.05255169723363173, 0.06350278238495512, 0.01029226007015114, 0.050862331634327296, 0.02611097117375222, 0.03339393349784998, 0.04912349973775206, 0.09634097271989431, 0.076949157631926, 0.055572994789409066, 0.06069578643467638, 0.024376053986470067, 0.028812691321476337, 0.01982955964312198, 0.04340440440442293, 0.05789131091366853, 0.059996279211895126, 0.03967024288290451, 0.05764117937595133, 0.05934997296501553, 0.00902653151687475, 0.04220590581216159, 0.06075979308075002, 0.025352934833555937, 0.04005659634487764, 0.03280205013711126, 0.01954996819427658, 0.07852798823507563, 0.06940185858477509, 0.17874320548388267, 0.13005188275729457, 0.1916505919108468, 0.2115617686462018, 0.47178504387697867, 0.236580683399112, 0.29316894770149265, 0.24520582219045012, 0.13555861468757355, 0.18419127040092023, 0.23550903364535303, 0.1909376398449944, 0.23739311964281146, 0.13330841527110146, 0.1227053830159768, 0.37707426795555704, 0.18745998371272318, 0.1868409540263876, 0.21966189206127198, 0.19781203790297433, 0.1030623600367577, 0.08287355303764343, 0.4669234499094948, 0.19517622046893646, 0.12812720942160777, 0.32081920593496294, 0.10776584877842858, 0.20960476640011036, 0.26589762719888843, 0.42180951264116073, 0.21394405694257831, 0.14870309000534399, 0.246859974558315, 0.15369318756124667, 0.11098539456725122, 0.1612885969300424, 0.13263019763173597, 0.15235314656409527, 0.20617286103867716, 0.1556122990986032, 0.16906498691007016, 0.175670089740907, 0.14652672614301407, 15.745017528533937, 65.22100648572369, 102.6949937881962, 100.42794227600099, 67.18317216442478, 44.482494015847486, 41.37250554177069, 71.62843350441226, 97.72210305736911, 64.6422411549476, 8.354701419030468, 1.0111114022231873, 1.857447343007211, 3.8796805662493554, 4.2011335107588, 1.2793303064761625, 0.2862482626111277, 0.15073282463896662, 0.3958706335434991, 0.1676437559147035, 18.585862767311838, 76.92375090814407, 113.04329672167378, 112.99280012807539, 96.2602121599259, 84.8084052916496, 74.06748094866353, 107.45767685674853, 88.81706760775658, 97.84572047571983, 91.97246536131829, 78.82231143213089, 82.27132212731146, 96.26127119987243, 104.6055567649103, 110.58758704893052, 114.5479492987356, 101.81028750634964, 93.13198858691801, 91.76007686122772, 86.77562298313265, 90.19798509536251, 77.80927304298648, 91.72959220024848, 70.40461478694793, 54.61605110476094, 45.243327925282145, 32.389640462013986, 87.24576611672678, 84.63030615160542, 88.89203979123025, 100.12754363398399, 91.83023237412976, 76.5118863505702, 84.2566062558082, 83.08709667574975, 84.20275995808264, 82.34445079680413, 77.29273611499418, 77.0098626229071, 74.69589171871063, 80.004560870509, 91.36592572735202, 92.01281086091073, 90.11619583252939, 85.41354856183453, 85.63674711412, 86.66680858981225, 76.97898572491061, 44.21885974945561, 39.52214310246129, 44.12360498982091, 86.36695907961938, 104.22846009654384, 57.52616736196703, 14.289588735949609, 0.8241592888389865, 0.2761748192771789, 2.6313923876131735, 3.3109270853381005, 2.400996531209638, 3.4401397647396212, 6.097695587142822, 1.347781181816132, 0.41923554914612926, 9.986172068503596, 57.41058295772922, 80.16747259324598, 69.49313440630513, 40.596943132338986, 55.05450540973295, 73.23382823697983, 78.96699982304727, 45.466640226302616, 11.776837014382886, 0.5670952989209084, 0.35190282509692256, 0.21061889827251437, 0.4511656035338679, 0.26682195824480825, 0.2371332932624125, 0.07449502561001048, 0.14781223700171517, 0.10452566458092583, 0.14011447828623558, 0.21012831088756362, 0.22498068730196646, 0.1445787790561876, 0.1867741971246658, 0.27264536027946784, 0.1976855874301926, 0.34124779845437697, 0.2749051051514764, 0.4034381726336095, 0.20319328463125616, 0.1367161888629198, 0.12209854178851652, 0.10260448460617375, 0.13798921248845517, 0.17694895095642538, 0.48291103073185493, 0.1424895959996408, 0.23993184309332605, 0.11302024666820804, 0.1429368074863188, 0.2727243899097366, 0.20556167609268622, 0.21746982339649432, 0.25559448006172336, 0.23867849260568622, 0.13546150538229174, 0.2241235574887645], [0.09957309767243364, 0.031495399082139615, 0.14672672105652673, 0.02099448251688192, 0.13306058582759675, 0.08416297860563764, 0.1096176824742748, 0.058754082964432824, 0.02337610240154449, 0.049257396585157806, 0.16589277003320957, 0.16321471051102684, 0.02484291371318602, 0.04429882354733925, 0.0438162685942746, 0.04075966204606718, 0.09221345952321446, 0.09191964182161516, 0.015018903819333403, 0.21616197341392118, 0.21795256604110042, 0.14744987741353052, 0.11573315553006627, 0.03394612967367134, 0.024395301945567615, 0.11743863578885795, 0.03920307097535941, 0.02496568696393121, 0.054727850421782465, 0.035646270299630786, 0.11277193458931101, 0.08381334373787527, 0.039300885081531546, 0.057123143060673634, 0.058464923077413154, 0.05867488096438109, 0.03045427793216321, 0.07842783756073445, 0.14936396341410377, 0.08268065975918885, 0.04664757251439076, 0.05351828185901527, 0.018561551978270856, 0.16721494585996674, 0.18193872675539988, 0.43080197527043285, 14.620407319838002, 45.314020802897794, 71.18218544990786, 72.89699077606201, 56.88079234092467, 23.92039602802646, 36.784642511798495, 63.68371586645804, 76.45726342355051, 37.023224599899784, 2.3877509322858628, 0.47005527863098734, 0.4708335933185393, 3.8588652831892816, 3.4109247259555326, 0.06190225617178987, 0.1618439340663533, 0.14380950420614214, 0.172178368234346, 0.11631717499826225, 6.901018571469092, 39.46789280060799, 82.8506483570222, 107.17944745094546, 101.22782338050105, 88.28451171998056, 80.57285739529519, 76.82449140856343, 97.49227569949244, 77.80856701635545, 77.28243597092168, 83.60651262344854, 93.44449950802712, 84.25219751173451, 72.69971909061556, 63.52368708579772, 65.99416055986958, 70.58385925908243, 78.23947860348609, 83.00477397057318, 77.7125709287582, 35.82179084900887, 3.2961118029009913, 2.390681923397126, 1.0265910361082324, 0.21016650803146825, 22.07522680682521, 94.63902596504458, 94.77521850216775, 78.81099931655392, 89.0849890247468, 96.02306565930768, 85.1580532135502, 92.21816262891217, 89.33841336158015, 89.93653558915662, 88.2353408875004, 94.36213016510011, 93.20942401885988, 83.72197151184082, 66.96682207046017, 65.04025974581319, 50.015711015270604, 28.770587175123154, 21.45863021573713, 22.240917528829268, 26.209756020576727, 41.185557534617764, 59.65644582625359, 63.6573536165299, 33.54426660845357, 8.26440747707121, 0.0023126808293689525, 0.2809232160929711, 0.3085306653332326, 0.7632407125446105, 0.07393146835027203, 1.2644446665240874, 0.7945868240729456, 0.6166216574849621, 0.3323959589244858, 3.615909016901447, 36.120134169055575, 70.74462152296498, 59.0904321209077, 31.805015110200454, 23.24492269946683, 44.955441644114835, 64.91769744503883, 42.207499704053326, 7.603638133695049, 0.7583261052927663, 0.22351278623025264, 0.13617828788776554, 0.04037097967680424, 0.09592943028697083, 0.12240743610046564, 0.142068829868109, 0.022125596015323556, 0.162081191496503, 0.19579266077808796, 0.07453978812742619, 0.07780776599482184, 0.06498146231376356, 0.022255911401683287, 0.07023733109235764, 0.06010705169530646, 0.01975478180083296, 0.03911044328443466, 0.1447850252471624, 0.095753850595605, 0.01797442410832211, 0.12989488069809255, 0.14308835499949996, 0.1983073903548141, 0.126547206703934, 0.4181666419871392, 1.0913532900233422, 0.5209448753345398, 0.18051672967210894, 0.04016448450725406, 0.2197749359953788, 0.47441667847095004, 0.9021345982628485, 0.3927529621268473, 0.13276533554157904, 0.12499524280428888, 0.37208997734612037, 0.2616353284928107, 0.18793961604035672, 0.14363718038845447, 0.00903223887191064, 0.09159613055207076, 0.11725868939632371, 0.0952755819044767, 0.09643604423129752, 0.11189106371133559, 0.0189866196934975, 0.04548782264933952, 0.04703961034876205, 0.1794049062676007, 0.07197484148726349, 0.030204609877640204, 0.1354516534915855, 0.055254233264995206, 0.06088453134702099, 0.08024126726893649, 0.1348932213600605, 0.04736467294635312, 0.0790671915597012, 0.015762116358194862, 0.04954518134435339, 0.07031624580943777, 0.0533510908304203, 0.06672194512981562, 0.13567959529257592, 0.03858257806108844, 0.025194180348227103, 0.08100894099522023, 0.1525895000104943, 0.13303939583561114, 0.010647425135116904, 0.04319168477048797, 0.11438714670798472, 0.02332816061924302, 0.016462490217940464, 0.03184246755535564, 0.05897959243626364, 0.1430085439595484, 0.07625345020524918, 0.031420762966116594, 0.13225982476386333, 0.07844013327191915, 0.08126432406565837, 0.13393889031102582, 2.8890283694190364, 25.293774720161196, 67.74276887216877, 84.75304495903754, 55.40011721272623, 27.366037407229026, 23.83585326133236, 60.59008759836997, 98.12638175102973, 89.26726156665434, 29.408521459948634, 0.30087471969666024, 0.8220268064929593, 1.2644799678556382, 1.2068567953763472, 1.2663705502786946, 0.9900873755255054, 0.22411189763055694, 0.3597870955784475, 0.7671543799581066, 0.1166914702363072, 12.418322024806855, 62.636439108079486, 101.81018552472516, 108.33562097241803, 91.84260352965325, 78.86412389816778, 86.80493877780053, 74.05198758648288, 104.17952460627403, 80.70187983974334, 65.25808072859242, 81.76479508799892, 81.11904744179019, 80.21159141294419, 78.06893394839379, 81.86774946028187, 74.58146833604383, 80.90371716407039, 84.259948115195, 93.10825040263515, 85.6007319111978, 63.585433037050315, 13.110860605393688, 7.18174897855328, 3.854782586136172, 0.8761329612424298, 40.74027046080559, 90.06336935104864, 91.16666932259837, 91.7233556316745, 91.3327189414732, 83.8312409001012, 90.45430414138302, 98.64341289766374, 97.08864027454008, 95.49736607459285, 92.24450526698944, 88.00720799353816, 87.9496354441489, 88.44004938679358, 84.95865560347035, 81.62630404195478, 77.18050925962388, 72.47226084432295, 62.128503937875074, 58.068697837091264, 52.87262816582957, 44.46694181811425, 63.2364676075597, 75.68523899201425, 56.94374638219034, 18.058704060892907, 0.5076489291123806, 0.5129084597912528, 1.3957869477810398, 1.3885791022931377, 0.8655182308247014, 0.682373145414937, 0.3534796485497106, 0.5848408983119073, 0.3224988383871894, 1.860057925505023, 32.35340560636213, 78.13014645730296, 72.88603167380057, 40.1024224681239, 22.765658094036965, 41.15374319015011, 73.26738803617417, 57.271154465213904, 12.853391324320148, 1.1009084289112399, 0.29526110317918564, 0.12230132526207356, 0.04650204262185482, 0.1400577111710464, 0.02395293596501072, 0.07755268935955341, 0.03310773454065765, 0.06560695012130084, 0.04234020485572758, 0.07995451289799907, 0.1096104889086658, 0.031720123313848055, 0.027439310177860242, 0.06369004108672661, 0.031834716660781734, 0.010949947510755832, 0.03919349870674553, 0.05246668828711395, 0.08648404881598488, 0.07337606226604793, 0.12654956625474076, 0.04423484371434297, 0.09200578074782126, 0.12479414472416525, 0.14480027039685558, 0.4430222114728343, 0.5291977260381945, 0.27930756730418055, 0.02997775400628246, 0.1270873829602234, 0.2746918875603907, 0.42825675539432034, 0.21219648781322667, 0.031876366946005055, 0.25981887273730775, 0.11411840306414713, 0.03861566539853811, 0.13604889563735456, 0.5053361709560118, 0.10881208739573918, 0.16389688116408166, 0.2566838724118087, 0.12750991109398105, 0.38342259343593355, 0.17716998264433878, 0.12492258702555012, 0.07970377998126131, 0.25812339758680714, 0.2225541804106005, 0.2401693150280945, 0.13712756275649995, 0.2501229728542028, 0.16133116077511542, 0.10960391587427548, 0.16239810674901933, 0.2101265488853378, 0.13851628098036015, 0.21417054317651257, 0.33299635735250294, 0.24368581181812674, 0.35825706477607455, 0.12003096241143443, 0.16610833185334362, 0.23866174592366143, 0.1386422718003873, 0.11094034093642428, 0.17139872055380576, 0.15231470427205487, 0.23401729191743562, 0.1393015364245061, 0.1876705812831079, 0.19780515843341429, 0.1849713317689396, 0.1473781256185424, 0.1075957925809968, 0.15051448958054667, 0.292338140669369, 0.19486849827151145, 0.14722870782979075, 0.25860250897465215, 0.2149115800256691, 0.3969040555098365, 0.2469809245198004, 1.8229713026554355, 27.776733098491547, 81.11346983140515, 97.44222625609368, 90.55200253763508, 72.17608267261137, 39.73601033610683, 50.499531453655614, 78.26179688976657, 96.02808629312824, 52.1349754641133, 4.684952478254996, 0.9568653291752263, 1.482835741293046, 7.795193454911632, 7.569310530539482, 2.0883821575872363, 0.2130353387685553, 0.2185420247335588, 0.8395510984043922, 0.41856525285590085, 6.230488409919124, 44.86796494453184, 84.61465589461788, 106.78067576500678, 100.98986887162732, 72.56357362193447, 94.87999285421064, 61.946309843371, 111.21086735879223, 86.08510540377709, 57.15804507655483, 67.22226250556209, 72.19120733199581, 75.92193049769249, 71.2006833476405, 82.42038788334017, 75.71156594061083, 89.31198443135908, 89.73436094099476, 103.00582593487155, 90.17174443890973, 51.82789702569285, 7.1484818862330535, 3.636877517546377, 1.645768546769696, 0.48674067362181606, 28.936711319031257, 99.79749187346428, 97.95504477716263, 96.54692957478186, 97.63513626590853, 103.23359012603761, 101.94462868475146, 111.0497050131521, 107.87044355946203, 111.26485486184399, 114.22818983754804, 109.24128055572511, 108.12888068537559, 100.36104233034196, 86.26761328789496, 88.21712540042016, 84.28142701425861, 82.24519914196384, 73.19193732353949, 70.84554410749867, 73.11796926682996, 78.26760984236195, 80.35116503315588, 76.90904986473822, 40.48119398855394, 9.039150111136898, 0.2060992553109123, 0.47150719910860067, 1.0865563538766678, 3.0934260208760542, 3.348699510097504, 2.404511465180305, 6.737270403292872, 1.765015219007769, 0.7318320269546201, 6.000971899878595, 45.977936867744695, 81.51992151814123, 66.3355322807066, 41.590150017892164, 32.39569660156004, 55.89242566016413, 83.2743114040744, 64.90908392014043, 18.444582916075184, 0.8677127356490782, 0.8330057044663738, 0.20269382594814225, 0.08618222549557687, 0.1812537522205422, 0.3767150646496204, 0.255979209417297, 0.15378427541544362, 0.16835277028862508, 0.2958615628942367, 0.17182890956680621, 0.2770610297879865, 0.18521019798373023, 0.15245102195730134, 0.14423269117551465, 0.22984130067690728, 0.0679020882554112, 0.09942410889291957, 0.29195059211023394, 0.11860107462252341, 0.20875627805869426, 0.23750654662088042, 0.24814499512074456, 0.3110369679427916, 0.17776249036673578, 0.4199599006002949, 1.235095286561597, 0.5239999114025025, 0.5879473542013477, 0.14102774702252882, 0.3482368798746217, 0.4848900809884072, 0.7960049447513396, 0.3967777429328811, 0.19842712989737912, 0.2857186507073141, 0.49163655768479075, 0.3251480623599022, 0.48515916171093143], [0.11990320958918142, 0.07908966857939959, 0.10278204080438423, 0.09621677454560996, 0.09465826059421224, 0.04324045009730805, 0.028013592668538614, 0.08422945205482744, 0.32795926796332486, 0.3568027234606205, 0.019135595066472888, 0.009752744564696426, 0.005118939180618092, 0.10999947771309845, 0.10193663213642375, 0.1280600618150446, 0.056117012976638736, 0.14980040370456635, 0.12436718860220526, 0.150414040131915, 0.040090128013323394, 0.1836183898511433, 0.0913926805820196, 0.19752095513526471, 0.1399870165773938, 0.10132967599577482, 0.05431956386253719, 0.06508338265120983, 0.05226531058489796, 0.014818861025325475, 0.1181702497565458, 0.07276712961855435, 0.060573181723274534, 0.07662315657662769, 0.02774267716543569, 0.04298920390166102, 0.07180418774125076, 0.03304961911072174, 0.04766723937204769, 0.029665412298674067, 0.01042352061748745, 0.10318070529930054, 0.1302926948354129, 0.0828466480297427, 0.08701257287494599, 0.04702274492310901, 0.07579785771667957, 2.367793422552847, 18.394990428801506, 64.87254311961513, 71.86193220077023, 73.8863851178077, 42.28185607540993, 26.879922382293213, 32.19505952250573, 74.67587978609147, 80.790737213627, 36.436547848486136, 2.2722832185606805, 0.7684535425036185, 0.5429551942694573, 5.080059689860191, 1.1697587731384462, 0.3904703571911781, 0.8060561408919673, 1.9662286413292733, 0.07506458133819603, 0.04008132566307341, 1.9497606927348723, 19.97438573068188, 62.50120362927837, 90.57145749368976, 97.90276742750599, 89.15486997173679, 84.05891095438312, 73.83504129225209, 63.75710341238207, 58.88166396848617, 64.73362845759239, 65.7837018659038, 64.67259245534098, 66.62420303590837, 70.91685279723137, 72.79416191962459, 54.337464763272195, 33.86536752024005, 8.698109830579451, 0.10936989133516628, 0.22209670334573717, 0.11558079596368537, 0.204836298080702, 0.19529582211567512, 0.03520277050894595, 12.618445273368591, 59.94453999304003, 61.01797111572758, 80.14313820869693, 66.81573237142256, 73.34661991365495, 87.42058615530692, 88.07491594745268, 77.33569391312139, 67.6532760743172, 60.28892801653955, 52.04057578117617, 56.001345957479174, 55.02484052411972, 32.10228566200503, 14.548514196949622, 12.010511236806071, 24.594535750727502, 30.54637359034631, 19.5423327338311, 28.08099331394319, 11.417419448975595, 2.8817342317873433, 0.6307316487354617, 0.29653565898056955, 0.40392289178506025, 10.637921921668514, 3.914355299165172, 1.9490756262694637, 0.2619385460932409, 0.45935603339345227, 0.47410328722288536, 2.1642045147957343, 28.551312954195087, 67.64242679842057, 61.387493687291304, 26.75339456527464, 22.12218934489835, 38.835806769709436, 57.511548688334805, 52.11493999727311, 15.458063790875098, 1.8893655077103648, 0.1355185176456167, 0.048117967202298106, 0.241885106830347, 0.11740731045363412, 0.024761827136840553, 0.11088142111416786, 0.07638425971832007, 0.0789065812263758, 0.04169464554457415, 0.07197317141558855, 0.04268287981469785, 0.052279065693578416, 0.030000771117967465, 0.061686146598789966, 0.07910056234968287, 0.06999058183282614, 0.09819421601752121, 0.0647995240926262, 0.0606218742717418, 0.043567447066907926, 0.004951720381335866, 0.10312114196318774, 0.030068859097457705, 0.060729471320706996, 0.07458098833599398, 0.09647207334637643, 0.2329920824136465, 0.07700584047744352, 0.23158168390152917, 0.24211683310568335, 0.19671008171093082, 0.5036282851811379, 0.2829763317300428, 0.18961957024951137, 0.09110722856055345, 0.1913670627700706, 0.0762188230310717, 0.08794703160322483, 0.12173556166911319, 0.15115034255769946, 0.22791674991528835, 0.08586126529882032, 0.016099496691998456, 0.043518034395791834, 0.11739240238262762, 0.08668539970512353, 0.017256155392275225, 0.027304472957527446, 0.03574999477413874, 0.11747799738640748, 0.03933348212270968, 0.06449396992402692, 0.05802588191844764, 0.1544485655763457, 0.04262883997251911, 0.03301996001673322, 0.025506158164071462, 0.14605382006735573, 0.0850549730802736, 0.2411415112475234, 0.13416520800561677, 0.15605261579396265, 0.0936423667195824, 0.18122188296289216, 0.10956618604400467, 0.058318125309362534, 0.04508337802103451, 0.09687296715715239, 0.05993960402725686, 0.05457146123291985, 0.0686460975257139, 0.03728105596476986, 0.054960361937241214, 0.025894051462772395, 0.11210591306970005, 0.025963372843820724, 0.048638979769161636, 0.03916562076718096, 0.04411811106688073, 0.05464818110809692, 0.05563735766636749, 0.10371255417985302, 0.0960055411222481, 0.07582634086570433, 0.17606437987377568, 0.11884285197142633, 0.5239839154866435, 4.950376816334264, 27.421436963542817, 79.2274687367101, 76.95533383277156, 51.00036713384813, 21.389110126803, 24.99815940856934, 47.905417027012, 104.36316213300152, 89.30726189767161, 26.419771486713042, 0.8413352865365245, 0.765484553431311, 1.195395262010636, 0.5989044339906785, 0.7286265312183289, 0.7119880208084661, 1.6187278493758173, 5.075644571934977, 0.8876130032923915, 0.3225062234747795, 4.962856327333759, 37.791307049412886, 88.05647296290245, 106.50387410194644, 98.20078126845821, 82.46442041089459, 98.54768353123819, 71.13253608826669, 95.92577518955355, 94.2583050266389, 98.01667305731006, 81.45855995916551, 69.06422322796237, 67.87692962154266, 81.87275440462174, 92.64780336810698, 79.29556892764184, 60.9944918078761, 25.32933492814341, 1.729198463501469, 0.32923400762581057, 0.1773934504918514, 0.200433177092383, 0.12290399131034652, 0.358971028077987, 34.221189252791866, 82.2306549933649, 76.66940089195006, 86.75716430910173, 88.27191306698708, 76.62305416599398, 88.1702923005627, 84.91790217737999, 84.25313888057586, 72.35343656232281, 75.96031481219877, 70.30198989375945, 72.0965370055168, 66.08243742296773, 67.04137063795521, 53.00561612652194, 37.345929761086744, 24.46127518530815, 35.769438974318966, 51.05326029562181, 48.48590820066391, 25.327644386599143, 6.996647917455243, 1.1524672493819268, 0.5010092757161587, 0.21680156490014446, 16.924034933890066, 6.17268346009716, 0.3820500090237587, 0.2829759946513561, 0.8404036623335654, 0.31195566058158875, 0.2624851345054565, 19.99633139179599, 68.23164524570589, 78.28332285727225, 40.085862221256384, 25.18668224734645, 33.17798391465218, 58.12903957982218, 66.0035114903604, 24.290197087872414, 3.119795870396399, 0.2708774438548473, 0.12566212234237503, 0.30779895943499386, 0.08482288674361284, 0.019679814351782687, 0.07984774322399209, 0.08600677603915816, 0.08270063167137486, 0.02194714157902185, 0.08251135432792288, 0.14373369214515533, 0.06940313795160863, 0.08212614233695692, 0.10683484510668825, 0.10322070274982723, 0.12196105964962514, 0.10302783245401037, 0.08862180184693107, 0.049293306956608454, 0.08615172753531126, 0.042266668075875896, 0.0744094995541438, 0.03462284578070526, 0.050792349502444274, 0.0631295481786853, 0.05665275358384656, 0.18387950325925506, 0.11336959808343842, 0.3316106575150644, 0.15796726869959987, 0.09872534477542486, 0.4770934816089369, 0.15641831552549718, 0.39266565874699627, 0.13943488168860638, 0.12723323844012716, 0.08871366344993153, 0.07303792637802901, 0.223370814816125, 0.22127153472073618, 0.26895885325727925, 0.12291422624501491, 0.2011652813563424, 0.1103627106415168, 0.15511641038521645, 0.18991843647053167, 0.16729673340676293, 0.1634224735560917, 0.34798652234096683, 0.43921959616484185, 0.1960845709207558, 0.14524507636745132, 0.12471040365316215, 0.2676881891825507, 0.12904041687086706, 0.21649569663549625, 0.12108432564644084, 0.41992901193518795, 0.16897314828970741, 0.1904952547122394, 0.27071589123337503, 0.2534099037368452, 0.22362795988878897, 0.27628302153560425, 0.26637195819808596, 0.16768909299806242, 0.19991510247270908, 0.23857899310608066, 0.12597489305922102, 0.1267649671964107, 0.24128106182381032, 0.2560600316933086, 0.10455487551347864, 0.17342721412499107, 0.16780743826060526, 0.12044296449711246, 0.131539365036353, 0.19948895840394884, 0.20152509753261844, 0.18550826747330929, 0.26889971126952483, 0.16435846446021912, 0.18097402287587044, 0.17846108594488713, 0.24596190500643947, 0.20822499608320577, 0.4618830816640008, 5.19057099857638, 37.12534742970621, 92.65420467622819, 93.51632595062257, 91.67388669906124, 55.06198144728138, 41.109094850478634, 45.76254383210213, 89.06555760291316, 100.70315145677137, 49.015553689772084, 4.224945239482388, 1.0056471115639134, 1.5611177923217898, 10.55066389422263, 3.7934570639364185, 1.245706033322119, 1.354011866834856, 4.83825292318098, 0.4125323410957091, 0.4294583489817958, 2.8616963134657953, 23.945854171629875, 79.45809625810193, 102.10380631108438, 105.63193121264058, 95.77768218132758, 94.70631814772084, 81.05305748601114, 90.97571265312934, 94.91039122304609, 90.43405686655353, 80.83429905676073, 71.75818550971248, 87.80599824843868, 104.42192708292316, 113.51964504488053, 83.37797180298837, 56.549877658967056, 14.45698372779354, 0.8695100392064742, 0.24609304393731782, 0.248671037054831, 0.24906846814818923, 0.1906939319545223, 0.13427627543287893, 18.010566772953158, 76.25763047126033, 84.36040001530802, 101.79852039583268, 77.7835266051754, 70.66514645853351, 90.29216120319983, 94.85939256606564, 83.12398264485022, 64.51109278586604, 65.42774285039594, 64.35710445527108, 78.19897620908677, 82.8248626955094, 80.8247127840596, 68.18962097167969, 50.886434047452866, 36.693647446170935, 50.59033040077456, 58.71542607584308, 38.88425980844806, 14.518953254145963, 2.8002901375293736, 1.4325920179966958, 0.3715464839291188, 1.0052206150947078, 18.337676755843624, 10.800840508553291, 4.9994883229655604, 3.3027813030827433, 2.465465097658096, 0.802967887251608, 3.13646373729552, 37.665371510290335, 76.95304316859092, 71.57154344743299, 34.6457544449837, 31.04698177306883, 48.741795785965465, 70.99803017031762, 73.38215658741613, 34.215376300196496, 4.454843690318446, 0.4005040252400983, 0.12848064408547458, 0.5404742951354673, 0.2172330869061332, 0.1415960157230016, 0.2305585734786526, 0.2233781539384396, 0.20930505748237335, 0.27566442085850623, 0.1492227427661419, 0.19862972950983435, 0.10460182138147855, 0.15614584869434758, 0.3003882538647421, 0.2186700227039476, 0.2043419721866808, 0.25633776920937723, 0.2638987505868558, 0.11026271318476047, 0.13815232792929297, 0.10772301680258206, 0.2066976465885678, 0.0864514058095313, 0.11185904123610067, 0.1644120599714018, 0.19016602076590064, 0.19553614389752189, 0.1422188758489586, 0.2659652267973269, 0.24207437651291971, 0.2263505291193724, 0.6302661737126689, 0.3431724871118223, 0.2906779974939362, 0.1867408416564426, 0.2917939118079601, 0.16491858198517756, 0.12020533934475915, 0.28347704679735247, 0.32330712243433923], [0.0871893476634737, 0.18641822670976962, 0.13416474835286218, 0.17622113678484194, 0.2163637456514182, 0.11132399776890395, 0.6182430672549433, 0.02711377452097593, 0.8528170446234365, 0.9321072060734996, 0.22998232214200884, 1.0172019850823188, 0.19485458611480652, 1.0604061570859726, 0.2608798738689192, 0.28473931454843093, 0.3653817131153999, 0.17124830685075254, 0.34088733876424454, 0.3492552865176432, 0.0750148009448763, 0.2071326466337327, 0.12256632273596142, 0.02780421700839314, 0.14068506057223967, 0.017147742459670674, 0.2336501825841204, 0.24235989748229905, 0.053045915875343554, 0.2418602855816003, 0.08028436737555651, 0.013396779672362873, 0.011428422088013783, 0.051547401930175485, 0.038683651871378386, 0.030345200418284347, 0.14415286481380463, 0.12592034759901224, 0.14072305853328398, 0.06461176360326429, 0.06738758360546443, 0.06692418468094642, 0.1680665598401139, 0.040131596352664695, 0.09511679486041108, 0.04043385251274994, 0.02523494771711769, 0.11806157252360737, 0.11405639590755587, 6.227427490295903, 41.3444645174088, 69.96494062485235, 81.187422198634, 74.60914457997968, 48.094212470516084, 20.528310691156697, 35.92916965484619, 66.56069986281857, 80.795836294851, 32.01014134191698, 2.792160535050977, 1.134552068768009, 0.19186333452741947, 1.5806938515555475, 1.5676800401941424, 1.2693226241296338, 0.2967799797413811, 0.1213679543786472, 0.13892431473059041, 0.302247396039386, 0.08786209543505985, 8.658371317771174, 37.45437937398111, 60.527969021951, 71.6277745462233, 58.85761199458953, 26.722953050367295, 28.762001106815955, 27.116533479382916, 25.472424953214585, 17.526105027044974, 12.191083431243898, 9.155791594136147, 1.970351542676649, 0.4449883301652247, 0.1331914796103393, 0.13115037623192036, 0.14807166501639352, 0.10857415580821615, 0.7840534215492587, 0.620032097062757, 0.09754183852384168, 0.42707940082876916, 0.43859842143231825, 2.103048880254069, 11.528086181609861, 68.21001729657574, 74.00698231112573, 61.76393531983899, 111.29413143281015, 87.21143753297868, 87.85598493391468, 63.37490766279159, 40.98535976102276, 49.605552688721694, 60.71088483256679, 51.83254111197687, 21.322706360970777, 25.65117716789246, 28.709555095241917, 39.2298480772203, 20.624579383480935, 2.5840248648197424, 0.6330527725719637, 0.15841336169790837, 0.7456471662848227, 1.1461769933662107, 3.1930691772891633, 1.0435611706587578, 6.1108786732919755, 4.3078185473718955, 0.498005383678021, 0.2392191821408849, 1.1456038370247812, 24.86903694368178, 65.19183581875217, 59.78794720865066, 30.346005193648804, 23.8372927711856, 37.839516901200824, 55.81424497788953, 67.21712420063635, 39.079499706145256, 5.183844133730858, 0.2775855242244659, 0.03644187942207341, 0.15590442374588984, 0.1950359497700007, 0.1265606285643674, 0.09179614078734191, 0.093562402462046, 0.1026952890078387, 0.044291499746783126, 0.030677640442586238, 0.04429387078890878, 0.059164112373705835, 0.07382716547938124, 0.06552498637428207, 0.06596305077114413, 0.018849137554606123, 0.010438260149150606, 0.092669113298818, 0.08118025357684783, 0.03803919572683592, 0.03523126897972918, 0.08090200278186992, 0.09355986671101663, 0.058913881244558486, 0.051509055399125626, 0.05535082163048848, 0.05001029247538217, 0.08512569065656393, 0.050078424504928054, 0.0824862649484027, 0.07431577635748733, 0.08904363284067762, 0.06068640185760395, 0.07856054697185755, 0.3437810367153537, 0.043036325969883514, 0.045467134444944324, 0.11829889890167022, 0.024879337363545934, 0.05336785666464318, 0.032443815932398846, 0.010298635836900964, 0.04685545430308388, 0.01313162419284063, 0.01997670406595834, 0.14413293120601486, 0.05314982038051371, 0.030187491642972155, 0.37182720918809214, 0.14092699113872745, 0.8254289110341381, 0.8542297107558098, 0.1393820369435895, 0.41640598807604084, 0.056001352852270495, 0.5867870680747495, 0.28828317599911846, 0.262951988486513, 0.38999296184028354, 0.14584346764510678, 0.23760808391436455, 0.06624517031013966, 0.02262878937706832, 0.07429628708069363, 0.06276819216568144, 0.03871965417337995, 0.05008977026708665, 0.03629662915162983, 0.11610119182976986, 0.055347899005057356, 0.06792048202647318, 0.20161854493762218, 0.14216964703894433, 0.07455956085675186, 0.02243848547579781, 0.023582886769286087, 0.029056776510251146, 0.09396937901094075, 0.024080788378693888, 0.10500982448819185, 0.009933441723396462, 0.07420323038053128, 0.04535566099108227, 0.06405071911191748, 0.16141463371534504, 0.050882311207392526, 0.1444218382840195, 0.03267540048146921, 0.09729787016347533, 0.20358248794030762, 0.38301288961402835, 9.03314692358817, 50.91644802401143, 81.98947629620953, 82.5209652992987, 46.84925610019315, 25.93758079313463, 25.494131349748184, 58.20041494984781, 100.64438650684973, 94.21903425647368, 24.3265554981847, 0.36122948592228277, 0.6358462355790601, 0.680223502699406, 1.2151919545665866, 0.44770349898645956, 2.601509565307248, 0.2728989353824047, 1.3359558486169385, 0.1329846052272666, 0.5416422421413084, 0.8801505714654924, 21.077675896306193, 60.19572465650497, 85.67433910985147, 86.24866823996268, 85.53546367153045, 68.25336733172017, 69.34516691392469, 69.78360160704582, 66.55789929051554, 56.19505613080917, 45.596858993653335, 35.39666868025257, 16.171122251018403, 7.446504552518168, 1.1287641212824853, 0.052806773868900155, 0.27741315444150283, 0.4039253739099349, 1.6970204417743993, 1.651495574943481, 0.1375711889516923, 0.1585648632458141, 0.47383383877815743, 11.631732852228227, 35.969205287195024, 80.62916694148895, 88.91657029428791, 57.82971174486222, 103.58482268548782, 94.63344050991921, 92.29843785685878, 60.0185315839706, 62.225645357562655, 83.74173241276895, 81.30941575573337, 71.81800949958064, 49.80393440492692, 30.46004418403872, 26.036724582795177, 42.49994770173104, 25.90525850172966, 5.647169697669245, 3.3018774419061603, 0.42551599923641453, 0.4245004117969544, 1.0651145947556342, 1.9954761622413515, 2.398079513542114, 7.354172448958121, 3.505267289377028, 0.6811017458958011, 0.3772049625554393, 0.7781191206266804, 14.952073135683614, 72.08803330698322, 86.38675920424923, 50.72489907664638, 27.540314197540287, 27.980674774416034, 51.28102056441769, 81.02464383648288, 49.170134298263065, 8.176028632348585, 0.2631307014774892, 0.10897130344904239, 0.10546345579167528, 0.16138140082118974, 0.09598928473649487, 0.170510487570878, 0.04904415601143434, 0.029232231712329294, 0.11259033344686033, 0.03345582191081297, 0.04575905990937064, 0.036772220365462766, 0.023988760151569883, 0.03193845071138875, 0.03449130465366668, 0.0651265440448638, 0.03678006127536778, 0.06854420783178461, 0.07252711427187727, 0.03164509266254402, 0.043314538460465214, 0.14755443309343633, 0.08337875738018945, 0.04400086897094885, 0.0739507737659639, 0.09737509948712203, 0.052899095124655196, 0.08080723004475718, 0.12942362937235063, 0.10625916833598768, 0.049713027378123616, 0.09421814308171311, 0.18951896758329487, 0.10252481912292781, 0.385758089081895, 0.054447075367094054, 0.045618861988787694, 0.006004318007222948, 0.023670615327935067, 0.06700625568027459, 0.0637059297502762, 0.0735470301081096, 0.17852401240698754, 0.26601266296159837, 0.28485585184347245, 0.36235064027770875, 0.4939310829485617, 0.18981467752206713, 1.0180283181609646, 0.20028437217397077, 0.9776307858767049, 1.150955175680499, 0.3311427922979478, 1.5439048385427845, 0.3210133326149756, 1.41522437574402, 0.4017676106624065, 0.33147153594801504, 0.6282656423507199, 0.18370085155531285, 0.39125771171623663, 0.3004251793026924, 0.3712516932958557, 0.35146345835058923, 0.205145598419251, 0.10001997208042492, 0.1534020588282616, 0.22623313380585564, 0.2949561388982881, 0.3715020201859936, 0.13499687305621563, 0.42988821623786805, 0.35459724825716793, 0.12447743631538846, 0.13774573442436036, 0.271832816783459, 0.136733548415284, 0.10892890814331271, 0.2448715167420526, 0.21306783621830327, 0.21762841891857887, 0.2077516916418268, 0.12753287840995098, 0.2065611143987025, 0.2634976575932195, 0.1574551082787014, 0.38698640381616933, 0.27209371568695195, 0.1559550161924093, 0.453479127778161, 0.40282377011833653, 11.081576308896466, 58.31126113091746, 90.4030466079712, 99.72394743273335, 90.27879376565257, 60.89438507633825, 34.17681940140263, 49.81736460039693, 80.55224141766949, 96.59617100992511, 41.62946785649946, 4.18882756463943, 1.45204832236613, 1.4091583076984653, 9.304867156090276, 2.666237988779622, 5.327860328458971, 0.7301760512974955, 0.8963593984803847, 0.18432852271343433, 0.3022818393524616, 0.25138380035998364, 11.78891497273599, 43.81945656191918, 71.98130561459449, 82.844498080592, 93.71380944405833, 82.721374880883, 77.00884280666229, 70.76420199486518, 61.05951293822258, 48.75984653349846, 33.04474884463895, 20.388368368148804, 5.761481292786137, 2.404289851265569, 0.3240187874724788, 0.1956296066242841, 0.11205156679235159, 0.28240437048577494, 1.2462648484976062, 1.0230055607614978, 0.1541419312237732, 1.0012240876113216, 0.4341172667280321, 5.387162152797946, 26.964963289999194, 78.81931474131923, 132.63475910309825, 57.28093685642366, 112.19585295646422, 91.15330972979146, 104.01961741908904, 58.84781783626926, 86.65432760792395, 137.1999272992534, 114.53981430299821, 82.04050633215135, 65.35609291445824, 43.727045520659416, 40.84748844946585, 41.67455942400041, 23.81035197165705, 3.2671372544380928, 2.2823828314581225, 0.25159088924767514, 0.9283450402079091, 3.722792623504516, 6.425335580302823, 5.491478077826962, 11.745559054036296, 9.484251852958433, 1.7779250875596078, 1.7856986123707987, 2.1260545619072455, 31.002486405834077, 79.07352355218704, 73.08285620904738, 46.62788929477815, 35.893221132216915, 47.73945370028096, 67.07908030479186, 88.80648505303168, 55.21839380264283, 11.68550854729068, 0.2505670433803912, 0.23166463590197026, 0.38020438064009915, 0.38111718972363784, 0.22230723962908794, 0.39663270716705634, 0.21684802047187285, 0.25041165010583016, 0.16785986931814303, 0.09547384545928049, 0.27030922111964995, 0.14451678722135483, 0.14578783434004555, 0.15575702842925826, 0.19612017868747636, 0.170611105558853, 0.15039081234605084, 0.19849279895424846, 0.15003131792670296, 0.09498031629670052, 0.10439415792784384, 0.25977581859596316, 0.2085610635338291, 0.13090502891329028, 0.17468057993438937, 0.26270739193404874, 0.16021774390772467, 0.13117305243447905, 0.11621526232169521, 0.18421861973981704, 0.18655670476296257, 0.1792019389329418, 0.26830758659108994, 0.12966906862153163, 0.41498118711094706, 0.16787454756277223, 0.15231986770466452, 0.22731065179311463, 0.14541867189109325, 0.11891852613658675, 0.1653934952111975, 0.1712719636458543], [0.08765810154258244, 0.03969294972898018, 0.05067910638547713, 0.10421849396680632, 0.07560756913716755, 0.022508097970257365, 0.04364307143635327, 0.04972882411112228, 0.043043998340445186, 0.034156428469765576, 0.015959571690238532, 0.06394157073490563, 0.06457457769541972, 0.11443858185122091, 0.09271145497839298, 0.08390447755734767, 0.010729981642667084, 0.04326147921082955, 0.0584859253778573, 0.04413750075224427, 0.08139878015724883, 0.033515132437910766, 0.023264171210147684, 0.06912044384666989, 0.023088853903895906, 0.06560511151028257, 0.060040712311503396, 0.06528775958764939, 0.03719356106293779, 0.10536987815172442, 0.0056215469639057354, 0.02983823598873231, 0.0403918938771371, 0.002343603968432534, 0.0261930977144549, 0.01824594290566541, 0.013423379202703796, 0.02996721072122455, 0.04057690028041121, 0.008969876442044493, 0.042088012541494066, 0.0838846358801088, 0.06222254604161267, 0.026037172008786472, 0.042617635936626506, 0.07743991355622008, 0.10902565738727009, 0.019227579243541248, 0.005604650415930777, 0.26552494074548444, 0.14324817626226333, 10.200190313400762, 43.08285113303892, 73.53823554131293, 77.17895600103563, 68.5464076072939, 36.766438791828776, 26.17274061326058, 25.76536128597875, 66.16509745197912, 82.91608133623677, 47.3795566251201, 5.286866657195553, 0.9461800573814301, 0.43556465196513366, 1.799986703741935, 2.3332419991493225, 1.9191426711697734, 0.9725687220211953, 0.9173638746142389, 0.30187948997462954, 0.8895042598728211, 1.6471114682574428, 0.2687414068608515, 0.9265430788359336, 2.7432534819649113, 8.730147750146928, 2.169803207920444, 0.364474450508433, 0.3931310418392382, 0.4175284601026966, 0.41669823529739536, 0.3742403248625417, 0.3281775723782278, 0.07241867452619538, 0.19339546441070496, 0.09301415163903468, 0.7535979331981751, 1.0716984156639346, 0.7239877156192257, 0.8496453180428475, 0.37053426727652555, 0.17709522778468748, 0.09904117984396797, 0.04413308425536079, 0.136862373760631, 1.8476835830557732, 8.179840195563532, 16.436896170339278, 18.708328970016975, 17.595125013782134, 17.125215261213242, 16.161220227518392, 9.123345748070749, 6.841119566271383, 5.723472545223852, 8.31819493924418, 12.08622572883483, 19.37427486142805, 6.023728020729558, 0.5553130505065764, 0.3174790319415831, 0.10067206612157245, 0.18217509552355737, 0.3043477333361103, 0.3099702364735065, 1.1223842636231454, 1.6897394195679696, 0.19729171098480303, 0.4013870794686579, 0.4577557982936983, 1.8260699750915652, 28.04138129757297, 59.73820371012534, 64.220390242915, 24.412037672535067, 18.14735747152759, 33.76985388417398, 58.9402327998992, 65.58178217180314, 46.866687113238925, 11.179712049422726, 0.6066441896461672, 0.12494062073528768, 0.11988871520565403, 0.12062072753906251, 0.05253415765060533, 0.01670369300090017, 0.11351428144881803, 0.036115728979629856, 0.12146251261114113, 0.05045307980429742, 0.07679799316270698, 0.009984835689406722, 0.029987471831601956, 0.004957808386309133, 0.04647007760321421, 0.008654922374614306, 0.020314418605618903, 0.03477701714502708, 0.02539757860734338, 0.038136006257827246, 0.006166416466341264, 0.07674406823371688, 0.05977439716638577, 0.028781743284555215, 0.05053659104892323, 0.025559560238053242, 0.04299270875391461, 0.035357727113390164, 0.0362593972785098, 0.03429173874939161, 0.07307803874174434, 0.07824484213826158, 0.06858078086928976, 0.031728404724309524, 0.04043070389138114, 0.07672382819075739, 0.04491888745237262, 0.05512302155576407, 0.01794754591349873, 0.043109640584237156, 0.09085427398883528, 0.060020502912060875, 0.020431247014071674, 0.035699141857725, 0.09144511163955735, 0.032647028415193485, 0.09465840615091786, 0.09481317889426025, 0.07327152190790062, 0.07892112923605789, 0.023052683062551003, 0.028802511928182457, 0.13745983041101886, 0.17766285297130385, 0.023728359205227707, 0.18332769012739583, 0.10075620555829617, 0.2594487909828463, 0.036533725703315395, 0.053601593920780774, 0.0703826503107144, 0.13063919640356494, 0.0851845491917864, 0.06234327766803965, 0.022217769799153173, 0.11907131471220525, 0.050136892335309144, 0.02148208598936758, 0.006146505841189215, 0.05608978621180981, 0.051339137097520214, 0.0082538437451266, 0.011211516741182537, 0.08315175020646665, 0.06714464180291661, 0.027925117174163464, 0.03641904617149023, 0.08916156441574136, 0.032956527936602795, 0.020190283633588303, 0.02144521417757196, 0.12876442603526578, 0.015765108889149084, 0.06525015233144646, 0.06680721071578803, 0.04469075412940114, 0.14561926435318687, 0.040303609904743014, 0.04248630931420673, 0.021312717355847843, 0.0809787264874866, 0.0026767547786866706, 0.02678448120282302, 0.2430739527147624, 0.16644305098922024, 13.177133952417682, 53.33215736573743, 87.42542636009955, 79.32769313935312, 46.10454313216671, 24.50700217677701, 28.181723702338438, 48.92750824651411, 107.30592819952197, 95.60164620799404, 34.828399612057595, 0.6484490560908472, 0.6611712024577203, 0.14502559217714495, 1.1232463270425797, 0.3941885802534319, 0.5704169948735546, 0.30848090026167135, 1.0288129362367815, 1.0944297765531847, 1.154698710287771, 2.1338056556640135, 1.8838842405426888, 6.010858233897917, 9.688809340999974, 22.212492112190496, 26.417198411880005, 9.103539739885639, 1.9356650426503152, 1.036326113727785, 0.7744539108487868, 0.3614756452941126, 0.7874093769538788, 0.16312057362689128, 0.6002792247360753, 0.8470019469818763, 4.015024400526478, 3.5319519091037015, 2.222613999920507, 3.576945172202203, 2.8587753734280987, 0.17755129524777014, 0.2941827884604854, 0.07063499201209315, 0.5495103328458725, 14.919945001602175, 27.59578435651718, 36.313699214689194, 63.417924296471384, 52.09950154827487, 53.27283151688115, 34.24767701856552, 16.4821465938322, 25.733093907756192, 27.47062936905892, 32.457893625382454, 25.234833263581802, 24.2974672009868, 11.241795324510145, 4.073757481190467, 0.5182607483959968, 0.22472421638667586, 0.5348426908735306, 1.5447887201463024, 1.1916797968649095, 2.1532770366437974, 0.36607888377001213, 0.6900181513159507, 0.6355975327953216, 0.2697364631439409, 1.1919522790178176, 16.6246953318196, 64.05428963322794, 85.91511772524926, 45.25331035737069, 19.383055087058775, 23.023212686661754, 52.847007243864, 76.35217528189384, 61.37146688276722, 16.60056491051951, 0.7350037535352092, 0.05974395666271449, 0.08488120901728831, 0.0702962968798895, 0.11256781046188648, 0.039656690787523985, 0.15978265193200883, 0.08887477940128696, 0.0723850662489572, 0.08245018220716908, 0.06186075335849197, 0.06542015490272353, 0.02728546823134586, 0.03300957569491959, 0.021107850123136755, 0.0334231635826009, 0.011504187226115216, 0.014165980786445641, 0.025235411200311877, 0.06278745544653747, 0.01522574564366932, 0.024251145265635946, 0.054778917842815, 0.042844773345296426, 0.05943808839806627, 0.06895602605636082, 0.03085803499655618, 0.032648679334670305, 0.012306659538749487, 0.06815949379796944, 0.025535694683992097, 0.004836169424496832, 0.05668069281044507, 0.07600993383675814, 0.03675225611415602, 0.029354522327682184, 0.10305052397832756, 0.08986718502015838, 0.06342761383782472, 0.07395266600313687, 0.17204298517636715, 0.007702746905476576, 0.03353517712844956, 0.0378759692032491, 0.2235759578404888, 0.12653088903114681, 0.1462188813715212, 0.16695236156304039, 0.18742679678384336, 0.1450935901413041, 0.10428256956079315, 0.12444192047921881, 0.2006074620951568, 0.14568315608607185, 0.13229380842418442, 0.1707622853498305, 0.13797517775768234, 0.20531471998941517, 0.19233971864225405, 0.3024601233342002, 0.13901203179792052, 0.12780498517977615, 0.17794222991553046, 0.15035126688739947, 0.12166642989482611, 0.18203061134103807, 0.1568291531575303, 0.18600423279548847, 0.13003967131578154, 0.10773036358577591, 0.12205403974099506, 0.21335611510421001, 0.0962194864968619, 0.16179006276351793, 0.08857957508054473, 0.1825497431620475, 0.11941826827223263, 0.15212042437445733, 0.16802473143944818, 0.09889878708148196, 0.08294883649796247, 0.16714958323826715, 0.0993140986669929, 0.0918592434496649, 0.23869269587580236, 0.09865214507425986, 0.1599488776898192, 0.2003435448052422, 0.1552455268439747, 0.14746481612805398, 0.20295092505553078, 0.16727991011594573, 0.07434121047657344, 0.3787765459668252, 0.23053782781766308, 16.0169848703569, 62.57770161474905, 96.99398563754175, 96.7795967286633, 80.2446726829775, 53.26919547973141, 40.36896321081346, 42.032432556152344, 85.73416309971964, 106.45384034802838, 60.62864449716384, 8.519177186873652, 1.3451663092259438, 1.217121760691366, 5.520651196279834, 10.786032580560255, 10.589019771545164, 4.70331407362415, 2.8758036080868017, 1.1505978722726147, 0.998867478582167, 2.0330114061793974, 0.6313901166281393, 1.6334975342596731, 3.7795900144884667, 25.46926940641096, 35.49177046745054, 10.827169418334963, 0.5881202449240993, 0.7370859192263696, 0.6115081125209408, 0.9104548647038399, 0.8412914663072556, 0.18923597470406564, 0.4080789187742818, 0.3792306216013047, 4.086262732744217, 1.9972436803002513, 1.9765839437323234, 3.8495128818096656, 2.445299457157812, 0.49559131805454537, 0.26401277511350574, 0.20071849887890203, 0.3395986256580199, 5.025199459445092, 12.893416170151005, 25.250624725895545, 38.291958378207305, 36.44609881985572, 32.496556428170976, 24.08418243931186, 12.896071614757663, 15.484340729251986, 17.709907293319702, 28.462714456742813, 29.15527755214322, 35.32319484218475, 10.544648939563382, 2.2974508616232105, 0.36960071253199733, 0.16446957785275676, 1.1256468175880372, 1.9012587469431663, 2.4257128565542163, 2.564216895449546, 3.6680924748220756, 1.8691116138812036, 1.2813130645982682, 0.6782151878841463, 3.8802321495548373, 38.2361352059149, 74.6718240553333, 77.7040829197053, 35.694651142243416, 27.30824128273995, 46.4219727054719, 72.7325963973999, 86.66005426837553, 69.62769523743661, 20.343486647452078, 1.0773001731403413, 0.42023924690100456, 0.1595675957299048, 0.17662697952360878, 0.2795939922573105, 0.16487863816080556, 0.21116321906447413, 0.19171554084506728, 0.14037583684248311, 0.13174194932704972, 0.2265520715304921, 0.1575842553809766, 0.10871369872362384, 0.14643772204797115, 0.12752733193337917, 0.15553097120456158, 0.12184540335569652, 0.11624232820806005, 0.10895503940240991, 0.09153079091300888, 0.12102205035907608, 0.15346673197082936, 0.15445447977512114, 0.10417847353364192, 0.12980713298724544, 0.15482511311288805, 0.13981472340322312, 0.11464795368092676, 0.09614791090209639, 0.14625189976105768, 0.11962940976504358, 0.12099364381884375, 0.10167663721668144, 0.1392826753398103, 0.14283295660730333, 0.1370171848083696, 0.12037792363234105, 0.16910649355380766, 0.13913573967593332, 0.16305386269044492, 0.20405786081908212, 0.13186649990177926, 0.14458714473632076, 0.09607725461284], [0.08207774856278012, 0.0796581594453704, 0.049761482439334356, 0.0115866192443777, 0.04969731491479663, 0.07445334276605038, 0.031573338952336105, 0.030687413809280244, 0.0904513577059392, 0.025939999501250928, 0.06905066089764719, 0.07093562789621853, 0.01325722718085613, 0.029821895333307407, 0.02997530444014457, 0.08566923003884093, 0.031049269694654696, 0.059004091928082134, 0.016517047169468096, 0.11817925128965609, 0.032939229671272545, 0.04501022811558458, 0.03220591115795317, 0.010683170797663831, 0.053095983551634904, 0.007932580943639961, 0.09671821739644774, 0.030261859628221685, 0.08391639022457023, 0.06445407972580965, 0.056740485972935156, 0.0054733185266565175, 0.07434411394980646, 0.04892380742896949, 0.030171731299149896, 0.02024121124357466, 0.04603107091820529, 0.023495386121794585, 0.036344245346563483, 0.08105854518831739, 0.04724931542671496, 0.013706528172347576, 0.06406102682493868, 0.032644619068671624, 0.024300768610931212, 0.023971797049706502, 0.03360850706456169, 0.06788810715079308, 0.031454001605931314, 0.12930030453829996, 0.05497222480874869, 0.333594641377849, 0.19425181281422416, 12.046111649082555, 50.56460749718451, 74.01621557051136, 76.6127226429601, 68.31363847178798, 47.48963402163598, 13.360129191029458, 30.330598123611946, 53.38309326479512, 73.67896233835529, 53.6998168114693, 12.65966546150946, 1.355422449208075, 0.5071425449944312, 0.5852829616877341, 0.46815081469474307, 1.8235493619595806, 1.4133983898547389, 1.3600181187352827, 2.938085943460465, 1.9204778704912433, 1.1682299067897182, 0.7124183783608099, 1.1491268608839282, 5.06734287546527, 4.789714082594841, 0.4046114822549205, 0.37354462509674413, 0.16933468050293385, 0.2356425780923136, 0.22439211727150027, 0.4449015477251622, 0.202667472523547, 1.5343682083391375, 5.191016187590938, 8.309620638047496, 4.86023731770054, 4.994859926162228, 2.023429546144701, 0.32996641832493967, 0.20852423002642972, 0.16726369969546798, 0.11763364346998355, 0.1580916047697106, 0.2778740942237839, 0.52330405841912, 0.35597813706244197, 0.19921891241063996, 0.08749793554025312, 0.23866534653690555, 0.17842691842346423, 0.11247673026856878, 0.08050701550899014, 0.1537893009522269, 0.03852609822887086, 0.4085638830738683, 0.7995982035513848, 0.04694069307597895, 0.37393952809995223, 1.0313476453865729, 0.14820628198644809, 2.2974432620310017, 0.6418909757368026, 1.1525675149694568, 0.23058593813930792, 0.34350852391892867, 6.544891874636374, 38.23126754453106, 67.74264335632324, 57.130278618105, 26.679706958032426, 16.89595860819663, 36.56276187589092, 69.46809399512507, 73.3898130539925, 49.730221302278586, 18.299876874493016, 1.0059358347808163, 0.13474611715684015, 0.11902293625978694, 0.07037170291427644, 0.062173416823028564, 0.05756871511919364, 0.021810802826357466, 0.03803377182433202, 0.1957453778314014, 0.05695613972362011, 0.03727627940656197, 0.06230972684739579, 0.07732919086852381, 0.03464756743802178, 0.11809744842110143, 0.026749327343197602, 0.035606675045264345, 0.09861737234337677, 0.011775192744549245, 0.06444415888719021, 0.04531510429637087, 0.03827519677278977, 0.021082009977450775, 0.028733690419504722, 0.058152447304418015, 0.04788554378695065, 0.022285920980897163, 0.036830726500240066, 0.009802613058127463, 0.03267632361741797, 0.055580858681951804, 0.04930220123740935, 0.017856471465840455, 0.03852920854584344, 0.02265397260235923, 0.01667657348838064, 0.04331275347560164, 0.03153219811558243, 0.06630883221664736, 0.054908501615207043, 0.027332628603964567, 0.018194701199630098, 0.037207783485252055, 0.05546165157049414, 0.04540977744205345, 0.06919981821650459, 0.015617110278277148, 0.09121985880718117, 0.04377704872299106, 0.014410240260223228, 0.0540622579114091, 0.027493260004707885, 0.02462642684188341, 0.06899285956376022, 0.03159326872968626, 0.024688198426437956, 0.09221045645855128, 0.04950492725437207, 0.009944629479920673, 0.1004748291245872, 0.04378126986745385, 0.047515680367547664, 0.0358402973882133, 0.022237372073915698, 0.018951509883927724, 0.06742603355838407, 0.029927784006201455, 0.044792536571021044, 0.004109419157518254, 0.03859485078963541, 0.09171176386336166, 0.032702267184973724, 0.06505916661192333, 0.04558993450876686, 0.06599448335867736, 0.03809554149366675, 0.11436864568461334, 0.013159825804553205, 0.05861283933383323, 0.1016968006508485, 0.00806988113664932, 0.019007233204320073, 0.041710453768891674, 0.03677031663697093, 0.045686963374816605, 0.06894539275597181, 0.03510557693399249, 0.03713381769616277, 0.03759772606915043, 0.10227669856601185, 0.048167567564955646, 0.07284782165961881, 0.05404042057512749, 0.06570698588245338, 0.011827732012006304, 0.033384365059675715, 0.027550433146496935, 0.3832537783009391, 0.3184990320474871, 14.294121034683721, 61.909235600502264, 89.77066639930972, 73.82751818626159, 50.96926666075184, 27.32775115197705, 18.89501613955344, 60.622596202358125, 106.06760455716042, 102.69227950803696, 40.669232414614775, 5.837482117837475, 1.4893029942627878, 0.3356707090091321, 0.02160819938346263, 0.8036644143923637, 0.6384066852831072, 2.858592247770679, 1.279077436174116, 0.6448318340605306, 2.5263647975460177, 2.0762625240510513, 0.6746844418587223, 3.3072307417469644, 4.961417798073062, 6.594355413990637, 1.0203814338291846, 0.7187512288651159, 1.0402638056585867, 0.432040095930138, 1.129249024295038, 1.6964846705236745, 1.132002283007868, 3.305446553614832, 5.3654150616738105, 9.14313018321991, 6.393734514713288, 4.834177580571944, 5.331689542339695, 2.2610120427223945, 0.580205453499671, 0.27634489079636915, 0.2865908571308659, 0.3108655787523716, 0.3586135714525177, 0.9118284297085578, 0.9981656194694581, 0.8926218087154051, 0.7945385911772329, 0.5151254876006035, 0.2448496832362106, 0.35091230405434487, 0.1609154201803669, 0.5690148701110195, 0.2583698327502897, 1.9857913399896316, 0.8910751078397998, 0.11793685340953451, 0.8193787776174084, 1.0373847859521066, 1.6030783278326837, 0.32733812387431827, 1.1493337659105178, 0.32443127985442843, 0.20543485789770083, 0.48252366603382174, 0.5028003279960925, 24.759039955754435, 73.05813743222144, 86.10223047194943, 43.49302514906853, 22.24706780525946, 20.87032764188705, 53.74010739787933, 79.02232877669796, 64.4554029741595, 24.942459790937363, 1.6987645481863332, 0.0796966553635655, 0.08934760886815288, 0.05469616502523423, 0.09575844712315068, 0.02392819707071589, 0.0036716085272811114, 0.05891263635168153, 0.11222992738288258, 0.08632262642945975, 0.035762240689608364, 0.06818384007220307, 0.034860723742073586, 0.05411927400517368, 0.031143276343843153, 0.05297505657278723, 0.023336037918324434, 0.10486698739470975, 0.03449991548193559, 0.025640466783736503, 0.04259950263545879, 0.07919646889692353, 0.00941382822460465, 0.0387050601984224, 0.06764247637963103, 0.005786162021855314, 0.11141026693005716, 0.03204899145320299, 0.03359205149594815, 0.039424972173066876, 0.04261327306589773, 0.039418372325599194, 0.01965265461964713, 0.0535047029505574, 0.03911063863685535, 0.04554272050999346, 0.07631695889417203, 0.04694517085989637, 0.03354654587324589, 0.017206802092973265, 0.05440143950944466, 0.05588993302456314, 0.02233699031714951, 0.023046751626797264, 0.055972429202689286, 0.07832718892924248, 0.1415635182732536, 0.29682870293336533, 0.16339956752715573, 0.1327080781301183, 0.11352582639383693, 0.19204924874488385, 0.11066452630104558, 0.18302818039251914, 0.17722933913671202, 0.14775298776165133, 0.1931950711314717, 0.11361449341019315, 0.14135981549418744, 0.16372425091122428, 0.12765951274383452, 0.22748790921703463, 0.0792042293675965, 0.187519294239821, 0.13812211342155933, 0.1650851448216746, 0.15412818760641162, 0.11993721623214022, 0.15941558856396906, 0.07760071541152655, 0.18179212817020957, 0.11365629882822115, 0.1626636634670919, 0.255212631196745, 0.14266306894921488, 0.18047998809526045, 0.17432689246150757, 0.11178067810232602, 0.10938484537144823, 0.17836728613943825, 0.1876612043669147, 0.08766134209450215, 0.12506802881797477, 0.13423588727751087, 0.09812356738914406, 0.2621799250764232, 0.22459306213403904, 0.12579564380669786, 0.13473848692111431, 0.226939175758631, 0.19881838632206764, 0.11127905139038641, 0.16457820912041973, 0.2508288309458764, 0.18129331300095206, 0.21485292833418618, 0.14716043407397886, 1.0216609232368008, 0.8229171845220751, 18.38121114238616, 74.32954234461631, 99.35426404399257, 92.7957473262664, 87.29907897210892, 68.21678730749315, 24.246123375431186, 46.313640763682706, 70.88095526541434, 93.46148337087324, 70.84016261562225, 18.324548582876883, 3.444861072686411, 0.48906814066633103, 1.9693023086555543, 4.439311594732346, 7.915663661495333, 8.694457123356482, 3.415754144230197, 9.93560879461227, 4.828921604541041, 3.2747027710560834, 0.4514473400289013, 3.5726793494916733, 8.154185443155228, 8.900619841391041, 0.9514973817333099, 0.39607937718110703, 1.0842892239170692, 1.1242894323602801, 0.3796378126548183, 0.8504416204748616, 2.4414077305024673, 4.648136621521366, 15.150101838573335, 21.875668379568285, 13.933772886953047, 14.791434426461498, 8.353102072592705, 2.316426553072468, 0.3210551916591583, 0.34641233423063833, 0.31852697893496484, 0.45940870959912583, 0.5195116780457959, 0.5203886342144782, 0.7208528225460361, 0.982627395179964, 0.4956305111127515, 0.2894620627405182, 0.19116136816240129, 0.35493172224490876, 0.16336838774863752, 0.46274407256034117, 0.22422425208553193, 1.650850467624203, 2.060518620475646, 0.21788036991511622, 1.564324452511726, 2.902866246238832, 5.646779912133371, 9.14813022459707, 5.701690643064438, 3.8781824659916664, 1.5288273701744697, 0.5774814287020315, 11.191997893394964, 51.12436502210556, 86.45445146868306, 75.24326632099768, 39.47141116665256, 26.456222072724376, 48.70953036892799, 90.22529263650218, 91.98470315625592, 71.49015426635742, 31.3489709361907, 2.709737564286878, 0.22567540647522097, 0.2853684259518501, 0.15314070027201407, 0.1818433947741024, 0.14877827387423287, 0.12337533456663932, 0.10589329240423058, 0.2224197166581308, 0.20932876024275057, 0.13640068321218415, 0.1395983648516478, 0.22657891525135887, 0.14121117911511852, 0.2291214384979779, 0.14468911103904247, 0.09035028772608888, 0.2127244296453653, 0.11204525422785552, 0.21171374516862057, 0.17809814412988004, 0.17863230659596382, 0.1034338207494828, 0.0942245475767601, 0.2624039291854828, 0.08580315752976364, 0.1093063596636057, 0.20116362660642595, 0.0859309180128959, 0.16088165102466462, 0.23761332395576665, 0.10223690795922473, 0.1530748779975599, 0.19078236914450125, 0.16209027729928493, 0.10744266692669162, 0.1874045189470053, 0.10455818501331153, 0.19967684912825787, 0.2487618644391337, 0.1414254232640228, 0.11349637797402759, 0.10324420632734414, 0.13043878780257318, 0.13577449826463578, 0.19199730798361764], [0.036342828083903565, 0.01911519031460968, 0.0178101614508177, 0.05344106402668742, 0.04562439697404062, 0.02556577704155878, 0.12566203807270335, 0.005275266603641813, 0.007272564595745456, 0.04410026121824499, 0.018345599453295433, 0.0114578302882071, 0.03455536875633463, 0.01350622107800577, 0.0523849428751536, 0.027258498105971564, 0.034162606968874895, 0.035055991893093434, 0.036321205252240744, 0.013782345978993804, 0.020652253804127538, 0.0033686609728442087, 0.04930165348454349, 0.012704965887561202, 0.028573386521349033, 0.0162160512240183, 0.052329688783614874, 0.011418673619177314, 0.04204187489625427, 0.034336838345494, 0.012748608958997555, 0.0501348813545079, 0.0863174093706954, 0.03242591628804803, 0.0645544755482866, 0.04247697836328899, 0.09020188117339727, 0.05585471213224435, 0.023503878206435232, 0.013696133316824994, 0.03944340041808544, 0.03270676029064963, 0.015516903104951546, 0.04775644648039053, 0.02512563463120211, 0.05182667545253231, 0.0317063682051676, 0.07936641018116668, 0.12151324295348699, 0.07404803628883055, 0.06850873796089042, 0.10227941817814305, 0.012037825879580792, 0.3173514936239489, 0.36703201972188493, 21.117864501091745, 63.32131239675707, 73.07483103967482, 63.55460320749591, 63.37857507890271, 28.897901427361276, 17.65484113847056, 16.583633999670706, 42.16592258022678, 68.43967991490518, 67.92793612326345, 41.8862065961284, 17.864372191890595, 4.000327769787082, 0.2009307205556862, 1.6392977391519856, 3.104124285521046, 1.960959549873106, 2.584362678950833, 0.5719583024901729, 1.6329010888453455, 1.514181852821381, 2.2700634021912856, 0.1061950084723292, 0.8338932020048943, 0.4562908543213722, 0.5789023685839869, 1.242554408888663, 4.868045776121078, 5.432130655934734, 0.9654780573421909, 5.302555157292274, 1.2900107978813111, 4.158716509419103, 2.134443776261422, 2.029972059592124, 3.0946257758525113, 2.1014882672217587, 1.2061002682293616, 0.1230809039947006, 0.1611586990616014, 0.2497227685225587, 0.10533739602373493, 0.7258489415530236, 0.7786246160826376, 0.479482603409598, 0.29366298248210265, 0.4398821090017596, 0.3832033390720045, 0.23281773612383874, 0.4934784475593798, 0.47130348100777597, 0.19178499437628255, 0.6425167163533549, 0.20652670172914384, 0.3998632999437471, 1.4093416785040211, 2.2813264881410906, 2.5494651063796017, 0.45075498040645356, 0.42792647956840457, 6.613146999189931, 18.1467612712614, 50.74010610580445, 60.212583003505586, 44.3589158211985, 22.63612181909623, 20.536726136361402, 44.17215216544367, 59.392395788623446, 76.17486061588411, 49.14128526564568, 23.544062260658514, 2.4880805034791273, 0.11503093635603306, 0.021230765100147937, 0.012926018642892521, 0.03094057330951816, 0.16099362243567744, 0.041276227472530264, 0.04569846235456006, 0.022668547425118667, 0.04763984789831504, 0.048421893434058276, 0.025643450696201577, 0.03171085748040388, 0.037623999054513635, 0.034985795256591616, 0.043112115048232584, 0.0718110289064146, 0.07979516660974872, 0.012419363521339913, 0.03560335405411259, 0.048426447826768124, 0.05939060626851936, 0.03993744285957467, 0.02033880892990818, 0.03646441772880574, 0.06560459057049406, 0.05311807369693153, 0.03296468677299638, 0.048654987176339475, 0.0567209852048226, 0.017704623263149012, 0.021534467251190258, 0.0916976142194002, 0.02614396275021136, 0.06346919709035466, 0.11071486593855005, 0.008262304228640372, 0.008240679481757746, 0.09459203995403745, 0.030292784682505076, 0.04977810654729124, 0.025137108713088017, 0.07101538531001537, 0.05157482787786473, 0.051362973923284205, 0.050361647210534544, 0.03324441611766815, 0.016841119598417033, 0.023282283443897482, 0.12874360376548383, 0.041933982903438236, 0.04552309716781301, 0.07030641690136925, 0.031588607084667014, 0.04300541815257842, 0.025616425029452772, 0.08008104764045247, 0.043751763991050185, 0.03312292223375651, 0.02560259331197989, 0.029287485803868023, 0.053357725151844566, 0.010857135958729253, 0.04951099084029275, 0.0563393623357819, 0.03195050893531692, 0.046643343709048726, 0.07474303891461703, 0.014561007321331532, 0.016651673715621713, 0.00461223857259498, 0.0670518072682523, 0.027328930314510103, 0.042467233724892146, 0.0028223849808601967, 0.026727509159114093, 0.08252573379826161, 0.029325569949803815, 0.01833379212316246, 0.05099789472296835, 0.022148548009535, 0.039650807232265516, 0.004045115652373962, 0.03590271823228367, 0.03439752400041588, 0.07270860816201857, 0.02595369332289744, 0.01902276180654524, 0.052592414806807236, 0.06509427642149311, 0.02956869944389309, 0.0733810341766765, 0.0792804014899077, 0.047023304167293736, 0.027532188762580196, 0.059609538875520236, 0.12212710920721294, 0.1316058001811466, 0.038210148247139114, 0.09206853867057832, 0.06014701850231617, 0.41368585500505667, 0.4016594390474981, 24.400011685586747, 76.7286600605134, 84.60160224668442, 65.35410427278089, 36.49733674141669, 16.440614577262632, 15.934705311252227, 34.275835714032574, 94.9056294656569, 105.47178868324526, 79.18202415589364, 33.977782649378625, 4.756764702258572, 1.6912753952126351, 0.7159239354152834, 1.8874555585845825, 1.7370660026227276, 0.49825822333655057, 2.6749789907086283, 2.060489938143761, 1.6185453365887366, 0.40722721286358377, 1.990692709242144, 1.7878613092245597, 0.44346712469573946, 1.6541924495850842, 0.3733963411181204, 1.5935717282756683, 1.8154331200545835, 4.3275495402274595, 2.7521021039255205, 3.181787705229175, 2.0509859126421714, 3.9628242725326173, 3.8199899369670502, 2.312460301383849, 2.0868230154437404, 3.6627421167589005, 2.809180924969335, 1.9131746623785266, 0.605725558294404, 1.376144085680285, 0.7618355234303783, 1.210014793661333, 1.3917163855606511, 2.3014031398680905, 1.6892198280942057, 1.3408874936642186, 1.0203626187097643, 0.6481280958940906, 1.6125977976668266, 0.7905526663507185, 1.1744089881258628, 0.8022502160841419, 0.23536016743990684, 0.8168428427269383, 1.0305037229291856, 1.0434248682952698, 1.1021252216831332, 0.08434521560106548, 0.3887358728435732, 0.8140671529596852, 6.177244686311291, 38.85823095998457, 80.96174470839962, 81.44689483027305, 41.3704502198004, 22.752765263280562, 28.046694147971373, 48.34446360988002, 80.61960420300885, 66.26845975075999, 31.91529254759512, 4.406284747585174, 0.02719355683263031, 0.06395256026617943, 0.0097980557925879, 0.025819846271206776, 0.007742379506629322, 0.08074397416484934, 0.03366165441430865, 0.05280358311269553, 0.02606172321153985, 0.10093045991755302, 0.012443619780242445, 0.02085714784991597, 0.06667419486949522, 0.03130143328059105, 0.04821122691576039, 0.04247132846484742, 0.07549932091346673, 0.05348088910743114, 0.020528605297928857, 0.005017114604162353, 0.06505768806222947, 0.0469577576844923, 0.006529944338610457, 0.02504773881106127, 0.06696283381672637, 0.02950314913065203, 0.04714872425181731, 0.07612149156029187, 0.0613565564215664, 0.08460677334017332, 0.016811155984478614, 0.02449411579648093, 0.03423567643509277, 0.07871825383194993, 0.050131196471592115, 0.044147080681737394, 0.0899978949417991, 0.07958020233819563, 0.02228025576069711, 0.013252219838661053, 0.0741358146431946, 0.05157268283167674, 0.04747358383610845, 0.03284993829325803, 0.023877535676283222, 0.013653727477386355, 0.020133727192578298, 0.1957550305392473, 0.26002547132872766, 0.11914336528148382, 0.1550465125230051, 0.2720450844255186, 0.11902905730230194, 0.2569213903118526, 0.07323495653127471, 0.13520348696939408, 0.12166459128380784, 0.09723076086130836, 0.08168096864415754, 0.1533664050962656, 0.1040009096745522, 0.18704885496727883, 0.14309318135342292, 0.14604401414192494, 0.15154280940130835, 0.14686849328779406, 0.1679847722933177, 0.16450696294346165, 0.11187624757088001, 0.1557665585630363, 0.16138098713371063, 0.14728948924570315, 0.1835801773854802, 0.11449786939568098, 0.20511144621958657, 0.13942522898076043, 0.14095944262319995, 0.20470275363374144, 0.1698466570627305, 0.22177445612126784, 0.1924436767735789, 0.17108931296294735, 0.11505961102703888, 0.1697096498983522, 0.21976928226649764, 0.15700953622018138, 0.1644431324976106, 0.13849346688197506, 0.16303498628399066, 0.13120843037482233, 0.1514469258367054, 0.17470527860906818, 0.15065702789973828, 0.1326400495224422, 0.22897978884077844, 0.23560916133705648, 0.20783110431605772, 0.18024564179922306, 0.35704698293439807, 0.14383175139946325, 0.7727520312032392, 0.8140940579675859, 31.19993655912338, 87.08980483393516, 95.95650303748347, 78.28249131479572, 81.46200380017682, 48.18201864919355, 26.463194085705666, 26.868569081829442, 59.61512757885841, 87.48642706101941, 87.82961091687604, 54.68394341007356, 25.63226349892155, 7.061372908853716, 0.897784751028784, 2.5375278630564293, 4.975854081492271, 3.337387884816816, 3.6044270136663994, 1.529268759392923, 4.26242740884904, 3.168471258494162, 6.000485525977227, 3.255258356371234, 1.7743867419419752, 4.129135954764582, 5.586684298130774, 3.842444770759152, 13.873172267790764, 15.492594376687082, 10.643208296068254, 18.262133867509906, 10.922829162689949, 11.963046635350874, 8.64025192876016, 8.898952834067806, 13.482222768568224, 8.653380101726903, 6.868169701868489, 1.9186157252519362, 0.31143153386731304, 1.1308562154731443, 0.976871562100226, 1.4024108504095387, 1.6570259943123788, 1.82195920857691, 2.252586546444124, 1.435665685322977, 1.334514867874884, 1.438074020608779, 1.9610280687770538, 1.4827981110542052, 1.7823107877085287, 2.8549608684355214, 3.0898015056886985, 2.4767306350892593, 7.162189589392755, 7.391009878727698, 7.370560111538057, 0.8051316259849457, 0.6903958633061379, 9.871948726715582, 30.152687257336034, 70.91699400255757, 78.22721727432744, 62.77591466903687, 35.915221706513435, 31.984063463826335, 56.74152074321624, 74.2746291622039, 96.76282467380648, 71.35849598915347, 38.77868137051983, 6.78908589386171, 0.22254325599680025, 0.2612834796309471, 0.15263580236463778, 0.17064174907582422, 0.3112366410993761, 0.12613949471063193, 0.1721981792680679, 0.11404516505858592, 0.13385124985248814, 0.17947716368061883, 0.13548139302480605, 0.09860396580470186, 0.2356041511220317, 0.09707624092698099, 0.10276180842230398, 0.1818064540143936, 0.12407697917472933, 0.23232454403994546, 0.08937119671534147, 0.12393729836349526, 0.17204627935444156, 0.12161952999210167, 0.1193937611195349, 0.11875947862262688, 0.19800953536985383, 0.24570537280411492, 0.23253710279541634, 0.21796209617487847, 0.23503456475032916, 0.12701247488298725, 0.19192606180665955, 0.21797153437810562, 0.18385437557533865, 0.3025037597023672, 0.22103896574868312, 0.09181494058500375, 0.14514222140273741, 0.26836678986587836, 0.14098317602709418, 0.1291042626384766, 0.15218171140839978, 0.2395279308961284, 0.12399595771585742, 0.14864275292042764, 0.1313785938245635, 0.15941921982073015, 0.10738435997477463], [0.0308634071881252, 0.03362337300073236, 0.07550246187395628, 0.10178608053754415, 0.03307583080905099, 0.045926208803129774, 0.039371499235952095, 0.017056849957894415, 0.024481186147538886, 0.03692731103529373, 0.011621211944598586, 0.04005717474126047, 0.008156132103214342, 0.030832420846807863, 0.03553086681471717, 0.024155376614221645, 0.05003205703331098, 0.04363975427564114, 0.035092626217632525, 0.04532920414461725, 0.07901659145230248, 0.040312749333679676, 0.0513631692757049, 0.027558182125851035, 0.03811574706266965, 0.04643935364701095, 0.053841218562616464, 0.040636406159929694, 0.032126755123176885, 0.026936409844746514, 0.011500035029565616, 0.11365003222900052, 0.05104313987577635, 0.05341583292090124, 0.0517212770759098, 0.025467438165158517, 0.014292975181653617, 0.04070931474768347, 0.0345505845372475, 0.018973033124160384, 0.0846484715058919, 0.05240333281577595, 0.045147783032828764, 0.022824057528088172, 0.13533715399042254, 0.03671384063519297, 0.04250098755883594, 0.0472026453503678, 0.02985295828341717, 0.04029172022015818, 0.1342108208806284, 0.04793377285222373, 0.07096110031970086, 0.06557993786109072, 0.04226046659412884, 0.3561125701713947, 2.7445645341950082, 33.978174886395855, 69.2937054172639, 71.19203059904038, 67.32633867571431, 79.43999844212686, 62.07397907010971, 28.04747469963566, 13.457358864045913, 16.935292136284612, 35.82943554847471, 80.14335001668623, 77.39704762735676, 60.47520529839301, 55.29084782446585, 34.35861733651931, 19.798204629651963, 7.752459722180521, 1.3359586678205, 0.2784525518936496, 0.38348562715034334, 1.302740605127427, 1.5882502976925144, 2.1662760165429886, 2.647706750900515, 0.8178332411954481, 1.3190582779146012, 1.1356291271025136, 3.3115703540463604, 2.3510907446184466, 1.7007383584014832, 0.8545598027206237, 1.7611424913329465, 5.783252408427577, 1.0849365375695692, 1.5120756626129153, 2.960336814003606, 2.8264506305417707, 2.9870905655045665, 3.2037765124151787, 2.7164171155421966, 2.377195098707753, 0.9060018713916502, 2.0164860929212263, 2.2235740000201814, 1.6448747366666796, 1.0408796177756403, 1.393112136471656, 1.9270536015110633, 2.4511504077142288, 0.7386115986493327, 1.0488181272822044, 1.7063190331382139, 1.5298642242147078, 0.4258859584168081, 0.005677242034805879, 2.6308332047154828, 11.324560276923641, 32.9697060585022, 55.92842125123548, 64.45900370997768, 90.88067362385412, 37.37292743498279, 15.667222219128764, 24.947196052920436, 44.90194835970479, 66.23736320003387, 66.04512783788866, 59.00145315354871, 26.48809329155953, 1.6197823540818308, 0.06993956037706907, 0.03954717468830847, 0.049724036061595527, 0.04595808572165909, 0.07884398418208284, 0.03561291100096799, 0.055410185783740976, 0.09153110500905784, 0.04274523554129466, 0.06884492032470242, 0.04410868052453284, 0.026848020535262845, 0.0332458027368111, 0.07430017114646974, 0.02243211928514704, 0.02244921836761698, 0.026026283984162638, 0.058258427907862974, 0.037453103990804766, 0.06683725668417831, 0.0310555707678319, 0.08711718984188573, 0.09826000764845841, 0.020047207137629874, 0.04932804904397457, 0.030792222298201055, 0.041573680261330265, 0.058506586769175147, 0.032832145901216615, 0.0802652151774495, 0.0166026862233036, 0.05542619702135844, 0.044253662664202914, 0.0438481072084077, 0.048011952124896555, 0.04106793199635802, 0.0660323434238953, 0.011859831096033656, 0.05971053990745737, 0.07628106767491949, 0.0712676350808432, 0.03506529603093382, 0.028923505939723506, 0.008980705094854198, 0.01976296936552371, 0.01108745358989484, 0.04044133336133054, 0.026424513724181923, 0.10220589672004986, 0.07122778318702214, 0.08707137778401376, 0.039866974261859735, 0.1292424495782583, 0.03280888364139584, 0.02418617909443715, 0.06310871441758449, 0.038883505058625055, 0.0589829670535701, 0.05154902220613534, 0.05784631090899629, 0.024787094631803133, 0.05831421060006946, 0.004523327365712894, 0.06894867161228772, 0.037671875719341545, 0.05308945265208041, 0.06171871682689075, 0.07318480841575131, 0.07866123390774574, 0.035748267245869485, 0.007827140432181618, 0.04780922610793383, 0.04777862089535883, 0.024822110595602184, 0.0802151743142355, 0.03118281797205489, 0.08099351198442521, 0.08185346866206777, 0.021565599149213206, 0.0381205887383511, 0.0657842688322548, 0.014921502443030478, 0.037396084066600575, 0.03905823439239495, 0.03537928865801904, 0.014983052819696887, 0.028118347531304728, 0.004135417787643571, 0.00942106584026929, 0.01629330544552255, 0.051765610584087914, 0.04079974376626554, 0.05969214996683502, 0.103150398861016, 0.05769597381473549, 0.06135428880131053, 0.014688483394321897, 0.033371042790672475, 0.04815763140457773, 0.03871709543971285, 0.07962860377325166, 0.051059626087906866, 0.08038219680348713, 0.0293266769468544, 0.3130923512001192, 4.2238455049453245, 42.62841709198491, 80.01493946198495, 80.77878182934177, 58.06340263735864, 45.59278365104429, 27.303561895124375, 17.043325977940714, 26.927659588475382, 52.34332392292639, 79.1018509095715, 110.42469886041458, 94.2350689057381, 55.8331782587113, 31.375011551764707, 14.22496376499053, 2.0275823555646406, 5.026490899824328, 2.6210412527284315, 0.6899746988088854, 0.23874722601425266, 0.28231620908744876, 0.4107954359102634, 0.6137073364469313, 0.776236015221765, 0.3125285411313657, 1.396710053086281, 0.9949309511050102, 1.7715791829170722, 2.285942627537635, 1.422053222214022, 0.5376371344731701, 0.792691154826072, 2.0476896508086115, 1.0318652756752507, 1.832826993157787, 1.546622550775928, 1.7019156823235175, 1.4234234777189072, 2.4098753063909473, 2.8803851815962025, 1.8473683225531734, 0.7096635874721312, 0.5790752593067385, 1.5196719453219445, 1.1983234339183377, 0.3296931700841073, 1.0670670770829724, 1.8517846662190653, 1.979283269855284, 1.685692023846411, 1.2606772299735778, 1.6018784502821586, 1.333636502104421, 0.6976363134960974, 0.09677369748392413, 1.7282893316399668, 0.8403374110498737, 7.738778004723211, 39.98368447826755, 74.1897020032329, 94.87570962598248, 60.489219927018695, 27.067749000364735, 16.8066736959642, 29.540381739216468, 50.60806735869377, 73.89206470981722, 74.43308507242511, 35.45474329302388, 2.8854881851903857, 0.0711248669352743, 0.0767797066439544, 0.02970486582677451, 0.08667055292115097, 0.0173081248818386, 0.023247026162402287, 0.05875432811256859, 0.053417721327634594, 0.06679012695507658, 0.051484801055442904, 0.015453130115694819, 0.06565427903326289, 0.030206180357884978, 0.04413265141568357, 0.0896724301480478, 0.028653335457126942, 0.012763100469695225, 0.06750325522115154, 0.032406756429061774, 0.031745369741392714, 0.05452104115618333, 0.080477888846109, 0.06790761174934526, 0.035362829258965875, 0.06290850499945302, 0.03392415444156335, 0.08737460304532321, 0.036470201692634055, 0.025181153023074714, 0.03775968471722257, 0.10029425453995505, 0.07398815885666879, 0.032571055475742586, 0.04906214375589644, 0.053934884302678614, 0.02814184344794241, 0.04369416950090278, 0.06816200656636108, 0.040110103755949006, 0.014038054636799762, 0.027143228686444705, 0.022878786849398768, 0.08855223340252716, 0.008419451844548027, 0.05724204756740121, 0.030095300622164246, 0.051873889451305714, 0.057058925740420825, 0.0247697101815814, 0.18061566226665052, 0.17736072321572613, 0.2936205412110975, 0.2823152284949057, 0.13841566299238514, 0.10181149167399253, 0.19166689426187547, 0.09607080415251756, 0.11843827327773457, 0.24970056729451304, 0.21174156948203043, 0.20776411758795862, 0.1643281580219346, 0.12954320037557235, 0.1522380188708344, 0.10866286112896859, 0.20373034290969375, 0.16877577339689578, 0.13150993193830215, 0.16408251958989328, 0.13644154634206526, 0.10351266651864975, 0.17146279614779258, 0.15601098657615725, 0.08660165097324118, 0.1523522579021031, 0.08770379868726577, 0.11756891670126109, 0.21728398578782238, 0.1333241200735492, 0.11097787158383478, 0.16401335717208926, 0.1960753165786305, 0.14831491325411106, 0.21207241221301018, 0.17792560580757358, 0.10760427317431859, 0.16380098227772022, 0.08080009010530288, 0.17245437439170577, 0.12666970416302645, 0.10671317502255402, 0.13984562739008857, 0.12564395839769033, 0.26491075273483033, 0.15225257454139574, 0.26799079391264147, 0.15206198718759323, 0.1475177068383463, 0.1150476600554201, 0.2995828503081876, 0.3594914162831922, 0.26507883242541747, 0.24367065859898446, 0.1580789183536845, 0.6881118794122051, 5.7581291371776215, 55.99933378158077, 101.18077062791394, 91.8103067336544, 83.98959482869795, 106.55927365826022, 94.07881736755373, 41.951631730602635, 21.007526266959406, 29.56480045472422, 49.161112846866736, 99.728560140056, 96.54430158676641, 84.27402942411362, 71.85677036162346, 48.36429903584142, 28.106622080649103, 9.215992131540853, 2.3035908418316997, 0.37745093806616725, 0.465853194435758, 1.8843942712391577, 2.4135407613169764, 4.550700533774592, 3.8521962733038015, 2.5616266602470033, 3.920726944361964, 5.125533198156665, 10.376748942559766, 7.569211980988903, 9.86417753081168, 9.652236180920756, 15.396959147145672, 18.404413923140496, 10.070567746316234, 14.741719365119936, 15.287403425862713, 13.084510122576068, 13.497295456547892, 14.895210535295549, 11.852958452317024, 10.908103604470531, 7.849568292017906, 11.914787753935784, 10.977467779190311, 9.909826074877094, 7.807126775864632, 6.615292535674188, 11.940705795441906, 10.449331422005931, 5.02424975556712, 4.9451316268213334, 5.632772637951759, 4.946369134610699, 1.201041391299617, 0.08562419172977248, 4.388312937751893, 19.260171151930287, 47.526468999924205, 80.04849141643894, 87.680309818637, 108.63838088127875, 52.0951202607924, 28.02940041788163, 37.129485530238, 59.37797323349984, 84.14346156581756, 87.17354743711411, 83.62282183862503, 40.72595773204681, 5.606012267451133, 0.18976972348267035, 0.30959044072416525, 0.1765688334501559, 0.3171752934013644, 0.2712926635098073, 0.057574502913461584, 0.1323843140515589, 0.2102922230598427, 0.1514539585238503, 0.1664920346510987, 0.11351507051938003, 0.19106789011388056, 0.11599266781441628, 0.13773615832530683, 0.13946393174269509, 0.18903484598042505, 0.10977949556564132, 0.21858639654613313, 0.13028593793992074, 0.12818972219622907, 0.11837163895008065, 0.18830545366771761, 0.2044860886469964, 0.14123842120170593, 0.16237060419253765, 0.12905915538149496, 0.18120040185749534, 0.18306743473775927, 0.15282217623485675, 0.19424200688879337, 0.16776488973729073, 0.3266905037866485, 0.12315319971211496, 0.16958598798561483, 0.16013756514556948, 0.07672141501379591, 0.16251393924317054, 0.19045865103121729, 0.1775744464248419, 0.17047497173470838, 0.2235286136067683, 0.13721115827079744, 0.299644106698613, 0.10972062170866037, 0.16409437863096116, 0.1330767043175236, 0.1585355833653481, 0.13665805811122542, 0.21662036978429366], [0.11764158014087908, 0.043603958817379135, 0.04008431723641773, 0.05079081349615609, 0.025124964304268364, 0.049390527344639265, 0.030456342539119146, 0.05679559067732865, 0.06671520355608195, 0.06302190133400502, 0.07141427963130897, 0.053160840555304484, 0.06129001785490302, 0.016264933379246824, 0.07255816381544837, 0.08558422492276277, 0.08926171509008254, 0.07163919538499848, 0.02912309674185611, 0.023904953963093223, 0.044119325316240715, 0.03527620769736748, 0.024992065286383997, 0.020708892599589402, 0.026000978184803843, 0.01744278015628938, 0.0364325178276387, 0.03914573695510626, 0.05162285776027749, 0.026566573238420873, 0.06426839533472253, 0.04335872258149809, 0.04656865013643138, 0.033853429204393784, 0.07401455824653949, 0.03120994323023385, 0.06855379159171736, 0.10511546035207088, 0.031994068694691506, 0.06625474640919317, 0.03456779087202684, 0.014087860885586952, 0.02637465672206975, 0.02666825417339081, 0.027627884635641694, 0.029200052189069892, 0.08530780507792389, 0.056194008643468546, 0.12830766909305127, 0.13263030488404537, 0.08759270061648662, 0.056964264086057106, 0.038266417405177514, 0.05674653040665773, 0.08197677051348072, 0.11731325017829096, 0.10684407646617583, 0.07812517920448896, 11.124734147902458, 48.75122516385971, 76.96947789961293, 66.75275479593586, 66.21790039923884, 84.27119747284921, 64.29874350947719, 53.639416233185806, 22.735296987718154, 16.043477539093264, 16.948424231621527, 28.770730341634444, 31.461586106208067, 39.761996038498424, 43.77255285939863, 53.8178526970648, 70.75888326091152, 59.14568654952511, 47.62744257527013, 45.5625343322754, 33.68397751162129, 21.945882728022916, 16.78359643105538, 8.174854863074518, 3.499134663612612, 1.4072722605159207, 0.6009655782291966, 0.3562731115568069, 0.10331045761103592, 0.19014876846584583, 1.063009017417508, 1.177837017082399, 0.641554203485289, 1.9007390328953344, 1.5762082535413005, 0.6356755511895303, 0.3772489666458099, 2.2478019902783055, 1.0675718370945224, 0.7293928642907451, 1.5955729950820248, 0.8477369623799479, 0.6622808042072481, 1.0975409515442387, 0.9949185098371199, 0.8512700373126615, 0.11001886739846199, 0.1067929937233848, 1.1689464747905731, 3.028989813981518, 9.721673900081266, 18.52548376206429, 30.883073768308087, 49.282219948307166, 56.65693090808008, 48.64930237493208, 42.8625080662389, 24.153122017460486, 14.438823153895719, 24.852257044084613, 30.55885457223462, 64.80701208114624, 63.66602989935107, 64.79591177355859, 57.13684074340328, 35.369055194239465, 4.245553372367736, 0.03713010600016963, 0.1273426511174729, 0.036818511228287415, 0.08314549126812527, 0.062183234239778215, 0.03710399006283091, 0.06130571499647153, 0.03479893875098036, 0.05981804502587165, 0.061058134531542185, 0.012477486612155073, 0.01622124913058454, 0.031082452793094902, 0.07263267352696388, 0.024677166760328318, 0.040023597107539256, 0.08894974876555706, 0.0310930113999113, 0.0644820112915289, 0.049777336628927346, 0.046869952517050895, 0.025350063919059695, 0.03970822552219033, 0.046479155745116935, 0.04353113832973665, 0.012059511913497363, 0.03372004946633693, 0.06464809915351291, 0.024959441432128512, 0.012691092035252483, 0.007962470342810717, 0.04060991483950808, 0.029199638501590783, 0.04251537852049355, 0.07412156540780299, 0.03809577898092328, 0.07262250754020869, 0.05945730954408646, 0.08220069035286866, 0.09174513465334332, 0.12486156812238118, 0.04260531724280408, 0.09904612111107958, 0.0416088551883736, 0.042209284259907665, 0.024154654576353008, 0.02977264928631485, 0.04192537590560894, 0.092210479441189, 0.01925252881201525, 0.04200753117460878, 0.033033967934428685, 0.04679930771911337, 0.0052934056504689644, 0.02910409201567452, 0.02248907792231729, 0.020149692464920304, 0.054940485786045754, 0.030790967829225045, 0.01612236824697785, 0.06510110226489844, 0.04055162703978919, 0.05259409253936141, 0.013441601561592713, 0.023094883015859994, 0.018963234859608838, 0.02908013644628227, 0.03787909101154055, 0.09837082226670558, 0.018765340942228516, 0.0074001057862093855, 0.027651646767833063, 0.06616293077146815, 0.044002531381744536, 0.04492591247863827, 0.018592819856900363, 0.044019856460152135, 0.044350243368816954, 0.004860160904260533, 0.11019846905143031, 0.03686041623774556, 0.06820861535567431, 0.04187928805608423, 0.02483144346173973, 0.03077677796564756, 0.07451109813466188, 0.015373653281600246, 0.11862035705557755, 0.1651751141875021, 0.02729382050494033, 0.033560760634680914, 0.036488407772154584, 0.03861093097516606, 0.08922084429932219, 0.01999249505329757, 0.03519201846492868, 0.05954711420101024, 0.024407511471860835, 0.04125538605055021, 0.051458620000630624, 0.14264109754754653, 0.0575470156787384, 0.06435274161518582, 0.05596174993702481, 0.051551006373859225, 0.028257913429350145, 0.08211558564536034, 0.1529240199635106, 0.035073041179848295, 15.045629509033697, 61.8865603785361, 90.01438679233675, 75.93554896693077, 67.18998139904392, 56.8419530314784, 22.011923674614202, 12.266563561654861, 12.435477491348022, 38.64689365510018, 46.11761639195104, 67.75130394966372, 84.51713792739376, 82.81926939564367, 85.1517931107552, 82.88035638870733, 67.73166856458111, 44.61123012727307, 23.219152727434714, 8.201541689134414, 3.1215719686400507, 2.3067191771922575, 3.5803235586612456, 2.339292500288256, 2.4504919398215512, 1.118599666703132, 1.070640724032156, 0.6883241164107478, 0.29361533181321237, 0.19213880442323225, 0.3795388647385182, 0.6468281979041716, 0.5733047786258882, 1.3760391622781756, 0.8240980018050441, 0.823182434804978, 0.5488328046856389, 1.1238941309913513, 0.9489315387702758, 1.0251048868221622, 0.2728716320087833, 0.38518928411987524, 1.6428898947854198, 0.33448906435120496, 0.6496187191336387, 0.8047879895856305, 0.32966451839573924, 0.4466502506646418, 1.5914825758626385, 2.246041091219072, 3.2293138388664495, 2.8788093693794745, 12.604875833757463, 27.0391764948445, 51.03737469642393, 62.21735346701838, 75.00739066831528, 56.89427744957709, 33.22469149866412, 48.20496059233143, 25.122584835175548, 36.47421044688071, 51.524113378217145, 71.78825439945345, 73.12664554965112, 46.94039629351708, 7.007763424227315, 0.05064616077429345, 0.02451932391962938, 0.01348912008031602, 0.05627296549538451, 0.07020238982213121, 0.03629943303343269, 0.06918288001249875, 0.04850110692542888, 0.019601374609215606, 0.07877950256149616, 0.02505473510902976, 0.04984868239731558, 0.025826367594662215, 0.07208375620745844, 0.055121217418702385, 0.01550879789471266, 0.06522285661870433, 0.04888574435045162, 0.07217775519576765, 0.03296883513910636, 0.035315236046669946, 0.023893409018074314, 0.04667138635751702, 0.04096845164895058, 0.05274012804992738, 0.02798836922363168, 0.04061477183694801, 0.0655886712634275, 0.008735162423803441, 0.02990894973458302, 0.0542574800971535, 0.04694305645722536, 0.015635456168843855, 0.05877331943221151, 0.06591245832462465, 0.04488896788848985, 0.018993977968010212, 0.01980665169896618, 0.0732556792096265, 0.08389546836335814, 0.05629628138135999, 0.0024369098865727507, 0.03486604805314734, 0.05735205779332788, 0.0175892370152137, 0.04783395159568998, 0.02975708237969347, 0.07405286264275351, 0.024909373755837162, 0.048953523979552334, 0.030948264832277934, 0.13179048865793214, 0.19809256397908737, 0.16588253509854117, 0.11913164413624233, 0.15755413280379388, 0.16031583380554953, 0.15335080754612723, 0.09172949113792951, 0.11166024141974988, 0.19399981585241136, 0.19415226734934316, 0.10349738306456036, 0.1224359039277319, 0.07409722679444859, 0.16767380188309378, 0.13566457996926, 0.18576129099294064, 0.24530211944253216, 0.16055102279830366, 0.12584012287158158, 0.12808649184843227, 0.1440493050482004, 0.08791348461302058, 0.170547244469485, 0.13812127072484265, 0.09039524942636491, 0.21139165116173608, 0.12433433109113287, 0.14877750778630858, 0.10306580743241696, 0.14367586782863065, 0.13038293999289313, 0.12942316971959608, 0.1584402820275676, 0.23117417109108743, 0.12441181322379459, 0.21433345943449006, 0.2876103362969814, 0.2015779729211523, 0.1912502343616178, 0.14851121562382869, 0.12602084301291935, 0.22552741361000847, 0.12889225546631122, 0.1178226143782658, 0.13048738842048954, 0.15499696195606263, 0.10840003168390644, 0.1717972088484995, 0.30356583335707266, 0.27408909893804984, 0.2389834568865838, 0.1369380938910669, 0.2836621642833756, 0.19910309523824724, 0.515166488626311, 0.3306121998015912, 0.1411835386628105, 17.872499342887632, 76.18625902360486, 105.62654972076417, 87.80275837067636, 84.97455689214891, 112.75025644610005, 89.4610188084264, 77.95877810447448, 32.2037201158462, 26.05484985536145, 26.69189376215781, 44.10223591712214, 43.93505273326751, 52.14737015385782, 58.324526586840236, 75.7526880694974, 99.50580873797017, 85.8713048504245, 69.06107748708418, 63.769184312512806, 49.026367664337165, 33.014868228666245, 23.07486245709081, 14.058878844784154, 6.102157773510103, 3.307607779579778, 1.9998411473727997, 0.9753354638814927, 0.6687282001779926, 0.4963556286548415, 1.6702610518663161, 1.93649462394176, 2.641339518370167, 4.678970863742213, 3.9067863504732814, 3.4978071864574187, 2.3968844163802365, 3.548576629930927, 3.5357931352430776, 3.3003472272426855, 3.289302323133715, 1.7895861715078356, 3.2066780857501493, 2.5736722590461856, 2.523585553130796, 1.514804651660304, 0.2156469784677029, 0.3029871918261051, 1.740422448323619, 4.842066937877286, 16.80820538151649, 32.440631274254095, 51.726460610666585, 78.4257911866711, 87.47133378059634, 72.02489883668962, 64.07627451804377, 38.816787196743874, 23.003169375081217, 40.56890603034727, 43.906274303313225, 88.51715533964096, 81.72356313274753, 87.60412170040993, 80.31187072876962, 56.726431385163345, 10.426288477836117, 0.09457176926756099, 0.5556323559534165, 0.37769976342397354, 0.19586946875337632, 0.2110390974989822, 0.19010137826684984, 0.1828362600457284, 0.31200861257891505, 0.13388569316556378, 0.1139500552427865, 0.12016692003535649, 0.14131124551978805, 0.21283454712360136, 0.20791425549935913, 0.14867613903216778, 0.08891123752560347, 0.32406907348382863, 0.1770738079663246, 0.17822857825986801, 0.1324015510298552, 0.08193087418593707, 0.14517847268331438, 0.1387274301340503, 0.15433446444090337, 0.09903801590084069, 0.09782656276177976, 0.15015514837878366, 0.16424511409094258, 0.11524990726743015, 0.1230122471949266, 0.08574357887189235, 0.13508851249371806, 0.12370029374236062, 0.11646001209174434, 0.10925317783990215, 0.11453235101315284, 0.18769426872172665, 0.10557704364820834, 0.18665291008449372, 0.16155571646748051, 0.13841589281876243, 0.08329795042593634, 0.21864832709393195, 0.1725645531569758, 0.15591539412496552, 0.17089317913257307, 0.1578962217055021, 0.10131046251063386, 0.23561236358458, 0.1940930334310378, 0.13992211360844875], [0.02515612876102809, 0.08543084645944257, 0.026848627659942836, 0.045546995280610944, 0.06185246045671164, 0.049935380567706404, 0.11905474423040306, 0.08852379621877786, 0.04618741797223207, 0.041208332930240905, 0.040942741738211726, 0.019205638485389854, 0.05345352061633622, 0.060249176327018976, 0.0611647701401624, 0.029594832618210106, 0.038871167212604515, 0.04549030094377456, 0.05623034419371717, 0.020043014721464247, 0.12836767676016017, 0.0468058999057018, 0.02849112974569923, 0.0062249652147593525, 0.059814030725148425, 0.04479746251637417, 0.013946307946987932, 0.03394591133861292, 0.02411190495495835, 0.013436855646901795, 0.05888306152736468, 0.031190739321191947, 0.05876225712258489, 0.0701226553909721, 0.036299934821023096, 0.028438947666736863, 0.02207581179156419, 0.00590046234015796, 0.0350597610456809, 0.014232917718829648, 0.000991727092402852, 0.09235576035514956, 0.05617963683400905, 0.057217433162394075, 0.14689611841834363, 0.03195181894566744, 0.05131431201833391, 0.019521109662168933, 0.06128757020398494, 0.0893202671901353, 0.028476185285516327, 0.07349970119614756, 0.028179285995241617, 0.015977885979678363, 0.06791606169915007, 0.12324420329664024, 0.05682852096675385, 0.005294293354851224, 0.4343034260936322, 0.03261328224212893, 18.345945112166866, 63.54278510616672, 77.08678814672655, 65.75229937030424, 64.45270830585112, 67.21481784697502, 81.63734943636003, 66.66587429661905, 51.74023205234159, 23.738898154227968, 29.89108870106359, 27.307666655509706, 29.9860296710845, 21.934449018970614, 22.456516488905876, 33.01859840270012, 41.379310854019664, 34.48915773822416, 39.42455453257407, 62.551810049241595, 56.038965409801854, 61.52744777740971, 63.4013875838249, 57.600762997904134, 55.96742137785881, 40.251127366096746, 38.61305928999378, 28.92667789613047, 23.37425304997352, 17.458393150760283, 10.36062603996646, 11.072148892187304, 9.145601276428469, 7.534821129614308, 6.4681085367356586, 11.59052933416059, 12.455642396403897, 14.470931676126296, 18.41408452680034, 21.30522043474259, 16.781907850696197, 28.53996357610149, 34.97261339618314, 42.797220214720696, 45.62186018113167, 59.80823370718188, 57.67277771426786, 68.06520338981383, 61.032554488028254, 45.23952714858517, 47.36423976959721, 44.14997900685957, 19.80317427266029, 16.445090001629247, 25.136062099087624, 34.02567871155278, 57.77347672370173, 62.59127693791544, 63.45630076623733, 61.9461254919729, 57.44588036690989, 34.666676367482836, 8.527199414468582, 0.06862217259983863, 0.29340232872674543, 0.025769301705182563, 0.15293947961782256, 0.05933869998120974, 0.032633104767169685, 0.06559014981312138, 0.04593383903885561, 0.08459412522854344, 0.02419480715968436, 0.03176548912550413, 0.026858808968456525, 0.04827312298960263, 0.08163616782234562, 0.08797911536549369, 0.09872591168048883, 0.08823992233843574, 0.05726360911203008, 0.08820813735045734, 0.054840235520274415, 0.01818304900230179, 0.04440584603036123, 0.06802088550982938, 0.020238740610018856, 0.04871219479208512, 0.0677535591286517, 0.039869728347947525, 0.07030444039452462, 0.04401630947306272, 0.04849078772108882, 0.05672789531789961, 0.008669549865918535, 0.0585097813558194, 0.023550540621903156, 0.05724012085627164, 0.07772991613995645, 0.051447538538805904, 0.04529437012670021, 0.010112145138273557, 0.07286557957770363, 0.01571098573490857, 0.05759469316070599, 0.071179757135049, 0.04277109483917875, 0.03863294834210988, 0.04453416958811783, 0.02054757555015385, 0.04250548066451185, 0.06998080655091232, 0.07236598299876337, 0.04550876749318935, 0.028613169467256918, 0.06862722111925965, 0.01573561929211381, 0.10685788137057137, 0.05228763438701149, 0.03165447532439665, 0.01590437984334365, 0.04858107118296528, 0.015384747192353733, 0.04685831947192069, 0.0390771261206077, 0.02654061817954625, 0.0821205345733512, 0.02255594016112868, 0.04842714879721884, 0.0669198869276912, 0.04125093891014976, 0.03798083897920386, 0.03390058574657287, 0.08828792540777115, 0.06350142640932914, 0.06102685516159381, 0.07567387404701403, 0.035663239147153594, 0.06595680715456124, 0.06446669719392253, 0.008521279293833482, 0.06516847203695966, 0.020175492390990257, 0.04299503766120442, 0.02199252462765623, 0.009437659304709205, 0.10207017658338433, 0.02567803956598284, 0.016206994149533492, 0.07287214495121472, 0.0678747235947559, 0.07241499730415883, 0.0762189839095358, 0.05047764441358948, 0.00911189956710704, 0.03889465929880258, 0.09182172812401287, 0.06604872238371642, 0.018929504008302768, 0.01729965577983568, 0.14917458647922163, 0.008270091512390684, 0.02243324160395611, 0.041587557944078604, 0.02468522983573137, 0.029214498692102013, 0.011209169639304522, 0.026547821321254297, 0.059396796258947546, 0.06591611256402347, 0.056862657844659784, 0.06672137056387241, 0.06385681842784248, 0.04549755962685712, 0.44426725756737495, 0.3761781289452507, 25.501658378108857, 75.27735956253545, 89.59606601345925, 74.24658421547183, 63.905984817012666, 63.28646213777604, 48.44735914661039, 29.616748325286377, 11.819159388542177, 14.193306315329767, 19.14366891307216, 30.269871988604148, 34.8087759940855, 40.614538884931996, 55.47818022389566, 69.40211972882672, 78.91729554822369, 80.1531167184153, 77.4606841610324, 81.81884534897344, 76.3750348552581, 65.00084777032176, 55.958819620070926, 41.662247104029504, 28.858883650072162, 23.872405828968173, 11.986496525426066, 11.102936556262355, 7.224224815445562, 1.9975285424340157, 1.8334211096648247, 3.6316860154751813, 2.6207112833376858, 2.5556489681043937, 0.9326440804908354, 3.049991164476641, 3.216200374787854, 2.7224926217909786, 1.5512939710770886, 2.3210811807263285, 9.426809722377408, 4.562659840429983, 9.436028272874895, 17.99533817075914, 27.46330826513229, 35.846348808657744, 47.071101434769176, 55.1342942637782, 64.05273637463971, 63.11102236470869, 64.4290485689717, 66.94182872772217, 42.66327519570628, 27.657689163761756, 24.894236210853826, 20.03441172261392, 27.03890192893244, 40.14777291205622, 63.8073685861403, 74.57521607798915, 73.0982554343439, 50.324581976859804, 12.568186963758162, 0.07085559469076895, 0.2583901800455586, 0.03641921854127319, 0.0893811175539609, 0.024478253946008704, 0.03571514543446322, 0.07453277076203978, 0.06628463149911935, 0.04878249868089634, 0.03577605325488314, 0.09103902375265475, 0.06289162808248112, 0.06340406812547196, 0.07984205885159393, 0.07190126640301558, 0.012723948588714966, 0.029379722789951393, 0.08113041189649413, 0.07034476726285874, 0.10300307249229762, 0.07260202234911342, 0.03402835006014474, 0.04416244457505884, 0.034920130030161915, 0.04826478795298646, 0.020082470164784504, 0.04383459724786301, 0.120002142183723, 0.028633763825881387, 0.04162220427045419, 0.03398132375291279, 0.023646002838147745, 0.048460864326766426, 0.06757400344095885, 0.11150667143444862, 0.03558915078399643, 0.02206571092228255, 0.05498933921297712, 0.13524597420567466, 0.04445263485033666, 0.009642720932231076, 0.10418883870325743, 0.12350144796073438, 0.058128468752388036, 0.015906913679153208, 0.06973176668848723, 0.023107038915998513, 0.04711174901815192, 0.08304439830563723, 0.07137425153726532, 0.03336330147219762, 0.015016935930977908, 0.022904567623270616, 0.10891432182923441, 0.1781068009234244, 0.11064259320377343, 0.14632700702115414, 0.1611866153055622, 0.18706003985097333, 0.18438677603919662, 0.23152461035117028, 0.1256381361294658, 0.11332569358449791, 0.15445616516855457, 0.07693045742569432, 0.125385319453574, 0.15549904065987757, 0.12683758467075326, 0.11297493256748685, 0.1549940201784334, 0.17884085105071146, 0.12016371012695375, 0.16763016551492677, 0.22244798530253673, 0.1629181425537794, 0.24905853964869054, 0.1259257944841539, 0.13731421241837163, 0.45654001675786515, 0.13407067275576054, 0.1962972062850191, 0.09305715981510379, 0.19378368712721333, 0.11280569608413404, 0.16615469549452105, 0.14528642979360398, 0.17386739292452413, 0.15037542930053127, 0.16330752972393267, 0.10384908636971828, 0.12102236445512503, 0.18488908456938882, 0.14240233858506526, 0.2036106186888872, 0.18041635683226973, 0.17562128994013035, 0.12043055387273913, 0.24296489243786185, 0.17116020673946028, 0.15845503688098925, 0.10530139755217299, 0.30311390276878114, 0.18113064189111033, 0.09968728307754764, 0.2498268951932269, 0.1908858982665885, 0.19667084268744917, 0.14001603598796553, 0.22743324118275798, 0.19904571525271864, 0.2755484351467702, 0.62699853292396, 0.44120066889351417, 29.4717029986843, 89.13278702766665, 107.83693082870977, 81.24702653577252, 80.62378544961253, 88.61655604454779, 104.22641261931389, 94.39513298772997, 79.1192505436559, 39.880592823028564, 41.750900514664195, 36.13691799102291, 36.518274353396514, 29.380623602098037, 33.779549983239946, 47.073815714928415, 57.51392172228906, 53.59628585077102, 60.1599604852738, 86.7422357682259, 81.82235979264783, 89.79580879211427, 94.43362712860109, 89.11704263379498, 84.78913860936319, 66.2525898410428, 61.826171567363126, 49.196625986406886, 38.26763576076877, 28.409478087579053, 18.189664156206195, 18.027442770619547, 14.292145140709417, 12.968325595701895, 11.916045854168555, 17.584028628564653, 19.131786092635124, 22.25760917509756, 26.480729041561005, 30.43308573384439, 25.010599205570838, 42.62957419118574, 52.48763968867641, 63.42552584986534, 65.6458697780486, 80.77006632281889, 78.08419196836411, 94.55959796905519, 87.80446067933114, 72.61438400514665, 68.7675900613108, 62.44820456351004, 34.132461317123905, 30.349205847709413, 42.39985665967388, 57.28572607040406, 86.07758229778659, 78.18563230576055, 88.75559622241606, 87.30411529541017, 87.0184882994621, 61.097446180159054, 18.122609276925367, 0.1425401884461603, 0.8605077093647373, 0.10161074599431408, 0.2587188624085919, 0.10429060582311885, 0.2279564179480076, 0.13482991185399795, 0.11222770572790217, 0.15527184962505294, 0.11495827291641506, 0.2112085101825576, 0.12739271496332463, 0.15777635958886918, 0.20440505186636604, 0.13826288973852513, 0.27917595339878915, 0.23029693913075233, 0.12711736764157974, 0.15202012814341054, 0.20558928590147726, 0.13868256802520446, 0.09261386303771889, 0.2783389563762373, 0.16183555306446168, 0.1506564916381913, 0.15157294730024953, 0.19333659821460325, 0.22574706633965816, 0.16662711127390786, 0.18605718479281474, 0.2033051334682011, 0.16484099260020643, 0.13023482455361274, 0.21620383245810387, 0.2013234938344648, 0.2278627253948681, 0.1396441615877613, 0.09159428428017324, 0.22686353223698758, 0.1909240034799422, 0.10645204629268377, 0.20354188528032074, 0.2866338806286935, 0.12407646589582005, 0.13178857343812145, 0.22987870108937064, 0.19673039836268272, 0.12592138181771004, 0.15150084310481626, 0.2518045052044815, 0.12621346816060044, 0.1047320869721232, 0.1402857602243462], [0.039225390947033326, 0.04208216729063181, 0.030424249200751225, 0.061443277574594946, 0.06628150586038828, 0.014277531806710026, 0.09850754597855192, 0.047783451079721415, 0.04881671216759471, 0.10643058816992468, 0.029335320333860097, 0.03583602261759582, 0.02797552959002074, 0.038728023683952714, 0.01795830753361506, 0.08058165545545279, 0.04292293346577114, 0.044005423363658695, 0.037699692371872165, 0.06584035412919137, 0.015305683088128366, 0.050434743489829764, 0.05132745042623532, 0.030704286895812522, 0.04625025250378155, 0.01868480211874891, 0.053635359246043436, 0.03546639285500973, 0.01957756076608935, 0.07335370782041743, 0.10098048545900853, 0.0938494939116701, 0.040728509080626314, 0.01806822391377101, 0.050441925564119895, 0.01661603913582381, 0.06159235445422031, 0.05603468533785594, 0.07256061529680606, 0.03159349664084373, 0.06848867411815351, 0.035728820103911624, 0.036527857469815406, 0.04016713900191169, 0.019826298023784356, 0.03306276134906277, 0.016264584809241277, 0.0854270006980627, 0.02116358110440835, 0.05540440565035228, 0.042169079965641426, 0.026952396184506438, 0.026739912122608196, 0.12458166257748682, 0.034379065111880346, 0.04919068181827184, 0.03350563294764969, 0.11599890377011993, 0.07693705344272238, 0.08680915354841179, 0.4010507362263818, 0.7037125551892865, 18.041312271548858, 55.38472583217006, 81.27625603829661, 76.0244926329582, 75.3068087177892, 69.8343413875949, 72.50722485203897, 76.64667467917167, 93.71312695164835, 76.80628376622354, 79.12893095324117, 86.24966452198645, 61.51850085104666, 49.8605538183643, 41.55326797116188, 25.235447114513768, 19.42798975975283, 14.409633855665884, 25.82570891226492, 12.693047773453499, 11.846968993063896, 18.817582668796664, 40.22498476889826, 57.120276574165594, 64.89005258006435, 43.15804689161239, 33.048969314944365, 44.205680585676625, 54.46875433767996, 42.3085242702115, 45.730517679645175, 58.67166811420072, 75.07068987815612, 56.97215218697825, 58.71643412497736, 42.193736107118674, 54.21962499618531, 44.140086789284986, 61.49147179818923, 66.40739794700377, 40.306895625206735, 38.1469601200473, 24.45214782991717, 17.03831711123067, 14.75380418762084, 30.756751875723566, 23.729358949968894, 20.87072184008937, 31.291353279544463, 35.926541666830744, 46.237711521887014, 62.4024461930798, 63.23146658559, 68.0135222404234, 70.8879606185421, 72.90438052146666, 62.192571932269686, 36.132297438959924, 8.159789529538925, 0.12695335587787052, 0.5519931931649485, 0.013030407698674789, 0.08980959053001097, 0.04226161955645488, 0.05601240750101786, 0.008085407823654673, 0.10660185478627683, 0.006961472569063547, 0.0357180948729717, 0.001977622460183357, 0.10153409889748982, 0.04534696206270207, 0.052808459262333574, 0.03129505559862141, 0.03610866564896799, 0.013621358347365694, 0.07429183610985357, 0.03672584523296645, 0.06203272477573445, 0.1023311520956697, 0.06595689908511217, 0.0573048476249941, 0.07387371298166052, 0.026492586381913676, 0.0779351893992674, 0.028987619838106538, 0.026196619803686778, 0.06924563027437657, 0.04242599521192812, 0.03278112827589916, 0.016683650225581183, 0.04620418380645495, 0.01789195665849313, 0.04031580985493718, 0.052716735555159475, 0.043620471842587, 0.017856634259524367, 0.0183863993809228, 0.015267407420211503, 0.009496974619856526, 0.03865139956976618, 0.045309293519465194, 0.02807410978411715, 0.015336861909036676, 0.05345340187270796, 0.04990479450732951, 0.02542631648060295, 0.09655689460135276, 0.12708005149878804, 0.06887524208474545, 0.016889268224458062, 0.07403819205900354, 0.04181711619058925, 0.038718834459300966, 0.018983149315200506, 0.041031868407322515, 0.060586515483596635, 0.06026513010804212, 0.05754395898792052, 0.04371866899272127, 0.049319262015483076, 0.029744342337512684, 0.02377239968477478, 0.04785908694048563, 0.0339435096529703, 0.03840953795119159, 0.02458438776703852, 0.03618312556476843, 0.03566194828900118, 0.042903233514798265, 0.025009401856110464, 0.008307829961150644, 0.04514959483076969, 0.011664095631379996, 0.022168638665349256, 0.037676548855679656, 0.013677142954791987, 0.050683515221481366, 0.06942890148850218, 0.05050893910529633, 0.041871653989918774, 0.034762449983146884, 0.0530931375349962, 0.07184175669305748, 0.034829344780695055, 0.039251334514589085, 0.054254626419635556, 0.030033237924198472, 0.0452310108249226, 0.02282151028573994, 0.08286232218867348, 0.049038368217166395, 0.06760586503772967, 0.06480143165155765, 0.07071060489021963, 0.009046675798843705, 0.010881187289112039, 0.03788870158455065, 0.052667441627671646, 0.07448314358630488, 0.018128930636110808, 0.014400054163660013, 0.03437276020826351, 0.04735678224073303, 0.05637443001051584, 0.11253476142883302, 0.07273738242445454, 0.11971533418663087, 0.04876326221311766, 0.04894243102640875, 0.059014181306044904, 0.12720375937680084, 0.1377527058244713, 0.05188697040261281, 0.4971997043298137, 1.6626659948979656, 27.074118929524577, 71.80177873180759, 93.77555539531093, 82.10652766689178, 81.31708006705009, 67.53820942294213, 59.76646438721688, 46.891041109638834, 46.06264437398603, 32.7557642998234, 35.12088291106686, 37.71331464090655, 26.217836103131695, 36.76930604442474, 30.501450684762773, 21.590788595138058, 25.774741634245842, 35.015771235189135, 43.07282947724865, 37.32569817573794, 42.187013164643325, 51.9929660520246, 73.67753459561256, 74.78454512934532, 84.96266426578646, 61.518814640660445, 58.52886638333721, 68.43852673807453, 68.93545181520524, 62.80430870671427, 65.41658370725571, 64.60921479809669, 64.62274697519118, 70.09928180325416, 79.3480267063264, 71.92630614003828, 83.02542132716026, 75.64260282824117, 59.42764612936205, 86.90559464116251, 82.26847448656636, 77.50277903772171, 64.52571145949825, 55.74790985353532, 45.88026985045403, 54.64257809423632, 44.64244434910436, 33.007090168614546, 42.21805087981686, 38.30630640829764, 31.122885519458404, 40.459683710528964, 49.98129221700853, 62.140424020828746, 77.10927901729461, 91.06829627867668, 76.38508396763956, 51.85233339186638, 15.725894993351353, 0.6075332193605362, 0.47785181672342364, 0.0329763772747209, 0.07404491065009948, 0.062334433182953834, 0.038262246056429805, 0.02565034165708048, 0.03773516224276635, 0.08554878569538556, 0.01863632215968063, 0.04285903790244653, 0.061729488023106134, 0.026158093241974715, 0.007200495353073723, 0.03875875913147484, 0.030886341945358345, 0.017073864770692684, 0.010820167428333192, 0.049976944668038245, 0.03705631258086332, 0.04954353042487657, 0.07174002787759227, 0.08709583897143604, 0.04917157175500066, 0.06743526491787165, 0.07055531886796798, 0.036212937876341805, 0.046626390183284405, 0.0699703494507459, 0.06136633936435946, 0.007384901813742135, 0.0791398549993192, 0.023273128693202333, 0.039623722193702575, 0.15803374980966892, 0.02274894643755209, 0.02788577089837242, 0.035542718194905794, 0.044621798555336656, 0.0358638852354019, 0.04577293376167936, 0.009320077257260922, 0.0424198167128188, 0.04801206703808519, 0.017062202997265324, 0.03740277584461916, 0.09954852923270195, 0.0924096929450189, 0.01811290982239429, 0.09446099295371002, 0.027694377237029617, 0.02824025701791529, 0.05848342793122415, 0.08841860468589491, 0.08837802500854577, 0.11786101070503074, 0.09393123549319084, 0.12829148931609047, 0.3028241989593352, 0.19813155785443323, 0.19238873294764952, 0.15258911696653213, 0.1719018717807147, 0.08960996333870197, 0.19471497425148565, 0.15818040968189317, 0.10490231170889833, 0.15332457669559987, 0.12736869810689844, 0.12383075851586559, 0.26679067121398065, 0.13546979445363247, 0.1350354685658409, 0.10379968902036067, 0.19061421284512167, 0.13973714934001047, 0.06684071940159605, 0.10610292470383068, 0.1813810913553161, 0.16754376611882643, 0.11360027481831851, 0.16612774452134488, 0.2142033317396718, 0.21351045117743556, 0.14926368250481545, 0.19512237980961802, 0.17304626924376335, 0.12406282186988862, 0.10249374659671899, 0.09803012764501957, 0.15311206390540447, 0.15448768202575947, 0.14921587861834035, 0.21349594147214968, 0.14059764994007928, 0.25249671160934434, 0.11862644745457558, 0.1380745700049785, 0.06704852841193638, 0.0883511659659205, 0.2110722078190696, 0.11378045869810928, 0.20877829542563808, 0.1476930950077311, 0.15668548102821075, 0.12485100376990535, 0.2539554196259668, 0.16867426674692862, 0.2726231437296637, 0.2101373966903456, 0.15803053224038693, 0.19514297225302268, 0.44720514346995666, 0.2754707231877312, 0.21130296882362137, 0.6464224777394726, 1.6265171862417653, 29.639633394056755, 83.36193715372394, 112.68177186289142, 102.78682431867047, 97.16937049742668, 89.12618960103681, 83.92202023536929, 91.72963142395021, 119.23934721177625, 97.78528459610479, 107.27437665385585, 116.04948751388059, 87.14619282753237, 71.6160309699274, 59.295576003289995, 37.22879994300104, 27.175527887959635, 25.068922888848093, 34.84341444507722, 22.133891736307454, 19.023915029341175, 29.8447851211794, 56.044060568655695, 78.17932513452347, 86.51179652060233, 64.52377380863314, 57.19495065750615, 67.97593024469191, 79.05498643075266, 63.22973289797383, 68.6753829833, 82.54678233977288, 99.70484548999418, 80.28453965340891, 84.64150844081756, 61.90175956295383, 78.49495041754939, 68.09804147289645, 86.75341452321699, 91.21310234069826, 59.9792568914352, 59.9984686605392, 40.810559334293494, 30.218220256990005, 28.585612120166903, 49.49529486317789, 41.43863670287594, 38.39179054383309, 51.44177498355989, 57.705949198815134, 73.7657408560476, 85.03207452835576, 81.74377118387531, 86.72762886170419, 92.42544420303838, 107.49277422505041, 86.68898567076653, 63.15445084725658, 20.763235169072306, 0.6316746110397001, 1.0973911660332833, 0.11024646445988648, 0.2020947605131134, 0.16546947581152763, 0.1827886400203551, 0.12249883038983231, 0.23804409519558956, 0.14175485639322188, 0.14509184346083673, 0.10393999802369265, 0.1812636653982824, 0.12721849890846398, 0.21769281626949388, 0.18449562181147838, 0.18283478915691379, 0.09631663410653991, 0.21403247881079876, 0.13554681693353962, 0.18095281756212636, 0.16113531805815237, 0.22865386439427254, 0.16594173837332957, 0.25193126211243294, 0.20082876957472295, 0.1565332900011732, 0.10117560039244353, 0.17010674391302372, 0.14460982093887945, 0.12064295174974589, 0.11273631150083196, 0.19841736993722378, 0.19888738020052835, 0.12771574359747673, 0.21082108419749046, 0.1354558210098936, 0.14053665401954807, 0.09234162603294657, 0.1016500156613127, 0.09092736643769088, 0.11952842405486493, 0.12963569783154996, 0.1335978892541701, 0.17753565173235633, 0.10445491636111852, 0.13742023898709205, 0.236683982694822, 0.143677614509098, 0.21468176897014343, 0.2584967581975845, 0.18865359466402762, 0.10716659948229791, 0.22626697957035036, 0.19664415218416723, 0.2042705268268624], [0.08594052475546637, 0.06521121974313451, 0.04524047584122708, 0.033147253186231664, 0.07189685373657173, 0.008668341362217983, 0.06703563515217074, 0.0018996558966107608, 0.03599385971263532, 0.010129478835170309, 0.028760794610265764, 0.04347038372690159, 0.09853299541939652, 0.08884803527185033, 0.06340700224222195, 0.0746185572878007, 0.07427171098008271, 0.12694417814453765, 0.06211185399743338, 0.050098829256791266, 0.011132608727371741, 0.029236853137732517, 0.013020503139423748, 0.032121356118530515, 0.022567511919224938, 0.08183236293975385, 0.057213755940357526, 0.07374452757498912, 0.035814315516261325, 0.045735506536138636, 0.044460770704092524, 0.034495207871640884, 0.04743480446538137, 0.02734211660290678, 0.02174358818710091, 0.0183854685840948, 0.02955040143382165, 0.06938763233202119, 0.017358562195553415, 0.021242070642690507, 0.051776837602618246, 0.02496729383335239, 0.042534672444866556, 0.046210435083917076, 0.023600987511717027, 0.018251991169827602, 0.08113665551307701, 0.04863041107572856, 0.038832514246384946, 0.04319266153259143, 0.03717428629076289, 0.04664183834627752, 0.11784389630080232, 0.04026894825660894, 0.019835914342453884, 0.044853141786710876, 0.02165364563435076, 0.054155157563546975, 0.0941829183589547, 0.05055359437040264, 0.11704555607490963, 0.04752557439308974, 0.30515932688309305, 0.5593254513317539, 7.723025275814918, 23.185659608533307, 48.767004859062936, 62.2400051547635, 79.07091909839262, 83.01384249041158, 83.22970621047482, 90.8881025929605, 74.15606375663512, 69.76460164593112, 66.95155620574951, 76.14152831415977, 66.34983324235486, 81.62237382704213, 79.66371474727508, 68.9561305507537, 73.03192030998969, 55.212412188130045, 58.62618823205271, 33.1716335973432, 19.038633723412794, 30.82638179102252, 19.10590825542327, 66.58521467639555, 88.36922707096224, 21.730197475802516, 19.40129214717496, 22.752757418540217, 21.23123472736728, 18.34436243580234, 30.800462768923854, 21.641322451253092, 17.093979466346003, 18.043002813093125, 19.91788987190493, 26.836811611729285, 111.08042501634168, 25.666129242989328, 22.885880701003536, 33.15921145100748, 48.406876364061915, 54.49143740438647, 62.773094484882975, 55.150803519833474, 54.314679714941214, 60.3663791379621, 54.4324920254369, 61.99208390328192, 67.26132931247835, 60.76181680925431, 65.79567686203988, 61.2024127283404, 42.26581358140515, 17.931670258122107, 3.3872475835584828, 0.09220166943005978, 0.3783088646108105, 0.06064420573473458, 0.0756276406407837, 0.02694822483575873, 0.018044036602781668, 0.06291395954547391, 0.035921115833785267, 0.04111183266485891, 0.01400759689615018, 0.0700256533379997, 0.04072748252280778, 0.03534389156547766, 0.08418124214175247, 0.009081989579323319, 0.08716357646570091, 0.02889416094178394, 0.01979796234668503, 0.023896417828396927, 0.03802014695059869, 0.0073048623838281685, 0.023669717089843847, 0.0463506291740604, 0.05461686726419195, 0.06259930808277381, 0.08058943124788423, 0.03929762154697411, 0.027261667794758276, 0.017317595643802516, 0.028021324410914417, 0.05246834686747002, 0.06582559927576973, 0.07423787287646726, 0.02196726862401251, 0.026333096452177535, 0.07713651975556728, 0.09305901374788055, 0.09497126879831476, 0.04601146672822295, 0.0591973414374215, 0.06780180734612289, 0.08945099243353452, 0.01387298758697486, 0.025134117139743704, 0.03850254868607848, 0.04765399371183688, 0.02848092545454781, 0.08956690153647816, 0.03243920025265506, 0.034501137392174815, 0.07054312274821344, 0.07105932811335211, 0.019124812378938642, 0.01569473605242468, 0.016787673474379608, 0.029514196118520155, 0.02739748177719453, 0.0335487675282263, 0.03749750644689606, 0.02530856685142123, 0.05436496989380929, 0.16253074721222924, 0.02886459952400577, 0.056497689727092945, 0.019775803253475218, 0.10754435743776061, 0.040280102496786464, 0.02680839655259925, 0.034545287039251096, 0.009034598422717423, 0.07855959702283144, 0.008635955952828931, 0.05020862114765952, 0.05320438882336021, 0.02576405400290124, 0.03132145690371192, 0.035007510018805345, 0.07052626881387926, 0.030175406605966633, 0.03421850840470964, 0.04945287541035683, 0.04677838585790127, 0.04784863367075882, 0.04052521998903925, 0.07183824034948504, 0.03610144910072127, 0.09662106978676974, 0.0594790626106964, 0.016172560412556897, 0.056424788800218416, 0.0365266585422139, 0.05847343048381229, 0.03778809891833413, 0.05849982604324337, 0.0885429867212811, 0.023547945499059655, 0.059353447173752134, 0.0875807956101433, 0.01677290904485891, 0.07077639652115685, 0.03370224558297665, 0.02184640293219878, 0.06335962736498445, 0.01865126661986353, 0.011873120806300113, 0.028258735058648933, 0.11377626819716347, 0.06809230788701004, 0.005543047370719574, 0.04428851966475768, 0.024555194071464004, 0.05438858838451486, 0.08439822888542568, 0.0376808887437707, 0.0517615273354515, 0.18507908969636888, 0.04195393566342612, 0.24719008184488744, 0.07755443604002077, 0.4052645875321281, 0.3780210300558998, 14.013109687835941, 40.102904919655096, 65.12003291037776, 81.23384737199353, 92.31123262836088, 89.51167229683169, 88.93889642530873, 82.86796954370315, 65.67536600174444, 62.9624233707305, 56.052956504206506, 50.13587674786968, 46.349867774594216, 40.85690998261975, 31.78099843763536, 29.49497638210174, 38.86325943854548, 21.423950579858598, 18.88412371758492, 21.51735986432722, 26.480974189696777, 45.528903930417954, 37.33555901435114, 60.795066741205034, 62.410381147938395, 37.72309310974614, 41.46304561245827, 38.57535354552731, 40.82648415719309, 44.9143861955212, 66.5898666074199, 48.17640573747697, 38.84499688302317, 32.51250282410653, 36.06088676760274, 35.590696565566525, 94.94923053249236, 41.50597595399426, 25.490730654808786, 28.24506409706608, 17.520025353277884, 16.121196362280077, 18.896304638155048, 39.806193305600075, 39.087466039965236, 41.53835119739656, 49.25644997627505, 57.52407673866519, 67.02596356791835, 71.44038723361108, 81.22956414376536, 81.73514981423655, 64.21635804637786, 29.650463058102517, 8.478743433952332, 0.2791411117199929, 0.34487234428524977, 0.03454801431226154, 0.1449811590775367, 0.03858740824545103, 0.024619445865673405, 0.04652158552480321, 0.05791597894483036, 0.043318008838762204, 0.03267003786599925, 0.06043151291387697, 0.08884824211558989, 0.03486611700106052, 0.07637371834848197, 0.019812699963128375, 0.050610572159771, 0.06150941394509808, 0.0574251540726231, 0.058263840319048014, 0.0526382958125924, 0.016291844132806987, 0.04557739364944639, 0.015568475186404203, 0.02823362269649102, 0.004542021826285148, 0.0026450341899744087, 0.05178994536700268, 0.02695037562760615, 0.0738615398445437, 0.04525276006109292, 0.013726242487469028, 0.03662913046296566, 0.07557289599771462, 0.035724905394618554, 0.03899037049362256, 0.1320934304667096, 0.04049687090540125, 0.08806408217717564, 0.06325050197061031, 0.0319747920072968, 0.0253958644856128, 0.052475119084720655, 0.030212129030617017, 0.0385786863344331, 0.04738730701407598, 0.025746263526079637, 0.023160061776457776, 0.09902526819778067, 0.0480118525334664, 0.09918945616171246, 0.008596760021793026, 0.023883298572693622, 0.039791369044612494, 0.06544411047211578, 0.04331280710175634, 0.036161123519583095, 0.13005554465757263, 0.1532902712783506, 0.15921789191422925, 0.12199206322792078, 0.20430356053815735, 0.32149094247048904, 0.07521651189533934, 0.08952906445389794, 0.11930618194803116, 0.17986851203585827, 0.16381903130921627, 0.0684609647179323, 0.10918823656656089, 0.160361124923633, 0.3010258841658792, 0.23619065271510234, 0.1291672810311279, 0.16142784107115962, 0.1655032602889884, 0.11915065077764374, 0.09835504085546541, 0.17541697429072473, 0.09026506810539192, 0.14943799815110623, 0.10307465574794239, 0.2077166507801702, 0.20885395426904002, 0.1347610711931221, 0.21190733558708624, 0.19796856498766333, 0.16279915377738016, 0.13944949864620163, 0.16220932736271815, 0.18066769495846766, 0.2137769118792588, 0.1207426963974872, 0.11598560448375442, 0.15854373454086243, 0.15729217669896542, 0.16413294349706944, 0.14668417253321217, 0.12501217334741546, 0.08187530982878902, 0.11750291822658432, 0.10558203088059541, 0.135002879185542, 0.0757838995946992, 0.27100167267264863, 0.13941029026623697, 0.17880617791125852, 0.22817398691850327, 0.24000485127250995, 0.20552030734477506, 0.14363416200203283, 0.06802855404995142, 0.1223162409939593, 0.19916343232316358, 0.17911737814785975, 0.12563628219668904, 0.3018041375663973, 0.30922342332140096, 0.4247811983429617, 0.08671183739939044, 0.5515939694258475, 0.47626380838694116, 14.024780700283667, 43.66418169390771, 76.44985014392485, 97.4924639732607, 109.68017808852657, 108.72177831588253, 101.58091514341294, 109.02757413925664, 86.43763234538417, 81.01626565379482, 82.18099778698337, 95.35740021736392, 88.02230911870157, 104.09480141055201, 111.0403540826613, 96.66455361150928, 105.4209626105524, 81.92910317451724, 89.81407134763657, 53.01093486047561, 32.65452596449083, 48.11698182936638, 29.656897706370202, 83.3404347204393, 105.1936298801053, 36.87972860951578, 28.532432625370642, 35.26803455045147, 33.12093696286602, 28.425669631650372, 47.0867673812374, 32.74481696467246, 25.46586871147156, 26.59301865485407, 29.905126863910308, 37.33552371301959, 126.09001774941723, 37.098079112268266, 40.91130148979926, 48.039138470926595, 65.12328847762078, 77.30450322551113, 87.845794616207, 74.52919883112754, 76.15742960283833, 82.14236244078606, 75.80383577654439, 79.36516746397942, 85.91787122911023, 83.37823067941974, 89.70848898733817, 92.72286968846475, 69.49586437594506, 30.963080313897905, 8.0592930124652, 0.22494820517397698, 0.6562679333071555, 0.18377949814161948, 0.3151818100483187, 0.24203175138081276, 0.15208538351280076, 0.14127697074605575, 0.11920937141703984, 0.14523430517123592, 0.10066300330142822, 0.2293626949070923, 0.21310399556832932, 0.12463554920208071, 0.2380215568888572, 0.16323698834786493, 0.1866874300063618, 0.14885716560867526, 0.11653158768650987, 0.11552872496747202, 0.12513775814084277, 0.13644401314518145, 0.12723386663222505, 0.19263346739594014, 0.1428438350558281, 0.16658208062571866, 0.16075958257480977, 0.1620043988429731, 0.14708244632328712, 0.1672526067423244, 0.09040921520922454, 0.14133870211099425, 0.1516588104348029, 0.18191514656909052, 0.09551300021309046, 0.22538911941791737, 0.1916165009982163, 0.16829545159013043, 0.20372467385905407, 0.20339225298695027, 0.16726137078817815, 0.1498536774588208, 0.2028567728496367, 0.07457504349370157, 0.16339497099961006, 0.19955327914607143, 0.13419575959203706, 0.10434399449056196, 0.2011552762480513, 0.14990610851635858, 0.19440697626240794, 0.19204368694655358, 0.13722867104074649, 0.11954850321936032, 0.1422755969988723, 0.11715021134624559, 0.08925911805201923, 0.20173108325369898], [0.05988286372514502, 0.025239530838124698, 0.07683871073588248, 0.037561654819235686, 0.005216109294128875, 0.005387204977112913, 0.01768498076877046, 0.027004574433029182, 0.03296182160415957, 0.06459235859614226, 0.010063702525991586, 0.01011211353714668, 0.03797327769139121, 0.050604160003844774, 0.05548991638446047, 0.03805618372655684, 0.08441361193094524, 0.038767917712609616, 0.065929381206872, 0.021206943596142436, 0.08461356854006168, 0.03921956867880879, 0.00767391853808095, 0.04001448832211956, 0.024636521965505618, 0.08549115290084193, 0.041182010149162625, 0.023838072572083726, 0.04673238610848785, 0.020278383744880557, 0.06714617397876517, 0.04481217140452035, 0.03319052566263465, 0.061233411618177934, 0.04146313760429621, 0.04503422581981267, 0.06206467447261657, 0.01876142431771563, 0.05215878605902676, 0.09305088555500393, 0.04255323092483225, 0.026969280762357578, 0.0586520477137979, 0.02098442186721631, 0.0247798761683366, 0.03715496555331253, 0.02890742383897305, 0.008038122961748271, 0.062300985784179745, 0.07136079903331495, 0.02574570428189491, 0.05728663388459433, 0.04736016834935835, 0.04048120057691009, 0.06125367847421478, 0.0703963786063175, 0.02364159017170389, 0.08674273372537668, 0.07222588083917095, 0.06859921294474794, 0.08173151512540157, 0.08077693892823112, 0.020988261882936763, 0.10965110689041116, 0.24301064320869986, 0.13677502441550457, 0.09226192990618368, 1.6812343727196417, 12.320606958481575, 16.92646288102673, 34.802763000611336, 55.48102394227059, 77.35768272030738, 87.0881966621645, 88.91403644315659, 93.74902448346539, 83.95742354854461, 80.44177962887673, 75.62096703437068, 75.92619803643997, 67.26277274470176, 71.20315444084906, 83.29254258063533, 78.8995978140062, 70.14478129725303, 58.794532437478345, 64.13307828287925, 50.75687816066127, 73.06225592090239, 82.02367936411213, 69.397232455592, 79.10265107308665, 73.37897946757656, 67.64235619575747, 61.013903617858894, 76.44962264645484, 83.64517934860723, 85.20284668091806, 86.97953916365101, 87.70715452009632, 48.35937253890499, 76.3069111301053, 92.04175795278242, 83.38441233481132, 82.21316122239637, 86.8141798819265, 80.96257625087615, 72.91152707992062, 74.30553743916174, 70.13757982561665, 73.94577764695691, 61.43520932043753, 58.71918762883833, 42.29460377846995, 15.569924885226836, 3.8480093882929896, 0.25534194683836353, 0.44261474462766803, 0.10630766936247388, 0.07781516640417038, 0.07034275245161788, 0.024096464452844475, 0.015638809718732393, 0.1137550475616609, 0.02347284398462263, 0.02477162923183172, 0.026260523027890635, 0.07002929225564003, 0.04294564414228644, 0.026318644203485984, 0.039912537341156316, 0.037957446484435955, 0.05520039643611639, 0.013528971016527185, 0.039681623119019696, 0.025374509784723484, 0.05125433116430237, 0.023885495329816497, 0.06416038842871785, 0.040476741945190776, 0.04665153318895929, 0.04440751227159654, 0.0022419402704408936, 0.02254547156964339, 0.03327907010492298, 0.029640964517790466, 0.03603875629543778, 0.06181410626478254, 0.02541888351251762, 0.04212927020665619, 0.06415432101235756, 0.020590892076612483, 0.041102578322733604, 0.09333078343901904, 0.07255282418261613, 0.019297151518384778, 0.047755473548726696, 0.028317781285412853, 0.012506426541104674, 0.102480968250142, 0.03209561173383507, 0.07071604411448203, 0.05246306852167172, 0.0836028074545245, 0.007212599063472402, 0.034512368241144765, 0.03508105062909665, 0.024260026139898166, 0.024386869232741096, 0.025262065314417406, 0.07225904478541306, 0.033410396727342764, 0.08847948569323748, 0.002863076937970736, 0.1087675087394253, 0.03492853401469127, 0.05101296367243894, 0.036334098512006384, 0.07011166202925867, 0.021187875667707096, 0.04326217635084064, 0.0035289026263560504, 0.058358153403406186, 0.07974580756478733, 0.006294638996252851, 0.07560322541863689, 0.059715324126544504, 0.05241784635150144, 0.06595170500898553, 0.06226956085752576, 0.09216560201058466, 0.03015399253326318, 0.029408393630517587, 0.038286592330663435, 0.046959029390446605, 0.025183644724048437, 0.06095886868875354, 0.02798369225685395, 0.04832188831642271, 0.04317823226653761, 0.02923002920954699, 0.05841915315437702, 0.02661985082311496, 0.05852605689377074, 0.07064315084848674, 0.02384029422706414, 0.06182472807385268, 0.011416139783367757, 0.024259141308345625, 0.045943664116484505, 0.11205154380971387, 0.02619604523774357, 0.03513763005274438, 0.023094122673595147, 0.008620116127384527, 0.042740355561217, 0.0643421236365553, 0.0244687142361316, 0.05042089262015877, 0.004292981963860052, 0.03320849425489864, 0.11093824951639099, 0.03511231467728654, 0.0048004807397392735, 0.06065553617513469, 0.051816884848860004, 0.01616861314452704, 0.06830410055455662, 0.040489413039458376, 0.015599144558842867, 0.021645304852075154, 0.08321225583072632, 0.0434889805112635, 0.045140325166885896, 0.18525392628244816, 0.03587205173267472, 0.13414455427517816, 0.05276935430423868, 0.12285595759749414, 0.036852602140917894, 0.3802150752275221, 0.07067288272082806, 0.151109847150022, 3.6307240541904204, 19.099279449832057, 31.89944224972879, 55.61930710269559, 79.25746702378797, 97.13099402766075, 104.13224435621693, 97.15962732991865, 102.71973609924318, 87.45075702667238, 81.05399101011216, 72.7689253899359, 69.42802306144469, 63.84336809958182, 59.17623789079728, 56.405844303869436, 40.11155766825522, 34.85369105492869, 39.07816610028667, 31.993349675209295, 60.58619268478886, 84.938047470585, 34.52918160346247, 26.729032724134385, 34.59211211050711, 25.899253352995842, 22.524306812594016, 35.39943787359422, 24.05630615449721, 30.19696297184114, 23.081108831590225, 30.108082063736457, 43.380731613405295, 76.49963286615188, 47.46877093468943, 44.74518691339801, 54.89313125610352, 64.66234330208071, 72.3122359860328, 75.76534948041363, 76.18868304837135, 80.54827982379545, 84.77208414385396, 88.6591608293595, 82.31496241784866, 82.69351820791923, 64.93603060322424, 33.36625376055318, 10.007626452753621, 0.5444929472381069, 0.28729087763255645, 0.24112641931541506, 0.09933652206053657, 0.04641432172408508, 0.0985655464952992, 0.09868609809106398, 0.06700272401494366, 0.05072187324385009, 0.05043333388804909, 0.08413786624347971, 0.056150954502123984, 0.03869715417104383, 0.05544176392797982, 0.03490102762776998, 0.05864063300372613, 0.03903632427776053, 0.03954601406510319, 0.03608617330751112, 0.018942286185319387, 0.08097384650740894, 0.013221765928451094, 0.025238276369148688, 0.11192395186592495, 0.044408538829415076, 0.01794740993289217, 0.11217111481293557, 0.008246302567121964, 0.03841341435608845, 0.03991607283692687, 0.024828323568668098, 0.0485273837412317, 0.049297957110308835, 0.07067983113830129, 0.061909549328829014, 0.03335128155266566, 0.045960246089605555, 0.024069287483730627, 0.057501521547355, 0.011097431885108594, 0.07992222229199064, 0.02708122152985344, 0.021442278145602154, 0.02683763046778979, 0.05910939837415373, 0.02839160151779652, 0.039261963984538475, 0.03839573687723568, 0.00759952326094912, 0.04194774184255831, 0.033489977940917015, 0.03834628590172337, 0.026125948192671906, 0.024046228237209782, 0.029356533308483423, 0.04378641414786539, 0.042030758960472966, 0.016848688547108925, 0.056868434147608865, 0.016307738542015997, 0.13512971270228588, 0.11283229465686506, 0.1893807193564792, 0.15182476040096055, 0.1318166122561501, 0.13652725625903378, 0.2402914447649833, 0.13145665818404767, 0.11822993566672649, 0.17329975241614928, 0.14623424909528226, 0.11990901653564746, 0.13473021317153208, 0.11417805833081085, 0.13269036617730895, 0.1423197083415524, 0.23841410034125854, 0.17622429306708998, 0.14606859024253585, 0.08492670697911132, 0.21314845931145454, 0.19329955020258505, 0.15809678352407872, 0.19920317696467524, 0.09918911908302577, 0.20392983220517638, 0.12372269415326657, 0.15744018488593642, 0.17165042640220735, 0.15912963858535215, 0.18155845603154552, 0.10935395670634125, 0.12811837642784082, 0.10568824131041767, 0.26162916914589945, 0.10605972500578051, 0.16119635994395903, 0.09485425652876016, 0.14378296692044507, 0.19350303847703243, 0.16854651392467562, 0.0847323734553591, 0.26252255023967835, 0.18642502957053725, 0.17892677547229877, 0.17652770985038052, 0.12772917311878937, 0.13302502402615163, 0.1694606866447195, 0.19277707823822576, 0.12331810013781633, 0.164923423660859, 0.17614085077037736, 0.08484774629675573, 0.15991227400879707, 0.3064011247648347, 0.2074329377782922, 0.29276331946734463, 0.2717416829639866, 0.1601578817973214, 0.2734501509656829, 0.16096624245326366, 0.11834717776265838, 0.11932744088792994, 0.3498839689118247, 0.2959145455350799, 0.142431894257184, 3.624575984093451, 19.424567491777484, 32.81703956665532, 60.71685860233923, 81.2859913610643, 105.3788128206807, 124.58929538726808, 117.17624325906078, 118.56187543561383, 104.06322633066486, 100.95618355658748, 86.33421513342088, 90.86314847392421, 78.3867871376776, 89.52266277805452, 105.58731032956032, 99.84157931420111, 91.09890645550144, 75.95772604788505, 83.86670697119929, 74.1095366016511, 96.73605841975059, 108.48149391912646, 94.22670641253072, 99.52632273397138, 92.82537691054806, 89.27712240526753, 81.68166437456685, 99.2794801342872, 108.41487638411984, 111.62800358187769, 114.74286756207867, 110.55226218315863, 67.10312443394815, 97.2134893171249, 121.83254380379955, 112.79439095527896, 114.87585160040088, 116.06489458391744, 109.67428668852776, 98.09710518006356, 98.97137011251142, 96.4140239838631, 99.60171853342365, 88.49650013831355, 88.15844674264231, 68.22673443825015, 33.60983687062418, 8.737582602808553, 0.5160333937214268, 0.5472655113666289, 0.42167268933788427, 0.290455648134793, 0.2679748899273334, 0.14285520380062444, 0.2617676471990924, 0.19724727788519478, 0.21480952179239643, 0.15589711526709218, 0.1641060538109272, 0.10444734741242663, 0.12767209190755122, 0.12928467634464466, 0.16235522114701811, 0.1333252232401602, 0.10932430144279234, 0.11768137074766621, 0.16256883710382447, 0.13847221560295553, 0.15583302435134688, 0.1384711737233785, 0.17770117268927638, 0.21276550727986523, 0.14776742085814476, 0.10184942068712366, 0.20726349445119982, 0.10167794722703197, 0.11410615331823788, 0.23731834946140168, 0.12687601164103518, 0.10896335911726761, 0.08801820117139048, 0.15097959688113582, 0.1471910775909501, 0.2864639623270881, 0.13919790005010946, 0.16262975641556326, 0.2570124628442911, 0.07502668296858188, 0.1166696520522237, 0.2042845768793937, 0.14484611309824452, 0.16442597212810672, 0.17112044677619012, 0.18809743015275848, 0.19109386049451368, 0.13677428897109725, 0.12141408053256812, 0.1351557596917114, 0.0801970103695508, 0.11749828339464242, 0.13816907461131775, 0.11829329879894374, 0.12687337629857565, 0.12256872059116442, 0.19100071952467967, 0.10742117816041555, 0.179386458870384, 0.12485347057302153], [0.027497312609827327, 0.06059254842600035, 0.09484830402558851, 0.021198053145781163, 0.029938329206479174, 0.017800112292470954, 0.04357089829300681, 0.02980548572996932, 0.03794975113123655, 0.04566259794838486, 0.07119562281596084, 0.024970706755055055, 0.1187446088560166, 0.06772212654111848, 0.03807059384041256, 0.027735889626426563, 0.027721142433884165, 0.10281082272769944, 0.03602675552810392, 0.07830229873258261, 0.11534443485640711, 0.01766375438760846, 0.03642065878657084, 0.014699796597743708, 0.048444998645854574, 0.021615747264736605, 0.005336067171752333, 0.07256779354065657, 0.03163228558766986, 0.07369791112479664, 0.01922297697033613, 0.04135693483535321, 0.029836690406345075, 0.04326050244872609, 0.037317701780627814, 0.01861796860823468, 0.020562428079785842, 0.014049837069075196, 0.007065331108958251, 0.007927281530423751, 0.06671058404589854, 0.030301910704903068, 0.05835431147246592, 0.0296574181711842, 0.041409235657943834, 0.04751057822197195, 0.04870813452608643, 0.035410943411050305, 0.0652569628530933, 0.029661175832452796, 0.06365392387153641, 0.028106095870175672, 0.031488190194772135, 0.014937745422245035, 0.037323029922141183, 0.09123177147440373, 0.027716643582548828, 0.05228164357944362, 0.08599747573175738, 0.023108396806844303, 0.07903932128101587, 0.0376709372616343, 0.15459396906437414, 0.12002058958093967, 0.02830315858215815, 0.04974486982269634, 0.05738059456850733, 0.05735210375860334, 0.35155207940167, 0.43033126020623796, 0.3596472692105078, 0.3238153451633069, 1.0971650168780358, 3.3801681956937237, 12.814695181385165, 13.020662761503651, 31.15828883263373, 59.788500262844956, 70.54341177786551, 93.10687757307484, 88.7466924421249, 85.01952294380435, 79.14112167973673, 80.72108376410701, 77.70621668907904, 84.06058188407653, 84.60002545387515, 87.86307657918623, 80.3390056856217, 81.52174934264153, 96.82444510921356, 85.84165173192179, 89.26937180180704, 97.5945318898847, 99.37298159445487, 88.9517225757722, 87.34983444213869, 83.96612336558681, 82.7842269405242, 76.80808021176246, 71.17324244591498, 75.32424757557531, 71.0234235948132, 68.91083502000379, 51.80211528655022, 45.72865455381332, 45.25260433073967, 36.45339050600606, 23.617704760643747, 14.363728396354185, 11.80123023448452, 5.086342346283698, 0.30471370885929755, 0.1092239439247116, 0.35289803459759683, 0.24066903418110264, 0.0911109977131409, 0.08729105349630119, 0.05534544752369966, 0.03955622984757347, 0.11374745563033128, 0.0495248340490845, 0.09401202712568546, 0.028669099631388823, 0.03493369744730092, 0.035059741893482786, 0.06412142136644933, 0.02687608233592924, 0.049137408064017375, 0.05393015370974618, 0.010604629548446787, 0.03248547579372122, 0.03405901655975369, 0.059252338889505596, 0.04062071667924043, 0.12517633832870953, 0.07221324038842032, 0.016932054235029127, 0.009366233097088915, 0.05195293057289335, 0.04009229604214911, 0.024153313922485518, 0.021311562478301987, 0.015000716892010985, 0.1358536657907309, 0.02087205783614228, 0.0202323054714549, 0.016000628257320536, 0.04139295245911326, 0.03580221898793694, 0.016010894793115796, 0.02801346626403111, 0.04030910275516011, 0.01816291238121208, 0.07485681829313118, 0.03948591063700376, 0.052614715626283046, 0.04325507471578256, 0.06852183040351638, 0.09319718536590377, 0.008398518492017061, 0.01596903862176283, 0.02846624912513841, 0.029815148013914307, 0.03441970607626342, 0.025858489661327293, 0.036292492276838714, 0.1086659944285789, 0.058503127882197026, 0.07209252791419145, 0.11100269283258146, 0.01848773749154662, 0.03641248462841876, 0.08609292262624349, 0.017673627345732624, 0.09675869748236672, 0.043088630622913765, 0.03776005243942623, 0.0007652869434452677, 0.007311229532088845, 0.023057676040597504, 0.020331222744237994, 0.05516714822020262, 0.03671001785645082, 0.05882236821156356, 0.021103035260532654, 0.02257820076098846, 0.05382898030802608, 0.029170615260579416, 0.10342959194414078, 0.05756859637556538, 0.061842849883701534, 0.06049937298220973, 0.052975301720923, 0.05092795472592116, 0.003178371914527229, 0.030500013381242756, 0.015187893239330622, 0.03434715371939444, 0.09104418718526441, 0.043498261666466156, 0.038745540284341386, 0.02782950748599345, 0.0676465672891467, 0.017552729095182112, 0.03966251305574852, 0.014048479178229408, 0.034541422125673106, 0.037656917852619966, 0.02168219581606888, 0.043648786452268405, 0.045368757264147845, 0.012461332690661714, 0.01428861422614465, 0.019815427236138813, 0.009107404546211324, 0.004217354242780036, 0.030349080653620825, 0.060166772079443744, 0.02514628261598128, 0.023798080867216475, 0.05491058537436109, 0.013747358743491915, 0.03240352736846094, 0.03398758269125416, 0.02131857792846859, 0.0476524577055487, 0.035352398971876794, 0.02248115274274061, 0.020765117707572157, 0.03753042907544202, 0.026418873401839408, 0.05238396611305014, 0.014330921431763038, 0.20297099655914694, 0.03364494220624047, 0.1346598250130492, 0.057795266470601486, 0.2235492673372069, 0.12107166221305249, 0.09315562509601155, 0.015982573480165053, 0.00835189725377507, 0.1715957583679307, 0.4993954961819034, 0.37010409358528357, 0.2532057719485414, 0.7937052713767175, 4.406716208304129, 13.53068071026956, 34.01301730063654, 43.002505302429206, 64.1949026815353, 84.93785135207638, 97.08221543219783, 109.134976479315, 108.03340235064107, 101.44095713092436, 98.42612143485778, 93.96800256544545, 92.85959566793134, 91.95471271391838, 88.00620386677404, 82.89157436740014, 83.81920706841254, 88.13739145955732, 91.76178701462285, 90.88003035514586, 84.52939141181209, 88.8589192974952, 92.6788136266893, 90.66989329553421, 90.9106562214513, 86.09003974545388, 88.30614751385104, 88.68005137289725, 83.82124670090215, 91.78920438212734, 92.28002625126993, 91.01899993035101, 77.11531162261963, 73.74961991463938, 73.44460856529975, 62.36172022358064, 45.53452860924506, 31.68976410742729, 26.79558357884807, 12.711619215626872, 2.544541306072666, 0.590347844746805, 0.23325319582175827, 0.5081386738006146, 0.047080814387769475, 0.2892147389150435, 0.05129613658233036, 0.017956432533420382, 0.1029905929200111, 0.030678176704133232, 0.13329382895702316, 0.012026456177174565, 0.015655488410453885, 0.052001136655528704, 0.07673102941724562, 0.032121970904089754, 0.07059675656379232, 0.09705750241635308, 0.0045341794799652795, 0.014691749801709047, 0.01820645298838856, 0.05648755821429434, 0.18642293048962472, 0.04236932385772948, 0.04761440994878931, 0.014400927503893693, 0.0786967880483116, 0.02577634779886613, 0.010913475022290745, 0.05628249179872294, 0.001224796954287036, 0.013876958795252347, 0.02770495499604412, 0.02562906739542321, 0.0935877446505812, 0.05697398957225585, 0.0620328052149665, 0.12388384840901821, 0.049161578138028426, 0.02590359691830893, 0.024600533070042733, 0.06726536193802472, 0.019528661373882525, 0.013703463820650453, 0.006457681658737843, 0.05492856545794395, 0.03037621740311865, 0.11189739159759014, 0.04734920563116189, 0.04452866141594226, 0.04212587260671201, 0.056773799306322495, 0.021401037717418327, 0.04819514289979012, 0.0669314471944686, 0.03929554544869931, 0.05739359508058237, 0.024560001273188862, 0.08978689900569378, 0.030556004832408605, 0.015968590460327125, 0.05300562348096602, 0.040808975125753114, 0.01713244176860298, 0.15356194137805892, 0.17538659124364778, 0.1288964536281363, 0.05570218019608048, 0.13521919177184183, 0.16494622243748558, 0.17290613644065397, 0.1602767020343773, 0.15617889772740104, 0.12571952531054137, 0.17240586570434033, 0.13572416628801054, 0.16490146758094912, 0.2409784877372365, 0.11018087967268883, 0.21256136016980295, 0.17000272449466491, 0.25719532803181683, 0.1373769856628872, 0.1846187781061857, 0.11562047931816309, 0.09756917254098, 0.165370068242473, 0.14091337009543373, 0.17230829674630396, 0.09635994871777874, 0.13793924823403358, 0.13885483055585815, 0.09326067873306813, 0.23346376274862599, 0.11248226908426132, 0.14555091398858255, 0.18774089283279835, 0.12787539632089678, 0.09067517795389698, 0.11824560982565727, 0.11748811740788723, 0.16747943005494534, 0.10349052657763805, 0.20341304461321524, 0.10504459721907493, 0.18704513177996684, 0.2109335765482918, 0.09068902882356798, 0.1460371193506064, 0.15032820764087862, 0.11742018839164127, 0.127743644519679, 0.12216779613687147, 0.12851013080968013, 0.1929558065509604, 0.14041369690770103, 0.1427992334168765, 0.12589362645221333, 0.13296041217061783, 0.30644546593389205, 0.17220037027953133, 0.1668471470475197, 0.31633749964737123, 0.07422602915715787, 0.289969090372324, 0.1976530133716522, 0.32536431365916807, 0.31079111500613155, 0.16654861790518607, 0.11906607467080317, 0.28520760877478507, 0.1732333938801481, 0.4408666239150109, 0.59362614947942, 0.5582303746092705, 0.4464050718853551, 1.8684269151379986, 8.097826377038034, 26.177333708732363, 35.52725615039949, 58.22241160177416, 82.64790888755553, 104.0052144758163, 123.05662924243559, 126.4047722662649, 118.12510382744574, 114.72098073651715, 114.93292993114842, 116.39361273857855, 122.10126538430492, 112.2691071418024, 111.7413051666752, 103.62871400771603, 102.84052156632947, 122.65045996635192, 110.69191425077378, 116.81421633689635, 128.22038250584757, 129.11247068835843, 119.9251736364057, 115.10337260461624, 111.9859512390629, 110.50894352697559, 109.90372965412756, 116.71783585702221, 112.86400518109723, 102.04817141256025, 100.2839756011963, 82.24290063304286, 74.49924761249174, 71.1833700056999, 60.144851515370036, 41.243698827682, 28.18136480546767, 19.781142319402388, 8.29844972779674, 1.135642487675913, 0.3908198465022349, 0.9769418583281579, 0.626052996564296, 0.35332070062718085, 0.4244819950432547, 0.18554536145060294, 0.17374962988880374, 0.3785449116220398, 0.09868670330052415, 0.35810547129761794, 0.0861915028203399, 0.12927411965304805, 0.14901891741300785, 0.39553612891224127, 0.13402437040161702, 0.15204346318158413, 0.1405886713896067, 0.15545952584474318, 0.08633642367297605, 0.204894321580087, 0.23455260351540583, 0.2939224717838149, 0.24538525530407507, 0.1421563630743373, 0.1347084869179995, 0.14604375367203068, 0.17119219857117823, 0.12332268134360352, 0.17394187199252267, 0.14450207833320866, 0.16538503760051343, 0.2528645257435499, 0.12410396079142248, 0.11261448053823364, 0.20693210013691457, 0.13818058125194044, 0.234354370604119, 0.11161363263043667, 0.1089342401152657, 0.17994577966390118, 0.1397782116527519, 0.17029334760961995, 0.20213729371466946, 0.1567237547809078, 0.16561993547985632, 0.10851181157293821, 0.2740908149750002, 0.1662760591434856, 0.11250705968949104, 0.1975778601462803, 0.20905100740492347, 0.1313800800351366, 0.19313173098189218, 0.19191041829124575, 0.1932912151659689, 0.18577606116812076, 0.13079059069916127, 0.2811987319540593, 0.1872646006485147, 0.1353264134377241, 0.16795644236187782, 0.14331075032391857, 0.18718334936326553], [0.013672157637624732, 0.041490498434511885, 0.03501125618875508, 0.011559884691040122, 0.02561112561623656, 0.07968874167530768, 0.048921796448168256, 0.05465776103759005, 0.045279163281403245, 0.035256090228475874, 0.03382057935420064, 0.08750653104676355, 0.045934643431176106, 0.0496828320225881, 0.026945350090822866, 0.01889148881028016, 0.034695122345921495, 0.005102829309180379, 0.026151261652909943, 0.04051753995759834, 0.04479273575388136, 0.028258047494736892, 0.08664085935320585, 0.08306083089161305, 0.008521120330589193, 0.03280857720622613, 0.03301518728896495, 0.0003349572814899617, 0.0491392198619583, 0.06951579118087407, 0.05368309801504497, 0.04353331401944161, 0.0208711844959086, 0.04129894197948518, 0.015587474166926359, 0.058496681252314206, 0.009534099240667157, 0.014462632055754864, 0.03508383918914103, 0.05969138004847112, 0.07722821281922441, 0.06922555110988117, 0.054164197401053486, 0.015144072052451874, 0.018055529836865685, 0.02400131824786865, 0.016211893281809265, 0.045051926281303174, 0.048803355424634876, 0.011354997348521027, 0.035308900499536146, 0.024385714355195244, 0.03174458450127033, 0.06156758683162832, 0.06819730023703269, 0.023598147240737756, 0.02175197876509159, 0.04168629518619949, 0.09111531078815462, 0.02574315895476649, 0.1341888954442355, 0.04946663817991653, 0.04103480252407251, 0.06653734858358099, 0.08025031476732224, 0.03011225414792857, 0.04908328778260658, 0.06086727138608695, 0.032790244722198096, 0.06504271870418903, 0.22495304684965844, 0.097559611763685, 0.1443045349010537, 0.016982960777597565, 0.20979788184406298, 0.2820414593142848, 0.12651611119508743, 0.33183898236001697, 1.6647703464954131, 5.785647015417776, 7.153239721252072, 6.521353240936033, 11.947776848270047, 15.519362591928052, 17.813450021128503, 23.39896986561437, 26.459197190500078, 40.00757171261696, 41.89421607602028, 41.26219672541465, 43.666319385651626, 45.71972723930113, 47.480887136151715, 37.783395628775324, 40.141716772510165, 29.57138023068828, 33.13468487031999, 40.02668542246665, 38.32400414251512, 27.453496456146244, 17.539941187827818, 14.204154610633852, 10.28281209930297, 4.631645506428135, 1.628083805403402, 0.3056844648334288, 0.12914370084481855, 0.019374195065709855, 0.22032727006702657, 0.23539531555387283, 0.2719074643908009, 0.1308716887668256, 0.00774096894723874, 0.15082371331030323, 0.10168032209959724, 0.09942302870894633, 0.04889824307493625, 0.1252743592786212, 0.0669540161447179, 0.05238578940230993, 0.020990805294845375, 0.047182757707853476, 0.0674750785072965, 0.05967801564463204, 0.01356231116299187, 0.041223907497741526, 0.027973765672575084, 0.07040082957715758, 0.11017105076462032, 0.03656432708545077, 0.022069623716355815, 0.018527474472179048, 0.07467934636459236, 0.07316334263211297, 0.037870510826788606, 0.016882549633362123, 0.06579939140788009, 0.05604379029283601, 0.025316706535616712, 0.037595374179222894, 0.006894638579744365, 0.06019541610693259, 0.11515555587867576, 0.07788564649320419, 0.03109238895347282, 0.029682017254432844, 0.01414103887885088, 0.05056441919277272, 0.029491299665683222, 0.10979540721182862, 0.013485301132013482, 0.02160770525675147, 0.01965892887974699, 0.029591860197063898, 0.032504551383035804, 0.024960462244287617, 0.013936709822906602, 0.056901935172537645, 0.015352282301342536, 0.06947937136095378, 0.06979063288458894, 0.04896033450119919, 0.039245382011417425, 0.05069467712253813, 0.03257709224858592, 0.06564047412886735, 0.011697932777385558, 0.03905990446406988, 0.009418754169957773, 0.0431729692424978, 0.00843524857754669, 0.0359804684957189, 0.04774712702079166, 0.05215668314767461, 0.08563448029059557, 0.07067865902377714, 0.07172608507737037, 0.051638447649536595, 0.09911257923851091, 0.011834935153714352, 0.013539755619281243, 0.05441157868312252, 0.05350408624977835, 0.021751967273772727, 0.02280435949233511, 0.015013236683913538, 0.021487946561988325, 0.050137359648942954, 0.06043614391537924, 0.049088275014993646, 0.023101710774485144, 0.04045131548698391, 0.017890305739016305, 0.06786531603504574, 0.02063646856244774, 0.08472956191267698, 0.10868688564627402, 0.08069544249484617, 0.03556633285517174, 0.027070140068028724, 0.06682876842997729, 0.0007847624545965735, 0.06562950374979167, 0.05378375047697656, 0.029595359303658048, 0.06239338747916683, 0.04734835910400556, 0.05967609659438172, 0.037734074397913875, 0.0681701730636339, 0.041199453971198494, 0.05446173445952516, 0.013800993516680696, 0.028920003002689734, 0.0834696843559223, 0.06179180927574635, 0.0996570838915725, 0.038235586196664846, 0.05935952225099168, 0.03306789030771583, 0.016407075247937636, 0.05090468097478152, 0.022350695630114888, 0.07926415276503371, 0.07699359073153428, 0.01194098662029231, 0.06365100890698452, 0.05565420777026204, 0.030442625734834906, 0.05345509875746024, 0.021503103611570214, 0.018076451698077783, 0.01972680810027786, 0.05615352855754956, 0.05637932531235199, 0.06952620997664428, 0.07079384800407194, 0.05211752456342501, 0.024214759919672244, 0.041122998396355304, 0.09990315899373063, 0.0994438203352113, 0.11401881929486991, 0.03127359173020288, 0.1057130012721304, 0.08145501867177025, 0.07472181827911446, 0.09107327554374935, 0.12356663438221141, 0.09433664922272006, 0.11112250898393894, 0.03076689160098472, 0.24755449454870918, 1.6736901839894636, 5.064129473701601, 13.884418683667338, 16.29586931197874, 17.97493596230784, 26.569370685085175, 33.57371184133714, 34.56301596856887, 44.29275720350204, 50.66063104137298, 66.56206484763854, 70.47074594805318, 65.9316615135439, 74.27159324769052, 72.86400364291283, 72.07311261084773, 67.02378273010254, 68.78310695771249, 57.8696414732164, 59.49292613613991, 64.99800012957665, 64.163574710969, 56.79400205612183, 38.538969639808904, 34.4569040882972, 27.320463388196885, 16.098488780759997, 5.706703922440929, 1.4842211959823486, 1.3278937844499465, 0.10845478398785477, 0.19949694104011984, 0.0685511332666201, 0.31438535439871973, 0.23778310436154568, 0.08035565951779004, 0.0830432491737508, 0.25590186518046165, 0.10116863665321182, 0.03743950593014879, 0.25504115007577405, 0.058063542800805265, 0.029908390490398295, 0.04267453711720244, 0.04380353238253344, 0.13509844099321675, 0.05843417613857216, 0.05676966243153138, 0.03894117998800451, 0.0371630133069571, 0.046295022682076505, 0.1579866354023257, 0.04037478330334829, 0.011345283353641149, 0.023893223241752675, 0.04737085527590206, 0.08950762931377658, 0.0074768103396279685, 0.048165403366569555, 0.10128861368303338, 0.06655101559215015, 0.10367010524796863, 0.047176448973797025, 0.037292593248909524, 0.008330516697418305, 0.03745775797494477, 0.03430137230503944, 0.04237495460397294, 0.02098450613688798, 0.01855159666569483, 0.01162398326766467, 0.02666756852469858, 0.053575600557509935, 0.011164909867089123, 0.038719202181504625, 0.03553025777481737, 0.026227613805883357, 0.018868881555634643, 0.010002846416506556, 0.05622813786049524, 0.04261772786717742, 0.025129277379282063, 0.02813466137365228, 0.03502167115408567, 0.04078375934172542, 0.014557376064570441, 0.010224197946128347, 0.07811977062374353, 0.023152630723592256, 0.036871666238913615, 0.025633893749346177, 0.0030982980106566706, 0.02931503432562515, 0.017734257459279992, 0.0405501063552595, 0.0340991250930294, 0.06013805527360209, 0.040499364521594784, 0.15270225283118988, 0.13864817067740426, 0.11969553847466746, 0.12125327101638242, 0.14627728791486833, 0.13280676557652413, 0.155833974300373, 0.16110646718692395, 0.06283845391965683, 0.13637823683600273, 0.12977661204434213, 0.0875964391255571, 0.15002946399392622, 0.1936873898751313, 0.14280166957647572, 0.1325428482866095, 0.12996436487282478, 0.0986298519156633, 0.09791699944124108, 0.11922600318587596, 0.21922627914576762, 0.23764341588943239, 0.1538870231278481, 0.23866048953946561, 0.2641708037305263, 0.14382300267536796, 0.10522817486837026, 0.13901710329997924, 0.1631035971184892, 0.19984894311956822, 0.12243477777848322, 0.14499451965093613, 0.17704268947484034, 0.14708201731404952, 0.16831137089719697, 0.10646712290303362, 0.1718680106944615, 0.08590216673309765, 0.08375326712285319, 0.1622301189889831, 0.20114979105851344, 0.1744101968623938, 0.15546099673355782, 0.09922922378586185, 0.09384631464678435, 0.1388719449600866, 0.10713010305358518, 0.13841262928420497, 0.24108908018998562, 0.13987668459453892, 0.08442923246372132, 0.24108596987301306, 0.13915544345734582, 0.09475143220756324, 0.14580816631355595, 0.10121037312332662, 0.11934527541480719, 0.07291368989934845, 0.20098967868233883, 0.2254781847999942, 0.2550686985975312, 0.28291948800606115, 0.17309385862561966, 0.1453515319454093, 0.12279070988898316, 0.19083898304210556, 0.23139226100137159, 0.2166514116669855, 0.12322537285546142, 0.10485280710723131, 0.1826584510385029, 0.4134175097269397, 0.1962275842144605, 0.17554409892087983, 0.13518801199332361, 0.21793679995161874, 0.5075971415686993, 0.16514891398049172, 0.42847165837883955, 1.8776449753392128, 6.189972287224186, 8.228599179175593, 10.447877203264545, 19.09334686494643, 24.597999203589655, 26.912834990409117, 35.340955334324995, 42.57813622874599, 58.459950339409616, 64.93778390269127, 65.07191327310377, 69.25645859010758, 71.78654424605831, 68.71397910579559, 56.84976247049148, 60.8324900750191, 52.1943130800801, 52.41162415473692, 60.69925892737604, 61.19857665031188, 56.69456604988345, 37.326478727402225, 31.20142705978886, 22.607210028556086, 10.76526657227547, 3.1740586748046264, 0.793811236658404, 0.5760298453031049, 0.07723360607821135, 0.4665606306685556, 0.515097111703888, 0.6235951413550685, 0.39697597584416794, 0.12307494383064971, 0.3793757492976804, 0.7475064310335344, 0.27668101953402646, 0.14611037267792612, 0.421124630036854, 0.27923488088192483, 0.12872546280343689, 0.19868324841222457, 0.18866041284655372, 0.2439009139855062, 0.11062492721623952, 0.15985831077541077, 0.07529364928843514, 0.11734023179498412, 0.18065407391517393, 0.266434685477326, 0.20065748763661231, 0.0993136007098421, 0.16850706039657518, 0.15123810559030504, 0.10903344850146002, 0.12030475457469303, 0.10329644586290083, 0.19811766101948677, 0.16755617674319975, 0.193852742292708, 0.07813979616208423, 0.123052803889638, 0.16467813762926287, 0.2340044063185492, 0.12483885361542627, 0.14968061819672585, 0.08029264878601798, 0.10005921110390656, 0.16857332700202543, 0.1142336226879589, 0.19315589339502398, 0.11717835741658365, 0.1028599059810081, 0.08113340730027807, 0.09422514512534104, 0.13456763399224128, 0.14629369751820642, 0.16114219752771242, 0.1802168675367871, 0.17177957350448256, 0.13946033112945097, 0.11094486085517753, 0.1731103141942332, 0.18981772655200577, 0.14024305848344681, 0.15863112985126435, 0.1304041912719127, 0.11547466214265555, 0.14364298733492054, 0.15346228866086853, 0.1894970727904189, 0.142946153758995, 0.16710944023103486, 0.20905503702740516, 0.16388889852791064, 0.27980383906152945, 0.24488558211634237], [0.05145550585321842, 0.01617189200084296, 0.02254462887292668, 0.08343702602771022, 0.02281817588804951, 0.007603664444984809, 0.012206027186625909, 0.018482225488931425, 0.03653272595857421, 0.06530933262359712, 0.04034431981703928, 0.07513226520630621, 0.0880637527593682, 0.07246899118106212, 0.039757684158581885, 0.01264468051357976, 0.07868349642282532, 0.07154673623341708, 0.056307983374403375, 0.04649100329486593, 0.026096248879067363, 0.05182011773990047, 0.0291034982975332, 0.04795953255867766, 0.013421220749977135, 0.04215254012735621, 0.010579869586734042, 0.06660163102130737, 0.04664900126836954, 0.034789351160607995, 0.03714882918903905, 0.030098793983098962, 0.03059313711409848, 0.05462063641677942, 0.03934346807880267, 0.0606524603321187, 0.0955085339204919, 0.08555056301936989, 0.029899053793821125, 0.014130904493222554, 0.08557051194891815, 0.021824839472350095, 0.09445620490418327, 0.05545283006804605, 0.027516263709854216, 0.029289071605871284, 0.03114283201284707, 0.09646769132344954, 0.021702939561838587, 0.03581246924436381, 0.036696710909206065, 0.08343056790650853, 0.008784504231786536, 0.05098531938969128, 0.07096023464034643, 0.046353456038500995, 0.06378349998304922, 0.01885373791259143, 0.02155228454108921, 0.03287099038941726, 0.020257900469005108, 0.006291914596072128, 0.03880657450926881, 0.08258014902352326, 0.04830926701787019, 0.02843442966320342, 0.1170103619956682, 0.043024378828704364, 0.128540605787308, 0.0359100075588832, 0.16324452665303985, 0.009373109693819237, 0.08185624190035366, 0.029991399947433706, 0.0861839491934065, 0.10992246289407054, 0.1347136963158846, 0.16833606957187577, 0.11661954990197575, 0.06190905903255748, 0.18881788988026882, 0.3467866447904418, 0.3286271434157126, 0.3541768804913567, 0.2699635928917316, 0.2132172080417795, 0.26530954746469376, 0.11906922329217197, 0.1311233639717102, 0.09650427968271318, 0.10106536034013956, 0.30943167666273735, 0.1330483897078422, 0.09133576024924556, 0.11169585684734969, 0.018930310315843073, 0.13096928836837893, 0.26572960879533525, 0.2876019399733313, 0.12602833535281882, 0.111684603015742, 0.09712501774511992, 0.22613165779940544, 0.3973233201090367, 0.16525429703535574, 0.07672681593366208, 0.03907360977703526, 0.08764503208259422, 0.09758931299250934, 0.10041688223399463, 0.025427643727931767, 0.028438702518601092, 0.034551500012317014, 0.18224422729784445, 0.06287309641559279, 0.05379352958933, 0.06603229745861984, 0.019809424937252077, 0.05071906170116798, 0.031206708423973575, 0.08836791264794527, 0.04055498633533716, 0.07616214784643344, 0.08792822414468374, 0.029514561925503998, 0.006918903457136044, 0.09759614649679392, 0.007604414732345651, 0.04079042813710628, 0.0473322406140787, 0.02662227932183493, 0.07502183363202118, 0.007873793750355441, 0.07758093502132163, 0.06003859407839276, 0.03620547617995932, 0.03607899506366061, 0.14696644528979255, 0.05136853572161448, 0.0702576017788341, 0.013262356139509188, 0.01284889369872549, 0.013414537590447695, 0.04600187913785058, 0.061090919264261766, 0.005722693552548487, 0.029592689487241933, 0.029022490245199976, 0.06044357496824476, 0.0647615644359781, 0.07039438677771438, 0.013521790857456866, 0.012283808093578106, 0.012553244089377264, 0.1112633006226632, 0.008727329174777674, 0.03413333857972776, 0.10997282551421274, 0.034330437680886644, 0.04009953557303356, 0.025324928574264053, 0.011446096694036838, 0.019695902198192575, 0.07165325309840903, 0.02089614364048166, 0.09059463913041739, 0.08641320866562667, 0.069911950568278, 0.04122834697726273, 0.005079195975521279, 0.07297375119261204, 0.06475962623352967, 0.02743645266990268, 0.017814734995725657, 0.051531459640471206, 0.028180913932080713, 0.0333082465635192, 0.046146811481805584, 0.05880018613571602, 0.04460529319100803, 0.0065551893297402615, 0.007557983100864917, 0.031908264931952285, 0.043995904721199505, 0.044533989557455626, 0.05830563041531752, 0.013144400624197819, 0.041456790565843546, 0.009552058256832103, 0.04291320414913278, 0.012281855526981095, 0.023677439256120595, 0.038501376571554335, 0.0664595140504741, 0.024923785784912687, 0.0644970266148448, 0.03955231130784077, 0.061230274488128004, 0.0407545828831292, 0.05760232339643183, 0.031082289999410994, 0.03634014677616858, 0.09164126845256937, 0.05096267383064955, 0.053117621705056205, 0.03143845193628823, 0.10500040160672319, 0.021757812524634986, 0.018570358158960458, 0.0693121420279626, 0.023292485819829088, 0.06997873045263753, 0.10441959204692995, 0.04837986585053225, 0.02841156768432308, 0.035049089440895666, 0.045081524088257746, 0.07151363357420891, 0.05322798816186767, 0.006552093376916263, 0.020650936132897774, 0.030722435518738725, 0.01919442870383782, 0.03762464256837003, 0.03577229559361454, 0.052706010324219545, 0.12959900221997692, 0.005670553608421958, 0.020948578528459036, 0.05889903063014631, 0.035684505747931625, 0.020633051810305447, 0.07249109281767761, 0.022972655602760857, 0.05062979713623082, 0.03243891680012307, 0.07074969835699567, 0.030912356376047098, 0.013303498891482671, 0.0666955993660996, 0.013455138335214748, 0.08101713047513077, 0.037324883854917945, 0.026966112988790678, 0.15890057829599227, 0.07916894335780414, 0.0317377069469301, 0.056970875424843644, 0.15594487318829184, 0.04051884613750924, 0.07034992303458915, 0.006224610899094373, 0.04426541445296138, 0.10812446219666351, 0.14974864680440197, 0.14499038277614504, 0.12476678772438919, 0.3244674392044544, 0.14309725694118008, 0.04715920433462147, 0.13458701601672557, 0.20050581754936328, 0.47359181628111874, 0.39630708915572016, 0.40819738661089255, 0.20351801398060015, 0.4721991603653278, 0.7959663952069899, 0.7764520520164121, 0.5662836134433746, 0.3625778313125334, 0.22122140192697126, 0.5012256802330094, 0.6541538370713111, 0.9648750542152313, 0.501051502482545, 0.2795366275935404, 0.3910353010700595, 0.5277571130183436, 0.3325566228839659, 0.2915464960519345, 0.2709125919688133, 0.11492114829560442, 0.0931605357196062, 0.04187709321418116, 0.03912703291843495, 0.0321872147821611, 0.12307094485168496, 0.02995109606173731, 0.08314840240223755, 0.011488603082515541, 0.05952626894859057, 0.010703885815136377, 0.03900217590853572, 0.0706694353251688, 0.030661569833154642, 0.0929694657304114, 0.020771370900254098, 0.02665271407984678, 0.09143650847216768, 0.048999244106873396, 0.13582337467420486, 0.11277817820589389, 0.05285580732649373, 0.02878486892328628, 0.06272219624670763, 0.06438055826771645, 0.026571382355365544, 0.04457255059312429, 0.013359256685831615, 0.03657684879257314, 0.01672586358542885, 0.024931745438445962, 0.055414652076339534, 0.06663963664323092, 0.04033490459644987, 0.05317978207923232, 0.01575447941919969, 0.02921290905965913, 0.014627248071314347, 0.043288411031807625, 0.031100599500801296, 0.05266300980902968, 0.007434160309663464, 0.027821442495370587, 0.01237260247205174, 0.012369689422719663, 0.04040788596255645, 0.035338965620124535, 0.0677426960018854, 0.04203601815407315, 0.05062601266188487, 0.016536088284826087, 0.061041824519634254, 0.08984209564063819, 0.036262488443284266, 0.014098156149679375, 0.05085037300182928, 0.01858439288973328, 0.023845605131599213, 0.0752457304887714, 0.08126245481112311, 0.09913677995603892, 0.06412163970150775, 0.022545465823983955, 0.026950986582725763, 0.03808845901080678, 0.025357991013856187, 0.04997667270682512, 0.023508447920903567, 0.08623709271271383, 0.07057447872695423, 0.11890501234560244, 0.18733235346453805, 0.15660911738391847, 0.28588982539311536, 0.1451404440787531, 0.1569954555241331, 0.09148765250199264, 0.07899122628112955, 0.09408233867537591, 0.1662401449415953, 0.10079120811555656, 0.0929424228266843, 0.1435107605591897, 0.12023068153329435, 0.10458926520039959, 0.07009024221089578, 0.16052951104938984, 0.14355358487415698, 0.15787156899609875, 0.15287318236885533, 0.16589588035018216, 0.18886992257208596, 0.19058499425168962, 0.20730136983817626, 0.11344216193162626, 0.09676743854558277, 0.1243709730765512, 0.13192271543366293, 0.19630693560165746, 0.08050531479379824, 0.1654080662035173, 0.11675487167292065, 0.07011039798418361, 0.1352186861538118, 0.15189732424914837, 0.11838908277211652, 0.2655537456514374, 0.17011130979705244, 0.14240154185362403, 0.11150232005503871, 0.10315116494894029, 0.1456863276900784, 0.16504910804571646, 0.15428103746906405, 0.21805175910553626, 0.11097743491371793, 0.11864536216542607, 0.16943883781711902, 0.1515448778387039, 0.18323874731938686, 0.1619774631915554, 0.14731576606150598, 0.09872896837130671, 0.1344242989416084, 0.14893544447277823, 0.09439093421303457, 0.10939460533160357, 0.16437389347101414, 0.19735448422931856, 0.11969056656403888, 0.23860713917641874, 0.08885339022644105, 0.22903577454628485, 0.17766732692478165, 0.13354934992328768, 0.13793345660932604, 0.27742173462625475, 0.16895807167935759, 0.20881439348863018, 0.2268348499051025, 0.4027783564261852, 0.30256026634766214, 0.21182588511897674, 0.12884016148746014, 0.1656016413002245, 0.16502437872752068, 0.17170967564227121, 0.2782034813877075, 0.14011161311739875, 0.1822178585514907, 0.18886717997731703, 0.38353398262012395, 0.47459891546637784, 0.5725905395323231, 0.610627540417256, 0.4774122048289546, 0.4391694940145939, 0.14943190009122895, 0.2430877116538825, 0.12301494382442006, 0.20389405589911247, 0.33067495772434824, 0.268837750078209, 0.2109971771677656, 0.24546929514936863, 0.1260253246272764, 0.18450600996373162, 0.2435069609313242, 0.38805693508155886, 0.3941374362236069, 0.3181683884993676, 0.41707138140355393, 1.3122712292017475, 0.7341311487459368, 0.3112125246515197, 0.31987713229271675, 0.13049347115860832, 0.22869291955665236, 0.22338302625763803, 0.2793388849785251, 0.22568211740543767, 0.15297496481047523, 0.12346399392211631, 0.4854661791074661, 0.22884319536387923, 0.24485020417599912, 0.21049263166083446, 0.1923941568501534, 0.1378804739684828, 0.1143965925720911, 0.27155368498736815, 0.12551534755696214, 0.17267339892925757, 0.17104543144664458, 0.13491644914592468, 0.271213143583267, 0.28129602512044294, 0.09118535420707158, 0.10243717866439013, 0.18087671438772834, 0.16199718229472637, 0.17717565169497845, 0.16560076795999082, 0.12367604705955713, 0.149304622243489, 0.1103954609002798, 0.09146554320449791, 0.24116617927868522, 0.22964954886945987, 0.2264229091064584, 0.14222805358229146, 0.13620159228242215, 0.05631155334413052, 0.11702805862671907, 0.13904371719446876, 0.13933368147380892, 0.12711711483256471, 0.16050531799274106, 0.14194316080501004, 0.1173593073842987, 0.25111386161898414, 0.10501007729720686, 0.11831776764724525, 0.1341625879849157, 0.17662085082021453, 0.2339808874192738, 0.15275022525700832, 0.2805044417900424, 0.2262512900896611, 0.0869440463101191, 0.09571379185804436, 0.12205382523637627, 0.09011759617996794, 0.2535422684084023, 0.15956252422784606, 0.18052491149114025, 0.19592179255860467, 0.12657916789213497, 0.16925163657194184, 0.10244102442577001, 0.1069964666760737, 0.25725425551495246, 0.13192676037790316, 0.14261114350970716, 0.23985932521041364, 0.16882958341269724], [0.04106472974883453, 0.03262109633895659, 0.052927168416640455, 0.03743202508156819, 0.06626671270257042, 0.03596222411180216, 0.03036512253475526, 0.025551862969634034, 0.02055256469776073, 0.08494570595963348, 0.03902392131426642, 0.04025088773379403, 0.03480304881269413, 0.06104039576565547, 0.05252487266496305, 0.03827932598670164, 0.040788183499488144, 0.02342681742213186, 0.03002580878655276, 0.053805235412813006, 0.021656370992141388, 0.008339203176869741, 0.03296465229903979, 0.09153883483621383, 0.03760086702963999, 0.03253262850546068, 0.013419967238611032, 0.02620806898771515, 0.019535096512446483, 0.0019892594554544157, 0.05233879756903457, 0.017927516544718417, 0.026046223337611845, 0.017551855754948432, 0.03443207839624055, 0.055404712085521994, 0.05657897165585911, 0.12139736449406033, 0.02216116739286771, 0.0333966760926189, 0.022516367889399973, 0.00529700051805365, 0.04251586115588585, 0.06785887323560254, 0.03160764628480519, 0.04725361317997018, 0.040613300948133396, 0.03759905906213868, 0.06920383251722782, 0.022899339073187402, 0.039544252062877344, 0.07836409904543432, 0.01973043935703895, 0.07438579679376657, 0.03658872698583911, 0.0021615333577257494, 0.10928560634173694, 0.05626542335976997, 0.04011007311243204, 0.03690430924536721, 0.0660624813228365, 0.05284056217680055, 0.023188742193123026, 0.09000188625988462, 0.0459499268852655, 0.04919725868310179, 0.04312747511111441, 0.05103416898618302, 0.030252268207409692, 0.11543667184249048, 0.068108587255401, 0.04111307755773587, 0.0901418045583752, 0.05592341872773344, 0.10476102211302328, 0.17264539075474586, 0.027246407323306607, 0.08987342097586201, 0.041912026823528355, 0.10664690075622452, 0.25660248323073315, 0.07407516346222932, 0.13493587713568442, 0.11303015984594823, 0.06691384249396863, 0.05193066805781377, 0.055331761362932386, 0.05883602372881386, 0.19748971406971255, 0.09961242862646619, 0.17148611586420767, 0.12960500834930327, 0.038925467524677515, 0.01281536681832926, 0.10567236030774732, 0.08237882877790159, 0.10428904300375332, 0.16914179488535852, 0.1476738049137977, 0.0695250302012409, 0.045567331084560965, 0.12066594970923279, 0.021766848531701875, 0.18067437524516738, 0.06429687082286804, 0.011944494345375608, 0.02216945071854899, 0.06684730009686563, 0.055698338265140215, 0.042630812648924134, 0.04108380916858873, 0.05274070644631021, 0.06090354947974125, 0.043832253018814715, 0.11525006814589424, 0.07233785225018378, 0.05429440553510382, 0.03269623424257002, 0.02927835020537098, 0.016754431004125266, 0.05860769888386131, 0.04766137496898732, 0.032000919435954386, 0.025838197907432917, 0.07571570244767974, 0.044282004086961674, 0.03148035886096618, 0.039189806162950494, 0.012349802737815246, 0.004706595707008796, 0.05719229781759843, 0.02488465592896025, 0.013557297117527456, 0.025861739789346055, 0.07560468098569302, 0.013589301398174177, 0.027437134488155285, 0.04590194296812819, 0.060383157444096384, 0.0078654998909652, 0.11948906245731539, 0.06489589795350068, 0.04427446578178675, 0.04138137304013775, 0.043042190372943885, 0.024931318344428174, 0.04500911345765476, 0.08011955121952681, 0.06444039739548199, 0.06478787955617712, 0.07362747700103829, 0.04522446460360962, 0.013222626819756004, 0.01792762954268725, 0.027245859570440747, 0.004199336333605912, 0.016300792039762584, 0.023467207492719737, 0.02501021773974982, 0.04074031066509985, 0.05404827297635136, 0.06102048897094304, 0.0009402906324530412, 0.03590675551564463, 0.02093769241905501, 0.034997052918638916, 0.055012570829280925, 0.009962296425064486, 0.0267387495841831, 0.03962749134629004, 0.034736640480977875, 0.04101907856942665, 0.002686196572950951, 0.02576450982521619, 0.003482166235522938, 0.039115403703744375, 0.0779399851096734, 0.03401411231607199, 0.04568838829835577, 0.035675316523279876, 0.035059052414350936, 0.012898219227340194, 0.04264216224152235, 0.07685646865396731, 0.0032584472548126456, 0.05999730576971366, 0.028272718078486865, 0.04081437604561929, 0.03236783533206871, 0.09989498483557856, 0.05451841730504267, 0.06883001225369592, 0.009691293779460174, 0.017597878486999584, 0.03380564830055641, 0.07510611862545052, 0.03104803437787679, 0.04428869969541988, 0.025573334498931805, 0.03290277154695603, 0.037571177292134494, 0.017724386416375637, 0.0272267188636526, 0.010589069345094746, 0.013761205782723284, 0.029484506381014665, 0.06125604185546118, 0.0973267363564622, 0.022756488573166634, 0.02478940630211465, 0.012302324438707964, 0.04583827723118086, 0.051171225946276426, 0.06683375566236435, 0.03999055956580466, 0.0457752856516069, 0.034944932126710494, 0.005359374918043614, 0.06190042522165084, 0.0564355599964338, 0.03966808634539766, 0.05291947306344106, 0.047428089704725056, 0.03286968037906674, 0.04115395217893585, 0.056635049291916435, 0.09546016312895284, 0.012867515380944938, 0.0653186176092394, 0.0982496807832391, 0.06344274790476888, 0.018734752966631806, 0.03680531919423131, 0.02878112658377617, 0.04869564729292066, 0.02556228368062406, 0.034598890211313, 0.07143937667170841, 0.03791764438632996, 0.07458568445496983, 0.020275551134780533, 0.07854297291487455, 0.03216610522940755, 0.042319175742206075, 0.07937849904861181, 0.1203869175045721, 0.08019050628307366, 0.03168443319267564, 0.045300667369437796, 0.09884895306200751, 0.033181056815890536, 0.13044030465666326, 0.0258042621276071, 0.06652307636555164, 0.11659532620181, 0.06856418740484985, 0.24484078129453046, 0.11605027762632217, 0.032321674704191186, 0.08492244753025233, 0.026539698874037114, 0.05467918468639255, 0.05217374775618796, 0.11156985836644327, 0.29894574094683896, 0.12683276597770954, 0.14949038324336852, 0.36645579902875813, 0.2603798942460168, 0.1288196609746064, 0.07082253799683626, 0.09153210858423864, 0.17533063618165834, 0.31900302597111274, 0.23054199533597117, 0.0834758973289882, 0.057380395385647015, 0.1326495490127033, 0.26262860745191574, 0.12482665749567172, 0.12132282413902784, 0.013770992555955966, 0.08270598662596557, 0.011061307009039147, 0.09939272227066179, 0.039589152476119424, 0.09507669781845424, 0.06635625305916033, 0.0730843130018442, 0.0606837435325067, 0.052146551634876, 0.05732569670785339, 0.02549664718249152, 0.08855714402612179, 0.014246044635412194, 0.05855794913405853, 0.05175476660951973, 0.07432343723673014, 0.09606511211924015, 0.02245737145835113, 0.06255150802673833, 0.022543439521424236, 0.0739515092103712, 0.0876204559819833, 0.014908238588231466, 0.08581814987044181, 0.015281761992692709, 0.025187482824549082, 0.09730344728356409, 0.014664885013424342, 0.012712316501194672, 0.023354148236854423, 0.023808216210454706, 0.00726100001972349, 0.035990351029942115, 0.029597395182316823, 0.02987500054821853, 0.029088013745363683, 0.006884355285775758, 0.028926363447681073, 0.05425171911596291, 0.032057016224209825, 0.0709724537427387, 0.1176334749306402, 0.030796579423270402, 0.09943545465507816, 0.04198631053910621, 0.010204824540133198, 0.03357735792956045, 0.04693236570024202, 0.05453598753158605, 0.021036423915516467, 0.07113468818246357, 0.013835531633136975, 0.02847658173601714, 0.038829970834476334, 0.01975169063605849, 0.03767756775261895, 0.016349187729159192, 0.07141405746581093, 0.05202880009047447, 0.012726967932746537, 0.03462155109211322, 0.03829491587596075, 0.01906840532507387, 0.02436426006287577, 0.03205032061575161, 0.03137091170966385, 0.032259234707922704, 0.054431627204100934, 0.041363101843143665, 0.0430341043149031, 0.219006028867537, 0.10070967337777538, 0.13084853758975384, 0.1400486406900229, 0.09923187445007986, 0.12257227523913308, 0.12289043155408676, 0.1582912319610196, 0.0878562348624391, 0.1985139429809586, 0.11066101761835237, 0.13255717413079354, 0.1341433285344993, 0.15341741123026417, 0.24198066863802173, 0.22649864455865276, 0.10626502890860844, 0.1087395541910683, 0.13784535649803378, 0.2100149451965286, 0.16736687641711007, 0.0956605717299446, 0.08202619084547605, 0.29316269642403053, 0.17192543664526555, 0.16204141621147433, 0.17120145291330355, 0.12874156597160524, 0.072079167340792, 0.0787844131850908, 0.1137934209057881, 0.15665586406905807, 0.15039124135528842, 0.10769261077286736, 0.13520812946221522, 0.15880566000217394, 0.16285342344593617, 0.2442147802080839, 0.08497186786224765, 0.12166988495136462, 0.1012487234848161, 0.11894731572078121, 0.10723590745680756, 0.104601078276192, 0.16231218232743203, 0.17690051887785235, 0.11715932013166529, 0.1519803375366234, 0.1982550052625518, 0.14719359035934174, 0.15910357627416813, 0.131176836908825, 0.20501969952977475, 0.3430610979276319, 0.2039631263863656, 0.06713552535661767, 0.0932279744395806, 0.17764841987481042, 0.1545326820304317, 0.10535245731232629, 0.21730044135643592, 0.15648911737145918, 0.25858326484599425, 0.17211306689968034, 0.15345833564717926, 0.16368562475808207, 0.1852012960420501, 0.11950046184562868, 0.17220133555031594, 0.2995123395756368, 0.21330156964400124, 0.17056222914928393, 0.1329289259569299, 0.15515805492478033, 0.20188463791724176, 0.1940287280106737, 0.12296317160249719, 0.22771327696259946, 0.20150041417969813, 0.16997018107964149, 0.2921046983570822, 0.22686492651700976, 0.2439610672093207, 0.2754434504576268, 0.20856602778357847, 0.20883798899669803, 0.34928697191419145, 0.19283672584401024, 0.2889588349048169, 0.22077198410707138, 0.1993637796371214, 0.41822909347472653, 0.2574081779006989, 0.21606506329149971, 0.19755008179814587, 0.16840913903809365, 0.2243579191065604, 0.3473242852957018, 0.617036019121447, 0.31754080927179706, 0.2082251952660661, 0.22482719392545764, 0.5512329887959265, 0.18729054038563084, 0.18634344120660137, 0.09067055844371358, 0.10191272253230696, 0.2640175248586363, 0.29172836532515867, 0.27107806696045783, 0.3678329493249617, 0.24038620984121678, 0.12646154275224095, 0.1667655893271008, 0.35829539981580555, 0.2103971924272276, 0.09201134254615154, 0.21302442967651353, 0.1592324169412736, 0.35623600225775476, 0.11782033909713069, 0.1323755653274636, 0.19015400850724792, 0.10753455151232982, 0.23755548431748347, 0.129808128901547, 0.1847011019145289, 0.18788232798537902, 0.07369486975573725, 0.19714013282810489, 0.1769480776161917, 0.13559132664194032, 0.16671082936227324, 0.12619254629938834, 0.12253583243657505, 0.2141640467509147, 0.07170353144887956, 0.10871191373876027, 0.2030754756302603, 0.19235896277091197, 0.1809508563770402, 0.12297974208429938, 0.16141003718779934, 0.15857823914097202, 0.15260880542618616, 0.08686336959081312, 0.15468597622408023, 0.2298495744264895, 0.2795049421969922, 0.22406657586895654, 0.10703459487206514, 0.12716311841241776, 0.13756783348658394, 0.1321263416039367, 0.10490423458958827, 0.10366431362326108, 0.21275971565515767, 0.15954036896507587, 0.14264564810981675, 0.14714053110970607, 0.12752329465001822, 0.14987151198569806, 0.09950690001489655, 0.2537814563801212, 0.1523304397180196, 0.10704163522008928, 0.1411477317132296, 0.14623648607202117, 0.12241686664281354, 0.22535266895448008, 0.12939379790857916, 0.15764857612309918, 0.11872541069263413, 0.10673394366618126, 0.09343280336789547, 0.0913574252157442], [0.07360707607961471, 0.04626616798040848, 0.08514044550998558, 0.02021671175175617, 0.012203315235373956, 0.018804095415098053, 0.011813012590151162, 0.11419038468551253, 0.06790116128902282, 0.052497875726511406, 0.11796001224748551, 0.06593116619173559, 0.05378025328560222, 0.04967037160249968, 0.07045587299451714, 0.007015607214622921, 0.02389661701125724, 0.07598870554037633, 0.035297681141885064, 0.013382608003373589, 0.03588454662671974, 0.004947012292236211, 0.00959325750779, 0.01370519900979895, 0.039971748276823954, 0.01388690836216894, 0.04270207031720108, 0.05789663139430266, 0.02800150380109347, 0.017004298241508585, 0.028651682622430306, 0.029286675665888096, 0.11154024140729059, 0.058547380951143084, 0.030541179115853967, 0.052486166072588776, 0.04763088466960096, 0.05791643476714531, 0.027895015664398674, 0.0581411513379745, 0.02557168549467479, 0.035446332842712445, 0.03332937526847086, 0.016642438525694515, 0.05372877217709057, 0.034699600129838915, 0.035413008018006245, 0.08331580027457207, 0.09889882538587817, 0.02750850898484069, 0.02360170380392623, 0.0373590245632635, 0.061858738547251116, 0.038874871247718414, 0.0551199495431877, 0.06146536388945195, 0.035194063919686505, 0.05849020014847479, 0.04295457289704392, 0.07036585766341417, 0.04524368958006944, 0.04670939964031981, 0.01810719097603954, 0.08303464600636114, 0.016924094581495852, 0.020299129405870073, 0.12390478559198881, 0.0486761465248081, 0.042380213797573126, 0.0326613312767398, 0.043715746367290136, 0.14498791597302885, 0.062129366767382434, 0.04260393828454037, 0.03391446342932121, 0.05635839962070027, 0.11703371235560026, 0.0878058722422969, 0.04896222673837216, 0.046419466004496625, 0.1301849369079836, 0.09225938649427506, 0.028528302247005127, 0.1716553906519567, 0.08684103812782035, 0.10497855277912271, 0.07918654805830411, 0.12362651947525241, 0.13278143870974743, 0.0810113158677855, 0.03940490833032997, 0.1241586747909746, 0.12955225553483735, 0.10922259560996488, 0.04256202944464261, 0.006749056018663631, 0.10499624174929435, 0.12463986227709441, 0.1777529908764747, 0.14278234883902535, 0.07589224740983018, 0.08110171424285059, 0.05442993414978828, 0.10096496451766261, 0.09058479490059038, 0.0690666644743854, 0.05737421305609807, 0.0333901260408663, 0.08376930900398763, 0.14395853895093166, 0.06497462114859974, 0.05693333328611428, 0.07096636334374067, 0.08508273610664953, 0.10145159888892405, 0.00371719794085009, 0.021950209761158596, 0.019618709263722264, 0.017451810417696834, 0.06171348827680754, 0.027310220532179363, 0.08031180098412499, 0.05253615330964808, 0.03469256744269402, 0.03663979823731127, 0.043252462355960766, 0.042207591205595, 0.1540657974058582, 0.05544858977138516, 0.014263012525325101, 0.019825214009371497, 0.029074059453822916, 0.0029000873638001545, 0.01722266011300587, 0.03623056938991912, 0.05972372428063424, 0.058947343965091055, 0.00823044837752898, 0.08155432664939473, 0.07065016821387314, 0.03335359130775736, 0.04991058996247669, 0.01645295625372279, 0.02607753718151681, 0.037834726859845465, 0.07711935172518415, 0.03014510782856134, 0.037129742108405604, 0.07156281641894771, 0.03580963471904397, 0.06052785613123448, 0.02596125844114971, 0.02355700448876427, 0.031190134111731768, 0.04862950709197791, 0.02572627820735497, 0.04062249017278514, 0.07121711924311615, 0.007801860009485315, 0.04048803791163429, 0.0077646755380556, 0.02190903445044833, 0.021142749258527355, 0.04807121668671889, 0.03893248872050355, 0.02011302558164443, 0.017437034496857275, 0.03721832102465053, 0.07368846526069027, 0.03619819451423903, 0.0020446592233999963, 0.025454096743957173, 0.046986941803967765, 0.03948197677551259, 0.02009904639224612, 0.01066359629358856, 0.01298847970657892, 0.02097077018040563, 0.01325692457612604, 0.02495752046665838, 0.034149529848007426, 0.0803856825035426, 0.06444640352480835, 0.06335511127667082, 0.01717385265134996, 0.03790671997252972, 0.000943612341812226, 0.04248519848671652, 0.028567931975328156, 0.05514909152782733, 0.048014955189559734, 0.030494221756535194, 0.02436030321874686, 0.04638882631796502, 0.03813605222310271, 0.06246102538200156, 0.04075120826582274, 0.025076915269657492, 0.05942555519962504, 0.04213959707187549, 0.05596939932494875, 0.049880145628365784, 0.04720484019227086, 0.03450735419568035, 0.019689821375293598, 0.007568021725502707, 0.028363488006195234, 0.05853785464780466, 0.015083563555362485, 0.03681989018655112, 0.015857075829239144, 0.026901033819623055, 0.057989695755344246, 0.02694816737916441, 0.015985717313484322, 0.07280012502545312, 0.03416597392530211, 0.0378991816673548, 0.030071377611508774, 0.04775231726647866, 0.04177618411279494, 0.06085780253934284, 0.060591177128615885, 0.05645620606599316, 0.050117383906317335, 0.02499436929581627, 0.02728489366540265, 0.10083973212468048, 0.05676650997972297, 0.0581196204368626, 0.06324836841574119, 0.012507120808286053, 0.042278220681774045, 0.03900940777854093, 0.04421200280288055, 0.05487112801582102, 0.05495085861654051, 0.07976156599338978, 0.04709269258103544, 0.0861271973999758, 0.040333774616761554, 0.06079618991803258, 0.03940773519477056, 0.10165419084050002, 0.06631911311659121, 0.06623079850068016, 0.02778503991242859, 0.02897205676192478, 0.20068598610739555, 0.04212588409803087, 0.06421836979326702, 0.002869101261885296, 0.032426165266623425, 0.07968033002989908, 0.05431495967411226, 0.029605833640802773, 0.01789393125011796, 0.07310169553684612, 0.08011469422208686, 0.06028371923152478, 0.06344883830376691, 0.06291575219121671, 0.02860328884825351, 0.12918912985872838, 0.03646306175317976, 0.07598728061683717, 0.12294486210110689, 0.13588236344437446, 0.05407199871936633, 0.16881424633245315, 0.13351404859173682, 0.057257633626220696, 0.1505354037808795, 0.1646166820559771, 0.19444282917726427, 0.0731402604029544, 0.045521135982726856, 0.08167513871505376, 0.20353333573908577, 0.09576075304780277, 0.10669796051637781, 0.10934173760394897, 0.022311994783400048, 0.052660711545256846, 0.0717166928394187, 0.04150847468765513, 0.057558411236612074, 0.07298644526951736, 0.029801618901171514, 0.05795686122690959, 0.07732454837570268, 0.023963121103964025, 0.008911356900728518, 0.07499762525361392, 0.03146718789432799, 0.1771534657886913, 0.07108214987261642, 0.01744420316460873, 0.05970775134741299, 0.04832671083990605, 0.02324823849654246, 0.03949136518302464, 0.022569706761128, 0.14688304895835538, 0.05199881923955776, 0.037481755679172855, 0.02348887820487782, 0.05115261384015603, 0.015510891229965755, 0.033084437806880286, 0.019855091438418435, 0.07379512768238783, 0.1205432300846423, 0.047401889497714664, 0.09644632513124136, 0.04879140062257648, 0.0444888478265174, 0.03894184265405901, 0.04553451570832441, 0.03823105478659272, 0.019209714073147026, 0.079775171714925, 0.03218016677325772, 0.008868793055655496, 0.02970384692983522, 0.030645418784491, 0.07788504894462325, 0.03648539704661216, 0.036289554329649094, 0.03836691281908462, 0.0143323463553022, 0.06416454062526745, 0.03390130203878207, 0.014881291445494901, 0.08985411556017014, 0.049129015570806886, 0.11613912084290098, 0.045346624984015385, 0.053060927368219823, 0.02801079644761499, 0.026684202208754518, 0.06660706258469051, 0.020435345584466573, 0.043074051969714706, 0.025514908803386555, 0.022752554711675452, 0.02054789156142262, 0.01952843154750524, 0.03276284175714658, 0.06369148899290351, 0.020373748284914804, 0.07760104482933398, 0.14697082731271946, 0.12865242398073598, 0.26462546159182826, 0.06920786213970954, 0.13099585629759297, 0.13510374232165276, 0.10471765387562976, 0.22770892558318956, 0.1447479772351442, 0.1541990813829245, 0.21052428641386572, 0.22460879758000377, 0.16371105887716816, 0.10132143288970956, 0.14061108712227116, 0.07139525000726984, 0.10300484215540272, 0.12207182830259686, 0.13306959502158627, 0.18249001894747058, 0.17774180599278022, 0.117136467728884, 0.1980193872605601, 0.08635224338861243, 0.1325643600355233, 0.07795666284378498, 0.11009655637486328, 0.15005148136087004, 0.16951837306541784, 0.11625184302007961, 0.10996370140703456, 0.17071831190297682, 0.1979851737738617, 0.23138433965223454, 0.11868376615307025, 0.10074839912234776, 0.21071484312415126, 0.2133848740448875, 0.1105423429380021, 0.2193367183809319, 0.09868696377041841, 0.12599164740212504, 0.16712909804717188, 0.17515825107693675, 0.19044496870088964, 0.14717534214498537, 0.11139362750034179, 0.19081160305969178, 0.19198684322257198, 0.14272510674932312, 0.128717357593198, 0.17163371036369957, 0.24592326353153876, 0.1651647873222828, 0.22397652989433658, 0.17345257163528474, 0.170369420140501, 0.09010962886555542, 0.0951345144740997, 0.22270319983363154, 0.10013395830267861, 0.15498331026925197, 0.11486761407145571, 0.22479290382996683, 0.11770477473375299, 0.12315101636153077, 0.2558065178774057, 0.2718882815491769, 0.11369751435854744, 0.22177441015599236, 0.23212108640901505, 0.21669561494021647, 0.32795323119048153, 0.08986990463228957, 0.15888513396343878, 0.11167907952180794, 0.1946745707743591, 0.21455433790481862, 0.1520117471415189, 0.09574189196310698, 0.17542730115594404, 0.14055421275477256, 0.1764865096418127, 0.29295312541146434, 0.24234475958491528, 0.20020514336084166, 0.4648007428453815, 0.3037932082529991, 0.2750708865782907, 0.2314784918581286, 0.2843509692578547, 0.3022275696839056, 0.27365671891358595, 0.2743154319543993, 0.18994325771927836, 0.1855329355044711, 0.3026258128304636, 0.3796915000965519, 0.4860363323842326, 0.37356291927637597, 0.25748368352651596, 0.5115287967266575, 0.32773406875710337, 0.4516915688591619, 0.22298634593044558, 0.23769964674307456, 0.18371606606148905, 0.2412848156546393, 0.2305333538641853, 0.345902732543407, 0.19432710393542246, 0.20591225324859544, 0.19900247725027226, 0.18324053996512968, 0.21395165653478718, 0.20509943396093386, 0.08105427807857914, 0.21892395020732958, 0.11435287959513166, 0.2431885135029593, 0.14705561792417882, 0.21427761162481002, 0.22127473696825967, 0.14874571513745094, 0.13471729692912873, 0.13119177562334847, 0.12692078948020935, 0.19122472363373927, 0.20108527113353053, 0.09280682526408665, 0.13849486116199725, 0.160927034073299, 0.12703055455800027, 0.07225391965719961, 0.1228110648451313, 0.14134222611544595, 0.17936729135051852, 0.09587960392837563, 0.14754266598291937, 0.20135386155978327, 0.13093522809926542, 0.11327597447821211, 0.08312149739433682, 0.10095092212601055, 0.130958563137439, 0.1333463825886288, 0.09991736226384679, 0.07883756436527738, 0.1619344396937278, 0.13406814466561043, 0.09144482818702537, 0.13692778234760608, 0.17343629992777304, 0.1253410012671544, 0.2241332561618859, 0.16354210584634737, 0.10099962233535706, 0.16795469568141047, 0.13858578047685086, 0.14276520379127997, 0.25143924980394305, 0.1816098145659893, 0.15601429607599013, 0.1756155902459737, 0.13346719465428783, 0.17971360905756875, 0.13202694935664055, 0.141939468261215, 0.23938997378272397, 0.155563009001555, 0.1585100113504356, 0.07248889414533492, 0.12298920327016424, 0.0996369127965262, 0.2101301648203404, 0.225712132730311], [0.03544155245406493, 0.001498501496239295, 0.0596772916915436, 0.012476700414422781, 0.03212271400937631, 0.015915156785218466, 0.046844587345877965, 0.020559076445117112, 0.033287343854505214, 0.03558456191732999, 0.04404174742258845, 0.02225805261743165, 0.04883964884004766, 0.021176395840161753, 0.0408141806931986, 0.024555376017346017, 0.0346058156461485, 0.048054052486775384, 0.013323646046281343, 0.031122032725702853, 0.04886512126352999, 0.025970288702557166, 0.013104543942327221, 0.052047710970885334, 0.01745381373761883, 0.040052405843931826, 0.07296235180429875, 0.03236721097041042, 0.021338302777299, 0.06391400689139001, 0.06277918935783448, 0.02030980292587511, 0.05148076760252157, 0.004591670548242908, 0.06996412881680074, 0.026152657848151944, 0.021789191486013514, 0.02645328607139809, 0.021128055692139654, 0.07125489503866242, 0.07241867452619538, 0.024885500540896773, 0.060071849955185774, 0.044153611581291885, 0.008372746336634361, 0.025892714639344526, 0.07335081200806365, 0.05231291911895237, 0.0383289301797988, 0.028176003308486075, 0.03140785055415284, 0.049154150915602525, 0.02477039391505382, 0.022950776131643404, 0.04986464000877835, 0.10408529425941168, 0.03068243423777242, 0.0627062960918392, 0.039251338345028704, 0.059737858602837215, 0.0430059161097292, 0.02490146772845859, 0.02095976341215353, 0.027666217760152878, 0.020699856592522516, 0.034284997175657944, 0.043081666883682056, 0.022259261121132204, 0.046375707062261726, 0.02124756540832741, 0.10704722766193653, 0.0370116917897136, 0.027280701249237024, 0.029745795989349007, 0.07033940464738878, 0.0367330847638509, 0.09563877652849882, 0.09891725746133635, 0.05206869028869176, 0.04407353241056685, 0.18930175101324437, 0.05903225715061831, 0.04149068612605333, 0.035646963609202255, 0.06005321486642765, 0.03854212478824681, 0.02105451508184835, 0.005551799446449525, 0.10010917535832814, 0.07645506156428207, 0.01874025156270833, 0.10149525057884956, 0.08213621639316121, 0.047305730141458974, 0.1518450464091955, 0.04562849554443552, 0.13707013680569588, 0.08336642336460852, 0.06558082652308288, 0.0580024472888439, 0.04685823520224902, 0.05845291847963968, 0.039905305471151106, 0.09982758442000036, 0.14098726693660985, 0.01390109918335633, 0.09825811541128544, 0.08028858085914005, 0.05319277876086774, 0.03427769252729993, 0.03478316500061943, 0.06534042813244366, 0.07395426712689862, 0.17716838918145628, 0.06375237000024607, 0.14195754793622803, 0.02906060886509236, 0.05459062109190611, 0.01902956275209304, 0.04270964309633259, 0.014759895237793606, 0.04069673175352716, 0.04236887569629377, 0.01951034421161298, 0.05219825490888569, 0.067203308816158, 0.006073691578011119, 0.012991877306523103, 0.022203769542336948, 0.031461430743577025, 0.030689867205857754, 0.019117141923596783, 0.06125963097738643, 0.02172589347126984, 0.01297135764147125, 0.04433324387777717, 0.050755309151305314, 0.04846759057874161, 0.041565659320763046, 0.1569627742132833, 0.0878080555928811, 0.037066057219260165, 0.0122454175124726, 0.02065551733868497, 0.017557653125315424, 0.02584034103840109, 0.0216202384551927, 0.037437851180232344, 0.009593901979256301, 0.028049912897028753, 0.009007532536352595, 0.04277734228620126, 0.07684932871451301, 0.025150840839130745, 0.06980016301836699, 0.04075210841913377, 0.0188312359950355, 0.027257406430679466, 0.008354118908755481, 0.04716600719538908, 0.018072466125651714, 0.0347332084070771, 0.013806300590776149, 0.06349273131138856, 0.02497155711265101, 0.04622342027423363, 0.06367551989012188, 0.06522881678275524, 0.008465749410642012, 0.002003003192517246, 0.09538134034242361, 0.06147861338010239, 0.028069105314751788, 0.033830189927210735, 0.07496654506652586, 0.07765027363934825, 0.055652932233868115, 0.01486056780953321, 0.04788438316374537, 0.06838228748810869, 0.013285397191441829, 0.06662232305614219, 0.023425716170740706, 0.04423915295891705, 0.036665220865078514, 0.022153288178566485, 0.10410404043091882, 0.020706933329723055, 0.05611479515209795, 0.025504656631739873, 0.06976123809093429, 0.052106623132262504, 0.042589773318820426, 0.040319475585654865, 0.022088938708146735, 0.058143959050216985, 0.04369400479199906, 0.016884794270980264, 0.07195185118865582, 0.03917317822455399, 0.009346572408122162, 0.006254220676172766, 0.05605532374653605, 0.07065804359773475, 0.05266833028966381, 0.03614740288485924, 0.03208430810651231, 0.06716944772990481, 0.04113600656930958, 0.032819057289030285, 0.04812098558871977, 0.07221383793700127, 0.02916566058692913, 0.0743071808509769, 0.0388363714990837, 0.053785343939859065, 0.04651603138735218, 0.023033864112691056, 0.09814293409186987, 0.025477868452247594, 0.04344129919885628, 0.05085429154156197, 0.020633706815480705, 0.013214798358779763, 0.009073416097840716, 0.041926456089582176, 0.03907759343424151, 0.020058556730228088, 0.019631449305903048, 0.0152925705356944, 0.01819408258363124, 0.050092842279663014, 0.03634109289475507, 0.05208665122007651, 0.07159721376674791, 0.0435538949715274, 0.03016444388777018, 0.019454551943307443, 0.014237330385273504, 0.07848749282739817, 0.12611641248147334, 0.04982253964689951, 0.0919400350821595, 0.0566371368815101, 0.06227113516821016, 0.05567986022440657, 0.08033497514383448, 0.015413148944536525, 0.054823580768800555, 0.06140512256552616, 0.06129233144043435, 0.05613543356077806, 0.06159643770285672, 0.061026200156418554, 0.08192616274520274, 0.12624555958374856, 0.1605933261734824, 0.06054823023958072, 0.024451519392671126, 0.057906609689516414, 0.014452763885680227, 0.12557799822740978, 0.08864592595566666, 0.036764459894789804, 0.025804459395247604, 0.0221182300799316, 0.09821964247572808, 0.06909022933893627, 0.051106644734259576, 0.032774317754252304, 0.15222154798046236, 0.09356738969443307, 0.10102277351242882, 0.05354442460943134, 0.1428734213714638, 0.08480718194116509, 0.08774509848726374, 0.05269386016974046, 0.08521557575271976, 0.035403006740154765, 0.03319808695044729, 0.08197831801108776, 0.1270686980757502, 0.03426714732702221, 0.024809293944628972, 0.08935782082018354, 0.041306315575756376, 0.04931285752043609, 0.05237969134243266, 0.06876025228731095, 0.07443849598207782, 0.09011898279911087, 0.06033397076891796, 0.12168816380923796, 0.029707759723908482, 0.05104725759836936, 0.028316442546765172, 0.08757169448560284, 0.07330272466905656, 0.01989432088580103, 0.03710769792838443, 0.023917060067516663, 0.04373702445938703, 0.06115363888262261, 0.07434772222392982, 0.045240081305946075, 0.061477291878433, 0.047895813195575634, 0.046753334782777295, 0.04756666351890853, 0.1018436826885708, 0.02164070257887004, 0.10395482948590672, 0.05543627490800235, 0.035304250345835765, 0.030705884189134648, 0.05072299939309878, 0.037270943604169354, 0.053896281132174116, 0.010213783938407658, 0.030239997394082528, 0.04866775020115799, 0.03592797232070758, 0.03813600242738763, 0.09643140173847638, 0.03844075986454564, 0.04975292906765977, 0.047172871343190634, 0.017705418079370455, 0.06763221080144567, 0.038313470525486816, 0.029097193393916376, 0.023991866638102842, 0.059537970941633954, 0.0484000446064578, 0.04487397554781168, 0.045659127570087873, 0.03157697403953681, 0.05091464394823678, 0.00491316844296131, 0.06819447337259209, 0.0615524604255634, 0.03226229139874059, 0.016648494450735952, 0.02520512582944526, 0.03180199704553572, 0.059627415537233316, 0.056759442818621476, 0.0562124522102456, 0.015846419546212402, 0.05557866384004874, 0.059123624626907616, 0.16146930174962168, 0.12357595001137066, 0.24834454570326114, 0.26151459303594404, 0.16595762703687916, 0.2142878465594784, 0.15109755909971653, 0.05571894219986374, 0.09050600275757814, 0.13186489111713826, 0.17061976235239737, 0.13133187778294086, 0.14128545900025677, 0.1361640539741324, 0.11525313249759137, 0.20250357567302643, 0.07913996991250785, 0.1575140817271125, 0.1166210820778243, 0.17082112090241525, 0.2531193112654071, 0.08597433221556487, 0.13439656655874946, 0.2284158561979571, 0.058310127351433046, 0.1847279149918787, 0.11761234622568854, 0.16846052821605437, 0.10277379769831897, 0.18084450805139157, 0.17756270995784193, 0.10683072355365562, 0.1720776429940616, 0.061800454577971856, 0.14429840619765943, 0.21794265286336023, 0.10699288138458807, 0.13153452336067153, 0.12693036557926288, 0.15900377033939286, 0.15514201304364592, 0.1288629909076037, 0.26591760677195364, 0.17447401198648638, 0.09971139952540399, 0.15176243148744106, 0.2563500419379242, 0.11371240710779545, 0.0826652767136693, 0.12435755887699705, 0.13307008531785783, 0.17775674470730368, 0.09534081429122918, 0.09385209094973342, 0.15886890822120253, 0.18822947306738746, 0.14620487728426534, 0.1426753876430373, 0.22025125882317945, 0.12286826863043732, 0.12353479576807831, 0.08274338703842894, 0.11796015780419113, 0.21628349028047056, 0.2351977261564424, 0.14974751299427402, 0.19949738537111592, 0.1676365240446983, 0.19642290599163503, 0.12373119006834685, 0.32036224980988814, 0.09644617957453575, 0.13918660791410556, 0.17845959973431405, 0.16734973136936465, 0.1575510378085798, 0.2101109973004749, 0.21544978743599308, 0.22505239313167913, 0.19009255293396213, 0.24016646518101617, 0.11106913563825431, 0.343008820087679, 0.24296768099790622, 0.16136307599804095, 0.19150181763595153, 0.30508425026651353, 0.14791262516331288, 0.17484449210666841, 0.18454359423729683, 0.16836377131121774, 0.3617955636112921, 0.17519808764899933, 0.23994223124557928, 0.16906141694034302, 0.160297769452295, 0.2823067708842216, 0.28716143941687, 0.1716886082243535, 0.25963973073709395, 0.1336999015221673, 0.24451075061675043, 0.3406925379268585, 0.2693026122306624, 0.2996840658447435, 0.16560772403834328, 0.3017099393952278, 0.18041369084629322, 0.10464766408286749, 0.26161871970661227, 0.25266822337383227, 0.20000023016285515, 0.19245959608064545, 0.4422863380562875, 0.14936558752050325, 0.28849838541880735, 0.09159553300348983, 0.2846718681675773, 0.09763480329345312, 0.17603480887989845, 0.11678265002105506, 0.18504144413576973, 0.16722954749580354, 0.10941224833649975, 0.11522405946086492, 0.1356495799677026, 0.18729712874177964, 0.10810411490139463, 0.11561756818405083, 0.07621982660625251, 0.13792513689446834, 0.1167135718729227, 0.17514090684633102, 0.12041634294174372, 0.20261141020924817, 0.18572324706662088, 0.17809088161635786, 0.12054980311903263, 0.15378023047120343, 0.20695656898521608, 0.1813394621375107, 0.1291833841992963, 0.20226498524988853, 0.07021435611550847, 0.11004163553157162, 0.17743653527671294, 0.12050261210289695, 0.1465595759932072, 0.241629570542324, 0.18937704213444265, 0.16584651364434153, 0.2556129734242155, 0.23838002475038653, 0.13576699060297784, 0.1789406723072452, 0.08355295811329158, 0.09744538805417477, 0.15071525058198362, 0.16448753495370189, 0.11810499438715559, 0.11832147551279877, 0.11093999619685835, 0.10868979678038629, 0.1910978747952369, 0.09211545389506126, 0.14262625076357396, 0.18981761929969634, 0.08976630656228912, 0.07859040907914601, 0.15381936224237566, 0.12617572300857113, 0.19225960116713278, 0.09975271464716043, 0.1311292322052102, 0.29083164408802986, 0.1576105475185379], [0.06623161821475913, 0.047418666823256406, 0.036117808908344276, 0.032427027115538236, 0.039954572585561586, 0.04052174578030263, 0.04120802266463157, 0.01743843643775871, 0.03409276656325787, 0.07848426759723695, 0.04175193742999146, 0.020664486313058485, 0.03694157942288345, 0.06953812264386686, 0.031386884642885096, 0.031361310712752805, 0.02899814014052672, 0.03787647482127913, 0.13036692875527567, 0.06020871156285848, 0.029785622985312538, 0.019687731870480125, 0.024901483050217072, 0.0291724021606628, 0.0856354532222594, 0.028887275726564472, 0.027972896162781025, 0.007787824799907544, 0.09759312044949302, 0.003242803021191409, 0.12658535788256314, 0.0554034250578092, 0.03464063434230705, 0.02448362805279753, 0.08049511050264682, 0.01626628552443318, 0.01393022680384738, 0.012083265427199584, 0.014530294856447128, 0.02790175532291253, 0.11698256066489605, 0.03402650761868685, 0.07394806181471195, 0.058445721083591064, 0.0826860376964173, 0.03815527719956252, 0.004179470716119414, 0.04870028212486256, 0.05348399942440372, 0.01738400780595839, 0.07343571753271165, 0.06403704061202946, 0.03846635103165623, 0.024844076251611117, 0.065186214633286, 0.014213330765825608, 0.06646128371357918, 0.03579569957970131, 0.04292997381379528, 0.02380957218608068, 0.03267188796833639, 0.02820802961416062, 0.06854203980295889, 0.05694873165339232, 0.03360140925994323, 0.009820082735630774, 0.06867941468954086, 0.04448747269869332, 0.048423885262661406, 0.10509974788874389, 0.019322721618077448, 0.07775481399749556, 0.07819246470687852, 0.07805234722552762, 0.025941912805841818, 0.08816692182013104, 0.013292359015453729, 0.07242435123771429, 0.04113209569045613, 0.08095617285899578, 0.07623503345154947, 0.07082151143901771, 0.04202703577316096, 0.039397691782083244, 0.034601023766182126, 0.0485302297578704, 0.08796403109426461, 0.11319604852507192, 0.10629505955524023, 0.016190774152956663, 0.05089074200499923, 0.08854509346307286, 0.03783518268216041, 0.041022736639265096, 0.024148196455151327, 0.05271175981409127, 0.08324201068570537, 0.09861538051477364, 0.11131492728788046, 0.06450398269319726, 0.03514580038045684, 0.02047781175332925, 0.024047917461082823, 0.03800017886885232, 0.09751998203536195, 0.049844702570548946, 0.01740129074953016, 0.0559039217900605, 0.026817945838575403, 0.042535856050709565, 0.061652270190778284, 0.013690286150742925, 0.04101560053025042, 0.0652650680633322, 0.0459684317390765, 0.06318602418046325, 0.053192660017239476, 0.024890390097073493, 0.04354100554220138, 0.06258132416875133, 0.030594692272584767, 0.05481416554821115, 0.049580601419532494, 0.08607133426853726, 0.04258680472811384, 0.06473195513770466, 0.06578098231505963, 0.03563173761170718, 0.04525503151178841, 0.009781004590613228, 0.026137613796538887, 0.028289437947434284, 0.05156591827530534, 0.02182550596884422, 0.07663756669048341, 0.01887161074386489, 0.016111765590105808, 0.031780416348708734, 0.1335656063090409, 0.015075153825173696, 0.05851949535069927, 0.06679673063298387, 0.03555807825778762, 0.01715161120368829, 0.00220004124604466, 0.023068510439066638, 0.05616184827240725, 0.04807044676835499, 0.04143157861225548, 0.04487833458810084, 0.028141883667558435, 0.030543069437807126, 0.08848576761421659, 0.01663117703320759, 0.009245129918018657, 0.0041775353865007, 0.04041388826144319, 0.06903747652447031, 0.010650201246232517, 0.023215670183661486, 0.05552931628640621, 0.05008738390320251, 0.0563886869067867, 0.04922102656095259, 0.053548672566971475, 0.11765225174566431, 0.06308527595754113, 0.020227873652812936, 0.058115514205588456, 0.03222983608382844, 0.011524957784962271, 0.03997937085167055, 0.0473526070615457, 0.03425472521133, 0.029272269382472002, 0.028272057327652172, 0.059058560779498476, 0.03526596893225947, 0.08439855830323312, 0.0892567508403332, 0.02461289581392081, 0.012462830392553682, 0.04964774902609568, 0.023052380457820914, 0.04885564092546702, 0.09053433268901803, 0.10623491399230496, 0.016571648171051376, 0.03376024993016355, 0.045776913588445996, 0.08851991215300176, 0.030187972363144643, 0.023769731783578475, 0.023087247034474727, 0.024352425919665445, 0.04737138387656981, 0.027982305637711, 0.04792628051232427, 0.025229025857463002, 0.03136884518748811, 0.042409777130571105, 0.03709671988842949, 0.056422168779517376, 0.06724456265088051, 0.09640911624075905, 0.03532004707883443, 0.04945087209043484, 0.04925261619651029, 0.04985408331718176, 0.021420588281245965, 0.07819051884355084, 0.014160207356326284, 0.12370918802316151, 0.046961477041364684, 0.030231708322741815, 0.026167629121412194, 0.09365800257411697, 0.049987194924465114, 0.04726329270089346, 0.010045246510285764, 0.03581110560785859, 0.029596297761365294, 0.009811284215820414, 0.06753650343706531, 0.03475571223985284, 0.05129880639874647, 0.01796254016939671, 0.0617317364911639, 0.05807514520241849, 0.030970944865276257, 0.01439557925257231, 0.04786368729847093, 0.06028450830208679, 0.042680336402789246, 0.058071441167304595, 0.06739888340234756, 0.030397754049889987, 0.0071538702843921085, 0.10409955115568253, 0.04774028585562783, 0.03908358807224901, 0.029269241419951283, 0.03958046120861846, 0.045537066781112266, 0.028290633044596163, 0.0910336075110301, 0.022924361420014215, 0.06952457820936557, 0.07830840445333913, 0.0561873245263292, 0.05289947050773809, 0.004898138755496832, 0.059692578976072615, 0.05757910710188651, 0.02465673711060757, 0.02909224255070571, 0.005056662935643427, 0.05577188270587114, 0.037025573302901564, 0.051548880479869344, 0.009905654756772903, 0.050341545063401424, 0.021394751965999607, 0.10069739298834916, 0.06998273709248151, 0.03402885950861439, 0.06517199604141136, 0.06080019655787657, 0.05046151443234375, 0.02617239610352103, 0.020685132382617846, 0.033496669718935605, 0.04667385699107282, 0.15426200784502492, 0.12419957622525193, 0.015499353945826091, 0.05021186553001885, 0.03875752189947713, 0.0624358325806116, 0.042895902053362904, 0.020456257869579622, 0.016575926772108483, 0.05662632355045888, 0.025251908903761257, 0.05385854364102406, 0.0519593810332158, 0.04412111796198353, 0.03876464268673332, 0.029164875346806743, 0.06191480469198958, 0.024427653838609977, 0.07693423423916101, 0.02102744153460428, 0.03957122601869126, 0.04966049289871609, 0.07600319992390371, 0.05159345530574361, 0.0491285176136561, 0.036704448397241296, 0.018872792434488094, 0.01620302964452534, 0.02153933190950944, 0.06866350304335356, 0.01918260413672655, 0.050756845157593496, 0.03212928321332701, 0.02779156889676327, 0.02269363105897942, 0.013016581726861338, 0.04294123913672182, 0.0485422381860835, 0.04192099005224244, 0.03722405136232415, 0.007858607014866487, 0.044278460930311875, 0.04201713791717926, 0.05636003138797899, 0.047810597405318296, 0.052375895376767845, 0.0186907067414253, 0.011657974588864995, 0.05220958151884618, 0.05097609569108294, 0.06992782391006909, 0.012503257809927868, 0.03517192780911442, 0.08141246248757647, 0.015790820715107744, 0.05909400766775493, 0.0022585868822305555, 0.02306910990286739, 0.01835858847405161, 0.05542051264896028, 0.0402119551454821, 0.04010109456195947, 0.07111409573905891, 0.0292567158823893, 0.05472793086101452, 0.06981393727924555, 0.044307541627917564, 0.038323483294657165, 0.07984573607363048, 0.06475858435395264, 0.06251354070921099, 0.06576550733898917, 0.009225345697374114, 0.013456772975323182, 0.04877320986481444, 0.023565368253677606, 0.03520365151005887, 0.009633483827084063, 0.02102244664133797, 0.18547773120864747, 0.1189389577015273, 0.14922088883336515, 0.19040937625592758, 0.10687620619372015, 0.09738367201099474, 0.11363704703868398, 0.09347613330089277, 0.09035589548969462, 0.23281686278360508, 0.221312704285787, 0.10147196916683067, 0.17932422188741548, 0.1764628834902279, 0.09406323244254436, 0.11803866649467139, 0.1177660234632992, 0.08754560153090185, 0.14123272150754929, 0.14598217552467702, 0.12977823615074158, 0.14347440202630338, 0.08321564960023088, 0.12215044424538651, 0.19991674190086706, 0.12627458665519953, 0.17327945108615583, 0.10955402056776709, 0.27553875179540727, 0.13705412556807842, 0.21884688176214698, 0.24493721644243888, 0.16204682479221977, 0.08247094318991707, 0.24335181280489893, 0.12837993416694865, 0.31172460846362576, 0.10375741628869888, 0.15208368279760884, 0.11397398782954102, 0.15741968437308268, 0.18501047886187033, 0.17196974717080596, 0.15612683439206693, 0.17440624384870454, 0.13457937045924126, 0.14277116395533085, 0.15533423982560635, 0.21973681546026663, 0.07094518101263432, 0.18837432497211043, 0.17985459987915334, 0.13317153068079104, 0.2020264101485091, 0.2788419084202859, 0.13088198498852793, 0.12339910627492975, 0.09203472354960057, 0.14113245592001947, 0.13207751115964306, 0.19815878461926215, 0.17070720362807476, 0.21331384237254822, 0.38932238975840233, 0.09594527298524495, 0.16521124289401118, 0.1691823822235869, 0.20608430127463034, 0.1165188859487253, 0.26145888312209037, 0.19072088292769848, 0.12060409577022638, 0.17565747993367334, 0.17603969652085535, 0.16010515962637242, 0.1246535522683013, 0.30341381086937846, 0.2357525576747233, 0.18418658194282364, 0.14163753768849757, 0.09920201234279141, 0.1344756421542937, 0.13945461611353582, 0.20798449044025716, 0.20331958188645302, 0.1397082678252651, 0.23324031022287187, 0.29730254363629127, 0.21039481755466233, 0.08923528505669487, 0.1465695657797398, 0.1547088822530162, 0.12716333291703655, 0.15420209976934618, 0.09363904955887026, 0.16470236132942861, 0.18995778274632272, 0.4045569367947117, 0.32576899194429, 0.3127362735329136, 0.1581223402172327, 0.19026648553629077, 0.23018777160154236, 0.22684840966136227, 0.18621568838434835, 0.15458690573371228, 0.1466394329984342, 0.2294483741805438, 0.276932756025945, 0.2905663018745761, 0.20704125234436607, 0.16076756521098076, 0.14184884005977264, 0.25289512329524566, 0.20183822831078885, 0.16823784177822454, 0.12008022186496567, 0.12472751039651134, 0.11070799412986926, 0.2388697234733451, 0.12813579726723895, 0.1945338251009103, 0.19242719056144839, 0.1716753855467804, 0.1699353240790867, 0.18936286950784345, 0.16823912880593733, 0.09772919298660371, 0.14072531083178136, 0.09329863072883698, 0.1781880522086736, 0.10981882651967388, 0.13219754181561932, 0.1919039678309233, 0.24393380980097482, 0.09219788495571384, 0.1288710654743256, 0.10234191563100585, 0.22512345544753537, 0.14375578612089157, 0.15590321332696946, 0.18267247044751722, 0.09913635094680133, 0.06966153940846843, 0.13894136784778488, 0.07128966776954551, 0.14050461622255464, 0.14109350800994905, 0.12635163977862368, 0.17957272548829356, 0.18275355319342307, 0.11086657433019531, 0.19597164956071686, 0.14991729340005308, 0.1985525844558593, 0.06495536169818332, 0.11792998160085372, 0.12674657342534873, 0.11987291081177613, 0.09977198941933532, 0.09042807629392033, 0.1682554464787245, 0.1618555632810439, 0.12784079979023627, 0.17400539600320403, 0.1786705497051439, 0.14232574511439572, 0.1840909894916319, 0.20921069077186047, 0.1566538262751795, 0.13081432410305546, 0.20728148219566192, 0.09998603438537929, 0.13860929937612626, 0.16308632949667592, 0.1346452386989709], [0.026883206953625047, 0.07731399934498534, 0.03044558666466225, 0.13789800206019034, 0.025199016278249123, 0.05781645646258708, 0.049005671584558104, 0.08363927323972026, 0.08336269251641729, 0.02768474751182141, 0.06881469815608955, 0.005437936755873624, 0.036918964507358695, 0.049412598337737784, 0.06889454750043732, 0.015593247597045718, 0.02695188290559717, 0.03474045942928042, 0.02641344375367607, 0.051834041387924266, 0.0025195777162744276, 0.0511949899936876, 0.03441359269462767, 0.007051444328915809, 0.0348301759860929, 0.02411934366870311, 0.11651186858333888, 0.02610454561128732, 0.0690423948089442, 0.042589627762114814, 0.08598622956102894, 0.051252676414385925, 0.028057621656766826, 0.011501323014888312, 0.06276447280880905, 0.04435380950810448, 0.03618397209192476, 0.05959828887435217, 0.010566961962819822, 0.00524966394521236, 0.027387329196978002, 0.030931596674265403, 0.04585074148170891, 0.02339352132572282, 0.017511406312546423, 0.051754253330610456, 0.04456363332968566, 0.11061591802224999, 0.05247763185311229, 0.00968415958566531, 0.06568725145752392, 0.06932908023196845, 0.037405633352576725, 0.033063672993692665, 0.06266280144993817, 0.045911840824109894, 0.0778977660041663, 0.041451650115871624, 0.03557987345923339, 0.034479939739309975, 0.06974922583228158, 0.06374053777225556, 0.008059786970637018, 0.03635661766654061, 0.1674125965444311, 0.01674117002215597, 0.029236000864916754, 0.021586385029818744, 0.016077389309723533, 0.03456216012578338, 0.06506053024842855, 0.027599976052560156, 0.044636277617105556, 0.02091499131863877, 0.06717879400258103, 0.07103356457645855, 0.05921665451399261, 0.02218668578162549, 0.08245770519058551, 0.06840262712249834, 0.09529244349969011, 0.023506103691855268, 0.0786306746604462, 0.03682914452867643, 0.013318168517622738, 0.027663103612740676, 0.04633143101067794, 0.0954248464756435, 0.07329857247250696, 0.11560626072628845, 0.01718709639634096, 0.10546203852901537, 0.08700524907438986, 0.047316244698219725, 0.059340580727063844, 0.008706334535212768, 0.08374190603893611, 0.1276146199914717, 0.05943990019600719, 0.02569699641166916, 0.055141760066391966, 0.026984914701672334, 0.12033956560997233, 0.0021166030191741283, 0.05523884255859641, 0.04073091459670856, 0.07953839692016763, 0.04903747189429499, 0.008414016450725256, 0.05043660125304615, 0.05884504441412226, 0.03313613342001073, 0.02725594320274409, 0.04148157351019402, 0.05721666324403017, 0.05130875788088288, 0.013592732514465048, 0.02826033809763049, 0.031129030938891154, 0.08010248278057383, 0.06674955493860668, 0.024770782704675393, 0.026343204982338414, 0.04855852138491408, 0.03543859535467721, 0.02926819379471483, 0.02427950775581262, 0.056724555174549746, 0.058285244815652414, 0.020187259501507206, 0.03947872473227401, 0.03426895912496313, 0.027783149590475426, 0.051793936685088186, 0.012888767617574383, 0.05258720157848251, 0.03373212301202359, 0.021403904801474947, 0.05751546051713729, 0.05543932393794099, 0.0531675361637627, 0.05722367677897696, 0.02653315456794395, 0.015055875222559177, 0.056032980792224414, 0.03520863491200632, 0.03530463722023753, 0.04571612451165434, 0.0247890749690874, 0.08619818310703962, 0.012959547438508561, 0.025522309212735104, 0.046650380226633245, 0.03654769914705427, 0.052998590793821125, 0.019376296061842192, 0.025186180475077806, 0.034480138922170285, 0.00801260122135582, 0.04835631630773987, 0.05271270976311738, 0.07758995953706965, 0.03401248054879327, 0.04207521121227934, 0.0726250509521173, 0.10346586620735546, 0.06389627578638254, 0.04258095947725158, 0.03178331982194176, 0.045868771361006845, 0.01733101367379629, 0.024363486314072244, 0.04305984103871931, 0.0304853274757343, 0.05733840227607758, 0.03765030651383343, 0.06682362031912611, 0.0512257369325286, 0.0409258954647568, 0.04041386527880546, 0.031044847452111786, 0.033624150579975504, 0.031331291557439876, 0.03854403234717827, 0.047874052468086445, 0.022790407116014152, 0.044430027595691146, 0.03785852538121324, 0.051453058202300346, 0.038821700915333726, 0.049932783529643095, 0.090284948087027, 0.053252388062256004, 0.05235202407704727, 0.040718592072446505, 0.0422171290002523, 0.004297766182947183, 0.01383984566576058, 0.02059171370591127, 0.036278863572665764, 0.031072826898326317, 0.04319448865229084, 0.19071602593025855, 0.0023464612369876237, 0.06636674846372297, 0.01866872384843807, 0.0578023566143407, 0.05406377476549918, 0.06872936362220396, 0.010209972650984363, 0.03657791365478789, 0.06208450465853657, 0.03146296100420577, 0.025778674790936134, 0.036325066335379116, 0.00654568744545442, 0.030143405198149627, 0.041304656995400306, 0.04412098389659678, 0.012777145734177002, 0.006151619478083787, 0.01382065612086726, 0.04754891326170295, 0.018204005337470484, 0.052827573156044375, 0.08731724604243234, 0.04489125083050421, 0.020264555857847297, 0.02208551046468558, 0.05985605830867445, 0.06624328573384593, 0.016959100969195846, 0.07458075084873746, 0.026019802880323222, 0.04078829075179754, 0.002118187145360055, 0.05338821162079131, 0.04815369754308655, 0.029950132706172528, 0.040846946273720076, 0.0933906072450261, 0.02928532160548193, 0.03202297510729442, 0.04067505146527002, 0.03138755305459903, 0.05714544388014944, 0.14289390656255907, 0.07510968093429843, 0.10887814715744988, 0.035037464056644714, 0.07885529930072446, 0.030727353803212606, 0.015157572436897505, 0.038870883760072535, 0.045662617100582975, 0.0739478013448177, 0.014231470770262664, 0.08305542231086763, 0.08830201376469866, 0.061185002522242654, 0.06978635811397145, 0.03800539592761667, 0.08387381871861797, 0.05067953539471473, 0.07999582801975551, 0.06100187686482265, 0.0342280576906858, 0.12077997423588269, 0.0030068103543242383, 0.04954263027156553, 0.08085727856885042, 0.08018655326938437, 0.12696895342800887, 0.013402526289404882, 0.0787181389187613, 0.0874101265423721, 0.019014499548281875, 0.07347407555508037, 0.03153858728887093, 0.012447497142749208, 0.024271469578267108, 0.004508316351641571, 0.03875858293125226, 0.06241850750220399, 0.08618282304415781, 0.0013496239191754873, 0.012720125809972806, 0.0787098728300583, 0.049693630031880834, 0.03915717464781577, 0.07645041141058169, 0.08095867030562894, 0.0408203362096702, 0.06382336719862877, 0.07714509227943998, 0.06426484834763312, 0.0322209686161049, 0.0438228722721819, 0.03372453874157321, 0.08765045598509812, 0.008788042600386807, 0.05670796171010983, 0.08472334127873184, 0.03197792147646748, 0.06279232010485665, 0.06925409554593986, 0.006682954600922043, 0.022822944785378153, 0.04449444792924389, 0.039251617967121066, 0.01752642355108213, 0.08022914775797436, 0.06686200898501181, 0.044737914502019846, 0.013065618057284626, 0.0746740373752771, 0.028202766590120814, 0.023713646486641902, 0.057740954667209625, 0.032601132087649844, 0.027918620748565565, 0.02577896207390774, 0.03638791235824747, 0.020680683326997587, 0.02165190086910321, 0.039329598056933576, 0.042354948217830354, 0.008086551209881662, 0.04217481796419428, 0.04496064307468553, 0.04185913611323603, 0.011780200086744323, 0.02974351113211484, 0.05591622133168483, 0.010304286692952438, 0.04595842663078539, 0.0444720590096568, 0.03160640139192824, 0.04437733223781951, 0.04871059366832337, 0.06810271902190101, 0.04231144591505009, 0.05239477944410136, 0.02060757747160331, 0.03511588081657406, 0.03169426210074416, 0.025873583508655432, 0.08450165075520355, 0.013712043047792489, 0.02165156570563634, 0.0634768273260805, 0.006109773361634824, 0.2065329070413305, 0.21843802063695847, 0.24660682846461576, 0.1775171583698642, 0.11409693728050879, 0.09749553616969817, 0.12546377451789956, 0.27000505357019366, 0.16325568089321738, 0.13819921251025893, 0.26273892411301214, 0.16158913322273763, 0.11820939684947653, 0.1737907841320961, 0.14085341605447954, 0.3100568044089502, 0.09147474392046852, 0.09153492012692076, 0.14911838626909643, 0.12087945841372975, 0.1147160435756368, 0.10298781202084596, 0.19548308464788622, 0.11383396993962028, 0.15616011325149767, 0.08389117061010293, 0.2624841539129134, 0.12494579182877658, 0.1363017046523671, 0.1756849058813626, 0.14798252302552425, 0.16720121756436365, 0.2424583244588106, 0.10094950486335064, 0.09151703963476805, 0.16998864379861664, 0.11378690915843172, 0.12290360060550513, 0.11378915379604987, 0.05084812836421113, 0.08854075740542143, 0.0945856967460244, 0.18231633149327772, 0.09081807633441302, 0.09715982111951998, 0.17539440534047543, 0.14045194001688113, 0.1582988009097115, 0.1546338209581952, 0.16887781630840995, 0.10648553199585407, 0.2098838675526842, 0.09714029353833008, 0.10563014886311947, 0.18787676618704874, 0.10583408146856293, 0.12912542198694524, 0.14543074543677992, 0.1883782933075582, 0.131397730700912, 0.19221256336858197, 0.21883549769559216, 0.126294321080129, 0.21201114050082623, 0.27255799561258287, 0.11801192236523475, 0.11914006344253018, 0.14034226686964113, 0.21009913825940704, 0.15074158868482038, 0.319285957563308, 0.1807724191777168, 0.1981233913571604, 0.10144799827567993, 0.12816958940557896, 0.1334939770881207, 0.1245748750384777, 0.1422065877986531, 0.13721694989550498, 0.15054462747948785, 0.1807027817853997, 0.19542458617398817, 0.1914146215084099, 0.13643744011079112, 0.18942921272208615, 0.12441923661578087, 0.42177500804105117, 0.14083434046516496, 0.28907509640820567, 0.20195927020282517, 0.13416119370489352, 0.2327547790182214, 0.16840644240860017, 0.15540067497039997, 0.1757750897518089, 0.20549531755668504, 0.23141319052346293, 0.20437529701138699, 0.21578534926858642, 0.2129501344696168, 0.10563356561526176, 0.161624955494077, 0.3782280883000743, 0.2348896209150553, 0.14530340630200603, 0.14786929523031558, 0.22753536070306457, 0.21354815802506863, 0.23334192412514843, 0.1594207673183372, 0.14928254358951124, 0.14548034196899784, 0.12460833009813102, 0.1759507537128464, 0.2310433539171373, 0.15470309062830864, 0.17095975217319306, 0.11849774468329646, 0.1922941976977933, 0.2080995262029671, 0.16491118157582899, 0.16246448060677898, 0.09870750258766836, 0.18568147995298911, 0.11961666206198356, 0.19817931577563289, 0.13685531042996915, 0.17603756679642588, 0.2053696025283106, 0.12860503378173999, 0.11865961906169692, 0.23373371681138394, 0.1829016379891865, 0.2681268817715107, 0.07573582757745059, 0.17007626893539585, 0.1614965438362091, 0.21626718792944186, 0.1179844964175455, 0.12145027818699038, 0.18532037674900026, 0.15636582318092548, 0.22681487033203726, 0.16667670780612578, 0.13141067758683236, 0.2010173804216808, 0.12598276078220338, 0.09350665424379612, 0.13228611690142464, 0.16898781121257814, 0.11267760618319435, 0.05725112570930393, 0.09174570155840728, 0.1612154508550321, 0.13454946238667737, 0.12006783422323004, 0.08906029525303072, 0.1666154514157003, 0.14651770162726604, 0.0716309829224502, 0.12208109030560141, 0.19256226718425754, 0.0886148993947333, 0.20029374909016395, 0.20307916817405533, 0.1637088219004293, 0.16123645698591588, 0.1039640608453943, 0.14794279370577107, 0.11146262903968174, 0.08614601251939613, 0.11216582114537878, 0.08596553752619414, 0.13374657159851444, 0.24321046958286918, 0.1024265070596049], [0.030561135706281474, 0.044460008446607864, 0.030953855358905373, 0.048365811967561324, 0.026589059834218314, 0.014364052819268358, 0.016772826690407052, 0.04666609652039986, 0.019247464970835758, 0.04051539108097073, 0.014490976351343337, 0.04136343892183035, 0.046929025556892164, 0.03564970620397118, 0.04810403972383469, 0.03759966044115924, 0.036747529351663206, 0.03166009649454105, 0.005112013266977644, 0.05338433904633407, 0.03922143793334404, 0.016233525689571135, 0.04562687526847567, 0.025862806566780614, 0.0231208706334714, 0.02090316292108788, 0.024210443014218926, 0.014617404799097249, 0.05739639130150599, 0.06524018552755156, 0.06011482748773791, 0.05769742555135201, 0.060060937032704396, 0.065924332687451, 0.03811801468292552, 0.03768212980620804, 0.03953200614740772, 0.053919665966062784, 0.0730601888931086, 0.03928294330234489, 0.09025727699120199, 0.037116948440070116, 0.046144953718589204, 0.08121120352898875, 0.0524300616234541, 0.02478238702150843, 0.01734627797568758, 0.019824685408703743, 0.031775827482042295, 0.0702383806328139, 0.008127733223861264, 0.012248391848838618, 0.012406636885697804, 0.07425327124374528, 0.04714096378114435, 0.038171361215532794, 0.05415078703193896, 0.035512603278602325, 0.10687739363000279, 0.034564182597903476, 0.041711572257261124, 0.03465765681598456, 0.06522246591386295, 0.05034742095778066, 0.0327515151471861, 0.019539746666146864, 0.07201811779410609, 0.06170308480279581, 0.11716275220556606, 0.05252976413635958, 0.031421168992716464, 0.05547355274639784, 0.05992904350522065, 0.05418774694384587, 0.059880251365323225, 0.01906124623342147, 0.021798267712696426, 0.05693122654432251, 0.01015265778292932, 0.03582480325994473, 0.12201919040131955, 0.049158479312374714, 0.041703106985697826, 0.05395558399839267, 0.013576942484735722, 0.023754161046517473, 0.008629621363305038, 0.034980275593097174, 0.005585660532702722, 0.06378551479429007, 0.028223935514688495, 0.060403060408369194, 0.033326609691064206, 0.033453944995398485, 0.04250259634347693, 0.09421707821949836, 0.11182093602274695, 0.05294295748875988, 0.026889758920597456, 0.0806599036760388, 0.014699565813756518, 0.06483065024498971, 0.007927495556237597, 0.10490661712303277, 0.052060221186688835, 0.04128519070124434, 0.0729582991991793, 0.03641877421027711, 0.10771353263407947, 0.037930840250825694, 0.11478996339945063, 0.01942149141893512, 0.02837267723084698, 0.03891102293686521, 0.051145236413445205, 0.016331360863161185, 0.055203334383306005, 0.026073965296569853, 0.03433418385083637, 0.051255066608709675, 0.07272073533385992, 0.02133590300687619, 0.0807928275917807, 0.040369436009636814, 0.0537364905129277, 0.052542914035579855, 0.033008526154463334, 0.06876020632203549, 0.07139282150854988, 0.06444691680371761, 0.01646551243480175, 0.0446668904905598, 0.009022111189551651, 0.0920852700308446, 0.04944917520568256, 0.028546552376581297, 0.016093163060084466, 0.04086164750098702, 0.015848803994876724, 0.049956352224633585, 0.03967257562063394, 0.06275298532038447, 0.05814834490358349, 0.03245502379873107, 0.08122487819843716, 0.072247116796432, 0.03900431712428409, 0.0271448029971291, 0.056197356447697654, 0.04844252801229877, 0.02322043908099013, 0.023625159500947884, 0.024538299917513808, 0.015362772917855653, 0.05178059909432646, 0.027367868648481466, 0.02407448922073649, 0.03720000386238098, 0.006384130993542532, 0.016854809589623924, 0.03403663147060621, 0.026838341014339562, 0.038826167207932284, 0.048641894733713525, 0.03503892345414047, 0.05469169490219605, 0.00801813477019389, 0.016491032738779342, 0.004010136077751316, 0.050613801220371846, 0.09142878630589094, 0.07153785727437466, 0.028384827385326068, 0.044956797313305645, 0.05903920556809153, 0.05039778357792286, 0.039971093271648696, 0.12513794200194459, 0.08160912491861852, 0.05861764653555809, 0.008153029447121006, 0.046252114097437555, 0.03100334846925351, 0.03143815890765719, 0.0290269871813155, 0.06555946033087469, 0.02228165195593911, 0.11013322900379859, 0.06151118360820317, 0.08594067797305123, 0.02764604283466695, 0.07072772695532731, 0.05654208069186538, 0.04769919289936943, 0.03215411978383218, 0.05669957687777858, 0.04485150235855291, 0.011224760486173534, 0.0580774549575102, 0.020323628897688562, 0.04596898332238198, 0.011844043939134047, 0.01624779024672124, 0.01831847227989666, 0.014067910040818877, 0.050044199526910825, 0.004051783490144918, 0.0492455298832107, 0.02120250028618161, 0.0160406228350175, 0.03160636691797165, 0.005832355687274568, 0.049814553180288886, 0.043874226976186044, 0.015662982665573158, 0.04190429699637237, 0.0788168799913218, 0.033951902146180796, 0.03970678910733231, 0.03475686520217888, 0.048903762738430695, 0.08250755453181845, 0.036179869691090244, 0.06521125038665149, 0.01825030194595456, 0.05689923854304418, 0.02524869133447928, 0.04344233724799368, 0.06989540306911354, 0.1268964585277342, 0.05772297841406638, 0.018905548438910517, 0.14588750237899442, 0.029122246384260156, 0.0610322943858562, 0.06292700985326402, 0.03116528796512754, 0.057953157191795696, 0.054764959720834616, 0.10774571598777849, 0.04296118040539084, 0.00926131831346861, 0.04376958702660857, 0.04019424319267273, 0.04107332908578458, 0.025386119847215956, 0.0272413588038856, 0.056658323043056076, 0.13043679597397007, 0.029949615596823638, 0.059354205600797176, 0.030289339202065623, 0.06227264819186061, 0.037515463547841195, 0.03377529206655679, 0.02557362369712322, 0.09984857522912564, 0.04175993538792095, 0.02579297573726264, 0.024720858669869845, 0.042695125730167476, 0.07693705344272238, 0.08091381585766232, 0.01307994198624886, 0.031325363952125755, 0.015507657381315387, 0.06715402637998905, 0.05121652855567875, 0.016843825804009553, 0.051961031952692624, 0.047010571785992196, 0.04844199941163102, 0.03649217692474204, 0.08187964588644044, 0.09859153219769079, 0.03001198281473931, 0.0915999686525714, 0.04872846649959684, 0.045439907680115396, 0.07547010998091391, 0.045448078007827845, 0.04268278405370732, 0.032947978395367825, 0.030655603923444307, 0.05999564718935759, 0.05944875234197225, 0.05661248034166713, 0.02009298663676506, 0.05202137669848819, 0.02221068923151301, 0.05227472197504775, 0.05066231756861653, 0.03827493247245589, 0.041027869428357774, 0.037774301674817844, 0.06201398243466693, 0.0993939403504614, 0.10544663250085809, 0.09844448162062515, 0.008748514378713745, 0.01742639736602864, 0.06297223968431354, 0.03287893472119205, 0.052921484044242295, 0.03783747328505401, 0.06947618443518877, 0.022757566841920058, 0.02698337486494453, 0.034105736431815935, 0.07066775759261462, 0.029259056280997973, 0.004304542709442397, 0.03779472940931878, 0.09093546398705052, 0.03046424856649772, 0.034364072771202174, 0.05165423672165602, 0.10515263093815697, 0.10580794254858648, 0.022699325007476637, 0.061959797035782575, 0.13399375752816278, 0.04777153841249886, 0.024597371042135264, 0.04003419593397168, 0.039873754139989614, 0.03359742560273698, 0.07362926198590188, 0.08001925498848, 0.06210335425191349, 0.07213972659120638, 0.03498614765703678, 0.02217313560146478, 0.02497659031031353, 0.06270928000430427, 0.07066981836913094, 0.060957803826538794, 0.05736926412810722, 0.1006051023761111, 0.018073804864299395, 0.016850209231638623, 0.030551013769581917, 0.05319865848568659, 0.011695579929848113, 0.023212684355976603, 0.029635272484513062, 0.05077731119649065, 0.10380433917406107, 0.02715340807973858, 0.06468026718545346, 0.021953212825821775, 0.052444498550387166, 0.1832503152470435, 0.24453621537935352, 0.08610513406775652, 0.17276315379046625, 0.1543551794583759, 0.11724528285764879, 0.17709348110422013, 0.10630741655345886, 0.1192821727524842, 0.17540568215472085, 0.098908064406245, 0.22137443565072554, 0.22504675472455643, 0.1438944940004618, 0.18912181228158936, 0.12607045486689578, 0.13426217941507218, 0.11297078037093725, 0.13460831326102057, 0.09322876351014261, 0.10623425515669008, 0.08692402077177841, 0.24160729270548592, 0.12095248957555141, 0.07051788781198763, 0.11135998857958664, 0.12351853172144583, 0.108653376960466, 0.10864851230214681, 0.10623565709759152, 0.19278904453160303, 0.0983170965205758, 0.1605000626295805, 0.13135148963380244, 0.09043290264784329, 0.0947597289397832, 0.10485880557567843, 0.1440577013718505, 0.19451537770369362, 0.1748340886326567, 0.252672222352797, 0.13757488149548733, 0.13833661804035788, 0.08601774641823384, 0.12575304931810788, 0.16296452151671534, 0.08681040993260761, 0.17138767356593765, 0.09227096974369019, 0.1348367760017995, 0.09371884527706331, 0.07855746729840195, 0.19031623528609354, 0.26055572674639765, 0.15479025611233327, 0.20363896394208555, 0.30320270768096375, 0.1390747590771606, 0.20685918388828156, 0.14431044909982912, 0.16127223329197976, 0.18642607145011428, 0.12354788054982502, 0.24409442779517945, 0.1453668843474119, 0.18539205193519595, 0.15085536806333452, 0.18718339532854097, 0.27069477785018187, 0.17373930302358445, 0.20257894340301716, 0.25681392349783455, 0.17064908819813884, 0.10554366519734745, 0.13535503448257524, 0.12446886379151575, 0.2665808856967957, 0.19229114866785466, 0.11476713397930707, 0.11927911606166633, 0.13746474869549274, 0.08988607674837114, 0.14990322802576328, 0.1191635670200471, 0.10115215810196054, 0.17177306175712617, 0.2507153580025319, 0.0841663723751422, 0.09432325800580364, 0.2466339173336183, 0.1175327496903558, 0.15429773818581335, 0.18763684277092257, 0.158338193150778, 0.14687413169491678, 0.2694919891655445, 0.16087832620307324, 0.16796310732681907, 0.27938984514724824, 0.24203754300552033, 0.1201969353602298, 0.16400390364710363, 0.21692752507665466, 0.484668804152358, 0.23025085128122763, 0.11222918427759603, 0.27922761836840265, 0.1149415109126318, 0.24361378423148589, 0.1543231416613825, 0.17705491623811184, 0.11743445294879137, 0.12812950002450135, 0.11624661830043602, 0.21360190675383617, 0.11597080366505731, 0.10147042933010286, 0.1633200935658909, 0.08920334685113161, 0.13450280763208866, 0.1967759959159359, 0.28690970292495144, 0.253613468620085, 0.07413303374402946, 0.18374942152971224, 0.17761855776752197, 0.12016092922778861, 0.1724138789840283, 0.1994473445079019, 0.14596467807648644, 0.11777914654944213, 0.15854519010791857, 0.13607613772394198, 0.1897156836404916, 0.1792586141175801, 0.07422684121035761, 0.12249555153351639, 0.21628073236394316, 0.18670033092700666, 0.12952604000606846, 0.1384788192808628, 0.22714081010030163, 0.2619531936943531, 0.08856355618204802, 0.20196533761918548, 0.31339253509236925, 0.14124275725935737, 0.10811793512754864, 0.13855158231191098, 0.14629386605754977, 0.12344465786290747, 0.15016803397767006, 0.12103606210721117, 0.14568842677099092, 0.10967902313437193, 0.12884825137594055, 0.11643114589875746, 0.12766370324478035, 0.17434025303490702, 0.1496651125771384, 0.13437919168462678, 0.1963490551157344, 0.1640599659614025, 0.10347181871052712, 0.15584636960298787, 0.1342119853342733, 0.1690078827161943, 0.06512238418743496, 0.2365358672555416, 0.1453219609515321, 0.18774003481432316, 0.11215348712979786, 0.23004238343527242, 0.13853745565058725, 0.1350134052336216, 0.15994316267390407], [0.026707407011980974, 0.05108820882836177, 0.042390598119386745, 0.06367512152440126, 0.052472571842372424, 0.07667384861457734, 0.06722102842984662, 0.044732674460617766, 0.03280908665469578, 0.07469259202480316, 0.05349413093720233, 0.00976328497692462, 0.023318153595732107, 0.03471935370696649, 0.020341476831104488, 0.0671276040074806, 0.019907999385689056, 0.011627040916092454, 0.03778154120570229, 0.05687911724371295, 0.06531700882459841, 0.031484547446692185, 0.04744590890984382, 0.04200989072541556, 0.07724210199329161, 0.010251436202276138, 0.06839964704047288, 0.01627084374758265, 0.06564608955335233, 0.028857741121863647, 0.03795329428788635, 0.05751312011852861, 0.01797956647351384, 0.017174760465540232, 0.03362002519650325, 0.06352123361261142, 0.03874197031461424, 0.06285822281854288, 0.05881616672981651, 0.009603599694767788, 0.04528870873693978, 0.0034857148984296913, 0.02788204196540098, 0.06489071153825329, 0.01598060271897984, 0.018901758218905138, 0.09401503785122788, 0.006352236359229973, 0.05750612573577993, 0.04954911903628419, 0.09216452182661142, 0.030846170209828886, 0.05846983753144742, 0.0641281093140283, 0.016496232560565396, 0.04709718568671135, 0.030144824376029354, 0.00594462730899273, 0.040010447208318985, 0.10419648426074175, 0.07187921073167555, 0.04483551027313356, 0.021165879368181192, 0.04613935361586271, 0.054897895127895384, 0.008817028494611865, 0.07221184610839813, 0.0430627215293146, 0.030304352610161713, 0.026952311914834767, 0.0338188901303276, 0.061494463739255746, 0.015181019515430015, 0.06766191203027003, 0.037112298286369735, 0.041175636297632615, 0.2043649548244092, 0.0894694398307512, 0.03994509607793824, 0.06896275996921525, 0.05834317255404688, 0.01074378846228243, 0.05980864129660111, 0.0379615527157101, 0.11365691169856057, 0.015075894057630532, 0.1580482595149548, 0.10067167541673107, 0.027844605163761207, 0.008327309661845287, 0.08333407913244541, 0.05455767548072243, 0.05784494727249107, 0.08218989617401555, 0.024081359114197474, 0.10168799063971928, 0.07529944857402195, 0.05594311484826669, 0.06175839252048924, 0.031136699479013204, 0.01957652463217176, 0.05277749015799454, 0.05646469815063381, 0.03416251503832398, 0.09608759679981778, 0.029634006524218187, 0.03048309432943502, 0.026463134131664713, 0.029858841838675643, 0.02164706876952081, 0.07574633064289248, 0.03453733504659707, 0.04995462852680395, 0.07399159093056956, 0.04360410437408475, 0.05690154829813589, 0.0038880128047293835, 0.1053258664004745, 0.012529084549075174, 0.04146692207864216, 0.04708435371397965, 0.04506059456616641, 0.11476642917841674, 0.04959572399515779, 0.006859636980093896, 0.09290803313976334, 0.03545872431488768, 0.014738100993957733, 0.05835094834647833, 0.019351857857057647, 0.030119587524583744, 0.0643408366088425, 0.0486778280878019, 0.09987942558983642, 0.05608571062405264, 0.04314577695162546, 0.07325492078258146, 0.032135687708373994, 0.09500952722925333, 0.012691800666582442, 0.024998504255387573, 0.010316887881696947, 0.030840024269456347, 0.03762168929942193, 0.02216575051387472, 0.03249978631614678, 0.025945505758206693, 0.026383598883365913, 0.02374439725592252, 0.047588014389358224, 0.0645728923019863, 0.03905755640458196, 0.03052004275002307, 0.08683003710522767, 0.062041887187308846, 0.0020825051638718338, 0.11140654374274517, 0.10289553673036637, 0.008249027924912592, 0.035813047640746644, 0.0023229219885017244, 0.03361942764792231, 0.018145280867634762, 0.05864951579320816, 0.013717538771039296, 0.07364462970966294, 0.07213825570239175, 0.06757993296149277, 0.05077695496560586, 0.057212082038242976, 0.007759806570491844, 0.04146040267040653, 0.05867465879888304, 0.023373836696508433, 0.0889380352811948, 0.04657995759419376, 0.0555545129182358, 0.01349763897803402, 0.055278629334943916, 0.0674531530709036, 0.021993154734973947, 0.03327456550792821, 0.03880542537738239, 0.09401752763698179, 0.03658890318606169, 0.02688985851202761, 0.07273645545806616, 0.011655485760720988, 0.03319678460097602, 0.010349639098069841, 0.014041810382848546, 0.03455609270942307, 0.02924959892557273, 0.04146796395821918, 0.04158008858681687, 0.14597860555494988, 0.045782697552274314, 0.02778460515753156, 0.0635408646156711, 0.03736894157144331, 0.06771220570249904, 0.025440939183857654, 0.05256771996256806, 0.029799925846858855, 0.01616912642343631, 0.007137949540910702, 0.039300605459439183, 0.04274140893211288, 0.08898288972916142, 0.05375674587764567, 0.04946111851642209, 0.1126965132331656, 0.024737530658321998, 0.06600960593430266, 0.04311011555875021, 0.03901283602200208, 0.07251043653776569, 0.08971598990742238, 0.03354682166489863, 0.08162387211116091, 0.06955974164509005, 0.05519902130829231, 0.018946183657634164, 0.029361788671643987, 0.04811798252405659, 0.02233676623643166, 0.024193767195327148, 0.027826473777813297, 0.03583838982928184, 0.10021123359160078, 0.024717999246692466, 0.03279279579498595, 0.020896333247242917, 0.010623123868548823, 0.035086692866658976, 0.030737506383429133, 0.032999704652015245, 0.014104285810683525, 0.09158316834439194, 0.007576671336972787, 0.05901950944755828, 0.06257001288054932, 0.05245247352567892, 0.06352212993548283, 0.033924506842008526, 0.0014090305663675311, 0.09469356192576309, 0.03574104303674352, 0.049314293935294115, 0.031953387510692405, 0.042728193915419044, 0.06814442484849884, 0.09370733863644062, 0.13592532565516813, 0.03701708887914016, 0.021733577333150372, 0.041315516291726986, 0.01389585339629482, 0.073597178223633, 0.055210133413634, 0.030814733791856036, 0.01753154867929557, 0.0260722913944553, 0.023388187438550017, 0.0766126535111858, 0.0763615528722444, 0.05716983611965853, 0.05209369156810065, 0.03297222124773168, 0.05094061432886989, 0.013174637156959264, 0.03919402730741328, 0.07395914710697628, 0.06625755795187528, 0.09512603388077791, 0.02855792495181724, 0.05581794374231851, 0.0429499150824643, 0.014083912659947191, 0.008738805171883395, 0.11205653870298017, 0.022318180943388614, 0.02677966825543873, 0.0017721063270601596, 0.032681559828380426, 0.0487363533747773, 0.05170690143601068, 0.03171702831863396, 0.031810111831873655, 0.032387883853047125, 0.05911212947760379, 0.08196945437380383, 0.04988033331990723, 0.013442267100476931, 0.02109291715427272, 0.06251277079084708, 0.10198989822979897, 0.029160070060301694, 0.050661030540903734, 0.043851615891100905, 0.011707828718147451, 0.016378806603531686, 0.01372127632249988, 0.04755744748117943, 0.022636881180768533, 0.02368209132504079, 0.03442751251221184, 0.06086219988402821, 0.03125879282672559, 0.08170543749245905, 0.054793883370415825, 0.03011730841300901, 0.015499142314037009, 0.010552268396432122, 0.021994640945547053, 0.05280786171375264, 0.04041483054959005, 0.037820692129072644, 0.01863528219532342, 0.08071254157731611, 0.021054237374975797, 0.06809770114599697, 0.02351476240061945, 0.031102181472364935, 0.03482664432076197, 0.02098309078944787, 0.04849501652643085, 0.032928282274834575, 0.050395263148651975, 0.005667550543758778, 0.02538249816655392, 0.01827615932861884, 0.09843390960727008, 0.06379242107692747, 0.022621065295571764, 0.05582699507114388, 0.013887325880087674, 0.024043916566898266, 0.013974153327815717, 0.04547801289346911, 0.03007860756629417, 0.06886241011201374, 0.05846007757129208, 0.0215139284339403, 0.009440920924046829, 0.004650077091590051, 0.027506212636287657, 0.03287178712085851, 0.04847117587022724, 0.0039042761331544292, 0.05554886301979423, 0.06063878949310991, 0.15294836623774422, 0.11140377050445927, 0.13610541760440797, 0.17424440011382106, 0.14365351338300014, 0.15572278429904293, 0.28390262396104876, 0.11766123795701612, 0.13498824690618824, 0.09625189967693822, 0.15008054673671722, 0.09344319918102796, 0.20674875997487577, 0.09182116121894891, 0.10822016190016463, 0.12545697165713196, 0.16491392417059791, 0.10930180910133547, 0.19608385079810697, 0.19675538815077276, 0.159787769399343, 0.18405391083609673, 0.16930601349280727, 0.14665930531919003, 0.18376653593394066, 0.11425835966703393, 0.174103899588508, 0.14661045955313792, 0.1312068675554568, 0.16126031296387797, 0.18325291994598605, 0.11441526979568506, 0.16146686559002246, 0.16577658513861318, 0.15583331546475812, 0.3570705477989489, 0.14226052038852247, 0.10917426312282201, 0.069602650229729, 0.1061615763953136, 0.18091984513786533, 0.17815031471752352, 0.11284850507734284, 0.1479651021861261, 0.12422641228523948, 0.158792820368563, 0.14039454470959403, 0.0903631043770621, 0.21921867955355875, 0.10133623370840665, 0.15402822845405148, 0.11482078311664444, 0.21673486928545663, 0.29968590445576176, 0.13949083675059581, 0.24953017401839458, 0.2301644365633688, 0.10154762801023261, 0.12130825314670803, 0.23245192913999482, 0.22599313378093705, 0.11744910054990362, 0.19358681785243173, 0.11991229539196338, 0.14047961111270613, 0.11935210125821254, 0.15422609364313467, 0.15875571106951084, 0.13763051480054855, 0.2441069303501037, 0.185153492155575, 0.10265283241507508, 0.2517876053048719, 0.12757466084534122, 0.1750707485142254, 0.19006885017358488, 0.314471309463824, 0.21372636539801476, 0.093074235914936, 0.12514301350400334, 0.27366103964947885, 0.17438568204881685, 0.21977404733338665, 0.20667702350164616, 0.3374081351343663, 0.13022969176452007, 0.35251471484380387, 0.2464017160837689, 0.17440175457346827, 0.18184005463075253, 0.4065262424128671, 0.1281214561012964, 0.12329104191233074, 0.18412328775851958, 0.08657402584269162, 0.17842232189591856, 0.26579282637084684, 0.217799685534931, 0.11848541066771555, 0.263389577908862, 0.12054834755197649, 0.11204674809930787, 0.1252541115747825, 0.13444150527638776, 0.2694107532020538, 0.10816836669560402, 0.12126362086423945, 0.2541231775596257, 0.12763961744044097, 0.12332278093503368, 0.24971921387459003, 0.12600650184697684, 0.174013945544439, 0.23023177569191303, 0.1788031135595614, 0.16077579299528755, 0.06733481546924, 0.28003804746174044, 0.14124839566648006, 0.18817979992637712, 0.19022379911714987, 0.1152741309675959, 0.2656431940774764, 0.08757210051220271, 0.10060808245813656, 0.2785376795837956, 0.07728904020041227, 0.10755964089185001, 0.12218174659797262, 0.14935576627331396, 0.14030201661009944, 0.13874888059593019, 0.13680879357120684, 0.18333296081231487, 0.2188086233312084, 0.09373296427750781, 0.19517173119370015, 0.10548725814348268, 0.19942701253439152, 0.11001302214759974, 0.17263506388952657, 0.10013701499349649, 0.18287730703671135, 0.18156772569542934, 0.1658309927029956, 0.19681839122166558, 0.18490049927946062, 0.10167573323293079, 0.2454201735916638, 0.09696754071140483, 0.17291129987326362, 0.21441874034222097, 0.14880903996527195, 0.2077103535374326, 0.09697268882225599, 0.0844680118344484, 0.23358497318000565, 0.16692288249971407, 0.17670164245270914, 0.13546296094934787, 0.14325030598669283, 0.12254707860730349, 0.14148831908260623, 0.14475949919752537, 0.14556306414306164, 0.1588181472353397, 0.1614378615012092, 0.1223704876798776, 0.13853157209532876, 0.07902108072753876, 0.07493776314321064, 0.09657241554269869, 0.14853188467602577, 0.07585313096041642, 0.1659592817867956, 0.10870144131683535], [0.028597209940574346, 0.03550630986630436, 0.010166647506036587, 0.037091583268897194, 0.010777571982133293, 0.0885998457670212, 0.03809016738687793, 0.06598105383736473, 0.04640445451162035, 0.02482266983978691, 0.03921109957680587, 0.01742013842768727, 0.033191636490124854, 0.046883803386721885, 0.05364567845038349, 0.0474417528828546, 0.02636879040378957, 0.059710267946244254, 0.02559035888782913, 0.021302495827718128, 0.04006574726513317, 0.014399297651834788, 0.05214608815168181, 0.02028662876616563, 0.020194924211189635, 0.061629352670523434, 0.015863128881450864, 0.01509596556124668, 0.05468344796569117, 0.0679143839665959, 0.06586696802368087, 0.019449997550597595, 0.030463702728851672, 0.02226066880769307, 0.07769038600306358, 0.04651906509553233, 0.0809462596812556, 0.056032639883098104, 0.010982259184182172, 0.007474674390734084, 0.06408330083133713, 0.012721277814688943, 0.039808085083120295, 0.05743898962053561, 0.011847788193863968, 0.0649542278880554, 0.05302684794690821, 0.0075720111283683975, 0.05518546538247217, 0.0425859198965613, 0.03965054293193164, 0.08692670207951339, 0.02201774424212354, 0.03550130731215881, 0.04513980039665776, 0.03508651283599677, 0.04062141381925152, 0.06235671868067115, 0.05768623683721789, 0.07475302870114965, 0.03904817182750952, 0.014886858031874704, 0.09854534475673592, 0.037781816997355035, 0.05824388755906013, 0.02392687939948613, 0.012923436926587695, 0.010762735731869696, 0.02513391221122396, 0.03176342260332839, 0.08366598672563992, 0.03975386521027934, 0.019568589876496026, 0.0547148997054225, 0.008158060729563718, 0.009850111467042759, 0.06415029138987584, 0.04380088937919467, 0.030390209999055635, 0.08483818551946072, 0.05563869448979536, 0.1324049677819975, 0.09176237929251888, 0.0961045656473406, 0.03196598965704682, 0.06365358296241011, 0.025157061473075903, 0.045034704624765345, 0.10722390285903409, 0.055029497541967905, 0.03596629969955933, 0.044363102154626, 0.06746310455304, 0.04100934159190905, 0.02684502896191853, 0.010924354428425433, 0.02360029420214555, 0.166736094942016, 0.05798004687793794, 0.044170438702548706, 0.036926104446812984, 0.09023563500734107, 0.044241933858082186, 0.08760966946400943, 0.025212378766868385, 0.02132790121850708, 0.02586620033628518, 0.015612377770124905, 0.03380116668619937, 0.030183914012365767, 0.04261118930674369, 0.014042753628605317, 0.06929890402863104, 0.06463431723175511, 0.03941582891369059, 0.01651138194926804, 0.016229342849504565, 0.07055557933786223, 0.028023716520457983, 0.037370435442895665, 0.04411073747060953, 0.06291523508186783, 0.021883508400811304, 0.00922394567169249, 0.0015751958750526332, 0.042891546843513366, 0.08346079773600064, 0.05030676084119947, 0.004633760855217735, 0.09910298781769891, 0.05744781495342332, 0.0418603120581998, 0.002102213493931378, 0.046576031393581824, 0.009024499468655597, 0.057196055478867025, 0.049491068723821835, 0.0060797546851268465, 0.05042788317246784, 0.04780707723130623, 0.06848364092049099, 0.03276392577155944, 0.06889781103499475, 0.020130117003235127, 0.02361307254872255, 0.041989217842778856, 0.05050896208793406, 0.026914733386929, 0.05468352840492322, 0.011014096840705362, 0.07969667068532399, 0.05527216738330261, 0.041497914165618925, 0.09550785210223929, 0.031201575634880897, 0.10839936518741232, 0.04312162986025215, 0.0491602489754798, 0.04869454029587008, 0.05086191411640856, 0.08389594333787119, 0.08506315489930492, 0.054233164466436834, 0.01978151826939035, 0.06830004794943718, 0.062305325672270796, 0.053320428161250974, 0.03867070881589767, 0.05269666405154332, 0.07629100383529741, 0.04028806598075936, 0.046287453733384616, 0.040983597207213604, 0.015990262130095113, 0.05623715854580364, 0.009071227001597085, 0.018021115252087196, 0.008073359175825552, 0.036729878685887785, 0.027839937773082527, 0.042756979669173883, 0.062066306239895286, 0.03814978051870581, 0.030195460872604486, 0.039349282686147964, 0.00416121484088381, 0.03802057212939666, 0.006117952307836423, 0.051849876425319144, 0.06076527443984824, 0.05010110453792638, 0.02106893668702293, 0.019343294909284003, 0.02073642005392861, 0.02544439424039616, 0.11367791782944434, 0.019387885056916746, 0.010362698024349108, 0.06389380898326635, 0.045481498593524586, 0.036629582454840985, 0.028134678610630577, 0.04317777261378304, 0.010327083554359214, 0.01604243367534852, 0.05360326016201608, 0.024651776691297853, 0.004475977386332928, 0.0185613451345313, 0.0017841279224094545, 0.022013421591010787, 0.07557768404724137, 0.008669698295453864, 0.04870080689509069, 0.05102519043571046, 0.022750093654218703, 0.016002537731471804, 0.03814866203033636, 0.02533606557746328, 0.05546138727016026, 0.051641117465952714, 0.040725774146736636, 0.02806711348614866, 0.11480510129683441, 0.028501125277891278, 0.04841374225854393, 0.046908115186998924, 0.02834721821390333, 0.03949423801274069, 0.05090966437672896, 0.029534518515931505, 0.06138178369691295, 0.03290366403938782, 0.0465869443160632, 0.07367935647527057, 0.07947491121388252, 0.06099438069448356, 0.013886540639965285, 0.02869399557370813, 0.02642592715640222, 0.03624542383477092, 0.06666548444979614, 0.014734146065048635, 0.026907809867313313, 0.04363382475510721, 0.042525337663509195, 0.03672480718382905, 0.034366236969588265, 0.012620187725030608, 0.03449967416423944, 0.03673944712406205, 0.025115842112309994, 0.01695688889031449, 0.011476060307975258, 0.13376619877113452, 0.08614161517471076, 0.03956697806115112, 0.04401166698024158, 0.024968594267603852, 0.023868250690640944, 0.061956905053868416, 0.06746830629004587, 0.058217311968966845, 0.0629612616443586, 0.028782792825011477, 0.05134344251165467, 0.03620697388185128, 0.03765756519691598, 0.012939926969157833, 0.052326379283781976, 0.028453706350598126, 0.016569455244368123, 0.08626998852818243, 0.061985690807623256, 0.07664303655826277, 0.030058627993228938, 0.07248465001823441, 0.03850328030004617, 0.08052433675695812, 0.059560754396502054, 0.013977624663722613, 0.06548716461346035, 0.01611332457903172, 0.028770864836030433, 0.029988090447600813, 0.048945254060409726, 0.0486412282372194, 0.056560980080957377, 0.013789120111464253, 0.03801192299673154, 0.043897500727325685, 0.04629462048591626, 0.016656731811141776, 0.07465563594333588, 0.03445605311783091, 0.041323046936022664, 0.12786762818934458, 0.016046712276405625, 0.13076739355681405, 0.05193648649559868, 0.04785671206792036, 0.03911344251865822, 0.054540940290016514, 0.07298506631125366, 0.01563282082638433, 0.028391002053995768, 0.044863464821490555, 0.046159877111354185, 0.024938312727176858, 0.022174504983629433, 0.03438374973953732, 0.09197302282817903, 0.03844100884312103, 0.027588611138203455, 0.05612095449900916, 0.054376315655967886, 0.04552217786230388, 0.03341580530808818, 0.03282348910767225, 0.07787496722753971, 0.04473368569667782, 0.02871454396705714, 0.03823390080323143, 0.06300185664346622, 0.02762260245940378, 0.006985881566745981, 0.03321823506285587, 0.03189685405232012, 0.026324441573852976, 0.06886057916187471, 0.03222263868777983, 0.07850383348282307, 0.020684195840130412, 0.057326252121598496, 0.03267927688636607, 0.028519302629114642, 0.028524004493749915, 0.0021118099421953726, 0.040012971468029485, 0.016558119058308583, 0.04018523782912282, 0.06969752255827188, 0.06076178107891352, 0.0581959879115945, 0.048348084692993475, 0.0415021161578836, 0.09317440957191492, 0.02303458998099931, 0.03519489512508435, 0.01785960093501114, 0.009950319597978267, 0.022742687499210722, 0.08677837979649344, 0.16406618659534764, 0.173968133486567, 0.12787050867993988, 0.10825091266944524, 0.16744696324871433, 0.1423083089532391, 0.1000923444066317, 0.20371051655421335, 0.12031639911114209, 0.12276093205136639, 0.08550245269772508, 0.1514965530124403, 0.12212518632652299, 0.08712133437755608, 0.1201489016473774, 0.09360257611279527, 0.08253793757889541, 0.09599133019125271, 0.17634456887120203, 0.10434833820909263, 0.06442313743454796, 0.20715653325521177, 0.20182990859593117, 0.1935269250985115, 0.1588581829902626, 0.12210340644683569, 0.0803663158008168, 0.23649774672042942, 0.2425909036349866, 0.19158535186321507, 0.12042798747819279, 0.12528452526537642, 0.17256394028663638, 0.10600265911630086, 0.19272077077579117, 0.15118975012052446, 0.13069504421324502, 0.09456158029816805, 0.13873162829587538, 0.17458720913817807, 0.16399794348305272, 0.1362408006623868, 0.14787669563966413, 0.10070935162084718, 0.13586151053107556, 0.0970197802469615, 0.27454161175316383, 0.08263929867215696, 0.1589729429613198, 0.11175803254328429, 0.23279152059506988, 0.09670808205320951, 0.18839114826292763, 0.19846362632609185, 0.11065436797516962, 0.11808633248532012, 0.1354974349059405, 0.27014304132711503, 0.26663193779606975, 0.12685753360030153, 0.12157756369560958, 0.14405780862415993, 0.25242359617785104, 0.1823604581577163, 0.14728469353529716, 0.07438226512843564, 0.1530447247768602, 0.0886834106378017, 0.10407385656670218, 0.15764891320178587, 0.13078784810439234, 0.09598645021117504, 0.12015757376268027, 0.14126171027460407, 0.09150872758078961, 0.1351083848144739, 0.09616864124132742, 0.2648031327032274, 0.14760090398692316, 0.0859262295547993, 0.2619506502824445, 0.18649717973124597, 0.16036886241166823, 0.1704922700000386, 0.18952676635836402, 0.19201005568667767, 0.2051265228299364, 0.21313725910600156, 0.1263573164901426, 0.15896511354273365, 0.21329657475073494, 0.21093181454606597, 0.27622541172369836, 0.1418529156475298, 0.06586913605250659, 0.13723423283907676, 0.24939027104166248, 0.22695978352379417, 0.15178184415544235, 0.13121915560576225, 0.24182075544470744, 0.23614422778689095, 0.17411134596313202, 0.09311860006663109, 0.15705568535674005, 0.08110471730751377, 0.11970755839419943, 0.17230308734841887, 0.15540162491942608, 0.21261340818337857, 0.17186378188911947, 0.2851162910942109, 0.11077172498429015, 0.15259455619079454, 0.08016514877277998, 0.06948858739868288, 0.20607912252026223, 0.15367861656892687, 0.11759379923704172, 0.21192875540544912, 0.15524212541359086, 0.16991278577235439, 0.10075329442418392, 0.12363903735193515, 0.0984745046063777, 0.25610958226025105, 0.27232663705945015, 0.14284464710902783, 0.1496604700843173, 0.20442107842574198, 0.1629892661566696, 0.18504976385062744, 0.21000615050715787, 0.12775418588951712, 0.20481273321615112, 0.1679144147783518, 0.14387347254781954, 0.171956371275648, 0.2307531291679029, 0.16789648832092363, 0.16549717755086962, 0.22316387914601835, 0.16787660067840932, 0.09824159855563795, 0.10124717598720905, 0.08479974322742032, 0.3111099608002171, 0.1148038985387933, 0.09506133009469318, 0.12382438466433557, 0.1282470025903275, 0.11501373768213297, 0.22223205576019905, 0.0809243725492589, 0.1903195907512019, 0.127126116365675, 0.16365092097511216, 0.09956752055234487, 0.11800698109812315, 0.2538085912143992, 0.2069876415114249, 0.10632441604449865, 0.14340546943487661, 0.25815097675208126, 0.15342479631785425, 0.12898125956135412, 0.09841078141283605, 0.17436213250602448, 0.12004151144215178, 0.19334608238310586, 0.1723442722352282, 0.11165114795608867, 0.13845646483523233, 0.17236028347284565, 0.052850846907184015], [0.02781044147277792, 0.02018857142707754, 0.02498481043374106, 0.05232302764911325, 0.040832838764594453, 0.047899452113215966, 0.012143640816512128, 0.02770795614548749, 0.02350842876870546, 0.03571438317697856, 0.03495168136132341, 0.047733567264531894, 0.027440767660136187, 0.06323077520656009, 0.06849209853117505, 0.028504061309861082, 0.00877725991285256, 0.02821616355269667, 0.012981862622132946, 0.04492737953701327, 0.018981019590771007, 0.04795431549991331, 0.027230691029539993, 0.0412002238895624, 0.03776806954955382, 0.018485724595525575, 0.04856261612486936, 0.015733134294409427, 0.03221140783880988, 0.021736622532649387, 0.08005299350066532, 0.02292439972441043, 0.08597817031606551, 0.0336123375041831, 0.020467379551020362, 0.024044016158328425, 0.041704620009348284, 0.028345124878650232, 0.03394468942837369, 0.019306432673587434, 0.0279578578568274, 0.041321890143257, 0.031518588563607584, 0.03783526312139246, 0.012227281338475164, 0.008624546030806679, 0.051788305938844724, 0.07218678737239492, 0.0386359399154542, 0.01867085165764776, 0.04782207340242402, 0.0656340389903034, 0.04283331266994919, 0.028447129485768177, 0.008092745030749469, 0.06442815531045198, 0.061669269681818066, 0.05013764693191455, 0.08074589704553928, 0.03639654999959373, 0.0205188051181575, 0.019280050520695025, 0.027152004223617337, 0.024363267979013826, 0.04429475562046132, 0.021605171420941913, 0.0385839493584729, 0.006977638460680723, 0.020398310978987047, 0.0075240286476459485, 0.0522399569050439, 0.045599610199250525, 0.027271012152214686, 0.00531550632947455, 0.028993997520076174, 0.026843242061835144, 0.024806767769698656, 0.02171955792413604, 0.11143075978203167, 0.03151765585155978, 0.044512757430634195, 0.08203896919205304, 0.014023947127674137, 0.11685987168382253, 0.02853347525571383, 0.01183465361640218, 0.02769252330425286, 0.055715019829691424, 0.057881428379445314, 0.03540458488127878, 0.037379774054692644, 0.05135814373892161, 0.023409461700207284, 0.11241061688070336, 0.06956266044008155, 0.0633916191967024, 0.10685869342377109, 0.09873459145667092, 0.05942946607847849, 0.03400909060972833, 0.03745047630922448, 0.02844366293791081, 0.041675194572176666, 0.07146055900281476, 0.06856680742555088, 0.05069371568219316, 0.07170350080536259, 0.028173272205036015, 0.07912285550827942, 0.021779331934428024, 0.050637546115584915, 0.006132573095871317, 0.029729926477997538, 0.04263738568331446, 0.029567230470298283, 0.05565899581978879, 0.025174218012140166, 0.03316276646669834, 0.01923772033243891, 0.09527994860564509, 0.03898641364949365, 0.04913692542862508, 0.11330191421532824, 0.05251175723969937, 0.045557624750560334, 0.028741263198636235, 0.06324997720038218, 0.026653292476229613, 0.036078393684640046, 0.04327650602546431, 0.06788246108279114, 0.033661141135399385, 0.038234544317087824, 0.02443851121971684, 0.08176440327999093, 0.05421377095063368, 0.02202326582083779, 0.009974273252150705, 0.018567776442655635, 0.05470639612946299, 0.10054617489297545, 0.09495454509892771, 0.046457260952241, 0.036240789002829024, 0.02669742871676722, 0.018790964668075887, 0.0620706039931505, 0.03807824705877612, 0.03201994139911427, 0.052973325214078354, 0.02983463537548819, 0.0522012809561866, 0.06297584029755766, 0.03837823176816587, 0.014447288272241432, 0.07438034990862494, 0.01152727903137284, 0.030820573297058864, 0.054794178314266674, 0.050151260314329024, 0.03616030380550412, 0.020529555246954965, 0.03298325291384132, 0.005592347043866833, 0.03356837171820864, 0.036755171078707904, 0.02157461025842255, 0.03923622343028265, 0.03919836719550433, 0.04687934475500257, 0.026913848555376454, 0.03712108914530085, 0.06005154479475272, 0.04428705260638268, 0.030165807524275397, 0.02079484574947386, 0.012890768064666661, 0.05475205880018973, 0.017204999871131395, 0.035610624228514014, 0.038677392933037014, 0.051387837306866725, 0.03589698789461005, 0.04042008591275062, 0.039740339927976175, 0.05346203951405422, 0.009840140832708249, 0.04139976298076011, 0.030395143605288, 0.026205452797453732, 0.04743528710077367, 0.02494616512840073, 0.03447173876808055, 0.03341082190614074, 0.05943682052255158, 0.04748964103900137, 0.04659533680927369, 0.015138347460437688, 0.0467844762568993, 0.03196863266038558, 0.02183443855404133, 0.050268199805530815, 0.02490011175283261, 0.013438665529622907, 0.02040809583699992, 0.03432302578021923, 0.03502867702815322, 0.022688714689725352, 0.05202101663716378, 0.023002720723349242, 0.01990593860917274, 0.04387883882549021, 0.013216722197079612, 0.07532538831113808, 0.04448517443492048, 0.011278686372773543, 0.05739862827824489, 0.10382700005486127, 0.11740436867600489, 0.07162087822272893, 0.022168535243479476, 0.035151484752855, 0.09247713166499331, 0.03201343731263713, 0.04825451088348224, 0.039718445135100235, 0.04161203445325937, 0.01422138522273951, 0.05289790768837256, 0.050655813482139385, 0.004738367288448518, 0.04086666154645143, 0.06767972357450955, 0.009128480582618186, 0.07053894756902611, 0.02958320531873934, 0.0194941682650918, 0.004517214941687041, 0.010946005030775504, 0.022878602988296942, 0.025741827876998052, 0.06073442407913747, 0.04535135940738744, 0.03211463752743458, 0.03807723582271607, 0.042925806295487194, 0.04093560179875743, 0.061839490588153564, 0.02110688293713235, 0.049428195887876135, 0.034202807432701515, 0.010983964687423601, 0.03901192054693257, 0.040622405903113466, 0.10171579963137066, 0.046764772475486806, 0.04242537085026984, 0.05671816983170087, 0.04658117567399337, 0.11076943438139655, 0.04395592642287093, 0.07674864177862484, 0.0313315999078294, 0.012378969620312414, 0.014150535496282242, 0.11783340855711892, 0.07326640444056642, 0.08071939040335917, 0.03796377437069051, 0.020608090750512578, 0.0484029978754059, 0.046462780615735444, 0.028471895193140355, 0.06618135518604709, 0.04888857504533184, 0.02120392520972077, 0.05068964775531523, 0.018653436563909054, 0.07692805957049131, 0.06663420507984777, 0.02735875411740234, 0.03727729064262202, 0.05608816976628958, 0.026616826691033862, 0.043749377627166054, 0.0358684855933872, 0.04447042341193846, 0.08275074914338128, 0.038854669509155136, 0.020309182394656445, 0.056443217045236985, 0.019810501290785692, 0.05519869572092449, 0.014278777657196888, 0.06573104870415504, 0.025974923534499064, 0.0074580675197554935, 0.07295338857558466, 0.05448436852724803, 0.028914655708978255, 0.01405557219479834, 0.06483206750764962, 0.007913599678901055, 0.03681597930769767, 0.051563700450764555, 0.039438937955926505, 0.030860086196973443, 0.023079425276767825, 0.054162071507063606, 0.07991636171936989, 0.07439385603873, 0.05618366262605114, 0.06698038489107164, 0.09097167696323126, 0.02716940974125699, 0.04602459747524512, 0.04145652243507005, 0.019418722011088844, 0.05800536608383541, 0.045755949592398065, 0.03596186405047774, 0.1382520572552758, 0.008095165868590196, 0.0641597334235426, 0.020497680243645466, 0.07308065876244538, 0.011826850053283476, 0.05197626561106694, 0.05366464678738868, 0.0447030421797066, 0.08167118570136447, 0.05938404855588752, 0.040603904879742095, 0.012102224188105715, 0.023843400713597095, 0.060281160497857686, 0.03219720456869372, 0.03595123458052835, 0.0549025146380788, 0.017661195653941364, 0.04745619747066691, 0.012852597733839385, 0.11536128112986205, 0.03329665565322484, 0.01289087531697606, 0.07202475211553036, 0.017831935584845564, 0.07421394028971273, 0.04890843970520843, 0.04072934028602416, 0.0633167187803455, 0.08261733493136783, 0.20292829481824753, 0.15852845874765228, 0.10599022550928978, 0.18218355313424142, 0.1986621197072729, 0.14309333457100776, 0.08978630145711285, 0.15403847871047838, 0.10255593761441209, 0.11697621745688301, 0.1771466629279237, 0.15202939780729433, 0.1389636916498984, 0.13281412002059723, 0.15850549143168235, 0.13172233747618814, 0.11209404636775294, 0.1244652555173924, 0.0997347575462153, 0.13403756243567314, 0.11601493799037511, 0.12810304700847597, 0.139182930692069, 0.10786321089272538, 0.11713365618620189, 0.2105198431039049, 0.18132187275876924, 0.1270635269822613, 0.06777281857906811, 0.20325078719085266, 0.17104042123161978, 0.10605898190049395, 0.09653440992077512, 0.15609645134498998, 0.10420806751015688, 0.10760365264309991, 0.10402365482502407, 0.2972000717155395, 0.09997399148320961, 0.10317387179501596, 0.1789594414613901, 0.15802147708112196, 0.22686621354472256, 0.16805653941006432, 0.06808838551683773, 0.0761252913563963, 0.17713909397923178, 0.1654105330066335, 0.17617671900699217, 0.14720123591682605, 0.2128124837913821, 0.18350450322031978, 0.08406017726707844, 0.14043222091371013, 0.12646055449881863, 0.2550010070685418, 0.16335813749221065, 0.11925735916461676, 0.17980325666646804, 0.11718466998107972, 0.10537862687581971, 0.18081129047899477, 0.0966927602947239, 0.1526744131960215, 0.13325786878985743, 0.11763815572785756, 0.09345651378915196, 0.12334916500314591, 0.14468117436814695, 0.2658775863387893, 0.18623697030688488, 0.18791197558804867, 0.14545964227328378, 0.1640675961971283, 0.18009509020034345, 0.19621794682837304, 0.08508368605567564, 0.18178031509441717, 0.2544727588012334, 0.10001566666629046, 0.10879556287921245, 0.1844615308988479, 0.1354074808618715, 0.19746098577255206, 0.13725551476161327, 0.1396922872311646, 0.11778837790892971, 0.09190336245322421, 0.19587717559789458, 0.24277741540103193, 0.1243538816549605, 0.124283884201319, 0.1603267275758328, 0.268650334328413, 0.18524972812062312, 0.16208508322315832, 0.23909539765407964, 0.19457591397147025, 0.20823838730012217, 0.17738042699713863, 0.09100246603690809, 0.16702009905730525, 0.18190065218556314, 0.24857109322422938, 0.13570763411060457, 0.18541737880197265, 0.14305694539460445, 0.09175621994560765, 0.1682737559801148, 0.07885530696160371, 0.17100265309695276, 0.0885319627160507, 0.14008994815090012, 0.12479137148587935, 0.2570986477357726, 0.13423484539793384, 0.1097463469411577, 0.17325728050162717, 0.18151276654774146, 0.13364085146496374, 0.08810827778952737, 0.12354869260302476, 0.1415589677109834, 0.13862825239137297, 0.08744529763897581, 0.1465467976466302, 0.0890898202816325, 0.11930863342938886, 0.11692370979055283, 0.08652103554096915, 0.1520294284508113, 0.09302250199740933, 0.11099176075790199, 0.17407776066853156, 0.17231672371347106, 0.13530614275124767, 0.1345649526845063, 0.14188000451653235, 0.13432789443721696, 0.12107489510409294, 0.18966643950871884, 0.19962095535330235, 0.0976329570215556, 0.11585950641141785, 0.11780810467297993, 0.30651769270339324, 0.11911744852700543, 0.19855436177984362, 0.13363668394665565, 0.20591139523012025, 0.08796719503739188, 0.14728777320875278, 0.182071152713991, 0.26971694322363027, 0.22284287298398636, 0.16434257579666955, 0.11287760109670701, 0.13722304795538226, 0.23635062719545058, 0.15298892293245564, 0.16410686586412693, 0.1984658020157968, 0.18309830808110777, 0.133625116018999, 0.15363882596213974, 0.11361221812905804, 0.23689681724194558, 0.15543717139911267, 0.09085443486729938, 0.15339016914367676, 0.3126582551387049, 0.22090945092420425, 0.16366875550198942, 0.06030198659807925, 0.14632883031041394, 0.14845204299255726], [0.029985236770082867, 0.0628295902823729, 0.07937928045829458, 0.0071167140624546, 0.06304944985576215, 0.025521479922557072, 0.045327212316014116, 0.06776979253176721, 0.03332423098805932, 0.043368432745938344, 0.03449248059863045, 0.01984444856193037, 0.044705796265794386, 0.045352041225640044, 0.022801007857666384, 0.008527328515605581, 0.04073286046003623, 0.026373852329749255, 0.04212427148295026, 0.058841279091974424, 0.017075079020052668, 0.08088658143195414, 0.038746834972933415, 0.025411121126624848, 0.006251916187935539, 0.07110597520706154, 0.03879907450849011, 0.06182163690907821, 0.017672926375281908, 0.03663767617376101, 0.10699671948508871, 0.10982687810375807, 0.0918154691856715, 0.009069668970281079, 0.05448175233698661, 0.04524351721028647, 0.025468414927261974, 0.05332457652736095, 0.042837503170895005, 0.039951190307375886, 0.0465437216353753, 0.06469585707471256, 0.024719146463359078, 0.016945273082162586, 0.01869936161974986, 0.11043745784028886, 0.07625449974570545, 0.011635260081910079, 0.06522677898887666, 0.021338632195106438, 0.03532145285017548, 0.03343316103001276, 0.19879593994588624, 0.050664853319645896, 0.09880952251654479, 0.04209729752713635, 0.027454063116062074, 0.05856905357852098, 0.03846334030611381, 0.0007702062453796727, 0.07250667504605747, 0.03787468600597593, 0.08018467635396989, 0.025689477258692348, 0.06390063099623208, 0.033202817543379726, 0.06478444748227635, 0.0486209154159071, 0.042501975812258265, 0.01830118359066546, 0.04926301200964278, 0.02593741395450648, 0.044185101625419436, 0.020110281071655696, 0.011467388192672404, 0.015993614722373747, 0.09838393769196926, 0.06074449813534176, 0.031231317083321275, 0.03301007365207038, 0.050231519515716264, 0.005861214219382214, 0.07392865680758992, 0.04658754186464414, 0.027701258621809464, 0.05762011195803362, 0.02166615585015426, 0.05773366917104972, 0.0688001731290452, 0.05392488685526675, 0.04235708177269947, 0.0695708116155959, 0.05613668994497388, 0.027914445569378235, 0.06247116072523979, 0.04076007573354629, 0.03995943724388077, 0.01123743253805104, 0.04193151610032205, 0.043388891123956254, 0.028637877718034773, 0.04788109281611058, 0.039883667317729805, 0.025436932544013666, 0.08346892592887725, 0.040715837986358715, 0.0197549675771546, 0.015159935818143911, 0.03336019115522504, 0.009875742853769373, 0.03518151156904717, 0.06409469255877119, 0.07145868974827951, 0.058235594657279795, 0.02732316358766008, 0.038569286435602174, 0.03041863186104644, 0.00043302165302579415, 0.04449254037031243, 0.028734138580940427, 0.04054577029760807, 0.05220965429719898, 0.06019632009068324, 0.038778091360244064, 0.02432798963010071, 0.10707780223099456, 0.10644279195055847, 0.012867750952981654, 0.02556987561195368, 0.018636193839953314, 0.035630354823003856, 0.04412772547033045, 0.03440335392951965, 0.05200708149782112, 0.04058812729894154, 0.04422509141506688, 0.04012924829317678, 0.05707815071688064, 0.03452625358477235, 0.01172026328276843, 0.10535477089785761, 0.018971761418206078, 0.07002776774067072, 0.04869820602658776, 0.0314246297949144, 0.028317819589809067, 0.03238304217736567, 0.0949364654239147, 0.017211641853434906, 0.03741984811401175, 0.04535515920349187, 0.019771070745322975, 0.03230323879829338, 0.01851059563998734, 0.07540173663367188, 0.05176969000228471, 0.01200665184672201, 0.027868796305190173, 0.055371126790921536, 0.023194968572727615, 0.03486689074986404, 0.018193146041143807, 0.039255950194332874, 0.02307717872392987, 0.03514873449720683, 0.030105466608919447, 0.0620942990926485, 0.02744503285465462, 0.04272994825676565, 0.06238235198261757, 0.0765309502340613, 0.03190558553943711, 0.0603455578487727, 0.04161532863133377, 0.014215488260942362, 0.027622079604395458, 0.009763729307920703, 0.043969834749136245, 0.028570795228945154, 0.06581670499496883, 0.014557279345970002, 0.1131540745677006, 0.04718864509355157, 0.017757113692500902, 0.04789681294031682, 0.03159376477161723, 0.0069179027547849525, 0.03060524130330211, 0.042795544535282164, 0.02126603004252238, 0.04599529844258101, 0.04196767161990847, 0.0651388933822032, 0.026749235412646687, 0.05034992606529305, 0.035927880390156666, 0.050280418907923084, 0.058564074007013155, 0.02391636675794519, 0.035039911707562786, 0.04038442451987536, 0.07068651142500101, 0.01768683278632741, 0.021883969968785683, 0.019455431029200554, 0.018674140090062734, 0.03193548212068216, 0.04657580156720454, 0.061680734187604926, 0.07916476817861681, 0.07828815674950039, 0.06988539796082244, 0.10609933175146581, 0.0409806975644202, 0.019149543612354228, 0.015372224527621462, 0.018543682977437012, 0.07196003300768715, 0.0587002078311578, 0.06727375826167484, 0.04446856564872208, 0.057094280698126366, 0.03916714145171066, 0.06497932492845482, 0.06287895698821352, 0.028640149168730266, 0.01760483648057186, 0.05105974483153513, 0.0434410885246771, 0.049639525072228526, 0.05651576557166635, 0.053647739226899804, 0.01639367828536178, 0.020414211133855487, 0.032782151003278075, 0.027330753603769888, 0.04901558093185868, 0.038281792789817824, 0.09588538789220395, 0.03433491929524368, 0.018454188586122567, 0.06663478730667023, 0.025632600975973953, 0.015602940524507676, 0.043718354896672314, 0.02849705926623316, 0.032016040096359874, 0.013249399677489795, 0.027559271885923324, 0.07662241347134113, 0.03782945617492642, 0.03468085778877139, 0.11264989678297313, 0.03343993707770302, 0.015579899472575036, 0.005595956275600099, 0.06781325269971164, 0.06869542592715833, 0.06975147813077896, 0.02803356841116423, 0.07943407872751837, 0.08577478163304829, 0.06748899832488069, 0.008101629735451312, 0.04249263337002166, 0.005813743581154174, 0.086221732649832, 0.004986478748070377, 0.02913042245763204, 0.0342470643320872, 0.01745771887081285, 0.07063399609779158, 0.048058955449490785, 0.05946037389578358, 0.03250058304758803, 0.05849116924969901, 0.03479689712666216, 0.04612328492165093, 0.009969729393149817, 0.05257029784843326, 0.09737189723959855, 0.03205274145359234, 0.05086935283015332, 0.056167980806241115, 0.021612324766934882, 0.06012177973565075, 0.04073710458713674, 0.05810982983319029, 0.056600468083014416, 0.04797047612467601, 0.06816636560665024, 0.014042928871217997, 0.03418800661400442, 0.0596358233522023, 0.026243069629755714, 0.02814668320840405, 0.08793791515692588, 0.07637271477330117, 0.04795842173118745, 0.028566022501176888, 0.02400096584742348, 0.0388781615953532, 0.03221190579596066, 0.06566089037204943, 0.04157907352031719, 0.014305179919897309, 0.06414849874413302, 0.035279965358636076, 0.06677144207060337, 0.03524166096242205, 0.03375219451563974, 0.005507756094072736, 0.08028500322853366, 0.014090623590163888, 0.023382072141694448, 0.015966324755291066, 0.044701012046707254, 0.056848052378383376, 0.08807703672397522, 0.06519043577774879, 0.03859673536592915, 0.04376227471737131, 0.06754314541936883, 0.03828470009349046, 0.0546913808061471, 0.02935060187272968, 0.07049560231427032, 0.04571601342890532, 0.03482840249254819, 0.031019219895824793, 0.08988975397040767, 0.018205407278371916, 0.016865021541654583, 0.02750944935776774, 0.022842451299150145, 0.06264300190753515, 0.03810720518231392, 0.004733801883224759, 0.06813322464304586, 0.016154195369792082, 0.035004690815243995, 0.04678017084276484, 0.04027256802205117, 0.01547468399944445, 0.018102046695627996, 0.03647263019135402, 0.04493036727991797, 0.025177912471155008, 0.030914962990209464, 0.03204334346998123, 0.050649972061716744, 0.05257380653112646, 0.12873376719653606, 0.24048866644021005, 0.15103610352643076, 0.1438264500710272, 0.09804577882131262, 0.1869741613946615, 0.10442974271192666, 0.14803616450198237, 0.2757223064620649, 0.13162832316612044, 0.10707819293583594, 0.12611782208325403, 0.06914279063142116, 0.25297645118928724, 0.20332733469624675, 0.1404620830209986, 0.1756752072082412, 0.16912233625208178, 0.1592267785341509, 0.12319369511979243, 0.10763899227904697, 0.16413374022851068, 0.1302343342573412, 0.129494569114139, 0.16878058442906027, 0.2647829999125773, 0.08872100257224615, 0.09557234904458446, 0.08706998350399156, 0.15849389286050874, 0.16654193761848635, 0.17063998707359837, 0.1407454895877069, 0.13384234791080798, 0.2619422539587944, 0.1680825404342144, 0.16005559373767148, 0.11047259063249636, 0.0875115336009091, 0.12534963507806102, 0.15045485729652067, 0.29753856000400364, 0.17783764359210769, 0.14775242085658735, 0.1219184038740012, 0.2116575909237708, 0.18759645461555452, 0.21169114557485427, 0.15174243659261735, 0.10172412700710759, 0.0826699268673697, 0.09824906791289968, 0.24988881041926725, 0.12590920101971398, 0.2342309844830344, 0.10747519501995657, 0.10417942348266802, 0.13924947308917202, 0.19925159372148976, 0.14432275247189308, 0.17395927751016232, 0.10167656060788902, 0.16487364326753925, 0.0750989557033585, 0.10659931137436822, 0.24629484681833178, 0.11294530794745493, 0.13953637301681504, 0.10104922652845422, 0.18246910474713773, 0.09229587526210854, 0.11793028803602343, 0.15357764618050668, 0.1201784496586169, 0.17300408844265247, 0.08348578752409067, 0.18875713910787337, 0.10993085921772065, 0.1414544120310776, 0.13270198007024106, 0.22163763281799134, 0.227069104270589, 0.2365823841143039, 0.15503365756763568, 0.22782699505407966, 0.4201205032727411, 0.2650365137284802, 0.09851725997343179, 0.1632042151064642, 0.10464825397056919, 0.20530191099932119, 0.1548436984059311, 0.1253979905478416, 0.0886920367878291, 0.1822268217802048, 0.17913121369577226, 0.24772191540368144, 0.15868572127674857, 0.1699298082460319, 0.1844785840160424, 0.21867461923149326, 0.1400402290446143, 0.14977090931948156, 0.09346260418814999, 0.20924950078610452, 0.17108038037775025, 0.14706156276647123, 0.12254537789211159, 0.13260542234826472, 0.16951848031772723, 0.15569892832108084, 0.12525529901106514, 0.1409890902258696, 0.1244310190480563, 0.1864294422369811, 0.11985758905329051, 0.11008366311509764, 0.184859620827821, 0.1538421150537268, 0.07067526525427258, 0.18793538723501468, 0.13017436489462852, 0.12590225260224075, 0.1453479313321652, 0.1612935918233087, 0.18093343553764207, 0.17261611087427986, 0.10298906840504178, 0.0834008360341672, 0.14145545391065462, 0.20580941360564003, 0.09381236162998023, 0.27922700549806323, 0.12373632285743953, 0.26318218258600085, 0.1113954890939978, 0.1919080127751635, 0.0896029000080401, 0.12791488815339344, 0.12723539114719437, 0.08621928116847431, 0.13932168453691468, 0.16818553329475466, 0.15677008777856827, 0.12412827642213915, 0.1428653621265004, 0.14026434040598332, 0.30471055257704954, 0.13334232232263013, 0.1358973328024149, 0.15216269710611913, 0.12137537777063348, 0.07798661688162435, 0.19492900389577114, 0.17873546799584744, 0.08316506481459064, 0.1711047113302254, 0.1131944320795517, 0.09531908803769658, 0.12769926504622545, 0.16933895527355133, 0.14903857522914488, 0.16871820955026537, 0.11299673542981187, 0.08153292215279034, 0.20577077213073933, 0.13804792546697203, 0.1226248441924972, 0.08578860952008156, 0.18903309929995768, 0.1641038934429807, 0.14318207819615641, 0.14440783419676367, 0.11543160800131098, 0.11301248619753508, 0.08027780200204543], [0.06733552793100958, 0.01606798366523318, 0.04519870872759531, 0.08733800702518033, 0.018756898653302944, 0.061691325353158105, 0.034151728520350116, 0.022278627823858012, 0.007087786103628817, 0.06322240569598733, 0.029799326383058104, 0.007997317288461472, 0.021693292599652084, 0.03700997575276321, 0.040342619101847374, 0.06764555605308664, 0.04102099761967698, 0.03414172724249863, 0.013773778243170632, 0.05893019125646642, 0.05274690792805726, 0.03823864671792235, 0.08552471521280466, 0.04830375884569461, 0.07711085581010388, 0.05062572920935289, 0.012287832928010294, 0.022158447780736515, 0.04299114210410945, 0.0823747302075067, 0.040735752441950386, 0.05653734626849333, 0.0167422846800858, 0.03161872391619029, 0.0631828832199737, 0.02982919232078618, 0.08865419970524889, 0.025962315642485218, 0.0032803193044533296, 0.0180746111718397, 0.022652227837111683, 0.04673771425000122, 0.006596137208098005, 0.0414591807601673, 0.02695977361121726, 0.06319357014651741, 0.03407458729681469, 0.032284412187554186, 0.05322300859035985, 0.02717029265758972, 0.020982659864990462, 0.04022541531031171, 0.06049045571877111, 0.03966957638641039, 0.03563315104392748, 0.10092033223519403, 0.009661477637447177, 0.018774329068800135, 0.043366452408654076, 0.08579747315736548, 0.07393506896351615, 0.025456184333550836, 0.028636841584117185, 0.09557608755365496, 0.021325989829136, 0.07015883006275662, 0.012055602949863721, 0.07002935354267398, 0.016238756154874162, 0.05508271767006767, 0.050084331042824254, 0.018570348582861405, 0.0465025942051603, 0.05943105954136099, 0.015007741918276637, 0.0399895291775465, 0.025890747708598935, 0.013796041715860128, 0.03371217408247533, 0.04487878657997616, 0.0202383728878152, 0.007494866074393354, 0.035735351003466115, 0.06344597696536972, 0.013069237822726851, 0.01910762519635741, 0.09419786473435741, 0.014617716979926393, 0.012178893309957799, 0.03438661873881375, 0.042083090426580566, 0.08426610936200427, 0.06872791571602707, 0.08829567821756487, 0.02975755926942633, 0.06168417392238494, 0.04986424547349734, 0.02036150045422537, 0.018991126205712076, 0.06641171782487823, 0.024730358160130923, 0.04576225066557527, 0.012164563635334134, 0.03641764040014917, 0.10176710453965973, 0.034253882514613296, 0.013820547910947955, 0.012884832798473298, 0.0546791042471605, 0.09036226168034539, 0.06033564084059289, 0.031017454063159325, 0.08172076691182391, 0.017807384382092187, 0.008208920349246793, 0.06254474347036693, 0.04591936380752633, 0.017288057208662073, 0.02963231155468572, 0.054846004162344246, 0.03292015408195796, 0.022873887717122995, 0.02323471704467891, 0.017155303747483322, 0.022945804221014825, 0.03925484702772191, 0.04992357515279324, 0.05212345791439857, 0.026198513956079562, 0.055199201338954514, 0.0310413425998582, 0.019240466757647453, 0.060864953970116, 0.016049248027434994, 0.011236001868852446, 0.051129171549673044, 0.02503572272196893, 0.05860953749487958, 0.08753741205099129, 0.06304361226577913, 0.054272893786190025, 0.048787803839771986, 0.049536486246412804, 0.03860856759391966, 0.030325889256933046, 0.014802357576216662, 0.04089669219308323, 0.0027320215585566457, 0.025634728785183643, 0.014677904677697489, 0.019707782306678353, 0.08024158136498544, 0.041274986410092925, 0.04873493994255701, 0.027045766980717742, 0.020336359363770293, 0.03427316877810705, 0.03299232722530442, 0.03609505992743277, 0.0025591612399195234, 0.014355153750417935, 0.09154862543988614, 0.030820444977331548, 0.01639129958235689, 0.02845832777600135, 0.01702734408149075, 0.0638352913571702, 0.0365743360241815, 0.03387234008480464, 0.03902864424631961, 0.0204490777105093, 0.03168011437200251, 0.046797829169419505, 0.027720382091619318, 0.03255062008036241, 0.0698224102116881, 0.001328610845619903, 0.03785580576908204, 0.04110455482957825, 0.06156615424720992, 0.050751409763770725, 0.021290056475047624, 0.027804042723390366, 0.010138939063425266, 0.04063743654818785, 0.0617587257687363, 0.03299213570332335, 0.0019610262426149644, 0.02027059837635006, 0.06816644987632191, 0.03376407653934533, 0.025614134426559174, 0.05051084283378817, 0.02506579933387618, 0.03041688518057908, 0.0740918028919447, 0.058086893160737334, 0.02204592670163801, 0.020612308064535744, 0.04217766398083299, 0.0378616510199443, 0.054829878011538144, 0.044067154728597215, 0.06388751940140802, 0.053028472053307685, 0.032904223283572544, 0.03721820611146189, 0.02418966287927282, 0.05561602211767628, 0.05246938108616779, 0.021735904325220375, 0.010877891195817821, 0.03887705076786299, 0.015842169673452457, 0.04179303421668949, 0.12331797756374845, 0.04508870233210825, 0.05626159675058819, 0.022908459349925962, 0.08804630127645309, 0.04948548394285383, 0.05350407475845949, 0.03704348060813162, 0.08411024111293017, 0.036939154754603104, 0.014475016824660764, 0.11498179181569046, 0.03955301610873111, 0.014306811687176027, 0.023798168967327765, 0.028146001390151443, 0.06791154944127606, 0.06290069473306499, 0.013084846864184065, 0.04075703819492652, 0.036882123339080045, 0.03425335391394554, 0.01381249345403405, 0.06705844925055582, 0.08390979420754217, 0.02579811235679494, 0.046653896570205695, 0.029635822152598735, 0.07580985465357382, 0.001178287517001492, 0.06588368406218868, 0.0664420472458005, 0.012184619817191796, 0.011172315064487199, 0.057548092032272014, 0.0358010123994562, 0.03100743363310974, 0.05535291688096139, 0.04585256094052907, 0.04282506190300469, 0.05453596071850869, 0.04182488432214145, 0.010275421457575455, 0.004751482234907247, 0.044711036307196465, 0.031112234461151307, 0.019338688805639263, 0.07946803940520172, 0.03717609042782457, 0.01875274454153353, 0.06558969782124605, 0.06250432084104227, 0.00963185110219544, 0.022425774161914186, 0.08054803185645612, 0.025530588707976767, 0.03058054262862331, 0.05408162844457454, 0.038102141341134425, 0.037485888723524353, 0.05488295258293229, 0.05849093176244248, 0.0494707137676737, 0.005541748851687918, 0.13307226100756278, 0.09499293376481342, 0.04656330667315953, 0.042077900180893565, 0.012728991362476542, 0.04299804838674684, 0.11281589271440623, 0.1177900403197254, 0.05095778618969264, 0.04890267872401784, 0.038442502714573376, 0.03658677729207181, 0.06337555433293024, 0.03551778586341008, 0.027765657887944294, 0.041331661594731194, 0.04140028775098824, 0.11898824013769628, 0.027653437498356068, 0.018584320111380472, 0.10672707951837972, 0.04160459190907498, 0.037568764115173015, 0.059826311114574635, 0.01256641409840555, 0.018008329244630954, 0.08270326701383438, 0.036547798738484426, 0.0466633654169498, 0.01132486423762936, 0.02508988705343537, 0.02434694839100684, 0.019283494085914666, 0.06531871720066955, 0.04379266542532752, 0.17785753123462203, 0.02312653202323183, 0.058678711404002486, 0.03712501534591279, 0.004334783551448416, 0.002209698981342597, 0.04020000800430294, 0.034377724458012855, 0.027790090347069408, 0.023841267158727975, 0.023572333908129125, 0.015179111956498556, 0.027857937008863496, 0.04182296910233075, 0.03375231708970762, 0.03783796358132555, 0.10832231972486743, 0.03741456976821346, 0.09660760962194014, 0.026151077791808114, 0.02713172587626163, 0.003917493543873031, 0.016292525951059598, 0.08163029192796639, 0.055164987852256146, 0.04956252940539872, 0.012662793704939466, 0.016549554195315126, 0.04073457649698661, 0.014335464333154023, 0.040447232238347494, 0.042615644108023376, 0.038364913329602256, 0.06659233837478584, 0.037104219889208194, 0.05718390915482756, 0.07388452248227212, 0.055361669435496294, 0.14729757913418356, 0.11685878383897005, 0.10886714613485722, 0.16016304522993105, 0.11269734060812382, 0.16156503209663978, 0.07753775830590919, 0.14410841639243788, 0.07999906857167521, 0.25391535322752695, 0.1624856552770061, 0.0762437362103693, 0.08140097116871227, 0.16122593093783627, 0.09829687179937478, 0.13033467645366348, 0.27628663747060683, 0.1271318083989524, 0.09225081397040237, 0.35528461298634934, 0.1378199070571892, 0.10684455910156812, 0.14105397787305618, 0.14362775750698584, 0.1899182985747053, 0.13488073412689472, 0.16062470513486093, 0.18103227620163273, 0.19053138341874848, 0.1257150590179428, 0.11905734892934562, 0.13083554473855805, 0.19526139412435795, 0.10538847876652595, 0.17351771975236555, 0.12382056954647265, 0.28298114276220726, 0.055604438868261157, 0.22098065113588689, 0.18851269577299395, 0.1147662070129187, 0.1550307464335234, 0.10331593513969453, 0.12083028322987019, 0.13157213827775371, 0.23698226668901984, 0.10233948713228588, 0.13673109693392632, 0.12699997232806298, 0.08687809380071779, 0.19786564873591547, 0.16391719781583355, 0.13084404831451754, 0.16165074201360827, 0.10616904575257533, 0.20232873908694715, 0.10407969415668519, 0.08015297563566316, 0.07163919538499848, 0.12955694399293394, 0.11811202707430048, 0.1272543824668373, 0.15059198703496687, 0.3037801541147694, 0.1448003623274065, 0.21695807666307498, 0.15640077211203116, 0.23781328822576234, 0.11801590602244101, 0.18354159719761343, 0.1668018865729532, 0.1274991092542487, 0.13529719484429206, 0.16122623737300598, 0.10116292163729669, 0.13307347142648313, 0.19774943319780214, 0.156313621949765, 0.12646413979030427, 0.18322546335477985, 0.1667892154786856, 0.11009348436228691, 0.1023245101133662, 0.1784392984043206, 0.13508249104263323, 0.07872353217774823, 0.20777269777271057, 0.12591982665922374, 0.11565402630836734, 0.10767689830954037, 0.11543978215946306, 0.181706479540275, 0.1772790888865148, 0.18100242941610276, 0.12350409096407315, 0.2499785959239929, 0.1253594410034918, 0.17679268434163065, 0.15163893811404705, 0.18300004964393957, 0.16376036429597488, 0.16415736638009548, 0.11454627083073701, 0.22190124367273625, 0.24250186889642672, 0.1835450292715142, 0.22732445669751014, 0.08732450089507526, 0.19809680810618788, 0.21637983349782808, 0.3427026607096196, 0.22163487490146394, 0.2251091602468683, 0.20313138472697428, 0.11101965401922503, 0.16468399054100438, 0.13631201619582792, 0.09325052806807142, 0.15450593024011583, 0.15073444874536607, 0.1849360764026642, 0.25416396408071446, 0.16493223367198823, 0.21178606386867263, 0.18479399773622715, 0.15238783502530667, 0.16424375045443737, 0.14360431521650285, 0.10666646664181065, 0.1910039830592371, 0.07186942012800325, 0.1145638065833238, 0.10680892069133059, 0.09549765547196712, 0.13327171965952844, 0.167024634297817, 0.16745045660964905, 0.185697031537852, 0.27249410387969786, 0.17259611597945615, 0.18897222595349436, 0.2557277027517557, 0.07994891279527257, 0.09893006645143033, 0.1594274782485539, 0.11686515002962082, 0.19395435619498455, 0.08410755980519519, 0.1262253272016683, 0.13554084144773024, 0.11464677390552337, 0.2094566969261054, 0.1138592278584838, 0.10556189042906608, 0.28847448347556975, 0.10237477314207824, 0.1096718755340384, 0.12169042376861458, 0.1432804898509095, 0.13205002392491988, 0.16934531380332288, 0.1769319897697818, 0.12224483393853712, 0.11552200637637608, 0.09869435651888771, 0.10211859334019885, 0.14643049017796594, 0.17838288368957658, 0.1124073993114214, 0.16251202402335985, 0.19043347738202543, 0.12511328929254126, 0.08564240930061187, 0.16236272880867605, 0.13057596350629486, 0.12345152201070902], [0.015879053934176844, 0.01694280053338697, 0.07459371305641628, 0.014774268004863013, 0.023137054240871823, 0.047919148233749216, 0.046413846749572024, 0.018430466673547224, 0.06048204024292289, 0.07173897833713601, 0.052420006719447916, 0.020009705218516534, 0.01585842127115616, 0.04808814722984549, 0.025200517810580712, 0.04264849395821652, 0.035755142884989904, 0.023257274503609347, 0.05487633741370613, 0.025261050247917735, 0.05887876760454909, 0.045715036666801864, 0.05794770647621444, 0.031428711128331004, 0.05153217976312003, 0.0907649864412604, 0.04597704256734541, 0.02276147772077351, 0.023777781452442852, 0.01780335475961047, 0.053992639671290116, 0.02510611662611125, 0.08396132128132928, 0.02174432554672803, 0.05095045472825727, 0.03189088622738998, 0.039559064372893304, 0.012841632142813217, 0.06235080448189571, 0.04527950419052955, 0.023384558097008738, 0.007051718684153692, 0.043885055628995744, 0.06255971665884699, 0.03205820557571227, 0.023742010892038385, 0.01137425392610772, 0.02008385869914726, 0.008093334918451166, 0.052220609354516195, 0.024330410467941436, 0.06490696792400653, 0.008413567331679648, 0.04512647046677528, 0.013090300452595037, 0.0412821225191076, 0.03529421076358807, 0.0568293176981951, 0.06906952964322222, 0.011003754653727577, 0.06625088532605479, 0.08387211034254682, 0.04103677137003791, 0.10679567503111978, 0.08024702825012707, 0.058698480302888545, 0.03475700309800525, 0.04252906468126082, 0.01971506780283826, 0.05353798947086739, 0.040675844366271655, 0.14899631781924158, 0.027192423022502375, 0.04877176578907717, 0.07520741843167814, 0.03696373468565364, 0.09557355946350483, 0.01837792836370007, 0.0753928270311125, 0.042514869072023904, 0.014920709542028848, 0.07718262292685048, 0.04485191987647165, 0.049485223472959576, 0.027694235510763623, 0.03254608867029029, 0.030133490105189627, 0.032783836396711494, 0.06888595965480612, 0.03462558837547418, 0.022944745104459506, 0.022675195153081612, 0.03087638663278232, 0.022273299682344642, 0.0526245521952308, 0.05555749300026125, 0.04565506730408919, 0.05806667226997595, 0.056100480799232764, 0.0883154049816151, 0.03394506098101697, 0.02246544219463343, 0.08068914525210857, 0.03691101251470466, 0.038174103810301716, 0.04087834055685709, 0.003411533168306755, 0.014486536871822131, 0.022254381141054536, 0.050543256013864474, 0.04485738591381139, 0.01238380459272453, 0.014486608692565033, 0.05077507038931212, 0.03395563682481166, 0.10672814438059446, 0.023402685652517026, 0.11927293373211739, 0.01556688363874151, 0.05762522559492819, 0.022110406407004884, 0.15475449512802786, 0.05247359840019096, 0.010661213760144048, 0.019188761568417954, 0.0428420307505275, 0.004189909142892688, 0.029975425098992647, 0.02062058564455759, 0.030744502681397626, 0.0451056941622688, 0.019971412313621373, 0.024476585789553584, 0.023764731144652735, 0.03042894915016669, 0.04665412639658298, 0.08722880885245339, 0.025436304351915757, 0.03181921487163392, 0.023032305123765143, 0.028117518241126693, 0.03407545297616913, 0.04688004572545329, 0.02167280166289739, 0.07910652251373376, 0.05867131865553318, 0.02990406783928554, 0.03732276562180731, 0.034441976252222256, 0.01462920446835098, 0.017779606033957774, 0.01689492003811944, 0.03400722135519309, 0.05481051130881233, 0.03199717326600465, 0.013686384847988526, 0.05545422817850786, 0.13786328295546194, 0.016921070449414755, 0.07374823544054263, 0.03339831552077686, 0.03684303370274363, 0.015470203342697313, 0.01660170754598033, 0.043153311426360766, 0.01641596569829891, 0.024959479736524726, 0.027596695281024423, 0.04304633873905386, 0.010327990410939581, 0.056152318138629205, 0.03477156642944582, 0.06675441959692587, 0.0447199190966785, 0.027957484388964313, 0.11868178198534636, 0.022945043878749977, 0.014459390546225253, 0.05495022276356336, 0.12358242345433082, 0.0317321949443149, 0.021875700049643076, 0.05716161982667062, 0.03299400878829822, 0.05245674446585679, 0.010876727699782821, 0.02449700777839509, 0.050434456206858165, 0.002464571406298708, 0.06302330710534608, 0.013138048797695628, 0.01582007090966668, 0.04603195958019746, 0.03097431182170347, 0.04690531513563568, 0.008276342789852812, 0.029858554555704037, 0.021207205981256503, 0.020230920767531763, 0.06046954534887787, 0.025294857708016233, 0.07069598027174512, 0.06404392774246874, 0.0872723532900695, 0.07962557006507151, 0.05105863400404492, 0.05028007799879678, 0.032618181374404705, 0.06515048429249756, 0.03823531423545173, 0.03002694834234013, 0.02309705295990552, 0.11260157195670951, 0.024254211532552878, 0.07003909052019158, 0.037349214807393095, 0.06943928964075542, 0.012582232856432037, 0.02254757639621535, 0.0475246895615372, 0.01733027822938898, 0.04416229135747399, 0.01109413291898466, 0.040054734751221635, 0.016005614532097694, 0.029664504484483795, 0.06799281604828374, 0.022481064642629316, 0.015514457369253281, 0.06286206857992277, 0.010978844347259691, 0.050592251167061834, 0.03929852553072476, 0.028082146046442852, 0.02813430131232787, 0.06059926701709629, 0.04639675532798133, 0.08662347681820394, 0.038833743817503416, 0.023772472463127588, 0.020134815037430778, 0.04491142192555051, 0.020113174968789664, 0.05007230346241305, 0.04748399497099942, 0.028602302510050998, 0.03856635231885218, 0.030580132771583817, 0.021530171413154855, 0.019309621514572252, 0.05357589167092116, 0.028844053045876568, 0.08285212555840131, 0.016948142081439015, 0.06650559423911957, 0.01182888018628282, 0.053260393681064735, 0.08301757756740817, 0.025434697482494578, 0.05917293387615393, 0.02091933695238925, 0.04958683354479652, 0.025592231972803994, 0.03562570849974309, 0.00923451002416832, 0.05372946165622242, 0.00646381993823114, 0.04760328635212876, 0.024382109911511504, 0.019970730495368762, 0.02902428097572298, 0.03774688338800784, 0.04714986189238487, 0.10500924226136939, 0.013475094925642256, 0.04211356157376882, 0.03428829901461159, 0.018124937402805495, 0.04285932135497851, 0.035150956152187246, 0.06580731275701715, 0.04132322313624524, 0.04211455365763076, 0.0255445908800128, 0.04232708176958465, 0.023477365818595695, 0.04152858066522787, 0.02582941853982066, 0.06474561448539458, 0.06004843447778014, 0.030478110927487576, 0.050570873483534784, 0.03821722689955946, 0.02870050349062489, 0.046270887082022046, 0.029088544261251247, 0.016405887811655, 0.07772674453594992, 0.04929584653807744, 0.03728503196109687, 0.022443371201534907, 0.022055916488170627, 0.04515627511746941, 0.07974403790168225, 0.03829083645776395, 0.052848843587262016, 0.0485094151489677, 0.036152443743401, 0.03576784462277447, 0.01816195285608692, 0.04710995254196948, 0.02811829965080946, 0.07489290103436479, 0.016464771244735006, 0.020360364728877624, 0.01724511031962691, 0.02917568484741834, 0.025998946136584686, 0.058453960359216704, 0.01671393751166761, 0.005277355150845383, 0.04193894332274795, 0.05733948246005082, 0.03552723172751646, 0.037740544010434425, 0.08410706950892365, 0.03245261062176959, 0.06078010207162269, 0.045473037152400905, 0.011952725960122002, 0.016711859498173, 0.13066030978675813, 0.037027764314365004, 0.07574639959080566, 0.04487498678387173, 0.0625018923423223, 0.04356190442077575, 0.008477525139648107, 0.01958106370312312, 0.03734264560344239, 0.07520891230313048, 0.025251680992603786, 0.06745040281525544, 0.028107480574098807, 0.047929762381940126, 0.023589498108072628, 0.02286289435540957, 0.029399669804279844, 0.05882922086804625, 0.043653570671355536, 0.014066461177032082, 0.08115649719031588, 0.12692576905171718, 0.2187665804259239, 0.204996012091156, 0.20771435251639736, 0.20506617042326158, 0.12417866202491908, 0.2259461572694202, 0.12583833788671803, 0.09888934887825482, 0.2063608436935371, 0.10172927511795875, 0.12454400935600843, 0.07070631479784366, 0.1706596755332524, 0.12121380216652348, 0.08580887254567877, 0.13431663294473004, 0.12955498280784777, 0.13577889560932113, 0.10790513888482126, 0.09186286704554673, 0.1394543096783661, 0.16015161519810078, 0.1365477874154045, 0.13025100433057354, 0.1112389773310673, 0.14401499963095113, 0.17064207083275243, 0.2002609298834878, 0.1335335685120475, 0.11538601044805781, 0.10995425554292818, 0.1277321685225733, 0.11741462659331099, 0.08518766716963823, 0.13249125992578845, 0.2055406086747685, 0.0919000682751498, 0.2339234155031943, 0.11324952912306595, 0.12747398923121153, 0.17711157610099162, 0.2134786891720949, 0.1396349991761869, 0.09828646832536306, 0.190058599917158, 0.11747738451606805, 0.1332191507061643, 0.07873336108581674, 0.14212850811741046, 0.2162744044776886, 0.17541980881604458, 0.10406341478829423, 0.15582314181712367, 0.11798829621364994, 0.17561807237084837, 0.06656789250912205, 0.17487815401006132, 0.21799782651566693, 0.22831537610580846, 0.11454324478343611, 0.27231986484219955, 0.10840832075524716, 0.25712481729926606, 0.17483928270878332, 0.15741873442405657, 0.18514992218584786, 0.18896773667825809, 0.14813636880247824, 0.16875017073846635, 0.10833231717227929, 0.1466385903017175, 0.14843152715794503, 0.15884761097690753, 0.1751774492403192, 0.1350431294450837, 0.35172303958285245, 0.13933407983952953, 0.1874869040423824, 0.15555568520099888, 0.20851257016822217, 0.21059504229455225, 0.14575833995496074, 0.13920940669073215, 0.17930563659437243, 0.11326232279140143, 0.05905216777577035, 0.14565523984211107, 0.2466998162168649, 0.17212616700318553, 0.15361711503036563, 0.2167463912478378, 0.16832174372769174, 0.17726453321595348, 0.12391713492932821, 0.11158191659037145, 0.14291275232549638, 0.20773558847365842, 0.17212955311181086, 0.1509792904459661, 0.14082214434541043, 0.11331166651460434, 0.22935900236329726, 0.1260168057295584, 0.14474547978851104, 0.12157938698486936, 0.13782553014255342, 0.08882958787463366, 0.23653978962571393, 0.17765952814971248, 0.10953105325179716, 0.14718975991972033, 0.1211451683493872, 0.22708635657064377, 0.07453501539965791, 0.24760494909940228, 0.10768972262139283, 0.24344391189515593, 0.17617129510448826, 0.15136339160944187, 0.09422863848627576, 0.23557739933171581, 0.16238741216159638, 0.17848782241344455, 0.08739734053491585, 0.10170731137716964, 0.12873813389770447, 0.13564600999797546, 0.1180666057212699, 0.12943668351058038, 0.22184936419850398, 0.0783525004742607, 0.14472042871338708, 0.11268344377317738, 0.09612655237076745, 0.11426671768628782, 0.18847354868006325, 0.08424756237335744, 0.08648479958215068, 0.08608239657816388, 0.14089181238124449, 0.10152393291073461, 0.18534266990759682, 0.11358284631804114, 0.14611287012455926, 0.18761021355467458, 0.1842155707098784, 0.1405720779251668, 0.19379303339988957, 0.13779819612541508, 0.21048550704313865, 0.0870219880955354, 0.09892595255927694, 0.17930813404100557, 0.09647254832088949, 0.12316522729252616, 0.08846629365918138, 0.178992536459719, 0.12475481377013269, 0.12746234469476247, 0.08718341814293977, 0.09015210078007753, 0.15023364174750545, 0.18697100511241346, 0.15377541943903894, 0.12514456866248963, 0.14733252806528924, 0.17655617767764678, 0.14340735401117033, 0.11200867352947114, 0.0952397519722581, 0.142438835013778, 0.13249167361326758, 0.2055369927397659, 0.1251889328141847, 0.16128266740950847], [0.07543827136678082, 0.04741408944790883, 0.025009978337273486, 0.036307561226309314, 0.04619352369298858, 0.04684956308694617, 0.09051026220643714, 0.07044804357593099, 0.03492883661942136, 0.019737611855230024, 0.0611772803559659, 0.05161453804541981, 0.026542167592373107, 0.00985784512463837, 0.027953985282370163, 0.02700373365153228, 0.07544083776132715, 0.029250780616195935, 0.04470932793112532, 0.023178961165549777, 0.04953964252866084, 0.03638957093860354, 0.04715803605053694, 0.02117090682018428, 0.025670305908387227, 0.021309128233922586, 0.04821845495532598, 0.025091357942249988, 0.033543990970018416, 0.050243512622170874, 0.008316757758298229, 0.015011578103557471, 0.03940415373372455, 0.0959866417331561, 0.028891740103943214, 0.05552000831812621, 0.03035263913202911, 0.07955331265205338, 0.05149944865655515, 0.08841642133531072, 0.03246259274742296, 0.022977150623656573, 0.01822013723393602, 0.025177925877693682, 0.05524294495943093, 0.0302573167268307, 0.043516172802135836, 0.037521982956076824, 0.0200045628533248, 0.006178346849347075, 0.039094972138803814, 0.04878721012163067, 0.05244203174727098, 0.09671460146144514, 0.06871590345737434, 0.01776295894336316, 0.06555030558017955, 0.024010047819765828, 0.026143321151574774, 0.025357282382526228, 0.04286679071224025, 0.029933719272394816, 0.05629967132042493, 0.04974281287661964, 0.08851867109056442, 0.051337141438477465, 0.0859174425263078, 0.004694715119718064, 0.005215721940922161, 0.021098909877060402, 0.018075706677571423, 0.04445155849680305, 0.027572670763718988, 0.04747329655313685, 0.01567914041750614, 0.06627201403100645, 0.11434346437454225, 0.08560006762103689, 0.036290167199988524, 0.011818083134599993, 0.07495018142846323, 0.04314373915774688, 0.03820867735832449, 0.009051825824914681, 0.023262083620554017, 0.03970036546008722, 0.02040217780778485, 0.022486440664637956, 0.022940608229668393, 0.057795354570712776, 0.04069596183516326, 0.05270667682071367, 0.030335348527578097, 0.035695958762399616, 0.0769501765288653, 0.009715759754931975, 0.01372318962709077, 0.043447064010486494, 0.02651335885598054, 0.03468356590958373, 0.03517191631779556, 0.030766843720489455, 0.04837493607473951, 0.09508901651227668, 0.07999569012392914, 0.03309458464143738, 0.06186295586127428, 0.05539348889743129, 0.12273017362120653, 0.07330610311680263, 0.03252906619661278, 0.02386692918897156, 0.06608463658560669, 0.048398202164999904, 0.040904360733205275, 0.03956623878630419, 0.02497350297597868, 0.02774806084832357, 0.07410983660168226, 0.006912871472342241, 0.010321777437873667, 0.038017775908473044, 0.05359108319445964, 0.03263137723890043, 0.022606804568861282, 0.05792348277604869, 0.0400764188699184, 0.018333554635905934, 0.015659877136650107, 0.024385256617660486, 0.029768209806793643, 0.10048284240427519, 0.04595881350518716, 0.05216930444622713, 0.05051685279355415, 0.05771935864862415, 0.030114318754884507, 0.030131458056970473, 0.03156163887451253, 0.03059644278349175, 0.02575954366024704, 0.07452498730872908, 0.06648524694385068, 0.021867560365447597, 0.0484123939437972, 0.07046524224983108, 0.057990580586896795, 0.03154205575194811, 0.06128529492284983, 0.008523204089743237, 0.010358115860952005, 0.03291031368257057, 0.020309287731746034, 0.01303771521986252, 0.03681131000179918, 0.024799219888424682, 0.07941973756157583, 0.06067534337841696, 0.02340135840518821, 0.01953945938317526, 0.03003916361429278, 0.01524787026292254, 0.04148032861731706, 0.034608998741473884, 0.02924137497170558, 0.025920272737200704, 0.029506560137134888, 0.023674729220088453, 0.018058180501083695, 0.011224042278744522, 0.07969087139973718, 0.01291001985420383, 0.044507567184947194, 0.0459796894011238, 0.018478400794969454, 0.0180874967707261, 0.0868314543678876, 0.0714591340792756, 0.011770019735840541, 0.029880614057483695, 0.03477786750262303, 0.09567593179282644, 0.04625240138040916, 0.005002162483100209, 0.04152724001136038, 0.009977780977234004, 0.056405257388588884, 0.02082147879616147, 0.06258968601844485, 0.04083947308601872, 0.06486674830798181, 0.046208002754757484, 0.058746762994316325, 0.009067086296366348, 0.014872914274042894, 0.009273998026225356, 0.0450428404785212, 0.024573880871157014, 0.038839416698582714, 0.026638778940504117, 0.020638755334901716, 0.023302314727897608, 0.017133079536799944, 0.012607716771233226, 0.050648493512022885, 0.03837878335147135, 0.04181384882559219, 0.036329015518628785, 0.13728381404953618, 0.07370551837788475, 0.05558898687482842, 0.047713304238934676, 0.0283161073832983, 0.04305037602241482, 0.03540925418717727, 0.04599841258999321, 0.05602557272199662, 0.019661453139457493, 0.030227757224272338, 0.09924737240878806, 0.024462744495981646, 0.01400959063997312, 0.07241581701823781, 0.05773033285813947, 0.049494355241017, 0.05210910142669755, 0.030241870479057395, 0.06351399408172696, 0.030421728771480343, 0.028457247592028112, 0.03324412500425693, 0.026262905561335148, 0.09283778287710683, 0.03625962327444746, 0.010308427398183174, 0.04785452105645691, 0.07758416791236208, 0.01945727538587826, 0.01753322641184974, 0.15108326389904947, 0.014781455824812575, 0.025018403389220758, 0.040516229947247816, 0.016798414027078018, 0.02330445211320635, 0.031184097338888436, 0.0164445101343576, 0.04114888833775636, 0.06409764199727966, 0.11039958245331243, 0.05680108735818536, 0.018946198979392648, 0.037724567246773553, 0.04022171510563743, 0.029685424430476084, 0.04725450950284158, 0.06914406233737547, 0.07201549777340505, 0.033694871986705455, 0.04413411081317933, 0.036246990484576073, 0.02926849639944492, 0.02135532142053689, 0.02948853408827657, 0.03461820711832374, 0.04792814593641989, 0.08853468232818189, 0.092979738969476, 0.04779961936536336, 0.05681772295746112, 0.026544954237197677, 0.0730471960419128, 0.04106846825790502, 0.010423795451530287, 0.008479103280772126, 0.05359328952768157, 0.06413015093834651, 0.09735104432629962, 0.0019487015637306257, 0.013009581598453225, 0.014642691446257936, 0.017436412050418796, 0.086893844568441, 0.05640020503872826, 0.028922845188888813, 0.04210321555635141, 0.049570929559488455, 0.04481823499044103, 0.054628258991626, 0.02633687518086405, 0.09779749738593256, 0.02193173172042495, 0.018907157223551505, 0.05459950771182776, 0.014307712798096962, 0.07023694038751625, 0.013245369097398174, 0.023703221945212256, 0.0376024987969187, 0.07233336297494751, 0.013753667477548364, 0.04345095573714183, 0.07016813803103662, 0.08117767186054299, 0.02356465004624859, 0.057771709266929865, 0.042171401212052, 0.07150745890553921, 0.025513612199574712, 0.039823219150064454, 0.03499891834273454, 0.07613299820091456, 0.03593882778659463, 0.05457473242835653, 0.04325651879151983, 0.044011034957704046, 0.031056212366468487, 0.049622766898884896, 0.051012921537603104, 0.040393376257270575, 0.033536490969239705, 0.06810774455868429, 0.09837531154194186, 0.03259933178102778, 0.032218723978486755, 0.06582703186018814, 0.04195894970889053, 0.08705071639269592, 0.008255338574188852, 0.0220337727167193, 0.029901311837977944, 0.06811709849223976, 0.003763821812519323, 0.03873114166180453, 0.04817003436807183, 0.08772789981336364, 0.009201852653566147, 0.060986256332046566, 0.027150901057006373, 0.03326639134977614, 0.06753058923828988, 0.08723257800504085, 0.10724269499581669, 0.030066162467964237, 0.06947635297453211, 0.024632467445166364, 0.023884539635130958, 0.03507594465308132, 0.03624681045391387, 0.010858783047766456, 0.05197128986999874, 0.05106549049096723, 0.17770707156629334, 0.14656524504384688, 0.08157825157527002, 0.20439132357076292, 0.17139384823460735, 0.13950784390251483, 0.17286033970454048, 0.16248216191607137, 0.14951261511493116, 0.08103147164107331, 0.19072731806626245, 0.1251999721411736, 0.18088638241733276, 0.09834057711545499, 0.12169957085843049, 0.1074449345469475, 0.2795567910277075, 0.06736063263228825, 0.17794661193845734, 0.09043501705051431, 0.17515607538723177, 0.15875577235654478, 0.09783461434586395, 0.21030587474665335, 0.08905126307640346, 0.11477874021135992, 0.15212094531424586, 0.18152949790800774, 0.11865548984778505, 0.10460615743912997, 0.16651111024041332, 0.13575508559663452, 0.18079624451216192, 0.1628276369264049, 0.11045611974212433, 0.3157196957017145, 0.10124546761113791, 0.1663236332035834, 0.13566805800843623, 0.1319798349492973, 0.2257077353856256, 0.14683444834043904, 0.07872570786745318, 0.2132712478839582, 0.13258827730051934, 0.09053139857226804, 0.1633606655823608, 0.14863051083539763, 0.16560332669365793, 0.11486828822882907, 0.13061897168236394, 0.16000694715447966, 0.1359648404703025, 0.2889438808685349, 0.26206017021209965, 0.143664866806038, 0.15050610857865504, 0.11915193014447728, 0.11316463892017642, 0.10772670934637708, 0.15299712007324542, 0.1437758729462662, 0.140913630565328, 0.2535146432778528, 0.1970155516098584, 0.14595114896374364, 0.2741638691194596, 0.10183415255479275, 0.08328329516394485, 0.16582380679826583, 0.06882830387762479, 0.1677531073050153, 0.17956039147271266, 0.17924041186849918, 0.10696134154474544, 0.1977246579143309, 0.16766488461965517, 0.14444669017628317, 0.11746346469848387, 0.13197522309999313, 0.1960703063636057, 0.1236315833164319, 0.18367377800806878, 0.23206350724062613, 0.17801655576594416, 0.10543522545166555, 0.19078993809319314, 0.10386284530883837, 0.1438486053337974, 0.12819508481169903, 0.18485384452487194, 0.2741972705529582, 0.13406949298035714, 0.22677819004222272, 0.12419940002502934, 0.1853028639790512, 0.12864784277494878, 0.13016762332089488, 0.08797073436360206, 0.1658083165004369, 0.22094072263327338, 0.18071824143971169, 0.12538544968852114, 0.20561490388166523, 0.13937828311276051, 0.1305616529838693, 0.19800913700413322, 0.13599536141320584, 0.26300236642841374, 0.1692722290153465, 0.17241948674763405, 0.11149776183188924, 0.18521903863837644, 0.2242760396292133, 0.21836223921948866, 0.13478707221727218, 0.055493877059029, 0.15958723822428336, 0.14507318155900126, 0.16394922029106848, 0.07926763846508919, 0.07930832539474772, 0.17040430778457274, 0.1281496557977892, 0.1071872532127365, 0.12048179749399425, 0.17958869076063558, 0.09449456292655199, 0.11831002249833077, 0.13759781816794028, 0.21014150292161973, 0.20900844355985043, 0.10994789701315666, 0.18490031541835877, 0.15170921902022055, 0.19256519364012828, 0.09327696576233833, 0.10463060330479376, 0.19762187955840943, 0.1233452962591283, 0.16272700361667142, 0.13046342519021806, 0.19780252309095478, 0.11210680173169221, 0.1219570606706604, 0.18304742452117706, 0.12997197978679212, 0.22745156600590677, 0.16692067616649214, 0.11407737905580191, 0.12128338593268588, 0.11677830630252439, 0.08257719192413554, 0.08821800456292207, 0.12406617733499697, 0.096599496750822, 0.13600695998437945, 0.10260632321719201, 0.1864914034282969, 0.18365392100907144, 0.13632476389888795, 0.15783885704173198, 0.16807892449921177, 0.12470519425527704, 0.17943168870143353, 0.18038767450038465, 0.22055528847680939, 0.11514728978997278, 0.14317064816432615, 0.13569340019697143, 0.26691015028665144, 0.14820750772712693, 0.11226168938822324, 0.08864145200218886, 0.08327618586800753, 0.1966049131606856], [0.017774559429756576, 0.028495726273244912, 0.02994298510583899, 0.06264472177492515, 0.03928033860340234, 0.011003768060266251, 0.031496984884142876, 0.035313290183342276, 0.023144711289675008, 0.04272353993127904, 0.020179543080889893, 0.006591823175474401, 0.0492399987283974, 0.014183582614115892, 0.013763836337133281, 0.02969316766417075, 0.027671946182606683, 0.007979489943658514, 0.07416041372644325, 0.006504230597431982, 0.03714588358097019, 0.06184304906656185, 0.019050545900339083, 0.05053260739171698, 0.020013110479339957, 0.05542054712291687, 0.03829039595720749, 0.026871451334426963, 0.01713972726476289, 0.07428372323873543, 0.04996440380871777, 0.041563181026328, 0.047720601226413445, 0.017512919336196878, 0.016750954880168843, 0.05574352979179352, 0.027217204051633036, 0.05467701282712722, 0.03702185394602918, 0.046293164918860125, 0.024807363403059786, 0.027642225801584222, 0.01435154834912429, 0.13508350227869328, 0.0195883798428, 0.03815612372671885, 0.02715613535274902, 0.024015343402542418, 0.015019122154391823, 0.027182619012291395, 0.035294111172157916, 0.03584513140301551, 0.04140811716957439, 0.06517517530629713, 0.011628791426999435, 0.010650794964373834, 0.03845297513649829, 0.05504902895359744, 0.03993387288984753, 0.009171389167257136, 0.059384925726560824, 0.04955124876071369, 0.12434259717983585, 0.01101598428982881, 0.02776739307709279, 0.05170640730929952, 0.0661341794916699, 0.016725913381143924, 0.04128665775961934, 0.041408798987827, 0.07824436716374852, 0.056639749241331895, 0.05552737425351816, 0.01778424086589967, 0.05836416336317217, 0.05191672525759186, 0.017510090556536472, 0.060505608937913374, 0.0537656286671277, 0.07305850349967519, 0.07543213500250733, 0.03145850045726665, 0.06013503688718042, 0.026350814150646332, 0.06407324592733095, 0.020945389687474218, 0.06455419975663386, 0.017359086965781548, 0.04780951339090544, 0.036726791351552934, 0.031858777567263574, 0.0441113235278716, 0.06519949093701378, 0.06554940925730814, 0.05036441661838082, 0.02025792728208246, 0.06605590828844617, 0.05455841092512973, 0.007101297500588361, 0.06387695504893219, 0.026189146615985422, 0.039331459650589574, 0.10657375468121422, 0.041850345254304915, 0.03313951186775681, 0.02109439570396658, 0.04108519578773168, 0.04999848323002939, 0.013410875690169634, 0.02104924248170949, 0.03529258282674897, 0.07318018124468866, 0.10829222779120169, 0.06110369761083877, 0.04544500982569111, 0.05008516990910134, 0.019672572905678424, 0.08033806247816933, 0.02887705611365457, 0.03939579954491027, 0.06749148044975535, 0.03960747729926821, 0.049227997961063544, 0.005942860039912405, 0.036879809753548716, 0.04097955609341303, 0.019531252666286403, 0.0683426117945102, 0.03953826891618871, 0.014712494505088658, 0.023712139208650878, 0.035478010578381444, 0.04119212250976313, 0.015099042361872572, 0.06186923778225338, 0.03779156163575188, 0.01462028816252226, 0.04017723987119333, 0.07502524272328423, 0.06365422264582689, 0.03691812181064198, 0.026738316744505882, 0.04177318487857138, 0.06862020375387323, 0.04963752941318578, 0.051178189685508135, 0.06189892368931925, 0.018496308100199508, 0.06690856414817034, 0.0038421157589783113, 0.036797462962567806, 0.07940869823458695, 0.04067644191485259, 0.028242045833218484, 0.03919218486595539, 0.027039328011714166, 0.01996739801289814, 0.015990113700559784, 0.035857982527945316, 0.07367798517788611, 0.048863658035594615, 0.033762571176574115, 0.10612338691228822, 0.05661891548023109, 0.03132307909489159, 0.034313338598416704, 0.014645651418475375, 0.04514285325703602, 0.04983450977071639, 0.040534501144241904, 0.018601187452253316, 0.024911292806087483, 0.06569544093743448, 0.08810363529670624, 0.03654374230292536, 0.07116907020850528, 0.004567986461258824, 0.03399357349882203, 0.04144928673462522, 0.04777502794299395, 0.07152920814170953, 0.02570794763854675, 0.06553478463883362, 0.012150696486294752, 0.03595519908553651, 0.03191883503008754, 0.056021248155664054, 0.06273410891393019, 0.03077357380290426, 0.031091140230156245, 0.03987195383336756, 0.046022406463781675, 0.07564275555552975, 0.017802261169098558, 0.0033153723756362114, 0.026144435809504603, 0.035839830074579485, 0.04195019332391601, 0.013420908569147991, 0.02987623203455681, 0.016272504243158525, 0.043240913580502235, 0.01804229375275393, 0.061112296947788816, 0.02081934332607254, 0.14445638884940457, 0.02363623521711317, 0.015084006928748664, 0.037788110409653, 0.010923438953355917, 0.07429205827535161, 0.10387621354311706, 0.05764293371729794, 0.07922204857271525, 0.015751258977087998, 0.0716628598409795, 0.13045363458654574, 0.06474910018545005, 0.030346811118145144, 0.09767081708677354, 0.050136647187173373, 0.016228247343772845, 0.029397407929683407, 0.02993430916009651, 0.025143867523799983, 0.06242640586870332, 0.01715450893126188, 0.06677761673927307, 0.01748837387910293, 0.005837112135674444, 0.056933352438312386, 0.026401791556347764, 0.001108848110532328, 0.009598177707483693, 0.029062999059416117, 0.02678537752569443, 0.05560306757087669, 0.02651070627654272, 0.031014531437728195, 0.11818197856266653, 0.04855555279420749, 0.07804963527427566, 0.06108894275741712, 0.03303165434889736, 0.048799494341496504, 0.025613134681817987, 0.01902778542810871, 0.060221317539652514, 0.03237290683412745, 0.024633788946835745, 0.034074675396925984, 0.05414666547890633, 0.05006824702685399, 0.03673713736897034, 0.014988530348355492, 0.11057342312509015, 0.05675847754783689, 0.007009065302554519, 0.041933174680678115, 0.033510865328172525, 0.052021323072333495, 0.035197128271383625, 0.06200012007367708, 0.042898127538782936, 0.03544521818478261, 0.02499193888187649, 0.017587588010956685, 0.01596771616248354, 0.0787395817197619, 0.05900916343014087, 0.0015475752931501296, 0.03765809762802336, 0.023621396094019857, 0.05122643024210007, 0.05170441165025677, 0.04185582661340314, 0.03141256007966736, 0.040795024664651965, 0.026696095723778974, 0.051194392445106665, 0.04856425555302732, 0.029036513484653928, 0.03413627652691738, 0.04520750341696605, 0.03985853963381341, 0.05703370229551389, 0.028674075372457027, 0.04777943294855857, 0.12186991816927349, 0.05258054810486013, 0.017531924062378464, 0.052320572337315935, 0.046938015598683595, 0.0022194529564360218, 0.0486098186323239, 0.11144225110089588, 0.037089047517867825, 0.04823275781687229, 0.022318401193666845, 0.033768485375349565, 0.01954964835256819, 0.07225236449871333, 0.026990438195606394, 0.06199036011352174, 0.07236971384695462, 0.0493906575795864, 0.005682513198529881, 0.0922290034471981, 0.023027109132418712, 0.005259618778983432, 0.024167310348862124, 0.022218436295647296, 0.025551600584519968, 0.08413981210680739, 0.06859475431302864, 0.013546261620978195, 0.01086050387276637, 0.05618241773317418, 0.023338292132041628, 0.0943541236882729, 0.04102460972423996, 0.07058950937202862, 0.09906665226745029, 0.032123284744879896, 0.011436952477050646, 0.02845270852107675, 0.0524253540131594, 0.03600180021397049, 0.02311891327882486, 0.009209551837205166, 0.03684630872861993, 0.03988564382457445, 0.057000013579043655, 0.030842092706851905, 0.06192641092404243, 0.051647318947699764, 0.01295889913660264, 0.011418559663598577, 0.057871036396752444, 0.013615102281854039, 0.030370500471983707, 0.07914530188446084, 0.028071715759353775, 0.005578829901247856, 0.04610766055843523, 0.027610730011797244, 0.1046092754169818, 0.007270106889923374, 0.11115165096857857, 0.055355762897600094, 0.02960066063209407, 0.025233909667980288, 0.1471015219126017, 0.12942796543000207, 0.19002021891215157, 0.11957323253755608, 0.1166443634898432, 0.08167332308667322, 0.11995750224037517, 0.12077851100794731, 0.10381838156571312, 0.1064704860290212, 0.15405560843646526, 0.08865319613006808, 0.11432336988828837, 0.129766637579568, 0.07989120339193652, 0.1954795912869515, 0.15728983246991712, 0.08081877498977608, 0.15585733998206355, 0.09321953981153427, 0.0898584746004593, 0.14701267103514365, 0.0907224992049798, 0.13667796107549823, 0.11997084749201614, 0.1304312035321228, 0.08675148244947196, 0.12026831943301425, 0.04850520549582378, 0.21370454721393126, 0.10281695909197293, 0.14838881009528715, 0.13618260862365847, 0.14602951975839754, 0.1090094622885508, 0.2359462247019814, 0.12735510004624245, 0.11551815295411695, 0.08660673013617916, 0.13254223541627008, 0.2543748987297858, 0.13348305267432045, 0.07593871830331703, 0.2530403276004138, 0.16691758117127806, 0.18876325248950915, 0.1583001645462167, 0.12350668800213646, 0.07286722666674084, 0.17568919597373855, 0.16027495535390993, 0.15729099692356202, 0.115543931812769, 0.12091687414795162, 0.15533433175615727, 0.12223545702234392, 0.16441302524218637, 0.20365400990891844, 0.1103726774454117, 0.20532932162525194, 0.18322212321142997, 0.08211757747396346, 0.17154174916926893, 0.16390812733481008, 0.10153203046009426, 0.12463712734320473, 0.16964117695967998, 0.10485844551435403, 0.11302570887510816, 0.20653822369152502, 0.13517305795704165, 0.13504777193790482, 0.12838191833467255, 0.07193504321959711, 0.12483115443178724, 0.13209957449186233, 0.23330041748141092, 0.16993494103512458, 0.21043659999005257, 0.34008264000858035, 0.19118545396674066, 0.14724144021109228, 0.08347899998508154, 0.11733598000700436, 0.16702235135580265, 0.255798734424095, 0.21965522709633076, 0.2832460866099404, 0.14634232877963974, 0.13871175597511953, 0.09855973954883315, 0.11396823450922967, 0.28664313497081884, 0.14924155788556223, 0.09817305666905257, 0.18173506994160915, 0.1722947523118027, 0.16088747329288916, 0.17747225029574287, 0.16921852625185446, 0.13497703137897676, 0.12961291437668185, 0.2797703763409969, 0.10038233932948883, 0.179870902230182, 0.10765444427247971, 0.1058426846359526, 0.12256757912015724, 0.16563098246772445, 0.10774979923641491, 0.10446442351225885, 0.1233050996257413, 0.2420822825402983, 0.17881851192683945, 0.15212171140217012, 0.11676676135750548, 0.10174447430237647, 0.1756035320220455, 0.1047456007631075, 0.10404132847343722, 0.1580479224362681, 0.14024632201800424, 0.18189443155161797, 0.08510544295272521, 0.1816073477628731, 0.1431204540835273, 0.11202112245824068, 0.16270038972218193, 0.11834111800717732, 0.13752926862047565, 0.13059084093378437, 0.24562026043572735, 0.12157011732098558, 0.15283149186401598, 0.25281725811862177, 0.20615009290556754, 0.11946214212765617, 0.16723304085673826, 0.1982830900458559, 0.13469609161538465, 0.14165714953935918, 0.16968144254098017, 0.1603666560784463, 0.22371094253274704, 0.1933694633865549, 0.13176690847162278, 0.13993703700121374, 0.08996729739010335, 0.21649531359153412, 0.10571373671653772, 0.18096099938115767, 0.1113236683510965, 0.13658227669375558, 0.0897208622266208, 0.15239194125658082, 0.0800179832825257, 0.1775164076036984, 0.12577209426390548, 0.1719812997767041, 0.11295794839820555, 0.128643338177954, 0.09330302041264311, 0.20111994427298346, 0.09160230522074046, 0.2619310997186169, 0.11757804080843927, 0.18937808401401968, 0.12563061314604937, 0.13264797087157928, 0.07012935866030955, 0.12537948952447023, 0.1169853415640612, 0.18558121436545927, 0.16457747367601241, 0.14343301795663374, 0.11422444495462603], [0.07900112413711126, 0.057269787611139406, 0.07997767173595006, 0.07503279635021765, 0.08880704956790132, 0.03958385497812302, 0.04540500471428518, 0.019611799150645252, 0.05723405727035096, 0.03846749250266341, 0.040469460279470494, 0.06408668693996246, 0.0825152613763367, 0.04416178956988358, 0.04041284255142655, 0.033519146738633994, 0.025860410626797427, 0.026584706539588592, 0.06775296158007077, 0.01718108643657498, 0.06066753311202892, 0.03600074301263498, 0.0646411507360397, 0.0416788871159717, 0.05674933811890022, 0.012578779715113344, 0.006463743808243665, 0.10394541426531731, 0.014917891296077401, 0.018371068046338136, 0.028048154725242528, 0.10430191328088123, 0.009938136884762395, 0.053040932473396106, 0.021394679187646797, 0.06821112812406595, 0.01598533426952218, 0.04394158142648878, 0.03785156164198153, 0.03580756628164842, 0.045314690608891754, 0.029171957829666716, 0.06264268015060695, 0.07128546194684121, 0.0324550467813688, 0.02891458867628488, 0.050107823129022316, 0.06358454694911357, 0.05304706883766959, 0.05981462061285012, 0.015840081126248885, 0.06422625666844749, 0.04075337629464846, 0.005980226457224138, 0.02306023668948441, 0.03798174296295451, 0.04695101228031901, 0.06542937860133187, 0.022119773747099024, 0.07448623092063973, 0.06158976124659662, 0.021381630795076493, 0.06257692299362633, 0.020418815322280414, 0.026777933066290234, 0.029873303663466248, 0.06799601829580723, 0.028167593578297286, 0.11479943224619474, 0.04839673893706453, 0.044042869741397525, 0.04311864977822669, 0.09277592893810042, 0.06244687956847972, 0.02724768860535997, 0.030291775361664837, 0.025099016906272982, 0.03800351135132294, 0.06692067599825322, 0.058559607714414603, 0.09600919536164693, 0.03349359004548, 0.04665814069730621, 0.03375238603762081, 0.03570535483079092, 0.020178053039877165, 0.02140506159424061, 0.0411952673006923, 0.05642115371301771, 0.04564364493313817, 0.030613970875199285, 0.029810796634504394, 0.012883780385187317, 0.04065365845998449, 0.015306731670974724, 0.02330032098407467, 0.017241712719682726, 0.03174030781543303, 0.048041339257671956, 0.06346495296325415, 0.031269855136352206, 0.04461089329373452, 0.06648046655520316, 0.10590269996394074, 0.01789305407944466, 0.06152760853329974, 0.018557704301671158, 0.06315241590322507, 0.061925464805455945, 0.08093269992499583, 0.02467940948272665, 0.03389266822787543, 0.007527940484109305, 0.037238932620253296, 0.05015171996708359, 0.04774057313859944, 0.02418079924198889, 0.006901856085600993, 0.08390388000876674, 0.021040415233601967, 0.029575653607025746, 0.014044165145605804, 0.03790644035043736, 0.024879392904920444, 0.04389265139076499, 0.01651929372230605, 0.05139642898293753, 0.03850866589815386, 0.044187254332486665, 0.0841754275344072, 0.032413467359278476, 0.011025751910863385, 0.02274235808140328, 0.07215866428469458, 0.027798258759562048, 0.052171441831535874, 0.07316456837279182, 0.02020783470793357, 0.06526640871719969, 0.032995065989633726, 0.04491346354986872, 0.04104067841845174, 0.019821569346071734, 0.03543189591577938, 0.023137573265440525, 0.025249624046527093, 0.0489286414437717, 0.011517680907291512, 0.04573111302189289, 0.048191074972912196, 0.060528388562341856, 0.016528025209423036, 0.02051438670605421, 0.03467009042299563, 0.07682201768001241, 0.03731235448691634, 0.10325435699234087, 0.026621758382046418, 0.05223803402435395, 0.04983809506220203, 0.031335732952180895, 0.038022916358444965, 0.015653381668662113, 0.05475370971966655, 0.014040431424584842, 0.02717001495071717, 0.04434781487009699, 0.0884253845640248, 0.07178016322394533, 0.017802167323327834, 0.027834113589638186, 0.06492022890597582, 0.040832049694032445, 0.011368031376942752, 0.01776718583348538, 0.041469300781647046, 0.051172765783004226, 0.045190664804390365, 0.026171947942085327, 0.05473278402801483, 0.01563250768794528, 0.031050271354615692, 0.04094302136030409, 0.06449527993437744, 0.0759184705994783, 0.0367023186728118, 0.02286422543317801, 0.03431051939485535, 0.030313788898169037, 0.09343004545136806, 0.018977112542357177, 0.02921362343664852, 0.031513972883863796, 0.06498319367247243, 0.03458019766596056, 0.03389234647094723, 0.0868707929827994, 0.03828491076766964, 0.046039367650425246, 0.020689401407575896, 0.030987791138731187, 0.02996866820350049, 0.0595410046498141, 0.05829174507168993, 0.033784626847914154, 0.05119533856369315, 0.007278715802972476, 0.01636282026377176, 0.0037775254496673666, 0.03599262248063761, 0.056408635836334965, 0.029588353429590503, 0.0718169354443108, 0.011715932013166529, 0.008847454634134569, 0.061043410321637515, 0.017848923584566485, 0.021841584239155058, 0.060071420945948174, 0.04045607289299369, 0.03500717294011866, 0.028819197323173288, 0.01099499826875305, 0.029756576761663444, 0.05463690812429113, 0.09376732332091178, 0.0051750163378704705, 0.09371250206905027, 0.04114716463992673, 0.027818697985381852, 0.05122345399051424, 0.013760178267294842, 0.03898155282161409, 0.025764777955989686, 0.02412114589054498, 0.04697962949473051, 0.04657160723581911, 0.019403404083042856, 0.044893997255712755, 0.008103597623806807, 0.06353147237771942, 0.0432953326362035, 0.07070711919016416, 0.08573047876838716, 0.08025612937466753, 0.013886572241092162, 0.0063713550409902975, 0.08768745037096162, 0.07599123363052646, 0.00795365458602206, 0.02758581108684021, 0.028539743770154256, 0.028386899653161247, 0.04472126358098561, 0.0757858148145099, 0.018468661902232036, 0.0511886544465538, 0.065810147282337, 0.03193070173203465, 0.01922366453424817, 0.04098602187549395, 0.09897886625220699, 0.04128628237653644, 0.049309126672244845, 0.0811569645039497, 0.02514571762613712, 0.034444128959289486, 0.042250913477713065, 0.07848551632055352, 0.008953468753926216, 0.019433735419184934, 0.049968889253514434, 0.022169916116962993, 0.03834658850645346, 0.03467865911642871, 0.06689413871255613, 0.03890944096530157, 0.045129021539563136, 0.012191535675928239, 0.06517108439678146, 0.09221903664330322, 0.02092894752539935, 0.052979829300555496, 0.004936677287332714, 0.027120391605421904, 0.023837513327899, 0.0069870383595116445, 0.04005883332161654, 0.05846097772460311, 0.03960572678836123, 0.028450065517737985, 0.04196523929074888, 0.041784814093261964, 0.012571497091783151, 0.014920203923998822, 0.02023937837821582, 0.037203309531774253, 0.024156885807432478, 0.040654577765493624, 0.06012503943976857, 0.04460696709312258, 0.03514234149347871, 0.04879588606737314, 0.0334866109844898, 0.022531086353645213, 0.04114888450731674, 0.08459237854807608, 0.03152430740996234, 0.032654053441459135, 0.06507036681737631, 0.027148983921975862, 0.03036110440359241, 0.04925669944514671, 0.06631811720228965, 0.03984431721149914, 0.03346930505828031, 0.05239584047587649, 0.06746025470596168, 0.005979430683392791, 0.0677133624952647, 0.07472738773832399, 0.01382981087156241, 0.034384998462853894, 0.05104771725112393, 0.02744981898896156, 0.021903985931027322, 0.028930136430708152, 0.059110179783836495, 0.03448552452027798, 0.034372572516722065, 0.07255213470348428, 0.07501236478527708, 0.037949142091336756, 0.027821760421859163, 0.051658323800732056, 0.048040259073698716, 0.014730415216857388, 0.02237556092891722, 0.0352218575895794, 0.05351824355461905, 0.08148711009491837, 0.04897039706608461, 0.041872389434326085, 0.03202899847359907, 0.0291492433227118, 0.04625201833644702, 0.06339633829831597, 0.04241839561971926, 0.05562513473353559, 0.008669393775503962, 0.017435843230135018, 0.033565989184764125, 0.15514887719144746, 0.21178425590117134, 0.27871804732468825, 0.3168906764157357, 0.10186529402891475, 0.11946927440623123, 0.15323644594079064, 0.18977441194076694, 0.1397134772231502, 0.13299552964106684, 0.13121699523781577, 0.14944256403513495, 0.10986194194805239, 0.17729885395496123, 0.14661162400678282, 0.19891273771082202, 0.10476148942665708, 0.12485391490401761, 0.1560194595085998, 0.09559720859772737, 0.1833734102547169, 0.18298753176725682, 0.13710942179445298, 0.2897670883084497, 0.15068946406245232, 0.15207847339972375, 0.18040777664751778, 0.13686690900114276, 0.15768681923227926, 0.10885872682856937, 0.26367342880656647, 0.18322376263958795, 0.09117619945637642, 0.08380582841533808, 0.1756138742090233, 0.18810365078670366, 0.13926107166034563, 0.15591865765952295, 0.07366270172379671, 0.13122981954966823, 0.1478352043176851, 0.11150096407941273, 0.12250816134075004, 0.16596404685368463, 0.15668505201897315, 0.09081938634476355, 0.1187797569699826, 0.17782717883106203, 0.1491452606334802, 0.23460552486921513, 0.07831199740570399, 0.19729790097523123, 0.15908681427038487, 0.11091587974900201, 0.20464653810185773, 0.11122238386662738, 0.16437481277652327, 0.1275891322462309, 0.10143911165575828, 0.21536455249353764, 0.21610525226400745, 0.07623590679178316, 0.16289528249011886, 0.13303950308792054, 0.178733813245931, 0.2146180457766018, 0.1301656927793257, 0.17100020161559507, 0.20114965316268707, 0.13346311906653066, 0.1280347426091471, 0.14787012260527382, 0.19205280339285252, 0.12086824288651829, 0.10550187510107795, 0.23115451327495037, 0.12663210456770274, 0.10496922182820498, 0.16464600790171854, 0.11316446271995384, 0.23268062170715104, 0.10862784324994973, 0.13780801737260434, 0.20085526089514458, 0.11009946750897555, 0.2633726933310109, 0.16630713166969438, 0.19298053586915617, 0.18894078570508188, 0.17606004381612425, 0.08582464629603971, 0.13169708721820386, 0.194123171329979, 0.09844354699335753, 0.08002732189432268, 0.11473513448670988, 0.12079426943654976, 0.11038439859065319, 0.17377751548924755, 0.252708979251404, 0.11375604347596247, 0.2147542868530558, 0.11037349715949067, 0.20152151224113282, 0.15430763604179507, 0.162535282452741, 0.19092392687114979, 0.19246010169867547, 0.13674104075518348, 0.16597731549653316, 0.12247009443179255, 0.13360711295277844, 0.14136461120459343, 0.22145311288054914, 0.1540466605295097, 0.12315552861940478, 0.14184317100913296, 0.0698656865185307, 0.2847237476418095, 0.13927009617609365, 0.1672858856017551, 0.06884010929253793, 0.17160410872630535, 0.14451482603626867, 0.09962191279496878, 0.06508113035271246, 0.12055328115820886, 0.07599368511188416, 0.16330107926361023, 0.2860385077374597, 0.12774817976019076, 0.16121667659571096, 0.1180679310533789, 0.18351026420151034, 0.14456152675613282, 0.09418751488650039, 0.1938965931654938, 0.14518274745393187, 0.11868994082173995, 0.14954200224770656, 0.14554101613260087, 0.10358692342115026, 0.11968687402024386, 0.08657312185894098, 0.19295286477333118, 0.19520956061540112, 0.131621872705798, 0.1375868171453476, 0.17665376195744162, 0.12700619296200816, 0.13885784894227982, 0.1904440493953805, 0.13800245048778673, 0.10552870350018626, 0.21229165125518076, 0.12699012809823598, 0.18255835399031642, 0.13980180716081975, 0.14075255291836877, 0.20603753926773227, 0.11208090795985154, 0.10394421916815544, 0.1968188202309032, 0.22281889443195638, 0.11051791239409678, 0.10267897133505154, 0.09483979278874975, 0.27653408387014944, 0.16785593162621223, 0.05932912005171661, 0.14883024527901603, 0.13131857849657536, 0.15485664529185142, 0.19050703714451483, 0.18986071940631638, 0.16426362277519319], [0.03183956791256224, 0.02397777636595551, 0.03591781782527124, 0.08067635158377309, 0.014569448652647197, 0.020827312555704868, 0.026668376747458696, 0.03228401382183356, 0.03602005225876647, 0.025284469555762988, 0.059234512023507595, 0.014091662596911194, 0.00702522496970731, 0.030940670985728506, 0.03660410237047942, 0.0326369735111873, 0.013832722005674676, 0.03285991275803216, 0.016308717219339266, 0.059286609832798286, 0.04136971318193021, 0.013582727406173946, 0.041810144790478294, 0.013367698017147281, 0.03357326318960517, 0.10949026673070847, 0.04654204773326074, 0.08709917911478589, 0.0772106004578452, 0.020728508280890606, 0.062211659932208646, 0.006378645325199731, 0.023040923612913298, 0.021048623865710634, 0.02246839354836172, 0.05386090702227047, 0.05042167019940192, 0.0576089040917014, 0.020588739369545254, 0.05941063946773929, 0.04672614249190496, 0.02953787015060023, 0.04209951152123752, 0.030558814459870902, 0.01613735867243621, 0.06624209829756329, 0.04682056665901215, 0.06028183082479143, 0.05261589540168644, 0.02858383596063622, 0.06138848313581079, 0.04836463985303718, 0.02870487402223291, 0.04504005957935606, 0.08489869880459963, 0.061474756127403635, 0.08683490942442611, 0.018674086463908036, 0.05632403674685667, 0.061318171586120324, 0.07313895039260387, 0.023926270359586325, 0.027876229273275505, 0.038285730481748624, 0.016626902262590105, 0.11843861801730049, 0.021409631308708942, 0.08315879821537003, 0.047502710498989596, 0.03752332744038394, 0.048256962364839937, 0.10199424194832964, 0.03821610841119001, 0.04095866870615752, 0.06404418438192337, 0.007940779999649573, 0.018580675448080706, 0.03490949289933328, 0.04510887342715456, 0.0911815467500879, 0.026319055975745284, 0.08527241181582214, 0.055173744237230676, 0.06413434143929232, 0.036635240014161796, 0.08813544326732237, 0.011985574852705244, 0.05203820381974501, 0.019119798333474228, 0.01793364333289285, 0.06410875793306098, 0.021579312123057824, 0.012882575711926386, 0.03208820940926671, 0.007895765630828758, 0.019493065098480835, 0.004085107357241213, 0.03150176144235077, 0.0804340762777194, 0.013894331754155219, 0.019066072587344437, 0.04967252047912729, 0.01948111987252149, 0.029347916734555078, 0.043353743009990266, 0.02692517516533694, 0.019535763008940606, 0.05521901237267641, 0.04725972656160594, 0.07254744624538768, 0.02013660768317359, 0.0034620049559781632, 0.08047176014271476, 0.04221680341288448, 0.04186350281440443, 0.021670750462480133, 0.01973668871928127, 0.09584522190233392, 0.021802136456714045, 0.036182367137723395, 0.06664068618368718, 0.05363290776468573, 0.03576995902544549, 0.11040413301558265, 0.02897772772778427, 0.049191643258616816, 0.02118714596895922, 0.033503817319269144, 0.09696321997551188, 0.022521326393489877, 0.01965647356794967, 0.04195030057622541, 0.006930866877683589, 0.07125543896108866, 0.029959032732632854, 0.03827143145064193, 0.060126000880113536, 0.014152264939771305, 0.0779253451694404, 0.02180204644138294, 0.06437680443688747, 0.09356085496443896, 0.04077413727739646, 0.1315941096794221, 0.07946307515545238, 0.037697846099974654, 0.0309726704783257, 0.04668180515328723, 0.01965666508993074, 0.031158174838750597, 0.010331151481237142, 0.03924567312482865, 0.017876901115561207, 0.07312058726505888, 0.01798422811853309, 0.060745662588986664, 0.05553767430566012, 0.10870096634232229, 0.05750306521452243, 0.047543133128314256, 0.05872695579103405, 0.06245003585072775, 0.04350298076807972, 0.050687479726489515, 0.10489534030878737, 0.0478598338762118, 0.058621679988479426, 0.027892263493530696, 0.04173805974724312, 0.07121912639347777, 0.023892587388775522, 0.06877425637456679, 0.06728719544386672, 0.05305948712292218, 0.03431954391060337, 0.012793000881379891, 0.08497575958890301, 0.04852102138102055, 0.024793137150305896, 0.047963313202583985, 0.06343359315407372, 0.018897686461587588, 0.009865033902197836, 0.011647942667496542, 0.02362454854582827, 0.024785395831831043, 0.07109922597244864, 0.041598344462052475, 0.033454990705415126, 0.043501130665742585, 0.02702126174323982, 0.017513154908233595, 0.07162428731399198, 0.028028902935705362, 0.027619227842097322, 0.028057546963194208, 0.045222158678957534, 0.02814752398990095, 0.03370823639054452, 0.045865488674251303, 0.035112372133880854, 0.03387831940105365, 0.07709128226363852, 0.019649910109658397, 0.03991144949630384, 0.05686626611878315, 0.04409867924668136, 0.016206490446723277, 0.058755350839947505, 0.016644817228699406, 0.015316189026399968, 0.11508671521779992, 0.05483339818555021, 0.02322307825388928, 0.042096749774270484, 0.018156101859565225, 0.047703931153181105, 0.02483867724696475, 0.015820490342805225, 0.06188582358581405, 0.032843993450965614, 0.06865087025348218, 0.061777425974967985, 0.01862572333324821, 0.0600293129231901, 0.07761996720106372, 0.03564464236279169, 0.0324767040869882, 0.0211461755867687, 0.0411474097880625, 0.04389795271920101, 0.03412581942675095, 0.05831642076373101, 0.03553262115606377, 0.052586017972639496, 0.029574791758110928, 0.026376874546610543, 0.03526236065813611, 0.043729095449370724, 0.021534647281852462, 0.060708300480919505, 0.0503483594154879, 0.03883382808717509, 0.04365546290852851, 0.02647799049173632, 0.01351441247313614, 0.07885098622571077, 0.05217581619358352, 0.02138988156202099, 0.024808313352085894, 0.06233645182463431, 0.03299705015735761, 0.018586403870534514, 0.018565462857124307, 0.06452719515730297, 0.04721151664853097, 0.029928364317804098, 0.07395128704487317, 0.05448622629046441, 0.023125582074205724, 0.016732963305267117, 0.08955400827671252, 0.024956030425645655, 0.0486553319159054, 0.023759510255448764, 0.06259527462985247, 0.02991455175252932, 0.031921156276498115, 0.048840617941271876, 0.035414275893520926, 0.008174187837979727, 0.02937898734554408, 0.014447872414283696, 0.02907425863668323, 0.07561317690077328, 0.024820149410516027, 0.0301277406153179, 0.04735990787946409, 0.05277742121008135, 0.03679701480113211, 0.02849478973075748, 0.01220713322606659, 0.014543321223989611, 0.025503840748100512, 0.02286021687811421, 0.022573182885084423, 0.02312639795784508, 0.012533777795221298, 0.039447820745408535, 0.031081939514185634, 0.015911090773560347, 0.045581576489512964, 0.045518186544218374, 0.01669848360301506, 0.04022841071409564, 0.0034793688175869327, 0.05458971710815545, 0.05420606793655504, 0.03526629068918767, 0.024847458529796813, 0.0419726703436144, 0.016637501089022528, 0.0025089642862909504, 0.009252911456109536, 0.024747332753313166, 0.028388590792254097, 0.02101182291704801, 0.10480312630534173, 0.04405819149988313, 0.09582410851914076, 0.020824027953729517, 0.011500665136883336, 0.05488179579016663, 0.032722522549691706, 0.04402007096477094, 0.061204265803098686, 0.04434075153943512, 0.0594694865116429, 0.04823363115710597, 0.026771756482400724, 0.05918735548132851, 0.025866365045188897, 0.03500686650494895, 0.032819536093982964, 0.050467401818041845, 0.04988576105285076, 0.06878822981830567, 0.05476504016006666, 0.04322353487593993, 0.031085281572755308, 0.032884967663595756, 0.1408644323988307, 0.06659586237923754, 0.05256465561087093, 0.05464115225139165, 0.042516148438857454, 0.02153905994829632, 0.08079177805132444, 0.09824447904623325, 0.04834619628626013, 0.05525505680951381, 0.060504203166572325, 0.03940848596093636, 0.042743473539068814, 0.06841988708343237, 0.056827988535646475, 0.030007076021584294, 0.06575028517193372, 0.04189242263354602, 0.0457781125160475, 0.05217517267972712, 0.0288895356859411, 0.16289330598327423, 0.10599825411073624, 0.11178017248429599, 0.2761103759609884, 0.1661224891581843, 0.15238362154172314, 0.0948832376349357, 0.1252920176052759, 0.1597049399729698, 0.08869313995444006, 0.14014314529636215, 0.1394765721934457, 0.08142149466420374, 0.15271789634660368, 0.2036280854935608, 0.1613830402493477, 0.22451916529286295, 0.17452504876400196, 0.14614142988237644, 0.14389679226423466, 0.24421421330301996, 0.09210495082961936, 0.09024514981936063, 0.10108543184375572, 0.1919803314752156, 0.23616733299868725, 0.14734215012961818, 0.17716849643376567, 0.18718797653432817, 0.12665463521355583, 0.15173616999339673, 0.10605539660900833, 0.12072886851045395, 0.12358483663129231, 0.0893981400276384, 0.13388949296166822, 0.2597283824316917, 0.16787036472270567, 0.08997527236539511, 0.10218594012962234, 0.08280997540080741, 0.08014278666627023, 0.19267442245637217, 0.17830242913576866, 0.09049362277672177, 0.16161262147849606, 0.1588405170027287, 0.16072809636112184, 0.20886938327983504, 0.16501362285306378, 0.09114400078091892, 0.09594138891946885, 0.10855188563225732, 0.15556829500823252, 0.15188214038648915, 0.15418115492549636, 0.1258387668959556, 0.17915759776388446, 0.15912432193515763, 0.1425615929427647, 0.11798734626462383, 0.11402728456643321, 0.12207542891584097, 0.10672362446184121, 0.17882819527820235, 0.15576793752130003, 0.13546202632208026, 0.1748905186691592, 0.245852752798988, 0.0792220026074398, 0.1685916824686912, 0.22891922192948483, 0.15848826977514452, 0.09689337573945524, 0.30308037876121463, 0.10512245473481956, 0.16405247362150302, 0.1449852040217769, 0.14834175697497784, 0.1689610134569868, 0.19393793126988798, 0.17429269429656769, 0.13390522840763294, 0.20107911178661933, 0.14647466280767996, 0.28420777210304815, 0.13712557092789682, 0.2942719610948717, 0.1109080579912951, 0.18513593342035048, 0.2218232559220445, 0.13429308340193766, 0.12703053923624177, 0.18583451367674336, 0.07800562352302574, 0.1311792730684242, 0.14030999924627044, 0.20847284084846898, 0.19709717061731125, 0.13548968209614679, 0.1632799352369001, 0.1269110448418125, 0.12839727073667512, 0.09991766103813726, 0.1412417460232973, 0.15317813132799443, 0.12380632797196028, 0.08562718713355642, 0.10324210724643162, 0.1791360706932122, 0.19783531165411397, 0.10045139449498347, 0.2365026496831448, 0.1963953574698779, 0.11746890392274627, 0.1310577868453918, 0.1519076051490922, 0.20690781514971487, 0.14258365627498398, 0.06293249504280186, 0.1767964534942181, 0.11065263661646074, 0.2469204495390577, 0.14460957579074368, 0.08573430154712931, 0.20345617536335223, 0.08682496560316894, 0.11014713349962428, 0.19162616902782073, 0.15963939349016837, 0.181851270157964, 0.182393737017147, 0.15445371368719688, 0.15390626725650605, 0.11444033619256751, 0.11782345707498251, 0.19294497406771108, 0.10248219399082084, 0.10398135911072455, 0.10649254170036125, 0.1802907337344462, 0.12452193070203067, 0.19706281923478652, 0.25307967387620484, 0.21316857678034615, 0.1401740799267446, 0.1411767051585259, 0.15421915288654067, 0.13438951854984607, 0.1437131763105431, 0.21094171240204768, 0.1683903545621903, 0.10184125418985084, 0.10703549119493655, 0.15735936260992484, 0.185837026445135, 0.17475378729643362, 0.18015631594725195, 0.13809324722857247, 0.10185704326197025, 0.14552448395519488, 0.12760340446426024, 0.20700685499656588, 0.1374172206006704, 0.14340701693248364, 0.1168124201977926, 0.11698900346433926, 0.09510910333765131, 0.23309594861442046, 0.13294400256727973, 0.15335070029381784, 0.16153644169530562, 0.13500762893067253, 0.18527298655000426, 0.13745411539510374, 0.13031043743173923], [0.049951361161806894, 0.024323609522393635, 0.010442365422814844, 0.006037985656275264, 0.022232773631150206, 0.019993565661171754, 0.030054826281904697, 0.012784110431018616, 0.10271075632302992, 0.006036885362494016, 0.04856620141635499, 0.04595718556834806, 0.05068456859237725, 0.009467219764877473, 0.036831255100907824, 0.043502176375759226, 0.029970673438642296, 0.004942866798955947, 0.029070895510695638, 0.04326724785289938, 0.03402383397183111, 0.06029303486068403, 0.0500389518246295, 0.05019686935890106, 0.12403193320478163, 0.06944211650519602, 0.020492137597513296, 0.041869118238889405, 0.004895856292287429, 0.04806775779974076, 0.004481022075314316, 0.045797172783603596, 0.06329408471262263, 0.06492401338032176, 0.037273942838392915, 0.1523938871199085, 0.05767350828635597, 0.05371298310497115, 0.02158385885488843, 0.05621935466244336, 0.05342861126747824, 0.01540856965396914, 0.013268551875596807, 0.0732589197615462, 0.054713516916719176, 0.05876935492720335, 0.09996128208454579, 0.04270928303500818, 0.036512750215948596, 0.04812208492489112, 0.028813947705672156, 0.028456270829924656, 0.08139475053476711, 0.014538745763861846, 0.06850678443668351, 0.07565227802842855, 0.05449567215457078, 0.026454676520980658, 0.00951408327842552, 0.01775489586796011, 0.003983744109357377, 0.06471045871054934, 0.03430358246870099, 0.07301104435276601, 0.01149163679069569, 0.009732896184188225, 0.024761076370674758, 0.03469620636033435, 0.03271025365158435, 0.0328475519293739, 0.11307566546865049, 0.08150845330448882, 0.06639638840551339, 0.05774617938685322, 0.029941029666412263, 0.024350345990951025, 0.042612495486654585, 0.05027302232901416, 0.007171385448365923, 0.07547345778514301, 0.08194112444236394, 0.04845684619560357, 0.06349219121940194, 0.023078806660768968, 0.011350379753557426, 0.022943898577303178, 0.028159455809321617, 0.08658730980729865, 0.07314920830991, 0.03969782970905785, 0.04586215619178069, 0.04130881685282915, 0.009384048471768058, 0.06825265775044119, 0.01302829042317406, 0.03612346263722547, 0.03041251656419087, 0.10206461478505405, 0.00823482082435681, 0.05548769089904043, 0.09907533204363239, 0.048225633199176485, 0.040233750346927874, 0.04468461776512765, 0.03971265351039268, 0.035220854014398596, 0.028916756705110593, 0.0164632486449855, 0.06595526731783344, 0.021666640400766365, 0.01688391326986734, 0.013643074067189329, 0.060063066757133896, 0.040223795034351854, 0.04270422302426831, 0.023645368900390405, 0.05347554181371966, 0.027078697270142938, 0.03104112043436016, 0.012092043837201933, 0.08186011830525053, 0.041497680508802016, 0.07595028623097366, 0.05979299395074768, 0.030205209341440952, 0.1146236380502101, 0.034485991833911794, 0.015676159377870782, 0.05329241998673928, 0.011932785649062886, 0.01426657004612348, 0.05391356790618551, 0.04348455252306115, 0.027408946282981385, 0.037052673663222985, 0.07502980860731295, 0.03965370304461929, 0.03525247046303365, 0.019410003930510535, 0.04136661435627649, 0.026730203873387752, 0.016004349529412727, 0.029086617550121683, 0.0358154378350704, 0.016519060065489144, 0.08118125715202863, 0.04348755175728471, 0.0955702806071889, 0.042715951830389044, 0.05909807942507248, 0.0414872961869884, 0.025339624055871562, 0.025495804485774813, 0.04391784419215495, 0.03226198113313125, 0.033268180165079334, 0.009102346450691263, 0.09975529636346525, 0.021658339838106788, 0.027298133579954028, 0.07854551632678317, 0.043801831667341536, 0.0093834834819239, 0.03062682008490928, 0.02653209353616882, 0.031921317154962214, 0.06332778492041173, 0.04213977327209808, 0.045693532578767314, 0.03791264183218441, 0.02372932639123211, 0.040516206964610085, 0.10757202853358562, 0.08259511072068446, 0.02276033624976633, 0.049310134077865275, 0.06507588265043113, 0.07554403746560698, 0.028657253996859637, 0.00710130085222303, 0.04282304709176383, 0.025873342190959284, 0.11400962623977855, 0.021060149658531434, 0.11889871510286486, 0.009931695042929102, 0.07148475205946354, 0.027617488822509206, 0.06191901051469388, 0.07891936723383204, 0.09712890947177526, 0.07872545505843817, 0.09454467273767918, 0.009557371076586987, 0.02052142896929816, 0.01938139054653866, 0.036884670581428275, 0.07625855235082489, 0.054987741919655, 0.034974725286085764, 0.06594766006474534, 0.019577610561804428, 0.0129261220647623, 0.03189118883212007, 0.06507824220123791, 0.07096122289376874, 0.05942695331008685, 0.03620934875441655, 0.09021259108257872, 0.06400662692143552, 0.039321236207240054, 0.009176531532448868, 0.02614718798037258, 0.008715582174068738, 0.06992015536994704, 0.01781821878056132, 0.1144305992150499, 0.0285665262039871, 0.09650925159334175, 0.05019680807186712, 0.0202652185239018, 0.03157971663430574, 0.06262572662484261, 0.030629664186328173, 0.01819031343104378, 0.038108185774857, 0.015702378737079283, 0.02644946712309555, 0.04525027027533901, 0.02945624922792758, 0.01683228660465008, 0.06504002207469556, 0.03770319722412575, 0.08158536087120734, 0.011989602559967148, 0.02473442800222866, 0.02678870809294524, 0.04316014493064534, 0.013963606212318186, 0.039725565922356425, 0.058851230574110826, 0.068861881511346, 0.06988963442704371, 0.01467963029074693, 0.03620318940750534, 0.050464237874914566, 0.11952145265475397, 0.04382743432577099, 0.05038406294319899, 0.0758351049115581, 0.01922597428933988, 0.06276456473935997, 0.018190278957087188, 0.05107631148289769, 0.027465943224547852, 0.10230853718014495, 0.05737184201397243, 0.06860352601976165, 0.04784262754143246, 0.07620028370330412, 0.05785087679302501, 0.025095558019294858, 0.026720690976587996, 0.011753721215251473, 0.01674681992059754, 0.14968838632827805, 0.03169862688669274, 0.041658191250697266, 0.07251934614032507, 0.012332001727284684, 0.036326035436603336, 0.08818701630638492, 0.02683123554884186, 0.08306823896184083, 0.018381249354851824, 0.08148321070738378, 0.0613967722071515, 0.023989390258887605, 0.030104482185936747, 0.01952760608776683, 0.022743846207196196, 0.029781660395524198, 0.020742529605124748, 0.05635782505475706, 0.028063660344829964, 0.040958599758244334, 0.04733307948035579, 0.03588114519633594, 0.054783993175313364, 0.046208761181802525, 0.0827164973522867, 0.013446495905818959, 0.02839272383660559, 0.006811239375477477, 0.04062163981518919, 0.039507215542178, 0.0650652646718006, 0.04243971967709161, 0.03976823318929922, 0.017561129249271848, 0.03625122695079735, 0.013574073485459292, 0.032641903286980044, 0.079568350958007, 0.016969657660792434, 0.016551846713428537, 0.020824981733195243, 0.07472351899430638, 0.030741664325638168, 0.03094104253837178, 0.05663389632959039, 0.08579492974545687, 0.03379461663444677, 0.016431659009427797, 0.005665494076487038, 0.13658198558034437, 0.03670254083830984, 0.018459867212861296, 0.036319531350126194, 0.00870297045161527, 0.012396403866249227, 0.034476339126065854, 0.03493237594563154, 0.03668728036685817, 0.02017581989357789, 0.08301630586145387, 0.05759620618435645, 0.05244838261616327, 0.043409311197577946, 0.13760961592197418, 0.0503841893477065, 0.07635186186000224, 0.0644023304865245, 0.04056253230139133, 0.029200603772375374, 0.06651420506738848, 0.040603498853142225, 0.06475323706024116, 0.030858360583924, 0.04491529833044737, 0.067307649991445, 0.06656905696276696, 0.03467440349800933, 0.04201694256475857, 0.021132209803909067, 0.014663043529576352, 0.01346531677089872, 0.020673876635790355, 0.025572947624530044, 0.017138980329036713, 0.02260161049273466, 0.08833044328756871, 0.1423285336744401, 0.13234432426191148, 0.18570571897491334, 0.16894636585587458, 0.16589185072770044, 0.09864620023196745, 0.17639712250280767, 0.14157795136974705, 0.32491961494088173, 0.06521999144986754, 0.1286561318462895, 0.12001961664927584, 0.13450594859257822, 0.1533295409453492, 0.23122502400750117, 0.19150477473533925, 0.16411832653947417, 0.11665296665723286, 0.12190466025663961, 0.10023888170478806, 0.21978013007150543, 0.28857790534534766, 0.1661017434971948, 0.1594840155373658, 0.37768529968396314, 0.1477055209538629, 0.13183412502609915, 0.16036535372897504, 0.12532446142886916, 0.1202950482406924, 0.14046796657625707, 0.13575920714966713, 0.1599274731932148, 0.21036265718360103, 0.1754511877774231, 0.23310987609288386, 0.15974886745454805, 0.17364262272754025, 0.1315108512438113, 0.31145163601444614, 0.24274887096497322, 0.13903031065579385, 0.12716327163000263, 0.23207873706856083, 0.22746799093100334, 0.1328200035758557, 0.21360972085066382, 0.2022657666595713, 0.11077020046932083, 0.13753771090940123, 0.12127362597253054, 0.11323272115400723, 0.15576187010493972, 0.10173479861189282, 0.14814392242941166, 0.21875798491941345, 0.10440526620274591, 0.30361982723397596, 0.18183781765401366, 0.18315334383758808, 0.09337913124792038, 0.10457348378915941, 0.10134806976683679, 0.18137582067039706, 0.17587541662637265, 0.10132923166477874, 0.3088273865080649, 0.14603270668416254, 0.15194577164947987, 0.1323578074093788, 0.2214624285097084, 0.09877164712956837, 0.23349632148540791, 0.11105039712762642, 0.26178241737427255, 0.13510971780746214, 0.2426106074163991, 0.19573805403084527, 0.23104916086360333, 0.15480458195651733, 0.22121633042491254, 0.18373350222264567, 0.14530774235965746, 0.16665752496450179, 0.1229880311556401, 0.16426290265254437, 0.19898812076257122, 0.1358787015440964, 0.15779319820144486, 0.3269599522313764, 0.1784982871744902, 0.1698421831092527, 0.13568744003292055, 0.11962208596448745, 0.21506867401542204, 0.1367758211469458, 0.12184177975981467, 0.24532084263140158, 0.1311867347648067, 0.1586228561016821, 0.15284882077286321, 0.14160962144453682, 0.09800889934863775, 0.1729917084617961, 0.2038005472070748, 0.08942186577065338, 0.08039658393470511, 0.12818352454492163, 0.22868519739037563, 0.1494283301215018, 0.1116015054585953, 0.08941947557632962, 0.15569820819843203, 0.17558156062037716, 0.19965769693015084, 0.08512474836841707, 0.10356171912844143, 0.10616028170672157, 0.12545705592680362, 0.12135463210964396, 0.13630017247651854, 0.14820910119000943, 0.15408473509934642, 0.29433842688318224, 0.08409501128499547, 0.1763051766301355, 0.15972568563395934, 0.22437589152926402, 0.1203795400778613, 0.1067817169091394, 0.10635562646653383, 0.18180225585256854, 0.10252965313773002, 0.11658473886669644, 0.21329145728340074, 0.15572629298173613, 0.14982936182810416, 0.15559924496037347, 0.203828003798281, 0.22709630039190093, 0.14865844240111692, 0.13078518211841583, 0.12345006644365289, 0.15028545993470377, 0.11830986161986667, 0.1439091875668495, 0.1299706008285284, 0.17851941587944187, 0.1567898834905317, 0.15554252381045974, 0.10753210003097212, 0.16841286222540564, 0.16746568643758375, 0.19799689491910322, 0.10013991846672951, 0.1093403280021683, 0.13722680178621124, 0.2730499772775558, 0.12178747944774167, 0.16141005250955784, 0.1775196098512219, 0.15527860652054512, 0.10320649181883182, 0.1294078939263859, 0.12972399712570254, 0.16681440444963594, 0.11559365857993403, 0.11938046183316939, 0.16928908294968067, 0.10290328187928086, 0.08188083332272307, 0.19354330405833262, 0.14937960692951757, 0.15829084891705744, 0.09360153423321825, 0.12451207115044519], [0.00018774009526344843, 0.014403803206439462, 0.026264138962893237, 0.047576840996982596, 0.03696831206100122, 0.056287770144521236, 0.036443380954405, 0.011731496046958192, 0.011808259014581001, 0.06289841945192988, 0.07157752530709391, 0.03245937517814098, 0.07623193845633539, 0.030221354644445163, 0.03506302074979871, 0.07653802888648165, 0.03247326435220819, 0.09289975172930187, 0.07872770735693556, 0.01882640772589272, 0.05651554723660793, 0.07056838066707696, 0.028061657024907972, 0.04677232993285983, 0.052650752402241194, 0.006018494943066711, 0.04858671725096722, 0.029383886477819858, 0.016678023309777343, 0.07148723418433821, 0.0408849825391606, 0.03799021206495743, 0.10554605539167121, 0.09565267336344528, 0.013434769972527941, 0.027660583183469794, 0.053262718757914926, 0.08846052501711155, 0.050492816784929846, 0.10547232708983845, 0.06329951244556616, 0.07377032175539963, 0.026068158350103808, 0.043165113010834304, 0.11462949862283085, 0.029130297968344345, 0.009863821568057663, 0.07605892515951589, 0.059827379807229006, 0.02080454059215563, 0.03629888145012721, 0.03699648111397701, 0.012885138276033105, 0.019633092564500628, 0.021770108235819687, 0.021722905728365147, 0.0395685140674393, 0.025604274874973684, 0.033584834947701425, 0.04913487614342763, 0.031345577182007894, 0.051164721859799284, 0.007836652850176418, 0.07315602649243609, 0.047055659890775724, 0.1012720968273859, 0.0686530919084626, 0.1408240748869796, 0.05483219542750909, 0.047416920142789046, 0.04885314347883386, 0.05160207379489176, 0.03166247519754595, 0.0269471638039836, 0.04911013916435261, 0.06225438082530614, 0.06514174322928153, 0.07612287051855557, 0.001357204000082528, 0.02002534873393034, 0.024327125865966085, 0.05684585370604069, 0.09284965723993317, 0.027782808681349122, 0.018295405372496576, 0.01776765697755881, 0.024823336336281032, 0.03873815519675132, 0.02245610741327607, 0.03626602393905482, 0.02944081830191276, 0.07236446614467329, 0.04772420950053681, 0.02234321478153429, 0.04940828526272409, 0.07655829957295811, 0.033195168155455784, 0.0815604400310305, 0.02011183239970236, 0.054815081023280664, 0.07266298762612766, 0.05740918496984148, 0.07172145790630771, 0.05305763702058504, 0.017214321245950077, 0.03938467594824972, 0.018231496402633288, 0.03953974363544295, 0.03303218678000473, 0.03615491820739643, 0.0665621928149654, 0.020652554493637818, 0.044036733377124035, 0.004934618426036211, 0.03502508024534872, 0.0345768575226107, 0.015177413156526464, 0.07691885885452071, 0.08139114226064376, 0.02686103636909637, 0.010132470408514624, 0.06565954205730269, 0.02087404966474541, 0.003085170615269172, 0.052738779735180645, 0.018424161769930395, 0.020104033624633186, 0.02769992945926084, 0.10481821823745005, 0.0335508972526558, 0.12607460706344537, 0.046272572475455465, 0.05505390510323548, 0.021312146620344252, 0.013248520591596683, 0.06687909274572326, 0.022501735610046217, 0.04178724259198193, 0.011890031239618699, 0.0287824921355012, 0.051006743038493785, 0.0292032391148349, 0.029756684013972842, 0.037820125224008676, 0.027351744412895174, 0.16498160037782886, 0.07259975472885756, 0.03454060624203375, 0.01959998607485285, 0.036003462624766176, 0.07581018407138125, 0.0318259583605874, 0.030092019850628513, 0.06648761415553671, 0.02432318434359566, 0.03627985565652771, 0.050605178900784066, 0.029580876411449526, 0.030407726599444306, 0.047781639281780496, 0.046889832498685974, 0.0839440000333613, 0.03957138689715536, 0.0755078704547017, 0.03148971854018108, 0.031039708917359674, 0.015774406323720132, 0.06091722414918965, 0.039204170311530756, 0.1122716868356351, 0.007699706494027088, 0.060574706238243854, 0.017221825077168403, 0.07593732402329484, 0.06031428230926395, 0.01767407933760795, 0.04066580095358434, 0.05524405961736076, 0.0373666126641535, 0.10942779992136265, 0.04478648447641923, 0.06540471823104928, 0.09475366152342289, 0.007181869840414654, 0.04204241498824089, 0.058165987908479676, 0.025685893882426526, 0.01421225728512171, 0.07848775329729242, 0.02216892786354067, 0.005985517730756153, 0.05421294357567545, 0.00661903940659437, 0.05489157490252007, 0.028079043390349518, 0.023292399634937608, 0.024834728063715082, 0.034598587606582916, 0.03983836087788786, 0.10008074583545809, 0.052743969980867646, 0.09539394248877803, 0.037236301108233394, 0.0506703844744592, 0.025999145319445, 0.02905410669383503, 0.01877510473282347, 0.05878956049620625, 0.02317616302940634, 0.017617911686219515, 0.06598614066118194, 0.01871553948149085, 0.06813853363236112, 0.050355664063845916, 0.03894943458538863, 0.026123879755276348, 0.024619880620570436, 0.005190972991723327, 0.09772699431426103, 0.03233988461415133, 0.007688515864673161, 0.07798325375563676, 0.005382478693425055, 0.06926836010308997, 0.01291913151245324, 0.014045352581888439, 0.06242891863709497, 0.027844109121830236, 0.04660928727037484, 0.024961820135133404, 0.027607460731580376, 0.023847340320747708, 0.041789770682132056, 0.04005499522111589, 0.04752449803955613, 0.07211215508681151, 0.024698594239570444, 0.06692485117744054, 0.039010790567244255, 0.03264555752637886, 0.04916532813841778, 0.04009894185489224, 0.02753012798606388, 0.03592308084931105, 0.024965729098767046, 0.1781622963326593, 0.03696372319433478, 0.028646509613721605, 0.01304414940081657, 0.03847976140077076, 0.06441883968129274, 0.04299488827405919, 0.023178413412683917, 0.007036325583730134, 0.022249298147676934, 0.04851155253427644, 0.03989976282501894, 0.0849978612255185, 0.016802887980555816, 0.02144521034713234, 0.01835310136929395, 0.059397140998513474, 0.05446574109936914, 0.05439850922313429, 0.030726656663201513, 0.07285443299840536, 0.0121990634473942, 0.0403759477569932, 0.017519279781188217, 0.017195282045811895, 0.01108509499669796, 0.07208955549304524, 0.01490158319938928, 0.01027481912094499, 0.012793730580127768, 0.03002056108427144, 0.08296551423207407, 0.06772532878864197, 0.07343240803287876, 0.019786968984971606, 0.07718076899407372, 0.019944595405831933, 0.06824306632962919, 0.021500489336528608, 0.03931988023161408, 0.032398769962451154, 0.051862704567611224, 0.020496743701158032, 0.025674101874052037, 0.03286686883638463, 0.0272601145514918, 0.03246610143011616, 0.061480846526401664, 0.013976697697334233, 0.09362825538001715, 0.06227848961228325, 0.06622790268832637, 0.04670309856714261, 0.056168850316035177, 0.028881666047738928, 0.01151954920421685, 0.0590391825854538, 0.03692304775599511, 0.01454800297881687, 0.0731521271049015, 0.07154428475205937, 0.03832370162971559, 0.04962341807362053, 0.020925304777319395, 0.03900361615383337, 0.027716116897100886, 0.07496394036758332, 0.023415333764146895, 0.03706993745459664, 0.05948535985343399, 0.017166559494310812, 0.05815808954198034, 0.027575907485199072, 0.026967407677382715, 0.07320657297368012, 0.019533135327360323, 0.060645584692998286, 0.07859523543306897, 0.03088597422315469, 0.03617279103866989, 0.020881065114912008, 0.07025777797905669, 0.04353417969879605, 0.04260898680396138, 0.04671169790409265, 0.06760624042081256, 0.011490735679774756, 0.026579650359288342, 0.07240168269603484, 0.060132792249562285, 0.0624550192526752, 0.02229991932249358, 0.10580034295637762, 0.08290860922105851, 0.013775830401197798, 0.03150297186127113, 0.08458311654507153, 0.060840998400723746, 0.08289491922985162, 0.039301735439127496, 0.04193718898140135, 0.035232667090190996, 0.026621505573031404, 0.09032752725385851, 0.05505865484836602, 0.025168535554961815, 0.1678225301927136, 0.11206046873403173, 0.11363908483256256, 0.06882808171212673, 0.17903315444146434, 0.08240899732035976, 0.12179396055158108, 0.12248844223757907, 0.07821780689541372, 0.07324908319259844, 0.11817536722387999, 0.11696862552555339, 0.14490474946796894, 0.1665917026900476, 0.11262180433878977, 0.138746413792814, 0.15465760032736486, 0.1235850511359111, 0.16053438336858827, 0.1637843734915218, 0.07824283498789995, 0.17228280134018392, 0.13926706246791348, 0.12312450205847142, 0.1668427650245928, 0.2166492666207975, 0.12289429263722514, 0.18124155610078768, 0.14084439153873152, 0.10556702321815876, 0.20341520498116172, 0.05313655939854441, 0.1144943300694708, 0.1828902386008732, 0.13364995258950418, 0.15704404082029097, 0.10682418116278226, 0.1551851284720244, 0.11284355614935199, 0.19189777784049514, 0.15213444378347168, 0.1330620107511359, 0.147746950988808, 0.17734184680927187, 0.14493425917481223, 0.1594363189032001, 0.16674718789515958, 0.14436608240489038, 0.12037901147719353, 0.13754537178864404, 0.12222576601010178, 0.1156875579768131, 0.14009394712986487, 0.108544240074773, 0.08831842336803676, 0.14830961192567504, 0.1421004692993818, 0.11044986080378295, 0.10656763363869921, 0.12962290416321448, 0.21793474683598166, 0.11053425304952169, 0.15781909197328553, 0.17930350686994292, 0.12346781670085846, 0.1279963156388652, 0.21113933244299507, 0.17293941530008472, 0.2429564041836608, 0.13403503434552302, 0.3441639581034261, 0.1088563519560041, 0.14814107258233333, 0.11305951633520665, 0.14219220066743513, 0.12445781680364763, 0.16936883270259828, 0.12237551321666088, 0.1516054753935145, 0.21411481794090043, 0.11943677695648325, 0.11868888362040443, 0.12629622863906045, 0.15325999548358304, 0.08132671426621177, 0.0988129775730833, 0.21848861308347797, 0.10624937007143613, 0.24390482103392003, 0.13135695950158183, 0.14684878950638158, 0.121113705118337, 0.14852394800513022, 0.10920573401475146, 0.18172794532391334, 0.1286011726986016, 0.199614412962429, 0.12678555963981536, 0.19240354908810509, 0.24050984111043716, 0.11132400542978318, 0.11586856923156208, 0.1767254218218788, 0.11900923860770081, 0.11553542823680948, 0.13799768542089771, 0.1124947409956686, 0.23070446726295257, 0.08066024075472548, 0.1174935719539081, 0.0889672232311099, 0.1903396009677841, 0.16927714729982038, 0.1894546008758968, 0.1280843008369688, 0.13234607094237882, 0.10692895900818611, 0.19420934089970207, 0.16018020559943494, 0.1910116439384799, 0.10733071083743727, 0.15579101208957935, 0.18344211301976637, 0.16934217284283332, 0.07859423185788816, 0.11845934069565228, 0.0947493484484092, 0.1386778336018324, 0.1621504764883749, 0.1936268995726301, 0.1329760863295486, 0.15019087871957212, 0.14047308404359127, 0.16728076813442094, 0.14228911078985662, 0.18558691405961592, 0.17514078427226315, 0.10694062652727289, 0.19223122527041744, 0.17189604951249016, 0.12372626412299373, 0.1549118342659166, 0.11906602870552771, 0.09841606741951359, 0.1870125883649434, 0.09325320171492715, 0.20655840244745055, 0.17546935938298705, 0.1710457532035728, 0.10140814638185887, 0.08324079260590576, 0.1750542776238534, 0.18757065277426474, 0.16164450605790462, 0.13402332852204002, 0.11748692997160459, 0.19494058714518625, 0.1071662930471282, 0.19592248203773655, 0.18431269533691869, 0.19050449373260622, 0.16348452667795843, 0.2214507073644669, 0.09874242087525707, 0.12450257166018411, 0.0989326558286144, 0.1474484984552668, 0.21275118143568117, 0.18405167385935786, 0.14199588297595903, 0.166436355380762, 0.11324663331071216, 0.17591761274924203, 0.17239448163778553, 0.15717851989451917, 0.1600014619649418, 0.24795635363026974], [0.056722184132424094, 0.00542046468434555, 0.03163176464788135, 0.06234253839319272, 0.037761197740873026, 0.03022148487939229, 0.047111067199899305, 0.021679933941472444, 0.0519767061116234, 0.014255281740559206, 0.021520647025036237, 0.03583440617207558, 0.0635551100206231, 0.04297687754695935, 0.05511319647813517, 0.02982690363311239, 0.022503970671565305, 0.0583650826686813, 0.03170730091721541, 0.014436491220558604, 0.01734208172908233, 0.02613909426145256, 0.03071886554901158, 0.05064690387958, 0.03551909204332098, 0.06121083117660977, 0.03187689554667281, 0.045743182737139926, 0.04811552338181965, 0.013479924152394938, 0.01703703700895271, 0.01632380915144759, 0.03960225641006424, 0.06364705972373486, 0.0309885093461602, 0.0352325598378816, 0.007840851969611382, 0.053816994862450715, 0.07079583983267508, 0.013748753023514105, 0.04374681506305934, 0.0057018540457882474, 0.0511676598069889, 0.06000168396220092, 0.04163667184090422, 0.025378146787144007, 0.0892493580918639, 0.02657262916346231, 0.07856024053668784, 0.0329755537302023, 0.015006095786849338, 0.014255612115976552, 0.029267791598554582, 0.008337301363597715, 0.03538924014015544, 0.050979569899819555, 0.050247151539811206, 0.029622670338158647, 0.15251647650955186, 0.06926740249318462, 0.08566464883305373, 0.05851170806694896, 0.01639023472014214, 0.02971876266172096, 0.06145844228505608, 0.029642806959248362, 0.03872570243754214, 0.025118563639660998, 0.022824400352434288, 0.027243120806111444, 0.02785717475137884, 0.04999805039035217, 0.029300384809293097, 0.10464661454241123, 0.06937205776452057, 0.04145002600947215, 0.04772034075651919, 0.1197808959911908, 0.021439029932803205, 0.021751224168486172, 0.010554165421654622, 0.06070438194118681, 0.0254962143428143, 0.0272539762719985, 0.053905520152540944, 0.029689174430865436, 0.06925527532134326, 0.0831392323297839, 0.04152768051191684, 0.0523353310211772, 0.08075244709729187, 0.03211060598973305, 0.010391035616668242, 0.03758429271739818, 0.00949116958861029, 0.027519546396609758, 0.028034102757491415, 0.027703983979600093, 0.053723099296011274, 0.08227357595798471, 0.053808100581649816, 0.07012539798574102, 0.030133702694588614, 0.015929292065031346, 0.03991243391928654, 0.08738336709117697, 0.04901595631494157, 0.04369045780490964, 0.06905903423865957, 0.05736398195186931, 0.08397193925995981, 0.09295532374732918, 0.053569625071700544, 0.08808457502915014, 0.0435111740784299, 0.009636979103238593, 0.12801334577342197, 0.0371111644762418, 0.007841714297331149, 0.0166212102293127, 0.027399542553710843, 0.03874456352223793, 0.028541752835735682, 0.025271260284728585, 0.04398508372926905, 0.02829005273299352, 0.04618781633795269, 0.0400612962942931, 0.08134012080488667, 0.0415252213696799, 0.04715635831798277, 0.04594123178732492, 0.05445160677716617, 0.040307658679422834, 0.04589148203752214, 0.012103813820548598, 0.06198600873411183, 0.023573375787706147, 0.04318156474900823, 0.05728155472165635, 0.0166151428129524, 0.022496604736173348, 0.06513106396361705, 0.030307805751480406, 0.029226221752563314, 0.04974821379648582, 0.021939277686479113, 0.04609310871831352, 0.049277732389107834, 0.0594168677625637, 0.03098832740027818, 0.048637551015182856, 0.11211070878010605, 0.04306325779086159, 0.05264303406640407, 0.009755679639056325, 0.013475085349543201, 0.04975024775992479, 0.030467563811990044, 0.007428144604238051, 0.039303420832560915, 0.08957075495873729, 0.01752936341349156, 0.028796279802918438, 0.025984076369974404, 0.02199354927025495, 0.03490946608625593, 0.011246682092126821, 0.04804649885984198, 0.0465546039143397, 0.04113119936758473, 0.05159779519383466, 0.0292418614375375, 0.0085259897769579, 0.04655473797972645, 0.08129072345552907, 0.020822298510240454, 0.011509248194464994, 0.02335339555546882, 0.007864058209252695, 0.026489355406093023, 0.09869232638588837, 0.027358185297118563, 0.019542123453931946, 0.05761716634996476, 0.021962200952393394, 0.025343588560879714, 0.029364058207119667, 0.04594749072566629, 0.03595977263044446, 0.03787388544409506, 0.03843820113087854, 0.10225277364013657, 0.07981837141297518, 0.011709445163667684, 0.08543574176127873, 0.09581752016299194, 0.04104118786692139, 0.04832656145276082, 0.03540657287944229, 0.048851787503207886, 0.07456742091885499, 0.031063118649105874, 0.09222472101570138, 0.0344947099144901, 0.019148819659265782, 0.03884459162251123, 0.05338501703414706, 0.03672087715277749, 0.02158145333880619, 0.011165607007100217, 0.008465274436128958, 0.03427547087231952, 0.09131875309732654, 0.052865352782030264, 0.01203948254471705, 0.06137390448261173, 0.03971561444022002, 0.06608587764804402, 0.03619535998891919, 0.04135143049361725, 0.0695412636043564, 0.03511560502492132, 0.0605767899973979, 0.025854209145050377, 0.03533801184065881, 0.027863286217794787, 0.04895047878005332, 0.13054568771152728, 0.0593638736304016, 0.03482241168498032, 0.014768951354668507, 0.03681691393496529, 0.03892225761627478, 0.07620505643107238, 0.033956851074171644, 0.09996241589467372, 0.03825514442137173, 0.0004830005409237328, 0.031472173211495244, 0.07825851680770998, 0.10810789171486132, 0.09469969062915734, 0.01887232320563447, 0.036717686396572864, 0.11002005483474463, 0.044127005347681623, 0.0493539504766945, 0.007564094088475912, 0.02086443526129569, 0.050723179423760985, 0.05909121910771055, 0.05138292285283247, 0.06223019925997623, 0.036769424144539146, 0.04304207162931562, 0.015573492104698335, 0.025940338495157422, 0.017722699107722412, 0.01831661260146047, 0.05616119709767162, 0.05481832157520037, 0.04599397311047201, 0.03805167529912245, 0.02594399081933643, 0.0076330530141750655, 0.03642108396536881, 0.021768784818930492, 0.026314310061054367, 0.016884704255649162, 0.04161381560768332, 0.016030463551531638, 0.06345183753799047, 0.017021889535469875, 0.0147432136732424, 0.028054982483867678, 0.11588630416700918, 0.06163658837096826, 0.02444579863109656, 0.045261278958810915, 0.024559306048397577, 0.027057323417055513, 0.06402300971169626, 0.016229216444997058, 0.053502676647997675, 0.04089566180482507, 0.027276849742197705, 0.04489203607062659, 0.030048913998349063, 0.06032564722362065, 0.07727973989301151, 0.05272582901882068, 0.06124867975050884, 0.03705966421553204, 0.019013737290797215, 0.017294216555573286, 0.0450967462553132, 0.014598469020828847, 0.04591348408270748, 0.03280147557116805, 0.031137490464795022, 0.01860188076182479, 0.05106427241116763, 0.01725349515195816, 0.1634622028758449, 0.0021983441218899023, 0.02229713650810863, 0.08373442135991589, 0.056208625601063815, 0.0185254251869816, 0.01936123668847065, 0.003308862543499638, 0.043205259848506226, 0.03350871645154492, 0.019760630882134842, 0.0513666243322434, 0.011463052135020977, 0.027033999870200793, 0.009797511870161662, 0.03622919809253466, 0.03686439223407257, 0.044724270476088415, 0.03146110898664883, 0.031025791014995308, 0.0321829553333021, 0.06953454501326047, 0.016484869561428507, 0.06126871294972878, 0.0787263743639473, 0.020254399447191148, 0.02462596335868922, 0.036634684600416696, 0.04960492088068878, 0.1557428558026591, 0.05984417628496886, 0.06227851259492098, 0.03804407953735321, 0.06809983087042648, 0.03144789780039461, 0.02951653460190902, 0.078698756894277, 0.028013841647114006, 0.058479042077857646, 0.04073715821329144, 0.014345394747872508, 0.009814044047567633, 0.028045762615698962, 0.042310626200971105, 0.030898988141768405, 0.02375791870778607, 0.06862097750267676, 0.033228688332582676, 0.14651468324084438, 0.1306566019212046, 0.12212365415067443, 0.17836481933632206, 0.19274620489487726, 0.21912823521321823, 0.21384780565577172, 0.054732117531520706, 0.11493609467100714, 0.13526167900812242, 0.08254635688518325, 0.13750502959855143, 0.20803258544014347, 0.13018892056518985, 0.18313316508166252, 0.10231635127697261, 0.21620872009906078, 0.2826299374142001, 0.125485653989017, 0.12634995438519026, 0.2064418804741675, 0.08939810938412145, 0.07263752286352458, 0.18912270094358152, 0.15736297854492742, 0.13617519289255142, 0.0925280305466825, 0.20077168070260556, 0.11041340267946644, 0.06516452668414963, 0.1340611426219825, 0.13940693480112862, 0.12295901940594758, 0.14789051586581817, 0.12683015361788774, 0.13789683760654542, 0.1610109207010077, 0.20391094047696362, 0.13514166367390465, 0.06493195005121731, 0.07509527848132196, 0.16579995082030374, 0.18430292005500487, 0.17340187193645587, 0.20791839237415022, 0.13692324710709436, 0.21841548233022615, 0.18445439095939362, 0.21582415928283047, 0.10744666590565637, 0.08962820389217908, 0.18107389009767966, 0.1767224647224911, 0.1522967778146267, 0.17281556952624552, 0.10319772011209881, 0.14977945886071653, 0.1398154588476304, 0.2248139099608506, 0.16958758144849734, 0.19501688950244458, 0.18858107678111524, 0.08334300405676327, 0.11549988941800211, 0.17846563650715738, 0.12430840667577521, 0.23878894716260896, 0.08504443937131474, 0.08876331360830415, 0.1550998782078105, 0.1421270831938713, 0.14261393206975154, 0.08655060653484638, 0.16853387347392498, 0.17739377224877959, 0.15444406097935093, 0.15697026655318277, 0.14416568912565708, 0.1251027709053409, 0.13476418151009467, 0.142473952484227, 0.11508633983471703, 0.07615859319846477, 0.16863519626279033, 0.1232518028888491, 0.12504218101140954, 0.1390281196443304, 0.2135592509782122, 0.1240999541515785, 0.1310205396505133, 0.17168036511828824, 0.14078126589377082, 0.14746708374830986, 0.18255093825920937, 0.14335620998134538, 0.09090981536334561, 0.15600404581956326, 0.054538967613611496, 0.19075998405535377, 0.19070145493793875, 0.1748033072198591, 0.14625684868904854, 0.21162754495538053, 0.14207004028702938, 0.20271159918798556, 0.1545486473027737, 0.12047701710534674, 0.13861990203299832, 0.20087283495212757, 0.15283944385667003, 0.15657965364235063, 0.15021041396164125, 0.109829337245995, 0.13785975895101024, 0.15032189507638255, 0.11898229529540386, 0.18459758811420013, 0.11518792309347661, 0.13623513161174713, 0.11450314774147927, 0.14985452015553752, 0.12175861325475479, 0.15090634355381613, 0.11493325248480805, 0.15561894874178595, 0.1731327912139316, 0.0912260564584886, 0.09844447395974591, 0.31409466999673075, 0.17050661116598115, 0.06414494026572475, 0.19186072982847693, 0.17687436463611741, 0.279639252731877, 0.16506605391060153, 0.15996712590417556, 0.16026012389169586, 0.16405849507258785, 0.11250025682872343, 0.18028716376471907, 0.17141992586754984, 0.14704671598249866, 0.17941167848485132, 0.10916261092549372, 0.11209432982028493, 0.10669799882077402, 0.09159830624177571, 0.1378286251377675, 0.090463561486573, 0.17798269467969097, 0.09450626108915576, 0.15549577712532014, 0.14883479584128628, 0.10677898197524971, 0.12298756384200628, 0.1425670168452686, 0.12786320786202146, 0.42286251581484274, 0.19222544896746838, 0.21588561485611626, 0.13801510626029584, 0.24547257400568456, 0.09889481874603419, 0.052360186743880474, 0.2170317283561153, 0.11890580141616446, 0.07776019959560326, 0.11040665344485354, 0.19943242111513693, 0.1341657749106807, 0.1052850032705934, 0.2157389396621335, 0.12182717812397789, 0.09309548719395554, 0.28356343087169433, 0.13607523374019131], [0.02573778101753804, 0.06508390359099835, 0.04579189060736568, 0.09025553031073463, 0.0918534824684743, 0.01989024912848348, 0.08161007486764463, 0.040791025685687224, 0.08683208255998551, 0.05429386161267758, 0.07832672161560866, 0.009167206327190563, 0.04471570178265533, 0.0222988314776411, 0.017083008030068972, 0.08373845098239761, 0.01691777627134035, 0.07170761469751596, 0.030788451230393785, 0.0451080575435152, 0.028992737305440733, 0.08996429432544018, 0.009200337714695883, 0.05451360627287819, 0.04172774437334269, 0.004420563852744959, 0.016425756301971215, 0.017410698309240323, 0.05885162893983145, 0.047909219734250545, 0.01996146466192459, 0.046749963995910464, 0.07234466277183065, 0.038661653656632676, 0.050574006783145095, 0.020915343719083938, 0.017890367026050246, 0.0442218393718283, 0.057553282277959014, 0.03336735024687744, 0.039138888129063194, 0.05430511161384564, 0.047597349170715585, 0.08927762673626985, 0.09263425629826323, 0.024118315195664767, 0.02826899297595505, 0.02212952030071568, 0.019416419916876385, 0.0032251080659578646, 0.06842573233429464, 0.01001064997962526, 0.03368428848203152, 0.011900595592094526, 0.037991449296955145, 0.04232956389445932, 0.05987671586955267, 0.03019919363601554, 0.047200350917034575, 0.04259251591358935, 0.09802362355854242, 0.02775620053251905, 0.05382519583368013, 0.09126843644245979, 0.059129630756233974, 0.038409350259650143, 0.04904963737053256, 0.004713011693374645, 0.014806842063403419, 0.03952080594195474, 0.07638376942204853, 0.03081165411840043, 0.0265083582170548, 0.02212707456501742, 0.05045460048882712, 0.03344028181726894, 0.025165293087822296, 0.025879612620619517, 0.07478282952140416, 0.06308570879721834, 0.09432593165265937, 0.008993673048192456, 0.019450658301432288, 0.07622693590218983, 0.048126666130678314, 0.03758402458662468, 0.03064833757948251, 0.053008040488367124, 0.029425094347266905, 0.06842894224269737, 0.047884287402754834, 0.03363378796606295, 0.11576328576812822, 0.04945094486878765, 0.082478481495092, 0.05266137421131135, 0.042093386648282896, 0.01091306612286116, 0.024337910468720143, 0.01807045322963067, 0.018919339936767376, 0.06915048215418093, 0.06496952666390328, 0.03592836685598858, 0.045182797081408, 0.11341147244937959, 0.012384644416611523, 0.03979367496926458, 0.056731250783007954, 0.0418668084837977, 0.035724560655052626, 0.05927067520397325, 0.0559876092349089, 0.06846383754764834, 0.011884206098564451, 0.0216791027360746, 0.026245467484958714, 0.007228921524309103, 0.04075805326142619, 0.04894086054616398, 0.020944954932577187, 0.09539486179428716, 0.0626003806058678, 0.03878526194321533, 0.016000214569841423, 0.019377096623723066, 0.07071668762833842, 0.018637178262936014, 0.03785669060063459, 0.03664830181327078, 0.040135679601301114, 0.021212491987934037, 0.07496755630258592, 0.04153745962427028, 0.03874402726069093, 0.07455766095869965, 0.04543737958996527, 0.06481656954894144, 0.07077733114842447, 0.017126236456416307, 0.003915964959061615, 0.08285077724365458, 0.047389057524982965, 0.03784473196813657, 0.014901469243810543, 0.005348920211901949, 0.032889372669160366, 0.05375666543841363, 0.037236167042846643, 0.02049421944144753, 0.03620461816148412, 0.007252440423584514, 0.009931090791078826, 0.05846784570284429, 0.027132250646489765, 0.08239855554195182, 0.015034345279057181, 0.013718685987705906, 0.0033829463580097524, 0.033943195556921345, 0.04316132470604874, 0.03402258524851453, 0.022692796023141955, 0.04886933474711353, 0.03359190210880291, 0.046012933786597945, 0.060631795110361236, 0.06907039532257665, 0.011004289957664667, 0.02242734847259858, 0.05441351305513133, 0.03198701302490888, 0.045887712884934685, 0.03801877948365385, 0.04417123926442958, 0.03938956741964625, 0.06617881943501773, 0.04021478584036231, 0.03242386317241096, 0.10798923235626952, 0.04788535226496959, 0.037132672394715974, 0.06022432443475532, 0.029038057151821353, 0.021490455499940345, 0.06934768850764922, 0.0023632134252693504, 0.014899543490290884, 0.013130861935355972, 0.05282904021441937, 0.08378479164093734, 0.055585803779503035, 0.047937285365356554, 0.06273981243852647, 0.028077536112358494, 0.042267506942152984, 0.028840963796321905, 0.034067527796592445, 0.0060928782500747234, 0.060383697536083004, 0.06616182760485718, 0.028439336456358436, 0.015928458944413693, 0.05803943784426778, 0.04600343046589725, 0.02868222463275156, 0.01692810696699927, 0.006658047167283874, 0.040044522799190976, 0.00984051525818124, 0.05151018537881394, 0.03524633792919978, 0.0012170042839810074, 0.012030414936523284, 0.06090209774312474, 0.08086487050018004, 0.060728475406405434, 0.031081228967635866, 0.07466817680265635, 0.07425161649382885, 0.08980030554436869, 0.003315263208107002, 0.01408561624796881, 0.005800640126014309, 0.06137925943720245, 0.024384327736052296, 0.0803165277466178, 0.03200032763303288, 0.04235158126140314, 0.047200645860885425, 0.015958886041546303, 0.03670669686529906, 0.01608503103676823, 0.030568959379208185, 0.04979522861239891, 0.07096184342498742, 0.020177888330973445, 0.09305729005005091, 0.06916605672168155, 0.032422625940413244, 0.06159306691598989, 0.053203316300266215, 0.0603743014676917, 0.027995472773909572, 0.05248277613352384, 0.045289509298820654, 0.027304930695062204, 0.028203525017165852, 0.011267857719963838, 0.04270781597663318, 0.0805752509604058, 0.07245792887143551, 0.05024316022172571, 0.08103805999722212, 0.06764771642103311, 0.04097913857549429, 0.016934118841985063, 0.06285855606678994, 0.0371746463520873, 0.11145118368609298, 0.07307700452304657, 0.01022870541595283, 0.04144346063596107, 0.010934048313497296, 0.027622866759737654, 0.017168423003186623, 0.01179050109649618, 0.03993016885473363, 0.04069154150784016, 0.026442219931331855, 0.04492368316277862, 0.07745470671403794, 0.022384526072851112, 0.048190339528504884, 0.03603980583589404, 0.029943774176400997, 0.039153585525890516, 0.08599745274911966, 0.04338899454582603, 0.013127885683770142, 0.023124109270171295, 0.014550824097598032, 0.0752819358040729, 0.03714500257985727, 0.09006838269171216, 0.02381118097072167, 0.00818965898361057, 0.01883140070393922, 0.025593603270188458, 0.07662579191908722, 0.07458877178930468, 0.049232954549933636, 0.017167802471967957, 0.06753739975993672, 0.014333125849765156, 0.0731230617290543, 0.00812269811097893, 0.05557356552491265, 0.018884977062923775, 0.03142324317577145, 0.03396292998185081, 0.058866050545006036, 0.057679238624029586, 0.031534368059627955, 0.015401574313610554, 0.053256655171994245, 0.05486980651415164, 0.0628853231788643, 0.03143913950020027, 0.017512070893820737, 0.048975740529356465, 0.047638154844002384, 0.030386768349055803, 0.06443521098023461, 0.014632739006511629, 0.026799485034820054, 0.04060130018079954, 0.03438841138455657, 0.07004436886598987, 0.03458568668593803, 0.012109844847732495, 0.0450386155036188, 0.040114581539866426, 0.05983540457823585, 0.06907588817299375, 0.03124417778435013, 0.03558549654459761, 0.013882572304517513, 0.04177801123249435, 0.03587572895471127, 0.026135181467379295, 0.061586811808088136, 0.0613109895118302, 0.0607535801076841, 0.10553378266312423, 0.01325386597008835, 0.08667609173684351, 0.04720174902749639, 0.030089978226310307, 0.025273529820204265, 0.059403453563009544, 0.055666304298586426, 0.027638540918668433, 0.021023342964209376, 0.02373879906841584, 0.08629615043079661, 0.010728508838632656, 0.030092213287829395, 0.06729762956139541, 0.017312865050870086, 0.03740112109470271, 0.03460848546256462, 0.08297337429417719, 0.13385535608376228, 0.13262213838677253, 0.266635890809759, 0.16440519582360022, 0.09760912402623123, 0.1142389546599119, 0.08593606612374706, 0.28632465689893694, 0.2065108896743867, 0.12441935918984875, 0.09755982626830378, 0.07897881565675621, 0.13520174028892673, 0.19270053073283167, 0.21588984366145827, 0.1682085925412755, 0.21068182473461475, 0.13491102524342077, 0.13401796590657006, 0.09111691191191636, 0.1493490093778218, 0.17885235769133415, 0.15662770267696152, 0.1717001148649762, 0.093435974971902, 0.08951342859936338, 0.16758631464214097, 0.15394469422678794, 0.18672133705789046, 0.07346145042608823, 0.14959800327497144, 0.21343686077142918, 0.17234824057067596, 0.10975255225334438, 0.10927196997668474, 0.12432261760677062, 0.10715688548741803, 0.17182828137470832, 0.1879541104238841, 0.1422266286587523, 0.1851945851118334, 0.17275360833492973, 0.1697426376443717, 0.20277398938853897, 0.13064325666956364, 0.1291209633552259, 0.1152666156450587, 0.1654219323949468, 0.2408887328760278, 0.15945893381872486, 0.14545316116944437, 0.10072053650454169, 0.15906868863009638, 0.2089498991206769, 0.12864244951596185, 0.16551763209844791, 0.15417176268754468, 0.16792506340049929, 0.18510328275301766, 0.1527461956345266, 0.16382417942006744, 0.22195748984813693, 0.20348107322089135, 0.17883732704625976, 0.19721185397957602, 0.1343362294738331, 0.14089332923533457, 0.12005118713263543, 0.14288650615321052, 0.18383988119181127, 0.1137596134456896, 0.09469644241635838, 0.12028404721809972, 0.17179915471182716, 0.1317779707812494, 0.18105910460074104, 0.1426829565917292, 0.18376549405436363, 0.19144446829393988, 0.17329422126133598, 0.1373676853554864, 0.10278656072313748, 0.21192975131975067, 0.10271895346381973, 0.09478742301824594, 0.11933893220679415, 0.19740351385647253, 0.215371094884411, 0.13958710335916089, 0.14064398293773975, 0.15137895851606323, 0.18113007498604639, 0.10871748319796978, 0.3183312587920697, 0.18017805752254304, 0.09075244558193991, 0.09843508172179423, 0.13500142361848586, 0.07562092204968776, 0.1485843463770805, 0.12649447687210577, 0.19674784984559784, 0.12913721974097914, 0.19197260930893884, 0.19520298758101082, 0.12188485688379697, 0.1553907464709013, 0.13523256766699976, 0.1459549181163311, 0.06832238707330919, 0.16013525156003816, 0.1458330182058196, 0.20822637504146946, 0.1734121375146412, 0.09896389689416656, 0.09106898545137337, 0.21638718794190118, 0.09508288780888242, 0.2566777590301729, 0.1914297440840352, 0.20336173204404695, 0.13840912060151178, 0.23410891603317954, 0.11944238472008899, 0.11423284893915539, 0.1253369946273104, 0.1448460364894521, 0.13349688822223296, 0.1380311174979133, 0.1403284772870041, 0.1665568150459759, 0.20342858087631965, 0.16362236121729498, 0.16374516511155715, 0.12958573357712838, 0.19858083777850677, 0.12486017384235898, 0.15215253878024318, 0.11860469055752601, 0.2392709083975323, 0.2240963920109695, 0.13991292055335738, 0.16896375605175573, 0.07673531184874235, 0.10516593788540173, 0.11992082961143986, 0.17295528864187582, 0.15162254383246745, 0.1007087617331455, 0.17650699483290797, 0.11143585426672814, 0.14075843647362726, 0.16277903630848856, 0.14280470328465586, 0.19759184891177764, 0.15638684463356772, 0.14783076100772427, 0.12255384316367489, 0.1381366537703622, 0.19435220097582187, 0.10575681384052, 0.1894521493945391, 0.2056501439261821, 0.153770562441599, 0.16153190645479387, 0.09694066634702106, 0.1435275838500069, 0.12218949940776634, 0.13385356343801946, 0.19170164401012083, 0.14919395318194745, 0.14347913644967542, 0.10078353191455526, 0.1601605171397809, 0.1728530618692598], [0.11560688125750712, 0.0182227649155163, 0.029367356215633696, 0.046067329859661485, 0.07896218388792008, 0.008600713035482313, 0.01856208249415842, 0.0318741567823435, 0.020977235962486556, 0.00680079855467944, 0.06686546404155032, 0.03780734687743168, 0.10332950255683354, 0.03367329128987847, 0.0149755384547696, 0.008737301724331995, 0.03422694686319559, 0.045838679427341114, 0.03204030210092183, 0.04735075695920856, 0.028891765001800754, 0.03922233425621544, 0.00826359221396307, 0.045102059075068084, 0.07105766570255642, 0.037272529406172615, 0.05370994173591176, 0.046692231609936685, 0.0018556136215451145, 0.025172011678918235, 0.054472735482117826, 0.02071469954605545, 0.013782448443253676, 0.03864965671973844, 0.03258252381196907, 0.03388068278230006, 0.060557247094449505, 0.07309031147029131, 0.07581328672747459, 0.0313506257014289, 0.030091117782097672, 0.019250519746433825, 0.048534638593874635, 0.05605897032505563, 0.029565299928729093, 0.04217345815812869, 0.0529340670383986, 0.017145942153048613, 0.019010990865588672, 0.020797396822261716, 0.06208666885692266, 0.01888420139890044, 0.033357942687167276, 0.014252200151883788, 0.052584788401521025, 0.06217906289103051, 0.10114506412778171, 0.012856471265906529, 0.08427467422499772, 0.02187727436032747, 0.024525128950875615, 0.030224499435374336, 0.06203995281530004, 0.04073129381023107, 0.108408221163817, 0.09887637134881751, 0.06862841621642152, 0.03283802179559585, 0.023142139149469235, 0.0271369812394222, 0.02841071924194694, 0.01154923894172234, 0.012262400724143993, 0.01427124318246159, 0.05037362116479105, 0.017779743929784146, 0.015805417562895004, 0.0393555722680063, 0.014914918874931193, 0.0564170551426228, 0.04143051758048035, 0.038059106351987976, 0.0690041823432811, 0.0716512459480474, 0.02375060065288938, 0.012119229424804931, 0.006966111231445065, 0.02569420402118516, 0.04835865670634855, 0.09261921033143036, 0.03280747020917554, 0.05426260905580656, 0.03933053651464082, 0.012864467308616206, 0.013850142845072815, 0.025720932828863303, 0.03608060001786198, 0.09748130991694429, 0.05385592362032302, 0.037987166865458416, 0.011305156625777243, 0.06010358131700947, 0.012347067803925565, 0.03239796557013066, 0.03518163414311505, 0.03355239112410815, 0.046805689231522625, 0.0615666177304041, 0.03434346883647865, 0.060804942472567486, 0.05346043455985285, 0.08991175601559301, 0.07488775292351361, 0.12646161170015413, 0.008303280356490325, 0.03156206596853032, 0.02625673663832488, 0.024322106074842236, 0.03209171809195992, 0.04647218817544561, 0.11062052221067491, 0.009388895893108942, 0.02881626129120348, 0.07454551080422056, 0.0687710541270433, 0.04909724590458697, 0.014220590406518071, 0.012188831385555527, 0.11861983611578904, 0.05192101918040745, 0.06213294822842844, 0.022406953296834425, 0.04852533062559463, 0.004413015492666032, 0.07935788362256943, 0.010644536983642367, 0.05613734111970952, 0.08728840283208317, 0.04451756080191943, 0.07780807242999155, 0.05206672527316598, 0.028642037575463616, 0.030123812499486154, 0.012519196269192524, 0.0380745200410245, 0.015393846401674374, 0.011154619391046224, 0.03327066995083325, 0.02986648356572034, 0.00739231946006898, 0.0107328123375473, 0.05019752436407632, 0.05797605939029206, 0.09048080612574855, 0.034286054376993454, 0.06263219623736317, 0.036765685635468656, 0.08891847705648792, 0.05824640032745177, 0.03759633945000749, 0.015652438422905344, 0.0786951792636706, 0.05161591317324389, 0.021833304743913394, 0.09276743302302015, 0.058785159321081255, 0.019636463351367463, 0.023777986380962596, 0.040974147512667605, 0.023519483417452827, 0.016811301541184227, 0.04510671688964771, 0.009159405636901577, 0.055724036684560205, 0.020255567731275674, 0.009748939980542468, 0.006977351177709118, 0.04652328240955549, 0.02950173378321192, 0.048219435547869054, 0.048320739184536284, 0.026819562284095634, 0.022188721660284266, 0.03867897107416103, 0.017109595111481125, 0.09508908546018986, 0.01794121611202436, 0.029604927741832314, 0.0034021979081444447, 0.047912456455730626, 0.02267869234445595, 0.020081581502792337, 0.043007072902494864, 0.07162336034760361, 0.06742994826767715, 0.003147834692255504, 0.06396003728432041, 0.0782747885152217, 0.043512323210316325, 0.021336219018144954, 0.07709895080376057, 0.03724837082348043, 0.0322172109548363, 0.0337330729610497, 0.03191948045916375, 0.04003157591327064, 0.03645871420420947, 0.010717727108708313, 0.022333209673243187, 0.04730110680083594, 0.018760037698572683, 0.03710952887852346, 0.05638557658981412, 0.1343090027090042, 0.04862945346582321, 0.06516120186255825, 0.04512383512431576, 0.025531002395455877, 0.012552346808895951, 0.034077912118406065, 0.0187768820568078, 0.04887035747449245, 0.0026794269891275515, 0.022293842330034223, 0.01118433306879935, 0.012206817214797822, 0.037696876998750434, 0.06522048940701831, 0.03999591068995576, 0.02914014602861097, 0.04680195838333138, 0.033236280263912295, 0.08780445497963699, 0.05363550863318867, 0.05041255375310298, 0.011857417919072173, 0.037688457692462596, 0.01848139045309396, 0.024740997206179366, 0.046306525492259575, 0.026041406559787934, 0.009090981536334562, 0.07089736946527997, 0.09697677973177164, 0.024460775650016243, 0.03081810457872287, 0.055782902880661914, 0.02265730125439023, 0.04957678247122996, 0.0468532556307412, 0.041676879965610085, 0.053299257321463483, 0.026291691315089984, 0.03202808682896918, 0.02091630132898929, 0.054215973453415986, 0.05197585958446707, 0.06632839044135425, 0.02252381426402398, 0.05106568584338792, 0.011129015775006867, 0.03851623484684575, 0.01525560392051815, 0.04444890783258504, 0.05517176389994641, 0.03782192553063074, 0.018215448775839423, 0.06575744809402574, 0.05933784196273454, 0.02386249928554941, 0.023600715550503904, 0.025702230707411806, 0.1116025243555346, 0.010486033392108737, 0.0200400174024605, 0.050298437295902165, 0.05488745717992706, 0.022400776712944912, 0.020954580827345772, 0.02048272812258332, 0.04912303242411825, 0.03153347939763579, 0.06235262394071587, 0.03544051057448791, 0.009730515565963523, 0.03555978280341914, 0.06705576028194159, 0.034896867770341136, 0.027382462623439012, 0.059743864732163574, 0.015437972108503024, 0.025070453318016186, 0.06742033386422742, 0.031106605630127654, 0.07126211924778839, 0.03389901526632809, 0.06891517058735894, 0.036244516020580646, 0.008911524482461955, 0.10994846391822062, 0.08958517273347225, 0.05262085199055653, 0.03944030925331097, 0.0003640749069276236, 0.004269332829637513, 0.03800222049317053, 0.02400978160421214, 0.041868133815906705, 0.04252866248510057, 0.012607192958615, 0.056000268837857636, 0.012474710501039462, 0.02444775790096291, 0.047602849682011915, 0.017127372181764054, 0.02611173534645669, 0.1267800514676398, 0.052329221469981056, 0.053234032595590244, 0.04780544929446713, 0.033842454994878465, 0.04501286345804411, 0.02041214652689955, 0.027583171913941062, 0.07580001808462605, 0.04484512084614366, 0.042657349934621204, 0.02154447810514079, 0.06486966710297332, 0.038183331339349674, 0.028792853474677093, 0.033939491521807454, 0.039086579645593325, 0.04463009528755661, 0.04111606147020094, 0.028982314679230896, 0.036901842442251025, 0.14086440175531373, 0.08098225815281754, 0.0854926850766905, 0.07847955615650262, 0.03219063153430339, 0.006763018449888595, 0.059879255451021664, 0.029278800282026493, 0.027130002178432002, 0.04408457173755573, 0.026650180244037223, 0.003946500744918481, 0.0990880950684509, 0.023907143059336854, 0.01814447264487465, 0.22513186709294397, 0.10952947511067314, 0.12983809826114487, 0.12896992146007477, 0.19066218527094012, 0.0880208901400047, 0.09172467244488579, 0.08527783571832603, 0.1044798065577784, 0.12360457105622177, 0.17549552894648046, 0.0757897525064407, 0.1769383942648288, 0.10962001138156462, 0.05908122549073831, 0.11250310667580175, 0.15246570020193054, 0.149815158557988, 0.1130288498355977, 0.14800058737877878, 0.08498862220515167, 0.1743115247377465, 0.08744016484988314, 0.11905945567113739, 0.20803880607408864, 0.15047905035316944, 0.10831065220578064, 0.12806828959935135, 0.11385350518168942, 0.11960282651407105, 0.22967820055782798, 0.06394551608771568, 0.1258316576000183, 0.10414328711527972, 0.14988576122108968, 0.11160509075008093, 0.0959696728856333, 0.21767231575664014, 0.10444533260118578, 0.206801773259236, 0.0964043281912323, 0.09048482808735102, 0.10127958916728536, 0.14645485177395806, 0.12388350366945229, 0.1274557103733382, 0.1679680715765684, 0.08358531000633394, 0.18931253753121824, 0.09656812545032271, 0.17494573828674134, 0.09579576326594239, 0.11375223601897878, 0.08858228703179667, 0.13709569349884987, 0.11508638579999247, 0.29465996930676125, 0.17007945586116086, 0.19026841607785996, 0.09683040331207937, 0.11262296113155543, 0.1398427468994933, 0.39101513763589246, 0.12961971723744947, 0.16843501748817583, 0.2273906313724095, 0.15302882079155217, 0.15774378553032875, 0.10900574676211804, 0.13113056519819846, 0.18228948777241094, 0.14471839091950847, 0.17793162725865844, 0.12593509479155465, 0.06851508116890347, 0.176988189979907, 0.11013592563329205, 0.11764477472752334, 0.23634056080012555, 0.22349522749502815, 0.15378481167699062, 0.16126978181062207, 0.17485851151568277, 0.2931533501513543, 0.0810249905372339, 0.11008491949929346, 0.11719931758219197, 0.10201843500497842, 0.16318055831136244, 0.23788546902998803, 0.13006406355529063, 0.1343355093511843, 0.1608231219072496, 0.09096547165104459, 0.11475633213957472, 0.12061092161363172, 0.1958036924441976, 0.13748411539821856, 0.1638563704346457, 0.148705740669562, 0.15581148195891611, 0.10793800405677288, 0.13661072919926337, 0.2007579217634855, 0.08842163839407506, 0.16698714195480271, 0.20664956691043995, 0.18524896203269883, 0.1763143543634684, 0.1790715354464708, 0.16853520646691325, 0.17429116212071913, 0.1889650400487646, 0.16154565007215546, 0.09584988737779279, 0.18330228665182668, 0.17980868056897195, 0.19795140461815944, 0.16781885297067706, 0.16114702388163538, 0.19703566907875, 0.11102222041377138, 0.1131660332001986, 0.17217587078771285, 0.2087838419022099, 0.13201394118368626, 0.23308071878648576, 0.10546327193057346, 0.14481237458605922, 0.11548512690370122, 0.1723848289299396, 0.14221472365240898, 0.26738972132725103, 0.07594018919213165, 0.2154209059212477, 0.1314848502196612, 0.11832446325570346, 0.14098073986749496, 0.08137203602781219, 0.2054348885412178, 0.18885951909807422, 0.12084158302675332, 0.19256445819572096, 0.07270377414721636, 0.1406168940687372, 0.12654680067733412, 0.13067288895047482, 0.13762170478941935, 0.1737291140541915, 0.11394482286226366, 0.09094144713373915, 0.11964527544595542, 0.22357326121099536, 0.1813453303710107, 0.12184760202803921, 0.10288475787327175, 0.18168748055975284, 0.20945902583339523, 0.09975073814031579, 0.10582673468536909, 0.1532666298050073, 0.33428568332906694, 0.23595036157677252, 0.20036340180423953, 0.1853481244536177, 0.14571242064477938, 0.09476856193355016, 0.20079521492363947, 0.18943261415246995, 0.14146231805845616, 0.21838712175526928, 0.14114387063009126, 0.08148487311817947, 0.19870595525830023, 0.1241026048157965, 0.1786022146622981], [0.047999123982604475, 0.0564995781338263, 0.008627898623085311, 0.034415075074761145, 0.016371572818306666, 0.10071155795406911, 0.07201127662894226, 0.06952437136562602, 0.00974047662419898, 0.02642852036402591, 0.051292512986448505, 0.0384542468424526, 0.02685350572480069, 0.05504507593990815, 0.023551302879387816, 0.01189981035197214, 0.058803277300490495, 0.01440853667220161, 0.032371236762452515, 0.03129910054286161, 0.02967093387738832, 0.060622264976583184, 0.016673087788325165, 0.010954519140443975, 0.03836726904996941, 0.02564240115574531, 0.0017036935981107697, 0.0552220882156924, 0.028455016360948646, 0.04856778338791863, 0.0313822134217668, 0.07918044999842683, 0.04863174023827718, 0.010960612412271722, 0.01734483773038993, 0.031492200665055745, 0.019395042233349338, 0.011786602666571498, 0.038827952192795855, 0.027031808858737353, 0.023494001417871446, 0.059851982720917275, 0.04118802010892861, 0.07192625619110561, 0.02938753114111962, 0.012502946586708629, 0.009346528358066515, 0.023003787500783805, 0.042365711753166495, 0.013506142553993532, 0.027337114048761227, 0.08277479664332445, 0.03396956047283546, 0.034578328411425316, 0.015132137360201489, 0.01939366135986582, 0.06675917700293564, 0.03156409993196928, 0.017362517124462514, 0.03927528625354171, 0.05070725628625482, 0.041982993378394076, 0.020184379010911913, 0.08367434474489382, 0.0912150860794129, 0.07021460126364423, 0.027324098214927702, 0.04636925660193928, 0.008623340399935842, 0.05389280309299788, 0.029434720242035486, 0.05593935718699809, 0.04464735524849065, 0.0635291051660334, 0.04973182334534584, 0.0404192240638358, 0.020007330345951264, 0.02553532887700825, 0.011440511913068835, 0.05044713113156538, 0.04096619168957395, 0.05069992099437983, 0.070341557354456, 0.07178571736139637, 0.09834011746270042, 0.0945037789642811, 0.032965617569824385, 0.02573862371425475, 0.05941226357413877, 0.0326932426692257, 0.04674817518060727, 0.028211201218167142, 0.05532379787895949, 0.0769631540583026, 0.024710591176464677, 0.0781269948328695, 0.028541251048145276, 0.04314786454121913, 0.038143843337292635, 0.015382916242214701, 0.024615418158411503, 0.052118053164092765, 0.07575887150221294, 0.03479026663567751, 0.0235298945523438, 0.04808785994687388, 0.046238198110293, 0.08336663786922732, 0.037101818203565576, 0.04666715372173537, 0.06021080681333139, 0.1220300458672066, 0.012149517668501265, 0.041869574061204354, 0.032503011546308, 0.056321700178687616, 0.06314000910929134, 0.045013644867726875, 0.0355538341306871, 0.027908106191804814, 0.0505550192939418, 0.07773523279015096, 0.009385755890229297, 0.03966795994089015, 0.024514600987576192, 0.06557557115992231, 0.026530626477793823, 0.04500667729805555, 0.013545720571381672, 0.0935742155378384, 0.07368065882474184, 0.013154231447486148, 0.05627560466828366, 0.047485124950687733, 0.02407957029889428, 0.023676315022091714, 0.008689449957361626, 0.026095741345817526, 0.018679144559428096, 0.05441709068573771, 0.08115990628157893, 0.02771025057882071, 0.04995495411417177, 0.017002252786750757, 0.010240953246642266, 0.028846667320918173, 0.02169764780950162, 0.018017158407958287, 0.04395811743433437, 0.06154109168076708, 0.011155679465211447, 0.03064025726710116, 0.013467704092392759, 0.006444798932681161, 0.044653583543315056, 0.12510723719793942, 0.007982854984865916, 0.05943295560897358, 0.08534894399945775, 0.034213904216284716, 0.013063384910985349, 0.02955017926832361, 0.049159548005029086, 0.040340539173132954, 0.029557294309920365, 0.02539415993998128, 0.04649332071083688, 0.019464354038298614, 0.025079541036017963, 0.010837042430085281, 0.0165098708408374, 0.06857030844736485, 0.035040528408341834, 0.01920789652954667, 0.01160743002284078, 0.009064531393138873, 0.01909989728442123, 0.04818188574826045, 0.01566326803332495, 0.05427001329559473, 0.01986302236365455, 0.045958916927056934, 0.08459127538146512, 0.05066489928492135, 0.011717219998489225, 0.019856397618329334, 0.01934905397525478, 0.07565454564868443, 0.01148208271667001, 0.02469798711489045, 0.017573622228097052, 0.04775877921811996, 0.01650596379242357, 0.021849526655710032, 0.019849767127344688, 0.029123412753124873, 0.026241114190328988, 0.02405839754388698, 0.052586006481320634, 0.027826186494841695, 0.037295826139949986, 0.07131743845680068, 0.041977492867097746, 0.043068643388969284, 0.042700967150590116, 0.06229525927694575, 0.030600997176201596, 0.013868756866413019, 0.053283671262643995, 0.07799036305157409, 0.06188917139004316, 0.031359809180421215, 0.04216855519541329, 0.03445709882784755, 0.0481180016762547, 0.04083744295301937, 0.049194929775811976, 0.07173970612066408, 0.013827697426501303, 0.04730616298113619, 0.036322017305440484, 0.03468001126161507, 0.03838888805119261, 0.0060688570844039565, 0.022644147524730335, 0.016704173721072656, 0.04118282603280198, 0.022135545582240148, 0.02890428479370331, 0.03696250511453517, 0.10526675505623703, 0.04097733826887223, 0.0238585424414205, 0.015514600053129178, 0.02040689690939842, 0.012217049276636494, 0.044656747486442334, 0.041685946616193945, 0.03639106097961626, 0.02095891305455758, 0.04289884383099214, 0.012284090588500184, 0.034934279674123374, 0.023943331137660052, 0.016531629653106776, 0.0699335695695012, 0.03696577247953223, 0.06645877860606679, 0.03069756064383734, 0.019166577577350602, 0.07344261232403017, 0.030495698391009244, 0.002096600224068689, 0.051921367750413, 0.007641253985404488, 0.0776474008096322, 0.044719942079316226, 0.03332480555400252, 0.01761666487812275, 0.05576994450342271, 0.031188737916489764, 0.00688684698674948, 0.11823442494196278, 0.005060103149228399, 0.013449485563943464, 0.03510497172453231, 0.08767553004285983, 0.023920911574555982, 0.031838884179089824, 0.02817426428889796, 0.018661984189924215, 0.04294922177289282, 0.05898365270226233, 0.06012789311728651, 0.02849801687613851, 0.048410467232667634, 0.04032580347190942, 0.08603048646041463, 0.04682938433102062, 0.03981958023242412, 0.04825279101609223, 0.06321769808569262, 0.01853627873764884, 0.0906960844933506, 0.034619808242085486, 0.06730277767224659, 0.018219411365627762, 0.005746963217989692, 0.03211186045870906, 0.030342390790822047, 0.05312637809003073, 0.07918268697516573, 0.019883607146179965, 0.05245874395533916, 0.04490748423361971, 0.029088956033510548, 0.05559113958189565, 0.06432767521830336, 0.015520565005229607, 0.03579567276662396, 0.09973979074387782, 0.1261309528302762, 0.06613828572294404, 0.019039048835815444, 0.04341820930881847, 0.025930549806704926, 0.02768665890119249, 0.01671940163378754, 0.03722632281301964, 0.03287162624239441, 0.07655018670183998, 0.06282637654353054, 0.02525696508406151, 0.04205093388595889, 0.04322652644928425, 0.025519013119440888, 0.020885372444266276, 0.057131838158614216, 0.04966660628035184, 0.0900226472426326, 0.025835981998111934, 0.022473926618394834, 0.010256478018427809, 0.06359368254761062, 0.009836367849681166, 0.01433009501441472, 0.06400593361186405, 0.05408091981324458, 0.020613464857301405, 0.00867456008094333, 0.07763255402565965, 0.07853290651954951, 0.02660934201201364, 0.0029850216167453198, 0.10356772525776779, 0.04790312550481289, 0.009084437230241396, 0.012782712320556805, 0.06291130888125589, 0.030702676195951722, 0.02136862453734202, 0.023412547119322325, 0.025563691367184924, 0.009671158115980367, 0.01786943558873909, 0.026604929345569787, 0.01667599126155819, 0.05979712316465955, 0.09119916677234635, 0.07874484474380171, 0.021672832306414362, 0.008080004988568685, 0.12051577349343609, 0.10475182905793191, 0.0929373053593501, 0.21572407755640247, 0.1493031513546744, 0.22160846018983474, 0.13172428333951583, 0.20489851974191206, 0.1091169903896028, 0.1275405622718315, 0.15712048107337567, 0.20332882090681986, 0.13413742965748235, 0.13430989137099636, 0.1803597276129069, 0.16687253520133036, 0.15567433689871144, 0.13768634728847012, 0.10433910684960504, 0.11695595443128579, 0.0899860971877652, 0.16333101797969113, 0.10667633385427537, 0.11641439155585344, 0.16263593108423297, 0.12433083773019815, 0.1133324045147146, 0.11749342639720249, 0.1309115100171297, 0.17277478300515683, 0.11820793362154115, 0.2205750688670143, 0.15410814674631243, 0.191356000460444, 0.19757278864422154, 0.24081566340980992, 0.13673402338979707, 0.12167499475781957, 0.15465545528117688, 0.18190606076630855, 0.14304052046950788, 0.15809848423927061, 0.07715099881733618, 0.2196167388390149, 0.11709277773456228, 0.1213208859365794, 0.11615545383744663, 0.13129475316213024, 0.1448973643803789, 0.09439391429506003, 0.1372025780860455, 0.17380094245797204, 0.07366987230676798, 0.13978743535136023, 0.23341033577678666, 0.11640787980849705, 0.25047431609803633, 0.10522764626770251, 0.05616555230752115, 0.09177441453380931, 0.09032146749837745, 0.1307704272649942, 0.13773503983693738, 0.21547390388384943, 0.22596549332862903, 0.10773889014437314, 0.23066072364247617, 0.2112677900661384, 0.18175935492880885, 0.11928779583784843, 0.2049817168904889, 0.20802959769723878, 0.13471251654048122, 0.10000217585794388, 0.0938272620401075, 0.13640793040394783, 0.14554529090321836, 0.08799586204751846, 0.06650560189999881, 0.17985421683519118, 0.231743726819273, 0.13359646433063094, 0.18195001889140378, 0.13870450878335586, 0.17206990550602638, 0.14574482616397644, 0.20848241694752248, 0.1745825972888739, 0.1607124681674665, 0.11276982018664, 0.20079067968312772, 0.1650734389981916, 0.07607413966569208, 0.12706711227374692, 0.12539375408162035, 0.1963003932107841, 0.15456036844801518, 0.12635610607122222, 0.1035738463002828, 0.10103566677219446, 0.08922754756865964, 0.21106770322207483, 0.18282587189347516, 0.1683525557840063, 0.13091514127389078, 0.12570490069206686, 0.20832676320306717, 0.1514284018306963, 0.2027858790731238, 0.12275775278648063, 0.19788427999423397, 0.1993846631939373, 0.1490272677713825, 0.09015113550929293, 0.10577616522148733, 0.17621701523180933, 0.18319949297414673, 0.13807270075044326, 0.1026376945176913, 0.13194318530299973, 0.1823651006505374, 0.16157218735785256, 0.0878324325106317, 0.14684391718718315, 0.18838454458502032, 0.31522167726389827, 0.25642436778833794, 0.09135569385703533, 0.10135425209638574, 0.17826977846843584, 0.15066096559166908, 0.0625841127287957, 0.18835279790143813, 0.153054530702291, 0.18205057559234483, 0.12216528336847983, 0.09728422613754388, 0.10403878506152861, 0.14100523935931344, 0.127958195103753, 0.1623747257455703, 0.09465411605854189, 0.1819684050015865, 0.18050160709648363, 0.10717802185324893, 0.2036524470895529, 0.09788105459583384, 0.2756982819447594, 0.10952865539659416, 0.099455326975834, 0.1007867954491127, 0.11380042294941603, 0.08416616553140265, 0.15555485782604064, 0.276320590487411, 0.2101264109895114, 0.14995372854173183, 0.144682691222237, 0.1755148650056893, 0.15832642604026104, 0.10986935767915942, 0.12485141745738446, 0.17720663229063635, 0.14808396838845747, 0.06723605141404175, 0.10070503854583349, 0.17641488042089248, 0.1291557897122637, 0.11379804041597152, 0.09115081896344501, 0.07739879761732395, 0.19535062804577813, 0.2871151370627265, 0.1538680854343599, 0.10789477371520574, 0.10665353507764878], [0.027142079554558284, 0.055377117598489414, 0.02959983517235566, 0.030578794032936136, 0.08351008783304885, 0.02518423269653032, 0.0462272085790192, 0.02703054864410191, 0.013356899050244642, 0.05090133317055241, 0.031214995580094478, 0.05534551264117322, 0.02078224743355907, 0.01593820549803035, 0.04301824629487049, 0.0715364859769902, 0.014286988204525364, 0.04456303578110472, 0.0246670160953316, 0.03440210520620308, 0.06864375329666561, 0.05746482976622159, 0.06464415380070287, 0.029633251927612774, 0.04785006625517722, 0.041773927983857935, 0.03667093588099365, 0.029600325468627196, 0.026039386002887643, 0.04017216836913459, 0.016182151833368887, 0.06795265771929296, 0.025477711404223117, 0.02211079902706608, 0.041360148574195565, 0.05844032782460413, 0.03970196658384897, 0.09655517856440238, 0.027186742480543834, 0.059126271460686004, 0.053292243786516695, 0.026728420803743987, 0.07145096758200277, 0.022551272770450003, 0.03802702258971911, 0.07244130476347863, 0.017466099872704477, 0.030676317025697043, 0.03320470595011308, 0.022611673057620085, 0.06934141424754936, 0.06658137565658939, 0.019217231310904026, 0.018023197096021428, 0.016906386459126108, 0.08407125489846354, 0.01923275416746976, 0.00422500602472874, 0.007232164470253573, 0.030901751803955248, 0.02631207499953528, 0.027276472443894997, 0.03478962695226073, 0.02259666922562305, 0.024061255051844546, 0.05326060052480429, 0.08470647202263917, 0.002322410624812267, 0.13266991162973066, 0.007861835596662375, 0.02781339474172602, 0.041685601876628016, 0.01833699245546614, 0.03046391723347047, 0.06564076524227858, 0.09639279856797188, 0.02711216765155475, 0.03593131246405744, 0.02217064007005144, 0.04156224639906038, 0.03496182436544088, 0.06479737138555897, 0.026108142394091816, 0.0403914840200976, 0.023090073898915323, 0.01961465091294339, 0.027280923414735064, 0.05271479735271104, 0.0290617790643967, 0.061633841945759715, 0.017002112975704576, 0.03334067889579362, 0.02516215787299218, 0.08109580004407514, 0.04812033824442376, 0.04941215783718133, 0.043961128159876794, 0.04993321636932031, 0.01819162918705373, 0.026813362717568397, 0.06318692050333466, 0.03233637976189775, 0.04191138714011158, 0.09902431058787531, 0.014113860952127126, 0.012868051642491933, 0.029958293457785924, 0.051580542893779856, 0.021416110497328545, 0.07121288277689489, 0.08811680434812462, 0.03225605161259732, 0.013387296461470187, 0.016185486231059316, 0.058658390921810945, 0.062041220690814726, 0.039701836348901835, 0.031190865725699454, 0.05372403009283928, 0.030863317172794096, 0.015276704854782552, 0.06642204469009753, 0.034404273235028794, 0.00403160281899956, 0.0511131986164518, 0.037890344843148224, 0.08688262138035029, 0.03491004831307838, 0.03474910856194554, 0.06549225143727756, 0.05121232656341407, 0.019897381407058528, 0.035540021565412326, 0.05119062329251921, 0.030522775768692938, 0.03856046876359371, 0.03515240022792451, 0.010247923689143313, 0.060575686830786936, 0.0753242085357347, 0.05486833562533702, 0.02163616350791868, 0.09836816394160833, 0.05549355913254042, 0.01536527994058786, 0.04812844345466264, 0.02794766697221466, 0.021290435688570145, 0.05406980387746327, 0.08013832803455093, 0.04270341097106857, 0.0075658508238472776, 0.05034329557430841, 0.0469577576844923, 0.027859105292948026, 0.01597139051169037, 0.0674264855502594, 0.09328124053295582, 0.026813604035264543, 0.021146257941220558, 0.057751928876724944, 0.03789327895989822, 0.0451871446303783, 0.1081491225669461, 0.04621581685158514, 0.0036817831325254616, 0.06626973108899209, 0.05725000339049486, 0.06142559243486293, 0.04931013024742565, 0.03006761803502037, 0.01451314980870173, 0.04154958679611164, 0.02758668059663427, 0.04647928598006407, 0.033295387777710156, 0.030782441270627806, 0.029212181276131063, 0.04927364147959217, 0.04338830506669418, 0.03182399526028143, 0.03141316337390773, 0.01602392977914743, 0.0008352597984823309, 0.026698392072332003, 0.034740084046197515, 0.010089744727367596, 0.0765012260225992, 0.05413312104440505, 0.038614566062366774, 0.06340316031128168, 0.026125840940362504, 0.044433632039374886, 0.012178045825191565, 0.016443508474396604, 0.03849630123905597, 0.04618905740039003, 0.014078902444922397, 0.05621491901336178, 0.018818407852743423, 0.021261954454765208, 0.015833313697047772, 0.017588836734273264, 0.04366898436039206, 0.08686870922364535, 0.03604782677646126, 0.009238546349919372, 0.022861448364452492, 0.02388413743897071, 0.03602500884763656, 0.033334852797129465, 0.036813393760953224, 0.006482317131162892, 0.07539993632704982, 0.0347817285857614, 0.06085162404023352, 0.024377408046876232, 0.006058442597878316, 0.02149353517339595, 0.04916081205010415, 0.03284285964083768, 0.08117714325987524, 0.048317341584592104, 0.07295581707430464, 0.0519378156581473, 0.026416377870426066, 0.05007734815139444, 0.0794187110037573, 0.03398040061696403, 0.02060978763526486, 0.023149462950025356, 0.039338335289709994, 0.05876973414072587, 0.05062990821897984, 0.04170553931485742, 0.03475367061553463, 0.05240364308138529, 0.041275798463292664, 0.020398303318107804, 0.008434038158626327, 0.027464769194803895, 0.03199948876675579, 0.12563696401494165, 0.06122359037098866, 0.0815754400325879, 0.10373339177139344, 0.02720918311106582, 0.04261474012427273, 0.02161654974183729, 0.03264660323639551, 0.02741633328579126, 0.059395949731791214, 0.0349328700723427, 0.039453708131106636, 0.0332551451790477, 0.015117201518507735, 0.02779553148655161, 0.05437493286726456, 0.05918681155890227, 0.03586610689038231, 0.013088807538752596, 0.017442908476016695, 0.0851032059759863, 0.04735556416093342, 0.120142673352553, 0.029409699810428486, 0.014318302048430329, 0.04560062909618982, 0.02588688087980113, 0.0599624487691589, 0.027585012440179146, 0.09227362806878744, 0.010641670857195654, 0.10413395616436198, 0.07353360058679696, 0.08000410943021698, 0.0610869164548574, 0.04743182438335592, 0.04515797200222169, 0.05741693394919557, 0.05511011680467956, 0.07114728266793875, 0.04508622786811283, 0.03501844975436407, 0.012274865932281942, 0.12081869998045507, 0.12949322079939227, 0.05236371074833217, 0.07077852624558634, 0.040328297088102955, 0.05192116856755269, 0.03720700207556929, 0.04386748157201275, 0.012932028602658501, 0.05038238904108444, 0.013473314728828208, 0.007292114680768141, 0.04575308059312163, 0.06441997349142067, 0.017661111384269693, 0.029160638880585472, 0.069420313642871, 0.06317273638541661, 0.01638565159913513, 0.023116438814829436, 0.0629224592909938, 0.03561338214504142, 0.05553077951434159, 0.043313665120231534, 0.0096253115841518, 0.051942013819972356, 0.009219184435243088, 0.031640706809177514, 0.031921650403209274, 0.12957202060328377, 0.03346324147235963, 0.009295109494198716, 0.03187498224208192, 0.026442154813858292, 0.023679410017305808, 0.05295780044229281, 0.07111451708741727, 0.03896057733424729, 0.013297871975678832, 0.009779388145092997, 0.07939382080709742, 0.0344967860127649, 0.03169642629913025, 0.07369840908194743, 0.046879869525230704, 0.01118425837522673, 0.026705662246733427, 0.10483825909754924, 0.02310213403806331, 0.015183106147413774, 0.0704035185457718, 0.05662006078167789, 0.0665114701334988, 0.04758674651384354, 0.048176205206301906, 0.016360993144072352, 0.03371115518553603, 0.033661118152761654, 0.05547027389008192, 0.024621954803625425, 0.03151723833364104, 0.030375190845300114, 0.013593613515577972, 0.03457859654219882, 0.01750617776246321, 0.05380145476890668, 0.0041751992971365975, 0.17027969592280928, 0.22665172424768248, 0.2380011483065544, 0.11346386520252114, 0.11627139358390724, 0.0924160821183074, 0.08790790749293181, 0.1103772433294404, 0.1588572330412365, 0.12573740580269407, 0.1411774559246917, 0.19244864102332823, 0.14481415191004354, 0.1114166254598287, 0.20886339247226718, 0.21343532859558062, 0.1369176393434886, 0.1463963379783015, 0.11340908991593508, 0.08169700286441273, 0.135736454338316, 0.1819269902883999, 0.1648689088441672, 0.12271077627496374, 0.09866763537208881, 0.187364881557803, 0.2223885062360956, 0.15316840201135606, 0.1677889755416301, 0.1125833850293871, 0.0910135283465347, 0.14877836580478376, 0.12891028917604877, 0.13993518306843697, 0.18748569362346204, 0.18973999927120824, 0.20823823408253733, 0.1774122962547887, 0.10208035023101877, 0.12911593781844263, 0.16126089519070042, 0.11212468988472417, 0.2256488691895239, 0.15461558806559733, 0.14493134804069996, 0.23350493231367683, 0.10656233997114244, 0.16022427097683953, 0.16808980294773657, 0.14867859051352547, 0.22242541635228744, 0.15484418870220262, 0.17285545206358358, 0.10289287074438988, 0.10110257689150111, 0.2538225186928626, 0.12846924469716128, 0.11072163815580069, 0.2002414099631771, 0.10651780728010402, 0.1698066213078076, 0.13014176019257115, 0.11525353852419123, 0.1863596975923546, 0.10474684182554485, 0.21084644170778416, 0.2912649434180029, 0.10890260834487216, 0.2759452380480305, 0.15901156911446204, 0.20671148213648027, 0.17010769386204982, 0.09698270925230558, 0.14219803825741814, 0.10392883612263588, 0.1957740908068034, 0.10808477118130654, 0.12714589675587992, 0.134609462392907, 0.149824213717253, 0.13180182675921148, 0.12927637195154545, 0.13996404926142386, 0.13121247531906252, 0.10698918884079303, 0.08345278445631267, 0.20377794761330853, 0.11105464891560617, 0.2006884069452363, 0.21902360292452, 0.18603902850900927, 0.09429409303852627, 0.10471752364068262, 0.23442043802670895, 0.19328591383753285, 0.19293907519069411, 0.11416855884054977, 0.2393456479354251, 0.1443442488990484, 0.09983932088700034, 0.11085188076380761, 0.12247363375800273, 0.15952873975038528, 0.14718142488310415, 0.09468017070884667, 0.1511254906654358, 0.1484393259330142, 0.18879752726324145, 0.1112026647634564, 0.41363737696120817, 0.18786524422466758, 0.12655953305863565, 0.3600388014268491, 0.13065592776383125, 0.19654578649468962, 0.1404066029335222, 0.1192782886867081, 0.20603701832794374, 0.3045337088406086, 0.0867912577345006, 0.07571871317322217, 0.17104100345844225, 0.1970396067706808, 0.10645730165584434, 0.13200367560550091, 0.10231878743657183, 0.19584642482861397, 0.13929016767970978, 0.14109093395452346, 0.32266860347120996, 0.14911136890371002, 0.20520817248090623, 0.12730693609844293, 0.14923544450392648, 0.2158819529558382, 0.11397959559314674, 0.1616654968670299, 0.18116605047497059, 0.12524226785547313, 0.15041238538199855, 0.08378158939341385, 0.16639513985043572, 0.24740175193836614, 0.1352251979011682, 0.1146861355030729, 0.16551159532560458, 0.14372570950898433, 0.08447052460284003, 0.18713143924551626, 0.14502323262633818, 0.17111565106578414, 0.05740350059744331, 0.1655434032962207, 0.12622035529103973, 0.1279553299349162, 0.19058088802041548, 0.1855566995518823, 0.17957623417098678, 0.10305250814605145, 0.09209032621114485, 0.18185359906525383, 0.15625089467052491, 0.10344340450941555, 0.17390342970048228, 0.11544507582701984, 0.15284819258076532, 0.08279797846391317, 0.15191433140106742, 0.08548666362560566, 0.24542400403128517, 0.11597931490189607, 0.11026861206177743, 0.11771740752362436, 0.1759399059078386, 0.1773790786823919, 0.20930312694080416], [0.026389375186314987, 0.03104218721179472, 0.019594186789266044, 0.018682900305476882, 0.043067298904662175, 0.008729751927838212, 0.03340582701287443, 0.02827759039768529, 0.01918711064894113, 0.022987948632949305, 0.0529905507010558, 0.03537757645150827, 0.01525949468956359, 0.04252226565093283, 0.022263281167514866, 0.03580999094992876, 0.04131488043874983, 0.007316826761985619, 0.040118653297183976, 0.025109669358860102, 0.06412797524864156, 0.07250740282958554, 0.09150102839715059, 0.0475760902308168, 0.08378811646252872, 0.03979374774761739, 0.059315973982935956, 0.1274234197673298, 0.03906042923429801, 0.02217556410018475, 0.05058194345404064, 0.0313176053966726, 0.05591239089206342, 0.01673117448996392, 0.06816957551505297, 0.017395893660103603, 0.04776311144533177, 0.04374912864859066, 0.06533095928569956, 0.03318630451817186, 0.04711292113267607, 0.040364747551540216, 0.02922375303422732, 0.022712842628900564, 0.02954873710780615, 0.028696443224626205, 0.03550966533141271, 0.060758858453482396, 0.05366173565327641, 0.01862245022259172, 0.03219965988049104, 0.016663940698509256, 0.036556375092796745, 0.03668276810898416, 0.03393843049003232, 0.057886024906991, 0.03339532011699292, 0.018435743104125706, 0.030367244598305518, 0.04561177950592772, 0.07206405242604595, 0.006409047045669849, 0.05039766100385497, 0.04760614769052594, 0.05174617493344892, 0.04564649861065611, 0.013366850532381045, 0.10506278414639736, 0.040903016248898166, 0.048628706530097036, 0.006691175203154525, 0.044369996945944526, 0.017526831492901813, 0.057066651737137195, 0.07364734166091488, 0.06583419478228016, 0.03501824674106414, 0.06106634699409047, 0.019432352630481608, 0.06254585429785714, 0.04941176330190032, 0.018480871428525256, 0.035584209516884825, 0.0542615250413937, 0.04655107990988801, 0.05571872769524494, 0.03370519885192475, 0.05955863999383104, 0.023452845259359287, 0.040211100957446524, 0.054981019498119434, 0.03292894494088908, 0.020353946827291962, 0.050059440846164385, 0.07151336544343541, 0.030346678967978206, 0.0613047267430492, 0.01591302418795925, 0.035596267740812995, 0.029747458400144696, 0.03204260611035411, 0.04215496479563656, 0.04968972298346701, 0.02515896520156774, 0.015797971188271, 0.1572501644371979, 0.06384166137826058, 0.03580236071420293, 0.1117156908637093, 0.001165766647787795, 0.03489366552281765, 0.03730957741819082, 0.03866231632268718, 0.043797154700563806, 0.06035285100581185, 0.021116148770576524, 0.0371547970139692, 0.044378964005098234, 0.026830733761251457, 0.052494458974369114, 0.05257723860502724, 0.04917721399256299, 0.018748898780153646, 0.014198678376663838, 0.04829643887557811, 0.023341896575725368, 0.052349147416891596, 0.025992357780435876, 0.03873797133564949, 0.062343534307494286, 0.03505527943132385, 0.015917388016297933, 0.03823562067062144, 0.0695341772910568, 0.05778333848162044, 0.0294730763491844, 0.05438976432947863, 0.0810093470218201, 0.03718341039794107, 0.02551939233296341, 0.07541682090490096, 0.008528991884011175, 0.01201147341259545, 0.03731807333327109, 0.044811106542305607, 0.056427902947630615, 0.04881765445574157, 0.0033250035372592752, 0.031888434746032285, 0.018369736968569698, 0.02875302647871356, 0.0165876345108113, 0.07560482654239863, 0.046508971887129935, 0.02095711274793552, 0.01847505490596016, 0.03863147745329527, 0.042803393106066415, 0.07221315611874865, 0.019426934473637133, 0.020312384642179937, 0.013797061570409327, 0.04139539244915209, 0.040884151333762754, 0.02072292924558203, 0.04451318260943217, 0.04273793089293665, 0.058571060728882594, 0.013950434288070088, 0.04066047664251059, 0.03514758536532041, 0.03241379677708591, 0.09670101106166841, 0.06689802277833223, 0.031590367171673045, 0.1027305443741141, 0.029549982000683105, 0.04955024518553288, 0.035491838465414705, 0.009347922638088707, 0.03081170774455513, 0.01992497014843168, 0.09487020647934369, 0.04488607207613607, 0.027759827958840518, 0.006988564789700773, 0.06411616600328876, 0.09740285485261872, 0.04066566688819759, 0.019197485394655697, 0.0761356718477703, 0.019580824300646782, 0.03936105745754415, 0.0487810239616421, 0.029447310897071036, 0.04100305967092995, 0.02228817710983417, 0.08179431901343408, 0.06972315586021832, 0.04242877228065364, 0.02477777134176464, 0.05699167854242748, 0.033414372723669775, 0.10020648384647024, 0.02637601844335516, 0.0329630435143988, 0.03645969479675255, 0.04595582576228246, 0.040317545044085676, 0.052986275930438316, 0.031091525189338193, 0.0349883348380606, 0.01678694186041192, 0.030301897298364393, 0.025286524586619872, 0.022054118096768376, 0.018915873388910008, 0.10552735518543951, 0.058133563237084504, 0.027601146251864495, 0.021852864883840088, 0.00911543793570731, 0.06159071885650197, 0.018876571163174607, 0.10543418357208853, 0.009625885192485107, 0.025415560606146054, 0.04629051042420249, 0.06889380439515076, 0.04125344018722254, 0.05556527645357194, 0.02731488792285804, 0.030435794145770134, 0.03182475368732647, 0.10369173957095032, 0.044026176685527454, 0.037167927760991364, 0.041157502996464895, 0.030433047720561587, 0.05721981186539896, 0.029281144511074792, 0.039006952466743613, 0.04439719306725649, 0.02578852668164238, 0.025955562577432683, 0.04833537912476928, 0.031172265110897924, 0.054623666294519944, 0.043637038493949565, 0.055305450073172974, 0.027060393514412067, 0.04694413664119859, 0.039906607820622386, 0.01704422099846265, 0.03638239652519265, 0.04276365612543399, 0.03683239274147538, 0.04629177063883794, 0.06354205971283299, 0.011286403751000764, 0.007119045842574129, 0.03311690844355091, 0.046158080635171746, 0.044915122130224784, 0.04451305620492466, 0.07123571219703845, 0.015697864563985458, 0.04816572895393737, 0.01210860187007535, 0.026575065323061524, 0.02774363094490142, 0.1429125224991191, 0.03452446476946916, 0.01731880414750307, 0.026125591961787115, 0.04978519286059084, 0.036058674581469066, 0.054311090930094647, 0.03473441499555784, 0.026931035737957687, 0.013293318540578889, 0.19991576130832397, 0.10275636919804158, 0.05539908133927853, 0.10260530432025272, 0.06991935863850579, 0.036812114394119674, 0.04709902429772962, 0.09843025536787126, 0.01210266181583246, 0.08010187757111366, 0.021143490448594097, 0.020180753499810255, 0.046913657833131096, 0.07694728071651152, 0.07035440464894618, 0.0335174651756402, 0.020856067665942737, 0.015606247151510851, 0.009266581337508416, 0.029324974316442688, 0.013263881612088413, 0.0422943927978556, 0.03515774369119637, 0.07744392019606407, 0.020973102918135065, 0.018101401266551787, 0.07752789109344445, 0.040489669678913015, 0.045637435790511875, 0.010506257155699836, 0.0337468893567641, 0.020888195478267247, 0.054250263548906774, 0.04672395914132076, 0.03714673010812652, 0.04951995789944645, 0.03262544005748726, 0.023286878056223356, 0.05074595138731022, 0.0666514803625403, 0.06982169008903927, 0.023768576906032624, 0.07997084589254472, 0.09857302351344017, 0.009161576538557007, 0.0385584807654302, 0.06568383470538162, 0.023625182483585614, 0.04059650447039355, 0.054951674500179876, 0.011620249546643709, 0.035853619657216534, 0.04631428979337216, 0.03860803133237266, 0.04284294622559701, 0.07063167485138101, 0.029469021828845147, 0.07691964026420348, 0.053289979996700446, 0.023433036140857205, 0.05394657480440313, 0.006959337098974615, 0.02316640306925101, 0.051731458384423494, 0.013200724366000824, 0.03284637215397051, 0.056239598535842476, 0.023042011457765778, 0.023456162420071425, 0.07587218356709327, 0.020406741776593754, 0.1302738490724756, 0.13431254203521437, 0.10178988799452783, 0.09060013198083447, 0.1292477815502113, 0.06618664119272463, 0.1655387301598826, 0.1463536668809191, 0.09270962402825395, 0.09736616690192493, 0.18314876263180088, 0.23598570887359882, 0.1099308668785999, 0.12126064844309323, 0.08654843850602066, 0.14111204733771665, 0.12864012060867203, 0.15256821808795776, 0.08985302005443843, 0.06543498636493761, 0.1657055841097909, 0.1622491792565392, 0.19551063316964334, 0.17842817480766004, 0.11653886552179053, 0.14691997439630572, 0.14707242589323752, 0.2567533872300579, 0.1859884360624898, 0.179712797004369, 0.1800446969366843, 0.13892552514951076, 0.09767872311415211, 0.11544503752262363, 0.1646029384386155, 0.10587769485409222, 0.19166166954223188, 0.17170625889012892, 0.22643821554318552, 0.12753752090277212, 0.13664938599592255, 0.1777728172319551, 0.20610333089866947, 0.12990580511189279, 0.08767012912299364, 0.1170562889667288, 0.12116847274404381, 0.13829834428766083, 0.19598030635426122, 0.07519280913496211, 0.10791241672010192, 0.09308076298405087, 0.1498495405840297, 0.0770350820535133, 0.16885095726578467, 0.13406927847573835, 0.1689372647313341, 0.06646124540918297, 0.19092404944521768, 0.09508772182368463, 0.13376915587052224, 0.13410988113572522, 0.1785661319210645, 0.1504780391171094, 0.1372510101646185, 0.23724042299774387, 0.17455731638737265, 0.21057953667496482, 0.1137235843306107, 0.18451537155816633, 0.15260263075751646, 0.21462976692184327, 0.10397582795591125, 0.22249565129318546, 0.1046615532569347, 0.11735571443193382, 0.1464964197047295, 0.08423767983913423, 0.09665314588815936, 0.23978381958459657, 0.11333908480141433, 0.11457332139534336, 0.17480077912970898, 0.14253373798583785, 0.14278095455900316, 0.06583959570214634, 0.1461332787068621, 0.18013472758954574, 0.1574063391214417, 0.24661174674908964, 0.1306908920166954, 0.15511938280636264, 0.14121382977933655, 0.15910277954272686, 0.23354800177677987, 0.27193246950064937, 0.22548379256359993, 0.14039546401510317, 0.1870586915362266, 0.24853573060564457, 0.12189231858017946, 0.2554896179466479, 0.1451290293686813, 0.12845354755559277, 0.15996703397362463, 0.2886453210826843, 0.1716482660342609, 0.14251556638027393, 0.2078082289306387, 0.1266453195843966, 0.1280802865362456, 0.1315814079416375, 0.18195870632846511, 0.14457070448946568, 0.14299647041386174, 0.052212550109552766, 0.12241431557002569, 0.10060034497010131, 0.11930797459377397, 0.22410357791569926, 0.12957131580239342, 0.10505210488073288, 0.16073799421710355, 0.08499943936664252, 0.20319861660320915, 0.199482906309347, 0.12013563300452887, 0.0902173867929847, 0.23537335947396296, 0.12621901463717222, 0.09772387633640921, 0.16294694745973234, 0.1467656076795632, 0.1389149531361557, 0.1191105001095322, 0.14520651150134303, 0.14181871748258992, 0.15476195682441035, 0.11675274194849115, 0.10448668602733843, 0.17262070740182556, 0.09367779062520112, 0.11013173513234624, 0.16962308196290848, 0.10299215573937663, 0.1353523991401157, 0.1085450444670935, 0.16884052314825598, 0.1338559536323432, 0.09504917227933485, 0.14577790584054687, 0.2343887526301607, 0.2349087731131623, 0.1546243674332096, 0.10943438061663222, 0.07963205116891092, 0.119711994043281, 0.15001144560594715, 0.17861919117070016, 0.1296894159168005, 0.14790943823754787, 0.08164673983570069, 0.13709996826946735, 0.19371286995949286, 0.1121756117490511, 0.1745376738929941, 0.11622015762353137, 0.12686373125160896, 0.11600127098180595, 0.1324061475574009, 0.1369124605891205, 0.08179979654209268, 0.1769699111220337, 0.20389617030178347, 0.11016448539110923, 0.1179831710854365], [0.035070949759815014, 0.03964121581145352, 0.025815167389209234, 0.10170783997783739, 0.043229789983841686, 0.05440514354455856, 0.04887027320482078, 0.05019592324031457, 0.0413673498006838, 0.04724510960401066, 0.013070891615033392, 0.04453784297971476, 0.06852779822844653, 0.00973884102648064, 0.03699078908069961, 0.038002277949764844, 0.04034898529249815, 0.07637074592733577, 0.032981682433596546, 0.06009266073364885, 0.01775252099539484, 0.0617718450244396, 0.034527437190615365, 0.06997603382314406, 0.05113211715774191, 0.018673157582299846, 0.027725532117690292, 0.03596736456177408, 0.026577851967886094, 0.04897663302178826, 0.06191542522320825, 0.07013541841579062, 0.017139916871524146, 0.044998598900894006, 0.024604403729280157, 0.025922496307400927, 0.028210166999469363, 0.042111631032199635, 0.03037134699914004, 0.024890711854001688, 0.09357778550756556, 0.022765568630289168, 0.0241558515887347, 0.03597137503205769, 0.0069999349709119535, 0.07094294403589542, 0.053574248412323576, 0.04825071108737781, 0.013742474932974626, 0.08231874450200027, 0.04529371129108533, 0.05310726802675955, 0.019754385350332148, 0.04594993071570512, 0.01921592130055351, 0.04274639616449995, 0.01662560948921788, 0.04006241861310217, 0.013339906262474195, 0.013313799901234527, 0.0356156152913407, 0.055927850546375404, 0.034386017359793186, 0.061589504607141986, 0.10570695683840783, 0.009150293021042262, 0.03804573045683004, 0.0397399683753329, 0.055358601253359556, 0.03693539326289489, 0.05648510290249702, 0.05140112510191337, 0.046945645834409425, 0.027023782172510703, 0.04840620012292939, 0.08496819064021112, 0.04377804463729263, 0.13023451811844303, 0.1276614049810075, 0.02538207298775594, 0.05421298188007167, 0.04994519032357682, 0.026669688673029025, 0.08617980465773614, 0.017933451810911778, 0.017955970965446006, 0.08382574670136937, 0.043819018849922765, 0.025182853738266616, 0.026913335276467186, 0.033209080312160716, 0.030684052598512465, 0.021673623292196183, 0.042284238302419265, 0.04572800653535993, 0.0308819675833107, 0.01146131503065267, 0.05673529955768778, 0.038692764487237706, 0.007417820611848466, 0.12695681859528826, 0.061232645530253656, 0.04024193216595919, 0.033654732809912775, 0.01790957668075158, 0.05462691067687927, 0.03587715770869005, 0.03985666271839892, 0.013522098250236484, 0.02325228152556285, 0.0646709515562942, 0.04639792361206586, 0.08035578975273718, 0.07770848866071432, 0.03558591789295597, 0.06646490730946103, 0.0400505940459909, 0.01665597529931655, 0.08632478679740622, 0.01862427925751094, 0.06355298412663322, 0.047479517187082, 0.019465991551236763, 0.027918019369545004, 0.03378989370239358, 0.0288287925744249, 0.04880702498579218, 0.07735090180029792, 0.042424528153553125, 0.05569743428138956, 0.04175242006538376, 0.007160472047079596, 0.030206797058664026, 0.059991912510726726, 0.027676749553891922, 0.04062168961090427, 0.061734210955159324, 0.018312741942223043, 0.07180325311398314, 0.06613656202511442, 0.0441572466684926, 0.015319657489477147, 0.019148572595910202, 0.05427375563510484, 0.06297240056277764, 0.045420322642331167, 0.040745719245845274, 0.05272991992833634, 0.026001698307452664, 0.03474918517073797, 0.028466980739106095, 0.04665408809218676, 0.04574541205299958, 0.036961421100122314, 0.016150054664561347, 0.029048491269350055, 0.012523881854459405, 0.03870660003515021, 0.02821322177506743, 0.08158330775557027, 0.028911426648377415, 0.025581179239276438, 0.02633789024736372, 0.019863342205362938, 0.04956644411469179, 0.03865796877371688, 0.030835104069762656, 0.01768779614189219, 0.005916915035941789, 0.04909350739551648, 0.027856559965819604, 0.023717342860876553, 0.010152202918224279, 0.019702080697301897, 0.01367496726508703, 0.02042916517013744, 0.07661967853745145, 0.02563220644069295, 0.1478244637649867, 0.07279666996891461, 0.009743045891575035, 0.07345826350032322, 0.05687037618049691, 0.07897618797517593, 0.0440026501253728, 0.03307846615151052, 0.04959681184001027, 0.07375902961939573, 0.05839558062894691, 0.04992635222151876, 0.03929322037184912, 0.0779655954289821, 0.007546210723493489, 0.025815833885703358, 0.034819538855264266, 0.03098878513781294, 0.061319213465697346, 0.03356002902071323, 0.03240301025911205, 0.08070486537631481, 0.06255748734298734, 0.03003397145338597, 0.017052730320081595, 0.017163230842279813, 0.024181603634309386, 0.05981636346287786, 0.09891456849272214, 0.06684316322207451, 0.027744322339253082, 0.11469523662761336, 0.047404398435666684, 0.015503256206190395, 0.038833464195411053, 0.07181823779378207, 0.022477345285756935, 0.037035291128221064, 0.08832983041722929, 0.02681769111434058, 0.10635417856035695, 0.0808003965404726, 0.07577230868440482, 0.03933384984491333, 0.019514249344807, 0.007105430544939854, 0.04843001013561603, 0.1000255721831514, 0.03313720594310472, 0.054767250323728214, 0.027860396151100437, 0.016516055085606152, 0.03388634034162087, 0.03158230218105018, 0.016988118464547782, 0.035517866302642136, 0.04025304044086126, 0.025668496025666118, 0.040744891870887055, 0.010572353306586945, 0.026442325268421444, 0.07845475789039366, 0.03984232538289601, 0.024025758367873008, 0.04452544384666028, 0.026676974169188933, 0.057711222794868296, 0.043819375080807556, 0.04571708595199932, 0.025101409015816548, 0.07500901698104798, 0.015030579956909342, 0.038084402575247714, 0.06574978721478293, 0.03264702458475386, 0.008050180228066542, 0.07105748184145459, 0.06890059959503912, 0.02785467155908625, 0.04916896705605811, 0.027146256648965424, 0.07367707353325621, 0.02698537243920709, 0.046535225720295025, 0.08327409444797425, 0.03335174886629947, 0.05358667818889503, 0.06078528848687007, 0.03136579424232966, 0.07534574326728621, 0.018790585454553366, 0.015575891875121144, 0.09713055656081247, 0.0419297349458981, 0.022425416015809583, 0.02655626552539968, 0.048596415924088615, 0.033537188109250805, 0.0755606692344431, 0.030406129306122184, 0.019599919042159474, 0.07515964518872, 0.09674521433489938, 0.004394959279095694, 0.05680248163820756, 0.07839984470798124, 0.04270013977563189, 0.11926117428247968, 0.05348870703469842, 0.01482309461871703, 0.06739655449505776, 0.0955879619164813, 0.07420463232143272, 0.04289821563889423, 0.01577605437036724, 0.01882935907962101, 0.11412685301395194, 0.046627635076161356, 0.04607262735765788, 0.03908677116757439, 0.024924946408117973, 0.020674229036235524, 0.045508453397140394, 0.04027738288465527, 0.02195311898005105, 0.041502897567566366, 0.09598096502163718, 0.013993176248585506, 0.05626757223639758, 0.00877495303059057, 0.023985534921408664, 0.07935428300932532, 0.009770175937803523, 0.021848074919093522, 0.025548126375783357, 0.021999754582441623, 0.01704921397650915, 0.03286560862174919, 0.05068194474123659, 0.03499517983366405, 0.013031311682425441, 0.018715305824673945, 0.06572321162468965, 0.00629603662790971, 0.030119968653326074, 0.0422498639372568, 0.04517518216744066, 0.041836555671667865, 0.04109849890453681, 0.03807296871297783, 0.04159311208152964, 0.061469209650831844, 0.030833196510831197, 0.015812830421172323, 0.1522983865992677, 0.03669125636318519, 0.035714241450712565, 0.0300885992680466, 0.04206577683949182, 0.005682132548592504, 0.06534221311730724, 0.03995528887777079, 0.03636949560454777, 0.01771100860599789, 0.04129691184648583, 0.0385105696266457, 0.010677110084572868, 0.034381133549275904, 0.06718907490252488, 0.027090933609513507, 0.055655356902148456, 0.09477097511051163, 0.09270135027867171, 0.03842697411234822, 0.13129386450013808, 0.1176720091532315, 0.19506498450233092, 0.2053153941467885, 0.11208188855239462, 0.14218267053365707, 0.16220439375648577, 0.20718572120512688, 0.09400458841194069, 0.206921007183771, 0.1939780436336033, 0.12946079995843673, 0.1498344180084044, 0.15698158933270365, 0.12740487277868295, 0.21463390379663438, 0.13064465094958583, 0.16005764685330853, 0.12211481349602823, 0.12286467567807245, 0.17327532953312322, 0.1874754280452767, 0.09016711610339342, 0.17120813320000328, 0.13874938621396019, 0.16436322952710813, 0.09948322023715704, 0.09138999161340537, 0.08561681430306166, 0.11356417675532642, 0.18377292510722915, 0.24585862103248798, 0.14584827867727126, 0.15916265697488863, 0.10369815938775578, 0.08706223835507709, 0.22178320484536312, 0.17395403746876026, 0.09398492293492441, 0.1366333900800636, 0.17378243377372143, 0.12833057512198726, 0.16950597776280296, 0.2946376914699232, 0.10980002672201204, 0.16146815261773526, 0.12817033251086551, 0.11127262391270169, 0.2266065863471839, 0.2071243728841505, 0.22296947667435293, 0.10267228338747256, 0.15506232457776226, 0.18024967142170478, 0.10660499574676638, 0.10504053695307625, 0.07411686162794791, 0.13835238412983958, 0.10842872933754999, 0.09458835507112165, 0.1346232213320271, 0.09643776792912714, 0.14144221591132303, 0.13420885969554225, 0.2515357155953684, 0.09467745875759472, 0.16884173356717633, 0.1728478524713747, 0.13627738902165046, 0.11219615056630104, 0.15195049075109346, 0.12951957422398752, 0.1786599164047549, 0.11010947261726665, 0.19221032639184307, 0.13599027458938862, 0.1279302022509998, 0.23908147017561623, 0.2748284657155314, 0.12501344505336978, 0.12680669600564626, 0.15280587388382805, 0.16624369958956398, 0.17444148389322145, 0.11142836192682867, 0.10710108364301343, 0.22221137138624347, 0.1514549237946349, 0.19015292066239542, 0.10186343243525875, 0.13277233758520696, 0.2356347180302105, 0.12532780157221904, 0.17191989016869377, 0.15150945393308518, 0.10726816741929901, 0.12750581252358614, 0.16580822456988598, 0.13938565287859211, 0.08929242755496695, 0.27807005951481484, 0.1341810507038909, 0.1727653448019297, 0.2078906446695328, 0.22222966556587528, 0.20801688063769572, 0.13382141838871664, 0.11690025217831136, 0.20912044561438023, 0.2282948909147132, 0.19402987714256012, 0.17316703534414693, 0.10991002162618023, 0.1763884503875048, 0.12813326917708884, 0.3200222293455755, 0.1379541563050401, 0.13485280256117546, 0.19333990771443615, 0.15166159899484727, 0.11911547968104003, 0.1870589979713963, 0.1592850318599132, 0.08223609127584966, 0.18262572376237762, 0.15723274359779973, 0.13721436051832092, 0.15394565949757255, 0.19598016845843486, 0.15080367245020407, 0.17835254660777508, 0.10228985229567175, 0.22901125973270786, 0.13970541797818678, 0.07978133872271546, 0.2567539847786388, 0.16121034870945639, 0.10402430599975972, 0.1766546199759168, 0.1754166065685211, 0.17327658591731904, 0.15886996542253803, 0.1941787433480063, 0.08732768782084027, 0.12627475519454287, 0.1309737929653737, 0.11804180745516094, 0.09349171552927264, 0.15291651230185263, 0.2461123033877342, 0.11840633507217131, 0.08659697783690307, 0.15514739098087435, 0.14390774732155187, 0.1588028254768541, 0.0985154520059305, 0.2416931251965223, 0.12539262793237163, 0.18166892591022676, 0.2169986180360279, 0.12654752846086217, 0.08070249050374954, 0.18360247054407675, 0.12896998274710872, 0.10302479874583022, 0.10064699206381075, 0.2592368297759564, 0.10777521803374253, 0.0844997278745136, 0.10602463817884845, 0.14829216044275992, 0.11416563238467901, 0.1324344774888408, 0.16324726924780877, 0.1213532071861048, 0.11437367888227587], [0.03184157314770405, 0.07766423942220789, 0.011230455392280654, 0.061757017392665155, 0.044802832792723374, 0.030338234763832825, 0.034216194819178314, 0.032181645322951584, 0.028245399383107023, 0.052948967448525855, 0.026902305525577357, 0.02801934598884996, 0.04727242063851126, 0.05751857083410986, 0.09529556913842117, 0.09537665954520626, 0.021739499192805063, 0.04943816652221065, 0.03585593324274786, 0.06547927390784025, 0.010877841400102744, 0.07556197924479362, 0.10009098843100572, 0.02029234761252038, 0.006507173332671125, 0.03060879595127077, 0.019300177565685684, 0.04756797735969867, 0.050229497043596166, 0.04092355506614812, 0.049900638480340286, 0.043021574946901495, 0.04926982636172925, 0.041601052582864805, 0.027861208204300176, 0.013735483423055661, 0.026178530552574707, 0.057699942150183266, 0.030614191125477516, 0.0692850991242355, 0.010507461828960767, 0.0726091776103262, 0.006661265694175757, 0.05160813738081244, 0.015219863046020752, 0.03542161118539591, 0.06785266792341586, 0.029919341717275883, 0.06234145437877986, 0.05103767766887623, 0.005931991646291629, 0.019832283085692796, 0.061135490259696404, 0.01784127228142273, 0.03870933113860027, 0.05594001219217336, 0.048697991521968964, 0.016823474678301045, 0.02673496127939753, 0.029073394872548602, 0.0351252653936465, 0.04374231046606456, 0.053124596935606776, 0.025966238012657534, 0.09013196798942744, 0.04393025481652829, 0.021064629357668663, 0.023999054458052404, 0.044574178529963385, 0.003800779809206424, 0.05065172257262373, 0.026027312457200982, 0.0427454577067927, 0.017899123411024773, 0.02831556154565225, 0.04133811971593288, 0.0322026782669127, 0.010509696890479855, 0.02819713201343773, 0.027384080984179052, 0.05041582494853966, 0.07279269397258759, 0.018863425094393954, 0.05792649733203073, 0.06550874531028733, 0.05131896217203429, 0.030480020401638844, 0.03990996328573074, 0.016153758699675242, 0.07321165979749734, 0.04269393446344522, 0.03991970409368796, 0.0312864102963959, 0.036624487970144524, 0.03743170332463999, 0.03319262474354717, 0.025857972551978407, 0.03417868715440554, 0.03912463889367158, 0.09983560536056758, 0.0350362996029998, 0.03537684483754058, 0.07424049289716829, 0.0020385467993741437, 0.033612142151762406, 0.0161747801523175, 0.03517145666504099, 0.011381091260831925, 0.05132448949640797, 0.023544586203511686, 0.030757120149510524, 0.020950675694151752, 0.0006687751268937944, 0.005309919154481782, 0.10506616259414343, 0.0785429269495991, 0.02565564490073631, 0.0844815256254327, 0.05093827776070084, 0.006664059999879571, 0.06630532353395416, 0.023293020166156274, 0.031822043651294325, 0.02524295333592642, 0.09526681785862293, 0.0377068208200076, 0.015774034771076854, 0.031180540775699966, 0.0741668641867657, 0.005606487590534192, 0.12531586592235874, 0.03900863402973741, 0.05499206265554794, 0.043367352561965104, 0.041230955506644906, 0.009458951760954674, 0.02846584309853854, 0.031836080297286955, 0.09338730540607246, 0.05435390375374306, 0.06686513462374288, 0.04286581395013679, 0.0714583296869551, 0.01670408179052174, 0.03805954685254443, 0.05945714100474312, 0.08188443393596719, 0.039357219357043505, 0.09722819446676201, 0.024581712204962972, 0.019162398567723653, 0.04482387339756374, 0.02412777829674944, 0.07179183074303212, 0.01861675818931432, 0.028770435826792836, 0.013149724935271568, 0.0678452445314296, 0.08799605356949954, 0.00736734547254239, 0.048007156414490555, 0.07638391497875414, 0.03679381255360861, 0.048274410017315424, 0.06229127178929987, 0.03775624498244255, 0.006152634544583459, 0.02307332147123112, 0.025320071576824112, 0.045938224892222115, 0.05966400772693658, 0.05025383948739018, 0.049215767367352406, 0.09453289030540375, 0.08226482723388942, 0.03298440970660698, 0.02532131646970107, 0.011184287103523892, 0.022872495352320617, 0.031948689476496754, 0.019782422253141002, 0.08832532582023452, 0.07477054913197795, 0.020238568240235892, 0.056348432816805384, 0.020977117218858293, 0.06415190783539607, 0.031398128898393725, 0.040832628090415275, 0.02883163284540417, 0.10797607096573038, 0.00571743244372849, 0.060755602579804203, 0.08794804283928487, 0.05389312101948646, 0.03947814633589118, 0.03918496448726904, 0.026629367550354333, 0.060232215140375404, 0.02126767330111996, 0.027440457394526854, 0.023083696216945688, 0.04380047569171556, 0.04132924458733009, 0.0348643243553177, 0.049513051616809065, 0.06726980524798555, 0.030369471998945363, 0.03411938045774737, 0.05049472817430093, 0.05486601437892645, 0.009868230404061897, 0.01604887168674219, 0.07902804446677048, 0.06314028107050447, 0.04130299841504424, 0.047568628534434304, 0.009624103080451248, 0.03325903307526343, 0.028261830053863027, 0.0033115462452593834, 0.04592900119361378, 0.045566185783114166, 0.027101003835278175, 0.03313921309346634, 0.05422479878630369, 0.06038263267386825, 0.07904031719531744, 0.04583877135789202, 0.009785303301478346, 0.06273404762689626, 0.04963544565403173, 0.023299443813401367, 0.03737132793532745, 0.038487931728483214, 0.0963998542377545, 0.05780326825897059, 0.07313848307897007, 0.07557974482375769, 0.03402472263382327, 0.030257238202818462, 0.01781425236033336, 0.008830974167663484, 0.023758422410596284, 0.029028057789189682, 0.047159955100787264, 0.029953233447046052, 0.042272685696521116, 0.06265822024415098, 0.0858542632551924, 0.033892082170613354, 0.021166291140440493, 0.05816226855160729, 0.03399951451067482, 0.012359821252645025, 0.07435698422693438, 0.05745334993867625, 0.07338818943788929, 0.026876162775161288, 0.07996352975286784, 0.06544665388402439, 0.07352816902341382, 0.0313155637723544, 0.04902032301610997, 0.024193914667252573, 0.05254709304520681, 0.002716693096801699, 0.0628984232823695, 0.05126936563981637, 0.03818080324919955, 0.06678845688340164, 0.061550782693009225, 0.05603285438771691, 0.06397725511041862, 0.033756197325044104, 0.07360280896987646, 0.030814802739769224, 0.07125320198434977, 0.02111424887252431, 0.04224826281349506, 0.03305058821194595, 0.0124081575702275, 0.1432199995484083, 0.027192589646625905, 0.015949087776994754, 0.035292318526415095, 0.041335993821943, 0.027355743391859918, 0.06504526211609764, 0.04355462275505547, 0.057586396428486036, 0.06631299207407622, 0.022341234444250024, 0.08646301970246338, 0.018894595296813116, 0.026836293644361922, 0.10282195398523923, 0.054827369073586124, 0.03470212821998904, 0.03515616555007235, 0.02750124647131851, 0.04964085806521678, 0.017265990046003175, 0.00630078828826006, 0.03539243089636007, 0.05920797473781052, 0.06543087247278422, 0.014224423718969188, 0.06372783603447099, 0.1063160120599693, 0.014629604749291416, 0.05555439417460754, 0.027774406612039577, 0.06052144780574788, 0.10356646887357197, 0.03615755738029557, 0.02242122934530339, 0.04636561768429895, 0.05581689420186224, 0.03690874872488841, 0.04509373552977078, 0.07609181331410524, 0.06283008057864443, 0.0721280820547573, 0.04982296482569749, 0.060530430186660066, 0.024218182417473966, 0.07668950745174963, 0.027476658879388726, 0.01774987607683626, 0.05023260736056874, 0.06132919942179035, 0.01639916730533925, 0.029870528509960543, 0.027505712763917063, 0.01733442468027915, 0.08005100933294143, 0.07452886371362595, 0.06678009886414775, 0.022162657433880434, 0.03853624506342796, 0.0209634272276514, 0.0416871378829162, 0.0663022515213778, 0.005181730140916883, 0.06454332896898832, 0.042508954873248454, 0.108389321774725, 0.010244026216828536, 0.007998962941083817, 0.04422335239547876, 0.031199411436494802, 0.23723216456992013, 0.23569660261273387, 0.12332013793169491, 0.1437902753992427, 0.10802091009193852, 0.15994492467612992, 0.14330494337745253, 0.12058216267295423, 0.12488367741987591, 0.1680702064186335, 0.13480555025800584, 0.1182520219815835, 0.1679645475721167, 0.1546821611062173, 0.21520704481630556, 0.16060017499952547, 0.2520879730582237, 0.11019274637463594, 0.10280899177756041, 0.13432397206704463, 0.1491286212037648, 0.12920895621420878, 0.2359975679146667, 0.11440544088761653, 0.22210057975063402, 0.24569651682771024, 0.13366723553307597, 0.1032984606741417, 0.14956765087141147, 0.16738221349735416, 0.24324616928014064, 0.10126707895148186, 0.17342238777106808, 0.2225362845966893, 0.19380722134824724, 0.09278678440398748, 0.1367186709877945, 0.18029054987334436, 0.14963088376868158, 0.18871290519112544, 0.1811743395463113, 0.06503672023574192, 0.0748806283058178, 0.18271472785742054, 0.1695207479379831, 0.15791129831585193, 0.15134739569358288, 0.09463721615893227, 0.14235847239052096, 0.12864577433755323, 0.16836087549886397, 0.10167125161857375, 0.1926034980363423, 0.1339946002248795, 0.1365373226543588, 0.09310680231259716, 0.130859017672558, 0.20068269192932114, 0.09643283432289478, 0.1330552844991607, 0.11862691476820938, 0.13238477370431348, 0.17650327164559595, 0.08469747048952887, 0.14982019941652977, 0.12135893752377842, 0.11939076571575097, 0.0734817211125647, 0.15795802967923303, 0.1744434297565491, 0.11450661045889701, 0.14773319204968793, 0.09263778796359416, 0.12890449755134123, 0.11930766049772502, 0.09507079128055804, 0.21351510899201517, 0.20138073592416703, 0.15820251897938792, 0.2148979436606169, 0.10249388449254537, 0.14510736440218266, 0.12640973222592186, 0.23437249624440748, 0.25957400039319073, 0.1279559734487726, 0.1059135401080693, 0.09684003303728758, 0.11749585489592246, 0.17671039117680443, 0.15490893845356282, 0.11319761134443745, 0.11242891106033519, 0.07130231588117539, 0.11995816107599006, 0.14296118440406938, 0.1481027528643608, 0.17558485479845157, 0.15745357610285282, 0.19614051066098676, 0.16334601798124854, 0.10374824621624525, 0.11341457510547293, 0.06695453708450641, 0.17671524817424436, 0.13517590780411998, 0.18230672475070725, 0.10966212323476231, 0.10223496975677629, 0.05225531696792572, 0.2562341175132221, 0.1305662341896565, 0.325798808086303, 0.0852227233530533, 0.13256207709350895, 0.20408487307929224, 0.12641648146053477, 0.2136223000143805, 0.09511980558595351, 0.055350189607950954, 0.1997260932600306, 0.1139190746471286, 0.18340121924636826, 0.20735963848569702, 0.13796721044326984, 0.08238540181229193, 0.2643507424621813, 0.09796497952793876, 0.24836912180387208, 0.09027565544050548, 0.20454804983831223, 0.14075826793428392, 0.2159470857511605, 0.25764054768989164, 0.12667391764660998, 0.08019982191223292, 0.1620840566653398, 0.18361086686772687, 0.292355117177771, 0.11231840287725772, 0.24921678277032994, 0.11540137051093964, 0.2488980289067953, 0.1605685355682527, 0.08697890331067386, 0.20622783550812354, 0.1398114292251487, 0.15976526173612765, 0.18275562163081863, 0.19316458083208532, 0.14722113888109886, 0.19392435619186973, 0.1369128589548411, 0.18190912511800567, 0.15338293727367155, 0.1439660466125896, 0.15668918889376426, 0.21183195253533704, 0.13996164374534162, 0.10714692634440239, 0.1787781084497129, 0.1434608269482851, 0.10796884675660443, 0.21610698362271633, 0.12523053904935239, 0.11181963367327569, 0.14658402951975025, 0.17770904807313798, 0.13943546391542883, 0.1622758237945457, 0.12863771509258978, 0.2259042982252375, 0.16410174839679273, 0.22594664756569172, 0.10744405354583457, 0.2113679790448758]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.013493476247775459, 0.01896857640766088, 0.10299327422774608, 0.05670017442635952, 0.029838741606762333, 0.06781654687778604, 0.09944372840466038, 0.03069499999495043, 0.019649496422179287, 0.07055616922556393, 0.0724764681992031, 0.06618781330724878, 0.026899534202511274, 0.08709385480371215, 0.11033676324352143, 0.04442154317192974, 0.08303496776328934, 0.11071218463081507, 0.052380112690791014, 0.022184351128676248, 0.04911147215734086, 0.01686110683236151, 0.0026161191588823475, 0.04569587680781561, 0.05190342597122635, 0.01252328334826856, 0.04620731710606525, 0.013821484453435388, 0.03536438441745216, 0.015821587763756754, 0.07156677709351625, 0.0612696475769964, 0.040403967422823754, 0.08374280236180752, 0.013510518831260985, 0.09574904722431976, 0.09204031599144782, 0.010228872040076362, 0.008303726602706217, 0.080780531880596, 0.06886353626126243, 0.014082264613300083, 0.027390569748897708, 0.027257710950629368, 0.039189986193612705, 0.010000623803916238, 0.03169086450079997, 0.012452271785737287, 0.04867265316387338, 0.028060735804179025, 0.02287564780412903, 0.02325913801248516, 0.013684892891755989, 0.09552803085816484, 0.027644242528044892, 0.005021247648513846, 0.02986235626702828, 0.03202070748703855, 0.04819820725148724, 0.02948892287789814, 0.03935582507702132, 0.09108881946773299, 0.022710412214960785, 0.0413757614460924, 0.04869615674139031, 0.041039946804484057, 0.028072365018869602, 0.06789907752986878, 0.02398547171915491, 0.04674546705979494, 0.021298611761942025, 0.04676801685784613, 0.006804526051236016, 0.05917025639885857, 0.031837949551822196, 0.03316202719185141, 0.03928280923695814, 0.041896869773946466, 0.07621877706579624, 0.021623122776227615, 0.09474194803906065, 0.06018168398088986, 0.02865521045732162, 0.10350675231987432, 0.02828846693099026, 0.027737314549965725, 0.01867171925222201, 0.020846857373873075, 0.04146403392716762, 0.035303894114950975, 0.018722700488363064, 0.06986750980779048, 0.020987200851161635, 0.022984888111691804, 0.016569351822498347, 0.029217505587204814, 0.021703646277948734, 0.0347749448771919, 0.06294031680050878, 0.06829680739751748, 0.027180156039614833, 0.021351761026908795, 0.02538121688450056, 0.03617175681997211, 0.0387471720516201, 0.0341942502305873, 0.020006363159946857, 0.006554341366169073, 0.07687908356949207, 0.029291339226127155, 0.05339661560532066, 0.02454991764088552, 0.02126396160512682, 0.024280518991872672, 0.019685054393184763, 0.007097888888130266, 0.019164784931607785, 0.03809345390407309, 0.08148969947210244, 0.007061347930556945, 0.015681994095024084, 0.014523538918564878, 0.009426551987417042, 0.02118729152566483, 0.04123337251404601, 0.06465015993002923, 0.08393029472039593, 0.027675150345349987, 0.046019254011973265, 0.0797660246251091, 0.07230334765007419, 0.009256825207792705, 0.05803230173525311, 0.0496462130198075, 0.006857810818004392, 0.05324634745897305, 0.03291753406125692, 0.03548986195857006, 0.011074138981770846, 0.02645832309950023, 0.024800246446243217, 0.0044557564955715456, 0.028904842122668223, 0.008160865568976489, 0.040040661716052604, 0.030726901811337283, 0.005608136594791206, 0.033097664314892986, 0.03587310510357061, 0.03410037764678559, 0.1064856622308012, 0.04432296297783333, 0.04301615870527683, 0.026924250114168373, 0.010174175277502548, 0.03273057796421551, 0.054025140951477715, 0.03957794844022682, 0.03183613200822184, 0.03553195849000927, 0.021983768242681702, 0.042151984713611104, 0.011002030955897945, 0.01670352829199645, 0.02640696839549609, 0.040441877283756776, 0.028648721692602963, 0.04204830237393899, 0.10175646357839147, 0.06601895220697888, 0.021593929080653097, 0.0209599721711129, 0.025022846699181586, 0.012885230206584018, 0.018269465635380438, 0.030384426035227317, 0.016660648435654662, 0.05463115480397979, 0.06228580192152051, 0.025911393778158293, 0.034916196168670734, 0.02764874329460004, 0.026649665049908143, 0.08429004194875879, 0.04779180526853569, 0.067677371684582, 0.024646758815393816, 0.054997785332342314, 0.023889614967629317, 0.07479859561088585, 0.06151170071755206, 0.015364661324589003, 0.022911255570849585, 0.05882289298179169, 0.0584586488173133, 0.005528706683581996, 0.07833342488494613, 0.010617553451729399, 0.01995523828232, 0.05861884546315959, 0.030993718744045308, 0.015664387479304306, 0.009341074769655544, 0.010027230995136404, 0.028118966147303585, 0.04605529844881066, 0.028408719752464565, 0.05383054312739161, 0.07063760437191495, 0.033884061230046135, 0.03523523348473734, 0.11744739217383247, 0.01727815743746056, 0.037162281692989414, 0.06212484301818956, 0.021139008834237055, 0.030529603527318087, 0.025810205054679708, 0.03519319824033207, 0.05077012529176089, 0.0500869165895687, 0.019271472251162897, 0.05924740145283361, 0.021466835094014966, 0.02706523710531333, 0.057130991631457885, 0.009076059101179484, 0.02550028610013185, 0.04720607742426857, 0.04927013662733859, 0.020081838142246972, 0.052038962246790055, 0.0191636951715355, 0.039290588859829216, 0.07097811513249913, 0.025547775890557997, 0.003655353817345214, 0.0749502656981349, 0.06347000148267516, 0.03407852115830587, 0.03452998060252398, 0.06817035692473573, 0.04080584182614281, 0.03572151545555361, 0.04371436357858681, 0.08676269797668343, 0.06938276001282277, 0.019685554265555356, 0.037363548312456384, 0.027657700777654688, 0.03150103174360289, 0.03369201064830826, 0.018318206064342972, 0.05793070315473503, 0.0162132952227107, 0.025700623837990627, 0.03653421216914731, 0.060694177650035395, 0.09254079357150102, 0.0868086709130195, 0.04113434415851389, 0.02452472866993518, 0.047360248788590395, 0.06958134532455476, 0.04874131379408702, 0.04158139093628815, 0.030390370877519734, 0.02911984278339773, 0.06257671614988677, 0.08821713888356764, 0.05072539724830178, 0.02992413742768188, 0.02279433714706571, 0.09602634040939231, 0.06815419246953341, 0.028003451579640952, 0.05272515869188694, 0.008967301429009006, 0.032032522478050766, 0.04114859339390551, 0.0031691144601697285, 0.012938273176851292, 0.04185836236443251, 0.04786401671627837, 0.04659909830098191, 0.02180018676294675, 0.05469695026535661, 0.040277256480147766, 0.03663631253725579, 0.020917975231103843, 0.03108094168466426, 0.029682486483286467, 0.035225147937214187, 0.052065511023805994, 0.06371890344927389, 0.0016511671386861934, 0.033097380862361005, 0.023894715197985212, 0.056178460889045274, 0.014046706642294604, 0.06914879676074752, 0.04378405842749823, 0.025172450264254888, 0.007036812528367005, 0.022963012471013976, 0.04926046859773417, 0.011623583944334138, 0.03430362843397645, 0.01156588507470705, 0.004954271932928673, 0.024076256968621767, 0.039730583798260465, 0.024223667607011817, 0.014202197593066, 0.02014831733709622, 0.04627918381424201, 0.022603223107815273, 0.05278523913734863, 0.04426216240972281, 0.04701732868148435, 0.043221834160748034, 0.027761185849686305, 0.021542708442035704, 0.03994378989802734, 0.0711154900190811, 0.040491270802674756, 0.06667870712736923, 0.028832624929266113, 0.04735217422186848, 0.00834126491099596, 0.08027816972424907, 0.03517852382614248, 0.043025696499934124, 0.049936399464645696, 0.020098205610749223, 0.01465795862097894, 0.06317735589560002, 0.054053076347636606, 0.0035888035199604933, 0.025560364630373738, 0.06185867342977755, 0.05628899205476046, 0.048748859760141185, 0.02133948829836182, 0.09417106697876608, 0.020355174483190623, 0.05390144073434415, 0.020376444914408272, 0.043162010354740966, 0.045480246039768385, 0.02765355624198433, 0.023040056018339052, 0.11281205461390557, 0.1696667183310755, 0.11098944717237066, 0.12918169880586286, 0.12918747510881196, 0.14542280876588437, 0.10154405037962622, 0.13977955996749863, 0.17811927283483167, 0.18805305834018415, 0.2029944694931469, 0.17564771997351802, 0.08127995225931368, 0.29586404501911134, 0.18030867551363286, 0.134179824963212, 0.16800202459337252, 0.1463956178556527, 0.15718363736185337, 0.12938124938837944, 0.15012278882486207, 0.1237603550356242, 0.08324957197351802, 0.14096521892614905, 0.07016058440410322, 0.16945051299708505, 0.15312600670562637, 0.18346287400251438, 0.2411894989951003, 0.17320984433735573, 0.17945606561918415, 0.13792096937616027, 0.16069314743001617, 0.19700346274241326, 0.09864601637086562, 0.3218917903159896, 0.16608508874572095, 0.08857150817470205, 0.1984065834192499, 0.1875950909790493, 0.14153089824943774, 0.11947361046388266, 0.10457232699639375, 0.08074531481871683, 0.10884608637781874, 0.16671133498030324, 0.11029347161492033, 0.12841662211764243, 0.07872769969605631, 0.11588913103144978, 0.09956003587332465, 0.05314593631473761, 0.12808476815060263, 0.18893477957575552, 0.15653872922543557, 0.20302206398017947, 0.1545541018487946, 0.09079655692461999, 0.08612498340587463, 0.18612251677099736, 0.1376847844691046, 0.3525648169940518, 0.1673207426023099, 0.12620890227657172, 0.1222095019634693, 0.13480049407770558, 0.11287705717428077, 0.10242755660006117, 0.13050965093556913, 0.11778809445639772, 0.13415284334651886, 0.18432332863730772, 0.13625342579137895, 0.14088303301363223, 0.13461877802206626, 0.1274534044486861, 0.1284804908678897, 0.14044349772795556, 0.18601457498246626, 0.09599034193783038, 0.1524760883541838, 0.20676702351099063, 0.17956923212735884, 0.20156415269499828, 0.16233364811107037, 0.0861841636980253, 0.12535341189152774, 0.12421058490872385, 0.07553796238836742, 0.15129591458507125, 0.08778917152554759, 0.1505489328936223, 0.12722389216745092, 0.23261075448845667, 0.10398397913142558, 0.16157273894115803, 0.11005573154937838, 0.1351446973820848, 0.12954840977345744, 0.17755281210186022, 0.10427923707832253, 0.05943392854063742, 0.07479265842947268, 0.1393047233502711, 0.10814172981847679, 0.15577026642858982, 0.16196643152544576, 0.11516448080299363, 0.14067841092905692, 0.1338408310567179, 0.2640740315039312, 0.13955491234458264, 0.11318485598049818, 0.17182058985194854, 0.13352940099373942, 0.0917783139213439, 0.1809780984636276, 0.2251240836396333, 0.21364560440903713, 0.07193413923584646, 0.13172837424903147, 0.1185724535776723, 0.08164636445261779, 0.11280859189648783, 0.11987093430493148, 0.17025669796332238, 0.17008743849733185, 0.16339763698558654, 0.0961284063035442, 0.18372470753327494, 0.20176753371713624, 0.13469003952078282, 0.06825864855800906, 0.09576374079070746, 0.1862533339449475, 0.19262419773205636, 0.08362565219642655, 0.12092720101317092, 0.14265940704893681, 0.06878255310678674, 0.10941078510856438, 0.18066440078039325, 0.1596016713207768, 0.1518890964648416, 0.11225256528104506, 0.19652985186586458, 0.15315053684096183, 0.14836955064487073, 0.10156923168969732, 0.14359294647170653, 0.19019744569255462, 0.11681393705188267, 0.17417146854342955, 0.11903949908070988, 0.1468745453823959, 0.11070188074823349, 0.10570170147524727, 0.1469632123987521, 0.11417102564366595, 0.08983745314781705, 0.21647092135202503, 0.12427181831651157, 0.1508536673481426, 0.07594316161327785, 0.17360618758586147, 0.15597904070971474, 0.17662710209767665, 0.10773573386212511, 0.31698196345279295, 0.1602113240909192, 0.08612125255768338, 0.1560049651250724, 0.17829381830749974, 0.3040989692653379, 0.1267911520816626, 0.07330506123722562], [0.025454410840006127, 0.036932903477140976, 0.031204689782293096, 0.05120435924900155, 0.02859957332182075, 0.0784445995645177, 0.06097446240845227, 0.0243243545429, 0.11226758060436096, 0.03686377553329353, 0.04717608508203299, 0.04426559831406321, 0.05440418976509283, 0.05321249020315948, 0.026859896813309, 0.06221972683805132, 0.07253590896124802, 0.09321079108743899, 0.028178571618252227, 0.02617804983240222, 0.023994164901875684, 0.03928191291408674, 0.09366027019437283, 0.014692355968779134, 0.017871377621627143, 0.02565820363440341, 0.03066505936364974, 0.05436529931161673, 0.012976122708360275, 0.09472828869137073, 0.07196713464274522, 0.028974171164595795, 0.02446557136042224, 0.061192161613895055, 0.04052947560745863, 0.03365340747780377, 0.02847130722065847, 0.0409418607370988, 0.028797122499635144, 0.07827875685066947, 0.07414548267279902, 0.06604199613174123, 0.01934294059361902, 0.05748384023806261, 0.025416656111877774, 0.0061504851891509, 0.04610639268292054, 0.030262058811081998, 0.035790608925444466, 0.010826915705336199, 0.03556736707386952, 0.04031540382833731, 0.004096037995505838, 0.01763919935441546, 0.04543662882379947, 0.032793592526427204, 0.054161899137280645, 0.06692465199458023, 0.03557831447030749, 0.10503325911779558, 0.019187428575429707, 0.09813144277300566, 0.03551445721137909, 0.012493692244583321, 0.0848665843988138, 0.012472538641774127, 0.07158392214126165, 0.02408754144374642, 0.036543462680833, 0.041366667982431195, 0.0065882991710227105, 0.041258132475758755, 0.02223589543944165, 0.008061583446819455, 0.08292474303274386, 0.013877272891301303, 0.008761085881551188, 0.01319197564190554, 0.1004556616047217, 0.024334673747240056, 0.06172699823735222, 0.07130573263331767, 0.045370549909890666, 0.030343206674461404, 0.0006278760267906042, 0.13942588781637533, 0.05915151022735143, 0.05979696611663508, 0.019637606737594453, 0.02326883285516693, 0.07729863162122427, 0.03610517994891252, 0.01990036148908398, 0.03551053101076715, 0.03375654972548928, 0.020682834118845004, 0.012510847826037678, 0.030960658219672983, 0.05413549591697032, 0.02656134468833766, 0.05409136159165252, 0.04475001486078386, 0.0396866716384407, 0.003920653656560687, 0.04876374101807033, 0.0583635964581082, 0.04749668138702551, 0.016636217891749357, 0.06194929780078031, 0.0827617961312494, 0.017098691765098803, 0.048757788514898676, 0.021797968938405958, 0.04209253246024732, 0.124235704931761, 0.03590252287986298, 0.02351168464238365, 0.05827258138226406, 0.02611050960577784, 0.07747087116924024, 0.039154374596452525, 0.10329102196039693, 0.03462002274670428, 0.014310660321385631, 0.05626176145949191, 0.019254987954252192, 0.06194633304051334, 0.02793941237483054, 0.04079126700338337, 0.07419574570151106, 0.06294346159143795, 0.04992520692007196, 0.03274599931413128, 0.1231364913344864, 0.06529962628959649, 0.04151690165482221, 0.03895659750748066, 0.04482081287630624, 0.06945910833535657, 0.0584773873279412, 0.06901938918857806, 0.047023526332791776, 0.03440863227531795, 0.04889689476018952, 0.1142036073630856, 0.03779611602846173, 0.06727083946668333, 0.02955991050018178, 0.01720577936559435, 0.037367007199434504, 0.019188629418251016, 0.030938405280692444, 0.00749844131097498, 0.029568927355050564, 0.10453227591971237, 0.08891869922198596, 0.044749712256053766, 0.052895490680971456, 0.0671151627395903, 0.01079811558743278, 0.014658363689968904, 0.08753572665755788, 0.059640454353704575, 0.040233367302965735, 0.03239955137213392, 0.046964736745482495, 0.042590428323995684, 0.030359721614889083, 0.028093327099697727, 0.051516915461228746, 0.02375467432542674, 0.031039929167637904, 0.018210105312567566, 0.0826860376964173, 0.06582811204416138, 0.046178638604619814, 0.023701454197326978, 0.06523535151274935, 0.004209293082596794, 0.0704350354029767, 0.06636348492916554, 0.01454457569296562, 0.024612560650453936, 0.016355343245630784, 0.02239058582833217, 0.047549667858308366, 0.05494150851342467, 0.06554990721445891, 0.07217431546098764, 0.09848517621116293, 0.09079041289946727, 0.041629960910687526, 0.032847620877287084, 0.061385261736089186, 0.011268254170464653, 0.028687642789596034, 0.0325216964307812, 0.06855457300140012, 0.06179476254469445, 0.035263628533650795, 0.02709728064796617, 0.0469239502243938, 0.016790316477718375, 0.043111387264704516, 0.042402012829458526, 0.041524807682200786, 0.07586780154416639, 0.04509521790990426, 0.04057783873811845, 0.007923079538159072, 0.03085558159997867, 0.04906346525756582, 0.04454407510497878, 0.022425770331474564, 0.0301777278523772, 0.07291706834709452, 0.013368143305753269, 0.07656784502849465, 0.011133506007853055, 0.03999145971911569, 0.03250905981047019, 0.024280128287031286, 0.03633173130032036, 0.046476424641666875, 0.013479045066501827, 0.024645912288237485, 0.04773498452719181, 0.06953040813846935, 0.014480747162334382, 0.02073510429791866, 0.012130596254381442, 0.044069613870834155, 0.06893190960850447, 0.03629475989709458, 0.003228656250059665, 0.06045759820769872, 0.0332525136670278, 0.04170755412609827, 0.08051363450865592, 0.007161924741306012, 0.030270382356379303, 0.05014249626847525, 0.0632034105459048, 0.0182362231651261, 0.002569531197584565, 0.030193645244223938, 0.021296633339877573, 0.04304557265112958, 0.028343345639446092, 0.02914456252549445, 0.025000888704051896, 0.029444334645485206, 0.039278228031170946, 0.02110362323301454, 0.026623280981795925, 0.006830821540431992, 0.017092817785939383, 0.057378315456932595, 0.025184219289991646, 0.05550157624266802, 0.05797545418083187, 0.1667347006619938, 0.03340586148683102, 0.0314968450730967, 0.04520061628652677, 0.02551483985547337, 0.060815667703507416, 0.020463393978594292, 0.02501371301590435, 0.041023230765976255, 0.02379774761896941, 0.019432651404772076, 0.012200980582424711, 0.11554984601154444, 0.05757544520160845, 0.047527684965321136, 0.05652371373388076, 0.01355188949439194, 0.03737403222570016, 0.035089477596263734, 0.04066494293510914, 0.10599751100544968, 0.02969185956904004, 0.07639166778854786, 0.08015700525814488, 0.07026641945084257, 0.010608600756724276, 0.02763394247590294, 0.06125725993526079, 0.04587239112644907, 0.057551508784414306, 0.025470766817189516, 0.021183880519181974, 0.0034943977868439812, 0.04974780776988595, 0.07830508729262699, 0.08060256965578565, 0.05157785009472601, 0.04932457100479834, 0.07048813295700858, 0.026041875788641554, 0.026493452061268113, 0.019666287154259703, 0.034236626384118875, 0.029643555810194344, 0.054395349110446634, 0.07187492830017883, 0.030186239089215958, 0.02082179289221043, 0.08206350698826775, 0.08085416059099859, 0.02082327527234391, 0.04714436904196778, 0.06851419250691129, 0.04613191107167833, 0.03679692670102081, 0.03196681894722485, 0.024588449948257016, 0.058797658045565894, 0.03594903207774605, 0.04433485649285778, 0.020741344084061926, 0.02233909705894128, 0.028127237981666, 0.03128569208896689, 0.10215608568321313, 0.038882187387395295, 0.017118048891725562, 0.029825926871008934, 0.0039676605721920616, 0.06407396221954016, 0.10144420614045474, 0.07960063390313618, 0.03763629476569834, 0.10297225277510383, 0.030452864499942913, 0.021633997394312775, 0.03652169429246457, 0.038527458034936464, 0.049957030212446574, 0.027513862024211598, 0.05944176562010281, 0.062119717889976125, 0.048189489170908935, 0.04920141854053063, 0.04806195468371434, 0.037999520033237436, 0.051189485651951645, 0.03409684598145466, 0.022422466577301105, 0.06121132147288131, 0.01604771393636662, 0.15168326396134593, 0.15935557323598093, 0.097591542308369, 0.13086533023705407, 0.10424402001644335, 0.1375131654523073, 0.18407752166592306, 0.16540783637714002, 0.1686034955444836, 0.18228476867079738, 0.20783683465373134, 0.22376372599072997, 0.21376106918098467, 0.24085842643774327, 0.17493263818323615, 0.19873079182880543, 0.1523994029529633, 0.11899433819757355, 0.09835029877121411, 0.1852310968623046, 0.1127141792206995, 0.20839385718347567, 0.13877108182397582, 0.1508462209735186, 0.1035150184085773, 0.093379529613641, 0.14109499422052216, 0.10914813186372481, 0.1376845699644858, 0.14550876383098865, 0.28364754732578035, 0.13928572436974895, 0.06942481823986577, 0.10598307790895624, 0.14777148112414346, 0.08890101025181432, 0.1325699065120951, 0.17858738320008402, 0.07588552115785499, 0.10548519736696636, 0.13877904913838834, 0.1858689723115775, 0.09251466997328306, 0.1930917565140032, 0.16024265708702226, 0.09434791071520698, 0.14274341625071343, 0.10572356562460623, 0.12917917071571275, 0.1259340452510984, 0.13162588700652122, 0.17027528325636543, 0.1654494043079115, 0.08906243263833946, 0.1069582542104106, 0.10526921419847397, 0.16914847517205825, 0.12635501822636974, 0.15423779946661767, 0.21566400094138038, 0.21356190164243022, 0.13623018268375628, 0.1726469535741114, 0.16996872551258535, 0.22420614176700193, 0.11484596442671553, 0.17592018680466762, 0.07076048487496954, 0.1112506831545503, 0.08701837982141203, 0.14601972915472525, 0.11708051266689455, 0.11435939134248804, 0.12944085102888847, 0.20177133351324067, 0.18189746525979814, 0.06838154438282214, 0.10000519424436555, 0.15161996977704187, 0.14028962130748457, 0.21163019561959853, 0.2365204229229881, 0.1244862693091554, 0.11119098958349037, 0.10188104479663795, 0.22696586626191295, 0.14693783956669992, 0.17898723513128298, 0.10720684208096036, 0.0705155895482148, 0.20156289631080246, 0.21702774469890904, 0.20786821361510985, 0.11849170024957388, 0.08282309082607109, 0.054153016347798615, 0.09253272666565834, 0.17294280140871005, 0.17015108508208107, 0.10873511854198672, 0.2290095436957575, 0.15616299374209297, 0.1499003322134095, 0.0790189050378338, 0.11966171569281048, 0.15465658909130484, 0.1658633369351587, 0.17182288811572138, 0.19341596492355873, 0.15938428621138298, 0.08647712338114939, 0.11286282326064764, 0.0918683905394808, 0.2005793466683357, 0.16713541061166795, 0.1817577155006509, 0.12120820972467623, 0.2319750547288887, 0.15136614952596927, 0.25650915839979727, 0.2053823808748876, 0.1360748047309537, 0.10768724049651816, 0.2347757955712657, 0.17156526806854433, 0.14061473370079072, 0.1898858317684743, 0.08818138556014146, 0.11134486600396135, 0.10704011070511996, 0.15489992925957327, 0.15746773340769354, 0.11247697541670454, 0.2512383202631628, 0.1952882684887417, 0.1254922729886828, 0.19482720613239274, 0.16100682979149206, 0.18857128617744293, 0.139864886840505, 0.1397762964329412, 0.1512944590180151, 0.16235998621390713, 0.10411645871617141, 0.14953276322733972, 0.0768066576171306, 0.11271358167211856, 0.08195237827397163, 0.10687835123990813, 0.27482172414179773, 0.09646873320302657, 0.10075894049218587, 0.15165694118026765, 0.13062643337874644, 0.168730819357499, 0.2165618713103956, 0.189608262791749, 0.17861464060842994, 0.18457034602761271, 0.12178749476950015, 0.09788888401441997, 0.1496239276903291, 0.28164716918141613, 0.13664554023454267, 0.19575242584030475, 0.1669175045624856, 0.2031525747189599, 0.13223690341316885, 0.13854534635620733, 0.13746583654034522, 0.12143272711264512, 0.24830792670048055, 0.17221710163979762, 0.25424357593780567, 0.1532677023281013, 0.15260712003275273], [0.010620610142547277, 0.03073074565749736, 0.015580747914951176, 0.05423619051373774, 0.06145199182473364, 0.03568607239773677, 0.036447778299090364, 0.10960268247271739, 0.044806165275193995, 0.05658446833671582, 0.024242649350555676, 0.058563897806790575, 0.05513901747162304, 0.03592242967457541, 0.028468648895561218, 0.012518062459064588, 0.04681552580047039, 0.030597070975589658, 0.01907637838514582, 0.007693592154781425, 0.04437666957176501, 0.025885153351531878, 0.017278126793943586, 0.016699092642914866, 0.001359560797760834, 0.04729874725002916, 0.022430795868257844, 0.02933869303594674, 0.014485899103625167, 0.027153825597657312, 0.02795960645251457, 0.036283643961313276, 0.04452155978088418, 0.06941063795238733, 0.02609102798986339, 0.04540373300833087, 0.02157074917528418, 0.015463453150474498, 0.056315575305732994, 0.012364793163273605, 0.028827078452694322, 0.012497193266397283, 0.055940249679429885, 0.003973941056756303, 0.03562380477125126, 0.04642185619882038, 0.0632569945657686, 0.046600396820013566, 0.001873116456291398, 0.06753964439755486, 0.03701793923673611, 0.03319466636786538, 0.03729002685436318, 0.012396129032206393, 0.0165877953892754, 0.05499853226806849, 0.03628206582018926, 0.04294068372297672, 0.024953255272139947, 0.04877471522758565, 0.05007925187988628, 0.04475532768053874, 0.07762468630267728, 0.03436750101466333, 0.06628001198893593, 0.02894547925661168, 0.03572833363807971, 0.014944859506231884, 0.011835490567459455, 0.03354365772177135, 0.04467316092022004, 0.022418812337902286, 0.060563398780481476, 0.030661498970021645, 0.016574082415430777, 0.04237094413368933, 0.029969991620389685, 0.028854012188892213, 0.05605571062093782, 0.03586815617557976, 0.014190733087279144, 0.031956896193385605, 0.05367972722817814, 0.057991024917892875, 0.009625133468709406, 0.027186514569386363, 0.015917455048991308, 0.04473321072216477, 0.007999753448060684, 0.052523355810872974, 0.0348409854867045, 0.030614426697514234, 0.03305549117466135, 0.010955740093073298, 0.019970477686353752, 0.03132051270034525, 0.08174399469768809, 0.02146613412356425, 0.02704267007028384, 0.013899645531520009, 0.03440012103847919, 0.03198332431155347, 0.010818775063530814, 0.010568573620290527, 0.046597780629752145, 0.018592191664802454, 0.072539915601092, 0.006954363751931177, 0.03888329055400626, 0.0498849451692114, 0.01747756054805171, 0.04931515961464855, 0.040361771299954385, 0.06712201156563337, 0.03799919827630924, 0.04302680732742433, 0.024238771030439005, 0.04395202703533634, 0.10054955334072152, 0.10592020507301055, 0.0037992995836952283, 0.02043500659056008, 0.07859774820146062, 0.0931302905683556, 0.012150067336586936, 0.051113719556240306, 0.06286348584258268, 0.1042519030611842, 0.04911357123825339, 0.0029756997631216844, 0.023028491921122038, 0.055567452143276894, 0.033706976175909086, 0.061623752567796945, 0.039305500761275335, 0.02327540971999688, 0.05647279569999345, 0.024532893251988198, 0.05876462816471054, 0.00907027034930164, 0.03509645282681431, 0.09185055601260356, 0.03194149591088776, 0.12018926682010775, 0.037284840439115806, 0.06703064791978368, 0.048145500402296745, 0.015465553188996931, 0.027465447182616884, 0.013901572242649573, 0.039192426183651534, 0.007095415381744745, 0.08034390006815234, 0.037185528631051706, 0.05640045401730365, 0.05614520501225226, 0.06713609226168164, 0.023872263076144363, 0.02531721981452598, 0.04342356426340919, 0.04520350060756168, 0.015040902991689023, 0.038582765752629894, 0.11029152575159266, 0.03176043294520388, 0.01859103870247641, 0.05376809163980427, 0.019017910554764733, 0.049257174419659766, 0.11577296911949113, 0.012447025041065872, 0.06234981622847338, 0.010107102364511981, 0.012572328297180996, 0.0892373305114527, 0.05043211197780986, 0.06566110487666822, 0.0903247693373311, 0.06179012388231293, 0.04065875294468096, 0.04088563371389624, 0.05046655912132514, 0.05503131700078807, 0.03334560867158636, 0.03140420780607289, 0.017116560765932647, 0.03760077126864945, 0.07858732174481116, 0.012377423080315274, 0.0408644360610314, 0.08342479160355945, 0.0926594146256966, 0.04232015250430953, 0.029288552581302585, 0.010205288980937293, 0.005954394930027306, 0.011086507471308354, 0.02601930492317244, 0.052871699820482926, 0.07072571980496568, 0.043278961337261626, 0.022259948685044245, 0.03188473837179763, 0.017630776217687997, 0.10068397878879502, 0.07607816162729457, 0.028656072306236433, 0.0208192284128839, 0.05740812010762673, 0.025988860589061535, 0.026739477367711165, 0.03883847824087547, 0.11891972123374862, 0.02695573249741668, 0.036522644241490675, 0.046256568898717244, 0.04075287450705806, 0.03079001979541875, 0.02919748196408393, 0.05600347874626037, 0.0679035208398296, 0.055331244253583496, 0.04747713082319787, 0.052653184731400786, 0.0466334228704293, 0.03355765797858758, 0.04191983325947677, 0.039621531182239135, 0.027638274703114748, 0.0323165763890551, 0.016058932336407806, 0.03435257379145872, 0.07252454787733094, 0.03514959634612164, 0.053360889094971845, 0.04521112701284789, 0.02546080575895406, 0.04848512633132839, 0.013462074303759203, 0.04576348023669374, 0.019116352853034774, 0.03508036881084404, 0.04297169879259121, 0.051770295211744886, 0.010879904091838869, 0.0582867999741387, 0.03924917031620299, 0.043547272141422, 0.03918312587625077, 0.05086215926454433, 0.03164069914829827, 0.0844169520742951, 0.011957999517870768, 0.027314792161867506, 0.03233429983318333, 0.1003401508674987, 0.027594778145993912, 0.058668265795154925, 0.06528584436783869, 0.04000832897520835, 0.04795135073964635, 0.03481879574997771, 0.01868128194473684, 0.0483747560440773, 0.021889108503537796, 0.02677625150329644, 0.008744893655661614, 0.032192631023785764, 0.00469461074023838, 0.019874730102357366, 0.01734278652997267, 0.030887238268229752, 0.018393322900538484, 0.017904177676105214, 0.02603080198769608, 0.04044790256528124, 0.07925063131317016, 0.028050897320011453, 0.005090459383228013, 0.01670358957903039, 0.03443365653736457, 0.03685785367363884, 0.0535962657792674, 0.013185005199404494, 0.019193836900916313, 0.02562485391183967, 0.039577370043843985, 0.03008945154086236, 0.03723365044401538, 0.008587683795110114, 0.020544264135101152, 0.04477516935777761, 0.022067078389227394, 0.038832280589568044, 0.019017255549589475, 0.12065651150600565, 0.021102575607778087, 0.03328186249540698, 0.06029155631099017, 0.026452274835338036, 0.045247535341449326, 0.05071352671591505, 0.024264546058651422, 0.03335380581237617, 0.039086840115487576, 0.05477307642239237, 0.01141403399918589, 0.05560987426208393, 0.00707098292261963, 0.05545939544155713, 0.0031904526422881795, 0.0037439217210762325, 0.020549640157109788, 0.023425932590579315, 0.024296149100747802, 0.018011830266444914, 0.01982196388135274, 0.027532520095607447, 0.048700845199486906, 0.09849199439368903, 0.054696402512490756, 0.033775426131943544, 0.0812232923964339, 0.007830516964707884, 0.026451742404230663, 0.0052740016009568454, 0.036420919256465095, 0.0019016671168144734, 0.006469868681198287, 0.042485382347818346, 0.014933941795700982, 0.039279013271293337, 0.0455006699438297, 0.01832027450173853, 0.014061264228075744, 0.0171338954204393, 0.029370612089311885, 0.030541311266020905, 0.049602044220533104, 0.043566462643925226, 0.031196201528092066, 0.011198335240835385, 0.07492347560342281, 0.03329722638872843, 0.031164868531988996, 0.027877790177421227, 0.01739772269502282, 0.04738163796343631, 0.05038407443451786, 0.04566185867353793, 0.03499174392932365, 0.046379311505945466, 0.1371481705216631, 0.18329894650847683, 0.227892664110949, 0.1285301716697793, 0.18590565260139205, 0.09938193575268793, 0.23960070924893503, 0.18607782320149485, 0.15245454596175304, 0.08752904637085815, 0.12194948406108927, 0.16171178389941493, 0.1409697235231438, 0.12837940556628089, 0.17929540165970403, 0.2587094548488817, 0.16385931221227493, 0.13827268034219742, 0.1598991432617749, 0.10876689586908588, 0.13999380411640291, 0.12432159104895209, 0.15533155851787137, 0.15099729351218671, 0.14040591345439035, 0.13676963115651763, 0.09599217288796941, 0.11256603313790214, 0.17969837922963405, 0.23573576502742308, 0.2336756473467235, 0.1121568579166647, 0.1289566681389847, 0.1488169766361675, 0.09336687384113189, 0.13148624449968338, 0.1831533131940711, 0.16396619679947055, 0.21965084507340388, 0.06458919465301499, 0.07475129734244078, 0.11117235066429262, 0.1388784107421675, 0.1706654978014769, 0.2082092146719656, 0.10868942139730339, 0.1652091897783741, 0.10726092022753532, 0.11955711404762923, 0.1344291865825653, 0.12697029408187638, 0.0892110383738914, 0.09744264545940584, 0.13388132646439538, 0.12088559477800324, 0.13062016677952584, 0.14213659800589085, 0.18745227686820493, 0.10667743702088633, 0.18524790483136333, 0.18212482483396608, 0.1926238453316112, 0.12523657582219572, 0.12624511525275248, 0.08620649516101807, 0.13881473351390133, 0.1149845727148556, 0.1629241027178303, 0.11016867589205505, 0.15544100183873408, 0.07972864719528346, 0.0794776844521684, 0.14079451921486086, 0.1264380008703278, 0.13787655159831047, 0.13636455450567508, 0.11981339344093878, 0.15137727312262983, 0.24884837108754346, 0.16464642158919768, 0.10661340739217498, 0.08373000869347204, 0.15211421906227066, 0.19183649080655268, 0.08914785144189674, 0.13384208744091372, 0.12101988233025036, 0.1291367294447076, 0.14938190519329042, 0.18033070820233515, 0.11181240946414972, 0.11755228493242495, 0.17906306251402826, 0.17573821027913403, 0.10221496720107333, 0.13528878319888346, 0.1374586506356155, 0.08045219425712863, 0.09426085248349175, 0.11447991229473584, 0.13377571358315407, 0.1462156791239977, 0.10727334617366714, 0.07953565432539872, 0.10681369341909887, 0.0874149222527781, 0.29209336025580285, 0.12010332707676197, 0.14595009176240814, 0.10385062620644608, 0.10740525119246976, 0.14419898330684633, 0.14390609257163542, 0.13719024407046457, 0.08348155871874864, 0.1509577020882599, 0.10538219684554685, 0.25576439836332876, 0.2348545800533987, 0.2506285449189525, 0.14259527016791607, 0.09370471861573959, 0.21778865386882137, 0.14630904992020902, 0.11393166913260376, 0.14267960112662087, 0.13586716425995674, 0.20734736575715004, 0.1338947176813118, 0.11770529567354149, 0.12580888180602945, 0.1378573687566865, 0.27192290872335434, 0.25512569553909764, 0.08097731688570592, 0.08795964141045848, 0.12217305916091128, 0.14667986711907774, 0.17640338910202827, 0.1088807978216679, 0.1375886404346074, 0.17049798501595376, 0.19820704815849183, 0.344266276806593, 0.2048974012535426, 0.12749342488185053, 0.17969585113948394, 0.06295124504474864, 0.17470123366482798, 0.09840252298501231, 0.17273992600460208, 0.08398965121276918, 0.15000291138647065, 0.20103604232351627, 0.13222510565913495, 0.21151724361604263, 0.2206248032950586, 0.176118848725192, 0.08115458963138443, 0.1931730077992524, 0.20532878536370494, 0.11605765505303299, 0.14009558655802282, 0.23382678117242553, 0.1108132392889069, 0.09618109783097621, 0.167831661960771, 0.1269703936733065, 0.10827110674712928, 0.15027514839124295, 0.11789631969746082, 0.16631306119022832, 0.2073995976318275, 0.1613242659837969, 0.11552099514031604, 0.23774702162031205], [0.03738137900889401, 0.005090557059438359, 0.028693120318254637, 0.029637570748285904, 0.014139532558469763, 0.02319760008474752, 0.07329674918324718, 0.024766034874764663, 0.028163600344991976, 0.06569245319452978, 0.03656076477660287, 0.057253355025163585, 0.06241372328311686, 0.05649416955308088, 0.009129203578096726, 0.036046616357540896, 0.03634460540788789, 0.05822630967163752, 0.06753233591875724, 0.02512271775143041, 0.051317407013548, 0.03694421476534298, 0.1031849570872803, 0.03518804246860166, 0.07039689188522678, 0.016828283795245716, 0.09473296182770884, 0.07529757165860745, 0.02175454899007755, 0.038647913869710705, 0.008010272314066008, 0.06256684510698242, 0.05118464014583057, 0.032988067776445425, 0.023540801729165742, 0.016228664861691576, 0.029785429548111655, 0.08370704137750211, 0.06392735214303098, 0.06146543283736514, 0.05375987151637674, 0.10013309262332418, 0.03504754194328862, 0.028470366847731417, 0.07322293661174274, 0.01857405070275549, 0.08049655074794447, 0.046460639399987076, 0.030856414720596328, 0.020573394628421917, 0.015640222193342785, 0.004696879796909108, 0.04098353975061928, 0.0630764659464119, 0.07479300316903861, 0.04441709220108967, 0.03092533773592403, 0.01192633614635035, 0.04303344930972784, 0.06975756852977699, 0.09769255100118537, 0.04632909061206926, 0.1114965207694519, 0.054002269396498326, 0.1342011681727825, 0.033234361213661974, 0.05570844296486147, 0.05279157468448243, 0.006160902069701303, 0.03225957178660939, 0.047910242461629456, 0.016128766996365403, 0.019881745552523963, 0.06567051243637839, 0.061295583483672915, 0.046400693019912134, 0.04855383292681748, 0.03240857205744232, 0.009691253559844149, 0.030518200308565172, 0.050832009874284274, 0.07954258742111345, 0.020078178157188722, 0.030587709381154952, 0.02854527492496756, 0.03868060667187937, 0.03810455068765629, 0.04979831977717338, 0.02096238151763476, 0.028040424898086537, 0.017630657474059733, 0.0625958185522787, 0.02732154331170023, 0.04369870857185414, 0.013558693312769456, 0.055716153639819355, 0.045226165318801526, 0.017945766674294587, 0.09157530062140957, 0.07022797715880218, 0.04452003909635448, 0.015852224577458638, 0.08251729150933605, 0.040413746535177195, 0.07096976477412448, 0.027689457037335927, 0.03470815350151351, 0.07814969401806593, 0.02897454080201926, 0.05177082764285226, 0.05971070078592147, 0.027645747890816103, 0.03506051947272593, 0.005000583863171239, 0.10673815714976481, 0.023952150724888332, 0.03175258437441963, 0.043629017553382346, 0.025691662524496357, 0.028667052261411186, 0.04402245349821545, 0.05660534423265246, 0.03548034331611088, 0.0335101452055237, 0.04467783022611853, 0.029402508160039306, 0.03527793522563673, 0.10234319499783939, 0.08951039489118323, 0.024930046638473872, 0.07673030163371757, 0.020680081947977026, 0.057516169148467244, 0.03432779084710825, 0.025678545184012865, 0.025290418228495027, 0.03177764311042284, 0.012576462299142395, 0.029876739567806645, 0.04174194764345885, 0.00807144204079504, 0.008194403940691583, 0.03239352226016983, 0.012828627800298555, 0.028458176473636302, 0.02716421758035018, 0.052815618353985974, 0.03338354917603635, 0.037086304923098896, 0.06221170206704448, 0.07777286302899161, 0.015139630657710857, 0.039774400197089686, 0.025084382711699413, 0.029538532816654736, 0.007953635912628905, 0.011606223434360038, 0.05252717475917551, 0.052079561076337294, 0.01282489886732712, 0.05909308453180617, 0.014753671731018733, 0.04134112278059606, 0.041398862827449076, 0.06337992103409863, 0.11702546158865576, 0.04657094073932498, 0.03854815773065052, 0.03479487082410244, 0.012130024561267948, 0.08406870382567568, 0.050600344885981856, 0.04782860813241813, 0.0637092967067034, 0.026213433518404924, 0.0378107866122117, 0.030124134256414352, 0.04914159856496319, 0.037854062919054306, 0.0166517426635349, 0.05842794018286852, 0.04862384570221748, 0.05252485734320456, 0.010195987715926624, 0.04125849636752279, 0.0450623297553149, 0.034272709125352484, 0.05399611771046635, 0.04779042631027199, 0.0388701789591822, 0.028307575079041625, 0.07022479789391642, 0.04130007195917349, 0.023940362546953465, 0.01905308931224769, 0.046848931064408635, 0.07675765863349361, 0.004057199731769582, 0.0870767020950875, 0.05101354972970101, 0.06535966460022234, 0.025502331554889682, 0.038228024908852194, 0.04728069438809349, 0.05264388825443964, 0.036044613037618904, 0.0357256484999051, 0.035221631593641736, 0.01617325180690856, 0.04157910033339455, 0.09089696806885543, 0.04200652376898835, 0.05497649957936618, 0.03512071866181589, 0.054334709420800216, 0.0008069351937475375, 0.10864296582557502, 0.03728417394262168, 0.04795126263953505, 0.05174930057217998, 0.05990701464695796, 0.08153941857838824, 0.04201989583370667, 0.03294596741456659, 0.012369608025877707, 0.057677997561592254, 0.008253071911542887, 0.12125364639946531, 0.023446691658107505, 0.019931355491280556, 0.0838918294457178, 0.040716056321417136, 0.041875748729874054, 0.039207364898175, 0.022051404230296615, 0.07065861816367797, 0.040337329264730215, 0.01899949763150465, 0.03943373238848102, 0.007853226204808321, 0.015447613325030094, 0.022761111913789666, 0.038809623539207444, 0.02050776387594881, 0.02470896898528501, 0.03310918627727417, 0.0758052351433904, 0.02002944347388562, 0.03350860919923552, 0.045265113228871945, 0.04685366931822031, 0.013553757791317279, 0.06580342103036181, 0.0030886196867457682, 0.01025450246919307, 0.05775944036882251, 0.022417351025186723, 0.013913079840882171, 0.02282225722146611, 0.04311013854138794, 0.020231445537759893, 0.06546268810427959, 0.0452312444817395, 0.0767497985713905, 0.0400051880147188, 0.05910471374649675, 0.10293531967627426, 0.041659535735004374, 0.013039269420738905, 0.03072296986506591, 0.03496176690884656, 0.03947348469087193, 0.07896514864818704, 0.06306391359577257, 0.06778023431017514, 0.0432849521448295, 0.05353566056357757, 0.006638945243696893, 0.0565821930555807, 0.06244338237710538, 0.053156171249406, 0.01543537985848924, 0.027470991743968862, 0.018419000252540556, 0.01722161823342885, 0.0320865967941861, 0.050061693144661766, 0.021047788829873168, 0.05699115377219935, 0.008865473022113645, 0.030589124728595058, 0.13733727166489249, 0.028707155049027457, 0.017101648864486528, 0.06895488458535365, 0.10819015423617057, 0.05474712902439698, 0.03951373495041363, 0.02422506763269344, 0.04053008464735843, 0.058354131441803715, 0.014952469632149705, 0.050939514992698554, 0.032254473471473304, 0.03371610028308726, 0.026447410177018855, 0.055490942942279006, 0.01845615360164835, 0.009696428483772663, 0.057033809547823285, 0.05357075122094924, 0.018138071980267283, 0.013876630335054813, 0.010900495577633623, 0.09344962665871268, 0.011902633385973112, 0.03223798342890317, 0.035586155380212495, 0.07069028823846771, 0.03297527410810994, 0.046484847778394345, 0.04432783146659213, 0.043426299197298866, 0.05057152848871005, 0.053853694304463365, 0.028193314980355003, 0.03270860656254715, 0.037482318753797206, 0.018495400286009236, 0.05111948436787052, 0.03954705211424059, 0.03308064950209472, 0.004419066629657943, 0.04723742574213013, 0.012618466900030692, 0.0120586060145269, 0.07646591703016913, 0.022475556470453743, 0.06172162030012377, 0.027281423287105658, 0.0748892697776037, 0.04721659198102932, 0.011773164526769712, 0.04354956657475522, 0.04503162878174936, 0.02618681962391542, 0.07895379522514921, 0.018050885428824735, 0.0488898927165616, 0.0681203084006425, 0.017103198277313384, 0.03291789029214171, 0.07267469344961067, 0.14971009726005216, 0.12136006367302711, 0.09124726943311193, 0.10970458748840517, 0.17410299560475737, 0.15012971425969757, 0.1935633449184318, 0.14920021978116807, 0.166315007053556, 0.1835419189545416, 0.18488536138207684, 0.21889185112330223, 0.1642962887642845, 0.12501857018158322, 0.16668171802115056, 0.09406744592612791, 0.18130192382922097, 0.13796953935055964, 0.23927371227933517, 0.30708419940164017, 0.11143269032360086, 0.18172667361795905, 0.16256692188401378, 0.16368885764912253, 0.14961645067218812, 0.13688339521327328, 0.14637903971297128, 0.1985339378757823, 0.22976073887078996, 0.09306898821265468, 0.17321545210096145, 0.14018797676169104, 0.15291652762361113, 0.17362823559632226, 0.1354908312280332, 0.14039788485294388, 0.18075220977827428, 0.16017648241212293, 0.1342350905460696, 0.13736072927713394, 0.2024432385881101, 0.17819681625452735, 0.13373059100441395, 0.21129875534003784, 0.09050031072430073, 0.13150839976245357, 0.13802106642434675, 0.07170981336985865, 0.20980506774879273, 0.09484098022503239, 0.28560202148172165, 0.23983874808876748, 0.12408200471151261, 0.21659545660499605, 0.12649515869035838, 0.1262118287324425, 0.18593625015308782, 0.11250132935181742, 0.14312708840495156, 0.1369139314779351, 0.1262221249541448, 0.15076409634803573, 0.14069373268754254, 0.2513948473478517, 0.11719467508937083, 0.38280800705955875, 0.16332564004246267, 0.0862920671821602, 0.08012603998424546, 0.21636037486455134, 0.15644929612115507, 0.08548946750740852, 0.144585827065091, 0.21169312208169894, 0.11923706549550257, 0.2993368441539426, 0.09590031128496894, 0.09715216790115642, 0.16049397989146172, 0.18830517787606488, 0.17794233716783986, 0.0923380867067364, 0.13034682660814256, 0.12233435897336853, 0.09931749243649746, 0.16511758098438864, 0.1402241207899586, 0.15559979654367895, 0.1628299964772117, 0.22777418095257976, 0.15066666528582573, 0.1257276764860557, 0.2046352612876123, 0.12024259420051692, 0.14382245109206246, 0.12695799070981242, 0.09205225930218736, 0.29252273721560357, 0.18292788416147235, 0.13380649499595165, 0.1310699216781124, 0.13340947759007254, 0.16953816877738123, 0.1184869964697188, 0.09891702763495908, 0.18200540704832924, 0.12247299024414633, 0.07465830959019161, 0.12344497195895641, 0.10859972016224939, 0.1483890705651814, 0.18959018311673598, 0.13157028434497695, 0.19476035730012003, 0.21989102895942428, 0.09041011153209595, 0.205690715942652, 0.11054743742269856, 0.19171109753510646, 0.1499278194481327, 0.11484077801146816, 0.13160181652394035, 0.18001045280646893, 0.13723421751731826, 0.07984929072159914, 0.12735889218146765, 0.13419350729353968, 0.2001507051529423, 0.0989433580769166, 0.19867517384550265, 0.235901944819958, 0.11150817296678021, 0.16471783630549908, 0.29661000015274175, 0.10608149722458855, 0.11626924853771926, 0.09581951199159508, 0.16462909268035045, 0.10869052456391436, 0.08474937294639888, 0.14688648103225618, 0.19187007610115314, 0.172102770677978, 0.1584168703806016, 0.09324557147920133, 0.21086017000338725, 0.13452165339502598, 0.17075785736162818, 0.25715791229759494, 0.26448578844147347, 0.13036141292222087, 0.08285342024699335, 0.15271302402740525, 0.13778992237583285, 0.09125932765704009, 0.18989798192295337, 0.07670754116148719, 0.08123086900600503, 0.15441426015909643, 0.1252838051427276, 0.24669551080273044, 0.204754326672804, 0.1615893783708734, 0.1892651932974977, 0.15602610915178255, 0.14693367204839183, 0.07326909340918064, 0.16034583380866438, 0.086904225059815, 0.17130930277128376, 0.1532109352129121, 0.1237661160168148, 0.16405774430642206, 0.1256169844418764, 0.17026365404167484], [0.032824580782964345, 0.0670342485330278, 0.026769297340163783, 0.020803458492962584, 0.14795108277711178, 0.0064492599584252365, 0.07094509674296265, 0.029598892884208795, 0.023480432085512627, 0.02353014736135881, 0.05231527483931953, 0.039133808966125214, 0.06955463949951433, 0.03307666967532808, 0.01439262981406383, 0.08658809121698142, 0.038697000953458974, 0.02583474476611422, 0.08566457222426131, 0.03939723979020792, 0.11611643697946303, 0.06718644722094459, 0.05790628410214859, 0.02596568451413224, 0.044764287078813206, 0.061699507172189416, 0.023662609709126335, 0.0844139107052357, 0.023572333908129125, 0.04295786707511833, 0.06587289754421481, 0.032591835610688694, 0.019810891995627074, 0.035513798375764204, 0.020205747118339907, 0.05823546442233267, 0.03582330938849238, 0.05288185431591926, 0.12114868469295964, 0.026383983842547865, 0.036562132243547714, 0.007519791702619724, 0.0443734634938019, 0.03268849292409516, 0.029895617889480728, 0.052521237577762336, 0.030414054485698862, 0.06562254767143919, 0.03852492994478634, 0.0493336912815369, 0.022493710839039376, 0.05248073833964525, 0.058923648865593065, 0.010735609516080831, 0.020057618272520845, 0.0591339131877307, 0.025322366010157332, 0.06726812751543138, 0.04237309684075656, 0.07573352165279851, 0.0861814440858941, 0.02966394524029907, 0.030238953599285696, 0.036840176194786065, 0.018211200818299286, 0.040504481988928975, 0.04124156965483581, 0.0412785602102597, 0.05053160764697579, 0.029242646677659887, 0.07336094735130187, 0.03450316369473454, 0.026632542984800476, 0.046916886893731934, 0.02548673591997114, 0.04399304338280232, 0.026959405889013605, 0.025384585756147583, 0.019813464135832844, 0.0995149439381015, 0.033666174333061905, 0.0211177192508213, 0.04913479187375596, 0.005135971709199611, 0.03140608280626757, 0.044694144068466085, 0.01624571606366625, 0.02807066238845789, 0.03691314223913416, 0.024180559839512554, 0.026216093758721987, 0.08836828037014893, 0.07478857518083627, 0.1258044921222233, 0.08573822391730163, 0.03152985771697375, 0.016281971174682823, 0.046602748709941105, 0.026112051357725458, 0.06974188670996698, 0.034369692026126775, 0.01976291956980863, 0.08101579748214253, 0.025493793504973574, 0.037878742441534996, 0.058885539821799726, 0.02036999828452545, 0.01479943782361525, 0.0888448636678438, 0.061703896855995546, 0.018824473353883913, 0.023604708783809217, 0.06323754359337111, 0.039795846828529914, 0.04826601369366531, 0.02236637170426548, 0.03398949408062524, 0.06977505831708831, 0.061283268620290106, 0.019406508654356003, 0.032127852544128414, 0.08201354273384617, 0.08982336479088954, 0.051071316589631384, 0.05985338849225833, 0.05076648254368094, 0.0375387296381016, 0.030437004564690496, 0.012107733317891197, 0.05541229252553275, 0.02575626480393112, 0.03206024528481066, 0.028450915875333934, 0.030855319214864608, 0.003800186809272536, 0.028619851669176456, 0.021094782578368342, 0.018679776581965627, 0.05472982309818749, 0.02031266809471192, 0.05703990760770056, 0.04843267612159253, 0.03510209123393701, 0.05482628122873364, 0.009554711793879829, 0.04644927065519076, 0.004043698868518996, 0.06546017533588795, 0.022077052854001526, 0.06605678928955909, 0.03943889199065105, 0.01034367701879913, 0.04082368784433892, 0.01698831190174866, 0.009911057591858891, 0.03364996774302375, 0.010926712064012405, 0.030951248744743007, 0.005453324589442703, 0.02433954032077905, 0.009438131406392542, 0.044106297991088325, 0.030577240789669658, 0.035866754234678326, 0.043202249122963804, 0.014786295585274218, 0.093716248239, 0.02748740517774657, 0.06271696003574519, 0.022199125134295995, 0.02502616385989372, 0.08109753906366327, 0.09644524494726812, 0.05814155353413475, 0.021852183065587477, 0.04754421714272711, 0.03737785883488194, 0.08002670902398326, 0.018478929395637205, 0.03209216433817581, 0.06349240572402073, 0.07140549260281748, 0.01691788735408937, 0.03934203166394465, 0.012052663087454295, 0.048010193953110326, 0.02995035678689038, 0.043047667901602485, 0.04069422664601476, 0.035889537689546426, 0.034071450166764765, 0.08134437259286642, 0.029411695469471238, 0.03590678998960122, 0.026292836616536783, 0.05534851953627602, 0.01098119911001695, 0.05220983815830081, 0.04690095992578615, 0.06978595974825083, 0.028531701762169123, 0.0756628270591459, 0.014433202788143631, 0.05510596843856958, 0.06351945628862708, 0.013667762208159172, 0.05045029890513228, 0.019861898129625667, 0.01180360024239147, 0.017994306005177, 0.00860115640886849, 0.0358131472321768, 0.04717392854452614, 0.02893570397469786, 0.0408413308492351, 0.07485448172496212, 0.04008305702178229, 0.03759012647694157, 0.050487205190884496, 0.029913412196741953, 0.02275655752107982, 0.04178124029309519, 0.06510544598342911, 0.015353174793774323, 0.028516140601207173, 0.02191662255133833, 0.030849686553401333, 0.04425722497305082, 0.03558630093691811, 0.052698713336740775, 0.04431594561244692, 0.07231098554667927, 0.02131481452154056, 0.13900461606681347, 0.05858895654279379, 0.03263753658581165, 0.09589733886382273, 0.03845663320633673, 0.07473271204939774, 0.025781727651314392, 0.03000345242570245, 0.014144633746435566, 0.03483806669171299, 0.0734164887258122, 0.011381618903889772, 0.04026743523295849, 0.046288514765159744, 0.04527937395558242, 0.06496286935984127, 0.04622050530968174, 0.0466406547404345, 0.010341924592672337, 0.030986643922064575, 0.03404778954122336, 0.04847070472615381, 0.030346858998640414, 0.045458420194805636, 0.10494781733160058, 0.008078822340335577, 0.08006057011023646, 0.029661566537294178, 0.04785130348717494, 0.03153389116989509, 0.028840530956644687, 0.04788677718850875, 0.07954875442890391, 0.05327103464233299, 0.04169546142821351, 0.08215801159460699, 0.089543643107097, 0.05491943752032615, 0.07735999526395913, 0.011158530269899677, 0.04053987908147035, 0.03084760279424729, 0.03207788254404741, 0.04570337680859431, 0.02425438581755565, 0.08110204366065803, 0.019660384446803122, 0.0866751034834212, 0.04653031892714001, 0.05371784010241109, 0.04465503144949194, 0.04344586508288499, 0.0601218410226847, 0.03214488459390498, 0.0369535074118645, 0.06098517231763371, 0.0662418837929445, 0.03906381534292333, 0.022973375725409678, 0.014418156821310762, 0.02177213453837941, 0.07168158302984892, 0.018443986210190964, 0.05911835777242819, 0.028398143908669873, 0.10732871900883414, 0.04653365524005025, 0.040231092021830624, 0.014158847550260685, 0.03651591798951549, 0.03516986320215849, 0.03581753308554331, 0.05015476133614298, 0.02988379906802889, 0.0770249696929128, 0.097470699599193, 0.026797211668904752, 0.03185434000296218, 0.034823637425659165, 0.016473767032185872, 0.004919398174200568, 0.027798092135438518, 0.021867658041657943, 0.03111893390004914, 0.019587975731419942, 0.050200469972145174, 0.03219398699941174, 0.0369530247764722, 0.04122726296284988, 0.02940716405939912, 0.017702495453939322, 0.010899144390057172, 0.03968490197533562, 0.08440664053083428, 0.08290587428716883, 0.016639471850207737, 0.023633101917502862, 0.03838861608997949, 0.034204247677999164, 0.0399631297876758, 0.05922970482178273, 0.06221236090265936, 0.019592329026049665, 0.014958917219642431, 0.04111286688355669, 0.049825117532764716, 0.034851377469397364, 0.025956866842123772, 0.026315267670959718, 0.05114611741455813, 0.015765557050584786, 0.067796352800102, 0.056605842189803246, 0.07464906290894555, 0.01827020682544718, 0.06951358484765215, 0.04829753055087021, 0.04859468839581936, 0.06698588540236797, 0.13862155678291477, 0.15036409119925193, 0.12303596527706231, 0.11932134282805267, 0.303714515701417, 0.17876272540419333, 0.12171061018541937, 0.2224872243260184, 0.1461453062872733, 0.14251199641054677, 0.1855433849437583, 0.13045242416762537, 0.13758105616415703, 0.10172121587299532, 0.12126093955650447, 0.17738958940871302, 0.08446959763645165, 0.09965678511728203, 0.22131307200799066, 0.13431425807216477, 0.18307750113308432, 0.14417806910651346, 0.15604552181978382, 0.1257798470736992, 0.13799114303002435, 0.15382037347843572, 0.1838693296116206, 0.14692559748166992, 0.11877720589719473, 0.1448830691797118, 0.1796829042535636, 0.09399974673625924, 0.1360109589633442, 0.11910029581838077, 0.10375611393922761, 0.1749586698509032, 0.22136620786641875, 0.1664936740792567, 0.15003951506749277, 0.1671059775136171, 0.12096724442897305, 0.14090157234139983, 0.19346242049528709, 0.14661738498797341, 0.07619279136340465, 0.18635891618267184, 0.11044485058875815, 0.2007925336159045, 0.14257242542601403, 0.10367867011096209, 0.06517897510240156, 0.13546617851862985, 0.1837556421636574, 0.11488609211218935, 0.1054412315809919, 0.2047285554750312, 0.1699015855669014, 0.27780768972250725, 0.16605145748584502, 0.12180878435291591, 0.15798058330772385, 0.13119298604226884, 0.08707639565991779, 0.24015762452637, 0.08695333895664062, 0.12288135341218404, 0.10796238097452349, 0.2494228297784444, 0.10521746495918882, 0.12317580696676048, 0.13495158193813217, 0.16032075209002342, 0.11494699610216964, 0.25416384150664656, 0.25187187497654273, 0.1739536697465566, 0.11062496552063573, 0.12530933885324386, 0.1522633457376111, 0.2196997980917654, 0.13894607162763997, 0.1335548657563425, 0.07669005137417587, 0.1973445557298199, 0.15634627261709783, 0.1800644773268892, 0.13939018811910384, 0.07643869792621943, 0.17672885389577958, 0.20748196740544614, 0.10633199265406978, 0.1653119374907786, 0.20479184965933525, 0.33327907444007937, 0.19871528620921797, 0.20448634911689068, 0.09704665461134526, 0.2418532682162139, 0.11644899574739319, 0.23213273094546413, 0.1347279455512762, 0.11345282587553225, 0.17889398690913955, 0.07655148905131125, 0.29006843665434473, 0.12033093945994494, 0.23033193402713348, 0.1292657846164319, 0.14435140416026115, 0.17469956359315306, 0.12623396101257495, 0.0940223080256293, 0.1998698419981426, 0.09388565326169615, 0.09865733148950724, 0.15726352501059734, 0.09533931275889759, 0.13377373707630943, 0.23585620937087845, 0.12230700197359248, 0.16581652896298518, 0.12664437729624972, 0.17985357332133478, 0.12473173920185336, 0.19304079634528007, 0.13948280814914935, 0.24707821768618402, 0.17379550323370965, 0.11652853865657123, 0.1783505088138965, 0.09420164920870336, 0.1689024536960548, 0.21969858767284503, 0.1008722525570662, 0.1943397137426561, 0.10195806727654512, 0.1173647466085611, 0.05827654971771183, 0.14287176662154738, 0.10337943616773813, 0.11236013934737253, 0.19767948937031532, 0.14118163876475828, 0.12684056475277872, 0.14937271213819905, 0.09428157516184354, 0.10055248745747151, 0.09524820958294215, 0.10606961520088297, 0.17496297526503765, 0.11376171252660214, 0.0876523482222711, 0.1406025222592777, 0.13073033022303737, 0.18336194957936966, 0.08977528511276169, 0.08173707692373185, 0.15629492940441256, 0.11882936116307975, 0.10997922234838048, 0.1294414638992279, 0.12309634066637486, 0.15084286550841025, 0.1088127538922333, 0.19379885566811408, 0.1192477371002878, 0.19791697662684227, 0.11206616076730913, 0.2332225982700625, 0.12796692850608982, 0.14928781427443027, 0.20085679307099313, 0.15260961747938587, 0.125369354181232, 0.0997450307852799, 0.12003721368889655], [0.019243536855004007, 0.04780687804844591, 0.03681799028849891, 0.029793145968728972, 0.023049589982556722, 0.05710891680791975, 0.05922376764036956, 0.022158635472277963, 0.04596858112622173, 0.01779447197012844, 0.036945268136238864, 0.06657984348074084, 0.05881248184690072, 0.01847735891539243, 0.018544044953981237, 0.05644422828129703, 0.09048099764772961, 0.02132229728534097, 0.08759663830841742, 0.04414060340833761, 0.0690315853083326, 0.05407939912871488, 0.01828757595391043, 0.05230090686029965, 0.014380137792848533, 0.03218103628305178, 0.04634874076732705, 0.09856850359468691, 0.01891549800582711, 0.04002233689290382, 0.044937618302121285, 0.05951485423851879, 0.020877633041011232, 0.03240338947263456, 0.02218219842160902, 0.013391879582477194, 0.08224359127662836, 0.05789277797204353, 0.04919760342266771, 0.05943071480179506, 0.05228633203754022, 0.017487151968863704, 0.05459502609747072, 0.009943894035513363, 0.06735895489973408, 0.05841693916027585, 0.01305280427914113, 0.04068849630834114, 0.029827166018226457, 0.030532229293678558, 0.03363124455415434, 0.020172008606154593, 0.0766656284911498, 0.046863421617496404, 0.0524998254202787, 0.03092257790417681, 0.004321220443553982, 0.027683004661793673, 0.004355513411874493, 0.036200511930209976, 0.010383207155692001, 0.058476828083756476, 0.05021279249640723, 0.06178798649700419, 0.04412548083271231, 0.05619772033946169, 0.011428637550242487, 0.0568657566703135, 0.0340047353998788, 0.06002998325012385, 0.03661465140119676, 0.043332572170202775, 0.02419871229287838, 0.01095879391106146, 0.029054968542749846, 0.07455206851685241, 0.03988403120949384, 0.014453433255004066, 0.022716868420942657, 0.015616755005002264, 0.02270253874631899, 0.05532540666360048, 0.03136781288401014, 0.03215905722050417, 0.02826352885383512, 0.05261273528899878, 0.019482389663255984, 0.0790840684766731, 0.007390172498661184, 0.03438235545951513, 0.00299834436455351, 0.07450693827723304, 0.03855471544328236, 0.04964249749337474, 0.10333782993257047, 0.048819274731701424, 0.033265422248551925, 0.026540637331744357, 0.0376221489521765, 0.06725056111932763, 0.03872774406186035, 0.02496631707124893, 0.06598371216246197, 0.013144777922500527, 0.0952139271483306, 0.03778325341221306, 0.08629678628377377, 0.036810317917937235, 0.03627250887333386, 0.03018482374177585, 0.027577633098248514, 0.005067635229938934, 0.027505710848697254, 0.03447821221104072, 0.055208057315359195, 0.046794435399914944, 0.02359154930848989, 0.024225104021869844, 0.039772167050790404, 0.021393214044491612, 0.034976054448634386, 0.11586470814842371, 0.062271510551293055, 0.00641327441459702, 0.043795078602289005, 0.03320493960692998, 0.0410322935861205, 0.010752090940161819, 0.06376222189095232, 0.03098277900848658, 0.010861904856057899, 0.04263999421269663, 0.08094665038609698, 0.025661595488688158, 0.021874110417200193, 0.031179636791949312, 0.027702210486055385, 0.017740872628506155, 0.02297944122655017, 0.054978100703127926, 0.060688604360386256, 0.06365884598644991, 0.0824310529916998, 0.013328079780143116, 0.0687331480965499, 0.05950918135743949, 0.040717914084633516, 0.03959572551050975, 0.01094341469598153, 0.009392718671851102, 0.06739102334024445, 0.02614391103927647, 0.040917571919459494, 0.018805221564346747, 0.06236135734305267, 0.03827128206349669, 0.042482639753049424, 0.037445404807165746, 0.01794044427844065, 0.15586716122925282, 0.025821935776020252, 0.037355711232990994, 0.0259441114781845, 0.04027774677641931, 0.017638950375840068, 0.0156895678317655, 0.09290273947220656, 0.0574678021873678, 0.026139145972387447, 0.04118280688060388, 0.04216807639046062, 0.08491726111500494, 0.030796202124967694, 0.00734920498930038, 0.054867987055331476, 0.030591852001605496, 0.049081816893791964, 0.035322900756352374, 0.013327546391425835, 0.015812084443056058, 0.04610765289755599, 0.021220809787571914, 0.02651906429579662, 0.06802270113820992, 0.06467816810454093, 0.07913226306798958, 0.04252739077914627, 0.0267672059201305, 0.07732565920319288, 0.015178317140277117, 0.02278791349982062, 0.10348534782326992, 0.04382779055665578, 0.07542333265225734, 0.10554497520769797, 0.03537019519435783, 0.016475446679959857, 0.06640006562754994, 0.02941994815163555, 0.018454786134703506, 0.014486350137890588, 0.02809779339229628, 0.02529588426583477, 0.028848864078041048, 0.01905870856717229, 0.0689544479152368, 0.02618610907736565, 0.05998404861818399, 0.028168509053366802, 0.01528567095632635, 0.08528526677119155, 0.04914082481615967, 0.011092096082715979, 0.053808483625611955, 0.03173919698794282, 0.03328673481460541, 0.026002018149161053, 0.029439954537778135, 0.02642128083314146, 0.03302079888301031, 0.02787531954386542, 0.08549095371798163, 0.017108802210479494, 0.009975375461151764, 0.05369952294014154, 0.030931598589485212, 0.011718891027774061, 0.021025171999128598, 0.03611683214624082, 0.028680788217893535, 0.05296687092331629, 0.0294153573697493, 0.05323994296392607, 0.03635928748295673, 0.03008540276618254, 0.07845713276295893, 0.018095134667331175, 0.02087344828572485, 0.031215665907028223, 0.06745021129327436, 0.0634453104688756, 0.09975970136902987, 0.07099107734017795, 0.026141160783628305, 0.017825416176609935, 0.0033376698434773476, 0.01924908524679561, 0.0478218014412109, 0.01762155251907966, 0.009593007571604705, 0.038093036386154355, 0.05957879576711886, 0.03205232776611323, 0.04630153825987251, 0.058001049178382086, 0.005609991006372918, 0.056866848345605604, 0.05542666433499225, 0.01557143132818202, 0.01328196990559058, 0.039165187927503745, 0.09145438130344115, 0.04143953443534913, 0.12874968650360263, 0.03134538374480701, 0.046636184617396326, 0.01045065449415556, 0.026399307516253284, 0.02010114355793884, 0.0047032014586992806, 0.008909592025672958, 0.04091600910009396, 0.033842477977516196, 0.15180942332071645, 0.06304277722994167, 0.04098994807610589, 0.06875690448308183, 0.028328359044427355, 0.024611070609441208, 0.017845593017315673, 0.09961448940298251, 0.05403524565119898, 0.029421170061874776, 0.00808260106902209, 0.031922834009052284, 0.0474279364871402, 0.023396503322968082, 0.00963033712093508, 0.03231109119951725, 0.018820001315625928, 0.01854866829460427, 0.03789685276006499, 0.04211399058300642, 0.009344096028906925, 0.077640958010189, 0.015186964357722432, 0.05201533992564486, 0.04875391977088106, 0.047163482935678576, 0.018882190418099205, 0.09156695026303492, 0.04747632260043775, 0.09612099057243717, 0.06091211051229508, 0.055578863022909056, 0.09380658532703116, 0.0297672177229317, 0.033148904105708484, 0.05138681840992743, 0.012839240033269651, 0.024271105686503074, 0.03756998602541224, 0.029230548234115687, 0.03138865239077038, 0.06193274647117623, 0.04682249720058134, 0.04722524494413407, 0.030347843421623114, 0.018013494592460415, 0.01604515711791934, 0.023958229632567496, 0.019844657320889737, 0.044261089886628815, 0.031198292948125355, 0.07728642017971124, 0.055987379408531615, 0.0634647652717127, 0.009298650735628702, 0.01631429816986765, 0.0069978354111944726, 0.03073919369208236, 0.02944963980436085, 0.03575015948304246, 0.022241020567655083, 0.04778359280598741, 0.013130809266811178, 0.07370488252490759, 0.05767482595758573, 0.049627957144571896, 0.04149743919110587, 0.013732768598973993, 0.02613038767219311, 0.06925431005055867, 0.021263729863529725, 0.04887244889452573, 0.026794978522605477, 0.02387307321412429, 0.01372781584054352, 0.04841622821385822, 0.03842756400004991, 0.003338380629429594, 0.03886290878478078, 0.18152416593605475, 0.14712324816613429, 0.09007199096583551, 0.20289697714390295, 0.10959502925435383, 0.10723223023477102, 0.14530527555654127, 0.15706326962719042, 0.16100846921965, 0.1360415871585569, 0.1274479958679407, 0.09323873797491675, 0.20676017468494756, 0.10587195685553936, 0.08428441120251533, 0.13788925333609506, 0.23496149528411128, 0.21419697320990025, 0.14787781412803358, 0.18719551483950309, 0.08147172704939881, 0.12021306917191514, 0.09611689200204226, 0.08931413848674105, 0.14030980006341012, 0.10478968912314986, 0.09205382978243214, 0.22960677051976805, 0.08692105601151144, 0.22831655588121186, 0.2030854807385514, 0.2463409040243395, 0.0644607829951471, 0.14617444827191292, 0.14556197629820916, 0.0978718692016217, 0.16832850062318389, 0.12310767110677497, 0.14611087829595612, 0.11500146495358599, 0.13374197507096877, 0.09437455525321346, 0.1708997674887219, 0.15327784533221878, 0.16334948069866628, 0.18670183245933827, 0.13085141808034914, 0.10524325913959935, 0.1432105307016642, 0.1128093196800159, 0.12887725546475381, 0.07707849625618228, 0.21140550203140707, 0.24377331438083805, 0.15555426027745972, 0.11215003207325937, 0.1045101972657346, 0.07640463765710592, 0.1634494551727849, 0.16426566056907177, 0.1080695873186473, 0.1505101994881707, 0.11547010391950609, 0.1105482494758983, 0.11459982803752346, 0.13221706173592998, 0.2770500594089108, 0.17563992119844885, 0.1429139014573828, 0.23451606112141765, 0.14203247133522265, 0.10614078476904862, 0.12950472744001498, 0.13076163257562345, 0.23735728204971362, 0.1435974357469428, 0.14136864082707515, 0.0862941969065897, 0.12660403510615711, 0.09274176141667752, 0.16194996063507375, 0.1224166981034702, 0.19560038803085206, 0.10242444628308858, 0.1856582828106419, 0.12974535565703146, 0.0632491919602598, 0.21410156461981036, 0.16845576314916536, 0.16038701869547367, 0.07109482096688402, 0.1185044096482377, 0.16412399559011384, 0.1670659264369357, 0.3199238023690639, 0.14915296747799844, 0.11071335674533922, 0.24761254869161115, 0.10621968416437026, 0.1858619702679496, 0.22212241325647603, 0.1224279366133194, 0.14374847764209395, 0.07950219926574538, 0.21457275465851833, 0.12001399356391161, 0.12918284793774928, 0.18304527947498908, 0.16849250472601385, 0.18457710292310486, 0.12384809508559205, 0.10650434711527441, 0.16432861767468915, 0.13500566774558637, 0.07926412212151675, 0.14005138328479183, 0.10555311872233307, 0.14300428451068942, 0.13398177591302704, 0.10767060872768203, 0.11203546362418322, 0.21980268369999625, 0.2250450540093645, 0.10415841735178426, 0.14833405013045958, 0.1272824825718999, 0.16150779000693755, 0.1290560450645224, 0.14044714430647512, 0.16465720810717152, 0.1450708986169869, 0.26738573767004475, 0.12691207139963104, 0.11433506805089214, 0.12811313638643873, 0.15549576180356164, 0.08516741180492025, 0.1205027270160856, 0.13954118404897953, 0.14381777795572437, 0.17572976799020845, 0.2260228886359161, 0.1375099785265423, 0.13803372219685586, 0.11184433234795449, 0.14669062299353464, 0.0864266535086978, 0.12945994193996155, 0.17371855736259492, 0.1407690391304993, 0.15708177831144104, 0.09521321468656102, 0.11308815270181626, 0.04908979186908372, 0.13625515715008782, 0.15515646146189782, 0.1485480338094696, 0.1323902742156098, 0.1085811272083271, 0.24725055682563016, 0.13348676053987396, 0.21673592648679213, 0.17840698481567446, 0.24107999438720368, 0.10612893338886001, 0.20726127279621942, 0.2519706543534994, 0.12082460651835128, 0.11816782125782584, 0.07925240097627526, 0.10849220738295587, 0.15099743140801308, 0.10423946945417313, 0.14346876361918065, 0.14194441718920586, 0.13665418170632856], [0.04753970105441348, 0.06806164138740109, 0.0298484000602677, 0.02530435911349712, 0.01766150974999032, 0.09112780568219962, 0.017204829416568243, 0.08267188805245584, 0.01622544920762941, 0.021060978948709466, 0.047356115744238904, 0.0544407666330376, 0.061166467024914684, 0.07031461404215905, 0.041342666447763486, 0.01441774313383165, 0.027412251952374657, 0.0645957293830091, 0.063994400158164, 0.06083249099432461, 0.02692923543133563, 0.03639483396264334, 0.04696560242483693, 0.03203128716127286, 0.06549675603427234, 0.004339875163315165, 0.01092610589694232, 0.04482054474553274, 0.04740862724100871, 0.0321211550204504, 0.009254660051796705, 0.02431444136515981, 0.017012234912404132, 0.046070256315532236, 0.08517589239824204, 0.03550754326786246, 0.030806264689853115, 0.02267953887161228, 0.1402189113920735, 0.0356038022155483, 0.03322387346997857, 0.030579278583548246, 0.09016016002504096, 0.016323106265777064, 0.05225945001227721, 0.06790782625396406, 0.09736815873052805, 0.04492137723812654, 0.03807644675215406, 0.06722393956395888, 0.026053158348546396, 0.05797113727537855, 0.032704527144350355, 0.05556487425741169, 0.016899901524847074, 0.04046774041208048, 0.009182954222084054, 0.004536427948023043, 0.055803740472202344, 0.02325551058616369, 0.004205317565074732, 0.0933847007071299, 0.029210101347416643, 0.012855714754081302, 0.12563669588416815, 0.017168783064511035, 0.024342474437529044, 0.02117770010485284, 0.06397790245471463, 0.04952763410044774, 0.07696108562090705, 0.00828905314612653, 0.0649623714026905, 0.011262082374624668, 0.03032740419580331, 0.03138498091439326, 0.05875287637595208, 0.06113950072998001, 0.034530413442201195, 0.022759560585742997, 0.06583274687610327, 0.031157659644621517, 0.03306061630287478, 0.04172869049192917, 0.040236833850823106, 0.03859371314906786, 0.043639202692335656, 0.025109462515120546, 0.02576713942201628, 0.05813544015249899, 0.04384380179427324, 0.1335369852641898, 0.057470395394991484, 0.04483120102855948, 0.02131504051747822, 0.0731757149520901, 0.02661212482639859, 0.03686082226434543, 0.08237337423188072, 0.010116025373610038, 0.014634868730941128, 0.008896729409424289, 0.015878617264060004, 0.06385181204325731, 0.021854860542882836, 0.05226791911428014, 0.07893246733733723, 0.048195062460558075, 0.02863573841750622, 0.020086823459414226, 0.029448479181155566, 0.03306141686475566, 0.027572837387842518, 0.012935020176002817, 0.021488109355672233, 0.10047142003332415, 0.011223284809309389, 0.018086479789006616, 0.13151043755633215, 0.04181516649682195, 0.07208851361346823, 0.0856582366771275, 0.006914574581558907, 0.0655059107849675, 0.039955966865583774, 0.024895595664518978, 0.016918718559487213, 0.024904518673617034, 0.07522137655365853, 0.06989853636872384, 0.01812068561482574, 0.014998771986293217, 0.021703579245255362, 0.05149848721621018, 0.02606609374314787, 0.04759799268457198, 0.023312658830095204, 0.03825531296071507, 0.07025731066542287, 0.028237054770391797, 0.030546045689392957, 0.03490360551363519, 0.06182544436606188, 0.03798780654887519, 0.018837644320522106, 0.06095678876003912, 0.01590928472127886, 0.041556914427107385, 0.031957645044331594, 0.04531200547071715, 0.0377680312451576, 0.01251123661565925, 0.03214452070214095, 0.04234575516273899, 0.04240017038800063, 0.06944387850742187, 0.06381319355099432, 0.014574464613331423, 0.022057167126707012, 0.07355730334717421, 0.07090312278559131, 0.0703471574571825, 0.04040671767847192, 0.0308454749850376, 0.02407115865348568, 0.029041058301264723, 0.022715763339111884, 0.095374537481656, 0.02185123694700099, 0.029342701591010538, 0.06669038230733526, 0.05514838289649737, 0.022761931627868645, 0.05268344137397024, 0.0608415806275462, 0.010670441289192006, 0.06643398033995783, 0.0416657142341137, 0.07054126881543668, 0.01830792899483875, 0.03694670455109689, 0.02308643498127499, 0.043587415148654295, 0.04805356219050385, 0.01705558016715992, 0.025181995719791423, 0.008953168064415937, 0.04007238541699706, 0.05137612382250448, 0.05729923220050912, 0.018639646981272007, 0.027026406023651365, 0.03607807575815147, 0.03299004045285044, 0.03226509528054345, 0.01029359689357901, 0.049018005600139025, 0.050667339274960185, 0.031552537749972076, 0.028880220056781848, 0.032149745421784545, 0.051700991067674854, 0.037381643309227885, 0.10268000555374932, 0.037133063099557356, 0.025497840364433588, 0.05061312323255886, 0.045352271052017334, 0.02214833542013601, 0.07725474244404225, 0.03714548521524957, 0.031871781909778234, 0.040034326168918805, 0.017804856291942058, 0.08360289938507542, 0.04257418726000094, 0.12772217107516143, 0.01064235554827798, 0.056447633542120464, 0.04034227053184183, 0.02098226724492927, 0.04055744930801373, 0.03403753162391725, 0.00842092177575274, 0.006314764604828651, 0.012046450114388381, 0.05220339152841799, 0.02678928648932807, 0.053369304570820064, 0.033060424780893716, 0.019110486534754598, 0.015037724684413164, 0.044065837057367455, 0.008976934027046928, 0.015064054168760778, 0.014693241757941584, 0.026667851977230563, 0.023139417622118227, 0.038404056592093366, 0.04886489909803195, 0.011350866219389343, 0.08095755947813874, 0.012859497313207437, 0.05646940959136813, 0.04639581687027409, 0.0887074811203826, 0.11371604602543578, 0.03200946131631011, 0.054031721646747286, 0.09685289565353625, 0.07053592918260444, 0.04911786516106898, 0.047419873411737146, 0.06788241511751568, 0.02102769051317967, 0.037441762059085795, 0.05431679445469091, 0.0635415464339237, 0.03500819183705795, 0.06311440262042227, 0.06669590580126931, 0.07546422642565544, 0.0531106234918679, 0.018093633134999586, 0.06252054658327853, 0.03541135709852942, 0.029487342821554314, 0.026881699675634026, 0.05948873064030082, 0.018728729600327152, 0.047026774545590726, 0.015758711097371435, 0.012726331122159477, 0.007423835359663973, 0.006004018275322574, 0.009084512881423918, 0.05263034381993836, 0.014998347765105146, 0.030799810399091056, 0.04650341008879966, 0.06183361086333471, 0.028051523596889553, 0.04761114258379225, 0.040365103782425006, 0.03500825695453152, 0.024279413910041896, 0.04506403813138605, 0.05689413256702885, 0.033423439374253634, 0.03531458870237393, 0.14667847283905552, 0.032346610866126516, 0.04173402629432179, 0.0754776789296058, 0.036087877853142644, 0.026590578603528203, 0.01251645558964341, 0.037130960188205206, 0.02485482254996896, 0.03296465229903979, 0.06503786936762833, 0.02766499584991365, 0.05665818131679008, 0.027088466806397326, 0.01738277248918049, 0.09499794397983821, 0.01963331664521848, 0.053156152097207886, 0.018829993017378355, 0.04423054979152737, 0.04396180997812941, 0.06593868151427278, 0.05402931996110467, 0.090231184036501, 0.08074096343930691, 0.07922788616269827, 0.08985822179144429, 0.04376543099961935, 0.07421278349694706, 0.013955599635899549, 0.05811151139618409, 0.07336044173327184, 0.06267928766206869, 0.02048460503799781, 0.04715537006456045, 0.03693070480479829, 0.007171460141938541, 0.04744742193349427, 0.06614246856301062, 0.026319402630531022, 0.02931972661416137, 0.05527986656694163, 0.010853250935343246, 0.06449299699236309, 0.034435694331243154, 0.01764892101017458, 0.0659786866256787, 0.017485223342514327, 0.04011864563630473, 0.058983668024020816, 0.05463290148444715, 0.03378432424318406, 0.06390980106868571, 0.0462953252868066, 0.05660448621417727, 0.03808483541492493, 0.0022554337122147124, 0.024046528926720063, 0.015423202890932802, 0.031499543617809975, 0.018329086428087567, 0.02383136738752646, 0.14963241594453014, 0.11402832644601023, 0.18711740451474346, 0.20302658389893272, 0.12013096752907, 0.093358515821878, 0.14096584711824695, 0.2148155432434813, 0.06650911058269202, 0.08362301685396703, 0.11863349546347896, 0.07878532482972068, 0.14410826317485304, 0.15940642615239467, 0.12194865668613104, 0.13167816484647413, 0.14993773262587287, 0.10551058552077702, 0.10305849895361932, 0.1286615557487934, 0.11418094648228538, 0.16535172809756574, 0.13289455925264668, 0.11503056097295015, 0.14192523434758186, 0.14635008158943347, 0.12033196601776347, 0.16542602330446243, 0.11466597206890584, 0.16922468559876566, 0.15011914224634249, 0.16443931737974768, 0.0825752000955324, 0.15775359145575957, 0.20559610408400336, 0.11989968558472973, 0.16188390853424228, 0.197770316754618, 0.3719452480154653, 0.17284861855929898, 0.2388401065141924, 0.15080057745498998, 0.27747431890137736, 0.15801893366921335, 0.15454706916164968, 0.17951324642185243, 0.27783097879540536, 0.12142139667224501, 0.11688588036885185, 0.0465193102436681, 0.20707557308337382, 0.16147688602007207, 0.18281298629458875, 0.16593263724878912, 0.07469936424205381, 0.15296590965121024, 0.07318785744568995, 0.16545911830279136, 0.12478055432438852, 0.10870662007120349, 0.07754319753017157, 0.20287920390405964, 0.19508398348285308, 0.13379770030658092, 0.2539893879645294, 0.15141625167621722, 0.10067827909463838, 0.11517922033465679, 0.13669760356987679, 0.19951626177757018, 0.30096263594685063, 0.10754890800003084, 0.15843390817603759, 0.1867818580039086, 0.14649127159387837, 0.15443011817912902, 0.08379135701444843, 0.0970719661563635, 0.08065296291944482, 0.10753203874393817, 0.19083602594271784, 0.20379431125137115, 0.13220314957922505, 0.15059381032422667, 0.13117548859407827, 0.10897370130424539, 0.18976345688344973, 0.07369192031722877, 0.18637218482552037, 0.2649965239388328, 0.14822572529796632, 0.2752153094737761, 0.1670515546274762, 0.23818419735518195, 0.15901274888986544, 0.11329318847387068, 0.10376333814835358, 0.0787111981621673, 0.15776374978163551, 0.16160212607393343, 0.07792969654885032, 0.10283147645813805, 0.14423816104329404, 0.1336144673968515, 0.10414514870893571, 0.13263309344408974, 0.09680585785498542, 0.17392512531049792, 0.17660931353607487, 0.1353266585858599, 0.1445297034637582, 0.15795070587867693, 0.15458626221985589, 0.07785247488608284, 0.20335690569012396, 0.15073247223852143, 0.08792378849560216, 0.2616581579129542, 0.270143102614149, 0.11361934274675385, 0.17099784206478827, 0.15992345889249157, 0.095577635051262, 0.14873312065197578, 0.17872186227431222, 0.09419970334537568, 0.13494742974158258, 0.15368305987888767, 0.13296317008714523, 0.12986898692625184, 0.12490111358103254, 0.08694386244901726, 0.11466822436740322, 0.1270985908265556, 0.13484069837197182, 0.17451204059104766, 0.25551984777613995, 0.1553553838523165, 0.1376118222551961, 0.18100203105038215, 0.14405266051330876, 0.18290476362791755, 0.18717669972008277, 0.08542276423184142, 0.18823973864557283, 0.15436651755965528, 0.13583817549290197, 0.15677808573649776, 0.2561067017696558, 0.1303203965747549, 0.06897631206459577, 0.11011636740858517, 0.19364902419188332, 0.14706821240965398, 0.11528445017193595, 0.18256699546210228, 0.19611536765531187, 0.11260222313144516, 0.09336352603690279, 0.10229980377780815, 0.22040459898210343, 0.1814638288511384, 0.13861826260484036, 0.20559002134588458, 0.1594369624170565, 0.12135597276351145, 0.17371438984428683, 0.20360295780964438, 0.37147937462695185, 0.118165775803068, 0.13805724109613127, 0.11930599042605008, 0.08044455636052356, 0.15314549598242008, 0.10008187964558603, 0.10427102461577424], [0.04270017424958848, 0.02892938757976217, 0.03391509545185874, 0.04454169640197389, 0.021615923464959188, 0.03466630211821006, 0.04940340911308604, 0.007185626544073345, 0.04679460776969791, 0.03856265977505715, 0.05945815990168241, 0.03451301175500116, 0.048063988647153305, 0.017971892187732364, 0.015880501840353733, 0.04701360932461197, 0.0478899909273511, 0.03561082341137432, 0.03939169331363613, 0.01444240733455386, 0.05718593162694766, 0.019921764070468567, 0.02221383593766199, 0.05250478200914879, 0.10629213309936947, 0.014533833225047397, 0.014412172717012227, 0.018985604626997825, 0.06092553237272848, 0.04844568812498643, 0.05571554076947993, 0.03470757510513067, 0.03593533059522029, 0.02772779782272635, 0.06190613640712635, 0.024513461431788824, 0.037682160449725007, 0.03262260553216742, 0.04485572733345532, 0.06284031551331282, 0.1130414289993144, 0.06132212459980961, 0.07613148134682449, 0.04319600550638091, 0.07798663986426208, 0.02860331374611105, 0.0638941384010738, 0.016971467543513547, 0.08791437327501275, 0.01926683358878138, 0.051346280867414135, 0.05465929704387823, 0.013746349422651676, 0.07857189273401614, 0.03883219631989637, 0.04996197914043742, 0.005102801059688172, 0.06792379152630607, 0.004892347609594224, 0.056989115978320765, 0.09585619994228887, 0.05271552513623911, 0.03322327209095801, 0.06573842613086586, 0.06028597919090141, 0.049760463542395064, 0.0635924989417676, 0.09746441001733465, 0.018786015740085035, 0.04263749676606348, 0.03665399767698781, 0.07557638935864934, 0.018281964359865076, 0.022923239101205143, 0.083653116448512, 0.057932970774990905, 0.033976271403052156, 0.055442219750294765, 0.09282955509280005, 0.01836271577274367, 0.12546412691834474, 0.054191018139282544, 0.05054387271464352, 0.04186696170138256, 0.030514821860819098, 0.09238173073578267, 0.014954768853532452, 0.01281405680797874, 0.08524631886112113, 0.03447396808394021, 0.0610061822789571, 0.04562916587136927, 0.050525846665785204, 0.04732507386154706, 0.048371469526882135, 0.07034803079741617, 0.05691683941310453, 0.07980861911369909, 0.05646134268552546, 0.036824908062455156, 0.05565526497159755, 0.05877793128151567, 0.03041530320901544, 0.05912808325862693, 0.0443039333537942, 0.03686968973206897, 0.02742316104441641, 0.049992434965867194, 0.016446628367468234, 0.0490201314941289, 0.05041212474386539, 0.024706057851172747, 0.02402792065103929, 0.011713929650854441, 0.058793157279010744, 0.04010352689111906, 0.043945258648525325, 0.006554024397290402, 0.026084859066853122, 0.03640214244144098, 0.0709778776452426, 0.042114021226523385, 0.02091338253399778, 0.05249863032311682, 0.016067642756106875, 0.05315312221946736, 0.02656877765642299, 0.0594457377859902, 0.034900460722706014, 0.023981936223384355, 0.010399086243142525, 0.016203755512833595, 0.0542552431204146, 0.06350555945368064, 0.0507917289712256, 0.015110216711858108, 0.04628019505030206, 0.036730261729849924, 0.06233460172229718, 0.012787649757228793, 0.008690683358919718, 0.017454673671313835, 0.0898012554933948, 0.033960095456530975, 0.0130718597586477, 0.033576591841636166, 0.07329302599593517, 0.07742592479072272, 0.027271218995954243, 0.10598978883917294, 0.031114687857728814, 0.035135802933044975, 0.03873577266330681, 0.049377143788602085, 0.01768831133602127, 0.02692025688086306, 0.06945523959133895, 0.02768423040247252, 0.07863526352711263, 0.02106893285658331, 0.006477280103060748, 0.027804125077842225, 0.027739798590060205, 0.01743770290857121, 0.03412236053977282, 0.0414510180933341, 0.04900732250403493, 0.027768013608311454, 0.04327834080604296, 0.040278133650821064, 0.03480632000813081, 0.06501268805755724, 0.035307881602596854, 0.012568506476048742, 0.05563176522452024, 0.09804412407139618, 0.027900841763062824, 0.02590383823600508, 0.033225401815387516, 0.018718600002748352, 0.007454208830641884, 0.0060818695666028134, 0.05018137140019287, 0.05319574735157433, 0.06521208542248895, 0.012844173639502018, 0.07606655539524171, 0.037688350440153194, 0.014048843069993442, 0.030157279050458344, 0.027282468997122302, 0.09925283461568818, 0.023572144301367864, 0.04543048096820713, 0.023352941648373683, 0.04691648852801131, 0.04852168021663543, 0.040342347140634255, 0.019676209908098947, 0.028816439406645876, 0.02948970811802053, 0.07161898598555597, 0.009781677790376688, 0.01615842417513411, 0.013764175331039775, 0.027031839502254323, 0.038806536204872594, 0.014894654891724068, 0.01845773940365161, 0.06464332642574465, 0.026206766638243874, 0.06240424677549351, 0.0600328024536852, 0.07760543451314011, 0.03247044131820721, 0.026521891160237215, 0.03527234278378948, 0.05576032626953337, 0.041575109015309045, 0.06307753080862664, 0.020967751793983965, 0.004048643008460321, 0.032141812581328616, 0.027748342385635744, 0.06406248622243443, 0.02600192813382995, 0.029336452228768222, 0.09792683601018884, 0.02536149969654939, 0.05497158895577154, 0.06021814976608562, 0.02716580912801287, 0.05770678714578671, 0.024950131548628695, 0.01985026508449547, 0.05348161306051959, 0.07819113171389026, 0.022578413350387447, 0.03105545393942345, 0.010356666039555304, 0.015904500502191724, 0.04995503455340382, 0.0582571255583917, 0.06795741512530273, 0.062480809602646105, 0.033739783891266396, 0.020973434251162316, 0.027847765276448864, 0.01184617079073383, 0.07149147831143872, 0.013560149837435495, 0.031021523905257066, 0.04877610950760784, 0.04783914950225623, 0.020788326341238235, 0.03696239403178615, 0.01509114399537324, 0.01900683675381926, 0.04208237413437136, 0.01914392435742963, 0.05137790497692843, 0.027326434783096758, 0.07145478269986569, 0.033934806894150474, 0.09510615389914283, 0.043153533591858806, 0.032960733759307095, 0.07729576645238746, 0.05391465575103799, 0.03186274398749154, 0.0895861303433776, 0.05822022693351873, 0.04371080893061815, 0.017724508990443522, 0.030188422439800158, 0.03801103816517899, 0.05277392401870701, 0.05539022153243423, 0.03926569483272972, 0.04463597884281509, 0.013822840429061364, 0.08625508811805518, 0.01929786781059398, 0.021500349525482427, 0.041112047169477715, 0.03163797762094727, 0.03667751274582359, 0.02307258028116438, 0.03228568006306887, 0.02882327482615027, 0.060403700091785965, 0.04558906116853318, 0.04119842741337996, 0.027834523446677674, 0.11520254005107189, 0.05286668194457889, 0.03829638676477536, 0.02533849982184268, 0.001081870084876315, 0.059249351146600904, 0.06315874761991924, 0.020639067515730858, 0.034958399952419346, 0.034950034272286205, 0.01923376157309019, 0.006434895809844978, 0.032294279400018916, 0.03671828011471418, 0.03552250879546327, 0.04352785564298111, 0.0167582135632514, 0.018736486240560492, 0.02613787618165295, 0.02482409093288645, 0.02257912198171741, 0.008868405223643828, 0.05251025570736778, 0.020815099198972026, 0.09458304608180639, 0.09131141397501193, 0.05630634394624541, 0.011671345695973405, 0.0366747931336924, 0.07987618040774139, 0.010876053542409454, 0.03703396579611205, 0.01882908328796827, 0.03430473160058741, 0.019206818260793245, 0.02103383836877202, 0.04539037243493142, 0.018431964375439192, 0.021688261317209374, 0.029898915897994757, 0.09854385088528357, 0.02442274704545496, 0.038750573482003906, 0.019758474344627994, 0.015427628963915332, 0.008234536414214922, 0.025527171955834475, 0.05776016432191095, 0.09964261249068285, 0.024834726148495273, 0.06381818844426064, 0.016371603461823637, 0.053156006540502274, 0.034661019941972154, 0.013748695566919784, 0.05262329581103498, 0.037216861627154776, 0.02782133524306119, 0.18843743529531265, 0.10693917096021677, 0.10706127005358858, 0.18834755786003607, 0.08755349989740119, 0.10964362987227018, 0.10438043729311998, 0.15229418843744263, 0.25854207995918493, 0.13679089775729564, 0.1349839108485368, 0.16684561487167113, 0.1352383899352243, 0.137751939736547, 0.12450781936246542, 0.2931401734390567, 0.16390287197164952, 0.15213389220016618, 0.15276136417542735, 0.07006707571206555, 0.16009118618263354, 0.18588990183366885, 0.11343152863123726, 0.17683909394808356, 0.13941271110407769, 0.17543180575293882, 0.11429670236764417, 0.07186684607257766, 0.18960316064617327, 0.16880074786322732, 0.15625490897124814, 0.13165737322020915, 0.12488062072905803, 0.14497622547130432, 0.14692760463203156, 0.11602530315999063, 0.1461878854541048, 0.16410514982717653, 0.19532030628573513, 0.2272991757960089, 0.16838333719680387, 0.16138256527483463, 0.15747381614581232, 0.20712163028938158, 0.1257349236778194, 0.08556000888347627, 0.16159221289619324, 0.1470175127108251, 0.21585104896897273, 0.2353763012515922, 0.14647254840500895, 0.2611259106666811, 0.11427420236530805, 0.17966315450687564, 0.16038853554956375, 0.09797997186861693, 0.21966771432949653, 0.10316975790286258, 0.16716401633476058, 0.20093311075000994, 0.16155364803008496, 0.17513439509897463, 0.19371124585309338, 0.10793145400502029, 0.15889625756009934, 0.15571282515602727, 0.16530896506963239, 0.18359096390345406, 0.17906635669210266, 0.1153185870498419, 0.11657779811010247, 0.11668601569028632, 0.03961190528747055, 0.14477339603247183, 0.09703952233277022, 0.16701603879130658, 0.17509412951767447, 0.11904375852956889, 0.15050405546301796, 0.12041268870234491, 0.22767538625386455, 0.10081627451243902, 0.12531243384845797, 0.10147213004529478, 0.15432917843422583, 0.17527478837197827, 0.2676153801862271, 0.08351912767055535, 0.15153887170937755, 0.1843090794019161, 0.21686343416090936, 0.21425182510527874, 0.13510809370106266, 0.12263102652204615, 0.1801161422965027, 0.21591726960914753, 0.1520986521556493, 0.1737774542022136, 0.1368438497546219, 0.16854292863318998, 0.12340444590776198, 0.17294407311466434, 0.15194358063801644, 0.14675057703448882, 0.07078486945359938, 0.18003194923362426, 0.13324709759364206, 0.16382054816330635, 0.08339144379621552, 0.11211401061905969, 0.16604583440048082, 0.12887935454566635, 0.14149090845979032, 0.2186963761285428, 0.22219120795207642, 0.19373088834747193, 0.14936385616179437, 0.09760094986807916, 0.2469327835546386, 0.11753921547243673, 0.25137224775408545, 0.12959757729643775, 0.13955065289572363, 0.14140746616307767, 0.0662250605021273, 0.1209055973337062, 0.11029262891820363, 0.10985733775962746, 0.07212950697829647, 0.1878638346228869, 0.15170263066407175, 0.11649346715139768, 0.13743199077585053, 0.11951248176516065, 0.072262292998212, 0.1278648626119379, 0.08235806779515359, 0.14356737445679404, 0.16012855595157993, 0.0604700509669079, 0.1272296837921585, 0.13970852829515934, 0.18456774132867015, 0.1571992502337502, 0.10117119538687891, 0.1718796399091521, 0.1848944471848588, 0.15048381542005848, 0.061601057213040135, 0.2039190456872025, 0.13391313443501152, 0.16302590048120869, 0.06602663606885942, 0.15212214041140773, 0.14776913689509516, 0.1548508230236269, 0.10558826683629906, 0.08094439042672034, 0.2140548026129123, 0.15640835638248152, 0.20917846911376525, 0.09194398043496955, 0.15444805995831568, 0.081916042723723, 0.1738431539025999, 0.12496488273984964, 0.12270205819438543, 0.10493994960861822, 0.1779282258282746, 0.1193658065711779, 0.17491759221640327, 0.0830514463145406, 0.13964146495826785, 0.10039023003510891, 0.18912096958487265, 0.15222245196421302], [0.04007447300659072, 0.020037977693362102, 0.006981160549912603, 0.06691724392435243, 0.01965130822012021, 0.04385115240790671, 0.0124122379460342, 0.03582150142099108, 0.05046708772199289, 0.06401278626834674, 0.05996810632847971, 0.0757711059263637, 0.01808454541699781, 0.04871592180983675, 0.02885317906827456, 0.03440926046741586, 0.026387534660076904, 0.03695058478643337, 0.06118710160315518, 0.01117698820082531, 0.059363421638526266, 0.06023892224015248, 0.02122055889377671, 0.03784431445021783, 0.015448633179579292, 0.06119865420905333, 0.0664964011840282, 0.07264027311917275, 0.014967268535626993, 0.02289238491005475, 0.021877090499225645, 0.022115531535218322, 0.026717519372581478, 0.007801294062031254, 0.02323654991003775, 0.048438770351030176, 0.055803667693849535, 0.013833542677363562, 0.07775990082131279, 0.03558188444003463, 0.01406626199417177, 0.014527090693703823, 0.06018873198979324, 0.03712432586678094, 0.01034198779492609, 0.03504022197317212, 0.050106298614052996, 0.07069800274386522, 0.04500882234424353, 0.03314790819140692, 0.013517723888188843, 0.04236824750419586, 0.024701968856876897, 0.02568588239110766, 0.079453629291346, 0.03535596511116432, 0.017883585232700554, 0.04145134368070191, 0.047056460452656594, 0.030324380063722213, 0.005034114574007089, 0.02894629705547085, 0.024111355286872676, 0.04262893190307002, 0.05403616112626849, 0.05145768920380262, 0.013662732840936272, 0.013315961226790905, 0.014362720783890016, 0.07175754064754133, 0.015617527796195881, 0.03287118191139833, 0.037344518688417254, 0.05619400481302893, 0.0011649739861886409, 0.032618135409129244, 0.010979492649165614, 0.02901485809425433, 0.009493188230290769, 0.012466706797450542, 0.04721289177635505, 0.031083439131297415, 0.013334254448812817, 0.0614153843132719, 0.1042420435095987, 0.05494811602177159, 0.04781654224761071, 0.06707629909919155, 0.047504729140670075, 0.03391385055898178, 0.0320184436972223, 0.01977345710920711, 0.056618172374944535, 0.026491218914968834, 0.05012469238511497, 0.021746035838018984, 0.10814654851152052, 0.02669094761292781, 0.018019891426628156, 0.03634173257817184, 0.01976764250186182, 0.03474095355599158, 0.03197192492324018, 0.01968780081839331, 0.05500529682443989, 0.12226325069223681, 0.06082021443533802, 0.0744160496058964, 0.012844666808603272, 0.059581580496723616, 0.0180328747017249, 0.04641913658668918, 0.020093702928974264, 0.04026165126913017, 0.00869327369371369, 0.028991593919213743, 0.03537020668567669, 0.03647534980348522, 0.008720014950320607, 0.048498314534944874, 0.03967136137127396, 0.049010233638147195, 0.051096781352234465, 0.004503323852400026, 0.05113374892502062, 0.054619678806874065, 0.041986735717904185, 0.05851188043673193, 0.03280347506065042, 0.04392767693066309, 0.0854497841529308, 0.0435554156560571, 0.025220491637986515, 0.04119264727999126, 0.021174731514146252, 0.031692494352858876, 0.053847492822716315, 0.05184926738541934, 0.04509192756226948, 0.06589170500275589, 0.025789160619399724, 0.02698242300069861, 0.011522476617697508, 0.026045669839086554, 0.0032072744966905207, 0.008040206720902315, 0.1033524392292865, 0.024446323401324695, 0.02540743815892887, 0.05210723217216231, 0.12404050572865433, 0.08091033015760683, 0.049252635348708405, 0.05570113831650346, 0.0165307390758948, 0.04077012680711285, 0.008286454192843408, 0.03510125619809955, 0.02982689788745296, 0.019221077072283915, 0.05681449772729989, 0.059230945884220065, 0.061761617750650456, 0.04010792806624405, 0.050780946283691356, 0.00850058630138876, 0.046321422071947206, 0.01503837011348937, 0.012727808714243434, 0.07258449425740589, 0.060614232544697104, 0.055988708571080244, 0.06644650587751981, 0.008071155715433341, 0.06032486198349826, 0.043137200597313144, 0.02594500780105591, 0.026766106583959153, 0.019587110052065506, 0.0688661792646012, 0.052785783059774875, 0.09149770357555921, 0.04279286322754718, 0.04309187117483347, 0.03542840638528428, 0.06108961308435087, 0.04795035482534478, 0.056643487750402385, 0.03712151049365921, 0.032109359181636286, 0.053565032374594486, 0.017725068234628247, 0.018095864366079052, 0.09285440698506371, 0.03976059529269415, 0.03723069334462766, 0.04433174617588521, 0.0751332304770908, 0.011741896648140205, 0.011911204952235905, 0.05275797789856311, 0.04082024044867966, 0.02891027560127118, 0.05501569263757237, 0.07301833750980516, 0.010827777554251013, 0.005696090670572895, 0.071050112075623, 0.0655593530785653, 0.063310865868604, 0.03009979372784015, 0.017282629475718545, 0.06854231559461163, 0.018414166237738346, 0.019452500742890184, 0.018249985934685797, 0.013005902461196869, 0.10189511783180699, 0.01794143253186297, 0.04663386337098576, 0.056451778077790817, 0.04154009113629018, 0.0811583434622134, 0.02634250784232732, 0.019561945978972702, 0.07110631994662747, 0.027298382558529417, 0.05817779715383246, 0.044904419881922585, 0.0639916230894385, 0.06095886868875354, 0.03581639544497575, 0.05710884402956694, 0.014464373948172697, 0.046746493617613474, 0.032119779892626314, 0.02477820801188148, 0.025978700347965764, 0.05099900938089817, 0.03042761998761806, 0.009782509953384439, 0.03913309650435563, 0.05256641378265716, 0.06385948058337935, 0.06683083686737284, 0.07918002865006847, 0.021206918698284897, 0.019686862360686064, 0.023009282266420704, 0.05376449485699977, 0.041205038752166495, 0.0075696223704595006, 0.03116078336813277, 0.02661323756910861, 0.023430726385765502, 0.030353401389513767, 0.0021166741217096005, 0.02946583681829995, 0.041275147288557024, 0.03866214395290421, 0.013758717912189184, 0.05679962796068961, 0.08623006002556893, 0.07568767129053032, 0.0449998323024521, 0.010507917651275714, 0.031521989993991396, 0.025540905997097015, 0.042191645085451104, 0.056617394795701395, 0.029067700924051386, 0.038796397031194745, 0.013387210276578704, 0.03090653602304238, 0.01621222653005633, 0.058326736137631445, 0.08306014907336043, 0.01685459891544475, 0.04600072617552454, 0.05513760786984236, 0.07597290880737767, 0.031071338772533402, 0.04262425876673191, 0.05114366210276081, 0.05588276244159188, 0.008887519117354626, 0.06379769942272576, 0.015479811042877696, 0.03890879362100556, 0.04758172097706026, 0.05162479596272592, 0.013943879448267964, 0.07542537810701518, 0.10548338173858582, 0.03251590863651326, 0.04831218198242207, 0.011216910957779375, 0.019307215998490012, 0.025406685477543264, 0.037238955602891026, 0.03648040598378547, 0.044563108559457526, 0.023823375175256404, 0.033360930430071975, 0.07196763259989601, 0.013862401209471208, 0.0033222535210135845, 0.06844135286707072, 0.020730827612081365, 0.0367477247040839, 0.010159039295338576, 0.016554922556444522, 0.09271577571428592, 0.07466829937672423, 0.0758404368835111, 0.07535053131681296, 0.006340761798539109, 0.06339005637733687, 0.06913260932290746, 0.016366478333610202, 0.038185273372237725, 0.03477074671536684, 0.010695797841875784, 0.06458154143465143, 0.018144980178124482, 0.03705355466433591, 0.10540885670531182, 0.07393165221137386, 0.03724137644073175, 0.0023768205832194298, 0.05832014012060339, 0.023932695922051227, 0.00880655415746714, 0.042437785305082805, 0.015851293780630635, 0.0217671032559367, 0.03068292261882415, 0.07160375615762127, 0.10123409120546234, 0.06449893417377627, 0.06169283454636894, 0.03635004463215028, 0.019109055865556, 0.003372595552542818, 0.053737072739750154, 0.029084794260861895, 0.03972252072285741, 0.01026415613464891, 0.029212681148501656, 0.025439784306311802, 0.03441948008032576, 0.031607131090676116, 0.1470907660381448, 0.1626618861431076, 0.0950193637982011, 0.2372112197260703, 0.25124673190857133, 0.15710287637287573, 0.11137229195165058, 0.1302264588734796, 0.1511621249899749, 0.23610767007114428, 0.2746502123773098, 0.20546876494922947, 0.11451244804888003, 0.09584717542654085, 0.13718183242505597, 0.18403912533915814, 0.05980233639298428, 0.11090504726575268, 0.21974277562431752, 0.12427155784661732, 0.16126215157489623, 0.2033333408255731, 0.13228156633915442, 0.20289420390561705, 0.1737778678896927, 0.16507969027565372, 0.2558058130765154, 0.16655074762961558, 0.16440403136995532, 0.11738374558908325, 0.12069306922175231, 0.0802733586920846, 0.23724999909679736, 0.11805660827385804, 0.18183769507994577, 0.11430791789485563, 0.1759920764954821, 0.12578451254915807, 0.178522985849169, 0.11828046682621203, 0.06417740324151612, 0.1895721494069984, 0.1059038567567064, 0.19491804883845393, 0.2628048689615342, 0.0853997279679583, 0.23303354309210855, 0.1545061753882516, 0.12451060026163056, 0.13272303216640027, 0.1328985735533699, 0.2550682236230181, 0.1284193340688944, 0.15260093004232453, 0.23989006065793578, 0.09454745363684432, 0.11511988682492126, 0.13637779250500665, 0.17010070714018038, 0.11666104888483403, 0.06864519354196326, 0.12489983421419898, 0.1561852102918971, 0.11303916903993777, 0.1899217000050891, 0.1100024731168824, 0.13302572882704197, 0.16369322435029093, 0.10169202026220099, 0.18730809912085536, 0.10839748061111859, 0.16859155989462332, 0.23114293002553526, 0.11751341363114697, 0.12878098885618872, 0.18206519254994008, 0.12173328638797808, 0.12357209658911153, 0.16416456760658374, 0.16484758095635524, 0.14737670069500325, 0.12096742829007488, 0.18243003426299942, 0.17982188792478654, 0.13729320628748787, 0.13647871692815136, 0.18413150022106786, 0.20348055228110284, 0.1365785381846851, 0.10146155037106046, 0.2669576477379568, 0.14147563266658014, 0.11628544363643854, 0.14300486673751187, 0.10369866500578581, 0.11650817603954386, 0.3077538215344952, 0.09352828090589854, 0.08235494981730178, 0.07215120258831209, 0.10968495265490587, 0.11837618185147164, 0.19367131735047988, 0.1743005390369123, 0.16302289741654552, 0.2083713648420188, 0.1724725613190282, 0.17957465602986275, 0.09128444768007725, 0.1400105354766692, 0.14500239503479775, 0.15496607329095566, 0.1322940076070447, 0.1819027053012002, 0.09696888136527232, 0.09514278822368193, 0.14317771149498804, 0.14071149060562735, 0.08459394902832086, 0.10122361878353743, 0.12269704797936064, 0.15430490876878464, 0.1170019886546558, 0.11707874300378947, 0.18750740455523615, 0.10257577163077171, 0.13246994735973497, 0.09535997415021544, 0.12968460488463604, 0.09467665436527423, 0.16962397062490064, 0.17711637181139764, 0.09799577626249484, 0.1382511073062497, 0.14082071942187127, 0.09789037788587232, 0.18946615348179496, 0.17173307196747872, 0.11418666149820052, 0.11399803532948417, 0.09228007086823065, 0.1357686300311358, 0.10466626469766903, 0.19497262494217968, 0.1000210062991227, 0.208131043060172, 0.2015510219479761, 0.10009492612293652, 0.11506314269236981, 0.1232749081006454, 0.24444612343945812, 0.12315067928284408, 0.16106480732560158, 0.1316784253163684, 0.10120828936417257, 0.13469164830542382, 0.10256488552136768, 0.17151542638819064, 0.08939424830098307, 0.10977957983531299, 0.14840983154792942, 0.14236772673264628, 0.2344359283245379, 0.1654214727421922, 0.15277605774181505, 0.22635944638281102, 0.10817372931107398, 0.11617720307361697, 0.14086463158169102, 0.13342374214722266, 0.12446901700910061, 0.1062994032737709, 0.1486922115568192, 0.09878583507792604, 0.1088490128336895, 0.2004191117180932], [0.029312847144601327, 0.03239074136100469, 0.04853637761346275, 0.02134060104107184, 0.03659919174688478, 0.019153908398302815, 0.0757632305425021, 0.034411187178545424, 0.004092196064565572, 0.02269745575294139, 0.0035487605829633054, 0.027787851455110698, 0.007834744812440007, 0.031922604182675, 0.09167956518790416, 0.05561450909402582, 0.031494131206624934, 0.025712002158886003, 0.055572738149954434, 0.022161318695232756, 0.05684127633069312, 0.04503693011018538, 0.023767693989699887, 0.04405303572815272, 0.024614043030587417, 0.028139520286312027, 0.1194434802258207, 0.05325223101423152, 0.006916603278143392, 0.028673665515417536, 0.023839351938917272, 0.006344419868377548, 0.10145335323027066, 0.019061451161941214, 0.019361556530179038, 0.07397927223674713, 0.018834330990249594, 0.03341480556334699, 0.04134522518143058, 0.06056634821898996, 0.038257879355261405, 0.03839266103421969, 0.03568247561493228, 0.039126623061395464, 0.013670861033812888, 0.06838401884681757, 0.024051064167231805, 0.061911560309630256, 0.06941865889295455, 0.047153431862112016, 0.010753715046561294, 0.03508430267233522, 0.07973574883034153, 0.03945062845765103, 0.004773842426197183, 0.0296530514700158, 0.03930736235493133, 0.08288185743074264, 0.03621758803004219, 0.022816634136101892, 0.0228368052311482, 0.04684798111538253, 0.08284628030753906, 0.05931996530102146, 0.04964745025180521, 0.023961226951571244, 0.035540354813659386, 0.06507119419233454, 0.03951757305091427, 0.061354246666474696, 0.05167554545726988, 0.07149678730075398, 0.05423769587650896, 0.015502649081510403, 0.045351953125528754, 0.03153834214073516, 0.08028139495441029, 0.0693849663460447, 0.04710107358292707, 0.0699993612004384, 0.011302386260321064, 0.03291166199731731, 0.06770473634523731, 0.03697398494208052, 0.030645104688442046, 0.06974210121458577, 0.05825305380107415, 0.030112451415569074, 0.028549693337070848, 0.08583983015869895, 0.056002402392726754, 0.022001265690872268, 0.00841413710957333, 0.04974771583933504, 0.01998069538404384, 0.049834172692029714, 0.006732237994700911, 0.006612636347962243, 0.030509030236111536, 0.06340960311072488, 0.032315990331793026, 0.006318179920556085, 0.07813608829653071, 0.003366269581508072, 0.0522756259587984, 0.03167482261966554, 0.026339870584647984, 0.011849930367222237, 0.014469546956881402, 0.027648352589758656, 0.09011181221613962, 0.11403806342352783, 0.03201266164861379, 0.01107977547367374, 0.06780438140154847, 0.06135833374555073, 0.04362986408053868, 0.04116879513246879, 0.06225214001812762, 0.030482925790091677, 0.06481770335906936, 0.08625316523736523, 0.03821328537718904, 0.015887977900884805, 0.027081633302112742, 0.008391131489207188, 0.07269665719039979, 0.019102023178411108, 0.06034316765444894, 0.02412483268868058, 0.01168213508677699, 0.017594461734857292, 0.06690882461806459, 0.0351792439487913, 0.04754698272013376, 0.08289629818811532, 0.019827600373255632, 0.03945606768191342, 0.008472739962951071, 0.12441534488912552, 0.037431354754634445, 0.0003848696753500976, 0.06476279783753619, 0.013087851844067055, 0.01981120609167603, 0.0071923575840980546, 0.02025371954415835, 0.04080623253098419, 0.061406482371591756, 0.024707999884060795, 0.022260695620770418, 0.04029983692171593, 0.056915414489565365, 0.05275476799016038, 0.05511184050250919, 0.12127688184620873, 0.034127006863033583, 0.04162429569048747, 0.05245160401588487, 0.07254915462145883, 0.051227962417948636, 0.02789637547046427, 0.06961966504252727, 0.03240145510062575, 0.020950217956616994, 0.019276223911513245, 0.004293622604886731, 0.021991318039175485, 0.07846487025099416, 0.07005931524139258, 0.03253740123322895, 0.02413135784257564, 0.03448483121070651, 0.006529077222841162, 0.05705694157269694, 0.021753099168680852, 0.022111886871918555, 0.04772624346397577, 0.036391543615008556, 0.010634180432516, 0.05423389608040453, 0.05737231698848548, 0.025967691664493857, 0.04785450573469843, 0.03685082481693357, 0.018379657807189132, 0.01707455808026416, 0.05505491633929553, 0.03048153725572892, 0.03083055925315186, 0.12233566898371905, 0.059182647871033806, 0.0264271050165858, 0.06405137028665313, 0.014778862617188885, 0.019551439083091194, 0.03989990838172455, 0.09723625371172544, 0.04761997940799883, 0.028666154023319967, 0.005094695370644331, 0.019596343326772896, 0.09246641409493263, 0.005522479346367501, 0.027744408524144563, 0.08982138062316565, 0.03482549901931517, 0.0246588361915201, 0.19463579140363202, 0.0452221165441217, 0.010097868132194685, 0.008856031946056794, 0.018726318338585478, 0.02250926625434189, 0.07243578893042381, 0.07786398918758478, 0.06970110784975753, 0.03197126800284511, 0.013541191076529364, 0.05819675399951878, 0.04344493811649661, 0.08312675275749738, 0.011687993744177925, 0.03235499569845777, 0.034189155745890834, 0.012248563261011676, 0.07874338917674557, 0.019335164801187573, 0.11735415161256829, 0.1012893491274407, 0.0619967952520857, 0.0412889062276771, 0.025347325154730392, 0.04480755955521618, 0.029584310400570114, 0.027193593221806714, 0.04034390229912054, 0.025948851647215988, 0.06406610215743704, 0.024507315491416284, 0.021511325650217555, 0.02263305265636694, 0.022111634062903545, 0.09402011701416585, 0.050367082604357315, 0.08222844571836534, 0.028332735321694807, 0.0253507629742906, 0.04036960071854053, 0.013735509278523106, 0.024135356821540385, 0.0534512798091577, 0.0462239871792976, 0.061903213781695214, 0.05421811083872473, 0.04117282858539013, 0.005192444359342898, 0.00882546791070772, 0.06528875550195094, 0.06734270617486009, 0.08168668366007267, 0.05037423403513047, 0.015332521063335722, 0.07173655749929529, 0.013954142153623604, 0.04003229986635908, 0.042060211210721926, 0.03817749374936666, 0.024158038769758517, 0.06189510091057709, 0.032625183418032624, 0.025557972520830172, 0.030216135670461004, 0.013924708097962844, 0.054708238570920886, 0.00815127989382393, 0.005602548940993485, 0.0175304627496629, 0.04422095454027576, 0.06822381454009203, 0.05536716228591339, 0.0009565245742241162, 0.05414891394696409, 0.06197823294168038, 0.049092963473090244, 0.03063449628591057, 0.049319671872522564, 0.12094213972769438, 0.09477802311941501, 0.0012713996388371133, 0.07795729869676214, 0.04804015565182894, 0.052962780013800635, 0.011607923191942034, 0.025273077828328938, 0.014396550269016336, 0.06766719803694757, 0.017343052745526357, 0.08797833395581092, 0.04285185965859602, 0.02379370267472921, 0.005818620209597172, 0.11175492988719095, 0.05329787453276016, 0.016718783017788685, 0.03530164564689321, 0.027955695573661118, 0.09758013525917646, 0.05979886601468729, 0.06366672903119076, 0.03803877054803795, 0.06483505525055432, 0.030023813127510013, 0.05646885417762303, 0.04444472116207884, 0.025888426462188367, 0.03336257751910918, 0.0030813806346662704, 0.01836067797886508, 0.04242333688683087, 0.019632014295747204, 0.05225632437354615, 0.03176751925850348, 0.06723346203685769, 0.04916510214248011, 0.033909047187696544, 0.01093500496579274, 0.03197959537858204, 0.11562269331226427, 0.016309245820007017, 0.01729886096361424, 0.14785412668941483, 0.03799427616139574, 0.03645694454110438, 0.030045275080708728, 0.028219337071923, 0.03435187282100801, 0.03380302444941575, 0.0813018087477934, 0.056464633033160246, 0.043520026224394964, 0.012097012875000797, 0.005436369148458565, 0.03537714361183105, 0.017313382160218976, 0.026587466371335813, 0.06476712623430837, 0.05154814886590166, 0.0393612987752403, 0.07238502794456098, 0.06389606128176374, 0.00890602205594581, 0.09590549003933707, 0.10402424471272577, 0.11210271848305581, 0.16691312253955873, 0.15989908197474095, 0.301537201890061, 0.18185381356987262, 0.14252866648377913, 0.15206427012960758, 0.16169548154838626, 0.19537117452390734, 0.17077164694426522, 0.08520906400536338, 0.19857156811462295, 0.23406089764208565, 0.16149911789163468, 0.07412164201659542, 0.19646959138974068, 0.08486908950632618, 0.10214688496724253, 0.11878749445801783, 0.19461522960374433, 0.16038729448712644, 0.15864508797324475, 0.10517260285034295, 0.07774342227006152, 0.19529174652791795, 0.20733752918820228, 0.1802984865442399, 0.213020752454477, 0.10084506409663348, 0.18440684754281275, 0.28242514679028147, 0.1531640965972216, 0.21706889894220138, 0.15820962827532523, 0.12344923906869466, 0.09610305645412977, 0.1483785291953433, 0.18208820583118548, 0.11949913651351968, 0.12019801554420304, 0.17553482925699604, 0.10446734230725035, 0.12655897381445094, 0.15746606333601862, 0.13337996788322926, 0.1395932627060721, 0.15666262096455022, 0.2147116004339149, 0.16565503762854686, 0.15159841206285263, 0.25132096582843416, 0.15123933133098388, 0.0981194228534737, 0.11977984645073453, 0.08064347109006298, 0.24739314111009722, 0.17323662677118856, 0.15519899466345388, 0.09758470880408442, 0.182516219154481, 0.1709617286800377, 0.1385080072307779, 0.1540889026176545, 0.16828733105813304, 0.08912718238969965, 0.21282486377223847, 0.14995673160639503, 0.2204868155381372, 0.08812149280622121, 0.14192353363238996, 0.20911981742228233, 0.08135320558663338, 0.11978076575624368, 0.14575981084377537, 0.22593212253864736, 0.16436718254079744, 0.1514226714930227, 0.23255283824138104, 0.07847769456284662, 0.08631381641833052, 0.22037412400447556, 0.1612814569905881, 0.14495647572461637, 0.16113908721073983, 0.18122497795810624, 0.174426483891664, 0.21190537440200008, 0.16140960817856176, 0.13032733733134885, 0.17617054433832247, 0.1317477562735158, 0.16292243264615536, 0.13802213894744075, 0.2436072724841295, 0.17611192329035652, 0.07270634820264193, 0.14515734397836272, 0.16522490990258035, 0.10467164263489748, 0.10881911242200483, 0.2642373308058708, 0.22725952308504815, 0.13212830278902285, 0.16407835207158522, 0.19278155219170356, 0.13540732764428662, 0.06123885467287995, 0.13052356309227406, 0.19743297759804035, 0.2673219378677107, 0.15801835144239088, 0.06195646072287233, 0.21081852546382338, 0.10188028636959293, 0.13838054552193613, 0.06892885291768659, 0.19660528088288923, 0.10155707387433899, 0.1703734804064997, 0.2263509428068515, 0.13351412520052927, 0.11583831641943225, 0.11975098025774765, 0.11495862531686023, 0.25538847901888434, 0.12125434353947641, 0.21742658539404794, 0.09485211914345142, 0.12547351915629643, 0.1345919955882334, 0.16213455718130837, 0.0922913936477515, 0.13940345676195237, 0.16372395979781307, 0.09141079090054959, 0.11015974330685793, 0.14952612890591546, 0.24518348306657808, 0.10794132121748502, 0.08746663318766702, 0.15470790166047313, 0.12046154212927628, 0.14899671618496219, 0.18041185223527495, 0.15642442890713293, 0.13436111200961376, 0.2061788978115205, 0.1472551531849369, 0.1526685756060385, 0.16124391868229837, 0.2508310372790983, 0.14190154690896312, 0.10909657414642074, 0.3287719340334016, 0.21380654416016995, 0.10515906607672092, 0.08868459041320509, 0.1491977223345349, 0.15310359097296192, 0.1020438997675815, 0.13807950361121085, 0.11015722287758706, 0.17122540082181656, 0.1791348909178088, 0.18501990174333896, 0.12243145295689184, 0.16575064540149706, 0.12338944590620457, 0.11463850015594114, 0.1666439039212081, 0.08007908645536631, 0.18822622485458854, 0.15872002669399785, 0.13797989685929593], [0.07082020908954643, 0.04793212959362615, 0.12084750488640801, 0.04357969681281717, 0.008789857271157445, 0.061994918336671215, 0.012060555708294195, 0.043151457493584004, 0.0152085785708961, 0.0950659342831181, 0.059232937712823196, 0.05232007821060477, 0.029629061426666957, 0.03451571987581349, 0.013328305776080778, 0.04393824894401816, 0.05574799608439208, 0.06088971010138912, 0.0864625217453126, 0.010344775397360567, 0.052295770240767356, 0.008153321518142137, 0.020880117081105713, 0.057031101427010955, 0.04189349515664001, 0.04518062522214267, 0.04915032047598113, 0.061316313822903944, 0.02456679647307723, 0.008247064824606623, 0.04924808095599856, 0.059143994904814236, 0.006781189576647575, 0.08146553705897062, 0.019828134719582818, 0.08609191139018343, 0.04626955025859418, 0.02243606463795708, 0.028711851168003295, 0.0334569174165447, 0.10539658397676484, 0.016048825721466736, 0.01589929684996605, 0.020548967914956234, 0.004923000223859544, 0.04426522293098031, 0.050971855394422054, 0.08785575222704681, 0.010135200554354778, 0.02147747797050303, 0.05268733693106521, 0.020838846009404912, 0.028962365749682632, 0.011073854571628955, 0.08437906902643942, 0.024324726095543276, 0.05636237561702729, 0.02845278704508899, 0.02740835448005988, 0.05133221166268472, 0.08131985777928945, 0.04113273154343328, 0.022818951552072843, 0.059798804727653344, 0.055130161495218356, 0.05271681599439152, 0.07796754895318901, 0.021040411403162346, 0.014681715965120783, 0.0213860530376194, 0.0684766618595008, 0.0360086222269362, 0.038340364042068684, 0.0931623819915037, 0.010094208147136435, 0.044549380263854424, 0.014851839195245938, 0.04463985524771195, 0.02999464241457322, 0.015034630646808975, 0.022052442279434013, 0.023031979536397323, 0.00723577561720665, 0.011601707346046404, 0.0661328005334062, 0.07067551040240834, 0.002117033943631536, 0.013056197091035787, 0.019025040918119976, 0.0386235905781148, 0.0446599995296809, 0.015944949944593733, 0.059827881594819415, 0.0854636043790848, 0.03212971605300423, 0.03705889429716814, 0.11520471574077684, 0.03139487493993535, 0.024251966894934737, 0.02834487206963522, 0.03206452388586777, 0.04225707282462428, 0.004459985779718526, 0.06807931503581424, 0.0033864397189444714, 0.13612066275410115, 0.0165159918833524, 0.025516467792312467, 0.032308858053217974, 0.034383899126682556, 0.008924234838735674, 0.09730481858094854, 0.08639735064559406, 0.03428630335556884, 0.029649205708635912, 0.04104441309708261, 0.05146417413808165, 0.04484324010028955, 0.04789924909991603, 0.025855691525183862, 0.0279784751980896, 0.08905533100328139, 0.07253739517182112, 0.032925095349069566, 0.051398868972976366, 0.041399701693726164, 0.04642795042825803, 0.06671847475151862, 0.06010935378951892, 0.06593860490548034, 0.02895279156584894, 0.028546357024160605, 0.023688769696520704, 0.09234965463439304, 0.02383743097344714, 0.016837317887092793, 0.03311028178300589, 0.017619646875368013, 0.0662364445686821, 0.036682293134471106, 0.012568118644037075, 0.016299732923207265, 0.01916138350122398, 0.030554181543148817, 0.06326197030683679, 0.04177930975152601, 0.010058170413568376, 0.038781596212497646, 0.03890705843185706, 0.014261591432225561, 0.07322392486516507, 0.04484853759828595, 0.029336674394266262, 0.05280144955782641, 0.06408941421297289, 0.032822278688751885, 0.038600860749401396, 0.02816710902768518, 0.06004998197538718, 0.042420418091839364, 0.007405528731103386, 0.0324655881512069, 0.04855246162943302, 0.022630398161709312, 0.07168616423563612, 0.0423120932593461, 0.08251053461384389, 0.10686816227051521, 0.08602303242491138, 0.03329978895283515, 0.025885613004286444, 0.010714521988355106, 0.02525765073275374, 0.06652489199393219, 0.014432281567414683, 0.010798161552708236, 0.02168718879411538, 0.02577921488292275, 0.03582209130869277, 0.03851813857533759, 0.03435966393519794, 0.09113580364012912, 0.06163728168053974, 0.05301023916070981, 0.014688221966817737, 0.0357598849692412, 0.07337606226604793, 0.0887175934809831, 0.05063690260172852, 0.033575791279755296, 0.032594095570065325, 0.005381212733130181, 0.009249351062481443, 0.04660686260209449, 0.021869737970372363, 0.03558704787264428, 0.021271787193273346, 0.006916691857059637, 0.0422236445780483, 0.0461941174111299, 0.08688384712102913, 0.04773230321945683, 0.06403456614803403, 0.01809446434039743, 0.04581062145711434, 0.008433211741278009, 0.025192318754571102, 0.008401158622526115, 0.004028086475427113, 0.008224379045948868, 0.05684727096870061, 0.056944372613103166, 0.008397862529231897, 0.05693837414465605, 0.05144087740430429, 0.01603680197149515, 0.04780614260403861, 0.031078631929572553, 0.04221311852996869, 0.0436442397204378, 0.007412314833697653, 0.06505895976818378, 0.035208458711783734, 0.10713956423945005, 0.06476099753091413, 0.00906903024447421, 0.014970941927223919, 0.031839866686852715, 0.0093138987581516, 0.04182619433249197, 0.10529310848083227, 0.05538710738502203, 0.06366391748850865, 0.041483312529782136, 0.027350578044030457, 0.03668610059145478, 0.034695612642193036, 0.018015743060518178, 0.04370913885894322, 0.06375451121599444, 0.04724406772443364, 0.040056688275428555, 0.10654610656802693, 0.01921907183714211, 0.09384348778234375, 0.058241190929566665, 0.03044080819123455, 0.08557919172510024, 0.01150134599752604, 0.08240079251869072, 0.005733035739526274, 0.08063484494003557, 0.018730696531072743, 0.0532219973542998, 0.029179329510718107, 0.04327687757810758, 0.06897500205424524, 0.04358939931637818, 0.03122204167377805, 0.03519051310215746, 0.022794628260476936, 0.05940322373663226, 0.055803357428240205, 0.06253427487888163, 0.020649700816119873, 0.030898928769954273, 0.004517893408304982, 0.012329441078397776, 0.027193242736581354, 0.0947899204648791, 0.052757085406131325, 0.03437284830837481, 0.04503632107028558, 0.006470685522447551, 0.01240950492736433, 0.09986929790747744, 0.030085609609922095, 0.041598922858435305, 0.03978923165930375, 0.054176071763879834, 0.04264989972955758, 0.037584756200592366, 0.0563309851643299, 0.03478285090457048, 0.0376944906348663, 0.04318136556614791, 0.07571512022085729, 0.05968026794312943, 0.06620243792572329, 0.09590952732269803, 0.030500453881799217, 0.014502337435260417, 0.03644975097549539, 0.03573146693769001, 0.05211390862842241, 0.025175790407604752, 0.05105239804834128, 0.04140591083635246, 0.020956226001163165, 0.04798096386835941, 0.04236056747275495, 0.06778871490349693, 0.05336289241489384, 0.019119030330330133, 0.04041192707635703, 0.02049842526415183, 0.029886233312408292, 0.005862507950364342, 0.017095250115098975, 0.05772800395084966, 0.0449324127346758, 0.06006682441840249, 0.06625887562310503, 0.04108314650253423, 0.05318558519525875, 0.02137171953255611, 0.05296449605075102, 0.04972598575536282, 0.04928849209400435, 0.024717033975907875, 0.032830755451634046, 0.03108403476465854, 0.0594957786492042, 0.02800669596200028, 0.0747715067418833, 0.02137854729118126, 0.08370309602469207, 0.11837723139192789, 0.042562266931899136, 0.07404956846467911, 0.026808971118542458, 0.06156707355271905, 0.04522740255079923, 0.1410166847129022, 0.0649955889750873, 0.08623301712495667, 0.07335763019058975, 0.07177098549061245, 0.013441371735215429, 0.05451463283069673, 0.058318657740469904, 0.003616944802249031, 0.05230472580860219, 0.10488744960316729, 0.04599537122093382, 0.01487661830915679, 0.011170705322236305, 0.05248413977002906, 0.006434514681102649, 0.03287802690700178, 0.01507162503267248, 0.030471001631550254, 0.16739977223257865, 0.2618136431180662, 0.2475368285611753, 0.1595783362826032, 0.07634833785555056, 0.20556693145584679, 0.15089149676984356, 0.14684319706453433, 0.16096817299483285, 0.10878542753597421, 0.1668095627739545, 0.09531976219506995, 0.13822263947898342, 0.14853850367569155, 0.12855237289782495, 0.15211765113617146, 0.1074891608028162, 0.13909613293024803, 0.1767742982314479, 0.06728603865110105, 0.11226018019501241, 0.15816554757616214, 0.08871702657591912, 0.10527094555718285, 0.13502632147602497, 0.1395929562709024, 0.16773706542388087, 0.11201150805479097, 0.1179486818070854, 0.06002807569119239, 0.1698372954682958, 0.12982982451156264, 0.09491775755680378, 0.13278683196873436, 0.14647910611764078, 0.18814986121029625, 0.08735921233892442, 0.14155985637297555, 0.13158810355009573, 0.11847220331190095, 0.16198777473501622, 0.10010438730880138, 0.09809786513928445, 0.07600893026157733, 0.11576150844414389, 0.15234485749275456, 0.19115353874381513, 0.22295128974703052, 0.13682728693369897, 0.10933768499882952, 0.13313924773566185, 0.12599942319455648, 0.08698223579314449, 0.13119793497025967, 0.20236181876351758, 0.17881645881120237, 0.16119413828897863, 0.16760038001643074, 0.16783985910156082, 0.17501715300304277, 0.25149747248618837, 0.15955078776084608, 0.07043994602657135, 0.19179406485730605, 0.14310462670701166, 0.12849413489382114, 0.17502274544489, 0.1990497908404758, 0.22541827672431547, 0.14693949431661638, 0.15391391281399036, 0.16246225895179858, 0.09717528077383196, 0.19376289550094836, 0.12100896557732937, 0.1514407511680357, 0.13025632098076806, 0.1392027570475494, 0.11115837722055374, 0.14983224231869946, 0.13806772117893543, 0.13247702601215533, 0.07069075555210153, 0.0838259841886259, 0.12812134118810778, 0.20459596097709673, 0.16084048145961377, 0.16419295882505758, 0.12969416566193104, 0.1142233111444981, 0.09294405459396302, 0.11176845899993375, 0.12725482679783337, 0.28467370677859555, 0.13915777236463564, 0.24106946833912404, 0.2152997720986605, 0.12066203499993972, 0.3078643527002104, 0.12949271518136227, 0.11778028035957007, 0.20158736515910397, 0.20421297830199042, 0.11079781793899114, 0.09206597227603198, 0.337322180069262, 0.12648132314244587, 0.13959214421770266, 0.11164126542186546, 0.09075935569501693, 0.13387115281676093, 0.14607614386946927, 0.18147467665614622, 0.20850504718480573, 0.0970396985329928, 0.11709905965554139, 0.16731056895467544, 0.10552609114036446, 0.11898854657286599, 0.1826625725915355, 0.0686150786256598, 0.17813369060956663, 0.16697345962447507, 0.18582743502432303, 0.1298061217511854, 0.14439134798463316, 0.12655647636781778, 0.2116149198263884, 0.1607175090260083, 0.14885318195146902, 0.12785868028238898, 0.09723780887021173, 0.2022013386651393, 0.1491048877998706, 0.11280792539999371, 0.12587329447870294, 0.14790087337455443, 0.180584283305272, 0.2050439232299405, 0.17715299081417824, 0.16553139103756798, 0.1245437182425972, 0.166874511708175, 0.08257358365001218, 0.18899928417897996, 0.11617303555530888, 0.16162486356352607, 0.11182408464411575, 0.1591977284800622, 0.0805161013117721, 0.24767421876951573, 0.17594931346754875, 0.11006014421582223, 0.17964109117465635, 0.11998838324460293, 0.1893978644042246, 0.14357714973870786, 0.2664077498259083, 0.17779615227012865, 0.12641309535190945, 0.24291881991009562, 0.12096061010754879, 0.15632413267608614, 0.10743083852914073, 0.16660314804363638, 0.28685212375656255, 0.2055831725198415, 0.21021795849646294, 0.1820579453581764, 0.10724313932681277, 0.11601698344513295, 0.3465621503851106, 0.1255701994523406, 0.1969234678413599, 0.12398710940033199, 0.13826282845149118], [0.03125195549200139, 0.029526020685631423, 0.07970885914419928, 0.03521280626075403, 0.04033834433122989, 0.029617089387630264, 0.060950299995320464, 0.04023119161326078, 0.07734414490480578, 0.030679636101628986, 0.031445317999309594, 0.04377772288036443, 0.049077917506257375, 0.03792908207903947, 0.02203967542417588, 0.0811599905512506, 0.031051068086056944, 0.03887362252440184, 0.02206005527818155, 0.04964822400060873, 0.04567585126947492, 0.032418328187158035, 0.019331276904971852, 0.0017523631639403082, 0.07930979628356234, 0.07624761261526616, 0.0010171481042033843, 0.06143265193508518, 0.021366071549334356, 0.04309916816231224, 0.044036940220863595, 0.06958182795994705, 0.03113606554125586, 0.018435733528026653, 0.0595579696668973, 0.03102754535634191, 0.04429588943058926, 0.021658456666515242, 0.0526732141001811, 0.02715009474946607, 0.04194022652002112, 0.02334703319525767, 0.034438249234470635, 0.060518364301852645, 0.036881901173582005, 0.03158113581218547, 0.03661030768266609, 0.04503142959888905, 0.031708352372891484, 0.04544545415668719, 0.07806450504088595, 0.07335811282598204, 0.03062343206106415, 0.057304384141799905, 0.02156606071718758, 0.09148654933538168, 0.057339762082143184, 0.055675332644774075, 0.031804425544255686, 0.11725300502392555, 0.03667317285773255, 0.04469798599940635, 0.026111423165627548, 0.04832492585504248, 0.00799992102979412, 0.022876729903322075, 0.049154568433521256, 0.028304413051134156, 0.04238421660697749, 0.05800469958734128, 0.012307169944829038, 0.0771797807406514, 0.01961342900270416, 0.010985273740164215, 0.12841608585609546, 0.0461493740459123, 0.08001794497812949, 0.02113700551431506, 0.07007934077973328, 0.031593330016720204, 0.044098215763487165, 0.08354145913354813, 0.024279952086808703, 0.05530589823460868, 0.032949269253520236, 0.05560269984867304, 0.06744756062905635, 0.05804512221666594, 0.015767597717293087, 0.04779956190876904, 0.03478918645170427, 0.07858005157040973, 0.04579286736946914, 0.023001364747723265, 0.04184173825647562, 0.008692030716056546, 0.05295760508987212, 0.023666016885169575, 0.0428023703786875, 0.014293385038693106, 0.020828925170785478, 0.043292394689013886, 0.05684719435990818, 0.05080146211830359, 0.03828430172776984, 0.04378602344302401, 0.05751394749348683, 0.026188143040804614, 0.03652403852151286, 0.030710936538995277, 0.0626169549181096, 0.05925423878755781, 0.09002745827479709, 0.019575701087653156, 0.06340766490827646, 0.028975276246426568, 0.023238262116548516, 0.038060129079366886, 0.016082587216289777, 0.030019913739975423, 0.061016076304499185, 0.01399912779414726, 0.04337312120403494, 0.020430975052858555, 0.04031092221398027, 0.01369092966459932, 0.021455052661739533, 0.04582299377709147, 0.0893817610678173, 0.0611866572721591, 0.01846646131466954, 0.026358199238236395, 0.0630088855001715, 0.03128014944283472, 0.015044418377651563, 0.02463096016717534, 0.014189690250092217, 0.032662491899945086, 0.10758049380514892, 0.043323038205985105, 0.04174738686772124, 0.055944532110926606, 0.04150434547374326, 0.041480186891051075, 0.023818138964293946, 0.03032961435946486, 0.06511749654647804, 0.05260734203001184, 0.01925579809223212, 0.048043323425395836, 0.04244615864609519, 0.0310206524802432, 0.06014651288428615, 0.01985097563104524, 0.02057977422561136, 0.034270330422347596, 0.04118849891388128, 0.01546116829324033, 0.10582884142716086, 0.041773521957258065, 0.01519787249215428, 0.004403961291010942, 0.06392974999823398, 0.03163317424966203, 0.11622332922753789, 0.019098619832807494, 0.0218772437168105, 0.024975971694314675, 0.0291385583113879, 0.005214274992355176, 0.026457434437508066, 0.013738759406541866, 0.027497814397417733, 0.019105842126713648, 0.03588313702493906, 0.029892936581745747, 0.018022316094908505, 0.03754789588011561, 0.0944070297203237, 0.01430285867348674, 0.07034164162412768, 0.022428093493104945, 0.03320613087365224, 0.02130552953589828, 0.045073552943405606, 0.046250122268834425, 0.07503191534910472, 0.011338876943374354, 0.030987929034557556, 0.05774355936615218, 0.04030891889405828, 0.0322982132615101, 0.029866144571813847, 0.013130082440893016, 0.04494832821130272, 0.03684402195616596, 0.046160260155316324, 0.03389736434685127, 0.05997419289703812, 0.007666819775852585, 0.04703914686556786, 0.03858063602820039, 0.041928413444228714, 0.062233458964094046, 0.034920892287646575, 0.01872495661730007, 0.07093102370779361, 0.045469455691354896, 0.027714385538392013, 0.040106499312265266, 0.07586495169708807, 0.03486144386472241, 0.027086425182079116, 0.06054196747079973, 0.052760973302347046, 0.043350276462132895, 0.05816530609022706, 0.05627656993906825, 0.0859983567328703, 0.06745898300000737, 0.012198625819667453, 0.05017751797793373, 0.023132084245463053, 0.02413403340465119, 0.028254902703807722, 0.04463518977225308, 0.029889720927683577, 0.02567983604216528, 0.03719269538358335, 0.012125180970366684, 0.06453463387104773, 0.07633808759912368, 0.03490008533962312, 0.008341404722042142, 0.016440145348409013, 0.10495786840516715, 0.051536504329452594, 0.02573432787621935, 0.04784754199546672, 0.03283220335781094, 0.043444099250219526, 0.00527524984546847, 0.01881482064603798, 0.04529598274178082, 0.04499114869583038, 0.032708365244851, 0.00943670073719395, 0.036577350580163544, 0.016373585714327715, 0.010700501621730868, 0.08077305486245502, 0.040774344121136015, 0.04455154829268013, 0.012762188825065331, 0.04452767699295956, 0.09447368703061536, 0.017499116347021153, 0.03411668765869352, 0.06094777573560996, 0.036646241036754464, 0.0506589314599912, 0.06463368137877795, 0.021252043192244826, 0.06368904134198543, 0.016071519161003734, 0.04880256635407287, 0.06016388392796921, 0.06607464679907407, 0.061252475716173656, 0.016622560459279245, 0.04220329728277941, 0.019863361357561043, 0.07632251303162306, 0.04969979320923167, 0.025396802943320047, 0.01850441905609783, 0.02419087904385261, 0.06105931430694558, 0.03053453138789102, 0.016386072947493485, 0.10861643620075719, 0.03128607704814884, 0.019648184496608954, 0.07025674376035891, 0.05987016198736045, 0.052436171174650235, 0.0028962961861848714, 0.051716232386928414, 0.04139578315399347, 0.052211458434260664, 0.04538100317961747, 0.025023495958697413, 0.01897070230165076, 0.01635172731062818, 0.015665547144899688, 0.039132062285657854, 0.025090524821632335, 0.06188113895815708, 0.028172825958820123, 0.008263150755796702, 0.06949729015750271, 0.033863074251360474, 0.032418377982873114, 0.02876911049468383, 0.020428912361122428, 0.04158296524697254, 0.009522816680762316, 0.015195123194116018, 0.08274606068528469, 0.035282489618346576, 0.0013666363379489933, 0.03428777424438346, 0.016809148834116997, 0.028849157106672085, 0.09216799220490841, 0.059282426992731715, 0.07703996969447022, 0.0451079311390077, 0.06395154903011938, 0.038250854328995755, 0.01217109740771834, 0.005110103314021422, 0.04067822689971617, 0.031246612028729533, 0.04709705928220384, 0.09526913144415426, 0.05823562147035714, 0.06255458003931469, 0.03954219511680065, 0.0294041897230331, 0.021710062264314583, 0.05364477063619322, 0.0630541842791342, 0.015729017529426324, 0.1279853222771518, 0.03075254468938276, 0.04267527256160975, 0.043939340619310256, 0.034393360312547416, 0.03366810104419147, 0.05916179878817451, 0.05091431836086897, 0.03188211643587678, 0.02089940334459947, 0.015364952438000231, 0.04160014093823491, 0.03703280900334639, 0.022533147130161527, 0.055176008027046926, 0.02633034811174918, 0.05661757865680322, 0.04099285154933891, 0.1580094035354353, 0.1506043057287893, 0.1693480410763333, 0.14988102679771764, 0.10117443593879862, 0.15389387195389118, 0.1788563719920574, 0.12979354258746872, 0.13536280261412745, 0.14036229240798181, 0.11681477974859938, 0.150125500776114, 0.1173237992090083, 0.10641303709557942, 0.11530040778339871, 0.1393364700338533, 0.1393045394891693, 0.1253652556108371, 0.10629114484594715, 0.18839525449420177, 0.15990666624519134, 0.16104082877357162, 0.13140039668688852, 0.1065033435400936, 0.17479762284746095, 0.2291700850811697, 0.09745927722824198, 0.16846756090319928, 0.10705660457812971, 0.0871461786089405, 0.16887375604241125, 0.18091152542300765, 0.1669669478771187, 0.1330870311827429, 0.16085416378994144, 0.13674295597499417, 0.09840416241317027, 0.15994956716895103, 0.16533329602210753, 0.2221099873103442, 0.15383048583903622, 0.17315228049072529, 0.17560659637374265, 0.23874575512543803, 0.18600916640172083, 0.08362396680299314, 0.10870903324816497, 0.21357463402373178, 0.13853022378058205, 0.17550265356417627, 0.1507951075872106, 0.1017030289456729, 0.10662431648421673, 0.07812272006225202, 0.19697801330156867, 0.266171702814679, 0.13017885416986483, 0.14155311479924187, 0.08088251350507622, 0.21868535978419168, 0.14936460692796016, 0.19584326854636594, 0.19732259964991003, 0.1457120682443342, 0.07798287837255387, 0.10001485461309072, 0.08461421971479732, 0.1779863719017275, 0.15446817742720728, 0.13306194946410196, 0.10350230134903424, 0.22347596804461173, 0.11655997124410446, 0.09894259964987155, 0.13393741942221118, 0.20422105286871234, 0.170856544808034, 0.09116099261107946, 0.13674603564844978, 0.227946397517958, 0.1218546347151841, 0.12181095238174162, 0.13277235290696546, 0.19311625600582172, 0.16653404691286627, 0.15429923971814496, 0.16556157490178464, 0.13716168431264741, 0.09935049550427545, 0.16527642165460896, 0.11151492220139313, 0.12741163733505434, 0.2876888756309786, 0.10572564938376028, 0.15635817762344115, 0.15240085852001944, 0.15718910722963272, 0.14857559765298523, 0.1244185624584075, 0.19160050508235732, 0.11690409793969124, 0.14955399918460077, 0.09147814535085233, 0.12847577942715538, 0.22143340909913664, 0.08343711029738189, 0.20229052662128405, 0.19397499460366466, 0.1176147364200123, 0.25779888274208196, 0.11722947080289164, 0.16544330624803422, 0.24919759992870594, 0.10397657872207704, 0.16308609967029866, 0.1691842974433976, 0.17439636131448133, 0.1719556205094822, 0.1199065344107728, 0.0828491531372551, 0.11527728724984393, 0.1571266404202869, 0.17653737787998494, 0.140110831707716, 0.13163845084847944, 0.09523653440297612, 0.11855485653805158, 0.13301308837629136, 0.16439943484240965, 0.10641810859763816, 0.15416191079683844, 0.20310201291595736, 0.13275651020869134, 0.15132858057416257, 0.07758190029210622, 0.14565835015908365, 0.11644987674850611, 0.1573773656761454, 0.2014083457329581, 0.18076173991205233, 0.18031109635147358, 0.10971623968573348, 0.13344790456035446, 0.1133205378127675, 0.07954372123124138, 0.08845706996057304, 0.20530471488112406, 0.19456811519640108, 0.10462217633762669, 0.19333791588583302, 0.08916528760305337, 0.2009292496668716, 0.17583259231140538, 0.14902834029447648, 0.25714170187711716, 0.10961706960393537, 0.21442972604305516, 0.105059175872274, 0.2492686622445622, 0.10496041181707576, 0.09485258645708523, 0.16330415893706585, 0.10955662526670965, 0.11145843087785667, 0.23866793591408964, 0.057105538360173666, 0.13319656643415653, 0.20741996024885487, 0.13029113201604736, 0.0908198766410351, 0.17387704563237008, 0.17164766848567994, 0.15886599708709026, 0.14636073021158097, 0.1084579402701028, 0.1257479701551699], [0.04307677541228552, 0.02005171364984445, 0.024191210376879862, 0.034467146070974494, 0.014710466287309125, 0.03920501300824746, 0.06295496440162102, 0.01707093065394269, 0.03772313466235515, 0.01897551141859543, 0.04888808091862067, 0.034488845511429736, 0.04827832472660849, 0.03481377787407368, 0.03550907927415064, 0.0698413632269348, 0.02490731872498028, 0.02249044347404232, 0.03728643773243793, 0.055193639540624236, 0.028118286244270783, 0.031860794293724244, 0.04989814103370713, 0.037451027892529964, 0.05285537448681651, 0.002124372108336238, 0.022405920993356455, 0.025543644761426315, 0.06312654894446174, 0.03558284204993998, 0.01708431037954025, 0.029150294778387875, 0.11073779495012377, 0.05065549172521119, 0.03561740793708352, 0.02689471359424774, 0.06374079824214982, 0.08639152837736953, 0.05655435725085198, 0.03266867805993365, 0.024162909173737132, 0.04275039131302507, 0.058227179181431575, 0.11996988988211078, 0.026989181811410575, 0.018984308023185983, 0.04400167336326934, 0.0351597891459542, 0.011036187943611896, 0.038306495294936245, 0.04193155057427864, 0.07527188473050633, 0.023391650155967763, 0.01935724920082477, 0.05972656646683332, 0.029419341026955557, 0.053830397570686, 0.046785368749331084, 0.015177761726532013, 0.03661656279056784, 0.0806958255388083, 0.06824484365361352, 0.006396128409241717, 0.015122557430708361, 0.033975241014793996, 0.021506409280963486, 0.02443672623485327, 0.02906468062240991, 0.05770158157834123, 0.09049630408445675, 0.045624879609432914, 0.03188274271275488, 0.06445050975608249, 0.049261541120828166, 0.027208980097765886, 0.03588038293885128, 0.050088521543770075, 0.028466793047564647, 0.053446962903704376, 0.0795698524903386, 0.07078126117947602, 0.03439414172223018, 0.035670961313430345, 0.04329401496497374, 0.0497355388717786, 0.06136912792440384, 0.01142646569097715, 0.05086259593466117, 0.017504883073871175, 0.03547315741138112, 0.008360035022750737, 0.04987549164422578, 0.12455553897926885, 0.0264774140105733, 0.07703555702802635, 0.020410985903694265, 0.017947038380248893, 0.06394499131748754, 0.08179677815567102, 0.02775704705967538, 0.00802040622088938, 0.050950512184851596, 0.020652081434344573, 0.04908345632194992, 0.08484853536731775, 0.08220043754385364, 0.06216399777199953, 0.0356190167217245, 0.06760334460845879, 0.03614645676627275, 0.04121922287008455, 0.06000134305307462, 0.03452520404431609, 0.06077867714808353, 0.018532536398138733, 0.02834197625728144, 0.06291883569511195, 0.011006737608582744, 0.021512591610512426, 0.04608696852360041, 0.04366392434965219, 0.034644782708417025, 0.03865917919263725, 0.034026009661536065, 0.07995606039560611, 0.011563446042278122, 0.07662370815993318, 0.035978664358657216, 0.03147710873294742, 0.030196571700094692, 0.04589140925916933, 0.025324763865360332, 0.05198874518335347, 0.006521988036711851, 0.030680256632847652, 0.026052583782603184, 0.025159595308885462, 0.05387526734041111, 0.05171167416377895, 0.056423383028877366, 0.008535676001150523, 0.028090594081027855, 0.026150171892837654, 0.07326936920083339, 0.022239390715596177, 0.034587605736188354, 0.05633404185514777, 0.004143372653127318, 0.02639035960929769, 0.038396135242956306, 0.012874910044634055, 0.035920391880696824, 0.022683844285746737, 0.02828459435653302, 0.019848725247767665, 0.039204798503628666, 0.06206576614790867, 0.032193515855338306, 0.07896385395959502, 0.05937610805455235, 0.06313369271435565, 0.012364395755162884, 0.07316881249989234, 0.0307871297287244, 0.06772381193455189, 0.0264516236606024, 0.02345647843134019, 0.025601020916515303, 0.007622794618063997, 0.03152826233887144, 0.052013869036830244, 0.01333468824609994, 0.02541953851769288, 0.02341925038865978, 0.023829082530292294, 0.04512550902643031, 0.0233542688957025, 0.09080476938716828, 0.013232290061310896, 0.048341599758714444, 0.0424248269278436, 0.07225940484673747, 0.06602138070569885, 0.030728165856412346, 0.06123728036219555, 0.05438859221495448, 0.03801181574442214, 0.021437143441289667, 0.05119191415067162, 0.02542899395789831, 0.009910079872145528, 0.0564071917605977, 0.005504651522759589, 0.0625353052671398, 0.023091575431246913, 0.028377710428509503, 0.039177491299567685, 0.027027310007402015, 0.06244420209118436, 0.040289487073858904, 0.054259816665322556, 0.025745683214476994, 0.11926028562048752, 0.029825741094687296, 0.022306249123967947, 0.010132197489691599, 0.0348932097005027, 0.03856483546476211, 0.030414031503061136, 0.027440403768372153, 0.007300405188523714, 0.01271705858544597, 0.020559105173414274, 0.04855086816655052, 0.0374263177265323, 0.026171342732625145, 0.008388791090598511, 0.06466070896074658, 0.016041588105802095, 0.07576771215685914, 0.01989664596265122, 0.03213838816830709, 0.011053810838700063, 0.06404131155220733, 0.057326317239072055, 0.04376777905910727, 0.013423750755347073, 0.09662792627369204, 0.043420040258957494, 0.030037152633491545, 0.01555253002387021, 0.003536936494656989, 0.048090437832739086, 0.016243228193132148, 0.05355067588689347, 0.035298849425969586, 0.04064480248357981, 0.02282105254820518, 0.017941528292853507, 0.021678637337660598, 0.04187291037411459, 0.06359216186308092, 0.05051281551019319, 0.03308464082018022, 0.045430201346114765, 0.0916792510918552, 0.04038868013829474, 0.03797406676195322, 0.03908318204564914, 0.07656104982860627, 0.06711402892946236, 0.042166153509770675, 0.058015087739594524, 0.027446277747531573, 0.03751079807238233, 0.0064611893838211415, 0.02326498134812761, 0.061845354991213936, 0.042884950826485316, 0.04517511321952747, 0.08940341837343671, 0.06864250457334904, 0.004878078264394595, 0.06559479996682176, 0.020802688574598684, 0.030037238818383025, 0.044575714536251566, 0.04046830731714445, 0.08001770749087296, 0.03118006963162653, 0.05978083613538935, 0.026226550858888417, 0.08476831830076634, 0.04377776118476064, 0.040288096624276334, 0.054054650658321, 0.12634594008446703, 0.08927127586737757, 0.003405017351108273, 0.04978499750817015, 0.023387335165734255, 0.059936922719521876, 0.03128605406551111, 0.02826063495670115, 0.033436317312260794, 0.06992463698430408, 0.028552717469151945, 0.020933231872115887, 0.047239126457322034, 0.06876436617946433, 0.021008701108756567, 0.0060427018850591156, 0.0678122797680478, 0.07959503380040969, 0.018260523474084276, 0.03485182563083307, 0.08842169968110901, 0.1033496659910006, 0.049211511748933026, 0.03907166391370758, 0.08354471500722632, 0.015231513328129246, 0.040072768460959196, 0.10134734964418797, 0.08804779514790544, 0.05626340088764987, 0.04173471960389326, 0.031152297029151555, 0.014964629362727848, 0.04700673368549155, 0.025363640912297754, 0.014363529964260036, 0.00479366495123794, 0.017258702634623455, 0.021297679049894217, 0.027220695497347947, 0.038718700393914215, 0.041415494596285206, 0.03679421474976886, 0.03953370303216, 0.058332799723552126, 0.028941022540112177, 0.04112569885628839, 0.03957574593744451, 0.040908321407773805, 0.07839319506479848, 0.04053071283945634, 0.04443698367404361, 0.00827479050419624, 0.03581653334080212, 0.03235590351264804, 0.1201181508780968, 0.05006562700615295, 0.046017890375468044, 0.08083555997619707, 0.02700946590442571, 0.0228489400638688, 0.0274771376843414, 0.04926960419623121, 0.03566655630786573, 0.045862037448152426, 0.0465707109129477, 0.010876350401480113, 0.050958751460477236, 0.03637851245941655, 0.02503807269667666, 0.04423158784066478, 0.021917080288873087, 0.0557155522607988, 0.0282509075552826, 0.0892488218303169, 0.006044225442418528, 0.13824739944069617, 0.12260124102355012, 0.07203616682560214, 0.0845123989687812, 0.1073141097121181, 0.2613020496022317, 0.19804377950006918, 0.11025253187624678, 0.1254678960709322, 0.12335268900759759, 0.10603455135658865, 0.09014427136149138, 0.12613086089972528, 0.12736226296833447, 0.10961918400660639, 0.16950781637382123, 0.08532603030964252, 0.1841647944022571, 0.14856749244274634, 0.10792886462783623, 0.15296722732244, 0.10804465881759122, 0.1639713449103217, 0.1562046076381399, 0.11096184502445883, 0.06866645248186204, 0.17013513513149756, 0.08649763921576162, 0.22122130999642037, 0.0968646627640532, 0.13230525377777316, 0.18599899275408638, 0.18202075945033183, 0.11623511932069257, 0.15188310565727373, 0.11346926612238731, 0.15943523105834762, 0.13777150562213314, 0.13414712833060374, 0.1356668322677574, 0.11783473388922792, 0.1794545334433356, 0.13454011611400113, 0.1236326558395259, 0.13184204637523622, 0.16787972631714038, 0.09465446845898706, 0.2142422643279837, 0.12322313587872252, 0.1809184661796016, 0.12318300819324872, 0.11089982254610908, 0.1408595294361153, 0.13275352246578664, 0.1234712947400347, 0.07272785229067649, 0.16298635502255734, 0.08037582295195711, 0.12986918610911216, 0.1269844054214416, 0.18252443161702928, 0.15865947510446274, 0.11585036698248118, 0.11596855136655992, 0.10885606850347213, 0.14798183354639238, 0.1539421967801548, 0.17829345058529608, 0.16642728489973854, 0.2987584171275939, 0.1392747233471563, 0.1384425373567689, 0.1059019415368957, 0.10347941064185674, 0.22162736723980597, 0.19504911116053983, 0.13070681132376194, 0.11466080863629619, 0.10099753857620301, 0.09731803359764238, 0.10778640291743702, 0.15388752874587813, 0.10715457956276594, 0.14594261474426717, 0.2185108143115236, 0.1517600566148758, 0.14928553133241593, 0.1552826821083023, 0.09278121494477795, 0.1177667206033103, 0.11310201889324574, 0.1887406069304674, 0.31431159545337, 0.1430437073952729, 0.18021236293979231, 0.18796730245794022, 0.19585122053901996, 0.20551569549547088, 0.1418831301552634, 0.1340836962504733, 0.2533281927988414, 0.14431879945820378, 0.09037461101768479, 0.1654404410791974, 0.2101016203842817, 0.18774129119851898, 0.22365883323213748, 0.10165437470160185, 0.1393387070105922, 0.1196849664613124, 0.08949924831188495, 0.1916024356239265, 0.13131721486007014, 0.20874964373727, 0.16133922002007886, 0.07102562024468376, 0.19154471855971122, 0.14709816644749335, 0.11727382729370749, 0.16232902094000773, 0.3059262728258487, 0.1222190780625228, 0.08998318605365292, 0.0725561106998113, 0.23474571895935845, 0.10470922690846267, 0.1473899386943348, 0.1606108082999145, 0.13413064211847323, 0.08310603774002484, 0.1339563877592164, 0.13676714903164294, 0.11795419764014022, 0.15298285551609533, 0.18856423816853957, 0.08366203371195063, 0.12446370035890611, 0.14604698656307114, 0.15334880039576562, 0.1356715054040955, 0.12040314324680837, 0.1057169389640612, 0.18600046364290101, 0.13473479437731928, 0.13738866084285323, 0.11125594617859011, 0.13280730183807113, 0.0900589215058473, 0.1176551322362596, 0.10928773606616644, 0.14794028093737943, 0.16442733576461194, 0.13168358874897804, 0.11638774701784696, 0.06411767136605998, 0.16509868925617588, 0.15634965872572315, 0.17959478882051286, 0.17842540156937417, 0.13565259835412427, 0.16640087018810934, 0.08231864491057012, 0.19081972359168917, 0.12226030125372833, 0.11825243566906261, 0.1500850666554705, 0.1600235099754026, 0.15026304420203934, 0.11127023371837794, 0.13714718992912, 0.17152100350827942, 0.12057765807595947, 0.13607244518014694, 0.09136433532882123, 0.14664232881078798, 0.12358079934793136], [0.015379714952301116, 0.0195814180187881, 0.010066630897082148, 0.01531904940718725, 0.009437140280140505, 0.07519523763368208, 0.009942947916926877, 0.03769363644683073, 0.03717724722059023, 0.06536251444730067, 0.046676607246720986, 0.04120288221465965, 0.030540022323088303, 0.011034404873968133, 0.042395309560121074, 0.04092563499486254, 0.05628516161513906, 0.029734210824714075, 0.028055518745414676, 0.009148412275188153, 0.0527197462807019, 0.05532070671418502, 0.07638289608181485, 0.019802375013128887, 0.06450014459269662, 0.05520343780517579, 0.01890373089531016, 0.05752502129443231, 0.040747132678065574, 0.012564315975102927, 0.016015950015806142, 0.06520840820045241, 0.036297092634824016, 0.07889069256282623, 0.0704170476585146, 0.0667056197961492, 0.06436827787829023, 0.016779116272265394, 0.03902022877047139, 0.03937880005387049, 0.051713968597112164, 0.03947588637651455, 0.019013310196779428, 0.04315163369380659, 0.0232129160975737, 0.05830037888259657, 0.04304721590972716, 0.024656558995165175, 0.03729938078791865, 0.04873183728646367, 0.0367756447784843, 0.07161094972323026, 0.013360853021543835, 0.017837813394444606, 0.08251729917021529, 0.03137576104622455, 0.039257440235345595, 0.012999403162769253, 0.045921187096786116, 0.025458116790339835, 0.008694860453326857, 0.03741365812358357, 0.07180066373679908, 0.037138624897887634, 0.022083664192788063, 0.061469025789730014, 0.04577565720425018, 0.10880947503591738, 0.027216482013764403, 0.01650473613652491, 0.07311713986939962, 0.007007641815430215, 0.011892352486029269, 0.04392991390740199, 0.04592662632104851, 0.018384828900678024, 0.022458568470732822, 0.04461498037281056, 0.04104191182000984, 0.014025908312760295, 0.0934285132755195, 0.07123670811134, 0.041438178459723155, 0.029532934629148053, 0.055255872693153164, 0.018057368447883956, 0.037548589189687086, 0.034107950425917105, 0.08773105609561167, 0.03801332876807259, 0.06302315388776122, 0.017414036537370375, 0.026856052967148925, 0.03207682917315153, 0.05996709892285928, 0.02266208547347736, 0.07669012798296829, 0.028363727408671574, 0.041066162333252935, 0.02406484991942923, 0.04226991245823522, 0.04136075761409537, 0.03253078606400279, 0.06902289021039201, 0.0313078511821767, 0.04977516860010163, 0.052369272546662446, 0.023792808267077612, 0.08205351720173513, 0.03695818054820261, 0.029167506858826648, 0.05934795049289542, 0.03469858123289962, 0.06978664922738267, 0.03000766590928599, 0.04607960258820846, 0.02993968518210515, 0.02865269960414979, 0.053691888873976086, 0.08461420439303884, 0.060997920020693736, 0.04543500854783962, 0.030174600298426328, 0.04649158935212801, 0.04544883643487289, 0.0649259515827702, 0.10600537872843205, 0.05600023819434066, 0.03387027930828833, 0.050737692959486484, 0.026229883341359037, 0.02657211205411342, 0.04753611576292784, 0.03877516873481293, 0.07242533949113662, 0.04958678757952106, 0.045453907936931624, 0.006002492323938397, 0.02459045518339882, 0.036280537474780314, 0.06183057332471494, 0.01773905316968599, 0.029235709751505527, 0.02538231047501247, 0.04173187358725456, 0.05986939206899655, 0.013720379042018567, 0.07598007939034894, 0.030947550455288544, 0.015052814701301678, 0.02491584336835771, 0.036252559943785595, 0.05395377986133099, 0.13867366608352433, 0.059337784506140225, 0.024878335703584938, 0.06588545372529377, 0.02367835090075049, 0.04869752037789553, 0.021310652748891906, 0.053868541088435924, 0.0199205172623718, 0.030254597114699504, 0.02193432301282883, 0.02232374082649908, 0.03507820461245795, 0.05328237274361234, 0.03362664036572941, 0.045802746073252736, 0.025224996234981284, 0.08311745245009662, 0.03516525901373356, 0.07525853181798613, 0.02159669274283994, 0.07195771176127658, 0.031668705407590154, 0.025901681698498227, 0.02675536220082112, 0.04037194877802845, 0.03627866055936583, 0.02000115376206175, 0.07262453001232878, 0.0290609555198781, 0.02754120753266879, 0.026487472745019103, 0.06151743871610492, 0.03205876865033661, 0.015432191017504423, 0.013995897775936513, 0.04782162907142793, 0.02523148883013956, 0.02781940278627219, 0.04694427453702496, 0.022123583119302508, 0.012062345481207295, 0.070146189612006, 0.056223460893717506, 0.07498733669279084, 0.05105142894711706, 0.007585354943594505, 0.01111259563795982, 0.04204259884934272, 0.03238442879650862, 0.046097249423544255, 0.06191608405882313, 0.012148279478893647, 0.042572306514146833, 0.024369335395374128, 0.026940971898335605, 0.06567858700310031, 0.09395529065401324, 0.02063868255654891, 0.07615541393357901, 0.028292791497322823, 0.05492010018638065, 0.05688042342362385, 0.0367515551437053, 0.07207695334669083, 0.0426245958454186, 0.03553364388344269, 0.048271556339797475, 0.05745273706833682, 0.023321459265125376, 0.021725914538687757, 0.048219163586655935, 0.019403559215847525, 0.018527049293381073, 0.05097794196298046, 0.020180200001284964, 0.11720206017696089, 0.0207375634401556, 0.028958422312092398, 0.015408415478774378, 0.03291706674762311, 0.030594849320609244, 0.06136123338834413, 0.025945758567221706, 0.05520110889788597, 0.052599106584825826, 0.03540556547382186, 0.01568113224610927, 0.05504103099566795, 0.044311268645669186, 0.03375184594563419, 0.05080540747111363, 0.022964544646862536, 0.03157289462134002, 0.049749244184743975, 0.035824339776750536, 0.044168791613511504, 0.04545640155312516, 0.03286042220650181, 0.12623619798931385, 0.02536729323647676, 0.01625159004282567, 0.01942239157224615, 0.07836993663541733, 0.03220423725583861, 0.011154805167367863, 0.0264432120151938, 0.008746302299832386, 0.037012952004349044, 0.04066005529415223, 0.027659594930047472, 0.062091204097434405, 0.046965230872193654, 0.06271064364080949, 0.023701626567109942, 0.057385658409686825, 0.09246113574913434, 0.11012418916629207, 0.024524468200040922, 0.0214879063423723, 0.06991905986421532, 0.012155806292749703, 0.0747632023487841, 0.042577508251152696, 0.033313348709094914, 0.04925948034431185, 0.05725316733362214, 0.005506461405480702, 0.06233229579764509, 0.07556233164523879, 0.035008689794208736, 0.11106654626107025, 0.06504175343340443, 0.03428477117972028, 0.037695815966975306, 0.053305849508051915, 0.0787392752845922, 0.027436611633146965, 0.015351899257380397, 0.03118899647116421, 0.027657560966608506, 0.01781996546102868, 0.020565896542863022, 0.06222640329431142, 0.057066640245818326, 0.058172143424951264, 0.02827494547912671, 0.013401435571722688, 0.07831903775372813, 0.07409569461860004, 0.08302330790508179, 0.08178210757192104, 0.009932244711014773, 0.04060924834301395, 0.02818874335066686, 0.014748866444513684, 0.05292245697590613, 0.02170049191092051, 0.03684258171086831, 0.035076561353860364, 0.024929621459675894, 0.0397416690905248, 0.09080809420875965, 0.06121756125902457, 0.03870742357966881, 0.04972774775758867, 0.01473225861592519, 0.05752107977206188, 0.07744110099250272, 0.05359181097798771, 0.01658220103220834, 0.03508621789214592, 0.06648414377723971, 0.00817561659195851, 0.012355871111785453, 0.03114644028697043, 0.01335966367004139, 0.06667274696331832, 0.010136123690303537, 0.07810445652613718, 0.056218500474407795, 0.01602001028180483, 0.042042889962753946, 0.05124021216385788, 0.045201884162041454, 0.054661013080828616, 0.06863294379605402, 0.03421396167287904, 0.0504783109100836, 0.06413650946811804, 0.02070909752810915, 0.025258949251785397, 0.03717010728113594, 0.018993108458216154, 0.015070410783312496, 0.01651030559573443, 0.02539834469526766, 0.06817617919296026, 0.14707285490247513, 0.15021674184789582, 0.10460546795999813, 0.10305562612390327, 0.10829134679008877, 0.06596742513319177, 0.11185204685335198, 0.19909672138671722, 0.1456133807979284, 0.12676516637927102, 0.20103634875868598, 0.14427933060834486, 0.13827330853429534, 0.053629690195403756, 0.19396851349982525, 0.12950889495832305, 0.14239493817571672, 0.14927347310848776, 0.1263655366135701, 0.11475392662349249, 0.13123662241043585, 0.17873914521788398, 0.13466722542239776, 0.148129734481054, 0.11616211880238787, 0.14686256376726015, 0.14188898306700493, 0.1467816802042146, 0.14703815111950522, 0.16854015539490408, 0.09250504024807485, 0.15204257451959197, 0.17464100383222106, 0.09081786949067347, 0.1625392967534642, 0.20658834116353145, 0.14678992331027985, 0.20580026651582412, 0.10272138962341894, 0.13816787951415585, 0.11966196850182549, 0.08964465179991338, 0.20744893369415116, 0.12770131816186253, 0.17424023259551297, 0.09632736699835909, 0.13194600450656108, 0.10892660987953987, 0.20630904082809726, 0.08299542996551722, 0.09436996638654702, 0.11906533156551662, 0.13440781272947788, 0.09475623557884848, 0.18119741411459062, 0.10557881331131344, 0.11872987698523269, 0.13868011654384677, 0.13919203181660947, 0.13549671478329167, 0.08850931715700897, 0.11681044369094795, 0.176541545398293, 0.3773443292706244, 0.15943593585923796, 0.09736471899574804, 0.1651510437049212, 0.14717734929534698, 0.1828113315446723, 0.12471374379651201, 0.10686530476255764, 0.11359677379650455, 0.15858393883512867, 0.1048572044519167, 0.17673207146506156, 0.2175724791783479, 0.16723435852796803, 0.13211492689386492, 0.10585566982626916, 0.23551551474919244, 0.08723590282663223, 0.2546880448297147, 0.14914929025596188, 0.1160976754861974, 0.12013868203446751, 0.15260050103308695, 0.11658404938756459, 0.18656119403819885, 0.1023396863151462, 0.19182676148991432, 0.14829065891042834, 0.18192276148305786, 0.11556932762745889, 0.14118677155385095, 0.20017183385789397, 0.14561630725379915, 0.12457044705027535, 0.201247176155448, 0.15656822361052036, 0.15369643577404563, 0.11665000955784514, 0.1320347787752267, 0.26856021174500067, 0.16067312189167546, 0.09098333682143882, 0.10870648983625636, 0.17709182635430368, 0.1989444843944042, 0.19881199714877915, 0.22904432408751982, 0.13917721567615388, 0.19186200153443123, 0.10197551109858098, 0.12750012049030873, 0.24544160873178514, 0.12834430341759037, 0.13502367081180697, 0.12871980907455569, 0.08159751102568642, 0.19039289004379706, 0.16990141702755807, 0.15456458193159875, 0.1433945143775594, 0.15036321785901824, 0.13009712791010258, 0.1347160252231744, 0.1592111350187371, 0.22040245393591545, 0.16171823435973737, 0.1672734596556233, 0.15200710464869777, 0.17140005354679402, 0.07220892731340663, 0.07730142018126865, 0.14754360061018698, 0.1696466774709763, 0.18347117839561355, 0.12269139425047945, 0.10704887475097373, 0.11955210383260444, 0.1436132937669754, 0.09965103945784992, 0.11169326747016561, 0.29575599597827085, 0.13468081582217448, 0.12148508156139044, 0.1372168273214371, 0.19305991789987012, 0.1375210255144104, 0.15092653763150016, 0.153633723816564, 0.14503751250524677, 0.0847723555841273, 0.14660744116671626, 0.21249166149045193, 0.11162767502208872, 0.1026163436472416, 0.19363739497719273, 0.14398185866734675, 0.23098287893639458, 0.11894815075661867, 0.1584656088943443, 0.11881350314304714, 0.10416725800643045, 0.13811446786407502, 0.13890491738434763, 0.12865876718874902, 0.24227383516488538, 0.12509410645091726, 0.13129910454154015, 0.18689425842415902, 0.1939455768273723, 0.16769873038414987, 0.13188578999571263, 0.09541053595321794, 0.21802546696797495, 0.33667930972672283], [0.03893186435884526, 0.02836783938560515, 0.052646653831846295, 0.04752258281974543, 0.06289277721436755, 0.01929189040956478, 0.04161139093940297, 0.0466412982542909, 0.05632698618536515, 0.04128184672745486, 0.020437542341589447, 0.00621877761835593, 0.04561362960826486, 0.08018207165502733, 0.07415415478810188, 0.040209354276979165, 0.08704985837422072, 0.042548550127614895, 0.027417030425802357, 0.0547798294874449, 0.05459132972323606, 0.0071764210400532095, 0.03503220486304453, 0.059112750008822455, 0.01843400408453759, 0.023828295374950095, 0.06135880488962416, 0.06585262685773835, 0.07132309984656111, 0.04660999207126518, 0.09501305889458427, 0.0708014092918846, 0.08602594355902365, 0.06679519845713532, 0.025261674609576023, 0.005890313590381054, 0.04854223435564388, 0.07244312039185917, 0.012914764811284842, 0.05915698009513079, 0.035144413761313886, 0.028641675598919395, 0.015895779548783698, 0.07451706595959202, 0.030084537086828105, 0.08158993441611528, 0.013789907266806452, 0.04797984921042958, 0.02754019629660874, 0.05174142135787876, 0.013560690887032018, 0.024110717518675714, 0.016175371955239003, 0.08129276124940765, 0.007929100031634013, 0.044207885080287536, 0.012809417187987317, 0.03947198698897997, 0.022961694799784212, 0.08686077255274981, 0.08954391889874974, 0.04280144341229912, 0.04481876742154841, 0.05301974248141051, 0.03872050070053628, 0.06030299400369968, 0.011459504190321651, 0.03806032060134796, 0.014273935981515436, 0.021002963110203707, 0.10824915066721941, 0.009447756343551222, 0.06450355368395967, 0.038165960295666615, 0.05985902689938104, 0.03771393011594492, 0.04374315699322089, 0.032345220416543946, 0.05081529000533685, 0.05544135790137995, 0.03885789856975598, 0.06123694711394849, 0.01695695400778805, 0.045962088531063455, 0.048289329579640786, 0.08909741221296211, 0.016825313289319316, 0.08201502128354005, 0.02518105917730399, 0.0709389680395684, 0.01760899250756108, 0.04705118593729792, 0.09291299738951268, 0.035060776112180565, 0.07540720650145123, 0.06511137550396305, 0.06969089589772687, 0.08460424525002319, 0.10460268706083299, 0.03522712444405883, 0.025182520490019553, 0.03561255093964358, 0.008344434599782671, 0.05686508634337976, 0.03245153809867559, 0.04855872822865363, 0.08166081287086972, 0.04164900585648514, 0.012068072946051197, 0.03723080442737668, 0.04173119559944157, 0.04743455165636636, 0.06415054036845123, 0.029924294475706357, 0.012523059267550709, 0.04984928760677577, 0.08427793775955517, 0.019785655144181465, 0.011493908241391184, 0.0213682453238195, 0.023975179327892202, 0.039067316364737294, 0.03571287781420735, 0.03354787503579452, 0.00520115525784692, 0.07283142737803922, 0.07235100597984369, 0.010159168572675799, 0.04066549451841463, 0.06382119533936344, 0.08987040258944036, 0.08031585358924444, 0.025820662154846137, 0.05362759111449123, 0.04321958569269027, 0.0314690514032038, 0.06197411138864775, 0.08308060362093872, 0.06844814806695908, 0.01981235139312283, 0.03768338235996423, 0.021616385032933567, 0.04526202972497671, 0.01363257387457716, 0.04102649813097331, 0.046262360523424806, 0.023834960339891336, 0.014605998707514618, 0.029495109037886706, 0.04187908887322392, 0.026006697031158595, 0.01327580960106946, 0.018358843198286432, 0.022428229473711505, 0.061181570448341875, 0.008312882311011275, 0.017803647788241506, 0.049049698657566504, 0.09687642987457015, 0.02445965141598736, 0.05533812755358316, 0.12211933341478148, 0.015236332978782876, 0.09579050024190257, 0.057031112918329824, 0.08075182656607321, 0.04382519734903209, 0.06880156740906739, 0.0656232294896918, 0.031425474406850916, 0.08872670992728203, 0.05522957672515223, 0.04328918861105077, 0.05206873625396721, 0.031941923004905545, 0.06002123452602856, 0.025497692892508163, 0.04554180886536356, 0.041256569656393224, 0.024901241732520923, 0.016394865721644416, 0.02654932859924532, 0.033459027988776084, 0.009647595166649309, 0.0034320535515660363, 0.04865303748257218, 0.06657528525759136, 0.018788178023251317, 0.06116848566659516, 0.020825667381887476, 0.11705274197963939, 0.02674587994753834, 0.04044439771302766, 0.03568658950708566, 0.032818923223643534, 0.04697908940274389, 0.042889344340731064, 0.018498734683699666, 0.011956492239879745, 0.04503215355197749, 0.05039490308732756, 0.024216420415248123, 0.0666686100885272, 0.005253449377168211, 0.022632476175203923, 0.04794144905322502, 0.03770140840882256, 0.05399431357340467, 0.051941213258091486, 0.016894251626405506, 0.018332386351821404, 0.00231286205704354, 0.051078671033704476, 0.09693990025909678, 0.05501396893974274, 0.06858678699861612, 0.021008904122056502, 0.03752715404956572, 0.05466364459284852, 0.08448927843522641, 0.017010476740617907, 0.06491672022328263, 0.021382465830913956, 0.002048355118829697, 0.023536885104652856, 0.016731540296947765, 0.04721322885504173, 0.05992716275936654, 0.02171668892485961, 0.06661791805057757, 0.0543447834770045, 0.028001858116758448, 0.02290006877193528, 0.03475305391475558, 0.03672740039145274, 0.03393087686309892, 0.021990057824540044, 0.0927014192265849, 0.04859203773160135, 0.025112383225331866, 0.036385234880952105, 0.04007599369112042, 0.05956386088303501, 0.025178207415005854, 0.02310743728171914, 0.031030973599803065, 0.036772170569747686, 0.044981928827661666, 0.02610017699489911, 0.007491014567354033, 0.030187244579616575, 0.01659258535402196, 0.03539034330676641, 0.0318596413313982, 0.016389489699635777, 0.029301118338480595, 0.039785500811112505, 0.06276914211470755, 0.03365391692627342, 0.048575444267161434, 0.004853774124996798, 0.03978231771578712, 0.044944731428498225, 0.03606639291730619, 0.05958007130351278, 0.038953364616440195, 0.07702535273687494, 0.015198562928896039, 0.032134714776710156, 0.06422903373717301, 0.07847864451187272, 0.032404427521771965, 0.03128269860040277, 0.08258727364121907, 0.05435982944383737, 0.05108659621328116, 0.02209283235002189, 0.0545501716495041, 0.08998326266244536, 0.09333708834263588, 0.015362213673670928, 0.08030166564088675, 0.11653989207960906, 0.04432256844255232, 0.08601190882825083, 0.030280251484063846, 0.021229897505573688, 0.02162324151985588, 0.008258451763991146, 0.07534028872126534, 0.03434838329051291, 0.053884740017594836, 0.04825154612321527, 0.03291983232502976, 0.010743959874455488, 0.032239917800911976, 0.07088325812571472, 0.025516157526703134, 0.08414884428343467, 0.02003430238654537, 0.02464964505164854, 0.04254881825838839, 0.07515887143991648, 0.04839589624034782, 0.050209942649328904, 0.04762402818267865, 0.0697764525971105, 0.04312664773615618, 0.02728112834325481, 0.03968641882942569, 0.022996888879025658, 0.08662906926005118, 0.011253999189413603, 0.014213945551384843, 0.030949247340040825, 0.08734732265433959, 0.019707349467001135, 0.051726881009075916, 0.043087289969046275, 0.034564006397680896, 0.08134808045841994, 0.06874947343021631, 0.007452355376670078, 0.06978501746010396, 0.024642507027414058, 0.05174632049015453, 0.006834309155707278, 0.029572240685323076, 0.020146472980418516, 0.025452135558871013, 0.06985347507701767, 0.016812502384005536, 0.04926359423646524, 0.033450658478203325, 0.03639130229731241, 0.010384728797831604, 0.06415668822404358, 0.06066448025165066, 0.023557780152787606, 0.02242538154185299, 0.024893693851246953, 0.03243291450123633, 0.058409722612029126, 0.0020189959961440297, 0.10278844529943121, 0.03269408153550279, 0.10433569775834199, 0.045506178116005276, 0.03781024268978546, 0.040397210527331605, 0.05905628932880298, 0.024164889511021397, 0.12261295450791238, 0.1019123011839486, 0.1512397603402215, 0.10158037060811635, 0.1250500487343919, 0.15035387158634203, 0.08603165857493879, 0.2126890670267805, 0.11230747846345748, 0.1241341752991561, 0.14281688408265192, 0.11266649790829229, 0.16490632457838905, 0.09217812754814664, 0.20862425046582378, 0.1216021934223752, 0.17516195894249026, 0.14234655206241917, 0.13893493270922092, 0.17241542648163535, 0.1987592596560717, 0.15289212006234354, 0.1089161297967357, 0.1160035156194241, 0.16011088996404604, 0.15374099144772177, 0.15930433727560506, 0.2613561660532029, 0.10370506183995355, 0.14827777331154193, 0.158223724293132, 0.24972474502940334, 0.24537080688582313, 0.1505225335037516, 0.07323547747106322, 0.06978317884908569, 0.0965144303477099, 0.2143763297147328, 0.08230262601207342, 0.1829663417752712, 0.12318677734583618, 0.12155710148715204, 0.2126892968531578, 0.21281229993028028, 0.16587682008262605, 0.2162048590159224, 0.13024679084699, 0.13888136784155525, 0.16501897014677525, 0.18256639791352136, 0.15907702366671256, 0.10369848880556323, 0.09422214206067786, 0.20073742125063174, 0.12043735673350674, 0.12070171835441744, 0.11489979742515473, 0.10034227293104896, 0.18659283346947164, 0.23116871654506654, 0.21046424044236062, 0.19416817133465122, 0.1312745897279632, 0.15899888269843596, 0.15949256507860077, 0.11053193946399036, 0.1656976627606538, 0.09963469114154579, 0.1081189310418502, 0.07349323541406663, 0.1488841931906439, 0.16328583411391706, 0.18653905409718716, 0.13073033022303737, 0.2781416121269426, 0.18942352834968798, 0.17497936954661725, 0.16662976193812587, 0.13516234804786023, 0.09583383017489988, 0.15869243220696527, 0.15516694154470198, 0.17052032413982576, 0.10825481971785908, 0.09696338851485523, 0.15152489826563867, 0.08889366346862047, 0.08606344356291717, 0.2080239439683576, 0.1658989140583623, 0.20456168620336443, 0.1322669953468346, 0.28571622986947337, 0.1409623997225877, 0.17835964058195392, 0.20474680368938755, 0.09470236427601307, 0.15469176784878777, 0.13525110699476736, 0.13664501929475417, 0.13555156667867016, 0.23597718997588082, 0.15602800904983477, 0.18525098450481894, 0.11437108184421256, 0.1162991795929209, 0.20468897937286287, 0.2275263974743505, 0.1711156817093011, 0.08682002433605733, 0.13322227634489536, 0.12893302666564144, 0.13443444194572587, 0.11607362798625424, 0.12206348560510144, 0.2023256900570085, 0.2564950010949566, 0.06158072523952973, 0.12960007474307092, 0.15450844300850747, 0.057350353247696356, 0.1960707353728433, 0.16691713684028195, 0.11749299738796488, 0.06918826561060644, 0.13694186304365435, 0.16997116167218457, 0.17079194827425867, 0.08311908421737534, 0.2165877497604778, 0.16284928657114506, 0.12722829717301554, 0.1431693151713379, 0.174756575856478, 0.14167985638543484, 0.19698188970646552, 0.14713383550124784, 0.22512330222995053, 0.17472147370778746, 0.2228661314133675, 0.17312474729072663, 0.14229260415079134, 0.20178529163522108, 0.14407653181302932, 0.12815356284620302, 0.24828707378718162, 0.08274547845846222, 0.23571437585257718, 0.07913371863504572, 0.12405110838552638, 0.11037663811998022, 0.0782095714502277, 0.13571564739029254, 0.08853183248110356, 0.22688953326113764, 0.16287318851438262, 0.1344794725939151, 0.20136961232750647, 0.1977486058228439, 0.09476092403694507, 0.18783188875644438, 0.18270904348502237, 0.11691611019834397, 0.17594963522447696, 0.09683450188247428, 0.2815051977672885, 0.1830890230954655, 0.14259775229279073, 0.20322251854644668, 0.12636097072954142, 0.21990196869498302, 0.1768317088604935, 0.1739389915019274, 0.12005509418104926, 0.1430585848227624, 0.25119436213806756], [0.037764062909709836, 0.052566471239251476, 0.07023174631138963, 0.030022595047710404, 0.058750639399213184, 0.07591450992490976, 0.05754117425831576, 0.024132731055179914, 0.030270441728193435, 0.04202812744845306, 0.028884117529096625, 0.029852661424346512, 0.06957688669283545, 0.036386119712504654, 0.03509574802592397, 0.0230561189668914, 0.029313276153838927, 0.027778095325394988, 0.050454447271242264, 0.10854978655134478, 0.07080081174330366, 0.01958851773862637, 0.08569968969471033, 0.033534372736129074, 0.049726862926036126, 0.022898858353014917, 0.04327056118317189, 0.03334703359512552, 0.04272932772554698, 0.030640358773751125, 0.03068688329339268, 0.038030630863842466, 0.04653298108267688, 0.018529998731889555, 0.1280997451695223, 0.01075100309530934, 0.0664564343770185, 0.04443711007855112, 0.038684774190187454, 0.04869450582191349, 0.04069637935308199, 0.03819347434346715, 0.029539243363204504, 0.016013220827575895, 0.03919046116812576, 0.028121783435645125, 0.10878289944582409, 0.08490282035763226, 0.043213529767648834, 0.012137661500263118, 0.03164221600238835, 0.017956106946052566, 0.04645712305641463, 0.043863854145691286, 0.025111404548008597, 0.03729519794785208, 0.09072606917470695, 0.0982855260372162, 0.019751868751500885, 0.0290728394588035, 0.017334279123573534, 0.09115547677802463, 0.022223760606721047, 0.039591366470220594, 0.03798434766189706, 0.04106628873776044, 0.09829512511890742, 0.037581546292189634, 0.04081043069280925, 0.05090682219052988, 0.03003588284275705, 0.024042635284844908, 0.0647892355318031, 0.008934622990988917, 0.05195711341295993, 0.03880924432568493, 0.0009593474286732325, 0.0484105859762959, 0.055855593133357265, 0.016288808509407025, 0.0549071686222188, 0.0273308627712991, 0.05698021786708025, 0.011150687444774855, 0.031308377867624644, 0.020989989411206018, 0.02640659301241319, 0.003951528675726525, 0.045120092784805645, 0.06839318125839196, 0.036793303105138966, 0.08862622217425416, 0.06543256552709688, 0.004972868717290582, 0.03660858015439684, 0.0391920086657328, 0.0427411254795809, 0.053044942943679715, 0.033798427921870065, 0.02559661591095069, 0.0690167308634808, 0.1099378842439863, 0.05024750010981675, 0.021041780785326997, 0.02782451450794695, 0.0067409824095516204, 0.08817681967611275, 0.03700622575237386, 0.016411258088004206, 0.053307006300817576, 0.0132654903967294, 0.05979569441068077, 0.013328123830198763, 0.050574179152928056, 0.09094896245627634, 0.04139398284737141, 0.072758189372478, 0.010959570532694701, 0.04950025028759434, 0.053285525195420756, 0.010704619344323875, 0.04713970739694853, 0.09966419318750983, 0.037682187262802355, 0.018502555547222015, 0.06273115564498209, 0.02727672142247039, 0.11051392107601128, 0.035730697019326116, 0.02028166834685591, 0.0805120563675319, 0.056103345968069575, 0.024052289907910654, 0.03632624994122213, 0.07901334323950353, 0.01626017022757761, 0.03857901958268016, 0.04177688891368528, 0.025628211292167826, 0.03206599285946258, 0.12808928806935588, 0.01972475498464079, 0.020681313434315306, 0.02728874517244197, 0.028771473875930233, 0.019654161897638155, 0.02790024996014132, 0.045322045052964846, 0.008659528478259041, 0.08788332373144166, 0.03622064855129969, 0.032228736747657104, 0.08229888750300293, 0.023724011656257416, 0.062228295531484394, 0.031042338514159766, 0.05851068150913043, 0.014155920136780029, 0.032842982214905565, 0.05077923790762021, 0.06370638174215151, 0.01712820721760152, 0.08672813208953989, 0.042114879244998585, 0.01711190486657283, 0.07940370334132064, 0.045517531539043116, 0.01655988297575424, 0.08869329317202491, 0.026836816499370243, 0.04669897701410998, 0.0680548768310297, 0.030245095709218617, 0.038971808183217244, 0.06369376810447824, 0.01827878509497931, 0.02337491879570148, 0.052066533751184904, 0.028783413356230147, 0.05834743200290588, 0.03240821582655753, 0.05720470461153215, 0.08728680170832143, 0.05365441185272029, 0.03897619020614413, 0.037496062371158795, 0.07056603643802867, 0.015016597894681318, 0.04621110924129044, 0.03580387373785338, 0.07912492394567498, 0.03243086138559926, 0.0521174326328741, 0.04334129025078109, 0.04398418740639764, 0.03886335311577686, 0.1109660814906801, 0.03500667498296788, 0.03748318443315164, 0.0288409810333002, 0.01750773100572969, 0.04170080106104574, 0.026617410833076127, 0.05591369707197432, 0.022332271215535944, 0.016059553825236376, 0.009390825477068224, 0.03498654985319703, 0.010978733264510671, 0.03672530897141945, 0.038511783876005685, 0.02269136152350374, 0.023721606140175176, 0.044914394346696716, 0.014360073950111628, 0.02986459324376718, 0.01376181003457356, 0.06944396277709354, 0.025863294947832346, 0.029006287485601443, 0.02629801920134454, 0.05251769059067292, 0.07018015795056859, 0.08414334377213832, 0.0302438757141992, 0.045275547346400644, 0.0239045383603943, 0.026111252711064396, 0.02593657125778977, 0.05328825246843119, 0.01492362546419064, 0.020837955432192936, 0.05071643785002732, 0.0899370062735773, 0.045355285607999375, 0.038330286155424775, 0.04795253434548936, 0.02498702442784223, 0.03155181762732325, 0.012355896967252897, 0.08646688078560176, 0.04867408574829179, 0.09583447368875628, 0.01075502601452172, 0.07731625164348273, 0.030477513378906636, 0.07926579985407092, 0.05749969059721597, 0.001638347614883265, 0.038629263459194096, 0.07452969108858416, 0.026427909408906297, 0.019268185733967734, 0.0751202529476535, 0.03612588347506619, 0.03642758039096671, 0.039883334069482745, 0.01758202812784622, 0.06349315649018654, 0.03852578030238229, 0.03440005975144525, 0.08211504938381334, 0.04201643311628892, 0.041012811970206044, 0.009959454238865404, 0.03222515911705071, 0.04265313645103767, 0.04364911587007585, 0.028596311702483126, 0.09118789761898019, 0.015298037530644047, 0.027134347812182484, 0.058976125888406276, 0.10224085331203477, 0.02206057621797006, 0.10084720914282146, 0.022989208847584746, 0.05171362768798586, 0.05371827677252793, 0.022072665085415208, 0.025606406514622995, 0.02926898861093627, 0.017080405246346228, 0.023748945902972936, 0.03711464251541803, 0.06964221101013884, 0.08719345389474785, 0.04677260572451257, 0.0038747901271563028, 0.05798444805306293, 0.03617402444022798, 0.03428469074048823, 0.06325186943755516, 0.03870282705212313, 0.03319067504977988, 0.049102715772366336, 0.10246433648130587, 0.03998950619490878, 0.03909668817575421, 0.030052319259172487, 0.08339470733077296, 0.056745802623129664, 0.04519391684762893, 0.03968689763437837, 0.07314741566416717, 0.03941896221330089, 0.09968952005428654, 0.01858461505523132, 0.020858256762186368, 0.031910122695168665, 0.07594732913158594, 0.05458963666892341, 0.04924079545983865, 0.013954490723629153, 0.059159485202643185, 0.026334195788348877, 0.015574682413810685, 0.1153570140201238, 0.07266504840264398, 0.06694486905490199, 0.010889226424267456, 0.029422043402108456, 0.02556621179645581, 0.036042548430662964, 0.10563599411398174, 0.011998573449560472, 0.06553425603816587, 0.014299290618979403, 0.023664379372231426, 0.04308733593432173, 0.032393146877086935, 0.014695597478308746, 0.061582088876034946, 0.0165779166854918, 0.04295282621657656, 0.033403804540754325, 0.012398698299582447, 0.011287437012088637, 0.01736853857554736, 0.05094580457455689, 0.06432104855775833, 0.04807148864793201, 0.0344742706886703, 0.00035006366752279595, 0.009637433967943634, 0.022336191670488448, 0.04550148199702944, 0.03479878170295589, 0.030085789640584303, 0.04108848230492684, 0.13248968178466444, 0.012407030463368903, 0.20116480638182935, 0.16834857212680002, 0.2193849665984031, 0.1492658735162789, 0.08689890074874125, 0.11492548435325585, 0.13752030539176158, 0.10423347098572601, 0.12043206306594996, 0.17126437937540395, 0.13586193954031314, 0.09383791066225498, 0.22495411937275242, 0.14155473890564135, 0.2389697132692222, 0.13052435982371532, 0.18668864042528216, 0.14125962651545002, 0.1560968343889521, 0.17093647842205342, 0.1951577424282028, 0.1708119125255654, 0.1551038771867752, 0.12597024290552064, 0.15960194711242953, 0.1680714628028293, 0.11361356644380478, 0.15617411733875353, 0.07502200217136452, 0.0914454410573648, 0.10708619089376543, 0.188807578336808, 0.1211145631368122, 0.17960745991478044, 0.15842135965583787, 0.06785609999731665, 0.11396027485569639, 0.13343791477382183, 0.13054328219544503, 0.123877689062107, 0.09785270934263546, 0.11295564247355347, 0.12474647873351652, 0.17556407849394506, 0.10376718390973345, 0.15147537834221317, 0.24489699682641417, 0.19268436627762933, 0.14052664891125696, 0.09503016563793344, 0.1699987101939417, 0.10309665013224849, 0.11745066336926915, 0.14626959639210857, 0.08970261401226444, 0.10340394332043587, 0.1744802939074655, 0.2330859894714048, 0.1255394869874562, 0.11885219824410255, 0.1736852478596472, 0.12699460971259302, 0.07649257688993409, 0.11216215924510073, 0.1169388630096951, 0.24827544457249104, 0.32177013555361383, 0.08938027485724419, 0.15803546584661932, 0.15372133363158474, 0.15005309014551102, 0.30587923502729786, 0.1303769185418083, 0.09776291617703053, 0.2409563631179833, 0.14021180209613618, 0.13497013658765825, 0.19664016852696098, 0.12966837914239976, 0.055192138008292646, 0.1319643752949853, 0.09523729283002116, 0.19493133280306094, 0.2139733521448028, 0.12105485424399377, 0.15415876983634888, 0.1916918840499655, 0.15753449030941533, 0.3026297964876698, 0.10618046812352636, 0.11880646279502301, 0.1795092167993707, 0.12404598325731293, 0.08928197811567977, 0.13393476875799318, 0.12250413937914757, 0.270483797235835, 0.1574126363641793, 0.08066635413636124, 0.2472504955385962, 0.1901862914523771, 0.215508975389023, 0.2175650634472409, 0.110173249436963, 0.15762603781636686, 0.0651983647877651, 0.161121329292655, 0.10666482721365268, 0.08011524580539235, 0.14023095429424318, 0.19404100073922068, 0.09133951408007453, 0.135054528833397, 0.11250439370351453, 0.16957814324527018, 0.09828177220638722, 0.15125036299709352, 0.06361084674755413, 0.14244104134699992, 0.20703181414113891, 0.1409221647848045, 0.20625124715508955, 0.1479388100485648, 0.0868196412920952, 0.16168604334515913, 0.17994564176807482, 0.10186175470270457, 0.15113385634556895, 0.16334024167829947, 0.11844412618947607, 0.26314351046758316, 0.12493007936544957, 0.10241391257412973, 0.13100299623704728, 0.19817694090306762, 0.12782094279123893, 0.1148214725957763, 0.1632426727202631, 0.14834491325722587, 0.14099512699871294, 0.25273292715991696, 0.17554344008526496, 0.17615684668623632, 0.12419685661312073, 0.11979653184572536, 0.1441773030185892, 0.18507153606943547, 0.2003891117149784, 0.16064480728199407, 0.3029997863115803, 0.14823974470698065, 0.08891653119316024, 0.1302328633685266, 0.1054710094186087, 0.1519240300741888, 0.15426314165515287, 0.10504334083487911, 0.09421055881126274, 0.09519970855645596, 0.1441230946370671, 0.13990977959286782, 0.16694185083671925, 0.1895415058900272, 0.13515716929349209, 0.21787958850543346, 0.15689269248997012, 0.1738016166153454, 0.06843137074141734, 0.1823268881848743, 0.16105307085860163, 0.1097412984217367, 0.1921060618253485, 0.11214493758856289, 0.14445842664328315, 0.1482281154922901, 0.09547942257936924], [0.02100688356515621, 0.056884564128854585, 0.05859225072086819, 0.06985026516861494, 0.0453910312705463, 0.025404237826625188, 0.032883021800268086, 0.03597065107896924, 0.060834528788203196, 0.0023309292831277897, 0.0455370361375953, 0.005441856253216224, 0.02744315210880051, 0.0423427865720324, 0.03020481863659957, 0.04715610550896776, 0.044917022028277, 0.056151176667622024, 0.0391362949214395, 0.03147910630720998, 0.053082071394929965, 0.03926623875515596, 0.05220808381695421, 0.037151108300613786, 0.04890908321906482, 0.07302250502811325, 0.04439306768378423, 0.036582701704314644, 0.028645879506403883, 0.03601524122660199, 0.011675685584064455, 0.017501136903921445, 0.029872554812520265, 0.04634147442336525, 0.012233892677261705, 0.027587002353562463, 0.02576820236901122, 0.03758344619024185, 0.017717572064289165, 0.10094595021538197, 0.03947707764323681, 0.0943016313437012, 0.01986048278218556, 0.06305651701686364, 0.057554327987975655, 0.040419545820764, 0.02386163169097516, 0.07432773498998535, 0.0553608114170211, 0.04218017674922463, 0.01516198510334136, 0.03561275778338313, 0.023348105718351664, 0.0038338527825075176, 0.018732701766214544, 0.072777877832132, 0.024416940098988916, 0.029338986064577778, 0.09432337291899229, 0.031142418325367956, 0.030986285775959976, 0.009556970795646552, 0.03046424090561848, 0.03773329298823111, 0.04479569285326908, 0.06297577134964448, 0.04902844737854697, 0.08076995986724093, 0.04358787480140886, 0.012076814009267236, 0.07699727561445006, 0.02142697170887503, 0.0715786897607388, 0.025787364143217285, 0.021438070407678044, 0.1120381449319182, 0.03173937318816541, 0.05444589942213028, 0.03000149124061629, 0.0410252072728209, 0.04168896500261561, 0.005779732150145837, 0.037189071787701505, 0.03761822275156456, 0.03154118241171443, 0.08450109917189806, 0.020254958691375873, 0.037772727364133445, 0.036652657023120316, 0.08760727926968567, 0.047512244463207266, 0.013708539153148812, 0.040463875498502486, 0.06581295116413986, 0.02050023897731256, 0.046623831449617306, 0.01792047811191409, 0.01877236788371398, 0.008521592432272532, 0.030009820531573028, 0.05133429159139914, 0.07667878988168894, 0.035806378845365784, 0.006938339586579993, 0.040268377521105354, 0.08824215931517464, 0.01743762055411935, 0.04895346652295801, 0.046422430764763586, 0.10972471261817603, 0.037138712997998924, 0.09585014784768706, 0.02031215290058284, 0.023104932174206744, 0.008990195009016223, 0.007493687256599867, 0.046802873858400894, 0.02418775532034136, 0.023780079716215693, 0.07747397382533358, 0.029259209498582833, 0.054367838893085725, 0.043397341073761066, 0.022796403669241457, 0.018903326783930103, 0.023464275291189555, 0.06912306386737094, 0.040463875498502486, 0.03988936701188645, 0.03543417502735411, 0.061865185177133936, 0.033883750964436805, 0.10156477305797801, 0.014487765485330697, 0.040309550916595806, 0.02043047709570777, 0.006669567693250195, 0.06852497136400593, 0.011259657706344321, 0.04987480982597317, 0.05816505328121205, 0.0551144720145291, 0.03186862179709058, 0.05372096191070253, 0.06802855404995142, 0.03645393381556196, 0.09292125581733643, 0.07450047249515211, 0.05600093916479138, 0.01777361139595028, 0.058320266525110895, 0.04239607947848497, 0.0045440773359469834, 0.03637999483955003, 0.04814088089211334, 0.037560854257354816, 0.059747970963437716, 0.03510882131635182, 0.04194750052486216, 0.037365015370831374, 0.07465843982513874, 0.0400623879695852, 0.030726331075833693, 0.003219325538544405, 0.06746416941525475, 0.055461371948401776, 0.05293411683411368, 0.05542269216910486, 0.10249327162220594, 0.01551606615389427, 0.008060110642785027, 0.05377127856556928, 0.050674475383974855, 0.008608217824310547, 0.04856491821908182, 0.07644131028604123, 0.018966891014227466, 0.09701250241168084, 0.03159671804056533, 0.01990478756206651, 0.02766999265839977, 0.0500218412508407, 0.04827300424597437, 0.06600387559662904, 0.014601275775461428, 0.07043121262423455, 0.05635648057044995, 0.06784008875969919, 0.0376186594216814, 0.022925866782785426, 0.04141412712934037, 0.046643420317841154, 0.03017772210671777, 0.013111543113125429, 0.0040994025579082875, 0.060518325997456435, 0.10791435492255035, 0.05028563596668744, 0.12324128450164873, 0.032878854281959996, 0.036722336550273245, 0.0470629224042979, 0.02883600146179238, 0.06017842427677205, 0.034333869754787416, 0.06668510396153697, 0.062364203359691374, 0.09555418509989978, 0.0415553247946645, 0.019924870557001522, 0.04201345686470309, 0.06631935826472699, 0.018677112511208942, 0.0592918920090362, 0.04952530519315793, 0.030455059341845975, 0.04591045803540657, 0.06656559424534922, 0.06754368934179507, 0.046359948633659276, 0.04856018379570977, 0.04326302670843659, 0.03497323524507304, 0.04319279176753856, 0.061269356463585174, 0.035400509293521606, 0.05259555576729679, 0.056868116221120285, 0.0494161797987838, 0.023078527038676605, 0.026629300517660957, 0.04763320591601153, 0.035360887226077824, 0.0943188300176013, 0.02585347370064307, 0.01611873315977714, 0.03400378545085269, 0.02745096620562817, 0.02943281459832384, 0.02230871975752375, 0.044882816202457876, 0.025047263836548216, 0.05543706014812474, 0.06725721842338962, 0.05076718734457128, 0.026880954655127662, 0.03232898701342844, 0.019309650242869413, 0.008070994836969242, 0.03606472284563127, 0.043617982056833086, 0.08970751697497983, 0.026656149984187177, 0.012651688302867116, 0.004772542949555623, 0.06064791743072772, 0.025667756750819185, 0.048466755542904146, 0.013144928267255667, 0.03443587053146574, 0.05820766309156053, 0.044068162134217645, 0.04509988721580275, 0.017756726818099137, 0.05245357669228989, 0.09567030104658297, 0.03941105618592232, 0.06527456755359327, 0.07402374364075161, 0.024669103684925267, 0.02772815022317152, 0.06914554088706933, 0.062304452332037116, 0.023541686560718283, 0.05214362134856563, 0.03132312889060667, 0.1259769155313411, 0.04829419423795996, 0.039069369480374365, 0.035398544277995825, 0.039627288332990104, 0.03618522847612058, 0.0829234789876688, 0.08897863794118167, 0.04074529789748692, 0.03414211794734001, 0.03345263881548759, 0.004348942292703977, 0.013413072447292508, 0.03056501019595852, 0.022847199129060875, 0.07378133809975079, 0.09024486636682864, 0.010933590575962538, 0.045281204905721455, 0.043758777525996974, 0.03201832112315441, 0.026217836608749726, 0.04739879833294019, 0.03969837746192371, 0.015655045037067706, 0.05900808324616763, 0.04999178762157118, 0.04311983338406971, 0.023691483562992468, 0.024678900034257004, 0.04419660060516289, 0.06813982832095317, 0.04258935197046207, 0.015178848613774585, 0.016803730677272526, 0.07473353942435595, 0.08498826214382726, 0.04486906875465666, 0.04758743216253577, 0.04909593206379683, 0.0224628777153069, 0.05193525692448021, 0.044936342765727354, 0.05662162360104342, 0.01830554454617443, 0.005880094456276106, 0.05578419756925395, 0.0651169526240518, 0.04768154606403363, 0.006434482601170819, 0.04663643742641134, 0.003916117937243994, 0.03229312643769287, 0.035784679404910535, 0.00945035816966406, 0.052761095876414935, 0.02664689564206187, 0.038747869191631194, 0.07380420582429056, 0.06604624025884175, 0.028911355785244418, 0.030186781096422387, 0.024655576487402284, 0.009600734525930979, 0.06155853550280295, 0.05197736494723828, 0.044055717035887704, 0.034377061791958353, 0.08439472020273248, 0.036472086268927784, 0.04911479314849262, 0.043852527535730795, 0.04806898737085923, 0.05728759915537893, 0.040621632154309945, 0.032664349663161465, 0.116280441082293, 0.16207801989249646, 0.2311449218541384, 0.13059280211887053, 0.15582357082636128, 0.17827285814189142, 0.14681667510059573, 0.16391166666102025, 0.1774508151556215, 0.11569417697647888, 0.13993343638796962, 0.22173362363490368, 0.12393415740300572, 0.13771204187745048, 0.14441581683293467, 0.09477584742971006, 0.10664015918249085, 0.10717073635708903, 0.10219492634097416, 0.10073444866124662, 0.17983210753769646, 0.08151953093587391, 0.17180565113742507, 0.12297590398379873, 0.1317417654659479, 0.11801313278415512, 0.08456146690033137, 0.17722780696086346, 0.09228719548592645, 0.20879252933927123, 0.1825724193646062, 0.18751144949947635, 0.14534448393650595, 0.1401492739997564, 0.09145408252915067, 0.20197448470900137, 0.06040235560747886, 0.1563783563793667, 0.15810527177827974, 0.2819359536853529, 0.15239417823331972, 0.20470687518677405, 0.1602040768991555, 0.2303373272861204, 0.2431289884712427, 0.09903136625765793, 0.15384216101900225, 0.21260622227864884, 0.14334456544489632, 0.16608124298434104, 0.18499347170995128, 0.11638305089887112, 0.1345226799528445, 0.17295216300314473, 0.07459910631540322, 0.18730796122502896, 0.1702985263639881, 0.15430060335465018, 0.17323193831309197, 0.15768950054001424, 0.1068671050691797, 0.11494410028981586, 0.10238213524703058, 0.11703510663562244, 0.21855933832064753, 0.1433599331686574, 0.17702116240416804, 0.20244259507425372, 0.14489797725071832, 0.09655836549016739, 0.12856922683215913, 0.1575249601756373, 0.11162376797367489, 0.16377547154984168, 0.07738177514364643, 0.2189860186509548, 0.10881864510837103, 0.131970549963655, 0.11809989224157988, 0.13410301698792365, 0.12996623412736003, 0.08466652053738795, 0.11815167978526124, 0.12407592197339382, 0.15796607360243797, 0.13734819607869272, 0.16543946048665434, 0.11831827326527528, 0.10532034290654045, 0.16413822950374696, 0.1177637328604056, 0.1230406154307627, 0.14489158807742983, 0.16504228986319036, 0.12356425184876689, 0.16049978683792776, 0.09611241804856448, 0.13319089738351683, 0.1533546686292656, 0.06820327572284207, 0.1500798419358269, 0.12565856769440636, 0.08820220782992341, 0.09934179274545563, 0.1222157838844484, 0.14541499466905672, 0.21716913388621426, 0.1825636706405109, 0.10650663771816801, 0.16027421990950264, 0.09528085258939574, 0.1647047208802354, 0.18070583081533834, 0.13552715911740257, 0.11044030768736718, 0.14761742084257065, 0.18164499332347225, 0.0702521778763302, 0.0991554571796329, 0.16956423108856525, 0.14421439699588284, 0.07875756180334477, 0.15070775824208416, 0.17361964008981184, 0.11289625533766325, 0.13405758797401382, 0.13615677613885174, 0.18990015761265833, 0.12691722717136145, 0.1332185071923079, 0.09127415145837492, 0.18786452410201873, 0.2807292732740602, 0.08148458966564748, 0.11993183063403254, 0.19889804414443432, 0.12422757673888438, 0.18563844113340303, 0.11972027545374249, 0.1367920162456651, 0.20440649211166367, 0.13090125976070283, 0.12641923171618294, 0.12657316942368785, 0.16993457331292092, 0.1196991773923078, 0.14857552104419278, 0.20039337116383737, 0.0947792028948184, 0.16793725952025385, 0.10554230922172148, 0.2191261361323057, 0.08106698747724295, 0.12877176515758038, 0.10572660699366562, 0.08814181711885237, 0.14746762000985686, 0.10578253907301735, 0.14758996425136445, 0.10454555988431939, 0.21017899526463402, 0.19816635356795406, 0.08074231175405365, 0.043461608189728954, 0.18211100460781207, 0.10700606575776493, 0.12071962182920788, 0.13301227632309162, 0.18410094863464757, 0.12310155772513921, 0.11576337003779989, 0.10501851958613242, 0.19145897799922576, 0.1384029152893251, 0.1467059907172957, 0.13975931992453916], [0.041425729530953595, 0.007875734346828634, 0.021479508103502375, 0.03029566134266075, 0.03542875878572945, 0.03011436280494015, 0.02392803427703198, 0.05668573749942645, 0.03671339247375727, 0.10235994934074341, 0.08814913325852926, 0.009497359579038477, 0.07924690812585816, 0.048016318826064955, 0.036727971126956326, 0.034751954578584245, 0.019529124857076717, 0.037453326156302806, 0.03855135614773439, 0.04415500586131408, 0.03943704954919316, 0.08527361457386325, 0.049669119048743486, 0.07166380212912637, 0.016058343406316015, 0.02478407241494185, 0.0443916121167281, 0.025491445445485657, 0.029334686396102753, 0.04339274454621538, 0.06685649315195699, 0.02828478204807447, 0.08123823111095736, 0.047000742877923676, 0.046790742856119914, 0.006710910585693896, 0.03813596412299141, 0.04269167067362897, 0.05744965739488121, 0.09257016538251793, 0.009173554323253133, 0.07403483659389519, 0.0927058931800627, 0.04192202427094022, 0.009582954582818335, 0.043919989238342935, 0.06329149533543857, 0.01465312077573711, 0.06232248221133506, 0.019826575730656906, 0.01669457272416161, 0.008440872620520814, 0.048014326997461824, 0.06090021699727063, 0.0668466872265262, 0.05002027843147517, 0.04462648318299363, 0.030792624494361303, 0.005592443283662321, 0.03211369906972734, 0.046792895563187144, 0.017417776961660674, 0.041543281892494816, 0.08578184496371016, 0.03494388258625423, 0.04819088728137074, 0.03968378348696617, 0.03768841938806638, 0.04489928326239029, 0.025437901645237883, 0.030887280403065587, 0.006317362121696915, 0.041754124611015284, 0.04035149423045017, 0.0696239321522655, 0.02974616754199228, 0.03266089077618334, 0.018070330655562784, 0.05361073718015706, 0.0719990958309462, 0.04138550608448925, 0.039399066909907327, 0.04076945648017911, 0.03453788279946293, 0.07962288109645729, 0.04665509549780719, 0.07286076854553915, 0.052832640827663487, 0.02359509821079912, 0.018319703766234943, 0.021274838138431795, 0.022653882587028128, 0.012423045531425987, 0.0613973620948532, 0.041536839093051614, 0.13786676099463818, 0.016630529688911575, 0.037631981690684636, 0.03574844727653169, 0.027507438376966505, 0.01870556884715634, 0.04091290644400063, 0.05624823234674912, 0.021105429285296032, 0.01680549076427856, 0.012163216278197305, 0.06366138173747929, 0.030204121496588476, 0.03010209199161299, 0.05617855665003581, 0.07827275838222235, 0.008355144508964112, 0.02907459188493029, 0.0039001880964684875, 0.10221710458638207, 0.021924664559323463, 0.058852621023693395, 0.025707043654796098, 0.03247041833556948, 0.06880988712392508, 0.021416757841624563, 0.013815988730188581, 0.03453261977542312, 0.041396966759836486, 0.029728827141826192, 0.09212266278242873, 0.015700670361008136, 0.02232762489227518, 0.04562335892490322, 0.014850519608796365, 0.024324971243679046, 0.03131254921637235, 0.03837198432114336, 0.024222106702866095, 0.057998823692962054, 0.025964035509875225, 0.043693824761336854, 0.06280916254787196, 0.06758980783483676, 0.042671901774742914, 0.010007722566144602, 0.05034843602428033, 0.041332998418159066, 0.025173727715868625, 0.03203181576194062, 0.06567815799386272, 0.08367688049592319, 0.033672617132505106, 0.03779369136018138, 0.03667683858845023, 0.027549588534560417, 0.02945576084687585, 0.07310458368832067, 0.01001757637207066, 0.057810316267873973, 0.010175443153017232, 0.046815407056842125, 0.04311817480371364, 0.08386716907543522, 0.03980762543036573, 0.03553003943975895, 0.02400134697616581, 0.055038575683870626, 0.0077252119550511485, 0.09268972872486038, 0.011954927505294402, 0.04177262180394704, 0.02338943041620716, 0.02007610205891392, 0.007728828847663658, 0.038249931193046996, 0.04573053079507044, 0.02568380246239324, 0.04600064573629249, 0.04627941747105891, 0.038065733012533, 0.02487330825158185, 0.0371674872604349, 0.023355138405496557, 0.037745332059961174, 0.03186474730741353, 0.03534435887911147, 0.01182198060691477, 0.06710820666123783, 0.024897688999772075, 0.016050318635309178, 0.029766798289793155, 0.03006502291217687, 0.0772705008726447, 0.024730093859797044, 0.038456368906002854, 0.03790111603936361, 0.036156986644791986, 0.04027047660201788, 0.09656508408126332, 0.008796057795294592, 0.056586211186743555, 0.12131088082828831, 0.023909851180149183, 0.005384826752912975, 0.019241487569806558, 0.048696800255246704, 0.031057133587197434, 0.016859892583001527, 0.0609992376919235, 0.037180476281191074, 0.021364489577770717, 0.022574335847410466, 0.029790638945996765, 0.026262185438686324, 0.05136592336179269, 0.009463683311497013, 0.04351790416084471, 0.012863078774253448, 0.07998852720183712, 0.06250062829724724, 0.05066304152170497, 0.035958589024601445, 0.029356684610848467, 0.004088414463049342, 0.07734433642678684, 0.060749378115419424, 0.05251343497225354, 0.043293624260132356, 0.07344587585858761, 0.03929159243501002, 0.04619976347913185, 0.031210167310951702, 0.0284051287153195, 0.046907816412708456, 0.02763257692417791, 0.04749390048786037, 0.06906125589363998, 0.049026520667417396, 0.05883716136938142, 0.03608848689304244, 0.04864587456048016, 0.019523769902485996, 0.0375231589010406, 0.054497399682840036, 0.04436453856948403, 0.06923900361383153, 0.056347459885141546, 0.04175547675620164, 0.03567565360196656, 0.0995624950155616, 0.00650229718303308, 0.03106113831182161, 0.028846646253500256, 0.022295276829672438, 0.008937418254302635, 0.016828199525574045, 0.0973937077628028, 0.07366044942529933, 0.07610947930163915, 0.029127097636040662, 0.08317169147513567, 0.08900186572704585, 0.027936248431703257, 0.02325091980427744, 0.10227048559294594, 0.025544839858588193, 0.05764119469770982, 0.04206855773865696, 0.042516926018100594, 0.07076585515131874, 0.07176600591910463, 0.03442712563781008, 0.017310710428583048, 0.11071810649046976, 0.0469797175948418, 0.035624808346432064, 0.05373855128944401, 0.015365041495721429, 0.007317501876968891, 0.03455468693808202, 0.03048691710817718, 0.02484640898934055, 0.04075223482364128, 0.040585059116804795, 0.03897868765277728, 0.010461993553044816, 0.03930074335526555, 0.01713266393410102, 0.012180753946003896, 0.07220429248146473, 0.07354979568551626, 0.049432363406184225, 0.05474992141488099, 0.022957542603234612, 0.08897639330356352, 0.04634112202292008, 0.0254447236582036, 0.05563862937232179, 0.05354031071727795, 0.0702358218991468, 0.07713737777404248, 0.03998137417159254, 0.050525907952819145, 0.05019634075823331, 0.028454026192306515, 0.02197882122991066, 0.03566452234442677, 0.00330463373815761, 0.045064854015025406, 0.032442168843361645, 0.009496933442630596, 0.06042042762161263, 0.08322709495381964, 0.046297485654753064, 0.07703723476058053, 0.01945224984909498, 0.041275660567466295, 0.08634223828032132, 0.028864450136860533, 0.01867753960522673, 0.049017047990233674, 0.03036977077323583, 0.013473697772790349, 0.0263735382337003, 0.051325676932690606, 0.03946437973589186, 0.05315092737756429, 0.05383099128882732, 0.04427380311573225, 0.04745143240377788, 0.030936735209017515, 0.031827419673302965, 0.022539446288118922, 0.020067537195920464, 0.039422168291264006, 0.03539783947710549, 0.017540272505533312, 0.013300743847784978, 0.06769412602748602, 0.05716370358582466, 0.048995398345493504, 0.05122691287749237, 0.12090099314528129, 0.044633929557617635, 0.03646495015991311, 0.09557250226216932, 0.022459589282891924, 0.10351095814257862, 0.019475452737101627, 0.042959881886359186, 0.03557879327526016, 0.01930341045672615, 0.013705374252411627, 0.014624883732458037, 0.034303950190904646, 0.026820219204490705, 0.14495534191448844, 0.07967043983479662, 0.12929757726528954, 0.12863990610405324, 0.0904094603573603, 0.1813884611211477, 0.10591334092520899, 0.13705414088983692, 0.1298860706869633, 0.24182968802990454, 0.12878976822380098, 0.07409120534336375, 0.2747815198475315, 0.08786205713066363, 0.11051854058619469, 0.2746289457765318, 0.1266162925129456, 0.09669025518721151, 0.2154963962253063, 0.09217600548459638, 0.08957969520481364, 0.2166545066621996, 0.24762598587380302, 0.1112847051192676, 0.1340513520183102, 0.22781358851540476, 0.21096734570399409, 0.15472216621762322, 0.1612616612786247, 0.14851927486879213, 0.22132647854666557, 0.10335804699289222, 0.15414553183701732, 0.07644122601636956, 0.12447081731572268, 0.0706673056007393, 0.1956893461606195, 0.11860390148696401, 0.23627538203952775, 0.2216454622365775, 0.10057012280148846, 0.19166055105386243, 0.3296795643625721, 0.19663655259195836, 0.13398563699616542, 0.17786304706767683, 0.19138200148459406, 0.103648409637953, 0.15568996509236677, 0.12729138451358005, 0.12282403471368937, 0.1416298768092548, 0.09810344992025245, 0.19617740545542012, 0.10138365455091962, 0.10716825423221435, 0.1794033128047182, 0.14515962692037707, 0.1352884307984383, 0.10585914020456615, 0.16887538014881073, 0.13403307316043686, 0.1143535154481088, 0.14610304887737, 0.21989113621173367, 0.20892880105924225, 0.11212934769930379, 0.1320159330122894, 0.1511520892381668, 0.21750035966115616, 0.11651066582529776, 0.0975456000155499, 0.11915371512934086, 0.13883045363810756, 0.16775057921486516, 0.14949156301877192, 0.13695571391332534, 0.12410163954501191, 0.11364168953150512, 0.12292871296766306, 0.3228129344361444, 0.20653358119870388, 0.11420304045802164, 0.19962524544567833, 0.24581619508324132, 0.22835752626340236, 0.16389787707838321, 0.1228066981439629, 0.1255899721816663, 0.13438496798757585, 0.14023666931015832, 0.18404657171378214, 0.13860625034618762, 0.15947621676229662, 0.18274526412208236, 0.205916972350209, 0.13915427900370092, 0.0986519382305203, 0.12077894001718491, 0.09799286512838257, 0.12661374144015775, 0.14544635830867678, 0.12116020665534082, 0.1439065369026315, 0.17701651991134693, 0.07921257972597115, 0.1323689922930733, 0.0954373030652923, 0.10892555267820436, 0.17022993085124802, 0.18924555080311914, 0.11107705698739137, 0.14512901404692283, 0.08299873180447087, 0.19347883009862518, 0.1679055588019471, 0.14876138929638172, 0.13861648528085602, 0.1943900916845568, 0.21632493563717414, 0.10580458708347813, 0.10581380312120724, 0.10902176566061475, 0.16923298999186487, 0.092934746625683, 0.13146677054464817, 0.11186769802964504, 0.090893168272751, 0.0810989793089609, 0.11068306562881317, 0.21659645251929763, 0.1787595691219453, 0.13157242939116495, 0.1614421362718267, 0.20634621141418336, 0.08780116846244182, 0.18295193932229475, 0.20613582834841745, 0.21218655931372798, 0.1069683665710111, 0.16978849566751913, 0.1546248883729981, 0.12882310837026567, 0.10402216095357172, 0.135288231615578, 0.13720478441926742, 0.27473129512321565, 0.15007723723688435, 0.09582249973449977, 0.09608744358223292, 0.11467621466445346, 0.11379434787217649, 0.1329906573218684, 0.07966457160129663, 0.1319754682481289, 0.10780583856807602, 0.11256103058375659, 0.11864243570955531, 0.1516731669225039, 0.16817873043398704, 0.10904991939183205, 0.20056656832175873, 0.14998043436677228, 0.20774122688078112, 0.1665522338401887, 0.18452890067090913, 0.09869735958355089, 0.19991813618088924, 0.10381974520221834, 0.12255528340897254, 0.11174807340026864, 0.1061857388084454, 0.08847833656135107, 0.17522839408728386, 0.18317507009112066, 0.0796142932508261], [0.036310698356359236, 0.044494378981330705, 0.03070688010343621, 0.04509623297640393, 0.029180752519037456, 0.017787686346339125, 0.03782954427503771, 0.02035779258867185, 0.02283727446000182, 0.004849290595419946, 0.03605842177245406, 0.013865033679101017, 0.005563988862934733, 0.06944365634192383, 0.02371096326368711, 0.012326327888595482, 0.06954076564720563, 0.022636955874341152, 0.046561123322575323, 0.09810133551758143, 0.07539799046372214, 0.06039268374743481, 0.05259243395900535, 0.02664384278168361, 0.05387395733006058, 0.10355519205932656, 0.011856394234083354, 0.011920542606422979, 0.028260874359177488, 0.07459152204495284, 0.02723231130549985, 0.032090341048916025, 0.026708581041724935, 0.032841112960370324, 0.08117540424028713, 0.0368988317167086, 0.02877616233402683, 0.027332214916485454, 0.05559769729452749, 0.02293964104366399, 0.03542237727332019, 0.007899630065601801, 0.06307006528180453, 0.019195122013409293, 0.058396522917093775, 0.07700893547265761, 0.015332605333007393, 0.02161223666682359, 0.05375031456952134, 0.05128748744966523, 0.03930853063901586, 0.029664617482452627, 0.08177802432328463, 0.05946751383523788, 0.035188283786297805, 0.030235255309831233, 0.046361844701271866, 0.06586327547988584, 0.05760816864729409, 0.010641980165195082, 0.05489118802811831, 0.018703144178875995, 0.026935835278803305, 0.02991867713600157, 0.0504802261298943, 0.019408038914984754, 0.01721654098571068, 0.08965996589751975, 0.048866722387291735, 0.03260169516227419, 0.024845706103670023, 0.018503832998835755, 0.04702839099111096, 0.012838153146027077, 0.01616161876177836, 0.043453805584220156, 0.06559945012052214, 0.006917715542048457, 0.03602785103383564, 0.044579874393680406, 0.01237999426291114, 0.04728624852554453, 0.0006482797013426711, 0.03679585417792682, 0.02550702767386552, 0.05464673703235965, 0.04820849198187071, 0.04351272540647657, 0.12345008176541138, 0.05561889111695271, 0.15657318786026972, 0.04278759254262813, 0.09078519584070291, 0.03450549643246397, 0.05120419070965821, 0.008551586689727922, 0.016189192181393024, 0.023491262653542143, 0.027274116723527832, 0.031563647940093954, 0.056651838108777046, 0.03550072508533636, 0.06780504023716336, 0.05611470322154703, 0.037858272572198225, 0.11078690118607014, 0.06221422249631536, 0.04298642300249588, 0.03353147692377529, 0.012537065270026366, 0.03195992607112614, 0.05208405801245282, 0.054793921674812035, 0.020257069263607264, 0.07626233682517083, 0.06065640568492874, 0.0466995707322513, 0.005975876514229083, 0.05479106799729409, 0.044833238822438067, 0.02914814398654046, 0.09339522675520952, 0.11324246579240407, 0.039256712451817534, 0.053458320157181834, 0.07271134309590825, 0.042977930917855234, 0.046181415673345334, 0.05823757116412444, 0.05837942000418421, 0.06408592851291742, 0.028650386018618464, 0.029559678758584687, 0.028200818811573332, 0.018431972036318436, 0.029120384790604154, 0.0427433279823632, 0.056709559003431956, 0.060339827511099085, 0.04889982121606027, 0.0342377410420487, 0.03174593856167649, 0.06473573195117135, 0.019322309845818147, 0.04865896317266649, 0.03668808092873904, 0.06550720547355952, 0.022343638045112454, 0.060907219040898554, 0.03802325726757127, 0.09457611298609166, 0.11288733041334538, 0.023556458651118224, 0.05805172589457324, 0.032188819736362465, 0.01497990324071819, 0.02576840155187153, 0.006100555887490872, 0.017112896950434775, 0.018511095512357932, 0.0368502579118696, 0.01847248851141382, 0.05181227299955584, 0.06384353829367508, 0.028181038421368407, 0.05599044759066836, 0.029850351669254805, 0.0815949829355363, 0.03658746677120367, 0.025155287979531194, 0.0998813025052509, 0.05791849937410124, 0.016259526713721214, 0.014139978804685658, 0.045978046142526215, 0.011897225762837598, 0.0659181580187813, 0.010955578256999294, 0.040717511888473265, 0.025481195189058784, 0.018816716713650573, 0.04170366239944293, 0.05663082048657441, 0.035347120626078504, 0.04273389744001531, 0.038947630448326956, 0.024684532695720275, 0.04187472600249514, 0.05304917174902174, 0.06706260910798466, 0.028137490153312687, 0.04318390131717728, 0.04366253773050924, 0.019679818182222305, 0.037496751850290645, 0.04747625748296419, 0.03888978697960416, 0.07408390452544536, 0.03754912545123408, 0.035011581776122895, 0.04771548758951887, 0.041978699455578486, 0.020746978660745007, 0.036750126389726516, 0.017653394963652376, 0.056816730873599175, 0.05545472613565865, 0.008287972962153296, 0.021119532963982033, 0.02753962747632496, 0.0192582648953483, 0.04204117775624318, 0.03761490559085243, 0.01646327162762323, 0.08612449310960309, 0.017341210304068464, 0.06147953268561152, 0.027544660673987482, 0.042636998808912696, 0.06806861278751204, 0.060952303315242456, 0.035835313986265854, 0.01769466795057299, 0.02649142001304896, 0.04513479401207259, 0.042762035849474134, 0.04802072000118995, 0.011112865683953128, 0.024585498594528726, 0.047794509558908405, 0.06753153918731598, 0.024468264159476085, 0.028639597585424784, 0.04359022669133641, 0.08844128854933286, 0.02401314473019973, 0.02970352325768721, 0.05344170371010419, 0.05142690396056541, 0.0393730926988346, 0.030512489123089664, 0.06209498857178035, 0.024324597775815957, 0.014643939211964609, 0.007575810445667876, 0.057237474022493254, 0.04526880960310659, 0.03222273827920998, 0.03447468054570979, 0.0423554040401453, 0.03981191935318132, 0.02303234725860098, 0.04867738375680582, 0.07876958172287672, 0.0015827884048884436, 0.0722304160796827, 0.030080051642031442, 0.045428776422575604, 0.03359843683879703, 0.05882739374834684, 0.03754067167098965, 0.08125162998875303, 0.00605308477045788, 0.07246873071116787, 0.03620726882570213, 0.04774506241383572, 0.06013821615206619, 0.03717696759849787, 0.09534413911282055, 0.07330041874440447, 0.08548774380957888, 0.08066607068382925, 0.06966350825443383, 0.020299301775653037, 0.02786490649375464, 0.04359562761120258, 0.03052509701510351, 0.03095745597214949, 0.037979038672581795, 0.028318438205807924, 0.03309745364071381, 0.014681316641790253, 0.012272828138403356, 0.05875806662163908, 0.0218442406490325, 0.005605763158640795, 0.011460981782405608, 0.07602578419591151, 0.061165149353684924, 0.05522171666304912, 0.037395815935827074, 0.01712590703860887, 0.02614475182077337, 0.07365390703442597, 0.024815056841039372, 0.07620032966857956, 0.04520738850377741, 0.06001176184884483, 0.05674865630064761, 0.03006417830024035, 0.014981633641817158, 0.057669298633212046, 0.08356242696003569, 0.07941123398561632, 0.041389183306525794, 0.09974402721009909, 0.08931121969174954, 0.013982184802091891, 0.03540438186797885, 0.03382212302136806, 0.09399750209864109, 0.05821636968081998, 0.00374699157903031, 0.14399589339811958, 0.06921917725835117, 0.04141602702739258, 0.018765421381460565, 0.0717824308442012, 0.04633930256409992, 0.053097224614072236, 0.028798516779657335, 0.008321356201063721, 0.018159865266493252, 0.05081321773750167, 0.05251949855817422, 0.033546132185766776, 0.011271398961393824, 0.08363767211595852, 0.04460638869673975, 0.050752099242902575, 0.03709042264569191, 0.01191694007795905, 0.016840305629997485, 0.06816212914042896, 0.09322916187586323, 0.040268706938912796, 0.03772886883046839, 0.024524987224609624, 0.020009663083680698, 0.07701282719931296, 0.012629719774028467, 0.019100617407070055, 0.018747619413320097, 0.041303733859451554, 0.01842475165763209, 0.011778461067156206, 0.05544825269269848, 0.01902221979933881, 0.008414669540680705, 0.01819982249740391, 0.009503250795176194, 0.0187571054970425, 0.12109014791466537, 0.07808836101884804, 0.11424507570242691, 0.10229955096879315, 0.031044659760570338, 0.17595000294668062, 0.17195257147954357, 0.2806104070717289, 0.08602586695023122, 0.09587704519470854, 0.11631195793949789, 0.14254611796669422, 0.08882872985615846, 0.13122352230693066, 0.1139124556474628, 0.11749957042235522, 0.15170515875422186, 0.21715056391492968, 0.15571797326687845, 0.18128853261230454, 0.14267154188165743, 0.1757397271332241, 0.12095245893203443, 0.12146844213167507, 0.15210202294251612, 0.20204390759669966, 0.12304662156008905, 0.16061664588989752, 0.12871545769514578, 0.15854908183457392, 0.12012715241120708, 0.19072465208028594, 0.143711153838423, 0.10423786833041138, 0.1341245900238714, 0.1076788365119888, 0.10962524376208745, 0.13478861971487924, 0.11472267023618184, 0.0806534072504409, 0.2074626160244788, 0.12868660682391736, 0.1400160666314825, 0.19228885040408183, 0.12601705087769416, 0.24139785958874613, 0.13833589791770906, 0.141781899296949, 0.21495558411603977, 0.165408939543751, 0.15292044999378343, 0.09806838607595814, 0.2527999138880161, 0.12563985982729545, 0.13332361445551918, 0.08602879340610198, 0.13713833395271532, 0.16467902629125505, 0.12636897634835015, 0.17359391485731449, 0.17443861872438463, 0.14473431022657504, 0.1421242180250345, 0.1139723560622623, 0.1578478662357215, 0.20684974568505443, 0.09235799733188846, 0.22723442604464872, 0.12673296004293427, 0.14179542840969178, 0.15907714624078045, 0.20827209516879053, 0.1549817627716449, 0.20302165029270036, 0.1306331902742386, 0.3106547819991266, 0.1500142648095085, 0.12955133622932818, 0.1001589251081309, 0.12530566929208656, 0.14158242532322485, 0.15222318740862031, 0.08419348422678248, 0.16799824011902656, 0.17976139762228538, 0.18015672963473106, 0.16645549225711054, 0.13832308892761508, 0.3179602577320991, 0.15759855058164368, 0.24709234434750774, 0.20361067997592114, 0.16414990468371302, 0.13043777656651315, 0.2076358438259171, 0.18289244493409512, 0.15447652778558194, 0.14935374380119387, 0.1304312188538813, 0.14628790589349885, 0.08712912549174602, 0.18131750605760083, 0.14094361524668433, 0.10044575608786076, 0.2031389383539077, 0.16756843414998826, 0.16486201405284867, 0.1061123935505748, 0.1398539164614293, 0.15144242123971063, 0.11396641121996988, 0.15769034323673095, 0.15755854547023773, 0.16469721321857747, 0.1616693579501683, 0.11265772620155928, 0.15525092010296163, 0.17716150971189623, 0.13103206161289446, 0.12675724503013397, 0.1739998954919077, 0.2046184379967951, 0.1346796207250126, 0.11557525714799283, 0.09580645785336533, 0.19254348270835417, 0.2577877591454214, 0.24701354454361626, 0.13480864525321992, 0.1562362164258957, 0.13459027955128303, 0.06433839278836405, 0.09812260977923871, 0.21639259652264659, 0.1921321547800495, 0.1716095939158432, 0.12430597817705524, 0.20163296271235714, 0.3365602596632896, 0.1332174653127309, 0.11874195819179859, 0.13493745527680845, 0.15527974033067304, 0.1608938011791437, 0.13542559118040148, 0.07096655486572175, 0.08920681722942861, 0.14840521969862525, 0.12486852420073365, 0.12770123389219085, 0.2598507726384748, 0.2539010273833429, 0.14250432020954548, 0.12580469896596286, 0.07402388153657799, 0.07790780175597438, 0.08524841028115443, 0.13975954975091642, 0.1586615435418583, 0.074061933123777, 0.12333503834182218, 0.10030360847351052, 0.15078258971052785, 0.1898914854973555, 0.073163848250143, 0.1678586282557057, 0.11663634254927598, 0.21409335215726208, 0.10128102175170377, 0.09557288530613146, 0.20363275862989888, 0.21758959358257635, 0.06024471386486004, 0.1388944832668189, 0.15244175229341755, 0.09424347760936908], [0.08373311134956538, 0.010460208568181242, 0.06898715220872434, 0.03541681547498992, 0.04547052055356964, 0.03539554887421189, 0.04497041835659935, 0.033441568844981735, 0.05724407770040055, 0.026903866429723082, 0.04099630660587742, 0.06509657468526595, 0.053687571968522765, 0.029347466657899564, 0.023618337487982168, 0.0307138400122283, 0.028485548795170845, 0.03061201543577256, 0.06351415496019107, 0.05166375919455483, 0.04635622544634727, 0.04032051746523188, 0.02083957570815279, 0.024031680227527698, 0.022490098734476396, 0.02119627582179683, 0.029083474674412323, 0.017759720306663264, 0.03327143220831791, 0.0318807776972291, 0.03328396540675913, 0.03070170709472751, 0.046240427426152655, 0.12264851630935747, 0.04776060250737975, 0.013796642137270783, 0.012386450468893013, 0.08706880372858818, 0.0786070714914991, 0.025319012460268797, 0.06298228692744048, 0.024246364876988436, 0.008442361703923634, 0.06296651317707955, 0.06542413855992979, 0.02176566684107867, 0.04093780430153974, 0.04508565330216962, 0.04142283371859982, 0.08740040488661298, 0.035395897444217436, 0.03832237246716696, 0.020042848097340717, 0.09096755541019863, 0.05600950402778484, 0.013704905981167912, 0.01935711322021821, 0.021361752728661223, 0.039902539893744454, 0.06631247879516694, 0.024376170814878518, 0.03882650811705859, 0.026099698189946435, 0.059343641248321345, 0.02316145988691959, 0.027281170478090647, 0.04321939034026958, 0.02286442653125813, 0.010655348399473775, 0.017114735561453046, 0.1099348045705307, 0.02781680191776926, 0.12211215517093098, 0.11116580061254003, 0.01810045131752568, 0.0490499476361419, 0.0578065432848469, 0.011046203585611957, 0.08935916147405103, 0.014160806820127032, 0.05063180428659243, 0.07254484920732437, 0.05114128339975592, 0.03979924825891372, 0.02427486143255186, 0.03709840528186291, 0.03736308865970181, 0.030251308682284532, 0.04132175990830987, 0.04362894094458992, 0.013468528594521266, 0.042241429309210474, 0.06192623472381985, 0.031927668023854494, 0.012016644506084343, 0.07132703753849191, 0.015480314745687911, 0.0252390482027324, 0.01597419343588333, 0.04422725944389259, 0.06885002247027813, 0.0962581969196758, 0.04844898996394008, 0.01703170503699972, 0.018825162833015767, 0.024860179419779492, 0.026941780121095722, 0.07581592206993411, 0.05993389667222097, 0.06304274275598508, 0.0789628503844142, 0.026566383631659612, 0.019492358382370685, 0.012020993970274445, 0.029645934513199235, 0.028432757676308675, 0.02196462179023412, 0.09182692986101874, 0.098947724778085, 0.06693040531489157, 0.027740149075285565, 0.04394928444056742, 0.06810085742824501, 0.03276730804974514, 0.0060667254447546465, 0.02346738752338194, 0.03091233147818956, 0.013172022881917657, 0.0767574594506333, 0.0149129873757521, 0.014049480838190406, 0.017164609800543518, 0.012208540912627453, 0.047644815978504, 0.062404997541659304, 0.06842627625672087, 0.041132003759905215, 0.037887387743760506, 0.02325452041752156, 0.02572357008654264, 0.04642647953944341, 0.06186195994697272, 0.08104975049894664, 0.022153127300102386, 0.0027495996853817376, 0.01527385692292404, 0.03647719607538274, 0.023423799035710194, 0.020563460383263808, 0.038782791309659524, 0.017982293746524283, 0.02738147437001669, 0.015475726836631376, 0.05572100297638005, 0.0034513599248678097, 0.038157544819818395, 0.02529679016480523, 0.03451103524815652, 0.029980720681769234, 0.022566381939536622, 0.040113819282381766, 0.044507674437256596, 0.03835712221541232, 0.03308627641789856, 0.028749186462993105, 0.0608024756694513, 0.06463496074561151, 0.061385744371481483, 0.05963674265771143, 0.03624594860499905, 0.03973714534133192, 0.037907087694733374, 0.04395505691307687, 0.031022554293515223, 0.054235596795596426, 0.048850653693079955, 0.049217812822110234, 0.05045820876295048, 0.029033447217736996, 0.04565776393358265, 0.0555488208849584, 0.03265979527045162, 0.04129690418560659, 0.0487283707386063, 0.06975461143038927, 0.04625009162531746, 0.02916797991811989, 0.0617594956871002, 0.008572761359955034, 0.02204445006716396, 0.058349247631286426, 0.022061342305894342, 0.05833623945833214, 0.023920798576587153, 0.044606112905087016, 0.04066725652064047, 0.10199844777103394, 0.02340879137327354, 0.049795692095593105, 0.0942370041664089, 0.06626002475499146, 0.021583678824226224, 0.021978662266666373, 0.08881990452327075, 0.031098611502637787, 0.010981507460406471, 0.10683836911113993, 0.030463626120059244, 0.04848277061096123, 0.053662218288668705, 0.09811959139281705, 0.014908373611228121, 0.04670447752540631, 0.03614165339498751, 0.05667508121639971, 0.009514358112468355, 0.07111407275642119, 0.04535309076609631, 0.06328573052380836, 0.06630947573050376, 0.018314191763619744, 0.018691800331937212, 0.035954452149810336, 0.054843066215154626, 0.05603767308076063, 0.02619004102363702, 0.032260514074756254, 0.01884421352447281, 0.08538793787480363, 0.04503063669788741, 0.0705247902641854, 0.026299922929836378, 0.015840775393430265, 0.07231621792720211, 0.009515270714708155, 0.034445067416996725, 0.020364310081687667, 0.037560620600537914, 0.051976778889976205, 0.020853849841401945, 0.0272095910528855, 0.08316141057519183, 0.05832578235816571, 0.024078300508159785, 0.03892827906735963, 0.07597945119825102, 0.04992084404934318, 0.030870424553511605, 0.021128492362256494, 0.0433831186514468, 0.0825042373711063, 0.057794515704435695, 0.06673832408963673, 0.05656894356493027, 0.06271497969846092, 0.036795789060453256, 0.008828499703668058, 0.05916884296663827, 0.021147012537825974, 0.04613754947880103, 0.04538864490666217, 0.06718951923352096, 0.01926845386474123, 0.015146786876533543, 0.032485533250315536, 0.004662502558916928, 0.016926375608290398, 0.03549746921165817, 0.05817860154615295, 0.11086387770070184, 0.04764259049308397, 0.08696415611813146, 0.10443448479617796, 0.005718831511800208, 0.0451107235294917, 0.055451960558251995, 0.01995116844022226, 0.0404747233035103, 0.04182395352531345, 0.028793548699468378, 0.014352251234794817, 0.010318866303761401, 0.005636931924645099, 0.03559047994654506, 0.08931028506448192, 0.012368663822511032, 0.032014540479248094, 0.02853833416837358, 0.02877973230375398, 0.006067226753540097, 0.09393703477877764, 0.12139509687380445, 0.04228703452334289, 0.052821498078804825, 0.041899156546400446, 0.03625543660394127, 0.050034910710828925, 0.036865024256610104, 0.07277420061009546, 0.03921753471536983, 0.061970675484307354, 0.06477693215973916, 0.03185672828206613, 0.06868912102354151, 0.04668655872885739, 0.05051515973924149, 0.05299571030322583, 0.0604684038778707, 0.030084123399348992, 0.08486442403086732, 0.08465716660383248, 0.04208373010999734, 0.009438699269066415, 0.06193881005709691, 0.09203070924887735, 0.05750753916800023, 0.023991393578809597, 0.024912137418024005, 0.0695656022177108, 0.018433416112055703, 0.038600899053797606, 0.038964645261125225, 0.006117654012350907, 0.05042915104798252, 0.03667687306240682, 0.06335879999002622, 0.03413768612869805, 0.04989700339313957, 0.010836395085789265, 0.055914501464294816, 0.010360555850990839, 0.03788708896947004, 0.03593683212755188, 0.0212440203364578, 0.04045469010429036, 0.013470979118269059, 0.03649680409580469, 0.03100623662072805, 0.030950277728298982, 0.07259664441188497, 0.0421075439531236, 0.04062168578046464, 0.025614389150793997, 0.04400710492665249, 0.009590385635683854, 0.03298783795006814, 0.04367409799728663, 0.03314504685300974, 0.039561868254696174, 0.03426928088189133, 0.08123878269426285, 0.03361128030284759, 0.17778294491431407, 0.1577937804282673, 0.12870290917494606, 0.11708838805075615, 0.13803318593530886, 0.11432709307560038, 0.1585221615049147, 0.15995281538175, 0.18721802250271846, 0.1313587981126001, 0.12283489017957643, 0.11931863853767996, 0.11423734587527092, 0.10484107064023133, 0.10554569533034679, 0.22132891470626478, 0.17419719377592688, 0.09446266302538496, 0.15769379063239022, 0.1489876610256972, 0.17286309762106788, 0.10586696196227305, 0.1403924456286815, 0.1100562907935631, 0.19610614395670353, 0.1227034677961661, 0.13497105589316738, 0.2689469329291775, 0.14574212953448296, 0.11491161816182638, 0.24234422332336827, 0.09496906246509283, 0.2912701221723711, 0.23268684234109618, 0.2335284052476768, 0.094935339274666, 0.10427190561688716, 0.2112005122246281, 0.1833331753169337, 0.1516479473080366, 0.18878088783352606, 0.14058009120485476, 0.15100740587278721, 0.11255288706912149, 0.18409416109563845, 0.10278145091668253, 0.20245146637241687, 0.13292863484351866, 0.17472055440227832, 0.1984353423599274, 0.1225608605290613, 0.07679269183427095, 0.16776443008453618, 0.19882186436124388, 0.18634789983832067, 0.10516717894783906, 0.17391890467655274, 0.09687710403194351, 0.190798073946949, 0.09942456088479489, 0.10349146120490567, 0.13835325747007324, 0.15411150221142078, 0.1442808934277104, 0.10726761583599354, 0.1277622527953598, 0.23106989120283436, 0.07354901427583349, 0.0937481941054425, 0.1723338074741825, 0.18229777684375165, 0.18420026427315128, 0.13191217406382486, 0.29587382030102516, 0.16016971019487228, 0.15087021484730706, 0.16203438352432945, 0.13192536609788097, 0.2148848435571117, 0.12101965250387309, 0.09713261733732878, 0.13078941092375787, 0.08525268505177191, 0.14937324839974606, 0.19343615900124275, 0.13894636274105118, 0.22094842947779164, 0.05939341015032223, 0.16242747856003625, 0.13080341501101372, 0.15639482726973875, 0.19530633284199625, 0.17440932352216015, 0.19341211916217882, 0.15572756468769045, 0.2274782411874302, 0.20500970974324212, 0.28127405371877456, 0.09508054357983413, 0.1639576012929601, 0.21515121232838402, 0.1607083466144339, 0.1152929767305332, 0.10227540387741982, 0.09045875811528775, 0.08312118329828785, 0.06687792063119911, 0.19232844182800865, 0.18140215877323382, 0.12065137105603373, 0.15453798335886773, 0.15364110890415408, 0.20560013370648508, 0.11797480540530336, 0.16268641627844305, 0.1615278308670367, 0.1050071508413361, 0.11015975096773718, 0.14640110304519055, 0.20599465366573105, 0.16256627837015739, 0.15221869813338404, 0.14113651618601816, 0.14162865106857594, 0.17375056451607138, 0.23668890097929587, 0.17227189224814216, 0.2149986535791428, 0.117868717549549, 0.16346109970923395, 0.08721987626725629, 0.13108839971884606, 0.09276613833442812, 0.15715913787003488, 0.1612513497351639, 0.1570916148803888, 0.12686249018917162, 0.19223237440230387, 0.20530790180688907, 0.15365042453331335, 0.13790705721945534, 0.09488542864639914, 0.16080833641031098, 0.0933442512647279, 0.12393528355225442, 0.08992301750807993, 0.12438149146375158, 0.1275364790231951, 0.13241063683263718, 0.13681285383720554, 0.16596875063353972, 0.14853925444185734, 0.08194654834486785, 0.12089328630076301, 0.04720440352215402, 0.15491860648316724, 0.14010543844872905, 0.14853001542149052, 0.11595162848431258, 0.09379781362029815, 0.12309551329141664, 0.15312579220100758, 0.16694474664907302, 0.13097382360889068, 0.0819810452840982, 0.22106941008279402, 0.10318084319512691, 0.10336826660580213, 0.12868725033777376, 0.14095679195898195, 0.09445305628281447, 0.10721880071345838, 0.14286021401564922, 0.10751011330754527, 0.19323788012468046, 0.18707425844284797], [0.034591137401519284, 0.033107837962527434, 0.042266020731579874, 0.03246451179767328, 0.0382899324740133, 0.04700671453329344, 0.03362852111158352, 0.057432171438009515, 0.014103571433694133, 0.026881343444749236, 0.0208065573186163, 0.020905472676179582, 0.033477823955998305, 0.07970712012461117, 0.03879401449775023, 0.005398443486962107, 0.04133189908198772, 0.006854056987175418, 0.08964481267837748, 0.026374371354317954, 0.026232359720574274, 0.07261355197237385, 0.01715421015697141, 0.053465697583892656, 0.02178950941250209, 0.06318356120778669, 0.028244742462711952, 0.04557430631511154, 0.019452611825639204, 0.02248792687521106, 0.04321112808200621, 0.02834604418415937, 0.012341535691502354, 0.05745487445364556, 0.03240849544864989, 0.014458984519625384, 0.06695776997554688, 0.008094908271525657, 0.05172274030384518, 0.019018661320930528, 0.022690030445735303, 0.026447291433390592, 0.015574446841773969, 0.04320031092051537, 0.0043338455725461245, 0.04882219352669293, 0.04287845440088742, 0.055408312698766116, 0.03840450858396869, 0.04821011225783056, 0.06563909517060365, 0.024618907688906597, 0.04773835531405864, 0.037354519966268734, 0.03845253080550221, 0.041371789280205004, 0.04111237275684553, 0.073958381019052, 0.03758028224711457, 0.0356586579413664, 0.03789420975672622, 0.026567260802332914, 0.05985491300722765, 0.027045293921424497, 0.06725959329595489, 0.07855522266078381, 0.01890992854661759, 0.027062471527906678, 0.03777036015244742, 0.010844190988028723, 0.05283855502643893, 0.02485214698789341, 0.07556567944946789, 0.04340396390386647, 0.008645231362372156, 0.03434585903080241, 0.04949416371903593, 0.02610897168426985, 0.06363818076469245, 0.03267846483316633, 0.09760365415845187, 0.009707715831727031, 0.03918121065644007, 0.016525816960981297, 0.013759589337203053, 0.09297701169646556, 0.04564126623013327, 0.03372787122404383, 0.047950542516886234, 0.036087448843905044, 0.04533882237850659, 0.0070276122912013485, 0.09550126374609048, 0.03676555540052153, 0.06511875293067386, 0.13621145949488686, 0.08771305302939109, 0.012578065338123952, 0.055403344618577155, 0.046301170537668856, 0.02375824812559351, 0.06523767275915993, 0.08183798602511806, 0.0013789703535299089, 0.09410941222261998, 0.07016081423048051, 0.029706394172183452, 0.014171625896837684, 0.08738986351677487, 0.12552896860025584, 0.01416032322712483, 0.05276131038103373, 0.04643845732413954, 0.06406456615114886, 0.026051342720165852, 0.03278506979826958, 0.03189964644280413, 0.04585167993941615, 0.035171219177784464, 0.024635384324938062, 0.04954091040417553, 0.044814887186211926, 0.09026943480656033, 0.06566717995390778, 0.03364370880468238, 0.06933523957887966, 0.07837077933213404, 0.08623229700230783, 0.08561920449738541, 0.03298093549787037, 0.10788584113000863, 0.03514496151417975, 0.013560770368654163, 0.018443742977275003, 0.02834153384150517, 0.05780041458145265, 0.02656992870352922, 0.06026874987348434, 0.00941080888057308, 0.07398275027592337, 0.04627556021836016, 0.07111154466627106, 0.0019548586363183156, 0.05932207204281323, 0.06850027268932712, 0.0445161052348633, 0.07794891769487051, 0.02687376491995829, 0.01917763222609797, 0.0316234142895067, 0.017658491363568653, 0.0357053165263947, 0.019797418424258792, 0.011082990170126001, 0.048500601307398854, 0.09433989743551902, 0.023093414042265187, 0.09377313792825707, 0.05401525458681488, 0.07985565691224991, 0.06888969050299737, 0.04581229535922889, 0.04213591984983894, 0.0016949664202383571, 0.03478618721748072, 0.04739488745408674, 0.02342722919439116, 0.020356593661070354, 0.05916902299730047, 0.05352008599607695, 0.07267817914966615, 0.023539782832226446, 0.01708925356187167, 0.026794980437825286, 0.020104355381561384, 0.030243462026720087, 0.04860461306487841, 0.02299538734669407, 0.03821446898303205, 0.020679951713029898, 0.047053909379868745, 0.040651819848966216, 0.04091996594422287, 0.08216960250490135, 0.07597486999246382, 0.010245517215451166, 0.03187743372343962, 0.0042998303110981665, 0.06803221595022949, 0.025911688722009142, 0.04963575591964107, 0.01988085880575161, 0.041566065347362915, 0.021720172709695274, 0.09312446063925182, 0.05259400826968974, 0.05823110538204351, 0.026963182702480305, 0.0816602000005303, 0.045780000922780846, 0.02344031397613787, 0.0938078263894685, 0.03743985066971472, 0.007510391803788803, 0.007452013031128915, 0.03305670542402133, 0.034533144545651255, 0.06409171630718535, 0.07008814312998327, 0.07778757957801705, 0.042104115709662444, 0.022742664516572992, 0.03990223728901437, 0.05347132833013612, 0.048356300985981385, 0.0398483008687054, 0.052287653539209604, 0.031228758349654176, 0.019720110576599836, 0.02709131856869546, 0.03289648962597693, 0.025236656093188835, 0.009195837905750641, 0.05955323907396486, 0.008344244035411506, 0.05985841785948123, 0.036683327353168885, 0.05249131418343994, 0.06814876090615027, 0.027905183566373684, 0.02101259666585153, 0.010841669601147935, 0.0017180032826276618, 0.0051752624436161455, 0.006037615061241893, 0.031008180568835912, 0.028272641469694437, 0.03162449830391955, 0.01633530430075142, 0.08019559310689088, 0.03579416740385275, 0.09468457571441129, 0.01811618293305078, 0.01562947781020475, 0.04179177017161443, 0.058388528789603905, 0.04208763715841117, 0.04632414934495765, 0.020193290528691104, 0.040522010080636515, 0.04752317653788675, 0.04523599039643042, 0.015113985864445569, 0.010349518439221767, 0.050277683974033406, 0.010546561999006138, 0.022612444891203797, 0.02508510091912843, 0.05267940792104891, 0.06650747115453405, 0.022910654191829027, 0.03973906822202187, 0.07173294922517193, 0.053877128934067105, 0.02618547705482812, 0.049182802603970614, 0.01112072287322653, 0.05640616903321878, 0.04602452469689231, 0.09282706530704614, 0.04253825007547294, 0.03044293983088386, 0.0314709302338381, 0.0655080251876385, 0.09200125316818876, 0.08384781769446789, 0.004198916900467369, 0.03579259309316835, 0.03430350202946894, 0.007037547493969361, 0.05939673880235322, 0.02785272378053877, 0.07018015028968935, 0.0574194620393457, 0.010234650258245248, 0.014114853993598974, 0.03270404067851844, 0.02489111596538175, 0.03947102937907462, 0.03358109260819132, 0.04481340097563882, 0.021740058436989788, 0.017961760674933755, 0.0520139494760623, 0.030765888025803916, 0.06732230525343649, 0.0364649654816716, 0.0148944279381765, 0.02490160753950477, 0.06576342357983513, 0.04631732350155231, 0.02607092009707084, 0.10067699972780482, 0.05053166893400973, 0.06737921026445205, 0.04441271783904203, 0.04064432367862713, 0.059745894865162914, 0.07594874639424586, 0.02876801690417192, 0.042991827752801685, 0.015108857863402415, 0.04462222373413463, 0.07814535029953526, 0.05256259483435462, 0.04320593017543997, 0.051752177232335654, 0.0607723530922686, 0.018361281273105455, 0.039984810075932936, 0.005549551457196715, 0.0285497565393246, 0.09389358227171245, 0.035620265445041085, 0.02761361624805197, 0.03662297877693369, 0.012998272225471034, 0.0254491976116814, 0.09298719300497925, 0.03680467951081453, 0.048629039778344096, 0.02688605680070337, 0.046859805682493795, 0.07476845771194467, 0.068582113862278, 0.07109470605369538, 0.050363635208698056, 0.015777014853102306, 0.021261487141131394, 0.07117422598023569, 0.04201226942842046, 0.044987751095886194, 0.022860253267290614, 0.012023488544077884, 0.021637239861452294, 0.030354876108768008, 0.02321922866206977, 0.025272007220454758, 0.0356745695875537, 0.027941208851012974, 0.007301530380162501, 0.036448563539212754, 0.1093548070639372, 0.1953420325392677, 0.14701035744961233, 0.0839550776647464, 0.11751477726765218, 0.12597081747146385, 0.19262438159315817, 0.1444585951826265, 0.20367815700029174, 0.10214300090146643, 0.08659757538548402, 0.12168827872242659, 0.173352750378751, 0.1600886580924834, 0.16169474610397894, 0.17705301634005963, 0.10325292440792246, 0.12045882251714507, 0.2129431477477474, 0.10829477886398954, 0.13754025432130984, 0.17461232150033598, 0.2025097963069716, 0.0862294088508333, 0.05894254442424544, 0.2394445652082082, 0.17658888963201355, 0.17131762248614144, 0.11385574215842832, 0.15780865785575685, 0.13177542736934078, 0.09335080131648049, 0.11482877341369468, 0.15698347390899736, 0.15122054685508052, 0.09806770425770553, 0.13979362534178844, 0.07981464056478393, 0.15861916355788708, 0.10630752380576827, 0.15191652241253084, 0.1176129131307525, 0.12365611345176736, 0.12022656764114097, 0.11395171765358218, 0.1321539207692108, 0.13511698032098432, 0.1728982150915169, 0.08434901539716991, 0.18472593848503407, 0.16355819369275726, 0.1031188283776564, 0.16163171238956914, 0.18887824228694364, 0.16936195323303824, 0.18511319593075784, 0.0628919077045735, 0.14414989239265844, 0.07395605977264143, 0.11517306098774557, 0.10495582295040931, 0.18162338964400754, 0.13282887487401887, 0.22492663213802924, 0.1937250814010059, 0.22489971180837, 0.07238575572808904, 0.1336899577009101, 0.17404463502668566, 0.15912167127093962, 0.12026275763468397, 0.1397324302383969, 0.13707792025900659, 0.12977219937789825, 0.12881183155602025, 0.18994241502256165, 0.13621023375420802, 0.09396063028684548, 0.1360060713223873, 0.07158578373491764, 0.15399432140252284, 0.10682596614764583, 0.2357266792246411, 0.1503514507485013, 0.10858586163169916, 0.21381846448827177, 0.18568860457068492, 0.1540948627817054, 0.0892408391941459, 0.22571801628556945, 0.2392122567060494, 0.16025209529024942, 0.16256450104617304, 0.22465064130242796, 0.19563225728850211, 0.19913609830602524, 0.19502715508062995, 0.1359226903127086, 0.14597981597387022, 0.21761257622030475, 0.1308726387158517, 0.1284625567495823, 0.159933126922096, 0.18273668393733042, 0.16268342853553835, 0.1330621180034453, 0.3014772325273483, 0.16286952661410456, 0.1700653291998371, 0.1876093708579579, 0.09227210355381812, 0.12036673874864656, 0.16665553313589868, 0.19077778793871406, 0.1710121985524893, 0.165642106064385, 0.0623480657175664, 0.09861481360970967, 0.1020259656492741, 0.18420596396730793, 0.11772607963892723, 0.17874251600475083, 0.13221448768050442, 0.14009506561823432, 0.11077331844717266, 0.18497405904195002, 0.15427501601797922, 0.22564745958774324, 0.16763816347285626, 0.13895809920805116, 0.22524719396906517, 0.2229184092533204, 0.17041877152458315, 0.14711676706229487, 0.08726711324866741, 0.1447743766250149, 0.09079959063280015, 0.17990081030274593, 0.08249643093515789, 0.16243589020544486, 0.24061289525801138, 0.16165843353636805, 0.12950606043300322, 0.11554549463213452, 0.15759199286901182, 0.09786443048787695, 0.23452795080600247, 0.11429366865946401, 0.11368062211981705, 0.1497891728555964, 0.19342785460814355, 0.17413420602679255, 0.13158300140452, 0.15881010331213474, 0.14226013734456033, 0.20570217661799925, 0.13244316492590213, 0.15156654280520257, 0.17574838392676848, 0.15296767165343608, 0.1986688306374896, 0.16259502198907638, 0.18520161779897829, 0.1652442459617892, 0.09140541296332114, 0.12779992133859666, 0.07528461711180788, 0.05959081951709044, 0.20955164586344074, 0.161965113854216, 0.27827212286572306, 0.1578832288543063, 0.09157913106103098, 0.13799350258083115, 0.04717601613411981, 0.14784144027338875], [0.028806072321810552, 0.026523149459652846, 0.030527676816188523, 0.021858290701563803, 0.021169962616817608, 0.04689138382673264, 0.0258959494456048, 0.08041678567326839, 0.04637874077044187, 0.03221123546902691, 0.04111095932462523, 0.04227355520631518, 0.048345560433282975, 0.030703367590303385, 0.020620104924385107, 0.03997700747042414, 0.04662779978506508, 0.07576958907227363, 0.009630610039758106, 0.11167831343388367, 0.08428176819917657, 0.08769187835916396, 0.0077121353129886334, 0.02380407359000416, 0.03983112900788265, 0.04411333833911246, 0.04542392325557528, 0.017530824726207123, 0.0646925705575174, 0.02105874963284981, 0.016538585731459242, 0.02330650714406323, 0.012276187433951325, 0.01167174214647422, 0.019396953622720415, 0.010904264730221082, 0.0366648071775994, 0.009261508877839773, 0.054186636116355665, 0.04207123904639194, 0.03708803245136815, 0.03174728304598361, 0.036275910303717664, 0.06022950318912345, 0.02983163422604482, 0.016004556373152283, 0.004371784640581257, 0.024137869589932026, 0.08329110159989327, 0.039796363937878804, 0.07088170296722843, 0.026419650981082555, 0.030620898225254593, 0.03793924040491543, 0.07229522711807682, 0.05632911207935503, 0.08150475309981454, 0.029591706979479042, 0.02160830663577203, 0.04316420136620441, 0.00524776691998986, 0.06331942690115783, 0.007500670626834636, 0.03608593965069421, 0.02286144644923268, 0.014406060292986373, 0.02105527925455282, 0.0008321204539594962, 0.018328973430118734, 0.09359467774629594, 0.023703955474399754, 0.018810270083767754, 0.016833512345328927, 0.073126585733506, 0.021078696647178263, 0.01842195543670847, 0.04179480004935496, 0.06692491246447449, 0.030780369002792626, 0.05292428792604516, 0.01775886037296826, 0.016836088315974322, 0.041667706062716824, 0.013796130773581326, 0.03539865153030523, 0.034697458914090554, 0.03405119480204678, 0.06676327557333055, 0.014927412811366302, 0.04414028931228865, 0.058213500681543545, 0.034432603166468685, 0.04419429851095042, 0.0706296677010194, 0.06844506839350348, 0.12283698159960971, 0.03168277461231957, 0.02562922827388731, 0.03703871554124259, 0.08725575982562958, 0.055577438099369894, 0.049717305979180726, 0.018975852327721737, 0.06891571450978518, 0.029168148457463232, 0.0567708115634178, 0.026226769193946838, 0.04615731454724747, 0.06492002206223627, 0.02340417186309013, 0.028543493770543608, 0.02789085197653021, 0.05189348214996919, 0.01791144018962739, 0.026700686505665223, 0.015555460310180583, 0.07086962176066253, 0.016602178690053763, 0.043442107421616395, 0.037514735764313134, 0.04352567612283653, 0.0718797010279471, 0.053521989724568786, 0.09431409559422925, 0.06622102321876634, 0.021313686457072056, 0.05911284193937337, 0.03501238233800377, 0.012283631893355521, 0.023640722577129642, 0.07851150968382437, 0.060372370926122514, 0.04332991384510552, 0.05454257971817448, 0.015348912472085608, 0.029173024607101278, 0.05543701035240966, 0.04281952691775176, 0.012971136433583115, 0.049183821500909906, 0.026147469517684756, 0.05446196811634207, 0.037133162690987515, 0.08617300945784777, 0.06267030911159611, 0.008824263237446787, 0.026748595729229913, 0.0623150626497884, 0.03985486241177686, 0.027382918445753957, 0.032481561084428144, 0.023038684720954588, 0.010414975864302007, 0.018748795358283867, 0.08942256291066447, 0.017516058381466616, 0.04340358085990433, 0.01805557771736095, 0.024433761474586303, 0.07503256652384035, 0.037196230879353906, 0.033390489932630336, 0.03644954030131621, 0.05332063500499053, 0.0044570708151666395, 0.03290067246604351, 0.025018935820328134, 0.06268293424058827, 0.07197723168158723, 0.03720503322960388, 0.02498333954492644, 0.08369733504350148, 0.01371737118930586, 0.024398314586329847, 0.06621978215632901, 0.07335875633983843, 0.012512408730183399, 0.04339660945979338, 0.041500633777750116, 0.05754371000934513, 0.018968218261556282, 0.024531299789105693, 0.017131005353744955, 0.06397170097296757, 0.029892143680744117, 0.03219830773530468, 0.040649628837502776, 0.045010825664165525, 0.02662840419478955, 0.02159716580213318, 0.0878138165740717, 0.04183620710166232, 0.06940080904431882, 0.022181909223417604, 0.04809134181648974, 0.052378354519004786, 0.04585620368860903, 0.04469489100419226, 0.053662781363293055, 0.05176682100300828, 0.01843332226628498, 0.04244570282378024, 0.06871623287518179, 0.0450940074909839, 0.08142783021133754, 0.0275482248980552, 0.04201172933643384, 0.023447388798118602, 0.08349390805608804, 0.04581273969022497, 0.02826516445155346, 0.035339789164643136, 0.018431533450981783, 0.0330950366333127, 0.04196112156815587, 0.04994452382708269, 0.012688051623802994, 0.04803494242350421, 0.008116808810061025, 0.03643089372123923, 0.09904982131575385, 0.054222385609342214, 0.03443474055177743, 0.011262624381831097, 0.05139118894153545, 0.03625828262057997, 0.052399510037033796, 0.06802743556158197, 0.05923117571059735, 0.011387463197142128, 0.0158989118907841, 0.05408633605486924, 0.026290892668428923, 0.02809562919391019, 0.0889380889073495, 0.0862354762671936, 0.017885247643496242, 0.05025404633112973, 0.04834019398737339, 0.03281145769682142, 0.046070850033673554, 0.02310276606060084, 0.03330701699240073, 0.030868426979249044, 0.033754094413691954, 0.0571590036364092, 0.02641286727251305, 0.0151328191784541, 0.04287087396087666, 0.03722476382409373, 0.05419773673037848, 0.03667989144882849, 0.07564550581117792, 0.03291245872875856, 0.023877924465904796, 0.017668465828342785, 0.03758752177799902, 0.0765505314414059, 0.018688201633912903, 0.03539904989602585, 0.03505846252664924, 0.04809191638243295, 0.03656838735144946, 0.028594019184369716, 0.035333396160915014, 0.026072525051272204, 0.07019403946375655, 0.04565124835578665, 0.21303633468285685, 0.07705032720320648, 0.061417433598469344, 0.09009710332799344, 0.013280297918695838, 0.01751231987239613, 0.09989060281265168, 0.10146673678630784, 0.035483560885392854, 0.17823671411362388, 0.06930956031165778, 0.022660041933939345, 0.03020665533239803, 0.012194717813643717, 0.0340730321383284, 0.046952942821888194, 0.15814516963737626, 0.020942377046711987, 0.0860611223165066, 0.022799399073025393, 0.041556458604792436, 0.017774680088604652, 0.0421086011544591, 0.05924681922601116, 0.05535261810667092, 0.0030413415281087043, 0.033188154620508996, 0.03628924023360014, 0.047968798392121835, 0.05650139376220684, 0.03708180415654375, 0.03607923638135676, 0.012760161564895704, 0.04855569452047349, 0.1142886890879562, 0.027495761281780662, 0.019908566290753025, 0.039716250293197176, 0.06486020591710845, 0.020910682074064692, 0.026325809040797815, 0.03391640929264888, 0.07584989806937595, 0.017309739412139022, 0.04360718021710073, 0.07497211452573538, 0.03082878767482696, 0.06211202636721635, 0.03632312047205145, 0.020040992249344147, 0.02332882137007771, 0.02355358007574274, 0.06926646020503775, 0.01998110332586352, 0.041387620487160263, 0.029747178778052333, 0.02334711746492934, 0.04658998185468297, 0.004357848064823738, 0.01939128648730055, 0.03629786255318792, 0.011172142694704236, 0.05144859957058103, 0.007500727604624005, 0.05329527366425722, 0.0959120630737274, 0.03282171178368792, 0.02910051438506813, 0.049327348073523854, 0.03846484566888502, 0.017277278351567445, 0.05415201660305743, 0.014594505473430601, 0.015607022815534185, 0.016630809311003938, 0.0826205678224083, 0.04585667100224284, 0.043887292605734644, 0.009842857572009728, 0.08453118344468456, 0.045144596107063756, 0.06193814356060279, 0.048822691483843716, 0.08451555525102923, 0.07556394042987978, 0.16068380115733993, 0.12293417517456318, 0.11523208806231139, 0.07384715271332572, 0.08723319853625952, 0.10389099137917643, 0.27799292978259826, 0.1854453103676919, 0.28214800682279373, 0.09424273450408252, 0.15003867237077606, 0.1371234565252258, 0.08632950589901979, 0.2384600349731984, 0.1200582504632973, 0.20250673195527447, 0.17957585112702462, 0.14832315636017632, 0.1559781214042056, 0.2118961813469087, 0.20704379575627468, 0.11775905206318825, 0.21840867946945855, 0.12992848131445148, 0.10990411508828403, 0.1855551980195507, 0.19796307979812547, 0.18443154621749155, 0.1766344105764743, 0.13530707737851527, 0.11726036712887788, 0.17197048261521325, 0.212115726824249, 0.10412902255812961, 0.14158627108460473, 0.11935265284151801, 0.07659650437774197, 0.1340792222969955, 0.18240671454658433, 0.1794582259871306, 0.1426886256423689, 0.10252363934752443, 0.16760185090524538, 0.2704245633175296, 0.1009643899517194, 0.2063936475784548, 0.15542920408470018, 0.08803076501334868, 0.12952862938325252, 0.220709563263001, 0.13634914081663857, 0.13191634158213295, 0.10512900478657215, 0.2148079589730309, 0.16878125858643364, 0.23481164848612202, 0.11457169728894388, 0.1380533800129929, 0.13186973279281972, 0.11245577010296046, 0.21370238684598478, 0.15260155823442245, 0.0955073158406923, 0.1483967467661827, 0.11547310698416927, 0.14749360571224845, 0.1063919313732655, 0.15216980640205646, 0.17454092210579306, 0.14005533629848113, 0.16110294318247229, 0.09440325290685701, 0.187777481192062, 0.16776171813328422, 0.1373181807538194, 0.14598217552467702, 0.12743232170900992, 0.1200578750802144, 0.10166031188301503, 0.10412309303759568, 0.15956313709818548, 0.08892367113261454, 0.10497469935686358, 0.0974037281928524, 0.10140286803606058, 0.08385239890025509, 0.14009589299319253, 0.13945133725721992, 0.13867886015965095, 0.2550727282200129, 0.16459299461735835, 0.3106430148886096, 0.2601423457024559, 0.15765617571530804, 0.2395166387601245, 0.18901500430318618, 0.10387346328746888, 0.24955850394983448, 0.19017483077702985, 0.10378281210338879, 0.22847740370179379, 0.12132677715271713, 0.16974931793107143, 0.10686179607986443, 0.12326076611756318, 0.1721257686374649, 0.11881649854683107, 0.2916078750164278, 0.11650747889953277, 0.17653676500964552, 0.09639056159123298, 0.13457681172557417, 0.14472856456714292, 0.13024726582150306, 0.1383223381614493, 0.1529763897340144, 0.10282952293393113, 0.12704329460018104, 0.12980822083209792, 0.12997357324967462, 0.16472482302736852, 0.12778028650509735, 0.3641382298402248, 0.17922660696410364, 0.21843334750062038, 0.19355209874770335, 0.09521139139730124, 0.11422029275807644, 0.0744720506331613, 0.17239553883912104, 0.17105805657563672, 0.06800825271995799, 0.1752465503710893, 0.13182986557724016, 0.12032795171704024, 0.1802171739719568, 0.10758952598177618, 0.08382087438217095, 0.26497415417144377, 0.07371577629519087, 0.12149498707825139, 0.12507031942086835, 0.11853639381907641, 0.14542781898090917, 0.06616151350880824, 0.16693975175580672, 0.22523230121981716, 0.07687876947344312, 0.22263129482105856, 0.07441738259888465, 0.09462328868046885, 0.13065569793745396, 0.08191077969968319, 0.1282033662221605, 0.07815404539747585, 0.19055045900806306, 0.20089551115468626, 0.08485524629753444, 0.2799803150757667, 0.16999222909010228, 0.08251110151890786, 0.11019507528192575, 0.12751453060416446, 0.1491801482775519, 0.14171166435605095, 0.10116656055493702, 0.15057934658421626, 0.32913067768658366, 0.16371662067549844, 0.07592533474727985, 0.21631519099877727, 0.10684161732393889, 0.13330682180821896, 0.1371073840005744, 0.25205670134915464], [0.10074869023575898, 0.028698605507792487, 0.05303935816271171, 0.024508186916430152, 0.048363509873348864, 0.03901501171170704, 0.06641451404580186, 0.04545210763030956, 0.07039357472451464, 0.019079925372235237, 0.006002766200371328, 0.01750734987698736, 0.012789095748185873, 0.022945528429362084, 0.011593401995337298, 0.020163026225242405, 0.04022381801698958, 0.1215001428499818, 0.02737626114169196, 0.06442996327795329, 0.04104694118723273, 0.03479746403172612, 0.04559723149624564, 0.03702978295604548, 0.033658475149422884, 0.06970787240612893, 0.07367460673014004, 0.06104750506159279, 0.013089605227803752, 0.020294791432998834, 0.03166188530984425, 0.057179519471021435, 0.013704406108797319, 0.05661362181267431, 0.014517759742786088, 0.015328398552693188, 0.028416821132263834, 0.06951387596106337, 0.013846479029574943, 0.05090845778824822, 0.05436780824956875, 0.046939160900130394, 0.0575982554695539, 0.09773445601064353, 0.03530300162251919, 0.06197995663951002, 0.043992595221366615, 0.07859050100969692, 0.04657970861561837, 0.051440440734187444, 0.023290695089306084, 0.022915463308773698, 0.03789290357681532, 0.044385387652343324, 0.022532053539649616, 0.03590811915214985, 0.04181564913221425, 0.041354713180372794, 0.02197870823194183, 0.021482813772895647, 0.026392403148835706, 0.042647187778305624, 0.11911285199945974, 0.040202635685883226, 0.06230559380304429, 0.08455103278280267, 0.054278689241337205, 0.042133767142771714, 0.013545014812881428, 0.14228509648913337, 0.039630597832822995, 0.03142140647997299, 0.0185326915309434, 0.028449632678060766, 0.06709872249273524, 0.02677665944511612, 0.044682947693452726, 0.051306497921506246, 0.049977860143107754, 0.05637703853989801, 0.07212203762103474, 0.07305350094552963, 0.026502468916136893, 0.08640740171916063, 0.010822323965840043, 0.04050894445108791, 0.014164474466064525, 0.015735021743532873, 0.03224826432884701, 0.009133695726162724, 0.051371722647379485, 0.029334992831272465, 0.021336245831222306, 0.016730103882089738, 0.0763833863780864, 0.04368263987764236, 0.047990831080824144, 0.016633191844448447, 0.02060746255841467, 0.07835292182261906, 0.04135773156679446, 0.14962002064191526, 0.028352201615850774, 0.05991513517895534, 0.0055764866298094636, 0.059308163716547915, 0.015500808555272319, 0.04195517289542383, 0.06322097311156892, 0.008444738491708714, 0.07304446110802312, 0.006033286664469709, 0.02074526262379462, 0.04326832803687261, 0.0700884725477907, 0.012251248399186279, 0.023998698227167613, 0.03770536525295146, 0.06784668477672724, 0.031100480757173032, 0.05630502627501565, 0.04360547950190883, 0.049906705896700584, 0.05977083485753787, 0.04815368988220731, 0.04572394626936124, 0.05293953690617796, 0.024013047053989385, 0.0601404378070466, 0.04898383807871611, 0.04331166563074916, 0.017181130486630627, 0.015870008351010902, 0.03828176597674047, 0.030495774999801672, 0.05151762792299833, 0.01741837067980199, 0.049373401449091976, 0.014182152902527202, 0.07044916972517967, 0.044511393794128974, 0.04016580217848382, 0.03493709887768473, 0.028490392386072108, 0.011229852098040284, 0.052235728099701874, 0.03182328279851185, 0.05159146347714048, 0.02774355433610899, 0.023148254446324804, 0.031095673555448174, 0.04773234152385304, 0.06337973334255718, 0.031520354396273056, 0.026249788220851656, 0.015390031283811457, 0.09052669479241295, 0.05476069644153599, 0.0706814092794253, 0.01169333337701016, 0.07929239076592269, 0.06024618475367466, 0.055407994772277536, 0.056549220631319674, 0.038221685531278776, 0.04384857069160189, 0.035112858599712776, 0.05242981647531833, 0.04626095475208375, 0.011630155063504654, 0.04927093335877984, 0.03348315209751168, 0.07543103183589636, 0.04705417368020262, 0.059915778692811734, 0.044529167033972285, 0.021430507204645587, 0.02645777343141456, 0.02735097257931146, 0.009483734705305148, 0.021824895013724605, 0.008561299726997894, 0.021491167961709925, 0.0025818565946763325, 0.05545411709575884, 0.013708592779303511, 0.0096355130024735, 0.03403077855886471, 0.0462996038878637, 0.03358879945270958, 0.030823949829585133, 0.03999578811588787, 0.0187533650727522, 0.0524034668811627, 0.06491400827203067, 0.036705789051108786, 0.04719216909800326, 0.03003112926718689, 0.07136372548918571, 0.050400641085880424, 0.05499940560830217, 0.04853763016721895, 0.046137944014082034, 0.0685609238702924, 0.07285507651226175, 0.025142651359220187, 0.07461780652163491, 0.02970024057093167, 0.04322606296609006, 0.050511823426331245, 0.09912896585921127, 0.024847242109958204, 0.019925887538721005, 0.023136370507399404, 0.04463816602383891, 0.02396137442349667, 0.021681494845618165, 0.048878048997252226, 0.006510366004095563, 0.01395657352517329, 0.06838333702856494, 0.035905434013975245, 0.08516796338822573, 0.036519422841769074, 0.034720280673354864, 0.023847223492339257, 0.03244298855744062, 0.03428026658272551, 0.010879732679665811, 0.03611823025670263, 0.06892729009832106, 0.03989851793214198, 0.03573348557937049, 0.03331806781070848, 0.03351864112060397, 0.04024173298309888, 0.008053894796889395, 0.09310607452906909, 0.038086095629560376, 0.025378012721757257, 0.047786940610216516, 0.08173703861933562, 0.02378353860319382, 0.04187997753521608, 0.016283568468004946, 0.04602034568726536, 0.06992313545197248, 0.04596613347530366, 0.05085830967272482, 0.05576694143875953, 0.009083066890466838, 0.006187181758333839, 0.0477023913164533, 0.03003962326704735, 0.039549503595598286, 0.07266874860731826, 0.015416418224753392, 0.12167792121369032, 0.04701853526996509, 0.041599305902397445, 0.050007921433256525, 0.045623044828854264, 0.019981143545479547, 0.022220569850516417, 0.0082475081979928, 0.025840074822847402, 0.056021822721607266, 0.023494154635456302, 0.10203689772395358, 0.04345745599317936, 0.013866667361599545, 0.02193265868681333, 0.015938117397919057, 0.024557683857217915, 0.0328865151612028, 0.03486847272142768, 0.04290616763154826, 0.05131734189607444, 0.06109902064406103, 0.013095026257477943, 0.013092409109606618, 0.021918712056151802, 0.057457574913578655, 0.05218249648028324, 0.022707625570136215, 0.08276756477331923, 0.0812000799323282, 0.04949348573122294, 0.03479990785220458, 0.11228520828749865, 0.026655134917687506, 0.042714833342019594, 0.08633424032239184, 0.05262466327797982, 0.03868803389430527, 0.043932905480746305, 0.04301233209609505, 0.0038501668642575465, 0.04489292473261876, 0.04788863878216475, 0.0631291536434043, 0.07004759409615109, 0.030562123959703796, 0.08578854823304762, 0.039389494641293446, 0.005083376421563087, 0.031132275321250482, 0.048213502196895505, 0.02472362807771612, 0.045754942186777635, 0.00976787001315144, 0.05851981327718785, 0.060824757336729, 0.012188629329865499, 0.028380071894536098, 0.014968807414744892, 0.009273685845396212, 0.08964662064587878, 0.013591355471421155, 0.03579239774074766, 0.023690686831551216, 0.02419335350784804, 0.09878415734537187, 0.024410102764264714, 0.03620162275770018, 0.038308648002003474, 0.03984423677226709, 0.04673689453592224, 0.04062638956031973, 0.05630780334374117, 0.022796759900126248, 0.02093652221975067, 0.06880913635775929, 0.036555157012997136, 0.04708462567519277, 0.0827271459744342, 0.06372755641237864, 0.05466177150787366, 0.004054417874994538, 0.04180531460611571, 0.07623108043786019, 0.03499106594151066, 0.08638561417859408, 0.024442839616489027, 0.02173300085198735, 0.060866758107177676, 0.05017559509724379, 0.036373287739772955, 0.04642471370677795, 0.014214298909439916, 0.034396842182163274, 0.04648547214005263, 0.17605229100633055, 0.12478778619439372, 0.17032979807305723, 0.13402571871636376, 0.15410877493841035, 0.1417655969459203, 0.17730210216776018, 0.13615899779383214, 0.11894405218622378, 0.10300749281962072, 0.10011714267274065, 0.08339337433778471, 0.2713196910917759, 0.08556010847490642, 0.13628748606049246, 0.12100960909118577, 0.15608670670659314, 0.3196161108151559, 0.13127615254732872, 0.18177433960860778, 0.15530710499132835, 0.17751458431443862, 0.1694041340341491, 0.10215869804303493, 0.19723037798558513, 0.16315783614352827, 0.16517512950926058, 0.30842264693590904, 0.19382700173845216, 0.1351832316046761, 0.12085521173092628, 0.25241515388892544, 0.14325762978724896, 0.18869566821282913, 0.1568606700147352, 0.09860236468094011, 0.07778125169176249, 0.16991419537413507, 0.15468858092302276, 0.09278408011361476, 0.12691870572105532, 0.13602862495087809, 0.15050456108104798, 0.3315859281968686, 0.16508869946964327, 0.11879240508161246, 0.2368185690213596, 0.15184953568443177, 0.16463569635825773, 0.11410692706704141, 0.09668901412477417, 0.2426876605398232, 0.05930249849634786, 0.11816689429143745, 0.12226606989579818, 0.1103460482291637, 0.1456327628224127, 0.0863405145824917, 0.12401153994423729, 0.1475275280855356, 0.10620545025073713, 0.11723163117083812, 0.2139014624539883, 0.23856269075505196, 0.18081645391160445, 0.20607840239761338, 0.18401634188429003, 0.123680459726001, 0.2154528671094487, 0.3356696364860381, 0.1418717614104671, 0.16035574698640456, 0.14591217041015625, 0.11236464394436729, 0.1647027137298738, 0.1107485584854599, 0.14442395268669053, 0.09696543396961305, 0.19243177176723558, 0.1168908292968427, 0.11400240969153182, 0.19765008691578143, 0.14565781389753665, 0.28137585148215294, 0.10579631333389591, 0.24923328430421893, 0.09347507609955727, 0.11735971341089857, 0.06823977981243404, 0.2321224347237618, 0.22110880232386051, 0.11202014952657685, 0.2015227073382947, 0.1732549056290619, 0.21284203946350083, 0.2606685255323687, 0.1060417372613184, 0.12504351400439778, 0.1595048990941817, 0.16708665677616674, 0.1331991558113406, 0.31823194315356595, 0.16478283120499504, 0.18861608699925486, 0.060334832617832776, 0.0863025549258436, 0.1565321102257698, 0.2734401918226673, 0.2828381907555365, 0.13573020306085387, 0.16792343929409984, 0.1008408812565669, 0.0926723538507377, 0.23356370657922762, 0.1565054963312803, 0.1441733653266584, 0.16526899060174344, 0.15460375966804643, 0.1613959258482341, 0.15876370902744033, 0.17169271445562764, 0.1047386906500305, 0.12809712514882127, 0.1638125042401014, 0.12885834841478255, 0.16111230477690697, 0.11690092633568472, 0.11442650830553425, 0.2206198084017923, 0.2731155850473912, 0.11199018782785825, 0.12435847818250619, 0.1264886852473982, 0.11555629647186688, 0.07918718391128125, 0.16641914904598268, 0.11327436569357112, 0.08556515699432743, 0.16887735665565537, 0.22814725044994588, 0.12104924648038803, 0.19135252242126774, 0.12609258714702823, 0.08088868817374592, 0.08145677301311686, 0.12610320512565876, 0.18252879831819765, 0.10376963539109116, 0.10622177558440356, 0.11886526004321153, 0.12741477063466466, 0.15880169166672617, 0.18584174554674857, 0.12846245715815213, 0.12539772241706812, 0.09139806618012729, 0.15322264103639513, 0.15167992381799608, 0.20052394318965175, 0.11462192967413895, 0.20723226870740616, 0.18392111715530196, 0.15361817223170113, 0.08621813969746714, 0.24982386148504673, 0.13815251179039478, 0.12364080701504024, 0.11836602352559568, 0.128900452607101, 0.09143024187294707, 0.14914383570994103, 0.1265615248872388, 0.16927645782068854, 0.1776980776940623, 0.14926978056469273, 0.09816584778168509], [0.029329007769364025, 0.05258079708343553, 0.03199336389380117, 0.029387703510902585, 0.04511787112982524, 0.022308560794279463, 0.007447579297267142, 0.029499004594981674, 0.04129346828126619, 0.05092395574695641, 0.0591790855621859, 0.021281918706071955, 0.1253528909517392, 0.025024298435798096, 0.024805553520338672, 0.008713725368462263, 0.016244162820399772, 0.03205401124432683, 0.01191316901015178, 0.06329088629553876, 0.07765487016689393, 0.01071313058116263, 0.08694188594217263, 0.013834527100346262, 0.02113541588187218, 0.05527719675052551, 0.06590098232751893, 0.006225590534027547, 0.08480223301317423, 0.04059672663589159, 0.1066095463090366, 0.00518455556894262, 0.03110370024167482, 0.0782277736993086, 0.08035750578968756, 0.010377382014637754, 0.025220483977107272, 0.03250673090318038, 0.054826101198071436, 0.023329625762398207, 0.032688067745297186, 0.07462746689036008, 0.02002434324352972, 0.042004129744224974, 0.011668204735483856, 0.04000687340815221, 0.057391909687148954, 0.04618159187356791, 0.06519838010952358, 0.031230089427422614, 0.06465359966480924, 0.032764339459038554, 0.017608077032491565, 0.035762757798957254, 0.04692724440246821, 0.05954059479277461, 0.005532196214077093, 0.030031657867854642, 0.018580700345938245, 0.006738996805412876, 0.02520783203503778, 0.03387704769509935, 0.06878258375030372, 0.1555797403618213, 0.03728283328875419, 0.12150961935760514, 0.07892903526343646, 0.0651430455787528, 0.0507107075123537, 0.07174583482405833, 0.031098008208397417, 0.09868020687492625, 0.032557361654096076, 0.07247638392953143, 0.09922083512309099, 0.07237963468557404, 0.04608682679733442, 0.029792942955429037, 0.0679271623131729, 0.07523764060029099, 0.009100030949940125, 0.023447620539715695, 0.011022451987129547, 0.0121444231838048, 0.03190275101411728, 0.05636123414602011, 0.03754318443938129, 0.007040088511853209, 0.04477290556796136, 0.0893917125499537, 0.017421678264415073, 0.0739067466929555, 0.022671274698129105, 0.0261441312895547, 0.050730568341790676, 0.06745959587034679, 0.032780231953027754, 0.03459377274397881, 0.01851420008367108, 0.06705111778912044, 0.09650241042817793, 0.07190340378832433, 0.05619599281119243, 0.022127137767271172, 0.053582280844209663, 0.08475740154784533, 0.05315646236281722, 0.09228796923472997, 0.017548833538087148, 0.06598224127364737, 0.019226230928794514, 0.035837911024329164, 0.058579583457040216, 0.039424186932944486, 0.02910168841481209, 0.04952669947318012, 0.02634163258687383, 0.01825376657859212, 0.033167140828745986, 0.055415119389973344, 0.06846320935555043, 0.05570797565122766, 0.03849525935947895, 0.056040017309808926, 0.0364426838143939, 0.04091286813960441, 0.0032910490840403067, 0.06371869660553432, 0.07573021981384485, 0.03303714719931445, 0.060659060179586374, 0.03080274834628067, 0.04080478845524692, 0.039178854936072906, 0.05081296492848666, 0.036715617959177306, 0.05200497092558973, 0.018865056861672672, 0.02763861178180143, 0.07904463027033114, 0.05563025986174903, 0.026682355936857003, 0.03854130124372821, 0.05835217408715718, 0.027829319794452, 0.08115194662804566, 0.05219134096536906, 0.02020351971770006, 0.033380860207422126, 0.02331371220099109, 0.06660344664968791, 0.034653715293614135, 0.032152330968528986, 0.033613325757605415, 0.027551733580748403, 0.03325468552629313, 0.03746742983498881, 0.06574512940020331, 0.027839932027423096, 0.031455208194412054, 0.03996235220843265, 0.020449954881182602, 0.01618081309472121, 0.017294233792551586, 0.051326806912378925, 0.0386166115171246, 0.011729319399643329, 0.00555541202981746, 0.0990420608450809, 0.04296444010950866, 0.04426281741489807, 0.030153883365733974, 0.012696515937756388, 0.037041389188098336, 0.004589384733398836, 0.020774645926130396, 0.007222533787435462, 0.06296827134886576, 0.012610927637245868, 0.02123006604491703, 0.07209595998809223, 0.02006839138395604, 0.019404221881902026, 0.047888899252059004, 0.048459596451251745, 0.021188304676944693, 0.05721906492967279, 0.01704539119776699, 0.07055655993040531, 0.09681572506745016, 0.0961770145823398, 0.007604435320958616, 0.02054786091790565, 0.07232992324016749, 0.02052688926097847, 0.04433729265245699, 0.035734523628507896, 0.036633493333694436, 0.08897843875832136, 0.04754672608067913, 0.00949158997935874, 0.08489904354416555, 0.021102847568991206, 0.048676069916015675, 0.05382507709005187, 0.03443984269735313, 0.05509426261508658, 0.10571670147680468, 0.104660427107686, 0.11435182239379614, 0.021872848287344943, 0.045595733794353666, 0.05149478318109628, 0.017758458176808014, 0.0103916006065124, 0.07355309752446991, 0.03013491885916841, 0.046095548708352356, 0.030520799261848294, 0.01117549720220268, 0.06953879680124021, 0.048378383470398766, 0.025103695788270524, 0.01601603045503819, 0.0484012435340593, 0.05511294366912015, 0.036431108225858023, 0.0300519457913094, 0.035048537857590184, 0.01698527819356851, 0.010596897806070987, 0.02553985645664075, 0.09992365184570513, 0.03164305869910506, 0.022283113268654675, 0.1090260710747492, 0.036323269859196684, 0.038286170982305086, 0.05842735795604606, 0.05503369953423258, 0.02789594263078705, 0.057317507227942835, 0.07339856226838405, 0.01883595892708869, 0.016426112532856006, 0.05729900620457146, 0.0588865548882994, 0.05096100375897462, 0.028587984326746196, 0.03215051150970882, 0.1174589754232476, 0.006867446767676983, 0.010656565521663476, 0.003024669060851598, 0.0739482686584515, 0.0639799900443083, 0.027615470180828727, 0.06579639600409616, 0.0414867062992867, 0.010481586251708289, 0.05524699373411075, 0.06180251918492779, 0.03673413047386754, 0.03143543354986656, 0.05598619197224898, 0.03161738900798223, 0.03891544326418831, 0.07791282729275766, 0.045854476160339774, 0.043721331148258144, 0.05249740075199835, 0.009409904896822429, 0.036598410337202014, 0.045081623679687904, 0.03472935115437835, 0.05448991500381982, 0.03230066857330742, 0.1580543116095566, 0.058657306907398093, 0.04629460899459739, 0.006588976680030746, 0.0816665202259056, 0.02944518500308116, 0.09931026056649224, 0.014382075037687056, 0.041587240017590024, 0.07662062082559833, 0.08826788454767197, 0.056435379965771595, 0.023984498787491072, 0.10577318513946188, 0.08806721547678595, 0.01868543605650625, 0.05967561012854981, 0.032371520214984496, 0.02559653547171864, 0.036643237972091285, 0.05302816944857759, 0.03236171045911408, 0.04503026897568376, 0.04735788157690437, 0.021008907952496124, 0.07361194073793388, 0.06956810732522319, 0.08249028691000516, 0.006428364431485535, 0.028811823726902087, 0.0450668037087927, 0.023945575775278193, 0.02900013005391004, 0.0797482360635073, 0.0483095734530399, 0.06638144203011068, 0.020374604388170188, 0.0428327955606003, 0.025866326740792683, 0.042843321608679916, 0.06917966244321677, 0.060181312428246585, 0.016219282199838952, 0.05044714645332387, 0.05476895869979936, 0.02663252574782218, 0.03249319029911872, 0.03602502033895543, 0.042268529669531894, 0.030365896283558784, 0.011521774689636884, 0.044024652170558135, 0.05935124850140945, 0.03853031554289403, 0.025506878286720287, 0.02718342340461189, 0.04016230498710948, 0.027034442285977067, 0.01892407627535924, 0.04749366300060384, 0.0278630736283958, 0.045445553748117345, 0.08942358946848301, 0.048653581404998425, 0.038196508051647295, 0.03896271088911642, 0.02917967041984441, 0.12653730118707304, 0.0390037463887805, 0.05510496103294915, 0.007086131353712371, 0.025515648078233488, 0.03824500524769387, 0.025818528599977016, 0.017470393795520067, 0.08387382637949721, 0.23330293024980256, 0.14079519337223423, 0.08308892333579641, 0.13163918629288673, 0.1275001511338257, 0.09455123811119026, 0.11926973914547313, 0.19705252301308418, 0.12499105230334306, 0.13529785367990696, 0.1190959520998501, 0.24274694042340403, 0.2595895979433291, 0.18481008558263703, 0.09956443321801002, 0.10734430889809325, 0.11769750455935156, 0.12001629182768446, 0.23337079031813532, 0.1845530937275579, 0.10308773286880986, 0.21410318872620984, 0.1342129659268164, 0.07668193084217849, 0.11844555877389447, 0.1825095082242643, 0.15034561315851827, 0.13934068351743684, 0.16079949575566477, 0.20835023613706713, 0.2123967278748751, 0.23941266530704117, 0.17405991081989583, 0.17857747002234384, 0.1363569702352247, 0.10395954858752028, 0.10495960742475526, 0.1277166858856236, 0.15833143625528584, 0.08703613773949685, 0.14798546480315347, 0.12276109292983048, 0.0951664450187837, 0.12323254343843269, 0.10761765673035577, 0.08689406673393904, 0.12055071476366251, 0.15537187006444703, 0.1669134902617624, 0.132062679697429, 0.0830629529551633, 0.13357251642211793, 0.14570126640460185, 0.17781164256795762, 0.12357748984809845, 0.15780468952030907, 0.2212266879336488, 0.22710722480570117, 0.1541248014977863, 0.11135382923267542, 0.21968099829410354, 0.15442808038525044, 0.18589992226371843, 0.14606826848560764, 0.2136008955177761, 0.29247471882450965, 0.12535472956275748, 0.12375578915159549, 0.1572855117340242, 0.14988018410100093, 0.3388031199574471, 0.1770969131781209, 0.18762550466964323, 0.1949953930752893, 0.1546700262734967, 0.13888409511456568, 0.134586050745941, 0.138388681375692, 0.15288786061348456, 0.12841194132042508, 0.23228012626209568, 0.10105254368916636, 0.19656026555645853, 0.1573497099020789, 0.16574954223488608, 0.12421970135502278, 0.17093002796173098, 0.1694134190197914, 0.15244185954572695, 0.18967941703815616, 0.2881833700643432, 0.1824845797232082, 0.21351271879769143, 0.1987238663939699, 0.18166396166047744, 0.21863349563171788, 0.11923043883495754, 0.15984689606533897, 0.19647176707944564, 0.27633937496331434, 0.2723652478908339, 0.15739385188827593, 0.15851819316946691, 0.1303383689974585, 0.13560992725674184, 0.10523770500214831, 0.17561624908158857, 0.09298416695767835, 0.1631529944678468, 0.2758991501985058, 0.13452675554060167, 0.1251154113560915, 0.13083307793544185, 0.1482602298980759, 0.18980263461989744, 0.10050282963821966, 0.13215313935952802, 0.14029700639507464, 0.12749757707840012, 0.2522151130101373, 0.2538914666060479, 0.10651236039496238, 0.16283713641666597, 0.13132502895689782, 0.15659324404212738, 0.13622220004758528, 0.17174296982346043, 0.22551244425196804, 0.1430957554088485, 0.15061011267525537, 0.09225533388915563, 0.10132321787457313, 0.1187818713726536, 0.14400634283740676, 0.09842552860537845, 0.1262514201563693, 0.0843858106001731, 0.12533360851868508, 0.17949173467293864, 0.16180809647325547, 0.1708353548160484, 0.09836899131656655, 0.22158748470246795, 0.12503199204201662, 0.18870810948071942, 0.12150230321792826, 0.09794509188542444, 0.11258956735893605, 0.1873342380408318, 0.16855615131076307, 0.11740362557071833, 0.1553975340099104, 0.12401757671708062, 0.12214196365206473, 0.09955415231806618, 0.17051557439469522, 0.21631287741324595, 0.10216668067920594, 0.17210791878882917, 0.08042119833971224, 0.10622582052864375, 0.15805642601222764, 0.13972853851174155, 0.2010281516178962, 0.11613558917757004, 0.1025072603877033, 0.15086161934079664, 0.19458829395232663, 0.1192416160577728, 0.1559834686979171, 0.10988441896775078, 0.14523954521263802, 0.09785585796400424, 0.0918987276212823, 0.15729637486079048], [0.0837804172788897, 0.02885637748535843, 0.09406998933803651, 0.020346690059429216, 0.06357083014482934, 0.033343467455838, 0.06289719371125102, 0.007859265850481368, 0.035787176851543694, 0.04505911984691217, 0.027732149202136264, 0.0732625893227035, 0.009515293697345882, 0.02328011541507177, 0.031412027648559986, 0.029049868312393947, 0.024058135158772913, 0.027102800311460614, 0.09662924394492181, 0.022808006070854685, 0.024805442437589652, 0.03235653936562519, 0.02304296906767113, 0.037565025606102524, 0.07067600835955913, 0.032410812864620844, 0.03117585040238356, 0.04949400284057183, 0.07226359534768328, 0.0336481865885998, 0.03207579686967356, 0.021750595976388263, 0.015482180169783534, 0.026184544342780308, 0.05608523181909996, 0.057475941871563276, 0.0414880661053523, 0.02163862839581505, 0.044838333307134534, 0.09248104637428638, 0.0340679491449508, 0.09702136604896477, 0.01952700662396608, 0.03414007632302181, 0.03690093845850037, 0.0023543078925520665, 0.06417101406822763, 0.06169348572110457, 0.07536229842732992, 0.0866111581243815, 0.07299250502499842, 0.007212569856370289, 0.03850242994245022, 0.05715148831387201, 0.028880302411233707, 0.014926026192223354, 0.023125342671729388, 0.05942289687452778, 0.013934520726662972, 0.028234790980575547, 0.040672373987974665, 0.06640195020384367, 0.026517800250721556, 0.03151378327710254, 0.008587042196473528, 0.09487021414022292, 0.02707356065061064, 0.03186742861514851, 0.045816784634465174, 0.05501839692794508, 0.013797685932067615, 0.04517899345486395, 0.08981725907013302, 0.008073277778983598, 0.06047240668727506, 0.02137092088589505, 0.030796583253710024, 0.04380824765370738, 0.02047786729470376, 0.06267697024609774, 0.03185887524347392, 0.033375470778874816, 0.0074613382363872185, 0.03939308759365832, 0.02481811736229687, 0.08268782268128089, 0.02135762159952954, 0.019020356290463, 0.030294196199505564, 0.05956055904408136, 0.013553495406203214, 0.04511736551179521, 0.012557924886594617, 0.022542797922787648, 0.05407046654351777, 0.15115303918719292, 0.028776913100192626, 0.05648653548691542, 0.016193758065421737, 0.02683547393028294, 0.015384072077370461, 0.04548008133086466, 0.032524013846752145, 0.03277370488391288, 0.05405701020912779, 0.03531851873342549, 0.08606960290982839, 0.032301733435522166, 0.05797836148450452, 0.021456600159346577, 0.019127857578437657, 0.04211607051172084, 0.04056933516215894, 0.015612529072489952, 0.02128701702120804, 0.062262198752573425, 0.0023978276717131057, 0.04773381624310728, 0.02340988496378545, 0.027032222546216463, 0.04722767727329366, 0.02690452335011815, 0.07811795499536299, 0.03367322617240491, 0.02915022008481526, 0.044559381541705904, 0.03774314487893735, 0.03478609911736942, 0.05189029139376456, 0.08416045817636675, 0.05007023885545712, 0.04104071672284796, 0.06770252235113614, 0.08245697740705744, 0.00450662664896358, 0.042686055249144, 0.03374195958097135, 0.05785838062424333, 0.03653500123970932, 0.08179177560152547, 0.017187554133875717, 0.02683336718849117, 0.08232020772993565, 0.07213294671307649, 0.05439284783337386, 0.03709634833578621, 0.02975626841127392, 0.02704526519312734, 0.013482622697108216, 0.012504131150161548, 0.058663738215522426, 0.04665126505818579, 0.024943596818634582, 0.05492632465076543, 0.11528924588234195, 0.015117068410730891, 0.05372046012311213, 0.03520237980410457, 0.07447417269671157, 0.06944641425845123, 0.03232297322322284, 0.00936190278509692, 0.00859933790765823, 0.0606024730950594, 0.10805064196427984, 0.03260727611280257, 0.04428608350515847, 0.058019465932081786, 0.026651827333074425, 0.0356785072794845, 0.025868603937147606, 0.045748112512932676, 0.02262868020953911, 0.03243938028331726, 0.007164776982409099, 0.04272305346544712, 0.003200982760209891, 0.037438452559252905, 0.0045057422962159885, 0.009198254913151746, 0.04105665135167299, 0.07455140968123752, 0.04591332320424338, 0.00583810996519582, 0.0701281865457854, 0.03269708460016597, 0.02925633858408659, 0.052636713841028755, 0.037861015166967146, 0.028968871751379584, 0.08435224062733113, 0.018579836581803618, 0.05430123520894878, 0.043671443502629, 0.021455173320587606, 0.04043299066383512, 0.07627547523307224, 0.06451632436965743, 0.04687984654259297, 0.008551297491536507, 0.018468024134035074, 0.049302791125111045, 0.031131873125090238, 0.007205650645999179, 0.04109087632969022, 0.08006472230678605, 0.008972329838622001, 0.03822943068019325, 0.09620294665857669, 0.04365885667803307, 0.09140397271802349, 0.01222585928776572, 0.06616801759528537, 0.01256492309978292, 0.020586178720658346, 0.02757644566196588, 0.05857511333400204, 0.09130461111424432, 0.0141077178845843, 0.07576439499614701, 0.031882616308247375, 0.027009071369144707, 0.04312309308818752, 0.034306279098194455, 0.00957072111627748, 0.07195636344652984, 0.011111282754779584, 0.05011484815528797, 0.01506109419654334, 0.04728149494997436, 0.059576179576857444, 0.10836853014846003, 0.029126283667621114, 0.05304820647823715, 0.028179536889036818, 0.0246495301384599, 0.03101888664757773, 0.07148221630843417, 0.07270583492373267, 0.024037491004433365, 0.028508027730089043, 0.08149382102513507, 0.05220683509363763, 0.01618800857555001, 0.00439123226134407, 0.09990671364169929, 0.04895335544020899, 0.040188451567965175, 0.08947919979090653, 0.034202389914782784, 0.019890534496235273, 0.0889627875820283, 0.030327886831195607, 0.04615510821402554, 0.05413111389404344, 0.07245248964717312, 0.024498631884794564, 0.032985646938604694, 0.036913234169685075, 0.01792016976152457, 0.04536158668117658, 0.054754234489894686, 0.03815039338904523, 0.008762775105424225, 0.028080636853232022, 0.07825672416196716, 0.012549602298907215, 0.06987822737785117, 0.07208430012988468, 0.04994569211116722, 0.030060506823863235, 0.06074285104630455, 0.043744321446865804, 0.052701432948871973, 0.05524041303884118, 0.0811893240578713, 0.008138173087049396, 0.10268464804657045, 0.04082327415685981, 0.02820914618731026, 0.003963940975917203, 0.030424402418336084, 0.01805191198664327, 0.08245477107383552, 0.03420849563553929, 0.10818866036471822, 0.010242927838267099, 0.06761749425242025, 0.036066339291151495, 0.05716368443362656, 0.051238185861298156, 0.028233097926262888, 0.04460222883931091, 0.05027156676195803, 0.1043240455610137, 0.010114537247817123, 0.029620485072354638, 0.0024860647212218254, 0.11668780833602914, 0.045792894182546486, 0.023772171773617307, 0.015426810207446257, 0.0313246380838175, 0.06385658477102557, 0.0695469020114791, 0.05559966997093251, 0.038777685333644195, 0.08943828303487071, 0.06042614646796739, 0.025136773549621145, 0.045456321113893104, 0.02085061503514167, 0.033958731820025755, 0.05351850402451331, 0.05354539371065555, 0.01526782589574014, 0.05364060694832475, 0.050949087261312434, 0.05458564918127753, 0.1258765963176566, 0.05011244263920573, 0.09774572516400969, 0.03728511623076854, 0.07521674938259587, 0.04057823710383908, 0.04848547490133394, 0.045570318827465664, 0.0407128464130144, 0.06686772400092694, 0.059626013596331885, 0.08630612489557074, 0.020850331582609686, 0.027792978498543945, 0.025939174041512515, 0.004120506365002404, 0.053541356427294594, 0.027913034052377748, 0.03104556948998042, 0.03360354281481236, 0.031850473174164375, 0.07876096323372857, 0.031095045363350265, 0.06342555689174803, 0.010984751842765799, 0.022693790022223707, 0.04042750547429727, 0.012146704210599345, 0.023298507270913933, 0.020147570401370045, 0.04530686885118485, 0.022452125671289624, 0.04391176528447578, 0.23561939627172487, 0.22246827131077168, 0.07835630027036514, 0.09908214256527925, 0.1375348610623229, 0.12980288886014493, 0.22859328216122043, 0.1253863766549095, 0.13783247089914738, 0.12492175198971264, 0.12658447688145022, 0.11262450862916247, 0.1028205673660963, 0.10554728113235005, 0.16460823976705152, 0.09798230843678599, 0.13826540250691677, 0.08561307579399118, 0.223066815806012, 0.09173594159825195, 0.2034720946704188, 0.17803400724885926, 0.14533458608052424, 0.19307606703331395, 0.1851891612093295, 0.13712206224520362, 0.1399523894032163, 0.1212141622278479, 0.21524059946738908, 0.13718535642950766, 0.12596521736873736, 0.10837433709492607, 0.14929164471405168, 0.18861921263798592, 0.16872887349417134, 0.0924519656766807, 0.13386232748387322, 0.0745035138642115, 0.08865816804069666, 0.16371606909219297, 0.16872064570986456, 0.20747147200088348, 0.09303091364281793, 0.3167275609748979, 0.21889345990794323, 0.1271418977769152, 0.19282695056209642, 0.13552283838150964, 0.12051233375865607, 0.1442654490951569, 0.16072369901643646, 0.14248378905317477, 0.22404890988142262, 0.1424029667771632, 0.1962974054678794, 0.2296686857458084, 0.18201820071666472, 0.12056261977000583, 0.11272807605564596, 0.11028283831453133, 0.13058129547824784, 0.17822238826943984, 0.16134916384133602, 0.15081450493345339, 0.16779415429599825, 0.19651670579708394, 0.09509003540921597, 0.2019475184140667, 0.1973122727846907, 0.24527913680480373, 0.18002047323651854, 0.14834305932444913, 0.21268457775154423, 0.10640614230426089, 0.15415637964202514, 0.23262161761522296, 0.1809946153192751, 0.1437458729431514, 0.09766035232572787, 0.16101724858726227, 0.22019352643720566, 0.21812043122706876, 0.14236578086931861, 0.12756360619659388, 0.0837661527217396, 0.25145293213427067, 0.11242934773045202, 0.12538696654261122, 0.22900416575852903, 0.219430839943309, 0.13651190385703119, 0.1741458505632416, 0.17374354715068496, 0.1933472008714753, 0.1961956230262595, 0.32708151506320127, 0.21697986420364151, 0.23104205156766602, 0.16488970047043217, 0.11799399590780658, 0.14533757382342893, 0.14856524014424893, 0.15989365807223707, 0.07449621304629311, 0.1361374400796429, 0.10349358326845592, 0.2504929933216303, 0.19258146534763998, 0.11698250703874136, 0.14790107255741475, 0.06956929476150582, 0.22831663249000428, 0.14453008650772034, 0.09884853937452841, 0.10614581796671115, 0.25373064942898294, 0.15854531268198646, 0.15012835062319232, 0.20245828455494297, 0.10470387195387196, 0.17305736219690693, 0.12937908902043296, 0.26783910850363396, 0.11053804518474687, 0.18375820089732448, 0.13025946194125762, 0.0930156225278493, 0.09940429019831842, 0.2176235772428974, 0.18764965176101656, 0.09863361340737152, 0.1670037507410011, 0.11928513751275117, 0.12923822077291627, 0.1430588146491397, 0.10710559590088745, 0.11114674034498392, 0.1580091583872995, 0.10809037894491227, 0.16009539966621708, 0.22879016675776054, 0.18296324678005713, 0.18578084155676827, 0.23516558110713962, 0.21996460404367218, 0.10305505155796006, 0.11888618956530288, 0.11208510612167659, 0.12813645610285382, 0.10663848911081591, 0.13831268545360337, 0.15916634951868366, 0.12274245401063275, 0.12765317719670075, 0.18709057611563515, 0.12814676764631464, 0.1689092718785809, 0.25290453085495584, 0.23542721545503986, 0.1536833663140574, 0.09828512001061633, 0.13741833908903983, 0.13581729193608608, 0.15053097579267719, 0.18210582585344393, 0.16294274929790728, 0.1330764898129048, 0.13608266479305683, 0.11252107909850537, 0.07249606472830619, 0.08423745001275694, 0.1657750836062816, 0.18166503418357144, 0.12288082481151628, 0.09153980776787767, 0.2545516352139173], [0.08578566774245232, 0.044098706059758706, 0.008620236786232601, 0.051567366181482235, 0.13491890062728237, 0.024914711473449588, 0.02489835932670582, 0.015018429802430254, 0.04180755541329423, 0.012057293131346665, 0.02260111253558388, 0.04235584071026214, 0.02142552571791795, 0.038151711060275, 0.035841955968569365, 0.007269709003007701, 0.019471032409778526, 0.053714143728176435, 0.04558259155601264, 0.029894424707538662, 0.0059650727592769175, 0.08601654366019272, 0.04635940088079341, 0.02104432419723561, 0.028969394606387908, 0.0887940873602225, 0.09758597284915949, 0.04435676277705258, 0.028729291159599542, 0.024546138912199006, 0.04955867598313959, 0.03366439317863795, 0.06840859494742847, 0.05403294738742614, 0.02626124315053946, 0.0770033660134481, 0.03850942815563852, 0.034392858524957014, 0.03760957361889943, 0.02450155067978607, 0.02214799834144933, 0.021179157587128784, 0.06788314290104375, 0.03507386089392728, 0.03972743134645205, 0.05056845264569406, 0.02686450674739336, 0.04874196113838304, 0.0754020813732378, 0.02504774072628108, 0.012587882754873606, 0.11709300756093957, 0.04583686379896057, 0.029704720270068898, 0.06687772910921805, 0.024083649717091073, 0.0524829485033068, 0.038200319339070594, 0.014369351274874664, 0.044590664742093895, 0.053252016509612726, 0.087467989163293, 0.04903567541811255, 0.0006124484524104534, 0.05381016135816613, 0.006846504317851918, 0.07091396292971988, 0.030998518284890923, 0.10112595789495016, 0.07291708366885301, 0.10199653255122323, 0.06278125396479042, 0.08889351025103562, 0.03105226318321882, 0.0870017480525759, 0.1044774623287301, 0.0675670167190894, 0.02859880531867666, 0.016174577139017564, 0.03675075841226405, 0.021431328833944375, 0.06013282672351888, 0.04008319491760866, 0.01592719681455844, 0.043342550465416525, 0.06393378345115532, 0.04268862164369033, 0.009793599076088398, 0.09643805904253837, 0.04020028379595569, 0.03353646798660198, 0.05506584075309577, 0.07475783207243489, 0.04703637362728196, 0.09190114845912303, 0.20770918908378772, 0.011753599598793494, 0.05330611380838579, 0.0659880635418719, 0.054346350126809655, 0.05264972584442266, 0.017996475949222525, 0.060090109660861, 0.04731464357445798, 0.051653489785929846, 0.041763865418972514, 0.03274652791479903, 0.034434928243318876, 0.004600177954642042, 0.028681745827798883, 0.0728976097138178, 0.01986140974857394, 0.059894473787637494, 0.013656579239684488, 0.0370636287205402, 0.03900545476485164, 0.03634989907544467, 0.015282906336529602, 0.034716488538129676, 0.06434724110388948, 0.05507081266372435, 0.046847908337029724, 0.018454278601453673, 0.004332528858926267, 0.01777967881231058, 0.05641103752197758, 0.028681303412022612, 0.030554321354195, 0.006701730458336252, 0.023819715190198154, 0.023682665890984, 0.09862514047492897, 0.01913597811043503, 0.02884973933349454, 0.0503313024678538, 0.056063141673803336, 0.06769991765219359, 0.02231374529430703, 0.04996191785340348, 0.03593795061592133, 0.005810994761920865, 0.04847658828141228, 0.048386737659213044, 0.0386329866465061, 0.029260724437453096, 0.03725118236616254, 0.025793864399254806, 0.03004667893682997, 0.05035582877274963, 0.04935619894475226, 0.05353557246346628, 0.022655665656671892, 0.040058929082607074, 0.05673864736191689, 0.02360541933035899, 0.012798303167425818, 0.020098625043887767, 0.07497085048066032, 0.01595770818136272, 0.04849294425859567, 0.028226258676318873, 0.0157315188064991, 0.060458417921777696, 0.0404823305565984, 0.020943734937557773, 0.09569149103856857, 0.009486133518118051, 0.04100155430815874, 0.024732610458628308, 0.0028249719640195013, 0.01564910019477529, 0.05159983298771324, 0.017926288888819756, 0.028469483931398684, 0.022473007312885696, 0.034074782649235386, 0.06330035514228287, 0.06861345451926032, 0.0283428993932302, 0.01125255415606643, 0.06539439902670922, 0.01516546218490769, 0.009207206650546963, 0.030657461686660687, 0.014376351403282776, 0.02821089286777762, 0.034241326333534335, 0.07098202218091296, 0.09501167993632056, 0.029781001559909315, 0.046369019114682754, 0.052677209248706225, 0.10131390990629312, 0.006269188597798348, 0.03843512911830218, 0.05943944437369224, 0.046017622244694543, 0.08683404374507167, 0.035192121886798454, 0.0428997133407862, 0.04804540718454988, 0.019976005010727434, 0.015222001388939399, 0.013678823560175878, 0.02256274110667648, 0.05352436842757368, 0.002466657320075038, 0.03189362116127966, 0.03961105109943498, 0.00807848813447861, 0.02859814839828159, 0.010762057744056709, 0.030817053123046795, 0.023455490177917867, 0.020502370616961873, 0.033642333676858295, 0.013782686888120108, 0.045228896422251585, 0.01239419561780749, 0.041726231349692236, 0.026868427202345866, 0.043217306581115535, 0.0047402049418568855, 0.024323944685860507, 0.02862353655209224, 0.011644395680407123, 0.024744542278048974, 0.03356658290290544, 0.04593717535176585, 0.026668049244871064, 0.09537839856479438, 0.04127128620541865, 0.07705062597749696, 0.029082369592581547, 0.032226361875091834, 0.01757716729996666, 0.016564646127423453, 0.011022511358943679, 0.043787931001955466, 0.04313641535719076, 0.04555059206341544, 0.0682278365016945, 0.05593752240641944, 0.018645245168778687, 0.02775125735018763, 0.05248660274270562, 0.003485354597702803, 0.07809748512602623, 0.044013949922255935, 0.17019338845725984, 0.14196617408625542, 0.010790950750120947, 0.015329137827540118, 0.06155846272445014, 0.03625613374395236, 0.017774138081398223, 0.035014619314742666, 0.06505722074859566, 0.03502598422909937, 0.05032125139428724, 0.04638259036226138, 0.036174346197156176, 0.0032673094556817128, 0.033360306068413684, 0.07565342716031498, 0.06156721144854542, 0.036927663435738896, 0.10801499589316307, 0.2118467839975511, 0.15055026588661058, 0.05997246919920849, 0.2147526014596224, 0.04142398668092586, 0.05640399334351382, 0.03467624593946723, 0.07595377959190838, 0.06338706480399256, 0.10012902469644624, 0.011767523246817293, 0.03110099020564268, 0.03171861986629665, 0.10092465297108698, 0.04938119256328191, 0.04696262234281148, 0.03647211691244476, 0.03042128252526445, 0.06546719270127435, 0.03238139125788885, 0.06409431717568828, 0.017828384767316522, 0.05829294782973105, 0.05415431869726989, 0.06542858953076987, 0.015177054052811959, 0.01697942911226663, 0.046959703547819975, 0.031150125169886217, 0.07480533718461953, 0.026453263088760358, 0.08376544025997001, 0.012795639096669132, 0.054174788566606666, 0.004974669502717593, 0.025103668975193175, 0.055051235286819364, 0.08393987081944944, 0.05435136417227407, 0.03928764708219998, 0.018583406551530766, 0.058996745144888285, 0.04888465267515952, 0.035664369126841906, 0.037986048377088966, 0.024872092087002053, 0.09162311216876393, 0.03801219495794466, 0.026380865864696044, 0.032140065900861256, 0.086788178061045, 0.10676409688688095, 0.0659763423966304, 0.10229885382878204, 0.07402743618454664, 0.034022206034992016, 0.021839065725103985, 0.04392787994396302, 0.023136188561517387, 0.027439720034899733, 0.06670603348362832, 0.017262364534901518, 0.004861463732536762, 0.04801420059295432, 0.024015661329030994, 0.014652617072926895, 0.047454496755475, 0.021060417789304932, 0.0250419452711339, 0.03307374321945733, 0.02834752464907304, 0.07172158048037561, 0.02685748172112771, 0.03880020448817842, 0.07394233147703833, 0.020249578838927612, 0.04172046653806202, 0.022463354605039763, 0.02821928536098811, 0.03526457082179766, 0.04787094598155349, 0.015236001645755625, 0.0178935980018709, 0.01681985874329844, 0.1446105257397698, 0.14708146573074404, 0.18537389565139048, 0.15477194661094298, 0.26503341873326614, 0.12710753873351122, 0.10473712783066497, 0.12263269659372107, 0.11642818113849049, 0.16974855184314713, 0.1387720624165189, 0.14290403424491807, 0.15951678877876652, 0.13878404403165465, 0.16437957784341228, 0.11804241266462112, 0.16203766238064538, 0.2056574217614628, 0.1540066094528283, 0.13460550937921772, 0.12934026368443044, 0.10961377542586097, 0.10446870594375557, 0.08749464902305797, 0.19985988285512696, 0.127408565322478, 0.16959842925350513, 0.10460482444614173, 0.09284877623882025, 0.13684335945835038, 0.14654644524618504, 0.0943179183729714, 0.12398113391452259, 0.09730295698729255, 0.11064319075235438, 0.13671553002730494, 0.1374686404221481, 0.10416591735256296, 0.13904682751144135, 0.13161562142833588, 0.19135370219667114, 0.09497133774622794, 0.10828952350082899, 0.12123566631588245, 0.1627823917735969, 0.27866512597087895, 0.0748845813195071, 0.12252734418237403, 0.15285459707581228, 0.1989039276996928, 0.13441596390499225, 0.18038042730862097, 0.2936893665502149, 0.09494973406676324, 0.2446305667681079, 0.11849657256877232, 0.23730793066563147, 0.1559876975032591, 0.10709094829977521, 0.18201582584409945, 0.11158166378135644, 0.18446651047035573, 0.10684658923456747, 0.1077372353944567, 0.16428936332944902, 0.2622284644073056, 0.18031367040689916, 0.11783200661621748, 0.22898222500037765, 0.3890670066879642, 0.22400849108253756, 0.1659536587014314, 0.20453183941783445, 0.27090634069135117, 0.17295490559791366, 0.20505645642838172, 0.14581254833648283, 0.16295813234342685, 0.13339769515779712, 0.08940615330732639, 0.10371762568191176, 0.18190161745634773, 0.14809146072835694, 0.12027053342711543, 0.14635208873979508, 0.1416265519876634, 0.09576144252693462, 0.1763847425219513, 0.18373098945425403, 0.17552087113501566, 0.15019634858735148, 0.1806830933257457, 0.3046883973142793, 0.3092462833850615, 0.27227362377508996, 0.5325008520195561, 0.18586416127941302, 0.11005302725900566, 0.15652425016366667, 0.15814418904483318, 0.22362659625228376, 0.19887109317125815, 0.1523665224592532, 0.10344426252789075, 0.1088528585950694, 0.16383121210721233, 0.1552721100949472, 0.08945502971689548, 0.17888614216879492, 0.09152290020738879, 0.18879049457609656, 0.12566136391532998, 0.1977106231835581, 0.11679505298454916, 0.14948696649122625, 0.23532592330969151, 0.18849853846815326, 0.07330487737612379, 0.11237939879778894, 0.18396810898857732, 0.1936070885389082, 0.20506007236338433, 0.09516217790904546, 0.2108799350718337, 0.14034287973998055, 0.17684228087384857, 0.08709302742875392, 0.060926597234943224, 0.189200995129443, 0.17002803603968314, 0.13980959061413042, 0.15566109889937987, 0.18793394698971705, 0.12543447931567508, 0.1892087785827537, 0.21712217269645584, 0.1552016453276719, 0.1392388244670245, 0.15319244185041997, 0.11282509343037683, 0.17134808214201083, 0.1277580086682593, 0.14582425415996583, 0.15932394912646664, 0.11832402658558662, 0.18460488127123925, 0.13256207709350895, 0.1306268011009501, 0.28444501421143936, 0.1865197486814953, 0.17830598378373733, 0.12971766923944797, 0.14113775724845548, 0.11481830865264901, 0.11047595375848394, 0.18906985619856467, 0.1797549931272384, 0.22177243364914773, 0.06672172296431757, 0.18984293084471457, 0.1627733212925734, 0.09706073530739355, 0.17206152450413476, 0.15108320261201552, 0.12495629489421846, 0.14497381995522207, 0.18894294607302836, 0.14442373818207171, 0.16369867889631182, 0.0886374683449826, 0.1127194575664978, 0.11168100240249788, 0.12519368255931523, 0.07066831683679935, 0.0928158191363177, 0.09222661325287435], [0.011112550630294269, 0.04126736766568596, 0.012484940647658323, 0.13187822104702074, 0.040269545805189884, 0.03504160859231507, 0.06476363287337365, 0.059521362155435555, 0.007929486427230821, 0.03984759989825468, 0.03680308987837165, 0.04474212798560339, 0.07114940473148901, 0.036192104115241, 0.02924000558954093, 0.008411261407027562, 0.04431028805312611, 0.08024084592057813, 0.04481257743112022, 0.0206865381539589, 0.017620778770276138, 0.0400934758175525, 0.060098889028473254, 0.019481508662143064, 0.06429262669576753, 0.02564504415908408, 0.015350991443190125, 0.05337630661444799, 0.07158207586936413, 0.03817072536255564, 0.07218178481824937, 0.028565721811666608, 0.014755246999313035, 0.0619209831910989, 0.006807702922097017, 0.041635928735617674, 0.017230928116928668, 0.006154092505664355, 0.024572425304100882, 0.07494257417537513, 0.03045159470920842, 0.045375966151515325, 0.057227150987713575, 0.015067708408159596, 0.05658671680477358, 0.07341151681518363, 0.027299907073498737, 0.05273312983673908, 0.06009025904800623, 0.029630436554491043, 0.020903429136641567, 0.0739654673323516, 0.015463097877199612, 0.038074646445532004, 0.036256926644953995, 0.03882709417432066, 0.05405399565314574, 0.03993186190904629, 0.024545541363618067, 0.05886254952319207, 0.04690867060074403, 0.05084514445174606, 0.02615466882895318, 0.05894574667176893, 0.09856864149051328, 0.09908570487412716, 0.07466266096960153, 0.08496579278500811, 0.21645057405675613, 0.10950616305513729, 0.15201252855120168, 0.047918397467583425, 0.11351620432950797, 0.06369882811521811, 0.21151063993813532, 0.08396937286541348, 0.05505156087418718, 0.03827143145064193, 0.028874633360594034, 0.06038858900747954, 0.062013174211906816, 0.09287018073542465, 0.09421933051799575, 0.03793355220207765, 0.0649734873384718, 0.09665892219110843, 0.10247967356154997, 0.02250589163703544, 0.11954088064451372, 0.09619232867994616, 0.030898681706598694, 0.01060331283482693, 0.03963483429904427, 0.03401135439954458, 0.04249736013251447, 0.08957152104666156, 0.04933129725677352, 0.06469817832112312, 0.05429473878335088, 0.033965841115963076, 0.09085411311037118, 0.06384451505577853, 0.08111795530684533, 0.06996431267790257, 0.0531544896864122, 0.016699833832981608, 0.044919412222600756, 0.023927492269825552, 0.1155856529611253, 0.03771718598962311, 0.05462766144304507, 0.04442025231377733, 0.04424919254116474, 0.027554332534031525, 0.013848732285682234, 0.05039281166729428, 0.05511934433372752, 0.014964816096659391, 0.033284651055451364, 0.018554532697664636, 0.021015097942924308, 0.03705055159967273, 0.046750182330968885, 0.029241428597860282, 0.035444624466641296, 0.0695164040512135, 0.024229509027434454, 0.10461515131136102, 0.03032749038069479, 0.030026829598711866, 0.014423107664521425, 0.046839236221726865, 0.008689472939999355, 0.030510014659094236, 0.030468408423926563, 0.11690360764341971, 0.038588277755245086, 0.11379845410345063, 0.031753176177341136, 0.04957518134746821, 0.051272016304034385, 0.04674122293269442, 0.06494978457809457, 0.04969912288229793, 0.034236553605766065, 0.07952531979930016, 0.025634895409307173, 0.12671441305428743, 0.074871894903481, 0.006310654064309934, 0.003610513015319744, 0.04546906115607389, 0.021107357911645405, 0.028578253094888026, 0.07557542408786475, 0.024346726225508798, 0.04372473257864195, 0.046246701686252514, 0.07730618524815767, 0.032660094044742086, 0.030980199207401568, 0.07027345213798747, 0.034265423629192576, 0.03212212029123499, 0.010357813256221914, 0.026014022746934526, 0.03879456608105571, 0.06552851037873376, 0.02877380278322005, 0.05751023196705407, 0.01584795651011049, 0.011754519861912536, 0.05011404376296748, 0.038196580830000104, 0.04869109673065044, 0.034770865458995104, 0.046110866636398344, 0.07005628919409168, 0.03562703766229172, 0.02908719211606489, 0.05528167836488255, 0.06990862574668662, 0.05439899568896621, 0.06904650104021834, 0.05770884026142378, 0.04143243280029105, 0.05455583303926453, 0.06372593613641878, 0.03639776424895372, 0.016957342797409625, 0.05791016816792469, 0.03185421551367448, 0.07667502838998072, 0.08053475555272833, 0.012393968664259921, 0.060130455681393226, 0.02856862720011944, 0.008764348458498716, 0.036792456577982635, 0.05559192482201804, 0.039967416049612146, 0.07619109064821275, 0.04164569252621263, 0.05771494215174068, 0.05370376323680243, 0.03900223336513004, 0.023063030995188222, 0.0896624633441529, 0.05494793216066976, 0.018142804488419526, 0.030765125768319256, 0.016502068235328602, 0.03711961442604661, 0.014482036105266985, 0.022271338497258486, 0.11611694259749306, 0.03285065458546723, 0.03909229849194808, 0.02357384693177958, 0.059751207684917804, 0.027148097175203507, 0.024323822111792626, 0.02681725444422374, 0.026359846327273596, 0.13036245480179787, 0.042230075886172634, 0.05180044843244457, 0.03840345138263318, 0.019397066620689248, 0.04742963337189248, 0.07667742624518371, 0.047451501351691065, 0.09234587782092633, 0.008963296704384829, 0.11228309388482764, 0.045770738919776295, 0.07828529924154282, 0.03729976000144117, 0.02070289987680172, 0.063939310775529, 0.10098640731866322, 0.05633062893344511, 0.06904869205168179, 0.12283819201853007, 0.03917422010413101, 0.07941920130002884, 0.11587099006940281, 0.11593562490757435, 0.030747471272104213, 0.0736596756764958, 0.18229002403395791, 0.07028325806341826, 0.08314031251375714, 0.03190318959945392, 0.039942885914276686, 0.020235113183697386, 0.10257426243756088, 0.0484372534969401, 0.10270263579103256, 0.025160267551039017, 0.16185881149384285, 0.13700043812634485, 0.09391555367338081, 0.13267821602282986, 0.17339375140445848, 0.05183694103071767, 0.021932509299668095, 0.08658234555754932, 0.13809602046685834, 0.0809100926703503, 0.11523413351706921, 0.0632274120805725, 0.032856143605444706, 0.05122458397020256, 0.06514001953145189, 0.04592302187736477, 0.12068578372559241, 0.07114609523165612, 0.02278526666604223, 0.0455583525340884, 0.05227803530532026, 0.023230656778680223, 0.0687378901808012, 0.05877526529553918, 0.13648300702052732, 0.062218489606053605, 0.01973781486852996, 0.040018900988563415, 0.016363465692847967, 0.04247456518632751, 0.01531032270811979, 0.026810330924608057, 0.05527394087684732, 0.02201121717300867, 0.011413879823991129, 0.0556754092535665, 0.09590495377779008, 0.04115563757236927, 0.06657648035475323, 0.054167985705839056, 0.03519748833270804, 0.03388681148569431, 0.003119877749873746, 0.050492226897228154, 0.048362686328830264, 0.05544241127227584, 0.014912164788843404, 0.036046876827435154, 0.035030155577847076, 0.0073046397395251745, 0.0048207174310640945, 0.05159766878932715, 0.04162624155381515, 0.039456994648301796, 0.028526069100705848, 0.043214192433703336, 0.036378294124358126, 0.059883955400437124, 0.05806451190202948, 0.04119221060987442, 0.09312573234520613, 0.03475213843968607, 0.06836364856891095, 0.04589048612322058, 0.0060284181757109066, 0.037585323105656335, 0.05974513643811788, 0.014048598879467578, 0.032880022566044526, 0.05361910669072982, 0.10137873626644574, 0.024924791275313305, 0.07802466846882336, 0.036695102124565074, 0.07862959447647296, 0.0671067510941817, 0.025845131003147653, 0.06984985148113582, 0.021593649458560734, 0.034202405236541264, 0.06568763450148606, 0.06028575702540337, 0.028884249679263563, 0.06962220845443588, 0.032415907349317305, 0.01695760326730388, 0.057096081004748424, 0.030691510464455334, 0.01264461060805667, 0.025170479503069675, 0.02176077345446233, 0.04029867246807103, 0.09734372052574351, 0.11727893710016243, 0.15433585872092556, 0.28589356390218584, 0.17577723479799687, 0.14857719111586773, 0.11708186098164129, 0.12149360045910844, 0.07332715521296186, 0.13635102539293228, 0.1525826818279682, 0.14190217510106104, 0.10481575909521311, 0.13061972244852973, 0.14627278331787358, 0.15123539363905308, 0.13288461543138952, 0.23287865543557754, 0.12536832762341346, 0.18639838503253076, 0.10920833105281477, 0.09313685594186669, 0.13423475346738292, 0.13058864992232094, 0.1364584309199164, 0.2197256612200891, 0.14007917695468472, 0.15644433187140575, 0.09686549779989066, 0.14051561724514733, 0.10925883156878334, 0.1432697186546941, 0.20070492380088378, 0.16524032359161686, 0.10296266135429183, 0.18201282277943628, 0.10498800630410833, 0.09494350577193884, 0.09164754271266923, 0.17536154016852382, 0.09207323478955416, 0.20002912699935899, 0.10595967392286948, 0.25570914810222967, 0.1833332519257261, 0.09369210114762669, 0.16026187057216323, 0.14229219046331223, 0.24122714455569946, 0.10536411717053383, 0.1121306040834996, 0.14674775783092747, 0.09169094159357971, 0.1261661239268799, 0.24050815571700376, 0.18498346660166018, 0.14572489255618665, 0.1033504167571664, 0.24595343207399695, 0.18468027964474695, 0.1941796013664815, 0.15371024067844116, 0.11314255260531941, 0.22189635603177935, 0.28525473850388683, 0.1303690431579467, 0.1737095481686054, 0.2801584151964034, 0.2873295803944911, 0.34024949395848864, 0.31263410804733155, 0.15541437262248609, 0.1825679607328869, 0.09750849837737699, 0.431472608639348, 0.18651360465634256, 0.21075861738814464, 0.27459281707002275, 0.09900307463061425, 0.15430700784969717, 0.4186311977044229, 0.22392560036913042, 0.26444555350369026, 0.13571940122112153, 0.25939252948568714, 0.37935040710914525, 0.36099135515189945, 0.260534061779899, 0.3457431104635039, 0.1819467860003633, 0.18428503956285217, 0.13283740909349534, 0.17461628983578376, 0.2257794105718213, 0.22401704062377253, 0.2566475445224393, 0.1567383257732276, 0.18118834363356714, 0.21410375563127382, 0.09263758878073386, 0.27647062114650206, 0.1912272364021309, 0.1675589959467611, 0.1835002131279438, 0.16921247415725263, 0.19761961193815356, 0.1707674181389232, 0.10520812634739185, 0.2170485210034155, 0.24143748165618992, 0.1590618551258118, 0.11846543875552955, 0.1639001446986391, 0.12058557942509653, 0.12948215848976566, 0.10515466873203555, 0.1813683283304976, 0.1132882701893968, 0.10911253941876274, 0.19619801322058325, 0.2991926357630761, 0.10630219949469452, 0.08853882686385224, 0.17996712287347164, 0.17690053419961085, 0.16087947533495967, 0.10153304935703356, 0.19061785942364126, 0.10389636165552563, 0.14361047456341405, 0.14052758353852457, 0.16255258071807124, 0.09527564319151063, 0.14844910121492802, 0.12177308465564445, 0.21068499633862128, 0.11956877390583677, 0.1273261342618254, 0.11680937882873321, 0.14723990803524373, 0.0847771512945333, 0.18258492191953046, 0.10579297319054605, 0.1547986371142249, 0.3160212585522283, 0.16122540999804774, 0.09316240497414144, 0.20825504205159603, 0.18911946805254107, 0.10349788868259038, 0.13615587215510108, 0.20685023598132596, 0.1282018646898289, 0.08721488137398997, 0.1887348459492768, 0.06718512954971484, 0.2678870962512109, 0.14492881995054985, 0.1464621602527557, 0.18014926793834857, 0.11463020342372118, 0.22884906359737922, 0.13616465152271334, 0.1170862123610512, 0.10389071558752369, 0.16959469074443465, 0.10825039172965674, 0.15022754368762817, 0.1090481573896062, 0.13671427364310912, 0.1732802324958386, 0.15024908608005894, 0.1395940287939964, 0.14295609758025216, 0.15047845280458852, 0.1499768797188036], [0.038494282597375494, 0.026196635125445265, 0.040523661000113335, 0.04600304742193511, 0.049028497174262047, 0.030314338566254706, 0.037472589437158844, 0.0752802197671225, 0.05283995696734037, 0.02799401912207325, 0.021673653935713154, 0.04303012831857608, 0.040086764887335806, 0.0698523719104067, 0.02944378880783916, 0.017027231083521922, 0.03310139516308423, 0.031068829834581386, 0.06981448120167179, 0.04617925530539886, 0.03586652823874066, 0.016312764078799277, 0.03245524213378949, 0.05823634925388521, 0.03417520145435007, 0.005864576866564852, 0.02936876581741437, 0.032061518905984784, 0.09683364386399908, 0.03500315863939543, 0.039409573805788835, 0.009509478132390689, 0.019649634318005656, 0.033074808081672076, 0.024684670591546644, 0.056770723463306506, 0.016246497473349015, 0.01411335724931691, 0.027419669598701502, 0.013100665622210551, 0.03205771336422092, 0.09424141683285275, 0.033445395454163515, 0.04619964090506396, 0.02851645852769575, 0.027490716592799273, 0.09197732058143424, 0.031613552822701396, 0.05299607419498986, 0.004898852174876319, 0.03403316109230922, 0.07008022944172544, 0.054514525578387325, 0.024109409423545006, 0.031364298455657504, 0.008307693980544085, 0.03622955049297983, 0.09534262991960972, 0.01675602063656815, 0.06557072182336161, 0.038290242739622636, 0.02056457887163326, 0.04203746989068966, 0.024381803476341793, 0.07114527551757713, 0.15704931150521004, 0.12960390518269232, 0.10737500604121916, 0.3264064077408083, 0.5974858843030468, 0.22618681612995364, 0.04065467735692378, 0.08570145169693617, 0.18207971757698446, 0.16275965428400427, 0.14243462153019446, 0.6464547760063603, 2.3245188930342278, 3.4813224452157177, 3.203848585967095, 1.9432415909344152, 1.2346901792672373, 5.362576736557869, 11.649601209548212, 15.827870734276312, 14.748114789685896, 13.492337580650085, 16.913887762254287, 19.036042997913977, 10.925800358095477, 3.2193556764433464, 0.5721463311103083, 0.17740710217866207, 0.14038348239996742, 0.16432570654057688, 0.4990401846026221, 0.17600476291150818, 0.15378796795923866, 0.11770636053575624, 0.0348608692987792, 0.04319021005123373, 0.19494582718658834, 0.15372920901544634, 0.03932481000740682, 0.013275771296673245, 0.060029335905827826, 0.06862795656366695, 0.04917897982522846, 0.02153434084668275, 0.04587290440535834, 0.024635834401593577, 0.05079717585636724, 0.06679204983576652, 0.04881369761161266, 0.049345144296004895, 0.04838412146895163, 0.09408546431410698, 0.06257209280926375, 0.07272852644804986, 0.047851759309489886, 0.05469457539279134, 0.025439487447241144, 0.04361029053407331, 0.008871271350090543, 0.025790428494914405, 0.05747966505887528, 0.0644442814612581, 0.011976738028498668, 0.053432395741824186, 0.0587173184049466, 0.013521712333444628, 0.044736045247484604, 0.013036850498117989, 0.08901521097868682, 0.019853448179820855, 0.06602668203413486, 0.061840804428943706, 0.011050315562545533, 0.09205612038532573, 0.04271095310668311, 0.11024108652265803, 0.037125685672846534, 0.1073598528220769, 0.019793789082717513, 0.02335354111217443, 0.1309167347367733, 0.04644974562970381, 0.041417804351376916, 0.018565983796912818, 0.06168888919355889, 0.0011340986079190888, 0.02783577025477444, 0.05530151621168179, 0.03912380002739449, 0.05307900321279323, 0.05639367030873414, 0.037170471172899976, 0.03232159809539876, 0.05535153409225806, 0.009487428206710086, 0.04625772186104329, 0.02315231279710368, 0.021661304598373753, 0.02536619773074504, 0.05682292469446698, 0.02871653579566027, 0.04105036560025427, 0.053577864347326185, 0.042175063112330054, 0.0451031354286017, 0.029985422546404506, 0.05366031456017687, 0.05243713644543483, 0.026323056869929837, 0.023784281708480372, 0.04244567984114251, 0.014516030299297024, 0.014843192935410528, 0.05632313276310602, 0.05043732137569497, 0.046686769403036565, 0.05257074984030859, 0.01737987859204652, 0.013833851027753086, 0.0023598325834985104, 0.01786685387243427, 0.052419405340427355, 0.0736324335899084, 0.03635784723765908, 0.016499538229958668, 0.010189171448620337, 0.025570469330095, 0.03289826311952165, 0.04213547168840324, 0.030733250765009757, 0.025287055102507436, 0.057359159428385965, 0.00905205469368206, 0.06100501016443295, 0.05591637071883006, 0.06826686102055735, 0.03428793512284756, 0.020449989355139194, 0.01612305389567008, 0.045771141115936546, 0.04262593649928609, 0.028279672241619522, 0.01807231482328667, 0.051320276012824434, 0.014639421208431164, 0.05627028418764953, 0.04404392311229341, 0.03136339447190685, 0.08930513695363076, 0.09305207299128657, 0.05020907313953485, 0.032816533029319785, 0.06242772353993309, 0.024436776030568347, 0.020764353534867688, 0.011472599505777321, 0.04633332707829053, 0.023514973074798624, 0.04179469662748518, 0.0444294108949121, 0.03729734682447968, 0.05420680721140197, 0.03544184356747616, 0.0379358887702467, 0.04120359084598961, 0.018151604923449697, 0.01221784696568765, 0.035454970484058705, 0.02739213448348305, 0.024096025867507826, 0.05882817132758999, 0.09539301552238966, 0.06745188902582853, 0.047518177814180815, 0.05762672329682016, 0.032964939582011396, 0.14542904472158802, 0.04056292300623271, 0.04394271523661671, 0.11165349984601622, 0.2192739144928994, 0.20252668088482273, 0.053580951681661035, 0.06114626145591179, 0.12791813636619237, 0.1567532491659926, 0.07779809796521742, 0.33923988200483784, 1.865284606333702, 3.090641873498117, 2.149295585770761, 1.4529702019306923, 0.672566055530502, 3.9022297820737286, 10.549590145387958, 14.774930073368935, 13.437799965181659, 12.321477724659829, 15.575234793847608, 18.473208373592747, 8.187415763255089, 2.3358592006468006, 0.35973585961807164, 0.13161418118303822, 0.1549811192577885, 0.15305692089661477, 0.31729737717297773, 0.08841806842434792, 0.09672202485343141, 0.07783450246337922, 0.05603410311103348, 0.1220605591492307, 0.19994661932991398, 0.05785949911261278, 0.11065154877160827, 0.04385884393066649, 0.10012223715743712, 0.035566853794960246, 0.04055810048274937, 0.02337601238621339, 0.025660111193334865, 0.06482637547437223, 0.03429523211032633, 0.031843446232678915, 0.021893159193437428, 0.018259259429009213, 0.028193858902781244, 0.037660434196192416, 0.011791330386674213, 0.04736776028068797, 0.005140337452758104, 0.06707488183653162, 0.009243570929092747, 0.03353553718977398, 0.026405336628217372, 0.085420006315314, 0.024583112230644594, 0.08190478123123608, 0.026876783306379954, 0.06339247338473797, 0.028951182781207948, 0.035375956175548416, 0.0495282354794683, 0.03537008411160881, 0.08164022042746506, 0.0461666991243199, 0.06462785911055342, 0.05034380119233843, 0.04117389344760487, 0.03344162630157606, 0.0342549933421035, 0.0912046519618842, 0.04049595159989211, 0.055983824760562954, 0.05947163155783088, 0.04392978367245486, 0.012211587069736374, 0.07191370001002666, 0.020852484289676915, 0.031005185165051973, 0.07029631220164799, 0.03375296826444326, 0.045699657451721935, 0.03475708736767692, 0.023946081393308217, 0.10594301151051637, 0.040273950810754494, 0.05454714177176357, 0.12390829427468202, 0.0416576434978314, 0.020181220813444065, 0.03846718989793332, 0.012750704209470462, 0.0596687727938256, 0.041433761962839676, 0.011012830880410489, 0.031015684400054238, 0.05942217675187896, 0.029982086233494264, 0.07617804417086226, 0.12185039058808358, 0.009576901530606613, 0.03388404207784803, 0.03276595590455878, 0.033699139096443696, 0.058427955504627004, 0.0895449301348098, 0.08038329997009809, 0.08746622716106715, 0.21038085943268192, 0.1530015020961723, 0.16226050203606007, 0.12892450776792344, 0.09972990054877535, 0.1355647127474508, 0.10337911441080994, 0.07473468089536314, 0.11860708841272902, 0.16558170769243472, 0.12095766832991955, 0.16498068107231972, 0.12229209390258598, 0.09902154501046866, 0.12833701026055122, 0.09045850530627275, 0.1946004747503227, 0.13729734316227898, 0.18246015684018213, 0.07728884101755197, 0.15670889267517676, 0.17404583012384756, 0.293292073352683, 0.0907589037031416, 0.08248634155719511, 0.13881130144000053, 0.27608255164757856, 0.10808854799477324, 0.12751324357645166, 0.12565307484398927, 0.1257622193905615, 0.13096732718329276, 0.16454399563372135, 0.10047362636654608, 0.0932975965101392, 0.14938120039240008, 0.16231723850773228, 0.14982001555542793, 0.1341080884899824, 0.17678940548531472, 0.1269480928538307, 0.16421324483329253, 0.11822837284736096, 0.15868795825348747, 0.16954599819596738, 0.11094698291872779, 0.13425983518602388, 0.1036700439609347, 0.22160139685917288, 0.26453699375833234, 0.12981778160939295, 0.1394350655497082, 0.13927090822929336, 0.0874529355355809, 0.09937586833632762, 0.1504903731326903, 0.09215363571720739, 0.19221496888466422, 0.17142367969837882, 0.10707440080061074, 0.13147361937069124, 0.15324540916950474, 0.1844904890223857, 0.3050439540416964, 0.2817648709301026, 0.21908596248155643, 0.38926159302073143, 0.7579819785971796, 0.5102996852609419, 0.1036882462100156, 0.10111792163262445, 0.25037903008201434, 0.19450426942879157, 0.322268215278464, 1.8069243959842192, 4.463156173306127, 6.339399391605008, 5.397699109969601, 4.182014407650117, 2.7903689924747717, 9.75231251408977, 19.659072276084654, 25.549725063385505, 21.522833531902684, 21.603844204256614, 25.211044088486705, 32.24246528840835, 17.094558015946422, 5.329489092673025, 1.1640470667231468, 0.4786342069987328, 0.41118476179338276, 0.48085439109033157, 0.44026279341309305, 0.2556577742460274, 0.30699689602178915, 0.21717849548064896, 0.192536756456379, 0.18478273624374023, 0.45111154836993067, 0.2612204765600543, 0.1259421198178203, 0.08237597126994403, 0.2243084145048934, 0.16672495602359697, 0.11449838267459024, 0.10220608058115167, 0.08182221227475713, 0.202382656355058, 0.123573184433964, 0.22623549335666243, 0.14843589385911343, 0.14142762959724473, 0.16810749957878746, 0.14167121491364895, 0.1810746868291209, 0.17834271003882732, 0.10653373424804981, 0.1020715325590103, 0.12475472183958178, 0.12284245146738908, 0.13203991156431938, 0.16685557401468679, 0.12709594782321684, 0.10584495225620848, 0.08713588238723817, 0.11184659230733111, 0.07645028117563456, 0.17836871106297741, 0.14854788059188476, 0.10691035073250534, 0.15753470481403414, 0.12827663487123867, 0.12950769986116117, 0.20487936754380504, 0.13277071347880748, 0.28318985575629824, 0.07668650438708645, 0.23883567852599008, 0.15628857087464104, 0.2962483147219304, 0.13300651534190103, 0.15921427597922666, 0.2098736632615328, 0.15233324359982245, 0.10368309809916443, 0.1586030910332357, 0.15808192141834768, 0.08097072086867788, 0.17946095326014105, 0.16337874525737378, 0.20321395368345324, 0.1829775419807242, 0.11703368937296253, 0.1829331548463914, 0.13615365050012065, 0.1258030059116502, 0.09106691701397782, 0.19790802871988666, 0.09511808954900312, 0.20023382569272674, 0.12379658333356343, 0.22268508951510155, 0.11604877609399059, 0.18920307888859705, 0.13880892656743526, 0.18269160732386575, 0.1361861019845932, 0.12693530684637447, 0.15444989856933394, 0.17379648382625273, 0.21001162037493723, 0.14294653680295716, 0.2743289763889005], [0.04163909650918457, 0.05088512275007464, 0.04951088741842297, 0.010739848855131818, 0.061182727241107536, 0.06697988693392085, 0.0635290323876806, 0.02738120049358376, 0.03340554739078207, 0.03405612457783953, 0.016214890600813013, 0.025169008614255056, 0.010682216060588197, 0.024659531416311383, 0.057527399997437195, 0.04048925982187352, 0.04375519223451134, 0.051908761773618965, 0.017932752755680875, 0.07351722162697585, 0.04956274391001752, 0.06008429888395533, 0.0647508085615212, 0.030745483273940704, 0.050517090280810674, 0.032248455850828084, 0.062111551392703294, 0.024368779981629025, 0.10356940299032197, 0.060743188124991236, 0.026648550391978314, 0.02499543224281121, 0.05683652658556258, 0.03669833884604516, 0.08822758066197557, 0.01454273229389782, 0.0560006557122594, 0.016815063032892444, 0.05405680336538823, 0.0286384905883742, 0.05955802712349161, 0.013968624088222222, 0.02990349518856214, 0.02946269394259059, 0.07024657011272446, 0.032057780396914294, 0.032047507157849695, 0.021245698069011974, 0.030697271445645925, 0.056381550797772025, 0.01728009563990899, 0.06346374254433379, 0.011520543203298605, 0.05860672978263709, 0.0620310508736199, 0.013522164325319953, 0.049847081273553834, 0.036705436650663614, 0.02397735501759716, 0.07590733168105926, 0.03564466534542941, 0.07102074792548534, 0.03707318566739559, 0.09051356404539078, 0.12109411625011314, 0.36926501280357765, 0.2538997097121131, 0.07395587591153961, 4.090979628024563, 14.637789303256621, 20.240330273105254, 41.606408242256414, 38.585430114499985, 40.293112416421216, 43.14300852437174, 71.64373859282463, 86.9315528869629, 96.56540393829347, 95.75392046282369, 96.19437125421341, 90.2062063832437, 94.12715665755734, 106.1641654660625, 128.14716754421113, 120.9906933384557, 122.23016231290757, 125.00857322446763, 132.85442752222863, 122.83700789174726, 108.3395198083693, 96.89506346179594, 81.55264977485903, 79.23412107652234, 74.61943687931185, 80.24424122225854, 49.85690601410405, 31.88106986784166, 19.410815661953343, 8.499834018368876, 2.351949008241777, 0.3011946686573567, 0.28396044827757344, 0.20849905637723787, 0.3188245887717893, 0.07010251493944276, 0.014622177526865517, 0.027225684644954822, 0.020242019466334776, 0.11085395686208241, 0.010889557757294707, 0.04379179208509384, 0.019926766624614116, 0.02403608523309231, 0.07387064096908416, 0.07309964242120905, 0.018665594379267385, 0.05148608042227645, 0.01729299847577368, 0.018391239141384443, 0.03435864886869827, 0.004064649458028256, 0.05212385244967957, 0.06909225181105637, 0.043374289488119465, 0.034926308529271234, 0.07502605477648397, 0.02306782479037441, 0.03855352034612048, 0.03644635720599083, 0.053419812747667876, 0.028820273676706903, 0.0743642007751811, 0.01924883435300041, 0.06102621930861666, 0.025052944378506754, 0.037575210745055834, 0.022425866092465097, 0.06152745914615451, 0.029402398992510095, 0.05835490136016762, 0.05881857607633837, 0.017720630670326854, 0.0266057011791535, 0.06869775483444815, 0.05693199263224679, 0.057657761349072384, 0.02049402791946646, 0.028837771124897466, 0.029047755824942744, 0.027041844610545426, 0.03677133936434984, 0.048056534611650055, 0.043634813008529526, 0.053017413574120695, 0.053957418778971325, 0.044426499760799834, 0.07158176177331517, 0.030000437869720405, 0.05602895500018232, 0.028591041017564076, 0.031934652830504125, 0.0038527124307884447, 0.07208809992598911, 0.024342227374173464, 0.09375802301351102, 0.06147451864014711, 0.04570548355038609, 0.05335571034060371, 0.12470086585850486, 0.08453931929844041, 0.02377318875533679, 0.031555366529632485, 0.036984572277194074, 0.023832190932045062, 0.04766430142485807, 0.029346237086781093, 0.054959871640969674, 0.06389149156729541, 0.04299107698663589, 0.04267958563662345, 0.07479350112618939, 0.03229315708120985, 0.08230228893338673, 0.09639009427759918, 0.011606709900191955, 0.06740641404664324, 0.04600883904664267, 0.011635174854628502, 0.03187509715527056, 0.04998373603748699, 0.05979585528914487, 0.023709672405534697, 0.07361025534450047, 0.03987791399741846, 0.027368431723105813, 0.029361302205812068, 0.07115282914451054, 0.042518358602519, 0.03102962145461671, 0.06486124013580623, 0.05743062777084209, 0.036480988210607926, 0.0498557189149001, 0.027004237354342497, 0.022301386380868576, 0.04260177408615428, 0.00911820830116349, 0.049181596015489874, 0.045446821623632026, 0.033657525200396776, 0.09947719112519296, 0.012483255254224905, 0.021072642637356635, 0.017175792769018202, 0.015297346136292383, 0.04551732086486394, 0.05831011202967456, 0.035430367570370436, 0.06653451405826115, 0.0655693045607017, 0.03737333125524944, 0.042614180880088004, 0.07674560807044468, 0.018598559770673033, 0.058062631156175375, 0.008445772710406493, 0.03312031370437434, 0.04820246286990662, 0.04900518894916581, 0.029111676286124898, 0.029521901047818606, 0.03688343334943056, 0.0454763121782772, 0.05615776502377084, 0.04820348176684591, 0.03696443948654398, 0.035479439332360224, 0.06572463654822881, 0.033537276209362095, 0.07493157315278247, 0.07034590873386591, 0.32798427307317335, 0.19851484696470922, 0.261132468379313, 2.7581906030254983, 11.607656363518009, 17.904258774172877, 40.03903696613927, 37.58622592495334, 40.67185255788988, 42.53057749040666, 72.12405635464576, 94.72965625024612, 106.08024243385562, 104.7332848272016, 107.60154154992874, 102.51670637438374, 100.34679628187611, 118.79438569468837, 142.2376783432499, 136.63499616807508, 136.30033954497307, 140.06435578869235, 148.36402831539033, 143.22878283839074, 125.47463709308256, 105.64193325657999, 84.05993861536827, 84.38436569706087, 76.61648027358517, 82.3291535531321, 48.160100444670654, 33.01678626768051, 20.6257462886072, 6.669974788542717, 1.966952931496405, 0.14761974974986047, 0.19228463692049827, 0.07933644848244806, 0.2719150946265267, 0.08824562203259238, 0.02104064505997925, 0.07312561280184215, 0.05068954050300583, 0.0040404109149089745, 0.03569004839406379, 0.06253704045628829, 0.034110187402656006, 0.07306878439961903, 0.10048172391590574, 0.0411396071825537, 0.020171165909437884, 0.05306719013700082, 0.032232046247489994, 0.04498638745938097, 0.012114178032554206, 0.04908674283914509, 0.1342506727744495, 0.06560244552430607, 0.02789629503123222, 0.0244586382647075, 0.016768168875827424, 0.015174036624000199, 0.0456372442685308, 0.05225579960331802, 0.02230150703971665, 0.055537911792916644, 0.1067846893302856, 0.027108821762545456, 0.03896708908160368, 0.027296214529703704, 0.03403322620978279, 0.03282541198836219, 0.06092756250572782, 0.04662778829374621, 0.03348862579573066, 0.03070326991409304, 0.02508370472388643, 0.03789982135077158, 0.04584769245177027, 0.017028391706727205, 0.061522448931129715, 0.03137244580073222, 0.031587034689202424, 0.027307690526809425, 0.06879721602965748, 0.058520671295663046, 0.04043256165459752, 0.07497834282055979, 0.042570743694781296, 0.020175375562581806, 0.01682395731369334, 0.05475963924020048, 0.06274560023279441, 0.03133508560788487, 0.05582307270097156, 0.07854222980958801, 0.040702944726593075, 0.04022066939562079, 0.04465445688354873, 0.10470721975810106, 0.09591225459570847, 0.06859246371013504, 0.051115611793413285, 0.06882532379559933, 0.0312701232671257, 0.04075768170878291, 0.035282474296588096, 0.05470431620074857, 0.033322783081882426, 0.06262557340725776, 0.06793306119018985, 0.13451678107582754, 0.12608939256038398, 0.10841322371796255, 0.12532717338012112, 0.1429112354714063, 0.12793158887014275, 0.2551733615297464, 0.2378012912888681, 0.17943369585179514, 0.13396101493027904, 0.14861520439867051, 0.08104067235704392, 0.22403951764347094, 0.14519509679127127, 0.15479710493837634, 0.14809846277198485, 0.1722628064453602, 0.12927045775277, 0.08510769525122258, 0.15355008233699108, 0.2075436374833507, 0.23608980490075004, 0.14145995850764936, 0.13541485062770306, 0.14880249757439862, 0.06620825253306858, 0.173025875983219, 0.06214869899615165, 0.3617546851596525, 0.12282317669521417, 0.10311252347403958, 0.12628865202948933, 0.28378041761536754, 0.11054088737094596, 0.2542080754233945, 0.13168135177223914, 0.06928814049329489, 0.14913596032607943, 0.18497775158574506, 0.1861477210637062, 0.14995826378224358, 0.13726596420090045, 0.18337295060196232, 0.22903133123632402, 0.18258735807912965, 0.2085118960108488, 0.21797905736152204, 0.09948053892942206, 0.13061832816850755, 0.15067713004687142, 0.07065219834687249, 0.1751916371886769, 0.11282480231696561, 0.1800734252338448, 0.11711385281335925, 0.06612608194231026, 0.1418398002222661, 0.16699783654222566, 0.1429608473253827, 0.15531242164152284, 0.13180974810834856, 0.2371139112379282, 0.16460810187122515, 0.2666927651772576, 0.2593561556310423, 0.4042028203125923, 0.33704951405525213, 0.33734310959135333, 6.860492642848723, 21.780890187909527, 32.47435973536584, 59.11433504473779, 56.79513562110163, 57.5758598696801, 64.90677756647911, 103.05454961715206, 122.72216089310186, 134.11204922583798, 133.6354184919788, 132.71482252305555, 129.59085079931444, 128.01657615169404, 145.27718574770037, 173.0568547402659, 164.29315013270227, 164.21950371034686, 167.0080892501339, 175.64244977889524, 167.6556568761026, 152.1751443801388, 134.3909454345703, 111.76978941886657, 113.60356023234706, 104.80764512092837, 112.47026197371946, 75.58266116726783, 52.11931736238542, 32.56545089906262, 12.332078910643055, 3.003694203592116, 0.2770422146685662, 0.284203727158808, 0.2956838611393206, 0.4564844907051133, 0.19797812576495832, 0.14942701245027204, 0.20076403514512126, 0.18084738854198687, 0.21045610458860475, 0.14673182320210243, 0.17656088145750184, 0.1497415681519816, 0.14225060721078228, 0.22242814362529786, 0.19949404522776606, 0.195390694444218, 0.15518230926846305, 0.11552101046207452, 0.1393115415327972, 0.15310490864419168, 0.16174267256452193, 0.31270137056708336, 0.2291827714971958, 0.08765675322783571, 0.12429991076069495, 0.16245161032965108, 0.14298047449800277, 0.16022669181468027, 0.14522970864369025, 0.13921754254448798, 0.1929105460763939, 0.16108659486616814, 0.1351254379316684, 0.2700958809544963, 0.145364111109126, 0.11730537479442936, 0.11755115112229703, 0.12830625949127059, 0.2602334795219283, 0.13150665308198622, 0.11779770885984744, 0.25899658460290204, 0.16779161088408964, 0.1312575366107687, 0.13551784348824333, 0.23779021365748298, 0.10154549828580312, 0.128107528622833, 0.11511496087956814, 0.11297091826676361, 0.16888155481748043, 0.11100804778717219, 0.21031788700530607, 0.15005851404801493, 0.13325523344739792, 0.2094398889570467, 0.12915103996713317, 0.1443147238704466, 0.1362795493895969, 0.09790316389332857, 0.17277764817399366, 0.1649701703459986, 0.30335227868730025, 0.16035012390104034, 0.21540031347784305, 0.27038910876839395, 0.1558333307865166, 0.1681779183807873, 0.2606836327862355, 0.17295916504677267, 0.14415769116772761, 0.18397586179837105, 0.09675794671620093, 0.2805982722390083, 0.10247060308052648, 0.18029237316260416], [0.032636893071955254, 0.08617326226686278, 0.04308776494355933, 0.0746397472797863, 0.035573396185833606, 0.03224880442083363, 0.03549885583080111, 0.016918226347995863, 0.0226701102444842, 0.08034273561450743, 0.01741798955105966, 0.02839504125257654, 0.010434011234000567, 0.05965479551964711, 0.07226462190550181, 0.09434038773179056, 0.017794167450178536, 0.032234528372364665, 0.06405969766239006, 0.07192793392365979, 0.0059379221244354645, 0.06814774967009021, 0.017587609078374603, 0.030255909040269834, 0.057951364546052875, 0.005090982717041287, 0.013877307365257895, 0.04078647895385662, 0.04641797979392352, 0.05999924397216209, 0.010838251891395739, 0.019460736188076196, 0.004928291497391559, 0.02591592135779079, 0.07932393060576531, 0.024704554403621345, 0.02961603027107495, 0.04742620512843133, 0.0917217230063773, 0.04882010210665965, 0.06567818863737969, 0.05757009024701773, 0.006250768492463977, 0.03439238355044396, 0.05554410561378445, 0.03999761140514766, 0.023017014008796504, 0.04288830246115404, 0.03930031817646758, 0.009671496152276955, 0.015833367323202473, 0.0979680821840321, 0.08802713375658759, 0.02525642307685508, 0.053738129941085656, 0.038633695277836055, 0.05354289243358278, 0.09478375345708863, 0.022882554086766416, 0.13271645913200994, 0.12465877698794489, 0.42758474306714156, 2.524635277448162, 7.993312372315315, 11.21329342165301, 21.598505858452093, 29.664803243452507, 53.70106020281392, 88.7900895457114, 101.19652286652597, 111.32616935237762, 121.73428058624269, 104.16257212238928, 113.24495361697291, 114.95353806403376, 103.09113748611944, 100.89948961811682, 90.1847117946994, 114.17489267164662, 108.72179400536322, 116.63334015877017, 108.1285119825794, 120.83042529321487, 100.87908544848042, 112.99871506229525, 113.83313655853273, 105.01309887055429, 110.47648983616983, 96.62827168741535, 104.91059164847098, 126.11556022397934, 125.88618786104264, 122.84098517510199, 113.41301148937596, 116.6474606913905, 123.02279487732919, 117.22894422469602, 119.26848257741621, 85.56539135594522, 74.14900349032494, 60.283891693238296, 38.79046024814729, 19.18879185953448, 6.769144563905655, 1.0426340204092766, 0.08324400251430851, 0.08167819540587165, 0.11484781069861305, 0.01004157311868884, 0.01971077004958305, 0.056252369221540234, 0.06191751281280191, 0.05245101029774355, 0.0360381702381757, 0.08330191876138411, 0.08878235855410177, 0.04815500755343707, 0.024941547533437133, 0.05759619469303758, 0.029368043779545737, 0.035426709500532, 0.06497256803296267, 0.05460839433174941, 0.029491504594202966, 0.039018868964405796, 0.017443416009266532, 0.09630709631188263, 0.048546658513406594, 0.009027767791262558, 0.05073348330634256, 0.03077393003378905, 0.07971612931860071, 0.01873818504053258, 0.007191753332247778, 0.021398162972482464, 0.04069974247906958, 0.05798351342579531, 0.03059330948388144, 0.03654214884004286, 0.016614460994699792, 0.01266225935861228, 0.045791181976035725, 0.017286243495501338, 0.05962093826383353, 0.038240040997944535, 0.06674425361017067, 0.029201285590627984, 0.08363436261612563, 0.03905546115410905, 0.07683863412709006, 0.08120488330361345, 0.02767081237247875, 0.07846422673713777, 0.013423995903482842, 0.03300356573515362, 0.03376121137050852, 0.030556100593399138, 0.10252840441441345, 0.01884866641053269, 0.04017744671493288, 0.01732112730913345, 0.09020091590261267, 0.024008100041218346, 0.054098447904952114, 0.03739039586376279, 0.1482231052772653, 0.03653383295562479, 0.08961533361505117, 0.04169761796572036, 0.03180595963532406, 0.02230372103381782, 0.024779456735198057, 0.025957125396798217, 0.039271969092829574, 0.02877110423850677, 0.04063609972475998, 0.056149747913643244, 0.004974766221318034, 0.06293932854708645, 0.03595867712471274, 0.0159732214618294, 0.04348888091983334, 0.01892410691887621, 0.055119765682085875, 0.04180948212442379, 0.037781522053504185, 0.03023940367594121, 0.02276508407967706, 0.0407636380423942, 0.05763757876270722, 0.020798712578271667, 0.10681249832193698, 0.07406768644408834, 0.03475527173929638, 0.06636908503189203, 0.05704786343079421, 0.03372928848670375, 0.032533754654709375, 0.026994149891599536, 0.07031607727009444, 0.036464115124075644, 0.016152349097894567, 0.019881647876313618, 0.023625735982110905, 0.045078831289203904, 0.030189316847451755, 0.027683127235861558, 0.03404659444406148, 0.0313447191635327, 0.03385009289148354, 0.024901356645709565, 0.03857521978657573, 0.030464639271339102, 0.033402402599852894, 0.04432634908645865, 0.037509557009944995, 0.05978057566549509, 0.06000424269586802, 0.046954172393006664, 0.023419238897340915, 0.06684255035173509, 0.03217095839640787, 0.016898589599276745, 0.034711443849148295, 0.012699693287422341, 0.050540191662167354, 0.043119913823301756, 0.005401718991643359, 0.04328441971372213, 0.11816667978681865, 0.020822036125126387, 0.009333118946561891, 0.02420502677259426, 0.10769827982350703, 0.035794458517263976, 0.08508347921193608, 0.06719563261515672, 0.20585859645037882, 1.6563197225332262, 6.64607088412008, 9.606912212987101, 19.31366639752542, 27.852742748875773, 57.45897716091525, 98.8672233396961, 118.65927573173278, 130.23084040611022, 143.42358343062864, 125.41608395115023, 133.9325458772721, 135.01158991167623, 134.1476486575219, 122.52525791045159, 116.72987753345122, 133.5151586224956, 127.21795805038946, 131.63042837573636, 134.14799382609706, 142.04221879282306, 124.59523385570897, 139.45481946391445, 131.2280716434602, 125.19611743188675, 124.14201182703819, 118.76601911360218, 129.1551225416122, 145.9447103931058, 149.54921168665734, 145.51552464885097, 139.04005235241306, 140.9911334130072, 147.50785335417717, 139.78014084600633, 142.74441719055176, 105.46277507658928, 88.77989138326338, 70.41719775046073, 46.92490293133644, 24.756896380455267, 7.917832241904351, 1.2256953264436414, 0.09745060511293913, 0.08639589507853793, 0.09584145274974647, 0.011858494272605788, 0.06390284882077286, 0.1302672607163268, 0.053166387031876275, 0.04920845888855477, 0.023743725013768962, 0.0076711869558259375, 0.10361954344496613, 0.06224965406281333, 0.06497997610319046, 0.049622337889647296, 0.009148444833924935, 0.032362997486826875, 0.058079136520504, 0.0423007283449894, 0.02795348349477976, 0.060640260381924535, 0.025722708237627824, 0.012953670586519426, 0.030333908282280452, 0.03418403827855664, 0.036633899360294306, 0.019363295549767155, 0.03764009456180277, 0.02402480075796766, 0.04972779755330375, 0.054233631780070644, 0.0017715451676556242, 0.03473636085888551, 0.028855086627206015, 0.035108323359201034, 0.01710537588223815, 0.032537274828721444, 0.03583275142215914, 0.031383381705851324, 0.038902929217945185, 0.022676683278874527, 0.0615072880511082, 0.06598941951749787, 0.0856163010241524, 0.03006155827953931, 0.05754397814011863, 0.057874008817898656, 0.06111273744834527, 0.05326347718495996, 0.07848589170363643, 0.08796617614045259, 0.017796603609777747, 0.013431726688248737, 0.013807151905982005, 0.037761580784835165, 0.060309149520171274, 0.04541644623743431, 0.02796318408312096, 0.052519318527512016, 0.0568907579497224, 0.0023698424798391403, 0.06020565870248022, 0.018031365508514068, 0.04138031966924187, 0.048942821731250134, 0.015455897608321282, 0.015360171091742815, 0.0366803587624623, 0.01776066642524975, 0.004347864981560458, 0.06743380168993628, 0.06925818645545552, 0.12795981154927324, 0.12054912130078002, 0.1608183108750851, 0.22054722923184597, 0.12082116678357126, 0.1704167030871876, 0.2115810434183767, 0.18608514700205098, 0.10773672211554744, 0.1707908604294062, 0.1280599545627352, 0.14585324292702062, 0.1443820476772324, 0.1871034004274876, 0.10330997497564363, 0.28956113323088617, 0.14268652656145636, 0.1857194932357919, 0.1745885880964418, 0.12818841984675777, 0.11636007592202195, 0.1243842876846752, 0.18652149536196264, 0.1322896715493933, 0.1567342808289874, 0.0962184292955264, 0.1525757410713742, 0.15624306525193876, 0.1852459130027602, 0.10791109138799292, 0.1580981778041009, 0.11885078864232188, 0.17120675424173956, 0.17389422132363244, 0.17011593696811508, 0.24794904515147212, 0.15635289161676363, 0.11098271325951624, 0.23587891621695412, 0.1741059067388696, 0.17132591155748214, 0.12172977770528487, 0.08081646906512399, 0.1823391149481458, 0.14039823725338907, 0.09502163907933621, 0.0667164139750023, 0.07080820449177297, 0.09306564806930481, 0.1346572816011406, 0.17494858813381967, 0.15205907605348096, 0.25821805541073123, 0.1852612500830043, 0.10792202346267239, 0.12119280369651896, 0.07817659136508742, 0.18964695023192515, 0.15040031183631192, 0.30274618056512653, 0.2025775031577195, 1.360700488571198, 5.4228846488460425, 14.124989413445997, 20.245323450334613, 33.846799019844305, 44.02171357985466, 79.17465009996968, 123.39736553930469, 138.92122022567258, 149.55052960303524, 160.88311995229415, 142.58386673465853, 147.89605817487165, 149.97518108737086, 138.96099305921987, 131.43971489321802, 123.33485080349831, 146.12134256670552, 142.3594130239179, 150.1118992220971, 144.6137874357162, 154.22235488891602, 131.3009963497039, 147.18069630284464, 146.78538414739793, 137.90582841442478, 142.85248633353942, 127.3395436809909, 137.26932187234203, 160.62474558430335, 158.23434337492913, 159.71168056611094, 149.77219058621316, 150.42664589420443, 160.7694810436618, 161.15693276928317, 166.9704031175183, 126.28284931182863, 110.15411023170718, 88.70258931190737, 61.720891229568, 31.98821529265373, 12.563073173646005, 3.356308663083661, 0.2498502915184344, 0.1876809847571196, 0.30926494528689696, 0.20461520510575465, 0.12481445371503792, 0.17968872652178813, 0.15136406576681524, 0.25649748321983123, 0.09299418738772793, 0.20146500559583788, 0.2541211857310226, 0.12501174433817788, 0.18789639335966882, 0.20388158398770517, 0.19281967272681577, 0.1432488504196367, 0.17023022196465926, 0.27126192806228516, 0.11726082678163245, 0.13566165351338927, 0.15066029143429574, 0.19443722141365852, 0.1457009752911906, 0.11285987382213916, 0.13054645379945157, 0.13055371631297374, 0.3124749149766661, 0.21320878107461239, 0.12448738779752486, 0.12421715028223493, 0.08181805241732829, 0.14109433538490726, 0.12121818418945036, 0.11826689174819378, 0.12503350889610668, 0.0916086101243573, 0.11856768851078327, 0.11264549943828776, 0.13701032066056806, 0.14975166519082364, 0.1829364490244658, 0.20616268739104274, 0.28097475848851666, 0.133368537851399, 0.3003215122847788, 0.15436587404579888, 0.1621954305277717, 0.17486379752236028, 0.2417984163208354, 0.2258254064907951, 0.12122517857219904, 0.13059038128102982, 0.22679709709219395, 0.11220006527559412, 0.19452139915477848, 0.10651721739240232, 0.17161434366097375, 0.15972288175215646, 0.18743323192240732, 0.16486979750615938, 0.393293054113465, 0.14502274233006662, 0.1985759807810668, 0.2447530182619249, 0.1085493422203487, 0.075844252001374, 0.13766649028947278, 0.11434291279123676, 0.09732728027888844, 0.12402126159999641, 0.19218210371271258], [0.040780334928703886, 0.046480875612506946, 0.024810508193988955, 0.020769559102313175, 0.08421670435176742, 0.044671069500186754, 0.042215213780441595, 0.055240359412686485, 0.027252095526144392, 0.050742676361433925, 0.003477565398732681, 0.014629850855037091, 0.06707760144866283, 0.015867563572922544, 0.009636640109332099, 0.058404593653376066, 0.03376593813300133, 0.013894221629016103, 0.010144016311143436, 0.01722678358125831, 0.023208110811068647, 0.04671308835367522, 0.03768218343236274, 0.008216220209555281, 0.031672604795124744, 0.03554766712289664, 0.07313611586728404, 0.0842187574674045, 0.017288423015645916, 0.05182322805687305, 0.006536879828349958, 0.020942970764853304, 0.03230309324158776, 0.06062278974681132, 0.027974642843248385, 0.022711641786079255, 0.05532236912498071, 0.07280009438193615, 0.03344482471865993, 0.045413657677389925, 0.05213968748707445, 0.04279504657813138, 0.020000613670075135, 0.05081519807478593, 0.08184350185817288, 0.04449344052362346, 0.047094197943806655, 0.03409840113994095, 0.01548558351538715, 0.04757418267188534, 0.030950963376991214, 0.055204192401781205, 0.0032378442776990275, 0.05697589713118731, 0.016881599684336016, 0.04178074233594441, 0.019657911898027507, 0.08554255740056116, 0.8904091016419473, 4.128541225387204, 15.520834461335214, 49.495106589409616, 78.54987144470215, 95.23825430100965, 102.9685163497925, 99.59697246551515, 110.9559368318127, 102.27531586923908, 103.70705942953788, 101.70326955856817, 103.41293657979658, 78.12023070550735, 88.05661416822865, 79.65391666658464, 87.07552740650793, 68.95837414649226, 68.56982415722263, 67.11022392396005, 90.40359573979532, 79.80860710144043, 89.81127077533354, 61.352619894089244, 79.63031184288764, 85.14481129184847, 76.57379704137003, 84.82746801068707, 85.35430508275186, 95.36508806290166, 76.55177685522264, 66.82096481323242, 86.12655701175814, 92.5214324458953, 90.45627317120953, 86.03551880005868, 80.22941466300719, 108.85867687963672, 96.45844874843475, 108.52144718170167, 114.91932715139082, 115.18153759741016, 123.63444143725981, 126.07089227245702, 133.65055884084396, 98.8754681617983, 82.49630928039551, 43.826614887483665, 27.375268705429573, 5.120072768580529, 0.3707362386968828, 0.024792131659905278, 0.25103663995621667, 0.0758139685457272, 0.07957304707698284, 0.07110455794440163, 0.03116170841930134, 0.04764988748056274, 0.022472584049307534, 0.06891621246693597, 0.054304115699544075, 0.06901493055685874, 0.023061696086980166, 0.019987932999708483, 0.019836249505920757, 0.02611257612795359, 0.02086574527164621, 0.08105967899844532, 0.03161478239381987, 0.05380681355393702, 0.011906497341941201, 0.0475192311850767, 0.02807640230223056, 0.019265215228041335, 0.03099378003107925, 0.09671189717107243, 0.06307945751975622, 0.03787533718071157, 0.06855971345137205, 0.01807521255086026, 0.09150916425090644, 0.040764687582850456, 0.05145157965260649, 0.031115756550383185, 0.011958967661485078, 0.040556725354925285, 0.0029653693068652388, 0.016769802558325955, 0.03065735251913148, 0.029997572700883594, 0.05862163402320397, 0.028777068232997294, 0.0907609261752617, 0.07700520462446636, 0.07805702802274497, 0.06420389073149813, 0.025863595637342623, 0.04101231401305526, 0.07601245426602903, 0.0324891951505936, 0.024703705961245204, 0.043130171740607876, 0.02172051170360177, 0.028000467667175878, 0.06466982540704551, 0.030301029703790144, 0.042926066765381445, 0.03330080401933482, 0.08218902283378186, 0.09117197831191363, 0.04829448918181081, 0.09088281076401473, 0.025705961555603053, 0.020051736632482182, 0.07128474948507163, 0.00807016937723083, 0.022845538633484996, 0.046333491787194245, 0.050582621441853624, 0.005960008918097424, 0.07846071039356532, 0.0261496069029935, 0.02232436710337718, 0.08569360695659153, 0.00728340378226412, 0.04147480129294338, 0.039890654039599245, 0.04883669940153918, 0.049229227532182014, 0.019837256911541187, 0.056268361306959586, 0.02217992888613334, 0.00824482880547763, 0.055262353796992576, 0.04238134377726144, 0.12483016617836491, 0.045407260843222184, 0.007470774045589591, 0.055144223039068525, 0.034652470400737184, 0.04635057937834532, 0.028856168726399064, 0.06393015219439423, 0.03285946842703608, 0.05951842803868556, 0.0824823272564719, 0.08675097683144194, 0.04701696862015994, 0.0419633815275325, 0.0331856495129966, 0.0841051466282337, 0.07446479578051837, 0.029938193225872614, 0.02392950133540698, 0.06514292300468491, 0.06724621740079696, 0.07722951516869568, 0.04753716530338411, 0.03932791649393978, 0.031212553674835834, 0.035576816768415516, 0.06408800461119221, 0.07653784502537982, 0.049130360055113995, 0.02582125012732802, 0.003740054892278427, 0.01644126192155865, 0.04604155100100944, 0.017385744910326698, 0.06979899856472208, 0.06114780895351883, 0.03863620038534846, 0.016605589696536624, 0.04030786935360201, 0.0631143183507506, 0.06157275409467759, 0.3556555834028029, 2.265914515141518, 16.37030707251641, 49.63481749257734, 82.26536796938989, 101.47226548963978, 114.97691539026077, 113.97739348873016, 126.67954998631632, 118.78363055567588, 115.97104011043426, 111.5546944833571, 114.00776832334458, 98.48745161487211, 100.70461842321582, 110.6432847053774, 115.17115116119386, 95.69432397042551, 102.52499042018768, 96.62511025705646, 120.54370787835892, 118.6827628843246, 124.30129927973594, 93.35299845664733, 109.39090328831827, 113.02864274671002, 105.91185508235809, 125.24478620098485, 114.90257863075503, 126.08453427591633, 99.87129519062658, 101.04165200264224, 125.40044938364338, 125.1673193900816, 125.09641078210647, 110.43306135362195, 115.54088161837672, 125.57131567308981, 120.6704318138861, 129.91244592974263, 131.06650921606249, 137.94764088046168, 147.4945172955913, 146.85903056975334, 157.4408478890696, 117.78363012498426, 103.1084978965021, 54.26606585902553, 34.84208868395898, 7.995907510480574, 0.6111979388421582, 0.08418517983368329, 0.15550184454168045, 0.10297727065100785, 0.12707728592138137, 0.017537468623730446, 0.028211101626736984, 0.053302268047005906, 0.027953008520266706, 0.059554771249813426, 0.05087470395430442, 0.06446813743922018, 0.02044535643841711, 0.03674490933096217, 0.0703696574595186, 0.012929072460880684, 0.009110276418317471, 0.05326805456030754, 0.028228941899273666, 0.0422667408542287, 0.004886799217802623, 0.0366435980334157, 0.0253516937711186, 0.011124884645875183, 0.030894525679609472, 0.0010336315632054223, 0.113477049575698, 0.06101549024723711, 0.07279611072472988, 0.05646000203165797, 0.038477723606892174, 0.04142038606768174, 0.04436796298250557, 0.027720368685080644, 0.011834971542890755, 0.07418747195192883, 0.0372230937524188, 0.03655108142523997, 0.046828878712990595, 0.03133957679834097, 0.006398564568840929, 0.058273535161729784, 0.04558578614265688, 0.06272160252856632, 0.030626486836662217, 0.00825471900058009, 0.05837129947218684, 0.032872151012622544, 0.018581244268364484, 0.052054364444507714, 0.0867467480260999, 0.04857456326604851, 0.047006281693616224, 0.017441102423735203, 0.026163643548986124, 0.07615304672189298, 0.10429296537392563, 0.03343197742416974, 0.0016822291311860507, 0.07059963705438761, 0.028402725114457072, 0.03464683965449372, 0.057063690807309844, 0.058490667462108605, 0.010193850330617881, 0.02451910558457096, 0.03371413143712186, 0.04781678356530686, 0.0830434790001281, 0.1529126205751973, 0.092579412063764, 0.14444076065574923, 0.20893941903787278, 0.28825697579210807, 0.14321255317378428, 0.11499666924317999, 0.23593652602886003, 0.19016929962221654, 0.1747678526707234, 0.12871783256771105, 0.12423997970237849, 0.15862765181208813, 0.12070881998947552, 0.1876580174411497, 0.19656855462779924, 0.16734934832540252, 0.12267122315543315, 0.13541265961623963, 0.17197733144125632, 0.11774697085662235, 0.1400929205720463, 0.1143033826543439, 0.1537500159634698, 0.17042831698011968, 0.15995019536104896, 0.17707324106126063, 0.2645628262431391, 0.13280239887535572, 0.17782203072021086, 0.20459865760659018, 0.20575074659239864, 0.19674141470703388, 0.08750608671576747, 0.13843558127841643, 0.09267214700699815, 0.1389884209680942, 0.2570457417037218, 0.18920755284207483, 0.09989707625561184, 0.1271051562000667, 0.08267779459035204, 0.16173085948872953, 0.2710666369286276, 0.1008021861555115, 0.26012083395354213, 0.15540338692165193, 0.09345314300228512, 0.15322570538809224, 0.16695245349359128, 0.22548460461679967, 0.15744948519333718, 0.1390204740868461, 0.15213519454963748, 0.12539178523565495, 0.19957914227439513, 0.2421582018535945, 0.968754155741584, 6.695589826953027, 30.376280007823823, 75.00046376259097, 108.68231142720869, 128.84824414407055, 136.03454405261624, 133.24506421242992, 145.42804010452764, 130.59571496901975, 126.40079498291017, 124.38694815481864, 126.26225686842396, 100.46930759183823, 108.69522386981596, 101.8108601723948, 109.81331117691533, 93.91908276465632, 94.80409499137633, 94.1335658104189, 117.98847982960363, 109.48893900840514, 118.41045625748174, 84.35232777749339, 109.13980099462695, 114.49996302204748, 105.99213815504505, 116.8487802628548, 112.03163900683003, 127.90061519991968, 106.52134433869394, 93.80379646055161, 119.2970060533093, 123.57220911210584, 123.04924734177129, 115.55563757496496, 113.53794682410457, 140.35345015987275, 128.44036471459174, 139.02199376013974, 149.54783101235668, 150.7712810270248, 162.92366243177847, 165.2886163034747, 177.6732647803522, 138.26061464125112, 121.61657810211183, 67.91213681620937, 43.57543022401872, 11.25480386518663, 1.6665236459624384, 0.2349730938552849, 0.29428011227038603, 0.23942913619741318, 0.21863878163839542, 0.10183115715100881, 0.12784297547994122, 0.15206802396043656, 0.22429437977412056, 0.16378000679035343, 0.17882476320430157, 0.2862623892724514, 0.1288701155252995, 0.1203269404809802, 0.12855300108992285, 0.12760532734495017, 0.14651287527334306, 0.11211732777977183, 0.13930374275772803, 0.08126450026588095, 0.09711366432208209, 0.0921267919963406, 0.15852527182188728, 0.10362412465075332, 0.1266798624889024, 0.12496358805125761, 0.22478991608706214, 0.17557575367391112, 0.19769476516352547, 0.24005798713093807, 0.16924920041234265, 0.1270113180902216, 0.1998934987932444, 0.16695089067422575, 0.09731312297404775, 0.1373347129312254, 0.09597754060861566, 0.07765918324190764, 0.22924053452668652, 0.170218225027765, 0.0664423536809702, 0.07374345505189511, 0.2317869341782024, 0.1651412684230074, 0.28337721021906026, 0.11029561666110832, 0.11412564259503158, 0.11116681184860007, 0.16825086527293728, 0.09658569950730571, 0.17581572305531273, 0.12657834051717676, 0.18206696987392443, 0.0954902244191016, 0.21853753545832252, 0.0804524930314191, 0.20693508787981926, 0.10421882338461377, 0.12946653029611035, 0.24830031178651318, 0.19211789022289938, 0.2119303641900901, 0.17528960451243386, 0.11649926643698447, 0.1341592018762904, 0.09926688466821948, 0.10845048623459955, 0.13353811907431773], [0.032558483972905145, 0.049425510749701536, 0.025001530302688483, 0.04668945454121117, 0.03324326315534211, 0.006554651631778407, 0.07762356781430783, 0.027101474979351607, 0.06027210150815307, 0.04230132589357034, 0.07743444368844071, 0.07605297265634423, 0.0371153702989461, 0.05137524665183118, 0.05118514959430022, 0.07881487284096018, 0.02775213069042131, 0.07401975998354536, 0.09704382774690468, 0.02354577938545375, 0.02662965866376556, 0.019172206408374252, 0.07283397845082706, 0.04615091771307973, 0.018285220233543266, 0.017376417789848584, 0.04959392368853573, 0.03753620920883071, 0.05012181955539892, 0.010010636573086583, 0.03935615449482876, 0.04469591373157117, 0.045407234030144836, 0.09367253526204056, 0.04436084985612862, 0.022088620781658158, 0.04144320399650643, 0.03717303756744631, 0.04678257635884708, 0.019863604590477004, 0.021892161363916054, 0.013208184147163505, 0.03577533696267394, 0.034878945143352595, 0.05975698015742725, 0.05035113648421342, 0.01567505621125982, 0.05736639895927041, 0.04592156247986902, 0.012658874207596867, 0.040337068794835965, 0.009462559077468131, 0.047405271775900364, 0.06097907042731682, 0.057475612453755834, 0.029410264800272645, 1.7506092113833276, 10.045506742692764, 17.372465787395356, 50.635343520872055, 84.9465041006765, 102.40182015203662, 87.27899643682665, 83.24533293324133, 81.55779592452511, 88.14727583239156, 87.36342153241559, 76.41462725977745, 65.01612540214293, 63.03787408336517, 55.81757507016582, 32.98204975743448, 28.832772431835053, 29.747578982383978, 26.74405932426453, 25.87870993921834, 19.49687050234887, 17.207910591556182, 21.55997641624943, 27.24629136823839, 23.107865279720677, 28.566000269305324, 35.98586359331685, 27.913670885947447, 30.79097063310685, 23.27440127249687, 24.835722292623213, 15.36669021652591, 24.763752683516472, 39.4689126168528, 19.329438247988303, 23.22545401511654, 28.31477245976848, 24.628452485607518, 15.545873891922737, 43.64391872959752, 52.63440693578413, 48.919596825876546, 77.7450167748236, 69.17427709025722, 72.48040368480068, 107.21217570766326, 90.37208341783094, 132.6798036021571, 123.78108316852202, 121.46033440866779, 122.2844792950538, 101.885298913525, 64.83884995983493, 39.20066956550845, 13.624292977394598, 2.4695742707098685, 0.1761516679318682, 0.060203000377382965, 0.028188752926765915, 0.03261865251847813, 0.0848863801107772, 0.01814628444281557, 0.10755388757153865, 0.06242893012841383, 0.06973702205164779, 0.06419840171152065, 0.02490710613558129, 0.003657093076335807, 0.039777514344501885, 0.07678807232408755, 0.024873482536584623, 0.06724112291610049, 0.034855070013192394, 0.045751176864629796, 0.04407615626170751, 0.04157995452143012, 0.03692741445716351, 0.042569230671130845, 0.040148806517883655, 0.030462946217026443, 0.0340596983780063, 0.019037962906182777, 0.015528643402391145, 0.06992529581991896, 0.031654492561374946, 0.04678503933152364, 0.04260985631375544, 0.016605618424833785, 0.027883252384321346, 0.03253836650401354, 0.0485610303228661, 0.0290173938452837, 0.011827947474235009, 0.036930356234792745, 0.05187327658096629, 0.057458582319199085, 0.043478374023951834, 0.09684638390617986, 0.10224527363935787, 0.03262905982292948, 0.03862536407165951, 0.04690984271526818, 0.07547567177924418, 0.05698107205511582, 0.023565772365057663, 0.025579945837718346, 0.032764362441676284, 0.02474455951502727, 0.06650989965325402, 0.07198535221358461, 0.07671034504329005, 0.05975701846182347, 0.04007311703096475, 0.04330152645707131, 0.007355349493258063, 0.07453595002692553, 0.021486012189979517, 0.08807816287322391, 0.08654212594152459, 0.03739057972486462, 0.031003354214912945, 0.059703350172288, 0.025425265024926876, 0.034013039792978, 0.019562336683814085, 0.03934794969315972, 0.020649568665952935, 0.038534682244062424, 0.03124668672230215, 0.027949697105214003, 0.02527761498406049, 0.02466419880699006, 0.09543643738593786, 0.006985136067434665, 0.05185605492442847, 0.028644268806543083, 0.01778980266422995, 0.1341231038132983, 0.12777450254126904, 0.02470194204379955, 0.06004419035067963, 0.0545176895215146, 0.024219431140790545, 0.11189628077009994, 0.018725542674562144, 0.044996235519647605, 0.05778149604016255, 0.015057558700772784, 0.021605125455666455, 0.028229007016747232, 0.03610638653739326, 0.1004278296304326, 0.021655283147288908, 0.118508615470942, 0.03896504745728547, 0.09796592181608563, 0.020915879980630932, 0.06455190915374026, 0.02311726427456785, 0.05175575869338167, 0.023184722146740364, 0.03980805443960332, 0.03512292499503782, 0.041927781421691186, 0.02827483822681731, 0.12014085006329323, 0.0522397424004251, 0.03164237113519302, 0.012524093486248486, 0.04661146679051942, 0.12475708139038856, 0.04157179185459691, 0.11311920224538735, 0.06369829185367112, 0.06268601391404387, 0.06277968731498526, 0.9709827974438668, 7.073040489227542, 16.126755341406792, 55.69014118563745, 98.02210946236887, 118.27959814379294, 102.44190677519768, 105.48362639642532, 98.76902288006198, 105.06734525003742, 98.34699153900148, 101.86898969834851, 94.77361033039709, 100.24370070426696, 105.18461627344932, 60.86086057847547, 59.56683535729686, 54.74306529568088, 50.78163223881876, 54.05338710354221, 41.773987585498446, 40.850351779691636, 47.58581446063134, 38.20461111684, 42.85434561391031, 53.24819510982883, 61.56847969178231, 54.96744840375839, 61.50343110484462, 47.07638486739128, 53.896621734865256, 42.03570381287606, 46.72878050035047, 53.58453835210493, 49.64701214144307, 56.25513507473854, 57.94762995935256, 47.099256207866055, 41.320553748838364, 82.64697536345452, 88.03793584146808, 90.67205844386932, 115.71573303591822, 111.22106552124025, 106.56558867423766, 128.44924496066187, 116.19689802969657, 147.80953068887035, 142.68953538710073, 135.78624233122795, 143.3928320484777, 118.81054585979832, 83.08019330424648, 48.717571227781235, 18.8058037911692, 3.7125535213178207, 0.2168540112794407, 0.023470281420515913, 0.037368393818577456, 0.05853352242059285, 0.1561148374551727, 0.04374635924074439, 0.013480119504815629, 0.005887558546683361, 0.10043789602575764, 0.0053376979814211455, 0.03989197554126863, 0.040619724595378486, 0.022609382454726486, 0.0762042367169934, 0.016122305044724096, 0.05150393027091219, 0.0756241702624867, 0.03363435487112692, 0.015194696100098232, 0.058244902625559807, 0.031914232756882426, 0.04862891337383659, 0.018906391135627226, 0.025508102112179323, 0.08274155608828991, 0.08203273323634941, 0.024845267518333373, 0.09041316056203458, 0.011934043948478516, 0.057899105858298085, 0.04010255778989485, 0.03669855335066396, 0.08946463645946595, 0.017094296335633245, 0.05144704058165512, 0.02035863528538856, 0.04663636464805854, 0.021995479811824138, 0.03701592059505563, 0.0795589893635723, 0.07350207606871283, 0.08566902319510138, 0.05273193857001682, 0.01436544039602121, 0.04422122650148888, 0.04929140322811661, 0.0741956997362356, 0.09691537778464057, 0.0717451147014095, 0.028874233079653595, 0.020828724072705355, 0.017147889931596095, 0.11557857430870495, 0.041064220300364884, 0.0011330704939844568, 0.11065191649381192, 0.04840669808008018, 0.021032974604637395, 0.021015053892868663, 0.028865356035830996, 0.03716484425709613, 0.03941931844418568, 0.05119079949274179, 0.04961653094318125, 0.10221543451470715, 0.11833021657601481, 0.21330425095173622, 0.15388208952161575, 0.15087525570584884, 0.22181358789244007, 0.31937099332290314, 0.07052413142857052, 0.09030965442258505, 0.17181504337537676, 0.23629880900825226, 0.24950665511911918, 0.18567942683735203, 0.1162948128917525, 0.1426084162366967, 0.19701282433684797, 0.16306172275254804, 0.37151633070841916, 0.32912372160823117, 0.13428719984667917, 0.24354619995480586, 0.1388405047116741, 0.16063855600453195, 0.18300950316892517, 0.11683373276384608, 0.09660999215538464, 0.15272604752211802, 0.14376862575450253, 0.08348977884217616, 0.10648242933976074, 0.18392474841206305, 0.18751783867276486, 0.08841741724961227, 0.1894355406083407, 0.09767437173474221, 0.1789756059165924, 0.12153462446745365, 0.25112789634975696, 0.1512721045723846, 0.18827335458369027, 0.15675652802230852, 0.2303094263639181, 0.09979604458015773, 0.1563235351275052, 0.17159283191205996, 0.15088950494124045, 0.10471481935030992, 0.19247091886016632, 0.21019249373385984, 0.15533698242037527, 0.21644139632342324, 0.11367990965804747, 0.15746145148671445, 0.1835656676801943, 0.25559333092983694, 0.137640688448183, 2.7526838404517022, 14.532681549749068, 30.758911140503425, 78.06064205784952, 122.70480048271918, 134.11633245406614, 112.88855137363558, 107.67369747161867, 101.92275754867062, 110.0913130852484, 106.92379520785425, 97.30917945984872, 89.22502548463883, 88.45809228958623, 79.917539165866, 50.76738619035291, 49.42233877797281, 48.034466928051366, 39.344624473202614, 45.39257411033877, 30.72214480369322, 25.308979788134177, 34.496669077104144, 42.32693979817052, 35.03649311680948, 43.124722434628396, 56.99778879842451, 40.73006053124705, 47.91756460743566, 38.51687100625808, 37.63821694158739, 24.31163480204921, 41.86321758454846, 54.46583217190158, 29.932477551121867, 36.41270376020862, 45.70020168058334, 39.514486635884936, 25.858170447811005, 64.17751481456142, 76.06297108434862, 74.01797279234856, 106.2230323976086, 97.54708690028038, 100.3031167676372, 135.72911693203835, 116.39534642619472, 157.3705903945431, 152.60946058457898, 151.11536702802107, 160.43352219366258, 140.2935947910432, 99.3412260855398, 60.66558145707654, 26.195941432829827, 5.850995173377376, 0.32977192392272336, 0.15745184474414395, 0.18628350248740566, 0.1648204614438357, 0.1906236663701073, 0.1767056414316739, 0.17106400141792913, 0.15490929085400798, 0.3258811165728877, 0.11227599224976956, 0.2014900260274449, 0.060911083954476544, 0.18625103568117465, 0.25706104814044894, 0.16887271416283425, 0.15940857119858265, 0.15168107294988248, 0.1158978874164243, 0.15548160449872095, 0.17335984435292984, 0.13315588716537724, 0.2226865144386407, 0.14383976467915122, 0.07165866934003369, 0.08924657719269877, 0.12029593690268456, 0.10028725249632713, 0.30187032756305515, 0.08077366773279444, 0.15879262118570267, 0.1165888834023668, 0.17092635073969442, 0.2563488774842793, 0.09322227474542395, 0.1667594146584311, 0.1445662152142294, 0.0956878827644452, 0.14700478032952355, 0.116243178565656, 0.14524239505971634, 0.1362834870815277, 0.16577738187005445, 0.29413262502320353, 0.12203903973943765, 0.1539695767625686, 0.33723024951834835, 0.2547635351337733, 0.2511464969645585, 0.1702925508781787, 0.16973431792951402, 0.13641090282509405, 0.05636637459599203, 0.18599830327495454, 0.17311431317319795, 0.14404060228938056, 0.2729522244584176, 0.20278667580456505, 0.11667540537253504, 0.18516127560888568, 0.19299057162096425, 0.14996096041173707, 0.15779574161335347, 0.14561118978646495, 0.11801685597146712], [0.11171189106760487, 0.05279421002694196, 0.024160700925295393, 0.045976904671519034, 0.04553828869135149, 0.038634530313673525, 0.04593088960034713, 0.08264772563932404, 0.04357754410574994, 0.015581629873674004, 0.0894026293028747, 0.036861998209309195, 0.0403635103195425, 0.02414913682807838, 0.048293205984537645, 0.0498617135529076, 0.02322425228363324, 0.05099907449837174, 0.029749965422876903, 0.10307408884287843, 0.04419497649876341, 0.05461358457743641, 0.058072781821172086, 0.06694181236408411, 0.04541800522636022, 0.03614488628602797, 0.16985129955555164, 0.07317087327640864, 0.07594073311455789, 0.03143119325320567, 0.02440793090499938, 0.014453339409233342, 0.01918580063859061, 0.048797965996087565, 0.020339281989201423, 0.03206956282918973, 0.02894774879208736, 0.04145804311959975, 0.07033662374822364, 0.07091056916021532, 0.026705905479649385, 0.03799534485405011, 0.03042282044677244, 0.030535096377735178, 0.055366009323587345, 0.058138607926065886, 0.13002657121227634, 0.06316281171635756, 0.02353684105459721, 0.1055784302673513, 0.02135631158917902, 0.06789307140054242, 0.04829320215409802, 0.08645630877224669, 0.0849520798111635, 1.9918301965921157, 12.5972762415486, 38.69547613205449, 63.915076871072095, 81.28237493576543, 80.38725083874118, 80.08136872322329, 72.46651849439068, 67.66152874115976, 67.82874722634593, 30.30980956169867, 40.83062225772489, 50.21799156742711, 43.24056571529758, 20.27139348368491, 22.119796699093236, 32.21168644966618, 32.20746009580551, 56.71147146532613, 69.57832828644784, 54.07558771871752, 74.23968084396856, 93.62191615566131, 77.36718270086473, 121.56793286723476, 75.91203043537756, 68.3471590472806, 56.486272504252774, 76.79832919951409, 61.1620044708252, 94.03245495211695, 92.81488064796694, 68.48728964405676, 59.313238436175936, 87.35091701630624, 98.84719571759625, 110.96339717988046, 96.35377637801632, 77.12849078639861, 97.72304442621048, 67.81444626469766, 65.76766721663937, 37.790471584566184, 35.12723715074601, 28.786865011338268, 41.95229853353193, 50.74663292977118, 39.29282173033684, 60.35199188417005, 63.18420202501359, 89.32626970352666, 86.31963960586056, 93.57982127897202, 111.48435069668679, 113.78314987305673, 109.8079610640003, 63.186029849513886, 20.84631489169213, 1.6530881798075092, 0.1634455174808541, 0.07308708624013009, 0.042320983709707376, 0.06499038723808143, 0.016639366513118148, 0.027637951030966737, 0.03803835303011922, 0.053046593863156535, 0.027392768421240395, 0.012814231092981514, 0.01706458936114946, 0.079675626250044, 0.016762189559578415, 0.040403438822156, 0.014223715087639229, 0.0317683293964834, 0.0944200761976742, 0.05019711833747645, 0.01670412584057739, 0.01571529689470246, 0.025445880450969263, 0.06819615110514626, 0.03693964888131426, 0.03408779465262929, 0.010131524289928136, 0.0213321644978057, 0.03306466507755461, 0.02737571147360629, 0.05733324650434717, 0.05434964430488406, 0.0473707556844719, 0.017250536137350628, 0.03435999335300538, 0.024065060593608408, 0.0386688357309228, 0.0056256479283254, 0.05846820959460832, 0.0247667032864786, 0.07635684909238931, 0.059198322029964584, 0.012398705002851786, 0.02187472903319905, 0.06253918167203665, 0.05177049822504482, 0.08000587909332207, 0.021099449969047022, 0.06089884953032579, 0.017163516210031607, 0.05633097367301103, 0.06017393500153577, 0.03275399727206076, 0.02840375550271523, 0.022728681496735063, 0.03188227539912107, 0.07521194601131063, 0.15153113422134232, 0.04340962146318728, 0.0531541143033293, 0.0171413762690199, 0.008844124066883759, 0.012315214825643888, 0.05360360873202163, 0.07073836791659556, 0.02779498756412537, 0.11162757543065857, 0.02937993537935038, 0.01863342443210704, 0.03834611353194041, 0.019215442495600834, 0.032780982719193545, 0.03208593604335141, 0.05042159359060949, 0.03216253142924078, 0.022154512004025524, 0.052307851447333256, 0.00627236929909897, 0.09145525464367482, 0.06657033632960051, 0.02699831932512743, 0.04521983743254696, 0.01785276360028694, 0.0692130638767154, 0.02153401142887531, 0.025822052604428707, 0.018258388003995343, 0.015007618386598845, 0.03223219563463523, 0.011865586331564815, 0.10577685470061918, 0.02660816798226968, 0.10036314116610635, 0.06276164211392884, 0.027034449946856307, 0.054928109635629004, 0.031000136645630966, 0.020098040901845502, 0.06921525488817884, 0.05809373432590116, 0.014116312433484823, 0.03488382512343026, 0.05469573601599663, 0.02269548499175618, 0.06659042315497514, 0.06313645063088306, 0.02252005468753557, 0.03593064213712369, 0.015508203218961436, 0.05412558273923013, 0.10301372877532437, 0.02393363821019809, 0.07459270182035624, 0.006302929025203471, 0.010491910244097874, 0.05555232190677235, 0.05848041337524211, 0.05311445776192893, 0.17390185155935828, 1.4461363299239067, 12.501745935409302, 46.98939454170966, 78.92315556926113, 96.75003774704473, 92.00484844946092, 92.41192771542458, 88.03046764866, 76.57314592792143, 79.58101549456197, 57.69872419295773, 72.3204102054719, 66.24057169883483, 56.24231676901541, 28.997037372281476, 31.303051748583396, 36.51732513981481, 25.784722105149303, 31.23347870765194, 39.560166558911725, 25.466529630845596, 32.114552874718946, 41.21264542302778, 46.01464240781723, 77.26986869688957, 42.82704199514082, 36.267521150650516, 44.84908657689249, 41.64531423199562, 43.404732596489694, 56.275437262750444, 52.068758010864265, 29.195772101802213, 41.26926875883534, 55.057784511197, 46.913665340792754, 60.36697926059846, 57.465276487412, 48.31723059377363, 46.276578287924494, 45.594540872881495, 53.943262638584265, 35.412016914736846, 42.81609073761971, 43.06690277591829, 57.39906295653313, 82.30160282504174, 74.31295856352776, 102.4323832604193, 103.85872179462065, 117.01454747107722, 107.46292498803909, 111.70631762473815, 128.42681684801656, 132.52592117555682, 127.73217293523975, 83.45721936994984, 28.89539895519134, 2.0522403356529053, 0.1660819477852314, 0.020614738478475524, 0.05245828047214497, 0.029907683774288145, 0.01602279118096997, 0.03191000969719983, 0.067806733291476, 0.050615819862052325, 0.08670128836867311, 0.051939899417301344, 0.05735511065370614, 0.06437119667328174, 0.04717859401998501, 0.03749377942914444, 0.011831959859738428, 0.05839585259016003, 0.053527501727183985, 0.017354976904067784, 0.02204842031783154, 0.014630102706442197, 0.05348808267304013, 0.04422036848301369, 0.025410100314465743, 0.03312322100804698, 0.02561835365580215, 0.05498062879327805, 0.007105271102890613, 0.017201801454047524, 0.03684777961743455, 0.04098325246764768, 0.05250627205016152, 0.031053337621532624, 0.013177524350823895, 0.06805127621778558, 0.08512446491588509, 0.02666511895856069, 0.012760175929044285, 0.01870367469476356, 0.04647357096414893, 0.022727319775449655, 0.08303975581281609, 0.032900909953300035, 0.02809978139045979, 0.02812007697479379, 0.031010078551668315, 0.027778880565517375, 0.022021509564271378, 0.06498484842238889, 0.04838974838475547, 0.03899806201638233, 0.01414057348043688, 0.0268084769918313, 0.019124875581192396, 0.005738877159948912, 0.04108278644120982, 0.07854300355839153, 0.03375221749827747, 0.042675356831281416, 0.019028103354597287, 0.08995140106567452, 0.04558983874777633, 0.027930778563923897, 0.24750509719935157, 0.117811766573258, 0.2015201486046276, 0.2028268647770728, 0.15934428109997706, 0.14781548521451413, 0.09434283155226901, 0.2159734085322388, 0.18841644448618736, 0.17599267404406302, 0.2843564850909095, 0.13190811379782616, 0.15674581811312707, 0.17626765364360425, 0.20529896922169194, 0.12647396869837277, 0.15855007774887547, 0.28567296122351005, 0.10045731635463816, 0.20690611443452298, 0.11122364791170244, 0.13586504985728573, 0.1394306835267813, 0.19619816643816812, 0.13484927855672377, 0.12488183880885764, 0.2849709182496994, 0.12320833506002543, 0.21217422529814706, 0.18480403348803523, 0.11732216744172959, 0.10803975585487582, 0.17626405303036013, 0.1652925707880528, 0.23987708312849845, 0.19990730369763993, 0.21774667225057082, 0.13238563172278867, 0.13728133192466152, 0.15906372438034705, 0.1573422635274549, 0.12999911462107014, 0.10886436523569208, 0.1705278624450007, 0.1398029256491892, 0.15606445951327202, 0.3295019545382069, 0.16598178945001096, 0.1568991123067756, 0.19715487235976806, 0.14977974997412774, 0.19383136843962057, 0.17471137666894546, 0.15177450503312773, 0.5172122498193096, 4.315481878096058, 17.198265483302457, 63.44674195012739, 101.39942707553988, 118.56465247369583, 105.92135506291544, 105.53374644248717, 101.6443947822817, 89.96227418222736, 91.08454273593043, 50.48381843874532, 62.981846947823804, 65.35062120806786, 60.455350260580744, 34.66922590809484, 32.509731669579786, 50.46617954008041, 50.98593673398418, 85.81877646907684, 101.08812424444385, 79.4010728405368, 113.0501373352543, 134.99040911274574, 109.89408062350367, 153.43563725871425, 112.7626903595463, 104.18080329895021, 83.22727434096798, 108.20879505526636, 81.40782017861643, 128.0442367061492, 119.94939819458993, 94.91101095753332, 87.47167110443117, 124.308743938323, 134.2715641760057, 146.15217239625994, 136.11917311145413, 108.95191161863266, 134.3297564598822, 92.91845475473713, 87.68794275099232, 51.70648397937898, 49.16578046737179, 41.91264729345999, 58.387374724111254, 76.17012239271595, 59.17727339652277, 86.53398929103729, 91.26319100779872, 119.71145153045656, 112.61275383733935, 117.45877942731305, 141.25699166328678, 147.57779705908993, 144.68404493024275, 100.95743871504261, 38.36442024477067, 3.550758203191142, 0.17542963006323384, 0.12868053940755705, 0.1519423548973376, 0.11286339782659086, 0.13186815465169568, 0.12810834067603274, 0.15288128757909422, 0.07925154295780006, 0.13513527450061616, 0.08041018199536108, 0.16136445495630466, 0.2269295996595775, 0.1962037282364984, 0.11375951385425945, 0.12853201028079758, 0.12615964282304049, 0.23128117825235092, 0.1388453157438386, 0.10887810119217443, 0.19260771151992584, 0.1901025886857702, 0.16251490451395512, 0.17014365402921555, 0.18725088767467007, 0.12752714807227736, 0.09504628412786031, 0.12091911112469052, 0.09118078066216362, 0.1413786765788832, 0.0921518660541023, 0.16714821960176193, 0.1551011345920063, 0.09210914133056518, 0.14678325834533862, 0.14713499995489276, 0.1341428995252617, 0.1826705858712235, 0.1656728874771826, 0.2066301389206802, 0.1597800165895493, 0.14845366709895674, 0.12158540843595421, 0.1883249582662698, 0.06148449693536086, 0.1338889720218797, 0.1323297073043162, 0.14733044430613518, 0.1610460381714567, 0.115412961421234, 0.20959160500957122, 0.14153310458265966, 0.11654230525657056, 0.12673614696869928, 0.18400184750076265, 0.24644510730380015, 0.2173521063260494, 0.14034549976068159, 0.14602697634648892, 0.21493076286729307, 0.292200765782787, 0.11566786951715909, 0.07502247714587758], [0.03581950193150871, 0.09018698842414925, 0.11270287942381636, 0.05462099264766421, 0.10451205119851137, 0.08516571875060759, 0.039741224759528716, 0.04716167113773766, 0.05576681886469165, 0.09547225199639799, 0.03327418246396607, 0.06326452904050389, 0.013102991656670648, 0.05364329591693898, 0.05147769175950558, 0.028789199235278274, 0.04163414758119372, 0.0547743711109844, 0.043789076303402265, 0.08773377570774286, 0.07457489027611672, 0.06927037491433083, 0.04437552810075783, 0.026592302301357833, 0.03855580328813484, 0.02630434325715948, 0.08999566562593946, 0.02202118206168375, 0.051422096758840546, 0.07464750775045927, 0.02311008411549753, 0.05193462490194267, 0.031831242452045126, 0.05636882224691011, 0.03270899726738853, 0.033190912537036404, 0.045844608947875044, 0.041286856942479654, 0.02991001651201758, 0.023923569899653236, 0.05119713887031521, 0.05441717878584901, 0.025249118428497065, 0.024387765555612506, 0.05540974528318452, 0.047789870896526886, 0.021572599277621316, 0.06969460376328038, 0.0755567315425123, 0.04402994583811491, 0.08193822863001017, 0.10776893611276343, 0.05681352862607568, 1.829053550477951, 16.32533513730572, 35.16457811478646, 49.10550148256364, 50.98632897100141, 49.26207073273198, 68.73887831164946, 76.04353181777462, 55.40970740779754, 25.41447585628879, 28.527704208127915, 22.121618640038278, 21.91319565619192, 13.381478651877373, 66.3660640101279, 71.67545487803798, 87.10834195536953, 124.3981190650694, 127.91454745877175, 115.79865978610133, 93.65849617988833, 81.13089299971058, 101.77116578625095, 86.83401138551774, 96.23060610986526, 106.90168872956308, 69.56330560868787, 76.86638232200377, 97.07521792381041, 99.72366502208095, 107.04966406668387, 121.68461553512083, 83.07885969838789, 103.29517918248331, 112.34012557614236, 106.32736744419222, 76.96769714355469, 120.68362666714577, 107.97830089446038, 90.72754429232691, 63.63711418644075, 78.80088744624969, 84.72158755025556, 78.57716329636114, 116.82165315074306, 92.46601720010081, 116.03352346727925, 92.21523654076361, 59.97436569583032, 42.08078361326649, 36.87790470738565, 31.505852014787738, 47.84343573354906, 55.21021173846338, 54.389859784033995, 68.58750620195943, 83.00257744327669, 91.06901015004804, 106.06417640562981, 101.93861176890712, 57.3013763273916, 13.267964278498004, 0.7141390118387438, 0.19321353385044684, 0.04596145650852592, 0.05909350971060415, 0.04645090242246947, 0.09335816342143283, 0.06097147466554757, 0.0235035143146712, 0.02300902754218588, 0.049237754090779254, 0.057170475803075306, 0.08688157183989402, 0.014888411275141183, 0.03501467294089737, 0.015376853613903927, 0.04790600216496856, 0.043232658983118115, 0.007684355049634413, 0.020727550670985254, 0.016492949873809854, 0.04090123126403459, 0.03348911992244182, 0.10283069504845528, 0.014353273004563826, 0.06129109037799701, 0.0786749545424696, 0.07875605261013394, 0.06503560174737247, 0.030184653287212697, 0.03522032158329122, 0.007915741373454372, 0.028536934142691955, 0.046180052036840114, 0.03968792802263652, 0.051689618492438916, 0.07145259934928148, 0.11476804562393697, 0.035603744758953976, 0.017643770984103604, 0.028923877492366783, 0.05799923355000154, 0.04362950784965389, 0.03594667252693926, 0.01659878109010958, 0.08069372645789578, 0.05013806444983329, 0.04465845203207386, 0.04361881709267055, 0.04128059034325904, 0.043785471859718525, 0.03708477274725034, 0.041925655527701305, 0.1274614024066156, 0.07031541843447955, 0.004132274433129257, 0.01953317937741597, 0.04464425642283694, 0.03005243608758094, 0.08027721211434373, 0.0834280015119622, 0.0732361516284366, 0.06250281930871068, 0.03294498682202351, 0.0243141713191665, 0.05768382366025641, 0.11488595421636298, 0.06708235119379337, 0.06269818705116069, 0.01975048404757775, 0.061280587312555125, 0.07466051592341355, 0.032025698549865235, 0.046890422386387666, 0.061169133010891184, 0.06092756250572782, 0.015344228802038538, 0.015902166806852386, 0.025291090470648585, 0.01779991885527007, 0.09284044120220408, 0.03245166833362272, 0.07382181052479052, 0.05806445444543516, 0.0478910826026432, 0.031844959256329367, 0.008269593555239901, 0.06267240819250865, 0.07506477286017711, 0.031034522502112295, 0.02923052716669777, 0.051638336566787575, 0.03407105946192338, 0.026729636968323783, 0.10084057482139719, 0.04100967867059573, 0.08068160694693366, 0.05256633717386473, 0.05833793634308442, 0.04195886543921886, 0.0028844316388600536, 0.06056889163089856, 0.05714996762934232, 0.05727738720334827, 0.022044520930296952, 0.08036563398256417, 0.05732302306099765, 0.023728380272645625, 0.04575760817275413, 0.05487968138749561, 0.03718782306438492, 0.08907051486594063, 0.025023059288580573, 0.01745974517337257, 0.06889907508006982, 1.2618735528761342, 14.787764068572754, 34.69597647267003, 54.55947091502529, 61.36914876199538, 64.58974807493149, 84.78705975317186, 97.17541094749205, 84.08624202974381, 50.93473411375477, 60.52012820397655, 44.20266820538429, 22.923156945936142, 21.82707021313329, 54.91813244358186, 48.03614570248512, 49.99829569170552, 54.38496858842912, 73.84338809597877, 77.86544138385405, 80.19340730482533, 73.8432861143543, 72.56080442859282, 63.57089281082154, 76.59542499050018, 74.25838270495015, 76.90624144769485, 70.82694422814154, 68.54912188745314, 60.77836136664114, 75.18115951168922, 57.789291720236506, 62.451722929554606, 68.95988033663842, 69.54106576981084, 67.64999697285315, 60.320444260874105, 87.39965638806744, 78.33712208655574, 68.47709148160874, 52.87152205744098, 55.51803542721657, 64.09766320259341, 56.155487260510846, 66.04694781764861, 62.78848978780932, 67.61777862425774, 64.36179560999717, 46.48018852356942, 33.03639419617192, 32.97202810164421, 38.27788491402903, 78.95272239562004, 84.55763247705276, 81.92499253057665, 90.88743579003119, 92.34947573754096, 102.99432554552632, 117.04872700475879, 122.55699772988598, 74.10715964532669, 18.412444976068315, 0.9697004888326892, 0.15488952578556153, 0.009547490457583581, 0.021106227931957093, 0.0312773532219111, 0.04384770118180783, 0.021211658867316383, 0.02475337718703574, 0.010781954005060178, 0.08666520562743948, 0.04967395306354569, 0.0780528988088331, 0.014046765056498831, 0.05667177554700644, 0.057499104539953896, 0.06443316552547679, 0.014888222625989829, 0.025363098905091325, 0.0170880603799296, 0.03694164837079664, 0.05254959432227958, 0.021096397108668764, 0.045342748579118526, 0.044884045773576346, 0.038342784879909414, 0.03662914578472415, 0.0619670135840293, 0.018181545554750392, 0.029349429758205533, 0.04593859644486539, 0.05503767170011998, 0.05147104211632283, 0.023279176957364527, 0.02484621746735948, 0.06477938364109685, 0.07453994134501105, 0.09685674907579538, 0.04956435652509813, 0.04137992130352124, 0.03997094005406384, 0.04249642550524685, 0.04795800421326872, 0.032647166311019854, 0.05303578053210532, 0.04725261726566861, 0.07018201188334534, 0.07400970124909956, 0.060283401305036205, 0.033689766010690125, 0.08536186790274036, 0.030920453925406745, 0.03071207034912321, 0.07025456807065396, 0.02067228891856728, 0.03754513030270896, 0.1028145382541322, 0.05116099101160804, 0.03261522427501698, 0.07160949415617412, 0.0389066370834987, 0.0638541179679094, 0.13311177582269715, 0.1931596012605775, 0.22225923655975252, 0.23720188877515255, 0.24196884024047086, 0.33712526482920496, 0.09371937387773106, 0.17042411881829464, 0.20713610935115045, 0.17955335878556777, 0.14477019378494832, 0.17843948226542244, 0.08921760374740248, 0.1681012636230838, 0.15232475534562143, 0.20640467924456443, 0.14233973387989307, 0.08543584901358812, 0.19468567904926118, 0.12055976226204827, 0.13499485058409555, 0.11435710073959444, 0.11869523448929672, 0.14561451460805633, 0.11425346436519777, 0.10144590685564665, 0.17722673443776948, 0.10260110615842766, 0.11578215451370324, 0.19703018388921217, 0.09441441480791378, 0.22727876721370607, 0.22686426768139487, 0.17088567147091513, 0.1864723584824993, 0.13679134208829175, 0.09767708368599416, 0.11502910540589403, 0.1545058536313234, 0.14936256913408158, 0.15018378474539326, 0.19174114350349675, 0.10884168137225414, 0.17144695344951846, 0.28946243046272185, 0.17724456896464671, 0.14657780888580507, 0.22618027373908028, 0.1534374980556388, 0.15492818258222074, 0.15826771306174417, 0.12908229123680823, 0.3361984823019274, 3.647635598336497, 21.355662115158577, 52.250375516953014, 78.69809781351398, 82.9763210973432, 79.70038890838623, 97.36614796423144, 107.08450255855438, 79.1268285628288, 41.439021095152825, 48.18906714839321, 40.3442208997665, 40.929489520288286, 27.32164009924858, 94.79737204890098, 104.93526335685485, 126.05775233237975, 181.41122079664663, 178.75663911142658, 167.82563670989006, 140.81643104553223, 125.02911075468987, 142.26623319810437, 125.23704344226469, 149.4440294081165, 152.63719958643762, 103.9724156164354, 123.79599601991715, 148.85095134858165, 144.6787105068084, 159.34296208043253, 177.34902597242788, 120.77330773876561, 155.44505180851107, 161.47980659238755, 147.84225894558816, 112.05609890722461, 182.19993099089592, 156.10855994686005, 123.76227148117559, 93.38685635597476, 117.04734633045813, 123.05925723045104, 114.86079754367952, 162.0077576175813, 133.0292554055491, 165.09536896982502, 131.00732065016226, 82.3158488735076, 55.98579375974594, 53.32732892805531, 52.17852161776636, 71.13764301423105, 79.63792124102193, 81.69125849200834, 93.10260218958702, 104.3913325955791, 113.23999574107509, 130.89685101662914, 139.54831307934177, 91.74596417334773, 23.44942919669613, 1.3719743610389772, 0.30170295267335834, 0.11033441901447312, 0.2227549873773129, 0.20702358635683216, 0.2115645265627292, 0.09893320741191988, 0.08317550659299859, 0.14623215001436973, 0.18065237319998204, 0.29225721114104797, 0.19220706285728564, 0.1100707162291773, 0.11964252519030726, 0.18530248093508905, 0.15087856520568171, 0.16312763695755314, 0.15460674741095112, 0.0771045968717625, 0.10212329712005393, 0.12605301870573915, 0.2092424834207181, 0.2069080143325752, 0.11470219270596582, 0.09671886091030414, 0.24948741099046123, 0.19580868733746393, 0.14626365154981613, 0.12119075824176112, 0.2547596893723934, 0.10342172422115842, 0.11641944773615369, 0.14697116439140614, 0.14191902903539522, 0.14622450445688542, 0.22406634604257925, 0.22264790360725698, 0.16712399590159618, 0.30935899024048163, 0.13840369669900787, 0.23517647487742288, 0.1902516387523182, 0.10836813178273941, 0.20104025580709983, 0.12110589868238858, 0.2260232257146028, 0.11764504285829684, 0.13748377831953187, 0.15122543449603743, 0.16884717279143874, 0.130238271949272, 0.11635494313292927, 0.24901338642643345, 0.22140849591983905, 0.1306579808794683, 0.1635599403732246, 0.17347140207646355, 0.11484168199521881, 0.213751646299516, 0.12439109820632205, 0.1272260908397936], [0.008060805867576312, 0.02171158294884428, 0.0795559479945129, 0.058432605658327384, 0.03879994784872379, 0.03674643384593149, 0.02934117707604122, 0.03425556407760709, 0.045537771582002604, 0.04138972722895203, 0.02446144597694999, 0.0304027680953544, 0.052635901787829016, 0.025634973933319413, 0.06449296634884612, 0.07237748197850681, 0.030786252558051102, 0.006426120272672345, 0.06343044070226532, 0.029208224432002154, 0.03312692504316088, 0.055415376029427976, 0.04181925357589799, 0.04626646292425933, 0.02708112959930253, 0.19379661869137518, 0.011815412360573969, 0.09450570184497104, 0.016741715859802022, 0.06084028976939379, 0.03604051063678438, 0.035238841758860696, 0.05284191049154728, 0.05860210644201406, 0.018748025439919967, 0.05832495881364711, 0.0757037591369402, 0.09258095956137104, 0.0197914601754277, 0.04864459136320699, 0.049773839437553, 0.015222213978338388, 0.016503326534744234, 0.01288598576079934, 0.07744552898070506, 0.05214808381072456, 0.05459086624004188, 0.03655081712490609, 0.033873960360764496, 0.03438832328444527, 0.1983848724874758, 0.4670430515562335, 6.595005546846698, 31.409795130452803, 51.96470929730324, 75.81295136482485, 71.20888110130065, 50.630224827797186, 43.125557899475105, 43.24245237535046, 29.840156724376065, 8.13188627842934, 20.36023909045804, 23.81479209469211, 35.40165401274158, 59.37114438702984, 89.91128336998725, 58.8396514615705, 50.48646603861163, 58.03516549448813, 51.99396625641854, 43.04175646074357, 17.28110594134177, 3.7675279907641874, 1.2219679716133303, 0.3467024057622879, 0.4964785091578961, 0.42889772583880736, 0.34978391782891366, 0.5457062466490654, 1.0879769873234535, 1.4709883447616332, 2.11827086344842, 1.2517369226101906, 1.7305021612874925, 0.6063889904368309, 0.3693257482542146, 0.6174547321373417, 0.40049428060170145, 0.9144748038341923, 0.3731240428263142, 0.5511564412905324, 0.5381383398367513, 0.9793132375324927, 1.0144438846938073, 1.6455066059866261, 0.18021196457407168, 0.7541361559302576, 3.889878973845513, 16.87974549108936, 36.9157281229573, 76.53939001021847, 132.13285261584866, 107.02292919158937, 104.60558029913135, 55.6446534587491, 37.38375317665839, 24.254036757253832, 37.07694930415, 67.05204732956426, 63.32812947611656, 81.89325271114227, 95.44878359763854, 93.54678707738077, 82.40440814725815, 48.44936347776844, 15.833246342597471, 8.237230354739774, 2.18458098269278, 0.23214270541023826, 0.03497113999460013, 0.07791928541395934, 0.008070979515210757, 0.04946212975248214, 0.03986816169814237, 0.09791252548776327, 0.02855269831695384, 0.05907821859563551, 0.03557027820798178, 0.03139243686511632, 0.06317336457751452, 0.029561697400265166, 0.019337712043535807, 0.014813100044134886, 0.02929843128508618, 0.051579006887491674, 0.07222858512954367, 0.057898650035983136, 0.026762975199568658, 0.01425475984316079, 0.022923162492412715, 0.03519973297032618, 0.019773183232774178, 0.04821390439305575, 0.030139358338689616, 0.06729447327914738, 0.02425371740584172, 0.03791229326217886, 0.12438679279218759, 0.03166858474874208, 0.019201352223453504, 0.031352872254266854, 0.008991044409002268, 0.06303644168280786, 0.024707551722625093, 0.08206941352616395, 0.047946099206925406, 0.007854057410206165, 0.03760976897132012, 0.03118970318727436, 0.0782842573619658, 0.06934728248104935, 0.023330334393728166, 0.014280964838220708, 0.04028505908565656, 0.021271610993050763, 0.05490889615048805, 0.060960534929988854, 0.01543049221753233, 0.04292604378274372, 0.07747267147586231, 0.04136358447853596, 0.018986129397225958, 0.022285350245393576, 0.07725519443591757, 0.03958294333349313, 0.05024688723947733, 0.009708750050424809, 0.07366352909875494, 0.017732353730788155, 0.15891165592737738, 0.03652891084071129, 0.04624879693672542, 0.01080457466624437, 0.014312113973221952, 0.04919071629222843, 0.033629168455879536, 0.02812821282854965, 0.04164692975821034, 0.06221973066849094, 0.0385515898045513, 0.012139922417249652, 0.06027617326547062, 0.06351306328489896, 0.04113224124716174, 0.059676560077575914, 0.031309651488798766, 0.004065816784502878, 0.039600716573336435, 0.032607073099502636, 0.019231158789367448, 0.12243809493919536, 0.07544167279716461, 0.020136193995694482, 0.047577584102269144, 0.02133178336906337, 0.02973236838325618, 0.020964520818163312, 0.018247978784324183, 0.12134101106635026, 0.0140713325386206, 0.036254551772388725, 0.03812986989355376, 0.06014699551967844, 0.0854085686226045, 0.0533590734665913, 0.01683610938339224, 0.0209978073384733, 0.05345687608144457, 0.04177439146705213, 0.03861007678713049, 0.0340451656900827, 0.05333434797883515, 0.006943151097549427, 0.04940302989956352, 0.11816433555777035, 0.05810592278477646, 0.3463220890731581, 6.795656354196611, 32.69336723512219, 60.9988417163972, 91.12058931781401, 93.57622054315384, 71.2323917881135, 60.473087218499955, 60.05919871791717, 47.07432170068064, 25.595404986412298, 24.250657635350382, 21.717871427536014, 34.84142188102969, 38.23908875065465, 43.76321369601835, 58.1984184634301, 56.94796685249575, 59.52310877461588, 57.11217295738959, 46.96507976901147, 19.839489536900675, 6.028675110109392, 1.4829830753226436, 0.3704210088377999, 0.40376550668189604, 0.3064000215982237, 0.7893290707180578, 0.3950049848325791, 1.1624239409162154, 2.124832743598569, 2.1948725465805303, 0.994358285059852, 1.9539132570066762, 0.23025284310983074, 0.22261451749551683, 0.47182598361565226, 0.990303902616424, 1.1998344044531546, 0.46996199976532693, 0.14183413117162644, 0.3214799414478964, 0.6621039911143242, 0.5069945980944942, 0.8224250496395173, 0.269628843112338, 1.6226447037150784, 4.926346905769841, 16.239999071244274, 33.649923493785245, 61.751434726099816, 81.31085918795678, 76.42036960970971, 64.40878952703169, 41.32408780436362, 38.37761117566017, 41.85565917722641, 58.83529763067923, 98.91131078043293, 90.66916373468216, 100.29641735938289, 107.27264296623969, 109.39880294184532, 100.50229472498741, 63.68264113703082, 23.096433531853464, 10.253102106432761, 2.430664848896765, 0.04217562235651478, 0.06179422628314746, 0.024078469047503128, 0.04118051244727066, 0.04075707649932273, 0.025947811682858778, 0.01556507088319068, 0.018337789186907393, 0.0435477203028577, 0.04820579535237724, 0.008201108167638943, 0.025615835141751076, 0.06757849271619512, 0.01190146988993811, 0.009161000057393986, 0.06277870672244219, 0.025951921744572542, 0.08146035064372324, 0.014875144547512455, 0.04237554832211426, 0.05707588309662477, 0.05500790152338244, 0.02007137721164092, 0.08897502966705831, 0.03975257435212693, 0.06046136352984656, 0.061780865709748, 0.01675020219878324, 0.05779068526481429, 0.05920302964025929, 0.09154409019937439, 0.01854998788105384, 0.02473986531127124, 0.05064949708720369, 0.01092630507980263, 0.03405518995057191, 0.06948548474258955, 0.05079595011568839, 0.03129670460287842, 0.026403808282808434, 0.05591053312884704, 0.034680620301514864, 0.027530463149530754, 0.05091532193604977, 0.0005666290927629527, 0.03500253044729752, 0.03093996618483817, 0.05830347770825029, 0.054682000059514284, 0.046987876431235386, 0.052078461740165956, 0.02707227936855728, 0.050960946302380294, 0.09819045452581299, 0.10970655633437057, 0.07922568749035559, 0.03284447991679753, 0.24917549063121122, 0.08934494288217637, 0.2154984493409434, 0.1693272954153438, 0.21658234117973238, 0.19002787979139438, 0.14689009696725877, 0.20468324903518925, 0.15581017960944485, 0.15852556293529851, 0.1457194992971997, 0.17018660091825072, 0.14768981615141516, 0.10940097918313359, 0.15932214115896534, 0.11175071640360741, 0.0980930770897577, 0.15258376967282067, 0.14234036207199097, 0.1577821818570937, 0.12148302844575337, 0.17290852663497772, 0.18153161231067874, 0.10724433442397464, 0.09600029341996678, 0.3207253448424801, 0.12298894280026998, 0.1125430811436907, 0.1164490340517894, 0.15326119058074492, 0.19379367691374597, 0.15016216574417007, 0.09726889671817904, 0.3002636879682541, 0.13126832312874256, 0.12641087369692902, 0.23598429927181816, 0.2648232042068436, 0.14320480036399058, 0.10737273076008405, 0.11582413613195382, 0.13870991736410127, 0.19340056655628068, 0.19715312567930068, 0.16947061514421818, 0.14859504096450346, 0.18254274111841956, 0.1649329997599125, 0.20828233010345892, 0.2251883584164804, 0.30842286144052783, 0.7140290628998511, 13.171025841466843, 46.584931496650945, 78.24162021760019, 113.33344228806035, 105.6975446208831, 82.54653915282219, 70.99548847444596, 72.36478005686115, 47.236994158837106, 16.33252288064649, 32.21334561224907, 38.62481855577038, 53.443591902332926, 89.49489239723452, 132.3572749476279, 96.23117093117007, 81.08239681490006, 86.04759970018941, 79.28944218543269, 67.45678101816486, 26.3525910915867, 8.554271613397907, 2.276583116862082, 0.5014037803536462, 1.0504433368482897, 0.6334461740428402, 1.0428786782487747, 1.321215581509375, 2.751076158977324, 2.6773159878869213, 5.18959972166246, 1.8347116920255848, 2.5701053536707357, 1.0792196830434184, 0.4538456548846537, 0.6965176412655462, 1.905116520581707, 2.116949760144757, 0.7532180761617999, 0.7635963612025785, 1.1884112367706916, 1.9064299017190935, 1.6102658260253169, 2.3396516423071585, 1.043049791647542, 2.4203897099341116, 7.521997920928463, 26.406302067541308, 54.97239059017551, 108.21230949894075, 180.3337927787535, 147.39182964448008, 138.6198566805932, 79.87505205215948, 53.028648284173784, 40.892564327486106, 57.86585638600012, 94.19080103597334, 89.85430702086418, 107.36247308792608, 116.42405033111574, 119.88948791257798, 118.20090755339592, 77.9140317055487, 29.36367504058346, 14.006939799554887, 4.539150624505935, 0.4084952109523358, 0.09148045893638365, 0.13521032047367867, 0.10569905081102926, 0.21779801546325608, 0.09261824506064577, 0.24620869257036718, 0.10844981207722619, 0.17236540094017985, 0.1548924522414323, 0.17495315401784836, 0.22350671881389236, 0.18331157163746897, 0.11157891352570827, 0.08096092260412632, 0.0998538459140447, 0.08334743204496561, 0.16227029263973236, 0.1449178189279572, 0.08699545847071756, 0.1553616504515371, 0.10793234266701246, 0.10075547777476812, 0.15549897937284363, 0.1376162195998815, 0.15686955663465685, 0.18463503449193894, 0.08448928609610566, 0.11054682455235913, 0.164822805672884, 0.1895612709584736, 0.11187469241239371, 0.09582738737545668, 0.12089072756709592, 0.1499186417147998, 0.07840671651666203, 0.14134723633047075, 0.09817306432993182, 0.0925955918407248, 0.11828330901241112, 0.08437393623734675, 0.21828415953824598, 0.23414055546445234, 0.13052699516617483, 0.1390443147430497, 0.1306273373624971, 0.1462661643182078, 0.20443941857064926, 0.1861961837857962, 0.05232516886486162, 0.14920748229469025, 0.15852033821565492, 0.2347094676787815, 0.24286703236641424, 0.1875177927074894, 0.33394370167966814, 0.22701917065968438], [0.020643635314979383, 0.022594472468500177, 0.0223186080374064, 0.03968889712386074, 0.03231091882973429, 0.10312984472200756, 0.04504580906922779, 0.05467421277576397, 0.04988027203287329, 0.06326785003165565, 0.0290405526832347, 0.04444232330687585, 0.07208743342949499, 0.09372344946548825, 0.010057439757210594, 0.012364429271509571, 0.018356979689410618, 0.09896451742538522, 0.05982700059370649, 0.03028182004908881, 0.03805631013106435, 0.02788261270090457, 0.033821261172453244, 0.009037508599219785, 0.0356564209646275, 0.080349316309777, 0.03773484431627778, 0.019756668292346503, 0.018520234941294598, 0.021571656989474452, 0.046226860009013646, 0.03819478818425729, 0.08983837245332618, 0.019684050818003958, 0.03461639915082244, 0.040709418169553244, 0.058414495339797395, 0.02322933336179103, 0.012710106337533124, 0.03827481372882763, 0.09352484883199777, 0.02577598007666248, 0.017241683991385565, 0.10310657863174716, 0.02836229290903336, 0.048988089866695866, 0.06190018007351507, 0.05732696075292845, 0.07782825884679634, 0.15195583804480492, 2.2004565308170934, 21.52212162171641, 51.31176017945813, 67.90627679517193, 69.42526955758372, 53.5256871100395, 52.2831351526322, 36.33016140230241, 44.04259627865207, 41.04757247432586, 39.5029587899485, 50.31470544876591, 64.72279094880628, 114.2376898181054, 114.67454771841727, 64.43041355379167, 54.407416312925285, 35.46199967784267, 18.640205244864188, 3.781135183188223, 0.41579146298670006, 0.21607873030006888, 0.03208728627331796, 0.049668854748409604, 0.02216183005892221, 0.26439968015878434, 0.036843248207362435, 0.3199350178962754, 0.04457327837665235, 0.04939507407646987, 0.011198678065181501, 0.04513674370583989, 0.030995658861713547, 0.1686926068918359, 0.018056278687811667, 0.14882767122359047, 0.27071178500210086, 0.15206823846505535, 0.06949726717486497, 0.022257349731761123, 0.1403858572725327, 0.29199413654785006, 0.23391246044587707, 0.32560232185548355, 0.5479895563856249, 0.8574567795280488, 0.14433439700834214, 0.1265675233556859, 0.2106819013434072, 0.6022947714213402, 0.5832535028457642, 0.26622444030738646, 4.188927094782553, 14.653425831948558, 40.944716161297215, 90.15693356913906, 85.33892154693605, 71.10613069226666, 48.98046808858072, 14.283931697568587, 21.047234381398848, 41.63058965436874, 74.08969725331953, 72.41606896923435, 80.82299478592412, 86.35856520745062, 79.60277680427798, 63.61842017019949, 35.89489990665067, 11.479387994735472, 1.2346918953041877, 0.12719783751714614, 0.08430037647485734, 0.029118770260303736, 0.03937590807195633, 0.020023123248510306, 0.024373500998462402, 0.05616485899794967, 0.033144422491351445, 0.04139212891459465, 0.04656337562107271, 0.009995030404459085, 0.03146276565178508, 0.05036908975471893, 0.07794285793938945, 0.004332426873471348, 0.031150912325228416, 0.11956527288402281, 0.06845545654575672, 0.02837414620444179, 0.0542287901043892, 0.015618693207450693, 0.02090469509693644, 0.037969328508141546, 0.05611133626511982, 0.028960954232682145, 0.07648167545877158, 0.06219763286231507, 0.03886925965367306, 0.01584380144073117, 0.03333349682150349, 0.01826024002155229, 0.024220141687340314, 0.038714345184064684, 0.038179481747530164, 0.014180009771559029, 0.04743177075720122, 0.029794283609296528, 0.04437663892824804, 0.013734056584296689, 0.06522729992866516, 0.03302141558378935, 0.007386051424433508, 0.06742804836962493, 0.01824999359556504, 0.026335848623045513, 0.02069978955982914, 0.06968675902293575, 0.0322204859807126, 0.06769598762114203, 0.014680839752057388, 0.04584015414659535, 0.017960096348918254, 0.07492879225361733, 0.08725665614850099, 0.025034696164150393, 0.05284367249377313, 0.06489147762617757, 0.0054276908086913255, 0.03570874860029548, 0.013137085442130846, 0.03227356821298599, 0.043104523116902965, 0.03355539801921095, 0.031571103890817014, 0.07177871531776844, 0.05158962869656183, 0.04383753519505263, 0.011776471153772887, 0.05848577982115169, 0.02378436023249261, 0.03487832461213393, 0.011107848765658996, 0.06812285947343034, 0.0736599438072693, 0.029391604813656984, 0.024698017758407423, 0.036541490004427975, 0.014981276453322461, 0.016324969774652875, 0.03241293875861072, 0.01839781409099458, 0.03239578221954646, 0.05332543837627577, 0.04185717492814987, 0.04611344452226355, 0.03827367225782045, 0.023024039035062158, 0.030402825551948724, 0.03524618088117531, 0.05794800142006529, 0.0697450583139735, 0.07805413221039119, 0.05959396047757999, 0.026744753798289646, 0.0854098939547135, 0.03649782682318361, 0.03921821270318281, 0.03597258928141767, 0.0358199309407463, 0.041597643491601756, 0.033344976649048834, 0.11513104872597803, 0.08546038680980284, 0.05312051751740998, 0.10034231123544517, 2.48856540649168, 23.712900684725856, 56.58636354630994, 84.8097232080275, 87.97321673362487, 79.74181698214623, 67.68833421891736, 49.71864638790008, 52.353047478583555, 52.75421965506769, 44.332184868474165, 23.554505571242302, 37.311926734062936, 62.77554596624067, 77.66183899294946, 62.37475818203342, 63.56697828538957, 38.38484794862809, 22.86683367144677, 6.373245033525652, 0.5828558725695456, 0.07023285713887985, 0.03572059231960485, 0.17903508498303353, 0.09300596215912411, 0.17269734683777058, 0.055191521307513605, 0.03148246177231833, 0.23067226092661583, 0.07215877919788323, 0.04818546720930646, 0.33071261860670587, 0.22764688778308131, 0.37087162175486166, 0.016255985472291228, 0.5247617705214409, 0.9054350889017506, 0.38335873234656553, 0.06747108718921101, 0.1214440728748037, 0.06394668054136057, 0.09235755300089236, 0.17023939969799212, 0.13705754232022072, 0.1376123585167431, 0.17630657091015772, 0.0929878288579564, 0.14819138923720007, 0.45275784067569247, 0.8637840529122661, 0.29666089903443094, 0.14246586259574662, 5.351309237941619, 17.68883239838385, 45.769509961528165, 78.64043112724059, 63.262049305823545, 42.734073977316584, 39.335583409955426, 30.6483159911248, 45.07267344382502, 65.02757087830575, 93.08599487427743, 88.82516337979226, 96.0887026017712, 105.90019779820597, 98.27903255339592, 83.7053406623102, 45.736436536235196, 13.168671438770911, 1.3297399950604285, 0.10736335384389085, 0.05145573184915608, 0.017859125960498087, 0.031334298452542673, 0.045889880913760395, 0.029201553721401482, 0.055062588709857196, 0.04234823728761366, 0.02760269374947154, 0.06133153215951978, 0.018744488028929602, 0.002489160674045824, 0.027668334078043703, 0.024388566117493377, 0.040431397200952617, 0.03414826963337199, 0.06368339527398348, 0.04816659846373143, 0.0436822530032406, 0.041853949697988654, 0.01720266521818215, 0.043416102567026695, 0.04149819378771129, 0.08478759307294123, 0.05054039084502766, 0.024696906930917216, 0.04239029934509628, 0.021009407824866717, 0.03994243009196174, 0.03544730194393666, 0.05171074719739057, 0.04691739251176196, 0.037563412991021915, 0.03631169810110042, 0.03275569415681305, 0.027326565018043886, 0.021989347277990273, 0.04945227020089665, 0.019301926161372857, 0.0867396770345588, 0.1633747003131336, 0.03814704941525575, 0.019581124990157062, 0.019239740889339198, 0.05675451304282873, 0.047805001133031426, 0.09688416736260538, 0.01617647512184997, 0.03493316501619355, 0.02554592387300105, 0.02178155741984806, 0.0427421635287183, 0.009484568783532708, 0.01012659930218492, 0.017117150653634342, 0.11204709283887379, 0.12440352415245388, 0.07601204823942916, 0.13300784833488927, 0.15875961811792466, 0.2072834280589896, 0.10451932903379203, 0.17450681587140407, 0.12204324556214195, 0.2226981436533313, 0.1713094559888686, 0.17550780167502744, 0.12878471204350073, 0.3610787811058183, 0.1294151717616666, 0.08462130602809691, 0.08615553499229493, 0.1438319812258405, 0.1410293558071698, 0.11888624319145757, 0.16219068078264115, 0.09515968812329155, 0.17695822062030916, 0.2018003682455709, 0.10882648984871565, 0.11731498153699983, 0.17070695847993897, 0.19540535736708872, 0.14684287530760612, 0.18995134760775875, 0.12237000504448531, 0.13325517216036398, 0.1863796312001444, 0.1582266967142782, 0.13233568279012559, 0.21613445553568103, 0.173486371434504, 0.21201046634345286, 0.11836856693750429, 0.21444464943582014, 0.2605603539174603, 0.1127252032259299, 0.1305662341896565, 0.18804997866672857, 0.10414866505250817, 0.10849085906820913, 0.15334792705553194, 0.26064088508006067, 0.14719005103313154, 0.22025904227649012, 4.106738730784386, 34.323519968217425, 76.35971407736503, 104.77595236993606, 106.10810695155975, 86.44113109957787, 82.82116782280707, 62.05900738316198, 68.2679428592805, 61.8655639310037, 61.64365191613475, 73.87315888558665, 95.90453947744062, 156.66657201705442, 156.05551381264965, 96.23915687684091, 79.69551732463222, 54.07291266226, 28.91146106104697, 8.638787904093343, 0.9594938074869495, 0.4165245784867195, 0.15953145170163724, 0.2182721166360763, 0.20192927019971035, 0.29679802877287714, 0.24723497459725027, 0.7254350702128103, 0.38866067365292584, 0.1673372288144404, 0.19481142472115257, 0.2537095360457897, 0.14857461706044214, 0.33135242459754793, 0.15791086930661433, 0.4092086839579767, 0.612772831753377, 0.26441273429701406, 0.13569240428266988, 0.25544296319205917, 0.44505966827273374, 0.31704340370432027, 0.529036541138926, 0.7854623491725614, 0.6655594153750328, 0.9946348121570003, 0.26678503280685795, 0.23414925822327215, 0.4707396709390225, 1.1135160298116746, 0.9424316810984766, 0.6001445771225038, 7.170724666887715, 23.669511425879694, 62.72084851418773, 129.55845986643146, 123.30903376302412, 103.7766658106158, 70.46951432381907, 25.626313263370147, 33.91720948680755, 62.04478094654699, 98.49656720315257, 97.69365802887948, 107.30422589086719, 116.31730694924633, 116.2398950515255, 100.27772334314163, 58.47771867629021, 17.07461472480528, 1.9570961378274427, 0.17535076897230842, 0.2435631764632079, 0.16658442485476696, 0.1145320598997416, 0.10545847622016746, 0.08236189057389576, 0.21494789259327998, 0.17478047779971556, 0.2733511417623489, 0.17089020671142688, 0.1880984720323355, 0.07795087887995666, 0.12763893562218837, 0.19146535185075578, 0.14059692981743044, 0.1425292180670846, 0.2691797623711248, 0.18843499913571343, 0.1524600158295324, 0.10794225584475264, 0.16464738685998226, 0.12920207674464873, 0.16503252990303502, 0.2097200473109561, 0.22961668369750823, 0.21037091561142476, 0.16623046159023241, 0.14787657306559626, 0.14273869714909984, 0.05980776412592781, 0.1692981074654287, 0.09003871976728402, 0.25569915831569706, 0.08928799956676461, 0.15809931161422885, 0.12927191331982613, 0.13575451869157054, 0.12483855484113579, 0.1519780086293336, 0.19205098010359273, 0.26610076307289066, 0.06970067884051992, 0.19479438692571657, 0.08237598659170252, 0.23103584625547935, 0.09734524504071283, 0.24805087355836747, 0.1241611109505738, 0.21988531394350916, 0.12924249554353376, 0.08348338200800842, 0.18158281762753764, 0.12956664266605533, 0.10345003116996059, 0.08674604322520957], [0.08746425065422252, 0.07454599343961285, 0.0576493343819053, 0.04486002508671053, 0.027009287788983316, 0.022508563368671367, 0.04251284276946418, 0.017389730482752767, 0.022685797809953653, 0.04017069364988035, 0.0054486016573895135, 0.03823901827056562, 0.028973493176782807, 0.019173679212408683, 0.09544313299439608, 0.03712117724541215, 0.03909088122928816, 0.05187590043210695, 0.05573509899418681, 0.0449393228477528, 0.032234367493900566, 0.00879798163359444, 0.02295977957997351, 0.04378556762070906, 0.040118653297183976, 0.03623121290377552, 0.07858980386968582, 0.042118548806155884, 0.03043089118305474, 0.03126574507463844, 0.017050832337249192, 0.1053236983716488, 0.037532807778446906, 0.0013312904775375502, 0.027862160068546093, 0.01251186863819678, 0.02813616482120368, 0.014881282827005753, 0.046307705267662966, 0.04151978980629675, 0.042455796032182636, 0.08177889000263908, 0.03604106222008986, 0.04243485118833281, 0.1351267249593812, 0.026301773032173518, 0.08819110721590058, 0.20058346822136836, 1.7271574826971179, 5.469988392245385, 27.301577175817183, 58.7135668723814, 63.98487937065863, 60.96791382758849, 55.627198911482296, 32.834501958662464, 30.04856009637156, 32.255503246861124, 34.47190323183614, 45.62859096834737, 42.70704884682932, 89.91079699608588, 81.19318023804696, 44.82259881111884, 31.264365411573845, 12.078060334728612, 1.1561676379173034, 0.18814675089332367, 0.36093300989558624, 0.012061467352924089, 0.09983378207130779, 0.1487733402680005, 0.05507221460462578, 0.03775388926207539, 0.16917861307099943, 0.2746719999178764, 0.15558510297729125, 0.26398727970738567, 0.16558581392370886, 0.02807577411013265, 0.11290042285597134, 0.07817947185568272, 0.0515624019317329, 0.09966928767220629, 0.08708984816386815, 0.2823163929485506, 0.20695063946468217, 0.24043013732279503, 0.18781892654876556, 0.08790902598130126, 0.12273581202832923, 0.15243340193504287, 0.24487094983698862, 0.10221375678215297, 0.2790450442942881, 0.6010144239952487, 0.18421878827916038, 0.0564631927878626, 0.13390449296322562, 0.2884618889900946, 0.0880905811584765, 0.19688654240340958, 0.13776019816437077, 0.1686043535629588, 0.18174168894127493, 5.916721349762333, 37.901898276421335, 83.48873169191423, 86.92676759535267, 87.33980886397823, 39.42819449209398, 23.471039495160504, 21.901183397539203, 33.78884992291851, 63.422321273434555, 64.19076850337368, 77.15834002340995, 79.03689645951795, 69.93304391061106, 49.84164014939339, 22.29842535911068, 4.662571924348032, 0.18135106070868431, 0.026910539055543563, 0.024943907084243915, 0.04124870193341086, 0.06663698597901291, 0.05533673710400059, 0.027484174201925917, 0.021124255896035223, 0.030569039818440235, 0.011180587856459522, 0.053623036721781384, 0.06150259959301161, 0.01675498833309018, 0.032024133815279895, 0.01735597664880897, 0.014552137938388174, 0.058897176697369547, 0.020214193237705097, 0.044182113882514744, 0.04595768352549884, 0.015503438152072412, 0.019567969345277356, 0.04516552945959472, 0.04967611343149216, 0.032013667139014414, 0.0369963355572714, 0.04076723865563831, 0.0211856214539899, 0.017326882544664607, 0.0638106846130423, 0.04835211048503557, 0.01587487779737961, 0.02523115366667269, 0.032555013594608155, 0.03190424488556962, 0.06453229730287868, 0.014404929355688155, 0.018650816543208017, 0.04911226122790287, 0.0389550308576755, 0.04706160856350776, 0.023906189279871124, 0.079250278912725, 0.03575870136339818, 0.054655945409209504, 0.019360679359505736, 0.02279171329592505, 0.03102577377801701, 0.06017128050687814, 0.06658129904779696, 0.011615887633524837, 0.04801932572116775, 0.03202775549594193, 0.032419538606078394, 0.051512464490388675, 0.05529433413739166, 0.04533568907889628, 0.04476318391220224, 0.0633859807895797, 0.03845030532008217, 0.13406276672838197, 0.018935402885319728, 0.0483141738110252, 0.017842289263142214, 0.007223231885056462, 0.009336516546506074, 0.06098172875241407, 0.017115597410367864, 0.10170607797561154, 0.04472173089461942, 0.019196229010459878, 0.018717517903555306, 0.062281350950680436, 0.12257707861041832, 0.02226307432377531, 0.12393722941558208, 0.00913228995482167, 0.06118852269625472, 0.03682978038165358, 0.025586664428814285, 0.022852144226612105, 0.09695737472464962, 0.051571510717152595, 0.024494293911923325, 0.08764438090785857, 0.075602566583022, 0.04641836283788566, 0.11054087204918747, 0.03024122504998119, 0.02418839308853832, 0.005524020619510163, 0.034352550808821, 0.051335245370864875, 0.03506826462164041, 0.08421757003112186, 0.034871586868839885, 0.028016921320569613, 0.034935153014357054, 0.05698569156529923, 0.04868856097962107, 0.011376182552457098, 0.20458272297776517, 1.337900608778, 5.995853206803722, 35.6240955475838, 69.84231164378505, 83.93416389342278, 79.50325058352563, 74.84692650456583, 52.12560492177164, 60.230355262756355, 50.16485129633258, 43.05491209030152, 34.539885751662716, 31.131071506008027, 55.82127386523832, 65.01159898696407, 56.72026149688229, 37.20723475179365, 14.38320198366719, 1.641667463606404, 0.33745839050219906, 0.08064943125411388, 0.30629791739967566, 0.11757141414789424, 0.10089120557231289, 0.08297602495839519, 0.16828541583832235, 0.34099376369868556, 0.2564756956792647, 0.40636257538872383, 0.7926641272441034, 0.46757796478848307, 0.6054442508086082, 1.3508216315700163, 0.8701295285455642, 1.1438623046682728, 0.34411915728161413, 1.2431137143604218, 1.8194595556105337, 1.3088217497833314, 0.9496122538562745, 0.932853130563613, 0.6744709791195008, 0.5128939041206914, 0.5682148291699348, 0.9170204220760254, 0.3751300593778011, 0.6408711594920005, 1.201818510890007, 0.33081876774949415, 0.1209002117355985, 0.3232093696152011, 0.18774029528421743, 0.22806771520164706, 0.08179665558160314, 0.2871644118380162, 0.2503023140372769, 0.17252729064033878, 7.743244113460665, 38.55198798641082, 72.29000399189611, 66.44212661250945, 42.72822180101949, 29.932383414237734, 36.11554107358379, 41.276015235531716, 61.22548018732379, 86.42626531662481, 85.5497097199963, 96.7215064264113, 97.01384067535402, 89.74553969598587, 73.40100749846428, 33.50738063935311, 6.704330338585762, 0.27654480910108936, 0.11854059964178071, 0.0517278807538171, 0.08628026942812628, 0.04117653645094364, 0.04120568226602289, 0.0865672383036825, 0.021179812592304042, 0.01614135956662076, 0.04152489195187246, 0.03805317683145404, 0.0640633748844266, 0.03282071203894673, 0.04922052477336219, 0.03979542548017156, 0.051041814543667345, 0.023585196524377794, 0.061994757458207116, 0.013002622647271042, 0.03423211795668449, 0.007666543026589939, 0.043614894722498236, 0.009242290604649293, 0.03971759860794391, 0.11283568076549039, 0.041263950913543665, 0.06639242007006561, 0.04896201606419298, 0.010760523652988336, 0.060882183287533066, 0.024470602642864953, 0.07975981165204318, 0.06366251937804684, 0.02938340384242756, 0.06669371478980587, 0.06525663343528587, 0.0444378761664754, 0.01538920486646314, 0.0018942852611578403, 0.05993230703977808, 0.05413321680539558, 0.04838169297023166, 0.08940820642296346, 0.08323718433178241, 0.06905036978423595, 0.07589857529608474, 0.06285796617908825, 0.06704302790064005, 0.040291306532679066, 0.026078862513625817, 0.028921328334798737, 0.04948326994875266, 0.01086573146523968, 0.05635775227640426, 0.2111081986297523, 0.23799365596665492, 0.09620679241995658, 0.10946820339848919, 0.19461722143234747, 0.14450252266420474, 0.2337552592038147, 0.1669854718831278, 0.1407196111376247, 0.10974389545980001, 0.17966081027782735, 0.15116558770739263, 0.10017555687696704, 0.145478579966772, 0.1519875847283871, 0.10443339695132549, 0.06433936572002788, 0.1295693546173073, 0.1783407028884657, 0.2513363795174707, 0.1754993287425849, 0.1651334696479382, 0.13535855848702694, 0.16570256572336922, 0.18544590791627286, 0.1220161949975356, 0.1576825291399033, 0.21039437322366625, 0.10322317721382265, 0.08203392067263204, 0.14459339601378288, 0.27375606519560663, 0.13898996846570125, 0.14251340601232745, 0.21745627896199304, 0.23957502998171315, 0.0977674360957838, 0.13200744475808837, 0.25484276394690236, 0.1276399775017654, 0.1861978845009881, 0.13351657668188696, 0.1043154577153825, 0.09280339319018588, 0.18587018273049788, 0.14296123036934485, 0.1750004982515689, 0.43784164913719703, 2.1830539549550703, 10.081021843417998, 53.24030330104213, 84.09683242920907, 105.88470443602532, 93.99757723654471, 83.83103693685224, 53.79207488029234, 52.21945155051447, 58.765028369042184, 57.48015403747559, 68.29634866406842, 62.34572872038811, 127.1509482783656, 110.67613063320037, 66.57146284657141, 51.29638448838265, 21.025274991989136, 1.937933153202457, 0.6157573877323059, 0.5786056167656376, 0.5321092891596979, 0.3610496084776617, 0.34185631741439143, 0.30407767202104297, 0.19435690475567696, 0.3823146157928052, 0.3578697307215583, 0.27819873164257697, 0.40758240186879713, 0.41005919477151287, 0.45673025171122245, 0.8143831489066925, 0.5823873331950558, 0.817178573098875, 0.22414076382354384, 0.49048031650243273, 0.8593276275261756, 0.4993901335664334, 0.2663013861785012, 0.35006862674509326, 0.3505481671421759, 0.32380164751122076, 0.2247754829905687, 0.7168888384776732, 0.3040869570066852, 0.6095888477659995, 1.2958791539553673, 0.5361215061237735, 0.4491506084319084, 0.5774195900847835, 0.8049670702988102, 0.5016545975400556, 0.2968236161095481, 0.3628741234781281, 0.28124641326646654, 0.6528163701295853, 10.237091971981911, 56.31400592865483, 118.28972570357786, 119.89188840312343, 120.82263546605265, 57.79188440692041, 38.45725490200905, 38.632796656700876, 52.718098548150834, 90.18089925089191, 88.81196068179223, 105.99115756250198, 109.0769018665437, 107.71032456428775, 89.43212662973713, 43.65259893478886, 7.241787227892107, 0.42924991177935756, 0.20973713107166753, 0.1583835455558954, 0.11598310703712127, 0.10694126238025005, 0.11889399600125129, 0.2189356253872956, 0.1295242933256011, 0.15615407647865434, 0.13329222017238218, 0.14770929010645037, 0.1090583923242746, 0.1301061524258506, 0.10077830719491167, 0.19550113367938227, 0.16757961903368274, 0.10286806481740168, 0.09447446077941887, 0.14193186866900614, 0.09253806629849058, 0.10894979936100783, 0.12261993356890256, 0.14789917265936253, 0.11334574210547632, 0.17638550860987556, 0.11006787404297821, 0.09658068929228092, 0.14540269129699276, 0.09916360835514723, 0.17019337313550134, 0.1520626613449666, 0.20623492948230238, 0.17055086040448758, 0.1283338539783032, 0.14180641411052597, 0.1883509286469029, 0.15240340193192806, 0.13041733734069333, 0.15381340207832475, 0.14545527557211538, 0.1711805080694537, 0.2474522677760932, 0.3325614032726134, 0.11236161023618714, 0.1357799068453812, 0.2323294929679363, 0.13157451315031898, 0.14383204251287446, 0.1987161135841762, 0.12319342698901893, 0.08455004452938035, 0.1691408449363324, 0.11245650554736776, 0.09799132529165476], [0.05752310224418199, 0.03252016808537226, 0.013273333221854222, 0.005275021934310996, 0.028617482542270617, 0.09198701925455563, 0.05774063291028143, 0.06688876077532768, 0.0028790575320712265, 0.03165750711735699, 0.011189374884951019, 0.026575946324174444, 0.05220193213092224, 0.013345100338600818, 0.02284796138654553, 0.008255803014992947, 0.02405974011297428, 0.043686282625722314, 0.03060051645602911, 0.033871845958093484, 0.13287156129315977, 0.013026962218235337, 0.03012074814778903, 0.08017463294128258, 0.05197987005475068, 0.056299276785143924, 0.03339009156690971, 0.04668405362134499, 0.05257728840074232, 0.02093595148424708, 0.018143126245347724, 0.04283687114835747, 0.01594057845537581, 0.07889647652665455, 0.01807079030831735, 0.012512825290492226, 0.03701472932833337, 0.029858958667084098, 0.03242572859650658, 0.08186407131893982, 0.09492371772085467, 0.08066178825233253, 0.04970694080956521, 0.06956004041938052, 0.2911216849761625, 0.6540246440037605, 3.0722753751662473, 6.412386855771465, 10.047749357838786, 29.308712828543882, 45.64462953998197, 53.94505516175301, 52.38099828843148, 49.96348073405605, 23.721425956295384, 24.165053867524673, 23.310018354846587, 39.14722334954047, 27.764732606949348, 35.59306959952078, 53.31464790528821, 35.50725990726102, 14.354226454611748, 2.880565610624129, 0.09656150645065693, 0.3770504272993534, 0.13431821108585404, 0.028825168978543054, 0.1792396764240919, 0.09669610809895302, 0.08754532573924911, 0.09949216814411264, 0.12525051862241762, 0.06773750192575878, 0.25598152300282834, 0.2981074568965743, 0.13433174019859684, 0.29699877445255557, 0.15795101231384664, 0.20449229395918309, 0.21642550765987367, 0.7999483363762979, 0.7532835307140505, 0.8442162674280905, 1.3534619995663244, 1.4521471170648452, 2.507274131621084, 1.3292333964378604, 0.1306229706613287, 0.28794576023374835, 0.17435079440474513, 0.3525559916611641, 0.256682462810028, 0.2260867956905596, 0.376960366002975, 0.47407411459472876, 0.18032038133711586, 0.01845296284544372, 0.04607117562104137, 0.06374745937665144, 0.06841915163902507, 0.0938147365025455, 0.022895799746977228, 0.029310815096382174, 0.04810066510652823, 0.27727682143449783, 0.18864663858567515, 1.1365760117769241, 20.35164713859558, 73.64715976099815, 104.39728675350067, 65.9394121170044, 36.83027536638322, 21.28479665325534, 19.711169196713357, 30.666651110495295, 41.202207995999245, 53.39942601419265, 61.91344430369716, 70.6586431687878, 64.87258626568702, 51.352482226587114, 14.083718234492888, 0.5951114407470149, 0.09580506357334315, 0.10586811875503872, 0.011191161785034404, 0.01003185146292972, 0.06104735184400793, 0.09858366447470843, 0.021766823633844336, 0.030198689933205326, 0.030483186259985934, 0.012714119680646448, 0.07204388133099965, 0.019781537421588457, 0.023407353043195703, 0.06666594410255071, 0.014261658464918935, 0.012752208614631767, 0.04522596613594121, 0.09324174103957993, 0.027869535580037103, 0.03389468303911629, 0.03539511220409505, 0.004441737086557213, 0.07600648644109888, 0.051540399886547565, 0.05131709674793867, 0.10206216330369634, 0.014322835373722259, 0.04182035674250895, 0.0699996829573666, 0.02876433010603632, 0.01870152581813595, 0.019364917740946817, 0.009499864686550874, 0.03648160491138697, 0.03329015539718732, 0.028969831276504748, 0.034643330971800515, 0.038062343073468057, 0.08166379295289516, 0.08585061667667282, 0.011872648704616774, 0.017151191770549745, 0.04199782484060815, 0.03804162422555589, 0.05553281347778055, 0.06730909023674266, 0.03588614775048148, 0.025157231927639054, 0.058997273745556036, 0.03255562263450796, 0.06225092193832802, 0.05130249128166226, 0.0225119169185599, 0.0019198806178117654, 0.011305026390830116, 0.03549009561538696, 0.039113212692280935, 0.025393278938868356, 0.057346135933673194, 0.02331870900947721, 0.009195734483880863, 0.034287839361857024, 0.007819141995447178, 0.02049659239879299, 0.11673306881059563, 0.015735303280845044, 0.02959748902808755, 0.03751933229185882, 0.023461877435986555, 0.035372045296694965, 0.036104103595378904, 0.02510135730488166, 0.11509324228691478, 0.04694391447570055, 0.016201704312416337, 0.019357011713568243, 0.05818046313980895, 0.037951114767741774, 0.023366846144199375, 0.02133000412985923, 0.034178794406714945, 0.02263383789648933, 0.058408002744639115, 0.010435205373552539, 0.02375444258382965, 0.05094283981428993, 0.02382587645232918, 0.017477512667556445, 0.014184336253111402, 0.05169458657262787, 0.023221952104640585, 0.09874450463441112, 0.03828935024719085, 0.08204010300218098, 0.017092691381431876, 0.16343736630533973, 0.13823816042032935, 0.44408256909058946, 2.059508365008139, 6.193290122093694, 13.881269020418967, 47.75032258802845, 74.96474665980186, 76.07342812322801, 73.2923186209894, 69.86300606881419, 48.453281925570586, 36.9238748858052, 27.880817113384126, 38.98671603971912, 26.871616763453332, 37.61986024918095, 49.68262334023753, 43.96492942687004, 21.37405607008165, 4.397965400449691, 0.07880917314680354, 0.38915225695217814, 0.33506338514627954, 0.0631688140152443, 0.12417956600866972, 0.21935519642166554, 0.5867703980015171, 0.5323153974548464, 0.5202314942594498, 0.682952369172727, 1.314027715594538, 1.0268790851677618, 1.1539111719016106, 1.312462444747648, 1.3800225743362982, 1.5033486341276479, 1.1223555812912605, 3.0603925547292157, 2.7417889670018227, 1.9637628188056333, 6.2447457351992215, 6.189964442483841, 8.251785289856697, 6.199430592598454, 3.8087268510172447, 2.9318682512929364, 2.2418848497252313, 1.1028800327931683, 0.8882345763906356, 1.2646401721623637, 1.1194628332891772, 0.8496434794318292, 0.9784108472447243, 0.8499536531106119, 0.31519838819100016, 0.42557756206200975, 0.23481483541188702, 0.11364800209600119, 0.11500575504596196, 0.15120101161301136, 0.04283678304824618, 0.3902856687143926, 0.314327591369229, 1.6231569407447692, 22.361142096980927, 69.80222502062398, 66.58694051927137, 37.47412458542855, 30.278134461372133, 32.386553556688376, 45.101953937161355, 49.163803592804946, 59.24561677440521, 67.45001100724744, 79.59606955128332, 86.57973981672718, 86.77959242174703, 72.33016906246063, 22.559013905063754, 0.6153361619480195, 0.06019553485056085, 0.07214990789972006, 0.05379098234698177, 0.17020065097078202, 0.02803580730312294, 0.022693615737220934, 0.017726498903826843, 0.04642235415597116, 0.07347334011067307, 0.07306864650379266, 0.05327040261979546, 0.04813450704058332, 0.04171234983650427, 0.08002844038269213, 0.028751201274233962, 0.03502099316627268, 0.0026874759397844997, 0.009281740302310116, 0.03933600255198056, 0.017867616129918926, 0.0430291821999896, 0.023676866605397195, 0.12599116476673272, 0.044731333806750276, 0.03512609276860472, 0.050039694929916056, 0.04841483776427565, 0.007286232561924525, 0.031308126973829446, 0.05147552756111949, 0.013691437197849156, 0.23022190847944832, 0.0021325888801290984, 0.046924402216269125, 0.05166395837741514, 0.07173762236151003, 0.049027022455007806, 0.0419145932180747, 0.05833259671025219, 0.06240248094282805, 0.025347771400946285, 0.007657856547138504, 0.05571873152568456, 0.03553888775528439, 0.06920809962696607, 0.03749703530282263, 0.05735633639438499, 0.02872448012743506, 0.04658188047488371, 0.03182400483638048, 0.01868287157717972, 0.041998801602711605, 0.15418752877702638, 0.11656162599402091, 0.05913878550692912, 0.125655212229298, 0.14852776312299315, 0.15232918333382378, 0.17793714309171324, 0.1304737980207128, 0.1705822546876246, 0.180096622376192, 0.07569106506003488, 0.15780557818230123, 0.1994325590109633, 0.09926796485219272, 0.08350001377684456, 0.22163421606584904, 0.16157793301728465, 0.1156446953574496, 0.08266182931801004, 0.12637268421390366, 0.276395084877168, 0.06918148573247657, 0.10786082835928087, 0.17120696874635835, 0.22269809768805582, 0.15306983713901814, 0.15152829969602247, 0.13816380392639868, 0.11341553271537828, 0.15634573635555085, 0.13482980460168856, 0.17060350596664414, 0.13168335892260075, 0.22473868012668627, 0.0737277732320851, 0.06723549983073628, 0.1850275319790648, 0.12927084079673215, 0.19038507594696938, 0.2520684531379131, 0.16395030813592096, 0.19474266066906915, 0.1647174072962615, 0.35346181402283333, 0.2788798144507793, 1.0644051360507165, 3.9408969975286916, 9.400320976011216, 27.738007537780273, 76.64714536359234, 100.941513892143, 94.07230623306768, 85.05599314166655, 78.98487798629269, 38.130490087693744, 33.731810815872684, 36.438924804810554, 58.81924729193411, 46.831562288345836, 56.58343745816139, 81.61310134395477, 56.67274590461486, 26.127700036571873, 6.298694014549256, 0.5326398510125376, 0.971531929267991, 0.7658514789035245, 0.21173085957284898, 0.4288595440166612, 0.2523021252765771, 0.2786928277102209, 0.2522771048449701, 0.5109202164796092, 0.39375825334460507, 0.7736031242435979, 0.4629173616488134, 0.7989694598701693, 0.6676975974152166, 0.5251250187716177, 0.5151746398018253, 0.46356862831500273, 1.9261920283879004, 2.6886859584239224, 2.1355248795401667, 4.803757148404276, 5.25264544833091, 10.424106659427768, 5.487721918090697, 2.142104165207955, 1.3445258597212455, 1.444178209189446, 0.8298540800329178, 0.5206016679444622, 0.6471307107037114, 0.6001321971416473, 0.5800844728946686, 0.42855810374021536, 0.31031071659057374, 0.11526162841267164, 0.3826444013224494, 0.22324159110505737, 0.22290305685131784, 0.5045178358352954, 0.3864974252158596, 0.16423408242483295, 0.42860569312207164, 0.43780876864348695, 2.2697981519083825, 31.957699252713113, 114.98697234738259, 149.51969977348082, 93.09791103486093, 55.267486187719534, 33.18584826684768, 31.405925712277813, 44.859578917103434, 60.92831750069896, 78.26615856539819, 92.86283554569368, 103.87058304202174, 106.27756118774415, 83.27395839075889, 26.699916970345285, 0.7114806867414906, 0.18993973371482667, 0.18781719519005668, 0.20467474545922973, 0.20044178792065193, 0.1673140316720932, 0.1693344047112811, 0.16498065042880275, 0.1208968639313694, 0.17286429271822976, 0.15211424970578763, 0.1579069622582005, 0.08693081597166677, 0.12588480111932562, 0.22359042158049924, 0.12080247423821881, 0.13993466212864847, 0.08887113282276739, 0.1883414598001588, 0.1537107462964712, 0.25831957738245687, 0.06743116634747676, 0.14693377930070126, 0.2474472728828269, 0.14738287536367295, 0.11163132160060829, 0.11902470592289202, 0.13933469270986898, 0.06769650090005129, 0.1815231546999947, 0.18923629646099385, 0.18132109134908647, 0.2996785500116887, 0.11186815002152037, 0.1297049675016634, 0.23614611236318467, 0.12660796513720868, 0.11604221838135874, 0.12215971390927031, 0.21186800463305366, 0.180108864461222, 0.10450976825649701, 0.11859676920838895, 0.13470235821460524, 0.09478918502047178, 0.13116202076836941, 0.2008607614064409, 0.1422161026106727, 0.1799962495363528, 0.19363020907246298, 0.09552060746617856, 0.11578817596478809, 0.12690697691493458], [0.0031230977131804873, 0.01343109179288149, 0.03906627831559989, 0.03053174091262683, 0.07670918825052439, 0.020430467519608718, 0.09962315385740611, 0.03183936681448212, 0.04236614459284371, 0.00843796531684817, 0.042607305240967584, 0.009622408110918778, 0.011088636238127949, 0.0871617301938034, 0.08032457933070199, 0.10085669331132405, 0.037556288373326106, 0.07546640211536039, 0.007702427063768189, 0.03734976639069858, 0.060132167887903994, 0.08674341554362928, 0.09103308657124158, 0.034404422622174025, 0.040830440909391454, 0.03443084116424284, 0.03391406506360058, 0.07991256192326546, 0.04823774121881974, 0.017730003756080425, 0.04314921285596587, 0.04013701642472898, 0.05084546620867426, 0.06582725402568618, 0.019972151588468302, 0.026961418785034653, 0.11935060738676018, 0.15017851406047422, 0.014399617493543175, 0.05074721926282491, 0.12674982929902692, 0.05086228949949146, 0.09069062994732972, 2.701363058820848, 4.117725289637043, 8.922502744582392, 15.537919325213279, 26.9222447564525, 37.91040981969526, 50.61448827866585, 54.46247070066391, 40.816995943746264, 56.240347739188906, 23.542065774240804, 28.901053051794733, 49.206773158042665, 79.28946571965372, 77.28163580740653, 41.07563703290878, 21.11342633924177, 8.915773918551784, 1.8086431295641008, 0.3350269806481177, 0.2674184036591361, 0.0455357835838391, 0.20353385667887428, 0.04928001916156181, 0.08226407646772363, 0.04507099804017813, 0.23732902872706615, 0.07179173881248122, 0.18484118875236283, 0.23064060617358456, 0.8382910369865356, 1.8430233169947903, 1.277777538184197, 0.5476514971063984, 2.591355774671801, 1.5730634932556462, 2.3344557275695186, 4.16727315995001, 4.073730514895532, 3.1135894550431162, 1.7172232222172523, 5.745926153275275, 7.337483744467459, 6.699374914169312, 8.557014330740898, 5.767689914472642, 2.773555262434867, 2.4805711257842282, 4.4301827684525525, 4.205070099522991, 2.3103493307867358, 0.7175173982977868, 1.1245974609928748, 0.6703063413020104, 0.4631138172361159, 0.15712869353592396, 0.28223800683213823, 0.21894881742135172, 0.17279721405957976, 0.023388505365038594, 0.016738674490742626, 0.03797199449411804, 0.06448471558190162, 0.17184861334821872, 0.02771331684573764, 0.19112320166201363, 0.6206620051976174, 20.462187374791792, 73.39261362629553, 87.51397778910976, 85.7010426059846, 37.10996389389038, 43.76675559628395, 42.87221593241538, 37.99029673299482, 52.928859264619895, 47.63995101374965, 64.14925021509971, 67.90225244337513, 65.74133634567261, 29.489628230371785, 3.388228176101562, 0.26944571745491797, 0.04426057660771955, 0.027724741131908474, 0.03657404491077027, 0.016546248525921858, 0.034143673105826305, 0.07127333477499985, 0.035731907438246474, 0.01480907233687298, 0.018155632630711602, 0.03235108098916469, 0.06255035123397266, 0.05705794897831737, 0.03240272680658006, 0.03309966380437536, 0.013670892634939764, 0.03853466309186432, 0.06597668713619632, 0.03776356878299867, 0.03680790091053613, 0.06001898222753118, 0.026998734927826354, 0.09218133745654937, 0.05842276142850038, 0.02693030220877019, 0.013508391979661201, 0.11847856950255171, 0.007278509438037873, 0.06284774273573872, 0.011845693901000966, 0.11701685842126609, 0.06691016527193208, 0.05038075727380572, 0.05099394553971868, 0.052274392557240305, 0.04233796404854905, 0.0821293062800842, 0.013054145890618525, 0.05534955758541342, 0.03350213958671497, 0.04396080257250898, 0.012671999208959601, 0.026097208404192523, 0.044709963784102476, 0.05803588319629912, 0.018946333044779398, 0.009779351755916592, 0.018117778311153094, 0.039398756644298, 0.03768193062334772, 0.0691385388434414, 0.04335267048689627, 0.006340825958402768, 0.01918910247754426, 0.03873248231567202, 0.01140024250132903, 0.08916180190299788, 0.05164567185866256, 0.04399922954279088, 0.04850631632331399, 0.10732304229731522, 0.035771698045033606, 0.033643279795444785, 0.025951824068362196, 0.022483247993213516, 0.05183013433951044, 0.08434814971781547, 0.022541757958430438, 0.047195095553874016, 0.060961507861652685, 0.02325561592325328, 0.04315094804511436, 0.01721957086345121, 0.0414175515423619, 0.018310014669212605, 0.12342342190564641, 0.02619503974734295, 0.0550359748153677, 0.05288269318219635, 0.10386390251017387, 0.03376047209566159, 0.01749260268444496, 0.03351983621776585, 0.06206757028497035, 0.10027478058491984, 0.1389722105476164, 0.03775816403269287, 0.0814158485962018, 0.04932049924748079, 0.03524550672380194, 0.0502542914792655, 0.049015113618224866, 0.02006268402892015, 0.07244384051450799, 1.3314298011602894, 4.129190867946995, 9.106421701369747, 18.321210645860244, 37.95783911981891, 66.2061882019043, 74.33428841252481, 79.63777219095539, 71.28447301926153, 78.40665786497055, 43.69308956207768, 23.608977487010343, 29.65222420230989, 44.92196421469412, 58.148851471562544, 46.94391073719148, 30.034186570875107, 15.597314796140118, 2.573668826972285, 0.23970523428532386, 0.1652909466816533, 0.18585512144190652, 0.047953239146379695, 0.2672511513435072, 0.25931083386944187, 0.3141953339499812, 1.050252611598661, 2.145080508724336, 0.8410701588276894, 1.9363794043179483, 2.277571063849234, 3.377550013603703, 2.904425633530463, 4.8747598932635405, 7.168862521648408, 6.321513383619248, 7.751399211345181, 7.681847253153402, 10.623872972303822, 8.195538501585684, 7.9787495924580485, 12.46494233608246, 12.182473828715663, 13.50445378211237, 15.259625200302372, 12.617108725732374, 12.128100952794476, 5.020054780667828, 5.157283313812749, 3.223687444002398, 3.585518983102614, 3.769280799934941, 2.3724811452050365, 2.3896223931543292, 2.6004872975810884, 2.086819338221704, 2.3742761198551428, 1.3483233269183867, 0.5392559701877256, 0.25399004680014425, 0.3513434583381299, 0.09033475912386373, 0.02550950788352038, 0.015308095307479945, 0.07328462967228505, 0.3157102268549704, 0.7438273703859699, 18.83518430494493, 62.05798756691718, 61.68296583237187, 53.477041875162435, 28.948447050586825, 45.98351447812973, 61.749332335687455, 56.32125839110344, 73.27740576959425, 65.55434127007761, 80.25519247977965, 86.46404558612456, 86.2128334660684, 48.73816759355607, 6.388660928895397, 0.21605616134981956, 0.008274608558314222, 0.03809306702967133, 0.06082786382326196, 0.02818107098010519, 0.025724866690354484, 0.07479085046197138, 0.06609281074375876, 0.0583050366971762, 0.03323430758750728, 0.08136477351429001, 0.08066257732289453, 0.026331870711498687, 0.03267110655865362, 0.028865513083855474, 0.024706875650031913, 0.02448380808345974, 0.02751383712635406, 0.020943242726066423, 0.04284995209966456, 0.05495484610418639, 0.04173235622264686, 0.09283761433776348, 0.045047758762995084, 0.0783113002656929, 0.01988599159484429, 0.039452371307678764, 0.032363120060894764, 0.05842287634168902, 0.040085428063907934, 0.018718031182464574, 0.05924056794854903, 0.03663373848183021, 0.05608962150290609, 0.0981359243873627, 0.037852025125175714, 0.03906933500641777, 0.022775253896871885, 0.023207155116383108, 0.027592933789316206, 0.04105357550865701, 0.033718095942130016, 0.060298091040984284, 0.03168583321835726, 0.06441542292915045, 0.04260243675220878, 0.031568776898747014, 0.05915694179073457, 0.08628164838638999, 0.01749451981947547, 0.07793027111479352, 0.10773374969440122, 0.08201623936333964, 0.09536879948310314, 0.09795201732025993, 0.1165094554063774, 0.1320290331157946, 0.206403024494648, 0.13484246037419767, 0.15025653245468296, 0.1633201701746833, 0.06726100289773557, 0.16636402135895145, 0.18890242002183394, 0.1593168704740463, 0.19101694526691593, 0.2219812692173066, 0.1421687124116767, 0.09728983390114962, 0.14127064285980118, 0.14371673095851176, 0.17551938492444255, 0.18088276648233015, 0.1852795595843946, 0.13728315521392132, 0.18514835936648233, 0.09560674639238466, 0.10149330471552188, 0.17149924661122984, 0.15067621074136228, 0.14636906524819715, 0.1942525176151145, 0.17468499260083323, 0.29348877408812124, 0.16870392967135678, 0.2657771368901576, 0.10237535536890069, 0.2294475468055856, 0.19466311009901185, 0.1507891321014012, 0.16896898077139932, 0.2630215492700377, 0.17542828174848712, 0.4263622199575748, 3.023715451840432, 7.1765140852620535, 16.187939413132206, 33.45086712991038, 60.74816303868448, 95.12720415669104, 97.91383635613226, 92.00950038048529, 68.33819250906667, 76.25598307578795, 39.66146569098196, 40.79124166119484, 70.86830169923844, 107.00786729012768, 104.58516044001426, 64.39515929068288, 36.55835705418741, 16.072433456297844, 3.3175026937838528, 0.770054298543161, 0.5392688404648536, 0.3942802350126928, 0.5103554871053465, 0.2334288291392788, 0.26666708591003574, 0.21542099785179863, 1.2240558982856813, 1.9867835770691595, 0.41221441460713265, 1.178507864955933, 1.5969433731609777, 5.0738834277276075, 4.103382897953834, 4.871162589519255, 10.530966731809801, 7.618789759374435, 7.658525820701354, 11.509443156180843, 11.75464326335538, 9.34043618940538, 8.611840240416988, 21.545028263522735, 21.851757610997847, 21.457351523060954, 23.24908237303457, 19.694854097981608, 13.900901463723953, 9.236590458500771, 15.368678858203275, 10.722161685266803, 9.267379103168365, 6.084552705287934, 4.754829502874806, 2.916694562281332, 2.241008935436126, 2.2498180885468764, 1.263001479448811, 0.9886272119418268, 0.3403003009096269, 0.13576156670047393, 0.25360251356276775, 0.2376688193650015, 0.17211921092483307, 0.24518081708060158, 0.18024979399577265, 0.3680531842814338, 0.766296974353252, 32.3198595354634, 104.12472125022643, 118.62868124438872, 118.56917104413434, 50.6144529773343, 56.85255127568399, 52.82001349233812, 56.17281629193214, 76.60359136519894, 75.61243980161606, 92.73685686049923, 101.79520991540726, 102.01657279845207, 54.59594111288748, 6.184442725873763, 0.3759270666107055, 0.11464403131075444, 0.12401102666532803, 0.09682151669215772, 0.125526134074936, 0.11101126535645417, 0.14351384023264532, 0.14407578104686353, 0.235671428963542, 0.11791744840241249, 0.147886945896091, 0.2008844948103351, 0.12850030956249084, 0.1768424340914334, 0.19708063843990528, 0.12389617476371989, 0.13630392630734753, 0.15947983269729923, 0.16383732548884808, 0.09775183854564544, 0.16750550768788786, 0.08085300379823293, 0.1612022434992175, 0.1620131475670684, 0.17759251077809643, 0.11112628579740563, 0.21768435865880983, 0.11154226387941069, 0.13524821118241356, 0.12940032497769402, 0.23624461594848867, 0.2639512429314275, 0.13167339977958512, 0.1441968689041753, 0.17269127942141027, 0.1205020835022292, 0.13307098930160846, 0.129639926636892, 0.18466282816183183, 0.11818353372115283, 0.1445509087775023, 0.08936092347627686, 0.2084798428920969, 0.1465692593445701, 0.16355436325313585, 0.127121604107801, 0.14859504096450346, 0.1361768169989509, 0.21905847524683322, 0.12574855238199234, 0.15686980178279264], [0.010950876392364021, 0.01917882732325985, 0.025343021655815746, 0.024775848461074695, 0.05982129706911022, 0.02072592464936597, 0.015356805092925507, 0.008511445597715436, 0.03927781817413146, 0.08653162287608271, 0.04432444535796681, 0.026761433447621046, 0.017159660872552666, 0.05464246992262141, 0.02439042579592957, 0.029431981477706187, 0.03491401281808654, 0.07569438988162626, 0.0450068841417951, 0.07727244673597236, 0.036702322503251415, 0.05029583259695961, 0.02770361434217663, 0.07114058705948054, 0.07963100162845466, 0.03798774143140163, 0.049583167814078836, 0.038450106137221864, 0.0437227369195992, 0.040597630619642236, 0.06722010912433748, 0.04246998398054031, 0.06300802365125668, 0.015137872485924634, 0.07398390706868903, 0.060531119665791916, 0.13494177601270138, 0.06297815005264937, 0.13204043250410788, 0.031087397890646132, 0.08198703609166608, 1.340983101437169, 7.1413975954055795, 16.8163364548837, 16.368570443122618, 22.49856821952328, 43.73733781999157, 50.80420547916044, 52.196674346923835, 58.55209073712749, 28.00847653419741, 22.55442080959197, 29.427929347561253, 31.800704425381078, 73.80603928719798, 71.43514694706087, 52.310172050229966, 25.240416757522095, 4.55544856286818, 0.6288167966469642, 0.1962060571437882, 0.1578186936075649, 0.03847018530171725, 0.1778052687164276, 0.060795301256040414, 0.10720756986448843, 0.2251502685248852, 0.2371634311613537, 0.2284811268891058, 1.1852353426717943, 3.576621576662987, 2.116607778495358, 1.0976898790367189, 3.165155629957876, 2.9837344875258784, 2.3789013297327104, 2.9555632895038975, 3.1578355066237913, 8.71408466369875, 9.764013924906331, 3.9555468049741562, 9.032440896957151, 5.037134741583179, 3.3582230248758873, 12.32679351683586, 10.524785076418231, 9.50629263154922, 9.384564815029021, 7.14048711522933, 13.330987941834236, 3.5988871560942743, 3.3619044144307417, 1.4764511032450585, 5.282314256314309, 5.433529961493708, 3.7533812272933225, 4.199559169430887, 2.4952574603019224, 1.7327352156562192, 1.7015770101739516, 0.5522128458945983, 0.8666267906946521, 0.13753213378931248, 0.17115378692265482, 0.12510476273394402, 0.11089241447588129, 0.06952767320457967, 0.07910044743649422, 0.05612884903506887, 0.12353234428672061, 0.414507438338572, 0.4208631795500556, 22.17574146486098, 78.85702440815588, 101.29225223295151, 72.94293742026053, 40.04827807026525, 20.651547639600693, 28.123502000685665, 33.209386410251746, 54.86681215224728, 63.86416842860561, 71.16735104591616, 81.77435782647903, 51.35175266573506, 6.015902892235787, 0.7894179369172742, 0.12591801869172242, 0.04841232882632364, 0.05144071269540056, 0.15703302447593984, 0.026402504018117345, 0.02722600831710283, 0.04988820870376883, 0.01049547829860521, 0.013183478769215365, 0.03723795202771022, 0.03850789981022958, 0.02809910531786661, 0.048586391663599404, 0.08686933741574326, 0.08818324715379747, 0.1462088762632301, 0.004316095315340546, 0.031996740426327434, 0.02182370757744197, 0.04503851208174902, 0.037854062919054306, 0.021033874757948424, 0.03771406418133167, 0.08553702624574785, 0.01979847754081411, 0.03959611238491151, 0.08567024127490099, 0.018381036765452836, 0.007826461007953773, 0.04201575895891555, 0.02230099184558757, 0.001359149624007724, 0.05737089972582556, 0.06989033922793404, 0.0649454944857186, 0.009186412151452274, 0.02994237989637881, 0.033180011105873895, 0.09097470301053218, 0.06127585288918307, 0.012158099768473016, 0.05468197707687655, 0.016198281814614614, 0.011576212897536256, 0.03415665829614286, 0.02624188027825327, 0.010848668771946143, 0.05720229526501029, 0.03404647570043322, 0.052632197752715125, 0.012710666539327753, 0.05051087347730514, 0.04221982946018538, 0.015029924951734082, 0.03772421484632838, 0.02316668460656318, 0.05831348281654139, 0.05064376291909045, 0.10364664763572717, 0.024519444578477455, 0.02982015056805986, 0.04293595313004429, 0.07589603954505536, 0.10050204056765764, 0.05305384105492023, 0.050621592334561774, 0.09567157275253728, 0.0069898680967819555, 0.026164168319214257, 0.1351917505023941, 0.057681697766266526, 0.04507384022637721, 0.043376216199249036, 0.050874688632545934, 0.018691436440173178, 0.042951654102052414, 0.027398150188908465, 0.02761105368394525, 0.00671238961419271, 0.00865643922870438, 0.03148849854516166, 0.007829281647929983, 0.018971786316063617, 0.10107874389617674, 0.06131357122813502, 0.02269420562492263, 0.07009623301846367, 0.12096689968940713, 0.045637033594351624, 0.11272109699465575, 0.5854557298364178, 4.968731547555616, 17.252839380694976, 20.14738186713188, 35.56792328434606, 68.08949070592081, 79.1403450504426, 77.24380062472436, 79.82951333445888, 57.522013571954545, 40.53749569000737, 43.06301178470735, 27.248354534949026, 36.43655961559665, 55.94736629916776, 52.0335586609379, 31.80567995194466, 7.065665943007316, 0.8082904822884068, 0.48797968294351335, 0.2925607351766479, 0.02416145935234043, 0.04765713467232643, 0.07648578169004572, 0.4889151988731277, 1.4009562639459487, 1.6495639302076834, 3.0936211587921267, 4.66775925890092, 4.812853124833876, 5.561354121854229, 3.660336723250728, 2.724726656752248, 1.9243467983699616, 3.1124414263233064, 2.0563989060540355, 4.393441436752196, 7.749878312310866, 10.431430705132025, 10.597626432295769, 12.572676116420377, 8.088991238224892, 11.74478340533472, 23.18046639042516, 20.573814107525735, 16.378363620850347, 11.975444266873023, 8.211341731009945, 5.367993529765837, 2.711849025180263, 0.886183605799752, 2.4729497153912825, 4.603283338008389, 4.899800794739877, 4.972145480494346, 0.8372307100122975, 1.913869657343434, 2.607018534214266, 4.201643909177473, 2.30818810482179, 2.3844644763777336, 2.437388771964658, 1.4879892454031975, 0.8734507954889729, 0.8557558191880104, 0.5836553619273248, 0.04567307803118902, 0.019283130194150636, 0.23884166933355794, 0.3899739935032783, 0.6911427071017604, 24.34139774691674, 64.93733675249162, 59.38934026225921, 57.67831610095117, 34.78860324428928, 33.757549408943426, 51.075052984299205, 51.08810663223267, 74.17289072467436, 74.72823558315154, 85.0220097264936, 100.23838981505364, 80.31073324141964, 14.599047072472112, 1.5787113385815776, 0.19126308931698724, 0.04255954731976794, 0.03675573798377187, 0.06956646789706523, 0.03789901312801146, 0.04188786824083617, 0.07637293693879921, 0.06094848819737954, 0.013918135063572517, 0.03485502404791694, 0.009666484979642256, 0.00778296301441808, 0.04384983473667695, 0.010681271857221522, 0.0379344753380264, 0.05874729925586332, 0.04495720717034513, 0.01365020443054457, 0.04079510127344439, 0.053909936649424416, 0.033715751713081714, 0.059381505143978906, 0.040511936024432225, 0.06273565258109762, 0.05185048163477933, 0.03084692097599468, 0.0044985736284645335, 0.019562631627664934, 0.02986729178848046, 0.06895991778301616, 0.044405819217283884, 0.02605153615736673, 0.016443665522421082, 0.07561406556276545, 0.02321996602169689, 0.028733062227406812, 0.02123068849135551, 0.012593699277438706, 0.03733769284501191, 0.022313385232982617, 0.02902196355975203, 0.03658974205233878, 0.057211369576473395, 0.06868148312693642, 0.021404013969004158, 0.027176429021863208, 0.05092185666604389, 0.018915350533901684, 0.023077506226517504, 0.15032370304388387, 0.11958309975002082, 0.12714961994319193, 0.08456796332592927, 0.15447278927651145, 0.07255526800309459, 0.06848900353596096, 0.15649817253072418, 0.1257766065217795, 0.3648232350185994, 0.124720937362121, 0.10805277168870935, 0.17397798537727327, 0.15110108310416823, 0.26675248939183455, 0.10025033471925605, 0.1968342185981812, 0.2079496027961854, 0.16711754544127375, 0.27138986474564003, 0.19360331938632075, 0.16341257570011003, 0.12916406346184592, 0.19895197673430368, 0.23965284919306157, 0.16293876564070103, 0.1905411587006623, 0.20557013370337027, 0.3007992753578771, 0.1881557754090717, 0.12205037017983776, 0.2036844082777539, 0.13522046347779615, 0.04117022771688719, 0.19075069906971148, 0.12579150693190674, 0.19896970400887154, 0.16936883270259828, 0.2120548075125102, 0.15183920881921245, 0.23343353291913388, 2.201040473676497, 9.494781455686017, 28.590715123761086, 39.04123698511432, 63.843885852444565, 95.99268297995292, 102.60879578128939, 90.93296666299143, 81.38451345505254, 44.943478415089274, 33.84390823302731, 40.260772474350475, 47.126069530364006, 101.87829356039725, 98.69836530377789, 74.42678574592837, 38.910810332144464, 8.129501477364572, 1.83745943490536, 0.7557354410809856, 0.5143239757707042, 0.12128641197998678, 0.6691682410816993, 0.19496723168319274, 0.32264378222246326, 1.1646264743420387, 1.5826535657528908, 2.6180987396547875, 6.914858164325838, 9.960197152629977, 7.900353179823968, 6.458068249687073, 9.59969211009241, 11.767983244311425, 14.835342418762947, 12.961596769671287, 15.523211417659638, 21.29930942289291, 19.682471175347608, 15.84708054219523, 20.373992881467267, 16.903824921577208, 16.41467300153548, 30.143406929508334, 30.14485036173175, 33.99637076162523, 27.074681789644305, 23.995840857105872, 27.69086653186429, 19.459941387176514, 16.277705796303287, 18.060157299041748, 19.94271259154043, 18.397410531197828, 14.646447935412008, 18.9067106862222, 14.548621081536817, 9.798070884520008, 8.416781752340256, 3.587666971068229, 3.082209513072045, 1.1845179166524642, 0.7499537448729239, 0.3405187278985978, 0.29353406520620473, 0.30952198310725154, 0.1586047917484276, 0.15048974494059242, 0.37744603510345187, 0.5801025525696817, 1.2403554301108084, 35.97327670743389, 112.01507875996252, 141.43039180386452, 97.43735467233967, 54.625119624599336, 33.139274043421594, 42.10136036719046, 49.01486335262176, 80.26352359402566, 87.32903019074472, 96.75703525543214, 120.35882303791662, 91.04405603101178, 17.010636944924634, 1.366604145976805, 0.24703525547539038, 0.14288080645905388, 0.15537554728648356, 0.24177869721766443, 0.08687731239103502, 0.09363189429765748, 0.16179320372400746, 0.1354597587018244, 0.12255098565571731, 0.12919132087019183, 0.11786045146084602, 0.14194101575882206, 0.1824176083168676, 0.29490514808604795, 0.21221450620120574, 0.19640306431439616, 0.11382715941797342, 0.12011261206240424, 0.16072414334743254, 0.1601515079457914, 0.1107677796314801, 0.11506623002670466, 0.07203816631508451, 0.14732324307964695, 0.09980607267108657, 0.12825363691175176, 0.24809034240822642, 0.11266586205531513, 0.10298385134627742, 0.19701694588988058, 0.10298626452323892, 0.1280881619201072, 0.16167291259813696, 0.22630145352694298, 0.18314552974076043, 0.18542686297047525, 0.2125901803975144, 0.1351446054515339, 0.17888451806239544, 0.17724141268239868, 0.14493908552873522, 0.16695760160444245, 0.14998340678791847, 0.15618197740085665, 0.09389650106670396, 0.16005557841591297, 0.10691599680050727, 0.15139611888556712, 0.05244250289134441], [0.02174872863707283, 0.07978172942755685, 0.06202949188469399, 0.108649117511607, 0.02846781194450394, 0.03893455332745949, 0.050634274920148235, 0.03158696574128924, 0.05697609631404762, 0.03932445377652203, 0.03551996538355466, 0.0479564069199466, 0.02661547646106732, 0.036926311290552544, 0.04379685975671296, 0.03106982766410276, 0.04655390677432861, 0.028948438271219214, 0.05561959974828267, 0.05546745851696019, 0.023556441414139928, 0.027354339535738674, 0.039127052070633064, 0.017419337865806395, 0.0353611515264117, 0.037166625411520084, 0.0509410088641509, 0.019204632994989236, 0.029246814195967974, 0.027523275329581195, 0.0388162731823902, 0.08057724278900893, 0.04577838830770024, 0.07627660904320017, 0.058008974357958765, 0.033036584124690106, 0.05637339579181806, 0.04659330667627435, 0.06293348712666381, 0.7842811641673889, 5.529252463771451, 18.853440976911976, 27.05329114390958, 23.640123067363618, 34.09262180328369, 39.05257263491231, 50.78082815293343, 37.83106419347948, 35.586397647857666, 19.2968374683011, 18.22362207597302, 33.53098546305011, 49.50249633481426, 75.88195370089623, 37.75498197924706, 19.172127669857396, 3.8635873265804785, 0.2448363686280866, 0.06023822510014138, 0.04054368653845403, 0.061400820981831326, 0.09934680296048042, 0.07512199962812086, 0.04599475835059439, 0.13037406869472998, 0.4742440022528172, 1.1755540750680433, 1.245835961834077, 1.729262324590837, 1.4128135889768603, 3.279207858347124, 5.361189688405683, 5.3012789160974565, 3.8636606258730737, 2.1926542010999497, 7.765833533579304, 9.885656429875283, 8.131119945356923, 5.508064310396872, 8.894898083902175, 6.841699586760614, 12.10225155276637, 8.757602380168054, 12.631643068405891, 12.345129616798895, 15.217187116222998, 22.879742191683864, 16.031107364162324, 10.923233166817697, 9.796406818974404, 5.437472924109429, 21.339639233004664, 46.08936748197002, 53.80920779320502, 48.86601332695254, 36.71486746880316, 26.91218976051577, 28.843731534096506, 10.17097551976481, 12.90944689704526, 4.590356676809249, 1.746286882027503, 2.0604637072932337, 0.8692526336639159, 0.6412394945659946, 0.17592132061479554, 0.22150306181321222, 0.15351262063749377, 0.12858505420867475, 0.030213370093054352, 0.1232417441544033, 0.039744607037714416, 0.11085941140810329, 4.74926414989656, 35.16204034128497, 62.15878855797553, 84.32130967417072, 64.18154701109856, 36.60624527162121, 23.859622824576594, 24.79882259522715, 46.94606804078626, 65.73321311704575, 59.414341449737556, 69.50518392747449, 62.644464277452045, 24.414304802494666, 3.3903406175874897, 0.08914981262698289, 0.03838329943978498, 0.06389051480519195, 0.010133835960239654, 0.05412099387256369, 0.017747600795701146, 0.07788383852570288, 0.01999713754611871, 0.005928664909480441, 0.03718059119437972, 0.05547550244016513, 0.0682841056597329, 0.014597097723444384, 0.03574283568248634, 0.01891312696370146, 0.017697092618853334, 0.04255110886128199, 0.05042759971993585, 0.052374493435866414, 0.048962736186841806, 0.05279286554263485, 0.006301447602679894, 0.018561161273429473, 0.01819383935071528, 0.03617148102831937, 0.027869075927282536, 0.02963777950724527, 0.0627778870083632, 0.06731417706055988, 0.048015751921000986, 0.04684784321955616, 0.011666843014198446, 0.020440675641199755, 0.009029572885934143, 0.07400653730597227, 0.037597208959801544, 0.11904356700758781, 0.030346192502146287, 0.14592456571277113, 0.050266763390672785, 0.04895036386686468, 0.017020116041925167, 0.012147015433818584, 0.0614577298232865, 0.04521145260021572, 0.033351350500578844, 0.007796351358504787, 0.036208755036275235, 0.03892281686045951, 0.05630759650000161, 0.05032330834036393, 0.0437827292649496, 0.0762346274249496, 0.02241873381389005, 0.03831022231268787, 0.013525955502935236, 0.04197033377544534, 0.06963222888448546, 0.06738906215515829, 0.02514238322844669, 0.05460736011305163, 0.05285109971619902, 0.033853984618138884, 0.03139855024675208, 0.015775260511755703, 0.023217382390172254, 0.12461982907787447, 0.025976402084192923, 0.03577806423568437, 0.11988243328467493, 0.01897619132162823, 0.019834815006282543, 0.05940854038682677, 0.047639361432483124, 0.06355232912145796, 0.013995048375950466, 0.025625062670799035, 0.09733360050426376, 0.050416177348984834, 0.043528954979152455, 0.02661977229910272, 0.03590656399366356, 0.06422943593333326, 0.03728288308446927, 0.061268789558521206, 0.038437986626259746, 0.07304271442755576, 0.1831874041067016, 3.7232365867783948, 17.631738378155617, 29.299522715230143, 36.11565482231879, 58.91985608685402, 67.77810158268099, 71.97160951552853, 61.95331127412858, 63.782810626491425, 45.46925644720755, 22.539558949009066, 24.014297569951705, 28.255415231950824, 54.35574693064536, 42.04537637772099, 28.691253316017892, 5.904649765260759, 0.22062167765632754, 0.1027405494824052, 0.017054662776870594, 0.0650891742759174, 0.13304553986076387, 0.4496279731392861, 0.6464658689595039, 1.6315997199666117, 2.832186361474376, 3.543535648815094, 5.411600480156561, 5.261538442104094, 3.8146430109777762, 5.1035247791198, 5.366180904449956, 3.308056155520101, 1.7778966503758586, 2.3825564884370376, 7.784794761288551, 7.645224082854487, 4.081581629091694, 2.0014979810483995, 5.6082293871910345, 10.308563440076767, 17.28055680951765, 15.928729580294704, 12.621498838547739, 13.16722898714004, 12.498238355882707, 20.45447011147776, 13.487414025491285, 3.316406881616962, 1.447124154336991, 4.171391158334671, 25.167956852143814, 54.2867132156126, 61.85901357281593, 53.14924155512164, 40.45390605926514, 32.10857126020616, 31.755816821129095, 14.222408340823266, 13.931492028697846, 5.974284583522428, 5.240604752494443, 4.249147734334392, 3.541135648565908, 3.1504835140320564, 0.9421865942497408, 1.6353360227038785, 0.24176959609312398, 0.31399452698326885, 0.05778285967666776, 0.26806783171430715, 0.052688884428672256, 0.24301972901148183, 4.431994413175891, 30.543188625766387, 52.07040540633663, 53.19271318374142, 45.17787533421671, 34.08810715521536, 36.281555391127064, 49.708495293894124, 66.02336652817266, 88.62029798569219, 69.25953372832268, 85.08191216376521, 91.30637630339592, 42.036853067336544, 6.012176150275815, 0.08740192174070305, 0.03890245041299251, 0.043962112582859494, 0.06685778784054904, 0.04694722397553344, 0.05262868907002192, 0.06329953159776426, 0.026083196656057434, 0.04799863368633294, 0.026217419090830994, 0.016874247155482733, 0.08862616854809946, 0.049102202493457064, 0.033352775424118006, 0.024147575923932657, 0.00732809687296169, 0.0029798375955227044, 0.05318716716682238, 0.03040549919880446, 0.016466425994651455, 0.05984724063666598, 0.02474991063917837, 0.03472727505610355, 0.04513958206159934, 0.0461166927350625, 0.010859841206711868, 0.054808090470971606, 0.047357257215246085, 0.01551266376590056, 0.023498802873936873, 0.04307652260327051, 0.06064622054597544, 0.0237193021307429, 0.038470867119969866, 0.05862125097924183, 0.0063382365812187, 0.06387339274008429, 0.06083256377267742, 0.00890148873065388, 0.08312884417753066, 0.138577644623095, 0.0614946169568406, 0.05513916302832866, 0.023846681485132828, 0.0511557050049305, 0.04297124297027627, 0.05423524439515126, 0.03889067564159632, 0.1049147453159094, 0.15770295304396462, 0.10631922962925128, 0.30074347351347247, 0.2266315914570324, 0.10822390040923512, 0.1911522057508269, 0.15901316257734455, 0.15110977054122957, 0.2009679983940817, 0.17106367966100094, 0.1260929931736281, 0.092366186811799, 0.1860970366866358, 0.16919453237806598, 0.13707649533546742, 0.20263272277530164, 0.0982236031502966, 0.1670629540157895, 0.13892923301506427, 0.15354969929302895, 0.23315443176656003, 0.11167712599760103, 0.1022229268546066, 0.12371186933089649, 0.2557297558673928, 0.1176921419438816, 0.1604288164526224, 0.15685706940149108, 0.14503199667219194, 0.09472638113243927, 0.17166907298228434, 0.14197918225920972, 0.18908709317686098, 0.12297777323833398, 0.12544845275941396, 0.24603085291962473, 0.17845852721122005, 0.16647628388337551, 1.8592252798618811, 8.796906490479747, 27.73080998851407, 46.21823695398147, 71.42319156277564, 93.04657505404566, 98.29517702902518, 93.39597194425522, 68.44972902728666, 60.25204596980926, 31.735795082584506, 25.45364856719971, 45.48196100419568, 69.89363193511963, 104.63865372442432, 57.68983610214726, 33.45965323909637, 7.653086473864894, 0.7389691472053529, 0.3349334872778385, 0.16284826001332653, 0.17635627469468504, 0.3274657541225034, 0.3437844381457375, 0.27172853689520593, 1.3372759713280586, 3.11472277487478, 4.204066953351421, 5.8562433046679345, 5.7712725093287816, 6.111348377120111, 12.044077900148208, 15.302334908516178, 12.8298149378069, 12.303517191640793, 13.849776310305442, 16.52022692465013, 19.298575078287435, 19.189266466325332, 19.858826821850194, 27.854239133096513, 20.833171029244703, 31.619363446389478, 27.065652493507635, 29.6134437284162, 30.38184585109834, 32.5496986604506, 48.08883097863967, 37.01226157526816, 26.175345067054998, 25.114873455416774, 16.930673545406712, 28.202627974171794, 56.683591258141306, 61.77573773168749, 55.42502034095026, 43.90941219945108, 36.90582806064237, 42.90419893880045, 20.75344297193712, 27.51920792364305, 16.793808321799002, 9.133063420172661, 10.189217482843707, 4.970474060504667, 3.0101138978235187, 0.48920330921969113, 0.7808463936371188, 0.3235123114239785, 0.2684180564697712, 0.33410393662991067, 0.37883599438974935, 0.12145113620546558, 0.4724744617217972, 7.263053338373862, 52.6383214612161, 90.38121469559209, 116.52458852337254, 83.23766077718427, 50.58458805084229, 32.45710326779273, 37.8785680186364, 66.50549642501339, 90.8246700225338, 80.92530588949882, 100.19251377351823, 110.90740926804082, 46.579746123283144, 5.714576119376767, 0.18444152068226569, 0.2444120938138616, 0.16844520645756877, 0.10399111907087988, 0.11009431173724514, 0.11804553064247293, 0.26322912845400076, 0.1375577364477419, 0.16276417420275752, 0.1326148145862164, 0.1302616069874456, 0.2350591255291816, 0.10266486765636552, 0.08328087432610412, 0.11535912842279482, 0.15587191097438335, 0.09334327833306405, 0.19794201238020775, 0.15343829478708007, 0.166000405386571, 0.17190173388488833, 0.1679542360286559, 0.10625685475045636, 0.220481698070803, 0.16125398507762342, 0.1330435939974362, 0.13416969728085304, 0.08532625247514056, 0.11014017742127181, 0.19223032128666678, 0.1490797601159542, 0.15038131285578976, 0.15500428575661876, 0.10277306225391165, 0.11292420988602024, 0.09635460142406727, 0.2265040378176397, 0.15334843267356196, 0.260821528612606, 0.2180208244751538, 0.19522370259848335, 0.21549900092424887, 0.093386186917703, 0.11848043109620772, 0.17505836853336904, 0.1921610056512779, 0.1081995924393977, 0.12952970190634652], [0.04519275239398403, 0.02761126435812443, 0.06117516978373451, 0.15236359600338245, 0.04265785555265123, 0.0551228491859811, 0.038097759318207546, 0.02163753097486352, 0.05381348234931788, 0.033038150774495255, 0.04815208875844556, 0.038528197309783394, 0.025570789171803384, 0.05697903426123723, 0.04571687910825976, 0.03782721919818752, 0.015514731245686211, 0.06432845662798613, 0.0062845127503087204, 0.010362406910937882, 0.04759108640193459, 0.05752165050756547, 0.021031124502300255, 0.04666393232201377, 0.011000105202378286, 0.1457880028793889, 0.06607322187553491, 0.04058849502114519, 0.01368149241898209, 0.07748671386751436, 0.06435769820405592, 0.039754570011169686, 0.025843815247137702, 0.01165541968563752, 0.09370452709375851, 0.07012403434923581, 0.018490698421373963, 0.18616659747016046, 4.751366540308922, 15.687704836168598, 28.60797747488945, 36.92528301669706, 41.23099427069388, 42.819664016846694, 40.750904006342736, 44.8364330107166, 40.26798963546753, 22.01779350157707, 32.874033566444155, 44.29290625356859, 75.12863897508191, 72.03608543642106, 57.796010740341686, 22.801406575787453, 6.556065726664759, 0.6957584787761012, 0.1741513970398134, 0.1226330566550455, 0.013682839776118918, 0.015763102696397375, 0.10606134911217999, 0.04012361371649369, 0.36214388846870393, 0.2457529775077297, 0.7137871016898464, 2.4385679344977103, 2.279622708597491, 3.301798504206442, 4.267031781135067, 2.506501179549002, 2.7777274385575326, 4.3302324414253235, 6.576130611281242, 25.418231525728782, 55.858238281742224, 77.43962103320708, 68.96381839629143, 43.67117527992495, 22.502698475314727, 8.099939553968369, 10.16794744999178, 9.9735047740321, 7.051709169341672, 9.964823588248223, 20.851739529640447, 15.024043725382898, 4.376094754665129, 5.654897257204979, 2.199710790188082, 5.06641915728969, 61.80216666190856, 116.13898031173215, 123.27024936676027, 124.06368209469704, 116.17436009068643, 107.53759907137965, 97.41606404704433, 86.89428252558555, 73.95279084482502, 58.073118348275464, 44.29481644784251, 30.554455634086366, 21.03560063146776, 11.409817895581646, 8.412430863226614, 4.575398227860851, 2.3179476972549193, 0.3476925897261789, 0.08019555480249467, 0.08781357908681517, 0.038796236152730645, 0.04163114068609092, 0.07495078663792341, 0.11817778806172072, 0.03892741338800519, 9.537087159772074, 35.530421503128544, 83.54738681547104, 95.76746048465853, 41.72238880588163, 24.438088094034505, 21.80020001626784, 27.16775767264828, 52.30581037459835, 70.61082947638728, 64.82152092841365, 63.496042220823234, 40.064897152685354, 4.6986748903028435, 0.44559096556998073, 0.036939572272521835, 0.026495777138118303, 0.04218403017148376, 0.07619236235416706, 0.0634503934622532, 0.05724281748576511, 0.05006484942690981, 0.02353102453203211, 0.04022818471815798, 0.07769083799493891, 0.05295501571268805, 0.053925028581532745, 0.05415706895291806, 0.025402311115495624, 0.007940858523661812, 0.0632235816409511, 0.04832930787796936, 0.024634430545472333, 0.04065669982904389, 0.04485208458537537, 0.04094034388300873, 0.027178413189587095, 0.08018430863176623, 0.04266481929188294, 0.09179773425022442, 0.012649633272010232, 0.009524203299905264, 0.030280803067369327, 0.13436282804656413, 0.03376345217768704, 0.04069651341846874, 0.04216031975022728, 0.018763536805166833, 0.06567107168056312, 0.05829488220173986, 0.0979400740095204, 0.02419590075019627, 0.038601868155021826, 0.020660711414811593, 0.06019413290965942, 0.019411426938829884, 0.004221515057818784, 0.0185435374207314, 0.08339869864885846, 0.034185792619903246, 0.0252124170712646, 0.019375104795119936, 0.021397207277796922, 0.06428521862553974, 0.1029954422565718, 0.06696503248906906, 0.029373414055894942, 0.02675538326823904, 0.10454795773952238, 0.11781617157882261, 0.04510636831964216, 0.06618232811771094, 0.038780945037762006, 0.04950468976711554, 0.0468751082887813, 0.018763205472139582, 0.042123873117229635, 0.0287728815624911, 0.07342739781785397, 0.028456655789106607, 0.04577812783780598, 0.04472763743251563, 0.14260826301911186, 0.10656364998149295, 0.0544206683163441, 0.02641309326845071, 0.035980188873626535, 0.04585558315739036, 0.04768482492034955, 0.02326233451434922, 0.06036546081304551, 0.0584358117362905, 0.09649109530953631, 0.010294302652079252, 0.09789607758002897, 0.004434399879462416, 0.046585883284288074, 0.04894073031121685, 0.3425629569157478, 2.995401332455297, 15.506888474187544, 30.66632947614116, 51.24826485110868, 67.60303051240983, 72.8971633603496, 71.63528980747347, 70.63390085774084, 68.80366802215576, 41.24757412941226, 38.03265048611549, 35.399857567202666, 38.526418055257494, 41.58635316356536, 53.555893282736506, 28.598946217567693, 8.411897420883179, 0.4573841843633883, 0.1941405155605847, 0.06665032356977463, 0.012860601437428306, 0.062279565965816866, 0.32542321049878675, 0.4728666987390288, 1.2645258105570272, 2.7102707614821773, 3.0506028090753867, 7.22615413127407, 7.398795293223474, 8.076689704771965, 4.599459517386652, 2.9912796568486, 1.7016678375582543, 2.367966251988565, 7.896440125280812, 29.924613198926373, 62.25434534011349, 81.79518561209403, 75.29883846159905, 50.593625191719305, 21.915025441877305, 5.559853815263318, 5.451325264669234, 11.219491747117813, 9.443326823173031, 6.766393511526047, 9.106017697241999, 2.964587437529718, 1.4032539148484509, 1.547302836852689, 0.6272606575681318, 7.606463711107931, 70.87898623558783, 125.8649992173718, 131.9993665141444, 129.02564510222405, 121.71597096227832, 115.33030525330575, 103.90191493495819, 94.90134623742874, 80.53939957772532, 64.72496394188174, 50.4527924906823, 33.70019651228382, 24.306357252982355, 11.014352767698227, 8.030745512054812, 5.6662348681880585, 5.301902572954855, 1.883877498968955, 0.8941045872146084, 0.951012785155927, 0.04311742020710822, 0.27056880235191316, 0.15297067471809928, 0.12722704844969895, 0.15743981716373276, 9.309917207687132, 38.3428511311931, 65.95939267066218, 57.59508340589462, 38.141668842684844, 27.152072114329187, 40.99681700429609, 50.365919836105846, 82.14643386102493, 92.48828841793923, 77.694378975899, 86.65697128542008, 61.25628648265716, 8.602640321177821, 0.5040670697006487, 0.06467139588729029, 0.05512710480440048, 0.08367126507143821, 0.054235558491200216, 0.13503127040401583, 0.1252073878722806, 0.016892303847858024, 0.0064924007634662335, 0.0992858759878624, 0.09552010950902778, 0.06590517282846474, 0.050668507559044715, 0.0052031293706668, 0.018193080923670245, 0.05898505081272414, 0.0052436080201709225, 0.04403822724857638, 0.013658322089712226, 0.07582079438913254, 0.05565732957855348, 0.005188055154341724, 0.025193939030530955, 0.024469884435435938, 0.015631644881420558, 0.09432182542138523, 0.0392508365574383, 0.03665816519529589, 0.02920665586697719, 0.07549490824702286, 0.037963452613762314, 0.0452579464763403, 0.015278663167038993, 0.025013100145564928, 0.04703863741709821, 0.040547528469394294, 0.08952330347270736, 0.040603548648857304, 0.056216435867451856, 0.02774137098552479, 0.04926735189773383, 0.04703158940819483, 0.004714446671817813, 0.030981317695771015, 0.04354381325444387, 0.03138223831962434, 0.015694769568771364, 0.18659741467525884, 0.13711565775015663, 0.15384119574821767, 0.3488924979202209, 0.17102969600067985, 0.16205356636595342, 0.16102553765860297, 0.09499824275412867, 0.208255072695113, 0.11642629656219676, 0.18557986605071253, 0.1237583861896588, 0.10546009266568769, 0.17862547309167925, 0.07089518611469577, 0.13125278686563815, 0.11660251210653975, 0.1733760854169246, 0.09983906807798533, 0.2157421572314155, 0.07653708659833477, 0.3102014111655374, 0.21012840281811454, 0.10285530179258316, 0.20983037929381096, 0.20794816255088777, 0.21321290262764503, 0.17021021174807704, 0.1885007448013752, 0.23086709240751885, 0.20803266204893592, 0.26767366415550636, 0.1957901939749718, 0.22067000248259117, 0.10491461508096227, 0.12069171324612633, 0.17509393033481416, 0.7821798156346045, 5.8626416710115254, 25.048365746774984, 50.50139457948747, 80.20563725502261, 101.18210423377253, 97.31049737622662, 84.71326428074991, 79.17603861901068, 66.31587336140295, 36.20315113375264, 44.864391665304865, 57.058926782300404, 102.79476319589924, 102.50550408517162, 88.42479136682327, 36.843870301400464, 12.201136465995544, 1.7015491858605416, 0.4744128480313286, 0.30422001115737424, 0.08928753991401003, 0.3367768480412422, 0.46324206035464044, 0.5630876784843784, 0.7945545870930919, 1.7743076816681893, 2.128530803226656, 6.9552772083590115, 8.430410027503967, 9.718957658736937, 11.717400358569238, 12.91516669334904, 12.922387776836274, 13.798980635981406, 14.398545315188748, 33.30666119052518, 67.46762244932114, 88.55592404642414, 80.77247465810468, 55.13970321224582, 33.15817594528198, 27.399222620071907, 29.524376507728334, 25.164589497350878, 23.765444755554203, 25.3239240184907, 43.79160381132557, 28.325411888860888, 19.009321851115075, 19.202704506535685, 12.71751355740332, 9.682287419995955, 75.16794896894886, 132.05922188297396, 138.97596082379744, 137.38578488749843, 129.83256293881325, 122.36223636134979, 111.19544459927468, 95.71245316536196, 83.02884947869086, 66.37107679920813, 54.42123090067218, 42.37726772985151, 37.08503723144531, 22.760296214011408, 19.290820552456765, 13.322370494565657, 7.717962476515002, 0.6435893620214155, 0.4610910080373288, 0.5056962935674576, 0.1307494517776274, 0.28700570906362227, 0.20559838702601774, 0.2134510027545114, 0.3403645910082325, 16.44818377110266, 54.93957604131391, 111.39554823598554, 124.68242814463954, 56.302176060215125, 35.20137386937296, 31.66980708799055, 40.526803308917636, 80.10155324013003, 100.03653680124592, 89.53699511866417, 105.28958674400084, 70.31848738270422, 9.030404206245176, 0.5680387515214183, 0.19778730858477855, 0.1590274730997701, 0.23624418693925106, 0.2150779896445813, 0.21783221362819596, 0.22875779188208042, 0.18842232804144585, 0.17594110100500046, 0.21750576824190157, 0.198252645711745, 0.18481773114012134, 0.17619928795724146, 0.21478468522189126, 0.2035646993787058, 0.11356120433418021, 0.14014529034255013, 0.1869054739513705, 0.08270237835184222, 0.15846646691281951, 0.13443289444811884, 0.12263206840162316, 0.1979644127911137, 0.34106868709768023, 0.14645175677874397, 0.1875499377567922, 0.13444498331556398, 0.12177492326666271, 0.15069467346033744, 0.19350755839578568, 0.15799578249214158, 0.19805093476128197, 0.12097177966948479, 0.07299891718092465, 0.1523872834420012, 0.3574578205664312, 0.17040511983777248, 0.09261926395758506, 0.1451624767674554, 0.11807130184024574, 0.19891048541232464, 0.17260270433560496, 0.060794167445912484, 0.08857547651014983, 0.2055528507597985, 0.10951680401640554, 0.1837627514595947], [0.030457813427933765, 0.01230833535608385, 0.05692685984315411, 0.034609316667962464, 0.018973416168122523, 0.007383654526840415, 0.0903700298118976, 0.09421568393947617, 0.09023807116694028, 0.09481251239776613, 0.014702261485640081, 0.07342361334350801, 0.00892990580459516, 0.028196544040955847, 0.019715209529104254, 0.012629653698944998, 0.04720143876188705, 0.052838585669955904, 0.09154936088429344, 0.019592307958631747, 0.07958393318638687, 0.07386163943597386, 0.016592763469464356, 0.08141129037305232, 0.046980851404969735, 0.06124003444828334, 0.059105510477938, 0.03807755757964427, 0.05484378250736383, 0.009958675702012355, 0.04661829646436438, 0.03461365655605351, 0.027477530304402597, 0.10526681634327097, 0.0926378645723866, 0.07253829915557178, 0.09282204743114211, 5.785914226885765, 17.11509358498358, 42.38954867086103, 54.037983955875525, 56.93370511454921, 44.289132933462824, 24.643818370757568, 21.36149467960481, 23.567419975034653, 25.513696132167695, 31.48047624095794, 58.01801689209477, 97.01227172728508, 51.27409365869338, 29.480114521518832, 4.307216463550445, 0.35051350932448144, 0.23770243530311894, 0.07880859858086033, 0.07444997964006278, 0.07612832506457645, 0.1371251419186592, 0.04906653343970257, 0.17711559040171487, 0.2387767663646129, 1.364868864897759, 3.5481714000625, 2.2404703449818397, 5.1314309720070135, 3.7060298842768518, 7.437843959177695, 5.07078230381012, 4.758312567587822, 10.072196510530288, 31.02604808345918, 79.055449270433, 110.48912771286504, 110.80516876712923, 115.24067125012799, 112.92552363487982, 112.35750952074605, 85.31823496664725, 28.396449935051706, 15.88114828832688, 13.565612358431663, 9.266388704699855, 5.807447058539237, 3.3188431637902416, 3.864705202079589, 8.44996206222042, 13.257020865717243, 14.949839345870481, 61.93145974989861, 128.98074965323173, 113.89099936331473, 117.51426527577063, 113.86805349780668, 118.3108280551049, 113.45239208590601, 116.60543641736432, 114.940045110641, 114.2349127800234, 110.47766654722153, 97.33723225132113, 91.8233133131458, 63.44250971271146, 40.2139707534544, 37.294919336995775, 14.047846198081972, 9.907256922414227, 4.52113272682313, 0.559692683239137, 0.19509919798902928, 0.2798187930978114, 0.2454432788034601, 0.0770964533571274, 0.019580772589711894, 0.0287652398354464, 0.05909072498099939, 0.6969600723635766, 17.206816250278106, 47.65790762439851, 91.30540355559319, 78.50924353445731, 33.60183131310248, 27.912480446600146, 23.48707610561002, 49.462731346007324, 59.3954199360263, 64.42746785379225, 75.17034945949432, 33.0001397286692, 7.6132082266192285, 1.009505007776522, 0.17083913929039435, 0.060131428613057064, 0.07980939286250262, 0.035009750825983864, 0.0652614521283296, 0.02435563391284837, 0.02699869853864995, 0.10080004110932352, 0.034258375620289196, 0.07191548499489023, 0.01122995360469025, 0.03169108858151782, 0.07306277060941344, 0.012813274440686069, 0.05617329745643562, 0.045937351551988435, 0.04267323476773116, 0.0367439478906172, 0.052771330811083324, 0.017780012060557644, 0.04361569911481873, 0.04099209312229388, 0.023724289363129966, 0.042487312889387535, 0.05885367439458928, 0.07615879238132509, 0.007668384031632976, 0.031833153841416204, 0.04293110379348359, 0.06472313746569619, 0.039800753621684934, 0.05402702935821107, 0.012736376450066606, 0.011879103952988744, 0.04545458975518423, 0.01805560261521849, 0.038760118937540444, 0.0651262759140903, 0.059781950793319175, 0.07082674381954056, 0.046090396767061566, 0.014722814667038621, 0.04697449670563783, 0.04378870475075899, 0.04515806010233299, 0.0935425531239279, 0.033440155412761435, 0.024361090374089057, 0.022833288887575753, 0.04766564590916519, 0.035286955910945134, 0.009502115069828447, 0.10583622651475091, 0.06326365953070984, 0.07272558467042062, 0.04515602996933364, 0.04672763253291769, 0.04090719142808549, 0.016352420620199655, 0.06213382539910175, 0.04907253190814968, 0.010274315418134774, 0.038949036219668005, 0.004400627372125465, 0.0617901889997865, 0.02811991418110988, 0.08231131344913475, 0.016140444091551246, 0.0592109969546718, 0.04625859137083735, 0.017399015468395045, 0.025999426856757175, 0.006062062842125494, 0.0504433045223836, 0.01781906339249784, 0.046835681573758205, 0.03619431044846293, 0.022164262388081803, 0.03787180934582026, 0.04409476070694866, 0.05550972358774274, 0.10156152484517905, 4.897638097886117, 23.212388600072554, 58.42046776125508, 73.0679355129119, 79.87246328784575, 68.58486252446329, 52.07134677517799, 48.71769282125658, 43.62361654158562, 31.02193743951859, 29.58281001737041, 37.5160272659794, 60.12007782536169, 50.02403820714643, 35.32931766202373, 7.116806785906515, 0.5936543415150335, 0.1879420675217144, 0.09322651121164523, 0.18959724644739784, 0.2713038483935018, 0.6470504859762808, 0.730439524256414, 1.1205228538282457, 2.104240790490181, 3.946142677337893, 7.528279106463156, 5.729633117875745, 8.160382297731216, 5.35545910558393, 3.089238645568971, 2.6380680164983197, 6.390635351980887, 9.430767393881275, 34.60567566656297, 87.59691238403322, 117.669583289854, 118.95238660996961, 119.4240516231906, 117.74999187838648, 120.27709653300624, 91.23469106612667, 34.73039527093211, 14.09672873635446, 6.156165869005266, 5.758176695915961, 1.136880730909686, 0.43650022918178194, 2.4424527970052536, 5.918979164092772, 12.345488513669661, 19.02830808393417, 69.25884339117235, 135.26729706794987, 117.3379155128233, 122.31763901249056, 119.06561759210403, 121.90535868367841, 115.24229511137932, 120.76314880001931, 118.16146419894312, 119.33122481069258, 113.90839115265878, 105.44417519723217, 94.70600435810705, 69.2253698841218, 48.03427473191292, 37.497039071975216, 17.905280551602765, 13.072168384828876, 7.536391058275777, 3.4745129654484415, 2.124222569888638, 1.1022873871749448, 1.0331867467011175, 0.4723867293327086, 0.08895274416934099, 0.03139297887232275, 0.20601086408620883, 0.09647118468438426, 15.948709153359937, 47.06314294568954, 57.37556795920096, 45.221668597190614, 25.326852067824333, 24.927156663710072, 29.420282686910323, 62.4167706889491, 87.01859812582694, 82.58817118983116, 94.42770434964089, 57.19967711356379, 16.31483691353952, 1.6346449501091436, 0.27528870069692213, 0.09668244875126308, 0.03493404601730647, 0.10976225092646577, 0.024544396062171268, 0.030763842571046085, 0.052258695415671796, 0.05555989851634349, 0.03857241590477286, 0.021528292582520557, 0.019563010841187452, 0.022081863886166005, 0.018216856462400288, 0.048644825020023895, 0.045393088216622995, 0.02232873955020501, 0.03842734566499149, 0.03957355109554145, 0.021352902497915972, 0.026463174351280736, 0.019290061374645562, 0.06734496613423671, 0.07995950779126537, 0.040718136250131556, 0.048656339321525834, 0.06545725654089643, 0.09632129958199878, 0.011638717053668394, 0.03801793295649752, 0.05570340976719895, 0.04264780447908467, 0.11781797188544467, 0.045094850187700604, 0.01657359786481867, 0.05181657075281105, 0.02469492276319333, 0.03988254116848111, 0.06476185554938932, 0.06636342364213159, 0.02938553548207687, 0.06229934252558216, 0.06585982808422658, 0.03791692426368114, 0.020599558446255904, 0.0644059464215271, 0.12565178781627648, 0.1282062467127558, 0.09709964491306775, 0.10852498062435659, 0.11050920963527695, 0.16199891365343527, 0.27411827156620644, 0.22586548821099345, 0.1877160256187762, 0.21679407256024502, 0.11442068603730972, 0.16648680993145512, 0.0814890329756083, 0.12343028605344797, 0.09486986173977775, 0.2788376489714269, 0.13799742495100345, 0.1087654326411505, 0.14617654735282545, 0.23315116823200258, 0.2525084480763443, 0.2228651814643414, 0.10685531497602502, 0.11996141694966825, 0.12282634063834146, 0.1413834722892892, 0.15987404622137547, 0.08247482725569318, 0.10277031199826349, 0.1809197685290729, 0.14297793108609416, 0.08594689094611714, 0.11808892186250418, 0.2667554618129807, 0.29530090910773127, 0.2026529934617781, 0.37491184689344903, 9.502628157215735, 45.02645615608462, 91.26660346984865, 104.52197105653825, 103.52928192384782, 89.619733595079, 51.12300788202594, 39.80010578709264, 41.59710438020768, 40.264569328677275, 46.97457190482847, 81.06668379998978, 136.5779492162889, 75.05412178654825, 47.515203952789314, 7.830840935630183, 1.368848477159777, 0.4208048036502254, 0.3473843465889654, 0.39095280872237304, 0.2766972605980212, 0.6219365916425182, 0.3707122141795774, 0.7094273259562831, 2.1744124831691867, 5.368692692249052, 9.57345929837996, 11.019470480180557, 12.855609424652593, 11.211543063963614, 17.884633195015695, 14.153187332614777, 17.547840841354862, 16.25440005333193, 40.82557416731312, 91.14374699131136, 121.59582091915993, 119.86582033095823, 123.36793991827197, 122.14716496006136, 120.59402404292938, 93.3682486318773, 42.355039658085, 33.41115313191568, 33.62564794478878, 27.101679463540357, 19.522356102543494, 14.671463831778496, 12.934458871041576, 17.607605995670443, 21.732629345309352, 21.933878314110544, 72.92031318910661, 137.81738681177941, 125.08722459116291, 128.22536391596643, 124.36837180968254, 126.27843272301459, 119.37479449856667, 121.38544851733793, 121.63306774631624, 119.91404979459702, 118.80161070054578, 105.77989086028069, 99.27927617103823, 71.71375290040048, 50.856055290468284, 49.38198151126985, 21.80379486853077, 21.498479535502774, 15.565296488423503, 2.7893606981923504, 1.2383259712688386, 1.1611392421107138, 0.6995681420929971, 0.2761315199876985, 0.20084102698151143, 0.13130517195790045, 0.3666240012934131, 1.726756052624795, 28.033536557228338, 70.39789184447258, 125.48164244621032, 103.45636506234447, 47.794037403598914, 40.879353784745746, 35.065855979919434, 70.24806514863046, 88.82171953878095, 91.9256087272398, 111.92855127396123, 72.37878291837632, 16.578317226902133, 1.391196794086887, 0.448141731922665, 0.17769633101359492, 0.11808987181153029, 0.17847292966419653, 0.1610720391956068, 0.14960353442978475, 0.1606319676483831, 0.1991026049419757, 0.12550551098801438, 0.16795080395475512, 0.11001763399690391, 0.20796619626062535, 0.10038877446805278, 0.19009491248476892, 0.14017121475790778, 0.1081756981570394, 0.204473739309657, 0.14512515296378445, 0.11672654940236, 0.11136830063356508, 0.19901289604604247, 0.1389949020719336, 0.17461768411580594, 0.11032018510083999, 0.23493296616981107, 0.16278950106953421, 0.20672459756174397, 0.06738297941703951, 0.1321270923701025, 0.19504347275341713, 0.18160665828374126, 0.16588201415875267, 0.14314582691557948, 0.17766849137842658, 0.11544303037226201, 0.13842957514909007, 0.08534434747191207, 0.19805565386289553, 0.16387870955851772, 0.17985380314771207, 0.12369438720446442, 0.1605483108470517, 0.1940852499777271, 0.10270675734406519, 0.17108794932644214], [0.021850999459744464, 0.06447880904400541, 0.06978894749115552, 0.04605849303545491, 0.06103055153582847, 0.0917484441531762, 0.17315408845822658, 0.3118898995941685, 0.06925096224632955, 0.0398042201695423, 0.03891700991399346, 0.12699830225638806, 0.0842233233514332, 0.10906950059917667, 0.024908592346154397, 0.026208256679256598, 0.008103090090556972, 0.05972623321858626, 0.01924550187052979, 0.13577860449590992, 0.05629777908325196, 0.05907428856458395, 0.10445484741320533, 0.022393707636623614, 0.08061478109729868, 0.11434649042184315, 0.05233651845745983, 0.030075252101185824, 0.029425079025508418, 0.08698507797934356, 0.11045936795492327, 0.07434990557451403, 0.029543975871356747, 0.05056993119538792, 0.1028662798325381, 0.11713632983305763, 6.8496816100612765, 34.58067055671446, 35.06919783930625, 45.363705465870524, 71.89659810835316, 39.670161585653986, 34.48077955553609, 11.88986207208326, 45.83353873222105, 31.02431243465793, 52.15740749912878, 74.64187283669749, 49.549486329478604, 22.64804582442007, 6.729374672135999, 0.5116013912183623, 0.06522300217540995, 0.04722081695593173, 0.07256502030237068, 0.14681390186230983, 0.0963747418755966, 0.12101749979680586, 0.10552245222272412, 0.46538459377423413, 0.8602469330353122, 1.8796334944425093, 3.4967866347682093, 3.9182639410418854, 5.070193457988001, 6.964264339016331, 5.0878573617627545, 7.665124718220004, 14.654068120064276, 34.68913978145969, 59.544579828939135, 102.38661704524871, 107.23144238994969, 102.26535304900139, 101.80554928318148, 106.85665991998489, 101.03442699678483, 108.32973741715955, 111.9218832446683, 100.04194182734336, 69.79457639878797, 32.39159968591506, 7.5510195378334295, 6.185366934345615, 19.70895109638091, 68.33543900520571, 94.90239743263491, 134.03656713424192, 73.08940656723516, 79.1383211074337, 122.97085485150738, 100.32501143793907, 104.016338317625, 111.4137323441044, 123.7514457395, 124.35837761048349, 121.15492297757058, 120.97894191741945, 123.23718378620764, 122.66440006994434, 123.64880515683083, 119.0652959577499, 113.53393816178846, 86.04017857582339, 70.45228727402227, 59.36648461126513, 38.6092310567056, 22.7204704284668, 5.535005109925424, 4.1412340152648195, 1.5090391352292032, 3.0227096090393686, 0.861008485719081, 0.23944075009034527, 0.12424723455502142, 0.46922750530704377, 0.046227204748579574, 0.14403666459744977, 1.86449657765127, 38.15726418648997, 66.01082278836158, 91.74598770756876, 72.96214134462419, 113.06301055415985, 134.6553445631458, 21.45093256427396, 57.00682593930153, 59.04950611052975, 61.09198624087919, 60.429035079094675, 31.15564907750776, 3.5083826318863904, 0.5627237560768281, 0.19271802818102224, 0.0751956896255574, 0.07100187151903106, 0.06486242757208886, 0.05291797536154909, 0.045390897205159556, 0.034581599606861996, 0.05657782635441231, 0.03100817673839629, 0.011155233218995555, 0.09013510128903775, 0.05384806355821991, 0.03562385839740596, 0.0980394739176958, 0.027710809823005434, 0.0362168564160745, 0.036020278254704136, 0.07532769423579017, 0.11720217509014953, 0.24874062848187264, 0.11006601244932222, 0.10172841709948356, 0.03337958084058858, 0.07371901684711057, 0.05734439308364546, 0.0340406189582521, 0.02473989020912878, 0.039269850859718944, 0.09057534137560476, 0.03759771457783157, 0.04787520926085211, 0.04708659835159779, 0.2366614137445727, 0.10954323404979323, 0.08481916355630083, 0.035319196721238476, 0.24993247743095123, 0.1234436619486059, 0.0777059605705642, 0.03534864514104782, 0.07932871099441283, 0.03942201507367915, 0.019440067135879112, 0.028051862590796048, 0.04031433130524332, 0.041215924861570524, 0.052047707140445716, 0.05235142269802671, 0.03515966657188631, 0.03614543020845421, 0.23242307826876643, 0.024919514844734824, 0.026579225180490364, 0.002979234061879857, 0.04523032134579075, 0.024821756279937206, 0.051573494884876475, 0.07392076610196983, 0.06556869935124152, 0.016571481546927846, 0.045867392402743144, 0.09084527245572499, 0.06916939686503142, 0.06670788741640507, 0.04504140406366318, 0.14378509664487454, 0.00959655743152384, 0.03593929510022845, 0.0972847470773324, 0.05083847948680482, 0.07584941543398366, 0.08886812209722497, 0.03212829879034431, 0.045016326175461856, 0.01801779426093544, 0.06087190621802884, 0.1352199731815246, 0.10646517703970594, 0.1388443657948125, 5.942340800839086, 37.21263585552093, 53.277432457093276, 68.24167082386633, 92.0087629748929, 66.95980102785173, 65.41462252216955, 25.521423201407156, 43.11322596765334, 33.59492401922903, 40.84737862310102, 52.094916297543435, 48.80490672203803, 30.224009675364343, 10.183187819296315, 0.5689169947178133, 0.13705210309595833, 0.18356586686305462, 0.10691546819983952, 0.32543908384057785, 0.3048417681167203, 0.9650646150112153, 1.3804915427200257, 2.949995485044295, 3.6059783110695505, 4.521929948560653, 3.410369465428014, 4.597546381335105, 6.826130228657877, 4.358759349392307, 2.6188297713956525, 6.739892998049337, 16.727224126938854, 37.85548487017232, 63.58598216887444, 109.0169680503107, 113.77156319156771, 108.78638759736093, 106.63193948807256, 111.87909803082867, 107.94679641723634, 115.90138666091428, 120.69489171428066, 108.4581950403029, 75.54026034570511, 31.27418898767041, 4.865205980116322, 6.625027368145605, 22.016781530072613, 76.87814943252071, 99.69828728706607, 145.68989753723145, 80.74624184639224, 83.2744526094006, 130.46533538449196, 108.1481630571427, 111.94202069313296, 119.0724503609442, 128.24179864698843, 129.85553233854233, 126.75598129149407, 126.31419689424577, 125.02423917093586, 122.92555932075747, 126.8328832810925, 122.11755106526037, 119.40846412412583, 97.0796266678841, 78.75319142495432, 61.41217324041552, 37.18291605672529, 19.315496183210804, 4.899013378927785, 4.726090296622246, 2.5648714409720514, 3.335230581222042, 7.953668976983717, 0.44209616438996413, 0.27269438990662176, 0.20609878033639925, 0.045283890043896054, 0.061983158887033506, 1.9414659829870349, 33.967623710632324, 57.158143135809134, 61.19968275870047, 49.87263079612486, 98.69098340311359, 150.00383007910946, 47.45165371125745, 77.48841531815069, 74.28917331080284, 82.73996691549979, 82.00147874893682, 49.797791973237075, 7.626539872538659, 0.7138256512341962, 0.13862016250289258, 0.07181908815137802, 0.05770057800316042, 0.06246084152089973, 0.026524618433247653, 0.06435462619147955, 0.041729950706564614, 0.03548773606458018, 0.05281179940568344, 0.010086284882779564, 0.08110301659232186, 0.04523044775029825, 0.005406851780736038, 0.06887145761039949, 0.030989941930578604, 0.017033696865602847, 0.020355373666050936, 0.016861055121426622, 0.05859777421480226, 0.11984262735612931, 0.06786984361467824, 0.07249896054065998, 0.01967032060718104, 0.020562248049123634, 0.01567787733004098, 0.042967791744177385, 0.012969109173413488, 0.05581554588711551, 0.03753578019959312, 0.08371080286921033, 0.06173308480591063, 0.11618756058235323, 0.08710073427327218, 0.13386925291870871, 0.019855298282157992, 0.017797084329950235, 0.15207350914997442, 0.07582712993626634, 0.03739697655903236, 0.05737711269889147, 0.0773395866816563, 0.028710726933974414, 0.0428611446442383, 0.13496852780301727, 0.25091815679784746, 0.20420887207071628, 0.1641759823166555, 0.21635108987890908, 0.2206790882853731, 0.2124251190933489, 0.36522016049392764, 0.18593441154206955, 0.17090866943040203, 0.18021516682159516, 0.15529493951509077, 0.13261573389172554, 0.22990768985642543, 0.12668030681989847, 0.1271853732666181, 0.1289097529145018, 0.16017994512954067, 0.14952497977402904, 0.2170318202866662, 0.18157886461384837, 0.17029017600561344, 0.2241058915012306, 0.10597076687601306, 0.14987525049476855, 0.32712604009336044, 0.19996359583831605, 0.23753544345738428, 0.15827526668867758, 0.11426476416208091, 0.2149197618447004, 0.16660209084230085, 0.15956460798700012, 0.2576037141824922, 0.13108858357994788, 0.25384475056442524, 12.301394208785027, 63.7615906038592, 72.80570937741187, 87.31923995479461, 116.85092972170924, 75.21853969943139, 63.15427434059882, 26.21006000426508, 61.16475012994582, 48.808103453728464, 78.39485937549223, 105.44661491147934, 73.03792153635334, 37.72794115927912, 13.539284429242535, 1.3002680410300533, 0.38054308343318205, 0.28296474848062764, 0.32059930805717746, 0.5208564994315947, 0.3486683099500595, 0.8727857085966295, 0.9503788320768265, 2.2934529858250774, 3.088145284883438, 7.019841382580419, 10.57786553136764, 13.558111806069652, 22.05131603825477, 20.7101615782707, 16.145601349492228, 17.74864265995641, 24.269063357383978, 44.17625104227374, 68.29588582438808, 113.10087711580339, 119.4053654516897, 111.92103601271107, 109.47610501320132, 117.19924403775124, 110.75267176474296, 117.13494854588663, 123.40170368071526, 112.50748526665473, 81.96013696732061, 49.56173589152675, 16.594345992611302, 13.262039538352722, 28.149448479375533, 76.57341264909314, 98.04108588926255, 143.74915584441155, 97.23929066811839, 93.17689972539102, 136.7801238644508, 117.23322745292418, 119.45303009402369, 127.28004132547687, 137.34629446460355, 137.44413406618182, 130.0294266977618, 131.23758731349824, 130.6448858014999, 126.34057875602477, 127.73872329342751, 123.19079783654983, 122.18499229800318, 94.08823105596727, 73.69138056232084, 70.82793266542497, 50.74650741392567, 35.82350492477417, 16.63011996976791, 13.612685703462171, 6.8428091272231075, 7.459101244326561, 5.645541914047734, 0.2419067105098117, 0.41903127946199914, 0.5840823486928017, 0.1693709164617523, 0.30043345305227465, 4.196017759461557, 58.857058940395234, 93.9999306586481, 120.5743965025871, 98.93923021131947, 126.34958451794041, 142.73644693436162, 32.75587020381805, 80.36590530026345, 83.85248445695447, 95.79996908864668, 97.6044084179786, 54.53160639732115, 7.8316229581832895, 0.8323936308583906, 0.31789455803171285, 0.17218538559973243, 0.1969562564045191, 0.11177191405647224, 0.2580201289346141, 0.14070603605960647, 0.1830046768150022, 0.07657734451875572, 0.18807513699416192, 0.17356881781691508, 0.1302182617326898, 0.16975204520408185, 0.15803992447833862, 0.09212889107725314, 0.13169244472538272, 0.13623073426706178, 0.16669717767546255, 0.25810498083310746, 0.21443513462380057, 0.35120522543307275, 0.15670239624957885, 0.16863511965399788, 0.15641076189856376, 0.09142902379314746, 0.14487911616602253, 0.13940071416718347, 0.055288347160263415, 0.1573862216525501, 0.22848799103690734, 0.1912906071952274, 0.09894043162104585, 0.21635069151318845, 0.33169394659419216, 0.23471119903749038, 0.10863544284215859, 0.158851349485978, 0.33418112764916114, 0.20841014421274587, 0.1405531095881616, 0.13032025867892852, 0.17023062033037986, 0.2326741559250701, 0.12649568729102612], [0.043928044652866746, 0.0266781137249763, 0.15244028140460292, 0.15019283990465826, 0.13127239871649973, 0.13011719941371871, 0.03785203661649458, 0.1297609838506868, 0.039244351623159264, 0.05468286956930834, 0.24059397288628165, 0.19128118431375873, 0.05727810349555747, 0.0350335072125158, 0.05778146922708519, 0.018894895986323396, 0.151498468232251, 0.08140374440699816, 0.30020053167977645, 0.451678698582034, 0.5971318291079614, 0.49888816211492787, 0.31479003268384165, 0.22336531430482867, 0.22471323068584168, 0.027904453867625807, 0.030032345431766687, 0.04165735238442018, 0.025878584147581173, 0.11136361983634772, 0.09833847803454246, 0.04060504252030965, 0.07799191054918113, 0.0037326990117904765, 0.3416731917569715, 7.68938212625442, 44.881383372891335, 82.44172557707756, 75.79939565350934, 36.479407587359034, 42.37265502252887, 22.33072215510953, 21.471303393763883, 48.20995376956079, 90.57104956719184, 65.3316447811742, 36.94224334532215, 31.21056814347544, 12.608750154895167, 3.111482406816175, 0.13089816476548874, 0.05310704586126151, 0.048343101291046034, 0.08122952835213754, 0.11409375801562302, 0.20535953613298558, 0.2674520502407705, 0.9281551116897214, 1.5893687860619639, 4.401799517293131, 4.717667496973469, 4.738766416426628, 4.930889010429382, 9.880750525382258, 6.1782777405554254, 11.282309486019997, 20.30485914599511, 42.844767185949514, 72.5203961710776, 88.27640810320455, 95.82654706893429, 105.0932328931747, 105.83955011060162, 98.51363735814249, 90.29495393076252, 98.38650549611738, 97.97686884480139, 102.00981847701534, 110.31906943167411, 110.11342740827992, 104.8207615267846, 86.06782344079788, 35.363328533787886, 59.287091916607274, 119.94388334212766, 146.4224550800939, 138.38962924095893, 144.9065060769358, 128.20322605871385, 64.83942262588009, 112.0281873210784, 96.03228322921261, 91.19492607731974, 95.18327836067446, 111.29788121869488, 102.36632270197715, 118.98735061768564, 115.4543855113368, 121.27573982361825, 119.08372325281944, 115.40574027645974, 106.3775267139558, 112.72939728152369, 108.86761988362959, 118.33839447267594, 88.66874710206064, 68.87981691668111, 35.513822032559304, 25.431094938708892, 8.12321440827462, 1.756334768668298, 1.7138997489406218, 7.33035336579046, 3.3838917507279307, 0.12304189479759625, 0.09333176403156213, 0.031122344906532, 0.20349002112784695, 0.11785467515789694, 0.5116646394373909, 13.39217495533728, 40.461872393085116, 47.15952342556369, 46.78663546039213, 55.29340128744803, 25.374446107495217, 23.716756374605243, 43.698412218401515, 51.463744178895034, 68.57214620036464, 68.83816134545111, 48.26804407181279, 10.967797175530466, 2.5962827619045012, 0.9466340104418417, 0.024196735786033735, 0.09354728754729995, 0.011851459670241081, 0.09937248988858155, 0.1073152894875215, 0.03914346550441077, 0.1281540454815953, 0.008402581630845465, 0.22982250087924544, 0.14550085780361008, 0.13103313413598847, 0.027295860214038726, 0.11106153604604545, 0.1514320177656989, 0.196461271674883, 0.2205953089099738, 0.7154281845977231, 0.7507608951099458, 0.1739188740330358, 0.22938979909785334, 0.059067359299308834, 0.07722741608778316, 0.04895533577749326, 0.07755822817524595, 0.05730621892237856, 0.012982283970491301, 0.03860232014689715, 0.048998106466305834, 0.07741395083646621, 0.15053206363752966, 0.1414933446193895, 0.13379316506606917, 0.011731772796220839, 0.057351460244746945, 0.22102368995547297, 0.10498512581351305, 0.022125243614878387, 0.1506065580272867, 0.11458704969094646, 0.1649663092628602, 0.11483906963539701, 0.13581755240598034, 0.019100044756346655, 0.15078870309216363, 0.14433405992965545, 0.10594164021313192, 0.04341509899184589, 0.043172417659192316, 0.10417284278739845, 0.07149045175362019, 0.02584061299961421, 0.05539559946966268, 0.15654770777590815, 0.08861509857759362, 0.06317617995063625, 0.027797299234436888, 0.0464592297982064, 0.017547918063017632, 0.07054830150258157, 0.17299094237387183, 0.40363116550349426, 0.29002290038812545, 0.23705469264138132, 0.16344447560127706, 0.08725951365645855, 0.15242817721539928, 0.01936139565171494, 0.08731021335528744, 0.05891504186776377, 0.03553275905189014, 0.0771672168986932, 0.047976608658509876, 0.045462518765200535, 0.03966291908234839, 0.08064726322528817, 0.3553060940917461, 7.579034086196654, 53.12151824274371, 106.56726744867142, 89.25249776532574, 46.737186139629735, 71.56315742000457, 39.23586107069446, 29.250024364840602, 37.64844256062662, 65.56037387540265, 51.25563106229229, 39.59452259925104, 37.97104181781892, 17.945006316707982, 3.425196760123776, 0.18937031588246747, 0.05160772369333333, 0.02716649286148529, 0.18675456995204573, 0.3726351868000723, 0.40012836636554816, 2.138356830804579, 3.1185350735341353, 4.5797025388286965, 4.6461254262155105, 3.5255361372424714, 5.843929023511949, 2.4315726324435207, 2.653530735161997, 1.105596396711565, 6.014316783797357, 20.80773641986232, 47.77478641079318, 76.32536980413622, 93.05259196988999, 98.58762894907306, 111.54549260293285, 110.61466709260019, 103.26869533907984, 93.56333947950795, 102.93017910372828, 101.95657622429633, 106.14180795608029, 113.63006760997158, 116.03568077087404, 112.13711154076361, 97.21987493576543, 42.869227086344075, 66.80170597568636, 133.2563292595648, 160.57781834756176, 149.8621540684854, 155.70373996611565, 131.75872125933248, 70.25404284077307, 115.63467333393713, 98.1407533153411, 93.758712737791, 102.1295919725972, 116.17379526938163, 105.9998260005828, 124.3341765865203, 119.47928643995716, 125.05066025641658, 124.20561698175247, 121.09734258344098, 112.85188505726477, 115.19460693482431, 113.00750901622158, 117.31621696103005, 98.10269847992929, 79.25913010874103, 39.987575469478486, 23.899544708190426, 7.833237013509197, 3.049755086821895, 2.4093752041939767, 12.615618225066894, 5.947464887172946, 0.3106939137702988, 0.04555162628211322, 0.1710683987626145, 0.09196360760758962, 0.11319517518483824, 0.2828505400928759, 13.290967998966096, 41.423739540961485, 45.51656807622602, 54.3660980655301, 60.710822074644035, 24.687997987193448, 42.05118933031636, 70.26268774463286, 65.4527558049848, 90.11294811002671, 89.16702931927097, 72.30851757910945, 21.80445186553463, 4.729167396022428, 0.9065677958630747, 0.0805326564718158, 0.06638586235743377, 0.0369685955135332, 0.015027449530128752, 0.02251439712821476, 0.02430431176758101, 0.07507356754954785, 0.03907971166735215, 0.0726235494197857, 0.10438308029645875, 0.11054370657450731, 0.0100561345349096, 0.02319969916566005, 0.1248190502425836, 0.16776105929766932, 0.21375575253079016, 0.5044124834239483, 0.40786625276650157, 0.1753930570257287, 0.1166728926041434, 0.09438747149561683, 0.07966375954809689, 0.04469351204592855, 0.009887887262589028, 0.07654327658876296, 0.04531058820805723, 0.02708176162184006, 0.02547482133752877, 0.07613709677130946, 0.1906337787307078, 0.22556489063126428, 0.10429242145149939, 0.032039218086508975, 0.0981122982357779, 0.2078051492571831, 0.06859298464992354, 0.03758336192057018, 0.09692757390439512, 0.0798090328011782, 0.17039880727327641, 0.12903087141533054, 0.23553215417890783, 0.07613253088728075, 0.28573326766490936, 0.39394251281215303, 0.27951818019632374, 0.19780914209062056, 0.1799008409462629, 0.34116947362499855, 0.16671620729950168, 0.10153625926543629, 0.3213156615534137, 0.3295000546401547, 0.17867989597782014, 0.10588527146366336, 0.15661714598536491, 0.1414391668813844, 0.18738686828122986, 0.19033027001686637, 0.3682717032009556, 0.5881648618848093, 0.6982828304171563, 0.6923525744388181, 0.3659566467808139, 0.37291103973984724, 0.3695283325449113, 0.0933158140809786, 0.2079087396663043, 0.30818457745255967, 0.11455173303763713, 0.11057258808925269, 0.272553613589656, 0.13674278743565083, 0.15426554717123508, 0.15927550172613514, 0.7423027941296179, 14.73750085599961, 73.52952003479004, 128.07509006992464, 112.98444547960835, 64.9872959813764, 70.22005158085977, 40.02994098970967, 33.10877369296166, 70.0564887446742, 112.45479999050018, 89.39942975198069, 57.32202368397867, 50.062344074249275, 23.29365618767277, 6.125487050702495, 0.740267942028661, 0.3029139538205439, 0.12042594202343496, 0.34791904531659623, 0.32583024833471547, 0.498738989474312, 2.646503563850157, 3.165821452294627, 4.252869573331648, 9.953232984389029, 9.208260159338675, 17.037771901776715, 14.417018698107812, 21.00985223247159, 17.973798474957867, 24.200580735360425, 31.03616583731867, 51.21790178360478, 82.71909990618306, 95.33465831510483, 99.27936246318203, 113.86042056545135, 115.66820175417008, 106.39368687906574, 94.62069280685918, 102.33182153394146, 104.32243224113219, 106.90970605419528, 115.4112708184027, 115.3452181047009, 115.72462112672868, 100.86017962424987, 48.414670113594305, 77.4991939913842, 138.17098063807336, 158.29455960181454, 150.62652987818566, 156.17340457054877, 127.12611967517485, 82.01657202935989, 123.21464584719752, 104.82190685887491, 96.3636842850716, 104.68813834651824, 121.81234359741212, 108.46097992312525, 125.87854708394698, 123.87343929659937, 129.2285179322766, 133.19339875252018, 126.83320491544663, 118.47426537544497, 123.26347151110251, 117.53867810772313, 124.86056650838546, 100.24915279880648, 82.00357329460883, 42.41856244302566, 32.66354937707224, 17.71484163499648, 11.03651317857927, 11.090967443681533, 21.863365865522816, 9.119770507658682, 0.34886182375973274, 0.24919974497489392, 0.15068895844442232, 0.22279652466456737, 0.2994341986073602, 0.9035562123021773, 22.678267686597763, 59.15075032941757, 68.43377282542568, 56.607179564814416, 62.473241052319935, 35.95260973899595, 31.3626011725395, 64.79162070059007, 72.49932519851193, 104.70869156622119, 109.77253421660393, 88.75397236116471, 25.857046688756636, 6.075472908635294, 1.5155480633820257, 0.23338254210689377, 0.23804610234595117, 0.1371748763467035, 0.207866987874431, 0.18792326772405257, 0.1673221215605736, 0.1296497325623228, 0.2196990320038411, 0.2640267179137276, 0.2286540022900989, 0.20075507191640718, 0.07790505150032621, 0.3037511347041976, 0.3061071921500468, 0.3422259088725813, 0.3528711908767301, 0.8377244996447718, 0.8541046239195332, 0.22149026814487674, 0.368596003541062, 0.20155085340863277, 0.2450926403605169, 0.14512374336200376, 0.19814225244185618, 0.18614687836698948, 0.11699097231030466, 0.10405393828067089, 0.09990731119028023, 0.20460910704587737, 0.20852536383655765, 0.29400919293684347, 0.24250491792636536, 0.2526660936494028, 0.2418455920152126, 0.33230074951725624, 0.2501347093212028, 0.16483363815613333, 0.22980250598442173, 0.15961999614392558, 0.29914495445066885, 0.17687358322643465], [0.01861026750937585, 0.08050234237265202, 0.10519629028896171, 0.046379889902328296, 0.1149697335917623, 0.0663712453998385, 0.03943215041691738, 0.17146561535135393, 0.082253833872176, 0.07129409575774785, 0.1163684799065513, 0.09670363108236944, 0.07473623605384942, 0.15235955105914226, 0.04204369818551406, 0.052385414019227035, 0.05338584057866566, 0.018612198050945036, 0.3262985732045866, 0.31373378129736074, 0.3530873196019281, 0.5321312912048832, 0.3163652320302302, 0.3444922727442557, 0.30538838717245287, 0.0736828881406015, 0.14570240021472977, 0.0647154995690911, 0.03191677808401085, 0.17219482380295956, 0.07168932817876339, 0.06436271607995996, 0.08527833367547683, 1.6040795128191672, 22.86294464142092, 63.596094039178666, 96.9535852247669, 93.35037046863188, 69.94204967252671, 50.334223162743356, 29.30178003926431, 35.57355973028368, 67.76818583088537, 67.27154316440706, 39.90848479732391, 37.06574701493786, 26.16459777278285, 8.90007463193709, 0.3555675139350276, 0.1530977533829789, 0.13641078025102615, 0.08417013386685042, 0.09641358253335762, 0.2704873518838037, 0.04552281754572065, 0.2626509465757878, 1.0557217439336162, 2.408965071362834, 5.488906473882738, 6.649356359435666, 10.489995614174875, 5.835586632451704, 3.1104905374588507, 6.7387981664749885, 27.22362791338275, 59.283377432054095, 78.2761449198569, 99.0709904701479, 101.44420485342704, 99.89237400793262, 99.42618462347217, 108.9120368034609, 105.8302148695915, 88.41256926136633, 83.26263058570125, 94.09958239524596, 101.82180358517556, 95.55718221972066, 90.1926898956299, 93.94151087730162, 100.80725116114463, 111.25932431990101, 71.44035585464971, 70.81786786356281, 115.28500972255584, 78.99674707843413, 92.75128333799302, 81.30931377410889, 108.44005800062611, 54.33717058550928, 111.54565734248008, 104.37998910104076, 92.8926141800419, 75.79081350757231, 86.41114065724035, 96.85440417258971, 103.68019903859785, 100.01461075198267, 102.9368471330212, 97.59851701797979, 100.76793332253733, 97.24299338556106, 105.10521181168096, 101.49391697299097, 104.31435215857722, 105.6577011846727, 102.07634187513783, 81.5783569889684, 50.690770533777055, 20.751562195439494, 6.56495479806777, 1.4843165586071632, 5.8467825478123086, 7.16591731194527, 0.3114037095539032, 0.10824054749982973, 0.20212974008773604, 0.06699980521995215, 0.05794776776324838, 0.146881869182952, 0.011210690323834219, 4.1199855554488405, 30.844862038089385, 43.38766636386995, 52.24890070576822, 74.61566355920608, 31.0102330869244, 10.395791069153818, 39.382310605818226, 46.89840732082244, 55.000188427586714, 62.747795197271536, 54.667014460409845, 30.858345185556722, 12.859907361768908, 2.5297135210806325, 0.15225367770800668, 0.07009953485741731, 0.058959926959247365, 0.010827738292244895, 0.08909870690155415, 0.07454005625819968, 0.14250225177214992, 0.13013518715818084, 0.08676734046950456, 0.0885164647573425, 0.0894782268592427, 0.08373983760154055, 0.112523591866897, 0.35166138482670634, 0.3377835182172637, 0.41225700909572266, 0.540647124571185, 0.20311215592007484, 0.21093576755975524, 0.017704131051657662, 0.11863773192970023, 0.047254501841962344, 0.08984443986968649, 0.02634845651505936, 0.09885867471776663, 0.11113278222300353, 0.05995663033137399, 0.07671835066209878, 0.05605709340964114, 0.0537981107951172, 0.08846486873564222, 0.10574125459477787, 0.024805363913577412, 0.04781913162479478, 0.09290336000342524, 0.042686380836511814, 0.1797111269326941, 0.018846276216208935, 0.09622245125712887, 0.06738988953011651, 0.06970106188448207, 0.020248238185060122, 0.17017711674974811, 0.03516538158780144, 0.010610598330986837, 0.14123863570632475, 0.0287870024781554, 0.15169645599540205, 0.044857378252932144, 0.052562966386997895, 0.026666591762595122, 0.05344777878734374, 0.04797545569618383, 0.060585741734793114, 0.039306301323156205, 0.02994260780753628, 0.05503575648030928, 0.024979099248265548, 0.12757469914973746, 0.31500588561738696, 0.20959434760434015, 0.4116500835985907, 0.22998013113054538, 0.3070671922497211, 0.21970237214719096, 0.07089810490968727, 0.1386754893727841, 0.05646626480043896, 0.08978276213090267, 0.0692476757291344, 0.07318454794585705, 0.047270470944743966, 0.18320724578394046, 1.707386775843559, 24.693393207365467, 73.22465773551696, 117.53557159054665, 103.78590691474177, 95.49068235581922, 78.21722307512837, 31.71687160768817, 26.775905047693563, 41.13966972597184, 54.92425918579102, 42.35403945369106, 44.182232656786525, 33.60849149765507, 11.822182555352489, 0.4456666244133827, 0.15676323895252522, 0.13470490162651386, 0.10896564205928196, 0.23449551464328844, 0.6784505300944852, 0.8596216827150315, 2.927543593029822, 3.74544725302727, 4.493100037497859, 6.447029719429632, 5.990442297151012, 5.334110625328557, 3.5708407384734002, 0.8786671188089156, 6.383907506542822, 30.165993898145615, 63.91895217280235, 82.81225619777557, 103.50135464822094, 106.85669914368661, 106.70935923053374, 102.87260655433901, 110.38739712007585, 109.42958570295765, 91.5401024972239, 84.67819044666906, 98.19448194196148, 102.69458586169829, 98.03975228340396, 96.44032739823865, 99.76872521062052, 103.99891514931957, 118.84092069441273, 77.03232995925411, 84.8076992650186, 127.6350550497732, 90.49536351234683, 104.87099924395162, 93.57768750959828, 117.0489937259305, 63.75309475006596, 115.07601015029417, 112.07231398551696, 95.66523567322763, 82.37554734753024, 89.68161290691745, 103.477796892966, 109.01561875497143, 105.8351178323069, 109.28543075438469, 102.94134216923868, 102.88631131572109, 100.40880110956009, 107.72052272673577, 102.7729077492991, 106.78051102545955, 110.93370483767603, 110.72534068938225, 88.94981630386846, 57.0578363633925, 26.433293857882102, 9.579457582965974, 1.4787144334085527, 1.5541255546192971, 7.485084495236797, 1.0309633756837537, 0.5813161584158099, 0.19145787483261478, 0.14829522479445706, 0.06291941792193441, 0.18936555081557846, 0.06787921286999218, 3.900498055642651, 30.060468412214714, 38.31120544864286, 43.74845381705992, 54.394315596549745, 27.86325077856741, 17.358764948383456, 61.32196657119259, 68.80022418114447, 69.97102814335977, 82.22257491080993, 80.56455766001056, 48.70324280954177, 17.35951804345654, 3.3404909699193897, 0.1632652263487539, 0.09219641406689921, 0.11945343936883634, 0.04924796604280991, 0.12275622827151131, 0.07473652716726065, 0.07340927217756549, 0.1143747054400944, 0.14441192510627932, 0.06421324466505358, 0.042941208493204854, 0.010422736334974968, 0.17845054457504905, 0.22504759742127312, 0.24656273244369417, 0.3772258920775306, 0.44913761558071263, 0.1730329239921224, 0.10485842253171629, 0.04659206178339739, 0.04537790052352413, 0.08429740405371113, 0.06817700656791849, 0.03455184092144332, 0.05557554969263654, 0.09464506089927689, 0.05032234690001896, 0.05344405176959211, 0.04152025711993056, 0.016119960815675797, 0.1777092319342398, 0.04820164698626726, 0.04441598520403908, 0.12947684183957117, 0.10992140569273504, 0.04195915655263009, 0.202572186507525, 0.05028760864309246, 0.0638702479491551, 0.07037897308867785, 0.14485728266018053, 0.16410236126713215, 0.26953721899659405, 0.31513278042116477, 0.2818178535709458, 0.31174222848588423, 0.19119026499890512, 0.4141877038824943, 0.2245813716323145, 0.1808854784335821, 0.4085753131056986, 0.25477570061001087, 0.13056425768281185, 0.23425684761135812, 0.19262116402387622, 0.18756611753375302, 0.14784643516665505, 0.2506909044759889, 0.39007288013254443, 0.4936265783204187, 0.5671948290640308, 0.7671087824048535, 0.5421349286071716, 0.4804198660196797, 0.4161856611890178, 0.17499521224489137, 0.2081351186479292, 0.15688353007839573, 0.3433363992841013, 0.33231119895654343, 0.27717949762459726, 0.13491102524342077, 0.42541395632490037, 5.291347474821153, 40.158814384091286, 95.12799647546585, 134.73142285500805, 124.98366617387342, 106.43492667905747, 82.09644717554893, 48.873140273555634, 56.241987289920935, 98.67598425957465, 95.02661105125182, 61.114218235015876, 59.37660040393953, 45.22750508400702, 15.643701726390471, 1.2248690546520296, 0.4165606152626776, 0.35411779979063623, 0.329631760476097, 0.31622335254665346, 0.8249848251861911, 1.0347680747509003, 2.599789360838552, 5.312573381008641, 6.880750704196192, 15.829468119528988, 17.94981514253924, 29.757108380717618, 16.245143259725264, 12.42133048272902, 14.740034707130926, 37.33664943325905, 74.77646504679035, 86.05265171297135, 106.88323005553215, 110.94221638094996, 108.7847480466289, 106.23518390040245, 114.84485703129923, 115.03382898146107, 95.58869454168504, 88.91573090707102, 98.85784103024392, 107.11803882352768, 101.88937817850422, 99.93541809820361, 100.81896335847917, 109.1556473701231, 123.72807625801333, 84.88204386926468, 95.8750589432255, 131.68805583830803, 97.92539165865992, 109.9061458341537, 108.41154236947338, 121.93501964692148, 72.30490899855091, 120.69504076434721, 118.72725040681901, 100.58483708289363, 86.62437638928814, 94.97648316044962, 109.87471195959277, 112.24371371730682, 111.45971821200465, 111.60657175125615, 106.12772664716168, 106.88860370266823, 105.41751092480075, 113.06462657067084, 109.85710051751907, 113.69800306135609, 117.29228265823858, 111.59642065725019, 86.9043630169284, 59.575390046642674, 29.67285586941627, 12.742742242351657, 4.497377872467041, 15.503589760872627, 20.45846700668335, 1.31072900227962, 1.1996876832938965, 0.320151575630711, 0.19241638872171604, 0.20526500088312935, 0.6186940785377257, 0.2083576059028987, 7.418968043019695, 46.21177681030766, 65.43743110472157, 73.58091877352807, 100.19606744089435, 41.66535362120598, 13.692028387900322, 58.709275799412886, 68.28663687552175, 83.61339246073078, 98.00074823441045, 103.65987331636491, 61.52232908433484, 22.810977159007905, 4.615411796877462, 0.27489680075837725, 0.2086576672210809, 0.22127315882713566, 0.13481233779701496, 0.380910407271116, 0.29856306470690236, 0.23296491693585153, 0.26339328577441556, 0.1655631836864256, 0.20821762631737417, 0.3506084429400583, 0.3017479067127551, 0.26106330596150895, 0.6961722888292805, 0.5805797334159575, 0.656628423640805, 0.787267497470302, 0.3408039271110489, 0.34648829950921, 0.168625436302635, 0.29579570997626553, 0.184063226465256, 0.15219491876421437, 0.1511586163072817, 0.14519921834430388, 0.16614942480960201, 0.15634452593663048, 0.14774644537077797, 0.1571001337781068, 0.13629598963645198, 0.27031078393901553, 0.1694401248448318, 0.11679094675327502, 0.2652316822880699, 0.2646861970424652, 0.1754451356828213, 0.2744411623045322, 0.1431539014823014, 0.20821211048431937, 0.23673494286354513], [0.07822842487404424, 0.03828502185041866, 0.10492001600082844, 0.10280618789575754, 0.039841727834315076, 0.03576905121125522, 0.007047885850507527, 0.08170464842189705, 0.042941775398268815, 0.01662421137875607, 0.07241376390260074, 0.04473481184592651, 0.07473067425551914, 0.11092673521488906, 0.029897822307482846, 0.09345620735398225, 0.05730136192493862, 0.034695248750429, 0.22597422673096582, 0.32046701999441274, 0.3682394968646188, 0.2396884722815406, 0.39960666048911314, 0.26713651394651783, 0.2506446634088793, 0.017432803776295438, 0.08504213344666266, 0.007903551478164211, 0.06707003249997093, 0.056060904697064436, 0.0844538392078492, 0.25703498582926493, 7.014926162458236, 35.44412151459725, 79.61980773556618, 103.12841569223713, 94.73608109258836, 87.48365002293741, 48.69779463737242, 13.501711064769378, 46.910974594854544, 56.245038893914995, 44.76183345240932, 50.851042501388065, 34.4284825940286, 16.483154642966486, 2.499371046020139, 0.14225491262491674, 0.034698232662894075, 0.2583681167133393, 0.15902560384523484, 0.07777884617568025, 0.21424126841368216, 0.4393718944441888, 1.4022767543792727, 1.6578150035873538, 3.442338008073069, 5.005306178523648, 6.047043569626347, 4.277339769947914, 4.057704690963992, 4.840752453573288, 37.731404612141276, 83.92988066519462, 106.45684488358037, 94.16519580348846, 93.63533066165064, 98.58104721192392, 101.03568215523997, 102.27302520505845, 100.46856234150549, 101.89919194867535, 95.55057694835048, 85.41558034958379, 85.07495387907952, 99.7563462103567, 105.21416741032755, 100.2247242773733, 89.57922335593932, 88.58236866612589, 96.95988455126363, 116.03775178232502, 76.39118717562768, 38.80843647064702, 82.64896792750206, 83.1781348874492, 81.94518489222374, 70.90295976208103, 98.33633838161346, 42.01557420915173, 106.70880225396927, 98.0150805750201, 96.96794109959757, 88.59999579768028, 80.14578973093342, 82.43977223673176, 89.4435642611596, 88.75059127807619, 92.42858994391658, 94.32705633101925, 92.22385791040237, 90.25034873716294, 91.77657435017248, 93.71710423500308, 95.12792587280275, 96.55176193483415, 103.39854148126419, 101.44656612027077, 91.65491027216758, 56.115890933621316, 21.914699885153002, 6.344063089739892, 1.0855008685781111, 4.308520161336468, 1.31018832806618, 0.38428140864256893, 0.5975914205754957, 0.17377995164884677, 0.05830061253941348, 0.0335054567474271, 0.04823316384347216, 0.04447036212490452, 1.6005839455512263, 18.110342064211448, 45.619267494447776, 63.77653875658589, 78.43467143274124, 58.37991045367334, 19.311199226687034, 20.381778786259314, 64.07071259713942, 56.02937913710072, 47.56810888167351, 51.89587562314926, 40.52055497323313, 22.650207050385017, 6.7332284008303, 0.4619409366240425, 0.059842364487027934, 0.03042802409899812, 0.026699148584157232, 0.009846706206219332, 0.11097469231894902, 0.10272070014428708, 0.04154675610123142, 0.07529305940073344, 0.12528513813571585, 0.04360115110513665, 0.035966916400338375, 0.11391689895742363, 0.16684259648524946, 0.09870174926735702, 0.1634025859135774, 0.07992660431491752, 0.02598374120650753, 0.02358846580459466, 0.020449771020080776, 0.0442914231379907, 0.07788043709531908, 0.11519409010126708, 0.049282493625557235, 0.02177221497761146, 0.052278403027523915, 0.0916190825462822, 0.10983527442740817, 0.13123141301255073, 0.028442015848873604, 0.0517489634934933, 0.0042905017542051935, 0.06367132172829683, 0.07753475524124599, 0.09558403188542974, 0.05617582171614613, 0.05931318542289157, 0.12467706350669747, 0.1689073719805287, 0.059651217889040715, 0.025318619840207602, 0.049684747242398804, 0.05135250916223853, 0.007848327072532548, 0.025987002825845155, 0.006470771707339033, 0.06869573236232804, 0.044101697633103024, 0.052449187008483764, 0.08489688317621909, 0.029821374393518896, 0.046106917453148676, 0.07613603190909471, 0.04154546524307901, 0.02593219306530251, 0.014207224087459187, 0.08223410710812577, 0.06296377824318987, 0.30615429123563154, 0.28625010122214595, 0.22577973232874948, 0.32717650996581205, 0.21706869975934107, 0.14839391224086285, 0.03889057221972654, 0.06706417958822943, 0.02492472041218031, 0.078113159284957, 0.07396434884398215, 0.04145747238409616, 0.2001678502006877, 8.212596399168815, 43.15450499134679, 94.50947007825299, 117.34460707633727, 107.39426782054286, 114.42771296347343, 72.03479889900454, 38.707427593969534, 65.04555494554582, 53.28764630902199, 50.059170876779866, 49.82307949373799, 41.85014824713431, 21.08175712247049, 3.0166907320099496, 0.1164201295544063, 0.02149476282929461, 0.3638059928292229, 0.14306649085014098, 0.3110963244351649, 0.6704316732864226, 2.1131296167450566, 3.297982773473186, 3.172613281396128, 4.820127160318436, 4.816204299849849, 4.217927628947843, 1.7929016774700535, 1.6851528205217856, 7.596706815304295, 43.79153713103264, 91.4615531121531, 114.30433088733305, 108.500148711666, 101.88251403070267, 102.58676775040166, 108.09088860788654, 103.9206167959398, 103.86509172378048, 106.23742749614101, 101.5839824368877, 89.45237390456661, 86.13088730842837, 102.28763995632049, 108.73819735742386, 102.41408148119527, 92.85168816966396, 87.79583146495204, 99.12778639024305, 118.79273045447566, 82.7116003344136, 45.85216999053956, 93.10400639810871, 93.77873251515051, 90.3627089531191, 78.28250700427641, 103.13346770501907, 47.75609239455193, 108.97668530864101, 104.18238009175947, 101.27633525479226, 92.4673508059594, 82.46556574298491, 86.5607790793142, 93.36581676237046, 93.27955599754088, 96.3861123977169, 96.43304747919883, 96.48308123311689, 95.91322360500213, 96.74147913532873, 99.35790400351249, 99.13861997665899, 100.21731884248796, 107.08705994390674, 105.39300395596413, 99.0426395785424, 62.73092116079023, 27.017850568217618, 10.378518912100024, 2.599493467038678, 1.3189095955702568, 2.5354004675342194, 1.7374376471965545, 0.8721639516372836, 0.46776528860772815, 0.3889258013617608, 0.07416988257318735, 0.08981892914180795, 0.1196591416373849, 1.66730358475639, 19.976690123158118, 39.00803019923549, 44.98200785729193, 51.505176175025206, 46.28090073985439, 31.09102999010394, 36.85489608395484, 90.01688141976634, 76.49966424511325, 69.44246522841915, 72.06194954533731, 59.69787390001359, 34.55763447669245, 9.40781956718814, 0.44928792203145645, 0.16467639094879552, 0.11359410781052806, 0.038187847427663305, 0.07440387646877959, 0.07134345480270925, 0.03500413157105927, 0.04296510660600278, 0.03680075331020259, 0.033585363548369176, 0.08864091574064187, 0.08554357629750045, 0.09963883567721614, 0.1482659142704741, 0.17189836309802148, 0.14354586270788025, 0.2242438639363935, 0.031261284527699315, 0.0578888364496731, 0.09489400883115108, 0.02463155580053647, 0.048729102352573994, 0.07707016888044535, 0.02319639924192621, 0.035962193468285185, 0.10092076890531088, 0.0675059135462488, 0.10309973746658334, 0.11181005757422217, 0.03849386507945676, 0.07034159565885222, 0.06183037031141501, 0.07008126366042322, 0.06691575005290008, 0.007691654431137948, 0.09564804619238262, 0.15420545523445453, 0.06433489176655008, 0.14794809503420708, 0.1941977116850115, 0.3460809245945946, 0.19047548964379296, 0.2179375813613015, 0.12007672850403095, 0.1595632290287364, 0.11804846475922293, 0.2503960985209673, 0.1652378261449837, 0.11688403409695435, 0.17468015092515177, 0.17473000792726395, 0.13370549396401452, 0.17653236766496014, 0.20579157907876278, 0.20587802444013859, 0.17822741380622312, 0.16991413408710113, 0.2456579059963265, 0.4988106340169907, 0.5679375666283792, 0.37664440069948474, 0.6380898313176248, 0.32324175981263964, 0.40429980704380625, 0.13119988083358736, 0.21931321480341498, 0.1401558470341467, 0.23238414568045448, 0.23903578069181214, 0.13599831851259356, 0.36218813770721037, 15.480981219199398, 64.42369061131632, 119.053097386514, 132.49507565652172, 124.64358883519327, 120.82422794834261, 78.65699921884845, 31.652897750177694, 73.77759425870835, 86.48887418931531, 68.17497484145626, 74.59318837811871, 55.39732056279337, 30.264255154517393, 4.365050831148702, 0.3017994184647837, 0.19581685383473674, 0.6723001923772597, 0.40370602761545493, 0.29644890718402406, 0.775213931356707, 2.1104381353624406, 5.343532648778731, 5.428595129520663, 11.31014262476275, 14.400211341919439, 17.61221085825274, 15.598265970906905, 14.46598654793155, 11.95263764550609, 45.41177803470243, 94.07239252521147, 111.60370842103036, 107.89682542124103, 104.87347033716019, 105.93805651510917, 112.64279134811895, 109.8010733819777, 108.06507156741236, 111.26125412602579, 104.20921694847846, 92.98486832649478, 88.539167681048, 103.74744415283205, 110.71995135276549, 103.94348421404439, 96.44728568292435, 91.8658318058137, 103.93603955545734, 125.07255492671844, 88.38768574499315, 54.70434365733978, 105.2811771823514, 102.69998304305538, 97.9720364847491, 85.41859272987612, 109.19003871179397, 58.81797252162811, 114.08254438830961, 106.53607676106115, 102.55621248675932, 94.86981038124331, 83.97371707424041, 89.23021085800664, 95.94736391498198, 97.15717977093112, 102.20821980507144, 103.73305689903998, 101.24027298342799, 101.12795199117353, 103.5799354122531, 105.2816870904738, 104.45363552339616, 106.5371750247094, 112.40660190582277, 112.06508113491921, 99.80401085269068, 62.82464227368755, 27.84479798809175, 13.998983271660345, 6.113862616400565, 10.281569688550888, 8.522188586573447, 4.3587279704309285, 1.842135758169236, 0.48563582161741875, 0.4167438022071316, 0.14627642989639314, 0.25624648217232, 0.22344828162702823, 2.9855395132495515, 30.852493009259625, 63.93072712805964, 84.14766634664228, 101.04632746788764, 80.41488785897532, 27.340887169684134, 30.428371044897265, 87.8436843810543, 85.95979352151194, 81.27487536399596, 98.05498676915323, 79.76343708653604, 46.47211236338462, 11.516230817764036, 0.8827824818511164, 0.18098235791248662, 0.15818589487143103, 0.14354468293247685, 0.1857068068197658, 0.18871610743864892, 0.22108925176003288, 0.11890081418377739, 0.10171786040788698, 0.2097040667168556, 0.26925934358469905, 0.16345641125113736, 0.3000271200172363, 0.4220596556701968, 0.31058773398399353, 0.4589688832000379, 0.48423838531298025, 0.2788296816570144, 0.14414440720312058, 0.1543283817027846, 0.10579709474357868, 0.16133235587227732, 0.15674865263844692, 0.1063244620097741, 0.10348431360457214, 0.28162578000657024, 0.1752446351512786, 0.3395486154383229, 0.2670689756351133, 0.25768835157636677, 0.22087733651841843, 0.11507370704484564, 0.13489673004275368, 0.17128331706889216, 0.16021999620622204, 0.13516723568881714, 0.24347581179632297, 0.23224749091652133, 0.31187080868309547], [0.04246161063952793, 0.09306017820152546, 0.04997161269608525, 0.09243101317195163, 0.04988230599631226, 0.02546392373680588, 0.09961689491906475, 0.13831524418727045, 0.09735908824950458, 0.07488465792829953, 0.06293428385810507, 0.03564214108571891, 0.07436843724140237, 0.14316174622264602, 0.05344915391516782, 0.05768608745007266, 0.028637835583198937, 0.04343305992323064, 0.04625733498664153, 0.14903040873187204, 0.1941967310924684, 0.20901322394849794, 0.3208785624273362, 0.20214261036486397, 0.13605923782433235, 0.08299461791231748, 0.006389262346220353, 0.07948463286964164, 0.06404210062276933, 0.11809911849277636, 0.6858088352507161, 15.951696038246157, 67.8911050673454, 105.55968115406652, 96.14310587606123, 91.40013663999497, 85.47410995729508, 36.13369772511144, 11.891154493055037, 34.341139255031464, 32.64795403326712, 32.30469761356231, 37.22267320079189, 25.18778835573504, 8.089533015604943, 0.5673728678976336, 0.13336427840254, 0.05245957899117663, 0.10567776888849274, 0.1183053570228719, 0.0965701096180466, 0.5489238772180773, 0.6475385146275644, 0.4443368489944166, 0.4998737495512732, 4.188677043684067, 2.3842502169070707, 5.454673988203849, 4.146607172104621, 1.5419404665308616, 19.293423045066096, 91.05419928027739, 101.55627481399044, 96.63058588581701, 96.00769781297254, 102.9073352198447, 99.11249699131136, 93.87057873510545, 96.00317924253403, 90.12461323891917, 89.79989590183382, 88.97808090333017, 84.99298418721845, 75.67834346525132, 90.37546450091948, 100.49990207918229, 110.41776410994991, 100.34615301316785, 100.82620405381726, 80.36053165312737, 87.45148658752443, 100.72538345090805, 102.21659798775951, 37.876885321832475, 71.29346309169647, 72.43575142275903, 73.45275140577748, 85.15187940289898, 83.51327788445258, 31.380832349100423, 85.97461223602296, 106.3875287578952, 104.3327323852047, 99.97610876637121, 94.67522944173506, 85.58666629175987, 81.48272960416733, 84.71871637528943, 87.18831123844271, 87.47655837766587, 84.93689429375434, 81.46881303479596, 84.77257051775533, 91.27105143762405, 88.55066022565289, 89.34103350485526, 91.9406000260384, 95.41104255184051, 99.93639084600635, 96.35153278227776, 59.09695894487443, 24.435036490040442, 4.011905871091351, 1.3167366024947937, 0.984364943879266, 0.8403564713174297, 0.8335012714228323, 0.8783150247989163, 0.070934065076853, 0.11162760607417553, 0.05146245427069165, 0.0719937791807517, 0.06417983557067572, 0.33645362022422975, 11.653311771731223, 48.5719257785428, 59.30138111114503, 45.59421531615719, 46.6077910700152, 48.44885749201621, 14.140193500826436, 22.029654748978157, 43.4686593855581, 50.565152706638465, 51.728845411731356, 53.48215272349697, 39.388390279585316, 12.305225383850837, 3.319000794041542, 0.11304292287076674, 0.13285251634736217, 0.021674169129842234, 0.035774704940136404, 0.0489110290823925, 0.04914110826869165, 0.05784465615907985, 0.06924987440147708, 0.026488292459098083, 0.18195250101627844, 0.07976963289923246, 0.08967930195672859, 0.1057590661390174, 0.14142177668550324, 0.09640888641438178, 0.12584226025689033, 0.05343650197309833, 0.07376644535050278, 0.07480889949346743, 0.08410961292083226, 0.1275406848458994, 0.015100042106613759, 0.07064175656846455, 0.06158956589417593, 0.0317850626719695, 0.11714111788258438, 0.040972105888349396, 0.045106065714912075, 0.07545896340161562, 0.031599320824288075, 0.06049750755811411, 0.07177345995460788, 0.088550272217441, 0.08108823109538325, 0.1371017455934517, 0.060456115827565236, 0.10824846884896679, 0.025699815615230513, 0.04361034416022801, 0.050802435049967426, 0.054660974776432406, 0.04093195905067748, 0.02665060925327482, 0.011450686518313184, 0.09428222633657918, 0.06527255274235241, 0.12895263851650302, 0.0831419672636736, 0.044287799542108854, 0.05010216173926189, 0.12135724446946576, 0.08020624938991763, 0.02704732405442384, 0.007252956096518545, 0.05177163203517276, 0.09768565620986686, 0.08663719745292779, 0.039241727772018606, 0.14910395317260297, 0.2780200492951178, 0.207333039912966, 0.07385528856708158, 0.12053963713227742, 0.029328078887755835, 0.05092474864795805, 0.035516640561963284, 0.10599531233310701, 0.48466304317116743, 18.89997205426616, 81.32784305080291, 118.21436128308697, 112.29021733806981, 108.54019611112534, 107.56241198508971, 61.79332563954016, 37.91993333447365, 34.817256158398045, 34.59103738107989, 42.232748000852524, 44.71465126160653, 35.266328319426506, 12.248513794714405, 0.8962514107265781, 0.06758420007123102, 0.055377056311455466, 0.15860053229956858, 0.3305821078679254, 0.6549820700480092, 1.6717205412926215, 2.100292434615474, 2.3576741978045437, 2.1130835288955323, 5.276269393582498, 2.3495480274000475, 2.548425678283938, 1.4420439495194344, 2.830052837248772, 22.420785657821163, 100.03520319538733, 111.99523941163095, 102.95940860625237, 99.90345862603958, 105.65240598494007, 101.99749438993393, 100.69734634891634, 103.06200996521981, 95.76942951448503, 93.0145606686992, 93.21220105694186, 88.34424941770493, 80.78679915397399, 95.42605738486014, 105.63997991623418, 110.19138059308453, 108.15135586646296, 101.48191452026369, 83.95776871711978, 92.08525703799341, 103.30473407622307, 106.21750185566565, 46.00110238598239, 79.70792770385742, 84.2669613130631, 78.52206968492078, 94.90267199854698, 93.64925507576235, 39.23260158108127, 95.19457478677073, 113.12602735334828, 107.64680570171727, 105.97996311803018, 99.29929594839774, 91.0460485950593, 85.67985396231376, 88.50092457186791, 88.59178235453945, 89.19874560448432, 86.61877524468207, 84.48975193885066, 90.91063268723028, 97.38281019272344, 92.7056347939276, 92.9118416386266, 95.9952482100456, 100.22321024248677, 102.81597537379112, 103.14959649116763, 63.4531589477293, 30.248346021098477, 6.91053080943323, 0.2700829493903345, 2.044456759768148, 3.285604263505628, 2.8838518213841224, 1.471776496018133, 1.349873153432723, 0.34051511196359513, 0.17047650391055694, 0.047446383884356874, 0.08458997303199384, 0.11561810444559782, 12.566729803239147, 39.20920856537358, 50.194614241200114, 37.7679414902964, 31.81487987118383, 37.572325045062655, 25.89840808222371, 47.53483933787192, 66.28778919096916, 71.57995300908243, 73.55244236607706, 74.41283779759561, 52.789870077563876, 15.826784237738579, 4.721815893726965, 0.0770085217851785, 0.12291062563177078, 0.015381927031182475, 0.04178419356204329, 0.1293346712425832, 0.10660511065995502, 0.084313775352653, 0.04223841092278881, 0.016997464737224004, 0.040091920659066214, 0.06414936825392709, 0.07633925971364783, 0.18214193923819452, 0.19138572467190607, 0.1623564009224215, 0.04588640287458416, 0.04260462776367222, 0.03269882361975408, 0.02868121531191132, 0.03995576002184422, 0.07539272743968234, 0.019685268897803563, 0.02426762381688722, 0.08027879791634698, 0.02103337680079764, 0.08022875705313298, 0.06994035710851032, 0.04999946382257247, 0.052608039170022936, 0.02896238107144112, 0.016474021756420695, 0.005659856148169286, 0.0318261556282279, 0.13743346166466514, 0.13404385967841073, 0.05048314875532543, 0.13082914024351106, 0.18448008554837397, 0.16681782120177824, 0.11940015795370264, 0.1805763925996519, 0.17001383276956697, 0.13048021783751826, 0.17026749980305472, 0.25507557806709125, 0.19461529089077828, 0.1612981730290959, 0.18614045855018402, 0.12215405251950988, 0.14627183336884747, 0.30978410775142334, 0.17383028362547198, 0.11123969745371612, 0.15495263610876378, 0.09949127948212047, 0.13329290965151402, 0.21900394510838295, 0.3667152576869534, 0.2779776693111466, 0.41998230101120093, 0.4785343397769236, 0.22072845499121377, 0.24334568410150467, 0.06402611619822922, 0.1126607905532564, 0.1297352279746725, 0.28079178604868155, 0.8836959650920284, 32.445267515797774, 105.88977213828795, 139.786620601531, 123.12730250820037, 122.21801081011374, 120.90268319652928, 57.74073669987341, 24.86097058942241, 51.02615671773111, 47.46342866651474, 52.156132728822776, 61.78428065392279, 46.140762298337876, 17.634029042336252, 1.3859578558514196, 0.28987804848340254, 0.17491461979525705, 0.3720628884771178, 0.21056809132137608, 0.47500806770497755, 1.831930363851209, 3.3949457253179247, 5.904622308669552, 4.223176740830945, 12.475301315707545, 8.197986060573209, 15.23199994717875, 14.143496136511526, 6.65422696259714, 21.66098137055674, 100.89488475553452, 113.93070943893926, 105.35675341083159, 106.82841885474421, 107.73483153312438, 103.39395230816257, 104.97697384126725, 107.68565285590388, 101.00338535924112, 97.31394906197825, 97.3950715218821, 92.21136123903337, 83.9338344143283, 98.14123968924247, 109.43758733810918, 116.17230476871615, 109.22028803056287, 108.28724245871268, 86.99812335352745, 95.46423773611747, 109.42376490562194, 109.41228805049774, 52.6371447501644, 88.01888881191131, 95.33316781443935, 87.0013475418091, 103.57302419600948, 106.55150736531904, 45.37887719369704, 99.35325207248812, 116.34350053725706, 113.49144320334159, 111.34883280723326, 104.56390119368031, 95.71106464632096, 89.58255737058579, 91.48897047965758, 93.2601010414862, 95.48957624743062, 93.17318916320802, 89.99589673934445, 95.37959298779889, 103.3302765507852, 99.04787986509263, 98.57186102098035, 101.40258850589876, 106.53632779275219, 107.1948858999437, 107.01097380730414, 65.29218965961088, 30.055304611882857, 9.76062499707745, 6.063848964629635, 5.854108064405381, 5.350479656650174, 7.692867642448795, 2.963549480322869, 1.8654329209558427, 0.29898937731500597, 0.2650011511098954, 0.13181157139760832, 0.2353938599868167, 0.4585587503688951, 21.6161584854126, 68.40079353701684, 80.58445192152455, 60.35916197684504, 64.61973067252868, 66.32637746872442, 24.934107103655418, 39.10912144568659, 69.98277171965569, 85.66060296950802, 95.27922737982966, 98.0255925270819, 65.24783549770233, 22.49376331606219, 6.051069882608229, 0.4337931808925444, 0.4293329863538666, 0.14459823768946434, 0.18394074432792204, 0.18058825164071976, 0.2058196485403084, 0.09965860840654182, 0.10103490834514942, 0.15053494412812496, 0.20587712045638792, 0.22573983446965296, 0.1673082860126611, 0.4315325473585437, 0.33664048439072025, 0.47082639209205107, 0.35073307012358024, 0.09313606687130467, 0.30237232965807764, 0.24054140393291754, 0.12389432849182237, 0.2720803244700355, 0.11881337290810001, 0.27338325616813475, 0.2894926143269385, 0.21160142135716256, 0.1542387187721268, 0.1976010266451105, 0.12556016370053255, 0.23809873258634923, 0.11495834952520748, 0.1406360615886027, 0.2404149228166188, 0.1081928278830263, 0.12918367531270752, 0.18655589270976283, 0.15249550102218506, 0.23458678635858723], [0.1332149831878562, 0.08704851772035323, 0.1110710125536688, 0.06708681748639192, 0.08487433720860751, 0.04299999041963489, 0.039944559816391244, 0.007117808131771463, 0.0404265440339523, 0.0951883857769351, 0.03443070326841647, 0.03787970005144035, 0.06844733601375934, 0.016639828081092527, 0.04268348502415804, 0.09471727234701957, 0.019167579237311598, 0.04485521405454605, 0.09296332170525867, 0.16515432256123713, 0.257379342351229, 0.21458237672284727, 0.2088256549811171, 0.15552802942693233, 0.049243905776811224, 0.15493660954938782, 0.036485224676829194, 0.010450840270477197, 0.04421505949369842, 2.0925151100081782, 39.134926719050256, 91.82518036134782, 108.68479820989795, 94.70090527688303, 88.34773248241794, 63.94907205335556, 36.469664419851, 26.365146598508282, 36.98118855876308, 71.40733734253915, 71.31913108210411, 41.10920467684346, 29.319358141191547, 8.968375844340171, 0.5342398716076728, 0.15511351457286268, 0.03689191777319197, 0.08629525410792521, 0.13180530479838773, 0.8001840463088405, 0.8150145892174014, 1.019298369365354, 0.44501897368219595, 3.1594260277286654, 3.1572255780619964, 1.5322464512240503, 2.9773120966649826, 2.2757523098299584, 10.941313332126988, 50.027489892898075, 106.50389763616748, 99.31882935185587, 94.00193106743598, 87.7678414314024, 87.34669654600083, 84.92060076805853, 87.7076958071801, 89.5356301338442, 84.56171958677231, 75.80068219092585, 77.2896452872984, 76.06207678394934, 80.97524550653274, 85.85336392925632, 96.16915041400541, 102.93399164753576, 100.65310201337262, 101.48595456154116, 101.53875750880088, 96.44952143392256, 86.48404967400336, 85.5744206520819, 101.54922239242062, 68.0107295128607, 46.33503337060252, 85.8648721633419, 79.26058138570478, 95.47087438644903, 60.24129475316694, 45.875370810108805, 108.41578637399982, 92.4731872927758, 100.62998356357699, 102.97330164140271, 106.15679925487888, 95.97641298847815, 80.68523330073204, 76.80945304132278, 79.08279603527438, 80.36996887576196, 79.8842853115451, 79.79093290144398, 83.80986398266208, 87.92111196825581, 87.35902063308224, 82.8564142411755, 81.62112651332733, 88.48959676681027, 92.89410468070739, 99.46485134863086, 92.92986885193856, 63.55732925476567, 18.779192470735122, 0.8987850779967924, 1.6608012756032329, 1.1209247741968402, 1.4630392938852312, 0.665573021096568, 1.7270151742043036, 0.22157504343457762, 0.05642510289626737, 0.08439676565749031, 0.07699843240721573, 0.08875903117680743, 0.8159259886991593, 8.843603287973712, 26.481570389962968, 51.08045016565631, 70.51477063086726, 80.7205738559846, 60.42565007363597, 15.381664845251269, 18.440776255822954, 30.90495667149944, 43.19346981663858, 45.57426614146079, 48.43950656152541, 36.45579884129186, 20.98113852162515, 9.34321911104264, 0.9887616756942965, 0.03737102150015774, 0.11229599480547252, 0.0170392720704718, 0.03356113601776381, 0.01823224333835946, 0.04995555549319233, 0.01757935639621029, 0.02036844504125897, 0.03549440102952142, 0.04820252415694056, 0.12706181860619015, 0.017250714252793023, 0.014295458264138191, 0.06008255986436721, 0.017422806328883576, 0.06274954175516483, 0.041835326100549394, 0.07194815098398155, 0.08594724334656231, 0.03871621826903955, 0.032035366579469655, 0.032013843339237, 0.016331498758987557, 0.10062518920148573, 0.15231835085057444, 0.04575124581254298, 0.013360896113989575, 0.02292035861060985, 0.015859161503612995, 0.04792289823413857, 0.04543512729146788, 0.0648942738471012, 0.12739746470845517, 0.08432967167708182, 0.021224638311973503, 0.0864927668965632, 0.059975897442669644, 0.0808608178950606, 0.05712988846484692, 0.06214658842392026, 0.04126729871777277, 0.08816930435357556, 0.020309948482580727, 0.08495291484700096, 0.07519976521331458, 0.011177132799921018, 0.06379465422322673, 0.05102172005741347, 0.05755742681362937, 0.036838479310033784, 0.11122675056779578, 0.032781978633495114, 0.02727377581440153, 0.09327551785616145, 0.08523478157698147, 0.09148443493271068, 0.07281699428154577, 0.11709346721369414, 0.15098031700378464, 0.028741088913633462, 0.08656811164391619, 0.11138684762221192, 0.020505113211730798, 0.0766342188862543, 2.8787039556810936, 46.14620262576688, 107.40441891454883, 123.38967769376694, 107.52599670040993, 103.07142365363337, 82.24104142958119, 63.193890279339215, 43.37211024376654, 21.845648519454464, 52.37524809375886, 59.19087225391019, 44.28500660004155, 37.40876220887707, 11.411377037725142, 0.7618686184287072, 0.17274573295106813, 0.07661742623895407, 0.12256656788409719, 0.23844612281649347, 2.8084810270417124, 2.2700067729719224, 2.7952302800070856, 3.302811211155307, 1.2766630947589874, 2.10899053562072, 3.321898690154476, 1.8499834402914972, 4.118390621677522, 13.851286422821785, 56.50280529452909, 113.91203895691903, 104.32198509093254, 97.7947453529604, 94.14807073531613, 92.0887165684854, 91.76026513499599, 93.80932700249457, 92.3585521021197, 89.80021753618794, 79.93097720607635, 82.10810445970105, 79.7892149033085, 84.95853008762484, 90.76787410243865, 101.59236061957576, 106.05706122613724, 103.2123230349633, 102.71369564917781, 104.34679800464262, 98.6501201506584, 91.08702951861967, 90.1556391869822, 106.79664765634845, 73.00068255393737, 54.30910994929653, 94.47259979863321, 87.96868247370567, 105.70493436628773, 66.91688245342624, 51.47612710152903, 111.26829870285528, 95.37221108713459, 103.42253069723807, 106.30566889239897, 109.79482896866338, 99.34462285810902, 84.5208014211347, 80.12344006569155, 81.17858902100595, 85.48119375782629, 83.71202438108384, 84.33919568215647, 87.13381382726854, 92.6712356075164, 88.87158070841144, 85.73963872848019, 84.54866593883884, 95.40532373612928, 95.96416734880017, 102.30382365565147, 98.07939175636538, 69.49439740950062, 22.869838206998764, 2.6007331811612655, 0.5768819802230405, 1.5555982820449339, 2.126407575222754, 3.7356856994090544, 3.44094826329139, 1.2171770415959822, 0.043198388039825425, 0.29331107233320514, 0.03658304644388057, 0.04747883153838977, 0.5736999574207491, 10.150184016073904, 25.49467263683196, 38.553909947795255, 53.79069420599169, 64.02540922164917, 43.28807346282467, 13.637832018636889, 32.51030629681003, 51.98319150555519, 63.34686663842971, 65.89460296015586, 72.311216169788, 61.507063219624186, 31.795417070388797, 10.950680932691021, 1.1466156859551708, 0.039638028885688514, 0.05011632670498183, 0.03963003858863827, 0.028489710567819498, 0.029873684792208578, 0.03593208238242134, 0.04582864750597266, 0.047303696178020015, 0.05020032441543956, 0.09977419575255725, 0.14893691536159287, 0.20207566960204035, 0.09161815557989383, 0.11667983336073738, 0.033474721299904975, 0.0749677861289632, 0.023106439452197765, 0.040744891870887055, 0.04246499291771362, 0.05531681115709006, 0.06876157761941995, 0.018957301508635283, 0.045432660488351706, 0.09095437103702177, 0.07872003115593426, 0.061029731821749485, 0.023883777377646298, 0.01566473700691976, 0.04655318665167978, 0.043154544827918855, 0.03713024006555638, 0.09750688193185676, 0.07806832781962811, 0.029391097280407147, 0.03973582767010216, 0.23378314480425852, 0.220178802227301, 0.1447842744809966, 0.17536236754348203, 0.17468583529754994, 0.1271325974695144, 0.17788540151330734, 0.08875308633451501, 0.16197963888126035, 0.22874009525102956, 0.13802710319719008, 0.2178760491792233, 0.1518686725607803, 0.10206597076068002, 0.1691752269623741, 0.2178945731852324, 0.1264472169080569, 0.11016272338888339, 0.20148769712015507, 0.2482597244482848, 0.2986150054681686, 0.33935831919793163, 0.3655760543000314, 0.3336458160511909, 0.19985737008673532, 0.2245777863408289, 0.2082496641143676, 0.25327370862566656, 0.2909003774965963, 5.274711722327817, 66.71946956265357, 132.6108640240085, 134.6734502238612, 120.37284158891248, 117.61509372342019, 91.98606814107588, 56.431445613984145, 37.83837941385085, 52.52891478999969, 96.61819904081284, 97.94633711538008, 63.52379691216254, 49.368100243230025, 17.653509493797056, 1.1602964228199375, 0.3167239143963783, 0.28584456491854887, 0.29609157313262263, 0.24918512801729867, 3.4914992797759274, 4.450852188371844, 4.863075152520211, 5.802647058040866, 9.076412627773902, 12.414837979501295, 11.205470254344325, 10.698079313001326, 9.609279363386094, 17.123387436712942, 55.922400413020966, 121.78644810953449, 106.55826168675577, 100.15804398444392, 96.96070824899982, 94.72904436049923, 95.22254128609934, 98.86391285927066, 97.56359223396548, 96.62135262643137, 83.79704567693895, 86.57625675201417, 84.89513674089986, 88.04545894745858, 93.34935849712741, 103.32235336303712, 107.89867677996236, 105.33472537994386, 104.1611365349062, 106.80006796313872, 101.28990665558847, 95.72422812061926, 92.26177154048797, 114.81757302438061, 77.52796849896832, 62.484470798123276, 104.68411399472146, 97.47088309257262, 116.08677356473862, 75.72158367403092, 56.50208750078755, 114.17022505114156, 102.10856022373324, 109.18628108116889, 109.13261521247126, 111.83664229608353, 102.69307967155211, 87.60431781891855, 85.28978993815761, 86.78388349471554, 91.52382466100877, 90.50454185855006, 91.72878419199299, 92.81068371188258, 98.02479236356675, 96.77860829137988, 91.08935940650203, 89.99844627995645, 99.51545776859408, 102.00890064239503, 105.19571658103698, 102.84009795035087, 70.30442176326629, 23.529069000674834, 4.284675092466416, 5.51088547514331, 4.902656280225323, 5.206423747924067, 6.124965375469578, 6.553383806059438, 0.970569477686959, 0.1383516946507077, 0.33152350735279823, 0.2073529735207558, 0.30350494468885086, 1.2436241127790943, 16.760158308090702, 41.60308599472046, 71.88576452193722, 90.4202030551049, 102.86435388749646, 83.3789602402718, 21.48769105634382, 29.61900761050563, 55.93285745190036, 77.98988249994095, 86.53878242738786, 93.5227115692631, 80.6328853484123, 41.447877807001916, 14.868336416059925, 1.937575482072369, 0.10772349943797435, 0.1354621948614236, 0.1769189049880351, 0.10614626229770723, 0.09842921348829424, 0.11683746361203733, 0.1863535229236849, 0.31784534454345703, 0.11721157498898045, 0.26904036501242273, 0.34907942337374537, 0.41158101311133755, 0.1695441749067076, 0.22366125406997822, 0.07339506890744933, 0.13608936040151504, 0.14647613369649456, 0.14278807917669897, 0.2034542754653, 0.1033649341233315, 0.1769950081624331, 0.11156978175765085, 0.08624067800419946, 0.1315727051828177, 0.2417649076350274, 0.18897970297163535, 0.1343280629765603, 0.11004844605321847, 0.1642857627162049, 0.11998203237571063, 0.2452804544760335, 0.2276213464116858, 0.17868541181087497, 0.20917494510931356, 0.15767561902682628], [0.09715435125174061, 0.05581420140280839, 0.033901478239004655, 0.04663335009207649, 0.04104916667265277, 0.02148334428878321, 0.0601537524151706, 0.16366722332614084, 0.074212055713419, 0.017270358662391384, 0.04975426589108763, 0.035813932472299186, 0.045989633222380956, 0.025382733738590634, 0.006308380698394632, 0.03981719386853999, 0.0318984953956979, 0.05933740912305732, 0.028263839119444453, 0.08856848978828039, 0.1468157557950866, 0.25371802429999074, 0.07692174700599524, 0.08968571411265482, 0.045744423799577265, 0.09514075809068258, 0.040152238591784434, 0.029389848557090568, 1.824830751265249, 49.11839039094987, 106.67993360950102, 101.25081631445117, 97.7545645929152, 69.26000441274336, 52.252819153570364, 24.502385547084195, 22.611201040206417, 42.9922483044286, 97.6889511846727, 61.748885185487815, 34.423736526120095, 32.88715781704072, 10.423110377403999, 0.3571538981651107, 0.14211182272241962, 0.03585335152644304, 0.012567393733338724, 0.16886172846200007, 0.08664948550323326, 2.333776176937165, 2.8271880361341664, 1.9194379520993081, 1.9869584902640314, 1.6516996607665093, 2.60608353922444, 3.1268894768530324, 11.705262584071006, 36.83872415173438, 78.74799036210584, 104.899962025304, 86.37050490225516, 96.98204594273722, 94.09175334438201, 90.67403531843617, 82.53442687373008, 85.03152539653163, 81.21819711500599, 80.0383246329523, 72.11544282974737, 72.32434042038457, 76.0166008241715, 83.84114096241613, 85.53522048457977, 96.04849046276462, 96.60236051005703, 102.70220310457292, 96.34151504885767, 99.53463031399636, 99.58479742850028, 99.58319710146998, 92.3322565324845, 86.0505336330783, 85.98066837556901, 100.1353491506269, 51.252371572679095, 60.36627323396745, 75.93276408410843, 88.73851037794545, 39.22534911863266, 86.19710476167741, 93.71044405045049, 86.65047584041473, 91.90631066599201, 99.63486256137972, 103.82493449795632, 102.79473181693785, 85.68906368747835, 73.78655295218192, 76.81685063146776, 75.30627527544576, 73.59194063371228, 76.1700439453125, 79.73454490784677, 83.72194797761979, 84.58289254096248, 79.21528585495489, 72.21441207393524, 82.6342119709138, 88.47590769490888, 96.2765056856217, 93.71322108853249, 90.59146158156857, 72.28545404249623, 21.834724718524566, 0.3787961884612038, 1.3278984422645261, 1.5596144213791818, 1.0341503014487605, 0.9053244658054844, 0.6776826648462204, 0.851374899427737, 0.36711662647224247, 0.09510285972106843, 0.15196377471570047, 0.05583792331538374, 0.30983923543845454, 4.758690586013179, 25.4661040536819, 47.47722756478095, 46.503456023431596, 87.65563811025312, 118.89801471464096, 36.301575168486565, 13.159800998626217, 28.274717215568792, 48.947567247575336, 55.45710925132998, 59.053573608398445, 55.95119453245594, 31.75618160155512, 21.426058853826216, 3.721820611146189, 0.08739760100481012, 0.3037984176508842, 0.013772467275210207, 0.03628644784311614, 0.07146091906413918, 0.0896486277962404, 0.03606296467384504, 0.00813000180172704, 0.04340559184070557, 0.05126443586402363, 0.04794770799156639, 0.04783459127910676, 0.0502703448517188, 0.025631457589746966, 0.038027899760392406, 0.03796482008070715, 0.0873370340935165, 0.08602524641901256, 0.029533260216515873, 0.040004567483500134, 0.0234786011353736, 0.07481901185406793, 0.06604551247531368, 0.076539775566949, 0.04738541860734263, 0.09734907548033422, 0.09640186138811613, 0.08240437781017634, 0.03709207739560835, 0.015766582650793417, 0.06761723378252599, 0.07061287505371917, 0.10936495772893391, 0.05776771794884436, 0.006994204633238335, 0.07593190778167018, 0.05328994552274385, 0.0468869022123756, 0.048327515232226545, 0.023888463920523084, 0.0539988296617183, 0.07401884067803621, 0.09211438137196726, 0.02689170478392513, 0.026958093963443275, 0.023883518822971853, 0.028761122112853393, 0.05813352493268829, 0.008419343634628722, 0.010862298433728998, 0.05021989030102569, 0.05504058666467186, 0.06801969041266749, 0.07202563311664328, 0.04287500317478853, 0.22060805661303384, 0.06551783111306929, 0.14891859053844406, 0.07647019946166585, 0.04233919745010715, 0.06811528286385922, 0.021958648219644543, 2.772784026399736, 61.02636106552617, 123.28454248366819, 118.6839395953763, 110.652039435602, 83.66782711398217, 71.57884690069383, 51.58134468140141, 40.14527828462663, 33.8662814324902, 68.27420296207552, 56.090999572507805, 39.258300950450284, 39.72929523837182, 13.94408577872861, 0.4557970953324149, 0.12874775596203344, 0.05053536147780476, 0.08198492934987431, 0.5129122902308741, 1.7241512311081735, 2.638486239217943, 2.566169745499088, 2.351855851950184, 0.45747206997006173, 0.7385506180505599, 1.3081909836299959, 4.281813723425712, 15.254666343812021, 43.86138669906124, 85.61741767391082, 108.74270023838167, 90.64455478422104, 100.79916323384931, 98.8559582925612, 94.8916893620645, 86.01811916597428, 88.5390970783849, 84.56968199822211, 85.83490525522541, 75.75166040851225, 76.86093022746425, 78.99077723103186, 87.86264511846727, 89.32415946837395, 98.44240711581324, 102.12410065435596, 105.32982241722846, 100.44564785495882, 104.21046426219326, 102.02979903067313, 103.86742161166285, 96.59275854787519, 88.32128786271619, 88.95400539521249, 104.40339780622914, 59.32328362618724, 69.03151850546561, 85.73664988240888, 99.37123221735801, 50.082791389957556, 90.57625847478067, 98.47451563804381, 90.30289280799128, 97.56818140706709, 101.57114059694352, 108.4540294831799, 105.45489111254292, 90.03333968500938, 77.45658136183216, 79.81047414964246, 78.17191969963812, 77.84822217879757, 77.80297371648973, 83.7509499826739, 87.86983090062296, 88.99846153874552, 83.09585140597436, 76.83774117500552, 87.21556386639996, 93.65214194020918, 101.77914388718145, 95.3323676509242, 94.65447225878316, 80.62345597051805, 27.063585404426824, 2.179617223239714, 0.378930069986851, 0.9104245889090723, 1.2954338423667418, 2.095986652758814, 1.778745966092233, 1.7396476576405189, 0.5296209130075671, 0.15977816265677253, 0.12397355730495146, 0.10992141335361427, 0.2043363184577996, 5.394487669391017, 29.61423016363575, 43.12547552970148, 46.84421193215155, 81.60215008643367, 93.060468089196, 38.22195583774198, 29.365553855896, 52.268132086723085, 71.93576689689391, 78.75363073041363, 78.8443551524993, 82.22248077392578, 52.31628310295844, 27.197349994413315, 3.822568650207212, 0.09853946120147744, 0.20705415326501095, 0.013245678405397603, 0.014129973696394554, 0.058952335027917746, 0.043933495368448, 0.015651671377371158, 0.013252284956134617, 0.08675499879304441, 0.07424343467479752, 0.06714962137442443, 0.06720863312723176, 0.16740841370436454, 0.0066289439658454114, 0.04730347018208235, 0.08215493192115138, 0.06558109465385638, 0.08197818777614063, 0.033487476663844246, 0.06383891878349167, 0.07684506160477478, 0.017345130759020968, 0.02266339356860807, 0.06702590583553238, 0.11082751150693625, 0.09202033641838259, 0.04043020210379074, 0.02850263638632192, 0.04175128625525583, 0.056608443058306174, 0.08132851457283383, 0.05581710870648104, 0.07400218592656237, 0.066562621824203, 0.17928636182219754, 0.21081570626026203, 0.12241741056523978, 0.16516847986607783, 0.20303752363449146, 0.09823440499002896, 0.1499558123008859, 0.3580236531073048, 0.16053603811850473, 0.15751256487302243, 0.16475899054879145, 0.1688083474554362, 0.15455180358502174, 0.15234464298813574, 0.10079423416285746, 0.15008212487784126, 0.18228384936528821, 0.195949126575743, 0.19500766580383624, 0.2083699552402381, 0.2638466872515217, 0.2990085908001469, 0.21238188109090253, 0.223704599324734, 0.1914859749376774, 0.2174618714038403, 0.16435204464341366, 0.15102199218686552, 5.752964846549496, 83.85731681700676, 142.3255551245905, 130.12202601278983, 123.44750911958756, 100.25928820333174, 75.4700969880627, 41.4963504575914, 37.54274645159322, 58.12907488115373, 125.89909245890956, 85.27741093789378, 53.84933756243799, 53.044918275648556, 20.051530907230994, 0.7782442074629569, 0.2029849853246443, 0.26012261127752645, 0.20084176242591875, 0.3650938479169723, 1.651484910999575, 9.05152028606784, 9.310795818605731, 8.882328848684988, 8.553997047485845, 5.627864281977377, 8.78383421128796, 9.659659266471863, 17.89603356392153, 45.030939425191576, 86.9792018398162, 113.28089821723201, 94.72065833307083, 106.65945883720153, 101.78603941394438, 99.16810835561445, 90.96945255033432, 91.01975302542411, 88.07031892961072, 91.7137928931944, 80.6961767135128, 80.13123773759412, 84.24206210720925, 92.12163309897147, 92.6279640197754, 104.16805559589018, 103.74094870782669, 107.80382602445542, 105.23232798422538, 106.2044168287708, 104.82054187405495, 106.73156769044938, 103.3274289100401, 94.75152738632696, 94.29585779866865, 110.01621538592924, 63.859630246316236, 76.44396658866637, 95.13886928558351, 110.14014659389373, 58.46810494699786, 94.63164406438028, 105.70781338599421, 96.61988565998693, 101.41822307340561, 106.7349801524993, 113.05020009317707, 110.21806055499663, 94.59250665480091, 81.30512468276486, 85.52841909470098, 81.47659501721783, 81.26218257411834, 83.79510802607383, 89.5631024145311, 92.76450957021406, 93.73020495137861, 88.58018782831009, 80.98232930706394, 93.56981139029227, 98.7457004670174, 108.17459983210411, 97.76467646321943, 98.6840251184279, 81.94060356386247, 25.633440209973244, 4.284657441800641, 6.792962176184501, 6.76388809757848, 4.250534782486578, 4.237505649366687, 4.210268220593853, 4.148260941428523, 0.8790640749277607, 0.22850990115154177, 0.3320725472463716, 0.22982974807100914, 0.614628725715222, 10.880843131772934, 40.89803603387649, 68.24964892479682, 63.039980396147705, 101.23953557783558, 136.29643286428146, 48.4814327762973, 22.950413496263568, 52.534751276816095, 76.99596958775675, 92.45732522779896, 101.07529024924003, 104.21039365953015, 69.80647686989077, 32.189832964251124, 5.287002959559041, 0.41078057380453237, 0.3075798889321666, 0.15226535288797272, 0.14734942796489886, 0.17745132077365153, 0.15607400496880855, 0.20004941300759393, 0.10515463808851858, 0.2192101146905653, 0.20850510847183967, 0.19211868695434065, 0.17250381770633882, 0.23375585675239566, 0.1498256999278261, 0.10264026857311688, 0.1315177307133713, 0.15159093504471166, 0.17941152526726648, 0.10507447464812188, 0.10908923502410613, 0.18450679137341439, 0.1994597244887583, 0.2168741440700908, 0.2723015706625677, 0.2164087762996074, 0.2523353581707324, 0.1512853272499577, 0.14366883514148576, 0.16214201887769086, 0.2043378046683727, 0.1737784501165152, 0.19965526077055162, 0.2294405141184407, 0.23234469215235404], [0.0984073186954183, 0.049681583299271526, 0.05036540104136352, 0.10022935157101001, 0.10531520245656853, 0.1075917476367566, 0.035119243942561655, 0.03000526039320375, 0.12212190747020707, 0.020813233774876403, 0.03234306004859748, 0.05860874459387795, 0.010114237515916748, 0.01221385756282196, 0.005338991233598321, 0.05471213412801585, 0.026754142205801704, 0.027495575505459023, 0.07823230893982035, 0.06944628402350411, 0.04072855121546215, 0.07307320472694213, 0.11787473133975461, 0.03727414968213247, 0.05762937396103817, 0.09075606917782177, 0.24840396348266836, 5.192668486026026, 65.34214496612549, 105.72839013991818, 102.64200256716822, 95.41861272627308, 88.88427349828905, 55.72945510187457, 25.71625909497661, 22.15765541599643, 38.99436073918497, 73.67104699534755, 50.698525059607725, 43.75685553396902, 37.18229632223807, 9.728220335898861, 0.2657290572120298, 0.032410763068905765, 0.1786818418411478, 0.02561710301726576, 0.19825920342437683, 0.43614733844034137, 1.7331426518578685, 2.011264315055263, 1.7934906458662403, 2.4265770037328047, 1.1373663693666458, 0.921259462352722, 7.000805629837898, 34.21298365439139, 66.2121109808645, 93.38864495677333, 98.76601049976965, 86.5910440875638, 87.00264976870629, 88.7434760985836, 86.85339573890933, 85.7098130256899, 84.24174047285511, 75.55469466793922, 73.48328313519879, 71.8413789810673, 71.6445779800415, 80.12671916715561, 84.77446894491874, 88.39721710451188, 94.08961173026793, 98.62891581750686, 101.93156719207765, 96.1799918451617, 92.16739931414205, 91.69301217602145, 95.41419613745906, 96.2746935506021, 95.25144915426932, 87.1366536232733, 88.56864821526312, 89.09226109904628, 97.1951404694588, 39.28429841995239, 77.8255195002402, 58.89165424531507, 60.69115531060004, 102.15151802186044, 83.35111925678869, 77.91574185894382, 78.8513683503674, 99.42045796302058, 99.4335743688768, 106.35694211529147, 81.64361738389539, 71.41948884533298, 71.34357529301798, 72.02092155333489, 72.35083995326873, 73.74818432715632, 75.98053070806688, 81.76713282062163, 81.35326000951952, 77.90210770022485, 74.2190021084201, 79.47019284771335, 91.07490939478721, 95.63185630306121, 92.42156890130813, 98.77957405582552, 97.033734936868, 96.74157327221286, 44.981097867411954, 3.836630102126829, 1.319132925521943, 2.7546891522022987, 0.8962536170598, 2.905424612183725, 0.8076585516814263, 0.787101409608318, 0.6165818821999335, 0.02744135180217845, 0.08812521599353322, 0.025272330892602765, 0.054014534464166056, 3.42382368541533, 15.420168792047809, 32.151729099212154, 34.12545204162598, 48.60708590476744, 79.62131392571234, 32.36164846727925, 12.043773916459854, 10.965759504225947, 29.211110530361054, 48.646117410352154, 51.724048353010616, 59.14020699839438, 50.05777059062835, 27.258719398129372, 6.037494559441844, 0.8651473216952816, 0.03773233154788613, 0.07080237456266919, 0.12706394833061965, 0.021127429415261554, 0.028154292376711968, 0.051538764288829225, 0.046346369725201404, 0.03763302357026166, 0.03509763643265732, 0.026686205528676513, 0.04690924899712686, 0.06261986222178226, 0.037976602512982585, 0.03235803706751716, 0.046233069151639945, 0.08117558044050971, 0.012840563450158845, 0.06127456203103066, 0.07063830917280528, 0.007408191844250166, 0.03901001298800111, 0.035212024851071264, 0.08196279706974184, 0.06936785194181627, 0.049009816120228464, 0.02724277415132571, 0.07025827593620747, 0.06589552778149806, 0.028559106642440445, 0.06155072523641491, 0.08593689349870529, 0.01630067329613432, 0.027412052769514344, 0.037905927071528095, 0.006905730575278041, 0.10609338690917339, 0.08018199504623491, 0.06373781432968474, 0.03835575474846748, 0.03015199304378081, 0.04531300138501872, 0.05786434844917348, 0.06855733091792754, 0.06424463511775098, 0.05063375398035973, 0.018726201510177027, 0.016071630243752754, 0.030284773318036914, 0.06346362763114514, 0.054787697210427255, 0.06613860747987224, 0.09306808422890403, 0.04073395213532833, 0.07578690265936237, 0.10129862645220372, 0.05883097520939285, 0.012111644196744648, 0.09314970323635686, 0.23871774695092635, 6.649582386016847, 79.0322131495322, 120.85730137363558, 118.22779932329733, 109.88909921338482, 104.52023736892208, 74.83437492001441, 48.11740544534499, 30.545181189813924, 30.882608967442668, 48.07955849555231, 43.99030323951475, 42.60971523100331, 40.16965973761774, 12.87933486123239, 0.5464598320184216, 0.04794021948210655, 0.12173528587746045, 0.21825216770652803, 0.38415586215353786, 1.524483835504901, 2.6816291241876544, 3.4351821339899495, 3.158212789604741, 1.2712577009393324, 1.5135154176142909, 1.6255266651991875, 9.018091886274277, 39.94402539345526, 75.16066904990905, 96.29647839453914, 100.19594976978918, 92.13839730908795, 93.22123819781889, 91.81389962473224, 90.11590557713663, 90.57716846466066, 87.78121671369, 80.81263972866921, 78.54107749077582, 73.93427725761168, 74.42431465271981, 82.47839189344838, 87.22287516440116, 92.6462971779608, 99.28838391457835, 101.25637039061516, 103.87670978423088, 97.30726534320463, 93.71902619638752, 93.9794009731662, 98.56589117357808, 100.03555620870283, 99.09119067653533, 91.89488087930988, 93.7061922011837, 91.97761151098436, 98.4356684838572, 48.109235148276056, 83.5395577646071, 66.07227063948109, 67.02339833782565, 104.78811956221058, 87.7671746284731, 81.73414568747245, 83.31920685306673, 104.29270851996638, 101.67170232342136, 106.72720601481777, 82.900266339702, 74.54244075282928, 74.64536374615085, 76.35306173755278, 76.44707310584285, 78.9253128728559, 78.69797229766846, 84.27491587977256, 84.32789141131987, 82.6247904377599, 77.03738197203606, 83.24787462911299, 96.85423158830213, 98.00883616170576, 92.53223465334986, 100.97949812489172, 101.64339065551759, 102.96591974073841, 53.337142698226444, 5.686193848809888, 0.35477819822488293, 1.3539161364878378, 0.3249818212803333, 0.7726793447809835, 2.020525766476508, 1.936506391052277, 1.3358843879353617, 0.09799605205414758, 0.19465403961798838, 0.043651973378033414, 0.05947990147697349, 3.596774959756482, 19.68798798899497, 32.28937487448416, 32.242935972829024, 45.64168383998256, 57.23075797480922, 28.981067442124893, 25.09546752898924, 27.024989281931234, 53.15639203594577, 68.88717528312438, 67.8333991573703, 81.95550857051727, 69.06911050119709, 34.654768051639685, 8.211130903613183, 1.1254231199141473, 0.024261378285084522, 0.017057156393064127, 0.038819732069368326, 0.050536610201121344, 0.022543659771702463, 0.04373352726801269, 0.03410242310154342, 0.016112219497200944, 0.04009410017921079, 0.015016732917677973, 0.0724009242689898, 0.04316170008913164, 0.024258133902725194, 0.0408253847290912, 0.031970794943551865, 0.03030390827916563, 0.023287042765127077, 0.03909998235382861, 0.040890214919683435, 0.021653973136938388, 0.046503904215510816, 0.08833682479997797, 0.06663070405803381, 0.050260289947712616, 0.03468869103779716, 0.021032206601493304, 0.05192340554429158, 0.01581773721432734, 0.001409919467762173, 0.08222607850667932, 0.04243285935972968, 0.09639716526914029, 0.12990326169998417, 0.1716647522463914, 0.1599988113007238, 0.34515138415078966, 0.1542919618828643, 0.17109476750896824, 0.17594082521334772, 0.09636905750319844, 0.2226405185196669, 0.11784923593363456, 0.15500016420358612, 0.14495318154654196, 0.14000998389336372, 0.10236918836111024, 0.09432490509484084, 0.12953904817902273, 0.12440139442802438, 0.1591776110111706, 0.1518884682727437, 0.3946012564964833, 0.13902379890843747, 0.1781728223807389, 0.24312267590674663, 0.2686677092025357, 0.23685387035291042, 0.16536441451359182, 0.5556458391008839, 10.05145501705908, 104.40692793938422, 141.06542310407087, 128.67667967273343, 124.07226424063407, 117.51788954580985, 77.54505434343892, 45.73274950827322, 35.078438943432225, 55.43461053602157, 108.22679088961695, 70.12676977342176, 66.37524235633113, 59.652460698158514, 18.88351575020821, 0.9755678030271685, 0.26197761657737917, 0.4347781861020673, 0.31124561964984865, 0.4751099267553899, 0.9933739540077026, 6.516007050391167, 9.90266578812753, 8.754910653637303, 10.360146530212896, 5.744064008035968, 1.3989840471936812, 7.6593593243629705, 39.43061851686047, 74.92942179402998, 99.84276386999316, 104.36597839478524, 96.90963114461591, 95.59795918003206, 97.33320005478399, 95.06191238280266, 94.49209397838962, 90.5092800817182, 85.93730265094389, 80.52994666561004, 78.16238834011939, 78.68180428781818, 87.55408010175152, 91.21245122724964, 97.7562512120893, 101.61089774101012, 102.93116754101169, 106.80022485794561, 102.74041483479162, 100.01883122228809, 99.48112918484597, 103.58148867084135, 104.78772732519336, 101.88340833110195, 96.14839323105352, 99.59903563222578, 96.65504578621157, 105.02121817681098, 54.87461766889019, 92.39364162568124, 73.91617944163661, 71.66407215979793, 111.37832903092908, 93.37901161563013, 86.43580452088388, 88.20631534822526, 109.03839988093223, 104.62321527542608, 112.02670466515326, 87.24394613696684, 78.56229751340805, 79.08767546376875, 82.00101590925648, 80.57073147066178, 84.96779472597184, 84.49360370635986, 90.55701532671529, 89.08350636882167, 86.0593197422643, 82.5620246702625, 89.12254179677656, 99.62573912835892, 103.08341826162031, 97.51011463903613, 106.14058417658653, 105.93434595292615, 111.65761747667867, 49.952505942313906, 5.586145952824624, 4.090639852708386, 10.604121877301125, 8.40711114868041, 8.502318839873038, 6.040298563818778, 3.0615861810022786, 2.465619540983631, 0.10142378223639342, 0.3191801148556894, 0.1826670925102888, 0.3250527610221217, 7.081359836363024, 29.56240192536385, 50.5496475773473, 50.82056568514917, 62.76795617995724, 100.2900552749634, 44.04005850515058, 23.969480568362822, 26.039281968147527, 53.34841951247185, 79.03542164833316, 87.43582848579653, 100.29105155698716, 84.3792038579141, 41.35017156600952, 11.752125101704753, 1.8333739186486893, 0.18624271596631697, 0.12355022477887331, 0.22857299615298549, 0.08125175256282091, 0.09359220328230052, 0.09780108267741819, 0.17647463527898635, 0.2623317637030156, 0.08746428129773948, 0.12967311356577182, 0.10381964561078819, 0.28388812957752135, 0.06282153486784908, 0.16589313775541323, 0.08265921695818824, 0.146841389097033, 0.10862684733564816, 0.13492262381459438, 0.15080941810963616, 0.1965658273547888, 0.11999092665651154, 0.2144733470894637, 0.15117294215146573, 0.16116493501730506, 0.21158536415426962, 0.121134466101085, 0.1866367609510499, 0.11146498092960928, 0.11702494064886725, 0.17175383295022673, 0.18733111240210074, 0.18005997272989444], [0.0100218252872207, 0.056048750712145726, 0.02537029438592013, 0.08041146136219464, 0.04400302167801608, 0.051469283944536606, 0.04355294119206168, 0.04386395373712144, 0.03282243573677636, 0.05010597302668518, 0.03880148002457234, 0.045600590791793606, 0.0681470678518376, 0.022268774017931956, 0.03209787552365132, 0.06205404500266718, 0.10428879785561755, 0.038167902328554666, 0.04425844305285043, 0.03546563442796469, 0.08686951361596586, 0.026584660574313135, 0.06600619684303961, 0.05534435584840756, 0.08739359436496612, 0.1626734693925227, 6.1487060112337915, 89.06200393553704, 110.04450351961198, 102.95870257962136, 92.71890024985038, 74.3768539736348, 44.426635542223536, 33.30978339718234, 23.906263728295606, 52.44121843768705, 92.68790568074873, 53.01754405421596, 56.490724394398356, 28.28125580664604, 7.195808714435947, 0.03575481729762208, 0.031006114046660163, 0.10259349124446031, 0.24065915164687943, 0.02554347047642354, 0.35123111920491346, 2.014990811867099, 4.1120805086628085, 2.549707312737742, 0.2672615394957604, 2.105467756909709, 6.472867842643492, 31.967973901379494, 65.17171013739802, 87.75816886655747, 92.37846205311438, 94.03989176596366, 89.98423161045199, 90.24964271053192, 73.76814134659307, 73.37282134640601, 78.34412743968349, 81.1851707581551, 81.609555521319, 80.58011378011396, 75.59270243490897, 72.43357058494323, 71.61083775181925, 80.60185940034928, 88.10788739112117, 94.78064706248622, 94.4681518308578, 94.54015085774084, 93.83754453351422, 88.35671471011254, 82.18597135236188, 81.50103138339135, 85.5834734824396, 90.63750236265122, 93.86712704935383, 95.01394964033558, 93.8029884522961, 93.12647373445573, 94.7412193975141, 75.67906518136301, 34.00870661581717, 45.16098953062489, 89.8265209505635, 90.1312812682121, 74.40758966630506, 68.43072906617196, 74.82121929045647, 78.33956180080291, 87.60128190440517, 82.62142504415205, 76.11961010963687, 71.36230853296095, 73.81772795031148, 71.77247078188005, 75.88501314963065, 71.51603406475436, 75.73404896643855, 75.76865996083906, 78.47984929238596, 73.03283814461001, 73.97495223629859, 77.30047102897399, 88.22912000840711, 95.3431777031191, 95.38091874891713, 93.9358469747728, 83.29881052817069, 87.49918260881978, 98.78346504703646, 80.64433082457512, 28.15122727424868, 2.4615422371895086, 1.3229924151974342, 1.667992451017903, 0.7470549907415145, 1.3134241608842727, 0.9233209743134437, 0.15743948008504607, 0.030575202995791074, 0.0156211820355947, 0.09181928430353442, 0.2045079527963554, 2.421987585483059, 13.069253083198303, 31.732868994435957, 41.82286424021567, 43.2766632879934, 57.280442637781945, 47.24655689731721, 36.43381003410586, 15.53836843659801, 31.919948400989657, 46.822474156656575, 54.45357084274293, 60.209696139058764, 62.69910289395241, 51.195167726086034, 20.37330254431694, 2.9493473133733197, 0.16668397031964796, 0.10222142532227502, 0.03672445478338388, 0.013951718442953162, 0.057420411988371806, 0.0698075021406816, 0.01475321112065426, 0.02998039892484104, 0.03883298539045838, 0.036282824247234294, 0.024030352980198882, 0.01781912276431197, 0.010363284081611182, 0.04769582977338184, 0.02567650930535409, 0.07637739557051852, 0.03762672632752407, 0.04047629378375508, 0.1211954773433747, 0.05125880894821979, 0.06496217221983018, 0.01824277896253813, 0.08605226634010192, 0.0335696357632837, 0.054884212797567736, 0.054868224542588, 0.12862824624584568, 0.05123280792406971, 0.0666872566686042, 0.017158929258584976, 0.024484428614678404, 0.02318112344871606, 0.03882604080342478, 0.03383205918174598, 0.04626318406794341, 0.05156325228932885, 0.02470991893431112, 0.10538901502807295, 0.02918335913319982, 0.038222941915474595, 0.028223604181661244, 0.015623864300939587, 0.013592958510402712, 0.05182593234724576, 0.021198277226499012, 0.053412236138096744, 0.08045453848617692, 0.025315678062578364, 0.010445259319948814, 0.011554854366207316, 0.03980034376464544, 0.07114142975619725, 0.04596791462972761, 0.07253323531439228, 0.019973764203548915, 0.07162123828405334, 0.03380641438848069, 7.821487553658025, 100.61113265252884, 129.60316704165552, 120.57363556277369, 104.58487018462151, 86.14061478645571, 64.10133454107469, 58.758999686087336, 28.218386096339074, 34.1182231133984, 71.79920565697455, 54.85919098700247, 57.931359967877796, 36.38521579004104, 11.319769101758158, 0.19339129689239687, 0.11819864097501963, 0.04886031023136551, 0.22181141220273512, 0.04610895141658764, 0.4039521257002508, 2.247840968831893, 7.7888862836745485, 3.5248779144979294, 0.5288494931113336, 3.292219585949375, 8.467774525765451, 36.93196281310051, 72.95526935208228, 93.19029854189966, 94.99964083394697, 96.10747506541591, 96.35001874739125, 94.83213209336805, 77.53867656953874, 77.28848426572739, 82.00664843282392, 85.3545561144429, 82.8020658800679, 83.81051509611069, 78.37992298987605, 77.8310186632218, 74.79171522202031, 84.03133669207173, 93.33290807662472, 97.52916166859289, 99.56758606818416, 97.63417920758648, 96.27542311145415, 91.27191435906195, 84.55411018863802, 86.36097354273643, 89.89188332711497, 94.78000379377796, 98.82384192559027, 97.55671239668324, 96.59287621898036, 97.78684569943337, 100.22992534022178, 76.66441163709088, 41.32206386135471, 53.02463962185768, 93.98359006451022, 96.61463752869638, 79.01458601797782, 72.57279119183941, 77.78923757614629, 84.3913318264869, 91.17136047732447, 87.52702359230288, 77.79851790397399, 74.76820453520745, 78.20774662879207, 77.31529758822533, 77.3111947890251, 76.88127948391822, 78.4975705608245, 79.776137721154, 81.38268563055223, 76.85943188205843, 76.54479503631592, 81.36505849899785, 93.15738201141359, 100.62993649513491, 98.22855164927822, 95.8362510127406, 89.57639140467491, 91.52078874649541, 105.93840952842467, 88.48665498918103, 33.89602868787704, 4.225971919874992, 0.3595925398891972, 0.9226700447259412, 0.176036877317294, 1.5626280274121993, 1.6433469734845625, 0.09269886815379705, 0.09489669013888606, 0.016469589937778733, 0.070269430176385, 0.1644923306641079, 1.9090075117926446, 15.420993470376539, 33.57373537555818, 35.39008694310343, 32.43657946586609, 39.584642148786976, 35.89539020292221, 38.36017231787405, 30.324079144385557, 46.3497854048206, 64.8185673836739, 72.93408070841144, 76.20255254930066, 84.22600392372378, 65.5652807604882, 24.906999603394542, 3.1067079017239236, 0.1073706086965338, 0.04877232120282227, 0.030577911116603403, 0.030972191673373024, 0.02421004081805868, 0.06065114649132856, 0.07978058029567042, 0.035458402557959484, 0.04535985532246771, 0.04383597620612672, 0.02930074487061751, 0.06456064255607706, 0.02773510630152399, 0.02755834108909532, 0.02965561786456214, 0.10412814921789593, 0.025305130947080832, 0.04261398169722769, 0.06800345700955199, 0.0700467897038306, 0.03663078521288211, 0.031787156007222594, 0.03996468877660171, 0.09515289292340318, 0.06254547891477424, 0.06658331385903782, 0.04048963903539604, 0.06205206849582254, 0.03302367554316598, 0.07199045435916032, 0.05961624980573693, 0.14397087296651256, 0.09067013709535522, 0.2079898836992441, 0.1300834762232919, 0.18382075963722122, 0.15020831488072872, 0.16350357162375606, 0.14295315580262294, 0.12988509009442023, 0.07395788306190122, 0.10335960981225777, 0.16462319380333348, 0.1657438885060049, 0.21113308116553292, 0.206258233876959, 0.1470047343642481, 0.2558417732436811, 0.14954404004158514, 0.10633108867031914, 0.0956940191287187, 0.2293133741665271, 0.17912364474708037, 0.24491677721661909, 0.13232779208450549, 0.1538086829767112, 0.2690484549009031, 11.562813866523005, 127.38064227565643, 145.54167901315998, 131.57669190437565, 121.60636425018312, 98.28337069480651, 67.16706691249725, 52.49501766697053, 36.140353987293864, 77.7013058816233, 127.95448503186627, 74.9474411626016, 88.5096400783908, 49.2921749238045, 15.091015254297565, 0.5235044670201118, 0.2686925610947994, 0.2928451070141408, 0.4123410336192577, 0.17598792429893248, 1.9076468170650545, 6.921437940289898, 14.15945331896505, 9.09344159787701, 4.480110618375964, 3.9499623304413216, 7.697950543895845, 37.66463018232776, 73.99967885786488, 95.75595225057295, 97.38508516742338, 97.21444637544694, 101.13151350329, 101.84441997158913, 83.48575069058327, 82.35269561890634, 85.98703830472886, 90.91752036925286, 90.88316040654337, 90.67672606437438, 82.13975798699164, 80.43095388720113, 77.57000061773485, 89.34774860259026, 97.31899323001986, 101.11742434963104, 103.98242550511515, 99.63345050811769, 102.69588024385514, 95.8910700582689, 90.82366589576968, 92.95203024341215, 95.67249205804642, 100.45102150209489, 103.40414262587025, 102.8204704100086, 102.18306956752654, 100.25880182943037, 104.75008041627946, 79.57702252172655, 49.52057846130864, 61.68123606712588, 98.17871401386877, 101.4676998507592, 83.0830095660302, 78.53756304710143, 82.59555309049546, 89.46768683771934, 96.75847868765555, 91.4282835683515, 83.02916326830464, 78.7812912848688, 81.25093321646415, 80.64201662617346, 82.75278522122292, 81.15854570942541, 83.07607481556555, 85.2251414329775, 87.0344288118424, 81.81470332607147, 79.61401831719184, 85.66551377696376, 100.687391373419, 104.65872841496622, 103.95850689180436, 103.06499096655078, 95.40260161122968, 95.39342326502647, 112.79731704342751, 89.31163926278391, 30.959350139864032, 2.8959726806609862, 6.963637740381303, 6.096470336760245, 3.4970974826043655, 5.1788651750933745, 3.498151864736311, 0.4070337909844614, 0.362523960009698, 0.2983616755133675, 0.23922708816826346, 0.3782192936107036, 4.677044489691335, 24.241822496537242, 47.81504954061201, 62.493245140198745, 60.396298977636526, 75.83967055043867, 68.38743394420993, 50.10145010486726, 22.38915958712178, 49.776505270311915, 75.09261592741936, 88.15574815196376, 93.31076237463182, 97.23155575413858, 76.94137803969845, 31.97921149192318, 5.750199085281742, 0.5762943601416004, 0.15352734484739844, 0.15209004132738038, 0.0935266797821368, 0.08885831617179418, 0.16038208508924132, 0.40260849941161375, 0.10349115476973596, 0.1805403251801768, 0.14894509718062418, 0.12700008724125164, 0.13004550890576455, 0.0839260122888992, 0.11230678132344639, 0.08798744274123062, 0.236309212482264, 0.14292349287819478, 0.1845353204877146, 0.13734819607869272, 0.11743785437917519, 0.12555117748918074, 0.13453699047527007, 0.1462337587990107, 0.1952269354895238, 0.14252269099796974, 0.23477737371238971, 0.26182179429358055, 0.21064960307651953, 0.14151767557186468, 0.13920695520937443, 0.20781379072896897], [0.032022879346303885, 0.06545894193432986, 0.05336955737983508, 0.05283519190045134, 0.06366471038951028, 0.07258116177493527, 0.05951342548454001, 0.049552083796551155, 0.05399436719955937, 0.016763034171514937, 0.06184013410200996, 0.03525293777666746, 0.020930389685916807, 0.07015090105274031, 0.07020837296881983, 0.023221561399799202, 0.06955448628192948, 0.059746113200221336, 0.02878025707398211, 0.058312747372134086, 0.06697587263319763, 0.08953217477087053, 0.07944609098617109, 0.024137905979108427, 0.06558145471518079, 4.263623241455325, 81.25949182818013, 116.31606748027187, 105.35770262441328, 104.60946344560193, 75.2517935537523, 57.03680853689871, 30.939222497324792, 25.527045919049172, 82.7898359298706, 70.24970469936248, 44.96702048086351, 46.85152715252292, 32.658973932266235, 9.787612865048072, 0.24072575533101637, 0.03852566921963327, 0.10820909192965877, 0.17868273050313999, 0.26717310230578145, 0.24631114916936045, 1.1524364832908878, 4.175510137311874, 1.891155211675552, 1.2413384741352451, 4.961324151485197, 22.678889382270075, 57.01294483677034, 91.25959027198054, 87.37192523094916, 90.72725403693416, 88.77057183173396, 93.81240998545002, 91.2820105398855, 87.39197638727005, 83.6599588394165, 72.42086995032527, 68.02212792058145, 70.83047436129662, 71.12658977508545, 71.25795779689666, 68.45134504379766, 70.93709222732052, 69.99749629728257, 83.41520294066399, 91.27429916012673, 95.62636498481997, 90.95101741052444, 93.06186445297735, 89.12447160290134, 81.82849437959733, 68.22405938179263, 73.05692149746802, 77.12543133766421, 87.5359744410361, 86.02979998434745, 96.74454642880349, 86.87998940867763, 98.73395689072149, 85.47663596368606, 107.81620502471925, 40.04709743684338, 36.536348635150546, 103.2477028139176, 77.38579042496221, 87.34066394067581, 63.83380928347188, 74.79171522202031, 66.93933410029258, 73.26638390941005, 64.945585496964, 73.6515292813701, 72.94369836007395, 74.84288646328834, 78.1100639220207, 78.21528542426326, 74.75452330804642, 72.3683572584583, 74.25136950708206, 78.33972654035016, 71.73604765245992, 73.07699618800994, 77.22655788544687, 86.44807369478288, 89.97023659367716, 91.56215406233265, 77.99900593296175, 74.57073673125237, 80.57696803923577, 83.49309336754584, 89.68876731011176, 92.26219515646659, 73.21857021700951, 25.752376279523297, 0.37257809792795493, 0.5690039610189777, 1.1801118692082744, 0.6088754666909095, 0.015242727897730807, 0.061176736433539665, 0.0384392851452914, 0.07312144528353408, 0.06840475684692783, 0.0357493972255578, 0.37502240870268116, 6.187249672028327, 23.379773785991055, 37.36045429783483, 50.78929655013546, 71.83569154431744, 59.76253417230422, 30.20847708948197, 18.081087066281228, 23.31398779346097, 44.47351963289323, 48.57890759744952, 68.6427096397646, 67.91839691900438, 59.66911900428034, 36.119887059734715, 6.070816564944483, 0.42479468149042904, 0.10403677025028776, 0.04115238935957032, 0.0327850736287092, 0.017318639438599348, 0.027280670605720054, 0.012313590719244413, 0.08267729663320127, 0.058203744551827835, 0.050058395136147744, 0.018029392832109047, 0.007831132707877025, 0.04445979394198907, 0.04822599326050089, 0.08725042019279734, 0.05042546999550635, 0.10257669093628084, 0.07026730811283474, 0.065796296412666, 0.058482389882086754, 0.010708186441221306, 0.050364378313984604, 0.04377021521870648, 0.021192414738658457, 0.09451365383762507, 0.037702128531471375, 0.02938588979774185, 0.04409747265820061, 0.029375133923284953, 0.0433150019436594, 0.03593800424207603, 0.06206460552470339, 0.04655492950170752, 0.06005357492775206, 0.03351006093585203, 0.07624836338143196, 0.02256284644376607, 0.024475746923276497, 0.021184162056494146, 0.017979549236535546, 0.01968261440314593, 0.043241442181169994, 0.04205656080176273, 0.03901348719673772, 0.04167008093528209, 0.02225867697908994, 0.08781917918954166, 0.0692355945225685, 0.008158013806678355, 0.08385719461066109, 0.044908231169345884, 0.03791328917648043, 0.01856176073723022, 0.051274391176599654, 0.05077302110411468, 5.772798311325812, 99.81602899489864, 135.7264183413598, 118.52258113122757, 117.40919282359462, 87.07406044006349, 77.97162778915899, 47.52719463840608, 33.18474215845908, 52.36503031945998, 49.5279799738238, 45.73283187804684, 45.552167507909964, 42.37500844463226, 12.88472027547898, 0.023932828072218165, 0.015366978740559952, 0.019299221871000145, 0.19204768592551832, 0.26672294904147426, 0.5654840015115277, 0.5027170082734478, 2.1710823908928902, 1.7685958526788221, 1.0285958575625573, 7.813052986898731, 26.08564046121413, 64.22899984544324, 98.63037493921097, 93.12602658425608, 92.71556623520391, 91.3180963454708, 93.36275731363605, 95.82972418877387, 91.92413391605501, 87.71794888281053, 77.63599841825425, 70.93436225768059, 74.96493493357013, 74.34804024234896, 75.90478974003946, 74.77938329019855, 73.50973559964088, 73.39400999007687, 86.84929293970909, 95.35965165784283, 98.63133199753301, 94.60332455173616, 96.36716734978461, 91.51709387379309, 85.6275373889554, 71.9429526790496, 77.15188380210631, 78.04492119819888, 91.35051081257483, 88.27580405819802, 98.73437266195975, 90.0565444269488, 99.4571948820545, 88.1565090917772, 111.45176364529519, 45.72576376699632, 41.817168958725475, 107.62165546417238, 82.00424794227847, 91.98935508728029, 67.54588942373952, 77.65211151492211, 70.678678635628, 77.11524886469688, 68.3588477103941, 76.49764030210434, 75.09591071836411, 80.43696295830512, 81.41716326436689, 81.65338408562445, 79.10517707947763, 77.5272624723373, 77.67981129307901, 81.13219522660779, 74.62284149662142, 76.4054096898725, 82.36090121730682, 89.16191454856627, 92.11784408938502, 94.54361038823282, 82.22291223464474, 78.25144967725201, 86.4026055797454, 87.92166110007994, 92.42495782913701, 93.96255047090592, 82.62626524894469, 33.56769100312264, 1.0231047844694507, 0.445687584578991, 0.4576460638594243, 1.0760181709643335, 0.2069746486602291, 0.18037360912609487, 0.09721150907177119, 0.1475836057215929, 0.09996648382155165, 0.05776818526247817, 0.12361673653245935, 8.15656485096101, 30.71596314830165, 38.84141968142602, 37.70130434343892, 54.486522674560554, 49.12467795033609, 16.758881576599613, 36.28446578979492, 40.42198973317301, 59.35466650993594, 66.5127920335339, 81.4889269490396, 83.51560777233493, 74.0603736139113, 45.41122105813796, 8.54714858916498, 0.3414142540385646, 0.03700957738704259, 0.020893289962963715, 0.02746740453726342, 0.0678886663949778, 0.03212481500550864, 0.07496708132807287, 0.011025339180994178, 0.044224984162757476, 0.05127562840859737, 0.03120456912344502, 0.021703236420909246, 0.08392990401555454, 0.01924121369337363, 0.06455527227972785, 0.03555636988171647, 0.09169841095084146, 0.07569171623477051, 0.07405285498187428, 0.03152113006029639, 0.025149605522352843, 0.037916801689613255, 0.03925478574068796, 0.025493701574422663, 0.11729176907289414, 0.08491595110465443, 0.06777006066254071, 0.01833650024397479, 0.007166716142467434, 0.10321511030797997, 0.16709111540788607, 0.14266458580330496, 0.19062061734016866, 0.1828001466609778, 0.12862872122035873, 0.1970610265890437, 0.15190129258459614, 0.11670535174949516, 0.11722337274301438, 0.13400477387251394, 0.13219783292903056, 0.11721273944262536, 0.16844030349485337, 0.25699283567167097, 0.15672327980639475, 0.08889907971024515, 0.19877406047476878, 0.13659805810499576, 0.10031340673806206, 0.23478385481622913, 0.11872824521795397, 0.19919180821987892, 0.20408746245647633, 0.13565072909958903, 0.15163919858394131, 10.067921127042464, 119.881635327493, 145.31604859136766, 134.20342476137225, 134.92333658279912, 101.62879159373622, 81.36749036850469, 45.80827082357099, 41.03102399456886, 110.84941310267295, 91.4719944615518, 64.08853584720244, 74.32227811505719, 52.25790646768386, 19.110687663478238, 0.7380933554903154, 0.24223936120829276, 0.22899955390922486, 0.4024870897973738, 0.6136226990530568, 1.5882885408016945, 4.671891475877454, 12.902760236494004, 7.778184096659384, 6.02567792900147, 9.072958000244634, 25.36488336901511, 65.81222534179688, 102.2364216466104, 99.05264162248181, 99.99893696077409, 95.88391565507459, 94.94644564967003, 101.96109479473483, 97.72952418173514, 94.06865058406707, 82.42332181622906, 75.50270757367535, 79.49401732414, 78.52005358665221, 80.56635410554948, 78.80820658899124, 77.3503008196431, 77.5641719756588, 90.79391864038284, 99.64609622955324, 103.5766641555294, 98.37316159279116, 101.21095718876009, 98.22444100533762, 88.58036041259767, 76.7769052136329, 79.05126017908897, 83.25526437451764, 96.36613968879946, 92.9519517960087, 104.01445557994228, 97.65459122196322, 104.00730902148833, 94.5217235626713, 113.31757237834316, 51.259169040187714, 47.420306128840295, 109.32256775517618, 86.7753170382592, 93.32924458288377, 70.64884508809736, 82.16850111561438, 74.08019727276218, 80.59846262778007, 71.34584242297758, 80.43976353060815, 81.05875276750135, 82.94950777484526, 86.50454798052388, 87.20828394736014, 84.26944025101201, 81.25750710887294, 82.23310255235242, 86.11176183146816, 78.93156513091057, 81.24727756746354, 85.16155196774392, 95.69557912888067, 97.10618895869102, 100.92321211291899, 87.67514797949022, 81.87156984882971, 88.88284575554633, 92.64186489966609, 93.42332655383696, 96.43594218838601, 82.21254148790914, 30.475421836299283, 0.67368405360368, 2.394832036187572, 4.051419092762855, 4.017628854320896, 1.2813655262993229, 0.41680444572721764, 0.2383122412908462, 0.3663401503957087, 0.16731507355167022, 0.19757007669296958, 1.1789287843050495, 14.878959175079101, 42.37032905701668, 55.98409537346133, 70.28925003543978, 86.9164203828381, 74.49228932780605, 47.44205959381596, 32.88114286238147, 39.59769971909062, 68.69696386398809, 80.34494415406259, 98.54179997597971, 98.85529148963191, 86.9773583258352, 54.36665504209457, 11.506080704350627, 0.5478209557552491, 0.20924950078610452, 0.1763630315901772, 0.14340989742307894, 0.24924451515318888, 0.23141127530365224, 0.12801719153480184, 0.16739404189490503, 0.19756851387360405, 0.16576429708830773, 0.1280502788722515, 0.07415999237808489, 0.11174608157166552, 0.12632153252319944, 0.14391119471721112, 0.140245525286563, 0.17607584054912293, 0.1303372045438136, 0.16712303063081158, 0.145548845551187, 0.11884292091933951, 0.13936872233546552, 0.13888760379725887, 0.08301558573880503, 0.21309674837656561, 0.09620940477977838, 0.11345474109534295, 0.14847661909316817, 0.09225793858809818, 0.1672864678285776], [0.03932796628965486, 0.030618829787859035, 0.037745159690178214, 0.0808151284112565, 0.02203169853366431, 0.05684726330782137, 0.041475326063171516, 0.07762808007218185, 0.09883152456173012, 0.02822134805272424, 0.05316251445741904, 0.020596450044503136, 0.07344157044445315, 0.051657883300175594, 0.05899381102813829, 0.10017998486516938, 0.025593235547984802, 0.03451093182628674, 0.046373765029373674, 0.015467933807221633, 0.006787171765726301, 0.06512270594436316, 0.057170832033960096, 0.032192780410930995, 0.3371609338829595, 72.03128445533015, 121.50855602756624, 105.6133548675045, 105.45846831414008, 73.35228381618377, 61.98119932605375, 22.623470214105424, 24.55785962843126, 83.22022191939816, 75.77900717335363, 67.51654225011026, 61.954319323262865, 43.61569727620771, 16.041824260065635, 0.7176519233372904, 0.1178803850686358, 0.175508797589329, 0.03960923547105443, 0.042537920657665505, 0.1934074460258407, 0.28063299134373665, 0.07861274820301803, 0.6493358181849603, 2.0815430148955314, 10.492835410179632, 32.64883852774097, 76.68077576544978, 94.82320477885585, 85.8488610482985, 88.74415859099358, 92.20238685607912, 92.17887616926625, 91.8176886343187, 88.33757354367165, 94.20323494941958, 83.19178473564887, 77.03280064367479, 74.80756159751647, 74.31790859468522, 67.52983124025407, 68.38216227869835, 67.61009077872, 68.09019673255183, 65.46068291510305, 71.48492966928791, 82.00712696198495, 87.57305652864518, 85.47045430829449, 82.11744754545151, 73.35735936318675, 69.56273294264271, 64.8306365166941, 70.17851368073495, 72.83697851242559, 75.25347232818604, 77.0989239600397, 79.95377402151786, 80.44419580890288, 82.24852531186997, 75.63067097817698, 91.1593266456358, 70.46639211716192, 41.9888864024993, 99.64721802742251, 81.2748832087363, 89.47325660336404, 73.82767508106848, 74.52833590968963, 76.60916897558397, 77.58288952612108, 73.48733886595696, 70.56551825615668, 68.30015336313556, 72.25218449869465, 77.57780613437777, 79.99309186012515, 76.24280391200897, 73.99148894894508, 69.05815139893564, 73.06622535951676, 68.20555363931965, 69.61448469469624, 71.58264375502064, 75.45094797688147, 73.0856881603118, 73.09542348307949, 64.76293640751993, 69.8505800001083, 80.22535893224901, 95.38407233453567, 84.50821061288157, 80.7506270562449, 95.37686301815896, 100.40361573619228, 54.68250390022032, 4.9960008455861, 0.22089094223995365, 0.5895400203524098, 0.4452593107858012, 0.11176225368774707, 0.035670333121332436, 0.19152126094746977, 0.13019363966680345, 0.08332277933556227, 0.07063703746685097, 0.8977640972983454, 8.442724308659955, 24.9837270475203, 33.82862275646579, 44.61302265044182, 58.32664074436311, 102.00156581017279, 27.56384841857418, 17.685951417492284, 20.262060203859885, 29.214054269175378, 56.98722585555046, 62.92758880123016, 74.94573885394682, 68.3130971847042, 51.1623727890753, 9.998388290405273, 0.23316002420840726, 0.04786717682896603, 0.03591013779383033, 0.03931642134463595, 0.03863898894539283, 0.05696215351382571, 0.03174645758624519, 0.023979860125109557, 0.08128539914445532, 0.03145099662604832, 0.09315822979495411, 0.03610908316688673, 0.022751378766711683, 0.08152192879107692, 0.009586171194490407, 0.05688887720386829, 0.05334776600882892, 0.04561207828021819, 0.04531200164027753, 0.04523692119325842, 0.008590575777024271, 0.01901838935971741, 0.0016302360604787548, 0.020050681346366485, 0.0109947387564687, 0.013040042211932522, 0.046078047429722165, 0.06393219764915205, 0.051711666502899704, 0.019794415359595613, 0.04173654672359267, 0.021324557244717594, 0.039277860308967294, 0.05528234103093705, 0.08171399469457327, 0.04854224201652312, 0.03555015307821093, 0.02604232203485745, 0.06353098974232713, 0.05060286148481312, 0.05603218023034354, 0.04649396039425366, 0.05988602383783268, 0.03352162120262942, 0.07091640675019834, 0.021997218831412254, 0.04213200131010625, 0.07771263319638469, 0.02834348353527246, 0.02522091681678449, 0.027253911154524937, 0.05566877493214223, 0.019240909173423727, 0.5475905777946596, 88.8700274498232, 140.16989892528903, 118.75543655887728, 116.88197135925294, 90.79379312453732, 85.54275928005096, 43.094575097483975, 36.17423542084233, 48.10753283962127, 78.88714821107926, 61.50744761190107, 49.49582830552132, 49.37921624029837, 20.172804709403746, 0.6793076292641702, 0.10922504709132257, 0.22595861385906899, 0.15558913259977297, 0.09779273997992279, 0.5195884706993257, 0.28157414568047373, 0.170131457909461, 0.9601807125633763, 1.1825297652713715, 12.999984025955202, 38.3042706981782, 78.75188919805711, 99.82017101780062, 91.48892341121551, 96.23113955220869, 95.53168681360061, 97.18306741406842, 92.8505349928333, 89.31595386997347, 97.37259634079473, 85.86225986480714, 82.50055328492196, 79.26917137638216, 76.2965560728504, 71.28064478597334, 71.20819076415032, 72.20698310482886, 71.64504081972184, 69.42067253974177, 76.64428203336655, 85.30766025666269, 93.06927773260301, 89.49423343904557, 85.3494256542575, 77.89827162219633, 74.29260146233344, 68.56301492260349, 72.54202412020776, 74.12292757341939, 77.71307299214025, 79.43911983120826, 82.41745395045128, 81.91503755507931, 86.45613808785716, 81.89184065788024, 94.19723372305594, 77.3049895994125, 44.418488779375636, 102.78494158098775, 85.57359695434572, 94.15418963278495, 78.4545264705535, 77.0793434881395, 80.2931139546056, 83.02972024486911, 78.70055321724185, 72.75531476543796, 71.62469156326787, 75.9394556476224, 81.08944923646989, 82.3517228711036, 79.30711638542914, 78.76365630857407, 73.97635644482028, 77.20274125376056, 71.4591989209575, 74.34745973156345, 75.12848208027502, 79.8736870673395, 77.06478365005987, 75.45442319685414, 67.85207748413086, 73.25072580768217, 86.36503711823495, 98.35114140664378, 87.20042351753482, 83.72416803913733, 97.00194804899155, 103.46020898511334, 63.68305298589892, 6.394328263498123, 0.3472792393257541, 0.5952750771276413, 0.6790989469135962, 0.05242127076452298, 0.06980397047535067, 0.235291326779031, 0.20566221747186877, 0.07526055429010622, 0.12586309784843078, 0.7035514928640858, 8.767774066617413, 30.219810778094878, 35.93502183114329, 33.697309647836995, 41.31054386015862, 82.95940783716019, 23.561083386021277, 29.52317234008543, 43.58031357488325, 42.53957540758195, 70.93200099083685, 76.27059782705, 86.97710729414418, 84.78326289884507, 64.59927551208004, 13.395094179338026, 0.38297581095849315, 0.02094653881936064, 0.058036109192236784, 0.04551781116113548, 0.09750112095066617, 0.09299105408811763, 0.026769054107247826, 0.04686561645939947, 0.06636320147663355, 0.029231377524293722, 0.04030880398086963, 0.02454543219608886, 0.03540066634154609, 0.012620806341029465, 0.04324454866770295, 0.011523070335838825, 0.06510650318476462, 0.04297889235820021, 0.012698211864898763, 0.07994232443912376, 0.0628600346164838, 0.09126293593116346, 0.056400197377849015, 0.019789451109846274, 0.027916845339801044, 0.051986879759257844, 0.06283235585977955, 0.006242294123606577, 0.02115177377427538, 0.12435743630292917, 0.1423713273458904, 0.10225793707274622, 0.32781009532270894, 0.15864288164002283, 0.14980797265325824, 0.10357870329772273, 0.17865679076602384, 0.15848689081688083, 0.1342210558152968, 0.2103256244933413, 0.13700973843374561, 0.18222024874581447, 0.12287288047974149, 0.12543479341172403, 0.19391082707912694, 0.10004997974441898, 0.13065859374980773, 0.19057276748841812, 0.14539501509599148, 0.12053127911302353, 0.1035264561012868, 0.17196427730302657, 0.17010758660974043, 1.2286713022378184, 106.23075162210773, 153.28313550641462, 131.5461366407333, 133.13864246491465, 99.59401499840521, 87.57637485381096, 34.87436586810697, 36.27951183626729, 108.8117810218565, 93.88518564162716, 87.20912333457701, 90.71700880604406, 66.91720408778038, 28.08619829916185, 1.6712603982417815, 0.2588561760081399, 0.6302484617598596, 0.257032779496043, 0.17021189714151044, 0.9387520688676065, 2.0480142269403707, 1.438295634523515, 5.222340726083325, 6.919339472247708, 15.901163162723666, 37.2568174331419, 80.1999576630131, 103.30523613960513, 98.01966190338136, 103.29341411590578, 103.55637765699818, 102.9061741982737, 97.53848122012232, 90.20422950867685, 100.30038679799726, 90.91423342304846, 88.03071083561068, 83.30767508476012, 82.44287090916788, 76.12975335890248, 73.86697723019508, 75.09772285338371, 75.02729277456962, 72.55306166987266, 80.36989042835852, 89.8562760506907, 96.40399056096231, 93.80312965762232, 89.99991324640091, 81.1362038889239, 78.33362333236202, 72.27742102838332, 78.7422166332122, 81.7955856938516, 83.12532409544914, 84.02617485292497, 89.64864146324896, 88.10012894292032, 91.81112258665024, 86.61555105640043, 99.42533739151494, 80.91717089376142, 48.52282947109592, 107.91350333921372, 90.93881099454819, 101.2439678561303, 81.61166575647171, 81.43338618739959, 85.42935571362896, 87.2185762466923, 83.9518851618613, 78.1864324692757, 74.31324881892051, 80.51923859503962, 85.7585523974511, 86.57744915254655, 84.33568908322243, 83.2151855960969, 77.16393332327567, 82.20906626793646, 76.32178475779872, 78.03224409780195, 79.58917402452039, 85.21151511899888, 81.87507644776376, 80.41544483553979, 71.48549449059271, 76.82298521841727, 91.09263850796609, 105.80613936147383, 88.83958201254569, 83.10942280677058, 101.5107439410302, 111.06060920223113, 67.17574319531842, 5.110187905450021, 2.3487807137350885, 3.17875252616021, 1.2691429305461146, 0.25924157952108695, 0.30801802993782107, 0.5421805874474588, 0.9069105742439147, 0.32302434405972885, 0.1696831279344136, 1.3600436141414027, 16.70735143846081, 43.52233702136625, 54.53287332288681, 63.693792435430716, 73.527174457427, 123.31043797154581, 43.652398893910075, 29.062413477128555, 36.54944935152608, 49.77319871225665, 84.33411229041316, 90.64843008595129, 100.46208258598082, 94.48917573498142, 73.5175411162838, 16.242612350371576, 0.5328192381608872, 0.09516946340520537, 0.20270075138297775, 0.18222853781715517, 0.15041929549507557, 0.1774241093305811, 0.14028421272673916, 0.19370968303372785, 0.12187390948735899, 0.07082842155209473, 0.2202177654591299, 0.11177839516031166, 0.1429757553963892, 0.20909018514137115, 0.14819479066758387, 0.2343945289331098, 0.2316706879965721, 0.19246042345560369, 0.1251409144230908, 0.1691692974418402, 0.17767981415794742, 0.15526014380156994, 0.1940835339407767, 0.0720208220844788, 0.181475427422312, 0.07265709640998995, 0.11103712082389863, 0.12594938233134248, 0.14760606741953283], [0.0099493591152432, 0.02847041089778706, 0.05874883909259112, 0.014808838680056075, 0.06610379644459294, 0.0872926852635799, 0.04359653542539285, 0.06292057088426044, 0.015103531637108855, 0.04808830044743034, 0.02367502224871949, 0.025932834663939093, 0.0335088926517675, 0.015738837819005695, 0.031636297973173286, 0.015722753803035425, 0.06722072199467691, 0.046014481284204996, 0.09232189926889636, 0.07571358804500873, 0.12340286010575872, 0.10223249529278088, 0.19458521427887102, 0.08648474595599598, 33.48527416106194, 119.89758368461364, 107.0290010206161, 105.63725779133459, 86.13306030150383, 58.25597532333867, 19.4178916177442, 42.215113024557795, 88.94524282024753, 83.13640086881577, 48.16021419340565, 47.87812517535302, 38.68846685655656, 15.881795479405312, 0.25191178815739773, 0.18072826186976126, 0.07205907285453812, 0.05136293561888799, 0.06106617462430751, 0.05331487402379994, 0.2528238617965291, 0.34954122117450165, 0.15468309573348493, 0.3935330541383836, 7.097739163906344, 34.97816354997697, 78.84832459111368, 99.74391229691045, 85.18551764949676, 92.84735787299373, 85.2833886300364, 81.24330028410881, 84.90510740587789, 91.12602572287284, 86.5101412803896, 91.57520771026613, 88.28918718522596, 86.42972484711679, 82.4632280103622, 80.38298329999371, 77.98116699341806, 69.56676513917985, 65.31018941633164, 66.23806138192454, 66.65738628756615, 65.46548389619397, 65.99926748583394, 71.69778885379915, 72.6358550594699, 69.71554848455614, 65.36302374255273, 65.70991423822218, 64.42584007017075, 65.61829551573723, 67.20396072633805, 67.63521748204386, 67.64838880108249, 65.21711941688292, 65.62043712985131, 64.70019809661373, 73.18160580050561, 85.63382102597146, 84.99612208335631, 39.5099013851535, 82.36087768308579, 87.6962189520559, 86.57165188943186, 77.49596980310257, 73.90578516067998, 84.78804034571495, 82.95983145313879, 76.51467123339253, 68.71222188395839, 67.13810413114487, 74.07960891723633, 77.47278075064384, 75.16669381049373, 75.82878205084032, 72.7013272623862, 71.34318305600074, 69.26966913284795, 67.54487745223507, 67.24145074044505, 66.17632327541229, 63.74870561784314, 65.04990877643709, 67.95704010994204, 74.25813951799947, 78.20846050016343, 87.78901438559257, 86.35851813900857, 83.16035870582827, 93.15920983591388, 91.01064528188398, 85.33747811471262, 93.74163473806074, 59.27131614377422, 3.3537436781391023, 0.49691634372838084, 0.18587831858425372, 0.1303035273186622, 0.0916756734612488, 0.16778119208831943, 0.10986427851622144, 0.09247893963249461, 0.046847034996796044, 0.08244366279893345, 0.4608143583661126, 5.362375715086538, 21.573181075434533, 38.41226923850275, 51.04754147991058, 54.94186670549455, 95.92132722177814, 35.17930269241333, 10.656504150359861, 19.53354270227494, 27.27832732662078, 57.2440783439144, 62.69214460926672, 76.76738169885452, 83.21695066267445, 49.76600116299045, 5.159625949398165, 0.07899383864095134, 0.04372337660301597, 0.09202977462160973, 0.06441923804701337, 0.05544388599153008, 0.09175789001728259, 0.052839849715030966, 0.06990945312164484, 0.037374468895817, 0.0022666341570701694, 0.06363007938489318, 0.025329959856706764, 0.057646135964821425, 0.03176017247530962, 0.020907847548744852, 0.03779879733619671, 0.016149177493888046, 0.0960554364287565, 0.05776440844901147, 0.07528638677491296, 0.09773904487730996, 0.07988566457624398, 0.026169789489358667, 0.04128865341866209, 0.040032908906258886, 0.0028315201005522884, 0.02728118388462932, 0.0628049299120903, 0.01582464158174492, 0.027803606053273526, 0.04677169024944306, 0.06065165977023783, 0.017587999783215985, 0.0746656257298685, 0.01965765142813325, 0.0426179385413566, 0.08372525128746226, 0.03753551206881962, 0.032467193105408264, 0.05862015164307049, 0.10482262324301467, 0.032554879529221405, 0.05084243633093373, 0.0357391431386913, 0.07547398638581077, 0.04157239706405709, 0.07126797982040914, 0.010132386138842953, 0.09359436365024698, 0.08987884487836592, 0.14562448907283046, 0.056758002573323835, 43.98352538385699, 138.05434503862935, 118.04382447273501, 118.94639322834631, 98.44812593152447, 74.99270531439012, 41.339522330991684, 49.430265888091064, 56.130348790076475, 83.22837260461624, 48.75731268236714, 50.86353917275706, 50.81537246704102, 19.72282648086548, 0.057409943396886515, 0.14614224193557618, 0.1457988353626382, 0.12219939726374804, 0.1801304834624452, 0.0916924584476698, 0.4265254579724804, 0.14909089903437323, 0.2822863623019188, 0.7231923324927207, 9.998602059579666, 39.119276462062714, 83.4846681164157, 103.23501002403998, 88.7034365438646, 95.72997047055154, 90.02751104293331, 86.84227974184098, 88.51488820968136, 95.31565835399013, 89.0553908194265, 92.99883196430822, 92.1062417184153, 91.60814777497323, 86.69846996184319, 85.57376169389295, 82.58718275254773, 72.02589511871338, 69.47758613094207, 69.9071248885124, 69.66232192131781, 68.01574230194092, 68.49337716256419, 75.51282728871992, 75.21266398891326, 73.91672072872039, 67.98620685454338, 68.98362636566162, 67.82419727694604, 68.92763060908165, 71.47001681789276, 71.42950657875308, 71.27588302858415, 69.93032178571148, 68.75334401284495, 66.08564592176869, 76.41316813807335, 88.94233242157968, 88.2707755796371, 41.256422996520996, 83.52027539283999, 91.88952292165449, 89.86437182272635, 80.00552577357139, 78.29718451346122, 85.71022095218783, 86.83216787153675, 79.79900513925861, 69.65251599588703, 69.20760154724121, 77.12827113366897, 80.56726409542946, 80.72531207915276, 78.77933009978264, 75.40280480538645, 73.73742134340348, 71.96993074109479, 71.19928698385917, 71.09250437828803, 70.37361237310594, 66.9010753016318, 67.59910814223751, 70.94553316793134, 79.4677217545048, 84.74363911536433, 93.03178771849602, 89.69603153967088, 83.15652262779975, 93.87356758117677, 93.39713296582623, 86.51191419170749, 96.66453792202859, 67.12097121823219, 5.066119095971508, 0.467487535769901, 0.057257032247200135, 0.3498551333623548, 0.018598023509126038, 0.2752676486007629, 0.08166289663002377, 0.14123146512335347, 0.19495327356121234, 0.08399451587108836, 0.25985717713352174, 5.0949534197007464, 24.79404710954236, 46.02478565708284, 49.25087236589002, 52.5284597950597, 68.91187837046962, 22.979644959972752, 16.083697522840193, 33.52463122337095, 44.408655397353634, 66.05394532603603, 75.06615561823692, 86.86359390135735, 96.42693642647036, 66.13670733667189, 8.54618956965785, 0.04901351249446312, 0.025319037358126333, 0.0768463716151253, 0.037587452830085834, 0.06032255222840656, 0.06560542560633152, 0.029823908229328455, 0.03365054230896696, 0.025011537326199394, 0.06103912405970116, 0.028968448487801418, 0.07044818147175735, 0.051035567096644835, 0.01761609222739935, 0.013064709285484448, 0.022533601037256663, 0.02627517637466231, 0.12813497755315997, 0.03546104939173787, 0.020110484084955627, 0.048320329327496796, 0.016459845299381885, 0.002944097439232733, 0.0672215263869974, 0.030938181199974595, 0.06140599973619946, 0.0639525028095851, 0.03563903459918595, 0.09714952489781765, 0.09647217293780658, 0.15786752405185855, 0.1284114586850328, 0.1608390565360746, 0.19134856940757847, 0.2556822890596044, 0.19049012192314674, 0.24480140437522244, 0.1693960594674272, 0.15087448961792455, 0.16191118126434667, 0.15612542479028627, 0.07703596305462622, 0.2403994018752729, 0.09167235630053668, 0.19064959078546495, 0.12216146058973767, 0.2433291519240987, 0.1818601261343687, 0.19831039341947726, 0.16360065028552087, 0.2208320913656104, 0.1461886515420291, 55.19520082781392, 156.60277858857188, 129.82547913828205, 135.1647663116455, 110.07947537206836, 82.89344141560217, 32.91384366250808, 59.671797983108036, 108.43880284217097, 101.19151007744574, 67.98190009209418, 71.12977473966538, 61.729594968980365, 26.108864815004413, 0.48164851783264073, 0.3659169021393023, 0.5046084793584963, 0.19644014296993134, 0.2952045046033398, 0.49825914264205967, 2.2737519010420773, 0.9496278207628959, 1.0381785756157291, 1.9351302519921336, 11.323725792669482, 38.190212095937426, 87.89928790061705, 110.69815081934776, 93.54350797591671, 102.54178600926554, 93.80457308984573, 91.39897561842396, 92.75191876196092, 100.3335072917323, 88.17838022785803, 97.91597797024636, 94.86575465048514, 95.42949338113108, 92.87118234942037, 88.54891084855603, 87.28794728555988, 77.78806870983493, 73.54815129310855, 72.32909433303341, 73.78783164485809, 73.45844668726768, 73.3384221599948, 79.71829060585269, 78.74909647049444, 76.61342082485076, 71.06612251650903, 73.12590814405873, 70.9167351261262, 71.71125827297088, 76.07823694905927, 74.63402809635286, 76.11336569632255, 72.21290588378906, 73.22071183112361, 69.84209983579575, 82.03852161284416, 92.5643353308401, 93.92280117157968, 47.19641331703433, 87.17495949037614, 93.08271577281337, 93.7763947825278, 84.72318787728587, 80.71531003521335, 90.16000870735415, 89.97454335612636, 81.82397580915882, 73.09112456537062, 72.45605361077094, 81.90794590980776, 86.61044413043608, 84.5634924980902, 84.6440109129875, 80.09081379059823, 77.58503114023517, 74.97877305553806, 74.92072982172813, 76.24506319722822, 73.1637982399233, 68.54420323525706, 70.79341580790859, 74.75937920231974, 83.37856800325456, 86.90724988137522, 97.33720087235974, 91.9961800113801, 85.70250957242905, 96.73197131003104, 97.46787071228029, 91.42112132041686, 102.30681250172277, 74.10148005331718, 5.999859417638471, 1.0716796618315483, 0.9388487798071677, 0.6709208051043173, 0.43089899264516374, 0.6866786821234612, 0.3033336474289817, 0.4928120123522897, 0.33582132189504565, 0.12806412208104326, 1.0711291816926773, 11.748730290320612, 37.03862774756647, 60.664738147489494, 72.30908240041425, 63.57916901188513, 118.08420135128884, 50.55316986576204, 18.30067115445291, 31.574840622563517, 45.77342840933031, 84.5210995212678, 89.95477461045789, 100.85788896006923, 108.63727477289017, 77.52894124677105, 10.691031794394217, 0.2776927765338652, 0.15100046511619322, 0.18083142326964488, 0.12356389178744248, 0.2532281417159304, 0.1624516869384435, 0.18573473838548507, 0.1416673385087521, 0.19124220576017134, 0.12053831180016841, 0.16336368396878242, 0.14274329367664554, 0.15447798335263807, 0.23546780279326826, 0.09185660810720536, 0.09900053121870565, 0.1072407108280928, 0.2380141411577502, 0.18105516690881024, 0.18208396170408497, 0.2353073839819239, 0.156990246126248, 0.08387806284571848, 0.1301679297560646, 0.19443996400842745, 0.10768082067971269, 0.1839569853919168, 0.14457340111895917], [0.030572152050632625, 0.055937939924338174, 0.04064597842854358, 0.03487913283489404, 0.038082812942804835, 0.04350600298494101, 0.06249423912395874, 0.13048227095315534, 0.013708520000950705, 0.08152093287677535, 0.06519048174302425, 0.02165110796810158, 0.04337188780247685, 0.08326246523328366, 0.059156508951057354, 0.023161092164715933, 0.03229358226000782, 0.039946601440709446, 0.08500356091967515, 0.08290249583942276, 0.05670128908428935, 0.19378408549293397, 0.3320819854495987, 13.566074217519454, 103.44408804370512, 108.81768811133601, 105.53678235700055, 88.62706015186926, 63.320810333375015, 28.626932328747166, 32.37074248252377, 65.61758948910621, 104.03504802334695, 50.626157329928496, 71.8513810250067, 37.49639580326696, 17.04483412927197, 0.17453957379104632, 0.2608226930662509, 0.18379100478224217, 0.08125940578118448, 0.021061197283767888, 0.1753954931853279, 0.24300048488282391, 0.2699234805280163, 0.02683547393028294, 0.21911401662134358, 2.2234587803963692, 30.219669572768677, 75.80621273286881, 95.73477145164244, 85.75936825044694, 91.08069881316155, 81.60192258896367, 76.96394735766997, 79.72451148494598, 87.60438842158165, 86.93767178443171, 84.90473870308169, 88.39034511196999, 88.13201781242125, 86.202603924659, 88.92165368603122, 87.16080757879442, 82.34840454593783, 75.05868742542883, 65.12322571969801, 67.36006321445589, 67.52291217927011, 63.964537958945, 62.78311614067324, 61.99727712139007, 65.64182973677113, 62.62822958730883, 66.40491116431453, 64.72843916185441, 65.018494513727, 66.03911092204433, 69.55582172639909, 63.472704118297955, 64.08593531577819, 61.02678468150478, 64.75861003321987, 66.04137805200392, 70.59209623644429, 78.25250871719854, 89.94520402723744, 34.74266836720128, 75.49950691961473, 87.32035390792355, 83.28575688023722, 75.25130717985093, 74.33974050706433, 85.15376998532204, 82.83491965263121, 80.58842136013894, 69.68005103449669, 63.10959069959579, 66.80042728301018, 72.72682266850626, 69.23173981328165, 66.67330326572542, 66.17928858726256, 65.22194000982469, 65.61288264489943, 63.50573439751903, 64.30154800415039, 65.86888790130615, 66.08484575825354, 68.79575267914804, 80.06708345105572, 82.0975140602358, 84.47203851515248, 86.66217234826858, 84.23557450694423, 81.82796093725389, 88.35207846856888, 81.90265855481549, 83.49088115076866, 84.02544529207292, 89.5514843540807, 60.92951382360151, 0.24813267642692213, 0.4073934232996356, 0.1123834743855461, 0.0690680434326491, 0.07385331206023693, 0.030527634681352687, 0.032122767635531006, 0.024572461693277283, 0.07950224523102084, 0.009321132543376617, 0.09391833457254595, 0.5363007706980552, 8.510681333080415, 23.171690087164603, 40.30815078366188, 54.2706040413149, 83.76604326309698, 68.40912465126284, 19.780083279455862, 21.5802982161122, 33.306908299846036, 44.22292332495413, 68.58550579317155, 78.07935176357147, 79.33555356917843, 45.64138966221964, 2.341233338079145, 0.10088918310019279, 0.08005007470567381, 0.06840582937002182, 0.04479242931871165, 0.04722179754847481, 0.022317633190522754, 0.04159996473801233, 0.0008484313636267138, 0.02729890158309812, 0.04389430997112105, 0.016270508584115776, 0.040435813697836095, 0.06081557960339612, 0.04185742773716489, 0.09562389144013006, 0.05647435468891936, 0.026402551898612615, 0.023784883087500933, 0.032569136425492265, 0.0034804525925973134, 0.08888637797246057, 0.06520797919121481, 0.011437259869830263, 0.0034518167047926616, 0.04320609871478331, 0.13126585632562637, 0.07393993362183533, 0.03197230605198251, 0.052129467874164545, 0.027431768042245702, 0.05365489448811259, 0.004203671433647434, 0.06455344132958882, 0.09450939438876607, 0.08645903604525713, 0.03759404118623465, 0.04005165890820565, 0.02203909894301286, 0.040835397498261546, 0.006567786688045149, 0.06613518306685072, 0.047576005961145126, 0.033281896969363574, 0.017587086223366282, 0.10637359122835821, 0.040074143588783286, 0.030972988404814276, 0.04712220611831835, 0.23040805252328997, 0.29087785451162246, 18.101659897835024, 128.7495965342368, 121.51349036924302, 117.96197245197912, 98.6717402550482, 86.38563740637996, 49.22054067734749, 36.20914059300577, 54.37206006819203, 98.05569279578425, 52.41444826126099, 64.62792450381865, 49.47208227649812, 18.386247465687415, 0.06800632983926805, 0.008275809401135531, 0.2520458382223883, 0.11570016778404675, 0.1876995547284042, 0.048588716740449595, 0.3447804137343361, 0.5285795237268172, 0.34755052638150036, 0.04971811420194084, 3.0089523859562415, 33.64223172587733, 81.32721547157534, 101.44975892959103, 91.90366698849587, 94.94606910213348, 84.63844899208316, 81.78055517135128, 83.50409169350901, 93.32096053707986, 92.3155080118487, 87.99050654134443, 88.16082369896674, 89.46836933012932, 89.2062843999555, 94.09163567327684, 89.38002970910843, 88.15570108352169, 77.96175910580543, 67.93221935149163, 71.9229172122094, 71.85527201621764, 68.14623171283354, 68.32964174209103, 65.00586448177215, 69.25889045961442, 66.62937271979548, 71.31534207251765, 67.78633856004285, 68.15032666729343, 69.07038919387325, 72.13874955331126, 69.2068406074278, 66.83518732747724, 63.0640951279671, 66.29743822159307, 70.41526794433594, 74.50964973818871, 82.02804888448408, 94.87305810374599, 37.969998467353086, 78.77913398127403, 91.41282158513224, 86.81720010695919, 78.72833928754254, 76.27230013570478, 90.14485266900833, 86.09819827541229, 86.1171825470463, 72.01453593469435, 68.26730743531259, 68.47644821290048, 75.46033813107398, 72.26996852505592, 68.8691637592931, 69.50982016901817, 68.4821984075731, 66.9135170598184, 66.19973198060067, 68.73639937370055, 69.01384430546915, 68.7496962085847, 74.80361569312312, 83.41984702694802, 89.153622658022, 88.80664194783857, 90.15819657233455, 84.52609662086734, 83.41590112255466, 94.12831767912834, 87.31155210925688, 86.25433998723184, 87.73097115178263, 94.98877586856966, 71.56346336487802, 1.0964572742100687, 0.6738814591400085, 0.041394484634961815, 0.10332374157564295, 0.16634580378811206, 0.007011703517843759, 0.05194770202281014, 0.05884396423014903, 0.05115360592401797, 0.023846654672055476, 0.14039144971437995, 0.20972720257216887, 6.7600520195499545, 28.97711173180611, 33.415503040436775, 51.07657486392606, 61.17055523780085, 35.240621105317146, 17.066224775006695, 33.627177669155984, 55.41223733655868, 52.6054794557633, 79.28313501419561, 89.21585498317596, 93.94444481019052, 60.50362679266161, 3.1696516467678935, 0.020203197960771864, 0.04529782901367834, 0.0265981130782635, 0.039071794148654714, 0.04786753689029044, 0.021409857304646604, 0.07849562868115403, 0.02126262286647914, 0.02713737194426358, 0.029584586192222855, 0.0543122285706622, 0.056060797444755034, 0.0831725188500939, 0.09916897863149644, 0.012557212424825036, 0.0212005122880181, 0.021193565785764687, 0.04530930884122368, 0.061472626402974136, 0.04331828463041494, 0.11002681173023679, 0.022603152244682276, 0.020945464381046837, 0.01172379111765974, 0.09122099261730911, 0.0737447037752117, 0.06405365322866748, 0.18302186782802307, 0.17566829709516418, 0.07345922877110782, 0.16701211642113425, 0.15697169147672194, 0.19293582697789516, 0.19961193083755432, 0.24632709911994397, 0.09062372748890231, 0.13549579547778254, 0.1658646239628715, 0.21901137616124847, 0.13647885482397773, 0.2663951859839501, 0.14807319719224207, 0.17229392493684448, 0.15144611378350567, 0.3074811555204853, 0.180707240417119, 0.12535197164623008, 0.22281336327714307, 0.4160888889624227, 0.5976870896354799, 23.326513882606264, 145.91497882719963, 136.6301481185421, 131.92446493333387, 114.1552729760447, 88.35479274872812, 43.099121124513694, 45.7230612539476, 90.80918450509348, 127.97370464571061, 70.73936554693407, 98.16953566766556, 60.151248901121086, 26.560827762849872, 0.49685205362977525, 0.5602916414218565, 0.5459978503565635, 0.256071308507554, 0.4852081913380854, 0.6984106138829262, 2.1998081139979826, 1.5880008594643686, 1.5839197558741418, 0.5028460787669305, 3.725068578797002, 34.32378668938914, 82.58290736905991, 107.47202488683887, 95.93865625319943, 100.6483716349448, 91.66842675978138, 87.10788696042954, 87.10142289438556, 98.63055536823889, 96.10196805769398, 86.92488485766997, 90.41630421915363, 93.90799814654936, 93.14401457386633, 98.15966698431201, 95.30539743361935, 91.17580060035952, 82.75121627315399, 71.27021128131499, 75.55079583198794, 73.67604409494709, 71.84254784737864, 71.29038795348137, 68.58111273857855, 73.31626076852122, 68.15405291895713, 73.33901051552066, 70.22182449217766, 72.34630569334954, 73.71520503874748, 77.88555529809769, 72.93717153610723, 72.3084234422253, 67.39268164480886, 71.80076676030313, 75.67352679467972, 78.51176169610794, 87.69756824739518, 98.65050454293528, 43.871059263906176, 79.77271741436374, 95.3051071782266, 92.79565318938225, 83.25621358809933, 82.6486776721093, 94.71581028353785, 91.8154058148784, 90.06620914705339, 78.15413567327684, 71.12617400384718, 74.69310683588829, 81.37979876610541, 74.99205420094152, 72.93773635741204, 74.30691026872205, 72.23367091148131, 71.39451119207567, 69.06017534194454, 72.26696398950392, 73.85259782114338, 74.06408417609431, 77.39452946570613, 87.69603852302798, 92.62703834041473, 92.70732925784205, 94.14156744557043, 87.63288051851335, 84.48658266375142, 98.42031632700275, 91.20553216626568, 93.13741714723649, 91.83594334510066, 98.38383043965986, 74.2816266705913, 1.4285844588471999, 0.8085847826253983, 0.6070475809035764, 0.2761983228546958, 0.3388923232353503, 0.3004116655117081, 0.2819367810603111, 0.2772167294977173, 0.27341034503713735, 0.15787038922069535, 0.3446780643876522, 1.2920148838912289, 14.957489928891583, 41.01148666874055, 60.47351083447857, 65.82958575217955, 106.28191501863542, 96.73726650976367, 31.138051363729666, 32.81759850440487, 54.5533480951863, 65.36652641911661, 93.59422422224476, 100.8602031584709, 105.97366379153345, 70.51703776082685, 3.7075615698291413, 0.22715856801838646, 0.1276574289846805, 0.1972985751326046, 0.12075147576509945, 0.1461749079246675, 0.11508282349114457, 0.17291560528739808, 0.1544977790646015, 0.1039588897519054, 0.21086655917667577, 0.08736495033747728, 0.14469576068222523, 0.17724444639057885, 0.15637316230324008, 0.10322598109562552, 0.11023248335526836, 0.20539944931384058, 0.12074527811379203, 0.1970083197398532, 0.20101381045195366, 0.21479446050380507, 0.18985523421677852, 0.07527106501642736, 0.06390803523602025, 0.24214582187273812, 0.2486075896529421, 0.16976676941398652], [0.027254389959477612, 0.06088978287974193, 0.041850655519914244, 0.019249531493011503, 0.016250316421651555, 0.008571050111054173, 0.11547403395055764, 0.021725112061587074, 0.019241728887502706, 0.03701053882738756, 0.037748124450445175, 0.049841864214789484, 0.017992905979495377, 0.038923548474427194, 0.03766016989585854, 0.014520977312068065, 0.06992327334779887, 0.03606091921908721, 0.0535350745063155, 0.01710949552005097, 0.022166108659979318, 0.05059458390479127, 0.7736753203695821, 73.21514991021925, 120.23458588507869, 103.58605430972193, 97.87487937558083, 76.98558315154045, 39.92420173460438, 27.8411207660552, 59.1024463407455, 82.04770780378773, 60.98700400321715, 61.66267541147048, 31.0012645875254, 14.321585470630279, 0.22426054933138434, 0.06169807075733139, 0.3198220658927195, 0.06433149033616628, 0.09213152641971266, 0.06151544688750179, 0.1964422114073269, 0.1665177139183206, 0.4446943056198859, 0.12664745696970534, 0.32011691781301654, 13.885754250711011, 70.59716393870693, 91.7800574148855, 88.12159215250324, 86.80957501934421, 81.15624720050444, 79.30545330047607, 67.6184924956291, 74.24973780109038, 85.002625373102, 90.01244129673128, 84.84676607193487, 90.4146646684216, 87.46632099151613, 83.0974203540433, 84.71944593614148, 85.54346530668198, 86.12629029058641, 79.30586907171434, 66.28884823091569, 61.24091471395185, 67.643187738234, 65.04307992996709, 65.7591635181058, 64.00453436759211, 64.43794450452252, 63.173297835934555, 66.57886828145674, 72.38017928215766, 65.73686484367617, 63.015595020786414, 69.59994839083764, 65.5221386109629, 65.25956338451755, 60.87652652494369, 76.55569922539496, 72.21853840735652, 77.54246557912519, 73.40329031790458, 92.50723346587151, 36.57518794459682, 68.52641136415544, 86.80857089258011, 72.94222354888916, 69.94991794709237, 74.37721483169064, 83.98458203961773, 81.57664683557327, 83.12963085789835, 72.00523991738596, 63.99910580727362, 59.6928140424913, 65.2168526957112, 65.30112874123358, 64.52117719957906, 64.18206868633148, 67.44642596090993, 65.80628295098582, 66.49197209265925, 61.9535779953003, 62.6402908755887, 63.17449808120728, 76.70869519633632, 81.96366710047569, 87.92579527824157, 85.88212274735974, 82.96429511039489, 74.81076225157707, 80.41083997295749, 85.02433176963561, 81.34337563668528, 67.38322873269358, 80.58391847918111, 81.57853741799632, 96.2362543229134, 53.24446493579496, 0.8508325091773464, 0.41001218761647906, 0.18576182725448764, 0.2507009861930724, 0.018113752519111, 0.013560083762352026, 0.040297714858165676, 0.06936449647670792, 0.025101851431592822, 0.2203268870230644, 0.0742276609244366, 0.10656769492573316, 2.830759599324196, 25.46923410507941, 43.92470944312311, 49.48268444307389, 98.68962626303397, 94.36776268866755, 37.09003825341502, 10.376971537067044, 38.5680147909349, 55.22878416122929, 72.47405728986188, 78.83824409977083, 77.62688282997378, 26.397115876597745, 0.6431280545169308, 0.027393065280311053, 0.055845392672645475, 0.05161729596194722, 0.030753596145058834, 0.049273622327394066, 0.10598898444685245, 0.0815178455424405, 0.008509973751290912, 0.08725402080604146, 0.04232636164693583, 0.08339728138619855, 0.02651696138444447, 0.06273795084487047, 0.07548130252548764, 0.04052734971346875, 0.012064679176546635, 0.05350558778210994, 0.01569364629235239, 0.04513713824112089, 0.0588278342489033, 0.023232775011790857, 0.010673000022859104, 0.04097894705351322, 0.05903113483180923, 0.027070379470505064, 0.09818105462698207, 0.07199403198976671, 0.032167426731076934, 0.024724805937899698, 0.023268417252468008, 0.03202525804930877, 0.07297780379773149, 0.14346907005435036, 0.090089296892045, 0.048913101350227674, 0.09979759207776479, 0.04440275869602638, 0.03837751930639629, 0.009035304181217667, 0.009458331229736008, 0.04908971909073092, 0.05744473527996771, 0.03678132149000322, 0.06802882984160416, 0.04083896746798869, 0.05516558923127671, 0.007964047047519877, 0.038022069831288634, 1.5358080859145813, 93.41694093519642, 133.8450299539874, 116.04245078179144, 107.84587383270265, 95.51018438031598, 55.16754419572892, 39.69315059723393, 42.50883971491168, 66.95085802385884, 59.42053879460981, 53.392448117656095, 42.24209893134333, 15.752870113618913, 0.2694870249157952, 0.021735952205715642, 0.15381681883046705, 0.1259986954110284, 0.0860784435644746, 0.03561866432127934, 0.2529370436264623, 0.07214911882915805, 0.8566298335790635, 0.35391141570383505, 0.4806437781981884, 16.7321761192814, 76.0193778622535, 95.86496276240196, 92.11597704118299, 89.36473246543639, 86.71294350777903, 81.69388648002379, 72.12811993014428, 79.93901022018926, 91.60718287191084, 92.44540906721546, 87.87385525241976, 90.14911236301546, 90.29373015126875, 84.62157495560186, 86.58851808117282, 88.50354471514302, 91.12939111648068, 83.49270897526895, 71.0009797926872, 62.80157481470416, 68.02039423296529, 68.44180583953857, 69.13645759705575, 65.92680561927058, 67.13718629652455, 67.94350793284755, 70.16500503786149, 74.81230766542497, 68.8574044935165, 66.35188856432515, 73.39441007183444, 68.4883329945226, 67.89818886787661, 64.96784102532172, 80.01333913495465, 76.25332370881112, 81.67510617163875, 76.75041352548908, 95.08760390743133, 40.39376827978319, 70.50797708572881, 90.85299737991826, 77.44230393440493, 73.95911370554279, 78.82791257673695, 87.07057737535047, 83.20912945655085, 84.50948146081741, 76.09162792082756, 67.32594643869709, 63.48646771523261, 69.0208496585969, 67.81275180078322, 68.53650754497897, 66.23558244397564, 72.35764134314753, 68.05280085532897, 70.1414551273469, 64.88707942347374, 65.66724277311756, 67.52999597980131, 79.70809244340467, 86.36113828228366, 90.00895038727792, 87.9280859424222, 84.36946853514641, 73.19809544471003, 82.79375045530259, 89.68384081317534, 85.68072472849201, 71.3235241366971, 84.29932086698471, 86.03508733933973, 100.15254482146233, 62.224221537190104, 1.6004423725028194, 0.25249093530639527, 0.44152852388158925, 0.16953835263848308, 0.3300752334537045, 0.05380630410546738, 0.1476741266707259, 0.043552228730292096, 0.10953973302797926, 0.03350388243674271, 0.03220103500831512, 0.0932364397111439, 2.237151774667925, 28.425036168867543, 36.92109392535302, 50.84883028461088, 92.34986012981784, 63.74916061278313, 29.223462074033677, 19.559681377103253, 53.97241761607509, 65.53609832640618, 83.90445586173766, 88.8637516575475, 95.5446384799096, 34.937665077947806, 0.7566381990909578, 0.05250524166190336, 0.08242958976376442, 0.062042170639840834, 0.04851083241162762, 0.014163318630908767, 0.04174256051379827, 0.038041245012033376, 0.0458460683453708, 0.06313123357211871, 0.07498476263736525, 0.024612501278639804, 0.04049228586917443, 0.00336863080813219, 0.06421527096761331, 0.03567400651292936, 0.05907177196575269, 0.03938555311892302, 0.015053329895430756, 0.04022859840563709, 0.03644681302830577, 0.048357568861496066, 0.0668503567876835, 0.04081099376743359, 0.0293171372369773, 0.029304492955787048, 0.02432512637648371, 0.17476897115909285, 0.1488386875679416, 0.15363732442980813, 0.09035231785908823, 0.12442701240821231, 0.09668641708671086, 0.3046575392926893, 0.13535878831340423, 0.08826324205485084, 0.14768937182041908, 0.1760222910032157, 0.1492535241789395, 0.08635720763836177, 0.08839932225284078, 0.13760998364417784, 0.14300319666583694, 0.26703106960461986, 0.18227070329650757, 0.1326853099970087, 0.23072709750023582, 0.10464976316378002, 0.2808494265041044, 2.308037829014563, 109.01121001089774, 151.5329425565658, 129.9943057952389, 121.86120064027848, 101.44645629390594, 59.78330704473681, 43.36947048864057, 87.03471906723516, 112.38981416148525, 80.29042320866739, 89.35426758181664, 52.00644331593668, 23.668438657637566, 0.8433220283158365, 0.18620243506325831, 0.5098507577373136, 0.29924537325578354, 0.5210375413298607, 0.25971030275667867, 1.201604741715616, 1.0274499738889358, 1.3008343332236814, 0.6673698956447264, 0.617588460445404, 18.3945099384554, 81.06476968334567, 100.42950337932956, 97.51458614103257, 95.60962430892452, 90.20684965195196, 87.82411175389444, 76.11959442015618, 84.34476544780117, 94.28911916671261, 96.99196953927317, 89.44413692720475, 95.0126003449963, 92.21921382411834, 88.9700008207752, 88.03409976343956, 90.81849621188258, 95.98295550192557, 88.9524599813646, 73.71207498734998, 65.60430834370275, 72.63049710181453, 71.52747954091718, 71.31201590261152, 72.57288532872354, 70.5633060393795, 71.43050286077684, 74.53407825962191, 75.3843931997976, 72.14528422201835, 69.1417920204901, 78.19046466581284, 72.8116164668914, 70.9048189655427, 68.428909086412, 85.53376920761602, 78.27105368337324, 85.2204502782514, 81.20896385562035, 100.02313798473728, 45.205320158312404, 73.9883981212493, 94.90087555300806, 80.80157864478328, 77.53390696740921, 82.80638833199778, 89.86309313005017, 85.1996381821171, 88.09794810510452, 78.71330876504221, 72.04746030992078, 67.88883009264546, 73.45574809658912, 74.07212503494756, 72.22290792772847, 70.23926334996378, 75.7040036109186, 71.67776907643965, 74.35628506445116, 69.64330627072242, 69.34079739355272, 72.03772498715308, 85.18547842579504, 91.23076085121401, 94.51732266333796, 90.77704460390153, 87.25178303257113, 74.00043195293796, 84.08150380657565, 95.28857831032046, 90.08433049724948, 73.90550275002757, 88.37289840944352, 91.24528931033228, 105.2341793429467, 62.60938652100102, 1.8376876678197616, 0.9496560127985094, 1.541849393998423, 0.8065904412538776, 0.27022130486945956, 0.25287765649057203, 0.2835055452681357, 0.2201022700436654, 0.16258072678840932, 0.3013332999281345, 0.18903605639934543, 0.35325748305166926, 5.530833178950894, 41.19141363328503, 62.88852199431389, 56.76176409567557, 118.49736029101958, 127.3792145329137, 54.48063519693191, 20.71305040390261, 58.10583876025293, 75.33154318409582, 96.45993924910023, 99.80514049530031, 109.15525513310587, 38.66061410596294, 1.007158204672798, 0.22339635618752052, 0.1268016015209498, 0.215337555555086, 0.14913174684249586, 0.11830842137456903, 0.17919106048441705, 0.14900157318240212, 0.19178830387611545, 0.18206902298956149, 0.15999197779643923, 0.21639327068001996, 0.0610728664023261, 0.18965713920131808, 0.13148616789089096, 0.14255854391282605, 0.10474963804646846, 0.1105571820610954, 0.12481114421520503, 0.09054036180098211, 0.15014843744856698, 0.14930394808611563, 0.1995222219416211, 0.11167609943978249, 0.16041655904583393, 0.2372265414845559, 0.15728745759735185], [0.05448089814895103, 0.051358323769583825, 0.09346656486271851, 0.024179665431860956, 0.10968259310409909, 0.05261373120330034, 0.05808610792061495, 0.04897799665829347, 0.022340640726108706, 0.007928740927919505, 0.047165340698894956, 0.05977699420444908, 0.04878042258262154, 0.06762773684796787, 0.0709524971523112, 0.04921851379256095, 0.06262488392812592, 0.059099010221900485, 0.10041799306148484, 0.12893489592017668, 0.25860287669685583, 0.2876880482560204, 24.785921919730402, 122.62949882015106, 104.54721543096728, 104.91835009667182, 84.9018047701928, 47.08835594115719, 27.459527100286177, 52.83284356517177, 65.60245306261125, 50.48436364819927, 57.10492833968132, 40.28602469351984, 13.228244396948046, 0.19939909629043073, 0.042678325421988, 0.11887947863508617, 0.14200104640856867, 0.039731457138494145, 0.013364012176621587, 0.1395307958967263, 0.05274500803000504, 0.04150175609655919, 0.9341896781998297, 0.11668554071577326, 1.6350892811052262, 31.90254092216492, 85.40769638553743, 89.16104378238802, 84.7813174032396, 81.04117270438903, 77.97058443869315, 72.13589406782582, 64.90869560549336, 76.3137831226472, 86.56244216426727, 87.63461420612951, 86.2281777781825, 90.25322775686942, 85.96148014068605, 88.31373337776431, 81.85337005123016, 79.4719579142909, 85.3481940300234, 84.67731968049081, 72.67455316358998, 60.553531108363984, 63.274777397032715, 64.26206542599586, 65.14772876616448, 62.37535045992944, 63.667653760602406, 61.10464372942525, 66.94257397805491, 72.1703403226791, 64.38421587790212, 63.50388303879769, 67.0005936776438, 64.72235948808732, 63.521251293920706, 68.97982951133483, 83.23596631326984, 78.61440227877709, 79.33414936065674, 69.15503394219184, 91.49094735422443, 53.66628839123634, 64.80076766783192, 84.02309971470987, 67.22862458998158, 68.34513510427168, 72.57187335721909, 82.93872125687139, 78.11257423893099, 82.57367410967427, 74.4028357536562, 67.64724346899217, 60.795153033348825, 62.184982145986254, 63.44009353268532, 66.02148379048994, 63.215408402104536, 64.16009164625599, 64.92209049963182, 66.20624311508672, 58.288146603492, 61.89221251395441, 65.2831760529549, 74.3995644969325, 79.71924766417473, 85.11231053260066, 81.86798480249222, 85.9003068554786, 80.02121525426065, 77.83763177933233, 82.81868888485818, 80.03382959673482, 74.84673823079756, 66.0098578852992, 82.70677581910165, 81.4862911162838, 94.29414764527353, 65.79764981423655, 14.713381221217496, 0.26500593149854296, 0.26529554337743794, 0.1914303875978916, 0.014865646014861284, 0.07703466836603419, 0.03186900292583291, 0.09702029352587077, 0.12051097012215084, 0.03344089085716875, 0.025718259182007566, 0.14375696589629497, 0.2832598455490605, 24.010947865824548, 32.62051313154159, 46.53623527096164, 134.71985970774006, 106.29618460132231, 41.25816452887751, 12.819793282016633, 38.30042285303916, 58.530482399848204, 75.19774329277777, 79.15199448985439, 66.64480332405337, 11.119693902231033, 0.20196899951946354, 0.06355180052079021, 0.045959139092554974, 0.07956231418516367, 0.054094950713577776, 0.05171927758642743, 0.028071845994300904, 0.04982234429447882, 0.04282672431380038, 0.0314330778294994, 0.045664968990510514, 0.03853967713732873, 0.05319827544172445, 0.08558034085698667, 0.03428726479591381, 0.03323261836363423, 0.04326779943620486, 0.025184998784454602, 0.021107717972969817, 0.06800343402691426, 0.03778045719128944, 0.009544964282653265, 0.03299845975913829, 0.03731900796053871, 0.04978898499581603, 0.03643159086125032, 0.017345969625298056, 0.017943713558657516, 0.02503302609247546, 0.0032634962530386064, 0.06422774670946022, 0.04125698334387234, 0.011522818484433718, 0.09761627162656478, 0.06901672320260156, 0.009944137268429323, 0.10553942873112618, 0.0571508601217741, 0.053073755510511904, 0.041402723910587455, 0.12186514544150523, 0.029251211540653344, 0.045357610684849566, 0.03450704776051064, 0.1239274081683928, 0.14073068876900982, 0.19071434053682512, 0.3674681688989363, 34.64175362740794, 142.69606221106747, 114.546843190347, 116.99905410889657, 99.87587651898785, 74.45080634086364, 44.514335816906346, 50.610452159758545, 63.43107208128899, 56.09985236198672, 49.53436167009416, 49.98779942912441, 16.629715965640163, 0.11331158224493267, 0.05990038032553369, 0.08782530023205666, 0.20158883604791858, 0.08703741710633041, 0.039502967584637866, 0.046543997427028035, 0.04912836056563163, 0.5161426072159122, 1.3785166293382647, 0.15088578175392844, 2.151321735112898, 36.104605505543375, 87.41304735983573, 94.00092694067186, 89.6122810917516, 86.47761698692076, 84.27779489947905, 76.10531699272894, 69.28212658051523, 81.56433843797254, 89.28122520446779, 91.49700349377048, 90.16193851347893, 93.23213454215758, 87.4661248730075, 90.62712377117526, 82.81023225476666, 82.65412976664882, 88.85277686580535, 87.49788822666292, 74.86916634344286, 64.93614042958906, 64.7467174068574, 67.24358450981879, 68.42134675671979, 65.5377810232101, 65.64652481386739, 64.48452657268894, 69.14365906869212, 73.51944738818754, 66.93191297592656, 66.74477669500536, 71.81115319651943, 66.8230515141641, 66.48205634086364, 71.51884248179775, 87.42974881202944, 83.30869490100493, 83.05332506856611, 73.46104329632175, 94.13324417606478, 57.89839244657948, 67.34233410127702, 89.80244544244583, 70.88701924970074, 71.63013581306704, 74.90853909523257, 87.96757636531707, 79.88949421913394, 87.05886517801594, 79.48396036701818, 70.82111558606549, 64.75641742829355, 63.38223465027348, 65.9996126544091, 70.46359938959922, 66.89687836554744, 66.85013940257411, 69.23061801541236, 68.10435648887389, 63.219244480133064, 63.039517556467366, 67.8306770324707, 77.07048677629041, 84.32425145179995, 85.79197099131923, 83.89818006946196, 89.18133812565958, 81.65438821238857, 80.12704864625009, 87.08470575271114, 83.15487523232737, 79.13794455989715, 69.97669989062895, 84.41638792714765, 86.80516627527054, 97.36281394958498, 79.454205266891, 18.98560327868308, 0.3148113912151706, 0.2894652190227663, 0.19070231295641393, 0.21001307594199337, 0.09878633303507682, 0.09686440995503819, 0.3041155167645024, 0.010176688045894187, 0.09490375346954792, 0.058078293823787284, 0.331160718755376, 0.020701005724408937, 27.878610780162198, 32.77247163557237, 48.13508356771162, 128.2943505625571, 79.15674840250324, 30.125871973652995, 29.387166115545458, 51.405657799013206, 63.02155310107816, 83.309447996078, 90.68660259246828, 86.25175122291812, 14.667186487105585, 0.23821274179124066, 0.034474860576371995, 0.1155481376354733, 0.06805476191784106, 0.049281949703130996, 0.007633768827579315, 0.12293759958758471, 0.05536248531913566, 0.005463116629529865, 0.04513663262309087, 0.0533173369964765, 0.0693544530640206, 0.1094526518136263, 0.053499673583334496, 0.050431368872523315, 0.0959557147636529, 0.03286994467940062, 0.026666513238582882, 0.031104169470528444, 0.04929010470908496, 0.054759574122726924, 0.04536017324895628, 0.07246015818729516, 0.04231653273886731, 0.05373964679517573, 0.040826296373721094, 0.11506007834067268, 0.2004716193844234, 0.12406269929582074, 0.06668288230655656, 0.16454453189526835, 0.25378278937310944, 0.13971785924607708, 0.16095154888687596, 0.23947648043113373, 0.20119106787587368, 0.28732388070033443, 0.14228034674400283, 0.22659760779671131, 0.15246928549341618, 0.2310490076460185, 0.17381502315402034, 0.13437241946737613, 0.15331094033054768, 0.2165832604852415, 0.254278831304081, 0.32138804154049966, 0.6288011071662749, 41.30105956908196, 159.56396410542152, 131.50972135605352, 131.853266069966, 112.33292410450598, 69.90221408105666, 40.69546130395705, 74.57920120608422, 91.54842576672955, 68.2576270257273, 82.61707121326079, 66.23300152440225, 23.642413731544252, 0.5194650386129657, 0.14561767089030436, 0.31534998166945677, 0.36601349050479554, 0.20015153252790052, 0.17886001857057696, 0.5101550478608378, 0.1302745998386414, 0.9637816322426643, 1.9583897845398996, 0.4842082320922806, 2.655946424891872, 41.65461024930401, 95.85128937998127, 101.03201866149904, 94.80382827020462, 89.42689418792726, 87.14164287813249, 80.43192663500386, 71.91993621087843, 85.03379252649124, 93.17205167585804, 94.91784372637349, 91.94287500073834, 96.76771979178153, 91.52174580481746, 95.90679876265988, 84.0992093855335, 82.25619746792702, 91.4870563630135, 93.21278156772738, 79.01133829547514, 68.51165540756719, 69.01964156858384, 72.9792271890948, 71.11007659666001, 67.66454112145209, 69.26080457625851, 68.33339937271612, 73.56180898604855, 77.62515698709797, 69.91405963897705, 69.84333146002986, 75.8728773363175, 71.49701841415899, 70.49938709505143, 76.02995257223807, 91.4381600964454, 88.09158602068501, 86.56266181699692, 76.44738689545663, 97.55195848403439, 62.790956958647705, 71.85440125003939, 93.67772363847303, 76.43332912075904, 75.72905971157935, 78.41297288094798, 90.99626587283228, 84.75586122082126, 89.01204078428208, 83.64120990999284, 75.05340791517689, 68.15403722947644, 68.30061620281589, 69.14501620877174, 71.20376633059594, 69.87290613112911, 71.7221389278289, 71.37925317210536, 71.31727187864243, 65.43006881590813, 67.48274710870558, 72.76074332575645, 82.66501826624717, 88.9881927736344, 90.92740474208709, 88.60439669701361, 92.77475480110415, 82.3658198695029, 80.89699422159504, 90.50155301247874, 87.35247811963482, 84.77454739232218, 73.32240320021107, 89.43090285024336, 90.0104408879434, 100.9783527928014, 79.38659929460096, 17.266779484287387, 0.5515376466416544, 1.213932996315341, 0.5640208961502199, 0.2331758362631644, 0.3557554199810951, 0.23994920264569022, 0.5494968496984052, 0.24921207899047484, 0.2905742691889886, 0.1542868597372886, 0.41998597823323747, 0.8140274389616905, 41.45222379315285, 49.43804394814276, 50.07711179794804, 140.73445350893084, 132.19167247895274, 61.58924471947455, 23.752965734850978, 55.81023631557342, 78.79830652667631, 97.88115516785653, 101.83322552711734, 99.02274531702842, 15.476594048161662, 0.2992489279037522, 0.11340782587086001, 0.1366385841561902, 0.11426015231277674, 0.15096948452053532, 0.12491808242855534, 0.20552214595579332, 0.18481143389738378, 0.1377715669091671, 0.28039228651792775, 0.2918385900557041, 0.12958024838759055, 0.32062553890770484, 0.11145985580139584, 0.11359138819839686, 0.18045280729570698, 0.19004525466551705, 0.20713520536739982, 0.12723970422220807, 0.17435365957358193, 0.08942515994872778, 0.15441102726805597, 0.14516923366294754, 0.1654172439368502, 0.2025864663864336, 0.13915317583708994], [0.044853252869459896, 0.05021822789023, 0.06242401567437957, 0.05574456784093092, 0.030291601076662063, 0.06484571153358107, 0.040029292971256285, 0.05215403631389622, 0.05370676630146561, 0.03308204378211691, 0.04512768471613527, 0.036606343177657936, 0.09532566107208691, 0.08494554508116939, 0.11727054843739157, 0.08632455697102893, 0.07341798259726456, 0.05766363341301199, 0.022085366823199778, 0.02836532087155408, 0.0478307148742099, 0.039847684167926355, 83.30463917024674, 106.32809700504427, 90.91453152318155, 97.41411070669852, 58.35450526206725, 26.029421129534324, 33.86340241278372, 72.25264733837497, 45.09763148523147, 49.206220103848366, 55.522408869958696, 13.937565818909677, 0.07169961673958648, 0.012054611823611684, 0.07510724477469921, 0.03560583234854764, 0.2168344300720961, 0.08839095657270762, 0.06460476155963636, 0.09139395228797391, 0.04932775410012372, 0.28940261431759406, 0.6008226568660429, 1.5050405239866627, 8.273631911123953, 46.93830567021524, 90.6102575794343, 87.49078089191069, 86.13177376408731, 84.14252804171655, 76.52988218492078, 69.71746260120024, 65.85402211835309, 70.52226235789638, 80.7008521787582, 84.268279229441, 88.11753642174506, 82.61740069235526, 84.26315661399596, 85.85277557373048, 89.78819939397997, 77.23407314669701, 83.73566842848255, 81.85818672180176, 72.4602819258167, 61.412608623504646, 63.57133603865101, 62.527032436863074, 68.31940435594129, 68.11111081031062, 69.59489637805571, 62.3821714616591, 63.998568442560014, 64.78796897395965, 66.01078356465986, 63.20577113859115, 66.45830246710008, 64.97024936060753, 67.0233355799029, 72.79260866103634, 79.3746752892771, 79.60924871506231, 85.15013002580213, 77.7591137732229, 88.19876870801373, 60.13597911404025, 64.02021208117085, 86.77374809019028, 66.49005013127481, 66.32705211639404, 67.76137659626623, 82.08316603014546, 78.02068879527431, 79.8792411435035, 78.57109146733438, 73.39197035758727, 62.54653053898966, 61.93739037359915, 60.02291287145307, 65.86390649118732, 65.12618318680795, 65.8453066118302, 65.38537733016476, 61.82386913607198, 60.1940066583695, 59.83125802009337, 63.44281173521473, 67.16412513486802, 71.21115607600059, 77.63589643662976, 78.19358687247001, 80.11159450777116, 80.03549268168788, 80.80718763412969, 81.03452820931712, 81.44848731256302, 75.5062141726094, 66.72152488462388, 67.18990295164048, 83.5041936751335, 80.41407200597948, 90.08560134518532, 98.30871705086001, 44.50083894114341, 0.876077373902644, 0.5505394034328, 0.19136856430240218, 0.08401196735400347, 0.06579353849613859, 0.06045633033218403, 0.0200099139774759, 0.12165054123127654, 0.06831538502968128, 0.11456628104731922, 0.07100589348063355, 1.447175267723299, 29.58868965025871, 65.98149914895335, 112.80444791240078, 98.59483826544978, 75.61953929162796, 33.97955163832634, 26.10383241407333, 51.72842571812292, 66.37938437923309, 75.97282717304846, 84.74849500963765, 52.23875353413244, 1.2487950224068858, 0.022450771610883456, 0.1143140312764914, 0.03357589470162507, 0.018042579120505723, 0.028357504859506607, 0.019280749575925932, 0.015515979969002789, 0.12736945653394346, 0.0570158064816027, 0.01669246406715003, 0.03830028232187033, 0.09394265020326262, 0.024863795354782094, 0.029317173626153704, 0.04013988925444503, 0.04472523957731263, 0.04855120141479758, 0.044045516575175914, 0.028348403734966155, 0.07987110890568265, 0.09850610573325427, 0.027370609328030582, 0.009651181415744848, 0.026302286311082786, 0.028200813065913898, 0.07402258684798595, 0.04199146631083662, 0.017389902852535728, 0.050712059657540054, 0.08264961021561777, 0.009283905458306114, 0.01667523091929334, 0.010493163755463978, 0.023748275576039188, 0.06470134226425041, 0.0608149858852548, 0.030811194465645862, 0.08149852480499015, 0.060203218712441386, 0.0700731507893051, 0.05879786488930545, 0.0441197351732802, 0.07042010434933248, 0.01989669767358611, 0.05521710864418457, 0.04039433769761555, 0.7049554562376392, 106.07498645782472, 117.26706966277092, 105.54316013090073, 108.94600452915316, 83.30948721977973, 41.80602158269575, 40.937122452643614, 51.729116055273245, 38.068324442832704, 49.401346252810576, 53.64989288391606, 18.159585460539788, 0.21135008323096463, 0.03848949071740912, 0.1451282786025155, 0.033365768275313804, 0.24343122547912985, 0.18807685303111232, 0.22410265861019013, 0.14353182797710742, 0.20967304015592222, 0.6303212094691493, 0.8520204357562527, 1.1600412236106012, 9.6166387104219, 55.44367121111963, 95.42773615929389, 90.40280342102052, 89.77529479611306, 89.33306324866511, 82.85538658019036, 75.96410382178523, 68.84814769990983, 72.86439587993007, 86.14674152866488, 88.96944384421073, 91.00465974500104, 84.10881919245567, 88.00982029207292, 91.55013592012467, 90.45536318132955, 78.9868470161192, 85.74088604219499, 84.09397694372362, 74.44886084525817, 64.38844419294789, 65.77907739147064, 68.51711534684705, 72.39814373754686, 72.73060383335238, 72.84600780856225, 65.67337736006706, 66.6451249584075, 67.53704055663079, 69.86915634524438, 64.21726411388767, 69.22658581887522, 69.53499394078409, 70.20746861734699, 76.05972336184594, 82.12475099871236, 83.33671631351595, 88.6031650727795, 81.47325315783101, 92.42991570503482, 63.404819657725675, 64.0954117621145, 89.3064146657144, 69.07656300452449, 70.00316019981139, 70.24841031720563, 86.14486663572251, 80.5197798821234, 82.30390133396273, 82.21134124263641, 75.8600119621523, 65.97282286613219, 64.0894183804912, 63.266685547367224, 70.1902807912519, 66.62589749982281, 69.13451210145028, 66.7641532036566, 63.84491351342971, 62.721966389686834, 62.002599777713904, 66.61994334190123, 71.00383527817266, 74.37438288042623, 82.13651026448896, 79.85825646308162, 85.01763236138129, 83.38325131324031, 81.79828428453015, 83.56795572465467, 86.52041004550073, 79.45431509325581, 71.70736728175994, 69.42527740232407, 89.61367745553294, 86.34721386817195, 94.53232965161725, 105.10700041247954, 53.97221365282613, 1.5472707224469033, 0.19567500499467697, 0.11471702416817989, 0.46325174370600336, 0.4297544572862887, 0.08570613249415353, 0.23129481461740312, 0.15881845367050942, 0.19204776253431075, 0.07792971187060879, 0.10823234269816069, 0.9381485754443754, 27.137069048420077, 52.81503600458945, 115.37225892466884, 97.69484258467152, 67.02910930879655, 37.22788210838072, 37.741516482445505, 61.7825940347487, 71.84179475230556, 84.72764368980162, 97.56139570666899, 67.45632602322486, 1.539334664421697, 0.01918831723742187, 0.07878776865019914, 0.022890546299036474, 0.008208288326709261, 0.02356691575128465, 0.011220477097066901, 0.042500696445424715, 0.04941829420145481, 0.016349229863995028, 0.026580998674035076, 0.05284833413879237, 0.06311863525620391, 0.03580971515827602, 0.016155995676414143, 0.007907351274268642, 0.025430229274676214, 0.041018802777773915, 0.030250885418706366, 0.050508218982647506, 0.0812352127245357, 0.04644498439325441, 0.03364340619995229, 0.03725618108986847, 0.009709744049506563, 0.013683317623461687, 0.2843872511819486, 0.11625036447038574, 0.21348359213481027, 0.20776312167365707, 0.20484582821448005, 0.13940042305377223, 0.1716655030125572, 0.20560803973386366, 0.21559842381506197, 0.16743562514743499, 0.10176490586731704, 0.1747927811717795, 0.18640587737243022, 0.1374609488993883, 0.1949586514984408, 0.21196293824863052, 0.2207130719456942, 0.22535985485920984, 0.06736597226512048, 0.29811208406763695, 0.13958002470674055, 1.4609663212491621, 122.34153409158031, 132.46932921871064, 120.94210301676105, 123.97309103319724, 80.79003118699598, 42.566969240865404, 47.71619404515913, 94.75417890856343, 62.05766201019288, 67.25665384723295, 85.43004605077928, 22.57341096478124, 0.3651211206470767, 0.13959047414602774, 0.5813951574025616, 0.12348352916418545, 0.4880117360622653, 0.2581193832860839, 0.4048005833981499, 0.31141075756280656, 0.5729059226089909, 1.764563778715749, 2.3824905435885153, 2.5642497452997395, 10.536331553612987, 64.53631362607403, 99.83589187745126, 95.52328509669151, 94.66440370005947, 93.99891084240329, 87.30908101604831, 79.5677657281199, 73.44595001589867, 77.32851597570604, 91.31534284160983, 91.48940194037654, 95.84821424176617, 87.52823168231596, 91.6887838609757, 94.64760811098161, 93.44785705689462, 79.14185908532913, 87.14369820010278, 89.96728697130757, 80.45171891489338, 68.87001883599066, 68.9838146394299, 71.04195287150722, 74.73359354080694, 75.92975954855643, 77.01901743488928, 68.59921055455362, 71.25532980888121, 71.18018504111998, 72.7006212357552, 66.92049103398477, 72.1121088151009, 72.63951855321085, 73.67793467737013, 81.18896761248189, 87.48235564078055, 85.49201165476154, 93.2654433096609, 85.18029305242723, 93.97544722403251, 68.68679708050144, 71.74575159626623, 93.42228320337112, 74.58268427079724, 72.5177054251394, 74.78206619139641, 89.65665094314083, 84.65886885120024, 84.49296828239196, 85.9141057537448, 81.11696074085852, 70.62925677145682, 67.54075896355414, 67.18858503526258, 73.23601691953598, 69.16476142021918, 73.48793506622314, 71.19396040516516, 68.89759309830205, 68.09618226943478, 66.93746705209055, 68.44282565578338, 74.29170716193416, 78.18353776008853, 88.15423411707725, 84.17222822866133, 89.40067706569549, 87.70132587802026, 82.26069250414449, 86.03364390711631, 88.82924264477145, 82.19838173158708, 74.83200580843034, 74.04345250898793, 92.24517991465908, 87.28859839900848, 96.14446301614085, 105.78930454869425, 51.47914340419155, 1.4126677258360771, 1.5557334812418109, 0.48370092866882203, 0.3171637714389832, 0.2933404288224636, 0.3050215536307904, 0.3799041048172982, 0.34423174156296643, 0.4092890925465092, 0.32647878772789435, 0.2645191898749721, 2.296187613279589, 49.9915413702688, 85.44996384651431, 115.92410502895233, 106.54436080686509, 97.48178728165166, 47.95852984151533, 45.79055739987282, 73.03892566311744, 86.63167199780865, 98.34889781090521, 107.41655472786196, 73.52207537620299, 1.6825546180048299, 0.1482937998709179, 0.17264762773148476, 0.07151989251255028, 0.10173462241167024, 0.18477470764229376, 0.22548684159353857, 0.14816721150230977, 0.18953078065908727, 0.14446968813577007, 0.1308121484133505, 0.17528623372556704, 0.21830850581247963, 0.17102349068849318, 0.14125268575885605, 0.16439886793734568, 0.0812105140498569, 0.12306578907995455, 0.13386879326595416, 0.16434646752332488, 0.16032157946498166, 0.13197097897289262, 0.1600717428711153, 0.08515821108894964, 0.10560774079133427, 0.1468196781652589], [0.0085278868021804, 0.06072751396606046, 0.021795592150620876, 0.04790007264443463, 0.03257528428108462, 0.0869025243446231, 0.04658035212947477, 0.0923756173541469, 0.03402239372653346, 0.07227206828012582, 0.0653127646974979, 0.0766136724081251, 0.04281681879693943, 0.024530068302767414, 0.03270404450895806, 0.023623659883836107, 0.04414706919041853, 0.11569647524025171, 0.0706370757712472, 0.1422878390839023, 0.4790838699667685, 20.378750716486287, 118.0385135835217, 111.82657749422135, 92.29163646698, 63.75327517909389, 44.0632789365707, 44.17723555718699, 53.48387072163244, 75.27382942938036, 61.529279524280184, 48.69364084735994, 22.658675447587047, 0.06158922498504962, 0.21854015547902356, 0.031182268303969217, 0.059328533994454535, 0.08496485049686126, 0.1385248611651121, 0.10977705174516286, 0.01858366127576559, 0.109189722777134, 0.40374436265518593, 1.0196808617441886, 1.1199664901341162, 9.214593806574422, 43.059666002950365, 72.53397541661417, 84.80970751854682, 87.66766409720145, 90.69296467688777, 84.46442911701818, 83.85479865535613, 67.85581942527526, 66.06874050632601, 67.62623525434925, 76.32465593276486, 76.87477619417253, 80.0258279615833, 75.14443043739566, 80.86103393185525, 79.6557366463446, 86.45325906815069, 82.98107500999205, 83.9959490683771, 80.68452727410101, 72.25900157805413, 62.437049342739975, 63.95432018464612, 69.10885980052333, 76.1213908656951, 77.16040319012058, 73.69494207443731, 67.04770918815368, 59.96777611394083, 61.71068522237963, 64.94003926554035, 59.78578598268571, 63.79924143514326, 66.45038712409236, 65.91568177746188, 66.88612322653493, 74.20648190283006, 76.51253746401879, 81.67539642703149, 78.83654963585639, 80.54028603338426, 49.118417847541075, 52.712195381041504, 83.41452829299435, 67.86251883352956, 67.53711900403424, 60.74987711444978, 74.71776285479146, 79.81299231129309, 76.2891584827054, 76.68327823761972, 74.11360802188997, 65.8943989969069, 62.630539863340324, 57.51882860737463, 62.48033269759148, 65.05456462983163, 63.463941543333, 60.43098057470014, 60.836122189798665, 56.950190836383456, 59.72180035806472, 62.220459984194854, 63.395955101136245, 62.67726313683295, 65.2407124734694, 68.08059477037, 75.26303506666615, 76.7475188163019, 82.71913128514444, 80.8515888644803, 81.81835113033172, 80.22183664383428, 68.98048846952378, 59.13555898974019, 71.40900827223255, 80.74840699472736, 82.90181959829023, 77.56625867659046, 102.76227028139176, 54.76225745293402, 0.5421102912195268, 1.0307695860824277, 0.2368184464472917, 0.3001853324953587, 0.054791447210816614, 0.06999396028057223, 0.11249200606177892, 0.1547693725555174, 0.11508254769949183, 0.09778929258426351, 0.05594430228454932, 3.582953998158055, 37.84710276511408, 36.95687378606489, 39.72094843464513, 46.82389013228878, 70.5327586204775, 27.4142276471661, 34.3842343361147, 51.45413044960269, 66.9918389474192, 77.8565768272646, 88.19550529603036, 16.72811842733814, 0.5389912102010943, 0.1328819647671715, 0.11283956483126649, 0.04014235222712159, 0.13260389017241617, 0.027474829844469507, 0.08412746276946799, 0.01747078066992183, 0.08230469444946897, 0.1343354020988749, 0.05339494553364573, 0.04893759701160654, 0.039274022208466645, 0.025202295134565043, 0.046500828372494835, 0.037993261094896064, 0.07855196678710562, 0.03326248047092269, 0.07766282215954796, 0.04675101736680635, 0.06065271697157334, 0.019081480530721527, 0.0558565660650211, 0.04742289562859843, 0.08308018993345961, 0.013195933443644356, 0.06396808886840459, 0.018503915353287614, 0.03713195993294639, 0.020407701301718914, 0.03555740793085387, 0.05401427016383218, 0.08809866338607766, 0.07737032979005769, 0.04850445856009761, 0.06601709061332288, 0.06314489291980863, 0.05148180182121935, 0.05199418057717624, 0.1467915780601963, 0.11991434084672122, 0.07310617715120316, 0.20609018482988883, 0.04337405583130256, 0.19298588316286766, 0.5368658984380384, 28.60980922175992, 140.09518561824677, 121.86854331724106, 105.16120756826093, 76.2100835000315, 62.761488191543094, 50.33222275395548, 56.02328377385294, 73.47935292028612, 51.845535924357755, 44.48840895006734, 29.881263163781938, 0.13341327738617698, 0.11625126079325715, 0.23750075499617287, 0.10603748547333865, 0.3426422010506353, 0.8813475685254221, 1.190856466850927, 0.07755153256678775, 0.17607237783170518, 0.6451640097844986, 2.456587548217466, 1.1704630837325127, 10.627265822502876, 51.59667722640499, 80.75039955877489, 87.62036031292331, 92.26887103049987, 95.50767406340569, 87.67497539520265, 88.29920491864605, 69.690688502404, 70.57590469237297, 70.5205600492416, 79.89657017492479, 80.8797279480965, 83.20610138677782, 78.76946926116943, 85.12589762287756, 84.4082058629682, 88.7106066365396, 84.49045796548167, 85.65466450106713, 84.125944260628, 76.2331235024237, 66.86621327554026, 66.54373168945312, 74.66038642391082, 77.8649942336544, 78.13846972680862, 77.64669079934397, 69.72143203981462, 65.35796388503044, 64.69251809581634, 66.56092736028856, 61.25485481754426, 68.49723677481374, 70.47369557042276, 70.92846301294142, 69.61774810667961, 76.97063107644358, 79.3651282402777, 85.23040525374874, 79.61098240267846, 85.92515114815005, 51.49949658301569, 53.76005657257573, 88.48282675589286, 70.01553135533487, 71.40762759793189, 62.19093238153766, 76.68763991325133, 83.15618530396493, 79.29509824322116, 77.9972408663842, 77.85561976894256, 68.91524376407747, 66.29666159229895, 60.661423744693884, 64.88694998525804, 67.56377543172529, 67.79455984792402, 63.13635303128151, 63.25334556641118, 60.261181169940585, 61.35672661565966, 64.5717522405809, 65.96006731833181, 65.3645730787708, 68.32018882997575, 70.86015101402037, 78.25027296620031, 80.60986103550081, 84.77653211162936, 82.85598278045654, 85.44040895277455, 83.69711152968868, 73.73923347842309, 64.01404611525997, 74.19312231002316, 85.04726194566297, 87.55608835527974, 79.62321235287575, 106.24655877390217, 64.11628661617156, 0.7701190789380382, 0.8122841292811979, 1.1329801789214535, 1.2417397816335003, 0.5549761556809949, 0.30687637506954135, 0.2225079853087664, 0.2061543063891511, 0.20370330000596665, 0.17626311840309253, 0.05792537118278204, 2.8186848278968566, 38.210804539342085, 42.21293218674199, 49.389069234171224, 46.001306349231356, 63.03620707604193, 35.87368772875878, 45.500164724165394, 58.37675294568462, 75.47894585517146, 85.8404593313894, 103.5560481779037, 24.24062225126451, 0.5624532963960402, 0.187890846883097, 0.06597460337704228, 0.04050991355231212, 0.0933404591295027, 0.03629005228679988, 0.07265410866708526, 0.03423445069441392, 0.08825818587455057, 0.09203702181337342, 0.04782411502674223, 0.06909774466147346, 0.07172478272789909, 0.031487943131416556, 0.05118324203536876, 0.1043096584297957, 0.0653168632678928, 0.020070350653822386, 0.04327165668890361, 0.021782639519041105, 0.02276330675569273, 0.014825654309994031, 0.01783956965101102, 0.02307684547568281, 0.036169719026093526, 0.08552183472220937, 0.17179800557994074, 0.15260466855139504, 0.12896917069390898, 0.14821440251844545, 0.13044148443206666, 0.10223603461899104, 0.16295588004492945, 0.1469676863522299, 0.23449851770795163, 0.22788108086153386, 0.17390399660554626, 0.11240288705354738, 0.11887052306725134, 0.24579212460066044, 0.31663158547974407, 0.2347767761638088, 0.30509613995109836, 0.2863181298298221, 0.4100821774092413, 0.8831892438953923, 35.70350785409251, 156.10126433833955, 134.04529048550515, 119.16473588635846, 87.18336120728524, 64.53179113326534, 57.46839084932881, 68.94248070255404, 97.52456465075093, 87.28667643762405, 76.53937432073778, 37.28764334032613, 0.4274708104710426, 0.3220604215898822, 0.3533832440453191, 0.18151835898958868, 0.5007573860066553, 0.571482224810508, 0.5578591590446811, 0.35776192682885355, 0.25502978133097776, 1.1200886964797974, 3.493967676354993, 2.2809595013818433, 14.89661572440978, 63.98526376293552, 85.95172912843766, 90.43414315869732, 96.93811539680728, 99.7288425507084, 92.16751698524722, 93.26759276851531, 74.4516457280805, 74.75865748620804, 76.5358991007651, 84.35395163874473, 84.70804752842074, 85.75390831116708, 83.89152772964971, 90.3603869099771, 88.0528094691615, 93.44522122413882, 85.69033453541418, 88.45313441368842, 88.10196461216097, 79.520626683389, 70.07588094280612, 69.94405008131459, 78.61940722311698, 82.1832178485009, 83.08945794259348, 81.96251392364502, 72.50135698626119, 68.43531823927357, 68.15297034478957, 71.92605510834726, 65.42367535252725, 71.01306853755828, 74.88261222839355, 73.88453375908637, 73.21351820422758, 82.1927256737986, 83.06826145418229, 89.2024326324463, 83.32249379927113, 89.9250901129938, 57.36798601765787, 60.509173024085264, 91.62113866498395, 77.17963849344562, 73.7997321159609, 66.84060804305538, 79.67840010120024, 87.95864905080488, 83.0366236163724, 81.8199122336603, 80.4220893306117, 72.07874513441517, 70.42711350225633, 62.42199528601862, 68.45254528907039, 71.2123877002347, 70.92224997858848, 66.37463046658424, 67.61887688790598, 64.4160694460715, 65.73969679494058, 70.52325863992014, 71.35294191298946, 70.7501442201676, 70.72324460552585, 76.57000803178357, 82.67115285319667, 84.94730426419167, 90.4644944590907, 86.96678361585064, 89.53760700841104, 88.29671029121646, 75.75948945937618, 66.30274911080637, 77.60487048856675, 88.00222658341931, 90.4470948250063, 82.05112026583764, 109.43805802252986, 62.92203864743633, 0.46978316420028293, 4.285382589986248, 1.9541088852190205, 1.260994451661264, 0.5030402667339772, 0.5222719847675293, 0.39010618963549215, 0.5208249366091144, 0.40660646714029774, 0.2166941134078849, 0.14430366156082, 7.495851891656076, 57.01686328457248, 50.15017770951795, 50.9145966652901, 62.09795259660291, 92.39591660038118, 40.46881498829011, 51.77877718402494, 70.00694136465751, 89.41313451336276, 96.4317060285999, 114.89887591331237, 24.54753398895264, 0.6925981515838254, 0.30455908167266077, 0.17899786843167198, 0.21451649316135915, 0.23317749101308086, 0.10578821578453626, 0.14419496900612308, 0.11707761685454077, 0.22439084556554595, 0.16985088586807254, 0.2140675656377308, 0.15429923971814496, 0.18777415637047062, 0.15886769780228216, 0.22024275524721992, 0.17292564103920616, 0.24489017864388807, 0.12630977307356175, 0.1915049279529241, 0.10689639261052494, 0.11754346726041649, 0.14868513290439883, 0.20738965381057034, 0.21029288189545756, 0.14197893711107393], [0.06413153372704983, 0.03917443843918943, 0.03740042395469162, 0.008120180554537764, 0.05380326273640799, 0.04694592928694141, 0.07244081446720708, 0.015466415037911747, 0.037369060315071576, 0.043668298711699825, 0.02372044168653027, 0.02441982058958421, 0.040228322613984346, 0.05433989966648722, 0.015863820275802527, 0.05696583456630188, 0.010120429421564745, 0.06296093222655116, 0.06644011670423132, 0.1808140330737637, 0.048354883723321467, 51.33321162193052, 126.00926399230958, 89.97349216092019, 95.3546388687626, 53.76276300799463, 34.9947081073638, 36.813154220581055, 57.256963329930464, 55.593737171542266, 47.70456421759821, 45.58842197541268, 1.3118483486675447, 0.04336311226530422, 0.166614179709746, 0.1159062990618329, 0.24751263550452648, 0.2947263431645209, 0.7779723381803882, 1.4540410089877345, 0.04824622947302076, 0.12846236522760124, 0.8220002692072623, 1.7724542391877023, 29.601537373758134, 77.7299548733619, 86.04233587941816, 80.34241814767161, 86.06417563653763, 85.5674623673962, 90.00250201071464, 86.24470664608864, 82.90497318390878, 71.68123645167198, 62.939873664609856, 62.33648761626213, 67.45909521656652, 71.5951168921686, 72.89082481015113, 69.03489958855414, 72.3453329455468, 79.1322571231473, 82.40275290704544, 85.2332607392342, 83.3171279968754, 77.45156857275194, 72.4103815324845, 69.71932964940225, 72.27688758603989, 74.3066200133293, 78.98059475806453, 80.85998273664906, 80.95254282797538, 69.59117797113234, 63.51976863799557, 63.20038964671474, 64.99994562518212, 60.47268713674238, 63.41455890286354, 62.34280263223956, 62.731164347740915, 65.40881349194434, 69.86349244271555, 71.95440599995275, 81.08669573260893, 74.92481693144768, 82.68852895306003, 41.303330621411725, 37.76474475860596, 92.1025860694147, 70.98525108829622, 77.15043252514255, 65.87396344830914, 69.061414810919, 74.97588619109123, 76.53188259370866, 75.03643189707111, 74.32198001492408, 70.2270177102858, 62.64563706613357, 58.00601443936748, 59.452588481287805, 62.308277929982836, 62.643856310075336, 59.668824826517415, 57.43626271524737, 55.79280530252765, 59.16829509119834, 58.86854364025978, 58.580343569478686, 60.332925242762414, 60.411706047673384, 62.204609686328524, 64.7341775894165, 74.07552180751678, 78.76846513440533, 83.52094219576928, 79.9433248273788, 80.2284340704641, 71.83710359757947, 62.065298864918375, 60.98116359403057, 69.46503454639067, 76.69364898435532, 89.30770904787126, 78.25798434595909, 98.07080961042836, 33.659709807365175, 0.789062594694476, 1.7566452487822504, 1.716655091412606, 0.20835979691436216, 0.08640456719384079, 0.471876238983485, 0.015225329083360493, 0.1873774607215197, 0.045991000689325795, 0.04245578837130339, 0.11285654133966855, 9.206514704611994, 37.90144328148135, 30.91775928774188, 33.78866949389058, 58.34924928603634, 60.814392259044034, 34.96227402840891, 40.77793698157034, 61.2003299497789, 68.24749946594238, 88.29720450985818, 65.526488519484, 1.0438096282943603, 0.04804059998282502, 0.024170738592323278, 0.04665910979853042, 0.08509769014293149, 0.03926514707986386, 0.018348774887741576, 0.0813432924088932, 0.10561735519478399, 0.09676572250863237, 0.06439965683966875, 0.0573784418614401, 0.021613512203217517, 0.04152718638520568, 0.01831719291306311, 0.018532220386869965, 0.04443288127320909, 0.09955699450426525, 0.040131240121779904, 0.07109266059893755, 0.04451345074020567, 0.046790608790733164, 0.04052348096945113, 0.015020073061027836, 0.04571725449134265, 0.018565510737619573, 0.06662408505836803, 0.08355520275090972, 0.028717171648637425, 0.04063301239042513, 0.037289578692927476, 0.02505503005288061, 0.0358610583709613, 0.011646195029419278, 0.033755768315806504, 0.017506771480604526, 0.05132857657548401, 0.021823056402706334, 0.010250077353820447, 0.019577227517842286, 0.07298820727174321, 0.011680489912959597, 0.05601598513162425, 0.049494424188930186, 0.243017400104192, 0.02199791597142335, 67.25013486800655, 139.36463632891255, 100.58068721525132, 106.50023414242654, 69.26202051101193, 46.532803197060865, 30.869569047804806, 26.734924124133205, 61.99293897997949, 52.2174354522459, 45.17181527230048, 1.2486848283198573, 0.04386982580106105, 0.035184483990193374, 0.41117887823812427, 0.29464869249251585, 0.4577696798068862, 2.698967961534377, 5.8962804079055795, 0.9236901061188791, 0.13462236331355187, 1.456088853939887, 1.6147986150556997, 32.435628291099306, 85.79480294258364, 95.56257155633743, 89.73511403606784, 91.0633776264806, 88.9885457869499, 93.70900846296742, 91.06832765763806, 88.35331009280297, 76.82839808925506, 66.55397692034322, 65.97512921979352, 72.44168204645958, 74.49789047241211, 75.52391975156723, 73.16245678932437, 75.38946874680059, 81.82371693272745, 84.95657674727902, 85.47149765876033, 84.78008577900549, 81.26448108303933, 75.25230346187469, 73.91416334336805, 78.25960820721042, 78.3037897848314, 83.59949158084008, 83.27837497957292, 82.93763868270382, 73.69262787603563, 64.9791649080092, 65.28962050714802, 67.80221631450038, 62.85272252175116, 66.22711012440344, 65.45914926836568, 66.62090824496362, 67.55108264184767, 73.04224398828322, 73.90002712126702, 84.14125719378072, 76.92082481999552, 87.24569551406368, 46.79177768768803, 39.18091258695049, 96.97896295978178, 74.11935037182224, 79.8475170135498, 68.04243010859336, 70.947141339702, 77.75794490691155, 79.44790594039425, 77.29921587051885, 79.14338880969633, 72.92028965488558, 65.9572353670674, 58.47143896164433, 63.487981750119125, 63.69018385487219, 65.00016135554161, 63.8890911686805, 61.13364573447936, 60.062987727503625, 61.0937983758988, 61.52108961536039, 62.9574066592801, 64.77849252762334, 63.370620512193256, 65.85570873752718, 69.40207266038465, 77.72428312609273, 82.31153426631805, 85.62457207710513, 84.73394301629837, 82.59620420394405, 75.16525037827031, 64.93992551680535, 66.9939648720526, 73.04599377416795, 79.36285326557775, 93.00428405884774, 82.86023462972334, 101.35187225957071, 42.27057141642417, 0.45567044567677284, 1.627360740976949, 2.3332760747401946, 1.018100575573983, 0.6824637276511039, 0.828585806152513, 0.35877460313420145, 0.10175630269992737, 0.4442358173189625, 0.014402698124608686, 0.09806551324624209, 10.404428128273258, 38.59682852222074, 33.33133682127922, 40.805515166251894, 50.63470417453397, 51.36921505774222, 41.23785449612526, 53.67845950588104, 65.53443524145311, 78.79574129658361, 96.77004183492353, 84.72449010418308, 2.40832842165424, 0.1518064049342948, 0.06457547401829113, 0.06227019671050291, 0.05912574286001825, 0.08892357920206363, 0.02709129558605773, 0.006798280998238273, 0.06318139700940059, 0.010195755974329528, 0.00905298357529025, 0.02870533175976767, 0.03666774895522864, 0.09212863060735887, 0.02270140685141087, 0.020580253030564037, 0.03421334497209999, 0.04211500947994571, 0.06529600269371463, 0.01997107331971488, 0.024124183429164753, 0.061530803119943994, 0.11213543043742258, 0.0070864344372474145, 0.028752900074206056, 0.14924569476035335, 0.10609864227233395, 0.20313107829180457, 0.12380648885042438, 0.2167212482421629, 0.17056834253091968, 0.11065389300065656, 0.09120811467930194, 0.14756707354418694, 0.24456560251212892, 0.11082823162958508, 0.12841318238286242, 0.11334171248299461, 0.13645149016332242, 0.09747573279685552, 0.1852516586621923, 0.1099119674895079, 0.13443362989252614, 0.2164461307467953, 0.30412792738887573, 0.1477949847016604, 77.99644070286905, 156.35086828662506, 112.40661759530346, 124.01089483691801, 76.44689267681491, 49.772512297476496, 51.82092697389665, 78.29183440054618, 76.09277325291788, 71.83605240237328, 71.25899330262216, 1.949926167726517, 0.19411195580276752, 0.309543831934852, 0.6180323011452152, 0.8194575314560245, 0.8782841974208433, 1.659239314256176, 6.603330287241167, 1.0112497270587952, 0.5131335364234063, 2.1638434115917455, 2.875762668348128, 38.7318443482922, 94.02596735185193, 101.34966788753387, 92.21722910481115, 95.74391841888429, 89.2683990540043, 95.18037580674695, 93.43790992613762, 92.43277903526061, 82.36308989986297, 70.16970403732793, 68.85635329831031, 76.5730361015566, 78.51140083805208, 80.61646630687099, 78.09762216383412, 79.933973896888, 86.72693852455386, 89.87842959742393, 90.25095278216948, 86.75364986542733, 87.38258623307752, 79.06520812742173, 76.99199230440202, 79.82814050489857, 83.64364177949967, 86.21885038191273, 86.48540681408298, 85.40102051150414, 76.1945273799281, 69.36163302390807, 68.66764022457984, 72.16970489871117, 66.37773698376071, 70.27484709216704, 69.01614281439012, 69.61947394955543, 72.00226676079535, 75.86318123725154, 78.06619613401352, 87.31475276331749, 81.99182187357258, 90.26639907590805, 50.26740166448778, 44.96018771202334, 99.36410134838474, 79.09474357481926, 84.04493947182932, 73.31454277038574, 76.42361733221239, 83.46580936062722, 82.41706955817439, 79.85101576774352, 82.92371426859211, 77.38565706437635, 70.28812039283015, 64.49073568467172, 65.89519916042205, 66.75673992403092, 70.39576591983919, 65.65490299655546, 64.51060248959449, 62.87183230923068, 66.0321291031376, 66.22536859204693, 67.0810728688394, 67.78843310571486, 67.80208295391452, 70.09004069912818, 73.79868876549506, 81.54402056047994, 86.66357655679026, 88.82372779230919, 86.7538538286763, 86.57223240021737, 79.22034571247717, 68.28987675328409, 69.5161194955149, 76.52532439078055, 81.82306581927885, 97.20649965347783, 86.4076340583063, 105.05191464577953, 40.96868184305007, 2.0017265816850047, 9.329128976791136, 6.154292937247984, 0.8466856445996993, 0.7410327429252287, 1.7129004025651564, 0.7681925823130916, 0.9678147480853143, 0.48493552532407547, 0.10374404805442018, 0.17182697902523703, 16.550954772580056, 61.125753925692656, 42.75674527691257, 52.27945204704039, 74.40376143301688, 75.14060220410748, 47.73845349588702, 59.058868808131066, 78.28152641173332, 89.44565880683162, 108.59350112176712, 91.21143925574519, 2.1830772440279684, 0.31813599830192907, 0.14711336563191107, 0.17610231654778605, 0.16684923080667374, 0.2539283767222397, 0.092063543777312, 0.1528004806248411, 0.16352580349531867, 0.2169513197675828, 0.1756332562335076, 0.11745547440143363, 0.1794891146522376, 0.15460362177222006, 0.1627600220062079, 0.08193291197981566, 0.21018641099574106, 0.18163276656020075, 0.1438313683555011, 0.18380713859392753, 0.1751688230902918, 0.09686470106844941, 0.22655639226638505, 0.07865348109795202, 0.12665132571372295], [0.015403551778065102, 0.030105102717155413, 0.04462535703374494, 0.049167867719886765, 0.011727007729331813, 0.007591044104042193, 0.023071228135978023, 0.05912237973403066, 0.008777224481286061, 0.05357073589919075, 0.07020625090526958, 0.017299753456046025, 0.04630099050700665, 0.035659462333686893, 0.08862806844615168, 0.049591276854757345, 0.05681289660353815, 0.08688449829576478, 0.0879091562162484, 0.15069551615705415, 3.6838491261005406, 95.02093930398264, 103.59917856031849, 95.05686821476107, 84.6521302192442, 52.82286897782357, 40.42938340094782, 118.97079037081812, 180.01160929279945, 79.92532899302822, 50.78728045186689, 10.250887928470489, 0.12312656283498773, 0.22718165790842426, 0.061462835799301827, 0.1779698703678385, 0.11151419441786506, 0.27833111163589264, 3.8148920814837184, 4.850422566936863, 0.336699319943305, 0.45838291786851426, 3.11658590070663, 50.280012084591775, 89.259628634299, 80.08475765105217, 81.15076372700354, 81.63195225500291, 84.31795212530321, 88.9789124458067, 84.1208138004426, 87.22106302938154, 83.8961482817127, 70.14613843733265, 61.09622632303546, 62.426694285485056, 62.75300410486037, 64.81450380817537, 64.28241076007967, 64.76070457889189, 67.53842123093145, 74.73650393947479, 79.47458590230634, 82.99093584860526, 82.06291875531598, 84.78642432920395, 78.57676321460356, 74.02851612337174, 76.47760483526415, 79.72247185245638, 78.05996741017988, 80.01690849181145, 76.75290815291866, 69.87238053352603, 60.13510442549183, 62.17678439232611, 64.4349988045231, 58.859122107105875, 59.61404892706103, 60.267366747702326, 60.48537208187965, 59.624839367405066, 60.401578487888465, 61.61898020775088, 68.2299429370511, 68.56595670023273, 83.27788860567155, 56.76830268675282, 27.53896294101592, 73.18006823139807, 75.63136131532731, 79.1989609502977, 71.3116942682574, 61.69107337151805, 67.38072626052364, 77.1607562034361, 74.10655560032015, 73.22803097386515, 70.11151175345145, 64.3871537331612, 59.112122827960604, 59.733967550339244, 59.66868754356139, 58.973545489772675, 57.29685383458292, 57.25637889677479, 57.11282799320837, 59.57095384597779, 56.68192817318825, 58.7203251161883, 60.51134209479056, 62.749972112717174, 61.223475856165734, 66.45972236510246, 72.44707138307633, 78.64372591818534, 77.10368571742889, 81.71800121184319, 77.17830488758703, 74.62407312085553, 59.45485953361758, 63.63334478870515, 62.55264159171813, 67.9551887512207, 73.68503416738203, 88.57348057531541, 81.28919985986526, 96.0591043964509, 8.728115962397668, 1.7961609219351125, 2.271905935579731, 1.4091663975869457, 0.0782979320314142, 0.0879666970802411, 0.1672420194072108, 0.2729062591829608, 0.555297606174023, 0.12280294431313393, 0.05057115693606677, 0.3176489808867055, 21.434513522732644, 38.10741478397001, 44.336981927194905, 72.98602073423325, 133.1594153373472, 51.42838008942143, 27.08949265941497, 50.43399649281656, 66.45568232382497, 70.30703406180106, 83.60491229641823, 15.9146394460432, 0.7827326246807653, 0.13526667390138875, 0.12507423413016144, 0.08368674770838792, 0.1196514807581421, 0.03717311034579912, 0.062108303179904345, 0.08207018727496748, 0.030858561682004123, 0.054795174228568236, 0.011931574272532618, 0.0347478483473101, 0.09172357693915406, 0.030088524574473984, 0.042708313933783965, 0.019660451479496497, 0.005904470416416805, 0.019394293382403352, 0.07855952807491826, 0.10842281513877454, 0.02058481508415313, 0.05246449344521088, 0.06351873616597827, 0.021145235213841644, 0.03586323023022663, 0.05188715043327501, 0.030351285071622942, 0.03721707613177357, 0.04761879963259544, 0.014045323853591278, 0.10826798876927746, 0.038082652064340736, 0.04054732162565474, 0.04522439182525681, 0.05791173098729022, 0.04540245747193695, 0.09011244040823753, 0.03584731858403933, 0.16846536989173583, 0.059122644034364534, 0.029097792857717124, 0.05121447544004168, 0.18397586179837105, 0.4015530141130571, 6.3902602753331585, 117.70716744084513, 112.91017932276573, 108.74763458005845, 93.14028047746228, 66.90118512799664, 43.109656610796534, 70.44323444366455, 120.78591423649942, 55.98137324856174, 54.61729841847574, 13.466555841507452, 0.141317711301869, 0.017532498628321676, 0.361035481816338, 0.3569725804751919, 0.519592454356532, 0.7677964842127216, 5.096730253388805, 7.180611491203309, 0.9844997753539394, 0.41326701941509403, 3.885334662852749, 54.19796959046395, 101.14762659995787, 88.37467132076141, 87.55434682292324, 89.13870196188651, 90.21646730361446, 91.05148500011813, 88.72069497262278, 89.37049050484934, 90.22690080827283, 74.35517111132222, 65.4535363566491, 63.92642036561043, 65.91565824324086, 67.88930862180649, 67.72723628628638, 68.37385469867338, 70.33023880374047, 75.25366844669466, 83.8718060524233, 85.13853549957277, 83.19239662539574, 86.17561017313312, 83.1418372738746, 78.27147729935186, 80.72779101710167, 82.67347489633869, 81.5900299626012, 81.67846372050624, 81.52140417406636, 71.71453737443494, 62.62042407066592, 62.99458288377332, 67.42927735851657, 63.78597597922049, 63.04118848616078, 62.55891346162366, 62.747689293276885, 61.38565017331032, 65.7487339358176, 63.62297011959938, 70.04970304427609, 70.91977104063957, 86.33511727856052, 62.87212648699361, 31.208293168775498, 76.5432103987663, 79.84590884177916, 84.0265827794229, 76.06799171816918, 66.76944840338923, 71.0291188763034, 80.58145523071289, 77.57342876926546, 76.53385162353516, 72.94401214968774, 67.58170066341278, 62.91891644077917, 62.51475541822372, 61.98278396360336, 60.61506132925711, 58.6179865560224, 61.35385544069352, 59.08050460200156, 62.34051981279927, 60.57410786228796, 62.89796706168883, 63.96929971633419, 62.976124209742395, 64.69669149767968, 69.64920551546159, 75.18619583499047, 81.50558133279124, 79.85591873045891, 84.33685010479343, 82.91950164302703, 78.6394505346975, 64.7283411026001, 65.77563747282952, 66.35581877923781, 72.20404132719963, 74.78402737648257, 94.5956680851598, 83.92018456612864, 101.21607195946478, 12.69364397371969, 0.9715443092488474, 2.1525891509748276, 1.7038502688369446, 1.4833912469687, 1.474798191939631, 0.5065739851805472, 0.5969749955881027, 0.9195387063007202, 0.25758155891972206, 0.03079747000048238, 0.09891140454959485, 25.055541723005234, 32.60734769605821, 40.75098245374618, 59.75401870666012, 107.43379746713947, 49.72588708323818, 38.95294835490566, 59.06338737856958, 75.83636791475358, 79.0380653258293, 101.0325913275442, 25.18259317644181, 0.8244629048051373, 0.1465397802812438, 0.11577209577925744, 0.059353087112427726, 0.092260520304403, 0.03128044247146576, 0.09214370721770872, 0.05614642309205187, 0.040842667672662966, 0.0337377269451897, 0.07498876161633, 0.022947368955600168, 0.056072468794281446, 0.05584865620720291, 0.0697708678161425, 0.0404455506753537, 0.036688544411933234, 0.026704765923862017, 0.016507668338055094, 0.04839047999872316, 0.0512274184955224, 0.030444039167055202, 0.05587673332962779, 0.06462405931444899, 0.15248122114327647, 0.16784676921463784, 0.17597810305174322, 0.17029126385046592, 0.10474717890423153, 0.11951596746521613, 0.23851392159779228, 0.11858971353860633, 0.18632313987660795, 0.15605112958338954, 0.11672152386557673, 0.12167212958898276, 0.2712085776992383, 0.09854933607482141, 0.29637478051647065, 0.12437340157527117, 0.11048490166543953, 0.16540561472215962, 0.2652073819791117, 0.6272940590016304, 8.20317780779254, 134.02950686793176, 128.6997667435677, 120.8646518953385, 106.7532583975023, 72.83868082108037, 59.38174263123543, 141.41093684780984, 201.73859042506066, 102.04976389485022, 75.8641775192753, 17.28658745365758, 0.19975471430488173, 0.41396805115284463, 0.40723753972880306, 0.9433413645432842, 1.1148873884831707, 0.7844516646958167, 12.674195881812805, 16.470603058415076, 2.8017230283829475, 1.5452220194762754, 5.535386560424682, 61.54355302933724, 105.40856792080788, 90.10377760856383, 91.16392366347775, 93.60237490746283, 94.39048105670561, 95.38362518433603, 90.2174400514172, 96.04753340444258, 92.35653600385113, 78.60680857012349, 68.65784998862975, 69.03530751505207, 69.25766668012066, 71.83935503805839, 70.87102382413804, 71.3412218709146, 75.21347199716877, 79.44768628766461, 87.84081320608817, 90.7714513040358, 86.12458798193163, 90.87986561559862, 86.97040788588986, 83.18969018997686, 84.88944930415, 87.64839741491502, 82.70308094639933, 85.3139909621208, 87.16334927466609, 76.86538603998001, 65.22755292154127, 66.85384996475713, 70.01509989461591, 66.33211197391634, 65.11729117362731, 67.40383686557894, 66.69969297224476, 65.47174792135915, 69.52095970030754, 68.50202206642398, 74.66763496398926, 75.20022223072668, 89.93138159475019, 65.53106592547509, 36.98205148020099, 84.52799504803073, 83.25010253537087, 87.0926760089013, 81.44133290936871, 70.97529611279889, 75.5856264791181, 86.32274612303704, 81.18248785695722, 78.86704214157598, 76.23519451387467, 70.62536578024589, 66.44646475392004, 67.68883628229942, 65.47744712521954, 64.62319412539082, 64.14308032681866, 65.39687771950999, 64.04409147077992, 65.46162820631459, 64.62961112299274, 65.9191805316556, 66.73223295519429, 67.50843078859391, 67.74011734993228, 72.70050356465002, 80.86848643518265, 85.76324355217719, 82.60161707478186, 89.12662890649612, 83.34274107410063, 82.53488971341042, 66.20562338059949, 70.77934234373032, 67.79692111476776, 75.38690351670789, 79.6856015728366, 97.61138239214498, 86.83494490961876, 105.89596163841986, 11.061658513161445, 4.952147276170792, 11.166160260477374, 5.676832131801113, 1.3277737844374873, 1.1529168510629286, 0.6440757359227827, 1.0194588188202152, 2.1664302147203878, 0.3650260951009489, 0.15018796758545985, 0.6368021907344942, 37.81684560160483, 56.46649983621413, 63.08741754101169, 89.570907931174, 146.36882843509798, 61.361190272915756, 44.28903879657869, 66.60986285055837, 90.63395654001545, 88.32896786351358, 116.71205428338821, 28.202775063053256, 1.011602495226168, 0.19677352911281973, 0.2635086892593292, 0.2217868667456412, 0.27691746491097635, 0.1978301635432628, 0.14042806871716054, 0.18199500357431753, 0.15888377032693357, 0.1253011493733333, 0.1075145566175061, 0.1609187296801998, 0.22083170832164828, 0.18916215447168197, 0.16574502231613283, 0.10952497817455761, 0.22509978333067512, 0.07785262810366769, 0.19270695054963713, 0.2188357888090034, 0.08702833896442767, 0.0909772311006823, 0.19254066350479282, 0.22954462546735044], [0.05297194242537503, 0.025546450558448994, 0.07518134079873562, 0.06267867862216889, 0.02795373438857496, 0.05999171332786641, 0.11537204466519818, 0.017445492107541333, 0.06869461387395859, 0.05895310877672127, 0.055621503476774505, 0.044063711163377574, 0.024027330763337594, 0.037284595290980035, 0.17659641261543, 0.018529454809463313, 0.0706977499348502, 0.15631087935499607, 0.3047340255110495, 0.4901513277042297, 28.838999194483605, 113.29525409206268, 92.17362803797569, 94.21804581919025, 73.09718854965703, 54.861752294724994, 47.16645425365817, 164.21252189144013, 148.55368275796215, 75.2343076275241, 27.256016885080648, 1.1843639636232008, 0.20355562889768233, 0.4027499192424359, 0.2615070240872522, 0.3753159735952655, 0.6561280150086649, 0.25315514885850493, 4.219682889599954, 6.881712175184681, 0.866045544464742, 3.5001289844512944, 58.629408497964185, 93.17124366760255, 83.79055807667395, 85.39155975464853, 79.1544028251402, 79.91963371153801, 84.72414493560791, 85.79506966375536, 88.39108251756238, 85.87211285868, 84.68126558488416, 69.23611717839395, 58.682074162267874, 59.322565832445704, 61.59952917406636, 63.941423431519546, 65.36004274122178, 66.90816694690336, 70.00926340779951, 75.12597176336473, 77.79420329678443, 81.03988616697251, 81.4690169980449, 78.03429941977225, 77.5232381205405, 78.6387288185858, 81.67253309680571, 77.47189429498489, 76.94657910254695, 76.24115651653659, 79.82704224125033, 67.04133141425349, 59.19380618679909, 61.352419853210456, 63.5022944788779, 62.69431760234218, 61.147628984143665, 58.23138206235824, 56.33698317312426, 55.55457622774186, 55.634278789643325, 57.504986563036525, 61.18871973406885, 62.34956087604646, 75.6239951041437, 66.42426413874473, 27.383142863550496, 60.95171443877682, 74.63955863829582, 78.91857424089986, 75.01615324328023, 62.82062968900127, 64.26593288298577, 76.68470598036244, 74.42258096510365, 72.9093776210662, 70.20315401015743, 64.65800516067013, 60.564278402636134, 57.98122505987845, 57.02549642132175, 57.39572894188666, 55.774358395607244, 56.351609691496826, 58.25274329031668, 59.62709473025415, 58.25001724304692, 60.512201093858295, 61.5764577927128, 61.841198167493275, 66.05242344640916, 70.38399880932224, 71.71241929454189, 78.34672404873756, 75.58521070787984, 77.18416490862447, 78.41611077708583, 73.25109451047837, 62.913919341179636, 60.26653912759597, 62.08923709008002, 69.36982293282786, 76.39481929040726, 80.45369578946023, 83.08956776895832, 87.46206129750898, 67.79726628334292, 1.0321103012369526, 1.6578059331063302, 2.1709566298992407, 1.4035392672784868, 0.2490781974648276, 0.04453212796379963, 0.07225999473443917, 0.3323575013106869, 0.07555288578113241, 0.06450501691189504, 0.06733531342639078, 2.1994629454228187, 31.149571364925755, 29.891096545803933, 85.09689561782345, 120.92445235098563, 118.50913524627687, 29.997745790789207, 45.301555510490175, 70.44731370864376, 72.98623254222255, 82.39848536829795, 50.69837993191135, 0.8011559973801337, 0.042088368772378856, 0.003999656952557064, 0.04366552164297431, 0.04316404814861956, 0.009650351167956909, 0.019898279645149747, 0.026043942310817303, 0.029975756432019898, 0.02008858354642026, 0.07296924659561727, 0.07282658570235775, 0.002087331038989848, 0.011233412491668378, 0.048622865109674396, 0.03349109259884685, 0.01852575652000885, 0.03450571859796201, 0.0379384475039138, 0.052831032043022495, 0.004415873479428551, 0.01487242685060107, 0.020810255608070764, 0.026748300785379066, 0.03524810759230487, 0.030115751339302912, 0.06440787696309629, 0.03362650246990304, 0.0405312605923222, 0.11776383245183576, 0.0069644296684512694, 0.0621247242745613, 0.03264979399260014, 0.03776657184766185, 0.04375207425665952, 0.044280625128697966, 0.04360922567185856, 0.03519053608479519, 0.14238853368066973, 0.04329296542451747, 0.16330624269621988, 0.18520498858584514, 0.3106658443087532, 0.575978548055695, 37.1869953217045, 129.7018381857103, 101.95466995239259, 104.5981199510636, 85.05868388760476, 72.22475144170946, 50.56325035710489, 158.91707112712245, 156.21451100995466, 65.2700557247285, 34.46875749095794, 0.6088394299149513, 0.09039066055969847, 0.29439539318123176, 0.4805168221073766, 0.2888960156950259, 1.1561740117688333, 2.5593659041389345, 4.388820394392937, 1.4617934510592492, 0.703152146550917, 4.301694746940367, 68.39738107496693, 99.56713891798451, 89.9429133630568, 91.58980677204748, 86.6421761051301, 84.44346797081732, 90.70834821270358, 88.30114256951117, 92.06357417568084, 89.94873416039252, 88.30941092583441, 74.16092749564879, 62.42127749227709, 63.103930719437145, 65.79991302182599, 68.4324235300864, 69.09498245485368, 70.34634405566801, 73.14952865723642, 78.64924077064761, 82.77810804305538, 83.77166009718373, 83.0903051745507, 77.6631804435484, 80.76508491270005, 80.19074009310815, 84.11010572987219, 80.99887386445077, 76.21388819909866, 80.75609484026509, 84.34416140279463, 70.99789680973177, 60.589503165214296, 63.37293078822475, 66.8332104529104, 64.19252572521087, 63.03617177471038, 60.3291166213251, 58.89659250936201, 59.50324981443344, 58.78398518408499, 59.742239829032656, 63.60965759523454, 65.76519220106064, 79.29233689461985, 68.50477557028493, 31.778746997156453, 67.16057146749189, 76.61577424695416, 81.25629117411953, 76.20602776927333, 68.02405772670623, 67.58570932572889, 80.502380248039, 76.38962607229911, 75.04197812849476, 71.24655938917591, 68.29013562971546, 64.35113853023898, 60.777431764910304, 59.41766761964368, 61.68409155261133, 59.22134514777892, 60.113299969703924, 60.184055605242335, 62.32850559296147, 62.12320873814245, 64.86272542707383, 63.52436173346735, 65.92569166614165, 69.56438818285542, 75.7988622111659, 75.98142500846618, 80.46516479984408, 78.99759431039134, 77.3452409621208, 81.64037750613305, 77.96002541818928, 65.02961443316552, 64.11256820924821, 64.22023334810811, 71.22109536201724, 82.0195451859505, 80.858319651696, 88.10729903559532, 89.56315732771351, 76.58434037239321, 2.1211351742667537, 0.3718482306407344, 1.1650596510979438, 1.703964630442281, 1.6889505328670626, 0.5167685929806002, 0.16108492479449318, 0.5911733810940097, 0.28882075521734457, 0.4036894188292565, 0.12492880765949527, 1.4887279993103397, 36.660417126071074, 29.814225935166885, 68.51140437587615, 112.5814062549222, 98.02673001443186, 33.56707126863542, 56.40435380320395, 78.26826095581055, 84.80010555636498, 92.49310508851083, 74.03586664507466, 1.3996441085492413, 0.022100690496905197, 0.024830914861071977, 0.05455332027087289, 0.03220235267954488, 0.034813632317368066, 0.07550426984145757, 0.011224547896774547, 0.05059962476333303, 0.027408180195057107, 0.06221050313944298, 0.037290030684802807, 0.07006961912397416, 0.06895499183766304, 0.06072596263801379, 0.028513574206660834, 0.021996674908986016, 0.05816139138093399, 0.13310189328847394, 0.030732821755772157, 0.02705048608233131, 0.009094899118457352, 0.04686261722517591, 0.04254638975966842, 0.1831524704973544, 0.09090177910101992, 0.14911325348000373, 0.12528709165992277, 0.20909177860425365, 0.22268723456128953, 0.20617089985359102, 0.12986586128752078, 0.18390944197533593, 0.13841881927463318, 0.16233194739587847, 0.1482666190713644, 0.22790449250849987, 0.09303086001666323, 0.2954528703083915, 0.108641923945998, 0.245220301252219, 0.34028954503517, 0.6806145752629926, 0.8135220047927673, 43.68098512772591, 144.3720909856981, 116.22927327309887, 121.81428909301759, 97.16904101833221, 75.34944488156226, 68.19993680523288, 177.4372479223436, 145.13621576370733, 101.3884444390574, 43.62005502946916, 1.7599927465761862, 0.38705109228049556, 0.8335952244458661, 0.6370564706383214, 1.4107586347287702, 1.8930737409860858, 2.140127045492972, 13.784071706956434, 18.52522880800309, 4.538442146393561, 4.616346301571015, 73.65102721798804, 103.7564734489687, 92.56340180673908, 96.15115457965483, 90.36104586816604, 86.71662269100067, 94.54129618983116, 92.59809909328338, 95.54506209588821, 93.98431962536228, 92.35240182568951, 77.61772017325126, 65.35928572377851, 66.03850687703779, 69.80151114925262, 72.5870450850456, 71.81925681329542, 73.48666421828732, 76.11357750431185, 82.9346812155939, 84.98034631052326, 88.95736294407999, 87.41369847328433, 82.3259215201101, 84.33889758202338, 84.26861655327582, 87.74719407481533, 82.7972335200156, 78.92464606992661, 85.48408846701346, 88.8123058503674, 74.3581364231725, 64.42628329800021, 67.82418158746535, 69.77279939959126, 67.27596759796143, 65.32120735414567, 63.86701606935071, 62.0116251514804, 61.297620419533025, 62.42212080186414, 63.77676625405589, 66.82331039059547, 69.23683104976531, 83.23327556733163, 72.84248552014752, 35.70307247100338, 68.80220890045166, 79.54616131321077, 83.8894724076794, 81.38403492589151, 70.32776771053192, 70.29034045434767, 84.6803399055235, 79.7565729387345, 79.89656233018445, 76.25310405608147, 72.03514406757971, 66.77605367475941, 64.60113079317155, 61.72170316019366, 65.0718975836231, 62.52245503087198, 63.11706673714423, 63.59909857473066, 66.48559431875906, 66.34841334435248, 65.58767749417213, 68.92643036380892, 68.91064674623551, 74.55758110169442, 77.57018104676278, 78.44317513127481, 85.55581292798443, 80.83693488951653, 80.73605937342491, 85.8585963710662, 81.97826616225704, 70.10221573614305, 66.38293020186886, 68.53355007786905, 75.77501420051821, 83.74816509985155, 85.32887243455457, 91.20357882591986, 92.29690813249158, 78.0969161372031, 1.748765819976407, 4.353377367219617, 9.68945457089332, 3.9014666359270778, 1.7226288611850433, 0.3765892117254196, 0.47857871158949794, 1.4516555950526269, 0.280636852426875, 0.4032194698529859, 0.19184569918340255, 3.535034646911006, 53.171697124358154, 49.545363918427505, 97.06985996615504, 124.42663469622214, 125.32035458472468, 42.53927338507868, 64.7029084544028, 90.8177823405112, 93.68080662142847, 104.33234014818746, 83.22458359502977, 1.5775717674724519, 0.2533308281413009, 0.14315809964412643, 0.2748840224118002, 0.14783607765791879, 0.1866378181523854, 0.2538426974487882, 0.14883738521847034, 0.12255293917992424, 0.11135610451381053, 0.1436157758918501, 0.1330886246456254, 0.31361546667833484, 0.19157608219933128, 0.18084265411861483, 0.18369469220840162, 0.19075020877343996, 0.20356425504770972, 0.1617993477491602, 0.1477402400585913, 0.10144435169716036, 0.16056473577214828, 0.12874113696236766, 0.12683799835823237], [0.08038084082786115, 0.03300287242558214, 0.07807794988395707, 0.05083468352114001, 0.041823589633549416, 0.035204203093364354, 0.06062758545721732, 0.0892609030368828, 0.04116107296619204, 0.03170015331688187, 0.010471173201597506, 0.04061866356360336, 0.009143425042801087, 0.035746432465290835, 0.015487682596299679, 0.053967446869900154, 0.02279406135541297, 0.016415481147686803, 0.09225662091686841, 0.04372386306884789, 52.87892749232631, 102.10884263438564, 95.40035017075078, 101.72182236948322, 46.523389508647305, 33.22711944580078, 42.34824219057637, 45.54764893747146, 52.24214638433149, 51.94592114417784, 10.3124975773596, 0.1850657597664864, 0.18220676559834711, 0.0881873150806754, 0.14185328336973346, 0.22194823550601162, 0.06345008702708349, 1.7272817728019532, 1.0735746569210485, 1.2912092045430215, 4.110448802671125, 57.474909828555205, 93.69958692981352, 81.30637984122001, 87.01457377403014, 71.04775797936225, 70.50123845377277, 68.43170965871504, 81.1541134311307, 81.99728181285244, 90.8786496808452, 84.48860660676034, 87.77192854112195, 67.73759134354131, 58.39575290679932, 61.98398028650592, 67.77731710864653, 66.04166830739668, 66.45445854433122, 71.47288014811855, 71.34759180007443, 73.86984056042087, 71.76765411130845, 75.40836672629081, 76.09990412189116, 80.49115442460584, 77.0725420982607, 75.8659190516318, 76.47070930850121, 79.55580249909433, 72.98308680134436, 73.67125095859652, 75.03624362330284, 59.88585349052184, 55.61844025888751, 57.871155508102916, 62.45318205125871, 58.92897951987482, 60.26085561321628, 55.91444192394134, 56.156663971562544, 56.10393947170627, 57.21564508253529, 59.62677701827019, 66.74385886038503, 65.96080472392421, 74.85540666887837, 64.06704910339849, 43.29335297307661, 82.96704861425584, 70.1698060189524, 75.97004229022612, 62.61590942259758, 57.0375616319718, 61.28138572938981, 73.51827852187618, 71.9065373943698, 72.79133781310051, 70.84732486355689, 67.87429378878686, 62.82257126223657, 59.70174920174384, 56.47021039839714, 58.418196708925315, 56.35373169376005, 56.54565718866164, 55.41726973748977, 62.21794966728457, 60.3283517591415, 61.97032651593609, 60.29082252133278, 66.19699416622039, 69.09232308787685, 75.11090986190304, 75.56420249323692, 77.07000040238904, 74.11463568287512, 72.94475740002048, 76.38916323261877, 73.69062746724775, 60.109263850796616, 57.93809467746366, 59.12516470878356, 66.45583921863188, 70.5906214252595, 79.84450463325747, 79.4034811758226, 80.12460108726256, 87.53954379789292, 55.95475212220223, 0.43855809456398415, 0.2016078656719577, 3.1491119102124245, 1.7667399587169772, 0.34158270145135544, 0.17301499753469424, 0.19533464745167764, 0.45501734039956526, 0.18813769573405867, 0.09228232316672803, 0.014548968249601463, 11.261146337755266, 32.93933514625796, 54.33399738803987, 97.8006681319206, 99.44224280695762, 47.57584771802349, 42.0585947652017, 63.94436128677861, 63.43525725026285, 75.89499165934902, 84.78791482986944, 13.849314451217653, 0.551177156308005, 0.1580429122212433, 0.08848479468255274, 0.0884983008126578, 0.0629416268108593, 0.05903925536380661, 0.04607045932883217, 0.07107422086260012, 0.008566798323074417, 0.04988466937755866, 0.08134324644361773, 0.06581119682279325, 0.06535850780745668, 0.025416194543903394, 0.11177072662018961, 0.05634201683043953, 0.08050752112702017, 0.030573797224450017, 0.03765627433876357, 0.039731472460252625, 0.05894346372975458, 0.04508778685703874, 0.05745066863094127, 0.12122438184075779, 0.05404656460028022, 0.02663365189707087, 0.009261640070396806, 0.06584423053408824, 0.03674338098555323, 0.036682515299969146, 0.024011323356159756, 0.030258314556352077, 0.057236746238965186, 0.012089499467683416, 0.03258994337351572, 0.03160148119223455, 0.02174686704341683, 0.08407055775845244, 0.04156156075036815, 0.08045270753603789, 0.045927656709306666, 0.036462280343496994, 0.030380758389289823, 69.90899193671443, 116.32446135244062, 105.22634244734242, 114.12276437205654, 62.763217956789084, 47.43496402617424, 40.795120885295255, 58.82643699645997, 61.1356657551181, 61.651790834242306, 11.450941985653294, 0.25848560395740694, 0.10275004897266628, 0.6265617402330522, 0.603794158706742, 0.7039003999483201, 1.064662541593275, 2.969756876268695, 1.540603796320577, 0.28903795646563657, 4.5841313850495125, 63.34195975334414, 102.05142697980328, 87.28251872524139, 92.26832974341609, 76.97028590786842, 74.66360276745212, 72.9487503728559, 84.70843976543796, 87.58554535527384, 92.18874485261979, 88.41391855670561, 89.08968802421325, 70.96939686805972, 61.994162759473255, 64.9672487474257, 71.28608903577252, 72.15106579565233, 72.46067416283393, 76.58032386533677, 74.68303418928578, 76.00316278396114, 76.76868392575172, 78.74510349765902, 78.8331763975082, 81.73212174446353, 78.6451458161877, 78.55205228251796, 79.38495189912858, 81.47958386328914, 77.69746980359479, 79.1521200056999, 77.90597515721475, 62.93722998711371, 57.22284655417166, 60.55180918785834, 64.26367752013668, 62.15722745464694, 63.92016418518559, 58.908524359426195, 57.66705889855662, 58.64399579263503, 61.963481979985396, 62.07839565892374, 69.11056210917812, 71.13314013327323, 78.01452282936343, 67.52605007540795, 47.17596600132604, 85.4869439524989, 73.43100578554215, 79.12785622381395, 67.69795971532022, 59.36379778769709, 63.56556230975736, 77.25183363883727, 76.48218616362541, 77.91203914150115, 74.22446989244031, 71.48826368393438, 65.04937925646382, 62.5584113982416, 58.48890919839182, 59.75728211864349, 59.16503952395532, 59.22240418772544, 59.983041978651485, 65.67611125207716, 63.51006861655944, 67.26370626880278, 63.74870954021331, 69.92963144856115, 74.74362696370771, 77.87736538917788, 77.75028844033518, 80.83158477660149, 76.90128357179704, 74.89721913491526, 81.06600130757978, 76.44881463819935, 63.82283841409991, 61.50304671256774, 62.940787576860004, 72.5637383614817, 72.37656285685878, 83.96179306891658, 82.17075255609329, 83.49933778086017, 89.70748486057406, 65.21082009038618, 1.3916372027127974, 0.468581019029502, 1.5828810632228854, 1.3363379119865357, 1.3983638224101838, 0.8337460518363984, 0.7815174866587885, 0.36950476768036045, 0.49417715038984056, 0.03818318578264406, 0.04299036069442669, 12.494526813107154, 36.00223948878627, 51.32402935335713, 95.53462074648951, 92.50888870608424, 41.458538809130275, 56.25200502334103, 69.48395606010192, 71.5235963944466, 81.91764200887373, 98.97756745738369, 22.49283371433135, 0.8278271339593396, 0.14544553093371854, 0.2088958286349812, 0.07778518938369329, 0.043544774694788846, 0.08745312705756196, 0.027666476314827323, 0.06373199206146021, 0.051296446847939686, 0.013125633385272758, 0.1118600141677645, 0.03743081083220821, 0.03306079250309737, 0.025237774581558285, 0.050085139265584375, 0.027361588642722177, 0.051102760668483474, 0.0416593442130233, 0.0018597504963362291, 0.07483614924093408, 0.035168871118296544, 0.03434732225873778, 0.04119202674877259, 0.13787469766553373, 0.2900838809868982, 0.12291532941162588, 0.17826251595491366, 0.2524448014915951, 0.2939397240838697, 0.1233725383457157, 0.14458257885229203, 0.17078825573046363, 0.0687126016184207, 0.1327436399315634, 0.13492507529595207, 0.11946352874679912, 0.10741843556564663, 0.13199960001774375, 0.195820837491943, 0.1706771270161675, 0.22114336821100405, 0.33820961632074853, 0.257931906249254, 82.37238591717136, 129.9131205774123, 119.38414542905747, 124.58582801203575, 67.58376383012342, 47.93198716255927, 61.80289622276061, 60.529530125279585, 67.53988819737589, 77.0067011925482, 14.97068968511397, 0.4183088891929196, 0.3152982860563263, 0.712237213888476, 2.1479556060606435, 1.0559543895144616, 0.7653682306408883, 6.326537939809985, 5.842638073428985, 9.09380735889558, 5.915778019735891, 69.6414392225204, 105.1299305885069, 88.12214912906771, 96.25472084168466, 79.42743116809477, 79.16107869917347, 76.12917284811698, 88.09493572481217, 91.0953841670867, 97.34970538846909, 92.07034418659826, 94.10120625649729, 75.64296368629702, 65.92112602726107, 68.1419720188264, 76.46571220890169, 75.60134733876875, 74.67696236025903, 79.56014064050491, 77.11169519732076, 81.31532284521288, 78.89751895781487, 82.9671270616593, 80.55898789436587, 84.69570775185862, 81.21381190515335, 81.01294732862904, 83.5879441230528, 85.53739347765523, 80.95823026472523, 81.2778877442883, 82.47574037121188, 66.62243796933082, 59.40959145945888, 61.71243852184665, 67.74095673714915, 63.78323424247004, 66.81304162548435, 60.90185719151651, 61.06953851638302, 63.5256443485137, 64.92006655662291, 66.88475824171498, 72.846298063955, 74.40331428281723, 82.92811516792544, 72.74709347755679, 50.264746219881125, 88.22777855780818, 78.58733792458811, 84.34761308854627, 70.31476113104051, 63.390624600072066, 67.5121727297383, 82.04772349326842, 80.02169378342168, 78.60178793630293, 76.33163775167158, 76.05021553654825, 69.25383844683248, 65.37903485759612, 63.518097708302165, 64.01093175334316, 62.16623713893276, 64.66409267917757, 61.2954709606786, 69.65914480147823, 66.84014520337506, 70.21341493052822, 66.93444682705787, 72.56982587998914, 76.60406204961961, 80.67969491404872, 83.03976151251024, 84.38893918068179, 79.38130409486833, 77.75149653034826, 84.95015190493676, 80.46565901848578, 66.91596461880592, 65.0439977645874, 66.4704853488553, 74.68319892883301, 76.9138979142712, 88.8681290226598, 83.38296890258789, 88.62029798569219, 91.76842366495441, 65.32874614961686, 1.0468196796794091, 4.579924643039703, 9.892802988329242, 6.15079467335055, 1.7084753561404444, 0.6403509551478971, 1.2765342694136406, 2.1079199737118137, 0.6032728511960276, 0.39734112399239696, 0.15592245745562738, 18.888069621978268, 53.35037677518783, 70.63495989768737, 104.76399698565083, 108.4850868102043, 57.14536405378773, 59.529325731339, 79.71075965512185, 88.48143823685186, 91.68378676137617, 114.62496111469885, 24.47495641246919, 0.85306893433294, 0.2537359354356604, 0.2940875177662219, 0.2910892947787239, 0.18213927325221801, 0.19646880998005792, 0.15796959760688967, 0.20974882157339206, 0.1413558778022566, 0.16570584457968512, 0.15821309099274297, 0.17578322560556475, 0.14351953992680197, 0.15673317766237646, 0.2200418716717151, 0.10758047848339043, 0.16917499713599685, 0.1198523413510092, 0.14554147578535542, 0.17496286801272826, 0.24593841675068104, 0.1334109178353702, 0.20310527645051482], [0.12024908296523557, 0.08780188858509065, 0.04689241038455118, 0.05894107736587044, 0.030746412155548894, 0.07597249511989855, 0.08717758055295675, 0.0766103629082922, 0.06390193717614298, 0.06513816559867514, 0.05103978824110762, 0.06428154140350319, 0.03256258637373967, 0.021137624130313917, 0.06316048663950737, 0.07222758155436286, 0.01815903597631522, 0.0762334629713047, 0.16780475695287028, 3.942373769898569, 94.00346863654353, 94.27765800106911, 93.37808593626946, 73.25230260049143, 50.087823790888635, 39.436188282505164, 62.1430088627723, 57.16182231903077, 60.308837967534224, 29.079993540240874, 0.19723304397156163, 0.07844554951354381, 0.06517929685932976, 0.13476678620903723, 0.19119522924865448, 0.2017602099165801, 1.0252939573218747, 3.9442869059501158, 1.5168816692406133, 0.6838288350451378, 45.67970337406282, 92.65239254120858, 87.06630983660298, 85.75817584991456, 75.504088247976, 70.83402802867275, 68.32213432558122, 60.59973662899387, 69.3553807658534, 81.9138765335083, 84.53622418065225, 86.2270010671308, 84.20752956021218, 65.86866040383616, 57.749675781496116, 61.44616842269898, 71.70720254221271, 71.19118336708316, 70.67728227184665, 72.40089724140783, 75.44413089752197, 73.52175374184885, 73.31597835786881, 72.57513676920246, 75.50794001548522, 77.62618464808311, 76.6053956554782, 74.56128381913709, 76.6253605196553, 73.85601028319329, 75.5808254980272, 71.53865829590829, 60.93436971787484, 55.829550066301906, 59.79361503354965, 58.075040309659904, 61.41547195373043, 62.54556955829744, 60.146189043598795, 57.7686914320915, 58.197559464362364, 58.35869435341128, 60.56225445962722, 60.61799133977583, 64.2058382495757, 67.79128074645996, 77.5379156297253, 67.57067880322857, 57.68659622438493, 73.30861999142554, 63.9042236728053, 61.2415462155496, 55.11474517083938, 54.663605920730106, 56.75722591338619, 64.97479146526706, 72.77568755611297, 71.98894639169016, 69.38803057516776, 68.18212139991023, 63.80838055764476, 58.54050405563847, 55.810385365639966, 55.58424503572526, 56.04278972071987, 56.99320354769307, 58.39791805513444, 59.502269221890366, 62.844516923350675, 63.80300298813851, 66.45627852409118, 71.22217009144445, 72.58879446214246, 75.3753403694399, 73.85167998652305, 74.81711649125623, 74.55175245961836, 74.18651703865298, 75.39332051430979, 74.05125018089049, 60.811948622426684, 57.90165585856284, 60.470361171230195, 68.44461425658196, 71.393585512715, 72.4849614789409, 76.16542339324951, 80.03593198714718, 76.52966253219113, 83.75240125963765, 49.94814818905246, 0.8515732855566087, 1.361313726632826, 2.4288514881364764, 1.8298966149168632, 0.1833803203677939, 0.2702377297945561, 0.7409170942921793, 0.9250309438474718, 0.2205673160572206, 0.13165447740785538, 1.379691624353009, 24.12420826573526, 31.485188968719978, 65.0487869785678, 69.25267742526147, 45.1320698953444, 20.570750736421157, 40.02294348132226, 62.46287030558433, 72.94498489749047, 77.14057168652936, 43.707755304151966, 0.7582735210176438, 0.037097597059102795, 0.0622419165747781, 0.027005537788593964, 0.05362449228883751, 0.028981581150043397, 0.03300761834027306, 0.03852538193666166, 0.061837567707463625, 0.09243256066955867, 0.07436999239988866, 0.05977414435737076, 0.06224921356225687, 0.03114599978641397, 0.05015126797520826, 0.032291870053497054, 0.012663491802560467, 0.05356006812484515, 0.04062347076532822, 0.0550579538779153, 0.029781583786731767, 0.029524036517907536, 0.08918755011813295, 0.06017801441973256, 0.16128599223109985, 0.0516702517897131, 0.11727248663984, 0.013747940012704463, 0.06690882461806459, 0.02452014554892817, 0.023465171614060962, 0.0675900836264895, 0.08199223782867193, 0.015305196622296449, 0.01600663342903699, 0.010766085451318613, 0.051553170572245316, 0.03144458830056172, 0.07105445579415368, 0.015114177386426638, 0.13327035602302323, 0.20241179833969764, 6.58290405427256, 113.83585083869197, 103.637955111842, 103.67994800690683, 83.16826620409566, 59.32607243137976, 39.69313490775324, 54.7705493434783, 65.99621588183989, 63.379359552937174, 32.463618324648955, 0.12224358521522054, 0.09169716222752487, 0.1459548261857802, 0.4852811229084769, 0.7752929916304927, 1.22480703217368, 2.96367573161279, 4.665513701977269, 0.1673590776420409, 1.018330279377199, 52.79529863788236, 98.66984967262515, 92.86642059203118, 91.05022199692266, 79.59745807032432, 74.05607469620244, 71.80741125537504, 66.14127297555247, 74.8043687881962, 86.63036977091144, 87.24814307305121, 90.13314831641414, 87.48583870549356, 68.41633396763956, 60.33697705115042, 65.37931726824853, 71.83068659997755, 74.27181290042016, 75.16113973432972, 75.69315433502197, 78.65783076132499, 76.80639359258836, 76.67335464108375, 77.82056946908274, 78.84463756315171, 79.49466059284826, 79.35776987383443, 77.55407579483526, 78.64309833895776, 78.70802925479028, 77.92364151247087, 75.42995545171922, 63.69972305913126, 59.69905453343546, 61.668766852348085, 61.81450251610049, 64.0494337389546, 64.186473508035, 63.59333661294753, 59.960527573862386, 62.17808661922332, 61.1078953742981, 66.37229273396154, 64.44183549573346, 66.5016838812059, 71.40722751617432, 79.8635438180739, 70.32249604502033, 62.777781717238895, 77.53484049151021, 66.68272479887932, 63.104005244470414, 58.43576500492712, 58.17626099432669, 59.84677099412488, 68.97991580347862, 74.8980349879111, 73.58676310508483, 71.97944641113281, 70.50040691129624, 67.21698299531015, 63.284261688109375, 59.965607043235536, 59.18875809638732, 58.80904912948609, 61.24034597027687, 61.74640624753891, 62.84297543187296, 66.28593783224782, 67.13928084219656, 70.69027316185736, 74.60339438530707, 76.15893579298451, 80.20325245395784, 76.31161012957173, 79.0959281306113, 76.91607090734666, 76.17250719378072, 79.0343390741656, 75.9547136675927, 63.48822493706981, 60.97501723997055, 62.064977230564246, 71.26697924829298, 75.04877951837356, 76.23876387073149, 78.32711219787598, 82.2081405885758, 80.26460616819321, 89.26298618316652, 60.01657039888444, 2.3877864787655496, 0.6454600261584406, 1.0172203711925014, 1.4362715689405319, 1.7778608587480362, 0.6435743466980997, 0.9358306385336385, 1.2208094015236826, 1.1046003598359324, 0.14889099605141148, 0.6277559793764546, 28.98895532854142, 30.181095023309034, 60.60315301341396, 71.90372897732642, 44.910087277812345, 33.614837892593876, 50.284412983925115, 69.60268620521792, 80.60508358863093, 85.53718166966593, 62.075657844543464, 0.9158774188929989, 0.038327443969225695, 0.037404231411675294, 0.05847731071914877, 0.06422982663817464, 0.030699175174137762, 0.033395059647098664, 0.06585487915623574, 0.04804228154581882, 0.01532601889207839, 0.030915888041378032, 0.05689217138194269, 0.042296120326124856, 0.02299008984869767, 0.06070864139004581, 0.09387339585490766, 0.03214897550342064, 0.03435674130976681, 0.05021748861538307, 0.04174316572325845, 0.018991997630725947, 0.055178693165221525, 0.04819469856879404, 0.1919210056263593, 0.298162094287334, 0.18916676632098614, 0.13382575444636807, 0.07315044937234733, 0.17391060028345356, 0.17836097357494218, 0.19721580699326532, 0.18883449866646723, 0.20414712538401927, 0.19590990287401985, 0.17234272473762113, 0.157434240043644, 0.15200836103289359, 0.10312791418043837, 0.1787861064076424, 0.252545511410121, 0.2965996120004885, 0.39644115454246925, 8.30550116877402, 130.7394855253158, 115.82571629554995, 117.54633457429948, 96.17100177272674, 69.8287873114309, 56.36241189895138, 85.50007604783582, 77.60118346060477, 81.4843926891204, 45.196334008247625, 0.5612142564308259, 0.32323633591013573, 0.3120471008362309, 1.2518403751234854, 1.963512767707148, 1.3629590383460446, 6.406573903176093, 12.989440694932016, 6.759850507782352, 1.2181220876593744, 57.737481132630386, 102.14621497738747, 95.6619095033215, 94.79912927073818, 82.16060930682768, 76.93320382025935, 75.42695091616723, 67.99232575201219, 76.96158609082623, 90.39474687268658, 92.97339147137058, 94.28583222050821, 92.94638203036402, 74.40125896084693, 64.19757773799282, 68.04751350033668, 78.87057227473106, 77.80601747574346, 76.68239178196077, 78.74956715491511, 83.63010175766485, 79.23466236360612, 78.69732118421986, 79.18971984617173, 81.42222312188919, 85.3001763743739, 80.58733094123103, 79.85550295922064, 84.51931876520958, 81.13863575843074, 82.97592886032598, 79.7218599627095, 68.77006115451937, 63.98051769502702, 64.73087887610158, 63.65944816220192, 65.79608871090797, 67.39041451484927, 65.86139617427703, 62.89509588672269, 64.77855528554609, 64.69516569568266, 67.9066925664102, 67.0920947290236, 70.58966436693746, 75.84759373818675, 84.58341029382522, 72.09539951816683, 66.84616996395972, 82.14795574065178, 72.84395248659196, 66.54938774724161, 62.26814031600953, 60.715281809529955, 62.85104766968758, 70.64654657917639, 77.59986554422687, 77.8142858320667, 74.59492206573486, 74.49058701915126, 70.41933936457481, 67.46017779073408, 63.52191809685, 61.49559028687016, 62.29021149296915, 65.91394024510538, 65.2405281220713, 66.13979816436768, 69.31647085374402, 72.10241271603492, 73.47377530990109, 79.00376027630222, 79.41814299552672, 82.79856712587419, 78.90581084835914, 82.05488574120307, 80.12476582680979, 79.29017959102508, 83.39983509432885, 79.78352746655865, 67.81664279199416, 65.43465406663957, 64.76130862389842, 75.13227893460181, 77.26433031020626, 79.73936942315872, 83.07391751197078, 85.98494375905683, 85.08296335897138, 89.58272995487337, 61.06028564514653, 1.6791986626002098, 5.740412771701814, 8.819430701194271, 5.075110148998999, 2.648552757117056, 0.6385350203321827, 2.589943721409767, 3.783212568490736, 1.4721282835929625, 0.22221002307149673, 2.4949461221694946, 39.775296795752745, 47.27192678759175, 73.09245817122921, 80.32604617457237, 56.03396046546198, 33.132833511598655, 57.94326828372095, 80.53546936281266, 92.33553563394855, 97.92124963575795, 70.17388528393161, 1.3747599793057288, 0.3096962221447499, 0.1158214471633396, 0.17767363948927772, 0.13395159204881038, 0.08944552256575516, 0.11206344115517794, 0.15083443854124318, 0.18253105061669506, 0.1271399289309498, 0.1847909487062885, 0.13867008079203869, 0.14321714970132998, 0.10623341245997338, 0.22992477361713687, 0.15562516937573112, 0.1513184222482866, 0.1961422879849711, 0.14686406529959173, 0.1632375399311704, 0.19763179273614961, 0.08409738615756074, 0.14387642964720726], [0.008657028158796171, 0.024539818686823693, 0.03699214505632559, 0.05572865236430399, 0.04645857862347076, 0.04705358379250092, 0.0700174715189684, 0.07155854930920948, 0.03329853256863933, 0.05682465988361547, 0.02259436521619078, 0.07962990612272294, 0.018506295971512314, 0.06311495037328813, 0.06158886109328559, 0.03217423725272379, 0.0733706000591478, 0.38081253187791, 0.7921040863279374, 18.999857171889275, 105.31541947395571, 87.71664665591332, 90.68320581989904, 68.11139322096302, 55.94127485829016, 42.254870168624386, 67.75394762715986, 48.38715860920568, 45.615243142650975, 5.360094856831336, 0.04658635825880113, 0.07822326144143459, 0.05611733856400656, 0.48091966178148027, 0.5639702730601834, 0.24463389158969928, 2.4865147423359657, 2.0138870323857954, 0.3298676849132584, 15.861299134069874, 86.3581729704334, 89.4574494515696, 86.5278390146071, 77.71662665951636, 77.97960589008947, 68.1581792523784, 68.83203460324195, 62.82015508221042, 59.92650101261755, 73.07367001810383, 83.35854038115471, 82.31696282663654, 76.55269468984297, 61.38529323762464, 60.856055675014375, 64.93228473970967, 74.75347995758057, 77.1825881158152, 76.6263803359001, 75.42243234572872, 78.91466756020823, 76.4203146965273, 78.3014206732473, 75.0069356733753, 75.45758462721302, 72.2354281333185, 75.75872067482241, 74.42454215018981, 69.70408731891264, 72.09648209233438, 69.84659487201323, 58.04825052138298, 55.185049733807965, 55.032116520789366, 57.236390498376664, 58.24498876448601, 61.576202838651604, 60.27279923039099, 59.75484240439631, 55.75358944554483, 60.232171320146136, 62.51135080091415, 64.39498670639531, 59.4281481927441, 62.71181137331071, 62.755267312449796, 74.19538943998276, 67.8084607278147, 54.918371708162375, 76.08964320152037, 63.66153094076342, 59.717262175775346, 55.6163731698067, 59.80889266537082, 60.95099272266511, 64.85082887834119, 69.05775131717806, 66.26125043438327, 68.34719042624197, 68.3207065828385, 64.00225547052199, 57.522531324817294, 54.9236237618231, 55.29496631314678, 54.504526353651485, 55.560044011762066, 58.05108639501757, 63.83505267481651, 67.96105661699849, 65.3756106284357, 73.54804146674373, 71.48240366289693, 74.69907668329056, 73.17348649424892, 73.18042124471357, 70.356291186425, 72.32537592611006, 73.51102213705741, 79.27025395054972, 71.28150770741125, 58.72213725120791, 57.01520412198959, 61.663934492295795, 63.49823874811973, 68.49646799025997, 70.852016018283, 73.46334180524273, 75.97740850140973, 79.4158209523847, 73.72624258841239, 83.47385021948045, 44.29017628392866, 2.1320736840848, 1.1714277416467667, 1.1452166255443328, 2.1986115459472906, 0.9482279636206167, 0.10381634377183453, 0.8041851703197727, 0.21737651388731696, 0.4931672626445371, 0.20109403517938432, 8.040982407908286, 30.65245213047151, 43.687629622797814, 50.26454225663216, 26.227653795673003, 25.819017348750947, 33.903261538474794, 61.330356520991174, 58.390904857266335, 70.10798162029636, 73.90567533431515, 7.1436289337373555, 0.4801703665045, 0.06745398810674107, 0.12774817209931152, 0.07896624415391877, 0.06997781880800763, 0.025477542864879774, 0.02836720927828743, 0.04668222267120596, 0.06940106185333383, 0.03129275733484857, 0.029828502841654326, 0.022832344684209076, 0.10096481130007776, 0.15060766119389765, 0.042484003389554645, 0.07575917793738265, 0.05607623794686891, 0.02966730645106685, 0.045654462094629006, 0.02695598530643169, 0.10413216351861916, 0.03624779487689657, 0.05068805429243273, 0.03955637157383946, 0.013795665375167325, 0.013396149565045153, 0.011528485619853581, 0.05979405115208319, 0.04468257614080945, 0.08772031554291326, 0.03361636329622519, 0.026007267766662186, 0.10559383629550857, 0.08209774345760384, 0.05698071965467065, 0.04586938040090665, 0.05988593956816101, 0.07037065337382017, 0.1185361410100614, 0.2439827015323024, 0.7865414912662199, 27.811312713930686, 122.49389463855375, 94.02531623840333, 99.00296088187926, 81.07281054219892, 77.61021275674143, 46.14481410672588, 66.29819131666615, 51.618473837452555, 50.57903005230812, 6.852867555233741, 0.04817338217230094, 0.1621836940607717, 0.48321403382766637, 1.109835988571567, 1.7985241499639328, 1.9374047363958053, 5.170645848397286, 2.32686520584168, 0.10607532255591885, 17.67627100790701, 91.32624703068888, 91.50578175821613, 93.33744233654392, 83.04697082888696, 83.28560783017068, 73.39759503641437, 69.57917551840507, 65.65216518217518, 63.16762216629521, 75.55962116487565, 86.76074935543923, 85.55671507312407, 82.33930464713805, 62.715263059062345, 64.15022296290245, 67.47723225624331, 78.09679062135758, 80.22636305901312, 80.03424536797309, 79.09408461663031, 82.21021160002678, 79.68902972436722, 80.68335840778967, 77.99033749488093, 79.81187835816415, 75.44733939632293, 81.07763505751088, 77.87156028132286, 76.37810214873284, 74.1738477829964, 73.34717689021942, 59.43909945026521, 58.39601178323069, 57.16529753900344, 60.59743419770272, 61.14576978068198, 64.35307618110411, 62.31231797126032, 62.9004499220079, 58.506108791597434, 63.611552100027765, 64.49778418387136, 67.19467255377, 63.65203096020607, 66.17420519551924, 65.30544334842314, 76.61684897638138, 69.91940190715175, 59.167349799986816, 79.16819387866606, 66.28439241839995, 62.605864232586285, 58.9576167445029, 62.17565867208666, 63.37330341339112, 68.68512615080803, 72.46034468373945, 69.45162004040134, 72.85135007673695, 70.85768776555216, 65.68005323410034, 58.43675344221054, 59.205545840724824, 56.74585888462683, 57.384911044951416, 58.8328226151005, 60.0277687657264, 66.84566790057768, 69.52909469604492, 69.27281487372615, 75.87592894031157, 74.8588034414476, 75.51903247833252, 75.46506066476145, 77.61926558709915, 72.10344822176042, 75.31588508236793, 76.36687632529967, 81.94666754814887, 76.53604030609131, 62.757848232023186, 59.87567493992468, 66.34951945274108, 67.88874380050167, 71.28845030261625, 74.29870467032157, 77.08759615498205, 79.94708245800388, 81.99101386531707, 77.9090581401702, 87.09126395563926, 53.88832199958063, 4.172182496516935, 0.4336601573853724, 0.3572828154410086, 2.7518446983829623, 3.6301482012194977, 0.6424405978571984, 1.2131068470977968, 0.4961020229083877, 0.775750560625907, 0.1230080260504638, 6.823899380622372, 34.55493980838407, 43.794557356065326, 60.393890642350726, 29.25434877795558, 26.892152332490493, 46.40220003743326, 66.80507921403455, 66.4099161086544, 75.19312274071478, 91.18643806826685, 14.491184834511051, 0.6014678867593889, 0.17051799523253597, 0.17879255686796483, 0.04765654095418511, 0.04967224085703493, 0.08331092795537365, 0.11082856870827176, 0.05539934947005203, 0.03011839242742187, 0.07856567976095023, 0.05020188723480509, 0.06438077277233524, 0.09777160361409189, 0.028819762313017444, 0.014243836386970455, 0.024899847452498736, 0.026211091204576438, 0.058748632248851566, 0.06349350506019208, 0.023337568178953185, 0.03077365424213631, 0.08354477629426026, 0.125115143225318, 0.16234207507823745, 0.09126817597256554, 0.16014790733254727, 0.12224596008778581, 0.19329349810798324, 0.16224355617117497, 0.23433457489215562, 0.19296214975897344, 0.15855023096646034, 0.3304911885530718, 0.12095220612301943, 0.12961017178191295, 0.1843537729714186, 0.1881636661146918, 0.16990103398359593, 0.2535775697399532, 0.4989094900027399, 1.4215908728299604, 34.79153717717817, 139.1491570011262, 105.46878414769327, 114.54329736771123, 89.6657508419406, 77.73832521130963, 56.18852930684244, 93.67244412822109, 61.78233515831732, 70.50603159012334, 8.88467344545549, 0.17775392550374233, 0.42307046272100945, 0.7002855068252933, 2.7395250239679894, 1.8999776027856337, 2.8823471021267677, 10.853745437437489, 9.459586028129825, 4.487991640644689, 21.948385200192853, 96.57573546132734, 94.36891586549821, 99.04316517614551, 85.39415636370259, 88.58268245573967, 78.29476048869472, 74.60470445694463, 69.50960051628851, 66.0867363406766, 79.78438254325621, 90.43437850090766, 87.64056836405109, 84.95747104767831, 66.78363953867267, 68.90269217952606, 71.6591299733808, 82.11367422534575, 85.30878205453196, 82.6277086811681, 81.84092044830322, 85.85807861820345, 81.93064074362479, 82.7375978039157, 82.08366809352752, 84.08009959805398, 77.40391961989864, 84.82886437446841, 83.0708815974574, 79.69272459706953, 79.47492322614117, 78.12381575184484, 63.77625634593349, 61.05218987311087, 60.245938839450965, 63.33426014069588, 65.35433177025088, 67.41627862376552, 64.40111344860446, 65.79666529932331, 61.16415000730946, 66.60886656853461, 67.19334679265177, 71.41738645492062, 65.36578116878387, 67.73082917736423, 68.97983735607517, 81.59043788909912, 74.20422261761081, 65.30648669888897, 84.69765324746409, 70.33452987670898, 64.22884687300652, 60.83051320045226, 65.44386771417433, 67.15513506243306, 73.71184748987999, 76.03818954959993, 71.22698676201605, 74.11526326210269, 74.16257489112117, 69.16966438293457, 62.320829514534246, 62.09377527236939, 59.74905298602197, 61.67264999881868, 60.654026154548895, 62.658067057209635, 70.02287403229745, 74.67516591472011, 72.10834333973547, 80.77704029698526, 77.54357953225413, 80.21527059616582, 78.95368729868244, 83.11383155084427, 76.81344601415819, 80.21305053464829, 80.7367261763542, 86.89614957378757, 80.30899170906314, 64.65852683590305, 61.787002778822384, 69.38968581538047, 69.76139314713018, 74.18605419897264, 78.53076950196298, 79.76064435897335, 83.56181329296481, 86.09371108393516, 81.21586722712364, 90.58702930327385, 55.04658614435504, 3.411956799607123, 3.7439910731007977, 5.339191075294249, 6.345271179752966, 4.42152266540835, 0.4612010795502894, 2.932501223779494, 1.100109981433038, 1.643034409611456, 0.3860412045351921, 12.977359794801282, 52.348913300421934, 59.570271353567804, 64.02329114175612, 36.234643843866166, 36.230799921097294, 51.16726398468018, 79.09069568880143, 79.69981624234109, 85.9582559524044, 102.13240038964057, 14.6895989102702, 0.8833653828309429, 0.3326746617113391, 0.3895116134756996, 0.18397468202296766, 0.20188482177834358, 0.14008711362558027, 0.22833739347275228, 0.19662029620620514, 0.09012406196204886, 0.21684362312718747, 0.14147619957164412, 0.1862519549866838, 0.1888557193019698, 0.19328111812712687, 0.12113307182106281, 0.17232649899538488, 0.1564298834531538, 0.12311811288518291, 0.1779280266454143, 0.17046351105936114, 0.20709342293200955, 0.21879075816081417], [0.03553768116680365, 0.011707793286580954, 0.030293765275048155, 0.008332160913625793, 0.012247008102525388, 0.027422356652095917, 0.02658691670325014, 0.09624957076964841, 0.027048017363995317, 0.04592420931364741, 0.05679700793998857, 0.023553593482281414, 0.038371681716413274, 0.0023974621041317383, 0.0244364274605628, 0.051983604733381546, 0.03802566278365351, 0.01183128570236506, 0.09198426899890746, 56.38563625274166, 95.63138561864054, 82.70078243747835, 69.97608800088206, 45.61748281601937, 29.097663817867158, 38.57707938840313, 45.77096123849192, 58.26880931854249, 33.100030729847575, 0.14010965193231262, 0.10431106803157639, 0.07789274812826226, 0.4634257375953659, 0.1734002325082979, 0.3610401702744346, 1.7838939543693297, 2.0515247482445935, 2.409012875249309, 1.923531925966663, 54.346572506812315, 95.43062302374071, 90.44907169957315, 86.20586733664237, 83.94855899195518, 82.10383692095357, 76.78160421309933, 66.10152367622622, 62.5051809126331, 61.99187601766279, 62.231336716682684, 70.25568239150509, 74.60633616293632, 63.54736643452799, 62.47010707855225, 59.12049316590833, 65.75244057563044, 77.18298035283243, 77.95844862538, 80.7715097550423, 77.66366681744977, 78.90280631280716, 77.70493799640288, 76.99264341785063, 76.63340137850854, 75.74841268600957, 73.70205725392988, 72.82435632521107, 69.34795964148738, 72.23962506940289, 63.37761409821049, 56.21053380350913, 52.32326884423533, 55.81999125019197, 54.84940859579272, 57.57828389444659, 55.85886978333997, 58.664976550686745, 57.40733131285637, 57.50196633800384, 53.11038263382451, 61.10589104314005, 66.24442346634405, 66.31594396406605, 61.09295506631175, 60.60902087919174, 62.42727087390039, 71.29082725894067, 67.65621785194644, 45.875943476153964, 72.94877390707694, 70.4947743877288, 70.72561371710994, 65.75533136244744, 60.319393065667924, 58.93757343292237, 62.8898948238742, 67.01844046192785, 68.36073044807681, 67.85376410330495, 65.7437172243672, 59.281451548299486, 54.94801698192474, 56.650729640837646, 54.96876239776612, 52.53581031676262, 56.12564586823987, 59.11816327802597, 62.956186802156516, 65.35098206612372, 71.25943260808145, 75.48782610124158, 70.54567106308477, 69.20556975949195, 71.08604815698439, 68.15535514585434, 67.87095977414039, 68.55735102007466, 70.97108348723381, 73.40788733574652, 70.16658183067076, 55.43989789101386, 59.83393307655089, 58.90568456342144, 64.984122783907, 64.59225054710143, 68.74040019127631, 69.70464429547711, 74.92556218178042, 75.13499321476107, 80.84876475795623, 72.80971019498764, 72.38247779107863, 46.504456227825536, 4.266031086444855, 0.7690221023175025, 1.2647142068993662, 1.049656411332469, 1.1525518254887674, 0.05107555305585266, 0.5814462095018357, 0.47864821108598865, 0.03965114814139182, 0.05756862318864273, 13.017048297389863, 32.828377177638394, 37.291499030205514, 30.71505511960676, 30.630698665495846, 24.393641756426906, 42.94521516369235, 59.17531613380679, 66.50025613846319, 76.09162792082756, 45.051284759275376, 0.37704944670681034, 0.05473782871699622, 0.08601423773554065, 0.04316930351178012, 0.05537277004951912, 0.02158976539278463, 0.07151546452434794, 0.028367601898348624, 0.03940859321324576, 0.021514773045876817, 0.0606256319330104, 0.07579270194494918, 0.07697355753231434, 0.04765780499926017, 0.03361084746317037, 0.033422566034019954, 0.03926707762143305, 0.020763281011773695, 0.06430043313171595, 0.01668386281498017, 0.006404977682377062, 0.04162310825420484, 0.08858652349801795, 0.020767107620955478, 0.03086354891439119, 0.053180643928147135, 0.05398704722944287, 0.03381435105937623, 0.02564428381681923, 0.043338574469089515, 0.028993457428089557, 0.05403444891975773, 0.05221168826063795, 0.10439734485360885, 0.02840114122767362, 0.06902096732970207, 0.07248923122402161, 0.01042398410068164, 0.005413451149398762, 0.0051091667715339895, 0.15368367274922712, 73.6134038432952, 106.37010558958977, 92.15437704516997, 78.79917729285457, 53.88664714751705, 40.39831038444273, 43.246147248052786, 46.563287858040106, 62.14885319432905, 36.7763388541437, 0.15277604242005657, 0.017110110305610205, 0.30763909220695496, 1.5646299070888952, 0.9422136831187433, 2.5965967966664225, 5.0125704080827775, 2.3687759762810123, 0.5798661071927317, 2.3133568081163594, 63.458940521363296, 100.01114337675034, 94.62765893628521, 90.16061275236069, 89.3696746518535, 85.28590679168703, 81.44135644358974, 70.80708134558894, 66.8194664678266, 66.25459024983068, 64.6891095561366, 72.88207792466687, 77.39519626863542, 67.60473282106462, 65.47061827874953, 62.59794888957855, 69.41029394826582, 81.19303903272076, 81.51039800336285, 83.48126349910613, 80.52124684856784, 83.20301055908203, 78.83598481455158, 80.25774202039166, 78.449552905175, 81.52261226407944, 75.8905593810543, 76.86628034037929, 74.94214596286898, 75.43799631057247, 66.56187657387026, 59.31710197079567, 56.20072395570817, 59.261663190780155, 57.10391636817687, 58.65900670328448, 59.61144447326661, 61.509385262766195, 59.310622215271, 58.022021632040705, 55.09487052117625, 63.284387203954886, 69.6737438632596, 70.31465130467569, 64.0735798497354, 65.59106249963084, 64.83282519925025, 74.81240180230911, 70.55248814244425, 48.947873192448775, 75.4952472256076, 73.88491815136325, 74.12420626609557, 69.68168274048837, 64.28385811467325, 62.61575645016086, 65.8123508576424, 70.25539213611235, 71.27411011726626, 70.76716730671545, 69.16760121622394, 62.663703503147254, 58.68698104735344, 59.18636937295238, 57.993643283844, 56.822631436009566, 59.346759011668546, 60.68429508516866, 66.27112696247717, 67.9753811128678, 74.15036063040458, 76.68029723628875, 70.99412348962599, 72.13486640684067, 75.44827292042395, 71.57657977073424, 73.24630921886813, 71.44252100298482, 74.15956251082882, 76.69296649194534, 72.38323873089206, 58.79916083428168, 62.42898102729552, 61.70103619175573, 68.70793865573022, 68.62738886187154, 71.5463069177443, 71.89218936427947, 78.27918083437028, 77.84055786748087, 86.23319841200306, 77.10949867002427, 76.89805153877505, 53.58476192720475, 7.132774754878014, 0.7768100295816699, 0.6031917684501218, 1.4316831312833296, 3.139128987827609, 1.1159637113732677, 1.349801937899282, 0.7001416661566304, 0.0608551825186418, 0.1069798578898753, 15.50383294782331, 38.61973516402706, 39.369296181586485, 22.834913422984464, 26.70818336548344, 37.598675527880275, 50.251841622014204, 67.1337346107729, 73.17019170330417, 82.62473552457749, 60.77679634094239, 0.7028728002502073, 0.05802856705662224, 0.07233101108501996, 0.05270312217274501, 0.06394275434074864, 0.024383151791088527, 0.043980736180298755, 0.030871621565893296, 0.1000120047660124, 0.03748323422886672, 0.030397581680107023, 0.0797622324898839, 0.10125967088125407, 0.06619631688320829, 0.049380035770516244, 0.06940008126079075, 0.025132920127362016, 0.024615092571043683, 0.031014713383610212, 0.0542527380129022, 0.09205578330663905, 0.03100159604312672, 0.15812122172886328, 0.15372188521489022, 0.08122117033288365, 0.13628109688720397, 0.11346151331259359, 0.24367430517750405, 0.14820430547960345, 0.15790022068446682, 0.07507129992929197, 0.14789753323120458, 0.24312878928838239, 0.2448903471832314, 0.2224240833592992, 0.0808175798926142, 0.13746332377195358, 0.09638456312278587, 0.13822159759940641, 0.07291209643646594, 0.20696183967013515, 84.41963564965033, 120.87732115099509, 104.40997169863795, 90.23278436353131, 64.76924750112718, 40.4986132344892, 53.024776904813706, 63.02487142624394, 80.70441369087466, 53.1148894371525, 0.3955528296289906, 0.34594259975898656, 0.35398394890850593, 2.525379792336495, 1.393838510397942, 2.692184957765764, 8.388359277479111, 9.458408336485586, 9.359704832876883, 3.4183598237652935, 70.53583375869259, 99.57399522104572, 99.45710074517035, 92.37248436097177, 92.79605327113983, 89.34970978767642, 85.91123457877868, 74.51195609185004, 70.26667287272792, 70.22342481920796, 68.80414655131679, 77.860318768409, 81.56931984809138, 71.65254039149131, 69.7923484925301, 64.77349150565364, 73.50236154371693, 83.406189334008, 85.90683367944534, 86.31522301704653, 83.37687353934012, 87.58963246499339, 82.7131457482615, 84.8570191475653, 81.71255696204402, 84.37975298973822, 79.35984873002576, 79.03095799107706, 76.88007139390515, 79.97100107131466, 69.96075937824865, 62.852267526811175, 60.09320566731115, 60.8376048457238, 59.88370795403758, 63.406545500601496, 61.93793166068293, 64.88412195636381, 62.57262999011625, 60.91075312706732, 58.33083375807732, 65.5943416010949, 71.91769261513987, 73.91106467093192, 67.39238354467577, 69.19879190383419, 68.71379083202731, 77.06308134140508, 72.79797446343207, 52.26895970682944, 77.98758399101996, 77.75366167868339, 77.66162718496015, 71.92607864256829, 66.66552912804389, 65.47130077115952, 68.9805826064079, 73.30888671259727, 74.0246251321608, 74.09179179899155, 72.2736006398355, 65.47416017901513, 60.51153821329917, 62.150924205780036, 61.66114960947345, 57.92801810849098, 62.4048270717744, 66.08155881204914, 70.2328698865829, 72.69795402403801, 77.21136262339931, 80.82608561361991, 77.03829196191604, 75.25891657798522, 78.98730201105919, 76.1783907490392, 78.60538082738077, 75.79941134299003, 77.1214226753481, 81.15812993818714, 78.26134973956694, 62.999207358206476, 65.68470124275454, 65.99317996732651, 73.63866390720491, 70.82985462680941, 76.18545101534936, 76.64170895853351, 81.60716287551388, 81.78188093246953, 88.67183008501607, 79.57950930441581, 78.85359625662528, 55.23989231355729, 5.347095631784009, 4.073932026663135, 4.726614913632793, 4.01640237819764, 6.161121293421715, 1.4411403334909871, 2.512395276177314, 1.5254543769744136, 0.22369581995712173, 0.18098287885227513, 23.353839074411702, 50.47181206364786, 50.160509232551824, 46.751055640559045, 44.95670072494015, 38.942169681672134, 59.647695018399155, 78.04980847143358, 83.4336223909932, 94.3582627081102, 64.23198084677419, 0.6366589016491367, 0.11050728675458701, 0.17080420568104715, 0.21597143202539415, 0.19213135804860823, 0.15111571538352198, 0.1654963348541529, 0.09447977742961339, 0.12310842187294077, 0.08943798426058024, 0.2051388874890343, 0.21857426171341252, 0.21925157536902737, 0.12737235234629724, 0.0682776628602897, 0.20710304499633853, 0.126266366531772, 0.08235239108363468, 0.12160928739655404, 0.12572045227692974, 0.164819618747119, 0.19861282961022472], [0.058765719840002645, 0.03947410139165098, 0.07203387622270854, 0.01809938454009112, 0.01583953241577312, 0.07300759695710675, 0.03369594834023907, 0.0331491569147235, 0.05305259233160366, 0.05342686075657126, 0.039059628672417135, 0.032697490626765836, 0.020221264229246208, 0.030902699837761543, 0.02739303463679408, 0.06550837758808367, 0.10266171903499674, 0.14568433586147525, 2.580238797010914, 78.74794329366377, 86.76285959059193, 87.18708745894894, 67.66155227538079, 63.67992685687158, 39.66113228951731, 69.42329268301688, 63.81575853593888, 58.18061482521796, 8.428704777071554, 0.0825720667959221, 0.10756375478400339, 0.036162759117301435, 0.5378257759636449, 0.41719827620733174, 1.1070937615248466, 2.0640703266666782, 1.919687145179318, 1.482455516534467, 25.9523485168334, 96.09111093705701, 85.13105161728399, 89.56254543796663, 88.40798793300506, 85.44407244651549, 82.11750245863392, 82.16828930762507, 75.58948609136766, 67.59466801920246, 60.83761661283432, 60.33166223956693, 60.43524026870728, 61.63108464210265, 60.37152920999835, 60.92615627473401, 58.357988326780266, 67.81679968680105, 78.58903238850256, 77.80395430903282, 76.08537566277289, 78.36173888175719, 75.17697826508554, 74.85404168405842, 77.23881136986518, 77.14346639571652, 75.53332559524044, 72.77773503334292, 74.27782197152415, 72.42719281104304, 63.269411594636985, 56.04389190673829, 53.97088396933771, 54.83886526476953, 53.64048311787268, 53.991272449493415, 55.014556069527906, 54.7577977180481, 57.01836555234848, 56.814896522029755, 54.70524580247941, 54.28858026381462, 61.15364589998799, 71.33138456652242, 69.66264355567195, 67.46524549299671, 62.89568816461871, 60.60908755948467, 68.02349290540143, 67.90909305695565, 46.295029117215066, 72.45175469306209, 71.82461477095082, 71.88230499144524, 65.84937018732872, 64.86647521295856, 62.072751368245775, 63.635819804283884, 66.57209042579898, 68.39647108508696, 65.14049199319655, 61.99874016546435, 58.34502489336076, 55.343360516332815, 57.110325521038426, 56.12672059766708, 53.72575152304865, 53.845544630481356, 53.34684664203275, 62.221154243715354, 66.92702570269185, 66.69053816026258, 70.98589435700448, 67.58752930548884, 68.38336252397107, 69.25451309450212, 67.59466801920246, 67.84617039465135, 65.20396770969515, 66.42872779600083, 65.98278568636987, 59.71553633289953, 56.92570347939768, 57.72250160094231, 56.91443843226279, 60.65905855547998, 63.62304072226248, 67.02372781692013, 71.48181530737108, 79.66853141784668, 76.52326906881025, 75.10320632688462, 76.42210329732588, 72.8287729140251, 73.05808251903903, 49.76212978363038, 6.628581525817995, 0.9563550533306215, 1.4429555328622943, 1.485166242045741, 1.2061344663943014, 0.3561334077629351, 0.28506756790222665, 0.35179180363493584, 0.04985650798546211, 1.481640153834897, 24.837522660532308, 32.51301273222893, 49.39014004122827, 36.941105857972175, 26.073504647900982, 44.43673956778742, 60.18827215317757, 71.45456267941383, 64.24478346301665, 68.94545385914465, 7.990865793920333, 0.41381032897099373, 0.05823475579100271, 0.042830443670672756, 0.025505790441867807, 0.04955962976260532, 0.03600615542382002, 0.07410609043173252, 0.032825254940337716, 0.054462416277777766, 0.04483092906734636, 0.06547614060822995, 0.08599437307566406, 0.039710707647065004, 0.06694447835006061, 0.0756926968273136, 0.02767075491588443, 0.05320140491089514, 0.02587281742073115, 0.07583289091745693, 0.026700878027646292, 0.0769621504831218, 0.016837903944354866, 0.004781161438703778, 0.008998762744839394, 0.044610123375370625, 0.02710022625603503, 0.04308071693465595, 0.01062562897606122, 0.0541080737997207, 0.06245066787326529, 0.05733307030412459, 0.019463040197508472, 0.02622841053732461, 0.04170275841569228, 0.0605072598573902, 0.014456778186403457, 0.028762340192653002, 0.09309731814409457, 0.2357488498091698, 5.188246994249282, 98.89683723449708, 95.7200860977173, 98.67322291097334, 79.59203735474618, 79.51135420030164, 43.7164080527521, 49.177335769899436, 50.560944003443566, 62.858382501909816, 8.98533127000255, 0.10215371847152711, 0.05387951912839086, 0.42607073882414453, 1.845615023086148, 2.0651671194261123, 3.46458078872773, 6.148251996886346, 0.28225317537303896, 1.0451330605053133, 31.711901964679843, 100.68414365091633, 87.32658263175719, 94.10419510256861, 91.13899307866251, 90.13514872520201, 87.69290847163047, 87.20760145495015, 80.26584563716766, 70.48791808466758, 64.8209325728878, 63.64891267591908, 63.925200508486846, 65.07643576591246, 63.60149906527612, 64.64876797891432, 61.41284788808515, 72.02371428089758, 81.43984240870323, 81.94964854947983, 77.97303199768066, 81.62283666672246, 79.46430929245489, 79.32980337450581, 81.49312388512396, 78.10745162348594, 80.1378979221467, 77.93182357665032, 77.69112340865597, 76.99994687111148, 67.17136583020611, 57.21627658413303, 56.775351185952466, 58.52843492261825, 56.973764281119074, 56.83765803613971, 58.45782441477622, 56.42300859574349, 58.296061946499734, 59.534201237463186, 56.5836061200788, 54.77581708661972, 65.01510558589813, 76.038009120572, 72.31002376925561, 71.75540847163047, 67.28423595428467, 63.294440238706535, 70.17321063626197, 71.52334536275556, 48.9007027687565, 72.23589881773918, 74.62230020953764, 75.89984755362235, 67.59753134942824, 67.17611189811461, 64.25430305542486, 66.8402942534416, 67.94085641061106, 72.1492850395941, 68.50988249624929, 66.00316632178523, 59.49609933360931, 58.30447935288953, 59.04479142158263, 58.00168806506742, 56.12564979061004, 55.30318367865778, 56.30592584609986, 64.34585117524671, 70.04254864108178, 71.01596324674546, 72.32092795833465, 71.79216892488542, 73.09814560797908, 74.76222684306484, 70.98664745207756, 71.97044849395752, 67.80022375045284, 68.52897659424814, 68.93233745328843, 63.26657179863223, 58.79900001710462, 59.47310247728902, 59.77804322396556, 63.66714385248, 65.641621851152, 70.3603861408849, 74.7845059056436, 81.71546736071187, 78.11219769139444, 79.1074755883986, 80.12122784891437, 74.54230739224342, 74.43646615551364, 57.11745246764153, 10.76269643922006, 1.0504255636084465, 0.7256145799352277, 0.7400599338354603, 1.9635397340020828, 1.341504776670087, 0.6311634771766201, 0.9150813616091206, 0.08770807345788326, 1.199306968239046, 29.664138401708296, 35.77827999668737, 38.23638623760593, 25.31845819565558, 27.676575376141457, 55.038447226247484, 66.14733695983887, 79.12075673380207, 69.89128635775658, 86.30407564101681, 14.459991205123163, 0.7393856538880257, 0.0737758988754884, 0.15400026624481525, 0.014066370204091074, 0.08809333907500391, 0.0353654109752707, 0.12212413678606673, 0.005540889875602819, 0.07783285537434202, 0.051820324583640026, 0.0769117342368249, 0.07639505389717317, 0.019752531417555386, 0.025905960299555334, 0.042293462001027606, 0.08727338750876727, 0.05989607874183886, 0.13170465616689575, 0.04358956019484228, 0.0643882804339932, 0.08668463361719925, 0.09586084243511, 0.11596207026272051, 0.08915793315898027, 0.11666228994727136, 0.11163007287729172, 0.08201718165148651, 0.08574194710461364, 0.14178649582449468, 0.11814149847674756, 0.10928061910934987, 0.18990833943168964, 0.10262425733549942, 0.1599292811607161, 0.19021354886072298, 0.17534554425266483, 0.13645263929520884, 0.20229555215806733, 0.2855000398572414, 6.068260650480948, 116.00470189125308, 104.58694904081284, 111.74983239942982, 89.27832265054026, 86.6562887930101, 53.034759336902255, 92.15580478791269, 83.90459706706386, 86.68766775438863, 13.826706890136967, 0.4396196166353841, 0.5642208144549401, 0.6527242557175699, 4.202402397509545, 4.406417617874761, 7.725792998267759, 10.696225012502364, 10.783013336120113, 3.918608129024506, 38.86765249313847, 101.54121291252875, 90.41242107268303, 95.49103536913472, 96.29548211251536, 93.976255232288, 91.49239078644784, 90.4137154548399, 82.48138073951968, 75.91079881114345, 69.93746834416544, 66.71978335226736, 67.0826888853504, 67.06604234633907, 66.31148030680995, 68.12454885052097, 64.72575626065655, 76.00741463322794, 85.12171637627387, 84.6611124469388, 79.17552871088829, 83.92234186972343, 81.74273567814981, 82.57221498797017, 83.19337721793883, 81.6954005149103, 84.67553107969223, 80.24748894476122, 82.10304460217877, 81.39606091283983, 69.98786295613935, 62.235502273805686, 59.67502609375985, 60.81049342309276, 60.56515701355473, 60.02525844881612, 62.27220389150805, 60.14867190391787, 63.16886555763983, 63.852032615292465, 59.5586258365262, 58.97131366114463, 67.545991405364, 78.55125211900281, 74.77797908167686, 75.70202673635175, 69.88209232207268, 68.22580091414913, 73.5253466329267, 74.80454921722412, 52.87529145517657, 75.33897999794253, 77.92386116520052, 79.52861262905984, 70.70031442949849, 70.46374843966576, 68.312955979378, 70.33626356432515, 71.97633989395635, 75.12405764672064, 71.38068875958844, 69.92521485974713, 63.00607935074837, 59.27917657359954, 61.77719293102142, 62.01264889009538, 60.202977118953584, 58.55512272927069, 60.18130210138137, 68.65889333909558, 73.07388967083347, 74.36296093848445, 78.05760614333614, 74.11127813400762, 74.8414038073632, 77.38106004653439, 74.78278790750812, 76.08708581616803, 70.88031984144642, 72.80552110364361, 71.16177343553113, 66.52851289318454, 62.33094138483848, 64.79979492002919, 62.92674549164311, 68.45898582089332, 68.88234292307209, 73.85471590103643, 79.25425068024667, 84.79160970257175, 81.71918576763522, 82.14236244078606, 82.60241723829701, 76.15190690563571, 76.92736733344294, 56.731907013923895, 8.842304983446676, 2.8748379695800046, 4.424023176393201, 4.952845948357736, 3.4636291236646715, 1.390112013586106, 1.10435594714457, 1.2859016248295385, 0.2794756469947677, 3.424497352492425, 40.85238748981107, 50.58910269891062, 68.27185738471248, 50.90179797141783, 38.182190848935036, 62.57841940849059, 75.96719464948102, 90.65240736930602, 81.34403459487423, 96.91218852996828, 15.142725821464294, 0.8101544661387321, 0.16680490495937486, 0.2886064038161309, 0.2232822397303197, 0.16494931743269967, 0.11136239409566888, 0.25264191591451246, 0.12560689506391365, 0.1819181496337537, 0.14022243539652518, 0.22896572346648864, 0.1657875555176889, 0.11162078789164943, 0.14386748174025168, 0.12204718325407275, 0.19525754836297807, 0.2142683726044432, 0.18025926284251675, 0.18622379359458724, 0.18572598966138978, 0.22856617797045942], [0.09566131483523116, 0.06265208004943787, 0.03535130729658469, 0.03559627540169224, 0.043888901390375636, 0.0017242643755913203, 0.017245263537211765, 0.06159665986835476, 0.04836553617590859, 0.01326118210976523, 0.04248268188788526, 0.08473988877789629, 0.027333911801237735, 0.045650738907317, 0.04001533867971551, 0.04871093457744968, 0.14523468821519805, 0.3703515399848262, 23.112115167802383, 101.76893003525274, 80.33664441877796, 88.52298398171702, 62.75195683202436, 26.43405675888062, 40.955502679271085, 108.05577555010396, 67.56640341974074, 36.661664439785866, 0.9061613402539684, 0.03330017199679729, 0.04990315890961117, 0.19588811533345332, 0.41410790816430126, 0.5718578530415412, 2.7179622842419535, 5.1442394718047115, 2.0170978600940397, 6.664017688843512, 86.97331043981737, 88.8346633603496, 89.30970945665914, 85.63533506085797, 85.34674275305964, 89.19758458291331, 85.2764303453507, 81.81006708452779, 77.94890942112093, 76.67562961578369, 70.39047072010656, 62.46598466750115, 60.599913135651626, 59.52059061296525, 59.91236086814635, 60.88794846688548, 54.486095136211766, 66.49190148999615, 77.49401646275675, 75.76335691636609, 76.65750042084726, 74.46487196030156, 72.93241762345838, 72.60988112418883, 72.53730943126064, 72.8711502013668, 69.27404649796026, 70.38941952490038, 66.71429987876647, 61.288795086645315, 54.5786669946486, 52.619666668676565, 54.70990165587395, 52.15328901044784, 54.39265251159669, 53.42606283003285, 54.50405174686063, 55.09728277883222, 57.23308394032141, 55.44335742150584, 57.24746727174329, 51.93407950862762, 63.151050152317175, 71.08519308028683, 73.73048659293883, 71.36857648049632, 70.67395610194053, 68.39205449627292, 71.76194314033755, 66.8207843842045, 51.79526682822935, 72.22235879590436, 64.75189493548486, 67.94961114083567, 64.72302236864644, 60.67723089648832, 57.71508832131663, 62.37475033729308, 66.86301262147965, 63.60184031148111, 61.85427927201795, 54.7287525669221, 53.20664936496366, 54.11936529221074, 55.445177401265795, 55.70724664195892, 53.33238878557759, 53.58286350004135, 53.451636683556345, 54.848682957310835, 65.17414592927503, 69.24987685295844, 63.279986304621545, 72.41489225818266, 71.93259762179467, 68.87214476062407, 65.57976607353457, 64.46861743927002, 60.50800415777392, 59.95268675588793, 57.17253038960119, 54.16605326437182, 55.90926047294371, 56.71957508210213, 56.057004390224336, 57.768024629162205, 62.66069504522509, 67.62046937019595, 72.05183767503308, 77.10965556483116, 79.84587746281778, 74.81400997407975, 65.92879818331811, 71.18152649171891, 71.79033325564477, 75.67550366924655, 56.36308654662102, 14.90166969837681, 0.41818631512503474, 0.7540162172048324, 0.5942624314658104, 0.656472999722727, 0.6494683820393778, 0.4305099731972141, 0.03487578503066494, 0.010195678407927195, 8.869388949486519, 31.7521180260566, 30.25680853474525, 57.81153155911354, 32.58206802029764, 25.4065114836539, 52.284872762618534, 46.8755595145687, 58.94199394410657, 69.64148629096248, 34.882830342938824, 0.7697538082157412, 0.10517262583298069, 0.053671863335635395, 0.045359912779062025, 0.022894717647784182, 0.06462009097900122, 0.0258892021262117, 0.07840842489273318, 0.05280352948654083, 0.03655758551171711, 0.06528778257028711, 0.06540938370650815, 0.020790766331277067, 0.015027371006116513, 0.06289603308804574, 0.0993175920279276, 0.05757802691791327, 0.024430440483434547, 0.004176175580435103, 0.007638520966734618, 0.02529460872944084, 0.05465193876936551, 0.03450180771910856, 0.039092175917880195, 0.081447311827252, 0.017168620270827127, 0.06363624639268364, 0.045508281027357426, 0.02267709888157345, 0.05615049484936942, 0.024068435210914865, 0.028517364426666213, 0.016925416083165237, 0.02963726048267657, 0.032265788590114926, 0.08685626795575505, 0.04199263459492115, 0.0682522287412036, 0.2629693940041527, 32.099606683177335, 117.97343361762263, 88.10962107873733, 96.9526909243676, 68.38288399481004, 41.63813629458028, 40.42036194955149, 70.829344718687, 69.31429786066856, 41.31464273698869, 0.7505540513703901, 0.03795508310318955, 0.5879613276450866, 1.4381110379772803, 2.502301791983266, 1.9568451061364145, 4.087576481603807, 1.5928304003131006, 0.5094459262346068, 10.93425012403919, 96.5720013649233, 91.6741612649733, 96.34583750078755, 89.21713367585214, 87.6970975629745, 92.89226901146674, 89.08745227321502, 85.71831672422348, 81.51487735009964, 77.65270771518831, 75.02419410213348, 65.63863692745086, 64.0123281171245, 61.930604673201046, 62.30930559096798, 63.38624723495976, 59.33893780554495, 66.84785658313383, 81.08241250438076, 77.05532289320423, 79.37162368528305, 79.07797936470278, 76.83342656781598, 75.72479217283188, 77.83156779504593, 75.73411956910165, 74.94045934369488, 74.63775434801656, 70.5193833381899, 64.02344411419284, 57.0664224316997, 55.16260593168197, 56.79953652043497, 55.331201168798636, 56.63097658464986, 56.01075964589273, 56.47359540385585, 57.39661931991578, 60.71548969514909, 58.07387144334855, 59.85180339505596, 55.09791035805979, 65.8813218147524, 73.42467508008404, 77.45252563107398, 74.4747563331358, 73.60356653890302, 71.26282153591033, 72.93571241440313, 70.38820359014696, 55.51327366982737, 74.81572012747489, 68.57895543498378, 69.78644140305059, 66.94421352878695, 61.779303166174124, 62.85305984558598, 66.80731496503277, 68.71682674654069, 66.02248007251372, 64.88826790163594, 58.39854563436201, 55.23720941235943, 55.99390522126229, 58.919985525069706, 58.527234677345525, 56.03234052658082, 54.87038935384443, 56.349954451284106, 57.974937500492224, 66.14252813400762, 71.40705493188673, 69.51509967927011, 74.9557722768476, 73.73089451943675, 71.76599887109572, 68.43585952635735, 66.88145560602989, 64.60508454230525, 61.94499977173344, 60.24168699018417, 59.62301938764511, 58.35590162584859, 58.81935711829894, 58.24197638419367, 62.12090238448113, 66.03410597770446, 70.44720388227894, 76.3928424158404, 78.6090757000831, 83.55738885941045, 76.63372301286267, 68.30191058497276, 74.45092401196881, 75.17413846908077, 78.32315060400194, 66.02967369940974, 22.057693812154955, 1.1082062437649698, 0.7147554981131709, 0.1333613979119447, 1.9132475939489182, 0.9903351590037347, 1.1040426478270562, 0.16210314757641286, 0.3042620847061757, 14.669796824455263, 47.59239227541032, 33.52697287836383, 42.240196581809755, 29.94866909519319, 44.39385629469349, 62.58450692699802, 54.82476826637022, 64.93645814157301, 80.19201094104399, 52.401382846217004, 1.046726033091545, 0.03500744490133178, 0.13246899741070886, 0.06480962113146821, 0.0257182476906887, 0.026787959241999254, 0.06223139052669849, 0.0213206023158085, 0.07713103456602943, 0.04672250740470425, 0.11410573196987953, 0.02737948254141356, 0.02529444402053712, 0.028988703852519396, 0.045994505541579384, 0.05410391777273148, 0.06117466799614411, 0.06035787271215551, 0.03558271564543247, 0.03868791515067701, 0.04430509780743911, 0.16356882699314626, 0.12783723748138837, 0.175481632111534, 0.2586849093917878, 0.12118050032445501, 0.1237283172386308, 0.11496217996482888, 0.19072538752469326, 0.2513915072045019, 0.0935399407641061, 0.11132994261119636, 0.13741863020245107, 0.11562405694876948, 0.11391949599548695, 0.16272904141055, 0.20350404053686127, 0.39281087837392287, 0.6268162039979812, 39.148082348608206, 131.54832532328945, 101.06218168812414, 110.34316847401281, 82.58919100607596, 39.979664048840924, 56.60517915602654, 145.68628895667294, 90.86012040415119, 60.139987776356364, 1.5638321950551004, 0.12351284734904767, 0.44688960717570403, 3.5182265552782246, 4.885273316214162, 4.3031269023495335, 11.456815734986337, 18.08584882367042, 6.486201940044281, 15.343519795325497, 96.09144041615149, 93.0099714955976, 98.89618612104847, 93.59414577484132, 89.44466252480784, 96.1221839535621, 91.81313868491881, 89.33874284067463, 86.89074454769012, 83.53390955155896, 77.37202290565737, 69.3378399264428, 65.950943885311, 65.33961111499418, 66.21974391321983, 66.1077602448002, 60.753238585687455, 73.67241198016752, 86.72406734958773, 80.98601633502592, 81.79911582700669, 83.79411958879041, 80.38276364726406, 79.72900652116346, 82.34132859014696, 79.31530629434894, 78.46710943406629, 78.57831647319179, 73.07370924180555, 68.79715688766973, 59.5089647077745, 59.44639113641555, 59.74542479361258, 59.14596896017752, 59.78979072263164, 60.26384445928759, 61.2083629638918, 61.10349839733493, 63.300233579451046, 60.75405051631313, 63.67714981878958, 57.932419007824315, 69.31735730940296, 76.35863934793781, 79.7922194388605, 76.42416646403652, 77.63320569069155, 74.2727856482229, 76.16082637540757, 74.91192802306145, 60.75453296784432, 78.10095617848059, 72.2871720406317, 74.50626081035983, 71.08607953594577, 65.76394488734584, 65.681547657136, 69.51225988326534, 71.99355909901281, 69.30632760447841, 68.21827780815863, 61.910035764017415, 59.72097273795836, 60.173359301782426, 61.73382328402612, 61.326304712603175, 59.92133132873043, 58.33854513783609, 58.43085027510121, 60.54760048466345, 70.65256349502071, 75.48031868473177, 71.03922290186729, 78.62047410780384, 78.27528984315934, 76.09842931070636, 71.72693206417945, 71.08007830958213, 67.06046473595404, 65.43207706943636, 62.985537898155954, 61.574633890582675, 62.78174331111293, 63.72304547217585, 62.166527394325506, 65.8348495729508, 68.42867374420166, 75.32624798436319, 78.81186223799183, 83.93878444548577, 84.63197708129883, 77.71674433062154, 71.48019144611975, 75.5634807771252, 77.86321347759616, 80.17171659777242, 65.87535981209048, 20.334039618892056, 2.436031141588765, 4.20127030341856, 3.676967327633212, 3.78991614426336, 2.340011274622333, 1.4993358042932328, 0.3321143143600033, 0.19854786535424573, 18.672084308439686, 53.94679277173935, 45.57823558007517, 82.55866712139499, 45.090841862463186, 39.90883781063942, 68.34391916951826, 68.63799495081749, 74.84836993678924, 93.07270588413363, 56.981177560744754, 0.9842831256889528, 0.18953747626754547, 0.29767087871028536, 0.1479240092298677, 0.13499799154458508, 0.17653771495867163, 0.17445485978837938, 0.13797398266052047, 0.254573269536899, 0.17017317905781731, 0.2824701314731952, 0.1022909171578865, 0.24100782890473646, 0.12209776037883376, 0.27171051850722683, 0.11402684023543713, 0.3053793779784634, 0.15069211472667035, 0.08446955933205544, 0.08835136514878081, 0.11070476889970804], [0.03326726852044944, 0.07599577653191744, 0.09351483606282743, 0.020750711424156063, 0.058709799251969785, 0.03304517580076091, 0.07499987755211131, 0.03233277914865363, 0.03424552832579902, 0.027890016940692743, 0.06279809640780573, 0.09012437605809781, 0.020699412261526433, 0.013982386857781921, 0.041054184548556805, 0.030536595994846958, 0.06429045100606258, 0.13984343637862515, 66.42125960319274, 84.8480369198707, 87.0504399268858, 75.07708334153699, 62.77720120645339, 35.36741956587761, 73.77969664912071, 121.62980433433287, 50.83226219300301, 14.262401807692743, 0.3309297279244469, 0.34372722669955225, 0.14054898803512897, 0.6182797781882748, 1.3841873960148905, 0.4418093104275965, 2.3970143448921943, 2.2615266086593753, 0.2455236414267171, 64.6812177473499, 95.42525722134499, 87.16946032739456, 84.46859467414119, 89.61159859934162, 82.6880112001973, 79.74328394859069, 86.70105872615692, 84.5712980147331, 85.17658249024423, 80.35251432849516, 77.2160537781254, 75.06248427975562, 61.81508302688599, 59.459303579022816, 58.07306735746322, 58.45017187057003, 58.06303785693262, 63.347270642557454, 71.79216892488542, 76.68289384534283, 77.10751395071708, 75.20437994310933, 67.61031827619, 61.683887589362364, 64.3442783048076, 64.06899852137413, 63.35054189928117, 59.95110996307866, 54.8683967897969, 53.29639711687642, 52.02013238783806, 51.9334872307316, 51.16151379000757, 51.425038230034616, 52.40162603316769, 51.49956718567879, 52.04139947891236, 52.669998522727724, 53.79048239800238, 55.83624162981587, 56.60318266960883, 55.32049309822821, 58.529501807305124, 67.54201412200928, 72.09153206117692, 72.50851923419584, 70.29473350894067, 69.8833788594892, 70.86004903239589, 62.58580130915489, 53.79209056977303, 71.16991627600886, 60.107565464512, 58.51408297015775, 56.46365219546903, 57.695731424516254, 58.64831039982458, 62.17461139925065, 58.25799142160724, 56.8848402269425, 55.37197812911003, 54.373299537166474, 52.42972197071199, 49.13088706231887, 51.00576823757541, 54.37184433783255, 52.11104116132183, 51.77831042197443, 52.097210884094245, 50.74890005973078, 56.60437507014121, 66.63684875734391, 70.23635295129591, 64.89318655383202, 63.89916773765319, 64.93075501534247, 64.55572935842699, 63.9311154427067, 62.02974257930633, 59.14404307642291, 55.09251317670269, 53.80440288974393, 52.77947579660724, 53.67064222212761, 54.400665913858724, 60.27891420548963, 62.62695089463265, 71.41941039792954, 74.39205708042269, 75.57400057392736, 71.7810764620381, 75.25672789542907, 77.06355202582576, 77.50776829258089, 74.61647941220191, 76.73997217609038, 77.28096115973689, 75.85437159384452, 26.794553956677838, 0.4826480787127249, 1.1712671696178376, 2.0203213129312765, 0.6169347729413741, 0.7750821029466968, 0.046961182097513834, 0.05038734562995453, 1.901236806185015, 17.83847866519805, 27.57302284240723, 47.15755439573719, 33.38750516214679, 14.461843544437041, 21.618570743068574, 38.134251640688994, 61.92809827866093, 57.58706215889224, 75.22124613485029, 13.133861384084149, 1.0198045389786845, 0.14246528036892414, 0.170042040126939, 0.07650802888336682, 0.054673155574428464, 0.06580992511683895, 0.030001998773866126, 0.03291405219164106, 0.09253194525597558, 0.03480548114185372, 0.01485931525577701, 0.02896959570446803, 0.07929257462702452, 0.07211174139933241, 0.08234928076666209, 0.057505869096325296, 0.08602119381389312, 0.036829006632850055, 0.05570293096224627, 0.039637573063373566, 0.0831880014870436, 0.038439170232102755, 0.06112087713254075, 0.11538664630103497, 0.048524698603057095, 0.036369376860919504, 0.07611189247860063, 0.07764020724402321, 0.08842193716836554, 0.04288053432960184, 0.04718936138576077, 0.05718973525349171, 0.0265848329440961, 0.01594418864471898, 0.055543167156077204, 0.027482109594969984, 0.10195862652072984, 0.6422050717857577, 84.8983766186622, 93.18319120714742, 97.06073653313422, 85.71133490531676, 73.15914630889893, 37.90529112662039, 60.576594644977206, 111.67142421968522, 55.840587615966804, 15.552695874244938, 0.28131790459156036, 0.04455424109173398, 1.22656584747376, 1.8361780455996914, 2.3827751605741443, 3.0616918398487956, 3.0966131917891966, 1.3041943335725417, 1.0083168973365138, 77.17853238505703, 99.41460578672348, 92.60959948262861, 86.01465179074196, 91.22062544668876, 85.8418478504304, 80.07045668940391, 89.12821354404574, 89.89749231646138, 87.59746936059769, 84.66741961817588, 80.86308140908518, 77.65387658149966, 65.05980883875202, 62.29600483371366, 60.64925655241936, 59.67730106845979, 60.72118497663929, 65.68204187577771, 78.01630358542167, 79.2659628775812, 79.59309639469271, 79.92757258876678, 71.36105337450581, 65.82884050184681, 68.35083823050222, 66.27872067113077, 64.4831145194269, 61.69388178856143, 56.57151345283755, 55.748984582962535, 54.542396837665194, 54.618592800632605, 54.46517321371264, 52.94755328086115, 55.787533637016054, 54.824274047728515, 54.837735622159904, 56.1133296258988, 57.52251955770678, 58.10400309101228, 59.712445505203746, 56.8629926250827, 61.539156052374075, 72.00395337996945, 74.0116891553325, 73.47239463560044, 73.29538591446416, 73.62233115780738, 73.77960251223656, 66.35801530653431, 56.6863133830409, 73.60574737671884, 64.00937457238474, 59.934926263747684, 58.99318479722547, 60.16257670617873, 61.23933007640224, 66.46857907695156, 61.39409111392114, 60.572103531129905, 57.951638621668664, 58.271045069540705, 54.51484218720467, 53.19069708547285, 54.82116753055204, 56.12572823801349, 52.816632409249586, 54.20185665930472, 54.40312916232694, 52.353369112937685, 59.716120766055205, 69.59582990215671, 71.93449604895808, 69.25445033657935, 68.56645091887444, 68.30191058497276, 66.78847189872496, 67.44754775877922, 63.58162049324282, 62.45949314486597, 58.22171734225366, 56.9919523116081, 56.136695185015284, 56.64137478797667, 58.53809964272284, 63.14161292968258, 66.23777897127214, 75.2121619255312, 78.60221939702188, 79.17617982433688, 76.02251575839135, 78.4609591576361, 80.18894364756923, 80.11009616236534, 79.06076015964632, 79.88565814110541, 80.1682492225401, 81.28143356692406, 37.05959673850767, 0.6851556993299915, 0.6266286043870835, 0.25405016938044184, 2.079366344598032, 1.5652753821303769, 0.8579460339200112, 0.05345941566291356, 0.9823284983154267, 28.63079390218181, 36.81264039008848, 46.970873109755985, 35.659922476737734, 24.28643357369208, 33.24054179653045, 45.11863577750422, 72.18133864864227, 62.09982748954528, 89.88610959822132, 23.613415648860318, 0.9384346633188186, 0.08844780795756849, 0.10208494675856444, 0.0557647159533395, 0.028595988030335116, 0.055648826002593965, 0.007894294263209187, 0.056709988012669556, 0.003666715858872199, 0.04736754960650879, 0.09273944783114618, 0.0019671249009984276, 0.027817476075142625, 0.05161971296934832, 0.12300348314907282, 0.03314945951945359, 0.05731747658442586, 0.060366954684497855, 0.08501069319825019, 0.0036519861427105724, 0.1834286758375745, 0.20069111889648825, 0.14095797173438535, 0.24380408047187715, 0.13107965099475077, 0.13104160706843102, 0.18865993787204066, 0.1898091770107708, 0.2332305809062335, 0.158487779478873, 0.16016266218596892, 0.1907736663856814, 0.11586113817869656, 0.14982965294151537, 0.17767475797764717, 0.1271489151423016, 0.15792573141234537, 1.0594619690410554, 101.27725308941257, 105.46899595568257, 110.69836262733706, 96.71557580271076, 85.69209175725138, 50.15934036624048, 102.74733389577558, 139.95478045555853, 73.2938640348373, 22.502306238297496, 0.42154153508524744, 0.4203839455881427, 1.5359225700939856, 3.5601292358290766, 3.6196536546753304, 5.859742549157912, 10.56058160720333, 10.558715539593852, 2.198380616403395, 82.50993559437414, 99.21538076093121, 97.8333257859753, 88.91279697418214, 99.44487863971342, 88.18642108671128, 83.69711937442904, 90.16918705355737, 91.46221991508239, 88.65450105359479, 89.49918347020304, 84.9949061486029, 82.45277881622314, 67.09686433115314, 64.05515255466585, 61.626134610945186, 63.77363228028821, 64.35447254488545, 68.96206117445423, 81.27653060420867, 81.77066295377671, 80.88427005275604, 85.23541019808862, 75.50833225250244, 68.79247357768398, 73.91339455881428, 71.39356197849398, 68.9940441808393, 65.0185808058708, 60.02546633443525, 60.187083675015366, 58.08404214920537, 57.73685355340281, 57.39681151605422, 56.85833284931799, 60.08453330686016, 58.291049157419515, 57.246176811956595, 59.732327999607215, 60.216827008032034, 62.572104392513154, 63.081522218642704, 58.90865379764188, 64.83905000071373, 75.17648404644382, 76.51645983419111, 79.38157866078039, 74.98122061452558, 77.49067460336994, 77.10552923140988, 69.61625760601413, 59.51709578114172, 78.28098512464955, 67.43368610259026, 63.49198649006506, 61.97951662924982, 63.742445515048125, 62.43311520545714, 71.35738988076487, 66.56422999597365, 64.35857926645588, 61.42025724534066, 60.72498967570644, 58.28681299763342, 56.57906793778943, 58.1932330900623, 59.8041779764237, 56.5110775732225, 58.38995956605481, 57.21293472474622, 54.92027798006612, 64.34918911226335, 74.32138381465789, 75.94499403430571, 73.56240518631475, 72.3923150954708, 72.56479740142822, 73.62550043290662, 71.14860996123284, 69.49307164838238, 67.13531140358218, 61.46416033467939, 59.93971547772808, 57.669290727184666, 61.390223656931234, 61.13066865551857, 67.45663981283865, 71.36138285360029, 77.30706845560383, 81.96828765253868, 82.69254546011649, 78.61135851952338, 79.59911331053704, 81.54995118418049, 82.85937955302578, 83.2011042871783, 84.55345123044907, 84.35210812476375, 82.47028043193203, 33.15377112357847, 1.3225189115731948, 5.836339237228517, 5.603771123193926, 3.118713051080704, 3.0019127120894775, 0.955715768279568, 0.13241157145990481, 3.0450205408757736, 31.255455747727428, 42.790461970913796, 65.53779279032062, 48.156805653725904, 20.64383625984192, 36.201201715777, 54.15716125119118, 84.5772913963564, 72.05854492802774, 98.77714218631868, 23.284299373626713, 1.5522930723044182, 0.23783841590967872, 0.2683283935391134, 0.210533035137961, 0.1559550161924093, 0.2272074137844386, 0.11039713097195472, 0.14073833432649413, 0.1064118343375383, 0.11989644503281002, 0.23987758874652848, 0.11501299457684641, 0.20509551159076153, 0.1611983058072867, 0.21211961855090436, 0.12042173620073066, 0.16832650879458075, 0.2195613813256064, 0.11944770137028349, 0.1551193368410872], [0.014326519299028142, 0.03965437337155304, 0.06808058674176855, 0.04621513886377216, 0.0200903800226027, 0.04841152060356352, 0.01846126532332311, 0.08050035820492814, 0.05340022387944403, 0.14307301791925586, 0.04951351126956363, 0.06869676658102582, 0.01712823211545906, 0.10220158364503615, 0.10559300125967111, 0.3564988929898508, 0.3583471567159699, 19.11085632539565, 93.89190073936217, 80.21677678631198, 87.09233084032613, 60.43749170918619, 37.68182193079303, 28.170503762460527, 41.75782349801833, 53.71225464728571, 42.0074039120828, 0.6418401687856644, 0.22549254128769522, 0.01364464742026382, 1.7410665750503542, 0.48384553542540926, 1.6419844401459542, 1.8853802570412237, 0.9655202841085773, 1.9107578694820406, 29.22973002156904, 100.75851963412379, 82.52299708704795, 85.97534179687501, 83.40885654572519, 84.49088942620062, 83.90529524895453, 84.78102714784684, 81.19844405881821, 80.58313400514665, 77.57517030162197, 84.53332947146508, 78.42036262635263, 77.76524051543205, 69.34765369661393, 58.04320635334138, 57.22261513433149, 57.73842250147174, 55.03462291532948, 59.09267963901643, 73.88942887706142, 77.30537399168938, 76.32578557537448, 71.44527450684579, 62.69443919581752, 57.05799325819939, 55.97013173564788, 54.27576980283184, 54.81999081950034, 50.99540533558015, 53.60076127513763, 51.59800690989341, 54.62786136134979, 51.31358408158826, 51.106839872175655, 51.755588131566206, 52.597956349772794, 52.58078813552857, 53.217180928876324, 51.59297058659216, 51.79745943315568, 54.441007491080995, 55.88716183939288, 53.1151443912137, 55.65169019083823, 60.0089963020817, 66.5945420726653, 69.4733891948577, 73.92131774656235, 68.43406308081843, 70.65359115600586, 60.845175020156375, 52.63823516907231, 72.07496396956905, 59.01847624009656, 54.13349759194159, 53.291933459620324, 53.38774519581949, 56.45080251078452, 55.72535230267433, 54.203747241727775, 56.35874840521044, 58.137170653189386, 58.24659301388649, 57.590207899770434, 55.409432841885476, 53.329548989572835, 52.78552801378312, 50.74370684162263, 51.151570581620746, 48.45869087403821, 49.50131570139239, 52.02261917052731, 52.65171635535456, 60.35909529655211, 65.60341404330346, 66.30411409562635, 65.27611578664472, 63.69295304821384, 66.88082802680232, 65.10314710678594, 59.82140894859069, 55.99506232046313, 54.98280840535318, 55.67496945781093, 51.777573016382036, 53.64165198418402, 59.43130962310299, 65.77292319267028, 71.85418944205009, 73.32253656079693, 73.69789954154723, 75.87701935921946, 75.10028808347641, 73.38796954001151, 72.07807048674553, 72.39517058095625, 71.09252791250907, 76.51838964031589, 74.80169373173868, 88.85770336274179, 40.715963532847745, 0.2719174541773335, 1.2699307140804108, 0.43062120916381963, 0.5261786041721221, 0.29253612843252, 0.11410021613682471, 0.489079907776848, 13.119423139479853, 24.77038541147786, 36.162585981430546, 49.53047067888322, 26.61852582808464, 22.09524070062945, 40.03262389090754, 48.9876538707364, 62.28110374942903, 64.19795428552936, 51.82162907815749, 1.7714019408149106, 0.025184726823241483, 0.0781926945332558, 0.08138191856203542, 0.03402646931429063, 0.04691782152099956, 0.20190547550878218, 0.05321951522942513, 0.07352202499826109, 0.12466210180953627, 0.04485485782366126, 0.03796902590341145, 0.05819700680853379, 0.04735750236338185, 0.02642999316806034, 0.03493152941847521, 0.06761879660189152, 0.001705956310615875, 0.033764034404509494, 0.03316493449552405, 0.03477258915682474, 0.03931911797412942, 0.049672899692649805, 0.05168683376283415, 0.008556279935874045, 0.04826076982182361, 0.012240221521126167, 0.10829785853744515, 0.04664808579330002, 0.08405093058583238, 0.05343220805028274, 0.01204046696769975, 0.019906549564292355, 0.06968970080056498, 0.126303376239394, 0.13206376754228147, 0.5364736001337729, 26.440473756482525, 111.56977207429948, 85.93341165973295, 98.739636482731, 67.78028242049679, 60.11564554706697, 41.081026369525546, 49.02417113704067, 59.415200448805294, 47.46602527556881, 1.283668570460812, 0.19649263531450303, 0.4954591219223315, 1.558666678686296, 2.2531055250475487, 5.62519952174156, 7.417943814108449, 0.38375044842400863, 2.0405580463909336, 35.921532800120694, 104.79848246420585, 87.2537128386959, 88.46754520170151, 88.51639439982753, 88.8707648554156, 85.89102652765091, 89.06905635710686, 82.09179524452456, 84.93985960560461, 79.13068033033802, 86.67255093974453, 83.99350150938957, 82.39825787082796, 72.55284986188336, 60.76858682017173, 61.10145092010499, 59.71608154235348, 59.25275156574865, 62.0109308919599, 77.67771674740699, 81.01854062849476, 77.60843984542355, 76.5544911353819, 64.81034217342254, 59.910321235656745, 57.40414242590628, 57.64967103158274, 56.54416276562599, 52.43748041891283, 55.87033879372382, 52.96985587766094, 57.73725755753056, 54.3394337930987, 53.477128167306226, 55.40861698888964, 54.54379320144654, 53.95434725669123, 55.888401308367335, 54.2649793624878, 56.60791697040681, 58.471364436611054, 58.019260283439394, 54.89633191016413, 59.362036643489716, 61.81979771583312, 68.628628330846, 70.03005981445312, 76.74157250312068, 70.50356049691477, 73.07650196936824, 62.05527720912811, 55.22403024858045, 75.69233848202613, 62.23808319337907, 57.181226284273215, 56.50751213873587, 56.534976574682425, 57.007939892430464, 58.15648440391787, 58.51489097841325, 59.876965399711366, 60.11380203308598, 64.11171705492082, 61.475311633079286, 58.667239758276175, 56.401388491353686, 55.62308042280136, 52.47380941144882, 53.76114306911346, 50.35795742465604, 53.23522383166898, 53.48127019020819, 55.95670938491822, 61.11028017536287, 69.80071098573747, 69.09146801117929, 70.17750955397084, 66.04470422191005, 69.46691728407338, 66.20829059231666, 63.80208907588836, 58.56601907360939, 57.22880855683358, 56.196554476215, 55.65912308231477, 56.53169747321837, 63.1827978164919, 71.49279794385357, 74.89734465076079, 74.80196829765075, 75.16375987760483, 75.65816679308492, 77.53981405688872, 75.56837589510026, 74.43359498054751, 74.34594569667694, 76.34763317723429, 78.94726245634018, 77.70719728162213, 91.47263773026006, 53.61762354450842, 0.9889004295391421, 1.0722833391158813, 0.7029586633847607, 1.0644736549546643, 1.1923706243115089, 0.12539120300883247, 0.2951082839600502, 8.491170483250773, 35.063730055286044, 38.89496787901848, 38.50916354886947, 25.29743036916179, 33.438927435105846, 47.85319851290795, 58.465833894668094, 71.9630273695915, 70.5697230369814, 69.01085545939785, 4.848011780169703, 0.14364499448528215, 0.09220367658042139, 0.014551160218674811, 0.057275671166397875, 0.035497534329131726, 0.1286872043724983, 0.12590997476851748, 0.01243050914302829, 0.04688767596117912, 0.048528414129489855, 0.06381670606412715, 0.030241782378946102, 0.04791941636452272, 0.035107917332601164, 0.023116438814829436, 0.07647358557029117, 0.05565911456341705, 0.01104227738500002, 0.051758374883643085, 0.11389790763778072, 0.0960731943468413, 0.13883888060527463, 0.1261481515041763, 0.06283031806590096, 0.1983240757498049, 0.2673217233630919, 0.19008909021654438, 0.15515701304520332, 0.24429831443534744, 0.12293261235519765, 0.18608749123109927, 0.1201628597693578, 0.2618462171766066, 0.24622660370603686, 0.403601594509617, 0.9267063474943562, 30.344247971811605, 124.1734927700412, 99.03321020064816, 111.10679903338033, 79.88613667026644, 57.126473919037856, 43.477594544810636, 65.29432342898461, 65.91547781421293, 65.33384915321105, 2.2764441178691004, 0.5413217722408233, 0.285671919343933, 6.863110824938744, 4.7189751171296646, 7.835704184347584, 8.852404106047846, 8.923854981699298, 5.1515860711374595, 42.107267456669966, 107.88048482710316, 90.75091377381356, 90.85469968857305, 92.57937369808074, 91.58614327830654, 92.1727337375764, 91.17936211247599, 87.5848001049411, 83.82861291208576, 81.62315045633625, 88.73152071429838, 85.65548035406297, 85.04631273208126, 77.4250376609064, 63.917999036850475, 64.81871643374043, 62.036649873179776, 62.14605654439619, 65.76040690945041, 81.41230737009357, 84.26347040360974, 79.56140364370039, 79.69874151291387, 68.58305038944368, 63.788156817036295, 61.453471875959835, 59.64275283198203, 59.03314982691119, 56.40241222996866, 57.56999984864266, 56.05587082524454, 61.99550813244235, 55.42042724547848, 56.80493762416225, 56.438239159122595, 56.706592036831765, 59.19954461436118, 59.522269387399, 58.07129052377517, 59.38885781072802, 62.71089746106056, 63.21724407134518, 57.49879314053444, 62.400896856861735, 65.25839059583603, 72.75747991377308, 74.44709577868062, 80.14429138552758, 73.31904565134357, 75.69784548974808, 64.71889603522517, 59.05209879721365, 78.90299458657542, 65.49896917035504, 58.50906233633719, 59.29577996653896, 58.560429696113836, 61.69207749828216, 61.66292644316151, 62.481034801852324, 63.87955588679161, 61.379095892752375, 66.16122999498921, 63.79829222156156, 61.54875801455591, 59.587918096973056, 57.679398675118726, 55.557514083000925, 56.99128158630864, 53.84010430305235, 54.91929738752304, 57.64148504503312, 60.24718223079559, 65.86383588852422, 71.27802464269823, 73.34414882044639, 73.37578665825629, 70.32473179601854, 75.19090267919725, 70.06278022643059, 67.1650900379304, 62.01364517211915, 59.87628290730139, 61.820786153116536, 58.977322732248616, 60.37916998709402, 68.42057012742566, 73.28408164362754, 79.73076374300065, 78.34062084074944, 77.99232221418812, 79.1237691140944, 82.01643866877403, 80.17607827340403, 77.33619597650345, 80.45593938519879, 78.953381353809, 82.98193008668962, 80.66117348209505, 95.97415370325889, 47.98280539051179, 0.896027835626756, 5.248270534699963, 4.188056328604299, 1.5102714949077176, 1.5853891737999457, 0.26041210058235353, 1.3344673091365447, 20.984868695659024, 42.68529930422383, 51.81804795419016, 63.8014183505889, 38.27681802934216, 33.35360411674746, 56.33583784103394, 67.4496187702302, 82.9683586858934, 83.46685271109305, 75.56996053264987, 3.8824071038153867, 0.19536466277655096, 0.18912317591809458, 0.2493586162886312, 0.21906572243859693, 0.12894048836202393, 0.2248357434666926, 0.2109864059715502, 0.172194869768235, 0.2863431962267045, 0.15068402483818993, 0.17757971710976095, 0.1249961238054018, 0.0918315570320814, 0.14012442210749274, 0.14524360547863668, 0.19705276816121994, 0.20949230469282598, 0.20647240141707085, 0.09578559727918717], [0.05729137596884563, 0.05130925966847328, 0.02837417110229933, 0.03630100351367747, 0.02559069022085638, 0.01729214811817773, 0.0633535139833487, 0.03803180680880624, 0.02083996258255455, 0.07820416286948227, 0.015023287757480097, 0.0441857757827928, 0.03841466690984465, 0.09283496367354548, 0.039644927507446664, 0.11502235617128112, 0.2365163933005064, 58.83381105238392, 92.0197848350771, 74.20869411960726, 69.39546738901447, 66.06380616464924, 21.518995492689072, 31.21394726537889, 42.14729132190828, 38.04146012952251, 15.930670172937456, 0.06366738403636603, 0.06553185052208363, 0.32369359847038026, 0.728883017455378, 1.6105551008255252, 1.7368974632793859, 3.0647137809184293, 3.3343323584525817, 2.396696387760101, 84.15609159777242, 84.80277276808216, 87.03652335751443, 81.59668230241346, 80.6982869486655, 81.01850924953338, 82.34879678295505, 82.60850475680444, 83.17807212952646, 81.51152764597248, 80.53091941341278, 74.83441414371615, 83.16103335349791, 81.03989401171285, 73.41909746969901, 60.021324311533284, 56.83013100777903, 56.82260397941836, 57.90415440836261, 56.08418641551849, 71.28335906613258, 74.08178975505214, 76.84953966448384, 66.52925029877694, 60.16552632854831, 55.99719216746669, 55.17153716856434, 54.274867657692205, 54.50331041889807, 54.808710082884765, 52.416621254336455, 50.78526043122815, 53.138254996268984, 51.37377677425262, 52.94705513984927, 52.60167475669615, 51.65178260495586, 50.581124597980136, 52.77519256837907, 50.04821569688859, 53.20884589226016, 54.49156684260215, 53.5005094159034, 54.068507840556485, 56.108344293409786, 54.115874382757376, 59.220748947512725, 60.322456436772505, 65.03807890799739, 63.16669256456437, 71.07180210851854, 60.87895447208036, 51.07046773356777, 72.0005173836985, 58.37000646898824, 52.74258590513661, 49.68493361626902, 53.41186777237923, 56.0752159549344, 61.55416304065336, 61.5120485521132, 67.01399249415245, 68.33739234555152, 67.19115811009561, 66.94490386593726, 66.06636355000158, 61.934385838047156, 59.89133304165256, 54.22674017567789, 51.023030588703776, 48.233338940528135, 47.42090625147666, 49.261666728604226, 50.02828221167288, 51.610276083792414, 53.46429809447258, 57.91341904670962, 62.55455178599205, 62.9045174198766, 63.5723009417134, 62.88759631495323, 60.52123431236514, 54.90096422933764, 52.357075752750525, 52.30752837273383, 52.464293741410785, 52.38634840134652, 59.68987618723224, 67.62381122958276, 73.6867521655175, 72.89957954037574, 73.21231795895484, 72.89683388125512, 73.45010772828134, 70.24831618032148, 71.88714519623788, 70.67519557091498, 73.01030805034023, 71.41796696570613, 75.17530733539213, 69.51498985290527, 91.69826815205236, 53.26970931022398, 0.19533674653259017, 1.2782965167876215, 0.9974953844662636, 1.110042648450021, 0.2771046048691196, 0.07839701784354064, 7.158718782086527, 42.924920820420795, 32.51284995386678, 65.77838313195014, 52.77850697117468, 22.645349194926602, 15.760689358557425, 48.53223531476913, 71.46012460031818, 56.952524646635986, 80.02039940126481, 24.526433598610666, 0.849799148498043, 0.13052451304130017, 0.03168125967344931, 0.05371043586262292, 0.02885339548811317, 0.042085603194972204, 0.01640400515058108, 0.03289467782803601, 0.03131944017725126, 0.02486528731101463, 0.06753897790106074, 0.010528481366383213, 0.07696866223047819, 0.07093280869265718, 0.010494282243833428, 0.026548269482690002, 0.0037918632639752283, 0.03360777162015438, 0.052032335586245024, 0.09428319926824301, 0.07355649895485371, 0.038332094122926076, 0.04156703061814751, 0.011797269483307197, 0.06932443007826805, 0.03515003301623849, 0.07487145057248493, 0.020950989790200707, 0.032322352692004175, 0.033911100303333615, 0.0811977357032799, 0.06697729755673679, 0.09310510159740526, 0.027151508181686365, 0.05059587093250406, 0.07950848118672449, 73.69735825446345, 101.95408159686674, 83.44790766316076, 77.69036246884254, 82.16496313771894, 40.426625974716686, 31.71724815522471, 28.99490752527791, 45.70744629829161, 18.135755100557883, 0.06294060025304075, 0.10467531219605478, 1.3843224726376997, 1.774974607171551, 2.337540671710045, 5.360937676122112, 4.433388815772149, 3.0808425670669926, 5.217606915581611, 91.68388874300065, 87.98619977889523, 92.93046505220475, 84.02399401510917, 83.19030207972374, 84.1572290851224, 86.71393194506246, 85.57965309389176, 87.60867949455016, 82.39956009772517, 83.7124558418028, 77.13744947987219, 84.7488715571742, 83.01135570772233, 77.79175573779692, 62.844371795654304, 59.98884708650651, 60.05508415160641, 59.81472130744689, 58.88222486742082, 73.23829973897627, 75.7319308865455, 81.22894440927814, 69.8865246003674, 61.844995021820075, 57.891771485728604, 57.10076278255832, 56.07776157317623, 57.22127368373256, 57.171098724488296, 54.45231176191761, 54.77801753628639, 54.787760703794426, 53.518062022424516, 56.622778830989716, 56.26734541308496, 55.081252051937966, 53.94292923711962, 56.411516051138605, 52.59914090556484, 56.45643895672214, 57.94853994923254, 55.835617972958474, 57.110717758055664, 55.96865692446309, 56.896026826673946, 62.228085071809836, 63.826505830211026, 68.92994480748331, 65.663269412133, 75.57684036993211, 62.950946515606304, 53.423325015652566, 76.31437147817304, 61.72504894195065, 56.92158499071675, 52.118909435887495, 55.615561239181034, 60.206373891522816, 64.7925110786192, 65.32633781433105, 69.71658399028163, 69.52813763772288, 70.87993544916954, 69.4149301898095, 66.73234278155913, 65.02014975393972, 63.69738140413838, 56.359995718925234, 53.39620182591101, 51.657803443170366, 48.98569268565024, 50.9064067563703, 53.83132996097688, 53.44072072736679, 55.893198367088075, 60.81348226916406, 64.05887096158921, 65.52937538393083, 66.23758285276352, 65.13111752848472, 62.1043852836855, 55.91918406947967, 56.30145434410342, 55.79438601770709, 55.25606424577775, 55.72441093383297, 63.402803559457105, 71.61312057125953, 76.14822772241409, 74.49210889877813, 76.10657999592443, 75.69789255819013, 75.22157561394476, 72.39139726085048, 74.6617514087308, 74.02610778808594, 76.39542333541378, 74.04645704453992, 79.18876278784968, 73.15262732967254, 93.37817222841325, 65.54471969604492, 0.6968867117839476, 0.5753339923197224, 0.9869814099323366, 1.1644947072190623, 0.8585803547213156, 0.11090503960487344, 2.776821125899592, 46.50555056910361, 41.08092831027123, 49.511972781150575, 33.85169806018953, 26.245071080423173, 31.439528657544045, 58.75773668289185, 77.58766697299096, 65.50812398233722, 87.99421710352745, 37.535866614310976, 0.6736318983377949, 0.1364287373519713, 0.04237310067119618, 0.06625181229244317, 0.07144133785679456, 0.04178367262225478, 0.0599585302294262, 0.026071764709007357, 0.02388710986011692, 0.010995275018015697, 0.0677996622999349, 0.02691517963314489, 0.10484491640161123, 0.046376963446457545, 0.06009006369558554, 0.0476123146983164, 0.015869712449550148, 0.028733590828074564, 0.016346797534835436, 0.2262525617956154, 0.18850782345379555, 0.10531786844254502, 0.20874743740404808, 0.0733415500050591, 0.13132507492217327, 0.10796289425343276, 0.1888327060207244, 0.11598340581141173, 0.16376142149731038, 0.09309742539640396, 0.1704183118718286, 0.23423498346199914, 0.2559514923561966, 0.09187840330865114, 0.19030235377290558, 0.48794177691302, 94.90174631918632, 112.58673283361621, 97.36019380630987, 86.95514202117921, 86.60183845027801, 31.68361971455236, 45.8486359350143, 57.073596446744865, 62.6357566156695, 26.72352375522737, 0.24511744628750512, 0.2645294248096405, 2.064315229654312, 5.365224336424182, 5.992452511864324, 8.543410570390764, 12.838124479016951, 10.407297342054306, 6.304101492128065, 95.17905789036905, 90.8774180566111, 96.50001018278061, 88.3101797103882, 85.74411023047664, 88.27053239268642, 91.43506142400926, 90.06095317102249, 89.36870190405077, 85.59591524062618, 86.80508782786708, 81.36559194134128, 87.72960616696267, 86.67364135865243, 81.10342856376403, 65.97928693217617, 65.06432348682036, 61.745908106527025, 63.40873418315765, 62.38398359667871, 78.236630962741, 79.3257947121897, 85.0116232902773, 72.70768934680571, 66.62139461886498, 61.71254834821148, 60.05926932058027, 60.618473791307025, 58.37466624475295, 61.17017084552396, 57.10322210865637, 56.63069025162728, 56.76487061285204, 56.92083974038401, 58.683925520989206, 59.34014981792819, 57.01288600121775, 57.57795833772229, 59.443743536549235, 55.769898660721324, 59.86424907561272, 61.4725895081797, 59.58909088565458, 60.9953704187947, 60.580893562686065, 60.1452398300171, 65.27780240581882, 67.25950148797804, 74.43142983221239, 70.16019621203023, 80.11486576449487, 67.34715077184862, 61.01594717271867, 78.1694015379875, 63.93979957026821, 58.45591814287248, 55.50612711137342, 58.95345903212025, 63.069504076434725, 66.93182668378277, 67.4111952320222, 73.79370735537621, 74.12077026982462, 73.3201752939532, 72.20186048938383, 70.54902861195227, 68.66989166505876, 65.97334061899494, 59.806437261642955, 57.41110855533231, 55.64976430708363, 53.876958893191436, 54.06493063895933, 57.00475100548037, 59.0653681755066, 59.227773912491344, 63.34207742444931, 67.71656743941769, 68.69389657051333, 69.8076771151635, 68.91619297765916, 68.17339020390665, 59.40066022257651, 59.31922005068872, 58.10903156957319, 59.612825147567264, 57.65238138937182, 66.78528693414503, 74.2735230538153, 79.98463523003363, 78.29498798616471, 78.07396242695471, 80.38907866324149, 78.4527692487163, 75.51644371401879, 80.1006510949904, 76.82471890603343, 84.42349526189989, 76.84457394384569, 84.34167462010538, 76.50734424591064, 99.28308871484573, 60.943340178458925, 0.3792035327323022, 6.484002470970155, 5.342478511794921, 2.5158241631523257, 0.9639506005952436, 0.2511046379203758, 12.0860953100266, 59.05830790919643, 50.88786179019559, 85.47563183692195, 67.14146168001237, 31.584695577621464, 29.235442953725016, 63.527385880870206, 89.74647322008687, 75.02766147736581, 103.46519823997252, 36.95223754452121, 1.1380156442042322, 0.266595441367357, 0.11691316842071472, 0.17645860871961042, 0.1582944035650261, 0.13973880408992692, 0.21180152352298462, 0.12099064075418058, 0.13565963104126916, 0.1554730396357275, 0.36212694260381884, 0.13566462593453546, 0.19800576621726637, 0.1635006604896438, 0.11805309193028558, 0.1382951726836543, 0.11460098483028913, 0.15902997054640325, 0.13673455965134407], [0.04084517278017537, 0.08572182197484278, 0.04151282223662542, 0.014157904304503916, 0.08124881844607093, 0.0146464969880218, 0.04108642152841053, 0.015690376054525616, 0.03905589399378627, 0.09351436874919361, 0.12452173918004959, 0.026243977443945986, 0.04327519601511379, 0.03953222448246614, 0.08509913038822912, 0.08146283276859792, 3.879388104523382, 69.30609226226807, 75.67369937896729, 81.92498468583631, 53.07268865646855, 26.509028942354266, 19.67153168493702, 61.02780057537941, 70.20318538911881, 38.24922807755009, 3.6495271613520965, 0.05343488935801772, 0.23399153604142128, 1.9081459386694817, 1.1809868029048367, 0.5632182198666758, 6.045822731910214, 6.795500930278533, 1.0675565153360367, 45.6111874118928, 98.95924214393862, 80.10069816343247, 84.77067993533227, 77.01504799627489, 80.89247565115653, 73.65156850507184, 79.87130226627474, 78.57530409289946, 80.58332227891492, 79.15928225363456, 82.70335551231139, 77.10346606469925, 78.5589478092809, 77.74486772475704, 70.30937179442375, 58.297521068203835, 56.228757135329715, 56.48889656989806, 55.277503921139626, 56.46725293128722, 66.27390400055917, 72.08723314346807, 70.20931997606831, 68.99847645913401, 62.19212085969987, 55.70155528283889, 55.34480002618606, 54.14715920725177, 52.60776619757376, 52.405815124511726, 51.499292619766734, 50.10738857330815, 52.53246061263546, 50.945571622540875, 55.264544410090295, 51.44219467716833, 53.59573279657672, 53.27556148652108, 54.340798777918664, 51.41873890353788, 52.346293157146825, 52.17494833853937, 55.466962245202836, 57.65471519962434, 54.71209818317045, 53.54946844039425, 53.015182787372225, 55.58786930576448, 56.86843687488187, 57.835179528882435, 69.92326151940131, 58.5601512078316, 50.1375319880824, 70.987408391891, 56.170996312172186, 52.61561486028856, 54.96844468578216, 62.87027905064245, 64.02662123403242, 64.292593233047, 64.8441255477167, 67.18802021395776, 64.77788456024663, 65.24495647799584, 64.95701528364613, 65.45288132083031, 64.7314162408152, 61.80972506923061, 59.23630506761613, 54.32044952146469, 49.88687292222054, 47.945715458162375, 47.59525952800628, 49.820537797866336, 51.24184785350677, 50.37869891812725, 50.409673875378026, 51.53608837435323, 53.74056631518949, 55.26422669810634, 58.1151936131139, 55.22579531515799, 52.01762599329795, 51.49095758315056, 53.7844301808265, 53.03779525141562, 52.1530968143094, 55.828145857780214, 69.49587222068541, 71.2574714229953, 72.82209703999182, 70.47138921676144, 69.63496731173608, 64.26712920588832, 64.70900774002075, 60.40724239041729, 63.642072062338556, 58.21549646316036, 64.02349118263491, 63.23893477839809, 78.74200482522288, 66.63729590754356, 90.83183227046844, 44.238750088599424, 0.20629754950923307, 1.2246957349200402, 1.651757638300619, 0.5238294108740745, 0.15029538843420245, 0.27868792474750553, 24.902734025832146, 54.279911825733805, 35.41277785455027, 63.20894825843073, 31.48252371818789, 16.74047781575111, 27.44265698617505, 50.55694318586781, 56.66832147106048, 60.20338896782168, 66.08672849593624, 4.334393585881879, 0.47218086618569594, 0.09868353935739688, 0.01923122390684101, 0.055941356676480467, 0.10086859065678813, 0.011711027135231323, 0.005322499754613326, 0.05595554079439852, 0.031335662089047894, 0.033229255237646645, 0.026803937920879935, 0.07820895091900903, 0.014407404777293485, 0.08947835709418982, 0.09884512262238611, 0.0324284520390774, 0.11395030805180151, 0.006146510150433789, 0.05479765252300328, 0.019047709459799434, 0.012471160641120327, 0.03396520526298592, 0.10428341225750985, 0.037436460730649775, 0.058351645486489426, 0.05525704863811693, 0.1300921023733193, 0.0765187464534275, 0.02153220920703344, 0.03882325607382002, 0.052444058049830704, 0.03813362372438273, 0.09306206277781919, 0.19462569436479002, 7.42350475442025, 90.46938957706575, 82.23045103011593, 93.0025189922702, 64.1880149995127, 41.62325089977634, 27.348510296114032, 46.27114972760601, 54.65934622672297, 48.438686786159394, 3.582664723357847, 0.026085523648127436, 1.120066878295714, 2.1335597720838364, 3.096221935364508, 4.32683615915237, 5.811523872037088, 0.5302988701770383, 0.9029514318512333, 51.69518363091254, 101.00038082368913, 85.67527263395249, 89.82867040941792, 81.29414204628237, 83.97334052670388, 77.70652263395249, 82.35115804979878, 80.33981369387719, 83.21152210235596, 83.01164596311509, 85.09662889665174, 79.80470042074882, 81.00435733795166, 80.9506836245137, 74.45448552408527, 61.274301928858605, 59.615272706554784, 60.5299537412582, 57.281529134319676, 59.20050167268323, 67.74823665618896, 74.36731476937571, 72.15001460044616, 72.3931074142456, 64.9209451675415, 57.63981803770989, 57.42279329607564, 56.146858046131754, 55.23047862514373, 53.94365879797167, 53.408918150009654, 53.396833327508745, 54.18072292881628, 53.83005126830071, 57.0538120115957, 54.43789705153435, 57.131110160581535, 56.59917008492255, 58.409108577236054, 53.765998963386785, 54.694612256942264, 54.87523740337741, 57.27257436321628, 60.89966850896036, 59.200729170153224, 56.475819387743556, 56.536063071220156, 56.90651916688489, 60.02625080846972, 60.380256483631754, 72.00525560686665, 62.95060526940131, 53.59639175476567, 74.2683219909668, 59.76371088335591, 55.61901292493267, 58.64432527172951, 65.40697782270371, 67.61739423198085, 67.64577650254773, 68.75683492229831, 70.16048646742298, 66.78767173520981, 67.6960220644551, 67.87470171528479, 68.13055792162496, 68.39149751970845, 64.06791202483639, 62.76666964254072, 57.06839538389637, 53.170183089471635, 51.200564907443145, 49.23951318187099, 53.07772105739963, 54.300076730789684, 53.0480993178583, 53.80927839586812, 53.59500323572467, 54.80527800898398, 57.52792458380423, 59.44056249433949, 57.478047724693056, 53.96400805442564, 53.2840455732038, 55.05776489934614, 54.85125603214387, 55.069339813724646, 59.575601854631984, 73.11159149292978, 73.45348096662953, 75.6074897704586, 71.46132484559091, 75.68207756165536, 67.83847470437327, 66.25041684796734, 61.4312320370828, 64.8613251409223, 60.39094886472149, 65.4410671418713, 65.55891867606871, 80.06447115252095, 70.18693893186509, 93.11211785962506, 56.42481680839293, 0.612983720437173, 0.7377812819134805, 1.3186264494734428, 1.4964119224779069, 0.35322687017821497, 0.5784237168488965, 23.213828109925796, 65.06953239440918, 36.29468356409381, 41.783903337294056, 36.36671396993822, 29.48055578816322, 41.40793631153722, 58.49661273341025, 64.9944817635321, 66.31238245194959, 82.07331303627261, 10.92073755879556, 0.7252605247401422, 0.18192577986947953, 0.014828881455375063, 0.07461359303805136, 0.12302429009709628, 0.06082579155542678, 0.04217621990509572, 0.07695258970582679, 0.03506814970845177, 0.02288780178904774, 0.04545593040905172, 0.006238928603594222, 0.032327209689444115, 0.022957473655321428, 0.01553783262704289, 0.03909039859389586, 0.053307940928085204, 0.04468133124793249, 0.19524146051656818, 0.314311626096887, 0.2199665039417244, 0.09243888855581323, 0.16497902632240327, 0.1703650840828496, 0.12182058976782907, 0.2396357807541086, 0.2732751764837773, 0.1765654320197721, 0.27909778178699557, 0.10284099893103685, 0.2634640416551021, 0.14272648570758684, 0.3371363884258655, 0.3712720099476076, 10.868365091662254, 107.07876020862211, 92.61041533562445, 104.67868543440296, 73.03787446791127, 42.170503908588046, 27.172609644551432, 86.81701183319093, 96.56050882031842, 59.39170937384329, 5.874153827467273, 0.1391081911541762, 1.1842373446110757, 4.361331443632803, 4.825916578692775, 6.914655671965692, 17.24449649933846, 20.455331071730583, 4.123366148241105, 56.735664644548976, 105.0084783184913, 90.4126956385951, 93.296994855327, 85.38168322655463, 86.80322077966507, 81.36800027662709, 86.35250122316423, 86.93004669681673, 87.38267252522131, 88.43795484112155, 88.25131277884208, 83.61375331878662, 85.62377975833031, 83.01699607603013, 78.05253059633317, 65.02798272717384, 62.70450399767969, 63.677836233569735, 59.63663785688339, 61.89763322953255, 72.48908781236219, 79.29611021472563, 75.92156179489629, 76.51971540143414, 68.48753283100744, 60.634465294499556, 60.56211325430102, 59.52203796755884, 58.005088760006814, 58.103924643608835, 56.086920307528594, 54.806305669969134, 57.071266558862504, 56.421965245277654, 61.82521450904108, 55.378532409667976, 58.657021983977295, 60.02585072671214, 62.04609101818454, 58.04144520913401, 57.541303788461995, 58.484806399191584, 60.93086311894079, 64.64204503643897, 62.355773910399414, 60.25844727793048, 58.92796754837037, 62.270713390842566, 63.50003127128848, 63.915755441111905, 75.94609229795395, 64.26126918485089, 56.463252113711455, 77.49611885316911, 63.50602073054161, 60.46201436750351, 59.964143999161266, 69.2136812210083, 70.71336023269161, 70.32073882318312, 71.04798547683224, 72.61854956226965, 70.41386373581426, 71.14613886802428, 72.8596027435795, 69.94325776253977, 72.58884153058453, 67.36185181525447, 64.65574979782104, 58.88256219125564, 58.16223067622031, 52.89082011868877, 53.16445250664988, 56.4767764460656, 56.225089719218595, 57.53867187807637, 56.45669783315351, 56.8657696631647, 57.193797480675485, 62.16655092854654, 65.20373628985497, 61.847709301979314, 57.661591114536414, 56.83869746423537, 59.3380670393667, 58.1555587245572, 58.68594554162795, 61.58749926474787, 77.51783309444305, 77.51281246062248, 78.11678686449605, 73.61290962465348, 77.39132881164551, 71.55457527406755, 72.9162888373098, 66.34250625487297, 70.72518225639098, 64.1087438983302, 70.43932776297294, 69.70725659401187, 86.28305958163354, 72.41191910159203, 97.51065592611991, 51.8037901386138, 0.7183858355687511, 5.297813992346487, 4.552003741264343, 2.1987390229778905, 0.584435545869412, 0.5767921947183148, 34.40826277579031, 70.20740585942423, 53.60000425769437, 84.68572924214025, 46.9307747194844, 24.753164245236306, 42.05031856413811, 70.07693998275265, 77.41709878367763, 75.98114259781377, 90.43522573286488, 9.59812218143094, 0.9997751395548544, 0.2539399906151718, 0.20674503678756379, 0.1335694367486623, 0.2729612642959241, 0.14248449385406511, 0.07067365646963158, 0.1574154096024652, 0.11770642182279019, 0.08390735804794297, 0.08634963868966988, 0.18241200055326187, 0.16974109014676464, 0.20499945948681525, 0.14736392234842624, 0.20447818261961784, 0.1671240725103886, 0.16029343339464358], [0.045189519502943566, 0.020993890713960416, 0.03384199917256352, 0.03737593212375238, 0.07391508939045091, 0.0834346434942657, 0.05594641668722034, 0.0845090894689483, 0.04109651856725255, 0.06892243310088111, 0.0911339573682316, 0.04575381220708932, 0.08035225808740624, 0.1848650600520834, 0.23939211882891195, 0.3597054612492362, 35.42683170687768, 90.9002148720526, 80.65994185786094, 69.99021637824275, 48.17362869939497, 36.70017819250784, 57.07444367870208, 60.435769788680545, 40.172860391678356, 19.274385821434763, 0.17399856249891943, 0.08729937321115887, 0.551234520971775, 0.7302248357765136, 1.0280364908037647, 2.0017301363329736, 3.136819447240522, 0.8132243949559428, 12.942825286619126, 93.84298093857305, 83.28763961791992, 88.3906824358048, 74.93718808697116, 76.87349750149635, 77.08531333554176, 78.04541541684058, 71.17453682807185, 74.57643985748291, 70.67928268063453, 75.13995109065887, 73.0840721438008, 76.4390322469896, 73.29995939808508, 71.24743800009452, 65.70450921212473, 59.662564723722404, 54.97229645329138, 57.670910666065836, 54.906549684463016, 56.86653060297812, 57.26629072620023, 67.22457670396375, 68.79947108607139, 67.4350824663716, 60.91368705995622, 58.043594667988444, 51.79187005566013, 53.69193284742294, 52.57442997347925, 52.26451566142421, 51.38794437531502, 52.046149469191036, 51.47231063535137, 54.93093113745413, 55.10321340253277, 57.76356097190612, 55.44291811604654, 55.95166521687662, 54.64896371287685, 53.772412038618526, 50.800039922037435, 51.83039165312245, 54.04251429342455, 56.7830821775621, 56.25328763838738, 58.85156762215399, 56.353896433307284, 51.2554310214135, 52.33321205262215, 56.84518898687055, 68.67977603789299, 57.5054572474572, 48.886044871422556, 72.81294222800963, 51.60266668565812, 59.72085506685319, 62.504031658172615, 66.52903849078764, 65.72851411757931, 62.2946673054849, 60.87964873160086, 63.081981135952866, 62.45290356297647, 62.663487772787775, 62.16838659778718, 64.55875742820002, 62.82787038433937, 62.971680164337165, 59.54699600896528, 53.98112527785763, 47.23894749918292, 48.73826173044021, 46.89574010910527, 47.87485391862931, 47.2285649853368, 50.44436331718199, 49.36061636094124, 52.25814965463454, 49.320678787846724, 52.67630569396481, 52.21822384865054, 53.08192583822435, 51.324327453490234, 51.47898258701448, 50.76073777291083, 54.329510196562744, 52.05286456692604, 53.99257075402045, 63.510374561432876, 72.61291703870221, 69.47560925637522, 71.19434479744204, 60.61648514962966, 58.15715512921734, 51.58780482507522, 53.86174794166319, 53.156580309714045, 58.043735873314645, 54.04087866506269, 59.6708252353053, 56.81845018940588, 79.956190201544, 68.70948406957811, 89.00764772968908, 18.170852468859767, 1.0759474457271638, 0.29360592425350224, 1.4595649319310344, 0.04400045911390935, 0.017601189902052283, 1.9823410025527402, 61.755321794940585, 36.286834901379, 38.71114600089289, 40.57994358001217, 18.990910245526223, 15.468585548862336, 27.718583960686964, 64.8823098213442, 60.40592055166922, 63.46886019552908, 40.61231882341447, 0.5876865165848887, 0.1054145640603477, 0.04587038397608746, 0.07255463215011744, 0.0234166054701012, 0.023724871589952422, 0.05863191109270819, 0.012112783752532016, 0.041349557408642386, 0.06055793274314173, 0.09140100029687728, 0.030818299931143562, 0.08563033575492521, 0.0478675292294112, 0.07160366422707035, 0.11211177364232079, 0.05543545136348375, 0.04486420026589786, 0.0677635106107881, 0.046058155956768224, 0.04445526636235657, 0.11401825238980594, 0.077348695467076, 0.06149101251315686, 0.08206366786673185, 0.07955362674810233, 0.07349020170588648, 0.042048781178891666, 0.07124308196287002, 0.08563447262971632, 0.040019598128574516, 0.043294669970149, 0.16605024706692467, 0.394749540475107, 47.736578602944654, 105.17490448490267, 89.9842708341537, 82.31715110040481, 53.797393614246005, 43.63590140496531, 42.52607853181901, 45.4271262691867, 45.11937710546678, 23.68975477833902, 0.0529091002329463, 0.15678919401139985, 1.483478642279102, 1.9747432489548962, 2.200970606457803, 4.422714575644463, 2.8136136935603235, 1.4502700177892562, 19.527170811930013, 98.42459955523091, 88.66140442509806, 89.32859174666866, 79.73751806443738, 81.23511821992936, 78.46870191635625, 80.69336045172908, 76.27305323077788, 76.68488640939036, 75.80579696163055, 79.48719240004017, 76.6562609518728, 81.48227460922735, 77.32403662896927, 73.9297273082118, 69.03675879201582, 62.614336552158484, 58.20768702414728, 61.79617328028526, 58.9610605855142, 60.33245063597157, 61.04149356965096, 70.96804757272044, 69.03238142690351, 69.32171114029424, 64.94184747818979, 60.83320002402029, 54.0374073674602, 57.28062306680987, 54.811420440673835, 54.65680453085131, 53.6446878986974, 54.94039581667993, 54.03312413923202, 56.442322346471975, 57.615307146503085, 59.631256365006976, 59.24792312806653, 59.07934750280073, 57.07992715220298, 56.132113856654016, 54.62220530356131, 54.56290691129623, 57.325706789570475, 61.40220257543749, 58.86060084066084, 60.316733698691095, 60.473569670031154, 56.152973021230395, 53.83380105418544, 59.226491297444994, 72.14128340444258, 62.451726851924775, 50.09624904201877, 76.37617234260806, 55.69908026726016, 62.127539034812685, 66.06072318169379, 71.15374042141822, 67.98109208383869, 68.44007215192242, 63.34741969262401, 65.59313351108183, 64.2126553289352, 66.2054664857926, 65.07061889094692, 66.8923048819265, 64.17487505943545, 65.75223661238148, 61.118607367238695, 56.06016582058322, 50.101748205000355, 53.24986211715206, 50.23446159978067, 50.4159535900239, 50.54605468626946, 53.114038282825106, 51.57498651935209, 53.26614779810752, 51.82414723980812, 55.02430315940611, 55.33051867638865, 55.412001994348344, 54.00272577039657, 55.09967934700751, 52.94630596714636, 55.40448673309819, 54.34792180215159, 56.28117961268271, 65.66929809508785, 76.4551139646961, 72.57940430794993, 72.56547989383822, 64.13413732282578, 61.180792623950595, 54.49834862063008, 58.569094211824485, 55.88548306495913, 61.38491669008809, 58.081496530963534, 63.426765318839784, 58.87146188366798, 80.77420834572085, 71.83845289291875, 91.5947489584646, 24.54623176205543, 0.8848466291542977, 0.5057246694641729, 1.6975144152679753, 0.33369122974334225, 0.06254914464549192, 1.307186734291815, 63.72119019108435, 48.83690149553361, 33.207746859519716, 27.835186219984486, 18.88374913123346, 22.795866227919056, 34.750183628451445, 72.62872419049664, 67.26775415482061, 68.36613547417426, 58.48305309972456, 2.3412382410418604, 0.271447413270512, 0.07381441011544197, 0.09894509709650472, 0.08047939803931983, 0.019940590681207758, 0.058497313274851734, 0.012899960162148122, 0.04402472877935056, 0.027149598707535097, 0.04283525087239762, 0.012753754197019003, 0.04604135181814913, 0.04389345578308548, 0.0614950995922329, 0.022337765981172843, 0.05415445276265664, 0.04763281904160977, 0.11583237157713984, 0.19459836034765168, 0.13040275102661503, 0.21958454782443665, 0.17184815369546416, 0.17534335324120137, 0.14687183343114393, 0.20373847876344958, 0.14378010175160824, 0.18424451351165774, 0.22885130057411812, 0.11974770140143172, 0.18120220982499663, 0.25195190052111305, 0.2783155447292713, 0.6063907677608152, 53.574414714690185, 116.00365854078724, 103.44020489723452, 92.73012607328354, 67.3949723089895, 50.536397810905214, 81.55406182812106, 86.96549707843413, 57.790362527293546, 32.56060284952964, 0.2927676095597206, 0.28453403362824076, 2.1597768943155966, 4.397622683355886, 6.309336385419292, 6.26559901622034, 14.73755478858948, 7.3810602964893475, 21.01840299944724, 106.57737147423529, 90.63726702044087, 96.73799607061572, 83.81151922287481, 87.46599935716199, 83.27027136279692, 84.99551803834977, 79.60166285114904, 82.05338739579724, 80.04535352030109, 82.06166359686083, 80.95635537178286, 86.75708586169829, 80.67241499500891, 77.74542470132151, 71.87509567506852, 65.86404769651352, 62.362014401343565, 64.52462104059035, 62.07523422856485, 63.885619871078006, 63.06623281971101, 77.08208914726012, 73.46492644279235, 74.0670181089832, 67.15365240650793, 64.09169335519114, 56.68851775507773, 59.434722085152906, 57.6692436587426, 57.63535045808362, 57.33808971220448, 59.56459176155829, 56.65316935508483, 59.588667269675966, 59.58357995556247, 64.47450883926885, 62.5852325654799, 61.67712150081512, 59.685777310402166, 62.2767303066869, 58.02594792458319, 57.33835251100602, 61.13810546936528, 63.92911895628899, 63.31923746293592, 64.34341930573987, 63.36596073642854, 57.66132831573487, 57.73451582078011, 63.31174181353662, 75.0764871412708, 65.77195828960788, 55.70066490480977, 80.59556007385254, 58.95727549829791, 65.40895469727056, 69.46522282015893, 72.64767708316927, 72.93199400747977, 70.18544058645926, 62.5060595235517, 67.3159130157963, 65.46098493760633, 67.29329662938272, 67.18639635270642, 68.43138802436091, 67.08143372689524, 69.2988907906317, 65.09328234580256, 58.03098424788445, 53.48243513414937, 56.30997765448786, 53.94341168865081, 53.444003751201016, 53.182679760840635, 54.06657018969136, 54.107762921241026, 56.574000235526796, 54.83432708248016, 57.18066538533857, 57.17233427109257, 59.10184229573896, 56.965707732785134, 57.98903057652136, 55.2493844493743, 59.957730923929525, 58.4413779166437, 58.90946180589738, 69.19984309904038, 80.03714007716026, 77.88622210102697, 77.29159078290387, 68.0939700526576, 63.40999326398296, 59.15397451769922, 59.87907955723425, 59.991424083709724, 65.09165456218105, 61.423787378495746, 66.26623184450212, 63.16230343234155, 86.46119794537945, 74.25213044689548, 95.84487238237935, 21.87586645926199, 2.3568362814764825, 3.7179288844908442, 3.193815653362582, 0.40103339199577615, 0.13790020839341227, 3.7667430264334527, 77.53168690589168, 56.48166764167048, 54.67299607492263, 54.81278934786397, 26.689812944781398, 24.131913761938772, 40.9871522841915, 83.4949133473058, 78.67099423562327, 82.92108628057665, 64.24797234996673, 1.5369371156538687, 0.2599685050306782, 0.1947231407487585, 0.26034768790968005, 0.20402565448274537, 0.10683237064269283, 0.1719256051846089, 0.21031983286863376, 0.1190755818219435, 0.19423733375245528, 0.22170239789111001, 0.187216904014349, 0.14642358006488893, 0.09214189158932817, 0.25846611468061326, 0.15912654359013806, 0.15757768234658628, 0.12460986227397958], [0.10957632904812213, 0.05851359264324269, 0.08847639835890263, 0.02458146897204701, 0.07204663924752705, 0.04767452869864722, 0.03657892106040832, 0.039517653490146326, 0.06336700096125565, 0.026951168528607777, 0.013795205722412756, 0.045502228932755615, 0.0576695591031063, 0.11243567561670659, 0.11731190952442347, 0.5394648363994015, 63.65481192065824, 69.64432608696723, 77.58129704383113, 61.167401652182306, 48.855646502587106, 26.16364855920115, 57.77920730652348, 49.75225717790666, 41.071420484973544, 7.077386475378468, 0.05455927660448417, 0.3538179836205898, 1.9021244875846373, 1.8375942663800333, 2.1265992810649257, 5.26885905573445, 2.4866348649224927, 2.998009708619887, 58.46886196444112, 93.77366481288787, 81.80831770743094, 81.55219477991905, 72.24857591813611, 73.36372144760625, 73.51294409844184, 73.81195422141784, 74.35822271531629, 71.01232328722554, 70.2888656431629, 68.60874975881269, 68.48228469971689, 70.13181394146335, 67.59915521067958, 64.56332306708059, 60.33143474209694, 57.02019337684878, 56.0919919321614, 53.68220144702543, 54.09363846625052, 55.404651472645426, 56.34188613583965, 59.272841945771255, 64.31244042611891, 63.476787305647335, 60.396926556864095, 56.298163475528845, 54.90070143053609, 51.70489541945919, 52.175301351854884, 50.94768578006376, 50.684027979450846, 51.151288170968336, 57.80615006723712, 56.99204252612207, 57.98617901340608, 58.77269660272906, 58.68832642032255, 56.44263221371559, 51.738867067521625, 50.592126846313484, 51.7954590243678, 49.25142542008431, 54.80977304520146, 58.23012298153293, 60.34792830867153, 59.83671403700306, 58.83725097102504, 55.42194912510534, 53.77196488841888, 54.099255300337276, 68.62646318251088, 59.17626142501832, 49.12099092237411, 69.44596398261287, 51.11738712556901, 61.258734041644686, 67.71466901225429, 63.989131219925426, 57.41068886172388, 60.977213767267045, 64.46326340398481, 67.09629166510798, 63.570351523737756, 65.4889710487858, 64.0217771068696, 65.67579746246338, 60.39033697497461, 57.87616045244279, 54.018003402217744, 52.80107236677601, 47.61934680323447, 47.2655019452495, 46.50165173315233, 47.46069869687481, 45.6539334020307, 49.66546297073365, 50.204204436271425, 49.070992469787605, 50.444814389751805, 51.443261561855195, 52.54395707961052, 51.96575264776907, 50.85414117382419, 52.472491495070926, 50.174661144133545, 50.92044099684685, 52.15074339220601, 52.23371721083119, 53.57827432693974, 58.57002381355532, 59.731665119048095, 58.556546549643244, 51.63889369656963, 51.840397619432025, 53.49409634067167, 64.2538715947059, 65.68940808696132, 66.06931317237117, 68.96931755927302, 68.60775347678893, 63.21802462300947, 64.36742813356462, 69.86742265762823, 83.90626799675726, 51.62506341934205, 0.329774467334632, 0.8350574105016647, 1.0417182695481086, 0.17704785290744998, 0.09279167204494439, 0.16531858713396136, 22.530508079836448, 64.59653377532959, 31.342806931464906, 75.19699804244503, 52.80337479806716, 29.39153171354725, 41.15423348642165, 46.66936443698022, 51.65216307486258, 55.813307531418346, 64.14282145038729, 23.74716062699595, 0.2846208467118202, 0.07124227757054953, 0.14442851857071923, 0.03957416013544125, 0.06551116614812805, 0.0697842743548174, 0.10819997548335984, 0.031703001248740384, 0.023881754905526197, 0.050173427068418076, 0.06270610840029775, 0.028272001786277662, 0.07593849613781899, 0.05789578103670671, 0.05649273313822285, 0.02240888575362342, 0.043784893463335695, 0.04844138271085197, 0.03150210618191669, 0.04617816363010676, 0.06543201394379139, 0.07446637392164239, 0.06348069223965849, 0.09079810442222704, 0.05587710105183144, 0.039947130041377205, 0.044780512821049466, 0.0675336382682285, 0.029165040055710464, 0.05506932262271162, 0.05544117787071774, 0.013916092481644405, 1.5203013631605333, 80.39657823501095, 78.73482688780754, 86.60949491685437, 72.269788096028, 68.85130913026872, 40.458503077107096, 47.6906947166689, 45.23638140770697, 52.188613876219726, 8.260376261126611, 0.11301390346019499, 1.5337262879456244, 2.5674204912877854, 2.594764804647815, 5.352429564922087, 3.1458426146737994, 2.469104076585462, 4.492043449032692, 64.05765502683579, 95.44457881681382, 86.08981224798387, 84.46093820756482, 75.38370286264728, 76.61455046746039, 78.978374696547, 77.22551453498103, 79.07761066190659, 75.37209264693722, 74.16058232707363, 72.26230421373921, 71.16559382407897, 71.05944664247575, 70.23164610708915, 67.60116346420781, 62.727791109392726, 61.5927238618174, 57.99579274269843, 57.94127179730324, 56.84747180631084, 57.95631800928424, 59.900911469613355, 62.630594776522734, 68.65451597398328, 66.90222847846248, 62.77693840765185, 57.54945447368007, 56.36307085714033, 55.30354453671364, 54.97657575914937, 53.745355529169885, 53.13685078774729, 52.731234565857925, 59.4211075382848, 60.86022515450755, 61.54587115010908, 63.533108618951616, 61.77666733341833, 57.23898318506057, 53.253760953103345, 53.55076674492129, 52.924081817750015, 50.16406682229812, 56.735774470913796, 61.100278131423465, 63.72812101917883, 63.039431264323575, 61.53525329405262, 58.04318674149052, 56.01003400741085, 58.210464062229285, 71.61401487165882, 61.26973236760786, 55.38995042923958, 71.50480039658086, 53.57977267234556, 64.65844446612944, 70.13233953906645, 65.78987175418486, 59.82753961317001, 61.06912666751493, 67.35489353056877, 71.51127230736518, 66.66616455201181, 67.80805280131679, 66.78005449233517, 67.56508550336285, 62.78848194306897, 59.78315014992992, 55.272922592778365, 54.40418035753312, 52.14811540419056, 48.42295023702806, 48.882283318427305, 49.886841543259166, 49.627945500035445, 50.63895602380076, 53.08354185473535, 51.719949476180545, 53.10488347084292, 53.885466514095185, 54.25449878938737, 56.54709277614471, 53.1907323868044, 55.142437104255926, 53.427780828168316, 54.06345582777455, 54.39983829375237, 56.120578165977236, 57.12890578854469, 61.419672812184984, 62.58110623205862, 60.385622286027484, 54.44185472303822, 53.492335196464296, 57.866668316625784, 66.89573303345712, 68.68361211592152, 70.74955586464175, 73.44283565398186, 72.42807926670199, 68.85440780270484, 67.87965959118259, 71.85844913605722, 85.25280983217301, 58.76275339434224, 0.6112997366055366, 0.5878321345775359, 3.5974704450176613, 1.2309337743828375, 0.14358934585846242, 0.29633056192148116, 22.30003353088133, 73.4961171304026, 37.92422832981233, 46.79565298941828, 31.179506894080873, 32.53752362343573, 57.700312752877515, 54.29707219523769, 57.25135826295423, 64.00009816692722, 73.52558981987738, 41.92203352528234, 0.5001279068810325, 0.007278698087189227, 0.04273217374218568, 0.08348223287612201, 0.04907199181616307, 0.027012434495132298, 0.024177455268199408, 0.026795171959806355, 0.025268320422319156, 0.031205314143951383, 0.02969442213314676, 0.02765403887737663, 0.03163735517450879, 0.042034501299983075, 0.03471811647496877, 0.0892645189718854, 0.06816917714933235, 0.2112632241821097, 0.20892166111978794, 0.1703522904145141, 0.21879631995914445, 0.2163063350223726, 0.2005808482006673, 0.2213733018405976, 0.13828179678849636, 0.15081344773211788, 0.10673068779250307, 0.178081136977961, 0.2070318447846559, 0.22302671876405517, 0.35241910707085367, 0.21756106446827614, 2.135445696692313, 95.67272740025675, 90.54003930860951, 97.10457294218003, 79.08056812901651, 68.94880356327181, 38.847930815912065, 82.24869789615755, 70.64343221725957, 64.35926568123602, 12.029415099851548, 0.3138661612906764, 1.3828193468432273, 4.773443600823803, 5.2795396697136665, 7.052783898768887, 14.503667777584447, 10.86806404975153, 5.961981579180687, 69.71747044594058, 97.75640026215585, 90.74993318127048, 88.00578025079544, 78.99792378948581, 79.45373458247032, 83.41612862002465, 81.81754312207623, 82.65645180979084, 79.05239766643894, 76.68254867676767, 74.3852243115825, 75.53876200029927, 73.90464767333, 74.08963449539678, 70.7512503285562, 66.4885360963883, 63.553304902968875, 61.4389394944714, 59.517142849583784, 60.17581078314013, 62.319692027184274, 63.588410116011104, 64.74293231964111, 71.93936763271209, 70.99641415380663, 67.11710376124229, 60.12709886797013, 59.572358054499475, 58.601559669740745, 57.23763388972129, 57.86166729465608, 56.754743053067116, 54.45534767643098, 62.232544806695756, 63.35305613856163, 63.624723419066406, 67.42002840965026, 64.1073122332173, 62.01786564242456, 57.184089614499, 55.69851152358517, 55.4044004409544, 54.15518045425416, 61.07443363435807, 64.90793074330976, 66.6122398068828, 65.8213487748177, 66.346922843687, 61.71395255673317, 59.2297782436494, 60.65125696120724, 76.19101293625371, 66.27210755502024, 59.4459165296247, 74.7935587360013, 57.09897418175974, 65.15097256629699, 73.43958008673884, 68.46321413593908, 62.35599356312906, 62.40256386418497, 68.72079618515508, 75.14475207174979, 72.0285701751709, 73.04506025006695, 72.24732075968097, 72.18270363346224, 66.76667921004757, 62.77334943894417, 58.77170424307547, 57.27985035988593, 53.71619662930889, 52.62034916108655, 53.89253070277553, 52.61992162273776, 52.38593263010825, 54.785501418575166, 56.1474895477295, 54.43096622343987, 55.88611456655688, 56.452434216776204, 59.569894806031265, 59.105760743541104, 56.207458665294034, 56.95243050975185, 55.42906822696809, 56.60177453871697, 58.30335755502024, 60.83553383427282, 60.815062984343506, 64.35627683516472, 66.86392261135963, 64.67433791006765, 58.112604848800174, 56.81251956570534, 61.587432584454945, 70.21538396035471, 73.93504604216545, 73.88407876414638, 75.74014432968633, 76.37010835832166, 71.06968402862549, 71.27202341633459, 76.852889368611, 89.49137795356013, 61.43011416158369, 0.5111110949468228, 3.8506234028647026, 6.2885473332097455, 1.2084639865544535, 0.43345968749734665, 0.40643176845004486, 31.07700359436774, 79.9016143429664, 48.397784310002486, 106.15376334036551, 72.57443074257144, 40.063026182113155, 58.07593461005919, 63.86338003220097, 70.39922545033117, 71.13973755990305, 89.5278795303837, 41.77870227444557, 0.5002470488750166, 0.2586859512713648, 0.25533898973897584, 0.27976185744327886, 0.29905614953848625, 0.11338630646106698, 0.21784851597922467, 0.07932445154555383, 0.1499037183220348, 0.09652193800936784, 0.18956644971284176, 0.124542607415107, 0.1746827862676113, 0.1554587904003359, 0.10406634124416499, 0.17114195852510392, 0.14661713983983765], [0.03485054626399952, 0.08666541247117905, 0.026746218941444834, 0.10362484477340214, 0.06065201983156224, 0.012279350419468697, 0.0583620029952257, 0.022261310406329653, 0.014111496613270814, 0.08598726377972672, 0.045380420952795014, 0.1438393356699136, 0.20057360100890362, 0.2024978606571113, 0.3495970536624232, 9.965400176663554, 79.171402377467, 73.87935623045891, 68.81811018913024, 43.64828432759931, 14.35507074479134, 31.327633242453302, 54.192996025085456, 42.33438445675758, 29.53466292350523, 1.4099067449569704, 0.029026860776807994, 0.5829653312121669, 1.5373227336714346, 0.6341566746273349, 0.0876400908154826, 2.088897458968624, 1.4392446029570796, 14.8872334149576, 95.94684616211923, 80.86609378937753, 86.38452345325102, 74.26124603517594, 71.78708553314209, 68.21797970802554, 72.52294571168962, 67.82572700131324, 72.31927271812194, 71.80869779279156, 72.59422302246094, 66.8904927469069, 65.59849146873721, 61.321170330047615, 62.47153874366515, 58.58578781927786, 58.76355355785739, 54.69073695521201, 57.611722100165586, 55.33468423351165, 53.80920387083485, 53.7167339940225, 55.90673446655274, 55.25248312181043, 60.53821033047092, 60.933459727994865, 56.69747252618113, 53.124240367643296, 52.59527344857493, 51.15617544420304, 51.487851065974084, 49.20467469000047, 52.14606792696061, 56.2674670065603, 61.23957718572309, 60.00783135814052, 60.287923889775435, 58.937012533987726, 57.39481895200668, 52.24847708978961, 49.71353161719538, 48.651098820471, 50.71899983190721, 48.615216978134654, 54.48827989639775, 55.58886166541807, 60.40382992836737, 59.60476075449298, 64.29478583797332, 57.464770501659764, 53.09153564514653, 52.82448107196439, 70.8316275381273, 57.42202843389204, 54.02355747838175, 65.70458765952819, 52.945050808691214, 63.02494987364739, 66.98125639269429, 58.26751101401545, 59.90475539238223, 64.69695429648122, 62.92867529776789, 61.29279590422108, 58.95529077899072, 56.974529143302675, 53.34210841886459, 52.40435208043745, 53.459065652662716, 49.28136094923943, 46.868114855981645, 47.81719899946644, 50.056338925515455, 47.24971440530593, 49.150279260450795, 46.25344414864817, 46.15971519101051, 46.23205154172836, 48.924837112426765, 49.274857659493726, 51.50510164999193, 49.93332947454145, 50.31310904410578, 52.298636359553186, 52.42077112197877, 49.855933266301314, 50.83172875065958, 51.2667509817308, 52.60224350037114, 50.5312006704269, 52.812831632552616, 51.5766417595648, 52.693101283042665, 49.540978708574855, 50.184094444397964, 54.105013339750236, 63.93883466720582, 66.9420091567501, 71.7660302500571, 69.36328826412078, 70.48972237494685, 69.56094434184413, 73.433210157579, 71.6993264229067, 70.20667629857218, 75.1109020171627, 73.54407987286969, 3.6492557823657994, 0.5686929293217198, 0.6881793564365757, 0.540285163348721, 0.07305874864781096, 0.008603946884132681, 1.4204033752602916, 59.800565473495, 45.43464545280703, 35.727399010812086, 57.5395465666248, 23.396991029862438, 12.588886291750017, 26.83434836326107, 48.83133565225909, 56.069002920581454, 55.62403355875323, 56.63722492033436, 6.265916728204297, 0.5015531062118469, 0.10008836074942544, 0.09804622315230871, 0.08081523566356591, 0.08476896947550197, 0.06654025971769326, 0.012416133503129166, 0.040655301718582074, 0.0639547206341259, 0.07637131283239973, 0.034171202475385326, 0.017706270352186217, 0.02162961345616608, 0.07087133013673368, 0.0662299634648427, 0.051878118256647746, 0.06314783852787749, 0.05808130071889009, 0.02949036120797598, 0.07794645855263357, 0.019351084108254122, 0.03786190382895931, 0.07869222982516212, 0.0494583644303343, 0.029637388802403887, 0.08027968657833916, 0.01995463498807963, 0.09764735947453207, 0.04617187787868804, 0.26508566592970206, 0.5175526992928597, 17.13066343338259, 96.80783779390397, 78.93172202571746, 81.203629432186, 56.15098437955303, 29.349015182064427, 26.34465809791319, 38.77702613030711, 46.71883336959347, 43.439029801276426, 1.3459676984817752, 0.04300734869414761, 0.6672824390472905, 2.2875468769381126, 3.9469117070398028, 5.2250888366853045, 2.1450373626524404, 1.5536382001253868, 19.41315535576113, 99.77198077786355, 82.44213350357549, 88.84060967353084, 78.31773773316415, 75.60538738004624, 72.3516087378225, 77.07484845192202, 72.40310161344468, 76.77363395690918, 74.95454849735384, 74.40473418081962, 70.9603048140003, 69.80861848400485, 64.06545662110852, 66.38227908842026, 64.71380087637132, 63.2391308969067, 58.39157166019563, 59.64902470188757, 56.69268723457091, 57.073596446744865, 56.6328985460343, 58.295822681919226, 58.381291127973995, 63.39136200566446, 63.355970459599654, 60.58550627000871, 57.78986830865183, 56.174338171559, 54.32260290268929, 52.42865900839529, 51.47838638674829, 54.24237474318474, 59.40221740353493, 64.84064640537386, 64.52570753712808, 63.08022391411566, 61.31951901220507, 59.2428828823951, 54.716361799547755, 52.57981538772584, 51.727170559667776, 53.820727794401115, 50.96890972506616, 56.370994044888405, 58.13666466743716, 61.507098520955736, 61.2024401849316, 66.5995313275245, 61.31732640727874, 55.70075119695356, 55.63276867712698, 72.54902162859517, 59.08123808522379, 58.80246346996677, 68.99028655021422, 56.60612052486789, 66.20051645463514, 69.01293431558918, 59.28725665615451, 61.28889314589962, 68.95580107165922, 67.496687212298, 62.13483464333319, 63.23515753592215, 59.138936150458555, 57.276253546437914, 54.00576168490995, 54.38399976299655, 52.07652822617562, 50.110000871842914, 49.850312509844386, 53.59628192840084, 48.60943932687083, 50.59580210716494, 50.51570338587607, 49.2929397859881, 50.57097350397418, 51.33913440089072, 51.630668486318285, 54.33476225022347, 53.50867971297234, 54.36378386712844, 53.17266594979071, 53.76629706351988, 52.74967362803798, 55.06967321518929, 53.80804284926384, 54.154988258115715, 53.47082491843931, 54.71894664149131, 54.48602845591884, 55.71897845114432, 52.43167923342798, 52.93851221761396, 58.24849536342006, 67.50683830630395, 69.87627152473696, 74.74654520711591, 72.78051207142492, 74.95574089788622, 72.89850481094854, 76.84036916302097, 75.64301859947943, 75.68935748069518, 76.26728734662457, 79.08011313407653, 4.416291694487295, 0.7361116392477867, 2.552630704256796, 2.3886746504614433, 0.30711484291861135, 0.030153090464732343, 0.9042204411760454, 62.37299703782605, 58.515718598519605, 42.39922908044631, 40.93420420923541, 23.027582207033714, 23.81158163470607, 39.76197250427739, 58.79106113987585, 62.467588916901626, 62.96065045941261, 72.4418467860068, 14.783902495138108, 0.7566399764149421, 0.16363903129052731, 0.02683276006381118, 0.05081840798318867, 0.012051964989833295, 0.02970556679722523, 0.11782190957737547, 0.08884096428030923, 0.02031607718597497, 0.08814716441256386, 0.01432678359936202, 0.023531007295053814, 0.026939410994189884, 0.03563323148315953, 0.059361506418715564, 0.019606800426939325, 0.27049960929059214, 0.2228031130207162, 0.18390507527416755, 0.12837159913033247, 0.18395571368596247, 0.23577190905569062, 0.15910362223944358, 0.12200936915413027, 0.26085722830987745, 0.18230130084820334, 0.12422651187666964, 0.2684923976419434, 0.3319594113817138, 0.4169994610692225, 0.818425273943332, 21.817081897489487, 112.93773789559643, 93.45657256341751, 89.49350387819352, 62.58823710103189, 23.18811893463135, 44.26037019298923, 81.2023978079519, 61.56761284797423, 50.44724233688847, 2.1383367286574457, 0.19653432581934238, 2.6316392517858938, 4.803446790864391, 4.269865203288294, 8.104524314403534, 12.438069197439379, 5.68198710680008, 20.28571797955421, 104.44975237692557, 87.55985383064517, 93.12741510329708, 80.39898657029676, 79.50612960323211, 74.99469003369732, 80.59253200407952, 74.75131480924546, 81.44265082574661, 80.21364673491448, 78.90591282998362, 73.52969261907762, 73.6585424792382, 67.43803993348153, 70.97816728776502, 66.78253343028408, 67.23069560143256, 60.715799562392704, 64.62891686347224, 61.48413304359683, 59.53832757088446, 60.526498133136386, 61.144192987872714, 60.9144126984381, 66.85525417327881, 68.73605420512538, 64.67031748064103, 58.863836796053, 58.465975099994296, 56.29230737686158, 55.956062193839784, 51.94017094950522, 57.630620079655806, 59.81552539333221, 67.59369527139972, 65.51927528073712, 66.95307024063604, 65.37197851365613, 63.04340070293796, 57.82536968108147, 55.16089577828684, 54.92331389457949, 57.497945908577215, 55.45063734054566, 60.49275398254395, 63.65306254356139, 67.06848206058626, 65.92573088984336, 70.16608761202905, 64.20328478659353, 58.57657417174309, 58.07555414015248, 76.37000637669718, 61.52670644944715, 63.252921950432565, 69.66046271785613, 59.285087585449226, 70.90372070189446, 72.38095591145178, 57.360812002612704, 63.2249907524355, 71.29206672791513, 72.625045007275, 65.78863620758057, 65.42320074573641, 62.39987311824676, 60.714195312992224, 57.23684549331666, 59.3667003416246, 54.18535917035995, 53.05361417032058, 52.83151388168336, 56.46352667962351, 52.02152090687906, 53.739311156734345, 51.97519379277384, 51.506192068899836, 52.58926045510077, 55.49272829486478, 54.63964416134743, 58.01063891380065, 55.86693025404408, 56.024307512467914, 57.08428098309425, 57.68949485594227, 56.457176362314534, 58.74093324907365, 56.875775629474276, 58.19206030138078, 57.4486848615831, 57.98065239383329, 57.92552348106139, 61.76758312409925, 55.49815293281309, 58.119684726961204, 62.502996152447125, 69.47014147235502, 74.94671160174956, 78.27888273423719, 76.87205406927293, 76.55933918491488, 76.1489337490451, 82.90293355141917, 79.00178340173538, 78.59399810914071, 80.20731602945636, 82.58012248623757, 5.141125109887892, 2.094425549430232, 4.384597472606167, 2.3199206494515945, 0.6624456050415194, 0.14441771673098688, 2.6078493412463897, 77.98727020140618, 62.60079653032365, 57.14768609692974, 76.47674191382625, 33.23731368587863, 20.73358597293977, 45.11895741185835, 65.75856731783959, 75.27813619182956, 69.94462274735974, 85.52178244436942, 15.732365923543131, 1.0631758407238991, 0.44153532674235685, 0.2565988213304551, 0.18978271633386615, 0.28102271559257663, 0.185194477859524, 0.2444029314022872, 0.16736073239195734, 0.21115485338434098, 0.20313348380788682, 0.11332976917225508, 0.10679474806473141, 0.1468687690794468, 0.16151024148829524, 0.13177884412148308, 0.15491233988394662], [0.05428291804667923, 0.01751685319768806, 0.024230776902949138, 0.05630130691814327, 0.05222836599474954, 0.04118319375500564, 0.05273080475988889, 0.01583199219537839, 0.03505273601941524, 0.05372647391331773, 0.02919494238261494, 0.046159654945856145, 0.05232316554493962, 0.049582777109237454, 0.1308075672075633, 31.442054663935018, 73.19713838638799, 66.63760185241699, 78.34299779707386, 37.7956687250445, 31.584964259978268, 64.31174616659841, 56.67864514935402, 35.244492484677224, 25.666807813029138, 0.692963790028326, 0.1787201768808788, 2.2165456029676625, 1.0400680548721746, 3.685123160962136, 7.447161549522032, 0.9129220968292606, 0.6322099532811873, 59.95983723671206, 95.02628157215734, 82.37071498747795, 78.88918784356888, 71.41214616837041, 71.18635100703086, 67.53991173159692, 67.9728158827751, 67.495298693257, 71.98791088596468, 69.05870053075975, 67.53972345782866, 65.9211495614821, 64.63036029569565, 62.48503954179826, 62.922623080592004, 57.56938795889578, 57.793249391740375, 56.75974407503682, 55.33507254815871, 55.010370900554044, 54.47144900598834, 54.43266068735431, 53.90671007094845, 52.88981991429483, 55.608073434522076, 55.229313681202555, 55.689490072188846, 52.041140602480986, 53.04509478230631, 49.50202957276375, 49.56313617767827, 48.486818190543886, 54.74863898369574, 63.91707727985998, 64.19114897328039, 61.89717038985222, 60.41125497510357, 56.07310964215187, 57.008563549287864, 50.43273348962107, 49.99498128890992, 48.587387761762066, 48.38462083570419, 48.49065819094258, 50.34710814875942, 54.18062486956197, 57.05616543369909, 57.351272798353634, 59.291080967072524, 60.988012052351436, 55.802489634483095, 52.231528528275035, 67.41120307676255, 59.7755015280939, 54.45494367230324, 65.87197872900194, 53.02480828377509, 64.9015059009675, 63.04127085593439, 65.09348238668134, 64.3516602054719, 62.62104380515314, 60.243530504165165, 53.607986280995036, 51.00789808457898, 50.41674198642854, 47.859748871095725, 48.0781150633289, 48.73556313976165, 49.68527486247402, 49.31053946095128, 46.90765234731859, 51.53712388007872, 47.836418613310784, 46.22721918167607, 46.27016521269276, 46.78484685959355, 48.18512124399985, 47.06825771639424, 48.79029589314615, 49.189248008112756, 50.259827567685036, 51.019594592432824, 50.85658481044155, 49.406986621118364, 49.29704650755852, 50.39354508922946, 50.0434539394994, 50.32140093465006, 49.094703197479255, 52.74330762124831, 49.99512249423612, 50.16632610751737, 49.01669509949223, 53.752984539155044, 57.64428561733615, 65.90174951860982, 69.64798173596783, 71.62669981679609, 66.70434490326913, 73.92433012685468, 69.6514569559405, 75.15822149092152, 69.42662669766334, 78.25818830920805, 73.72596017775997, 77.58692956739857, 6.75447391886865, 0.46081993548620137, 2.412202742791945, 1.65282329724681, 0.2540961499776571, 0.07494603689279287, 0.11403165892848086, 17.93067397609834, 79.82086843059909, 30.788670163000788, 40.91115243973271, 42.84365323282058, 20.86976085939715, 23.20845054041955, 25.480093186901463, 51.24639780290666, 59.64390600881269, 57.45681201258014, 39.034714083517756, 0.3079939441334817, 0.09556438939105119, 0.0527782524154792, 0.02205710775489288, 0.06673072449742787, 0.01194147883178366, 0.06762672561190783, 0.0653969884038933, 0.0725015422569648, 0.03382105432871369, 0.0597601555918734, 0.016887778183445334, 0.04604091514803229, 0.08700299677589247, 0.024849429290982026, 0.0411028809274637, 0.07678090940199553, 0.033756714434392994, 0.0616904481824848, 0.03345976726362302, 0.015851291865410826, 0.06310667279326627, 0.04155973746110836, 0.029521462462481954, 0.010142690021424525, 0.12136053098666093, 0.06558639598229239, 0.06519882444051966, 0.01366828985121702, 0.030815162801093636, 0.17026213718758476, 50.11828491764684, 86.02139042269799, 76.49224312074723, 84.23884576366794, 54.185159129481164, 41.69320244942942, 45.06617799881966, 53.61288532134026, 43.53096623574534, 28.19409485786192, 0.1774709479462716, 0.6541076266477186, 3.014981068911091, 3.000227563804196, 9.83603060245514, 8.279941043546124, 2.2600932275095293, 1.0520392512121508, 66.17424441922095, 99.38292872521185, 86.25775244928177, 84.67706864879978, 73.79758265710646, 74.40172180052727, 71.87258535815825, 71.6484611265121, 72.99789767111503, 73.5930859658026, 72.25331414130427, 70.6479900113998, 68.53696253991896, 67.40352307596515, 66.91287379111013, 66.23002836781164, 61.09363363635156, 60.87914274584863, 59.767539116644095, 57.55188242081673, 56.7822035666435, 55.748451140619096, 57.362910470654896, 55.47949814027356, 57.541574432003884, 57.817724981615626, 58.71184887424592, 58.55309486389161, 56.04674346985356, 56.69148698929818, 53.691901468461566, 52.14332619021016, 51.465528857323434, 58.33992973450692, 65.58950531867244, 67.69947375020674, 64.57282304763794, 64.41391214247673, 59.891336964022734, 58.801180854920425, 52.11056263216081, 54.60578626201999, 51.5872125471792, 51.325806187045195, 51.87638536576302, 52.586079412891024, 54.78927473868094, 60.38382191811839, 62.215537409628595, 63.41529238608576, 63.24503014164587, 58.149612411375976, 55.54861422507994, 70.02537650446739, 61.46546648394678, 58.309354859013716, 69.28196184096798, 56.354571080976925, 68.12068139353107, 65.94762556014523, 68.88633589590751, 68.22427118978193, 65.36003489648142, 62.79809959473149, 56.63180420475622, 54.290125677662516, 53.91984608865554, 50.31330908498457, 51.30886154790079, 53.91633164498114, 52.17125738820722, 51.483046162513, 50.31161462107013, 52.13000582110498, 50.49287126910303, 47.876332652184274, 49.21426880744196, 50.38413532318608, 50.38915987937681, 49.884405751382154, 52.3582838427636, 52.484031108117875, 52.211900987932765, 54.327709828653646, 54.27341245835828, 52.475633313578946, 52.08294522377753, 53.07492832983694, 53.963215735650834, 53.72619082850795, 54.190470018694484, 54.955951936783336, 54.27681707566785, 54.41778705966089, 51.98414464150706, 57.62121815835276, 60.62782472179782, 69.23251644257577, 72.29421661746117, 74.4776039738809, 71.31940564801617, 77.14846349531605, 72.07319890299152, 77.49579721881499, 72.13960463000883, 80.88980059469901, 76.5315374251335, 77.92566545547979, 9.032213399487159, 0.9224599527735865, 3.5086177289485936, 2.567696773236798, 1.5164478796143688, 0.13551290988201095, 0.15152117507832666, 15.508744735871593, 85.30274944920694, 40.90370385877548, 42.32217411841116, 26.217841986686956, 24.245489912648356, 40.63897132873535, 40.118861121516076, 61.07235477816675, 66.79011144945699, 62.35946486073156, 63.168661594390876, 2.9949850709207597, 0.24801246190984405, 0.07602226019145981, 0.09685153967791027, 0.054331304159976786, 0.009490326891893582, 0.06430078553216112, 0.0464678559482338, 0.08321113734235687, 0.01198963703392374, 0.02341335151164282, 0.058475740238904, 0.03331209998577833, 0.12265873592226736, 0.0316187794575648, 0.0746666293050493, 0.22008422101216935, 0.25070078701021214, 0.12308334015429982, 0.14340153174294581, 0.12634955601946962, 0.1648987249861802, 0.1758221428721182, 0.09166140124321946, 0.15119848352286125, 0.18802229224914507, 0.10959178870243412, 0.15590117553309088, 0.12537598850265627, 0.1291697478342441, 0.24474408567672779, 63.59239916647635, 97.86231210154872, 86.67868552669403, 96.4938363721294, 53.9315975096918, 47.372261016599595, 92.57825190021147, 81.7499214603055, 55.32302694935953, 38.32899731974448, 1.1095855697508783, 0.4108784798412554, 5.643559155925628, 5.643392945489576, 10.528574086004689, 13.746214951238326, 5.801858171339958, 2.138094767447441, 71.4341506650371, 103.48402561679964, 91.23356142351705, 87.62227442956741, 78.65466148622575, 80.59859598836591, 77.22867596533992, 75.57055673291607, 77.87203096574353, 78.06330142482635, 76.47517296575731, 73.7516438576483, 72.74630115878198, 71.886305809021, 69.53130691282212, 70.55341382180491, 65.40188658622004, 63.72711689241471, 62.64975163244433, 61.14030984140212, 60.545502016621256, 58.214511948247115, 60.54936162887081, 58.85436819445703, 60.51874752967589, 61.183891296386726, 60.57737911901167, 62.12494242575861, 57.55010558712868, 59.9173540453757, 55.541946195787006, 54.52796251543107, 53.50903664865802, 59.89999755736321, 70.08789124027376, 69.13841093740156, 68.25990200042725, 68.02840371285716, 65.09260377576275, 62.60938652100102, 56.07170935600035, 58.06177485373713, 54.98978630188973, 53.73067801998508, 55.02788036100326, 56.37283363649922, 59.095578270573775, 63.76743101304578, 63.93536729197349, 65.55355287367298, 68.94302983437815, 60.883567179403, 58.886578698312086, 73.15772641089656, 66.17240090523997, 63.11743151757025, 74.0093671121905, 58.459150175894464, 71.078823151127, 69.03180091611802, 71.00219572744062, 70.38283778775123, 69.7320616629816, 66.78021923188241, 60.10886376903903, 57.8513789176941, 58.20652992494645, 54.48391429839596, 55.267164553365404, 57.14636425818167, 56.116424375964755, 54.61769065549297, 52.6302178444401, 56.4472488434084, 55.4623769944714, 51.89342806416174, 52.18310294612762, 52.98044627712619, 54.65106610328921, 51.94408939730737, 54.9314175113555, 55.33744950448313, 55.49872952122843, 56.80932675638507, 58.26048212666666, 55.1094852724383, 54.212596108836514, 55.946075839381066, 57.309789811411214, 56.287663290577555, 55.1526274219636, 58.9418056703383, 58.16769846024052, 55.90633046242499, 55.6898783868359, 60.51389163540256, 65.85599899291992, 73.04570351877521, 77.11236200025006, 79.55158987352925, 73.10738671210505, 81.199918870003, 75.03515320439493, 80.8176838967108, 74.08135829433319, 85.7072634850779, 79.11460645737188, 82.31100082397461, 10.47753522472997, 1.6335665434598925, 8.200735642064004, 4.266380667686462, 1.5833609406986546, 0.3614756452941126, 0.3425385340327217, 22.497952407406224, 97.3132195011262, 46.43013123543032, 61.37867227677376, 58.10179479660527, 29.717308090579127, 34.88015920885148, 40.31003744371476, 67.53780934118456, 79.25115200781053, 73.7915578965218, 71.9172219307192, 2.1182076152293914, 0.3876054335025049, 0.18226785344942925, 0.14478900890436866, 0.17477857790166335, 0.09706415205953584, 0.233696393007713, 0.1531433356144736, 0.13379242962166188, 0.20995408717182376, 0.17938814426381744, 0.13018723517175645, 0.15144274299663885, 0.2462325485483293, 0.13267276147680898, 0.1722186184938877], [0.04575739366813533, 0.06474514717176076, 0.05680702837003816, 0.017376352672375018, 0.023171030240313664, 0.021276046642132347, 0.029789574083782015, 0.0768548368866886, 0.037228218880632234, 0.02563229454080424, 0.06901675384611854, 0.07101847264435023, 0.05893941112463513, 0.08823149537126865, 1.3574341348102017, 63.29797821660196, 78.6276206662578, 69.2083546423143, 50.31973000495665, 23.67724241748933, 24.76188171294428, 48.24226625504033, 40.70423956840269, 40.88979905651462, 18.292822491738107, 0.21159452656584404, 0.8774152698536074, 0.8867151482451348, 0.9897814919390987, 9.632819467975247, 9.163924628688443, 6.161634143321745, 19.00345398533729, 88.50749061953637, 83.1885213236655, 84.06080153680618, 74.57025820209135, 69.44907834452968, 64.27361288378316, 66.81413204439225, 62.549542919282, 63.74441454487463, 63.73817405393047, 67.53771520430043, 65.6857563603309, 62.23791845383183, 58.30692691187705, 59.73703092144382, 60.965301529053725, 57.48674361936508, 52.96191700043217, 56.03103437731343, 51.82792840465423, 52.688892579847774, 54.1930038698258, 52.572154998779304, 53.96412964790098, 52.12344369580669, 52.56358461995279, 53.59607012041154, 52.4810814857483, 51.04921240960398, 49.694908203617224, 50.16460026464155, 50.12550600113408, 51.31533738105528, 63.14348782262495, 64.89360624744047, 64.71558163242956, 63.524106779406154, 60.13926606024466, 58.520762766561205, 55.24673684950798, 51.87055280131679, 49.150883305457334, 48.17132626810382, 50.23164533799695, 52.5019798740264, 54.8218107992603, 54.45104875872212, 52.298993295238866, 53.853212864168235, 58.907814410425004, 60.814815875022646, 56.21610749152399, 54.476128393603915, 65.33412371912311, 57.41456808582429, 53.70728108190722, 65.07924418295583, 54.27114532839868, 66.24449406900715, 62.62496617532546, 65.51150506542575, 62.073445627766276, 58.31457553371307, 53.43549220792709, 54.053818564261164, 51.59152323199857, 49.64162672719648, 48.32072150322699, 47.97257977147257, 48.67865739330169, 48.68820051993094, 48.71608072711576, 47.941298869348344, 45.4857970822242, 47.10571242916969, 44.210650228684955, 47.50575104067403, 46.00470704417075, 46.763501321115804, 47.632372994576734, 47.726160787766986, 46.821775974765906, 47.24292478253765, 49.66451767952212, 49.860393001187234, 49.51014887902045, 51.120336747938595, 49.35898465494956, 50.38426083903159, 50.912000056236025, 50.5379589142338, 51.65830942892259, 50.1744258019232, 52.70845343989711, 51.324111723130756, 54.6336115560224, 58.439212768308586, 63.60876329483525, 67.30038827465427, 68.37994221718081, 68.7937444256198, 70.62714653630411, 69.9795396866337, 72.31094160387593, 70.30763026206725, 73.50601719271752, 68.33352488856163, 74.42925683913693, 11.842608298024825, 0.3666373312232956, 2.498556663913112, 2.323632927671556, 0.29501408578888066, 0.16003307075269763, 0.045459458243943034, 1.1151007899353582, 61.646358351553644, 63.91331572686473, 30.765334021660593, 48.084190814725815, 30.679944023009273, 10.610026025003004, 22.936724424362186, 39.52457104959796, 52.61312023285897, 54.38359968123898, 62.21577667420911, 27.134497934772124, 0.5095725452467319, 0.09501931017204639, 0.1013497015341155, 0.024924436959648327, 0.03667240676980826, 0.029222038912496744, 0.04662317261400242, 0.09568813557346022, 0.020276977973539504, 0.06337182348473899, 0.02719727427428288, 0.0565934851915846, 0.04522266429698756, 0.05497443880284986, 0.06373683756758129, 0.06895201941651684, 0.06338483165769328, 0.07596346294327129, 0.028348696763597192, 0.07816004386592297, 0.028220342562323617, 0.026118599494258245, 0.0025439776166627606, 0.037816827215494654, 0.06706338285678817, 0.04618238477456955, 0.07129797216264472, 0.10193947432262283, 0.2113141077420404, 3.0575731060197278, 80.70311146397745, 85.28655006039529, 77.73373603820801, 67.29883501606604, 28.877203079961962, 29.9160800826165, 47.980895196237874, 44.065871623254594, 48.10006072444301, 16.329128069262353, 0.2776277203473353, 2.2493993755309813, 2.5805133629229764, 5.203006382911436, 7.685795118731837, 6.298352768344264, 9.559423096718328, 22.098713959417037, 95.54985523223878, 86.29728994061871, 89.93683368928971, 77.0338047704389, 74.35777556511664, 65.88688373565674, 69.36176638449393, 64.68230424388763, 69.18388689717939, 66.91596461880592, 69.61221756473665, 65.94247941047915, 67.42884589779761, 60.8848850957809, 64.46476567176082, 63.0104253368993, 61.206943065889426, 55.54943007807578, 59.012067087234996, 54.40286244115522, 56.0178199122029, 56.665140428850734, 54.81835126876832, 55.3240232313833, 53.7286070085341, 55.28066927386869, 57.176821462569706, 55.22028438506588, 53.72116234994704, 51.95326382114042, 54.2501449584961, 52.159023515639774, 55.31574310794954, 65.0002476476854, 69.55876350402832, 67.32762521313083, 65.79586905817833, 62.556285473608206, 61.24422911674746, 56.51758870770855, 55.65830722931893, 51.49764914666453, 52.20949265264696, 50.83520789300242, 55.20769749918292, 56.62290042446506, 56.03027343750001, 54.17405489952334, 57.21520185470582, 61.849705788397024, 62.56347517813406, 60.869834961429724, 55.90473798013503, 69.28469965534826, 60.53466843020532, 57.41081437756939, 68.51096507041686, 56.979934169400124, 69.74539772156747, 64.93043338098835, 68.16505908966064, 65.36865626612018, 60.59690860009963, 56.163045667832904, 56.850303757575254, 53.83151431237498, 52.04401962218746, 50.57424868306806, 51.07962646792012, 52.908961080735736, 52.23221494305519, 50.97453440389326, 51.3606878249876, 48.43758852251115, 49.00849734583209, 47.386840466530096, 48.40244408576719, 47.518094739606305, 49.19066006137479, 49.31010015549199, 50.82748474613313, 49.8142659279608, 50.64378838385306, 52.2212323065727, 53.030801665398386, 51.48627427316482, 52.83808777409216, 51.480041626961004, 52.88823527674521, 52.758687234693966, 53.96008568425333, 54.15154833947459, 52.48072062769244, 53.739860288558475, 54.732847521382, 57.75339418841947, 60.896063850772, 65.60715990681803, 69.99508796199676, 73.14333131236415, 71.6328187142649, 72.38578042676373, 72.55172806401407, 72.28873314396029, 73.10450769239857, 72.26529305981052, 69.08042261677404, 75.55937013318463, 15.765288337584465, 0.31320726438876123, 2.400984028654714, 3.5038934792241747, 1.8811095313679789, 0.4590636329545129, 0.034370626653394395, 0.6307855200382971, 62.07912521977579, 71.57893319283762, 38.69077713258805, 39.858819746202045, 28.791695410205474, 19.09421959230977, 39.06766591533538, 47.22729413740097, 58.889147850774954, 61.745464878697554, 75.4301986386699, 43.384854024456395, 0.19739465788006785, 0.05607347619990188, 0.013837671891275435, 0.0658694424876763, 0.02676270132313573, 0.04655690217811254, 0.029841308001308676, 0.04128049841270812, 0.05333221825440565, 0.072235410972949, 0.05955704653094854, 0.04073077670088218, 0.02512334785874813, 0.04806234921899535, 0.04377643585265164, 0.18000191858699247, 0.10414183920910282, 0.24748795215160618, 0.09468268347723831, 0.1280430470022463, 0.10561512587892433, 0.13139281241643813, 0.17430032453229352, 0.14691856479452503, 0.1645815186202526, 0.21234976668511668, 0.38398058123646245, 0.2231086901719532, 0.4078227389724024, 4.644251023569415, 95.46896026980494, 97.11934458824896, 89.82361055189564, 66.46876735071983, 37.130524958333666, 36.65487873938776, 67.16645502275037, 57.637394012943396, 58.537146506770966, 23.419793728859197, 0.3149796854103765, 2.1388618359642644, 2.5194932953003915, 5.2725328456970955, 22.259405620636482, 23.59789090771829, 15.294455847432538, 24.387036485056726, 97.82367675535141, 90.41972452594389, 94.80717012959143, 82.47696415070565, 76.35234002144107, 70.98074036259806, 74.30784379282306, 68.35703557537448, 72.92857370068951, 70.80926218340474, 73.99625855107462, 71.18241294737786, 70.31371778057468, 64.54196576149234, 67.41458415985107, 66.6329263871716, 63.88965991235549, 58.64399579263503, 63.42388237676313, 57.084473179232695, 57.80044694100657, 60.169793867295795, 58.19851260031424, 59.50264184705673, 58.133569917371204, 57.039209027444166, 60.78603352269819, 56.630286247499534, 57.06662247257849, 55.057772744086485, 56.27065197114022, 57.03862067191832, 57.29240586680751, 68.80888477448495, 72.57677631993448, 70.66953166838616, 70.01791615639964, 66.04967778728854, 65.61786797738844, 60.08720836331768, 59.71379087817285, 56.62504988331949, 54.33901017712009, 54.96935075329196, 58.94953273957776, 60.98820817086005, 62.96461205328665, 57.97503555974653, 61.047494796014604, 65.32842843763291, 70.10504768740746, 63.52573456302766, 60.23406190256919, 71.46014813453921, 64.28223033105174, 61.003525026382945, 72.81487203413441, 60.72170665187221, 73.54589985262963, 67.19377040863037, 70.55607318878174, 66.98711641373174, 63.85855159451885, 59.94375551900556, 59.692817964861476, 58.38982620546895, 55.613796172603486, 54.222366732935754, 53.60369520802652, 55.95715261274769, 54.958540701097064, 55.090202900671194, 53.72862662038496, 50.76244400393579, 52.34038214529715, 51.292203241778964, 53.11546210319766, 50.136833806191724, 51.62815424703783, 53.1333794901448, 55.093340796809045, 52.106981508193485, 51.72923764874859, 54.963282846635394, 53.682754501219726, 54.81490742775702, 55.86626345111478, 53.70399805807299, 56.15992738354591, 56.983028919466086, 57.08403387377339, 59.0239675583378, 55.6671953201294, 59.02545021426294, 58.201066063296416, 60.67342619742117, 63.942321654289, 69.42872124333536, 74.24379148790914, 75.65436993875812, 77.3686888910109, 75.12685037428334, 75.46422912228492, 77.20478873099051, 74.51960471368606, 77.0260855459398, 70.47710803247267, 78.4697295773414, 18.887234157131566, 0.9598330925068549, 12.50122033780621, 7.759874472695013, 3.272956826033131, 0.4409948057465015, 0.11989239242769058, 1.5267595456492518, 74.38206288122362, 79.15275542966782, 45.86958923647481, 64.70670923109978, 39.966202474409535, 14.134877708650405, 35.23931495604977, 53.61692144024757, 72.70174303362447, 68.89775783784928, 88.83822487246606, 46.96059257753434, 0.742623018881967, 0.1984111646250371, 0.26700735152248417, 0.11222084158010061, 0.16925752012720033, 0.1291538898142115, 0.0753691319316145, 0.12771350662073783, 0.13391353280073212, 0.19546508158166565, 0.1221291240184538, 0.1419555561076249, 0.09584724437445404, 0.12592433891709776, 0.1506912873517121], [0.14183782371542147, 0.04892267744928118, 0.04980558995157481, 0.08910065276488181, 0.04716515683779313, 0.025172850545195323, 0.05103173282658381, 0.08368012870872214, 0.021906605951728362, 0.028619826771318916, 0.07855692337597571, 0.14942138936490784, 0.07814246980893998, 0.2291684916182872, 16.524519958803733, 80.73404327515634, 66.66941227451449, 66.7426586151123, 25.715915887586533, 116.80887406872166, 71.4570180831417, 43.40028855108446, 45.189952311977265, 57.216453090790786, 6.537636960706403, 0.2841854023356592, 3.552795384199389, 2.1752315230907935, 2.0568426241797786, 5.287284879915176, 4.895259670672878, 10.093945072543237, 52.83744058301372, 84.2700364512782, 83.60015838376938, 79.77256051955685, 75.04188399161063, 67.82844912621283, 63.714671211857954, 58.95322761228008, 58.428520387218846, 59.87935804551648, 59.632291870732466, 59.57291895343412, 58.14049290072534, 57.67004382225775, 57.8972275026383, 54.32071624263641, 53.420453840686434, 57.88273826722176, 55.82807525511711, 52.97552370255994, 54.09827078542402, 53.691407249819854, 54.529256897587935, 53.04951137112033, 51.96264220822243, 53.02264313543997, 51.06546278922789, 53.169524131282685, 53.37471508210706, 52.335502716802786, 49.52690132202641, 50.77716858156266, 49.629871383790054, 50.419142476974, 61.8913927385884, 66.02466875506987, 66.56632454164567, 66.36201612411007, 63.0438203965464, 56.30208976807133, 54.556678187462595, 51.69081018817041, 50.74429519714848, 49.08217906951905, 49.205721962836485, 55.41797968649096, 61.476347138804776, 58.62396424816501, 54.66868539010325, 50.91797774837863, 55.70426171825778, 55.734722845015995, 56.3315075443637, 52.12036463522142, 66.12592866343837, 56.76925190033452, 53.293710293308386, 64.03272836439072, 55.36682805707378, 64.77340521350985, 63.624370405750895, 65.74642758215627, 60.38143711705362, 56.76111690459713, 54.52717804139661, 52.43237349294847, 50.49232998201924, 50.98761943078811, 50.02324196600145, 47.779324593082556, 46.00587198811193, 49.61626075929212, 48.637001822071696, 48.8034515227041, 46.17947609193864, 47.092678393087084, 44.693866622063425, 44.170108610583895, 42.647958340183386, 45.05330085754395, 47.799705228497906, 48.276022172743275, 48.54120577535322, 48.18235597302837, 50.83017549207134, 49.33794898371543, 49.29754072620023, 51.57567293413224, 48.59071393166819, 49.395144985568145, 48.60719965350244, 49.88986961303219, 51.7089472278472, 52.83946452602264, 52.03400188876737, 49.96286099956882, 51.46739982789563, 55.23085909505045, 59.699666423182336, 62.635784072260705, 63.74794075565954, 63.95230800874772, 66.90202451521351, 67.11338535431894, 70.89147506221649, 68.98690546712568, 71.96680068969727, 67.16641579904865, 72.14326027900943, 28.946213260773693, 0.5803058416612688, 1.2690687732350443, 2.2582680996387237, 1.6003325461379945, 0.9807456993768293, 0.11093553756513905, 0.1269601357560004, 17.761296226132302, 78.88907801720404, 44.99816802240188, 37.12731253716254, 44.99979972839356, 29.89396183721481, 13.419302067449017, 27.685230085926673, 47.27178558226555, 55.50883354679231, 59.93482820449337, 54.92372966581776, 2.0174262360219033, 0.2417785440000796, 0.08469877283900015, 0.07983046794129957, 0.02346724005145652, 0.04102163347265413, 0.07975012063980103, 0.018668505513379653, 0.1442620323430146, 0.027193757930710435, 0.06515047663161833, 0.028595867371487043, 0.04719762364402414, 0.09780409340296062, 0.03563039312740007, 0.04302047178029053, 0.06503955476106175, 0.06475943471154859, 0.027732970831435055, 0.05065155020284076, 0.04118002598143874, 0.020429906360204184, 0.040195254428732785, 0.1257857536115954, 0.02916546906494806, 0.05736307030723942, 0.037380635903607455, 0.10765261332234068, 0.3164425456235486, 24.742777809020012, 95.62320355446109, 72.31181237005418, 73.58583742572416, 32.687928868878274, 97.30517079753261, 41.84158963541831, 42.015134903692434, 51.32222898544804, 64.0583335968756, 5.420160072465097, 0.3685774335697774, 2.403398982940182, 3.5928278296224536, 4.256988552308852, 1.9525922762770809, 2.384484088228595, 13.99268884812632, 60.26476621627808, 89.11054718878962, 86.78845697833647, 82.21622067113077, 77.20841300102973, 70.48652956562658, 66.4967809184905, 62.50935039212627, 62.63500352059642, 63.480337050653276, 62.99418672438591, 62.792369011909734, 63.44928756836922, 61.24959491914319, 59.2952779031569, 57.05866398349885, 56.41694461145709, 61.054653121579086, 57.759928857126546, 56.24385826049313, 56.9851940678012, 56.2986380823197, 55.51909446716309, 55.45898806664252, 55.8100833431367, 54.466036135150546, 54.58897106109127, 56.56926201235864, 55.12543755192911, 55.21605607002012, 51.92910202087895, 52.28316653159357, 52.83327502589072, 54.131050032954064, 64.50680955763787, 67.88118147080945, 68.9198721608808, 67.95375316373764, 65.20649763845628, 59.14080319866058, 57.955753187979425, 54.71937025746992, 53.77547148735293, 51.646926710682536, 51.08044624328614, 57.00259762425577, 64.64651261606525, 63.07602697803129, 57.91139118133053, 53.53447714159566, 57.32733849556216, 57.68929089269331, 58.61653920142882, 54.703563105675485, 67.80032573207733, 61.64959822931598, 57.82568739306543, 65.13977812182519, 58.7595566626518, 67.86630784311603, 66.26871078245102, 67.2912726863738, 63.85388789638397, 59.95494211873701, 57.39485425333823, 55.80822021730485, 53.33925293337915, 54.453629678295506, 51.588824641320016, 49.76478522823703, 49.4249471541374, 51.930517996511156, 51.371533178514056, 51.17768179985785, 48.07585970047982, 49.40111875534058, 47.468084519909276, 46.053885721391254, 46.886993223621005, 48.02155056307393, 49.24108605231009, 50.61846556202058, 51.004042394699596, 49.698736436905406, 55.04351885088029, 50.625718024469194, 51.93286749624437, 53.26512405949255, 51.05190315554219, 52.22760615810272, 52.962768154759566, 53.108939201601096, 55.56334664744716, 55.39236268689556, 54.17464325504919, 52.2621936182822, 54.115748866911865, 58.16963218873548, 61.85347518613262, 65.06598264940324, 66.99745578150596, 66.31191961226925, 69.85101930556759, 70.45129883673884, 72.53469713272588, 73.25661720768099, 75.71480581837316, 68.16942861003261, 71.60969241972893, 36.91919549818962, 0.09788206583189388, 0.043802348776690425, 1.8546407645748508, 1.9713177940537854, 2.4454948402220205, 0.4282610761302133, 0.14715652702556503, 16.40815794467926, 84.09007810777234, 54.22455149312174, 40.65105615123626, 28.592282110644927, 22.179469677709765, 15.377005069486557, 42.83455725639097, 59.638940288174545, 62.36337546379336, 67.46439826103949, 70.08276862482872, 5.5036335029909695, 0.4211724645668461, 0.10356639226477954, 0.11303511643481833, 0.0842697099752484, 0.021545037349325516, 0.03130445932789195, 0.1490696324335952, 0.07243969597883763, 0.030987034626905958, 0.055289097926429207, 0.02390726563340474, 0.01829686285477252, 0.08403680392450864, 0.054300794708392316, 0.12831272527335152, 0.15756160982193487, 0.15966219226679496, 0.16762317879305733, 0.11912841124520188, 0.2560347814353243, 0.15414372386951603, 0.11225326242105615, 0.19102854383808954, 0.14605887624765598, 0.20345234492373085, 0.20786617582123126, 0.22133038559507942, 0.43971997415346487, 30.56555594167402, 109.00262002022036, 82.06247944985667, 89.20338969076835, 39.767808991093794, 127.02616199370354, 89.83307915349161, 62.674972472652314, 65.04749651878112, 72.19924034610872, 8.680970053518973, 0.44911929075756385, 7.324296245651861, 6.68989650664791, 10.660855039473503, 14.009342251285432, 17.653291802252493, 16.57934096551711, 62.24740666727867, 94.76192166728359, 87.38883849113219, 86.71918007635301, 82.63805589368268, 75.64458754754837, 68.35541955886349, 64.6351416649357, 65.64664640734273, 68.76847651696974, 66.30869542398761, 66.53263922660582, 64.89877593132758, 63.451029100725734, 61.747441753264404, 60.056417757465, 59.228185761359434, 65.38111763615763, 61.3927653528029, 59.04878439441804, 58.989462467931936, 58.91768309377856, 58.85600774518905, 59.25715246508199, 57.60882346860824, 58.18324673560358, 56.259249641049294, 59.64427078923872, 59.777254827560924, 57.67573910374796, 55.41685788862167, 58.12646258261896, 55.21450673380206, 56.78195645732265, 67.17501363446637, 70.52022272540678, 69.84843054125386, 71.68269557337608, 68.72644439820321, 63.11363074087328, 60.282593388711255, 58.32361267459009, 54.840520504982244, 54.33812764383132, 53.26940336535054, 61.88355192061394, 68.03111014827606, 66.2445411374492, 60.965372131716826, 56.70527412045387, 62.833887300183704, 61.6158462339832, 63.537438915621856, 58.347495986569314, 72.76396751403809, 65.83682644751765, 62.21022652041528, 69.21077866708079, 62.683009409135394, 71.47484917794505, 71.30060180541008, 73.11882434352752, 67.28498904935776, 62.55617172487321, 61.63943144582934, 59.64463556966474, 57.621151478059836, 58.2998784126774, 55.884678979073804, 54.311008376459924, 53.29787585043138, 56.905711158629394, 54.89175842654321, 53.71940120573967, 50.56848279891476, 53.222291777210856, 50.14300369447278, 51.06994605833485, 50.048082336302734, 51.274964424871634, 52.15355573161956, 53.53450852055704, 54.74871350872902, 51.978712158818404, 57.660571298291615, 54.186190712836485, 53.766018575237645, 57.949673514212336, 53.14100850012995, 54.95106074117846, 54.95815238645, 57.14713304273544, 58.78957848395071, 60.44954123035554, 57.93137173498831, 55.909707623143355, 57.75332750812654, 61.59146085862191, 65.42060021431216, 68.79675680591215, 71.16436219984486, 71.57741915795111, 75.20881222140405, 74.95836104116133, 77.1074119690926, 75.94060097971271, 77.68913084460844, 72.61061068504088, 74.7256075951361, 39.24595725151801, 0.9918617577322069, 8.249749579737264, 8.346898844165187, 8.222237094756096, 2.9283023265100296, 0.5595085769891739, 0.2722034194777089, 23.07262082253733, 93.36214542388917, 60.51631173779888, 55.5356978601025, 58.87122261908747, 41.49569934414279, 20.93680004919729, 42.32416276008853, 62.554504717549975, 74.15942130550262, 75.47226998113817, 82.31513500213623, 6.101946455817069, 0.6115133832058599, 0.306104863242757, 0.25896397990084463, 0.3179033220775666, 0.15981806051586905, 0.15345908641334505, 0.30321959225881484, 0.17443008450490816, 0.1306545794490845, 0.18081420161310705, 0.1019453731996398, 0.11568180465650175, 0.14338265533649153, 0.12006260184270721], [0.029778350895691304, 0.03845649148007074, 0.02508518901923972, 0.03120358853090194, 0.06736922047791943, 0.12221479563102608, 0.02903561716178252, 0.017178567922523907, 0.07385790858778261, 0.04773051057371402, 0.06872814554240435, 0.06944848269584679, 0.17881558547096868, 0.17329979838142473, 50.51804111849878, 82.06877093161307, 67.12573297562139, 68.8446803246775, 58.946336007887325, 76.99402409215128, 88.59694419368621, 44.41695121026809, 53.58995122294272, 48.967590947305005, 0.12148284458465154, 0.10762888757932572, 2.7834119335297616, 2.2912000744573535, 5.3428501563687485, 2.2132142849506873, 1.920506920545332, 38.102943281973566, 78.52144210569321, 84.08624202974381, 77.94608531459686, 78.64322385480328, 68.40650450798773, 67.96818748597177, 61.29885988850748, 60.55602965816375, 58.896706258097005, 62.40356014620874, 56.635098995700965, 60.30881051094302, 58.076726928834, 56.449363000931285, 54.58322086641866, 54.25884477553829, 53.10756244967061, 53.85322463127875, 52.01225234616188, 54.10459756851197, 52.791799883688654, 52.43444842676963, 53.72518670174384, 53.36043765467983, 51.14074091757498, 50.79235599886987, 50.05672331779234, 52.27812628592215, 51.4343067907518, 50.71807415254655, 48.21318972495295, 51.404241823381, 51.730151560998735, 53.57207698206748, 65.03480765127367, 66.11804469939202, 65.44316953228366, 69.3200872790429, 63.64155038710564, 59.01314966140255, 53.960823089845725, 52.164569747063425, 51.22312245830413, 48.282701969146736, 49.15690414367184, 54.545640637797696, 62.37038473929129, 61.8745893047702, 59.41205470792709, 52.883198953443966, 52.029985381710915, 51.674026366203066, 52.67351688877229, 51.60199596035866, 63.52966085557015, 58.461448684815444, 55.962494880922385, 64.64171947971468, 57.17595461876162, 66.00065600487494, 60.10867549527077, 60.702710613127685, 54.885262981537856, 59.575386124272505, 56.314245193235344, 56.65526390075684, 51.505533110710886, 51.94461499491046, 50.77439154348066, 47.93326585523544, 44.577395762166674, 47.68537990508541, 46.597000629671165, 49.879087017428496, 46.65878580462548, 46.53900838667347, 44.81029041351811, 45.37559024749264, 42.78672787450975, 43.65483076341691, 43.8751934420678, 45.81192255020142, 47.13326707963021, 48.886939171821844, 47.68313238697667, 49.68712229882517, 46.76874553003619, 50.45239633129489, 48.13318906291839, 52.085161362924886, 48.74846773762857, 50.672355005818034, 49.83783937269642, 52.484333130621145, 49.375215422722604, 51.35910710980816, 52.67989858504265, 53.37202825853902, 53.38178319315757, 57.82204743354552, 55.390338743886645, 61.70470360786685, 60.26111841201783, 65.24891414949971, 62.4711621961286, 70.61501856773131, 70.32012693343624, 73.70802710133215, 70.66724884894587, 67.61225592705512, 3.5021090459439064, 1.383693912817586, 1.5967738532250928, 0.5028806140105571, 0.7288813014184276, 0.1423894223426619, 0.14566354423521027, 1.0425261552295377, 54.698091399285104, 70.81797768992763, 41.99957878358903, 53.44641600885699, 69.05920259414181, 64.8595836085658, 16.359523496320172, 17.44896573405112, 55.43519496917725, 57.04388841505974, 65.51067352294922, 15.659022504283538, 0.81939201561674, 0.11525039756370169, 0.06422778118341681, 0.04633875864167367, 0.060765577044578335, 0.08362179111328819, 0.06096714626877539, 0.014767098379501653, 0.029892549707343983, 0.00583973694442501, 0.09324968537135471, 0.055743437861242605, 0.06463532080693592, 0.05214454065407476, 0.08564112993377833, 0.08061873411098797, 0.0979563610387906, 0.04734821354729995, 0.029500942797430103, 0.06311442560305999, 0.055406137009061156, 0.04148974383790647, 0.027020646957680586, 0.07184348805176635, 0.06789520112497192, 0.06578073716692387, 0.09007085715570758, 0.1418719605933274, 63.13851033487628, 91.26437556359076, 78.38540646337694, 77.12781613872897, 55.0954157306302, 98.20113428177373, 74.68970221857872, 38.607768012631325, 64.71276144827566, 51.3768401453572, 0.09219403919433394, 0.18596549939003684, 3.7950978404091256, 3.2942516188467703, 5.022590592984231, 1.5013485930619703, 2.699059892085291, 41.83349386338265, 85.8499671566871, 85.59415801878899, 82.6258808566678, 81.0715240047824, 74.06679845625355, 71.31567939635246, 64.63277255335163, 64.95967465062296, 63.51725439871512, 64.34475683396863, 60.2765803952371, 62.040819352672955, 61.294482523395175, 60.37620467524375, 57.099629217578524, 56.78307825519193, 56.13317681897072, 56.64747015122445, 55.562628853705625, 56.298893036380896, 54.600589121541674, 56.660484575456195, 56.77418231964112, 56.62768963844546, 55.14188405006163, 52.67208914602957, 53.11626618908298, 54.73714251672068, 54.43874820586174, 53.79489898681641, 52.165903352922015, 53.89275427787535, 56.19328714186146, 55.99215584416544, 67.92742621514105, 70.19740381548482, 70.33534572970483, 71.99301781192904, 68.03989625746205, 61.60867221893803, 57.90564883139826, 53.6527915154734, 53.28566943445514, 50.477793678160644, 51.78358993222637, 58.32804887525497, 64.67613435560658, 64.04854336092549, 63.041051203204745, 55.52813945278045, 56.54145240783692, 55.96835490195982, 56.30500408910937, 55.19988806016984, 64.95353614130329, 60.02279912271808, 57.62607013025592, 67.79808213633876, 59.36171500913559, 66.69049893656086, 65.70955338016634, 65.2842390152716, 57.47566292362829, 62.1289393209642, 58.76376928821687, 60.267707993907315, 54.70578316719302, 54.72825834828039, 52.75665152457453, 51.78138556018953, 47.31652021408082, 49.8867081826733, 49.91743210823306, 52.65321077839021, 48.99984851960213, 48.649090566942775, 48.43999293542678, 46.16620279127552, 45.0604199594067, 45.96605600849275, 46.252683208834746, 50.23436354052637, 50.487383873231956, 50.38547677378501, 50.27215165476645, 51.49848461151124, 51.07500591585713, 52.92332480030676, 51.9921305871779, 52.12375748542048, 50.84468826170891, 53.710485658337994, 53.326179673594815, 55.66578718923754, 52.82395155199113, 54.88363127554617, 55.8877541172889, 55.61892663278888, 55.99698428184756, 60.02129685494208, 59.35157960461032, 63.73612265433035, 63.50922530697238, 68.71318678702079, 66.72637293415686, 72.77551497182539, 73.37462563668528, 77.34125583402573, 73.65241573702905, 70.94065373943698, 7.033649596475787, 0.7321815469091939, 0.31864287271615, 2.946951235494306, 2.605220617786531, 0.7681842472764754, 0.1139886967176872, 0.6376781663106335, 56.57059169584706, 78.5728879128733, 51.8179577396762, 41.13211916339013, 44.16246783348822, 49.68192515834686, 25.26190350132604, 31.72328664410499, 61.51900291442872, 63.10997901424285, 77.48264943399738, 26.06238472846247, 0.7235155603097332, 0.10266845294785115, 0.05478226564704411, 0.013150021794342227, 0.0411798038159407, 0.03084857764113094, 0.031958284727748365, 0.023568051476632396, 0.07305665722777767, 0.030865012142326564, 0.06522799706867626, 0.04821696108387363, 0.06135187945478867, 0.02318246410258355, 0.14508753804670227, 0.3049179172563938, 0.1517194999201644, 0.20840101244468845, 0.17323235200057108, 0.22500391508783066, 0.11125081338949742, 0.11611866629532269, 0.12714352188331465, 0.11669860251488225, 0.13578983534487987, 0.2268669030238544, 0.31665610029332103, 0.20364239601598633, 73.50038466915008, 104.97579713021557, 89.2895249397524, 85.09281635284425, 76.10261055731004, 81.686857592675, 112.18848674528061, 65.88100802513861, 70.10757369379844, 62.591708398634395, 0.47852811914297844, 0.5004803686132354, 8.137563418957496, 9.855740512571028, 17.055236254968953, 6.925166643434956, 3.723073563268108, 46.64442992979481, 87.88606166839601, 90.36818458187966, 87.6679543525942, 87.39420429352792, 75.59677385514783, 76.8993616104126, 67.87805141941195, 69.0548958316926, 65.2156210714771, 69.07853987909132, 62.372192951940725, 66.87526610589796, 63.469193596993726, 62.88661964478032, 61.77987190984911, 60.61321389290595, 59.45664028967581, 59.34387606959189, 58.03947617930751, 59.48712495065505, 55.843866717430856, 58.91404705662882, 59.840969808640025, 58.84651560937205, 58.052078754671165, 56.17826446410149, 57.05101536166284, 57.58036667300809, 56.166846444529874, 56.051191437628965, 54.645598319269, 57.35735247212072, 59.70010180627147, 59.77586238614975, 71.00651817937052, 73.49850977620771, 72.21743229896792, 77.49036081375615, 69.65879178816273, 64.4842363172962, 60.466328974693056, 57.45672179806618, 57.755845669777166, 52.7595462337617, 55.81695925804877, 59.885755431267526, 66.74422756318124, 67.64889086446455, 66.30136059176537, 57.78291394633632, 59.391399506599676, 59.5661489425167, 57.73474724062028, 57.921895288651996, 69.13480235684302, 66.43370136137932, 63.43632413494972, 70.61341824070101, 62.41011834913685, 73.41512803108462, 68.37557269680885, 67.08633668961065, 60.59899922340148, 64.44846430132466, 62.59050030862132, 63.70786982197916, 56.183810695525146, 58.99532641133955, 58.033890724182136, 54.307313503757605, 50.839224400058875, 51.904489148047666, 52.43460139920635, 57.27809313804873, 52.52910698613813, 50.605051056031265, 50.67279431127733, 52.19607814665764, 48.25903438752698, 49.247299086663034, 49.64204642080492, 52.13528925372709, 53.91651599637924, 54.0429457541435, 53.43048726358722, 56.996972945428666, 51.8439002959959, 55.90078030863116, 55.504726825221894, 56.54388035497358, 54.852052273288855, 56.189588346788966, 56.17886458673785, 59.77685866817352, 56.004432862804784, 58.08650932004375, 59.81943991876418, 59.23366531249016, 58.682442865064075, 63.513481078609345, 62.18653932694466, 67.42499413028841, 66.95616891307216, 71.67900070067375, 68.57316601660945, 77.10417209133026, 76.25249216633459, 81.47922300523328, 73.71164352663102, 73.60357438364338, 6.318508848067253, 4.656577071835918, 7.034656174721257, 6.420582157950248, 4.572490280674351, 0.8383224159479142, 0.38086514679654954, 1.3913892353734663, 69.10874212941816, 86.1494871877855, 63.34541536146595, 76.94799115580898, 93.87509730554397, 76.56581109569919, 26.532143469779726, 29.652196745718683, 74.36095268495622, 72.37224040492889, 92.5234720783849, 27.50512073116918, 1.1453754815363115, 0.31886310767262216, 0.08973817581370955, 0.16012667137528622, 0.10329266138855489, 0.17636103976157405, 0.08148927812374408, 0.16294668698983808, 0.28763252220326857, 0.24358183836504338, 0.14080452432315196, 0.13193517202331176, 0.1413497031335869, 0.19642832989413894], [0.05832455278704724, 0.04053506038842663, 0.07239140945697024, 0.02022422324385374, 0.07359161642530272, 0.028350156161092946, 0.07636029648804858, 0.10633216885429238, 0.009704166929417802, 0.05267482671526171, 0.02068287625368084, 0.08288387990286274, 0.11351051229623058, 3.3647334239175244, 74.39002529267343, 70.53688495389878, 71.83039634458481, 42.14322774640976, 30.67104808745846, 3.795783764893009, 31.03611484650643, 37.95170453286941, 74.30847921679097, 21.385764345046013, 0.281637730978189, 0.49781977589572635, 0.9749902953063289, 2.2756628307604023, 2.2341391492274503, 1.507775519163378, 16.375522844253048, 64.3324327468872, 79.53658288524997, 82.31636662637034, 79.04908718601351, 77.41185065238707, 68.58406236094814, 66.0484383183141, 64.74482290206417, 62.041784255735344, 62.55251607587261, 59.70758961093042, 60.94057098511727, 58.35830211639405, 58.03858972364857, 56.42084344740837, 54.870934563298384, 55.17614203114664, 52.69892208037838, 53.782135594275694, 54.255899075538885, 55.25276945483301, 52.826685444001235, 54.90791859165315, 51.847618702919256, 53.38587422524729, 54.62680232140326, 53.65893786953342, 50.61412349823983, 51.73049280720373, 51.72554277604627, 49.80654278109151, 50.44355138655632, 50.853239028684555, 49.935337728069676, 49.509195743068574, 59.421087926433934, 65.43047674240606, 66.36767218189856, 65.3776777175165, 64.83308799805181, 60.32310362785094, 55.8313778908022, 54.85294657368814, 53.335220736842004, 51.59801867700393, 50.32961045542071, 53.7620295247724, 62.58911178958032, 63.21515737041351, 64.67516553017401, 61.04087383516374, 56.901435775141564, 53.65224238364927, 54.48107058002103, 53.20206803660239, 66.61022370861423, 55.256307432728434, 51.600646665019376, 66.22888303572132, 58.28849961680751, 61.95697084549935, 59.947226816608065, 62.29978599855977, 60.32855964476063, 63.16881848919777, 61.20265983766126, 58.92998756900911, 49.702537213602376, 49.38816316666142, 49.33743907559303, 50.90601844172324, 45.32418758638444, 44.811369065315496, 46.80789862909625, 49.300247161619126, 47.19582888387865, 44.94065430856521, 45.177969471100845, 43.06475331706386, 44.074728335103686, 43.19687443394815, 43.654862142378285, 45.0145282283906, 45.02180422506025, 48.132224159856, 46.77154610233922, 46.552144404380556, 50.30012992120559, 48.002680040174916, 49.37581554535897, 49.81794118881226, 47.96439770729312, 50.21555185317994, 53.56949214012393, 51.40683058769473, 51.69794497951385, 50.14316451164984, 54.09894935546383, 54.845152824155754, 56.61066655189761, 58.54625032794092, 59.376051272115404, 60.66040000607891, 66.5164476825345, 66.34413011612432, 70.21357967007545, 67.4597933984572, 71.98932293922671, 70.4907343464513, 71.02081914101878, 72.20305288991621, 47.72856520068261, 0.9265025068194637, 0.6430056643101477, 0.6775839927215731, 2.568247130801601, 0.7941363643734687, 0.15730884677219778, 0.26556321449818154, 16.919655607592677, 74.46600160291119, 61.7113834042703, 31.693790420409176, 87.15427291008734, 155.53703923379223, 84.34282779693604, 25.573849601130334, 44.307834794444425, 50.39744784755092, 68.1948612582299, 37.34812628838324, 0.3919382122976165, 0.021072119782348315, 0.08092374435716099, 0.08201968675899891, 0.05173540373723354, 0.022003904863771413, 0.024337833859927716, 0.044152136862037644, 0.051991039616686684, 0.09503371262502286, 0.0826034227746629, 0.013696293237679189, 0.04969962466988833, 0.02004151893479209, 0.06276863649667752, 0.017980857331666256, 0.03866023639397275, 0.020128732299311988, 0.06268334792806737, 0.01674335528795998, 0.0465136373625888, 0.07371682583564713, 0.030098504784907547, 0.04951433481408223, 0.019984259608111555, 0.14343142449375124, 0.1742416881625691, 5.713730358308362, 90.85506839136924, 76.57172602991905, 79.92661553044474, 53.44183468049573, 47.352523649892504, 11.26631307986475, 30.97790687314926, 43.3031588985074, 87.26027104162401, 22.517768221516764, 0.29325444311384236, 0.37222275570515667, 2.370650624075244, 3.6090387403965, 3.4778349678362575, 2.8165495876343023, 20.831545206808276, 69.97492697931105, 85.16516839304279, 86.40291152461883, 81.71356108880813, 80.36377153088971, 73.56276604437059, 69.81981292847665, 66.32807193263885, 63.70508101678664, 65.15867217894524, 62.94988747565978, 64.20068425516929, 60.4453678284922, 60.98768257325696, 59.486689567565925, 60.071095266649806, 56.96532334050825, 55.559279149578465, 55.930386358691806, 56.39969010506907, 57.046896872981904, 55.333076061741004, 56.734315349209695, 55.91588927853493, 54.82073606983308, 56.85627360497752, 54.75144347836895, 54.414551104268725, 55.16726178507651, 55.002341808811316, 54.12537436331473, 53.59283024264921, 51.62108613598732, 53.54180412907755, 52.91661754731209, 64.18790125077771, 67.20975014471239, 68.79349339392878, 69.03862584021785, 65.69021609521681, 63.76928237176711, 57.53928376782326, 57.60192009710497, 58.21575141722157, 54.309580633717204, 53.07373592930456, 55.15125067003312, 64.91228849657121, 67.19121302327802, 66.67651176452637, 61.91724115802396, 59.31667835481706, 55.09665127723448, 57.207255132736705, 56.62823092552924, 71.45103254625874, 57.0468694163907, 55.41483786798293, 70.6077935618739, 61.93206771727532, 64.32081076406664, 63.14719446243779, 62.325434377116544, 63.89114256828063, 68.07686851870629, 64.69935086465651, 61.186742859502, 52.61013530915784, 52.99283704450054, 54.33689601959721, 54.9280874190792, 48.383491193094564, 47.133627937686065, 49.060813919190444, 50.43274133436142, 50.36256228723834, 47.95127345669655, 48.10629729301699, 46.356072964206824, 46.324713614679155, 47.4534030883543, 46.435642165522424, 48.81381834706953, 48.31387304490613, 51.524858628549886, 49.17115803687803, 49.3419341118105, 52.634838396503085, 51.254760296114036, 51.75314057257868, 52.669747491036695, 51.360962390899665, 55.27310302180629, 56.44686445113152, 54.41204470972861, 54.455269229027536, 53.388255103941894, 58.15914769326487, 58.34506019469231, 61.7077709013416, 61.46514484959265, 63.860630450710175, 65.18949024138912, 69.58431382333079, 68.35610205127348, 73.47327324651903, 69.03092230519941, 74.1259870221538, 71.51648121495401, 73.39180561804002, 71.14704101316391, 55.41788554960682, 2.12700353034081, 0.26762880204666045, 0.9964296642330386, 2.7493245755472495, 1.500288449948834, 0.38989723149326544, 0.25401978633336486, 16.48148763564325, 79.50581581361833, 70.49142468360164, 37.33599439744027, 73.14343329398864, 130.04539074436312, 68.01069028915899, 31.682295914619203, 54.12217763162429, 56.122625643207186, 74.81062889099121, 48.89191273720034, 0.468155074143602, 0.041966836584071, 0.08094054466534047, 0.028198342432358095, 0.03308092912418708, 0.039430338618976456, 0.055373712337665984, 0.12489922134385956, 0.0473950942978263, 0.04751341274729179, 0.03818307853033466, 0.05844335387190504, 0.06201330444685394, 0.020167998135870984, 0.20646500100772228, 0.1748232255058904, 0.13328733253142527, 0.12778256944711172, 0.13783276201255862, 0.1594810431162196, 0.17387847055590924, 0.15840723299451415, 0.12225509185584323, 0.17781234736884796, 0.18758162315334045, 0.2537895615903601, 0.30915134976948466, 7.093131849842687, 106.14241200108683, 88.96398390493086, 93.10219426308909, 59.5102551675612, 45.724132061004646, 10.137524566342755, 49.20588670238372, 54.060215950012214, 93.70874958653604, 27.159967845486058, 0.39656320767056563, 1.059278107939228, 3.990229137482182, 8.459580694475482, 7.872720081960002, 4.893762305859597, 22.44962880688329, 72.94344732838293, 87.23738793403872, 88.92111239894744, 83.46826476435508, 84.60118647544616, 77.99299686185776, 73.98176147091773, 70.10059971963206, 66.7718175149733, 69.67584625367196, 66.68352496239447, 65.50050281709241, 64.53819636375674, 65.15442032967844, 63.64542176646572, 64.00664068037464, 60.25824723705169, 59.55335809338478, 58.70062697318293, 58.78227503068986, 60.73675286385321, 57.30548304896201, 60.82160157542075, 57.39326569341845, 58.268742638249556, 61.33799337571668, 59.24427532380628, 56.29248388351933, 57.29071532526324, 58.85246192255328, 56.56716746668662, 57.21331127228276, 53.08015684927664, 56.13625587955598, 54.21046626183295, 66.83827031043269, 70.87807624570786, 72.44208212821715, 70.38617964713805, 67.49502412734493, 69.15241379891673, 61.798950318367254, 62.93087966980473, 59.277584091309585, 57.556530429470925, 55.871590029808786, 57.26155250303207, 69.44965885531518, 69.38027997170725, 69.76077341264295, 66.3847815605902, 61.89007089984033, 60.40122547457295, 62.54028220330516, 59.54168511975197, 75.72895772995489, 60.70965713070285, 58.37786297644339, 73.03917669480848, 64.50542103859686, 66.25743789057579, 66.89183419750583, 67.53109424344956, 68.27279090881348, 68.46364559665804, 68.13844188567131, 64.285650637842, 56.329616961940644, 56.626324653625495, 58.1621051603748, 57.48187988035141, 50.64383545229512, 51.19114729665941, 52.654842484381895, 55.10181703875142, 53.87994381689257, 49.83996921969999, 50.982975344504084, 50.02328118970318, 51.42031177397698, 49.45640848528955, 48.943134969280614, 51.00586629682972, 50.64579271501111, 54.026075640032374, 51.84481420824605, 51.99654717599192, 56.245909660093254, 53.41814748702511, 54.00155690408523, 55.73182421345865, 55.68909391280144, 56.84277672921458, 60.924638317477324, 57.40358544934181, 58.97938589895926, 55.13902071983584, 61.52779686835505, 61.08733430985482, 63.66244877538374, 65.9783769422962, 64.99120266206803, 66.89723137886294, 75.54226859923332, 72.56469541980375, 77.47115688939249, 72.70107623069518, 80.03300589899864, 73.7705026134368, 78.69400285905408, 73.2685882814469, 59.014851970057336, 1.753000999169965, 4.603680968284607, 6.132239901250409, 7.599458848276447, 3.480887552422862, 0.7546059823324605, 0.31185809162355244, 21.51182932238425, 89.40985541189872, 78.31639628256522, 49.83485052662511, 95.28175338622063, 154.29741336453347, 93.55724411626016, 36.54864918801093, 60.347520382173606, 68.59285631487447, 88.87853114835679, 58.934247263016246, 1.0396300977276218, 0.21854246906455488, 0.25330959218403987, 0.24876797782076945, 0.19919134856712437, 0.09836453268484724, 0.16185090546646427, 0.17372407319564975, 0.1251970073809066, 0.19158798720567458, 0.23239965130004192, 0.21589656991343345, 0.2322204786563112, 0.057917840538486365], [0.09127086494117977, 0.030087047939999934, 0.03589790720011919, 0.050656771092044736, 0.05059724989076776, 0.09361838816755241, 0.015142783109519272, 0.06161132279122549, 0.028664872741266608, 0.08601583885930239, 0.05018291123692067, 0.15182555713240178, 0.3451869306304763, 25.086912839643418, 86.45768350170505, 67.54983532813289, 64.67575388569986, 29.76384505148857, 18.148404744363603, 47.02446053105016, 61.74634348961615, 42.11810496545608, 84.24876151546356, 4.097807984198294, 0.15821721254577562, 0.22079875121914574, 1.4235840497478363, 1.8021006161166777, 1.1580854317834302, 9.628773543142504, 38.83116268342541, 79.21920038038685, 82.32897312410417, 81.7622612368676, 76.1742251919162, 74.80967183266917, 71.3508395225771, 67.01448671279415, 64.58170329370807, 61.51980307794387, 61.2403695044979, 60.706185833100356, 55.453484981290764, 61.21887491595361, 58.12858458488219, 59.12439200185961, 57.698210362465154, 54.88634163333524, 54.57396015044182, 50.31512514237435, 53.719969949414654, 53.65766702159759, 53.92655726402037, 54.9388700146829, 54.85448414279569, 51.601623335192286, 54.718750522982695, 50.97764876581008, 50.47682877509825, 49.929203141120176, 50.47735437270134, 50.05658211246614, 50.332493397497366, 48.45503914740778, 50.17791671137656, 50.569945842989036, 55.304638877991714, 63.69467889108966, 64.77766098514681, 64.34575703836256, 65.65202397684898, 63.091383057255904, 60.357722466991795, 57.983064651489265, 61.98560414775726, 60.78724945745161, 57.932383706492764, 50.617798759091286, 58.318999967267445, 63.564040430130504, 65.91488161394673, 64.39982298881777, 63.00883285460934, 57.228702652838926, 55.6623355034859, 53.8250933924029, 67.92994437679168, 51.2843349672133, 48.64200676641157, 65.85708156708749, 58.131322399262466, 63.25369857972669, 60.86048010856875, 61.97507650621476, 59.64894233211395, 59.15873627508841, 57.54818362574424, 58.1672199310795, 49.05264754449168, 50.89959359938099, 48.89187743586879, 55.04315799282443, 47.4370389599954, 44.60008275124335, 45.23067828147642, 45.01118244663362, 45.35612352432744, 45.73351044808665, 45.525636596064416, 46.382568574720814, 43.336361762016054, 44.00855795029671, 42.32182502746582, 42.65697194683937, 45.23369458413894, 45.93946233872445, 46.19111768661007, 46.35506491507254, 46.866400780216345, 48.00517074523434, 49.72427891146753, 48.283862990717736, 48.76269025187339, 50.81332891218124, 51.69641525514665, 54.83554693960375, 51.88295141343148, 51.64431441214777, 56.1738557200278, 56.24144208046698, 64.4682095127721, 63.470833147725756, 62.91769658365558, 65.95787863577566, 67.99470270833662, 69.17971349531605, 67.97905245134908, 68.49791926722374, 69.60384722678893, 67.829955316359, 69.5097574110954, 66.93090884916245, 69.94212027518981, 35.68463340882332, 0.618059083579048, 2.1175295354858523, 2.3138399950919615, 1.4245859701787273, 0.018236219334686478, 0.03953304419654512, 0.9346286159369254, 52.986890731319306, 69.79230142408802, 53.53757581403179, 61.26158560475996, 104.73353585889264, 110.40045076800932, 35.47037786053073, 30.517012688421435, 59.6070396515631, 55.84511010877548, 58.49953489918863, 3.660834619114476, 0.1923185746155439, 0.10522514882106936, 0.03885886001010095, 0.08200172199717454, 0.03201501162332152, 0.04965548268369129, 0.053610622266968416, 0.01948690766678943, 0.01813152958939393, 0.040391514663614576, 0.10028192052437414, 0.05155517772260693, 0.04335040669708003, 0.04253234736801636, 0.08668633433239115, 0.06329244145402504, 0.03876769171667196, 0.04622440469721633, 0.03782170719557232, 0.09242659284462852, 0.03793122329478783, 0.045014824643130266, 0.10771129565734057, 0.05559423457710974, 0.1761076025544636, 0.364416993914112, 34.00256026175715, 96.82896367965206, 75.7723940572431, 70.65701930753647, 37.11887159655171, 26.545120631494832, 40.67916777826125, 57.35388117451822, 52.28372743052822, 88.49551954577046, 3.639682012219583, 0.15548298345698466, 0.5781674144729492, 2.205882884802357, 1.2480199865756498, 1.916760076438227, 13.113569001997671, 44.589143260832756, 84.42724504778462, 86.46096260316911, 85.30555002150997, 80.38124176763719, 78.29811019282188, 73.59652980681389, 69.01302060773297, 67.5742716943064, 64.67911143456736, 63.56901007313883, 63.83327191875827, 60.37960537018315, 65.25046348571777, 60.52121470051428, 60.75265807490195, 60.90444987820041, 58.57976305869318, 57.72334098815919, 55.24447364191855, 56.396057990289506, 54.85188361137144, 56.318881434779016, 58.88284852427822, 56.29284474157519, 54.480941141805346, 57.56671290243826, 53.967263621668664, 54.956669730524865, 52.9274982021701, 53.769317288552564, 53.19700425670993, 53.610018068744296, 53.47304105758668, 52.840900113505704, 51.99552735974712, 57.3078364710654, 66.01712995959868, 66.70672185959356, 67.16024198839742, 68.67482600673553, 66.2300048335906, 63.74716020399525, 60.5900836759998, 67.24341977027156, 65.2365469163464, 60.584686494642696, 52.46253259720341, 61.71019100373792, 65.39381434840541, 67.46669676996046, 65.40781720992058, 66.23009112573439, 59.28365199796615, 59.742914476702296, 57.487692832946784, 70.12332593241047, 54.155666828155525, 50.27663492387342, 69.39191372163835, 59.60975000935217, 68.00819566172939, 62.70590820620137, 66.31639895900604, 60.9919697238553, 61.841037350316206, 61.88087294178625, 61.0365435384935, 52.03559044868716, 53.194125237003455, 53.67246220188757, 56.96107541361163, 50.990890687511815, 48.11261623136459, 48.77386116212415, 47.50223659699964, 47.56562602135443, 46.289643702968476, 47.7410069588692, 49.6724408672702, 46.27093007487636, 46.325050938513975, 44.19164242282991, 45.705896962073545, 48.73727721552695, 48.38859811905892, 48.65293448971164, 49.2672953298015, 50.04948262245425, 50.30337764370827, 51.348897180249615, 50.82893602309689, 50.46670121531333, 54.11561942869618, 55.425616541216456, 57.38199280154321, 57.12759963927731, 55.99891801034251, 58.545705118486964, 59.68588713676699, 66.85446969924435, 65.47033979046729, 65.5633980228055, 70.04064236917804, 70.10158031217514, 72.14038125930294, 70.92102619909471, 71.94697703084638, 72.53859596867716, 69.79157970797631, 71.40601942616125, 69.20419692993164, 69.5403205194781, 44.70394711340628, 0.8683412954691918, 0.6116524434858753, 1.8249273396307424, 1.804752383501299, 0.477389406052328, 0.037155723980357575, 0.6244725265329885, 52.89629574744932, 77.82161281954858, 59.89430619824318, 62.976120287372225, 105.67077836682721, 110.27509966204244, 46.35955995129001, 36.80015156345983, 67.92466486653974, 63.792969565237726, 72.62760239262735, 6.599102462491682, 0.30501450562188703, 0.05962387621102314, 0.07935141017960926, 0.021475083945739656, 0.043785609755544894, 0.05700777404971662, 0.01381189015979368, 0.021619244456110943, 0.013119907835648667, 0.01779163552958879, 0.07660443338775828, 0.03221439175127495, 0.016629418861421368, 0.16126374503777874, 0.11778751989045452, 0.10689008770690811, 0.14077679194029302, 0.17884138731225846, 0.17821075905474926, 0.14299558175186958, 0.21533225422664998, 0.15780936265664716, 0.2427620936425463, 0.12542726276742835, 0.29446415723331515, 0.6027196131406293, 41.72700151320427, 109.3017791932629, 84.8379485837875, 83.70502687269642, 45.873307643398164, 26.840394696881695, 66.29866984582716, 86.37267005059027, 57.320501804351814, 99.6037660106536, 5.057188349385416, 0.3753889664526909, 1.049500864840323, 6.759559762093329, 5.978542806640749, 5.47986590093182, 15.855080216161667, 46.7782651224444, 88.15982741694297, 86.5129889211347, 89.99701069247338, 82.50017673738542, 83.63228259548065, 76.42165614712623, 74.13933877022036, 71.11019426776518, 68.20483976794829, 67.40423694733651, 68.55968875269737, 64.52063199012511, 68.96188859016665, 63.870954129003714, 66.09991550445557, 65.09993860798498, 60.87752672933764, 60.64615395761306, 56.70570558117282, 60.820734731612674, 58.29191207885743, 57.66559977685252, 60.47981408334548, 60.20238876342774, 56.562127221015196, 61.670029855543575, 57.28680079983127, 56.148909445731874, 56.193922565829375, 55.81243284286992, 56.69131832738077, 56.07489432058027, 56.21677037208312, 54.797280296202636, 56.75818689407841, 60.720325977571555, 70.27657293504285, 69.24490328757994, 69.2720696233934, 70.09056629673128, 69.18722091182586, 67.22291361901068, 65.09353337749359, 70.22138518671836, 67.40294256517964, 63.441560499129764, 54.68879145960654, 64.58291530609131, 70.49101675710371, 70.87089830829252, 69.38300994134718, 69.17732869425129, 62.75429456464706, 62.07622658821845, 59.51311849778699, 73.17834238852225, 57.49859702202582, 54.324677836510446, 72.09230869047104, 63.94491434097291, 69.08046184047576, 67.05531858628797, 68.62166220141997, 64.17095268926313, 63.54941783412811, 63.64384889602662, 63.5778550178774, 55.30787483338387, 58.202478116558446, 55.96191829250705, 61.3682113155242, 54.660593540437766, 51.68813513171289, 51.29750236388176, 50.39887166792347, 50.73716825054538, 48.369904102817664, 50.39255272957587, 53.27557717600177, 49.52554418194679, 50.33146965888239, 48.60959229930755, 49.61465650989164, 50.43534186578567, 51.58855399777813, 50.5716363845333, 52.450126140348374, 52.598254449905895, 54.13838878754647, 55.75415034447947, 52.98252121094735, 53.00640060055641, 57.972689982383486, 59.38388816771969, 60.59959934603784, 58.980872477254565, 59.113817291875044, 61.43289119966569, 62.13478365252095, 68.33646666619086, 67.93992288651006, 69.4380957080472, 71.90687471820463, 71.68125214115267, 76.15423679351807, 75.5678895211989, 75.97988743935862, 76.43635719053208, 73.3086827493483, 73.69537353515625, 72.37315039480887, 72.02041164521249, 45.81196177390314, 0.513979266848295, 7.900995958235956, 8.34118297023158, 3.5389950150443665, 0.7557356249420875, 0.11669877871510484, 1.5296079218387606, 63.13224630971109, 82.64820698768862, 72.71380039953416, 70.73873012296616, 105.18956630460679, 117.77170611966042, 49.12271676524993, 44.429902876577074, 77.73073934739637, 72.1909406108241, 84.88630356327181, 7.366533308259903, 0.5279616891376434, 0.3447860521414588, 0.13889200114194425, 0.18545174550625587, 0.11273446522893445, 0.16323700366962343, 0.20640210518913887, 0.10356078450117381, 0.11351949084670314, 0.16089919443813064, 0.14771379470344514, 0.1742313306538328, 0.19446058709534908], [0.09235470315381404, 0.02025235590765313, 0.10665606316779891, 0.07780203565714822, 0.027091092572757797, 0.09457997406923002, 0.06042218579339886, 0.056410432312517404, 0.05331174838506887, 0.059515815678863764, 0.05014147737153596, 0.06354372978450791, 0.14950746700408, 48.647180372668856, 78.89637362572455, 65.61879757911929, 58.19877932148596, 31.713594467409198, 32.27793920424677, 50.59570404791063, 31.270970682944025, 71.775679280681, 62.233756819079005, 0.5531751749015624, 0.21770465998880326, 0.2177926681695446, 2.1376118256199748, 0.7109294098711784, 4.267960892569635, 15.272360155659339, 52.64787243258569, 74.09806759126725, 85.77196690344041, 84.00384872190415, 84.31744221718081, 76.38304433514996, 72.82150083972563, 65.67193785021382, 66.01469024535149, 58.783298769304835, 60.03323654974661, 57.795908758717204, 57.79336314047537, 56.30382737805767, 59.28263610409152, 55.84418442941482, 58.92614756861041, 58.46171932835733, 55.572646587125725, 53.6312420137467, 52.885218974082704, 52.99372742252966, 55.288482635251945, 58.01113313244235, 56.937909895373934, 53.385207422318004, 54.663825573459754, 50.785150604863325, 50.89400029951527, 49.36816300115278, 51.53370749565863, 46.932386813625214, 48.91762387367987, 51.15655983647993, 50.749570785030244, 49.37671376812843, 57.918471059491566, 65.20212419571416, 66.80577739592522, 58.59535055775797, 64.49800383660101, 64.33721803849744, 65.88620908798711, 63.74653262476768, 64.89149993465793, 64.53963195123981, 65.63533429176577, 55.81756330305531, 55.17296098893689, 59.68937020148001, 66.73092288355674, 62.17481144012944, 64.31365636087233, 59.70376137764224, 65.21033371648481, 56.48266000132407, 70.85365556901502, 37.09209749775548, 33.35521228851811, 70.22517419630482, 55.247321282663655, 67.82837852354973, 58.989737033844, 66.38528362397226, 54.19525923267488, 61.16259674872122, 58.65826929769209, 53.58802926155829, 47.303278292379076, 51.55349977554814, 52.605710875603464, 49.58042990776801, 44.405890126382154, 46.30591761681342, 45.367769041369044, 46.3783912504873, 44.45280559601323, 46.3108362690095, 44.36479153171663, 46.222967332409276, 42.93706055610411, 43.55366106956236, 41.712767231848936, 41.72171415821199, 43.36905863977248, 46.098400700476866, 46.32013620868806, 46.315656861951275, 44.342665441574596, 48.73826957518055, 50.18417681417158, 49.297073964149725, 47.7164529215905, 52.63023353392079, 53.053763220387125, 58.0652500737098, 57.14712912036527, 58.87454878899359, 59.0352600620639, 63.9943479722546, 73.13743206762499, 67.61529968630883, 63.74758381997386, 71.20060490023705, 66.00207590287732, 69.71762734074747, 69.58412554956251, 68.56452895749, 69.03311883249592, 73.12702209718766, 64.29735891280636, 67.81763907401793, 62.4954338227549, 72.50419678226595, 23.957766409843202, 0.11555247369312471, 2.3911989408154644, 1.0322028446582057, 0.2707677400640903, 0.16172644682228565, 0.14659034208424632, 16.307845288707366, 76.16492132986747, 55.11399207576629, 43.37009414549797, 51.143070805457334, 37.605610278344926, 16.93504894933393, 34.188633580361646, 48.646772446170935, 57.174738684008204, 68.2328062672769, 18.993548039467104, 0.626929339862639, 0.12014793637659281, 0.06967724421091619, 0.10315389222195072, 0.04250349649678796, 0.07867825638142326, 0.04268502486088584, 0.06633766776611728, 0.0518070214668349, 0.042876769007454, 0.06321559517434047, 0.025779335541770827, 0.059019999743829814, 0.044807034784988056, 0.036132276478794315, 0.0778948318874163, 0.0025711892991356795, 0.0681858319008062, 0.03985224239107582, 0.037601732708994424, 0.04841579920462063, 0.04228261036558017, 0.09133160805269595, 0.009416416644178813, 0.058434425117147554, 0.1329001670162524, 60.50884354499079, 88.68031024932863, 71.95857155707576, 68.21826211867794, 48.550466491330056, 36.150905163057395, 32.95388321722708, 36.537474355389996, 77.87287819770076, 66.79958005105296, 0.2067493728452152, 0.28934852851013987, 0.8718229505804278, 4.828194985466619, 1.784908254781077, 3.8448307975645992, 20.88377941039301, 56.246372499773585, 81.27404382151943, 86.1923743832496, 86.26973921252836, 84.37015102755639, 79.5161630261329, 75.33652459421467, 70.14837418833088, 66.05818933056247, 63.258303442308986, 63.077529245807284, 59.73791345473259, 59.26729963671777, 60.22084743745866, 61.10418873448526, 59.16345096403553, 61.85721320490684, 62.65497230714368, 58.81260279686221, 55.85910904792048, 55.27831977413547, 56.38210611958658, 57.141990815439534, 59.71223761958461, 59.504877598054954, 55.918442741517104, 55.04951223250359, 52.84871739725913, 52.91430334891043, 52.015311794896284, 54.700586026714696, 50.71427337584957, 51.931498589054236, 52.48256414167343, 53.38559181459489, 51.307869188247196, 62.6920896960843, 68.20924066728162, 69.61976420494818, 61.76852057057043, 65.49916136649348, 67.80532283167686, 66.8324887367987, 65.9025889058267, 66.26272524556806, 67.00859531279534, 68.72907238621866, 60.49663320664437, 57.72358809748004, 63.818037433008996, 68.64013656493157, 65.74805144340762, 67.34757438782724, 63.961125496895086, 64.25387551707607, 61.34967027171966, 71.78250420478084, 49.43941677770307, 40.92113487182125, 69.16212558746338, 59.293199046965576, 68.33389359135782, 61.44107326384514, 66.23599037047356, 58.89516476661929, 63.951876548028764, 62.23962468485679, 56.80761268061977, 48.38569164276124, 53.19324270371468, 55.662182531049176, 53.30394767945813, 48.26205461255966, 48.55463597082323, 47.93573302607383, 49.74633832131663, 45.68346492705807, 48.71204853057862, 45.99088853405368, 49.54351648207634, 45.90156439811953, 45.60688457181377, 45.79247936125725, 46.1510742095209, 46.16152340365995, 49.21262533433976, 50.20643626489947, 48.05383951433244, 46.274758308164536, 50.19794433347641, 52.41340491079515, 52.959900902163604, 49.59697446515484, 54.97501857819096, 58.193209555841264, 59.04217127830752, 59.5314516559724, 61.830792119426114, 62.269320949431396, 66.53230974751135, 75.97798901219522, 71.83194960317304, 66.60612875415434, 73.01349301492014, 68.91274913664788, 73.91437515135735, 72.48532233699676, 70.45857091103831, 70.0645060693064, 75.4118105673021, 66.16017095504269, 70.28695937125914, 66.63870011606525, 74.64432039568501, 30.120559123254594, 1.1166990332065092, 0.3644005996325324, 0.9251578692947665, 1.0007601447643772, 0.2799104172135553, 0.19709323292538045, 14.896440198344571, 80.01571609127907, 63.23343953778667, 50.88654779618787, 53.50179203094975, 53.00993073371149, 19.253575686485537, 43.943191651375066, 57.70885567511282, 63.317939158408876, 77.175049320344, 27.449048488370835, 0.6992489592202249, 0.18675202654013712, 0.05213863411617856, 0.10418724524037493, 0.11951404458452618, 0.08175644362645765, 0.06181343593784879, 0.006648214428775734, 0.009369994588797132, 0.043850535707127665, 0.039451547763160164, 0.02861080034035108, 0.04824925552032167, 0.12652161936726303, 0.1479586210822867, 0.2521450772520996, 0.11904225699723729, 0.12596317957485878, 0.2403317869550759, 0.15990239147457386, 0.12703795496734882, 0.1495699491351843, 0.1813919851255994, 0.10860091525941126, 0.1609006193616698, 0.8941922276731461, 74.95665873250654, 101.20943530913323, 82.81036561535251, 75.92200894509593, 45.753161522649954, 46.02375015135735, 66.71324083881994, 47.54692416037283, 87.79790247640302, 72.37584898548742, 0.7372414657185156, 0.6844011946551262, 2.3709001848774576, 8.2725130550323, 5.300624370574951, 9.961416029161024, 22.655665028479792, 60.3561064504808, 82.64872474055137, 91.14227218012657, 88.8774642636699, 85.20426657892044, 82.26328126845821, 79.56431404236825, 71.91520583245062, 69.8893722411125, 67.03990367151076, 68.89215669324322, 63.02576180427306, 62.58682112539969, 63.578031524535156, 67.30143946986045, 63.41238983215825, 66.44678638827416, 65.80887563766973, 61.50457643693494, 58.26860535529352, 59.06059465100689, 57.16314808014901, 59.77090058788177, 61.1025256495322, 62.04376505267236, 57.93371338998118, 58.01316492019161, 55.34270940288421, 55.2228182361972, 55.71829988110451, 57.35563447398525, 51.929007883994814, 52.94798866395028, 58.07669162750245, 56.26995771161972, 54.363438698553274, 66.49465499385711, 71.83387940929782, 71.41818661843577, 62.56829969344601, 67.21833229064941, 69.1993881041004, 69.25750978531377, 70.05197017423569, 68.1520603549096, 70.99628079322078, 71.36031596891343, 63.102738318904755, 61.3721925212491, 66.67213439941406, 70.29449032198998, 68.86724964264901, 69.36374325906077, 66.06350806451613, 68.72461657370292, 63.68756763396725, 72.64532366106587, 53.10163574834024, 44.40675304782006, 72.69072117344027, 62.120157134148386, 68.95725234862297, 66.63192226040748, 69.3686854454779, 61.67379925327917, 65.61086262426069, 64.52313838466522, 59.59728863931472, 51.48186552909113, 57.82188661636845, 60.31590215621456, 56.73721005839687, 51.140642858320675, 52.44603510825865, 50.99198502878989, 53.02005829349641, 49.88885371915756, 52.16826854213592, 48.16392867795883, 52.68259325335103, 51.216270077613096, 48.22609040044969, 48.299779968877, 49.9557654319271, 47.99598847666095, 51.399613426577666, 53.19429389892086, 50.920464531067886, 48.09865651592132, 53.689191110672496, 55.276331132458104, 54.9982350872409, 51.991922701558764, 59.537464649446555, 59.97606408211493, 64.11601989499985, 63.51268483746437, 65.16795642914312, 64.92711505582257, 69.0203397504745, 75.41543483734131, 75.78660088200724, 70.03715930446502, 79.05197405046033, 71.51538295130577, 78.33009319920694, 77.22783657812303, 73.05262257975917, 74.16992541282409, 78.78390358340356, 68.36524901851531, 73.95801544189453, 67.85740406282487, 75.25649255321872, 31.25041746324109, 1.9509720922477785, 8.824887698696507, 7.593694435011956, 2.2574012558306418, 0.5228328837021705, 0.2419683652659578, 20.005645059770156, 88.92374823170324, 69.45267908034786, 58.22964053000174, 60.978778792965805, 48.41770995047785, 25.487014209070516, 50.084701584231475, 67.1411322009179, 74.45537197974421, 88.6584940264302, 33.839472032362416, 1.005196958299606, 0.3613251549822669, 0.11159071127974218, 0.1517129115640156, 0.25214225804853824, 0.1593265538254092, 0.1319859023656576, 0.11825759144079302, 0.1256289200917367, 0.13954018813467797, 0.12218293403425526, 0.1589734792228668, 0.17217447650769066], [0.048362536941685026, 0.0419084913277578, 0.0690731608999833, 0.010223618592135608, 0.0698719148133551, 0.14912129740320867, 0.07929946941834304, 0.05732891810757499, 0.11596616117223618, 0.02143644630127857, 0.06878110520060986, 0.09822102143399178, 1.5689648615737117, 60.19393997807657, 73.30132438290504, 66.75309996451101, 37.409613363204464, 16.28895123158732, 33.383033660150346, 65.91408145043158, 41.75408940161429, 90.76848599218553, 30.96212325557586, 0.08803002956894138, 0.6795273432808538, 0.5111367129270108, 1.6619482011564317, 1.1368483713557644, 7.877864760737266, 25.528605061192668, 68.42033478521532, 84.19769225582, 84.25152286406487, 82.825741306428, 75.3927243140436, 73.16872473685973, 68.95563633211198, 66.13981385384837, 61.58683638418875, 61.02905573383455, 59.135049081617794, 55.019761054746574, 56.52127181330035, 57.21417811609084, 60.07833203961773, 57.993996297159505, 57.51278423493909, 58.20754581882108, 58.70967588117046, 55.22182195417343, 56.264293809090894, 50.92147650257234, 54.85457043493948, 53.65377210801648, 56.676017161338564, 53.17702370305216, 54.207567630275605, 52.14548349380494, 52.205860537867395, 49.032851342232, 52.33904461706839, 48.00411955002816, 48.99991912226523, 50.6878601351092, 52.26894401734876, 51.02812574755762, 58.518515248452466, 64.35601011399301, 67.55689559444305, 63.65056399376162, 66.84606798233526, 61.97832815108761, 64.61774595322149, 57.00302516260455, 63.80925132382301, 64.13758116383707, 66.31986633423837, 59.07207935087143, 60.344151066195586, 57.24853807880033, 68.24749162120204, 57.56939580363613, 67.88083630223429, 57.700006808004076, 68.27247711919969, 51.51432706463722, 85.06579906709733, 19.256890089281146, 18.38567283845717, 74.51999695070329, 52.79817373521867, 65.22822364684075, 52.728261409267304, 60.73777268009802, 54.430099379631784, 64.42400832330027, 52.67275202658869, 53.46978156797348, 47.56996024039484, 51.46844710073164, 49.457534205529, 52.72557850806944, 45.52802924186953, 44.61419936149351, 44.83895901710757, 47.46295798209406, 44.29680508951987, 49.1282473071929, 42.64488712433846, 45.84113244087466, 45.061628049419774, 43.51536696957004, 39.31656775936004, 41.10441154049289, 42.790105035228116, 45.4584660068635, 44.2802526873927, 46.904996902711936, 45.18941494726366, 47.867860332612075, 48.08225316386069, 48.66217951620779, 48.31722667140346, 53.18338186510148, 55.41826601951353, 61.04931869814473, 57.96088364816482, 60.42477930745771, 61.01157372997653, 70.58318461141279, 71.522717783528, 65.20807835363573, 67.23994455029889, 66.79203341084143, 68.68110964375158, 66.03928350633191, 66.78955447289252, 68.44422201956472, 68.39963251544584, 69.8775266831921, 69.22502471554664, 66.2710642045544, 69.96080644669073, 70.69214021005939, 66.57916638158983, 15.580572159059587, 0.7848685391006932, 1.6759516755419395, 0.5393295146284566, 0.1039847682019876, 0.04792032417871299, 1.2593490173739772, 52.75015607956917, 76.47558873699558, 50.693728000886985, 41.365872813809304, 40.36617048325078, 36.64620637893677, 23.632054751919163, 34.97921866755332, 49.78127879481162, 57.77170381238384, 45.22506536975984, 0.8556322645275825, 0.14235617412674811, 0.06959164154625709, 0.00911617721055424, 0.053528892176766554, 0.04115164242384415, 0.07232837574256044, 0.04810245392183143, 0.0661928618266698, 0.07570942052670064, 0.018534217961132526, 0.0202246273552338, 0.08450647710912651, 0.044980948235118584, 0.025148952432397394, 0.024089713303011753, 0.03798961834681611, 0.035423821349057465, 0.01778415085056857, 0.0325900812693421, 0.014198797120292102, 0.12703592483434947, 0.0598353241390038, 0.1103588802018954, 0.1343123122088371, 3.4890735389724856, 78.40261782369306, 80.45080108027305, 74.68697224893879, 41.498817628429784, 26.246830263445457, 31.002198111626413, 51.42697195852957, 47.84491054473385, 98.32252379386657, 32.30305414046011, 0.18006401767413463, 0.2620743581604573, 0.5927873751328838, 2.116599443458742, 0.778840407729149, 10.98379260109317, 31.36762965110041, 73.37067973229193, 87.40950153719994, 87.8559535549533, 81.54690742492676, 79.24511155774518, 76.42232295005553, 73.83967753379576, 69.86028394391461, 66.33757975793654, 62.910765755561094, 60.80482559819376, 59.663282517463934, 59.39265466505482, 60.29867902878792, 62.65698840541225, 62.21272507021504, 60.464136369766734, 62.00370980847267, 62.30418297552294, 59.24323589571061, 57.008940096824404, 53.090613888156035, 56.96684914250528, 55.288870949899, 59.92081357586769, 55.11045017550069, 57.71818307138259, 53.18348776909613, 55.91677573419387, 53.209371489863244, 54.05369697078582, 51.99334259956114, 50.419138554603826, 52.95810445662468, 52.65436395522087, 54.25132951428814, 63.625421600957075, 66.51241548599737, 69.36117018422773, 66.43469764340308, 68.19071923532795, 65.27533131261026, 66.12450092069565, 61.417386070374526, 66.23348789830362, 66.05754606185421, 69.80135425444573, 63.85372315683673, 62.150786922824004, 61.72306814501363, 69.76385639559838, 62.21809871735112, 66.48474708680185, 62.85544072428058, 66.9338192478303, 58.87663548992526, 78.48974935470089, 37.88702464872791, 32.12121305927154, 71.9214580905053, 59.254889257492565, 64.65047420993929, 56.60387692912933, 60.63155881820187, 59.0026298646004, 64.87808150629844, 55.85854422661566, 55.413335600206935, 50.521669310908166, 52.374585213199744, 52.604036023539884, 54.65110140462076, 49.54647787155644, 46.76912599994291, 48.19446432975031, 49.28645218572309, 48.60741146149174, 50.44825038602276, 46.82636514786751, 48.87052797502088, 46.176832414442494, 45.559690613900464, 44.33034919923352, 43.82712479560606, 46.12567294028498, 48.687635698626124, 48.20325436130647, 48.311888325598936, 47.50258961031514, 48.394681715196185, 50.479703872434555, 50.041484909672896, 51.64156483065698, 55.4844795503924, 58.563018460427564, 62.715525857863895, 61.85936266376127, 62.98238823490759, 65.53033636462304, 71.97312355041504, 74.08633970445203, 68.7632126961985, 69.64360437085553, 67.46351180538055, 71.92654148224862, 67.06433219294395, 69.36891294294789, 70.5760145187378, 72.2477129966982, 70.78512391736432, 70.18384025942895, 68.05975129527431, 72.81578202401438, 72.48092928240376, 74.01005744934082, 20.13710133491024, 0.2355503870715057, 0.29008256331566845, 1.9426984652396173, 0.4065749349613344, 0.05416271502092, 1.0729402135456763, 54.6387969293902, 81.37384460818383, 59.45684425292477, 45.758958785764634, 39.47853419088548, 33.211512334885136, 36.242382680216146, 44.03802671740132, 57.70502744182464, 63.46048985758136, 57.96779486440844, 1.3971310950094655, 0.08401871658861639, 0.04344648178366404, 0.04027149549895718, 0.11906641941036909, 0.06199831976705502, 0.036266954735882824, 0.020557879432735425, 0.051649234167510466, 0.013875179556048205, 0.062478162768867716, 0.05022543294715786, 0.08095061872154474, 0.14919504102679992, 0.07212055141046163, 0.2562227334466673, 0.13245701579557312, 0.1423661026262468, 0.28850273679821725, 0.18166218433649312, 0.2049210427268859, 0.3030495207396246, 0.17356117225943074, 0.23695997353042328, 0.2900470474794988, 6.30795669171118, 94.02939550338253, 90.65085411071779, 85.19720631261026, 53.30792496281286, 25.859972776905185, 45.686214508548865, 89.63618401558169, 57.49975804359683, 105.49790382385255, 37.491065302202784, 0.24354816113989203, 1.163055810236162, 2.835192858211456, 7.370588058425535, 2.803287808933566, 12.942534050633832, 38.216907747330204, 73.13183092301892, 88.93087125593617, 88.94307767191242, 90.11409344211702, 82.68954876930484, 80.68102067516696, 75.68449374168151, 73.41854049313453, 67.87789452460505, 68.66722445334159, 64.52969266522315, 62.66773177731422, 63.609198677924375, 64.50844518599972, 65.22571725230064, 63.45387281910066, 63.63237988564276, 66.69337795626733, 64.84694180950042, 61.73846344793997, 60.9140439956419, 56.32862067991688, 59.15076209652809, 58.15417412788638, 62.679424362797896, 58.45753415938347, 61.314396396760024, 56.96794740615353, 58.20527476649131, 55.45909397063717, 57.5623865281382, 56.140350834015884, 53.37625265121461, 55.752659843813994, 55.854531641929384, 56.88946862374583, 65.43992965452134, 69.99660199688327, 72.5492020576231, 68.55324037613408, 69.10317236377348, 65.58645371467837, 68.9098544274607, 63.04331833316434, 69.27780412858533, 67.74763261118244, 71.52296097047868, 67.58427373824581, 64.96862942172636, 65.41070799673757, 73.14709678772958, 64.0547760071293, 69.8718314017019, 64.95987469150175, 70.83887607820573, 60.176591334804414, 83.68805085459064, 32.19787186191928, 28.595329792268817, 74.69875504893642, 61.74998344913606, 70.33046630121046, 59.86517475497339, 63.767905619836625, 61.29633388211651, 69.97928081020233, 58.406625716916984, 59.456938389808904, 53.21958926416213, 54.47027229493665, 54.78167710765716, 57.973564670931914, 52.2277081397272, 49.79409710053475, 52.3300741564843, 53.6631348056178, 51.905740384132635, 52.90057113093715, 48.78892306358584, 51.28128336321924, 48.65289918838009, 49.008701309081054, 45.77842943130001, 47.07942470427483, 49.33461104669879, 51.75080283995598, 50.82181692123414, 52.752736999142556, 49.75437918016988, 51.51513507289272, 52.323041346765336, 51.52673744386243, 52.73549033749489, 58.69040919888405, 60.9890789370383, 67.10126523048648, 65.37207265054026, 65.31588077545166, 70.79037204865487, 73.40664002203172, 78.4667956444525, 73.39367266624205, 71.35206330207087, 72.14583335384246, 74.3235646524737, 71.78459875045284, 73.2564446233934, 74.21071806261617, 74.80503559112549, 74.93196348990165, 74.75124420658236, 72.22356688591742, 75.60523832997968, 75.23182084483486, 73.28022203137799, 20.828876033906017, 3.1682214525438126, 7.530185378366902, 3.5377141160349694, 0.5818755864616364, 0.18174915063765743, 1.8743322885805562, 67.17462139744913, 87.96752145213466, 67.22893837959536, 58.77468524440643, 54.89351172601023, 49.167482776026574, 38.47223051132695, 52.352278694029785, 69.1578737381966, 74.67860191099106, 68.0777314401442, 2.0301998022102543, 0.31090173810239763, 0.22538436967278683, 0.1910526602859459, 0.17396600376213753, 0.13146830272049675, 0.2084604761893711, 0.08903359708886954, 0.21161069102104635, 0.13549830824617418, 0.08032150731812562, 0.20649754442274573, 0.10964838727827995], [0.029653200857161038, 0.07278626649490288, 0.028641700496776935, 0.07806753108818686, 0.26213589034253554, 0.049431980362222086, 0.03041729120717895, 0.04178473748446953, 0.10415397404182343, 0.05634740242854722, 0.26861316374232697, 0.28096369617889005, 18.600763851596465, 76.67838311964466, 62.15103403214486, 60.26935931174987, 47.622653361289736, 24.412622105690744, 37.6229706887276, 30.780156658541774, 48.15301272176927, 95.39581591083159, 9.148680337013738, 0.03388602241513229, 0.08082665037363768, 1.6088595337444738, 2.564563044617253, 10.25034958316434, 10.022060774987745, 46.44136882597401, 77.27885092458418, 74.7902717897969, 70.66548378236833, 76.02570072297128, 73.13445106629403, 72.65196815613778, 67.00305692611202, 64.25218105316162, 62.7073359489441, 55.537082456773334, 57.49126611217376, 56.75524903881935, 57.77677151464648, 56.842886555579405, 57.92167955829252, 56.42145141478508, 59.725997294149096, 59.969196011943204, 56.38233753942675, 58.119735717773445, 57.574408592716345, 51.94614079690749, 53.714780653676684, 53.96787943378572, 51.34342939622941, 54.62884195389287, 53.84853347655266, 52.03388029529203, 50.47841733501804, 49.799188337018414, 50.39825977817659, 46.76649016718711, 49.97620882526521, 50.96078649643929, 51.874608532074966, 50.68082732539023, 56.553623522481615, 61.95377803617909, 68.81923198699951, 61.657568485506125, 64.13017965132191, 58.84066735544513, 59.75755276218538, 56.72929471538913, 61.265974736982784, 67.64533719708844, 68.00290046199676, 60.2830130823197, 65.37856025080528, 58.80052974147182, 71.4561394722231, 60.533503486264145, 58.83437195131856, 52.097803161990264, 68.37441951997819, 49.40756713190387, 80.15375214238321, 11.827769971662953, 9.990146410080696, 79.86906651527651, 49.033180821326475, 64.16699894012945, 53.48147415345716, 65.22104570942541, 55.8157786246269, 61.66572701546454, 49.79259091038858, 51.87492232168875, 46.40928383796446, 51.27339939917288, 51.63299445183047, 54.468715113978234, 46.10554333656065, 45.57686275051486, 43.39067089942194, 46.729627732307684, 44.55768585205079, 50.92267674784507, 43.91682155670659, 47.843596550726126, 45.91092709572085, 43.56868374732233, 41.43084687571372, 39.05536928484517, 41.50723503481957, 42.745123294092, 46.42919378895914, 46.17958591830346, 43.625083508030066, 47.199359017033736, 47.452842189419655, 47.305027669475926, 49.205651360173384, 51.531918894860056, 55.767651142612586, 62.7434649006013, 61.06976601385302, 61.6251265618109, 64.45872129932528, 76.1912404337237, 61.44415232443041, 67.45790281603414, 68.02055112777218, 67.03262375247094, 68.26017656633931, 65.61686385062434, 64.55989491554999, 66.02912456758561, 68.33034776872205, 68.63166424535936, 62.81208676676597, 68.26819389097153, 71.44119524186658, 70.5223721842612, 74.47340703779652, 61.03411166898666, 4.412078578625956, 1.1806122165533806, 0.9603528065546867, 0.7538275757143575, 0.3069381830432723, 0.31664647822899206, 17.864658524913175, 75.95223472964379, 63.706610741153845, 59.24637771421864, 50.34730426726803, 31.757997658944902, 18.120318612744732, 26.514002507732762, 54.537529176281346, 53.62073006168489, 63.709003386958955, 14.782421800398058, 0.48897326833778815, 0.13752873235892865, 0.038495918195093834, 0.017485234833833192, 0.17126428744485303, 0.061458174154282584, 0.04044350139015625, 0.03057461885374881, 0.07159467801571855, 0.037309581248630444, 0.025001432626478137, 0.08696979452525416, 0.06282380248810496, 0.025993045344347918, 0.14427857984217907, 0.004540384792151951, 0.14061683278170325, 0.057053995964628075, 0.03425600840860317, 0.0741412002413023, 0.08865725639606677, 0.052954069594101566, 0.2022715276407619, 0.17663223488676935, 29.42131034789547, 91.73167105643981, 68.11849271097492, 71.58346745275682, 62.321421792430264, 28.872623712785785, 23.530106467585412, 37.85983085632324, 56.03958906665925, 100.91109198908653, 9.176985140769713, 0.07282708365950855, 0.5220249367337073, 3.179138634474047, 3.968929196557691, 13.628269280156783, 15.579045376470013, 50.64754209210796, 77.07675472382577, 79.42681927834788, 75.24394096866732, 80.59499525254773, 76.60062605334868, 74.69102797969695, 69.76551163581111, 67.44420589939241, 65.41649349274175, 59.0686825783022, 61.80935244406424, 59.64461595781388, 61.64761351000879, 59.463943742936664, 58.513239660570704, 59.03215354488742, 62.23205843279439, 61.73692587883242, 59.6317623507592, 59.327719826852125, 59.72465584355017, 55.72767042344617, 55.59294485276746, 56.68261851033857, 54.18179373587332, 58.08367344640917, 55.39288436212848, 55.650129087509654, 53.29275323498634, 52.28009923811882, 53.72080149189119, 50.432831548875384, 51.81805187656034, 53.62091049071282, 53.28181374457575, 54.724206539892386, 59.572087410957586, 64.30239523610761, 69.94960415747859, 66.09039983441754, 65.84214518147131, 61.50272507821361, 62.21839289511404, 59.63749685595113, 63.430934798332956, 69.56175235009962, 68.00769359834733, 63.848651532203924, 67.49897787647863, 62.844050161300174, 71.91535488251718, 65.5335880094959, 62.25134864930184, 56.37486542424848, 66.74894225212836, 56.525456982274214, 73.02298515073716, 20.705809708564512, 20.26789080712103, 73.5115320451798, 56.29175432266728, 65.21045138758998, 58.58794120050246, 65.75247195459181, 59.94131188238821, 62.915256869408395, 54.77301651431669, 55.02436983969904, 47.81594776338147, 53.24736748972247, 55.77181669973559, 57.40993968902096, 49.08350090826712, 47.67903351014661, 46.03512110248689, 50.321616665009536, 47.27860266162504, 52.42426987617247, 49.51338875678278, 50.97076892852784, 49.57842165423978, 45.72760728097732, 45.05120631187193, 42.21886281044253, 45.45455932617188, 45.70504580774615, 49.0206527709961, 48.73732428396902, 45.82816116271481, 48.742066429507354, 51.54637282894504, 49.70834232145741, 49.47577322683027, 55.35651222352059, 58.41330551332044, 64.53117139877813, 64.12122095784834, 65.58706168205508, 66.79863083747126, 75.89322659277147, 66.31073505647721, 68.81876130257884, 71.20513131541591, 70.36684236218854, 70.60776218291252, 67.02768156605383, 66.19856311428931, 68.16653390084544, 70.70811210140106, 70.20866886261972, 65.55644366048998, 69.19251611155849, 73.16030733046993, 75.73581403301608, 75.48273486475792, 68.1814310627599, 7.183295863289987, 0.6830250555949827, 1.7812630245762489, 1.590152279503884, 0.4484626921194215, 0.2868007958656357, 15.708155093654511, 80.39470334206858, 67.4125131484001, 64.87754021921467, 38.88346748967325, 33.44651722138928, 28.890894113048432, 29.6962861476406, 63.250619519141416, 57.53965639298963, 74.89568941054806, 20.40757621488264, 0.46051061982589386, 0.09942242349948614, 0.020892282557343284, 0.07102492310467266, 0.07046980047298056, 0.056886283996244597, 0.06374285901866614, 0.02337817275415986, 0.04037166532549647, 0.038934469057787816, 0.06056912145727585, 0.04157022137435214, 0.14650343707011593, 0.0973331408515092, 0.19285512727595147, 0.1923696880018519, 0.3611006299334188, 0.2262228529059118, 0.17451685162321215, 0.12926356296145147, 0.25317151249656755, 0.2403538196437782, 0.3225032816971502, 0.42301199489062835, 38.01957722633116, 107.57930955579205, 79.73911054672735, 83.09975808666599, 62.89815141308693, 36.19826778288811, 53.657816071664136, 51.804421640211544, 61.575991030662294, 113.55795875672372, 11.260930607395789, 0.1606131525289628, 0.5399836924287581, 4.782299822376621, 7.572901460432238, 17.371816635131836, 21.787348370398245, 51.448878395941954, 79.66060038535826, 81.74807794632451, 79.66883736272013, 85.41186194266044, 81.0525397331484, 76.98255508176743, 74.3837808793591, 71.79413795471191, 69.68097671385735, 63.16886555763983, 65.85923887068226, 63.27836636574038, 64.7040851654545, 62.615991792371204, 64.37415499841013, 62.5377679640247, 66.80915847901376, 65.5284575493105, 60.881154921747026, 64.05946323948523, 63.032119966322384, 57.22030093592983, 58.727534432565015, 58.270044865146765, 54.51177097135975, 59.280596471601925, 59.1485930258228, 58.7717709233684, 56.515560842329464, 55.66625395128804, 57.29574772619433, 53.497277382881414, 56.08253117530577, 56.41685047457295, 56.67243995974141, 57.29300598944388, 61.3355536614695, 68.4918866618987, 75.9613738521453, 66.94327215994558, 70.65692517065233, 64.3992228661814, 66.61191817252868, 61.87549537228, 69.01782943356422, 70.57810906440982, 68.80132244479272, 66.84794287527761, 70.49638255949944, 66.32715409801853, 76.16984782680389, 65.06540213861774, 66.17626051748952, 56.59906025855773, 74.03929479660528, 56.54274286762361, 82.83399397327055, 12.843134326319541, 14.211135448948031, 81.50785630749118, 56.030438177047245, 69.32431559408866, 58.40884185606434, 70.3322470572687, 63.85684144112372, 68.42792064912858, 55.297649214344645, 58.37848271093061, 51.19939996350197, 56.46920627163303, 56.213193170485965, 60.25453667486868, 51.5955005153533, 50.164219794734834, 48.73422561153289, 53.08611492956839, 49.815085703326815, 56.245215400572754, 50.4982017701672, 53.71916194115916, 52.79057218182472, 49.971384309953265, 48.62503074830579, 44.688143883982015, 48.19973991763208, 48.860298433611476, 51.77774560066962, 53.95354709317608, 47.95955750250047, 52.25803198352937, 52.897037075411895, 50.79421520233155, 53.111351459257065, 57.60293991334977, 59.75991795139929, 70.82569691442674, 66.6756017746464, 68.34532337803995, 67.667020059401, 80.1228517101657, 71.72265668069163, 72.71813854094475, 76.54714061367896, 73.00737411745133, 74.19317722320557, 71.24106022619432, 69.67277111545687, 71.02677329894036, 76.18899683798514, 74.3793878247661, 68.06956506544545, 72.99328496379238, 76.34979048082906, 78.50174396268784, 80.66766108236006, 71.6114810205275, 7.065006004225824, 3.5396701530102765, 6.514210114555975, 1.7427348081142673, 0.9495962579404155, 0.5020200521234544, 22.519978477108864, 90.44663198532598, 74.28200321812784, 76.29713658363589, 65.92654674283921, 42.6819888237984, 30.927322026221987, 39.92359376722767, 74.23162429563462, 68.75117886450984, 87.03362864832725, 25.414005171868112, 0.5811675986455334, 0.3021454144149058, 0.18126159696088684, 0.1611192302117425, 0.2144494757897431, 0.2573410992420489, 0.2058842757176007, 0.10937579021218324, 0.18431563711454793, 0.11928709869783734, 0.2583025702305379, 0.2077252769301976], [0.06261138162846047, 0.04963137389671418, 0.04274678303890171, 0.04341808290431096, 0.18918138327858142, 0.14284193515777588, 0.05437178424589577, 0.01965202642754922, 0.0573196675958893, 0.08750272358977988, 0.14762583248797925, 0.3554388418072655, 44.33170241694297, 74.4115355706984, 63.510378483803045, 48.225152953978515, 19.33737712521707, 30.791427589231926, 54.03735245427778, 42.83680085212954, 80.41116945205196, 65.10806183661184, 1.0096286237239838, 0.07176173114848715, 0.5174023621985989, 3.009019801693578, 2.3850797981985155, 8.998609473628383, 18.564711386157622, 51.58170553945726, 75.77428463966616, 75.2180847044914, 79.01914381211805, 78.3512818428778, 73.58298978497906, 67.75889765831732, 63.47166469020229, 61.17492475817281, 61.856228689993586, 57.84611509692285, 59.14354493541103, 58.38653141452421, 59.09767281624579, 55.36841661699357, 60.38056635087537, 57.69722192518173, 57.604897176065755, 54.46155286604359, 56.932238148104766, 55.730039535030244, 56.60689323179184, 52.48011266031573, 54.24081363985616, 54.50229060265326, 51.447627159856985, 52.58966445922852, 54.76548556358584, 50.61488051568308, 50.439742765119, 48.66629016014838, 49.87414483101138, 48.78294144907306, 49.08710948882565, 50.78548400632797, 53.859986797455825, 51.48329719420403, 53.80699165405766, 56.28450186021867, 58.13801788514661, 57.315916553620376, 59.2550971431117, 54.53409710238057, 57.09987240452921, 54.20021318620252, 64.33607662877729, 57.83909013194423, 64.73326367716636, 59.933004302363244, 65.55839307846563, 59.64310976766772, 69.07538629347279, 51.888517256705995, 63.850110653908025, 57.88818643939111, 72.37908101850941, 56.7621563326928, 72.05991775758805, 11.476350119037013, 8.820932968970268, 73.4170578372094, 49.56730173480127, 65.53093256488924, 56.56385306389102, 60.21086108299994, 57.19425639798565, 62.08076477050782, 48.180979221097886, 49.66455298085367, 45.33993198025612, 53.07595206845192, 53.146433138078265, 52.20581346942533, 46.18716393747638, 44.63769435882569, 43.84969411357757, 48.599456894782286, 48.87329716836253, 50.23181399991436, 44.313306500834805, 47.85304161810106, 46.82763207343317, 42.97511539151592, 40.10986712671096, 40.378992711344075, 40.776434713794345, 41.83279960386215, 47.07693792158558, 45.89076219066497, 44.147127443744296, 45.35677463777604, 44.7280304662643, 46.94433435317009, 49.02477910441738, 51.71512496086859, 57.0298816311744, 64.27749995262393, 64.43358282889089, 59.37652587890626, 68.03344003615841, 67.40768863308814, 63.31001204829063, 69.46056304439422, 64.71143960952759, 66.07681274414062, 61.53850493892547, 60.38714416565434, 60.7310026691806, 67.98129604708764, 68.2961368560791, 66.38107884314753, 66.6498867157967, 71.8876080359182, 73.62441001399871, 73.60903432292324, 68.35026556445708, 74.15520867993756, 35.51595187956287, 0.2380807754854041, 0.8461263391279406, 0.4702570355467258, 0.06391890602366579, 0.0812504425524704, 0.6893440552296177, 53.855989902250236, 69.91159639050885, 51.642239478326616, 48.72672211739325, 43.62419705237112, 28.066915927394746, 21.684903906237697, 33.126165482305716, 56.397003281501036, 55.72518364075692, 43.44342285586942, 3.2458694279193883, 0.1675955383407493, 0.0521357957604191, 0.02726902606927099, 0.07530200730768905, 0.08763287426723589, 0.1541941018114167, 0.07652829190896404, 0.12736564141608056, 0.019217972500970768, 0.07340469097177829, 0.03805467453334601, 0.08116924489337592, 0.028001735542690562, 0.0675456275442435, 0.03601787656906151, 0.027690994958843917, 0.045453095883731885, 0.05473056237303442, 0.10174015356648354, 0.017318411527441877, 0.11171843345847823, 0.129951877639659, 0.42159880781846665, 61.50029713107694, 84.6818696298907, 72.79595052042316, 56.96168730335852, 31.94448478760258, 30.475874870054184, 39.62742344025643, 49.60746680536578, 88.83955847832465, 67.98368869289276, 0.42357611139455154, 0.1194965624580941, 1.4566247477646799, 3.5375569760799412, 7.1037761818978105, 8.931092735259764, 20.62791928168266, 56.4075779914856, 77.9671484424222, 81.29855079035606, 81.63751417590727, 80.70315068767917, 76.45355286136751, 71.4542567345404, 68.72356537849673, 64.43736007136684, 65.18353216109738, 61.47240123441143, 61.09475543422084, 61.88709774324971, 62.08500877503426, 59.499507873289055, 62.112382996466856, 60.444881454590835, 60.673704685703406, 60.110836721235714, 59.92796013432165, 57.93357218465498, 60.667448505278564, 55.301340164676795, 57.98275870661582, 55.663484757946385, 54.06396573589694, 55.721924151143725, 57.15376577069683, 52.107679690084154, 54.02122759049939, 53.378896328710745, 51.482018501527854, 50.1244822625191, 51.818110712112926, 52.68893572591966, 56.38508712091754, 55.936717064149924, 57.2107264303392, 58.622203103957645, 62.20155023759412, 59.539139501510135, 59.63902658031833, 57.607199607356904, 59.48527751430389, 56.84813076449979, 64.4262283848178, 62.77051356530959, 64.70870179514732, 60.784162552126, 67.40797104374056, 63.95375536334131, 68.98150044102823, 56.68499154429282, 65.19411079345211, 62.739954379297075, 71.8727030292634, 61.735333396542465, 66.91113225875363, 16.669851618428385, 16.543284577708093, 68.64325092684838, 57.42830422616775, 64.36298408815938, 59.55782959538122, 62.30607748031617, 59.15866175005513, 61.00037928550475, 54.58537032527309, 52.171806520031346, 47.86239254859186, 53.82298315725019, 54.249603671412316, 53.83478949146887, 50.561818691991995, 47.57370218153923, 45.89904231409873, 52.5133704370068, 51.649248753824544, 52.615242235122196, 49.038291669661, 50.04248903643701, 48.84822537822109, 45.848577099461714, 43.5470950218939, 43.05947380681192, 43.78273140999579, 46.51909451330862, 48.31496738618421, 48.12886268861833, 45.9077460535111, 46.78054794188469, 48.93338395703224, 50.724212661866225, 50.7628244738425, 55.529861373286096, 61.089475923968905, 66.63864520288283, 67.37334435985935, 63.192034998247706, 67.5956407670052, 68.80805323200842, 66.0638375436106, 73.38384320659023, 67.1347701164984, 67.22261551887759, 62.96635750801333, 63.60485661414362, 64.62094268491192, 72.23714613145398, 70.69776488888648, 68.75556407436248, 69.1020348764235, 74.86096858978271, 73.36992663721885, 77.60541962039086, 71.57904301920246, 78.2239224833827, 42.05999112898304, 0.49499208408017314, 0.4966804192912194, 1.7135990747521002, 0.9065905333526674, 0.06731313518098286, 0.3795961987587714, 55.117424149667066, 73.54236971947455, 61.45100078275127, 45.23763656616212, 40.62877708865751, 36.03048839876729, 34.73658869343419, 44.46674962197581, 63.13901239825834, 62.463741071762584, 51.98793365109352, 4.104186493542887, 0.16759780596100515, 0.07034496644571905, 0.061010208070999196, 0.1465275381962138, 0.02286562545885963, 0.0988753677736367, 0.02767008458895068, 0.034749740584483074, 0.0201373967537356, 0.09185152894426739, 0.0859309180128959, 0.1424036715780535, 0.15466175252391448, 0.20676593566613816, 0.14408489749316247, 0.26310220300670595, 0.3557811911788679, 0.18883362532623355, 0.2008121148232491, 0.1317994672084047, 0.28219014165862916, 0.26807114121414, 0.8086205742532208, 75.88120060582315, 96.85676543943345, 80.0728807141704, 68.10030075811571, 31.039205674202215, 44.70996010688044, 81.3267683213757, 61.03218578523206, 99.06989220649966, 75.62955702504804, 1.348440140005081, 0.31781350592932395, 2.369057896637148, 4.792565645710115, 13.674999417797213, 12.84265285538089, 25.122427940368656, 57.34272203137798, 81.8746449870448, 83.12690873299876, 83.72197935658117, 83.99041068169379, 79.80006417920514, 73.57731803770989, 71.36302240433233, 67.41498424160865, 69.36907768249512, 64.47344979932232, 63.16128753846692, 63.77875489573326, 67.171750222483, 61.287084933250185, 66.81028812162339, 64.10913221297726, 62.49615946123677, 61.08107028468963, 62.1936192051057, 60.86192354079216, 64.66035858277353, 55.33882625641362, 60.227095773143155, 61.74095415299939, 56.212393006970814, 57.88307559105658, 60.77012438927928, 55.5860532483747, 56.40111000307145, 53.71751454568679, 53.65219139283704, 54.12983409820065, 55.211914047118164, 55.30555279024186, 60.67074329622331, 57.89844735976189, 59.65881101546749, 61.33242753244216, 65.01646272597775, 62.62664494975921, 64.1706467443897, 59.665632017197154, 63.498313273153, 59.94953317026938, 70.88129258924916, 66.36403222237864, 66.3597176151891, 62.09172387276927, 71.85085542740362, 65.11237252143123, 73.54531934184413, 57.4980047441298, 71.09471659506522, 62.483156804115545, 79.55428061946746, 58.765773619374926, 79.9784771088631, 10.06710429345408, 10.44855087034164, 78.86249219217609, 55.934398943378085, 71.89939868065619, 61.37973131672029, 65.83267657987534, 61.03886950400568, 65.33961111499418, 54.30173981574274, 55.97924340155817, 50.20576946197018, 58.308021253155125, 58.26307089098039, 57.9788520259242, 52.12248663748465, 51.060147977644405, 48.87524658633817, 56.13173338674731, 54.34839248657227, 56.62573237572947, 49.433745030433904, 53.166099902122255, 52.0517506137971, 48.374002979647734, 46.06690406799317, 46.584911884800086, 45.55941604798841, 46.85603003348074, 53.42606283003285, 52.32303350202499, 50.2696805615579, 49.770107884560865, 50.48199061424502, 52.15573656943537, 53.24463752008254, 58.67292327265586, 63.11170877948884, 70.97870073010846, 70.51777516641926, 65.90480896734422, 69.57688485422443, 74.36117233768587, 69.49586437594506, 76.98584987271217, 72.53423429304554, 70.5313701014365, 66.17531130390783, 66.96435097725161, 67.8488846748106, 76.08738391630112, 74.93839617698424, 71.08270629759758, 71.69443130493164, 78.50776872327252, 80.1939485919091, 79.13519890077653, 77.5430460899107, 80.67186586318478, 46.409840814528934, 0.5423397498746072, 3.7025073507139763, 3.119208005166823, 0.9652325414842176, 0.2691599360156444, 0.9471697204055326, 66.46050683913693, 83.40623640245008, 66.9510070739254, 67.82931204765075, 57.315532161343484, 37.65269833226358, 35.82599955220377, 49.88132669079689, 75.11136485684302, 72.9664324175927, 61.53122894225582, 5.250639155987771, 0.28122680141560497, 0.14742907046550704, 0.1305859226493105, 0.2527155522857943, 0.22870549872036905, 0.26897794416835236, 0.1559369365173963, 0.2007447144076709, 0.16512982306941865, 0.21115609444677833, 0.18196363993469747], [0.028536300204934615, 0.020130930971654675, 0.03261624317195627, 0.07752949987808544, 0.047471170659146966, 0.14482823260609182, 0.08890510882220923, 0.0897811916506579, 0.08502704151455434, 0.042686675780362664, 0.3329512194520043, 4.726881144508239, 70.2016164410499, 66.85505021002986, 69.37368254507743, 46.68048435641874, 24.803702023721513, 35.909726465902025, 44.17081071484474, 45.871770074290616, 86.01382024826543, 33.91771547255978, 0.11777141672228614, 0.5194288792629396, 0.7055390313748391, 11.9212959466442, 7.115238818430132, 2.184934731452696, 26.817652794622607, 62.37505235979634, 85.42260923693257, 77.05948060558688, 77.19047207986155, 72.28641894555861, 70.85771129977319, 64.30400733024844, 63.88992663352721, 60.13585359819474, 60.96065352039953, 57.76370609960249, 62.4922880818767, 60.19344183706469, 65.19573857707363, 59.04091219748221, 57.154095249791304, 55.46965691351122, 57.582873067548206, 56.56155847734021, 54.319704271131954, 55.514583741464925, 56.12299826837356, 51.55660237035444, 53.96798533778037, 52.538567742993756, 52.76679085146997, 51.82479050851638, 52.611249262286776, 49.69643008324408, 49.12867092317151, 52.19629387701712, 50.19490057422269, 46.313676065014256, 48.91684332201558, 50.2885236278657, 55.39654785586942, 55.66585779190064, 55.69816635501001, 54.38696115247665, 56.56316664911086, 50.19887785757742, 53.18009099652691, 52.45680201438166, 57.00449605141917, 56.56721845749886, 62.26784221587643, 58.57479733805503, 59.59852810828917, 61.33097233310823, 56.996208083245065, 61.883218519149295, 58.782690801928126, 56.45053971198298, 69.21901564444266, 60.644502639770515, 71.77333370331796, 58.62503113285188, 65.85381815510412, 11.78462193858239, 8.25884065320415, 66.783874880883, 51.10011300733013, 59.0563428017401, 54.21410622135286, 59.8874459728118, 57.955058928458925, 59.890372060960345, 52.08754224161948, 50.61158964710851, 45.670956488578554, 51.0302673616717, 51.72719801625898, 53.73607912371236, 49.08778021412511, 48.705321665733095, 47.915748550045876, 53.94818129078035, 51.86907014539165, 51.553495853177964, 46.24479924478839, 46.3454354962995, 46.51736082569246, 43.186621358317716, 40.031109856021025, 40.77419504042595, 39.62604668832595, 42.28801811895063, 43.74035804502426, 47.177699688942205, 43.59144133906211, 45.413464653876524, 45.41344111965549, 48.12256728449176, 47.8589722418016, 50.95782902932937, 58.062418122445386, 65.2689927624118, 65.77686517469346, 61.104294638479914, 61.92754914683681, 61.31346287265901, 66.2406187672769, 66.41941608921175, 64.3578379384933, 62.935233500696, 58.29166496953657, 58.943625650098255, 61.23283855376705, 69.79449795138451, 66.90046341188493, 69.89585984137751, 65.61540865129041, 71.11515214366298, 69.32836348010649, 71.26522987119614, 69.44854490218624, 72.19936586195423, 64.26846281174691, 9.779912271807271, 1.3128787062821852, 1.597115467152288, 1.1139282464019715, 0.3083780912622329, 0.2966815527648695, 17.00399833340799, 74.32558859548261, 69.72018472609982, 48.359972661541356, 42.18618554453696, 32.06196958018888, 8.336798740971474, 21.64802185950741, 46.944236293915786, 55.07785135699857, 62.51034667415004, 16.086817768312272, 0.49794290154691667, 0.1971109448781898, 0.03648693305290034, 0.07321840903211026, 0.04894808092485032, 0.05295575498753498, 0.043677192992500724, 0.06571003491239202, 0.02773505650580891, 0.04368801398443119, 0.11439103843464006, 0.011569547932595016, 0.030490977374175866, 0.047324893830884854, 0.018983093773825996, 0.0513524861796008, 0.039049160080931844, 0.06950637596028467, 0.11131009327307825, 0.14754683350122746, 0.10746304486547748, 0.41918373095893097, 7.993110860547713, 87.62247054807602, 74.78061491443266, 78.91188267738589, 60.078465400203584, 35.13940434302054, 38.93334042641425, 47.707925688835886, 53.668492763273186, 93.62000988375758, 35.40029295029179, 0.2079912320139908, 0.21297584438035566, 2.0011466837698415, 14.978209849326843, 11.033983249818126, 3.0100727129367093, 32.017050596975515, 65.4554073272213, 86.6299069312311, 79.44548191562777, 79.49607264611029, 74.58385313710859, 72.72918393535, 68.1638902233493, 66.24781239417293, 63.71445940386865, 63.9152612224702, 61.673112838499016, 66.4037109190418, 64.1939809245448, 68.51793119984289, 62.23628674784015, 60.931039625598544, 57.92176977280648, 60.46375197748984, 58.43894604713687, 58.550553168019945, 59.696799170586374, 57.874116897583015, 54.1552314450664, 56.85153930417953, 55.10179742690056, 53.589233429201194, 55.13850688934327, 54.51118653820407, 50.27006495383478, 52.70250320434571, 55.25246743232974, 51.03742568723617, 50.4578366587239, 51.7931918944082, 51.863057151917495, 56.99814181174002, 58.89473722827051, 58.244321961556714, 58.00317072099256, 59.080743866582075, 52.539171788000296, 54.48882118348153, 54.52578952235561, 59.87761651315997, 60.02794919475433, 65.20905894617881, 61.77577695538921, 61.510028531474454, 63.71218835153888, 59.397639997543834, 63.26049212486514, 59.850473711567545, 59.362303364661436, 67.81244585590979, 65.15132165724232, 71.46158372202228, 63.25136084710399, 63.15282698600524, 16.685333213498517, 14.679733168694282, 61.72257784874209, 55.43996064893661, 60.68213385920371, 58.27604609151041, 61.04999334581437, 61.75347043621925, 60.629707459480535, 57.78821306843912, 53.587915512823294, 49.12407390532955, 52.16195352615849, 53.10233785260109, 54.907624413890225, 51.37678130980461, 50.01671514203472, 51.39792680740357, 56.635220589176306, 56.0162901878357, 53.40564297091577, 50.037813571191606, 48.52687735711375, 50.62756153845018, 46.496164337281265, 43.32989769597208, 43.55411606450235, 42.67750555469144, 44.654999856025945, 46.14085251285184, 50.68079594642886, 47.40562469728532, 46.286062579001154, 47.34325901154549, 49.96072723019508, 49.49693833628009, 54.523338040997906, 61.05078174221901, 66.37026094621228, 66.34623250653668, 62.90415656182074, 65.76212882995605, 63.30203394736014, 67.5170756924537, 67.14829444885254, 66.40533478029313, 65.07892647097188, 60.82747728593888, 61.6992554356975, 66.02468444455054, 70.85221213679161, 69.09939119892736, 71.16546830823346, 67.44732810604957, 73.04372664420836, 73.56580980362432, 72.42195252449282, 74.16368099950975, 74.08158579180318, 70.34908187004828, 13.254134001270419, 0.9809328699784895, 1.4460908549447216, 2.728714481476815, 0.6079344042847233, 0.36556064061099486, 16.628831471166304, 78.61808146199873, 74.92835490934311, 57.273507887317294, 27.8774772151824, 29.69509766947839, 14.974929767270243, 28.144857345088838, 52.55149587508171, 61.496190409506525, 72.26847802439045, 20.946335331086193, 0.47272521762117264, 0.05903517211517019, 0.08322337942738688, 0.09760488756000997, 0.011388209175258394, 0.10860355826275003, 0.059880006217187455, 0.0627235866962902, 0.019346669526590456, 0.04026305704047123, 0.048495878375345663, 0.1308254936649915, 0.2522916911590484, 0.18634699585457004, 0.16180374509384557, 0.16969916981554803, 0.23002188292241868, 0.22220496689119648, 0.16756878655043342, 0.25395898959569396, 0.25283072594433065, 0.6305946109275664, 11.275955246340844, 102.375697166689, 85.87359551460513, 92.76705911082607, 63.10078890092912, 33.863735814248365, 51.25309721116097, 63.98322020807574, 59.59703760762369, 102.22231680347075, 40.959978103637695, 0.31759832715315206, 0.9078475917058607, 4.224226465148311, 16.204140763128958, 17.655627573690108, 4.897361570788968, 35.29383197907479, 69.56550998072471, 88.49373878971224, 81.39960673547561, 83.03988702835576, 79.47322876222673, 78.514358305162, 72.02249834614416, 71.73846383248606, 67.38378570925805, 67.79062178827101, 64.00335373417025, 68.94738366526943, 67.33574451938753, 73.29958285054853, 66.55063506095641, 63.858900685464185, 59.890160252971036, 62.395205497741706, 61.175352296521595, 59.70346719987931, 63.88375674524615, 61.75882447150446, 56.38393002171671, 60.023050154409106, 56.826663632546705, 56.872943678209865, 55.177538394927986, 58.47432974846133, 54.92563201535133, 55.23308700130832, 57.676276468461566, 55.6794644940284, 52.91133019231981, 52.69578418424053, 55.91492829784271, 59.97744083404542, 60.196928824147875, 63.11602730904857, 59.142697703453806, 61.80061732569049, 55.59406665063674, 57.06600666046143, 57.575695130132864, 62.46895390172159, 62.77003895851874, 67.68729086845153, 64.71869991671655, 64.39355896365258, 63.017713100679465, 61.65852946619834, 64.20451641082764, 63.209273815155036, 60.363088269387525, 73.10573147189233, 65.96005162885113, 79.80381396508987, 62.53845437880486, 70.88425790109943, 14.10221613222553, 9.584399769383094, 71.07457914660054, 54.477536524495775, 66.08348861817392, 58.01022706493255, 65.87541472527289, 65.02103620959868, 62.55437527933429, 57.51900511403238, 55.03566234342514, 51.04823181706091, 56.87652087980702, 57.17795110517933, 59.570553764220215, 55.00719770308464, 54.090080876504224, 53.04445935833839, 59.71919982664047, 58.84233436276836, 56.006476417664565, 51.39147843084028, 50.78227550752702, 52.75491783695837, 48.621728112620694, 47.0376318500888, 46.42087051945348, 45.79879829960485, 46.64501044058031, 47.390747147221724, 54.00668736427061, 50.587082678271884, 49.875898130478404, 51.408940822847434, 52.58876231408889, 53.47137405026344, 55.89051938826039, 64.21832707620436, 71.94808313923498, 69.6934812299667, 64.86567897181358, 68.72817808581938, 66.55731093498969, 71.05011140146564, 71.86622327373874, 71.41426424826346, 69.62220391919537, 64.06981829674014, 64.53105765004312, 69.0206378506076, 76.94639082877868, 72.9573089845719, 75.06298634313768, 69.30709638903218, 76.91082277605611, 75.9177492510888, 75.94513523963191, 78.36105638934721, 79.16876654471122, 73.70800356711112, 14.467308386679619, 2.9551185907856112, 5.3490700548694985, 2.533658444881439, 1.0504584134586397, 0.41219900091809614, 21.89893195706029, 88.5652671321746, 82.61853033496489, 65.00338946619343, 58.90331545183736, 41.53791581430743, 16.92172661904366, 34.65830602953511, 64.7199550751717, 70.92894154210245, 85.24638498983076, 25.581792400729274, 0.812757755479505, 0.3799720721379403, 0.15303638974024406, 0.2944800918621402, 0.10692573377802488, 0.17772974776885203, 0.24772288067446602, 0.18007014637752888, 0.2716201814191957, 0.15812911243448335, 0.2321798147092904], [0.0246912666085747, 0.02624423216818081, 0.03719641091001611, 0.04480254550975177, 0.11805181256345204, 0.09059730511639388, 0.045967255794112725, 0.08033872131378421, 0.03761660247560471, 0.12579385116095507, 0.055156043775740175, 27.701166675936793, 76.57612692925238, 60.913247754496915, 66.6929308060677, 35.43502946053782, 33.02256391894433, 52.39983350999894, 42.61537913353213, 65.32066214469172, 89.00381949640091, 9.213350415229797, 0.14560504576131222, 0.36225150850030685, 0.9059153340997235, 4.002208546284707, 0.9486717430333939, 5.92691804132154, 34.85560909394295, 68.95791915155226, 81.15958905989125, 79.86326925216183, 78.1988585379816, 73.76724704619377, 67.4806760972546, 64.0781258767651, 62.70517864534932, 62.262601929326216, 62.834707075549716, 63.51691315251013, 63.70340616472306, 67.38134599501088, 69.14313347108903, 71.40907103015532, 70.2331522972353, 62.64276589116743, 56.96537040895032, 55.26101819930538, 54.38910276659074, 55.56531567727366, 53.24018562993696, 50.33291701347598, 52.83005083760908, 51.75473305486864, 50.25070413466423, 50.431137084960945, 52.03646121486541, 48.83005695958292, 51.039755575118534, 53.5651030079011, 47.7203203785804, 48.2933041357225, 47.24190496629285, 50.84198182629001, 59.290045461347034, 65.78264282595727, 66.40083189933532, 63.15698077601772, 61.847564174282944, 60.12350205452212, 57.56750522121307, 56.97150107352965, 58.468563864308024, 59.98359111047561, 59.94693263884514, 59.78871207083426, 57.562198254369925, 57.989289452952725, 60.27729426660846, 49.821024171767704, 53.98574975229079, 65.22675275802612, 60.87267867980465, 61.76798320585682, 62.37096525007679, 67.19381747707244, 50.295752556093284, 15.579167950537899, 8.686355467765562, 47.33334325974988, 53.66173451946628, 61.92431711381482, 57.347119008341146, 56.85279446263468, 58.309409772196126, 60.8821080576989, 53.09494418482627, 55.25822154937252, 53.15651362942111, 50.3344859615449, 50.328712232651256, 51.22150644179314, 47.67996311187745, 48.53933480478103, 52.55392382221838, 54.34334047379033, 54.4840358918713, 56.903091015354285, 49.972690459220644, 45.57571349605438, 46.83302533242011, 45.58998307874126, 39.7873031708502, 40.4958636529984, 40.94566537487892, 41.864378606119466, 42.87561662735478, 46.70736828157979, 43.170896576296904, 44.88216000218546, 44.64152651448404, 47.057184865397794, 46.32672186820738, 49.64268576714301, 59.153142975222686, 63.70466524554838, 62.28742268777663, 63.85460176775533, 62.76757178768035, 62.69622387424592, 65.47521921896166, 63.7367541559281, 61.33761682818013, 56.32125446873327, 55.918552567881925, 57.53414546289752, 60.17047635970577, 67.34770774841309, 67.22924432446881, 67.13378952395531, 69.8697917692123, 66.66159106839088, 67.54770155875914, 68.27519139935895, 68.06339125479421, 69.85788345336914, 77.39660047715711, 37.068253409477975, 0.08308944427558491, 1.1591787924689632, 1.0667541454876623, 0.4684004980710245, 0.22580489065618287, 1.7032674291441519, 54.22554777514551, 67.07958236817392, 59.738548878700506, 64.22626595343313, 47.96551166042205, 25.00571977707648, 17.846280259470788, 36.90094470977783, 54.70043697664815, 56.87250829512074, 42.13135080952799, 1.270844013460221, 0.04249433025477394, 0.10034215801786031, 0.060027796069100026, 0.026894397582978975, 0.07357896831367286, 0.0545976001528963, 0.05723385425705103, 0.029405704661903363, 0.024063963172656876, 0.025829968207906333, 0.01423910675164793, 0.04321862808278492, 0.023708770337003856, 0.04226805469501884, 0.049482542165224595, 0.04207359859719873, 0.04571282650314031, 0.07666747476304732, 0.06283558875082002, 0.11946052568213594, 0.19362490774402696, 35.708787364344445, 88.60670305067494, 70.85078439404889, 75.99933455067297, 43.49249562909527, 31.267044390401534, 33.56408634493428, 51.62678926221786, 72.76839194759246, 95.75315952301027, 8.969620216277338, 0.1973681972031632, 0.44483517386740257, 2.688074558973313, 6.602042769232105, 2.0285716508665392, 7.755793736826989, 38.01549403898178, 71.76228046417236, 83.62274339122158, 82.0762469691615, 80.57678761020784, 76.37910627549695, 71.48270960777037, 67.0019821966848, 65.11675773128387, 65.48794338780066, 66.47496469559209, 65.7132992436809, 68.41290581610896, 69.11393534752631, 70.90371285715412, 74.70430912510042, 73.31683343456638, 66.53794227107879, 60.1387639968626, 56.52087957628312, 57.4478768533276, 58.52116677068896, 56.51284656217022, 51.8165692206352, 54.86225435810705, 55.011135762737645, 51.59825401921427, 53.58630341868247, 53.65005370109312, 50.89397284292406, 51.8341532061177, 55.46092179513747, 51.01275005648213, 50.96798404570549, 49.55146712641562, 53.12834316684354, 62.65340335907475, 69.83416095856698, 67.4710427561114, 65.57028178245791, 65.49497227514944, 62.850914309101725, 60.111248570103804, 60.515892044190444, 60.64804061766594, 61.043266480968846, 61.356095114061915, 64.33493521905714, 59.83254455750989, 60.450659105854655, 60.62857389450074, 55.35009522591868, 57.05952690493677, 67.26969965042608, 63.02135698256954, 65.48336990417974, 65.83700687654557, 69.78465280225201, 48.941797441051854, 18.349294816294027, 14.493360769364143, 45.74156307405042, 58.322941949290616, 62.458787118234945, 60.43205530412736, 57.611247493374734, 60.96783145781487, 62.451244400393584, 59.03912359668363, 58.18757703227382, 56.96563713012203, 53.50417683201452, 51.59108392653927, 54.42864025792768, 51.360021022058305, 51.9081408746781, 55.041569432904645, 56.636044286912494, 56.83078604359781, 57.93410562699842, 52.37727203676778, 47.79669677057574, 49.00730102292953, 47.96487231408396, 43.7079631897711, 43.06120749442808, 42.68182408425116, 44.148378679829264, 46.31325637140582, 48.443173977636526, 47.10712056006155, 45.97485780715943, 47.0026364634114, 50.369026353282315, 48.70245441313713, 51.260196701172866, 61.83774648174163, 66.57008217227074, 67.00975633436634, 64.3882166954779, 65.97756108930035, 64.58115416188394, 67.25256673751339, 65.79319792409098, 64.06710009421072, 58.31997271507018, 59.34045968517181, 59.17684193580382, 62.841108383670935, 67.73563800319549, 71.00247029335269, 69.71691346937611, 72.16553149684783, 69.87135287254088, 71.43668451616841, 69.5902052233296, 72.45113495857485, 71.17404260943013, 81.15157957999938, 42.01032607786117, 0.15738580796507098, 0.4525984943874421, 3.520021529928331, 0.6069683367686888, 0.09667951463451309, 0.9139140887606529, 59.247064128998794, 70.94656082891649, 70.72549604600476, 55.897744394117794, 42.39137257299116, 24.39348093924984, 21.784188901224447, 48.70839288157802, 58.83149293161208, 67.21203296415268, 49.535330495526715, 1.3931666819318649, 0.06104755102686825, 0.032830694164600105, 0.02209646552200279, 0.02448752935555193, 0.07157790835105604, 0.05016324959034401, 0.023651602940874237, 0.07487549551672514, 0.023612777604871703, 0.022406909246778777, 0.07975194392906082, 0.09922949191663535, 0.1378682472052113, 0.09361053576632854, 0.305894005202478, 0.15007906052614414, 0.14255676658884173, 0.2903000403556132, 0.15556797325130434, 0.35800692174703846, 0.2936351275251758, 41.50461489154447, 101.55155228030299, 79.690504535552, 87.25749400354202, 49.83835712555916, 46.48939432636384, 70.19594469378072, 62.31704442731796, 80.95118568789574, 105.19121370007916, 11.784877873236134, 0.3785586399176429, 0.9661085783473908, 5.126005353466158, 10.077677042253557, 2.9915083800592734, 8.302704518841159, 42.662114174135276, 73.06945739253875, 87.35278406450826, 85.63717857483896, 85.91678865494268, 81.89026386507096, 74.25071054889311, 70.36275525246897, 68.31761575514271, 68.83536861788842, 71.32480282937327, 68.72707982217112, 70.24494294197329, 71.60391084609493, 77.60243077431956, 77.90405319583031, 79.1427847646898, 67.39729435213151, 63.40489810512912, 59.115598047933275, 60.86939565597042, 61.95864569756293, 59.688703398550714, 55.21765247468026, 57.7012070532768, 57.816336462574625, 53.174780107313595, 54.463184572035274, 57.72077575806649, 53.90306618905837, 55.14259399906282, 59.59897918085898, 52.85885672415457, 53.91636694631269, 50.54214800557783, 54.86894984399119, 67.19963042966782, 70.72949686358052, 70.80394344945108, 66.77279810751638, 69.60567505128923, 64.13351758833855, 62.61022983058807, 60.72833545746342, 66.0977425113801, 64.38711450945947, 65.63571476167249, 65.82858947015578, 61.84393205950337, 60.58303909917032, 63.238730815149125, 56.785423832554976, 58.50881130464616, 68.93014877073227, 66.79899954026746, 65.97852599236273, 69.93877841580299, 72.09009647369385, 57.45375256384573, 19.39176274884132, 11.825729358580805, 54.82635682629001, 58.24301188991916, 68.223157236653, 61.84801524685275, 63.503333906973566, 61.506937703778675, 66.74289395732265, 57.66339540481568, 58.79848226424187, 57.69496656233265, 55.23420879917761, 54.43193504887243, 59.1610465511199, 53.69682012065765, 54.7602060533339, 56.279783248901374, 60.60622030688871, 58.57386381395402, 61.079207158857784, 56.39515976752005, 48.899863381539625, 52.346555955948375, 53.091955338754964, 46.708372408343905, 47.26576474405105, 44.97448475130143, 46.742587243357015, 49.37770612778203, 52.46014779613864, 48.75950920966364, 50.813356368772446, 48.832237797398726, 53.003717699358546, 50.21753657248713, 55.04551925966817, 64.51269311289634, 72.11175580178538, 69.64474185820549, 66.5935536353819, 67.19999913246401, 70.51764965057373, 68.27010800761562, 71.37389521444999, 69.51108317221366, 62.42534891251595, 61.578717077932055, 62.38139875473515, 66.5746948795934, 73.89604983791229, 71.47997963813044, 73.21402026760963, 75.50025216994747, 72.04126296504852, 74.70884338501962, 74.1834811241396, 74.5161844068958, 75.52845401148643, 83.75367210757348, 46.69083941367365, 0.24875176740029167, 4.869295541317233, 5.353179227921271, 0.9201421997239514, 0.33017044286093405, 2.1196032435663286, 69.16280807987337, 79.31764402697164, 74.98332300493794, 85.05893491929578, 62.411804968310946, 34.57116273141677, 32.15541416598905, 54.641220954156694, 71.51222152094688, 75.95949895920293, 58.69717528743129, 2.527430701640345, 0.20357065954275672, 0.22815973768311165, 0.17145826090728084, 0.13891553536297815, 0.16781600312359873, 0.17820041686777147, 0.15846853535021507, 0.1514242649559052, 0.11206951623241748, 0.14211194529648752], [0.048720702198484254, 0.030131440819992177, 0.03804610200947331, 0.04186902630833849, 0.06603448080920404, 0.0844592784321116, 0.038458383717243715, 0.02448445159731613, 0.04465354523891884, 0.021467953582384416, 0.3291889616558629, 53.47517090459024, 69.85728725310295, 65.71420138882053, 50.620956267080004, 80.671324576101, 62.1325243673017, 64.9039730718059, 53.23934624272009, 68.34344848509758, 62.304606591501546, 1.3968698896708027, 0.020055657087434686, 0.40581414836548996, 0.6982392553360232, 1.780946783481106, 2.2047402493415342, 14.987416632713812, 45.74559134821738, 71.0740613937378, 79.15789373459356, 77.15061295417048, 73.19147448385917, 69.41544009793189, 67.01894252530991, 64.39996419414398, 63.68141343516689, 66.66807082391554, 63.01675604235742, 66.06550847330402, 69.80598265124907, 74.04340544054585, 79.50620805063556, 69.90896055775305, 67.64389376486501, 68.31825902385097, 68.21397104570943, 59.66770695101831, 55.77546842636601, 52.636583851229766, 53.37100844229422, 49.08740758895875, 52.97829289590159, 53.406384298878336, 51.582905784729995, 50.37361552638393, 48.66012811660767, 47.640288337584465, 47.525704137740604, 52.10415740166941, 47.814453340345814, 45.999796236715014, 44.05088424682618, 50.98062584477087, 60.37190183516472, 65.99213661686068, 61.07075445113644, 63.16940684472362, 65.40583249061339, 62.973068683378166, 61.187582246718875, 59.02689756885652, 59.87426680903281, 61.27682401287941, 64.17349830750497, 62.69248977784188, 56.73790039554719, 57.076612749407374, 58.35946706033523, 57.70647087404805, 62.97741859189926, 62.896249063553356, 62.73413358196136, 57.501778064235566, 61.91977500915528, 62.64968102978122, 42.37569485941241, 17.271880526696485, 10.774227226934126, 47.795978976834206, 61.32647729689076, 60.51207950038295, 60.16790720724291, 58.772743671171135, 54.95372795289563, 55.69722106379848, 58.36376205567391, 56.72491342790666, 54.49571671024446, 54.23085474198865, 53.28441819837017, 50.61282127134262, 48.38011011000603, 53.79406744433988, 52.62811153165756, 55.73637808522871, 56.991999380050174, 58.491952957645545, 56.26151284863872, 46.537313922759026, 45.48228656091998, 43.733909668460974, 39.98296276215584, 39.157433279099, 39.60039046502883, 42.471353623174856, 45.271714118219194, 45.91251565564064, 46.40096056845881, 44.238514746389086, 43.65833343998079, 45.6748317903088, 46.73269894815261, 47.05977362971152, 56.72881226385794, 65.43041006211313, 62.79906449779388, 64.03349714894449, 59.51302828327302, 60.01782163496941, 62.29675400641657, 59.029254913330085, 59.90553594404652, 56.21160461056618, 58.17648456942651, 58.61405241873957, 61.2283552846601, 62.532488453772764, 68.32486429522115, 66.54444556082449, 66.04498663256246, 64.46021572236093, 65.85296307840656, 66.76860117143201, 71.07367700146091, 71.3175307550738, 73.29717451526274, 59.76304015805645, 3.383314181720057, 0.2393357500794434, 2.0567958008858467, 1.5597570975941997, 0.405226313779431, 0.29777319741345226, 23.728452882459088, 75.01172096498551, 63.91678310209706, 50.57684921449231, 47.68323829097133, 34.56240800119216, 18.541049688093125, 14.729553153437955, 49.07356554462064, 58.07229857290945, 60.36998771852063, 12.710254230806905, 0.45538601255224603, 0.07328291363533466, 0.05267072431442719, 0.12449474224159796, 0.059248389706255934, 0.07522300832093724, 0.04620449024162466, 0.11255225121614434, 0.04060342607478942, 0.08023539137455725, 0.062261264125305804, 0.09710870007233274, 0.06478986372390101, 0.02875297476777867, 0.03936764581369297, 0.037469628507331494, 0.05771491150822371, 0.04226836496062818, 0.05626726197078825, 0.07172989253435405, 0.28131146945299645, 66.09314549353816, 77.66853840120378, 75.45439181789276, 57.70139532704508, 81.67462764247772, 47.151313904793035, 56.81523776823475, 61.727829902402824, 76.69921875, 67.11944149386498, 1.1558512742480924, 0.05953514790763298, 0.9673231034990281, 3.867712679409212, 4.902474380308583, 3.875590514752173, 17.345813282074467, 52.40671726965135, 74.15352206076346, 84.06702241589947, 77.77028468347366, 76.84796287167457, 73.55519586993803, 71.0335119308964, 66.97588274555822, 66.2676517425045, 67.0887371801561, 67.21964236228698, 69.07286813182216, 73.63863252824353, 78.73663117808681, 78.11005607728036, 73.77532712874874, 71.94484326147264, 70.51829291928199, 69.63504575913953, 62.815040311505726, 58.1159310187063, 55.953387137382265, 55.49655260578279, 51.62273745382986, 55.28658813045871, 54.15556876890121, 52.56472995204311, 52.63515610848704, 51.353101961074344, 51.030361498555834, 50.27812150216872, 52.937990542381044, 50.468791838615175, 49.110373066317656, 48.07411424575314, 53.274726021674375, 63.921835114878995, 68.81069690950456, 62.10888031990298, 67.56213588099327, 66.22794951162031, 65.30898917105891, 63.24152746508199, 60.781973869569846, 62.983839511871345, 64.3610974281065, 66.3402783486151, 63.47497124825755, 59.54431703013759, 60.97705687246015, 60.8604879533091, 61.17531307281987, 65.5294499089641, 64.45884289280062, 63.66439819335938, 61.03657491745488, 63.620679455418745, 66.79523406490203, 44.77418499608194, 18.193839519254624, 17.255306551533362, 49.16959693354946, 63.26068432100358, 61.48499988740491, 63.08935519187682, 63.46775408714049, 59.50281443134431, 58.31383812812067, 61.492409244660415, 60.284193715741566, 58.18965981083532, 57.77942303688296, 57.44817887583087, 51.78842621464884, 51.82537494167205, 54.10807671085481, 58.37510555021225, 57.23351147867019, 60.38291977297876, 61.11485758135396, 58.78320071005053, 47.10043684128792, 47.68982002812047, 46.35849306660314, 42.99655898924797, 40.467991290553925, 42.331976121471776, 44.861324371830115, 47.303121397572184, 47.37509689023418, 49.199677590400945, 47.19819407309256, 47.851708012242476, 48.528983669896284, 48.62667422140799, 48.56513223340435, 59.39495709634597, 67.04958408109604, 65.37180200699838, 67.16634519638555, 63.06762133875201, 64.16061332148891, 63.42551800512499, 62.27253729297269, 60.22153777460898, 58.72351792550857, 60.41341227869834, 61.221369543383204, 63.757672156057055, 65.32235268623599, 70.44517993927002, 69.97276967571628, 69.87139994098295, 66.4023224000008, 69.39544385479343, 69.27789042072912, 72.52378509890649, 73.05163414247575, 75.9381377312445, 63.661829040896514, 5.508968907017862, 0.4264470105690341, 1.1287827525408038, 2.1137196883078544, 0.19799741585889172, 0.35830952647712927, 22.610022367969638, 81.6630958741711, 68.92117438777801, 60.29249737339636, 42.68342833365164, 36.58486835418209, 28.375153426201116, 23.21306520892728, 61.7248998918841, 63.236553899703495, 70.91915130615234, 17.566048483694754, 0.44882845313799, 0.025683107237601956, 0.06771668731685608, 0.11439914364487895, 0.03811211197546894, 0.01131702715816397, 0.056471953003276745, 0.01230749936263648, 0.05597642435121441, 0.057053095811317046, 0.11469879893646126, 0.1506957613051899, 0.14298165427340617, 0.10338892033624072, 0.1719533835327433, 0.1553139691391299, 0.17068472660837636, 0.11497761663650313, 0.15319538362804921, 0.1481129877990292, 0.9524251448531306, 78.73314026863345, 90.44594949291599, 84.32258052210655, 66.3733753081291, 92.03898875944077, 78.65752481645154, 90.93411199508175, 70.21946322533393, 81.837751173204, 75.35583834494315, 1.9789448428538539, 0.1851072664102239, 1.5068041196753903, 5.209277272224426, 10.397937586230617, 8.429230374674644, 21.18195995207756, 55.16047216230824, 76.97083503969255, 86.16934222559776, 82.34387028601863, 81.88893025921237, 77.1413875395252, 75.28797349622174, 69.28499775548136, 69.25543092912244, 73.16959550303798, 69.04108908868605, 70.52682799677696, 76.4543765591037, 82.76924348646595, 78.16126654225012, 74.61070568330827, 74.67041200207126, 71.37298522457, 74.90242019776376, 64.6065083626778, 60.9441521090846, 57.334245789435606, 59.18736565497614, 52.87500904452417, 59.43756580352784, 57.04346087671096, 56.67347938783708, 55.751196799739716, 53.998850468666326, 53.23781259598271, 52.89823732068462, 55.53636074066163, 54.22269621203023, 49.761513971513324, 49.906453394120746, 56.094674833359264, 67.19251525017523, 72.53759184191304, 64.72680745586273, 68.39834597802931, 69.66679342331426, 68.2292055314587, 69.07453121677523, 64.31397015048613, 66.77799132562453, 66.75368832003686, 68.76455414679744, 66.62029635521674, 63.504867553710945, 64.4724731291494, 62.44661600359025, 60.610629050962395, 69.00939633769374, 67.85650976242559, 66.75761853494953, 63.54766453466108, 67.79241038906959, 66.991470244623, 50.255336453837735, 18.986519152118316, 12.900586262825998, 57.486712240403705, 64.17684408926195, 68.49802124884822, 65.21955128638976, 64.80243075278499, 59.83666696856099, 60.30529214489845, 61.49411547568537, 62.66532344202842, 61.40545814268051, 62.137576380083644, 59.87061900477256, 56.39945868522891, 54.92569869564426, 58.08022176065753, 59.55687645942935, 61.34465748263944, 62.374134525176025, 64.04403263522734, 61.683954269655295, 49.70575747951385, 50.16369419713175, 51.526176544927786, 45.33798256228047, 43.729987298288655, 46.66691295562252, 47.46117330366566, 49.92103284405124, 50.28291071614912, 52.17185358847342, 50.74518949754777, 50.88114277009041, 50.097986652005105, 51.53888502428609, 52.303876646103404, 61.984647089435214, 70.9455410126717, 67.67045605567195, 68.167616475013, 65.5384752827306, 67.34179281419324, 67.9715685690603, 65.19730752514255, 63.801316368964414, 61.5416467574335, 63.96420847985053, 65.110364267903, 67.61524477312642, 70.12683253134452, 74.92861378577449, 74.32165053582962, 74.8225450515747, 68.89461994171143, 72.74787795159125, 71.76461819679507, 76.28540085208031, 77.6296990917575, 78.90181003078338, 68.28679377032866, 6.578194268288152, 2.451387711109654, 10.760971576936784, 2.6003274609965663, 1.3463774635907144, 0.3427270835926456, 28.663120115956954, 90.17957348977366, 77.2325591118105, 68.7826519627725, 64.75145955239573, 49.39061464801912, 31.204466896672404, 28.57397444786564, 71.03713620093562, 73.4421217826105, 80.43481349945068, 22.40733781168538, 0.8111986746230434, 0.2028151436318313, 0.2194077347315127, 0.3477459400892258, 0.18725424313977843, 0.11545462128255637, 0.20392731943678474, 0.15905724327650764, 0.15413909669845335, 0.20640106330956184], [0.060666292049591584, 0.0418278107780122, 0.0796541145011302, 0.022465055320231665, 0.0861012806454974, 0.1296307642253176, 0.07916907359275126, 0.09216430732199261, 0.0793449214148906, 0.15788253937517444, 5.562884336517704, 64.32764353290682, 67.85304238719326, 53.21173275670698, 40.54575227922009, 64.67282779755132, 42.92741152548021, 53.357660616597826, 55.33525689955681, 90.64387229181106, 34.22832796650548, 0.05343452163581407, 0.15751244229895456, 0.7675883534454531, 2.882953843762798, 1.823218902272563, 4.458808716266386, 27.210117309324204, 57.767557867111705, 75.51888342826598, 75.93498414562595, 74.925734766068, 73.80008512927641, 71.15393653992685, 68.84608453319919, 67.00274313649824, 67.00111927524691, 69.91892337799072, 71.134136415297, 72.67824019155195, 71.82030016376127, 69.64238843610211, 73.85205653405959, 84.65612319207962, 76.15852002174624, 69.43473031443935, 70.09469263015255, 68.37416064354682, 65.03103825353807, 59.297890201691665, 52.956621800699544, 50.43249814741073, 51.60378063878706, 52.77002288449196, 52.10879364321309, 51.90903125270721, 48.95301541974468, 48.578727168421594, 49.0201428628737, 50.84443330764771, 49.0823281195856, 46.960588655164166, 43.96452150037212, 48.533851331280125, 59.217218814357636, 67.62275218963623, 63.76550905166134, 59.7654837946738, 60.890874555034024, 64.82925976476362, 64.39320202796691, 64.82831839592227, 61.91107126974291, 61.9936175500193, 58.49602830025458, 61.64995124263149, 55.46223186677503, 53.38688227438158, 61.358397545353064, 57.98222134190222, 64.68261803350141, 59.421993993943744, 57.02756351040256, 54.03811339409121, 59.553244344649784, 62.65492131633144, 42.68937464683287, 20.747906546438895, 18.617837928956558, 55.957446790510616, 61.537779300443596, 60.276498025463475, 61.2702932665425, 57.83777221556633, 60.986698058343705, 58.40208753462761, 53.674592048891135, 62.44910670864967, 60.16889172215616, 57.90306006708453, 58.79031981191328, 55.78774936737553, 53.86486230358001, 54.92165865436677, 53.09352428682389, 57.32529101833221, 59.42679497503466, 58.39473309055452, 61.11302583448349, 52.44350125712734, 44.605903548579064, 44.06230618876796, 42.074197953747166, 40.75662282205398, 42.665977708755, 41.00774864996634, 44.1857353333504, 45.131446238487, 46.788278933494325, 43.529742456251576, 44.41298961639405, 44.5468169643033, 46.89281794332689, 48.433477878570564, 49.17173462529337, 62.202291565556685, 62.11995317089943, 61.58451826341691, 60.06448999527962, 59.59791621854229, 60.684122500881074, 58.422330887086936, 58.81868639299947, 57.01094442798246, 55.537894387399, 57.82745638201314, 56.194299113365915, 61.19770196176345, 62.140780956514426, 61.522858604308105, 63.60124018884475, 60.79145423827633, 63.834511387732725, 67.64139913743543, 69.87970752100792, 71.23296445415866, 70.63371258397257, 70.76056203534527, 17.84297174023044, 0.40688118626994474, 2.165153483229299, 1.562995749615854, 0.1301120053375921, 0.0725392337828394, 3.3999680751754395, 57.332425809675655, 70.94496050188619, 58.32847249123358, 63.440007240541526, 42.39247475900958, 11.685599742397187, 14.549498711862872, 29.49987150007679, 50.979657019338305, 62.72418645120437, 38.286647488993985, 1.8300260531325496, 0.18991623013730974, 0.024877044845432527, 0.04200089685318451, 0.034972323600443146, 0.008211558564536033, 0.04334233596079773, 0.015822197761266463, 0.02326686400920153, 0.07550009466227024, 0.0035043095281693127, 0.048639630943897276, 0.06100676833621918, 0.030514210905699484, 0.09820408322998593, 0.08989752210195988, 0.03379369732893763, 0.16644678949829073, 0.13707641872667498, 0.19252243061219493, 9.086743170215238, 79.19511702752884, 72.63291328184067, 62.46099149027179, 49.04190809495988, 72.41155824353619, 41.15159765366585, 60.764433030159246, 63.77514631517472, 96.04576833786504, 38.64339490090647, 0.0971980182634246, 0.26321803550085715, 1.6021311980101371, 3.318692397686743, 6.33597957511102, 4.645680727497225, 30.643630719953972, 60.23992192360663, 77.6271338616648, 79.17796058039512, 77.26712303776895, 77.56412490721672, 72.78415987568518, 71.92210920395391, 70.44793344313099, 70.6360738508163, 71.78143732009396, 73.31012618157172, 76.71791276624127, 74.99942825686547, 72.69532603602256, 76.40477426590459, 80.98687141172348, 79.34045653189384, 72.93757946260514, 73.46201604412448, 70.44628604765862, 67.84397386735486, 62.834726687400575, 54.538439166161325, 53.05086066645961, 53.902701408632346, 53.20653953859883, 53.12356571997366, 53.05821118816253, 52.840111717101074, 50.08476434215423, 52.80668920086276, 53.45335468169182, 50.32315815648725, 51.2796595019679, 47.16130418162192, 51.333207699560354, 62.69189749994586, 67.99904869448754, 65.3158337070096, 63.29509135215514, 63.061659336090095, 66.70235233922159, 65.73870443528699, 68.66502792604508, 64.83876366769114, 66.40238515792355, 60.43949211797407, 62.86023386063115, 59.06362272077992, 55.292318713280466, 61.03764572451192, 60.25206558166012, 67.49676565970144, 65.07814591930759, 57.505665133076334, 57.26605930636006, 63.91826968039236, 65.73514292317053, 43.116681575775154, 22.053237999639205, 25.066553777264012, 56.06317035613522, 65.52946559844479, 61.81205887948314, 62.47432362648749, 60.270720374199655, 64.72306551471834, 60.45519728814403, 54.35750807485273, 62.45479414539953, 62.963804045031154, 60.750351721240634, 58.731778437091464, 57.44328768022599, 56.30321941068096, 56.87642674292288, 58.0127138476218, 60.06950278435985, 61.271215023532996, 60.86029967954082, 62.29030170748311, 54.69582034695534, 48.10766227783696, 46.59725950610253, 43.65201057926301, 43.22881037189115, 45.10711185393795, 44.20686906383884, 47.66545426461005, 47.10078593223326, 48.72889511046871, 47.931418418884284, 46.091642456669966, 47.30061892540225, 47.60490855863018, 49.94149192687004, 51.44808607716715, 64.27672724569997, 63.70244518403084, 65.22452092939808, 63.16613951037007, 62.66119710860714, 63.258609387182425, 61.1582507625703, 60.92311251548029, 59.89412576921525, 59.546344895516675, 61.3735810402901, 60.72668806199105, 62.08130213522143, 64.36694960440359, 65.68346961852043, 65.63814663117932, 64.9214982217358, 66.80693841749623, 70.548840338184, 74.15319258166899, 74.98078915380663, 72.884243073002, 76.41265822995094, 21.312435634674568, 0.0722242950371677, 0.24598995914622662, 3.0676170702903502, 0.46705886361099064, 0.05028829046134507, 2.7625520335089777, 60.94423840122839, 76.00874039434618, 66.36036088389736, 60.34849705234651, 43.017610349962794, 21.42448009983186, 22.303267525088405, 34.380198217207386, 59.29319120222523, 71.1773766240766, 48.13851564161239, 2.1390608962505095, 0.1645614164731195, 0.015174389982055274, 0.06824468277514943, 0.053884655747923164, 0.04518236807217041, 0.0540160091834203, 0.08229891048564066, 0.061385445597191016, 0.1170858369779683, 0.10840793005040578, 0.20336553184015138, 0.1392265823819945, 0.13214526397566642, 0.19615053109103636, 0.17650656582367036, 0.26364949621981193, 0.25348410701319096, 0.31323070667924424, 0.34592053642676723, 13.780621982389881, 94.69977563427341, 83.16370056521508, 72.14723756236415, 56.16404194985667, 74.95618020334553, 59.24660521168863, 71.01426878283101, 71.04744418974846, 105.13449622738747, 43.357809282118275, 0.16629853616318396, 0.43371206750312163, 3.1996038459962417, 11.456898104759956, 12.840050362771558, 9.474829339211988, 34.96855766542497, 64.04514658835627, 81.13268160050916, 81.31738601192352, 80.22719460148966, 83.00336976205149, 78.43795837894564, 74.17558931535291, 75.34253366531865, 74.5021580111596, 76.22606323611352, 77.11266794512349, 77.6186066289102, 76.9153021227929, 75.05961310478949, 81.812757830466, 81.01180984127907, 80.69495293401903, 77.30265186678979, 77.22185104124009, 72.11237553627261, 70.12268266370221, 64.86413748033586, 59.00630120308169, 54.43028373102988, 56.6789589389678, 56.434763939149924, 54.884286311364946, 55.993014843233176, 56.00743739835678, 53.7843595781634, 54.16328799340033, 56.96168338098834, 54.73275730686804, 53.16750018827377, 49.41663957411244, 54.52202404699018, 66.18630178513067, 71.01836373729091, 68.2363756241337, 64.00616215121362, 66.25461378405171, 70.39846451051774, 72.22537902093703, 69.23223403192335, 67.95187042605492, 67.74783657443139, 62.61078288478237, 65.52992451575496, 58.400640180034024, 58.95433372066867, 62.82645048633699, 62.11206920685307, 70.61120602392381, 65.15786809305992, 62.77293759007608, 58.6530250887717, 65.32445115427818, 65.1667679509809, 50.4036138134618, 22.963759360774873, 21.29192752222861, 62.743657096739746, 67.92278997359738, 68.12359963693928, 64.66264140221381, 62.096120849732436, 67.10620741690359, 63.512335746519035, 55.2208060602988, 64.59973442939021, 65.02823768123504, 63.55358339125111, 62.53810136548935, 63.478858317098315, 60.72746469128517, 62.51170773659984, 59.135441318635024, 60.88130397181357, 66.44099696989983, 62.50787165857131, 66.2769320703322, 55.97456009157243, 49.693692268863806, 51.480127919104795, 46.97730187446841, 45.95276701834894, 49.46431206118677, 45.051163165800034, 49.7701314187819, 50.77782753975161, 53.5728536113616, 51.11045629747453, 50.1542922758287, 49.256481355236424, 49.879141930610906, 52.43862967337332, 54.04851551978819, 68.47816621103595, 66.35150417204827, 69.37525149314635, 66.4164743115825, 64.96192216873169, 67.37881214387956, 64.15216453613775, 63.65245457618468, 63.09540348668253, 61.34139799302625, 65.88280447067754, 61.74611206977599, 66.25269182266729, 68.2544969743298, 69.37441210592948, 69.32006374482187, 67.48797170577511, 70.1857465313327, 74.28769849961805, 76.52318277666646, 76.87451731774115, 77.42908554692423, 76.6622543334961, 23.974048168428485, 0.5438735191860508, 8.66459317745701, 5.401290530158628, 1.33356295766369, 0.28789253244476937, 4.46628475381482, 70.7797973386703, 83.88340057865267, 72.20404917193999, 79.36536358248803, 58.93704783531928, 20.87755068655937, 24.12421807166069, 44.09031975653864, 68.9133139579527, 81.12735502181515, 58.80299298994003, 3.113915256915554, 0.32599743936331044, 0.37385357303484795, 0.1407651014385685, 0.22923616782551814, 0.12818585345221142, 0.14545602633828117, 0.21405625817996843, 0.2649364320020522, 0.24611789582958146], [0.07280879714075597, 0.045701836971866514, 0.04966379090723011, 0.04065709053388527, 0.04524864616893953, 0.09000741741469792, 0.09106491752449544, 0.08069833830719994, 0.0770413256700962, 0.17178328137003607, 31.511366867250015, 84.51123083791425, 65.7326247615199, 57.15065533115018, 25.566238241810954, 23.166604734236195, 45.572810942126864, 65.50349166316371, 56.597573680262414, 81.21353733924128, 9.395899484234473, 0.20450629804643894, 0.11657864080681918, 0.9963680707639264, 5.085065124496337, 1.7043208306835544, 7.942849118863383, 38.91639970964001, 68.26197301187824, 72.33901792956938, 81.32006106838104, 75.00215038176506, 72.36838079267933, 70.49698660450598, 68.54285393991779, 68.41257633701449, 71.2810605572116, 73.97104555560698, 69.5001397594329, 70.6720890537385, 73.80407025737148, 68.84092269405242, 59.18734212075511, 54.38809863982662, 56.94643712812855, 68.81343472388484, 70.9119890582177, 68.83023815770304, 70.57757562206638, 66.43832191344231, 60.29660409496677, 49.54476771816131, 52.559960349913574, 50.56640394272343, 50.273842196310724, 51.456256374236084, 48.26259982201361, 46.666885499031316, 48.63997497866231, 49.189785372826364, 47.608783860360425, 46.85837561084379, 43.69639219776277, 45.088708093089444, 56.77819882669757, 63.68021318989416, 61.71562348642657, 64.22705434983777, 60.61701859197309, 56.6338752162072, 60.53153445643764, 56.406146326372706, 62.01422960527482, 61.569001367015225, 57.5616216659546, 58.59093789131411, 53.181969811839444, 59.94393594803349, 62.01348043257191, 61.842943622219956, 63.15321137828212, 62.21484707247827, 54.815217295000636, 54.93259030003702, 62.52367488799557, 60.67657978303971, 40.03267488171978, 23.729604098104662, 20.567255904597623, 52.179043292999275, 63.201060372014204, 60.111907528292754, 60.330799318129024, 60.53000080970026, 59.396035748143355, 62.846635003243726, 60.29631383957402, 50.92572835183913, 53.417119826039965, 58.67085618357505, 57.664776079116336, 57.92017729051652, 56.813237359446866, 55.408985691685835, 58.44286057256884, 58.90257804624496, 54.439258113984145, 57.709687217589355, 60.205914974212654, 60.07662973096294, 51.10233699121783, 44.42775341772264, 42.400849019327474, 41.1501463767021, 42.79330568928873, 42.33005808245751, 44.74384938516925, 47.63225140110139, 46.154200338548236, 43.82639523475401, 44.55080209239837, 45.734761684171616, 45.31081622646701, 46.05468196253623, 46.28827871814851, 48.06261385640791, 58.075146213654556, 58.947391125463675, 58.07740942124398, 57.05685184847925, 57.34044313430787, 58.08774878901821, 58.62725511673958, 57.386676111528956, 56.796441770369015, 59.721486568450935, 56.98287594702936, 58.78261235452468, 57.266855547505045, 59.805189947928156, 57.93114815988849, 61.502603484738266, 64.27593884929534, 67.777419090271, 70.65080627318352, 74.81572012747489, 68.1123738135061, 71.67830251878308, 41.20602053980674, 0.8253082368643054, 0.4776788953571551, 1.4330991069155357, 0.14444008649837586, 0.1975873902800583, 0.10443893576701803, 32.68762488518992, 73.05296774833434, 60.08632975239908, 58.013141385970584, 54.521894608774495, 21.706031753170876, 17.564554060659102, 27.583226888410508, 45.7266737568763, 58.598582590779955, 58.24742847873319, 9.608155604331724, 0.18478590784774673, 0.104465059365236, 0.03547205424477016, 0.060189996034868305, 0.03665207479629786, 0.07098396804424063, 0.033389371444260886, 0.07838382580948454, 0.05282048684274478, 0.05334421519129988, 0.0871469140533478, 0.048281630396001765, 0.043129804018404216, 0.03856539087850721, 0.020294810585196943, 0.2227039812433143, 0.07365671857710808, 0.13873653125859078, 0.2557308437122453, 39.696143365675404, 96.13170746834048, 73.5488808539606, 63.66935999162736, 37.70357147339852, 31.288954750184093, 48.0288226373734, 74.74663934400006, 62.95257822159798, 89.77077622567454, 9.862599757409866, 0.216267601616921, 0.1456502143053278, 1.32586935114476, 5.8712547056136595, 1.8817467939469124, 10.52851721163719, 41.589024297652706, 68.98433239229264, 75.3412079042004, 81.96391813216671, 80.19409764197566, 75.43519573826944, 71.72179375925373, 71.430142002721, 70.05928147223689, 75.73537472755679, 75.5979819451609, 72.56968467466294, 74.01193234228319, 76.4818488397906, 70.50441557361235, 63.75504416804161, 57.13194170305806, 55.150387748595215, 72.87891649430799, 72.69423561711466, 71.19502728985202, 73.1352904535109, 69.87970752100792, 63.22734417453889, 54.49468120451897, 53.90783579118791, 53.33344390315395, 51.471016253194506, 53.959622844573, 51.142141203726496, 49.69775584436233, 50.01818210847917, 52.857421136671505, 51.64377704743416, 50.044732632175574, 46.52967314566336, 48.1218534131204, 57.60163768645256, 64.28575654183665, 63.346627373849195, 66.49077184738653, 62.52665196695636, 59.64440807219475, 61.09837578188989, 57.037177239694905, 62.382626456599084, 62.35804888509936, 58.550247223146506, 61.07872862969676, 56.711934305006466, 63.90459629797167, 63.69422389614967, 65.7572219448705, 65.09738122263263, 66.16156731882404, 54.283351744374926, 59.01585609682145, 65.10060541091427, 65.65468726619598, 42.85491827995547, 24.215403372241607, 24.9528403435984, 54.405957191221184, 65.12878764060237, 61.809140636074936, 61.254850895174094, 62.23521201841293, 64.9980511203889, 64.12546888474496, 64.19695015876525, 50.927544409228915, 52.66408358850787, 61.21039475164106, 59.84796731702743, 60.80664557795371, 61.5736807546308, 59.952165080655014, 60.93172211800853, 59.23336328998689, 58.185859034138346, 58.74633043043075, 62.11452461058094, 62.693866529772365, 53.095767882562455, 45.82380340945336, 45.18973265924762, 42.83842863575105, 44.69440006440686, 44.9317858296056, 48.02166431180893, 49.059656819989605, 47.417258447216405, 47.262575857100956, 47.35816794057047, 46.88525953600484, 49.340698565206225, 47.639448950367594, 48.692252328318936, 51.93437760876071, 61.269116555490804, 59.00677973224271, 60.87334156036378, 59.31501134749382, 60.25372474424301, 59.58937721867716, 61.13929786989766, 61.96058334842805, 61.88169271715226, 62.00034441486482, 60.185781448118156, 62.27427490295903, 60.54472930969731, 63.62153845448648, 62.126056378887554, 64.65478489475866, 67.95342368464317, 69.63918778204149, 72.3270703900245, 77.77026114925262, 70.37352608096215, 72.3466508619247, 48.85005712509156, 1.284480623660549, 0.10925347661419262, 1.1310875127392432, 1.0938531881378544, 0.10450458184124962, 0.23498516740097156, 32.663670970547585, 79.98618064388153, 67.01414154421899, 63.13035964965821, 53.57337920896469, 22.634280266300326, 19.774972431121334, 36.59997340171568, 54.82917308807374, 63.453005975292584, 68.60863208770752, 11.974109680421892, 0.2547277588277094, 0.14203555100867826, 0.02271498192942912, 0.05013543676825301, 0.08180123678739033, 0.03181091813941396, 0.021032378971276265, 0.1995856846652685, 0.08067800633368954, 0.1541717473657862, 0.13145230680463776, 0.10561651249806728, 0.12270027320952186, 0.14450685872185615, 0.1815955500088392, 0.2675932555669739, 0.19452437157592467, 0.26138717729237776, 0.30334247276186943, 48.27138985356977, 105.06048110223587, 82.29689598083496, 75.0000479913527, 38.594828113432854, 33.00110070936142, 63.82301492075767, 85.0228020452684, 72.54514632686492, 96.92904687696888, 12.870857638697471, 0.4472994335716771, 0.7533002620743168, 5.628207979663726, 15.302077012677348, 6.688392767983099, 16.475351087508663, 44.42911055780227, 73.43088026969664, 75.78903275151407, 86.29718795899423, 83.09054836150139, 78.08243474652691, 76.43939310504545, 76.58815291620071, 73.2745659735895, 77.98821941498788, 79.01778667203843, 74.24016721786992, 74.6645127573321, 80.11312423213836, 69.12400799412882, 65.8644477782711, 65.1417746082429, 59.88315882221345, 75.41932582855225, 76.5047005684145, 74.45756066230037, 76.12853742414906, 73.81767303712907, 66.4045738404797, 56.829766227353005, 58.013604225650916, 55.89659906202748, 52.775859371308364, 55.15777749399985, 53.876570578544374, 51.699753192163286, 52.5119387718939, 54.55823929079118, 52.240287180869814, 51.189778389469275, 49.49012517929078, 49.79412847949613, 60.539959707567775, 69.44768982548868, 65.88944896574944, 66.79769731337025, 63.508578115893954, 61.0697542467425, 64.45977249453145, 60.13511227023218, 65.85817983073574, 64.7835406180351, 57.52490828114172, 61.66624476832729, 61.39347530180409, 64.61225071261006, 65.49374457328551, 65.88683666721468, 68.68343953163394, 67.19009122540875, 59.6393286028216, 61.69649800946636, 68.42437482649281, 64.74940423042544, 47.460808523239635, 22.965238094329838, 22.64076198301008, 57.72894997750559, 70.52905590303483, 65.29422144736013, 64.86944836954918, 63.90199184417725, 64.85360199405302, 67.09149068401706, 65.75955183275285, 53.36616431513141, 56.02214236413279, 67.038679892017, 63.965706825256355, 64.1519291939274, 65.3284715837048, 59.62968741693805, 63.263288774798, 61.14074130212108, 59.61698678232009, 60.29451347166493, 65.64667386393394, 65.23691169677242, 55.60767727513468, 50.085399766122144, 49.54143762588502, 46.902361069956136, 48.64173612286968, 46.625492726602864, 50.11324074960525, 53.10948441105505, 51.76480962384132, 49.17987354340092, 49.422264252939534, 50.50791748108403, 50.6825610130064, 50.2826439949774, 51.1733671926683, 53.85077707229122, 64.3593676628605, 62.541953132998565, 63.373279879170084, 62.960234688174346, 63.34143415574105, 62.26597909004458, 64.62998767052927, 65.0781302298269, 64.19791898419781, 66.34417718456638, 63.98306723563903, 65.51062253213698, 63.46975449592837, 66.20931825330182, 65.47332471416843, 66.86519345929547, 71.64990455873551, 73.13427848200645, 75.67160483329528, 80.28970933729603, 73.40820897010066, 70.93760213544293, 52.769854222574544, 2.0227145716067283, 4.032016353261087, 7.311352424083218, 1.7825300727159747, 0.4013913695610339, 0.3689129494370953, 41.310496791716545, 85.4054763240199, 72.15832218047112, 72.1645587490451, 73.72771739959717, 31.518105499206055, 27.031741642182876, 44.68372729516799, 63.27799374057401, 73.92956256866455, 79.15784666615149, 16.723566516753166, 0.5714303759797927, 0.21037102286373416, 0.0651181323994552, 0.24001058161018357, 0.16275101281221838, 0.20397651760328203, 0.12286087588196802, 0.289017241448164, 0.2060312113814777], [0.10356774824040552, 0.1106231881966514, 0.022724006445177143, 0.02359854177601876, 0.025277341107627558, 0.036516691738319014, 0.11750621240465872, 0.10831434474957567, 0.09564405487429711, 0.7177616884150814, 64.79777097702026, 71.51761085756364, 54.2027235031128, 36.32840025809504, 15.215039618553655, 20.213154131366363, 63.10914747176632, 43.842269066841375, 68.86825376941313, 62.876480317884884, 3.034144298684213, 0.1928386870290964, 0.4215306566367227, 0.4401481866596207, 0.8468455424712551, 2.153451091820194, 12.165644899491342, 57.91254435816119, 64.8496247106983, 72.0683979219006, 77.71872120518839, 75.29982689888247, 75.15657409544914, 73.22914492699408, 71.3738089223062, 73.79129902009042, 76.21363716740763, 73.8569438072943, 71.48303908686485, 73.36124250965734, 72.8416225987096, 70.8909494646134, 74.90955891147738, 69.37922093176073, 63.49667372242097, 68.78768828607375, 68.93103522639122, 69.98811398783039, 68.46104898760396, 68.72886057822936, 65.55961685795938, 58.41458812836678, 51.127134215447214, 50.95510298205961, 50.1929158549155, 50.140611048667665, 47.65939420269382, 46.050551706744784, 49.35613701420446, 53.08918614541331, 50.70779754269508, 48.0640886675927, 44.51676768641318, 45.192858788274954, 45.81906126391503, 54.4835691298208, 58.4068924380887, 63.296919176655436, 62.98588698910129, 59.61067568871283, 49.620187051834606, 44.899351750650716, 51.91990014045469, 54.550582824214814, 56.78458052296793, 56.12009179207587, 58.59242446960942, 61.10138031744189, 62.50994267002229, 64.24727024570589, 61.70286009388586, 57.99250187412385, 51.95347562912972, 53.98215293884278, 60.09020505412933, 61.960755932715635, 42.4663172998736, 28.649240809102213, 23.976138791730328, 46.398505164730935, 61.681620459402765, 60.150005509776456, 55.08529601558563, 50.94996467713387, 59.12352123568135, 60.13406891976634, 60.12810299473425, 58.75752487490254, 41.6235960683515, 43.52733804333595, 67.96139394083332, 62.10516975771997, 58.07786833855414, 59.664435694294596, 56.98120501733596, 57.28473371075046, 54.31474247286397, 54.45015838069301, 60.17947819925124, 59.54127719325405, 54.52805665231521, 44.93958350150816, 41.29300694311819, 39.158551154598115, 41.498582286219445, 40.724408395828746, 45.24021356336532, 45.80732945472964, 47.821203739412375, 45.86940880744688, 43.74369990441107, 43.82102943235829, 45.612422958497085, 46.571046306240945, 45.24080976363152, 46.831852543738584, 45.002768962614, 51.26578215629824, 54.172285910575624, 58.955945814809496, 56.34536135581232, 57.85796065484324, 57.42501335759317, 59.878212713426166, 59.54908270989696, 59.40592404334777, 55.45705826051774, 57.356764116594874, 57.67846907338789, 59.19188814778482, 61.8729026855961, 65.38806023136263, 68.1109852944651, 70.57115862446447, 68.24437725928523, 70.80316682015696, 68.97770358670142, 68.91731477552845, 67.56392448179184, 28.35744196368802, 0.6451394949709216, 0.9880063742879899, 1.3943908291478313, 0.20881672239592, 0.27119947657469784, 3.860249144415702, 64.15245086916032, 70.10204315185547, 60.56426271315544, 61.56827965090352, 52.33974279895906, 26.1858432908212, 14.35769186865899, 29.711836384188747, 56.07111315573416, 57.30606748211769, 33.05683758951003, 0.5652692517445934, 0.08114211771997713, 0.05558018452457844, 0.07822736767270873, 0.07681582002870499, 0.045658905404589833, 0.06911296682852892, 0.1055472351670746, 0.009494760625755355, 0.14613479556095216, 0.12618631800456395, 0.015844492835082834, 0.04678757508255301, 0.017456816802282008, 0.07783284771346277, 0.037932755470636396, 0.04779724449279809, 0.10118261775782994, 1.4030329138040545, 75.78036431343325, 79.63960001545568, 62.29759339363345, 45.840465637945364, 27.34281109225366, 28.36599469184876, 63.9920533857038, 53.42001845759731, 73.3369630382907, 70.63880382045623, 2.332553868332217, 0.1777296711600596, 0.8709282211719022, 1.2542366981506348, 2.228111937161415, 1.428393733597571, 15.067361400973413, 60.735940933227546, 67.38751196092176, 72.94689901413457, 81.98127854254939, 76.65241702910393, 77.09764526736352, 74.20157894011467, 74.47272454538654, 75.37477554813509, 76.1899225173458, 76.89513329536685, 75.59985683810326, 75.38227511990455, 74.00013385280486, 73.46400076343168, 74.06850076490834, 74.91620340654927, 68.54892576894453, 70.24012627140169, 70.03315064214891, 71.84783520237093, 70.2509206341159, 70.62283192911457, 69.12239197761782, 60.52251300504131, 53.92526680423368, 51.48616052442982, 52.015739333245065, 52.02502358344294, 50.578116140057965, 50.432172590686434, 52.670673170397365, 54.611108918343824, 55.124358900131725, 49.99194537439654, 46.15837766278175, 47.90658981569352, 49.83425432635892, 55.588355679665845, 61.06633001758207, 66.62026497625536, 64.49022577654931, 63.09192042196951, 55.96778223591467, 46.57493337508171, 51.73225002904093, 54.81348360738447, 59.41811084747315, 59.039060838760875, 61.74907738162626, 64.07535668342345, 64.01299884242397, 63.472778643331225, 65.18962360197499, 60.279098556887725, 53.119368783889286, 58.46263324060748, 60.94370103651478, 65.62102940774733, 43.91583311942316, 27.350059632332098, 27.409444316740963, 48.49495710865144, 64.19801704345211, 61.500234373154186, 57.56344949045489, 53.52905250364735, 61.683942502544774, 61.95919875175723, 61.14340459146808, 60.36401002637802, 46.24475609871649, 43.53765387688914, 62.821229811637636, 62.08304758994811, 60.913891023205174, 60.20699362601004, 60.69079053017401, 58.86771994252359, 55.198829020223315, 55.839948269628714, 63.13837305192025, 62.82646225344751, 56.12916423428444, 45.75945692677652, 42.15593230339789, 41.94230433433287, 43.209798643665934, 44.915876696186686, 45.65629466887444, 47.6514906267966, 50.055640743624785, 48.91423494585099, 46.468495938085745, 46.975795684322236, 48.14998857436642, 48.56123731982324, 47.56051517301991, 50.323989698963786, 47.32665954097625, 52.82151576011412, 57.95484319809945, 60.70440115467195, 59.6430548544853, 61.52620438606509, 59.80167158188359, 61.226413711424804, 61.46940062122961, 62.06152946718278, 59.26391463125906, 61.12179625418879, 60.084360722572576, 61.537143876475675, 64.85731255623602, 67.9478068505564, 70.46115967535204, 71.98584771925404, 70.79086626729658, 73.0660213962678, 69.83209779185634, 71.87413861674648, 73.77028296070715, 34.602694665232015, 0.26128154908937795, 0.743716502141568, 2.0101412914453016, 0.7647112949240593, 0.27476059032544015, 3.3592916255997074, 70.64200447451684, 76.70464731031849, 67.63585290601178, 60.343707838366115, 46.06904568210725, 37.068645646495206, 23.781173459945187, 36.87857935505529, 64.85138193253549, 64.94247505741735, 42.32131904171359, 0.6960896126204922, 0.12121089103241121, 0.012331995024015347, 0.08341963583182904, 0.06780561480310655, 0.18793708795020658, 0.026468831910601547, 0.09252453718574778, 0.04010880140647773, 0.34800947433517826, 0.24433122557257456, 0.10343457151564861, 0.1015223394478521, 0.14250805871861597, 0.12079686647461307, 0.15622204379929652, 0.34009164920256985, 0.2229322601229914, 2.513904162952977, 88.56074071699574, 89.16243230142902, 70.67111630593577, 52.09121750247095, 22.454210135244555, 30.226582750197384, 83.88126680927893, 59.97649946520406, 83.06540596869685, 77.09658622741699, 4.026826812374977, 0.4845894680869195, 3.40930282588928, 3.646492962875674, 6.48273995807094, 7.925193059828974, 15.504284020393127, 65.20256742354363, 70.74809674293765, 75.30168610234415, 83.50107931321668, 81.7573739636329, 80.6572981803648, 77.95966456013342, 76.13807662840813, 79.55657912838845, 81.36745114480296, 80.27211358470302, 77.66719695060485, 77.99379702537291, 75.35557162377143, 76.2919512102681, 77.1980893227362, 75.86354994004773, 69.47957085024926, 73.23307514190674, 72.11549774292978, 74.44054542049285, 73.99827464934319, 72.98365162264916, 70.87958243585402, 63.19079945164343, 54.522894813168435, 54.617490614614184, 52.94076365809287, 54.921976366350734, 54.1488693606469, 51.56152102255052, 54.822210881017874, 59.15182113647462, 57.42915930286531, 50.62971884204496, 49.35471319383191, 50.67375529196955, 51.03721780161704, 58.91689077500374, 62.52768355031168, 68.24983719856509, 68.30962980947187, 64.58134635802239, 57.39449731765255, 48.8753132666311, 55.029747409205285, 56.835398750920454, 59.38473539967691, 61.403747989285385, 64.85941102427822, 67.90014220822242, 67.44862248820644, 66.77330801563879, 67.74898975126206, 63.34273246026809, 56.76996184933571, 61.18307152102071, 65.11143899733021, 68.3947217079901, 47.03687091027537, 30.706947580460582, 27.803844521122596, 50.042198781044256, 65.7973164127719, 63.092700973633804, 59.3483671834392, 54.64425294629989, 62.38555254474763, 65.68335194741526, 66.23726121840939, 64.06925347543532, 48.20140300258514, 46.305494000834805, 62.67321132844495, 66.8427025887274, 63.36121859089021, 64.7021867382911, 63.54049836435626, 61.43957491843932, 56.93160664650702, 56.99329768457721, 67.82120843087473, 65.05145811265515, 58.0909376759683, 50.76568780406829, 46.29999091548305, 47.758579177241174, 46.53500364672753, 47.71515461706346, 49.71436315967191, 50.37443137937977, 55.582452512556515, 52.89848835237565, 50.32214226261262, 50.37116012265606, 50.51203204739479, 52.57501832900509, 50.49640140225811, 52.617544666413345, 48.96775568685224, 56.47731381077921, 59.90510056095739, 64.73346371804514, 64.08416632683047, 63.91823437906081, 62.308513272193174, 64.47913331370201, 64.61436879250311, 67.52688946262484, 62.43026756471204, 64.85447276023127, 62.25654578978016, 66.45179133261404, 67.90228382233651, 70.0536254144484, 73.52595067793324, 77.56892588830765, 73.02362057470506, 75.55369054117511, 71.40195585066273, 74.0472807422761, 74.36236473821825, 36.34823568405644, 1.4070586139155974, 7.8564084153021545, 4.845260237493823, 0.7560762582767395, 0.31498765272478907, 5.601599601007277, 81.03731309213947, 80.46835760916434, 77.32904941804948, 74.7652784470589, 69.34864213389736, 40.321820243712395, 27.426083011011926, 47.39949011033582, 72.40747897855698, 74.35007203009822, 55.52008290444651, 1.1292513532023276, 0.2413558320052201, 0.22410414482076324, 0.16054189103024621, 0.15709351477844102, 0.1976450000919642, 0.1280477124777052, 0.3012619924641425, 0.2815049526191527], [0.023574576630527457, 0.026779084113396467, 0.07837994940458767, 0.10611905085463678, 0.015640857088710033, 0.04426226583159259, 0.08939670744322001, 0.17583233184151112, 0.4473511291848075, 6.012815986910175, 79.95440160074543, 66.08682263282039, 55.93796830023489, 27.712998505561586, 14.78074694833448, 27.96957446682838, 56.562484156700876, 52.18260480511574, 76.81151620803341, 39.846519193341656, 0.07344511743154257, 0.14768033198291255, 0.0718805590464223, 0.5864976094134393, 2.230654368477483, 1.7619824914201614, 30.951442641596643, 66.20088515743133, 70.42199873155164, 71.32038624055924, 72.3261054869621, 76.51420839371221, 77.2028903038271, 76.9102579547513, 74.13842878034039, 74.59088986919772, 73.70528144221153, 76.04288854906636, 69.08026572196715, 74.55226236774077, 70.6016589749244, 71.53756003226005, 72.28284174396147, 73.98381679288804, 72.50180413646083, 67.25265302965718, 67.60183811187744, 67.63989294728925, 70.13923506582938, 68.34724533942439, 67.04759936178884, 62.81747610338273, 53.53367697808051, 50.44487714767457, 51.6257929801941, 50.4214096069336, 46.78286606265653, 45.45461816172446, 48.13431086078767, 49.08276350267472, 48.189553522294574, 47.508586914308616, 45.75305169628513, 45.027020977389434, 44.22711633866833, 47.72972622225362, 50.30856693944624, 59.791908802524695, 62.11070029966293, 63.791851689738614, 63.973229931246856, 60.050879370781686, 50.46676397323609, 59.52753713054042, 59.77680375499111, 60.180023408705196, 58.19197008686682, 60.64979391713297, 60.52630985936811, 63.05032760866227, 62.23834206981044, 57.68668643889889, 49.8264370426055, 59.23075099145213, 60.61256277945734, 64.3763123020049, 40.20211735079366, 25.656405687332157, 24.97190502382094, 39.29020158706173, 63.74948224713726, 59.337561053614465, 53.30459879290674, 48.11546387210969, 52.65763128957441, 57.87294410890149, 58.02244132564914, 56.7310284030053, 52.449459337419086, 53.073178952740086, 47.6759309153403, 54.26744261095601, 58.805103225092736, 58.600885022071104, 58.48279814566336, 57.283439328593595, 54.74149634761196, 59.08721185499623, 59.197677566159165, 59.062026316119784, 53.55736024918095, 44.51711677735852, 37.714577644102036, 39.94697109345467, 42.311975955963135, 41.66885629776986, 43.581494208305116, 46.77513114867672, 46.19458898421257, 43.35801324536724, 42.8040922072626, 43.04565137432468, 46.023538343368045, 46.186701097796046, 46.93576005197341, 48.47045798455515, 45.48135303681897, 45.8252429193066, 53.06691100520473, 55.9005057427191, 56.250251723874, 57.38729192364601, 58.85317187155447, 59.60855760881978, 58.38622546965077, 59.91769921395087, 57.9018323652206, 58.39362305979575, 59.35519995227937, 62.5940735878483, 64.99952200920352, 67.09422849839734, 67.29818390261742, 67.49778547594624, 66.84428722627702, 73.4078481120448, 73.46673073307161, 70.59725807559106, 70.83129805903282, 79.89475803990518, 18.290484759115405, 1.6701710825004887, 0.690922747936941, 1.1866820843950396, 0.12643822303582586, 0.043624095438468846, 35.83537793928577, 72.24534388511412, 60.419229153663885, 58.98241396873229, 54.92949162760089, 15.177995774053759, 17.01612630198079, 34.2117481077871, 43.30792065589659, 55.836504428617424, 57.051905739691954, 4.850551514856277, 0.16019413307789834, 0.08102852220256483, 0.04857603415486313, 0.15016642519302908, 0.09886386879389325, 0.13593977407342003, 0.04893935901383239, 0.01747299657924281, 0.025712061530700134, 0.06408353448815404, 0.015671051486635643, 0.07018434079063517, 0.04360856683624368, 0.060425058623114904, 0.1403369961847221, 0.1088708846439277, 0.48722882484716756, 9.267362433095133, 92.85902300188619, 71.31046264402329, 63.35395828370125, 34.279201107640425, 17.77565210096298, 25.622969442798247, 62.01277440594089, 57.521817453445934, 86.75160238819738, 44.74532419635404, 0.09331522419327691, 0.27727014114779813, 0.4121036382932817, 1.6374588829855767, 1.7018838130658673, 2.3627173852535988, 34.81091760819958, 69.70057287523824, 72.61476839742353, 72.01012719062068, 77.01186303169497, 79.49490377979895, 80.98379627350839, 76.40209920944707, 79.25682375507971, 75.6916795238372, 76.27927410987117, 77.34513113575598, 72.08793917009908, 75.46555488340317, 73.68016258362802, 73.59931468963623, 73.92673846214049, 76.15708443426317, 76.2284480371783, 69.3194361655943, 69.67688175939745, 69.60633400947818, 70.12343575877529, 70.5496483464395, 71.02516512716971, 67.03380830826299, 55.247929250040364, 53.51313160311792, 51.60386300856068, 53.21342329825125, 50.155159119636785, 48.08968605533723, 50.033663703549294, 50.52723907655286, 51.36825015467983, 51.34719487159483, 47.49487823055637, 48.51699690664969, 48.28239602427329, 49.31287327120381, 53.43848889873874, 61.567106862222, 63.37159325999599, 64.69134530713482, 66.00207590287732, 63.0678919822939, 55.896548071215236, 61.96678853804066, 62.93706524756647, 64.35880676392587, 63.543965739588586, 63.02969594155589, 61.734105694678526, 65.44075335225752, 64.5850137741335, 59.24049023658999, 49.761870907199004, 60.1436238135061, 61.51530411935622, 68.12156000444966, 39.950567906902684, 24.830699697617565, 26.21364308941749, 42.07295848477272, 66.64552504016508, 63.396974917381044, 57.06029176712037, 50.50258698001985, 53.639726100429414, 58.098892242677756, 62.02216063776324, 55.95644658611667, 54.28387734197802, 49.43947169088548, 49.422244641088675, 54.98012158178515, 58.912521254631784, 58.744792861323205, 61.892812636590776, 59.451980513911096, 57.68818478430472, 61.62231030002717, 60.211853442653535, 58.724859376107496, 55.915089115019775, 46.70303406253938, 40.859106509916245, 41.905210479613274, 43.76252728123819, 44.13237933189639, 47.49352109047675, 48.47530603408814, 49.66978150029337, 46.33661408578196, 45.42081909794962, 45.20101731823337, 49.83594094553302, 50.3287906800547, 46.87608118980162, 49.30608364843553, 48.3191760893791, 48.937404386458866, 55.17705594339679, 58.82413064279864, 59.1408855684342, 60.19156694412232, 61.27062666800715, 62.25823240895426, 61.661957617728945, 62.38825898016653, 61.79074471996677, 60.9318672457049, 64.07261886904317, 64.55360735616377, 66.25269182266729, 70.19204585782944, 70.2991657872354, 70.50141888280069, 69.87262372047671, 74.41588155684933, 74.90216916607272, 73.85121714684271, 71.75199600958055, 86.41818523406984, 28.82573373856083, 1.3944329946271836, 1.364963614652234, 1.2485144503654972, 0.5063898789305841, 0.06539934029382083, 36.615525599448915, 79.40480693694084, 66.2377005238687, 65.6728909861657, 52.354439919994725, 21.92779079560311, 24.621445171294678, 43.084251419190444, 49.95853854763893, 63.289450983847345, 67.25452007785921, 5.967026237518557, 0.1956098415558377, 0.07933008229179729, 0.07390349081927731, 0.17612163728523642, 0.06525128614157438, 0.051195832690404314, 0.06099916491357069, 0.035553209769028815, 0.0915613808038254, 0.09399033917654907, 0.19149516799276878, 0.2954814300662087, 0.14665866180533363, 0.13748382428480735, 0.3718749517875333, 0.35286172202998595, 0.5269727615579483, 12.288545504693063, 106.0982382682062, 81.25680892698227, 72.6757690983434, 40.555922985076904, 22.399147902765584, 40.23830121563327, 76.64204628236833, 69.94650548504245, 93.99205453934209, 50.4157849281065, 0.16238949592075042, 0.33722568363431965, 0.8928482030187884, 3.85630740754066, 9.219209455674696, 3.9251256373620804, 38.56916404539539, 73.71170628455378, 77.0496746801561, 75.62604258137365, 79.28684557637861, 80.86720774250647, 85.29417514801027, 81.01533997443416, 81.90850288637223, 79.16391065043788, 79.51073446581441, 83.34230176864132, 72.71065465865597, 77.93281201393374, 77.94692470181373, 76.87233647992535, 77.64198395513719, 79.71561554939517, 79.47973205197242, 72.0749875037901, 73.12359394565706, 73.77100467681885, 74.4169641310169, 72.45864237508466, 72.31870789681712, 70.58345133258452, 59.16410992222448, 54.70583808037543, 56.54642989558559, 54.207830429077156, 52.11613632017567, 49.28125504524478, 53.385066216991795, 53.33124737585745, 53.35870788943384, 54.31429140029415, 49.407394547616285, 50.49229075831752, 49.23896012767669, 53.87738250917005, 55.01920015581193, 65.72159897896552, 64.93169638418382, 68.58909083950904, 68.66637722138437, 65.2026850946488, 57.356866098219356, 62.87438969458304, 66.05327852310674, 65.79462958920386, 64.95384208617672, 66.95031673677506, 65.62962332079488, 65.920851461349, 64.27616634676534, 63.14160508494224, 54.39002844595141, 65.13752668134629, 64.65446326040453, 70.6332262100712, 42.74422899369271, 32.52235581797938, 31.003741564289218, 42.70466796813473, 71.81454996908866, 64.79231496011057, 59.26985309969995, 52.22589208233742, 57.01553752345424, 61.812247153251406, 65.7952493236911, 60.49149097934846, 55.864298343658454, 51.26822971528577, 55.42149413016535, 58.71101340939922, 62.097780012315326, 62.83639369472381, 61.90444246415169, 60.4040103573953, 59.69343377697853, 62.707112373844275, 64.79806907715337, 63.099314089744325, 59.05444045220653, 51.02197154875725, 44.309525335988695, 44.18666101271107, 47.47525461258427, 47.309036331792036, 48.95203090483143, 52.14241227796001, 51.7003180134681, 49.0209783277204, 48.439412424641276, 48.6543857666754, 51.74242465726791, 51.80773996537732, 50.677234434312396, 52.82626967276297, 50.91625190550282, 50.73024918956142, 57.95159547559677, 62.45718286883447, 61.93124009716896, 63.562789194045536, 64.65168229995236, 64.91676392093783, 64.51445817947388, 66.59797806893626, 62.775196875295336, 64.45837220837994, 65.32559256399831, 66.49228588227304, 70.36514005353375, 72.79202815025084, 73.26403833204701, 73.7132203194403, 71.12546013247582, 77.55810014663204, 79.78904231902092, 76.19469211947533, 73.87596730263003, 86.69494767342844, 29.79928758836562, 3.7545155277175293, 4.933905313091894, 2.0492163108241175, 0.41364243314150845, 0.20734718189604823, 44.64716688279183, 86.35656479866275, 73.57692580069266, 76.850339827999, 70.95668838870141, 23.44852116800124, 29.323478591057565, 45.60894773852441, 60.18966851695892, 72.60519781420308, 82.082381556111, 8.226297728476986, 0.612350135080276, 0.1995325334850819, 0.21478781086062232, 0.35072706399425385, 0.18601883443132525, 0.2193793894783143, 0.21810265798722545, 0.1160440186879808], [0.025285557400615468, 0.044961091236121235, 0.07380206843898182, 0.020554799759279818, 0.11114144667742715, 0.02433818051471345, 0.12212916998372925, 0.16856658542829175, 0.457137442764736, 17.04286313826038, 78.83102693865376, 58.20780077288228, 48.78992719034995, 25.497530083502493, 31.983753596582723, 47.2624268070344, 54.349227951418975, 52.0502483460211, 83.83284907187186, 20.853292788228682, 0.2729272193485691, 0.3913719813910223, 0.21850238734435654, 1.0242265210516992, 0.9997069883731105, 7.553825993691722, 51.00861980069069, 71.19648641155612, 74.8277461144232, 75.13642880224413, 73.79128333060973, 73.1908312151509, 73.27930419675766, 71.06362788907944, 69.22493057866251, 79.31287442484211, 77.76844901423301, 69.9338597636069, 73.9352107817127, 67.22772244484194, 68.71663847277242, 67.12723132102721, 65.4216004187061, 64.51742741369432, 63.85878301435902, 65.94099675455402, 65.90504430955457, 64.97488167978102, 68.38534724327826, 67.6705894162578, 66.91590186088317, 64.59871853551557, 55.156914572561945, 49.39035184921757, 49.870893186138524, 49.012141227722175, 46.5848099031756, 46.19791123174852, 46.82046982549852, 48.32300432266728, 49.088980459397845, 47.97840056880828, 45.00499686887188, 43.25069719745267, 45.82651768961261, 45.38462738836966, 44.37740587419079, 48.82386353708083, 56.34432585008683, 58.61183627959221, 59.28384027173443, 60.82748120830905, 62.9373162792575, 64.881713621078, 61.85040789265787, 60.300671592835464, 56.87130804984801, 53.74019369002312, 55.95164560502576, 57.822063123026204, 53.57150039365215, 48.4527837845587, 52.45401320918914, 60.84479455024966, 60.720043566919145, 64.83765363693237, 29.07523374403677, 17.83956516173578, 26.287789613969867, 34.88029649180751, 62.040627156534505, 58.85650588620094, 58.8441425754178, 47.21830014259585, 50.42461418336438, 51.178207397460945, 59.22633832500827, 57.18831792954476, 55.99074771327358, 48.24397640843546, 53.74181755127446, 59.27131614377422, 58.71508482963809, 57.24469023366129, 56.95829445315946, 59.34183251473212, 59.78905331703925, 59.788841509049945, 56.292103413612615, 56.57168603712513, 50.61258200676211, 40.623913349643836, 38.1787391631834, 38.9629307869942, 41.77394443942655, 40.487297196542066, 43.418723690894346, 44.53343775964553, 47.09851880227366, 44.550633430480964, 44.57057868280719, 41.827704445008315, 45.55243815145185, 47.041636590034734, 46.327706383120635, 46.8896996590399, 48.59620132753926, 45.25476555670462, 49.108894332762695, 54.21333743679909, 54.22900730563749, 55.50875902175904, 56.97674136007986, 57.47829091164374, 58.81410114226803, 57.80982532808858, 58.941342830657966, 61.522093742124504, 64.8369005418593, 65.27859080222346, 69.77616479319911, 66.99788724222492, 72.13530571229997, 69.21258295736006, 70.46316792888027, 69.48635655064737, 70.78051121004167, 66.06051921844482, 68.71466944294592, 69.63608126486503, 68.06242635173183, 4.213457107543945, 1.1146665100128421, 2.244857516019575, 0.0968770657275473, 0.23699694493364906, 10.10812444071616, 72.42906770398541, 67.05571866804554, 58.846621513366706, 63.30172408011652, 64.00778993483513, 18.549359229303178, 15.388291689657397, 44.7284266256517, 50.14174853601764, 65.75426055539039, 16.888139363258116, 0.4194050384384971, 0.12703610103457205, 0.0423113769671369, 0.02565706599383585, 0.0981633426741727, 0.061879629764946244, 0.040809476913343516, 0.021739026133511818, 0.04308925115413243, 0.0869871081123429, 0.012955632729215488, 0.04223548063647844, 0.026231618530507532, 0.03128514625132084, 0.08608231230849221, 0.0923276679109662, 0.525496356910275, 22.277197491738107, 91.26417160034181, 64.39441796272033, 58.3119357785871, 36.61884784698486, 36.697424688646876, 45.615529475673554, 61.89933946055751, 60.76543715692336, 92.32913432582733, 20.506872976979903, 0.27968595345174113, 0.3026989589054739, 1.1635393649339676, 2.0838152929659812, 0.8053797771853786, 8.807817543706587, 55.83501392795194, 76.15671573146697, 79.05780269253638, 79.91495824629261, 75.62543853636711, 74.31264477391397, 74.02213050473121, 74.00582913429507, 73.81299757188367, 79.24586465281826, 80.14061220230596, 73.82853015776604, 76.18625902360486, 69.72454640173143, 72.24511638764413, 69.30773965774044, 68.5244188001079, 67.73102529587285, 66.66707454189178, 68.13703767714962, 67.9544827245897, 69.61188024090183, 68.8503050035046, 68.39510610026699, 69.33999723003757, 68.1871263442501, 55.171105707845385, 51.84864244153423, 51.479061034417924, 51.91269474644815, 49.38522138903218, 47.32459637426561, 49.454749322706654, 51.76864962424002, 49.22154088174143, 50.341659976590066, 47.393484961602, 45.8139661050612, 48.100307833763864, 49.49144309566867, 48.9793659025623, 52.40496397018433, 59.72443226845034, 60.95885707486061, 62.265884953160445, 63.43065631005072, 65.39079412337273, 67.04475956578409, 64.63709108291134, 63.13790628986975, 58.28027048418599, 55.445122488083385, 58.758466243743904, 59.227930807298236, 54.91155855117306, 50.83540401151104, 52.28891672626619, 63.66819112531601, 61.49253083813576, 67.64330540933918, 31.02347500862614, 19.025978196051813, 26.44692997778616, 36.156384714188114, 64.08836718528502, 60.302664156883, 61.92099486627887, 51.11648105805921, 51.73213628030593, 55.209705752711145, 61.018469256739465, 60.96333249922722, 57.06342574088805, 52.97310752253379, 56.39557161638814, 59.346613883972175, 61.103027712914255, 57.99592610328429, 59.26025898225846, 61.03782223116968, 64.23544822200653, 60.37115266246181, 60.11382948967719, 59.598100569940385, 52.276600483925115, 41.92496745817123, 41.094507555807795, 42.65815258026124, 44.7862619738425, 43.56871512628371, 44.90420372255387, 47.78112496099165, 48.29280599471062, 47.144469368842344, 47.8120332379495, 45.751447446884654, 46.3395558634112, 48.20150498420962, 49.22995436576105, 48.37559938430787, 50.80533119939989, 46.71854311420072, 51.41777400047549, 57.82662091716644, 57.423813112320445, 58.514541887467914, 59.88385308173395, 58.47297260838171, 61.43553095479166, 59.86501393779632, 62.40976141345117, 64.30682751440233, 67.9855400516141, 67.02797182144658, 71.5287111651513, 68.84566091722058, 75.92761793444234, 69.88060966614755, 73.61624363929995, 69.57150336234801, 74.00001618169969, 69.33402738263531, 75.1077562762845, 70.6649346505442, 76.97977019894508, 15.622050243039286, 1.1417905577728826, 0.016857291714498596, 1.680247161176897, 0.27848720971134405, 9.749657069483112, 79.28029521819084, 70.57324532539614, 68.45777773088025, 61.7091594203826, 47.27364478572723, 24.865446013789025, 27.9615806764172, 50.48880377123433, 57.85148874405892, 74.74157164173742, 22.02944294098885, 0.43137277206105573, 0.11810188407018302, 0.047747713078053734, 0.06160399899066937, 0.030234636693832376, 0.06658733582064029, 0.03336827721326582, 0.0637911761840505, 0.1853929405971881, 0.3204428729030394, 0.1711347572986157, 0.18362772080206102, 0.18976803808923692, 0.18425756764988746, 0.25497728898640604, 0.32933936003715764, 0.6994829531158171, 28.949682597191106, 104.99418520158338, 74.69174185106831, 69.28593127958237, 37.12866967724216, 46.20377909752631, 67.21940702007663, 73.37514338954803, 67.42687686797112, 98.5818552201794, 25.366417015752486, 0.5197278987015448, 1.1301488405273807, 2.321758770173596, 4.5840588212013245, 4.081136685225272, 8.901034632036763, 60.459433447930124, 79.16515011941233, 83.07681222115794, 84.38362829146847, 77.7935286491148, 77.01420860905802, 78.58635733204504, 75.526304552632, 74.28343880561091, 82.02189860805389, 82.01785856677641, 76.56108071727138, 77.2555285115396, 71.33661700833228, 75.53518479870212, 72.55923548052388, 69.2003059387207, 71.42382698674356, 68.44735207096224, 71.449126274355, 72.53785071834442, 70.77747529552829, 74.19607193239274, 71.10815463527557, 70.66650359861313, 71.01127209201937, 59.76139276258407, 52.66140068731001, 53.0350221357038, 53.859986797455825, 51.4709181939402, 50.5334246543146, 51.75711785593341, 54.32662725448609, 53.5699353679534, 51.53577066236927, 50.91878575663413, 48.45031269135014, 51.51180105824625, 53.24157414897796, 53.70183290973787, 55.61992291481265, 61.11299837789228, 66.11339276836765, 67.32385189302506, 67.32668384428948, 68.2351283104189, 71.00165444035684, 67.69342545540103, 66.06112326345136, 62.40718833861813, 59.97119642073109, 62.758671929759366, 62.93239370469124, 58.22764012121386, 55.721994753806825, 55.958446994904556, 66.72401951205346, 66.59782117412936, 70.10998987382459, 36.90486315757998, 31.369618292777773, 34.12882920234434, 40.60985165257608, 68.00734058503183, 63.11367780931535, 63.75137282956032, 52.651437867072325, 56.34593794422766, 57.74306266538559, 64.53453679238596, 63.9082754811933, 59.31126548397926, 55.785427324233524, 58.86369951309697, 63.07740765233194, 65.1056456565857, 61.02716122904132, 60.96950238750827, 63.24109208199286, 64.3447332997476, 63.943388538975874, 62.89561363958544, 63.93896018305133, 54.90796958246539, 45.31286370369696, 43.55672444066694, 44.69410588664394, 48.17879446091191, 45.45095859035369, 48.949277400970466, 49.60454071721723, 50.162505718969534, 50.14949129473779, 50.14147789247575, 48.452018922375096, 48.32493020642189, 52.36716016646355, 50.954553850235484, 51.39231389568698, 53.26607327307425, 49.49219619074176, 54.1163097658465, 60.879621275009654, 60.74145970805999, 61.90028475176904, 65.08775964859994, 62.24108772893106, 64.12985801696777, 63.30888632805117, 64.11496869979366, 68.3154349173269, 71.20316228558941, 70.84295534318494, 76.212280027328, 70.15412438300349, 76.01948768861833, 75.24274856813493, 76.79707404105895, 72.44928359985352, 77.35026159594136, 70.2022518650178, 77.67874440839215, 74.86519690482848, 79.59865047085671, 16.018541070722765, 2.9444271902884207, 7.207049737053533, 0.9285732731223107, 0.2596079534099948, 13.272312225834018, 87.73355207135602, 78.18567152946227, 73.45315148753505, 79.21286967492874, 81.84933785469302, 27.919081795600157, 26.844911306135117, 61.21346988985616, 67.30544813217656, 84.96177781012751, 28.734575894571122, 0.6781087323061882, 0.38940157260625596, 0.20818479178893953, 0.1517278043132636, 0.26345877097018305, 0.1825003304909314, 0.16541365864536456, 0.16360310176687856], [0.07609228828861829, 0.07714408870425916, 0.02544115177325664, 0.053640748674590746, 0.029727384981308735, 0.006357870935913056, 0.10882282028755835, 0.15397224274854507, 0.32351225013694457, 34.09805428597235, 73.43986249739125, 60.24696257806594, 46.28330907514019, 17.286964001194125, 23.48494233623628, 43.2198909021193, 53.47174275305964, 68.57263257426601, 74.31878720560383, 4.968527584306655, 0.31359441458217563, 0.3421771243935631, 0.7699629808625867, 0.5551210382292348, 1.9165099027656742, 27.330663511829993, 72.28332027312248, 76.69492767703149, 72.40512555645358, 73.00771144128615, 76.09143180231895, 74.8871543330531, 68.43988387815415, 66.84750356981831, 69.30974006652832, 69.90194735988494, 64.47355178094679, 69.6603136677896, 69.63484964063092, 66.06728138462191, 62.70150338449786, 59.63043658964096, 54.32509753011889, 52.367258225717855, 55.7158209431556, 55.589924627734774, 59.69660697444793, 67.53634237474012, 67.77303388041835, 69.54146585156842, 66.89568596501505, 61.68733143037366, 50.83473328621157, 49.699717029448486, 48.37180252998106, 48.801309908590014, 46.445852095080966, 47.957219769877774, 48.91891041109639, 52.092860975573146, 49.59291873439666, 48.30116456554782, 45.032225962608095, 45.84291711930306, 43.98263500582787, 43.9798540453757, 42.916593628544966, 45.70073904529695, 49.90423333260321, 55.19540086869271, 58.45625154433712, 62.52132146589218, 60.88464583120039, 61.38641111312374, 58.496659801852324, 53.84890610171903, 47.18061793235041, 50.48697202436386, 49.274747833128906, 50.03402848397532, 45.044703022126235, 56.03810248836395, 58.33049251187233, 65.30461965068694, 61.193006884667184, 65.04262885739728, 19.085988498503163, 10.545256906940091, 27.685943957298036, 27.18451992157967, 62.4034660093246, 58.548858704105506, 58.98144906566989, 51.892117992524184, 46.09108155773532, 51.25202640410393, 56.269373278464045, 57.869464966558645, 61.703621033699285, 59.81554500518307, 58.861761862231845, 59.32653919343026, 59.45585189327117, 58.83728627235659, 57.07527129880844, 57.96041296374414, 60.40384954021823, 59.359593006872366, 56.17169841643303, 51.071040399612926, 43.10727573210194, 38.1713572625191, 39.88018881890082, 39.23044819985667, 39.945500204640055, 41.64112514065158, 43.36301818970711, 44.2853674580974, 48.056734223519605, 49.127168655395515, 43.82138244567379, 43.77376487178188, 45.8087375856215, 48.01420004137101, 44.17194427982454, 48.02937961393788, 45.27230639611521, 47.86346727801908, 47.686442867402114, 49.54106107834847, 50.95890768112675, 53.458465530026345, 54.235216417620265, 54.845686266499186, 56.22330896316036, 59.662996184441354, 64.59783207985663, 65.0250566390253, 64.06983006385066, 67.9359063794536, 68.0269524358934, 68.30424831759545, 66.45452130225398, 69.1236000676309, 66.84324387581118, 68.68270997078189, 67.77565402369346, 70.80154295890563, 70.39892735019808, 75.52307251961001, 70.88534047526699, 48.79276306398454, 3.0043345305227467, 1.0633937774165985, 1.9899584905755137, 0.12960664777746125, 0.3515936932977169, 47.227992319291644, 69.23535623858052, 63.25673057186989, 63.163637038200136, 68.34284444009104, 26.19876750053898, 11.400972950843073, 19.461733910345263, 49.571039753575484, 62.52724816722255, 34.9696716185539, 0.7723653100190625, 0.0833533539046203, 0.057748312941722335, 0.06455007054272198, 0.05060651189377231, 0.04397061615881901, 0.062113715591089386, 0.03478169411180481, 0.04218325642268023, 0.06101247952169469, 0.0357249130554978, 0.08204120616879194, 0.047087755144363454, 0.04488033790802283, 0.07528144550780136, 0.14275956538415727, 0.20977552739843247, 42.51043219720164, 82.20844653344925, 68.56606652659755, 54.2129098984503, 22.158647775650028, 27.694957563954016, 45.15849490319529, 60.25165373279203, 75.89740783937516, 82.29109087297994, 4.9579013932135805, 0.30097798834885325, 0.3476077071841686, 2.1948137110279453, 1.1236437121706626, 1.1403253073653867, 31.488338631968347, 78.70760563881167, 80.23760457192698, 76.50116259051909, 76.09806845265051, 79.33744415160149, 77.53024347366826, 70.39564824873402, 68.51091015723445, 70.63136700660952, 74.54226032380136, 68.14760454239385, 71.45950486583095, 71.43509203387846, 68.68671078835764, 65.96037326320526, 61.65392460361604, 58.46746952302995, 54.76385385759416, 57.18121843953287, 56.63985290834981, 62.85613890617125, 67.53271025996055, 70.33995059228712, 70.62532655654415, 68.86590034730973, 64.0546622583943, 54.954669321736986, 52.86454023853425, 51.117732294144176, 52.71512539156022, 49.017832586842204, 49.8964278159603, 51.859491717430856, 52.1830637224259, 52.50127384739538, 49.824558227292954, 48.67950070288874, 47.30030121341829, 45.791267348874, 45.162491798400886, 46.77313858462919, 47.912540051244925, 51.29436446774391, 56.90335381415583, 60.81985612069408, 66.70203070486745, 62.00793420114825, 64.89530463372508, 61.698447427442005, 56.55343917108352, 50.138575338548236, 51.84506131756691, 50.57313080756895, 51.58339608100153, 48.20571368740451, 58.02785811885711, 61.260055880392756, 67.38002807863298, 60.86797575796805, 69.07591189107588, 21.079613547171316, 12.094419560124798, 27.813016983770556, 28.868454233292614, 61.7723213472674, 61.200777099978545, 60.82946200524608, 53.50895035651423, 49.73569300866897, 51.47175758115707, 57.86416192208567, 59.9902512950282, 61.34612837145406, 60.438852771635986, 62.33716226393177, 60.65873692112585, 59.96643466334189, 60.104611919772246, 58.89042654345113, 58.800969046931115, 61.23131275177003, 61.423826602197465, 58.269989951964355, 53.217180928876324, 46.88696968939997, 40.99926456328362, 41.38099747319376, 42.738851424186464, 43.62861756355532, 43.68372686447636, 46.3044898740707, 45.847023840873476, 50.93081566595262, 50.72478140554121, 45.25631881529286, 46.519019988275346, 47.63193368911744, 50.85360380911058, 47.79203307244086, 48.360255072193766, 46.19258465305452, 49.56195946662657, 49.04809367272162, 52.950196958357296, 54.71549495573967, 55.359583439365515, 55.148858024228005, 57.54934856968542, 60.67417929249426, 61.56826003905266, 68.64212912897911, 66.90700592533236, 66.59406354350429, 70.33951128682783, 69.47856672348516, 69.41347891284575, 68.5249993108934, 71.62444837631719, 69.66107460760301, 73.17802859890845, 70.11235898540866, 73.73867650185862, 71.50960922241211, 78.43981758240731, 70.73447827369937, 62.33392630853961, 8.271960981430547, 1.3252047545486882, 1.63971878107517, 0.10369368543427798, 0.3605299250733468, 50.46323776245118, 78.3069198362289, 67.9863872835713, 70.60549505295293, 58.51536950757427, 28.39372584896703, 14.81119336620454, 27.616164991932532, 57.24170530996015, 68.93384364343459, 43.88686641570061, 0.8781363118079402, 0.25678902564029543, 0.05866080409877243, 0.07364052347838879, 0.03549416737270451, 0.015211316377615497, 0.08399372680052634, 0.06852114858526377, 0.13146338443602287, 0.1370686352733643, 0.09596111568351907, 0.35124377497742254, 0.06858854900084196, 0.0958106023890357, 0.3265616784413015, 0.3624879538772568, 0.340582374483347, 50.32042426447715, 95.1469179891771, 78.24874324183311, 64.60451187626009, 25.65112029352496, 32.57409776410749, 55.72441093383297, 70.60569117146154, 80.38354812129852, 91.02617786776636, 6.396126179925858, 0.37397222473256053, 0.9538063094500573, 3.745524229541902, 6.439157032197522, 4.607195411959003, 33.226680140341486, 82.13283108126733, 82.36938922635971, 78.88118620841735, 79.8540359927762, 83.5521407281199, 78.68303591205229, 72.4665577180924, 67.8209730886644, 73.31156961379513, 69.92022560488793, 69.02802759601225, 74.49947510996174, 73.8063766110328, 73.94362034336214, 68.82761801442793, 65.10788925232427, 60.73547417117704, 58.03758951925463, 60.6183639649422, 59.35519995227937, 65.43770174826345, 71.07264149573543, 71.93377433284637, 74.2496358194659, 69.64497720041584, 66.2574065116144, 58.40382514461395, 54.784665953728464, 52.46746301651002, 54.25191394744381, 51.34247233790737, 53.538921187000895, 55.2915067826548, 55.95625438997823, 55.65175687113116, 52.69760024163031, 49.66434901760471, 51.006768441969356, 48.44772784940658, 48.70279173697195, 48.44527244567872, 50.67988203417871, 55.015195415865996, 60.305907957015506, 63.39337810393303, 69.24858247080158, 66.65202832991078, 67.30514218730312, 64.34190527085336, 61.03788498909243, 53.46940894280711, 53.98868368517969, 54.74431653176585, 54.50193758933775, 50.607529993980165, 62.88034385250461, 64.05103406598492, 70.68038878902313, 68.65330003922986, 71.65464278190368, 26.470652472588327, 18.51716833729898, 40.19770860671997, 31.859806699137536, 64.71514624934044, 63.92357272486534, 65.33313920420986, 57.06541438256541, 52.18671152668615, 55.31226004323652, 61.57530461588214, 63.69265887045092, 63.21245877973495, 61.65439528803672, 66.37746241784865, 65.56972872826361, 63.276577764941806, 64.0959648163088, 60.85884055783672, 61.88170448426278, 64.69299662497737, 63.6095634583504, 59.80022422729, 56.48847295391945, 48.95034036328716, 43.122620044216035, 44.28059393359769, 44.96292160403344, 46.579691210100734, 47.17064726737238, 49.181364044066406, 47.18211235538606, 53.00997387978339, 54.417975333429155, 47.84939773621098, 49.335297461478945, 51.01600170135499, 54.923007949706054, 50.071173329507154, 51.897770127942486, 48.65347185442525, 53.33117677319435, 51.6623886939018, 55.939529403563476, 56.673020470526914, 60.829575753981075, 56.76964413735175, 61.67612129642118, 64.46043929746075, 66.04991312949889, 70.78931300870835, 71.62651938776817, 68.08931812163323, 72.81618995051231, 74.70348542736423, 73.30928679435485, 72.92480038058373, 76.20197203851517, 74.31368812437981, 75.61867637019004, 75.14306545257568, 76.774198778214, 75.45658834518926, 81.65769869281401, 74.27036162345641, 63.42379216224917, 9.36050303520695, 4.825371369238823, 4.031239478818832, 0.3418992796251851, 0.6922165172234659, 60.217878203238214, 85.77233560623662, 78.20226315529116, 81.4652358331988, 83.94581333283456, 38.84240811870944, 19.959104176490538, 36.331361647575136, 67.7394348575223, 79.80415128892469, 57.026531927047245, 1.1964794296410777, 0.40669223834430024, 0.15446142053171513, 0.17726692341027722, 0.12741657094128672, 0.10804872674446915, 0.1481761440875069, 0.21259447048989036], [0.043337494285116275, 0.0552821533393956, 0.00781409539124598, 0.0560920576625053, 0.08409122681064952, 0.04353681504125557, 0.05544025856520861, 0.10598406616237857, 0.22603102448967197, 50.35808294050155, 70.62144341007357, 49.8670296515188, 38.131984510729396, 24.233008930760047, 48.14431290472708, 54.789710121770064, 50.76922578196372, 74.45828237841206, 52.398421456736905, 0.48286696535445034, 0.1575029121651765, 0.2754073217511177, 0.7341266135054251, 1.6517749212441908, 5.037841258510467, 61.337412864931174, 73.07744333820959, 77.63376266725602, 70.85349082946777, 74.03024981098791, 72.83365234251946, 72.94385525488084, 74.63413792271768, 63.02529504222255, 67.92591218025454, 57.04973274661649, 62.56820947893205, 75.8883628537578, 65.57931892333492, 68.844099813892, 63.94358465748449, 65.88100802513861, 61.721734539155044, 59.650087664204264, 50.42446513329783, 49.56305773027482, 49.533863529082275, 56.8707000824713, 61.538336277008064, 66.52577507880427, 64.55816122793382, 53.0800352558013, 50.171684065172755, 50.143301794605875, 50.31403080109627, 48.769162162657715, 45.772985181500836, 48.2420152233493, 49.69156634423041, 50.14947952762727, 46.94813905223724, 47.462451996341834, 45.306513386387984, 44.54949594313099, 43.01631596780593, 43.06245480814288, 42.586545790395434, 45.26181405590427, 44.736816575450284, 45.07951797977571, 47.02944586353917, 55.29193432100358, 56.60062920662665, 56.39297892970424, 45.774514905868045, 47.318759887449204, 44.55599138813634, 49.09969245233844, 47.02391532159621, 47.87029220211891, 46.37379815501552, 60.561442529001546, 59.5033831750193, 63.75240049054546, 53.8864000381962, 63.899226573205766, 22.13137553584191, 11.671497841035167, 24.44071804323504, 21.501362477579427, 54.16662593041697, 59.3718857149924, 58.82736267582063, 54.46348267216837, 46.409001427312056, 49.822094978824744, 56.484115200658, 56.41938432570427, 58.14197947902065, 57.840047190266276, 57.69872027058756, 57.1279840315542, 57.78347092290079, 51.562191747849994, 53.35431483484084, 57.39159476372504, 55.309518306486076, 54.54635450916906, 48.08489684135684, 42.73449367092502, 38.41317922838273, 38.059585402088786, 39.76573013490246, 38.61232580677156, 39.844628610918605, 41.27061020943427, 44.39981437498524, 47.0905642355642, 48.59330269598192, 46.69545604336647, 45.05610142984698, 43.75741251053349, 44.05872506480063, 47.22758831516389, 45.579322076612904, 47.78137207031251, 46.120134553601666, 47.307294799435525, 45.70557140534925, 48.50556711996756, 45.41865787198467, 48.8468917723625, 50.44603816924557, 53.53643048194147, 53.80458724114203, 59.21034289944557, 59.646129992700395, 64.82046188846712, 65.75659044327276, 69.1811647722798, 66.58878403325235, 68.06532890565934, 66.74446290539157, 66.94792409096995, 61.44724315212619, 65.0703090237033, 62.19991460923226, 68.55185185709308, 68.14340760630947, 74.12320213933145, 71.69292511478548, 73.16235480769988, 22.284328360711378, 0.36178584961641225, 4.685431007416018, 0.0456071944697009, 0.12771064911278027, 17.180859965662805, 76.50952508372646, 62.674937171320764, 57.945162788514175, 63.57066139098137, 41.539461228155325, 18.7246754477101, 17.743396489850937, 44.63258351049116, 63.01032727764499, 50.80888878914618, 3.1975737742839323, 0.2138434389546033, 0.12372990304063405, 0.01711933017377892, 0.09003173304541458, 0.0810545921746281, 0.07297737478849388, 0.08666280011135725, 0.031011363664161296, 0.023778562862125617, 0.026875601615756754, 0.06088427853800597, 0.0936432783642123, 0.03719938716160194, 0.03478587312143176, 0.15972853548103766, 0.37268994676489986, 63.324214950684585, 78.48402269424932, 58.327880213337565, 45.42509840380761, 32.664224024741884, 35.15653725593321, 49.832755980953095, 59.94473611154864, 81.6598246174474, 57.85801556802566, 0.31228627348619126, 0.042107513309606624, 0.6748324500456934, 2.764504393262248, 0.8539392715019565, 6.09542747659068, 65.08201729866767, 76.03468295066588, 79.8645636343187, 77.18801667613369, 76.3773568984001, 76.18553730749315, 74.31571206738873, 75.95143456612864, 63.35891615959906, 69.34792041778564, 63.651144504547126, 65.59270989510321, 78.12463160484069, 69.20418124045096, 72.21617714051278, 68.05185948648761, 68.43234508268296, 63.78135934952767, 62.570100061355106, 53.26841100569695, 52.30240575728878, 52.61243774044899, 57.850119836868785, 63.887871311556914, 65.6582409335721, 65.84877398706251, 56.604704549235684, 52.05129169648694, 52.82912515824842, 51.491251760913485, 51.52221102868357, 49.038742742230816, 51.807971385217485, 52.01213467505671, 51.20463632768201, 48.64913763538484, 50.51001594912622, 45.68893663344845, 45.74573647591376, 45.74535600600704, 46.07681589741861, 44.9641885295991, 47.73705320973551, 47.810778079494355, 48.6121496846599, 51.7121478819078, 56.421106246209916, 58.08472464161535, 58.1238071380123, 50.520939750056115, 50.199819226418775, 46.360242443699995, 51.1908805754877, 48.899471144522394, 51.01171847312681, 48.901502932271654, 62.342759486167665, 62.206763067553126, 65.97165399982084, 57.874779778142134, 64.78854164000481, 24.821407602679347, 13.25167271398729, 24.79134459649363, 22.909348241744503, 57.18141455804148, 61.51163670324511, 60.29020278684555, 56.034286022186286, 49.27390452354185, 52.42652523902155, 59.093530793343824, 57.800827410913286, 59.634166763674834, 59.64669481400521, 58.00962301992602, 58.7361087337617, 58.927798886452955, 53.26333938106414, 55.6744634720587, 57.761168326101, 57.50690460205079, 57.225815788392104, 51.60254901455295, 43.90256766350039, 42.458088167252086, 40.406006074720814, 41.04752540588379, 42.25004957568261, 43.6213376445155, 43.1886649131775, 45.58876322161767, 47.38996267318726, 50.08014771246141, 48.801843350933446, 47.416630867988836, 46.328173145171135, 48.00420584217195, 48.90331506729127, 47.61738561814832, 50.04065336719636, 49.95654598359139, 48.319948796303045, 49.263875023011245, 50.10968708222913, 49.379282920591294, 51.75876132903561, 53.085926655800115, 54.15161501976752, 57.687725866994555, 62.50680085151427, 63.12551160012523, 67.6356646322435, 68.50080613167056, 71.13014344246157, 68.68186273882466, 70.94997329096641, 69.04357587137531, 69.64140784355902, 67.4377732123098, 65.96964574629261, 64.20764253985497, 69.3380517344321, 71.92594528198242, 74.92120050614881, 77.08057511237361, 74.50869267986667, 31.39237000096229, 1.3093787263478003, 2.38323089095854, 0.2531809506997947, 0.1761246250281411, 18.466681549626013, 86.31035927803286, 66.07034083335631, 65.27413106733754, 60.89325151135845, 37.896783505716634, 20.04416665723247, 21.06243552700166, 50.89619290444159, 71.3650385026009, 60.705813207933986, 4.062854763000242, 0.13302462566043102, 0.12100348038779152, 0.09083378879774003, 0.035546678869474324, 0.016142485715869456, 0.0607140806143082, 0.10181719902902843, 0.1878141155166011, 0.15145015872774586, 0.08821322417427456, 0.11234492484119632, 0.24791443329905313, 0.12002957579229148, 0.15679213578902906, 0.32230216829526814, 0.5623369123185835, 72.22517505768808, 87.67877224952944, 67.46559850631222, 55.12332339440623, 37.87621851890318, 68.13899886223578, 76.08452058607533, 66.56499878052743, 88.87978630681192, 66.5777543283278, 0.996897713311257, 0.20559336148923446, 1.480915986241833, 7.095892217851455, 5.297361939184127, 6.0212829132233905, 66.96259375541442, 78.42034693687194, 84.88609175528251, 78.08919691270398, 81.35196562736266, 78.86343356101744, 78.79688662867393, 77.69542232636483, 68.74601702536307, 71.65931824714907, 60.62538892992082, 70.91362076420938, 80.91833976007278, 70.79970728966498, 73.05033976031889, 68.80050659179688, 71.41994384027296, 66.5654851544288, 67.85170878133466, 56.2635564034985, 56.4263229985391, 55.01099455741144, 61.912008716214096, 65.87436353006672, 69.56961277992495, 68.98061398536929, 58.14628624146985, 54.84482334506128, 56.12322576584355, 55.79147561903923, 55.00211431134132, 50.451553021707845, 54.09774126545076, 54.840375377285866, 53.78341428695187, 50.93907225516535, 52.2984363186744, 48.96608083478866, 48.99765983704598, 48.38475027391988, 50.007544640571844, 48.57698955843526, 50.053628567726385, 50.71113155734155, 50.329783039708296, 53.760327216117616, 58.65594725455008, 61.01977540600685, 60.91753882746543, 49.00522216673821, 51.86504971596503, 49.04321424422726, 53.095646289087114, 52.522415422624164, 53.317656363210375, 51.24588005004391, 62.86488579165552, 64.91996457499843, 68.66983675187635, 60.35306269122709, 67.9455004968951, 28.1697565509427, 16.986863459310225, 34.271450504179924, 28.298145532608036, 59.37751823855985, 66.02628477158086, 63.181323005307114, 60.0836782301626, 51.610330996974824, 54.533716632473855, 62.446961172165416, 60.94557592945715, 63.99434012751426, 64.98167914728965, 61.35117253949566, 61.2749687317879, 62.8379116519805, 56.39132368949152, 58.336811450219926, 60.75094792150683, 60.55937151755057, 59.00273969096523, 52.60987251035629, 47.16602671530939, 45.14917535166587, 43.62092187327724, 44.68098163604737, 43.742554572320756, 46.186920750525694, 46.24397162468203, 47.87639148773686, 51.742738446881695, 52.86781933999831, 51.563282166757894, 51.869297642861646, 48.85524249845936, 49.250770384265536, 53.26930138372606, 48.8815616023156, 53.06567938097062, 52.38650529615341, 53.018128487371634, 51.238843317954775, 52.90134776023127, 50.26531104118594, 54.615258785986136, 56.67570337172478, 57.25759483152821, 60.099348099001, 65.93165366880356, 64.22893316515031, 71.14990434338971, 70.18804504025367, 73.91820338464552, 72.00221969235328, 74.47056724179176, 72.78342247009277, 73.77270698547363, 68.81595288553547, 70.18948062773674, 67.62971047432193, 73.97412069382207, 76.10710559352752, 80.06231384892618, 79.68717052090554, 81.5929638954901, 28.798402663200136, 4.178543110047618, 10.200731600484541, 0.32187640727047, 0.2969318183679735, 22.25646580419233, 91.48393415635633, 75.35940770179995, 73.05140664500576, 77.65305288376348, 56.69284805174797, 32.94980395224787, 32.796576561466345, 63.144542940201305, 79.39876648687547, 74.1978213094896, 5.968237759605532, 0.330247204870947, 0.33329562193924384, 0.20407551148485756, 0.24158385041500294, 0.25179710479513295, 0.18102919652817712, 0.1837379455326065], [0.02064914540237477, 0.011372250606185727, 0.11822830389944777, 0.025540936640613986, 0.05646893461685508, 0.1634335665092353, 0.017434276580329866, 0.04053447816160418, 0.5839783445962015, 56.67750373963387, 65.3793643366906, 57.84819003074401, 34.64931203472999, 20.262572073167373, 57.97375294470019, 59.22385938705937, 55.65283160055838, 86.599971402076, 31.93196850438272, 0.12297694586337575, 0.051429612081377744, 0.5834942996021241, 0.9896234939655951, 0.5531732137164762, 34.47255434528474, 84.50543357479958, 74.35913270519626, 78.87080761694139, 73.7216220363494, 70.97830064835088, 72.32160260600429, 73.65441614581694, 70.47393091263311, 69.08379585512223, 64.92952339110836, 50.08046934681554, 70.15060209458875, 73.24639551101193, 71.685653040486, 70.56460826627671, 68.81934965810468, 69.55226021428263, 67.37518787384033, 71.77123915764594, 63.09377962543119, 50.459644871373335, 49.25408086469097, 50.59263283206571, 50.85538848753899, 52.58334159851075, 50.737156483434866, 46.316688445306596, 47.18966684033794, 47.61165895769673, 48.47950297017252, 48.8348344064528, 45.42270968037267, 46.91158256223125, 50.75044939594885, 49.85743553407731, 49.53598160897532, 47.427723330836145, 45.39142485587828, 44.82897266264885, 42.38549294010286, 42.69231250209194, 42.46967484874111, 42.020645833784535, 42.24547609206169, 45.44401207277852, 45.93437110224078, 44.002278235650834, 46.31538621840939, 47.20941989652572, 44.291129419880534, 47.28617675842778, 46.50593888375067, 48.10477149101996, 47.937643220347745, 46.37528081094065, 45.740986485635084, 58.32462856846472, 58.90537469617782, 61.200067150977354, 58.08775663375855, 64.08682961617747, 39.84473059254308, 18.958427136944188, 27.664929859099853, 19.294703698927357, 56.089983678633175, 57.31091945402084, 58.73315911139212, 53.14426798974314, 46.873410055714274, 47.92454250397221, 52.350266518131384, 57.99827952538767, 59.88013075244043, 55.70800758177235, 58.054432176774554, 55.487021246264064, 53.04868767338415, 49.446916349472545, 50.14302722869381, 48.69174634256671, 48.78257274627686, 44.55423024392898, 44.980434986852835, 38.802525458797334, 39.483715641883116, 40.08362647025816, 39.84182019387522, 40.588329607440585, 39.88848463181527, 41.9072618792134, 45.576090043590916, 46.9517005643537, 46.458815528500466, 46.307918025601296, 46.189309473960634, 44.1123713216474, 43.038987267401914, 45.818857300666075, 45.930511489991225, 46.21646796503375, 45.95378291222357, 45.95807790756226, 47.396520876115375, 47.750091168188284, 47.918780542189076, 46.918211367822465, 48.34430671507313, 50.53316185551305, 52.60413016042402, 53.362547889832534, 58.71537116266067, 60.726711596212084, 61.95538228557956, 61.72624918722338, 64.70703871019425, 61.48422325811079, 60.87536550337269, 57.25449615909208, 54.086833154001546, 54.152956470366455, 61.3123881432318, 62.14693907768496, 67.82360892142019, 69.56885184011152, 74.22231258884554, 69.621717545294, 55.92707980063654, 7.43429470446802, 1.539237585759932, 0.6568481376574886, 0.18258596379910746, 2.524439649235818, 53.454558849334724, 70.10824049672773, 55.918548645511756, 60.61097814190773, 62.10174552855953, 20.27010106271313, 22.461184109410933, 42.41230234023064, 51.748727906134825, 62.48000714086718, 11.07640270263918, 0.29156040820863943, 0.16368033875140453, 0.04499710502944166, 0.10435876466574208, 0.012992516989939877, 0.007665082192679327, 0.03644366057649736, 0.12686074350870427, 0.07259980069413301, 0.03403760057183043, 0.10551803189540103, 0.020248159661047885, 0.06533114314680138, 0.035857197287822926, 0.03627478415446897, 1.4109427409787334, 69.13634777069092, 73.06869645272532, 64.6942674729132, 43.362280784114716, 24.075916044173706, 43.3225118729376, 58.567791984927275, 66.11602075638311, 93.07239993926018, 35.4387164884998, 0.18539375265038785, 0.13763423798786056, 1.5481090064971679, 1.3568742164681036, 0.4869819300309305, 37.71440505981445, 91.26637597237864, 78.21488534250568, 80.62456207890665, 76.75085283094838, 73.50789993040024, 75.62247322451684, 76.55766825522147, 75.2332878112793, 70.17991788925664, 69.19503427320912, 58.142038314573234, 69.93128668877387, 73.12830863460418, 74.46935130703834, 73.45355941403297, 71.47936774838355, 74.39927424153974, 70.91025537060153, 71.89130290862053, 64.55607452700215, 53.42615696691698, 50.2811848732733, 52.026800417131, 53.388055063063106, 53.27680880023588, 51.55946570058023, 48.66151663564867, 50.64488272513113, 50.41757745127524, 50.3007378885823, 49.640049934387214, 49.11566042130994, 51.505015357848144, 52.827313023228804, 51.64278861015074, 50.45882901837749, 48.4555176765688, 47.899098088664395, 46.662735631389005, 46.56554714325936, 44.27110572015086, 45.26116686482584, 44.625083938721694, 44.6713992857164, 47.334712166940015, 46.27507209777833, 47.392386697953754, 48.9235858763418, 48.614683535791215, 48.586693502241566, 50.44724625925864, 49.36641362405593, 50.32686479630009, 49.99930374083981, 48.58068835350775, 48.73009535574144, 59.966160097429835, 61.02511375181137, 63.67840497724472, 60.191100182071814, 68.361326648343, 42.164302641345614, 22.53220646612106, 30.7548907110768, 21.897706216381444, 58.29753283531436, 61.07066031425231, 60.55438226269138, 54.42965615180231, 49.18219950891311, 48.38776265421222, 54.76780368435768, 59.40155060060563, 61.49552360657723, 58.50515173327539, 59.430250583156464, 59.21068414565056, 56.690882944291644, 52.18874723680558, 53.32903515908026, 50.511671189338934, 50.11687286438481, 45.56131839752198, 47.332319521134906, 40.30533452187815, 42.28639033532912, 41.4803824886199, 42.392113900953724, 42.935601434400006, 44.67255246254706, 43.287634157365375, 46.802776013651204, 47.95708248692174, 49.70403163663803, 49.187498631015906, 48.30620088884908, 46.83491199247299, 45.228462142329064, 48.92705325157412, 48.322086488046956, 48.02023264669603, 48.24145824678483, 47.654706970337905, 48.59057272634199, 48.88692740471133, 50.0586845028785, 49.00083695688556, 50.77909446531727, 53.06281605074483, 54.88365480976721, 54.94212950429609, 61.83484000544395, 62.25392956887523, 64.49700363220708, 64.17287465064757, 66.48403321543049, 62.740899670508604, 65.00075363343763, 58.92639860030144, 57.60406563358923, 55.79621384220739, 63.62725727019772, 64.72011196997859, 72.17845178419545, 73.53590565343058, 78.81000303453015, 72.58353848611155, 64.30328169176656, 8.826613541572325, 1.0577261976657375, 1.666591184273843, 0.2555564361354036, 2.9494730743669697, 58.68479628716746, 78.70184759939872, 61.417389992744695, 68.24043135489187, 49.31874505935177, 19.56666123482489, 32.09246208590846, 50.940794175670995, 60.28533512546171, 74.2721894479567, 14.994869136041212, 0.39335060263833693, 0.2244063358633749, 0.17766024827236132, 0.06579665647399041, 0.03235095841509681, 0.019646656151200016, 0.008548089498353582, 0.18358576982732744, 0.15302894336562003, 0.1931492590735997, 0.26431124296880537, 0.1933257810531124, 0.2865706630531819, 0.185605468709142, 0.2812838596442054, 1.9574326036437868, 82.78857292667513, 81.53876458444904, 75.48752800110849, 48.87230088633876, 32.21248465199625, 79.98516867237707, 77.32598212457474, 70.17091997208135, 102.7848082204019, 41.471588534693566, 0.20125810056924823, 0.3416415676474572, 2.9812673166874917, 9.312656002659953, 3.67440601991069, 38.1071598299088, 90.34601534566572, 80.64975154015326, 83.20308116174515, 79.61539114675215, 77.3787223139117, 78.60607900927144, 79.39934699766098, 76.48378649065572, 75.77892088120984, 69.46754486330094, 55.44576183442147, 74.19085518006356, 77.0637010758923, 77.20219996667679, 75.93354071340254, 73.9371798115392, 74.36973094940186, 73.34072851365613, 74.92892757538827, 69.96938859262775, 55.104782350601695, 51.58070141269315, 56.292099491242446, 54.85204835091868, 59.0911969830913, 54.37963808736494, 50.32302087353122, 52.78342562337076, 52.2872144176114, 51.71937288776521, 51.06026564874957, 51.99611571527297, 51.96449748931393, 56.32555338644213, 54.273581120275686, 52.78311967849732, 51.995358697829715, 50.73463439941407, 49.594468070614724, 49.60296000203779, 47.05414110614408, 48.020436609944994, 46.995709557687086, 47.41947850873394, 52.52197611716486, 49.82002396737376, 49.50552440458729, 50.546325329811346, 50.16598486131238, 50.67195492406046, 52.747528091553725, 53.98566738251717, 53.81607194100657, 52.504658852854085, 51.142074523433564, 50.54377971156951, 63.27103937825849, 63.49672863560339, 66.07427104826897, 64.20199040443667, 70.61661889476161, 43.90406600890621, 25.677170715024396, 36.419348255280525, 27.069433658353745, 63.415923887683505, 61.90521517107564, 64.65496924615675, 57.62210461401171, 52.05165647691297, 50.850791469697036, 57.27513174856863, 64.85338234132337, 64.74393252403506, 58.83246175704464, 63.21820112966723, 63.94090960102697, 59.21144508546399, 54.27783296954248, 56.11532218994633, 52.591088279601074, 53.976406666540335, 49.131432271772816, 51.0919270207805, 42.838652210850874, 44.816789780893636, 44.09723489515243, 44.65886339064568, 46.52875923341321, 45.753247814793745, 46.51274027362947, 50.75508563749252, 50.97007466900734, 50.4905649154417, 50.961614116545654, 51.27388185070407, 50.12212884041571, 47.76209754328574, 51.07032260587139, 50.79059877703267, 51.88936841103339, 51.72724900707122, 50.58559609997658, 51.73738048922632, 52.3051945624813, 53.54514991083453, 53.09807815859395, 53.38788640114569, 56.66506590381746, 57.612596788714015, 58.724216107399236, 64.76496035052885, 67.08738004007648, 67.44450399952551, 68.56040262406873, 69.1238275651009, 67.9517762891708, 68.75683492229831, 63.69829531638854, 60.72634289341589, 61.059403111857755, 67.35512887277912, 69.86051928612494, 74.0157841097924, 78.97737841452323, 80.57106094975626, 76.4894425484442, 65.68213993503203, 9.258287049108937, 5.630657499836338, 1.5282468593889669, 0.29608136884147124, 4.33643174748267, 68.32549971918907, 83.83669299464073, 70.1909319047005, 77.35345440526163, 81.28075107451409, 32.56496452516125, 35.27822879052932, 62.78765432296261, 67.86161668838994, 88.37492235245244, 19.860274176443777, 0.6687187006877315, 0.4447204445398623, 0.27707825144452436, 0.14706743099997122, 0.12809692596596095, 0.19418355438017076, 0.13003562637154134], [0.016239941675936984, 0.04085240465018057, 0.06320002443727947, 0.07048612580664697, 0.04211128246219408, 0.07820419351299925, 0.0645508979176802, 0.39879319768759514, 3.4776753763998713, 62.18253458699873, 63.23037224431192, 44.12082402936874, 15.610362560518327, 28.461374967328965, 57.67131859256376, 60.80787327981765, 59.55059674478347, 81.18336646787583, 15.574510135958272, 0.10868509300053121, 0.20604288656144373, 0.6522498327878214, 2.6388988235304436, 5.891427455409881, 84.93187365993377, 71.07366131198022, 76.45913831649288, 70.35469870413505, 73.06788844446983, 66.79591655731201, 72.33228714235368, 68.74924905838506, 72.00023497304609, 69.11035030118882, 70.40866267296576, 50.68245903138192, 68.39591410852248, 67.800090389867, 71.56075692945912, 68.36042450320336, 68.6620783036755, 67.84688426602271, 69.26497013338151, 68.16188981456142, 67.34894721738755, 53.47781850445656, 51.252716741254254, 48.69430765028923, 50.110373497009284, 50.38742619176065, 49.30319286161854, 47.63676212679955, 49.392524842293035, 47.0685048257151, 48.17043589007471, 46.88987616569766, 45.691278288441325, 47.411127782637074, 50.410936878573516, 48.66804738198557, 48.52925823580835, 47.59007415463848, 46.22433231722924, 45.35861815175703, 42.5773125310098, 41.39887955880935, 41.13800664101878, 40.98320245742798, 42.1555204545298, 42.877216954385084, 42.75090879009616, 42.70483663005214, 43.92569395803636, 47.82215687536424, 45.55568587395453, 47.20697625990837, 47.63695824530817, 49.884652860703014, 48.89882003107379, 46.06198149342691, 47.526182666901626, 51.134563184553585, 59.883154899843284, 62.57100612886491, 58.5228180885315, 62.52222753340199, 52.596281497709214, 32.07914367798836, 42.99544503611904, 34.96912640909995, 54.42675752024497, 59.685989118391475, 57.33564215321695, 50.80585679700298, 45.72621483956614, 46.4894570842866, 48.443797634493926, 48.853795143865774, 50.81939681883782, 50.314595622401086, 50.15819503415016, 49.117009716649214, 48.20674919313001, 45.73074909948534, 47.84755029985982, 45.1846492675043, 45.843195607585294, 43.21988697974913, 40.6194261581667, 40.086591782108435, 38.51929110865439, 37.5053584191107, 40.8908071056489, 40.952098061961514, 40.69998379676573, 41.89380030478201, 45.66070341294812, 45.88065032036074, 47.42087095014511, 45.59095190417382, 45.514457841073316, 42.77882822098271, 44.0225019762593, 43.52320386517433, 46.78067738010038, 45.81941819960072, 46.344854985514, 46.2185585883356, 47.23366014419064, 47.13864857150663, 48.53060360877745, 45.813989639282234, 49.20455309652513, 45.72402615700999, 47.70208527964931, 48.29823847739927, 48.21785734545801, 50.38967763223956, 52.5229057188957, 50.14027764720302, 52.078850269317634, 49.65961471680672, 53.91476269691221, 51.23090444072601, 52.741809275842485, 52.45732761198475, 56.50880259852256, 55.648971988308816, 63.81551142661803, 63.179985477078354, 73.88035251248267, 69.89691888132404, 71.36450506025746, 26.04576956841254, 0.7296340900563425, 2.574928152945734, 0.07989000829477465, 0.24952989822674185, 44.505424191874845, 72.96149023117559, 60.3222446287832, 51.45589551618023, 66.30285893717121, 32.111126684373424, 9.947350409723098, 28.373690382126842, 53.94680061647969, 73.3988658843502, 26.50219617351409, 0.6372137331674177, 0.13375899754464626, 0.13249535083530412, 0.055528967716400666, 0.025408868828127464, 0.020094957397950274, 0.030003335597293995, 0.016859153308154597, 0.00862012761870339, 0.035132225302438584, 0.010469946503308753, 0.15180741617035481, 0.13279665321592363, 0.07825447186346977, 0.15482669125401205, 4.574449014279151, 76.6240582927581, 69.28507620288481, 52.426180070446385, 25.64918068147475, 33.6624123204139, 48.9511287596918, 67.74829941411173, 67.74174905592396, 91.92060378289993, 16.08301208865258, 0.10210460457470148, 0.17868764878761384, 0.6747517350219912, 1.695581054495227, 7.551566708472468, 89.99038188688218, 74.68930213682114, 79.05446867788993, 74.10337848048057, 76.46437075830276, 68.98829398616668, 74.02511935080253, 69.07154237070392, 75.41946703387846, 69.87600480356525, 72.44241160731163, 54.80135563881167, 68.87447464850642, 69.38975641804358, 73.49723892827188, 71.21601197027391, 73.68697181824716, 71.43262094066989, 72.48740903792843, 69.15934854938139, 69.32353112005418, 56.08552002137708, 51.960508438848684, 51.55382140990227, 49.450705359059, 52.62422054044662, 51.78716713382352, 51.36727348450692, 50.94129231668288, 49.53915088407455, 49.598794444914795, 48.56231597162063, 47.80587903914913, 50.00482251567226, 52.63047672087147, 50.07915143043765, 50.277250735990464, 51.544039018692516, 49.25428090556976, 46.860646663173554, 45.65269393305625, 45.39036189356158, 44.84396003907727, 43.52600443747736, 45.934955535396455, 44.02019954496815, 46.180574355586884, 44.50092131091703, 47.17488734952865, 49.26307878186626, 50.061936147751354, 49.238167808901885, 50.98356370002993, 50.486583709716804, 48.90511151283018, 47.357387388906176, 49.97998606774115, 54.67013666706701, 60.89258863079933, 64.62419825215494, 61.4020456806306, 65.48009080271568, 55.11070905193206, 36.890244483947754, 48.63597808345672, 38.136499158797726, 55.65962122332666, 60.12262344360352, 60.31009704835954, 52.98672599177207, 49.457349854130904, 47.09418850560343, 50.52773721756474, 51.88209241436374, 54.131050032954064, 50.639940538714015, 52.18637028048116, 50.088145425242764, 50.243483051177, 46.110183500474506, 48.54353566323557, 46.12184078462663, 47.877383847390455, 44.52962913820821, 42.980375289917, 41.33464290249733, 41.62390201322494, 40.460876111061346, 44.25674200057984, 42.71826682552215, 43.877444882546705, 45.313785460687455, 46.162335334285615, 48.189984983013524, 49.00231176807035, 46.52206374752907, 46.07960078024095, 42.832019482889486, 45.61031272334438, 46.40957017098704, 49.72404749162736, 47.52544133893905, 48.65202842220184, 48.02629270861226, 51.373443372787975, 49.82668022955618, 48.59549137853807, 48.92044798020394, 50.221462865029615, 47.39799176492999, 50.16433354346983, 50.50184957442745, 51.64817010202716, 52.320833052358324, 53.420936292217625, 52.205821314165675, 54.51956864326231, 51.39226682724492, 54.31119272785803, 53.327834913807536, 57.21197766642417, 56.33051126233993, 59.042112442754934, 57.77773249533869, 65.53325853040143, 67.1641565138294, 75.99556907530754, 72.10137721030944, 74.87643841774234, 30.850747554532944, 0.694284035313514, 0.7234084918614357, 0.025981414214437528, 0.20253486270385407, 46.19529108847342, 81.71192938281645, 65.49430939459032, 62.49011508880123, 65.18000987268263, 35.08796638058078, 16.26268998269112, 37.28646270690426, 60.42875266844227, 81.33203214214694, 31.560922092007054, 0.5717417141122203, 0.19515887623833073, 0.09943628203003638, 0.040943492504377524, 0.02540277651390962, 0.04799793654632184, 0.04787245517476432, 0.19593398867835923, 0.1250652249361719, 0.17203530897536587, 0.1646770651061689, 0.2565618958925047, 0.3941198162013485, 0.21320795369965417, 0.8488331422690423, 6.9586406407817725, 91.51249685595113, 78.2233419725972, 62.197066968487164, 26.680371799776633, 43.2482417937248, 76.17560586621686, 79.48680016302293, 71.94779288384223, 100.77918268019154, 19.238800118046424, 0.275117464724087, 0.5451370739648419, 2.740574993433491, 7.428680812158893, 5.859653315236492, 90.47138998585363, 76.54656010289347, 81.67660451704457, 75.88693511101508, 77.17373924870645, 72.16992455144083, 76.33739579108455, 72.76473629859187, 75.72642387882357, 73.84740460303523, 71.83799789797875, 52.89687233586466, 73.16826974191974, 71.04375716178649, 77.5081919085595, 72.75428710445281, 73.74066906590616, 73.42859745025635, 71.93266822445777, 72.7637243270874, 73.47182196955528, 58.808366637076105, 54.74295154694588, 52.69535272352157, 52.90815307248024, 55.14228413181921, 54.11189709940265, 53.00273318444529, 52.398080210531916, 50.58398400583575, 52.421022153669796, 50.63354707533314, 51.51295815744708, 53.126499652862556, 56.17650724226429, 50.31107725635652, 50.807276695005356, 54.43309999281361, 51.154233870967744, 49.059762723984264, 48.26532586928337, 46.61873840516614, 46.6025782400562, 46.963177419477894, 48.784157383826475, 47.79830101997622, 49.33443061767086, 47.68263424596479, 48.189341714305264, 51.50215594999252, 51.92759975310295, 51.57644171868601, 52.7268454336351, 54.57490151928317, 54.55935716629029, 50.18484753947104, 52.555484925546956, 56.92637028232698, 66.65642922924411, 66.7764929802187, 65.59782074343774, 69.53631970190233, 56.90570331388905, 41.2151361280872, 51.690621914402136, 43.468357363054835, 58.6529819426998, 63.268838928591826, 63.44240773108698, 54.54021207747921, 50.83444303081882, 50.448787750736365, 54.33173418045045, 53.96627126201507, 57.36212207425026, 56.33258227379092, 56.46229505538941, 54.67533380754533, 53.98755796494023, 47.49481547263361, 51.762919041418264, 49.41013236199656, 51.25191265536893, 48.059319065463164, 45.8090199962739, 44.72533972032609, 42.208123360910726, 42.68665644430345, 47.15682483488514, 45.226018505711714, 45.867832014637614, 47.994105738978234, 50.125117686487016, 49.36604099888956, 53.55263771549348, 49.87585106203633, 50.14485897556428, 46.23497762987691, 49.1434072679089, 48.08797982431228, 51.519692867032944, 48.9424289426496, 50.782675589284594, 50.25854103026852, 53.96906791194793, 52.36015481333579, 53.78905465525966, 51.18933908400997, 54.73180417091616, 51.079226386162546, 51.78401354820498, 52.862257419093964, 54.63638074936406, 55.09627080732777, 56.9570981302569, 54.9232276024357, 55.75295009920674, 55.337280842565725, 58.678167481576246, 55.99343453684161, 59.209052439658876, 59.26034135203208, 62.85252248087237, 63.46973880644768, 69.96233617105793, 70.03104825173655, 79.20455425016343, 74.3930612071868, 79.7004359768283, 29.259665550724154, 3.3253869029783436, 6.372729732144264, 0.18257041221424458, 0.7344061436672366, 53.85862181263586, 87.94688978502828, 73.00120815154045, 69.31193659382483, 82.77416213866204, 47.36935846267208, 18.736940699238932, 47.207725432611284, 69.99778655267531, 92.72702740084742, 41.09946935407577, 0.8010667021716795, 0.3561139797731754, 0.2123958545346414, 0.14284463178726936, 0.19430594458695383, 0.13829914101910207, 0.1464011643322245], [0.10312961489563027, 0.014134640129463328, 0.08875955977747518, 0.05878850712531036, 0.05018342451582994, 0.06083391591786377, 0.16968133528867077, 0.33382603057449867, 8.354693574290122, 60.57881470649474, 52.64654667146745, 44.59588581515897, 18.718236877072243, 24.30581400471349, 46.48572298788255, 54.19014053960001, 70.14083539285969, 74.89538346567463, 6.367610058476848, 0.25306355538627795, 0.1990721452861063, 0.139823364875009, 0.41060746857716196, 57.04875999881376, 87.07794358653408, 74.10229590631302, 75.94175415654337, 67.53369869724398, 68.10792584573069, 64.70951764814316, 68.89625949244346, 68.74265947649556, 68.75608967196557, 72.381348148469, 66.479765676683, 56.05592181605678, 72.37832007869598, 65.41231616850823, 72.16720242654124, 68.3978674488683, 70.18242820616692, 70.34250013289913, 70.65031205454181, 65.37152351871615, 65.53934212653868, 53.74966229161909, 52.13505783388692, 47.273095653903106, 51.11046806458504, 47.506076597398334, 49.98595983751359, 47.34932691820207, 50.87139960258238, 46.6243826958441, 48.639876919408, 48.75266467371295, 47.533956804583156, 46.63748733458981, 48.92774358872445, 47.00004769909767, 48.10787800819644, 48.29339042786629, 46.66625791980375, 44.69407450768256, 43.29771464870822, 41.574997901916504, 43.50486678461875, 42.156191179829264, 41.88342955804641, 39.944233279074396, 42.49987709906794, 44.2075397891383, 44.729717085438395, 46.513159967237904, 47.50914781324325, 46.629215055896395, 47.74489010533979, 43.84421848481701, 44.83050630938622, 46.09720437757431, 45.50218866717431, 45.236393174817486, 49.95780898678688, 53.99317872139716, 57.13734672915552, 56.77573165585918, 54.78298325692454, 35.766799219193, 50.75521507570821, 39.789232976974986, 47.33031518997685, 59.24111781581756, 54.28189654504099, 50.57662563939249, 46.464518654731016, 47.71911228856733, 44.71803626706524, 43.84137476644209, 45.355005648828325, 43.30891693792036, 45.50004313069005, 45.473880921640706, 43.729544070459184, 43.91584096416351, 46.841940879821784, 45.817966922636955, 43.24102071023757, 39.6443445451798, 40.574248298521965, 38.33159785116873, 41.11416255274127, 41.07593905541205, 41.17971712543119, 40.144874280498875, 40.683709882920795, 43.130908012390144, 46.41546941572621, 46.68348889197073, 45.52531888408046, 46.36857748031617, 45.5704535976533, 42.99966550642445, 42.29499209311701, 45.03957648431101, 48.05496523457189, 44.655290111418694, 45.49651691990514, 45.98578945282967, 46.3670987467612, 47.20048081490302, 46.60968949717861, 46.31139716794414, 45.27874692793816, 44.33381657446585, 47.81560259480631, 46.804446943344615, 47.38257292778262, 48.1633520895435, 48.9224366218813, 47.252718940857925, 48.97082690269717, 48.52345705032349, 51.7407262709833, 51.30892822819372, 55.632603937579745, 58.17206798061248, 58.48604586816604, 58.86104406849031, 58.48468088334607, 62.869172942253854, 68.74236137636247, 72.9582581981536, 73.82202686802034, 45.37893602924962, 2.8141885659387036, 1.6338083820958293, 0.33304912548872734, 0.041262671546710115, 26.14128908803386, 70.45089875498127, 66.93895755275604, 57.123355634750865, 58.73057426944856, 28.403163071601625, 15.220638801974637, 34.2936707312061, 46.81238582057338, 63.3454938088694, 44.11311657198014, 0.272463092640523, 0.10650069287587559, 0.03950007943316333, 0.04861385591568486, 0.028480571138882832, 0.015609361298923052, 0.009326336195602292, 0.034098772692584225, 0.032520160424493016, 0.06967581162649779, 0.1113902107481995, 0.04132519581265027, 0.2565411655532737, 0.14669707345385707, 0.3603692917573837, 12.836464335841518, 77.2900845927577, 59.49276531896284, 50.95957056168587, 21.79557554183468, 27.63905986662834, 46.37948559176537, 65.2642035484314, 76.02371600366409, 84.28391379694786, 6.612004118580972, 0.39185385069539475, 0.5562248177105381, 1.0020021877942547, 1.242515062612872, 62.17472514798565, 88.4497376411192, 77.25010779596145, 79.67475229693999, 71.33543245254025, 70.67475626545568, 66.83888220017957, 72.23476917512956, 70.99744181479178, 70.59586955655006, 71.29946431806012, 68.49045107441565, 62.355899426244925, 75.60884691053822, 68.63099744243007, 73.82643561209403, 70.44730586390342, 71.33731519022297, 72.12303653840097, 71.64344833743188, 69.33414505374047, 67.93779696187666, 54.398696884032226, 54.28541098871539, 51.46899231018559, 53.42131283975417, 50.07809239049112, 52.96664345648981, 50.1846553433326, 52.1716574699648, 51.339036341636415, 51.74378571971771, 50.329735971266224, 50.54358751543107, 49.46240578928302, 50.18905624266594, 49.06377138630037, 48.60661914271694, 49.33312446840348, 50.19731675424884, 47.96658246747909, 45.92367479878087, 44.04751885321833, 44.257757894454464, 45.42491405240951, 43.885199408377375, 44.25425129552042, 45.072893096554665, 46.13944045958981, 47.76462747204689, 48.91664328113679, 49.51856628541024, 49.43964819754324, 49.4920353735647, 46.31672766900832, 46.26217534465175, 47.29212699397918, 48.571572765227295, 47.5727568903277, 51.27083024671001, 57.42204412337273, 57.37253204468758, 61.46496049819454, 56.82916610471664, 38.998455693644864, 55.83721045524844, 42.97732760829311, 51.13506132556547, 62.35966490161035, 58.254771155695764, 52.22286009019422, 49.24009761502666, 48.97174081494732, 47.12056644501225, 45.81251482809744, 46.23231826290008, 45.831514789212136, 47.14296317869618, 45.972249430994836, 45.50033730845298, 45.083663925047844, 47.45732153615644, 46.09820458196825, 45.48579315985403, 42.55965009812386, 43.23945176216864, 42.2044441776891, 44.743696412732525, 42.74060864602366, 43.175336699331964, 42.91973936942316, 43.926117574014974, 46.4920497709705, 48.178998424160866, 47.808052032224595, 48.03319608011554, 49.42930098502867, 47.655526745703916, 46.61664385949412, 44.84503869087466, 47.35885043298045, 49.37517227665071, 47.15388697962607, 47.87784276470062, 48.54374354885471, 48.85307342775407, 49.96099787373697, 48.230024537732525, 48.067481517791755, 48.77897201045867, 47.88598560517835, 49.353556094631074, 48.22074028753465, 49.995095037644916, 50.87789896995791, 51.096037664721095, 51.807845869371974, 51.08665143289874, 52.14825268714659, 52.39386366259668, 54.13323479314005, 58.20387448033979, 60.06172864667831, 63.09743527443179, 62.229567727734974, 61.520579707237985, 65.30107382805117, 72.45128400864141, 74.97446629308885, 75.68971049401068, 50.23315937288346, 2.7744017589476804, 3.528359263173996, 0.14042509629601432, 0.07482764566497457, 27.114587983777447, 77.53549160495882, 72.4830630517775, 66.62030419995709, 63.76773695791922, 34.45138139109458, 23.72097880609574, 41.60711426888743, 51.96517213698357, 73.32586273070305, 52.5257533596408, 0.1941811795076055, 0.06396301353590624, 0.08869801993451773, 0.061685457119658116, 0.038929251999023466, 0.02747464789858749, 0.08207528942054318, 0.1976121195982541, 0.16059085937036624, 0.1948218281951643, 0.248078529332434, 0.2686959625251832, 0.4703689763142217, 0.3250810756318031, 0.6212935680823942, 17.193437045620335, 91.10143246189241, 68.41357261903825, 62.8250894238872, 28.149217059535367, 37.11065815341088, 63.38164629474763, 72.0336849458756, 82.73356560737857, 91.78641165456465, 9.175830002753965, 0.5136139654824811, 1.429528524318049, 4.545971626235593, 2.5553420426384097, 62.22753986235588, 92.22844708350398, 78.90743470961048, 80.33836241691344, 73.99530149275257, 72.04539714321014, 69.91311042539536, 74.54722604443951, 74.42825271237281, 73.97910994868126, 76.61407193829938, 67.58894135875087, 63.178361615827015, 77.91258827332528, 70.18326759338379, 79.2645037558771, 73.70716417989424, 74.5414052471038, 75.34815834414574, 76.49990743206394, 71.21572955962151, 71.67245818722633, 56.823188412574034, 57.60846653292256, 52.82970566903391, 56.80622808394894, 52.073966918453095, 55.49649769260038, 51.530459773155954, 54.72301021698983, 51.517551252918864, 55.263493214884114, 53.83797837841896, 55.008052779782204, 50.446328424638324, 52.06634575320829, 51.90622283566383, 51.50083018887428, 52.81472221497567, 53.45369592789681, 48.775692908994614, 49.055110792959894, 46.25153395437425, 47.5752083716854, 46.63551830476331, 48.4562119360893, 47.92096138000489, 48.01989532286122, 49.39032831499654, 49.683035189105624, 52.276439666748054, 51.66808005302183, 53.001987934112556, 53.86732162967805, 48.36684465408326, 48.2035053929975, 51.271697090518096, 50.61088754284767, 50.80910059713548, 54.33763342518961, 59.473569239339525, 61.450228075827326, 64.41106450173163, 59.579630128798954, 47.149584139547045, 58.77254363029235, 48.609298121544626, 55.09700429054999, 66.05636935080251, 60.71393251419068, 54.338492424257346, 51.46003361671202, 53.104487311455514, 48.9162039756775, 49.50918005358789, 50.97882547686177, 48.32338087020382, 50.32203635861797, 49.12013976804672, 46.873798370361335, 48.34047455941477, 51.321315073197894, 49.66949124490061, 49.32169075935118, 43.91256970743979, 45.571081176880874, 45.542930326154156, 47.69442489070278, 46.38247836020685, 46.29072235476586, 46.14110354454287, 46.292157942248934, 48.38464044755506, 51.79004615353, 51.452334004063765, 49.88162479092998, 52.44707845872449, 50.73278696306291, 49.91357641835367, 48.895599765162316, 50.07066734375493, 52.429871020778535, 49.02554788897115, 50.01780556094263, 50.60938919744184, 52.145420735882176, 52.72596290034633, 51.413471160396455, 52.066369287429325, 48.94895184424616, 48.48194660678987, 52.670080892501346, 52.593441701704464, 52.001528586110766, 53.42641976571853, 53.40443488090269, 52.89868839325444, 52.76264490619783, 53.84660367042788, 55.59354105303365, 55.87696367694486, 63.63326241893154, 62.89091464011901, 66.12614831616803, 64.4276875065219, 63.44148205172632, 68.56279526987385, 77.5304631263979, 78.2117239121468, 80.26803431972381, 49.87549020398048, 4.825643973965799, 5.431624179886234, 0.8185262136882352, 0.1872732267985421, 33.52907919114636, 85.01345895951795, 78.7587219668973, 74.48817083912512, 75.8682724737352, 40.98603048632222, 24.860566585294663, 50.64827557533018, 62.029715122715125, 82.72783110218664, 62.88794932826873, 0.5530160737614478, 0.23065506991359497, 0.1734640169888735, 0.10834652810327469, 0.15782782537562234, 0.32758118825093396, 0.15443039397078176], [0.05616045399238506, 0.05039240181025478, 0.00339247984342247, 0.042520036335073175, 0.06299721798108471, 0.10741355558556896, 0.1006192060547971, 0.2930638097947644, 12.42462037071105, 61.63832533744074, 53.77007430599582, 44.339068628126576, 33.314294122880504, 43.51105236238049, 51.08985993169969, 55.13092887017035, 75.75619466843145, 53.24612409837785, 1.413987971121265, 0.19462140427241403, 0.42868830804382607, 1.8684044840835758, 17.716787130601947, 95.37025774678877, 71.490326850645, 79.40116697742094, 67.36699012018019, 70.21940831215151, 64.61861279702956, 67.08839985632127, 64.49209674712151, 71.19869862833332, 67.88396635363179, 73.53936518392256, 63.645386465134166, 57.17590362794938, 72.38064996657833, 67.75158636031613, 68.68106257530951, 67.13207152581984, 67.67950888602965, 63.86817709092171, 63.868239848844475, 60.49453866097235, 58.55637004298549, 54.06627601192844, 51.94896490343156, 48.63550347666587, 47.98888898664906, 47.76343114914433, 47.46912394800494, 47.46718237476964, 48.27652423612533, 48.593220326208304, 49.2088794708252, 45.8387319503292, 44.74475937504923, 47.107673614255845, 49.16363493088753, 50.52221452036212, 48.33865457965482, 46.818339978494954, 46.6041079644234, 44.752713941758685, 44.65055581062071, 41.22674242142708, 42.81865989008258, 40.68505525588989, 40.30638963945451, 40.93616539432157, 41.155319982959384, 41.4181266292449, 41.919076058172415, 41.005261867277085, 44.305049911622085, 42.62730313885597, 45.30166925922517, 44.96588299351354, 43.181843911447835, 47.11657347217683, 46.105798290621856, 46.299684970609604, 48.712829082242905, 48.097899498478064, 55.485844535212365, 59.37800853483139, 53.29640888398694, 35.95695964751705, 47.697088180049775, 42.51007133914579, 49.39496063417005, 55.661719691368845, 56.02458207837997, 49.373552337769546, 45.056187721990774, 44.69776938038488, 43.88112798813851, 42.75732578769807, 42.44404608203519, 42.47185960892708, 45.48520872669835, 46.18753656264275, 45.48526363988077, 45.456249867716146, 42.85085862682712, 39.8224554523345, 42.01976722286594, 40.03650703737813, 39.149435566317656, 40.74421244282877, 39.75854043037661, 39.69210332439792, 40.03037245042863, 38.1513806312315, 41.36914014816284, 45.05824696633124, 47.111270427703865, 45.945789121812396, 48.13403237250544, 46.46891955406436, 44.57872544565509, 43.763080335432484, 42.151805969976614, 44.542631795329434, 46.41757965087891, 45.97860367067399, 46.29411520496492, 46.71555426812942, 45.649634484321844, 46.171568593671246, 47.73304846978957, 47.845683251657796, 45.17278409773304, 46.02351088677683, 46.8821765530494, 46.97805496954149, 47.418556751743445, 50.080081032168486, 50.21885056649485, 49.87587851862754, 51.88945862554735, 54.340492833045225, 56.36627935594129, 58.20521200856855, 60.83664778740176, 63.221401783727835, 66.64547012698266, 65.28850655401907, 63.10976720625355, 62.698573373979144, 67.63650401946038, 71.14344812208607, 73.36157983349216, 56.31948155741538, 3.842958846399861, 2.4222930400602283, 0.5975130344590833, 0.2474552401972394, 5.211502727000944, 62.708289084895966, 72.41981875511908, 57.657205904683764, 59.17957190544375, 48.5524159093057, 10.711256515595222, 19.472885208745158, 43.681906884716405, 63.336821448418405, 50.93964099884034, 0.5181135982275009, 0.13129055500030518, 0.08152777404193917, 0.04387004413611947, 0.04226163104777375, 0.02004002123290012, 0.0671241642727006, 0.01482394306109317, 0.025056847596480965, 0.018531948425656846, 0.10808633400067207, 0.015872530695501597, 0.06965248424920344, 0.1028172578662634, 0.33027358893905917, 17.47975830108889, 75.54967403411865, 61.10483592556369, 58.240258386058194, 29.278838096126435, 31.96236687321817, 52.71326226572837, 64.99969067112093, 81.73384758733934, 61.23440357946581, 1.610080494034675, 0.30136657878756523, 0.43060122959075436, 1.6125529355579808, 19.822138932443437, 97.43493064757317, 75.07483190105808, 83.39231198833835, 68.75430107116699, 72.59118710794758, 68.19577124810988, 69.87275708106257, 68.18731461801838, 76.30608743236911, 69.91037261101508, 72.83526051429011, 63.96192566041024, 62.294981095098684, 70.89404813704952, 70.28928141440116, 71.1419968451223, 70.15224164532077, 69.9401512453633, 66.27367650308918, 66.16933361176523, 62.64952021260416, 61.89718607933291, 56.135004643471014, 52.822088426159276, 52.20747263200822, 48.749518932834754, 50.467972063249164, 49.17383309333555, 50.82886149806362, 50.025960168530865, 51.66007449550014, 51.09581801199144, 49.49825233028781, 47.012536525726325, 51.3272221626774, 48.664603540974284, 52.52363527974775, 48.46656307097405, 48.05795800301337, 49.28240822207544, 47.47482707423549, 46.8855066453257, 43.9221324459199, 45.03214359283448, 43.55326883254513, 42.33575336394772, 45.6316464947116, 44.239907187800256, 44.09790169808173, 44.08345560873709, 46.15520838768252, 45.118729914388354, 46.18325725678475, 46.47788609227827, 47.33006808065599, 45.96229053312733, 49.920342506900916, 49.279242869346376, 47.66576805422383, 48.51981709080358, 50.87681247342018, 56.709267093289284, 63.55338727274249, 55.00653874489569, 40.643219255631976, 50.78949659101425, 44.97172732507029, 52.520567986273, 56.16238278727378, 57.97140344496697, 49.342961772795654, 46.23059242002426, 45.638204697639715, 47.39528140714092, 44.797338747209125, 44.85751575039279, 45.68344923757738, 47.314974800232925, 49.072118190027055, 47.70948286979429, 47.70441908990183, 44.789725426704656, 44.17281504600279, 43.572970897920676, 43.268049763095, 40.66375678585422, 42.84433572523056, 43.078352174451275, 41.95604831941667, 42.48473282783262, 43.110119450476866, 44.18080883641397, 46.457619205597915, 49.34243617519256, 49.281792409958385, 48.584963736995576, 49.80816271997268, 47.425687620716715, 46.289890812289336, 44.19465088075207, 46.15553394440682, 48.47629447137156, 48.08860740353985, 48.79810140978906, 48.70006961207236, 49.28239645496492, 48.80202770233155, 49.390226333372055, 49.78985701837848, 48.136173986619525, 49.71168810321439, 48.204258488070586, 50.37754181892642, 50.02410880980953, 51.460449387950284, 51.38156660141484, 52.22784542268323, 54.12517040006576, 57.752331226102775, 58.20816947567848, 59.95717394736506, 63.38275240313623, 68.0338950310984, 67.40145206451416, 68.87096804957237, 68.35657273569416, 65.39430464467695, 71.14026315750615, 74.85306893625568, 76.09011388594105, 58.67087971779608, 4.933516508148563, 2.8070454395586446, 0.07198597274480328, 0.2464120429489882, 4.831404955156388, 69.12728709559288, 75.84917053099602, 65.65147092265468, 64.78469771723594, 42.36714017006659, 15.975480310378538, 29.358234713154456, 50.036350527117335, 73.33060095387121, 59.15755956403671, 1.007491606137445, 0.031320257976110426, 0.03376608368970695, 0.02273079589940608, 0.0472683833551503, 0.026328452044136585, 0.02904596509441974, 0.13857205218124774, 0.1508766653076295, 0.13814592343424598, 0.14004114835012343, 0.19391220603739062, 0.16241882176649186, 0.33560614311887377, 0.5398959906831865, 24.709223893380937, 91.10873591515326, 68.48953323979532, 64.69591094601539, 45.6760085013605, 62.843779517758286, 67.38164409514397, 72.68821870127033, 87.80488429530975, 66.96056196766516, 2.548279324846883, 0.42727928848997243, 1.0126630060615078, 4.753991096250473, 18.76341081434681, 100.61566691244803, 76.99783663595878, 85.23819508091097, 71.56362810442525, 76.62862393163866, 72.20142902866488, 74.60976431446691, 69.13895222448534, 77.55618602998796, 74.67788019487935, 75.4758236485143, 63.54072586182625, 66.43947509027296, 74.3871384282266, 74.78862439432453, 72.91515919470018, 71.9758221410936, 72.60930845814367, 68.44869352156117, 70.25063037872314, 66.06974463309011, 64.37813620413503, 58.421887659257465, 56.109681821638546, 54.56050642075078, 49.98592453618204, 53.054904630107266, 50.354776382446296, 52.832372880751095, 51.96747456827472, 54.997191736775065, 53.5150888658339, 50.89895033067273, 50.01933136293965, 53.736439981768214, 52.661992965206025, 56.35386897671608, 50.8966165204202, 49.58719991868543, 52.47309554007746, 49.19542966350433, 49.791712299469985, 45.2275796090403, 48.891430285669145, 46.14747739607289, 45.31776666641236, 47.54223692801691, 47.91788231941962, 46.87901512269051, 45.44815801805066, 47.495486197933076, 49.88518238067628, 48.65291880023096, 47.23381703899753, 48.64371299743653, 48.13636618275797, 53.04724424116073, 50.61128762460525, 49.5308276145689, 51.82401387922226, 54.07674481791835, 59.450537081687685, 63.69386696046399, 58.556628919416866, 45.570900747852946, 52.633751899965354, 47.56128395757368, 56.4531010197055, 60.863417963827814, 61.04768306978288, 52.631167058021795, 49.674390285245835, 49.13046344634026, 49.504504588342485, 49.195845434742594, 47.98537454297466, 47.89820771063528, 50.43371800453433, 51.512201140003825, 50.73943538050498, 50.90967409072384, 45.740519723584576, 45.12759839334796, 47.10727353249827, 44.69838911487211, 44.46555329907326, 46.258001942788404, 45.529684482082246, 46.06954774548931, 45.128692734626036, 44.46007374794253, 46.239994341327304, 51.88684632701259, 50.82794758581346, 51.998763315139286, 52.38712110827046, 52.370325519192605, 49.71010346566477, 50.90557521389377, 47.15423214820124, 49.22662819585493, 52.01184441966396, 50.79908286371539, 51.477397949464866, 52.021924911006806, 50.61675933099563, 52.41238117218018, 51.82102503315095, 53.30195119304042, 50.39192122797812, 52.03026386999315, 51.9890554489628, 52.32899158231674, 52.55417877627958, 55.135267011580936, 55.385969223514685, 55.18931727255545, 56.032862201813735, 61.028149666324744, 60.947439055288996, 61.93942216134841, 66.01092476998606, 69.43429100898005, 71.64402884821739, 72.4818157380627, 70.69305019993936, 68.81163043360557, 74.90267122945478, 78.6998785695722, 79.43799803333899, 61.664664053147845, 4.574889300330993, 5.039127795926986, 1.9136943764263585, 0.48416110236317883, 7.954697618561407, 78.62071729475453, 83.55755359895768, 73.05843553235455, 76.03100376744425, 63.64613563783708, 17.364844622150546, 34.60090606443344, 61.66646834342711, 81.6534625330279, 72.94225492785054, 1.8721632178752654, 0.3256718826390082, 0.1587791840035108, 0.12081622551645964, 0.1059111039484701, 0.10566368819244447, 0.17128857243205273], [0.036755059995958884, 0.03018708944681191, 0.04754390687711778, 0.019767106240314823, 0.04965881516616191, 0.03815923021325181, 0.10616035065463475, 0.21545835229898655, 15.06283204401693, 57.52075841349941, 51.24921014232021, 44.00770679596932, 40.86114614240585, 36.82159516119188, 59.63548075768256, 58.41129725979221, 79.84893691155219, 40.59071440850535, 0.09361864097656743, 0.10476816971335681, 0.693437538800701, 0.5501257772407224, 68.69656378223051, 89.47047956528203, 75.53866001867479, 75.12667778999575, 63.84962035763649, 66.70126192031368, 62.129606123893495, 66.14215158647107, 66.55891126201999, 72.0889982100456, 63.6429585179975, 78.45222011689218, 58.242556894979174, 61.36300240793536, 70.66418940021147, 68.47492633327361, 68.60393308824109, 66.36311438775832, 66.31409260534471, 65.22457192021032, 62.35605632105182, 59.25520696947652, 61.28830479037378, 56.77975208528581, 52.577344294517275, 49.15595493009014, 49.84380137535834, 49.72977415207894, 49.77767413662326, 48.351861200025006, 47.97531366348267, 47.70195976380379, 49.39669432178621, 47.54321752055999, 46.107563357199396, 47.12104497417327, 47.96346026082193, 47.6653052145435, 48.052046991163685, 48.43956931944817, 51.11102504114951, 51.6907827315792, 48.2639765739441, 42.758102416992195, 40.689558136847715, 41.233885057510875, 41.884990661374985, 41.88815209173387, 41.522951972100046, 40.741686436437796, 41.32423293206, 39.78045471252934, 41.105058731571326, 41.913639653113584, 40.715269273327245, 42.73971434562437, 50.91165096529069, 54.69693822245444, 56.3946420146573, 54.88221137754379, 54.561455634332475, 53.91483329957532, 54.19525923267488, 59.35420367025561, 53.17601565391787, 36.47027238722771, 41.45774649035546, 39.15105158282865, 39.20600006657262, 52.58769542940202, 54.50421648640787, 51.89196894245764, 49.96379452366983, 49.566136790860085, 49.87993032701554, 43.15115528721964, 41.64890712307346, 43.686021451027166, 41.74440899202901, 43.454703592485004, 41.85629460119432, 43.22559795072002, 42.739616286370065, 41.52993379100677, 41.60328211322908, 42.15035077064268, 41.02680744663362, 39.77856413010628, 40.68990330542288, 40.06743884855702, 42.246225264764604, 46.952026121078006, 46.25049060390842, 50.57493117547805, 48.996259550894464, 44.11103771578881, 44.41271112811181, 46.65676970635691, 43.00529802999189, 42.29986367687103, 41.62543958233249, 43.90126543660318, 47.07063075034849, 45.55596828460694, 45.28983154604512, 47.231451849783625, 46.69162388770811, 46.91716409498646, 47.14485376111923, 45.58152644864975, 46.962494927067915, 48.634562107824514, 49.56504244958201, 49.7773289680481, 51.28288369024954, 53.32709750821514, 54.428455906529585, 57.54070758819581, 60.35669088363648, 62.74387674946939, 63.9547908690668, 66.37122584927467, 66.50144853899556, 68.05418937436997, 66.87543869018555, 73.5384395045619, 68.00883108569731, 67.2769638799852, 65.80494150038689, 69.72886100892099, 73.44973902548514, 59.52495621096704, 10.083555694549315, 1.0715223993024519, 0.28415123481423626, 0.05358252982278505, 0.9665852076103612, 50.462763155660326, 73.05489755445912, 62.87572330044162, 58.04892124668245, 50.90049182215045, 26.901756255857407, 15.833363033110096, 35.06906447872039, 58.622885596367624, 57.34931945800782, 1.259364216558395, 0.07151709629162666, 0.022963429988932707, 0.06852569148665474, 0.04279029683300084, 0.06408091063701338, 0.031343497253293474, 0.018395720755741484, 0.020821760333473646, 0.03806767887586067, 0.07940051641555564, 0.11544367388611841, 0.031659711535359104, 0.07296700195799913, 0.27515668842581015, 22.874321476105724, 71.09113154872772, 59.536397764759684, 50.57562543499855, 43.664660223068736, 42.089761918590916, 63.894268697307965, 66.7274711978051, 84.2911623370263, 46.494987626229566, 0.038710273426747134, 0.08478825190855611, 1.1875871713123014, 0.6873277730999455, 74.44991204046434, 94.89063032211797, 79.0773125617735, 79.50612960323211, 68.29706253543978, 70.15845467967372, 63.613211262610655, 68.76221641417473, 67.97669118450534, 75.44696284878638, 67.96928574962001, 75.02063259001702, 59.888975697179, 63.127249210111565, 72.10003575971051, 69.55517061295049, 71.7921846143661, 69.1202268292827, 69.52530568645847, 67.41288185119629, 64.22313197966545, 61.94587446028187, 63.2198053790677, 60.388720958463615, 54.00502820168772, 51.798185071637555, 50.70671889089769, 51.66202391347578, 51.22122403114073, 50.13005202816379, 49.065273654076364, 49.9274145403216, 50.86071898860317, 49.61941042254048, 47.899988466693515, 49.23536331422868, 51.35269011220625, 48.395450499749955, 48.940938441984116, 49.20665156456732, 51.15874459666591, 54.31768817286338, 51.43364391019268, 45.647135934522076, 42.462034071645434, 44.149163153863725, 45.422611621118364, 43.312078368279245, 43.943352468552135, 43.939649751109464, 43.67503489217451, 43.357111100227606, 44.12727240593203, 44.60777451915126, 43.248484980675485, 45.20967791157384, 54.47466927189981, 58.04975278915898, 59.17509648107714, 57.72242707590903, 56.115337879427024, 57.18509374126312, 55.66161378737419, 62.208814467153246, 53.574163682999156, 39.91989497215518, 43.83380851437969, 41.20367496244369, 41.81856924487699, 54.18412754612585, 55.951065094240256, 54.494112460843986, 50.335847023994695, 52.466411821303836, 50.96504619044643, 45.67611440535515, 44.672560307287405, 44.76707373895953, 44.035077095031745, 45.42928357278147, 43.84537950638802, 45.365431308746345, 45.884788420892534, 45.569206283938506, 42.54016768547797, 44.27286686435823, 43.143957737953436, 43.166240722902366, 43.46361129514633, 42.711798837108, 45.19050928854173, 48.659998678391986, 48.25697122081634, 54.29027865009924, 50.0401238472231, 46.596682917687204, 47.65439710309429, 48.36789584928944, 46.16977214813233, 46.03827861047561, 45.264242003040934, 46.46317720413209, 49.034353610008, 48.337846571399325, 46.661307888646284, 47.470563457858184, 48.62030429224814, 49.78124349348007, 48.346354192303075, 48.99578886647379, 49.76569521811701, 51.60494950509841, 52.420755432498076, 53.60851187859812, 54.50649930584816, 56.50674335418209, 57.29421800182712, 60.45928439786358, 62.07489690473003, 66.68120291925246, 66.53928372167772, 68.05916293974846, 67.48750886609479, 69.94378336014287, 69.02390126259097, 74.99906739880963, 69.86468484324794, 72.21320398392217, 67.55044721787976, 74.18718384158227, 76.1683730156191, 61.97031474882557, 10.70339314399227, 1.3794565272908057, 0.6067112989483342, 0.029615865562171228, 0.8463564719403944, 56.31878337552471, 79.35738548155754, 69.65980375966718, 65.88222395989203, 51.1726729331478, 23.1179359651381, 18.964457781084125, 42.684863921134706, 64.64026820275092, 68.13466856556555, 2.371964372934834, 0.11958266307990398, 0.0467159305398743, 0.023409482767625202, 0.03211920149624348, 0.08266622666269541, 0.08272116282774557, 0.08996474631731549, 0.1211090702863951, 0.13603050952717183, 0.1531397350012295, 0.18204565730787095, 0.17020330163500003, 0.18726731259976664, 0.3839924709210473, 30.794765526248565, 87.18252182006837, 65.45741558074951, 61.76890104047714, 50.18030151244133, 58.55101208533011, 78.15190776701897, 74.64425763776227, 90.47870912859517, 53.889992929274044, 0.2012566450021921, 0.31414232066562103, 3.417558924805734, 0.872315637046291, 75.7412661275556, 99.22533573642855, 83.62939573103382, 82.45047246256183, 70.25229346367621, 73.38349019327472, 67.48859928500268, 70.023956606465, 72.9206112892397, 75.80490266123127, 70.81599297062044, 75.27569647758239, 64.59893034350488, 67.55204754491007, 74.84957018206197, 72.90707126740487, 73.81474694898053, 71.66671583729406, 72.88043837393485, 71.67667865753174, 65.84241190264302, 64.91576371654388, 67.30656993004584, 62.80878805345105, 57.65497799842589, 54.42656532410653, 53.59198301069198, 56.15525191830051, 52.55449256589336, 53.445964936287176, 51.5973557964448, 52.42332066259077, 52.98823610428841, 51.9350169550988, 51.50833760538409, 51.51600583907097, 53.97622231514224, 52.31323934370472, 51.16481250332248, 52.53894821290047, 52.26391161641767, 55.53022223134195, 54.12437023655061, 48.071588239362164, 45.52445596264255, 46.257444966223936, 48.28938176555019, 46.20646984346452, 47.93571341422297, 46.33062070415866, 47.92864530317245, 46.6365538104888, 45.597145326675914, 48.820133363046956, 46.67097260875087, 48.60807434205086, 58.09218106731292, 61.797969725824174, 62.02986417278167, 61.4256073582557, 61.079116944343816, 59.912466772141, 58.253339490582874, 64.16792854186028, 58.443707804526056, 43.365916821264456, 44.04998994642689, 44.18089120618759, 45.49111581617787, 57.58511274091659, 59.234547845778934, 57.807919056184836, 55.81195039133872, 55.034415029710345, 56.02640205813993, 50.3002554370511, 46.288306174739716, 48.6279333022333, 46.34523545542071, 48.25951683905817, 46.49944736111549, 49.28572262487104, 49.08912950946439, 47.94362091249036, 46.22761534106347, 48.31486148218955, 46.612368476006296, 45.09089285327543, 45.240601878012384, 45.28213585576704, 47.82209411744149, 51.60878950549711, 51.25015935590191, 55.15441602276218, 52.60289853618991, 49.431387685960345, 48.08856425746795, 51.07201314741566, 49.480719335617565, 49.180956117568485, 47.94168326162523, 49.21755183127619, 52.16948447688934, 52.07434346598964, 49.699666038636245, 50.419730832499845, 50.22738172161964, 51.326465145234145, 50.82327212056806, 50.63233506294989, 51.7253113562061, 53.5523945285428, 55.01392064555999, 55.93348110875776, 57.194150493990996, 60.58964044817033, 60.30135800761562, 62.045687014056796, 65.27686103697746, 70.91691555515413, 69.64522823210686, 71.97907770833662, 72.01207268622615, 75.96978341379474, 72.37112645179995, 77.49524024225052, 74.11355310870756, 74.72337968887823, 70.74227594560193, 77.45483982947566, 80.20559803132089, 67.07673472742881, 11.72435668206984, 4.033457334003141, 0.9905653531032225, 0.22325086076894116, 1.3110956213166638, 65.916685904226, 85.10561112434634, 76.34798619054979, 74.83350415383616, 69.55035394237888, 39.41659212112427, 27.04340480989026, 54.53080231143583, 74.50073026841687, 82.31715110040481, 5.3508478691501, 0.39623660906668634, 0.36272354123573153, 0.12887717885596137, 0.15643976598737702, 0.25387171685935994, 0.18105630071893816], [0.07967197967152442, 0.04763713594706309, 0.03154443637017281, 0.032361630019882036, 0.028488858295003736, 0.004637646836213647, 0.06649719025459021, 0.10501076677633871, 24.083076330923266, 60.7226715549346, 38.800630954004106, 46.089665582103116, 37.41080968610702, 33.46880020633821, 58.46206841930267, 61.58437705809071, 80.78179420963411, 27.022592713755948, 0.5163947420735513, 0.49981172707292343, 3.05104652720113, 15.31220849483244, 97.16295349982478, 72.00353760873118, 77.55315796021493, 65.5146155049724, 64.76880427329772, 60.947564571134514, 65.34236069648497, 60.10622793628324, 68.52284200729864, 69.06298375898793, 69.45092185851067, 70.76807729659542, 50.591895426473315, 64.51999264378702, 68.73847822989188, 68.67074674175632, 68.13954014931956, 66.71422143136301, 65.93217926640665, 64.49507382608229, 65.8710059811992, 64.43710511730563, 64.10369580791843, 60.531275580006266, 53.937559512353715, 46.85881491630308, 49.59413074677991, 47.87061775884321, 47.55275672481906, 47.26962827867078, 47.50053428834485, 49.22354129052932, 51.30142865642425, 47.627681839850645, 46.752644200478834, 45.97143750036917, 48.09214930380545, 46.79786128382529, 48.139884548802534, 52.8531143742223, 53.73021125793458, 48.235409951979115, 47.169498012911895, 49.548415522421564, 47.20561519745858, 38.23495849486321, 40.42918336006903, 39.55685215611612, 39.50078579687303, 40.07667210794265, 40.716583267334975, 41.14006588535924, 40.28387131229524, 39.0689955988238, 40.0394017465653, 42.07794381726173, 43.36905079503214, 45.27485593672722, 50.48737995086178, 61.2452724672133, 59.93747188198952, 60.06636488822199, 57.46063632349814, 65.717535403467, 53.58487175356958, 36.89850891790083, 45.458442472642474, 41.5613127523853, 39.214401783481726, 55.31803377213017, 60.428729134221236, 55.05998888323384, 57.943829182655584, 53.048256212665194, 52.9699892382468, 48.69568832458989, 43.74716335727323, 42.07192297904722, 40.44912469002509, 41.606463155438824, 42.194112654655214, 41.47662093562465, 40.52696804846487, 39.940781593322754, 41.13982269840856, 41.430564465061316, 40.58831784033006, 41.68032923052388, 42.94932188526277, 40.95481626449093, 45.15146993821667, 47.82319238108974, 44.94913839524792, 44.91520989325739, 48.55259241596345, 46.43876829454976, 43.99741841900734, 45.133058332627826, 44.06989597505139, 43.27067382874028, 41.787437392819314, 46.372527307079686, 47.319454146969704, 44.61215972900391, 45.10097726698845, 47.43046114521642, 45.881168073223485, 46.769239748677904, 46.24798420936831, 49.78679756964407, 52.476578604790475, 56.187631084072976, 56.9994754175986, 59.39148579874347, 58.27836421228225, 63.01715220174482, 63.27799374057401, 65.2714010976976, 65.25815917599586, 68.72624827969459, 66.27425701387467, 69.87656962487006, 65.71118116378784, 68.25651307259837, 63.847078661764826, 89.15652521194951, 75.26791449516051, 68.36254258309641, 69.70906088429113, 68.4553772403348, 72.52326734604375, 63.488362220025834, 8.394706653010461, 0.9232552746130575, 0.36890970122429634, 0.17361665234690712, 0.029606053891081004, 34.35562064570766, 76.50076250876151, 65.90743695535969, 60.052197287159586, 43.53210372309531, 28.202408321442146, 21.72960323672141, 48.56912520623977, 53.024243462470274, 70.05098173695227, 6.673439221997415, 0.46843347049528555, 0.11888131724610446, 0.09313261947564541, 0.043289307354679035, 0.03221197474387384, 0.03805194342989595, 0.04756752153738372, 0.14915293683448147, 0.018687489172143322, 0.045010752885812716, 0.04304106422369519, 0.09574968307729691, 0.03204106435840649, 0.1289845843829455, 32.000843363423506, 75.60250836033975, 44.5154340805546, 51.29854179197743, 48.57562849598546, 32.93047843440887, 67.89086188039472, 67.87404275709584, 86.9067007495511, 28.80298987511666, 0.511877611880341, 0.2799712139512262, 3.806672019343223, 19.129652323261386, 101.67437737987888, 73.46794666782503, 80.90868288470854, 68.09440935811689, 67.52387708233249, 62.77100386158113, 67.53321232334261, 63.728219078433135, 69.86615965443274, 71.15596048293575, 71.4577397992534, 68.15421765850436, 56.74310930313603, 66.92115783691406, 69.65928600680444, 71.57338696141397, 72.25587152665662, 69.85185084804412, 70.93951625208702, 65.88303981288787, 69.6131040203956, 68.1543980875323, 65.3148688039472, 61.131817909979056, 57.642281286178104, 47.902416413830174, 52.02526677039362, 50.898499258102916, 49.132785489482266, 49.4687129605201, 50.97688390362648, 51.06989898989278, 51.87920554991692, 47.693432531049176, 49.247993346183534, 47.67092204863026, 50.48415576258014, 47.992391663212935, 49.160634317705714, 52.988141967404275, 54.18102887368972, 50.518464734477384, 48.8103941179091, 51.62511441015428, 48.65815124204082, 41.20833081583823, 43.11858000293855, 42.711571339638006, 44.064910642562374, 43.53217040338824, 44.74441420647406, 43.55246474665981, 42.358342293770086, 42.925336591659054, 43.246127636201926, 44.02230193538051, 45.07443458803239, 49.08923541345904, 53.20819870118172, 60.74436618435768, 60.8666931429217, 60.58697715882332, 61.14394980092203, 65.44226738714403, 59.181203611435436, 42.57866574871925, 47.59039186662244, 43.81681680679322, 41.657144100435325, 56.25114602427329, 60.663133898089015, 56.37547339162519, 60.14839733800581, 56.30909512119909, 54.15634147582516, 50.5390493331417, 45.63657299164803, 45.62605711721605, 43.16512676977342, 43.74985802558161, 43.53044456051242, 42.375192796030355, 43.61405772547568, 42.916260227080315, 45.109335837825654, 43.65754504357615, 44.24871683120728, 46.26356386369275, 43.55052317342451, 44.376201706547896, 47.68875706580378, 50.54234412408645, 47.20709000864337, 46.53013990771386, 49.663191918403875, 48.7595288215145, 44.911793508837306, 47.566794887665786, 45.68376694956134, 46.115160988223174, 44.28877207540697, 49.1439171760313, 48.74245474415441, 48.566924756573094, 49.03907222132529, 48.46730832130679, 48.65682155855241, 49.79220259574152, 48.22419981802664, 52.89207527714392, 55.052779566857126, 59.04987873569612, 60.17211983280798, 62.7022917809025, 61.81121949226626, 66.29414343064832, 64.98140458137759, 67.88253076614873, 66.42425629400438, 71.80035098906487, 69.56839684517153, 70.04893425972232, 68.92109594037457, 69.11001297735399, 67.88158155256703, 87.21522654256513, 75.09939378307712, 70.85923317940005, 73.11119925591254, 72.55034738971342, 74.5369415898477, 66.74419618421986, 9.690245909075584, 0.3831433390657748, 1.2169496667000557, 0.2428259853754313, 0.05602942231381613, 37.15640475673061, 83.61920541332614, 69.93209469702937, 69.68827232237786, 46.76094393576346, 32.820644224843676, 26.84961226678664, 57.07726386285598, 59.4785310376075, 80.74615555424845, 9.932800377568892, 0.6195832921131965, 0.1946265523832652, 0.046823745923897916, 0.11779769353808896, 0.00812885458506043, 0.11454298431354185, 0.11698504278977072, 0.19290441737299968, 0.14785594997867463, 0.12424335048924531, 0.15984096654480504, 0.17642609594810396, 0.14013275714410892, 0.172297602158881, 43.58826421922253, 88.95595089081796, 55.07350929321782, 62.45295063141854, 42.684832542173325, 48.61962964457851, 75.4714305939213, 76.73036236916819, 93.79919944270965, 34.40092794356808, 0.7335168688047318, 1.1060588686696946, 7.531400822824048, 18.7834031351151, 102.99696922302248, 77.7441224744243, 83.2291570786507, 71.41078118355044, 68.62358416280439, 66.86982970083913, 72.12655882681571, 65.5205382839326, 74.09700855132073, 73.96802533057429, 71.77303560318487, 71.31374959022769, 61.98260745694561, 67.55370278512278, 73.09332109266713, 74.01104588662425, 72.20839515809091, 71.16161654072424, 71.61691742558634, 69.4454070060484, 70.01473119181972, 72.56641341793922, 68.30810008510467, 63.53733693399737, 60.51595872448337, 50.523575582811915, 54.32294022652411, 52.39724866805538, 50.609848114752005, 52.90300300044399, 53.65369366061304, 54.02640904149702, 54.39885770120929, 53.089990231298636, 52.854679399921054, 51.02063794289866, 52.34103718111592, 51.731504778708185, 52.837150327620975, 54.96458115116243, 57.73363720986151, 51.88425756269886, 49.764757771645826, 53.79734654580393, 51.24576237893874, 44.99958792040425, 45.39991678730134, 44.784198807131865, 47.14269253515428, 45.949252574674546, 47.37756406107257, 46.52706869186894, 45.197032190138295, 44.70307242485785, 44.94853042787121, 47.94276975816297, 47.79027977297383, 52.762452710059385, 56.15142368501233, 66.45392510198778, 66.7038820635888, 63.32393646240235, 63.991700372388294, 67.58102601574313, 62.44823986484159, 45.98445192460091, 47.109277863656324, 44.674592095036665, 46.67825252779069, 61.56836594304731, 64.46083545684814, 59.76876681850803, 62.324555766197946, 59.48930971084103, 58.10928260126422, 54.7164402469512, 47.48205992483324, 48.308377804294715, 46.139569897805494, 46.711455391299346, 48.29327275676113, 47.09933073289933, 45.65178394317628, 46.705363950421734, 47.10728922197896, 48.88656654665547, 47.82784038974393, 48.152812680890484, 48.407162697084495, 48.431497081633545, 49.88344477068994, 52.74235056292627, 49.34152226294241, 48.22337219792028, 51.628550406425234, 50.28453457740046, 47.23940641649308, 50.00890178065146, 49.46728521777738, 48.53891903354276, 46.91470476888841, 53.01380603544174, 52.29625155848842, 50.49738199480119, 50.24123161069809, 52.96258380336147, 51.85642050158594, 51.76743761185677, 50.1840748325471, 54.50988038893669, 56.69409928783294, 61.769814952727295, 63.27406352566135, 64.55090092074487, 64.8452316561053, 69.79214452928113, 69.03129885273596, 70.73071279833394, 69.97910822591474, 75.50914026075795, 72.4374694208945, 72.45546525524509, 72.32106916366085, 71.6887281787011, 70.05015019447573, 89.37038852322488, 77.54192429204141, 75.18974165762626, 76.18354474344562, 75.58477140242054, 78.74323644945699, 72.38293278601863, 11.751985857563636, 4.254594925911197, 1.4445800069839725, 0.5581441437525134, 0.13287614249894697, 43.18149874287267, 91.25185535800074, 76.0489917570545, 77.9338239854382, 58.45067001158192, 39.63230679112096, 34.40069652372791, 67.60017502692439, 67.3740582312307, 93.37141006223618, 15.173996917663084, 1.03816693107928, 0.28657890615924714, 0.34149919786760885, 0.37450367524739236, 0.15929880612079175, 0.20411297318435487], [0.10559673976874161, 0.043510369686109406, 0.06463613286013566, 0.015991662155776735, 0.06729895489350443, 0.033350699325843204, 0.11513426629526001, 0.1451340242619476, 33.45241254375827, 53.95666537746307, 40.92901883586761, 32.035315113682906, 28.609307158377867, 45.73678170481036, 59.29121432765838, 63.82689414485809, 77.40726147928547, 17.691113256639053, 0.4458936928741394, 0.9631657588385767, 7.225175990212349, 56.91576811575121, 85.69335476044687, 75.70747098615094, 73.9151047122094, 66.14555620378064, 63.32652914908625, 61.646323050222094, 61.607522964477546, 59.11478611730761, 68.52551706375615, 69.01939838163315, 72.32482679428594, 45.98388318092593, 54.340045682845584, 70.19969447966545, 66.9348547535558, 66.65682146626135, 66.907680573002, 66.62613284203314, 66.42973976750528, 68.67186069488525, 67.09000018335158, 65.41523048954626, 65.64480289336174, 65.96888480647918, 55.882302022749386, 48.77920343029884, 48.90848867354855, 50.41574962677495, 47.39740340940414, 47.958859320609804, 47.25813573406589, 46.72279888583768, 47.05555315940611, 45.315797636585856, 46.467785989084554, 46.71587198011337, 45.685273139707505, 44.86701573095014, 47.58679113080425, 48.04891301739601, 52.30881883252052, 47.96387995443037, 46.79113834134994, 44.87642157462336, 46.46447943102929, 48.616876140717544, 42.012836394771455, 42.896985700053555, 39.217543601989746, 43.39445206426805, 40.93228617022115, 42.317710461155066, 41.44016642724314, 42.73270114775627, 41.22909976590065, 39.668843669276086, 39.40449945388302, 40.22343935505037, 38.433104868858095, 43.32510063725133, 47.49296803628245, 51.82667716856926, 50.37516486260199, 57.92036948665496, 33.54945590419154, 39.87443077948786, 48.59244369691419, 48.73741842085316, 36.16682214121665, 39.554122186476185, 55.15662039479902, 55.65324344942647, 55.545244909101925, 44.54908801663307, 46.8739866441296, 44.35733510601906, 41.50951393188969, 39.883158053121264, 40.334744453430176, 40.76459307824412, 40.562265457645545, 39.54913685398717, 41.29680771981516, 40.7468012071425, 39.94981088945943, 39.94966183939288, 42.54163072955224, 40.479330862722094, 42.518084741407826, 48.44035379348263, 47.41961579168997, 42.517280655522505, 41.186196880955855, 44.00987586667461, 47.18556796350787, 45.50857036344467, 46.337884933717795, 46.08851632764263, 45.461117529099994, 42.58340789425758, 41.64791084104969, 44.014951413677586, 46.08133054548695, 45.69491432559106, 45.673804129323656, 48.058377696621804, 46.42167460533881, 47.561695806441776, 50.81648642016996, 56.80198015705232, 59.9605550304536, 62.80001371137558, 61.50794967528313, 64.72768214441115, 62.19296024691675, 62.55690520809543, 61.79441605844806, 64.34899299375473, 63.05976090892669, 64.1084026521252, 61.3206055087428, 63.7973939987921, 61.57970551521548, 68.04883926145493, 63.66333523104268, 69.46563074665686, 79.90338725428428, 70.83150202228178, 71.28226864722468, 72.42481585471862, 72.36624702330559, 64.9016353391832, 11.089137657996147, 0.36498769877418397, 0.7855844942312088, 0.10698744982120492, 0.13669365055618748, 20.838121060402166, 77.14934210623466, 66.51962480237408, 67.18362715936476, 55.216012923948234, 28.75177548777673, 9.390763140493824, 21.492894080377397, 45.69644012758809, 68.32352284462222, 15.664335354681938, 0.4954280187526057, 0.21338056863075305, 0.053511816076934345, 0.14073321685915993, 0.04016055064576288, 0.0856145466828058, 0.09381213946448219, 0.04863419938051412, 0.03415326069619867, 0.03182240754305836, 0.05848575300807434, 0.04076294856326234, 0.1263728910576432, 0.03400171701345713, 44.23342350990542, 68.61036577532369, 47.45255193402691, 39.421750037900864, 28.51571156132606, 46.208952703783595, 69.15897200184484, 70.1064048274871, 86.59490369981336, 19.355818148582213, 0.25588081308430244, 1.524294581144087, 9.839383248359928, 68.8784440871208, 90.57331669715144, 79.44894929086009, 75.47940869485178, 68.09877887848886, 67.12317559026903, 64.24099445343018, 64.38858539827409, 62.53379068066997, 70.65750568143784, 71.78463797415458, 70.38519120985463, 50.4609392535302, 56.81662628727575, 71.6009690684657, 68.49289863340317, 69.38736377223846, 68.55703723046088, 69.81780467494842, 67.5333849076302, 70.79709499113022, 67.11931597801947, 67.01082321905321, 68.06667035625827, 68.62935789169805, 58.89316043546123, 50.56941632301577, 51.199600004380756, 50.820416635082616, 50.732735972250666, 49.335724999827725, 48.3937874147969, 48.76738925133982, 50.08634897970384, 48.27084464411582, 46.865349585010165, 49.38508410607615, 47.035894240102465, 48.64230878891484, 47.324106077994074, 51.70032978057862, 53.12225957070628, 47.2115772001205, 47.42067090926632, 45.651340715346805, 47.34464753058649, 50.993255876725726, 45.725540191896506, 44.59221839904786, 42.32073460855792, 46.246211298050426, 43.87632700704759, 43.63361466315485, 44.96167821268882, 44.79425184188351, 43.341048994371974, 42.91311448620212, 41.22238466816564, 44.13096727863435, 40.765020616592906, 45.74188078603437, 50.61290364111624, 54.90296856049569, 55.38528280873453, 58.11008276477937, 38.96275820270662, 44.63864357240739, 50.31079092333394, 50.8509522868741, 40.50249245858962, 45.18084849080732, 57.72606311305877, 57.22164238652876, 56.558114636328916, 47.071175959802446, 47.94481723539291, 46.36217224982477, 43.587185567425145, 41.67745805555775, 42.16777001657794, 42.249323937200735, 40.59272658440375, 42.863822060246626, 43.21549392515614, 43.29267832540697, 42.51435456737396, 44.00255672393307, 43.59607365823562, 43.43064377384801, 45.544448283410844, 51.01165571520406, 49.06497555394327, 44.69221530422088, 42.966262602037006, 44.69335279157085, 47.9302534749431, 48.03142709116782, 47.78991499254781, 47.942012740719704, 47.37547343777072, 46.86931510125437, 43.157725257258264, 47.049814731844016, 48.557020771888, 46.292193243580485, 48.421228316522416, 49.63383690003426, 48.391920366594874, 49.991741411147586, 54.1470846822185, 59.79636069267028, 62.103416458252944, 65.60739917139854, 65.33990921512728, 66.58180221434563, 63.311290740966804, 65.7484358356845, 63.36905940886467, 67.10738412795529, 63.43038958887901, 64.92497736407866, 61.51705349645307, 65.9245071103496, 64.23306342094176, 70.84789752960205, 66.11739358594342, 71.0159554020051, 78.00653688369259, 75.93740032565209, 73.24421467319613, 76.34607991864605, 73.77824537215695, 68.86519432067871, 14.031308504842944, 0.745938647418253, 1.434511405325705, 0.059752831791317275, 0.16043473065139788, 21.971829206712787, 84.71713958248016, 71.00302726991715, 76.18656496847831, 52.466737378028135, 26.18425080853124, 20.39507758232855, 30.78484389089769, 50.78817082989601, 79.42768219978579, 19.021194865626676, 0.6784116741149657, 0.14301583711658755, 0.024703263545468934, 0.1152195088985947, 0.04487422452638707, 0.05059409360851973, 0.23811618406926435, 0.16290147248054707, 0.16868598789217013, 0.13834668443568293, 0.20722446993233698, 0.1359363113560023, 0.22814135157292892, 0.30752292263411707, 56.58804624311386, 79.12434962487991, 59.457648338810095, 46.81095023309031, 39.758767927846606, 67.56607394064626, 76.16857697886806, 76.69850487862864, 92.81271549963182, 22.876996532563243, 0.6508187192582315, 2.9096742551172934, 12.867700130708757, 74.54216618691721, 88.68304021896856, 84.72794963467507, 77.06656440611809, 72.08859028354769, 68.82302099658598, 68.28334992931735, 66.46724547109297, 65.88471858732163, 72.90915012359619, 76.77971363067627, 72.61287781500047, 58.85931430324432, 62.05812877224338, 72.1199143317438, 71.30257867997693, 71.62950823383947, 71.94557282232469, 74.21573085169639, 71.43957922535559, 73.84486290716356, 70.3936243057251, 71.40858465625395, 71.51396305330339, 69.8874738139491, 61.64662899509553, 53.722390051810976, 52.96087757233651, 52.969848032920595, 51.32897546214443, 52.38189651120094, 50.559375055374645, 50.75069258289953, 53.007734206414995, 50.49982563141854, 50.65189592299923, 51.47693118741436, 49.32289884936426, 50.285840726667836, 50.190997815901234, 53.573045807500044, 55.30492128864412, 49.17405274606521, 47.874316553915705, 47.29992466588175, 49.3903047807755, 52.861221913368475, 48.315991124799176, 47.140762729029504, 45.39974420301376, 49.78120034740817, 47.192565471895286, 48.59417346216018, 50.02837242618684, 47.489888975697184, 47.087916635697894, 43.52179965665264, 45.72287298017933, 46.15496520073184, 43.99434720316241, 49.705373087236964, 55.08863787497244, 57.70147769681869, 55.20919584458875, 62.06773857916556, 42.632378685858946, 48.25382547993814, 50.237968198714725, 53.977748117139264, 44.967169530930065, 48.61390298412692, 59.390952356400035, 59.56101848233131, 59.66977796246929, 48.28110948685677, 53.43693956252068, 50.74783317504391, 46.25575834704984, 44.65055188825054, 45.39331151593117, 46.0473902763859, 44.43670818882604, 45.62779864957256, 45.86805166736726, 48.13001978781916, 45.17434520106162, 46.832385986082016, 45.89248018880045, 48.46582958775182, 51.27402305603028, 53.52729920418032, 50.969654975398896, 44.6549920112856, 42.94475624638219, 45.90650658453665, 49.72240794089533, 50.727279955340975, 50.175802553853686, 51.60368650190292, 51.43792321605068, 49.781890684558505, 46.07739248583394, 49.391971788098736, 50.197681534674864, 48.52845807229319, 51.17229246324109, 52.995539557549264, 50.472910327296105, 52.338126782448064, 58.6823251939589, 63.03223763742755, 63.961360839105424, 69.60514160894579, 67.74616564473799, 70.14507939738613, 65.95569779795986, 69.5413246462422, 66.81061760071786, 71.26976413111534, 68.06785491205031, 67.552000476468, 64.90980171388196, 68.892925477797, 65.68734884262085, 73.4215764076479, 67.03660103582567, 77.30221256133049, 79.45870030310847, 78.32638263702393, 77.00032341864802, 80.35843710745536, 78.82237419005364, 73.2437204545544, 14.820268750190737, 3.365869195230546, 2.6322835010866967, 0.46082621740718044, 0.1959518998140289, 25.845036391289007, 93.70970664485809, 77.43962887794741, 82.95122577298073, 70.92409349256947, 40.16431746944305, 18.510610134370868, 37.156487126504224, 61.90597611088907, 89.76864245630081, 26.928404838808124, 0.9909574675463861, 0.3316858873492287, 0.26296816826347386, 0.2590552975814189, 0.20908603294482156, 0.13689707754360092], [0.09840116700938634, 0.047244649951256094, 0.06445323702909293, 0.009496134795969533, 0.08249416331490202, 0.04099765109018453, 0.13076013104329187, 0.566211907613662, 28.02527212327527, 49.03342400827716, 41.07021631733064, 30.479718792823057, 32.34875759770794, 42.587757802778675, 58.78651511284613, 63.18490020690426, 73.85971300063595, 5.931015447262795, 0.11418974117165613, 0.6648263611620473, 11.439163108025829, 78.19849767992574, 72.7825987723566, 80.1950703897784, 68.92051542958906, 69.03096937364148, 62.20367223985734, 63.621589445298724, 58.496726482145256, 62.44407823008876, 59.25481473245929, 68.88053863279282, 56.666866271726555, 59.819718407046416, 68.47407125657605, 67.63397016832906, 65.8153553931944, 66.3824987411499, 65.3888290159164, 67.51464382294687, 68.01846442684051, 67.07296925206339, 64.70746232617286, 63.73293768975043, 64.61354509476693, 64.7152364638544, 51.501681343201675, 48.18738837395945, 48.07852691219699, 48.287479416016616, 48.451108932495124, 49.88729653819915, 49.08851369734734, 48.338827163942405, 49.225757429676676, 45.84813387163224, 44.53992928228071, 45.1920586247598, 45.35324842699113, 46.139295331893436, 45.17042675325948, 46.48879812609765, 51.70838632891255, 45.32556433831492, 45.61448612520772, 46.16933284267303, 41.094080017459014, 44.89747685770835, 45.5804713310734, 41.41103890634353, 41.05984557059504, 40.01640096787484, 41.61945796781971, 39.38140846067859, 39.999930935521284, 40.969995837057795, 40.62274840570266, 39.77073507924234, 39.46306436292587, 41.367869300227014, 41.0725736618042, 39.899467268297755, 39.12832144768008, 40.59213430650773, 42.998641767809474, 44.46756155260148, 43.18195373781266, 44.70289199582992, 46.593827432201756, 46.882231466231815, 40.678826532056256, 38.82137636984549, 41.78117336765413, 42.483069742879565, 40.354960349298295, 37.956485902109456, 40.116276279572524, 39.39045344629596, 39.23710838440926, 39.46928916438934, 41.18267459254111, 41.02498746687367, 39.20320341663976, 39.2551395200914, 41.01996291068293, 40.478491475505216, 39.776720616125296, 39.051952900425086, 38.95980465796686, 44.438049639424975, 49.366421468796275, 45.02148651307629, 42.19449312456193, 43.13183761412098, 41.108075034233835, 44.1311163287009, 48.76507897530833, 47.02600594489805, 45.940427241786836, 45.25442431049962, 42.92507379285751, 40.53599342223137, 41.63293915410196, 43.1134299309023, 46.56087560038413, 46.30805530855733, 43.54938176370437, 44.80688579620854, 45.96923312833233, 46.348730287244244, 55.79816326018303, 61.46346999752907, 61.541183917753166, 62.20199738779376, 60.04259532497775, 59.98640344988916, 57.04329613716372, 59.60042653545257, 57.184611289731926, 60.56511778985301, 57.35939994935067, 57.804392845399924, 59.35325837904408, 62.205715794717115, 63.914111968009706, 65.6507452841728, 69.80719858600249, 57.556546118951616, 65.78486680984497, 73.97557197078582, 67.50072725357549, 74.73556257063343, 66.26526694143972, 69.48891393599972, 22.384572375205256, 0.8161574085393261, 1.7088946820266786, 0.2360310766004747, 0.30355336144566536, 8.929018782031152, 72.02679726385301, 67.87229337999898, 69.08720831717216, 60.2118455979132, 59.38930103855749, 13.241058780301003, 26.353675626939346, 44.40286990134947, 71.37735474494197, 21.18166381312955, 0.7114560493538458, 0.17380605992530623, 0.12459020445784255, 0.13311271044996478, 0.14262502502289512, 0.1026513691871397, 0.10911160479149512, 0.042329177020057555, 0.02855470355209564, 0.020848337838786746, 0.05857749203700693, 0.08937301234372201, 0.21645569152409033, 0.41969066666018584, 39.22985592196065, 61.92608610276253, 50.157085003391394, 38.71121268118582, 35.925470859773704, 48.40649981652537, 66.74707520392634, 69.60460032186201, 80.80671694970901, 7.801852658871682, 0.2845173329114914, 1.1578124593342505, 12.901863974909629, 84.17630749364054, 75.80690307001915, 80.0443023250949, 70.99251531785535, 70.94776891892957, 65.83902297481414, 64.75116145226264, 60.23289695862801, 64.1595817381336, 63.43687718914401, 69.19215525350263, 60.21565814172069, 62.257683277130134, 72.00845626092726, 71.53978009377757, 68.348829976974, 68.98141414888444, 70.09193912629159, 71.35083167783677, 68.47402418813398, 70.81784432934177, 66.45549405005671, 68.23791319324125, 66.39986699627292, 67.47811871190225, 54.15079524440151, 50.20364745970696, 49.928763835660874, 50.13680634960052, 48.84718987249559, 52.048310695155976, 49.527732864502944, 49.97118426907448, 49.91633776695498, 47.35174702059838, 47.66427755355836, 48.33791325169225, 48.205529336006414, 47.76056781891854, 47.8626984934653, 48.505343544867735, 52.98962070095924, 46.21725243906821, 45.75077672158518, 45.67811481414303, 41.420068202480195, 44.67552561913767, 48.036067255081676, 44.333898944239465, 44.13048874947333, 43.3415981261961, 44.97891702959615, 43.122851464056204, 42.36893661560551, 44.19796920591786, 42.31992267793225, 43.78929745766425, 43.09850139002646, 43.36665422685685, 45.336213573332756, 41.93472239278978, 40.922648906707764, 43.1649463407455, 44.527436533281886, 46.77700604161909, 45.22377490997315, 47.07168586792485, 47.755598175910215, 51.23735673965947, 43.42904344681771, 42.04892612272694, 43.216717704649895, 45.55445032735025, 41.99561718971499, 39.79796417297856, 41.410156373054754, 40.817792184891246, 43.10511842850716, 42.48596837443691, 44.9238940208189, 42.5961987433895, 42.996409939181426, 42.39851913144512, 42.47658606498472, 44.502066643007346, 43.59575986862183, 42.38748550415039, 42.426591534768384, 47.91789800890031, 51.28032238252702, 44.585617050047844, 40.7800393719827, 44.08942153376918, 43.023489982851096, 45.013543713477354, 49.446971262654955, 50.77066529181696, 47.1642263474003, 47.66051207819293, 45.05510907019339, 43.846281651527654, 43.0669576891007, 43.95207974218553, 48.12156708009782, 47.84916631637081, 46.7606262237795, 47.42890004188784, 49.35969460395075, 48.310962646238266, 56.88904108539705, 63.451115392869525, 62.68688863323581, 63.61229342799034, 60.86056640071254, 61.67717641399753, 60.411486394943736, 62.60715861474315, 59.584890027200025, 61.82354750171785, 60.54230528493082, 59.01048244968538, 61.30443749889251, 63.28963141287527, 65.34683612085158, 69.11682221197313, 70.20418167114258, 60.82035818407613, 65.08964630865282, 75.56501834623276, 67.5232102794032, 75.66292070573377, 68.78012595638153, 70.61748966093987, 24.989883207505752, 1.135585000438075, 1.779141757757433, 0.0518553807670551, 0.3621812122723749, 9.266804475938121, 78.45731919811618, 72.97938408390169, 76.7984547153596, 58.787366267173525, 41.36843019916166, 16.47194843138418, 32.65846206295875, 49.78547180852583, 81.61587838203677, 27.44277269609513, 0.5240602791309357, 0.13947750682071333, 0.006767677700883079, 0.12162123070729357, 0.03159503647757154, 0.016675765265620524, 0.22360981892674203, 0.23882126075125512, 0.1574314668053581, 0.17065992068138816, 0.19791250267336447, 0.22108323030894805, 0.20693488869695895, 0.8726311426970267, 54.19063868061189, 74.02611563282629, 61.40577977703464, 45.3780613407012, 46.67143152606103, 58.04783867251489, 77.2459343940981, 75.45832987754576, 88.93544473955708, 9.067436283634557, 0.5213532308416983, 3.077779195962414, 19.934891385416833, 85.87077925282141, 78.77495273467034, 84.88235765887846, 74.89255935915055, 72.75852326423892, 68.93698153957244, 68.93396131453976, 62.540580303438254, 67.80094546656456, 64.48788804392662, 71.15050838839623, 63.87628070769772, 65.81933267654912, 73.76678420651344, 73.79485268746653, 71.54719337340325, 71.2701955918343, 71.08428309040686, 72.03982737756544, 72.36590969947078, 72.52627188159575, 70.52422354298254, 70.06241936837473, 67.8393925389936, 70.1153164525186, 56.29219362812658, 53.51986631270378, 53.104824635290335, 51.492161750793464, 51.26346795789657, 53.642483526660556, 52.359056549687544, 52.69903582911338, 52.65834908331595, 50.910003569818315, 49.122426509857185, 49.38482522964478, 51.94333237986411, 51.98238741966986, 49.229095366693315, 50.43040360173872, 55.21697390464045, 46.5736742942564, 46.79250724854008, 44.80772518342541, 41.4385857120637, 45.55162229845601, 49.13921425419469, 46.68009211940151, 47.59955452334496, 45.162527099732436, 48.54404557135798, 44.50885626577562, 46.93947453652659, 47.1576524549915, 45.539953247193374, 47.61376527047927, 45.430201407401796, 46.95455997220932, 46.93974125769831, 44.08273781499555, 44.554500887470866, 45.131583521443034, 48.1268544350901, 50.06019069302467, 48.700540296493045, 50.993848154621745, 52.204056247588134, 55.49351669126942, 45.90833440903695, 43.0155118819206, 47.59371019178822, 47.97130500116656, 46.584574560965265, 42.15076261951078, 44.57223000064973, 42.21717619126843, 45.934202440323375, 44.70261350754769, 47.94553502913445, 46.00062385682137, 45.59506254811441, 43.506329828693026, 46.88734623693651, 48.76524763722574, 47.291075798773, 44.93560229578326, 47.6451442318578, 52.153975425228, 52.87864115930373, 46.61039552380962, 41.122140653671764, 44.95589271668465, 43.234811598254794, 46.48373434620519, 51.98610974896339, 53.1477314426053, 50.02694468344412, 49.38588819196148, 49.141077380026545, 45.73480483024351, 48.11418517943352, 46.19892320325298, 49.901268020752944, 49.56730173480127, 49.804997367243615, 49.274449732995805, 52.1183563816932, 50.91683633865849, 60.81754976703275, 68.08017899913173, 67.26455350075999, 67.91365869583623, 65.28685523617652, 66.5145492553711, 62.64544094762495, 65.95249714389925, 61.235293957494925, 65.44959045225575, 62.8379116519805, 60.841503681675086, 62.49805004365983, 66.37540709587836, 68.3055034760506, 71.0848165327503, 70.94806701906266, 65.64191210654475, 72.97128046712568, 76.52402216388334, 73.00880186019405, 80.03394726783999, 73.49624264624812, 75.86779394457417, 27.765999532515004, 1.5266473903771371, 4.200663316634394, 1.1013180714461113, 0.42280916545179587, 11.855566828481614, 88.91970034568541, 79.7771026242164, 84.60277895773612, 75.03905204034622, 76.07910771523753, 20.7261432755378, 43.27482761875276, 59.87214480676959, 93.11185898319368, 38.68042992007348, 0.9526869017750987, 0.41084841855110665, 0.1438664858259501, 0.35399773849114297, 0.2413247441572528, 0.13805587745962605], [0.08683819594162126, 0.04438775869446897, 0.023233908821918794, 0.09740651675289679, 0.1240280414781263, 0.13775596935902873, 0.312782698461125, 2.520714378164661, 42.837118564113496, 44.853765964508064, 41.22735038880379, 24.54370967803463, 23.93268677496141, 49.76563638256442, 56.983354476190385, 67.23512003498693, 67.71117810280093, 4.369998410824807, 0.04823864137213077, 0.295165924415473, 6.786504974288325, 79.16525994577717, 70.43935129719397, 79.03435476364629, 65.74012825565954, 73.27513863963466, 64.77945743068572, 68.19930922600531, 58.293292753158084, 59.75667022889661, 58.45047781544348, 62.43695128348566, 62.78619127888834, 68.27319099057105, 59.99268316453504, 67.87270915123725, 65.1457558139678, 65.84066252554616, 65.74224241318242, 64.86643598925683, 65.94757064696282, 67.81066509985155, 64.65275702937957, 64.9437145263918, 62.1181724148412, 57.53895428872878, 47.39972153017598, 48.62829808265933, 45.151014943276685, 49.126560688018806, 45.71113332625359, 48.06820715627363, 48.329182055688676, 47.6142987128227, 46.50822562556113, 46.82344690445931, 45.834205535150346, 46.20103736077586, 44.19898509979249, 48.03190954269902, 44.82756453175699, 48.90439764145882, 47.6774331831163, 47.447276346145145, 43.60410667234852, 43.960006852303785, 42.5766182714893, 44.74332770993633, 40.30499327567316, 44.017430351626494, 43.442634459464784, 45.42871482910649, 39.31300624724358, 39.398890464536606, 39.98117808372744, 40.41880869096325, 40.28522453000469, 39.365609153624504, 40.42372734315934, 41.13698682477398, 38.17682504653931, 40.80238119248421, 42.18009410365936, 42.35054462186752, 41.52598788661342, 45.261923882269095, 40.886186553585915, 42.837832435484856, 43.11540288309897, 44.09154745840257, 42.68570723072175, 42.81544746891145, 39.94273493366857, 41.49489918062764, 39.766173362731934, 40.932125353044086, 40.617798374545195, 40.31298706608434, 40.088909902880275, 41.429823137098744, 39.008242007224794, 40.606141090393066, 37.83108772770051, 40.69756761673958, 41.12625521998252, 40.530866884416156, 39.04819919217018, 43.26650042687693, 44.78250042084725, 45.94281204285161, 42.15240217024281, 44.86018296210997, 43.30615558931905, 42.62903682647213, 41.531263474495184, 41.56372893241144, 47.81329231877481, 46.12420205147036, 43.932891507302564, 46.56020879745484, 42.848583652127175, 42.79083851845034, 41.177018534752634, 43.287775362691576, 43.73477258989888, 46.85808143308086, 42.495939039414935, 45.79855903502434, 44.65224635216498, 49.75523033449727, 59.88202525723366, 59.85089340517598, 59.64722433397847, 57.20207760410925, 61.41057291338521, 60.62263934843002, 60.69808613869452, 59.86784196669056, 61.15654060917517, 63.79704883021694, 63.268199582253736, 65.49579597288563, 65.55177603998493, 65.23905331088652, 67.25700686054846, 66.23018526261853, 66.99012094928374, 63.13449382781983, 51.5627997152267, 69.16863672194943, 66.16708217128631, 71.79860945670836, 68.23009198711765, 68.89155264823668, 49.164054624495975, 2.358259366404626, 2.124416727212168, 0.18734821148457068, 0.036937775796339396, 2.4168343265210432, 62.72486502124418, 66.99916593490109, 72.09739992695471, 53.38510544069352, 81.89250746080953, 46.37754794090025, 18.841073743758663, 42.97206770989203, 64.1731531389298, 36.11052043976323, 0.5094181938517479, 0.17611115720243226, 0.127957942294738, 0.0839932365042548, 0.087258517742157, 0.052213132336375215, 0.04532506726982613, 0.06591638069479697, 0.02048007362792569, 0.023794051244734757, 0.05498376209288836, 0.12216548255134015, 0.26657362318327354, 2.757455894062596, 54.237107000043316, 57.67960263836769, 49.61538999311386, 33.55573954120759, 29.577989424428633, 51.75441142051451, 67.15627254978304, 72.84863579657771, 76.2757988898985, 4.396124337950061, 0.02941912460711695, 0.7344139271205472, 7.795405753197209, 86.11122054438438, 73.82252108666205, 82.18811296647596, 70.74909302496141, 75.73863813954016, 68.27026490242251, 71.12986887654951, 61.772254666974476, 62.625495695298724, 60.94757633824503, 64.45792113581012, 64.52161258266818, 72.04516964574015, 63.539455013890425, 71.56961364130821, 67.49260010257845, 69.01929640000867, 67.36769614681121, 67.98425351419758, 65.92012190049695, 69.21072375389838, 67.7451301390125, 67.26179999689903, 63.5656564466415, 60.42235136032105, 49.647624031189956, 50.56887111356182, 47.93486618226575, 51.587702843450735, 47.74009696898922, 50.16577697569325, 48.29943087793166, 50.859636414435606, 48.082029588760875, 49.31879212779384, 47.50615504480178, 47.87388117082658, 47.23188331050258, 51.59879922866822, 48.33580301653955, 49.55541695317915, 48.53895825724448, 49.148333764845326, 43.54208615518386, 44.9093420274796, 43.00380752932641, 42.63216687786964, 41.35859289476949, 43.84292410266015, 46.29094200749552, 48.3195447921753, 43.05101325435024, 42.452063406667406, 41.36243289516818, 43.86220647442726, 44.61380320210611, 43.253442856573294, 41.47527556265555, 45.16081302396713, 42.184930386081824, 43.71996956486856, 44.47687325939056, 43.26755554445329, 43.78330407604095, 48.58457542234852, 44.52255318241735, 46.53170101104244, 46.4629771632533, 46.43693262530912, 44.13047305999264, 43.65025335742582, 41.11147180680306, 43.00831825502458, 42.320852279663086, 42.52885556990101, 43.39478938810287, 43.879849295462336, 42.13522218888806, 44.050880324456, 41.266154396918516, 42.99629226807625, 42.17151195772233, 43.65393646301762, 43.764876780971406, 43.54212145651541, 42.45983362197876, 47.88933138693533, 48.19062825172178, 47.25496253659649, 41.09829656539425, 45.48246698994791, 42.63891335456602, 43.12544022836993, 41.3975263410999, 43.59697580337525, 48.52769321010959, 47.25034590690367, 46.503938474962794, 48.15508373322026, 46.52459759866038, 45.704453529850134, 42.76913604428692, 44.85256179686516, 46.170768430156095, 48.26380006728634, 44.7445083433582, 47.761411128505586, 48.64157922806279, 50.45503608642086, 61.72916350826141, 62.122400729886955, 63.87351151435607, 62.05571651458741, 62.07992930566112, 63.67427472145327, 61.18238510624055, 63.327603878513465, 64.37915209800967, 66.17921798459946, 64.60117001687327, 67.40702967489919, 67.77621100025793, 68.06440322629868, 67.77240630119078, 69.19015484471475, 69.00421880906629, 65.85367694977792, 54.84651388660554, 70.40386169187485, 70.26604529350035, 74.71620959620323, 72.54176524377638, 74.43779976137223, 53.41249535160681, 3.2699932302198107, 1.9792879276698636, 0.1697252780920075, 0.10695831549744453, 2.571691462109166, 69.55848109337592, 72.08316956796955, 78.73710186250749, 58.38563319175475, 67.3823344322943, 34.40939634077011, 26.286652126619895, 50.40506901279573, 74.29850855181294, 44.56582869252851, 0.5346455917723718, 0.14902765081534464, 0.06866397801786661, 0.050216741679656896, 0.06548575501167966, 0.1321683998309797, 0.20473796303474134, 0.1625726368999289, 0.20569319806752667, 0.24586107251384567, 0.18475246044897264, 0.3157868662909154, 0.5056805427997343, 3.7109674128793904, 68.62861264136531, 67.61343263810681, 61.590786210952274, 40.402970160207445, 40.19804200818462, 69.56620031787504, 74.97157942864203, 79.90046901087608, 82.28911399841309, 6.314691401297047, 0.14444266055380145, 0.8633187617505751, 8.782310370476015, 85.96747352230935, 75.90599783005254, 86.13432330469932, 72.64355859448834, 80.03235478555003, 70.5212111626902, 74.72375623641476, 64.8554729646252, 66.17528776968679, 64.96962178137996, 65.72552919387817, 67.33714088316887, 73.9071423007596, 64.91350443132463, 75.0414760651127, 69.72015334713844, 70.5095931022398, 71.3185505713186, 69.50126940204252, 70.89445606354745, 70.86995693945116, 70.1527907771449, 69.54832999936997, 66.10026851777108, 63.00761691985592, 51.725621223449714, 53.368717778113584, 51.02636068098007, 53.673937013072354, 49.87256019346176, 52.257506385926284, 51.60151350882746, 52.70555873070994, 51.84176652662216, 51.21084151729461, 50.64753032499745, 49.94029952633766, 48.67080088584654, 53.804183237014286, 50.835251039074315, 53.285441936985144, 50.088110123911214, 51.32803409330307, 43.85259666750508, 44.42708661479335, 43.97921077666744, 42.46234786125922, 40.35092030802081, 44.4782421665807, 47.06563757311913, 53.02789126673053, 45.5934347644929, 45.25023129678542, 45.15818895832185, 46.54646089000087, 46.84810684573266, 44.49375906298238, 46.4744814749687, 49.10506217710434, 43.97051095962525, 46.336782747699374, 49.53770352948097, 48.09764454441686, 45.98320461088612, 49.949262142181404, 46.019549292902795, 48.028046008079286, 47.33086432180097, 50.0395001903657, 47.427276180636504, 47.481899107656176, 42.7099004099446, 45.53447369606265, 44.7329883421621, 45.106194019317634, 46.45976866445234, 48.52612426204067, 44.73644395028391, 46.511516494135705, 44.112634120448945, 46.337853554756414, 43.50546690725511, 45.411927084768976, 46.85412768394717, 45.80068103728756, 45.27636997161373, 52.29985621667678, 49.79215160492928, 47.23164404592207, 40.55705655005671, 45.848294688809304, 43.588487794322354, 44.940909262626406, 43.08844835527482, 42.789748099542436, 53.14833156524166, 50.256387649043916, 48.770303572377856, 50.39119166712607, 47.73950076872303, 48.565991232472086, 45.71582448097968, 47.87187683966852, 48.83803898288358, 51.489631822032315, 47.94985748106434, 48.55420843247445, 50.498456724228404, 53.474582549064394, 65.7511579605841, 64.74063773309031, 67.99373780527424, 62.46610233860632, 65.99401150980304, 65.76832617482832, 63.36495660966443, 64.90083517566805, 67.70742047217585, 68.25627773038804, 68.4991273572368, 69.44745448327834, 71.4442939143027, 68.37852231917843, 71.98587125347507, 72.03011558901879, 73.52289122919883, 67.78664450491628, 60.828916795792125, 72.45573982115715, 74.04008711538008, 78.48634473739132, 75.76691058374222, 78.20197289989841, 59.66825216047226, 3.042250612089711, 3.7765962654544465, 0.7348787892730005, 0.13010460492824355, 3.4652429338424438, 78.61314712032195, 79.54700070042765, 86.26544813955985, 66.3854875872212, 98.54159601273076, 58.8781887485135, 33.2437934414033, 60.454008809981815, 80.3333104041315, 57.55268650670206, 0.7483753586007703, 0.26688781116277943, 0.39843338151131913, 0.1101358643462581, 0.22040156527392327, 0.2627378209464012], [0.12406983923527504, 0.011808340411422955, 0.06862855411224789, 0.05097388935786101, 0.05458159657615808, 0.07713773017448765, 0.17055835274438705, 3.2776528837219363, 54.40490991838517, 45.89484930038453, 46.901917842126664, 30.493582410197106, 36.34268945263278, 49.2721276898538, 58.05831532324515, 67.46176242828369, 66.90300510775658, 5.4355980311670615, 0.15123406064606484, 0.1950818231149066, 17.77974509423779, 82.98641727816674, 69.22615435815626, 80.25865201027163, 66.1972608873921, 74.4439814167638, 63.91820300009943, 70.19514453026557, 59.229558590919744, 61.732144509592366, 52.70405646293394, 60.56643962860108, 60.9396884518285, 63.29709568331319, 63.863858561361994, 65.45899629592896, 61.67455627072243, 68.19733235143846, 61.491718907510084, 64.73596226784491, 62.49581429266161, 60.978143368997884, 56.9784789700662, 59.47834276383924, 51.87913102488364, 49.3593768919668, 47.178695970965975, 49.41155225999894, 44.73463181526431, 49.207381125419374, 47.859733181615034, 47.709922175253595, 46.470868972039995, 47.071085745288485, 48.25410789059055, 45.308647155761726, 43.53101330418741, 46.327137639445645, 43.42890224149151, 48.39419141892464, 44.908428115229455, 44.28520271855016, 47.27647281462147, 45.13955770000335, 44.22441774798978, 44.86381507688954, 45.77637803169989, 46.446122738622854, 43.59623447541268, 42.5243644560537, 40.81762352297383, 45.400022691295995, 42.73238735814249, 41.15916390572825, 39.1964961636451, 40.78744088449786, 38.93773740337741, 40.914498221489694, 40.494734010388775, 41.61133473919284, 38.74290150980796, 41.60256039711737, 40.654452923805486, 41.10952238882742, 42.82629282243791, 44.31709551042126, 41.88787360345164, 43.70466447645619, 41.48479515506376, 40.1977478304217, 40.63508425989459, 41.34266414949971, 41.06904745101929, 42.349112956754624, 37.88338861157818, 39.94422935670422, 38.49283079947195, 41.42357480141425, 40.23576736450195, 41.2024276487289, 38.29971290403797, 41.690429333717596, 41.83450583488711, 42.799875659327355, 40.43589453543387, 41.412168548953154, 44.3687766598117, 47.822525578160445, 42.600250551777506, 41.18347475605626, 43.78490832544143, 45.598357339059156, 40.870834396731475, 41.311473461889456, 38.14505384814355, 44.42849866805538, 44.9126446631647, 45.529025523893296, 41.45025476332634, 44.73774617718112, 41.44203739781534, 42.50233642516598, 39.552121777688306, 44.52267477589269, 44.854640653056485, 45.95530479185043, 44.270552665956565, 47.26004985070998, 44.39883378244216, 51.98297577519571, 58.083936245210715, 60.10489433042465, 54.08275388902234, 54.625456948434156, 63.189865927542414, 61.60997444583524, 61.006223617061494, 64.4208312034607, 66.13555415984123, 64.86131337381178, 64.41822674966627, 66.91386222839355, 64.28254412066552, 62.75701276717648, 67.26946430821573, 66.66756091579315, 67.20349788665771, 65.83503784671908, 61.82978407029183, 62.72075437730359, 69.23277531900715, 67.91731434483683, 69.02073983223208, 66.32866813290504, 71.73388250412481, 11.595127332595087, 1.173043758157761, 0.21570536968929155, 0.06705289511310478, 0.5480502305492279, 54.65160739037299, 69.62459656500047, 72.42207804033833, 57.95255253391882, 78.75956919885452, 50.928383796445786, 19.91130813475578, 43.319491647904925, 63.04298100932952, 52.94402314770607, 0.9545358703021081, 0.02712603192776442, 0.08343313430105487, 0.08013220699203592, 0.10570281996361672, 0.01951365179622606, 0.05657213049069528, 0.036959502049871994, 0.03873952266369616, 0.07329596777356441, 0.07509561556000864, 0.1033539790660143, 0.3095740464425856, 4.5163479255091765, 65.71469560746225, 56.244980058362415, 55.79991263727988, 38.26340352335284, 42.32830478299049, 55.38565935627107, 66.78076836370653, 71.91306421833654, 73.21995089131018, 5.904451685567056, 0.08352315729303707, 0.5584446953669672, 20.666354587001187, 87.42498705464025, 72.24044876713907, 81.5561955974948, 69.41786412269839, 77.68888765765776, 66.31070367751583, 70.84748175836378, 63.35706480087773, 63.35331893736317, 57.670498817197746, 61.93689223258727, 63.27942932805708, 66.2980422665996, 67.5473956138857, 68.07990443321967, 64.76611352735951, 69.91300844377088, 64.06102826518398, 65.04653946045907, 63.439316903391195, 63.37897123829011, 59.140163852322495, 62.13642320325298, 55.840944551652484, 53.18020866763208, 48.33477143318423, 51.34410404389905, 48.11433815187024, 51.79957751304873, 47.82145869347357, 49.833324724628085, 47.894461847120716, 47.72033999043126, 49.16827117243121, 46.7895576261705, 47.04618653943462, 49.00124488338348, 47.75870469308669, 48.48628867057062, 46.94140826502154, 48.0322233323128, 48.6186098283337, 47.84170989067324, 43.86503058095133, 43.9362294443192, 45.31652719743791, 47.15043921624461, 43.16261645286314, 43.57167651576381, 40.19801455159342, 46.16377092176869, 45.39709268077728, 43.849364634483095, 42.63863486628379, 44.05121764829082, 42.71648214709374, 43.78305696672009, 42.67035899623748, 43.342331609418316, 42.778549732700476, 44.09286929715065, 43.57098225624331, 43.4593790577304, 44.643479854829856, 45.92153710703696, 43.82117456005466, 46.85050733627812, 44.93701042667512, 43.079277853811945, 44.00845596867223, 44.099082331503595, 41.499562878762525, 44.82053172203803, 42.459429617851015, 42.65864679890294, 41.48070412297403, 44.997532598433956, 43.714921474456794, 43.71831432465584, 42.301185515619096, 43.59928215703657, 43.95393894564721, 45.25219640424175, 42.77433710713541, 44.56556589372697, 47.556957583273615, 50.0111492987602, 42.567004542196955, 41.03280082825692, 44.21712998420962, 45.74603849841703, 40.16723963522142, 41.01752319643575, 37.409413322325676, 43.86442653594479, 47.566030025482185, 46.690937472927956, 42.86418684067265, 47.5828452264109, 43.894934731145064, 45.469585926302024, 42.40745821306783, 46.85772449739518, 47.8063654130505, 48.173844429754446, 47.21054953913535, 49.19903039932252, 47.77912455220377, 55.48566018381427, 60.20098455490605, 62.00039148330689, 59.88000131422474, 59.12252103128741, 64.67199625507479, 64.5162114789409, 63.56661350496354, 65.9183725234001, 67.22062295483005, 65.23373457693285, 66.84637392720869, 65.84350232155093, 68.0077563562701, 67.16607063047348, 68.29561910321637, 69.08292508894398, 71.61152024422923, 69.02815311185776, 65.31391174562516, 66.97837737298781, 72.59966727226012, 68.49400474179176, 72.87455481867637, 69.43953914027061, 77.47083525503837, 12.824320677788029, 0.9062399102314826, 0.3077066918053935, 0.03905068076546154, 0.6786074861884118, 59.046874200144124, 77.49020391894926, 78.29903587218254, 62.615352446033114, 77.73792512955205, 41.98206932313981, 25.326112701046853, 50.26993159324893, 70.61534020208543, 63.12915155964514, 0.82951957540166, 0.02808918256402737, 0.06259007672328623, 0.050270773860956394, 0.08330155103918045, 0.013939822055098992, 0.17546168318198574, 0.15637238089355732, 0.1477612308677166, 0.18220759297330535, 0.1750107025427203, 0.1401890646065435, 0.5132194608449936, 6.2311620769962195, 80.97800685513405, 66.23781819497385, 69.2276527035621, 42.93358141376127, 52.50049721810126, 69.69876858495897, 75.21260123099051, 77.67276671624954, 84.21451922385924, 8.441861387222044, 0.24393906516413538, 1.4069594514946784, 23.46783099635955, 89.70353111144036, 74.64787406306114, 87.08715331169867, 71.6974985984064, 81.24818755734353, 67.6699383028092, 75.86748015496039, 65.63245134968912, 67.58846282958984, 58.926782992578325, 66.6878552590647, 66.17724111003261, 69.26300894829535, 68.8985501566241, 72.94474171053979, 66.44320134193667, 72.44606725631222, 66.47026569612565, 69.19397523326259, 66.86670749418198, 67.26733838358234, 63.652097640498994, 64.27365602985506, 57.70494114968085, 54.14101677556192, 50.95743679231214, 53.94467861421647, 50.53212634978756, 53.799782337680945, 51.17839567122921, 52.293215643975046, 50.00974509023851, 49.32460508038921, 52.10558906678231, 50.1846984894045, 48.473250712117846, 52.32493977392874, 49.416145355470725, 52.11064500193442, 50.09991645812989, 49.97682855975244, 51.884755703710745, 47.59640878246677, 45.03663470668178, 44.014774907019834, 46.61709885443411, 49.0084110536883, 43.759295248216205, 45.16603369866648, 39.68150900256249, 49.15073425539079, 48.9847356273282, 45.65602402533255, 46.01454434856292, 47.69202832252749, 44.90447436609576, 48.556546165097146, 45.47872897117369, 47.03107756953086, 43.44918481765255, 48.04628110701039, 45.208489433411636, 47.52407243174892, 49.19062476004324, 49.25062133419899, 47.54794005424746, 49.34245578704342, 47.833029685481904, 44.867760981282885, 46.1311956374876, 47.99770255242625, 45.10973591958323, 48.57041174365629, 44.62051437747094, 44.42192477564658, 44.555395187870154, 46.65652259703606, 47.23473487361785, 47.500212653990715, 44.51588123075424, 47.17036877909015, 47.05907544782085, 47.540271820560584, 47.196597668432425, 47.042079817864206, 50.750225820849025, 51.51915157994917, 42.5137112986657, 40.358435569270966, 45.07283033863191, 46.7525775201859, 41.091550088697865, 39.902946410640595, 38.26776912135463, 45.76652503782704, 48.838603804188395, 50.04007285641086, 46.04673131819695, 49.75814073316513, 46.521353798527876, 50.27481102174329, 44.03685000634963, 49.34715870888003, 50.42943085393598, 50.570714627542806, 50.60491377307523, 50.31487411068332, 50.8101753265627, 56.586406692381836, 64.9936306092047, 63.949825148428644, 61.65032386779786, 61.14774273287866, 67.64676493983116, 66.28824418590915, 67.13456615324944, 70.54528667080787, 73.75362857695549, 69.42009202895626, 70.45366010358258, 71.75561243487944, 69.31720041459607, 68.87752625250047, 72.21806772293584, 70.4734916071738, 74.28802797871252, 70.43848053101571, 68.23483805502615, 68.27238298231556, 77.0221317968061, 73.19703640476351, 76.87053218964608, 73.17765205137192, 81.29408713309996, 12.851383070791922, 2.7038282684741484, 0.8019846593660693, 0.27140442041620133, 1.0978668759907446, 66.20947514810871, 86.24038419415875, 87.04877684193274, 71.7168515728366, 93.72549026243149, 61.89870011421942, 33.52392127436976, 60.488686484675256, 80.842818444775, 78.24482871640113, 1.4596422761678698, 0.19691232892294086, 0.17667096829222095, 0.1591526825101145, 0.1876002084463835, 0.1163403798014887], [0.03312469572730122, 0.03517141069976553, 0.051062272921685255, 0.011019227714578231, 0.060358600495683576, 0.09961478817727297, 0.2466861185647788, 6.60349355589959, 58.53027451422907, 47.498518190076275, 37.35230753498693, 37.31887325163811, 46.138565771041385, 36.73899396773308, 64.84140734518728, 68.23427323372134, 56.256590274072465, 0.7484616507445613, 0.0820406239419695, 0.7404331718721698, 21.603755950927738, 82.17323933878254, 70.1199213151009, 77.55014557992259, 65.76162284420383, 71.36044148475894, 65.54229174890827, 66.3906886500697, 58.95373359803231, 59.48190819832587, 57.943558539113695, 58.240003431996996, 57.95442350449101, 62.88860828645768, 62.519332824214814, 66.62683886866417, 64.31256201959425, 60.9993084784477, 62.383030460726836, 62.27279224703389, 57.511744806843424, 54.79276172576412, 51.064890123182735, 49.52394777728666, 45.919407260033395, 48.91761210656936, 47.088328484565984, 46.501188893472, 46.71431872152513, 46.09694942351311, 45.318488382524066, 46.28201861535349, 46.049335771991366, 45.86944803114861, 44.10423240353985, 45.82025758681759, 43.13964705313406, 44.752341316592315, 42.97823759817308, 45.87528844033518, 42.915256100316206, 45.601569760230284, 47.37224532711891, 46.555694149386504, 42.92377548833048, 45.98773494843514, 45.13182278602354, 49.343499137509255, 46.54270325937579, 48.54113125031995, 45.47779544707268, 45.96194144218199, 46.18028017782396, 41.379475593566895, 42.04001057532526, 38.66419915230044, 40.41287414489254, 38.32480430603027, 39.06553214596164, 43.63086900403423, 40.84033012390137, 40.42618666925738, 40.09121233417142, 41.875165124093336, 41.29598794444915, 43.58751504651962, 41.669625082323634, 43.09212361612628, 39.70746724836288, 40.336081981658936, 43.40257921526509, 41.81162272730182, 39.82846452343849, 40.289213580469934, 40.482111823174264, 41.475510904865885, 38.79774016718711, 42.12361197317801, 38.5236959303579, 40.45966017630793, 39.11311049615183, 41.01478538205547, 40.70971127479307, 40.08237915654337, 44.61528193566107, 45.26406941875335, 46.12821463615664, 44.51338268095448, 40.66949129104614, 48.39444245061567, 48.35087276274159, 45.19899729759463, 39.886437154585316, 41.00186117233769, 40.64767506814773, 41.891050723291215, 44.130602498208326, 45.03795654542985, 43.3240572867855, 43.352619986380304, 43.08602433050833, 40.49454181425033, 39.54655201204362, 44.50181168894614, 46.14144479074786, 44.97643416927707, 44.544287035542155, 45.10076938136932, 45.86781632515692, 52.7672536911503, 56.77496287130541, 59.06472098442816, 52.71190512564875, 56.0127757441613, 61.6462799041502, 58.643026967202466, 59.470843192069765, 58.31856850654849, 60.23045332201066, 58.8328226151005, 62.01410801179948, 63.42252915905368, 66.0267319217805, 66.46306422448927, 65.74955763355379, 63.609841946632635, 65.51563924358737, 64.37481003422891, 68.65916790500765, 66.7542217623803, 67.19914405576645, 62.75562424813548, 69.01574273263255, 64.876500791119, 77.62288985713836, 31.017648327735166, 0.6789833595675807, 0.2705109473918715, 0.10912852767374247, 0.10138664229382431, 42.177266074765114, 76.24912677272674, 65.42622881550943, 65.57021117979481, 51.85895043034708, 36.2060183863486, 20.32220386689709, 42.799750143481845, 65.08624169134325, 60.19204155091317, 1.3345219771708212, 0.23105798619649104, 0.02325294419161735, 0.05525711758603012, 0.011603363053572756, 0.07448965533366127, 0.0417653669513041, 0.05770038265073973, 0.06351257681906705, 0.017099049911203406, 0.0224778758016445, 0.11651176899190872, 0.27158999755497903, 7.444098178417453, 74.55122686201527, 56.26503513705347, 47.3906373208569, 34.63163783473354, 37.65072145769673, 46.00840976161342, 72.67034838276525, 73.58651991813414, 65.73739044127926, 0.9324678802682508, 0.11261877829148886, 0.5622910083301607, 23.87731271405374, 85.43020294558617, 72.04662092270391, 79.51732404770391, 68.11127554985785, 74.25878278670773, 69.90228468371977, 70.13136679126372, 61.42322255719093, 62.14016514439737, 58.65521769369803, 60.1786623462554, 60.31258775341896, 65.85484581608927, 66.2782342972294, 70.97903020920293, 64.4481622788214, 63.71328661518713, 65.02063612784109, 63.92075646308161, 60.16499680857505, 57.53768736316312, 53.47002475492416, 53.04997421080067, 47.6840070755251, 50.66318058198499, 49.349539587574625, 47.88844493127639, 47.90458548453547, 48.7274516782453, 47.179696175359915, 49.215339614499, 48.83734864573325, 47.974831211951475, 45.79406007643669, 48.64398364097842, 46.369997378318544, 46.56188757188859, 46.31748860882175, 47.1798687596475, 45.11006932104788, 46.593062570018155, 48.47547861837572, 47.366624570661976, 44.05893687278994, 46.014803224994296, 44.37305988803987, 50.277533146642874, 48.73558667398269, 49.10736068602532, 44.969205241049494, 46.36059153464533, 49.54998054812032, 43.992146753495746, 44.8532364445348, 42.10263121512629, 44.31773093438918, 40.609329977343165, 45.06595442371984, 44.6535603461727, 45.028891947961625, 42.6263500029041, 42.00209302286948, 45.98589143445415, 43.080921326914144, 46.65140782633136, 44.41662565354378, 46.42502038709579, 43.11745428269909, 41.894420039269235, 45.58824154638475, 43.79099584394886, 42.335953404826505, 42.091209273184504, 43.6483431631519, 43.797201033561464, 40.6947748891769, 43.873008681881814, 42.34184480482533, 43.80200201465238, 41.082363897754306, 42.166318739614184, 40.98833291761337, 42.7253153247218, 46.36539251573625, 47.15854675539079, 46.088202538028845, 44.22777137448711, 42.81919725479619, 49.189553952986195, 49.13193825752505, 45.80448965872488, 40.057177928186235, 42.56962076310189, 40.06714467079409, 43.85379691277781, 46.09412139461887, 46.98696659457299, 44.58230656962241, 45.57504277075491, 44.796644487688624, 44.48939738735076, 42.63406922740322, 46.43715620040894, 48.16789419420304, 46.205638300987985, 46.99511335742089, 46.870362374090384, 48.679645830585116, 54.936273405628825, 60.40861129760743, 59.64702429309968, 55.5513402723497, 58.84399744772143, 64.50634279558736, 61.34792089462281, 63.72355930266842, 60.61020543498378, 62.054779068116225, 62.116007266506074, 64.97981602145781, 66.64574469289472, 67.88678261541551, 68.5987320253926, 67.59786082852271, 66.07976236651021, 68.50556004431941, 66.4017261997346, 72.72848575345932, 68.17458260443904, 71.68933222370764, 64.50239689119401, 71.76635188441124, 67.26816992605886, 81.68774404833394, 33.252728600655836, 0.0922946495214297, 0.8950284892512906, 0.021988973810127186, 0.08776274915303915, 45.29134558093163, 81.12110276376048, 72.7130865281628, 70.72781808914678, 57.97553762312859, 36.44409841106784, 23.880795778766757, 53.563345786063906, 71.16685682727446, 73.08017330784952, 1.9718247603985573, 0.17101356218899452, 0.043613358716210054, 0.004427326493896544, 0.050898743793368346, 0.05000935401767493, 0.18593096414641028, 0.1861297333192441, 0.16540366885883195, 0.08219920414229555, 0.1346848454446562, 0.18457454418943775, 0.5441484528203164, 9.32738156087937, 88.35342776390814, 66.55524776827905, 57.120378555790076, 49.396196180774325, 61.317157745361335, 52.808948486082016, 84.87561902692242, 78.27388563463765, 76.82539355370307, 1.407508215596599, 0.23505158722400668, 1.2073653551840013, 25.888333474436116, 88.09596338579732, 76.09032569393035, 82.52354621887207, 71.30817197984265, 77.04050417869323, 71.99323746465868, 73.90638920568651, 62.69843216865294, 65.66267713423699, 61.819378022224676, 64.9152224294601, 62.547103205034816, 68.57130681314777, 67.1173155692316, 71.95548072937997, 66.91334447553082, 66.5113172223491, 69.25081822179979, 66.78683234799293, 63.67633788816391, 60.86774433812788, 56.52057363140968, 53.02583594476023, 49.93698120117188, 54.272212213085545, 51.234811121417636, 50.27934135929231, 49.951862673605646, 51.07452738669611, 49.49082728355162, 51.91791149877733, 50.95512259391047, 50.532169495859456, 49.06446956819104, 51.00947095501808, 49.154413438612416, 49.509584057715635, 48.2270396140314, 50.815850996202045, 47.223677712102095, 49.67983845741519, 50.22549898393693, 48.228224169823434, 44.467824351403024, 46.474238288018014, 44.02192931021414, 50.40695567284861, 49.882017027947214, 49.66279575901647, 47.249690871084894, 46.939125445581254, 50.243475206436656, 46.60939531941568, 46.71885298144433, 43.949416452838534, 48.85454823893886, 42.10357258396764, 47.56532792122134, 49.09778225806452, 47.34565165735061, 46.12827347170922, 44.93917557501024, 48.56305729958319, 44.76242965267551, 49.05188660467825, 47.16945486684, 50.03661332591888, 45.605382304037775, 43.96858899824081, 48.24541199591852, 46.94305173812374, 45.3562411954326, 44.25681652561311, 46.62532406468546, 48.42808069721345, 43.99193102313627, 48.66175982259935, 46.196475644265455, 46.74837273936118, 45.98351447812973, 45.647637997904134, 44.92176417381533, 44.63896912913169, 50.68522822472357, 47.49179132523076, 45.65511403545257, 45.266003147248306, 44.02769127199727, 50.64019549277521, 51.07351541519166, 46.697676104883996, 40.87616882016582, 42.18624830245972, 42.10264690460698, 43.637031047574936, 50.05846877251902, 50.53310301996047, 47.62883893905148, 48.51270975605134, 48.39439145980343, 45.417206595020915, 44.613940485062145, 50.91369844252064, 51.1287933780301, 47.601350968883885, 49.74046653316867, 49.936996890652566, 50.857514412172385, 56.991446325855875, 63.56752349484352, 63.333805145755896, 61.38057070393717, 63.480215457177934, 67.04715221158921, 63.53504234744657, 66.39630548415646, 62.487596927150605, 63.75584825392693, 62.25767151001961, 68.11216985025715, 67.78055698640885, 70.4632620657644, 71.30559890500962, 70.86356347607028, 69.06582355499268, 72.39877131677443, 69.97009461925876, 75.72566293901014, 71.72508855019846, 74.34538872011247, 68.76380105172434, 77.58385442918348, 72.92694983943817, 84.80684418832102, 35.66422923918694, 2.0119887277964623, 1.4811583151740413, 0.4601335207060461, 0.21060066537991648, 51.12919345978768, 90.86962822944888, 79.86282994670253, 81.66046004141532, 67.21280959344679, 49.423935182632945, 33.26035368827082, 62.15914941603138, 79.61067645780503, 87.48190064584055, 3.6309542482899086, 0.457823152744001, 0.1603329022445025, 0.15218586360494937, 0.1344999118197349, 0.26620715736381473], [0.06974554861024504, 0.1104084001253209, 0.06991522942459391, 0.0874951929454842, 0.07469521970638344, 0.05031467835989691, 0.515543281310989, 8.447325248872081, 57.460377447066776, 43.104667355937345, 38.92515051749445, 47.82800512929117, 58.39802003675892, 36.795927170784246, 65.54652398632419, 65.37908584840837, 51.84589678241361, 0.10490045777612156, 0.25308070043402336, 0.4519499856377802, 30.939195040733587, 83.48528000616258, 70.04929511777817, 71.5979645329137, 66.10743861044607, 70.01149131405738, 63.92413754617015, 64.1654456815412, 60.0705579019362, 60.61297070595526, 55.85412763780164, 58.34384033756872, 61.708574987226925, 59.828830072956706, 61.92058301741078, 62.60378537639495, 61.770901449265025, 59.1421171926683, 58.591753744309955, 56.53138760597476, 53.2936514577558, 48.81545397543138, 48.89527813080819, 47.910790674148075, 47.002483490974676, 46.09579624668245, 45.604993989390714, 45.692600127189394, 44.06769552538472, 47.477906134820756, 45.87737906363703, 45.86325853101669, 48.86516217262515, 44.989134803895034, 45.68477499869562, 43.91599393660023, 44.93937169351886, 44.236784981143096, 44.0294014253924, 43.60161204491892, 46.402960977246686, 44.612673559496486, 46.94396172800372, 47.358654314471835, 46.06250709103, 42.930714161165305, 45.49998821750764, 49.43768701245708, 50.136743591677764, 48.60652892820297, 46.42042336925384, 44.660012645106164, 46.18797979047222, 46.24227716076759, 41.703463369800204, 41.52209297303231, 40.37698838018602, 39.90213448001493, 38.5866891953253, 40.794748260128884, 38.974827335726836, 40.94854047221523, 40.767056326712336, 43.08282367644772, 39.541303880753055, 44.022545122331195, 41.999233615013864, 43.066353644094164, 39.0198169216033, 41.97774294883975, 42.830932986351755, 42.877518976888354, 38.80070940140755, 40.599206339928415, 39.3343125620196, 40.517664186416134, 40.43290568936256, 40.02308076427829, 40.74880553830055, 39.737092910274384, 42.75255618556854, 43.1742972712363, 41.50015907902872, 42.003760030192716, 46.53380732382498, 45.683559063942205, 48.04424539689095, 49.322851780922186, 49.19697507735222, 48.784796730164565, 47.96890843299128, 45.516830875027566, 43.13095115846203, 40.72582829383112, 39.880945836344075, 45.988652783055464, 44.96376883599066, 40.59217353020945, 41.51249493322065, 44.082435792492284, 41.15973264940324, 40.91875399312666, 41.619650163958156, 43.102866988028254, 44.341990793904955, 43.38730158344392, 44.75289044841644, 45.19639284380021, 45.36870648784023, 51.589311015221384, 56.53963635044714, 59.57407997500513, 51.497064713508856, 55.91659138279577, 58.88314270204114, 59.777701977760564, 59.563462118948664, 61.544823877273075, 60.178725104178156, 61.27923234816521, 59.14973443554294, 60.943320566608065, 63.876798460560465, 63.537740938125125, 65.41861549500497, 61.22642155616515, 64.20623048659294, 66.16153593986266, 66.06412779900336, 63.55031605689757, 65.11221170425415, 59.78013776963758, 65.69275779108848, 64.53872588373, 78.75565467342254, 48.463644827565844, 0.5810808774925048, 0.6500917937486403, 0.07329504846805528, 0.06655699873883879, 31.336742947178504, 77.31736859967633, 66.1924442168205, 69.25966708890854, 44.27537325889834, 25.119815641833892, 18.61742215771829, 33.267939552184075, 58.068662535759714, 72.89114644450527, 7.863153421109724, 0.49698118541029196, 0.15291019973735656, 0.035773866073859316, 0.013696072987400958, 0.1619784131405815, 0.03261880190562337, 0.09064973617393164, 0.042355821558064034, 0.11757995602824997, 0.10362737286355227, 0.2071145516369612, 0.3947257611059374, 11.135678541275764, 73.77124786376953, 53.539670359703806, 48.217935792861454, 48.86148691177369, 55.92146296654978, 42.178674205656975, 75.78999765457647, 72.25485171041181, 57.482060309379335, 0.1728731946599099, 0.1263388844146844, 0.5850934008917501, 33.45644081792524, 83.82427477067517, 72.87559032440186, 75.37596010392713, 67.38893970366448, 71.33869586452361, 65.54121309711088, 66.71540598715505, 61.85392625870244, 61.32580657159129, 58.975204652355565, 60.264566175399295, 63.69636943263393, 62.32718767658357, 64.53425045936339, 65.8160614198254, 63.14404087681925, 62.442877984816036, 61.722875948875185, 59.40392755693006, 55.0338972768476, 51.68595821626725, 50.49436961450885, 50.01415775668237, 47.243987744854344, 46.1220290583949, 48.5941420831988, 49.3996988573382, 48.75688122164819, 49.25318264192151, 49.37295221513318, 49.257101089723655, 49.685835761408654, 49.63050680775797, 47.29184458332677, 47.89876468719975, 46.92407531123008, 46.672431730454974, 46.54582938840313, 47.29344491035708, 47.08803430680306, 45.99420293684929, 49.26401230596727, 48.73335484535464, 46.8236037992662, 44.442740794151064, 47.566496787532685, 47.49469387915827, 50.97698980762113, 50.627926318876206, 46.901576595921675, 44.84808637249855, 45.6960988813831, 45.415119894089244, 44.74520652524887, 43.73555314156317, 41.82339768255911, 43.45241292830437, 42.091848619522594, 42.58718513673352, 42.2062563127087, 43.95740632087954, 43.849046922499134, 44.41439774728591, 42.58207036602882, 45.624641141583844, 45.12780627896709, 46.835292462379705, 42.65337513339135, 42.22167907222625, 45.815291866179436, 45.634709865816184, 42.221922259176935, 42.59106436083394, 42.564615818762014, 42.39698548470774, 43.578968201914144, 43.56669510564497, 42.682694850429414, 43.169704175764515, 44.823438198335715, 45.34766689423592, 43.70628441533735, 44.52730317269602, 46.477160453796394, 45.86350564033755, 48.318022912548436, 50.05105549289335, 49.3390158684023, 51.7735408198449, 48.077201151078754, 45.36847114562989, 44.003003874132716, 40.30770363346223, 40.55276939945836, 45.864015548459946, 48.57614232647804, 43.31529078945037, 43.70719048284715, 45.95211590490034, 43.7736628901574, 43.21645490584835, 43.52873048474712, 43.63495611375378, 47.06813220054873, 46.56203662195514, 45.39295065787531, 46.840011073697, 47.83891716311055, 52.604192918346776, 58.973772987242675, 60.28098129457044, 55.77863377909507, 57.299658329256125, 62.464843257781006, 60.49541727189095, 62.21975787993401, 62.81747610338273, 62.86903565929782, 63.94569097026702, 63.303626429650095, 62.72605742177656, 66.19714321628695, 67.50947413905975, 68.39706728535315, 63.94739327892181, 66.56083322340443, 67.99427124761766, 69.79849092421993, 67.69869712091261, 67.58210074517035, 62.85907283906014, 68.79296779632568, 69.14730687295237, 81.54037275621968, 50.86450015344928, 0.8390356131619023, 0.8555481174299795, 0.044377205833312006, 0.06440626051757606, 34.10443598224271, 85.19431160342309, 71.41966927436091, 77.52348915223153, 49.74946837271414, 31.657567331867835, 21.86160276013036, 44.86524281963226, 63.33444056972381, 84.21484085821336, 9.19385721606593, 0.3970310728876822, 0.1006936774619164, 0.025584877528730902, 0.015770800922426487, 0.054912140532847376, 0.13650566790132754, 0.1845731345876571, 0.15758465374669722, 0.33910866646516713, 0.21596812252556125, 0.4689295890350496, 0.7001543525726565, 13.40515603942256, 87.25007287917599, 63.621267810944595, 59.42938766171856, 63.973480962937884, 79.70280508841239, 53.16963003527734, 82.04662522962018, 78.38530448175247, 66.42490740745299, 0.38953211398855336, 0.45893572691467505, 1.2113081952256541, 38.986347336922925, 85.52193149443596, 75.99508270140618, 78.13183307647705, 71.8503455192812, 76.49379637933548, 68.85131697500907, 69.14282752621558, 64.62998767052927, 67.2255886754682, 62.02105845174482, 62.04165481751966, 69.27729422046293, 65.4920893330728, 66.18320311269453, 69.81734968000843, 67.23190369144564, 64.95943930841261, 66.01898131832, 61.011962044623594, 60.07487250912575, 53.82234381091211, 53.03548497538413, 53.589464849041356, 49.289688141115256, 49.62704727726598, 49.19431963274556, 52.925560551304976, 49.3517243477606, 52.33761295195549, 51.4020178394933, 51.29145406907605, 52.90731760763353, 50.200442883276175, 50.18340802961781, 50.59488427254462, 48.41525062437981, 50.3644528696614, 50.00350459929436, 49.418588992088075, 52.80058207050447, 49.5404334991209, 50.680768489837654, 51.021214531313994, 48.141382894208355, 43.37109042752174, 48.01422357559205, 48.813520246936434, 52.54085840717439, 53.465514029226, 48.24376067807598, 47.01713354356828, 45.86085411810106, 47.023060244898645, 47.10889347137944, 46.08175808383573, 43.94507831142795, 46.4290015928207, 44.336181763679754, 46.20498718753938, 45.87184459932389, 46.563625181874926, 47.38524013949979, 47.46862580699306, 46.81228776131907, 48.19386028474378, 47.50062450285881, 50.10758469181676, 44.877927764769524, 46.057470767728745, 48.00659064323672, 49.08171622983871, 43.98184660942324, 45.02563245834843, 45.09559185274186, 44.88210901137322, 46.984083652496345, 46.20698759632726, 44.65880847746327, 44.939469752773164, 48.95893035396453, 49.363071764669115, 45.88557681729717, 47.20089266377111, 49.26064298998926, 46.50151837256647, 49.59393462827129, 50.57120100144417, 51.4795748649105, 51.74712757910452, 49.07618568789575, 45.14651206231887, 44.54798583061465, 42.10672616958618, 40.934608213363155, 47.92164387241487, 51.06341138962777, 46.366694742633456, 45.455857630698915, 49.76587564714494, 46.985119158221835, 45.57854544731879, 47.27846930103917, 47.94188722487419, 48.611027886790616, 49.70691065634451, 46.87134296663346, 50.36819873317596, 51.29852610249674, 56.481863760179095, 62.695278583034394, 63.36237176772087, 59.49060409299789, 62.40587826698058, 64.32977730228056, 63.84707081702448, 65.52995589471632, 65.57554952559933, 66.3319315448884, 66.65596638956379, 64.83056199166083, 67.22292930849137, 68.91136846234723, 71.11398327735164, 71.47428435664024, 65.44450313814225, 69.56376060362786, 72.68973273615684, 73.74329705392161, 71.00205452211442, 72.65711430580386, 67.72907195552703, 72.53424998252623, 75.08245698867306, 85.63175785926082, 54.67762447172596, 1.1598782001003143, 2.3436316222913804, 0.41501048231317156, 0.14134814031422138, 37.15611450133785, 93.52868141666536, 77.17813230329945, 86.1296792184153, 58.094773753996826, 38.91262246716408, 28.812709508403657, 52.79442787170411, 73.0690965344829, 97.51796722412111, 14.404149401572443, 0.9595975051483802, 0.2924158832719249, 0.223856330699017, 0.28099970231133126, 0.28411896719086555], [0.039621592469273076, 0.06536925602103434, 0.018073197739619403, 0.02516175567683193, 0.035755970259948124, 0.06272568577720274, 0.20567150245751106, 5.685610886543028, 52.50493734113632, 40.98342211015763, 38.5834453951928, 34.75680851167248, 30.228236029225013, 40.79283022111462, 63.46815024652789, 66.61802922525715, 43.75153287764519, 0.11461709565933674, 0.1801466785611645, 0.8383895865371152, 26.668585077408824, 86.8280807618172, 69.42399086490755, 73.49133183879238, 63.96083916387251, 68.71898405013546, 62.33579335674163, 63.58344831774312, 55.744669975772986, 58.692997963197776, 57.85510124698762, 59.20043891476047, 61.07170366471814, 61.78499844766433, 58.70727539062501, 59.300565258149184, 56.89595622401084, 57.26261546534877, 54.08885709701046, 50.822664153191354, 50.139948168108546, 48.6327931188768, 46.606022081067486, 47.70315608670635, 45.48259250579342, 47.13363970479658, 46.09887530726772, 46.331467936115885, 46.16750109580256, 46.12536307304136, 45.489374283821356, 45.13930274594215, 44.73822862871232, 46.17295711271225, 45.46611070632935, 45.88048165844333, 44.6434876995702, 44.81143574560843, 43.28282533153411, 45.77016107497677, 48.311119541045166, 44.74593608610092, 47.48802584986533, 50.7887238840903, 41.96013150676605, 43.61335954358501, 44.55059420677924, 44.28741493532735, 48.33609719430247, 50.18117620098976, 44.346732939443285, 45.397273109805205, 46.928264402574115, 48.678292612875666, 46.557227796123875, 46.80754169341057, 39.82636997776647, 39.67644522267003, 39.319199669745664, 39.20301514287149, 37.563715442534416, 40.164556734023556, 42.409097763799856, 40.28087069911342, 42.66367135509368, 42.502767885884936, 40.78072578676286, 42.53601389546549, 41.023410674064394, 39.3864800853114, 41.566239249321725, 42.081258220057336, 40.77505403949369, 42.27719237727504, 38.17637005159932, 40.61661774112333, 39.91008904672439, 39.32217282633628, 40.48952118042977, 38.86758973521572, 37.892433597195534, 40.61989684258738, 44.45067967137983, 46.40619301026868, 45.99657204843337, 45.98008240422895, 48.35184551054432, 45.45969370872744, 47.6451442318578, 46.04247162418981, 46.03971419795867, 41.47025492883498, 38.91392077169111, 38.72434085415256, 39.64089285942816, 41.82793586484848, 44.166723605125185, 42.53981074979229, 43.6588982612856, 42.56154068054692, 39.765561472985056, 41.95794674658006, 40.23129194013534, 43.02810661254391, 44.17823183921076, 43.63093568432716, 43.73866358110982, 45.004804672733435, 47.31590832433393, 48.988132399897424, 56.29668081960371, 54.67493372578775, 51.76715520120437, 57.267428213550204, 56.9377020097548, 57.92962235789145, 56.30150925728583, 55.531555837200536, 62.387631400938965, 57.45470177742743, 61.932585470138065, 60.21683485277238, 62.748101142144975, 65.69017687151509, 62.88320326036023, 64.45079418920702, 65.66487758390366, 65.25863770515689, 66.94335060734903, 60.0156839432255, 57.46981859207154, 55.850413153248454, 64.98063579682382, 64.62505725122267, 74.31487268017185, 57.68436439575688, 3.771479778712796, 0.903084853724126, 0.39241162399130486, 0.37801882372267787, 20.407036888983942, 78.10939711909141, 64.281940075659, 69.36013467850225, 52.25267010350382, 30.22433719327373, 28.792817208074755, 43.38640728304463, 52.39039628736435, 73.52502499857258, 12.818356713941021, 0.7657790376294045, 0.21922649365038643, 0.11258625785910314, 0.03226899083763842, 0.08271754689274297, 0.026730079384100054, 0.06150618105405762, 0.0518020112518101, 0.019534451083370277, 0.06258368754999773, 0.1634859669232561, 0.30097207415007776, 7.540467381477357, 66.58355159144249, 51.03557040614467, 49.6265765928453, 38.368154341174716, 33.62993117301695, 46.73557012311874, 71.07973314100697, 72.35538205792828, 48.01650639503233, 0.09320836258871902, 0.22372263303447157, 0.8594970248879925, 29.250047899061634, 90.66153864706718, 72.21163503585323, 76.37831395672214, 65.57696550123154, 69.88670502939533, 66.84218483586466, 66.7928021953952, 57.96715159570017, 60.27629013984435, 59.73758789800829, 62.601894793971894, 61.68378168536771, 63.311059321126635, 61.112759113311775, 63.78718799160373, 60.79930290099114, 58.51012922102406, 57.239136157497285, 53.14993189227197, 52.490683447930124, 49.76172185713246, 48.49132891624205, 50.12564328409011, 48.48258595312796, 48.73361764415618, 47.082017390958725, 48.63182429344424, 47.99064228611608, 49.047442559273016, 49.1500517629808, 48.5081676513918, 46.93691715117424, 47.35964275175526, 46.73389527105516, 47.033929132646136, 50.0298511597418, 46.583754785599254, 43.37625226666851, 46.41050369508805, 49.381636342694684, 47.28580805563158, 49.13384845179897, 51.1507272720337, 43.00607858165618, 42.581270202513664, 44.60215376269433, 45.33233434923234, 49.060602111201135, 51.08670242371098, 45.57130082961052, 45.79468373329409, 50.071828365325935, 49.12150867523686, 46.169124957053896, 48.64764321234919, 43.24669245750674, 41.897236301052956, 41.66494569470806, 43.08802866166638, 40.82183222616873, 42.68974727199924, 44.79188273029943, 44.06104318557247, 45.65659276900753, 44.93189565597042, 43.6082330057698, 45.6416210820598, 42.35517694104103, 42.29142665863037, 43.76801075473909, 45.69564388644311, 43.77474938669513, 43.767230203074796, 42.18579722988991, 43.96488628079815, 43.61637584624752, 42.8118702673143, 44.32857236554546, 41.295195625674346, 43.07845023370559, 45.809498525434925, 45.57548992095455, 46.18136275199152, 47.07778123117263, 46.51366203061996, 50.18360414812642, 46.26254796981812, 48.047281311404326, 46.78029691019366, 47.94226377241073, 42.698380408748505, 40.0359029923716, 39.754649439165675, 39.328005390782515, 43.30015828532558, 46.691204194099676, 44.941642745848625, 45.292694876270915, 44.0516177300484, 43.054425716400154, 44.276773545049856, 44.3841641179977, 45.4983643562563, 47.48933984387306, 45.31388744231194, 45.90906789225917, 46.66861526427731, 49.69310391333796, 51.868834803181315, 57.5372794366652, 56.24479570696431, 55.10144049121488, 58.93728709989979, 59.212727700510335, 59.6350924430355, 59.720611879902506, 59.145321769099084, 63.17636120703913, 59.99142800607989, 63.89250755310059, 63.64224072425597, 66.28872271507018, 65.52943814185359, 65.62228848857265, 66.22561177899762, 68.28222813144808, 66.8020825232229, 70.00430553190171, 63.65256048017933, 60.16092538833619, 59.448873996734626, 67.74749925059658, 65.87190812633884, 79.18652703685146, 63.57444255582748, 4.56242940118236, 1.4122279300805063, 0.24078042336529304, 0.22181769412371422, 21.437574932652137, 88.28764177137806, 69.41595785079464, 78.5756649509553, 57.03560044688564, 32.31025757328157, 30.66524297960343, 48.879129732808764, 57.856968295189645, 84.36473031197825, 16.99525340910881, 0.6247747328973586, 0.12683769192306266, 0.0822299242680592, 0.055635783355683095, 0.03607678106955944, 0.1392680124169396, 0.14888008695936975, 0.16887421569516584, 0.1013317137896534, 0.13435323662575216, 0.34870741107771475, 0.5494574421355801, 11.888985422349746, 86.46865044870685, 62.91253474450881, 56.97811811201034, 47.17045899360411, 44.008157868539136, 55.64293546061362, 78.23908636646887, 77.62399596552696, 55.417791412722686, 0.2330602335953905, 0.2954003166767859, 1.0589275461050773, 32.95548354425738, 93.16656820235714, 75.0867166826802, 78.97511912930396, 69.04696479920419, 75.83428905856225, 69.46098666037284, 71.37584071005546, 61.89406779504592, 65.26032040196081, 64.43609706817135, 65.40709549380888, 66.88114966115644, 68.04829797437115, 63.31982189609159, 67.07402829200991, 63.247077618875814, 61.64018454090242, 60.13920722469207, 56.11931908515192, 55.98429149196994, 53.915217691852206, 50.88804614159369, 53.94140735749276, 48.990144575795824, 51.33239184656451, 49.6776536972292, 51.72086338843069, 50.80063612230363, 51.150287966574396, 51.475244568240264, 51.31480001634168, 47.83088414899765, 50.102669961990856, 50.16454142908896, 49.1219558254365, 51.66671899057204, 48.78165098928636, 45.430491662794545, 49.470093634820756, 54.255130290985115, 49.188749867100874, 50.29695280136601, 51.82493171384258, 41.926869807704804, 43.94024595137566, 44.30158253638975, 48.61489142141035, 50.52372463287846, 53.595454308294485, 48.00399011181247, 47.94457012607206, 50.79328952297088, 49.332281158816436, 47.91344611875473, 51.996378514074514, 49.09455806978288, 44.30654041228756, 44.19197582429455, 44.78834083003383, 44.54347510491648, 44.09345373030632, 48.597742819016986, 46.06120486413279, 49.04210029109832, 48.19926138847105, 47.62248469937233, 48.13482861365042, 45.34039481993645, 45.22570471609793, 45.67771473238545, 48.12957263761952, 46.875583048789736, 46.59952663606214, 45.95774842846779, 47.39045689182897, 46.58900291688981, 46.00551505242625, 47.39971760780581, 43.84900377642724, 45.773185222379624, 48.627039001834014, 47.70905140907534, 47.99644739397111, 47.311021051099225, 46.47840384514102, 50.5668197139617, 45.709591834775864, 49.75979989574802, 47.76376847297915, 47.55359611203594, 43.19816489373484, 40.11613115187615, 38.4224634785806, 40.038864381851695, 44.13602713615664, 49.51403594786122, 47.81952104260845, 49.644580271936235, 49.05278482744771, 45.40581995441068, 47.967861160155266, 46.22192790431362, 49.18961671090896, 50.21785820684126, 47.51574916224326, 49.10199096125942, 49.9640965461731, 52.641882973332564, 54.88634555570541, 60.99386030627836, 59.65941506047403, 58.25089193159535, 61.29399614949381, 63.02849569628316, 61.75314880186512, 62.71662412151214, 61.4044540159164, 66.78355324652888, 63.004839881773925, 68.33339937271612, 67.14971434685492, 69.77930268933697, 69.21265356002316, 68.25111589124127, 68.77800787648847, 72.46127036310011, 69.62884056952693, 74.98537832690825, 67.69976400559949, 65.1469325250195, 62.86618017381238, 71.78614416430074, 71.02632614874071, 81.99334375319943, 67.01218820387318, 4.818116945605125, 3.0611221155812665, 0.548873131553973, 0.29546402454856907, 23.723040011621293, 96.15870121986636, 76.18205424278014, 86.00912909353934, 67.80398922581827, 46.24463058287098, 41.788163031301195, 62.217157348509765, 65.75190321091684, 98.96898531144666, 23.78147744363354, 1.094412738757749, 0.295588682375608, 0.24455728279727124, 0.10703752132793588, 0.14519017850679738], [0.0751642263945072, 0.037605815957630837, 0.09698536757740284, 0.023710135888728886, 0.051434017086942355, 0.06739840076695527, 0.17251153987261558, 2.199322965837294, 36.07729796440371, 41.77394836179672, 33.37796595788772, 46.7943468401509, 44.824155992077245, 39.36915889863045, 65.57073285502773, 65.00886509495398, 36.71134125801825, 0.1406605304369042, 0.46360864874816715, 0.600100634319167, 20.655732808574555, 86.1267609750071, 68.91281189457064, 71.03791283022973, 63.84723555657172, 65.28834965921217, 61.08183906924341, 62.92518438831453, 57.602147594574966, 58.454549235682336, 54.3944215005444, 57.025625859537435, 56.879717611497455, 57.4187610995385, 54.84352111816407, 54.96485571707449, 51.766680594413515, 51.208680291329664, 50.65066037639495, 48.99630269696636, 49.664902071799006, 44.66674343232186, 47.09651447111561, 46.302783643045736, 46.02724106081071, 45.077152790561804, 47.485237044672814, 46.294530976203184, 46.26116337314729, 48.27499843412831, 50.60904010649651, 49.14159513288929, 49.856678516634055, 46.01869421620523, 45.17598475179365, 46.079149707671135, 45.60879476608769, 43.49673571125154, 43.02054820522186, 43.71829863517515, 46.304870343977406, 45.84037934580157, 46.26719205610214, 46.75640967584426, 45.95404178865495, 45.43706947757352, 43.440065307001916, 42.88533626064178, 46.3206696510315, 43.76899134728217, 43.874075566568685, 46.50799420572097, 46.84751849020682, 47.50536664839714, 44.112610586227916, 48.09329463589577, 45.02231805555282, 40.95527125943092, 39.22860076350551, 40.87463909579862, 40.27606187328216, 40.36717853238506, 38.71600973990656, 41.705887394566695, 43.79306685539984, 45.7367346363683, 42.2092608482607, 40.573832527283706, 39.310711660692775, 41.403735453082675, 41.27925511329405, 40.93759313706429, 42.39181580082063, 40.99608352107387, 40.160277428165564, 38.802450933764064, 41.55347193441084, 40.74534993017874, 40.48726973995086, 41.015903257554584, 44.63116753485895, 46.78898103775517, 42.3919334719258, 44.93081308180287, 47.26711403939032, 46.545264567098315, 46.70606605468258, 48.7791524394866, 45.30844711488294, 47.784678628367764, 42.422829981773134, 40.53815464819632, 39.07233745821061, 40.153166171043154, 39.85249688548427, 43.09725407631167, 42.62542040117326, 42.590052389329486, 38.93595664731918, 40.495965634622884, 40.54969426124327, 41.63567304611206, 40.84981441497803, 42.54218378374654, 43.188598232884566, 43.1353912814971, 45.89704190531085, 43.528181352923, 44.286830502171675, 48.4452881351594, 51.42424591125981, 51.43034127450759, 52.67570557132844, 54.21984072654478, 53.03993294315954, 56.74305831232379, 56.56379422833843, 55.978666813142844, 58.57771165909306, 59.7580312913464, 57.68992239429105, 58.106238842010505, 58.727126506067094, 62.69094828636416, 65.6755974215846, 63.46472601736746, 61.36537151951944, 61.99329591566517, 56.256233338386785, 53.88151668733167, 54.49919193021713, 56.72048899435229, 64.3131660646008, 69.09246429320305, 70.6104999972928, 62.818856777683386, 9.388480321053537, 0.9169836498556599, 0.2991151076651389, 0.27834686240361584, 10.615031949935421, 75.77128794885452, 62.082502380494155, 68.72169048555436, 58.41895372636857, 39.77050758177235, 22.278850770765736, 39.13615442091419, 49.47910724147674, 81.40727104679232, 19.508568971387803, 0.5380749077566209, 0.14412274223662194, 0.11415797916631545, 0.025740818556157813, 0.0368478064305119, 0.09103016777625007, 0.09082720810247046, 0.03631131888757791, 0.06419138817657387, 0.07080546955788328, 0.12597488539834178, 0.07303369757268699, 3.5748202281613506, 52.64657805042883, 52.444046466581284, 44.74481036586147, 48.58258285830098, 41.46970971938103, 47.25750423246815, 72.41988151304184, 74.47960438266878, 41.69635211267779, 0.12277415472893946, 0.2756310500685246, 0.7212768675338838, 22.883513550604544, 89.86216745068951, 69.483093138664, 74.27024395235124, 66.27231936300954, 67.7128254982733, 62.66367604655605, 63.558639326403224, 59.82149916310465, 62.61402668491487, 57.28174878704933, 58.8381491937945, 58.49250993421001, 58.84711180963824, 59.96937644097113, 57.804734091604914, 54.31857462852232, 53.644091698431204, 51.26657839744322, 51.79205440705823, 51.06606683423443, 47.55623194479173, 49.06889792411558, 50.03808813710367, 48.38729196979154, 47.33852471074751, 49.5086544559848, 48.16000238541634, 49.58446994904549, 51.23737635151033, 53.534877223353234, 53.662703344898844, 50.68866029862435, 46.789565470910844, 46.63878563911685, 46.3852632430292, 46.39994467458418, 46.735919214064076, 46.21812320524647, 45.70586950548234, 48.5421157652332, 46.88280805464714, 48.578083899713334, 48.343231985645915, 45.18904624446746, 45.41997971073274, 42.82265678528817, 44.01196648997646, 47.929476845648985, 45.31074562380391, 44.4264002000132, 47.54931680617794, 46.61341182647213, 47.16045302729453, 44.79587178076468, 48.148976602861964, 48.18708635145619, 42.523521146466656, 42.24912389632195, 42.645055786255874, 43.30540641661614, 43.2482143371336, 42.39614609749087, 43.08416120467648, 46.0333913372409, 47.31192319623886, 43.45368769861037, 42.91034137049029, 41.984826749370946, 43.67011231760825, 44.696596591703354, 44.36825106220861, 44.9223642964517, 45.114662416519664, 42.31714956222042, 42.16625598169143, 42.99719049084572, 42.70619377013176, 42.23703515145087, 44.209473517633256, 46.43149229788011, 48.6563547965019, 42.69843924430109, 45.445624166919345, 45.14631594381025, 47.54063660098661, 48.09945667943647, 49.420495263991825, 45.51239467436268, 46.89865050777313, 44.65976553578531, 40.14388976558563, 39.42436233643563, 38.931885227080315, 41.382413448825965, 45.26656012381277, 45.82045762769638, 45.01984696234427, 43.040042384978264, 41.94631299664898, 44.157615861585064, 42.95811191681893, 42.157061946007516, 44.75741294122512, 45.5628598889997, 45.085695712797104, 45.70332780961068, 47.11010940613286, 47.01600390095865, 49.563724533204116, 52.98909510335615, 54.020745138968195, 58.02531642298545, 56.00099686653384, 56.576961625006895, 59.674524030377796, 58.896631733063735, 57.25756345256683, 60.9546366045552, 61.9912092147335, 61.71810242437548, 61.12150599879604, 61.74604931185323, 63.845282216225904, 68.46526161316903, 64.51204984418808, 65.74814558029175, 66.09998610711867, 58.413560467381636, 56.82124683933874, 58.39221100653372, 60.98371313464258, 69.18655410889657, 72.24022911440942, 74.72865135438981, 66.82594622335127, 10.528687834739685, 1.4324435808004872, 0.1098875905717573, 0.288853237345334, 11.627495711849583, 82.31283649321526, 69.85101930556759, 76.30272988350161, 64.74379131870886, 47.62938022613526, 25.02306449797846, 51.657764219468646, 53.283586655893636, 91.67518108121811, 24.110876129519557, 0.5353467767277073, 0.14098392679325997, 0.08415612211871533, 0.03155690253592067, 0.06855525481965273, 0.1487601329121859, 0.16942799001211123, 0.13173362961219204, 0.13419848686504748, 0.15062983177842634, 0.2570495108563093, 0.29236090880247856, 7.565664687464315, 73.21547938931373, 61.614320431986165, 54.56817073206748, 61.41570729594077, 64.21686403213009, 56.84784835384738, 79.43244395717498, 81.12875923033684, 48.94158171069238, 0.22954928328193006, 0.8139708097423277, 0.981135730060839, 28.320404983335926, 93.77185267786827, 73.60797528297671, 77.37238376371323, 71.27300400887766, 71.19849466508435, 67.64361919895296, 66.53015244391658, 63.8044071966602, 64.60511199889645, 60.2519557552953, 61.88260270703224, 62.66087155188284, 62.259483645039225, 61.48700421856296, 62.13126920884656, 56.405114743017386, 56.031650189430486, 55.80298777549498, 53.48846381710422, 54.24251594851094, 50.01480102539063, 51.835106342069565, 51.719596462865034, 50.534095379614065, 49.93206647134597, 51.22002770823818, 51.000390668069166, 50.513024407048384, 53.63882003291961, 55.25724487919962, 53.321759162410615, 54.748183988755756, 50.00615612153084, 48.58033926256242, 49.575621081936745, 50.31572918738089, 49.60846308738955, 49.691664403484715, 49.338380444434385, 51.89398111835603, 50.874898356776086, 51.86242957268992, 49.511207918966974, 45.61247394930932, 45.02152573677802, 43.335181128594186, 44.849114033483694, 48.273292203103345, 46.47962762463478, 45.57212060497653, 48.05694210913874, 48.42400143223424, 48.122665343746064, 44.43606099774761, 48.69185224656136, 49.374568231644176, 47.18902749399985, 45.56829629405853, 46.501067299996656, 46.252651829873365, 45.76695257617582, 43.7058098085465, 47.014340816005586, 50.46140601558071, 50.813250464777795, 46.46132192304058, 45.83956349280573, 44.534783132614635, 47.61148245103898, 47.28097177320912, 47.85854470345282, 47.910218008102916, 48.35259076087706, 45.33853561647477, 46.12794399261475, 46.93046092987061, 46.447334751006096, 46.377269452618016, 46.357351656883, 49.64289757513231, 50.404096264992994, 41.607835984999134, 46.595412069751376, 46.67060782832485, 45.97838009557417, 48.01086210435437, 50.86280961190501, 46.2119415498549, 48.43721197497461, 44.90298386543028, 40.92418255344514, 40.21584172402659, 39.65986928632183, 40.59746872994208, 46.579142078276604, 49.55770761735978, 48.016443637109575, 44.92960106941962, 45.131061846210116, 46.60321758639428, 44.42328191572621, 44.89776319073093, 46.44711117590628, 48.86389916942966, 46.099738228705625, 50.07411510713639, 48.08389271459272, 49.845197739139685, 52.29933454144386, 57.44255811937394, 55.21594232128513, 60.08076390912456, 59.2462561207433, 59.853101699583, 62.76805816158172, 62.32044904462753, 60.459131425426854, 65.99412133616786, 65.53702008339667, 64.52772755776682, 62.42998123168946, 65.71781389174923, 68.3367176978819, 72.75255341683665, 66.87994941588371, 67.57133776141752, 70.52577680157077, 63.01918791186426, 62.49464150398009, 62.67221896879135, 63.51936463386782, 72.18184855676466, 76.73732849859422, 79.3350907294981, 69.48416786809122, 10.94443848056178, 2.3151253067678024, 0.7451779527529594, 0.3730822757126824, 12.646792242603919, 91.1928472211284, 74.25937898697393, 83.11263915031188, 74.66163373762562, 57.03538863889633, 31.69452194244631, 58.148239581815666, 60.92109249484155, 105.04472886362385, 32.649787741322676, 0.6835174969127101, 0.23998795137290033, 0.14701063324126507, 0.20086293709614586, 0.13079615249749155], [0.03934026200083956, 0.004546986076034485, 0.06244068574761191, 0.15022749772235272, 0.03340577338671973, 0.041848280647348975, 0.051634582735958605, 1.7749423701916973, 30.269173806713475, 36.08563300101988, 35.12226358536751, 22.9302760477989, 49.95660089677381, 55.2928953016958, 60.66572658477291, 73.29548789608863, 32.888340411647675, 0.13845387545804824, 0.1524565071468392, 0.9771391412904187, 10.453296938250142, 83.54184058404739, 68.42397474473523, 71.7521607491278, 60.733112904333304, 63.78420699027277, 60.18870361389653, 61.16222412355485, 60.09902646464687, 60.68629941632671, 55.469515708185014, 55.26810592220676, 55.40323549701322, 54.704563310069425, 48.54484181250296, 49.85595287815217, 47.36665594962336, 47.382772968661406, 47.40478138769827, 47.577655930672925, 48.93758481548679, 47.09124280560402, 47.23165973540276, 45.06336565940611, 46.491481027295514, 49.89483533367034, 50.38520220787295, 56.08876774387976, 56.48848864340014, 56.130329178225615, 56.26157560656148, 55.51941217914705, 53.828199909579375, 50.00375563098539, 44.70388827785369, 42.87809164293351, 44.95762640430082, 45.010456808151744, 44.17133631244783, 46.11951089674427, 43.94045383699479, 44.45865384994015, 44.44148171332575, 50.20236092229044, 47.203759916367076, 43.0888484370324, 43.91282858387117, 45.30459534737372, 42.47487198921942, 44.73067806613061, 46.849679716171764, 45.536246607380534, 44.06069801699731, 47.11509866099204, 45.81986142743019, 48.34404783864176, 44.48571820412913, 44.088852790094194, 39.58174351722964, 40.58861986283333, 39.12918044674782, 41.72852339283113, 41.82387228934996, 43.2546470242162, 39.65196571042461, 42.09981103097239, 41.60960105157668, 41.252500626348684, 40.210338638674834, 40.31232418552522, 43.946478597579464, 42.75043026093514, 41.73780372065883, 42.02914168757778, 41.04836479310067, 42.07135423537224, 37.645904787125126, 39.56450470032231, 41.63351574251729, 44.94602011096093, 45.57490941016905, 41.094864491493475, 42.44494822717483, 48.35013535714919, 44.9462083847292, 46.74178707984186, 45.62788886408652, 48.727251637366514, 41.93698952274938, 43.08551442238593, 41.88965435950987, 40.65651216814595, 38.820599740551366, 39.40630374416229, 41.259666796653505, 44.86374447422643, 40.77294380434098, 40.64885177919942, 38.78988365973196, 39.998346297971665, 42.20490309499925, 40.28375756356024, 42.18080797503072, 44.91378607288484, 44.12747636918099, 43.777216557533514, 44.567660439398985, 45.56736669232769, 44.44654157084804, 45.27727996149371, 47.032972074324086, 49.762710294415875, 51.122086125035445, 52.55117816309775, 51.75918102264405, 52.84618746849799, 53.478163673031716, 55.01124558910247, 53.039073944091804, 57.1780256302126, 56.622708228326616, 59.902641234859345, 60.34729680707378, 59.721894494948856, 62.2112149576987, 59.20158032448062, 58.12701563681326, 54.4378617502028, 51.54486663879887, 53.07312011718751, 53.185672529282115, 62.052660988223174, 67.47005431882798, 68.39287819400911, 68.9995982570033, 68.58471347439674, 12.954902264379687, 0.8741671183416921, 0.2786462189209077, 0.13329114764928818, 5.568133448400806, 73.12692011556318, 62.16156559605753, 65.64899198470577, 54.791486955458126, 31.905547418902, 18.758174450166766, 35.81232616978307, 43.05811274436213, 74.18614049111643, 23.97775088587115, 0.4855517970938837, 0.16493416421355742, 0.07019367940243214, 0.029303251893349716, 0.052340540419062304, 0.06867574512838356, 0.05611391798142464, 0.023490992607548836, 0.08545833369416576, 0.0845503049992746, 0.07739446922055176, 0.1598088368172607, 3.575004824707585, 48.47275649347613, 47.81282163435414, 46.56576287361884, 33.461069214728575, 58.05786425067533, 60.30272691480575, 70.50370170224097, 77.29311266253072, 37.85353937456685, 0.18728211341846376, 0.2191985161193917, 1.3776176711243968, 13.003331768897272, 88.85166291267642, 73.45160607368716, 74.35810504421111, 62.45921465658373, 65.56637117939611, 64.15210570058515, 63.935775218471406, 63.06806848895166, 63.76126896950507, 58.65902631513534, 57.036518281505955, 57.64045738404798, 56.012661995426306, 52.33988008191509, 50.51351078094975, 49.73582636925482, 50.266264177137806, 50.36916363623835, 50.32742177286456, 51.79451373315627, 48.819886253726104, 49.35793345974338, 47.71542918297553, 49.50790136091171, 52.107714991415705, 53.00376084543044, 57.640606434114524, 60.365673111331084, 57.23248774005521, 59.85529430450932, 57.04980334927959, 55.7622931849572, 52.792101906191924, 46.019478690239694, 46.51758832316245, 44.50864053541615, 45.133760436888664, 47.041440471526116, 47.417631072382775, 47.487323745604485, 46.630889907959975, 44.78196697850382, 51.73269717924057, 48.30988791681106, 43.17593289959816, 43.51801849180653, 46.04981430115239, 41.93900169864778, 45.32461120236305, 46.532450183745354, 46.41151958896268, 45.68838750162433, 46.85669683641004, 46.55623151410011, 48.18166563587804, 46.51157140731812, 46.41320228576661, 43.714850871793686, 43.23917719625658, 42.534825417303274, 44.56296536230272, 43.688108151958836, 45.07654090081492, 42.77938127517701, 44.94139563652777, 44.68197007333079, 44.32048836062032, 42.950027911893784, 43.24309564405873, 46.219276382077126, 45.62537854717624, 45.19667917682279, 44.2213543768852, 43.965388344180205, 46.50006317323255, 42.186424809117476, 41.55631565278576, 43.00378791747555, 45.695985132648104, 46.0064721107483, 42.46785094661098, 42.95977107940182, 47.29489618732084, 45.7880941514046, 46.98928079297466, 45.482651341346006, 48.731009267991595, 42.25001427435106, 40.91999346210111, 40.427073124916326, 39.71930496154293, 38.08320591526647, 39.14092402304373, 42.30199744624477, 47.220324085604766, 42.9363113834012, 42.42879198443505, 41.82018918375815, 42.33906776674333, 45.03270841413929, 43.72514317112584, 42.49060069361041, 47.12896816192135, 46.67327896241219, 45.46353763149631, 47.22745103220786, 46.429342839025686, 45.98898618452011, 47.14119811211863, 48.35423815634943, 51.27347000183598, 52.57572435563611, 53.791007995605476, 54.83737476410405, 55.658581795230994, 56.371884422917525, 56.7797677747665, 53.476720240808305, 60.17188449059764, 59.354282117659054, 60.1808588735519, 62.265833962348204, 61.96885954949164, 62.71958158862207, 61.011726702413256, 59.12321921317809, 58.121234063179266, 55.40147043043568, 57.68746699056318, 56.36909561772501, 63.26315149184197, 71.10672689253285, 70.1510335553077, 74.20627793958111, 71.04287070612754, 14.794387971201251, 0.5801357088550445, 0.2283044823355252, 0.20811455684804148, 6.321539859617911, 79.00060669068368, 68.08314431098201, 71.20961850689304, 63.78656825711651, 36.12363684561945, 24.758524164076775, 45.49677971870669, 48.404954402677475, 87.32113053721767, 31.281612073221517, 0.244919014193358, 0.06364190778244408, 0.04876816517583305, 0.017385354205485315, 0.014560040135327128, 0.11859524469341963, 0.1656999303809097, 0.1341050854253192, 0.23302323154864774, 0.12226028593196986, 0.2573349092516207, 0.29113657772541046, 8.476907764711688, 73.24205736960135, 56.07154069408294, 57.04499844581851, 36.46213739149032, 68.1337115072435, 73.42449465105611, 77.21748936560847, 86.81732562280472, 43.4461175241778, 0.2011360934064273, 0.5200623420457686, 1.8513750236841942, 16.043773678041276, 94.5611982960855, 74.9887986336985, 78.11191528074204, 66.04136236252324, 68.28571119616109, 66.85909809604769, 67.34231841179633, 66.37157101784983, 66.4212360689717, 62.53726982301282, 60.20729564851331, 61.596638387249364, 60.043285662128085, 55.00792726393669, 52.55220974645307, 51.13027603395524, 52.54369820317915, 52.55013873500209, 52.871396541595466, 55.17529872155959, 50.14024234587147, 52.08565165919643, 50.09911237224456, 50.9436418164161, 53.86800412208804, 56.3878837708504, 59.69036648350378, 61.12209435432189, 59.693119987364746, 63.47263351563485, 61.03889303822672, 58.52084513633483, 54.27242009870468, 47.607767966485795, 46.64972512952743, 49.221713466029016, 48.8580705273536, 48.46892433781778, 51.36999168703633, 49.2766894063642, 49.59627236089399, 47.66225753291961, 53.72885019548478, 48.56571274418985, 44.041607841368645, 44.41844563330374, 46.92533046968522, 41.6371831586284, 47.06865387578165, 47.69440135648174, 46.28929853439332, 47.96958308066092, 47.67283224290418, 47.17001968814481, 48.355085388306655, 45.231596116096746, 48.47484711677798, 47.28780454204929, 45.71339653384301, 45.915037739661436, 49.75910563622752, 48.191302899391424, 48.45242684887302, 43.72935971906109, 47.5010363517269, 46.97249304863715, 45.84678065392279, 44.79285547810216, 46.590297299046675, 50.08799637517622, 47.61829168565812, 48.563822161766794, 47.59697752614176, 46.742959868523386, 48.296253758092085, 43.95783778159849, 43.88144177775229, 46.953226366350734, 49.09412268669375, 48.1903850647711, 39.94005595484088, 43.340068401828894, 49.40255042045347, 44.98930738818261, 48.68199533031833, 45.9336454637589, 50.389916896820075, 44.285853831998764, 43.93124018946002, 42.008341358553984, 40.608725932336625, 39.37672122832268, 39.120025634765625, 43.68418185941635, 48.575000916757894, 46.24089256409676, 45.56503288207516, 43.43283637877434, 45.429063920051824, 48.52869341450353, 45.1771967641769, 47.70125765954295, 50.2989375206732, 48.111878825772195, 47.91039059239049, 50.24420476728871, 49.33842751287645, 48.87280687209099, 50.50992965698243, 51.419923459329915, 55.591262155963534, 56.36460450387771, 57.504951261704974, 58.61018103937949, 59.164121689335, 59.70984889614967, 59.84448032994425, 58.47716169972574, 62.70455498849193, 64.08389568328857, 65.39792891471618, 66.5692663192749, 65.38705610459851, 67.96505743457426, 66.62472078877111, 62.12301261963383, 61.53670849338655, 58.033518099015765, 60.101783890878, 59.84151894046415, 68.45230994686004, 73.78488986722886, 75.60405377418765, 78.75758447954732, 75.45670601629442, 15.756723842313214, 2.2973307390366835, 0.9578381995520285, 0.24619769154777452, 7.47293838570195, 88.34770110345657, 72.84938104691045, 80.4217912304786, 72.35080857430735, 45.97186896108812, 27.470803914531587, 53.07321033170147, 57.24059920157156, 98.03804997474917, 37.53995372403053, 0.5471934991017465, 0.2396595294797613, 0.19244553070635567, 0.16635770879445538, 0.10710427822965769], [0.04409697470104983, 0.0743652196721204, 0.028041836415087024, 0.06339729973866094, 0.17729488561951345, 0.0238595268644032, 0.09335571194007512, 4.724777773503335, 30.111084638103364, 35.93923837907853, 47.80018375765893, 12.900334250542427, 19.909203783158336, 52.08199601019583, 62.124416828155525, 69.61075844303255, 37.035344723732244, 0.13797422780865623, 0.23895189406410342, 0.22080428237395905, 5.938672404135428, 75.43947896649762, 70.86457544757475, 70.32345310334237, 60.81709084972259, 63.72778761771418, 62.33595809628887, 64.09195223162251, 60.003371623254594, 60.21841556795182, 56.58340607920001, 54.5551053170235, 48.87835310351465, 47.88101596217002, 48.62805097333847, 46.39002892278856, 47.209537567630896, 47.24917704059232, 48.43106562091459, 48.13677018688571, 45.61358005769792, 47.769985429702274, 46.11816944614534, 48.77872490113782, 52.398990200411895, 58.06552071725169, 58.18915382508309, 54.501996424890336, 57.241203246578095, 59.487991794463134, 60.55058148599441, 56.657703615004024, 60.26176168072609, 58.17717490657684, 51.14390234793387, 44.84614872163342, 45.250458794255415, 45.43060541152955, 42.68658191927018, 43.832145429426625, 44.545820682279526, 45.73829966206705, 42.78642585200649, 47.72715314742058, 51.72208716792446, 45.821889292809274, 42.566055328615256, 44.26149199085851, 42.66800165176392, 48.41245005207677, 49.24684801409322, 46.5546743331417, 46.02800984536448, 48.33606189297092, 46.32940869177542, 46.947197683395885, 44.60494649025702, 44.02612232392834, 45.143421234623084, 42.88763476956276, 42.504070112782145, 38.53038749387188, 41.94092758240239, 41.4976252278974, 41.280243550577474, 42.78968534161968, 40.37494874769642, 38.73683360315139, 40.66496487586729, 40.7475660693261, 40.440801420519435, 42.55268004632766, 40.36329930828464, 40.34893166634345, 40.85433298541654, 40.72259233843896, 40.08211243537165, 41.44473598849389, 47.07489828909598, 42.25255597022272, 41.153837327034246, 40.35277558911232, 41.8362356001331, 46.20397521603493, 50.2774586216096, 43.95774756708453, 43.78802268735824, 46.55254056376796, 39.95938147267988, 37.989590706363806, 40.59129884166103, 39.17555462929511, 39.37288515029415, 36.872217270635794, 43.19575263607887, 46.219833358641594, 39.54113129646548, 42.78677494295182, 40.94798741802093, 40.84428387303507, 39.231699435941636, 42.72695095308366, 41.04896491573703, 44.82501891351516, 43.59015087927542, 44.65446249131234, 44.59871384405321, 43.11171193276682, 42.56833422568537, 45.04945693477508, 43.57658732321955, 42.944297329072036, 46.43121380959788, 47.43801170779813, 50.274787487522254, 50.150346371435354, 51.001120228921216, 52.6503082244627, 53.95546905456051, 53.390765420852176, 54.33936711280577, 53.00320779123614, 53.54402811296525, 53.35841371167091, 53.40963986612136, 51.26711576215683, 48.57966069252261, 49.30706031860844, 51.14564780266055, 49.83459949493409, 54.32886300548431, 64.36225060493716, 68.29080243264475, 67.26871121314265, 68.69301011485439, 66.81581081882601, 17.77784078351913, 0.5059503283231489, 0.16207293306867923, 0.09989334540742059, 2.37295844862538, 68.44380624832647, 65.05925578455772, 62.58763305602535, 57.551356823213645, 51.12968375605922, 19.963069692734752, 42.60364732434673, 45.76488548709501, 71.0687348150438, 36.80583115546934, 0.179425866433209, 0.11434789236274459, 0.07610364937253537, 0.049769614462650595, 0.042937063957534494, 0.04175995837055868, 0.05355058778678218, 0.037856326708870555, 0.046717903216279326, 0.18414420195885245, 0.0356500854174937, 0.05414690679660248, 6.039331209275031, 46.327490652761156, 48.1387705956736, 54.06615834082327, 22.036616956034017, 31.979021256969823, 58.41710236764724, 69.42667376610541, 74.85263747553672, 40.26446342468262, 0.04723328503689939, 0.19040853355921086, 0.6611247468859919, 7.929545910127702, 83.18878804483722, 69.76857108454551, 71.53969380163377, 64.4293623585855, 66.3482250705842, 63.20695177201302, 65.52416647634199, 63.144688067897675, 61.55611638099917, 58.43592582210418, 56.05265055933307, 53.15724711264334, 49.6451097919095, 49.945837913020966, 47.900733717026256, 50.61552378439134, 50.352336668199115, 50.150150252926736, 48.82314966570947, 47.45477199554444, 49.664921683649865, 48.72872252618113, 50.91375335570305, 55.49585834626229, 59.58241893399147, 60.714964097545995, 58.675068809140114, 59.96301435655164, 61.205550624478256, 62.265579008287006, 60.13678712229575, 61.619348910547075, 58.73537525053948, 53.14897483394992, 47.27181696122693, 47.78566706565119, 47.260065540190666, 45.16127978601764, 46.440074443817146, 46.92164344172324, 45.5487903471916, 45.96564023725448, 49.591789091787035, 56.192263403246486, 45.40892647158715, 42.05906544962237, 44.93952466595558, 42.99627265622539, 48.34578544862809, 50.46658354420816, 47.26546664391795, 46.26634874651509, 48.32588726474393, 45.31323632886333, 48.76623215213899, 44.28876423066662, 42.100462144420995, 46.4208116839009, 44.35707230721751, 43.156779966046734, 41.25801547881096, 43.41451498769945, 44.44331346019622, 43.69838868418048, 46.514881887743556, 43.61333600936398, 42.05631586813158, 41.959904009296054, 42.63409668399442, 44.04407108983686, 44.151567566779356, 43.31833062633392, 41.8972441457933, 44.977034291913434, 43.07337468670261, 42.5176493583187, 43.31045058465774, 47.99216416574294, 44.317927052897794, 41.12735348363077, 39.7714920966856, 42.62145880729922, 45.346517639775435, 50.03253406093967, 44.97550456754623, 43.97397049011723, 45.15601204287621, 39.20875749280376, 38.30263114744617, 39.14700369681082, 39.32380453232796, 39.43960466692525, 37.584343187270626, 44.32010396834343, 48.16407380565521, 42.032746345766135, 44.70922270128804, 42.78704950886388, 41.59993240910192, 42.30611985729587, 43.7867400723119, 43.76289598403439, 45.532575268899244, 45.982557419807684, 46.83164858048963, 46.321136413082, 46.3997564008159, 45.307595960555545, 47.08261359122492, 46.13521214454405, 46.297272712953635, 48.74238806386148, 47.91849028679633, 53.00565535022367, 51.6001328345268, 53.74290404781219, 55.88468682381415, 56.080640592882716, 55.93472842247256, 56.93871790362943, 56.1651715924663, 55.838359709708925, 55.94981385815529, 56.12887397889168, 53.16607636790122, 52.80762664733395, 52.10352982244184, 54.7016764456226, 53.44640816411665, 59.32074585268575, 67.46825002854871, 70.07133883814659, 71.29278844402683, 72.83772376275832, 69.90456750316005, 18.90013091025814, 0.24540348819667296, 0.7251986861228944, 0.16403794859445867, 3.0038430085105285, 74.4214120987923, 72.9316645283853, 69.71836474633986, 64.09732980112877, 53.22856364711639, 22.31312836370161, 47.42568369834654, 49.33436001500776, 80.25174079402801, 44.26366498393398, 0.16782361803756607, 0.10469780453751165, 0.045852901849655375, 0.02660765087292079, 0.04965784989537732, 0.1611118757676694, 0.10075544713125115, 0.06701417702941165, 0.18187121908751228, 0.2673619583008751, 0.15142417302535427, 0.24087080641859965, 9.7419653015752, 70.0335350344258, 57.595750208823915, 72.47760311249765, 22.726526568012854, 30.508201083829327, 68.8071353973881, 76.6928723550612, 83.34405114573818, 46.94566011428834, 0.3408574306916806, 0.23063964090279995, 1.3383024065725266, 11.249866581732228, 89.53919949070101, 76.98783459201937, 74.83992115143808, 66.6396571743873, 69.90926650262648, 67.48108402375253, 68.83660024212253, 65.35882680646836, 65.58818347992437, 60.762985675565666, 59.240768724872225, 54.55223021968719, 53.34811748996858, 54.3074703985645, 49.983633872001406, 53.8361309420678, 52.80901516637495, 52.942787601101784, 51.30065987187048, 49.44018948462702, 53.073057359264745, 50.464320336618734, 53.22900295257569, 58.039903717656294, 62.940289435848115, 61.79678517003214, 60.16771108873429, 65.11706367615731, 63.946420531119074, 66.17226754465412, 60.74921031152049, 64.98979453117617, 62.489503199054354, 54.06447172164918, 49.79577195259833, 49.572910724147675, 50.489152862179665, 47.6901416624746, 49.7815651278342, 47.47752566491404, 49.42386065759967, 47.653745989645685, 52.511346493997884, 57.762854945275095, 45.82160688215687, 42.366383152623335, 44.71931495974141, 43.92838470397457, 47.58845029338714, 50.90004467195081, 47.52096591457244, 45.55949449539185, 49.188549826222086, 46.28976529644382, 49.153946676561915, 44.57754481223322, 43.88911785617952, 47.73146775461013, 47.36962910621397, 48.71746924615676, 43.24151885124945, 47.335798663477746, 47.31291163352228, 48.36891174316407, 49.49325915305845, 46.66321023817986, 44.45754381918138, 45.142636760588616, 45.65628682413409, 46.57051286389751, 48.75356681885258, 46.409609394688765, 44.59557987028553, 47.89477955910468, 45.850091134348226, 45.35650791660432, 46.4207410812378, 50.595245130600475, 44.30538331308673, 41.3611698919727, 40.58883167082264, 42.51120882649576, 46.197099301122854, 52.290238565014256, 46.18608920804916, 44.90509802295316, 46.83412359606835, 40.64788295376686, 38.556224146196925, 40.99923710669241, 39.68693364051081, 39.1183586274424, 37.55010874040666, 43.17319116284771, 50.33904767805531, 44.309862659823516, 48.76516526745212, 44.96967984784035, 45.590889146251065, 45.11898486844955, 47.01119507512739, 45.416477034168864, 48.011360245366255, 49.62581957540205, 49.24050946389475, 49.16570201996834, 47.67771559376871, 48.93062260843093, 50.319977114277506, 48.24267418153825, 50.44806603462466, 50.906865673680464, 51.49369931990101, 55.57147772081437, 55.18088809905514, 56.77849300446049, 60.01234600620886, 59.43374541498, 59.49823702535322, 60.923724405227176, 60.64577741007651, 60.27620777007073, 61.45135379606678, 58.717587301808024, 57.82433809772615, 55.64654011880198, 55.672572889635646, 58.62071260329216, 56.9052561636894, 61.5666401001715, 72.29730744515696, 75.99512976984825, 76.2343002134754, 76.71635950765302, 73.69508327976351, 21.105685541706702, 1.4253853982494724, 1.4341234584008495, 0.21551295904622925, 3.386676633550275, 81.7589193774808, 76.43192491223736, 78.46478739092427, 71.78804259146415, 70.35465163569297, 32.1869029537324, 58.27228846088533, 60.237219410557906, 93.34382011044411, 53.50593013148154, 0.1892927724627718, 0.2000904293550599, 0.14552027047161134, 0.16236275945219303, 0.12535385622252382], [0.0390637195819328, 0.03094472550606776, 0.11440904150086065, 0.044999384141016396, 0.022709789768522306, 0.14539198138781134, 0.2223665654779442, 4.447507877503672, 33.41672289756037, 46.081891444421586, 48.97383928298951, 32.95071001975767, 25.293568795727147, 49.660909098963586, 66.47523926150414, 68.83287399045884, 40.272645488862075, 0.06806513474833581, 0.1150851907028306, 0.3226172449367662, 2.585224129499928, 64.54988894924041, 74.4037300540555, 68.55044764857139, 62.40033203555692, 61.50967944052912, 60.21070418819305, 59.06838447816911, 62.170469376348684, 59.22744051102669, 55.37765379874937, 50.865555271025634, 49.64780446021788, 49.82568394753241, 48.53567131104008, 49.805424905592396, 49.25939175390428, 51.50387787049817, 53.90077552487774, 52.06363147304904, 54.31871583384853, 54.32415616127753, 53.734474874311886, 56.69349916519658, 58.15529200338549, 61.11606959373721, 69.36459833575834, 70.3600880407518, 58.15219725331953, 56.22827076142835, 53.520309540533255, 56.89143373120216, 56.73895943549372, 57.66152835661366, 56.709569115792554, 49.160755911181056, 47.57149388713222, 44.74570074389058, 42.182596575829294, 43.493319326831454, 41.64235676488569, 43.845336360316125, 43.12039998269851, 43.966478763088105, 48.571878710100734, 56.56996411661948, 43.710018511741396, 44.55743482035976, 46.03274806853264, 45.09072811372819, 52.21115965997019, 44.46722030639649, 44.5735949854697, 46.155918336683705, 44.98815813372212, 49.78360868269398, 45.795126961123565, 41.93645215803578, 39.73983072465466, 45.76336360746815, 42.39080382931618, 41.61734773266701, 41.41569475973807, 42.07055014948691, 42.870191989406464, 41.6137352297383, 42.60872679371988, 40.032894534449426, 39.92546081542969, 41.612201583000925, 43.6269623233426, 41.91705603753367, 40.68334902486494, 41.19638719866353, 40.95571840963056, 40.0394017465653, 43.243013274285104, 48.72522377198743, 42.91178872508388, 39.239453961772305, 41.69965867073306, 41.16458069893622, 39.32065094670942, 50.54238334778817, 48.32069012426561, 44.33668774943198, 42.41514998097574, 39.600437533470895, 38.921381119758856, 38.87942744839577, 36.692368753494755, 40.90243301083965, 38.714844795965384, 40.689613050030125, 51.845532001987586, 44.156258721505445, 41.53674302562591, 39.37533270928168, 38.6467916734757, 38.11991537770918, 42.16281214068013, 43.07453178590344, 41.960684560960345, 44.702370320597005, 43.20663721330705, 42.998057334653794, 42.74554691007061, 43.4431286781065, 43.659545452364036, 41.55441330325219, 44.124491445479855, 42.13061340393559, 42.66152581860943, 44.72921502205634, 43.8107410553963, 45.012170883917044, 47.08172713556598, 47.3845027339074, 44.88372895025438, 46.101985746814364, 46.949711922676336, 52.07277451792071, 49.280847118746856, 48.65571937253399, 46.50537406244586, 47.94288742926813, 51.37229019595731, 51.03746098856772, 51.23888646402667, 53.39333457331504, 58.68254876905873, 64.13849507608722, 68.92874456221058, 66.3648166964131, 68.86576698672387, 66.32065080827283, 20.14424200980894, 0.03743051205791774, 0.4648547367222848, 0.055617653884954994, 0.751877606155411, 61.51823805224512, 66.7227251298966, 64.42401616804062, 60.15644211922923, 52.56056831729028, 27.417767586246615, 33.03505274557298, 45.14790058135987, 67.81326170890563, 49.10711357670446, 0.08730138036152048, 0.06556142151596085, 0.03657928878261197, 0.030519140681492227, 0.02161973283716267, 0.011519950442767192, 0.05555519090604879, 0.028940164521636984, 0.012009589793911625, 0.03066361145747285, 0.13539284858251774, 0.13981873770394634, 6.986727752993184, 50.40781467191635, 56.6153851632149, 56.11564382430046, 35.82467379108552, 30.17339933303095, 54.9649106302569, 71.81653468839585, 76.65376632444321, 45.63964420749296, 0.0980614529802434, 0.09215386554358468, 1.2716430738087625, 2.5387285986254295, 72.87071874064785, 78.01136139900454, 71.56572265009727, 63.8701068970465, 62.92843995555755, 65.48189901536512, 62.9317347465023, 64.04291083735805, 59.71046078589655, 57.007779075253396, 52.371353180177756, 50.72327913776521, 51.66931559962612, 51.3933886251142, 53.15485446683822, 53.233792166556086, 54.15134045385546, 54.56724505270682, 53.54486357781195, 56.13778952629336, 56.613686776930294, 56.40781333369594, 59.8707405982479, 60.826528072357185, 62.84729788380285, 68.89613397659795, 65.83339829598704, 58.45913840878395, 56.272083636253114, 57.53136058007517, 57.201104856306515, 58.95593404769898, 60.373568842487956, 57.62007282626245, 51.05406438150714, 49.28427919264763, 46.34832236074632, 45.40052475467805, 45.78446988136538, 45.52300468567879, 45.19358442675683, 46.78179917796966, 44.832141937748084, 50.7724303583945, 56.81093492815572, 45.33324433911232, 44.421665899215206, 46.905036126413655, 46.195424449059274, 54.717754240958925, 47.34498877679148, 46.68090405002717, 47.193953990936286, 45.65310185955417, 50.59951659171812, 47.09621244861234, 41.013585136782744, 40.87376048488002, 48.00784187932169, 45.85143258494716, 44.99553218964608, 43.728508564733694, 44.49225287283621, 45.86092079839399, 43.44047715587001, 43.2702737469827, 43.911616571487926, 42.7770435425543, 43.39736246293591, 46.13784405492967, 44.668849745104396, 42.87700906876595, 43.189312104255926, 42.069032192230225, 42.41802507831205, 46.841368213776626, 48.902856149981105, 44.39294630481351, 39.79171975966423, 42.5220698695029, 41.88172332702145, 40.27089218939505, 51.584674773677705, 49.09865694661295, 44.364724851423695, 43.07372377764794, 41.34606876680928, 39.04559866074593, 39.27247639625303, 37.47255563735962, 40.438855924913966, 38.14093143709245, 39.57926065691056, 55.90782488546064, 48.18642739326724, 43.60295349551786, 40.63993230942757, 43.19092812076692, 41.066823467131584, 43.445984163591945, 44.31720141441592, 43.997606692775605, 45.638224309490575, 44.788729144680886, 44.715471036972545, 47.04691610028667, 46.039282737239716, 45.30156335523052, 44.36337163371425, 46.185744039474, 45.03075507379348, 46.68308881021316, 46.79529213136243, 46.626383104631984, 49.027050156747144, 48.54781889146375, 49.690664199090776, 48.08492822031821, 49.88033040877312, 48.833649850660755, 53.74856402797084, 52.17884325212049, 49.32975515242546, 49.89035990930373, 50.44565377696868, 53.869847636069025, 53.492605840006185, 53.06263169934673, 55.24695257986746, 62.484192309841035, 67.60150078804263, 72.05455979993268, 71.20700620835828, 72.74613641923474, 69.71476401052168, 20.603102445602417, 0.13418693425914935, 0.4524350725114346, 0.05897352885034296, 0.799694914490946, 66.3684723454137, 74.62546948463687, 71.13255962248772, 68.529815981465, 53.263672782528786, 25.729724591778172, 34.61346941609537, 51.63688936541158, 78.084576360641, 59.737101524106926, 0.10376841731129155, 0.10079411158878958, 0.06180697015576786, 0.007769391288034499, 0.026566443003473744, 0.14197627112509745, 0.10876691119084436, 0.17875757729334218, 0.12025195579495161, 0.10603255952798551, 0.20317252364850816, 0.4311788292421449, 12.061800149179275, 68.46922320704307, 69.25358741514145, 71.56052943198912, 44.9755947820602, 37.92843703300723, 66.49778504525462, 77.81754139930972, 85.34356563322007, 50.539567086004446, 0.14850156291598274, 0.21299142660873555, 1.5028730467442544, 4.23464379002971, 81.14025961968207, 82.29482496938398, 75.33035078356343, 68.56269328824936, 67.86104402234479, 67.14121064832135, 64.84507083892822, 67.1214811263546, 64.16886598833146, 62.780288111779, 57.177570635272616, 54.08935131565217, 55.9207098714767, 54.36331710507793, 56.4933249258226, 54.50447144046907, 56.50319360917615, 57.7657025860202, 56.660166863472234, 59.272022170405236, 59.421103615914625, 58.62785523937595, 60.85274911695912, 62.953033216537975, 65.39736409341135, 71.91876734456709, 66.13854300591254, 56.048712499680065, 57.71567667684248, 59.40961499367992, 60.56437253952027, 61.68824926499398, 62.71375294654601, 61.188013707437825, 54.14263279207292, 51.86630487442017, 48.50223702769126, 47.3449730873108, 47.7675025693832, 47.41970208383376, 49.347221466802786, 46.959019707095244, 48.99011319683444, 55.30372104337139, 59.48883902642035, 46.56452340464438, 46.30558421534877, 46.953744119213475, 45.204410168432425, 55.56515093772642, 46.922220030138575, 47.57921703400151, 48.20280721110683, 45.69762076100996, 51.82597898667859, 48.94888124158306, 42.69637607759045, 40.01340427706319, 50.69252383324408, 47.59500849631525, 47.38504794336135, 47.95399558159613, 47.23105569039622, 48.1510397695726, 47.2832114465775, 46.360120850224654, 46.08097753217144, 46.06286010434551, 47.668580393637384, 49.927104673077984, 46.21195723933559, 46.948947060492735, 47.10860321598668, 43.87955904006959, 43.71086182132844, 50.294238521206765, 53.00137604436567, 44.34792533997567, 40.28259261961907, 44.97508095156762, 42.52326227003529, 40.778909729373076, 51.85957408720448, 50.07172246133128, 44.30042543718892, 45.42520038543209, 40.120124124711566, 39.44260920247724, 38.73207184576219, 35.581533908843994, 40.373218982450425, 38.85155508595128, 40.91989148047663, 57.68443499841998, 51.563062514028246, 47.128301358992054, 45.216267493463334, 44.621110577737134, 43.98682801954208, 46.42883685327346, 47.77615924035349, 46.67178453937654, 51.70657811626312, 47.67567203890893, 45.53553665837934, 49.268475963223366, 49.54083358087848, 47.77933636019307, 47.38097260075231, 49.02030368005076, 46.611262367617705, 48.46248772836501, 51.45738993921588, 48.64044174071282, 52.19114380498087, 51.82850107069939, 53.10351064128261, 50.07986137943883, 53.209442092526345, 52.05286848929621, 58.84331495531144, 56.21520142401419, 53.1750899745572, 52.61472055988928, 54.80080650698755, 57.29566927879088, 56.99736126007573, 55.76812967177361, 58.70192527770997, 64.92735824277325, 71.33193369834655, 75.64672916166245, 74.69654283215924, 75.24459208211591, 74.7826623916626, 22.726587364750525, 0.4237281338822457, 1.8161511589442532, 0.12579628732055426, 1.2376891989861767, 74.55809885455717, 78.76412699299475, 79.78600640450755, 76.86988892093783, 69.87770711222004, 43.648476523737756, 46.024683675458355, 60.70832744721444, 90.83307958418324, 69.44545407449046, 0.34553660380263485, 0.140518635631569, 0.16001430159855276, 0.18117156630802542, 0.053494950651281306], [0.05379448719923535, 0.06121793664210747, 0.057282669379586176, 0.08998415132443752, 0.06978038262816207, 0.08429692907919807, 0.11097873726318921, 5.597180560711892, 33.69246944304436, 42.028737683450025, 42.89401646583311, 26.627896370426303, 41.66342773745137, 55.530912568492276, 64.23330660789244, 68.86321744611188, 41.073879811071585, 0.05823959746668416, 0.07496605477025432, 0.23000872153187954, 0.4641437458415186, 51.16527926537299, 75.41833739126884, 66.2252587656821, 67.52337501895043, 56.166465974623165, 59.445865538812455, 57.21326028147052, 60.50231279865388, 52.56476917574483, 51.03177355181787, 48.413760123714326, 48.34641695022584, 49.66814587193151, 54.49848982595629, 53.89924187814036, 59.0426694193194, 63.42026202909408, 64.27983768524663, 65.90910788505309, 62.136305532147816, 59.62144259483584, 57.472238694467855, 59.597959364614184, 60.24453463092927, 63.924831805690644, 51.47713907303349, 46.12284098902057, 56.53976186629265, 54.526013097455426, 59.20877787374682, 57.22539609478366, 62.3326240816424, 60.671566993959495, 58.95560064623433, 53.748991566319624, 49.393289704476636, 44.793706632429554, 43.7957654460784, 43.209512310643355, 41.4301133924915, 40.284145878207305, 42.987784647172504, 43.46283466585221, 45.39091494775588, 53.12928061331473, 50.3289044287897, 42.58945226669312, 41.04528965488557, 47.00846902785763, 54.86230142654912, 48.086454022315245, 46.29247565423289, 51.94618786534956, 46.022236116470836, 49.15723362276631, 55.30350139064174, 41.633554966219016, 43.7925059564652, 42.06634536866219, 47.847291423428445, 44.81412649154664, 41.305393788122366, 38.37812108378257, 43.00978914383919, 40.93203513853012, 40.4174280166626, 38.457176454605595, 40.250523321090206, 41.47174150713029, 43.03412352838824, 42.431686693622225, 41.81402714021745, 42.30223671082528, 43.649617933457904, 43.83276124154368, 45.930601704505186, 40.14497233975319, 39.597636961167865, 39.63029069285239, 39.73993662864932, 40.262502239596465, 48.87312850644512, 50.72981380647229, 44.37262842732091, 40.045034270132746, 42.07714757611675, 40.322816525736165, 40.253425875017726, 38.45319917125087, 39.438329896619244, 35.781060957139545, 42.02127733538228, 52.60345159038421, 50.35382716886459, 42.674508863879794, 37.874500520767704, 40.25855241283294, 38.51449012756348, 40.73686192112584, 39.523296279291955, 42.306143391516905, 42.926007316958525, 44.976689123338275, 43.79946424115089, 43.62341650070683, 42.034778133515395, 41.273806941124704, 43.67713728258687, 43.56430638221003, 43.53710866743519, 41.88790890478319, 43.385724790634654, 44.11214382417741, 43.12239254674604, 44.376166405216345, 45.47871720406317, 45.87536296536846, 44.73735001779372, 45.74452054116034, 46.069202576914144, 45.47608921604772, 46.44144335100728, 46.02409531993251, 48.245494365692146, 48.00116992765858, 49.28498914164882, 49.257050098911414, 50.34792792412543, 53.438053515649614, 62.5262636523093, 67.54370074118337, 63.30534442778557, 69.95418548583984, 66.94897528617614, 67.41544708128899, 23.959988432545817, 0.06938645255661781, 1.0185738340500863, 0.20479886702472166, 0.09870266091198691, 49.78211425965833, 72.4917079556373, 66.24145815449377, 55.346231691298954, 59.74763701038977, 30.415093821863977, 27.897528371503277, 51.0983597078631, 67.44785370365267, 62.94617691347676, 0.484632644802332, 0.021557051523198045, 0.07642499261325406, 0.06992228509437654, 0.1044391809151538, 0.05345353976853433, 0.023022259795858015, 0.0374298608831821, 0.10383903529615172, 0.05317333161890988, 0.0417153260880901, 0.16406811713691682, 7.861699692664608, 50.116861097274295, 51.896397298382176, 56.71584883043843, 36.14282508050242, 42.76385653403498, 62.287167733715435, 70.02298385866227, 78.7946508776757, 44.48230181970904, 0.06746192477763661, 0.015961075137789934, 0.5298383594039948, 0.8675168622885981, 59.941343261349594, 77.44473580391177, 68.10451338368078, 69.88464970742503, 59.923688673204, 61.58338469843711, 59.64041509935933, 63.49609321163547, 56.62035088385306, 53.56120024957965, 51.10195259894095, 50.898114865826024, 52.46005758162468, 55.68352022478658, 57.21209925989951, 61.86192789385396, 63.26593245229414, 68.19792855170466, 68.74093363361975, 63.8879301471095, 60.21468147154778, 60.55407631781794, 61.25241902566726, 63.569174812686065, 65.04006362730458, 54.03641108543643, 45.77646824621385, 55.96339310369184, 54.025734393827385, 58.487140209444114, 59.65048774596184, 62.93881462466333, 60.05086760367117, 59.630048274993904, 54.675910395960656, 50.950525576068515, 47.246341166957734, 45.71364756553404, 44.503729727960405, 44.169861501263036, 45.00131768565024, 45.266313014491914, 45.77390301612116, 46.693914551888746, 55.281512583455736, 49.117703976169715, 41.558288604982444, 41.92810143193891, 47.04729657019339, 56.12790123108895, 49.56309695397654, 47.145430349534564, 51.79207794127926, 47.05570220947266, 48.402475464728575, 56.06826551498906, 42.41771913343861, 42.566577003848174, 44.73535745374618, 49.78104737497146, 46.17760904373662, 43.84958428721274, 41.75248907458398, 44.503835631955056, 44.50739714407152, 44.43075010853429, 40.63417819238479, 43.61866258805798, 43.318871913417695, 46.50932781157955, 45.7455325126648, 44.42404677790981, 45.28950991169099, 45.22861119239561, 46.61403156095936, 48.592326025809015, 38.70936916720483, 41.06352475381667, 40.227808875422326, 39.77853275114491, 40.86183647955618, 49.409073322050034, 50.65026813937772, 43.17144570812103, 39.874097378023215, 41.66408277327015, 42.46241454155215, 41.02581116460985, 38.59379653007754, 40.78006682857391, 37.478035188490345, 42.54658468307988, 56.39925864435012, 54.026840502215975, 44.41458209868401, 41.18336885206161, 43.68949667099984, 43.348874122865745, 41.97531500170308, 42.26739821895477, 44.53040576750233, 45.77791167843727, 46.957803772341826, 46.48560923914756, 44.890487194061286, 45.07201448563607, 44.497901085884344, 46.870166255581765, 47.115514432230306, 45.629446045044936, 45.03475589136924, 46.50051032343219, 46.686803294766335, 45.751804382570334, 47.22114778334095, 47.79030722956504, 47.01511352292953, 49.07154160161173, 48.13173386358446, 48.030972096227835, 47.723807365663596, 48.44416241491995, 49.48411218581661, 51.33797337931972, 51.48858847156648, 52.14828406610797, 50.97040022573164, 52.560066253908225, 55.8401483105075, 67.36657434894194, 70.61457141753166, 66.49592584179294, 75.31008781925325, 69.58442364969562, 72.46449455138176, 25.957286780880345, 0.18421745528617214, 0.7655595074738226, 0.025446569930101116, 0.0851930144633497, 54.54539352847684, 78.67635219327866, 72.23054870482414, 65.38969193735431, 58.53203565843644, 29.39330658605022, 42.884685147193174, 56.35979175567628, 76.56438335295647, 71.13738413779967, 0.5461454908213308, 0.05297935432604244, 0.11878881212924758, 0.041017684289404464, 0.018019667345910304, 0.34715571530884315, 0.12869921663115103, 0.15771084374958472, 0.21839404719010477, 0.15634899989010828, 0.22448698960004315, 0.3408756635842785, 13.427623375769585, 70.53876769158148, 62.196482535331484, 62.402250074571185, 38.9814208399865, 63.02685222318096, 72.73399276118126, 76.64945171725365, 84.47882421555059, 51.70268320268201, 0.15659488347028533, 0.2445951122189722, 0.6152298289441294, 1.61968735917922, 70.1991767268027, 82.80726694291639, 72.22138604810162, 72.94010546899611, 62.08003128728559, 64.55322688625705, 62.738703143212106, 67.72678913608675, 59.38231137491042, 57.55152156276088, 54.163833202854285, 54.336091933711884, 55.04430332491475, 58.35795302544871, 58.51146282688264, 66.69679826305759, 67.89392917386948, 72.1818014883226, 72.49532438093617, 65.54584541628438, 63.28080607998756, 62.202934834264944, 65.43521104320403, 67.0393310054656, 66.59298096933674, 56.9090530180162, 52.89376974105836, 58.35019457724787, 54.10551932550246, 59.77652918907904, 62.96586328937162, 65.94871597905313, 63.5876452538275, 63.21406695150561, 59.11644135752032, 54.20074662854595, 51.47886491590931, 47.627120940916, 47.000738036247995, 46.150831022570216, 46.11908728076566, 47.640158899368785, 46.953720584992446, 49.150581282954064, 56.89335177021643, 51.10701245646323, 42.18684842509609, 42.77943226598924, 47.91596820277553, 57.87788629531861, 51.08137976738715, 47.80652623022757, 55.813629165772475, 47.50961457529376, 51.065235291757894, 56.86061566875827, 43.432612803674516, 45.122969996544626, 45.29158876788232, 53.55235530484108, 48.65878274363857, 46.56050297521776, 44.616795970547585, 48.11557369847452, 45.914610201312655, 47.41506976466025, 43.899155201450476, 46.33870078671364, 47.45912190406553, 49.988270113545084, 48.13096115666051, 47.145857887883345, 48.04294316999374, 48.99900913238526, 50.82195420419016, 49.11968085073656, 38.70672941207886, 39.787864069784845, 40.87007345691804, 40.07242418104603, 40.7136179554847, 52.204201375284505, 53.0099150442308, 43.94195218240061, 38.5292931525938, 42.179172346668864, 42.86324939420147, 42.13222549807641, 39.5195072697055, 40.038495679055494, 37.74095950588104, 43.878264657912716, 59.60727499377344, 59.96633268171742, 45.95076268719089, 43.28602598559472, 44.1543955956736, 44.3129966335912, 45.917803010632916, 43.70337793903966, 47.39036667731501, 47.43860006332398, 49.20539248374201, 47.32984842792634, 48.29273539204752, 48.1402297173777, 46.04993197225755, 48.94955981162287, 49.294343994509795, 47.49679626957063, 46.40247460334532, 49.094758110661665, 50.28585249377836, 47.39952933403754, 49.851563745929354, 51.71572508350496, 52.41270672890448, 50.93053325530022, 51.23232826109856, 49.79459131917646, 51.76128733542658, 51.4437283239057, 52.89814710617066, 54.68989756799514, 53.983733654022224, 55.628897297766905, 55.10249560879123, 55.60943841934205, 59.817972952319735, 69.6401213061425, 74.74605883321455, 69.91667193751182, 79.23208928877308, 71.40019862882554, 76.29934095567273, 28.063056315145186, 0.8136972244228087, 2.617596431124595, 0.42663461017993193, 0.20185011799537367, 59.13156601690478, 84.02381358608123, 81.91235465388145, 72.07304200818463, 80.66894761977657, 45.68989761414067, 41.96084930050758, 70.32725780240952, 85.10081014325543, 85.69814789679744, 0.9893592855622693, 0.16575107441073464, 0.4191736492418474, 0.3092928002438238, 0.20616072620595657], [0.05047244267658361, 0.06294362246990204, 0.0818252153394203, 0.10665654580319121, 0.05434605901339843, 0.0865356141941682, 0.03181008884923593, 8.228115747051856, 40.78777820833268, 40.88910479699412, 39.36365189090852, 28.76395836953194, 29.45025351739699, 53.867725633805804, 65.84726779691636, 70.99634355114353, 42.99642562866212, 0.060483660518882744, 0.1629791537960691, 0.8439291989611042, 0.11371527227663225, 35.24139381224109, 80.75937394172915, 62.91167966781124, 67.95368256107454, 56.28738872466549, 62.03956419421781, 55.93943134430916, 54.19363144905337, 46.59245068027128, 48.30409065369637, 49.28884875389838, 51.155332134615996, 52.6786865726594, 55.8382498833441, 58.41571777097641, 58.286393304024976, 57.70470972984069, 57.91646672833351, 54.684806331511474, 64.35356255500548, 61.78130749733218, 61.29400791660432, 60.042712996082926, 59.45338472243279, 59.72738189081992, 62.249003071938795, 53.31888014270414, 51.68027470188757, 52.28018945263278, 52.20124390817458, 52.392337860599646, 53.099956973906494, 54.84105394732568, 58.66045405787807, 57.166038866966005, 51.76071074701125, 44.44979321572089, 45.61709450137231, 41.82602567057456, 43.7987974382216, 43.55535161110663, 43.034386327189786, 43.41968074921639, 43.506318061582505, 46.02454639250233, 58.65999906293808, 54.82988303707492, 39.94362138932751, 44.047416871593846, 46.710996473989184, 48.90404070577314, 49.31553656055082, 54.43178599880588, 53.606793880462654, 51.299298809420684, 58.661501330714074, 46.16169598794753, 42.37914262279388, 42.90247309592463, 48.70068150181925, 48.89015943773332, 45.029268495498165, 45.25965282993932, 44.04952710674655, 40.084971843227265, 42.23776471230292, 41.14026592623803, 42.241942036536436, 41.64036027846798, 42.827618583556145, 41.02502276820522, 42.07413911819458, 42.91635436396445, 45.626716075405, 45.72396339908723, 43.21906328201295, 40.873368247862786, 40.53791930598598, 43.26958733220255, 41.60474123493318, 47.3260005827873, 51.01639786074239, 43.61237895104193, 41.53003577263125, 42.569856105312226, 53.40252860899895, 46.6807157762589, 41.83603555925431, 42.92926680657172, 39.85069651757517, 38.245376310040875, 48.64498384537236, 45.949358478669204, 46.4066715394297, 43.537814694066206, 42.33503557020619, 39.03384723970967, 40.893905778085035, 40.754132116994555, 41.77218721758935, 41.135727743948664, 41.92268071636077, 43.756031836232836, 43.00002244211013, 43.06268622798305, 44.12185561272406, 47.39859580993653, 50.28495427100889, 48.112196537756155, 47.30502374710576, 45.26193564937961, 45.713702478716456, 45.040568843964614, 44.68563748944191, 44.59371674445368, 44.55020981450235, 45.71553422558693, 43.536194755185036, 44.91968923999418, 44.71136431540213, 47.16800358987624, 46.11745949714415, 46.23497370750674, 46.883553304979884, 46.813931234421275, 48.53632634685886, 52.08244316039547, 49.70891106513239, 54.94114498938284, 61.75372539028045, 67.14649015857329, 66.1898240735454, 71.53155096115606, 65.69724890493578, 70.12309843494047, 25.0969325342486, 0.3220210140270572, 0.14867071512966387, 0.19429526532128935, 0.07422980597062458, 40.435486608935946, 73.50638589551373, 67.3142420861029, 58.67963052565052, 54.852393519493845, 46.31954785316221, 17.428418397903442, 44.796467981030865, 64.15614574186264, 60.02646653882919, 1.4021172855169544, 0.21773663649876274, 0.08228456165881888, 0.08001667327217518, 0.053993317659103104, 0.03280688415191347, 0.10880363744593437, 0.0860475702211261, 0.06606520093496769, 0.07586465292279759, 0.15326667577028275, 0.24993169602126847, 13.05022664608494, 56.47657640518681, 50.76524849860899, 49.754096769517474, 31.676302532995905, 31.982696517821285, 62.40394061611545, 70.64066302391791, 78.79505095943328, 46.87326100564773, 0.07504480860887036, 0.11764813019263169, 1.0892593572216651, 0.12672064900999108, 42.340264089645885, 86.51389891101469, 65.93479940968176, 71.82372047055152, 58.35198710041662, 62.8748486118932, 56.72700012883833, 57.76829919507427, 48.73729290500764, 52.43029855912732, 51.60647922946561, 54.851463917763006, 55.13973851357737, 59.263447869208555, 59.76964542942663, 63.39412335426577, 59.99062392019457, 60.80110326890023, 60.23267730589836, 66.19179310337191, 64.52959460596885, 64.16144486396544, 62.481015190001465, 62.00897755161409, 59.26680934044623, 63.74530884527392, 54.0169757412326, 55.369710999150435, 55.072305125574914, 58.15631574200046, 55.55296021123087, 57.27282147253714, 58.48666168028309, 61.43451113854686, 59.06837663342876, 54.48165893554688, 46.48797835073164, 46.34856554769701, 45.569598520955736, 45.57178328114171, 45.34039481993645, 46.43514402451054, 44.72405318290957, 46.18539494852866, 47.476454857857, 59.820004740068995, 56.340525073389855, 42.046996316602154, 44.47799505725984, 48.173240384747906, 48.222513198852546, 51.19635620424825, 53.26346489690965, 54.9484758992349, 51.89100403939524, 59.18490240650793, 46.15613406704318, 42.11540637477752, 45.05476782398839, 50.07128315587198, 50.30898663305467, 46.905216555441584, 47.45769416132281, 47.265968707300004, 42.24591539752099, 44.821441711918006, 42.47111043622417, 45.70026051613593, 44.11620739967593, 46.091697369852376, 42.42959999269055, 45.3214301601533, 44.06299652591829, 47.1142122053331, 45.25116089851626, 44.35704092825613, 39.006527931459495, 42.15963894321073, 44.01399827772572, 42.34501407992455, 45.43155462511125, 52.32845421760313, 44.711532977319536, 43.955927587324574, 45.42791858796151, 55.41769335346838, 46.22237113214309, 41.752665581241736, 41.95714658306491, 39.55476937755462, 37.98243238079933, 50.533381508242705, 49.674103952223255, 48.773978833229314, 45.33208723991148, 42.434824589760076, 40.29610126249252, 43.25376056855725, 41.95637779851114, 43.45494285706551, 43.23749842182283, 43.763845197616085, 46.95316753079815, 45.7045005982922, 46.07191685707339, 46.23858621043544, 50.072291205006266, 53.24934436428932, 52.785449566379675, 51.671261095231586, 46.58878718653033, 48.878129528414824, 48.641692976797785, 46.53598031690044, 46.68198270182456, 47.51240730285645, 48.791629499004735, 45.416904572517645, 46.620123001836966, 47.55345098433956, 49.871658048322125, 47.298897004896595, 48.66717269343715, 50.410697613993, 50.26618180736419, 51.42483426678566, 54.64999921860234, 51.08061490520355, 58.8344935447939, 64.23061586195423, 70.28553947325676, 68.48819178919639, 75.77421403700306, 70.57606943192022, 76.19567271201842, 26.336556442322273, 0.3928987639805963, 1.0066042924600265, 0.18982687364182166, 0.028033700561331167, 43.763417659267304, 80.07701489233202, 74.20037869484194, 64.64544573137837, 62.16466819086383, 36.32361104411464, 18.934233957721343, 57.54308454452023, 71.6645428442186, 76.2208543285247, 1.8159758780271777, 0.1967323289042519, 0.08293484007158587, 0.028419665233682723, 0.013118654324282563, 0.14352917731288942, 0.1868169907961161, 0.31066354604498037, 0.21444250438963214, 0.14544588333416372, 0.33134139293143827, 0.3279467347648836, 19.678797875681234, 76.54144533218877, 60.44026874726819, 59.122642624762754, 42.14275706198908, 44.215141342532256, 70.0354491510699, 76.43671804858793, 88.10045057727446, 53.568001639458444, 0.1755840733887688, 0.4630654924098523, 2.245281377146321, 0.22285701496706856, 51.12482393941572, 94.36473461889452, 68.95855457552018, 75.63229483942833, 60.13671651963265, 68.9445830929664, 61.92576839077858, 59.547274497247514, 53.181683478816865, 54.36540772837978, 57.16307355511574, 56.42580524567635, 58.348523647554465, 62.87140869325208, 63.12435057855422, 65.8347083676246, 63.624692040105025, 65.40982154107863, 63.697765796415275, 70.8973664622153, 67.49904847914173, 67.26330618704519, 66.74210163854784, 64.04057310473534, 61.775074851128366, 64.69333787118235, 56.347655942363126, 58.70978178516511, 58.81099462509156, 59.07121642943352, 55.867526454310266, 55.30492128864412, 59.600379467010505, 65.47526236503356, 59.44459076850646, 57.017157462335405, 49.17646500372118, 49.9620137676116, 47.99270545282672, 49.6422190050925, 48.13158873588809, 47.98435864910003, 48.890430081275206, 49.251896104504986, 49.91885200623543, 61.725853027835974, 57.00983831959387, 39.33020191807901, 44.974249409091094, 48.23621011549427, 50.93619715782904, 51.87720514112904, 56.0211068584073, 55.751322315585234, 54.00871130727953, 60.353352946619836, 46.82984821258053, 43.72635126113892, 44.926306278474875, 53.00057195848035, 54.17212117102839, 50.85434905944332, 50.57658641569076, 49.34042007692399, 45.22991341929282, 47.25479779704925, 46.182837563176314, 48.05077614322786, 46.74826291299636, 49.61118913465931, 45.0319984651381, 47.795053297473544, 47.79907372690017, 50.79498398688532, 48.00265650595389, 43.84805064047537, 40.99772699417607, 43.25024220251268, 43.53249988248272, 41.7203099496903, 46.962161525603264, 56.26125397220735, 43.961736617549775, 43.23335247655069, 46.91581479964718, 55.91727779757593, 47.946095928069084, 42.92788613227106, 42.99408789603941, 40.14025765080606, 37.98902588505899, 52.898962959166504, 52.405140476842085, 50.70439684775568, 48.70491766160535, 46.63848361661358, 43.34644617572908, 46.552732759906405, 45.60829270270563, 45.177098704922585, 46.282975673675544, 46.46798210759317, 49.72144303783294, 46.69632680954472, 49.00559871427475, 48.50406485219156, 53.36072006533223, 55.55511359245547, 54.905843657831994, 53.57237900457075, 50.828061334548465, 50.91081942281416, 51.44863520899127, 48.74748714508549, 50.18094478114959, 49.985363637247396, 52.322225493769494, 48.33230033997567, 50.145568924565474, 50.81460760485742, 54.55336378466699, 50.91637349897816, 51.17007240172356, 54.349890831978094, 52.06878546745547, 54.561114388127486, 57.177194087736076, 55.06668044674782, 62.15248530910861, 69.8269045737482, 74.07553749699747, 72.43212715271981, 78.29086949748378, 74.1111369286814, 79.07367260225358, 28.695985655630793, 0.7097215037192068, 1.9365484339575616, 0.34925038355492777, 0.14815818698656175, 48.22501959339265, 88.24861418816351, 84.44689612234794, 74.42129442768713, 70.81574978366976, 62.93610426687426, 25.556983409389375, 66.41498381091704, 80.08293767129221, 89.08108234405519, 2.5018639574127817, 0.25742429639062575, 0.29608749754486546, 0.09131810958347014, 0.2314177870510086], [0.04942033582577302, 0.11022513657207451, 0.05519015001012914, 0.13655511121596062, 0.06909448112691603, 0.07649246963762468, 0.2821798454369268, 3.824904911941098, 40.745291094626154, 45.13356039600988, 42.10124661845546, 36.49830164447908, 37.580259999921246, 55.34807520527994, 66.05980534707346, 69.79562759399414, 45.51255549153974, 0.06826956531093006, 0.058308825001961766, 0.3351804433811096, 0.08036349659725543, 16.036830102243734, 79.42088865464734, 60.87385931322652, 71.71396470838978, 54.05233198596586, 58.116778250663515, 49.9216761127595, 52.247700460495494, 48.796324576101, 49.60581548752324, 46.782077666251894, 52.810819456654215, 52.35783277019378, 61.05288805500154, 57.91501937373992, 63.60764934170631, 59.61347626101587, 60.632613935778224, 52.050699418590916, 49.667259416272564, 54.6709172187313, 57.547559968886844, 55.45115901577858, 58.34199682358773, 58.408606513854004, 59.64380402718822, 60.190798159568544, 60.61897193231891, 58.15209919406522, 57.40918659394788, 53.890491070285925, 38.167536873971265, 41.077445245558216, 58.45576909280593, 54.219370042124105, 50.90696373293477, 41.743844170724195, 42.05921449968892, 42.59173900850358, 45.502459310716205, 42.13558696931408, 44.600463221150065, 41.04998473198184, 45.37023621220743, 42.611896068819114, 46.867506888604936, 57.75339418841947, 54.74870566398867, 43.07874048909834, 48.48571992689564, 50.57955957228138, 53.410361582233065, 55.236781874010646, 56.927374409091094, 55.717789972982104, 59.61033444250784, 48.51394530265562, 43.674077833852465, 42.528153465640166, 45.690352609080655, 43.959740131132065, 48.57259650384226, 45.72123735181747, 47.71302869243007, 41.23364971530053, 41.948956674145116, 42.17763085519114, 44.04305519596223, 43.72639832958099, 43.171575146336714, 43.413357888498616, 46.01349315335674, 40.677634131523874, 47.13271402543592, 39.767965885900686, 41.87731850531794, 38.674248264681914, 41.99605649517429, 39.559484066501746, 46.089328258268296, 46.66372014630226, 46.91528920204409, 42.81731843948365, 45.67687926753875, 54.92353354730914, 54.865851171555065, 51.58267044251966, 38.94579395171135, 39.10219061759211, 39.16064962264031, 45.80005345805999, 50.50432851237636, 53.07800346805204, 43.842198464178274, 41.96416762567336, 41.72830766247165, 39.350790439113496, 39.49537292603524, 41.41614975467805, 41.92082935763944, 40.71441811899985, 43.38699563857048, 41.710468722927956, 41.84403327203567, 42.7762786803707, 48.82292216823947, 48.27638303079913, 51.22995914951448, 56.27946945928759, 55.16853263301235, 51.244334636196015, 49.00116643598003, 47.12668926485124, 47.15660518215549, 46.60370396029565, 45.144546954862534, 47.90033755763885, 49.856180375622166, 48.63111042207288, 47.88660533966557, 45.619879384194654, 47.268479024210286, 48.76220387797202, 49.72764430507537, 49.65217005821967, 49.19612000065465, 48.62343042127548, 50.81207767609627, 53.029766159672896, 61.61673268964214, 68.27198290055799, 64.07328959434264, 72.47040164086127, 67.27694819050451, 70.49923804498488, 24.987282676081506, 0.08460957722197618, 0.4812852082954299, 0.13617649524202272, 0.0910880687015672, 32.89930931983456, 78.62759713203677, 64.19039980057748, 64.38250964687717, 49.79002960266606, 39.37589360821632, 45.032814318133944, 44.37430327938449, 64.90094892440304, 51.92732518719089, 1.6249904036521914, 0.32377492636442184, 0.042441405070525025, 0.07181399366668156, 0.0503648609493769, 0.017272965276553746, 0.11405046638702193, 0.06909326304711642, 0.09482868451384768, 0.06370613659401575, 0.132050973873946, 0.39822580232735605, 7.198307754531984, 59.25796439570766, 52.33087824236963, 50.83547461417414, 31.448787412335797, 35.28859169252458, 63.60138139417095, 72.03665025772588, 76.87290130123016, 49.12419942117507, 0.08785674814134838, 0.11699828844998153, 0.648804827322883, 0.41188046155918034, 22.072877307091993, 83.96045946305799, 64.73808819247832, 72.27558535914268, 56.593200237520286, 60.581019078531575, 51.893184877211056, 53.53468894958497, 51.258702278137214, 53.010444564204064, 50.59652382327665, 55.215338276278594, 55.074442817318825, 62.87311492427703, 61.1245850593813, 66.64366583670339, 65.09958951703965, 61.943246472266416, 52.71485474801833, 51.22812348027384, 55.90508707108037, 58.59837078279065, 56.91688599125032, 59.471121680352, 58.14564297276159, 61.72007145420198, 61.786198692937056, 63.87127968572802, 58.46571622356292, 60.02938870460757, 54.53996104578818, 41.9893531645498, 44.35334213318364, 59.85705544871669, 56.78525517063757, 53.66476258923931, 43.079348456475046, 45.59578426422612, 45.68759518284952, 46.29225992387342, 43.460904859727435, 46.021934093967566, 43.482819141880164, 47.7195555163968, 44.668194709285615, 50.00605413990636, 59.71197482078307, 54.76226922004454, 43.1430555928138, 48.34415374263641, 50.35566676047541, 54.64012269050845, 56.10655569261121, 58.22969544318415, 56.14380251976752, 59.180579954578036, 49.009199450092936, 42.3269711771319, 42.35497690016224, 47.35885435535062, 47.370633232978086, 51.9202962998421, 47.256198083200765, 51.2388825416565, 43.261997545919115, 43.12419683702531, 45.34246190901726, 45.47728161658011, 45.00622457073581, 44.52505957695746, 47.14203749933551, 49.51879378288023, 44.38004170694659, 48.9692775664791, 40.807597944813395, 40.46916407923545, 37.73737445954354, 43.073429599885024, 40.0655286542831, 47.00142052865798, 47.76320365167434, 47.11009763902234, 43.76561810893398, 47.99886749636743, 55.88764821329425, 55.92178852327409, 52.13700725186256, 38.40952357938213, 39.33424980409684, 39.71558655461958, 46.166646019104995, 54.88443536143149, 54.7301685425543, 46.5156545946675, 44.03949760621594, 42.504121103594386, 43.21902405831122, 42.15445356984293, 42.203581256251184, 45.60144816675494, 44.93571604451826, 45.04933926366991, 43.58704436209894, 46.73166736479729, 45.45690490353493, 49.6369630290616, 50.82409974067442, 53.60234983505742, 58.36682934914866, 57.991980198890936, 54.92689894091699, 51.021893101353804, 51.261161604235255, 50.80777091364707, 48.75137813629643, 49.096719295747825, 50.6271340001014, 54.00622060222011, 50.07498979568482, 49.24136454059232, 49.672013328921416, 48.298265933990486, 50.54312075338056, 52.71400751606111, 51.65483420894992, 52.66940232246153, 52.404944358333466, 54.142209176094305, 56.07929914228378, 66.68529002897202, 71.21995787466727, 68.353223031567, 75.70462334540584, 70.39909993448566, 75.36978629327591, 26.251823440674816, 0.502583647687589, 0.6381351224357082, 0.1753971939005198, 0.17421862891604825, 34.97579051602271, 83.64222188149729, 69.68103947178011, 71.19839268345987, 58.67460596945978, 51.38559095321163, 44.37933568031558, 52.19053583760416, 70.42355199013987, 67.05691891331827, 2.049236045249047, 0.30222824384127894, 0.12661080732340776, 0.029729537688375964, 0.061540605214935165, 0.17371697922147092, 0.2867618479555653, 0.3084551597074155, 0.19146415675359388, 0.2120717533773953, 0.23710977436313707, 0.7966782441062312, 13.454651448034472, 75.64671347218176, 65.98538229542395, 63.183805865626184, 54.63864003458331, 58.465296529954486, 71.62747644609021, 79.06342737136349, 84.31740299347909, 54.9416470527649, 0.26857216271661943, 0.6606644199740502, 2.1771108286996044, 0.5097194196235749, 26.87813574267972, 93.49145027898973, 65.36810713429605, 76.87523118911251, 59.786915625295336, 65.26468207759243, 54.835507715902025, 57.00748881986065, 54.52058845950712, 56.10061722417032, 52.604389036855395, 59.19653615643902, 56.58682638599027, 66.18583110070998, 62.9200460833888, 69.42769358235022, 65.69217728030297, 61.396389622842115, 54.194965054911954, 53.68935192784956, 58.30129438830961, 61.48254840604721, 58.44698298361994, 62.225963069546616, 61.837224806508715, 65.73255808122697, 64.6427079169981, 66.06713233455535, 61.06465124314832, 62.332526022388095, 60.002065473987216, 44.1049894209831, 45.69358464210264, 62.185284168489524, 60.51107145124867, 56.46556238974295, 45.78563090293638, 45.603381895249896, 47.39537946639523, 50.42544180347074, 46.32082654583839, 49.073024257536865, 46.64537914337651, 51.05192668976323, 47.71960650720904, 53.38293636998823, 62.26836781347952, 57.55529096049648, 44.27491826395835, 47.666579984849506, 52.53238608760219, 59.04528956259451, 59.50213193893433, 58.469003169767326, 57.33399475774458, 61.57857195023568, 50.548945473086455, 42.98025761881183, 44.734890691695675, 49.1811522360771, 50.41240776738813, 53.799354799332164, 48.556102937267674, 51.83819324739518, 45.421270170519435, 45.868224251654844, 49.374964391031575, 49.21299795950613, 48.62740770463021, 47.26879673619425, 50.04866284708823, 51.36507695721042, 45.93159406415878, 51.035868506277765, 40.76844092338316, 40.68832651261361, 37.36857360409152, 42.6613728461727, 40.894513745461744, 47.62591285090293, 47.20368146896363, 47.54669274053266, 44.39211476233698, 47.057612403746575, 57.19771592847763, 59.146365119564926, 53.56854292654223, 40.2627375818068, 40.93186647661271, 40.29166113945746, 48.19742571923041, 57.198465101180545, 57.16547012329102, 48.20570976503434, 47.85603046417237, 47.45254801165673, 43.891047662304295, 45.518129179554606, 44.67815360715313, 48.4945805611149, 45.82472908881403, 48.06069973976382, 46.19858587941816, 49.35197930182181, 48.608317529001546, 53.485773071166015, 52.26271921588529, 56.753566342015425, 61.66292644316151, 59.601968026930294, 56.394206631568174, 52.40907461412492, 52.84101778461088, 52.2556903285365, 51.54268187861289, 51.70081615447999, 52.316463531986365, 55.60426481308476, 51.52962038593908, 52.263676274207334, 54.140298981820386, 52.340782227054724, 53.78599128415508, 55.072677750741285, 53.61996912187146, 55.24524242647233, 54.567319577740086, 58.04252778330157, 59.63873632492558, 69.34363718955748, 77.45971141322967, 72.40148559693368, 80.30131170826574, 73.3411442848944, 79.45510741203063, 29.292315360038515, 0.6165044153890302, 1.8398262175821491, 0.6923109605427712, 0.20617109903645134, 40.44517486326156, 90.68738706650274, 76.72884048954134, 78.91702882705196, 69.89630699157715, 60.3292578266513, 56.438898117311545, 63.864160583865264, 78.49093391049293, 85.29424575067337, 3.1171708241585763, 0.5815126446466292, 0.25724310127477495, 0.18029462546110156, 0.17331397100802393], [0.06331275044489773, 0.13204294527249952, 0.09550069684102651, 0.00626091676343593, 0.1052914307482781, 0.13829811446128354, 0.16039990429436007, 3.9635832511609603, 38.56691652728666, 42.17856045692198, 35.12477782464797, 32.26212813008216, 36.05823132299608, 54.24287288419662, 65.40906060126521, 64.32822012132215, 47.332982401694025, 0.07159847015094373, 0.1156078618500502, 1.0097293183207512, 0.12648839413398696, 2.6998137226027827, 68.35579610640004, 64.56335444604197, 68.83205029272264, 59.186875358704604, 57.53496916063371, 50.96598755928778, 51.675097173260106, 47.6061519499748, 49.6792697137402, 49.35655278544272, 51.87859366017004, 52.499610762442316, 57.03395305141326, 57.989607164936686, 61.43132225159676, 64.9803965322433, 64.8354963333376, 58.770731495272734, 58.04955274828019, 53.403556269984094, 49.47473772110478, 53.42949882630379, 55.20384573167371, 58.291245275928134, 60.75042624627391, 54.742786807398645, 57.59347523412397, 56.86054506609517, 57.91970268372567, 60.679035186767585, 60.65310831992858, 55.158252100790705, 58.80471491044568, 52.46929084101031, 46.919282174879505, 42.65009210955712, 44.976995068211714, 42.80840289208197, 43.49035401498118, 42.32973252573321, 42.9727658917827, 43.306551748706454, 43.6455661250699, 45.25420858014015, 42.345453385383856, 43.51675156624087, 53.41495860007502, 51.23093189731721, 45.900419066029215, 45.94560869278447, 50.475193146736395, 55.11722018641811, 58.1088746747663, 58.08296741977815, 61.21476034964285, 52.30422573704874, 43.29292151235765, 40.993977208291334, 47.526880848792295, 43.73510599136353, 44.3049910760695, 46.966633027599705, 44.78319468036775, 43.178368691475164, 46.85179779606481, 43.61879987101401, 43.737600618793124, 46.94911572241014, 46.31207573798395, 48.343016255286436, 44.2628961993802, 46.254487499114006, 46.36912661214029, 40.9872228868546, 40.73677562898205, 39.81878411385321, 41.37863228397985, 44.45897548429428, 48.69108738437776, 47.95572142447195, 47.466837206194484, 44.11717622510849, 53.2140116537771, 53.75111749095302, 54.15455679739676, 45.3814188895687, 37.692506467142415, 37.540844102059644, 46.89336707515102, 50.35865560654671, 56.59037613099622, 44.55597177628548, 39.95177207454559, 39.99578106787897, 42.575166994525546, 40.131612746946274, 39.909951763768355, 39.80875069095243, 42.55252315152077, 41.52128496477681, 42.0944256167258, 42.17092360219648, 43.2683753198193, 43.74042864768736, 46.94075322920277, 51.26391903046639, 55.57593745570029, 54.557623478674124, 58.368170799747595, 57.39146140313918, 57.245180529932824, 53.726026088960715, 50.61578266082272, 50.62870294817033, 50.300604527996434, 51.59011510110671, 53.29663245908676, 53.70362935527679, 55.38535341139763, 55.078471091485795, 54.22556346462619, 54.4298561926811, 52.502250517568285, 52.18622123041461, 52.38921173157231, 54.36759641093593, 51.031785318928385, 51.34775969289964, 60.77004594187583, 68.94020572785409, 65.83364932767807, 67.26883672898816, 66.5084852710847, 75.55409062293269, 27.72782506481294, 0.1421992486763385, 0.33537959559790553, 0.2157851654074846, 0.06062697258687789, 24.728555294775195, 79.98086190992787, 65.56390008618756, 65.58195475609072, 55.85453948666973, 29.45253045328202, 15.697637258037446, 51.56663579325522, 59.057978430101954, 62.227681067682084, 1.659326709566578, 0.15448164525291613, 0.14216929463849914, 0.12694485996279026, 0.07720263314343269, 0.03683441138315586, 0.07525422640385167, 0.02635094630081327, 0.01926584916579868, 0.06725563262138637, 0.04335460102846546, 0.15699249842474539, 6.726109789263818, 53.246269226074226, 53.82668587469286, 40.5720047027834, 27.676398869483705, 41.069227880047215, 60.301522747162856, 71.63798055341168, 68.66123107171828, 50.474514576696585, 0.019853808241145268, 0.031011779266860218, 2.520858770416629, 1.046712549944078, 4.207925094712166, 77.62310166512766, 67.16050870956914, 72.43199379213395, 61.68075753796486, 59.81901630278557, 53.43101678356048, 54.201986097520404, 48.92991658179991, 53.11424224607406, 50.80113818568569, 54.87142485956992, 53.52181573067942, 59.293540293170565, 59.92832491474768, 66.45122651130923, 64.45941948121595, 64.97114758337698, 58.011450844426314, 58.84265207475232, 55.52395428380659, 53.621643973935036, 56.24754136608493, 56.43561117110714, 59.561124386325965, 62.25359224504041, 57.96288797932287, 59.44403771431216, 59.072208789087114, 61.09060164420836, 62.36184966179633, 61.8306666035806, 58.14808660937894, 59.28786462353122, 55.529810382473855, 49.03705220068655, 44.627531497709214, 45.69301589842766, 46.44982545606552, 45.23798565710745, 43.70267975714899, 44.09912547757549, 45.556976333741225, 44.460136505865286, 46.450472647143954, 45.57345028846495, 47.91430904019264, 56.338775696293006, 53.47287631803944, 48.470595267511186, 47.844549686678, 51.18701311849779, 55.60465312773182, 60.245366173405806, 59.47689933161582, 62.129912068766934, 52.401092590824256, 44.744782909270256, 41.44254338356757, 47.41748202231623, 44.92751044611777, 47.27437826894945, 47.48809253015826, 45.87349591716644, 44.53217083407987, 49.44628877024497, 45.07970625354398, 46.782591496744466, 47.633435956893436, 49.063681171786406, 49.5590647574394, 47.65007857353457, 48.05148216985887, 48.117974189019975, 40.2378579878038, 39.25126814073132, 40.227275433078894, 41.87002289679743, 46.45400670266921, 50.125384407658736, 48.58929011129564, 48.81237491484612, 43.91374641849149, 53.23164270770166, 56.01048507998067, 55.44835844347554, 46.911402133203325, 39.779697695086085, 39.17851209640503, 47.180782671897646, 52.03896368703535, 59.36910475454023, 48.18623127475862, 42.02984771420879, 42.96962799564485, 45.17056011384533, 42.48566242956346, 40.99580503279164, 41.794705544748616, 42.71124578291371, 42.91024331123599, 45.332954083719564, 44.646637362818566, 46.36009731600362, 46.53665888694025, 48.59936275789815, 53.07121384528376, 58.1590731682316, 58.00631253950058, 60.396546086957386, 60.62871117745677, 59.01991182757963, 57.7224466877599, 52.589303601172666, 54.46550661517728, 52.69074001619893, 54.53243401742751, 55.02779406885947, 56.6586842075471, 58.40555098748977, 59.30887676054432, 57.746506506396884, 57.32496546160791, 56.172247548257154, 54.200381848119925, 55.577933942118, 57.49315669459682, 52.7659357747724, 54.19641240950554, 62.16054577981273, 71.6576708516767, 70.0361002645185, 72.82892980883199, 69.94792538304483, 79.7613033171623, 29.653748043121833, 0.5416159500037471, 0.6559578822024408, 0.1396981554646646, 0.11754380433910316, 26.489207244688465, 86.30012189188312, 70.81840915064659, 72.83657058592766, 63.16200140983828, 40.33508569963517, 23.902566894408196, 61.63090421307472, 68.4409664523217, 74.69127116664764, 2.4622732689303737, 0.16629386302684585, 0.06037409845439177, 0.13139917094620968, 0.07095346242309579, 0.15574817245285358, 0.2386037377460349, 0.1848353358406213, 0.1884984005723269, 0.14513056154452986, 0.312520818965089, 0.42011400684714323, 13.666965423091767, 74.97822392371394, 60.694885484633915, 50.933624082996005, 44.67361934723393, 53.275620322073664, 69.60000330402006, 77.81400342141428, 76.56639945122504, 59.38731239688013, 0.23037770011973, 0.3903172621803899, 3.7867561847932882, 0.6816979461619932, 6.272729394897339, 88.93050255313997, 70.42069650465443, 77.11440947748001, 63.45704993894024, 63.64122483038134, 55.61327449737057, 56.94894352266866, 50.48655233075542, 55.463592929224816, 54.68148016160535, 57.799701690673835, 57.842224105711914, 63.00271395714053, 62.2905017483619, 69.17666973606234, 65.33561421978858, 68.74549927250033, 58.02297476799258, 58.905370773807654, 56.91568966834777, 54.48353775085942, 58.083991158393125, 57.6029359909796, 62.566428722873816, 64.42940942702755, 60.688609692358206, 63.030554940623624, 61.35866034415461, 60.888787854102354, 63.42461978235553, 63.57130073731946, 59.6771441736529, 63.64419406460178, 55.85661049812071, 50.43853075273576, 45.66093091041812, 48.25892848353232, 46.36986794010286, 48.25266053599697, 46.07080290394445, 47.55841670497772, 48.81322999154368, 48.18032810764928, 49.272449324207926, 48.715680645358184, 48.70313298317694, 56.08837158449235, 53.002097760477376, 47.43445019568167, 48.89338362601496, 54.765109016049294, 61.15781930185134, 62.98317663131222, 62.798444763306655, 63.970433281313994, 55.01312440441501, 45.18388048295052, 42.90186512854792, 50.601418941251694, 48.20607062309019, 49.15540579826602, 49.94899934337985, 49.268421050040956, 45.22776003806822, 53.10692310333253, 47.08101326419462, 49.147208044605875, 51.637869957954656, 50.85722415677963, 53.627833474066954, 47.95774928985104, 50.56501542368243, 50.200325212171, 41.77164985287575, 39.655915537188136, 41.37445888211651, 41.94026470184326, 46.75912003363333, 50.85060711829893, 47.89479132621519, 50.63913253045852, 44.30676006501721, 56.459741592407234, 57.49941287502166, 59.141560216103834, 50.13367237583284, 40.30635826049313, 39.308342549108694, 48.83745847209808, 55.69476958244078, 62.410008522772024, 51.75741987843668, 43.74524139588879, 44.843869824563306, 46.8679658059151, 45.91570454259073, 45.11627451066048, 43.56056051869547, 46.97494452999484, 44.79720930899344, 46.765960647213845, 46.549257539933734, 47.96642165030203, 49.228177532073, 51.51252669672812, 54.158522313640965, 61.35755031339584, 61.87422452434417, 64.08735913615074, 63.4448984361464, 62.74305697410338, 60.83558874745523, 55.55399179458619, 58.32298117299234, 55.185528262968994, 56.39800740826515, 58.66728682671824, 62.10653082016976, 60.794796097663145, 60.950843672598566, 58.92908542386947, 61.11148826537594, 59.52343825371035, 56.774837355459894, 58.88830454118791, 62.268964013745716, 55.70749375127978, 56.48453097189627, 65.28534904603036, 75.72927151956867, 74.60631262871527, 78.04996536624047, 74.04353095639136, 83.79813609584686, 33.19011188322498, 0.8171123218151831, 1.6814313492467328, 0.5435371759437746, 0.17002805136144164, 31.55800973215411, 93.3742263240199, 77.20343159091088, 83.38346312122961, 74.55151711740803, 43.68634700775147, 22.20999356239073, 73.95931766879174, 73.23178860449022, 92.9816912066552, 3.8567246496677403, 0.3975314508763052, 0.2437319303111684, 0.22907674492847538, 0.24067753775706216], [0.14980480104925173, 0.04201488561868187, 0.038320422773399664, 0.12460621569546, 0.09178979757932887, 0.11095431438016315, 0.13305552964729647, 5.352374161443403, 45.36256013378021, 34.36310845036661, 53.49256269393429, 36.344752619343424, 30.262409679351318, 59.34892416000367, 64.94339289203768, 69.18345543646043, 31.432925347358953, 0.26118903631164186, 0.059448032219323425, 0.401772452338088, 0.24088375330451997, 0.19441069944971995, 46.313891795373735, 74.35455922157534, 65.06412344594156, 65.7856434391391, 59.941806101029925, 58.93746360655754, 56.17560901949483, 52.279526572073664, 49.60987121828141, 48.90090280963529, 51.50247758434665, 54.409593228370916, 56.66056302285964, 57.94915576134959, 58.62294050955004, 56.33723028244511, 61.662310631044456, 60.50936914259388, 61.55027597181259, 59.24136492513842, 58.25763448592156, 57.03089360267886, 56.25583325662921, 58.736928509127715, 60.49107913048037, 59.47889189566336, 59.158524467099106, 57.83801148014685, 59.39317241791756, 57.55705994944419, 57.21190706376107, 57.06435142024871, 54.529296121289654, 47.927499971082135, 42.378185564471835, 44.46337246125744, 42.809732575570386, 42.21515617062969, 44.3626852189341, 44.436406166322776, 44.135685889951645, 43.17805490186138, 44.02132134283743, 44.88579211696502, 43.46767094827468, 42.03377792912145, 44.90969896316529, 50.40498272065194, 49.83096738015452, 46.27302462054838, 46.89321018034413, 50.0124672151381, 53.209422480675485, 56.953528773400095, 59.716709121581054, 54.040659012333045, 50.836941580618586, 40.6964458188703, 43.868423431150376, 43.10616962371334, 41.93183945071313, 44.61885521488805, 42.93388343626454, 40.440248366325136, 44.32034323292394, 44.96140364677676, 41.37107779902797, 44.85181654653242, 47.542103567431056, 44.76032726226315, 45.53839606623496, 49.3485511502912, 44.04279631953086, 41.22168648627497, 42.07830859768776, 42.09552388037405, 43.61002945130871, 48.61139266721664, 48.02406872472456, 48.87889046822825, 50.00411256667107, 52.25634144198511, 55.37496305281117, 48.61441289224933, 41.53608798980713, 41.320906762153875, 41.12625129761235, 44.32919602240286, 48.91478800004529, 50.192739348257746, 45.217353990001065, 40.48299043409286, 42.2462684108365, 41.90080958027994, 41.52596043002221, 39.55441636423911, 42.06183072059385, 40.08716052578342, 41.804064319979766, 40.87902822802144, 42.93282831868818, 42.25123020910448, 43.45210698343093, 41.77146942384782, 45.12206392903482, 46.6239433903848, 51.575990646116196, 54.628951780257694, 56.89632884917721, 58.483519861775065, 57.01626708430629, 58.10007679846979, 54.99448922372634, 55.938807687451764, 53.645484139842374, 58.47944451916603, 62.586040573735396, 64.47723096416843, 66.04675954388034, 61.02113254608647, 58.02245309275966, 60.69959625121086, 59.85212502941009, 59.916993187319854, 60.274305420537154, 57.55257668033723, 55.557514083000925, 52.04125042884581, 54.90802841801798, 67.35722341845113, 68.72806041471421, 71.74670865458828, 66.40808043941375, 73.51964350669616, 28.23392260459162, 0.2743110805749893, 0.10874291731705589, 0.15214086360027715, 0.184726536033615, 17.82807457831598, 79.28543352311658, 66.76816186597271, 68.51361659265334, 54.031602259605165, 42.0778771369688, 31.369734002697854, 43.122510217851215, 57.39282246558898, 67.6974105834961, 2.414504438638687, 0.15387355530213925, 0.013042636377166116, 0.09309824511048295, 0.046835248734080986, 0.08979078307146988, 0.020676764787264892, 0.010088055503494557, 0.03923807353261979, 0.05662991267238414, 0.0812788797362197, 0.173923455238823, 9.034901203647737, 63.53857248060165, 42.80387647690312, 61.68212644515499, 44.52150590958134, 35.94826375284503, 64.48047476430094, 68.94288078431161, 74.44411477734967, 36.516277866978804, 0.3389167154748594, 0.03937648646833916, 1.285170715662741, 0.6157418821127184, 0.14911591946598024, 54.581008649641475, 75.29286861419678, 69.6201878209268, 67.45542387808523, 61.40498745825983, 60.850470219889, 59.23180610902848, 54.926628297375096, 51.39876227225027, 51.75471344301778, 53.2422487966476, 54.17769093667307, 57.94900671128304, 57.72576501292568, 62.04313747344479, 60.84209988194128, 64.43298270625453, 61.58496933598673, 62.762292277428415, 59.75338720506238, 61.16136120211694, 58.76259649953535, 58.17040097328925, 60.464222661910526, 66.32406327032274, 59.12417627150013, 61.119940973097286, 59.5683023237413, 59.98632892485588, 59.75376375259892, 61.31102315841183, 59.24981763285976, 56.87697979711718, 50.11033427330756, 44.97007992959792, 45.73056082571707, 44.67979315788516, 45.390930637236565, 46.9944465544916, 46.066990360136955, 45.79620561292095, 45.51650531830327, 45.71462815807712, 45.78267343582646, 45.388769411271625, 44.24396291855843, 47.795476913452156, 54.53001391503119, 53.22929320796844, 47.858042640070764, 47.54227615171864, 52.77752245626142, 54.94842098605249, 59.773403060051706, 59.53408748872819, 57.16745484259821, 51.776270789484826, 41.35790255761916, 44.82402655386156, 45.14569620932303, 44.73295304083055, 46.103468402739495, 45.32072805589246, 41.6692328453064, 45.247022797984464, 48.29743831388412, 44.468875546609205, 46.19170604213592, 48.7779482718437, 46.02492294003887, 47.07719287564678, 49.975863656690045, 44.34006098778018, 40.58028090384699, 43.616670024010446, 40.23364536223873, 44.24465717807893, 51.284229063218646, 46.95506595796155, 48.323639746635195, 49.53638953547324, 52.670782996762185, 57.19232266949069, 50.04085340807515, 41.47489509274883, 43.721534590567316, 43.00720430189564, 44.02042704243814, 50.021194488771506, 53.32371250275643, 46.24574453599992, 43.461603041618105, 44.17910652775919, 43.36232785255679, 43.38042566853185, 42.02749821447557, 43.56065857794977, 43.69792976687032, 42.99448405542682, 43.98623966401623, 45.861505231549664, 44.34555230602142, 45.698091445430634, 44.49532408868113, 48.94266036248977, 50.105364630299235, 54.57352084498252, 57.77859149440643, 59.098786769374726, 60.53165997228315, 59.95875074017433, 60.4715653388731, 58.936231982323434, 57.91154807613742, 58.268013077397505, 60.7768512541248, 64.78406621563819, 66.5263791238108, 66.24085410948723, 64.15114471989294, 62.24348429710635, 62.483866753116736, 64.12227215305452, 63.4268202320222, 62.537242366421616, 60.62495746920186, 58.63410749743062, 54.37520188670005, 58.185851189398, 72.85622166049096, 69.55977547553279, 76.8325008884553, 70.38691705273044, 76.052349305922, 30.234237255588656, 0.28835782360646034, 0.4133444555824803, 0.053230183003770734, 0.2310123579997209, 19.795660972595215, 86.75708586169829, 74.64071965986683, 76.31030005793419, 62.7126625276381, 42.564243193595644, 25.84006870946577, 52.45193435299782, 61.40329691671557, 81.35010642390098, 3.1233434090691232, 0.08041981172056929, 0.09231351826700473, 0.06555691691896608, 0.05725420155231992, 0.2888329819806161, 0.15906412274606768, 0.14176138346233677, 0.22811412480809998, 0.31522627379144397, 0.15455370348307396, 0.2812484663821036, 15.539965821850686, 79.157744684527, 51.07466074728197, 69.18529110570108, 53.70688492251981, 45.63267023332658, 74.02926921844482, 77.47714242627545, 82.4843382066296, 42.87684432921871, 0.830278737891105, 0.20593981709211104, 5.242686060167128, 1.6005003500369288, 0.3789477819396604, 63.41041687996157, 81.10597810437604, 74.14552827035227, 70.942975782579, 65.41843506597704, 65.27738663458055, 63.715294868715354, 58.99254937325755, 56.654298997694454, 54.51617971543343, 57.00819876886184, 59.13906558867424, 62.678800705940496, 61.786077099461714, 65.77132286563997, 63.31817842298939, 65.51600794638357, 63.12961832169564, 65.57929146674373, 62.55959595403364, 63.30510908557523, 60.933051801496944, 60.27527032359954, 63.75807223781463, 64.14089556663268, 60.76911241777482, 63.53948247048163, 59.97277321354036, 63.244614370407604, 62.134352191802, 65.12577918268019, 61.33461621499831, 60.11970912256549, 52.511970150855284, 45.21224706403671, 49.74570681971889, 47.72993803024293, 46.28359540816277, 49.728118911866225, 49.825538819836034, 49.43297232350996, 47.56926598087434, 48.97444725036622, 49.82673514273859, 46.35443733584496, 47.26763179225307, 50.65626544337119, 55.61398052400159, 55.315907847496774, 49.314865835251354, 49.72882493849724, 56.61314156747634, 56.91422270190332, 62.76265313548427, 64.33923413676601, 60.3857752584642, 54.34577234329716, 43.20699022662255, 47.87249657415575, 46.85953663241479, 45.53373629047025, 48.97454138725035, 46.36629466087588, 42.100336628575484, 47.492971958652625, 49.513541729219504, 44.617807942052046, 47.09389825021067, 51.985254672265825, 47.421569132035785, 48.41547419947963, 51.20302031117102, 46.04666856027419, 41.96596014884211, 43.91913183273808, 42.31481575196789, 45.25633842714372, 52.08668716492192, 48.693095637905984, 51.01986523597471, 52.426537006132065, 55.31010273964175, 58.61229519690237, 54.70827779462261, 45.2897923223434, 44.61153214977634, 43.6698926648786, 44.666570848034276, 51.713928637966035, 55.839336379881836, 48.38572694409279, 47.03025387179467, 46.98022011787661, 46.489123682821955, 47.68541520641696, 44.1405810079267, 45.15688673142464, 46.068163148818485, 45.94749535283735, 45.57920440550774, 47.33869337266492, 45.916410569221746, 48.916749185131444, 48.1884160349446, 50.54323450211556, 53.23126616016511, 56.85961154199416, 61.60317305595645, 62.56337319650958, 64.8612976843311, 62.524749617422785, 64.55761601847988, 60.80236627209572, 61.68241277817757, 60.85487896396268, 64.36118764262046, 66.18649005889893, 69.98086544775194, 69.33292127424671, 68.87046598619031, 65.04160119641212, 68.43578892369425, 65.83241770344397, 65.40562068262409, 64.18483395730296, 63.60681387685961, 62.146538995927386, 59.35337997251942, 60.8910902853935, 76.4158510392712, 73.79114212528353, 79.62579327244913, 75.08792477269327, 80.71260359979446, 33.48106545786704, 1.0289548770073922, 1.1609683738600824, 0.8737896514996406, 0.2621522233370812, 23.011267108301965, 94.92683379880845, 80.8306198735391, 82.97769392690351, 73.05240292702952, 61.083949304396114, 41.91541648680165, 63.14922625018705, 70.60120397998442, 97.19611321726154, 5.282949680282224, 0.415469951206638, 0.15382351443892525, 0.1759449008011049, 0.23895368670984624], [0.02674730678629731, 0.15045160908372174, 0.04901124870464687, 0.04820650015326758, 0.05254869799940817, 0.17381051855702556, 0.20621476604813532, 3.434545974577627, 44.493260921970496, 50.98094355675482, 32.77170677338877, 14.949247067974461, 38.623684990790586, 49.85121465498402, 69.56900873491841, 65.46245974879112, 38.63186705497004, 0.6880147394634063, 0.1340476288309982, 4.127171827900795, 1.4083135272226026, 0.5161795632973795, 14.603634284388635, 81.25556161326747, 63.15756913154357, 65.0145289974828, 63.86836144231982, 63.20791275270524, 58.27101369057932, 54.90023859085576, 51.53027542175786, 51.11584171172112, 50.75694091858403, 54.276919057292325, 55.16314721876576, 58.64102263604441, 57.73278213316395, 60.207303493253654, 61.659302173122285, 61.91450726601386, 60.597402818741344, 58.41654539108277, 58.81204974266791, 57.284149277594786, 55.91857610210296, 60.14846401829874, 57.889382762293664, 55.952084910485056, 61.09789725272887, 58.69280184468916, 59.306982255751095, 56.963013064476755, 53.50063100937874, 54.70535562884424, 49.583340306435865, 45.245771561899495, 45.6652259057568, 44.21833022948235, 46.55630603913338, 47.613165147842906, 48.8623066871397, 45.18626528401529, 41.71660723224763, 42.85181176277899, 41.352352403825336, 43.76419036619125, 44.908890954909786, 42.46197523609285, 43.59725036928731, 45.25287889665174, 50.071761685033, 50.02476776799848, 47.91847067494547, 51.418389812592544, 50.48909010425691, 50.48202591557657, 53.92638860210296, 57.00587672571982, 52.41502484967632, 43.37632286933161, 41.80078129614554, 44.44188963982367, 44.82906679953299, 43.129856817183956, 43.696345129320704, 41.660513416413345, 44.080792319390085, 43.412808756674494, 38.82719324481103, 44.00954638758014, 46.426259856070246, 45.187936213708696, 43.47029109154978, 50.035334633242705, 44.64793174497543, 40.98301810602988, 40.0938795458886, 41.86811662489369, 44.23376475611041, 49.14028113888156, 47.91778818253548, 48.36408722785212, 51.78028729654128, 54.75823310113723, 52.639247140576764, 44.847792194735625, 44.01936408012144, 42.85722463361679, 44.729630793294604, 46.41373965048021, 49.648679148766306, 42.69993758970692, 40.83149694627331, 38.866828795402284, 40.63367612900273, 42.894969601784986, 40.87334471364176, 41.26652702208489, 42.63606571382092, 40.09673110900387, 40.45880117724019, 41.81883204367853, 45.6860536913718, 45.181181892271965, 45.08839038110549, 41.30858659744263, 43.05997587019398, 44.976547918012066, 47.75288389575097, 50.194665232012355, 55.57822419751076, 56.063778323511926, 58.82754702721873, 59.06897283369496, 57.95519621141496, 55.85741458400604, 56.88121203453311, 54.104911358125754, 50.20076844000047, 54.61919292326897, 59.054322781101355, 63.24398286880986, 63.106048799330196, 62.14466410298502, 61.6448482390373, 62.19285042055192, 71.73485525192754, 67.07998244993149, 58.2590308497029, 57.279999409952474, 52.089440668782885, 64.24643870322936, 65.930571094636, 73.71380867496615, 64.59558848411807, 72.20537493305822, 29.484701733435358, 0.3891626144609144, 0.37027796490057824, 0.2797274447737202, 0.17855640260442612, 15.716016504072375, 79.8054378263412, 62.877256947179, 73.02860982956426, 54.400057946482015, 39.06946628324447, 21.47120337332449, 39.231522929283884, 53.86114389665666, 72.46988388799852, 3.338620979939738, 0.2278434506226932, 0.13434683213070517, 0.010069355297262871, 0.027739829233577176, 0.0643121466160782, 0.0813904527815119, 0.024961218756112843, 0.0619518373822493, 0.023919011676503767, 0.16703759650549582, 0.2758100082076365, 7.527654469013215, 60.25831783971479, 57.541605810965265, 44.7075713834455, 18.80502323950491, 44.64160496188749, 57.36451472005537, 75.82759749504828, 70.77931096476894, 45.05690551573231, 0.5737177306605924, 0.0997992238450435, 2.75499215529811, 4.05975854204547, 1.382376977032231, 17.266663774367302, 84.8895199068131, 66.4697479432629, 67.94692039489746, 64.70168075253888, 66.77711271470594, 61.49014995944116, 58.17561772561843, 54.03443813323975, 54.35128719575944, 53.00799700521654, 59.34511161619618, 56.587053883460264, 61.44732552189981, 60.514978131940296, 63.74968228801605, 64.07781600952148, 63.468032575422725, 62.472640929683564, 60.50607827401931, 61.60396929710143, 58.52586969252556, 57.53474950790406, 62.51885037268362, 62.181357875947036, 58.31417545195549, 61.51723784785117, 59.46684237449401, 60.71741165653352, 59.95153357905727, 56.517878963101296, 56.707604008336226, 51.4748993996651, 48.65382094537058, 47.37756406107257, 47.225929152581, 46.80970684174569, 50.71457147598267, 51.314325409550825, 46.29711974051691, 44.07108837558378, 44.495688869107155, 45.59059496848814, 44.39035361812961, 44.4212148266454, 45.3662589288527, 44.34845485994893, 48.498910857785134, 51.10348624567832, 51.187726989869155, 50.66822867239676, 54.31946500655144, 52.72594721086564, 53.098776340484626, 57.560821502439445, 59.55300508006927, 54.56684497094924, 44.52225508228425, 43.335341945771255, 45.389875519660215, 45.97388113698652, 44.86538402495846, 44.719373795294, 42.222883239869155, 45.66582210602299, 45.22402986403435, 39.58716815517795, 43.96181114258305, 46.498623663379306, 45.827129579359486, 47.653479268473966, 51.86026834672498, 46.46288694873933, 40.399263520394605, 41.95370666442379, 43.28216637334516, 43.23308575537897, 51.75471344301778, 47.42626813150222, 50.314383814411784, 54.52531099319459, 57.39621139341786, 54.910209255833784, 47.597248169683645, 46.838681390208585, 44.353149937045195, 45.9121234186234, 47.144198725300456, 52.33530659829417, 43.16154956817628, 43.579587936401374, 41.5282432494625, 42.137379492482836, 44.564679438068026, 42.37745992598995, 43.16796656577818, 43.8685764035871, 42.4409709438201, 45.19240771570514, 46.40985258163945, 48.26425113985616, 48.00381360515472, 47.575584919221946, 45.456249867716146, 44.94845982520811, 46.846490829221665, 50.50889807362711, 50.7931169386833, 59.08836895419706, 59.2804866452371, 61.611413955688484, 59.71700329934398, 60.03460545693675, 58.52673261396347, 60.51889657974244, 57.93533725123252, 52.445929204264, 56.86101182814568, 59.119414514110936, 63.68204101439446, 66.7816234404041, 66.69224046891736, 63.914221794374534, 66.74809502017114, 71.15801580490606, 69.71090439827212, 62.32563049562516, 60.0973359231026, 53.71772635367609, 68.57174611860707, 70.02851440060523, 75.74489824233517, 68.45532232715239, 76.13392676076582, 33.33982875270228, 0.4311015462923435, 0.3724544206934591, 0.2633761560484286, 0.30812751922395926, 17.408014228267056, 87.92512847531228, 68.97661316779353, 79.8515570548273, 62.23400000602969, 47.519444034945586, 31.16867526885002, 56.93749412413567, 57.71415871958579, 87.51177341707292, 4.7219374872023065, 0.17790884380379032, 0.10683502130691083, 0.016721196194750168, 0.009318822788284912, 0.17992602991721324, 0.27740494197895454, 0.16275636010592984, 0.18490702634857548, 0.20610333089866947, 0.4001655675951512, 0.6713876897288907, 14.288245324165592, 76.3939328347483, 65.31309197025915, 48.0036174866461, 23.605565024960427, 54.95210016927412, 62.27020740509034, 84.25468429442375, 77.79998487041843, 52.419009977771395, 1.3825901333362827, 0.15147496465473406, 8.535219680878425, 6.594528978870762, 0.8542718149481282, 18.957764256385065, 89.50894232719176, 69.18857020716514, 72.48763653539842, 70.62799376826133, 72.25143140362155, 65.28322312139696, 61.71705515153947, 56.59005841901226, 57.313135593168205, 54.63013633604973, 59.72353404568088, 60.71827065560126, 63.885910126470755, 63.43803428834485, 64.50158103819817, 68.50076690796884, 67.08493248108896, 64.47865478454098, 63.14119715844432, 62.78756018607848, 59.641650645963615, 59.68168627831244, 61.37089029435189, 60.56936571674963, 60.29252482998756, 65.84434955350815, 63.44376094879643, 62.6950942316363, 62.133724612574426, 58.27521062666371, 60.43405179054507, 54.54147900304487, 48.862942111107614, 52.840825588472434, 49.0373856021512, 49.70147425128568, 53.498897321762584, 53.79727594314083, 48.93070890057472, 46.86156449779388, 47.477247176631806, 47.441573219914595, 47.99155619836623, 49.1577749098501, 46.57752213939544, 47.468547359589614, 52.285959259156265, 54.68176649462793, 54.85963813720211, 53.286297013682706, 55.57336830323743, 56.73410746359057, 55.49037487276139, 58.86637064718432, 62.729454194345784, 57.22031662541052, 46.032650009278335, 44.268269846516276, 48.29936027526856, 49.56019440004903, 47.34696172898816, 48.01598471979941, 43.81480463089482, 46.34152097086753, 47.21686455511278, 41.212849386276744, 46.66938797120125, 48.25658290616928, 48.17473088541339, 49.448293101403024, 54.09935728196175, 47.20466598387688, 41.31387003006474, 42.45788812637329, 42.865124287143836, 45.95932914364723, 52.11968214281144, 48.55744831023678, 50.93733856754919, 53.98488290848271, 59.48147281523674, 59.768857033021995, 51.600913386191095, 47.09531814821305, 46.37522589775824, 47.873355573223485, 51.30158947360132, 55.039157175248675, 45.721743337569706, 46.07024200500981, 43.512786049996656, 44.92650631935366, 47.24326602874264, 45.54964150151899, 46.8661379814148, 46.926926874345355, 43.57599504532353, 47.189517790271395, 46.99352871987128, 49.77395965207008, 50.606710218614154, 49.99871146294379, 48.45398402983143, 48.57897820011262, 48.78556159234817, 52.084592619249904, 55.65183139616444, 62.41563320159913, 62.7545730529293, 64.04049073496174, 63.22230785123764, 61.86021774045883, 62.326375745957904, 62.93485303078929, 59.20616949758222, 57.47827522216305, 61.07839130586194, 62.96922868297946, 69.2737562425675, 68.36109130613266, 67.94060537892004, 67.97978201220113, 70.24024394250685, 73.2374603517594, 72.3173350672568, 65.6384761102738, 62.05029579900927, 58.45150547642862, 70.47371125990345, 73.17793446202433, 78.37250186551002, 74.92454236553561, 82.40025043487549, 34.8918596390755, 1.1156752945915347, 1.64954382806055, 0.5095461305351027, 0.27062147855758667, 21.57896068788344, 97.39854674185477, 74.82383943373158, 88.16828404703449, 71.74624581490794, 55.36980513603457, 33.67066106488628, 63.33991227611419, 66.3032433294481, 102.97159148800759, 7.17944311518823, 0.393211082705567, 0.23999765004602172, 0.16986363357113254, 0.15004144560906196], [0.09127304829176396, 0.12112199418967771, 0.07563000019159048, 0.07279693809968811, 0.0706203980371356, 0.13583400797459388, 0.22089995143394317, 12.540897073284274, 53.329497998760594, 48.595714953637895, 44.88146966503513, 26.057709263217067, 39.436043154808786, 49.19633573101413, 68.44757172369188, 65.21304407427388, 50.26771937647174, 1.0547901810176912, 0.07223472149381716, 0.6179096657902964, 0.8115784090853507, 0.13821241986607352, 0.05837775759338852, 34.027432011019805, 79.56665177499094, 62.4258235193068, 66.94363301800144, 57.787601178692235, 63.159357732342144, 55.22623854298746, 55.08363685300274, 51.3400443907707, 56.171690571692686, 56.268302471407004, 59.499511795659224, 58.0933460112541, 61.34848179355745, 60.76538224374095, 60.982795300022254, 57.741901643814586, 61.37904882431031, 60.65472433643957, 60.241302597907286, 54.03610121819281, 58.09760962763141, 52.66511909423336, 46.1309406834264, 62.76132345199586, 57.095848052732414, 59.11263665845318, 55.32557256760136, 54.702174586634484, 49.51221204573109, 50.39751845021402, 48.21990090031778, 46.91643845650458, 45.233270968160326, 49.73674420387515, 52.61030397107525, 53.35967279249623, 52.442708938352524, 45.59259145490585, 42.33265861388176, 43.23365449905396, 42.373835655950735, 41.22810740624705, 43.87263997908562, 43.291803636858546, 44.20905382402482, 45.77605247497559, 47.57905229445427, 50.352054257546705, 48.252899800577474, 48.586246352041925, 52.01003620701452, 49.99369475149339, 54.385780519054784, 54.07562302004907, 52.29691051667737, 46.8091812441426, 45.491778696736986, 44.76519100127682, 44.26698330909976, 39.765153546487134, 41.2903985669536, 40.38212276274159, 41.12370175700034, 45.72826231679609, 44.896876735071984, 41.76223224209201, 46.20716802535519, 46.40302765753962, 41.898216893596036, 46.12626129581083, 45.449115076372706, 42.09747722071987, 43.67843950948408, 39.88665680731497, 44.90047354852, 48.84963350911295, 48.99186649630147, 52.63037081687681, 55.421819686889656, 49.17906161277525, 47.79133096818001, 48.13289880752564, 44.64431139730638, 43.38744278877012, 41.345292137515166, 47.513419274360906, 42.5053801844197, 39.70170920894992, 40.962276612558675, 40.9290345253483, 43.405779869325706, 41.51972386144823, 39.40323252831736, 42.574790446989, 41.19636758681267, 42.56756151876142, 44.985122219208755, 46.46809585632817, 51.072115129040135, 49.55858622827838, 49.853560232347064, 46.25727630430653, 47.02199336021177, 41.71283783451204, 43.445164388225926, 46.20990976210564, 48.674495758548865, 54.74941169061969, 56.914356062489176, 57.177539256311235, 58.08681134254702, 56.89689367048202, 59.33936534389373, 50.24145126342774, 50.875878949319166, 56.44681346031928, 51.99547244656471, 49.432784049741684, 54.0575683501459, 63.28069233125257, 63.59646274197487, 67.53187087274367, 73.33772397810414, 66.53235681595342, 62.49990140238116, 62.69346644801479, 53.462152557988325, 57.48932453893847, 67.95873457385649, 71.99754422710788, 68.31948280334473, 66.3025608370381, 33.72978687286377, 0.24134835498707913, 0.32772674495654724, 0.0988365654202719, 0.7713135019425423, 20.105249727925948, 79.1624201497724, 65.44665651936685, 75.1301294757474, 53.633250267274924, 39.737163512937485, 21.989834846988803, 33.44772138903218, 52.859256805912146, 66.16092405011578, 2.790844334710029, 0.2573479021028165, 0.024091528931392298, 0.014943450862061114, 0.012167004582982872, 0.02774295104186862, 0.15398174223880615, 0.0695338172297324, 0.11119954678560458, 0.09103075766395177, 0.2125055276818814, 0.30308883637189865, 17.039007448380996, 62.8391589656953, 53.896480529539055, 39.61871970084406, 38.45267357364778, 54.99107283930625, 55.21693468093873, 77.5284234939083, 68.75763508581346, 57.31905052738806, 0.8311623130594531, 0.05232960068350358, 1.181781818309138, 1.9426976072211422, 1.353319813647578, 0.075779571197927, 38.58680686643047, 81.15874182793402, 65.22006511688232, 66.15313422295355, 61.261464011284616, 65.48608026196881, 57.80057245685209, 55.31789648917414, 51.76424872490668, 57.78224322103686, 58.89843994571317, 61.423740310053674, 59.73753690719605, 63.83258158160795, 62.37690764088785, 63.29673090288716, 59.19146060943604, 63.42742819939891, 60.375012274711366, 62.27787956114739, 55.495826967300914, 59.50002170378163, 56.60455157679897, 48.62601526321904, 62.67572164535523, 59.51950019405734, 61.203522759099165, 57.97477276094499, 57.11810358109013, 53.50019954865979, 51.38148423164122, 51.291399155893636, 48.78816212377241, 47.172902630221465, 51.705028780045055, 54.85343686995968, 55.21251416975453, 56.92358932187481, 47.234836855242335, 44.157149099534564, 43.528138206851104, 44.58405202434909, 43.02583948258431, 46.027052787042436, 45.12224435806275, 46.897407116428504, 46.41272375660558, 51.02001428604127, 52.5235999784162, 50.82908899553361, 51.33138379743023, 53.63527028791366, 52.461297050599136, 53.682668209075935, 55.20515188094109, 55.30204619130781, 47.499126157452984, 47.10769714847688, 45.92606744458599, 45.4627178561303, 43.49777121697703, 43.98966781554684, 41.6808509057568, 42.141729401003936, 45.26438713073731, 43.813847572572776, 43.27247419664937, 47.29531980329945, 45.459901594346576, 43.249842120755105, 48.30079194038145, 46.71842544309555, 41.558308216833304, 41.639191412156634, 40.19169561324581, 45.87792035072081, 50.945908946375695, 48.665313489975475, 54.417724301738126, 56.97479194210422, 49.9161220365955, 50.74111023256856, 50.19772860311693, 46.647026538848884, 46.00329891327889, 43.4113064888985, 49.797972402264996, 44.491911626631214, 43.16186728016023, 42.816114271840746, 43.56059974239719, 46.22501480963923, 42.81782442523588, 42.77818495227445, 43.18131439147457, 43.391612268263295, 43.55126842375725, 48.36615431693293, 50.61297424377934, 53.122330173369384, 55.369444277978715, 53.81883328960788, 49.820667236082016, 49.155641140476355, 44.45977172543926, 47.40687201100011, 48.91816516076365, 51.62044678964923, 55.93395179317844, 60.84139385531026, 59.82135403540827, 60.79462743574574, 59.77592122170233, 61.73121490786153, 53.15245397629277, 50.49280066643992, 57.69975185394288, 55.09105405499859, 51.2579531054343, 54.22704612055133, 63.30776845255206, 65.18280260024532, 67.74247861677601, 77.85020689810477, 70.59757186520484, 65.52254261509066, 65.70556825207126, 56.41164941172446, 61.2749687317879, 70.1481859145626, 76.44283694605674, 73.83536292660621, 70.6852525280368, 35.76299059775568, 0.33006600975509615, 0.7092222595407117, 0.07399349848950103, 0.9978680096326337, 23.985177893792432, 85.36299705505373, 71.86328934084985, 83.38406716623615, 60.89850356501918, 47.03435667099492, 21.127027157814275, 39.11106694129206, 61.48217185851067, 81.41837135437997, 5.2075048512028115, 0.18396404872257865, 0.04482273192655656, 0.06954860272667102, 0.11688276239100004, 0.17823735762748028, 0.22268582495950887, 0.12425711708924464, 0.17306270949061842, 0.2696805080819515, 0.2509373702829884, 0.38031491180581434, 27.442947241567797, 82.09253265011696, 63.673768735701046, 61.91091437493602, 41.51597015319332, 57.860070889995946, 65.78727122276061, 81.9695035872921, 76.67695537690194, 63.27120019543556, 1.3988826784395403, 0.243640260230149, 1.26470587186275, 2.405353303878538, 0.8996882650160021, 0.25508152290938363, 41.71056678218227, 85.89389770261704, 67.00128401479414, 71.76913676723358, 66.10197867116621, 68.09482512935516, 60.20578553599697, 60.25698031148603, 56.303866601759395, 61.78755975538685, 61.481159887006214, 64.5031068401952, 63.26476358598279, 66.2812231433007, 66.02971292311146, 66.45139909559681, 60.692261418988636, 67.25032314177483, 63.48025468087966, 64.38190167950046, 57.42606847516952, 60.985909661939075, 54.212325465294626, 48.68004983471286, 67.47769509592365, 60.860099638662035, 65.0937138065215, 60.894847916018584, 62.21560408992153, 55.2047674886642, 52.90864729112195, 55.68284557711694, 54.50553832515594, 48.05456123044414, 53.23745566029703, 58.1192885675738, 58.03058416612687, 59.26735454990018, 52.25637282094648, 46.59048949518512, 47.53250944998957, 47.304533450834214, 44.96696949005128, 48.979997404160045, 48.70909106346869, 49.90564146349507, 50.40253516166441, 52.733015321916156, 55.4465227742349, 53.72279013356855, 52.50286632968534, 56.80146632655975, 54.26961560403147, 56.592400074005134, 58.20698491988644, 57.27176635496078, 49.32386375242665, 49.599221983263575, 47.13858581358387, 48.840388482616795, 43.71691403850433, 44.16106362496653, 42.42369290321104, 42.73003785840927, 45.49244942203645, 45.75398522038614, 43.826618809853834, 49.208361717962454, 48.233680186733125, 46.03403460594916, 49.6298360824585, 48.68406634176932, 43.17318331810736, 44.070523554278964, 40.50361033408873, 47.856116756316155, 51.55230737501576, 49.825464294802764, 57.09351816485005, 59.83855755098405, 52.44826301451653, 53.26820704244798, 52.02611007998067, 49.43501980073991, 47.866895429549686, 44.631857872009284, 52.7754436000701, 47.917835250977554, 44.20269173960532, 45.95343382127824, 45.68370026926841, 49.40107953163886, 45.015218565540934, 44.80551296664823, 46.45579530346779, 46.05823955228252, 45.64244870216616, 50.78593900126796, 52.43733136884628, 55.94446766761042, 56.431692723305, 55.315190053755245, 51.95475432180589, 52.92733346262286, 47.628697733725275, 50.130754132424634, 51.71137125261369, 55.690478509472264, 59.601450274067545, 64.46339676457067, 61.59918792786137, 61.56607135649651, 60.576971192513746, 66.56274734004852, 54.47359846484277, 52.58014878919048, 60.467235042202866, 57.71804186605639, 54.725669583966656, 57.91602350050404, 64.87286083159908, 68.20312961455315, 68.71622270153415, 76.94293914302703, 77.13078145057925, 70.54404720183342, 70.52153279704433, 59.879318821814756, 65.8345671622984, 72.9138961915047, 79.9577199259112, 75.23608053884199, 76.22962474822998, 39.427182520589525, 0.8391183506577247, 1.5155503922893157, 0.3181108706180127, 1.738270783135968, 28.649999787730557, 92.40331419052617, 78.46386955630395, 91.1507680339198, 68.91707158857777, 59.74781743941769, 32.1999938641825, 50.85798509659306, 66.68046551366007, 98.71167782814273, 9.703800639798565, 0.6085872337702782, 0.16254657458874489, 0.27037908833834434, 0.2589344395504844], [0.09653309224954537, 0.011555627157400933, 0.02956048315090518, 0.0853064644240564, 0.023242979302942272, 0.12877893574055166, 0.24173501488422197, 22.24944083921371, 61.67099083623579, 52.17416386450491, 51.51467223321238, 18.16861867904663, 39.044029712677, 50.140771865844734, 71.69374096778132, 60.17709732055665, 58.217598853572724, 1.9612527470434866, 0.22519416536294648, 1.2606171686803143, 2.728373480419959, 1.5567488848201692, 0.1771175669085595, 0.5603304361143421, 57.874724864959724, 67.71324126951157, 68.38928530293127, 63.747348477763516, 60.66909590075093, 56.78531400619015, 55.13348233315253, 54.61393302486789, 58.49456525618031, 59.73911370000532, 59.90608115350047, 56.85811711895851, 62.838056779676876, 60.87587148912492, 61.8287250303453, 57.832202449921645, 59.444884946269376, 55.71488741905459, 54.11922016451436, 53.32722694643083, 55.501228071028194, 36.65591816748343, 51.723393317191835, 59.396733930034024, 54.823936723893695, 55.31951642805531, 53.543702556240945, 51.9884043355142, 49.887202401315015, 49.56715660710489, 47.02506065368653, 47.785031641683275, 49.74422808616392, 52.91096933426396, 55.035062220788774, 55.43995280419627, 56.683414751483554, 50.26096505503501, 43.26959517694289, 40.532620183883175, 40.402224909874704, 42.39122352292461, 40.66341553964923, 43.100631237030036, 45.46055270779518, 45.97108448705366, 45.05260659802345, 48.24979720577117, 47.074886521985455, 47.397234747486735, 48.186486228819824, 50.81840838155439, 55.35646907744869, 52.67931415188698, 51.89544416243031, 49.18532171557027, 47.821866619971495, 47.72234039921915, 44.03790904629616, 39.75024461746216, 40.23232744586083, 38.766667150682025, 42.91464028819915, 50.0645641357668, 46.44573834634597, 40.71825419702838, 48.10120213416315, 42.804919827368956, 44.67136398438485, 45.520431610845755, 45.192984304120465, 43.75618480866955, 40.68867560355894, 39.036624277791674, 45.178844159649266, 47.395363776914536, 48.25579058739447, 55.974991552291385, 48.89348953000961, 44.967561767947295, 53.42666295266921, 45.50034515319332, 46.65258061501288, 43.70505671347342, 46.83787338195309, 45.00190211880592, 44.27932308566186, 41.59323692321777, 42.48487403315883, 41.17982302942584, 43.5358182076485, 41.66835031201763, 42.61967020650064, 42.881335443066014, 41.95856255869712, 42.24518191429877, 47.64442643811626, 50.12300745133431, 51.90898810663531, 53.86656068986463, 53.44670234187957, 56.60190789930282, 52.5080007122409, 52.759456019247736, 47.560648533605764, 44.56985696669548, 45.99157887120401, 48.9882775275938, 55.43557151671379, 55.4483074526633, 59.51872356476323, 59.32650389209871, 55.49241842762117, 54.59101853832122, 52.96667875782136, 59.54944356795281, 60.76513121204992, 58.55835083992251, 50.66674601647162, 46.6417391838566, 47.60013503413047, 61.17909031529581, 59.189817136333836, 66.94116976953322, 67.98037036772698, 66.20417210363573, 58.19543353972897, 54.64819492832307, 65.08983458242109, 71.56065494783464, 70.09058983095231, 72.02594218715545, 32.206573640146566, 0.23528031043467984, 0.2375296824761937, 0.050289002923114653, 0.8996312680744356, 31.595229102719216, 75.88362463058965, 67.22868734790434, 71.58301245781684, 51.81236836218065, 41.763063784568544, 27.89084661391474, 46.01593286760392, 51.156975607718195, 73.4601568406628, 8.206246081859835, 0.36765034460733015, 0.16412836229128225, 0.10203791662089287, 0.04436460368695759, 0.09595808963621817, 0.07997537347217722, 0.10835463331351358, 0.15097801874001182, 0.05737135937858013, 0.10687058310835593, 0.2589042250427508, 27.732120060151626, 75.13027852581394, 56.89007266875237, 62.323430045958496, 28.047762993843328, 45.15758099094514, 57.50920311097176, 79.70952803088774, 67.65174634995, 67.45793419499552, 2.6458686301785135, 0.27619743419270365, 2.0965853045063634, 7.058007515245869, 5.315770112699078, 0.30341623170721915, 0.3116297974221168, 60.46200260039299, 67.19932448479437, 71.86878850383144, 64.19818570536953, 62.93722998711371, 60.87694229618196, 57.949085158686486, 57.28514163724838, 60.62974668318226, 61.32750103550573, 62.67239155307893, 60.96672534942628, 65.46238130138767, 62.050272264788234, 65.02589994861235, 59.25801930889007, 62.23764781028994, 57.24067764897501, 56.38980965460501, 53.56677393759451, 57.88958280317245, 41.55144799140192, 54.001415698759025, 60.398852440618704, 58.58071227227488, 59.25379099384431, 55.296382288778986, 55.050873294953384, 52.641290695436545, 51.03642940521241, 50.28855500682708, 49.48162540312737, 52.9614463160115, 55.34641996506722, 56.132702212179865, 58.25869352586808, 58.169604732144265, 52.894699342789195, 44.09447354655112, 44.018928697032315, 42.17642668754824, 45.565111329478604, 44.15808262363557, 44.026593008349025, 46.659899757754424, 47.62782304517685, 48.45045389667634, 50.556880427945046, 51.13186459387503, 50.08702754974366, 50.96867046048565, 52.76562198515862, 56.6481291094134, 56.40954309894193, 53.534857611502375, 50.132425062118045, 49.67955604676278, 49.238936593455655, 44.93216629951231, 43.05940712651899, 42.101850663461995, 41.02737619030861, 44.16564887569797, 50.74314202031782, 46.845525926159276, 42.726621473989184, 49.564356034801854, 44.934084338526574, 44.956477149840325, 47.63225532347157, 45.02538534902757, 44.0832281112671, 41.80579016285558, 39.50419433655278, 47.659005888046764, 47.71790419855426, 48.2518760619625, 56.67502872405514, 52.566145927675315, 47.60777973359632, 56.929104174337084, 48.925178358631754, 48.82103158581642, 44.16766105159637, 48.93182677607383, 47.164293027693226, 45.40880487811181, 43.585522482472086, 44.131602702602265, 45.028374195098884, 45.474433975835005, 43.92027324245822, 44.13501516465218, 44.178918253990915, 44.677643699030725, 46.1481834227039, 48.277391079933416, 50.85674170524844, 54.87203282694663, 56.297916366207986, 55.27445623951574, 59.77218712529829, 54.35199714476063, 55.476254340141054, 50.03931976133778, 47.50231504440308, 48.681642317002826, 51.91318504271969, 58.29828593038744, 59.06984359987321, 62.1598122965905, 62.23730264171478, 58.073796918315274, 54.54883736948813, 53.8701065125004, 58.56439521235805, 59.58181488898493, 59.71936064381754, 50.875023872621604, 51.792352507191325, 47.969175154163, 63.47661472135975, 65.69412669827862, 67.55443234597483, 70.43921009186776, 69.7708539039858, 62.00601616213399, 57.48217013574416, 67.7604744511266, 73.935650087172, 72.37237376551475, 75.51928351002356, 34.61913331862419, 0.45025873929262167, 0.33672037203946426, 0.01456701345065789, 0.7977629633199784, 37.58315863147859, 84.69692368661204, 71.1626991148918, 79.97530783376386, 60.0044620421625, 46.75324824548537, 31.110430032976215, 57.151455494665335, 57.40267153709166, 86.67334325851934, 11.252753446179053, 0.3110856298477419, 0.13782424311484062, 0.03169617732055485, 0.07442907310060917, 0.2807671180175197, 0.1889803924507672, 0.18515421227822382, 0.2685892617990894, 0.25171248272301694, 0.32850512093113315, 0.3447391062734589, 38.945060468489125, 86.87083459669545, 68.70469877796789, 70.31642421599358, 25.313865100183797, 54.97986662772394, 66.0528862860895, 86.48685024630639, 72.81529565011301, 74.95425039722075, 3.1854813521908176, 0.35608162021925377, 4.219720152116591, 11.82666386327436, 5.175318862161329, 0.23805863554439238, 1.2143584509049694, 64.04564080699798, 71.22599047999229, 73.88963284031038, 67.7430042143791, 66.42398172809233, 64.87780694038638, 60.242051770610196, 61.47502530005671, 63.39882235373221, 64.72061403336065, 64.52672735337289, 60.66540495041878, 67.87564308412614, 65.3446670501463, 65.95391704190162, 61.63430098564395, 63.250905852163996, 60.84096239459131, 54.509676425687736, 54.942051056892645, 58.09529935159991, 39.680987327329575, 57.46673953148627, 62.47532383088143, 61.99138179902108, 64.18092727661133, 58.58386585789343, 57.662324597758634, 54.15297215984714, 56.068626373044914, 52.033939130844615, 51.1595682944021, 55.08787693515901, 58.93649478112498, 58.336580030379764, 61.24999107853059, 62.45254270492062, 55.27508774111348, 48.172797156918435, 46.64466134963497, 45.11928689095282, 46.516541050326445, 45.060235608008604, 46.032096955084036, 49.158990844603515, 49.39738073656636, 51.18900176017515, 53.22927359611758, 53.50844829313217, 53.920226558562256, 53.12418153209072, 56.136267646666504, 61.042340801608184, 57.8167796904041, 56.833719976486705, 50.94197873146304, 50.8746277132342, 51.628923031591604, 46.986460608820764, 44.22303707368913, 43.200082932749105, 42.17868205039732, 43.42388945241129, 50.53536622754989, 47.42141223722889, 42.81341175879202, 50.60757706242223, 45.87988545817714, 46.95821169883975, 49.82177726684078, 47.75636696046399, 47.356320504219305, 42.86833278594479, 40.05215729436567, 48.071368586632516, 50.7332262685222, 50.594288072278424, 59.26012169930243, 55.66568520761306, 53.744763251273866, 57.648506087641564, 52.30062500123055, 50.420119147146906, 48.00010696534188, 52.475044958053104, 51.9045558283406, 48.78198046838084, 45.60346818739369, 47.31859907027214, 47.54371566157187, 48.24152884944793, 47.42981787650816, 45.61643946555353, 48.23583356795773, 46.96538963625508, 47.84681289426742, 51.307410270937034, 55.221453251377234, 58.08376366092313, 57.18648226030412, 57.567309102704456, 61.95129517586001, 56.95924366674116, 57.885566296116004, 51.61497116088868, 50.03693496027301, 52.51764189812445, 55.48056502496043, 61.085553553796586, 61.4911501638351, 65.91370490289503, 64.12802234772714, 59.06745879880844, 55.576765075806655, 55.51356000284995, 58.22707137753887, 59.317254943232385, 59.4591349171054, 51.929827659360825, 50.86267625131915, 50.62554151781144, 64.59616899490356, 68.97056487298781, 71.15083786749071, 72.83313458965671, 73.68824266618299, 64.6510233417634, 60.62388666214482, 71.34544234122001, 77.04075521038425, 77.3299123394874, 79.58378468790363, 37.570328558644945, 1.1618966272761746, 1.3027294508872496, 0.12370063848192654, 1.7453876786654996, 42.753470097818685, 91.31558602856052, 77.62842824382167, 87.62164685033983, 67.58075144983107, 62.86585853945825, 40.22372176570278, 66.73456284307665, 63.4491071393413, 102.60044113282235, 17.058019176606212, 0.6423747142957104, 0.54916596100215, 0.21860614629282107, 0.14083467754385165], [0.12307744127728286, 0.027185455452831044, 0.008011689097920974, 0.0639960817211578, 0.026366497885676164, 0.015651883966770145, 0.18174410977911565, 23.276360496397942, 56.63578541048112, 42.75359169129403, 25.325141914429206, 29.866277748538604, 44.49003281131868, 51.32432353112006, 74.8355673205468, 58.68673001566241, 70.49816331555768, 5.2334116158946875, 0.21079093097679077, 1.2133225774572742, 1.7072072048341076, 5.250082179423302, 0.7960760377107129, 0.4159530768952062, 14.14851284796192, 65.79707714819139, 61.7022168251776, 65.64599529389413, 58.14502323827436, 57.382475253074404, 54.15080701151202, 57.8782981441867, 57.33098237745224, 62.97890909256474, 63.53615237820534, 62.53486541009719, 59.437467744273526, 61.60570298471759, 61.258965461484856, 61.64156521520307, 56.875587355706, 55.10246030745968, 52.99249972066572, 55.69217297338671, 51.962202902763124, 46.08460572458083, 55.88712261569116, 57.480208950658, 52.46143041118499, 52.78684985253119, 52.76737528462564, 48.15404822749477, 46.49422668641614, 48.611953566151286, 49.74058812664401, 50.04106521606446, 53.91201311542142, 57.91244237653671, 57.293237409284046, 55.258374521809245, 57.944609734319876, 50.39412952238514, 42.11690472018334, 40.86637073947538, 41.92295920464301, 40.96214325197282, 41.280400445384366, 43.03864209882675, 41.26107884991554, 45.23247864938552, 47.48267181458012, 47.25702570330712, 47.58782271415957, 53.30975278731316, 49.00443377033357, 48.49676139893071, 48.86476993560792, 54.16397833055066, 50.84228384879328, 49.769747026505016, 41.23697980757683, 46.26332459911224, 43.543859066501746, 41.08662359176144, 38.28504716196368, 38.35095867033928, 43.149378453531575, 51.02835716739778, 46.73706454615439, 42.37555757645638, 47.641088501099624, 42.885450009376775, 40.77940787038496, 44.85584874306956, 41.72335370894402, 43.33540470369401, 42.353262824396936, 41.84787327243436, 46.84969540565245, 52.23214434039209, 53.626813657822154, 52.10922510393205, 44.35943749643142, 52.023744890766764, 48.896384239196784, 46.644410317943944, 46.069841923252234, 43.858974441405266, 48.01499236014582, 45.372617090902025, 43.40769398596979, 43.341798167074884, 44.60120062674246, 40.54198288148449, 40.86241306797151, 41.781730344218595, 44.470260143280036, 40.99376540030203, 45.03804283757364, 46.387930454746375, 49.66548258258451, 50.650727056687884, 53.537618960103686, 54.24446536648659, 54.25485964744322, 51.70229488803495, 55.948017412616366, 50.03524049635857, 49.26427510476882, 51.02310119136688, 46.30673346980926, 44.7014642530872, 49.582336179671756, 53.728791359932195, 57.71961081412531, 58.60629004816855, 59.39073662604056, 55.63778538857737, 52.218141478876916, 51.54212490204842, 56.35899943690146, 60.88162168379753, 68.04478353069675, 59.35938512125323, 56.67648784575924, 50.6840907373736, 45.02995491027833, 69.73272062117054, 71.77829942395611, 67.96514372671804, 60.79967160378734, 58.02836410460934, 59.6047725216035, 72.43288809253325, 67.99604415893555, 70.4328715416693, 27.851093392218313, 0.12925974784358857, 0.04365606811798869, 0.064091294958827, 0.8792284467527944, 45.81073799440938, 72.34039860387003, 67.90808108545119, 74.79373132028888, 50.5477766067751, 42.06513335627895, 23.092656289377523, 29.092582387308923, 51.793705724900775, 71.46956966769311, 15.487835561075519, 0.4532692809739421, 0.10703005197067415, 0.06995410072587191, 0.1023677864202088, 0.1388396773367159, 0.04546588572162775, 0.03552397585383827, 0.20003710963553, 0.028638634229860002, 0.04842897591691825, 0.1296474955855839, 32.36403130715893, 69.42842314320227, 50.80164809380808, 38.3917317082805, 23.803068130247055, 49.020899880316954, 57.05503186871929, 82.67722468222343, 64.36593371052896, 80.16936317566903, 5.331942535215809, 0.05378134879133394, 2.02758762624956, 5.410932696634724, 9.4933174310192, 1.8706489378406157, 0.4973679065944687, 18.878899120515396, 70.19548969884073, 61.814902597858065, 69.80129149652296, 60.248664886720725, 60.748512129629816, 56.02319355933897, 58.90328799524615, 59.58700810709308, 64.56407223978351, 64.0132067280431, 64.30856904675885, 61.355381242690555, 63.30696436666674, 62.663880009805005, 62.8943153350584, 59.239042881996404, 57.73368035593341, 54.24204918646044, 58.480468257781006, 53.75814245593164, 46.9373486118932, 57.77950932902675, 57.64932194063741, 55.38325494335544, 55.00651521067466, 55.06145192730812, 51.722683368190644, 49.59932396488805, 50.35701997818486, 52.84177480205413, 52.83933508780695, 55.560934389791186, 58.80500124346826, 59.25994911501485, 56.74590203069872, 60.58616522819766, 52.90772945650163, 42.763919291957734, 42.947866685928844, 45.20054663381269, 42.556590649389456, 42.07786536985829, 45.1145290559338, 45.786407532230506, 49.20782043087868, 48.57712291902112, 48.14077100446148, 49.61901818552325, 54.35347587831559, 52.464776192941976, 52.102545307528594, 51.99652756414106, 56.14296705492082, 51.158309213576786, 51.19834484592561, 43.7227269910997, 48.104775413390136, 45.92706372660976, 42.87775824146886, 41.423386527645974, 39.878592414240686, 43.99919917506557, 50.831203153056485, 46.37371186287173, 41.468756583429155, 46.66974882925711, 43.992150675865915, 42.77754560593636, 47.79467282756683, 43.2268334973243, 45.44914253296391, 42.722793240701, 42.0026421546936, 49.120488858992054, 52.21111259152813, 55.997152943764966, 51.918644981999556, 47.58428081389397, 55.08206398256364, 51.15921135871641, 48.83615624520087, 48.16985930165937, 45.79539760466545, 49.01149011427357, 48.298697394709436, 45.92092913966025, 45.063263677781634, 46.13517292084233, 43.14885677829866, 43.711426642633256, 43.00159531254923, 44.735263316862046, 43.27844012168146, 46.343274270334554, 47.620390153700306, 53.2291990710843, 54.78463457476709, 55.52307175051782, 56.639323388376546, 55.37232722005537, 54.69800902951149, 58.280066520937034, 53.2913843277962, 53.649241770467455, 53.54780535544119, 48.573392744987245, 46.57929505071333, 49.755614726774155, 55.172866852052756, 60.68038055973669, 60.9745857792516, 62.02100353856241, 57.632906821466264, 54.29911967246763, 55.15054464340211, 57.97717717386062, 60.61555554789882, 67.72938574514082, 60.58469433938304, 61.474103543066214, 57.6082351130824, 48.60162596548758, 69.6609490917575, 72.21897771281581, 72.88047759763657, 63.15822416736234, 60.36536324408747, 62.59300278079126, 76.76309847062635, 72.26850155861148, 75.44269531003891, 30.172697228770105, 0.2275480930843661, 0.14599308461671875, 0.1444235543209699, 0.7180308610681565, 50.878714822953754, 80.31655403875536, 74.27135790548017, 80.72817540937855, 58.05057648689517, 49.05986470560874, 26.721582181992073, 36.11534887744535, 56.40649933968821, 84.92732371053388, 20.99873427421816, 0.4490724981071488, 0.2756397834708614, 0.03520687290978047, 0.10381416042125034, 0.2409246011126426, 0.17197126402489601, 0.08246325932803654, 0.2270224341942418, 0.11425585455952153, 0.12773825126069208, 0.2880440339926751, 44.0683505612035, 79.93240494881907, 58.248707171409364, 38.38337705981347, 43.799052392282796, 64.0436403982101, 63.0290291386266, 89.8666467974263, 71.0213839623236, 87.74938275737148, 6.277685309610059, 0.5512407722492372, 3.9673254374534856, 9.139999151229858, 13.528130189065012, 1.2632059329940428, 0.382840764979201, 20.129146768200783, 75.53994655609131, 64.40836198868291, 73.7144519436744, 63.59240701121669, 62.81976284519319, 57.14862746577109, 62.46445886550411, 61.890674944846864, 67.13737457029282, 65.89022559504356, 66.54944266042402, 65.01912209295458, 66.20129308392926, 63.80897283554078, 64.82846352361864, 61.704440809065304, 59.497887934407885, 55.65242367406046, 59.58266212094215, 55.07080285779892, 50.50563466164374, 59.271292609553186, 63.40241524481005, 56.27298970376292, 57.452552318573005, 58.89037163026872, 53.377543111001295, 52.216411713630926, 54.280857116945334, 56.812860811910326, 56.42309096551711, 59.709790060597086, 62.19372118673017, 62.69440781685614, 59.686008730242335, 63.3523932580025, 56.20553278153943, 45.12950858762188, 44.891899247323316, 47.57303930098011, 45.71239632944907, 45.82339156058527, 48.67515079436764, 46.548096518362726, 51.53292694399434, 52.401108280304946, 50.94998428898474, 53.1366232902773, 59.196696973616085, 55.630160300962395, 54.605688202765684, 56.382259092023304, 59.00256318430747, 53.76937220173498, 55.712792873382575, 44.76588133842715, 48.64419152659755, 47.3764971763857, 45.873390013171786, 42.222283117232784, 39.940405045786214, 45.53425404333299, 52.99068366327594, 46.0099277188701, 43.613214415888635, 46.004997299563506, 44.814436358790246, 44.615011292119185, 49.452423357194476, 43.323845478796194, 46.448225129035215, 44.730984011004054, 42.62139212700629, 48.71991680514429, 52.18556227222566, 57.43097143788492, 55.70272807152041, 52.496778811177904, 57.93935375828897, 53.38684305067986, 52.070468164259395, 50.304417071803925, 49.707530390831735, 54.34672547924904, 51.66302411786972, 47.39534024269351, 49.34191842232981, 48.45006165965911, 45.214251395194765, 46.05218733510664, 45.4746183272331, 48.05083497878044, 44.95499841628536, 49.520743200855875, 51.836334043933505, 54.10307176651494, 58.76323192350326, 58.23090353319722, 60.46259487828901, 57.74882462716872, 57.52100552282026, 62.291270532915675, 56.99236023810602, 54.636584712613015, 55.71934715394051, 52.21219908806586, 48.90813173786287, 55.29316986760786, 58.66619640781034, 64.44130597576019, 64.559553669345, 61.39837826451948, 59.645663230649895, 55.95718791407924, 56.45994555565619, 60.900727548906886, 61.83900164019678, 67.16805534978067, 60.203345821749785, 57.80591864739695, 52.55925040091238, 53.997497250956876, 71.09324962862077, 79.07786169359761, 75.41467389752789, 69.2927562036822, 63.30510124083489, 67.29965086906188, 79.63882338616156, 77.16196429344916, 79.39039614892776, 34.36728577460013, 0.9095473263052203, 0.44583712494181055, 0.331714355176495, 1.8484214789444402, 57.050336791623025, 86.60234835840042, 81.70887777882238, 90.79118082600256, 64.45794859240132, 61.18807254299041, 33.59553198660574, 43.81325529467675, 65.58645371467837, 100.35994406669371, 29.31813043932761, 0.663447893194614, 0.4798054635044067, 0.17162543661411733, 0.466799742031482], [0.01459660838478275, 0.053643640656504905, 0.0852324603305709, 0.05295601928786886, 0.0785644386985129, 0.04623691108258021, 0.3013539843020901, 31.515965846277055, 59.875145419951416, 45.06359315687611, 40.997060191246774, 29.695487945310532, 39.7677933016131, 52.60887622833253, 75.66885917417466, 58.334979703349454, 70.31807161146595, 10.156173475327032, 0.4084527390378137, 1.6464364528656008, 4.0879508228071275, 8.092593935228164, 1.2656691814622572, 0.3016280292743637, 6.771796086142141, 61.8320276660304, 62.813706705647135, 68.11435068807295, 57.1814694712239, 59.639728684579175, 57.27253906188473, 60.936295601629446, 59.879977780003706, 61.70384460879911, 59.50033549339541, 63.446855698862386, 59.571961895112075, 61.11009582396477, 56.464966189476755, 56.17808011270339, 52.569570156835745, 56.18091990870815, 56.75072654601067, 58.00935237638412, 53.08272992410968, 52.776592854530584, 53.797554431423066, 53.81375382023474, 52.11704238768547, 54.54438155697238, 48.93169733785814, 48.44096960559968, 47.60458300190587, 49.730280137831166, 52.0652671014109, 55.089900878167924, 55.396594924311486, 60.135618255984404, 53.97136642086891, 59.02486578110726, 54.4335118416817, 47.06480210827243, 39.10145321199971, 42.11926206465691, 40.04102168544647, 40.45109764222176, 41.659034682858376, 40.74874278037779, 40.946355712029245, 44.38676464942194, 46.29547234504454, 48.52719114672754, 46.662665028725904, 49.93157225270426, 50.57546069545131, 51.395498860266905, 50.49786052396221, 48.27472386821624, 51.52534500245125, 52.463921116244414, 49.322710575595984, 46.984138565678755, 43.95953224551293, 39.59412251749347, 39.40426411167268, 38.18232813189107, 39.848460766576956, 48.328064180189564, 48.92598636688725, 38.794162965589955, 47.239261288796705, 43.36082558478079, 41.47646796318793, 41.31688241035708, 43.109778204271876, 42.7242523624051, 43.422595070254424, 49.269758578269716, 52.71771023350378, 48.45236409095026, 47.848534814773075, 45.79174587803502, 47.853441699858635, 49.779290153134255, 46.247533136798495, 48.7638081273725, 47.367103099823005, 46.96719784890452, 44.406313742360766, 46.245230705507346, 40.81639974348007, 41.689291846367624, 41.97549150836083, 41.8081396625888, 40.14032040872882, 41.72163178843837, 41.203384707050944, 40.799168771313084, 44.56200438161051, 51.73399548376761, 52.741346436162154, 51.42923908848917, 53.208834125149636, 53.223574392257206, 52.60317310210198, 55.151172222629675, 51.12790300000099, 72.19948353305941, 65.5649983498358, 52.18757444812406, 52.433307017049486, 45.20065253780734, 47.73735523223878, 52.165354221097886, 54.62354283179007, 57.07249818309661, 56.800917194735625, 58.66728290434807, 62.305124344364295, 62.68355069621917, 59.65688905408306, 62.069880193279644, 58.62343080582158, 66.47771035471271, 66.9047466401131, 46.84515722336308, 58.73283747703799, 64.99653708550238, 65.62761898963683, 67.41003421045119, 62.430298943673414, 61.00459191106982, 57.780733108520515, 70.67540737890428, 66.08477515559044, 74.44911972168954, 26.54099233688847, 0.10853090248401127, 0.24966880528917237, 0.1507951229089691, 1.0182956522030215, 53.27007016827984, 74.0616915302892, 69.82575139691754, 70.43056518800798, 51.359311073057114, 38.43463067085513, 33.60767564465923, 39.8026200263731, 59.4348789799598, 72.85723363199543, 18.877149743418542, 0.5476407718754585, 0.2045253123487196, 0.09516156503870603, 0.1660030407290305, 0.056918455858624754, 0.005723673666286613, 0.020735343700395, 0.02505572144723227, 0.06972377639143698, 0.11269263682826874, 0.36628836285202737, 41.62132501602173, 70.85691898099839, 52.17405796051026, 50.04952184615597, 26.18611001199292, 43.66663709763558, 59.584564470475726, 80.44125403127363, 63.188614691457445, 79.67782743515508, 10.71106824182695, 0.3323221999791361, 1.194401799190429, 7.757237169050402, 5.4396978885896745, 2.9611002052983935, 1.7708193462702537, 7.8145361331201375, 68.43261180385467, 63.59720799230761, 70.18791952440816, 58.29335943345101, 63.117749229554214, 58.75900360845751, 65.11985640372, 62.91589229337631, 62.50287063660161, 62.432079699731645, 65.44644863374772, 63.6584440354378, 61.21039082927089, 58.654150809011156, 58.17074614186441, 55.15633406177644, 58.0402998770437, 57.36511092032156, 58.42237403315883, 55.1464928350141, 55.20981950144614, 57.68471740907239, 56.64120612605926, 52.191845909241714, 59.31525061207434, 51.24403261369275, 51.31416459237376, 50.47965680399249, 50.89611837940832, 54.95362597127115, 56.79872066743913, 56.525472671754905, 62.65314056027321, 56.0245075533467, 60.41833093089443, 54.58979475882746, 50.48585022649458, 41.482622161988296, 44.76306507664342, 41.51308721111667, 43.00223073651714, 43.51254678541615, 40.847194271702925, 43.756890835300574, 48.20370543387629, 47.42304394322057, 50.02832535774478, 51.70671932158932, 53.758471935026115, 54.286403348368985, 54.29485605609033, 54.75711130326795, 51.97640580515708, 55.679562553282715, 55.70316345460954, 49.706173250752116, 49.73476340693813, 45.94134115403699, 41.9539184724131, 40.12579194961056, 39.62679586102886, 43.44296786092943, 48.458937983359064, 48.68814560674852, 39.85681541504399, 47.6122159342612, 45.08856688776324, 44.20194256690241, 43.13259463156424, 45.61704351056007, 43.77553386072959, 44.56002750704366, 49.21327644778837, 52.244366445849025, 48.638413875333725, 48.61857844937233, 50.298600196838386, 52.22213052934217, 51.771367826769435, 49.38229922325381, 50.425822273377456, 50.67601849955898, 50.14925203015728, 47.345212351891306, 49.61488008499146, 45.69283939176991, 44.53049598201629, 43.56503594306208, 43.52643197582614, 41.56741203800325, 44.15312867010794, 44.201185549459154, 43.30816384284727, 46.67198458025533, 52.918610111359634, 54.76066104827389, 55.55183449099141, 55.56485283759333, 55.8448237757529, 54.256824754899554, 56.621351088246996, 53.74001718336537, 69.15159010118055, 65.29009903630903, 55.78407410652407, 53.26667339571061, 48.72551010501001, 49.988376017539736, 54.161585684745546, 56.18546201336769, 58.77690530592396, 59.16278416110624, 60.110962237081225, 65.46808834998839, 64.0313986809023, 62.56271031595046, 66.92785724516838, 58.83710976569884, 66.87048865902808, 70.88874509257656, 48.21566474053168, 61.33436910567745, 67.48256667967766, 67.88093828385877, 70.15601496542655, 66.28538870042371, 65.61332587272891, 59.080779167913626, 75.57240024689706, 69.75871809067266, 79.28477456492763, 28.691818137322706, 0.1478035802081708, 0.4756770156804593, 0.07768294728931882, 2.2729541890082823, 59.19894056935465, 80.40464262808524, 76.93808324875371, 78.70242026544388, 57.73063267430952, 41.31127342101067, 28.896942407854144, 43.84546579853181, 64.28971421334052, 87.79395657200968, 23.526170369117494, 0.4435733657690787, 0.36404090603032424, 0.16692688147867882, 0.19102851319457256, 0.1840737525133356, 0.11931836274602722, 0.16180634979278813, 0.14485437152606828, 0.23457284355836533, 0.3261572146607984, 0.8607314683256612, 56.14242969020721, 84.46780235536637, 61.99816357704901, 56.25538610642957, 39.87867870638448, 54.86562759645524, 66.53497695922852, 89.0974307829334, 68.54888654524281, 87.60327446845271, 12.60067399471037, 0.6065547718636451, 4.3339425133120635, 16.849431453212617, 17.467773499027377, 8.371952003048312, 1.515721260539947, 8.710291731742121, 70.27011671373921, 64.16914839898386, 74.96979082784345, 61.60110204450546, 66.48383709692186, 62.326501261803415, 67.43079923814344, 67.15219328480383, 63.369977243484996, 65.32519640461092, 67.41595698941138, 64.20614027207898, 65.16344178107478, 61.47904180711316, 62.014814038430494, 58.75551269900415, 59.246385558958984, 61.99786155454574, 63.81863755564537, 59.21126073406589, 57.44563325758904, 59.35585498809815, 59.347331677713704, 56.15589910937894, 61.105400746868504, 54.60184427999682, 52.85014514000186, 52.83875065465128, 56.19337735637542, 57.06291191039547, 59.47732294759443, 57.849888417028616, 62.8057207599763, 57.08651673409247, 63.909012886785696, 59.07919845273418, 54.6004008477734, 45.26119039904687, 47.50877518807688, 44.167276659319484, 44.279107355302386, 46.66948603045556, 43.46007723962107, 45.32844728039157, 49.08697612823979, 51.67534036021079, 52.47320144407211, 55.92868797240719, 56.382102197216405, 59.0914519371525, 56.79815976850448, 56.593737602233894, 53.68772414422805, 57.9241898752028, 57.31860337718841, 52.648778500095496, 51.3249275761266, 48.6473725688073, 44.26286482041882, 41.97640542061099, 41.463304488889634, 42.821538909789055, 51.0545232988173, 50.25754867061492, 40.41683573876658, 47.295468853365996, 46.06122447598366, 44.877923842399355, 44.1846017683706, 48.56886240743822, 46.089806787429325, 48.11411065440024, 53.58002370403659, 55.67811519868913, 52.60305935336698, 54.26191599138322, 55.46426365452429, 54.39817128642913, 54.222402034267304, 51.662867223062825, 53.64598620322443, 53.21301537175333, 52.236364810697495, 49.472090121238466, 50.41580061758719, 46.09272503083753, 45.44996230832992, 45.98211419197821, 46.23928831469628, 45.06184770214943, 46.122166341350926, 46.36410597831973, 44.25357664785078, 49.28775049025013, 57.55074101109659, 58.51051753567111, 57.330197903417776, 59.56139895223803, 60.09588856850902, 56.45982003981068, 58.358294271653705, 57.00060506020823, 67.67407248097082, 66.94127959589805, 60.859848606971006, 56.05860079488447, 51.94184972393898, 52.54487099186067, 56.877846640925256, 58.854736897253225, 62.199969522414676, 62.199651810430716, 61.83267485710883, 69.13925032461844, 67.47618890577748, 65.4789533153657, 68.72395761551397, 62.52968003672939, 69.44441856876497, 66.78642442149501, 48.689149733512636, 61.66313040641047, 71.52776195156959, 73.19417307453772, 72.62419777531778, 70.84441446488904, 67.93427467346191, 63.13017137588994, 77.28021590940415, 72.9164457321167, 81.97868193349531, 32.139559945752545, 0.4511152255919672, 1.1304219355506282, 0.46095277513227156, 4.640738541080106, 66.31050755900722, 89.88307368370795, 83.2563312592045, 86.9069282470211, 67.74192164021154, 58.71855612724059, 46.0355447184655, 58.36505643783077, 73.94462447012626, 103.08676012100713, 34.88775683987525, 0.8465957978079397, 0.6149004111366888, 0.29119210377816235, 0.28431150040799574], [0.045467046344833034, 0.053831864629061, 0.03553094725394922, 0.06976326822393364, 0.0441363439594786, 0.08246075422052415, 0.8995237706169006, 36.64374313046856, 58.489725051387666, 46.82334492283483, 26.930399364040746, 21.433427026194913, 43.883508866833104, 47.84961738894063, 79.931196858806, 53.85406009612545, 75.53259603438839, 14.345998302582773, 0.08105404059132261, 0.9596578115897795, 3.036952960875727, 6.817565243090353, 5.749937757369011, 0.8159085218944858, 2.5794366723106754, 57.06713630307106, 61.46025757635794, 67.53976268153038, 62.69849884894587, 65.35224899168938, 59.12083833448349, 62.26411596421273, 61.8621632360643, 62.25445908884849, 63.31230271247126, 59.329763381711906, 54.947161905227176, 55.72004925820136, 52.89209488899478, 57.42966921098771, 55.68199442278955, 61.9851726870383, 54.21586344319006, 59.92999192207091, 53.79687193901309, 54.89113084731564, 54.070108167586795, 54.71908392444734, 50.59639830743113, 53.67978526699928, 49.093495107466175, 52.686947084242306, 50.912266777407744, 55.17835424792383, 54.52049040025281, 53.19370162102484, 60.80748496517059, 56.103284435887495, 55.69898613037602, 56.9782946186681, 51.706225102947606, 42.84472011750744, 39.34692690449376, 39.42659808743385, 39.10963135380899, 40.711896034979056, 39.65747664051671, 41.77380715647052, 39.96502576335784, 42.774521458533506, 47.35123319010581, 51.932855729133856, 49.457028219776774, 51.909788270150464, 49.87003026470062, 51.12423558388987, 52.67936514269922, 52.11679527836462, 50.71764661419777, 49.994224271466656, 53.957222354027536, 54.48645991663779, 46.97957292679818, 43.80420246431905, 40.41376844529183, 40.54355182955342, 39.28684403819423, 45.6913096674027, 45.94623234964187, 41.923108254709554, 50.22717775837068, 42.743020903679636, 42.527769073363274, 43.83023915752288, 43.43219311006608, 44.89775926836076, 41.41213716999177, 44.61221856455649, 51.94443848825271, 49.082312430104906, 49.156480527693226, 52.319883838776626, 51.035013429580204, 48.27036219258463, 47.9182667116965, 48.14486595892137, 47.04069914356355, 48.15584859540386, 47.98411546214935, 45.36398395415276, 40.06142585508285, 42.7751608048716, 41.65257453918457, 40.169298879561886, 40.58439939252792, 42.54148952422604, 41.15568476338541, 41.216375597061656, 47.60933299218455, 54.522871278947406, 52.475080259384654, 53.981933286113126, 55.444961670906316, 52.239086935597086, 53.502141121895086, 55.37724194988128, 53.53266108420588, 59.841362045657256, 56.049430293421594, 57.10307698095999, 52.16768410898025, 50.111448226436494, 49.00564186034664, 48.2007283549155, 48.33049212732623, 53.63866313811272, 55.01110830614644, 56.07705162417505, 54.86766330657467, 57.68175601959229, 56.09982098302534, 60.83050143334174, 59.96911756453976, 62.66566076586324, 45.75694660986624, 58.71481026372602, 61.32438667358891, 63.5724421470396, 67.54318298832064, 67.94379034349996, 63.74878798761676, 68.13112274292978, 63.941082185314556, 70.70331112031015, 69.02828647244361, 71.09281032316147, 21.181108797750166, 0.11456193732878855, 0.5583667382597923, 0.07050017585917827, 0.9442660633114077, 58.55118466961769, 67.24607129250803, 65.45473660192182, 68.82067541922294, 51.417409220049464, 48.669326074661754, 36.67338448186075, 29.868844939816384, 47.83036247376473, 78.15219017767137, 22.534779540954098, 0.4739537468600658, 0.1832629863413111, 0.044941850937902934, 0.050442959782817674, 0.08754311174514794, 0.08932864053114768, 0.019620735566281987, 0.030474274742206743, 0.06881718028096423, 0.07581826629898242, 1.0148466017938431, 50.45645990679341, 68.38643766218617, 54.856492396323915, 39.338199630860366, 22.068097899037024, 49.63218165982155, 53.62792761095109, 85.61689992104807, 60.6180384082179, 80.97414724288448, 16.69451940444208, 0.1457506024669255, 0.2755535526141044, 7.556641274882902, 6.136881536053074, 4.614017394281203, 2.423919107644789, 3.2999701894098714, 59.38543358156758, 63.214859270280414, 70.25147761068037, 64.10463717675978, 64.85316661096388, 61.13214346670336, 65.06741823688631, 63.62567655501827, 63.235628220342825, 61.79191358627812, 61.53899915756718, 57.71353114035822, 57.61787629896595, 55.45487350033176, 59.57514293732182, 58.83086927475468, 61.3475678813073, 59.40843828262822, 59.22656974484844, 56.7591949432127, 55.306278428723736, 56.67179669103315, 57.15681737469089, 54.56402478679534, 52.99575921027891, 50.30492697992633, 53.71401971386325, 53.47189572549636, 57.5525962921881, 58.11595455292733, 51.83454544313493, 63.507879934003284, 59.19892095750379, 56.64782708691013, 57.43620780206496, 53.642895375528646, 45.327211733787294, 42.125400573976584, 42.395855842098115, 41.75235179162795, 43.04063466287429, 41.98874519717309, 43.13820362091065, 42.1963954740955, 44.805595336421845, 49.089647262327134, 53.61760393265755, 50.21014682708248, 53.54150995131462, 51.19776433514011, 54.414892350473714, 53.80409302250032, 51.885096949915734, 50.81120298754785, 54.0361600537454, 56.477156915972316, 55.9848641580151, 49.0705257077371, 44.171842298200055, 42.11148008223503, 43.4027910232544, 41.734501084973736, 47.484538862782145, 47.7569749278407, 42.361766522930516, 47.496662908984774, 45.26896845909857, 42.78985008116692, 44.77602851006293, 45.60163251815304, 45.42903254109044, 45.85051082795667, 48.717633985704, 52.48412524500201, 50.97975115622244, 53.5324728104376, 54.651164162543516, 54.84115592895016, 51.89402426442793, 51.41456942404471, 51.90416751369354, 49.0103526269236, 49.976930541376916, 49.43380778835666, 47.64362627460111, 43.610735477939734, 44.51178235392417, 43.35751510435536, 42.89474994905534, 42.09838721059984, 43.10768365859986, 42.63087249571278, 43.397370307676255, 50.102760176504816, 56.52349971955823, 55.207987754575676, 55.19623241116924, 55.75327173356087, 55.00156910188737, 56.1951934137652, 56.131003825895256, 54.331024231449256, 60.018574730042495, 56.242328536125925, 58.14108910099153, 53.41346809940954, 54.00332197066277, 52.1253695795613, 51.34255078531081, 49.32255760315926, 56.01980855388027, 56.295543332253736, 58.97808367206205, 58.58654091435095, 58.899055757830226, 59.27848623644922, 63.134525206781205, 61.601105966875636, 66.51296461782148, 49.6223835791311, 61.009235997353834, 61.71492138216573, 64.92754259417134, 70.37929196511546, 68.70038417077834, 67.02700691838419, 69.90317113937871, 65.37740315160444, 71.56330647007113, 70.31009351053547, 75.77156251476657, 22.30405003793778, 0.10663359380897977, 0.45618216176667525, 0.05359302905778732, 1.6533372503134514, 65.39708560512912, 72.20553182786512, 73.60042864276518, 76.6465413185858, 60.86630482827464, 52.35727971599948, 25.37603858978518, 35.67769081361833, 56.92283230443155, 90.20047972279211, 29.733566314943378, 0.7021037705482975, 0.22163910370680595, 0.06525662577440662, 0.05253713390219116, 0.21649408785085525, 0.23400088231409752, 0.17350153997540477, 0.16898240263183273, 0.17968909424399176, 0.2062590765736757, 1.4483266059429416, 62.07464979540918, 79.38424587249756, 63.92932291953795, 40.226420356381325, 32.90760317156392, 64.25287531268212, 60.88553620922951, 93.21922994429066, 64.48436575551187, 91.75442864817958, 18.04905306908392, 0.19879678264260295, 2.7388329707807113, 17.352495039663008, 18.02374005317688, 10.889231120386432, 2.866805200615237, 4.213608609091851, 62.73942093695364, 65.24267758092573, 72.37567640119984, 66.34640509082426, 69.74553108215332, 64.208462315221, 67.7012937299667, 67.00040540387555, 64.38474147550522, 62.94315276607391, 63.55692917300809, 59.72037653769217, 61.15605031290362, 59.152417336740804, 63.40466668528896, 60.420652974036436, 63.633034921461544, 58.0099368095398, 62.474723708245065, 57.37317139102567, 58.005492764134566, 59.10334456351496, 59.88638693286527, 56.15718172442529, 55.402317662392896, 53.33304774376654, 57.95960495548864, 55.595682667147734, 57.85877258546891, 59.514377578612304, 56.625273458419315, 59.988874543097715, 59.7732343981343, 60.331207244626945, 61.35262773882959, 57.49572192468951, 48.3417179507594, 42.81710270912417, 44.81915104773737, 43.72841050547939, 44.99516348684988, 44.143683602733, 45.714490875121086, 45.38790256746354, 48.61953943006454, 52.00925565535023, 57.07349838749055, 54.153399698195926, 56.64478332765641, 54.11033599607406, 54.79944544453775, 55.30155589503627, 55.681598263402144, 54.90046216595558, 56.99836146446967, 58.45748316857123, 59.520119928544574, 52.556520431272446, 46.77414663376347, 42.74650396839265, 43.14942552197365, 41.96780758519327, 49.583693319751376, 49.27811714910692, 43.81012916564942, 48.980122920005556, 47.12817584314654, 44.75572632205102, 47.92346385217483, 48.40264804901616, 46.007982223264634, 45.45348067437449, 49.57367558633128, 56.19953547754596, 54.325713342235936, 54.18222911896245, 56.848217056643584, 56.75878309434461, 52.840178397394, 53.966906685982984, 55.12868919680196, 52.424112981365575, 54.06105925959926, 53.77221984248008, 49.13955550039969, 43.96246225603166, 47.43343430180704, 46.73203998996366, 44.18534701870334, 44.95418256328952, 46.90133340897099, 45.68837965688398, 45.93169996815343, 53.238534312094416, 60.88588137780467, 58.390524387359626, 59.11031069294099, 60.25434055636006, 59.0267171398286, 58.12772950818462, 58.26274141188591, 56.468657139808904, 59.32921817225795, 56.913912834659705, 61.2975537392401, 55.87497111289732, 56.510304866298554, 54.27329870962328, 53.28721092593286, 52.15031193148706, 58.983849556215354, 61.64233792212702, 61.59375544517272, 62.0907275907455, 62.051143030966486, 62.0243767769106, 66.48167979332709, 64.88982508259436, 66.70720823349492, 51.34515523910523, 64.96736641853087, 62.72350788116456, 65.32301164442494, 72.13224626356556, 73.56801417566115, 70.4933152660247, 74.13839740137901, 70.16968834784724, 75.19165577427034, 77.09651562475389, 79.08014451303791, 26.354975892651467, 0.399145781993866, 2.1060360102884235, 0.39954304454788087, 3.1151461457052543, 72.05786243561776, 79.70251483301963, 78.39488290971326, 83.51829851827314, 67.10951005258869, 69.31841634934949, 48.00839101114581, 46.53362689479705, 65.80664773141184, 103.94231534773304, 37.337531966547814, 0.6697746149955258, 0.35288737065369086, 0.22280542660624753, 0.17442285263490293], [0.07000056395847952, 0.050815833927763086, 0.045925320141137614, 0.07715364948155419, 0.10899046330802864, 0.12218263525996478, 0.1271540862357905, 39.322286575071274, 62.38612521079279, 41.7509279712554, 39.229236187473425, 26.523755481166226, 30.156986175044892, 50.654559212346236, 71.57067268125473, 56.40259265899659, 68.2955720347743, 23.313346485937796, 0.40042689550788174, 0.6595273616333163, 6.603909817434127, 0.6276867250280996, 1.6976982763698025, 1.1988066208939399, 1.278416271651945, 44.78631296465474, 65.97914572684996, 59.590593153430575, 62.290642953688106, 63.60931242665937, 61.75107386804397, 60.70960613989062, 61.29774985774871, 60.45826458161878, 57.193385631807395, 61.13336724619712, 52.90973771002985, 56.33180172212663, 56.44415017097228, 59.91772667054207, 56.664693278651086, 59.139202871630275, 55.00179267698719, 53.980631059215916, 53.92246623193064, 51.86119794845582, 51.115845634091286, 51.345312133912124, 50.09317782617385, 49.053200598685976, 51.61894059950306, 52.336824555550855, 54.48170992635912, 54.57619197906987, 55.76288154048305, 66.72281926678073, 50.04599563537106, 54.83134215877902, 56.39341431279337, 53.98078795402281, 46.616651704234464, 42.97311498272804, 40.55403632502402, 40.96538312973515, 44.931440661030436, 42.27513705530475, 40.70138408291725, 38.83866617756505, 40.28846048539685, 40.04258278877505, 44.76604607797439, 46.84228997076712, 48.178531662110366, 51.3656613903661, 49.573534381005075, 50.48898812263243, 51.604635715484626, 52.67048881899927, 49.13544877882927, 52.7034681074081, 50.41784025007679, 51.677964425856075, 54.44591829853674, 49.50799157542568, 43.68346798804499, 43.28337054098807, 41.00569725036621, 41.316482328599506, 47.53793016556771, 42.7539917730516, 50.752724370648785, 42.0828507023473, 41.42530456666024, 43.22283267974854, 45.930213389858125, 45.870275651254964, 50.083364056002715, 49.40999115667036, 47.51498037768949, 51.51156571603591, 48.49909520918324, 51.1472834310224, 49.81233219946585, 48.757681385163345, 49.42851651099421, 48.302349121339866, 47.68977688204858, 47.77286837177892, 48.02975223910425, 42.79610233922159, 41.68649519643476, 41.361573896100445, 40.62658448373118, 40.821271327234086, 40.546736794133345, 39.870371126359515, 41.3146545040992, 42.125808500474506, 49.28997055176766, 56.21201645943427, 54.12918690712222, 52.3409979574142, 55.800493148065385, 53.65500765462076, 53.57705054744598, 53.71698110334335, 56.97345049150529, 44.339994307487245, 47.80723225685858, 54.078666779302786, 55.2413357457807, 54.83332687808622, 52.808893572899606, 52.346148029450454, 51.649495863145404, 52.78799910699168, 50.33070479669879, 53.315020530454575, 51.8714863254178, 55.207348408237586, 57.20791016855548, 55.76539185739333, 59.031059203609345, 53.19341921037244, 55.59929909244661, 68.13860662521856, 64.20209238606115, 60.41505182943037, 60.203738058767016, 73.46934303160637, 66.3807415193127, 68.17070730270879, 64.505401426746, 72.25332198604461, 66.08572436917213, 86.28660540426932, 14.538427822051512, 0.06501599755739013, 0.10432343269067426, 0.1648843531767207, 0.8757586200391093, 62.42883589959914, 68.85731035663237, 67.47755389059743, 74.67489134880805, 45.42122702444754, 52.448110042079804, 57.884260146848625, 33.09311951360395, 58.628282777724735, 77.3935410284227, 15.596803907425175, 0.7287798100902189, 0.26373394975258463, 0.24773754359733677, 0.02415752357562944, 0.04170894074524122, 0.04262009124842383, 0.0019234068965869808, 0.09627770917910723, 0.04773771563064187, 0.08985325754169496, 0.1556470182033316, 48.91726301562402, 72.0501353663783, 52.04314493363904, 41.96292031195856, 27.364776365218628, 41.758039228377804, 55.34910678863526, 80.04751082389586, 60.453051751659764, 77.77443455111596, 25.93658058874069, 0.3616659721780208, 0.29740657837640855, 5.538518082711005, 3.2422213785109983, 5.718836793976446, 2.712656297991353, 1.788560349133707, 50.526662488137525, 67.07245149920064, 65.01562726113104, 64.56099317919823, 65.82245488320628, 64.76705097383069, 62.024792548148866, 61.60654237193447, 61.546945879536295, 58.406308004933024, 62.38217930639944, 55.50556621243877, 58.10512096651139, 60.51731194219282, 60.019057181573686, 57.79986643022107, 61.741593499337476, 57.51167028181015, 55.863784513165875, 56.241277340919744, 54.715043883169855, 54.57001424604847, 53.08076873902352, 54.91986613119803, 51.798467482289965, 52.76727722537134, 57.13727220412224, 55.397791247214045, 59.25356349637432, 55.92182774697581, 64.02710760793379, 56.83055854612782, 56.47855720212383, 60.083595860388975, 56.05763981419226, 48.830135406986365, 44.56864887668241, 42.0565394432314, 43.0652436133354, 44.96986812160861, 45.225783163501376, 41.84731237349972, 41.21726989746094, 42.06472542978103, 43.171771264845326, 46.491508483886726, 48.2365317498484, 51.914173480003114, 52.08700487690588, 53.238432330469934, 53.9273182038338, 53.951036776265795, 54.198848201382546, 52.30590451148249, 54.59726295163555, 51.80471581797446, 54.85071082268992, 53.118996158722915, 49.50900354693013, 45.56802565051664, 44.42702385687059, 42.17293970046505, 43.678961184717, 48.79745029634046, 43.27525515710154, 51.3993820067375, 44.61830216069376, 42.58861680184641, 45.321237964014855, 48.2785834804658, 48.27657914930775, 48.365589495628114, 49.32604066787228, 50.804334917376124, 51.200353099453835, 50.855521848124845, 51.94678798798592, 51.659733249295144, 50.241443418687396, 52.60121191701582, 51.58605152560819, 51.48873752163303, 49.43048946319088, 48.50800683421474, 48.88828454479095, 42.4139928817749, 41.48099830073696, 44.00167811301447, 42.482140141148726, 43.364422398228804, 44.02712252832229, 42.34861481574274, 43.09697558802944, 51.888411352711344, 58.33237524955504, 57.22750632993637, 55.62020532546505, 56.59713437480312, 54.19631042788106, 56.68232041020548, 57.61446775928621, 56.92264010829311, 47.73024005274619, 48.65544480662192, 54.57246964977634, 58.467277326891505, 57.712166155538256, 55.62160561161657, 54.582954145246944, 54.40656908096806, 55.851244695724986, 52.164624660245835, 56.02495470354634, 55.79402908202141, 58.2517626977736, 58.95775794982911, 60.09337040685839, 61.53620250763432, 54.633925345636186, 58.207757626810384, 69.41347891284575, 66.82165515038275, 62.39630376138995, 62.03685383642874, 75.89394046414283, 70.5643964582874, 71.24906970608619, 67.75215118162095, 74.22529359017649, 70.0171003034038, 87.76192649718254, 15.309311824460185, 0.07976897406361758, 0.4310624145211712, 0.1667306557177536, 1.0180158768930743, 66.4504498820151, 74.57099560768374, 73.7124829138479, 79.56079959869385, 54.409416721713164, 51.22350292821085, 51.57609262774068, 41.28083190610332, 61.71389372118058, 89.65352873648368, 21.51105465427522, 0.8543658292581959, 0.33229523368420144, 0.1716049361012636, 0.06770376341357347, 0.13881153126637782, 0.192223702287001, 0.22417736750456596, 0.2172443330768616, 0.1259114073529359, 0.20761972533599024, 0.48530042832416875, 61.590429275266594, 84.43378756123205, 57.668882800686745, 51.971361637115486, 39.12377934302054, 44.215717930947584, 64.29921811626804, 85.24392174136254, 66.1125063127087, 85.56238682039323, 30.17440934335032, 0.709514782553719, 2.855729162693024, 17.255667409589215, 8.713888545190136, 11.38042071173268, 4.218135024270704, 2.4552867922090718, 52.418033307598485, 70.36998025832638, 67.34038860567155, 68.19157431202551, 68.63837149835402, 68.15259379725303, 64.53100665923088, 63.79178108707551, 61.69831798922632, 62.34679560507498, 65.45019449726229, 60.79998931577129, 60.94441883025631, 62.36535233836021, 63.400677634823715, 61.89240863246303, 63.8096357160999, 59.98289685095511, 58.83661554705713, 60.808238060243674, 57.948481113679954, 55.761249834491366, 54.27835856714557, 58.0256498244501, 54.378716330374445, 55.99351298424506, 59.02427350321124, 57.020471865131015, 62.345289414928814, 56.44823335832166, 58.64175611926664, 58.605336912216686, 61.189547354175204, 60.218199837592344, 60.445791444470814, 52.651077009016475, 47.06795569389097, 45.927534411030436, 45.66691252493089, 47.879878474820046, 47.50330740405668, 46.466746560988895, 43.87689575072258, 43.57056256263487, 46.31604125422817, 50.62884415349653, 52.29064256914201, 55.54304053706508, 56.38082350454023, 55.86654193939702, 55.07792588203184, 55.846184838202696, 58.60929066135038, 53.33021187013196, 56.93778830189859, 55.26579956854544, 57.393112720981726, 59.15757917588758, 54.775926912984545, 47.90322442208567, 46.07910656159925, 43.93615099691576, 46.556153066696666, 52.8642225265503, 46.7937663293654, 52.5556065190223, 45.66941107473066, 44.05652069276379, 46.90360446130076, 49.37035560607911, 51.068977232902284, 51.647303258219075, 51.425928608063735, 52.086102731766246, 53.479057973431004, 53.38361101765787, 55.70034327045564, 54.57575659598074, 54.51593260611258, 56.245964573275664, 52.66682924762849, 54.09108500326834, 52.54864823433661, 53.21967163393575, 50.162607700594016, 45.46687164614278, 45.68886210841518, 46.3735314338438, 45.99436767639653, 46.0438758327115, 44.133257942814986, 44.969974025603264, 45.24904281862321, 53.880653765893754, 60.18803681096723, 60.26473875968688, 57.415395705930656, 60.12286270818403, 56.30956188324959, 58.87614127128356, 59.74118078908613, 60.42925473182433, 51.16347497509372, 50.339161426790305, 55.80522744886337, 60.16101168047998, 61.03258194461946, 57.728644032632154, 56.04060888290406, 56.2530993646191, 57.74406286977953, 56.2174097184212, 58.57628391635034, 59.63036598697786, 59.884292387193256, 62.29404757099768, 61.72393106645154, 64.90278067127352, 60.70533860114313, 62.24331955755911, 71.02578486165693, 71.42301113374772, 62.58806059437414, 65.41824679220876, 79.73147761437201, 75.56498696727138, 75.07115271783645, 72.18562187687044, 78.80624540390508, 76.83158305383499, 87.45676609777635, 17.15460950328458, 0.5320003821003823, 0.772774707405798, 0.43402172024211577, 1.5714534828739783, 73.87450818092593, 83.93352846945487, 77.75206135165307, 89.27995435653195, 59.97817823963781, 75.33373971139231, 79.66391086578369, 49.50609314826227, 74.82543976076188, 104.13063618444629, 27.623478251118815, 1.1381107616809107, 0.4511823042506172, 0.3154091543007282, 0.17163896572686013], [0.13851646484146196, 0.09681819187056634, 0.14353737445367923, 0.05190192060845514, 0.11131467447886545, 0.0990556818883746, 0.5518030194986252, 57.440753829094675, 50.39048564049506, 47.43259491459016, 37.89100193208264, 27.661131043587964, 33.875271504925145, 48.51332164579823, 76.4359727982552, 56.42315372343987, 68.2040003807314, 35.17584316192135, 0.07723431853998093, 0.2394838501969653, 3.6449137185850455, 1.8567953715401313, 3.319324144432622, 1.6455778215200672, 0.5111227394832719, 35.92744381197038, 58.74101954121744, 62.583012503962365, 63.140518588404504, 60.786880754655414, 61.45778256077921, 63.73642467683362, 56.40446755193896, 53.567785909098966, 48.96076994557535, 57.04121335860222, 58.31076298990558, 58.19501384612053, 60.985038895760816, 59.73095124767673, 56.358156127314416, 55.37874029528711, 51.550620755841656, 53.07184142451133, 51.86320620198404, 50.69166875654652, 53.613065750368186, 53.23188981702251, 50.60003434458087, 52.6799770324461, 51.11758324407762, 54.62302507892732, 57.151757517168605, 53.97164098678097, 65.48952802535027, 45.27772711169335, 45.28423432380923, 60.27362292812717, 52.546722350582, 50.12703964787145, 44.56936667042394, 42.157760127898186, 37.68506180855536, 45.34991833471483, 43.01229161600913, 38.03985980249221, 38.89310083081646, 39.97485914537984, 39.770558572584584, 39.07968797991353, 44.877370788205056, 47.11663230772942, 45.78792548948719, 49.938656053235455, 47.36186673564296, 50.74835092790666, 49.504202565839215, 51.44157886505128, 48.78337683216218, 52.51458637176022, 51.81176039480394, 52.08528295640023, 50.89203911442911, 52.87461680750693, 50.2839893679465, 42.60379637441328, 43.514762924563506, 41.67072334597188, 44.5531790487228, 44.686041493569654, 48.8228476432062, 40.10942389888149, 42.84750107795962, 42.41935083943029, 43.37920581140826, 47.153937970438314, 46.984213090712025, 49.56664669898249, 48.05211759382679, 52.56101546748992, 50.64568681101645, 50.914035766355454, 51.320440384649466, 49.049850894558816, 49.62940069936937, 48.187894359711684, 47.68135163091844, 47.93676853179932, 44.5509119187632, 42.21974142136113, 38.57602427082677, 40.18292127117034, 40.56008069745956, 39.30449862633982, 38.328169699638124, 38.96791611948321, 40.29687396941647, 43.32109197493523, 44.80369298688827, 53.008730488438765, 53.64058509949715, 54.25929192573794, 50.82425663548132, 52.92742367713682, 55.033367756874334, 56.38123143103815, 55.437336583291334, 48.138598011386016, 52.86823511123658, 50.64447479863321, 53.303147515942975, 56.75506076505108, 56.05324675959926, 54.35535469362813, 55.65489476726901, 60.417016936886704, 53.33575417918544, 53.51010745571506, 49.690899541301114, 53.25471408905522, 50.67941134975803, 56.39842317950342, 54.07597211099441, 55.133345050196496, 60.10074054041217, 59.93280033911429, 63.81990055884085, 65.44242428195092, 62.56032159251552, 62.64117733124764, 66.46353490890996, 68.75154756730603, 68.28658196233934, 64.70861158063336, 77.64618873596191, 70.4108121318202, 8.328397024062372, 0.03167761884058916, 0.08453250111591432, 0.1385242023294972, 2.274752595732289, 65.46281668447679, 69.31506664522233, 66.93683947286299, 75.93352502392185, 45.861889623826556, 98.4232267256706, 59.34848485454437, 28.238237211781165, 61.47282485039004, 81.93271959981611, 19.133317778187415, 0.37392598366545093, 0.2680208245592733, 0.15462085875051637, 0.08114074642259268, 0.06905286723086912, 0.043460573971031174, 0.1537546124910155, 0.15350203330238021, 0.06727951158198618, 0.10297653520660055, 0.9001584591404085, 64.97508956540015, 61.710391044616706, 53.38057902551467, 47.823953320903165, 18.880118977638986, 34.196631293143, 56.21089073919482, 81.15295240955969, 62.665860806742025, 75.59809177152573, 38.46242066352598, 0.046488651404938394, 0.20872997059937448, 6.424614844783661, 2.9438974251670222, 6.259134459880091, 2.925045043230057, 0.4847613475736111, 39.94667299332158, 60.1277264471977, 64.55465462899977, 63.14307597375686, 63.02367510334138, 62.993551300418, 63.57882776568013, 57.44163244001327, 55.54142452055409, 52.33112927406065, 61.74149544008317, 60.5278984192879, 59.71229253276702, 60.283236657419515, 61.408223413651996, 59.574138810557706, 58.974439790171964, 56.37187657817718, 55.610713189648045, 54.09071237810197, 54.4180537808326, 54.40126603649509, 55.30524684536842, 54.29605237899288, 54.32525834729595, 55.41805028915406, 54.68800306320191, 59.415396567313906, 54.008903503417976, 60.28142060002973, 50.38795178936374, 46.98635862719628, 63.301555418199115, 55.35674364336076, 51.089675580301595, 47.3398583166061, 45.34224617865778, 39.50050338622063, 47.002820814809496, 44.693258654686716, 40.38806123118247, 39.88252655152352, 42.95320895410354, 41.572012978215376, 42.324060778464045, 45.24222181689355, 49.6955200933641, 47.336779256020826, 51.300138196637555, 51.14161560612341, 52.608593817680116, 51.11249200759396, 53.07243370240735, 51.675332515470444, 53.71419622052101, 53.72147221719065, 56.34117618683846, 53.47508461244645, 53.78541469573975, 52.14824876477642, 44.613783590255245, 45.40445496959072, 45.284924660959554, 47.35001333298222, 47.91019839625205, 47.96313078172746, 43.00421545582433, 43.994947325798776, 45.073477529710345, 45.451990173709014, 48.01183877452728, 47.62424976594987, 52.95014204517488, 49.54241037368775, 52.09808557264267, 52.5259377110389, 52.750936631233465, 52.82328867143201, 51.1637613081163, 51.763362269247736, 50.13509227383522, 53.26345312979914, 51.562705578342566, 46.786941405265566, 42.15031546931113, 40.581641966296786, 42.747817962400376, 42.77199937451271, 42.97220891521823, 41.034212881518954, 42.38477514636132, 41.03254979656589, 45.840128314110544, 46.355213965139086, 55.19623633353941, 56.31412752213017, 57.15172613820722, 52.14069820219471, 53.93211134018437, 57.83546978427518, 59.28772341820502, 57.80376134380218, 50.981688807087565, 55.636883243437744, 51.75321117524178, 55.81108354753064, 59.46189626570671, 57.951065955623505, 57.01829102731521, 58.255124169011275, 62.95395497352847, 56.8044630173714, 56.43188491944344, 53.31901742566017, 56.244023000040364, 53.513912154782204, 59.145710083746145, 55.85056612568518, 59.32657449476181, 63.547025188323, 63.533340038791785, 67.5199390226795, 67.10408933701055, 65.03801615007463, 64.37886576498708, 69.97522507944416, 71.09870956790063, 72.4509153058452, 67.24855807519728, 79.20911204430365, 74.51208160769555, 9.20227462245572, 0.39395532180224696, 0.15682708472013474, 0.23110375228908756, 3.0069612927975196, 70.61149627931657, 76.18396835942423, 74.74753364439934, 85.07393406283471, 52.43446411625032, 107.58208659387405, 69.35825978555988, 34.806791274778305, 70.00792980194092, 93.36136879459505, 24.902904648934644, 0.8120342620438146, 0.3004674060690788, 0.13948622490129164, 0.10673280219517409, 0.153880741206869, 0.16341720287117267, 0.2516999035593002, 0.2407986562578909, 0.19687866701954798, 0.3283684202019246, 2.0513885684551734, 81.53546979350429, 68.99920601998606, 63.804077717565725, 55.063499404538064, 41.38841075281943, 49.75625799548242, 61.57382980469735, 90.25919760427168, 68.22622453012775, 83.19295360196023, 42.683114544037856, 0.2665094250152188, 0.3392707706699449, 11.569921201275243, 10.567584999146002, 11.895156291223342, 5.826955947183794, 0.6474142858097631, 42.8262653658467, 62.86353257394607, 67.75448891424364, 65.8609333345967, 65.26421531554192, 65.41109238901447, 65.41650133748209, 60.25268531614735, 58.11772746424521, 56.784964915244814, 62.367399815590154, 61.199353279605994, 63.019748810798895, 63.731674686554946, 65.27247582712482, 61.61029608018937, 60.33174460934055, 57.239469558961936, 58.02313950753982, 57.4956670115071, 56.471402798929525, 57.73222123422931, 58.93136432093959, 56.15214540112404, 54.64082871713946, 55.74796476671773, 58.26121168751871, 62.514673048450106, 55.83225257935063, 60.846300740395826, 52.659266917936264, 52.76395497783538, 64.39293922916536, 58.85767083014212, 54.27844485928936, 49.9076065709514, 46.63204700716081, 41.72584833637361, 48.78723252204157, 47.97492927120578, 42.32979528365597, 43.256721958037346, 43.75873434928156, 43.386744606879454, 44.69513746999925, 49.56958455424155, 51.75627062397619, 49.616147010557114, 56.141476554255334, 52.355275384841434, 55.32212088184973, 53.12966500559161, 55.647850190439534, 54.636596479723536, 58.740670450272106, 57.66864745847641, 59.12426648601409, 56.04146003723145, 58.51783667841266, 55.593011533060384, 46.88354546023954, 45.863070257248424, 47.79573578988352, 53.28535172247118, 49.34082800342191, 47.66949822825771, 45.94433784484864, 46.42651873250162, 47.06206821626233, 44.73678519648891, 50.86155837582004, 49.19402153261247, 54.71708351565946, 52.2709640379875, 56.153039701523326, 54.05219862538, 54.218440440393266, 53.92019910197104, 53.49271566637101, 54.80877676317769, 52.45575866391582, 55.691223759805005, 55.689427314266084, 50.64383152992495, 45.84137955019551, 45.01795245755104, 46.19006256903372, 43.54123500085647, 44.61682734950897, 43.34895649263936, 44.0072988694714, 44.75940550527265, 47.57679300923502, 49.40093048157231, 56.61326708332185, 59.628106701758604, 58.352912779777284, 55.809283179621545, 55.675906904282115, 59.73603071704988, 61.14293782941757, 61.11329255565521, 53.96818145628899, 54.386219824514086, 51.49233041271087, 57.37270855134534, 62.66779061286681, 60.35448258922946, 59.14620430238786, 60.41786024647375, 62.75289035612538, 59.107415983753825, 58.85779242361746, 54.83570775678081, 60.13503382282873, 59.20202355231009, 61.058618637823294, 62.55781519797541, 61.14810751330469, 65.64528142252277, 66.87360302094491, 71.6250838002851, 69.0924721379434, 67.08598367629513, 65.81580254339403, 73.08060476856848, 74.75096179592994, 76.55456958278533, 72.93444941120764, 83.76302303806429, 68.34989686166087, 11.496711142601507, 0.6615900380476829, 0.5384727831809752, 0.6402534474768947, 3.9589386745806667, 80.55605396147698, 83.46715081122615, 83.7376453030494, 91.1879756373744, 62.177882655974365, 108.61141066397391, 68.74030605439218, 44.10750366026356, 79.76199365431263, 103.6102161099834, 34.982678198045306, 1.066350876804321, 0.45159111941053026, 0.1771317242134002, 0.2148040366028586], [0.107315557618295, 0.04795138521360294, 0.08706336450432578, 0.07522169064970748, 0.023844898415489063, 0.06344847058156325, 0.43172606116821693, 54.64053453937654, 55.77485261424896, 48.92066371056342, 20.27225248275265, 49.959617199436316, 65.50600590244417, 46.735150429510306, 64.0017730189908, 59.734414700538885, 65.13380435205275, 52.698843632974935, 0.21409134500690047, 0.1736359730843575, 2.9812028427277846, 1.07844072484201, 2.5141836318277546, 0.9096101455150113, 0.4508778302659912, 25.01072668260144, 56.9028909744755, 56.380635230771965, 61.55997599324873, 60.12669094147221, 59.80257372702322, 54.22160579312233, 52.454883975367395, 50.85327040764594, 53.927949705431544, 54.11349742643295, 58.319678537307254, 58.60402684057913, 59.32892399449503, 57.52904245930334, 56.43548565526163, 55.85771660650931, 54.44307850253198, 51.72099282664638, 50.7798122590588, 51.98067726627473, 54.43362951278687, 52.727257282503196, 51.61239024131529, 50.64970724044308, 53.47949727889031, 54.860928596988806, 49.03369857418922, 31.880032400931086, 25.36322028406205, 42.24669987155546, 58.41312508429251, 55.173835677485314, 54.19619275677589, 46.827518324698175, 43.31408662180747, 38.907939157178326, 41.995256331659135, 40.199069669169766, 39.11851159987911, 39.69741029124106, 39.33548927307129, 37.99163426122358, 38.125230189292665, 39.268903117026056, 41.24265547721617, 44.0397447155368, 48.46245634940363, 49.83718825924782, 49.756913031301195, 47.83462216777187, 49.750798056202555, 49.90757519199003, 49.05092954635621, 50.26270658739152, 49.06201416446317, 47.18170442888814, 50.375623779912154, 52.49794375511908, 51.349469846294774, 47.413187026977546, 46.424765433034594, 41.64450230136995, 44.23976206010388, 45.24486549438969, 50.40397467151765, 41.07026730814288, 37.944577586266306, 43.437802099412494, 47.88859005897276, 47.25374660184307, 48.35731329456453, 52.000924541104226, 50.857534024023245, 50.77861201378607, 49.00598310655164, 49.48267267596338, 51.526105942264685, 50.352301366867565, 47.43095928622831, 48.200732277285674, 47.820599694405836, 45.001078421069735, 44.00738516161519, 39.949959939525975, 39.21869677882041, 40.28815061815324, 41.39449042658652, 38.235138923891135, 41.221357007180494, 40.32875107180688, 39.77475550866897, 43.21670985990956, 41.248131105976725, 50.30720195462627, 56.39328487457768, 57.16341087895056, 54.53512868573589, 52.29205462240404, 53.22390779372185, 53.53631281083631, 58.83443863161149, 44.76655598609678, 53.05585384368897, 53.91136200197282, 52.29358042440107, 56.24650193798927, 59.45225507982316, 58.66769475321616, 59.310135841369636, 60.63985463111632, 55.36687512551585, 58.58295979038362, 54.590528242049686, 56.81522600112423, 54.54059254738593, 57.33043716799829, 53.26131543805523, 58.26672261761081, 55.27927291008734, 61.2870260976976, 59.88624964990924, 62.999740800549915, 68.46785037748276, 65.18140231409382, 59.84718284299297, 62.76067626091742, 69.70894321318596, 66.85578761562225, 68.35432913995558, 41.481716094478486, 4.844069798146525, 0.13975761920934723, 0.1814778942254282, 0.28178739391507646, 4.780715675123276, 69.77367016576952, 62.13237139486498, 73.86314115216656, 72.23409452745992, 60.49433077535322, 34.17342262883341, 35.10709577991117, 46.08661397810906, 54.89093080643685, 74.89020593704717, 11.829448746096704, 0.60514627324958, 0.11924681013389943, 0.11934716765198017, 0.010907891198932644, 0.031056421125427853, 0.06649244050945967, 0.1589693576698342, 0.07260556933620284, 0.03321967913859314, 0.10016431836711784, 1.1074444459330652, 68.43312171197707, 60.267225542376124, 58.6704247228561, 25.006400308301373, 36.69458881501229, 60.17980767834572, 52.746159184363584, 71.77113717602145, 64.59918137519591, 71.9974422454834, 58.97024677645776, 0.37661562643704877, 0.05393024180985747, 3.105387288716532, 4.002916288952674, 3.6196242368990377, 3.9538420448380136, 0.5459296378877856, 28.24038274826542, 59.88482190716652, 60.00731752764795, 66.38593473742085, 63.47802677462178, 63.11397198707827, 58.31814881294005, 55.584805934659904, 55.392511736962106, 55.085668640752, 57.34584031566497, 61.26819872087049, 58.27848580575759, 62.81717408087946, 57.77489662170411, 59.914726057360255, 56.8537828999181, 56.956148916675204, 53.628045282056256, 54.45219801318262, 54.29609160269461, 56.89883916608749, 53.42861237064485, 53.89802594338694, 54.91920717300908, 56.87600312694427, 56.23677445996193, 51.070099030771566, 33.929290386938284, 32.60297033094591, 43.60535790843349, 59.266836797037435, 55.25553472580449, 55.18286889599216, 46.941153310960345, 45.95387704910771, 41.803283768315474, 43.35360450129355, 40.68776561367897, 40.61207171409361, 41.10460373663133, 41.96253984205185, 39.87634881850212, 39.25242916230233, 40.45188211625622, 42.991420684322236, 48.14304990153159, 49.68670260521674, 53.84739598920269, 51.381664660669145, 49.995153873197495, 51.77897330253355, 52.23877706835347, 51.943983493312714, 52.37054517192226, 51.526768822823804, 52.52770669998662, 53.430742217648415, 53.41980272723783, 53.59929038632301, 48.061088054410874, 46.01418741287724, 44.27976631349133, 46.37330001400363, 46.307808199236476, 51.03543312318864, 42.40883496499831, 41.70056866061303, 44.726383070791925, 46.507358781753055, 49.801196590546645, 51.842378416369044, 55.38196448356875, 54.14557064733198, 53.79725633128997, 50.89930726635841, 51.758223964322, 53.252246918216834, 52.5681306469825, 51.4261600279039, 51.18410271982993, 50.04825492059031, 48.143999115113296, 46.177824774096095, 43.255549169355824, 40.99635808698593, 41.67486144650368, 40.94351199365432, 41.886912622759425, 44.02953478597826, 43.00083829510597, 42.666809251231534, 44.48124670213269, 44.44784772011542, 53.67984410255186, 60.26158125169816, 58.69177810607418, 57.47891064613097, 54.56694303020355, 53.522290337470274, 57.45232874347318, 58.75125300499701, 48.6452897902458, 55.05292861692367, 54.57546634058799, 55.23453043353174, 59.86219375364242, 63.875621749508774, 59.590699057425226, 63.215286808629195, 65.05761623382568, 58.05518919421781, 60.75563907623292, 55.93998047613329, 60.20576200177593, 58.14001437156432, 60.701396619119954, 56.49902412968298, 59.132017089474594, 59.148259624358154, 64.31247964982065, 62.544251641919544, 66.2550687789917, 69.5745078979, 67.53416938166465, 60.89815447407385, 64.43210801770611, 73.62241744995117, 68.86021291055988, 72.07718403108659, 45.770114006534705, 4.864892190502537, 0.14929383572551513, 0.398764607286261, 0.2715789046018355, 6.574078721384849, 75.57967232119653, 69.41142359087544, 76.7633887260191, 81.87333491540726, 62.570441307560095, 56.536651426746005, 49.36031826080815, 48.374465819328066, 64.6110543897075, 86.63722607397264, 22.05030995030557, 0.8603614172147167, 0.20832423511291706, 0.12027091647107756, 0.133420187499254, 0.21934883789189402, 0.21863052321057166, 0.26563587027692026, 0.33472186314963526, 0.10048036794027976, 0.3528195871941505, 1.9402984649904313, 81.23041922046293, 71.12593866163685, 67.83803539891397, 34.60214945577806, 61.69706675314135, 74.03995375479423, 61.10795813222086, 76.03498889553931, 72.33508771465671, 77.76342838041245, 65.01025753636515, 0.6316027213488856, 0.577057138566048, 11.149489206652488, 7.89832188237098, 10.489835777590352, 6.1262656411817, 0.7801379768117782, 30.69681021475023, 61.96290931394024, 62.81186711403632, 68.70640893136301, 66.72822429287818, 65.64673269948652, 61.942732641773844, 58.61841017200101, 56.20632902268441, 57.53979759831583, 57.3631928813073, 62.16578998873311, 62.59637601913945, 62.074390918977805, 59.92845827533353, 62.901226551302024, 60.28291894543556, 60.04319936998429, 56.14874470618464, 58.384323120117195, 58.45814604913035, 60.510973391994355, 55.84629074219735, 56.926801743045935, 56.06548063216671, 59.0250305206545, 57.56628928645965, 52.04874215587493, 35.33599745842719, 40.257210962234005, 48.83051979926325, 62.65417214362853, 58.55250650836576, 58.20518455197735, 52.11049987423805, 49.55531889392484, 43.340189995304236, 45.44375711871732, 44.456982920246745, 44.17566660911807, 42.546106153918856, 43.295282779201386, 42.275941141190074, 41.33336028745098, 42.341695754758774, 46.40192154915103, 49.27850546375398, 53.6518423018917, 57.94709651700912, 55.29172251301428, 51.63726199057795, 55.4750148711666, 55.746187933029674, 55.796053025030325, 54.51885869426113, 55.25136132394114, 52.91759813985517, 53.84648599932271, 56.958357211082216, 54.47902310279108, 49.3625500894362, 49.35614878131498, 49.13274626578055, 52.961042311883745, 49.57805295144358, 52.106965818712794, 46.85576331230902, 44.03311198757541, 46.14623008235809, 50.701290330579205, 49.97220800768945, 53.92622386255572, 57.707655429840095, 55.88234516882128, 54.99902348364554, 54.01586963284401, 55.15594574712939, 55.259339424871634, 54.92986425276726, 52.78647330499465, 54.31929242226386, 50.77163019487935, 49.36532320514802, 47.56998769698605, 44.9566928801998, 43.21743157602126, 45.22362193753643, 45.352562012210974, 44.28403777460898, 46.12729680153632, 44.76016252271591, 45.08340504861648, 48.602045659096014, 47.15346336364747, 53.98625966041319, 63.336464512732725, 61.572778609491166, 59.91102726228776, 58.00386105814288, 54.68789715920725, 61.03106398736278, 62.96502782452492, 53.286599036185976, 52.96967544863301, 56.965295883917044, 57.27397857173797, 61.41431093215943, 65.79277430811237, 63.028911467521425, 65.20448154018771, 67.05519307044246, 61.9621209175356, 63.6208128160046, 60.46996108947262, 63.37425262697282, 60.940523916675204, 64.49474042461765, 59.54038681522493, 63.06857447470389, 62.17392106210033, 67.98316309528967, 65.62401825381865, 70.15024123653289, 73.65641655460482, 70.86903910483085, 61.612516141706905, 67.58272047965758, 76.81644270496984, 75.85123369770666, 67.93571810568532, 46.52598611770138, 7.013486652604996, 0.3477991678782048, 1.943548516400399, 0.709644649778643, 7.847598281598861, 84.75119360031621, 74.93572896526706, 87.08491756070046, 86.54941989529519, 75.07203132875505, 52.53152708853445, 47.55641629618984, 67.01116838762837, 71.90233261354508, 99.88252101405975, 31.66107589198697, 1.2555385573256401, 0.4004530957148921, 0.5613530102756716, 0.18358333366772822], [0.043454177136863434, 0.01693260581833461, 0.004770351459287228, 0.06003448401667899, 0.03140703084007387, 0.12363369005822367, 1.1517651451210822, 48.30828366741058, 59.84866549891811, 40.09729985267886, 51.155512563643924, 74.84401610589798, 85.02021328095468, 54.333271749557994, 55.436403059190326, 64.70455584987518, 57.98241353804066, 64.88267067940005, 2.148466004479316, 0.5288300038345399, 3.212789873923025, 1.8576532674412576, 3.815454451307174, 1.2275189834256326, 0.43438098483508636, 15.176885743294994, 55.64907004756313, 51.073629163926654, 57.437149170906316, 55.035219115595666, 56.83840720884262, 54.73959007570821, 56.212895070352864, 53.61869827393563, 58.169565508442545, 49.473804197003766, 54.81681369966077, 57.225423551374874, 53.222884055106874, 58.570416050572554, 58.3923561342301, 59.22975078705819, 57.78129792982533, 55.47713295105965, 55.938286012218846, 55.33588447878438, 53.73498478243428, 56.25981053998394, 54.73423211805282, 54.65028162925474, 54.214623974215606, 53.68740250987392, 42.9812813574268, 39.89960062888361, 52.073586448546386, 61.63823512292678, 55.20047641569569, 57.29470829809866, 49.07949224595101, 46.391586103746974, 45.07951405740554, 38.11491435573947, 38.7824390011449, 38.11789535707043, 39.235978741799634, 39.3807848038212, 38.30912267008136, 39.334936218877, 38.81361792164464, 38.24094403174616, 39.56672083946967, 42.918197877945445, 47.71834742638373, 50.46659138894851, 47.54094254586005, 49.65661802599507, 50.69268857279132, 48.34707590841478, 46.46880972769953, 50.436416595212876, 49.53448718593967, 50.062238170254616, 49.24265107800884, 53.13348539413945, 53.86938087401852, 51.04924378856536, 49.442244806597316, 42.3641630911058, 40.37541158737675, 43.76226056006647, 47.6178131564971, 37.945471886665594, 40.4731805862919, 41.85301157736009, 48.723293965862645, 47.41487756852181, 51.70326763583768, 51.438841050670995, 53.11315967190651, 49.42278200580228, 48.83563064759778, 48.8859115108367, 50.06366199062717, 47.629729317080596, 47.67924531813591, 47.60560281815068, 47.84505567243023, 45.384776438436205, 42.775502051076586, 39.16490147190709, 37.917693661105254, 38.16600322723389, 38.32909145662862, 38.155659937089496, 38.3347749710083, 42.71907091140748, 43.57214327781431, 40.32280868099582, 42.105894627109656, 43.13322221079181, 50.17690473987211, 53.099352928899954, 56.42833909680767, 56.13108619566887, 56.28317609910042, 50.32856710495488, 57.881141862561634, 48.906586324014974, 47.28110513379497, 60.38689705633349, 50.731292540027255, 55.65899756646926, 54.76730946571597, 56.14979982376099, 57.494145131880245, 52.68926128264397, 54.612638642711026, 59.60860467726185, 55.71255753117224, 59.250700166148526, 58.17578246516567, 62.412381556726274, 58.07899013642342, 61.00085781466577, 57.25257027533747, 57.04597511599141, 57.23131495137369, 61.71419574368385, 61.65673302065942, 66.7344294824908, 66.04435120859455, 68.4080263876146, 61.727653395745065, 70.51353900663315, 57.882298961762466, 38.69734710262668, 1.3702577112182495, 0.029736172009800232, 0.4995294696381016, 0.4563595570864216, 12.719543383967492, 74.0093671121905, 64.31561754595849, 78.75845524572557, 73.39844226837158, 65.20134364404987, 35.9998978337934, 30.9155176531884, 45.26638753952519, 57.601096399368785, 69.51560174265217, 11.080505501839424, 0.5002153634784684, 0.261474204880576, 0.10499488577366838, 0.11733560462392147, 0.10029144299727294, 0.08919017013883399, 0.05786859257627399, 0.14712476502022437, 0.08696987879492583, 0.21978901669142709, 1.2331401076047652, 60.23059452733686, 64.9256794683395, 53.4801640818196, 50.61774776827905, 74.38225899973224, 86.91631840121362, 56.87785840803578, 63.024220312795336, 69.61212342785251, 63.5627656598245, 71.78255911796325, 2.5067019558721975, 0.3106641589153198, 1.8275094849448053, 3.5954161036399106, 4.10560148858255, 2.691673088458277, 0.8982686734487935, 18.200036864126883, 59.09855142716439, 53.24929729584725, 60.83397665331441, 57.202571822750954, 60.427552423169544, 57.23605709691202, 60.733128593813994, 55.31899867519256, 57.90962219238282, 55.4420316603876, 57.1551150660361, 56.46871989773166, 55.177632531812115, 61.060454307063935, 60.259023866345814, 60.26056143545336, 59.650817225056315, 58.345550490963845, 57.26142698718656, 56.21779411069809, 55.61887956434681, 59.8487517910619, 55.90171383273218, 54.99697208404542, 56.012716908608716, 54.37624523716589, 44.137858883027114, 46.999777055555775, 58.61397397133612, 60.95088681867046, 57.45263076597645, 57.500581741333015, 52.05036601712627, 47.61096469817623, 46.108543949742476, 40.50077053808397, 41.282326329138975, 37.97996520996094, 41.03817839776316, 39.64829044957315, 40.39414090494956, 43.061662489368075, 40.58228131263487, 39.71420980268909, 41.288743326740885, 44.41799063836375, 49.50133923561343, 50.98201828618204, 49.465280886619325, 51.41496558343211, 53.5310136887335, 50.03791947518626, 53.099156810391335, 51.36343348410822, 53.3336635558836, 51.26362877507364, 52.549248356972974, 54.254561547310125, 54.148053507651056, 50.319894744503884, 49.50167263707807, 44.664860694639145, 45.25242782408192, 46.84940907262987, 48.42287963436496, 40.38847308005057, 43.82334755313012, 44.224574642796675, 47.851586418767134, 50.75148490167434, 52.30956408285326, 52.275243343845496, 54.794609162115286, 52.31061920042961, 50.92178244744578, 50.761796812857355, 52.008961477587306, 49.45074458276072, 50.32266001547537, 51.440535514585434, 50.350391172593646, 47.96811611421647, 45.46978988955098, 40.84548019593762, 40.21045630978, 39.629910222945675, 39.87325406843617, 39.87089280159243, 40.32514249124835, 44.04236485881191, 46.29646470469814, 41.36209949370354, 44.30196300629647, 44.607276378139375, 52.64269490395823, 54.640718890774636, 58.989572294296764, 58.92655157273816, 57.8337243295485, 51.81765571717293, 58.59903366334977, 51.47794708128899, 51.3190047971664, 62.46614156230804, 52.46161476258309, 58.74216879567793, 56.97377212585942, 57.758434434090894, 62.08323978608655, 58.29490092492873, 56.98069903158373, 63.699479872180575, 57.704235123049834, 63.45942689526466, 60.45557383568057, 63.881470003435695, 60.46109261051301, 63.371636406067886, 59.82290729399651, 60.89244350310295, 59.369308717789195, 66.40102017310359, 63.79813924912484, 69.47383634505734, 68.46616375830867, 70.06791853135633, 62.787289542536584, 70.1719319435858, 64.09614132296655, 39.88635870718187, 1.7370245725877824, 0.3577577593105455, 0.532250800921071, 0.30351217655885604, 13.602231606360405, 83.39088424559563, 69.6590663540748, 81.6564670685799, 79.76806548333938, 67.64239541945919, 40.88031476543796, 31.974549754973385, 46.005730782785726, 66.20316013213127, 82.20146471454252, 13.932672662119712, 0.9202932722626195, 0.2948698161109802, 0.15071233944787135, 0.07048952723703078, 0.21261538469022323, 0.3398195041283485, 0.19201167979307715, 0.18769141887464832, 0.13802109706786372, 0.33238121939282267, 2.0904632201117854, 77.34721783668765, 74.59427095228627, 59.130181420233946, 66.76776178421514, 86.2751599281065, 90.45086814511208, 66.96376262172576, 69.41526751364432, 76.73477111324188, 68.93788368471208, 77.63952070666899, 3.1361153817945913, 0.9988825551925168, 12.510083913803102, 4.578456205706443, 13.517902608840698, 7.023044488122387, 1.0682733284850274, 21.661106886402255, 63.289113660012525, 53.600165074871434, 63.04363212277813, 60.440551157920595, 67.08818804833197, 59.350308756674494, 62.470397333945, 55.79456644673502, 60.80680247276061, 53.50655378833894, 56.54738695390763, 60.586631990248165, 57.35191606706189, 64.17229806223224, 63.801547788804584, 64.08415848209013, 62.3516240427571, 60.13687341443954, 59.8861280564339, 58.87934977008451, 59.45995861484159, 62.177055035868, 55.491461369299124, 57.307165745765936, 59.68147839269331, 56.558934411694935, 43.77649091905163, 49.167172908782966, 54.07329705453689, 63.454253289007376, 60.74305219034995, 62.376574239423206, 53.52418091989333, 50.328665164209184, 49.94278238665674, 42.36120954636605, 44.09795268889397, 43.03784978005194, 43.28903836588706, 44.21062669446392, 43.07678714875252, 43.293537324474705, 43.331721598102206, 43.3251202491022, 44.0271068388416, 46.702347647759225, 52.46288953288909, 53.614352287784705, 53.16890047442529, 55.37329212311776, 54.24240612214612, 52.5422312367347, 54.05611707318214, 56.2685574254682, 56.912665520944905, 54.41724969494728, 52.71840841539445, 58.09395005626064, 59.13935192169682, 52.28679080163279, 52.02116397119338, 47.427240879304954, 47.91341473979335, 48.59043936575613, 51.9985907308517, 45.30500327387164, 44.95204487154561, 47.82471033834642, 50.69873294522686, 52.040399274518414, 54.83874367129419, 57.238437975606615, 57.68144222997851, 53.31335744550152, 53.256075151505016, 50.66635377945439, 54.607484648304606, 51.72751965061311, 51.904347942721465, 54.58184411448818, 50.61751242606871, 51.249021868551935, 47.18454814726307, 42.81036407716813, 41.918864250183105, 43.214183853518584, 41.68104702426542, 41.372984070931714, 42.194434289009344, 47.72601566007061, 49.25936037494291, 45.621585615219615, 46.1103403952814, 46.19255719646331, 55.30484284124067, 59.72536579255135, 60.28031449164114, 62.18833577248358, 59.021359182173214, 53.45213090219806, 60.99542140960694, 54.460870373633604, 51.891866960833156, 57.09231007483698, 57.77281384314261, 59.36246810420867, 58.68092098543721, 58.96642638790993, 61.77267828295308, 58.93684387207032, 59.032337896285526, 66.08674418541693, 59.768229453794426, 64.59309385668847, 63.805325031280525, 67.48226073480421, 62.686182606604795, 67.30580114549207, 64.70713284707838, 63.90032483685402, 61.498080991929584, 68.48776032847744, 67.82187523380404, 74.04553136517926, 71.3808064306936, 68.91920535795151, 65.220990796243, 71.37315780885758, 62.07814070486254, 43.8455520906756, 2.511208759200189, 0.3562113342265929, 1.4551581490424372, 0.5505367680903405, 18.15530223231162, 91.927593446547, 78.18928795476114, 90.12733536381876, 86.04836064000284, 76.97109391612392, 56.43790575765795, 42.63110783792312, 62.24921880229827, 73.98466402484526, 98.11787805249615, 24.200061021312592, 1.0723832369812074, 0.5251451209187508, 0.1867348048835993, 0.24540203262961682], [0.025196980399590348, 0.06582018303414507, 0.08577146447233616, 0.07835404031098851, 0.08291864497286659, 0.174149175384833, 1.0758672822867672, 52.78949353002733, 52.31763239829771, 38.54670063141854, 34.53668509760211, 70.71507038608675, 85.03566741943361, 54.108723901933246, 54.56576239678168, 70.21729807699882, 57.3349557384368, 76.79092376462876, 10.281976634456266, 0.3635580867769257, 1.0904565381426965, 3.4636558448114707, 1.2824841372428404, 1.4308555111769707, 0.18164123949264327, 7.938656595445449, 53.27454167027628, 49.362981550155155, 57.18249713220904, 54.689030724187056, 59.56075960589994, 55.64607335675148, 62.97035048084875, 60.702459581436656, 57.62821958911035, 47.31029541261735, 52.337071664871715, 60.89539312547254, 58.97018794090518, 58.050388213126894, 60.83404725597751, 57.92489982420399, 56.61900943325412, 57.36417739622055, 56.40849190373575, 56.465942859649665, 53.0577483484822, 49.35828255068872, 53.028059928647934, 54.68066038623933, 56.33181348923714, 50.244318516023704, 51.460394474767874, 64.64152728357624, 62.20985781761908, 52.86466575437977, 56.16171598434449, 52.42852564780943, 46.82248200139692, 46.030316199025805, 41.765150485500214, 40.36719422186575, 37.664496821741906, 36.806729378238806, 41.45203944175474, 39.41071641060614, 40.25793660071589, 38.47820428109939, 38.327828453433135, 41.39050137612128, 39.84258505605882, 44.821445634288175, 46.15971911338068, 48.26814997580744, 48.182030416304066, 49.2237138748169, 49.722741342359974, 50.367543697357185, 48.809903821637555, 50.084183831368726, 47.2778848678835, 49.59232645650064, 49.73192753330354, 53.13988670226067, 50.1891190005887, 53.301162796635786, 48.59425583193379, 41.22272199200046, 39.55391037848688, 45.84492929520146, 45.18774793994042, 36.6455787997092, 41.435667468655495, 45.110045786826845, 51.14988396244665, 51.23965132621027, 51.740028089092625, 51.59765781894807, 50.302275457689845, 50.03745271313576, 47.77766150812949, 47.14630111571282, 48.22927928739979, 48.63958666401525, 49.092557660995, 47.45912974880588, 46.60677909851075, 44.01997204749815, 38.69708038145496, 39.186953037015854, 37.25440517548592, 40.52936853901033, 38.26137565797375, 40.650609001036614, 37.90444781703334, 39.70996187579247, 40.78680938290012, 40.003692488516535, 41.284126697048066, 44.024290577057876, 43.683883759283255, 52.951001044242616, 52.20593506290067, 55.82859693035003, 57.90278942354264, 56.24330128392866, 47.157075866576164, 51.795380576964355, 41.12929897923624, 54.16316247755482, 60.49142037668536, 52.88494048580047, 54.864262611635276, 51.732218650079545, 49.974843840445246, 45.48779356864191, 55.85253907788185, 57.07469863276328, 59.58875356181976, 60.333007612536036, 61.32280988077964, 57.97762040169009, 60.61433176840506, 62.958116608281294, 60.67528540088285, 59.73124542543965, 58.55433825523623, 58.88776325410413, 62.61028474377048, 61.32018189276419, 64.25554644676947, 64.19165495903262, 66.72521975732619, 64.4626279800169, 55.88859742687595, 25.269008874893192, 0.07155413664276562, 0.05576504920158656, 0.353368473870139, 0.23604033094260002, 19.59209780539236, 75.00579034128498, 63.69487500959828, 77.19268429663875, 74.79968547821045, 65.63063136992916, 49.52496759353146, 45.7819595644551, 46.08699444801577, 58.76523625466132, 74.79617103453606, 13.436084908823814, 0.38867642442064904, 0.19305579634683748, 0.04122732424988382, 0.18165732733905318, 0.039678474497650905, 0.08655668161208592, 0.07002669521757672, 0.14487804364292853, 0.06708106416608058, 0.18892849765477643, 1.5781331567033645, 64.84755762161748, 58.04914482178227, 40.00282956707863, 42.1158339131263, 86.19073483251756, 84.75208005597516, 65.49922020204606, 62.79522449739518, 75.99034447823801, 61.37624825200727, 80.70978733801073, 10.970096665043986, 0.621943210642184, 0.778124881607871, 3.652615292418388, 3.250114658186513, 4.706723103600164, 0.6352069505280065, 10.258187459361169, 57.88717839025683, 50.6772618909036, 57.351363012867594, 56.4646484774928, 62.15238332748414, 57.20758461183118, 65.05550599867298, 61.21795708133329, 59.510113962234996, 49.87701600597751, 55.54409565464143, 62.00232128943167, 60.19612866063272, 60.421939511452955, 64.24592487273678, 59.24375757094353, 59.98716831207276, 58.167839665566724, 59.12295249200637, 58.802891008315555, 56.89385383359848, 54.29314982506537, 56.07063462657314, 57.46919885758431, 58.66030893018169, 50.420601598678104, 53.55146492681196, 66.81832898047664, 60.65312793177944, 56.229416093518665, 58.128188425494784, 54.608182830195275, 48.144379585020005, 47.848981964972715, 44.44084236698766, 42.461108392284764, 39.64824730350126, 39.45871837677495, 41.88818347069525, 42.4495844687185, 41.01498150056408, 40.647635844446, 39.83374011132025, 42.60583992927305, 41.50315969221054, 45.68230782785724, 49.70333345474736, 51.22915114125898, 49.428363538557484, 50.37103460681055, 51.21971784099456, 50.82402521564115, 50.19592431283767, 52.368862475118334, 51.27044585443313, 51.72833550360895, 52.002634694499356, 55.703681207472286, 51.119736625302224, 52.34867011347125, 49.9366948681493, 45.26237495483891, 44.11146133176742, 46.42841715966502, 45.94966834591281, 39.5048572171119, 41.80202468749016, 48.269334531599476, 48.70383900980796, 54.70433581259943, 54.814613249994096, 52.8158087115134, 52.173748093266646, 51.22282828054121, 49.074754022782855, 50.31210883971184, 51.67114734649659, 50.90294722587832, 50.48003335152903, 50.24298883253529, 48.028528459610484, 46.714024543762214, 43.25073642115439, 40.947336304572325, 39.40775502112604, 41.5051483338879, 39.27882279119184, 42.558591058177335, 40.52661895751953, 40.10455623749764, 43.11908598869078, 41.50580729207685, 41.08730608417142, 46.97718812573341, 45.26372032780802, 56.64583844523276, 55.942886952430975, 57.16791768227854, 60.541403139791186, 56.95800419776671, 50.12862428542107, 52.931287211756555, 43.18041224633494, 59.643094078187026, 64.0391061382909, 53.0247925942944, 55.64875233557917, 52.43854338122953, 54.102954095409764, 47.60149609658026, 55.27145562633392, 60.13000926663799, 61.84446942421698, 62.077795536287375, 62.96339611853323, 62.08543239101287, 63.34121058064123, 65.69972784288468, 62.79551475278793, 63.86009700836674, 61.55439053812335, 62.9637687436996, 64.68199437664401, 64.2010098118936, 68.24447139616936, 69.18491455816454, 68.75743112256451, 66.98898346193376, 62.7424725409477, 25.920645959915657, 0.09779490800874849, 0.33446479468576373, 0.4172726173795039, 0.19073574503342952, 21.455551155151863, 84.14510896128994, 69.30527640927222, 83.20297918012066, 80.47882249278408, 73.28139089768933, 53.80250054021036, 36.209136670635594, 46.475034529163, 62.29917803118306, 85.67917146990376, 20.19781178043735, 0.4782138698764386, 0.1618194805398103, 0.06115319838206615, 0.21305815286694035, 0.1401434976968073, 0.21989937931779893, 0.20394975049120767, 0.2328880783170462, 0.21487860760140806, 0.4514144288916742, 1.7792287853456314, 79.28582576013382, 67.43874596011254, 54.08517399141866, 47.16162973834623, 81.74046070344987, 86.67783044999646, 72.27531863797095, 68.19042113519484, 83.15431041102256, 69.46209276876142, 88.43767243046915, 13.531080792027137, 1.0548534292367198, 3.2868265721105763, 10.013958138804282, 7.480293810367585, 7.188399357180442, 1.5297961956070316, 12.508404158776807, 62.11802336477465, 49.30904896028581, 59.39575333749095, 55.97821574057303, 64.32259152012487, 58.86124018699893, 68.60015192339498, 63.79294995338687, 61.220745886525805, 53.36175557105772, 58.8897087497096, 63.51527752414827, 62.39527217803463, 62.48964832675073, 66.43223439493488, 59.83372126856158, 61.461034205652055, 61.01926549788445, 60.65448114948889, 62.53921924098846, 60.53470765390704, 57.17414248374201, 60.91086295343215, 59.08429753395819, 59.02461082704606, 50.648102991042606, 55.79480178894536, 66.04602998302829, 63.18499042141823, 57.63902964130525, 60.334666775118926, 57.33036656533518, 51.71884336779195, 50.31809437659479, 48.10255927424277, 43.168307811983176, 43.478433932027514, 42.358020659415956, 45.50014903468471, 42.95470729950936, 43.48633750792473, 43.11226498696112, 42.75591373443604, 45.47872112643334, 44.72934838264219, 49.85325036510345, 52.89952385810114, 53.201989589198945, 52.58291406016196, 54.93173130096928, 54.69871897851267, 56.465499631820194, 52.62942552566529, 55.543624970220755, 53.308529007819395, 55.20094317774619, 55.95701140742148, 57.50975616516606, 55.130211076428814, 56.410409942750015, 51.06217192065332, 48.23992460004745, 47.9438562547007, 49.70728720388105, 51.59027591828377, 42.63525770556542, 44.66645709929928, 49.59916314771099, 52.021446381845784, 56.42391074088312, 57.13706039613294, 58.05770735586844, 55.109202861785896, 53.80309281810638, 50.922606145181966, 51.25286186895063, 55.46995109127414, 53.95577107706378, 55.06848473702708, 54.100279038952245, 50.24946466568978, 49.59262455663374, 43.33973500036424, 42.80047185959355, 40.80478560539984, 44.94442762867097, 41.534326845599765, 43.33960163977839, 43.083772890029415, 42.25116352881155, 45.327494144439704, 43.60405568153628, 43.95376243898946, 48.913360257302564, 46.55154820411436, 59.47162374373406, 61.00922423024332, 59.49370276543402, 63.61910266260948, 58.49930347934846, 50.478864485217684, 53.444290084223596, 49.18385474912582, 57.18685880784066, 61.159148985339755, 57.587889778998594, 56.75053042750205, 56.30128960455618, 51.476758603126775, 49.68289790614959, 58.32111412479032, 62.27590660895071, 65.27746115961384, 64.94871947073167, 65.99740043763192, 64.68097063802904, 65.19156517521029, 68.56195588265696, 64.60905005854946, 64.60213884230583, 66.26123474490258, 66.04479835879418, 69.80044426456575, 68.20687940043788, 71.78914869985273, 71.6977810090588, 72.27664439908921, 63.68409633636475, 63.29673482525734, 30.15560942311441, 0.22884429853049018, 0.5884925636552996, 1.1910584689148012, 0.447337829898442, 26.144830988299464, 89.23017947904526, 77.41933453467585, 90.264280996015, 88.24240115381058, 81.17361545562744, 68.6243921710599, 62.016535958936146, 67.37412098915347, 74.1141414642334, 100.12381738232028, 27.271063097061653, 0.8525281375454319, 0.3943914403357814, 0.22765580504651994, 0.568502142785057], [0.10663502639339817, 0.14855241583239648, 0.06184047884157589, 0.0386546784260821, 0.08182478633018271, 0.11321319357281732, 0.6801920011639596, 52.26837527367377, 56.15400068221554, 52.3041316001646, 32.941464993261526, 46.09410178276801, 75.42051822908464, 49.51784064692836, 60.01097317664855, 71.36228499873992, 58.28060780802081, 74.33839121172505, 17.67136412282144, 0.44876400982179954, 0.7743374041972623, 3.9325349946175856, 0.23412543288882703, 2.0883591136624737, 0.5525651850527333, 4.367034569863351, 50.83969116210938, 54.184884563569106, 58.158010205914906, 54.262943652368364, 58.66325855255128, 54.97591680096042, 58.63946937745618, 50.11322113775438, 55.573737006033625, 61.6355404546184, 61.65043369416268, 59.80153429892756, 59.89077214271792, 60.33141905261625, 58.57775088279479, 55.52995551017023, 56.38644033862699, 54.571296861094815, 57.2046624460528, 55.85214684086462, 57.071195956199404, 52.91364831309165, 47.558934457840465, 50.712806409405125, 49.47776971324798, 51.4927932523912, 58.39858093569356, 54.32801577352709, 55.457266146136874, 55.347122069328066, 52.99980317392657, 46.000949413545676, 45.02355752452728, 46.23860189991613, 42.81197224893878, 38.49408203555692, 39.702128902558364, 42.243244263433645, 41.20315720958095, 38.332786329330936, 39.82489124421151, 40.9539415759425, 39.378760860812285, 39.82628760799285, 37.84341181478193, 45.24745818107359, 47.357352087574625, 45.98707599024619, 48.89562329938335, 48.517271472561745, 45.97704648971558, 47.75686902384604, 48.72354891992385, 47.83933293434882, 48.44758272171021, 50.068494350679465, 52.23850642481158, 50.79487416052049, 50.15057779127552, 53.648920136113325, 49.99820547719156, 45.240570499051, 41.723789092033144, 43.531542824160674, 42.91974329179333, 36.779492439762244, 41.64604379284767, 47.87661114046651, 49.59281283040201, 51.375561452681026, 49.58929838672761, 50.16593387050014, 48.95382735037035, 50.40799117857411, 48.489457945669855, 51.16416531224405, 47.3614078183328, 47.71891617005872, 46.68730535814839, 46.42729928416591, 45.45752071565198, 42.05660612352433, 39.375466069867535, 36.94900551149922, 39.57560108553979, 37.884263300126605, 38.272083728544175, 36.96797409365254, 37.84155261132025, 38.44404828163886, 41.85388234353835, 39.54856811031219, 40.46882675540063, 43.116736488957564, 43.39927265720983, 44.910032364629934, 52.42966705752958, 53.63655682533018, 56.09427475160169, 56.77449218688473, 55.56600993679416, 50.36138165381647, 52.82100977436189, 39.96033068626158, 55.14406488787744, 62.47666135911019, 49.647557350897024, 56.05032067145071, 46.92786824318671, 44.97581051241967, 53.87479766722649, 52.6450091023599, 58.02992520793792, 56.200645508304724, 56.525759004777484, 56.58073102274249, 60.1141825029927, 61.74842626817765, 63.818676779347086, 61.4632660342801, 65.87900761635073, 62.910495112019206, 65.22399925416516, 62.47892064432945, 68.65115058037543, 67.46220957848334, 72.76041384666198, 54.03448127931165, 57.57287494597897, 12.645659658216662, 0.21301954203555662, 0.22108260211685013, 0.6295878488209941, 0.09600674388028922, 23.224245925103467, 78.89482821187666, 60.99467223690402, 74.57176439223751, 68.75190842536189, 65.19857837307838, 42.934797348514685, 40.85549792935772, 40.87111680738388, 54.67867174456197, 77.8617229769307, 10.057519001345481, 0.4339754485314892, 0.016287328044493354, 0.12593972962349653, 0.05258753865716919, 0.05992369621150917, 0.09361820430645058, 0.05466935194788441, 0.052171598879560355, 0.08545310131364292, 0.2672554107923662, 0.7644768720192294, 64.16115460857269, 64.16475926676105, 52.360052831711315, 36.85355071098574, 74.03017136358446, 83.83892874563895, 58.82982200191867, 64.38210564274942, 76.7294131555865, 62.7121526195157, 81.49118623425885, 19.824029514866492, 0.3358738448831343, 0.12499589397902451, 5.6644438159081245, 2.2960206673991297, 3.1092066966718246, 0.2009823395600242, 5.076948760017272, 57.095957879097234, 51.5527545252154, 59.20718931382703, 54.108798426966516, 60.79289767049975, 54.53141812355288, 60.50844738560339, 52.65184187120008, 58.05940181978288, 60.02791389342278, 61.41151428222657, 59.81891432116109, 61.12084704060709, 61.22373473259711, 59.675583070324315, 58.54837625257431, 56.452771540611025, 56.05846351192844, 58.59231856561477, 57.45246994879938, 59.28148684963104, 54.4327038334262, 50.74373037584367, 51.98667064789803, 51.434718639619895, 50.64392566680909, 61.0406384929534, 55.60201729497602, 55.399807345482614, 56.412943793881325, 54.602671900103175, 47.61329850842876, 47.97143836175242, 48.09133345080961, 43.869635443533625, 40.0701609734566, 41.43184315773749, 43.08860525008171, 43.14439312104256, 40.34083589430779, 41.667095153562485, 40.768946909135394, 40.190785623365834, 39.8814243655051, 40.18085418208953, 46.901545216960294, 47.52104436197589, 49.10843541545253, 51.00924345754808, 49.67628871240924, 49.14195991331532, 50.38708886792583, 50.85767522934945, 51.732826617456254, 50.52249300864435, 51.35856582272438, 54.44854628655219, 54.4566342138475, 54.490319528887355, 54.58305612687142, 51.28322493645453, 48.5909963423206, 44.60880610250658, 45.006142200962195, 44.16763751737533, 40.799874797944106, 44.83412665705527, 50.99013367006856, 50.78471914414437, 53.89639423739526, 52.66746859396658, 52.094222038022934, 51.577096754504794, 53.154595590406856, 48.935392210560465, 51.45718597596692, 51.96729021687662, 49.88000485204881, 50.14129354107765, 49.40096186053369, 48.78572240952523, 45.17714185099448, 40.23010346197313, 38.529948188412575, 41.35135219943139, 39.97774600982666, 39.036428159283055, 40.207447851857836, 38.022256205158854, 41.70407133717691, 42.76467630940099, 42.365065236245435, 41.34668065655617, 42.96273639125209, 44.686837734714636, 47.89983941662697, 54.63038344537058, 56.63020387772591, 57.51001111922726, 59.56358763479418, 56.877434792057166, 51.173041635944, 52.97570413158786, 42.14557724614298, 62.88254822454145, 66.27405305062571, 53.795789364845525, 57.14652507535873, 52.32688526953421, 45.355613616205034, 56.75746910033688, 56.09361971578291, 61.28185249144032, 61.8780606023727, 61.18345983566777, 58.53665228812926, 63.58325219923451, 64.00813902578047, 65.94803348664315, 64.66980757251864, 67.74553806551042, 64.93103742599487, 68.94637953850531, 65.19536202953708, 71.24459035934942, 67.99693845933484, 73.55951832186791, 60.812266334410644, 60.466242682549264, 13.032276899583879, 0.1409733701016634, 1.032355694520858, 0.6907115528179754, 0.13296674005687237, 27.653794250180646, 85.21477068624189, 68.46672073487314, 83.32710650659378, 76.83975727327409, 75.70925958694951, 47.21230676097255, 31.48112931559163, 48.39689785434354, 60.68162787345148, 90.48558896587741, 13.851207975418339, 0.5348896367415306, 0.2644507322580584, 0.10255788347773975, 0.0746016267446741, 0.1654559926640603, 0.33146038170783754, 0.25237171670361874, 0.22831943637180716, 0.2207698237391249, 0.35525688060349037, 1.4150001877738585, 80.2962596954838, 74.0066763662523, 68.21668532586867, 46.43971358576129, 64.02277338889338, 84.83279458938107, 66.3142651896323, 71.58134152812343, 82.48591499943888, 67.23449245575937, 88.7188514586418, 23.085392059818393, 0.8123715858786338, 1.819996184879734, 12.262094020843508, 7.015893026705712, 7.480899816559208, 1.8782203380138645, 8.419543100941567, 61.39909213589084, 54.03364189209477, 60.541583568819114, 53.44066189181421, 62.34242608470302, 55.54081655317738, 64.87932097527289, 55.467515299397135, 60.42017836724559, 59.48547363281251, 62.25924830282889, 61.84233173247307, 63.50811919858379, 62.82702707475232, 61.34342978077551, 60.49346000917497, 59.728209510926284, 58.465159246998454, 60.09180145878946, 58.37744720520512, 59.63178588498024, 59.322083380914506, 55.448597708056056, 54.109618202332534, 53.78563827083957, 53.090315788022934, 60.09631218448762, 55.93988241687898, 58.210550354373076, 59.636324067269605, 59.03524437258321, 50.363821368063654, 51.47556228022422, 51.602164622276064, 46.87569287515456, 41.79405050892984, 45.546142747325284, 44.81460894307783, 45.62366447141094, 41.07573116979292, 44.78686994121921, 43.119603741553526, 44.74164893550258, 43.031479850892104, 42.019641707020426, 49.56073960950298, 50.773885557728434, 51.446360234291326, 53.34186915428408, 52.805524256921586, 52.84833692735242, 51.137916811050914, 53.59778027380667, 53.61675277833016, 54.17845972122685, 57.38902561126217, 59.72544031758463, 56.981926733447665, 58.46305685658609, 56.70103796066777, 54.32206946034586, 51.67244565102362, 48.794304555462254, 49.277265994779526, 51.233850140725416, 43.41349124908448, 46.18803470365463, 53.27561247733332, 52.93737473026399, 56.959945771002005, 55.60330775476272, 56.317402701224054, 54.161087543733665, 57.871430074014974, 52.55107618147328, 53.668226042101466, 53.00376869017079, 54.10000447304019, 53.66736704303373, 51.657928959015884, 50.509972803054325, 47.76858906592093, 42.033872066005586, 40.40590801546651, 44.54092948667465, 42.66950784191009, 42.20230648594518, 41.847284916908514, 40.086058339764996, 43.31244707107545, 45.608096584197014, 45.0285977701987, 44.544447852719216, 47.159033129292155, 48.86313430724606, 49.64410958751556, 58.31136703491212, 58.40785341878092, 59.91516536281955, 61.27855770049557, 57.526077147453066, 52.03040507531936, 56.398576151940134, 48.2074159960593, 58.17100109592561, 62.80362621430428, 56.373006220786806, 58.01321983337403, 50.701231495026626, 47.499247750928326, 58.272041351564475, 57.642053788708104, 64.67869958569928, 64.23806836528163, 62.28938387286279, 61.42562697010656, 66.96750456287016, 68.49342423100626, 69.14746376775926, 67.04385742064446, 71.32774460700251, 66.78415729153541, 72.4463261327436, 67.46689288846909, 72.63503136173372, 71.96672224229383, 76.3639110134494, 61.058453898276056, 65.44090240232407, 14.526317504144485, 0.3395110158429992, 1.7137959287051232, 1.8400292002385663, 0.36935593211843126, 33.50618039408038, 91.20590871380222, 76.68362340619488, 88.66162407782771, 81.20152704177364, 82.22685029429775, 64.57612176095286, 55.513477633076334, 60.87312975237447, 72.06174558208835, 103.88278161325763, 19.328461577815396, 1.024309871417861, 0.4491306288588432, 0.31475782634750493, 0.2832755043862328], [0.04383750072109603, 0.10623071583047991, 0.05139758960614282, 0.08622242212896386, 0.06332665494072341, 0.06709319133792194, 0.4547401697885606, 54.90574559857769, 63.19208598905995, 42.25204606210032, 28.878789678696666, 16.365862046518636, 22.51820360460589, 49.43945207903462, 60.80812823387885, 71.51779913133191, 60.32833214729064, 71.6000041654033, 23.596282735947643, 0.12298034729375956, 0.22422051357646144, 2.1737071919825772, 1.65958852777558, 4.146991074085236, 0.13915723610308864, 4.037672656197702, 55.56651984491656, 53.57549728885774, 58.51021943553802, 53.51999575091947, 57.507700843195764, 56.90005117847074, 63.63026572811989, 64.65069386266893, 67.96472795547979, 61.63612488777407, 64.20197471495598, 56.04892823003954, 56.15588734226843, 58.25236674278014, 60.69145733310331, 57.395026837625814, 56.41603069920694, 55.32112459982596, 53.30101374656924, 53.52389066450058, 52.98315271254509, 53.76488108788767, 77.50461470696234, 59.76600154753655, 52.023046708876095, 52.65394033924226, 50.50752132169662, 53.29837399144327, 56.79896777675998, 48.411332176577666, 49.78662890772666, 42.50636077696278, 47.9366155593626, 44.053884860008, 39.86044752982355, 38.61437328400151, 48.80628347396851, 42.00858846787484, 36.69203927440029, 38.36043119430542, 38.56683023514287, 41.501700570506436, 37.10618272904427, 37.64976047700451, 40.60146562514767, 42.999587059021, 46.79682185572963, 47.289196983460464, 47.0773889941554, 48.756630189957164, 48.13664859341037, 47.475125174368586, 48.704446977184666, 49.49525956184634, 48.068587626180346, 50.92787781069356, 51.22220070131364, 50.40432768483316, 50.75823530074089, 51.983234651627086, 50.53473080358198, 45.25717389199042, 42.666236585186375, 43.900171095325106, 40.73235119542768, 38.46949269694667, 45.28646615243728, 49.008222779920025, 52.0824117814341, 52.03502170501217, 48.73279786879017, 49.5936639847294, 47.65030214863439, 49.532937849721606, 47.61549895809543, 48.31297874450684, 47.40118065188008, 47.31947375882057, 46.48019244593959, 45.76397549721503, 44.685739471066384, 41.734465783642186, 36.08258139702582, 39.83927065326322, 39.284808328074796, 38.41056692984797, 37.798457530237016, 37.790612789892386, 39.2233879335465, 38.64405385909542, 40.479330862722094, 41.76471118004092, 38.84097253122638, 42.83231758302258, 44.56522856989215, 44.67973432233257, 46.49231256977205, 55.40789135040776, 53.87128322355209, 56.432175174836196, 54.19693408473846, 57.86309111502863, 51.5282710905998, 48.77892101964643, 33.78142879855248, 54.85156197701731, 59.72274172690607, 55.78212468854843, 47.5645395248167, 47.85211201637022, 59.3465393589389, 55.532446215229655, 57.49801258887015, 58.108274552129934, 59.909093533792806, 58.10520333628501, 56.291369930390395, 57.349295923786784, 57.94017745602516, 56.801576152924575, 58.35378746832571, 62.48795386283629, 65.23480930636006, 65.53073252401045, 66.77987406330725, 65.43608965412264, 70.17408924718058, 45.37728078903691, 61.236560883060584, 4.8055251567594475, 0.1731762283992383, 0.2916078443729109, 0.3800528484486765, 0.4773283641665213, 36.23923693933795, 74.68105731471893, 64.71257709687757, 72.34028093276486, 69.2482686811878, 63.874747060960345, 44.14328352097542, 51.804264745404645, 42.02439954203945, 54.05086894189158, 76.44242117481848, 8.65282214456989, 0.41299049231794577, 0.343106726124402, 0.04186344918824973, 0.08967547917798643, 0.019326090489724473, 0.14375019367904435, 0.06682440938968813, 0.06621474895866648, 0.06854967003868473, 0.06164008173190298, 0.6299890337451812, 66.35789763542914, 70.06245074733611, 54.27232988419072, 35.3734992396447, 35.16265223103185, 37.39485348424604, 53.987479517536784, 67.94573583910542, 78.33552960426577, 64.98148302878103, 76.09464814586025, 26.7477188956353, 0.2557340306380103, 0.36277575778865045, 2.7250093125527908, 3.3913783296462032, 1.2051945684417602, 0.2054129477830664, 5.3360218001950175, 59.719529305734945, 53.943548971606845, 60.975197668998476, 53.33672692698818, 57.14324597389468, 57.53209798566757, 65.64977253637007, 65.73253454700594, 70.3795979099889, 61.67543095927085, 65.83142926616054, 57.53380421669253, 59.93896238265499, 59.21123327747468, 60.63231583564513, 57.78357290452527, 60.47226352076377, 56.955901807354344, 56.663516567599395, 56.10996423229095, 55.880203554707194, 53.96158402965915, 71.90700023405014, 60.2407338542323, 51.556700429608746, 54.223739562496064, 52.41546415513562, 56.47786686497351, 57.90194219158542, 49.56101025304487, 52.3534946287832, 45.59294446822136, 49.90592779651765, 45.4547122986086, 42.24306775677589, 41.4384719633287, 50.81294059753419, 43.92265804352299, 38.70477607173305, 40.82021228728756, 39.222211222494806, 40.90608865984025, 39.34751918238979, 37.72439141427317, 42.572048710238555, 44.31782507127331, 48.17227940405569, 48.76580853616038, 49.52190814479705, 52.28957176208497, 49.262435513158, 49.5596178116337, 53.65207372173187, 51.25831004111998, 50.66174107213175, 54.657816502355764, 53.713882430907226, 54.83777876823179, 52.769210953866285, 54.73785638809205, 51.35919340195195, 47.766117972712365, 45.772859665655325, 43.684236772598766, 42.935864233201556, 40.17357034067954, 45.52236141697053, 49.71670089229461, 53.21972262474799, 54.28149646328342, 51.30772406055082, 51.09419807311028, 50.591001126074026, 51.967674609153505, 51.12327068082748, 50.29579570216518, 49.11729604967179, 48.89279527048911, 48.00664555641913, 47.967347329662694, 47.055666908141106, 44.866086129219305, 39.7881817817688, 40.56177908374418, 41.53683716251005, 41.12517656818513, 40.61445651515838, 39.13810776126, 40.849975232155096, 40.67065623498733, 42.65785448012814, 43.12159630560106, 44.16023992723034, 44.29632656035885, 46.98589970988613, 48.55346710451188, 49.09904133888983, 57.156193717833496, 57.07853078842164, 59.314485749890736, 55.7963825041248, 58.91233690323369, 51.83553388041835, 50.38830480267925, 38.28294477155132, 63.04196511545489, 62.504765141394834, 56.5280379018476, 52.3792528337048, 49.29931755988829, 61.593873116277884, 58.396553070314475, 60.32339388324369, 61.50099531296761, 63.45219404466691, 62.016077041625984, 59.38626904641429, 57.96204074736565, 63.116513682949936, 60.40629317683559, 61.266990630857414, 64.55319942966585, 67.95732252059445, 68.53703314258208, 70.02463125413465, 64.74764308621808, 69.82158583979454, 50.51308324260097, 61.96025386933358, 5.782283582995015, 0.20633824409977083, 1.6149937529717724, 1.3146386247488762, 0.3821599886061684, 39.89033206816643, 80.84259094730501, 70.82069981482722, 80.39154975645005, 75.51928351002356, 67.4035152312248, 55.64714808617869, 57.657955077386674, 48.27116627846995, 62.363045984698886, 88.88918430574479, 11.964745021635487, 0.5742498859763145, 0.26388857693922135, 0.15827920438060838, 0.09126161059905445, 0.21398116624163044, 0.33212602018348636, 0.10518563400593497, 0.26155623757550794, 0.11501131684429224, 0.2665048897747071, 0.7324146214992769, 81.05379489160354, 82.1055627638294, 61.94866326547439, 38.646932878801906, 26.30128845091789, 33.576100564772084, 65.78906766829952, 72.78723501390027, 86.87136803903888, 70.06076412816202, 83.12790501502253, 31.43717327425557, 0.2841598456425052, 1.4136902387103727, 8.405349023880499, 7.428225326922632, 10.944572821740183, 1.5047208508176189, 8.550242358638394, 63.46456127782022, 54.242041341720096, 58.898898863023334, 53.48920514506679, 57.745043462322606, 59.95211408984277, 68.44949368507632, 67.10869419959285, 68.93968797499134, 64.14376674159881, 68.75084154067501, 60.469878719699004, 60.64895452991609, 63.54456193985478, 63.717075624773585, 60.38050359295261, 61.45437009872929, 59.26866069916756, 57.38334209688249, 58.59535840249831, 58.46489644819691, 54.8884871698195, 69.16178041888823, 60.160093845859656, 53.77398883142779, 55.0958550360895, 52.64284787639495, 59.43145475079937, 62.73103098715506, 52.24305637421147, 54.328655119865175, 47.61583628193025, 52.44518003156109, 49.77484218535885, 43.275745453373084, 43.79269815260365, 53.86180285484561, 46.0235304986277, 40.90744972229004, 42.985431225069114, 42.36080161986813, 45.672239103624904, 40.18734962709489, 40.5600610856087, 44.61694894298431, 47.58788547208233, 51.064627324381185, 52.51951286869665, 52.79635767782889, 54.914359123476096, 52.20742164119598, 52.68859447971467, 54.70253936706051, 55.23504818639448, 53.09568551278884, 57.9532350263288, 58.40938314314812, 57.85102198200842, 54.988778252755445, 55.88906811129663, 54.68287652538669, 51.89501270171135, 49.70456115661129, 49.048352549152995, 48.27870115157097, 43.86631319599767, 49.49247075665382, 54.55720770743586, 57.15533471876576, 56.80494154653242, 55.40531827557472, 56.76587081724598, 52.77058770579677, 55.46705638208697, 54.34645875807732, 53.71873048044021, 52.336181286842596, 51.17020968467959, 52.495351068435184, 50.84384102975169, 50.85614942735242, 47.464609299936605, 40.269974354774725, 43.760719068588756, 44.00602802153557, 43.62927652174427, 43.133932159793, 41.34676302632978, 42.723985641233384, 41.34795934923234, 44.480266109589614, 44.88745127954791, 44.978101176600305, 46.808569354395715, 53.158718001457956, 51.19329675551384, 50.51146722608998, 61.4497220900751, 61.207656937260786, 58.77940385572372, 59.67874842305338, 60.89669142999957, 54.43235474248087, 51.41980186585457, 42.70016508717691, 55.41391218862226, 62.301841320530066, 59.10592548308834, 48.94558645063832, 52.1688098292197, 61.859225380805235, 59.49439702495452, 61.901496764152284, 64.11777319446688, 64.54664122673773, 61.84937630930255, 60.86574000696982, 60.711430042020744, 65.08198199733611, 64.89700694237986, 66.40405608761695, 69.26354239063879, 71.61632122532015, 73.59517266673427, 74.76796919299711, 70.97999511226531, 69.50938870829921, 54.74908613389539, 64.2814144780559, 7.809555213297568, 0.2295660452857133, 1.7811650878960088, 1.959248661033569, 0.5920889480940758, 48.274982744647616, 88.79798919923844, 75.97097581432712, 85.86681765894737, 83.92136127718034, 77.26824483563824, 62.9370338686051, 68.67767364748063, 61.131798298128196, 69.16496538346814, 102.87340671785417, 16.283796256588353, 0.8988729636034659, 0.6265820262412871, 0.34134077088486764, 0.2624385257161433], [0.09228819140022801, 0.01799859418233316, 0.10670007491904883, 0.16147089521250418, 0.056995746469305414, 0.06695391655328774, 0.07711896102034277, 43.25467840317757, 70.18942571455433, 46.510998741272964, 38.89543856343916, 23.214061490951046, 14.101153169908832, 47.675621048096694, 56.50262094313099, 72.23655777592813, 62.720750454933416, 71.12783708880025, 42.9583433366591, 0.2590218655044033, 0.3083775703224444, 2.4431877511162914, 2.2052084822808546, 0.6023916662220032, 0.12899973760208777, 10.265236939153365, 69.31436061859131, 59.250147111954234, 60.73507408941946, 55.74856881172427, 63.41918729966687, 62.4115853155813, 69.14870323673372, 61.89941790796096, 59.36886941232989, 59.05109859281971, 60.83678507035779, 59.98288900621476, 58.5473721258102, 55.36775765880462, 57.345302950951364, 56.91759986262168, 58.616374461881584, 57.845428682142696, 56.73590783149966, 57.61208688059161, 50.3530034711284, 62.893146468747055, 55.0811343808328, 45.141456127166755, 54.57203426668721, 52.984466706552816, 58.45432958295269, 51.28234240316576, 55.66734437019595, 50.82619428634644, 44.512837471500525, 43.85828802662511, 48.690044033911924, 41.319141695576334, 41.266707451112815, 44.716153529382524, 42.99371134850287, 39.048869917469645, 39.52014661604358, 37.0140266418457, 38.768094893424745, 37.42091371167091, 39.08651290401336, 37.40204711114207, 38.942028476345925, 42.97002023266208, 44.60342068825999, 46.597679199710974, 46.47938051531392, 49.478832675564675, 48.07210206985474, 47.67823334663145, 48.96209570669359, 47.923401094252064, 48.79920751817765, 50.89057999272501, 49.563763756905836, 49.62805924877044, 51.21936875004923, 50.33306214117235, 50.06334035627304, 44.22119355970814, 44.31705236434937, 43.09743058296942, 40.09128685920469, 38.94862198060559, 45.260676568554295, 50.88168013480402, 51.33947172472554, 50.041092672655665, 49.401585517391084, 47.46787663429014, 48.42740997191399, 50.41230186339348, 49.96439072393602, 49.128651311320645, 49.203780389601185, 49.18957748720723, 48.372096707743985, 45.049409866333015, 44.45022075406967, 40.970941128269324, 38.5592875173015, 38.22785900485131, 40.26130199432373, 38.825804725770034, 38.40047859376477, 38.84769547370173, 40.22116438035042, 40.211072121897054, 38.856505117108746, 43.57879561762656, 41.92188055284562, 41.050577009877856, 44.44450978309878, 43.33907996454547, 44.263829723481216, 50.22492631789177, 53.411969754003714, 55.665814645828746, 54.987436802156516, 56.347102888168834, 56.48426425072455, 53.200326504245886, 46.2700318521069, 32.697493568543464, 53.94908735829016, 62.69780851179554, 44.74830912005517, 52.6905321305798, 59.90522999917308, 57.07616167683756, 55.13920899360411, 57.808134786544315, 60.22209475117346, 61.74217401012298, 62.49745776576381, 55.63214502026958, 56.89113955343924, 61.88294003086706, 57.94292311514578, 57.68279937005813, 57.435384104328776, 60.77494498222106, 54.88868328832812, 69.20508338559058, 57.03283517591415, 57.58140610110376, 56.07747916252383, 1.224844049542181, 0.06479821408227568, 1.0307986361365165, 0.3103163243541795, 0.517641871927246, 49.791763290282226, 70.49962243726178, 62.813063436938876, 73.38905211417907, 69.85943671195739, 68.47156878440612, 39.00542574544107, 20.55119968229725, 35.44893034042851, 57.23723773033389, 70.14452242082166, 4.809090591246083, 0.29453249227616096, 0.3364093096986894, 0.033127151039098544, 0.06165433479773422, 0.06878897292359222, 0.030879738267451048, 0.04360233471097966, 0.2946041368188397, 0.08569274893811635, 0.12498489295643185, 0.05111976015952326, 53.37866883124075, 78.41889565990817, 49.031145111207046, 29.545947582490985, 19.94811957882297, 19.963471735677413, 54.889228497782064, 62.636388117267245, 77.39554143721058, 66.65861791180026, 76.85886706075361, 47.496035329757206, 0.12983886434906913, 0.3083959870761441, 1.5362841635942461, 3.9867142035115153, 1.457798026742474, 0.2564672993556146, 12.729796459597926, 70.21408957819786, 59.629177508815644, 61.703264098013605, 56.586963668946304, 65.50916733280306, 64.6909922938193, 70.78051905478202, 63.570331911886896, 61.744515665115856, 61.73307803369338, 63.88188969704413, 60.449678513311575, 59.54811388446439, 57.31872497066375, 59.93269051274946, 59.533455987130445, 59.689044644755704, 59.36928518356816, 57.59492651108773, 58.13174601524108, 52.788803192877005, 58.964076888176706, 58.52928999931582, 46.945326712823686, 54.378359394688765, 57.80234929054015, 60.01792361659389, 55.53568217062182, 56.736684460793775, 55.70629742837722, 45.351934432983406, 47.783984368847264, 50.35239942612187, 42.29447434025426, 42.14721287450483, 46.77600583722515, 44.62519768745669, 39.779807521450905, 41.68511452213411, 39.08779551905971, 40.46072313862462, 39.097644590562396, 40.172574058655776, 37.309447796114036, 40.49207856578212, 46.17610285359044, 47.74461161705756, 48.48013054940009, 47.8379757942692, 50.3137013220018, 49.75938412450975, 50.35746320601433, 51.06724354528612, 49.983951583985366, 50.87767931722826, 54.705842002745605, 53.088597789887466, 51.68057672439083, 54.06459331512452, 53.493370702189786, 51.42673661631923, 46.251741839993386, 47.97762393951417, 45.33767269503686, 43.221404937005815, 40.84406814267559, 45.952872922343595, 52.44456029707386, 55.0700968311679, 53.87872788213915, 51.77483912437193, 50.91436132307976, 49.0736557591346, 52.581035244849424, 51.720596667258974, 50.32035758418422, 50.48947841890397, 48.515949633813676, 49.15568820891842, 48.79526945852464, 47.13734634460942, 43.85662886404222, 41.44449672391338, 39.42546060008388, 42.192257373563706, 42.34213506021808, 40.54363027695687, 40.6720055303266, 41.19154307150072, 40.40372325528053, 42.18044319460469, 46.09452932111679, 43.53905808541083, 43.645946594976614, 46.218150661837676, 46.20124132402482, 46.05929859222905, 52.40730170280703, 54.64800273218463, 59.42927783535373, 56.36782476978918, 58.84292271829421, 56.01410150527955, 56.55782830330634, 46.7444033007468, 37.80970688789122, 60.227009480999364, 63.218032467749815, 49.20456094126548, 54.070433724311094, 61.53051507088446, 59.848794937133796, 59.47599718647619, 59.322961991833104, 62.084479255061, 63.57484655995523, 64.6154199877093, 57.29617918691328, 59.20648328719601, 64.67265521326374, 60.63656376254175, 60.091687710054465, 60.1466283490581, 63.023149505738296, 59.06065740892964, 70.33827966259372, 59.709009508932795, 61.76370389999882, 57.92631187746602, 1.4522114684504848, 0.07196559480601741, 2.6218274427998454, 0.2242852939713386, 0.5997264769769485, 54.91399826542024, 78.36620253901329, 70.29803614462577, 79.5851182937622, 74.18712892839986, 74.73189123215215, 49.39011258463706, 32.2837580403974, 45.89222915710942, 61.72941061758227, 86.04444611457087, 6.593829326091274, 0.290759141526876, 0.43499106661446635, 0.09099896501509414, 0.05585323358255048, 0.18333299145583185, 0.19470441755988907, 0.1848821897780703, 0.3673899360001088, 0.22176310269823, 0.201061369190293, 0.16851317377821093, 59.84919501889137, 90.49036641274729, 61.160490435938684, 53.35378923723775, 35.41112261433756, 26.896082547403154, 63.54309889578051, 69.62496526779668, 84.72556483361029, 71.62477001067131, 81.62885358256679, 52.962430830924745, 0.4112722796778525, 1.361403941146789, 8.09986306775001, 6.21066524136451, 6.166896002907907, 0.8975584792994684, 18.187950080440892, 74.07020307356312, 60.89948415756226, 62.514174907438225, 57.97330579450054, 65.85301799158897, 66.07314140565934, 71.38374820832284, 63.85236209438693, 64.12056592202956, 63.10574285445675, 66.51606329025762, 62.80626204706008, 62.8374292004493, 60.06538037330874, 64.47748591822963, 62.28570468964116, 62.23820870922458, 61.323637500886, 61.29053269663165, 59.17468855457922, 55.58772025569793, 62.47305670092183, 64.71136900686449, 48.952544735324004, 57.41478381618377, 57.91069299943986, 61.84822705484206, 55.25245958758939, 59.10645892543178, 59.40249981418733, 50.16915805878178, 48.41649793809461, 54.75725643096432, 45.88195254725795, 46.628183472541075, 50.118806592879764, 47.35383764390023, 42.534288052589666, 44.925635553175404, 39.60108472454933, 42.23569370085194, 41.07595474489274, 43.034315724526685, 42.68317730196061, 43.92301890157884, 46.90181586050218, 49.88193858054377, 51.4518476301624, 49.51475766397292, 53.025063237836285, 53.85606050491334, 53.912797589455884, 54.639934416740175, 52.47412712343278, 54.66986994589529, 56.20854908420194, 53.87383668653427, 54.72557544708253, 56.2417519477106, 56.587924649638516, 54.40155236951767, 51.111209392547615, 52.19328149672478, 50.25200636156144, 49.7235885743172, 42.748727952280355, 47.24310521156558, 55.35986192764775, 57.04262541186426, 55.88849544525147, 53.81041980558827, 53.827611554053526, 51.90697593073691, 56.33627714649324, 55.969272736580145, 52.74716723349787, 52.86720352788126, 52.79091735039988, 53.166849074825166, 50.6343040927764, 49.94603010915941, 46.93293986781951, 43.97985796774588, 41.521579142539736, 44.54251020185409, 44.14989663708595, 43.49837526198357, 42.95528781029486, 44.52637749333536, 45.55418360617853, 44.23791854612289, 47.217296015831735, 45.40764777891098, 46.67803287506104, 48.74742046479256, 47.792715564850845, 48.04934840048514, 55.824811843133745, 59.04470905180901, 61.932314826596176, 59.38502957743984, 59.70994695540398, 61.2823506324522, 57.73973257310929, 48.29262164331252, 38.95661969338694, 55.3148135062187, 61.67595263450377, 51.17152760105749, 55.02078871573172, 65.11457297109789, 63.419379495805316, 60.93805282346664, 62.31525582651939, 65.04719057390767, 64.95579934889271, 66.12984318887034, 59.100677351797785, 61.69880044075751, 65.38019587916713, 63.775640533816436, 63.30390099556216, 64.26444238232028, 67.39429766131987, 62.25817357340167, 67.13790801263625, 64.79838286676716, 66.8343714744814, 61.46865144852669, 2.0786419318568323, 0.19768597047415473, 3.2046200671503624, 2.4897595230610143, 0.997466211838107, 60.77934195918422, 84.9414050194525, 76.64072052125009, 86.57156559728807, 83.3836200160365, 83.44613475184288, 58.30305553251698, 34.07614392618979, 57.737159498276256, 73.28464646493235, 98.59261820393225, 10.37053983057699, 0.5786509078837211, 0.8219067451934662, 0.12533927756932475, 0.24695522993082003], [0.06932334989429483, 0.04649719328529412, 0.07467848834611716, 0.05491577562004809, 0.08895678145270194, 0.15386358083736512, 0.3000552201222989, 22.077990116611605, 69.48743912481493, 49.70757745927381, 52.258647795646425, 36.42811083024548, 39.12412843396587, 46.68938029196955, 60.65575984216506, 69.45140823241204, 64.023789282768, 67.52533620403659, 53.703703880310066, 0.5441739482264365, 0.11045711565642588, 0.2430102754864962, 2.493609819681414, 1.0236716895334184, 0.3268104731555908, 18.964597025225242, 73.41356692775604, 56.52819479665449, 60.840421107507524, 59.53788826542517, 65.8080440951932, 59.498511591265284, 63.06027473941926, 57.51019547062536, 61.135508860311205, 56.86546371829126, 57.67876325115081, 54.071504531368134, 55.17990750651206, 53.34896079955563, 56.78404315825432, 54.71542435307657, 59.87002280450637, 54.20393551549604, 55.99612528277982, 48.92643351708689, 52.50489419506442, 33.61090375531104, 32.42914853557464, 57.42048694241432, 54.23261980856619, 57.59816638885006, 54.19313723041166, 55.32912623497748, 51.08586695886428, 47.62006851934618, 45.79238914674329, 45.64468445316438, 47.45926310939174, 41.89807961064, 42.05215423337875, 42.874184962241884, 41.53529567103232, 37.90925272049443, 37.27777465697258, 37.29131467880742, 38.34934657619846, 37.30885551821801, 40.012160885718565, 39.86687629453598, 37.47790575027466, 41.845802260983376, 45.194270841536984, 45.97375169877083, 48.829798083151545, 46.09918125214116, 47.75635519335347, 47.854704703054125, 46.887424684339955, 47.993352643905155, 48.886029181941865, 47.807385229295306, 50.72156898437008, 50.27636035796135, 49.87037935564595, 53.31937828371602, 50.890729042791556, 42.089620713264715, 46.03093201114286, 46.029084574791696, 38.13063913776029, 38.29508450723464, 47.44805689780943, 53.31252982539516, 50.95567172573459, 50.91056446875296, 51.179635140203665, 48.54983891210249, 47.840482188809304, 49.64266223292197, 48.31027230908794, 48.189106372094926, 47.24037131955547, 49.99393401607391, 46.30983214224539, 45.79436602131013, 47.27349573566068, 39.914642918494444, 38.33691658512239, 39.77853667351508, 39.56835646783152, 37.78099121585969, 39.67666879776986, 39.6589945977734, 38.81630082284251, 38.54523758734427, 38.79719888010333, 40.53676612915532, 41.58646298993019, 40.25325721310031, 41.93768378226988, 44.68385673338368, 43.12188263862364, 42.32079344411051, 45.922152919154016, 51.18470676483647, 55.12868135206161, 58.70304707557925, 57.63002780175979, 56.5370201295422, 55.929425377999586, 48.80696596637849, 37.114658970986646, 66.39203794540899, 46.64431225868964, 55.25809603352701, 59.07934750280073, 57.94795551607686, 56.26804359497563, 54.35384850348196, 55.855292581742816, 59.32310711952948, 60.77211303095664, 57.62936099883049, 61.64570723810504, 64.90367889404297, 60.43296921637751, 62.28869745808264, 61.73185425419962, 58.83110461696502, 62.34249276499595, 58.13944170551916, 44.888741739334606, 65.82077610877253, 36.13312113669611, 0.44713221189956515, 0.06413731769087815, 2.0152681969827224, 1.4984717796887121, 1.6563423987357848, 56.24969474730953, 69.65395942811044, 66.98557884462419, 70.6036280047509, 76.16128921508789, 55.6446534587491, 45.762092759532315, 42.03972031993251, 33.7151328979, 63.16396259492444, 68.37028534181657, 3.4302058719819595, 0.2757996813424172, 0.0856980043012769, 0.0742818922885964, 0.09394944540315098, 0.0330153213543517, 0.12302256639926665, 0.049004185373985, 0.20150738557980907, 0.14714365674843713, 0.13017808808194054, 0.29215703748406907, 27.72509901754318, 80.50950327227193, 54.91374331135904, 51.43789968182964, 24.883012348605742, 37.673788916680124, 55.010151247824396, 65.75610406937139, 76.68061102590254, 71.3923381990002, 71.1846879220778, 58.0852267049974, 0.8413892191263938, 0.3039246995843226, 0.5532879430440165, 3.3570757316004847, 0.7548218352660057, 0.23164238870864917, 22.04119436202511, 76.96227642797655, 60.30337018351401, 62.03613996505738, 61.67626250174738, 69.20880179251395, 61.436841026429214, 65.40713863988077, 58.71311972218176, 62.03603013869255, 59.59945771002001, 58.285985377527055, 55.98535837665681, 57.172671594927394, 55.62977983105568, 59.36462933017362, 57.47816539579823, 61.643075327719416, 56.767761399669034, 58.31631706606958, 53.27146653206118, 53.030068182176166, 36.43887381399832, 34.797554093022505, 57.46758676344349, 55.821046367768325, 58.72906415693222, 55.18958399372717, 57.86384421010172, 51.853898417565134, 49.648985093639745, 49.28888405522993, 47.996792562546275, 49.485418335084, 43.68973593558035, 44.86768253387944, 44.27065072521087, 42.141517593014626, 40.020735186915246, 38.821097881563254, 38.956521634132635, 38.3010975007088, 38.81026429514731, 41.49445595279817, 39.74093683304326, 39.369582514609064, 44.45274283809047, 47.251099001976755, 47.49014785212856, 48.04884633710308, 48.486551469372166, 48.96775960922242, 50.188177631747344, 50.68411427159464, 49.56682320564024, 52.7399657618615, 52.26794381295481, 53.670104857414, 53.26532410037134, 52.38906268150576, 55.307035446167, 52.24066765077653, 46.4008625092045, 48.10012348236577, 45.62787709697601, 40.715641898493615, 40.85589801111529, 48.613495057629, 55.230757113425966, 54.40329390187418, 52.43381300280171, 52.21405436915737, 51.13828159147694, 50.99057297552786, 50.21854854399159, 51.73907103077058, 50.228146583803245, 48.22030098207536, 52.00346623697589, 48.726898624051, 47.62817213612218, 48.15625652190178, 42.99164425942206, 40.95880531495617, 41.05480140255344, 40.7830007614628, 39.12995315367176, 40.36614302665957, 40.832434392744496, 41.04288524196994, 42.360236798563314, 42.622823792119185, 42.389670264336374, 43.312807929131296, 42.497382471638346, 44.92164650271016, 48.9640490470394, 45.51598364307035, 44.48121532317131, 51.25391306415681, 53.64429958405034, 58.89177191642023, 59.54241468060402, 59.84966570331205, 57.76442781571419, 57.234394011958955, 49.157531722899414, 40.910681755312034, 64.91073916035315, 48.75419439808015, 58.21109164145685, 63.87484904258483, 59.16425897229103, 59.67434360134987, 58.77502256824125, 60.01912386186662, 64.01401865866877, 61.43340503015826, 59.62873428098617, 60.30087163371425, 63.90720467413626, 61.657839129048014, 65.39420658542265, 63.804987707445704, 64.37775181185815, 62.154905411504934, 58.96892886007986, 46.02273033511254, 71.21627869144564, 38.58845426190285, 0.24766632806389566, 0.03276968292231041, 4.039984648266147, 0.7389023443383556, 2.1467002024573665, 62.66087547425301, 74.5068177869243, 73.76682343021517, 76.20264668618479, 81.6607895205098, 67.67828510653588, 58.75573627410397, 39.76300408763271, 39.061868652220696, 70.28376656193888, 79.67149672969695, 5.084384102975169, 0.3477741321248393, 0.19663433093697796, 0.06129885850954921, 0.04629238350917736, 0.22677495715118226, 0.1375122001815227, 0.20321979127343626, 0.26634413388467604, 0.27247636128337155, 0.23711628611049346, 0.5174018719023274, 32.9173541838123, 92.39699917454874, 65.16428901303199, 70.66907667344617, 51.04245024342691, 53.89755918133644, 62.5585957496397, 74.57259593471404, 80.93531577817856, 77.73308492475941, 78.00335976385301, 65.3100521333756, 1.2863471815663001, 1.3688349940123097, 3.441522155077227, 12.032368644591301, 3.5213374851211428, 0.45612605348710095, 26.843061908598873, 77.5666509136077, 60.52049298440257, 63.12164022076515, 62.97790104343046, 69.79912634818785, 62.71532581698511, 68.34548811758718, 62.502517623286096, 64.55208547653692, 60.83682037168934, 61.716882567251886, 59.58061072134203, 62.523286573348514, 57.77342181051932, 61.54712630856422, 59.14617684579665, 63.726218669645256, 60.24209491668209, 60.61318643631474, 55.43104510153494, 54.69269814029817, 43.189723953124016, 39.149792502003336, 57.50484928008049, 60.22450700882943, 59.12152082689347, 56.2697772825918, 60.3339332918967, 57.28962490635534, 51.533876157576046, 52.27469421202137, 49.19769287109376, 53.37047499995078, 45.034026330517186, 46.11234864880962, 45.35244826347598, 45.98015692926223, 41.82930869440879, 41.35821242486277, 42.05494696094144, 40.20347056850311, 42.12809131991479, 44.09524625347507, 42.46246945473456, 42.24200087208902, 47.67265573624642, 51.345418037906775, 50.362440693763, 52.32140179603331, 51.46760771351477, 52.175697511242284, 52.447451083890854, 51.8737809119686, 52.701871702747965, 54.96247091600972, 54.11491732443533, 54.351867706544944, 56.56013857933783, 57.109737165512584, 59.32697457651938, 53.360625928448094, 51.424555778503425, 52.81702856863699, 53.45715938075897, 48.280317168081964, 43.68879064436882, 51.1106877173147, 57.24557276695006, 56.0717878034038, 56.72494088449786, 57.320038964671475, 52.9950531836479, 53.09137482796946, 53.96230966814103, 54.59505465722854, 53.869369106908, 50.577029643520234, 55.59714963359218, 50.78528004307901, 49.905672842456454, 50.9618337692753, 43.89971610038511, 42.90573258553782, 45.04548357379052, 43.35538917972196, 42.320401207093276, 43.12382813422911, 43.67466226700814, 43.9312715684214, 45.24789356416272, 43.97713584284629, 44.82640743255616, 43.95135018133348, 44.13164584867416, 45.87259769439698, 50.71930185441048, 49.61999877806633, 47.9520030175486, 52.95517836847613, 56.465519243671054, 61.36506949701617, 65.56990523492136, 62.52182745164441, 61.80257458840648, 58.91268207180885, 51.329767780919234, 43.33659318185622, 58.32886865062099, 52.59249248812276, 58.847872749451675, 65.98712382778045, 63.720158607729026, 62.478391124356186, 58.021382285702614, 60.79916954040528, 65.6273522684651, 67.33405790021344, 65.30275260248493, 64.0488257715779, 64.31924181599771, 62.543678975874386, 67.1176685825471, 66.52401785696706, 66.2750179536881, 64.10392330538842, 60.54157180170859, 52.786343866778964, 72.74058234307074, 44.50927988175423, 0.6494954096213464, 0.13765663839876652, 7.672608110212511, 4.174714876759437, 3.1446977728797547, 68.42809323341616, 81.11972208945983, 80.88794923597767, 81.34546233761696, 87.54322298111455, 72.31019635354319, 64.97101030042096, 60.816114179549686, 52.38965888177195, 78.33185042104414, 91.81923404816659, 8.460074913117195, 0.6058702569815421, 0.4652006407418559, 0.16963799003391497, 0.28045458478793023], [0.06371270579796645, 0.05417908631986188, 0.04423086388757633, 0.22104710160243898, 0.057732221264872825, 0.09823573798301721, 0.375104563971681, 8.508748585178006, 72.71121947996079, 49.08023749628375, 35.535857908187374, 33.06834582359561, 34.932232595259144, 43.985086487185576, 56.564406118085316, 69.69991391704929, 66.75322548035653, 62.91441355982135, 62.28295903052054, 4.301876646857108, 0.09742967559084778, 0.8181896252978234, 4.366458962040563, 0.2880190901698605, 0.213711763762178, 28.870423263119115, 68.18650660976287, 48.36744085434945, 63.7901964495259, 63.569920063018806, 62.41814744087958, 59.82829663061327, 58.642136589173354, 54.550829933535674, 55.89190398493121, 53.63356013451853, 56.63570696307767, 54.415939623309725, 55.92444789025092, 51.58758124997539, 54.2670189949774, 55.52827673573648, 53.28661080329649, 52.97537073012322, 53.74297465047529, 53.020909447823804, 48.812951503261445, 38.3810354048206, 48.432195263524214, 57.71110711559173, 55.71333808283652, 54.377896555008434, 54.46738543048982, 49.724023957406324, 45.80952598202614, 44.066138344426314, 43.297918611957186, 45.672596039310584, 45.52857052895331, 40.91472179658952, 42.47953176498413, 42.65961954670568, 40.2115192720967, 41.56081461137341, 43.5934260583693, 39.55051360591766, 39.54575969326881, 37.498996334691206, 37.81451179135231, 37.18160990745791, 38.66172805909188, 36.63450594871275, 41.221031450456195, 45.77937864488172, 47.6884275867093, 46.2651720354634, 47.66641916767244, 47.50012636184693, 47.21469548440749, 48.994227763145204, 50.60114045296946, 48.591059100243356, 49.05627573690107, 52.84313194213375, 51.18842909413, 50.89399637714509, 49.84909265272079, 41.45127457957114, 44.23663200870637, 45.531916310710294, 39.50310784001505, 39.72611811853225, 45.95380252407443, 51.07379390347389, 53.16459371197609, 49.5313806687632, 48.88991625078263, 50.17494355478595, 47.81865419880037, 46.81626112230363, 50.37579244182956, 47.384043816597234, 45.46310224840718, 48.62465027839907, 45.98350663338938, 45.10473489761353, 44.59881582567769, 39.397407808611476, 38.98007938938756, 39.17891217816261, 38.180441471838186, 36.41653983823715, 37.43220229302683, 37.9248833656311, 41.587886810302734, 39.1401905398215, 37.94539736163232, 42.420296130641816, 40.3409888667445, 42.2419891049785, 39.81310844421387, 46.949931575405984, 44.604566020350305, 43.30992498705464, 44.51331600066155, 45.75574244222334, 47.887138782009, 52.6388745154104, 53.86174794166319, 54.41918342344223, 54.73614231232674, 57.312582538973906, 37.446122784768384, 46.651431360552394, 56.630678484516764, 53.01952485115298, 60.4191271720394, 55.1123329131834, 54.28082966035413, 54.394190080704234, 53.73729113609561, 57.364197008071415, 60.5399126391257, 61.002442452215384, 63.144848885074744, 59.39152894481536, 61.10557333115609, 65.73964188175817, 66.21108331987935, 66.61082775362077, 63.72036649334816, 54.92742061614991, 55.720555243953584, 65.30054823044809, 19.191504178508637, 0.03633702879831676, 0.26344387822093507, 2.0992363364465776, 0.11843399850711708, 2.3996614544622363, 65.08013063861479, 67.03281987097957, 71.68175420453473, 69.36883449554443, 76.2788583386329, 48.53950738906861, 60.17546561456496, 38.85196693481938, 43.527243906451815, 68.89996220988613, 62.62657434709611, 2.215500536464876, 0.09579259166193586, 0.24450005602932748, 0.10101801610641903, 0.16774909300429208, 0.038642712132704836, 0.02783628353368371, 0.028818994309873353, 0.2667007631351871, 0.04433618948584603, 0.21929547220708864, 0.5459570944789918, 12.483751081651258, 83.82043084790631, 56.8247377487921, 45.362454229785556, 34.35711506874331, 46.31476648392216, 51.749673197346354, 62.406603905462454, 75.02853224354406, 70.41026299999606, 66.2962850447624, 66.62894125907653, 4.836791840291792, 0.08725206728183454, 0.7329626501567903, 3.894548800683791, 0.5582310487666439, 0.1515296633325277, 32.59467059566129, 72.55510914710261, 52.25843206528695, 65.86817402993479, 65.14930163660358, 63.803705092399355, 61.631469034379535, 62.093539930159054, 55.38535341139763, 57.98084458997173, 55.8638237368676, 57.72918531971594, 56.51489796177034, 56.36393770094841, 54.07272046612155, 57.91085381661692, 56.61913102672946, 57.69987344741822, 54.40919314661334, 57.17258922515377, 52.045443442560014, 48.50453945898241, 38.51349384553971, 48.07140781033424, 59.31471324736073, 58.546379766156605, 57.90969671741609, 55.15476903607769, 51.090067817318825, 47.77641027204452, 47.21570353354178, 46.13199187863258, 46.81679456464706, 47.61811125663019, 43.30950529344621, 44.15018297010853, 45.239570294657064, 42.82404530432917, 43.71422329256612, 45.154686281757975, 43.32725794084611, 41.48580712656821, 39.217743642868534, 38.64140625922911, 37.419858594094556, 40.2456791939274, 38.45745102051766, 44.07368498463785, 49.42236623456402, 49.36808847611951, 49.059939230642016, 48.77106451219129, 48.83688580605292, 50.025618922325876, 50.783456140948886, 52.50081100771504, 51.6670641591472, 52.298867779393355, 54.2158281418585, 52.820056638410016, 54.60435851927727, 51.093366530633745, 44.72295099689115, 46.27535843080091, 45.737628936767585, 42.50661573102398, 42.5026031463377, 47.67953557352866, 53.560137287262954, 54.26300248792095, 52.311988107619754, 49.92855595004175, 53.357021270259736, 51.397460045353064, 49.43581996425506, 51.026901968063854, 49.896902422751154, 46.53871813128072, 47.903059682538434, 48.49151719001032, 47.09908362357847, 47.35240597878733, 40.800486687690984, 38.952728702176, 41.56409763520764, 39.58349681669666, 39.003193916813025, 40.256406876348684, 40.80365596279022, 42.74586462205456, 41.8383615247665, 40.33646637393583, 43.9406224989122, 42.28563331788586, 44.231670210438395, 42.98597251215289, 49.37827487145701, 47.38034502152474, 45.0864331183895, 46.61620455403482, 49.359937790901434, 50.93344757633825, 55.41559096305601, 54.45735985232938, 56.01610191406743, 56.76822423934937, 60.04321898183515, 38.59332192328669, 51.09897159760999, 54.8416462252217, 53.88852204045942, 62.07335149088214, 56.58355905163673, 57.98091127026466, 57.97611813391409, 56.6674820838436, 61.112441401327814, 64.14465711962792, 62.18842990936772, 66.50286843699794, 64.42057232702932, 63.06107882530459, 65.97743557345483, 68.35383492131388, 66.13459710151919, 65.292511293965, 58.21446487980505, 58.1029518958061, 69.53642168352681, 22.686086931536277, 0.11347524160819669, 0.9161388693797974, 4.317481306291396, 0.3278431596775209, 3.1884831911133182, 69.69545025979319, 72.40396453488258, 79.62100013609856, 77.41949927422309, 85.16890248944684, 56.39688953276604, 59.357239584768976, 44.99704230216242, 52.00530582858671, 76.08422248594223, 78.17053118059712, 3.286089166518181, 0.22012520671611835, 0.1572019162197267, 0.1511672271355506, 0.08985747868615775, 0.138125131807981, 0.1545853735578637, 0.13869124014050732, 0.4293767452961014, 0.2599494141196051, 0.3230821070892196, 0.5712022043524251, 14.924541038851585, 98.60945301671183, 64.07821216890889, 50.8282260740957, 44.0062084505635, 51.800962109719556, 56.92389134437808, 73.5084725964454, 80.53299042486375, 78.20612276754072, 70.9076116931054, 74.10263323014783, 6.573971836797654, 0.38883249185258345, 2.2753625242940845, 9.938706486455857, 1.641125318504149, 0.3009991936625973, 36.54464837043516, 73.72035118841356, 55.588642012688425, 66.730177633224, 66.87007288778982, 65.20406576894945, 63.7304195280998, 62.29958595768098, 57.48223681603709, 59.64505134090301, 57.49334889073526, 61.55314714677873, 57.44979881471204, 58.47908758348035, 55.14291171104678, 60.60476902992495, 60.08182687144126, 60.09124055985482, 58.13251479979485, 59.52012777328492, 54.52049432262298, 50.464010469375125, 39.189624171103205, 48.91609807168284, 62.784269317503906, 62.535179199710974, 58.98142945381903, 59.68680497138732, 53.99785810901273, 48.87527012055921, 47.83454764273859, 48.905676334134995, 49.56827056023383, 50.6143117720081, 46.10414697277931, 45.90702433739939, 47.00451135635377, 45.941960888524214, 46.56998726629442, 48.944860812156435, 44.65392120422856, 45.033940038373395, 42.30722204331429, 40.54648184007214, 39.15998281971101, 42.83004260832264, 40.64524319864089, 45.58453490657192, 50.15234678022323, 52.84044119619554, 51.42171990486884, 53.676004102153165, 51.224224644322554, 52.17281849153581, 54.56892774951074, 56.672789050686745, 53.21721623020788, 55.37828922271729, 58.895298127205145, 57.8654053134303, 56.26015963092927, 53.53925066609537, 49.68297243118287, 50.723341895687966, 53.70140144901892, 48.94916365223546, 43.21672554939024, 48.84018844173801, 54.43823829773934, 58.26538901175223, 55.95710162193545, 53.07172375340616, 54.63330953351913, 52.967098451429806, 52.59113927041331, 53.74158220906412, 51.75226196166008, 49.28547159318001, 51.407689586762466, 49.34168308011947, 49.97250218545237, 49.99528331141318, 42.99793181880828, 42.59492789545367, 43.29139178799045, 42.99948507739652, 41.448234742687596, 42.0276786435035, 42.20888037835398, 44.865748805384484, 42.80768117597027, 42.93875894238872, 46.97108099537511, 43.12685228163197, 45.210544755381925, 44.636960875603464, 53.07405756365869, 50.11413112763436, 47.959588881461855, 49.05133355048395, 51.86402989972023, 54.23328661149549, 58.691609444156775, 58.19394303906349, 58.39820831052719, 60.88827402360978, 62.75021137729768, 38.24751007941462, 50.426536144748816, 55.278770846705285, 56.72376809581634, 65.48600181456536, 60.05291900327129, 59.69334748483474, 61.00394864236156, 58.83797660950692, 65.14968602888047, 66.91688245342624, 63.828537617960286, 68.14802815837245, 65.22245384031727, 68.1973715751402, 69.6826711777718, 71.82667793766146, 69.23311264284196, 68.74491876171481, 60.31162285035657, 63.32855309209516, 72.12324050164992, 25.2860947193638, 0.1779275210273843, 0.9835823084558211, 7.648797852377738, 1.022623313530799, 4.527190337258001, 78.87440050801924, 76.06627372003372, 85.47100344011861, 83.0986519782774, 90.3479294623098, 63.398645847074455, 78.55438217040032, 52.99490413358135, 63.400465826834406, 86.24708360241306, 90.59555653602847, 4.735864843091657, 0.34082004560097573, 0.4657963507117764, 0.2598230402556158, 0.350689617616515], [0.06325008828313121, 0.12339584274037231, 0.06932287491978177, 0.04860741694668128, 0.0136509973315462, 0.07173698650853289, 0.29979432121880595, 3.7823660719779233, 62.13244984226843, 53.006075043832105, 46.50342464447022, 23.924547856853856, 31.33540149657957, 38.81490445906116, 62.18641773346932, 64.98726068004486, 72.72565380219491, 58.001770434841035, 68.44594786244055, 8.821103592072765, 0.2842120928389411, 0.39906074623427085, 0.9682783844970888, 0.3576977899478328, 0.2566383055020725, 35.18126387749949, 59.215077200243556, 48.900290919888405, 65.5453472752725, 62.79966854280042, 62.9792699506206, 60.65052740035519, 56.52610417335265, 53.82043361663819, 59.45208249553558, 58.601524368409194, 59.05814709201936, 56.63775836267779, 55.095050950204175, 54.4610547250317, 56.42355380519744, 56.701775366260165, 56.24641956821565, 54.77311849594117, 57.28736954350626, 53.642428613478145, 51.438821438820135, 50.89273729631978, 49.59397777434319, 55.599836457160215, 55.41418283216415, 55.152478371897054, 51.30467637892693, 47.446582086624645, 45.47105289274647, 45.659722820405044, 47.556902670091205, 45.68146844064036, 46.105978719649784, 43.657337157957016, 42.91939812321817, 44.9200540204202, 43.97074237946541, 48.69235430994342, 43.13658760439965, 37.806855324775945, 37.446409117790964, 36.94050965770599, 37.766207802680235, 37.669811633325395, 36.94684820790445, 36.72688561101114, 42.0732448177953, 43.48669052124024, 47.75857133250083, 46.59558073166878, 47.922275374012614, 44.55731322688442, 46.94203192187894, 49.056871937167266, 48.78038406372071, 47.56229200670796, 50.87578089006486, 51.16643636457382, 51.80400586897328, 50.297858868875814, 51.30850853458528, 41.4621905357607, 42.46009642078031, 40.405770732510476, 39.53029771004954, 40.995346115481475, 50.35386247019614, 52.241087344384965, 50.01223971766811, 50.75187713869157, 51.41242388756045, 48.90243253400249, 50.30556632626442, 47.50064411470967, 47.69702542212702, 47.05530212771508, 48.36579345887708, 46.74179492458221, 48.132271228298066, 46.127375248939764, 42.954770057432114, 38.66134758918516, 37.90642076923002, 38.16184551485124, 37.081303135041274, 35.70620644477106, 36.74517954549482, 38.53182308135494, 38.2507146558454, 45.601624673412694, 42.4752014683139, 40.51087456364786, 42.23949447754891, 41.00222203039354, 42.76520582937425, 45.93510066309283, 47.430771012460035, 44.78131978742538, 46.999023960482695, 44.07689740580898, 44.41698651159964, 49.06475197884345, 51.99688057745657, 52.623055596505445, 55.43707378448979, 56.65766046893213, 51.2386981902584, 34.332133493115826, 58.976126409346065, 60.58927959011447, 55.095709908393125, 56.569917048177416, 54.93317865556287, 58.069976529767445, 54.343273793497396, 59.009595994026434, 59.411905657860544, 63.524957933733546, 63.03177479774722, 67.63808081226965, 63.34368951859013, 65.6864074737795, 62.38180668123307, 65.2233010722745, 62.56501666961178, 71.45664153560516, 56.343929690699426, 65.64546185155069, 11.33420636576991, 0.5019841685650811, 0.7772622053180972, 3.020701110363007, 0.19041260914696803, 3.115128249891343, 68.46571660810902, 64.47506581583332, 74.07491776251024, 67.33632503017303, 79.61059801040157, 47.901447588397616, 65.04639433276269, 34.842516222307765, 37.17893877337056, 69.21247313099524, 51.44946282909763, 0.04497867678442309, 0.03917615447613982, 0.12157335787290528, 0.0793431134473893, 0.04217834962952522, 0.04788366304109654, 0.09849996936898078, 0.019093960103008057, 0.12403787804707406, 0.027316764838272528, 0.04901587587570952, 0.35550123200781886, 5.970221008023908, 75.88703709263956, 58.95631059523552, 50.70840943244196, 28.528865229698923, 39.0398092423716, 44.41334655207973, 70.3853088809598, 70.50218766735446, 75.7920608212871, 61.22191867520733, 74.30775750067927, 9.596479688921283, 0.19467547475810976, 0.3884036664760882, 3.6732060197860967, 0.10571031996439542, 0.2272839459680742, 39.313241589453916, 61.563937587122766, 54.34057520281885, 67.74443980186217, 65.33974055320986, 66.21104409617763, 62.06165498302829, 57.71442151838734, 55.07518806765157, 61.60090984836702, 60.73074379274922, 62.20629630550262, 58.05831532324515, 56.385769613327525, 56.8497585481213, 58.29095502053538, 57.52102513467112, 55.82734177189489, 54.47945064113986, 54.79421300272788, 52.391776961665, 52.35690709083311, 50.57190310570502, 51.46683500659082, 56.456156546069735, 56.28919301494476, 55.83613572582122, 53.61035147020894, 50.221192221487726, 48.01201528118503, 47.91700370850102, 49.51992342548986, 47.50988129646548, 48.32278074756746, 45.856453218767726, 43.886576160307854, 44.00292934909944, 46.95248111601799, 51.273944608626834, 44.13375608382687, 39.079735048355595, 40.96228053492885, 39.030701498831476, 39.43942423789732, 40.913764738267474, 38.43708999695317, 39.89346996430428, 44.51391612329791, 45.07457971572877, 49.242145092256614, 48.32571860282652, 50.20530269991968, 45.84967144073979, 48.21865750897316, 50.95143164357832, 50.43493001691757, 48.15935519433791, 53.20249949732135, 52.52200749612624, 52.98425489856351, 53.66696696127615, 54.08014551285775, 43.10778956259451, 47.0021971579521, 41.4211586213881, 41.9844658913151, 45.19646736883348, 51.6277894666118, 53.13528576204854, 52.367917183906805, 53.1385217174407, 53.072574907733554, 51.65640315701885, 51.1506135232987, 49.101908591485795, 51.39398482538039, 51.339962020997085, 50.52161047535558, 46.80627084547474, 49.48290409580354, 51.17497144206878, 43.95614331768405, 41.42803453630017, 39.324604695843114, 40.342051829061205, 39.16806290226598, 37.653694614287346, 39.35974521021689, 40.48089196605068, 38.3242198728746, 47.44188308715821, 44.9494247282705, 44.42332898416827, 45.941333309296645, 43.27669074458461, 44.331831855158654, 50.03284785055345, 48.68276019250193, 47.37683842259069, 48.99956610894973, 47.75602179188883, 47.05327033996583, 51.38846997291812, 55.46174549287366, 54.31003170628702, 56.386558009732155, 61.2891794789222, 50.87434138021162, 39.32393004817348, 57.60715253891484, 59.29007291793824, 58.8285707658337, 59.78355415405766, 60.22242423026793, 60.83327454905356, 59.16202714366298, 60.03051050247685, 61.73421552104335, 63.07606620173301, 64.82081097941246, 69.00192030014531, 64.063122810856, 66.82706802122055, 64.9966626013479, 66.06950144613943, 65.01400339987971, 71.44958911403533, 60.45145534699964, 71.53541841814595, 12.936669126633676, 0.2841284360376097, 3.6267318167994103, 5.475222795240341, 0.06561373766030996, 3.8639143541935956, 74.59774617225894, 70.32767357364779, 81.42624747368598, 73.73868434659897, 88.0053174111151, 54.835201771028586, 68.6000342522898, 30.41169704929475, 42.74943397891137, 75.65966513849075, 63.70182937191379, 0.6705647887241456, 0.08225646921463552, 0.015174232934030796, 0.05872335134735031, 0.05622870476555921, 0.10936145670711996, 0.17518898652445886, 0.12322967060871663, 0.21856401145698565, 0.18185231203754104, 0.23714363544939027, 0.4535564720149963, 6.7005467222582915, 88.73619617954378, 68.61819482618763, 65.59460439989644, 34.90608999806066, 47.93116346482308, 52.21874160151328, 75.33195895533409, 76.17264055436658, 81.82125368425923, 66.4701166460591, 80.4773163026379, 11.974854930754631, 0.5010539539639027, 1.0784828903213626, 5.068438687632161, 0.9319096166760692, 0.4327299121406771, 42.83834234360726, 65.93945134070613, 57.97413733697707, 70.44827861170616, 67.43077570392241, 68.24735041587584, 65.97288562405494, 60.0682201693135, 58.92357841614754, 64.11547860791607, 61.627778084047385, 65.74917716364708, 61.239271240849654, 61.689661318256015, 62.61908262006698, 59.45722864520166, 59.115456842607074, 57.1087291163783, 53.86525846296742, 55.99746281100858, 52.51579053940312, 53.08495783036756, 52.4101964119942, 53.816809346598966, 58.5064539601726, 58.32530713850453, 57.66898478231123, 57.2337075971788, 52.13225726158389, 51.87812689811953, 48.55911923993019, 51.59856388645788, 49.54250451057188, 51.324256850827126, 47.743885978575676, 45.194980790538175, 48.132337908591, 49.594656344383, 52.852396580480764, 47.56999554172639, 42.48367771025627, 41.62677711056125, 39.32349858745452, 41.44148434362104, 42.918197877945445, 42.01353457666213, 42.43837825713619, 46.246383882338, 49.96695203165854, 50.6722883255251, 51.289226162818174, 53.49808539113691, 49.485622298332956, 51.53790050937284, 54.22762663133683, 54.40817725273871, 51.7668806352923, 57.06425336099441, 57.59890379444246, 56.29617875622165, 56.27084808964884, 57.26299985762566, 48.5356830781506, 51.06821237071868, 48.441448134760705, 47.09424734115601, 46.09980098662838, 54.84330538780459, 54.81722554852886, 54.710603760134795, 54.67700081486856, 56.47720398441438, 54.116427436951675, 55.4335161947435, 52.42343833369594, 51.823390222364864, 53.47408440805251, 52.18177718500937, 49.941009475338845, 51.686256316400346, 52.27532963598929, 47.06215843077629, 43.07993288963072, 39.54463005065918, 41.51941007183444, 42.029859481319306, 39.87471319014027, 41.943108420218195, 42.03266789836269, 42.30786531202255, 50.28278127793343, 46.60020520610195, 46.51898076457363, 49.58718815157491, 45.95874471049155, 46.77720216012771, 51.02825126340313, 51.79872635872134, 50.51698992329259, 52.722428844821074, 50.958833156093476, 49.716214518393244, 55.598836252766276, 59.96897243684339, 57.876917469886045, 58.37209709229008, 64.13170545331894, 50.7905948546625, 48.35898030188776, 57.76945237190493, 59.95813492805728, 62.46638082688855, 60.178281876348684, 62.44246221357777, 63.27403606907014, 60.72963376199046, 63.905149352165964, 65.25831214843258, 68.28742134955623, 67.41846730632167, 72.882172061551, 70.73384284973145, 71.79565198959844, 70.8674152435795, 68.97735057338592, 68.39989923661756, 75.44617837475192, 64.90649123345652, 74.22394429483722, 15.421213123106188, 0.47146258214789055, 2.9166590158016454, 7.424679994583131, 0.9610947473875938, 5.110563472394021, 81.70408464247181, 77.2816671863679, 85.45735359191896, 80.5796117167319, 93.11176484630954, 62.39557812290808, 85.56145329629221, 46.97696062826341, 55.49955714133478, 85.77860355377199, 77.10934961995771, 1.829089587253909, 0.20379328469355262, 0.28151736324352605, 0.19546653714872178, 0.1225001710436998], [0.03671348823474781, 0.009449335442285144, 0.11317915628634154, 0.07753387424013308, 0.04766461169046741, 0.03256333713990546, 0.15341730397795478, 1.1144165814884248, 55.877046046718476, 56.512368033009196, 42.18914301164689, 28.769218267933017, 38.19979836863857, 37.675789325468, 61.952966105553415, 63.90085827919745, 71.51419055077338, 55.01068076779766, 71.18533903552641, 19.38452401468831, 0.3640054514811885, 0.19446009679907755, 2.022042007696244, 1.3253247545611475, 0.10873168646808594, 31.04180620562646, 56.77987760113132, 48.04024457931519, 62.710199279169885, 58.94530834690217, 60.831415345591886, 57.85477176789315, 56.40594236312374, 56.17236129699215, 59.48534419459682, 60.46002964819632, 59.9119568640186, 57.30605571500717, 53.975426073997255, 53.91371934644638, 51.72358551333028, 50.87271359659011, 52.31762847592754, 54.7476113227106, 58.40567650333528, 56.94020448192474, 58.20301940364223, 56.97013608870968, 56.90615046408869, 55.0049227283847, 56.48477415884695, 55.50220081883093, 53.74377873636062, 51.73138318523284, 54.91610457820278, 51.31785946507608, 51.00759606207571, 48.04248033031341, 48.667561008084206, 44.908961557572894, 41.449838992088075, 45.06447961253505, 50.72233776892386, 45.54023565784578, 38.82979377623528, 39.86813145299112, 39.988928687187936, 38.894516806448664, 39.23832039679251, 36.19116044813587, 38.35750902852705, 38.71710408118464, 42.33989538684968, 41.41369435095018, 46.23664855957032, 45.90571818813201, 45.31023179331134, 47.44589959421466, 47.31719093938028, 47.677386114674235, 47.8010388343565, 49.38470363616944, 47.03780051200621, 52.278169431994044, 50.573103350977746, 48.913019011097575, 46.93833704917662, 38.925338791262725, 41.849759932487245, 37.769663410802046, 35.92046591543382, 41.8624605671052, 53.19013618653821, 51.736443042755134, 50.76868449487994, 49.7525905793713, 52.189567012171594, 47.94828853299541, 49.94297458279518, 49.11535839880667, 48.387923471389286, 47.12437898881974, 48.388280407074966, 46.465358041947894, 47.539593250520774, 46.072250258538034, 43.28583378945628, 38.87304182975523, 38.1575426747722, 37.187791562849476, 38.53074835192773, 38.01685902380174, 38.00057334284629, 38.50391149520874, 38.82369449061733, 37.898881973758826, 48.934646960227724, 46.40826794408983, 44.77557351512294, 42.49749622037334, 44.67590216667422, 45.289003925938765, 46.6226686200788, 47.04036181972873, 48.8120375910113, 49.89776926655924, 53.06191782797537, 49.57437376822195, 53.75463585699759, 52.06704001272879, 54.54386772647981, 54.00220801753383, 60.65892519489412, 28.18647369261711, 50.48350072676136, 63.6220601297194, 53.92399987866802, 62.237514449704086, 56.404691127038774, 61.821962864168235, 57.9308069136835, 60.96117519563245, 60.11531606797249, 60.26309528658467, 57.41300306012554, 57.8115511709644, 59.21392794578307, 62.21641602054719, 61.076994942080596, 66.18019857714253, 62.87003586369177, 67.9060100740002, 59.006583613734094, 58.208498954772956, 3.191508319108717, 0.3680808860207758, 2.390819451501293, 3.8130196400227088, 0.15781438819343047, 4.298347003998296, 68.35584317484211, 65.44461296450707, 73.66649704594766, 70.0463298059279, 73.99721560939666, 53.46100722589801, 34.31045063080327, 39.02527293851299, 49.30096103299049, 72.32747831652242, 45.447424534828436, 0.1516084478146607, 0.12332890197754869, 0.0036675681316879613, 0.15766216652287593, 0.004595733208266358, 0.011347310613810776, 0.15993361721836752, 0.05272369546395156, 0.08264749581294675, 0.06586115341633558, 0.07484557978328198, 0.18753358944048806, 2.0489689563551257, 66.18475637128277, 63.740754973503854, 50.28647615063576, 31.03246508106109, 50.023104683045425, 40.410406974054155, 70.14611490311162, 69.14460043753348, 77.48956849498134, 61.48496850844353, 81.26912516932335, 20.74137972247216, 0.4406709650591497, 0.2166680357749424, 6.226636642409909, 0.5828610206803968, 0.08663558100740756, 35.44612192338513, 57.83813699599236, 52.215070263032, 66.2609052658081, 62.94309393052132, 63.40956964800435, 59.72700926565356, 59.0998811106528, 56.62008416268134, 60.57009919997185, 60.71395604841171, 60.86633228486585, 60.27681965981761, 57.26918151301723, 56.31533953451342, 52.66169094270276, 51.69981595008604, 52.276404365416504, 56.33584176340411, 59.39582786252422, 58.93053277846306, 60.14115272029754, 57.99464348823794, 58.69047587917697, 56.52537853487077, 56.85278269552416, 56.96038507646131, 53.396974532834946, 54.4092833611273, 55.290502655890684, 55.69349873450495, 52.28862254850326, 51.51512722815237, 49.93252538865613, 46.82154063255557, 43.6501984442434, 48.23191904252576, 54.458124714512984, 47.49291312310004, 39.91550583993235, 40.814140458260816, 40.99155318352484, 40.084218748154186, 39.461024730436264, 37.72564265035814, 39.85673696764054, 42.12084277983635, 43.33820527599704, 44.55963134765626, 48.74348632750973, 47.05387046260219, 48.387499855410674, 48.508744239807136, 49.44312341751591, 50.0660664035428, 50.658179560015284, 52.3687957948254, 50.70715819635699, 52.48218367176672, 54.66041311140984, 53.56899007674187, 49.026995243564734, 43.568589610438195, 45.31513475602674, 39.39420323218069, 41.22651884632726, 44.929746197115996, 52.80157443015806, 51.49627239473405, 51.85107431104107, 51.8160593125128, 52.332792359013716, 50.51705660358552, 52.553096202112016, 51.5200537250888, 49.48668918301983, 49.162395461913086, 50.25832529990904, 48.317434557022594, 48.69992448437599, 47.37468896373626, 44.120172915920136, 40.58925528680125, 41.12797714048817, 39.880981137675626, 40.42072280760735, 39.59182400857249, 37.853837474699944, 41.24831545737482, 41.66935443878174, 40.93857765197754, 51.8576011350078, 48.55931928080898, 46.79220914840699, 42.729508338436005, 46.5519404411316, 49.21635158600346, 47.974580180260446, 48.396678201613895, 52.214340702179946, 52.65906687705748, 55.37298225587415, 52.037241766529704, 55.58727702786846, 55.43668546984273, 57.20656871795655, 57.79659909586753, 60.94746258951003, 33.00100265010711, 52.17780774639499, 58.99922132492066, 57.67953203570459, 61.516496519888605, 60.45965310065978, 64.53248539278584, 64.68903503110333, 62.62448372379426, 63.13773762795233, 60.54194834924514, 59.58702379657377, 60.86426127341486, 63.2539653008984, 63.90515327453614, 63.99543446879234, 67.7956267326109, 67.73377879973381, 69.58702810349004, 63.65230552611813, 64.48657797228906, 3.8874309245617162, 0.3021091937778458, 7.408445304439915, 3.0100673196777223, 0.08734385993692183, 5.673382897530833, 78.00436389061713, 70.36475566125685, 80.55581861926665, 73.90475749969482, 83.76125797148674, 59.381432763991825, 46.51598407376198, 38.82003491924655, 52.05892855121244, 81.3972846923336, 55.56751220457016, 0.0465819149488403, 0.036342460361699906, 0.030921028491349953, 0.11587104369555751, 0.08693288440906233, 0.09677640177429685, 0.2508301486171061, 0.307083280096131, 0.19165773185030108, 0.12454184132718271, 0.18549605603179625, 0.3082560687776535, 2.5593308479555192, 79.182738027265, 71.41844549486714, 60.88089212294548, 40.35252847979146, 57.5306349415933, 50.594264538057395, 76.03444760845554, 74.36036432943037, 83.62568516885081, 66.34626388549805, 86.17076212360014, 23.096445298963978, 0.47632356324503505, 0.3095975193765856, 4.128477977168176, 2.6726714113066277, 0.40444818295298085, 39.44051073443505, 63.502514131607555, 57.11814280479186, 68.8586361177506, 65.16752104605398, 66.23193463971539, 64.36689469122118, 61.71232869548183, 61.18398935564103, 63.04806047870267, 63.86277206482426, 64.37024047297817, 64.07820432416855, 59.369900995685214, 57.44597058142386, 53.22131902940812, 52.226735391924464, 54.51017456669962, 58.60090855629214, 62.80399883947065, 61.72744551012593, 63.123260159646314, 62.418206276432166, 60.38745011052778, 58.26920155555972, 60.3034290190666, 59.42820310592652, 55.64082914783109, 55.98335012312859, 58.75875649913665, 60.30082064290201, 56.566779152039565, 53.67827123211276, 52.27247415050384, 50.724644122585175, 45.612477871679495, 50.41437287484446, 58.18416064785373, 49.35814526773269, 42.559873673223684, 43.92668239531979, 44.259409212297015, 43.37488335947837, 42.145671383027114, 41.388563725256155, 43.532558718035304, 44.41642953503517, 46.48678202782908, 45.59889862614293, 52.00342309090399, 51.026666625853515, 49.5777391618298, 55.43080191458426, 52.55286085990168, 53.15883567256313, 55.16678325591549, 56.41032365060622, 51.736443042755134, 57.04820694461946, 57.62427760708717, 56.43799989454208, 51.18063926696778, 48.02692028783983, 49.93944837201027, 46.36497674449798, 46.29340133359356, 46.81292318528699, 56.096173178765085, 53.68927348044611, 53.33036092019851, 54.18794008993334, 57.0932004528661, 52.531342737136356, 54.791918416177076, 53.379892610734515, 52.40384609468522, 52.71981262391614, 55.313640717537176, 52.631473002895234, 50.96554825382849, 50.580022411961714, 46.403882734237186, 42.71696459862494, 41.31410929464525, 42.06319570541382, 44.26768933573077, 42.77925183696132, 42.20587192043182, 44.45689662810295, 45.953171022476695, 42.201141542004, 54.058235153075195, 52.16623675438666, 49.48010744587068, 47.054219553547526, 48.782753175304784, 50.95739756861041, 50.45027825140184, 51.156955995867335, 55.494454137740604, 56.38292197258242, 56.64811734230288, 56.45626637243456, 58.173256458774695, 59.598453583255896, 59.570612599772794, 59.55458579524871, 62.471903524091175, 40.26231004345802, 58.65246811220723, 56.619217318873254, 60.688699906872166, 64.71100422643846, 63.33000044668875, 66.04089167810255, 64.87992109790926, 66.52874039065453, 67.05960181451613, 64.28109284370177, 63.20138985110868, 63.93072712805964, 64.15756171749484, 66.16543477581394, 66.05799321205386, 71.74787752089962, 67.7405958790933, 72.14146383347051, 66.2262942714076, 66.11651497502481, 5.047007347306898, 0.44236711436702364, 6.370871999571401, 11.180899546992395, 0.5466613437860244, 7.756156556067928, 80.68015775372906, 77.39326646251064, 84.05932672562139, 83.62595973476287, 86.79714895063832, 67.34349512284803, 53.602977414284986, 53.337621227387466, 67.31697990048316, 87.61231160932972, 69.5895697993617, 0.3827043706851621, 0.24560549026054723, 0.14238479517159924, 0.17528024291799915, 0.13200608112158316], [0.10347808530974774, 0.040021015391234434, 0.06407342595799316, 0.0673034058643445, 0.018377574048035087, 0.021010985965990735, 0.08255752644711926, 0.6422754905877576, 57.66080664050195, 54.404745178837935, 46.735044525515654, 24.141678502482755, 23.609614872163345, 46.58379400930097, 63.808000087738044, 63.97181003324447, 70.76529241377308, 56.770628652265, 69.67226120733446, 29.10296097878487, 0.30387196209161516, 0.4257533639188736, 6.7025490922312585, 0.6439336112910702, 0.5304687578351267, 26.72770892420123, 56.225140710030836, 53.90799660836497, 64.54882598692372, 60.75023797250564, 60.0500125269736, 54.71700114588584, 54.78907469780215, 54.17796550258514, 61.48726309499433, 59.64572598857265, 59.079084703999186, 59.68641273437008, 58.44726147190217, 57.317159944965, 59.6614037021514, 56.30890292506064, 56.81184884040587, 58.80074939420147, 57.267514505693995, 51.882366980275805, 55.45616003774828, 56.97911831640429, 55.666352010542354, 54.965189118539136, 55.97651735428841, 55.441129515247965, 55.6828377323766, 55.202947508904245, 52.729626394087276, 55.76474074394473, 65.05230926698255, 55.841674112504535, 48.10277892697243, 42.503607273101814, 43.09941530227662, 44.80351648023052, 48.83995309952767, 46.00306357106855, 51.019037615868356, 46.498537371235514, 37.74538001706524, 39.147764636624245, 35.69611026394752, 38.55396878334784, 37.68418712000693, 38.34769133598574, 39.74345891706405, 42.80637894907306, 44.66080496388097, 44.801316030563854, 46.034148354684156, 44.4826626777649, 48.074290752410896, 46.49970231517669, 48.217327825484745, 47.92837858200074, 49.10555639574605, 51.74399752770701, 50.87208993973271, 51.77003814328102, 46.68634829982635, 37.7354250415679, 42.765770650679066, 34.315498721215036, 34.87677812576294, 42.65572855549474, 51.45572685426282, 52.17675262881864, 51.100748431298044, 52.242279744917354, 54.16133073068435, 50.332513009348226, 51.0158016604762, 49.80376182063934, 48.80853491444742, 46.36679672425794, 48.14961202682988, 45.603405429470925, 45.556407590066236, 44.644429068411554, 42.31884010376469, 37.945824899981105, 37.040906644636586, 37.781520735832956, 37.77281699642059, 38.83826609580748, 38.77030318783176, 35.89319367562571, 42.11530047078287, 44.71800881047403, 43.205252616636216, 47.87612868893532, 45.44192929421702, 44.21923237462198, 45.83188349200834, 45.721496228248846, 45.25938610876761, 50.53156937322309, 50.750210131368334, 55.95190448145713, 50.65830899823097, 65.77641410212364, 64.11534132496004, 50.51288712409235, 55.29409162459835, 57.14179077456075, 56.97471741707095, 44.15300315426242, 38.58588510943998, 60.07428807597007, 52.90896892547608, 57.94175032646426, 56.72097929062382, 57.762545078031486, 57.75164481132262, 58.69082104775214, 62.786218735479544, 61.61466952293151, 58.59183611408357, 58.40474690160444, 54.58122830237112, 56.408413456332305, 60.81600827555503, 61.78656739573326, 64.78933003640944, 69.4911418422576, 67.09964136923513, 61.718788839155636, 1.163789048310249, 0.14165799223607586, 6.331710075178455, 3.468053557219044, 0.07335323284590438, 5.505566250893378, 68.82786120137861, 65.89756042726579, 67.41965186211371, 68.12316817622032, 71.09513236630347, 49.11694695872646, 33.5438508372153, 26.81279690034928, 48.29118605582945, 71.50999361468901, 41.77304229428692, 0.3452006895695964, 0.1819342221584051, 0.06370109573547399, 0.0899665542848168, 0.03039524894237759, 0.14888797766498982, 0.0965543435285649, 0.049371348333454905, 0.019174728752864946, 0.09391618186547872, 0.04171575892776732, 0.1285229781041703, 1.0216540590889993, 66.90146753864904, 64.63719698690599, 51.05761412651309, 33.43911570887412, 36.541792884949714, 50.10713754161712, 71.46700443760042, 69.0662314814906, 76.10948254985195, 60.52807492594565, 75.92809646360337, 31.343234469813687, 0.35262745234274095, 0.2676288633336944, 8.319592283618066, 0.100742569193244, 0.5283669802931048, 31.354077862155055, 58.44607299373996, 56.57185077667237, 66.93122263877623, 63.886372966151086, 62.429243826097064, 57.547650183400805, 55.80024603874453, 55.96791167413035, 62.18793176835584, 60.968906187242084, 59.0572214126587, 62.23808711574924, 60.62551052339616, 58.23717540310275, 61.68813551625898, 59.726012983629786, 59.22719340170584, 60.511989285868985, 57.231718955501435, 54.75759375479914, 56.55186630064442, 56.94255398165796, 58.94363349483859, 55.3319424967612, 58.304922580719, 58.08959230299919, 58.69673205960182, 58.76569124960131, 56.128564111648075, 56.96585286048151, 62.539297688391905, 59.17818338640275, 50.6448866475013, 46.399842692959695, 43.72266815554711, 48.27313923066663, 51.601521353567804, 47.56787746183334, 51.33103862885506, 50.10952626505206, 40.11045940460698, 41.10423895620531, 37.99979671355217, 39.89066939200125, 38.478816170846265, 41.181862661915446, 43.350266564276914, 42.27031646236297, 47.872657391332815, 46.68967839210264, 48.20847111363565, 45.969809716747655, 51.51878679952314, 48.63021612167359, 49.075236474314046, 49.61630390536401, 49.66810272585962, 53.41848481085993, 54.9143159774042, 53.86759619559012, 50.06874930474066, 42.2006747799535, 46.32155218432027, 37.00221246288669, 38.69953578518283, 44.25449840484127, 52.28974826874272, 53.21076785364459, 52.99276644183744, 54.48261207149875, 54.75281630792926, 49.60813360829508, 52.562109808768, 50.97133374983265, 48.92113831735427, 48.1270387864882, 50.80011444707071, 47.363376848159305, 48.18462702535814, 48.53795805285054, 43.47553530047017, 40.54579934766216, 39.10529321239841, 41.322691440582275, 40.40142474635955, 40.77702699169036, 40.60816895577216, 39.27335108480146, 44.506973528092914, 47.63842128938245, 44.107550728705625, 50.15486101950369, 46.964103098838564, 45.49053922776253, 49.60103804065336, 49.495389000062026, 47.65908825782038, 53.09287709574546, 52.534025638334214, 57.51833046636274, 53.53657560963785, 63.00453001453031, 64.5272058825339, 53.667139545563735, 58.660697244828754, 60.564294092116825, 59.885096473078576, 47.689969078187026, 41.75143395700763, 59.06016711265811, 54.55880411209599, 59.04528171785417, 59.86685352940714, 58.0069754200597, 58.05067454614947, 60.62793454816265, 65.18173571555846, 64.53481920303838, 61.881543667085715, 60.279384889910304, 57.79302189427038, 60.96684302053144, 63.879418603835575, 64.13440012162732, 68.24603249949794, 72.34631353808989, 70.97029901319935, 65.40619727103942, 1.362807536798139, 0.06491386271532505, 5.980326994772881, 2.8464027470157993, 0.033016301946894776, 5.996370469370197, 77.54579959377166, 70.2195808964391, 76.1837330172139, 74.2335384122787, 81.96991151379001, 53.546122658637266, 49.58704302387853, 31.967795433536654, 51.11389229374548, 81.70471222169938, 51.48426994200676, 0.21674602352563413, 0.08665334658637162, 0.04763986705051315, 0.06362112381705834, 0.008011344837160001, 0.1987676559797218, 0.14216909545563883, 0.1840711018491176, 0.14072256823701246, 0.169163643712959, 0.08316568534580931, 0.19774194085790267, 1.2147238442013342, 80.44726310237762, 70.99536295860045, 65.78097189626386, 32.419697584644446, 34.95975194438812, 62.98575362851543, 76.35265381105485, 75.08417498680853, 83.2972651143228, 66.12651701896422, 80.76985451482958, 35.98509873113325, 0.2990275591371521, 1.3201461227670794, 15.63977151147781, 0.8028635767198379, 0.869013981953744, 36.359175174467026, 60.97012604436567, 61.021356121186294, 70.25398792759066, 68.06351677063974, 64.94001965368948, 60.66127469462734, 57.736822174441436, 58.251739163552564, 64.48663680784165, 62.57794087932956, 63.20711258919009, 63.18100921569332, 62.19374472095121, 59.8742118958504, 64.06743741804554, 62.47652799852433, 59.52954146169848, 64.17369442601358, 59.50294386956, 55.0095550475582, 60.417997529429776, 60.08866748502178, 61.30605743777368, 56.20079455837127, 59.572389433460856, 58.7411097557314, 59.48507355105493, 59.91072131741432, 59.214794789591146, 59.296913531518754, 65.24318748904814, 62.06181972257553, 51.537586719759055, 46.7809441012721, 46.29931626781341, 51.16203154287031, 53.403838680636504, 48.75754802457748, 54.89738310537031, 52.46077145299604, 40.98980380642799, 43.92352488733108, 39.46340560913086, 41.71933720188756, 43.17375598415252, 43.787465710793775, 46.404655441161125, 45.82126955832205, 50.80570382456626, 51.29859278278967, 52.4909697809527, 49.20464723340927, 53.44736914480887, 52.05132699781849, 52.0770695132594, 54.69151358450613, 53.2611350090273, 58.44111119547198, 58.221289803904874, 57.226655175608975, 51.726566514661236, 45.90902474618728, 54.11169705852386, 42.84929752349854, 41.19752860838368, 47.31014244018063, 56.39171984887893, 56.37460654781711, 56.802564590208, 58.49959373474122, 60.69648581166422, 54.600659724204775, 55.25137701342183, 53.91585703819029, 53.153709134747906, 50.97388721281483, 52.61685825163319, 48.26964047647292, 50.28044746768091, 50.59876741901521, 45.147806444475734, 40.916329968360166, 42.01660579250705, 42.51210704926522, 43.50177987929314, 44.87131857102917, 42.78066389022335, 41.569196716431655, 47.71854746726252, 50.70446745041878, 47.00492320522186, 52.607169997307565, 50.30857478418658, 48.63342069810437, 53.026075209340746, 52.856726877151004, 50.213300412701024, 53.94277234231272, 55.55585884278821, 59.57292287580429, 57.26337248279203, 63.70062520427089, 67.53961363146382, 56.83703437928231, 61.80607334260018, 60.35176830907022, 62.83325579858596, 47.19391868960473, 49.30465982806299, 64.53582332980248, 53.21891853886267, 64.38127017790272, 59.15992867562079, 61.93780614483742, 59.0891848071929, 61.50352524172876, 67.41662379234069, 67.23561425362864, 61.90791768412437, 65.66411272172006, 59.31732554589549, 62.18015370830413, 65.69348342957036, 67.99252187052082, 70.05866958249, 76.1075762779482, 71.71092094913607, 69.13946997734809, 2.069465546838699, 0.2966827478620314, 12.705394414163406, 10.211719139929741, 0.25944085431195074, 9.121636575268163, 79.89795084922545, 78.52643920529273, 79.67928655685918, 79.39545600645005, 84.64179085146996, 62.7989625161694, 55.25435801475279, 40.01456137626402, 66.26791061893587, 90.3138832892141, 67.3123279694588, 0.574162184230743, 0.2536779119362754, 0.22761780708547563, 0.2177859878828449, 0.0947084546750111], [0.010285580741061319, 0.09568172341753399, 0.06387758707146972, 0.029142591764309236, 0.10532612687036877, 0.05834740902026815, 0.07479601389458103, 0.22597496217537313, 50.94302600429904, 60.42452043102634, 46.49914926098239, 29.836132372579268, 29.589054430684737, 46.311836473403446, 55.92718178226102, 62.54726009984171, 67.22261551887759, 59.97682894429853, 65.80403935524726, 44.71280774762554, 0.11204830325779416, 0.17130862861391039, 8.085102208199041, 0.2295332720443126, 0.4334656323396391, 18.00563635364656, 62.645550773989775, 56.04882624841506, 66.8222435059086, 58.59659787147277, 61.11439081930346, 55.64022902519473, 55.36923639235958, 51.65561868298439, 56.549132408634314, 55.85071909812189, 60.40816414740778, 58.459628705055486, 60.04254433416552, 59.20148226522631, 59.462692506851695, 55.48419321736982, 56.690294588765795, 53.77348284567557, 54.0229691228559, 52.12422032510081, 56.88467548739526, 55.23941378439627, 60.08748685159991, 56.21544461096487, 52.621059110087735, 54.065114990357436, 53.354828665333415, 53.43893997130856, 62.26396691414618, 62.702028982100956, 54.806042871167584, 57.134483398929724, 50.44926627989739, 44.73744807704803, 43.769281602674916, 46.197154214305264, 51.093735233429946, 48.78000751618416, 53.788105441677956, 42.547412303186235, 36.247787706313595, 37.07748666886361, 36.91856399659188, 38.34775017153832, 36.82279932883478, 37.33509225230063, 40.37025367060016, 41.3704776763916, 41.41627919289374, 43.848007494403475, 45.91355116136613, 46.505354450595, 46.7759273898217, 45.7087367580783, 46.421462797349506, 45.96109421022477, 48.2419446206862, 49.60331693772347, 48.73957180207776, 52.02417635148572, 46.393033458340554, 36.603778100782826, 39.621386912561235, 32.52747843342443, 37.17802486112041, 41.83430971637849, 50.312171597634595, 53.15714120864869, 54.25280040310275, 51.29796520356209, 52.395695409467145, 48.80724053229056, 51.14575762902537, 47.410460979707786, 47.60465752693915, 46.56242101423202, 46.062460022587935, 46.679225275593424, 47.180394357250584, 44.85546827316285, 39.56063332096223, 38.3120213016387, 38.72483507279427, 38.97492539498114, 37.89637557921871, 37.20573248401765, 36.91976816423478, 38.819921170511556, 37.377697037112334, 47.01007719962828, 51.66852720322148, 49.25912111036239, 44.7613117771764, 40.76574625507478, 45.795680015317856, 45.862234792401715, 51.03156566619874, 50.3261979933708, 54.67213707585489, 54.44028185259912, 56.05993832311323, 69.49752746089813, 51.26093410676526, 53.625872288980794, 54.48579703607867, 54.932743272473736, 57.85092784512428, 58.76932728675104, 38.77591609954834, 34.43811985754198, 54.996442564072154, 46.711208281978486, 50.446861866981756, 51.48709404853083, 58.11422871005151, 56.04340553283692, 62.64882203071349, 60.91916268871677, 62.50908759332473, 53.87468391849149, 53.510809559975904, 55.24922363219723, 61.57077427833312, 60.690480662930405, 66.13475399632608, 67.24651844270768, 71.50840113239904, 55.979078662010934, 0.3669568205312375, 0.017871279945416797, 10.994783082316, 0.7902499696900769, 0.2800344928137718, 8.116890076668032, 72.4168691327495, 68.03647595067179, 67.7363754087879, 69.5892010965655, 71.58342038431476, 52.60180811728201, 24.931586980819706, 26.548062409124068, 48.6183980203444, 63.536105309763265, 38.56597123607513, 0.19225451434331556, 0.2084900931485238, 0.051924275054085645, 0.26181967989090954, 0.02268461994977007, 0.0066598326309524, 0.06541151343093765, 0.08948253227337714, 0.04890359802952698, 0.09947467835680132, 0.04691733505516764, 0.06515234588615357, 0.4734580266860224, 61.2105163451164, 64.73615446398335, 55.59928732533609, 33.2749919737539, 40.36206768405053, 56.14665800525297, 60.62074876600697, 68.6984778988746, 72.4645886882659, 64.93894492426227, 70.7331838915425, 49.89727112554735, 0.22062507908671136, 0.3166385722016135, 6.34879493905652, 0.5226092473153146, 0.22582782732863582, 20.112637512145504, 65.36992319168584, 58.64834570115613, 67.57248309350783, 61.32415525374874, 62.66464487198861, 59.142266242734856, 58.92170744557535, 52.90027303080405, 58.15893588527557, 58.65065205481745, 61.066177045145345, 58.931576128928896, 61.46047722908759, 59.44835624387188, 61.49229941829559, 58.71619093802668, 58.594856339116255, 58.577601832728234, 55.686179591763405, 53.47881086411015, 57.989607164936686, 57.98371184256769, 60.3253197669983, 56.089411012588016, 54.28361454317647, 54.3888674243804, 54.65889123178298, 54.220040767423576, 60.81975021669942, 62.60646043285247, 57.96184070648686, 57.89865916775119, 53.041874516394834, 46.772052088091456, 45.19327848188339, 48.02437074722783, 52.32841891627158, 53.8710125800102, 55.361952550949596, 42.8808412244243, 38.049320559347834, 40.86035774600121, 40.224314043598795, 39.73358238897016, 40.18889504094278, 39.521888148400095, 42.99096568938225, 41.45568332364483, 44.93184858752836, 44.8939702587743, 49.60849054398076, 46.63022310503068, 50.24529518619661, 48.56195903593495, 48.33853298617948, 47.12339839627666, 48.84369504067206, 49.659053817872085, 52.19791773826846, 54.45351592956051, 49.354909312340524, 40.75699544722035, 43.74116997564993, 35.28055083367133, 38.67425218705208, 43.07707740414528, 51.233740314360595, 54.0104999080781, 53.84117118773922, 53.462815438547445, 54.79703710925195, 49.82169097469699, 53.58672703466108, 48.94227204784271, 50.00471268930743, 49.02013894050352, 49.62267383452385, 49.46229988528837, 48.156158462647475, 48.50454730372275, 41.40202922205771, 40.58172825844058, 40.60874946655766, 41.33104216667914, 40.36760214836367, 39.45965582324613, 38.67586035882273, 39.819097903467, 38.660394453233295, 48.2420152233493, 51.75464676272485, 50.32078120016283, 46.433641756734545, 43.72712004569269, 47.5349844655683, 48.52763829692718, 53.70934817098803, 54.503498692666334, 57.27670069663756, 57.27597505815568, 56.56452378919048, 68.9534241153348, 55.288113932455744, 56.25315427780152, 56.91920018965199, 57.198167001047445, 58.83562318740353, 58.664188154282115, 40.84461335212954, 36.54662916737218, 55.457638771303245, 48.43650987071376, 50.458166137818374, 49.95402782194076, 59.38347239648143, 58.54165331009896, 63.80157132302562, 64.71899409447947, 65.72011240067022, 56.039710660134595, 56.444012888016246, 57.730746423044515, 62.97035440321892, 62.732748985290534, 68.07791971391248, 70.46845528387254, 75.40439728767642, 59.53692728473295, 0.5212712287902832, 0.02513798588376132, 10.823693217769748, 1.292427958500001, 0.36220719797476647, 9.766355579899205, 80.73620057875111, 71.53326111455118, 74.24407389856155, 74.9500613058767, 77.90679885495094, 54.72612850127682, 38.98352323039886, 27.889299238881758, 53.31773873298399, 73.7774452086418, 46.87127236397036, 0.41040984853621454, 0.23607364044554774, 0.07531889188554018, 0.08254471745702528, 0.03577903716734821, 0.14416915184307483, 0.13358766964126018, 0.19727196123811508, 0.27927177567635814, 0.21746214719549303, 0.17499107537010025, 0.13983853341590974, 0.7322131097316743, 71.97542205933603, 77.33162249288252, 62.40101452796691, 38.35374355316162, 45.371887530049975, 60.99429961173766, 66.2911153608753, 75.51105437740203, 77.6165513069399, 70.16352238193636, 75.51564355050364, 55.5997540873866, 1.026079411948881, 0.6087932194913588, 17.50690894742166, 0.5544233466348341, 0.6592555536377815, 25.179974994351788, 66.93977340575188, 61.08153704674014, 70.91755097912204, 63.72026843409385, 65.15084705045147, 61.98653767185827, 59.8258137702942, 56.93415618711903, 61.2994521664035, 60.283268036380896, 63.555301389386585, 61.63677992359285, 65.18129248772898, 63.223092325272106, 64.27930816527336, 59.321973554549686, 60.1418665916689, 59.31261870168871, 57.6415595700664, 56.96964971480831, 60.772434665310776, 61.00346226846019, 65.31553168450633, 60.0468393295042, 55.33997943324428, 55.41512812337568, 55.05871019055767, 55.18552041822865, 60.26712748312182, 62.60776658211986, 59.68498499162736, 61.86412442115046, 55.79768865339218, 49.10781960333548, 46.99409746354627, 49.532118074355594, 56.64994124443301, 56.24969866967971, 59.405269007528986, 45.50327516371205, 40.40751618723716, 42.09260563696585, 41.074577992962254, 41.844354906389796, 41.62281159431704, 42.151841271308164, 45.217675624355195, 44.395370329580004, 46.47815281344999, 48.04837957505257, 52.97344484636861, 50.85297622988301, 52.86425782788185, 51.022657963537405, 49.9850655371143, 47.841800105187204, 52.201420414832334, 53.26314326255552, 53.7606410057314, 57.60807429590533, 53.174944846860825, 45.42658890447309, 48.986579141309186, 40.72386710874496, 44.22431968873547, 45.83328377815985, 54.942333467545055, 58.097754755327784, 57.73493943675872, 57.29854045375701, 58.30127085408857, 52.06630652950656, 56.91046899364841, 51.147118691475164, 53.18067542968258, 50.990494528124415, 51.83543974353422, 53.33985697838568, 51.4780294510626, 49.79370094114735, 42.38117441054314, 44.1804087546564, 42.32322531361734, 42.30740247234222, 42.91636613107497, 42.41570303517003, 42.9820462196104, 42.71407381180794, 41.274340383468136, 50.866037722556825, 56.00889652006088, 52.833498600990545, 49.85387794433102, 44.960234780465406, 51.10776162916615, 52.00708266227476, 56.37921925513976, 55.21108250464163, 57.74074454461375, 60.04420741911858, 59.70268664821502, 69.03195781092491, 60.05882217038063, 55.33076186333933, 60.50920048067647, 58.376552904805834, 62.171963799384336, 58.68159563310685, 43.83899781011766, 45.23396522768083, 56.69016122817994, 48.635593691179835, 52.037433962668146, 50.97643675342683, 58.448434260583696, 58.64912625282042, 65.78279972076416, 66.96539432771745, 68.58123825442406, 59.66059961626607, 60.534946918487556, 58.19027562295237, 68.23930171228224, 65.97765522618448, 71.0525118920111, 73.38860496397942, 76.35130451571557, 63.023526053274836, 1.0116976739898806, 0.17150689216871418, 28.231453472568145, 5.408643993639178, 0.6734242578667979, 14.208884008469122, 85.35692522602697, 77.0386214410105, 80.47286049012216, 82.86424329203945, 83.64925861358643, 69.46559152295514, 38.910473008309644, 36.439026786435036, 67.3920383761006, 81.03766610545497, 59.085007482959384, 0.5680460446784573, 0.507598459239929, 0.1333098708381576, 0.2597082496410416, 0.11892135300102735], [0.045903720292112524, 0.02456649386834714, 0.02803542617438061, 0.0625717633914563, 0.05378741620769424, 0.021316980635146462, 0.13161770518748991, 0.16055077765016787, 47.799579712652395, 63.21845216135826, 47.33553978704637, 47.39973721965667, 29.72648643678235, 42.224601238004624, 67.11809219852572, 69.54112068299325, 66.30613803863525, 65.61711488231536, 61.59884668165638, 59.335242932842625, 0.9783358932022126, 0.09706174654345359, 3.6734626898842477, 0.27491273538720223, 0.16420471061381603, 8.55675349312444, 68.10848282229516, 58.7604352735704, 65.56860300802416, 55.87818353406845, 58.044665475045484, 54.388486954473684, 58.59436604284472, 52.59725032314178, 52.93368377993184, 48.28462000816099, 53.82610536390736, 53.135324985750266, 55.344964765733295, 53.701350458206676, 55.30545080861738, 54.47770518641318, 53.69050118231005, 53.34627005361742, 50.02318705281904, 47.131721665782315, 49.725216357938706, 54.3155034126774, 56.76245051045572, 55.640021139575595, 57.76599284141295, 56.32608682878556, 51.710182774451475, 52.85118849046769, 47.77402547097976, 39.99693032233946, 49.841043949127204, 58.01693039555704, 51.74656275779971, 43.30949744870586, 43.506565170903365, 46.051387171591486, 51.41880950620098, 46.614792500772786, 49.70496516073904, 47.49260325585642, 43.59865850017917, 37.02264016674411, 39.107544652877316, 36.6315798605642, 37.45055114069293, 38.58002116603237, 39.21810057855422, 40.04795643591112, 43.10609509868007, 42.47112220333469, 44.88894570258356, 44.45972073462702, 46.0042049807887, 47.472359903397106, 47.7507265921562, 44.04250998650828, 46.7851645715775, 49.81289702077066, 48.825322658784934, 49.61938688831945, 44.38894156486758, 31.80793727597883, 38.516310107323434, 32.69172376201999, 36.19564371724283, 40.4385107563388, 48.94117378419446, 50.11195421218873, 53.52489479126469, 51.18625610105453, 50.93830347061158, 49.64652968991188, 51.21905888280561, 46.58042861569313, 47.9485591765373, 45.93208436043032, 47.894818782806404, 45.09035941093199, 48.50731649706441, 40.59905336749169, 39.884919197328635, 36.091720519527314, 37.95693697467927, 38.94220106063351, 37.03245001454508, 38.916140833208644, 37.578906782211796, 40.631154044981926, 47.140492085487615, 43.69124997046686, 49.36819830248433, 48.630121984789454, 44.640702816747854, 42.24967302814607, 46.467499656061975, 47.94350324138519, 54.05577974934732, 53.73527111545686, 55.29243246201546, 52.26295063572546, 57.38732722497756, 51.50701968900619, 50.41474550001083, 54.929071933992454, 54.391573859799294, 56.601668634722316, 53.26998779850622, 53.759174039286954, 53.78453216245098, 44.197796621630275, 55.19177267628332, 55.88336890743625, 44.82055525625906, 53.47518267170076, 51.8914355001142, 59.17659482648296, 62.849847424414854, 60.97032608524446, 57.263129295841345, 51.899358687862275, 54.69583603643603, 55.9118413925171, 62.16341303240869, 64.24719179830244, 62.73512594161495, 67.27368477852114, 72.28631696393414, 51.976248910350186, 0.8005085611535657, 0.08651378068832621, 5.558748687467268, 0.8419272579973744, 0.28586546379712324, 12.31945280105837, 78.31310933636081, 63.61683553264987, 68.37972256445116, 62.81095320178617, 75.52215468498969, 54.6357374806558, 29.38962151927333, 30.02022489424675, 45.63187791455177, 74.04448016997307, 29.1128747693954, 0.2892771597591139, 0.19163435084685204, 0.07399025027670207, 0.15667037377434392, 0.037204780420588876, 0.05001164462056853, 0.04210965835579461, 0.01791676833114076, 0.05868327345759158, 0.0661356273978468, 0.09053646241344752, 0.17704244432670457, 0.19091697079279732, 57.9580242403092, 69.83118780197637, 55.82629057668871, 36.69831114430582, 30.188474962788245, 52.225821479674316, 68.4764011444584, 74.75888498367803, 68.90612817579701, 71.71139163355674, 65.76925969892933, 63.534073522014005, 0.9221701263900727, 0.04462270253908731, 4.261452209564948, 1.515871658921242, 0.30965675329489095, 11.323504178754746, 71.38819617609825, 60.56572967959989, 67.81825096376481, 57.615718995371175, 59.90516331888015, 55.52560952401931, 58.4715997788214, 54.04024716346495, 55.26813337879797, 50.33653343877485, 54.93699512174053, 56.711228278375444, 56.94790017220282, 54.05899609288862, 58.06017060433665, 57.78043893075759, 58.01719319435858, 56.41197104607859, 53.016253594429266, 48.00657495375603, 53.14385614087505, 55.02347946166993, 57.01630238563784, 56.752464155997004, 60.22792731561969, 58.36744908363589, 52.90879241881832, 51.48243819513629, 48.696923871194166, 44.47892073662051, 50.79849843055972, 59.741878970976806, 53.03029175727598, 45.833691704657774, 44.51609696111372, 48.89839641509518, 52.751897611925685, 48.919792944385165, 53.60096523838659, 49.392218897419596, 44.41551954515519, 40.120465370916556, 41.04428945049163, 38.70768254803073, 39.81247302024595, 39.730424880981445, 40.9460223105646, 42.14926035173478, 44.3786374984249, 44.25520050910212, 47.836446069901996, 45.41262918902982, 47.21149483034688, 49.19098561809909, 49.659681397099654, 47.62108441322081, 50.31596060722105, 52.081635152139974, 52.34089205341955, 53.12062394234442, 47.062993895622995, 36.27336548220727, 41.27696444911342, 35.471958575710175, 40.93049756942257, 43.33793071008498, 49.17121687243062, 53.59683890496531, 56.204709083803245, 54.52717804139661, 52.77448261937788, 51.31592573658113, 52.802621702994074, 49.87377220584501, 51.44818805879163, 46.90717774052774, 49.72260405940395, 45.64675154224519, 50.88868548793178, 42.23521124932074, 41.23950189159763, 39.22634540065643, 38.82394159993818, 39.82527171411822, 39.62007684092368, 41.0276036877786, 40.17182488595286, 42.0690361146004, 48.81883505851992, 44.76844656851984, 52.26727701002552, 50.06787853856241, 46.769365264523415, 46.15307069593861, 48.76013286652104, 50.28072987833331, 56.1146749988679, 57.09931935033491, 57.5256182301429, 52.70408784189532, 55.140656348197695, 54.5890808874561, 51.027717821059696, 56.304937408816436, 56.325247441568685, 59.62726339217156, 56.83796398101315, 57.35816440274639, 55.95469720901982, 47.65518157712875, 57.33597947705177, 58.13218532070037, 45.44809133775773, 54.92835021788075, 57.17080454672537, 59.416412461188536, 64.77044774639991, 63.48792291456654, 59.65445718457622, 56.295115793904955, 57.45334463734781, 59.95137668425038, 65.07311351837652, 67.01445533383277, 66.00900280860164, 70.84963121721822, 75.90448379516602, 58.94514752972511, 1.0736587427316175, 0.07652179548336614, 8.809572804358698, 0.020894910238923568, 0.42057338381005877, 14.70924606246333, 84.78618898699361, 69.1570657299411, 73.62332743983116, 71.01214285819762, 80.0158808308263, 61.74076980160129, 34.869419759319676, 26.58484051304479, 55.0377647338375, 78.87945252080118, 39.074671268463135, 0.40072907122873497, 0.18842848738835705, 0.058531189682863416, 0.2552012471301902, 0.037148821528159806, 0.13860323195976598, 0.19383841644852393, 0.2797147277141771, 0.16937129950571447, 0.1580207876019901, 0.13807913588900722, 0.44524031180527907, 0.2658967691804132, 67.84999078319919, 79.6146458964194, 66.30655380987352, 62.09216710059874, 45.20803443847164, 57.96833222912204, 78.46459127241566, 82.90712264276321, 75.51766749351256, 74.32083468283378, 72.19320774078369, 71.98469454242338, 2.02604380586455, 0.3397837125005261, 9.121474777498554, 1.680798621908311, 0.4909132481102021, 14.045545727975908, 71.93588456799908, 63.876743547378055, 70.72144031524658, 60.43303197430026, 62.70440986079555, 59.06800793063257, 63.01954484754994, 57.30349048491448, 57.57350644757671, 53.00894229642807, 58.88288382560977, 60.581234808891054, 59.36646107704409, 56.644618588109175, 60.466274061510646, 59.970211905817834, 59.22977432127922, 59.50347338953326, 55.003663647559385, 51.51084007755403, 55.63273337579543, 58.836337058774895, 60.52037923566757, 58.58286173112931, 61.97295450395154, 60.86224125277612, 52.09194314095282, 52.55781089105914, 50.021731853485115, 47.008759283250384, 52.87828422361805, 63.53623082560878, 56.62748959756667, 47.87953330624489, 46.86976617382419, 49.96619109184512, 59.46321025971444, 52.1935482178965, 56.9545485896449, 52.94150890842561, 48.011022921531435, 42.93860989232218, 42.62995073872228, 42.6636125195411, 42.211371083413404, 43.721946439435406, 43.87061995844687, 44.099101943354455, 46.80568248994889, 46.695907115936286, 50.84579829246768, 50.15384904799923, 49.84607635005828, 52.02833798623855, 53.01679488151304, 50.59140513020177, 51.63176674996653, 54.19696938607001, 55.07485466618692, 54.87033444066202, 50.50719184260215, 41.75492094409081, 47.95950258931806, 39.15234988735568, 45.75440099162441, 46.46289087110951, 53.16423285392023, 56.46405227722661, 58.97032130149103, 55.968468650694824, 55.00477367831815, 53.944870810354914, 55.66231196926486, 50.78904551844443, 54.381869915992986, 49.570663206038944, 55.44049801365022, 48.29903864091443, 53.91119726242558, 44.02673029130505, 44.981235150367986, 40.63756712021367, 42.4667997514048, 42.93899820696923, 41.72818214662614, 43.19449747762373, 41.41482791592998, 44.5312883007911, 52.31044661614203, 45.10957902477634, 55.71353812371531, 53.01098977365802, 49.30493831634522, 46.96288324171498, 51.973628767075084, 51.44388914108277, 58.68734582777947, 59.296658577457556, 58.00710878064556, 56.584053270278446, 57.82750345045521, 57.66210886739916, 53.26395127081102, 57.737892981498476, 60.0233051084703, 60.404308457528394, 59.296215349628085, 59.40590050912673, 58.89685138579338, 49.662603562878026, 61.4830740036503, 59.267546746038626, 47.851566806916274, 54.589053430864894, 58.11271859753517, 63.421650548135084, 69.58822050402242, 67.64798087458458, 62.09764665172946, 59.15325672395768, 59.330410572790335, 61.3237081035491, 69.69641516285559, 69.73125365472609, 68.51664466242637, 70.9879026105327, 79.56479257152927, 63.947989479188, 1.7997348140324316, 0.149894479301668, 14.768982779595161, 4.764745744966692, 0.42381310835480696, 18.157192814734675, 90.8546212411696, 72.59169701606997, 81.21963270248906, 74.85761104091522, 88.98491367217034, 70.8110821631647, 47.300230610755186, 40.34409146155081, 68.04329303003126, 91.22249249489077, 48.78472220513129, 0.5335693914563425, 0.2677513148275114, 0.19348664419545283, 0.39887881567401273, 0.15767692137629757], [0.042574803960779985, 0.0553428772987137, 0.05165101532193442, 0.026136470410311897, 0.016467667057088787, 0.04031366480874919, 0.05232487009057114, 0.07233179249470273, 40.06397539569486, 74.52141684870567, 46.057043229379964, 45.397951679845015, 39.211036389873875, 45.365847079984604, 62.894950759026315, 68.98495212677987, 64.18749724664997, 68.7939013204267, 57.60739964823569, 67.65034998616865, 5.270674132531689, 0.25828620659247525, 1.7988109732827835, 1.5695431660259924, 0.054238461964433236, 2.0515291609110373, 63.998223273984856, 59.20125869012649, 66.05527108715427, 57.13492270438903, 57.70185816672541, 54.60528027626776, 61.66715083583709, 55.984424852555804, 57.21762587947231, 53.4566730068576, 50.263804851039765, 47.26944784964285, 49.61292674464565, 49.1586809773599, 50.86985418873449, 51.778483006262014, 52.95090690735848, 47.20981605591313, 47.673032283782966, 44.07404192032353, 49.17115803687803, 54.209807303644, 56.4277821202432, 54.30461491307905, 57.893120781067886, 55.37263708729898, 51.443759702867084, 42.426285589894945, 39.94928529185634, 55.101503249137636, 57.83619150038689, 53.696573011336795, 44.98071347513507, 43.17379913022442, 44.04455354136806, 45.62726520722913, 50.19267659033499, 46.18293562243062, 49.72079976912468, 45.43671646425801, 38.344125901499105, 38.12501838130336, 39.56295536410424, 39.818740967781316, 39.81069226418772, 38.0526977200662, 38.192157591542895, 39.320592111156834, 39.17518984886908, 41.31428972367318, 42.327806641978604, 44.943258762359626, 43.57657163373886, 43.27561209278722, 45.19172130092498, 43.5496327953954, 47.724485935703406, 50.234547891924464, 49.22960919718589, 50.66120762978831, 42.189013573431204, 34.39034931121334, 37.22660733807472, 38.4350738986846, 39.988269728998986, 41.744734548753314, 48.19109501377229, 51.0095101787198, 53.674038994696836, 50.349877342101074, 50.266103359960745, 48.61959826561713, 48.90536254452121, 46.522871755784564, 46.80582761764527, 45.27318500703382, 45.72961945687571, 43.68426815156014, 43.45132643176664, 40.985238167547415, 38.25406828234273, 41.40660270567864, 38.73196594176754, 36.65982484817505, 38.66501108292611, 39.420071263467115, 39.24025804765763, 41.27027680796962, 46.850538715239495, 54.59838474950483, 53.8797829997155, 46.37617511133994, 43.42190865547427, 44.15383861910912, 46.7874042449459, 53.171857941535215, 55.87195088786464, 56.01141075934134, 53.09455194780904, 51.30504508172312, 52.08054865560224, 50.57657857095042, 53.02756178763605, 55.20384180930353, 56.32568674702799, 56.186540665165076, 55.65792675941221, 55.79513126803983, 56.071156301806056, 56.56142119438418, 55.24898828998689, 57.661445986840036, 51.54223080604307, 47.395469680909194, 56.75908511684787, 61.19754506695656, 59.42178610832461, 58.63759448451381, 54.60633931621429, 54.01687768197829, 55.05004175247685, 62.887851269014426, 59.47817410192182, 60.929411841977036, 57.57898599870744, 67.23785000462686, 65.95179111726823, 52.50678085511731, 0.9917974676336012, 0.06969163134213417, 4.966535510555391, 0.9154555189513391, 0.39314639424124076, 18.4627023050862, 73.3957907461351, 63.50979405064737, 64.02335389967888, 68.0944642712993, 70.14296131749308, 46.13661635306574, 42.713622739238126, 33.88164927882533, 43.00101872413389, 76.0806139053837, 16.69433113067381, 0.2846889366065302, 0.19307381473481658, 0.061198401400038314, 0.10899508281821206, 0.013436414188735429, 0.09423043879289782, 0.02578997075737965, 0.10506009517778313, 0.005373681131224599, 0.06777255044829461, 0.06844379668754917, 0.10283243406804339, 0.022128292644817023, 49.13675492809665, 81.15211302234282, 57.31495165055799, 42.724338654548895, 33.93524062248969, 54.11771789673836, 67.68040318642893, 78.88204128511491, 68.08107329953101, 75.90445241620465, 61.71188154528218, 73.0894850146386, 5.310773503395819, 0.20547576699285738, 0.23464882415869545, 3.5667006767565206, 0.16483274949414117, 3.3433324819610966, 70.03118161232241, 59.52107306449645, 68.30021612105831, 60.527137479474476, 60.230139532396876, 56.736990405667214, 65.03676883635983, 58.990854909343106, 58.99298867871685, 53.937932137520086, 51.58201148433071, 49.0451636622029, 51.87016448666973, 51.965532995039425, 52.54276860144831, 53.38111639022828, 54.71355730487455, 49.880000929678644, 48.45433312077677, 46.08772008649765, 51.66758191200995, 54.463918055257494, 57.04138202051963, 56.98262883770851, 58.79415196757163, 56.93675671854327, 53.90380359465077, 44.704351117534024, 42.3551377173393, 54.9628709977673, 61.41097691751296, 54.174047054782996, 48.125995436022365, 46.78436440806235, 45.92798156123008, 48.904974229874156, 53.54137266835859, 50.11406052497126, 52.167280104852495, 49.584340510829804, 40.438416619454664, 40.573730545659224, 41.20923688334804, 41.78998693343132, 41.53454257595924, 40.561590809975904, 41.81709835606237, 40.908187127882435, 41.703694789640366, 43.21326209652809, 46.9679234873864, 46.868040330948375, 47.35262170914681, 45.81133811704574, 49.417486806069654, 46.4713357340905, 49.31799588664886, 52.727904473581624, 52.904438587927054, 53.70900692478303, 45.19889923834032, 35.940485692793324, 39.402495122724964, 41.13915981784944, 42.537018022229596, 44.458371439287745, 49.92737531661988, 52.4324127166502, 55.49004931603709, 52.63259872313469, 52.32244514649915, 49.02199422159503, 51.36006024576003, 49.43122294641311, 48.39984355434295, 49.10463071638539, 47.777277115852606, 46.78374467357513, 47.50319365532168, 43.03266440668414, 40.90063656530073, 42.56647894459386, 39.910038055912146, 39.19928889120779, 39.98316672540481, 40.17085998289047, 40.540374709713845, 44.714510056280325, 49.18188571929932, 55.78774152263519, 55.40946029847669, 49.934141405167125, 45.05851368750296, 45.3992852857036, 48.75657527677475, 53.175423376021854, 56.820532967967374, 58.10299111950783, 55.737170404003514, 52.9186571798017, 52.174909114837654, 50.163733420833466, 55.19024687428629, 55.7306828037385, 56.4025063668528, 58.806727086344075, 58.63630010235695, 56.796943833751065, 58.02094690261349, 59.31699998917119, 58.25804241241948, 59.61613170562252, 54.97940378804361, 50.046517310603974, 59.093813203996234, 63.15808688440631, 61.21371307680684, 61.08553394194573, 57.15005520851382, 57.31204909663047, 59.48286917901809, 64.68800737011817, 61.60717779590238, 63.02102750347507, 62.20832809325188, 71.3505571119247, 70.22010649404218, 61.43957884080949, 1.2112042524160878, 0.07297727519706373, 3.484795213707032, 0.31638750986706826, 0.3750015404676238, 20.450926250027074, 81.07870194219774, 68.77177915265484, 72.53119053379183, 72.29987267524966, 77.90435914070376, 57.29114286361202, 40.979499739985314, 27.630130590931063, 49.67373132705689, 86.56226957997968, 22.86989115899609, 0.5895232277051096, 0.2943200407729995, 0.05860545807668279, 0.12395989795726155, 0.10807075177229221, 0.16585325521807517, 0.13352434481343917, 0.27310715808022407, 0.13991161820388612, 0.08168551154554853, 0.2234659935798376, 0.2584752464486707, 0.11110733278215894, 56.58611251461891, 96.41802480143886, 62.838029323085664, 58.03815826292961, 50.74811950806649, 60.88196293000252, 74.2668628692627, 83.45066116702172, 73.47455193919521, 80.89636664236747, 67.15078907628214, 79.30464529222058, 7.486031747633412, 0.3532217527108808, 6.615435211889206, 4.284611353951116, 0.23074652548999558, 4.067842546970614, 72.89246436088317, 61.20170277933921, 71.86914151714694, 62.92492551188316, 63.971523700221894, 57.765204445008315, 66.54444556082449, 59.52091616968955, 60.60068584257557, 56.50273861423616, 54.35322876899473, 51.73976921266126, 54.509268499189815, 55.777511981225786, 54.814526957850305, 55.12893630612282, 57.34177281779628, 53.182699372691495, 51.82987782262987, 47.242218755906634, 55.638008963677194, 58.910881703899754, 59.969517646297334, 58.775508942142615, 62.507506878145286, 58.96857976913453, 56.553890243653335, 47.036266865268836, 42.983807363817775, 57.024182427314024, 62.10697797036941, 56.95465449363955, 48.81873307689544, 48.309056374334524, 48.90254628273749, 51.047937639297984, 58.0148672288464, 51.68454224063505, 55.63527114929692, 51.409995940423784, 42.50050860066568, 41.696477628523304, 42.53173458960749, 44.9431489359948, 44.5669073443259, 40.91479632162279, 44.08921757052022, 43.076728313199936, 43.66882970256191, 45.716416758875695, 49.65892045728622, 50.06818056106568, 48.83349687822404, 48.15813533721432, 52.23351324758222, 50.58013616069671, 52.260271656897764, 55.504456181680005, 56.90968059724378, 59.65075054476338, 48.92276610097578, 41.65171946248701, 48.307040276065955, 46.09675722737467, 47.33231167639456, 47.93021425124138, 52.44017900959138, 54.750525643748624, 60.34186432438513, 54.36686685008388, 55.309698735514, 53.094912805864894, 53.168363109711684, 51.04554499349287, 51.414718474111254, 51.60567906595046, 52.008679066934896, 48.97507482959379, 50.29329715236541, 46.831672114710656, 45.4066671863679, 46.7956216104569, 44.2077398300171, 41.415357435903246, 42.9065994293459, 43.14467553169497, 44.62842187573833, 46.02006704576554, 52.093115929634344, 58.364142525580625, 60.01531916279947, 51.612052917480476, 49.42760259874406, 48.35622287565663, 53.042694291760846, 56.36276883463706, 59.01733875274659, 58.67784976959229, 57.090090013319454, 54.799653330156886, 56.32525528630903, 54.210756517225704, 57.93659240968766, 58.127988384615996, 57.94624536268173, 60.73576834893996, 60.11144076624225, 59.839585211969194, 60.73450534574447, 61.624373466737815, 61.61904688804381, 62.432436635417325, 56.54045612581315, 55.406914680234856, 64.40102715646067, 65.73493895992156, 65.20150053885676, 64.69689546092864, 59.37524718623008, 60.479770937273585, 61.61611687752509, 69.48897669392248, 65.25541743924542, 66.84836649125623, 64.8889700058968, 72.60114992818525, 73.79624905124788, 65.61910352399273, 1.56559799707705, 0.23963426390001852, 10.594084532030168, 1.7656847185665563, 0.3804927667783153, 24.352482365023707, 85.63760219081756, 72.400559917573, 79.23178334389964, 79.03128747017153, 83.9784082289665, 63.31753515428113, 65.1782016600332, 46.60631233646024, 59.65880709309732, 96.4262931577621, 30.06624214110836, 0.9466575446628755, 0.4046336068741737, 0.21354582911777883, 0.24849315143881306, 0.24436424396211104], [0.08446647965859982, 0.05954207334246847, 0.060069463591301636, 0.028330596021166252, 0.08533540722583571, 0.014395680759222278, 0.05955506236322465, 0.22119682582636035, 37.701206284184615, 69.64452220547584, 37.820081556996996, 32.16856979554699, 25.784675036707235, 45.74054325780561, 64.01715655480662, 65.7213322577938, 61.64663683983588, 69.02113991398966, 55.311926641771876, 69.0127617313016, 7.608241035092262, 0.2635925299217624, 1.120270351248403, 3.1694467029263897, 0.06502600266568123, 0.20389059318169472, 52.63678781447872, 63.55382657820179, 63.65576113423994, 57.80959390824842, 51.85120767162692, 56.01037525361585, 62.82518356077133, 60.52200309691891, 59.5448543948512, 56.800524957718395, 54.51761138054633, 51.937331153500466, 47.58759913905975, 45.14804963142642, 45.65700069550545, 48.888021745989406, 52.26134638632498, 49.56970614771689, 46.77353082164642, 43.060987841698434, 45.781433966852006, 48.283047137721894, 51.428799783029866, 54.0863585472107, 55.98091040888141, 53.487396932417354, 52.49056185445478, 50.84689655611592, 56.003158092498786, 56.03141092484998, 53.58595825010731, 52.40807833210115, 45.54516607715238, 43.981524975069114, 43.829646879626864, 46.79202871937906, 49.785632625702895, 47.263666276008856, 46.636883289583274, 38.812347073708814, 40.644521482529186, 39.46932446572089, 39.86369525232623, 39.53164308301864, 37.842262560321444, 37.79924984901182, 37.72106132199688, 38.56060151130923, 40.040915781451815, 41.98974147919686, 40.84855925652289, 42.80058560832855, 42.959539659561656, 44.78902724481399, 46.409840814528934, 42.021638193438136, 48.61408341315485, 50.92546555303758, 50.92037431655392, 50.731186636032604, 42.536841515571844, 37.49161051165673, 38.488159256596724, 38.75470392165646, 40.41825955913913, 42.07001670714348, 50.931572683395885, 54.0459502896955, 49.97290618958012, 53.37497003616826, 50.447791468712595, 46.69835859729398, 47.777955685892415, 45.99577188491822, 47.49014392975838, 44.10114157584406, 44.83711158075641, 42.89706022508683, 42.58065439039662, 39.53893869153915, 39.032380273265225, 38.20191644853161, 38.15307509514594, 39.29543010650143, 38.0842218091411, 38.08548088996641, 37.70749776594101, 39.31273952607186, 41.445292965058364, 43.70111865382041, 47.256158859499045, 48.03017193271268, 44.39806892025856, 43.354224235780784, 48.01725556773525, 54.506648355914706, 55.14952874952748, 51.457750797271736, 51.373804230843824, 52.77985234414378, 51.00244991240963, 46.526990244465495, 52.42945524954027, 53.936045477467204, 57.438933849334724, 55.17164307255899, 56.551521132069254, 55.625598584451986, 51.903940016223544, 52.258953740519864, 53.963980597834436, 55.57789864078645, 56.185760113500784, 56.798222526427246, 56.973121012410815, 60.14532219979071, 57.330821560275176, 59.585439159024155, 56.712667788228686, 58.50299835205079, 58.477349973494015, 60.940735724664506, 56.46160471823908, 59.83179538480697, 57.910700844180205, 69.74674701690674, 64.53214806895103, 60.90153947953255, 2.0630637484212078, 0.26118486879333375, 4.7280735450406235, 0.34362435641307987, 0.3409781967920642, 24.736921710352746, 72.3931780169087, 63.878186979601466, 62.218106562091464, 70.49148744152438, 55.64027609363679, 44.52248650212442, 38.8612864863488, 42.570162050185665, 50.47650714074412, 66.32856615128057, 9.895256430872026, 0.2967120124207389, 0.1924516594097499, 0.10667513109623425, 0.05465913999585375, 0.037928009555945476, 0.07273304636680311, 0.05798475831867226, 0.10869722783325181, 0.02891458484584526, 0.06574196545707603, 0.01403583872747878, 0.038976971615826896, 0.10083707379958323, 43.24762205923758, 79.51189548738542, 47.47431716611309, 39.32791517626855, 34.74224475122268, 52.907592173545595, 68.31201461053664, 74.66743100074031, 68.4599664134364, 74.37321401411488, 61.31614969622705, 76.64714536359234, 8.906854448779937, 0.37582618815283625, 0.8610575766332689, 5.2704132949152305, 0.06035319574537778, 0.5786833287246766, 55.96313422726047, 66.16616433666599, 66.54060163805562, 57.53660871136574, 56.50371920677924, 58.80110240751698, 65.69566426738616, 63.993771383839274, 63.23096844457812, 57.58180226049116, 57.1835522497854, 52.97183275222779, 51.12161936298494, 47.75760642943844, 47.36698150634766, 50.436934348075624, 55.26476798519012, 51.63652458498555, 49.0031550776574, 47.00725309310421, 47.18495607376099, 49.46715970193186, 54.545766153643214, 55.790169469771854, 56.91614074091758, 55.764583849137836, 56.6469955444336, 50.8307481581165, 57.604912865546446, 55.29225987772788, 56.27873597606536, 53.482352764375754, 48.014423616470836, 45.58662945224393, 47.053564517728745, 48.89254816116826, 53.49815991617019, 51.69566216007356, 51.181698306914306, 41.50649370685701, 41.96874110929428, 40.01742862885998, 40.407822132110596, 40.677379177462676, 39.4348939003483, 39.161328192680116, 40.30611507354244, 41.2628556836036, 42.94276760470483, 42.32797530389602, 43.4914562009996, 45.47992137170608, 45.441611582233065, 46.81863415625788, 48.185599773160874, 44.80736824773973, 51.46227721245059, 54.98170229696459, 53.07230034182149, 52.89348733040595, 45.933508180802875, 39.61269886262956, 40.419514717594275, 41.58236019072994, 44.24987785277828, 43.329729034054665, 52.627209386517926, 56.86838196169946, 51.30018134270945, 54.89012279818135, 51.41572652324554, 48.661391119803156, 50.058315800082305, 48.18699613694222, 48.488445974165394, 47.15091774540563, 48.51056421956709, 45.16596309600338, 45.404066654943655, 43.69439571134506, 41.29267746402372, 38.321391843980365, 38.85221796651041, 39.71022859696419, 39.163022656594556, 39.87824332329535, 41.03120442359678, 40.23623412655246, 43.84716026244625, 45.2154084943956, 50.197858041332616, 50.58760827587497, 46.866636122426684, 45.05005705741144, 49.887453433006044, 56.74465471698392, 56.375340031039336, 53.89777491169592, 55.44467141551357, 52.551331135534475, 54.09795307344007, 47.57730683972759, 54.73487930913126, 54.8747431847357, 59.49134934333063, 56.46672341131396, 57.02815971066875, 57.96761835775068, 54.938987685788064, 55.70499520148001, 55.01395986926172, 57.40305200699837, 60.87651083546301, 59.332611022457, 58.0610570599956, 62.99692453876619, 58.82353444253245, 61.195481900245916, 58.67723787984541, 62.26353545342723, 61.21112039012294, 63.41380580779045, 60.182612173018924, 60.85129783999536, 61.203256037927446, 73.16018965936476, 71.50059561575614, 68.16188196982107, 2.4010345291706825, 0.15865815743323297, 10.23511411682252, 0.4695681079981789, 0.18377971264623827, 27.585970586346043, 80.50693019743889, 68.061383001266, 69.59963460122385, 76.14570956076346, 63.85655510810114, 52.324002327457556, 46.19687572602303, 39.97490621382191, 58.17543337422033, 75.15196923286685, 14.89887991259175, 0.5510990766267623, 0.26676045670624704, 0.11380017014040102, 0.08246800907316708, 0.11468755276573282, 0.2107400474168601, 0.13987369685163423, 0.23633375793935793, 0.1613582343223595, 0.2205123722312912, 0.1112472280980118, 0.3260347631669814, 0.2764856977568519, 49.56090827142039, 88.93129487191477, 52.817773818969734, 46.66217081008419, 37.36204678012479, 63.90210951528242, 75.69732773688533, 79.15210431621921, 72.99696414701401, 81.21339613391508, 64.69669934242003, 83.51101859923332, 9.596430659294128, 0.39434529119922274, 2.8445754128117717, 8.830665349960327, 0.1268231285916221, 0.8110469892140358, 60.732379421111084, 67.41889876704063, 69.26460143058532, 60.266652876330966, 57.62150841374552, 60.60109376907349, 66.88089862946542, 66.36691124208512, 63.01076266073412, 60.23489344504572, 57.95686714110836, 56.74838881338797, 53.3980021938201, 49.27286901781636, 50.15596712789228, 53.209312654310665, 59.029274525180945, 53.33471082871961, 51.76020083888885, 48.539111229681204, 49.81560737855973, 52.51162498228012, 56.56208015257313, 57.70841244728335, 59.93665995136384, 57.5400564747472, 56.59572232154108, 52.98787524623256, 58.671056224453835, 60.197481878342174, 58.01559678969845, 56.26195999883837, 49.51853882881903, 46.874406337738044, 49.02890936020882, 51.07237008310134, 56.57981711049234, 53.362245867329264, 51.96620372033889, 41.89469852755147, 44.98222751002158, 42.67472851660944, 41.7476684816422, 41.69028028365105, 42.011228223000806, 42.54494513234785, 43.27594549425187, 42.78989714960898, 44.73112129396008, 45.268642902374275, 45.85165223767681, 48.16073194626839, 47.012826781119074, 48.149490433354536, 52.88284201775828, 47.93545061542142, 54.68021323603969, 57.6848860709898, 56.29091885782058, 56.00531147372339, 49.99243567066808, 45.08082020667292, 48.22605902148832, 42.715230911008774, 47.48210307090513, 46.6344004292642, 55.70571299522154, 60.269975123866914, 54.903129377672755, 59.04252429162303, 55.81790062689013, 52.95920272027293, 53.55181794012747, 50.52155556217317, 51.1312017133159, 49.08428145993141, 51.7856256423458, 47.52284472988498, 48.031380022725756, 45.55165759978756, 43.00278771308161, 42.14643232284054, 41.95740153712612, 42.180756984218476, 41.08109304981847, 42.869599711510446, 43.76492777178365, 42.46694880147135, 45.691901945298724, 47.96649225296513, 52.27689858405821, 53.053743608536266, 49.99485969543458, 47.22390128720192, 54.07220271325881, 59.86159363100606, 60.37523584981119, 53.51644600591352, 56.84305521749682, 53.79352223488593, 57.248298814219815, 51.96096343378867, 54.902776364357244, 57.900894918749415, 60.775949108985166, 59.167263507843025, 61.33269817598405, 60.12544362775741, 56.33623400042134, 56.42680937244047, 57.1363426023914, 60.23501111615089, 62.85788043852776, 60.64565973897135, 59.040100266856534, 64.04102417730516, 61.57254326728083, 64.90587934370964, 62.654289814733694, 65.23637040968865, 62.738365819377286, 65.90069832340365, 61.51528842987553, 62.88023402613979, 63.641644523989775, 76.44744965337938, 72.21321967340285, 71.73234493501725, 2.5776980817317963, 0.2850764545221483, 15.178131095824705, 1.0800159241883986, 0.4788208873041215, 32.03169084364368, 85.57722906912528, 73.36641219354445, 75.55423182825889, 82.22755632092877, 67.48504561762657, 59.948121117007354, 59.66573007645146, 56.27405266607962, 69.49300889045962, 89.58602474581811, 22.08382268105784, 0.7125174794946948, 0.5072938320377182, 0.32353474247840147, 0.2779230319203869, 0.18620398256086534], [0.07528439494630984, 0.028178516076877717, 0.06103844607188817, 0.03516197249653839, 0.07885514608313961, 0.06801977468233916, 0.1108567454221268, 0.19531236961483958, 27.44444754815871, 72.05664650086435, 49.00555949057303, 38.783854976777114, 20.83802692351803, 41.86512777882238, 58.79935303042012, 63.675161177112216, 62.179879142392075, 67.66034418536772, 54.79239302296793, 71.41216970259144, 13.057780150444279, 0.35734735068775, 0.28139163289339314, 5.133565721973296, 0.14531289047050863, 0.19055536197077846, 35.220209090940415, 70.6794003517397, 61.139431230483524, 62.0967209723688, 52.38134345700664, 57.38921388503044, 61.72315443715742, 60.32945002278974, 57.03355689202586, 60.3053980488931, 58.09033363096176, 58.6247879459012, 52.31487104969641, 45.442023431101155, 48.069250506739465, 50.32476240588773, 52.48507445858371, 50.27987872400592, 47.42100431073097, 44.16466828315489, 41.91086653740176, 46.31643741361557, 48.61178882660405, 48.22712198380501, 52.725178426311864, 53.98101545149281, 54.75518934188351, 56.110682026032485, 54.264116441049886, 56.25675893598988, 54.03711318969727, 47.542495804448286, 45.87666519226567, 42.27803960923226, 45.348353309016076, 48.296861725468794, 49.211354486403934, 47.09864824048935, 46.927891777407744, 43.184738620635, 41.59500591216549, 40.27910955490605, 38.5836140571102, 39.61242429671749, 38.59420837894563, 37.87609692542784, 39.199771342738984, 38.83392010965655, 40.31414416528518, 39.87259118787704, 40.66366264897008, 41.56917710458079, 43.93415843286822, 41.97102392873457, 44.18155016437654, 44.184590001260084, 46.950339501903905, 49.365978240966804, 52.31101535981702, 49.25768160050916, 45.64412355422974, 39.37110439423592, 38.33392381668091, 42.032393332450624, 41.1047645538084, 43.057045859675256, 52.30677920003092, 52.75085818383002, 51.49964563308224, 52.60659733126241, 46.57822032128611, 45.37240528291272, 45.776997766187115, 47.827691339677386, 45.38969509063229, 46.160942892874445, 44.49214696884156, 41.39706350141957, 42.60680875470562, 40.90800277648434, 37.9841503789348, 39.96189963433051, 36.64418243592785, 39.57600116729736, 38.389676386310214, 37.55605505358788, 39.222481866036695, 38.55789115352016, 45.79579376405286, 49.19349985737955, 47.97598438878214, 47.446299675972234, 44.87573123747303, 42.930698471684615, 46.75938675480504, 52.17894131137479, 54.03380663164201, 50.3969693183899, 47.260277348179976, 51.158721062444876, 55.7625049929465, 50.064469998882664, 53.20098154006466, 54.51361056297056, 56.98582949176912, 56.29330758125552, 53.62432295276273, 54.600961746708045, 51.97128318971204, 48.734166775980306, 50.46026068349039, 53.05723451798963, 56.865314668224705, 59.083807237686656, 58.474086561510646, 58.933180378329375, 57.650549642501346, 59.57462518445907, 60.530240074280776, 61.02471759242397, 60.93269878818143, 64.13555722082815, 58.70230966998685, 58.134570121765144, 54.328388398693455, 67.77208466683665, 64.36764386392409, 67.11143985871347, 2.881661177642884, 0.13980623514902207, 3.176342719985593, 0.20885426070420973, 0.14299754293695574, 27.247989754523, 73.4866955972487, 60.36728520547191, 62.009126601680634, 71.99988980447093, 52.800640906057055, 46.54092642568773, 32.96916477141842, 28.426871838108188, 53.71340782411637, 64.29231474476477, 4.729238488981801, 0.09611540579146917, 0.10150085834245529, 0.1116622485701115, 0.14792394794283376, 0.010639179156221932, 0.04095354357794408, 0.06219040099230986, 0.012356648691028599, 0.11595028016956584, 0.13498236335092975, 0.004744046393992199, 0.11061698288446474, 0.21767433822876026, 33.37256485416044, 78.71920800978138, 53.124722819174494, 41.34908114710162, 33.92181042701968, 53.83935120797927, 60.96746667738884, 67.64107750308129, 70.03920678169497, 72.61146576173844, 60.35638101639287, 75.22479195748606, 13.173809743696644, 0.47468444152224454, 0.31942180027404143, 4.619947037389202, 0.5829827367298065, 0.14417531118998606, 39.707765348495975, 72.81703718246953, 63.35800616971908, 64.26030428178849, 53.45865380379462, 57.03614565633959, 62.178616139196585, 61.59865840788811, 59.07410329388034, 62.2182006989756, 59.448132668772054, 58.89386646209225, 54.44184687829787, 47.90711541329661, 51.158273912245235, 51.538622225484545, 52.388776348483184, 51.174320328620176, 49.73733255940099, 45.632140713353316, 45.73750734329224, 47.56475917754635, 51.7878927723054, 51.519692867032944, 54.05867053616432, 55.788031778027936, 56.31735171041181, 57.80964882143083, 55.56406444118869, 56.25704526901246, 56.766172839749245, 49.07476578989337, 47.785372887888265, 44.37911602758592, 47.95601560223488, 52.49296626737041, 50.80165201617826, 49.06850176472818, 47.96965368332402, 44.73524762738136, 42.70995140075684, 42.41520881652832, 38.20220278155419, 40.8329443008669, 38.59906427321896, 40.565685764435806, 42.00146152127174, 41.14171328083162, 40.832399091412945, 41.681674603492986, 41.87163106856808, 44.280107559696326, 46.27323642853768, 45.867953608112956, 47.98521372579759, 46.49481896431216, 49.07474617804251, 50.2703042184153, 54.01437128743818, 51.608934633193485, 44.45526492211127, 41.223741808245265, 41.44572834814749, 44.12806864707701, 42.88797601576775, 46.52026337961997, 53.65048516181208, 54.48801317522603, 53.8671451230203, 54.38551772025324, 51.05672374848397, 47.527755537340724, 48.442515019447576, 49.401561983170055, 48.60725456668485, 48.32202765249437, 47.656330831589244, 42.51529593621531, 42.74757869781987, 42.065015685173776, 39.8515437495324, 40.83748248315627, 39.522311764378706, 39.453835025910415, 39.87103008454846, 39.2794660599001, 39.22405865884597, 39.53630678115353, 48.31094695675758, 52.693724939900065, 48.72441184136176, 50.97465991973878, 46.79272297889956, 44.29771900177003, 48.723898010869185, 53.75504770586568, 56.59397294444423, 50.477668162315126, 48.67707275575208, 53.38474850500784, 56.15419680072416, 52.50629055884577, 54.88816161309519, 55.54755910750359, 56.22319521442537, 58.450089500796416, 55.11263885805684, 57.52386100830571, 53.348172403151, 50.87289402561804, 51.82564950758412, 55.183994616231615, 57.866381983603205, 59.57650007740144, 60.93667607153616, 61.30750871473744, 59.718474188158595, 62.34809783197219, 61.83169426456575, 61.8086071937315, 62.87457796835131, 66.75358633841238, 61.30764992006364, 61.427191995805316, 57.149368793733665, 72.54622105629214, 65.3539748345652, 72.87037357207268, 3.925102838585454, 0.08987341331498278, 8.762306282597205, 0.08195777153295856, 0.20444429088984767, 29.598744646195446, 79.76794781223421, 66.90917107366747, 71.12530323766893, 78.95564063902825, 56.382259092023304, 51.41327896425801, 47.008833808283654, 33.16724838749055, 60.48525441077448, 76.34895893835252, 7.824927962595417, 0.38468694494616607, 0.2623432550218798, 0.10437592503524597, 0.16890839853834722, 0.030241209728222702, 0.192609136443465, 0.145258697410745, 0.1497489072742962, 0.2253289202288274, 0.2868842688058653, 0.2934700815427688, 0.35557640055494927, 0.4420415269992044, 38.07781657864971, 94.151914658085, 63.25636971381403, 53.05531255660519, 29.625391267961074, 58.70215669755013, 69.0867768564532, 76.73236277795608, 73.92741310981013, 80.50204292420419, 62.97156641560217, 82.09457228260656, 15.822496106547696, 0.39564169582820713, 0.8348465218178688, 11.492978026790004, 0.40080497522027264, 0.2232527453452349, 42.73399945228331, 73.77578996842908, 65.95645089303294, 66.01996975560343, 56.94188717872866, 59.50314783280896, 65.45997688847204, 63.38727881831508, 59.45400445692001, 63.45638313601094, 63.72239435872724, 62.030087747881495, 56.03041856519638, 51.1863463155685, 54.08333439980784, 53.07082945300687, 57.40585257930141, 54.260264673540675, 51.76658645752938, 49.81459932942545, 47.147870063781745, 50.95055695502989, 54.17585526743243, 52.51968545298423, 57.97289394563245, 57.67233056406821, 58.43680443302278, 57.69246016779254, 58.53196505577334, 58.92925408578689, 57.62324602373185, 51.62762864943474, 48.6738956359125, 48.28182728059831, 49.284506690117624, 53.15191268920899, 54.87415090683968, 52.44756483262586, 53.40343859887893, 47.43231250393776, 46.33521772200062, 45.5209493637085, 40.58990247787968, 45.601922773545795, 40.37317583637853, 41.30939460569813, 44.566660235005045, 44.05509295002107, 44.88752580458119, 43.441418524711366, 44.678177141374164, 45.73760932491672, 49.49518111444289, 49.50397114599905, 49.58279509698191, 48.22830261722688, 54.00215702672159, 52.63935696694159, 57.90053013832339, 53.267242139385594, 47.90924526030018, 46.18637554107174, 43.809250554730816, 46.650552749633796, 47.81633607802853, 47.89534830277967, 56.48817485378635, 57.61003940336166, 55.35620627864715, 57.42598218302573, 53.29899764830067, 50.70462826759585, 52.06221157504667, 53.90017932461154, 50.844319558912716, 51.28293468106178, 49.55430300005021, 44.97937202453614, 44.97859539524202, 45.59515668499855, 41.08119503144295, 44.66902232939198, 39.933329089995354, 42.82503766398276, 43.3906905112728, 40.571141781345496, 42.188476208717596, 42.42914892012074, 50.79347387436898, 54.20661449432374, 53.776428545674975, 52.20370715664279, 49.09900603755828, 45.49016268022599, 51.06139921372937, 55.98804912259502, 60.80655144106958, 52.1917909960593, 51.69778416233679, 54.59985171594928, 60.25188123026202, 55.58075804864207, 56.43202220239947, 57.688616245023674, 61.3060966614754, 61.50703968540315, 56.94435042719687, 63.1491909488555, 55.19971547588226, 53.142385252060436, 54.098545351336085, 57.78356505978493, 60.26856699297505, 63.5603573245387, 61.67474846686087, 63.170913034869784, 62.000975916462565, 63.67363537511518, 65.77479416324248, 67.23867370236304, 65.94660574390043, 70.26650028844034, 64.00271831020233, 63.36698055267335, 59.25115123871834, 74.58762645721436, 68.3864611964072, 76.45656524165985, 4.406540191942646, 0.20186548571913474, 9.35161494439648, 1.5456574025654024, 0.2505913283675909, 34.60826050850653, 85.23657906439998, 70.69830617597027, 76.75676776516822, 83.71167136776833, 64.78940456144272, 63.25952722180275, 49.51941743973763, 42.034746754554014, 69.6694371008104, 88.92469744528495, 11.50453725168782, 0.8502679943077026, 0.5822601013125912, 0.38954317629817997, 0.3348104229136821, 0.16981339352505823], [0.04052959435108689, 0.039160576078199574, 0.07048177442723705, 0.11852747655563778, 0.1051446712846237, 0.030319454118369088, 0.09270591616270044, 0.3638328978371236, 19.92532668575164, 67.0310861833634, 54.203158886201926, 42.22533472122685, 22.75259660136315, 35.758460260206654, 61.68455831466183, 71.08823683954054, 57.95620426054924, 68.84176992600965, 56.85835246116885, 68.65603000886979, 29.729336038712535, 0.2671042769666641, 0.23675423295747852, 3.992830159202699, 0.2221476635144603, 0.3298703815427519, 16.03861380007959, 74.61696578610328, 58.56767823619228, 62.06303173495878, 52.206605788200136, 55.72071606113065, 59.165510208376, 59.38574737118137, 56.129583927892874, 50.730653193689164, 53.64398187206638, 62.587256508488814, 53.35526797079271, 47.91913355550459, 44.694239247229795, 47.860356838472434, 50.3619582422318, 50.44200205033826, 46.85546128980575, 40.13946533203125, 41.92416337228591, 44.095983659067464, 46.0860687686551, 55.02071026832827, 52.14283981630879, 52.9516835366526, 55.36150540074995, 56.38606379109045, 56.81024459100539, 54.8728447575723, 50.2309157771449, 46.757154926176995, 44.90715726729363, 45.17956979813115, 46.614243368948664, 50.88026023680165, 49.069050896552305, 49.36267560528171, 46.64751291275025, 48.72263893004387, 46.59643580836635, 41.9877802941107, 40.388406399757635, 40.47590271119149, 39.158068703066924, 39.09016855301396, 40.51307501331453, 40.25785423094227, 38.43773326566143, 41.96741927054621, 39.13181235713344, 41.139508908794774, 44.35911193970711, 46.59998163100212, 46.8018424895502, 44.994108369273526, 44.61334428479595, 47.62923117606871, 49.1523188929404, 52.109193724970666, 44.919355838529526, 41.13051491398966, 42.5774262797448, 42.614249490922504, 42.1088638613301, 45.794946532095636, 51.26133811089301, 51.70691151772776, 51.80844206963816, 49.753276994151456, 48.21508815211635, 44.28577146222515, 46.30232472573557, 45.06396578204247, 45.546193738137525, 43.05027977112801, 42.62107441502233, 42.516264761647875, 42.13653618289579, 40.73026841686618, 38.70328557106757, 39.30878185456799, 36.589179039001465, 38.87058250365719, 40.519676362314534, 42.15436335532896, 40.71509276666949, 40.36535070788476, 40.710134890771684, 43.2815662507088, 49.92040526482367, 48.721273945223906, 44.541560988272394, 44.09443824521957, 44.96969161495086, 51.957707866545654, 57.481711218434, 54.933547358359064, 48.78575378848661, 49.862809181213386, 54.513410522091775, 49.57090247061945, 53.399182827241965, 54.21123112401655, 54.40670244155392, 54.69763248197494, 51.003975714406664, 52.42115943662582, 48.421851973379816, 45.42782837344755, 46.10292319328555, 51.03701383836808, 52.967710341176684, 57.412010700471946, 58.494345603450654, 59.51278509632234, 57.70133256912232, 61.65048468497492, 60.08476472670033, 62.886803996178415, 62.293588653687515, 62.3904594298332, 57.25641419810634, 57.95980499636743, 54.007267875056115, 68.7632126961985, 61.812545253384506, 68.7441421324207, 6.319188398699607, 0.1606315692826625, 11.009741040968127, 0.5816678847036054, 0.3313874194939291, 31.904272648596, 74.9463507436937, 57.27952480316163, 56.19383235131541, 71.40115568714758, 60.4086858226407, 53.64558219909669, 28.609752347392423, 29.33984468060155, 52.2241936960528, 52.704193745889974, 2.176028744828317, 0.24905945895419968, 0.12872515636826717, 0.026943544038541378, 0.1045914332292253, 0.06401549438915907, 0.10009678771659251, 0.08951018038656443, 0.07012573506442771, 0.09572019635309136, 0.11585048189566982, 0.1867370265385797, 0.07772320520973976, 0.4279113416710208, 25.05455916927707, 79.10054083793395, 58.51989200038295, 48.122288796209524, 26.607039167035012, 45.196318318766934, 65.62092350375268, 75.62608180507537, 65.6582683901633, 73.35542171232163, 61.37393797597578, 75.82146290809878, 31.828427737759007, 0.5215880214687317, 0.11723517049704829, 4.705616995211571, 2.16075086785901, 0.36620568664323905, 19.460431683448054, 76.62719618889594, 60.18600502321797, 63.4590111240264, 55.43880747210596, 57.58942342573597, 60.703412717388524, 61.376059978239006, 56.062707516454886, 52.41273026312552, 56.569775842851215, 63.2083010673523, 55.90917810317009, 50.14689860805389, 47.15183950239613, 50.17220966277584, 52.26361743865475, 52.968369299365634, 49.018401330517186, 44.46788318695561, 42.265213458768784, 45.77356176991617, 48.809617488614975, 57.22001852527742, 55.75582127417288, 54.27010197793284, 55.800759869237105, 56.45372859893307, 57.94249949916717, 57.66705497618645, 52.22032231669272, 47.1065047479445, 48.00476674110659, 47.95460747134301, 46.96936299723964, 51.97554288371917, 50.24634245903262, 52.80693238781345, 50.6462045638792, 51.56678484332178, 47.97052837187245, 44.90653361043623, 43.781668447679095, 42.03609212752312, 41.33303865309685, 41.33296805043375, 42.37714613637617, 41.743557837701616, 39.75327268723519, 42.27987135610273, 41.353387909550825, 43.773113758333274, 47.46365224161456, 47.370939177851525, 47.279783295046904, 47.4912892618487, 47.32756953085623, 48.459718535023356, 52.68496236493511, 50.58889089092132, 48.527128388804776, 42.15293953495641, 43.07633215381254, 44.41018119935067, 44.39299337325558, 46.441768907731586, 55.193388692794315, 53.98161949649934, 53.05128428243822, 52.17588970738073, 51.25641161395658, 46.17284728634743, 48.01373720169068, 46.86483575451759, 47.603433747445386, 46.596643693985484, 43.522788093936065, 44.90268184292702, 42.17594815838722, 42.534637143535, 40.83074385120023, 41.76020437671293, 38.22939265158869, 39.647219642516106, 43.28922271728516, 42.778804686761674, 42.56152106869606, 40.081563303547526, 42.039096663075114, 47.37095094496205, 51.74787675180743, 51.74881027590845, 45.046075851686545, 45.625759017082956, 46.69728779023694, 54.45384933102516, 56.94287561601209, 57.378764690891394, 51.41768378596152, 52.314502346900206, 56.71258541845507, 53.0631180732481, 57.11049810532601, 57.05356882464502, 57.113930179226784, 56.901431852771395, 53.897888660430915, 53.82467762116463, 50.777341165850245, 49.06089628896406, 49.90594348599834, 53.78611680000059, 56.096047662919574, 59.407320407129106, 61.6165404935037, 62.59897262819352, 59.094523152997425, 62.599643353492986, 62.60036899197487, 66.19941034624654, 65.59634593225294, 66.05099570366644, 58.62946733351677, 60.67219849555724, 57.28071328132384, 71.96324702232116, 65.9793810690603, 75.69600982050743, 7.548932346605486, 0.10129288079277163, 9.326322520932845, 0.26222690158794004, 0.5169726788036285, 36.152921261325965, 80.38721161503946, 63.698871904803866, 62.16841405437839, 77.44843852135443, 63.91960720862112, 61.548887452771595, 35.99786212367397, 31.96118820098139, 60.42968619254328, 62.30804651014267, 3.334552501478503, 0.2954827170939215, 0.2077116558869039, 0.0654503770713364, 0.11220199581716331, 0.05898309728851723, 0.33492625540783333, 0.24142346224717556, 0.23183651538866185, 0.18549093856446205, 0.21087262659303604, 0.356127156485473, 0.36987990561512213, 0.7126304314982507, 28.18819953549293, 86.82584501081898, 67.17400950770225, 60.16937809605753, 32.08999491507007, 51.13637139720302, 73.14375492834276, 83.58532397977768, 70.08073683707946, 81.99077852310674, 67.95544762765208, 83.1657951108871, 37.85603007962627, 0.6345822517910312, 0.4363026091408345, 10.888735921152177, 2.194162352431205, 0.43302200614444675, 20.80296681773278, 80.32016261931389, 62.68743776505994, 66.45306218054988, 59.052628317186915, 60.97589977325932, 63.4528765370769, 63.111900975627286, 57.05426308416552, 52.509095053518976, 57.69606090361073, 67.50568512947329, 57.807746471897254, 53.02691067418745, 50.15664962030227, 52.96575700083087, 54.98594630149103, 54.15314082176455, 50.558253257505356, 45.33930440102854, 44.355558272330995, 49.198375363503736, 49.08781551545667, 59.07240490759573, 56.951830387115486, 55.066829496814364, 58.336760459407685, 59.17923458160893, 60.422739674968106, 59.379118565590154, 54.863501671821844, 49.920558237260394, 48.13471486491542, 49.65943821014897, 50.06195968197238, 56.35081737272201, 53.76347687936599, 55.61344315928798, 54.10834343202653, 54.00675404456354, 51.044364360071, 48.19176966144193, 46.0912972880948, 44.021639054821385, 43.71532547858454, 41.737623291630904, 45.97322217879757, 44.99351216900734, 43.73341544981926, 45.618498709894, 44.37090650681527, 46.64088802952921, 51.62713443079303, 49.7304174207872, 50.858106690068404, 50.04488560461229, 51.175285231682565, 49.72318849255962, 55.090269580964126, 53.237232085197206, 50.89772262880879, 45.68752850255659, 48.11798203376032, 46.520977250991336, 47.39000189688898, 49.44562196731568, 58.582018421542266, 57.68010862411992, 56.66084935588222, 53.02383945834253, 54.07550927131407, 47.986437505291356, 51.91003145710115, 48.834952077557965, 50.494852066040046, 48.04773630634431, 47.17045507123394, 46.304317289783114, 45.27627975709977, 44.153548363716375, 42.888462389669115, 44.23835392921202, 40.14270913216376, 43.40069255521221, 45.47286110539591, 46.207528883411044, 44.68569240262432, 42.816114271840746, 45.18943063674435, 48.49063073435138, 53.945686663350756, 54.061373049213046, 48.851280904585316, 47.72027331013834, 48.63955528505387, 56.290106927194905, 60.06366629754344, 60.42595994087958, 54.55073579665154, 54.50244749746015, 59.30324423697687, 55.780218416644686, 60.07718670752741, 56.612902302895826, 60.41593828508931, 57.048552113194624, 55.664073113472234, 56.87961562987297, 53.60848049963675, 50.39967967617897, 51.2782003802638, 55.70649354688583, 57.55731490350539, 62.03355120074365, 62.50010536563013, 62.380892768982925, 62.21666312986805, 65.20486201009443, 64.68119029075869, 67.37771388023131, 67.46100148847027, 67.86102048812374, 61.8638498552384, 62.73033672763456, 59.061685069914795, 75.03246245845672, 68.01312215866582, 78.57068354083647, 9.160077764141946, 0.14689444834666868, 19.5903209717043, 2.050379416154277, 0.5550181372992454, 39.01564351973995, 87.72929237734887, 69.09146801117929, 70.94850632452196, 82.52706850728681, 72.68298625946045, 70.53531600582984, 41.82669639587402, 43.48383895812496, 69.40622252802696, 75.18933373112833, 4.644307897936914, 0.616245906679861, 0.4492844593140387, 0.22847735773651834, 0.22619515116656982, 0.10846487336581755], [0.003976354951925215, 0.031992126661803455, 0.10241162197123613, 0.16214370427112426, 0.06265416763903153, 0.1954574513459398, 0.22036687681271186, 0.564808679684516, 13.8986421785047, 71.25031701980099, 53.5001564025879, 37.264222868027225, 56.614408493042, 43.46520769980646, 52.6362386826546, 66.98806562731343, 50.97531103318738, 68.01147476319345, 60.904991165284194, 62.07832113389046, 48.01372151220999, 0.0457558844749245, 0.06798716998028179, 1.5638233697222126, 2.4116099745996538, 0.21822616668237796, 4.1521955690076275, 68.75670156171246, 60.59840694550545, 63.27849972632624, 51.06576088936099, 51.48194397649458, 56.0597578940853, 62.359409947549146, 57.043111785765625, 50.28707627327212, 59.952184692505874, 57.6831013925614, 56.36365529029601, 46.96943752227291, 43.72136200627973, 47.09159189654935, 48.7861656373547, 49.11339721372051, 45.53512480951125, 40.608690631005075, 42.20931183907294, 46.60708504338419, 51.79325465233096, 53.545750033470895, 54.97140215289209, 55.14314705325712, 55.82698875857938, 54.86243870950515, 56.110697715513176, 55.081891398276056, 51.88702675604051, 45.57070462934433, 46.79292301977835, 43.935244929405954, 45.8506049648408, 49.25140973060362, 49.14437217097129, 51.284217296108125, 50.08452899994389, 48.303333636253114, 45.720052796025435, 42.317663392712994, 38.74248181619952, 40.937871625346524, 41.34545295469223, 40.62107747600925, 37.63476525583575, 37.600852443325905, 37.07993422785113, 37.53479188488376, 39.30277670583418, 42.27634906768799, 45.23101952768142, 43.23614128174321, 44.43561776991814, 45.39559433537145, 42.1504762864882, 41.923798591859885, 50.49251433341734, 57.26056798811882, 44.567444709039506, 43.33394165961973, 42.865767555852095, 44.02621253844231, 46.365165018266254, 50.010286377322295, 53.17036351849956, 53.90650610769949, 52.401061211862874, 50.73837634055845, 49.192601634610085, 46.23325178700109, 44.42746708470006, 43.62946479551254, 42.15073908528974, 43.45369162098054, 42.807543893014234, 41.166730157790646, 39.13021595247331, 40.70281967040032, 36.71272193231891, 39.167427478298066, 39.06876025661346, 38.22279130258868, 37.339614745109316, 41.18169399999803, 46.12772041751493, 43.03161321147796, 47.18319492955362, 47.16947840106103, 46.976654683389974, 49.112353863254675, 43.429047369187884, 44.440489353672156, 43.91823753233879, 44.540584318099484, 53.841092740335775, 54.51978045125162, 54.56563688093617, 55.55226595171037, 55.82333310957878, 54.90035626196093, 54.01504593510782, 52.789873999934045, 51.55193474984939, 50.67666569063741, 47.97287787160566, 45.52749579952609, 44.788497724840724, 44.27043891722157, 45.04193382878458, 47.50808485092656, 51.442226056129705, 55.77121657709922, 55.36702809795257, 59.99123580994145, 58.68231734921856, 60.011035934571304, 57.17585263713714, 60.96632919003887, 60.28566852692635, 65.75300147456508, 56.897760514290106, 53.611018273138235, 53.140659409184615, 65.42616605758667, 60.822907724688136, 71.44110110498244, 8.072685455122302, 0.4951257817447186, 9.634497261816456, 0.20347106811260024, 0.9127085728030052, 39.407468688103464, 70.77207026943084, 60.87672656582248, 55.025593619192804, 65.78514922049739, 52.8638812803453, 48.192138364238126, 41.26871570464104, 32.96368914265787, 56.95841996900497, 41.45043911472444, 0.40423475085727634, 0.07201460145053364, 0.05570864214772179, 0.0300396500801247, 0.057125981416433096, 0.061595300062289166, 0.031662463706227086, 0.05615916696467227, 0.06434544079726742, 0.08514354816607891, 0.1372433492853757, 0.17887258241253515, 0.2774775671141763, 0.6105841491972247, 16.549103413858724, 80.16062413492511, 58.624329028591035, 39.553729949458955, 35.2793505883986, 46.8319349135122, 61.15900385764338, 73.09612950971051, 58.00090751340313, 74.88469892932524, 64.99143800427838, 70.67705477437666, 52.55208423060756, 0.36812439981487494, 0.08891561188765111, 1.4467998233533677, 5.390002439098974, 0.41841243363676534, 5.018478478154829, 70.59186089423396, 61.75856167270292, 65.92516606853854, 52.804669180224025, 54.562063601709184, 57.78964473355202, 65.23952007293701, 57.290605498898415, 52.120176361453154, 62.12635840139082, 60.33987568270776, 57.53371400217856, 49.244035674679665, 45.03363801587013, 49.99520878637991, 51.94571325855871, 49.65693573797903, 47.39788978330551, 41.35946366094774, 45.09796096432594, 47.642261289781146, 54.1545646421371, 54.52067475165091, 55.6410252663397, 56.79857161737258, 58.206310272216804, 58.01136455228252, 55.59032863186252, 58.574177603567804, 53.639349552892874, 46.351758357017275, 48.54379061729678, 46.838767682352376, 48.766577320714156, 50.548290437267674, 51.63585385968609, 54.855782447322724, 52.20875132468439, 50.88038183027699, 48.99321971401092, 44.665378447501894, 40.13997916252383, 42.59910521968719, 43.159811958189934, 42.58913847707933, 41.3830880964956, 41.22523623128092, 38.688815947501894, 38.51545503062587, 40.62630991781912, 45.428808965990626, 48.17557027263027, 45.902486155110026, 47.618609397642075, 48.67105976227791, 44.24428455291256, 43.22456244499453, 49.38543319702149, 57.091180432227354, 45.99971778931157, 47.90282826269827, 43.42260683736494, 46.514493573096495, 48.339846980187204, 52.4300749840275, 56.69961021792505, 57.05791088842577, 52.436629264585434, 52.50171707522485, 49.24766386708906, 47.07654960693852, 45.82585873142366, 46.4976744497976, 45.64796355462844, 46.24071605743901, 44.84260289899765, 44.04736980315178, 41.148416611456106, 42.84752461218065, 38.844188874767674, 41.715995342500754, 40.788648974510934, 41.8355413406126, 40.155978510456706, 43.42570943217124, 47.082817554473884, 45.06503658909952, 49.540053029214185, 48.28532211242184, 48.89008491270004, 53.06602454954579, 45.11593718682566, 45.19947974912582, 46.52359347189627, 46.80795354227866, 55.95288115163004, 56.50639818560693, 56.37257476006785, 57.794586919969134, 57.052921633566584, 58.107348872769265, 55.71163185181157, 56.89384991122831, 54.889295178074995, 54.06552291685536, 49.649212591109745, 48.80711109407487, 47.361450964404696, 45.496630668640144, 46.505009282019834, 49.38419765041721, 53.65513317046627, 57.86209091063469, 57.47015983827653, 62.664413452148445, 60.423559450334125, 63.19276455909976, 60.43784864487187, 62.57668964324459, 62.14088686050908, 69.2980121797131, 58.65634341393748, 55.64946228458036, 57.036659486832164, 70.60893104922387, 64.33115013184087, 75.16140645550144, 10.356296723888768, 0.4234922094450843, 3.987998534594813, 0.10446030962010545, 1.4013520556111492, 43.79509079840876, 77.61315453437068, 66.801219601785, 59.88007583925801, 72.58939066240865, 61.009620389630726, 57.61720165129631, 42.20992372881982, 36.57854549346432, 66.76981710618543, 51.94357948918497, 1.2038871934337, 0.09353381206071185, 0.01197566454779477, 0.05232465175551273, 0.04297557136704845, 0.003651431686575375, 0.16846714721572015, 0.11647021638289576, 0.30365485277387405, 0.3085965488947207, 0.24859988280842382, 0.2805850648831937, 0.3779220821395997, 0.9120466115493929, 19.985560563302812, 95.63931665112896, 68.27420296207552, 51.15440253288516, 72.42188192182972, 63.46978587488975, 62.4750727991904, 78.06310530631774, 61.7126307179851, 79.57763441147344, 70.81264326649328, 73.97747039794922, 60.04030073842695, 1.1691918680744788, 0.27369952790679475, 6.340788891238551, 9.181466448691584, 0.5124674995820369, 6.177988465755217, 73.2218022500315, 63.53146122347925, 67.99080387238534, 55.38299998929424, 57.04605748576503, 60.063289750006895, 68.4289796890751, 59.88198995590211, 52.529330561237956, 62.02929150673651, 64.50953560490763, 61.134849902122255, 52.618921418343824, 47.54530029912149, 51.98449765482257, 56.210910351045676, 53.81050609773206, 48.645760474666474, 43.503556712981194, 47.28853410290134, 50.304628879793235, 56.037353315661036, 57.92180507413803, 57.55580479098905, 58.79257909713253, 61.25257984284432, 58.027297219922474, 59.614535300962395, 60.426677734621116, 55.45167284627115, 49.56139856769193, 50.422919719449936, 48.381851642362534, 51.09149163769138, 55.08094218469436, 55.647155930919034, 60.20681319698211, 54.539847297053186, 53.054496703609345, 50.08438779461769, 46.38432187418784, 42.66594240742345, 46.605629844050256, 46.977505837717366, 44.50487506005072, 43.03254673557897, 43.07471221493137, 41.803138640619096, 40.78268304947884, 44.874236814437374, 47.016678548628285, 53.526404903781035, 50.91771102720692, 49.009132769800004, 49.568788313096576, 46.336445423864554, 43.08891119495515, 50.85561206263881, 60.0076352396319, 51.016523376587905, 50.034424643362726, 46.45030790759672, 49.133001219841745, 50.7773333211099, 55.26727437973023, 57.27643397546584, 57.88908858453074, 55.573395759828635, 54.99921960215415, 51.53277789392779, 49.53583255890877, 49.06519128430275, 49.635629423203014, 49.380349805278165, 48.270173918816354, 47.76118363103559, 45.70027228324644, 42.90496380098405, 46.03007693444529, 41.06743535687847, 43.926188176678075, 42.922728215494466, 43.197388264440725, 42.423453638630534, 45.35444474989369, 51.11451987297305, 47.48238548155754, 53.27938579743909, 52.15078261590774, 52.813176801127774, 54.18502184652514, 45.70359060841222, 47.981303122735795, 48.83922353867562, 49.82603696084792, 60.718023546280406, 59.43153712057299, 59.78489952702677, 59.84238578427223, 58.01980157052317, 59.297199864541334, 59.304366034846154, 58.33951788563883, 57.50958750324865, 55.81877139306838, 52.106428453999186, 51.06599230920115, 50.847877148659, 47.37473210980816, 50.089177008598085, 51.86028011383549, 56.331935082712484, 61.44744319300498, 61.589931134254705, 64.29835519483014, 61.77321172529652, 65.80235273607316, 62.199887152641054, 64.03615259355115, 64.87938765556582, 72.67077199874386, 62.90186197526994, 57.27915610036543, 58.501401947390654, 72.98389480959985, 66.93440760335615, 79.08194880331718, 12.802051421134705, 0.6564502009461004, 16.220657863924583, 0.5401837333075462, 1.7485819588745795, 49.444657064253285, 84.59553041765767, 72.48187065124512, 68.10552535518524, 77.85507848185878, 66.8731637154856, 63.84238358466857, 61.96663556560394, 49.54784677874658, 76.78704846289851, 68.88216249404415, 2.2405468312002, 0.28208604563147793, 0.17266158585346517, 0.28226267486330003, 0.10285460465257207, 0.2260296148878913], [0.058523364094716895, 0.03447856078104627, 0.07414291627825269, 0.07310513527162614, 0.061823916020652944, 0.11908295924865431, 0.1268089712867814, 0.4068226877960467, 9.755875987391319, 69.49537015730336, 53.323398713142645, 41.3682536925039, 63.47562628407633, 56.826020363838445, 41.539531830818426, 66.59433810941636, 50.39322345487533, 59.984026493564734, 65.61217661826842, 58.33626624076598, 59.78088694234049, 1.5702968739694165, 0.14570652176776241, 0.6322838654441219, 3.7061696187142408, 0.02121487643659836, 0.06019132902785655, 48.00333115362352, 64.78636864692935, 62.36328917164957, 56.21547991229642, 50.60099140290291, 53.89928894658243, 58.87471352854083, 58.644956773327245, 61.983019305813706, 58.31360670828051, 54.19438454412646, 54.10240496358564, 44.32097865689186, 45.409150046686975, 45.61849086515365, 48.27210764731131, 48.0517332015499, 42.055092088637814, 41.53598208581248, 45.26369679358698, 52.13682290046446, 55.30204619130781, 54.38432531972086, 57.25182110263456, 57.00133069869011, 53.762908135691, 54.90526314704649, 54.618396682123986, 51.457182053596746, 45.07909044142693, 46.297241333992254, 48.60435201275734, 44.043584715935495, 44.361657557948945, 48.9386320883228, 48.639535673203014, 47.94423672460741, 49.58636053146855, 48.31980366860667, 44.21112875784598, 39.68778087246803, 40.97723653239589, 40.310582653168716, 39.375662188376154, 40.453137274711366, 38.91197919845581, 39.243819559774096, 38.341792091246575, 38.003197408491566, 41.368740066405266, 43.61548154584823, 45.742429917858495, 45.33452695415866, 46.48770770718975, 48.928888920814764, 48.631926275068714, 42.899962779014345, 47.058855795091205, 51.70040822798207, 48.679308506750296, 49.002680470866544, 43.44662350993003, 47.24958496709024, 47.4946899567881, 54.812114700194336, 54.92335311828121, 45.93521441182783, 49.787221185622684, 46.53911821303829, 45.47401035985639, 45.37161296413791, 49.12081833808653, 41.8190634635187, 43.698074894566695, 43.548460006713874, 41.390348403684555, 40.73161771220546, 39.3204979742727, 38.42901383676837, 38.14568142737112, 37.62680284438595, 39.12188483822731, 40.354925047966745, 37.37966998930901, 40.574299289334206, 45.48789162789622, 46.10611208023564, 44.95727731335548, 50.6083889930479, 49.000911481918834, 48.272260619748025, 44.10273013576385, 42.736317573055146, 47.25335828719601, 42.70957877559047, 46.521730346064416, 53.37189489795316, 52.97505694050943, 52.31595362386396, 54.60722577187323, 55.44541274347613, 54.838272986873505, 54.73136094308669, 51.5141740922005, 49.69019743704027, 46.319398803095666, 47.05457256686303, 44.93031494079098, 43.53440615438646, 40.57231457002702, 46.19571470445203, 48.54070371197116, 52.44178718136203, 55.72352055580386, 58.42213084620815, 57.61491098711568, 61.20391891848657, 59.120320581620746, 57.53073692321778, 59.16497284366239, 61.05161328469554, 53.14056527230048, 51.37720100341305, 50.537268577083466, 64.74461893881521, 63.30452465241956, 69.69936478522517, 7.317592915027373, 0.8763572104996251, 4.569918676730126, 0.22130743360086796, 0.5869947085457464, 47.553643180478005, 66.47672191742929, 57.898510117684644, 59.623415547032515, 69.42428896504065, 47.495752919104795, 49.706475273255386, 31.420358073326852, 28.623598314100697, 59.355298011533684, 27.31844532874323, 0.14745335545270674, 0.06631274692594044, 0.04568181526396544, 0.0620839913796273, 0.05810845087492659, 0.005193190816264119, 0.050971870716180534, 0.013173280223723383, 0.06923907256174473, 0.11283249383972538, 0.09962169829034999, 0.253423907824101, 0.20036634358186878, 0.4548836733785368, 12.921799421310427, 79.82277470250284, 60.22710754025368, 46.12399416585123, 60.09922650552566, 65.08426089440623, 47.91233216562579, 74.26708252199235, 51.894290985599646, 67.21440207573676, 69.19159827693817, 65.31139358397454, 64.22506178579023, 1.6158174507079588, 0.2806463519171361, 0.6627138583890854, 6.073911315010441, 0.10057537050376977, 0.09537936383557898, 52.375067664730935, 66.20522329884191, 63.9825181038149, 56.495199818764966, 52.33652645541776, 54.78528961058586, 63.29634651061028, 59.922484505561094, 63.94924463764314, 61.50689455770678, 58.48984272249284, 56.11732259873421, 46.9363837088308, 46.76481139275336, 48.61782927666941, 50.45753071385045, 48.10282599541449, 44.62114980143886, 43.4729661480073, 47.018604432382894, 55.864137526481386, 56.49615295471684, 55.43188448875181, 58.797117279421904, 58.75804262776529, 56.041154092358006, 56.83800712708504, 55.81784963607789, 52.40713304088962, 48.43767481465494, 47.35752467186221, 49.94663415416595, 44.44101887364542, 45.610767718284364, 50.921554949975786, 51.361715485972745, 51.285570513817575, 51.52328183574062, 50.89088201522828, 45.40219960674163, 40.72608324789232, 42.67616018172234, 41.40092311366912, 42.9245795742158, 42.26115772801061, 40.824785770908484, 40.72568708850492, 40.242859009773504, 40.01130188665083, 42.86397111031317, 44.95502587287657, 49.401867928043494, 48.30087431015507, 48.42123223889259, 50.47098052117133, 47.51678074559858, 42.81512583455732, 46.388734540631695, 55.74259111958166, 49.4626921223056, 49.78095716045749, 43.92459569438812, 49.44471589980587, 50.102081606465006, 56.43996500199842, 53.947738062950876, 46.82617295172907, 52.19064566396898, 47.94098507973456, 47.17914704353579, 48.224195895656464, 50.59236218852382, 44.39269135075231, 45.412182038830174, 43.417743098351266, 44.559513676551084, 42.52479983914284, 39.84113377909507, 41.45304356851886, 39.97944047374111, 40.36958294530069, 41.52650563947616, 41.039865016937256, 39.41674901593117, 42.432616295353064, 48.77857585107127, 47.88272611556515, 47.28277214111821, 53.928341942448775, 51.079387203339614, 50.25756828246578, 45.39564140381352, 44.89007534519319, 49.54223386702999, 45.85588055272257, 49.34490334603095, 55.90471836828417, 53.89748857867334, 54.389432245685214, 57.81829372529061, 58.5939149702749, 56.317422313074914, 57.11881745246149, 52.897484225611535, 51.594547379401426, 48.901644137597856, 49.95167439983737, 46.80018332696731, 47.08388443916075, 43.156991774036044, 48.97288222466746, 49.156586431687884, 55.009476600154755, 60.27867886327929, 60.68460887478244, 60.75422702297088, 62.61293234363679, 59.44724621311311, 59.68103908723401, 62.4326955118487, 63.782434078954886, 54.73046272031723, 54.08780590180428, 55.00145535315237, 67.43809484666394, 65.96666474496165, 73.84239965869536, 11.551545877610485, 0.8294122618052268, 1.9433097421161591, 0.19210394742267747, 0.8352325688446722, 52.52090531010782, 73.86022290875836, 64.06337776491719, 66.48835566736037, 76.34018067390689, 52.236964933333866, 55.777029529694595, 39.68574123997843, 34.34952528245988, 66.74699675652289, 37.9078249777517, 0.07978601185905357, 0.0970199564471841, 0.03305330016319791, 0.09843472166046982, 0.1416639370783683, 0.045393076725304134, 0.160940854299453, 0.14010617389313637, 0.2385573434613405, 0.21441670254834239, 0.17413769938772725, 0.4330128130893554, 0.34680147625265584, 0.66671020201137, 14.012340903282167, 92.75921437048143, 69.0480552181121, 56.62201789117629, 73.59022263557681, 71.60052191826605, 54.456218442609234, 76.71224886371245, 62.25767935475996, 70.29461583783551, 75.2930647327054, 69.05615099014776, 72.71644407703032, 2.4808454465481544, 0.4131357732319063, 3.273927122354508, 10.158023853455822, 0.26727824021250973, 0.2986953834131841, 55.32463904350035, 67.9147804937055, 69.0548409185102, 60.68058060061548, 55.74412084394886, 57.590023548372336, 65.10737542183169, 61.54822457221247, 64.44544799866216, 61.789870031418346, 61.28465306374335, 58.83561142029301, 49.573907006171446, 50.46131580106674, 50.499472618103034, 53.06140791985297, 51.88652469265846, 45.57137143227362, 45.11052823835804, 48.90478203373571, 57.898969034994806, 59.60408610682334, 58.23535934571297, 61.838154408239554, 62.73058775932559, 56.29423718298636, 58.91229767953196, 59.53224789711737, 54.81194603827692, 48.851225991402906, 49.16230132502895, 52.93261689524497, 46.83932858128702, 49.17477053980674, 54.01117847811792, 54.03143359768776, 53.55651301722373, 55.10475489401049, 55.53225794146138, 47.68590158031833, 43.37774668970416, 45.73136098923222, 44.62336986295639, 44.45369205167217, 47.46535062789918, 41.77103796312886, 43.14555414261357, 43.214395661507886, 42.64670318172824, 46.05891027758199, 49.64979310189524, 49.9658812246015, 51.92298704578031, 52.66758234270158, 55.516811647722804, 50.22136480577531, 42.73712950368082, 48.4874536145118, 56.0654963216474, 50.807311996336914, 53.56435383519819, 47.41777620007915, 49.56763121389574, 51.59832462187737, 58.4674342216984, 55.649897667669485, 47.924040440590154, 53.15199113661244, 48.81355162589781, 46.550328346990774, 50.55135773074243, 53.569123437327725, 48.76596935333745, 48.633883537784705, 45.126119659793, 46.81118557530065, 45.95357894897462, 42.203028202056885, 42.87567546290737, 43.93776701342675, 42.46450516485399, 43.62438532613939, 42.56212119133242, 42.38101359336607, 44.78197874561433, 50.20305910418111, 49.9266771347292, 50.69179035002186, 55.92635416215467, 53.428957539220015, 52.30564955742129, 48.7679030818324, 47.133647549536924, 51.66822518071821, 47.564370862899295, 52.278220422806285, 57.93320740422895, 56.21030238366897, 56.60394753179243, 59.93389075802219, 61.59684235049833, 58.920915126800544, 58.992035542764974, 55.36399610580937, 54.28146508432204, 51.73900435047766, 51.282734640182994, 49.91617694977791, 49.902083873748786, 45.79499752290788, 52.63814103218817, 53.507487312439956, 58.012176482908195, 62.46727904965801, 62.05382593216435, 61.60749550788634, 65.03726305500155, 61.15592871942828, 60.11123680299329, 65.1794921198199, 66.25489619470412, 56.876489500845636, 57.621155400430005, 57.31823075202204, 70.84151191096153, 68.71986266105407, 74.06628854813115, 16.68051262055674, 1.388062452597003, 10.684592243163817, 0.3794079249905002, 2.1475633690434117, 58.06677587570683, 79.11852098280384, 69.82942273539882, 73.87201355349633, 81.73993510584678, 60.705848509265536, 66.42475835738644, 47.68337165155719, 42.02648232060094, 78.78329953839703, 52.8550834040488, 0.3100121874482401, 0.1433405205006561, 0.17289105983030412, 0.1294151717616666, 0.2566662064242748, 0.27526801632296655], [0.055879100541313814, 0.15549421430595461, 0.06182214635754786, 0.025952831473982623, 0.026802501506021908, 0.0771391014718721, 0.08281696978355609, 0.4287191047783821, 4.8831885764675755, 63.873001606233665, 52.795883071038034, 38.00411916548206, 68.18288233972365, 76.48141737907164, 42.46985527776903, 57.35333596506427, 58.111961580091915, 57.08731297523745, 69.76395837722286, 57.15982191024288, 68.81704330444336, 7.607697296527125, 1.4519484245008039, 0.18267289945675483, 3.8290726753973194, 0.49926084856833186, 0.23831345170976656, 18.590544116112497, 71.67919681918237, 62.115375764908336, 58.22925613772485, 50.6413447472357, 56.93128108978272, 57.922554246840946, 59.07109483595818, 59.194469067358206, 60.5747393638857, 55.78564697696317, 51.922728169348936, 44.737153899285104, 48.10353986678585, 45.3240934495003, 45.70528114995649, 43.68966533291725, 42.02808264763125, 42.832199911917414, 50.69333968623992, 54.67160755588163, 54.63188179077641, 53.17907118028211, 52.213344420156176, 51.9500357104886, 55.419823200471946, 54.507738774822606, 51.32628079383604, 46.632600061355106, 46.23358126609556, 45.53240660698184, 49.290994290382635, 44.482996079229544, 45.582079502844046, 48.176131171564904, 48.04332363990046, 47.12744235992432, 50.032271262138124, 45.74648564861667, 45.3300162284605, 45.717970017463934, 41.85244283368511, 40.29996479711225, 40.59059281503001, 40.33473268631966, 38.42835880094959, 38.10931713350358, 36.395547313074914, 40.82979463761853, 39.53937407462828, 41.95272214951054, 48.82811146397745, 49.933804081332305, 52.649437458284446, 56.6224415071549, 49.643172141044374, 39.34445973365538, 37.21182000252509, 47.330377947899606, 46.971304570474935, 50.40737536645705, 44.11476396745251, 50.20605187262259, 46.38379235421458, 56.96380930562174, 54.575309445781095, 42.95804915889617, 41.49440496198593, 42.40377510747602, 41.416930306342344, 46.35258597712363, 40.7553009833059, 41.734053934774096, 48.43096756166028, 41.396424155081476, 41.16299606138661, 39.55303961230863, 38.7787127494812, 39.540123247331195, 37.61250188273769, 37.252953898522165, 39.70155231414303, 37.61177232188564, 40.11278537011916, 43.87201632222822, 47.70283445235222, 50.10531756185716, 53.59927469684232, 50.9599627987031, 50.24977845530356, 49.32495024896438, 47.041350257012155, 41.473373213121974, 48.576958179473884, 44.7091011078127, 42.86260220312303, 50.068831674514286, 53.47151917795981, 55.63309815622146, 54.94392987220518, 57.714448974978545, 54.60389960196711, 57.06213135873118, 54.48121963008758, 52.65002581381029, 51.781314957526426, 51.561332748782256, 46.374539482978086, 47.00591164250528, 43.31429842979678, 43.87181628134943, 43.97042466748146, 47.56727341682681, 49.28373398319368, 56.0813936879558, 55.95557581993842, 58.61464469663559, 59.35400755174699, 59.03072972451488, 59.89806775123843, 57.424436769177845, 52.349282003218136, 47.60544592334379, 54.27228281574865, 60.33874211772796, 61.70040861252816, 64.1136037149737, 6.067132969056407, 0.40018787607550627, 1.0865843007641456, 0.20261291174157975, 1.1127879398484384, 61.6676175978876, 63.827486422754106, 60.895220541184955, 56.85569309419202, 71.68540200879498, 51.48958475359025, 43.18313437123453, 24.214546334358957, 28.867691332294097, 55.380819151478434, 26.97809146296594, 0.2292532362644711, 0.08088396907213234, 0.017147196622024623, 0.05824024098054056, 0.035344255457241694, 0.06545198585597739, 0.1493049593221757, 0.06034563828800475, 0.03971797016058718, 0.03173641608877769, 0.033392129360788295, 0.07305412147674831, 0.1010970074322916, 0.4464802404324855, 6.580653104089922, 74.7031794824908, 59.94741509037634, 42.69536018371583, 57.358992022852746, 79.93912789129442, 46.98844140575778, 65.11440823155066, 60.4567309348814, 64.45284951117732, 74.58034653817454, 61.69101061359529, 75.40219291563957, 10.181752231813247, 2.171811216300534, 0.46056470563334806, 9.454050583224143, 1.4625775573715087, 0.45935827037019117, 21.869680881500248, 72.00106651552262, 62.37993963303105, 61.653916758875695, 53.41994001019386, 59.477613202987186, 60.55701809544718, 61.66360501320132, 60.24308727633569, 61.87731927441013, 58.53741715031286, 52.64896677386377, 47.49453306198121, 48.83035113734584, 46.46595816458426, 47.29215052820022, 45.00341223132226, 42.93937475450578, 43.46256009994015, 53.31465182765838, 56.31295865581882, 57.88616641875237, 54.65841662499213, 51.728100161398615, 53.61251269617389, 57.03811468616609, 56.191639746389086, 52.30283721800774, 48.231644476613695, 47.196436851255356, 47.47553310086651, 50.72375766692623, 47.76573358043548, 47.1323335555292, 50.423119760328724, 51.92076306189261, 50.85000699566257, 51.939343329398866, 48.288177597907286, 47.35586943164949, 46.8723863170993, 43.63963942373953, 41.99100840476252, 41.08686285634195, 41.809061419579294, 39.92909685257943, 39.67785335356189, 38.80329816572128, 40.462217561660275, 41.77980838283416, 45.47275127903108, 49.9833946074209, 55.342313243496804, 55.16948969133439, 57.87188114658479, 48.165591762911895, 41.5279176927382, 39.51329031298238, 48.2544412920552, 48.45450570506435, 54.605295965748454, 45.37793974722586, 51.08166610040973, 47.70123412532192, 57.63012978338427, 56.918631445977, 43.4604420200471, 41.5661294229569, 43.143671404930856, 42.32055025715982, 46.90442815903695, 43.39783314735659, 42.26202849418887, 48.47103457297049, 44.45937948842203, 42.469576789486794, 40.146101982362815, 40.69556328558153, 40.255924424817486, 40.99601684078094, 41.55788067848452, 40.69493178398379, 39.793622109197806, 41.34095399610458, 45.31263228385679, 47.96856326441611, 53.54613050337761, 52.94045379084926, 53.186688423156745, 53.02871104209654, 50.33596469509987, 48.42470353649509, 44.890475426950765, 48.50080144020819, 47.315778886118245, 45.14981077563378, 52.931251910425004, 55.234357849244155, 57.35184546439879, 55.64404549137239, 59.41802455532936, 58.01923282684819, 59.10428200998614, 55.133556858185806, 55.6163025671436, 55.093587906129905, 53.38310895427581, 49.30031384191206, 48.78719329833985, 45.91848942541307, 46.436348192153446, 46.02449540169009, 51.025438923989576, 52.29336469404159, 57.06492408629387, 59.67699512358635, 60.685511019922075, 62.49992101423202, 60.685777741093794, 62.13209290658275, 62.17808269685315, 56.015054641231416, 51.049169263532086, 56.15178062069801, 63.37603338303105, 65.41597181750883, 69.67224551785377, 10.4418691127531, 0.6064301140366063, 0.45269097652166124, 0.059304904012430104, 2.1188356847532335, 66.09794647462907, 69.94085727199432, 67.92498650089388, 63.84923988772977, 78.83877754211426, 54.710231134968424, 53.28117439823767, 24.182327985763553, 33.124204297219556, 64.67524789994764, 35.87840634007608, 0.2300945846664329, 0.0984700306528999, 0.06196635857885403, 0.046623475218732516, 0.05745102869226568, 0.10747507244588868, 0.2121729995574682, 0.27860187775185036, 0.12138315356306492, 0.16026206975502355, 0.2385073025981265, 0.1519128451904943, 0.17593043706109449, 0.6212187366139504, 7.393426549050116, 86.66482387050506, 69.02220679867652, 54.1037424918144, 76.09127490751206, 85.94899915879773, 54.653035133115715, 70.12690313400762, 68.42311966803767, 70.53820287027668, 77.73436361743559, 66.20849455556562, 79.11571256576046, 13.92468769704142, 2.2855697572231293, 0.5375068382390085, 15.19453738966296, 1.0968308799689817, 0.43410179175196156, 23.163692374383253, 73.22348102446526, 67.44207997475901, 63.46492605824625, 56.602402117944536, 62.746069354395715, 65.86742877960205, 62.765677282887125, 61.30066025641657, 63.83435841529601, 61.361496217789195, 55.28385423844861, 48.92634330257293, 53.35047091207197, 48.40713916286346, 51.41456942404471, 47.3259299801242, 46.06604114655526, 45.47442613109466, 53.26648512194234, 58.89239557327763, 59.14543159546391, 57.09471841012278, 54.24994099524714, 55.28418371754309, 58.25634794850504, 58.32038064156809, 53.8923934198195, 50.80980270139633, 51.39905252764302, 50.64567896627611, 54.46245893355339, 49.6937354149357, 50.653527628990915, 53.81429118494834, 54.04938628596645, 54.43695176032282, 55.337190628051765, 50.206950095392045, 49.05327512371925, 49.357619670129594, 45.685571239840606, 44.14863755626064, 43.24934397974322, 44.497002863114886, 41.449074129904474, 41.63988174930696, 40.50630108002694, 43.96511770063832, 42.8314507392145, 48.44543326285578, 53.127197834753225, 56.4765646380763, 54.88434514691753, 60.525195906239176, 52.4672943545926, 42.977778680862926, 39.62802748526297, 48.69887328916981, 48.328330901361284, 55.70506580414311, 47.78213301012593, 54.782720458122995, 47.55099950298187, 60.86493984345467, 57.14046501344251, 43.47486065280053, 41.3608011891765, 42.51377797895863, 43.533307890738214, 46.84389029779742, 50.645004318606475, 46.952351677802305, 51.20576204792146, 47.54471586596581, 45.00218060708816, 43.65766663705149, 43.638917707627826, 44.22566898407475, 42.702287089440134, 42.973111060357866, 42.38711287898403, 41.51120055106379, 43.639309944645056, 48.5342945591096, 51.07215435274186, 56.061209171049065, 58.30236911773682, 56.30721238351638, 56.24009278512771, 54.1345448647776, 51.10494144501225, 45.707505133844194, 51.58826766475555, 50.5399279440603, 48.17736671816919, 56.394849900276434, 57.4195259617221, 58.95547905275899, 57.57475376129151, 61.8821124107607, 60.76267580832205, 61.34968988357052, 56.8656559144297, 57.808919260578776, 58.49089391769902, 55.52930439672163, 51.49844931017969, 51.41225914801321, 48.29231177606891, 48.1817715398727, 46.97466211934244, 53.45349588701802, 54.0361169076735, 60.42190813249158, 60.49082809878934, 63.82041438933342, 64.4298134311553, 64.50056514432355, 65.29975591167327, 63.93245689330563, 57.75103684394591, 52.87899809498941, 58.58705474484352, 66.34123540693714, 67.72615371211883, 73.24803506174396, 15.309158852023465, 0.7005769266716896, 4.540158183343949, 0.556381467369295, 3.941194117069245, 73.86953461554744, 75.24707102006482, 75.00211900280368, 72.01765814135152, 83.94574273017146, 62.58486778505387, 59.47240821776852, 36.17400400100216, 44.73780893510388, 74.53971862792969, 49.40491168729721, 0.3547646537903817, 0.20923338229617766, 0.15639527160073483, 0.11397967220193918, 0.15050022502339658, 0.2172777804756357], [0.04920671603852703, 0.06971410836183256, 0.05415003626577316, 0.0399537528714826, 0.041602933328718915, 0.03124004665521845, 0.04284902130283656, 0.03973411163315177, 1.1528273719933726, 55.91204927813623, 55.552446380738296, 51.22289103846396, 76.63780227784189, 99.15063027412661, 44.902081720290646, 60.18024698380501, 59.62736537379604, 47.28137185496669, 69.11788909666001, 54.37151878110824, 71.48245857607934, 16.475294213141165, 1.320313681517878, 0.12781210213659272, 5.546475100901819, 0.4950613077850112, 0.2969272218404278, 4.7559767961502075, 60.06782400992609, 60.707382156002915, 59.686702989762836, 49.703039276984434, 55.396524321648386, 57.60872540935394, 61.770548435949514, 61.75792232636483, 55.77872007123886, 52.88228111882364, 50.38841855141425, 43.4102435265818, 41.2910496804022, 43.577073697120916, 41.7935170665864, 44.10833912511026, 41.218501521695046, 44.783206447478264, 52.666005549892304, 55.23634649092152, 54.770451284223995, 50.09200503749233, 49.42646118902391, 55.10657487377044, 54.85111482681767, 52.89563678926038, 53.068562323047274, 50.108145590751406, 44.51022517296576, 43.5328842747596, 48.86840597275765, 44.304406642913825, 45.02502841334189, 47.54117396570022, 47.81757946937315, 49.90018152421521, 50.02191620488321, 48.58270445177632, 49.21435117721558, 45.15874201251615, 40.69136242712698, 41.31138324737549, 38.64501483978764, 38.644508854035415, 41.02033945821947, 38.24968307249008, 38.220681067435976, 37.492151798740515, 39.82390672929826, 47.81990935725551, 53.30678747546289, 53.69814980414606, 51.64066268551735, 43.13601101598432, 38.07937375960812, 36.39729669017177, 38.59406325124925, 45.056807456478, 45.17657702968967, 51.014064050489864, 48.40759808017362, 50.30383263864825, 48.82723285305885, 50.72907247850972, 52.91669207234537, 42.83632232296852, 42.6603255733367, 42.244813211502574, 44.6766552617473, 46.368781443565126, 47.669988524529245, 52.486682630354366, 48.35589731893232, 43.877676302386874, 40.05327124749461, 39.49708700180054, 38.57880130890877, 38.526739689611624, 38.72425848437894, 38.93922398167272, 40.09726847371748, 40.146835465585035, 38.41768603171072, 40.040005791571836, 42.43254177031979, 48.16290886171403, 48.57454592181791, 47.91561518946002, 48.692554350822206, 50.77350116545155, 46.38481609282955, 46.44138843782487, 47.002444267272956, 44.816632886086744, 43.84013529746763, 47.23926521116688, 48.249667767555486, 53.02731860068537, 53.313914422065984, 56.30518059576712, 56.753978190883515, 56.86541664984919, 56.4968668260882, 53.53153536396643, 55.335319657479566, 52.22049097861014, 52.394067625845636, 46.43491260467037, 46.30172460309921, 43.63499533745551, 45.108602354603434, 45.377982893297755, 43.785739867917954, 50.091212718717514, 52.572174610630164, 56.758218273039795, 59.93021157480056, 58.088254774770434, 60.19739950856855, 56.97410944969424, 52.33310222625733, 48.75466508250083, 53.37036517358596, 60.46850196776852, 60.302220929053526, 55.277751030460486, 3.796807013211712, 0.18364806809732992, 0.4279885326902713, 0.4579550117975282, 3.6023932647320533, 63.406831833624075, 57.45812208421769, 58.48920337615475, 62.21098353785854, 65.51847511722197, 54.184068710573264, 42.605247651377034, 43.763131326244725, 42.80548464867377, 57.9265982104886, 27.802440312600908, 0.1666912481549286, 0.09320715216979866, 0.0719254824423021, 0.06566911049547695, 0.04474723396161872, 0.08572975864573833, 0.0606554480750234, 0.03136976832343686, 0.05495289257997948, 0.05940986954937539, 0.09848899132902585, 0.05045725498348475, 0.07768728334697024, 0.08299739881148262, 1.9136740291310896, 69.55997943878174, 62.04537714681318, 55.57794963159869, 75.14293209198983, 88.1505157101539, 48.460075470709036, 62.235753305496715, 65.39960768914992, 52.57904268080189, 76.01006615546443, 58.900110875406575, 78.03796291351318, 18.089984963017127, 1.436019066360689, 0.12601990838565175, 6.400999234568689, 3.0849495337855433, 0.575056484630031, 6.039181668912211, 63.50651494918331, 60.91335758086174, 61.39409111392114, 50.427250016120176, 58.223549089124134, 61.02625123916134, 63.25545972393405, 63.121863795864975, 58.452411543938425, 54.60587255416378, 51.413894776375066, 43.67731378924462, 43.861076831817634, 46.272922638923895, 45.38164246466852, 44.78777993109919, 42.75803965906943, 47.09653800533664, 54.50904492408999, 57.46722198301747, 57.193742567493075, 52.718078936299975, 50.36122475900958, 56.009582934841035, 57.07135677337647, 54.053139994221354, 55.91356723539291, 52.015692264803, 45.716683480047415, 45.50805261058193, 51.406697227108864, 45.59724338593022, 46.90047833227342, 49.109733719979566, 52.58212566375733, 51.834588589206824, 51.90591689079039, 50.857483033211004, 49.789307886554354, 47.17405188468195, 41.555899881547504, 42.964607361824285, 41.426147876247285, 39.39151248624248, 42.8515136626459, 41.925532279476045, 41.358220269603116, 39.133895135694935, 41.92634813247189, 51.28438988039571, 55.275256403030895, 55.47053944679999, 53.41910454534715, 47.46526041338521, 40.86739055572018, 37.877579581352975, 40.10453662564678, 45.81673137603268, 45.56276182974539, 50.66649890715077, 50.14619650379304, 53.32813301394063, 47.26984400903025, 52.17183005425238, 53.14792756111392, 42.31348606847948, 42.0774378315095, 39.715198239972516, 44.50633418175482, 47.9808638172765, 49.44804991445234, 52.94216394424439, 51.31616107879147, 46.19551858594341, 41.320902839783706, 40.242145138402144, 41.20606760824881, 40.30833513505998, 40.682780281189956, 39.49108577543689, 40.791143601940526, 41.516464371835035, 40.43935798829602, 43.60731909351964, 45.30459534737372, 50.775987948140795, 51.60762456155593, 52.20462106889295, 53.0255143104061, 52.55385321955527, 48.73621425321026, 47.84795822635774, 49.14198736990652, 48.16990244773127, 46.63744811088809, 50.20099985984064, 49.97833867226878, 54.55558384618452, 54.608877089715776, 55.177024564435406, 57.840459039134366, 57.78149012596377, 59.82891244273032, 55.228031066156205, 55.97649382006738, 54.29176130602437, 53.502764778752486, 48.76689111032794, 47.5712271659605, 45.34392103072136, 45.14638262410318, 45.51812525718443, 46.36957768471011, 50.99268321068057, 54.002933656015706, 59.38243689075593, 61.989098979580795, 60.953393213210575, 62.30654424236667, 57.98125643883982, 55.14922280465403, 50.2514023165549, 58.14342683361423, 67.81853337441721, 65.11431017229634, 59.98757623857068, 7.920355306517694, 0.36882068180749494, 0.6176096657591482, 0.4232578171837715, 5.026369796645257, 70.27869885967624, 62.09788591630998, 66.49402741462954, 68.42579472449519, 73.21488318904754, 56.91513269178329, 53.71649865181216, 41.357169074396936, 42.54217593900619, 67.60889837818762, 33.496331322577696, 0.13964275198598064, 0.09456407008392197, 0.06789680224873366, 0.12120568163452611, 0.017101445851186593, 0.09002534387212607, 0.1565091888750753, 0.14702146572451438, 0.12670859078606292, 0.1724281588629369, 0.2729244307885247, 0.16518634503647206, 0.1012329573953344, 0.14890040361112164, 2.2241380858805875, 80.68249548635175, 72.25935459136963, 67.39579600672569, 87.77558419012254, 100.58977926931074, 56.6099173791947, 73.05647434726839, 73.60831260681152, 60.088126197938, 79.7173963054534, 64.49308126203476, 85.20440778424664, 22.850242045617875, 1.7881500937284964, 0.20886300942830502, 15.025471468125621, 5.882052500401774, 0.5062947308103884, 6.6663730721319885, 64.93972547592656, 64.86584763373098, 64.27127907353064, 54.98211414583268, 61.32608505987353, 61.13969402928507, 66.84700150643626, 66.77412386863463, 60.043446479305146, 56.55756942687496, 53.89486843539823, 45.86482747908562, 44.556869999054946, 49.371826494893725, 47.41499523962698, 48.13256540606099, 43.355024399295935, 48.799113381293516, 56.91479536794848, 59.850544314230646, 59.522167405774525, 53.81142000998221, 51.29686693991385, 57.539020969021706, 59.31729416693411, 55.24670939291678, 58.91511786368586, 54.18837155065229, 48.86371481803156, 48.43842398735785, 53.46443145505844, 47.835681207718395, 48.969214808556345, 52.14731524067541, 56.50745330318328, 54.81849247409452, 56.78930697902557, 54.058203774113814, 54.59069298159692, 49.29631694670647, 43.357005196232954, 46.00334990409113, 41.98459140716061, 41.16605551012101, 45.206124244197724, 45.260998202908425, 43.59448509831583, 40.33396782413606, 43.804418194678526, 52.32774034623177, 57.01258005634431, 58.79132001630722, 56.28267795808854, 48.541911801984234, 41.94996080090923, 37.20325746843892, 38.58774039053148, 47.27469990330358, 46.05557234056535, 51.616053735056234, 53.9502562246015, 54.89695164465136, 48.750389699013006, 51.99833185442033, 53.08128256951609, 41.99114961008872, 43.14097673662248, 40.841879460119436, 45.92776190850043, 53.11943546418221, 54.657565470664736, 55.33584917745283, 53.642483526660556, 48.43273262823782, 43.12935083143173, 42.7264488897016, 42.64308675642937, 44.55685038720408, 43.2712661066363, 41.43507126838931, 43.33745218092396, 44.57608176815895, 43.52697326290993, 45.22094688107891, 45.623280079134055, 53.703335177513864, 55.31225612086635, 54.07102207983694, 54.765034491016024, 55.650882182582734, 51.51997920005552, 52.55073885763846, 50.90348066822175, 51.091883874708614, 49.188181123425885, 52.35453013450869, 51.16655795804916, 55.7052933016131, 58.73473198183122, 58.926994800567634, 59.287068382386245, 58.86563324159192, 62.22755555183657, 58.47972692981843, 58.52388497321837, 56.42854306005663, 56.76489414707307, 50.30861400788831, 50.45849169454267, 46.998368924663914, 50.152323246002204, 48.33637960495488, 47.52934801963068, 55.09459595526419, 57.658559122393214, 61.48886734439481, 64.70953725999402, 62.567750561621885, 65.77522562396142, 62.47411181849819, 57.713805706270286, 55.034383650748964, 60.04588619355233, 70.64976292271768, 66.88315791468467, 67.22883639797088, 14.352065228646802, 0.5805631246297591, 2.7561877427562593, 0.6931355775844666, 7.6832637190818796, 76.56962363950669, 69.93500509569722, 72.19285472746819, 77.13385658879434, 77.51619354371103, 67.6401988921627, 59.95700920781782, 58.95290597792595, 58.699081559335035, 77.69452802596554, 45.38636892072616, 0.31183526220340885, 0.25636075184710566, 0.17799391020690242, 0.1462950917982286, 0.11370254755620995, 0.1532241425687267], [0.09314542080486014, 0.03378813936104698, 0.022116157812096422, 0.10378863437161331, 0.10185680577471372, 0.06757532111218861, 0.04549675906497625, 0.060379909231297435, 0.08708088493515408, 38.61083922847625, 62.30499490614861, 39.34724069410755, 58.92669670043453, 93.20352477412071, 46.47645834953555, 54.37220127351823, 64.42452607616302, 51.03415050814229, 63.2376717752026, 56.82822473587529, 67.7866288154356, 29.996767159431215, 1.8018913821827982, 0.27478872107401975, 4.205255431513633, 5.258729044468173, 0.08484764670532557, 0.1728410649323656, 42.4312513105331, 62.27118015289307, 57.03008559442336, 53.780829445008315, 53.773984909057624, 57.304973140839614, 59.8862692617601, 61.32645768503989, 56.314154978721376, 53.73570257617582, 48.97823625995267, 46.99314824996456, 41.33009295309744, 44.229281487003455, 41.07482117991294, 43.159933551665276, 39.536561735214725, 45.56915137075609, 50.491773005454775, 54.80734509806479, 55.143755020633826, 55.73132215007659, 53.713278385900686, 55.75063590080508, 53.34588173897036, 56.63373793325117, 54.823654313241285, 55.6296347033593, 49.320980810349994, 43.22415451849661, 46.38688710428054, 49.014478960344874, 43.41809611166678, 49.40326429182484, 48.879965197655466, 50.69199431327082, 46.84172122709213, 51.29935764497327, 46.39256277391988, 41.473177094613355, 39.099680300681825, 39.626756637327134, 37.583523411904615, 40.927763677412464, 38.937682490195, 37.953300937529534, 38.99727898259317, 40.14487820286905, 45.28756441608552, 50.58363099252024, 53.8132478344825, 52.6910420387022, 53.024294453282515, 40.08761944309358, 38.901129922559186, 38.302584079004106, 38.21633508128505, 38.27613553693218, 40.36472312865719, 51.21920793287216, 52.70376620754119, 50.52607021024151, 47.922738213692945, 41.31627836535054, 41.60046192907518, 40.93440032774403, 41.85968745139338, 43.43452692031861, 46.43761119534893, 54.14902625545379, 57.1737188677634, 55.38177228743031, 51.00171642918741, 47.703520867132376, 44.13389728915307, 36.85066776890909, 37.5575690884744, 39.52449260219451, 37.66598340003721, 37.88223935711769, 38.53650639134069, 39.34655820169757, 38.092819644558816, 37.12013852211737, 41.15670065726004, 46.819320571038034, 51.179187990004024, 47.69548000827913, 48.736912435100926, 47.994439140442886, 45.010256767272956, 43.64875108964982, 48.29095463598929, 42.278847617487756, 45.29555820649671, 47.57524367301695, 52.07652822617562, 52.56331789878107, 54.78446199047951, 54.599341807826875, 52.581764805701475, 60.606318366143014, 50.823911466906154, 54.92832276128954, 55.34514911713139, 56.333606012405895, 51.025721334641986, 46.63740496481619, 38.73471944562851, 42.204220602589274, 44.71832260008782, 41.842291739679155, 41.29674496189241, 43.53921498021772, 47.17875480651856, 49.37885538224251, 55.66443397152809, 57.58541868579004, 59.5193079979189, 54.86241909765429, 51.86868183074459, 46.363686284711285, 56.97132848924207, 59.89347073339648, 60.44746237416422, 35.12792356552617, 0.875954922408827, 0.12073762489542847, 0.8412600873458771, 0.5097319221784992, 12.05977620617036, 67.40882612043812, 60.08446270419706, 65.41463821165024, 64.87823840110534, 62.088938989946925, 55.830161956048784, 37.300606773745635, 21.67774950304339, 39.2428703461924, 60.58698500356367, 12.974732787378374, 0.31258955237365543, 0.18362042764502187, 0.1333081701229657, 0.11381810425870842, 0.05758762599960451, 0.0518233084961051, 0.028224042766997894, 0.06926465223753644, 0.06680775463821427, 0.03196375459552773, 0.030379097893713947, 0.057870232004431955, 0.04863577369119852, 0.0869535841047764, 0.04255945538921703, 49.85288558467742, 70.23658829350626, 47.14811325073243, 67.05659727896413, 93.08392386282645, 54.44706363062705, 61.69317968430058, 72.7827948908652, 53.37089469355922, 72.6623781265751, 59.18243915803971, 75.0645003780242, 31.142079637896632, 2.2606244635197426, 0.3555387090290747, 3.326925207530299, 6.386102562950504, 0.22009634052313146, 0.19509047990845096, 46.545939214767955, 64.42514581065025, 58.54592477121661, 53.32278290102559, 55.94466378611904, 60.85826789179156, 60.32467649829004, 62.748242347471184, 57.91526256069061, 54.51117869346373, 52.03140135734312, 49.14921237576393, 43.64164375489758, 47.397968230708955, 42.342374324798584, 45.542844034010365, 41.698580018935665, 48.24286245530652, 51.66329083904144, 55.52986921802644, 56.94543692373461, 56.38245913290209, 56.07263503536102, 55.1836141463249, 55.07372110120712, 56.533599822751945, 55.620213170205396, 57.725659108931026, 50.588988950175626, 46.50081626830563, 49.29526967387046, 49.99853103391586, 45.1501206428774, 50.51802150664791, 50.09413096212572, 51.59245283372941, 50.330693029588275, 53.35331855281707, 49.473160928295506, 43.2282220163653, 40.448414741023896, 41.11511176632297, 38.74826338983352, 42.460782835560465, 40.80488366465415, 40.615790121016964, 41.695865738776426, 42.248735581674886, 46.467087807193884, 50.798698471438506, 54.516473893196356, 55.93834092540126, 54.54607209851665, 43.1666604165108, 38.94765315517303, 39.02447277499784, 37.28051247135286, 38.95594112334713, 42.417495558338786, 51.671869062608295, 52.58232570463612, 51.78970490732501, 46.451225742217034, 41.15509248548939, 42.47632326618318, 40.0522239746586, 40.80366772990073, 41.6690053478364, 47.40491082591396, 55.58740646608415, 58.848304210170625, 57.51041904572518, 52.82653247156451, 49.923429412226525, 45.736181582174, 39.37422660089309, 39.605571916026456, 40.17192686757734, 39.159563126102576, 41.1020581183895, 41.384092223259714, 40.265977459569136, 41.649475866748446, 39.69904984197309, 41.961347441519464, 49.34521713564473, 52.35519693743799, 49.88319373899891, 50.297482321339274, 50.4340200270376, 45.91106437867688, 45.10666470373831, 50.23063336649249, 45.80132038362565, 45.73614235847227, 50.00493234203708, 54.10748443295879, 55.41324930806314, 55.1346198205025, 58.30214162026682, 51.393039534168864, 65.68968657524356, 55.05420730959985, 55.77758650625906, 57.96312724390338, 56.47492900971444, 53.793396719040416, 48.36517372438985, 43.296902718082556, 45.25041957055369, 47.011293134381695, 45.11601171185894, 43.506294527361476, 45.51701522642567, 48.76426704468266, 50.415643722780295, 57.71578258083713, 59.950596132586085, 61.63260652172951, 58.18700828859883, 55.19052928493869, 49.11022009388093, 58.39752581811721, 65.70891403382825, 63.1904346712174, 44.89069115731024, 3.7315878031715273, 0.6802293862546644, 0.3016009710488781, 0.4248376437012227, 13.768317507159326, 74.76881642495432, 63.83351902807913, 71.06101559054467, 69.75601165525376, 71.54342789803782, 59.03290271759034, 51.68397741933023, 31.23434751264511, 45.669689563012895, 72.1916623269358, 16.81200811939855, 0.35141424486233347, 0.23793918711523857, 0.06959629936083671, 0.10420392297448651, 0.03931839019060135, 0.04479072860351974, 0.22209077382520323, 0.19254648577301733, 0.17715786313337667, 0.14211389115981518, 0.2079241839988578, 0.19500680778536106, 0.17797098885620796, 0.25937742223182036, 0.274224144917342, 57.62178297965758, 82.02675450232722, 54.70220204322569, 70.62916263457268, 97.63621884007608, 60.77492144800002, 65.74038713209092, 78.62471811233029, 59.07817471411921, 75.2995680224511, 63.99903520461052, 81.61325823876166, 35.201291499599336, 3.1753498700357254, 0.6333983088693311, 10.499712305684245, 9.253715526673103, 0.21287761658670443, 0.7994034946445496, 47.253793670285134, 67.83891400983258, 60.8723884244119, 58.37746681705598, 59.16130542755128, 62.77308664014263, 64.33314661825857, 66.08608522722798, 59.424472931892645, 57.945915883587254, 55.52785704212805, 52.69924763710269, 46.76479570327267, 51.36521424016645, 44.3715536978937, 46.50520147815828, 42.7689399257783, 51.910749250842684, 54.60014981608237, 59.15270759213356, 58.75033124800652, 60.419299756326986, 58.53414589358915, 59.30706070315454, 57.55446726276029, 61.17226146882581, 58.133444401525686, 60.04580774614888, 54.511143392132176, 47.614502676071666, 50.08631760074247, 52.821252961312574, 47.805231848070704, 54.91174682494133, 53.692278015998106, 54.806784199130156, 53.96371779903289, 55.70181808164043, 50.91185885090982, 46.222967332409276, 41.65913274211269, 44.317617185654186, 40.36002805156093, 45.71110979203255, 41.9914633997025, 45.131559987222, 44.9234821719508, 43.840131375097464, 48.2018619198953, 54.26351239604335, 56.48228737615771, 59.73088848975397, 59.9578760516259, 46.603739261627204, 39.71374304063859, 37.662072796975416, 37.634404397779896, 38.47709425034062, 43.182040029956454, 53.27323552100889, 56.72421132364581, 51.78565309893701, 47.662892956887525, 41.37006190515334, 40.312583061956595, 40.61470754684941, 39.274680768289876, 43.09024480081374, 48.104818559462025, 57.1736757216915, 59.72508730426912, 58.33985128710347, 57.99861684922249, 52.13893705798734, 48.42018496605658, 41.7849466877599, 40.460201463391705, 45.23358868014428, 41.97620145736202, 43.53990531736805, 43.03318608191706, 43.05543768790461, 43.48611001045474, 40.401636554348855, 44.50486329294021, 51.096555417583836, 57.1212963904104, 52.234274187395656, 52.08481619434973, 52.68785315175211, 48.98817554596932, 48.51704005272158, 51.984003436180856, 47.127285465117424, 48.93790252747075, 51.60789912746799, 56.746490386224565, 55.7002922796434, 57.5468147185541, 59.59009109004852, 54.39539032597696, 60.16116857528687, 54.16812819819297, 58.603234521804325, 58.19753593014133, 59.53038084891535, 56.63393797412996, 51.13355905778947, 43.85511482915571, 47.12981539387857, 50.26915888632498, 46.513085442204634, 44.63266588026478, 49.14903979147635, 50.913317972613925, 53.22140532155191, 61.498453617095954, 62.37013762997043, 65.33167616013559, 62.38093591505482, 57.1076230079897, 51.69366567365585, 61.23410547933271, 67.97164701646375, 67.92171524417016, 54.976889548763154, 8.958533636985287, 0.9490680249948656, 2.7090847348013236, 0.7554488629102708, 18.452386471533007, 79.45327958753033, 71.93924211686658, 77.60707486060359, 76.05491453601469, 75.35399483096215, 69.10673387588994, 52.63789784523749, 33.57391188221593, 56.73579408276466, 82.92767586246615, 23.289068975756248, 0.7322434468134758, 0.28180663804373435, 0.24162532641522347, 0.4381343253677891, 0.11304592593542992, 0.10854685243459479], [0.08220455909688627, 0.05732452076288962, 0.10162298041846483, 0.1559804656332539, 0.05208621838039929, 0.07943518189412933, 0.1434559393073282, 0.1710322087690715, 0.311429450108159, 27.123223081711803, 59.17455911636353, 43.8043789709768, 36.159534377436486, 66.3034551374374, 54.11492516917568, 42.50772183941257, 66.35032746099657, 45.98004318052723, 49.59398169671336, 58.77635617409983, 59.6517115254556, 45.48453407902872, 0.7014044854910143, 0.4078042915751858, 1.3932713601858386, 4.936842187758415, 0.3305464694576879, 0.0761685676632389, 16.98576911803215, 67.41004989993188, 55.96988070395685, 55.138871669769294, 50.044450221523164, 62.99065659123083, 60.297514084846746, 61.25680423551991, 52.51794784299789, 52.06255282125166, 48.11160425986014, 48.356493519198516, 42.92352445663945, 42.909105823886016, 39.24405097961426, 42.22191833680676, 41.057601974856475, 43.82688160865538, 46.109614756799516, 52.63056301301526, 50.75770185839746, 54.23358471162858, 55.96062783272036, 55.21625218852874, 52.2583536178835, 54.16024423414662, 53.23354113486506, 56.13190989340506, 54.16693972003076, 45.97992550942206, 44.01091921714045, 48.19298559619535, 42.423967469123106, 46.4965840308897, 46.0924308530746, 50.517641036741196, 46.92589136861986, 45.48844075972035, 46.54334652808405, 42.7554234381645, 40.20496499153876, 40.933557018156975, 37.56171111137637, 39.6202729594323, 38.63081585976386, 39.08014689722369, 41.070510495093565, 42.454134418118386, 44.49060155499367, 46.89334354092998, 51.50713343774119, 51.73158714848181, 50.10669431378765, 44.10731146412511, 37.4538145526763, 40.151114771443034, 38.1727183249689, 40.712927618334376, 40.87244649087229, 47.675852467936856, 52.50948336816604, 50.15270371590891, 42.591448753110825, 42.450906307466575, 43.274070601309504, 43.43265594974641, 41.790088915055804, 42.21961590551561, 42.986196087252715, 46.509661213044204, 51.79641216031967, 56.14289252988754, 53.5474641092362, 50.19563405744491, 42.809238356928674, 40.85546262802617, 38.70227752193328, 39.93447834445585, 38.42635839216171, 38.22898472509077, 38.214224846132346, 40.0726399114055, 41.51160455519154, 40.969317267017985, 42.38352391027635, 45.42479245893417, 48.56029987335206, 48.587956505437056, 48.19747671004265, 48.2237369783463, 44.433684041423184, 43.75036793370401, 46.233804841195386, 45.13723565686134, 51.618046299103774, 52.15792132962135, 52.83804855039043, 52.097210884094245, 53.80273196005053, 53.247998991320216, 60.32120127831737, 39.58800362002465, 44.56871947934551, 59.10537242889405, 53.960878003028135, 54.29772723105646, 50.0419516717234, 42.466207473508774, 40.97687175196987, 44.165299784752634, 44.066918896090606, 43.95688072327645, 43.75261937418292, 43.50112484347436, 45.78277541745094, 45.52794687209591, 44.5810474887971, 49.2968503890499, 54.65920109902659, 49.992639633917044, 46.69196121154293, 48.666168566673036, 56.94606842533235, 58.13154597436228, 60.05404864588092, 34.178384427101385, 0.7094558857141003, 0.25666730959088574, 0.5616637968247937, 0.15661403566839235, 32.849306944877874, 67.67302128576463, 54.322595057948945, 59.53178897980721, 65.94193812339537, 58.98001347818683, 54.613885956425825, 34.06042698890933, 24.91358526291386, 41.39230174403037, 61.230834222609005, 4.2428846897617465, 0.25799457224146016, 0.1684872187193363, 0.05003282312123526, 0.056171324780030604, 0.07033770393219686, 0.060872024961657105, 0.07095498693806511, 0.062499226356345805, 0.051560846773246606, 0.045328813439775864, 0.02654255829721449, 0.02994789764465344, 0.0937710465082238, 0.15639127262177008, 0.2055650009142776, 33.85754239174628, 71.06814645951795, 45.22689711663031, 46.83981887755856, 75.1757231066304, 60.51709228946317, 47.02737877445836, 74.86489095995503, 51.47210274973224, 56.12408084254111, 64.45084910238943, 65.72658431145453, 47.709102399887584, 1.2339388002311031, 0.6020292147032676, 1.7657917257278197, 8.475890890244516, 1.1159502282258005, 0.1047386906500305, 20.639784451453917, 71.60049053930467, 57.22434097720731, 58.76469496757754, 51.40284153722948, 63.42167015998595, 62.12702912669029, 63.51887433759628, 55.61922473292197, 55.00792726393669, 50.623431282658736, 49.5821165269421, 45.3365626642781, 43.4840743003353, 43.58811909152616, 44.753180703809186, 42.92551702068698, 45.66197818325412, 47.919796436063706, 53.41716297211186, 53.251105508496686, 56.08471201312158, 55.982145955485684, 55.8282752959959, 57.1298393126457, 56.20662712281751, 56.44299307177144, 55.98456213551184, 54.59941633286015, 49.88792411742672, 44.37382475022347, 50.357329845428474, 43.84001370399229, 50.861723115367276, 48.76134095653411, 51.16179620065997, 51.21541107854536, 48.05456907518449, 47.71895147139027, 44.1154739164537, 43.267312357502604, 43.81405153582173, 39.150671112921934, 41.06598015754454, 42.69288124576692, 42.86964677995251, 42.43240840973393, 44.89096180085213, 46.36248603943856, 51.44499917184153, 54.31647223810996, 53.340284516734464, 51.85861702888243, 45.14776722077401, 37.53143825838643, 39.19075381371283, 38.66274003059634, 39.66661184064804, 41.499864901265795, 49.00762265728366, 52.52454526962773, 51.83661645458591, 45.03710931347263, 42.40373196140413, 42.018876844836825, 43.69157944956134, 40.70010539024107, 39.70418422452865, 42.72133019662673, 49.87310148054554, 53.355095386505134, 58.705518168787805, 56.64839190821494, 54.16387634892618, 44.96782848911901, 43.217039339004025, 40.343444270472375, 42.880990274490856, 40.274590984467544, 40.68396483698199, 40.205368995666504, 40.497016829829064, 42.85766393907609, 43.090919448483376, 42.47384825060445, 47.98138549250942, 51.10881282437233, 51.648209325728885, 50.22328676715974, 49.98018610861994, 46.36415696913197, 44.3316278919097, 48.5326785425986, 47.356406796363096, 52.30112706461261, 54.344681924389256, 54.20275880444435, 55.946181743375725, 58.99933899602583, 50.987140901627086, 58.52185710783928, 47.34582816400836, 44.7906118823636, 61.25550593099287, 55.291600919538936, 57.02782238683393, 51.928721550972234, 44.98278056421588, 43.63868628778766, 45.59305821695636, 46.56005582501812, 46.457654506929465, 45.98261625536027, 48.535832128217145, 47.665799433185214, 49.40394286186465, 46.938466487392304, 55.482847844400716, 55.962102643905155, 53.09772122290827, 49.34922579796084, 50.71867427518291, 58.59976322420182, 62.51600273193852, 62.95153879350232, 42.17249647263558, 1.2941389699136059, 0.9100848135928955, 0.6992593780159951, 0.06114002166976852, 37.26783144858576, 74.3375910482099, 60.20318500457272, 66.1556916083059, 72.68214687224358, 65.9348621676045, 58.26777773518717, 46.92584822254796, 26.369806374272994, 47.28685532846759, 68.87991105356525, 6.686861082430809, 0.36811465517647807, 0.2935706229219514, 0.0865116126595005, 0.07194925415059251, 0.1027321378369966, 0.14529442775153345, 0.1670729591240806, 0.2110181066898569, 0.22253197918255485, 0.2585779941610752, 0.16704030845674778, 0.22055130481960314, 0.23014027415023697, 0.21032194727130477, 0.3755313055890222, 38.44069073277135, 81.40049319113456, 56.23481327487577, 47.85580296670237, 72.96273754489037, 70.57683821647399, 51.73340320587159, 80.65420735266902, 57.85311260531026, 62.48273318813693, 66.62253210621496, 72.20792447367023, 54.10218138848582, 3.0645235459650717, 0.8078788785684494, 6.018997152005473, 15.244972205931141, 1.5570320309169832, 0.25934524653900054, 21.076081452831147, 73.81597857321464, 61.9063408913151, 60.722345998210294, 55.06628820973059, 66.88234990642917, 64.16804621296545, 64.28137525435417, 56.18093559818884, 55.22293982967254, 54.03535989023025, 53.02745980601157, 49.02825432439005, 46.86459648993708, 45.36295237079744, 46.92153753772859, 44.935221825876546, 47.25292290410688, 50.41725581692111, 56.477423637144035, 54.269341038119414, 56.52779863726709, 60.48870217415595, 59.202584451244725, 56.70668225134573, 59.36051476386286, 59.106843317708666, 58.669467664534054, 57.43949082589919, 51.1776464985263, 45.813185553396906, 53.2499562540362, 45.83233064220798, 52.56716966629029, 50.64571034523749, 54.87568847594723, 52.59398691115841, 51.80970507283365, 50.92008013879099, 46.46772715353197, 43.9612227870572, 46.03444645481725, 41.95629542873752, 43.469373256929465, 44.55832519838887, 44.99856418178928, 46.26839230137487, 48.61508361754879, 49.9222291669538, 53.19568241796186, 57.19227167867846, 56.29532760189426, 54.615474516345614, 47.30921283844979, 38.06221731247441, 39.16002204341274, 38.533156687213534, 40.10709401099913, 41.55286004466396, 50.66745988784298, 55.525723272754306, 53.066707041955766, 44.26876798752816, 44.38932203477429, 42.14933879913823, 44.182342483151345, 40.438910838096376, 41.007681969673406, 42.03857106547202, 48.785796934558505, 54.58797870143768, 61.40196331085698, 59.30391103990617, 56.764388161320845, 46.396096829445135, 47.18354009812879, 43.153426339549405, 47.01877701667048, 42.33622797073857, 43.17136726071758, 40.29025693093577, 43.78261373889062, 45.325619251497336, 45.09598408975909, 45.430558343087476, 51.287908246440274, 52.71518422711281, 54.230152637727805, 51.87622062621578, 52.39216527631206, 49.22639677601476, 47.70340711839738, 49.804922842210345, 50.84504911976477, 55.50854721376973, 57.43093613655337, 58.65761426187331, 57.54140184771631, 59.48081777941797, 55.26163793379261, 54.10743344214655, 44.98335715263121, 46.096051200743645, 63.38817704108454, 58.450485660183816, 58.118433490876235, 54.28744669883482, 47.205811315967196, 45.44388263456283, 47.71528405527915, 49.00566147219751, 48.071243070787006, 47.73396238203972, 50.91462804425148, 50.238129015891786, 51.857640358709524, 47.615291072476296, 56.83958391989432, 59.89374922167871, 57.577475886191095, 52.177121331614835, 54.260480403900154, 61.604691013213134, 66.61402840768137, 66.29752451373686, 52.61354384883758, 3.600206788509123, 1.180069703728922, 1.9945372448813532, 0.18169662764956876, 41.05028283211493, 82.42831891582858, 64.59831060901766, 71.83546404684745, 78.82003645743094, 70.89500519537157, 69.29434084123181, 49.65697888405093, 36.07572117159444, 54.85890857635006, 83.04995967495827, 9.61728786268542, 0.713658705353737, 0.5941071914088342, 0.16864900116718587, 0.16892339853990465, 0.2659466261825254, 0.1470064504011985], [0.02030203670954272, 0.03986352303576085, 0.06403480746573018, 0.0921408956750266, 0.06871296167974511, 0.0490058324630222, 0.10705360917434578, 0.13446784337922452, 0.4912474769498072, 10.302560252528037, 60.58659276654644, 44.547405319829146, 35.5987766481215, 30.40253439257222, 40.11454259195636, 43.49089530206496, 67.50821113586426, 60.21738790696668, 48.89382293147426, 58.73470844761018, 59.1948809162263, 54.219381809234626, 1.707386775843559, 0.22521465055404172, 0.7005362320811518, 6.977437128943782, 0.37170822041169294, 0.27364706620574, 6.503198550593469, 63.63826344090124, 59.929289817810066, 54.34602337498819, 54.466412682687086, 59.03444813143823, 57.61426771840742, 60.255764376732614, 58.89885571695144, 53.31520880422285, 49.31774485495783, 45.4338845129936, 43.57345334945187, 42.1959561686362, 40.67446877879482, 40.030878436180856, 41.536574363708496, 43.552186258377574, 43.66629977380076, 44.863999428287634, 49.40556280074581, 52.525980857110795, 52.87807633799892, 55.62862273185484, 54.332024435843195, 54.48392998787665, 50.53459744299612, 52.87247911576302, 55.264579711421845, 51.08426663183397, 45.58121658140614, 49.08510908003777, 43.24022446909259, 45.62655918059811, 48.60799197227725, 47.50884971311016, 46.96648005516299, 45.69994672652214, 45.44670281871673, 41.98410503325924, 39.03017590122838, 39.24468640358218, 39.317611109825876, 40.30468340842955, 39.83254771078787, 40.96877205756403, 41.58301130417855, 42.29889485143846, 41.40836777225618, 46.105068729769805, 53.686096360606534, 54.89948549578267, 53.97803445016184, 42.78814385014196, 36.87893629074097, 42.09042479915004, 38.851621766244214, 40.70839335841518, 40.209765972629675, 46.72606229782105, 52.00009692099787, 47.26687477480981, 41.036099541571836, 41.935906948581824, 43.19734511836883, 44.14400523708713, 43.82899968854843, 41.27288518413421, 40.93528678340297, 45.1262608651192, 50.54210485950593, 55.061212662727606, 53.52937413800148, 52.86166906356812, 46.06784151446435, 38.34132925156624, 38.50592759347732, 38.98209156528596, 37.881611777890114, 38.51098352862943, 38.294315722680864, 38.93167734146118, 41.28925715723346, 46.41104105980166, 49.264859537924494, 45.500035285949714, 45.916288975746404, 50.15791262349775, 48.421765681236025, 47.94681372181062, 41.0126986811238, 44.06792694522489, 45.54802156263783, 50.69977629569269, 54.47599895538823, 54.234149532933394, 55.108653729961766, 55.12386860386018, 56.52307218120944, 61.175497424217966, 39.762125476714104, 36.93120187328708, 58.446045537148755, 53.47163292669482, 58.15149514905868, 48.947300526403616, 42.41698957258656, 40.70493382792319, 44.8700673349442, 40.56848241436867, 44.21587874812465, 41.480915930963334, 44.24200565584245, 44.52471833075247, 46.04431906054097, 44.63494085496472, 44.82505029247653, 43.05542592079409, 45.61655321428853, 42.21004532229516, 47.334319929922785, 47.15584424234206, 59.79751779187111, 56.184081339067035, 64.40863655459496, 31.65559045730099, 0.19428847778228023, 0.21608767820702446, 0.8409119769930841, 0.5419071247020076, 48.31379067513251, 60.40723062330677, 60.44635234340545, 71.57712890255836, 56.30917749097271, 57.57393398592549, 56.87280639525383, 32.2800043321425, 35.45478251672561, 43.98560031767815, 52.52816953966695, 0.891805342849224, 0.0643255684765116, 0.036341008625083396, 0.048950325562468464, 0.06549307115135655, 0.021475652766023434, 0.040296619352433956, 0.017761189280258074, 0.01035614797259651, 0.07596081227905328, 0.11305865065585222, 0.08274294270743286, 0.07850486004064161, 0.11709815567179073, 0.2532791938152044, 0.4530473606240365, 15.198287175547692, 71.69313692277478, 50.79601557024064, 36.32101835743074, 45.196420300391416, 56.05047364388743, 45.190983895332586, 74.95496426859211, 63.094587633686686, 55.77260509614022, 66.37962756618377, 61.09731281957319, 61.464007362242675, 2.853465709955462, 0.2668023463939467, 0.6534783926702316, 7.217588655410275, 1.3726178748953728, 0.35095355022818814, 8.593312924908055, 68.60732201606997, 59.35758475334414, 56.12159798222204, 56.653408619665335, 60.17807399072955, 60.42985093209052, 60.525250819421586, 61.919771086785104, 55.591277845444225, 52.85132185105355, 48.73803031060004, 44.28213150270524, 45.013382896300286, 43.15815671797722, 42.636375581064534, 43.063125533442346, 45.947099193449944, 45.56119680404664, 46.96075731708158, 53.182930792531664, 54.836900157313195, 54.951519658488614, 56.766721971573375, 56.48994776510424, 55.654608434246434, 51.77554515100295, 54.41646129854264, 56.96559006167997, 52.510005043398955, 47.9988714187376, 50.37096400414744, 45.49195128102457, 46.67982147585961, 50.35057944636191, 50.72997854601953, 49.32587592832504, 48.196825596594046, 48.351343447162265, 43.67218332905924, 40.924661082606164, 40.278423140125895, 39.632832388724054, 40.633099540587395, 41.1649376346219, 43.22627652075983, 44.15837287902833, 45.665571074331964, 44.6910935063516, 50.43965647297521, 55.18303755790957, 58.94918364863242, 55.81557073900777, 42.17488127370035, 36.972751540522424, 42.71170470022386, 39.08168054396106, 40.54214369866156, 39.46142481219384, 46.351719133315555, 53.220118784135394, 48.36291836154077, 42.133798368515514, 41.480684511123165, 42.20178088834209, 42.04739247598956, 42.99972434197703, 40.914890458506925, 39.550678345464895, 46.70028448104859, 52.321813644901404, 57.825820753651286, 56.19427557914488, 56.31082096407491, 49.93623987320931, 41.14745170839372, 38.40946866619972, 41.556021475022845, 40.670620933655776, 41.596441499648556, 40.03624031620641, 41.01240450336088, 42.76512345960064, 47.984421407022786, 51.156563758850105, 48.78926038742066, 47.575106390060924, 53.264531781596524, 50.38445695754021, 50.43355718735726, 42.50393282982611, 46.2483686016452, 47.71103612838253, 53.44613359820459, 56.46832373834426, 57.81825450158889, 58.49347875964258, 57.97108965535318, 55.15018378534625, 61.0804230936112, 46.401517545023275, 40.77817624615085, 59.417408743212306, 55.173408139136534, 59.732131881098596, 50.96304970402872, 46.68345751300935, 42.86579109007313, 44.85139293055381, 44.954013901372115, 46.73970822365054, 42.84035451950566, 44.76373187957272, 46.053921022722804, 48.14790579580492, 45.19684391637003, 49.48122532136979, 46.97492884051415, 48.97508267433413, 46.682716185046786, 49.32761746068155, 50.593036836193455, 61.505992412567146, 60.20023930457331, 66.93525483531337, 36.60952437308527, 0.28909660815711946, 1.5561257182590424, 0.6098765903903592, 0.8230491967931871, 54.608233821007516, 67.31646214762043, 66.0356278573313, 79.38046470765146, 63.80871003673923, 64.98418946419993, 62.65284638251028, 41.80179326764999, 30.989344504571733, 51.41356137491042, 61.709963506267925, 1.8284750008775343, 0.023267886736580444, 0.05851855306255241, 0.07130843692369039, 0.060537416908529505, 0.02289823782179625, 0.02700976276349637, 0.20378707938136595, 0.2696057379005417, 0.21653761696671286, 0.4274868063869015, 0.19526576082552635, 0.22292256144987, 0.26558956792277677, 0.3900182120982678, 0.5901396526925026, 16.486325879250806, 85.33412056584513, 59.34051459835422, 51.81075626803983, 41.08982816819222, 57.523205972486934, 54.87280945624075, 79.27192488024312, 72.51615216655117, 61.96671793537756, 67.99267092058736, 68.42946606297647, 65.0701678183771, 6.287240203349821, 0.4728720613544988, 3.4418538405049235, 16.446091186615728, 3.5858085030509583, 0.4363306786023802, 9.981713314210216, 70.28200149536133, 63.14851237881569, 58.08606609221428, 58.62383480994933, 62.92271329510597, 64.31147160068636, 61.686648937963675, 65.31442949848791, 58.50002127309, 54.0413454271132, 49.794744291613185, 48.18756880298738, 46.963848144777366, 46.32996959071006, 44.599823874811975, 45.388930228448686, 49.00362576207807, 48.98006408445297, 46.66183348624937, 55.96737430941675, 57.923891775069706, 56.36989578124016, 57.915066442181995, 57.20057533633325, 57.90703735043926, 53.38874147784326, 56.417023058860536, 60.10554936624343, 55.176220478550086, 49.77381060200353, 53.53288858167587, 47.822647171635786, 49.13966140439434, 53.82553662023237, 53.08054908629387, 51.87602450770717, 51.84445727256037, 50.62288607320478, 47.10584578975555, 43.77011314515145, 42.85138422443021, 42.65066085323211, 43.187264627025975, 43.33369847266905, 45.30690954577538, 48.19621762921734, 47.978839874267585, 47.6538283594193, 52.691285225652884, 58.86125979884979, 62.538936830336056, 58.25814439404396, 43.935346911030436, 36.95826622747606, 44.243225512966035, 38.3929515654041, 41.822554372972064, 39.59945301855765, 48.17868071217691, 53.143636488145404, 50.05221259209418, 42.4633284538023, 41.348649686382664, 43.56619304226291, 43.82568136338265, 43.04880103757305, 42.58221941609537, 40.06082573244649, 46.9334654654226, 53.45044428302396, 56.7310284030053, 60.16822884159704, 59.06610165872882, 50.32044779869818, 42.86604604413433, 41.34455865429294, 44.14669206065517, 41.19160582942348, 43.189257191073516, 42.979673185656154, 43.79756973635766, 45.525868015904585, 50.018311546694854, 54.51184549639302, 51.87354949212844, 50.95291037713328, 56.492379634611076, 52.60398895509782, 51.916209190122544, 43.869062777488466, 47.9568902907833, 49.769947067383804, 57.79600289560134, 58.497067728350245, 61.15998837255663, 59.872831221549745, 58.99048620654691, 55.34162682871665, 58.422687822772616, 44.58713892967471, 44.32235148645217, 60.20464412627682, 59.49763298034669, 63.948165985845755, 54.01345737518803, 46.490457288680545, 44.59774894099082, 47.20792939586025, 48.392955872320364, 49.780627681363015, 47.00850040681901, 47.8891235013162, 49.06709755620649, 49.099715986559474, 49.343797237642356, 50.43458877071258, 49.34289509250272, 51.727119568855535, 50.00848993178337, 51.94193993845294, 53.91100506628714, 65.38675800446542, 65.35939555014333, 70.40783897522958, 45.83420945752052, 0.24861851406674235, 1.5965567745508689, 2.5997570012846305, 0.8074175710639646, 59.76203995366251, 72.99560700693439, 72.14258563133978, 84.97381164181618, 67.70406292330834, 73.75731560491747, 68.70083916571834, 47.15731513115668, 45.66415902106993, 60.64537340594877, 75.43543108047979, 4.30930414507466, 0.28105378811878545, 0.2729853501002635, 0.1877989929409758, 0.27189321515540926, 0.08282089981460765, 0.1673078570034235], [0.06358333653019321, 0.061337162905763236, 0.05437030952664153, 0.0734559499147919, 0.06657252734106395, 0.08305635693813525, 0.10796915319177414, 0.051926462235109466, 0.18325302719829545, 2.1109730485946905, 58.300137289108775, 49.92172710357174, 47.863157410775464, 25.643934511369277, 25.48005396319974, 45.49727785971857, 60.138771841602946, 65.34807166745587, 42.41934691706012, 61.52550228180424, 53.852538216498594, 61.35772289768342, 13.017790605944972, 0.2296157643919991, 0.759239956255882, 4.047851451942998, 2.383712607045328, 0.14210980025029954, 1.6154607601704138, 53.930711054032855, 64.42455353275423, 56.89288108579574, 61.39456572071199, 56.83392786210584, 63.16954412767964, 59.446720615510024, 56.159178210842995, 52.90504263293359, 48.930402955701275, 45.7459992747153, 42.92381078966203, 41.36498635815036, 40.772763375313055, 42.34116623478551, 44.32121007673202, 42.7366078284479, 41.917597324617454, 43.228284774288056, 44.9698563544981, 45.48182764360982, 48.91998906289378, 52.08108994268602, 57.21670020011164, 55.82227014726209, 52.87618183320569, 55.536870648784024, 52.50401166177566, 53.82464231983308, 48.104281194748424, 44.09738394521898, 44.58343621223204, 41.88846195897749, 49.62467816568191, 49.46762646398237, 48.049297409672896, 44.55468916123913, 45.19163108641102, 42.98277185809228, 41.21308472848708, 41.48126502190867, 39.29095468213482, 39.472395681565814, 41.014067588313935, 41.687722898298695, 42.83283141351516, 44.980595804029896, 45.673627622665904, 47.45246171951295, 55.07624710759809, 51.52450561523438, 54.2030490598371, 43.536033938007975, 39.425723398885424, 42.4825833689782, 39.14508173542638, 38.75353897771528, 39.79818382570821, 44.1154739164537, 50.27070430017287, 46.4337751173204, 41.47687588968585, 43.39976295348137, 44.030837012875466, 42.26817484824888, 40.50036261158605, 41.527623514975275, 43.076638098685976, 41.70251023384833, 51.47632322003765, 54.80681950046171, 56.052156340691354, 51.154939897598766, 46.48331465259675, 44.06979399342691, 42.24497010630947, 38.38656202439339, 37.547013990340695, 37.65915063119704, 38.788616734166304, 38.032273938578946, 40.06101792858493, 45.169893310916045, 50.375376670591294, 47.17303206843715, 48.71533547678302, 48.06286096572877, 50.785119225901944, 46.916446301244925, 41.09179327564855, 45.78623887031309, 47.942777602903305, 52.76768515186926, 53.27022314071656, 53.3084858617475, 46.41651668856221, 59.70275725087812, 51.28991257759833, 39.743062757676654, 42.34591622506419, 56.14093526717156, 55.106119878830455, 55.85450418533818, 49.91027378266858, 44.592657704507154, 41.66856996474728, 44.838629538013095, 44.23711446023757, 43.387886016599595, 41.05558195421773, 43.4525227546692, 42.2509438760819, 42.55204069998957, 44.20065995185606, 43.55814433866932, 44.51271195565501, 43.76530039695002, 44.26580267567789, 43.60718181056362, 47.78682416485202, 50.87287441376717, 60.181274644790165, 56.53839295910251, 68.25140614663401, 16.79408092652598, 0.5684000385865089, 0.8220943448043639, 1.440287585700712, 2.7457630634307866, 58.6222658618804, 61.00141871360041, 49.774583308927475, 54.70831701832434, 54.33729217898462, 56.02422906506447, 44.22713987288937, 34.010444225803504, 33.96967511023245, 45.264649929538855, 49.0892550253099, 0.3855112861962088, 0.048858575042217016, 0.0475186757713316, 0.037990192912759325, 0.09469522433655878, 0.0070519054180852355, 0.10131194872120697, 0.013097993890574623, 0.05604081021081056, 0.036509072993912046, 0.06898103116620934, 0.012879207797889269, 0.0987914658241695, 0.08623928372417727, 0.1403310206989127, 0.28472512660007326, 3.396078064557045, 70.58751490808302, 55.06894365433724, 47.709780969927394, 29.156668032369307, 40.80680170366841, 50.23184145650556, 66.87352457354146, 71.49006797421363, 48.84129062775643, 66.02542185014295, 59.559127899908255, 69.09810466151085, 14.815611916203654, 0.2759167089337303, 0.5375529260885331, 9.598977258128505, 3.7686225771903996, 0.17915654056254895, 2.383341943064044, 59.84122476270122, 66.07045065972113, 57.99853840181905, 62.70092287371236, 59.87558080304054, 64.36449812304589, 61.180165044723026, 58.489383805182676, 56.3239844383732, 50.861934923356586, 48.772998240686235, 46.205673602319536, 42.720592791034335, 45.30345786002375, 43.44815323429723, 46.434304637293664, 44.37646058297927, 44.62339731954759, 44.96223911162346, 47.35078996227634, 48.09623249115483, 50.97304390322778, 54.82955748035062, 60.47523275498421, 58.93311762040662, 54.02654240208288, 55.56621782241329, 54.363524990697066, 56.49683152475665, 50.026513222725164, 47.63913516075381, 45.43529656625564, 43.99952473178987, 49.83325019959481, 50.24041968007242, 51.28233848079559, 47.36072924829299, 46.42064302198349, 44.72122123164516, 41.51153003015826, 43.81397308841829, 41.37798509290142, 40.90858720964001, 42.35347071001607, 45.44543981552125, 45.87644946190619, 47.72353672212171, 47.515239254120864, 49.437863519114835, 55.820548226756436, 55.347639822190814, 55.87937593460084, 44.701405417534616, 39.18046543675084, 40.610455697582616, 38.364396710549634, 38.396932771128995, 40.61969287933842, 45.91047210078086, 53.01832460588025, 47.54166426197175, 40.98089610376666, 41.923782902379195, 41.99136141807803, 42.84677543947774, 41.047086100424494, 41.38943449143441, 42.64527936135569, 41.833274210653, 52.44526632370488, 58.99158054782499, 57.9196556152836, 55.561577658499445, 48.72338810274678, 45.02325157965384, 44.29276504824239, 40.97144319165138, 41.860601363643525, 40.45964448682724, 40.31250461455315, 40.184651036416334, 41.10809856845487, 47.537345732412035, 53.65169325182515, 49.929046246313284, 49.40225232032038, 49.749817463659475, 52.75520809235112, 49.73895642065233, 43.17461498322026, 46.60332349038894, 49.66761635195825, 55.38733028596448, 57.015816011736476, 54.71813471086564, 47.39224941499772, 56.78765958355319, 56.06590424814532, 45.22553213181035, 43.069436627049605, 59.17408058720251, 57.70129726779077, 57.07524384221723, 53.674717564736646, 46.47812143448861, 43.90980443646831, 46.66923499876454, 46.798747739484234, 46.334860786314934, 44.167437476496545, 45.66172322919292, 45.54421686357068, 46.42046259295556, 46.39557123184205, 46.028284411276545, 46.445907008263376, 46.609964063090665, 47.25677074924592, 46.112199598743075, 50.7446325209833, 55.48621323800857, 61.46141467555877, 60.086035574636156, 70.27508243437737, 18.407675373938776, 0.4967984887621095, 2.485323077247989, 1.5265935803613357, 4.18665555215651, 65.34602026785574, 64.66615192351803, 59.44923877716065, 66.79506148061445, 59.90683817094373, 61.927913927262836, 52.321833256752264, 36.47855643303164, 29.384008607556744, 53.67776916873071, 54.514030256579005, 1.2148265612702216, 0.06956440712054891, 0.09730926955178862, 0.04278648554557755, 0.028149448785810705, 0.05405342874808177, 0.09342541061942616, 0.16044482769023988, 0.3322991866978907, 0.13590943699161853, 0.2069503789947879, 0.1827862957913068, 0.20266866762070887, 0.37222870054744905, 0.21368351043953052, 0.31968919560313225, 3.2813080424262635, 80.30055861319266, 63.07447371944305, 63.360159550943685, 35.00926794544343, 42.13339044201759, 59.920397804629424, 73.27476993683847, 76.42380560598066, 52.65437572233139, 71.864317001835, 65.31742226692938, 76.07673075891311, 20.171249489630423, 0.37836006992766935, 3.6698482257704583, 14.676853168395258, 6.063211089180363, 0.21116567054583182, 2.8878450393676762, 62.57162978572231, 67.50889362827425, 60.77536075345932, 65.88025493006553, 61.27104636161559, 67.128706132212, 63.2693527590844, 62.25054848578669, 57.343949733241914, 52.945192014017415, 51.552150480208866, 49.08848231838596, 46.31269547247118, 46.3125228881836, 45.669936672333755, 47.85792104659542, 45.87984231210525, 46.1726237112476, 49.021358797627116, 49.78555417829945, 49.330374886912686, 53.993041438441125, 56.86910760018134, 62.08930377037295, 59.90400229730914, 56.00595474243165, 59.20409456376107, 55.00094544502997, 58.603701283854825, 52.98914609416839, 48.877592163701216, 48.91871821495795, 46.64014277919647, 54.41343715113979, 53.745210401473514, 53.54966848127304, 50.371968130911554, 51.51369556303948, 48.62926298572172, 44.13330501125705, 46.07900065760459, 44.583510737265314, 43.800233025704664, 44.19456458860829, 47.188949046596406, 49.3272134565538, 53.00050527818742, 51.24174587188229, 52.5501230455214, 57.85773707974342, 56.04666894482028, 59.001547290432846, 45.96455766308693, 39.056804872328236, 42.44624653170186, 38.60779546922253, 37.25686057921379, 38.86799373934346, 48.10320254295103, 55.215832494920306, 47.76200732877178, 41.831826856059415, 42.417730900549124, 42.884700836673865, 42.65490878012873, 41.03502481214462, 40.99215722853138, 43.2166039559149, 40.82338548475697, 54.951213713615175, 60.330783628648334, 62.19709050270819, 57.63842167392854, 53.133724658719956, 48.406342921718476, 47.80857370745751, 44.26531630177652, 43.53072697116483, 41.27266160903439, 43.29269401488766, 42.8438336618485, 42.80639463855375, 50.445689078300234, 57.117311262315326, 52.07804226106214, 52.35511849003454, 52.25633359724476, 55.18080572928152, 50.86303318700483, 45.98436563245712, 51.52493315358316, 53.56481275250835, 59.509709958107244, 58.2184813868615, 57.33874474802325, 47.87756819878855, 58.058213341620664, 54.92715389497819, 49.82639781890377, 49.426896572113044, 60.01689203323857, 59.40763811911307, 60.360354377377426, 56.11445142376808, 50.46940372836206, 46.13173692457138, 50.64820889503726, 50.20237268940095, 49.196469091599994, 46.3537666105455, 49.54071983214348, 47.30833030516102, 48.90748846915461, 49.308017376930486, 49.13029478442285, 47.773229229834776, 49.096185853404386, 49.07672697497953, 48.720975845090805, 54.32583101334111, 57.94659445362707, 66.50671235976681, 65.3100246767844, 75.2240074834516, 22.981359035738055, 0.6548156757508555, 6.269593459944572, 3.315252724193758, 4.437096436177531, 70.07593585598853, 71.26838345681468, 61.72753964701007, 68.03747223269555, 67.62374062691966, 64.55787097254108, 58.688557840162716, 48.72153674402545, 46.79252686039094, 63.566193811355106, 70.27938135208623, 3.219335819444349, 0.3678312026444943, 0.36746476746855244, 0.12795083299880067, 0.29618718090557283, 0.16304759609122432, 0.17837847102313273], [0.07475449192908502, 0.014149510853683517, 0.05981169032653975, 0.05195534374985484, 0.05078208009381929, 0.04985838873131622, 0.028639710583393613, 0.036341870473998214, 0.0435076653957367, 0.019239273575705387, 35.91068352422407, 56.22579182347944, 40.71866604589647, 38.77696729475452, 30.371400579329464, 47.830727254190755, 62.63568209063623, 67.14339148613715, 57.64814130721554, 63.77018059453657, 53.756444069647024, 61.25384676840998, 37.065064522527884, 0.19359222643317717, 0.9786183651416533, 3.808135798861904, 0.24369485165563323, 0.0936138759096784, 1.1496323563398854, 43.05161729935677, 67.66099529881632, 56.796873231087964, 60.76570387809508, 58.821220244130785, 61.89907666175597, 58.554263730202955, 57.57761316914713, 53.34310077851819, 48.54453978999969, 45.25758574085851, 42.282593481002316, 41.77436805540516, 41.865202303855654, 41.233226099321925, 40.44448060374106, 40.211425135212565, 41.08847495048277, 41.613233166356245, 43.071197771256976, 44.908918411501, 46.72437960101713, 50.03055326400265, 54.356660842895515, 53.16835134260116, 54.895665107234834, 53.233203811030236, 54.6846612038151, 54.01267290115357, 50.86193100098641, 47.15504800119708, 43.858456688542525, 41.542744251989554, 49.00590858151836, 49.3710930116715, 46.35620632479268, 46.4185877000132, 45.86849881756691, 41.734089236105646, 41.993757986253314, 39.34577765003328, 39.45518824361986, 40.42141706712785, 40.91776947821341, 40.56486598906979, 42.879033011774865, 48.00657495375603, 49.68948356566891, 49.670950366604714, 56.527590751647956, 55.17358856816446, 55.57393312454224, 46.20570498128092, 39.19373481504379, 40.32229092813308, 39.26741261636057, 38.769146088630926, 38.289083280871, 45.02599723877446, 53.84685470211891, 45.21959366336946, 39.830774799469985, 40.74220026693037, 40.993118209223596, 42.30078935623169, 41.26916285484068, 42.63704238399383, 41.94795254738101, 43.242405306908395, 51.96066533365558, 54.2800687205407, 56.65719370688162, 50.75721548449609, 46.190395970498365, 46.16821496717392, 45.324089527130134, 40.5044928673775, 38.70510162845735, 38.196272157853656, 37.96407176602272, 34.62510708839663, 40.00173914817072, 40.42336256273332, 47.7831292921497, 49.04592460201633, 48.333108348231164, 48.23181706090128, 47.923844322081536, 44.85915530112482, 41.30854737374091, 46.870330995129, 48.65673134403844, 54.909244352771395, 52.26820661175636, 48.41139885687059, 38.98919497766803, 47.76393321252639, 45.29409516242243, 50.070871307003884, 57.65127135861305, 52.887925409501605, 51.747300163392104, 44.63289730010494, 41.4922555031315, 41.23450086962792, 40.64394489411385, 42.620364466021144, 41.110142123314645, 39.677669002163796, 41.44580287318076, 40.798254859062936, 42.161808013916016, 42.156293161453746, 41.313724902368364, 42.51709630412441, 45.24212375763924, 43.87480120505057, 45.53107692349342, 46.88461234492641, 52.32230786354312, 56.12893281444427, 62.51823456056657, 57.372724240826024, 63.382438613522446, 5.817647672468617, 0.04081283237845187, 3.702967738912952, 1.6316368599091808, 12.562534828339855, 62.01811667411559, 60.065196021910644, 44.46557291092412, 49.06643467564737, 63.06988454634144, 59.4361537502658, 43.04466685941143, 31.347796186324093, 32.52721955699305, 47.409433318722634, 42.74141273190899, 0.26458020111726177, 0.0780176587643162, 0.03591646184964526, 0.11106086188867209, 0.06544554305653419, 0.11676476952890236, 0.02381978222289153, 0.01879973829002871, 0.021974900774958155, 0.06688781848718083, 0.12994089193882483, 0.04532117937361041, 0.0420798039093854, 0.035059458440950805, 0.04416616393193122, 0.05748334611135145, 0.04096061073904557, 45.596223569685414, 64.4413451994619, 43.87647605711415, 38.513866470706084, 39.32166684058405, 53.037116681375814, 70.05632400512695, 73.38946788541733, 54.6586755014235, 69.41276504147437, 60.17688159019717, 67.67306050946637, 42.85826013934228, 0.12322995406124862, 0.9229052643622122, 6.534132813253711, 5.533958817681959, 0.395391614086205, 1.001814649470391, 48.954721650769635, 67.79451277948195, 58.6906563082049, 60.763330844140825, 59.64969150481686, 62.26672041800715, 60.58043072300573, 57.74971892756801, 58.05197677304668, 49.09085535234021, 48.24454907448062, 44.30233563146284, 45.38556483484084, 42.90090022548553, 43.83477341744208, 42.136402822309925, 43.001352125598544, 42.19303008048765, 44.55970195031936, 43.912028420356016, 46.498251038212935, 48.01862055255521, 52.64478160488991, 55.457779976629446, 55.55115984332178, 55.97471306400915, 56.658790111541755, 56.13718155891665, 55.95330084523847, 52.1905868284164, 47.81997211517827, 44.01282156667402, 43.00840454716837, 51.41837412311185, 51.66220042013353, 48.15508765559043, 47.2711697701485, 47.683963929453206, 43.69114406647221, 44.3621321647398, 41.92040181929066, 40.493270966314505, 42.01669600702102, 41.5112554642462, 43.29254104245094, 46.52976336017732, 50.00980784816127, 51.53834765957248, 51.88466156682661, 58.973757297761985, 56.06048745493735, 57.928210304629424, 45.833013134617964, 38.913395174088016, 39.095601035702614, 38.37720717153242, 39.70471766687209, 38.14812898635864, 45.61883211135865, 56.78762035985147, 47.18596412289528, 40.76175720460954, 41.88208810744747, 40.67225263964745, 41.54538400711552, 41.76467587870937, 40.74645603856733, 42.88661495331795, 42.71880026786558, 53.19292106936055, 57.463644781420314, 57.52407281629501, 53.9908919795867, 49.771053175772394, 47.56800297767886, 47.03436843810543, 42.05238565321892, 40.59999865870322, 40.69490432739258, 40.97560482640421, 37.86876601557578, 41.42670485281175, 41.90251973367507, 50.942037567015625, 51.53249940564556, 52.19978870884065, 50.57342106296171, 50.687703240302305, 48.599743227804865, 42.05697090395036, 48.03656931846373, 50.07310705800211, 57.306742129787324, 54.375241110401774, 49.599939777005105, 40.20181925066056, 49.99729940968175, 48.61435797906692, 52.08786387597361, 59.591252111619525, 55.701292484037346, 54.4882445950662, 47.619303657162575, 44.545287239936094, 45.20671652209374, 42.56235653354276, 45.22056641117219, 43.65097115116735, 42.3468928952371, 43.36215134589903, 42.05151488704067, 44.18329561910322, 44.750023195820475, 45.21516530744491, 46.53573320757958, 48.06012707371866, 47.29753202007663, 48.94831249790807, 47.55916587768063, 54.45502211970668, 59.95895470342329, 67.55271434783936, 61.210849746581054, 67.66774962025305, 5.754172936562569, 0.07318438706739296, 7.8409557477120435, 1.7992964891656753, 16.548944557866744, 67.19193473938974, 68.377988876835, 48.56963903673234, 49.700489736372425, 68.3017615349062, 59.761847757524066, 50.50446971770256, 38.32626735010455, 31.860424472439675, 55.3374259702621, 51.14883668961064, 0.5862927881460036, 0.04282353738803537, 0.08623703142567989, 0.04622992819115039, 0.04542491916987685, 0.029706346291688182, 0.03934176736361077, 0.2531890712317921, 0.10300136411622648, 0.13987590318485615, 0.2470101737567494, 0.1560873808639665, 0.15819407669046234, 0.10427131572918547, 0.196355857976502, 0.1201050354528331, 0.1221678191195092, 51.6951600966915, 75.13161213167253, 54.170501232147224, 50.266440683795565, 45.375629471194365, 60.22589552787043, 72.84094010629963, 81.96605190154045, 66.63128683643957, 75.45409371775966, 63.71001143609325, 72.95952904608943, 48.93545104611305, 0.4884230946340869, 3.2245449721813206, 13.857543583839172, 5.432548388358086, 0.49694661952314845, 2.135735461788793, 52.01651988490936, 70.51244858772525, 62.01099757225283, 62.29564789802798, 63.7101447966791, 64.96304788897115, 63.09096728601764, 61.01290733583512, 61.204789684664824, 52.993648975126206, 49.96052326694612, 46.63951127759872, 47.640127520407404, 46.001898627127375, 45.33356205109627, 45.317029260819965, 45.967813230329945, 44.814361833756976, 46.307204154229936, 48.45467044461159, 49.32653488651399, 49.44291945426695, 55.73666834062146, 59.03571505700389, 57.94817124643634, 57.46932437342983, 58.98353968897174, 59.23080198226437, 57.89869839145292, 54.62120117679719, 50.96656414770311, 47.17579341703846, 45.36558428118306, 53.625833065279075, 53.492197913508264, 51.66788785688339, 49.55123962894563, 50.10872217916673, 45.891009299985825, 45.58045564159271, 44.51215105672037, 41.93778576389436, 46.421835422515876, 44.74282956892445, 47.18077874952748, 47.90496595444218, 51.51167554240073, 55.30821215721869, 54.14367222016858, 63.09746273102299, 58.55124350517028, 62.91528824836978, 47.415669887296616, 38.48438201412078, 40.469599462324574, 38.25268760804207, 39.17303254527431, 37.438489852413056, 46.47570133209229, 59.450293894737, 50.087055006334865, 39.30353372327743, 41.055303465935495, 40.60783947667768, 42.35105060761975, 41.36664159836308, 40.87677678754253, 43.01138162612916, 43.01424887872512, 56.024731128446525, 60.120501441340295, 61.776608497865745, 56.83968982388897, 52.264401912689216, 50.57475859119047, 50.542457872821444, 47.390511805011386, 43.74436278497019, 42.92644270004765, 43.69376420974732, 39.13510322570801, 43.68953197233139, 44.09207305600567, 54.34779628630608, 55.608681401898785, 55.16193520638251, 53.30721893618184, 53.03560656885947, 50.44072335766208, 44.644146657759144, 52.84400270831201, 53.08673858642579, 59.37219950460619, 54.75051779900828, 52.75243889900946, 41.25711333367133, 56.03228953576858, 54.20401396289949, 57.32216488930487, 60.82950907368814, 58.562053557365175, 55.90085091129426, 49.675920009613044, 46.529096557248025, 48.446617818647816, 43.7389067680605, 48.186258731349824, 45.975673660155266, 46.169693700728885, 46.86236073893886, 44.44532955846479, 45.66768130948467, 47.206776219029585, 44.92443138553251, 48.49031302236742, 51.389007337631725, 50.25798013133388, 51.110213110523844, 52.18027883960355, 57.20689035231068, 62.2028838434527, 70.71108525799167, 64.01735267331524, 72.62243270874023, 8.00639396713626, 0.13796812974877898, 13.077173329168751, 2.9369889055528953, 18.340469483406313, 75.51456882107642, 75.08066838787448, 56.87282992947487, 60.83420807315458, 74.4831423605642, 68.69300227011405, 55.9641501211351, 48.94046383519327, 47.42810772311303, 65.29143656453779, 61.05082096592073, 1.1109310652940505, 0.19718861087195336, 0.18573372714942504, 0.15688135438869077, 0.15184477061754273, 0.22217332745992371, 0.1612100269525282], [0.10773631608894757, 0.07127378676687518, 0.057107913232738935, 0.02010207626998665, 0.05576949634198701, 0.048698991266710144, 0.05727762852104441, 0.16875484387480444, 0.22299540108971058, 0.5206691449688328, 13.074239396279859, 66.01655729355352, 47.166717052459724, 41.122693707866055, 32.78476042132224, 38.331805736787864, 42.63480663299561, 60.51909269825105, 65.50806514678463, 59.23762298399403, 55.90271403712612, 52.99901869989211, 61.20255001129643, 6.2218900842051355, 0.6838125326941091, 4.119954176487462, 7.608144446726769, 0.2560115842929771, 0.34189658299569164, 29.928982719298336, 58.905013838121974, 59.21556749651509, 58.024304451480994, 65.27924583804223, 57.706392426644605, 58.94670863305369, 55.33668071992936, 50.920162508564616, 45.82865145898635, 44.10566406865274, 39.66462712134085, 43.33969185429235, 41.527674505787516, 41.84752418148903, 41.338628030592396, 42.67865088678176, 38.170247231760335, 40.329272747039795, 40.17401749087919, 42.9312240692877, 43.48851834574054, 46.93750550670009, 47.67250668617987, 48.503343136079856, 51.64486746634207, 52.30629674849972, 51.48661159699964, 51.23761561609084, 50.07606060274186, 49.07555418629801, 46.02035337878812, 41.01592286940544, 46.77795133283062, 47.79228018176171, 47.14257486404912, 46.87853659352949, 44.67702788691367, 43.89381293327578, 41.12374882544241, 40.04998430129021, 40.39322307032924, 42.96486623825566, 41.20902507535873, 44.15528989607289, 45.812314787218654, 49.85110875098936, 47.39485386879214, 53.41908493349629, 53.91440576122653, 54.159232262642156, 55.18144899798978, 51.830964319167606, 40.231374309908965, 38.805604519382605, 38.10008387411795, 40.176574876231534, 39.57649146356891, 42.43986091306133, 51.18386345524942, 46.29639410203504, 42.05386438677388, 41.330285149235884, 41.28852759638141, 40.085469984239154, 39.02038566527828, 40.5136594464702, 40.81372076465238, 43.33119992286929, 52.448180644742905, 54.93929755303168, 54.24534005503501, 53.387203908735714, 47.37810927052652, 45.625974747442434, 49.96197846628005, 43.77769116432437, 38.28519621203023, 37.863674779092115, 37.44031767691336, 38.93336396063528, 38.71047919796359, 37.49543874494491, 41.01373810921946, 44.61698032194569, 49.06594045700566, 48.5928241668209, 50.08694517997004, 43.11239834754698, 42.357930444901996, 46.03538782365861, 49.50856031910066, 55.12901475352626, 51.73054772038614, 50.49672695898241, 58.147278601123446, 53.867509903446326, 55.48178488208402, 56.7863416671753, 50.36975983650454, 50.313791536515765, 44.07529707877867, 40.19767330538842, 39.94165235950101, 41.56735712482084, 40.23137038753879, 42.080901284371656, 44.80867047463694, 49.02129996207453, 48.03319215774537, 48.093424074111454, 45.40127392738096, 44.58474628386959, 41.05792753158077, 42.593409938196984, 42.31235642586985, 44.44474512530912, 43.47097358395977, 49.69937186087332, 55.31457816400836, 58.2049648992477, 60.044658491688395, 63.01451636898903, 44.6903992468311, 0.2661646854492926, 0.04508710120834651, 2.0440161059941016, 0.5230853862820134, 26.0100563879936, 65.73307583408972, 51.49346397769067, 65.1247868230266, 63.72268853649017, 65.59813061068135, 63.05548160306869, 44.21643572468912, 21.830688599617254, 20.34904660717134, 56.09027393402592, 27.745903268937145, 0.10305697443865, 0.06712262443597279, 0.1386768683310478, 0.046333514769831975, 0.0522154382610273, 0.062492756743825255, 0.028746941825374964, 0.18084581040086287, 0.044718306481597886, 0.10011200988364798, 0.12276045707685333, 0.06884413891501966, 0.026577286978041934, 0.10578901251597751, 0.26783497162884284, 0.16782994592382064, 0.5587189548438596, 17.828286386305287, 74.14393578806232, 52.81680499353717, 40.11153805640436, 46.51511330758372, 47.743634946884654, 51.83691455471901, 69.6531435751146, 67.41935376198062, 64.55471346455236, 62.58075321874311, 59.94779556028305, 67.1528208640314, 6.393859540262531, 0.43000205690341614, 3.7088880663917916, 7.787449715598938, 0.7298811380901645, 0.1527537339397015, 35.58920214253087, 58.71723428849251, 61.75417646285027, 59.18308242674797, 65.71194602597144, 61.26953624909925, 61.847062110900886, 59.09236584940265, 55.979698396498165, 49.62927518352386, 48.177802101258315, 41.689668393904164, 46.76421911485734, 44.69314098358155, 43.58223945863786, 43.185177926094305, 42.84238238488474, 41.016260193240264, 42.70284014363443, 42.82496313894949, 43.52270180179227, 45.14384092823152, 47.340485895833666, 50.63939925163023, 50.7505552999435, 53.35526012605237, 54.773608792212706, 52.3744636197244, 51.86408481290264, 52.0100950425671, 51.83111336923415, 48.447186562322806, 43.57723059192781, 49.249130833533506, 51.02726674848988, 50.94462240895918, 50.57673546575731, 44.37905719203334, 45.819465268042784, 43.525427849062034, 41.28600943473078, 42.82766565199822, 44.99016638725035, 43.73585908643661, 46.642354995973655, 48.34181208764353, 51.33654563657699, 50.34703754609632, 54.91820696861514, 57.26363920396375, 55.86031321556338, 58.07895875746205, 52.4122085878926, 39.86182428175404, 37.67839377926242, 37.172741428498306, 40.316238710957194, 38.118707287696104, 42.7568119572055, 51.95127125709288, 48.32218062493109, 41.381075920597205, 41.4303958031439, 40.809680723374896, 39.65191471961237, 39.47875776598531, 39.24597686336887, 42.688080264676, 41.74754688816686, 55.40928379181893, 57.41903174308039, 56.17059230804444, 54.74721908569337, 50.389226559669744, 49.10430515966108, 50.6986427307129, 46.359654088174146, 40.85823574373799, 40.49083909680767, 39.66450945023568, 40.92536710923718, 40.69997987439556, 39.308483754434896, 43.850043204522905, 47.65081990149714, 51.89814275310886, 50.74376959954539, 49.90530806203043, 45.67633013571463, 45.238409273086056, 47.36337292578913, 51.25787073566068, 56.923769750902736, 54.125927417509025, 50.28087500602969, 57.81876440971129, 55.67105493237896, 58.01564778051069, 59.497405482876694, 51.61734419484293, 51.55579828446912, 46.06664126919162, 43.45828079408215, 42.0819289453568, 43.57464182761408, 41.16778919773717, 43.86964328827397, 47.12322188961891, 52.16074151377524, 49.37407793537263, 51.400633242822465, 47.516008038674634, 48.08432809768185, 43.11661881785239, 44.26812079644973, 44.511927481620546, 45.614905818816155, 47.07194474435622, 52.2289829100332, 58.980907778586115, 61.53825782960462, 63.642625116532855, 66.69958314587994, 47.272440618084325, 0.29015898824699465, 0.2932419405589181, 1.73788124274823, 0.18261513642726407, 29.615134269960468, 72.35127925872803, 56.890186417487364, 67.86163237787062, 64.92711505582257, 73.39050339114281, 65.69587999774565, 55.62636736900576, 23.793393604217037, 20.394942260557606, 66.04185658116495, 34.45295818390385, 0.18758410527821512, 0.03293544902736622, 0.012654665512062851, 0.07239344725084883, 0.0976356766336868, 0.010260288348241199, 0.0514375679044714, 0.30920990953041666, 0.20153985238604008, 0.2132399608531306, 0.25261286586042375, 0.18688155668637446, 0.11964122284083598, 0.2859324198817053, 0.3953604802729622, 0.44877948479787, 0.7324875530696685, 20.91952593095841, 87.2286645827755, 62.45963042782199, 50.88366093174104, 43.32715595922163, 57.97313321021296, 60.52440750983454, 71.2139174246019, 77.57969671680083, 68.5430500584264, 68.50794484538417, 65.55501591774726, 75.25971674150037, 8.11311528567345, 1.5858398786475583, 15.114883857388651, 15.71842581995072, 0.5245831801045326, 0.5205906975653865, 40.29535208978961, 59.632436998428844, 65.40899784334245, 61.36250426692348, 69.37527502736738, 62.870169224277625, 64.05234805999264, 61.03714366112987, 57.69292692984305, 50.97111017473283, 49.54965499139602, 43.866764268567486, 48.288816944245376, 47.1385387451418, 45.78654481518654, 46.706289629782404, 45.3885458361718, 41.628459807365175, 43.435503590491514, 44.62643715643114, 46.53130092928487, 47.783639200272106, 50.16510625039378, 52.58100386588804, 52.721499243090236, 55.668740733977295, 59.417251848405414, 55.92574227240778, 53.87933584951586, 52.89881390909995, 55.63421603172056, 52.11221787237352, 46.34213678298458, 51.146973563778786, 53.6514461425043, 53.1813814563136, 54.09625860952563, 46.48927665525868, 48.24928729764877, 45.58742177101874, 42.66235736108596, 43.674309253692634, 48.217151318826986, 46.90478117235246, 50.93867609577795, 52.65172812246507, 54.20539463720014, 52.405787667920514, 58.27982333398635, 61.104949674298695, 60.26884548125729, 60.97694312372516, 54.65429029157085, 40.34844921481225, 38.771393606739665, 37.12151135167768, 39.114157768987845, 37.57097967209355, 43.71276809323219, 58.42879887550109, 51.71050833117578, 42.50591754913331, 40.651385630330736, 41.36062076014858, 40.22981712895055, 39.78937810467136, 40.38233457073089, 42.571695696923044, 43.02473337419572, 57.98530040248748, 59.36074226133285, 57.47541581430743, 58.896635655433904, 52.49055008734427, 50.88072699885215, 54.75281630792926, 49.06054327564855, 42.825567183956025, 43.6156423630253, 41.99473073405605, 45.45773252364128, 43.51523753135435, 41.89393366536787, 46.62920721115605, 49.64973426634266, 56.16024901790004, 53.58708789271694, 53.42812991911366, 47.615220469813195, 47.58589290803479, 51.153198365242254, 54.06090628716254, 58.19641805464222, 56.30746733757758, 51.97700200542327, 60.43401648921352, 58.6578849054152, 58.12369731164748, 61.71157560040874, 53.24445709105461, 54.14446846131356, 47.881341518894324, 45.22825817908011, 44.18334660991546, 47.165826674430605, 43.09157056193198, 45.68482206713769, 49.495408611912886, 55.84321168161208, 52.95912035049931, 53.96310983165618, 48.62451299544304, 50.91926036342498, 45.265308887727805, 46.94754677434122, 46.83134263561618, 48.15417374334028, 48.44514300746303, 54.47090379653439, 60.305907957015506, 63.69998978030298, 68.65673603550081, 67.45815384772517, 53.064337930371686, 0.7726768932996259, 0.49342920342760704, 7.888151176514165, 0.7274140898258455, 37.110454190161924, 77.6815842043969, 63.416276900999016, 77.02375565805744, 72.63434102458339, 78.68062757676648, 75.5144589947116, 60.844841618691724, 35.33800963432559, 31.96188246050189, 72.96093325461112, 46.102417207533314, 0.40093824387558047, 0.18490279754323347, 0.23341995784111563, 0.12953584593149925, 0.221496933109818, 0.2000515886972989, 0.19354878924787047], [0.10903556290413104, 0.04141871216556719, 0.07007901902280508, 0.13089120868713627, 0.034385822007372495, 0.061020247653246894, 0.08646925565816703, 0.10004537555599406, 0.08192613210168578, 0.1895847132489566, 2.0781938010646455, 55.61663989097842, 44.67657681434385, 38.23787673827141, 31.81364824694972, 38.60082541742633, 40.056467979185044, 55.320006724326845, 60.44337134207449, 54.95918789217549, 60.05837502018098, 55.6060730257342, 64.05219116518575, 27.945334219163467, 0.31536511956684055, 1.7152774814636478, 5.677645043019326, 1.4516689556260265, 0.18654823183052002, 7.050000977131629, 50.423739494815955, 56.48018498574534, 58.04755233949231, 61.7098811364943, 56.21169090270997, 58.6076158092868, 52.92063013199837, 49.35170473590974, 45.22029184526013, 43.430067185432684, 42.25988688007478, 42.19352822149954, 41.653366857959384, 44.51310419267224, 44.91916756476126, 45.872680064170595, 42.076390558673495, 41.772920700811575, 39.973811872543834, 42.64969987253989, 42.852215766906745, 42.839401383553785, 43.057900936372825, 46.309522275001775, 44.5498764130377, 49.501150961845156, 49.1533818552571, 49.28708368732084, 48.36258496007612, 46.796374705529985, 44.21358416157384, 41.875769169099875, 45.293714692515714, 51.11904236578172, 45.22823856722924, 47.95047329318139, 45.223484654580396, 42.78078940606887, 41.28043966908609, 41.6506290435791, 39.76555362824471, 39.7269182820474, 43.62742908539311, 45.02490289749638, 48.54179020850889, 50.72060408130769, 51.707703836502574, 52.2501362523725, 53.74994077990132, 56.82014073095014, 54.283567474734404, 53.06889180214175, 43.18231067349834, 38.4658331255759, 39.878804222229995, 38.47326993942261, 40.791480925775346, 40.355156467806914, 49.695084710274976, 47.69590754662791, 41.344903822868105, 42.85939370432208, 42.657681895840554, 41.797274697211485, 40.00873273418796, 41.3548078075532, 40.36666470189249, 42.29921648579259, 51.18137275019, 55.92852715523013, 55.66308075381864, 53.67418804476338, 48.899914372351866, 47.719708488833525, 46.53949868294501, 49.654668608019435, 46.766886326574514, 40.707746167336744, 36.089347485573064, 37.822434979100386, 37.44739755507439, 38.656452471210116, 37.54391924027474, 43.879139346461145, 46.11489818942162, 46.51599191850232, 46.03518778277982, 41.979692366815385, 42.66829975189702, 45.4063416296436, 48.61787634511148, 54.487660161910526, 51.4748562535932, 52.46392896098476, 52.719502756672526, 53.08061184421663, 49.548219403912945, 47.66746644050845, 46.82016388062508, 41.757623457139545, 42.4692080866906, 41.67543411254883, 39.794390893751576, 40.98272392826696, 41.16770290559338, 51.768445660991055, 52.99901869989211, 53.671010924923806, 53.52414954093195, 53.60744107154108, 54.41776744781002, 55.55012433759628, 48.37208494063347, 42.39725220587946, 41.545258491270005, 44.87579007302561, 43.100584168587964, 54.140298981820386, 55.06247174355292, 62.3060578684653, 59.174060975351644, 62.042929587825654, 21.61603493075217, 0.10083317441204864, 0.2593624988390554, 1.2060611671017063, 0.07543143020161698, 40.38022041320801, 58.42398220492948, 55.28879250249555, 58.90440194837509, 57.009112681111986, 62.970311257147024, 61.162926227815696, 36.11284640527541, 45.45701080752958, 42.37260403171663, 51.5549785091031, 22.010239016625192, 0.2504761393872961, 0.22481959433324877, 0.11045631892498463, 0.031791045818658124, 0.08527141590152057, 0.03630843456654299, 0.04381833703167016, 0.1161065697669983, 0.016031246876434212, 0.04602192382838938, 0.03893234699423756, 0.040280883906469236, 0.019362675018548485, 0.134048885215194, 0.0590575457129988, 0.07358359548473552, 0.3273904630013051, 3.8202676898048775, 66.53119579438241, 51.10703991305444, 39.51753039513865, 36.68296290982154, 46.79789266278667, 48.59590714977634, 64.51452485976681, 66.40335790572628, 62.1181018121781, 64.8189909996525, 60.67986280687394, 69.43924104013752, 29.93737266909692, 0.50761767272507, 0.33829590846453944, 9.195949800552862, 2.7725315238198927, 0.2958958836332444, 10.669115551056402, 53.156576387343875, 57.07690300480012, 61.83995869851882, 62.23423534824003, 59.41920518875123, 61.79755395458591, 54.02636589542512, 50.75854516798451, 49.12920828788511, 45.24406925324471, 43.066871396956905, 44.52622059852847, 43.11802694874425, 46.37786173051404, 45.51640725904896, 46.520914493068574, 44.83955129500359, 44.75551059169155, 42.808806896209724, 45.13936158149473, 44.430546145285334, 45.80550947496968, 45.33211469650269, 48.45276417270784, 46.94458538486112, 51.358754096492646, 50.8465592322811, 52.01337414403116, 49.33458751247775, 47.868276103850334, 45.95177073632517, 44.13876495053692, 46.97483078125985, 52.17158294493153, 48.0496935690603, 49.597782473410334, 47.571486042391875, 46.86216069806007, 44.304073241449174, 43.03133472319573, 41.27908645137664, 41.511047578627064, 45.32493283671718, 47.562986266228464, 49.95237650409822, 53.34569346520209, 54.35289536753009, 55.3221522608111, 56.03653354029502, 60.36712831066501, 57.537381418289684, 54.938269892046534, 43.92475258919501, 39.76021920481036, 38.77464525161251, 37.786976752742646, 39.505253376499304, 41.13072279960879, 52.750454179702274, 48.32127847979146, 40.49651868881718, 41.354713670669064, 42.05695521446967, 40.87706704293528, 39.04877185821533, 41.00047265329669, 39.401828319795676, 42.8285324958063, 53.47665748288555, 57.679096652615456, 56.611086245506044, 56.87464990923482, 52.42454444208453, 50.037440946025235, 50.307449063947125, 51.51124800405195, 48.067002988630726, 43.11222968562957, 39.27489257627918, 39.30725213020079, 39.690134294571415, 39.5337886195029, 40.945108398314446, 44.77397711046281, 47.951238155365, 50.61415879957138, 47.23730402608072, 43.91686470277848, 44.10021589648339, 46.655851871736594, 50.861170061172984, 54.73922529528218, 54.47385341890397, 55.43192763482371, 52.94534890882431, 55.24007274258522, 52.459253495739354, 48.38023170348137, 49.35073983284735, 44.700891587042044, 45.10216182278049, 43.98699275908932, 39.94887736535842, 42.87789944679507, 44.118713794216035, 53.193783990798465, 57.26836958239156, 57.09556956445017, 57.314881047894886, 56.77716724334225, 56.33276662518902, 56.978184792303274, 52.47575098468412, 45.145445177632, 45.3372137777267, 48.11332225799561, 45.69950349869267, 56.41341055593183, 59.134531328755045, 64.58315457067182, 62.770474341607866, 63.2449830732038, 26.083906773597967, 0.14862997457385063, 0.711899706192555, 1.8085154073853649, 0.07545936942821549, 46.72182221566477, 64.53484665962958, 60.02247356599378, 67.73450836058586, 63.864694026208696, 71.70250354274627, 65.31382545348137, 52.13398702682988, 45.84562355472196, 38.23181275398501, 61.983752789035925, 25.041876185324885, 0.33547805321793406, 0.1718480770866717, 0.05751235786104395, 0.10881806288154856, 0.0592620222408685, 0.09101873774441982, 0.037997758031011596, 0.16023992981401183, 0.14846497455671911, 0.17313933360480493, 0.2869885793376354, 0.11723817356171147, 0.16372365336264336, 0.32814113723654903, 0.1870293044034512, 0.17129588091085035, 0.4527499959353478, 3.7187655750782262, 76.87923985142862, 59.277670383453376, 49.22282349678778, 42.89406745664535, 55.9866645259242, 51.498774866903986, 67.60547807139736, 72.88011673958071, 66.84650728779455, 69.6558500105335, 66.88457781268706, 75.74674175631615, 34.841857264118815, 0.5281397279712462, 10.961771434353246, 17.865133131704024, 4.515100121498108, 0.30654413805853936, 17.215569019317627, 55.75940632051038, 59.63428443478, 64.15088584346157, 65.31465307358773, 61.31714990062099, 63.9482444332492, 55.873284493723226, 53.45924608169064, 50.9103879620952, 49.21731648906585, 45.351620643369614, 46.98775499097763, 45.53242229646253, 50.43000351998114, 47.9708460838564, 49.783851869644664, 48.11152581245669, 47.53894605944234, 44.8183822631836, 48.01261148145122, 48.28028578912058, 46.83002864160846, 47.56165658274005, 51.01187929030388, 48.65543696188158, 55.16278243833973, 52.47836720558905, 53.075461772180375, 52.18377759379726, 49.85638433887113, 47.962565960422644, 45.35516254363522, 49.98776020542268, 57.23099331701956, 51.255654596513324, 52.0464083456224, 49.99001164590159, 48.1310905948762, 46.96874326275241, 47.50809661803707, 44.66212288025887, 44.21426665398383, 49.52964698114703, 50.03780180408109, 53.447071044675766, 57.01775758497177, 57.99948761540075, 55.95915694390574, 59.24787213725429, 63.05826648589104, 60.61804233058807, 56.95226969257478, 44.55348107122606, 38.98122079910771, 38.66866280955654, 38.34967997766311, 40.91673789485809, 40.753186825783025, 57.51635751416607, 50.80074202629828, 40.65540605975736, 42.1566108734377, 43.789391594548384, 42.660478545773415, 39.553443616436375, 42.809289347740915, 39.723223409345074, 42.644114417414514, 56.32878541946412, 61.57553995809248, 59.79434067203153, 59.653633486840036, 54.05918828902706, 54.49568140891291, 53.861061526883034, 54.276738628264404, 51.43288689274942, 47.0175414700662, 41.17928174234206, 42.78820660806472, 41.03413051174533, 41.768449198815134, 43.37040009037141, 47.83655197389665, 50.87124663014566, 52.585240025674146, 50.016064028586115, 45.6931806379749, 46.010457238843365, 47.587050007235625, 51.948384392646055, 57.132184890008745, 57.39574855373752, 57.340929508209236, 56.63589131447577, 56.981609021463704, 54.33315015608265, 51.51208346889865, 52.30399431720857, 45.98774671554566, 47.525511941602154, 46.330879580590036, 42.70231062366117, 46.27836688872307, 46.16174697875977, 57.01914610401277, 57.78662450851933, 59.40378635160385, 59.61270747646209, 57.71626110999816, 58.974824182448856, 59.34699435387889, 55.07856522836993, 46.77296207797143, 47.20029646350492, 51.03818270467943, 48.70202687478835, 59.816172584410644, 62.77542437276533, 68.26089043771067, 66.48448036563012, 66.04817159714239, 30.846678095479167, 0.3108031579083012, 1.4879191330363675, 3.6474110426441317, 0.15882758543856684, 54.079113929502434, 68.78785302562099, 69.14457690331244, 71.62437777365409, 71.41620974386893, 76.06428115598618, 74.42054917735439, 48.42076155447191, 54.87955201056696, 54.784822848535356, 71.0733239881454, 36.351989392311346, 0.4441144689917565, 0.3056996027308126, 0.2827823889111319, 0.2379546008042751, 0.17306865433291083, 0.11427270083297646, 0.22602541672606624], [0.012994375710766162, 0.021890366802953427, 0.06667663102909442, 0.10363701791051896, 0.0047486515400270305, 0.06762641151585887, 0.06845107452282984, 0.027314330593893127, 0.043562230008143576, 0.0763086315184351, 0.017878703337403077, 39.51307066025273, 55.22843507028396, 42.93768813533168, 45.27676220863096, 40.11343256119759, 53.99838370661582, 49.55061989445841, 66.74993068941178, 54.98081191893547, 61.008200491628344, 53.5005800185665, 59.27797240595664, 43.77071326778781, 0.5027037702741162, 2.6880323934939603, 4.612240070296872, 3.4216519180805456, 0.40486346389497485, 1.3520532558041236, 35.02914651747673, 57.23269170330417, 58.1016339794282, 60.18882912974204, 57.97170154510006, 56.074509928303385, 51.0454979250508, 45.44296087757234, 44.86069287023237, 44.198047653321304, 43.32786198585264, 45.420862244021514, 50.67016632326188, 50.33713748378139, 51.84884248241302, 53.57786640044182, 48.46999122250465, 43.25016767747941, 39.85611723315331, 39.98562605150285, 41.88834821024249, 41.11062065247567, 41.67594009830106, 44.63919270423151, 43.15996100825649, 47.244693771485366, 49.91269780743507, 51.31413321341238, 50.12718477556783, 46.06378578370618, 45.47282188169418, 42.95014166062878, 43.01401353651478, 45.71214922012822, 46.58970502115066, 47.439772852005504, 45.71982922092561, 41.872117442469445, 38.76056786506407, 39.77613618296962, 39.72836171427081, 38.90128289499591, 43.48211703761932, 44.054975278915904, 50.96706621108517, 49.057017064863636, 52.893969781937145, 52.79878562496555, 53.235757274012414, 54.08718224494688, 55.04002009668658, 54.81158518022107, 45.409255950681626, 38.327565654631584, 40.1366961386896, 39.16823548655356, 42.46602312211068, 42.92564645890267, 50.300832025466434, 46.69577375535042, 41.02218689457063, 43.26650434924711, 41.57888497075727, 41.15930511105446, 40.273378972084295, 39.53827581098003, 40.53761728348271, 46.36087786766791, 56.17680142002722, 54.37690027298466, 54.871468005641816, 51.9348757497726, 49.953914073205766, 48.301211633989894, 45.00752679763302, 45.74605811026789, 48.17784524733021, 42.341001495238274, 39.22119140625, 36.89551222708918, 39.307346267084924, 36.84364672630064, 40.0996885761138, 42.74416623576995, 47.2661256021069, 46.11452556425526, 44.6609853929089, 38.612435633136386, 42.51748461877146, 44.314589115881155, 49.89097572142079, 54.00337688384518, 52.97363704250705, 51.910156972946666, 55.77784538269044, 51.9668822903787, 50.153017505522705, 45.40628279409101, 41.83567862356863, 42.09235852764499, 44.134132631363414, 39.086097132775095, 40.137260959994414, 40.23482207329043, 50.717564244424146, 57.10765438695108, 56.033470169190444, 56.10365313868369, 54.22561837780861, 54.94216088325747, 56.790577826961396, 55.216142362163914, 57.259759979863325, 53.110904309057425, 45.849859714508064, 41.61284877407936, 43.941869812627, 50.62489040436284, 59.329037743230025, 58.44473938788138, 56.8809296238807, 53.695235483108036, 31.16689843516196, 0.8082917693161196, 0.41087461875811704, 1.5067879398984294, 1.1870270078220677, 53.313518262678585, 53.72234298336891, 59.63164467965404, 60.73463086158999, 65.26332885988298, 61.72411934021981, 58.19004028074203, 34.27350974852039, 51.52482724958851, 62.03262552138298, 55.19560875431184, 16.331015709907778, 0.604052851277013, 0.22829633116001086, 0.07863723237307803, 0.11540573721210803, 0.019054709588207545, 0.03637868099875989, 0.08430958485170718, 0.058910893501653794, 0.04773201210604561, 0.07172232358566216, 0.09119335982588031, 0.03649556303336736, 0.053588060977598356, 0.06433327532102985, 0.01802364525745713, 0.041819334015130036, 0.015180206504620373, 0.17212086567474952, 47.79570441092215, 63.55874915276805, 42.361036962078465, 41.86268021983486, 52.83318873374693, 52.43348352370724, 55.301838305688676, 70.63645824309319, 60.96988285741499, 66.27995229536488, 60.691641684501406, 62.32788585847425, 50.75984347251154, 0.6815614599374034, 1.3713380790525869, 4.067176969781999, 5.8096911445740735, 0.42744782783331414, 1.3880979990766895, 42.14766002470448, 59.268139023934644, 61.735392232095045, 62.771725577692834, 62.025059269320586, 56.34126640135243, 54.64905000502064, 47.56345695064914, 48.221234506176366, 45.401709310470096, 44.88470954279746, 47.610337118948664, 50.44521839387956, 53.403269936961514, 55.38812260473929, 54.90765579285161, 50.01956278277982, 43.68936723278415, 40.611754002109656, 41.05367568231399, 43.700538143034905, 42.326590707225186, 41.71189254330051, 46.03263824216781, 45.751200337563795, 49.04586184409357, 50.851399437073745, 52.37320061652891, 52.91427196994905, 47.099719047546394, 48.19314249100224, 44.569033268959295, 44.209920667832904, 48.46457442929668, 48.61066702873477, 49.54832138553743, 48.383310764066636, 43.758051856871575, 42.37267071200956, 42.09740661805676, 42.395640111738636, 41.10844373703003, 45.8884911383352, 46.11474129461473, 53.94608282273816, 51.67457157565702, 54.06316949475197, 53.547118940661036, 54.52982956363309, 57.35996084828531, 57.78907598987703, 56.16390466690064, 45.674361105888124, 37.553038750925374, 38.87519521097983, 40.43182703756517, 40.98684633931806, 42.95677438859017, 53.73362371998449, 48.304023973403446, 41.36862631767027, 41.890693787605535, 41.98162609531034, 41.92781902128651, 40.0477328608113, 39.44324462644516, 40.87508624599826, 47.262226766155614, 57.29535156680692, 54.935665438252116, 58.48570854433122, 54.15420378408125, 53.652058032251176, 52.31166255089545, 49.4017816358997, 48.45404286538401, 51.608079556495916, 44.28798760137251, 41.451851167986476, 38.83943103974865, 41.23699941942769, 38.47622348416237, 42.01187541407924, 44.14292658528974, 49.01504770401986, 48.27802258153116, 47.863243702919256, 41.43408675347605, 45.630881632528, 45.88665154672439, 51.53170708687075, 54.205567221487726, 55.19815829492385, 54.61829862286968, 58.26928392533333, 54.046075805541015, 51.903492866023896, 48.793198447073664, 43.836169781223425, 44.887604251984634, 44.4375789550043, 41.63359811229091, 43.48874584321053, 41.917059959903845, 52.784916124036236, 59.59409975236463, 58.799811947730284, 57.96517472113333, 59.22404373845747, 60.57397842407227, 58.50406523673766, 58.335011082310835, 60.7329716990071, 56.77923433242306, 47.53466283121417, 44.97012307566982, 48.50207228814402, 54.061875112595104, 62.76702265585623, 62.013099962665194, 59.74966095339868, 51.10942863648938, 35.92904021663051, 1.1579905594548872, 1.483041175430821, 1.2811800717346131, 1.4015294202873785, 59.76171831930838, 59.739011718380844, 64.46989220957603, 65.2024301405876, 71.30671285813855, 69.23858042686217, 64.29822183424427, 45.63653769031648, 59.141893617568485, 66.58239841461182, 62.75743246078492, 21.722493940784087, 0.7024021158295294, 0.07634995430107079, 0.11431950880514999, 0.04299897535313522, 0.05329254639124679, 0.06567975145674522, 0.028669618655957525, 0.14058822705861063, 0.2292981903038679, 0.3445021706002374, 0.24258923356331166, 0.2129829383545345, 0.13539110190205036, 0.1734344153514793, 0.13392275649934046, 0.10681901773017262, 0.09640691756841638, 0.26485878133004714, 60.91261625289918, 73.12211913447227, 55.654977137042636, 57.77601841957339, 54.93455148512318, 64.09339958621611, 62.068044524038996, 77.51967660842404, 66.65407580714073, 71.44895369006743, 63.467820767433416, 69.91660133484872, 53.37224791126867, 0.8972478153244142, 5.134568868144866, 12.481131918968694, 8.615709658591978, 0.6623230309736344, 3.1222954007887074, 46.74681948077294, 60.24279702094294, 62.97723816287134, 63.751486578295314, 64.601436738045, 58.15083619086974, 55.325796142701186, 49.637837717610026, 51.64668352373185, 48.00286831394319, 46.759237704738496, 49.47630666917371, 55.32742784869287, 55.92199640889322, 58.04272782418036, 56.883639981669766, 53.55399877794328, 45.38498824642551, 42.08647105001634, 42.38957612745224, 45.118067033829234, 44.75329445254418, 44.340225727327415, 48.29637535156743, 47.21210279772359, 51.41589910753312, 54.53605828746673, 56.022432619525546, 54.85672773853425, 50.11899878901821, 50.05440127465033, 47.15552260798793, 46.9469976425171, 49.17476269506639, 49.91235656123008, 52.236843339858524, 50.26319296129289, 45.662805803360484, 44.71175263004918, 44.77146679355253, 44.96954648725448, 43.17152415552447, 49.42001281246063, 49.14716489853398, 56.726913836694536, 53.46290565306141, 56.77491580286334, 57.75974450572845, 56.742775901671386, 58.755952004463445, 60.031785272782855, 58.21199770896666, 46.91396344092585, 38.385699102955485, 40.04179047000024, 39.8118572081289, 41.38401769822644, 43.58571467861053, 57.846452420757664, 49.21228801050494, 40.21739498261483, 42.856624510980424, 40.835874311385616, 42.769281171983295, 39.63776673040083, 40.13974774268366, 41.56708648127895, 48.10557165453511, 60.288476943969734, 59.24610707067675, 59.99585243963427, 55.50811575305078, 55.68399483157743, 55.27715090782412, 50.2684332478431, 50.08275216625583, 54.59126564764208, 46.8677108518539, 45.70876421466951, 40.01577338864727, 44.717291016732496, 41.99101232713269, 44.54411837362474, 46.514917189075106, 51.57699477288031, 49.773065351670795, 50.43870725939351, 41.944712669618674, 47.63318492520241, 49.260776350575114, 54.27571096727925, 55.91506558079874, 57.794335888278106, 56.88007062481296, 59.00970582039126, 57.984472782381125, 54.11829056278352, 51.73738441159649, 45.98786438665083, 47.120538988421046, 49.1680319078507, 43.44655290726693, 46.165716417374156, 44.7362478317753, 55.229674539258404, 62.529527064292665, 60.61728531314481, 61.94284639050884, 61.08291379867062, 62.703299830036784, 61.62801342625772, 59.48077463334607, 63.7650619014617, 59.38789290766562, 50.455314574703095, 45.89599463247484, 51.74217754794706, 56.76297218568864, 66.227965201101, 64.03152027437764, 61.16338906749603, 54.22199803013956, 43.29951893898749, 1.8472788434836174, 2.491368675424207, 4.475731292078573, 2.146940447630421, 68.66476904961371, 65.4656486357412, 71.59808220401888, 70.46265017601752, 78.81446669178625, 73.36616116185343, 69.98956526479414, 48.874132633209236, 56.52824578746673, 71.60164371613534, 74.1333532333374, 27.070235783053985, 0.8930519824066471, 0.44239123081487997, 0.2439289068382594, 0.15517087923663278, 0.16391028770275656, 0.1804507541800699, 0.15611295287887897], [0.043060005747623024, 0.0740639019697424, 0.03622347541574029, 0.07494596794487969, 0.05382343766189391, 0.05056681704797572, 0.06292026061865111, 0.011025965457872279, 0.033187848185339285, 0.22264738266746845, 0.15927962327916778, 12.321589512209739, 51.91259276482367, 41.959994223810014, 32.67054688545966, 30.504437569648992, 59.17466109798801, 59.26003148478847, 62.102098541875044, 61.24903402020855, 58.92395888605426, 59.51924916236632, 58.3754389516769, 50.48072761104953, 2.578221473001665, 0.39938743676870103, 4.6593800956203095, 3.8567160694829883, 0.24229107214318168, 0.02115263179275057, 27.788221720726263, 56.95263839537098, 59.95561676640665, 58.39129709428357, 56.34296871000721, 50.64627908891248, 49.74490273383356, 46.15709897010557, 50.07711179794804, 51.53499795544533, 52.18977489779073, 55.527060800983065, 56.16655226676695, 55.11244273954823, 58.49350229386361, 55.86999754751883, 52.670045591169796, 48.02768515002344, 39.68829078059043, 40.7363167116719, 40.569364947657434, 41.01848025475779, 42.81785188182708, 42.65829378558744, 44.8156758277647, 47.3393758650749, 50.274246200438476, 51.13027603395524, 51.23909827201597, 48.5544280852041, 45.72796029429282, 41.89976230744393, 43.16023949653872, 42.76846924135762, 47.47799242696455, 46.22345370631064, 46.05665883710308, 41.29028874058878, 39.435403808470696, 38.28376846928751, 39.705678647564305, 40.5831128551114, 42.89570308500721, 47.0702895041435, 50.54312467575074, 50.093919154136415, 50.54375617734848, 52.5189951158339, 54.433523608792214, 54.32488572212958, 57.62807838378414, 54.68753237878123, 48.903016967158166, 38.56531227788618, 39.825448220775975, 39.32827995669457, 43.32877982047297, 41.09134220307873, 49.307770267609634, 46.79907721857871, 42.791724974109286, 43.21849061596779, 42.71013967452511, 41.2541127204895, 39.05688724210186, 40.03741310488793, 39.47041488462879, 48.48463343035791, 54.42971890972507, 54.80378750831851, 57.09090194394512, 54.2404253252091, 53.01057008004958, 50.142054480891076, 50.16429431976811, 44.79986867597027, 44.09321446572581, 44.415370495088645, 41.81178354447888, 38.306243650374874, 39.37785871567265, 38.62965483819285, 40.50101764740483, 42.451000444350704, 46.45097471052601, 44.57151612927837, 42.728829768396196, 41.073930801883826, 43.86041395125851, 45.843634913044596, 45.57727852175313, 56.012916949487504, 54.92276868512554, 52.07745390553629, 52.18388349779191, 52.16978257702243, 50.220803906840665, 45.141405136354514, 45.15603165472708, 41.07123221120527, 39.303455275873986, 40.79601518569454, 40.48215104687599, 41.71346933610978, 54.45160573528659, 56.898364559296645, 56.583288408094845, 55.72796067883892, 58.191620995921475, 56.45431695445892, 58.309605890704745, 57.54170387021957, 58.93250965302991, 56.43632896484868, 57.75756759028281, 42.79558850872902, 41.73612886859525, 49.44391181392055, 58.9889015689973, 58.97968792146253, 61.43471117942565, 45.99000207839474, 24.044348809026904, 0.10234796772560767, 0.8998343733049209, 2.2181447042572886, 5.495581367323476, 59.34184428184264, 51.25334432048183, 60.22943742813603, 56.81672434653006, 59.917899254829656, 63.56356190096948, 51.28048319970408, 33.09404911533479, 30.600300296660397, 45.23814647428451, 52.40774100826633, 4.444281237740671, 0.1675976374216618, 0.3007870179510886, 0.06647862028330564, 0.09636494361104504, 0.017662902114792697, 0.03302427692218654, 0.008279278821822616, 0.04309835227867288, 0.040176335887442675, 0.10308538863976156, 0.06302182089477297, 0.04149076273484577, 0.015248452489744994, 0.03340544396891229, 0.07662434401291032, 0.05109037685718748, 0.06161259066674018, 0.2887493558228016, 19.742732509489983, 63.201417307699884, 45.80159494953771, 35.6751020493046, 42.10595738503241, 62.28585766207788, 63.26879578251993, 67.50918388366699, 65.37078219075357, 64.67715417185138, 65.41841937649635, 63.97176296480241, 56.90618184305007, 3.349596016830014, 0.8108835366945114, 3.7911016806479427, 4.356525069282902, 0.7482269214045617, 0.05702104652300478, 31.369029937251923, 58.48937203807216, 62.394424946077415, 62.23825970003682, 59.842699573886016, 52.92096745583319, 53.06921735886605, 49.47826393188969, 52.77326276225429, 53.28879948585264, 54.054100974913574, 60.155281097658225, 57.93920078585225, 56.92379328512377, 63.56654682467061, 58.48252750212147, 56.9796831377091, 49.103936456864886, 41.41448274735482, 42.86483010938091, 43.65050438911685, 42.36690875022642, 44.22026788034747, 44.69599254669682, 46.47250460040185, 49.489544668505275, 54.61496853059339, 52.71707088716569, 52.48448610305787, 50.53986518613754, 47.41075907984088, 43.664001264879786, 43.71314464076873, 44.90059121962517, 50.14041100778888, 47.45809032071022, 48.15268716504497, 45.08618208669847, 40.93643211549328, 41.087106043292636, 41.134190174841116, 42.88207284865841, 44.789588143748624, 47.96054201741373, 53.47357449993011, 51.16591076697073, 52.61747014138007, 53.7803352263666, 56.249133848374896, 56.47493293208461, 59.016797465662805, 55.66896430907711, 47.87520693194482, 39.82297320519724, 40.29011572560957, 38.07601228837044, 41.71590905035696, 40.263984895521595, 51.63044098884829, 45.68219407912224, 41.36062076014858, 43.432079361331084, 43.05390404116723, 41.28342459278722, 39.334814625401656, 42.30504120549848, 39.21701800438666, 49.32169075935118, 57.42787276544879, 56.83636757635302, 59.52773717141921, 56.78340381191623, 55.348800843761815, 52.03977954003119, 51.49475443747736, 47.338277601426654, 49.64383894397367, 47.36205500941123, 42.748068994091405, 40.38041653171663, 42.938166664492705, 40.11858655560402, 42.180298066908314, 44.743213961201334, 49.58725875423801, 46.421447107868815, 44.39313065621161, 43.37740936586934, 45.16701429120956, 46.39060943357406, 48.45243469361336, 57.47464702975366, 56.99557265927715, 55.32308186254194, 54.3116359556875, 53.75390629614554, 52.54338441356536, 45.28421863432854, 46.9015726735515, 43.30989360809327, 42.57894031463131, 41.88112712675526, 41.999410121671616, 44.80380673562327, 55.717680146617276, 57.84210643460674, 59.98288116147442, 58.593946349236276, 58.339663013335205, 60.38882294008809, 59.78120073195427, 60.377455911328724, 61.890318009161184, 59.099551631558334, 61.17167703567013, 44.366666424658995, 45.56183222801455, 54.25629523492629, 61.121176519701564, 61.0959949031953, 65.41268094893425, 46.386628227849165, 26.932956749393096, 0.09067675609502102, 1.6013556718826296, 1.6037043135973716, 7.2731328491241705, 66.28249399123654, 56.06405681179416, 66.3814240117227, 63.2276697312632, 67.45395691164079, 69.28890443617298, 56.211945856771166, 45.78656050466722, 33.641847333600445, 48.71607680474558, 61.3785820622598, 7.974633555258475, 0.19449020405450176, 0.3063839950388478, 0.048135315263343435, 0.03809849093217523, 0.10533069275439748, 0.040380643875969034, 0.053251733057080745, 0.1303576437696334, 0.26970088602073733, 0.33694639862064396, 0.34587071006817205, 0.13357441632017014, 0.13158601979094167, 0.2100838318226799, 0.2530843010472675, 0.2490185805025601, 0.28598031569873134, 0.41915039081246624, 24.903720501930486, 75.08834838867188, 55.25550726921328, 44.42043035261093, 44.36447774210284, 73.00704463835686, 75.88731165855162, 73.93378303896996, 71.6027812034853, 70.09839534759521, 72.10738628141343, 68.92220204876315, 64.13483942708662, 3.7169634911321827, 3.152546435594559, 13.599562433458145, 8.75755629231853, 0.8105663762938592, 0.2721424082354192, 37.46513059062343, 57.975310125658595, 66.3701589645878, 64.86267835863175, 62.295283117601954, 55.570030366220784, 55.64437889283704, 51.28728458958288, 55.12627301677581, 58.13202842589348, 57.440451806591405, 61.094590694673606, 62.82698000631025, 57.99614575601394, 66.36213379521524, 58.61541740355953, 56.94999864024501, 52.85080409819081, 43.25525106922273, 45.844101675095104, 45.65498851960706, 44.9831884907138, 46.800508883691606, 48.57803290890109, 51.020998800954516, 53.01073481959682, 56.30818120894894, 55.87302169492168, 54.91273133985458, 52.727916240692146, 49.94315108945293, 46.19670314173545, 46.6112349110265, 46.78186978063276, 54.56843353086903, 49.91506299664898, 49.56486202055409, 46.85297450711651, 42.893255526019686, 43.499449991410785, 43.45137742257888, 43.98297625203287, 48.79550087836481, 50.18076435212166, 55.71883332344794, 53.020191654082275, 54.10834343202653, 55.48810382043162, 60.27625091614262, 60.27916131481048, 62.81313011723181, 57.087877796542266, 49.997005231918834, 40.87924395838092, 40.6306049131578, 38.89370879819317, 42.233563853848366, 40.99999020176549, 56.00457799050116, 46.258656978607185, 42.93416976928712, 44.05309646360336, 44.8174605061931, 41.65739905449652, 38.69413075908538, 42.09119358370381, 39.68089319044544, 50.11348393655593, 59.11587653621551, 59.55773153612691, 63.96917027811851, 59.0054500487543, 58.50581069146433, 55.41299043163177, 56.31439424330189, 50.37671419882005, 52.1070638779671, 48.806620797803326, 46.82093658754903, 43.4088550075408, 45.40842833057527, 44.334487299765314, 46.76008101432554, 46.83645740632088, 50.22834662468203, 47.66545034223988, 45.20161351849956, 46.01785875135853, 47.861694366701194, 48.30398474970172, 49.879679295324514, 59.596868945706284, 60.89849964264901, 57.490477715769124, 55.484169683148785, 57.04637912011916, 55.63315306940387, 49.45921297996275, 50.08927506785239, 45.538388221494614, 42.59044070397654, 45.686575366604714, 44.101043516589755, 46.48564061810894, 58.52082552448396, 62.62609581793509, 63.01123726752497, 58.659446008743785, 61.032213241823264, 61.74866161038799, 62.34485403183968, 63.50171004572223, 65.84296887920749, 60.33203878710347, 64.60051105868432, 47.787153643946496, 49.02024876686835, 56.81520638927337, 64.78101068927397, 65.92678992978989, 65.19165931209442, 49.36628026347007, 33.05595113385108, 0.1388663065529639, 4.56084329274393, 4.926793565673213, 8.216054458771984, 73.90875047253024, 62.53245707481139, 73.1520938873291, 66.65144781912527, 72.75130610312186, 74.84209414451354, 64.09292497942525, 47.028426047294374, 39.6322871792701, 57.305455592370805, 71.26057794017177, 10.996937444133144, 0.4375255919031559, 0.5071943938251465, 0.1867736608631188, 0.12533805948952514, 0.3127397975373653, 0.1376893656748918, 0.2551598630605206], [0.025866926204593434, 0.12355848320669706, 0.09831380234250138, 0.08630532050325025, 0.03402306022302758, 0.050920496859978286, 0.039077562790724545, 0.04654772061434004, 0.08199916326350744, 0.08600363507866861, 0.17722815936130865, 4.101100078513546, 57.200410596786014, 40.41959316499772, 37.77628437165291, 37.93280263100901, 48.790966618445616, 57.446209846004365, 57.461393340941406, 62.20731219937725, 58.96407296580654, 61.61691704104024, 55.28085754763696, 61.44621549114105, 17.055726551240493, 1.2121630267750834, 1.5304094336686598, 4.3972750632993645, 0.986685025836191, 0.10075690269830728, 19.844721978710545, 59.508603849718654, 59.02327722118747, 57.647737303087794, 53.96091722672986, 55.326745356282885, 52.28213494823825, 55.821014988806944, 55.53234423360517, 55.054097483235026, 54.275224593377885, 54.490268538075114, 55.71235356792327, 56.84006637142551, 56.09719299500989, 56.628968331121634, 55.76886315499583, 50.135209944940385, 45.003455377394154, 40.212119394733065, 39.264341400515654, 41.11917141945132, 41.390991672392815, 41.71414790614959, 46.32049314437374, 47.97458410263062, 49.20428637535342, 50.2252910983178, 48.123947958792414, 45.17157993009014, 46.31634327673143, 42.80980710060366, 39.70853413304975, 44.0517589353746, 48.24436080071234, 47.40180823110765, 47.02964198204779, 42.902602534140314, 38.8013683595965, 38.33375907713367, 40.2772464290742, 42.68794690409015, 43.49772022616479, 51.1726729331478, 50.506321076423895, 56.33741463384321, 52.978300740641934, 56.30610235275761, 54.66604171260711, 55.931119841914025, 53.79247888442009, 53.92530210556523, 45.8501656593815, 38.91140653241066, 39.85944732542961, 44.21935004572715, 44.69241534509967, 42.619811411826845, 48.035729931246856, 46.00026692113569, 41.42990158450219, 42.32335082946285, 41.40630068317537, 40.80832358329527, 39.6524481619558, 38.44611144834949, 40.986661987919966, 48.818599716309585, 57.93265827240483, 54.773844134423044, 56.034878300082305, 55.17094096829815, 53.55650909485356, 52.3788135282455, 49.717297092560806, 45.250015566425944, 42.47635464514456, 44.201899420830514, 44.17768270738664, 42.89984903027935, 38.546100508782175, 39.361180797699966, 40.80614274547946, 40.591126257373446, 42.57359020171627, 41.907650193860455, 41.78849643276584, 40.48840722730083, 42.26755903613183, 44.21862440724527, 44.56990403513755, 54.854154663701216, 52.98241922932287, 51.37551830660913, 56.27038132759833, 52.82256303295013, 51.40907810580347, 48.02568474123555, 47.09671843436457, 43.73920879056377, 41.76161250760479, 41.36681810502083, 41.068494396824995, 41.52749015438942, 51.9138204666876, 57.41501523602394, 57.04535538150419, 56.28506275915331, 56.00243637638708, 58.031702041625984, 52.830572512842, 47.605037996845866, 54.42487086019209, 61.50129341310071, 57.632581264741965, 52.903811008699485, 42.34453555076353, 45.49467732829433, 57.17839825537897, 57.75043672130954, 59.85270946256576, 54.16230740085725, 2.3241219982024166, 0.23929119440576724, 1.0567199871424706, 0.9288450198308115, 17.229071778635827, 54.41980708029963, 53.4300361910174, 58.69718705454181, 58.37443482491278, 61.41675849114696, 61.34635586892406, 44.96261565916, 36.102624708606356, 26.865766548341323, 45.64546500482867, 43.71993426353701, 0.447065255814983, 0.11453369932789957, 0.13515032046744901, 0.06470598475707155, 0.04608585003523096, 0.034435357252556476, 0.007751569210086019, 0.04994181953670998, 0.010914579146511613, 0.052510163776816866, 0.0317773845557484, 0.021207045102792404, 0.04075411556949539, 0.08812575991595946, 0.05914722396541507, 0.10393919363137215, 0.04723341527184652, 0.13887804301996387, 0.3209942723474195, 6.234546592158656, 67.19471962221208, 45.10099687883931, 36.045773875328806, 46.10280944455055, 57.5971701068263, 62.24929332733155, 63.98609138304188, 65.41184940645772, 64.65083899036532, 66.10117066291072, 59.541873393520234, 65.17541285484069, 17.725245721878544, 0.7641450640174651, 2.623833489994849, 6.636528247787107, 1.6351870952113983, 0.15436322338158084, 24.592600061047463, 59.89979359411425, 60.244656224404615, 60.76467621710993, 57.23852426775041, 59.12345063301825, 54.91212729484805, 57.37724281126454, 57.01042667511971, 58.41611785273398, 58.33965516859486, 56.095886845742505, 57.84902157322053, 59.33647847944691, 59.44532032935851, 59.872776308367335, 59.34311512977847, 52.94674919497583, 45.715683275653475, 41.938703598514685, 43.9103300340714, 43.97729273765318, 42.60342374924691, 44.044957545495805, 48.13511102430282, 50.57803377028435, 51.297729861351755, 51.38896419155983, 51.07607672291418, 47.67795093597905, 49.52704644972279, 42.23601533520607, 41.877040017035704, 45.05399903943462, 50.333473990040446, 51.56712608952677, 49.18252114326724, 44.36992983664236, 42.35641641001548, 42.784582338025494, 41.66564387659873, 45.30773716588175, 46.37194287392401, 52.58054102620771, 52.574951648712165, 56.191961380743216, 54.6158157625506, 56.21817850297498, 56.14715222389468, 56.94059671894197, 56.410731577104144, 55.783250408787886, 45.83253460545694, 37.56732402309295, 40.30033742227862, 42.15794447929629, 43.74674366366479, 40.06548943058137, 51.09997180200393, 47.308699007957216, 41.96957657414098, 44.826258382489605, 41.833125160586455, 42.46161830040717, 39.32225911848007, 39.81106881172427, 39.671483424402055, 49.056228668459006, 59.767021363781346, 55.83550422422348, 57.505574918562374, 57.34619332898048, 56.11232157676451, 55.796390348865145, 52.50689068148213, 45.862446600391024, 45.773573537026685, 46.09823596092963, 46.561573782274806, 44.744269078777684, 41.551051832014515, 41.381448545763575, 43.796506774040964, 42.441406326909224, 44.46149756831508, 45.04120426793253, 42.78842233842419, 41.79553316485497, 44.950695576206336, 46.177911066239886, 46.570418727013376, 56.30615726594002, 55.5471747152267, 53.38314817797754, 57.020381650617054, 54.69824437172183, 53.184762539402136, 49.773794912522845, 48.32079210589009, 45.199828840071156, 42.703424576790106, 43.19868656896776, 41.57550388766874, 44.14462889394453, 54.68673613763625, 59.64999352732013, 59.36882234388783, 58.17239353733679, 59.785401590408824, 60.19343006995417, 54.847310127750525, 52.74841062484249, 56.84252177515338, 63.72426532929944, 60.02474854069372, 55.90329454791162, 44.67305060355894, 49.43695352923486, 60.058492691286155, 62.79589522269465, 63.81030644139936, 57.29013481447774, 3.1636700322551117, 0.5698557895037436, 2.4021217611528214, 0.7987429429927181, 22.16732013610102, 61.08224699574133, 60.242334181262606, 65.68603484861313, 64.52684502447805, 68.80307182188957, 65.21476599477953, 51.210496348719445, 38.058200805417954, 22.766634764209872, 52.85652291390204, 51.330960181451616, 1.0224801470195095, 0.04249344925366102, 0.07793381810188293, 0.06074710283428431, 0.044778635905634974, 0.03329867812534494, 0.01712262818229295, 0.08788629615258786, 0.10090862641171103, 0.26461537987474476, 0.2144070191969795, 0.21240605882579283, 0.1974464454237492, 0.1355917709729364, 0.19963119028797074, 0.2489002812052927, 0.1961811439644906, 0.3383878696589701, 0.3862506223301734, 9.226987515726398, 82.22453609589608, 52.18407961630052, 49.152275746868504, 50.54747066190166, 64.5341916238108, 66.2035680586292, 68.3118498709894, 70.65799205533921, 69.96460330101752, 72.94405137338947, 64.13038361457087, 73.43757967795096, 24.607069684613137, 2.1963988388738325, 9.759546345280064, 14.894631985695133, 3.463110390209383, 0.24361065859275483, 27.21491829041512, 59.94650510049636, 63.50900957661291, 63.30543464229953, 59.93858583511845, 62.09383410792198, 57.028850047819084, 60.770477402594786, 58.496604888669914, 60.14723239406463, 60.65582260008782, 59.23719544564525, 60.50474466816072, 61.153069311572665, 60.84515148593534, 59.834905824353626, 60.35223507112073, 55.57045790456957, 49.860342010375, 43.47817113322597, 46.148854148003366, 47.51073637316304, 46.49235571584394, 45.006840382852864, 50.130789433756185, 54.043388981972974, 54.187845953049205, 52.78663804454189, 54.18288023241105, 49.04024893237699, 51.018574776188025, 45.561753780611106, 44.040211477587306, 47.65663677646268, 53.16216184246925, 53.63521537473125, 52.426215371777936, 47.58431219285535, 44.4718094794981, 43.075979140497026, 45.775573945814564, 46.193439729752086, 48.199516342532256, 56.41808994354741, 54.61168942912933, 60.26804139537197, 58.309052836510446, 61.56373362387381, 58.67756735893988, 60.03899851152974, 58.49454564432944, 58.596746921539314, 45.80408565459713, 38.122151128707394, 40.54606606883388, 43.21817290398383, 44.55861153141145, 41.74777438563686, 53.6853511102738, 48.069964378110825, 40.90416277608564, 43.77654975460422, 40.98878791255336, 40.462837296147505, 39.64738438206334, 39.496514335755386, 40.598633673883256, 49.93581233486053, 64.08817106677641, 58.05385166598905, 61.860919844719675, 61.522536969953975, 58.39886334634597, 56.91352452001264, 56.798528471300685, 49.872136577483154, 48.143967736151914, 48.462020966314505, 49.43800080207087, 48.17618608474732, 44.018803181186804, 43.89193411796324, 46.38055639882242, 44.395813557409475, 45.573022750116166, 47.062766398153, 45.94490658852362, 43.65528968072707, 45.44008578023603, 48.57343196868897, 48.3077423803268, 58.07973146438599, 56.7005241301752, 56.046700323781664, 59.04689381199499, 57.04266855793615, 56.02369170035086, 52.6929836119375, 51.34799503510999, 48.29228824184787, 45.772840053804465, 46.228976403513265, 43.365453981584125, 46.56570796043643, 56.82308250857938, 62.658957435238754, 62.39569579401324, 59.84546876722767, 62.828003744925226, 61.64464035341817, 56.4198197087934, 55.00465208484281, 59.31774523950393, 67.78508340158771, 63.96443597732052, 58.06286135027486, 48.061476369057935, 52.61714458465577, 62.306140238238925, 66.55476139437768, 64.70351642177951, 60.86178625783613, 5.3296852111816415, 0.4563003844551502, 9.039817894658736, 2.674224424746729, 24.003371807836718, 68.11861822682043, 64.63527894789173, 71.80338690357824, 71.63379146206763, 72.65029722644438, 72.69622033642185, 56.74692184694352, 49.42468043296568, 38.745368680646344, 59.29649383791032, 64.06086744800692, 1.8517654220904074, 0.3180237510992635, 0.2795292731494673, 0.19494739000595387, 0.19310821208261675, 0.14926254869468752, 0.07115384804144984, 0.2339970825179931], [0.06121189986926414, 0.0067418581438100636, 0.02685917669066018, 0.048622719552968784, 0.031113102055725553, 0.033836885535668944, 0.03137305292541222, 0.03970226152769981, 0.051952359837389765, 0.05319397002758999, 0.11992297465762786, 0.893516231688761, 42.56064638014763, 48.216743392329064, 39.83770954993464, 19.8164907193953, 46.37808138324369, 56.29863023757935, 59.149079399724165, 60.551781731267134, 61.1860054539096, 58.57507974870744, 56.33783824982182, 52.96800844130978, 44.11787832936933, 0.10570275101570353, 1.0901319620109375, 1.3647205502756181, 0.8874659144109296, 0.1555648169690563, 17.03945459858064, 62.35771156126454, 56.41768986178983, 61.72535488682409, 56.45862763927829, 58.0141023666628, 56.924110997107725, 58.3181841142716, 56.3215761030874, 58.50012717708465, 57.95169353485108, 60.922551616545654, 56.42516982170844, 54.043365447751945, 51.764001615585826, 56.72734137504332, 57.38951982990388, 50.46651686391523, 44.460638569247344, 42.14567530539728, 40.584246420091205, 42.126577285028276, 42.24720977967785, 43.379790244563935, 44.59793721475909, 48.22465481296663, 51.51073417355938, 53.963251036982385, 50.18607131896481, 46.17730309886318, 45.260637344852576, 42.88186104066911, 41.859177543270974, 42.19674064267067, 44.4554728077304, 46.177134436945764, 41.59275447168658, 40.08779987212151, 39.02046411268173, 37.0226283996336, 42.581246668292636, 42.38938785368397, 49.5136986240264, 52.07650469195459, 50.84121304173624, 54.027805405278365, 50.88517888899773, 52.53659871316726, 53.41223647517543, 54.53454033021004, 54.357378636637044, 52.668084406083636, 45.47893685679282, 39.922130723153394, 40.61342493180306, 41.02022963185465, 43.09354743649883, 41.967501640319824, 49.57796273692962, 46.86641254732686, 42.78685731272544, 43.34341418358588, 43.454931089955, 43.5623412747537, 41.57351916836154, 40.76544031020134, 42.47278136591758, 51.4962370934025, 56.680774996357584, 54.73212188290012, 53.990260477988954, 54.90252925503639, 53.49586140724921, 53.67261909669446, 51.72737452291673, 47.33600654909688, 43.246484571887606, 43.984784464682306, 43.31515742886452, 43.75654174435524, 42.468878607596125, 41.247774170291045, 40.690664245236306, 41.564081945726954, 42.35875022026801, 41.95283197587536, 39.7895703008098, 40.139382962257635, 42.09836367637881, 47.10438666805145, 47.34545161647182, 53.60760581108832, 54.11957710020004, 53.15063007416264, 51.067157253142334, 53.65705513185071, 52.3241513775241, 50.158559814576186, 47.31423347227035, 46.84997389393468, 42.518975119436945, 41.21389273674258, 41.764236573250066, 41.7052205916374, 45.23314152994464, 54.08368349075318, 54.830640054518184, 55.480227701125614, 54.045844385700846, 55.873998365094586, 55.31618633577901, 56.43231245779223, 53.209014554177564, 52.21778846556141, 62.13903157941757, 55.64680291760353, 48.533153149389456, 43.60065498659688, 54.88485113266976, 57.59991968831709, 64.3141858808456, 48.54442604126469, 1.1748245142159925, 0.053064305815965905, 0.7653881489269195, 0.25298501605228074, 25.739530517208962, 53.33874302525675, 53.325677610212765, 59.60636500389346, 57.29528096414382, 63.07773320905624, 57.759305200269154, 45.57195978779947, 34.75551020714545, 40.77808995400706, 49.48428869247437, 28.109881570262296, 0.07533685664736456, 0.057898293805098346, 0.04629734009804745, 0.05037147611860306, 0.0629855657837564, 0.053281273407440995, 0.07045152927598647, 0.05299503997629208, 0.017412722696580233, 0.03182977539367013, 0.026400393445885954, 0.07281879458816783, 0.04688512488839127, 0.09799769914318478, 0.020103736765562527, 0.06572556351461718, 0.05332382959163478, 0.07795132321095274, 0.07021954253075585, 2.171320429732723, 53.943850994110115, 54.221597948381984, 42.16560879061299, 34.93143635411417, 56.41785852370724, 59.92502620143276, 63.41418627769717, 66.05085449834024, 66.3106252301124, 63.7544362006649, 60.640525356415786, 58.33760769136491, 46.286933345179406, 0.10375379269281704, 1.0116952837955568, 6.934009136692171, 2.494364875939585, 0.2664352370606315, 19.57383328868497, 60.81652210604761, 57.856646660835516, 64.81155418580579, 59.54115167740853, 60.26969663558468, 59.526984076346125, 61.21731381262503, 59.73882736698274, 61.491534556111986, 60.060901026571955, 62.63032021061067, 58.66235640741164, 55.778065035420084, 51.54292898793375, 58.370328103342366, 60.199690172749186, 52.676858748159106, 45.454645618315666, 43.93662952607678, 43.5938222177567, 43.33084690955378, 44.52739730958016, 45.362846466802786, 47.18305764659759, 49.79532480239869, 52.35563624289728, 53.89941446242794, 49.41554915520453, 48.53364736803117, 48.63576627546742, 45.0767840877656, 44.632285410358065, 43.820072374036236, 45.32250881195069, 47.15181596817509, 43.83459298841415, 42.131605763589185, 41.53855516064552, 39.30579693086686, 43.24515488839919, 44.24165656489711, 49.97606369756883, 53.24155845949727, 53.07149233356599, 56.558134248179776, 55.48756645571802, 54.382442582038145, 55.260727943912634, 59.15627694899037, 56.72609798369869, 54.86359188633581, 46.91846632188367, 38.01837305868826, 41.01578950881958, 40.17875179167717, 44.02405523484753, 42.97722170429845, 52.65994548797608, 47.612721920013435, 41.198340539009344, 43.4374608532075, 42.97023596302156, 41.7027416536885, 39.68265041228264, 42.20137688421434, 41.748617695223906, 52.81627939593408, 56.21923362055133, 58.52736803793139, 56.15185514573128, 58.38536647058303, 55.82262316057759, 54.58231087653868, 53.57966676835091, 50.321926532253144, 44.91096588873094, 46.41017421599358, 46.36587496726744, 46.5558785007846, 45.02291425581902, 43.748508730242335, 43.18268329866471, 43.55793645305019, 44.79485588689005, 43.172767546869096, 42.54533344699491, 42.021014536580736, 43.243652620623195, 48.4560001281, 50.17593199206937, 55.913861413155836, 55.654906534379535, 51.59053087234498, 53.98468286760392, 54.59820824284708, 53.82043361663819, 51.092029002404985, 50.35399190841183, 48.53120765378399, 43.50434903175601, 42.837777522302446, 43.454813418849824, 43.41811180114747, 49.16560003834386, 55.60175841854465, 56.439149149002574, 58.97395733864077, 55.02486798071093, 57.29098204643496, 58.52023716895812, 59.79850622915453, 55.18417896762971, 54.90273321828535, 65.70175963063394, 58.87583140403994, 52.50716132502402, 45.31293430636006, 57.11242398908062, 62.174838896720644, 67.66171701492803, 51.652774964609456, 1.336341834356708, 0.13920766001026477, 0.4793003664141702, 0.23529296620718895, 32.56569996956856, 59.685032060069425, 60.00656443257486, 66.16435220164638, 64.51627815923383, 70.49796719704905, 61.807897244730306, 55.34151700235183, 43.522968522963986, 34.75887560075329, 56.916905603101185, 34.768191229912546, 0.12447002058428143, 0.02832596693488379, 0.05379961615788841, 0.04778512881227559, 0.12314605977266066, 0.07620985214147838, 0.023745067582856265, 0.05433403143298723, 0.1285170026183609, 0.14411934080623812, 0.10626733483326052, 0.15351646639887365, 0.11214821644487882, 0.20616552191636256, 0.14008060187822388, 0.1389395598802836, 0.15068506671776696, 0.30226458705240683, 0.28152643372454955, 2.4516894884647864, 64.46625617242628, 63.70333556205996, 51.37910335294662, 29.468767104610322, 61.20017697734218, 67.93268219117196, 69.6217881479571, 68.95336135741204, 73.05409739094397, 67.8239619347357, 66.60835666041221, 62.84163005890385, 53.732858857800885, 0.20888913302652298, 6.711673505844609, 9.979272619370493, 5.56742791206606, 0.21857269889404699, 23.676744276477447, 59.973200751889145, 59.900946770944905, 67.77792115365305, 61.58100381974251, 64.50668011942219, 61.71114806205996, 62.77600880592101, 61.0604033162517, 63.810886952184866, 61.90707829690749, 64.39638699254682, 60.15566156756494, 56.70841201659172, 51.95319321847732, 60.71061811139507, 64.62106035601708, 54.09576046851374, 48.09826820127426, 46.569438134470296, 44.16434272643059, 46.81095023309031, 47.03039899949105, 48.603826415154245, 49.34597023071782, 52.699714399153194, 55.99960834749284, 57.39452477424376, 53.06545188350063, 49.00124096101331, 50.28562107393819, 48.99891891787129, 45.99243787027175, 47.099240518385365, 47.884212693860455, 50.91059977008451, 44.17126570978473, 44.067240530444735, 44.794698992083156, 42.18409492123512, 47.244058347517445, 46.70985898663921, 53.133273586150146, 56.544602071085286, 56.09716553841868, 60.377008761129076, 57.535741867557654, 56.00093803098125, 58.80619756637081, 63.69391010653589, 58.694123683437226, 57.255998426868075, 45.91030343886345, 39.20017142449656, 41.74769593823341, 40.70993877226307, 44.53857606457126, 42.320997407359464, 56.070340448810214, 48.96235458312496, 42.616818643385365, 43.789552411725445, 43.66524857859458, 42.380895922260905, 40.56852556044056, 42.32057379138085, 41.90284529039937, 53.780794143676765, 61.956868863874874, 62.576218958823915, 59.59249942533432, 61.47685704692718, 59.73030797896847, 59.58228949577578, 55.74542699321624, 53.10046295965872, 49.31756050355973, 48.641402721405036, 48.889053329344726, 48.3570191168016, 47.64407734717093, 45.70688932172714, 44.867051032281694, 46.61546714844243, 47.243650421019524, 46.593113560830396, 44.97033096128895, 43.868705841802786, 46.9968274331862, 51.97695885935138, 51.59430419245074, 58.34495036832748, 58.38509974941131, 55.53568217062182, 55.42976248648859, 58.61051836321431, 57.642300898028964, 54.577694246845866, 51.89854675723661, 51.27707073765417, 46.238456772219756, 45.69159207805511, 46.59624753459808, 47.3056552487035, 52.77140748116278, 58.351559562067834, 59.29950229583248, 62.62090259982694, 59.45945655145953, 60.155320321359945, 61.24913207946285, 60.79387826304282, 55.98603694669662, 58.0939971247027, 67.5926362314532, 62.13059848354709, 56.00718636666575, 48.75659096625544, 61.101082217308786, 65.3661184926187, 69.80013047495197, 54.71056453643307, 2.3788214114404496, 0.223168000699051, 5.917918653257432, 0.4489982488655275, 35.987977750839725, 66.42060064500379, 65.99811430900328, 69.77749055431735, 70.88961585875481, 73.88804035802042, 71.90314062180059, 56.8120135799531, 51.52046165158672, 51.607636328666445, 65.5900897518281, 45.97703472260506, 0.5374372161684499, 0.08164202839496636, 0.19559519395472544, 0.22899477352057734, 0.2306892067915009, 0.1885595037451675, 0.19554673123263544, 0.16921886333054112], [0.025317267695021246, 0.11770056125016944, 0.06673974135229666, 0.09675948655292874, 0.0758754471016507, 0.07607979339457328, 0.09468937908569652, 0.042839583099609425, 0.020949091807368304, 0.057649602512678796, 0.12483383573952223, 0.19658514809223915, 33.55928928621354, 55.544923274747795, 45.62810067207583, 42.578524543393044, 34.5391797250317, 56.1907022999179, 57.02440992478402, 57.84989233939879, 58.966751944634225, 56.58694797946561, 56.95205788458548, 56.22286573533089, 58.137064749194735, 2.546027639219838, 1.8402633167082265, 3.6919213639151667, 1.3877650879083143, 0.5248100647041875, 16.76523385509368, 73.33999110806373, 51.308904693972686, 64.16570455797257, 57.53092911935622, 63.91686547187067, 55.302481574396936, 57.751350633559696, 52.059654189694314, 55.816731760578776, 55.55848683080366, 57.08665009467833, 53.85156546869586, 56.64320261247697, 54.77140442017586, 55.342434836972146, 56.38350248336793, 48.51566722316127, 42.832290126431374, 43.03582583704303, 42.50513307509884, 43.60152967514531, 42.81012089021745, 45.87441767415693, 47.576945981671734, 51.29641586734403, 49.25857197853827, 51.097143773109686, 51.91469907760621, 48.347311250625125, 45.19926009639617, 44.12158889155234, 42.33519246501308, 42.428340911865234, 42.03485658091884, 43.943568198911606, 38.82312182457217, 40.45294115620275, 38.49627464048324, 39.22871058987033, 41.37892646174277, 46.03227346174179, 46.160982116576164, 53.59895306248819, 52.65708215775029, 53.19339959852157, 53.406976576774355, 54.9078126876585, 53.46695746144941, 53.24460221875099, 51.22598186615975, 54.79502885572372, 42.26615090523997, 38.940961591659054, 40.42015406393236, 40.451427121316236, 41.40046027398879, 41.62965613026773, 47.959392762953236, 45.639954074736565, 40.717583471728915, 43.03296642918741, 41.55743745065505, 43.30105258572487, 42.19597578048706, 41.3384436791943, 42.87385156077724, 50.45968801744523, 55.006268101353804, 57.70588644089238, 54.74758778848956, 54.722853322182935, 54.673949210874504, 54.017693534974136, 51.992436532051336, 49.664545136113325, 48.15634281404557, 41.55765318101452, 41.01412250149635, 44.94328621895083, 41.250131514764604, 40.40016958790441, 40.81598789461198, 42.12093299435031, 43.19939651796895, 40.23122525984242, 40.39563925035539, 39.566101104982444, 41.40019355281707, 47.42205942830732, 49.79897260665894, 53.0446280202558, 51.908431130070845, 50.310069207222234, 51.33442363431377, 53.93630827626875, 53.53067244252851, 50.36277801759782, 45.22388473633797, 46.89235118127639, 40.760572648817494, 42.85179999566848, 41.52643895918324, 41.543207091669885, 39.21779855605095, 45.39303302764893, 46.79715133482411, 52.328709171664336, 52.30350009856686, 55.880964494520626, 53.46861270166213, 58.30317712599232, 55.19043514805456, 41.47499707437331, 55.56115404252083, 62.337927126115375, 51.34623389090262, 44.06020772072577, 49.72230595927085, 59.00696408364081, 58.01625182551723, 48.59303205244003, 0.05442151484350043, 1.0979817278923527, 0.3142884289545398, 3.3751110348009297, 39.829817741147934, 47.67020425488872, 57.08513998216199, 54.35680204822172, 55.880042737530125, 59.88875604444935, 54.28915685222995, 36.44957011745822, 25.833826257336526, 33.99657472487419, 48.4976125532581, 9.16368438351539, 0.22526853717863562, 0.10077508196475045, 0.01611389722975512, 0.037040546491381623, 0.05803621261410656, 0.04365258241793321, 0.033013444438937216, 0.01940701044194641, 0.0672374380331847, 0.03416963582558017, 0.03651812432273742, 0.029588470257998958, 0.10068916520404239, 0.0411110244420988, 0.027858178326559645, 0.037072086331224254, 0.09195778533936509, 0.07979346589455683, 0.13501325201603676, 0.10598045022737597, 40.773512548015965, 62.49805004365983, 43.40057488410704, 35.8647172681747, 47.69009851640271, 61.193112788661836, 63.624692040105025, 62.12698990298856, 67.20713000143728, 62.78258662069998, 62.936492581521314, 59.80544882435953, 61.730269616650006, 2.4476362091879693, 0.8636556565761567, 4.839237438094232, 2.334935727619356, 0.5332781554710481, 19.99800036030431, 70.86784670429846, 52.46072438455398, 64.60247224377048, 59.77496808575046, 65.20408930317049, 58.03640496346259, 59.75791362024123, 54.791204544805716, 57.16143400438371, 55.074246698810214, 58.56944722513999, 57.5715531072309, 56.81979164000481, 53.94184274058188, 58.37764724608391, 59.06718815526655, 51.04900060161468, 43.18030241997012, 43.70156188164988, 43.01396646807271, 44.66991270742109, 45.20902287575507, 48.73868534641881, 49.54360277422013, 52.22544493213777, 50.82650023121988, 51.57572784731465, 51.888164243390484, 50.343550559013124, 48.52779519173407, 45.75264769215738, 43.33831510236187, 44.68391556893626, 45.64133082666705, 45.759021543687396, 41.155155243412146, 42.114688581035985, 40.16648654014834, 42.849972171168176, 44.395491923055346, 48.721921136302335, 48.73499047371649, 55.075172378170876, 54.04932745041386, 55.87634394245764, 55.40738536465553, 56.39554808216711, 55.48595828394736, 55.58201712946738, 54.81485251457461, 55.58171902933429, 43.45827294934181, 39.21061669626544, 41.89828749625914, 39.50956406131868, 41.89328255191926, 41.55510756277269, 51.55685340204547, 46.11001876092727, 41.340071462815814, 42.44211235354024, 40.289284183133034, 43.40013557864774, 40.28942146608907, 42.059704795960464, 42.92354406849031, 49.8625659942627, 56.23699019032141, 59.52763126742456, 57.40267545946183, 57.403632517783876, 56.89354396635487, 55.84803227455386, 52.90138306156282, 53.49943468647619, 48.71054626280262, 44.549546933943226, 44.70535916666831, 45.48655409966746, 43.64133781002414, 41.31777278838619, 43.472013012055434, 44.546801274822606, 46.073015120721635, 42.13585761285598, 41.82402526178668, 41.19517126391011, 42.753807421653505, 47.60203738366404, 51.19941957535283, 55.00011782492361, 52.277922322673184, 52.38473238483552, 53.59211637127785, 56.0714191006076, 54.52967659119637, 53.14753532409669, 49.14215210945376, 49.03584411067348, 44.57884703913043, 44.67130514883226, 43.20016138015255, 44.32865473531908, 42.25485840151387, 47.173028146066976, 48.93892234371555, 55.30083417892457, 55.05199117045249, 56.41837235419982, 55.69613848963092, 60.3679088623293, 56.78088957263578, 46.654196631523874, 57.52046031336631, 63.081824241145966, 54.76850186624835, 47.45764317051057, 52.500897299858835, 62.80533244532924, 61.57471233798612, 49.58562704824632, 0.1379783187181719, 1.1784359139780844, 1.8734870178084222, 4.0778928850927665, 45.722869057809156, 53.19978913953228, 62.523321874680065, 63.30529343697333, 61.64016885142173, 67.95976223484163, 57.8854682368617, 47.831417591341086, 28.69475599258177, 35.25086241383707, 60.601874320737785, 12.843625603183625, 0.2790053915833273, 0.04655474947104531, 0.03248638360791149, 0.07160724951855599, 0.050902459319801106, 0.03372834236811727, 0.06297286404597183, 0.05055338369622346, 0.19119833956562704, 0.22460967092023743, 0.14327623040205048, 0.14365032645723513, 0.2059316812383552, 0.15999879597896532, 0.20601863221776104, 0.16776242293417457, 0.16837981319235218, 0.12549581231489298, 0.2908318585926487, 0.23594460059558195, 48.760536870648785, 71.20856731168686, 56.21547991229642, 52.971130647966945, 49.72083507045623, 69.90143745176255, 70.43902966283983, 69.92766241873466, 70.2698499925675, 68.74852734227335, 68.29870993091215, 66.2324994610202, 69.38846988062706, 3.5255993854614998, 5.3701287700283915, 14.026290812800008, 5.984985789945049, 1.0859818492204913, 24.06447252919597, 71.79022342927995, 52.72471166426136, 68.36461359454741, 62.82847835171608, 68.44566545178814, 59.51831956063548, 62.42303471411429, 56.04303290767055, 60.52820436416134, 58.27752482506537, 61.740844326634566, 57.81561866883309, 59.40337058036559, 56.431877074703095, 59.21910155204035, 62.70253104548301, 53.68626502252395, 47.2466863355329, 47.62009989830756, 46.78265425466722, 47.706548936905406, 48.17898665705035, 50.07973194122315, 51.678682219597604, 54.56260096642279, 53.85304027988065, 54.58863373725645, 56.183869531077725, 53.725331829440215, 48.244800106171645, 48.48003249014578, 46.340222666340495, 46.640468335920765, 47.23528792781215, 47.81300206338206, 43.67092817060409, 45.80175184434461, 43.106377509332475, 45.429350253074404, 46.324031122269176, 52.30947779070947, 53.126554566044966, 59.100049772570216, 55.08210320626536, 59.549698522014005, 55.967719477991906, 59.801251888275154, 58.20480015970046, 57.50683792175786, 56.54764583033901, 57.38062781672324, 42.717027356547696, 39.987814734059, 41.13340177843648, 39.447508242822465, 43.09151564874957, 41.19543798508183, 55.508500145327666, 47.09550249961115, 40.819706301535334, 43.12880169960761, 40.26442027861073, 43.3201466837237, 41.96861167107859, 42.94853741122831, 43.204417151789514, 50.09931633549352, 59.12892626177881, 63.34993785427463, 58.17438217901415, 59.49395771949523, 59.99254195920883, 59.29743912912185, 55.71613865513956, 57.397462629502826, 53.41695508649273, 47.22099481090423, 45.38052066679924, 49.754987147546586, 46.36948354782597, 43.683526823597575, 44.47351963289323, 47.00641762825751, 48.18854547316029, 43.299118857229914, 44.44543546245944, 42.95051428579515, 43.857836954055294, 50.77540743735529, 52.41813921159314, 56.68618394482521, 56.24655292880151, 54.90898155396985, 56.12384550033077, 58.38862596019622, 57.76170569081461, 54.39628462637625, 50.481590532487445, 51.30925770728819, 46.82452947862687, 46.95222223958662, 45.46407107383975, 47.9031930431243, 44.572186854577836, 50.16336864040744, 52.62955888625115, 56.400388286959746, 56.421627921442834, 58.71173512551093, 58.31100617685626, 65.28108935202322, 57.31807385721515, 46.892896390730336, 60.69386566838911, 66.39360689347791, 56.90345971815048, 49.36705297039401, 55.89713250437091, 68.2411922947053, 60.994009356344904, 55.662661060210205, 0.2958893259206126, 2.4890968876500286, 3.3450095403578977, 3.565985824792616, 53.04604007351784, 57.74747925419962, 71.65686284342121, 67.09305178734564, 72.31378924462103, 72.93504561147383, 67.61576252598917, 47.62619918392551, 35.36135950396138, 43.67359930469144, 68.2549362797891, 21.105208973730765, 0.3689289453529543, 0.19221219564637831, 0.23293951346028238, 0.12589056210051622, 0.11930779839355139, 0.10862336163559269, 0.16711386821923718, 0.1422417512343776], [0.036459388361582835, 0.0208858244361416, 0.06900160828785551, 0.060265233529911894, 0.04701467418682672, 0.011041833054003938, 0.018031763874234694, 0.03351309081359256, 0.07036379688689787, 0.12718281453295102, 0.11253184263384151, 0.3274285835364173, 14.083677049606079, 55.26464246934461, 48.1946643706291, 43.264939323548354, 33.88847028055499, 50.23227291722452, 58.391759933963904, 66.24829092333394, 58.09627994414299, 57.83996482049265, 53.01315884436331, 44.715576940967196, 63.80355211996264, 12.37420810807136, 1.0890267116408194, 3.254720501361355, 2.0334143071405353, 0.5930740145906326, 17.22385306512156, 46.77375439674624, 53.80780358468333, 59.28502482752646, 61.58325526022143, 61.93710796294674, 58.92973653731808, 58.11660566637593, 55.16892879239975, 54.85810449046474, 55.27526817014141, 57.83895677135837, 57.038444165260564, 60.77401145812004, 58.74884466971121, 56.9154151024357, 49.82125951397804, 43.344167278658965, 39.276288940060525, 41.519884678625296, 41.879071804784964, 42.19198280765165, 46.65671087080433, 50.90764230297458, 49.85312484925794, 52.54028966349941, 51.55617875437583, 53.29972720915272, 50.71432828903199, 52.89092602268342, 46.53159902941796, 43.55684603414228, 42.39349065288421, 41.41115657744869, 39.85374419919906, 40.171456183156664, 39.25070724179668, 40.981103989385794, 38.375963780187796, 39.816050221843106, 42.26567629844912, 47.183747983747914, 51.97682549876552, 53.175062517966, 52.428192246344786, 53.60542105090234, 51.548498753578436, 51.09555913556007, 53.26904642966486, 53.108852909457305, 55.745297555000555, 53.59824703585718, 43.25316436829106, 41.37703587931972, 41.53713526264314, 43.14979422476984, 41.12458036791894, 42.7701872394931, 47.2296985503166, 46.40239615594187, 41.37835771806779, 43.41760973776541, 42.80854801977835, 44.45007954874347, 42.889529274355986, 44.125523028835175, 44.47860302463655, 49.380561613267474, 54.69960935654179, 54.81635870472078, 56.62780338718046, 53.30431245988416, 51.82741065179148, 52.97140913624918, 53.241813413558475, 51.32972071247717, 49.246726420617875, 44.54296127442391, 43.01334281121531, 43.28723799797797, 40.665812107824514, 37.804592117186516, 36.18640653548702, 38.946343083535474, 41.73469328111218, 41.07036928976736, 37.641107728404386, 39.83913337030719, 42.82902671444801, 47.44684880779636, 47.67132997512818, 52.638992186515566, 48.2249568354699, 51.19686611237065, 53.37842172191989, 51.27932610050325, 50.97404802999189, 50.36341344156573, 46.149924955060406, 43.46761603509226, 40.978091609093454, 42.35301571507608, 38.952403145451704, 40.24039183893512, 39.10117080134731, 41.06846694023379, 39.01443542972688, 40.10207729954874, 44.633642550437685, 46.1743377870129, 52.56620868559807, 55.20188454658755, 56.909511935326364, 57.67711193330827, 51.667323035578576, 56.309361842370805, 56.76285843695364, 49.346154582115915, 51.92794884404829, 56.29448036993704, 63.95161374922722, 37.61520831815658, 0.8460884024539302, 4.3464102572010415, 1.5829500724231045, 14.197876857173059, 57.91939281648206, 49.683482339305264, 56.3505506515503, 57.410320158927675, 57.704537145553104, 60.832537143461174, 48.48424511571085, 33.018076727467204, 37.3452276568259, 34.67321103618991, 48.8287704221664, 2.8115269926286515, 0.14850281930017858, 0.015334589500731279, 0.04819588217463705, 0.06609856406407011, 0.017089132903023593, 0.11220905914782517, 0.042833718696549054, 0.08817960823615713, 0.03848646083966859, 0.052120719150069265, 0.05624301528798477, 0.04252018189177879, 0.06684866373337085, 0.04361245090201978, 0.11471030557708395, 0.03151146011547216, 0.073870541377654, 0.005304050920981794, 0.1800118777300081, 0.3371162862787324, 19.907258287552867, 65.60679904876217, 48.09645998862482, 41.44053120766917, 44.71224292632073, 56.55143876229563, 65.02394660826653, 72.51884291248938, 64.52743730237408, 61.89525627320813, 60.766288311250754, 50.719082201680834, 68.59266019636586, 12.916247306331513, 1.5469445528522616, 2.998273978310247, 5.622262156778767, 2.7208614060955667, 21.420022326131022, 48.86815494106662, 55.35984623816706, 62.203436897647, 60.94492089363837, 62.134720894598196, 59.56500753279656, 60.103792144406235, 56.95959668005667, 57.021970210536836, 57.3360461573447, 60.32433525208504, 60.13482201483942, 62.509754396254024, 61.275851265076675, 59.29674094723117, 51.69241835994106, 46.053313055346095, 42.534323353921216, 43.09160978563371, 43.32344931940879, 43.5505388629052, 48.03140747931696, 52.91801391109344, 49.5580880872665, 56.01004577452137, 53.0369637089391, 54.68666945734332, 52.85023535451582, 53.95703015788909, 47.764156787626206, 46.59030906615719, 44.57050023540374, 43.057975461406095, 42.06003427505493, 41.30148710743074, 41.61096211402647, 41.68117254011093, 40.75387324056318, 41.877891171363096, 43.04450211986419, 47.6492940995001, 52.87757819698703, 55.69173759029758, 55.089700837289136, 54.95669718711607, 54.19891095930531, 55.833331231148016, 55.360101192228264, 56.23915926102669, 56.94763737340128, 54.768121396341634, 44.281445087925086, 40.1875888916754, 41.93123148333642, 42.489863288018014, 42.10036016279652, 42.370697759812884, 50.32507227313135, 48.16305791178058, 39.499903263584265, 44.63077922021189, 42.760510752277995, 44.730697677981475, 43.66608012107111, 43.732662354746175, 43.79563993023288, 49.47617723095802, 56.665211031513834, 57.40729993389499, 56.73863387876942, 56.16297898753997, 55.02292248510546, 55.92782505096928, 55.20156683460359, 53.37406004628828, 51.00615655222247, 46.883925930146255, 44.97982309710595, 44.6258056548334, 43.37021181660314, 39.2874716174218, 39.126407331035985, 41.074864325984834, 43.32196274111348, 42.35718127219908, 40.40516668750394, 42.07322912831461, 45.9350771288718, 50.049776800217174, 49.19884212555424, 52.83729153294718, 51.867532576284106, 54.03244949156239, 53.89884571875296, 52.38102966739286, 52.57057428359986, 50.31764722639515, 46.83879906131376, 46.14838738595286, 43.986780951100016, 43.90503875670895, 41.84483343555082, 41.37517667585804, 41.41235682272142, 43.81901333408971, 41.05684103504304, 40.962864968084524, 46.769914396347545, 48.84394999473326, 54.46633031291347, 58.181313007108635, 58.93577698738345, 60.03703732644359, 55.55332891402706, 59.4464264377471, 59.666079167396795, 51.65943122679188, 55.05827480746854, 60.36814420453964, 67.14576844246157, 39.05223138870732, 1.315039074228656, 5.666228494336528, 2.0841670805408112, 17.177333754877893, 59.316878395695845, 54.77912364467498, 62.73504749421151, 61.22765318039925, 68.11365250618228, 69.3199460737167, 51.192900596126435, 44.78640710153888, 34.64515824471751, 37.47850195054085, 57.41394442896689, 4.522759039555827, 0.2402359646775069, 0.03152057273133147, 0.016983320838921977, 0.02183323579600021, 0.0839609305764879, 0.02610872845135389, 0.01593110769341189, 0.019026253252260147, 0.15401333570480347, 0.10952082597800802, 0.1603711300319241, 0.13900861504577822, 0.15256667059035073, 0.18205534065923384, 0.28187393120700316, 0.09061854107365494, 0.186246408510112, 0.40557359675726584, 0.30673584390071135, 0.6318932218897728, 22.665004191860078, 74.62335140474381, 60.977374584444114, 56.252864022408765, 44.98864058525332, 63.55210858006632, 70.69593706438619, 79.05746536870157, 67.69131522024831, 71.21818496334937, 67.70109761145808, 56.914163866350734, 73.68073524967318, 16.201837351245267, 3.6198122655191733, 13.970253871333215, 9.213572029144533, 6.74646738075441, 25.897237254727273, 53.65404275155837, 54.655427778920824, 65.33544948024135, 62.82357146663051, 64.48473838067824, 61.79072118574574, 63.281288531518754, 58.75050775466427, 58.64445863231536, 57.54082918167115, 63.09538779720184, 62.65560380874142, 67.62275218963623, 63.181122964428326, 62.7140235900879, 52.46625100412677, 47.44142809221822, 43.066012397889175, 46.783819198608406, 45.836162797866336, 46.297417840650006, 50.8807623001837, 55.723618615058164, 51.99909279423376, 56.905711158629394, 53.5987961676813, 56.833064940667924, 54.32064563997331, 57.21530383633029, 50.63328427653159, 49.30835077839513, 47.564767022286695, 46.587214316091234, 44.96741271788075, 44.51441818667997, 43.93249142554499, 44.89402517195671, 40.739231032709924, 44.006592842840384, 46.09688274322018, 52.45102436311784, 56.52053833007813, 60.35165063796505, 56.703469830174605, 58.21799109058996, 54.32215183011947, 56.480883167636016, 58.11352268342049, 58.53553441263015, 60.45040022942328, 56.97334066514046, 44.27159993879257, 41.42168029662102, 41.470682467183764, 42.642059095444225, 40.581092834472656, 43.05687327538767, 54.296209273799775, 49.74169423503261, 39.340894299168745, 44.89333091243621, 43.116203046614125, 45.47727769420993, 42.099371725513095, 45.72867416566419, 44.38063006247244, 49.565764165693714, 58.531639499049035, 58.89742012946837, 60.93145931920698, 59.482021947060865, 58.00877971033896, 58.29294758458292, 60.21086500537012, 55.942294674534956, 54.11982028715072, 48.888645402846805, 47.755578564059356, 48.89270505597515, 45.24419476909023, 42.51499391371205, 42.05030679702759, 42.61028005230812, 44.87215795824605, 44.99563024890038, 43.26019325563985, 44.334754020937034, 48.33619525355678, 52.94225808112852, 51.274070124472345, 56.01006538637223, 52.921712706165934, 55.21766816416095, 58.87650605170958, 54.70257466839206, 55.2962097044914, 53.11556800719231, 51.350787762672674, 49.05300055780719, 45.095529094819106, 47.3955677401635, 43.21151664180141, 44.46950312583677, 43.648174501234486, 47.344000339508064, 42.99333480096633, 43.57956832455051, 49.25904266295895, 50.228895756506155, 56.73138533869098, 61.117999399861986, 61.52590236356182, 58.23990537274269, 55.99170869396579, 62.833102826149236, 62.92923619670253, 54.41157794767811, 58.98718357086182, 63.45634783467939, 69.21731333578788, 44.97002893878568, 1.9498996917278537, 8.129164643826025, 3.5665834959476226, 17.63349952236299, 71.97922675840317, 60.64239240461781, 68.071330132023, 67.19800656841647, 70.3605979488742, 71.56737004556965, 61.72659043342837, 47.3727003220589, 49.14707076164984, 47.9404555597613, 70.31480819948258, 7.007476110612193, 0.5078679996152078, 0.20122675225138667, 0.13277524871931923, 0.11993247414788893, 0.22868090729799964, 0.1927650200142976, 0.14349520897432683, 0.11894629682384192], [0.03483950310657102, 0.0653502417187537, 0.0487551263593618, 0.06003387114633957, 0.02777504246501673, 0.08083023566512332, 0.02954403332795107, 0.040988120956406485, 0.0038479227054443576, 0.055396603044843486, 0.0852852744320708, 0.11838951944223336, 1.2030343230693572, 45.18883835884833, 53.22353124618531, 32.38742040049645, 24.14042922758287, 45.907196921686975, 48.28361980376705, 56.17270254319715, 57.52637524758616, 59.530710328009825, 54.71522038982761, 54.64234667439615, 58.4004597510061, 28.721977241577644, 1.1532778316928496, 1.0920106547494088, 1.9261824676106054, 13.974479244601342, 34.53803831531156, 47.06721436592841, 60.1299229744942, 61.23808276268744, 60.63404952326129, 57.71063250880088, 57.49053655132171, 58.32156519736014, 58.318427301222286, 58.90778303146363, 58.60688624843475, 57.74780481092392, 56.25940653585619, 55.64568896447459, 52.40712911851945, 48.26934237633982, 43.591355046918316, 40.985042049038796, 41.75075146459764, 41.648067735856586, 40.252076579678445, 44.73391402152277, 48.06831306026828, 50.8502854839448, 54.27031378592215, 54.63673768504974, 53.581208259828635, 54.4542258785617, 56.85728165411181, 53.95180556081957, 48.85093573601016, 43.8661680683013, 42.20919809033794, 42.77385857797439, 44.137949097541075, 41.05589966620169, 39.52851303162114, 38.99589830829252, 40.848261156389796, 42.227413577418176, 44.10532674481792, 52.2677476944462, 53.281088106093875, 53.603153920942745, 53.04886810241207, 56.016709881444136, 51.87219235204881, 51.81787929227276, 54.49258273647678, 55.13945610292497, 55.928358493312714, 50.86606910151821, 44.570923851382354, 42.79266242058047, 41.72680539469565, 41.37903236573742, 42.931800657703036, 43.13703867696947, 46.882360904447495, 46.63755401488274, 41.386833960010165, 42.140109462122766, 43.31533785789244, 44.563985178547526, 42.70585252392677, 44.158416025100216, 43.436911721383375, 49.892015149516446, 53.350514058143865, 55.07729045806393, 51.34875989729359, 54.33802173983667, 52.86508152561804, 53.86660775830669, 50.8387811722294, 51.59766566368842, 51.90385764644992, 47.635722698703894, 42.43628763383435, 40.65098554857316, 40.16431746944305, 39.056683278852894, 36.53912567323254, 39.079891943162494, 39.98397865603047, 39.27465331169867, 40.45302352597637, 40.870516684747514, 45.31309512353713, 46.48143191491404, 48.88990448367212, 52.36266905261625, 52.405140476842085, 49.78238490320022, 50.9589861285302, 48.52321778574298, 48.55849950544296, 46.14492785546088, 41.75870210893693, 41.634845426005704, 40.057103403152965, 38.55747538228189, 39.1518517463438, 40.421460213199744, 39.59689955557547, 40.66398820569439, 39.66149314757317, 43.472032623906294, 41.57032635904128, 46.30818866914319, 49.658449772865545, 56.430410108258656, 54.55488566429385, 61.575649784457305, 58.34507980654317, 57.32061947545698, 57.007312313202895, 54.60503708931708, 51.072613270052024, 60.264248463415335, 57.19412303739979, 39.9541647203507, 3.9354181818423735, 0.9231166433422797, 0.6098162226619259, 23.942833946597194, 59.68088611479729, 51.639478129725305, 52.3224804478307, 55.372103644955544, 43.22631574446156, 43.43704900433941, 47.21735485138432, 30.43609615295164, 19.59825788774798, 41.287747044717115, 36.77795094828452, 0.3125578363335902, 0.0718989068522088, 0.041656482874626116, 0.007688415794438052, 0.039484822792151285, 0.0246491183662006, 0.06191442164802744, 0.07502941790247157, 0.023134909194683837, 0.06854963939516776, 0.06256824704788386, 0.07668645842181099, 0.040562398236004577, 0.02255143747935372, 0.01451895388233806, 0.04211740733514871, 0.042510896906136506, 0.07643396350284738, 0.04258727970262689, 0.08935617373114632, 0.2239151968951187, 2.7454421645210636, 55.2681137669471, 53.91706120583319, 32.99858254771079, 37.73353445914484, 49.83885526657105, 54.3472549992223, 62.70313116811938, 61.796989133281095, 66.63187519196542, 58.81565440085627, 57.843651848454634, 63.42893046717491, 30.665984307566, 0.5077882958275657, 1.0907270591105185, 3.5348149941813563, 18.78302266520839, 38.81263340673139, 47.568759995122115, 60.77566277596259, 64.34578841732394, 63.77880980891567, 61.541564387659875, 59.15196626417099, 61.72053429388232, 60.80749280991093, 61.54485133386428, 60.750104611919774, 59.33338372938095, 58.62498014203964, 57.43548608595326, 55.169819170428866, 52.298867779393355, 46.55044209572577, 42.9668862588944, 42.750120393691525, 44.64932810875678, 42.25637635877056, 45.26048829478603, 49.46429637170608, 53.06917813516433, 56.08280181884766, 55.74931798442718, 55.34862433710406, 55.28159103085918, 59.261467072271536, 55.40310605879753, 49.5610494767466, 45.945651838856364, 44.04111754509711, 43.664895565279075, 43.22066753141342, 41.09815928243822, 41.12297219614829, 42.585369079343735, 41.82310350479619, 45.38694158677132, 48.307044198436124, 53.065616623047866, 54.95223745223015, 54.94801305955457, 53.864717175883634, 55.677726884042066, 54.19827161296722, 54.33669205634825, 57.267208560820556, 56.89812137234596, 56.96749633358371, 53.763449422774784, 43.56396121363486, 43.102757161663426, 39.26153690584245, 40.71428083604382, 44.54598934419694, 43.391251410207445, 49.60253638605918, 48.18248148887388, 39.934356750980506, 41.46334763496153, 42.83737744054487, 45.11238744181972, 42.9938917775308, 45.03563842465801, 42.39497330880935, 50.875043484472464, 54.57643124365038, 57.72438433862502, 53.60740184783936, 56.58783051275439, 54.75192200752997, 57.089889972440666, 54.08473860832953, 54.73742492737309, 53.99941136760097, 49.22220376230056, 44.737118597953554, 44.51577532675959, 41.80575486152403, 41.92205705950337, 39.89813758480934, 41.15451981944423, 42.633665223275464, 42.12661650873, 41.32988898984848, 42.6551676565601, 45.57592530404368, 48.74931496958579, 51.4779313918083, 54.14048725558866, 54.3761864016133, 53.36930221126926, 53.78102556351693, 50.68319643697431, 48.19305227648828, 47.72778072664815, 43.12345158669257, 45.54701743587371, 43.07609288923202, 39.35499521993822, 41.071204754614065, 42.1107897450847, 41.55042817515712, 43.524141311645515, 41.148012607328354, 45.55039459659208, 43.78476712011522, 48.87935330790859, 52.04865194136097, 58.0826065617223, 57.58433611162248, 64.17732261842298, 58.13393469779723, 60.65917230421498, 58.66892637745027, 58.066822944148896, 55.767604074170514, 64.47313993207871, 58.016495012467914, 45.516011099661554, 3.979736552123101, 1.3527931128778767, 0.20235948985622776, 28.199719536689024, 66.43954569293608, 56.82813452136133, 60.0155701944905, 61.78329613900954, 51.59779902427427, 49.44054249794253, 54.42195653915406, 41.09142849522252, 20.5633060778341, 46.44927240187123, 45.861771952721384, 0.4922155669379619, 0.01689197059961096, 0.061653327392113794, 0.08956386016741877, 0.0619146821179217, 0.04537698887889424, 0.062060154553863316, 0.07306320727953027, 0.03559163673931072, 0.24165143469168296, 0.15573807541401158, 0.21170138050952267, 0.12409434638797276, 0.17470416012069873, 0.12486341439427869, 0.05701016807447999, 0.22608270478104392, 0.15707980180459638, 0.22795209721211465, 0.23116868590154957, 0.3330019344725917, 3.410193939362803, 65.32201144003099, 65.13084296257266, 43.25387431729225, 36.98420486142559, 60.26750010828818, 60.59559460609191, 69.84201354365196, 68.41098385472452, 71.00585922118157, 64.3955829066615, 66.6248070809149, 67.57996697579661, 36.6222720761453, 2.0160868691821254, 8.294206703862837, 4.901924758188186, 26.10703502931903, 46.22505795571112, 51.08298009441745, 64.79140889260077, 65.72118320772725, 67.39447024560744, 63.50519703280542, 61.275227608219275, 63.64047565767842, 62.654431020059896, 64.46675823580834, 63.963055303019864, 62.047667810993815, 61.2690184962365, 60.661455123655266, 57.62815290881742, 54.59776501501761, 47.84947226124425, 44.12266362097956, 44.542039517433416, 46.3396264660743, 44.79057265866188, 50.308402199899, 53.73571826565651, 54.640612986779985, 57.55475751815304, 58.369096479108265, 56.027159075583185, 57.76161155393047, 61.106416640743134, 59.17805394818706, 52.959241943974654, 48.705694290899466, 46.1367065675797, 47.33110358638149, 46.4303469657898, 43.93853579798053, 43.1523084640503, 44.21483147528864, 46.648826906757975, 48.37226144729122, 52.244652778871604, 57.33599124416229, 58.475357409446474, 57.503598043995524, 56.86041562787948, 59.19419842381632, 56.13390245745259, 57.51391387754872, 58.79621513428227, 59.54068491535803, 59.01576980467766, 55.585963033860736, 44.07655615960398, 43.13361052543887, 41.08967911812567, 39.51058779993365, 43.6383254297318, 44.78574814334993, 53.15640380305629, 49.45519255053613, 41.554064212306855, 42.16260033269083, 43.89589963420745, 44.94557296076129, 43.52151332363006, 44.5215686675041, 42.57132307175667, 51.65863890801707, 57.3494920422954, 59.47467142535795, 55.21904099372126, 58.95541629483623, 58.07197693855532, 62.060109569180405, 56.15897816996421, 57.82998631077429, 57.14748997842112, 53.38432488902923, 47.851335387076105, 47.84694233248311, 42.65383405070151, 42.55778304992184, 41.897718752584154, 43.082968804144095, 44.47942280000256, 43.45554690207205, 44.695737592635616, 46.63216467826597, 49.5473054916628, 51.8054610683072, 52.635520888913064, 56.78650248435236, 55.60948548778411, 55.42265515173636, 56.22970242654124, 53.50060355278754, 52.0400619506836, 49.39112455614152, 46.18167261923514, 47.474893754528416, 45.69754231360651, 41.1305659048019, 43.172912674565474, 45.26391252394646, 43.11114318909184, 45.93538699611541, 44.35795484050628, 49.07960991705618, 46.23975115437662, 49.92451198639409, 54.09064177543887, 61.927200055891475, 60.17712085477768, 63.332291110869384, 59.4969504879367, 63.54046306302471, 63.03120605407223, 60.63488891047817, 57.17717055351504, 67.76986460531911, 62.94403922173285, 47.72388973543721, 8.431632826405188, 2.570357365954307, 1.313148246657464, 32.27200269699097, 74.14764635024532, 62.79715038114979, 65.05985982956426, 65.8070085894677, 57.874830768954375, 55.57937737434141, 58.94188411774174, 43.63969433692194, 29.791168282108924, 55.89937610010947, 56.17592673147879, 0.9125204828958359, 0.17741540657176127, 0.25579000102175825, 0.17532544210553172, 0.2047966913350167, 0.14973712484202079, 0.15408452059472763, 0.20473564944921002, 0.08137997269870774], [0.045003693385590474, 0.03153080383556024, 0.027686212654976596, 0.010479162541037847, 0.0757091983612026, 0.024263203489564122, 0.06071292382154254, 0.02762268098341602, 0.06715473884175863, 0.022520336224847746, 0.08164247272596245, 0.09416565073714142, 0.11944354917373388, 32.1485068721156, 61.09904650718936, 34.65645467081378, 29.2039208258352, 43.19588599666473, 58.5735970927823, 63.57677636608001, 63.20609277294528, 56.902341842651374, 60.55175427467593, 55.11850672383463, 57.14085332808956, 42.64848786015665, 0.11808817875721764, 2.080246916701717, 0.9996541589498521, 16.243557641583106, 22.086052548500803, 53.896264799179576, 66.32258061439761, 58.904672591916984, 59.53252246302944, 53.158627786943995, 60.45439712462887, 53.298472050697576, 57.918506360823116, 56.17593065384896, 56.27196204277777, 51.706048596289854, 52.627099560153106, 45.884247133808756, 45.102201046482215, 41.48637979261337, 42.496099856592, 42.291363900707616, 43.580089999783425, 42.079763797021684, 42.312701594445016, 42.365406482450425, 47.89299488067628, 48.244074467689764, 53.924619613155244, 52.016967035109005, 54.6965616749179, 44.41487627644693, 46.3662632819145, 59.58404671761298, 48.893156128544966, 46.13940123588809, 43.67806688431771, 42.38880734289847, 40.642156293315274, 40.88735934226744, 41.18506331597605, 40.75177085015082, 39.9114187302128, 42.770387280371885, 46.73515827425065, 52.93504092001146, 52.83943706943143, 52.944336937319854, 53.937865457227154, 51.794796143808675, 56.60884657213765, 54.05813709382088, 54.03062558943226, 51.203008544060495, 52.03587285933956, 45.45322572031329, 38.66536017387144, 41.75273618390484, 41.43237267771075, 41.30909258319486, 42.16904870925411, 43.18900223701231, 46.64910539504021, 47.061158226382354, 43.857460406518754, 42.223169572891734, 42.02310123751241, 43.69007718178534, 42.38158625941123, 42.82493568235829, 42.264872212563795, 46.84539256557342, 51.96850222925986, 54.568802233665224, 53.84427378254553, 53.15104584540091, 52.05208793763192, 51.536676729879076, 51.32028741221274, 53.004470794431626, 51.068137845685406, 49.868873165499785, 46.935681604569965, 39.57889587648454, 39.25534740571053, 40.72525955015614, 39.13926878283101, 38.69882191381147, 39.5393426956669, 39.13142404248638, 38.267019948651715, 41.069388697224284, 42.00428955016598, 47.32630652766074, 47.09394924102291, 48.34619729749618, 48.678971182915475, 47.906460377477835, 45.95444187041252, 43.00326231987246, 40.256049940663004, 39.64595663932062, 42.20262812029931, 40.28755834025722, 38.512368125300256, 41.235920767630304, 40.49277282530262, 39.291209636196015, 39.949975629006666, 42.12795795932893, 46.11050121245846, 48.785490989685066, 50.69842307798324, 51.605941864752005, 51.63836809896654, 53.34031197332567, 55.561930671814956, 58.40138935273694, 54.7246576124622, 56.78084642656388, 56.49107740771387, 56.17992362668438, 56.26902810988888, 60.42555201438166, 58.274700718541304, 18.424751412483957, 1.0538252779553015, 1.9692862514526615, 0.44891382597627183, 30.96150548227372, 53.6924623673962, 53.10746046804613, 53.902262103173044, 53.044243627978915, 50.183451175689704, 52.36632077924667, 40.246420521889966, 30.448377093961163, 30.099139059743575, 55.277790254162205, 16.088213151501073, 0.19699855977969785, 0.09063167948155634, 0.060308509836754495, 0.049864153542946425, 0.049166894788222934, 0.008356990780861629, 0.02318375304551615, 0.00888168344259142, 0.05921066370642474, 0.058613942500444195, 0.03879924304783344, 0.07358436923353903, 0.010788513632911828, 0.02874409963917588, 0.032440866493890365, 0.02822678919220644, 0.04383866900518056, 0.03598169806683737, 0.029657347308051203, 0.07566081224790505, 0.049140054897795764, 0.21305383213104742, 40.100178872385335, 68.5242069921186, 37.6399584739439, 39.4410284872978, 53.79862131610994, 58.806389762509255, 69.80097770690918, 67.80068659013318, 62.54863292940202, 65.04719449627784, 61.420774998203406, 60.17773666689473, 46.299237820409964, 0.09044766516214417, 2.2208646228236537, 0.972267618823436, 19.238553008725567, 27.439193533312892, 55.541961885267696, 68.65910514708489, 59.702055146617276, 62.77493407649379, 55.922314120877175, 60.32189161546769, 56.96048313571561, 61.28078168438327, 56.09598490499682, 59.42232739540839, 53.959058023268184, 54.933241413485625, 48.64940827892673, 49.79268112490254, 44.35407561640586, 44.29178053332914, 43.76566909974621, 45.26145712021859, 44.054743859075735, 44.16519388075798, 44.66442138917985, 49.649020394971295, 51.87025470118369, 56.61166675629155, 52.55726175923502, 56.04361734082622, 46.400478116927616, 49.29370857054188, 60.09601408435453, 50.83618456317533, 46.66001742885959, 45.129940048340835, 43.34116666547714, 43.79924066605107, 41.023908815076275, 41.81612560825963, 44.299829236922726, 41.928219103044086, 44.110669012992616, 48.430963639290106, 54.09299911991243, 53.44155226984332, 54.419846304001354, 55.497270399524325, 54.87566101935602, 57.89753344751174, 57.03711055940198, 55.746454654201386, 53.99293945681665, 53.75108218962147, 46.297025603632775, 40.186537696469216, 41.427877641493275, 41.90311593394126, 41.735446376185266, 42.50910251371322, 44.60715478466403, 50.16476892655896, 47.64628171920777, 42.51567248375186, 41.876537953653646, 43.503317448400686, 43.55879545211793, 42.181670896468624, 42.797467324041556, 43.40595245361329, 48.468814511452955, 53.455841464381066, 55.45595215212915, 54.92918568272745, 56.68834124841998, 54.83887310950987, 53.168684744065814, 53.6230952508988, 54.228175763160955, 52.68885335614605, 51.84220975445163, 48.985790744904556, 41.19038204992972, 41.81506656831311, 43.57659124558972, 40.835748795540106, 40.61657459505143, 40.663796009555945, 40.04244158344884, 39.85472871411232, 42.939288462361986, 42.95028678832516, 49.00405722279703, 50.39450214755151, 50.94295540163594, 50.26050221535468, 50.53606833181074, 47.998098711813654, 45.9127196188896, 43.1183328936177, 41.7869863202495, 42.83283533588533, 42.45629564408333, 40.77790560260896, 42.49652739494078, 41.45243952351232, 42.283479936661266, 41.84353120865361, 44.800923793546616, 49.426684764123735, 51.434028302469564, 53.41247181738577, 54.07227331592191, 53.399327954938336, 56.239959424541844, 57.537950161964666, 61.23931830929172, 56.803717767038655, 58.126831285415165, 60.047243333631954, 60.42772108508695, 59.74524044221448, 62.51117037188623, 60.28711588151994, 19.658052459839855, 2.0785249961960703, 2.7324453909550948, 0.3084824630810369, 36.90317653840588, 60.042571790756725, 59.823829050987, 60.71069263642835, 55.871193870421386, 55.715487541690955, 53.29528708611765, 50.61410780875914, 30.67168547261146, 23.60890296197707, 63.11299531690536, 20.228543550737445, 0.1748777096790652, 0.08014612680962009, 0.029165520775882952, 0.019037162344301903, 0.09381871249887253, 0.08405994744070115, 0.02457103102407869, 0.07266613624749646, 0.017077580297125444, 0.22789309312018657, 0.19684206333852586, 0.183667159008403, 0.11238709032054871, 0.15083299829594551, 0.16268978706530987, 0.14191335998475552, 0.21917277556513587, 0.19310122536074734, 0.18008655598086698, 0.1480651839125541, 0.3263591247941217, 0.28741768050578337, 50.57578232980544, 76.20343116021927, 47.159017439811464, 38.36316116394536, 56.172529958909564, 68.73505792310162, 76.58335193510979, 72.97410457364975, 71.65715309881395, 70.83352596529069, 67.19671218625962, 66.05948371271934, 53.54948805224512, 0.2853996823391607, 7.593344853770349, 2.5374913359841993, 20.10109986028364, 34.82275139900946, 57.894160209163545, 69.2577451275241, 62.92109727859498, 66.07270994494039, 57.04512003929385, 65.29032653377902, 57.93695719011369, 63.82255992581768, 59.965948289440526, 62.08789563948109, 56.188772493793124, 57.895811527006096, 50.86055424905593, 50.63348431741038, 45.79790399920556, 48.079444746817316, 46.19920953627556, 47.963421037120206, 46.02676645401986, 47.43943160580051, 47.645383496438306, 50.61182106694868, 54.02424781553207, 59.30406793471306, 55.31244047226445, 55.77923390173144, 47.794790498672, 50.75277143909086, 62.705935662792584, 54.87464904785157, 49.59125172707343, 47.20592506470219, 45.12845347004552, 45.673447193637976, 43.391290633909165, 44.55396352275726, 46.1730630167069, 44.848560979289395, 48.61670355642996, 50.306429247702326, 57.31585379569762, 55.35827336772796, 57.227918178804465, 58.07850768489223, 57.086171565517304, 62.240546441847286, 60.345186571921076, 58.733829836691584, 57.017369270324714, 55.27402085642661, 46.3396970687374, 38.880823812177105, 43.046455460210005, 41.89742065245106, 41.37548654310165, 42.900672728015536, 46.03312069369901, 53.842104711840236, 49.009791727988954, 43.99700264776907, 42.529745947930124, 43.48002641431747, 44.4783127692438, 42.4193782960215, 43.43308348809519, 41.72133368830527, 46.68235140462076, 56.180872840266076, 57.024927677646765, 57.785942016109345, 59.90428863033172, 56.38802105380643, 55.62942289537, 55.69040006206882, 58.302082784714244, 55.03360309908467, 54.13058719327373, 52.49293488840903, 43.88909039958831, 43.797467754733184, 46.34968342319612, 42.70161244177049, 43.94416047680763, 42.721275283444314, 42.312313279797955, 41.10524700533959, 45.70977618617397, 44.141318413519095, 51.77321918549077, 50.9778017382468, 53.22080519891555, 53.23465901036417, 54.03664250527659, 50.72365960767193, 48.32311807140228, 44.83532297995783, 44.94717328779159, 46.9663231603561, 44.54118051836568, 41.56978899432767, 44.916398371419604, 44.38418765221873, 45.19769899306759, 44.02777364177089, 47.236248908504365, 52.41258513542914, 54.265654010157434, 55.94765263219034, 56.03927527704547, 56.727125644683845, 58.31544237752115, 59.98559544163366, 62.52994283553093, 58.91466286874587, 63.158930193993356, 61.43518578621649, 60.414628213451756, 62.52213339651785, 63.532606555569565, 63.206814489056995, 23.879458250537997, 3.6497227895644406, 4.179399167337726, 1.1134426079450117, 40.744969460272024, 66.02349204401817, 64.84493747834237, 64.25582885742188, 65.77863416364117, 63.43067592190158, 65.2815600364439, 51.60420033239549, 40.83294037849673, 42.90210439312843, 71.9954732156569, 27.184384599808727, 0.41524015547287085, 0.2330580119404101, 0.19132239984408503, 0.15375519471783794, 0.17671835849121695, 0.16586725930533103, 0.12398861093266357, 0.16894713194379885, 0.188997614107305], [0.03223260932211434, 0.020044395594947764, 0.06429130136365853, 0.09966261504638581, 0.018001444029411482, 0.0585510888166966, 0.08993745826545263, 0.02840875614164097, 0.056471217558869434, 0.08716750649675246, 0.05423794102464473, 0.029392514543067065, 0.22799188781890178, 12.657373816736284, 57.1563349231597, 34.45818670334355, 26.699744386057702, 30.51610269854146, 61.40137103296096, 52.21740407328452, 56.67152212512109, 58.97419268085111, 55.451025655192716, 57.865346477877715, 55.53605087341801, 53.78988227536602, 2.3355642874394698, 1.4873718398232616, 0.9331143359022757, 0.9749521747712167, 13.75332816954582, 55.902396325142156, 61.670426014930975, 58.64647865295411, 58.1576140465275, 50.13830861737652, 47.17100028068789, 46.66493608105568, 45.39430387558476, 44.65898498412102, 46.500710364310976, 45.24941544378958, 43.065118097489886, 43.04829505182082, 42.20413431044548, 41.60331741456063, 43.609735273545795, 42.84095071977185, 41.533330563575994, 41.435808673981704, 42.83678516264885, 41.45107846106253, 41.832768224900775, 45.58260510044713, 51.455048284223004, 52.66380902259581, 55.563664359431115, 53.14006320891842, 43.25877335763747, 57.92005569704118, 53.02362765035322, 47.791487862986905, 42.702318468401515, 40.634750858429946, 39.272135150048044, 41.21416338028447, 40.03133343112084, 38.85442626091742, 39.85572107376591, 40.87753772735596, 50.19567720351681, 53.10300073316021, 53.833942259511645, 51.70411094542473, 53.90445863046954, 54.64393523431594, 52.289524693642896, 54.46889946537634, 53.69245060028569, 51.280824445909076, 49.97185499437394, 43.660812377929695, 39.639335678469756, 41.759066889362956, 41.05208320002402, 43.07712447258734, 44.316871935321444, 44.431648331303755, 50.423578677638886, 47.25336613193635, 42.9437207406567, 44.03871313218148, 41.666055725466826, 42.00690184870074, 41.53030641617314, 43.90369730611002, 43.17738025419174, 46.4117863101344, 52.04228985694147, 53.13348147176927, 55.643767003090154, 54.31891587472732, 54.18179373587332, 51.86799149359427, 52.29206246714438, 49.51638936996461, 53.77622066005584, 51.21922362235285, 50.28754303532262, 42.106537895817915, 40.95465936968404, 38.652035882396085, 37.58502567968061, 39.43248556506249, 38.50149923755277, 38.73606089622744, 38.95662361575712, 38.23263645172119, 41.265715091459214, 45.50682490871799, 47.944342628602065, 50.43323163063296, 47.361094028719016, 45.79294612330776, 44.757601214993386, 41.088321978046054, 41.733842126784786, 40.01094102859497, 39.44124814002745, 37.00228306554979, 38.82449857650265, 41.64870708219467, 40.28520491815383, 39.4560746992788, 42.09071505454279, 46.063546519125666, 49.749833153140166, 52.90572512534357, 54.46458878055696, 56.65380870142291, 56.07496884561355, 55.28284618931433, 55.171458721160896, 54.87326052881057, 57.3755758039413, 56.13087831004974, 56.09500431245374, 57.62636430801884, 56.039675358803045, 61.48451351350354, 28.04483494450969, 0.6778551878467683, 0.13536055031563007, 1.1457150117043526, 0.8875979879690755, 34.275584682341545, 52.45970456830917, 49.48206078621649, 52.60969208132837, 58.65496273963683, 56.774496109254905, 51.849972125022646, 34.492123050074426, 35.618027640927224, 32.28256367867993, 46.71079251074022, 6.771176841951187, 0.13275166853300988, 0.14208908523282698, 0.09122673061586196, 0.08687438593516428, 0.028526036541969068, 0.023787037709787972, 0.06755835226466579, 0.09310933806362653, 0.05403780055442645, 0.038368854851972674, 0.009693902308842348, 0.04199355390043028, 0.022206759200461453, 0.025305872137147575, 0.041264307144428455, 0.06709175109262429, 0.042424133618272124, 0.03582082343317809, 0.023230714235274542, 0.05725391809978793, 0.044838777638130614, 0.18267608638251984, 16.972040822429044, 69.6358145436933, 27.545301491214385, 28.875543917379073, 45.1329759628542, 62.11916085212462, 63.26469690568986, 64.3688754881582, 67.93008558211788, 62.96436102159562, 64.05601547610375, 60.43349873635077, 60.42585011451476, 2.5886285016613626, 2.1683303579207394, 2.4889088590298933, 1.1352077174571253, 16.767785356890773, 52.62893915176392, 65.39039404161515, 61.03496282331405, 60.87566752587596, 52.09499866731706, 50.720258912732525, 49.60055166675199, 49.355944818066014, 47.73912029881632, 48.79399076584847, 48.70622381087273, 45.57592138167351, 43.464650723241995, 45.408381262133204, 44.51634799280475, 45.89583773766795, 44.227959648255386, 43.13425379414713, 43.49215438289028, 44.2374360945917, 44.19777700977941, 44.93783412441131, 47.60342590270504, 53.97218227386475, 55.77888873315627, 57.775959584020804, 54.27172583918418, 46.580185428742446, 58.034357486232636, 55.644371048096694, 49.2659499568324, 44.033402242968165, 42.49932404487364, 42.936491812429125, 43.05372753450948, 41.960013835660874, 40.44510033822829, 42.11822655893142, 43.27072481955252, 52.88000222175352, 55.16563792382517, 55.15694202915315, 54.68395909955425, 53.98872683125158, 56.34723232638452, 55.078506392817346, 56.666046496360536, 56.85560680204823, 54.41064050120693, 49.678128304020056, 44.92182693173809, 38.775159082105084, 43.13424987177695, 41.99396587187245, 43.74702999668737, 43.67880821228028, 44.94457275636735, 53.5934695889873, 48.10063731285834, 43.47186003961871, 43.863449865771884, 41.06186166886361, 43.939661518219985, 41.07258542891472, 43.72713965754355, 43.68358565915016, 47.31021304284373, 53.656015703755045, 53.57126112907164, 57.04226063143823, 55.16964658614128, 56.09748325040264, 55.54842987368184, 54.737275877306544, 53.614438579928496, 57.62433252026958, 54.83507625518307, 50.40306860400785, 44.502423578693026, 42.13137826611919, 41.289421896780695, 39.587956551582586, 41.5112829208374, 41.18203524620303, 42.02319537439654, 40.811057475305375, 40.393862416667325, 42.03456240315592, 47.289036166283395, 50.17088782402777, 50.793532709921564, 48.26789894411641, 47.56022883999733, 47.04113452665268, 44.407980749684, 42.45674671665315, 41.84827727656211, 41.8607190347487, 41.37112094509987, 41.49997865000079, 42.69331270648588, 41.87235670704996, 42.064266512470866, 45.29928053579023, 49.17637086683705, 53.3887493225836, 55.04311484675254, 57.52984654518866, 58.894584255833784, 59.04110047125048, 58.956196846500525, 58.10414037396831, 56.30234472213253, 58.68697712498327, 57.81730921037736, 57.90071448972149, 60.96809033424624, 61.755463000266786, 63.46327081803353, 30.03580454857119, 1.150923183848781, 0.30228533271339636, 1.3669411020894207, 1.0457287704752338, 37.549614521764944, 57.4723602879432, 55.80665126923592, 56.62693654337237, 62.441156064310384, 62.69454902218234, 54.68465728144492, 48.28907974304692, 38.37683454636605, 33.19499915645969, 56.92086719697522, 8.926900702138102, 0.1751673522014772, 0.09156328836275686, 0.056514444069996964, 0.0930472849417598, 0.0372778958520822, 0.019324328487498627, 0.07146487207782846, 0.04338926267659953, 0.05456060193659318, 0.09289288758150033, 0.11533623771561731, 0.13572502430648575, 0.2385442433578353, 0.10084607533269352, 0.16145122207460866, 0.19942302887718524, 0.2285426437494255, 0.08286723281226813, 0.1781945179907545, 0.2012004294703084, 0.14420172590161526, 0.49912488328353055, 23.003767536532497, 77.34308365852603, 44.74202548303912, 37.56129926250827, 44.07190815094979, 72.6588950618621, 65.31483742498583, 69.36124078689083, 68.17779894798034, 66.73788116824242, 69.47462866383215, 67.34502484721523, 64.82172096929243, 3.245345791501384, 5.836235294418951, 2.417416553343496, 1.2276853164357524, 22.300125706580378, 55.348832222723196, 66.30031724129954, 64.31961444116408, 64.08829266025175, 54.78089655599287, 53.02576141972696, 50.76260874348303, 50.9588723797952, 48.885276086868785, 51.95286766175301, 51.108483345277854, 48.81482639620381, 46.00180056787307, 47.17294577629336, 46.804737198737364, 47.462522599004934, 46.204653786074736, 45.434198302607385, 46.07584707198605, 47.87521869905534, 45.98852334483978, 47.4491669285682, 49.51390258727535, 55.45322610485939, 57.300376122997655, 59.05736654035507, 56.94112623891523, 45.98953923871441, 61.99758306626351, 60.09075810832363, 51.960061288649044, 46.9157128180227, 44.068346638833326, 42.045694089704945, 44.938716657700084, 43.815973497206166, 44.29850347580449, 45.38543147425498, 47.45050053442679, 56.037247411666385, 58.17331529432728, 58.24244706861435, 55.441360935088134, 58.22038373639507, 59.968442916870124, 57.885687889591345, 60.49756673074538, 59.67766192651565, 53.60052985529746, 50.28291071614912, 44.82663885239632, 39.164293504530384, 41.75982782917638, 42.587863706773334, 43.01221316860568, 44.816024918710035, 46.650215425798976, 57.39446593869118, 51.856338131812315, 43.71244645887806, 45.44476124548143, 41.364637267205026, 43.126056040486986, 40.54610137016543, 44.22437460191789, 42.9675099157518, 47.822847212514574, 55.670882348091375, 56.814108125625125, 60.476719333279526, 58.63947329982635, 58.33213206260436, 57.79180203714679, 57.74182319641114, 55.23951576602075, 60.17720714692147, 56.33562603304463, 54.232631575676706, 46.84905213694419, 45.9850206682759, 44.039179894231985, 43.39006293204523, 44.04919370528191, 43.21098712182815, 43.689037753689675, 42.332493874334524, 41.98534842460386, 43.89344815284976, 49.302259337517526, 52.57915642953689, 55.5695753712808, 50.92879172294371, 50.65234307319888, 49.03107058617377, 46.346678887644124, 45.035614890436975, 45.52247124333536, 43.839217462847316, 42.013012901429214, 42.64401243579003, 46.16806591710737, 44.15119886398316, 45.18308424180554, 48.637982414614775, 50.629122641778764, 55.788263197868105, 58.89803594158542, 61.91712348691879, 62.0484640521388, 60.82360982894898, 61.082364666846495, 61.52476487621185, 58.82037693454374, 62.66187567864696, 59.56672553093203, 60.41768766218617, 62.85580942707678, 63.14485672981509, 63.938611092105994, 35.72257841787031, 2.6803702885104768, 0.8560864014490959, 2.8124882184690048, 1.342005982033668, 49.202438939002256, 62.460748303321104, 62.01321763377037, 60.08809089660645, 70.38592861544701, 66.98450411519697, 63.43977189833119, 46.98746473558488, 48.69170711886499, 43.67517217513054, 63.047236780966486, 11.563397319086137, 0.49734247247538266, 0.3266214945864293, 0.14982959165448143, 0.18760157208288872, 0.12692779918471653, 0.16547690686439315, 0.16327192195721213, 0.2079877233312976, 0.16746890400686573], [0.0800477994245387, 0.08453872174985948, 0.05641383757334083, 0.030007397778512492, 0.020313935970226606, 0.06176066780162435, 0.0387153142852889, 0.0357242695416414, 0.050098388756234805, 0.06536372486622104, 0.022947627510274612, 0.06211704424312038, 0.12707851932293948, 3.057602033499749, 45.395955193427305, 47.64525405822262, 41.229539071359945, 26.910022650995565, 47.572968698317005, 56.91751749284806, 53.25389431368921, 49.659857903757405, 54.30236347260014, 57.243450764686834, 52.0632980715844, 60.84463373307259, 8.210732292744423, 1.7479467800548, 0.35424831052941663, 0.08064766925188803, 7.447747943862793, 66.46984992488738, 63.99784672644831, 58.05655810140795, 58.67903040301416, 56.53289379612092, 51.22683694285732, 46.86352176050986, 44.144828934823316, 41.83461173888176, 41.959441169615715, 42.417122933172415, 42.936566337462395, 43.04497280428487, 45.51182985305787, 42.78168370646816, 41.77802762677593, 44.02398463218443, 42.83822075013192, 42.98365831375123, 42.60310995963312, 40.691860568138864, 39.82596597363872, 40.127349130568966, 45.38842032032628, 53.40676869115522, 56.879541104839696, 57.04077013077275, 45.622727024939756, 55.92995097560268, 56.55302732221542, 47.558546143193404, 45.34603911061441, 42.905756119758856, 41.1336684996082, 40.575013160705566, 40.94885426182901, 38.24244237715198, 38.91522692095849, 41.205930325292776, 50.196983352784194, 50.950721694577126, 51.6698411972292, 53.8716362368676, 53.135701533286806, 53.2378282854634, 53.773451466714185, 54.51201023594026, 54.904517896713756, 50.86959531230312, 45.829020161782545, 42.07624150860695, 43.85833509506718, 41.68808375635455, 42.55902644126646, 44.655678426065755, 42.67293207107052, 47.184528535412205, 52.14440091963738, 49.49912309646607, 44.04063901593609, 42.82166834800474, 42.057531802884995, 42.9423322216157, 42.66585611527966, 43.20355030798143, 43.661510559820364, 43.60213764252202, 49.44895990433232, 52.44514080785936, 54.989543114939046, 55.706450400813935, 53.116858466979004, 53.69089734169745, 54.18445702522032, 51.981901045768495, 54.00051355361939, 50.99617412013393, 51.41728762657412, 46.6959188830468, 40.93722051189792, 37.226944661909535, 40.254751636135964, 37.800065702007664, 40.02895647479642, 39.17652737709784, 39.464641155735144, 37.36421585083008, 42.24362473334036, 44.28739140110631, 49.02705800148749, 48.11882534334737, 47.49307394027711, 44.444505860728604, 43.485988416979396, 40.90257421616585, 38.45511328789496, 40.86439386490853, 40.878573233081454, 39.15357366684945, 40.039527262410815, 37.76124600441226, 41.13318212570683, 40.6461061200788, 42.683208680921986, 45.797943222907286, 50.461339335287775, 50.64047005868728, 55.06901425700034, 54.376202091093994, 56.02930068969727, 52.799052346137266, 58.22923260350382, 54.43241750040362, 56.89383029937745, 52.98430196700558, 57.43640784294375, 52.08492209834438, 62.65487424788937, 40.28863306968443, 15.974688972196272, 2.566210440089626, 0.7143882662057878, 1.485503811028696, 3.270494067861188, 57.25719474977063, 46.96443650030321, 51.20357336536531, 51.37354143204228, 62.15118700458158, 56.50404084113337, 47.22827080757388, 30.53122735792591, 21.42316414463905, 43.904199369492076, 34.787697176779474, 0.44855744187389657, 0.03513284200321763, 0.03144711064505241, 0.036092612276514696, 0.021674412362758192, 0.03246723907068372, 0.012235881633035118, 0.07617923926802413, 0.019502216018736362, 0.03750939996192052, 0.025797984037067623, 0.01869849402517561, 0.048367470547917395, 0.03941379495025162, 0.029412501777011543, 0.08372928857082322, 0.06492272635260898, 0.027588208942043207, 0.02770260502133639, 0.02896858446840798, 0.039511566921587915, 0.138208175738973, 0.13658742480460676, 5.092463695233868, 58.84243242202267, 44.00206642766153, 26.97022907195553, 44.35024346074751, 51.88162172994306, 61.28893629197152, 55.55281508353449, 56.641194358948745, 62.299774231449256, 62.61904731873543, 57.23670428799045, 65.09401975139495, 8.382673801914338, 2.292558685425789, 3.378156019795326, 0.0688527727259263, 10.377912905908401, 65.84534583553192, 64.84145049125918, 61.3718238184529, 59.75257527443671, 59.80473887535834, 53.090990435692575, 48.446708033161784, 46.8726687277517, 43.44203825919859, 43.866356342069565, 45.186473169634425, 45.49510486664311, 43.9080629041118, 46.72945907039028, 46.25050237101894, 45.166810327960604, 45.6704818817877, 43.362425911811094, 44.16864164413945, 44.75757768077236, 43.41886489622055, 42.875679385277536, 43.68594300362372, 47.66128086274671, 53.84063774539579, 58.24332960190312, 57.227651457632746, 48.49292139853201, 57.36662887757825, 58.93875406634424, 50.34414675927932, 46.175471351992705, 46.0796086249813, 42.34412762426561, 44.60225966668899, 44.40991055580878, 40.51993916111608, 41.31337581142303, 44.52683641064552, 51.904736257368526, 53.749701515320815, 52.96769465169599, 58.16669433347641, 54.9598390056241, 54.63059525335989, 56.755347098073656, 56.30365087139992, 56.96248354450349, 52.121890437218454, 47.47647054733769, 42.87786806783369, 44.4074276954897, 41.846084671635786, 43.90230878706902, 43.679765270602324, 41.5978810095018, 47.2466157328698, 54.509091992532056, 50.17843446423931, 43.194685751392, 41.042398868068574, 44.02993879010601, 41.804209447676136, 43.04994636966337, 42.83895815572431, 44.35953163331555, 44.79717400766189, 50.726617074781856, 53.00679283757364, 57.30838560288953, 55.85457478800128, 55.43268465226697, 56.17380472921557, 55.127096714512, 53.55475971775671, 55.45489703455279, 53.85853552049207, 54.49017832356115, 47.569081629476244, 42.210602298859634, 39.886668574425485, 41.947599534065496, 40.27359470244377, 41.202121703855454, 40.164003679829264, 41.704855811211374, 39.49995033202633, 43.57540668979768, 46.78234046505344, 49.38291111300069, 50.20191377209079, 49.25071547108312, 48.0226880504239, 45.664947417474565, 43.0043056703383, 42.54532167988439, 41.81224638415922, 42.53648065751599, 41.85314101557578, 41.85444324247299, 41.44359065640358, 44.36494450415335, 42.39711100055326, 45.18937180119176, 46.724987568393836, 52.25838891921505, 53.12056118442167, 57.57121186102591, 57.53984858912807, 58.874776286463586, 55.21224744858281, 60.94835688990932, 56.82292953614266, 59.628902942903586, 54.677483266399754, 60.0161232486848, 53.623263912816206, 65.68634079348656, 41.19943488028742, 20.29257232143033, 3.099093355478779, 1.4558514279703942, 2.0135430895513107, 4.557941229112687, 62.654054472523356, 53.343418490502145, 56.19278900084957, 56.74330934401482, 67.88220128705426, 63.54089452374367, 53.237075190390314, 41.97465996588431, 24.78911472905067, 45.54629179739183, 43.84845072223295, 0.9891368136290581, 0.009514574532306964, 0.0960373261102265, 0.06520753486021873, 0.02302953954635849, 0.03823587347963645, 0.013964615533158425, 0.05111835055774258, 0.058097522630686724, 0.01310202542827615, 0.16263401586442225, 0.17056955294984003, 0.1128883186667677, 0.08322829005098151, 0.1286470766870245, 0.19162310467612362, 0.142653891215882, 0.0952179874143293, 0.13725571394447358, 0.18099083084492915, 0.25714032291885347, 0.24273030099368867, 0.44155025013512184, 6.065113929010207, 67.77017839493291, 60.421582575767275, 51.57344895024454, 39.588152670091205, 61.239749770010675, 69.15698728253766, 65.12928578161424, 60.67266133523757, 69.48823144358974, 65.78836556403868, 62.21316045330417, 71.97266071073471, 11.373399669124234, 4.74662390447432, 3.2732201151309477, 0.22352345017415864, 14.266524218743848, 65.91235560755577, 66.21249537314138, 63.03911747470979, 62.816950505779644, 64.31286404209753, 55.564248792586795, 51.9894947544221, 50.47635809067757, 46.748662994753936, 48.74902863656321, 48.57361632008707, 47.982872070804724, 47.95537625589679, 50.91592242640834, 48.238845948250066, 46.78274054681101, 47.95239133219565, 46.08389969794981, 47.293743010490175, 47.635165722139426, 45.17216828561599, 44.96738918365971, 44.6632799794597, 49.04824664515834, 56.77777913308913, 59.79933777163106, 59.398157750406575, 46.31395847566667, 60.167797380878085, 62.33103552172261, 52.070774109132834, 48.12350865333311, 50.61012660303424, 45.41584161020095, 46.97560741055397, 47.27110701222574, 42.59328442235147, 44.350816126792665, 46.92797022481119, 54.02572654908704, 55.632407819071126, 57.313457227522335, 59.21785031595538, 57.08410839880667, 56.42418530679519, 58.42886555579401, 58.35318734568935, 60.210868927740286, 53.17357593967069, 48.015478734047186, 43.07684990667528, 45.735652062200735, 40.95135281162877, 43.05143294795867, 44.22194273241105, 43.19974953128446, 48.4960828288909, 56.26155991708079, 53.39556247957292, 44.82676436824184, 43.70235812279486, 42.50245409627115, 42.83921703215569, 43.38601896839757, 43.67521532120244, 44.53670901636924, 41.88203711663523, 51.54305058140909, 55.12856368095645, 58.504590834340746, 59.90309622979934, 58.29661500069403, 58.44498257483206, 59.125639315574404, 56.33229594076834, 60.47234196816722, 56.64296727026663, 57.455835342407234, 50.19056243281211, 45.50348304933118, 41.66558896341632, 45.55986319818805, 42.32440594703921, 44.15746681151852, 40.67146032087265, 42.96026137567336, 42.24414640857328, 45.969413557360255, 51.05758666992188, 54.08988868036578, 53.01592411533479, 52.057387059734715, 50.92561068073396, 47.663602905888716, 45.55568587395453, 44.090080491958126, 44.63931429770685, 44.58819012488089, 43.898872790798066, 45.04232214343163, 43.17861187842585, 46.455018674173665, 45.798335459924516, 48.059013120589725, 50.05518574868479, 55.51477593760337, 55.256146615551366, 58.391065674443404, 61.691999050878714, 61.03833606166225, 57.77319039067915, 62.58007072633313, 58.21794009977772, 60.503662093993164, 56.60057037107406, 61.278345892506266, 54.0109823596093, 66.05657331405148, 44.83997883335237, 25.333361241125292, 4.063736070548335, 2.071217865713181, 4.09163637988029, 4.976155613699268, 72.45804617481848, 58.40491164115168, 64.76507017689367, 60.30094615874752, 75.31338261019799, 68.50662692900627, 60.78807707755797, 41.68680506367838, 33.15616376938359, 55.369424666127856, 55.11265062516736, 1.52575419314446, 0.21662473648546204, 0.1567444085113464, 0.14851161398954932, 0.1232927885927981, 0.12245211434820968, 0.11525569123125846, 0.2692474845436312, 0.21920429242234077, 0.26098731003942033], [0.05539697842792638, 0.05774900625129381, 0.015565740252514521, 0.007148475588990316, 0.044939675248197974, 0.007462627179319821, 0.009453179288445222, 0.02438799921242941, 0.07227067400010363, 0.02145805189596309, 0.033926743818747426, 0.07943617780843089, 0.043274460570706476, 0.0591449371929611, 26.597278348861206, 59.684902621853745, 29.232495292540523, 19.153843541299146, 38.791986050144324, 63.19037583566482, 62.75757758848129, 50.45345537124142, 52.077955968918346, 60.11490029673423, 52.19013575584658, 63.362332544019154, 22.13604903990223, 2.683638603456559, 3.1713537102745426, 0.22878959985269656, 6.562025277845322, 39.12519924102291, 57.7067336728496, 60.597885270272535, 59.64950323104859, 57.3882568267084, 56.788491126029726, 56.42871564434421, 50.15641427809193, 46.35931284196916, 46.012787126725726, 43.36848205135715, 42.587400867092995, 42.935440617222945, 42.84163713455201, 42.69684283964096, 44.44778888456283, 46.69911953710741, 46.649831033522084, 45.76078661026494, 44.44831448216593, 41.70165123478059, 41.01851555608934, 43.23918504099692, 45.167563423033684, 49.878949734472464, 54.94057232333768, 58.74962129900533, 51.382409911001886, 48.29401800709386, 57.94099723139117, 49.21380596776163, 45.88234478427518, 41.05607225048927, 40.79426188622752, 40.10120261100031, 40.43694573064005, 39.10452835021481, 39.38688016706897, 40.46646156618672, 51.03136954769012, 53.079525347678896, 53.92707893925329, 53.104754032627234, 54.9579405784607, 53.600871101502456, 55.51909838953326, 56.09184288209485, 50.72444408170639, 48.22464696822628, 42.59284511689217, 41.86492773794359, 43.149256860056234, 42.612303995317035, 43.891098653116536, 40.65755944098196, 42.57839902754753, 51.832446975092736, 52.995182621863584, 48.15477778834682, 45.360512656550256, 40.901821121092766, 44.66393501527848, 43.080599692560014, 42.976962827867084, 43.939006482401204, 42.84816003614857, 43.3487956754623, 46.30204623745334, 51.33957370635002, 54.71713842884187, 52.120497995807284, 55.369142255475445, 52.52587887548631, 50.97497370935256, 52.088154131366366, 51.67749374143539, 50.54414449199554, 49.36131454283192, 49.154946880955855, 41.84212700013192, 36.82023802111226, 38.8079853980772, 38.39455581480457, 38.9394397120322, 38.796230054670765, 37.96674290011006, 40.971098023076216, 42.79447847797025, 45.32081827040642, 47.54044440484817, 48.19701779273249, 49.15380154886554, 44.67214845841931, 42.87430263334706, 42.3760086490262, 40.76897828809677, 39.38926889050392, 42.10788326878702, 39.80298088442895, 40.15741802030995, 38.828585686222205, 38.862031736681544, 38.39566976793351, 42.675756177594586, 42.62030170809838, 45.911527218357215, 46.47884707297049, 51.44609743548978, 51.9206650026383, 56.43002963835194, 54.10692353402415, 55.691133545291045, 54.56627230490408, 60.030377141890995, 53.27289819717408, 56.31426088271603, 44.47209581252068, 64.9147988134815, 23.558416174304103, 13.750524655465158, 0.6640119177679862, 0.8168445587638886, 0.5484740916759737, 6.8985827795920835, 54.03635224988384, 46.680241169468054, 60.04456043243409, 55.03360702145485, 62.22814390736242, 54.230937111762266, 43.24089911676223, 25.453819190302205, 26.419424356952792, 48.30143913145989, 13.110665467477615, 0.13080281746243277, 0.01883727085265902, 0.08057660693603177, 0.04151506687424356, 0.041553195070235, 0.03426884804221411, 0.07746910150613516, 0.029184536993383404, 0.022543426114885558, 0.06049035995778057, 0.08035202826102895, 0.059125949703757806, 0.06496521358888957, 0.014912760422204532, 0.030448800403504606, 0.02667603188104207, 0.0673910310011237, 0.09098558911993619, 0.04388253903016449, 0.02776100773424391, 0.06207112493293901, 0.02897170436147961, 0.031244945787494222, 0.12913037091493607, 34.68902603272469, 66.52529654964324, 26.99696198586495, 28.42611089829476, 51.19991771636471, 68.32440930028116, 67.61807672439083, 51.436930856397076, 60.27099494011172, 64.16491223919776, 59.020755137166674, 65.58403753465223, 24.25733547056875, 2.6929520262825877, 2.1986336092795096, 0.40853768286685793, 7.367815433009979, 44.454021530766646, 56.51906744126351, 62.914503774335316, 61.136775785876864, 61.83106668533818, 59.413345167713786, 58.48735986217376, 51.627244257157855, 49.964629988516535, 46.58816352967293, 46.638487538983746, 45.92444750570482, 44.50644400811965, 44.767630715524, 44.47435117536976, 45.87186813354493, 48.506732063908736, 49.86729245032034, 49.02784247552195, 46.85774410924604, 44.12898255932716, 43.494119490346606, 45.38490587665189, 47.33881496614026, 51.25317958093459, 57.292511770802165, 59.45623628554806, 51.75989489401541, 50.225934367026056, 58.60339926135156, 51.73196369601835, 48.483699906256895, 43.10562441425939, 43.140145194145944, 40.367029482318515, 43.21432113647462, 41.28072992447884, 41.27427370317521, 42.36712840295608, 51.965984067609234, 53.73525542597617, 53.39698237757529, 55.674271275920255, 55.18837590371409, 54.705967518591116, 56.86498126676006, 57.082657121842914, 53.64282869523572, 49.7097739865703, 43.29225863179853, 41.82700234074747, 43.28872849864345, 42.094237342957534, 44.21483147528864, 41.2288369670991, 43.363210385845555, 51.586384927072835, 53.42923994987242, 51.206111138866795, 45.48483217916181, 42.42479116685929, 46.21046673867011, 42.23599964572538, 43.16642899667063, 42.87646778168217, 43.15874899587324, 44.90855363107497, 48.804302677031494, 53.70450012145504, 58.2066083723499, 54.84634130231796, 58.70325496119838, 53.87079684965072, 54.82356017635715, 55.22217496748894, 55.03793339575491, 53.062945488960516, 50.721310107938706, 51.98829450914937, 43.30987791861258, 38.17853127756427, 40.171970013649236, 39.834932511852635, 41.36687694057342, 41.89510645404939, 39.19312684766708, 42.5860829507151, 44.239836585137155, 46.184673232416955, 50.10934975839431, 50.89189790910291, 50.08353271792012, 46.22123364479312, 45.75237312624532, 45.775107183764064, 42.981901091914025, 40.35753342413133, 43.64798622746622, 42.360268177524695, 42.71130854083646, 41.62755766222554, 42.337024211883545, 40.870155826691665, 44.440132417986476, 44.684076386113325, 47.567406777412664, 48.69020485108899, 52.28106806355139, 54.17029726889826, 59.13422146151143, 56.289251850497344, 58.19581793200586, 55.98598987825456, 61.133049534213164, 54.82216773494598, 57.488477306981245, 46.30119508312595, 64.75839038049021, 26.241105564178962, 15.734570295579973, 0.8385557356861331, 0.45048265147113037, 0.556559261054762, 8.244572051109808, 61.40424220792709, 51.6186228875191, 65.54666126928022, 58.399279117584236, 70.05242516917568, 58.108451058787686, 53.43138940872685, 34.349603729863325, 21.918512428960494, 58.58079856441867, 17.737905171609697, 0.09415330906068126, 0.04017776464142146, 0.030006512946959947, 0.04606592025788081, 0.05712133126273271, 0.06315858674145515, 0.047985246299856135, 0.030691973947649522, 0.028515535391746994, 0.020892629212129022, 0.12403092962960083, 0.16643650859834688, 0.1392709695163273, 0.14900783978162274, 0.20322011303036444, 0.10195363162746353, 0.18745399290515533, 0.2662754311196266, 0.1801805243256592, 0.10147642779854998, 0.15537622144385693, 0.13206859389620443, 0.1347933388164928, 0.2177951196509023, 43.2066019119755, 76.44310366722846, 38.17623276864329, 27.7277171996332, 53.369737594358384, 75.56676772332962, 73.49964726355769, 60.16900154852099, 66.00321339022729, 70.79977789232808, 63.74333589307724, 72.68206058009979, 27.361763984926288, 4.351024925708771, 9.242239652141448, 0.7784191819448626, 10.15677163677831, 49.32885300728583, 57.51194877009238, 66.21047143013247, 63.798033345130186, 64.21901349098452, 61.63891761533676, 61.97036966200798, 54.224323995651744, 51.49837478514641, 49.8266488505948, 51.41256117051648, 47.333002013544885, 47.492579721635394, 48.35242602132982, 47.175256052324855, 46.7183195391009, 52.228143522816325, 53.42591770233647, 51.66092172745736, 49.45696546185402, 46.557192494792325, 45.361081400225245, 47.59765609618157, 49.263608301839525, 55.159322907847745, 59.173162752582186, 62.03683814694805, 52.10291401032479, 54.84341913653959, 60.470682805584325, 53.14788833741219, 50.884559154510505, 46.75490740806826, 44.02440824816304, 42.77581584069037, 45.92866405364006, 45.523016452789314, 45.02802902652372, 44.50332964620283, 54.70426520993633, 55.95983159157538, 54.57486621795162, 58.82002392122823, 58.870995121617476, 58.164839052384906, 59.72006667044855, 60.27487024184197, 55.141687931553015, 50.77978872483777, 43.41010232125559, 41.783460109464585, 42.948600169151064, 42.69383830408896, 43.53657522509175, 42.60787171702231, 43.61852922747212, 53.063106306137584, 55.609336437717566, 53.74655185207244, 47.03701211560158, 41.73731342438729, 46.13199972337293, 43.771278089092625, 42.78408811938378, 43.588860419488725, 43.78355903010215, 45.690568339440134, 47.87621890344928, 55.07726300147272, 59.702286566457445, 54.43670465100197, 61.88747036841608, 56.54901865989932, 57.61423241707587, 58.13907300272296, 57.47433324013987, 54.867635849983465, 51.48874536637337, 54.97486168338407, 44.70415892139558, 41.80091465673139, 42.44525024967809, 42.360731017205026, 43.706649195763376, 43.51543364986297, 41.57937134465864, 44.79334185200353, 48.520142647527884, 50.05204393017677, 53.25877766455374, 54.05786645027899, 52.835083238540165, 47.98014994590513, 48.01440400461997, 48.8601101598432, 44.11088082098192, 41.79070080480268, 47.617185577269524, 45.319884746305405, 43.66534663784889, 43.01837128977622, 44.13752940393264, 43.54370609406502, 47.28724364311465, 49.13690790053337, 50.27881968405939, 51.09146025873, 54.61235230968845, 56.559044238059755, 60.43998633661578, 58.48346102622248, 62.7021505755763, 60.37565162104946, 62.23093663492511, 58.19468044465589, 58.42876357416953, 47.42271838649627, 62.85438560670423, 30.19492530053662, 21.646256792929865, 1.1956249658138522, 1.493005711705454, 2.4385657281644884, 8.669910930818128, 65.68594463409917, 58.85646274012905, 72.9308408306491, 65.42872344293903, 72.63408214815202, 64.68113929994645, 55.3863496934214, 37.183904494008715, 36.95880359218967, 63.42159563495267, 25.69696887846916, 0.26784744354025014, 0.1437976298433158, 0.16257491984194325, 0.16397747361371595, 0.1325891659625115, 0.10012591437947366, 0.2075732391207449, 0.13287212819822375, 0.17725655057978246, 0.13966011153834482], [0.07302539317958778, 0.05962687161480708, 0.0207787444965253, 0.018619399277433273, 0.08354987077895673, 0.03471608251152981, 0.0615249885125987, 0.06485750162673574, 0.07820325888573162, 0.08306512098398902, 0.01572226063393417, 0.06239570106469816, 0.2318272916900535, 0.05844994222805385, 10.076867072812973, 50.57893591542398, 43.92394458093951, 43.57239038713517, 32.21886046471135, 53.458343936551, 61.71722773582705, 56.938231529728064, 49.232715714362364, 60.347057542493275, 53.72417473023938, 63.213290322211485, 30.632810861833637, 0.6096488477722292, 4.797973613585196, 0.3204774694336999, 2.151135177381577, 39.56390065531577, 54.09883952909901, 61.178811827013575, 59.62531397419592, 60.55565311062721, 59.98693689223259, 57.58436356821368, 56.82275302948491, 55.698978285635675, 51.45219672110773, 50.71525396839265, 47.313817701032086, 47.28200335656443, 46.810263818310155, 48.43037136139409, 46.805819772904925, 47.73504495620728, 50.79480748022757, 51.499453436943796, 48.29917592387046, 45.22667354153049, 42.710218121928555, 44.617117604901715, 43.65253225449593, 47.69492303171466, 52.04589059275966, 55.498250992067405, 59.98204177425754, 51.62258840376332, 53.10378520719467, 52.44729811145414, 45.36630991966494, 43.7142546715275, 42.53579032036566, 39.05896609829318, 39.63841392147926, 37.87470448401667, 39.403436491566325, 40.12613319581555, 48.076416677044286, 51.87234924685571, 53.45828117862825, 51.91293793339884, 53.966957676795225, 55.31316611074633, 54.374829261533684, 52.96727103571738, 47.78445505326795, 42.97925741441789, 44.936167117088075, 41.544219063174346, 42.29620018313008, 40.84729233095723, 40.463833578171275, 43.68813168617987, 47.47339148675242, 51.27044193206295, 49.932090005567, 48.45195616445234, 46.50566431783861, 40.68441983192198, 42.98159122467042, 43.34706983258648, 44.18962632456134, 42.813403914051676, 44.24426886343187, 43.28992089917583, 45.57718830723917, 46.64649701887562, 52.20481718740156, 53.73741272957095, 53.8974375878611, 55.77801796697802, 54.122522800199455, 51.0403831543461, 50.23104521536058, 51.24142031515799, 51.387336407938314, 52.204805420291045, 44.218534192731305, 38.27151498486919, 37.02066721454744, 37.88323956151163, 38.56799125671387, 38.7414933789161, 40.091761465995546, 38.28152095117877, 42.06363108850295, 44.18608834666591, 47.51449008141795, 48.356426838905584, 49.299698029795, 44.58142011396347, 43.968757660158225, 42.7429973694586, 39.94602972461332, 39.27094667188583, 40.56542688800443, 38.43479148803219, 40.75085693790067, 39.44812797730969, 41.083042467794115, 37.80512163715978, 40.39708660494897, 39.28603210756856, 41.6925827149422, 41.24514225990542, 42.70557403564454, 42.899605843328665, 46.370730861540764, 46.596396584664625, 51.64635012226721, 52.051962421786406, 55.39786577224732, 53.93240159557712, 56.698033425115774, 50.88813243373748, 54.23408285264046, 10.482292079156446, 1.9393923974806264, 0.39961254404437163, 0.33799980016004655, 1.4975165599776854, 11.561194908234382, 57.589152782194084, 48.500405280820786, 57.00699852358911, 53.66050681760235, 62.75411413561914, 49.25975261196014, 37.18274347243771, 28.955805417030092, 34.50662405260148, 44.26328843639743, 3.1859427209823363, 0.15457595067639507, 0.09139700897879179, 0.07735415001309688, 0.04145946421269928, 0.0859738725628103, 0.012267516276258375, 0.03565433720547346, 0.023063858370146444, 0.13040488075104453, 0.06412133326633804, 0.02738535843579279, 0.031195544607696996, 0.05628999562994127, 0.037903885447209885, 0.07690087111005861, 0.03605471773734016, 0.02449501403457215, 0.08765291512733506, 0.014130949500888107, 0.05419312871151394, 0.02274694886328953, 0.03883471291872763, 0.10611080008769229, 0.11658247890731982, 15.147075729985392, 63.66621817311933, 34.96174843080583, 31.131869708338094, 45.708517105348655, 58.88263671628891, 68.90379828791465, 60.17872118180799, 56.8656284578385, 64.28793345728229, 59.7664055516643, 67.31490104429184, 34.22276604560114, 1.7247093108392533, 2.2585453621802793, 0.8712900598202983, 2.8186240311591857, 43.41882567251883, 54.488574074160674, 60.348395070722034, 62.59332441514539, 62.27289422865837, 61.08189398242582, 59.40352747517248, 58.46869722489388, 58.81277538114979, 53.346481861606726, 51.682690881913715, 48.9284025469134, 49.22930325231245, 48.585909028207105, 51.40788570527108, 48.24627883972661, 51.16042337109966, 52.458574925699544, 51.43161212244342, 50.49573852169899, 46.767619809796734, 45.84445076604044, 45.77607600919662, 44.78820746944797, 46.546974720493445, 55.338579147092766, 57.79029976937079, 60.4721183930674, 53.1983692415299, 54.55148496935445, 54.62460579410676, 48.67637849623158, 45.503887053458925, 42.65119821794572, 41.498990212717366, 40.5587157126396, 40.3979887500886, 42.574170712501775, 41.43070174801735, 49.320145345503285, 55.11107383235809, 54.6006283452434, 54.05490898316907, 56.83016238674041, 58.3508143117351, 56.754295902867476, 55.53403085277927, 49.5953506039035, 44.45694369654502, 46.447974097344186, 40.7823496480142, 43.802778643946496, 43.63128869764267, 42.34738711387881, 45.631858302700905, 47.00696676008163, 51.03279729043284, 51.06377617005379, 49.27427322633805, 45.46951140126875, 40.97508707354146, 43.39968058370775, 43.24342904552337, 43.8245556431432, 41.978323459625244, 43.93279737041843, 42.87125495172317, 45.02430669723019, 47.846918798262074, 54.15103843135219, 55.156506646064024, 57.82968428827102, 55.42255709248205, 55.98267155308878, 55.33787704283192, 52.69480751406763, 54.34905928950156, 53.03324922438591, 53.677357319862615, 46.80784763828401, 38.55531023394677, 39.33402622899702, 40.50222965978807, 40.64874195283459, 41.4132668126014, 40.31784688272784, 40.39609424529537, 44.56773888680243, 46.20786228487569, 48.30107827340403, 49.288691859091486, 50.24439696342715, 46.37765776726508, 44.615383917285556, 43.061697790699625, 41.53118894946191, 40.94412780577137, 41.50902363561815, 41.39042292871783, 43.09093906033424, 40.936887110433275, 42.956370384462424, 40.63724940822971, 43.319817204629224, 41.15612799121488, 44.994088757422666, 42.33753019763578, 45.992575153227776, 45.1837706565857, 48.61895499690887, 48.98153889563776, 55.256754582928075, 53.588429343315866, 57.93872225669123, 56.35568503410586, 56.30753009550033, 52.74377830566899, 55.39451214574999, 13.43916004703891, 4.492644552261599, 1.5533103144937948, 0.4867789780180301, 1.6027003094073267, 13.108982770673691, 64.5721915460402, 54.02494207505257, 64.99332466433125, 59.011765064731726, 72.28050401133876, 52.68342087345739, 51.47464836797407, 27.969423455576745, 31.346956799107215, 54.59350532101047, 5.350674304269976, 0.17436372596890698, 0.09015500425331055, 0.01895856555371035, 0.016813505959186344, 0.07994250830022559, 0.02600591562147583, 0.021411904674624244, 0.010127613411074685, 0.02536512903809067, 0.05894513380142951, 0.19353089343395927, 0.15712818791789396, 0.07462019671595867, 0.18939878370973373, 0.2674265854781674, 0.08786133700801481, 0.1070614156102942, 0.23094586156789335, 0.16813645770232524, 0.2593101903555855, 0.16529321430190919, 0.19072891152914495, 0.3180696244441694, 0.21250756547576, 18.48373797632033, 72.04445577436879, 53.609308119743105, 58.84528006276777, 47.12099398336103, 64.2502002562246, 73.64136249788346, 69.82716345017957, 62.00747528383809, 70.75865576344152, 65.09603584966352, 74.8186932840655, 37.94521301023422, 1.9714441679177748, 18.140869871262584, 2.657980173826218, 4.616321296461167, 49.05369873969786, 54.74954897357572, 63.142671969629106, 65.19353420503678, 67.19406066402313, 65.45208115731516, 64.90871129497405, 61.4333148156443, 63.94467899876257, 56.38412221785515, 57.64063389070573, 52.77014840033747, 53.450259931625865, 51.11068379494452, 54.231509777807425, 50.972008397502286, 53.30265721967144, 55.81310749053956, 54.05974526559153, 53.67380757485667, 50.83734950711651, 46.927107303373276, 49.05642086459745, 46.505613327026374, 48.51205864260274, 56.54648088639783, 59.66890719629104, 59.933996662016845, 55.9356580242034, 58.0005427329771, 57.73686532051333, 50.881546774218165, 46.824702062914454, 45.134027158060384, 44.9340529595652, 44.67177975562311, 45.08553097324987, 43.84366543062272, 45.0778901961542, 53.32403021474039, 56.61624023991247, 57.516271222022276, 56.0744079466789, 59.48831735118743, 60.5255606866652, 59.115225422766905, 56.79704973774572, 49.86560190877607, 44.36072403384794, 47.19757433860533, 42.08551006932413, 42.51947326044883, 44.023239381851695, 43.4458351135254, 47.63538929723924, 47.29088752500473, 52.57413579571632, 52.363171115998306, 50.74365585081039, 49.10775292304255, 41.88948961996263, 44.72938760634392, 44.49394733675065, 44.50277266963836, 42.4098704707238, 44.28359846914969, 43.63432461215604, 45.709960537572066, 47.6758603126772, 57.18005349559169, 58.505414532076934, 60.42305738695207, 60.89014891655215, 59.4707961236277, 58.29801528684555, 55.17573410464872, 56.98895954316663, 56.88353800004529, 56.70188519262499, 48.23175430297852, 42.491914687618134, 42.325594425201416, 44.18190317769205, 42.23831776649722, 43.32098999331075, 42.92889025903518, 41.17719111904022, 44.8508555658402, 49.617978757427586, 51.41029011818671, 51.67628172905215, 52.45164801997524, 49.79869019600653, 48.010701287177305, 48.211699224287464, 43.38302227758592, 43.138913569911836, 43.972091674804695, 44.019195418204035, 45.41810874016055, 43.71390950295233, 46.576357195454264, 42.80910107397264, 46.75516628449964, 44.989291698701926, 48.37321066087293, 44.91066778859785, 48.47704756644465, 48.826142434150945, 52.98893820854926, 50.3816956089389, 57.91701586015763, 56.15246311310799, 62.67718076705933, 57.63731556553995, 56.47978490398776, 51.98344645961639, 59.541869471150065, 17.956469443536577, 7.921437880685253, 2.4967065309324576, 0.6750739209594265, 4.108940406191734, 13.91235968758983, 71.54308272946265, 59.73526193249611, 69.85347470929547, 65.87777599211663, 74.21654670469223, 60.08745155026836, 51.4808496352165, 40.892407432679214, 44.99306501880769, 66.42165184020996, 8.554707977079577, 0.5873150558721635, 0.27122307208276564, 0.19321002516775362, 0.17673228596968038, 0.2617359924460611, 0.06819840340364365, 0.18067792989313605, 0.1582303126492808, 0.1883893402954263, 0.12241554131070453], [0.1737569996546353, 0.05656057405435751, 0.02185653061455777, 0.02765186127245186, 0.02537676208322087, 0.04120384365500462, 0.07807895345913787, 0.04839013908959685, 0.024756433877853617, 0.023724714541927944, 0.05692528936290934, 0.04766329018879802, 0.0655320803484609, 0.14615229300914273, 0.35856423539019405, 41.99246360409645, 48.20409374852335, 26.986489257504864, 26.33393237667699, 44.20002452788815, 60.899374331197436, 59.116896352460316, 46.949037275006695, 58.19502169086088, 55.432198278365604, 57.84401662888066, 40.148918244146536, 0.20068500551485247, 2.63057604432106, 0.25850647219246436, 0.08014280964890796, 22.446361472529752, 64.05960052244126, 55.28838849836781, 60.0306164064715, 59.808774994265654, 61.47942227701987, 58.91860485076905, 60.69307727198447, 57.51542006769488, 63.724422224106334, 54.90367066475653, 54.39306043809461, 51.53065589166457, 54.323269705618586, 51.51384461310602, 52.22718646449428, 48.634915121140025, 52.03507269582441, 53.47519443881128, 51.243605075343964, 46.008617647232555, 44.41427223144039, 45.25832706882108, 44.179165363311775, 44.1537719388162, 51.742522716522224, 53.21258391103437, 55.00377347392421, 57.38893147437804, 55.787996476696385, 53.87380138520272, 46.69400868877288, 40.27599519298923, 42.33535328219014, 40.17131497783046, 39.3769879494944, 36.1879127256332, 40.11553887398013, 37.120044385233236, 42.90182982721637, 50.5274038161001, 50.19284132988223, 50.59493526335686, 53.672171946494814, 56.71725696133029, 54.79797063335296, 46.78057147610573, 43.858794012377345, 43.99054250409527, 42.271630456370694, 42.34965032146823, 41.04904728551065, 39.26677327002249, 41.17750883102417, 45.1086062769736, 45.37241312765306, 45.540008160375784, 42.967941376470755, 42.714638633112756, 45.5030829675736, 43.311062474404615, 41.91460847854614, 43.17412076457855, 40.90050712708504, 44.04936628956949, 42.56313316283688, 43.949863603038175, 44.58493063526769, 42.704675812875074, 46.824851112981, 53.4521387469384, 50.53185962861585, 52.80494374613608, 52.10630293815367, 52.17962772615495, 52.85409496676538, 51.63577933465281, 49.82662923874394, 49.216437878147254, 42.78221322644142, 37.19615797842703, 38.21220090312343, 37.0680376791185, 37.83667318282589, 38.234534878884595, 39.48519045306791, 40.99450280589443, 41.723181124656435, 42.43565220986643, 46.48806072050526, 46.84182713108678, 49.50093523148568, 45.730513757275, 44.769352636029645, 40.186733814977835, 41.70909197099748, 39.35896858092278, 39.98002882926695, 38.81572815679735, 38.39867038111533, 37.97181844711304, 38.64576793486072, 36.869255881155695, 40.25923098287275, 42.4576880854945, 42.95979069125268, 40.350539838114095, 45.93694025470365, 37.260084767495435, 45.35756303418068, 47.860411751654844, 51.80162891264885, 49.22914243513539, 58.3735679811047, 54.177792918297556, 56.87883507820868, 46.944506937457675, 51.9407553826609, 2.532348373243886, 0.8583709369263343, 0.9725204278384486, 0.11850422578713588, 0.5671937871844538, 20.866895567986276, 55.24570526615266, 48.31603819324125, 56.07380390167237, 58.026191111533876, 58.81927082615515, 37.96218510596983, 32.669997753635535, 31.024894906628518, 46.79319758569041, 25.62527971882974, 0.2188454721603663, 0.1279406899946832, 0.018942879903460705, 0.016709467388629433, 0.03298413774539386, 0.06875915678157922, 0.04339145751850259, 0.0542205048634881, 0.04477129678332037, 0.08354443921557358, 0.01766372757453111, 0.03205934896193926, 0.01750990094977521, 0.10123619028637487, 0.05587273435066304, 0.019082396005791043, 0.01889239470925062, 0.03857231631334271, 0.047728078244554425, 0.08998250423540032, 0.06010725853904601, 0.06147026302172773, 0.05446090708456693, 0.08592602271105974, 0.048509147018194206, 1.1958816359120032, 54.129406559851866, 51.83229792502619, 31.152532754405854, 44.46772629214872, 50.751065208065896, 68.4631827569777, 64.65913872564992, 53.00811075395154, 63.694733804272076, 59.69719532997378, 63.17026192142118, 42.87820931403868, 0.09872542904509653, 1.9760152000573374, 1.044324194231341, 0.10950496795797542, 26.11050828810661, 63.16607675244732, 57.30154106693884, 64.38523569414693, 61.8706080990453, 64.50633495084702, 60.88571271588726, 62.61536421314363, 58.995098913869555, 63.253098457090324, 57.80829168135121, 56.2418931530368, 54.01770530208465, 57.077667866983724, 52.1695040887402, 52.58838968892252, 50.37573360627698, 53.56727992334674, 55.18680303327499, 53.82389706950034, 49.49363962296517, 47.459494529231904, 46.785427370379054, 45.25528330956736, 45.66072694716915, 55.27064369570825, 55.28088108185799, 58.205176707237, 57.679755610804406, 56.70740396745744, 55.53001434572282, 46.7721030789037, 42.25225394771945, 44.55713672022666, 40.362075528790875, 41.34096968558527, 39.8590943121141, 42.64140798199562, 39.05081933544528, 44.46633385073754, 51.862449184540786, 51.17407321929932, 53.52443195158436, 56.5578047690853, 56.23784918938914, 56.33345303996917, 49.64285835143059, 43.918735673350675, 43.02780066767047, 43.79953092144382, 42.007007752695394, 42.54999322275962, 39.58582670457902, 42.47304416471913, 44.71210956573487, 46.87885038314327, 48.194848722027196, 46.54568426070675, 44.666515934851866, 46.77077731778545, 45.054916874054946, 43.98176423964962, 43.17321077469857, 40.90038161123953, 45.13148153981855, 42.31709857140818, 42.877993583679206, 43.95044019145351, 44.3339656245324, 48.373932376984634, 54.66104069063741, 54.01221006147323, 52.51248790371803, 53.80063741437851, 53.022674514401345, 54.376076575248476, 54.43642224034956, 52.41135743356521, 50.97600921507805, 45.912990262431485, 38.889453026556204, 38.923503122022076, 37.990928234592566, 39.408519883309644, 40.08903149635562, 42.094378548283736, 42.01462107319986, 43.30916796961139, 44.43112665607084, 47.86274948427754, 48.772409885160386, 52.270414906163374, 46.87079383480934, 46.82752616943852, 42.60844830543765, 43.107644434898134, 41.739886499220326, 42.26938686063213, 39.20754940279069, 41.19019377616144, 38.85844276797387, 41.38074251913255, 39.417356983307876, 42.3001225533024, 44.06990774216191, 45.505565827892674, 42.738180698887, 47.69768045794579, 40.069266673057314, 47.62703464877221, 50.48085312689505, 54.87351940524194, 51.78920676631313, 59.52175163453626, 56.84401227581886, 57.4301948085908, 47.165520729557166, 54.82175196370771, 3.4703648138430814, 1.8180071754801659, 1.7539230013085951, 0.26308881178978955, 0.5195366831556444, 23.073583764414636, 61.12112552888932, 52.7019658396321, 60.92606998259022, 63.38427428276309, 67.06898412396832, 43.4615755850269, 48.275641702836566, 24.5363748458124, 51.31002649184197, 34.76728124003257, 0.3684857481669995, 0.039899781977217046, 0.030650051701213085, 0.056458791612737605, 0.02256421391071091, 0.06375760621120853, 0.036351232068432916, 0.04124393303608222, 0.0745622881297623, 0.055702681983670885, 0.008205557223259202, 0.33146347670305165, 0.0954752090957857, 0.2223769995954729, 0.12713508725526834, 0.12284605208063319, 0.10839665323616036, 0.17260676460160365, 0.1338346717098067, 0.1963531919905255, 0.19977728325513103, 0.1673606557831649, 0.1377776190037689, 0.14502591393407316, 0.3702698137250639, 2.060900070974904, 65.84536936975294, 61.92027315016716, 37.50063196305306, 37.81503346658523, 58.191938707905436, 72.26731700281944, 71.16120861422631, 59.99280868038055, 67.77296327775525, 63.70335517391082, 68.791791085274, 50.08931036918394, 0.3783488544004579, 6.696045312189288, 3.7001512319810934, 0.6684152072956485, 32.77707649815467, 64.08573135252922, 59.718560480302386, 62.93373515529018, 63.34266577997516, 65.29239362285983, 63.404674530029304, 64.26209680495724, 62.77294543481643, 67.62556845141997, 60.36325693130494, 57.92781414524202, 58.102834224700935, 58.03536161299675, 56.10954846105268, 55.273632541779556, 53.73646743835942, 57.42804534973637, 58.680089442960686, 56.40027453822475, 52.48743180305728, 49.53152579645957, 49.2655106513731, 46.58658281449349, 49.174503818635024, 56.95974573012322, 57.977969492635424, 58.80439327609155, 59.90747751728181, 60.30005185834823, 55.78814552676294, 48.37696436912783, 44.841983164510424, 45.45133906026041, 42.45031010720038, 43.45080475653372, 40.375909728388635, 45.684414140639774, 42.05067549982379, 47.479526073701926, 53.99545761846728, 53.404603542820105, 54.236216622014204, 56.68992980833977, 61.38768980579992, 57.325491059211, 49.38480169542375, 43.39603670181767, 44.20166015625001, 42.007384300231934, 41.28765290783298, 42.14047032017862, 40.9698114856597, 41.299529844714755, 47.116067486424605, 47.673393141838815, 49.766722879102154, 47.457121495277654, 45.74029614848476, 50.319498585116484, 46.946275926405384, 44.48115256524856, 44.27364349365235, 41.761796859002885, 46.68446948451381, 42.07045209023261, 43.54449841283983, 44.393213025985226, 42.47573491065733, 46.50061230505667, 56.21454246582524, 54.73680911525604, 57.87404237254974, 57.93318779237809, 54.9157750991083, 57.615091416143606, 57.197684549516254, 54.146292363443685, 53.23686338240101, 48.49709480039535, 42.12943277051372, 41.383837269198516, 40.11947301126296, 41.557347236141084, 41.51477775266094, 44.225249290466316, 44.07728572045603, 45.25326328892862, 46.3084279337237, 50.801000902729655, 52.36274357764952, 54.839194743864006, 46.840658264775435, 49.65766137646091, 44.083843923384144, 47.1798962162387, 43.822994539814616, 44.44023832198113, 42.6232042620259, 43.29536122660483, 42.55898721756474, 42.747747359737275, 41.115201980836936, 45.05372055115239, 46.63320410636164, 49.476675371969904, 45.195690739539366, 52.689641752550685, 41.18426707483108, 49.53838209952078, 52.54939348466935, 57.73693200080626, 54.567500006768014, 64.59765165082871, 58.984685021062056, 59.584070251834014, 46.85359424160373, 56.81653999513196, 6.214587121240555, 3.6451000311682304, 2.9080388719035737, 0.6222031289531339, 1.4950398283620037, 26.515383182033418, 69.22006683964884, 57.75464542450444, 67.23203705203149, 67.07535405312815, 70.50241516482446, 48.06102529648812, 46.5032716720335, 39.29228436562323, 60.51006340211438, 45.05933346286897, 0.825884641418534, 0.1905397490988816, 0.1846171999650617, 0.15130101673064694, 0.17495349109653505, 0.15016708402864395, 0.1653791387234965, 0.155671609625701, 0.24055870219824776, 0.19749161396776477, 0.17287691784722192], [0.054272269424531734, 0.02390210603123471, 0.022151740680959438, 0.01949941405215331, 0.04608575044380081, 0.01968542786104785, 0.011305191099733837, 0.10315121857509499, 0.050058410457906224, 0.04088294857572164, 0.04379383753985167, 0.04839147974346434, 0.011509879259392621, 0.04461334477509222, 0.03312384536970527, 22.097209730455955, 56.84789149991928, 21.53380636245974, 18.407353739584646, 36.6889915927764, 56.832417749589496, 61.8540164732164, 48.918494639858125, 53.03788938829976, 56.845204676351244, 55.10541385219943, 47.49479586078275, 0.8334537739715269, 1.7793118905636574, 0.4792934103358177, 0.13398128561675549, 8.467485250965241, 58.39030865700015, 62.82025314146473, 62.20151101389239, 62.414429033956225, 61.26719459410637, 62.830282641995346, 59.37316833003875, 59.25101003339214, 57.78905637802617, 56.35521827205535, 57.01492955607753, 58.057217059596894, 57.64496026500579, 57.179963281077725, 53.25418064671179, 52.88812545038039, 54.72568919581752, 52.03009520807574, 47.71205202225716, 45.9414392132913, 45.4266438176555, 42.56696531849523, 43.945101845648985, 42.3875129607416, 48.68907128610919, 53.20700630064934, 55.87646945830315, 55.0427657558072, 55.85172714725618, 50.29358348538799, 47.96480563379104, 43.02147388458253, 41.75627416180026, 41.07300904489333, 40.486548023839156, 39.02036997579759, 39.64459557687083, 38.91226160910822, 40.552851769231985, 47.143131840613584, 48.98304116341376, 50.981598592573604, 52.02737700554633, 55.478282205520145, 47.725380236102694, 44.067009110604566, 45.36163837678971, 43.61894892108056, 42.33186237273678, 40.892980098724365, 41.026850592705514, 43.126342373509566, 44.0694135235202, 43.09261783476799, 41.302652051371915, 39.78780523423226, 39.282011678141934, 39.771656836232836, 39.92680226602862, 42.111872319252264, 41.367614346165816, 42.517013934350786, 42.5248469075849, 41.419962298485544, 42.17580695306101, 43.499948132422666, 43.200118234080655, 43.62948048499323, 44.75478887557984, 45.28705058559295, 50.246063970750384, 53.584612877138206, 50.47361243155695, 51.38803458982899, 51.1534611640438, 53.27996238585442, 50.31459954477126, 45.86115221823416, 39.34350267533333, 35.72230777432842, 38.06145637266098, 35.85502901384908, 39.22767508414484, 38.7417051869054, 38.45797269575058, 40.60679220384167, 39.28889936016452, 40.83961625253001, 45.07257538457071, 44.83532297995783, 45.88603573460733, 45.2297329902649, 43.58498904012865, 40.34320892826204, 40.2593368868674, 37.57317619939005, 37.893331819965, 36.552485266039454, 39.04319032546013, 37.801881759397446, 38.60574014725224, 37.666136372473936, 41.36274668478197, 41.761887073516846, 46.00788024164016, 47.20153985484954, 47.182747779353974, 49.708048143694484, 51.033091468195764, 50.10699633629092, 53.086177687491144, 49.77667000985915, 55.28669403445337, 54.50102759945778, 54.94373375369657, 53.915900184262185, 53.222899744587565, 2.951158467800387, 0.1549093674628004, 0.2779663924969012, 0.32962915577715446, 0.2732472908833335, 22.300604235741403, 55.77092632170647, 49.481237088480306, 55.80883995179207, 51.6534496122791, 50.84105222455917, 39.28237645856796, 30.049666204760154, 27.08229511014877, 45.6409268225393, 12.94890986334893, 0.13026396653825237, 0.059759807021867846, 0.04877054004839832, 0.06144771322367653, 0.02604615438969866, 0.08318055511241959, 0.01970665232699004, 0.046933269683992675, 0.04360471341398455, 0.03601380098130434, 0.0368860533701316, 0.07007573250560992, 0.04210110881455964, 0.04183978856270833, 0.036009909254648996, 0.027087449824677843, 0.02189264208408854, 0.050084599173597755, 0.028691191691905264, 0.03015032871776531, 0.0093896581505936, 0.05991678992887178, 0.03054943179801828, 0.07437068187902052, 0.022148025154526678, 0.033260254985502655, 30.55126870832136, 63.647932083376, 15.980773548926077, 28.621523380279545, 50.478950777361476, 59.659195407744384, 70.29154854436075, 55.98122027612502, 58.83101440245106, 63.08211449653872, 59.676630343160326, 50.46823486205071, 0.9439004248669072, 2.7224507014597616, 0.44265608273206225, 0.08556802982404348, 11.222206027277055, 59.48888609486242, 62.36232819095735, 63.6458061587426, 62.03945436785298, 62.2024170814022, 63.24800329823648, 61.44589385678692, 60.81573763201314, 59.425786925900375, 59.27281448918005, 60.2433971435793, 59.53185173772997, 59.856055244322754, 58.63717479090537, 55.84246643127934, 54.67358443044848, 56.20394814398981, 54.61414875522737, 49.42716329328476, 47.580652621484575, 46.47738402889621, 44.862732502721975, 45.031139466070364, 44.93462170324018, 50.071240009800086, 56.202853802711736, 58.13388762935516, 57.33645408384262, 55.63507895315848, 53.9528920573573, 48.25028750204271, 44.315499105761134, 42.76152272378245, 43.25809478759766, 41.57852019033125, 39.317560119013635, 41.79845533063335, 40.65888912447038, 42.979673185656154, 49.52449690911078, 50.87826375038394, 53.058434763262355, 54.068841242021136, 56.72783167131486, 48.82326341444447, 45.39045995281589, 44.57157104246078, 45.08247544688564, 43.35735820954846, 43.54561236596877, 41.844715764445645, 44.719840557344504, 46.151776313781745, 44.42308579721759, 43.45016148782546, 41.27035133300289, 42.40902323876658, 39.74470623077885, 42.88666986650036, 42.78533935546876, 44.004612045903365, 43.24375460224767, 44.66635904004497, 41.77406603290189, 44.87854357688658, 43.50325469047793, 44.15426615745791, 42.743589647354625, 45.04218093810543, 46.38951116992582, 52.02124241859683, 53.82942368907314, 53.01365698537519, 53.33803699862573, 55.092626925437685, 54.36745520560972, 50.990784783517164, 47.875281456978094, 41.647091065683675, 37.17030955899147, 39.87911801184378, 38.09510638636928, 42.15666578662011, 40.54452849972633, 41.51333432043753, 41.69450075395646, 42.03415055428782, 43.56560468673707, 49.17393899733021, 47.8205055575217, 47.34127821460847, 47.79088774035054, 45.68993291547222, 42.3694622132086, 42.89182778327696, 38.84957821138444, 40.48367684887302, 38.929119956108835, 40.2271891409351, 39.24847149079846, 40.92981899938276, 39.82041189747472, 44.39754724502564, 45.4129155220524, 50.162666536146595, 50.149012765576764, 50.65566139836466, 51.554935363031205, 52.86715645943919, 53.548723190061516, 56.252467863021366, 55.174828037138916, 59.56145386542044, 54.774554083424235, 58.50366123260991, 53.26906604151572, 55.92957442806613, 4.102823960204279, 0.7824153417060453, 0.3380686561426809, 0.5001857924845912, 0.585511991333577, 26.513290597546487, 60.86394356143091, 53.82978454712899, 61.29430601673742, 60.68493443150675, 52.79887976184968, 52.358146559807565, 35.9163317372722, 22.184121608734134, 57.8866998610958, 17.025838090527444, 0.11649510657955563, 0.057498415060822046, 0.0554017243426173, 0.035722618622164574, 0.01833188264901119, 0.06345573692552506, 0.035209860652685165, 0.015857551761362103, 0.03558831574815897, 0.04337249301193703, 0.012409524079562436, 0.14402825295204116, 0.13654178128607813, 0.08826127320888542, 0.08153027914945157, 0.22748867530495892, 0.0879808007589271, 0.15467495987972907, 0.1860760458775105, 0.1815709585864698, 0.06649984857968746, 0.18689402859778176, 0.13343511089201898, 0.14556528579804207, 0.17056020667716382, 0.1307481647499146, 37.34874994524064, 76.26287860255088, 29.821370532435758, 27.940856833611768, 51.15349254300518, 68.12131681749898, 75.48101686662244, 64.2173307941806, 64.50736653420233, 66.9773732462237, 65.00355812811083, 57.1303217641769, 1.195089562285331, 7.2044899002198255, 1.1321297600384683, 0.17865478361566223, 14.233419414489502, 62.339637279510505, 65.21094560623169, 66.94343689949282, 65.38874664614278, 64.96359309842511, 65.64080207578598, 60.35196442757884, 59.57152651202295, 61.44392874933059, 61.726547287356475, 62.602820473332564, 64.26635649896437, 63.96185113537697, 61.19161052088584, 59.229860613423014, 58.5391822168904, 58.98040179283389, 58.338148978448686, 52.31060351094892, 50.177140082082445, 50.00711710222306, 47.02759058244767, 47.5047351467994, 46.23397742548297, 53.3086702131456, 57.843310602249645, 60.18327897594821, 61.6766704282453, 58.38359748163531, 55.02356575381372, 49.758858526906664, 47.624955792580884, 44.81712318235829, 46.75213036998626, 44.349054982585294, 42.322048602565644, 44.16190693455358, 41.99768820116597, 44.24200957821262, 50.86351563853603, 52.42049263369653, 54.47214326550884, 54.256232477003536, 59.656610565800825, 48.29467304291264, 45.33313059037732, 45.31608004723826, 46.56524512075609, 43.099552585232644, 45.449169989555116, 44.52279636936803, 46.81296633135888, 49.50157065545359, 45.50500492895804, 45.804273928365404, 43.63012375370149, 42.59863453526651, 43.023584119735226, 46.387251884706565, 46.46141213755454, 46.9989102117477, 45.679228767271965, 45.49337510139712, 43.20196959280199, 44.82268118089245, 42.90390868340769, 43.52309796117967, 43.22422512115971, 46.945260032530754, 44.548676167764974, 51.398954468388716, 56.576918478935, 54.11561158395583, 55.643782692570845, 56.22226561269453, 57.60097088352327, 54.37276217245287, 50.5113927010567, 44.41036947311894, 40.16628649926955, 42.607703055104906, 39.9510621255444, 43.93333081276187, 43.32922304830244, 41.78926521731962, 44.357166444101644, 43.70042439429991, 44.66740631288098, 50.826139373164025, 49.28251412607009, 50.53447584952078, 49.57147121429444, 49.16629822023454, 44.769988059997566, 44.82116714600594, 41.16485134247811, 41.88070351077665, 40.62014787427841, 43.085447742092995, 41.790108526906664, 42.74280909569033, 41.440072290359005, 47.246729481604795, 48.59349489212037, 52.397703662995376, 54.87222502308508, 53.16965356949837, 54.61778479237711, 56.69438169848535, 56.41829782916654, 58.86559009552003, 55.26717239810575, 63.1694656802762, 57.340203869727354, 59.66972304928688, 55.97402272685882, 59.318784667599594, 6.521819512690268, 1.6581781905504966, 2.470059418870557, 0.8151975310137196, 1.9667818180976377, 29.90736261490853, 68.6572616331039, 58.01806788290701, 66.02442556811918, 61.245990260954834, 61.618544824661754, 50.91058408060382, 43.402485078380955, 39.09753084182739, 64.88377678778865, 22.813006985572077, 0.16393944500915467, 0.1666499560158099, 0.12869685708034423, 0.1619423150775894, 0.1155083010634107, 0.20872575711579094, 0.1502742750510093, 0.08931966198067512, 0.11852029065090804, 0.17502513563921376, 0.13286897191597571], [0.034433032175706285, 0.008637157753260146, 0.06624885519305546, 0.04133517410786402, 0.021140971934543024, 0.030816892244582696, 0.03413246523949408, 0.05383204082928358, 0.03345412119562107, 0.07347962203165216, 0.02797850584160657, 0.046897056707811934, 0.042285896882775335, 0.06219358408763524, 0.274938567872009, 4.344552034331906, 53.16902991264097, 44.23214481722924, 32.91368284533101, 27.156698549947432, 46.1263358208441, 63.50025876875847, 53.87111848400485, 53.19776519652336, 57.95872242219987, 52.03084830314883, 50.53156152848275, 1.2841692855281215, 0.8795549227826057, 0.34701061825598445, 0.14488089349000685, 2.920995931471548, 59.65373154609435, 66.28555343997094, 61.72989306911346, 60.507458948319965, 61.55745390922793, 62.192469950645204, 63.630042153020064, 59.952698522998446, 59.01904890614172, 57.025445430509514, 57.59581296674667, 56.825941916435, 56.559754187060946, 55.49706251390519, 54.795499540144405, 57.165787835274976, 54.77197708622102, 48.858270568232385, 45.77613876711938, 43.096214648216005, 42.57956397148871, 43.20117727402718, 43.35414578837734, 42.121391911660474, 47.35915637785389, 51.168170052189986, 52.97472746141496, 54.0250087553455, 53.919606824075025, 50.88872863400368, 46.60176630943052, 43.31664008478965, 41.46625411125922, 40.387727829717825, 40.23016621989589, 39.61412660537228, 41.3931332865069, 38.792162556802076, 42.58739302235265, 47.276092344714755, 50.61131508119645, 50.66487504589943, 55.13861671570809, 48.5059711240953, 42.43674262877434, 44.40587443690146, 43.709485069397964, 42.03096166733773, 41.272873417023696, 41.58025387794741, 43.10221195220948, 41.59109530910369, 40.53748784526702, 38.24359947635282, 40.05604436320644, 40.59597430690643, 40.95770312893776, 39.48448050406672, 40.33521513785086, 38.45155962051884, 39.60263798313756, 39.90863776976063, 39.47832238289618, 43.62349887048045, 43.113112218918346, 42.19812916171166, 43.319923108623875, 44.27431029658164, 45.584860463296216, 42.99980671175065, 41.97929228505781, 45.80857676844443, 53.4145075275052, 50.703961464666556, 52.14343993894516, 50.64498078438544, 48.87788634146414, 41.39015620754611, 39.95733399544993, 36.848259433623284, 36.98587579111899, 37.851817454061205, 37.768208211468114, 38.69955931940387, 37.72208898298202, 38.85788971377958, 39.43013606532928, 40.995075471939586, 46.37799116872972, 44.36426593411354, 44.43613552278088, 45.156753370838786, 41.028831389642534, 38.91787844319498, 39.94932843792824, 39.75993287178778, 38.731671764004616, 38.390849174991736, 38.44563291918847, 37.38171746653896, 38.076471205680605, 38.76059532165527, 40.12774921232655, 45.76215551745507, 48.89229320710706, 50.505360095731675, 53.5313549349385, 52.70677466546336, 55.33568051553542, 53.749489707331506, 55.8794230030429, 53.81350671091388, 58.55767619225287, 53.19418799492621, 58.68781651220014, 51.78831638828401, 63.11728638987388, 7.295724720724168, 0.04742134047011214, 0.8030270905263963, 0.755955461532839, 1.191951911295614, 34.456198061666186, 51.85003096057523, 52.33017221573861, 54.840128267965014, 55.38549461672383, 55.38223120474047, 33.818467740089666, 34.872789075297696, 40.4535295117286, 37.68050401441513, 0.7226297788081631, 0.061480662665299834, 0.05064671235759893, 0.029387042760067893, 0.04350044501705035, 0.06837088043891615, 0.05371241236946756, 0.04831732626283362, 0.01739407611650325, 0.05470173831488337, 0.04342986150614677, 0.0018313037364878844, 0.02518223895270738, 0.013645763035803555, 0.04683558964320729, 0.03943561313433513, 0.04380926655064668, 0.013060325347337753, 0.013956178989892286, 0.08994672026845718, 0.009858060586867074, 0.04415131714795867, 0.0500655465669209, 0.011352641628153864, 0.02096948123747303, 0.09776021954753707, 0.2956701022002005, 6.6746899677861125, 67.04188839081796, 36.755620894893525, 25.16686054968065, 45.468750461455315, 52.586346134062744, 68.59363294416859, 57.57763278099799, 59.71750144035586, 64.4508687142403, 56.15992346117574, 53.258342281464614, 1.6739787233452645, 1.4920931477700512, 0.2507774417679156, 0.20947050183050095, 4.216431244727104, 61.0541118344953, 68.29556419003394, 65.39306125333233, 62.37571524035547, 62.319848921991166, 63.6914860817694, 64.29840618564238, 61.8074736287517, 59.6771441736529, 58.376996132635306, 61.86520307294784, 60.20996678260065, 57.88513875776722, 57.242874176271506, 54.760735573307166, 59.55203625463671, 56.09256067583638, 51.55744175757132, 48.471187545407204, 45.56055745770855, 44.727791201683786, 43.83657770772135, 45.175761176693825, 43.96787512686945, 49.43059536718553, 54.65981691114364, 55.21191012474799, 57.58602665316675, 56.793146979424264, 52.694101487436605, 49.07583267458024, 45.232113868959495, 42.411364893759455, 43.026239564341886, 41.974240272275864, 41.97018061914752, 43.22566855338312, 40.0195663206039, 43.63495219138361, 46.03399930461761, 50.61332725709485, 52.47163249600319, 54.78723118382116, 49.2055493785489, 42.019606405688876, 43.9896168247346, 44.044902632313395, 43.01731617219987, 42.03768068744291, 42.85017613441714, 44.30239054464525, 42.885042082878854, 44.26576345197616, 42.391913860074936, 43.08308255287909, 42.8911139119056, 41.4388838121968, 41.936762025279386, 43.0207404013603, 40.42535904915103, 41.30321295030656, 40.15910463948404, 43.02493341507451, 42.860009516439135, 44.386705813869355, 42.822927428830056, 44.44831448216593, 44.51628523488199, 45.09303446738951, 42.495550724767874, 43.28910504617999, 49.19466087895055, 56.069450070781095, 52.943850563418486, 51.19488531543363, 53.33730743777368, 49.73044879974858, 45.82476831251576, 40.87073241510699, 40.10438757558023, 39.37647019663165, 38.988649768214074, 40.68992683964391, 40.007454041511785, 40.51947239906558, 40.562461576154156, 42.7044169364437, 41.81070097031132, 47.54434324079945, 48.320039010817005, 47.82751091064946, 47.44420513030022, 43.65292841388334, 40.946959757035785, 43.25305454192623, 41.90081350265011, 41.566615796858265, 39.96033068626158, 41.583658495256984, 38.742654400487105, 40.1852511590527, 39.93192880384384, 43.401359358141505, 48.6080547302, 50.68842495641401, 52.03476675095097, 57.53596936502765, 54.67608298024824, 58.43437256351594, 54.791510489679155, 58.51228652461883, 56.06605329821187, 61.12085096297726, 55.32618837971842, 63.77955505924841, 54.02409092072518, 66.8611063495759, 8.532605421158577, 0.30845503713334765, 1.372614442821472, 1.030052895507505, 1.4480616008081746, 40.28368696089714, 58.778501710584095, 57.041982143156, 60.74071838009743, 59.81708649666079, 59.25996088212537, 45.96658945083619, 32.62655946516222, 40.52422238934425, 46.432665086561634, 1.5730473134786853, 0.12201113881723535, 0.0755311748493583, 0.09987480607965302, 0.031135642277677695, 0.024053940827387477, 0.07315806428631468, 0.05849684979165754, 0.06792474147533217, 0.06972572225476466, 0.10888426819996488, 0.09523256606752835, 0.15434312123444774, 0.11657028278756527, 0.1868784310476434, 0.16745454751916472, 0.15928209008228394, 0.14119637829642143, 0.12539060546025155, 0.25109213536545155, 0.16965041598004682, 0.1199419353337538, 0.1131315439218475, 0.10920947252382195, 0.19513390177199919, 0.18439342568237937, 0.4208226994641366, 8.668747948062036, 72.49649324724751, 53.68012651320427, 43.732893774586344, 39.940365822084495, 58.77701120991861, 72.63787900247883, 66.49629454458913, 65.08797145658924, 71.00957762810492, 61.13060197522564, 60.707954822048066, 2.3201358895148, 4.884139751234363, 0.6635137767561021, 0.38092456457595675, 4.797032735040111, 63.97191593723913, 68.85304281788488, 68.24094910775462, 65.67430696179791, 66.59921753791072, 65.67485609362203, 69.05096561677995, 62.68522947065292, 62.21077172986923, 57.88823350783318, 62.434629240343654, 61.864273471217004, 60.982257935308645, 58.91505902813327, 57.964829552558164, 62.369490438892, 60.15063308900403, 53.493582510179095, 50.44626566671556, 47.00083217313213, 47.92959843912433, 47.118240479500066, 47.676707544634425, 45.58646079032652, 51.08673380267236, 57.27277832646524, 55.718499921983295, 58.73990951045867, 59.30547606560492, 54.69552616919241, 49.92771656282487, 48.16618796317808, 44.194623424160866, 44.555787424887384, 44.21097578540925, 43.93735516455866, 45.505506992340095, 43.10800529295399, 45.765744486162745, 48.60793313672466, 52.72534708822928, 54.12276990952031, 58.386770679104714, 49.39954588490148, 42.787665320980935, 46.06999097331878, 44.286936406166326, 44.15482313402238, 45.00055674583682, 44.00855795029671, 47.079220741025864, 44.832942101263235, 45.366521727654245, 42.18123159100933, 45.412127125647764, 45.579761382072206, 45.35153435122582, 44.32342229350921, 44.69669072858749, 41.20360828215077, 44.523572998662154, 44.0036000743989, 43.9847570080911, 46.091320822315836, 45.135827525969475, 43.888321615034535, 44.54791522795155, 44.22080916743125, 47.24794541635821, 42.52499595765145, 43.223099400920255, 49.34539364230249, 56.2759393261325, 54.39582570906609, 55.80269752010223, 55.48818619020524, 52.01890076360395, 47.2477061517777, 45.306972303698146, 41.326111747372536, 42.043662301955685, 41.87959740238805, 42.202298641204834, 42.71373256560295, 41.839777500398704, 41.67370042493267, 44.65933799743653, 44.23724782082343, 50.73290855653825, 50.44581459414575, 49.61550766421903, 50.73021388822987, 47.01099111187843, 42.81594953229351, 46.42579309401974, 44.84614872163342, 42.847104918572214, 42.134386724041356, 43.985733678264005, 42.117948070649184, 41.95563647054857, 42.018606201294936, 45.2789822701485, 51.84103304339994, 51.90678373459847, 56.39032348509758, 60.18526761762558, 58.72773839581398, 61.745178545674975, 58.03883683296942, 60.99834749775549, 57.3630791325723, 64.73396970379737, 59.48901553307811, 65.4047969848879, 55.84238406150572, 69.93951582139539, 11.194708251184034, 0.597551706577501, 2.864175251414699, 1.2967892664094127, 2.0061615566092152, 45.548794269561775, 66.13840964532667, 62.6234874417705, 68.1818703682192, 67.84861010889854, 67.80338518081173, 45.088508052210656, 48.106473799674745, 50.95816635316419, 55.88297667041902, 2.505706899589108, 0.34780345797058076, 0.21685206541611304, 0.20898104825567818, 0.18076255196525207, 0.23947219033875775, 0.12318171350465668, 0.09454242810006104, 0.10614207179676141, 0.27437932368728424, 0.14206218022492625, 0.21827800019133478], [0.032399566693892407, 0.040054746242540504, 0.08407196736023312, 0.05200194870872844, 0.06729720055215782, 0.05133914092795984, 0.05503199115816144, 0.01849883235991001, 0.042558735266568205, 0.02799503801901254, 0.08393658430225427, 0.037208093750861385, 0.05165380771241842, 0.03016108842266183, 0.019485373575721058, 0.03670697648739142, 28.494664122981412, 50.20564002375449, 32.560716598264634, 28.056035272536743, 40.28636986209501, 57.225568679071245, 52.843857580615634, 56.31217025941419, 59.385249230169485, 53.92205830543272, 55.98816287133002, 4.3498580205825075, 1.0734070981702497, 0.0737688661883435, 0.19003771636034214, 2.5170724574596655, 57.37425004282306, 64.77360133201846, 59.97736238664197, 58.467995120633034, 57.84354594445998, 59.592699466213105, 59.92295911235195, 62.606687930322465, 59.62871859150549, 58.30813107951995, 60.49653122501989, 57.617660568606475, 55.96781753724622, 53.727030215724824, 58.98676779962356, 56.670059081046816, 51.361107518596036, 44.71914237545383, 41.92945857201853, 43.30897185110277, 40.1925899136451, 40.10312457238474, 40.96866615356938, 43.47713954987065, 44.64555871102118, 49.986936507686494, 51.14813850771997, 52.92694907034598, 53.369447338965635, 48.785102675038004, 46.31227577886274, 44.99723057593069, 41.80744932543847, 39.89382689998996, 40.135017364255845, 40.092083100349676, 41.479951027900945, 42.452922405735144, 41.70771521906699, 45.42375303083851, 48.80911150286275, 49.02395932905136, 53.27795805469636, 44.74542617797852, 41.955318758564616, 42.984540847039995, 42.16666783055952, 42.19597185811689, 43.61006867501044, 44.08659742724511, 39.136801611992624, 40.48641858562347, 40.582983416895715, 39.437702317391675, 37.664496821741906, 39.009348115613385, 37.86307465645575, 39.67637854237711, 37.61182331269787, 36.69130579117806, 39.43607453377017, 38.111717624049035, 37.359854175198464, 38.94169507488128, 39.98694396788075, 41.693386800827525, 41.25238687761369, 40.94729315850043, 41.1468594304977, 42.69193203218522, 44.850557465707105, 43.83312994433988, 48.3776350944273, 50.796866724568034, 49.458754062652595, 47.139762524635564, 45.42016798450101, 41.85773411104756, 39.01550231441375, 38.550254298794655, 38.69551927812638, 37.696499439977835, 36.603083841262325, 38.50198953382431, 38.39436361866613, 39.35231624111053, 38.12233155773532, 40.301423918816354, 43.5957363344008, 44.63415245856009, 44.29076463945451, 42.43535018736317, 39.59860578660042, 39.28350217880742, 39.60153579711914, 37.81684167923466, 37.54678257050053, 38.37634817246468, 39.07307878617318, 38.18486198302239, 39.154875893746656, 38.424365828114176, 38.88340473175049, 43.514409911247995, 49.11325208602413, 52.08325901339131, 56.94194601428125, 54.55969841249528, 56.22632526582288, 55.01765081959387, 54.30332445329236, 54.212199949449115, 55.38283917211718, 50.5828151395244, 53.722374362330285, 52.89926890403994, 62.002666458006836, 16.590966870707852, 0.3798269750850816, 0.2016449443274929, 0.420197326569788, 1.9445181998514363, 43.84346538974393, 51.01147136380596, 51.61732066062189, 56.82764814745996, 61.58187458592077, 43.37595024416524, 38.91052007675171, 34.780652599949995, 46.56040491596345, 17.886621836693056, 0.14739412153440137, 0.04260170130780147, 0.09045063758329039, 0.06951102611398505, 0.0719951045128607, 0.031229647011646343, 0.06566430712419172, 0.04801141586334956, 0.08897499902354133, 0.09194408768727895, 0.03581071490301721, 0.04252962392544554, 0.007260408216801983, 0.017527645461321358, 0.030792136113309575, 0.05199607281434921, 0.09877868747759251, 0.05852137992699301, 0.04078760893354493, 0.07109421575742383, 0.0720273185100767, 0.03181716941687609, 0.0264193196480553, 0.01543748276984139, 0.00968509517054284, 0.051789573814359405, 0.04501079502064855, 0.17788785299466503, 36.19332951884116, 53.527208989666356, 23.964793336006906, 37.123951065924864, 50.29488963465537, 62.866831287260986, 63.150406883608916, 59.32706871340352, 64.4495076517905, 59.04493262690883, 61.57446130629509, 3.9724350600473346, 1.602924497377488, 0.07256677464371727, 0.0800009454870897, 2.6010440289974213, 59.333846569061286, 67.74296499067738, 61.973825270129794, 62.11095133135396, 59.595280385786495, 61.31693417026151, 60.94439921840545, 64.21509504318237, 60.98505066287134, 59.22146674125426, 59.53503277993972, 57.1127103221032, 56.944738741843935, 56.16128060125536, 60.25354039284491, 57.60690150722381, 52.983391977125606, 48.095204830169685, 43.72147183264456, 44.14691171338482, 42.04443108650946, 42.098085188096576, 43.06187429735738, 46.890044827615064, 48.05358848264141, 51.363315813003055, 55.37999153137208, 54.666673214204856, 54.367286543692316, 50.60327029997303, 48.694841092632664, 45.84227777296498, 43.52194086197884, 40.533228151259884, 42.01774327985702, 41.72325564968971, 42.54690631743401, 41.950596224877145, 43.68774729390299, 47.851139268567486, 49.75738371572187, 50.872207610837876, 56.14310826024702, 44.00034058478571, 41.5629562254875, 44.97777169750583, 44.48156441411665, 44.29204725450085, 45.170411063778786, 45.39416659262873, 40.808688363721295, 43.253905696253625, 41.24362038027856, 40.90389213254375, 39.65020456621724, 41.155355284290934, 41.25430883899812, 42.43601306792229, 40.491258790416104, 40.06328505854453, 40.56861185258435, 38.319732681397475, 40.10678022138534, 41.17937980159637, 40.66576503938244, 44.7400172295109, 43.00747102306735, 42.13468482417446, 41.570663682876095, 42.49956330945415, 44.34208493078909, 43.51725362962292, 49.57679387061827, 51.74119303303381, 51.501877461710286, 50.04862362338651, 47.6905535113427, 44.355452368336344, 40.55431089093609, 38.81563794228339, 41.15864615286551, 40.26534595797139, 38.580382024088216, 39.68385457992554, 40.834415189681515, 41.52232439287248, 39.05672642492479, 42.58882468746555, 46.544232983742994, 45.97065694870488, 46.88181569499355, 43.92876517388129, 42.309191073140795, 40.89810663653959, 42.86342590085922, 41.30135374684488, 39.77808560094526, 39.83326158215923, 41.76824523556618, 41.06489758337698, 42.28767687274564, 40.13249135786488, 42.032785569467855, 45.276401350575114, 51.30331139410696, 53.176670689736646, 58.03919769102528, 56.513831077083466, 57.92112650409822, 55.82030503980575, 57.00763002518685, 56.7916407892781, 59.60449403332126, 53.487930374760786, 57.711111037961906, 55.142256675228, 65.85883878892469, 19.33627886156882, 0.31392487426919324, 0.38178825210179057, 0.4883065266955284, 2.330840773159458, 48.35592085315336, 55.752102867249526, 57.35883905041603, 61.561905799373505, 67.23224101528045, 49.473090325632405, 47.5588010972546, 31.02598532553642, 53.17470558228032, 23.288755186142463, 0.14859641992276715, 0.02881437096925032, 0.04998048782468804, 0.03628050300082372, 0.03421038021183303, 0.05157519560006838, 0.03857306324906888, 0.040719871439280055, 0.09064340828767709, 0.029701786153318904, 0.07185508662293996, 0.08539199814080231, 0.09785358268286913, 0.15505904572144633, 0.17000467035799258, 0.15587529708300868, 0.16489399056280815, 0.11603186853350171, 0.14069318110423704, 0.1538983305856105, 0.18575309385215083, 0.17623818990203644, 0.1676781532625037, 0.0981176685121271, 0.10213332521098276, 0.19549103664054027, 0.19700919308008688, 0.3489718646291764, 44.44745940546836, 67.38588025493007, 42.80783414840699, 39.263823647652906, 54.26170026102374, 68.09961042096539, 69.5641528406451, 68.46377111250355, 69.76660989945935, 66.31430441333403, 66.52144478213403, 5.3425206772742735, 3.7327230841882773, 0.1349210916387458, 0.4131124535154912, 3.8244994369245346, 64.05053592497303, 69.73760789440524, 65.1511686848056, 64.27554661227812, 63.251866832856216, 64.21204343918832, 63.43761067236624, 67.91430980928483, 64.78193244626446, 61.17839213340514, 60.64578133244669, 60.24992004517586, 60.388407168849824, 58.97016440668414, 60.79484316610522, 61.081384074303415, 55.770130080561486, 49.358384532313195, 45.24462230743901, 45.91174294871669, 44.24809709672005, 44.235290558107444, 45.4532531769045, 48.55902118067588, 47.569171843990205, 53.3242694793209, 55.03014356859269, 56.87318686516055, 56.52418221196821, 51.67037856194281, 49.984865496235514, 48.38944535101614, 43.67715297206756, 42.662757442843535, 43.6775295196041, 43.97934413725331, 45.537117373558786, 45.88555720544631, 46.405989047019716, 49.73922314182405, 52.01338983351185, 52.48319956564134, 56.86747981655983, 46.04132236972932, 41.882829435410045, 45.48138441578035, 45.44549865107383, 47.132058989617136, 47.85323773660968, 47.70609786433559, 43.62684465223744, 45.656126006957024, 45.580208532271854, 43.520026745334754, 41.673088535185784, 43.51412750059559, 43.50420390405963, 44.39869257711595, 42.546718043665734, 43.28387652674029, 43.455609659994806, 40.17341736824282, 43.29962484298214, 43.76115445167788, 43.06944839416012, 46.86910721563524, 44.39451917525261, 43.31524372100831, 41.85361562236663, 43.854389190673835, 46.161676376096665, 44.8906833125699, 52.26359782680389, 56.1485799666374, 52.87562877901139, 52.89367952654439, 50.33666287699054, 48.24381559125839, 42.88721115358415, 40.66061888971637, 43.537748013773275, 41.894314135274584, 41.029541338643725, 42.37856603437855, 43.653148066612985, 43.709967520929155, 40.60860826123146, 45.02163164077267, 50.84027167289488, 49.058319291760846, 49.55519337807932, 46.419482000412486, 44.31384778791859, 43.20625282103016, 44.57497173740018, 43.63056698153096, 41.689574257020034, 42.72400917545442, 44.41021257831205, 43.60588350603658, 45.25737001049904, 42.890729519628714, 45.400716950816495, 49.324083405156294, 54.601691307560095, 55.4416198115195, 62.49277053340789, 56.85387311443206, 60.72742938995362, 56.808424611245435, 59.36880273203696, 58.60133217227075, 63.63040693344609, 56.213444202176994, 59.85970304858301, 58.55279284138834, 69.28720997225854, 21.62375415525129, 0.31176904156323404, 1.4158009641593503, 0.9404109863023605, 2.9818622912130053, 55.631890066208385, 60.98020261333835, 63.14699049918883, 65.51627074518512, 72.11467404519358, 53.662381710544715, 53.74479070786507, 44.33788014996437, 59.81764739559543, 30.710818959820656, 0.20866086946860438, 0.1505736622118181, 0.23771648535565024, 0.16505394972139792, 0.10932058591635958, 0.18329923762188804, 0.24950559791778368, 0.10317922674960668, 0.16177513937075294, 0.2730293235471172, 0.18693110725331694, 0.23473335430026057], [0.022188572273139032, 0.0823155269327183, 0.017305296102178194, 0.057474536100222226, 0.08810741977105219, 0.03509208612564591, 0.028577331874159076, 0.0706667310347961, 0.11791105922912398, 0.05330859210282084, 0.01217286036755409, 0.037578359366424625, 0.01723724642708417, 0.14752147599093376, 0.19721053630834628, 0.33779497889261095, 11.015080367365192, 55.91457136215703, 42.80578667117704, 23.2648620682378, 28.47922763516826, 47.69888854795887, 49.807080145805116, 59.41174876305365, 59.35929882910944, 51.57768118766047, 56.77095028661913, 10.759047654367263, 0.9327869405669551, 0.021344475530748887, 0.06215825211256743, 1.5261273086071017, 54.16603365252095, 66.31020945887413, 55.65942118244787, 52.8019666671753, 47.15493033009191, 54.86168561443206, 53.40436427823959, 57.475160860246234, 57.933466280660326, 60.38056242850519, 58.936820337849284, 59.54064961402648, 58.665239349488296, 61.37628355333882, 54.7980647702371, 48.88398170471192, 44.00175263804775, 42.61766979771276, 43.27876175603559, 42.8664892719638, 42.14243542763495, 42.42839582504765, 43.03938734915949, 44.80974520406416, 44.02140763498122, 50.21763855411161, 49.516589410843395, 51.169633096264256, 49.702717642630304, 50.66784820249004, 46.49346966897288, 42.193500764908336, 41.720274648358746, 43.110421472980136, 39.18610188268846, 41.55689616357127, 41.74304008483887, 41.588114307772734, 43.39005116493472, 44.55783097974716, 48.079232938828014, 52.530224861637244, 54.203088283538825, 45.81668038522044, 43.36623453324841, 43.46166187717069, 41.070263385772705, 42.880617649324485, 41.267797870020715, 38.70530559170631, 39.08091568177746, 39.664062300036036, 38.70884356960174, 38.33615172293879, 38.70688630688576, 37.608912914030014, 38.41081403916882, 39.52207249979819, 38.755900244559015, 38.288985221616684, 38.93732947687949, 36.81580182044737, 37.315264671079575, 37.37859918225197, 35.89410366550569, 38.424032426649525, 41.07823364196285, 43.57943496396465, 42.1624630497348, 41.92235908200664, 42.55478635911019, 42.38007222452472, 44.603942363492905, 52.63219471900694, 47.81390420852169, 46.78971059860722, 43.27162304232198, 42.166812958255896, 40.34211458698396, 38.09081531340076, 39.1296354416878, 36.67886403299148, 38.71417799303609, 39.26120742674797, 37.1521411403533, 37.15576541039252, 40.19976785106044, 40.49582835166685, 42.72633906333677, 42.92223399685275, 41.87116822888775, 39.82690342010991, 37.64027618592785, 36.82479189288232, 39.806012876572154, 37.35958745402675, 37.69611897007112, 36.45758351972027, 38.02508031168292, 39.337917220207956, 37.438007400881865, 38.24807490071943, 38.01271700089978, 39.87199890998102, 44.10451089182208, 52.778765847606046, 54.51183372928251, 55.15598104846094, 53.30910559623472, 53.655996091904186, 56.51703565351425, 51.48223423188733, 50.582783760563025, 47.129631042480476, 52.90239503306728, 52.71323088676699, 61.08018382903069, 29.043803791846003, 0.15445679336065246, 0.36189555340716917, 0.4572742660680125, 2.730477341721135, 47.3516881850458, 50.94235135662941, 55.427777767181404, 50.44423780133648, 50.62403532766527, 37.71715464130525, 26.876203975369855, 35.7867483938894, 51.96354435336206, 4.314488537849919, 0.4289882774314573, 0.04322000704104862, 0.05879805641128652, 0.0245233190681545, 0.062457570325463056, 0.07663485473923146, 0.1000625818907734, 0.07631802375638679, 0.0474169124819098, 0.07718096051605479, 0.045910412070131114, 0.04847248205013814, 0.04734459378185773, 0.0406039240319402, 0.025850895814777865, 0.03659756764048531, 0.018003374570980668, 0.025808123210745475, 0.05884226734539675, 0.028970520755636598, 0.044648615463126096, 0.02295087763829337, 0.08815055818206842, 0.018854975144589142, 0.08136336391250934, 0.017971355926185366, 0.1289212289116075, 0.47883063194251835, 16.9556257032579, 69.24578189849854, 35.41739448424309, 22.690562355902888, 48.7528843264426, 51.08474123862482, 57.70670229388822, 63.56119671175557, 66.65351098583591, 56.261971765948886, 64.60054636001587, 11.546067307072303, 1.7672718075975296, 0.06872007097568243, 0.05139707632723355, 1.5987780618090786, 56.44504054900139, 68.77102605758175, 60.02956128889515, 56.59925245469617, 50.83568642216345, 57.72179165194112, 54.26925474597562, 60.24951211867794, 60.413753524903335, 63.78091219932803, 61.64247128271288, 61.194163983868016, 59.810806782014915, 62.90888694024856, 57.205811700513294, 52.312109701095096, 45.19750287455898, 44.681028704489435, 44.27691475037606, 44.4289497406252, 42.61550072700747, 43.742060353679044, 43.38377537265901, 46.69460488903908, 46.82111309420678, 51.937558650970466, 52.123847699934444, 52.97266821707449, 51.87940166842554, 51.29707874790315, 47.66984731920304, 43.94821620756581, 43.95511173432873, 42.96539575822892, 42.03300129982733, 42.72249121819773, 44.79243186212356, 42.49285213408932, 45.14387622956307, 47.12643823316021, 50.01903718517673, 52.90006514518492, 55.037129309869584, 46.73720967385077, 43.712375856214955, 43.13414004541213, 44.41487627644693, 45.77254587604154, 44.07037058184224, 41.16686744074668, 39.76661659056141, 39.85000618042485, 41.78858272490963, 40.33408549524123, 43.16144366418162, 39.93116001929007, 39.56099810138826, 41.0699103724572, 40.48481041385282, 41.3099515822626, 40.98482631867932, 39.49162706252068, 38.3781877640755, 40.96978795143866, 38.71921431633734, 39.820988485890055, 43.99986597799486, 44.77827995054184, 41.760263212265514, 42.56312139572636, 43.08584782385057, 42.350517165276315, 46.23587977501654, 53.14569181011569, 50.07842971432594, 48.05397679728847, 46.946287693515906, 43.89657428187709, 41.637838194447184, 39.62368149911204, 40.79918838316395, 38.777649787164506, 40.66014820529569, 39.78343179149013, 37.71906875794934, 40.55031007336032, 43.22757482528687, 42.510165476029925, 44.47497875459733, 44.253423675414055, 44.844352276094504, 43.07029954848751, 39.70456861680554, 39.617233122548754, 41.57750037408645, 40.289707799111646, 38.01167757280412, 38.89867451883132, 39.164003249137636, 41.4307370493489, 40.90979922202326, 40.11762165254162, 41.02947858072097, 41.94495977893953, 45.18825000332248, 55.63040348791308, 56.5347529995826, 58.387464938625214, 55.41357486478744, 55.61933063691663, 58.92163292054207, 56.936984216013265, 54.584417189321215, 49.89381159505537, 55.090544146876184, 56.64672490089171, 64.74889432230304, 29.79521812931184, 0.13420748073727856, 0.3896393050109187, 0.26579782126411317, 3.646817784155569, 52.16154952203074, 55.67808774209792, 59.122387670701556, 59.6289853126772, 56.223356031602435, 49.02880345621417, 34.73829100208898, 33.32193489997618, 65.16783483566778, 6.498746660447891, 0.27978839472897593, 0.027403263825803038, 0.029755192057740305, 0.018938327425970666, 0.07098072749232093, 0.04268159661742468, 0.03939890603144323, 0.08171068519474038, 0.05170652605292778, 0.02982479689132062, 0.02389358904873652, 0.024417836421860323, 0.09239717506833615, 0.14507157277436028, 0.07392100358922636, 0.16453544609248638, 0.24755938218966608, 0.16017735575235661, 0.1444913531022687, 0.12943383366350206, 0.2350545290016359, 0.14737074053095234, 0.15744400000379932, 0.23330699051580123, 0.14718327881588092, 0.32831369088061396, 0.2997704192755684, 0.711646345594237, 20.848911500746205, 75.12234749332552, 53.9381714021006, 33.26819450624528, 40.53737017416185, 57.87460327148438, 64.42932313488376, 70.61613252086025, 70.72060877277006, 62.59211632513232, 69.2638954039543, 13.81213136257664, 2.6039595757761314, 0.11397703685947966, 0.19713236469655268, 2.482995885995127, 58.74354162523824, 70.90552499217372, 62.31211400801136, 58.7238670164539, 52.61444207160704, 59.58363879111506, 57.45658059273997, 63.22706568625666, 65.29782218317833, 67.6626976074711, 65.34156837771016, 64.01880787264916, 62.03080554162303, 65.15443601915914, 57.37554050260975, 53.9951712854447, 47.751550289892386, 47.49724341977028, 47.1563345386136, 47.89680350211359, 45.66315881667599, 46.61926008039906, 46.24878045051329, 50.06666652617916, 48.69807312565465, 54.42321561997937, 54.38940478909401, 54.597019764684866, 54.81036140072731, 53.59044151921427, 52.32459852772375, 45.5242794559848, 44.69102682605867, 46.932025955569365, 44.524408463508856, 44.97480638565556, 46.780473416851414, 46.356123955019065, 45.99293208891346, 47.588783694851784, 50.645149446302845, 54.83997137315812, 56.06125231712095, 48.15518571484474, 45.29300474351453, 46.002965511814246, 46.28763937181043, 47.35550072885329, 45.86736133021694, 43.34351616521036, 43.91832774685275, 44.51535563315115, 43.76640258296844, 42.495962573635964, 44.306226622673776, 41.72877050215199, 42.33850294543851, 44.124722865320024, 42.8937497446614, 44.73017208037838, 44.057383614201704, 41.18820121211391, 41.253336091195386, 42.81571811245334, 41.521257508185606, 41.932659226079146, 46.69057661487211, 46.689137105018865, 42.898676241597826, 42.75139124162736, 44.371447793899044, 42.417891717726185, 46.08369965707102, 53.7978329197053, 51.32415486920265, 50.55601750650714, 47.69892384929042, 45.867847704118304, 45.734334145822835, 41.72839787698562, 42.553221333411436, 41.43665198356875, 42.8170556406821, 43.553237453583755, 40.50066463408932, 43.334345663747484, 47.62929001162129, 43.317424558824115, 47.1557814844193, 46.99922400136148, 48.42979869534893, 45.01777595089328, 42.682047659350985, 42.89069814066733, 43.77148597471176, 40.351092892308394, 41.364209728856245, 41.47027846305601, 43.32968588798277, 43.49566098182432, 42.57437075338056, 42.55992074166575, 43.092841409867816, 45.574842729876124, 47.24228151382939, 58.589435623538115, 59.5607792177508, 59.78409544114144, 56.36490652638098, 57.478961636943204, 62.51672052568006, 58.62026545309252, 55.77687655725787, 53.25185860356977, 57.904676083595525, 59.76473069960072, 65.5928667899101, 33.10776172145721, 0.26289391902185255, 0.7884777325295633, 0.9237852235955577, 5.558160822237692, 58.93661245223015, 60.61000147173482, 67.75735224446943, 63.716075420379646, 63.713745532497285, 50.32242467326503, 39.17815123834918, 45.4806823115195, 73.07790617788993, 9.64131728295357, 0.48520528020397313, 0.2413475276121209, 0.08404382128989504, 0.13810887542222777, 0.19813240055114995, 0.18038108614423584, 0.182299017906189, 0.13976737916950258, 0.1977707610856141, 0.0915047362627041, 0.11424787192335052, 0.14022758350737635], [0.013885606012697664, 0.05363753110530877, 0.027266419455108624, 0.06740803815304272, 0.01029806797422709, 0.06534171516015645, 0.024244394115803224, 0.029507592440612858, 0.06351078800376385, 0.038111031791495706, 0.029428449812375253, 0.05271943218465294, 0.02663883639709844, 0.045041645381359324, 0.022151987744315017, 0.10080322803508851, 0.15248256945802321, 28.78089124156583, 53.70018943663567, 24.766049231252364, 22.929067957785822, 41.718368376455004, 64.99361099735384, 59.13193471970097, 59.205808639526374, 54.061427962395456, 60.24140850190194, 14.842675289800091, 0.7591999971097516, 0.1560194441868413, 0.20984626795736053, 0.8877319001382398, 49.563697076612904, 71.39259707543158, 56.10425718369023, 54.836880545462336, 45.881454406246064, 47.16212787935811, 47.000098689909905, 49.50737184093845, 49.77110024421446, 52.88164569485573, 52.979995204556374, 56.7652157814272, 53.145436856054495, 49.972153094507036, 46.26863548832555, 44.53887416470436, 40.540319796531435, 42.25780017914311, 41.39696936453543, 40.543940144200484, 42.65654440849058, 42.2567529063071, 41.4463363155242, 43.13708182304136, 44.82723113029234, 49.07460497271631, 47.352966877721975, 48.372383040766564, 49.368186535373816, 48.22552165677471, 45.18678695924821, 42.23172426223755, 40.8199377213755, 39.17954367976035, 40.36893183185209, 40.423456699617454, 39.98986221128895, 42.60671461782148, 44.82245368342246, 42.973448384192686, 48.27699099817584, 49.48556346278037, 51.70983760587631, 50.36706124582599, 46.9775019153472, 44.28441432214553, 42.29779658779022, 41.04494840868058, 38.6998378076861, 37.94403629918253, 38.78663201485911, 37.907279768297755, 39.47326644774407, 39.182277571770456, 38.37392807006836, 39.50196250792473, 38.23200102775328, 37.66757980469735, 39.940103023282944, 38.964260470482614, 38.35962318604992, 36.45557526619204, 36.86509424640287, 37.18655209387503, 38.019545847369784, 38.19862165758687, 35.985447822078584, 38.87485004240467, 41.92015078759963, 43.6626245129493, 42.95806877074703, 43.215309573758034, 46.95567784770843, 53.590053204567205, 48.868684461039884, 47.56281368194088, 43.479944044543856, 42.04921245574951, 40.512898506656775, 39.28394148426671, 39.17284034913586, 38.55335297123079, 38.198680493139456, 36.93743451949089, 38.29384111589001, 39.43400352231918, 37.60763814372402, 39.217080762309415, 39.54079005026048, 39.466708244815955, 40.392575879250806, 39.76538888869747, 38.0921136179278, 37.61549072880899, 38.460259437561035, 38.35383769004576, 39.62339516608946, 38.64006480863018, 37.30883198399698, 38.45195577990624, 39.26401192142118, 38.13251795307283, 37.69208677353398, 38.71989680874733, 38.913273580612675, 42.95459355077436, 48.965986697904526, 54.38873014142437, 54.66812449116861, 54.893699999778505, 51.76238559907483, 46.247870460633315, 41.77232057817521, 44.14661361325172, 52.80690493122224, 53.85947688933342, 62.05196672870267, 36.970182388059555, 0.1638351804426601, 0.06035093961644077, 0.1520530852459131, 1.5285485141700315, 45.93062523872622, 52.22114601442891, 50.31108902346704, 52.030538435905214, 44.43518630919918, 38.525845389212336, 28.3962381270624, 39.44826133789555, 24.947309801655432, 0.06873583706516413, 0.06045437680797712, 0.07114847010422139, 0.054878911469131715, 0.02529684762139955, 0.032276812595345324, 0.01798048577902298, 0.07136678218000359, 0.022542075884919015, 0.030427037760795608, 0.020145124665671782, 0.025206581396501393, 0.039250495648312, 0.055177892603340654, 0.05325134618267898, 0.019158970324262496, 0.019994956110754324, 0.023029353770036853, 0.034183923365368, 0.014279249758880227, 0.04633232350310972, 0.013904708415089596, 0.08966915129173188, 0.007734659734377338, 0.039582361106670676, 0.05504982951547831, 0.03806497075504834, 0.09617447883131043, 0.047721903575884725, 1.0128178171092466, 38.64575224538004, 58.37757272105063, 18.695838182203232, 36.602691604245095, 50.572444392788796, 66.69324459568148, 64.1723882767462, 63.55983564930578, 60.037864946549945, 65.33949736625918, 16.45148640678775, 1.2029459471664121, 0.055256780507343436, 0.05240053659485233, 1.1648306827391348, 50.612507481728834, 71.85538968732281, 58.89880080376902, 57.24251331821565, 48.19475066277289, 50.05977099941623, 47.07845587884226, 50.19679115664575, 53.25670665310275, 55.40365911299183, 55.936077717811834, 59.175425960171616, 56.842670825219926, 53.898692746316236, 49.6121265811305, 48.052007767461966, 42.340103272468816, 44.68014224883049, 43.29203113432854, 43.32350031022103, 43.29331767174506, 44.15867882390177, 43.100568479107274, 44.5659581307442, 45.09258339481969, 51.06518430094565, 50.07029079621839, 53.14295007336525, 50.67708930661602, 50.88856781682661, 47.089007054605794, 43.95283283725862, 42.392517905081476, 42.0757943584073, 43.23887125138314, 44.28826608965474, 41.988090161354314, 43.415621096088046, 47.875014735806374, 46.69969612552274, 49.20360780531361, 52.99239381667107, 54.21988387261668, 51.616461661554155, 48.173879731086, 46.06774345521004, 47.743368225712935, 43.92346997414866, 41.26385981036771, 42.210351267168605, 40.809327710059385, 41.314117139385594, 39.531760754123816, 41.300243716086115, 39.95403135976484, 40.80647222457394, 40.0470817473627, 40.36726482452885, 42.76040484828334, 40.8216243405496, 40.28429492827385, 39.13903736299084, 38.89514830804641, 40.091977196355025, 40.0994610786438, 39.190781270304036, 39.67943799111151, 40.14351321804909, 42.871937444133145, 44.604546408499445, 45.03027654463246, 43.622302547577895, 46.60483752527545, 54.03751327145485, 51.48342271004954, 48.55056455058437, 45.03857627991707, 43.356758086912095, 42.77738871112947, 41.727919347824596, 40.75122956306704, 40.36080468085505, 40.769786296352265, 38.21545647036645, 39.751746885238155, 41.21676783407889, 38.33644590070171, 40.226687077553045, 40.978107298574145, 40.07685253697057, 42.7147602265881, 42.52699244406916, 40.44733608922651, 38.61664041396111, 41.796545136359434, 42.30146400390133, 41.341244251497336, 40.319251091249534, 39.54516349300262, 41.24662491583055, 42.11181348369968, 41.083881855010986, 41.16975038282333, 41.89107817988242, 41.46488520406908, 44.496775365644886, 51.58407857341152, 57.8032632027903, 57.016867206942656, 57.80994692156392, 54.12555086997248, 50.01901757332587, 44.66657869277462, 46.50034166151478, 55.42614606118972, 59.376012048413685, 62.04694217251193, 39.54970952003233, 0.11635569389909507, 0.15436876985815265, 0.25192902513569404, 1.7363111915126925, 52.17990621443718, 57.82771525844451, 55.85771660650931, 58.885221558232466, 47.80228222570112, 54.97985093824325, 26.26353563800935, 40.397604357811716, 34.10916243830035, 0.25394379041127624, 0.046401355685966636, 0.06911178705312553, 0.058392516277249784, 0.0486439478493506, 0.02245878489057143, 0.05422701661084449, 0.026432749169367938, 0.031158856657003204, 0.021886873442018707, 0.08834823951004975, 0.05508094800696258, 0.020605895908609517, 0.1616245111630809, 0.0725975790391526, 0.14924963245228415, 0.1115087092283272, 0.10243425220851937, 0.15053232410742393, 0.21860539552665528, 0.11068180924461735, 0.1072853814149576, 0.18226425283618514, 0.14758835546672344, 0.11499690673043651, 0.1510883507228667, 0.15416923459739457, 0.22071313323272815, 0.2645402419711313, 1.017574365100553, 47.82225101224838, 67.857725697179, 34.45164418989612, 33.03024391974173, 56.174953983676055, 76.06300246331, 68.4694742387341, 69.70418145579677, 65.47006130218506, 72.27414192691927, 19.5394282187185, 2.377113464378542, 0.17686973746505477, 0.6067063346985848, 1.4078858662997524, 53.210434452179946, 75.03458053834977, 62.10144742842644, 59.665918350219734, 50.63141722832957, 53.50056040671564, 50.64020333751556, 54.03579919568954, 55.957450712880785, 56.52698278427125, 56.72695698276643, 62.94205842479583, 57.689043783372455, 56.30384306753836, 51.19232793008128, 49.480181970903956, 43.954197822078584, 47.907119335666785, 45.885443456711315, 44.453574380567, 45.555003381544545, 47.21209887535342, 45.28070419065414, 46.95197120789559, 50.6669617468311, 54.40156413662819, 51.70988467431838, 53.79256517656388, 51.765201860858554, 53.016610530114946, 49.911893721549745, 46.47654856404951, 44.24020528793336, 42.38379847618842, 44.12031019887617, 45.462541349472545, 44.07321822258734, 45.11694915833012, 49.53539325344948, 50.11050685759514, 52.03335862005911, 54.57062613579535, 54.47361415432346, 55.574344973410334, 50.20243544732371, 48.86252241749918, 48.858639271028586, 43.94692182540894, 43.521556469701956, 44.372440153552645, 42.945991792986476, 41.87358048654372, 42.75076366239979, 43.682169683517955, 43.10960561998429, 43.81565970759238, 42.96580760709701, 41.9778057067625, 45.8099417532644, 43.50252512962588, 42.54763195591588, 40.95247460949806, 40.38924970934468, 41.12293297244657, 43.592888693655695, 43.08875822251843, 41.30037707667197, 43.434483774246715, 44.452401591885476, 46.49271265152962, 45.8007045715086, 43.85555805698518, 48.40773144075948, 54.51594829559327, 53.55459890057964, 51.26768450583182, 46.72314405441285, 44.533304399059666, 44.79363602976645, 44.477449847805886, 42.43860967697636, 42.21986301483647, 43.9451842154226, 39.04196262359619, 41.75588976952338, 43.54704010871149, 40.803946218182965, 44.12952384641094, 43.94142266242735, 43.40858436399891, 44.16170297130462, 45.21572620637956, 43.06617713743641, 41.74895501905873, 43.87414224686162, 43.77108981532436, 44.67289370875205, 43.157846850733605, 42.69549746667185, 43.74735555341167, 44.66501366707587, 43.06151343930153, 42.711798837108, 43.96540011129072, 43.94421931236021, 47.54618283241026, 52.16290273974019, 61.3768679864945, 61.3771660866276, 61.195732931936945, 58.63576273764334, 51.879315376281745, 46.362262464338734, 50.475883483886726, 57.53680482987435, 61.95388786254391, 64.55849462939848, 43.19281085844963, 0.19139943764575068, 0.3130647107478111, 0.669615759003547, 2.3767685409515136, 58.61997912006994, 62.9160923342551, 62.664750775983265, 65.99433314415717, 56.54790470677038, 51.01640570548273, 40.318376402701105, 52.51773603500859, 42.88848592389015, 0.32868447743596574, 0.1405052137711356, 0.11424293831711817, 0.14562150132992577, 0.17301656035405977, 0.11133872963968786, 0.12337877430141934, 0.12023871013474081, 0.18758330854677385, 0.1258434706758107, 0.18598941665503288, 0.11228636508026432, 0.15282596070920268], [0.038113199820321415, 0.03697427222505212, 0.052952460809460575, 0.018257606594312577, 0.022067551448520635, 0.02868269386160518, 0.029213104412079822, 0.09349117926772564, 0.04334040158878892, 0.06653284398658622, 0.06731241505833403, 0.030126878766403086, 0.01663972082878313, 0.03136655458459451, 0.11449973865021622, 0.09194461628794671, 0.2677207632410911, 8.503677941137745, 57.215080261230476, 41.247115212102095, 32.78712364935106, 29.007572858564316, 57.92789651501564, 59.91905635403049, 63.11978493967364, 48.30817776341593, 58.76391049354308, 11.068747216655362, 0.5924706437414693, 0.1109399502315829, 0.03158147097565234, 0.09401115378545177, 41.68177658511747, 69.82925799585158, 58.714610222847234, 58.44252324873402, 47.93328546708631, 48.50352356510778, 45.050606189235566, 45.62235047740322, 43.77572997923821, 42.97240895609702, 43.99476689677085, 42.058167226852916, 41.79678832331012, 44.48083093089443, 39.79134713449786, 43.66870026434622, 44.28131957207957, 40.98923898512318, 42.31443920443135, 41.88837174446353, 40.86200514147359, 41.783424808133034, 43.436931333234234, 43.41393839928412, 42.00033187866211, 44.864783902322095, 49.24858954644973, 47.410123655872965, 45.47704627436977, 48.01042672126524, 44.462019243548, 41.2061539003926, 41.462998544016195, 39.575628542131, 40.60896519691714, 42.44503059694844, 42.3454612301242, 45.30475224218061, 47.849303599326845, 42.015562442041215, 47.08884231505856, 47.86593052648729, 50.905512455971014, 47.7004143499559, 46.2973197813957, 41.33423889836958, 41.963700863622854, 39.09893897271926, 39.72131713744133, 39.78631473356678, 38.89122593787409, 38.39638363930487, 36.96791525809996, 37.84275677896316, 38.62463812674246, 38.498698665249734, 39.964841411959746, 36.85972452163696, 38.38930768351401, 38.3093148662198, 38.32455719670942, 38.00400933911724, 38.71198538810977, 36.80854543562859, 38.07835786573349, 38.297112372613725, 37.46030215294131, 37.28112828346991, 37.86983290026265, 38.47176767164661, 41.46848201751709, 43.96174446229012, 49.35527409276655, 51.14068992676274, 46.287525623075425, 45.495136245604485, 41.58746319432413, 42.212116333746145, 44.78212779568088, 38.42161232425321, 37.97528974471554, 40.07137690821002, 37.20886253541516, 38.09992697931106, 39.02401778005785, 38.353892603228175, 39.393022598758826, 38.7273806910361, 38.612223825147076, 37.44591097677908, 38.218543375692065, 39.81092368402789, 39.72533756686796, 37.67473028552148, 37.78581180880147, 39.427829711667954, 38.01918498931393, 36.69396515815489, 38.56927779413039, 36.80257166585615, 38.79395115760065, 37.695518847434755, 38.81530061844857, 38.34864839430779, 40.222658803386075, 37.88150587389546, 40.61064004898071, 43.39202803950156, 44.32795655342841, 44.78685032936835, 41.118579141555294, 39.003197839183194, 42.92603477354973, 45.23915844578897, 52.49370367296281, 56.016619666930175, 62.98249806127241, 31.988964465356645, 0.2853913473025445, 0.10573251353156184, 0.07457079936660106, 2.2710170284394295, 49.30797815322877, 50.45474583102811, 53.764681047008885, 55.780951899866906, 34.284304111234604, 27.969411688466227, 30.796444300682317, 47.660821945436545, 6.822074497899702, 0.3480069615667866, 0.08666514434040555, 0.009231450460520724, 0.061850300088765166, 0.061144667993029284, 0.05326278004494887, 0.02651433944852362, 0.07453691529771013, 0.06066042764653122, 0.04877186921094695, 0.03157311678683806, 0.04497805242276481, 0.013972916095818003, 0.09166850287827755, 0.03354310230802625, 0.036048684794936454, 0.030340343420844407, 0.021220403760972045, 0.009216355655582683, 0.01681265177115077, 0.010645070372359648, 0.025907429273150144, 0.08175810603725334, 0.06634664631658985, 0.03642325199419453, 0.0030981914765547004, 0.08508160995740084, 0.0737288304334206, 0.06556206502981725, 0.25457106320367706, 13.343313009508195, 69.22496980236423, 31.5438146745005, 30.750321149826053, 45.15023439161239, 61.548303019615915, 65.82185868294009, 66.18264613613006, 54.96962139683386, 65.03345443356422, 13.43354223235961, 0.9015570292549749, 0.11766127626141233, 0.15380030197481956, 0.256925757013021, 44.81313805426321, 72.63024607012349, 61.40270463881954, 60.14614197515673, 49.00217448511432, 51.60719310083697, 46.40510259136077, 47.670686706419914, 45.08521326126591, 47.69088691280734, 45.90099957681472, 45.555234801384714, 44.68091495575444, 45.630089313753196, 42.39256497352354, 46.712149650819846, 45.48176880805723, 45.34066546347834, 44.14560164174726, 43.93566070064422, 41.846014068972686, 44.35671144916166, 44.95817945849511, 45.315323029795, 44.748438558270855, 47.711298927184075, 49.75144916965116, 48.94260152693718, 48.8981375386638, 49.84169506257581, 46.427616996149865, 42.79054826305759, 42.95568789205244, 40.276979707902484, 41.86872066990022, 43.42836879914807, 42.51647264726701, 47.668509790974284, 46.50544858747914, 43.40159470035184, 47.99948330848448, 48.928261341587195, 53.40060664761452, 49.23972106749012, 47.92160857108332, 44.768564239625015, 43.63710557260821, 42.479645513719134, 42.12868359781081, 41.77479951612411, 40.053114352687714, 41.220854943798436, 40.23372380964218, 40.80879426771595, 41.51214191990514, 41.09163245847149, 41.27188497974027, 39.248240070958296, 41.15825391584828, 42.016472431921194, 40.472015642350726, 38.45188909961332, 41.44128822511242, 39.80697385726437, 40.75431646839265, 40.006814695173695, 39.510940813249164, 39.38347947212958, 40.45548285207441, 42.4855016123864, 44.0627258823764, 45.53156721976496, 51.62437700456189, 53.27035257893225, 48.23513146369688, 47.490991161715606, 43.96750642407326, 43.87067487162929, 47.453057919779134, 40.265016478876916, 40.06213580408404, 41.53820606970018, 40.251719643992764, 39.646717579134055, 40.726087170262495, 41.44502232151647, 41.28890022154778, 38.72640794323337, 40.595923316094186, 40.41865571852654, 40.60026145750477, 41.389509016467684, 42.91815865424372, 40.13928490300333, 41.8424407897457, 41.562085459309245, 41.37657696200956, 39.07233745821061, 41.336098101831254, 39.40740200781053, 40.96450844118672, 40.25523408766716, 40.4601034041374, 40.90591607555267, 43.40898836812666, 40.07840187318864, 42.68641325735277, 45.64298998924994, 47.27527649171891, 47.2005121938644, 43.02443527406262, 42.338981474599535, 45.87311152488955, 49.86191880318427, 55.28958089890019, 58.89888317354264, 64.81378601443383, 35.20436271544426, 0.17709363432180497, 0.17790764870662845, 0.24619482637893772, 2.2222617220494056, 55.05455247817501, 55.34303495960852, 59.49938235744354, 62.440030344070934, 44.118925602205344, 39.702148514409224, 27.85035598662592, 56.339736676985225, 10.281664806027567, 0.48228847704106764, 0.13910731781394253, 0.022387471680919972, 0.02228375486729126, 0.077091833846944, 0.07016996132029642, 0.0165685378540788, 0.10623351971228277, 0.02540089002239608, 0.026044225763349284, 0.026587960498046972, 0.06059929383017364, 0.04996137010053762, 0.15051363156207148, 0.1076757568385332, 0.26442998659706884, 0.15008649157900966, 0.10363762311997915, 0.10273313375129815, 0.1429993049391816, 0.22610988558059741, 0.23508452900475074, 0.24553701732187505, 0.1752486800955188, 0.1898992536289077, 0.1035325771438018, 0.12251358524325395, 0.2195770248410202, 0.22060592688860434, 0.4161757939765531, 17.15519589762534, 77.64632209654778, 50.692119829116336, 44.60325202634258, 42.15029977983044, 69.33644356266146, 70.00091660407283, 72.94182346713158, 59.666451792563166, 73.23979808438209, 15.256858948738346, 1.6377453385822236, 0.1846579711643919, 0.4642551656692259, 0.26458924095476827, 47.523456619631865, 75.3332611822313, 64.80993424692463, 63.22183324444679, 54.06715854521721, 54.53869412022253, 48.88855126596267, 49.61984188325944, 48.65070266108359, 49.862350263903224, 48.99423953025572, 47.05043838870141, 47.26217969771355, 47.87523438853603, 44.337464378726104, 48.067038289962284, 48.13136908315843, 46.76481531512353, 46.83108768155498, 47.01586661800262, 45.482600350533765, 47.02604516859978, 47.52626503667524, 48.3772663916311, 46.79459394947175, 50.04128486879411, 53.27814240609446, 50.891368389129646, 50.13164058808358, 51.38627344562162, 48.123787141615345, 44.48075248349098, 45.7269718570094, 43.01458620255993, 42.11050341206212, 46.97951801361577, 46.234448109903646, 50.4092384922889, 49.77350465713009, 46.11370578888924, 49.68933843797254, 49.65153463425175, 57.22787111036239, 53.463148840012096, 50.55660586203299, 43.97955202287243, 45.83466837483068, 45.148308507857784, 43.9337936524422, 42.74604505108249, 42.23162620298324, 44.37908464862455, 42.951753754769605, 42.79498838609265, 44.26446122507895, 42.65066085323211, 45.13102262250839, 41.4256497352354, 42.35334911654073, 43.55795998727122, 43.64945319391067, 41.397800907011955, 43.4389905775747, 41.24471864392681, 43.12665224075318, 42.984187833724484, 41.528800226026966, 42.89945287089194, 43.27227023340041, 43.820554825567434, 46.09340360087734, 47.585716401377034, 53.82933347455917, 55.52812376329976, 49.260274287193056, 48.96317828086115, 45.58387987075314, 46.64558702899564, 50.30486422200357, 41.42564581286523, 41.490109966647246, 43.25677294884959, 41.33798868425431, 41.692049272598766, 43.87231442236131, 43.88765088973507, 44.26837575051093, 41.74572298603673, 43.648692254097234, 42.5129032904102, 44.01481805309173, 45.35480560794954, 43.62420881948164, 43.436766593687, 42.951522334929436, 44.73236076293453, 43.62541298712454, 41.34482537546466, 42.699694402756236, 42.16761312177105, 44.74452403283889, 42.57017381729619, 43.28311558692686, 43.19978875498618, 46.00000019996397, 42.67168475735573, 45.19347460039201, 48.709318560938684, 48.26240762587517, 50.40219391545942, 45.2075166856089, 46.14554366757793, 46.85472780658353, 53.573559637992616, 56.94921808858072, 63.004628073784616, 66.65746473496961, 38.08033081793016, 0.5437530901643538, 0.23496626035100032, 0.5438816703615651, 3.439495025142547, 62.712301669582246, 59.56135188379596, 64.62830889609553, 66.46529213074716, 46.96702134224677, 41.389246217666134, 41.97036497054562, 66.12030398461127, 16.63346379033981, 0.6497538570434817, 0.1829289873280833, 0.3098627390159715, 0.11256248615081273, 0.1278991680291872, 0.20279686477395797, 0.15900516461941505, 0.25420088951866476, 0.10799055768837852, 0.13231345091856297, 0.14014286950470942, 0.14949651194676278, 0.09615843695017601], [0.04705983123952343, 0.06003834893025699, 0.06193767624696898, 0.09226192224530444, 0.004048527616466726, 0.016809631469509295, 0.02400546278353901, 0.024843338891983997, 0.03520950059136076, 0.017794098502265352, 0.016485767799519723, 0.05315362400705776, 0.013037596476234257, 0.057620732489252285, 0.033724841346303304, 0.05801467788255504, 0.04401763480517172, 0.3201379086221418, 33.175928592681885, 53.69055609549246, 35.99946637307444, 16.71957354391775, 43.67494860003072, 58.41162673888668, 57.376450492489724, 50.15299789367184, 58.027261918590916, 14.040696697850382, 0.3915001938660299, 0.11622648550978593, 0.3440945198939693, 0.18791551491425884, 26.62616268281014, 76.98665003622733, 56.11185873708418, 61.11847400665284, 51.94336768119566, 49.563677464762044, 45.151332655260646, 48.04204886959445, 44.0295857767905, 42.351536981521114, 42.07675533909952, 42.884010499523534, 43.24804959758636, 42.32128766275222, 44.808246858658336, 41.853144937945956, 40.69659486893685, 44.43863407258065, 41.13190735540083, 40.95426713266681, 40.31167699444679, 40.602269711032996, 40.22928760897729, 40.98270039404593, 43.57694425890523, 46.06761793936453, 44.60136144391952, 46.66184917573006, 47.176703406918435, 45.435822163858724, 44.13673316278766, 42.67346159104378, 40.79655647277832, 40.246404832409276, 39.417702151883034, 42.06486663510723, 41.72567182971586, 47.419215709932395, 47.346534190639375, 42.3198873766007, 43.63101020936043, 48.96451580908991, 48.38382067218904, 42.489667169509396, 41.820432370708836, 40.91981303307318, 38.916674275552076, 40.886327758912124, 38.285113842256614, 38.31150354877595, 41.502614482756584, 39.30316502048124, 39.6714912691424, 38.689294476662916, 39.26206642581571, 39.91020671782955, 39.42113422578381, 39.419730017262125, 39.64239904957433, 39.81680723928636, 38.74972643390779, 38.547814584547474, 38.58362190185055, 37.62703818659629, 37.46494623922533, 37.542197319769095, 38.57212543487549, 37.31177376162621, 36.54154577562886, 35.947667552578835, 37.480337619781494, 38.23924956783172, 41.95800558213265, 45.49537943255517, 45.83668055072908, 46.049641716864805, 41.73964723463982, 40.2488955374687, 47.11297273635865, 40.275430371684415, 37.76710602544969, 40.32948847739927, 37.44499706452893, 37.85747743421985, 38.81897587930003, 39.30869164005403, 40.06077474163425, 38.270350040928015, 38.84946446264944, 39.25408440251505, 39.66612546674667, 39.87085750026088, 39.09583637791295, 35.779813643424745, 37.68797220722322, 37.87638325845042, 36.94524395850397, 37.76564690374559, 37.0500300776574, 37.76663926339919, 38.27799081802368, 37.206587560715214, 39.66477224903722, 37.51756875745712, 39.214656737542924, 40.13274631192608, 41.31180294098393, 38.7733861707872, 40.3434834941741, 38.9385179550417, 40.07681331326885, 40.581594897854714, 46.583217420885646, 46.60704974205264, 55.387930408600845, 54.0029493454964, 66.51167023566462, 27.04503651588194, 0.7495510890599221, 0.25035433140733554, 0.24245772691022968, 4.8888784646987915, 56.679386477316584, 46.21624046756376, 56.97558426087903, 44.700358144698605, 33.576739911110174, 28.491222243155207, 34.43205587325558, 34.18282847250662, 0.7073856709945587, 0.07597800329207413, 0.08487259818901939, 0.05868095604162063, 0.05132033346941875, 0.039063344198849895, 0.02942384753917014, 0.05918233760542447, 0.08255732726425895, 0.06299565133127956, 0.03283340611585206, 0.034365264037924434, 0.043064594614289464, 0.06528271106822837, 0.05192805952843159, 0.007505314077265682, 0.014653442532665309, 0.039547044453361345, 0.06617408501164568, 0.022194869515876618, 0.005978479776756779, 0.05791723149858656, 0.03871601142529999, 0.06380531816713272, 0.015597762727749445, 0.03492291475976667, 0.029968647136082573, 0.07838167310241731, 0.03847347564935204, 0.06368782709262545, 0.052836122697279345, 1.0636356160525353, 45.77973165819722, 54.15765939220306, 27.11797102805107, 33.24684112302719, 55.61430608072589, 61.20878657987041, 66.87969053945234, 53.9962891609438, 66.52374329105501, 15.54348909085797, 0.2841060049831867, 0.03686684754586989, 0.4516064105254989, 0.1608431321238318, 28.213481172438595, 77.22433782392933, 58.985881343964614, 62.93902643265263, 53.999070121395974, 52.32513981480753, 47.46160476438461, 47.93961617254442, 45.46527916385282, 45.00700904477028, 45.53591712828606, 45.919925012896144, 45.754871676045084, 44.092735936564786, 45.396582772654874, 45.470421391148726, 44.81325180299821, 45.20484947389172, 42.18598942602835, 43.666605718674205, 43.6838916040236, 44.15822382896177, 41.220337190935695, 43.549977963970555, 46.26432088113601, 45.636831868079405, 47.47833759553971, 50.686706958278535, 48.11161994934083, 48.45053234407979, 45.65162704836938, 43.88607017455563, 42.657089617944536, 42.36778343877485, 42.720679083178126, 44.58022379106091, 43.54023087409235, 48.162991231487645, 49.59740200350362, 43.75844801625898, 45.32680772965955, 50.19595961416922, 50.78474660073557, 46.030904554551654, 43.685542921866144, 43.23342307921379, 41.048509920797045, 43.19210483181862, 40.61575874205559, 42.186322827492994, 41.685279261681345, 39.76216470041583, 40.51283574873402, 40.12936915120771, 41.677893438646876, 41.326276486919774, 41.94582662274761, 41.46860753336261, 41.56628239539362, 43.042427186043035, 40.17950880912043, 40.00925048705071, 41.2626713322055, 39.65233049085064, 39.70642389789705, 39.74210962172478, 40.226047731214955, 39.79233557178129, 39.45639633363293, 38.984276325471946, 40.50335145765736, 40.33170461654663, 45.05259090854276, 47.91749792714273, 48.59420091875138, 47.99801241966986, 43.757459578975556, 41.947191607567575, 47.83572435379029, 42.938794243720274, 40.72893873337777, 41.026725076860004, 38.609427175214215, 38.91513670644453, 39.81128061971357, 40.97248654211722, 41.15803426311862, 40.40652382758356, 41.79765908948837, 40.187035837481105, 43.38491678237916, 42.22645651909613, 40.344762186850275, 38.4080683800482, 41.02858428032168, 40.06423034975606, 40.002390261619325, 39.808154490686235, 40.16023035972349, 40.05393412805373, 41.74757434475807, 39.760372177247085, 41.494232377698346, 41.83975396617767, 41.911125413833126, 41.444026039492705, 42.90299869352772, 41.284111007567375, 42.10336077597834, 40.22719698567545, 43.87716639426447, 43.53758327422604, 48.636311484921364, 48.92560981935071, 58.21743019165532, 54.9918024001583, 68.42924641024682, 27.69878971961237, 0.8764583953926641, 0.09263024965841925, 0.2881216540211632, 5.557081680144034, 63.452860847596206, 50.67388080781507, 65.938674711412, 49.0658502424917, 45.39408030048494, 25.81988419255903, 33.46459150314331, 44.875911666500954, 1.0345972065002689, 0.11342931463713608, 0.07390241063530407, 0.07997960993839849, 0.030696652829647068, 0.05324663474194465, 0.052909625003174435, 0.023000702081668763, 0.037076981633060405, 0.03580061786417519, 0.05070143401803029, 0.0827184661982521, 0.01090928643656474, 0.018743160781600786, 0.14669060767177614, 0.1790475875379578, 0.15785909708469145, 0.20140305972628056, 0.13877318090488835, 0.10378141016248735, 0.13019359370152797, 0.13945021876885047, 0.12991181124121914, 0.0655134644119009, 0.26684901647029385, 0.12151236961325332, 0.1294585936252148, 0.11740297439598268, 0.1646996340564182, 0.16872086021448338, 0.1364909283696644, 1.3540314786857175, 54.89838330976425, 67.50199025677097, 47.152580830358694, 28.430578477921028, 57.37563856186406, 69.45339295171922, 71.49829710683515, 60.75567829993464, 73.4366383091096, 19.330242333873628, 1.5516814277056725, 0.2954954035099476, 1.0254305661205323, 0.3292978074281447, 29.96073626702832, 80.15565056954661, 62.962662635311005, 65.49308169272639, 57.76031324940344, 55.0000629117412, 51.25503878439627, 51.72701758723105, 48.68523520808066, 47.41603859009282, 49.128455192812034, 48.57511858786307, 48.64900819716915, 47.888542990530695, 49.492560971167784, 47.675495532251176, 46.41654806752359, 48.63808047386908, 44.47287636418497, 45.730231346622595, 44.239550252114576, 45.9241964740138, 42.65767012873004, 45.83962232835832, 48.96642208099366, 49.3031418708063, 48.68799655668197, 53.501623369032345, 50.03992772871449, 50.52012781943045, 46.76443484521682, 46.36311361866613, 43.03749676673643, 45.12440558402769, 42.782209304071245, 45.78715278256325, 45.523141968634825, 50.44195498189619, 51.12484355126658, 46.13577696584886, 47.533227243731105, 52.806540150796216, 53.08764857630576, 46.790251885691, 46.1097873410871, 45.976332618344216, 42.94041418260144, 47.59157642241448, 42.521705089076875, 45.93765804844518, 44.825862223102206, 43.62677404957433, 43.98925596667875, 42.992683687517726, 44.48864429227768, 43.967796679466005, 44.792078848808046, 45.48040382323727, 44.71599663457563, 44.6757060481656, 44.36474446327456, 42.664134194774014, 44.01383746054865, 42.21574452615554, 41.919789929543775, 42.19261823161956, 43.37380863005116, 41.602823195918916, 41.47637774867397, 39.80340450040756, 43.62724865636518, 43.05852851560039, 45.921399824080936, 49.884739152846805, 48.77767762830181, 51.15589695592081, 45.38732990141838, 44.327995777130134, 50.30333449763637, 43.873451909711285, 42.66192982273717, 44.053351417664565, 40.73744635428152, 41.721372912007, 43.89678216749623, 43.68617442346389, 43.77853055154124, 42.31729076754662, 44.42801621652419, 42.69706249237061, 44.60419731755411, 44.74143712751327, 42.07627288756832, 40.49299640040244, 43.12667577497421, 42.4036221350393, 42.17286909780195, 43.5178812088505, 41.17588496977284, 42.60310995963312, 44.14653516584828, 41.25394798094227, 44.03226475561819, 43.09239425966817, 43.40240270860734, 44.45821454448085, 44.17286211444486, 43.4340327016769, 45.313397146040394, 43.145687503199426, 45.915002438329886, 47.7452431186553, 51.9368447795991, 53.41602548476189, 59.54219895024454, 60.571836809958185, 70.87496972853138, 32.80596671565887, 1.0590484041360118, 0.4693575257495527, 0.520845590339553, 6.822094600046835, 69.25707047985446, 56.22079864625008, 68.30749604009813, 57.29585363018898, 47.0833823757787, 41.94983920743389, 46.904612510435044, 54.692741286370065, 1.800393527073245, 0.20223728351054654, 0.12346092190953994, 0.1754017904280655, 0.10609153297639663, 0.1211861540533362, 0.12545104979747726, 0.14338441733871737, 0.1282845868638927, 0.1761640019474491, 0.16773685091926208, 0.2391258726317075, 0.15218952550522744, 0.20459078222272858], [0.07822593508829033, 0.08729643143352964, 0.03224105161103991, 0.06698039255195087, 0.009418444861958345, 0.007506345901938697, 0.01157855999941427, 0.06057407421570632, 0.0826106546446681, 0.06494220796852343, 0.04489059582532895, 0.04543475190838499, 0.06264230093708442, 0.08291902801682872, 0.1391136150566801, 0.18600329816822084, 0.0656629051832903, 0.23964808412617256, 11.532603771455827, 54.03938816439722, 39.967092852438654, 19.67212200164795, 24.255213468305527, 50.58495675363849, 66.11434982668969, 51.8350592736275, 53.66071078085131, 19.847018526446437, 0.1680178979351636, 0.23523580072627914, 0.34299000496825865, 0.18099263881243047, 12.713480380273635, 76.38710006590813, 54.860520670490885, 62.106201341075284, 52.58744439771099, 51.42341436878328, 50.089804587825654, 48.710012820459184, 44.66932042952507, 47.43224582364483, 42.07581397025816, 42.61254718226772, 40.19547285572175, 45.2567228194206, 42.45893932157948, 43.94186589025682, 41.48771339847196, 41.90409260411417, 39.208953611312374, 42.17467338808122, 38.81858756465297, 39.69661797246626, 42.068334010339555, 42.673794992508434, 42.15987036305089, 44.082396568790564, 43.33097242539929, 44.04702071220645, 45.85227589453421, 45.018411374861195, 42.3805703655366, 41.64758920669556, 42.57397851636333, 41.36029912579445, 41.547553077820815, 41.54846699007096, 40.00414356108635, 48.247475162629165, 46.86820507049561, 43.11015082943825, 44.94858141868345, 48.80480866278372, 45.0372975872409, 42.00350115376134, 42.685346372665904, 38.83342589101484, 38.651639723008685, 36.70003698718163, 38.502048369376894, 37.8221211894866, 39.60372840204547, 38.097773598086455, 39.543818120033514, 37.25342066057267, 38.355288967009514, 40.45321179974464, 41.03104752878989, 40.460589778038766, 39.55274151217553, 39.61706446063134, 40.432815474848596, 38.7495695391009, 38.350276177929295, 37.86747947815926, 39.25945020491077, 38.15851150020477, 38.986508154099994, 38.8705236681046, 36.385078507085005, 37.824007849539484, 37.10094636486423, 38.25902615824054, 39.7515429219892, 39.36218884683425, 43.69394856114542, 44.325771793242424, 40.42339394169469, 40.564744395594445, 44.83236551284791, 43.37129046840053, 38.56131930505076, 39.26955423047466, 36.898689346928755, 38.19443256624284, 38.75430383989888, 39.85976503741357, 39.758375690829375, 39.43513316492881, 39.19735124034267, 36.14428420220652, 37.88227465844924, 37.13995041385774, 37.43623448956398, 38.302638992186516, 38.23560176357147, 37.049292672065, 38.459078804139175, 35.37811586933751, 38.14225327584052, 36.83314261897918, 37.73291472465762, 37.93091204858596, 38.246655002717056, 38.13889572697301, 37.85641447190316, 38.772464413796705, 40.27019400750437, 39.47505504854264, 40.168620309522076, 41.96428137440836, 45.79905717603622, 47.77949717737014, 52.10929570659515, 51.2302964733493, 58.37903968749508, 53.07073139375257, 69.03718240799444, 11.560450638494185, 0.622380800064533, 0.23175049903652362, 0.2721887718765967, 5.867330374256258, 55.81160522276356, 48.17947303095172, 59.737744792815185, 42.49286390119984, 29.654989473281372, 28.4968194653911, 47.746133496684415, 17.33377552801563, 0.12539746194717385, 0.05880200176409656, 0.07568574074896113, 0.01274283265604848, 0.056574536006777525, 0.04400092642754317, 0.08846606383280409, 0.024295243201777342, 0.05334166794895165, 0.04139507835310313, 0.07889507458575311, 0.04071381168379899, 0.10610248803371385, 0.055303764679739555, 0.06396455337263404, 0.07448721151318281, 0.03818041254435817, 0.07444817933344072, 0.08108146653901185, 0.08456789437801608, 0.04506761576199243, 0.019427616291889743, 0.049569504635949294, 0.04514306776165482, 0.039816056227972435, 0.05169674694057434, 0.08006512833338592, 0.012605601410952308, 0.05678643209619388, 0.09844185393904487, 0.0647379765887895, 0.2640835922812262, 16.94739264826621, 63.36345041951826, 35.76780334595711, 20.445321183050833, 39.63711169458205, 57.62457962959044, 71.82914118612968, 54.861289455044655, 63.06911968415784, 22.036428682265743, 0.13063064686232997, 0.3872198461284561, 0.32321899167953, 0.3955339532225363, 14.159155218831955, 77.63257811146399, 58.64772204429873, 67.33649761446061, 55.10336637496949, 55.798496661647675, 51.14329438055716, 51.78451168921686, 46.71614262365526, 49.10367758043351, 45.40072087318667, 45.135447056062766, 44.107546806335456, 47.04535107458792, 44.71000325295233, 46.37902667445522, 44.51681083248508, 44.67185820302656, 43.35781712685862, 43.03065223078574, 41.985042479730424, 42.98913786488195, 44.88631379219794, 44.1702498159101, 44.695808195298724, 46.96635846168765, 46.96325194451117, 47.44951601951353, 49.422923211128484, 47.38779360248197, 43.66925724091069, 44.47942280000256, 43.15588174327728, 43.98091308532223, 43.99966593711607, 42.79681621059295, 42.58496507521599, 50.274909080997595, 48.272527340919744, 44.0175990135439, 46.731141767194195, 50.6684914711983, 46.176255826027166, 42.791285668649984, 43.62260457008116, 41.40112315454791, 41.29172825044201, 40.28633063839328, 40.52326140865203, 39.6588533924472, 42.21471294280022, 40.102175358803045, 42.13846206665039, 40.13971636372228, 41.464136031366166, 42.91501291336552, 43.77474154195478, 42.07246426613101, 42.17370456264865, 40.615001724612334, 42.35171348817887, 41.29809817960186, 41.8957144214261, 40.59821398027482, 41.87679683008502, 39.472752617251494, 41.25735652062201, 40.943963066224136, 40.00382192673222, 40.35117133971184, 39.79823873889062, 39.755331931575654, 42.9769314489057, 41.53180083920879, 45.84601186936902, 45.78967486658404, 42.96437201961395, 40.37606270082536, 46.116337699274865, 44.54497345032231, 40.732814035108014, 41.86164471410936, 39.419251488101104, 40.39100300881171, 39.87489361916819, 40.435772941958525, 41.63513175902828, 39.77791301665768, 41.01617390109647, 39.96981105496807, 40.233778722824596, 39.96302143219979, 38.98437830709642, 39.806463949141964, 41.272143856171645, 39.94222502554617, 40.64702787706929, 38.56422578134845, 40.09917082325105, 39.539927128822576, 40.426720111600815, 41.64232538592431, 40.38665310029061, 40.56423840984222, 41.28046320330712, 39.825754165649414, 42.62338469105382, 41.09577840374362, 42.734713323654674, 43.65370504317745, 47.108403175107895, 50.924567330268125, 54.45359045459379, 54.151018819501324, 59.87159567494547, 54.99768987778695, 71.16779035137546, 13.409562822311157, 0.7394207713584746, 0.2851037885392866, 0.28253083628031517, 7.279268416666216, 62.54261993592786, 52.98726335648568, 64.37125636685279, 47.74491363956083, 43.73254468364101, 25.4355566347799, 52.79105463335591, 23.253124375497144, 0.2669058908377924, 0.015706048298236585, 0.05875137867406011, 0.0680443354611916, 0.05458880163308594, 0.0860473403947488, 0.03615887505152533, 0.010660069416307155, 0.029573958637493274, 0.019129937507152077, 0.06103767232308465, 0.030623889798598907, 0.06797135792552464, 0.07399881513969553, 0.1954114707487245, 0.2675434904954126, 0.08830165370337426, 0.2266795179175754, 0.1844745237500437, 0.15104218626454954, 0.18033836908157796, 0.13453745012802465, 0.18836746082430889, 0.12513539092915674, 0.14098136805959288, 0.1891997234234887, 0.1665034493611705, 0.1285508254002179, 0.26963530889441895, 0.2928330028249372, 0.22439076895675353, 0.492283626189155, 22.39225825955791, 72.0530692992672, 50.70293380368141, 30.872267638483358, 37.4443067273786, 60.81221926596857, 76.94551221786007, 63.09607028961182, 67.60106148258333, 27.507087799810595, 0.24924639972948262, 0.3621957985864532, 1.7962398596348303, 0.4746947071004299, 15.262744465181905, 80.72186039340112, 60.77457235705469, 68.91434946367818, 57.91322685057118, 60.16787582828153, 54.77260466544859, 54.30315186900478, 48.34680918724307, 51.56194856089931, 46.28469367181101, 47.10853653569376, 45.102291260996175, 49.91680452900548, 46.881254796058904, 48.930701055834376, 47.52687300405195, 47.111054697344386, 43.2513443885311, 46.735825077179946, 44.277150092586396, 44.85743338061918, 47.307169283590014, 48.20022629153345, 47.85348876830071, 49.81612905379265, 49.48903476038287, 49.007865844234345, 51.21442264126193, 51.10759688961891, 45.709693816400346, 45.807984490548414, 45.70482223264633, 44.032460874126805, 47.0028914174726, 46.03647432019634, 44.392801177117136, 51.79931863661736, 49.82847275272493, 46.943883280600275, 48.10426158289756, 52.8008331021955, 48.009736384114916, 45.31500139544087, 47.09395708576326, 43.06285096753029, 44.08704457744476, 41.96930593059909, 42.74881816679432, 42.60990350477157, 44.315353978064756, 42.79945988808909, 44.278985761827045, 41.42540654828472, 43.79778938908731, 46.75495055414016, 46.209097831479966, 45.877241780681, 44.44321147857174, 42.89214941763109, 44.936202418419626, 44.51570472409649, 43.92339937148556, 43.11451642744003, 44.85464849779683, 43.003156415877804, 44.87021638501076, 43.29429041954779, 42.24382477421915, 41.711343411476385, 42.32599058458882, 42.467113541018584, 44.96875024610951, 42.15237863602177, 48.45578047537035, 47.54154266849641, 44.86575665012483, 43.96206609664425, 49.15689629893149, 48.08622652484525, 43.85928038627871, 42.76522151885494, 40.29586984265236, 42.037170779320505, 42.61367290250717, 44.80758005572904, 43.30239011395363, 41.9400332820031, 43.90588598866617, 41.955106950575306, 43.63174761495283, 41.57912423533779, 41.693477015341486, 42.68685648518224, 43.169896371902965, 42.73787475401356, 43.01294665182791, 40.11187930260935, 43.788858152204945, 42.76216207012054, 43.264421570685606, 44.496645927429206, 42.56256049679172, 43.86445399253599, 42.658176114482266, 43.11793673423029, 45.11401522544123, 43.97435096002395, 45.3369156775936, 47.69868458470991, 52.185017062771706, 54.370589179377404, 57.06462598616078, 56.558683380003906, 64.70156700380387, 58.363373741026855, 72.25706392718901, 16.22148842580857, 1.0456720186818032, 0.46593461426035054, 0.48112944729866525, 9.330310590805547, 69.38577913468885, 58.36902195407499, 73.12716330251386, 52.46068123848208, 44.61350902434319, 39.92841043779927, 62.12518953507947, 31.15883992564294, 0.25396441349819787, 0.14432790058274425, 0.18646321139268338, 0.16654225937541456, 0.09095439401965949, 0.17940312894361635, 0.1620326215221036, 0.13543251661523698, 0.147911996971215, 0.08031658903365174, 0.14876293679398878, 0.12557536288495028, 0.1857488956903258, 0.21748254045603738], [0.03884053901739178, 0.07037219321054798, 0.056732013040492614, 0.06904359756698532, 0.03259235655047721, 0.014438383457731577, 0.05959826589171445, 0.03591003437196055, 0.05591231811371061, 0.015869447191606368, 0.023398073803212856, 0.10741917101005394, 0.007061856421416686, 0.09692388136060008, 0.038242343092156995, 0.013361734022656757, 0.03760554399641772, 0.09135554830032973, 0.6688689764949584, 42.44225748123662, 42.16117651231828, 32.334791998709406, 25.291839030481157, 34.64587211608887, 57.295967378923976, 50.31758054610222, 60.75598032243791, 26.393828930393344, 0.36605819939605655, 0.5006405422764441, 0.3682059728570523, 0.16976992569623456, 3.06705960342961, 70.44051231876497, 58.87574903426632, 63.07305774381084, 56.30875779736427, 56.10750882856308, 53.48478463388259, 56.45692925299368, 54.75231032217703, 55.104880409856, 51.79188966751099, 50.94734453385877, 43.66345213305566, 42.26886126302904, 43.18060836484356, 44.699051995431226, 40.68189774790118, 43.617905570614724, 41.746785948353434, 42.31782813226023, 41.848104692274525, 41.41694207345286, 39.45847126745409, 41.43045071632632, 40.83589392323648, 43.37621304296678, 43.284304065089074, 43.381661215136134, 41.5376647826164, 40.708797362542924, 42.013562033253336, 43.32955252739691, 42.389329018131384, 42.20256928474673, 42.692885168137096, 41.9465797178207, 40.59846108959567, 46.207262162239324, 45.3706519834457, 44.09745454788209, 44.713815796759825, 44.69922850208898, 42.278726024012414, 41.892086229016705, 40.85078324041059, 39.06932900028844, 39.644364157030665, 39.37673691780337, 38.1328199755761, 38.13889964934319, 39.27003275963568, 39.74130945820963, 37.2034300527265, 39.03832266407628, 40.053090818466686, 41.14596513009841, 40.29079037327921, 40.500884286818966, 43.11146874581614, 41.62811463879001, 38.04015005788496, 38.60589311968896, 38.32587511308732, 38.35969378871303, 38.55693409519811, 37.84067007803148, 38.94697066276304, 37.52017321125154, 38.53642402156707, 39.48838326238817, 38.32985239644205, 38.88659361870059, 38.94467607621224, 37.935344326880674, 41.710417732115715, 41.68817397086851, 41.46364573509463, 39.74090937645205, 42.27609803599697, 42.702338080252375, 38.00111462993007, 37.479623748410134, 40.478507164985906, 38.80024656172722, 37.932684959903845, 38.665583748971265, 39.178284598935036, 38.02256999477264, 37.415998981845, 37.93702310131442, 36.76762334762081, 39.21846143661007, 36.81224030833091, 36.830820575837166, 35.74101748005037, 37.27752362528155, 36.825560677436094, 38.65393430955949, 38.284274455039736, 38.81577522523942, 37.43393990301317, 38.28523151336178, 38.258798660770545, 40.8844607107101, 38.0411502622789, 40.144568335625436, 39.88309137282833, 39.07726003277687, 39.93046968213974, 40.086929105943256, 49.749107514658284, 52.55717546709123, 54.42709092170962, 54.57478777054818, 57.07935056378765, 57.044453236364554, 60.601842941776404, 5.040168204615194, 0.7909007154164777, 0.38113612741712605, 0.5708539714255642, 11.430906518813103, 58.00696365294918, 48.25943446928456, 54.76487759620913, 33.65037064398489, 24.224581718444828, 28.265709492468066, 38.915199464367284, 0.6589598436990093, 0.1433774765821234, 0.046486460393474954, 0.08059179079869101, 0.03099837847384474, 0.10448575906095006, 0.016125928640605944, 0.022484006420258554, 0.0456453877831659, 0.029296675028519768, 0.02423026170882006, 0.02204082264084249, 0.01912278033071949, 0.04885646446998562, 0.039612602427481644, 0.028093106849419496, 0.03559610303190928, 0.05118954310854597, 0.11130737366094706, 0.03636420576743061, 0.02382699685591844, 0.036403858478391365, 0.030400969703952153, 0.06045960152762071, 0.0839739770538384, 0.033434225892227505, 0.010082664159727434, 0.027795544893090284, 0.02843951265658102, 0.032239117239031105, 0.0064794653688647575, 0.07011259665652629, 0.15247193615763419, 2.6198434589370607, 52.52981301276915, 45.672611728791274, 21.33467939592177, 31.750390221995694, 43.892114546991166, 63.477214843996116, 58.03132941645961, 65.68042585926672, 31.520500106196252, 0.46388851598866526, 0.47819208233587207, 0.12468352928877839, 0.2838663726804718, 3.919882654182373, 72.3906441657774, 60.21993352520851, 65.99179144828551, 58.03736594415481, 59.75005711278608, 55.40538103349748, 57.98798330368535, 54.907553811227125, 57.56175894891062, 52.932624739985314, 52.74642982790547, 44.482172381493356, 45.422693990891986, 44.632928679066325, 46.875245724954915, 42.935636735731556, 44.58481688653269, 43.292450827936975, 44.08738582364975, 42.76911643243606, 44.456731888555716, 41.597598598849395, 43.24139725777411, 43.73204262025895, 45.52811945638349, 44.072057201016335, 45.06597795794087, 43.52752239473405, 43.56212554439422, 44.420293069654896, 44.72104080261723, 44.38320313730548, 43.49696320872153, 43.956155084794574, 44.71485522485549, 41.76128695088048, 47.670270935181655, 46.512567689341886, 46.00593866840486, 47.13096464833906, 48.78955064281341, 43.892110624621, 43.72923420321557, 42.76442920008014, 41.637034108561856, 42.72861403803672, 42.460712232897365, 41.07890044489215, 39.9242409583061, 42.917542842126664, 42.29065395170643, 40.649138112222, 41.56937322308941, 42.472534256596724, 43.04190551081012, 40.54865091077743, 41.48240643162882, 43.63162602147749, 43.55359046689926, 39.640873247577304, 40.07465600967407, 39.47039135040776, 40.75658359835225, 39.49431780845889, 41.420385914464156, 40.75817608064221, 41.079049494958696, 41.32713940835769, 41.064360218663374, 40.31962763878607, 40.392520966068396, 41.26824894259053, 40.132609028970045, 44.47879522077499, 45.12718654447987, 43.861221959514005, 42.05436645015594, 44.62933578798848, 44.717985276252996, 41.154661024770434, 40.75902331259943, 42.432384875512895, 39.716586759013516, 40.21267637129753, 41.23649735604563, 40.81853743522398, 41.23205723301057, 38.62152376482564, 40.20222325478831, 39.974345314887266, 41.10613738336871, 38.62632082354638, 39.55050576117731, 39.44344858969412, 40.01662454297466, 38.88200444559897, 40.595072161766794, 40.610718496384166, 41.509902246536754, 39.765545783504365, 40.26024295437721, 41.36598264017413, 42.097857690626576, 40.5933149399296, 42.28361721961729, 41.96434020996094, 40.23636356476815, 43.88119859080161, 44.60147127028435, 52.72090696519422, 56.52409591982442, 56.78788315865302, 58.31618762785389, 59.21191969225484, 60.911855313085745, 59.789967229289395, 5.704566230697017, 1.1575130108864078, 0.20125767156001062, 0.6861224410033996, 13.436493815914279, 64.38950715526458, 53.760523334626235, 60.55472743126654, 44.683707683317124, 31.648628250245128, 27.312461753045362, 49.897984996918716, 1.5584711730480196, 0.015987741700824232, 0.042098063615060625, 0.06841647799216932, 0.04315813394984411, 0.10125919590674101, 0.02972138651286162, 0.05395366494814235, 0.05408018436883727, 0.1004300129810168, 0.013589642307300483, 0.054072684368058566, 0.03985549060387477, 0.013403884180250668, 0.014162501789659504, 0.12277469099048646, 0.19318785458322496, 0.17070314336207607, 0.26566963943262256, 0.1847677515639413, 0.12400855986221183, 0.1483047549282351, 0.08843777986663966, 0.16975160087308577, 0.12028927193774332, 0.0675696827050659, 0.24843675204582755, 0.11743919503304268, 0.1979272728485446, 0.15849760072606225, 0.07764010765259305, 0.23252879840231713, 0.29515878447601873, 3.1875705046038476, 63.5477900505066, 54.35650394808862, 42.02549780568769, 39.886346940071356, 46.122825299539876, 70.56215286254883, 62.16517809898623, 71.92194446440666, 38.50388796098771, 1.2745500404027201, 1.4945682859228504, 1.1904936476099877, 0.46119010917121367, 4.600194961793961, 76.79187297821045, 63.2263792714765, 70.04803211458268, 61.426752690346014, 62.388411952603256, 60.5617053278031, 62.22864989311465, 58.563391085593935, 61.6834992747153, 57.513525562901656, 56.69267154509022, 47.383792784906205, 47.718908325318374, 46.8131193037956, 51.024332815600985, 43.59177866289693, 47.21839035710981, 45.35719433138448, 46.70890977305751, 45.82821215352705, 46.684430260812086, 43.66608796581146, 47.01372500388853, 45.626743531996205, 49.70406301559941, 46.98113795249693, 47.40168663763231, 46.17226677556192, 46.07512927824452, 45.980270677997225, 47.29633569717408, 46.967633231993645, 47.460937961455315, 47.0116892937691, 46.220151070625555, 42.76951259182346, 51.08680832770563, 48.34263578537972, 50.17493178767543, 51.25511330942954, 49.455729915249734, 48.40218128696565, 46.77451925892984, 44.973249204697154, 43.419527776779674, 44.9953164592866, 45.5973453675547, 43.629849187789425, 42.418821319457024, 44.42377221199774, 45.40559245694069, 41.49702118289086, 44.48588686604654, 44.83781760738742, 46.03257940661523, 44.035826267734656, 46.655459634719364, 48.58128455377395, 47.41997272737565, 42.811266222307765, 43.1281231295678, 41.77250100720314, 43.08664798736573, 42.68771156187981, 41.77998881186209, 44.734474920457416, 43.04347445887905, 43.19146548548053, 45.53919230737994, 42.96162243812315, 42.95083199777911, 43.343669137647076, 42.704958223527484, 46.49068870852071, 47.22422292155605, 45.28031195363691, 43.17352456431235, 47.248098388794936, 47.060962107873735, 43.56441228620468, 42.47928073329311, 44.6228874114252, 41.6185519003099, 42.332850810020204, 43.05042097645421, 43.290772053503225, 42.993221052231334, 41.20903684246925, 40.680466082788286, 42.24193419179609, 43.87945313607493, 41.48318306092293, 39.908669148722005, 41.29782361368979, 41.619226547979544, 41.22091377935102, 42.35235675688713, 43.88368929586103, 43.79621259627804, 42.94755289631505, 42.57296654485887, 45.224410333941066, 46.83463742656093, 43.368470284246634, 45.49976464240782, 43.30611244324715, 41.739529563534646, 45.8734723829454, 46.327565177794426, 57.31066842232981, 60.01069468836631, 60.88756799697877, 59.88857561542142, 63.10780209879722, 61.59277485262964, 64.05259124694332, 6.647482447085842, 0.8751555556251157, 0.7921070893926005, 0.7449721508929807, 15.982208155816602, 70.1356892431936, 58.64900858171525, 65.9235735862486, 46.32547063212241, 36.544016868837424, 37.86813451397804, 59.54095163652974, 2.9137214056907164, 0.3168994098180725, 0.1379737375123847, 0.252937916966696, 0.11882261958934608, 0.24935311577733488, 0.13101750594233313, 0.15751618080802504, 0.18471331335604194, 0.2017165888701716, 0.09414413132734838, 0.13055832816227791, 0.1195024306915941, 0.060606874270184394, 0.1519130596951131], [0.10494108341874615, 0.02373148484395877, 0.04679037896435588, 0.030850688213362332, 0.025117265120629343, 0.06846794377892249, 0.09539362839272908, 0.02442389043168195, 0.06038424145850924, 0.09004653386411168, 0.015139685241475463, 0.02105396349854287, 0.02541751029991335, 0.023500137782144933, 0.050680255517363555, 0.020427230798128634, 0.009366219690550239, 0.06727003507436284, 0.11980664420632586, 15.698398197850874, 50.07025157251666, 31.64766138599765, 19.86512810953202, 31.477622716657578, 48.31365339217648, 53.48574953694498, 52.959061514946725, 50.25949808859056, 0.624343149604336, 0.35403098670705674, 0.2243771785569768, 0.05994889284333876, 0.13736828290406736, 44.091700430839296, 68.72205134361022, 57.5786094511709, 62.55891346162366, 55.46927644360451, 60.0016144014174, 55.50141634479646, 59.94548920662173, 58.627965065740774, 61.15212794273131, 57.49425888061524, 55.677267966731904, 50.31580371241416, 45.41272724828413, 43.567609017895116, 44.25075646369688, 41.72667987885014, 43.74884213170698, 42.37229024210284, 42.05331525494976, 40.04358299316899, 43.375354043899044, 42.07420972085769, 40.84175394427392, 40.615813655238, 41.755787787898896, 41.88032304086993, 42.06651010820943, 41.7912224800356, 44.61189693020236, 42.306519939053445, 42.506709867908114, 41.884472908512244, 41.79648630080685, 43.02128953318442, 40.7786508529417, 44.75564787464757, 46.693526237241684, 43.88856087961505, 41.11924202211442, 41.59951663786366, 42.376922561276345, 42.49682549507388, 41.097284593889796, 40.1567159160491, 39.9047742351409, 39.74585548523934, 40.83451324893583, 38.30692222041469, 40.11031035454043, 40.0042220084898, 39.457580889424975, 45.12244047657136, 46.10419011885121, 45.1649119007972, 45.81939858774985, 43.68086353425057, 44.5901434652267, 44.38227745794481, 41.1672322211727, 41.91500463793355, 40.2066594554532, 39.2608348015816, 38.05636513617731, 38.86646793734643, 38.93133609525619, 38.873677253723145, 38.483307284693566, 36.789776894354056, 37.19837019520421, 39.07422804063366, 38.64827825177101, 38.97567849005423, 38.29808119804629, 40.19723007755895, 38.73373885308543, 39.98881493845294, 41.723922452619, 42.34141726647654, 39.73260964116743, 40.05450679409889, 41.27161433619838, 38.33767752493582, 38.77733991992089, 40.933890419621626, 38.174506925767474, 41.09793962970857, 37.92140422328826, 37.58306841696463, 37.48915118555869, 39.573643822823804, 38.297488920150265, 38.18335579287621, 37.53051257902576, 36.59847897868003, 36.565378096795854, 36.75193386693155, 36.14196215906451, 37.78868690613778, 37.954199160299, 40.99674640163299, 38.19564457862608, 40.44261747790922, 41.3612836407077, 40.91090533041185, 40.56489344566099, 42.031051881851695, 40.07390683697116, 43.96427831342144, 53.377841211134395, 52.12108242896296, 56.10012300552861, 55.37293126506191, 57.15590738481092, 53.86755697188839, 43.7463592713879, 1.3372465535517664, 0.5017777844782799, 0.4635199051230185, 0.48529843649556564, 22.774253968269598, 54.112473687817975, 53.40657649501678, 45.97677192380352, 26.54335948728746, 26.78263975727943, 45.28839203619188, 23.013895096317416, 0.030447057553476868, 0.08884219002098807, 0.02959282355262868, 0.08237911989131282, 0.05772669394049914, 0.048661050762260155, 0.04185387308919623, 0.02466520238217087, 0.03435985545717901, 0.036254934816350864, 0.022650538613238645, 0.035660998339975075, 0.06975343165498588, 0.04108572821883906, 0.029493458118409883, 0.09895074316450665, 0.018279171969381072, 0.03410779720833225, 0.043623815816376484, 0.04880941518011594, 0.08156950285117473, 0.06589693738327873, 0.017725252095730077, 0.06124034471389267, 0.04650034190666291, 0.042863412264494166, 0.05480666171699282, 0.012530774730558117, 0.05062791255993709, 0.028446125910587372, 0.013327813564589428, 0.06250460812401387, 0.03931888814775213, 0.15322886167034028, 23.870311283296157, 57.448222021902765, 29.32237248266897, 23.24412057476659, 40.597170629808986, 54.88611805823542, 60.09754773109191, 59.24268676388649, 53.35772337452058, 0.5343669196290355, 0.570558138912724, 0.2113173099895639, 0.1696626733868353, 0.23463534101122813, 48.11263976558563, 69.25494455522107, 61.576308742646255, 64.08483312975976, 58.60011231514716, 61.41971988062705, 58.25416711068923, 60.96214009869484, 60.43658564167639, 64.199903703505, 59.50059044745661, 56.535047177345525, 49.38767287038988, 45.92479659665016, 45.268023167887044, 44.987601157157656, 43.98288995988908, 45.658542186983176, 44.27487511788645, 43.9858905730709, 42.60669892834079, 43.89134184006722, 43.093363085100734, 43.56516145890759, 43.05384128324447, 43.53115450951361, 44.67448226867184, 45.635619855696156, 43.05282538936984, 44.1983457534544, 43.68392690535515, 44.46200747643748, 43.49726915359498, 45.095144702542214, 45.2011977472613, 43.35567551274454, 46.27268337434339, 48.561304000116166, 45.047362389103064, 44.30572063692155, 41.30479758785617, 43.94538425630139, 42.11107215573711, 42.481445881628225, 42.939967032401796, 41.92475565018193, 41.568718187270626, 42.59025635257844, 41.933196590792754, 41.21753661863266, 41.44038215760262, 41.233245711172785, 46.821097404726096, 47.96961445962229, 47.480781232157064, 46.48520523501981, 45.50166306957122, 47.7689185450154, 44.633375829265965, 44.32750940322877, 44.50033687776135, 41.60971480031168, 42.22640552828389, 41.88179000731438, 41.457487613924094, 41.21847014273367, 40.31790571828043, 39.723666637174546, 39.72861666833201, 40.333995280727265, 41.60049723040673, 39.36682508837792, 41.127259346746634, 40.06285359782558, 41.52914539460213, 41.316215607427786, 42.02386217732584, 43.28797148120019, 44.271376363692745, 41.37208192579208, 40.79881575799758, 42.04859272126229, 40.57131828800325, 40.20118382669265, 42.64210616388629, 40.84552726437969, 42.591127118756695, 39.31353576721684, 40.94190774425384, 40.45416101332634, 41.08485460281372, 39.45420372870661, 40.56343824632707, 39.35764281980453, 38.44648407351586, 38.85556767063756, 38.49926348655455, 38.973297611359634, 40.98136678818734, 39.55143928527832, 42.675324716875636, 39.7532844543457, 42.81958164707307, 42.93078084145823, 42.74110678703555, 41.98155941501741, 42.95187927061512, 42.70452676280853, 47.24413287255072, 54.6908663934277, 55.90465561036141, 57.4682378768921, 59.451160738545084, 59.145337458579775, 55.80525490545458, 45.51452844373642, 1.3145751313817118, 0.6358328137186267, 1.797448562518243, 0.545792967802094, 25.95379194905681, 59.389403020181966, 59.768872722502685, 50.82457826983545, 40.01516934364073, 24.42451080968303, 47.277928013955396, 28.569204845736106, 0.043023562945065, 0.10277816439948737, 0.07765931347685476, 0.07175023982962293, 0.041983510487742966, 0.042574826943417715, 0.0920015979077547, 0.07482448938272654, 0.053465720566530386, 0.09550227498215053, 0.028006573387932394, 0.01895278925076127, 0.10472497001530663, 0.044838432898564685, 0.06396373365855505, 0.17875123408532914, 0.11722213168057705, 0.10885537136346103, 0.11683004022005106, 0.1468883809303084, 0.20620252396310532, 0.2039056238267691, 0.12479145575555102, 0.13822306848822102, 0.13541351763471482, 0.2733394665823829, 0.09468796948391585, 0.13597668418961187, 0.08813443203126231, 0.1689477294923798, 0.08859066803368831, 0.19628246675335592, 0.1775962799306839, 0.32468822574423206, 29.489241876909812, 68.64299989515736, 40.67227225149832, 31.935712406712195, 46.51164985472157, 62.458430182549264, 68.04605437863258, 63.34844735360915, 64.85635942028415, 0.9612836953132384, 2.5168118649913422, 1.0107408608159711, 0.3451871144915781, 0.8800787430617117, 48.50490031703826, 73.66392397111463, 63.85152270717006, 68.53264793272942, 62.10229466038366, 64.34488234981414, 59.90717549477855, 65.02417802810669, 63.666637866727775, 67.30754267784857, 62.27687935675345, 59.99670359396166, 52.755408133229906, 49.29625026641354, 48.75560645134219, 49.79301060399702, 45.986350351764315, 48.252542864891794, 46.56889292501634, 46.78231693083241, 45.569190594457815, 48.044151260006814, 46.759916274778305, 46.07276801140078, 44.91969316236435, 44.865678202721384, 46.316547239980395, 47.66540719616798, 45.598235745583814, 47.212193012237556, 44.81518945386333, 46.646418571472175, 45.66343730495822, 47.1218922061305, 48.223034874085464, 45.9903197903787, 48.24973837021859, 52.994664869000836, 48.378125390698834, 45.436190866654925, 44.298417183660696, 47.56474348806566, 45.63211717913228, 45.70204127219416, 44.55916458560575, 45.58886128087198, 45.44258825240597, 45.492029728428015, 43.58640893813103, 44.27307867234753, 43.56810323653683, 44.94740863000193, 50.89021128992881, 51.69261447844967, 49.75278669787992, 50.58153252447806, 48.805997140945934, 51.97228731647615, 48.324887060349994, 48.63549170955535, 46.906432490195, 46.090591261463786, 44.81154164960308, 44.579145139263524, 42.57305675937284, 44.37735488337856, 43.81940557110695, 42.55131898387786, 40.53804089946132, 41.38632012951759, 42.55331547029557, 44.261072297250074, 42.46411292783676, 42.85793850498815, 43.704688010677216, 43.98222707932995, 43.137791772042554, 46.11499232630576, 45.72919191852693, 44.01454740954984, 43.01344087046962, 45.90144672701436, 41.04999257672218, 43.301648785991055, 45.95888983818793, 41.44938791951826, 46.02704101993192, 42.90520698793473, 42.39566364595967, 44.08340461792485, 44.40242275114983, 42.14459273122972, 42.38785812931676, 43.055637728783395, 41.531455670633626, 40.856607960116484, 39.95230551688902, 40.692554827659364, 42.27187364332138, 41.21077837482576, 46.119903133761504, 43.28966202274446, 44.50014860399308, 46.46599346591581, 44.64024782180787, 45.733333941428896, 46.46975894128123, 45.79117713436004, 49.782922267913825, 59.092295246739546, 58.34997492451822, 61.115614598797215, 61.073056882427586, 63.958611257614635, 56.56755185896351, 47.47168133335729, 1.975501492138832, 1.1121718825832492, 1.31725141357991, 0.6458614562307635, 29.18214971019376, 65.60821502439438, 63.25876628198932, 56.335284786839644, 38.807279371446185, 36.59610202235561, 57.680414568993356, 36.2590802100397, 0.1430000403835889, 0.21479974651048261, 0.14928511764493682, 0.17083370006613194, 0.16684573744573902, 0.17151141208746742, 0.2188546039284237, 0.17214383299071945, 0.12912275600096873, 0.20506515918720156, 0.12864860886287305, 0.060610540000902074, 0.35014915790769363, 0.1309021331009365, 0.19406085773821802], [0.10437941073530144, 0.01081705806897052, 0.017845414901873278, 0.07073410080685731, 0.017920734751368725, 0.09922639692142125, 0.025826612742797985, 0.0896177008267372, 0.017718179188969157, 0.06824628389891117, 0.05446066576687079, 0.07394631513424459, 0.0024106665871166176, 0.0207091779673412, 0.02311985939741135, 0.04238368034543049, 0.015551666259735584, 0.04929503448487771, 0.1244995302911247, 0.8643999263163537, 35.07161794170257, 39.523508087281265, 29.219449489347397, 32.84689664840698, 37.957093869486165, 67.84077321329426, 50.21510862535047, 61.59206490362845, 7.363598394778467, 0.3905118791566741, 0.17979283787069783, 0.06376314119646145, 0.2184499409650603, 19.244809189150413, 69.32182096665906, 58.51273367481848, 64.57832221061953, 57.53903273613223, 62.622836328321895, 57.59046677620181, 62.565024514352125, 58.95223133025631, 61.373000529504594, 59.19512410317699, 63.6671869985519, 56.33653210055444, 54.81828066610522, 45.248446618357015, 44.54297304153443, 42.82405707143968, 41.742738062335604, 42.37254519616404, 43.95405269438221, 42.87713850698164, 42.282860202174035, 41.86198596031436, 42.86197462389546, 41.29783145843014, 41.247170125284505, 42.34984643997685, 42.862770865040446, 43.894683699454035, 43.08768349309122, 44.423787901478434, 44.25389828220491, 41.06663127099314, 43.28111125576881, 41.122964351407944, 42.05394283417733, 43.09404557751071, 41.83864001304873, 39.31550087467317, 39.8766351515247, 42.37933481893232, 42.264244633336226, 40.59895138586722, 40.271723731871575, 41.55185984027001, 41.320518447506814, 40.528713503191554, 40.63153059251847, 38.47498009281774, 41.57041657355524, 39.48631617330736, 46.52313063221593, 49.4966676927382, 53.01601040747858, 54.07255964894449, 52.32415922226445, 52.41917471731863, 48.21532349432669, 49.11371492570447, 49.742404184033795, 46.04360518916961, 45.157647671238074, 43.773808017853774, 41.58710233626827, 40.76020786839147, 39.77785810347527, 38.59737765404486, 38.23270313201412, 39.528928802859404, 38.761874014331454, 37.9636638395248, 39.15562898881974, 39.627552878472116, 38.90689972908267, 39.024857167274725, 38.83462613628757, 40.53102770159322, 42.011126241376324, 41.46860753336261, 38.475109531033425, 39.02033467446604, 39.18811405858686, 38.03938519570136, 39.25675945897257, 40.06287713204661, 38.67260479157971, 39.86694689719908, 38.07471398384341, 38.26023817062378, 37.26557216336651, 38.23362096663445, 37.60308427195395, 38.41451675661149, 37.028923803760165, 36.50889204394433, 39.163665925302816, 40.83107333029471, 46.16321394520421, 45.48607164813627, 46.52995555631576, 45.81043597190611, 47.152278807855424, 49.74919772917225, 49.15551562463084, 51.44567381951117, 47.237547213031405, 47.33524168691328, 48.278889425339244, 51.19593651063981, 52.2398635648912, 55.20275923513598, 51.95021221714636, 53.761719657528786, 55.51940825677688, 49.928387288124334, 32.28652331136888, 0.08980004507447444, 0.020663287385456988, 0.5913106027630068, 0.09683224192309765, 37.78578042984009, 57.473521309514204, 52.433577660591375, 37.39416314709572, 25.749283490642426, 31.359922193711807, 40.819882808193086, 2.624199741309689, 0.28091583100538103, 0.05507727461536566, 0.027306786543058775, 0.09407945052390138, 0.09111822192226687, 0.08875756794887205, 0.042621535324161096, 0.02693904710242585, 0.014931497975222528, 0.09197115357364379, 0.04880139806998834, 0.024185177434476155, 0.014420193657579442, 0.07544795471814371, 0.03540150137738355, 0.03292993702475102, 0.08186192627275184, 0.01923515010745295, 0.053140799695205305, 0.02778652037734226, 0.09813217821741298, 0.07170338589217394, 0.07387431053024146, 0.05138467719417907, 0.05930489252111124, 0.0507955402586489, 0.07581815904667301, 0.0651558775514845, 0.03573741177998243, 0.009883954358707753, 0.05673712667738719, 0.05260829963991719, 0.06345884341205801, 0.15091423425943623, 2.1384796500205994, 48.26864811681932, 41.96930200822892, 24.96103221370328, 36.48275336911602, 47.73473508896367, 72.48985659691596, 56.05334481885357, 68.79840420138451, 7.065073174815025, 0.7434707411354589, 0.16566878124590845, 0.031010856130911462, 0.13999081637349822, 21.943115495866348, 74.31229176059847, 59.790841917837824, 67.67992465726792, 58.789198014044, 64.81011467595255, 59.65688905408306, 64.64826983790245, 59.33246589476063, 64.03759994814473, 60.57975999770626, 65.478117850519, 57.66211278976933, 55.445428432956824, 46.34863222798994, 46.65109795908774, 43.2210950697622, 44.4003438949585, 43.647358648238644, 44.785857969714755, 45.244716444323146, 45.224806493328465, 42.880566658512244, 45.381018807811124, 41.58360750444474, 42.60978975603658, 43.5366105264233, 45.23470655564339, 44.53541855658255, 45.40590624655447, 44.86893376996441, 45.52870781190934, 42.06449400994086, 47.19405205019059, 44.17816123654766, 43.19952203381447, 44.66892819250784, 45.39784185348019, 42.57861475790701, 42.12095652857135, 46.02267542193013, 44.803277215650006, 42.62284732634022, 44.36840403464533, 44.15748250099921, 43.33900936188237, 42.27774935383951, 42.81486303575578, 41.334882167077836, 43.10795430214175, 43.193183483616004, 48.030670073724565, 50.495267837278305, 52.54908361742574, 55.595019786588615, 53.46501981058429, 51.68158477352512, 49.3429264714641, 50.00075894017374, 50.415573120117195, 47.10377085593439, 46.54318963327716, 46.128802991682484, 42.938860924013206, 42.369128811743956, 40.31270073306176, 41.03108675249162, 41.20637355312225, 41.59007941522906, 39.928280999583585, 39.3941875427, 39.88851993314682, 40.44706936805479, 40.52533242010301, 40.736183351086034, 41.272928330206106, 42.97213439018496, 44.128468728834584, 42.5101262523282, 40.890520772626324, 42.10324702724334, 41.071612681111986, 39.77425736765708, 41.11836341119582, 40.785656206069454, 40.87822021976594, 40.870563753189586, 41.120301062060946, 39.74540049029935, 38.74424688277706, 40.40720631999355, 40.40323295900899, 41.1956262588501, 39.05013292066513, 39.11027854488742, 41.552581556381725, 42.528388807850504, 46.120919027636134, 47.70440732279132, 48.575742244720466, 47.83332386324483, 50.8624997446614, 50.62116415269914, 51.964003270672215, 51.75902020546698, 50.8591265063132, 49.17949699586438, 50.80331510113132, 51.619458352365804, 55.91086079997402, 57.90414656362226, 56.061303307933194, 56.720371323247115, 57.33020967052829, 52.658921749361106, 36.61211705976917, 0.1051483791501772, 0.49755081774726995, 2.3221483105613343, 0.1718247880137736, 41.42561835627402, 64.08531558129096, 57.464997999129764, 43.98897355602634, 34.16856673456008, 25.850264910728704, 51.86158626310287, 3.178156816190289, 0.26730333725290917, 0.01684247174360339, 0.0717073159232255, 0.05651603370243984, 0.029188359772125562, 0.057936724605819875, 0.052083077419909744, 0.0197900639801857, 0.0340568523613676, 0.05377140497007678, 0.09205195286701764, 0.025209712780891888, 0.00884829254280175, 0.11711084974869607, 0.043052367851017945, 0.166266544331466, 0.20826386738448374, 0.08384508276057821, 0.14615803866857482, 0.0971649615694919, 0.21821551806023046, 0.1985802708734428, 0.24318897315571386, 0.16497222346163568, 0.17934302168507732, 0.20037363673890793, 0.19669512767464886, 0.1572138365478285, 0.1371166689862167, 0.17527439000625766, 0.22779434438674684, 0.2162725965101873, 0.19210198623759134, 0.26327236645644714, 3.0701033626833274, 62.093379112981985, 51.970298674798784, 37.92136107721637, 49.80437763275639, 52.466753067508826, 80.53163328478414, 63.00285124009656, 74.64543434881395, 10.499690732648297, 0.9132332511005864, 0.8229043755319811, 0.2246822041249083, 0.4298178587229021, 24.490236005475445, 74.04924192736226, 65.51407029551845, 70.31028178430373, 61.44432490871799, 66.63509153550672, 61.471926627620576, 66.88335403319329, 62.4715034423336, 65.91768218624976, 62.850761336665, 68.30133007418725, 62.54349462447628, 60.36602220227642, 52.743770460928644, 50.74643681126257, 49.044034019593276, 47.65289875768846, 45.96747590649513, 49.14219525552566, 48.89776491349744, 47.22175575071766, 45.54092599499611, 48.29813257340462, 45.13922037616853, 46.93406558805897, 47.977953418608635, 47.83603029866373, 48.10352809967534, 47.40970003989435, 47.66046108738069, 49.09527194115424, 44.70755961633498, 48.36135725821219, 44.9646984377215, 45.55074760990758, 46.68151986214423, 47.467441251201016, 42.43701327231623, 44.21497660298502, 47.987649517674605, 46.95617598872031, 43.88333236017535, 46.08128347704488, 46.303281784057624, 45.1020323845648, 43.859543185080256, 45.57685098340435, 43.73527073091076, 46.700370773192375, 44.12130255852976, 50.20534976836174, 52.79744417436662, 56.67890010341522, 58.723113921380815, 57.20531748187158, 55.31395450715096, 51.21353226323282, 53.14688813301825, 53.677290639569684, 50.51086318108344, 50.512345837008574, 49.28780148106237, 46.369977766467684, 44.765838192355254, 45.41610833137266, 43.63913736035747, 43.164459966844134, 45.08584084049348, 42.93198500910113, 41.339267376930486, 42.689288354689076, 43.44603123203401, 42.00113204217727, 42.628248430067494, 43.74985802558161, 45.87216623367802, 46.06436629449168, 45.92923671968522, 42.97326795516476, 44.89116184173092, 43.32647738918182, 42.1386738746397, 43.28860298279793, 44.5437849721601, 44.24195074266003, 43.15601510386313, 42.46877270360147, 42.02277568078811, 40.39358785075527, 42.693175423529844, 41.94162184192289, 43.68754333065402, 40.95711477341191, 40.50151186604654, 44.61316385576802, 45.26561875497141, 50.24091389871413, 50.08066546532416, 52.27233686754781, 51.29335249623945, 54.744351833097404, 53.286210721538914, 54.63736918664748, 56.484911441802986, 52.22715116316273, 52.41659772011542, 53.06309061665689, 56.769079316046934, 57.71954021146221, 61.6242479508923, 58.3827502496781, 57.53326685197892, 57.965111963210575, 52.49748091543875, 36.459223070452296, 0.2418325225552244, 0.3430530080391515, 1.62462133313379, 0.26133247861458414, 45.421666329906834, 68.19781088059949, 63.765838530755815, 46.91793680191041, 40.146784474772794, 42.12118794841152, 60.976017444364494, 6.72826317048842, 0.5774365665931855, 0.1897848767018126, 0.29643971412893266, 0.2050521050489718, 0.18108273075232584, 0.12671385381010272, 0.11984076576247332, 0.158256191099363, 0.10983902825823716, 0.31192547671737214, 0.17077517094871691, 0.09387662874594813, 0.11419871206124944, 0.17361000270372437, 0.11354110984792633], [0.027774672827593265, 0.05924211161571646, 0.08037436738490097, 0.04512149472570708, 0.00355375116698504, 0.1043446839696938, 0.054592195402590506, 0.01823220694918306, 0.03322982980358986, 0.040377874468122764, 0.05836680636651093, 0.11430296130598554, 0.012299307009896204, 0.030167720828866287, 0.037999592811590245, 0.05207954958501843, 0.060182185768480265, 0.0422214957014207, 0.12723599635665456, 0.11506706506254212, 16.740703352036014, 46.171548981820386, 53.402485462927054, 49.148651476829286, 27.047954759290143, 56.357693287634085, 48.50462182875603, 68.81636865677373, 19.501767581509007, 0.11126764434119386, 0.22567107041756954, 0.30036784528243926, 0.06602413862222625, 4.416710897799462, 60.90792117580291, 56.94273048831571, 66.97800867019161, 60.431510094673406, 65.40409880299723, 59.150613046461544, 61.448262968371, 56.89292030949747, 60.260416307756984, 57.11878607350012, 58.80140835239042, 59.20838955909976, 58.39251302903699, 51.29418011634581, 45.48848390579224, 44.00504350662232, 42.92017083014212, 43.64053372413882, 44.8698555269549, 43.52801661337576, 43.2921213488425, 41.61301743599677, 44.228602916963645, 42.5306559378101, 43.342421823932284, 41.83322714221093, 43.34517925016342, 44.789301810726045, 45.59079108699676, 43.302558775871034, 43.54481612482379, 42.478292296009684, 41.35636106614144, 42.871635421629875, 42.047400320729906, 42.507168785218276, 40.572157675220126, 41.342691606090916, 39.124677565789995, 42.614320093585604, 43.67776093944427, 41.003261458489206, 42.055531394097116, 42.67952557533018, 41.53385223880891, 40.37461926860195, 41.58340354119578, 41.78551935380505, 42.08572187731343, 41.201902051125806, 47.82004271784137, 57.837254462703584, 54.42255273942025, 56.487837529951534, 57.43190496198593, 58.47896206763483, 53.44389000246602, 53.124683595472774, 57.0027780532837, 58.613236565743726, 55.05933776978524, 50.64629870076334, 43.35867220355619, 40.353018776063, 39.76006623237364, 39.07827984902167, 38.977541615886075, 38.04357428704539, 39.412599148288855, 37.86451808867916, 38.966774709763065, 39.266734046320764, 37.85070742330244, 37.74373654396304, 37.959286474412494, 38.141155012192264, 38.72961251966415, 39.2709937403279, 39.19011838974492, 38.4242207004178, 41.63004052254462, 37.083405525453635, 39.083724098820845, 38.9771415341285, 41.40148401260376, 40.264286918024865, 40.124101408066295, 39.402118575188425, 37.881678458183046, 38.249137863036125, 38.72674134469802, 38.27331927514846, 38.236511753451445, 38.095439787833925, 44.2189891876713, 51.51337392868535, 53.966012385583696, 53.77027042450444, 51.59938366182389, 53.15388171903549, 53.52183534253029, 55.00795079815773, 53.56582472401281, 53.67861640068793, 52.81361610658708, 54.14655123987506, 52.03232311433362, 52.48329370252548, 52.573080678139966, 54.96621677952429, 53.580211977804865, 58.909112714952045, 49.79901967510101, 52.79260396957398, 29.09725981373941, 0.811238388621038, 1.9453150538667559, 2.6567421757405807, 0.7620353191610306, 51.59017001428912, 44.53204924060453, 51.53335448234312, 31.284463636336792, 31.556862438878706, 42.8411429159103, 21.536402971513812, 0.31271868415417214, 0.04013570641437846, 0.07066628670380001, 0.09687389412354078, 0.0440000913917057, 0.04782777692702028, 0.01766503758488163, 0.0457590177745348, 0.018454759321626157, 0.022782533647372358, 0.02966179253323184, 0.04208191448161679, 0.06458384735930352, 0.05480499164531789, 0.024403520153775334, 0.020465531363903035, 0.10139408100756908, 0.04661141699480434, 0.020266438518921216, 0.05983596765286019, 0.07201692269694421, 0.027605118417751887, 0.025529181021415902, 0.043798683045972744, 0.07428531670161793, 0.012299011108435452, 0.08631130364993889, 0.133658685991841, 0.026880504578472148, 0.006638269649908668, 0.03346000475087955, 0.056490898357644204, 0.04047015741948159, 0.04126803033174046, 0.04302020364951703, 0.053243382698706085, 25.00320749898111, 53.50516134692777, 51.08239173889161, 54.66886189676101, 35.65718073998728, 65.48426812694919, 53.7154160776446, 75.19098897134104, 21.084343925599132, 0.15563122147033293, 0.37480153023235263, 0.4020233614550483, 0.06397918948242742, 5.925301534514274, 64.76850225079444, 58.54560705923266, 69.27336400555026, 59.913423830463046, 67.49275699738534, 61.08829529054704, 63.54514637301045, 58.469650360845755, 63.20675565350441, 58.76053725519488, 61.62549134223693, 62.24073079324538, 60.876016616821296, 53.01694000920942, 47.44866094281597, 44.635046758959376, 45.529915901922415, 44.938575452373875, 48.177853092070556, 46.27828059657928, 45.396257215930575, 42.74620586825956, 45.60686495996291, 43.442261834298414, 45.04432647458969, 45.66308429164272, 45.96277298465852, 45.790863344746256, 46.95656822573754, 45.461886313653764, 46.00569940382435, 45.52871565664969, 43.46655307277557, 43.73594930095058, 42.84055063801427, 45.79125558176349, 44.03266875974594, 42.14680102563674, 41.53429546663838, 44.60437774658204, 45.79135364101779, 43.018661545168975, 44.60744896242696, 44.504137654458326, 43.32133908425608, 43.91984178173927, 44.18798285145914, 43.81095678575578, 44.201970023493615, 43.446501916454686, 52.564255345252256, 58.31446570734824, 57.643226577389626, 57.8210158501902, 57.30480840129238, 59.23664239145095, 54.12889665172946, 53.443540911520685, 57.50794010777628, 57.10002537696593, 55.69265150254773, 51.968439471337106, 44.78675227011404, 42.00481514776907, 41.06055159722605, 41.46823098582607, 41.51871581231394, 39.98227242500552, 40.43494532185216, 40.90928931390086, 40.80980231685024, 40.88407631843321, 40.77640333483296, 40.912046740132, 40.03462822206559, 40.040613758948545, 40.855325345070135, 41.13008737564087, 41.459146776506984, 40.39014400974397, 43.16606813861478, 40.33330886594711, 40.41837330787413, 42.71199103324644, 43.759656106272054, 42.38496734249977, 42.18673859873126, 42.227966631612475, 41.136688724640884, 41.635716192183956, 39.92470772035661, 39.7052118855138, 42.08084244881907, 41.48817231578212, 44.43625319388605, 54.303983411481305, 54.93852484610773, 55.50691943014822, 54.730592158532914, 55.52812376329976, 55.89260608919206, 56.95440346194852, 54.52632688706922, 55.423502383693574, 55.91197475310295, 57.4912896463948, 54.81540164639873, 56.41769770653018, 56.37786995980048, 57.90758648226338, 56.02736303883215, 59.8637705464517, 51.462512554660925, 57.471736631085804, 31.59849447588767, 0.911861279558751, 2.8118638261671993, 1.2786592134544927, 1.4696391719964244, 55.487142839739406, 54.93731283372449, 55.01811758164437, 41.298086412491344, 31.692309725669126, 44.68325661074731, 29.523211563787154, 0.5480152356528467, 0.013056980415938363, 0.04874510592931221, 0.0687448156156367, 0.023332081074195526, 0.059957174253800226, 0.06428860473416506, 0.08806184520043674, 0.0786323753756381, 0.03251814944369178, 0.032799299881463094, 0.03765789844516305, 0.0538240620235522, 0.026825679496171016, 0.05659342773499028, 0.017616205225368182, 0.16647816845966926, 0.14006872751539753, 0.13187826701229619, 0.13451264420103642, 0.1551369262198287, 0.2151281377601047, 0.13651778741228965, 0.09425446331020325, 0.21547096210622022, 0.1839888086842914, 0.1512904447172919, 0.24962060303697664, 0.13834719005371296, 0.1754730059615066, 0.15377912730459245, 0.1716527246659802, 0.14037753755767501, 0.13984012687879224, 0.16893262223851296, 0.14636557188726243, 31.777499683441658, 66.35369285460442, 60.326806345293605, 64.45577167695569, 42.0292083678707, 70.11281398034865, 60.24469937047651, 83.10549259185791, 26.154960509269472, 0.289855157776225, 0.8088184700858209, 0.6516727540762194, 0.1767838743305014, 7.244858443737031, 66.29726563730549, 60.72828446665118, 73.11701220850792, 61.89852360756167, 70.68285203749134, 63.31329114975468, 66.06744612416914, 61.52407846143169, 65.1007426938703, 61.53260961655648, 63.962302207946784, 64.13562782349126, 63.72670112117645, 56.23192248805877, 49.27258660716396, 48.66921624829693, 47.12242172610375, 47.53438042056176, 50.59894784804314, 48.29541437087521, 46.89228842335363, 44.974374924936605, 49.29428908132738, 46.6257280688132, 47.62794071628202, 46.609607127404985, 47.97092060888968, 47.99559231727354, 49.867163012104655, 47.180359055919034, 47.838909318370206, 45.39013439609159, 44.86716085864652, 47.13150593542284, 46.29651961788055, 47.83008790785267, 46.011025982518355, 45.20563787029636, 42.294748906166326, 47.281583662955995, 47.24423877654537, 45.77488360866424, 46.623919856163766, 46.467123108525435, 46.94469913359612, 45.10582531652143, 46.35829694809453, 44.35974344130486, 45.12335831119169, 45.373456478118904, 53.69245060028569, 59.604733297901774, 58.74384364774151, 58.149565342933904, 61.58173730296474, 61.82452809426093, 57.802325756319114, 57.7647102263666, 61.219749604502034, 63.409451976899184, 60.15427697089411, 55.32147369077129, 48.30703243132561, 44.8158170330909, 44.881881513903224, 43.773596209864465, 43.386168018464126, 42.29575303293044, 45.01656786088021, 42.257772722551906, 43.387815413936494, 43.17714883435158, 41.984967954697154, 42.58864033606745, 42.77196015081098, 40.89708682029478, 42.669570599832845, 43.32634402859596, 43.50890682589623, 41.13028349414949, 45.012308166873076, 41.27132408080563, 42.324005865281634, 44.3478782715336, 45.39450391646355, 43.74591996592861, 45.58456236316312, 44.381336089103456, 42.66642093658448, 43.82746604181106, 42.92200257701259, 41.2844051853303, 43.447678627506384, 44.2207307200278, 49.09733903023505, 57.60964324397426, 57.812845553121264, 58.19662201789118, 58.98590487818564, 59.30335798571187, 58.000307390766764, 60.58618091767835, 58.26056841881045, 58.17674736822806, 58.74908393429172, 59.97729570634904, 56.72868282564225, 58.794230414975075, 58.20110136462797, 62.59366566135038, 58.66131305694581, 58.69067592005576, 57.45670218621531, 54.684629824853715, 32.71716033258746, 1.2715686713495564, 3.3529084584405346, 7.345511365321375, 1.6580540230197292, 63.47426129925636, 57.31737567532448, 61.676874391494266, 42.92477569272442, 45.63533352267358, 56.459831806921194, 39.73720665900938, 0.3960356488823891, 0.06791518069803715, 0.15456623668151517, 0.14748995913372887, 0.11779485135188988, 0.133626755447157, 0.17075707595194542, 0.2529695104326933, 0.23073022313896688, 0.12269572264725163, 0.0846098147092327, 0.1449571805255067, 0.11539196295122947, 0.15845047099696052, 0.11273875532131042, 0.17793725034402263], [0.07493443066074003, 0.011637909788518183, 0.0543259913402219, 0.08259800653303824, 0.026402804707627625, 0.03215814557587428, 0.008453211424151256, 0.05941582205254705, 0.018530678634922353, 0.04126876960658739, 0.08858957252795659, 0.03850768530561078, 0.06296881910173163, 0.03050248593001837, 0.11159571383388774, 0.03272587418436043, 0.03837325219665805, 0.047271083815083395, 0.04691006488076622, 0.042751034826881466, 1.5098801159089612, 40.83226965319726, 42.45644077177971, 37.01305389404297, 30.043910126532282, 42.00056329850228, 58.268460227597146, 55.62872471347932, 43.54199201829972, 0.061737348085209254, 0.05460975413781501, 0.0137052440174645, 0.0535349864062042, 0.2895061281179228, 36.548437380021625, 62.93506876114876, 56.94096542173817, 63.25833089890019, 61.38681119488132, 61.64726049669328, 59.74580134114912, 59.08449757483698, 58.49114887176022, 58.93465518951417, 59.45867207742507, 57.68037534529164, 56.531591569223714, 57.496247522292606, 51.00402278284873, 45.09896116871988, 43.612857480202955, 45.34177157186693, 43.12883700093916, 43.58516162441623, 43.976241542447, 44.06672669995216, 45.175294414643325, 43.76319408416749, 42.00694891714281, 43.71013226047639, 43.15310862756545, 43.36410468624484, 46.16886215825235, 45.98756236414756, 41.91984876509636, 43.027220156884965, 43.9153035994499, 43.97739471927766, 44.27610674212056, 43.72380956526726, 42.93065924798289, 41.759784683104485, 43.60486761216195, 42.4426850195854, 41.017809529458326, 41.81040287017822, 41.710311828121064, 42.29978915183775, 41.83529030892157, 44.42573731945407, 42.459484531033425, 41.31211280822754, 41.55872791044174, 42.05653552086123, 49.39097550607497, 53.20317414499099, 56.39546571239349, 57.21455074125721, 58.52155116296584, 63.704276930901315, 56.35034276593117, 55.984122830052534, 59.96988242672336, 57.01707901493196, 55.18714035710981, 52.207500088599424, 43.42778828836257, 42.91084343387235, 42.150272323239236, 41.19762274526781, 39.68584714397308, 38.71949280461958, 39.96952864431566, 39.52348455306023, 39.54099401350945, 39.7683895018793, 40.39171688018307, 38.65375780290173, 37.77536261466242, 39.34714655722342, 39.812484787356475, 39.72886770002304, 39.640979151571955, 40.88735541989727, 40.95278447674167, 38.96843387234596, 38.99865181215348, 39.440036127644206, 39.87570947216403, 41.40601435015279, 40.387943560077304, 39.31890156961257, 40.547540880018666, 37.462506524978146, 39.297607021947066, 37.81273495766425, 38.97694933799006, 42.31177199271418, 51.17591673328031, 54.0037416642712, 53.41926144015405, 52.47703359973047, 55.24970608372843, 52.36853691839403, 52.450228121972856, 53.79355753621748, 54.380120538896136, 55.13005418162192, 56.05950686239428, 55.18213541276994, 56.51722000491235, 54.076634991553526, 55.202872983870975, 53.85675476443384, 55.76812967177361, 54.81901414932744, 47.40775846665906, 64.620648507149, 15.12775903747928, 0.9959890717460264, 1.769220980425035, 0.6103217794049172, 10.388458198116673, 57.53594190843644, 54.320563270199685, 44.78312015533448, 25.52776175160562, 34.327948324141964, 45.0824950587365, 9.039086372621599, 0.2930715932480751, 0.034621681327060345, 0.06708544618900746, 0.054405373370935844, 0.14748170070590513, 0.02562223389113863, 0.02738836533089559, 0.03439932047659832, 0.034161350584679076, 0.026243199864702842, 0.02204006229857764, 0.017680340191169132, 0.0739520607936767, 0.11369009096656116, 0.0799682105500852, 0.02688875726063646, 0.0721258067736222, 0.02376278719654487, 0.02304528839886189, 0.1327760454507605, 0.0757522065372717, 0.007833086710888892, 0.05557925755819006, 0.05926186902328365, 0.02796908679057754, 0.051970554425591425, 0.027035668026655916, 0.07209293394079132, 0.03811630247641475, 0.07366410366469815, 0.06340209927950656, 0.03332429227509326, 0.02738522053996642, 0.02340567531064153, 0.1051463719998156, 0.19473820203734984, 3.6904747447659894, 52.51258596297234, 48.182155932149584, 42.62241194325109, 37.50576242323845, 51.33102686174455, 61.461030283281886, 62.28553995009392, 45.9110761457874, 0.03473533047062736, 0.07545877187963455, 0.25244270241068256, 0.09270161840944521, 0.2429875073533866, 40.88786925038984, 63.59250114810083, 62.20494308779317, 65.88909595243393, 63.034402785762666, 62.286885323063025, 61.03646116871988, 61.29960513884022, 57.90908482766921, 59.48253185518327, 60.356561445420795, 59.855109953111224, 59.510078660903446, 59.73930589614376, 52.76544155613069, 47.489261396469615, 45.68850125035932, 48.054341577714496, 45.7608768247789, 45.81788455286334, 43.9817681620198, 47.423302819651944, 46.79124816771477, 45.89443352914626, 44.300401902967884, 47.48268358169064, 45.330400620737386, 46.58052275257726, 47.059942291628936, 46.682704417936264, 44.24740283719955, 44.863928825624534, 45.179522729689076, 44.77706009341825, 46.585916011564194, 45.695683110144834, 44.70747332419119, 44.60884924857847, 47.12249625113703, 45.01659531747141, 44.58374607947565, 44.86186565891389, 43.088766067258774, 43.819640913317286, 44.219761894595244, 46.6226254740069, 44.294977265019575, 42.940167073280584, 42.27008896489298, 44.749693716726, 49.42756729741251, 57.363377232705396, 57.92975179610714, 59.10600000812162, 61.105985180024184, 64.60314689144012, 58.28547546940466, 58.851995160502774, 61.27538450302617, 57.929387015681115, 58.344103136370265, 53.80827426910401, 45.30541512273973, 43.90615270983788, 43.146260169244584, 42.28930073399698, 41.397604788503344, 40.39632566513554, 41.3806797612098, 40.128761183831, 41.97816656481835, 42.62363180037468, 41.9173070692247, 40.925410255309075, 40.47950344700968, 41.73857642758278, 42.104878733235026, 42.274768352508545, 41.98009244857296, 42.03435843990695, 42.67285362366707, 40.502202203196866, 41.33046950063398, 41.96798409185102, 42.394906628516416, 42.60715784565095, 43.70169916460591, 41.431517601013184, 41.47973529754147, 39.917478792129025, 40.93198022534771, 40.483092415717344, 41.995919212218254, 43.257255400380785, 53.167045193333784, 56.34787559509278, 54.64621413138605, 56.421659300404215, 58.701466360399806, 54.668975645496005, 55.491814382614635, 54.85781815744216, 56.26854958072786, 57.86856674378919, 58.069388174241595, 57.78742467203448, 60.31815751906365, 57.6550329116083, 57.68668251652872, 56.25717078485797, 56.28025785569222, 56.139852693003995, 51.392431566792155, 67.20053257480745, 15.804533612343574, 1.259511060291721, 2.0259724677570405, 1.6970671424942634, 12.277040212385117, 63.32229691167032, 57.96968544683149, 50.23718764705043, 34.72271919250488, 30.534165213184973, 54.61101085908952, 12.437326888884268, 0.8555956761683188, 0.048993712952060085, 0.05866744608107594, 0.05875725456843934, 0.08036292969219147, 0.03281216249771176, 0.026293298184511163, 0.06362295476719737, 0.0387153142852889, 0.025635851103992715, 0.10800817771063698, 0.07020076571573174, 0.05936938180257717, 0.07329899382086531, 0.053269544601320266, 0.011401091901315077, 0.16769856184480653, 0.18248412007045361, 0.13570317547888527, 0.26517064040226324, 0.18355287401185882, 0.09381785448039733, 0.08455814207873999, 0.10727728386559796, 0.10864995254744446, 0.1712654978637734, 0.2132297412402207, 0.17365750015502976, 0.13633794061118557, 0.1362697741076831, 0.24063572467815494, 0.10036831225959525, 0.15825836678906796, 0.2001779625612882, 0.2632683521557239, 0.38630424848487305, 4.254165916673599, 63.82321888400663, 52.68152636866416, 48.52188417988439, 44.73673420567667, 54.66853241766653, 70.69357579754245, 67.42993631670552, 54.757099536157426, 0.2318417554300639, 0.23368249617276654, 0.2695938482159569, 0.1736014684842479, 0.7760565667863816, 44.37809621134112, 64.48090230264972, 64.57944793085899, 68.0341225285684, 67.76058427749142, 63.103660075895256, 63.69414544874623, 63.2724553538907, 60.41360839720696, 60.19419493213777, 62.9200029373169, 63.25975079690257, 61.71403884887696, 63.265332329657774, 56.936733184322236, 51.15851709919592, 48.678900580252375, 48.67203251008065, 47.38056467425439, 48.45086966791461, 46.63305505629509, 50.395553342757694, 50.44537528868645, 47.814574933821156, 45.820496851398104, 49.57853932534495, 47.83697558987526, 48.11297708942045, 50.96424602693128, 49.69413941906345, 45.69484764529813, 47.741587469654704, 48.44107943196451, 47.219986761769945, 49.79255560905703, 48.63446012620003, 46.319634145306004, 46.17853080072711, 50.737085880771765, 46.691062988773474, 46.222539794060495, 46.792970088220414, 45.17236048175443, 46.01514839356946, 45.86149738680932, 48.701720929914906, 45.58729233280305, 44.929746197115996, 45.18602209706461, 46.303658331594164, 52.635838600897024, 58.52530094885058, 59.19352769851685, 61.564435728134654, 64.23990795689245, 66.51322349425286, 60.49628803806921, 61.941073479190955, 64.25427167646347, 59.671448892162694, 60.66811138583768, 54.58606850716376, 47.76348606232674, 45.85457832582536, 45.61480383719168, 43.3266499734694, 44.307619064084946, 42.97662942640243, 44.781723791553134, 43.62233392653927, 44.2606016128294, 45.87297031956334, 44.9748299198766, 43.3237317300612, 41.66742463265696, 44.63750608505742, 44.35884521853539, 44.88211685611356, 44.50316098428542, 45.20056624566355, 44.86564682376, 42.69535233897548, 43.32522615309685, 43.974896169477894, 43.430204468388716, 45.64818320735809, 45.70631665568198, 44.02242352885585, 43.59455570097893, 41.45873885000906, 44.611979299975985, 42.52344269906321, 43.37374194975823, 46.43888596565493, 55.453763469573, 58.58978471448345, 57.235029435926876, 58.624203512745524, 59.79827873168453, 55.53475256889097, 57.76163508815151, 57.05141152105024, 58.98398291680121, 59.30025539090557, 59.44559881764074, 58.558166488524414, 62.68820654961371, 59.00412821000623, 60.54645515257313, 57.988148043232584, 57.19248348666776, 57.90031048559374, 53.56979024025702, 62.50114087135562, 19.254666105393444, 1.6860539850688752, 5.439818501472474, 4.186978167103184, 14.030082764164096, 70.50260343859273, 64.7400886012662, 55.969966996100645, 40.01016832167103, 45.58358569299021, 62.08078438235868, 19.99408583487234, 0.8995139646914698, 0.18964857433832463, 0.21163232534402804, 0.21517108464913987, 0.2392872873573534, 0.08647454166484457, 0.13831558126595714, 0.1472925382756418, 0.10784875481359421, 0.11636106417544427, 0.2854245955184583, 0.1594391993937954, 0.1863395954452215, 0.2282879654798777, 0.13317660218284977, 0.10379038105208067], [0.02817259613244284, 0.07103648337145006, 0.04875489270254489, 0.040614986341566815, 0.030419361559794317, 0.020322382089591796, 0.04446262463686928, 0.07143190731444667, 0.018312182698038318, 0.0028515664669084215, 0.02518589702254582, 0.037533409157467466, 0.07776005403889764, 0.032060706852785045, 0.07140036747460404, 0.023310944708364627, 0.009455449781530808, 0.013600263158760726, 0.05420254776254297, 0.05936935881993944, 0.0205857228983434, 18.67342968140879, 49.302816314081994, 34.98893437847015, 41.51363242057062, 31.213417745405632, 52.90177137620988, 54.50470286030924, 57.099397797738355, 3.2748746198992578, 0.392073963077799, 0.19607076601636028, 0.05348695269335182, 0.1883588040307645, 18.98774293161208, 56.93055937367102, 55.65967613650907, 61.44769030232584, 58.221285881534705, 60.835980984472464, 62.882736498309725, 61.625373671131754, 57.8804946714832, 60.474299230883204, 59.1294793159731, 64.54000457640618, 57.03497679002824, 57.27917963458646, 58.836748907642985, 49.47379635226343, 43.403449981443345, 44.936845687127885, 44.029232763474994, 43.99961494630383, 43.983058621806485, 45.45915242164366, 40.34074567979382, 43.806022444079005, 44.48366288215884, 43.5044353238998, 43.206954925291, 46.71236145880915, 43.852428005587676, 43.86330081570534, 41.986768322606245, 42.854624102192545, 44.759562400079545, 45.58557433466758, 45.111669648078184, 42.82089956345097, 42.37935443078318, 42.74045175121677, 43.06269015035322, 43.437249045218195, 42.41824080867153, 42.70889236081032, 43.246045266428304, 41.00439110109883, 44.795985529499674, 45.30845103725311, 43.47331916132281, 43.15867839321014, 44.022211720866544, 42.17007637023926, 45.87018935911117, 48.55698154818628, 53.364473773587136, 53.49010336783625, 61.21305411861789, 73.60810079882222, 55.70852533463509, 56.36491044875115, 58.912552633593165, 54.808733617105794, 49.94914447107623, 48.34403999390141, 46.467142720376295, 44.430934459932395, 45.503247707120835, 41.64116828672348, 43.65108489990235, 40.717909028453214, 40.37169710282357, 40.54390484286893, 39.634381724942116, 40.262969001646965, 40.30189852560721, 39.57684839925459, 39.67666095302951, 38.459455351675714, 41.907257956843225, 38.7266589749244, 41.00372822053971, 42.19062566757202, 43.13127671518634, 41.01266730216242, 41.3071313981087, 40.979409525471354, 39.62424239804668, 39.30755023033389, 39.9107244706923, 38.949833992988836, 40.38597845262097, 39.37560335282357, 39.81281426645095, 39.42262864881946, 38.459722072847434, 41.958742987725046, 54.46396120132939, 54.4013640957494, 54.04710738889633, 52.84113153334587, 51.16545577203074, 51.396479452809984, 54.10172247117566, 54.279876524402255, 53.699554012667754, 54.414496191086315, 52.70095386812764, 53.71723213503438, 55.23930395803144, 51.878087674417806, 51.44886662883144, 48.99411009204004, 55.484577609646706, 57.371351411265714, 59.37176412151706, 51.999445807549264, 3.0561242805373285, 0.48639305356529455, 0.8939630754532353, 0.9166006671805537, 24.694922931732673, 53.38381498090683, 42.60534571063134, 31.028107327799646, 28.337282942187404, 37.532764019504675, 25.789136732778243, 0.3252827712605077, 0.07152810497509857, 0.040567848951585835, 0.06830543354754487, 0.051049513727306366, 0.07383474974983162, 0.10934768244624139, 0.07766645341630905, 0.04925363126300997, 0.03724793415336359, 0.06744621997518886, 0.07507344497547996, 0.07708567450003279, 0.019423908426336223, 0.07454783205063113, 0.052519785841145826, 0.034829723994217576, 0.009207105143896995, 0.014351717846077538, 0.05805436123703277, 0.038094649001234965, 0.07087680766539228, 0.05402813635526165, 0.14366854402807452, 0.047579832570326906, 0.03751448295529812, 0.025032328952464367, 0.01504563454223136, 0.024759314368448915, 0.02692732978762398, 0.0444419747368703, 0.08895789228019216, 0.060689776474910404, 0.04257116504313965, 0.015104870375756536, 0.08567582605586899, 0.05688309324003997, 0.12439158850259359, 28.971912630142707, 57.15187518827377, 35.506149876502256, 46.73895512857745, 43.1391175331608, 60.889748834794574, 59.88757933339765, 61.81947608147899, 3.3440225739632887, 0.2850249121266027, 0.7165452020783579, 0.31050223857164383, 0.5934609809229451, 23.108639947829708, 60.76038906651159, 56.149944951457364, 63.59226972826066, 60.752862038150916, 63.332295033239554, 63.7819790840149, 61.399488295278246, 58.68218791100287, 61.99443732538531, 60.921108184322236, 64.4990824883984, 59.6193088254621, 59.9331533524298, 59.72476959228516, 50.61770462220716, 45.99699958678215, 45.539776740535615, 45.71886824023339, 46.543550491333015, 45.01340250815115, 46.89588523680165, 42.89478917275706, 44.76552048037129, 46.460113833027506, 45.483420125899784, 46.27207932933685, 48.829903987146196, 45.69320024982576, 44.64511548319171, 44.4026816275812, 44.72362956693096, 45.65022676221786, 47.140723505327784, 48.35684261014385, 44.53273957775485, 44.27584786568919, 45.95771312713624, 44.16668438142346, 44.772329714990434, 45.882682108110004, 45.44878559727823, 44.131186931364, 44.2257748880694, 46.159872085817405, 47.80790298215805, 44.66731217599685, 45.032904532647905, 42.80992477170883, 43.928290567090436, 48.756183039757516, 53.596595718014626, 54.22902691748835, 56.31235068844211, 60.48832170424923, 61.05369998562721, 58.72907984641291, 59.10542341970629, 60.82845787848196, 58.3957411396888, 52.051625097951586, 51.52470565611317, 48.07480458290347, 45.91354723899595, 45.894610035804014, 45.63612976381856, 45.47584995146721, 44.29076463945451, 44.15753349181145, 41.56077538767169, 41.073954336104855, 42.55895191623319, 41.46584226239113, 41.555437041867165, 40.70492206081268, 40.40579034436134, 41.55836705238589, 41.34096968558527, 42.72297366972893, 44.03601061913275, 43.70197765288815, 42.90469315744216, 41.780282989625015, 42.2479824866018, 41.517535178892075, 40.35847087060252, 41.69355546274493, 42.64944884084886, 42.75765526679255, 41.201902051125806, 41.59247206103417, 41.03791167659145, 40.96511640856343, 44.74721870114727, 53.725116099080736, 56.59259227014358, 55.752761825438476, 54.613423116745494, 52.98328215076078, 54.471437238877826, 57.54450444252261, 55.697232830908995, 54.76524629900533, 54.4473970320917, 54.04586791992188, 56.00738248517437, 56.42195347816714, 55.948876411684104, 54.49954102116247, 50.87014836649741, 53.70117787391909, 57.23850073352937, 59.84423322062339, 53.71132504555487, 3.7062284542668253, 0.38270890592567386, 2.209095060825348, 1.0372926102530573, 29.098367883313088, 61.38778786505423, 50.17559466823455, 38.002409012086936, 30.916741432682162, 39.65373469937233, 31.382018866077548, 0.7470829376289922, 0.03197445492861012, 0.05286167939043334, 0.05042602157881183, 0.04605024609895003, 0.007393127204024143, 0.09667138644163648, 0.03816482265509906, 0.09284455509435746, 0.04736443545909659, 0.08015506705569644, 0.032493025590215004, 0.05365460720514098, 0.012586314189848642, 0.08720138290476415, 0.06770770110550427, 0.03357997028938225, 0.10017715033984954, 0.11646853098946235, 0.19683352911904936, 0.1545592193161288, 0.13816262415099528, 0.13563589763737496, 0.24996155812855692, 0.09291250709324114, 0.07962550877803758, 0.07642298546289245, 0.08518786635249855, 0.06433643926415714, 0.14875699195169634, 0.23880195533556325, 0.2240355952732986, 0.1949502245312737, 0.1255002019986991, 0.10819765423694927, 0.28369176592076983, 0.15308186471942933, 0.19182101583048222, 33.574139379685924, 66.71823793841948, 42.53133450784991, 57.45026557676254, 45.15212889640562, 66.92380935915055, 67.07937840492495, 70.8381700515747, 4.575744377028558, 0.6978298579492878, 1.0087965296641475, 0.2654563299109859, 1.0146480930909034, 26.01906999464958, 60.726048715652965, 58.25969373026202, 65.3695309546686, 63.43333528887842, 65.27578630755025, 67.75349263221987, 65.57129767633253, 62.2850888775241, 64.6883721505442, 61.56873856821368, 67.43913035238943, 63.426494675297896, 63.15694155231599, 62.58334198305684, 53.3242694793209, 47.505574534016276, 47.661571118139456, 47.362486470130186, 49.45348631951117, 46.70659949702602, 49.424527460528964, 44.763304341223936, 47.582578505239184, 49.397604311666186, 49.05975880161409, 48.224497918159734, 52.14312614933137, 47.541519134275376, 46.302767953565045, 46.48716642010597, 46.28626654225011, 47.970712723270545, 49.66211326660649, 49.99695031873642, 48.518216763773275, 46.187579708714644, 47.24553708107241, 47.20172420624764, 47.70361500401651, 48.37246148817001, 47.16702691970333, 47.07694576632592, 46.95886673465852, 50.36222104103335, 49.22691452887751, 46.289930035991055, 46.1707252840842, 45.92928771049746, 46.73329122604863, 51.25365026535527, 54.179844317897675, 56.95416027499784, 58.66348212765109, 63.33803738317182, 62.762578610450994, 59.27823912712836, 61.79354136989963, 63.119192661777625, 60.08947549327728, 52.79536531817529, 54.218032513895345, 50.326754969935266, 47.75465680706886, 49.78464811078964, 46.96682130136798, 49.24178031183059, 46.29066351921328, 44.7570756173903, 43.90642335337978, 42.2818874543713, 45.71276503224527, 45.925432020618075, 44.16661377876036, 44.979705426000784, 43.1286330376902, 44.317515204029704, 42.54859685897828, 47.44815495706374, 46.97388549004832, 47.28914207027805, 45.56870814292662, 45.48516165825629, 44.15769823135869, 42.799569714453916, 43.727794693362334, 43.066086922922445, 43.932856205971014, 43.782095986027876, 43.24689249838553, 43.89360897002682, 44.58517774458855, 42.545364825956284, 46.986495910152314, 57.47625912389448, 58.1199396810224, 59.57065574584469, 57.04541421705677, 56.337689199755275, 57.94674742606379, 58.48914846297234, 56.882357366623424, 55.7779630537956, 57.21499004671651, 56.22659983173494, 58.071027724973625, 58.39590195686587, 55.27663707733155, 55.32206204629714, 51.60370611375379, 57.37968252551172, 59.498848915100105, 57.53318055983513, 54.26447729910574, 5.571536594821561, 0.7882095404690312, 5.938920494048826, 3.294581343089381, 31.20326076784442, 65.49786698433661, 56.35709708736789, 43.5133469489313, 42.309995159026116, 50.853521439336966, 44.4538293346282, 1.5467616723429773, 0.0960972112032675, 0.18086284819629886, 0.1628144295705903, 0.1784017294525139, 0.18020528428737195, 0.2058085862306818, 0.18034017704907926, 0.1346680374755975, 0.12053379188141516, 0.17398815902490772, 0.18498096915502704, 0.13262091264609369, 0.07350868740749937, 0.254870327790418, 0.10709154584835615, 0.08570833882737545], [0.04717061521425363, 0.08078064679378465, 0.06956163388226302, 0.02585844369605184, 0.049257580446259636, 0.014854396971303129, 0.042404793728623665, 0.09119116881441686, 0.03995867498639611, 0.08733985329707784, 0.04619249713517005, 0.0257577471840646, 0.09470956550250131, 0.009834064797858798, 0.06715499165077364, 0.037826311383997245, 0.06181009579449893, 0.07707137163848647, 0.04313933415218227, 0.010763957642108924, 0.09767483904837601, 0.5705488845705986, 36.43887381399832, 44.924847156770774, 33.02989090642622, 33.89768392808976, 41.381483847095126, 52.32959954969345, 66.56845831101941, 16.154848337173462, 0.35415334627032286, 0.9311462253812821, 0.4565542966367737, 0.4871915010434966, 5.047291719144391, 53.124044249134684, 58.347813698553274, 62.56927636361892, 58.561963342851215, 62.325375541563965, 59.88519060996271, 62.35887258283554, 60.13369629459997, 61.59589313691663, 57.78429462063698, 62.2844652206667, 60.909874516148726, 57.14725071384061, 59.973702815271196, 60.16190205850909, 47.4309318296371, 43.590856905906435, 45.76773705021028, 41.67186083332185, 46.37992881959485, 47.0111793856467, 46.02718222525812, 47.322482216742735, 48.02390006280715, 44.43142083383376, 41.25696820597495, 42.62628724498134, 43.49384492443454, 44.67578057319888, 45.40048553097633, 42.73471724602484, 44.177957273298695, 44.76497134854717, 45.49045293561874, 44.32285354983422, 42.59743036762361, 42.13535947184409, 43.77916989787933, 42.280824492054606, 42.54287412089687, 42.685150254157286, 41.55271491696758, 42.146424478100194, 43.93862209012432, 46.23223197075629, 46.012006575061434, 43.94614519611482, 45.522071161577784, 44.19641986969979, 48.565316584802446, 52.84209643640826, 57.73415496272426, 58.83230093986758, 62.00833428290583, 103.97974260391729, 65.51487438140377, 55.945205073202814, 58.14335230858096, 52.833769244532434, 49.24784037374681, 48.429908521713756, 52.09153129208473, 50.99060043211907, 50.81632560299289, 47.19124363314721, 42.44825870760026, 42.67047274497248, 41.68751893504974, 39.27971316922096, 41.01455003984513, 41.38748507345877, 40.73291993910267, 40.014781028993674, 41.89127429839104, 39.57028235158613, 40.92860698699951, 40.29790555277179, 41.898930764967396, 40.614429058567175, 41.67015067992672, 41.62609854052144, 39.833520458590606, 39.69165617419828, 42.37700493104997, 41.40768135747602, 39.655531144911244, 40.51421642303467, 39.015090465545654, 39.80789561425486, 38.927103857840265, 40.69917971088041, 39.56915663134667, 41.100316586032996, 51.8364477926685, 53.205908037001095, 52.967761331988925, 50.86825386170418, 51.649225219603515, 55.39248035800073, 53.753396388023134, 53.02103496366932, 54.86346637049029, 54.463984735550426, 57.14209671943419, 56.36368666925738, 55.32096378264889, 54.73586382404451, 56.11594584680373, 53.726316344353464, 54.51703086976082, 57.063543411993216, 60.51853964405676, 25.29400614000136, 0.11786737689568151, 0.14609066889651362, 1.1110510653065098, 0.12825212771854094, 31.308397939128263, 57.72253297990369, 39.132522306134625, 33.2422205709642, 32.60820081157069, 30.47447458390267, 6.707408418578487, 0.15483232966113478, 0.023774175093539303, 0.027065669944990548, 0.09453297457507542, 0.03613509568235567, 0.15414934695488022, 0.05185156947963181, 0.027959313423883532, 0.06619633220496678, 0.05057396847874888, 0.058360888337295865, 0.02526043929279812, 0.047159460974076105, 0.057598734274506576, 0.038845047444826176, 0.005303107196420071, 0.023089060747635462, 0.006871117765249144, 0.10068454569385898, 0.057720017484239036, 0.03274375084607351, 0.013646364414824114, 0.037742708208820516, 0.024807238913772088, 0.054341021985296285, 0.07079417742187939, 0.06793094678751885, 0.07452218342692622, 0.04598103771587053, 0.08197430371036453, 0.006936820338465154, 0.029949533242371776, 0.053036619398382404, 0.020930165605198954, 0.04763823528323443, 0.047880238628075014, 0.004875595181910021, 0.05232353326714328, 2.3117327017168847, 50.57771605830039, 49.460487750268754, 39.676919829460886, 41.32848478132679, 54.62992452806043, 57.757167508525235, 70.28233881919616, 16.749426703299246, 0.5865033703946299, 1.381369663342353, 1.9469615913206533, 0.31567547710672506, 5.391993041961424, 56.656366086775265, 59.85158766469648, 65.54212308699086, 60.77220324547061, 62.46771443274714, 62.04004272337883, 65.7717151026572, 61.54693411242578, 62.75806004001249, 58.44789297349992, 62.40140284261396, 60.84347271150159, 63.31805290714387, 60.44826253767937, 63.57515250482867, 51.102956725705056, 44.96130166515228, 46.27746474358344, 44.828003837216286, 47.752872128640455, 48.07246292791059, 48.62316370010377, 47.47517224281065, 47.54774785810902, 45.86165428161622, 44.43561384754796, 46.53780814140074, 45.20635958640806, 45.92489073353429, 48.63584080050069, 45.62410377687024, 44.806607307926306, 46.06003992019161, 48.678618169599964, 44.75183140846991, 45.30472086321923, 46.3203715508984, 45.672682331454375, 44.03049576667048, 44.94754983532814, 45.589818339194025, 44.52356515392181, 45.02911160069127, 47.52389984746134, 45.98680926907448, 47.479835940945534, 45.141852286554155, 46.334570530922186, 44.09935689741566, 47.85051953408026, 54.11344643562071, 60.77824369553597, 59.659568032910755, 66.17782162081811, 80.44410951675908, 60.152037297525716, 59.130789387610655, 59.977499669598, 54.28011971135294, 51.028039455413825, 50.42795996512137, 51.535535320158935, 50.72087472484958, 48.926939502839126, 47.173918524096095, 43.98137200263239, 43.798016886557306, 44.341190630389804, 39.00784584783739, 43.811176438485425, 43.12211013609364, 42.35633796261203, 41.990031734589614, 41.5501614539854, 42.5859692019801, 42.65271617520241, 41.51784896850586, 44.1847861197687, 42.12831097264444, 41.49221235705961, 41.88280197881883, 41.51411879447199, 41.70214937579247, 43.01282113598239, 43.13011961598551, 41.42465737558181, 43.89836288267567, 42.182361233618956, 41.744542352614864, 42.113637385829804, 42.881598241867565, 41.37901667625674, 44.99281398711666, 55.33984607265842, 55.39472003136912, 54.71760519089238, 52.50867535991054, 53.56006668459985, 56.44647221411429, 54.93913673585462, 54.624943117941584, 54.403568467786236, 54.71695799981394, 56.86867613946238, 57.98215073923911, 56.95722364610242, 55.14467677762432, 56.662535975056315, 57.008418421591486, 55.87217054059429, 56.715146726177586, 59.944889083985366, 28.381321353297082, 0.3687738891570799, 0.5387944175351052, 1.9730604295769048, 0.38952923349795804, 35.69613379816855, 64.85529645796746, 43.8582331134427, 41.72344392345798, 38.96171485224078, 37.88992720265543, 10.763861383161238, 0.4675356460915458, 0.0375862653938032, 0.10168655805530087, 0.04634050915258066, 0.032757214841342745, 0.05721078734965094, 0.05019887650926268, 0.024665407310690612, 0.04920144152316836, 0.04013407081666012, 0.01654993723927727, 0.05598604258510375, 0.03526306928946607, 0.037719032261520624, 0.005216768129743757, 0.04531312012864698, 0.04328797436169079, 0.12036395784948142, 0.20338733470247639, 0.16339751441151867, 0.18260376768246775, 0.14762336568486306, 0.06603628877670535, 0.1579440102702187, 0.1432583192663808, 0.1410597082107298, 0.17546750545021028, 0.184123395010829, 0.1345421539078797, 0.16416030815772473, 0.106668749583825, 0.1510851178318262, 0.14578846253214345, 0.08865880389367381, 0.1517583558996839, 0.1423735796443878, 0.1271549136107487, 0.20457444922818294, 2.6251786178158176, 62.24715563558764, 57.48438235252135, 47.13969584434263, 44.840037668904955, 58.0041709253865, 62.53981936362482, 79.39912734493133, 22.421266148167273, 1.183340715304498, 4.503710048813974, 1.8459299158665443, 0.8313893815202098, 6.713098797105975, 60.373141304139175, 60.061932609927275, 68.0303256742416, 62.62017303897489, 66.53114872594034, 65.9771296285814, 69.47984541616133, 65.04379380133845, 66.36941371425506, 60.95356187512798, 64.63975044988817, 64.47963145471388, 66.17399338752993, 65.70860024421447, 67.50214715157786, 52.142518181954664, 47.83313951184673, 48.73984636798982, 46.39831689096267, 50.10081075852918, 49.92168787987002, 52.154410808317124, 53.330831604619185, 51.975425212614, 47.462573589817175, 45.71043906673309, 46.479337369242025, 45.346803972798014, 47.64004907300396, 50.77330504694293, 46.737841175448516, 47.745078379108065, 46.758614047881096, 50.632809669740745, 47.904428589728575, 47.410194258536066, 48.76071729967671, 48.30225106208555, 46.773821077039166, 46.6068143998423, 47.20458361410326, 46.47511297656644, 46.09485095547092, 48.693872267200106, 49.22845602035523, 50.55077721995693, 47.27526080223822, 47.714346608807965, 45.88803222102504, 51.39520468250398, 57.155534759644546, 63.53705844571514, 60.97180481879943, 67.6630506207866, 80.97607704900926, 58.661819042698035, 62.44713767882317, 60.88309257261215, 58.35114379082957, 52.848258479948974, 51.71847074262558, 55.711847582171046, 54.76673679967081, 53.07399088336576, 51.74798657817226, 46.26159875623642, 47.34261182046706, 48.13828422177223, 42.29791033652521, 46.97614869763775, 46.16927792949062, 46.04446811060752, 44.952409651971635, 44.74945837451566, 44.23048565464635, 44.97688916421706, 43.700891156350416, 46.66352010542347, 44.984910411219445, 45.49798780871976, 44.70391181207473, 41.92142555790563, 43.90547413979807, 45.64417062267181, 46.56637868573589, 42.87544796543737, 46.696001252820416, 44.08629148237167, 43.56520852734966, 43.37246717945222, 45.38567073883549, 44.524765399194536, 46.72664280860655, 57.57394967540618, 56.895387480335856, 57.45911836624146, 57.127509424763346, 58.82819814066733, 56.32512977046352, 57.31100182379446, 56.99323492665445, 59.218768150575706, 56.81645762535834, 59.300655472663145, 59.013337935170824, 58.422636831960375, 55.671455014136534, 59.88968956855036, 59.67621064955189, 58.682211445223906, 57.81882716763405, 60.29481157179802, 31.29455589479016, 0.4207868159057633, 0.4150831687354273, 3.75138204424612, 1.4361668906865583, 39.95265460783436, 70.85897430296868, 49.31384601900655, 45.721409936105054, 45.97742695962229, 53.33618563990439, 20.842202286566458, 0.663835411110232, 0.15104322814412657, 0.21125286667337342, 0.12793003371165645, 0.16887502774836557, 0.26894981341977275, 0.1832719189265082, 0.2679235007493727, 0.14165921797675474, 0.21314933265168823, 0.14393307418832857, 0.08722550701349975, 0.1758499518637696, 0.09418048986023474, 0.1984523801553634, 0.12571724236852702, 0.18270150517984746], [0.06255800828277584, 0.03967333404767898, 0.04013718879451195, 0.014250393141992392, 0.03256679602688359, 0.09342134269254823, 0.02113023138184461, 0.04487664919466742, 0.05456388845378834, 0.06965632234970409, 0.07662954574991619, 0.09705469087367097, 0.0545350490738788, 0.12525953547728638, 0.06388234447747951, 0.015382644281001582, 0.021890705796859918, 0.09770165978660507, 0.02989760971808386, 0.023416569080924796, 0.028114030625851407, 0.1792727714224208, 6.719271136868385, 39.34026671994118, 24.7635506814526, 34.77309811499811, 31.948648383540494, 51.481018297133915, 59.13721815232308, 40.75107659063032, 0.17508053911789773, 1.2356940608832145, 1.146305573563422, 0.2200971372545727, 0.12102467804065636, 24.01625483266769, 63.56672333132837, 58.86063614199239, 63.13263070198798, 57.810241099326845, 61.12473018707768, 60.21266145090903, 60.86100178380167, 58.853811217892556, 60.75115580712596, 57.12574043581563, 59.67251969921974, 60.57641029357911, 59.84759469186107, 61.108087570436545, 54.982875085646114, 46.55943216816072, 44.73261179462556, 48.17096933241814, 50.294897479395715, 54.34639600015456, 55.69294568031065, 56.3319899958949, 56.512317042196955, 55.31099704004104, 52.27803999377836, 45.72427326633085, 43.76633590267551, 44.13893361245432, 44.15874158182452, 42.60024270703716, 41.2106881603118, 44.65861235895465, 44.44916955886349, 44.75641273683117, 43.291968376405784, 42.34039745023174, 42.60252944884762, 45.49432039260865, 41.18982115099507, 44.497328419839185, 43.97238977493779, 42.83414932989305, 42.03306405775009, 44.00549065682196, 43.06978179562477, 46.10342133429743, 44.87264825451759, 49.51968808327952, 51.09695157697124, 57.10532449906873, 57.08400641718219, 62.90926741015527, 57.37909809235604, 98.21891830813502, 87.7583336061047, 59.63554743797549, 58.46948562129852, 54.80592912243259, 54.0415297785113, 56.27731607806299, 55.74687434780983, 58.82277742508919, 58.53986470930038, 55.38795786519205, 48.99320010216006, 40.03844861061343, 42.40353192052534, 41.20596170425415, 40.60624307201755, 40.46417090200609, 40.84668044121035, 40.17233087170509, 41.29668220396965, 42.22776266836351, 41.610844442921305, 42.97134207141015, 44.23563964905278, 40.97764445889381, 40.68839711527671, 40.07825674549226, 39.290511454305346, 38.6321416208821, 40.57170660265031, 40.988144643845104, 40.81466605586391, 41.87316471530546, 39.89659217096145, 40.9035587310791, 38.267125852646366, 42.134084701538086, 39.552663064772084, 43.04869905594857, 50.09748851099322, 52.480963814643125, 52.75342341392271, 48.001146393437544, 58.44781452609647, 50.54882387961111, 52.0714448344323, 54.31994745808264, 53.48118782043458, 54.98575802772276, 55.11394108495405, 56.04271519568659, 56.375897007603804, 57.353163380776685, 56.406722914788034, 56.78243890885384, 54.47590089613392, 54.691701858274406, 50.77947101285381, 3.6395113891170876, 0.6629132863975341, 0.48123400297857105, 2.341639058243844, 0.9765295191637933, 53.79015684127808, 49.45414920007029, 33.648868376208895, 36.38034420628702, 22.69391009884496, 19.684165639262048, 0.9316373796712969, 0.10610292470383068, 0.16139499122096648, 0.06658202683132503, 0.02573430872402124, 0.02374835984571086, 0.06701623780592796, 0.06545089801112491, 0.052583961026562806, 0.05608426271787575, 0.05391134242076547, 0.04607281121875971, 0.047303401234169165, 0.05322560179798354, 0.13135801670291733, 0.058820882000990456, 0.052987949832552866, 0.024013592891635436, 0.03835010868046553, 0.02210088201888627, 0.0054479830413906565, 0.03531359661851199, 0.0178030023591653, 0.03622207347483885, 0.09558829133428874, 0.021249641506602208, 0.02371442981154448, 0.05237422913553254, 0.0946726247427925, 0.08057830765122369, 0.029933435819862835, 0.11018382145031808, 0.03344289034665112, 0.04061307112175611, 0.007833722085061093, 0.03939568846216125, 0.0260594766587019, 0.10433425751304436, 0.04775409076002337, 0.2029080241317711, 15.83692748700419, 52.41441295992944, 27.315046594988917, 43.065102408009196, 44.31273775715982, 57.163077477485906, 66.89697250243157, 45.565123096589126, 0.06436114559971517, 0.5752798145817173, 3.9321510926369703, 1.395097836371391, 0.10144805956271388, 26.823518699215306, 66.15271060697495, 59.26596603085918, 64.00960599222492, 60.04368182151549, 63.10659400878414, 62.97994067592006, 63.00397303796584, 60.40764639454504, 61.21543891968266, 57.65261673158216, 60.964571968201675, 62.735580936554946, 62.97181352492302, 63.08220471105268, 57.478247765571844, 47.34806783737675, 44.97504565023607, 49.26056846495598, 51.82782250065958, 53.32496766121157, 58.363663996419604, 57.54945839605024, 56.1254144483997, 54.5351561423271, 53.91460187973515, 47.8208742603179, 44.335769914811664, 46.6495878465714, 47.32099563844743, 45.0119786877786, 43.279663901175226, 45.39214657198998, 48.7417761741146, 46.598016523545795, 45.56629196290047, 45.807305920508604, 45.622354399773386, 44.792098460658906, 44.21900095478181, 47.27180127174624, 47.79698310359832, 45.715004705613666, 44.875962657313195, 45.853962513708304, 45.58599795064619, 46.49699980212797, 45.29306357906711, 49.9626805705409, 53.367646971056544, 59.47705622642272, 62.895213557827866, 61.9014379285997, 61.99012664056594, 96.11622195090018, 66.355481455403, 60.16206679805633, 60.06179924934142, 56.86939001083375, 54.96245914889921, 59.049776754071644, 58.39024589907739, 59.226832543649984, 57.28415712233513, 54.28462651468093, 49.55981000777214, 41.01425978445238, 43.54069763614286, 41.187926646201845, 42.63277876761652, 42.93874325290803, 43.86168087682417, 41.55136562162831, 42.2691083723499, 44.09818803110431, 43.76804213370047, 42.80234675253592, 44.94747138792469, 42.852596236813454, 42.37176464449975, 41.86076610319076, 38.87050405625374, 39.73922667964813, 41.91553415790681, 42.15860343748524, 41.83939703049199, 45.012829842105994, 43.7182358772524, 40.71539478917276, 41.16654188402238, 43.91278936016945, 41.35976568345101, 46.42241985567155, 54.81185974613313, 55.449794030958614, 54.42060332144461, 51.85201175751225, 58.572106592116825, 52.07989754215364, 55.95943935455815, 57.72080713702787, 56.94372677033948, 57.9237505697435, 56.185826793793716, 56.41703482597106, 59.397765513389345, 58.67858325281451, 57.24698089784192, 58.975079136510054, 56.728549465056396, 57.32287091593589, 48.95514134437808, 4.510120182268081, 1.022907624081258, 1.657532592934947, 2.1166342544940213, 1.3346358484798864, 57.99634187452255, 59.05599371079476, 40.79238307091498, 48.7991722168461, 29.538383291613673, 29.31883646595863, 2.1476479451502524, 0.051340585003697106, 0.07305462709477833, 0.06202023754256868, 0.0534792535097128, 0.023656433125236825, 0.08188696968699656, 0.023835961999852332, 0.008598103548490233, 0.022660666295597633, 0.04331130939986437, 0.06603520859273211, 0.054696739591177435, 0.06658180466582699, 0.05201655417500485, 0.01934022481192745, 0.03045891659454473, 0.045740436311931386, 0.13265298108660406, 0.09870003323040663, 0.1593369879429379, 0.07346573285758495, 0.19713337593261274, 0.1260386392354004, 0.1528426461041935, 0.12012728264615422, 0.0637889736812682, 0.1919609494507313, 0.2999076715880825, 0.23115008528674805, 0.09778370780329551, 0.3339382164901303, 0.2457025229570366, 0.08263171440170658, 0.11947778564306999, 0.16337404147751872, 0.09872774263062785, 0.21263176365004433, 0.13643655144879896, 0.40127694666866337, 21.441575750227898, 62.550590192118, 36.904874924690496, 51.010086767135135, 42.48903174554148, 65.94690384403353, 69.6130334177325, 53.29236884270945, 0.4075243324041367, 5.708581266864654, 4.974598432740858, 1.770277078593931, 0.2197743231250394, 28.11852059056682, 68.83848297980525, 61.77126622969105, 67.1409047034479, 62.67206599635463, 65.74811812370055, 63.59359156700873, 64.41948190812143, 63.396704273839156, 63.694471005470525, 60.8604448072372, 61.76561409427274, 64.58924208917927, 64.77936721617176, 65.15180410877352, 59.600344165678955, 51.51657458274595, 49.542426063168435, 52.312717668471805, 54.541753568956935, 56.925644643845104, 60.859460292323945, 62.44237984380415, 63.01638341719105, 59.26705252739691, 57.37532869462044, 50.75286949834516, 47.12743451518398, 47.04146400574715, 48.336258011479536, 46.11373324548045, 45.69169405967959, 48.72877743936355, 50.75862753775812, 46.99307764730146, 46.01627411380891, 45.64850484171222, 47.719029918793716, 47.47249326398296, 45.75813508802845, 49.1062859565981, 50.500272781618186, 46.54278170677924, 48.569364470820275, 48.630839778530984, 45.234561427947014, 50.10723167850126, 48.89410926449684, 53.604938599371145, 55.61312152493385, 59.29028864829772, 63.38824372137747, 64.65281194256198, 62.662114943227465, 102.13615802026565, 66.08200596224877, 61.85225532900903, 61.40491685559673, 58.3923129881582, 57.016388677781634, 60.436856285218276, 58.811394706849136, 63.17953048213836, 62.27720099110758, 58.574605141916585, 51.80325669627036, 42.96609786248977, 45.33140866987167, 44.95026019311721, 46.004016707020426, 44.82388927090553, 45.406792702213416, 45.72406930308188, 45.53121420644945, 47.250742066291075, 46.661307888646284, 45.93116652581, 48.03048572232647, 45.17917363874374, 44.95998767114455, 44.421952232237786, 42.814780665982155, 42.63084503912157, 42.90552862228886, 44.14453867943057, 43.73378023024529, 47.013144493103034, 46.214761734008796, 43.54511814732706, 43.131998431298044, 46.88070566423478, 42.80246834601126, 47.78172900599819, 58.681497573852546, 57.379227530571725, 59.354015396487334, 53.62206758991365, 60.49420133713753, 53.4195948416187, 57.23877137707126, 59.025583574848795, 57.893818962958555, 60.19480289951448, 58.316293531848544, 59.92939179943454, 62.20087951229465, 61.92952994377383, 59.025873830241544, 61.870439437127885, 59.488458556513635, 59.427520613516535, 51.114739525702696, 5.1805164929359195, 1.2808101431977366, 2.031551426456821, 8.52274360195283, 1.4918688372258218, 65.67678197737663, 61.238769177467596, 43.51834012616066, 50.74831170420493, 38.001734364417295, 44.64112251035629, 5.5049553417390396, 0.31179009365939325, 0.40812304543872036, 0.2227615910552202, 0.15246154800538095, 0.14991786030511703, 0.27660275599168194, 0.2381841513899065, 0.1361629814510384, 0.08081487560224149, 0.13053465604541764, 0.19356884542972813, 0.15350269213799508, 0.16310983307419286, 0.16624521644365403, 0.13391860430279087, 0.1291995639762571, 0.1293344414162059], [0.08786252444429744, 0.04058310176215826, 0.09437878405855549, 0.13384262370246072, 0.026692654073779142, 0.07284505608221216, 0.07108889910722933, 0.023307773104358106, 0.057735002164037964, 0.014416543248620246, 0.0665556580849713, 0.042411102462680116, 0.11228540747035896, 0.08772252187613519, 0.06095167512314455, 0.05143968613758203, 0.01981558428416329, 0.0821610376419079, 0.06405715042004181, 0.08435905880985722, 0.07279885331949881, 0.06668533378791425, 0.6568622949623293, 18.507460471122496, 34.020477648704286, 27.55646259553971, 25.987736140528035, 40.19524928062193, 45.778370595747425, 56.820262324425485, 6.93602817673837, 1.9362173614002045, 2.5267283522313644, 0.3439193309074448, 0.24355173110961917, 3.058347283832489, 47.43323426092825, 59.54703523266701, 61.801817570963216, 61.868619457367934, 61.715709778570364, 60.208178181802076, 62.234117677134854, 58.96763055555282, 58.676684825651115, 59.59195421588037, 59.619065638511415, 61.43651154733474, 63.5474919503735, 61.86853708759431, 57.65380128737419, 48.92415854238695, 46.25417370950022, 54.3168919317184, 57.9832999936996, 55.64909358178416, 60.16922904599098, 59.824142840600786, 59.20899360410629, 59.04732919508412, 56.792201688212735, 49.56430896635979, 44.30798384451097, 46.17172548847814, 46.26470135104272, 46.10799874028852, 42.983234697772616, 43.92936921888783, 45.045436505348455, 43.385493370794485, 44.75309833403557, 43.879190337273386, 42.62001929744598, 42.489878977498705, 42.572691978946814, 43.20014569067186, 45.11189322317801, 44.569445117827385, 42.549479392267045, 44.035010414738814, 44.947024237725046, 44.484121799469, 45.11701976099322, 48.99238424916422, 57.924605646441066, 60.277564910150346, 61.32645768503989, 59.248189849238244, 58.296093325461115, 47.42257718117007, 94.82405985555341, 79.99260548622378, 57.40278528582666, 58.97688342678932, 57.50858729885471, 61.00141086886006, 59.305095595698205, 61.03651608190229, 58.07014519168485, 59.99412267438827, 52.530934810638435, 45.90012096589612, 41.08052430614349, 41.6898762795233, 40.120198649744836, 41.32633140010219, 41.54011234160393, 41.126718059662856, 40.82492305386452, 42.22345590591431, 39.9558081934529, 41.57150307009297, 42.31917742759951, 43.2658532357985, 40.45646736698766, 37.495238704066125, 40.460574088558076, 39.41515261127103, 40.34018870322935, 40.979570342648415, 39.98194686828121, 41.53503287223078, 40.67932075069797, 41.565635204315186, 38.86818985785208, 41.3850296697309, 39.8137281787011, 46.413029701479026, 52.30154675822104, 52.43700581212198, 51.587094876074026, 52.56013293420115, 49.30494223871539, 54.052885040160156, 53.20935580038255, 54.294730540244814, 53.407725749477265, 56.32806370335241, 52.74909703962265, 55.35222899529242, 53.41807688436201, 56.89471675503639, 51.43939802723547, 61.355793091558645, 49.73757574635167, 59.82255820305117, 20.81053306979518, 0.36095170244093866, 0.9791692742897619, 0.9068290624887714, 2.0855220142872106, 10.256992117051157, 60.47641338840608, 38.56657135871149, 37.148481568982525, 31.99361639638101, 33.0112047349253, 19.534034959731564, 0.4046164158611529, 0.09201709586646288, 0.05850486307134552, 0.07970799346484485, 0.06321669834095144, 0.02262870319217684, 0.1390774097413786, 0.0613606549919613, 0.03980700489914706, 0.10792996779444719, 0.046235861542123946, 0.015866195148367797, 0.041632136600392486, 0.06011533310576793, 0.05203162312447544, 0.07049436891271223, 0.037287870316856334, 0.006091760719315179, 0.03099252939254286, 0.06631076275821655, 0.033998365378788406, 0.06209653606938739, 0.036990352410582766, 0.07250135839586297, 0.004701032472263661, 0.04609610029165784, 0.05768328739870941, 0.0481439529046897, 0.0670392434262941, 0.037300809541897434, 0.048195162051988226, 0.032810519239114176, 0.03247632870390531, 0.05361866235973374, 0.010561103305418887, 0.062097283005113565, 0.02666628724264522, 0.03003495396114886, 0.04144910670396301, 0.04402906866744161, 0.6689425822227233, 36.1964556478685, 40.968960331332305, 31.012849307829338, 31.914916000058575, 49.30879400622461, 53.101843633959376, 62.9526331347804, 6.835576276625357, 1.3268683297980217, 3.8594766826398916, 2.1715873960525762, 0.5616280664840053, 3.415587688646009, 53.351882965334006, 63.51719164079236, 62.86963970430436, 64.01934915973295, 64.91041752599901, 62.13166536823396, 64.30685889336371, 60.94851378471621, 63.00743256845782, 61.36122557424731, 61.2371257043654, 60.329748122922844, 64.64346101207119, 65.47989860657724, 62.38883949095204, 51.856620542464725, 48.220022493793124, 53.59603089670981, 58.540782543920706, 57.05250193995815, 60.19381446223105, 62.22347628685736, 62.22747318206295, 61.49685721243582, 58.03836614854875, 50.4449712845587, 47.70695294103315, 49.40148353576661, 50.08765120660105, 48.52987797029557, 44.47715174767279, 45.34078313458351, 44.73645179502426, 45.4114564003483, 46.82604743588356, 44.38450928657286, 48.07984090620472, 45.37673165721279, 46.059753587169034, 46.32880072439871, 49.16804367496122, 46.198613336009366, 44.57172009252733, 45.85222882609214, 48.49105435032999, 46.9363562522396, 48.303047303230535, 51.42807806691816, 56.66937266626666, 61.68251868217223, 61.68549183876284, 63.259233044039824, 59.36410373257053, 62.506424303977724, 82.47468133126536, 68.20702060576409, 60.43562858335434, 59.33033212538689, 57.88029855297458, 61.70776697897143, 60.69344989715084, 63.644409794961255, 58.84767270857289, 59.490364828417384, 53.812016210248395, 46.3491617479632, 43.64190263132895, 42.206020970498365, 40.466210534495694, 42.97698636208811, 44.72204492938134, 43.611131637327134, 41.69598340988159, 42.82043672377064, 42.389023073257945, 43.12849183236399, 45.17520420012936, 45.02638555342152, 41.85046203674809, 39.128525410929036, 40.10858843403478, 41.650491760623076, 42.13725397663732, 41.8159177226405, 42.21076703840687, 42.198442951325454, 43.59059802947506, 44.16972814067718, 41.72789973597373, 42.520689195202245, 42.86729335784913, 47.21330696536649, 54.615988346838186, 57.12463040505686, 53.219459825946444, 57.52905030404368, 51.93903346215525, 55.564750855968846, 54.42421582437331, 55.91792891102453, 56.289447969005955, 58.30988830135715, 54.723920206869806, 56.14324554320305, 56.35644205154912, 59.87859710570305, 54.508240838204664, 62.536928576807824, 51.845532001987586, 62.99169209695632, 22.062404578731908, 0.38800576040821694, 1.3119221382564115, 0.7813372414919638, 2.19381031970824, 11.586331417483668, 70.35414172757056, 44.074587129777484, 46.040463370661584, 42.981536311488, 36.8003829833, 30.904535016705914, 0.5536136836294205, 0.09848470123664987, 0.13771386516671028, 0.05310739826170668, 0.09635324544844129, 0.03605439981085158, 0.08564145935158576, 0.09888325847925679, 0.0799299827626636, 0.027259260363456224, 0.032989937030980666, 0.04126491618432826, 0.07010288266164642, 0.02794475009244296, 0.05171990194808572, 0.02083682353728481, 0.08293331555661657, 0.025338049745187167, 0.19864278364806406, 0.17366773508969816, 0.16649047183173318, 0.2252609069429098, 0.11330939889434846, 0.18208523341003927, 0.11699358467012645, 0.11782030845361373, 0.16453205998386108, 0.11691711377352478, 0.19761909099836505, 0.13349337953953974, 0.2094956754796928, 0.19283044392303114, 0.08684883690288953, 0.16704243818117728, 0.08283938551622053, 0.1305038133455861, 0.10978436788483974, 0.1644998536475243, 0.10832112462770556, 0.2124513346221178, 1.8373801294834384, 50.64385898651616, 49.84449563487884, 41.78817087604154, 37.197919122634396, 53.53645009379233, 56.623959464411584, 72.95173137418686, 8.26964678302888, 6.4622622439938215, 11.972884920335586, 2.178241942198046, 0.6518484640025324, 4.3000360746537485, 55.33570012738628, 64.83067181802565, 65.63150213610741, 66.09017233694753, 68.71710131245275, 62.68831245360836, 66.99606726246496, 63.13703160132132, 63.73873103049494, 63.47415931763188, 62.23390586914555, 64.10492350978237, 69.82269979292347, 68.60951069862612, 63.02328678869433, 55.406914680234856, 53.407631612593136, 57.37455991006667, 61.56815413505801, 60.06915761578468, 63.476163648789935, 63.85010280916768, 67.18441163339924, 63.799531690536014, 62.45446466630506, 52.37178071852654, 49.378267026716664, 51.31649055788594, 51.69482669522686, 50.099673271179206, 48.01636126733596, 47.66156327339911, 48.717159378913145, 46.71226339955484, 47.95569789025092, 46.572897664962284, 50.02733692046135, 49.0452774109379, 48.117597641483435, 49.21834807242117, 51.33445109090498, 47.230381042726584, 45.1934902898727, 49.54623468460576, 52.35977826579925, 48.425829256734545, 50.29103394477598, 54.76458734081638, 62.33278489881947, 66.12995301523517, 62.24852454277777, 64.71207111112534, 61.458594491404874, 73.19984482180688, 85.40351513893374, 67.10979246324109, 63.93716373751241, 60.28083224450389, 62.414750668310354, 63.87866943113266, 64.57610607147217, 63.71492224354898, 63.224363173207934, 63.001705908006244, 55.979419908215924, 49.96069977360387, 45.70352000574912, 43.41418943097515, 44.8476823683708, 46.35428044103807, 46.32162278698337, 45.0060990548903, 45.22353564539264, 44.48767938921529, 43.48975781471499, 46.49284208974531, 47.433410767586004, 47.351699952156316, 43.95131880237211, 41.81265038828696, 43.40035523137739, 44.91252306968936, 45.09435238376741, 43.96639639331449, 43.85496577908916, 44.264920142389116, 46.110936595547585, 47.90516991769114, 43.52703994320285, 45.30308131248721, 44.72220182418824, 47.764372517985684, 57.4730820040549, 58.37024573356875, 55.835559137405895, 57.71974809708134, 53.66246408031833, 58.62629413604737, 56.46460140905073, 58.529552798117365, 56.80829517302975, 62.259432654226984, 53.4717192188386, 60.364029638228885, 57.70384680840277, 62.15954557541878, 56.896940738924094, 63.7364835123862, 53.835883832746944, 63.773200819569254, 24.406348274600123, 0.4660867286785957, 1.7619399582186055, 4.15197003272272, 5.314365413881117, 12.465551284051712, 73.20678741701188, 46.88046639965427, 49.92814802354383, 45.377374925921046, 47.94776293539232, 43.732266195358775, 0.8889698369368431, 0.2736798241253822, 0.3494263692728935, 0.2426881201925778, 0.2058664105472065, 0.13791048929335611, 0.17210486975889053, 0.1820809433176633, 0.15964163046690727, 0.15536833073823683, 0.10433592758471928, 0.10835353780778186, 0.13098192881912957, 0.15522470457419274, 0.19489604679326858, 0.22133554902768907, 0.11764831405373351, 0.10289244173515229], [0.03944103320639941, 0.11236077520034968, 0.07761302644446974, 0.04225469795205901, 0.0901974838287119, 0.04158522903678879, 0.02771550211154165, 0.056318390678854725, 0.08954280807125954, 0.04634499459737732, 0.032359439008418596, 0.040748768275783914, 0.037735775113105774, 0.007086446886176184, 0.11903413646523991, 0.08126074643505198, 0.03076814798518054, 0.03695364530769087, 0.05808685868678074, 0.06841518330357729, 0.0854652131637258, 0.02296297033617814, 0.08046764625056137, 4.155657060684697, 27.950137161439468, 27.36107364777596, 34.78455535827145, 35.525981380093484, 41.344189951496745, 63.553344126670595, 33.99877517454086, 0.6062991436450713, 3.6595299407359096, 1.4657578641368498, 0.21900765297393646, 0.0683551756364684, 17.909942288552564, 57.82350655524962, 62.038913080769206, 63.201809544717115, 60.55175035230575, 62.752768762650035, 60.86454368406727, 59.971918136842795, 59.1107068523284, 61.76703399227512, 57.43580772030739, 59.33400346386818, 62.303786816135535, 60.63624212818762, 59.84897144379155, 54.976332572198686, 55.04527999508766, 57.483986193133944, 60.07165616558444, 60.11348039873185, 61.622718226525095, 61.55909345995996, 60.94851770708638, 59.767201792809274, 58.92921878445534, 52.41824119321762, 43.943101436861106, 44.423215235433275, 44.04450255055582, 45.66266852040445, 43.80571649920556, 42.38395929336548, 43.499610808587846, 43.87455017335954, 43.646766370342625, 42.44892158815938, 43.69661969523276, 42.762236595153816, 42.4118826466222, 41.64884044278053, 44.5924537412582, 46.46194557989798, 47.40564430913618, 44.89021262814922, 44.40092048337383, 45.93629698599539, 44.79365564161732, 46.99513689164193, 55.96768025429019, 58.90853220416654, 61.26505690236246, 58.60994569716915, 61.07252736245433, 30.689181204765077, 41.4604333139235, 93.16870981647124, 61.33929560261389, 61.84074709492346, 59.0539619230455, 61.287994923130164, 60.30300540308799, 60.16940947501891, 56.2644350144171, 58.352375415063676, 53.49780690285468, 46.78352894321565, 40.88715537901848, 43.05576324462891, 41.06880818643878, 39.926547311967425, 41.447309063326934, 39.87940826723653, 40.81012395120437, 41.71985495475031, 40.53287906031455, 40.452231207201564, 42.25902788100704, 41.16363148535452, 40.169797020573775, 39.85813333142189, 38.738630048690304, 41.85359993288594, 40.65896364950365, 40.19252323335217, 40.50079799467518, 42.20263988740983, 38.96694337168048, 40.74472627332134, 39.31412804511286, 42.3835317550167, 37.93893329558834, 46.748074639228086, 51.06366634368897, 52.8562169690286, 51.79297224167855, 56.34739706593176, 53.853216786538404, 52.493107472696614, 53.858884611437404, 54.65448641007947, 52.654481626326046, 54.044651985168464, 54.04321639768539, 58.19477458154002, 53.08904886245728, 57.42886904747256, 54.32037499643142, 59.778325634617964, 51.84323741543678, 46.94586799990746, 1.453602929269114, 0.3375584415851101, 1.286735741361495, 0.9053013605936882, 0.656671998721938, 20.92083796378105, 59.701894329440215, 32.981261361029844, 28.89533619726858, 28.295527350518014, 39.36058851980394, 9.911450916720975, 0.11957194550984329, 0.07399418796863287, 0.03999804424482488, 0.054932499319435134, 0.1352756677736198, 0.08661144923779272, 0.018040255958875342, 0.08457237599237312, 0.022333945117650494, 0.07081458600418222, 0.042536484242807475, 0.10769412762695744, 0.04915677859718281, 0.022651364072977055, 0.009987336966479498, 0.014843069403732737, 0.02513568570476867, 0.05059831858342213, 0.012857879910077299, 0.04069821030322102, 0.07459596535491367, 0.036154994816188855, 0.01418869912384018, 0.040066838940425266, 0.06438361495853433, 0.018656602422256145, 0.03547457467404104, 0.08259218426481371, 0.05534233720672708, 0.027653755424844644, 0.11330026712629104, 0.025130761674635356, 0.1488902452852457, 0.07818656582986155, 0.030719694839189612, 0.048239487899287094, 0.10916988109989513, 0.07250366432051505, 0.017046492449158145, 0.03891017257926926, 0.06306740312626766, 11.753115500173262, 45.63856555569557, 30.738834488776426, 34.57073127069781, 42.27319155969928, 47.693609037706935, 71.37506408076133, 33.66097281056066, 0.4838878541223465, 3.8604920862182497, 4.211849426069568, 0.3678551352312488, 0.2728578117826293, 20.525186523314446, 61.81332972741897, 62.150375073955914, 65.71604098043134, 62.973033382046616, 64.84260366808984, 63.64199361493511, 62.41927316111904, 60.69211629129226, 64.48629163926648, 58.84974764239404, 61.61156300575503, 65.75340155632266, 62.422928810119636, 61.45558995585288, 55.758504175370746, 56.55866376815304, 59.200509517423576, 63.249482031791445, 61.218357163090865, 62.971680164337165, 63.3794419227108, 62.58036490409606, 60.35058375327819, 58.175770698055146, 54.14421350725236, 45.948177845247336, 46.90314946636077, 48.927602383398245, 47.41240255294308, 47.678609894168, 45.207759872559585, 45.73675032584898, 46.34449804982832, 46.32939300229473, 44.08092567997594, 45.730160743959495, 45.54779406516783, 44.916166951579434, 44.3230692801937, 46.82842439220798, 48.92422130030971, 47.50563336956886, 46.58955597108411, 46.98810408192296, 45.59505078100389, 47.89705453380462, 49.16853789360293, 58.465606397198094, 60.13241367955362, 61.95089117173226, 60.24872764464348, 63.97403009476201, 35.33116117600472, 61.03249957484584, 87.30632751218735, 60.24795886008971, 65.55361955396592, 57.51946010897237, 61.72731999428042, 60.89401637354205, 62.642150079050374, 59.39850291898174, 59.34972824588899, 54.39993635300667, 49.047403335571296, 43.82409672583304, 43.85973145884853, 40.9970994149485, 40.93848743746358, 43.095932237563595, 43.858845003189586, 43.308065783592966, 42.94839228353193, 42.5898092023788, 42.77727496239447, 42.98816119470904, 43.408780482507524, 41.67594009830106, 43.29699293259652, 39.25542193074381, 43.81643241451633, 43.117803373644435, 42.77071675946636, 41.7312337506202, 43.841147268972094, 40.92920710963588, 42.650935419144176, 41.961633774542044, 43.27834206242716, 41.810453860990464, 47.98419783192296, 52.544196344191036, 56.95145383957894, 57.09325928841868, 59.21159021316036, 58.57054548878824, 54.88639262414748, 56.683108806610115, 56.808695254787324, 57.19954375297793, 57.1904948449904, 57.036051519455455, 59.79762761823593, 55.41200591671852, 58.612110845504276, 56.221339933333866, 60.881135309896166, 55.894178959631155, 47.1007937769736, 2.084819419730094, 1.6436277906740866, 2.7849026793433778, 2.138251171958062, 1.303429348814872, 25.449828178651874, 65.2888987910363, 38.42011005647721, 40.17061287356962, 29.58550076330862, 46.13027388049711, 15.236744053902166, 0.17281500262118157, 0.05749676414134522, 0.00921638917192937, 0.013121880512053688, 0.05223535271661897, 0.02861901663333899, 0.043966797210516474, 0.04593458980502141, 0.047746583098365415, 0.04022527358404571, 0.020107883216452696, 0.0646477927183432, 0.056400653200163964, 0.025798610313945723, 0.02034050198422084, 0.0413182397342978, 0.055402739409116976, 0.07896729369437502, 0.1415809850779272, 0.23735875293852823, 0.1311851106584072, 0.14834837597464362, 0.21173688102393382, 0.13416128563544444, 0.11465995827870024, 0.13526111210305847, 0.11502656199398542, 0.21122803010286825, 0.12920819012628448, 0.23847521883585762, 0.1913295551052978, 0.13871930960205295, 0.2224229035838958, 0.182943144632924, 0.15083612393467657, 0.08833415881400147, 0.19754753838623726, 0.18221750615104554, 0.19613573027233924, 0.08417848422522507, 0.2872733801843659, 18.219168224642356, 58.62185793538248, 38.29935204598212, 51.27210109464584, 50.124011578098425, 53.269917195843114, 77.79656456362817, 43.70083232079783, 1.7581047382085555, 14.275119112383935, 5.542142352750225, 0.5873893357573018, 0.54885070049955, 24.138338604281028, 62.22971677780152, 65.10752839426841, 66.65114187425183, 65.54724178006573, 68.44572036497055, 64.50467578826412, 64.92854672093546, 62.00738114695396, 66.58643061114897, 60.36718322384743, 66.26154068977603, 69.94172803817257, 66.65198910620906, 65.74607456884077, 60.515354679476836, 60.49343255258376, 61.26972452286751, 65.78926770917832, 64.3859181865569, 64.78982817742133, 65.71609589361375, 65.59192542106875, 64.1607702162958, 62.13553674759404, 55.83960310105355, 47.2167625734883, 48.5413077569777, 48.79885058249197, 48.214672380878085, 48.15022783894693, 47.7501735379619, 48.54541055617794, 48.224996059171616, 47.4734228657138, 46.35950111573743, 47.30536891568092, 48.350366776989354, 46.78603141538559, 46.50624875099429, 47.96446830995622, 50.539139547655665, 50.36985397338868, 48.22133256543068, 48.15254595971877, 48.812967192742136, 49.977644412748276, 52.677215683844786, 59.84413123899891, 61.74478238628757, 63.16057366709556, 61.99881076812745, 64.78554102682298, 45.52444027316186, 67.77129234806185, 82.70299465425553, 61.19291274778305, 67.52258270017563, 59.53183604824928, 65.38215314188312, 63.86584328066919, 65.33140551659369, 61.20583303513066, 62.888549450905096, 56.87446163546655, 50.680964608346265, 44.24540242841167, 46.9619026491719, 44.03062128251599, 44.67417240142823, 46.58659458160401, 45.876316101320334, 45.748952819455056, 46.74254017491495, 44.70107201606997, 46.41024089628651, 45.68335902306342, 43.989208898236676, 42.22241647781865, 46.15843257596416, 41.457879850941325, 46.888652386203894, 45.152423074168546, 44.64175008958386, 42.8774130728937, 47.24812584538614, 42.35592611374394, 45.817912009454545, 44.05317098863664, 45.38228573337678, 44.57385778427125, 50.44576360333351, 54.26719942400533, 58.993118116932536, 57.806989454454, 58.45168982782672, 60.954413029455374, 58.51568721955823, 56.6864114422952, 58.763047572105165, 57.43452118289087, 60.989726128116736, 60.72791184148481, 61.768497036349395, 56.32322349855977, 62.849259068889005, 58.787613376494384, 65.04005970493441, 55.535835143058534, 51.89483227268342, 3.039212000946845, 1.906940300137766, 4.791357555697042, 5.219335209938788, 2.889247041556143, 27.41482580861738, 71.68311134461435, 42.77948717917166, 43.702248296430035, 40.00582625789028, 58.019256361069225, 22.021741367155506, 0.16786402151469262, 0.19025874804825554, 0.10705304993016106, 0.2599881168815398, 0.21757698377534268, 0.16766200412905988, 0.1483153729068656, 0.24530840136351126, 0.09137912082575983, 0.1698141902564995, 0.1131814928545106, 0.25371238589286804, 0.1218883349229732, 0.12818060574993012, 0.12364076104976478, 0.16251571656715486, 0.107065353302225, 0.22975531496828605], [0.014045423445021434, 0.03392528825169129, 0.038127372446920604, 0.10930544035809656, 0.030270501100007566, 0.04879481737471877, 0.0528629242833103, 0.06591362277826955, 0.048102392634797486, 0.03641805025718866, 0.04334032114955687, 0.03841384336532604, 0.019601746161858884, 0.055250854817249125, 0.022616922675121217, 0.05532647535625485, 0.05656652272708955, 0.043120587980675126, 0.022430778631279548, 0.09170066324933883, 0.016416335335722374, 0.03234691347085661, 0.0364739325408253, 0.27740396138641144, 6.936545439304845, 33.39840935122582, 39.82317716844621, 41.53133799952846, 31.89393916437703, 53.78985089640464, 54.121914832822746, 0.8631914072940428, 2.8429439519682242, 1.8130630278779616, 0.7472975648218586, 0.2738697220000529, 1.4537098138563096, 36.21233340232603, 61.35966054854855, 61.26291921061855, 64.73127111311882, 61.82726983101138, 63.51486567528018, 61.98624349409535, 62.05632840433429, 60.99319350334906, 60.37169394954559, 61.51739866502824, 61.86293986535842, 61.040128584830995, 61.91218130050167, 58.600006411152506, 60.512342299184496, 58.58082209863971, 59.754383487086145, 63.38225033975417, 62.42162658322243, 60.28759048831079, 62.383622738622854, 58.36694702025383, 56.28492939856745, 51.58139567221365, 46.89961148846535, 47.12042916205622, 45.76217512930594, 45.066154464598625, 46.35804983877367, 43.37313398238152, 42.726366519927986, 42.68657407452984, 43.55000149819159, 42.95558983279813, 44.720930976252404, 43.49727307596515, 42.527161105986565, 44.5993806469825, 45.02128254982733, 50.550624247520204, 53.42759255440005, 54.9455145097548, 51.03102437911495, 46.96428745023666, 46.20095499100224, 45.72195514555901, 52.339460388306655, 60.22752331149194, 60.31656895914386, 61.208547315289906, 58.1978654092358, 43.88317938773863, 20.644636423357074, 56.58021719224992, 70.30971696299892, 56.22814524558283, 61.14105116936469, 57.763031451932854, 59.22911928546045, 56.75978329873855, 56.97920853091825, 55.19258068453882, 50.782495160256666, 42.56552580864199, 43.69579991986675, 41.09713162145307, 41.908379754712506, 39.34245148012715, 42.464297279234856, 39.744867047955914, 42.06851051699731, 40.16293679514239, 41.84757909467144, 37.862086219172326, 40.04654438264909, 40.95716576422415, 41.80834362583776, 39.3982118944968, 41.03649962332941, 40.315701346243586, 40.781977022847826, 39.58049228114467, 41.458287777439246, 40.656739665615945, 40.482947288020966, 39.601669157705004, 39.43088131566202, 40.800502377171675, 39.67505278125886, 42.727833486372425, 49.57433062215006, 50.4530474447435, 53.79234160146406, 51.786955325834214, 55.200201849783625, 54.40632589401738, 56.02115392684937, 55.42343178103047, 58.81698800671486, 56.505554876019886, 56.723811241888235, 50.65326483018937, 60.0787321213753, 53.90073237880584, 61.9739233293841, 51.442280969312115, 57.02097785088324, 16.389527666953303, 0.044186875118964145, 1.4752627476569147, 0.6099205944807299, 0.5388067362289275, 0.07121326582085702, 39.84913149187642, 52.43098889627765, 25.9071373170422, 23.932869165174424, 31.4796741162577, 42.14874259887203, 2.0967042013522117, 0.17713674975018348, 0.04298548454478864, 0.078717372830837, 0.05568893070543005, 0.02104934398835946, 0.05099642766459335, 0.018177546575785648, 0.006436029619972913, 0.049097165465354926, 0.08210523579750331, 0.04680173238739372, 0.01213232090982098, 0.04993875518501286, 0.030128673327365713, 0.027051183222342404, 0.0718632377984543, 0.04310946055357495, 0.04510112444780046, 0.10183972201400227, 0.04821310383117488, 0.04347056758800342, 0.05801033033358474, 0.0726884983540062, 0.08431592805972023, 0.03699852656873484, 0.03018488311358998, 0.04848704921201833, 0.02439029364576263, 0.01649391514459445, 0.02637506657910924, 0.015116635571053673, 0.06135696244816627, 0.030078781851296945, 0.05032960175266189, 0.04620642078319385, 0.09512483112273679, 0.06843679464392124, 0.06361115701316346, 0.04752450570043537, 0.0256696566488714, 0.10192829709980758, 0.36843077369755317, 26.25502605592051, 41.962704581599084, 46.48840196671025, 49.70360409828925, 37.93360279452416, 60.328571411871145, 57.82700530944332, 0.8886922679601178, 0.8284382269747796, 2.9052598726364876, 1.1004577240636273, 0.22655380288920096, 1.4024472549077005, 44.20673570325298, 62.34651711679275, 63.346768579175404, 67.00510440334197, 63.6457787021514, 63.68078193356914, 62.287811002423695, 62.55322994724397, 63.175674792258974, 62.688481115525775, 63.108461056986165, 62.98231763224449, 62.04436125293855, 61.688731716525176, 60.7645389341539, 61.057206584561264, 60.38673231678625, 61.22986539717644, 64.06233441445136, 63.82357581969231, 62.05579103962068, 64.98962586925876, 60.83293330284857, 57.88958280317245, 52.54874237122075, 49.811433976696385, 49.8354898729632, 48.835520821232954, 46.48636625659081, 48.87152425704464, 44.47155844780707, 44.661471766810266, 44.66087948891425, 47.91825102221581, 44.26000933493338, 45.28284188239805, 45.28330472207839, 45.72301026313536, 46.8346413489311, 46.09480388702885, 50.70716604109734, 54.81739813281644, 54.406439642752375, 51.478429532820186, 49.0316040285172, 46.618322633927875, 49.599578918949256, 54.598769141781716, 59.87048956655688, 60.24915910536244, 60.0154289891643, 61.61290053398379, 40.21573582003194, 24.177417178307813, 66.8812124190792, 65.46901795171922, 59.6338176727295, 62.35034142771075, 60.053087665188706, 61.16259674872122, 60.02526629355646, 59.16738510131837, 59.427481389814815, 51.75565873422931, 45.564487672621205, 45.317080251632206, 42.58433749598842, 43.043694111608694, 41.05727641813217, 43.26530802634455, 42.5438900147715, 44.562326015964636, 43.20860624313355, 44.84390512589486, 39.66428979750603, 41.951255183066095, 43.392286915932935, 43.15774486910912, 41.82020487323884, 43.73159939242948, 41.983795166015625, 43.565134002316384, 41.91286302381947, 42.814408040815785, 42.566663295991965, 42.13423375160464, 42.1712334694401, 40.922770500183105, 41.22109813074912, 42.13974468169674, 46.189984121630275, 52.160200226691465, 51.40875647144934, 57.591918053165564, 55.55069700364144, 57.86966892980761, 56.79802248554846, 57.806138300126605, 56.95567430988435, 58.76112561072073, 59.123011327558956, 59.80450745551818, 53.73946412917107, 61.82343375298285, 56.644293031384876, 62.311470739303104, 55.12016196404734, 61.13026465139082, 18.032573230804935, 0.038439216197378216, 2.8935940082996123, 3.6493744340635117, 1.690372514628595, 0.40315131867124193, 43.06251756606564, 60.07039708475913, 33.253642512905984, 30.33007448719394, 32.82419789221979, 52.614547975601695, 2.3757484795585757, 0.2043971151954705, 0.044973000072904175, 0.11811978754497345, 0.03421583858829352, 0.0129547938629384, 0.06808279307499047, 0.035354563170262886, 0.04253428557046479, 0.05777850829725785, 0.06929025489596591, 0.024258373305201534, 0.04252542959406011, 0.0768077684446208, 0.06625227960607698, 0.020491501744536143, 0.031648896289088076, 0.06031546591510696, 0.0972543946737724, 0.18349874223912918, 0.12026338582678188, 0.1433989883310372, 0.17741297041216206, 0.13089785833031903, 0.1923508422389146, 0.25629391833659143, 0.1320657440491261, 0.16376845418445526, 0.1302750135261205, 0.11079781793899114, 0.12062890169721459, 0.10785003418042775, 0.1446281917273037, 0.07287279612595036, 0.15178025069255985, 0.15906485819047497, 0.10972963856352914, 0.16019594104539964, 0.20896491444399282, 0.08815769812152272, 0.12719347081597776, 0.18997561727319995, 0.5507342962007369, 40.860742138278106, 50.611240556163175, 52.74408425054243, 56.28201899989959, 43.77604769122216, 66.8181485514487, 68.6376105585406, 1.5761285803971754, 7.877372993576912, 8.662921267171061, 2.965487131187993, 0.3860430125026934, 2.1721907056147054, 46.339563708151545, 63.47093120698006, 64.11955787289527, 68.86613568952008, 65.57963663531889, 69.55896746727728, 66.2041485694147, 65.21325588226318, 66.37889016059138, 64.87211558126634, 64.56310341435095, 65.71998296245452, 65.43005312642744, 65.51665905983218, 62.75884451404695, 63.13938502342471, 64.89649703425746, 63.5240008754115, 66.18916511535645, 66.5389620873236, 65.8547124555034, 66.16433651216569, 62.8929974186805, 60.9822500905683, 55.14922672702421, 52.576701025809015, 51.914616707832586, 50.48886260678692, 49.380334115797474, 49.627302231327185, 46.34354883624662, 46.935144239856356, 45.72499106007238, 50.245405012561434, 45.66183305555775, 48.61304006268902, 48.44914382503879, 48.48861855845298, 49.744165328241166, 48.745310229639855, 52.85430285238451, 57.60226526568013, 57.80140792169879, 55.67748761946156, 52.772631260656546, 51.49471521377564, 51.670602137042636, 56.18455202348771, 63.825309507308475, 63.201127052307136, 63.57223426142047, 62.03072317184941, 46.36373335315336, 34.532041011318086, 71.44692190231817, 62.52813070051132, 64.16159391403198, 64.00962952644595, 61.76306455366073, 63.690301525977354, 62.95049544303649, 59.98453247931696, 64.38671442770189, 55.2713732565603, 47.79514743435768, 47.78332933302849, 46.086617900479226, 44.61161844192013, 41.90332774193057, 47.12668534248106, 43.94403888333229, 45.88729481543265, 44.964086547974624, 47.11151361465455, 40.26591862401655, 45.95184526135845, 46.78752191605107, 45.34595674084079, 42.76770045680385, 45.31927285655853, 45.36602358664236, 45.93372783353252, 45.261657161097375, 46.38162328350929, 44.41650013769827, 43.62554242534023, 43.69555281054589, 43.29780878559236, 44.854279795000636, 43.23093237415437, 48.13257717317151, 52.16078073747697, 53.12637021464687, 59.12039118428385, 57.79172358974334, 58.07387144334855, 58.46263716297766, 59.68822094701952, 58.55604056389102, 62.176619652778875, 59.13914403607769, 63.50292990284582, 57.42847288808515, 64.93518337126702, 57.42231084454445, 64.41448480852189, 57.76805208575342, 63.96334163604244, 19.125684845832087, 0.32220217849939103, 5.612961236507663, 4.635274189133798, 5.497956362462813, 1.1226245087961997, 51.63696781281502, 63.92813836374591, 37.97940823339647, 37.397395180117705, 43.19888268747638, 62.96884036833241, 4.562819186718234, 0.5509448784493631, 0.1736160394765677, 0.30354735531633903, 0.19420103650660286, 0.0979993692148597, 0.13674606629196676, 0.12838253120501197, 0.18061414541256043, 0.3242311470450894, 0.2676743995999136, 0.10930398479104043, 0.20051629763216744, 0.17334279123573534, 0.154257120204068, 0.0935830025663299, 0.09150816833660488, 0.20974011881457222, 0.17820492146476624], [0.049849096084794695, 0.004817559712401201, 0.031275210090942925, 0.05317038984128064, 0.011012712136782225, 0.039113572753605344, 0.03171638671999737, 0.12310794689842772, 0.029681959797838525, 0.042357740608314355, 0.06158235700680845, 0.03123267305894725, 0.021145752323190534, 0.038702547430030765, 0.0925208906072282, 0.026207641893697363, 0.06007418269291521, 0.07844345043263129, 0.06748435583205954, 0.024894662952471166, 0.05741008129271288, 0.03728803502576005, 0.05759094316031664, 0.08563146956505314, 2.6145659098702096, 26.573371502660937, 33.64891544465096, 41.87295290731615, 33.911427913173554, 36.90728718234647, 74.2590416631391, 7.401675783818768, 2.5552824716414175, 1.8738802354181967, 0.6914224824117077, 0.19691134833039778, 0.1990946069840462, 4.2239901423454285, 47.194687474158506, 67.29085691513555, 62.6764629733178, 62.38822367883498, 61.847262151779674, 60.599666026330766, 60.438127133154104, 61.53211932028494, 61.75342729014736, 65.7581711584522, 63.426655492474964, 59.92491637506793, 62.07844664973598, 63.09934546870571, 59.88985823046777, 62.243939292046335, 63.05748985659692, 62.76648529114262, 63.552736159293886, 61.87130628093597, 60.668142764799065, 58.57898250702889, 55.93800360156644, 54.730960861329116, 46.62667336002473, 44.821551538282826, 46.61554951821604, 44.71990723763743, 46.21619732149186, 45.87283695897749, 44.02469065881545, 41.312434442581676, 44.689481412210775, 43.68642153278474, 44.20917541750016, 42.526819859781575, 43.51698690845121, 45.494720474366225, 52.68175386613416, 58.5266855455214, 61.000124331443544, 59.53930816342754, 59.46685414160452, 57.63447969190536, 53.08441654328377, 48.07335330593971, 46.61280385909542, 54.290431622535955, 60.024371993157175, 59.51045128606982, 59.02785462717856, 60.151092006314194, 43.42319911526096, 32.55553514726701, 61.64552288670694, 60.12613788727791, 57.987987226055516, 61.781848784415956, 58.509956636736476, 60.62509475215789, 55.911166744847456, 50.45611081584808, 43.59551668167115, 42.92423440564064, 42.47701752570368, 41.32331901980985, 42.932267419753536, 41.266993784135394, 42.670939507022986, 40.986862028798754, 41.52061031710717, 41.28927284671415, 41.63663010443411, 41.275301364160356, 40.425684605875325, 40.37834552026565, 42.37846797512424, 42.101140714460804, 41.77567812704271, 39.70863219230406, 41.48172393921883, 40.900005063702984, 39.3345243700089, 42.28525677034932, 43.59191986822313, 40.207436084747314, 39.6803754375827, 41.07351503064556, 39.56295144173407, 40.217183174625525, 42.741275448952955, 46.427903329172445, 47.0368669879052, 50.239592059966064, 51.281024486787864, 52.70753168290662, 53.274659341381444, 56.093764843479285, 57.97763609117078, 56.05385472697597, 59.669444561004646, 57.85733699798585, 54.827364875424294, 58.3312181503542, 60.50739226802703, 54.67765585068734, 45.677428399362874, 1.471083339664244, 0.15275712004832684, 2.4883634044278056, 1.6607486913281104, 1.1212781552345523, 1.4591855651909307, 55.04201266073412, 37.29496640543784, 24.373463123075425, 28.84076818343132, 38.300928838791386, 19.937003581754624, 0.08689263414952063, 0.02046994019990727, 0.027178175702330568, 0.011682379277302854, 0.02739819998462354, 0.00548115800014667, 0.02600108735233305, 0.08690671484556892, 0.03320851340709675, 0.028903675753803506, 0.03755914588128367, 0.047148869808522925, 0.040528973819868225, 0.1160331172568183, 0.07363621040337509, 0.037502470696645404, 0.040750392382183385, 0.018895717615622188, 0.05096396468880196, 0.034471072271586425, 0.04211169998011282, 0.05708408023741457, 0.06803882728901602, 0.058611261192709214, 0.0381998367036783, 0.033997813795482924, 0.033930708323755575, 0.022363544839824882, 0.05793190591277615, 0.015775023024499176, 0.07412686673623901, 0.009068265114159835, 0.020197504012274648, 0.028568711469791112, 0.015958518319342647, 0.07432711445876668, 0.06629385519772768, 0.01775607372814369, 0.05743146280667955, 0.038739449885343356, 0.049783798580568646, 0.15952169174148192, 0.20717036880312428, 9.173816846263025, 43.45656279594668, 38.09132914389334, 48.27708513505998, 39.12556009907877, 43.91036925777313, 77.9155614299159, 8.102565090502463, 1.860529590518244, 4.061014190796883, 2.52757411329977, 1.0825892441695737, 1.1236298613009916, 5.135852463783757, 53.82198295285625, 67.04783470399919, 63.037646585895175, 64.96241638737341, 62.82505804492582, 61.94023409197408, 61.18975131742416, 62.21767902374268, 64.41381408322242, 66.89727060256466, 65.80495718986758, 60.88599120416949, 63.77132200425672, 65.11518486084478, 62.0489308141893, 64.68561864668324, 62.964251195230794, 65.3167554640001, 64.54430349411504, 61.811945130748136, 63.984604804746574, 60.30085986660373, 58.28106672533097, 55.344964765733295, 48.22404292321975, 46.71829992725004, 47.94699807320872, 47.81532410652407, 48.18467409380021, 47.767439811460434, 46.55728270930629, 44.22046792122626, 47.131290205063365, 46.86080748035062, 45.35451535255679, 45.98482847213746, 44.6286964416504, 48.07458885254399, 51.90987063992409, 59.94128442579701, 63.53566208193379, 62.075767670908284, 59.67123316180322, 58.966665652490434, 53.56964511256064, 49.927457686393495, 49.58447779378584, 58.500833203715665, 60.509914352047836, 62.675596129509714, 59.09409169227847, 59.350555865995354, 38.66753708931708, 38.49263860333351, 67.73456327376827, 59.291061355221665, 59.570322344380045, 61.96974600515058, 60.04958498862482, 61.36252387877434, 59.81363088853898, 55.17235694393035, 47.647576101364635, 44.61627429531467, 44.84234794493645, 44.85668420791627, 44.53632854646252, 44.581157315161924, 43.93920260090982, 42.18689549353815, 42.967266728801114, 43.12926061691777, 42.74795524535641, 43.881167211840236, 42.7362391256517, 42.7265900950278, 44.54666791423675, 43.57174711842691, 44.100043312195815, 43.20247557855422, 43.1532145315601, 40.982441517614554, 41.26642896283058, 42.54516870744767, 43.67847088844546, 42.564600129281324, 42.32349595715923, 42.55190733940371, 41.94600705177554, 43.71134819522981, 45.60240914744716, 48.65104390728859, 50.978676426795225, 53.71170159309141, 54.293141980325025, 55.168003113039084, 56.25731591255435, 57.40875905559909, 58.44710457709528, 57.78325519254131, 59.71161788509738, 60.49842965218329, 56.979577233714444, 59.66365906500048, 61.148770393863806, 56.92684488911783, 48.13921774587324, 1.9248368494933652, 0.1856995596280021, 6.918679533466217, 8.796088676298819, 3.2096973301902896, 1.768642798546822, 62.38416794807681, 41.96588562380883, 32.16565351332388, 32.04095940436087, 42.084451029377604, 30.409837845833074, 0.10150444363394093, 0.06983716506510973, 0.07008373812441865, 0.025315354390430356, 0.02995978158357884, 0.0348085378326716, 0.0163271397186984, 0.046238435597549525, 0.05027443193079484, 0.027127068061682007, 0.04094417432263013, 0.035729417652492566, 0.03839039724440344, 0.10348347856873467, 0.05549035305457731, 0.06334051347127365, 0.010611135550143739, 0.04922418667364025, 0.06365946651766859, 0.14535576075075135, 0.1443580538034439, 0.12920806755221662, 0.1382058468316832, 0.1523595970244177, 0.20097657857883364, 0.18713047397473168, 0.24328692515771239, 0.1797400697344734, 0.13083935985642095, 0.15247541419681043, 0.2352308671200468, 0.13963240979900285, 0.1233703549951315, 0.17377613653098384, 0.11487064777963585, 0.1904945192678321, 0.2660080664340527, 0.18288930397360556, 0.13654303767027395, 0.22211499752536898, 0.17028004832325444, 0.21852319429237999, 0.45592095642801256, 13.58564684467931, 55.54178537860994, 44.10735461019701, 63.26794855056271, 46.72403835481214, 48.69937927492204, 88.25798865287535, 10.35851776599884, 8.177447059462148, 4.569147440694994, 2.3005970927976795, 1.3322879422095515, 0.5758833080049485, 6.250829821632755, 53.148535528490626, 70.46879260770737, 62.89470757207563, 64.49498361156833, 64.43142552529612, 62.62839824922624, 63.8060075236905, 66.0556084109891, 67.61747267938429, 69.35537292111304, 67.81163000291394, 62.77800136996854, 67.73351992330244, 68.64485909861904, 62.15448179552632, 67.26538504323652, 67.50403773400092, 67.05285533781975, 68.3130422715218, 64.98406787072459, 64.90138430749217, 63.411220965846894, 62.441920926493985, 58.766056030027336, 50.61548848305979, 47.9163839740138, 49.94619092633648, 48.02796363830567, 49.86744150038689, 49.829971098130756, 48.3976548717868, 45.4850322200406, 48.64148116880848, 46.68964701314127, 47.417434953874164, 47.938996438057195, 45.7591196029417, 51.515692049457186, 55.97427768092002, 62.807627031880045, 65.72177940799345, 62.719969903269124, 61.18190657707953, 61.002171808673495, 57.446245147335915, 53.26294714404691, 50.891388000980506, 59.70831917178247, 63.862925037260986, 64.29833558297926, 60.80002853947302, 64.02827647424513, 45.977152393710234, 47.92529952141547, 68.0727892537271, 58.818549110043435, 63.47083707009593, 65.31732813004525, 61.67983185860419, 63.66800285154774, 61.1046358846849, 56.64137871034684, 51.45250266598117, 46.228211541329664, 45.72084119243007, 45.01146485728603, 48.07140781033424, 46.365965181781405, 47.652177041576756, 45.758668530371885, 46.545354781612275, 45.65503166567895, 46.360866100557395, 46.14879139008061, 44.33763304064351, 44.05024882285826, 48.18720794493153, 44.714208033777055, 46.90682864958241, 45.019101712011526, 46.36567100401848, 43.962999620745265, 44.722068463602376, 46.48556217070549, 47.802521490281634, 43.376954370929354, 44.917610383802845, 44.95735183838875, 43.57933298234017, 45.072198837034165, 48.17470735119235, 49.45334119181479, 52.36391636633104, 56.17018045917634, 57.10592854407526, 57.40176939195203, 59.05841381319108, 60.314293984443914, 60.676415043492476, 59.55866506022792, 63.696467491888235, 61.71358777630714, 62.360268946616884, 61.80420237202799, 64.74710572150447, 59.91862097094136, 50.91655000563591, 2.1755009408920043, 0.37327373640671857, 3.302063754489345, 8.575076845384414, 7.480719387531281, 1.790768398392585, 68.959119396825, 45.567833454378196, 39.21687679906046, 40.896008168497396, 53.976869506220666, 40.47822867670367, 0.253342442034233, 0.17213076353073123, 0.16676243304485278, 0.08882249390045482, 0.2326021896254632, 0.09904311038553716, 0.10881139791660732, 0.20555884156736637, 0.10525573871188587, 0.12074432050388668, 0.17412983932562415, 0.14020884499674843, 0.14656237987501008, 0.2590463190309463, 0.34572080198314886, 0.16214989426155246, 0.1512853119281992, 0.17973044767014443, 0.13947914624887128], [0.060820934557986844, 0.035801989161559654, 0.03474153195237441, 0.029143708337458874, 0.010309016328274963, 0.025595972397094293, 0.08912282334941049, 0.04187222472542236, 0.07532455327530062, 0.023658262160156044, 0.02550393459387124, 0.007201562609313237, 0.06707543341983711, 0.030055209325866836, 0.018820863164540742, 0.11957600577584199, 0.01920243240742674, 0.0729107634434777, 0.06325284619965861, 0.045969653649315725, 0.027123235706840793, 0.01876851637667466, 0.07709691300988197, 0.04447439174738623, 0.32612880812056605, 19.350407238929503, 42.73103021806286, 39.02309994543753, 41.16400803289106, 28.22393821131799, 65.04626881691718, 36.10392301313339, 0.16942507887799896, 3.85728505830611, 1.3304235906370225, 0.41257168737150013, 0.1626802875750488, 0.10232984208531919, 5.328353076211868, 56.47611748787665, 67.01489463929208, 65.0387574780372, 62.67397619062855, 61.571048844245176, 58.609977076130534, 63.648791082443736, 61.39300853975358, 61.718043588822894, 65.7906287716281, 62.44001465459024, 61.45858272429436, 63.813495328349454, 64.17447890004804, 63.48786407901395, 66.21041651695006, 64.17534182148596, 61.409494261587824, 61.07046419574369, 59.093974021173295, 58.32706436034172, 57.41391697237569, 54.27087076248662, 46.707764440967196, 46.392366655411266, 44.287740492051654, 47.53403917435677, 45.212968780148415, 44.957744075405984, 47.292782029797955, 43.706005927055116, 45.30512878971715, 45.19771860491845, 43.99563766294911, 43.85561297016759, 45.25052547454835, 46.43610892757293, 55.83802630824428, 59.47384380525159, 60.01236169568954, 61.771136791475364, 59.0834463796308, 57.859929684669744, 60.516660828744214, 54.08409926199145, 46.10014223283338, 49.87376436110466, 56.337296962738044, 56.06995213416315, 59.43710688621768, 56.910884764886674, 59.85033642861151, 41.093832908138154, 40.09882957704606, 61.906148695176654, 59.00134724955405, 61.23670993312713, 58.27328866527927, 55.65840921094341, 49.046979719592684, 47.58704608486545, 42.878303450922814, 42.46377168163177, 43.58077249219341, 43.44649407171434, 41.423739540961485, 43.49659058355516, 41.82275441385085, 42.57958358333957, 44.142730466781124, 41.752238042892955, 42.656034500368186, 41.5486317296182, 40.7711983496143, 42.05042446813276, 40.442213473781464, 43.98017175735966, 40.56405798081429, 41.1796308332874, 40.286428697647594, 41.215077292534616, 40.39506266194005, 40.64542362766881, 39.2840003198193, 43.52636921790339, 40.74987634535759, 39.33233568745275, 39.83313998868389, 38.54920702595865, 40.413780212402344, 42.32499430256505, 43.571656903912945, 48.466869015847486, 46.20113542003017, 53.76002911598452, 50.81902811604162, 53.26165668426022, 55.04677049575314, 57.186203772021884, 52.92227752747075, 59.20346306216333, 59.075625173507206, 57.73470801691855, 55.385223973181944, 55.50996318940194, 25.989644373616866, 0.02917103660893777, 0.4913025127062875, 6.7659934297684705, 2.581063965635915, 3.0469741263697228, 7.114655365867, 53.55597565251013, 26.648779069223714, 32.242116197463005, 21.561631656462147, 38.23950452189292, 7.239843693471725, 0.25335646144324736, 0.05873745502603631, 0.09909780140245154, 0.038602412077448064, 0.06417598214841659, 0.03611300553705904, 0.08950405168317019, 0.10923948784869526, 0.03449121272311576, 0.056666321000985564, 0.008443368151934158, 0.048306210327052304, 0.03541727129730486, 0.029750551480138977, 0.053217917936103004, 0.01636360933433377, 0.009262587146593199, 0.02169849050621833, 0.017593772255725438, 0.07002153178496708, 0.04947816780317695, 0.038334407708457405, 0.03164919889381817, 0.034888505920647614, 0.02041048028566424, 0.055594104342162616, 0.02474278219104294, 0.05703010934314901, 0.08416357615421857, 0.030436751755675485, 0.0030947778366446016, 0.019883825481238387, 0.042960199812847766, 0.034486436164907874, 0.05653394866854914, 0.05266276466089392, 0.06047254841354105, 0.02431991123293917, 0.07926185450126087, 0.06629309677068265, 0.08881880135665979, 0.07683596814111357, 0.07363978803398148, 0.7199862851731239, 31.45501809735452, 47.67340098657916, 42.655646185721125, 50.305931106690444, 35.85910827882829, 73.9768663529427, 35.12491902997417, 0.17394263808044697, 1.3909066612682035, 2.9103974421178145, 2.3019191766938856, 1.0339818846794868, 0.4385738759752243, 7.027946470245239, 59.918346405029304, 65.20938450290312, 66.58007637146981, 63.64341351293749, 62.22644944344798, 61.671653716794914, 65.12714416750016, 62.38852570133825, 64.02489146878644, 66.25157786953834, 64.04031815067415, 64.48826851383333, 66.00197392125284, 65.24330123778313, 64.32245815953901, 64.70317125320435, 64.88713041428598, 63.92534563618322, 64.88305507167694, 61.94423098717967, 60.3489951933584, 57.31615974057106, 56.02642166999079, 48.21540978647048, 47.30651424777123, 45.91901110064599, 47.76882048576109, 47.97469000662527, 46.89194717714864, 49.09382458656065, 44.99005263851535, 47.205317097325484, 47.054666703747166, 46.54009096084103, 46.41251194861628, 46.103625297546394, 48.11705243202948, 58.1742331289476, 60.7154740056684, 61.306159419398156, 63.067829224371145, 63.55982780456544, 60.711520256534705, 62.23504727886569, 54.091183062522646, 47.043346743429865, 52.942375752233694, 56.862482716960294, 57.500048298989576, 62.679906814329094, 60.386677403603834, 61.31073290301908, 39.49295674600909, 44.60760193486368, 63.67900902225126, 60.06203459155176, 62.50090945151545, 59.266193528329175, 57.36302814176006, 51.836745892801595, 50.6310446031632, 46.25008659978067, 46.01323819929554, 44.85056923281762, 44.61534469358383, 43.867729171629875, 45.731902276316, 44.048989742032944, 43.28393536229288, 45.54793527049404, 43.91782176110053, 43.76358239881454, 44.165786158654, 42.479767107194476, 45.085997735300374, 41.67546549151021, 44.34245755595546, 42.85666765705232, 42.09883043842931, 41.96693289664484, 43.99198201394851, 43.43709999515165, 42.59709304378879, 43.49445289181125, 44.04718152938351, 41.247507449119325, 42.078171314731726, 41.35687097426384, 41.05992794036865, 42.947721558232466, 44.34768999776533, 46.25351867368145, 51.90102569518551, 48.88852380937146, 54.55237534738357, 54.32259898031912, 55.676087333310036, 56.8485269238872, 60.10771059220838, 54.427757724638916, 61.14933521516862, 59.71374380973078, 59.5022496100395, 56.99778879842451, 59.19080949598744, 27.336568640124415, 0.06475142909273987, 1.3695093965338123, 8.3299728362791, 6.525619308794699, 1.4803539841405808, 8.345772143333189, 61.165711110638036, 32.29830611136652, 38.05257612659086, 22.22555164367922, 48.5907413882594, 11.417522411192618, 0.14329429475530503, 0.1013222449429093, 0.13228803212123533, 0.014162375385151997, 0.0725188328614158, 0.005699040587886327, 0.06449505010800016, 0.06803425374410807, 0.018015656875626698, 0.023874293209143707, 0.0935991440388945, 0.03446070710197091, 0.047635795293195594, 0.051180648827745076, 0.09689986450417389, 0.04407313787528584, 0.027343068467152697, 0.04068608696181928, 0.07211199420834742, 0.20308445418073287, 0.16631378131287713, 0.11986926423325656, 0.12386298017396082, 0.08707876287160382, 0.15474488838545739, 0.22507067198955247, 0.20748398987756622, 0.14359080142551853, 0.13013163251021218, 0.14351266045724193, 0.07549547515208684, 0.10784038913346107, 0.11343889839706883, 0.15098233947590475, 0.23369976379457982, 0.12754509751234325, 0.25180304963742534, 0.14735946371670694, 0.18773369160631012, 0.14815532181772495, 0.1073754963374907, 0.1548261090271896, 0.26261628875809334, 0.8867691421220381, 47.855544090271, 58.195955214961884, 49.04948611413279, 57.48795170937815, 38.676064322071696, 75.14987468719482, 44.76894470953172, 0.627289217325949, 13.44912482846168, 5.7661675445495115, 2.571297509054984, 0.5867415318085302, 0.2548037700715565, 7.332051261778801, 61.28254675096082, 69.47350686596286, 68.87715754970428, 65.47755695158436, 65.72707853009625, 63.85088728320215, 66.73007565159952, 65.22707047001009, 67.56365776062012, 69.62655775008663, 67.50315912308233, 66.58181005908598, 66.89194402387066, 67.7905668750886, 66.46879088494086, 68.21888969790551, 68.3044679703251, 65.95099879849342, 66.95212102705433, 63.93519863005608, 64.06257760140204, 60.93287921720936, 60.059210485027684, 51.0558843612671, 50.14722024240802, 47.831417591341086, 49.36802179582658, 48.768683633496686, 49.19572384126725, 52.92221476954799, 47.2839488521699, 50.497585958050145, 49.436510301405384, 49.67871273717573, 49.73690502105221, 49.54013539898781, 51.49058495798419, 58.97366708324802, 62.420936246072095, 63.25664035735592, 65.66310075021559, 64.86334908393123, 62.82535222268874, 63.06506003102949, 57.65188324835993, 50.28438552733391, 55.20874477201893, 58.62211288944368, 59.33236783550632, 64.19195698153588, 60.83541224079748, 61.360731355605594, 45.75738983769571, 51.017613795495805, 64.48450696083808, 63.88010109624555, 63.59803169004379, 63.12554690145678, 59.27796848358647, 54.2925653919097, 52.44611747803227, 47.74427429322274, 48.126105262387185, 49.02725804236628, 47.325102360017844, 45.88511005524666, 48.159119852127574, 46.39045253876717, 45.88093273101315, 50.512722384545114, 45.2636654146256, 47.9852843284607, 47.38015674775647, 45.67932682652628, 48.577436708634906, 45.868973424357755, 46.6479875195411, 45.234004451382546, 44.35903741467384, 44.960862359692975, 47.400619752945445, 45.45463385120515, 44.70213890075684, 44.62528790197065, 46.80938128502139, 43.32362190369637, 43.410506325383345, 45.126680558727635, 42.446913334631155, 46.17276883894398, 45.86268586497153, 48.07718546159806, 54.80524663002261, 50.898593394987046, 57.99815793191233, 57.4882851108428, 57.87881589704945, 59.92126072606733, 62.370820122380415, 57.09543228149415, 61.0901427268982, 63.11581550105926, 62.23565132387223, 59.6825138984188, 61.718737848343395, 30.87342473768419, 0.19972430061428778, 1.8120495854846894, 11.887456678575086, 10.299839108220993, 5.0081518580836635, 9.185240749389894, 67.21661429251394, 37.069963562873106, 49.865574452184866, 31.102751993363906, 60.4528909344827, 16.696880671285815, 0.39519117484169625, 0.18823442199537832, 0.29739744660835116, 0.1637902570467803, 0.27606903785659426, 0.09065487662390356, 0.2805718268838621, 0.2486378041606757, 0.1237248085559376, 0.13318824671929883, 0.154762860808161, 0.12454781681299211, 0.11853478503443542, 0.13186351215887454, 0.2888388042488406, 0.11423707008361818, 0.11273875532131042, 0.1320957900175164, 0.12096405750320804], [0.035871975123882294, 0.016904440595798435, 0.02151185999654474, 0.02144191425383812, 0.06391503727964817, 0.055275074686975255, 0.030601876262094707, 0.030678908318100922, 0.03790606113691484, 0.020856636486226515, 0.11570381436256633, 0.03965387924484188, 0.02357292188061101, 0.06242903738072323, 0.048105445495175744, 0.09096161056790622, 0.030529270279071027, 0.03543930015556755, 0.0880116741022756, 0.13147104531526566, 0.033376543301968806, 0.06436045612058332, 0.13170533032426912, 0.09571933833461616, 0.14407861557218338, 6.843736277472589, 40.48600673675537, 40.8536583377469, 44.010707409151145, 35.60487985610962, 40.19062872855894, 69.165326241524, 1.4285266038871582, 0.5295234666235986, 3.1744768975242494, 1.8160762661887755, 2.716601712088431, 1.2989194811351839, 0.05496045386779213, 4.806158619542276, 58.79516393907609, 63.51866252960698, 66.5893017861151, 59.545007367287916, 61.744825532359464, 61.19784316708965, 64.6576560697248, 61.66568779176282, 62.1086645895435, 61.10956630399151, 64.07759243442167, 64.13720461630052, 64.19445945370582, 64.89275509311308, 63.114360301725334, 61.129735131417554, 62.07584611831173, 57.41410524614396, 60.4232652725712, 58.30477745302262, 57.85153581250099, 51.978441515276515, 46.2500826774105, 45.116909934628396, 44.87829254519555, 44.01368056574176, 45.921062500246116, 45.320457412350564, 47.24578811276344, 44.42666692118491, 44.50532613262054, 45.13719251078945, 43.09381415767055, 43.64438549164803, 43.905882066295995, 48.18363858807472, 60.315329490169404, 59.92762281048683, 62.60880208784535, 54.71805234109202, 61.48423894759148, 71.3194997849003, 55.25894326548423, 59.87317639012491, 53.60779800722676, 50.084132840556485, 48.76236077277891, 54.58327970197124, 58.63328379969443, 59.884272775342396, 60.12252538434921, 58.69953263190485, 51.5193594655683, 57.85332441329957, 57.386589819385165, 55.47995705758372, 54.26519901521745, 48.02604559929141, 46.596824123013405, 42.62165492580783, 42.707131216602946, 46.940533576473115, 48.899526057704804, 47.03948320881013, 44.49755199493901, 42.16118435705862, 43.06490628950058, 41.2662838351342, 43.1916537592488, 42.716925374923214, 42.68913930462253, 42.18860564693328, 42.42295941998882, 42.856977524295935, 41.988411795708444, 42.54758488747382, 42.6789568316552, 41.07922207924628, 40.46523778669296, 41.24729564113002, 40.11500543163669, 42.30503336075814, 43.09710110387495, 39.90639809639224, 40.910517015764796, 41.56103034173289, 41.654135642513154, 39.68930667446506, 40.22159976343955, 44.15705496265043, 44.12720180326893, 45.70579498044906, 48.18159111084477, 49.33294796174573, 49.640885399233916, 53.41688056145945, 53.31303581114739, 56.28371738618421, 57.13134550279187, 56.551164196383574, 57.6719932402334, 61.901567366815385, 52.82568131723712, 54.39047951852122, 10.0510343428581, 0.29240543383263773, 1.224308523439592, 16.10674733115781, 21.79669733970396, 2.7547675996057452, 19.220794477770408, 45.7168835209262, 24.24414453967925, 36.813044394216234, 29.455391822322724, 31.469983900746993, 0.8066661920278304, 0.06761847484496332, 0.0704216288643018, 0.03547440230425808, 0.01205515861886764, 0.03029730843169795, 0.07187285986278327, 0.02694297904869722, 0.06198895051174107, 0.09204046154815344, 0.04344308418371985, 0.03007939472163637, 0.03460643234692755, 0.05521791686694469, 0.016575710352269873, 0.03653886615328732, 0.02812572112757593, 0.07488869521166049, 0.009286186485100658, 0.03701494000251255, 0.04560210764588368, 0.026147808511591247, 0.07325935643166304, 0.04069809155959276, 0.042758454388428124, 0.03425326581383425, 0.03039072519318471, 0.03819837347574292, 0.02293718764708648, 0.09021492765074776, 0.129856591623637, 0.035296486044723185, 0.058698840364212954, 0.05120725506135533, 0.03248096736628683, 0.0586557517489118, 0.053915027303681265, 0.05376027754297661, 0.04592444297046431, 0.09695611067957456, 0.039199386092443625, 0.0738587819280163, 0.06601318356490905, 0.02174631929055097, 0.23380099465289425, 15.35028882565037, 52.47810832915768, 44.48496118668587, 53.62916315755537, 40.35620374064292, 48.95184263106316, 71.93048738664197, 1.5478546653063068, 0.08100456663317258, 1.9768722379399886, 1.843537760357703, 4.304217321257438, 2.7069213025031553, 0.1661338885464976, 6.909155038095291, 63.56701750909129, 64.5875358581543, 67.99360444468837, 60.83067009525915, 62.72646534827448, 62.18415060350972, 67.60594875581803, 63.52216912854103, 64.30059094582835, 62.19991068686209, 64.88719709457891, 66.30201954995432, 65.06633174034857, 68.1250979823451, 64.83271145051526, 62.55028424724456, 62.286936313875266, 60.583623532325994, 62.347411417192035, 59.250790380662494, 60.745966511387984, 54.64849302845617, 48.128741095142985, 45.649418753962365, 46.246642758769376, 46.272475488724254, 47.01737673051896, 47.79834808841829, 49.04831332545127, 48.6632267890438, 46.223928313101496, 47.51610609792894, 45.73853108190721, 47.623739857827466, 46.124378558128114, 50.575382248047866, 61.31271762232627, 61.39865675280171, 64.03075148982387, 58.084151975570194, 59.10382309267598, 70.15228871376284, 60.15796792122626, 60.09648869114538, 55.32538037146292, 51.268688632595925, 50.8030915260315, 57.44149123468707, 59.744538337953635, 61.23785526521745, 61.826151955512266, 55.84119950571368, 49.76667973303026, 59.32621363670596, 60.52905551848873, 57.35785845787295, 56.16489310418406, 49.38349554615636, 49.01916619270079, 45.83007920172907, 46.06719824575609, 47.70926713943482, 50.344978301755845, 48.01561601700322, 46.58628079199022, 44.714902293297556, 44.61607425443588, 43.06440422611852, 43.834847942475356, 44.818162610453946, 43.750454225847804, 42.65790154857021, 44.53579118174892, 42.68267916094872, 43.41917868583433, 45.48701301697762, 44.423944796285326, 43.00330154357418, 42.98276401335194, 43.14743688029628, 42.739526071856105, 44.279397610695135, 45.486734528695386, 42.46027292743806, 42.69079846720542, 42.4792532767019, 42.99526460709111, 42.531099165639574, 41.38764981300601, 46.26039458859352, 48.30016043878371, 47.00932018218502, 49.60473683572585, 49.6227797385185, 52.1041456345589, 54.943012037584865, 55.995976232713275, 57.83795656696443, 60.68324781233265, 57.374791329906834, 59.38399407171435, 64.28083788964057, 57.20074792062083, 56.060409007533906, 11.236473648778855, 0.6764009078183483, 2.2378001914870356, 6.111316017566189, 2.8458788654496594, 2.1342589345670517, 18.868040038693337, 52.6169837674787, 28.60714397122783, 46.040247640302105, 30.078419139308316, 46.89100973067745, 2.064896966180494, 0.06786190694378269, 0.04021742884370108, 0.06590570909001174, 0.06348395960465555, 0.07907033252019076, 0.053025518784359585, 0.09584906000283458, 0.053680707820721214, 0.025325667849110983, 0.05123225251032461, 0.05159296500947207, 0.025212323225493875, 0.0650658545595023, 0.10660865764704444, 0.051009673324804154, 0.04929241829461629, 0.09796825072337544, 0.02959033759731439, 0.07037612324159953, 0.13425188319336984, 0.10725872155519263, 0.14912641487054287, 0.1918327522974822, 0.15022182867171305, 0.29078782385876106, 0.22186899137112404, 0.1303593444848253, 0.08330570323573006, 0.16714645759953609, 0.2768629807378015, 0.0918121750075971, 0.23321677600183796, 0.2291851923350365, 0.2211065040600877, 0.21613169761915363, 0.13474887507336755, 0.14275867672216508, 0.21127083909607705, 0.29707415750430477, 0.1714500024794571, 0.15076048041303314, 0.27411790384400275, 0.20865644148040205, 0.38628528014786784, 17.041527571216708, 65.98253465467884, 49.416839614991225, 60.731147796876975, 45.68356690868255, 52.9417795519675, 81.74544995830905, 2.3164304754426404, 3.819538864397234, 8.525452979149359, 6.641737155375942, 6.86259356237227, 2.5278665750257434, 0.19063543348062426, 7.000859562427768, 64.08980669513826, 64.8272515112354, 70.58029774696597, 59.69655206126552, 63.34372874229186, 62.144758239869155, 68.15653970164638, 63.832424686801055, 66.75841085372433, 62.48270180917556, 66.89199109231272, 66.65237349848594, 68.28515421959662, 70.21377578858407, 69.67120216738793, 66.51255669132357, 68.07960633308657, 62.4432937560543, 66.30048982558712, 61.82152355870893, 62.681052146419404, 56.674318775053955, 51.06691798856182, 47.55179966649702, 47.933575722479056, 47.86745632848432, 50.926916830001346, 51.71740778030888, 53.109959017845895, 49.235924213163315, 50.14118763708299, 49.624842905229144, 46.492814633154104, 49.04487340681015, 47.97024203884987, 53.59500323572467, 63.559349275404415, 65.64739165767547, 66.72419209634104, 59.89660470716415, 59.46616380445419, 70.2513599395752, 62.05463001804968, 62.98029761160574, 58.67498251699633, 54.29177699550506, 52.56982511089694, 61.860276576011415, 62.146735114436, 64.6712980731841, 64.4900728041126, 60.023940532438225, 56.12744623614896, 59.90542611768169, 61.366348189692346, 60.144820136408654, 58.13735892695766, 52.82741108248311, 51.38424165787236, 48.306495066612, 48.051686133107836, 52.15325763148647, 56.35514374702208, 53.42410164494669, 48.71304873497256, 47.838211136479536, 45.96616583485758, 45.24900751729166, 47.26219538719424, 47.75559033116987, 45.65281552653159, 45.60485278406451, 47.03924002185945, 45.51730548181842, 43.687629622797814, 47.25345634645032, 47.248102311165106, 45.11963990426833, 44.40671774648851, 45.01346918844408, 44.136862601003344, 48.11489905080488, 47.3047060351218, 44.82854512430007, 44.44776142797163, 46.5390044643033, 46.05580376040551, 44.183962422032515, 44.749395616592906, 50.52276365218624, 49.313975457222234, 50.891713557704804, 53.004396269398356, 54.39653565806728, 54.623907612216094, 59.82404870371665, 58.5801709851911, 59.57466048579062, 63.690980096017164, 61.02903219961352, 59.248150625536525, 66.90490353492, 57.65805313664099, 60.96832959882675, 12.09813992823324, 0.421296080514308, 3.8951199958401346, 29.271907268031953, 37.45517169275592, 3.9780516489859554, 24.50449185986673, 60.30591580175585, 35.56673872855402, 53.26190379358108, 39.31592841302195, 60.75775323375579, 4.6777892497278035, 0.1679902421610971, 0.13965433523539575, 0.10321101939846432, 0.1887702085678616, 0.12745892028174094, 0.13052984501325315, 0.18892730255761456, 0.1747580467452926, 0.1660062276547955, 0.11220484566424163, 0.1550245717648537, 0.10811414299232346, 0.13551782816648483, 0.1484890603610585, 0.15626073123947268, 0.1394612504349601, 0.21632344942660103, 0.07412633813557125, 0.1909505254438808], [0.07851902500636156, 0.07071349304169416, 0.03452957074548449, 0.03490014662665706, 0.05298779278452839, 0.029620833642360185, 0.0375823277018724, 0.08230671692158907, 0.07202361830540242, 0.040374404089825774, 0.04985472683103816, 0.04494704501402955, 0.08666066272604851, 0.03810471539656001, 0.03990481134443995, 0.05638769482292476, 0.02205858247414712, 0.05298006678781202, 0.10227728845371355, 0.08035028924144084, 0.054234168041617646, 0.07024663139975841, 0.018905197953685157, 0.13203379818268363, 0.007932598659423211, 0.1449024665259546, 16.836468019793113, 49.7373600159922, 42.62435351648639, 44.3905105129365, 31.668971623143843, 59.69901923210391, 15.625798067738934, 1.06716342030033, 1.2190747333149756, 3.433245463717369, 2.2634130235641234, 3.015249996416031, 0.1508850922747966, 0.3427716086228048, 14.358528314098237, 76.86393476301625, 62.24013459297919, 67.92160541780534, 61.54717337700629, 66.19333067247945, 63.09349721477878, 66.69521362550798, 64.36598862371137, 65.80809116363525, 64.62650852818643, 65.65106691852694, 66.56203346867716, 64.62210370648292, 60.29774158231674, 56.979385037576, 59.94131188238821, 56.473399285347234, 58.675386521124075, 58.08953346744661, 57.3730105738486, 50.72085511299872, 44.820304224568034, 46.72108088770221, 45.95705416894729, 46.91137075424195, 45.81568410319667, 47.202708721160896, 47.65721728724819, 47.99959705721948, 48.4215852522081, 44.29736206608434, 43.797961973374896, 43.28344898839151, 43.449781017918745, 47.2058387725584, 57.50015420298423, 59.55054575397123, 62.96439632292717, 57.15010619932606, 64.54644118585895, 52.80628127436484, 57.76411402610041, 60.671029629245886, 58.058531053604625, 55.81817911517236, 51.210759147520996, 52.539830746189246, 53.562949626676506, 59.4939890984566, 61.94572933258549, 58.277819002828295, 64.08557053535216, 58.063292810993815, 55.55676098792784, 51.89860167041902, 47.75193860453945, 43.235580382808564, 43.28609266588765, 48.23833996249784, 53.76768166019071, 59.11263273608301, 58.354356212000695, 57.22696112048242, 51.05181294102823, 45.470017387020974, 43.588287753443566, 41.34635117746169, 42.243138359438994, 43.14163569481143, 43.751470119722434, 43.052323325987786, 44.43627280573691, 44.17807494440387, 42.36812468497984, 40.8900853895372, 42.65460283525529, 44.42172473476779, 47.44642519181775, 45.42455711672383, 44.166672614312944, 40.9506546297381, 43.442293213259795, 41.37500409157046, 41.04733320974535, 39.298320893318426, 42.22119662069505, 40.492878729297274, 43.41489937997634, 46.7190412552126, 49.330539626459924, 51.35819711992818, 49.7897824933452, 50.683176825123454, 54.45657930066509, 51.96484265788909, 53.56849585810016, 54.48908398228308, 56.95392885515767, 56.31156229203748, 61.16803707615022, 60.76105194707071, 56.56670070463612, 40.82371496385144, 1.2357186982708595, 0.3851900808513165, 1.2628606418448112, 3.1197865547672397, 0.4206345482699333, 0.2819231446952589, 29.778293102018296, 33.0010889422509, 31.903629379887736, 50.78453871511644, 33.17827417004493, 31.64984810736872, 0.3058080194938568, 0.06660522397367225, 0.09197843906980369, 0.08200689309066342, 0.03793544443925062, 0.038974094955671224, 0.08958026977075685, 0.03707615425810218, 0.06798874046052657, 0.022725686092951128, 0.07215281137295308, 0.04973865684963042, 0.049395227294054725, 0.016259143669759075, 0.0373200077052799, 0.03520833613771585, 0.04970093851067847, 0.04805125243541214, 0.025468112322531884, 0.05211779652463813, 0.014963513747188113, 0.04522062650310897, 0.055042498054042946, 0.08639777199395242, 0.05796366791811682, 0.017633359849212632, 0.03377802700044648, 0.1198513224540699, 0.04344261687008604, 0.04089855378673923, 0.030637328896010597, 0.00810816542305533, 0.05666955772246565, 0.03203948430206267, 0.07958542705783922, 0.042798176047302065, 0.04902731739885865, 0.06440710321429276, 0.03296640280994677, 0.10053201758813474, 0.01790889677771878, 0.03526336423331692, 0.010776041721504544, 0.06378717720508575, 0.09288151117582476, 0.6879577425218398, 35.526263790745894, 55.98199690541914, 46.06721393523678, 55.97258321700558, 36.26306926050494, 73.94919010900682, 14.733466698277383, 1.0492359822796238, 1.5128939670901147, 3.5231957079902774, 7.429599627371758, 5.335462862445462, 1.6323844391492106, 0.8397880953646476, 17.59578985552634, 78.551848319269, 61.158544940333215, 66.3775408652521, 62.152442163036724, 68.83022246822235, 63.47790518114644, 68.0165816891578, 66.22809071694651, 67.37481917104414, 67.01057218736219, 66.70777305479973, 67.7073420247724, 65.993987975582, 63.608786829056285, 62.4740529829456, 61.29019929516701, 60.081132611920765, 62.21534913586032, 62.478732370561175, 57.906029301304976, 52.75795375147174, 47.67183596088041, 48.07460454202468, 49.78939025632797, 49.84511536936606, 48.66417208025533, 48.41821201385991, 48.806836528162805, 49.45088578808693, 49.46845016171856, 45.99119055655695, 46.44606390307027, 46.46655828722062, 46.20341039473011, 49.4136977964832, 59.81854954073506, 62.34783111080047, 64.45209249373406, 57.184968225417606, 60.80445297302739, 58.25501042027628, 60.106718232554776, 62.905364651833814, 59.46876825824861, 56.47466621091289, 51.12667137576688, 54.51623462861585, 55.76782764927034, 61.495135291930175, 64.02068276559153, 61.53725762521068, 65.98496652418568, 59.50505802708288, 58.31279085528467, 53.83643296457107, 51.01421310055641, 46.20994506343719, 45.61275635996173, 47.935250574542636, 54.358088585638235, 58.57748808399324, 59.76799803395426, 58.779431312314934, 51.56591015477335, 46.25750380177652, 45.53846274652789, 43.21143427202779, 43.853534113976266, 44.77599713110155, 46.295578249039195, 45.065672013067434, 45.61259554278466, 44.833903081955455, 43.097642390958725, 42.52226206564134, 43.64228310123567, 45.199099279219105, 48.416113545817716, 47.70169304263207, 46.817390764913256, 43.09464962251725, 44.04603227492302, 42.32521003292453, 42.57573573820053, 42.078798893959295, 43.1665192111846, 41.093934889762636, 46.86494558088241, 49.021696121461936, 50.2678095909857, 50.60157583605859, 52.632559499432965, 52.04522378983037, 57.491862312439956, 54.02929590594385, 55.40209800966325, 56.43262624740601, 59.94967437559559, 57.15342060212166, 63.46542027688796, 61.26407630981938, 58.13229906943537, 43.17958854859875, 2.338343777002827, 1.0179892783203432, 2.199169748252438, 1.9612327674704215, 1.0459145927621474, 0.43618132210066246, 35.1177607044097, 39.63347957980248, 39.428182724983465, 55.7600260549976, 37.49256756997878, 41.77186166086505, 1.0030733012864668, 0.0343647392676963, 0.03514291988986154, 0.09111459832638504, 0.0623358772586911, 0.03781793804298486, 0.07079734136500666, 0.0721891086188055, 0.006088742332893514, 0.024883705979934143, 0.004625574726941846, 0.012825932128414994, 0.054300377190473585, 0.02342108133879881, 0.04598772183300988, 0.007236378911447021, 0.04046315537585367, 0.053654453987556125, 0.0436017524841572, 0.07416731617864102, 0.14487341647186588, 0.1659209467470646, 0.1654530049211556, 0.2569026824447417, 0.11855491782508551, 0.09093838278204204, 0.1498388000313313, 0.18343432956645567, 0.12859938005285879, 0.13683192942652012, 0.10224155811292511, 0.1356977975416568, 0.2984887235347302, 0.1129002926210242, 0.10740215619725567, 0.22334485975725038, 0.16612674860704332, 0.17397291387521452, 0.32358539621195487, 0.16782827585214571, 0.06108480205218639, 0.11033143127156843, 0.18526691913364396, 0.14619861068504472, 0.28241408448065486, 0.5502606700024297, 43.232921015831735, 63.06677018442462, 51.70141627711635, 58.97915447911909, 42.19378709793091, 75.36307904028124, 18.950005808184226, 2.2271977797631295, 7.858924615767695, 6.787906731328657, 7.9617019910966205, 5.34141456888568, 2.682539604363903, 0.5463320485526516, 18.83563929988492, 79.19178301288237, 60.90510491401919, 67.6066626271894, 65.0563963767021, 68.7221533252347, 65.22517204284668, 68.32185975966915, 66.5084146684216, 67.82517002474877, 69.4536361386699, 66.70968717144382, 70.85665225982666, 69.58636914530109, 63.92376492100378, 64.11312910818285, 62.81384398860317, 63.56146735529747, 63.8378728589704, 63.73203946698097, 62.5536221842612, 54.852213090465916, 50.39299203503517, 49.842436390538374, 51.82669285804995, 52.04494530154813, 50.727279955340975, 50.79490946185205, 51.559963841592115, 53.70282919176164, 53.56063935064501, 48.795622471840154, 48.207219877550685, 48.73222912511518, 48.885225096056544, 52.72233078556677, 61.51257022734612, 63.49373194479174, 65.42640139979702, 61.31370998197987, 60.534005549646196, 57.805730373628684, 60.931788798301454, 64.70583062018117, 61.81035264845818, 59.61732802852508, 53.480266063444084, 56.85071952881352, 58.74398485306771, 65.03427420893024, 65.59965249030822, 60.92523844011369, 68.84815554465018, 61.15855278507356, 58.242909908294685, 58.150255680084236, 53.93521785736085, 48.19188341017693, 47.771071926240005, 53.1682611280872, 58.907775186723285, 64.23288691428401, 61.22197751075991, 62.68920675400765, 53.94346267946305, 50.06082611699259, 47.597197178871404, 45.52579349087131, 44.7089873590777, 48.38710761839344, 48.829225417106386, 48.34900179216939, 47.854740004385675, 48.239167582604196, 46.76785515200707, 44.22635147648473, 45.07863936885711, 48.09721308369791, 50.701623732043856, 52.09541051618515, 48.62960815429688, 45.28314390490132, 47.292833020610196, 45.69733442798738, 44.7254652361716, 43.17424628042406, 45.83396234819966, 44.001952678926536, 47.94913184258246, 52.49377819799608, 53.27357284484371, 55.92919788052959, 53.961838983720355, 56.704128788363555, 61.21440341395717, 55.790310675098056, 60.09456672976094, 61.14411846283944, 61.655517085906006, 60.16297286556613, 65.33446888769826, 60.968353133047785, 61.38492845719861, 46.37684975900958, 1.8415401707733832, 0.6708747785418265, 4.859678379950985, 12.742225470081454, 4.2876801183146815, 0.8621667493735591, 37.442749546420195, 45.97301429317844, 44.77314164561611, 58.6032659007657, 44.84753724067442, 55.74100255966187, 0.8890041576758508, 0.2664359418615218, 0.19842670088814152, 0.23892668977139458, 0.15230194124723637, 0.19888119021010017, 0.14828382540614377, 0.14996232404824228, 0.09568991289744455, 0.16024463359386693, 0.1249243566886552, 0.10516024585212431, 0.1843689874775948, 0.12063148341351941, 0.10625064943826969, 0.158872141112243, 0.20172910674685435, 0.18253895664407363, 0.1995535242942072, 0.18506195997038197], [0.026197705733319445, 0.02341971387185397, 0.028146474449444684, 0.04361896264937617, 0.014536468567506922, 0.027441558645918008, 0.018624200733498703, 0.02918939590604315, 0.03587222410245769, 0.024560662024023554, 0.045410099198981646, 0.017018175924256924, 0.045232159956809015, 0.018974708941494747, 0.06365600763069046, 0.03105504216716415, 0.08922592346226016, 0.06395642517975743, 0.02071768345852052, 0.01828624296092218, 0.0501692250761534, 0.053758343170967796, 0.12956428311524854, 0.019298509409230565, 0.07717331495857047, 0.12011631992795777, 0.9152893085152873, 37.09265055194978, 33.80865396991853, 36.98755456555274, 38.52906957749398, 37.51465443641909, 50.711931720856704, 0.29677394296853776, 1.021489380828796, 1.2399870950368144, 4.352452668451495, 3.99446897449032, 1.3626640025646457, 0.2981121453546709, 0.6131719329184102, 50.05501316439722, 72.39124036604359, 60.6294995738614, 66.66443086439564, 66.6856195080665, 68.61559037239321, 68.7583803361462, 69.32269957757765, 61.989546129780436, 63.71889952690371, 60.700408181836536, 58.59411893352386, 57.5120742859379, 57.7551474878865, 57.663085537572066, 58.81980034612841, 57.459436078225416, 58.450356221968136, 54.28056293918241, 54.00775032658731, 48.10046080620059, 46.70190834229993, 45.22567333713655, 47.94096939025387, 46.452841758728034, 45.5162738984631, 47.11821302290886, 47.17309482635991, 47.47058699207921, 43.555128036006806, 45.81895143755021, 43.25713380690544, 45.85197387203094, 45.21949168174498, 48.71681028796781, 51.52584706583331, 62.29857006380635, 58.03924868183752, 64.86543186249273, 50.91117635849984, 48.161559566374756, 61.125918665239894, 60.02761971565985, 59.54041819418631, 58.70061128370224, 57.47235636557303, 53.62689602759577, 58.010485941363925, 59.3688537228492, 59.62566698751142, 60.58754982486848, 61.921265509820756, 57.02162504196168, 54.690191745758064, 47.68807457339379, 46.196189311242875, 48.28834625982469, 53.32871744709631, 57.57926840935984, 59.314897598758826, 58.755112617246574, 59.979280425656235, 58.64206990888042, 54.86771429738691, 44.52172163994082, 43.60829968606272, 41.63409625330279, 42.09345679129324, 42.672229966809674, 42.679945268938624, 41.28670761662145, 43.262605513295824, 41.70047844609907, 43.667680448101414, 41.47370269221645, 47.14750528335572, 50.880177867028024, 50.85339200112128, 50.26965702733686, 47.80181154128044, 44.27187058233446, 43.89237342342254, 44.07135117438532, 41.94294760304113, 41.8324387458063, 41.30280110143846, 40.00630086468112, 44.739577924051595, 49.15624126311272, 52.0379791721221, 49.84037322382773, 54.33502897139519, 52.628295883055664, 54.47251981304538, 52.780585827366004, 53.194788117562574, 51.77747103475755, 58.49616558321061, 55.689462615597634, 61.56136451228973, 54.36629810640889, 51.36983086985927, 11.335476233113198, 0.18734565275090356, 0.7572608753558129, 0.25571723799071006, 2.552186740982917, 0.9180667143194907, 0.47661859902643394, 31.986952289458248, 28.327104391590243, 38.640496269349136, 43.41873153563469, 42.77600803682881, 16.08002520376636, 0.18570263930145772, 0.09880328656084116, 0.02945160673510644, 0.09141055341329306, 0.09076398286607959, 0.03613919808319019, 0.054612581002255606, 0.05088493888897281, 0.03958639072915239, 0.03787282824275955, 0.031150931477426525, 0.05754022430928965, 0.04670535852651923, 0.05754742936621751, 0.011263608804813797, 0.0388376968311927, 0.08362445709926468, 0.03626471775914392, 0.05924503424114758, 0.03015040915699736, 0.0171872113095296, 0.05972746662014435, 0.09954113648423266, 0.040305712816095164, 0.022549939777461753, 0.05143459165288557, 0.09808284981596856, 0.04888029746530999, 0.015124678536648712, 0.029707301986373724, 0.030350270005123272, 0.019812673150051027, 0.07470010734734035, 0.02345468003993794, 0.03365681656906682, 0.051076840083565445, 0.014313726588302563, 0.058133980755003235, 0.0102777561105247, 0.018757203173252846, 0.05183330211307734, 0.02506738513587944, 0.07734216073708189, 0.020626999715703632, 0.09580159319504615, 0.14192238450050354, 5.198539783877711, 50.88887376170005, 33.78297029003021, 48.67230707599271, 43.46004193828952, 42.92482276116648, 51.118681507725874, 0.2668504873591085, 1.759468252139707, 3.260657008617155, 9.166472208115364, 6.866606147058549, 3.0636476316759667, 2.0649621755846086, 0.806243985651001, 56.8441770153661, 68.93695016061106, 63.47599106450235, 65.82272944911834, 66.20760809990668, 70.49288380530574, 69.87899364963656, 69.97358552871212, 66.98903053037583, 65.11095262342884, 63.538545024010446, 62.04610670766523, 61.274537271068944, 60.28065181547596, 59.05493859321841, 60.41815442423667, 60.284942888444476, 59.23077844804334, 57.49610239459623, 56.12199414160944, 51.34901485135479, 48.27583782134518, 47.73986554914906, 50.07760209421958, 47.44331082990093, 47.20095542169387, 48.98099368618381, 49.06597183596704, 49.39317595574164, 46.28243438659176, 47.59544387940438, 46.411621570587165, 45.82950653568391, 46.38269409056633, 49.96026831288492, 53.380535879442775, 62.744661223503854, 61.438002048000214, 63.9219057175421, 55.07589409428259, 47.616487395378854, 61.30743418970416, 61.985215833110196, 62.44375267336446, 61.52384704159152, 59.824178141932336, 55.63187829909786, 59.504665790065644, 60.89624427979993, 59.95859776773761, 61.032927113194624, 63.30766647092758, 59.71970973476287, 56.79297831750686, 50.454514411187944, 46.772361955335064, 48.2636353277391, 53.98001524709887, 59.372144591423776, 60.67934897638137, 63.73661295060189, 60.538018134332475, 60.59557891661122, 56.8737752206864, 45.853731093868134, 45.558317784340154, 43.16018850572648, 44.36077894703035, 44.02712645069246, 45.80918081345097, 43.98037179823845, 43.973550796508796, 43.35622464456866, 46.09168560274186, 43.977834024736964, 48.87715678061209, 51.98528212885703, 53.05081359801754, 51.43656607597105, 49.64306231467955, 46.58698681862124, 45.087299962197584, 45.529974737475, 43.76026407364876, 43.50648672349992, 43.21287378188103, 42.26682555290961, 47.24702758173789, 51.410384255070845, 55.093627129831624, 53.05077437431582, 56.96115386101508, 53.2307719415234, 55.84325482768398, 55.02481698989869, 57.563641686593336, 54.657459566670084, 59.800663532749304, 58.01447499182917, 62.087974086884536, 55.564374308432306, 55.968915800894464, 13.16255352189464, 0.4374571955732761, 2.5520345039906043, 3.241883074083636, 2.641221602116862, 0.7688822453060459, 0.24842967339340719, 38.92513482801376, 32.98617609085576, 49.59049470963017, 43.03302134236982, 50.08208536332654, 23.6354358350077, 0.21212806083982993, 0.1281591093227748, 0.022506586861826723, 0.02745068658353581, 0.07536734694675093, 0.18938291036794264, 0.04566172843859081, 0.0752190476463687, 0.02968732624374811, 0.024375148087499604, 0.0519016448168024, 0.01821983654442574, 0.07413694845332254, 0.050219043773869355, 0.038612413355299545, 0.02550303827099983, 0.032063217705956874, 0.08041503899280103, 0.04005096559863418, 0.050309756244983406, 0.09797802600528925, 0.14611624091142608, 0.18375991693427488, 0.10536488325845812, 0.053495544369422623, 0.10084740832568177, 0.27657137703030343, 0.14100090330166204, 0.1735708249672767, 0.0927233063585816, 0.0900311125141959, 0.11540954466909172, 0.15603611426007363, 0.1291933739858289, 0.1580813545132837, 0.1771296098107292, 0.15681456684345202, 0.28639783361746424, 0.08870627836234148, 0.10099004623630356, 0.13783360470927533, 0.1621682650499767, 0.16634042585088363, 0.08198082311860017, 0.14146279303296921, 0.2198367899343852, 6.690296588405487, 64.32269350174936, 43.775341664591146, 52.37215726606308, 50.96239466820994, 49.5384644692944, 62.36972185873217, 0.4770874141925766, 5.436945855617524, 4.946619676005456, 13.104207284988897, 10.399658526143721, 5.582606994336651, 1.8781455678324548, 1.3475497619759653, 58.21129168233564, 70.93707653783983, 62.38921603848858, 67.49186269698605, 69.05485660799089, 72.09433263347995, 74.22971017899053, 73.08309939599806, 67.24596146614321, 68.15822632082048, 66.91230896980532, 62.82186131323538, 63.09058289374075, 62.67457239089474, 64.14980326929401, 63.59332092346684, 64.40723626844346, 62.582953668409786, 60.76013411245039, 58.979217237041844, 54.2947187731343, 52.25391349484844, 50.053216718858295, 51.55027950963667, 51.50569000551778, 50.13743392882809, 52.088479688090665, 51.67674849110266, 54.33456613171486, 46.60672810769851, 51.348159774657226, 48.066626441094186, 48.97515327699723, 49.25015457214848, 53.50496522841915, 55.85666148893295, 66.42710393474948, 64.78785522522466, 66.92252282173403, 60.19130414532077, 52.699482979313025, 60.02714118649883, 64.86156832787299, 62.82275953600484, 65.33535926572739, 62.07662274760585, 59.715477497346946, 63.080294516778764, 62.87788452640657, 62.341441569789765, 65.22597612873201, 65.08639466377997, 60.11874029713293, 59.13523735538606, 50.94907822147493, 50.315470310949514, 52.10414171218873, 58.37556446752241, 63.08417374087919, 64.28045741973385, 64.77259328288417, 62.96880506700086, 63.49029202615062, 59.22245517853768, 50.224490934802645, 47.26762002514255, 46.44422823382963, 48.03242729556177, 45.45601060313564, 47.353935703154534, 44.7238217630694, 46.35864603903986, 45.901383969091604, 47.94338949265019, 46.14956017463438, 53.05778364981375, 55.891362697847434, 55.47663873241794, 55.784321215844926, 51.426767995280606, 49.026175468198716, 47.69410325634865, 49.11937490586312, 46.36349801094302, 45.385007858276374, 46.03069666893252, 43.367219048161665, 49.52852910564792, 54.03824675467707, 58.01693039555704, 55.65653431800104, 60.89167079617901, 55.26674093738679, 60.88294744491578, 57.45950275851835, 59.81880449479627, 57.80040771730485, 63.52066293839486, 60.01965730421005, 62.68818301539268, 58.14283063334804, 56.86607560803814, 13.551137831903274, 0.5920538919106607, 3.3280509277697536, 6.293569928215397, 10.253137407764312, 2.2661694692027186, 0.8466445822869578, 43.839115481222834, 40.45175267804054, 51.526764900453635, 48.13484430313111, 60.55308395816434, 28.46109844023182, 0.3798030424983271, 0.20843338732036854, 0.16992413919539223, 0.16746167213686053, 0.18826550984334564, 0.37699395129757546, 0.15307379015270742, 0.25393185476141594, 0.23667953938486117, 0.14407509156773168, 0.18720303782291953, 0.14926317688678542, 0.15292011291509675, 0.18402587201806808, 0.06592866874510242, 0.15181527623245794, 0.23439861984262544, 0.12501627191781037, 0.09416358229974586, 0.15767045559421664], [0.05221499393003122, 0.02236007063108827, 0.038478459051299485, 0.03804670338849387, 0.06326384339181167, 0.008824716186932018, 0.010620395637928479, 0.011315133005771185, 0.06560296646409458, 0.03029099012154245, 0.011460366039236468, 0.061494402452221805, 0.0990043156930516, 0.02609856054937888, 0.03471716269550305, 0.06261634204777018, 0.036760985686053196, 0.08681985579671399, 0.07317799023322522, 0.029116257491912094, 0.05292585457585031, 0.04172351939844028, 0.11034649256015978, 0.043254630384786476, 0.04373959468437299, 0.031247376201434002, 0.059559314151204405, 22.360475294051632, 50.73520706545923, 24.47875522798108, 50.19323748926963, 28.43047453511146, 63.09598399746803, 3.9227239210759444, 1.7215079213342361, 2.003397143656208, 9.761982137157071, 6.5281100138541195, 2.2902189916180027, 2.1549761583728175, 0.5383103112539938, 13.456197842474907, 72.88759277712914, 65.66804685900289, 70.11274337768555, 66.72454510965656, 65.05758485486432, 63.62388010947936, 59.23000574111939, 57.76307067563457, 58.048834954538655, 55.39658315720097, 56.43192414314517, 54.86308197821341, 55.42428685772804, 55.041334090694306, 57.508697125219534, 55.80081870478969, 57.43327386917607, 53.9412739969069, 51.55549626196585, 45.401768146022675, 47.198166616501354, 47.778363612390336, 48.62918453831827, 46.49514059866629, 47.01846714942686, 45.369538030316754, 46.91364572894189, 47.41745064335485, 47.62081376967892, 45.028503633314564, 45.76195547657628, 44.62748442926715, 45.22843468573786, 47.376018647224676, 49.349006145231186, 58.001076175320534, 59.77883554274037, 61.199776895584606, 52.89902179471908, 56.62605008771343, 57.75160950999106, 62.02022298689812, 60.988427823589696, 60.42646200426164, 60.19374385956795, 59.16693010637837, 59.336223525385705, 60.90505784557712, 61.180400386933364, 61.054566829435295, 60.05024786918395, 55.412711943349535, 52.18873939206524, 50.53862963953326, 54.572261764157204, 57.46493916357718, 57.43710210246425, 58.50772088573825, 61.51621803160637, 61.44441120086178, 60.01775103230631, 59.1329937596475, 52.22195010031424, 43.15129257017567, 43.75438836313064, 43.08995846779116, 42.56243105857603, 42.868140589806345, 43.96862037720219, 42.51132257523076, 42.483144267912834, 42.358020659415956, 41.955008891321, 42.99282097047375, 49.842381477355964, 56.590509491582075, 55.03720775727303, 56.30205054436961, 52.618011428463845, 47.6280426979065, 45.44195675080823, 45.30164964737431, 44.49056625366212, 43.1749915307568, 40.86183647955618, 41.22066667003017, 44.64809648452267, 51.42818004854264, 52.743821451740885, 57.06502214554818, 54.487911193601555, 57.23123258160007, 55.26052398066367, 56.58469261661653, 52.41926493183259, 54.83802195518248, 54.60552738558862, 61.44694112962293, 54.27658565582768, 58.426716096939586, 26.547493665449082, 0.629626275791276, 0.4726975158818307, 1.6285077891042157, 1.69829937959871, 0.2807931956504622, 0.7421234069812683, 4.046910328249778, 26.220995572305497, 35.969738729538456, 31.087146843633345, 40.21805394080378, 37.48875894854146, 1.0918525342018375, 0.11320022370425925, 0.02492450207712189, 0.048261715940410094, 0.07768685433773265, 0.05520372891858701, 0.08926338516175748, 0.014865688149697118, 0.023068807298137296, 0.05971443163411272, 0.004418710877578105, 0.06512799195104069, 0.05652847880076978, 0.04278362803761998, 0.07128649616553899, 0.032278547784493815, 0.03628547491145231, 0.10608207945141102, 0.06643329852170522, 0.017257942292358608, 0.07993516151703174, 0.04538571845079142, 0.05181044971029605, 0.033690570403010614, 0.06461967729152211, 0.0387967111272437, 0.01931024396101073, 0.09161173576308836, 0.022322907705881426, 0.03677719227609135, 0.027457757575076916, 0.056913844009320584, 0.022917334478528752, 0.013941681733535183, 0.04284400342693252, 0.024534195601459474, 0.05083207882219746, 0.06737986910006694, 0.09688586041691805, 0.03984291910103733, 0.03422764017276707, 0.06303930302120506, 0.03757105471806661, 0.0529546671426825, 0.08286537121861212, 0.022033765055840055, 0.05320077671879723, 0.17537557489929662, 31.08224388091795, 49.5692942988488, 27.80232068031065, 66.86393830084032, 32.264987537937785, 71.34496381205898, 2.414240904392735, 0.7422937236485944, 1.8237371454315803, 5.542488992214204, 6.712882576450226, 5.091150681818686, 3.4906795044099135, 1.1485887607259135, 15.680231740397794, 75.29032691832512, 63.00927216006864, 73.01565816325527, 68.31623508084205, 67.61760603997016, 65.24521143205705, 64.0458800715785, 59.79776882356214, 59.73772518096432, 57.11161990319529, 57.92640993672033, 56.588352187987304, 57.76301576245216, 57.40777846305602, 60.99794741599791, 58.62894958065402, 61.358774092889604, 58.32467563690678, 53.40687851752005, 47.88591500251524, 50.369379366597826, 49.144513376297496, 50.36033830335064, 47.756916092288115, 49.145231170039025, 47.93451709132041, 49.35760790301908, 49.510545038407855, 48.408374709467736, 46.836269132552616, 48.315920522136075, 47.806608600001184, 46.60056214178763, 49.349166962408255, 51.30884193604993, 62.16246774119716, 60.64912711420367, 63.38153646838281, 54.17965212175923, 57.23313885350382, 59.402848905132664, 62.15005736197195, 64.62041708730882, 61.82205700105237, 61.15881950624528, 59.71219055114254, 60.905112758759536, 64.20239833093459, 63.503655541327696, 62.71501202737132, 61.066153510924316, 58.69215465361073, 55.474344145867136, 51.99870055721652, 53.6288611350521, 58.73175490287043, 60.03049089062599, 60.7212124332305, 62.55916841568486, 62.2939024433013, 61.58998996980729, 60.41161975552959, 54.87672005930255, 44.93265267341368, 44.559478375219534, 43.21016342409196, 45.25965282993932, 46.27609191402313, 44.74082131539622, 44.59792544764858, 45.77290281172722, 43.77948368749311, 44.270376159298806, 44.218424366366484, 51.63186873159101, 57.818387862174745, 58.91397253159554, 57.42977119261219, 53.62379343278947, 49.917565468818914, 47.44520533469416, 47.103280559662856, 47.12408088868665, 44.72309220221735, 43.709641964204856, 44.5260597813514, 46.78564310073853, 53.3867528361659, 54.8298869594451, 58.92799892733174, 56.84640492162397, 58.46107605964907, 58.51074111077094, 58.333975576585345, 56.19457367927798, 59.48779175358435, 57.62950612652687, 62.76184904959894, 55.20843098240515, 60.11256256411153, 28.218038966578824, 1.1709663728552482, 1.360765207679041, 3.6439765172619976, 3.6854911283139264, 0.18415449818055477, 0.793270439870896, 5.033336906663833, 31.15417818869314, 42.54602770651541, 37.74781580894224, 40.017291345903956, 50.018703783712084, 1.8493616220451172, 0.12836917063161252, 0.07467714769224967, 0.02532674803308422, 0.04053703689527127, 0.04510018599009322, 0.06801167713297952, 0.10984774633881547, 0.08090305232232617, 0.028697703439261646, 0.025728195342385483, 0.060478347699127855, 0.01433239615101728, 0.06852684061854117, 0.08306388758243093, 0.03636634315273935, 0.07289608519884848, 0.02034689115750934, 0.06602046906106895, 0.06259502565127707, 0.010939021181735781, 0.1555950467985484, 0.16554173322454577, 0.14359832440893497, 0.2432177933834253, 0.13272451837697338, 0.07653894053111154, 0.21364362790219246, 0.0985818335245694, 0.14245680743648162, 0.23960550495934105, 0.10164652230037798, 0.08992120187969939, 0.12408287039086704, 0.10682120108075681, 0.14841508691108998, 0.1015274186107901, 0.14891034743237883, 0.15391518451994465, 0.2618728463928546, 0.16635102850775565, 0.21467651360698287, 0.11973167484205578, 0.29036947856506995, 0.13260223542249974, 0.17117991052087278, 0.22621554442711417, 0.18721043823226807, 37.56049909899312, 67.74385929107666, 37.19791520026423, 65.7200574874878, 38.04454703484812, 76.05558918368432, 5.014890490039702, 4.254393904439865, 6.195434677985407, 20.64029239839123, 14.376228009500812, 6.902889051745015, 7.8051533333716865, 0.9977876623311351, 17.388137617418845, 74.54932059011152, 65.04443707004671, 75.08048011410621, 70.3504390101279, 70.11512817875033, 69.05442514727193, 64.17132531442951, 64.05119488316198, 62.178882860368304, 60.08983242896296, 63.38562750047254, 61.04640045473653, 60.80432745718188, 60.129232637343875, 62.78703851084556, 62.49317845990581, 63.13432124353225, 60.07291524640976, 56.2227794431871, 51.54256420750772, 51.962485313415534, 53.730462289625606, 54.72157462950676, 51.07286037937288, 51.98250116840486, 50.852987996993534, 50.97131806035196, 50.514718870962824, 51.5950886664852, 48.885884054245494, 51.377958020856305, 50.045466115397794, 49.864809590001265, 52.299722856090916, 54.034920584770944, 62.60248314949774, 63.45424544426703, 65.50000075371035, 57.91962423632222, 58.36409937950873, 60.17541854612289, 64.35407246312788, 66.32444766259962, 65.61327880428684, 63.25478507626442, 63.29939419223417, 63.91342555322955, 66.28710669855919, 63.89119355909286, 63.97381044203236, 64.45894879679527, 60.082901600868475, 58.28246308911232, 54.997583973792295, 58.74451437304097, 61.8139337724255, 60.89618152187717, 63.81105561410228, 65.4703672470585, 63.758080082554976, 64.99628997618153, 62.70585721538913, 56.935858495773815, 46.507739251659764, 48.148670657988525, 46.62299809917327, 47.51157968275009, 48.723827408206084, 47.66491689989644, 45.56964166702763, 49.056283581641416, 47.46676660353138, 46.24547389245803, 46.820120734553186, 53.85070254725795, 60.67749761766004, 61.687613841026064, 61.35744048703102, 58.11897477796001, 51.21801160996961, 50.02314782911732, 49.927618503570564, 50.54241080437937, 46.17054877742645, 46.40270994555566, 47.44439340406849, 49.14762773821431, 55.96201242939119, 58.47768337495866, 61.728994846344, 59.687899312665394, 60.41324753915111, 61.474221214171386, 60.9192293690097, 60.32300556859663, 62.510946796786406, 59.32895537345641, 62.29363179975941, 58.867872914960316, 61.39065511765019, 29.43790589609454, 1.0914477946296817, 2.8190579433594984, 5.794128160322867, 9.061215404541262, 3.168767152294036, 1.4304386367720943, 5.936120412042064, 38.1033355189908, 48.83283399766492, 43.43909255919918, 47.65886860509073, 61.772525310516365, 2.1946712799610633, 0.1786085885138281, 0.1848415564745665, 0.16747658020786702, 0.12795337641070928, 0.13327907410360154, 0.20898474079947318, 0.12160411630306514, 0.1833367759301778, 0.2046643573069765, 0.12472204818961122, 0.21427850028680218, 0.15803171201579033, 0.21453855649357845, 0.11959432293811154, 0.08921568852759178, 0.09241465719476824, 0.2686456765138334, 0.13513686796349866, 0.12999316977877773, 0.1785497223177264], [0.07091195577935827, 0.05887190728718716, 0.07730713519718378, 0.03273697096794363, 0.02448873402881286, 0.012405983795742355, 0.05524102207874099, 0.07317509442087143, 0.02217851162347342, 0.10353692852321172, 0.02986039508194212, 0.10383374928947418, 0.08074447978287935, 0.06283264697319077, 0.055794535925792116, 0.11446122741026264, 0.06175270814809108, 0.024437318037774776, 0.02205751761193237, 0.028681832012690367, 0.0527676574194864, 0.02500046352525392, 0.03972657715841647, 0.06545269831774697, 0.02750712236569774, 0.08203674753707263, 0.054306574841781016, 1.8174188199543186, 57.51824025184878, 24.975539099785593, 40.495608698937204, 33.23977301197667, 36.6326859689528, 27.836753206868327, 1.2466070752951408, 0.8799375377355084, 1.2269325890848715, 9.9347968639866, 6.490381225462883, 1.0800981713879494, 0.884992124572877, 1.459564073912559, 45.10497023982387, 75.80709134378742, 62.51250790011499, 69.54591381934382, 60.08321146811209, 66.19558211295836, 58.68586317185433, 59.08437598136164, 56.7107105255127, 61.44618411217967, 52.19341093494047, 57.08213152423982, 53.4074943296371, 56.50952039226409, 51.46638001165083, 54.85924590018488, 54.29861760908558, 54.11733742683165, 47.836042065774244, 48.14165746012042, 47.173934213576786, 48.10528139914236, 46.440470603204545, 48.832171117105794, 49.59325605823148, 49.350877115803385, 49.6863966603433, 48.4097396942877, 46.00023554217431, 47.28678080343431, 43.45391127371019, 44.25152132588048, 44.557548569094756, 45.549512063303304, 49.684247201488866, 56.188682279279156, 57.643297180052734, 64.65096450621083, 55.1833591922637, 58.61463685189524, 59.67546147684897, 57.86953164685158, 59.47180025039181, 60.42921943049277, 60.8333686859377, 61.06232135526596, 61.17257918080976, 59.09919469587265, 60.51429956190048, 60.81949526263822, 60.743805285423036, 59.45911530525454, 57.30740501034645, 58.984312395895685, 59.86923833047191, 60.238239226802705, 61.237325745244185, 60.00505039768835, 60.895844198042354, 58.282133610017844, 58.926567262218846, 55.10814382183937, 48.19556651576873, 41.847390820903165, 42.05914781939599, 42.34352750162925, 42.51904964447022, 42.576096596256384, 43.15942364354288, 42.78777122497559, 43.28151133752639, 42.00189690436087, 43.1703866681745, 43.406089736569314, 54.389200825845045, 56.27022051042127, 59.72235341225902, 55.5278923434596, 56.753833063187145, 55.13811072995586, 49.77555605673021, 45.40079147584977, 45.108049300409135, 47.141166733157256, 44.72527304003316, 40.49388677843156, 42.47962590186827, 51.834890611710094, 52.53758322808051, 57.42337772923132, 56.58004853033251, 56.98519799017138, 54.0497039979504, 57.62469337832544, 54.478823061912294, 55.607539992178644, 55.674126148223884, 58.39463895367038, 56.921310424804695, 40.088301935503566, 2.0708261189922212, 0.13518943691686278, 0.7951330754064745, 1.4044115043455556, 2.973548827632781, 0.38770376854846555, 0.10204769956368594, 4.935666947595535, 31.60216385318387, 45.53754883427774, 26.861491164853497, 45.298492139385594, 20.15133365508049, 0.14954223207408382, 0.019757495667304725, 0.02727277032400091, 0.11399234329620678, 0.06117041237772473, 0.019435650638995633, 0.028988791952630686, 0.09594890424200604, 0.03528568037455121, 0.021089190136521094, 0.06536875040300431, 0.06482351030553542, 0.010413810453047196, 0.0602671679019207, 0.040412356085594625, 0.036436053323409254, 0.025531295424086914, 0.06427240197456653, 0.029036258760419105, 0.06646290015909942, 0.008525927532314053, 0.05663342901595658, 0.004424796009721656, 0.03250675771625773, 0.04790253178667157, 0.07083590623111495, 0.07797760002675556, 0.0270769007939605, 0.008637528348293518, 0.03749587467961735, 0.024796768407066985, 0.037884434474812406, 0.045968056355993596, 0.05654082047722994, 0.05855566236160456, 0.04141643305399245, 0.09875864661749333, 0.04950844742838414, 0.05393977577407515, 0.07242967554878804, 0.026780646932761998, 0.032715156614299745, 0.05659745735747199, 0.051486436653161244, 0.06033219727537325, 0.03522066249241752, 0.006236968854922922, 0.018946438381868987, 4.609209058746215, 70.1590665694206, 22.356223444784842, 49.528180014702585, 38.439129629442775, 46.405867453544374, 26.779921554750015, 1.2591184555522859, 0.9793675378445656, 2.9394769139828223, 3.6540231781621135, 5.090140181203043, 5.042637336638666, 2.5200544393831685, 1.3855746893152114, 48.12007265706217, 76.3216749314339, 67.89432925562706, 68.62833807545324, 63.78074745978079, 66.02194663017028, 61.73898120080272, 60.35796565394248, 58.271131361684496, 61.50387825504426, 54.92826392573696, 59.79536048827633, 56.326796777786754, 58.635574463875066, 55.59771053252682, 57.64271666926723, 55.31917910422049, 54.87019323533582, 50.43490648269654, 49.13033400812457, 48.711813188368275, 49.95319627946424, 49.26928397147886, 50.80102443695069, 53.38972991512668, 50.89867968713084, 50.67177449503253, 50.351395299357755, 47.13208644620834, 48.917459134132635, 45.938677864689986, 46.02469544256888, 45.671007479390795, 47.440965252537886, 51.546808212034165, 58.35550154409101, 60.87657751575593, 64.38377265007266, 58.55527177933724, 59.44943489566926, 61.12882906390775, 59.567188370612364, 62.4823840971916, 64.06017711085659, 62.70998747118058, 63.40564727783204, 61.4878632176307, 61.11825827629336, 60.118002891540534, 62.92298786101803, 62.33276136459843, 61.50541974652199, 57.17683715205039, 58.81179871097688, 61.372945616322184, 61.85789177494665, 61.980630582378765, 62.62477790155719, 61.04224666472405, 61.380770744815955, 61.74577866831134, 58.32702905901017, 50.78391505825905, 45.40403919835245, 43.55267263227894, 43.44852978183378, 44.56512658826767, 45.67919738831059, 43.7882697966791, 45.685539860879224, 44.82435603295603, 42.81964440499583, 46.28448186382171, 45.78718416152462, 56.32095636860017, 57.84487170557822, 62.24560629936957, 58.17643750098444, 56.449508128627656, 57.70011271199873, 49.64339179377402, 47.52752803987073, 48.00074631167997, 49.204509950453236, 45.41803813749745, 43.30116241208969, 44.546977781480365, 53.714047170454464, 55.06551550280664, 59.99640157145839, 60.17535186582997, 58.56743112687142, 56.39028426139586, 60.93573862506498, 56.23422099697975, 60.00421493284164, 57.7852830579204, 59.863382231804636, 58.22208996742003, 43.228806449520974, 2.8852187673891745, 0.15057718621626978, 1.7915268867246568, 3.200777860418443, 3.1679535056314165, 0.3611201498537295, 0.2837261479468115, 7.347225441086677, 36.78836484109202, 54.5839935733426, 26.483133454476636, 48.29863855915685, 27.55318937763091, 0.2651824687998141, 0.020209380290320805, 0.12649754122380288, 0.12809849644620575, 0.051919958148632324, 0.0313306691110014, 0.03307089337237901, 0.06627409012928125, 0.017904922696611574, 0.016079775673607667, 0.057108641016267, 0.048596293350020726, 0.06021159205345377, 0.04903613507086712, 0.09340246628609397, 0.005066785351147936, 0.03300288774734063, 0.01301384200492213, 0.012494731251330627, 0.06052416741787907, 0.10418402767109294, 0.15461725813727226, 0.24282356453759057, 0.17083857238533037, 0.13264870631598658, 0.17613639213865803, 0.14804206337899933, 0.11368629117045673, 0.10189929301099432, 0.18936791036638523, 0.1565114258518142, 0.13038156103462945, 0.17160570218918786, 0.28195357370761137, 0.11486391386678142, 0.20462445944787996, 0.24799756916059604, 0.16064822403413637, 0.1361334870659536, 0.12261331456923678, 0.1488111084026675, 0.14334614358602032, 0.16711114094622675, 0.1548570896228475, 0.1142462937822265, 0.17249531413037933, 0.10270151730266311, 0.11308370173097619, 5.496044207003809, 78.8971737892397, 38.79629281259353, 56.34861300068518, 45.51624644187189, 49.42503344628119, 31.476838242623117, 1.5472299052822975, 4.336930378790825, 8.633435829993218, 22.7149869549659, 10.53515778433892, 6.303163065064338, 2.3189003429105206, 2.3693871305834864, 50.03684474575905, 76.80028253985991, 69.14159590198149, 72.36418385659495, 66.46307991396996, 69.80311147628292, 65.86582060783141, 62.814597083676254, 62.19340739711639, 68.41001895166212, 57.18684704073014, 61.66920223543721, 58.7326374361592, 61.260071569873446, 56.55851471808649, 60.39583221558602, 58.01415335747504, 57.51687134465864, 53.954712037117254, 52.329121020532426, 54.34276780774517, 52.455005568842736, 52.795024071970296, 52.558105068822066, 57.53345120337702, 53.95106031048683, 55.6741379153344, 52.909337628272276, 50.14922457356607, 51.512452171694854, 49.73284144555369, 46.665748011681345, 48.81192776464647, 50.40345691865491, 53.728650154605994, 61.16994334805397, 62.840123868757686, 69.21597188518894, 61.22505264897501, 60.939151087114894, 63.50714645078106, 61.545949597512525, 63.0941326387467, 64.91341813918083, 64.06888085026895, 64.48140828840195, 64.35979127883911, 60.78848108168572, 64.05651361711564, 64.86815790976247, 64.99253234555646, 63.46474170684815, 61.2798010918402, 61.518387102311664, 63.77512278095369, 64.02669183669552, 65.49114404186126, 64.78916529686221, 64.36456088096865, 63.54973946848224, 62.25574954863518, 59.598743838648645, 52.45455057390275, 46.4813103214387, 46.76294826692151, 46.69935487931775, 48.56036655364498, 48.091125565190474, 48.14281063695108, 47.0623270926937, 47.47519185466152, 44.462136914653165, 47.06984627631403, 48.74683603163689, 60.372874582967455, 58.53261224685177, 64.8786541723436, 58.4922000669664, 59.36708865627166, 62.82636027182303, 53.341955446427875, 51.044944870856504, 50.24223965983237, 53.209673512366514, 48.58142183672998, 44.929820722149266, 46.939372554902114, 57.69096182238672, 55.25066706442065, 61.598348540644494, 61.22071450756442, 59.898914983195645, 58.3565095932253, 64.15668702894642, 58.32043555475051, 61.24999500090077, 62.050464460926676, 63.37239734588131, 60.747711966114665, 44.36105743531258, 3.201388769572781, 0.5134642412585597, 2.9232652677643687, 5.7832097526519535, 8.682062433611963, 2.052594206986889, 0.6594961665330396, 8.996912067936314, 46.28366993319604, 57.50196633800384, 37.68406944890177, 56.267729805361846, 34.42048880361742, 0.21784493068773902, 0.1513109605519041, 0.14076032104992098, 0.3270070819604782, 0.1026228936989942, 0.09730438957171095, 0.08590123210583003, 0.19287829377478172, 0.13082422195903717, 0.08121132610305663, 0.13091687263259966, 0.20559342277626838, 0.09252398560244231, 0.2101362169149422, 0.2454467568426363, 0.11851509657478142, 0.1554353481098529, 0.18028875722760157, 0.12629151719832613, 0.12080016065268748, 0.20955144668058043], [0.049549636145633076, 0.08031877238423595, 0.03906452780469291, 0.024238514390984373, 0.08130917085274574, 0.03794480603368532, 0.0522166371886288, 0.013684933111372014, 0.03974833022502642, 0.008141220201768221, 0.015750175920285044, 0.03755726130498994, 0.0026199108153025833, 0.06591219019385115, 0.12170221386176926, 0.01377757229361563, 0.04016514717330856, 0.07960757465973016, 0.04322263855306853, 0.02967703002204578, 0.04340232447570851, 0.08088289654903835, 0.028458894681065317, 0.006621876804743924, 0.06852051273228661, 0.029766166267255624, 0.035692959528176055, 0.07051368965016258, 24.79724580241788, 53.10476579973775, 33.52249353162704, 61.04473736978347, 36.033810646303245, 35.0413647005635, 0.42512097365913853, 1.2911475497868754, 1.3449694552729208, 1.0820698978439456, 4.058337418302413, 3.6995248784942016, 1.455223358446552, 0.1956133195950139, 18.643058769164547, 70.32106045753726, 69.2681864769228, 69.81227413300546, 67.82146730730611, 69.52201874025407, 70.55234693711805, 65.75967342622819, 61.00760429136215, 57.54308062215006, 62.06909179687501, 56.325478861408854, 52.84286522096204, 56.127085378093106, 53.48824808674475, 54.1487281553207, 52.017410262938476, 49.29832520023469, 47.248494548182336, 47.34201954257104, 47.970375399435724, 49.599492626805464, 52.76175060579854, 54.52055315817557, 53.55708176089872, 54.388804666457645, 52.067189062795336, 53.008373552753085, 48.41845912318076, 45.10942997470979, 44.95945815117129, 44.72780689116448, 44.78036272910334, 43.19832963328208, 49.680199315471036, 51.61279032307287, 56.29459411867204, 59.148734231149, 60.19343791469451, 58.17905764425955, 59.120179376294544, 61.71539206658641, 58.606713664147165, 56.72226582804034, 63.415139413649044, 63.80480335604761, 60.45765661424207, 56.41326935060563, 53.30074702539752, 63.316782059208045, 59.699289875645796, 60.760349842809866, 59.544560217088275, 57.285412280790275, 60.295321479920425, 60.44994131211312, 59.37267018902687, 58.45789109506915, 60.258255081792036, 60.261589096438506, 57.76516522130659, 52.85784475265011, 48.100429427239206, 44.5627417872029, 42.671190538714015, 43.46820046824794, 44.323841987117646, 42.22713508913594, 43.159415798802534, 45.08583299575314, 42.78610814002253, 42.67510506414598, 43.48910277889621, 43.49907344387424, 52.0480243621334, 58.936871328661525, 57.99014845202046, 59.11010280732186, 59.5996577508988, 55.14119763528147, 51.253783625941125, 46.15105459767003, 47.03526273850472, 44.988315028529016, 45.039231315735854, 43.96301531022595, 42.62613035017445, 44.94243898699361, 51.5239643281506, 57.18465835817399, 57.76136444460962, 56.738692714322, 57.86264788719916, 53.92993442473873, 56.770463912717766, 54.06542877997122, 55.90162361821821, 53.22636319744972, 50.45514199041551, 4.698531233495282, 0.10325963533813916, 0.5505870234581732, 1.4063858048569773, 2.6182691176091475, 1.7270697196645124, 0.1795789614439972, 0.08725341559658129, 10.810027680089398, 45.038109517866566, 41.918115077480195, 31.73290429576751, 51.25880425976169, 3.566334425441681, 0.20594738604080295, 0.06387112511982841, 0.019668941648917335, 0.0379489888737519, 0.03660701350459168, 0.06468710835061728, 0.05104682858913176, 0.0640800909229344, 0.06186425438030593, 0.05326635767555526, 0.07825464806369237, 0.05427189021100921, 0.06871830897345658, 0.046129723890654506, 0.03591538166567203, 0.03750593341406315, 0.09204786195750199, 0.009207158770051696, 0.05316881553059625, 0.05307409641963821, 0.016947264910765716, 0.029923959312239484, 0.0688845577139047, 0.03580272843640658, 0.0354570810562901, 0.018723472321946776, 0.01424636064668096, 0.028344588617103237, 0.019606859798753457, 0.019012461754403288, 0.042013797773829395, 0.016857981193630446, 0.02008298535891358, 0.025086920377948595, 0.02055163007049311, 0.08812643407333283, 0.011974737581406391, 0.0339052090871959, 0.03364959619038048, 0.05074921492186766, 0.03392387481947099, 0.018718904522698254, 0.003948070028150875, 0.01252311863936484, 0.04054594649783066, 0.07510329942188917, 0.05660299234272492, 0.06631260903011407, 0.11835610268697624, 36.06231058797529, 51.491557705786924, 35.21850678228563, 65.69402863902431, 38.073011675188624, 45.003557359018636, 0.03943293182660015, 1.592068602481196, 2.313873580386562, 2.5372221633311245, 4.036000255615481, 4.9922647879969695, 5.414497640825087, 0.719819032857495, 22.53350869301827, 71.1485158243487, 70.25879675342192, 73.02624856272053, 67.84986526735368, 72.34293245500135, 71.10351054899155, 67.25143709490376, 62.7972484404041, 60.634414303687315, 61.75042275459536, 59.599846024667066, 56.044750905806026, 59.25310065669399, 56.872425925347116, 55.92108641901324, 53.834977765237134, 51.89369086296328, 49.425739472912205, 50.32280514317174, 50.96654061348208, 51.409333059864665, 53.60551518778647, 54.73823293562859, 53.992951223927165, 55.85366872049148, 54.313875629055886, 54.8871261073697, 50.53635466483332, 48.21729252415319, 48.700454004349254, 47.988112357354936, 47.23471918413716, 46.284881945579286, 51.5282004879367, 55.11922059520599, 57.88381299664898, 61.412647847206365, 61.25185028199227, 60.93662900309409, 60.85807569565312, 61.595673484186975, 59.96658371340845, 57.557577702306936, 62.671583544823434, 65.14957228014546, 61.81677356843026, 57.2277142155555, 54.90254886688725, 62.406937306927105, 62.89527631575062, 62.27496524010936, 61.81907992209158, 59.899499416351325, 62.36316757817423, 62.672921073052194, 61.29842842778852, 60.07286425559752, 62.02798143509896, 59.97214563431279, 60.833356918827185, 54.403019335962114, 50.31385821680869, 46.28006527500768, 44.32139442813012, 45.68768539736348, 45.59089306862124, 44.18521365811748, 44.97286089005009, 45.62267995649769, 44.15569390020063, 44.132222437089496, 46.62170371701641, 44.67554915335871, 54.946789280060806, 60.53613539664977, 59.302597045898445, 60.32506481293709, 59.29525829130604, 58.784640219903764, 53.409792838558076, 48.05098010647682, 49.788401819044545, 47.251028399313654, 47.68635657525832, 45.981219891578924, 44.495955590278875, 47.720120337701616, 53.054029941558845, 59.08186566445136, 59.50144944652435, 58.68186627664874, 58.57562888053156, 58.13168717968849, 59.03391861146497, 58.42522951864428, 58.09327148622083, 55.274883777864524, 56.24743546209028, 6.47033203032709, 0.2455684575702875, 3.370769706464583, 4.9597811891186625, 2.867903954559757, 1.2053249872499898, 0.11173023121251215, 0.09989434898260141, 14.30253844107351, 52.433899294945505, 50.761028028303585, 31.436041670460856, 59.72463230932913, 5.364631568231891, 0.1507823598841506, 0.11602056873661858, 0.03775951234743961, 0.05542265386470864, 0.030319191733255025, 0.022649879777623762, 0.07716427512106395, 0.059452303159501285, 0.059369029402132, 0.06565483061656838, 0.090465959341776, 0.019851186305224415, 0.062399791974213824, 0.009650386599523407, 0.026833275257940256, 0.05703411215255338, 0.1371937527531578, 0.014620093767711473, 0.04152753112477161, 0.04048701518425538, 0.03447401787965529, 0.11220021083229974, 0.13018907378277472, 0.12747850148908554, 0.19666295198182907, 0.1581594035510094, 0.17539769951854983, 0.16922372032798108, 0.16578352589520717, 0.12321126151589618, 0.11548777756791924, 0.10852983762179652, 0.1953716494984204, 0.11561877094209196, 0.21455387825206404, 0.24736085816496806, 0.07172118977553422, 0.16562217245659522, 0.19818443324296706, 0.15018671120126403, 0.12450864673742365, 0.10068824589853326, 0.25458825421669795, 0.16697525227021787, 0.20902016470509194, 0.2569883770399517, 0.09224840079344089, 0.1482681052819375, 0.190305617307463, 40.69598297918997, 67.97250209316131, 49.207792974287464, 71.61890998963388, 47.63309078831827, 46.67384770608718, 0.7844301529469029, 5.2022444625054645, 6.983306465610382, 6.054467635769998, 10.674133243099337, 9.148984320702093, 6.834733457334581, 0.5453662874717866, 23.9002566183767, 72.97780729109242, 73.80246208560082, 76.57021983977288, 73.20717965402912, 73.68767784487817, 75.90644498025218, 70.74937543561383, 64.8651533742105, 61.63740750282042, 67.52939977953511, 64.00244766666044, 58.99048228417674, 61.72718271132439, 60.75499188515448, 59.81274051050986, 56.341807688436205, 55.24549345816336, 52.51278208148096, 52.99433146753619, 53.97360217186713, 53.252062566818736, 58.14068901923395, 60.10414123535157, 57.995282834576024, 61.17247327681511, 57.71631210081039, 57.761478193344615, 52.72939105187693, 51.99679820768295, 50.8299832959329, 49.96302966148623, 50.150330681954664, 45.90622417388424, 54.21477302428215, 57.04019746472759, 60.414628213451756, 64.01812145786901, 64.66444961486324, 61.655430793762214, 61.60190613039079, 64.23999032666607, 60.61362181940387, 59.10567837376749, 66.34691499894666, 66.48544526869252, 64.30718052771785, 58.31949026353898, 52.528047946191606, 63.792118410910334, 64.4879900255511, 65.85049198519799, 63.915575012083984, 62.09097862243653, 65.03855351478823, 62.93120914889921, 62.34008835208032, 61.50803204505675, 64.30529779003513, 62.626240945631466, 62.46792231836627, 57.47582374080535, 52.78276666518181, 49.3554505994243, 47.51257988714403, 47.26865160849787, 48.77759133615802, 45.39685341619676, 47.730957846487726, 49.245102559366536, 46.26337558992448, 48.256324029737904, 49.589380756501235, 45.27509127893756, 56.943954267809474, 63.29023938025198, 62.07387316611506, 63.53487368552916, 63.42931093708162, 60.218301819216826, 54.86126592082363, 50.47886840758785, 52.769085438020774, 49.533687022424516, 49.97326704763597, 49.71245688776816, 47.61735423918694, 48.63610359930223, 55.65350232585784, 61.60065881667599, 63.14175413500879, 61.40589352576964, 63.03918415500272, 62.75418473828224, 61.28870094976118, 60.95319317233179, 61.34413188503635, 56.83935250005415, 57.666207744229226, 6.734834121119592, 0.1885453464403268, 2.4246748993473672, 7.130080576865905, 10.95140068761764, 6.028743751587407, 0.7202207080779538, 0.16045209020376205, 19.75404658625203, 58.23017789471535, 55.16394738228091, 44.63334445030459, 69.5457883034983, 7.470652624484032, 0.4653461974474692, 0.19044136808764553, 0.23292796085438422, 0.18582014186728388, 0.23201976362014973, 0.10131286036583687, 0.16569442986961336, 0.11967235665407874, 0.11319986364293484, 0.14489505079484757, 0.1517514304648484, 0.16755357204425722, 0.16322980244313517, 0.09822165728696892, 0.14430082703550018, 0.0970890039517995, 0.21593519606657569, 0.10801191621970747, 0.11874934327938866, 0.12087964227483158, 0.1200321192042001], [0.08719497074883792, 0.046311849803333326, 0.07666252583505646, 0.04375130816873524, 0.04758732874066599, 0.01912918291054666, 0.04695234910374688, 0.040536799408014745, 0.07551341693127349, 0.02907959635429565, 0.04646696728624163, 0.052356911718004176, 0.029479421472417253, 0.05391259497452167, 0.09620945074505384, 0.02826215947167047, 0.07683446660878197, 0.04737208484702053, 0.12925132087642147, 0.06000620388095418, 0.006828091394591837, 0.07359166239057818, 0.03413896166509198, 0.03561007647564815, 0.028361683869133555, 0.030942182094159148, 0.021372320911576672, 0.08195849931648663, 2.562766108782061, 58.52761122488207, 28.151811707404356, 42.26962612521264, 59.97638963883924, 30.46129934249386, 5.075420996835155, 1.6090676645117423, 0.36400094688419377, 2.0149654390350467, 0.8672183944332985, 4.601605544167181, 2.79312004485438, 0.48616604639157174, 2.0678232994771775, 45.63989131681381, 71.33116491379278, 68.23088430589246, 71.70142096857872, 69.59961891174316, 69.73514464593703, 65.62146871320664, 65.53960100297006, 60.037437408201164, 58.77543049473917, 55.55563134531821, 55.29432304443852, 55.07825928349649, 53.267293130197835, 53.69866755700881, 49.625697981926706, 48.691452164803785, 47.77962269321565, 48.47270550266389, 50.331481425992905, 54.07127703389814, 55.44935864786948, 57.11596588934622, 57.52617520670737, 60.58958553498792, 58.47651843101748, 53.31880561767086, 55.40872289288429, 48.53533398720526, 45.257201348581624, 45.14546086711269, 44.80128465160247, 47.15664048348704, 44.67367426041634, 49.801074997071304, 52.96882429430562, 58.16087745851087, 55.853229415032175, 59.6223682741965, 57.667329542098514, 62.090437335352746, 64.51117515563965, 62.875676231999556, 61.36437915986585, 61.20791581369216, 61.6630127353053, 61.467666933613444, 54.94959377473401, 55.435120444143976, 60.54212877827307, 61.17665060104863, 60.74021631671537, 60.11693600685366, 59.24525983871953, 59.67881902571648, 59.252182822073664, 58.69280184468916, 59.637908704819225, 57.26859707986155, 55.1594719579143, 49.840188872429636, 48.84318121017949, 45.30712919850504, 41.209409467635616, 43.39197312631915, 44.203695866369436, 43.340958779858006, 42.087957628311656, 44.77287100207421, 42.65608549118043, 41.79312482956917, 43.477433727633574, 43.218980912239324, 51.3371967500256, 58.18752604146158, 57.82914692355741, 59.58707086501583, 59.27341461181641, 58.99758961892898, 55.27973967213785, 50.24701710670225, 45.538192102986, 45.69962509216801, 46.1714195436047, 45.529825687408454, 43.08385133743287, 43.88483462795135, 45.849357651126006, 52.71635309342415, 55.165006422227435, 56.96865343278455, 56.20976894132553, 59.16984442741641, 56.51209346709713, 58.57287929904077, 52.045408141228464, 59.57383678805444, 16.76991912626451, 0.059915456935883536, 0.37979253177200595, 1.4465956149562713, 2.39141883869325, 1.2003305842799525, 0.46989204061608164, 0.14527973418514575, 0.7241685736563899, 28.06554505901952, 55.70933334289059, 26.047163971008796, 43.06862077405376, 32.48050216705569, 0.048284001438127416, 0.04690649491103907, 0.08786611739666232, 0.0562570346969991, 0.0046381974619092246, 0.094316738597568, 0.026512347619920492, 0.028245232758983493, 0.0049783151236272635, 0.035956888309409546, 0.024841396859095945, 0.02702476276505378, 0.043710835743695504, 0.0549344988089175, 0.05617685976528353, 0.037658764124517484, 0.01874359170605819, 0.0364021654240787, 0.008743127822996149, 0.021311752085063248, 0.006101417257600735, 0.01884325016890803, 0.049078802337809924, 0.032388914241305286, 0.021080098588079698, 0.03984107282913981, 0.036975294952431036, 0.047135103208523606, 0.009488555313568682, 0.0270111283152214, 0.033756220307681835, 0.08089976580513102, 0.029873318985224735, 0.01992213562311184, 0.0421326371630834, 0.03879820882913567, 0.012647117630788877, 0.023606692951533104, 0.04368903288137048, 0.014094251016485355, 0.036173350282854615, 0.04053644700756958, 0.04204639098456791, 0.06463154399346921, 0.026726273842336192, 0.030822295079668684, 0.027495906838486274, 0.022908386571573156, 0.0764482663643937, 0.05234673040949049, 5.526240083479113, 72.98155707697715, 30.69037948885272, 55.029978829045454, 60.23741160669635, 39.10927049575314, 5.759669648062799, 1.5947896242141726, 1.7398442664454061, 1.8222982484486796, 3.3052286169221325, 6.257358116488303, 5.9987734113970115, 1.4709493662080457, 2.252858906022964, 51.88959590850338, 74.88214938871323, 68.55782170449534, 76.25835218737203, 70.04847142004198, 69.94209674096876, 67.84562126282724, 68.3872692046627, 62.11084542735931, 60.59300976414835, 59.380612988625806, 57.7623018910808, 56.42926869853851, 56.226795950243556, 55.29193824337375, 51.99737087372811, 49.85915353221279, 49.01179213677683, 51.34653591340589, 51.418087790089274, 56.64309278611214, 57.90617835137152, 58.39927127284389, 59.41364326784688, 63.672415517991595, 58.21077785184307, 56.50069505937638, 56.61025078065934, 50.302385284054665, 47.6262423299974, 48.19879854879072, 46.27198127008254, 46.15972695812103, 48.177574603788315, 52.51137002821892, 54.98038438058669, 60.76253852536602, 61.231249993847264, 60.639886010077696, 61.27388223525017, 62.90205809377856, 66.19402100962978, 64.25909619177541, 62.46145040758195, 65.13412990877706, 64.03260284854521, 60.85713040444159, 54.09285399221606, 58.331606465001265, 61.09197447376867, 61.708398480569166, 63.291357255751095, 63.43439432882494, 62.0700135538655, 60.614782840974875, 59.92400638518795, 62.40653330279935, 60.75130877956268, 60.42712880719093, 57.79217858468333, 53.51204118421001, 50.24163953719601, 47.63420081907704, 44.13541916877993, 45.23271006922568, 46.62901501501761, 46.944616763822495, 43.27767525949786, 46.01676048771028, 45.53214380818029, 45.40580818730016, 46.75627239288823, 47.07230560241207, 54.334734793632265, 59.969207779053725, 60.359091374181936, 59.735144261390936, 61.89667617121051, 60.47447965991113, 57.065167273244555, 52.54143107321955, 48.288358026935214, 47.96311509224677, 48.347742711344075, 48.23684946183236, 44.42613347884148, 45.323234450432565, 47.73339756073491, 54.36807886246712, 57.18008879692324, 59.09914762743058, 58.61731190835276, 60.89418111308929, 59.2797923857166, 60.2043499485139, 54.90589857101441, 60.37535744328653, 19.823564714001073, 0.27965552443938874, 0.5626429184790581, 4.742647601712135, 5.453343324122891, 4.19797109980737, 0.4286684510448287, 0.2908710210073379, 1.1691906423337999, 30.372583173936416, 62.25147416514736, 30.770113429715558, 44.44103064075593, 41.80081267510691, 0.13164795033874052, 0.06468006800259314, 0.06414513561814543, 0.020216286572958195, 0.051358967283440214, 0.0635737412789416, 0.04380147926689636, 0.09939990817539154, 0.022484801236479994, 0.021285963650312156, 0.04376649969227372, 0.02406687239154933, 0.02709449591836141, 0.043885296946691896, 0.02844287578256861, 0.05168645454931164, 0.09515880712217863, 0.007958181686849605, 0.06243198298879209, 0.01482984193811013, 0.005514138564091897, 0.029208063553538055, 0.17908924739928017, 0.18615429409809653, 0.1895686254025467, 0.15186623640118108, 0.11831404445993325, 0.14373315588360833, 0.1490129725707154, 0.15873000115877198, 0.1933296114927338, 0.14580088847827527, 0.11421278509641848, 0.12331560269118318, 0.12863717883104278, 0.12028437663590717, 0.19651656790125757, 0.10354100411096889, 0.18868250682228999, 0.16032134963860437, 0.14780321248596714, 0.18104179101365228, 0.1437498106350822, 0.16968453753619425, 0.13872857926593674, 0.1822908973741916, 0.10667781240396923, 0.13959287966210998, 0.1732177350429758, 0.23000470723115632, 6.256406941721517, 83.20296349063997, 41.10490968150478, 58.47527503967286, 69.2644759147398, 47.40635818050754, 7.523850750538611, 3.5693009630326307, 5.217759888018332, 4.950616080914775, 6.857353766118327, 11.672675532679404, 7.901447030805773, 1.2600761267446703, 2.961972442365462, 50.55223634166103, 72.56868839263916, 71.51308444238478, 78.34051885912496, 72.998807660995, 72.36933785100138, 70.51980695416852, 71.16801000410511, 66.40050242024084, 65.09990330665343, 61.68125175660657, 60.35184675647367, 60.53194630530573, 58.30257700335596, 59.66875814622449, 55.306133301027366, 54.07834122257849, 52.92468194038638, 54.85722587954614, 55.807231780021425, 60.39493791518673, 61.210743842586396, 61.164122550718254, 59.99864908956713, 67.96133118291056, 65.34278431246358, 59.5754998730075, 61.84121385697396, 52.953625109887895, 49.431732854535504, 49.098751083497085, 49.32268311900478, 50.96167687446841, 49.66824393118582, 54.52646417002524, 57.54943878419938, 62.53152747308055, 63.152081735672496, 62.43846531837218, 62.67962832604686, 64.86531419138755, 70.85743673386114, 68.44894455325219, 64.79693158980339, 66.26200352945636, 66.52904633552798, 62.93473143731395, 55.11278006338305, 57.4957807602421, 63.340920325248476, 64.26561124863164, 63.60771209962907, 63.29448338477843, 63.06484430067001, 63.35982222710887, 64.45241020571801, 65.11300794539913, 62.701726959597686, 62.18211097102012, 58.868802516691154, 53.90763182793894, 53.38800014988069, 50.82003224280573, 46.4997572283591, 48.30553408591978, 50.08386611938477, 48.86495036463584, 45.817609986951275, 47.60449278739191, 46.87115469286519, 45.59885548007104, 49.0393271753865, 49.64571383691604, 57.978040095298525, 61.9098121889176, 61.52623968739664, 61.551048678736535, 64.95291248444589, 63.63851447259227, 60.16658929086501, 55.13684772676038, 50.66415725215789, 49.983135730989524, 50.56901231888802, 49.7177363980201, 46.66153146374611, 48.36221233490975, 47.71470746686382, 56.95774139896516, 59.563654315087106, 62.73281566558346, 59.518174432939105, 64.84274095104587, 60.536908103573715, 66.99252143982919, 58.148208202854285, 66.52820694831111, 19.932526196202925, 0.32156865442952803, 0.7895846376495977, 2.6345780876375016, 7.5819356595316245, 7.919530137892693, 2.96001150242744, 0.7030736378604366, 1.533039015146994, 43.491679776099424, 68.16460409472066, 37.54844957782377, 54.13147757130285, 48.443119064454116, 0.1527202252538935, 0.1555287189060642, 0.10045213760027003, 0.1527632334299626, 0.10927295056922783, 0.20175987283789343, 0.10178019698228567, 0.1736715348858026, 0.08793581607601336, 0.11932604660790776, 0.09480967021156704, 0.16078869391593242, 0.15531222245866255, 0.1502195304079402, 0.1491185088431643, 0.12874112164060916, 0.20440034808651095, 0.12290769151502079, 0.14641109283172316, 0.14634410610362408, 0.11173226900639073, 0.16274538972685415], [0.030434803977128, 0.06542475143026921, 0.0461739463160836, 0.0392327951868215, 0.020153469278387005, 0.02244206885206363, 0.025040552906331517, 0.005900910980398617, 0.01633246786021177, 0.016161747081505678, 0.059941821851797646, 0.03293903048841223, 0.052438461777543834, 0.03664215012723881, 0.029717012150813977, 0.02550981240347028, 0.030740766087546948, 0.06310507166950453, 0.017269018008523894, 0.0553385105975453, 0.047302098884697885, 0.015409443951812724, 0.07541833009811179, 0.022864294381091194, 0.01648272260002071, 0.06576388323258969, 0.06962308179466956, 0.01544048966494419, 0.11696675627101814, 20.501105131641513, 58.71376299089002, 23.224695036488196, 58.920652327998994, 47.10552023303124, 10.384662324382413, 0.3685189044523624, 1.3881313392231542, 0.8043111764615583, 1.953203430579555, 2.431718250436168, 2.9077324367338613, 2.220263274446611, 0.14942361101988824, 9.397990107536316, 61.11080577296596, 65.6348047717925, 71.5584348863171, 65.66630924901655, 74.10767739818942, 67.63874761519894, 65.64831341466596, 58.49342384646016, 60.36285292717719, 56.95223046887306, 56.12561841164866, 54.25775827900056, 55.80370556923651, 49.749746860996375, 50.062842215261156, 47.814021879626864, 49.86802985591274, 49.41378801099716, 56.69062799023044, 59.819718407046416, 59.96850567479288, 60.31476859123477, 60.63301793990597, 58.43906764061221, 60.6863582518793, 61.93505264097645, 59.64703213784003, 52.35558132971487, 45.8815485431302, 45.19334908454649, 46.67021166893744, 45.71034100747878, 46.30498801508258, 47.25989295590309, 51.88107259811894, 52.236698212162146, 55.51617622375489, 57.06528494434973, 58.70076425613896, 58.614413276795425, 62.801441454118304, 59.881872284796934, 60.29788671001312, 59.36533927917481, 64.57972249677105, 59.52446983706567, 52.32303742439517, 62.86656456608927, 57.769628878562685, 61.33907594988423, 60.23608976794828, 61.9624896203318, 57.6351974856469, 63.42983653468471, 59.57094207886727, 57.22313680956441, 60.935726857954464, 58.29915277419552, 53.99113124416721, 49.98592453618204, 48.32024689643614, 44.77689535387101, 42.5705974332748, 43.691602983782374, 42.90390476103752, 42.37704023238152, 42.8145767027332, 43.38397933590797, 41.2198115933326, 41.95681710397044, 43.16382846524639, 43.660047515746086, 47.51951463760869, 56.728784807266734, 57.83897246083906, 57.5510940244121, 58.40442526725031, 57.46992449606619, 56.606948144974254, 56.282226885518725, 50.511686878819624, 45.14714356391661, 44.94610640310472, 46.135608303931456, 45.555995741198146, 42.064678361338956, 44.59419135124453, 51.32307229503509, 50.60234854298253, 54.398328181236025, 56.510893221824404, 54.17110919952393, 58.1382885286885, 55.69715438350555, 52.81299637209985, 41.40690080581173, 1.0586836237099864, 0.3130278772404117, 0.05432715962430643, 8.835893869400024, 7.3656801927474245, 1.8796610736077832, 0.2530725645802675, 0.22677920127828277, 5.444261075988893, 47.058840105610514, 39.80255726845034, 27.068266753227483, 53.87283255977016, 6.530197205082064, 0.36610042616244287, 0.07477479325907846, 0.09431318394959935, 0.0464189603864666, 0.02847515489725817, 0.021632708451380173, 0.05146776326000691, 0.028775375178684632, 0.025212489849617405, 0.05835747158515358, 0.03233516551253777, 0.10984321875918297, 0.02228115208356852, 0.020230164255706534, 0.042266327166749586, 0.053717614106473424, 0.014348639130231836, 0.08157535576291623, 0.07040927186608315, 0.046206807657595605, 0.07577852165747075, 0.020717865404402538, 0.037453115482123635, 0.03151457043244474, 0.04490559199644674, 0.02991288168085439, 0.03545596256792065, 0.025427473273368615, 0.02512610769049535, 0.04523371511529531, 0.0734553064009355, 0.034579902722109715, 0.039297307450925155, 0.016934298872647267, 0.03796741711877046, 0.03809253842900357, 0.006686855903676441, 0.03652629465044987, 0.04109996213247219, 0.04278204989649596, 0.03497233509176201, 0.030696449816347133, 0.01966570684265706, 0.002831826775124477, 0.016104054915147926, 0.12061033172593003, 0.021912790196497115, 0.07659176229349068, 0.03584073022789052, 0.015496274272370485, 0.036116625302501267, 32.67805234078438, 56.725807728305945, 28.942606641400246, 73.35472353043096, 46.44018819255214, 14.577816263321909, 0.24014276242063892, 0.7487243269720386, 1.6635920419808359, 1.919909739686597, 4.977845664947264, 3.488928166127974, 4.510642347797271, 0.43387355883755996, 11.212786455308239, 63.69617723649549, 67.08061002915906, 70.88340282440186, 66.27329995555263, 75.63864907910748, 68.74263594227453, 67.88241309504356, 60.69107686319659, 63.5101588310734, 57.894011159097, 57.38940215879872, 57.61395785116381, 57.50223305917556, 53.14075746843892, 53.13109274833433, 51.500614458514804, 52.166848644133545, 50.61404112846621, 56.25825335902553, 62.627990322728316, 60.89741706848145, 59.587117933457904, 63.10751968814481, 62.139447350655836, 64.71298894574566, 64.33968128696566, 63.65976979655605, 54.72062933829523, 47.71311890694403, 46.71135733204503, 49.53187880977508, 48.50932475059263, 49.580916281669374, 51.07930091119582, 54.436547756195075, 53.40423876239408, 58.41807511544997, 59.01698573943108, 62.482474311705566, 62.93862242852489, 64.49103378480481, 61.4655057076485, 62.105420789411, 62.881042034395286, 65.57105841175203, 63.29345572379328, 53.928698878134455, 58.57199284338183, 58.45299205472393, 61.11309251477642, 62.54899770982804, 62.472978253518384, 60.34797145474342, 63.76484617110222, 61.596242227861964, 60.37107813742853, 63.532414359431115, 60.21181029658164, 56.49685113660751, 53.40163038622949, 50.277085996443226, 46.30801608485561, 44.61447000503541, 44.49133111584572, 46.170478174763346, 45.179095191340295, 44.524659495199884, 46.32220329776887, 44.187955394867934, 44.19581190232308, 46.84364318847657, 44.045973439370435, 50.73424608476701, 58.73761884627804, 59.73536391412059, 59.4474462539919, 59.962488758948545, 58.652119021261896, 59.74979431398454, 57.308162027789706, 52.04406276825936, 47.5936278220146, 47.73746113623343, 46.16923478341872, 48.20228553587391, 45.33158125415925, 47.54057776543402, 53.69314878217636, 54.46661664593605, 56.662857609410445, 58.13013392110025, 57.23208373592746, 61.83420065910586, 57.78165094314083, 57.877968665092226, 44.97932495609407, 1.2878088773258272, 0.7068419324294214, 1.016045498751825, 10.379888799882705, 2.3002661428143902, 0.7551125809550286, 0.4095313908352006, 0.1897549686292487, 7.001136089524915, 55.49012776344053, 53.66996757445797, 26.520439117185532, 58.942025323067945, 9.650118101027704, 0.33431874768387887, 0.19360172592343824, 0.06573320141122227, 0.04571233237642915, 0.02884935437431259, 0.03869847184227359, 0.06172176585682939, 0.02265225081974941, 0.0674329819758573, 0.05468186216368791, 0.0635887221283009, 0.03505925542765087, 0.07207235681914514, 0.11948749197707062, 0.012090164048957729, 0.04900079543492006, 0.02594481819429465, 0.10916158436767517, 0.004985685368263794, 0.06334945371735, 0.0023565867647243246, 0.10074996194171329, 0.2969359552427646, 0.09952221411250292, 0.14165120469706674, 0.13601837469445122, 0.17238974721441347, 0.18449896195482823, 0.11313990960198064, 0.11477931477730313, 0.17960349157933267, 0.12116807437832318, 0.1849154226722256, 0.12623866479243004, 0.15105108820622967, 0.1870514596662214, 0.10905928098626676, 0.18438023364832326, 0.1318616582260978, 0.28504473848208306, 0.15207793713817674, 0.20085907601300748, 0.20987577766420382, 0.11462569882672642, 0.21414659526799956, 0.18923871729883457, 0.18847842099926165, 0.11976245625485336, 0.21846232094591667, 0.19573111327425127, 0.1905471188647132, 37.25149869918823, 72.60420937691966, 36.91743435398225, 70.75543157515988, 60.86135871948735, 19.604323833219468, 0.8464374933992663, 3.147508886552626, 4.807420642145218, 6.944685338004944, 10.592999996677523, 8.994917542703691, 5.7916335328932735, 0.3445374106447543, 12.011396711872472, 64.59874991447695, 66.0333921063331, 75.15789201182704, 66.42551145245953, 79.80628505829843, 70.82537528007262, 70.40899999680059, 63.58335418085899, 68.70955467224121, 61.49636691616428, 60.60354132806102, 60.4762408041185, 61.68471520946872, 56.9957923120068, 55.894818305969245, 52.59547741182389, 55.82187006550451, 53.87467215138098, 61.44444257982316, 65.92966894949636, 64.76246964546942, 65.60125281733852, 65.56872067912933, 63.01435162944179, 66.0232880807692, 66.26601219177246, 66.34239642850815, 58.53814671116491, 50.59463324085359, 50.127416195407996, 53.21592184805101, 50.96605031721054, 51.85538891823062, 52.769140351203184, 55.45030001671084, 54.82876123920564, 60.58611031501525, 62.03268827930574, 64.49428935204783, 62.67578440327799, 68.18108589418473, 62.0552497525369, 63.869342034862896, 64.4208037468695, 70.73674540365897, 64.36703981891756, 54.151332609115116, 61.33815419289374, 59.40078573842203, 61.53228798220235, 64.17563599924888, 65.87052745203819, 62.23344302946522, 68.0064384398922, 64.20543816781813, 62.30071560029061, 65.60614793531357, 65.34569863350161, 57.98391188344648, 54.63641605069561, 52.83759355545045, 48.16992990432247, 46.82057572949318, 46.92545990790091, 48.5132118194334, 47.58286876063193, 47.32990726347893, 49.14491738042524, 46.130921071575536, 46.162229430290964, 48.71942650887274, 47.28440384710989, 52.19925134412704, 61.59689726368074, 62.15419546250374, 60.885449917085715, 61.51268789845129, 60.11724587409728, 61.73163852384014, 60.933875499233125, 56.38474587471255, 49.92645355962938, 49.35563102845223, 50.72593458237187, 50.74411869049073, 47.27396249771119, 50.48925092143398, 55.680276424654075, 56.44881779147733, 60.0860159627853, 61.22733939078547, 59.52743907128612, 63.92952688278691, 61.242456205429576, 58.879341925344164, 46.851821330285844, 1.5819962010268243, 1.089462707600286, 0.2624848280702868, 17.521935547551802, 19.294178101324267, 4.783689812306435, 1.0918889386999993, 0.6665730416294068, 10.966179197834386, 61.47065577968475, 55.263865840050485, 36.525495436883745, 69.797376971091, 13.58055756938073, 0.5083122080372227, 0.2825481805109209, 0.23028500348089204, 0.21629450662482172, 0.19457030620786453, 0.16956378675756917, 0.11912980552522406, 0.1684533576330831, 0.17047115661684545, 0.14631741560034214, 0.13202377775263402, 0.19173642440188318, 0.25646742192968247, 0.24585554135903237, 0.20716525133579008, 0.09011603336060241, 0.11751267818673966, 0.24332930514168358, 0.16869864366467924, 0.10767700556184977, 0.1749782510582478, 0.17990833328616235], [0.020351305739173008, 0.05095131657717209, 0.04456990758978552, 0.04338948484209757, 0.043328488921566356, 0.12242356991215099, 0.04632345603538617, 0.03592695342376828, 0.06115123336654037, 0.015371428753790117, 0.10456517173518097, 0.03763033077120781, 0.04797047995511563, 0.0638393363014104, 0.07244676697037875, 0.1411760616446695, 0.03427010059597031, 0.07778530429688194, 0.07892464557963033, 0.05278222458136659, 0.02672590803535235, 0.06759600548614418, 0.06232644288590359, 0.0885874274817686, 0.05757304351596583, 0.052698606084431374, 0.08245202081818735, 0.1921350199488863, 0.16156886253626118, 1.7961033121232064, 50.194363209509085, 36.49617179747551, 35.69107394064627, 65.66391660321143, 26.288213229948475, 0.43925308952889136, 0.9350620991280003, 0.3355969500637824, 1.5541780163203518, 4.061320871114731, 2.882544691524198, 1.7424363402589675, 0.2374800706222173, 0.02338153396492764, 19.779861665541127, 66.41920428122243, 64.596702437247, 71.3697845705094, 68.89230574330976, 69.36584564947313, 66.55527914724043, 65.17103941209855, 56.017321771191014, 57.941989591044766, 56.46060451384514, 54.126786416576756, 51.71594865860478, 52.207519700450284, 45.96118050236856, 47.531838724690104, 49.00712451627178, 58.953149164876635, 62.90952236421647, 61.50377627341979, 60.23732531455256, 63.66468452638196, 64.41401412410121, 63.02325148736278, 63.17858519092683, 64.34032455567392, 64.05444652803483, 60.41155699760684, 52.84282599726031, 45.954916477203376, 48.155091577960604, 44.634748658826275, 48.18552917049777, 48.28515345050443, 49.546881875684186, 49.884476354045255, 51.36001317731796, 53.53222177874658, 56.51093244552613, 54.05853717557846, 52.591339311292096, 54.09127719940678, 56.44279695326283, 59.46085291524088, 64.95569344489806, 59.33644317811536, 40.22208221497075, 60.46193984247024, 61.51698289378997, 62.6828525143285, 60.86950940470542, 61.81849941130608, 64.63183902925061, 62.864532778340006, 59.19487307148596, 56.78113275958646, 57.548148324412686, 55.02036509975311, 53.94887555030085, 49.543940098054954, 46.99383074237455, 42.466988025173066, 43.029593190839215, 43.75876965061311, 41.67797580842049, 43.67832183837891, 44.846136954522905, 42.53742594872752, 42.709253218866166, 45.11870638016732, 46.26363838872602, 45.75713880600468, 45.52806454320108, 53.147507867505475, 59.59090694304436, 61.10209026644307, 58.38367592903876, 58.826923370361335, 61.82566165924073, 55.8070082049216, 55.10436657936343, 47.97558430702456, 48.18314829180318, 46.310377351699344, 45.9526179682824, 44.36569759922643, 48.32029788724838, 47.78492966005879, 52.71744743470223, 53.083573233696725, 55.432017849337676, 55.42450258808752, 60.85138413213915, 53.93399015549691, 55.348083050020286, 11.86118954612363, 0.12003784954187371, 0.3305787983680925, 3.4439417671772743, 14.132725308018347, 1.7358118247601295, 1.4668577212479808, 0.10469061097190266, 0.1495472882543841, 20.17098472964379, 52.47089509041079, 22.040449111692368, 42.99036164437571, 40.85037531391267, 0.4504535094864907, 0.07584746190977674, 0.011735456721526722, 0.08392505467899385, 0.03481540198047315, 0.06539760127423272, 0.08671448040272921, 0.04179658503421853, 0.05810797206997391, 0.04644854287166269, 0.017000119231881636, 0.011977588386094619, 0.1052320282906294, 0.0719426811162022, 0.019008353607909336, 0.03286418369821003, 0.05423889863455007, 0.030014621987638455, 0.032880715875616, 0.03246993186973757, 0.07777387426505167, 0.06320447157767993, 0.03819684129989436, 0.044999177297276836, 0.031872136225443215, 0.07069529845349251, 0.018017964715498592, 0.07563995167372689, 0.12649227053888384, 0.035252964589744806, 0.08818029005440974, 0.114290481733699, 0.04989573934806451, 0.03467549134286181, 0.05860969454290406, 0.03043409343057823, 0.06542780046020785, 0.040205428076367226, 0.07058386330402668, 0.039517235972227595, 0.08998694754536114, 0.03450203754548584, 0.0683106659280677, 0.03588394524769918, 0.06202787160873414, 0.07537837861286056, 0.05494040534681371, 0.08710906164900911, 0.061172369732371265, 0.06230453277126916, 0.1284957206958244, 0.2326071845187295, 4.753363517022902, 65.59519667779246, 34.04865987839238, 48.20732185917516, 70.62404786386799, 28.713210744242517, 0.9093930055537532, 0.5400070427886902, 0.7656999773556187, 1.910907654992996, 2.6932150702322684, 6.193713247776032, 4.511603328489489, 2.1153464913368225, 1.0037625352701833, 26.900222609120032, 68.47211791623023, 65.23336195176648, 72.30394409548852, 70.30370004715459, 68.94135105994441, 68.65379425787157, 65.22363839610931, 57.768397254328576, 61.21770604964226, 60.048349442020545, 57.03533372571392, 55.26814122353831, 53.88206974152596, 48.9971616960341, 49.784546129165165, 51.5514366088375, 60.4790884448636, 64.41722262290217, 62.66457819169568, 64.04262450433546, 64.36407450706729, 65.54643377181023, 64.81046376689788, 64.36794980879753, 67.51800137181436, 66.21664524078369, 62.545016504103145, 53.54768376196585, 48.256229892853774, 49.05407136486423, 48.150388656123994, 49.60386606954759, 50.22826425490841, 52.03218975374776, 54.007216884243874, 54.52740161649643, 56.737449322977376, 61.90070836774765, 56.83929758687174, 58.26734627446821, 60.00495233843404, 58.58427378439135, 62.26374726141653, 67.069227310919, 61.93846510302637, 41.84227997256864, 60.74424066851216, 60.69483841619184, 62.393605170711396, 61.25544317307011, 63.433790283818404, 65.87281811621882, 65.65617384449129, 61.16717807708248, 60.03438188183693, 61.346147983304924, 57.39695272138042, 56.22150075051093, 53.08046671652025, 50.135170721238666, 45.25973519971294, 45.78940030067198, 46.00640543045537, 43.02700442652549, 44.53785827082973, 46.896885441195586, 44.06160016213694, 43.34843481740644, 46.56151494672222, 48.66145387772591, 47.91812942874047, 48.23825759272422, 54.69179207278837, 61.034954978573715, 61.676752798018924, 59.85061491689375, 60.56921274431291, 63.9761991654673, 58.06723479301699, 58.05568341285952, 50.34220518604402, 50.402813649946644, 49.40517840846893, 47.95579594950522, 45.30690954577538, 49.24860915830059, 49.89538838786464, 56.46699013248567, 56.18331255451326, 58.92060133718676, 58.605093725266, 61.61273971680672, 56.133804398198286, 59.00945086633006, 14.222423049711413, 0.27598394080996513, 0.9259386048201592, 8.213042078479644, 9.58089513163413, 1.5555955854154404, 0.17881616769779116, 0.12682042430124937, 0.25994435793930487, 24.059867666613673, 62.22269965756325, 28.740077018737797, 41.96902351994669, 50.097449287291504, 0.8389002913909575, 0.025827106869509144, 0.021826702981225906, 0.12285057199938644, 0.04524033411496109, 0.0437000262430839, 0.04388625455659725, 0.06521534895704639, 0.08563265700133578, 0.039892228350283644, 0.05256196664225671, 0.020347226320976214, 0.15142895341400178, 0.021414827300055374, 0.0320224886414625, 0.02773341899287076, 0.048173163837242516, 0.02342649758042347, 0.06517045620468355, 0.05936001254726322, 0.06393159243969188, 0.06730740484330924, 0.07688885119052664, 0.14202504028235713, 0.2142231427733937, 0.21736205014730656, 0.2166371624315939, 0.20276003126655856, 0.3291037726786829, 0.1108879405224035, 0.14165664392132915, 0.2084110788400135, 0.2213078166448301, 0.22519655555727022, 0.2313565919476171, 0.13906515233459013, 0.2039281008464675, 0.18666032581560074, 0.2397358624805366, 0.11953124325842628, 0.18140635693505888, 0.22524509488815264, 0.1316423272533763, 0.16113170212314976, 0.2536744798623747, 0.2833033593431596, 0.18295354810693573, 0.17994588691621058, 0.23338364527350475, 0.21917561009045572, 0.3679588941797134, 0.31707962434138026, 5.296798588768129, 73.46218078367173, 48.35532465288716, 52.315161305089156, 75.6848624444777, 41.43005455693891, 1.335694643278276, 2.809122579713022, 2.6756484902674154, 6.076793766790821, 10.008094195396671, 16.80147655548588, 4.408289569039499, 1.4405535714280222, 0.3777377000979839, 24.182508414791478, 72.47505357188564, 63.32311668703633, 73.75487589067029, 71.14977882754418, 72.8714483014999, 70.2658256407707, 70.53011494298136, 59.440444823234316, 63.91430416414815, 63.89575919797344, 59.71011953969156, 57.2889502586857, 57.51993471576322, 52.19415226290303, 54.45263339627174, 52.60684051821309, 64.78005363095191, 68.23441443904754, 67.25705392899053, 66.22298379098216, 69.50135569418632, 68.4146551932058, 69.53648444144957, 69.06924386178294, 70.8498744041689, 69.24618982499646, 63.772486948197894, 56.859999856641224, 50.45580879334481, 52.332423656217514, 50.740368904605994, 51.38286882831205, 52.90121832201558, 55.6488896185352, 56.760108855462846, 56.74089708635884, 59.805727312641764, 62.533931885996175, 60.02584680434197, 56.412833967516505, 60.55332322274486, 60.81658878634053, 64.60823028318345, 70.11576360271823, 64.56655902247276, 40.05403610967821, 58.678704846289854, 62.992951177781634, 63.765144271235314, 63.79741361064296, 65.94249509995984, 67.8342777682889, 67.36068294894311, 64.78026543894123, 61.15894502209079, 62.61441499956193, 59.334172125785585, 58.81646633148194, 54.54100047388385, 52.224578088329686, 46.79210716678251, 48.137907674235684, 49.358741467998875, 45.35375833511353, 48.293151163285785, 50.631970282523866, 46.54500176829677, 46.79365650300057, 49.62014390576271, 50.60730641888034, 50.51109067855343, 50.55382490158082, 56.65504032565702, 64.44387512822306, 65.94011814363542, 62.1343953378739, 61.77983660851756, 68.40774397696218, 60.29308965129238, 61.947816033517164, 53.91651599637924, 53.96510239570372, 51.56128960271036, 50.7132064911627, 48.39292449335898, 52.13968230832008, 51.34696345175467, 59.631523086178696, 57.29460239410401, 61.33799337571668, 60.166765797522764, 65.60035459456905, 57.14990615844727, 61.905791759490974, 14.802225847398082, 0.20902083886246528, 1.121648941789904, 9.034037301617285, 29.47155983217301, 9.58219539734625, 2.3318998131059834, 0.7957023706647658, 0.32664604004352327, 31.875872727363344, 65.6010998449018, 33.994468412091656, 53.434519460124356, 58.26591853172549, 0.8934637699877063, 0.22736041686467587, 0.14606944826101104, 0.23565593866571305, 0.1666385719492551, 0.16367125294862256, 0.1969080081870479, 0.23107860928341267, 0.09507040057571665, 0.13346025389769386, 0.07433825337718572, 0.19302368194105166, 0.2355415157733425, 0.1597170901274489, 0.10602325922058475, 0.12635279657138934, 0.13215205151467554, 0.12492561307285102, 0.13924381936029082, 0.1244884679814981, 0.14107496868218147, 0.18556364030847627, 0.17463060035820932], [0.034387419300694624, 0.031059778505756013, 0.08490271310532287, 0.021248017400202733, 0.03747260858935695, 0.025122740734068137, 0.06844430230557919, 0.08587676325752851, 0.0799047095220416, 0.06216437698552205, 0.10341425486389669, 0.051222599802478674, 0.04549031243509343, 0.06158460547486621, 0.04056160916544257, 0.025139493161752343, 0.03601452876483241, 0.07787161176243136, 0.10311106790698345, 0.043785743820931644, 0.012744311205742341, 0.05427167570639042, 0.031270188384599266, 0.09769895549623236, 0.056153792857883446, 0.017719349388273496, 0.03922417669767334, 0.04869913682341576, 0.03438587946396682, 0.10292600404711501, 13.80988580565299, 62.11161028954291, 30.358541088719523, 58.864648726678666, 56.55416873193557, 8.390183179609238, 0.2401284059329379, 0.289124769549216, 0.1897897030557356, 1.8082822715082478, 1.089222217279096, 5.011488814507762, 1.0530875046407024, 0.21509562498859822, 1.6868152926045081, 40.248326793793716, 69.423614317371, 68.38570810133412, 72.8745077502343, 70.79084273307555, 69.85896602753671, 61.679588671653505, 64.55678447600334, 58.317023092700595, 59.36261323190505, 54.20438266569569, 56.885781595783854, 50.14014428661716, 50.62034437733312, 49.764259630633944, 56.67122402498799, 63.374582106067294, 63.52877047754104, 64.26867854210639, 62.953692174726925, 65.28994998624249, 65.12105272662255, 63.411628892344815, 66.27499441946706, 64.47259080025458, 65.3492013100655, 66.19052225543608, 60.091420988882746, 47.23898280051447, 46.815323675832445, 46.164045487680745, 46.897120783405924, 47.0675556121334, 46.88749528700306, 46.67986462193151, 48.91680802068403, 48.17337766770394, 47.844596755120065, 50.69364563111336, 49.05702098723381, 49.29488528159357, 55.883000204640055, 61.881206343250895, 62.56818202234084, 61.70158140120968, 57.30790707372851, 61.98184259476201, 63.60373481627434, 61.221047909029075, 60.53980673513105, 60.162396277150805, 60.21152004118889, 59.843056509571696, 59.7247499804343, 56.707909953209665, 53.948702966013265, 56.46696659826464, 54.04760160753804, 52.7250607552067, 46.80208959887105, 43.05739887299077, 45.03549329696163, 46.094407727641446, 42.00061036694435, 43.53290388661046, 43.456947188223566, 45.13241114154939, 47.00732761813749, 47.94630381368822, 47.19717033447758, 47.171902425827525, 45.822975789347005, 49.40713567118491, 58.21712816915205, 59.24939009451098, 59.96081782925514, 57.96330767293131, 59.003888945425714, 59.738497887888265, 57.58645026914535, 53.511590111640196, 46.44157671159314, 45.805736972439675, 49.566387822551114, 48.0277753645374, 51.805951364578746, 53.83016893940588, 53.18780237628568, 56.5244528555101, 59.51734289046257, 58.506908955112586, 59.57070281428676, 54.3761864016133, 33.060061777791674, 0.8480687703817122, 0.192263646111373, 0.3923544125451196, 12.793976241542449, 5.097566698828052, 0.6487593523436977, 0.135231786257317, 0.47926714884177335, 1.3104514945899288, 38.780917121518044, 43.98996199330976, 30.273533521160005, 51.74520169534991, 13.046133652810129, 0.24544189984519638, 0.037669071837538676, 0.024999599761119293, 0.1317979809978316, 0.04005319108405421, 0.021273620058632186, 0.03964031948858211, 0.011342805059206103, 0.04365871112132746, 0.08083214322405477, 0.038841814553785714, 0.01958278357051313, 0.03615592561301686, 0.01562167999274548, 0.017954500076631387, 0.05619159163606744, 0.03233912235666667, 0.056320937921202956, 0.02829059474019995, 0.0907311253550072, 0.04504584354318438, 0.036340564294087316, 0.02668362764281131, 0.03809220901119613, 0.02130042164466314, 0.014065654869491776, 0.04160053164307629, 0.03699942672204587, 0.06018538801600376, 0.01400354141820102, 0.07357386616809715, 0.041769166747408534, 0.03418946601150017, 0.04373248538843567, 0.026440406218171123, 0.05267946920808285, 0.0635836199827252, 0.04361470703095679, 0.04334517431655719, 0.01752357561922362, 0.06612533117614447, 0.049099433085610794, 0.028504019175025246, 0.019820075474619385, 0.042225532984781655, 0.07934102968823525, 0.04988062060287884, 0.08572304771552164, 0.043648870721940077, 0.02978753437468362, 0.0474681522727253, 0.07773127211558242, 0.18597443197523394, 23.05022801122358, 63.31484833071309, 32.52482102763268, 73.32345439541724, 59.456899166107185, 10.7059250339385, 0.3481710882436845, 0.0704611819838324, 1.1846967522175083, 1.6076431086947842, 3.6278634205941236, 4.834690920768246, 4.380917799088263, 2.101940320384118, 1.5246687997733395, 48.104406710593935, 66.85513650217365, 68.24127858684909, 73.68900360599642, 74.04547645199683, 68.9227198016259, 65.0993424077188, 65.41333206238286, 61.01347215713994, 62.1499946040492, 59.967819260012725, 57.07498104341569, 52.267402525871034, 51.25584679265177, 53.33407932712186, 57.6882436198573, 64.16357863333918, 65.7108477623232, 67.96356693390878, 64.99263040481075, 67.32364008503576, 64.7244304995383, 65.46568001470258, 68.45026246963009, 67.80338518081173, 67.12080647868495, 68.22476540842365, 62.55032739331646, 50.800785172370176, 49.53963333560575, 49.02466535568238, 48.626787970142985, 50.600771750173266, 48.802682738150324, 49.733167002277995, 51.30064418238979, 50.89984463107202, 50.75989054095361, 52.152763412844756, 50.21073518260833, 49.369884921658425, 55.83574348880399, 64.09795345798616, 64.99234014941801, 63.75512261544505, 54.6099086730711, 62.12988068980556, 64.1391775684972, 62.8926012592931, 63.30798810528171, 61.87444025470365, 62.575697283591, 61.471550080084036, 62.801315938272786, 59.248170237387384, 57.93358002939532, 57.79819550052766, 55.481690745199884, 53.15474071810323, 48.8807261374689, 44.35724489150509, 46.3134721017653, 46.335837456487845, 44.03036240608462, 45.7338007034794, 45.612262141320016, 48.0263436994245, 50.132742774102, 50.26875488219723, 48.077612999946844, 49.76744067284369, 48.12212013429212, 50.93731111095798, 60.415091053132095, 63.251886444707075, 62.02610261978642, 59.172131169226866, 60.9966883351726, 61.48295241017496, 59.06727444741034, 52.7902780040618, 47.92704497614215, 49.054628341428696, 51.11362949494393, 51.32144451141358, 53.441061973571784, 56.07326653695876, 54.9431767771321, 59.63805775488577, 62.12140052549301, 61.726257031963726, 61.64545228404384, 56.73574701432259, 39.22983631010979, 1.235694673753554, 0.24690236986404468, 2.6677054455203395, 8.32482962839065, 1.9900343639235345, 0.5100317996355795, 0.12831629524307867, 0.6916878552686784, 2.2083292180492036, 46.664818409950506, 56.83493198886995, 27.873058665183287, 57.19761394685315, 18.56973398116327, 0.3568470033426439, 0.12934976317469152, 0.004110816789175114, 0.09958702515089705, 0.07600203547025881, 0.03540726235857414, 0.017396244145328962, 0.08366437794099893, 0.05202223854740301, 0.041050246856626005, 0.04669037001628069, 0.09322643460285279, 0.04715088078932417, 0.031866624222828016, 0.03904327269523375, 0.050539563470069444, 0.023236404353332137, 0.038915351333637396, 0.056005976192893527, 0.04875399254923386, 0.038957991787502845, 0.01559963581272431, 0.06802841615412505, 0.1664250019577242, 0.08818974357939537, 0.11017956966233831, 0.12357529117575577, 0.1316075928268894, 0.16422766260802746, 0.2496251382774884, 0.10098793183363254, 0.15141134871350181, 0.19823255888637037, 0.2216478064656258, 0.11695262194881517, 0.08547634442126559, 0.14322822733271506, 0.12639995694400805, 0.14955517896000417, 0.10831194689437267, 0.20099579206397458, 0.15846075189690437, 0.05625004797512966, 0.07640096809594862, 0.28265776172761, 0.15186709441965626, 0.209692468145682, 0.11077529495401729, 0.12938416052249171, 0.09412790558511212, 0.20695577225377484, 0.2142081121283193, 0.2974666396696722, 25.607201514705537, 80.50865604031472, 44.960811368880734, 71.43025182908582, 70.5054432345975, 16.30830224483244, 0.7241128024555022, 2.620935348733779, 1.9839022284553898, 7.491237713444618, 7.811457562831141, 16.97168977029862, 4.946466703568736, 1.2359209454828695, 2.7134226310637692, 48.358580220130186, 75.31153125147667, 69.31243081246653, 77.62842039908134, 76.26091741746473, 74.21502482506537, 66.10765826317572, 70.23297186820739, 64.82118752694899, 66.83596395677137, 59.992263470926595, 63.16445289119598, 55.457321059319284, 56.0919487860895, 56.90766842134538, 61.47293467675487, 67.7366578194403, 66.5719021520307, 72.00977417730516, 66.53698521275675, 70.71154809767201, 68.75775275691863, 68.18363543479674, 72.92698121839955, 68.38304873435729, 71.3914046748992, 73.10741024632608, 65.29014218238093, 54.32354819390082, 53.076744387226725, 51.871584384672104, 51.582517470082934, 50.84372335864652, 52.17311266929873, 50.56665889678463, 53.34911377199235, 53.356507439767164, 53.13597609919887, 54.741143334296446, 53.34496390435004, 50.94704643372567, 58.43619646564607, 66.65510346812587, 67.30847620194959, 64.83837143067392, 62.81253783933578, 65.69480134594825, 69.05721003009428, 65.14656774459347, 65.97763953670379, 65.04960283156365, 66.4560902503229, 63.70859546046104, 63.88552573419387, 60.83090935983966, 58.94013866301506, 62.019481658935554, 58.8730739778088, 56.01732569356119, 52.238267160231075, 47.567261649716286, 50.627122232990885, 49.26065475709977, 47.71005161346928, 47.63178856142106, 47.82365522077007, 49.93469053699125, 54.45643417296871, 54.82975752122941, 51.59152715436874, 51.690625836772305, 49.5639677201548, 53.11363820106753, 62.504729840063284, 66.34506364022532, 65.0310068745767, 59.96462645069246, 62.71797733922159, 66.10858394253638, 62.1513831230902, 57.61617006794099, 49.632028687384825, 51.709610108406316, 53.8768216102354, 54.307242901094504, 56.556384871082926, 58.90688873106434, 58.07013342457434, 62.4014538334262, 66.8004665067119, 63.486914865432254, 66.54833655203542, 59.757803793876406, 38.91764702335481, 1.3587027764128101, 0.250741359026682, 2.9004914962476303, 24.991575710235107, 16.22146293040245, 2.430015451485111, 0.8732114696214277, 1.685330185198015, 3.2527014613151555, 53.63432499670214, 56.41540311997937, 40.29366154824534, 67.60848260694935, 22.225126066515525, 0.40251607856442856, 0.18307351747587805, 0.22679391016642894, 0.29275378933356655, 0.12906563648533437, 0.14155876852812307, 0.1392557396883926, 0.2648134289249297, 0.1090133463543269, 0.13537236339142247, 0.14396641433479326, 0.1836898505327202, 0.12942330761542245, 0.15183473486573468, 0.08365639530482792, 0.15699157911923625, 0.10446444649489657, 0.18315668398093793, 0.15949170706012558, 0.21061425577969323, 0.12768133092791806, 0.10478352977623863, 0.11157773375030487], [0.022306743250679106, 0.013723806327869816, 0.049792420900156426, 0.003214967695267631, 0.06810222106475024, 0.01991929343691276, 0.048976330417058164, 0.04039072176261295, 0.031963413686401425, 0.057144486270244085, 0.05070154893121893, 0.04984031671718244, 0.018157687661568486, 0.03541550163419978, 0.08967361758433043, 0.06777606679186707, 0.06184662669716824, 0.0748051533235177, 0.028669997869480043, 0.03765731621834059, 0.035628719225285516, 0.0712771728755005, 0.029848631801864797, 0.013035275229823687, 0.049023088593516624, 0.11653115867727226, 0.00865265571196834, 0.023624588765444297, 0.04005202279996969, 0.0860216764492854, 1.3969534851851002, 48.3191760893791, 43.979991328331735, 35.23417272875386, 60.44148468202161, 30.181726524906775, 0.6771851979917096, 0.26960343963676886, 0.6343407195902641, 0.1525838309598546, 3.58480584717566, 3.957939450779269, 6.6190227097080605, 3.732390908464309, 0.195834152100067, 2.963779429274221, 46.12064446172407, 68.08509765132781, 73.59921270801176, 71.95255464123142, 69.49112615277691, 69.34455502417781, 61.52016393599972, 59.36152673536732, 60.78364087689308, 57.116248299998624, 54.69844049023044, 53.01335496287192, 51.112319423306374, 52.00587457226169, 63.902792007692405, 69.03301685087143, 65.39419481831213, 63.137463062040275, 65.4652956224257, 62.39389934847432, 67.09032966244605, 64.55514100290114, 68.46154320624568, 66.47924007907991, 64.0865275936742, 64.90596563585343, 60.65200221153998, 49.88708080783967, 46.26285783706173, 46.99787078365203, 46.55361529319517, 48.0495092176622, 48.91242281083138, 48.12900389394453, 47.354982975990545, 45.53600342042985, 46.33097371747417, 47.010292929987756, 51.50434855491885, 53.54005475198069, 62.60862165881742, 58.47780104606383, 67.15824157960954, 55.12448049360707, 50.542583388666955, 69.49692341589159, 60.27878868964411, 62.28753251414146, 60.06301518409484, 60.608812993572606, 60.58026206108832, 58.7910258385443, 57.77385719360844, 58.046293258667, 56.68716453736829, 54.830067388473026, 52.71937724082701, 49.55719770923738, 44.436139445151056, 43.498936160918205, 43.23476452981272, 44.16306011138424, 43.26371946642476, 46.214463633875695, 42.12476907237884, 46.07935759329027, 50.34845352172852, 51.749759489490145, 49.98080976547734, 50.34962238803987, 46.06946537571569, 47.832276590408824, 51.04756893650178, 58.61403672925888, 59.78264416417768, 60.809340246262096, 58.84917105397871, 60.599575811816806, 59.78382479759955, 58.39003409108808, 50.42727355034121, 47.36833080168694, 47.51904395318801, 56.834649578217544, 55.467640815242646, 56.336653694029785, 56.71066737944081, 59.31481915135538, 57.13964131570632, 64.19996253905758, 55.558922213892785, 57.15310289013771, 11.073043192586592, 0.09983119269412372, 0.13692847182673795, 0.540253171517003, 8.51215418308012, 1.5616730528493084, 0.24755493887970526, 0.3266261830445259, 0.12011926936646623, 14.510682936637634, 53.43106777437272, 18.16279592052583, 39.761533198818086, 37.77862994901596, 0.3069482954038728, 0.06613551248465815, 0.016639958316039656, 0.06006925291712246, 0.04139070399105549, 0.05381759624147127, 0.046548747172158574, 0.04609899993445124, 0.036584616924125346, 0.007622934907915132, 0.04471465990307831, 0.028024384932171915, 0.07811679820259733, 0.02992105392378665, 0.06018940231672699, 0.050506372710749994, 0.05845387991998465, 0.046221271397606026, 0.07545193837534997, 0.01517123753024686, 0.011233044769464722, 0.06865831662810619, 0.10512986280504735, 0.0563802216352234, 0.07818351679992291, 0.052887075205123237, 0.07072080918137105, 0.016336449602198218, 0.023969146385488492, 0.0990916573772988, 0.05712657896501403, 0.07303216539683842, 0.041254072209760066, 0.011020087648273237, 0.032169012533080195, 0.040531432962105166, 0.03685169815716725, 0.032123303897078, 0.016908414676905643, 0.021913833991293947, 0.0311531646237258, 0.03801451237391561, 0.06433728196087383, 0.02835636913415886, 0.029063301664146206, 0.0992647932481862, 0.03442897957058684, 0.06985555883617171, 0.046347488213570855, 0.06483183768127235, 0.031239887691974163, 0.05004026949585927, 0.07613057736307383, 0.07024668502591311, 2.291126039720351, 62.545749987325365, 40.27446154625186, 46.30931046701247, 72.81452686555924, 31.83781396958136, 1.0528503238193452, 0.34810238547863503, 0.226695912199155, 0.6492141634225845, 1.817805786286631, 5.281089496228003, 7.0465855733040845, 4.6695272672560915, 0.353615491260444, 4.039656640060486, 55.112450584288574, 69.69601508109801, 74.12120957528391, 71.12573469838789, 72.74945474440052, 69.70226733915268, 64.2416141879174, 63.05312425859513, 62.090543239347404, 59.87125835111065, 58.67768110767488, 54.39670039761452, 51.03707267392067, 52.670602567734264, 64.48334986163725, 69.63612048856675, 67.86025954831031, 66.28778134622883, 65.9770590259183, 66.27342547139814, 69.47355393440493, 66.30472598537322, 71.44468615131994, 68.23367703345515, 66.42881408814462, 68.96252401413457, 62.8899379699461, 51.434632347476104, 47.950885142049486, 49.821255591607866, 48.400427987498624, 49.41407434401974, 52.3103799358491, 49.51311026850055, 49.59406406648698, 47.774958995080766, 47.90298907987533, 48.83253589753182, 52.82014293055381, 55.67147854835757, 63.74763088841593, 60.85856206955449, 66.85879215117424, 57.33301808757167, 55.06084395993141, 69.42464197835615, 62.03772852497717, 63.542843941719305, 61.22458980929468, 63.25667565868747, 61.154795154448486, 60.43871156630978, 59.18508675790603, 60.37919744368523, 58.72787960114018, 59.19511625843664, 54.43329218895205, 51.88859962647962, 46.68215920848232, 46.611587924342004, 45.72073921080559, 47.1163224404858, 44.53367310185587, 46.9054126739502, 45.43550445187477, 47.611454994447776, 50.806829544805716, 53.054049553409705, 51.12122320359754, 51.7496104394236, 49.67166423797608, 50.59800255683161, 53.48621629899549, 62.760562512182425, 60.89066666941489, 61.80197446577011, 59.56581946342223, 60.99998312611734, 59.24394192234163, 59.53671155437347, 52.41644082530853, 49.53258875877627, 50.15670845585485, 59.376455276243156, 58.03373775174541, 59.03908829535208, 59.55395429365097, 59.73455198349492, 59.412701899005526, 67.36431506372267, 56.907837083262784, 61.92758444816836, 14.14996510551822, 0.09472714722036354, 1.2923876316316667, 2.9292937055710824, 3.368082882896547, 0.9567757275316023, 0.440216000762678, 0.21889535980599545, 0.32809964591457, 15.674467817429575, 62.042906053604625, 24.298645873223585, 39.461271839757124, 48.332414088710664, 0.9123703909497108, 0.07058629180274664, 0.029473091670942884, 0.01932330192968009, 0.05952192139962028, 0.01747979369435099, 0.03942209934335082, 0.040650119133774316, 0.033802660557651715, 0.025848817801283255, 0.05478792703680454, 0.009791480842977762, 0.08365362972742127, 0.04247121355165878, 0.04845694195659411, 0.05034501927213804, 0.02709061568302493, 0.018927734345197678, 0.03128123920290701, 0.05019922890970784, 0.027361353070685462, 0.008699839067224775, 0.04781921206402683, 0.031323714947868744, 0.17596475780010226, 0.17005141704313217, 0.09463396028525407, 0.08587178368602069, 0.1726599311035487, 0.184079191737598, 0.13941468761092232, 0.18678424819823236, 0.15532049620824476, 0.13073396147979846, 0.07997903537245528, 0.17702148416109625, 0.14681492842012836, 0.12292731868764087, 0.1261078476184799, 0.23174706696262284, 0.17934760289086452, 0.1038186113920904, 0.12007826834075874, 0.16606955248261654, 0.15454657886537815, 0.2589748889928864, 0.13491195987068838, 0.21146194738966806, 0.11428422279535763, 0.12119853403419258, 0.13800497857793687, 0.15672392332025115, 0.1537149751018132, 0.2658875761253219, 2.7714021263584017, 70.46737270970499, 58.230393625074825, 49.351559608213364, 72.29479712824669, 46.14714791697841, 1.6303618444550423, 1.2381300979083585, 1.5538633686880914, 1.9942482152292806, 10.31202297056875, 11.749193130000947, 15.412015165052107, 6.964829650617416, 0.25172570540058997, 4.497522509867146, 53.373726644823634, 72.3984496824203, 76.56852537585844, 76.42590015165268, 74.17949599604454, 75.15069838493102, 65.73323665126678, 64.64208818251088, 64.56224833765339, 63.58657052440029, 61.48126186863069, 58.332618436505726, 55.205085200648156, 56.38209043010589, 67.76282002848964, 73.87901106188374, 69.8946439066241, 68.83642765783495, 69.52434078339608, 67.8157014231528, 70.60694632991668, 69.09269179067304, 74.89849782759144, 70.48084997361707, 66.95410574636152, 69.05510763968192, 66.09182757716026, 54.86847523720034, 51.15781891730524, 52.47097746018441, 51.425952142284764, 53.199028199718846, 54.83389169939103, 54.15654936144429, 51.965948766277684, 50.098308286359234, 51.45036105186709, 50.63017775935512, 57.35484999995078, 58.08928243575558, 69.63215104995236, 62.244810058224594, 70.05615926557972, 60.145224140536406, 54.52801742861348, 72.34286969707858, 63.963639736175544, 67.70667522184311, 64.73773910153297, 66.33628537577968, 64.94993148311492, 63.10725296697309, 62.13912963867188, 62.61227338544784, 61.49324470950712, 60.89049016275714, 57.71859492025068, 53.413534779702466, 48.630569134989095, 50.5220615479254, 48.20437223680558, 49.16634136630643, 47.64046092187205, 50.57204431103122, 47.99218769996397, 51.51399758554275, 54.95023704344227, 57.25871662939749, 53.87525658453665, 54.91994457860147, 53.37393453044277, 53.234666855104514, 55.92303975935906, 64.19852695157452, 64.62328826227497, 65.77477847376178, 58.90625330709643, 64.3782695647209, 64.52056923220235, 63.39788490726102, 55.70342625341108, 52.00005377492597, 53.452668266911665, 61.52598473333544, 60.687468282638065, 60.68285557531542, 61.796679266037486, 62.67246215574203, 60.87405543173514, 69.29297585641184, 58.90466474717664, 64.04818250286964, 14.303604345167837, 0.16594333183621207, 0.6412770635178012, 5.17464715626932, 17.43534726481284, 7.787578663518352, 0.8602992108752652, 0.4241084199278586, 0.5683158302018719, 24.48411318563646, 69.46909812188917, 29.504115504603234, 51.76786907257573, 57.74746356471893, 1.3155080426123835, 0.2788617960628002, 0.15929146699847715, 0.17244239277657003, 0.19793920849840488, 0.18242205162682842, 0.11660820413981715, 0.163922070135032, 0.11152698808620054, 0.09782935898270338, 0.18782747609000053, 0.1578699142461823, 0.20005014845200125, 0.14320218034328955, 0.14849610836996188, 0.14899337604161234, 0.1640660180560043, 0.20254679835371434, 0.16357484844423112, 0.14619283438209565, 0.13058140273055724, 0.10664258768121082, 0.1233118641821127, 0.14641336045197903], [0.07091761716911871, 0.0629751852923824, 0.02466341165164786, 0.10426286577938065, 0.02879049966952974, 0.05002001413114129, 0.07920399188033997, 0.07730981650491876, 0.05085062964128391, 0.010862050412763512, 0.008923453429052907, 0.05202216193861058, 0.05530516279020137, 0.042964271570165316, 0.01760035678143463, 0.042281308016108896, 0.02435418217623186, 0.07047669526429907, 0.03190732455902523, 0.04366079871092112, 0.04136053544859733, 0.0528514712688423, 0.029585953659167694, 0.017601975142174674, 0.03182015141412135, 0.04005265865294684, 0.0492306026600061, 0.08124596093811336, 0.045476580309050704, 0.05514121614396573, 0.06054320470279744, 15.650242278652808, 55.805090165907345, 37.057510037576, 40.6617328428453, 64.37909718482726, 9.199565245259194, 0.2533402816662865, 0.6121857019682085, 0.5092635666651111, 1.308344201214852, 2.9095678608263693, 3.9743707497273726, 4.618496741017988, 0.2945467415115526, 0.16929409316470548, 7.697742167980441, 60.6064909504306, 66.17235383679791, 74.48548793792725, 71.27528682831796, 71.28273933164536, 69.11615540904384, 64.73442077636719, 59.85822431502804, 59.22909182886924, 52.90004553333406, 54.58321694404849, 51.5899738957805, 60.58475317493562, 70.59299838158393, 66.77456317409393, 65.71250300253591, 68.31796876845821, 69.66845650826731, 67.72442786924302, 67.83342269159132, 65.31686921273509, 67.74686382662865, 63.55945125702889, 68.21134305769398, 66.00668076545962, 67.53509506102532, 51.23809022288169, 46.70554045707949, 49.17170716870216, 48.258724520283366, 48.61000022580547, 48.918545630670366, 45.89077788014566, 49.35131249889251, 51.61654403132778, 53.126115260585664, 56.48546449599728, 59.023834197751945, 63.10831200691962, 64.7476666204391, 61.65508562518705, 65.61546356447282, 57.06240984701342, 62.107621239077666, 66.4729642868042, 61.44659596104776, 59.2546852942436, 54.14460574426959, 58.151310797660585, 55.22141402767551, 57.90352290676486, 58.11580550286078, 59.97729178397887, 56.55647508559689, 57.940134309953265, 51.00749408045123, 44.697949809412805, 44.42940865793536, 44.77576178889121, 42.80843427104335, 43.86648185791508, 43.40229680461269, 46.73198507678124, 44.62504471501997, 45.48733072896158, 50.13127580765755, 51.436377802202784, 54.40094047977079, 52.35403591586698, 49.49173335106143, 48.908437682736306, 50.72652293789772, 56.904071607897365, 60.22477373000115, 59.017111255276596, 60.843182456108835, 59.21915646522277, 61.27402736294655, 57.47588257635794, 54.0672173807698, 45.12538617657077, 52.369894058473655, 56.28284269763578, 59.52966305517382, 60.80584541443856, 59.95717002499489, 60.92492072812973, 63.43630452309886, 57.72995018189954, 58.701003520719475, 26.41227975968392, 0.004022901975399545, 0.14645350345921132, 0.7329434060281323, 3.263720134573598, 2.5248188934018536, 0.7377917007092507, 0.13237939576708502, 0.15461387202864693, 1.3916077849365052, 41.09472328616727, 40.292986900575706, 22.54001786631923, 48.600119775341405, 12.32423024792825, 0.1529476461150954, 0.11894414411677469, 0.09034700886977297, 0.02007099033723916, 0.021040532062010422, 0.13005013607682722, 0.04464445177525763, 0.09064911564271297, 0.04650914808735252, 0.06611200890714122, 0.02810914873055393, 0.012999182912491023, 0.059327587875868046, 0.029731370553734805, 0.0415057665668428, 0.10117551612277186, 0.03804052871982417, 0.019418990141862345, 0.05196478961396122, 0.05175147243144532, 0.007891964877114422, 0.04150495068320344, 0.04965371685102583, 0.021904652427521445, 0.08201328226395192, 0.07837812611532789, 0.01958875905632252, 0.05221688999764381, 0.0388177938669199, 0.04153688505832707, 0.03530789692435534, 0.05170687462293333, 0.03416689706125087, 0.03309907008623404, 0.03273766427751511, 0.0750358836845525, 0.006228240719440604, 0.05739196331330365, 0.015103141889877379, 0.053679474419163126, 0.01914772798397368, 0.01339416060927174, 0.03479088716689618, 0.04243187493674698, 0.02891379386006344, 0.028593256926885056, 0.028186657676293005, 0.05025169827164181, 0.06505756548816158, 0.06192755239504961, 0.05434354241456717, 0.10562615754503397, 0.026480166181441278, 0.055306629848576365, 0.04152764603796025, 26.619851589202884, 61.06791073276151, 33.39031357919016, 58.76771127024005, 68.68324341312533, 10.353768756312709, 0.3698554214450621, 0.14876665998130076, 0.3417699026965326, 1.2488483421264158, 3.1860863777898976, 9.384723671021002, 8.480740900962584, 1.8490342267097968, 0.2461262768314731, 11.01780249226478, 64.71352238808909, 71.22053054071242, 78.32914398562524, 73.33816328356343, 72.41382537349578, 70.7685479810161, 67.23755190449377, 63.6058372066867, 62.59856077932543, 56.03208949488979, 56.782309470638154, 53.83592697881884, 62.828203785804014, 69.89906049543812, 70.17897652041528, 69.98150087171986, 70.80042116103634, 69.86792472101027, 69.14827177601477, 69.22887648305586, 66.65269513284007, 69.5014419863301, 65.50696688313639, 69.32783003776305, 67.9720941666634, 68.70869175080331, 53.71436096006825, 48.3786549106721, 51.02879647285708, 50.682992473725356, 50.19966625398206, 49.388386741761245, 47.73795927724531, 48.292758926268554, 51.02765506313693, 54.28725058032621, 57.512760700718054, 59.402523348408366, 63.167708458439, 65.34142717238396, 63.23553016108852, 68.73228088501962, 58.58352068931826, 59.003206453015736, 67.3449307103311, 63.121173458714644, 62.09130417916083, 58.3356818076103, 60.65638742139263, 59.31533298184795, 61.775623982952496, 59.94554411980414, 60.9478077580852, 59.87080727854083, 58.372324589760076, 54.14405269007529, 47.53193678394441, 46.4672407796306, 46.3350647495639, 44.77791909248599, 44.842979446534194, 44.873875956381525, 47.44696255653135, 46.301606931994044, 47.986347290777395, 52.54129771263369, 55.112128949934444, 54.12828868435275, 52.62270650556011, 51.40237477517898, 50.92550869910948, 52.98087773784515, 58.569105978935, 62.2275516294664, 62.05243741312335, 60.951785041439926, 60.04953007544241, 62.52956628799439, 58.72251379874445, 55.778688692277484, 46.75275794921383, 55.54825336702409, 58.657116120861424, 62.105930697533395, 63.177847785334436, 62.048381682365175, 62.599949298366425, 66.55271391714773, 59.10530182623095, 62.09581098248882, 30.953403826682802, 0.08028986022597359, 0.994971645695548, 3.1811785121117873, 3.503240404590484, 1.3730928494084267, 0.13737560670462348, 0.022774420776254228, 0.2076854863234105, 2.102640953756148, 49.58610557740735, 50.9301253288023, 20.20392087198073, 52.99262131414106, 20.321219351983842, 0.252719106933763, 0.11786552296290476, 0.010026380637540452, 0.06021256498511761, 0.056667144545504165, 0.044494942055955056, 0.06901263995396514, 0.029357410479156725, 0.048520454475956584, 0.0863911989595621, 0.039675387163316055, 0.025751561024076036, 0.07494099603425111, 0.029121924627331958, 0.036629655233193795, 0.07688695895335368, 0.05890010698367992, 0.03244295408348403, 0.04286345439933, 0.057748914320742896, 0.02873253554195887, 0.015056417229765607, 0.025813506893633355, 0.038866405976155115, 0.19499445844802166, 0.2319937013089657, 0.14755002042699247, 0.14783836059993313, 0.09873043159924208, 0.12506674179026198, 0.19187861032062964, 0.18117835384703454, 0.12931908901420333, 0.11807905465003946, 0.1620610280623359, 0.15521891294948517, 0.24528157296440295, 0.16634618683207422, 0.07967046281743435, 0.14227622519097022, 0.11022710541803991, 0.12163007136193976, 0.22199305164958202, 0.17222039581787202, 0.1592715946777213, 0.24345744100789873, 0.1402280431601309, 0.14712586818683535, 0.16117049681563533, 0.11723880941468863, 0.2336592377433854, 0.23621959551688165, 0.147607492343072, 0.1451934726848718, 0.21319957269776255, 28.1137352989566, 76.43491375830867, 50.11990093415784, 49.60925148379419, 81.49266889018398, 18.359702825546265, 0.6667561059997928, 2.7998113632202153, 1.5416858801918647, 5.884926126849267, 8.76634926565232, 12.55626295843432, 11.29149567696356, 1.4184169399161495, 0.3570826519881526, 12.310391145367777, 67.75796413421631, 71.5511235883159, 79.69262261544505, 77.13391150197675, 76.65509208556145, 76.89736904636507, 71.12106707788283, 65.74301904247653, 65.15653056483116, 57.54774824265511, 60.150789983810924, 56.70694897251745, 64.74886294334166, 74.51613733845373, 73.04766470386137, 71.40845914040843, 74.51781611288749, 73.1288028532459, 72.10876695571407, 71.91608444336923, 68.6257806901009, 70.90287346993723, 65.746694303328, 70.76217020711591, 71.8513967144874, 71.84803916561988, 58.96006038112026, 52.76336662230953, 53.219193104774725, 53.73495732584308, 52.981058166873076, 52.246896374610166, 47.33042893871185, 53.229744280538256, 56.38935465966502, 58.17642181150375, 63.12540961850075, 63.09956904380553, 66.21464483199581, 67.2136725148847, 66.03294495613345, 71.28245692099296, 63.15488230797553, 67.43696520405432, 69.3594051176502, 65.25173433365362, 66.97210942545246, 58.627082532452, 63.686320320252456, 61.552115563423406, 63.22794821954543, 62.97830504755821, 63.7222727652519, 60.779181142007154, 61.83846819785334, 55.65625582971881, 48.56204532807874, 49.970403717410186, 48.88623314519083, 45.33084384856686, 45.82371711730958, 45.827698323034475, 51.39020758290445, 48.93256418166622, 50.57180896882088, 55.38640852897398, 58.39971842304353, 58.07749571338777, 56.822294112174745, 53.619537661152506, 52.65255574257144, 54.84498416223834, 62.15504269446097, 64.2294313061622, 63.54567981535389, 64.61998562658987, 61.915346653230735, 64.52511918160224, 61.28633968291744, 60.343974559537834, 50.31159500921927, 56.12046833961241, 60.86383373506608, 64.08373486611151, 65.76501177203271, 63.83402501383136, 67.36696658595916, 69.51109886169434, 59.95985292619275, 63.13249734140212, 28.995266422148678, 0.2866572922756595, 0.6830246265857451, 2.015379126514158, 13.60778077956169, 12.210098101246743, 1.4338979221159414, 0.23196754706723077, 0.7077971521404482, 3.5971816605137246, 57.7989838969323, 53.78708170306299, 32.62288616549584, 65.30899309342908, 21.854085537695116, 0.2862913473959892, 0.30739379085360036, 0.11498511663728184, 0.16479623774366994, 0.19983650185167792, 0.14169709336373115, 0.24364936135468945, 0.17573804173979068, 0.16212591570952248, 0.20986564998184482, 0.06964212674046717, 0.12259791620195874, 0.1830665307540086, 0.1375720163266505, 0.15637555249756382, 0.24488250244288678, 0.10549652014648724, 0.14156295136818964, 0.14943393788510753, 0.13587145435233272, 0.13200050400149438, 0.1363341714585981, 0.10301304695707175, 0.2134409823244618], [0.010808838903152896, 0.027186003205696904, 0.09971065642011744, 0.040013955891012185, 0.028738955358764338, 0.017658801629177986, 0.034836415772236166, 0.05900319560521072, 0.04760879452430433, 0.02954490858340456, 0.02812152105053106, 0.03327579507904668, 0.04426327323721302, 0.017630044603720307, 0.046083444519148725, 0.022462621075852264, 0.12033721372004479, 0.04129370959896234, 0.043523013967299656, 0.012616269185297914, 0.08268003156709094, 0.05090460819642871, 0.050712511649415384, 0.03474196096161201, 0.06573388322947488, 0.057260540929893335, 0.04959963870445087, 0.025168169747977972, 0.0332507248517246, 0.0702084189340953, 0.09416640916418645, 0.5006222787403292, 43.785328019049864, 52.45487220825688, 24.566932070639826, 56.850323369426114, 47.50658258315056, 2.1916522806690586, 0.21370361258666362, 0.1398613628360533, 0.3322618016071858, 4.041042952768264, 7.978042585234489, 5.703907272508068, 2.467365486006583, 0.4193112386330482, 0.4101888781353351, 19.867836506136005, 59.73714467017882, 66.58734844576928, 81.47448478206512, 72.57920034470098, 68.77679194173506, 66.10080196011451, 66.35566972917127, 57.75038573049731, 58.24628706901305, 53.81414605725197, 57.937392573202814, 66.02420591538953, 69.89607949410716, 72.02063129794213, 69.28217364895728, 66.02301351485714, 67.78067465751403, 68.13499019991967, 69.66567162544497, 68.5517498754686, 67.22086614178073, 65.22391296202137, 66.64481901353406, 63.610104745434185, 64.44121183887606, 52.13833693535098, 46.336068876328014, 49.5279799738238, 48.056985255210634, 49.99608739729851, 49.36035748450987, 53.76747769694175, 59.52201835570797, 63.95199421913394, 61.58319642466884, 61.743413479097434, 62.390216242882516, 64.96293414023616, 64.93909005195864, 65.08270371344783, 63.615525461012325, 57.039832684301565, 61.212583434197214, 64.21220425636538, 59.92311992952901, 58.68003452977827, 53.56878611349291, 56.731903091553725, 58.062473035627804, 59.3914387303014, 58.15903786690005, 55.892802207700676, 53.46393331404656, 48.9622369120198, 44.2139450196297, 44.39612734702326, 44.230740608707556, 45.425741672515876, 46.58271143513341, 45.92658911981891, 45.13476064128261, 47.8338376937374, 44.939858067420225, 46.213016279282115, 49.9289168080976, 52.232689549846036, 54.18419814878895, 54.718730911131836, 53.814008774295935, 50.306397868740945, 50.056746852013376, 50.983116549830285, 58.0410372826361, 61.099246548068145, 62.21625520337013, 63.43440217356529, 61.14047850331953, 59.77815305033038, 56.942385319740545, 50.07404450447329, 50.08057132844002, 61.717470922777736, 62.42743561344763, 60.70008654748241, 63.335734951880674, 62.0217566336355, 62.730838791016616, 60.423277039681714, 43.34313177293347, 0.9997299710108388, 0.14778286519069828, 0.15848929633296308, 5.635488879296088, 2.659727589737985, 1.050411222442504, 0.16980478269678934, 0.25190034280380896, 0.01925119007336757, 22.616637445265248, 50.62711831062071, 23.209342879633752, 43.29293327946817, 37.03565459097586, 0.31663039038258217, 0.09250900092264337, 0.057092878757224935, 0.08622692672595864, 0.039574711718746734, 0.019943881028842543, 0.008502039953225083, 0.14321069924100754, 0.014661214494657134, 0.013926154088919923, 0.08513034847114356, 0.05491548833707648, 0.06007420950599256, 0.05321062860950347, 0.052627229672526164, 0.020756855449308793, 0.032075961578577276, 0.08326441875749058, 0.07414455570641064, 0.05929619742317065, 0.007813284774461101, 0.04310952184060889, 0.052033538344286145, 0.03681511745878285, 0.05036900548504726, 0.08122969689148088, 0.06854392437925262, 0.04063061453522213, 0.04862865290394233, 0.04928456206295279, 0.02193998057214964, 0.03481096250095195, 0.05826778184141844, 0.02352875691177624, 0.012201733263810317, 0.009752710090739834, 0.08598886490348848, 0.07793439266782615, 0.06286083900880429, 0.05690830136318842, 0.019018550238181508, 0.07414015836172527, 0.02907418394311061, 0.02127701382813675, 0.015196112405148246, 0.0217474703376572, 0.017031205164629127, 0.12478976270123837, 0.02553835492430916, 0.05838954385610358, 0.02915042309811519, 0.024748799811688163, 0.02200001696755569, 0.061187768099649306, 0.05527968653627942, 0.12331367214961399, 1.8399782094263264, 60.494766158442346, 49.54388126250237, 28.764997797627604, 73.46734262281849, 45.85571189080515, 2.7694657012339565, 0.2539622224867344, 0.2492116040159618, 0.17828799603927523, 0.9868559553738564, 3.7553850681551046, 15.088055826002552, 6.018526467584795, 1.2629526949697927, 0.08602520811461634, 25.872106629033244, 67.63962622611754, 66.00427243017381, 83.21138089702976, 74.34421985380112, 70.95967723477271, 70.50332515470444, 68.76859418807491, 60.474385523026996, 61.85892728067214, 57.05420424861293, 59.08265798322616, 67.03060765420237, 72.66744582883774, 72.62076177904683, 71.08997052715671, 67.75780723940942, 68.98751735687256, 70.06485908262192, 71.40569779180711, 70.53778709903841, 65.99126585068242, 65.09236451118224, 66.85005311043032, 67.58489347273304, 67.17778282780802, 52.95357804144583, 48.295951735588815, 50.74737818010392, 49.89026185004942, 50.15519049859817, 53.01555149016842, 54.642570249495975, 60.91453821428361, 63.52824880230812, 64.08503317063855, 63.19951888053649, 63.53390878246677, 67.6153624442316, 66.64098293550553, 66.66578015973492, 66.07697748368787, 57.52012691190166, 64.38931888149631, 66.56164123165992, 61.76399807776175, 61.68712354475453, 54.788690305525265, 60.520755783204116, 59.07816294700869, 59.45703644906322, 58.6638782870385, 60.06927136451968, 57.251609294645256, 53.33304774376654, 47.692322500290416, 45.48856627556586, 47.31260961101901, 47.3672599946299, 48.07050958756478, 47.60547337993499, 46.16747756158152, 48.42102827564363, 47.21828445311516, 47.28434108918714, 51.33312140741656, 54.35114206806306, 56.96341706860451, 58.016510701948604, 55.04242058723204, 53.595167975271906, 51.64724442266649, 52.895719159033995, 60.684185258803836, 61.62428717459402, 63.2793704925045, 61.89253414830854, 61.63203385568435, 63.74294365606001, 59.720666793084916, 52.93485264624319, 52.617976127132295, 64.3480477025432, 64.60224474630049, 61.068852101602864, 66.03940117743709, 64.90614998725154, 62.445145114775634, 62.21288980976228, 48.560880384137555, 1.77689865231514, 0.29719973463685284, 1.8543858105136504, 5.904220756023161, 0.5409614044812419, 0.6479603532821901, 0.23171683713313074, 0.19645474460576812, 0.06699703198166625, 27.254363606053015, 59.17205272182342, 29.727804353160245, 38.840282194076046, 52.987373182850504, 0.8225892376034492, 0.07356756892535957, 0.03982020459408241, 0.09248339826421392, 0.005460614873652137, 0.012696502531217712, 0.06688402635195563, 0.10258199226471687, 0.021490681495878006, 0.05683598266313634, 0.14295376867296236, 0.045557414076381156, 0.06469407208984898, 0.06703594158734046, 0.04787969087520915, 0.029237079133670178, 0.08501907420014182, 0.09865514813892304, 0.04436003397248926, 0.040040906864188375, 0.05573691079212774, 0.028581838386373657, 0.045046429600446455, 0.03577647843368111, 0.028668412067476782, 0.1630414520660716, 0.09244087272353711, 0.13526420709827255, 0.2303456470009781, 0.123970860675458, 0.09912322786065841, 0.09025262683750161, 0.1572931572915085, 0.10515511306303163, 0.0971257302068895, 0.1074925622332, 0.17606293962847802, 0.19131916695304457, 0.1509027582623305, 0.13242461027637606, 0.1636639751133419, 0.25972185536257686, 0.14450388630070995, 0.15678959237712045, 0.1190326119502706, 0.1934500405144307, 0.10973155378333985, 0.24557906022715956, 0.27480410411953926, 0.16812251490210334, 0.15995808606666906, 0.18534219493308376, 0.09817359293059957, 0.21404740220356375, 0.11612470306816602, 0.2379904996844069, 1.7479802427753326, 69.50343455037763, 67.21007962380686, 36.52550720399426, 68.50988249624929, 66.84156510137743, 4.534315322676013, 0.5876341161708678, 0.9622351765151947, 0.8333790037901172, 10.624409356424886, 18.964157719765943, 15.414854961056864, 7.791566733391055, 1.4773717570689417, 0.45394297869455436, 24.737768942309966, 78.45785264045962, 70.32959553503221, 85.52113917566116, 79.13865843126851, 73.04126339574015, 72.55394028079125, 72.13945557994228, 63.84290133753131, 62.745249579029704, 60.591534952963556, 63.94719323804302, 70.08352956464215, 73.93859186480123, 77.51574639351138, 74.44020025191769, 72.16473917807303, 71.72058566924065, 72.37636673835017, 74.02921430526241, 73.85909326614873, 69.79408218014625, 69.02417582850303, 67.5316982884561, 69.22649952673143, 70.38414001464844, 56.157997577421135, 49.555350272886216, 54.600997048039595, 53.09745450173655, 52.562741310365745, 56.538789118489916, 60.56524722806869, 65.2136363521699, 67.72278831851098, 66.76661645212482, 66.51296461782148, 67.33143775693833, 70.69077522523942, 68.87314104264783, 69.02138310094034, 66.22419972573557, 59.56828271189044, 63.90701247799782, 69.1325116926624, 64.88756971974527, 65.87396344830914, 57.668204230646936, 61.30719100275348, 62.10241233148883, 61.36394377677672, 63.18372741822274, 60.5844158511008, 59.37176412151706, 54.74050791032853, 48.7378655710528, 47.626575731462054, 49.154644858452585, 50.03892752432054, 51.73979274688229, 51.80143671651041, 49.19505703833796, 51.26069091981458, 49.90252710157826, 50.25772909964285, 55.016513332243896, 55.81482548867503, 59.79220690265779, 61.7189771129239, 59.98244185601512, 57.20297190450854, 54.47224524713332, 54.772887076101, 61.802974670164055, 66.34422425300845, 66.15215363041048, 62.9475458206669, 64.71456966092511, 66.33271601892287, 60.91331443478985, 54.223735640125895, 54.583365994115034, 67.03017619348341, 68.10590974746212, 64.71935495253533, 68.63378232525241, 68.21508499883836, 66.00191900807043, 65.9881514887656, 48.512525404653246, 1.7065468983304117, 0.2760494260057327, 1.3191742329828202, 13.274600928829564, 8.674439307182066, 4.093194786579379, 0.5455679218134573, 0.5951890301319861, 0.08456116812604089, 37.80052069694766, 66.95105414236745, 37.153576727836366, 54.555003335399014, 60.69689373816214, 1.2932044652200516, 0.19076160816175325, 0.13597057080797612, 0.26716749454217575, 0.2223188688437785, 0.12675444880921033, 0.12488002318047708, 0.25927081343627745, 0.10144567702926936, 0.18384539702486608, 0.31345578331139784, 0.12909611146296227, 0.1577250010544254, 0.24205223657190802, 0.1865978743280134, 0.16888409822938905, 0.1546625798988727, 0.1942396473379866, 0.19230388104915622, 0.11373988668163938, 0.12758253622920285, 0.10261158624123182, 0.3508896278517862, 0.13605338491259084, 0.14349283410176156], [0.07279825577091786, 0.0444875224944084, 0.038207949574796424, 0.13666718987928284, 0.02092922714749171, 0.06408590936071931, 0.0350396091028327, 0.013908464161138383, 0.06110935133971995, 0.03219677555945612, 0.041582517085536834, 0.10202946667108806, 0.006802746812031875, 0.03627009186593275, 0.02546496178594328, 0.042752835133503524, 0.023784434926065228, 0.043449699352946014, 0.023119872803950024, 0.022673281848490722, 0.054357358810281566, 0.015995255108141614, 0.0871443170152845, 0.05400792695581914, 0.015384777835870703, 0.1177732170289082, 0.027296700995535623, 0.032650069784252875, 0.015093171255542867, 0.049444356512638836, 0.04512250596176713, 0.04279375571997897, 10.322092675393629, 63.75698181890673, 36.39040116340884, 33.670159001504224, 64.07279537570092, 22.20916005872911, 0.08225466890801346, 0.38433763949621114, 0.3014165583637453, 0.18081784819162663, 6.309060348618416, 15.861491330208318, 7.930766257547564, 2.2426288743172926, 0.5941811035717688, 0.5564161558305064, 45.62101294917446, 78.41311408627418, 77.82013016362345, 71.38759997583205, 76.26640089096563, 69.52748652427428, 66.07081151777699, 61.35651088530018, 58.60814925163024, 61.97798298251245, 65.91834898917907, 69.075300001329, 70.95424867445423, 67.7728142276887, 65.59946813891011, 69.56812227925947, 70.5427606644169, 70.8230532369306, 69.53464877220893, 64.39995242703345, 65.97955365334788, 63.873519359096406, 65.03539208442935, 65.55365485529747, 66.84238095437327, 51.47555835785405, 48.388892296821844, 49.286558089717744, 48.77931325666366, 49.89408616096743, 53.91768486269059, 64.51314810783633, 67.28410259369882, 66.60607384097192, 66.25027564264113, 65.31119746546592, 65.93908263790992, 67.14834151729461, 65.0628565203759, 65.0780321705726, 59.79765899719731, 60.596743860552394, 59.29091230515511, 63.445341663975874, 63.38080690753076, 61.65710172345562, 60.47617804619574, 54.80529762083485, 50.745593501675515, 53.468859810982984, 50.87202325943978, 49.58517205330634, 48.39408159255982, 46.26918462014968, 44.20389198487805, 45.83011058069045, 44.753306219654704, 45.3641761502912, 45.22226479745681, 45.50452247742684, 47.72670207485076, 46.47820380426223, 45.34712952952231, 47.73786906273135, 49.12771386484946, 54.881113113895545, 54.97213171374414, 55.65074489962671, 54.88880095943328, 53.99327678065146, 53.320970766005985, 53.06122749082504, 58.05495777437764, 59.84041283207556, 63.86032058346657, 62.390357448208725, 63.29035312898698, 60.95340498032109, 61.040842456202355, 55.50919440484817, 55.344643131379165, 59.39111709594727, 61.097340276164395, 62.69985206665532, 58.800918056118874, 66.15670357981037, 56.50211103500859, 51.91887247946955, 6.13601076987482, 0.0952871268494956, 0.10046719888886137, 3.7159299465917774, 6.374459497390255, 1.8887119427804027, 0.11736808675191096, 0.06870500968709108, 0.1465213482057856, 8.932830345246101, 46.66596374204082, 30.322820063560243, 24.531805284561653, 56.74382317450739, 10.909114595382444, 0.1488646885920917, 0.1162261943963747, 0.05498071306294972, 0.07904492138374238, 0.052020499527814894, 0.04470670791042428, 0.029795323573653738, 0.020008544595311248, 0.024445260454329754, 0.04932616063724122, 0.023371716548177986, 0.019908748236635042, 0.04317603742463454, 0.011036843906397061, 0.023647366474652966, 0.11881167985378735, 0.04296693372570219, 0.04483510041609407, 0.049060167249051795, 0.06649340578024426, 0.06016216789101882, 0.03781912164882787, 0.0024268863442909695, 0.07140604418612297, 0.05167758708158809, 0.036433984886013696, 0.014774897154570829, 0.007250247496901261, 0.1328141353423557, 0.02144067702184041, 0.036422999185179515, 0.022571635387477376, 0.05397409268264329, 0.08772949327624614, 0.0592470950176639, 0.04675474438455798, 0.07422833508180995, 0.022692629399018425, 0.01943162676217335, 0.02676953482742031, 0.02243144704299348, 0.0544864944212379, 0.04669976991511161, 0.053139198571443565, 0.03755189102864073, 0.08121691088402465, 0.014345517321940393, 0.07936690813831745, 0.007675407621483769, 0.054785985003916494, 0.018640685030409408, 0.04829001522833302, 0.029550501025251807, 0.03231553067903846, 0.058384234866788315, 0.02331149820688992, 0.041371651384378635, 19.40973504897087, 74.86331416714576, 24.593241368570638, 47.78551801558464, 79.85939395043158, 22.429846332919215, 0.1422110923956479, 0.077207091775152, 0.09729959386130495, 0.15918628312647343, 1.0805406637730137, 8.733801437962441, 11.845455938769925, 5.088551621283255, 0.7044466512818491, 0.8659886088102096, 54.472068740475564, 78.93623275141563, 81.6856102789602, 74.14628136542537, 77.9992098962107, 70.39964122156944, 69.17364951102965, 63.19714584658223, 61.42244592789681, 63.32149282578499, 69.88567736841017, 72.76930193747245, 73.91312783764255, 71.2560829039543, 71.08111381530762, 72.56501705415788, 71.25576911434051, 71.28234709462812, 70.38730144500732, 66.25300561228107, 67.30827223870062, 64.14166435118645, 66.31002902984619, 68.2287819154801, 68.54140266295403, 55.08695910053869, 50.318251271401685, 50.301314476997625, 52.56662445683634, 52.00123440834784, 54.69387092897969, 65.12787765072238, 67.74639314220798, 66.60060605695172, 66.96970109016665, 67.84103993446597, 67.5234220873925, 67.00009161426176, 66.05014062696888, 65.44891188221594, 61.291007303422504, 60.624255364941014, 62.38599969494728, 66.17771179445329, 65.6544166226541, 64.58003236401466, 61.120572474695024, 56.31635935075822, 55.13643980026246, 56.28781626301428, 54.67764016120665, 53.27416512273973, 49.64798881161598, 47.304227505960775, 45.01511658391645, 46.77708841139271, 47.463714999537316, 47.53156415877804, 47.60548122467534, 47.28253679890787, 48.21420169645741, 48.277336166751006, 48.22639242295296, 50.346974788173554, 53.28413186534759, 57.660002554616625, 57.62762338884416, 57.82924106044155, 55.37002086639405, 56.45321084607033, 53.78956456338206, 54.62971272007112, 59.65155855301888, 60.85288247754497, 64.63600066400343, 63.230438924604854, 64.2541108592864, 62.79082752043202, 60.84707344731977, 56.018694600751324, 57.56657169711206, 63.08141631464805, 62.2697877114819, 65.34743232111778, 59.3988912336288, 66.82243962441721, 58.678092956542976, 56.0303165835719, 8.944806321974724, 0.2081189082274514, 1.6923664269908782, 4.504682306320437, 1.2691461174718797, 0.8483225599892679, 0.15604792733586606, 0.07417417266556332, 0.1087758131325245, 15.044871510997897, 55.50394627355761, 46.55674142222251, 22.436953667671453, 66.64251265987274, 15.84751396409927, 0.11838431004434825, 0.08123538892475829, 0.03952323827111433, 0.0467225342177816, 0.028721302777769107, 0.019255196713211558, 0.04722437160390039, 0.06833957808633005, 0.026875689715868043, 0.04766765688996642, 0.02586535955478828, 0.027235500146484664, 0.060604403636628584, 0.014709917576833358, 0.06022288801989729, 0.025224647664975737, 0.029221316874628107, 0.05981156775247186, 0.021626480156555775, 0.043004119633546764, 0.083757741076331, 0.04967302992759694, 0.003548402436858704, 0.02342206959222113, 0.04874257017828284, 0.1549394900399831, 0.09430185350919924, 0.1020042930218962, 0.3379115468311695, 0.10312751581471774, 0.22486722968038053, 0.17156906786464876, 0.1518506848163182, 0.17903960490178678, 0.10372773038163301, 0.15806206441935033, 0.23466233794967975, 0.12251515572349872, 0.14504273722489036, 0.10646121636513742, 0.15371027132195814, 0.16969405234821383, 0.15890080812236956, 0.15973454161036402, 0.16264910779653058, 0.21944997681965753, 0.13622313467485292, 0.174180033406423, 0.10409989589524847, 0.13284151532476948, 0.22449416018301444, 0.13071044258052303, 0.13283953881792485, 0.17417805689957835, 0.2694054825171348, 0.14386821718465898, 0.22345137662224232, 19.12464149536625, 86.36411928361463, 52.85161995118665, 45.06185946925994, 79.74767700318368, 35.271658820490686, 0.305894005202478, 0.9558334393847374, 0.6967793369004804, 0.9724728078130753, 14.070928365953508, 28.183792752604333, 21.802580894962436, 8.742437516489337, 0.9361778295809223, 1.0454732035436938, 52.88269296769173, 85.03303943141815, 81.60303654209261, 75.24631008025139, 82.21476939416702, 76.17757489604335, 72.21745583318895, 66.9691990267846, 65.29439403164771, 67.49105468873056, 73.25045908651045, 74.9237657362415, 75.209471179593, 73.07447802635932, 70.8438810225456, 75.31436320274108, 74.7830467839395, 74.81536711415937, 74.23973575715097, 67.16475271409558, 67.73989769720262, 63.821406748987016, 68.34497036472445, 73.59855374982281, 73.29644495441069, 59.05147906272643, 53.07163746126237, 54.85384087408743, 56.20724293493456, 54.324713137842, 58.18312906449842, 69.72460131491385, 71.15506618253647, 70.06633389380671, 70.3817944372854, 70.47287971742692, 69.67691313835883, 69.58372546780494, 67.10607405631774, 67.0918672315536, 61.5729158924472, 63.10797076071463, 64.63579670075448, 67.81962379332512, 67.94964251979705, 67.53919786022556, 65.08475119067778, 59.336439255745184, 56.10015830686016, 58.11807263282038, 56.0264059805101, 54.49795246124268, 52.552652974282545, 49.59884543572703, 48.32105098232147, 49.881695393593084, 48.44238165886172, 48.37585041599889, 50.28324019524359, 49.68946003144788, 52.33404751746885, 50.50486195471979, 49.557362448784616, 52.571048890390706, 57.4993658065796, 62.67150509741999, 60.498778743128625, 60.65932135428152, 57.54233929418749, 59.00173948657129, 58.77106489673738, 59.675920394159135, 63.13630204046927, 61.45504082402876, 68.59330346507411, 65.47515253866872, 63.83300911995673, 63.91972487972629, 64.89727758592176, 59.400773971311516, 59.791963715707105, 65.31249184762278, 64.60853230568671, 68.51098860463789, 62.0403172892909, 68.51134161795339, 60.64228650062316, 58.36294620267807, 7.826085061796251, 0.22491981395550315, 0.5400566852861836, 7.50989789924314, 17.564418738888158, 4.334674035349201, 0.6292170009786083, 0.15411496492883853, 0.23475702641712082, 17.93435904287523, 60.32806934848909, 44.52318860638527, 36.113732860934356, 74.48490742714175, 18.79840620102421, 0.42113321022160594, 0.15612982213497162, 0.109737238155738, 0.14571499470020496, 0.1125583645977801, 0.1348789414811519, 0.120376659587266, 0.1318752792693915, 0.12376404757941924, 0.21057480225159278, 0.10118269436662236, 0.1621511046804728, 0.1456768128780588, 0.1130435587237439, 0.1784805292564054, 0.15401829995455282, 0.16137744780750046, 0.11857685858323691, 0.09260806375213208, 0.12204188192563674, 0.18522617857783072, 0.163535057837444, 0.1216563711603803, 0.16153834159335784, 0.16462812740956584], [0.007238412874885985, 0.030205663248536088, 0.06997578101412905, 0.09257332932564521, 0.024804199459932508, 0.013852089666010392, 0.01706764605196734, 0.08780663833022119, 0.043321463895300706, 0.027275279261952928, 0.01606302611875318, 0.03943605363489159, 0.025931959408485604, 0.03631537532313697, 0.01785004207293593, 0.0029224714953377242, 0.05403892670367515, 0.06615297928933175, 0.06130387638545325, 0.08037571569964772, 0.022856623925749334, 0.028057047090823614, 0.016438726170529282, 0.024959119675200314, 0.08489270033615251, 0.019372094069577513, 0.07381381256686104, 0.07838907351176586, 0.03553491175895737, 0.07129391955752527, 0.03693491062750259, 0.03920224743084081, 0.21579659543931487, 31.715538001829582, 54.696342022188254, 21.988613028680128, 51.00111630655105, 64.30241484795847, 8.882884844656914, 0.025543118075978373, 0.200794127078787, 0.04120852445222197, 0.6061658443462464, 9.938848672374602, 14.330138198791014, 2.776309256592105, 0.7191055292083371, 0.2933486719285288, 5.330908500379132, 60.3535569098688, 76.82847653665851, 78.74398169978973, 72.50483220623386, 74.1920397358556, 66.96872834236392, 62.182036445986846, 64.555501860957, 68.14410578820014, 67.28051754736131, 71.68635122237667, 72.67625547224476, 70.87795072986235, 70.30237428603634, 67.80199666177073, 69.6569247399607, 67.26295317372968, 69.78459004432925, 72.66466879075574, 68.19588107447471, 67.92890102632585, 67.56050417500158, 65.86934289624615, 64.1827041102994, 51.17219440398678, 47.81443765086513, 50.125439320841146, 51.13280596271638, 51.826296698662546, 63.38960086145709, 64.95654459922545, 66.23249161627986, 64.4390506129111, 68.4652223894673, 66.27772438910701, 68.64481203017696, 63.99324578623619, 66.43818855285645, 58.107650895272535, 65.48607241722846, 45.34161075468987, 40.0992767272457, 72.38310537030621, 63.52015695264263, 68.54382668772053, 58.57651925856068, 58.18499611270044, 52.828077885412405, 50.539535707043065, 46.78707476585142, 48.046249728049006, 47.07615736992129, 47.47837681924143, 46.75070654961371, 47.831974567905554, 46.298990711089104, 47.954866347774384, 45.58098123919579, 47.29925786295245, 45.469083862919966, 46.68109232379545, 46.33681020429058, 47.38947237691572, 48.67792783244964, 49.56220657594743, 54.64857539822979, 58.06917244388212, 57.01323509216309, 55.354147034306685, 53.617917722271336, 52.264994190585234, 55.333574202752885, 61.56534571801463, 62.9092203417132, 64.5043816105012, 61.946419669735825, 63.59323070895288, 61.726139360858554, 58.688240128178755, 55.06985364421722, 63.07721153382332, 63.64289968244491, 60.7101748835656, 70.61951360394879, 54.3336522194647, 58.61119693325412, 18.430862465212424, 0.07739511273440815, 0.17037073781173076, 2.622571957688178, 2.244770488431377, 3.770412894025926, 0.17992558558621716, 0.4652613455489759, 0.22841375711704456, 3.988675878893945, 40.72235307385845, 35.21996198161956, 18.016032595788282, 47.61405160350185, 28.375694713284894, 0.21231777485339873, 0.021834666465198802, 0.03541398861054932, 0.046594873326079506, 0.09242008875815139, 0.016809386321373524, 0.07321514549755281, 0.0961427781130037, 0.02187578814975437, 0.03386181403672503, 0.037650965349448305, 0.015636918439169326, 0.017472349234946796, 0.03778626030731586, 0.05660462411000364, 0.10065178777421675, 0.0862019905640233, 0.04763943804127555, 0.05518058923283412, 0.03851858290633367, 0.02420789385665088, 0.07696793444695012, 0.03507277687951442, 0.05871029720912057, 0.025857453527409705, 0.054570005665863716, 0.03042261934869232, 0.029807864432974212, 0.05174691420829585, 0.023153086545907205, 0.04047929301797863, 0.029098800263337554, 0.026265385770990003, 0.043157716431925376, 0.04861516209559576, 0.03840478437562143, 0.0238524041619272, 0.01740447001441592, 0.0655255456184668, 0.07973459969845512, 0.04168796908831404, 0.0263680262310851, 0.0372281767457964, 0.04858924917155697, 0.1227018207071289, 0.024173205395439462, 0.0593729134679081, 0.04861758293343648, 0.0826333844733815, 0.04142153136912854, 0.015779334184293066, 0.05691699263068938, 0.07936290915935271, 0.12877649958095244, 0.03931062205904915, 0.08603956460231736, 0.017581583796850136, 0.12345129218433173, 0.6544339188164281, 48.170655542804354, 53.24783425177298, 21.81437546207059, 70.03443717956543, 63.234573102766475, 11.454137736751187, 0.12523485212436608, 0.03350064571526262, 0.1009098751350276, 0.163604756516795, 2.515869760705579, 8.214230556641857, 9.869070687601644, 4.19623839278375, 1.3640968934182198, 8.396589390693173, 65.53628660017445, 75.95775742684641, 81.92820887411796, 74.69896685692572, 78.02407772310319, 68.38481380093482, 67.11508766297372, 66.59972744603311, 68.9568365773847, 68.21199417114258, 73.42780513148155, 74.8594702443769, 72.34098695939588, 71.48019929086009, 67.917432015942, 71.14183995031541, 71.46057175051781, 72.10460924333142, 72.00203926332536, 68.88609270895682, 68.67367282990487, 69.17219038932555, 69.19525392593877, 66.17153798380207, 52.967690729325824, 49.49915055305728, 51.9055050419223, 52.63855680342644, 52.148593933351584, 64.04998287077873, 67.86331115230438, 68.87681238112911, 66.24997754250803, 69.69248494794293, 66.54543399810791, 71.36799596971082, 67.56630143811627, 69.81421178387058, 59.10063420572589, 63.3139540303138, 49.77109632184429, 43.786983259262584, 71.30567735241306, 65.67122397884246, 69.66331035860124, 60.85355320284444, 60.44675242516303, 54.18695949739026, 51.80953641091624, 49.320392454824145, 50.381217079777876, 49.52952146530152, 50.35868698550809, 49.047368034239746, 49.47860125572451, 47.11201175566643, 50.078410102475075, 47.71380139935402, 49.280419580398075, 48.38652710760794, 48.979730682988325, 49.42383712337863, 47.777512458062944, 50.475561849532596, 52.18193800218644, 55.996313556548095, 60.49042409466159, 59.31117919183547, 57.64864729296777, 56.06717901845133, 53.16504086217573, 57.15412270638251, 62.87874744784448, 66.20257962134578, 64.70036675853115, 63.15586682288878, 64.20787395969515, 64.92139624011132, 61.180474911966634, 58.92682221628005, 65.8719002815985, 65.8692644488427, 61.87561304338517, 71.52541637420654, 58.89504317314395, 62.60139665296001, 24.095365116673133, 0.06025438189446446, 1.0003454154056888, 3.146032359330885, 3.2003687081798433, 1.8262524878786457, 0.16643099276529205, 0.3337651419062769, 0.2123818044821101, 10.69514439951989, 38.954136833067864, 49.712339216663, 19.23897662470418, 47.25693156642299, 40.538895976158884, 0.4860285795744389, 0.026892972659439813, 0.050567108161386945, 0.0363182979485681, 0.03608849072348207, 0.10221656066395583, 0.049509163720593344, 0.07680374648301833, 0.0722875815605925, 0.05283625676266609, 0.031310637827001275, 0.01572405232206708, 0.04760101107099364, 0.021936787900725202, 0.0529912133671103, 0.03796355603563209, 0.059125053380886396, 0.025602313689887527, 0.01805086819184644, 0.0016169808241688918, 0.04056631294529765, 0.043576735882989825, 0.033544703431787996, 0.05703901511526877, 0.027303272114706137, 0.030577591274895018, 0.13895981524500156, 0.11181836962820062, 0.15424038884380173, 0.1829690384047647, 0.17658069249122374, 0.168977300486257, 0.12137622046735018, 0.2535768802608213, 0.1956452654614564, 0.09066895731995184, 0.12046649871814637, 0.08588755743638163, 0.15345055219386855, 0.2356601521492966, 0.13782594383003252, 0.06723339308894451, 0.18585691408764932, 0.1593632954022577, 0.22112763276503933, 0.14101682260872858, 0.13002994199914317, 0.12911250574454186, 0.2095494701737358, 0.09992671619740226, 0.17601973226954862, 0.15518984757363796, 0.12454391742545752, 0.3512920998036862, 0.10258867255141658, 0.18286979937505338, 0.08179092524392952, 0.13186551930923618, 0.6742125929843995, 50.929937055034024, 72.60593521979548, 33.47140466013263, 59.7543050396827, 82.0117239798269, 16.682756216295306, 0.1828349730180156, 0.24686179784757478, 0.1370740591758682, 1.1044866111009353, 19.18301420827066, 34.65148502780546, 13.104954496506723, 3.54184657815964, 1.1538058807772975, 7.899518205273536, 66.56152356055476, 79.6099861206547, 86.47706785509664, 79.59330820268201, 80.8399002013668, 73.25369111953243, 70.74148362682712, 71.32565790607084, 72.93880324209891, 71.99939558582922, 75.51866377553633, 77.08674892302483, 74.91013157752253, 75.54086439071163, 71.67363489827802, 74.40802112702401, 70.01775926159274, 76.40129904593192, 75.56635979683169, 71.25886778677665, 71.03734016418457, 73.64544176286267, 70.43341282875308, 67.6616621017456, 54.888028252509336, 52.0063413343122, 55.30163042006954, 55.069324124243956, 56.52341342741444, 69.96784317877986, 69.89891929011192, 71.69374881252166, 68.44378271410542, 72.18329198898809, 69.71918844407605, 72.65736533749488, 69.93344399236864, 71.2132506216726, 59.062465621579086, 66.61261635441934, 49.0586095471536, 44.808984264250725, 75.14425785310807, 68.36087165340301, 73.13256832861131, 62.692281892222745, 63.748242778162805, 57.187345181742025, 55.524299452381754, 52.28140146501603, 54.222076477543006, 53.0727239578001, 53.0292837081417, 52.76835195479855, 52.28671627659952, 49.982865087447635, 54.17774977222566, 52.80801888435118, 54.80135563881167, 52.382751587898504, 51.98643530568769, 51.73765113276821, 51.12260780026836, 52.78546133349019, 53.44270544667398, 57.97415302645776, 63.67091717258577, 64.47510111716487, 60.26340907619846, 58.19777127235167, 55.682272911071784, 59.879624766688195, 67.64300730920607, 69.45722118500741, 66.74836174134286, 63.776299492005386, 66.77348059992637, 66.00350364562004, 63.33156939475768, 60.60101532167005, 68.65260970207953, 68.12827510218467, 65.1567933636327, 72.16008724704866, 59.57879858632242, 66.59860564816383, 22.396878811620898, 0.17821023811496076, 0.5834946060372938, 8.345754492667414, 13.051923071184467, 8.719456349649738, 0.34071306908322924, 0.6508293832021376, 0.5922566907059762, 10.829628744433004, 56.41095122983379, 48.648321782389, 31.39761224869759, 60.93457760349397, 47.518094739606305, 0.7465176873149411, 0.08916239945157882, 0.18653876298377592, 0.08223274347162055, 0.15035328935951958, 0.12803183147503486, 0.14393108235972543, 0.19615658318563817, 0.1224084473365257, 0.1927147493247063, 0.20213896378634438, 0.0847775649820124, 0.21608386308916155, 0.12581036801660253, 0.15183471954397618, 0.13067849671408055, 0.28887974398751415, 0.1762565453687022, 0.16649299992188332, 0.18843481527461162, 0.08957895976040633, 0.13957374278576146, 0.08624476125283588, 0.11616210348062939, 0.07806382322263333, 0.12988038631456514], [0.018742404269775557, 0.05148229594793051, 0.017901241644135406, 0.06185349084496979, 0.0039908617843813715, 0.07107575303844868, 0.10642973015144949, 0.06660212897845814, 0.037995498071634964, 0.008996657918267434, 0.03271981442887937, 0.035649468716714657, 0.026638608485940966, 0.03318383005417643, 0.027600745970924056, 0.012633470732027726, 0.04467343671187278, 0.03962842597355766, 0.04807284845399761, 0.08370171706642836, 0.010531554336569483, 0.043995422085807215, 0.057568768745348345, 0.0677868303272032, 0.03830428896171432, 0.0007796397802585196, 0.04018223859489926, 0.057257032247200135, 0.04771842936714811, 0.08299915315282923, 0.08422933714163881, 0.05171131410245454, 0.23885594921246653, 7.054824021554763, 58.61532718904557, 50.703945775185865, 23.78721194882547, 56.06826159261889, 54.35032229269705, 8.625497933356993, 0.10736162248518198, 0.044098242576564514, 0.09476642454824141, 0.12103768621361065, 6.67743758809182, 9.631393686417612, 5.073681425663733, 0.4442902708486204, 0.26751159059424556, 14.40157828792449, 76.8853352146764, 75.20018300702496, 83.72333649666079, 70.73949106277959, 70.0876166743617, 69.61982696287095, 72.20654379936957, 67.3104138528147, 71.48035618566698, 74.04261312177105, 73.6462889948199, 69.07267985805389, 70.46243836802822, 68.81235214971727, 71.75524373208323, 74.07860479047223, 73.54949274370748, 69.39709909500615, 68.29288913357642, 68.81535668526926, 66.09524788395052, 68.92483788151895, 64.20904674837666, 48.691161909411036, 52.59616382660405, 48.53261578467585, 52.15630531311036, 57.4832409428012, 64.3713701155878, 62.912138585121404, 69.38300209660684, 66.01403913190289, 67.64491358110982, 63.12479772875386, 67.36593892497402, 59.92885051235076, 65.40988429900139, 58.8711049479823, 68.35090098842498, 39.476121933229514, 41.189887831288004, 73.79064790664181, 61.92261480516004, 68.19997602893461, 59.560696847977184, 60.69980021445983, 55.001220010942035, 52.22187557528096, 51.935209151237245, 54.39892045913204, 48.79306900885798, 47.43798032883675, 45.54133392149403, 47.26998913672663, 45.836774687613214, 46.76268939049014, 46.32960088791386, 46.388004979779645, 46.89741888353902, 48.23238580457626, 47.05537665274836, 49.0490036626016, 51.25862775310394, 51.901210046583614, 50.78938284227925, 49.71992508057625, 54.56662139584942, 56.399552822113044, 56.14765428727674, 57.42493098781955, 56.2827681726025, 59.323330694629306, 63.3924053561303, 65.48174604292839, 66.15368335477768, 62.99690492691533, 63.639059682046216, 61.85134141675888, 63.85837901023127, 57.7321937776381, 67.12178707122803, 70.83762876449093, 56.65524036653581, 61.680267241693315, 32.969298132004276, 0.07285686915800457, 0.19272670029632508, 1.7399100887198604, 8.381438255310059, 1.9266537649016229, 0.017881076294748534, 0.20161829978948642, 0.29259548492489323, 7.616580484374878, 45.793840423707046, 53.94910697014102, 23.278300108448153, 39.86385606950329, 46.15086632390177, 5.7663460123923524, 0.27032242847546456, 0.18205314964777042, 0.029275331818949313, 0.12992491134472434, 0.07361044686648154, 0.04414467516565516, 0.034737130777249416, 0.07374723952624106, 0.026906275776244944, 0.029023486159501538, 0.05975319951352093, 0.019069648302731015, 0.036210045894427646, 0.059889011580737374, 0.0376966739854505, 0.0846929275881379, 0.013617224345404296, 0.027067797754200238, 0.021658385803382245, 0.026068719509508342, 0.028305671350549788, 0.02328456638591184, 0.034472240555670955, 0.09265671799620313, 0.09668697633089558, 0.007876529641855028, 0.041659079912689426, 0.08852632430892798, 0.003242717075702404, 0.04697363868716264, 0.0369248365712983, 0.040115799619666034, 0.06867171550590186, 0.03378369605108615, 0.011807973646829206, 0.019034586373656508, 0.010542261372921208, 0.005079892636727422, 0.016976339862711968, 0.04239007334915861, 0.04675926813375085, 0.04832159337257186, 0.05265185939929178, 0.01797794619755399, 0.020967920333327308, 0.03353030480925114, 0.04007877459028556, 0.058856543393865715, 0.024828292925151128, 0.07612753599401444, 0.05966797989282397, 0.03489987466544394, 0.08251097894483998, 0.13539641855224488, 0.027889396409474076, 0.14222361027233063, 0.07380373084977751, 0.030432074788897753, 0.1378203207446683, 11.801797016974419, 70.96837705181491, 35.94536119891752, 30.73223117859133, 82.3682438942694, 49.747181630903675, 10.676721026820521, 0.08585794047722894, 0.039404073294492505, 0.10713093808942264, 0.2702726634039033, 1.027627522426267, 5.687424982747724, 8.798718625499356, 1.8192137946044247, 0.6987827487530247, 19.05910065097194, 82.8443725647465, 77.29322248889555, 85.74267464299356, 73.95030406213576, 74.54663768891366, 71.59685842452511, 74.23385220189249, 70.99601407204905, 73.91668150501867, 76.75515959339758, 75.58796421174081, 69.9545463438957, 73.00679360666584, 71.14709592634632, 73.24683481647124, 74.8162849487797, 72.8088237393287, 71.21106193911645, 69.31357614455685, 71.02845207337411, 71.27098006586876, 70.18825684824299, 66.1008176495952, 51.27623527280746, 53.742605947679095, 51.64348286967124, 53.816683830753455, 58.86937126036614, 65.24989081967261, 65.84971535590388, 71.79839764871906, 67.12230482409078, 71.10038834233438, 67.2956657409668, 67.29838002112605, 61.90165365895918, 66.42162830598893, 58.078625355997396, 69.27705103351225, 39.64699606741629, 40.689005082653416, 75.7124210173084, 64.04265588329685, 70.08639289486793, 63.54765276755057, 62.46547868174892, 56.09631830646146, 54.702421695955344, 53.794734247269176, 54.46529480718798, 51.30527257919312, 50.29945919590612, 48.31641474077779, 48.745188636164514, 49.69285288164693, 48.04399436519992, 49.223764865629136, 49.162344471100845, 48.6483492389802, 50.86031106210525, 48.55695801396524, 50.45297291971023, 50.53047895431519, 53.7447593289037, 53.226661297582815, 52.91658616835072, 56.34422386846235, 59.6182890092173, 58.31508936420564, 57.60631707406814, 57.646344861676624, 62.59325381248229, 63.73878594367736, 66.94894390721475, 64.742155690347, 65.36721675626694, 65.8498251822687, 63.95974874496461, 65.32973458690029, 62.34461476725917, 65.85679131169474, 71.68200523622575, 58.50508113061228, 63.60393485715313, 37.998012035123764, 0.19417155744327655, 0.40897389333094325, 1.9078949069784534, 5.15292408966249, 2.351581531186258, 0.14030350282067253, 0.1893893301847481, 0.31401003260285626, 15.43449721028728, 41.517923493539136, 64.42728350239416, 27.12601580927449, 34.85379303655317, 60.77192867955854, 7.700352995626389, 0.25100916804325196, 0.18732850770315818, 0.039792843763866735, 0.08141448495969658, 0.08937683512246417, 0.01786628888259011, 0.013517645364176604, 0.03028765763907183, 0.042615632616704514, 0.03127751601559501, 0.00851514005673028, 0.042413982953275406, 0.026355747756878697, 0.03458781641036753, 0.028661528767477122, 0.02627028490326578, 0.043096034862701936, 0.0548400899635688, 0.04031962880323972, 0.033521333919657816, 0.04002425594315414, 0.01888053566818276, 0.04214097603013919, 0.07984690052727539, 0.08828581866597937, 0.03223657382712249, 0.14810005623486736, 0.19596708367668814, 0.12744415776744006, 0.10959951852959011, 0.10597303449626892, 0.183435034367346, 0.2099652414120013, 0.14017591853776287, 0.0657581911993123, 0.17423070246173492, 0.14880262014846649, 0.11093209783035902, 0.12315281666815282, 0.0918010590718158, 0.17751090709240208, 0.1818152027384889, 0.19006825262500396, 0.11062731741056328, 0.1535281262570812, 0.348846624575315, 0.22639395098292062, 0.2018824622275368, 0.21523047178503008, 0.18863517791032794, 0.25196585864309345, 0.09627109017944145, 0.15067297785032183, 0.2695437767092259, 0.14283015272550045, 0.41240906222693385, 0.23882365094557886, 0.15086499012766347, 0.4005196840772706, 13.099004260955319, 80.51696362033968, 63.67071320933681, 38.854614534685695, 65.38305920939293, 75.25013831353958, 14.02696938283982, 0.20212267675707418, 0.33744371225756986, 0.19060575523443762, 0.6152450894155811, 13.414499125173016, 23.172782467257594, 12.918254579267195, 0.8266935076925063, 0.7575857579227417, 16.52643015307765, 86.20898954329952, 77.39295267289685, 92.12672433545514, 76.59660954629221, 77.69589301078551, 75.10339460065289, 78.92254367951425, 74.52614722713348, 78.19346920136483, 78.9304982462237, 77.850599135122, 70.5770343349826, 74.97195597617858, 72.26174723717475, 77.28364406093475, 77.1567161621586, 76.68663578648722, 71.24688886827039, 69.60205862599035, 71.4345899704964, 75.12728967974263, 74.33142508229902, 69.46122200258317, 55.153384439406864, 58.470395611178496, 52.93507622134302, 58.92634368711903, 64.3057410178646, 68.67034665999874, 68.24988426700716, 73.1637982399233, 69.50477600097656, 74.69717825612715, 70.97511568377095, 69.35527093948858, 63.30408534696026, 65.1950325504426, 59.749268716381444, 71.75810706230902, 43.597991697249874, 46.91686207248319, 77.02648562769737, 66.97030513517319, 72.01262966279062, 65.90851952952724, 64.70703086545392, 62.64504871060772, 58.97776203770792, 56.800528880088564, 58.73971339195006, 53.99748156147619, 53.84288134113435, 49.905778746451105, 51.30053043365479, 52.44222648682133, 51.24215379838021, 51.03985755674301, 50.61532766588273, 50.70516955467963, 51.56881663107103, 50.585886355369325, 53.253368716086115, 56.43839997629966, 58.82262445265248, 55.991893045363895, 55.89322582367928, 59.96793300874772, 62.83959827115459, 63.129084879352206, 65.10660271490774, 61.01413896006923, 64.26999253611412, 70.29081113876836, 69.35079943749213, 65.19525220317226, 63.77512278095369, 69.91306335695329, 65.20272039598035, 67.89010094058129, 62.81314580671249, 70.93953194156771, 73.76650179586103, 64.38386678695679, 69.3291401094006, 35.79417736299577, 0.29848017399349525, 0.2950801532114706, 3.456442606064581, 19.619211189208492, 9.80843476710781, 0.3514760528360644, 0.3312367146774646, 0.6595288938091648, 13.81424944246969, 60.72466804135231, 64.64363751872894, 38.50333882916359, 52.82885451470652, 69.60183112852036, 9.655344659282315, 0.5649153191235758, 0.3144527394925395, 0.2690446551047987, 0.1819678687400395, 0.26746902674917256, 0.12702637171793368, 0.20122301374231616, 0.12180156780466919, 0.12700222462656038, 0.222057479644014, 0.10869446225584516, 0.19747235451734838, 0.14138307392356858, 0.16277428656335802, 0.15293384121069986, 0.20427250333370703, 0.08615220250982432, 0.18521292525674068, 0.13790083658551017, 0.2015228145906041, 0.171213204702062, 0.1359252337246172, 0.27090015070092294, 0.2054605371649227, 0.19877064372262648, 0.09696941762681931], [0.024629583124131448, 0.010567022292243858, 0.05871802320583694, 0.07020822741211423, 0.02057982976698587, 0.018737899672780788, 0.05339131810732427, 0.03131262007950535, 0.023233200190588835, 0.04907949564738139, 0.028009831176830396, 0.11006366055939468, 0.03138147606213968, 0.11540582914265896, 0.055528799177057324, 0.057447474044297016, 0.03935937589455036, 0.0734944841373832, 0.03744934632953617, 0.025460166075537284, 0.053753876878369244, 0.047873853285226135, 0.02892168839612315, 0.018263875108753002, 0.03512809608852671, 0.01672533306954128, 0.030532235039337993, 0.007315482756483459, 0.044238467310224815, 0.04265644595087056, 0.04636314322030352, 0.07232352640599975, 0.05501318753005997, 0.021371089425238392, 29.170666971514304, 61.28097388052172, 42.83790696051813, 32.31924372334635, 67.42827323175246, 54.445322098270545, 11.199884799218948, 0.41308781612784634, 0.15462410696331533, 0.1493904394127669, 0.7907573037570523, 6.404423954025392, 10.692608587203488, 5.951174468763414, 0.32704563150482796, 0.16117789722498388, 28.2869432433959, 86.92573208962718, 73.21551076827511, 83.22371282885152, 74.82807559351768, 72.25675013757521, 75.61709173264043, 76.02194309234619, 73.32408197464483, 74.40518133101925, 72.5466368275304, 71.96271357997772, 67.68259186898509, 71.95475901326826, 70.65051601779076, 69.34044438023722, 70.68313444814375, 78.65010369208552, 78.10722412601595, 68.23021750296316, 66.70259552617227, 68.9504901824459, 56.47331299320344, 48.46035788136144, 51.212457533805605, 52.08203523389755, 58.47114870625158, 63.22934458332678, 62.80346931949739, 66.1119258019232, 68.7194468898158, 68.6355395470896, 67.50806208579772, 62.35584059069234, 63.895343426735174, 64.11074038474791, 66.67140483856201, 62.422681700798776, 66.02662209541568, 51.85980550704464, 43.9470120399229, 77.42648893787016, 63.34011231699298, 69.46102588407456, 58.101108381825114, 59.64676149429814, 56.75014995759534, 55.701723944756296, 56.53441959811796, 58.88135017887239, 52.84206897981706, 50.49636217855638, 47.826302820636386, 49.84746879146945, 48.782804166117025, 48.712770246690326, 46.99543499177503, 51.33443932379446, 49.35950633018248, 49.037244396824995, 50.28250671202137, 56.387856314259196, 54.73947632697321, 56.96247962213332, 54.95974879111014, 56.28758092080393, 52.826520704454, 51.50422303907333, 50.403806009600245, 52.32196269496795, 53.93861462993007, 62.468946056981245, 64.7468311555924, 66.97873823104366, 65.16309269012945, 67.54265739071754, 66.81196689605713, 62.221938717749815, 59.76229098535354, 70.4786063778785, 65.29846152951642, 53.405639048545595, 63.478626897258145, 35.872236451795025, 0.18097420673697226, 0.07566442818290765, 0.1492906641215086, 1.386632503521058, 2.4286997414404348, 0.17670559546639844, 0.04878416875257127, 0.3204221578855669, 11.1603973181017, 33.52729843508813, 50.24358503280148, 21.173436641693115, 30.77998603543928, 45.313020598503854, 17.27590487849328, 0.12702996467029856, 0.06658447065180348, 0.08540035616005621, 0.008788997337462441, 0.03520091274572957, 0.03693081588754731, 0.01667346125618825, 0.021546289903081713, 0.031619777287086176, 0.08443652562076047, 0.05909460138589625, 0.060460792794342966, 0.03779914207576263, 0.04431678830916363, 0.019092322590069908, 0.008582188071863306, 0.021391285418142236, 0.0385903385317614, 0.034583166256667144, 0.04727651537846654, 0.03498364637996401, 0.042212099633029396, 0.026696040182404464, 0.04561968936374591, 0.04422730157872842, 0.007666463066162843, 0.04790531268583671, 0.007639705530187536, 0.0447066389625111, 0.022317470396838845, 0.07839518689340161, 0.07106860543811513, 0.02356833492916438, 0.04312962781818163, 0.024567765574301445, 0.09954673658695914, 0.037234110096769954, 0.05407535035403506, 0.005568361309762564, 0.026921689465281465, 0.040017901243822235, 0.02391042000043296, 0.06541308391118242, 0.016934323770504807, 0.012581827787442074, 0.03343097001854931, 0.01723900076843077, 0.02321496538277115, 0.09173715201717231, 0.029649625141774456, 0.010342928167853144, 0.02670122276721222, 0.015088174447056749, 0.021830351474965294, 0.026467280582554882, 0.08548679386055277, 0.10748454895351203, 0.06453306339080296, 0.025420787241009456, 0.016723594049953164, 0.08078083065488646, 41.68310234623571, 70.97921063823085, 28.143341349017238, 41.82786918455555, 90.76851737114691, 49.63311910629273, 13.27434205239819, 0.3787539616948174, 0.05110717716536695, 0.13581625005650905, 0.43407553025791723, 2.4983220571471803, 6.701053688603063, 9.552432452478717, 1.267896842571997, 0.18522297633030724, 37.296150961229884, 87.27281478143509, 75.32446722830497, 83.83699893951416, 76.75642259659307, 76.1877259900493, 78.11579058247229, 80.0525785261585, 77.53987681481146, 74.40547943115234, 76.3616438834898, 72.46138018946495, 68.88375497633412, 70.88856466354864, 72.31908444435366, 73.3477024878225, 72.94249811480123, 79.79927970517068, 77.11341319545623, 69.43562461483863, 67.16112844405636, 71.25359612126505, 60.76928892443257, 51.50604301883329, 54.531590707840465, 52.719506679042695, 59.6712645407646, 64.3787520162521, 65.92042000063005, 68.06197920153218, 70.79511811656337, 69.68307910426971, 70.68784129235053, 62.91972837140484, 66.78528693414503, 65.82566338200724, 66.5002247595018, 62.62239702286259, 65.6066539210658, 50.111052067049094, 48.510548530086396, 75.4642605012463, 67.18245829305341, 70.61933317492085, 61.431279105524865, 62.12454626637121, 58.758878092611994, 58.89673371468821, 58.246761675803896, 60.98381903863723, 55.212094476146085, 52.39112192584623, 49.781231726369555, 51.738212031702844, 49.2078871111716, 50.61792035256663, 48.79452420819191, 53.01095447232647, 50.79028890978906, 50.4942637105142, 51.85543206430251, 56.56046413606214, 54.72138635573849, 57.59764863598732, 57.429896708457704, 56.22600363146875, 55.089579243813795, 54.76290464401246, 53.00835001853205, 55.68711311586442, 56.83584982349027, 62.50194887961111, 66.34035679601854, 67.23466504004695, 64.57700037187146, 67.05261215086907, 67.29262198171308, 66.31888574169528, 63.10982604180614, 70.95474289309594, 69.14213718906527, 57.065720327438854, 66.15442860511043, 41.69482631068076, 0.45845413340195534, 0.42865741937871904, 0.7817089473528247, 1.6602523889272445, 1.1761736869812012, 0.2996549238601039, 0.04392353622543235, 0.26122829065688197, 18.992371328415413, 30.61695468041205, 61.498634046123875, 33.164428203336655, 27.30238518407268, 57.29524566281227, 25.050364194377778, 0.10465175499238315, 0.03283493063082138, 0.054035732117030895, 0.04665064452696712, 0.02805957901141336, 0.01925105600798082, 0.03820516101475205, 0.02750113921900911, 0.06479230754437947, 0.0712687229256957, 0.013417841344621154, 0.036003734585979295, 0.06954783663874672, 0.05818835001498942, 0.0837682671244106, 0.04544250088773909, 0.02579554404702879, 0.03792441277314098, 0.008478605323621343, 0.012569274479192833, 0.12169414695592658, 0.07839461232745841, 0.031896532295391924, 0.016274141756096677, 0.06915310983576121, 0.023064193533613317, 0.04162131943890164, 0.17748201025589821, 0.1468492031938607, 0.24035196571100145, 0.13987434036549062, 0.1669263758606488, 0.07169047731064981, 0.15208933652649004, 0.10693469700673897, 0.13307219972052883, 0.18887522390052197, 0.0706978725089181, 0.12170772969482407, 0.15379852465083524, 0.3043712369136272, 0.1438530792872752, 0.13413199043321994, 0.1466390039891966, 0.10115274032878299, 0.11229435537731457, 0.055483366332707874, 0.2037510426054078, 0.14166746108281997, 0.1250394690601576, 0.08860192952617522, 0.1519436266032919, 0.24151773702713752, 0.18250313437273427, 0.07804441821551131, 0.1663006352440965, 0.3018057310292798, 0.17990569794370284, 0.12589509734102797, 0.13922947819434828, 0.22656230646516048, 44.82603872975996, 84.34393390532463, 55.42364358901978, 48.359097972992934, 80.77987224824967, 73.36314093682074, 18.02609935883553, 0.5791124605363416, 0.3497543161915195, 0.28379301210084273, 2.4105146527290344, 17.97394556383933, 25.114516519731094, 10.141330246002445, 0.5636961974443928, 0.16079620157759036, 32.88978972742635, 92.71727638859903, 76.36560547736384, 89.01699081543954, 80.62948073110273, 79.82347288439351, 80.16345608618953, 85.59496602704449, 79.88831750808224, 78.21472844769879, 75.33599899661156, 76.32168277617424, 70.94448981746551, 74.08475506690242, 75.74205060159007, 73.78724328933224, 75.85107680289977, 82.92831128643405, 78.5104045560283, 73.81486462008569, 71.26952094416465, 73.8796700200727, 61.714850779502626, 51.91619742301203, 55.291228294372566, 57.62667025289228, 63.73103926258703, 69.08957742875623, 68.41962091384396, 72.43189181050947, 74.66829392217821, 72.13427020657447, 73.40280394400321, 65.74201099334225, 68.75019042722641, 69.87334543658842, 69.43592271497174, 64.79975961869764, 68.5583943705405, 54.61909486401466, 48.67883782232962, 79.19939241101666, 68.33630977138397, 72.49774840570265, 63.490056683940274, 65.01616854821482, 61.377758364523615, 60.78749656677247, 63.64819095980737, 64.2030494443832, 59.166745754980276, 56.29069920509093, 51.189778389469275, 55.53605087341801, 53.23872650823286, 54.56385612487794, 52.513111560575425, 58.19070316130116, 54.67787550341699, 54.19047394106465, 56.216884120818115, 62.604530626727694, 57.045198486697295, 60.66105896426786, 60.983313052885, 62.74929746504753, 59.3582280220524, 57.06410823329803, 54.370530343824825, 55.94333802500079, 59.56301104637885, 67.1352800246208, 68.42236657296458, 69.19343394617881, 64.77911226211056, 69.09705346630466, 67.93903643085112, 68.47389867228847, 66.03572199421545, 75.2281024379115, 68.95291420721239, 63.01781508230395, 70.41136910838466, 38.02869673698179, 0.5770727667597033, 0.724266326475528, 0.6762368424284844, 7.410120156503494, 8.284345865249634, 0.6947750670294608, 0.16120418936254519, 0.5002878047525883, 21.112228055154127, 46.01195950661936, 63.30117102592223, 34.83354576172368, 43.228943732477006, 67.45763609486242, 31.92857369299858, 0.2953186517040576, 0.16513716219173324, 0.2241863766985555, 0.22829492155823017, 0.08233651774184358, 0.09704892989248039, 0.10419804708010728, 0.055817530054839394, 0.19065575013237615, 0.22140160112852053, 0.1401089164879053, 0.14370697099835644, 0.13260309344097493, 0.1670681940571916, 0.25091314658282265, 0.1171135233955518, 0.12404930807890431, 0.1976610879383741, 0.14314297706850115, 0.13561640836058125, 0.11161998349932895, 0.1658729436777292, 0.17788679579332953, 0.1338639515902727, 0.08224934459693971, 0.156468540249813, 0.2113743682181643], [0.0059794551024453775, 0.04427020250248813, 0.04812040336189732, 0.0273978169406614, 0.023913976563621434, 0.013747858615862507, 0.007712385727978883, 0.05955058840974685, 0.08415347911537656, 0.07413356234469722, 0.03806102157179867, 0.02493053118908598, 0.033783569646578644, 0.03992076512546309, 0.00980758592636595, 0.08695807338001267, 0.012740515240077532, 0.02137346046736404, 0.05077493632392538, 0.016201259981420253, 0.025361128143906116, 0.024650374750396418, 0.05729612188353654, 0.04861631888836142, 0.01899829295824372, 0.04442351201789514, 0.04068596055731177, 0.04614220729338066, 0.014481428980586991, 0.09987297512951399, 0.08379103525752023, 0.029128028432868665, 0.10073056459547051, 0.09851679265979799, 1.2332560626729843, 46.22095907888105, 57.490779738272394, 46.22309677062496, 27.292112496591386, 70.71453694374331, 66.47156792302286, 21.39642926954454, 2.1713795104334435, 0.04148097213117346, 0.042160557237483805, 0.08940573195896803, 3.029401417701475, 7.148535818822923, 2.1968513823324636, 0.11192736861806725, 0.13905700115907577, 42.77665130553707, 94.12047293878372, 73.59286631307295, 79.2436210570797, 75.81760329584922, 75.8969057759931, 73.89184505708756, 77.96816041392665, 75.13203574765113, 71.07224141397785, 67.37307763868763, 71.27272159822526, 73.31329545667096, 74.98679038017028, 76.47930714391893, 74.95135568803357, 72.21496120575937, 67.37001818995323, 69.89584415189682, 71.69498043675577, 69.14058393047702, 56.08386870353453, 50.78325217769992, 52.87394608220747, 59.24207879650978, 65.15427912435224, 62.695329573846635, 63.67417273982879, 63.32565053816765, 69.26930043005174, 68.1062392265566, 68.29092010374993, 59.56462706288984, 66.13928825624528, 61.53752042401222, 65.11077611677109, 59.32475059263168, 76.52639127546742, 39.29837972887101, 36.33565272054365, 79.31772247437509, 62.36683891665552, 68.83162667674404, 61.795380961510446, 63.43866186757242, 58.76567556012062, 65.30054038570773, 61.0682519789665, 66.25816745142784, 57.33831720967447, 53.437586753599106, 47.14278274966825, 49.317019216475956, 49.192954647925596, 47.7936569336922, 49.53753486756356, 50.68823668264574, 49.15110688055716, 48.955090353565836, 53.46011292549872, 60.625694874794256, 61.42529749101209, 63.829749630343535, 62.98696956326885, 62.84573285810409, 61.259895063215694, 58.88569616502332, 55.45621102856052, 56.26186193958406, 57.495290463970555, 58.89710633985458, 62.54579313339726, 68.01356930886546, 71.71563563808319, 65.23762949051397, 64.91870157180294, 68.54396789304673, 71.40795707702637, 61.00100686473232, 54.06617795267413, 64.72509338009742, 29.778989322723884, 0.07191113361548032, 0.06423663715982149, 0.03975442828490369, 1.349690150349371, 0.3753664128242001, 0.21908082969246373, 0.030978749386004867, 0.5262988493327172, 16.334094770493046, 42.137599145212484, 57.06494369814473, 58.6089337256647, 33.12469851586127, 39.380494548428445, 36.610144107572495, 0.0761361927875588, 0.08976744037241706, 0.0291681427118038, 0.08894167419883514, 0.07334687431613285, 0.019226121761265303, 0.06760850038018919, 0.07314766847318219, 0.0773592904630688, 0.05613933677875227, 0.04324304713537136, 0.014181868492385313, 0.023008428078385133, 0.042955036380238114, 0.04983649010800066, 0.02016194987170879, 0.039660747223083055, 0.02196068409830332, 0.03486975974914047, 0.0500507993743785, 0.019968801869019386, 0.05538347612826094, 0.059650294753091956, 0.0846283540370003, 0.02248724697217826, 0.03012164638588025, 0.04976899776187155, 0.06123293281322526, 0.04847323664674356, 0.012254354885719236, 0.039823671141939784, 0.015044420292871374, 0.027563274695327687, 0.04038936195654735, 0.031929129336570064, 0.0180954257807424, 0.021071727162287123, 0.021962290967724497, 0.026614919132102403, 0.007143063656610227, 0.06541475398285736, 0.02387375694759671, 0.01771228414239182, 0.037860291213878704, 0.02894550990012865, 0.06747341609650082, 0.05439153782302334, 0.01377512560030746, 0.07485609817048235, 0.020339448613324956, 0.005881864598186146, 0.04835608648136259, 0.023620430823235262, 0.029344996024343758, 0.10298971191889818, 0.01822962140243861, 0.02405182259427684, 0.0388851598085415, 0.006888762206560182, 0.03832664340734482, 0.06641684295309168, 0.08463495005402835, 4.330123595653042, 58.40792794381419, 63.95158237026584, 36.48925665886172, 41.53553493561284, 95.32436601577267, 62.21228968712592, 20.129631180917066, 2.8525304698175002, 0.04207505416425486, 0.07926484990504482, 0.4183931282210735, 1.488659725554528, 5.614996946627095, 7.048348678696541, 1.5017489199676823, 0.6062398177962149, 51.819150140208585, 94.25286077683973, 76.76344363920151, 81.15485083672309, 79.37517735265916, 77.70137648428641, 78.26236955581173, 81.53678770988219, 77.88856767839002, 72.21265485209804, 69.8277125820037, 72.1400910039102, 74.45675265404486, 76.09613080178538, 76.37989074953141, 74.23741371400895, 73.15050924977949, 73.84534928106493, 71.27886402991511, 74.04939097742881, 72.81500539472027, 57.409676890219416, 53.132724454326016, 54.50986862182618, 57.87916891036495, 67.21867745922458, 63.950946946297925, 66.03572983895579, 64.96720952372398, 70.31665171346357, 71.09710924087032, 70.49880658426594, 62.12808032189647, 68.20650285290134, 62.9928138948256, 65.63921351586619, 60.8419979003168, 76.98414756405738, 42.14402790992491, 37.654836024007494, 80.33909197776549, 64.32995380893831, 70.43015726151006, 63.597274672600534, 65.14745420025241, 61.6046674789921, 65.9954627867668, 65.12164500451857, 66.3115587542134, 59.18544761596188, 54.71046255480859, 48.5958561589641, 50.47015290106497, 50.26163578033448, 48.9534939489057, 50.319945735316125, 51.713159853412265, 51.492271577158284, 50.96203381015409, 56.5612486100966, 62.96804020481726, 63.850306772416644, 65.15779356802663, 64.43672464739892, 62.944564819335945, 61.573100243845296, 60.307535740637014, 58.056107028838134, 56.48951238201511, 59.258293874802135, 63.283551739108184, 65.33889332125264, 68.75273212309807, 70.8718082981725, 66.39786658748504, 64.82236423800069, 66.79843471896264, 72.47136654392366, 64.50975918000745, 56.163865443198915, 70.0466828192434, 36.54813143514818, 0.5810588141602855, 0.1341129761309393, 0.353653826300175, 0.7575956864222404, 0.4011611754615461, 0.1878121849750319, 0.1510174416245953, 0.8494683210888218, 23.432182535048454, 38.09495341393256, 59.395733725640085, 49.227012588131814, 26.79244568271022, 44.87273846903155, 45.93576746602213, 0.6325410258385443, 0.11887909559112404, 0.03288673349626122, 0.06613496090135267, 0.014606158628368811, 0.017007985039644184, 0.023920038234322302, 0.028036918130613146, 0.03994829449502211, 0.03666605590091598, 0.0830348911544969, 0.044055491039950045, 0.02040119721524177, 0.03612491437384198, 0.029535125640611497, 0.05064409999777714, 0.030083037469716325, 0.017914977600617756, 0.07403058480591544, 0.021456236267582546, 0.07683645077650586, 0.049619066694210616, 0.007087668796415411, 0.03956917290305419, 0.06478869160937686, 0.021918283046914205, 0.04139997748537891, 0.040183483487776214, 0.14824729833391406, 0.12198547487177196, 0.1137455633931583, 0.0844143397144733, 0.11018973564909351, 0.2213683988778822, 0.09078315038594509, 0.09110618668097643, 0.17629129511694755, 0.18742190914288645, 0.10808060366299846, 0.12877916556692895, 0.12524363915285758, 0.20463435730386167, 0.07857016903618652, 0.21976618727128353, 0.10156583792019276, 0.21489883232260906, 0.12196086812764408, 0.13412656653071606, 0.1509134988150289, 0.10356283761681088, 0.11366247349689085, 0.15614618577303427, 0.1110540820105422, 0.11327808888088312, 0.15649359132493698, 0.13955282858542858, 0.18022512596461082, 0.1079135581911091, 0.1469369968699832, 0.14440389650483287, 0.1801578481231005, 0.19640320221022253, 2.854750531335031, 66.90737462812855, 76.05278861138129, 61.78672821291032, 42.39308272638629, 82.42154106017082, 85.3657897826164, 31.842487473641675, 2.995607992333751, 0.12080652684333826, 0.14802436674794844, 0.670201417899901, 12.074341927805255, 16.127500591739533, 6.076245125262968, 0.8573205997386287, 0.7804078849092607, 46.47606219014814, 99.31590326370733, 79.20773921474334, 83.377712926557, 81.21977390781527, 82.32411722983085, 80.84203397074054, 84.31436707896572, 78.341930912387, 74.01568997290828, 69.82828524804884, 71.9151666087489, 75.14244571808847, 77.74427152449086, 80.19186973571777, 76.98457902477634, 74.6358637655935, 74.51590199624339, 73.52765298658802, 78.29696486073156, 75.68181084048364, 61.906944936321636, 55.98946509822723, 60.66063534828925, 64.22075110097086, 71.8906125714702, 67.3407651532081, 68.79237944079985, 65.99400366506269, 74.35340604474469, 74.12513979019658, 72.54880982060587, 64.9019334393163, 69.22100036374985, 61.34767378530195, 65.9373724845148, 61.97119728211434, 77.5336794699392, 42.387403134376775, 39.84621717083839, 79.88601899916127, 69.34037377757411, 72.0345635567942, 68.1126719136392, 68.96985100161645, 64.18302182228335, 72.12954767288701, 68.57032622060468, 71.22119734364172, 63.00129405913815, 57.40758626691757, 52.006894388506495, 52.14990008261896, 54.17945992562079, 50.69492824615971, 53.83880207615515, 55.46259664720105, 54.62668072792792, 54.05191229235742, 59.38624158982308, 65.79182509453067, 66.92144024756648, 70.13435563733502, 67.50686968526533, 66.95299963797292, 66.04022487517327, 65.5723802505001, 61.82215506030668, 63.47692066623319, 61.94631768811134, 63.6404364339767, 67.38110280806019, 71.93648076826527, 71.7468027914724, 65.73564890892276, 65.55600827740085, 69.06845938774848, 72.14036556982225, 65.54055413892193, 64.03550148010254, 69.87642841954386, 32.43189419469526, 0.8497168400114583, 0.2725407126690111, 0.2646177700690685, 4.007002418079685, 4.9865528364335345, 0.42858828760443196, 0.11841858481808056, 1.0406233153996929, 28.43874877498996, 54.044455866659845, 68.44291979266752, 68.69824255666425, 46.861944967700595, 54.316138836645315, 54.536081821687766, 0.6467859098507512, 0.28042921195587805, 0.19698242596801252, 0.21553405710766393, 0.17533566171844162, 0.06879248926716466, 0.09264286712653215, 0.14085232820962706, 0.2311796256371083, 0.18908784394302677, 0.13311496274846216, 0.18886123513502462, 0.12592303656762646, 0.07998350932593308, 0.25474367813477594, 0.1269628553681316, 0.12197436659686989, 0.12848471201235248, 0.11404100520115708, 0.13538770047166657, 0.10585703346277438, 0.17335006907101602, 0.1602692403379948, 0.13654037168429745, 0.1379759591673651, 0.25478893860934243, 0.11277241722470331, 0.15376011300231182], [0.07108924384679526, 0.009469577400464444, 0.06280142122939711, 0.03374179870250725, 0.01769098498287701, 0.06861503266038434, 0.06671488179915375, 0.04675860163725672, 0.0778912159524137, 0.048911354669760314, 0.03790375904270238, 0.04684245379100885, 0.09772819707230215, 0.0944170501503733, 0.025821640832169403, 0.00784979844015212, 0.0032439830359972774, 0.04772946486369737, 0.02720901265650267, 0.04226484478661611, 0.0366797152486059, 0.10478027390256044, 0.08589911770315901, 0.03308516942084797, 0.05911849949869418, 0.04476135296206321, 0.04008484583708548, 0.041895555933156324, 0.10107721938120742, 0.03828080836683512, 0.04795628051543909, 0.042876374472173, 0.034382953008096066, 0.05497833819038445, 0.15727824922050201, 4.7137980787984795, 43.666680243707475, 44.67166208451794, 47.394685206874726, 24.671543644320582, 50.40811669441962, 74.71817862602973, 30.671442285660778, 4.066911719499096, 0.1633911865252641, 0.04101534389079579, 0.11257694989082315, 4.727681798319663, 6.5054558746276365, 0.35843072158675043, 0.003454859510266913, 0.9655523985143631, 44.076689520189845, 90.34350502875544, 80.4469414680235, 75.01391749228202, 83.17556181261617, 75.13611501263034, 76.81772139764603, 72.12801010377946, 73.50040820337111, 75.36959801950763, 73.89773645708638, 74.62082539835285, 74.08732814173545, 72.24695205688477, 76.74714226876536, 74.37730112383443, 78.03003188102477, 70.84149622148084, 70.58248642952212, 62.84165359312489, 52.704672275050996, 50.489741217705514, 57.36356550647367, 69.97773539635443, 69.87362000250047, 66.45530577628844, 63.251760928861565, 64.46436559000324, 69.71594072157338, 68.84824968153431, 78.68127869021508, 64.51583885377454, 65.5316032901887, 66.79466924359723, 73.78644312581709, 65.63343586460238, 66.95078742119574, 41.84550023848011, 41.23931361782936, 83.67593857549852, 66.90797082839474, 74.75931644439697, 66.7313543442757, 69.58811852239793, 64.85364121775474, 69.56517265688989, 64.80618838341006, 64.08322103561895, 56.70401896199873, 50.253638067553126, 50.29579570216518, 52.49586097655758, 50.82899485864947, 51.42888215280349, 50.57571172714234, 51.91943730077436, 50.1089535990069, 51.55310361616073, 57.82235730078913, 61.22066743912236, 64.41223729041316, 65.63103145168674, 66.68161869049072, 69.67072363822692, 70.14457733400407, 66.0227232594644, 65.01902795607045, 61.616634630387836, 60.932110432655584, 64.44977437296222, 66.25305268072313, 65.6002486905744, 67.95984852698543, 66.15120441682878, 64.75182825519194, 64.14921883613833, 59.84015003327401, 63.27316138052172, 61.817361923956106, 19.957870591071345, 0.13032629545177185, 0.1297259429890302, 0.053315115341496085, 0.258407861354851, 1.1383333561881896, 0.37709038644548387, 0.19965092471290022, 1.01953040207586, 17.067679974340624, 47.87646993514031, 47.86180811543619, 38.41100623530727, 72.1614130081669, 40.519601837281265, 50.20695401776222, 3.365611789687988, 0.17994099927525367, 0.047658019503878976, 0.04257506826111386, 0.0767373419817417, 0.012760633666579042, 0.02198453241538617, 0.052247219418566075, 0.09732422358807057, 0.028385706471219182, 0.05449953706814878, 0.03648218713820942, 0.03263804220384167, 0.03715992214218263, 0.0946100889855335, 0.024131838562748125, 0.06618830360352032, 0.04767156010794063, 0.05943564840802743, 0.07641947678019924, 0.04047893295665422, 0.0023838501581321322, 0.03178606433193049, 0.06526515233300387, 0.03854779000844687, 0.03306681395418221, 0.043147286144836296, 0.05802947104037289, 0.035050575651468775, 0.0562628684565425, 0.0252961945314441, 0.04513490126438199, 0.02042178582820681, 0.036130725150747646, 0.046343860787249384, 0.049958198496531096, 0.03047771639220657, 0.016547422555665818, 0.024727276571455504, 0.05288604481686508, 0.05067744397468144, 0.01066414404645442, 0.04877709776103016, 0.03520924778234574, 0.05873485415753338, 0.02891231722558939, 0.03983189509580693, 0.029726666773879723, 0.0083803593353819, 0.012158079658665005, 0.06081611969538274, 0.014965765088075593, 0.03576468451008682, 0.07197543137496518, 0.031174808522806536, 0.012333150859171105, 0.013441328642769687, 0.09479777286610297, 0.055166807311076316, 0.021846362712582754, 0.05829826447992556, 0.021067906298764774, 0.03188304340226516, 0.16943586539597283, 12.410437080167956, 60.85345514359013, 52.3128039606156, 36.46234919947963, 41.04060634489983, 82.17325502826323, 79.63167682770761, 29.1935638073952, 6.080812235032359, 0.18468723572309942, 0.12815254394926373, 0.25113037847463165, 1.6186212099367574, 3.9966615794166445, 2.0688036468721207, 0.1734375256684519, 2.0868671421081793, 54.62964996214836, 91.1170042714765, 80.30430839907739, 80.36708985605549, 84.41505432128906, 77.09188722795056, 77.46080183213758, 71.66396233343309, 75.90639006706976, 74.38250218668293, 73.040463232225, 72.09786276663505, 75.20485847227036, 74.73846512456095, 81.37002421963601, 77.08056726763326, 74.62253555174797, 72.23428280122819, 73.33558236399006, 65.80565929412842, 54.152262210845954, 51.48766671457599, 59.77410908668273, 68.72767602243732, 71.50949155130695, 66.99532985687256, 66.75156239540347, 69.11012280371882, 73.82648268053609, 71.19264248878726, 78.36861087429908, 62.77005464799943, 67.386515678898, 65.7763042757588, 73.03893350785779, 64.1341059438644, 70.30462572651525, 41.125831604003906, 41.27557985244259, 82.44368676216372, 69.44764275704661, 74.83970149870842, 66.8785765863234, 68.13323297808248, 64.37622600986113, 69.8168005481843, 64.04821388183102, 66.2781636945663, 58.04226498450003, 52.838632983546105, 50.69661878770398, 53.95712429477323, 53.160894916903594, 54.67825989569388, 50.928611293915786, 54.40399208376485, 51.21091996469806, 53.60332650523032, 57.23620614697857, 64.00334981180006, 64.95742321014404, 66.6410300039476, 68.86353123572566, 70.18959829884191, 71.41123617849043, 66.6294825461603, 64.35249959268879, 63.31833139542611, 61.46317581976614, 65.63440076766476, 68.91356498964372, 68.91034864610242, 69.16323954059233, 64.76420725545576, 67.38721386078866, 66.8721595887215, 61.3860777116591, 64.03252047877159, 66.7980581714261, 26.216467195941558, 0.19453005594832284, 0.15189640494363923, 0.07699099369347095, 0.3641451859185773, 0.10517067230877378, 0.3232629651263837, 0.25632146685834856, 1.8166702601217457, 23.30402889559346, 41.58324272401872, 56.22387378446518, 49.767346535959554, 76.19662977034046, 42.73959275214903, 57.95106987799368, 7.1380395562418055, 0.31608303588244224, 0.08610145684571997, 0.09242541306922514, 0.08279058571544387, 0.03560166099979993, 0.06917226969474746, 0.03942664224474181, 0.059628572329998984, 0.054881837925002466, 0.02063634407316004, 0.024014027646532463, 0.039372066141016064, 0.04692549772200085, 0.030727474462060683, 0.01896826614205155, 0.047560753150572704, 0.07758184666595153, 0.019278232977094672, 0.111696308839225, 0.040050172697632544, 0.03530875877327016, 0.0482490984722972, 0.0730178625352921, 0.05531129532403523, 0.023388334910475442, 0.04815424529595241, 0.024899387799744165, 0.06148083886552242, 0.13920534642473345, 0.17803912471619346, 0.1404294936406997, 0.22652708174240208, 0.13865443727662488, 0.14443038782525447, 0.17031818418012512, 0.17946660698902223, 0.1486718795833088, 0.13446267994661487, 0.13274267466077883, 0.1668710030254818, 0.2006294181750667, 0.17399747465406695, 0.11260717972031525, 0.09579020912849134, 0.09402468289819457, 0.340726061934425, 0.09606817647093728, 0.13014761310431266, 0.09910024522293, 0.19349194552388885, 0.1325217808686918, 0.11611718008474958, 0.255703417764556, 0.12255217309199995, 0.1946761795590001, 0.13606286908109344, 0.16924529336392882, 0.1798151310292944, 0.11037195732276286, 0.17560751567925179, 0.09515850068700892, 0.15502227350108086, 0.21158415373534928, 9.253693953637155, 69.7975887790803, 65.21478168426022, 62.55057450263732, 38.82718540007068, 58.66710639769032, 94.246106455403, 45.45905436238935, 7.601058194714208, 0.2707599872542966, 0.17704207660450091, 0.36910998725122024, 14.176208703748642, 18.584407567977905, 0.9278535794827246, 0.1137601650289951, 1.8600790082446992, 50.72904894428869, 91.38305864026471, 83.81412367666923, 81.4051765011203, 86.2904336375575, 77.12973025537308, 77.79818058013916, 72.63773779715262, 76.37643121903943, 75.58327305701472, 74.17982547513901, 77.1725154692127, 76.4544471617668, 75.99706742071336, 79.37064309273997, 81.29234560074346, 81.98513815479895, 77.8805346642771, 76.42906942675191, 67.670730621584, 58.51775430863904, 53.475010087413175, 62.40286196431806, 74.80209381349626, 75.7411249222294, 71.41542526983446, 69.45589542388916, 72.78496788394067, 78.7692339189591, 73.44000370271745, 84.73032659099948, 62.48056019506147, 68.90372768525155, 71.57599925994873, 76.11306759618944, 67.56515610602595, 70.43243223621, 45.24120592301892, 45.55654095065209, 85.77326913033762, 72.48212952767649, 78.60831476026966, 72.76805462375765, 73.04834719627135, 67.4031465284286, 72.34594483529368, 69.39343560126521, 70.06792637609666, 61.54778526675317, 54.91792455796273, 53.563596817754934, 56.66831754869031, 55.026272189232614, 58.33141819123299, 54.37913994635306, 59.58611380669379, 55.82596501996441, 56.61802491834087, 63.670736743557846, 68.23814069071125, 67.9128271533597, 67.01656556898548, 72.86576870949038, 76.1113025296119, 75.75657121596798, 69.84843054125386, 69.49535446782266, 67.50199810151132, 65.53867140123921, 71.87901020050049, 70.91248327685942, 71.45737894119756, 71.39720193801388, 65.9227498885124, 69.35884814108573, 65.92248316734069, 65.5996681797889, 71.46464317075669, 64.95723885874595, 22.960023303185743, 0.36226869951332774, 0.3055183769714448, 0.1597977898293926, 1.3573574034437057, 6.463513970375062, 0.539748411505453, 0.35352959748237367, 1.674847038042161, 30.144416939827707, 58.11602123322026, 58.299854878456365, 50.35819668923655, 75.84867631235431, 51.629774185919, 70.34109592437744, 7.813557011465873, 0.3130174278011245, 0.2993388053390288, 0.16121595647306214, 0.1255230927058766, 0.11187582622252165, 0.18005804218832525, 0.15520602735059877, 0.20275220184797244, 0.1400069042199081, 0.1844294931018545, 0.12233667255889986, 0.1613354355457329, 0.09379750718512843, 0.15675847388563618, 0.23129823136954542, 0.14607589872133347, 0.21881605438407392, 0.10118701510251531, 0.23218370643594574, 0.12629622863906045, 0.15298291680312928, 0.12636409636827248, 0.13482819581704755, 0.21775788777778227, 0.10727443401851963, 0.16077620668276665, 0.1825214132306076, 0.11630525467016044], [0.05258709815661273, 0.039741875934264356, 0.013107070117257537, 0.023047391310214035, 0.010225908237419302, 0.03436790321082358, 0.11202775677966495, 0.041186694776819605, 0.05848972517396173, 0.03467132382455372, 0.019458219589244936, 0.042752019249864166, 0.01781777061912562, 0.02434421537233697, 0.012483316541258848, 0.06584092869513458, 0.06892828601262263, 0.031090810812348803, 0.03191619394196859, 0.06677484350098718, 0.013300976546991979, 0.07615532966390734, 0.02044432796537876, 0.03307883387371417, 0.03088250576007751, 0.09559510951681484, 0.02381576600694849, 0.06953347249016648, 0.023020827211439613, 0.019524365535847122, 0.03077193628996611, 0.040453740155264255, 0.09006448330417757, 0.11017632144953936, 0.06172849593924419, 0.09198222354414964, 6.432179625957243, 37.11141909322431, 48.24775757328157, 49.90044432301676, 31.139465378176784, 42.311367988586426, 72.09120258208245, 48.195111520828746, 10.451145518210627, 0.186689329904414, 0.11856188156431723, 0.04938996427001492, 3.2436383347357474, 8.358552205947138, 0.5314356833696365, 0.12836612160167388, 0.34328942277258445, 29.9388631697624, 85.77501066269414, 83.27516648077196, 73.82287409997755, 75.00557853329566, 82.95763492584229, 78.68297315412953, 75.49308992201283, 71.68597467484014, 74.22516022959064, 77.17897953525667, 75.2580536565473, 81.55162995861423, 75.26340376946234, 69.00539552011799, 69.75368961211174, 72.19935801721388, 74.81575935117661, 59.457463987412, 56.052834910731164, 55.038502139429895, 68.80891615344633, 73.12455100397911, 74.92453452079528, 70.83313372827345, 68.74385187702795, 64.23138856887817, 71.97584567531463, 67.81936491689375, 72.50083923339844, 68.5993282256588, 69.60177621533795, 61.505066733206476, 69.09701424260294, 55.57789471841628, 69.98015942112093, 44.187025793137096, 36.57135186656829, 75.41079859579764, 61.818954406246064, 77.12942431049963, 67.23992101607784, 72.90754979656589, 67.74276887216877, 74.19288696781283, 66.58572458451795, 67.24076040329473, 52.71772984535464, 53.67113251839915, 49.73551650201121, 52.84048041989727, 51.26942211581815, 52.85459703014743, 49.36456618770477, 52.19990637994582, 51.04121077445246, 49.67236634223692, 53.75333755247055, 67.25005642060312, 66.89461908032818, 73.95866655534314, 69.86801101315406, 69.07798290252686, 65.47598800351544, 72.46073692075669, 69.50995352960402, 69.11562981144075, 66.8257422601023, 67.35450129355154, 64.86989159737864, 68.69315132018059, 71.71558072490078, 67.26573021181169, 52.72618255307598, 65.2279608480392, 67.54392039391303, 42.60516135923324, 6.962810120274944, 0.3112727391623682, 0.05914977503820293, 0.17851059054655416, 0.15507963816485099, 0.6627098747318791, 0.040919157721462755, 0.06430114559348553, 1.9364167894086532, 28.302824920223607, 52.723868354674316, 60.62205099290418, 28.500098566855158, 27.157408498948623, 33.69785093492077, 43.84935286737258, 9.648131420535426, 0.1842219752049254, 0.10040471675775706, 0.0461529172025621, 0.04267504273523246, 0.04528261450750213, 0.06347045730499011, 0.026515695424149596, 0.027040442669643994, 0.04874022594923454, 0.12170421335125163, 0.02566515396709644, 0.11165215153126948, 0.01746376138931561, 0.03537675290698967, 0.04143439781581683, 0.04984043929125032, 0.0405882268903717, 0.05533259256833023, 0.03990597962852448, 0.05873083219593091, 0.06300796619466235, 0.04179476174495874, 0.029187679869092764, 0.11463688371042091, 0.0332994403828296, 0.0418956057288714, 0.03095811480776437, 0.06890331920717033, 0.06194990301024049, 0.02793710070451902, 0.027530059038150697, 0.012346130303828227, 0.06512035405443561, 0.01411379200421394, 0.04549279072952848, 0.02992651230024715, 0.02624939560079046, 0.03709284348353263, 0.02360856603650797, 0.01986952645013169, 0.05572146262913462, 0.02364311851711283, 0.03818452260607193, 0.03001078388713781, 0.01104969215849715, 0.007960925718033387, 0.06052252798972111, 0.05618372391308508, 0.05171915118191993, 0.0705600456304608, 0.07787285282486871, 0.03598811788364284, 0.040619958252195394, 0.06360241211950779, 0.08212860914007311, 0.022792601957917217, 0.026379741630667163, 0.04129124662628578, 0.00791067609586002, 0.009278461445994195, 0.019024395489043767, 0.006761411101662464, 0.058272941443588466, 0.04885563326458778, 0.05239679808578184, 12.51570761203766, 53.50879738407751, 56.109007173968905, 32.588222219098, 32.62620645184671, 68.24705231574275, 79.48996159338182, 42.687754707951704, 11.224544740492298, 0.28394295082938287, 0.1288029602578571, 0.05923305262601184, 0.6795161890406763, 2.854331082874729, 1.6260854803746747, 0.3869522669382634, 1.4944116362640936, 39.58304966649702, 86.02448125039378, 80.24326062971546, 72.68166049834221, 74.56658686361006, 82.06681759126725, 78.9088781418339, 73.76291674952354, 72.538023302632, 74.46265974352437, 80.08393395331599, 77.86983443844703, 81.86359174789922, 76.71418651457756, 68.33814544062461, 76.955184782705, 77.9105172618743, 75.21031841155022, 60.643345540569676, 56.48715503754155, 55.3079140570856, 69.2612595711985, 75.34930367623606, 76.21094642146942, 72.27724844409575, 69.43578150964552, 65.58233914836761, 71.10868023287865, 70.3555694703133, 76.3447541575278, 68.02240248649352, 68.23628148724957, 63.18769685683712, 71.42170106211017, 60.87951929338517, 68.41391778761341, 46.11132491019465, 38.744439078915505, 77.14928719305223, 62.25171735209804, 77.15626901195895, 68.89549855263003, 76.03440054001348, 70.30149567511775, 74.48719809132238, 68.4845910533782, 69.25325793604698, 57.38797049368582, 53.889922326610936, 52.50747511463781, 53.1699477472613, 53.25023474231843, 54.87946571842317, 50.04388540021835, 53.75470645966069, 51.980065376527854, 52.9736017411755, 56.50394278187906, 67.57375394144367, 67.81625839971727, 75.0846613607099, 70.64718984788465, 72.02958214667537, 65.90807237932759, 73.75875119240054, 69.76161279985982, 71.35443241365495, 68.37773000040363, 69.76562930691627, 67.14685886136948, 71.15237543659826, 72.85287980110415, 67.97811892724806, 55.250282672143754, 65.24172836734404, 72.17775360230478, 52.334667251956084, 10.794605901164394, 0.2479464251307711, 0.17209055923646496, 0.12874122889291856, 0.22960932925343516, 0.3986908483409113, 0.02950841598513146, 0.21517690691736438, 2.730477586869271, 28.83548475080921, 50.77070843788886, 73.09012828334686, 34.16418152470743, 28.682139688922515, 42.439676561663234, 52.96754167925928, 15.632111122531278, 0.10519907118812685, 0.0443344121618617, 0.08689861729620926, 0.10679018984158194, 0.03993971047983055, 0.05050593221019353, 0.07924587390716038, 0.10210805963123999, 0.1395761329800852, 0.06261128203703031, 0.018094753538588845, 0.03814836325604589, 0.029586767627587243, 0.007658702595489881, 0.009524615072164564, 0.026688063291892893, 0.06336795091028176, 0.018163209240282738, 0.00940195003133868, 0.010455281665218214, 0.01901358598843217, 0.039620117750018835, 0.02190270273375415, 0.08667633688497929, 0.058690470853640195, 0.03426823517187469, 0.05744240254223828, 0.056174894749757745, 0.04229784785439411, 0.16260305059052285, 0.13833609710056938, 0.09601776022464038, 0.1630110996625116, 0.0848669980862929, 0.12854550875002338, 0.18784171000363367, 0.1684886129993585, 0.1656803032082896, 0.12414552872219395, 0.17446199972783366, 0.16423141643885644, 0.08726620160403752, 0.10724206680371877, 0.15116621589949056, 0.1527124571223413, 0.18308367580175403, 0.1320724703011013, 0.09702092937884793, 0.19062692990466473, 0.12632509483204735, 0.18494888539275817, 0.12827592240946908, 0.09837015577021146, 0.21894722395846922, 0.3679574845779327, 0.14804215530955023, 0.1734240731645015, 0.08753892890508137, 0.10119078425510276, 0.06380600381582495, 0.08922892652692334, 0.22059814343529366, 0.1907184314463408, 0.15332974012820952, 0.22875083580372796, 9.557265793123554, 64.02598188769433, 68.85576494278448, 62.72972483788768, 45.03749370574952, 53.84443067735242, 87.65704231877481, 67.19156603659353, 19.29704143155006, 0.26024034366972987, 0.26860158049291183, 0.0831274728801462, 12.377204798883009, 23.12285069496401, 1.646540518249235, 0.31559093164340146, 1.193590481435099, 34.46391336379513, 88.48149315003427, 82.07336010471468, 73.5304614036314, 75.07221175778297, 82.05832958221436, 78.94797632771154, 75.09019974739321, 71.34989030899541, 75.74922853900541, 83.51265814996536, 80.36737226670789, 84.16456391734462, 79.18821365602555, 70.88034337566745, 77.45407888966223, 80.15390119244977, 79.85428702446723, 64.16322562002367, 60.2937093857796, 61.62831152639082, 74.57766363697668, 79.01388783608714, 79.3285874397524, 78.49608790489935, 74.01815322137648, 67.21076211621686, 74.93354812745126, 73.0032713182511, 77.84630806215348, 74.74169715758293, 69.93369502405967, 63.85419776362758, 70.15411653826314, 59.924477069608635, 74.86248262466924, 49.34593492938627, 39.45382718117007, 75.19819044297742, 65.03712184967534, 79.07215856736707, 73.14735566416095, 78.817761482731, 74.6086032928959, 79.48127746582031, 72.99414788523029, 71.7972993850708, 58.40804169254919, 58.13877098021969, 54.417975333429155, 57.058483554470925, 56.32515330468455, 56.85112745531144, 53.98645185655164, 56.95229322679582, 54.948534734787486, 56.18389698766894, 58.63531558744369, 74.39856821490874, 72.06195739007765, 78.48497975257136, 73.7374762565859, 74.15425162161551, 68.72137669594058, 77.57874750321912, 76.63025563763034, 76.91914604556176, 70.77014046330606, 69.7394984768283, 70.56049762233611, 73.26662709636074, 72.47605769864975, 65.24162246334937, 60.939527634651434, 74.9283705988238, 74.20829403784968, 47.0084454936366, 9.412299894517469, 0.47266068237443126, 0.3466201279192202, 0.299711246644297, 2.732610130502332, 3.80987512488519, 0.23329433474329211, 0.487482859602859, 3.151353299617768, 43.366469875458755, 64.57369773618638, 72.32032391332811, 42.96570562547253, 39.30938589957453, 47.279798984527595, 64.26013169750091, 15.864233066958768, 0.18897588785377242, 0.2011787951473267, 0.1251083939907051, 0.2000868287418158, 0.10568686235215395, 0.11766612559797303, 0.14798770177989237, 0.14836812572133157, 0.22386385368243342, 0.1936611896681209, 0.12378930549828276, 0.2571262269010467, 0.0957866927849189, 0.14659860051207005, 0.16977705031393037, 0.15693599177945047, 0.14476207325295096, 0.1388553055303712, 0.12801302401649375, 0.15965431688293336, 0.15214052652159046, 0.11249679411130567, 0.11669758361794295, 0.1614044294241936, 0.14553812032024707, 0.1862292787841251, 0.1396729205284388, 0.1517580341427557, 0.13607583128877226], [0.04665605310771254, 0.02731206488885707, 0.0682108523324132, 0.0324074229255559, 0.06600805077581637, 0.024395706056947672, 0.05222189638222899, 0.057168189030621326, 0.0068490544330298666, 0.07736726543836056, 0.04804586300686483, 0.00764313521006355, 0.028490147237936338, 0.029454029488166975, 0.0028822830016349233, 0.052759437296058864, 0.05914755721366214, 0.01708232238137674, 0.05680158531533615, 0.012640887420744666, 0.025375360142319434, 0.13325774621578956, 0.0556435170132787, 0.02120927824909168, 0.05474632846251611, 0.0016680318461317991, 0.0639052888108117, 0.028090783687789115, 0.04634197238051603, 0.056217516051425095, 0.055020147438852064, 0.08360738866031171, 0.0167652826395727, 0.03504852636627132, 0.08659350745860608, 0.033968683302162156, 0.12924517685126874, 3.034407097485758, 31.183197844413023, 54.93182151548324, 64.24496389204457, 36.54821772729197, 38.209168910980225, 68.65803826239802, 75.67137733582528, 21.604962079755722, 0.5895851276093914, 0.15848882135845002, 0.31892975732203455, 1.5966333833432969, 2.098355274046621, 0.1467380285142891, 0.08584163812620026, 0.1499896733871391, 10.607734380229827, 61.53532781908589, 93.06151928440218, 84.2237211042835, 73.64368454102548, 70.39928036351358, 78.58186229582756, 77.74831941050869, 77.8285946384553, 74.78804388353902, 77.93973891965805, 75.99045430460285, 78.19780734277542, 78.64305911525604, 75.9399498662641, 70.69032023029943, 62.42463111877442, 53.243868735528764, 52.19877281496602, 57.90803363246303, 73.93907039396225, 73.03261849188036, 76.13400520816927, 71.76319829879269, 75.19172637693345, 67.74825234566966, 71.49188010923325, 69.00818040294033, 75.4108456642397, 70.62433811926073, 73.14862651209678, 69.21593266148722, 64.88815023053077, 53.83478556909869, 80.79920168845885, 36.85364877024005, 25.66780213386782, 73.80947528346893, 66.86464432747134, 75.29993672524729, 70.43615064313336, 75.46502144105973, 69.79621594951999, 72.40201119453677, 70.14493034731957, 60.876000927340606, 49.388029806075565, 52.58797391768425, 52.40603869961154, 62.71889125147174, 63.57887875649237, 65.93133987918978, 61.80868564113494, 58.81795290977725, 54.52188676403415, 53.37532304948377, 55.46251035505726, 64.55767485403246, 63.64722997911515, 70.81720890537386, 71.26710476413851, 70.33483582158243, 71.41533113295033, 68.61930877931657, 69.84974061289142, 68.07514267583048, 68.37263091917961, 70.1755169899233, 72.64890086266303, 72.33100060493716, 68.71569710393106, 67.31384200434532, 72.4654516097038, 56.41387731798234, 15.52431752604823, 0.6007252104820744, 0.11732481044506836, 0.1785864332510579, 0.203030567556139, 0.1346717300193925, 0.3834582012026541, 0.09572729032727019, 0.03544805271010246, 3.34416157295627, 40.27664630643783, 57.239881407830026, 36.77073378716746, 20.557193063920547, 35.651006929336056, 44.59927866535802, 37.436403151481386, 5.52158962334356, 0.3206333836480495, 0.046232368181189226, 0.04028119800251819, 0.050524628585985595, 0.022275347052322283, 0.10278802395107285, 0.04447205517921717, 0.0163078821835018, 0.061618405274085464, 0.06764767045575766, 0.07544698944735913, 0.014699848308678598, 0.02872521940228199, 0.02644733931388586, 0.07665448957273076, 0.038062932961169756, 0.020311833058874455, 0.08731456473469736, 0.003568195036589919, 0.03879640469207399, 0.0732020224114099, 0.025428534305143743, 0.016165265340297934, 0.02792242820554924, 0.020310662859570117, 0.03480040580935536, 0.013849765546770107, 0.036385196576555895, 0.009718373072363678, 0.06422190528903758, 0.07254740028011222, 0.061024070431989055, 0.06654172294562863, 0.03087084781708977, 0.05771235277455661, 0.05266040894052675, 0.022076133548492388, 0.038688290533759905, 0.07890622116505139, 0.06496495311899532, 0.02994071557036331, 0.03542625367821705, 0.0283072667286521, 0.06211875261919153, 0.04837553362332044, 0.038225244009687055, 0.06072067280089664, 0.035569412528627345, 0.04243031211738144, 0.07083133268620699, 0.0255219683036088, 0.028069781387344967, 0.01779955304828623, 0.024699096027160847, 0.11599036955064344, 0.042440504917213996, 0.03092333824644166, 0.05529851697745824, 0.022380843105155136, 0.05117743508890272, 0.02432919238814183, 0.06932740249941427, 0.027190517378790725, 0.06645340066883834, 0.03558472279579409, 0.03331312271315725, 0.03557686273369097, 8.751608017952211, 51.10166626591837, 63.92675768944525, 45.82841611677601, 27.734765698832852, 55.68484990827499, 83.81777932566982, 72.47866999718451, 19.42302207792959, 1.4387941432576028, 0.28833949878331155, 0.049124292638753696, 0.639287318673826, 1.1443095774419847, 0.8333008628218406, 0.3005815838133135, 0.22868007992304143, 18.62739282269632, 69.57535512985723, 91.7077132194273, 81.23887585055444, 71.99918377783992, 68.14864789285969, 78.54208946228027, 77.01991173528856, 77.82785723286291, 75.97171321991952, 79.18156916095366, 82.02112197875977, 81.28224157517957, 80.52700488798081, 75.42094968980359, 70.98304671625938, 65.0650099016005, 55.39224893816056, 54.60528812100811, 58.975290944499356, 76.76771902268933, 76.3017806699199, 79.28877538250339, 72.27829963930192, 76.86563707167103, 68.87444326954504, 75.03821265312934, 72.94041141386955, 75.99954635866227, 71.07923892236525, 71.88757665695684, 68.16918542308193, 66.35241416192824, 54.51816051237045, 78.70951191071542, 39.30451039345034, 29.603137700788437, 70.7409501844837, 65.4431224638416, 75.7953477674915, 71.25151726507372, 75.83061772008097, 71.84036700956284, 74.32179958589616, 70.57919163857737, 65.44066313774356, 51.596030035326564, 54.15563937156431, 54.71019975600704, 62.675658887432476, 62.75687548422045, 64.66227662178778, 61.18237726150021, 59.11302889547041, 56.45463466644288, 55.270639773338075, 58.19271141482938, 66.33314747964182, 67.55972754570746, 71.95484530541205, 73.04871589906755, 71.36632504001741, 73.07420346044725, 70.33331394195557, 69.98901613297002, 70.28792427432153, 70.49500972993913, 71.48462372441446, 74.3254787691178, 72.45656351889335, 66.98217422731462, 67.03922902384113, 74.28333682398643, 63.89151519344699, 22.428206782187186, 1.8566511018622307, 0.15081807490318053, 0.29495748721303483, 0.31943390446324504, 0.2955316547905245, 0.05193496198062936, 0.06217865303399102, 0.09709926952998485, 3.550680736380239, 37.17644414594097, 68.70216492683657, 58.7505744349572, 28.583633284414972, 36.53891386524324, 47.67789602279664, 48.30237657793107, 10.660532424526831, 0.331432189672224, 0.037018019675968156, 0.045614506778938156, 0.017489570891484618, 0.02795185364272085, 0.013533310904618234, 0.030800365812836156, 0.02385150209339636, 0.06268003459779486, 0.06534245826544301, 0.0188833529565243, 0.049322314875861334, 0.06441308636098139, 0.028735226425792904, 0.018213108377230745, 0.018646616466163148, 0.027034114783389435, 0.08137550640610919, 0.027321436059390827, 0.04986705318573983, 0.09364938408496881, 0.01022445458558298, 0.027971454002263568, 0.01838729953423383, 0.021185579319154064, 0.04785024245539981, 0.031530112441208576, 0.018608963244684765, 0.05455851434699951, 0.010384974903577279, 0.16182050709762882, 0.13312879829637467, 0.17546384354993222, 0.08351581817072246, 0.17138076345286063, 0.09308933550792356, 0.12322269154772644, 0.09340402144458025, 0.2561626874751622, 0.17219972676567494, 0.16123604329843677, 0.15354272789291798, 0.08374508530382188, 0.12526073823532752, 0.1599711095613818, 0.18429070861349184, 0.13968559162270638, 0.12525761259659646, 0.11675443500280382, 0.22552917561223432, 0.15357430603715683, 0.17518760756619517, 0.24454203764757804, 0.10937933719927266, 0.19600475988080426, 0.11260315009783353, 0.2765276793751025, 0.11114308610558511, 0.15373598123269697, 0.15624859640675207, 0.13249677575884328, 0.19140472365242822, 0.1551507311242242, 0.17523916528349923, 0.2130660895378359, 0.1542654552406842, 0.19392624076816345, 7.081571644352329, 56.967323749296135, 81.08143975657802, 79.28697893696447, 54.106550908857784, 57.062562819450136, 80.80206501868464, 91.91196672378048, 32.90013105638566, 1.61477483568653, 0.4942541269044723, 0.45494005744976385, 7.769422502286973, 6.225166243891563, 1.5014644255561214, 0.19863556709981736, 0.4001989383851329, 14.222783907767266, 65.89102575855871, 93.9936548663724, 85.10077876429405, 77.74971577429002, 72.60595875401651, 78.17383381628221, 77.90070349170317, 78.38828548308342, 78.4968331552321, 78.93600525394564, 82.22748571826567, 83.1955345215336, 87.5641841273154, 82.72307718953779, 76.89585501147856, 67.65007542025658, 58.56432853206512, 56.10654392550069, 62.72555143602433, 79.77824795630671, 77.77084950477847, 81.41433131310248, 76.56042175908243, 79.80345310703402, 75.6315338996149, 79.83109012726815, 76.60741175374677, 80.20438994130781, 72.99120610760104, 75.27313909223004, 73.59051289096956, 69.89664431541198, 59.633539184447265, 80.12793510190903, 41.58988721909062, 32.054197403692434, 72.6221267638668, 68.04483059913882, 79.3198876227102, 73.03476010599445, 78.29300326685753, 75.86638973605248, 75.72336443008916, 74.66250450380387, 68.40632407895981, 54.850530393662, 59.78671950678672, 58.19808506196546, 68.4236531103811, 70.29731442851406, 72.08491894506639, 68.6944535470778, 63.28817229117117, 61.518795028809585, 60.98909854888917, 60.563709658961145, 71.99905826199439, 69.72712732130482, 72.85876335636263, 75.14268890503915, 74.80903640870126, 77.7534184917327, 72.6841002125894, 71.48472570603894, 69.96497984855407, 73.86527492154029, 76.44763008240731, 75.53888751614478, 73.69708368855139, 68.66540447358163, 71.6871121621901, 79.7980716151576, 60.06620014867475, 18.813217070794877, 1.5341989335513886, 0.3300730884075165, 0.4588815491766699, 0.43053985062626104, 1.154844696002622, 1.3823664356623928, 0.5006883768064361, 0.15086468369249376, 5.686592459678651, 55.323607460145034, 66.6902086811681, 47.47616852483442, 33.36100562926262, 48.753617809664824, 61.60167471055062, 60.03725305680306, 11.380797259269222, 0.39890976562615366, 0.14074216476611554, 0.14999595530811818, 0.19183385546409315, 0.20371083831114156, 0.322737765889014, 0.10260145089799359, 0.14630221641592442, 0.10306556994516043, 0.21306722334796385, 0.13835455981954453, 0.09914434890473083, 0.14748168538414663, 0.10457875447407847, 0.23554442690745478, 0.17657431863969372, 0.07276535995544926, 0.2073738264340547, 0.13095001359620403, 0.15555096609938532, 0.18875474891354962, 0.12237812557648267, 0.12461385359206509, 0.11992974687487849, 0.1770703912141823, 0.16530913360897573, 0.13898753230610203, 0.0978938099597731, 0.1331941455963158, 0.26269390878658144], [0.04984558357166187, 0.018831540514985402, 0.031863632649483706, 0.06828304845839739, 0.019544009945445487, 0.08704683232691982, 0.033065028969318636, 0.05545731934328234, 0.015423192357223843, 0.07704719390359617, 0.009838289772761206, 0.006516323774121703, 0.08192582566651606, 0.04698998317302716, 0.10521724279369078, 0.06589582655578852, 0.04094345803042093, 0.01982103499974455, 0.03715062949566111, 0.03999349368255466, 0.053525950399137316, 0.02461730464992504, 0.06051233902032818, 0.05688454497665648, 0.007024943432395137, 0.08559576986778168, 0.041010115340712576, 0.07302593710201402, 0.03884022492134283, 0.07012129175446688, 0.04059872229493434, 0.02979142610133896, 0.049349143274969635, 0.05893951454650491, 0.038799829105095524, 0.09615495125012052, 0.03275766683321807, 0.12073809220906227, 1.4047711366607298, 22.77235357992111, 56.521071772421564, 58.294077227192545, 38.96191097074939, 36.58027133634014, 44.17179915212816, 81.7199702416697, 36.55477985259026, 3.931541899519582, 0.2360996414696978, 0.08234205655753613, 1.3297026099697238, 0.9118296554492367, 0.12454841436157305, 0.07766460714441153, 0.606436733036272, 0.6611858500588326, 21.628296259910833, 67.34671931112966, 86.3909718298143, 85.64480366245394, 74.61623622525123, 78.76870832135602, 78.27709413343861, 75.81056656376009, 79.93598999515658, 76.57436186267485, 73.91585780728248, 70.11258648287865, 72.03002145213466, 68.29441101320329, 62.46391365605017, 57.18363854192919, 56.74648254148422, 66.01345077637704, 79.08649875271705, 73.16728130463632, 74.77157777355563, 77.76484043367448, 72.97412810787078, 68.7961135372039, 67.76613835365542, 71.72750473022461, 74.98036553782802, 73.35804970033708, 75.45934184905022, 65.47105366183867, 63.55301464757612, 64.12961090764692, 81.89803015801215, 35.742558971528084, 23.42081746747417, 83.6401116463446, 70.09956421390658, 77.02389686338364, 70.35034487324377, 73.94752702405377, 71.09703079346689, 74.87843882653021, 67.82523278267153, 57.386338787694136, 52.01624531899729, 58.66494517172537, 65.92922964403706, 71.82110032727643, 71.33979412817186, 70.14197288020965, 65.79168388920446, 63.383619246944306, 59.01933916153447, 60.66191011859525, 58.21871280670167, 68.41827946324503, 72.47120964911677, 77.47974688006987, 75.10198254739085, 70.05108371857675, 69.02895327537291, 71.57516771747221, 68.44877981370496, 75.62091212118827, 73.43826217036094, 71.87016917813209, 70.41936289879584, 76.7103425918087, 80.7803664668914, 61.4721502027204, 21.28404159699717, 2.347749375527905, 0.1072351107253663, 0.13722565265432482, 0.13485588223463105, 0.1611045979323887, 0.816851668059826, 0.15944555792356693, 0.09340447343645558, 0.03234251995661086, 8.624737974136107, 57.18769035031719, 55.45211215173045, 24.991307027878303, 20.46646275827962, 37.93788994512251, 53.15767857336229, 19.698056713227306, 0.7305128235490091, 0.04032641251180922, 0.06044636735872877, 0.05065061174513352, 0.00939733243637508, 0.00409006777655093, 0.04855873588953288, 0.04019501694147626, 0.05420019970305505, 0.020139503495527372, 0.10142037314513039, 0.02927136539872135, 0.021588422823697332, 0.0209990962814059, 0.09423777791521243, 0.08784409236883925, 0.04868165469698368, 0.046740280644547556, 0.06141992721466288, 0.01537505713772149, 0.005750907613189832, 0.027218284235606273, 0.05648378523126726, 0.025867971914610075, 0.0549767179144246, 0.009487936697569827, 0.02151092728449693, 0.026450407496022604, 0.0656862095779469, 0.045806806339251424, 0.07078983370334872, 0.047694274614895546, 0.06167654751709873, 0.030917111866837068, 0.03152649076054654, 0.010091670480887256, 0.0097079427852746, 0.031721391189362735, 0.029736256279471903, 0.04269357823256043, 0.04594999200273906, 0.008926858689876334, 0.012682433326488302, 0.03297420158501595, 0.04371963043306624, 0.018763630650937557, 0.11731315824774005, 0.007807004289896859, 0.032730620099051345, 0.042857509557037585, 0.03764505498111248, 0.01874555480636416, 0.016809664028246078, 0.04354393582851176, 0.05786375090059254, 0.03205404380306361, 0.0145375564123594, 0.07821694887693852, 0.018983605137515455, 0.013543338037937159, 0.07483262523648239, 0.14893231883404717, 0.031872567149900624, 0.07825942845233987, 0.010517950530254073, 0.05165311823328657, 0.056569947140111085, 0.09323816340897353, 0.06143660494877447, 0.07896899440956694, 4.556576244292721, 37.64415148765811, 71.18578618572604, 55.17387882355721, 35.52694628315587, 45.95409670183736, 73.50601719271752, 90.2499565001457, 29.979767607104396, 4.3895818245026375, 0.1640401549276806, 0.07687556722591962, 0.3636388937311788, 0.5652023875905622, 0.338596674583612, 0.1734816829764074, 1.2575745125932078, 2.182676181677849, 31.667528190920432, 77.12462332940872, 87.27099480167513, 82.8744649887085, 73.49468154291954, 79.36464186637633, 79.31987977796986, 77.22492617945518, 82.34900074620401, 79.07309993620842, 75.5983663374378, 73.47131206143287, 75.96836351579236, 74.78684363826629, 64.22243772014495, 57.81044506257581, 57.05104281825405, 64.87065253719207, 81.87147571194558, 74.67826458715624, 76.66921261818179, 77.36790441697644, 73.84853424564486, 68.90451215928601, 68.04248502177578, 71.30403780168103, 75.33706588129844, 72.51495192127844, 74.82667922973633, 67.3896457302955, 65.56001693971696, 63.688854171383774, 82.0063267984698, 38.674358091046734, 24.767380875925866, 84.41769015404486, 69.47153783613636, 77.47923697194746, 69.80232700224846, 77.03052566897485, 73.23747604124009, 78.04481137183406, 72.40241912103468, 60.438072219971694, 54.09840806838005, 59.93334947093841, 67.34917471485754, 72.07839996584, 73.75047499133696, 72.42556110505136, 67.84788839278683, 64.87281376315703, 60.48244207136093, 61.261071774267386, 62.2717567413084, 70.71791802683185, 74.44304004792245, 76.5332083548269, 74.13045852415024, 70.29155638910109, 70.99002069042575, 73.74570538920742, 72.27454200867685, 76.00063677757018, 74.19884897047474, 73.97754884535267, 71.34487751991519, 74.47834137947329, 78.72475424120503, 66.24502751135057, 30.6737623676177, 4.767119269217215, 0.19376311000556717, 0.11209662042317853, 1.328238217580703, 0.10942878051390571, 0.39277735436635636, 0.11453906960424878, 0.13207078490766788, 0.08375635445718804, 6.279848987056363, 56.10239013548821, 75.37844688661637, 42.691657466273156, 13.815430075891557, 33.972628654972205, 60.90747402560327, 29.39973338957756, 1.4166740592448943, 0.08861768795477767, 0.047223896629387335, 0.039003252262069334, 0.026163992118991675, 0.014961478826139244, 0.07646182612065347, 0.06584614575389894, 0.03754564358161823, 0.026981417510297992, 0.09158244056086387, 0.03545277564215564, 0.0026620485239677253, 0.04331704356797761, 0.08100775355893759, 0.04937160114246992, 0.015622309142453297, 0.027641026873982726, 0.035554600218611385, 0.0337267910400706, 0.06687376843464952, 0.08763183238765887, 0.02413332285810142, 0.09144795382575643, 0.045209644632714416, 0.03723854574585154, 0.028067532919287205, 0.05989694825163292, 0.022818467001460736, 0.05167349617207243, 0.030299261955904867, 0.03746335041679202, 0.21516509384157198, 0.119298635981977, 0.07710990586107777, 0.11986118200565539, 0.1162806019607571, 0.20071978590661482, 0.11280414092564776, 0.11572597728621577, 0.14182159797318522, 0.1755033890085836, 0.07081597262332517, 0.1523278809843525, 0.1342760915717771, 0.1226061056818693, 0.2751716731056091, 0.15784343824751917, 0.11670863826669033, 0.17934139757867784, 0.20884820860960793, 0.0985492058398743, 0.16604675370598995, 0.10366996735214226, 0.19840359567634522, 0.10985906911833633, 0.16777576818581552, 0.1902689983046824, 0.19737440251534988, 0.1675919990145391, 0.17760300618265906, 0.30099946945425005, 0.1286697528895832, 0.21916463971138003, 0.13419494753883732, 0.13682379357276425, 0.12488948436634195, 0.24241850320850653, 0.1295946661623255, 0.245641925402226, 2.892594539350079, 37.66352799630935, 81.46206655809956, 74.29482936859131, 54.05403429462064, 54.01486942845007, 59.086556819177446, 97.3849125831358, 55.04731962757727, 7.89224858245542, 0.34259396815492266, 0.13366847659551329, 2.5888202075035345, 3.054602155762334, 0.4275269800376508, 0.1328522405557094, 0.7195168877801588, 1.2953763551289037, 25.307759931010587, 72.71596554786929, 89.38375596077212, 83.14733643685618, 73.2942876508159, 80.09313583374023, 79.06713008880615, 75.99729491818336, 85.32439308781778, 83.23686061366912, 80.01558273069321, 74.77026770191809, 76.8126380059027, 75.12181405098208, 68.31896505048199, 63.073677478298066, 61.75609450186453, 71.21412138785087, 86.76873530111006, 78.33130913396036, 80.07299054053523, 83.43683088979414, 78.71803129872968, 74.49408577334496, 67.4759300293461, 76.77272396702921, 79.6810830023981, 79.29421963230257, 77.23208842738983, 67.31668180035007, 64.25041206421392, 65.69356579934397, 83.05373299506404, 41.05265978843936, 30.681340386790616, 82.20552829004104, 75.31143711459252, 80.0389051437378, 73.20973703938147, 79.5481538772583, 78.07193848394579, 82.80310138579338, 76.1247641040433, 61.71612162743846, 57.9918860620068, 63.490088062901656, 72.33896301638696, 77.13249160397437, 78.59593576000583, 74.19901371002197, 70.72727680206299, 69.7470372722995, 64.16771673387098, 65.30839297079271, 65.41639151111727, 73.22697977865897, 78.76695894425916, 80.6030753351027, 77.99680156092491, 71.15770986003261, 71.85110645909464, 78.82230358739054, 77.0988533573766, 83.39013899526289, 76.37216368029195, 73.84910691169001, 73.84662012900077, 77.13538631316155, 80.5451419276576, 65.84012908320274, 24.95871605411653, 3.6104201501415627, 0.17862890516558003, 0.22687825644689225, 1.1114243033432192, 1.4368727947435072, 2.438248751624938, 1.2273103623620927, 0.41841246428028234, 0.25705205426821787, 15.392220923977515, 73.5042207471786, 62.93147194770075, 37.98635867334182, 31.246783387276437, 50.485995354190955, 73.13168971769272, 35.28040570597495, 1.6058011881766783, 0.1939115931670512, 0.18994802278616738, 0.11905639131944026, 0.1517969973745846, 0.1920366542594087, 0.11389587750478138, 0.11005789957820408, 0.15011643029509053, 0.16820479274517106, 0.1755553297698498, 0.07989446692649396, 0.12052574029733097, 0.10798462050696535, 0.17518244413358552, 0.16535159020173937, 0.11583106922766856, 0.24546330434180078, 0.08826212356648139, 0.21819923103096026, 0.12520023261106786, 0.1810711781464277, 0.13453651550075701, 0.17403069222646375, 0.11745535182736574, 0.1483190194853852, 0.16587556369843023, 0.1286004525759528, 0.16459766775369644, 0.12564351406669425, 0.1543675287957153, 0.10625543748779644], [0.03862303516436969, 0.030442905356927268, 0.012994161206147364, 0.0845209178664992, 0.03415483500688307, 0.021518563265882192, 0.010113699339149941, 0.054348797777727734, 0.051228567627408815, 0.03365389011319607, 0.057379702076075546, 0.045525230722682136, 0.029900777491650758, 0.0779933737771165, 0.029482503061092673, 0.05292523404463165, 0.0640190988328428, 0.04259139359478028, 0.02803237331400235, 0.05783445186792843, 0.04255755932160443, 0.023294874098933032, 0.013815355750041143, 0.087116630597701, 0.0572162380652322, 0.0438141924959998, 0.019590028847057014, 0.0070332933119648415, 0.027440457394526854, 0.0915155993894704, 0.023889817980929248, 0.028120686014693592, 0.10548987816418372, 0.03541893370810055, 0.021623505820189754, 0.04591183316323065, 0.019409839221606814, 0.00864705943968147, 0.10514996495218047, 0.24707952003565528, 15.124461304756904, 57.555012472214244, 64.32218751599713, 53.52296106276974, 35.53543036983859, 34.592194480280725, 76.74132147142964, 64.17001132042178, 16.88738234581486, 0.12794662717609637, 0.0703877677780486, 0.3216639864108255, 0.2056314360590712, 0.383474258405547, 0.4797173633931145, 0.08108581025754252, 0.40153717141478296, 1.4077943034710423, 25.029871771412513, 65.27218949410224, 90.59195580021029, 77.98676029328378, 77.34002420979162, 78.45675437681138, 76.8571255283971, 73.1592639800041, 80.77525169618669, 82.17600068738385, 80.88953387352728, 67.41252883788079, 62.532453152441214, 57.52989361363073, 56.9868806869753, 68.14918133520311, 77.58878877086025, 76.32823313436201, 77.53152216634443, 75.53771864983344, 78.32858700906077, 70.72044403322282, 74.07724765039261, 73.15438455150974, 75.22135596121512, 73.36274869980352, 77.42877960205078, 72.32739986911898, 74.45519155071628, 71.20611975269934, 72.77064338807138, 34.8719379209703, 41.68635791347873, 79.33128603043096, 68.60714158704205, 70.48429381462836, 73.82280349731445, 75.82656983406314, 72.00538896745252, 74.11394534572479, 59.64676149429814, 52.55822666229741, 59.339467325518214, 71.32165708849507, 74.85672458525627, 73.85301359238164, 76.17896341508435, 78.49037693392846, 77.0238027264995, 72.81207930657172, 67.03063118842341, 63.828729814098736, 66.234907796306, 67.27197462512602, 66.3158498271819, 69.89017240462765, 72.70421412683302, 75.65247151159471, 76.58681931034212, 72.3891144414102, 78.02366979660528, 71.85657424311485, 76.48457880943053, 81.3962648760888, 84.43952991116433, 74.31727317071731, 32.30409356855577, 3.1490918080652914, 0.15745645659344812, 0.2529176156367025, 0.7601888021153789, 0.47206527883968047, 0.9223571131306311, 0.5292357239992388, 0.11400846178613364, 0.12944023815854905, 0.20984272863115036, 21.046041980866466, 65.78368225405293, 42.99127163425569, 20.650298364700813, 35.80005699588407, 58.03718159275671, 50.66220391181208, 15.01618133437249, 0.8424885859412532, 0.04239613693507929, 0.05043108541999133, 0.06845426910947408, 0.015017866727805909, 0.026808745122604796, 0.04604502137930644, 0.05596583701610085, 0.05971270793628308, 0.07851084318733023, 0.06292436684992525, 0.041558427450757836, 0.046187544376739574, 0.08931865840549431, 0.07622899667870614, 0.02247539367676983, 0.018889175224748832, 0.08328030742104016, 0.026543257352445396, 0.035004384380074284, 0.03561510967331068, 0.052122462000097, 0.03874930943692884, 0.0275333704532034, 0.06805320675935476, 0.046446125864261584, 0.02803239438142027, 0.06737020107046252, 0.033657057886762966, 0.12336633303352904, 0.04722982998036089, 0.013979451783422022, 0.07162401152233924, 0.02433875316543685, 0.052227117271432956, 0.04841700579310137, 0.053975023479471286, 0.05140828802400539, 0.05579278541488513, 0.02387285487906587, 0.05423091216793945, 0.06956780855093272, 0.049269087086882324, 0.06275187066245465, 0.027557994434309584, 0.04238765251131789, 0.06512761656795779, 0.028029630719233426, 0.08820432989347367, 0.07797808266214787, 0.07499099093218965, 0.013375293778916521, 0.0384175933657154, 0.022525840566583702, 0.033003910474719546, 0.04243210093268464, 0.09903004092554893, 0.07811312098056078, 0.03232813665583249, 0.01436516460436847, 0.011809264504981619, 0.05150719380546963, 0.049724775336442456, 0.10767349687915657, 0.0508146196784031, 0.014232093216701141, 0.05635942234807918, 0.025459865386027004, 0.03410452218245595, 0.012532538648003773, 0.018940803805185903, 0.10087144816474569, 0.8651496506025715, 28.030818354698923, 70.27128558005057, 65.06623760346444, 46.69815463404502, 30.55314556244881, 57.91268948585757, 94.03851893640335, 61.96799662805373, 11.249011505034662, 0.20919290221025869, 0.19409330922269052, 0.07465399651517791, 0.15524195687424752, 0.7744014491477321, 0.5696612644580104, 0.7287068172327934, 0.2676361564907336, 3.562745211585876, 35.04383971614223, 72.38461156045237, 88.51866937452748, 75.99020327291181, 77.25570894056752, 78.0312321262975, 77.65297443636003, 77.81610581182665, 84.21564102172852, 85.28527921245944, 77.87247811594318, 67.93269788065265, 61.36572061046478, 59.3753295560037, 59.71597563835883, 70.68334625613305, 80.50123491594869, 78.89105489177089, 79.55718317339498, 79.28440586213144, 79.03948522383168, 71.61651734382876, 75.3551087840911, 76.30508330560501, 77.05907267908897, 72.81674692707678, 78.1929906722038, 71.55176685702416, 73.93294365175309, 69.68226325127387, 72.51476364751016, 37.280441868689756, 40.23305700671288, 76.23397073438092, 70.55249598718459, 72.99959213502946, 74.19171025676113, 75.10665801263626, 74.33223309055452, 76.26264326034054, 62.18860641602547, 54.98663271627119, 60.155532129349254, 71.59199468551144, 74.71825707343318, 73.88101931541198, 77.05711933874315, 78.01815494414299, 75.1758643119566, 74.80313716396209, 68.57110284989881, 66.6822462697183, 66.6487806074081, 69.67033140120968, 68.74948440059539, 73.16102904658165, 75.69554698082709, 76.45849504778462, 75.99303522417623, 71.0307192033337, 73.92203946267405, 73.72573268028998, 77.70409076444565, 79.53309982053696, 84.97501188708891, 79.12855440570463, 40.65216225962485, 8.181590062956657, 0.18397334902997942, 0.19460404472004986, 1.606510524307528, 1.8969664482339736, 0.34535409101555425, 0.6522905273783592, 0.16356579328496612, 0.07887835088636606, 0.2564260991470468, 17.912338856727846, 77.56719220069148, 66.45607456084221, 28.314138996985655, 20.043195870614824, 48.01934619103709, 60.141450820430634, 26.266426424826346, 1.983108929088039, 0.09820441264779338, 0.09347473135999135, 0.10452106805338014, 0.017613075756197496, 0.017201973823830485, 0.0742425536736846, 0.08609811670237011, 0.06052367329116791, 0.04721487211363931, 0.041474452722937837, 0.05111750020014663, 0.031776970868269284, 0.10967841026403251, 0.039725673174665826, 0.05138989808338304, 0.047604868323692394, 0.06476708026903291, 0.10095318208538717, 0.015768673113216797, 0.06397635495710759, 0.11869266809475039, 0.021777227107856064, 0.04146018433534811, 0.03825986735342491, 0.05619091747869408, 0.025185630806992133, 0.02833956691075958, 0.017849421541717266, 0.09074200380353198, 0.017959439428523183, 0.05211687338868937, 0.20434646146191707, 0.16510754523258056, 0.13993692974890434, 0.12209832728389772, 0.21252844903257587, 0.10674755704859573, 0.08245773583410249, 0.193496051755163, 0.1209560135800031, 0.2217828984101934, 0.12210921339330175, 0.22846503904269588, 0.0961013633998171, 0.23865275205143038, 0.14258025484460016, 0.1387998714081703, 0.170770819569307, 0.15693597645769197, 0.13128726082223077, 0.14449012736158987, 0.24606158836714684, 0.12837697706756093, 0.15515376483240437, 0.1198979465651416, 0.1726093693005462, 0.1832589413970709, 0.22112251529770516, 0.11318828805439896, 0.1573979274760331, 0.13946198587936742, 0.2228303857508206, 0.2943661286225242, 0.14412594448414542, 0.19652954543069487, 0.20898348441527737, 0.13508671984797524, 0.12682046260564558, 0.10612507230572163, 0.12086488742140994, 0.18562561682155057, 0.49103808979834285, 25.855083542485392, 82.64284903003325, 82.87426887019988, 68.52632507201164, 51.24648409505045, 46.481298554328184, 88.19125344676357, 79.93968486785889, 24.85640887291201, 0.2951991726313868, 0.20778722279975492, 1.0514409671868048, 1.2307491778366029, 2.09139306699076, 1.3385762370401815, 0.5657095990834698, 0.44107061780748835, 2.0366827446606854, 28.28500755371586, 68.12473712428924, 90.78546201029133, 75.50483349830874, 76.36631150399485, 81.43736347075432, 78.30942230839884, 77.5412182654104, 84.73012262775053, 92.22724683823125, 84.12875267767137, 73.66123322517642, 66.29065252119496, 64.5813032119505, 61.74406851491621, 73.49935700816494, 82.30427788149926, 84.10385347181752, 82.28745091346003, 81.65278004061791, 83.40229049805673, 78.05695502988755, 83.1719453873173, 81.98668356864684, 79.53781450948408, 76.35772151331749, 82.02712320512342, 77.55675085129278, 76.21926969097507, 73.77723340065249, 68.68717362803798, 47.84003111623949, 56.37954088949389, 74.15494195876583, 73.72068851224839, 72.2638653170678, 77.80950838519682, 76.81130440004411, 77.6576263673844, 78.77752580950337, 63.66974830627442, 57.745616128367764, 66.79924272721814, 77.00362605433311, 81.41759472508585, 78.3815860748291, 82.02852741364511, 84.5447043449648, 82.54011431047994, 81.23776974216585, 75.57534986926665, 69.99340134282266, 70.76056988008561, 75.52652420536165, 72.1362784601027, 74.98778666219404, 78.06001447862195, 78.1514919957807, 79.34489665492889, 69.85593795776367, 77.93447509888681, 70.87596601055515, 79.8850933198006, 80.91079311986124, 84.74715355903872, 77.98089242750599, 37.08464107205791, 5.045120196957742, 0.20322467891439316, 0.3065787958762338, 1.0894346381387403, 2.0735460375585864, 4.5306062313818165, 4.22579933558741, 0.867183705972087, 0.32759997272683733, 0.7413722730932698, 31.524816674570886, 80.21185028937556, 52.72291914109261, 33.28408402781333, 46.93955690630021, 70.20739016994354, 71.05136655992078, 28.156814690559145, 1.6143982881499876, 0.13102761830293363, 0.26997811791877596, 0.18434503956908183, 0.09121657995086524, 0.22084781148981666, 0.1267882103040334, 0.23270861455990424, 0.1979745251517142, 0.2097322740742276, 0.13538495787689764, 0.17055337317287925, 0.270892643039265, 0.18482989661635893, 0.11237600502828438, 0.1540842448030749, 0.15065998499912603, 0.24250491792636536, 0.18135060105592976, 0.11802642440964138, 0.11155236091825271, 0.1306016734170337, 0.08137808812241401, 0.23446280268892167, 0.11231829562494833, 0.09925959151118033, 0.1449910262900014, 0.14184819654591624, 0.14176403412655478, 0.2751335832140138, 0.1661911766014753, 0.21037865309946, 0.329834068975141], [0.11994382757092677, 0.051420817392007004, 0.02495156604826691, 0.062172654565543904, 0.04981168418101246, 0.034305700701811624, 0.0864992633221611, 0.022889268847422737, 0.039697308769269336, 0.059299173674756483, 0.011287158347606178, 0.05716997018504528, 0.030053380290947618, 0.08929878608473847, 0.013526478357943557, 0.14116239463610036, 0.015300704474230448, 0.09699362600522657, 0.06534606653956637, 0.07444395818897794, 0.05523765129187415, 0.0826157721120023, 0.06772958057662172, 0.0646300731046546, 0.018152420807089058, 0.05209153120015418, 0.026806086797507542, 0.050283762881712574, 0.020154616495053616, 0.010438066711949726, 0.05172424566661639, 0.026204227056774883, 0.03529661244923069, 0.028862722608591282, 0.10523883881227625, 0.007915747597918757, 0.06184386495020121, 0.05454869693024986, 0.07054261713018341, 0.044496704058180896, 0.039059406506919095, 4.660024344921112, 41.94862719505064, 65.55665546847929, 59.15884217908306, 39.75789323929818, 28.345476773477372, 51.68083952319238, 72.82827085064304, 41.31072036681637, 2.150658364257505, 0.4393794633928807, 0.346624601872698, 1.0693609281893701, 0.7401375845074655, 0.06965234635337707, 0.2133834950866238, 0.14125916686269546, 0.26807604417685543, 1.3979888683365238, 24.80568870421379, 73.88073690475957, 86.15338602373677, 76.74720502668812, 91.01582281051144, 89.359829502721, 81.5898181546119, 73.75975531916465, 74.92568769762593, 74.39251207536267, 75.12713278493574, 69.69962366165655, 64.02302834295458, 70.65289297411519, 78.33335661119031, 80.09071180897375, 78.30965765060918, 78.14673808313186, 72.9742536237163, 74.91314395781487, 74.6383583930231, 74.62797980154716, 73.70001762144028, 75.51132109857376, 70.5926924367105, 66.50435109292307, 68.55742946747812, 73.22335550861975, 70.0745394922072, 39.62767054957729, 37.3975089288527, 64.4844481252855, 78.36366868788197, 72.56581721767303, 79.13694043313303, 74.36751088788434, 78.32990492543867, 65.93834523231753, 59.432957018575365, 57.673907356877486, 72.97521852677869, 72.91927768338111, 76.03545173521965, 73.84334102753671, 76.4795660203503, 77.14069720237487, 75.87574851128363, 70.68153412111344, 71.34922350606611, 68.71538331431728, 67.9128271533597, 70.51095024231942, 76.93671826393374, 79.5429841933712, 80.48746739664386, 74.542707474001, 72.14377803187217, 80.25493360334828, 71.27187436626804, 70.20445623705464, 76.49086244644658, 72.220962432123, 45.71210607405632, 11.418361798409494, 0.5580280661102265, 0.020824853413467927, 1.3852753634414365, 1.0203294624244015, 2.2921755188895814, 0.7223659994140749, 0.9598771578842594, 0.38871111288186044, 0.217484011344852, 1.5467942770450347, 35.41947726280459, 62.1536071069779, 23.381997769878758, 20.601327573099447, 41.73358717272359, 56.970712677125015, 44.1189883601281, 7.000991452124811, 0.4098212478622314, 0.03155730090164129, 0.10971759566135945, 0.036718192014602885, 0.05160128472432975, 0.05004237623765104, 0.030614782928399024, 0.021419111646771915, 0.027820921555582075, 0.053089904643955736, 0.013572232959221208, 0.017989799492962418, 0.08015345061017622, 0.07658426229271197, 0.02516975171954161, 0.06654689403911752, 0.01369251546660258, 0.03636456965919464, 0.024481040590833274, 0.025551255844954043, 0.031036757563631383, 0.14854789591364323, 0.008171282449526893, 0.05048816280078985, 0.03979873114956483, 0.027777108987192475, 0.03557064976062506, 0.02904239129425297, 0.030684115800766215, 0.058228742000797105, 0.060317710552725105, 0.027835586393672614, 0.015263697639438174, 0.03564427464058803, 0.07450769670427808, 0.006114357440251738, 0.06805623280665568, 0.016998131233718128, 0.024678373348809058, 0.0933823028519269, 0.06681266526180892, 0.0297890167548171, 0.07012388113165094, 0.07423196633857104, 0.032303974242700685, 0.045314985552742604, 0.05057484564942218, 0.0402162337465392, 0.04375330765821761, 0.06763099272164606, 0.024348302451413006, 0.10518263860215103, 0.02677893472625123, 0.08769144168904713, 0.02490330442425705, 0.005116349803434024, 0.013629734561207795, 0.0101072488788275, 0.08769488908470639, 0.026794695070073492, 0.08524739138421514, 0.0982882839537436, 0.0645688473577461, 0.01975931129568527, 0.03716373726004555, 0.04025540765254729, 0.07653233685320424, 0.011143415355153624, 0.07024713701778842, 0.04333131195556733, 0.11976220344583835, 0.060404132931463184, 0.022835150481231754, 0.14207595448580482, 0.04122663094031234, 12.474463889675757, 56.9620010929723, 74.2909226878997, 49.88417433154199, 24.82195673450347, 42.19978832429455, 80.41195392608643, 92.2875415125201, 34.8888982495954, 0.521015968293913, 0.3434047036834302, 0.2238369486745327, 0.4895231356063197, 0.29668875399135775, 0.28318185779836874, 0.3014282948307453, 0.6203808202858895, 0.1911427215823243, 4.242667978809727, 35.51330427969656, 81.00762859467538, 85.44123265051073, 79.48565483093262, 90.09314798539685, 84.17065143585205, 80.97734005220475, 75.42463671776557, 79.89285961274179, 77.39720452216365, 74.49522326069494, 68.61670432552215, 63.948060081851104, 71.00693395060878, 79.95258162098547, 81.89053058624268, 77.90282941633656, 78.99028301239014, 74.44904911902644, 75.31539870846656, 74.65218082551034, 72.61294841766357, 72.97964296033307, 76.56015503791072, 72.72906626424482, 70.02775346079181, 70.93467604729437, 73.73346759426978, 71.08778968934091, 43.56961727142335, 47.03940868377686, 69.30183256826093, 78.41677758001512, 75.34304357344105, 76.94557497578283, 78.49000038639193, 80.54440452206521, 71.38445423495385, 63.4027761028659, 58.30396552239695, 72.85109904504591, 75.40164378381546, 79.96819265427129, 75.97514921619047, 79.84865450089978, 79.11947804112589, 77.55871988111927, 74.30148170840356, 73.57901250162433, 69.23463452246882, 68.90694402879285, 71.37776267143988, 75.10148048400879, 77.91421213457662, 79.48840049005325, 75.40955912682318, 74.67403627211048, 79.59719134915261, 77.04469327003726, 69.67881941026258, 75.93598827239006, 78.19086474757042, 54.27108257047592, 19.203492902940322, 1.621786072369545, 0.2069444341524955, 2.408904274625163, 2.0042121386335743, 2.4965837117164367, 0.9066081227314089, 0.7271043451563005, 0.09349954494785878, 0.09313451937369763, 1.8019850287706622, 31.85138733156266, 80.27515734395674, 43.90797661196801, 18.859618709933375, 25.536520404200402, 58.12845906903667, 59.846763149384536, 13.810521229620903, 0.489845444117823, 0.05842075427813877, 0.10651532515522935, 0.06731767808237384, 0.09464604149181997, 0.026771620501794165, 0.028822299979266622, 0.03099906029209735, 0.04788762371566507, 0.04835939215075585, 0.07034037757905261, 0.01594225235749036, 0.035589415084330306, 0.053580373285278204, 0.08657496046995924, 0.07689490328512846, 0.031833471767904784, 0.04612266822087188, 0.06459324725813444, 0.012182303358830754, 0.018193010060537248, 0.08156806260587708, 0.03719513154318256, 0.01845479379558275, 0.0279177857127281, 0.02086408094563071, 0.05272295618910463, 0.0940046803424916, 0.030127836376308437, 0.0542588935293738, 0.04488743954308091, 0.04015854349540126, 0.02333840321479065, 0.049721982945958455, 0.19107098510909468, 0.15367302412707962, 0.1897145038650882, 0.10347660676005388, 0.08698222813226524, 0.26200605376112845, 0.22552919093399282, 0.13141098402200208, 0.1440943356963896, 0.15221263071702373, 0.07893497244484964, 0.10218954074286646, 0.13736315011497469, 0.1945807862906687, 0.10169418063014747, 0.19247568392705536, 0.07675607283149036, 0.19376363094535567, 0.15149659897771575, 0.16583606420505434, 0.13715927879656517, 0.18777312981265207, 0.11503138068702914, 0.1542280701499793, 0.13194497794874255, 0.13595777713964063, 0.2891336255256207, 0.16256523649058036, 0.27606680087985536, 0.07637036288337362, 0.22736280705899964, 0.10936630604368065, 0.18972518313075268, 0.12577776331454515, 0.27489888451753125, 0.11072936798295668, 0.24047374304744507, 0.19696949440385067, 0.17489388945602602, 0.23173565225255108, 0.11510080357472743, 9.865794527915217, 62.65083420661188, 87.16685587360014, 72.74095104586694, 56.40129043209938, 48.011022921531435, 66.6975199791693, 90.90253691519462, 59.64767540654829, 4.029533492942011, 0.8614849924079834, 1.10277792859462, 6.284836771026735, 1.2084947526454926, 0.16986470609422655, 0.366707167798473, 0.20959261624563127, 0.2359728692399879, 2.5408613874066264, 27.90186651291386, 78.6896490281628, 87.19987438571069, 77.00332010945966, 89.24395484309044, 91.31377389354091, 84.83034703039354, 78.41891134938886, 77.66575351838144, 79.58738542372181, 81.06273005085608, 76.27415933916646, 68.81677658327165, 75.976208256137, 84.59977442218413, 86.23831318270776, 82.15081122613724, 84.07558102761546, 76.89033231427594, 77.33013983695739, 74.12293541815974, 75.32354939368464, 78.06712181337419, 81.34060644334363, 74.96554682331701, 67.85920835310414, 68.25362620815154, 70.87888425396335, 73.26044544096916, 51.529102633076334, 49.55202802535027, 66.51585932700866, 82.1279045843309, 76.9999704053325, 85.04579497921853, 82.23220825195312, 85.91328205600863, 73.89040162486415, 66.2870204064154, 63.20114274178783, 76.32198872104769, 77.27023739968577, 82.87711651094499, 79.33943671564903, 84.46089113912275, 81.40632183321061, 80.27589474954914, 76.17449975782826, 75.95951464868362, 73.73258113861084, 75.92445650408345, 71.38912970019926, 82.26157895980343, 82.91914078497118, 82.95980007417741, 75.09792681663268, 76.43561194019934, 85.91481962511617, 76.35344612982966, 71.95840681752851, 76.9280262916319, 73.90110969543457, 48.91750228020453, 15.448403973733226, 1.066641745067412, 0.2550915893047087, 2.4157063999483666, 3.029130283863314, 8.509631118466778, 9.019498055981053, 7.738652488877697, 1.5086089002509273, 0.40616535371349705, 3.917366698864968, 50.12884786052089, 75.01630229334678, 34.10791904695573, 32.290457448651715, 52.966192383919996, 73.2609945727933, 63.93334334896457, 15.62606773068828, 0.46833188723652597, 0.2803274448360166, 0.29292668005631817, 0.1574463901981231, 0.16721463942479703, 0.12512766110200074, 0.13983808908491366, 0.10043916773171195, 0.12771775840871757, 0.26220943478326647, 0.09381517317266234, 0.08357798620577782, 0.15443520500294625, 0.15519920916807267, 0.20301565948513248, 0.2432992438515348, 0.18160678085780915, 0.12104501001416676, 0.2574744598279076, 0.10603023828157496, 0.11608205495342133, 0.2207602476400714, 0.11994484646786606, 0.09574035212637917, 0.12829413231942924, 0.14972419327785894, 0.19580668018710232, 0.336318175879217, 0.14067859479015873, 0.1649963552312505, 0.1723234959307217, 0.262752928200268, 0.14451770652686396, 0.13191419653594494], [0.08559436792688024, 0.031996139047306874, 0.04046293321035562, 0.1361722357931637, 0.08566195986443952, 0.030929683369674513, 0.0070331884536802055, 0.07701400697471635, 0.10938790206226612, 0.05455921914788985, 0.026946031909075477, 0.12160601620111736, 0.02079124130579012, 0.06298252058425738, 0.002351992631203405, 0.06620162587252355, 0.10957507266392631, 0.11070686031974132, 0.03873204181511556, 0.06393368769016478, 0.049008398857568546, 0.12339610321026658, 0.044767730644032847, 0.10157260247656416, 0.03054187434064525, 0.16000654878875903, 0.08719255757187644, 0.046458030870604905, 0.0821208563302794, 0.11608053809933125, 0.04616411740801508, 0.043925118196995995, 0.1286093851611499, 0.11458638319445234, 0.01597437729698516, 0.037391410930262464, 0.024007743810333555, 0.017933857837511648, 0.05048818578342757, 0.05077581349459868, 0.039682017654300704, 0.0773700999636804, 0.9213854684945076, 23.237315262517622, 61.89383637520575, 65.09096814740089, 48.294614207360056, 32.27714296310179, 36.746332722325484, 58.958267857951505, 66.71524124760782, 16.394330609229304, 0.6955532897864619, 0.7951099089076443, 0.8733373531891454, 0.32653382348437465, 0.2551095923709293, 0.15119926493254401, 0.26735561509286204, 0.05099470779720334, 0.10175127716314408, 3.2451660979178647, 46.963244099770826, 79.96392511552381, 85.61910429308492, 79.61526563090663, 79.53326456008419, 95.4533806154805, 87.09730440570463, 82.66508102416992, 75.07745204433319, 75.11331819718885, 70.49732392834079, 73.69724842809862, 75.19241671408378, 82.29031424368583, 76.52626575962191, 78.34608862476965, 79.66979442104217, 79.53251146501111, 78.44406158693376, 77.25147278078141, 73.58208763983943, 76.58861575588104, 72.83157348632812, 84.18801969097507, 77.08287362129458, 80.57827811087333, 46.24356762055428, 43.27014038639684, 39.852955802794426, 55.00644853038173, 78.0656470021894, 70.48654525510727, 80.43382506216727, 78.29420351213025, 71.54585976754466, 64.59108168079008, 68.8931372857863, 67.04863486751434, 75.83424983486053, 73.45525387794741, 78.1582384724771, 80.01965415093207, 81.53795657619354, 83.87320241620465, 87.17604990928405, 79.28312716945526, 80.01723012616559, 76.56540316920128, 79.75611009905415, 72.90411380029494, 71.25538472206362, 71.86962789104831, 75.43916517688383, 80.59121408770162, 92.89340649881672, 93.33310419513334, 80.56852709862494, 77.13748870357391, 60.30382125608383, 24.569118792010894, 1.785985803411853, 0.08943407721216641, 0.33322167913279227, 1.1615481492011779, 0.46153809694993886, 1.7022374392517152, 2.700050780850072, 0.6056534234554537, 0.5167366011488823, 0.17650756173797194, 10.385886103876176, 53.79056084540583, 55.58819094011861, 18.25254563362368, 25.276559437474898, 50.28589956222042, 52.50067372475901, 31.579092471830307, 2.090515926960976, 0.22369758195934758, 0.05327337887138129, 0.04430746118868551, 0.04948182204257577, 0.13832849750836052, 0.012314237105930525, 0.04949255110395532, 0.04841000374947344, 0.026608667854640274, 0.025426498426484968, 0.04892705564176844, 0.08032460997421896, 0.05571993428372568, 0.019545844726024136, 0.01280635570911991, 0.024660818444024173, 0.04954147347879987, 0.03564941892099958, 0.01693668715175121, 0.04657545299719899, 0.029437637121807185, 0.12238495141988802, 0.026947826470038103, 0.030061569770858176, 0.08462522073738998, 0.04563961531065645, 0.09950900675668832, 0.05627499562838385, 0.12587515607235894, 0.10848569563559948, 0.07556888169699139, 0.019777978943180174, 0.11057267235892435, 0.1347018985618507, 0.03140492409828209, 0.054251577389696916, 0.028852945411457654, 0.02366177467328887, 0.0447518304891644, 0.04336323866981172, 0.041054341596581286, 0.05272941431030632, 0.05345027240353727, 0.046606081192411726, 0.05087794067578451, 0.007970985410089095, 0.04790656907003253, 0.08319669658498419, 0.041963251292585366, 0.022806745856219245, 0.006789162157914572, 0.08232576952826592, 0.05926184604064592, 0.03625845882080255, 0.04800159078572066, 0.06667815554406374, 0.09385426663943837, 0.05882593052041146, 0.0847469061432827, 0.0585274818173099, 0.15008151200750183, 0.06860421549889349, 0.061803530420987844, 0.049336433876305825, 0.08800221291641075, 0.07953554707308931, 0.06553355889815478, 0.09412432795450573, 0.1304727561411358, 0.06305716053072004, 0.12820171147224405, 0.13965943738097145, 0.03407213198501737, 0.07868938763896305, 0.03673640192456303, 0.005943405398753502, 0.03842873994501368, 4.030149795355336, 36.8477612926114, 74.44373822981312, 63.78781164846113, 37.36271358305408, 29.140913832572203, 55.413390513389345, 94.56573255600469, 70.93895927552255, 9.73552280856717, 0.2644678313405283, 0.21052946516823387, 1.191109582301109, 0.1667279897317771, 0.6432618441120271, 0.5850726858742776, 0.5460331516881143, 0.2394971341615723, 0.12224435896402407, 6.927589197312632, 56.750428445877574, 80.325787298141, 84.61096886665591, 82.60358610460835, 83.36485539713215, 96.46699167067005, 83.1025900379304, 79.6814360157136, 74.26861224635955, 75.46854372947448, 71.28123314149919, 76.5548441486974, 79.92644294615715, 84.27490019029187, 79.13958411062919, 82.33659036697881, 81.30993350859612, 81.7977665316674, 81.47432788725823, 81.80467774791103, 77.9284974067442, 74.56129950861778, 70.54615743698614, 77.27311641939225, 73.28951020394602, 77.04943149320542, 53.35125930847661, 44.783433944948264, 43.904830871089814, 54.152034713375954, 80.57015880461663, 73.04817461198377, 86.09051042987456, 78.61685768250497, 74.49934174937587, 66.73744186278313, 64.14655162442115, 66.23035784690612, 76.79873712601201, 73.52524465130222, 77.7806083617672, 78.48992978372883, 82.73355776263823, 86.81036733811902, 86.45817772034677, 81.00875823728501, 82.63131726172664, 79.61914093263688, 75.8763760905112, 77.41845592375725, 77.38739859673285, 76.95174878643405, 80.12733890164284, 77.14700437361195, 86.82524096581244, 91.09679622034874, 73.70131984833749, 82.34712585326164, 70.6513318707866, 31.11514276073825, 4.16247364974791, 0.21976211168352636, 1.3879705220460894, 2.705898544480724, 2.328691069156893, 1.375856404342959, 0.9996652519029956, 0.7031205224414027, 0.1519213640882123, 0.23677802764840666, 8.629096707990094, 53.13540343315371, 78.10266633187571, 28.86581055579647, 12.883223891258242, 38.33917194797147, 63.192180125944084, 43.26753201023225, 5.81808501674283, 0.14067880929477755, 0.05205609580321659, 0.027228620676924626, 0.033626759109357675, 0.12061284449432166, 0.009004890490623732, 0.07660133073166495, 0.01733727069691785, 0.02612725245736299, 0.0018238293517741466, 0.021797359898506154, 0.009920981303308039, 0.06600563759885489, 0.024932327665268414, 0.036088394962491534, 0.042589589457718596, 0.07528201241286532, 0.051653512768567576, 0.028987552805413163, 0.041674543397441026, 0.10949448787517126, 0.0550599227238807, 0.015484706344713849, 0.019404413403883096, 0.04442656870871302, 0.027063118872202696, 0.020500566479900194, 0.022055807320641416, 0.05425956002586792, 0.030245122522295966, 0.059034034474602634, 0.0073370112635705986, 0.06611698847864905, 0.058977987482062275, 0.012416811490942155, 0.1609928103824777, 0.1265883379645886, 0.09814550048641621, 0.21299191690500707, 0.15950843842039186, 0.07458771458796917, 0.13390853790746582, 0.2743758609698665, 0.20654300408017254, 0.18434062690263797, 0.09217685584219233, 0.18717446274334387, 0.1793254782716113, 0.19973225260694183, 0.17853274580932435, 0.12841116757162158, 0.2259035321373132, 0.12894480909791686, 0.1595343628357495, 0.11168256522186341, 0.11724008878152217, 0.3210689199547614, 0.0965429058358554, 0.15419450017713732, 0.21370280053346388, 0.20133706891248304, 0.1278496098013655, 0.16367805580939018, 0.13812122475956717, 0.1908343711928014, 0.15237499539169574, 0.24963656830931866, 0.21548989979970842, 0.2687805386320237, 0.1433931200975372, 0.21095407706114555, 0.19189486670638287, 0.13402614772560137, 0.1454796371681075, 0.15047152736975303, 0.20420004673782857, 0.22713825136663454, 2.6437478536559693, 38.05882838464553, 87.7796163866597, 81.98727192417269, 60.22475019578011, 47.251099001976755, 51.53977932468538, 72.39648065259381, 88.7151252069781, 26.14835916026946, 1.1539494150107907, 1.3649507443751059, 3.961349706495962, 2.509268656853707, 1.794306498862082, 0.7246576441872505, 0.3331122204901711, 0.11631969542753313, 0.1501386162013777, 4.436985629220163, 51.65754064436882, 85.59378147125246, 86.5665449634675, 77.31118694428476, 81.76549326988959, 102.7481262145504, 91.19104293084915, 88.62731118356028, 78.55870462233021, 80.20925368032148, 76.9625666833693, 80.39139286164315, 81.36996930645358, 87.25458360487416, 79.13395943180208, 83.05616486457087, 85.21371949103572, 88.0406815005887, 92.99696491610621, 88.30173092503702, 80.76761876383136, 76.94950519069549, 75.0400875460717, 87.40341401869252, 79.95218938396823, 80.94399990574007, 52.3664306056115, 53.644731044769294, 55.45275542043871, 60.953055889375754, 79.24429570474933, 79.72647267003214, 87.73965527934413, 83.6368090106595, 75.65970436219247, 68.02825466279062, 70.6963763698455, 74.35970537124142, 83.55692601973011, 79.49357801868071, 84.31270399401265, 83.93729394482028, 88.53821062272596, 94.29407704261043, 91.68213152116346, 84.89763136832946, 89.10798980343728, 86.02484995318999, 81.7328905290173, 85.55606395967546, 80.92436452065745, 81.61559597138437, 84.57477323470577, 78.47991205030873, 92.27081652610534, 92.41454785869968, 81.15334464657693, 83.79204073259908, 67.36881009994015, 27.79621158876727, 2.739096259878528, 0.2822127872176709, 1.2493784749700179, 4.324136587881274, 4.98211810665746, 6.992730450245642, 12.613930625300254, 4.461566142497524, 0.9240915361912021, 0.5989953226620152, 16.111698342907815, 66.59487939650013, 66.10661491270989, 30.35825279451186, 38.72062636959938, 62.72833631884668, 71.08303577669206, 51.078940053139966, 6.909387438528, 0.389628303988326, 0.35925144690179056, 0.1885813372510095, 0.15528312643929837, 0.22061691258943852, 0.16561763721608347, 0.21259162064281203, 0.10886235042445122, 0.08901321915008369, 0.08609932712129048, 0.12731637430167006, 0.11018163809973387, 0.1670277139712726, 0.1939449333135159, 0.07857726301036536, 0.11387287188441524, 0.14226710874467127, 0.19850812071273405, 0.17808306751953018, 0.13733819097040162, 0.14044519844314746, 0.20538159946520484, 0.07873999540724101, 0.10451320033039778, 0.31131239187332893, 0.09487635816537565, 0.1571601797496119, 0.19050879914674068, 0.18891633217853887, 0.2147475146358052, 0.1894485334595365, 0.13250040701560437, 0.15954237611543748, 0.24820609829358517, 0.1251256999169146], [0.03024794747151675, 0.034943147141846924, 0.029237155742462606, 0.04696111314960065, 0.012415650867736869, 0.10275892027082945, 0.1537965481439906, 0.09152785679625888, 0.13994160288524243, 0.09510688934355013, 0.09915704298163615, 0.06833318125216231, 0.03886319223731276, 0.03677660621882927, 0.13651435533838888, 0.040623463104448976, 0.025582016190333713, 0.05372443228899952, 0.10061318460371226, 0.04197127606359221, 0.15755580287546883, 0.1129998380859052, 0.10650917346919737, 0.10388172937617188, 0.10701939568764741, 0.016116802618207953, 0.031124786811790643, 0.1275303043545254, 0.06759886299410174, 0.03893029387860049, 0.16181074713747348, 0.0938273003445037, 0.02095883836098496, 0.10548365753023856, 0.0430744273527976, 0.07135400383342659, 0.05079305813377423, 0.04204101304733946, 0.10586288637451588, 0.09472002260266774, 0.049867892052016916, 0.05499502358537528, 0.061728538074080026, 0.5355563783837903, 10.574367757766478, 45.80103797297324, 63.014394775513686, 60.52074793846377, 36.639950198511926, 22.2793234163715, 32.44460659642374, 69.88517530502813, 51.54236024425876, 9.140149181888951, 0.5998112982319248, 0.792710276380662, 0.75592034406239, 2.3963828432944516, 0.29378751773507367, 0.2145978976641932, 1.0314350406969748, 0.07527232906150241, 0.07308700963133767, 22.597533541340983, 80.43505668640137, 97.69097512768161, 88.76084435370662, 71.89577441061698, 79.89456192139657, 83.17629137346822, 85.93359993350121, 84.18370508378553, 84.42278923526888, 83.47625071002592, 86.04569342828567, 82.52363251101586, 85.38835125584757, 79.64240843249907, 75.4872299009754, 81.03880359280495, 79.26830061020391, 85.16963989503923, 82.77321292508034, 84.35224933008995, 74.57760087905392, 69.52532922067951, 67.37545459501206, 77.83975770396572, 50.29111239217943, 70.67996517304452, 47.04504512971448, 59.99938649515952, 65.73983407789662, 77.74051389386578, 74.91364602119693, 76.05463212536228, 77.98011579821187, 83.24705877611714, 78.36593581784156, 79.05337825898202, 78.98843165366881, 78.43405169825401, 79.3819159846152, 78.54452133178711, 75.32093709514987, 77.62038738496842, 78.78014595277848, 76.91985207219278, 77.04261441384593, 77.07917090385192, 75.51665552200811, 81.1950159072876, 96.10572568831905, 107.94438808195054, 98.40625855230518, 84.0820372489191, 67.97693437145603, 83.4069424290811, 69.32441757571313, 36.33037713266189, 4.145688356891755, 0.34953392801746247, 0.12782703319023694, 0.4059952821943068, 1.8245004141522994, 1.1521555435272957, 3.514047269859622, 1.923061364120053, 1.0174064386275508, 0.24939310556698233, 3.190588278155173, 32.32040082254718, 62.664844912867395, 44.93547677993775, 21.94040317689219, 38.4609027062693, 55.628234417207786, 48.424123025709584, 17.652854457978282, 0.38315259340790014, 0.15031700743542564, 0.12805499797386508, 0.028188754841985724, 0.04883748464166157, 0.014191257857507276, 0.06962705013011733, 0.04893113889040486, 0.052113464297426325, 0.10342305721414667, 0.057848658968484214, 0.02083565142276066, 0.043514318869359074, 0.10929391839571538, 0.09132398547784937, 0.018272989639832128, 0.031066564129545327, 0.05265794979828981, 0.036778812552051204, 0.061152451446339975, 0.016128816792080482, 0.11486510896394331, 0.011668071627707012, 0.05616178698537331, 0.10030134851413389, 0.023353056561562325, 0.06392927502372092, 0.014036794422164321, 0.0486130936582002, 0.025931476773093307, 0.05101336586859919, 0.04026555065666476, 0.02175558129355552, 0.052647232228229125, 0.07221145540355675, 0.0666547362362185, 0.06956352611943599, 0.042883671459651766, 0.02042833779517922, 0.07758575371436535, 0.013086580138112749, 0.05475033127192048, 0.04686627146457473, 0.08154840478974004, 0.07434953019143113, 0.16399005277743264, 0.07665069743750558, 0.06438122476421057, 0.10011436177357551, 0.041394706800459855, 0.009884836317430581, 0.07220168012164294, 0.04235949878010058, 0.04659560494004719, 0.013259747610127014, 0.0808386626322904, 0.017752917445895654, 0.037409176509226524, 0.061019006590809555, 0.09582649105258527, 0.05987824421496161, 0.04402569021969553, 0.014499170619303422, 0.10638070818517478, 0.13324751128112117, 0.07092625098002535, 0.09137152123355097, 0.08361804494333845, 0.06168743745694238, 0.05889461413326283, 0.04569875729841091, 0.05439602709825962, 0.04722504959171338, 0.06067682192811082, 0.07319259952994124, 0.02743591257791606, 0.05756545541507583, 0.056977762555282925, 0.05084840415586388, 0.25676043523896125, 1.2643093447531424, 20.08043093066062, 60.66873112032491, 75.68978894141414, 52.732395587428925, 25.99100543606666, 28.500881079704534, 66.14281838940036, 100.1877441713887, 52.378860596687566, 3.9202045336846387, 0.5687849211596674, 0.505889623516029, 1.853096821615773, 0.7470639386484701, 1.1317950102590746, 1.046215144376601, 1.3914488063704584, 0.4262058767339876, 0.40793605869816196, 32.07897697725604, 92.12319420230006, 92.26047715833111, 79.25123829995432, 74.68634466971122, 88.78228402906849, 86.19758329083844, 87.27719999128773, 84.96890083436044, 82.22672477845224, 80.91807303890106, 82.61619260234218, 82.22350059017059, 80.61361866612589, 82.46781718346381, 76.98284533716019, 79.7383809858753, 76.14806298286685, 81.34524268488731, 79.52578067779541, 84.3739321924025, 74.49199122767295, 75.55004273691486, 71.19483117134341, 83.81173103086411, 56.54844207148398, 65.60819541254352, 59.55205586648757, 61.32784228171072, 71.0409487447431, 80.2087986853815, 79.06214867868732, 84.6144833103303, 80.0044196651828, 82.8969793934976, 82.57560391579905, 78.31769850946243, 80.32530876897997, 81.87065201420938, 83.56318612252512, 82.31097728975358, 78.87596161134782, 80.33544417350524, 84.01170915172946, 80.92577657391949, 78.9777078936177, 78.29483109135782, 80.0623530726279, 79.7776125323388, 86.7564033692883, 98.64018086464175, 92.6919771009876, 83.36487108661284, 71.06860929919829, 89.92461942857312, 81.67541211651218, 47.95870634817308, 9.132994778694647, 2.159673441802302, 1.1073825460287834, 3.589096184699766, 2.5046767871226034, 2.943926842943315, 1.238795184800702, 0.27876922199803017, 0.33414407963714293, 0.3275916683337381, 1.1314590347390021, 31.666563287858043, 72.88419600455993, 63.59339544850012, 27.821944298282748, 27.94357111377101, 55.13891481584119, 60.38186857777258, 24.022940512626406, 1.168818997759973, 0.1353634001627084, 0.07502489032283907, 0.03585355070930335, 0.013436360562580728, 0.007491354518870433, 0.03857729971529015, 0.045355335403714454, 0.07757617761531184, 0.04198377478807684, 0.09092647777569872, 0.04853787531535472, 0.032317346307419004, 0.06896768591456837, 0.06278882674392193, 0.007515910030868386, 0.03158285759479529, 0.02666303902984627, 0.03514811013554854, 0.03055585353004356, 0.05552269728674043, 0.025857292648945606, 0.04579252646034283, 0.02799926873957438, 0.08193753148999908, 0.02421119761082434, 0.03425993077877549, 0.06211159352753913, 0.013554723062101873, 0.07867232686088932, 0.053425615863694306, 0.10905143624592213, 0.04128223743229624, 0.09131474645748254, 0.0903503260304851, 0.05445536443843477, 0.026102919589668035, 0.10591355542982779, 0.10123517138943558, 0.11837137848018639, 0.09825951735218687, 0.07429937441502849, 0.28589353325866884, 0.2896304488662751, 0.1836289312209814, 0.23255342046820351, 0.2138360998322887, 0.13099948755435406, 0.19123253773056692, 0.22811424738216787, 0.17375390465942123, 0.19235632742845243, 0.2670782912642725, 0.2476562616685706, 0.17538522760714256, 0.3249313820513987, 0.06579104871038469, 0.20953165096861703, 0.23083395144391447, 0.11208813982985674, 0.13489714373023282, 0.16493977197716314, 0.13269090243885595, 0.23701523911328087, 0.29950130790952717, 0.14937262020764813, 0.11049609421001327, 0.2672186998590346, 0.15104057747990857, 0.12757958679069437, 0.24706913188340204, 0.16254390860276838, 0.11804645760886132, 0.15390016919662877, 0.18318021820197183, 0.23144170431600464, 0.1368786607899012, 0.21825979794225386, 0.17357146848113308, 0.2632567689063088, 0.8778580686738415, 17.103830499033776, 69.24304408411827, 89.08650305963333, 75.82089024205362, 53.10953932423746, 39.26663990943663, 48.83612878860966, 86.9622415111911, 71.88779630968648, 13.83368282548843, 0.7017517991123662, 2.006280943751335, 5.471798566079909, 8.34056813870707, 2.8613013798190705, 0.4146183985135248, 1.2540424182530374, 0.18346802211336552, 0.1546241376068323, 25.001460083069343, 89.41692352294923, 98.68411925531204, 84.51735758012342, 72.92145852119693, 88.28428422251056, 86.42716746176444, 92.8926141800419, 88.72517431935957, 88.25914182970601, 86.36292688308224, 91.27880988582488, 84.06532010724469, 89.29124293788787, 87.92432831179711, 79.50338394411149, 79.71953791956749, 72.600051664537, 84.32721676365023, 86.00739540592318, 92.02907300764515, 74.40420073847618, 69.71256748322519, 69.61759905661307, 82.43805423859628, 69.99961437717562, 81.67517677430185, 68.46523807894799, 69.86723438385995, 70.92706664916008, 84.7566770738171, 89.70615125471546, 86.78155360683319, 87.09466857294883, 91.80052434244465, 87.04332474739321, 80.29097234049152, 80.37766456604004, 81.42035607368716, 85.55817419482817, 82.71140421590498, 80.78781112547844, 77.01653849694037, 83.1647752946423, 82.08283655105099, 77.66744798229587, 80.47515899904313, 82.23212980454969, 76.1526756901895, 96.40657932527604, 112.68256418166624, 99.77868018611785, 84.232177734375, 67.67984620986446, 87.21259855454969, 75.76101918374339, 41.264001015693914, 5.73723957423241, 0.9960489491781882, 0.41484439445118754, 2.083420604467392, 5.3480659281053855, 7.490513545851554, 13.054690303341037, 9.034010825618621, 2.2582374561217526, 0.39296939728721497, 7.127476123071487, 46.889076002182506, 78.85163507153912, 60.333278256077925, 37.40523207572199, 53.20486076416508, 71.40517219420403, 67.34406778889318, 29.048698909821052, 1.198770338969846, 0.320785099700574, 0.375327127835443, 0.2716736849998274, 0.21119511896564117, 0.23379408453981723, 0.3125753950688147, 0.10370763589537914, 0.16227666649126238, 0.2055633001990857, 0.20731722785820886, 0.1628990976079818, 0.13036660699834748, 0.17878923204637345, 0.1253538868660408, 0.12009340623814253, 0.12170556166599836, 0.12491224483857233, 0.08723818576864659, 0.15298677788626763, 0.11289192694089106, 0.2523508791120783, 0.146997379920175, 0.17089832724342424, 0.3702799567291814, 0.1480403013767735, 0.15040751306280015, 0.15235791163098428, 0.16002216166065586, 0.13433662783955375, 0.09960306703203148, 0.21663483352430407, 0.12814337387681007, 0.1609782240683994, 0.14452020397349713, 0.16673558932398597, 0.14700756888956795], [0.07646174951186104, 0.04713497297357648, 0.1257403629020818, 0.1170098104123627, 0.04298082289976939, 0.3076318909804667, 0.4787668321401843, 0.28982531099069503, 0.008497288292874734, 0.030349952078634695, 0.1190557171620669, 0.07430416246455523, 0.10353499798164253, 0.13630239413149897, 0.010100250665639198, 0.08200769748298392, 0.281169222247216, 0.16846746897264836, 0.047068660402850765, 0.03277673093121379, 0.25092707406128606, 0.15863374987196538, 0.07271371030759427, 0.05177340552871747, 0.041786426708342574, 0.03129066783003509, 0.09197828585221883, 0.14542147577289613, 0.20727762111252357, 0.1647469936118972, 0.041522727753486366, 0.03207117352905053, 0.030916077648139292, 0.03933849999861371, 0.19297394751300737, 0.11040319838831503, 0.14978217081196848, 0.027831483992838094, 0.007453607451621324, 0.04341430226040464, 0.09625757638845714, 0.03420260441940158, 0.03549707084593754, 0.1523414867058877, 0.16755724926629376, 1.106190390644535, 22.7043749824647, 45.9505626463121, 60.08200337809902, 55.10591199321132, 25.955339324089792, 22.766185652825143, 46.01258708584694, 62.289379950492616, 41.67253548099149, 4.301752111604137, 0.16268894436859316, 0.4011191325562616, 2.2194966962260585, 1.3183330071549262, 0.5348354590035255, 0.5348053670698597, 0.77190792488475, 0.29863044980072206, 1.5620134410358246, 31.043061364081602, 86.18720469936248, 104.09157722227036, 101.04599798879316, 81.88390962539181, 82.85475115622245, 78.70013744600358, 80.46318792527723, 75.49317621415662, 86.11296207674089, 81.71897395964592, 78.13997591695478, 80.08160406543364, 89.9367238629249, 82.20876032306303, 79.20008274816698, 73.34432924947431, 72.36799640040245, 67.80052185058594, 87.07599024618827, 96.70173768074282, 81.54192601480793, 33.71495246887207, 10.947466550334807, 35.85004760373023, 33.093680412538596, 63.6690422796434, 78.12444333107241, 64.35078943929365, 74.66693678209859, 87.63736770999047, 75.27126419928767, 69.97790013590168, 77.77674874951764, 73.34335650167158, 77.38517069047498, 81.0605021445982, 81.02247084340742, 81.2197974420363, 83.29403308130081, 85.88933206373646, 87.74033777175411, 87.77906725483557, 86.84541763797884, 77.83424285150345, 90.36362678773942, 78.41772679359683, 63.21290200756442, 65.97367009808941, 84.25772020893713, 88.40722699319163, 81.86006945948448, 39.91966747468518, 4.407037842658259, 0.3616085462272168, 0.022044308340897965, 3.897693070673174, 7.224541056540705, 3.4768487368860557, 3.019769302298946, 2.6531333500339143, 0.7833980792953122, 0.5182582356276051, 0.5696724186981879, 20.439869088511315, 61.39757417863416, 57.04211942611202, 35.18460965925647, 28.753150278522124, 49.005418285246826, 50.758733441752774, 33.79418042398269, 5.574113101728502, 0.14156010152111131, 0.022135773493397622, 0.0558508740317437, 0.10656495233096423, 0.06346632426063861, 0.05537275472776063, 0.05328431094606077, 0.011935612513503481, 0.09331554595020511, 0.05399650075442849, 0.060316408203253825, 0.06128332224644481, 0.0712687612300919, 0.017339869650200974, 0.04425365500332368, 0.14603813058666645, 0.07877099898553665, 0.055822509626347216, 0.03410048872953461, 0.03853719501245407, 0.1198424971211822, 0.11061077757227807, 0.1161014676214226, 0.056744902469818635, 0.10333773800201955, 0.23279038678494193, 0.03609683342097748, 0.0858461580449535, 0.12875861908879974, 0.2599864621316233, 0.036579047464915825, 0.0997600307868373, 0.02289892347048848, 0.04835301829922584, 0.07766081500918635, 0.1001851253151413, 0.19075177159280549, 0.11198706218912718, 0.037734886451113614, 0.05944456950190568, 0.06136497189741462, 0.015402576931181456, 0.04312683159725801, 0.0859869726663155, 0.1497948265844776, 0.15092264590484483, 0.06291092966773337, 0.020419774847405574, 0.1315833384832067, 0.15128961734233365, 0.05369016134570684, 0.13911071924432633, 0.057741448793920784, 0.058597739740845665, 0.05963091272860766, 0.07040643734076331, 0.06329833267016277, 0.10450804455866737, 0.1696752372287935, 0.06831255816524068, 0.04090898407382831, 0.04709281515510333, 0.10722409438101516, 0.06011519137950194, 0.04300992658001281, 0.08918304552113818, 0.10194321283169332, 0.05197127454824025, 0.08476473300928071, 0.06485592348561173, 0.005347242958152728, 0.07034279841689334, 0.08685881136766366, 0.07920254397416308, 0.0910543684937781, 0.019120905330524813, 0.010244739636208021, 0.03702582611191658, 0.06912967520615748, 0.030889264570789474, 0.059176251036866065, 0.053471182773430506, 0.10052224230622092, 3.6916769512238043, 34.39398534836308, 63.08680957363498, 63.1932117092994, 33.81175656472483, 16.862006571985063, 39.158692359924316, 84.89989065354871, 93.86493052205732, 38.46841796751946, 1.7379378719675926, 0.4559855836053049, 0.7866816547128462, 1.70656785849602, 0.4401367872713074, 1.7547796714690425, 2.6032905665136155, 0.702894434573189, 0.29989204339442715, 4.6654215262782195, 49.31736830742129, 101.45922753118701, 100.77329128019272, 93.42064365263909, 78.93587189335977, 81.92668699449109, 81.93638309355705, 84.49995010129868, 80.3268777170489, 88.84261792705905, 82.82381150030321, 80.59377931779431, 78.74379342602145, 85.14357966761436, 86.22687555128529, 90.54145920661189, 88.19081414130427, 80.8807477643413, 72.59043401287448, 81.82463476734777, 82.4580426369944, 77.42754013307633, 48.90651964372205, 22.289258780017978, 60.40150004048502, 49.66339195928266, 74.34421200906077, 71.45260149432768, 70.84552841801798, 86.3950667842742, 84.66239113961497, 80.97377854008829, 76.55792713165283, 78.65746205852878, 77.5480745684716, 79.37371823095506, 79.92299126040551, 80.20333874610164, 78.29153630041307, 81.92984842484998, 83.95063784814651, 86.93068212078464, 85.65517440918954, 89.0775365214194, 81.75105894765547, 84.95101482637467, 88.34471225738527, 68.91793451001568, 61.26025984364172, 81.29700537650817, 87.7033027525871, 90.44330581541985, 53.731854731036776, 10.062453343022256, 0.7458656545608275, 0.1499930594957644, 5.944498594730131, 5.968120578796634, 3.4829771951321638, 1.8322653587787383, 1.8213388612193449, 1.386309888574385, 0.3442972267587339, 0.36336248920809844, 17.015624238598733, 68.62929513377529, 72.72898781684138, 47.571917503110825, 29.01667275736409, 43.15912554340978, 63.80993381623299, 44.679408765608265, 8.198315049371413, 0.167476074589837, 0.0687202624976635, 0.04911888405800827, 0.10940114772247692, 0.0946279158515315, 0.10728020266058946, 0.1053264026620215, 0.041557837563056144, 0.013563760984388572, 0.010238512298993526, 0.04874624740031939, 0.02305655372178843, 0.040115588945486856, 0.009600082393585434, 0.0384261122634334, 0.2244414992990994, 0.11614131951524366, 0.059829578479571696, 0.033829898813799504, 0.07710800596302556, 0.022979144367479512, 0.05001833639858712, 0.0953329618900053, 0.03497179883021501, 0.0266573527422283, 0.26581476712899826, 0.07669190530695262, 0.057936847179887764, 0.042172282213164915, 0.1966353574947965, 0.028880511170193076, 0.07396936671988619, 0.030108640128145778, 0.07846295503118346, 0.07752645850902604, 0.042999147722918185, 0.06914213945668551, 0.05994710785847518, 0.24085036719277983, 0.1843145952349709, 0.3355289214561063, 0.23940906469379705, 0.09732908058551051, 0.34484761496705396, 0.5791031449071823, 0.26664416455934126, 0.19935215042243082, 0.07529000270991557, 0.2607071057202355, 0.24394491807587687, 0.22786330762169055, 0.25726871925496286, 0.1045283075842646, 0.24493039825991278, 0.391663002871698, 0.20657942390009282, 0.13172681142966594, 0.19838992866777605, 0.5161799310195831, 0.2621599761468749, 0.16004443949749395, 0.17202052347842725, 0.30408232983562256, 0.3979145867689964, 0.2581892505047783, 0.3316104123669286, 0.3173838531778705, 0.1888483648578967, 0.1249728040889867, 0.07520378717491705, 0.17612779663214762, 0.21179971555548333, 0.41187632468438923, 0.22452840431322976, 0.3171453546852835, 0.2702973314350651, 0.16585434306292765, 0.14265695556757912, 0.16290311190870502, 0.19342402416852214, 0.16715416444405434, 0.30773761111401743, 0.5061152210879711, 2.588227684459379, 41.14196039015248, 78.50486616934501, 81.4069180334768, 70.18810779817643, 44.250281856906035, 40.093299035103094, 60.4254617998677, 82.7789709644933, 59.79068502303093, 8.475317243606813, 1.0170433742384757, 1.6390744092002993, 9.953712494142595, 8.624350640081591, 1.8331900575468618, 0.8264425985755459, 1.5899619219764587, 0.33796946307824505, 2.361823084854311, 39.350358978394546, 91.72635232248615, 103.49559660880797, 97.74284455084033, 84.07814625770816, 84.04162114666354, 83.50430350149833, 88.21492102838333, 78.7880220720845, 88.10645964837845, 84.1214256901895, 73.18322966175695, 74.99249350640082, 90.10370700590073, 91.41936409857966, 107.17246563203874, 88.46269715216853, 76.22498066194596, 68.73936468555083, 96.24737816472208, 106.23683129587482, 89.18439757439398, 45.58514287394863, 13.89991302644053, 53.081235501074026, 53.25492197467435, 86.9840891130509, 84.34186289387365, 71.8771666865195, 86.76138477940714, 89.81734260436028, 85.2674481176561, 74.16956455476823, 84.09733449259113, 83.07257606137185, 86.59881038050499, 86.86111496340844, 85.97064279740857, 79.77092881356516, 81.68539062623056, 88.81606348099248, 91.40896981762302, 88.12277670829528, 99.17550594575944, 84.84333007566391, 90.19761639256632, 108.58848048794655, 52.337020674059474, 40.52669348255281, 70.08276862482872, 91.16770482832386, 103.88195791552144, 51.655147998563706, 7.93287011884874, 0.5506261858728625, 0.13445239904667103, 6.367681641732493, 13.804200330088216, 6.133452894226198, 10.13840219666881, 14.325567656947722, 4.96171050494717, 1.4149603512017959, 1.4883092862944451, 25.437141272329516, 69.27160678371307, 68.96631302372103, 50.388544067259765, 42.77296819994527, 66.06530451005506, 75.7549238204956, 54.809102319901996, 10.381354785734608, 0.37570741388105583, 0.16522414381465605, 0.256818795817033, 0.2564172584924006, 0.20650051684389192, 0.23003375728524503, 0.32248713256370637, 0.14471682810014294, 0.1764975872731978, 0.1566795821511938, 0.25834102784433677, 0.1862258620319828, 0.23562604591490763, 0.07486078662857895, 0.22762053435848606, 0.2424886768623706, 0.26105316295739145, 0.14343660324811935, 0.14357632236374965, 0.1682481992869608, 0.16864051291298482, 0.20143759496990712, 0.18173807300627234, 0.14162365617530961, 0.2647030509767994, 0.4629879643119151, 0.12975764370733692, 0.30362868321038067, 0.18165389526515238, 0.6525595161703326, 0.47023999775128983, 0.24945160404088038, 0.11215894167581875, 0.18508030011528925, 0.14460468814978678, 0.247801190182086, 0.49726249289608776, 0.3163674996504861], [0.34336679765293676, 0.13257110160925697, 0.27683883364642825, 0.333983262460078, 0.1504319206240677, 0.22489680067425777, 0.2553713646146559, 0.3482873497470733, 0.3217074389178907, 0.3080977643689802, 0.5498499855879815, 0.24510646058667093, 0.12923048328488104, 0.21990457339392555, 0.031414134390351754, 0.24701331471723897, 0.22999212806743963, 0.030855344112722144, 0.6197909938712275, 0.13915856909607688, 0.37856142847768726, 0.5640694354811023, 0.03485074544685983, 0.1486667621159746, 0.47532887468414925, 0.0671983675490464, 0.12038209881152838, 0.0856090538323887, 0.07977174730190346, 0.00830152409992391, 0.20591796826451056, 0.19681227784002983, 0.16269078297961145, 0.19321203231811526, 0.11984351601812149, 0.015448127561549266, 0.1046753888048472, 0.04926183606467901, 0.2638936637630386, 0.06986830653923173, 0.1339179301454175, 0.05201568466521079, 0.06554634490561101, 0.03529442526820687, 0.07545715543411433, 0.02925002410437071, 0.036123221319529324, 3.4704871427628303, 40.07234181127241, 70.3605979488742, 69.13257445058515, 50.15153484959757, 27.90170373455171, 24.94172238534497, 48.49968356470908, 75.22987534922939, 31.302392790394446, 2.5075771347168954, 1.3411065335235288, 2.8601462418033234, 5.026177600506814, 4.183347032916162, 0.38109521832196946, 0.47767910986177387, 0.2875311534491278, 0.25033301884128206, 2.3503972205423542, 22.332734331007927, 57.33512832272438, 85.45352535863077, 102.96246805498677, 94.76128624331568, 93.4472922355898, 90.94220776711741, 88.11861899591263, 83.35771668341853, 88.84691684476792, 86.37062257336032, 80.85376185755577, 83.94565643802767, 103.18528221499537, 104.37954195084112, 105.62938167202859, 109.94475764612999, 99.88743182151549, 44.94283122401084, 13.553138240691155, 0.1535482437259728, 1.1665413264305362, 1.2258937738595472, 3.115686697344626, 17.665864959839855, 65.04726117657077, 96.10661998871835, 60.700070858001716, 60.700729816190666, 85.57706432957804, 88.60685994548183, 87.12119164005404, 84.99739293129214, 88.43675459584883, 87.02352462276336, 91.80371715176491, 80.25989932398643, 81.15839665935886, 82.69911935252529, 84.39326947735202, 79.70747270891744, 87.46039036781558, 89.95188774601107, 75.56672849962789, 96.87387481812509, 69.28848082019438, 83.88578537971743, 67.24370218092396, 40.03912718065324, 5.236979011566409, 0.10750198511466866, 0.438914938319114, 2.055715800773713, 1.6845247509979433, 4.439303749992002, 5.0099149634761195, 8.45950028588695, 1.1855175081760654, 1.9797413291469699, 0.2835934002312922, 9.194545592031172, 48.682501316070564, 58.19135035237959, 35.90663956057641, 27.338765167420913, 41.50103376757714, 56.53887933300388, 49.384684024318574, 15.769669625066943, 0.27636664769341873, 0.3399653366256145, 0.091358712243457, 0.08362752911184104, 0.05006381520821203, 0.2242652837547564, 0.14310358482743465, 0.06428766244601819, 0.02501646901721195, 0.07953254400842613, 0.14536587311135185, 0.07266041357070208, 0.17392690263448224, 0.138187951017772, 0.16626542584309656, 0.2617906604803378, 0.1858678078579326, 0.2648378211644388, 0.42657770516891635, 0.032881290441559206, 0.030726122316874327, 0.07463489028234636, 0.07922569515123483, 0.020806001904871196, 0.23620903882528507, 0.08023564418357226, 0.3571682086875362, 0.40682146205536784, 0.1806737164095525, 0.25591537897144595, 0.1723826685619931, 0.5897838201734328, 0.6313994322572986, 0.287632093194031, 0.17087396564743212, 0.1466197292170217, 0.059514769968847116, 0.1055095436412, 0.7554071877271898, 0.6235417603485046, 0.381206393001541, 0.07866902502193567, 0.1795139359009843, 0.26555166189228335, 0.033891660822255, 0.08994951648938079, 0.1509933711420144, 0.08526954664698533, 0.13855130652025824, 0.07653354727212461, 0.2550587394545155, 0.12260673387396721, 0.040358239634623455, 0.19400674128724685, 0.0703586870804429, 0.10026249253461439, 0.14187338551686657, 0.09278785692708147, 0.2165363299390001, 0.025799964374351888, 0.42782612205032383, 0.20848217179938672, 0.0419049826450646, 0.0870373634801757, 0.3126181734185065, 0.14019890117549128, 0.13091411471607226, 0.13602955957814572, 0.03391698385859209, 0.0948412330340474, 0.033406987636079716, 0.09693992324173452, 0.15090214539199107, 0.17039388898880253, 0.13612623987418992, 0.03719956336182453, 0.1871009795896469, 0.091303622860822, 0.13027067746846907, 0.01074329433557127, 0.07625025561860493, 0.04291350292342325, 0.09202887063785907, 0.10204687218872771, 0.08007320290010783, 0.1696688327337465, 0.15704937279224396, 8.155770571001115, 55.38193310460737, 81.83440931381719, 58.89261130363711, 28.386079188316103, 19.32931665451296, 39.51622424587127, 88.63821537263932, 87.84191931447675, 27.647965608104585, 0.42325751074860174, 0.3809011835725077, 1.5357624883613281, 0.9972808185604312, 2.2242613953928796, 0.33360928897896125, 0.33396889065061847, 0.2335889721589704, 0.1954970580916251, 4.887098198936832, 35.45517083137266, 73.93901548077984, 95.29921577822779, 104.82123221120527, 88.0910368888609, 93.30266660259616, 83.41078635184996, 86.39826743833481, 80.86024945782077, 79.32677530473279, 83.02553115352508, 76.7410312160369, 79.0865772001205, 89.97833236571282, 79.59643040933918, 87.93943728170088, 99.67591408760318, 121.0591543874433, 83.42693082747921, 27.94109609819228, 0.33793106675148016, 0.24230237960094408, 4.106201611218914, 8.838329661277033, 31.31580141282851, 81.72393183554374, 81.06140428973784, 68.06258324653872, 78.84865407020816, 87.30633535692769, 91.76088486948322, 95.76426767533826, 85.09591502528038, 89.62480129734163, 93.07409440317463, 95.94909760259813, 83.72388562848492, 89.26514348676129, 83.19512659503569, 85.0837399882655, 84.89497984609297, 79.69994960292694, 89.01306844526722, 81.69325105605587, 102.1968763105331, 51.7905992077243, 71.34297909275179, 85.2428940803774, 60.987517833709724, 15.31883239746094, 0.41750465009001, 1.2772594175992475, 2.6045999027067617, 3.2060448681154563, 5.85062401909982, 5.681891989323401, 1.605990810259696, 0.6007923197842414, 0.20919688586746493, 0.3716578118262753, 7.5915474276388855, 46.93937647727228, 77.49695824038598, 50.67779925561721, 33.52775735239829, 40.907775279014345, 60.32028736606721, 59.341589327781435, 20.85508531139743, 0.8130401048448779, 0.4246773781074632, 0.03744312186515139, 0.05571721850203411, 0.03496326844117815, 0.17487482918846994, 0.07559346545848154, 0.03833195239666008, 0.022694106033492475, 0.052075768941112106, 0.11771168484682999, 0.10281025582263548, 0.1897319706697618, 0.1399364547743913, 0.0809493393547112, 0.07049807677826575, 0.2246819130114971, 0.1215871780990593, 0.19986555190576663, 0.08632604318160204, 0.08896591322075936, 0.12494924688531507, 0.09529091132384154, 0.023577344123153918, 0.12855202049737977, 0.08532977647959225, 0.252919806648166, 0.2563463647158877, 0.10539276119802268, 0.23380376789118015, 0.12889283769313367, 0.22828560592907093, 0.3195850382889471, 0.10790932938576707, 0.09012475910205996, 0.05991184100088093, 0.08541414574269326, 0.07223234662125189, 0.4036254658093376, 0.26627561498072844, 0.6525215794963222, 0.2528200007133907, 0.18512202126364555, 0.2285425671406331, 0.16908141183516673, 0.27345373625716857, 0.3832589876988242, 0.43802786978983116, 0.45583316275189, 0.3458466855508666, 0.6102773463053088, 0.37592672953201883, 0.23968890129077822, 0.20180470430322234, 0.200514612238734, 0.2602153079163644, 0.24884691552048732, 0.2378221595239255, 1.0088805541876824, 0.23592688864277256, 0.9465213035864215, 0.41064482302434985, 0.11548524947776911, 0.26554200918443743, 0.5459499238960205, 0.2717812743879134, 0.12400184893199515, 0.3256708407594312, 0.2048924063602763, 0.18080321591227286, 0.3486814866623571, 0.30070467882098695, 0.3120025451625547, 0.3707044307262667, 0.2889859544173364, 0.1321713722521259, 0.21881539554845905, 0.09415857974560031, 0.3993884480047611, 0.2124012937589038, 0.28882544367544116, 0.17860914009713358, 0.14795410116353344, 0.2024758432901675, 0.23878545380167424, 0.22774396644484615, 0.12642316940811374, 9.223554461233078, 65.11505542262908, 90.92916980866464, 83.03514096044725, 69.59843435595113, 42.52272882769185, 36.643856879203554, 65.17043536709201, 100.76644282187186, 47.00156173398418, 4.229476557623956, 2.3051980330098063, 5.990335412563817, 12.294515352095328, 9.590086225540409, 3.5554469064358747, 0.41033394454467687, 0.25669370898075644, 0.21953426181308686, 3.3088389135176137, 26.02369643026783, 60.4301647217043, 89.70495100944274, 103.05721682886924, 92.44915100835985, 99.50216093370992, 99.83539765880954, 93.97459214733493, 84.5171614616148, 90.31571895845475, 84.50748105202952, 64.08338577516618, 80.57747010261782, 96.01766063321023, 103.67852810890444, 126.85901411118047, 144.4046466581283, 147.03756117051648, 72.95587339708882, 15.217756840490527, 0.15554549623160593, 1.469306383402117, 1.6104695441261416, 4.429668447663707, 21.77730121920186, 82.20981936300956, 100.20195099615283, 75.1573036563012, 75.2398773931688, 86.48925073685186, 112.15249507657944, 100.48863703204741, 84.12080595570227, 92.24918073223483, 93.51144652212821, 101.76571369171144, 87.2267504661314, 96.86302554222846, 82.12010691242834, 81.48565569231587, 84.60252008130475, 69.56995010375977, 102.28471386817195, 73.44980962814824, 112.10577180308681, 81.37717077808996, 88.11226475623347, 82.34391735446069, 53.39336987464659, 7.481503371269473, 0.21604935848905196, 0.6278292173820158, 3.509452948647161, 5.295047250486189, 17.09979045775629, 21.256953708587154, 20.10087432399873, 7.859278609675746, 3.348687742986987, 0.4347297387017358, 16.15640355694679, 63.8849687576294, 79.84432420422955, 55.24612103739093, 42.73711381420013, 56.44677423661756, 74.13875825943487, 65.16437138280561, 24.08051698438583, 1.094925956379983, 0.8101820453040062, 0.20793817276435517, 0.3006482641062429, 0.1541831467540995, 0.3305942120571291, 0.19945929547952068, 0.15446407119593314, 0.24656185910346048, 0.1354037270310425, 0.16594135532936743, 0.2365167150574346, 0.22969261833256294, 0.2850931245953806, 0.1761470714043225, 0.28919065311070413, 0.4003501947849028, 0.22484217860525657, 0.5732602229522121, 0.30722519022322475, 0.19846785513143386, 0.3472034885518013, 0.15503811619935498, 0.11393261142075063, 0.3166786232782949, 0.25160215074016207, 0.46356734128728994, 0.4669669943471109, 0.31806285222691877, 0.3543598835747088, 0.3866212250244233, 0.5201029753492725, 1.0563158604406542, 0.264245665842487, 0.1729381435941304, 0.15321396892109226, 0.24187635810625172, 0.22275219881726852, 0.6738103661806353, 0.6499664004771941], [0.11922218806801305, 0.08737677107414893, 0.12366669312600168, 0.32825427310120675, 0.1303459379461504, 0.07410450462972926, 0.904629715988713, 0.28341447273569725, 0.0909011662306805, 0.26412658513553683, 0.09650636344186722, 0.05553202823765817, 0.08335243459911117, 0.40029286076464965, 0.0447065508623998, 0.09009174071252347, 0.25356347372214644, 0.09733962961622784, 0.3026273450063121, 0.4989699190182071, 0.046465339349402536, 0.41775004337391547, 0.026037350124228868, 0.05710985909606661, 0.07565512787550688, 0.09683310760245209, 0.04821482369856489, 0.09409250466213112, 0.05525871104891262, 0.055663600008213715, 0.044707677011648496, 0.05670693132185167, 0.005949191756606583, 0.0613953396227331, 0.021947440353312322, 0.059534232432563464, 0.089877174806691, 0.08100925509126918, 0.11388835452136495, 0.018197321220331134, 0.0470998976379633, 0.015309584390882765, 0.06653551763344197, 0.009822795644492633, 0.006228777938597506, 0.03324269625027815, 0.08661850490757535, 0.29714589397753444, 0.5185424236039962, 15.494429065335183, 50.60495299677695, 73.08827692462553, 71.62043971400108, 52.61605024337769, 25.048242192114554, 40.10302259076027, 66.26666330522107, 69.03377779068487, 25.895746754061793, 1.0232244167597064, 0.6192180213908995, 1.838542254221055, 2.3582574052195397, 0.1686812075035226, 2.4809135977298986, 0.26955189724122325, 0.12504300072548852, 0.24603878959052025, 0.32290495691760895, 6.17340321502378, 25.77132328864067, 55.05852583915957, 70.23284635236188, 84.60832518915977, 86.48378295283165, 82.65347865320022, 63.54911581162484, 58.65141299463088, 84.84169836967223, 81.28617963483258, 82.23185523863762, 84.93281502877512, 82.69478905585505, 44.175513636681345, 6.456960180113393, 0.28090345102452463, 0.705810594222238, 0.08765460052076848, 0.2100508287549019, 0.09801911130066841, 0.29322042881000426, 0.1637336891144514, 6.400272125197995, 49.62799256847751, 98.32548126097649, 77.24143151314028, 71.68381737124535, 79.06446287708899, 82.84372929603823, 68.34930850613502, 73.16114671768682, 70.82770516795497, 76.804291202176, 77.96310055640437, 88.82045653558548, 85.2791367807696, 83.5603855502221, 79.5930414815103, 64.01270074229087, 64.3405677426246, 42.72518588650612, 40.62708262474307, 37.57775360538114, 25.130100096425704, 3.91872089716696, 0.4055513495639448, 0.3347272564086222, 1.297407407433756, 1.227119391964328, 23.473075205279937, 20.369272308964884, 10.581656502139184, 2.05440511626582, 2.5296078622341156, 0.4564617532155206, 9.936858069512153, 46.39098990348078, 66.89814136874291, 49.96312772074054, 31.75684448211424, 39.43760818050754, 47.60579109191895, 46.766596071181766, 25.50164661099834, 3.1733188177308733, 0.12972629538947536, 0.20157201275710138, 0.01540715239130922, 0.08272312401283173, 0.0853390384825968, 0.15965580309350647, 0.06924014508483872, 0.09398190454850275, 0.10020531939282533, 0.2050813083206454, 0.050147609905369823, 0.04766539310015017, 0.06143792262000423, 0.06553200373966848, 0.05165134473974186, 0.13739927882148376, 0.1296016988494704, 0.027739386817800905, 0.06141577501811328, 0.07098659572582092, 0.02224578754976392, 0.09186087521694361, 0.032845663522640546, 0.10503698230510759, 0.042390180601468014, 0.047676217922520255, 0.10920016455554193, 0.11940738982370785, 0.04038805577663645, 0.0633201202107293, 0.1834278944278917, 0.5398708629992701, 0.08885021096155529, 0.2187661514166863, 0.03643639806297518, 0.06508293065933451, 0.1368758109428229, 0.09200223376073184, 0.07746256677614105, 0.06638288993628756, 0.23108904340094139, 0.1674135771369742, 0.024162012850865725, 0.09548600327463881, 0.37680975311706144, 0.1656571979964933, 0.06771069650928821, 0.6132362230170159, 0.33890825786417533, 0.060501583145871285, 0.2782706826204254, 0.14311020382710044, 0.035860395704906796, 0.11816421298370247, 0.3800393346576922, 0.09286909289057217, 0.09063603086096626, 0.5153624232738249, 0.14322228249042265, 0.5065738626064793, 0.3709429292188537, 0.014866836323973634, 0.5977716044552865, 0.055657976922849496, 0.2249793696307367, 0.21336691694394236, 0.05301144191875093, 0.03725967062036357, 0.08789380381424582, 0.034669385622105295, 0.05188971682782135, 0.07111123823110135, 0.07858654799600763, 0.09600339607606012, 0.07798130789230909, 0.03232714074153093, 0.01859789327417891, 0.03737269157183267, 0.1247639608599486, 0.05215925337266057, 0.016962149999134483, 0.024325229798353488, 0.005503982632240702, 0.023228910098212863, 0.06495088008382628, 0.04352748409033783, 0.02567503650131966, 0.23067889524804008, 0.3049460480049733, 1.3111281034446534, 24.328891269622314, 68.33120284541961, 80.31658541771674, 57.29087614244031, 28.99380926162966, 25.37545023425933, 67.5206450493105, 94.78004301747968, 76.43936957082441, 16.16235967605345, 0.954172867200067, 0.3477796786014111, 2.338535482844999, 0.9652136037907294, 0.08620045838817474, 3.178263210481213, 0.4010177638021208, 1.021181536057303, 0.10816520275247675, 1.270340356615282, 12.892358110797021, 40.47745204740956, 71.62035342185729, 79.92895326306744, 95.63005201278195, 91.42755400749945, 90.4484833440473, 82.16919145276471, 72.05545410033196, 92.64536365385979, 87.10754179185437, 100.2919380126461, 102.57205886225547, 111.6443520207559, 84.01221121511152, 27.33892010104272, 4.071722751663578, 0.4130059060069823, 0.2706645939859652, 1.055007627414119, 0.2827559741995027, 0.14134368168250208, 0.33788421281403114, 15.898407697677614, 85.07584033473846, 92.82159574570196, 63.8718209728118, 76.05032536291307, 82.01904312256845, 89.15074363831552, 85.14991821781283, 86.36640994779526, 78.52718445562547, 81.3124438255064, 78.60604763031006, 84.46904966908117, 85.81571702034243, 85.36791570724981, 85.8449229886455, 73.8350962054345, 81.92878154016311, 52.70413098796722, 62.43403304007746, 52.152743800993896, 46.27443275144024, 8.997214090439583, 2.120579423442964, 1.0050555691123009, 1.7087236912019792, 3.2965099234734816, 33.686483906161406, 23.471341517663774, 5.502398446682961, 2.719346635764645, 0.6429166755368633, 0.46765932332604165, 6.0855803662730805, 46.60847356242519, 80.26197818017776, 67.3044204711914, 37.831299535689816, 37.68424595555952, 51.20078456017279, 56.517612241929584, 32.26441683307771, 4.501494890259159, 0.1064940891979683, 0.1716647522463914, 0.03880849738995876, 0.03136777266439411, 0.042470164011202516, 0.15857753434008168, 0.09011689903995684, 0.0972878420725465, 0.03894676476897251, 0.10215151979918442, 0.010344369370760697, 0.1090588596379084, 0.1012806693512586, 0.13146629557013512, 0.21114743765323393, 0.2568001032716805, 0.07616630770386228, 0.06841946573507401, 0.08418730955811278, 0.14084140379582683, 0.015973877424614567, 0.08822454695379542, 0.05663944663660181, 0.06506982289495007, 0.0818789947117048, 0.16140522615563485, 0.11656147277643604, 0.1641495982485433, 0.17938382352792448, 0.033278610452168414, 0.3150541491566166, 0.429453875028318, 0.23651636265698942, 0.29183187912548747, 0.130954839950127, 0.14138881958300067, 0.12443297257226323, 0.09072001708010513, 0.22314432858219072, 0.3064935149685029, 0.2635186484023448, 0.20569376497259065, 0.19964619028952815, 0.25750010845161253, 0.46827556445233287, 0.23869076533423317, 0.13568218466975998, 0.9589984856786268, 0.43701127111431093, 0.1421304846242551, 0.3146457323624242, 0.10595580517885186, 0.09215462397062972, 0.13222806275852267, 0.612324639674156, 0.15564312647667625, 0.27983883395791054, 0.39057849816256957, 0.3120498281092413, 0.4710938487081759, 0.5180051814644567, 0.10544190573836527, 0.6551712018347556, 0.2834298557812168, 0.21107305051578631, 0.26119421506601, 0.2476481871018487, 0.14998959677834667, 0.29625392248553617, 0.2482981667403252, 0.16724702962223562, 0.15219741621084754, 0.20126733958961504, 0.09419061754259372, 0.21464112034488111, 0.10072484191867614, 0.12275742336867318, 0.19219258379551674, 0.1935762151955597, 0.17761152508037706, 0.09666485171164237, 0.12955950272660102, 0.12154688187424215, 0.14971265599371927, 0.14248161336346982, 0.11052365805352889, 0.1594706089986909, 0.3373342842584656, 0.3219939558015716, 1.4528445635111102, 29.920641799126905, 81.58606052398682, 94.88001638843168, 90.96560862756546, 73.29884544495614, 43.499665721770256, 61.59750130868728, 85.79851350476666, 93.1159225586922, 35.1994126842868, 2.551419182169822, 1.8165969608291503, 3.998620067873309, 5.440961872377704, 0.3291148349883095, 4.762788972546978, 0.5840924610534023, 0.9072700226979872, 0.3585735510193533, 0.7304780125137299, 9.478215325263239, 30.780156658541774, 60.770693132954264, 68.30382470161685, 92.6091052639869, 81.29382825666859, 88.93233037764027, 71.39597031377977, 65.94083985974713, 91.88956999009656, 72.95464961759507, 76.25004460734706, 74.52770048572172, 88.98462341677758, 57.82098447122882, 11.91442689587993, 2.4448049933679643, 0.7930210016427502, 0.2715094357488617, 0.8210957338733058, 0.2412598871535832, 0.3984407053118752, 0.2542518956526633, 9.87993565297896, 76.61290307198801, 95.74242791821881, 80.30270807204708, 77.73106098175049, 67.13622139346215, 96.27223030213388, 99.61587044500537, 97.65096695192399, 85.21150727425852, 84.4595261543028, 83.08311154765468, 81.36365429047616, 88.32877958974531, 83.10088772927561, 105.96132401497134, 65.73040862237254, 71.96599268144178, 58.162485630281516, 50.85126999885806, 48.93663952427526, 31.689697427134362, 5.194519844747359, 1.4336038669270854, 0.5493292909476065, 1.6804072429095547, 1.2226439675977154, 33.8757029656441, 37.92684847308744, 19.99490757142344, 10.835985925889785, 5.649084794905878, 0.4972034734824012, 12.86366597298653, 59.56476826821605, 80.03953272296538, 66.70656496478666, 44.9974698405112, 53.71243899868381, 64.5250525013093, 71.05468488508656, 41.29080257108135, 7.523419780115928, 0.1735606819631592, 0.25525183957670966, 0.27210603438077435, 0.2939785187763553, 0.1591801544230792, 0.3744002533776145, 0.20312824376648475, 0.2999355571885263, 0.18703647498642245, 0.2744406720082606, 0.09257103106187237, 0.1895293404137896, 0.15285758481871697, 0.13620911526583857, 0.25619457205457075, 0.3136620448241311, 0.20046129251920408, 0.08725054276686522, 0.15437381071669443, 0.16524715709590143, 0.15480363200749123, 0.19929817186728602, 0.11484400324162938, 0.16487728984605882, 0.126061438012027, 0.27186202005513255, 0.22545521748402428, 0.13923430454827126, 0.21989803100305222, 0.16341701901007086, 0.26382312238697087, 0.5003891122196952, 0.262577218273955, 0.29772027605964296, 0.32360221950277207, 0.18026546815470343, 0.2489739482200915, 0.29089853888557804, 0.21953299010713256, 0.37649400231819, 0.23215546843505677], [0.028231232502167265, 0.05027007289050568, 0.05339306478779163, 0.045072177815581524, 0.11467976931242213, 0.1757293083374539, 0.39092210391836785, 0.7887188357210929, 0.059412899427115924, 0.1291912289396409, 0.16169168175228182, 0.1438823591677412, 0.0759608505834495, 0.5164183988686532, 0.33672184292827884, 0.17384735206442495, 0.07535728055142588, 0.05078466564056374, 0.02782513695438543, 0.12431073558306503, 0.1876624607511105, 0.11513301757194343, 0.09927650673254844, 0.10377323600433527, 0.21408328576193703, 0.03672740422189236, 0.04296787218340943, 0.035006908639784784, 0.04991722811434058, 0.013053603883412097, 0.05836188808203705, 0.10831354035725517, 0.06693610500904822, 0.09305870731271083, 0.023133156768557046, 0.08879158991358935, 0.07699954323470592, 0.07903906081112162, 0.014587301374112648, 0.025618411112396468, 0.03916904134976287, 0.04076160790939485, 0.059066106745552634, 0.11442443986813869, 0.10842314455658199, 0.04874423641951815, 0.058316723368461096, 0.038489249399712974, 0.10314242388572424, 0.5686386290096468, 2.963963535524184, 24.479194533440378, 53.533304352914136, 70.30053077205535, 65.12801493367841, 35.350208205561486, 26.190581513989358, 38.12463791139665, 65.24228926627868, 68.78258136010939, 21.060911686189716, 0.9630673931490992, 1.1207867557964017, 0.8100947725676722, 1.295010961832539, 1.4322250312374485, 0.30628743731687147, 0.11720099531474615, 0.20177406078625112, 0.6259014950163904, 0.3382497899714978, 0.03319993705278443, 3.698651905982725, 9.733508671483687, 16.393872672511687, 16.607038782488917, 2.8675629535029015, 8.779341136255573, 15.212733264892334, 8.290696182558614, 9.345636271661329, 2.5578636363629372, 0.3089473865205242, 0.7119491035419127, 0.08259514902508067, 0.08926418189319874, 0.42302789887593645, 0.12701196926495723, 0.08398563691204594, 0.2498748063320114, 0.15130827924416912, 0.02361856156870002, 0.1788577356285626, 2.707009800980168, 28.96119671483194, 94.8937133050734, 100.30614483741023, 66.65852377491613, 70.24685705861738, 88.35355327975365, 82.40573390837639, 65.64198663157802, 52.56136455843526, 34.77906404003021, 26.817152692425637, 27.25759760026009, 34.07468088211552, 31.539629505526637, 18.485153951952537, 11.017010173489972, 17.243549246941846, 9.057438162065322, 0.8680044006436103, 0.0849634638777183, 0.1309429043002667, 0.18243630086222004, 0.15774323394702328, 0.3035833001617463, 7.279507681246727, 5.164936348315209, 1.517269371017333, 0.8291109747463657, 0.5144835059200564, 8.54144154056426, 37.714914967936856, 62.21490983040103, 40.42863422824491, 25.00015393380196, 30.201793370708344, 51.909074398779104, 55.48773904000559, 35.059752771931315, 6.1343256215895385, 0.12749994429008615, 0.3626624687064079, 0.04436039403381367, 0.07170106464576337, 0.09583987460862245, 0.025592971247650927, 0.011470343376840315, 0.04506217653773004, 0.010546670208925442, 0.11727260921390788, 0.04769153968100587, 0.07396705313435487, 0.07530196134241358, 0.05658733733599225, 0.04222611904204373, 0.046611175677108194, 0.09449554351909507, 0.033734225923375744, 0.02737352429258247, 0.033567218755882595, 0.07923631312986536, 0.03692895812433093, 0.09133223624479386, 0.022464547786981832, 0.05117415240214718, 0.08529377034715108, 0.0707185645437529, 0.06265185788393983, 0.05820233878048678, 0.03091831270965838, 0.07660362133455854, 0.016461109344456947, 0.0997571119918458, 0.1017288001434457, 0.022907434707327236, 0.00909732761717732, 0.12406333514879789, 0.04082777492341496, 0.02612347564389629, 0.03568251774976811, 0.029148034819011247, 0.024538566133067496, 0.14936866719395886, 0.027730735769915967, 0.029389103536584207, 0.05907974694104445, 0.1071416863030003, 0.021738434330590313, 0.0971829110095578, 0.3637262890415807, 0.7949134839638587, 0.0871035841203505, 0.2679762688855971, 0.3483231720184127, 0.04544735788517902, 0.23406803758153993, 0.35567632906379243, 0.19968386649364428, 0.2814731140050196, 0.048268097452819354, 0.04248354373680007, 0.07822611128851291, 0.17321568192733874, 0.15479017950354085, 0.15530191091520174, 0.044170722155080694, 0.24052148564688622, 0.2047049293234464, 0.049832793733766007, 0.08422746788710357, 0.019524074422435898, 0.05262271741465215, 0.07415570994658817, 0.01816497124250858, 0.017737616754827962, 0.033896621241564714, 0.03209932534504802, 0.02679192566222722, 0.02583496501639245, 0.04016625800079877, 0.07606672393458505, 0.055991746109700015, 0.018839584438190348, 0.011644183091008136, 0.051581060003128745, 0.029530044562453707, 0.07603254109140366, 0.17796950264563485, 0.12985463043855083, 0.1161605483221431, 0.028174492200055433, 0.08705376542263454, 0.35159954620945844, 5.695966924390485, 36.15154450939548, 72.88201516674411, 79.27550208184027, 53.381339965328095, 28.1071182604759, 36.14830855400332, 57.82367521716703, 89.22291524948614, 64.90817785263062, 11.685018251019141, 1.5294203835148967, 0.3821932981091161, 0.8053874380646214, 0.7579374229235034, 1.1763201629923237, 1.188319061071642, 0.5664498238794266, 0.5760136042391101, 0.5262933947866963, 0.3541220898830122, 1.1782943409296776, 8.971847141942671, 20.041775972612445, 26.38009867360515, 30.393905178193126, 11.830112607248369, 20.673075568291452, 31.32704096455728, 19.35979150956677, 21.33451661755962, 11.20403858923143, 7.077700755288524, 1.5610626339912417, 0.09274191463426237, 0.17079001773268948, 0.7488896181025814, 1.6151284618723778, 1.5504526226751267, 0.7708463108827992, 0.3648306507497065, 0.018184437536664547, 0.2993515223985718, 8.43518159081859, 71.25518860355501, 114.41356889663206, 100.89624189561414, 84.49198768984887, 78.68505201032086, 94.75396710057413, 89.42458783426594, 74.70986320126441, 64.26627020682058, 56.58490050223566, 44.42823586925384, 37.518894518575365, 50.61568852393858, 47.35056638717652, 31.536944643143688, 22.459109175589777, 25.054694491048014, 15.449009979924849, 2.9104219569313914, 0.4468186367903987, 0.25109337642788887, 0.2365891103662791, 0.3182522291618009, 0.46687564602301973, 5.560919719357645, 8.668435139040794, 3.7610462740544355, 0.9874988563599126, 0.49199196119462296, 4.055505221889866, 39.17046339281144, 80.6958943028604, 63.15843989772182, 35.09211232585292, 32.894288686013994, 53.639526059550626, 65.30858908930134, 46.54005173713931, 11.134223341941835, 0.1433927064100581, 0.32405528390119154, 0.041640038797331434, 0.10969567788584579, 0.051421901406419855, 0.08299941362272348, 0.1181538401532077, 0.030880194089765993, 0.03536536117955562, 0.05307480888140779, 0.048490301255256905, 0.051067957294083414, 0.015129213777160453, 0.0932661486008475, 0.03977723855284914, 0.06834366899584571, 0.13489397212622628, 0.050990540278895255, 0.05472432258689115, 0.041519441236291206, 0.012747848616732706, 0.047295319006568005, 0.036123661820085785, 0.05056035892677404, 0.038162110703847105, 0.040795269812787735, 0.08921924317556043, 0.05342005406536403, 0.06513619675270974, 0.01712717299890374, 0.09641341399401428, 0.12206324045696568, 0.064854291718333, 0.16976448647197218, 0.021629075279399272, 0.021460258229185018, 0.06291445750262468, 0.05610962405860905, 0.07912009759175201, 0.01551179042566688, 0.10678620618437568, 0.04334305991388617, 0.13514518767835634, 0.17114041102749689, 0.09468505068892434, 0.18944828831140073, 0.11958161353944771, 0.19392443280066216, 0.3661845119730119, 0.23987149068665123, 0.9926790816168632, 0.14135756319569004, 0.3916919303517188, 0.3452993310507267, 0.1898189522926846, 0.5212152124412599, 0.3986128912337365, 0.33969769614838785, 0.31691093178045365, 0.23643668951286426, 0.15295625694336432, 0.22951272556618338, 0.15808291733264923, 0.3501068085672394, 0.23458577512252718, 0.16179110464309493, 0.673030243525582, 0.29352946867865903, 0.1571862573825544, 0.14070258866394722, 0.09941363647099465, 0.17271001793203816, 0.1303119849293463, 0.22826268457837645, 0.12623251310639805, 0.08987538982182743, 0.21458919490537337, 0.08776908470017296, 0.14204918737373046, 0.2313179045074409, 0.24625320227876787, 0.14843811551409383, 0.13423689851357093, 0.19184079622068714, 0.20152080744024248, 0.12765919864778558, 0.2752597732169013, 0.2545468395035113, 0.20985636499620255, 0.187289314644952, 0.14615794673802393, 0.20890443946325013, 0.6513103638445178, 7.109519512422624, 47.19995521729993, 85.66924787336781, 93.06526907028692, 82.59025004602249, 50.94704643372567, 46.52281292023198, 54.945773386186175, 83.6874624990648, 85.25375904575472, 26.223864786086548, 1.6143688703736954, 1.922162528480253, 1.5707640037421258, 2.807407033058905, 7.156908608252003, 2.8028570836590183, 0.39864203321837616, 0.36234245845867746, 0.8140153041289699, 0.6136128318405921, 0.3197078575049678, 4.782384643631597, 11.136911146102413, 18.805121298759214, 22.717210938853604, 11.051363272051658, 17.77605414390564, 24.520808919783562, 11.247388624375867, 13.167321162839091, 5.053913660587804, 2.0002537316853, 0.6709337366684791, 0.1742780773389724, 0.11681189159712485, 0.8188385937002398, 0.7773808570158097, 0.4954111648182716, 0.4903534829856888, 0.4445353270538392, 0.16080387777859168, 0.27795824132138686, 4.402419251780357, 55.34086196653305, 102.64320281244095, 114.24943339440131, 96.53096552818053, 67.15426429625481, 108.51127255347468, 90.30566200133293, 73.32933010593538, 56.33200960774576, 50.99466008524741, 34.42542314529419, 27.875206162852628, 47.57748726875552, 37.929727492793916, 35.181467840748454, 16.437446282755946, 23.17831693157073, 15.238895473941682, 1.4625121028192583, 0.46237619713910166, 0.14773222677890332, 0.37271936454119226, 1.0042376323573052, 2.0249837853254813, 23.81255634369389, 12.244378635960242, 1.783540205609414, 3.5607921163881984, 0.6841637686856332, 12.337499626221197, 49.850296820363695, 78.3051626143917, 56.06200541219404, 39.63728427886963, 44.67507846893803, 70.24233848817887, 74.98281309681555, 53.86541928014448, 13.859140969091847, 0.2207950433535922, 0.6533294651777514, 0.23931711882112489, 0.29942178798298685, 0.1685685772568949, 0.15700748310454432, 0.12472694349144736, 0.10556433424954453, 0.13860528507540304, 0.4064287347418647, 0.22513421132199227, 0.14310500975097382, 0.10389702049114051, 0.15282992904465045, 0.10688963571503278, 0.1594439951042014, 0.1749890069327047, 0.1489172881889728, 0.16261253475902543, 0.1608718604209923, 0.17082018627514764, 0.10940597407639989, 0.15706215113882097, 0.10620681388724236, 0.15643619601764988, 0.20124901476646626, 0.17750030443553003, 0.1627706859501139, 0.11454799452856665, 0.12057741292782369, 0.21671652914054934, 0.13234041721349762, 0.09526379181132202, 0.42645988084616204, 0.11406619417210741, 0.0847121870385543, 0.216994236013101, 0.2469530082758396, 0.2524141426528654, 0.11734093659587445, 0.167882805990596, 0.12252137635744388, 0.3444718335184359], [0.08988410024152649, 0.024335491546099226, 0.018000982461437103, 0.028361634073418476, 0.02951693488284946, 0.027361663336294795, 0.033745678937843734, 0.050147349435475566, 0.033243129089955366, 0.024652966042800296, 0.1590758285695507, 0.060215127549224326, 0.05845170039984007, 0.046303510936277534, 0.04060109333705999, 0.021690419769936034, 0.029200659313749884, 0.11292215677038317, 0.0758191779436123, 0.11078616574166283, 0.018456456206378438, 0.05858083601079642, 0.058142986118553154, 0.020758253559770606, 0.09534669784648765, 0.11110026945149708, 0.07209990534090227, 0.017088588980597355, 0.0024812503374226753, 0.044307147092636556, 0.10519851960482136, 0.004309401622102146, 0.05742182159015248, 0.07484464515601436, 0.034295511732418696, 0.09444447609806254, 0.0770352965581321, 0.04161564655782234, 0.06722074497731463, 0.0496562717542533, 0.018477395304568836, 0.02872059989209858, 0.08304969963407324, 0.02869301306594524, 0.08808756277205483, 0.056751015851454395, 0.041558684090212475, 0.05189886774807688, 0.018801008080763203, 0.09340635801274931, 0.35332048612256206, 0.16937676937349383, 5.92186063528061, 31.754655799558087, 59.46168838008758, 69.77254052315989, 44.853930704055294, 35.33298900050502, 30.367066360289055, 40.94811685623662, 62.29011343371484, 59.78555064047537, 20.414575684455134, 1.180301859013496, 1.5298815071582796, 1.1483791590698305, 1.759973012151257, 3.1604178970859897, 3.0596669162473376, 3.1875320163465317, 0.5456622425586947, 0.20339016922779624, 0.27587883354675385, 1.0066178368945276, 0.46610759691365306, 0.011812855542126683, 0.6947176410786567, 2.259354841324591, 0.9203151517337369, 0.367531294543897, 0.1731442825327958, 0.45571209021633674, 0.7729941149873119, 0.2157685566212862, 0.5820589572671921, 1.5847527692394874, 1.4272308734155472, 5.279547514454012, 5.069388881806405, 0.6085787148725602, 0.014248428126466612, 0.07945000569546416, 0.1165085973879022, 0.059905015157475594, 0.2997704192755684, 1.8076880324271418, 20.205703589224047, 25.745333663878906, 22.394845062686553, 22.441323188043413, 13.20284410830467, 6.6145433629712755, 2.6236231528943588, 1.7224966037657954, 0.3317048556862339, 3.8936062061017562, 14.847438027781827, 1.561654299016922, 3.8781547642523244, 0.6721527357735942, 0.16751192750469332, 0.2065390663882417, 0.038165887517313805, 0.22979637728102748, 0.44696866744948976, 0.8957570082237645, 0.5247206469216655, 2.0676786620770735, 3.1805543649581174, 1.070503563650193, 0.010280304310482838, 7.229516092808017, 46.66488116787326, 62.50534172981017, 40.04275537306263, 23.891588180295884, 30.070089986247403, 51.72591540121263, 61.15028442875032, 31.176137578102853, 11.488924257216915, 0.38213004989008753, 0.18630073946570197, 0.05450688768178225, 0.043217260615840074, 0.07631844510474513, 0.007248321264576648, 0.13985983066020474, 0.043183870673660314, 0.01054173372986336, 0.02352118413264473, 0.04994714001734411, 0.07787712759548619, 0.0751481002437011, 0.052690523856830214, 0.040111605288280595, 0.02722524222917855, 0.12298640704924062, 0.053784248434127345, 0.06812273689936246, 0.03243908916990603, 0.006558559637802143, 0.010521344299758635, 0.021908875487204042, 0.05245156571148865, 0.03873097312246119, 0.02752099621800646, 0.014070055087006861, 0.021746311629671725, 0.07022535713810114, 0.030972561310796492, 0.06778487680299629, 0.04062702541329688, 0.07512542404114239, 0.08105574130651452, 0.040735668172278715, 0.012048817326074407, 0.047070518166067145, 0.06479922531833572, 0.007536526414520679, 0.03120317675864264, 0.012887529427966764, 0.022787283392502897, 0.01947680679750779, 0.026322459321348902, 0.03495135960439521, 0.11232527468593852, 0.02472581717395975, 0.05108057476219632, 0.08929926105925153, 0.08783692944674723, 0.13751583143828378, 0.04577031374097832, 0.05052275550101073, 0.054148182332996404, 0.08231408668742066, 0.13675126036809337, 0.03067645683674322, 0.17390871570715982, 0.06041151801905325, 0.03198954494549863, 0.08367146425429853, 0.06586158242557319, 0.09124700130233843, 0.06317765083945086, 0.0410149340337563, 0.048306945771459615, 0.02336721961206246, 0.022781846083460316, 0.047384472488756144, 0.03470621146862546, 0.019560969216869246, 0.05561604510031401, 0.01374785382781298, 0.048745021659640536, 0.057795883171380534, 0.03338220086128962, 0.008922798423877647, 0.07400773240313416, 0.07005867938841544, 0.03181890460602459, 0.03177734433613237, 0.03838978820450364, 0.029700359314559933, 0.06285797767040711, 0.056691969624690475, 0.046228001480020826, 0.0036843883102729677, 0.04678667875968161, 0.05063866077351475, 0.015959962395079914, 0.07351936667316383, 0.09453052309371772, 0.08201620871982268, 0.06069475221597861, 0.05536160048758311, 0.42957528464255795, 0.06847126093963463, 10.343729449856667, 44.30445371135589, 75.52314312227311, 70.22756684210994, 37.20281031823928, 30.200530367512858, 38.72218355055779, 73.37238204094672, 98.92304651198849, 68.45853867069368, 8.844139672094776, 1.7647473946694405, 0.8821833398072951, 0.3835128385934138, 1.712314130798463, 0.9201004019668027, 0.4181930873422854, 0.47786664818563773, 0.9032027086903973, 0.4710582715849723, 1.0885177841109615, 1.1048475917308562, 0.6736344111061866, 0.0443960860702059, 1.4226104439266267, 7.944562214036142, 3.018347933407753, 0.618901289999485, 0.3275797173621193, 0.38006492199436315, 1.8982803196676317, 2.4615790094098737, 1.5451774025155653, 3.888512027840461, 3.1210868204793627, 7.101649766968143, 4.786319271210702, 2.762621165283265, 1.117938502180961, 0.4277597481925642, 0.1401889879977511, 0.028269240039310632, 0.8752040949559982, 16.416061520576477, 48.98480230762113, 41.06346199589391, 39.46828503762522, 46.26907871615502, 29.47397405101407, 16.23635518935419, 9.242588743086785, 3.8167297119094483, 0.8337163889119703, 7.110288296976398, 25.743903959951094, 7.436654500422939, 7.858615729116625, 1.4489742873176452, 2.701430964854456, 0.3321164287626744, 0.09649373831287508, 0.6539446031374316, 0.3944234321674993, 1.505199870274913, 1.2569453399027548, 0.47511954881971885, 1.827461803632398, 1.610357266279959, 0.17262994642219237, 3.186590647505176, 41.920182166561005, 76.16315626328992, 56.905805295513524, 31.273439814967496, 23.01543070423988, 45.39704953470538, 66.31755998057704, 43.37990399329893, 16.90259918089836, 0.6466529782741302, 0.21560009388673693, 0.023000204124517983, 0.11147127051146762, 0.03249206031943041, 0.06223240559319816, 0.007489250649908378, 0.07610476020002559, 0.02968382522193415, 0.042939963600327896, 0.07777323075119527, 0.03097891984056802, 0.050943575258697235, 0.10514362940504667, 0.12769708169564126, 0.03202168424914201, 0.09019278004885682, 0.04867043150889297, 0.035871235849035364, 0.0738168845794374, 0.03011017996487358, 0.044840597096950784, 0.026698099043700966, 0.05972211549599325, 0.03777265458578064, 0.040938275445613174, 0.06745790281603414, 0.05075951114356999, 0.05731604016956784, 0.020005304043391542, 0.055913248910538615, 0.004787428995534297, 0.032751679856089816, 0.002126493693081542, 0.038889300513772235, 0.033666369685482596, 0.040639677355366374, 0.032645331530441205, 0.09980840157837638, 0.016028605788315258, 0.01885716041039315, 0.029794819870843526, 0.0751515016740849, 0.056858555443825266, 0.11868868443754413, 0.3290561220097927, 0.1399625170855753, 0.1345739005914619, 0.10623744208245509, 0.1376748559696059, 0.1221645785675895, 0.1399949838918063, 0.11282962101000933, 0.14614578126178634, 0.13528381894913413, 0.34956683915468956, 0.15650552697479725, 0.33305200597932266, 0.17282525287760844, 0.1458494431309162, 0.20124040393819734, 0.24657935655165106, 0.22753595825164552, 0.246628386178805, 0.20083731911595792, 0.09644385832812517, 0.18893531583730253, 0.15268405058210896, 0.10358963537240222, 0.13741069353155552, 0.22211280651390555, 0.13346103530737663, 0.07901089175814584, 0.1626548381342042, 0.1369154023667497, 0.185465473801859, 0.12802306742918107, 0.1689961768927113, 0.27580216346729186, 0.18715239941112458, 0.15089054682081746, 0.2343796208621033, 0.08238914032136241, 0.19702825334764298, 0.1104342096274899, 0.1756803246755754, 0.14393881984776066, 0.2712617442011833, 0.16350059920260984, 0.18144604028953662, 0.10826831052620565, 0.31749922601926717, 0.22614420631960516, 0.1478717313899148, 0.28775457533136495, 0.6366813939905936, 0.22886524337434003, 12.492772533047585, 56.252201141849646, 90.74313179139169, 87.49095347619827, 57.470151993536184, 54.894037323613325, 49.8114182872157, 58.152640481149, 78.37821283648091, 77.54321082945793, 26.395860718142604, 2.461136271876674, 2.591659268063884, 4.198405992600226, 10.355440666598659, 10.98984383767651, 10.3808742953885, 7.508873180035622, 2.0525862396724763, 0.35888415370737353, 0.6665395176218403, 1.252410712261354, 0.8640398037049078, 0.07667597833900683, 2.52256132421955, 9.0333479450595, 4.538824087189091, 0.4543422943642063, 0.21676381208723594, 0.4754773425238748, 1.7778640456738013, 2.281040890562919, 1.9013808307147797, 4.437636252372496, 4.3681107701793795, 12.024491544692749, 11.33094491497163, 2.186839532467627, 0.5597051857940613, 0.39180200186467945, 0.15030510242908232, 0.1518831363007907, 0.5131095119061009, 10.495879169433348, 33.00382283426101, 43.640314071409165, 35.95325693007439, 27.80437796346603, 17.036093127342962, 8.553173349749658, 5.141763475633437, 3.1354858413819344, 1.761355770211066, 5.587213327807765, 27.20768936218754, 4.6856158491103885, 6.649657891642663, 1.650553225509582, 1.9035038135705458, 0.14896395826531997, 0.1936527780227123, 0.6939350056552118, 3.6714335987644815, 3.3171928265402397, 4.665933395585706, 9.149292226760618, 8.53215140681113, 2.2460685478102778, 0.15464704363576828, 10.785245164748162, 58.76234154547415, 75.49664358938895, 54.42400793875418, 37.63651855530278, 41.59436656582741, 66.2473887781943, 81.80116330423664, 55.675675484441946, 23.638589420626243, 1.1962579383004097, 0.4217312797423332, 0.21897411364461147, 0.2619843887946298, 0.20580121646485022, 0.10703812653739607, 0.30773292265592084, 0.17878230661153796, 0.17999621889283582, 0.17300356750286397, 0.25495269756403666, 0.20556696209936373, 0.19995210451945183, 0.17288690763375453, 0.1538043009537843, 0.1514648369723751, 0.2048792143262202, 0.1581144801551296, 0.10135996711230087, 0.15103280934835636, 0.12064095226026351, 0.17204031919039067, 0.1185263350846306, 0.15693199280048573, 0.2328456830113165, 0.19733839638290868, 0.18572571386973705, 0.16419959314648183, 0.20222528657365232, 0.1502029062999833, 0.14221591874957085, 0.10670012854520353, 0.1486366395387919, 0.11927065079010303, 0.1009774364290699, 0.10918524116277696, 0.1320787369003219, 0.09980437195589466, 0.2143838986634247, 0.19231063794464837, 0.0744876558441789, 0.163453055786029, 0.17744215836207713, 0.0984043845786683, 0.1170317664922726], [0.043777240244972135, 0.06209874240260932, 0.011602321173995735, 0.02680845592441338, 0.027370567193194747, 0.006687903528912895, 0.02251865466185395, 0.043696663117096315, 0.041323897293618614, 0.04486686625187436, 0.024560610313088666, 0.02227864697605612, 0.03812006396812297, 0.037596688020013036, 0.04326519473726231, 0.06857005563834984, 0.034880875684921785, 0.044887971974188284, 0.02994990096457543, 0.0476039030529078, 0.03288571076888231, 0.04400759522292403, 0.072311008529317, 0.02243770023567542, 0.026269062993026553, 0.013296168387657212, 0.010954591918796783, 0.016604921284822688, 0.011752731046609342, 0.03918853062655657, 0.018305345363314116, 0.05148027347581041, 0.040846724108222036, 0.1068241351975068, 0.03073997893220475, 0.010523095768275521, 0.027827527148709185, 0.02442522725510982, 0.013890987780365734, 0.05738109252565811, 0.04340671798995426, 0.043710962148203004, 0.03852748484801381, 0.026694167097429597, 0.05926338970781334, 0.02430954797854347, 0.027951725322993535, 0.017255569335013148, 0.04096811073982427, 0.08367822114979068, 0.08262841256275293, 0.056409819442177975, 0.5067858238133692, 0.16098479710278973, 9.40184775860079, 51.07804575274068, 69.42464197835615, 60.34391964635542, 47.2234227580409, 32.09665706080775, 24.04113638785578, 23.279559189273467, 58.87018711336198, 67.20279970476705, 34.99376281615227, 8.581901769484244, 0.7253314338384137, 0.47323797559065206, 2.059759886995439, 1.5393863906783443, 1.1121380521405129, 0.7136944356945254, 1.643336922410996, 2.240015104893715, 2.0653080796041796, 1.164875299699845, 0.26977038551722804, 0.8238054175050029, 1.8054188187083893, 0.5866823898207757, 0.3527709865762342, 0.21740651389043178, 0.7501807520466467, 2.0161579621414987, 3.3558259664043306, 3.326501346403553, 0.8320448463482242, 4.688905737092418, 3.782373671570132, 4.376531608643071, 3.520950151066627, 0.20272548070117352, 0.03767177612791139, 0.1436814602704779, 0.13079336393744717, 0.31356606932897724, 0.5939054344930957, 0.24465652182698253, 0.2135196748760439, 0.17743736265167115, 0.7062349456452555, 0.13011597367303987, 0.11148578787763273, 0.19796554660124166, 0.044950166822320996, 0.6615709164930929, 1.794466458020672, 0.397022737851066, 0.4288063775147162, 0.6490640101894256, 0.9521274737292721, 2.418514326695473, 1.3167332929949607, 1.4099831086012626, 0.41656974703073507, 1.9768297047384324, 0.9594716215806623, 1.3676977518104738, 0.520786999935104, 14.842452695292813, 49.516322689671675, 60.66077263124528, 40.11796289874662, 24.102480296165716, 37.90403989053542, 55.94640531847554, 70.65205358689832, 50.077202012462, 19.80501582545619, 0.3107836992750245, 0.16413410795071434, 0.062489087182667956, 0.19537053101005095, 0.06154760342812347, 0.012219359031728199, 0.03546620516346828, 0.0587116263716692, 0.0359983298356735, 0.08795419452531685, 0.10989833112445571, 0.050624786921206026, 0.04451645763530847, 0.015743705350154593, 0.08137870865363268, 0.06441801996721376, 0.03975332511829273, 0.04022900826267658, 0.057016484469415686, 0.07412334273178732, 0.04366264498281864, 0.015517995737853552, 0.07653940784474535, 0.04624285975531225, 0.02539061103767205, 0.08114890525898627, 0.042993413554804946, 0.01635502914958183, 0.043480289243762536, 0.04048539873873515, 0.07158808199869049, 0.06081048511869966, 0.012623242500628675, 0.08358203115001803, 0.06876579110300349, 0.015554067945378202, 0.055417218470885876, 0.052616194175976905, 0.03177070235382886, 0.03755834148896318, 0.030691020168183796, 0.0187882469711645, 0.05687820176864344, 0.022651302785943114, 0.12327960421962124, 0.021591301399072813, 0.02500731618173661, 0.047871677595521175, 0.037731504172927914, 0.04038058641937472, 0.049989025874604145, 0.05262844009144653, 0.0366793743394796, 0.049669885136667764, 0.03362874327708156, 0.06622344405660707, 0.042499600939692996, 0.10283883856309038, 0.0026018553199396743, 0.07122839605736156, 0.09594796195385918, 0.024030230406130997, 0.04819205556545527, 0.034754501820932475, 0.04445576048906773, 0.017191938072022413, 0.03738102660844884, 0.03949393157757098, 0.0824667220454543, 0.0066523187448300665, 0.08459584126549383, 0.033329758312433, 0.053353262689685634, 0.028044778192716262, 0.07635413714113735, 0.0032568837172396842, 0.013178248303912342, 0.048074863265238466, 0.03225985140870175, 0.05989147838385356, 0.05920629700525634, 0.02658358422077952, 0.05083326242804047, 0.04911570862356213, 0.05415085981029177, 0.0554760884974272, 0.04112040901917123, 0.07189771175504693, 0.04258462520796926, 0.03876236740559821, 0.026317767032812682, 0.04614511076661368, 0.02803671511731321, 0.0028041705222529995, 0.026804700178364595, 0.03657835415534435, 0.15244366751322824, 0.07603058756719674, 0.05034511503312857, 0.4283932722624271, 0.21614490497496822, 15.556239735695625, 67.08001382889287, 81.20754395761799, 66.0902350948703, 42.853306185814645, 24.048988972940755, 26.69977576501908, 48.51683216710245, 97.6117354054605, 76.8067858296056, 21.190153783367528, 1.8705299184206996, 1.184798243545717, 0.3965397653800826, 0.5833294374808189, 1.1289885544007825, 1.5280831004342728, 1.6821960888562666, 2.404182721530238, 0.6599397620847148, 0.7245723326360026, 1.1419608131531747, 1.9809562833078447, 2.2238152257857786, 3.461748592315182, 1.0391096482353828, 1.0729799275436709, 0.9003057318829721, 1.8844138830900194, 1.9899014936339472, 2.3153572169042405, 5.540301780546866, 3.712588577501236, 4.9855202724856715, 3.1644898076211256, 4.64005163600368, 5.232601646454104, 2.584882147850529, 1.2748205613705421, 0.8886368031943999, 0.07866104238576467, 0.24141973905986358, 0.5552093528451458, 0.7281828130925856, 1.0808307965916972, 0.2858312962757003, 0.5935075590687414, 0.3587962987442171, 0.28946595446717355, 0.5676665553642858, 0.19916845785994686, 2.7908994930405773, 3.541992931596695, 1.0883399291384606, 2.135765615009493, 1.2163101977879003, 1.9911982046981014, 2.687766162618514, 1.1359687798446225, 1.6342208438342618, 1.623957104259922, 1.2776998262251578, 1.5050194412469866, 0.8342861744665331, 0.6767389058105407, 6.851722713439696, 51.89660126163114, 80.22759468324723, 62.51364930983513, 34.68647256974251, 31.69697342380401, 43.00653357659617, 75.96651215707102, 65.61665204263502, 29.509502880034912, 1.3169378691142606, 0.15957098183853013, 0.05935867189339573, 0.12907605528110458, 0.05666409168512591, 0.09756517356201526, 0.10830992442225257, 0.022961156623017405, 0.08144414022324548, 0.11367476920807555, 0.035688937566573584, 0.05379403520736003, 0.025221590974157857, 0.016332213135976947, 0.07887059807657235, 0.04493202586027403, 0.028745723745575356, 0.02639817370612535, 0.05965581824702602, 0.03905934905032477, 0.04589906630797252, 0.056638715022634116, 0.059654086888317144, 0.05390149053005923, 0.05688840989023448, 0.0685943176429118, 0.02907248705835833, 0.06302662043561859, 0.04161113429994833, 0.17300555933146708, 0.04951443057507277, 0.07708522250815746, 0.014313014126532983, 0.0629083211383512, 0.022695440941700534, 0.03810619011581425, 0.06223711703393248, 0.009871340721034476, 0.06214889051813272, 0.0913722949823545, 0.05570357447610267, 0.059373273529232516, 0.025226737169789213, 0.0351512702482362, 0.03287453354606706, 0.0460102946136988, 0.014848023119773117, 0.1715870556091109, 0.17030209633371524, 0.11439859972245271, 0.14175838039767358, 0.16184105357575804, 0.08578668663939161, 0.10410069262668972, 0.1466527476065582, 0.17083855706357187, 0.1986248725123944, 0.1581160582962536, 0.13439676574160977, 0.16581268320160528, 0.12655306727655474, 0.10010109313072697, 0.1723990781653312, 0.14607848809851756, 0.23858867645744355, 0.2529445512881202, 0.21237852562579418, 0.16053217703536635, 0.1922512814522751, 0.1723579698873143, 0.15615619088132537, 0.08959172278522484, 0.14041144460920366, 0.22005368474750753, 0.16424707527602875, 0.05405910162916107, 0.09721210662035212, 0.15500149719657438, 0.10953239390566465, 0.13738801732899683, 0.1704948593772227, 0.09567706560295436, 0.10453175497992385, 0.2579353383231548, 0.09142723880828389, 0.14474143484427085, 0.1141240184886321, 0.1497263689675639, 0.13237672978110854, 0.16640077825755845, 0.1250767009332776, 0.11912391430908635, 0.12838315939710987, 0.0807765941886652, 0.0848826032973105, 0.11344274415844872, 0.3298960608099738, 0.23839968256652358, 0.17237221912270592, 0.6237932210487704, 0.27215638167915807, 17.16439973923468, 76.39114010718562, 96.10847919218003, 80.52390621554467, 63.7909613117095, 54.178432264635646, 38.26387420777352, 36.679581826733006, 78.02203809061359, 86.72283572535362, 45.16306054207587, 12.106020950501966, 1.4985152934828114, 0.8528106707719065, 5.18621422590748, 4.819753064263252, 5.106252297278374, 4.5880645417398025, 5.492311091192308, 6.610450369696464, 4.612924523891942, 3.2920595042167173, 3.5668254571576274, 4.277917338955787, 6.151477165760533, 3.506368739951042, 1.6395491385652174, 1.4689522669199975, 1.7822623709517142, 3.7100762994058676, 6.623157378165953, 9.497089770532424, 5.437965181566054, 10.153100298297021, 11.43333544654231, 11.118934923602689, 11.43258725443194, 3.9157114586522503, 0.7179764381820156, 0.5770692733987686, 0.24543636869038307, 0.5989369161186681, 0.625002169080319, 0.3900592437674923, 0.594434219021951, 0.20519475062047282, 0.805145109132413, 0.30599378049373627, 0.2132266768885236, 0.4320448150317516, 0.15936323411522374, 2.7520753827787217, 3.3190093742262934, 1.3097756211796117, 2.445918211052495, 1.8798293678029891, 2.783175365578744, 9.265279654533634, 5.819036681805888, 6.751570874644864, 7.44503366370355, 7.052854011135717, 5.0703581975352385, 2.810014918927224, 0.9923695820954539, 21.28472016703698, 60.60078390182988, 76.428434002784, 53.15369344526722, 38.57739710038708, 53.95646925895445, 67.6675299675234, 91.71849189266082, 73.18362189877418, 35.90978530145461, 1.5901136686725001, 0.2966205108790629, 0.23111450816354445, 0.43735398820811705, 0.20498931648269778, 0.15587362701133375, 0.205060440085588, 0.10231209948899285, 0.21180834170551072, 0.2071689898448606, 0.10032603952793345, 0.10632764127465988, 0.11242194732110347, 0.09764865416312411, 0.17021683074774283, 0.1504911238988561, 0.13586973831538232, 0.10298355257198696, 0.147953518936711, 0.2397552445050209, 0.1654532194257744, 0.21110427625957998, 0.2196507991081284, 0.20955567548592247, 0.1354437781077239, 0.16344332646939064, 0.15964538429773625, 0.128538997002667, 0.09980025806374128, 0.20705517982282948, 0.11662420005567613, 0.12406956344362229, 0.15137597077315854, 0.13900826264533306, 0.18339178104314113, 0.15124927515224104, 0.09422938159156231, 0.1578535199646027, 0.12157700445142486, 0.2227138944210545, 0.1271103655979518, 0.10995130610441971, 0.16619932777698965, 0.13026304723274323, 0.14788541372024244, 0.16742732075433578, 0.12351461701215276], [0.03830378334368429, 0.08485819573604292, 0.019682675690179872, 0.020772188699113268, 0.04382350429471943, 0.016562937751352307, 0.04410996755224563, 0.04048920619571882, 0.103512137917982, 0.06811877622479393, 0.025832984679108186, 0.1242491650965906, 0.005862204388024346, 0.09726063829035529, 0.04592754179611803, 0.024486175295145764, 0.022911343670960878, 0.025768822900229887, 0.03672115294443023, 0.05744876873288905, 0.0705626962946788, 0.09325710110246174, 0.015335433155057893, 0.047629398459027854, 0.046917239294177106, 0.07078973411191856, 0.10199584307209139, 0.008859087679264768, 0.037215635886475924, 0.054279516616295424, 0.08105042465632001, 0.021986238876237504, 0.05174476150122862, 0.0499584130011499, 0.021999273862269138, 0.06184635856639474, 0.008978802323972267, 0.05646751735419516, 0.009353460496171348, 0.026117641884352893, 0.016772937773156072, 0.039968055733028925, 0.0073195272219187075, 0.03866382551589801, 0.03093808926942368, 0.023561543559715636, 0.04556615897003682, 0.006957720174649431, 0.04487812391392166, 0.04401429083138224, 0.05595138093696968, 0.10972401547816493, 0.03438160469334933, 0.13064823624107147, 0.8319746114073262, 0.3636385566524921, 24.504207488029238, 59.310888936442716, 66.17772748393398, 57.975345426990145, 60.64228257825298, 45.258287845119355, 13.427778309391392, 13.465768425695359, 45.28278304684547, 62.24719485928936, 60.03422106465986, 37.687764321604085, 20.469987007879443, 5.309406067094495, 0.5403123747917914, 0.7918095408428101, 2.320560976382225, 3.991390649349459, 1.755627761444738, 2.8207492203481737, 1.1259169708336554, 1.8088800652373223, 1.1330293311226753, 1.2846136165242041, 2.023291037447991, 4.13783920388068, 3.270490880935423, 1.1150410963642983, 2.455116169106576, 5.97421839352577, 3.933678855819087, 4.373078452002618, 2.1437937261596804, 2.6707094907760625, 3.5321266997245053, 0.854119761816917, 3.8572495118264234, 1.1534645119982383, 0.10838705415446913, 0.3907839935873786, 0.4314256321278311, 0.294863595477035, 0.21618143204719792, 0.507415272295475, 0.7006708796947234, 0.21554623790566, 0.23806015239848247, 1.102804527167351, 0.9241569294564186, 1.0954033823743945, 0.41496660079686876, 2.0406078114624946, 0.9715574246741111, 2.1487601822422397, 0.9438412215921187, 2.108881934996574, 3.12044428721551, 1.8241565938918822, 0.11784909037692894, 1.3610642884046802, 11.990086474726278, 34.61455983500327, 60.74812773735293, 49.497122687678186, 27.88699680759061, 24.25428975012995, 25.901106672902262, 51.76982241292154, 65.72463097110872, 55.052155909999726, 19.245323019642985, 2.119782692001712, 0.19669842185272327, 0.0721945861474641, 0.039740807241609985, 0.028516891367372968, 0.16360955222720103, 0.11330236620720356, 0.02459312691503475, 0.020681447499702056, 0.043719362302292744, 0.03833670214179062, 0.04747449931117797, 0.054848934448654615, 0.07760423175509899, 0.03806457621976733, 0.02591168297634971, 0.021578298971777963, 0.042469857576032805, 0.03766406928339312, 0.0552104743227603, 0.07823212507871852, 0.04527204632458668, 0.10017507424157474, 0.07127029340594046, 0.018877059544226336, 0.07128459626748677, 0.053428864076493256, 0.05868642207896037, 0.03347085255588735, 0.04390049996154924, 0.03487729039343615, 0.04479599162755955, 0.02202071857848956, 0.03278778941040078, 0.022009428357705477, 0.052217322837321035, 0.02721696656437651, 0.026254762046700044, 0.05762704888418798, 0.0527918198326182, 0.020319570546909686, 0.01164232628540166, 0.04668646679830648, 0.05297915131274251, 0.008499048379880768, 0.04092226420799571, 0.06365054542379034, 0.0454385478740498, 0.0624627337580727, 0.03714646580779264, 0.05152114426657077, 0.01915042269824734, 0.059619367783588756, 0.026083503091227145, 0.033749677916808475, 0.045803041017103585, 0.07182804371921286, 0.1205682888206455, 0.052465941351387775, 0.009832115104091505, 0.04147663990396165, 0.026464750577184944, 0.04869378569926466, 0.018414763786319285, 0.013790417672886003, 0.060149324426968256, 0.07338735440205182, 0.02548307210447327, 0.018929697445503647, 0.04936384067179696, 0.021328140620983416, 0.0712265421245848, 0.02722751176465423, 0.05727578991002614, 0.03345376496473628, 0.005557766313769765, 0.051179235395524776, 0.05164167287969782, 0.06062904485471307, 0.07605713251377307, 0.011205294192017568, 0.01900718723904462, 0.031106015742425958, 0.04162570912270777, 0.03367783036082983, 0.012528016814030709, 0.02894711485433002, 0.06047967686167648, 0.0271592284327433, 0.022644281590117082, 0.06389489299767921, 0.05292473608748086, 0.05490408511832357, 0.03341569422533916, 0.055894525721669204, 0.03326251111443966, 0.040061449511877956, 0.013643254097851535, 0.02925710850245049, 0.1603067326810091, 0.012423070429283525, 0.0820954605155895, 0.2223995838674807, 0.5721446150733579, 1.2886856496334076, 32.46671895827017, 72.66526499102193, 75.93525871153801, 54.53048852182204, 44.584365813962876, 22.11541541161076, 20.643857832877867, 42.716925374923214, 90.95742656338601, 94.17249141200897, 55.309518306486076, 21.039389641054218, 4.174002476276891, 2.122060363331149, 0.8722851161033878, 1.5801681313783893, 2.37291848947925, 0.5559860434262984, 0.6501633770042851, 1.0968462017274674, 1.9902716673189595, 2.2640511441615323, 1.9938013101777725, 1.0720714085525083, 1.6996079803474489, 2.321091476948031, 3.1240849821798267, 0.3716194767865443, 1.6184807400549612, 2.049180886918499, 2.2656855467827093, 3.4277036449601574, 4.840700972464777, 3.312289373528573, 3.557682167137823, 2.36423852943605, 1.4463421317838854, 1.7418436946407443, 0.21273045109645014, 0.4753176591569378, 0.30400716128849214, 1.2309614761221794, 1.3421791791915896, 1.230901414828916, 1.2752957810317318, 1.417583803976736, 1.6567639309552409, 2.304569963485964, 2.3695955064988907, 2.573016242634866, 1.7693971193605855, 2.4314887917810872, 1.231610383237562, 0.3715925717786435, 0.9972919728006087, 1.4181796365207242, 0.9307378085870898, 0.8329422110992094, 0.3084618706376322, 1.28034865183215, 5.0919910496281044, 15.997404398456698, 54.176671120428274, 81.92318824029739, 52.89115744252359, 33.084859002021055, 20.89518370166902, 42.61165288186843, 71.33082758995795, 70.0190693332303, 28.206777841814105, 4.102868577164989, 0.18879740468917355, 0.13652075983343587, 0.1017124594880208, 0.019499268495447693, 0.10708140284423867, 0.07911124161534733, 0.05654943513593847, 0.0639871682881588, 0.053042755762655894, 0.06038165208132518, 0.03821054661285974, 0.02645135361460909, 0.01749760140815089, 0.06865474665837903, 0.09120285165526214, 0.003981614145525401, 0.027463078055711045, 0.03778771587437199, 0.027086909732691226, 0.02876422476894673, 0.07962566199562243, 0.10052897621907535, 0.07538713499783509, 0.008903666335578648, 0.05121642130336935, 0.10081002323497688, 0.08008125448419202, 0.018029959737173012, 0.0944569786529868, 0.06650738688486238, 0.04720766322627183, 0.005011754861522106, 0.013816891756329327, 0.03534364641734189, 0.009253106808530228, 0.07467197659876078, 0.02951006115894885, 0.0661300962430335, 0.026534374562963366, 0.015454032184225659, 0.06739525214558648, 0.09431949651409542, 0.01477199463894771, 0.020251304451977054, 0.03752228173036729, 0.07953766147576033, 0.06295234438091998, 0.05545410560443998, 0.13223952343386988, 0.23995344677279073, 0.11804196067274579, 0.20453533277876917, 0.14609914182895614, 0.22694915022340514, 0.11997935106797565, 0.13701553005845318, 0.29401814084379907, 0.1393892841353532, 0.12512828929409867, 0.22882467135787013, 0.1431619760490233, 0.15296135908894, 0.14320006594061852, 0.13297175027189717, 0.1614289289160121, 0.1366540438105022, 0.10446769470769553, 0.1226934090617203, 0.17421070756691118, 0.19232998932561568, 0.16427699867035114, 0.07858785034547891, 0.12156794929215986, 0.10630174750281919, 0.1956306791473781, 0.10843993720388222, 0.1248943949899366, 0.09035283879887673, 0.16641547182394614, 0.15058282462339248, 0.08476376007761686, 0.0972622853793925, 0.09588727246849768, 0.13809792036491056, 0.06692548703041769, 0.10691908413484212, 0.12384928252187469, 0.12154788544942295, 0.08664562442009488, 0.21805217279301536, 0.10349765119533386, 0.18934934039510068, 0.10067494661216775, 0.194776353215979, 0.11072893897371908, 0.14931061305105686, 0.14741737996378254, 0.1298738286019333, 0.27761475813965647, 0.2762422043709986, 0.14425976472275873, 0.23228749602792725, 1.1975846800111956, 1.1476203030155552, 37.11907948217085, 86.58918488410212, 89.115199119814, 71.84261845004174, 79.1846364544284, 66.21813574144917, 23.911241216044274, 24.95717456263881, 62.34731335793773, 75.63936295047884, 77.52339501534739, 49.21002872528569, 27.24875657789169, 8.14501396109981, 0.6919013180078999, 1.4430352060064193, 3.778868788673032, 6.766590120330934, 3.8292494272032096, 7.340103397446295, 6.5504018241359345, 6.930488319166246, 6.727368870089132, 7.653673848798198, 8.096512383030307, 11.382574092957283, 22.760462914743734, 16.18016625604322, 14.615873059918805, 19.62380820705045, 18.36948129438585, 18.960823705119473, 14.652241276156518, 15.050252022281772, 18.128828194833574, 8.928845217151027, 10.169181035410974, 3.2580692248959697, 0.20472659428994502, 0.5308207905580921, 1.218059820032889, 0.8170397579669954, 1.2674894063703477, 1.9699954650094433, 3.180304313859632, 3.9071670655281316, 4.871751925637645, 7.7233223953554715, 10.136142911449557, 10.021340039468582, 6.07160545164539, 8.742960172314799, 6.543179269759886, 6.429389840172184, 4.909663594538166, 5.1214343213265945, 6.386001071622295, 3.324757607713823, 0.22457423169286023, 1.7531111932569936, 17.547991852606497, 46.976956705893244, 77.24448311713435, 64.88875427553731, 42.9266623527773, 37.40705597785212, 37.87193136830484, 65.94145959423435, 80.76100564772084, 79.38685032629198, 33.98852994365077, 6.124297591947741, 0.1682856916299751, 0.2769007335507101, 0.20308597103482295, 0.15493564427860324, 0.3954923086829724, 0.24940839668195097, 0.2233155339115089, 0.1914556225341174, 0.15364167580921806, 0.1476020224752926, 0.2693601913990513, 0.1512020534925884, 0.17568421640223073, 0.20512054734412702, 0.1446909036847853, 0.18128077980251084, 0.09822092950344087, 0.11352601791581801, 0.1615532803078813, 0.17382202519764825, 0.2404706327304725, 0.24451629709332223, 0.139083921488735, 0.1889817867307894, 0.11180146206771174, 0.20727582846678075, 0.20274294750584712, 0.11423284127827614, 0.13333080036024894, 0.19614601117228309, 0.19485115404090575, 0.08821519302023996, 0.08495921208973854, 0.1413497184553454, 0.07184459887925657, 0.16082721281676524, 0.10243848101386141, 0.13805682740865216, 0.0799546814373424, 0.1330326236183605, 0.19688422881787826, 0.16915935362058301, 0.14251083195690187, 0.09030799201178936, 0.22403747984959235, 0.16034145178573747, 0.1639035461290229, 0.16578323478179594], [0.04211654931667351, 0.0461521472841982, 0.03891017257926926, 0.05898350331511709, 0.010206900638407998, 0.04073238548552317, 0.0649868938771467, 0.03763483153776296, 0.05097554410777746, 0.027986088196837136, 0.04576027415873063, 0.053130748621638746, 0.04657330412057139, 0.03367203490568265, 0.021316149429748618, 0.05070400807345587, 0.009801239845523191, 0.042729101729609316, 0.032271277610092394, 0.08317304745076165, 0.0447383166981801, 0.04627443406911147, 0.02661646471448964, 0.039992942099249175, 0.0740522344506556, 0.06157397600491682, 0.07796975528641094, 0.032322019443757115, 0.024353485036220764, 0.023511968094915636, 0.060947074765159245, 0.019264853251497113, 0.13536928371796686, 0.0006612043826833308, 0.05000466172913871, 0.01741658952537804, 0.05042296105755433, 0.022799513986214034, 0.047533959225420995, 0.05618366262605114, 0.05823041207247204, 0.052060788091752803, 0.046594432825523044, 0.04192999541579236, 0.04993801974060555, 0.009788749739527702, 0.044499481126906416, 0.02036645129743603, 0.02938790652420252, 0.06828926909234255, 0.029368547482355952, 0.060476846166796265, 0.24271360027693936, 0.06815629155044595, 0.06968000978832284, 0.12983823615697124, 0.5883140958124592, 3.6686261623136462, 38.305223834130075, 64.11597282655778, 56.56616726229268, 52.241797293386156, 56.76464703775222, 36.42128198377548, 22.25607748954527, 10.348878541300374, 29.228539582221742, 51.676717112141276, 44.322704499767674, 54.70681082817816, 61.6923402970837, 51.56737319884762, 43.661063409620716, 28.141807702279863, 15.66217608990208, 6.899250563113921, 1.6215139579388405, 0.34360998460362036, 0.05102577649297253, 0.626519329605564, 0.5192471632073002, 0.7022765999840153, 3.7902426815802053, 3.856017887592316, 1.1196774604820436, 1.9602670063895566, 1.2775182940306202, 0.9470204251908487, 2.3448858001539787, 0.1847976596365052, 0.8558255638326369, 1.472730489988481, 0.3245952533137414, 1.1438130298929832, 1.1348985856579197, 2.641768527607764, 1.222565397620201, 0.7508975039086034, 0.8924711038989406, 0.10467677542399015, 3.7799704843951814, 3.0385238701297395, 3.773255631808312, 1.9145476145129052, 2.8259674435661686, 4.133644719277659, 2.6852477558197516, 0.9426756034935675, 1.5060962544333552, 0.3378067766466449, 0.536944039406315, 3.9801822314339304, 12.509787774855091, 28.48678408130523, 45.99799586880592, 63.43497483961044, 46.68151201740388, 91.78832577120875, 51.165514607583326, 15.164220410008586, 40.679218769073486, 60.533185774280184, 65.65361645913893, 62.5849776114187, 34.46002237258419, 5.503735974911721, 0.05980834635275026, 0.09793254336522472, 0.02817235481474669, 0.12048206562476775, 0.06955306901926957, 0.028971415163288196, 0.034133982093584155, 0.030994894689009077, 0.06665521887161079, 0.013341679756018906, 0.040355891575135534, 0.018726588384578788, 0.052897911518812187, 0.052665955417098544, 0.023176553734247724, 0.001709660345729771, 0.04177632966950055, 0.06714331647080761, 0.07417640198142299, 0.024223522050306204, 0.07401954547892656, 0.03238619462917409, 0.0789036471096258, 0.04001628862874162, 0.022932742421905843, 0.044911184438293984, 0.035027807518359155, 0.0540265160793018, 0.015813868470309723, 0.05670080644889705, 0.043889418499724525, 0.009611117890134696, 0.04503442500267298, 0.08368611185541076, 0.0163565096144955, 0.05841259544174518, 0.0500130350701511, 0.04574024478995031, 0.06148409090876099, 0.06866181764992015, 0.03676668921064946, 0.04032414489155335, 0.025003715568492492, 0.02210823646295936, 0.022609960851109317, 0.036562994092462525, 0.027387930575998563, 0.0389867622194992, 0.008528721838017866, 0.11722415415269714, 0.07452832745207895, 0.054557683141601664, 0.05813777289022842, 0.03245114739383421, 0.032755406873841444, 0.016410570524092165, 0.014815598448377945, 0.007285202652471321, 0.0839080092226786, 0.04024223094024966, 0.027066991446659933, 0.06991326823950776, 0.07134531639636525, 0.10073084038712325, 0.10530774076018604, 0.020849699560072155, 0.07985255425615657, 0.07162714482194955, 0.028957006964652292, 0.047660543763589476, 0.03150968853714726, 0.013223937787716428, 0.04248413362450177, 0.018023168367724267, 0.015882103921725385, 0.07311923895031214, 0.04273506572409984, 0.07037843682713087, 0.037852366034302025, 0.059150702004591306, 0.030879054533978625, 0.02363651675442534, 0.09822243103577245, 0.0725335264278035, 0.04217127863798411, 0.02497587401810433, 0.02600583709746359, 0.03937334933828923, 0.03150622198928989, 0.021801851088962248, 0.05838213961631541, 0.057354436496332775, 0.031490919383002386, 0.0344973759004666, 0.036785814595679124, 0.05266105628482277, 0.08760459796195069, 0.09138944769097913, 0.037391154290807825, 0.08157963819441297, 0.044414257675769835, 0.052922441654147646, 0.32328199475042285, 0.0593611540182704, 0.06651700894919134, 0.2247946505104342, 0.41184889873669994, 5.938914120197297, 50.80805724666965, 78.92874886912685, 66.56237079251197, 58.88835945437032, 31.109176835706158, 10.816358385547515, 19.39861709071744, 24.631853180546916, 64.04970830486667, 95.23353176732218, 88.22392679029896, 81.8436582626835, 59.609063594572014, 42.53377814446726, 27.16853822431257, 5.269031149725761, 2.5211632444012553, 1.5302905368228115, 1.7381149914956864, 0.7997983057172069, 0.2482280084082196, 0.3934350255275927, 0.671609977801, 0.46950011003401976, 0.7624913559805963, 0.9152326792959244, 0.730512946123077, 1.4944926577229656, 0.9020226881388695, 1.7994680928607143, 2.2586287125464413, 1.4361633360385897, 1.4354342654828103, 1.092109449448124, 0.9228562960220922, 1.1837502352653013, 0.9670419185873002, 0.755740282756667, 0.21759307162175257, 1.431667686950776, 1.4089623117639174, 0.8130421886040319, 0.621207521086739, 1.3120710657488917, 0.8401050106171639, 1.7632877826690676, 2.082114700348147, 1.9643564450163997, 0.7362777271097707, 1.1487152571639707, 0.9475756244313334, 0.47185503366974096, 0.6475425595718046, 1.7390259619682067, 2.3592296627260025, 12.35705558330782, 28.587485051924183, 62.0203955711857, 67.77294758827456, 108.85280901385893, 66.6038537794544, 17.135919409413493, 21.896490281628026, 45.98618561221708, 67.18646695536953, 78.4296743331417, 46.22426171456614, 8.66847534333506, 0.20075441308079228, 0.10442630297714665, 0.07100217029332154, 0.09124637311024052, 0.010933794546872379, 0.03928047649922871, 0.03299165689837068, 0.058115958536584536, 0.03047492017128295, 0.18207361951710718, 0.019125769988843994, 0.14273250715867167, 0.12478110590769399, 0.0921911127384632, 0.008642109554080714, 0.047537736038887696, 0.0755178602412343, 0.10632902789380282, 0.10775523846067729, 0.03486319054518977, 0.057436308312800624, 0.055728242507264505, 0.03184970134058066, 0.04600351856600854, 0.06192855597023041, 0.028139882262856252, 0.057893681955794175, 0.022384280924715345, 0.030930993380025033, 0.1043263744683035, 0.09940590664383867, 0.02003843543089686, 0.04617907527473666, 0.03570244752711827, 0.03580573533150939, 0.06468936064911467, 0.06923895764855609, 0.01213967343867426, 0.02867163538241819, 0.09435772430151702, 0.04135528008543676, 0.04113459696752891, 0.03508498449058783, 0.021872331177996054, 0.03927589529344151, 0.031808744364928816, 0.03692967824697976, 0.05142455207063787, 0.017596681474617893, 0.06966831162571907, 0.2374043504917814, 0.30216536334445404, 0.17258874621362458, 0.17626380788222437, 0.13533957482826325, 0.1896386918041014, 0.22166274518014925, 0.17550453814046998, 0.18346000883367755, 0.11959193274378778, 0.14577151666725838, 0.11654312497064953, 0.12957430354529811, 0.12986898692625184, 0.2145293327949701, 0.09782877675588093, 0.0826223221637549, 0.2268536956680398, 0.13422136225046652, 0.2524096074123537, 0.12366818699745402, 0.16430808651831844, 0.09081580871415716, 0.10976543019135153, 0.12639768932375217, 0.15376519982612905, 0.14430775247033567, 0.22355358807309983, 0.1713497981789612, 0.239754080051376, 0.1899394732449324, 0.10065672138044912, 0.20270242145465267, 0.12679604738349878, 0.16430787201369965, 0.12739197185803808, 0.1318498298285469, 0.13168833849410858, 0.15505722243218653, 0.18673367107347136, 0.14407909054669643, 0.23132818540738476, 0.20953707487112094, 0.15706662509229877, 0.19021552536756764, 0.07166394768583198, 0.15747642084475488, 0.13234751118767646, 0.1366159998841824, 0.3054303075036695, 0.28817399314815, 0.1516771046144347, 0.5113072747424726, 0.24529831964642773, 0.26497167204656913, 0.25173788619858606, 0.6438715275256865, 6.622940176917661, 60.67664254096247, 95.29866664640366, 80.99376693848642, 69.95496211513397, 78.46660737068423, 58.55849204524871, 38.279512697650546, 19.520914631505168, 46.41943885434059, 70.57516728678058, 62.203276080469934, 75.1987160405805, 79.76397052887948, 67.66411750547348, 57.933662399168945, 37.79996372038318, 19.902451422906694, 9.520993674955061, 2.5435004070881875, 0.5668072498613789, 0.26647577843358444, 1.1678061682370402, 0.945393254439677, 0.9424893521974165, 5.94655244581161, 7.557860641710221, 3.1420200197927417, 5.718582330211516, 3.9214739107316543, 5.451365959259772, 10.181050127552403, 8.232470558535669, 8.126520476033612, 9.925117434993867, 9.801417646869536, 9.983063590142036, 8.542734942128583, 9.310567340543194, 6.93604729829296, 4.271514559945753, 7.06181368520183, 5.625866814967125, 9.587275847311943, 11.696239171489594, 10.366087940431411, 7.083267579155584, 6.446604142265936, 9.065687887130245, 5.9622350623530735, 3.3523975697255906, 3.2249730008263744, 1.0685683642664263, 0.8834350049015015, 4.447662320829207, 16.427239294975035, 37.49775294334658, 57.88031816482545, 79.53196233318698, 64.73386379980272, 100.44913091967183, 67.42812418168592, 24.59531826357688, 61.91924156681184, 75.4152387188327, 87.8870971741215, 87.54600001919655, 54.747313222577496, 10.723247201211992, 0.21582279564632526, 0.29918059286090637, 0.17254808226660376, 0.17402471674065437, 0.22191805164179496, 0.15069865711754368, 0.17729988051277978, 0.20715973550273528, 0.1494830594428124, 0.19577330939712065, 0.19709672628631517, 0.2666550123643491, 0.24856620558327247, 0.166690313527661, 0.13323775132096585, 0.1527273498715893, 0.1712176939772983, 0.15435118047941118, 0.2037898985849273, 0.10612308813799774, 0.13158185227263358, 0.18637665877899817, 0.12607336600100802, 0.13119378277371008, 0.20980934251941022, 0.1368830581345866, 0.1540050925987382, 0.09423341121404402, 0.06925036469774862, 0.1882537427328287, 0.24172726207442824, 0.09442506343006127, 0.1880290644663957, 0.2034733816981316, 0.2420051987733572, 0.12120253301315731, 0.12825313129372176, 0.15856719215310391, 0.18538359432451187, 0.2272644566912805, 0.36570812785817736, 0.11759591363971272, 0.11525972851461942, 0.138829963341836, 0.15256290143776327, 0.14650351367890835, 0.09143784146515593, 0.2036014562773128, 0.14774713484990984, 0.24472514798323958], [0.031004455466304096, 0.04501518087401506, 0.03144487558353332, 0.016977693923118136, 0.01766915530747464, 0.04313396770627268, 0.07129079391879421, 0.006408610854357962, 0.04129122747408767, 0.08913038463722314, 0.04199247371645705, 0.11621070409854574, 0.08278461022963447, 0.08398771301032075, 0.08417173499061216, 0.04371161715337827, 0.11431816049040326, 0.03717481106099102, 0.05249804043541512, 0.025746150528110807, 0.024245164034167127, 0.043608045896455165, 0.06531242761881122, 0.03543307569118277, 0.06011087830448824, 0.010103077530079793, 0.06334936178679909, 0.04886414450142653, 0.055959072459729454, 0.012509795412751696, 0.08549935770251098, 0.057303939810803825, 0.04686417621410182, 0.039825701274939125, 0.06533271362704617, 0.023566243509131096, 0.02965160356383891, 0.04508561116733378, 0.013704567944871323, 0.05941926178732707, 0.0945063760023444, 0.08750102287458797, 0.08094849665799449, 0.05641518971852719, 0.04996811550471091, 0.025805150789599267, 0.035643148491339344, 0.01046797382690373, 0.08862153371615757, 0.06865732071380462, 0.12572140222595585, 0.010875120830361643, 0.11044901810706624, 0.02850028258117457, 0.1695638786881201, 0.04921914581509848, 0.02630620676603529, 0.5615605281726007, 0.085605813280469, 9.347504300455894, 43.78168021478961, 64.42888382942446, 58.37033202571254, 61.48987147115893, 68.13756327475271, 70.2387926655431, 39.91921247974519, 19.79971670335339, 10.786853336518812, 18.74628378498939, 21.483829482909172, 30.830943507532922, 22.689348382334558, 43.33886031181582, 54.84403494865664, 64.38218801252305, 67.37347772044521, 66.32375732544931, 54.118584740546446, 51.53635509552495, 36.31087118579496, 30.345911056764667, 26.533141712988577, 18.722310258496194, 10.851616571026465, 6.869808762304245, 3.063110512110495, 1.3891673352449172, 0.4671717543275126, 0.10045275047060945, 0.2458739427909736, 0.5011392655151506, 0.3753018775774587, 0.2659616415058413, 0.6990053432603037, 0.6215667243926757, 0.21418637055302822, 0.37200959940110484, 0.08138122908290356, 0.07114516060438848, 0.6197370612813581, 0.9906750568939794, 1.1136735374889066, 1.7471505389098199, 5.558580025549858, 8.297434814514654, 14.907124734693959, 20.08908171807566, 34.78515548090781, 49.101163341153054, 56.813182446264456, 56.772589837351155, 47.81230388149139, 47.27563342740459, 40.589486706641416, 35.47629671712076, 31.854250661788452, 29.366146133792018, 36.191662511517926, 70.8105722550423, 66.71717889847295, 49.68027384050431, 34.49724958788964, 10.413914380535003, 0.2392117204445024, 0.20848417894974833, 0.035085934439613935, 0.025153123781145103, 0.03261217141463872, 0.0407099122962644, 0.0283952136223595, 0.010958808275210041, 0.09871941525489093, 0.006028393277853367, 0.020506405985103022, 0.03219845329201029, 0.033338656423673514, 0.016190812457352877, 0.07317831199015341, 0.03664354057682138, 0.03807764567975556, 0.03377125095275622, 0.0172303612118647, 0.04075047282141544, 0.02488129280297266, 0.1054336779540585, 0.033584834947701425, 0.04237945920096771, 0.037324799585246274, 0.03800605093279193, 0.033551104096395355, 0.014393718616526215, 0.1433918637133414, 0.06634414120907746, 0.060044454651013504, 0.1866317200925081, 0.11587436851714888, 0.0031455881394175517, 0.13389030501486796, 0.034445879470196464, 0.03696003831141899, 0.024238066229548667, 0.03653111717393322, 0.06527115080145098, 0.01989061302024751, 0.012996617475554589, 0.016897275758486603, 0.039707455603826436, 0.11984808956302943, 0.020323475680103707, 0.05766817248396336, 0.092854636811441, 0.011741190889639961, 0.017491453552558538, 0.03906758066507117, 0.04807864390914479, 0.026928275906210466, 0.051004172813507824, 0.017491899798774434, 0.024610630108884746, 0.07882944383328, 0.020974518265575174, 0.040551328265498725, 0.03481005085632205, 0.053963103151369485, 0.07360737485390517, 0.07567029641640764, 0.03409840497038057, 0.09275756581055541, 0.03272149599187317, 0.03436796832829714, 0.03198194918372939, 0.11541771882724379, 0.029803183635756857, 0.021322954205736037, 0.06976284687557528, 0.038129119127387964, 0.015750991803924405, 0.03506873959615346, 0.03721531412954773, 0.06579004513520388, 0.023550322286844737, 0.0304717619738151, 0.07235970873866351, 0.04977931313577199, 0.02906407158251011, 0.033099974069984696, 0.03210291255175347, 0.031139591460927363, 0.05237799445768038, 0.025060316059558142, 0.019902947035828428, 0.043643151875585325, 0.020938362745988755, 0.03767977025540125, 0.008980035725530357, 0.055278227138783664, 0.04166952552153699, 0.09833264044455944, 0.0700727754062222, 0.03023822390053782, 0.06794176394900969, 0.03567232111949594, 0.024221804098136002, 0.07305389165037102, 0.0927208548772239, 0.04049296385698742, 0.04092387682307632, 0.11150100238380894, 0.05068037809143144, 0.1367171694554629, 0.07185739254759205, 0.030223643332118952, 0.7513248583962842, 0.06068817918158828, 15.130318384016714, 58.36785701013381, 74.05980094786614, 66.82068240258002, 59.45863677609352, 46.66682274110856, 25.412926520070723, 26.03279829025269, 23.823946906674294, 15.419712816515277, 34.426442961538996, 53.48157221271146, 72.16029121029761, 68.35092452264601, 90.01851312575802, 90.99671302303192, 74.5502305799915, 68.55166358332481, 53.17572147615495, 35.88043812782534, 20.2310577900179, 18.750929832458496, 13.667041909310127, 2.8595218495015176, 4.386384112219657, 1.8150754489244956, 3.0154500372948188, 2.357098835129892, 1.7778638005256655, 0.87454623993366, 0.2475829164107, 0.49232882537668754, 0.8003153844225792, 0.40208762091013694, 0.3845728591324822, 0.22156816396501758, 0.3414623337166925, 0.29225117436820464, 0.7590016722679139, 0.27024995655782763, 0.3011061088933099, 0.4378112814118786, 0.8218659280288605, 0.9288958267819498, 1.5079434456363803, 3.7131798748047125, 2.662712758587253, 1.8326218041681477, 9.167799930418692, 13.19250964349316, 24.39388494337759, 36.82654519234934, 64.29624495967742, 74.97403483236991, 82.3890010772213, 68.73312811697684, 52.45376217749811, 30.882371664047245, 39.420569404479, 37.3652042881135, 50.22327500004923, 74.67252223722397, 68.99073370041387, 49.62799256847751, 16.476376787308727, 0.7437797503605966, 0.047617550909278855, 0.019768194085167303, 0.025797579925687566, 0.13797104088289125, 0.08106401505609674, 0.03546746537810372, 0.04074666153399214, 0.06778797945908963, 0.03170480155536244, 0.04719479294914392, 0.03344610408549348, 0.055775445014719045, 0.029915254638199846, 0.04138409648270857, 0.028292490807812543, 0.018014344950056365, 0.0827210785580739, 0.06405799311675853, 0.0193514020347427, 0.05912111951939522, 0.016452916034106767, 0.05608992410763618, 0.021167013178309126, 0.0512795009830546, 0.03905885492361361, 0.032386822821272, 0.030105493421996796, 0.12113939204643812, 0.07330517615041426, 0.058918960407496467, 0.09641510704832693, 0.047271455367726666, 0.010438195031677044, 0.06640895990835083, 0.03408909317166094, 0.025628935245256272, 0.04843752545815322, 0.025205520364726265, 0.06005131113793581, 0.01787918597279537, 0.040169632618105224, 0.05708278937926216, 0.04096357549931254, 0.04521483104796179, 0.02839378678360053, 0.03546530117971763, 0.05702638232539739, 0.03722692036160058, 0.0465933334893517, 0.017003388512098504, 0.0482838022552671, 0.1227300816906556, 0.17231094741052197, 0.16780035960818493, 0.09853482636953555, 0.2105953334079635, 0.17305691786591085, 0.2035397095906158, 0.14802022987315733, 0.17747059554582645, 0.18987311470893123, 0.21179668184730316, 0.1689957325617152, 0.1811418574183218, 0.17546529911698835, 0.2465584576730767, 0.10037659367005672, 0.3290631087316621, 0.2277451768637665, 0.1653640927566636, 0.19753126667872553, 0.1464127629033981, 0.1729337922147205, 0.19588509694703166, 0.12281432837968874, 0.17468010495987632, 0.057434718680357745, 0.11673449373413479, 0.1960416699969961, 0.1635891283231397, 0.08797510106477045, 0.10458415539394464, 0.15040331490097508, 0.12365599087769948, 0.16882625859110587, 0.2120036481609268, 0.13416087194796533, 0.08874085957124349, 0.18359078004235224, 0.13452064215896592, 0.12832178809349576, 0.23307111204391529, 0.10941843832692794, 0.19736714000182767, 0.10583358351141216, 0.12629969901735746, 0.3089485509741691, 0.1241307355643761, 0.1943777270254589, 0.20787873966318948, 0.2681752678848082, 0.40722025678523127, 0.16970775000029997, 0.17773719414347605, 0.1532392804661105, 0.5976229221109421, 0.2539325442405478, 0.13699913577687356, 0.8118153447585722, 0.154571216253023, 18.31856108480884, 74.79839894079393, 97.68211057109218, 80.41437795085292, 82.22872518724012, 87.79008911501977, 96.45874684856784, 61.43665275266094, 34.83632672217585, 21.833106740828484, 33.13879551426057, 33.9322910001201, 41.65001715383222, 33.6368384668904, 58.12263042696061, 69.64577736393099, 83.26825526452835, 85.40724923533779, 82.21788375608384, 69.30524503031086, 67.0657128672446, 50.44943494181479, 43.694776181251775, 36.49420276764901, 27.80431912791345, 16.780123172267793, 11.971712131654064, 4.909922961265811, 2.537751928452523, 0.7197029552152081, 0.24655402968487433, 0.3436821194425706, 1.1592650846127541, 0.6591745321789096, 0.5980163848688526, 1.1357579524478605, 0.772543655287835, 0.5901294790448681, 0.5202639763874393, 0.18560597432717202, 0.23219026414857757, 0.7118339452051348, 1.2225790033417365, 1.15007484872495, 2.2943396866321564, 6.726340228511441, 10.377975663831158, 18.9428259095838, 28.274260259443714, 43.361782643102835, 62.52329441808886, 75.5214172793973, 82.00218477556783, 73.40933861271029, 73.02772337390532, 59.511753512967026, 52.95172276035432, 43.82934877949376, 41.52443855039535, 47.5563221593057, 93.4719325650123, 89.72952073620212, 76.14080659804806, 57.048642327708585, 18.479872480515514, 0.6173344869767466, 0.48215772115415145, 0.10292533755062089, 0.31438088044524193, 0.22627313891726158, 0.21068697284546592, 0.23662192957295528, 0.11950432292876706, 0.2871160563682356, 0.16017046096103807, 0.1676019275140378, 0.2378011840365587, 0.25420525621983314, 0.19789295210953683, 0.228651229051813, 0.11349005008777303, 0.09149322962208141, 0.17255298522931917, 0.17641791412907262, 0.10563299104931856, 0.1764720459018023, 0.17545275059678864, 0.11187041764177623, 0.0995242136019853, 0.12717663220340206, 0.22017696361628272, 0.19883139449502193, 0.0738151838642455, 0.14998564376465737, 0.18793166404770267, 0.18283627536748687, 0.5215844668207631, 0.19229424366306877, 0.07873376711241661, 0.25415034303742073, 0.14859700214958962, 0.1259078297223295, 0.269049619354548, 0.10230728079594913, 0.23187644389127535, 0.10995665339813118, 0.04421527399831722, 0.22690775083197703, 0.1599168398928258, 0.1087300853443242, 0.0851651671673021, 0.10694185226795175, 0.17467317952504083, 0.15936052216397179, 0.19370052062215345, 0.14645244625787582, 0.1102348888713506], [0.022639612284218593, 0.04176841981168236, 0.00721313915545902, 0.05674729649458201, 0.05783478894661512, 0.049226086571692466, 0.06568515237661139, 0.03993948448389288, 0.05104774023376165, 0.05016511884487925, 0.056061103879924745, 0.08500598175751586, 0.07529675960540771, 0.03145778608027726, 0.008937463261968186, 0.053389831896751165, 0.03810011503857471, 0.04674054877532106, 0.05791124452145831, 0.05837332577474656, 0.04314841229408499, 0.04570495111927871, 0.020693507638850042, 0.040315959242082415, 0.034343947641431324, 0.06319332882882127, 0.042766992438344226, 0.06131020044126819, 0.017521013055116903, 0.03581803487313371, 0.009862194588828472, 0.02714160458004523, 0.0682617512141024, 0.018397821751873822, 0.059929629562482725, 0.020245106800669627, 0.05792264007933198, 0.07334701221195922, 0.003844721176128294, 0.03327561504838448, 0.04458947347537164, 0.01961039912496363, 0.03118749876927224, 0.023309305280206666, 0.04661490652529944, 0.007585078673136811, 0.029208419784422845, 0.017585452540867755, 0.03203922574738822, 0.07698058255858, 0.026579305619722413, 0.020163058783979188, 0.1665680612167043, 0.00590627886272306, 0.11368426869833663, 0.05787414288328541, 0.10268935182642552, 0.06881747139437545, 0.024656131901147387, 0.6166214736238603, 0.8614379239659157, 20.120252793835057, 50.699878277317175, 71.28074676759782, 60.413184781228345, 61.27880480981643, 67.68982471958284, 60.61708134989585, 73.1056373350082, 56.77131506704516, 33.47862574361986, 41.84934416124898, 39.674138869008715, 19.76278562699595, 32.34536474750888, 35.12160854954874, 12.20045691536319, 16.412426464019283, 34.10291018024568, 45.57174405743999, 46.15709112536523, 42.8740123779543, 39.9734196355266, 49.88564914272678, 48.31476734530542, 47.482205052529615, 48.26363925010928, 45.53992971297234, 38.41135140388243, 40.49591856618082, 36.10861024548931, 32.87948762216876, 31.92798337628765, 32.768117804681104, 36.750164877983835, 41.45296904348558, 39.45996176811957, 40.856431453458725, 42.929400167157574, 47.14390454753753, 36.432735304678644, 47.26049700090962, 56.46773146044824, 61.97071875295332, 53.24475519118771, 56.029190863332445, 54.602993534457305, 56.0456177496141, 65.09182714646863, 61.43679395798714, 61.839633141794515, 41.77330509308846, 28.784697901818063, 34.360425549168745, 37.64273943439607, 47.868201578817065, 62.41728451944167, 67.96177048836985, 71.32762693589734, 57.267604720207956, 26.23381583921371, 6.223192311102345, 0.4188874694368532, 0.2007154345272049, 0.08557927599477191, 0.15526855544697854, 0.1009947270335209, 0.021195272246616024, 0.014582595679037755, 0.04113054053196984, 0.027512990599197727, 0.01749336877236924, 0.04323125321177706, 0.05907542620515151, 0.03960649287628551, 0.013334806989728203, 0.012578196530680985, 0.012445293682356997, 0.05248907337626142, 0.06241624371238774, 0.05183637029521408, 0.0500869165895687, 0.049637115725706664, 0.06328315646838277, 0.06120630742741689, 0.05109798027983597, 0.038321491466054035, 0.02592052554621572, 0.009877845765121523, 0.006160156570389988, 0.03938372216878399, 0.02692337294349507, 0.05178821400829381, 0.06300785894235296, 0.08714240179547379, 0.05674571835345799, 0.07063162888610555, 0.03911549180385567, 0.03485383278119468, 0.015256667825122996, 0.016984694051526247, 0.023830208679540985, 0.015860320211598472, 0.06007188059870274, 0.02996357563402384, 0.08977509359078062, 0.06275561300196475, 0.05244354477092143, 0.03282446203933608, 0.07232677461879869, 0.05451542956213798, 0.06010553484121638, 0.021633564554635557, 0.04520056266037207, 0.06535888319053958, 0.005122984603663246, 0.019544494496057593, 0.08135838434100151, 0.048801731318235404, 0.08916609199537386, 0.01585652041549404, 0.030645983774335157, 0.0323991185324567, 0.04287075138680878, 0.038704738441494205, 0.020724292882087252, 0.05847698513178095, 0.0545232551502845, 0.04375463682076624, 0.04069500422525791, 0.032722560854087916, 0.07417847807969778, 0.09409861804376687, 0.09375928705858608, 0.082569508062255, 0.019170189681913585, 0.04645059598729976, 0.023793447950494387, 0.05210350132397106, 0.056777894046277776, 0.03859425324105448, 0.07056812019718271, 0.046288725439338915, 0.040593547371005824, 0.03444524361721931, 0.05297014594919259, 0.04875596139519926, 0.031063392525538806, 0.06786856424784468, 0.011644927153904593, 0.09012941691663959, 0.0284731017816211, 0.028739692718391458, 0.022172022858754765, 0.02487487681660681, 0.06539867379732671, 0.0650748024664579, 0.05466640250937593, 0.048535780064881816, 0.04774552206659029, 0.04293109230216473, 0.03732587976921951, 0.03366477239216047, 0.040905234073438955, 0.08709811425257115, 0.07205316631664192, 0.028258445860457518, 0.03471166218420671, 0.07553481376699864, 0.11725004026365858, 0.08999035663662419, 0.03191374246061089, 0.10548474537509103, 0.12001070704671646, 0.05383969787808676, 0.6795604995662167, 1.0353489532586069, 28.992510957102624, 68.00712877704252, 83.60427687245031, 73.06738638108777, 73.00384398429625, 66.340207745952, 38.085724076917096, 29.005790141321, 27.53240473808781, 14.999994693263886, 25.959334258110296, 18.43139590755586, 24.291513043065226, 39.489563895810036, 56.1945423003166, 43.785182891353486, 52.08429844148698, 68.12810251789709, 89.54179609975508, 79.7892149033085, 75.20696870742306, 79.94498791233187, 66.91622349523729, 61.74565315246583, 68.38500991944345, 54.88762424838159, 41.80549990746283, 33.577218440271196, 23.70012748625971, 23.295980191999867, 18.74962172200603, 15.224326810529156, 17.228877621312296, 11.498815494198954, 14.86247149205977, 17.14500557991766, 28.108136115535615, 31.50741704048649, 33.01540559337985, 28.372943170609016, 41.60525506542575, 47.306969242711226, 57.72299581958402, 68.16183490137901, 70.53337835496473, 75.57791509935933, 69.9557936576105, 89.57603054661905, 85.79612085896154, 80.50085836841215, 56.54943050876741, 36.329208266350534, 27.55722745772331, 29.416448570066883, 38.62504605324038, 53.04576550760577, 59.803499406383885, 74.23637820828345, 72.96565578829858, 40.80318920073971, 12.5189180720237, 1.5101449984696604, 0.3266553863161995, 0.10748378286558775, 0.09859514813269339, 0.07000862320344295, 0.028360668802633885, 0.028868638722586538, 0.1357865105232885, 0.033879790289868275, 0.03650648361672798, 0.019832440133717273, 0.014932820434501816, 0.02852751700688274, 0.012065197243505429, 0.1540818852522681, 0.06846273438103738, 0.05950131746489675, 0.041068330362078645, 0.03871759722730325, 0.028793426125400493, 0.039153022451266166, 0.023610544458572424, 0.07465443318529476, 0.07064891949055657, 0.028374759074781212, 0.09707003561479431, 0.03371990390963132, 0.01713178484820791, 0.03386845218858892, 0.09036300478563195, 0.13304553986076387, 0.08808597697005158, 0.13041519229450535, 0.09481634283738752, 0.03364169782388114, 0.038465297660760345, 0.02717561505344366, 0.03569736836418029, 0.034522492093064135, 0.03301293882090719, 0.05360024943647366, 0.018620868251028082, 0.021701679347203146, 0.04177472471529919, 0.03485803094301974, 0.015549593991900404, 0.02996724327996133, 0.0368564325805393, 0.08999155939466531, 0.027701741257201762, 0.026756530484905647, 0.05465654295779044, 0.030252737436263315, 0.03811252949338767, 0.15656591002498904, 0.1880377059381816, 0.14263392696457525, 0.14317498422197758, 0.1425808370714226, 0.1745183837990607, 0.14831771713591393, 0.16373911301695532, 0.16291382181788647, 0.17144698409303544, 0.17471053397222874, 0.12095310244589083, 0.13604304272561304, 0.06701590838812052, 0.09296788758928738, 0.09926519161390682, 0.1585392912309016, 0.21360244301538314, 0.2643852470622909, 0.14846333512856116, 0.1278854397335841, 0.16820004300004052, 0.15779174263438872, 0.19390791594501466, 0.16625660051020885, 0.18081642326808747, 0.11854062262441843, 0.17197687178850177, 0.12883346587900193, 0.12822188256729034, 0.14666875884417566, 0.07396398878265774, 0.24483056168162057, 0.07475439233765488, 0.17486551355931068, 0.11679226442450479, 0.1285513616617649, 0.12962696442921318, 0.1220599156353743, 0.1342081702164104, 0.1553263184764693, 0.09992499249957262, 0.11153051975153147, 0.13682327263297575, 0.12128248194893523, 0.1563381214415835, 0.12982685209041642, 0.11453477951187281, 0.24386251765874126, 0.2898995908758333, 0.2594653997690447, 0.11510656455591803, 0.29347663925540063, 0.19842048025419637, 0.28871322711629255, 0.13887398275396517, 0.26665970082244567, 0.17937990115775218, 0.23766708800629263, 0.6323088092669364, 0.8562812942170328, 31.826913702872496, 80.52532611354705, 101.66628160784322, 84.80918976568407, 83.44318512947329, 84.2822350225141, 78.4255950681625, 93.6276977292953, 78.45462060743763, 46.572274008104884, 63.485345917363325, 59.48041769766039, 30.966086810634984, 43.22899472328925, 45.55073976516724, 21.162965874518118, 29.534498183957993, 51.015852651288434, 66.82229841909101, 64.43594409573463, 62.75889550485919, 59.911764667880156, 71.31089410474225, 71.6689202093309, 68.99266350653865, 70.69288546039213, 66.62338718291252, 57.896203764023326, 58.02880733243881, 51.81114458268689, 49.390473442692915, 45.62195431801581, 44.79968432457217, 49.05933910800565, 53.22333905004686, 55.30505464922998, 56.777402585552586, 56.15595794493153, 65.17174936109974, 53.29470265296198, 65.39719150912377, 75.11181200704267, 82.44378089904785, 71.21304665842365, 75.8950230383104, 77.38167978102162, 74.487394209831, 89.23527856026926, 85.4894385799285, 83.15589504857218, 59.57109505130399, 46.897866033738666, 52.75587097291024, 55.456928822302054, 61.509706897120324, 84.43045354658558, 88.18132985022761, 92.74763553373276, 76.78860172148674, 50.95471858978272, 18.41459639610783, 1.5796892344951632, 0.49199591420831223, 0.20312415285696908, 0.29987218639542984, 0.12443484182679847, 0.23339299154618096, 0.1313909584836614, 0.2521655164779194, 0.23745169472550195, 0.1408447286174182, 0.17132974199710355, 0.10445375190747362, 0.09753893505060866, 0.10110175717742213, 0.2209740321362211, 0.20640883144111405, 0.18206485547125342, 0.1403465569620171, 0.14093229246716346, 0.0762738204831558, 0.1059616657514726, 0.11115816271593494, 0.12453703029501824, 0.1726823008709377, 0.08259014647093513, 0.2081959153856001, 0.13798529011828287, 0.14691216029947804, 0.09980398891193253, 0.2555114054872144, 0.2220036083411786, 0.22467120310231564, 0.20902557328583735, 0.13150570313296012, 0.13787839020932877, 0.0809915048340636, 0.12008020654320718, 0.11192955196865144, 0.0637844116276791, 0.1243864174091047, 0.13518139299365783, 0.13756777219955, 0.10635761829513697, 0.2654465239855551, 0.11076369638284368, 0.2134922795718716, 0.09451184587012376, 0.20866610951000647, 0.12870059558941474, 0.14462456047054262, 0.2702075152868225, 0.15997052733455935, 0.11274944224785413, 0.07341112611034224], [0.027972649099425446, 0.0751045404843265, 0.04120390111159894, 0.058495160567784504, 0.14099403915386047, 0.027669567479601795, 0.013840202854255275, 0.03419804236581249, 0.01673174714068732, 0.030342143727466468, 0.045011404060548356, 0.06249202896029719, 0.06557970803471343, 0.10701361938469833, 0.09934526312375262, 0.05059328155531999, 0.03061218589033571, 0.06312624250929202, 0.08540388016450791, 0.173063674761403, 0.07221267348335636, 0.05661640271183945, 0.09900567166867758, 0.04532329760672105, 0.1153044680493974, 0.040493450322819334, 0.02356186340142402, 0.04275135275337004, 0.03441518998794979, 0.0666703261254776, 0.09311247902411608, 0.0592144328590122, 0.0875654585298992, 0.060895432778183496, 0.017787787852989092, 0.02617457753888542, 0.0790745843081705, 0.01183516210726192, 0.09238353870328396, 0.09118450384947563, 0.05485072326395781, 0.06720176131855096, 0.010761425721519178, 0.03980417037382722, 0.0693363044410944, 0.11093984297927349, 0.030625988879511436, 0.044137918270163, 0.038614137053129174, 0.03659405129691286, 0.020069864187990467, 0.09275303823092292, 0.11809854392683315, 0.05562314290493246, 0.08109950024874941, 0.019026929324853326, 0.03127889114341909, 0.049520678022095276, 0.03880551347749368, 0.08007619830389177, 0.11393670233026629, 0.5294654278024551, 0.6943169464507412, 14.199542883903751, 40.67151131168489, 39.21202090478713, 53.718628498815725, 75.6789553549982, 68.39938932849516, 63.4333509783591, 78.5156056188768, 90.36908672701928, 84.23357409815635, 93.26126990779754, 78.19859966155022, 56.64677196933378, 78.89147066300916, 63.467287325089984, 48.630851545641505, 22.415419855425437, 41.78872785260601, 57.65066339123634, 30.873063879628337, 53.769654612387384, 82.77725296635782, 23.499966975181337, 56.33061716633459, 34.823641777038574, 19.752028526798373, 40.97042729777675, 31.769209754082468, 37.14774024101996, 35.593779548521965, 36.90229008274694, 57.19591948293871, 45.206995010375984, 44.52891134446667, 25.66784920230989, 24.371033214753677, 37.41179812339045, 97.37305918047505, 68.40192317962646, 51.8200836643096, 28.47542097491603, 22.563128471374515, 20.328501232208747, 23.372046716751594, 42.68366759823215, 38.51302316111904, 39.93738089838336, 41.35898513178672, 58.25051146168863, 60.793011419234745, 62.63543498131537, 61.05210358096708, 53.44196019634124, 49.52900763480894, 41.72518937818466, 30.925707970896077, 9.515278781613997, 0.291407497058953, 0.21229483818094577, 0.08421885705883465, 0.11535408756425304, 0.059807561112627874, 0.06405653754970239, 0.02730704892817284, 0.03081531601867849, 0.059730787611296104, 0.04227873396068331, 0.03577693808643568, 0.014411275436530912, 0.05189033735904002, 0.025592044281262546, 0.014528773214307525, 0.019151567999694138, 0.03398294402887264, 0.052159322320573756, 0.04622525122437266, 0.04527836654996199, 0.028930571185605183, 0.06928501485456383, 0.028601634098337065, 0.024144044258601727, 0.05574515006775337, 0.018119120880240397, 0.023700871970504526, 0.11226313729440013, 0.04936082611581491, 0.07912410423159599, 0.03248389382215758, 0.0873659385908996, 0.03121339254111292, 0.028284475612904758, 0.043431945265300816, 0.00932881257481753, 0.027092887133720423, 0.02971438829967332, 0.02154906697180723, 0.06945091119456677, 0.027443514085344733, 0.006683281145899767, 0.018602903489203706, 0.09632545177854838, 0.009332842197299246, 0.05704107589178509, 0.03333882496301686, 0.10393701028078796, 0.07099283168152457, 0.025618070203270164, 0.10214657087119357, 0.026306551505601215, 0.07423105469394116, 0.02793240075510356, 0.041382104654105446, 0.07080662635064895, 0.0748065859079361, 0.028449335818990108, 0.03407956686832252, 0.005932491039857269, 0.11098833634488045, 0.04673952604794214, 0.059382550853995554, 0.07279998712962674, 0.02670455141924322, 0.07564358293048798, 0.057590004702609394, 0.03527845999586486, 0.09258993045096436, 0.02985576599565966, 0.014091590776168292, 0.05136143025611678, 0.1261293593673937, 0.07878765373701051, 0.059111118241543734, 0.10336888713702079, 0.09259428949125352, 0.09786923385916219, 0.04657791596987555, 0.031610873430186225, 0.027102995663881305, 0.04405820682164162, 0.04808139799523258, 0.03390192640044036, 0.051079950400538025, 0.018345086174386165, 0.0748985777458837, 0.050181854035585165, 0.030249770760776538, 0.04514284176571716, 0.09419673858510871, 0.02107541204520291, 0.05872018740422303, 0.028131210147553397, 0.0046392034311147955, 0.024988753871331294, 0.03107719551471453, 0.031789714740889694, 0.0070877272106196374, 0.06208357003126895, 0.01823049091223267, 0.04018277102600663, 0.043262984573600755, 0.03987791399741846, 0.0596487281032868, 0.047315038109738985, 0.054371703806663715, 0.051128838301425984, 0.049251038055386276, 0.07578832758290154, 0.09389119973826794, 0.08999137553356348, 0.02521618813907187, 0.11116498089846104, 0.07346879720928208, 0.16526846966195494, 0.09204424602249939, 0.6349541415129939, 1.431558105734087, 25.479077293026833, 54.44272941158664, 56.34458472651821, 68.59478612099925, 81.47770897034677, 74.35553196937808, 67.8810324207429, 59.69869759774978, 57.523292264630726, 52.50652197868594, 36.0422319750632, 40.564709094262895, 33.646146251309304, 16.707043532402285, 18.993222482742805, 28.687911456631078, 22.953072863240397, 33.2871630883986, 41.875792703320904, 31.65668283739398, 55.43165699128182, 76.89757300961402, 41.92473603833107, 67.16322298972838, 57.10419877882927, 47.92037302447904, 73.78107732342136, 61.10239621131652, 69.09746923754292, 67.19865768186509, 68.23384177300238, 89.57842319242417, 82.82495683239353, 76.03697361484652, 60.900551042249134, 61.7367023037326, 64.80487831177251, 88.02181490005987, 82.65554181991085, 71.70939122476886, 52.05946591592605, 39.13958649481497, 34.95905376249744, 34.599701896790535, 46.965903466747655, 42.44297135260798, 41.51959442323254, 52.912263716420824, 50.38601806086879, 50.37350177764893, 59.619657916407434, 65.29991672885033, 70.38452440692534, 68.29301464942195, 63.93691270582138, 44.841606616973884, 16.86304796126581, 0.7472311296770651, 0.32272716323214196, 0.16836069163776216, 0.06087159212197989, 0.03713816141469344, 0.03239416577402623, 0.12009074025216604, 0.025060157096313856, 0.0447334673616194, 0.03384875223761605, 0.03686461056913099, 0.0474093243810198, 0.08702480729909674, 0.016923881992096865, 0.026772769633680586, 0.062861681705521, 0.06020738623074948, 0.08333437790673587, 0.03737427354339631, 0.041799381255142154, 0.043801942750090556, 0.06323685028379963, 0.008318284188487358, 0.02484305735467182, 0.01597786203943073, 0.026237768301319693, 0.021514525982521234, 0.07379485955161434, 0.057788980719182766, 0.09881951996395666, 0.06222413184361593, 0.0516845508208198, 0.06937316859201079, 0.06395279392299634, 0.05574504281544397, 0.015653461150284258, 0.05227303275117471, 0.013407372753135862, 0.03185351454322377, 0.03218221988889479, 0.03375594451602909, 0.05478107054988223, 0.02768433190912249, 0.023319375505971334, 0.06085643890283762, 0.07904285294634682, 0.023765464673840234, 0.05492058282177295, 0.01596404564371633, 0.09329879160730109, 0.07580691287594457, 0.10315092746168376, 0.056007048715987516, 0.04352517433524613, 0.02108186059030554, 0.10048652728719097, 0.16059953148566908, 0.14574844209897905, 0.1211270580308572, 0.12378225748937939, 0.23172730189417642, 0.07278317149968878, 0.12376184890707656, 0.09151504014528568, 0.11987229028055746, 0.16323732542655162, 0.17493176484300246, 0.1386087631145793, 0.20655492440827433, 0.24204145005393415, 0.19204757867320893, 0.12856355778151943, 0.20725650772933038, 0.2797363620371588, 0.1818741915086585, 0.2826455349643385, 0.17924992668051876, 0.1538149495759318, 0.15217533755686977, 0.1519295612290021, 0.1877124403272906, 0.14556789049698463, 0.16501201406842278, 0.1211905743806593, 0.20675206947470867, 0.20557206424493946, 0.17287051335217493, 0.21885394509280884, 0.18984358968032947, 0.135880708694458, 0.13831185807864513, 0.1266865044712059, 0.16986299005727615, 0.07871225536350282, 0.18904390113969005, 0.1853908108727586, 0.20473672197230403, 0.20383828469822485, 0.14016177655468065, 0.30682238119263805, 0.12006162891104338, 0.2045678761937926, 0.17842785305073186, 0.16305001692906504, 0.23060631607809376, 0.1639332550187265, 0.15513534807870466, 0.25304771268800386, 0.2223350486207393, 0.14867684383305813, 0.2100873558271316, 0.30482295299729995, 0.1059189793323317, 0.22691872121105272, 0.1631124684166524, 0.17988279191476686, 0.20959990940267043, 0.5793654534124559, 0.9141586853131172, 24.42942161713877, 62.68528046146516, 73.17412976295718, 87.50036716461183, 102.74438427340601, 86.47516942793324, 80.46234069332, 90.64727690912063, 108.27582051677089, 100.97945105644965, 115.09630449356573, 101.48764902545561, 74.29085208523658, 106.95943386323991, 86.52115529583347, 71.70879502450266, 40.988944807360255, 55.895500798379224, 71.49638299019107, 44.03211570555165, 65.97999295880719, 95.70100768919914, 35.150230084696126, 70.8104310497161, 52.96328198525214, 35.38883570701846, 63.991539555211226, 49.873313288534845, 56.85124120404644, 54.01892123683807, 54.256518810026115, 79.17284580969041, 65.64297114649128, 61.3840929923519, 39.73155452359108, 38.46779038829189, 52.333651358081454, 112.26723224886003, 88.96174815393265, 65.52928909178704, 43.883453953650694, 34.1683510042006, 33.52900466611309, 37.69659749923214, 59.72505592530774, 55.79775141131494, 54.98148656660511, 62.12831174173663, 85.6441133253036, 91.90307078822967, 86.88184861213931, 89.86580741020941, 83.36667537689209, 81.44964833413401, 74.07795367702361, 49.67925794662968, 21.365691615689187, 1.169077874191346, 0.8264707293241256, 0.19368244094714043, 0.2981094487251774, 0.13447259312435506, 0.2324616431348747, 0.16388025705612477, 0.10647116784727383, 0.1602417684250301, 0.18979546403692615, 0.2369177927293124, 0.159181977712339, 0.27105107002200624, 0.0992588330841353, 0.11428140359179628, 0.16372225908262117, 0.09926368242069598, 0.20232218137431532, 0.19044944265436745, 0.12598792421481303, 0.14307470331268926, 0.19431545939897338, 0.1078894877085282, 0.1422094682892484, 0.13871497354440152, 0.1981061697006226, 0.17309821000502956, 0.16610915922830183, 0.14396472894135984, 0.1770879652711653, 0.10164077664094587, 0.16851328103052032, 0.17691424717345547, 0.18841871210644323, 0.13782001430949858, 0.13795624006419413, 0.1796318827978065, 0.09736024504227024, 0.09848260981661659, 0.14754307967039848, 0.08022998279381184, 0.07720750546263111, 0.07415413180546415, 0.16048408203548, 0.1141412707886869, 0.2006547450418434, 0.2591189748096851, 0.17188503316813902, 0.17149924661122984, 0.09639522706669185, 0.2579451136050686, 0.1286607130520767, 0.1095100317991549, 0.1272146684688426, 0.08861754239807207, 0.17033437927884443], [0.07060512224392546, 0.10251952545537103, 0.04619580280456332, 0.058399748147254994, 0.014396748494266745, 0.050441079036963564, 0.10074529646625442, 0.038887979012102857, 0.043581926128676826, 0.07036853131026992, 0.11189374501907057, 0.10140150439955535, 0.04643379184868067, 0.07161150896741499, 0.046552592933538466, 0.07107783679760273, 0.06053711047335979, 0.06512282851843104, 0.08542536126990473, 0.07792513832570085, 0.05897463967783317, 0.040403350722044706, 0.014952183306788006, 0.03224716116223605, 0.06569695779152455, 0.03424452092017859, 0.051205194284839016, 0.021335730637093226, 0.08078913504798567, 0.04340802800030478, 0.025638995894921884, 0.040302797851543275, 0.03801014567274721, 0.026621614740560615, 0.00626213915248011, 0.04456062643458286, 0.06025722408066354, 0.04297728357355922, 0.030362891303675792, 0.027445672538071394, 0.028694861253062566, 0.06665707280438754, 0.0903275808800132, 0.06565679180165453, 0.05795479278951403, 0.07245079659286045, 0.0746944076531837, 0.028370666250045744, 0.0668264625053252, 0.00637377875166074, 0.03708549670033878, 0.007474319117459199, 0.101553603496042, 0.022803384645451463, 0.09699751007100267, 0.022075643252220847, 0.024222947484362992, 0.07288039571815923, 0.055952047433463804, 0.16380465949975676, 0.037558261049731125, 0.08642592572516973, 0.11796945045071265, 0.8036976319647605, 0.04278900597484843, 0.2286806315063469, 3.579185090718731, 31.9949637305352, 59.34475860288067, 74.42720151716664, 73.73210260944983, 74.42509912675428, 83.29172672763949, 82.81582555463238, 75.85018250250047, 84.63545230127151, 87.101728839259, 79.82679120955929, 74.4699239730835, 85.07806039625599, 70.22151854730421, 54.377790651013775, 69.79728283420687, 42.48211660692769, 52.49970882169662, 66.60657590435397, 69.96312848983273, 78.15089579551451, 55.13378043328562, 40.9433864778088, 55.202198336201334, 47.56084857448455, 33.14910742544359, 39.37818427239695, 33.15517140972999, 34.096732447224284, 40.494553581360854, 41.28244400024414, 49.69823829589352, 43.63261838113108, 69.70744486778014, 56.85688941709457, 40.53286337083386, 59.18759707481631, 71.56264751188218, 81.10154582608132, 84.29775976365613, 72.42175640598421, 64.33201697564894, 55.23675441741944, 32.368498886785204, 19.346304439729263, 22.65593763320677, 28.339583412293468, 22.89106215200117, 11.563161976875799, 6.711198408757487, 0.3869673129050963, 0.0321410043585685, 0.43920298737864344, 0.028284230464768988, 0.12098424392001284, 0.06840238963524181, 0.07648074083150395, 0.0052877394726590045, 0.05931186775166181, 0.013628278036541758, 0.028021985161749106, 0.06902378653326342, 0.06380562460230244, 0.032696544508179354, 0.07006061759086386, 0.04607827342565983, 0.0525023496799892, 0.024304072365104675, 0.033446180694285906, 0.04206612540949737, 0.00930535113213644, 0.047713599182785525, 0.06118456202168619, 0.07519400423212398, 0.10757280994326839, 0.029387301314742337, 0.042952883673170884, 0.051154816342938336, 0.051287552567138794, 0.04239722477993177, 0.026391711754484043, 0.024309601604698167, 0.039703805194867235, 0.08250118834116767, 0.038865226200751724, 0.047927391339814475, 0.015101494800840175, 0.0316322204701963, 0.012871412853259715, 0.03988738667460219, 0.02646754296766895, 0.05495385402032445, 0.06149135725272279, 0.05458861011110487, 0.01762985691217886, 0.007548200636876808, 0.047264529932891174, 0.05397954339822454, 0.017331115180446256, 0.028894877233993144, 0.15995580312465468, 0.13470974330219532, 0.09144035423354757, 0.06160683351598921, 0.05804033416713919, 0.07453254859654174, 0.08419104040630403, 0.0607767925717898, 0.04987243878384752, 0.052470825161905064, 0.027016875889873313, 0.04872040342419379, 0.0708292948923284, 0.042415472994288134, 0.06393676353318077, 0.10637628019697244, 0.030181169502377033, 0.03613747055492094, 0.07494039082479093, 0.08728284103375289, 0.061904811075017344, 0.0346036322955643, 0.04750878940666876, 0.10020414727830118, 0.03798573428104001, 0.041946408849570065, 0.04970880240322121, 0.05771966508379387, 0.06416542928725963, 0.06926583967381908, 0.007015042703583717, 0.012242202816020337, 0.04560852746268915, 0.006942082883700008, 0.03992536165300877, 0.024473546335714, 0.006554662165487366, 0.013001192935682353, 0.04162964681463857, 0.009204065690057413, 0.010865087951383284, 0.07961528150424843, 0.08167438794888797, 0.010714837999623871, 0.0021955919510219246, 0.037540196696476597, 0.015954637126396262, 0.014644443872384729, 0.07285441767664687, 0.04798087193780849, 0.07017761453865998, 0.05955675924797693, 0.006999514580163504, 0.03962260753577275, 0.0077541801334929565, 0.035586327749995456, 0.0581194595583985, 0.06302621440901872, 0.12013730307620381, 0.047728438305878834, 0.057087527633073835, 0.10521807016864901, 0.02021057155704306, 0.032093183235115105, 0.047955353549050714, 0.04522866276543468, 0.03355450552677916, 0.043193649786013755, 0.28907233849167824, 0.02771369605926016, 0.1259729395350141, 0.19743348321607038, 0.7719240433746769, 0.14170040286356403, 1.613197920303191, 10.62351211424797, 49.4391147551998, 70.75779284200361, 83.30557269434776, 88.67671735825078, 91.76018668759255, 91.95102568595641, 93.90639781951906, 81.08350292328866, 72.51649733512633, 78.87469860815233, 73.1481558276761, 65.80021896669942, 49.596868561160186, 53.87933977188603, 51.81626719813193, 38.98122079910771, 48.34065106607253, 64.94061585395568, 25.248908688945157, 60.49490344139838, 52.60783680023686, 27.69699327407345, 33.25195981610206, 34.28072298726728, 33.76775933850196, 25.579407599664506, 30.08193946653797, 39.99316484697404, 29.925989950856856, 34.62491096988801, 19.2362956846914, 19.58484926531392, 30.213136865246682, 86.16518451321511, 57.26378040928995, 40.1347545654543, 32.43722273457435, 33.91182407256096, 42.63922322180964, 51.95499750875658, 68.58996160568731, 64.83006777301912, 67.74134112942603, 56.30813806287704, 49.78990800919072, 48.1438853663783, 54.120494934820364, 45.23554594286027, 26.930093419167306, 13.46732266487614, 1.7800376516196037, 0.0709079874439105, 0.544021220937852, 0.04995363261250239, 0.21852058959343743, 0.033219759577825185, 0.0584520987655607, 0.05933940095166045, 0.052379078472093235, 0.0202234284276323, 0.002219256646405425, 0.03656749102857806, 0.0557539064527279, 0.027201215796653303, 0.05700746378410728, 0.05391127347285229, 0.013630978496474846, 0.06869137332203888, 0.06346424050148457, 0.023703294723565062, 0.050722646992653615, 0.0354094380482791, 0.07767144830957537, 0.03307729020654675, 0.0533772029373194, 0.015975272662246662, 0.034965118543515285, 0.022738627233212034, 0.028881953330710534, 0.023227084893733266, 0.045190136203722614, 0.0049713240925132515, 0.050711921761713685, 0.033560626569294164, 0.04700794793485154, 0.044789705876140826, 0.06467922530587643, 0.025383369591567787, 0.02536383817993826, 0.026512286332886548, 0.022120760085301536, 0.02471451354663699, 0.057226882856940074, 0.02604770571774533, 0.038210270821206996, 0.04284424091418905, 0.0643025551952662, 0.0512754560388144, 0.07682466834423042, 0.0511271950428284, 0.13694356375884625, 0.13896465692068302, 0.04809893374781936, 0.08487992965045475, 0.021312602442659197, 0.03228071581331953, 0.043786073238739086, 0.03259277023795632, 0.06066921467502272, 0.1939339629344402, 0.24687883564301077, 0.18807892146850788, 0.14513471374107947, 0.1005344077824585, 0.17583113674434925, 0.2663737968091042, 0.12916927285973104, 0.1533080445181939, 0.10069831995473755, 0.249496205679832, 0.21614904184975933, 0.14034822703369204, 0.17105670826088998, 0.1679953443066728, 0.08905907717323111, 0.17031072248374263, 0.2776246866391551, 0.176772628159773, 0.15372608337671528, 0.22371239809980317, 0.18442693436818738, 0.15384032240798398, 0.1252334961487401, 0.1569325290620327, 0.13268757761726457, 0.1156146110846631, 0.11145866070423396, 0.12945802672015083, 0.16047358663091738, 0.1254678424447775, 0.17615085587866847, 0.28216403338216967, 0.10328287078488259, 0.05617260031642453, 0.10295754388695764, 0.2205020606878304, 0.16889718301113577, 0.11519323974367111, 0.11178661528373919, 0.1206433118110703, 0.1722505643603302, 0.17066503814872236, 0.12812299593802423, 0.13301200053143886, 0.20354913247208442, 0.14979923925092145, 0.1888369654695834, 0.16803231570989857, 0.263488587112196, 0.13527746041936262, 0.1893649532669975, 0.3018014715804208, 0.18670483552400144, 0.18371405891112744, 0.1311579911458877, 0.2834035636436555, 0.2019084479299284, 0.14290021912705514, 0.34862513323464706, 0.13768037180266074, 0.26722415440505554, 0.2005105826162523, 1.1566185879130517, 0.17107569191965366, 0.838767604962472, 10.501693102621264, 50.494816764708496, 78.82209177940123, 97.43973947340443, 98.74435901641847, 102.92665681531354, 106.56832648861794, 106.2791693595148, 93.78420814391106, 102.10953297153597, 108.83609187218451, 100.34955763047742, 95.7884059413787, 106.0406578740766, 96.17555956686698, 75.05983275751915, 90.50881724203788, 65.08056994407409, 74.10113488474201, 97.36731683054279, 91.82458416108163, 100.37916368053806, 75.4093159398725, 56.22149290577058, 73.32150889981177, 63.31968461313556, 45.09390131119759, 52.01082068104898, 45.93170389052361, 43.758797107204316, 55.836861364303104, 56.436187759522475, 68.0341225285684, 60.85071340683968, 89.2075317136703, 74.41189642875426, 57.97923249583091, 75.81460660503757, 88.93257356459095, 97.11847382207071, 103.07584808718775, 95.41641619897659, 92.59272544614731, 93.51490605262019, 78.53438592726185, 60.38319433889082, 58.65462541580201, 65.96332288557484, 52.95571965555991, 36.407898856747536, 13.86971567907641, 2.261292737337851, 0.12279735953216592, 1.0669459739039022, 0.2234313817274186, 0.4996119313422711, 0.13281719969405284, 0.19473765045404437, 0.09252799224228629, 0.28170729176171366, 0.09604229035997584, 0.18071349169458115, 0.19729135858435787, 0.19774905015383998, 0.1266582434876792, 0.11525436589914946, 0.19170481561412736, 0.18080015156057574, 0.14341887597355152, 0.16109804021975688, 0.12052823774396412, 0.15892107880884604, 0.2186649818454058, 0.18855766513414923, 0.18353465644101943, 0.23704957517404712, 0.12596043698008985, 0.1793241912438985, 0.17995048344375628, 0.17119400653867953, 0.11532834700999722, 0.22928132104777524, 0.15135439773721082, 0.24071230282706602, 0.1747332408183044, 0.1199947341134952, 0.11322310675055751, 0.18100535587197353, 0.12456660894977471, 0.10236570266105476, 0.08362845607822941, 0.13699073945322346, 0.20143100661375832, 0.2502040096348332, 0.14207025479164817, 0.10530664525445431, 0.1304638848429726, 0.23510412553385382, 0.15992287666566912, 0.18512969746464686, 0.18045283793922395, 0.23816386538167156, 0.22436665250889717, 0.13469685770330891, 0.19686529112439002, 0.10865736827855149, 0.20392039400194922, 0.34039011705786953, 0.1387754791686612, 0.27312410394510916], [0.06115283832074173, 0.02587983095567794, 0.07667201000355905, 0.0785910142886062, 0.0800342703117959, 0.03634149126047569, 0.11690612041181135, 0.17672468637747152, 0.07737076646017452, 0.13283892594758542, 0.03849470394573385, 0.05055173660718626, 0.06465165380148158, 0.08707152334071937, 0.04790331319635434, 0.0793122937301955, 0.05184221937651596, 0.02557299550502531, 0.05332795880554665, 0.07030225704394041, 0.04936885854770099, 0.03570658440190939, 0.039302413426940484, 0.045214739117410876, 0.04756076847233119, 0.006220602822835528, 0.011308304289536131, 0.06783359999498052, 0.1467387792804549, 0.12967939548675092, 0.0299385666937357, 0.04660032021122114, 0.027522815676826625, 0.07061504308254489, 0.07549351396700067, 0.062453452602870045, 0.10149024036382476, 0.14195304333923325, 0.047923231482385635, 0.02212112589228538, 0.06335236868190189, 0.02504897029739955, 0.014667322130633459, 0.030098841863594232, 0.062471275638428435, 0.024146911342658346, 0.008953155615487167, 0.06420476790217143, 0.04835099582710574, 0.07843189016585389, 0.07648476279310643, 0.09058706252084625, 0.0837504938845673, 0.057759643382122444, 0.0930396393842755, 0.03985926741734147, 0.03593454535509791, 0.02279638260182354, 0.018972946939268903, 0.11792646525728127, 0.08606270045763062, 0.06515925599923057, 0.029952666541982084, 0.3530486168399934, 0.1799802536204938, 0.16268781055846523, 0.15632451572004827, 0.2815689362825886, 0.23386841039023093, 2.665125506539499, 5.178923030053416, 9.31536537985648, 22.10852969077326, 32.62087006722727, 48.583163369086485, 58.98113135368594, 65.43300274879702, 46.07968707238474, 57.47273291310957, 66.9797109788464, 70.19223413159771, 80.09454004226193, 75.66281087936895, 77.39607487955402, 68.65882273643248, 71.6426952423588, 60.899303728534335, 71.53450058352563, 77.76167115857525, 85.66920864966609, 78.8376243652836, 79.9387199647965, 85.46798321508592, 81.91901483843404, 92.2938016153151, 94.95221153382333, 92.26589787390925, 102.65930021962812, 87.55946159362794, 81.88133655055877, 71.46454903387254, 73.75594277535716, 82.40932679945423, 84.35510481557539, 76.61537416519658, 81.93738722032117, 80.52921710475799, 75.90034177226406, 39.968183271346554, 9.642145883652473, 10.287523846472464, 6.739023702759897, 4.060624650409145, 2.24950724071072, 0.1600606805614887, 0.22524219907579884, 0.5174778065373821, 0.0846723121620955, 0.10241618785526484, 0.2656442666005704, 0.04335288882195469, 0.15126524042458306, 0.05301673941674733, 0.1298838337102244, 0.02559104645174117, 0.027041681816861517, 0.022111038429542415, 0.0693671241582882, 0.023716304811739156, 0.05282460073489816, 0.02839909194247617, 0.0358012460562731, 0.040821753472330115, 0.0339831700248103, 0.05868107478524889, 0.08617651047966174, 0.08725266483041548, 0.0353270031571869, 0.025419053967080774, 0.07763181092037309, 0.051640083247254935, 0.037906842546597604, 0.08913160271702275, 0.06943070945600349, 0.042805584117529855, 0.03766745539201844, 0.04196707024088791, 0.025897449062716578, 0.03002850350082642, 0.05004583129418954, 0.028368354579734228, 0.010292561717271324, 0.04369717256556596, 0.0327482401213098, 0.0673739932056877, 0.009990194474437065, 0.0185431620376485, 0.031080054937891906, 0.03716983531992282, 0.04336850935473077, 0.032383340951656146, 0.06539244550250231, 0.051255384535198255, 0.009807891403925757, 0.027993304745083856, 0.033213447013329116, 0.06419908352977326, 0.03830130887968886, 0.018175217668495832, 0.04243564791977406, 0.11815368693562285, 0.04836179000595885, 0.05496855907803101, 0.05109814115830007, 0.018048382236532146, 0.011833129101432862, 0.021033623864153222, 0.042961394910009644, 0.011432304238570074, 0.048181851274303855, 0.06051273355560918, 0.07728377717637247, 0.048824637347171386, 0.07674668825441792, 0.10579498034090766, 0.06470862776041031, 0.052638939326448794, 0.12488596802276951, 0.037091793943076365, 0.04527532901134222, 0.06885734627083426, 0.03423669150159244, 0.004440481181166345, 0.09537339601064883, 0.05949014790296074, 0.038936905217387026, 0.027488240213584036, 0.06383586592311341, 0.06940716757409035, 0.042102935934259046, 0.07348230333938714, 0.04000514971032258, 0.054000388650644215, 0.06194387006783678, 0.07050769118171546, 0.07680208407222264, 0.01712574999058439, 0.04571607088549964, 0.11098588486352276, 0.03105827505820461, 0.01590747388094784, 0.035627083627567176, 0.038214947787984725, 0.06300326241480728, 0.03924101914068864, 0.062449246780165744, 0.04269381571981696, 0.02815522700397959, 0.023239698531406543, 0.017061214743843003, 0.03516362724645484, 0.03219319026797049, 0.016153733801817702, 0.033495685295952905, 0.007492844559883158, 0.05203710831401329, 0.056263688170621474, 0.0723016469348823, 0.011382161868706105, 0.0532013627760593, 0.006287047543728184, 0.025629316373998602, 0.09420399343775165, 0.1005964762260837, 0.03603275399655104, 0.09004356144296546, 0.07911478094155751, 0.09646926180369432, 0.05584721979234488, 0.3855339930422845, 0.09630768619958432, 0.20732171713344513, 0.4208049875113272, 0.24139793619753855, 0.7864319713365647, 6.674865493851324, 11.541239849982723, 19.21731729661265, 39.388158859745154, 52.70916731126847, 67.50205301469373, 82.01091597157141, 86.66252536158409, 74.86401234903644, 79.79168599651706, 84.85210834010955, 78.00243408449235, 78.02764707996, 71.67752588948896, 68.8560159744755, 59.88883056948262, 67.35965528795796, 61.513197806573686, 80.82028835050522, 70.35392991958126, 72.06303211950487, 73.49283802893855, 69.34432752670781, 65.81581038813438, 68.1921705122917, 63.6553414406315, 68.73527757583126, 77.40581804706206, 78.9527302403604, 75.96139738636633, 78.83717721508395, 84.80139993852185, 85.79917246295561, 78.53684133098972, 94.69157788061327, 91.60816346445392, 104.57219308422458, 103.34452259925105, 93.07156839678365, 65.58142523611745, 34.017398588119015, 16.760417184522076, 7.6835647609926045, 5.932904068500766, 4.716071582609608, 0.6709827050085991, 0.6278096668181882, 0.37906251126720064, 0.09334495606561823, 0.055657731774713726, 0.29241266570264296, 0.05848866797262623, 0.061746008709193244, 0.030922014829552466, 0.14295485651781484, 0.028488339270435037, 0.05009049422017509, 0.09738637630136744, 0.03931518028219862, 0.06451501435930691, 0.0010861532345804717, 0.08688056826471321, 0.024216723019978213, 0.019662217312161962, 0.006509193889571415, 0.0878441536558732, 0.010781055766968958, 0.02252946799290517, 0.021037762654164148, 0.030602433591059623, 0.033513485348873565, 0.04651151146859892, 0.020590551167486176, 0.039632122347792315, 0.05100007807355254, 0.04981864408980455, 0.015062232794720801, 0.037913258532963456, 0.05926500615333358, 0.044707309289444844, 0.04646445834828962, 0.04856204538936577, 0.029358808589618535, 0.01816927282620342, 0.0685450122241051, 0.020135493025243766, 0.0022171362586725024, 0.02994369756760857, 0.04453953603402742, 0.02509732193674051, 0.11768227473141686, 0.011997425275283956, 0.061996078959876494, 0.004572132912148992, 0.05228907080186952, 0.07261629456714278, 0.07355911897555475, 0.13336017217126586, 0.04491672708442615, 0.0578562279171761, 0.06151271195361211, 0.027151125137724226, 0.019515360172297207, 0.15796089484806985, 0.04196861773849495, 0.009240948035561991, 0.021471906596073703, 0.1132473381116025, 0.1553072582089132, 0.18963674594077373, 0.10694333081764561, 0.15397780454687535, 0.10734247794795422, 0.18825895213071378, 0.23689710835535682, 0.1861927517118954, 0.1321737011594157, 0.13309260830283165, 0.188453569106998, 0.21748059459270971, 0.17878442101420897, 0.18918634752833074, 0.13200149991579596, 0.15253806486725807, 0.2030756748131206, 0.12314661135596615, 0.12725903262053767, 0.1637733111818952, 0.18866793582997016, 0.1373619396960543, 0.1230662257500714, 0.21314128872848329, 0.11071655133198346, 0.25790184495910523, 0.14495460647008113, 0.21908242315534623, 0.17234609552448796, 0.20487326948392778, 0.13320130085752857, 0.1819544468796061, 0.10535673974382301, 0.14405785458943537, 0.10686883642788857, 0.19039577053439236, 0.22357627959741702, 0.15555042983783832, 0.14796119513771228, 0.10305637689006907, 0.13956608190651865, 0.07729538340842532, 0.15586731444683768, 0.20094869297838983, 0.23382026942506914, 0.10246282728809504, 0.21075389828653107, 0.12409449194467838, 0.24531321239567574, 0.09797068688297465, 0.13720026450051417, 0.26420022150681866, 0.2199026275305979, 0.20219369310765498, 0.1675627191340731, 0.21196505265130153, 0.1330653355727273, 0.25443359638654417, 0.21096443456988181, 0.20248206392411264, 0.209480031964279, 0.10427914514777162, 0.4032526874253827, 0.3687320913999312, 0.29184143990278244, 0.4083239749795006, 0.6630318768082127, 0.23986971336266688, 2.8664779278539845, 8.089741391520347, 15.350973279245439, 34.5565362130442, 50.50579547882081, 72.37147162037512, 84.71168748794064, 96.93118849108296, 86.66221941671064, 96.19058224462695, 96.28151062996157, 93.4703871511644, 105.20058816479099, 98.33141188467704, 100.1121287192068, 86.83631773917907, 90.01872493374734, 79.81278834804412, 96.30721784407093, 103.56349283649077, 108.45559058650848, 102.71456641535606, 101.5595539154545, 109.7413121500323, 111.0982168874433, 118.87301352716263, 121.65093022008097, 118.8037758488809, 129.3287266454389, 118.23117256164552, 105.67342988906368, 94.89761998576503, 99.54489907910748, 110.5192985842305, 115.74739440794914, 105.70579728772564, 108.9296325560539, 108.10496207206481, 99.44472958964687, 72.54906085229689, 40.068462587171986, 22.447573484912997, 7.585538356534897, 5.949434897591991, 5.148445723518249, 0.4108050273310754, 0.7233239157545952, 1.0446719368619304, 0.26308259115584437, 0.23189452356628834, 0.5455418135369978, 0.15540151766711668, 0.28986698617377593, 0.09440315331542685, 0.22051824046479118, 0.18055336399664804, 0.16585572202119137, 0.26202162066774987, 0.2234353194193494, 0.14970439756589551, 0.17856369576146527, 0.12552098596408484, 0.10527571828495111, 0.09063740215835073, 0.08186658408733145, 0.29187242049844037, 0.17417015087219978, 0.17676427780139833, 0.12083121019625857, 0.21321746851167372, 0.1487593821460201, 0.13601478940296557, 0.16784252508753733, 0.17130507396594172, 0.13995586744239255, 0.11548239963069079, 0.14498025509378604, 0.2659488631592643, 0.129333276962561, 0.1338856625220468, 0.14871900931241053, 0.09151049724389469, 0.14518175153963028, 0.1284774494988303, 0.1224573084243363, 0.10170603967121533, 0.06801660307833264, 0.0891902237649887, 0.14999711976176308, 0.11144667142821897, 0.1463321857755223, 0.11627602841584914, 0.21878035468680246, 0.17041055906203487, 0.16506847474844227, 0.10766615009596271, 0.18493115811819033, 0.2293721637538364, 0.10773737329028307, 0.10478994959304411, 0.12080727760950405, 0.20668371911010436, 0.1681772748669309, 0.19321092915150428, 0.24144290555869383, 0.2653735004846127, 0.09984943324760084], [0.16452332658152427, 0.12582358303329638, 0.09647802584954808, 0.08092491647168513, 0.0658381937612449, 0.11511303799887819, 0.08323253417808203, 0.04604374201247289, 0.04123415009328916, 0.042688656117646925, 0.1372321644016812, 0.03473170687474551, 0.03831687195587062, 0.0581570629841618, 0.02551822404887888, 0.13225829258801478, 0.0374482776368818, 0.046253454751305045, 0.020449441602273334, 0.0334393969857164, 0.027622351565608577, 0.0429665774948174, 0.0265390879189175, 0.06514467734603152, 0.033096273865310416, 0.016159362632841352, 0.054706886425734534, 0.07690882310271263, 0.027273222315876235, 0.06183615044480371, 0.05320349633092842, 0.03699818182916891, 0.047477889250242905, 0.09127910038636577, 0.0524045394042567, 0.01740403334429908, 0.0476615320170118, 0.08566541492097801, 0.04153337254519424, 0.018561839261242462, 0.03923646091753918, 0.07648075615326244, 0.03878269937910861, 0.041337342136689735, 0.061223801045167836, 0.013000776375373526, 0.03781901439651847, 0.08665301716856419, 0.006994874481367128, 0.07370806178979336, 0.020060862654880173, 0.06463492244121528, 0.15042539355495285, 0.08318686767691567, 0.07941675747955039, 0.018172681917466463, 0.08330706687223527, 0.01902172375740784, 0.026950429253760847, 0.035476474572093256, 0.13827816553173528, 0.1542742652518134, 0.026948021822458795, 0.1569159049540758, 0.09193949882061252, 0.054301989805554195, 0.037140766113635995, 0.4282642630559783, 0.12868703583315497, 0.04159555207156847, 0.35965588003877674, 0.3784472813769695, 0.5424650818590195, 0.6749399475032284, 0.36814811789701063, 0.4388173693610776, 1.6917294095600806, 2.171473647317579, 5.158098676512319, 18.079214134523948, 27.244426281221454, 31.296344495588738, 48.29145277700117, 47.36942122059484, 52.08841693016791, 55.70782715274442, 67.33517969808271, 67.64588632891255, 57.92004000756049, 49.051168810936716, 51.16469090984714, 63.05097479974071, 51.26078113432854, 53.33076884669643, 48.185344819099676, 48.086579538160755, 39.30007811515562, 36.54304804340486, 22.133832900754868, 23.58820265339267, 10.034220122521925, 21.847888192822857, 28.798963562134777, 20.056598609493626, 14.989133650256743, 11.991445575990985, 7.434849229551132, 5.148067705092892, 1.2726896112003636, 0.38427129628196843, 0.13984247110784054, 0.10979501650698724, 0.22125386873320227, 0.17720407355696927, 0.053998936914027705, 0.1419021138140271, 0.13984150583705596, 0.03521770922346942, 0.0906447719241823, 0.04483315838320602, 0.058797964480735605, 0.14285495865248865, 0.039990360382944345, 0.006349708269079847, 0.016319854222538493, 0.031895126524050875, 0.0367470811902275, 0.04415214069247727, 0.03778595387214615, 0.024201759407597206, 0.06198609683422312, 0.07892577172887903, 0.034633417794060324, 0.049062932826458454, 0.047532974802438295, 0.0198471566827427, 0.05167837998258972, 0.08427079782010087, 0.07904977838118231, 0.026588109885192206, 0.07446789843661171, 0.0643080480456833, 0.034885119812022296, 0.050317643120163874, 0.031980823034480695, 0.023092345349610816, 0.03906553904075296, 0.020162507200673706, 0.04344500323397018, 0.023508911404097756, 0.025468945443149538, 0.05009474600815485, 0.10297822826091321, 0.09542870755878188, 0.07134092671255912, 0.011341813932954064, 0.0615961657416436, 0.058931597027807474, 0.00789335867833166, 0.06631088533228444, 0.029071925898953795, 0.02567006076025146, 0.07981097100362664, 0.06532194243083078, 0.041778739016022415, 0.05858869224245991, 0.0350279760577025, 0.08928341070009817, 0.02502458188833008, 0.024001385280562025, 0.01834586566884912, 0.013579130623369448, 0.07978433412649939, 0.03444165832573368, 0.07885671656338439, 0.06301119142482359, 0.036737528073811726, 0.05347444630798794, 0.1655433113656698, 0.16324774422232183, 0.16174284110386528, 0.07103525763077122, 0.028901798838389017, 0.05520655961346723, 0.032168051092735225, 0.05997741812719934, 0.04418209856075626, 0.07899347857962694, 0.024913740457005562, 0.0700936972674343, 0.0965792184034663, 0.04811786378042833, 0.028284406664991574, 0.04068751188535844, 0.03293117808718835, 0.03885078927381866, 0.030150368937381336, 0.07386199949729828, 0.06366583653875897, 0.05938448522600436, 0.05956788284463748, 0.04523265408352018, 0.014677415339035854, 0.02698976978389246, 0.05930050666774473, 0.020153407991353064, 0.05289678536956349, 0.06613691442555959, 0.033131383674880194, 0.05930811775127246, 0.04722146430022774, 0.01648179754885214, 0.06535063242359508, 0.018088454380631447, 0.026852800923910354, 0.03451527554481741, 0.03366153950112001, 0.05382660160502119, 0.03700488892894599, 0.033268287417388735, 0.10035800071613443, 0.03793640971003521, 0.04294370977027763, 0.049545920619200316, 0.05124509597437517, 0.022684813386970953, 0.059512912205630736, 0.043576762696067174, 0.13725142385209763, 0.06939032130063542, 0.06494049193157304, 0.020283093270395073, 0.03852228311100795, 0.03943010113171993, 0.05228335578595439, 0.08116382865175124, 0.08366873698128809, 0.16971565602767855, 0.01785681045974695, 0.2604311302063927, 0.08683361473583406, 0.06857422315665791, 0.10989023357509606, 0.09716494624773342, 0.1620367890404117, 0.17881550886217626, 0.3856551268648717, 0.2450433349417102, 0.24109799745342425, 0.7330808728452652, 1.246979455313375, 3.136897404347697, 8.901258207136586, 6.823191883102541, 19.172080601415328, 37.57154841576853, 50.265750346645234, 58.96996828817553, 72.79472674092939, 75.13999031436059, 77.04705453688099, 81.03051170226067, 87.64148619867142, 84.78305109085576, 77.92177446426885, 79.50845949111446, 82.29838648150044, 89.57797604222452, 83.25866899182721, 80.74606141736432, 77.30151437943982, 75.70422326364826, 72.3883064331547, 70.22542522799584, 56.94158907859557, 60.68493050913657, 51.41137269235427, 54.97149236740605, 58.199657932404556, 40.34213027646465, 30.918941882348832, 26.530545103934507, 18.257442712783813, 14.306163691705274, 4.3333732793408055, 1.1450777491254192, 0.8419928351236928, 0.5101412889217177, 0.32050192296024294, 0.24570249231351962, 0.07579582758368024, 0.23031711788667789, 0.07159463971132232, 0.02998925490124572, 0.07916283763704762, 0.13390167375966427, 0.05669809832808472, 0.19398435619809937, 0.05645604518752906, 0.026110515351437276, 0.03621540084901837, 0.0758499976608061, 0.035420021552953034, 0.041579598290545326, 0.05064067175431598, 0.046403240262260365, 0.0288613838699436, 0.05868147698140914, 0.03855233674027747, 0.058976290597309994, 0.011675833055989878, 0.008609928115601502, 0.02804482415799172, 0.033354510613266504, 0.04819790081631753, 0.03527806546058386, 0.128090207374865, 0.07293558469222439, 0.015732641125308172, 0.07049927187542762, 0.03321751110976742, 0.030036275462818243, 0.008544509952527382, 0.022649278398603204, 0.014323837033683255, 0.04033633335042865, 0.04387152651625295, 0.026104317700129845, 0.045696769300247395, 0.03440962052874027, 0.01724942530986042, 0.029186942509465644, 0.036388349028364304, 0.018135011459009785, 0.020338657627543135, 0.011033718267665997, 0.026986174916307774, 0.044220322517738234, 0.05757292094189794, 0.13194850195319424, 0.05350877087743533, 0.06224958511490015, 0.024507867074721766, 0.06660838791679952, 0.018181884548656883, 0.06749565562894268, 0.05587928823285526, 0.01771012952010478, 0.0476436706770572, 0.07439530394490688, 0.04914588865733916, 0.01896042331692673, 0.1749337413498471, 0.21798670291900638, 0.20775069572752525, 0.25633663539924934, 0.23731007571181945, 0.26012837225871704, 0.27002294938410487, 0.13823868136011785, 0.15331766658252285, 0.2596968808962453, 0.11767856686586335, 0.16612160049619215, 0.1581496129473371, 0.1348754327984587, 0.12006946599050877, 0.18786574984269758, 0.1572422584098193, 0.1456300049058853, 0.19629765061601517, 0.14435068403761234, 0.10062934139803534, 0.13679226139380088, 0.14624365665499242, 0.13648136759236937, 0.10222150959194669, 0.2538821969421641, 0.12686519447954434, 0.1324414795324687, 0.13850921764969826, 0.13925406961671769, 0.12575429038054523, 0.12214909593063979, 0.1548730855387065, 0.3455035088043059, 0.12796826149907806, 0.12131905498644038, 0.12213010461099687, 0.14986175202554272, 0.07959389232940252, 0.15761583352521544, 0.1537711906336969, 0.14886082750895333, 0.08970231523797398, 0.08361627528023335, 0.1990685446728622, 0.17468817952659824, 0.0781350847213499, 0.1343506319268096, 0.11518060695379974, 0.14262609754598912, 0.20745546076326601, 0.09158605649586647, 0.2417756635094843, 0.14853125648392787, 0.13495691391008516, 0.13484926323496527, 0.23367920199469214, 0.1599821871927669, 0.14804659861951106, 0.4867137992574323, 0.18086094829824664, 0.443766818291718, 0.1750473368672594, 0.3370540799392808, 0.23489933490993517, 0.1968729060383574, 0.21622859241981662, 0.5553248789041274, 0.28762305335652444, 0.24654050057213156, 0.45082402025018975, 0.6883083043559906, 0.9147365607561604, 0.8093416774945875, 0.5602329284433396, 1.3883525854156864, 4.840358745667243, 4.521783840271735, 16.30611748464646, 32.91662070059007, 46.16343359793387, 51.33413730129119, 71.76766980078914, 73.04868452010616, 81.43624167288505, 91.82911842100083, 98.88706268802767, 96.77852984397643, 87.17441035855202, 83.51043024370748, 88.37484390504899, 97.71345815350934, 86.63482558342719, 84.23651587578559, 75.27053463843562, 70.86366545769476, 71.18875934231666, 65.41144540232997, 56.79570436477662, 61.74402929121449, 52.16523654999272, 59.09268356138661, 53.177227666301114, 35.15106554954283, 23.898436638616747, 19.781726752558065, 12.733970842053814, 8.087831687542701, 2.629598148407475, 0.4037834944263582, 0.33140145422470185, 0.22348082504205166, 0.46597766840169513, 0.8065260898682379, 0.12123424139234329, 0.37600235773190377, 0.4699407638080659, 0.1589741227367232, 0.26778205027503355, 0.3232095228327859, 0.28971756838502427, 0.30011289122123874, 0.09914129987479219, 0.136002654570245, 0.12243031148588467, 0.13444689853537467, 0.10848522066108643, 0.15632932675221275, 0.12918991126841115, 0.12471637913897154, 0.15387669626262881, 0.1395929409491439, 0.14736550048955027, 0.16425666669684072, 0.10289994173593099, 0.08293977367781824, 0.14655972921079205, 0.12730538093995664, 0.32850034054248567, 0.0580802818219508, 0.19013766019094377, 0.2032439077212926, 0.11192259589029897, 0.14201595447957516, 0.09100314019428146, 0.12486920601898625, 0.12185971387812208, 0.1167321495050865, 0.1211969635539478, 0.2949845760820374, 0.1330163365890903, 0.13873901338346545, 0.11705762962059629, 0.18467398240200936, 0.16699446575535884, 0.16675316338096896, 0.27760872136681314, 0.13237694428572733, 0.1441717565420174, 0.16873707063496116, 0.17570497738497873, 0.23144723547081794, 0.19281631726170742, 0.16790554348018863, 0.185950959041234, 0.12664002591683982, 0.14647044932409642, 0.15852101237302826, 0.11982955023526184, 0.154021839280763, 0.10495907116320827, 0.0666795268414482, 0.1863264800199578, 0.1697442157854957, 0.14979787561441624, 0.1906678543215798], [0.024949882570053303, 0.040312921703462644, 0.0306123984797347, 0.07379652962328927, 0.058790472140836145, 0.03117619322672967, 0.025858248343631148, 0.01373314206683708, 0.025230921925075596, 0.04079187604328317, 0.023902349264150666, 0.05630641672459822, 0.030803110322824893, 0.06849258116656734, 0.053108654645902496, 0.028260975865827456, 0.050145231202364936, 0.05125289091900472, 0.046139223380915584, 0.05051325218031003, 0.03586632139500111, 0.05773528178613033, 0.03207879993433674, 0.07804889982986836, 0.07598967847204016, 0.04304340462230387, 0.037038056705627716, 0.021990031011462696, 0.061357877923235785, 0.0711234879770106, 0.014822475045108268, 0.04904695223235796, 0.04699854420558099, 0.024773578925599015, 0.009424121573477263, 0.029614009714174657, 0.01690800290464634, 0.14138696565022393, 0.010642406301602963, 0.02875611764348803, 0.06717582924231406, 0.07058027801254103, 0.015603684587404134, 0.013816000221507444, 0.08382688051149731, 0.0281401235805524, 0.07288563575956129, 0.039764119297145836, 0.044850720948870146, 0.056488895037722205, 0.044954227088319684, 0.08516347411298945, 0.10299690548450717, 0.03560194445233192, 0.04510362955531286, 0.029358023349496148, 0.03831261633745125, 0.04186619561345827, 0.054412199214341185, 0.048910515803483226, 0.03716835293978934, 0.06185782690262122, 0.05591045268961499, 0.10963081322129696, 0.05890170044656243, 0.019973540122831063, 0.06348945245507263, 0.21185013946265946, 0.1305999727018418, 0.04640897826081322, 0.06053580046300927, 0.14446003542792413, 0.24301946854158757, 0.1995543669909239, 0.1296550338907588, 0.03633828518251258, 0.2548594340201347, 0.10195108821555492, 0.319519124083942, 0.5969270078405258, 0.21147789734025157, 0.03806434256295043, 0.06473431468851144, 0.2122706604460555, 0.3383331709811765, 0.44819244694325233, 0.9433056342024958, 2.1843002880773237, 2.659568733746006, 2.307298952533353, 2.12259110904509, 2.062667343885668, 1.877584178601542, 2.071366180335322, 2.0428347371278273, 1.143827003336722, 1.0858975182617865, 1.2303021502110267, 0.33487511137800835, 0.4231694106373095, 0.11652918983130686, 0.2252288538241579, 0.030844555679528467, 0.08970998377809603, 0.4991979987150239, 0.49620115468578957, 0.6751425624374421, 0.3614567688876583, 0.11005884952723019, 0.12843289382515416, 0.045680371188228173, 0.11976573511116928, 0.32274677508300353, 0.1694277908292509, 0.06482979988739376, 0.04600269885192956, 0.06308400425158682, 0.021835267844219363, 0.048268407718428684, 0.08791984314279211, 0.06109488759970954, 0.07452174675680938, 0.08351840754790653, 0.014035604113051969, 0.058586830648803906, 0.033637744810191855, 0.07444959659610065, 0.02552947979570637, 0.018548030526407303, 0.02890371597341953, 0.054129248469947815, 0.051301932037477536, 0.03590811915214985, 0.06262412550108087, 0.03022552599319287, 0.046916921367688526, 0.023694266377377416, 0.05336470804327438, 0.0875038190955116, 0.023659189126544425, 0.07377677987660132, 0.045027606820146886, 0.0017063425865114458, 0.06774490999598658, 0.010990258099721565, 0.036905014046257546, 0.00916962524981148, 0.02653816095252912, 0.026048109829125386, 0.04221820152334629, 0.04884394276286325, 0.011188860648431847, 0.036050002466166214, 0.09469432801368738, 0.044252885084959774, 0.0463258768732269, 0.027799088049740083, 0.060306234555619384, 0.022315871188296907, 0.05585921672923912, 0.04599853133362147, 0.025912765075542757, 0.01669323207029412, 0.06605071421231955, 0.02699110469210052, 0.07926183151862315, 0.06501075751598805, 0.02500385154909905, 0.054312986997707244, 0.012797414505433653, 0.039490752312685215, 0.053580790803196936, 0.045595626542044264, 0.04806360177275154, 0.03181485200090514, 0.06304599096878402, 0.08351177322648226, 0.044122745898822625, 0.0647621390019213, 0.0797106134855459, 0.016165985462946758, 0.03284456035602958, 0.06592037967376171, 0.03254702329755791, 0.059192737248996576, 0.02600469179601679, 0.057400420923987706, 0.022895213689715154, 0.026999924279328798, 0.05259489693168191, 0.005265686674148686, 0.049953375973047755, 0.07510666254787676, 0.06284818323629518, 0.0225495720552581, 0.06688067854772653, 0.039926353736870715, 0.01249715879244069, 0.03088553180737842, 0.03285022174579001, 0.04975872452280695, 0.03973569360471541, 0.027954354919793627, 0.0506454712951616, 0.057711138525196624, 0.07527800577302134, 0.05735375084764054, 0.050142094072315006, 0.012434883505075931, 0.048206159244141275, 0.014077745652156732, 0.07794357040115903, 0.013177612450935189, 0.08269117048550999, 0.046470380207944306, 0.02817830348747873, 0.02920504516711639, 0.04138944760685967, 0.026848602762085297, 0.012250468904723325, 0.14265706281988852, 0.0334009355414779, 0.0032882952373549947, 0.04645425022669858, 0.01804563198088398, 0.015584510364269298, 0.01110292569313559, 0.1151298459679369, 0.09014496084062323, 0.00870048258108117, 0.05106215800849661, 0.07461592960622042, 0.05747018472081231, 0.03926992746851137, 0.030911423663999286, 0.03482472910095127, 0.05616055741425484, 0.08957843115973858, 0.02726572231509753, 0.12994213300126214, 0.07891130032798938, 0.09728453257271359, 0.08356412767522758, 0.10683022559650483, 0.10776618585711527, 0.10975845113036134, 0.055603883454516057, 0.007616372407233764, 0.12167785992665638, 0.26804521679878235, 0.19797130758243223, 0.07542531681998123, 0.3761595283304492, 0.3022163235131772, 0.5848913375408419, 0.5581939088240747, 0.6252630679838119, 0.1833644470260028, 0.3096554049801442, 1.047379965743711, 1.2880128405747877, 2.9323747273414367, 5.540767562004828, 8.73372789352171, 8.682575283511992, 6.14037391639525, 7.402469573482391, 9.48231420209331, 6.521797449358049, 6.548838759622266, 5.466003264150312, 4.827243810699833, 3.8979855323991472, 3.9678517705009835, 2.7914402898280852, 1.2505597212622244, 0.06456616605001111, 0.4711749927411157, 0.1773686292431047, 0.24613496426853443, 0.30429527163505554, 0.08913187850867549, 0.27777100943269273, 0.4171813916294806, 0.0699802473067276, 0.14207986153421864, 0.039288807705405264, 0.10375760781067996, 0.057619882131656336, 0.11238185794002588, 0.1025708303636601, 0.16807635044378622, 0.15081042934569622, 0.04100105635100796, 0.07930510782546575, 0.19350833980546844, 0.029880640870561043, 0.028846286192175843, 0.031010204956175822, 0.02513599022471857, 0.06103021062670216, 0.0014478210693097584, 0.05909439071171707, 0.07652905799688832, 0.05592557143480067, 0.03758228173659694, 0.04879175685346127, 0.028006330155016437, 0.10234635128008743, 0.037004180297616034, 0.01816527193201886, 0.06202827380489438, 0.06483308640458892, 0.025238464060690136, 0.060629163598341335, 0.11909811246779659, 0.04019235095549976, 0.023905507461618514, 0.019645367208267414, 0.04038929300863416, 0.10085945122785146, 0.03635971649219433, 0.05542316714361791, 0.03867377316759479, 0.08062562124142725, 0.044218686920019894, 0.04547978255657419, 0.055663404655793024, 0.033633178926163146, 0.05309650449142341, 0.07476491072485525, 0.03972600259247326, 0.014932888424805096, 0.09383565070287836, 0.024982247869634343, 0.08128863203549579, 0.027957133903738954, 0.03040087585818143, 0.05779725063832537, 0.05728141299539036, 0.016175529003263484, 0.01358235776875048, 0.043401868653393565, 0.006806125259777952, 0.0111738367066268, 0.038684613311723355, 0.05714213821075617, 0.019475540837212917, 0.04531239617555853, 0.04211796274889381, 0.03059011106679757, 0.06361082376491639, 0.2548174983671596, 0.16093878586205745, 0.12333416500158849, 0.19652203776903693, 0.18161390547550496, 0.10412922940186917, 0.12532515090800103, 0.09981964008822557, 0.20690228399490157, 0.1525678503657541, 0.13257644890296844, 0.12319181820437794, 0.10968768758879555, 0.19734867728285252, 0.1185263887107853, 0.1589834077223655, 0.1707759217148827, 0.13315116806376365, 0.09941891481679294, 0.14385418245388618, 0.16139555812603043, 0.14501624590446874, 0.1128135255027202, 0.11791674360152214, 0.1518928349739121, 0.12653759996136352, 0.18214638254815535, 0.11629734098190263, 0.1236785445061903, 0.13663700601506618, 0.14061254268932727, 0.09144026230299666, 0.09470200421468866, 0.1625526420051052, 0.09377463946058866, 0.13684168938667546, 0.10597745482359203, 0.22220816913872, 0.1812552537528738, 0.1288748193051546, 0.08868061441687808, 0.14358081163898592, 0.20359742665483108, 0.06788851317739295, 0.2704314887523651, 0.12542817441205825, 0.2843866076680922, 0.12249125378026117, 0.1585865588558297, 0.19333330403652885, 0.09720568680354665, 0.26383614588168364, 0.16586039515752948, 0.1472982686133154, 0.10657083588622271, 0.2172701195963929, 0.17346438471107714, 0.1622134182722338, 0.13936348229406342, 0.10075972956274787, 0.19629201220889247, 0.1559737547030372, 0.15955500124442965, 0.2106333313690078, 0.16258186059853724, 0.1789404731243849, 0.1857528180604981, 0.5568219372822393, 0.2834018476067051, 0.21746895005626066, 0.18530439615489977, 0.26363126332721404, 0.38319218483182693, 0.5023879275446939, 0.401821359391174, 0.15616398965639455, 0.48315578050190405, 0.3153797671679528, 0.860259987173542, 0.830924948376994, 0.4007255472242833, 0.36016777998978095, 0.16345952156810992, 0.35162026122693096, 0.48575671029187023, 0.8580717336266273, 2.2305845012587886, 3.7226592629186572, 4.384796532892413, 3.1160752571398214, 3.7503497254463936, 5.1293501546305995, 3.6722747020183073, 3.734879407190508, 2.614666175457739, 2.2441990481268976, 1.785485456066747, 2.3707173043681733, 1.6598823378163001, 0.6020216151110588, 0.15696591517377287, 0.1942226095425506, 0.09295414397192579, 0.30003536312330154, 0.6766806218412615, 0.7767694575652, 0.961794093731911, 0.5409693105086204, 0.2737147577347294, 0.2097572791840761, 0.18720841576014796, 0.23902523932197403, 0.34404570477143415, 0.40500773357287534, 0.15829224319707963, 0.2964486926794052, 0.3223250590024456, 0.2235267903175085, 0.15259893821372142, 0.3173367234487688, 0.13329418135746834, 0.3694627554185929, 0.19121695550218706, 0.07360883042096131, 0.178193460789419, 0.10569924999388958, 0.16167832117888237, 0.13672060152936366, 0.2703662487047334, 0.11122003963757908, 0.2493244640889668, 0.14372217018277417, 0.22483218881872394, 0.18156460005669825, 0.1765821327365214, 0.12021715242055156, 0.1289630879557902, 0.13980168458675185, 0.1761754013357624, 0.14793438206036247, 0.1880600450620536, 0.07872718641714704, 0.125592929281054, 0.19776994903241435, 0.13668836454950994, 0.3181954773683702, 0.10503345063977665, 0.14656207343984037, 0.15671345855920546, 0.10297756176441909, 0.17538467602383706, 0.11231474863785891, 0.10795868843072846, 0.1863378794082711, 0.21250868396412945, 0.1374529969067343, 0.1055649547807632, 0.1638842560350895, 0.13967017793366987, 0.21052656935588007, 0.12494486486238819, 0.12247128952895442, 0.17323449704675906, 0.2005197297060682, 0.11788932531471215, 0.11401873502519824, 0.13519231740745807, 0.12185727771852287, 0.12747820271479507, 0.14784081208129085, 0.1694088378140042, 0.14098562750845187, 0.19013232821899076, 0.16333612012526683, 0.10847958225396373, 0.25030911689804447], [0.012176336491510514, 0.025246184311747074, 0.08048360386202413, 0.01437435287141031, 0.04290464311657895, 0.04732863617039496, 0.01049807533666852, 0.04207130033342589, 0.05714822094887496, 0.09093444509011123, 0.028335684760203286, 0.017131997437606898, 0.04804553358905739, 0.09928853431295964, 0.044390773250451016, 0.01894488513860251, 0.07783565925614488, 0.02886594209309307, 0.03458834501103528, 0.06004682186269953, 0.036470646023630135, 0.021930651536451715, 0.005623275928589846, 0.03257299750863064, 0.00924255490498317, 0.08110459473344588, 0.040509787147804614, 0.06600275710825959, 0.0578716722497296, 0.00800250514012371, 0.017288574318010962, 0.053863791343305385, 0.050792717224647926, 0.01430549497355617, 0.0045985734792456275, 0.005944032154436554, 0.09335790295153858, 0.044375014821848566, 0.13076601459855033, 0.03215977734315299, 0.016068883818544207, 0.020498247148709434, 0.05145602679300693, 0.02725348214528734, 0.03590340771141552, 0.018020714971146757, 0.03216470711894574, 0.014161680160360712, 0.0661899813360745, 0.08022210740995023, 0.036251981547402765, 0.05033007672717495, 0.03720112235075043, 0.1032533074518846, 0.028806922679406502, 0.11284923286087091, 0.03680019789645749, 0.05542741127071842, 0.02604331220349958, 0.011556059039468247, 0.02824107481677446, 0.0946785849068434, 0.09745585281522044, 0.04206091984205189, 0.1366271081590845, 0.034289880986175234, 0.036484975698253805, 0.16628649326101427, 0.14764093974184606, 0.07361738762307553, 0.09481177695335881, 0.09274494068156328, 0.061141109514621005, 0.09743718325250572, 0.05090976396815912, 0.055548050966594494, 0.04681328882373149, 0.08426216400919423, 0.15829181418784205, 0.4006831059532781, 0.12427793935902658, 0.10876151027097818, 0.0560671444832077, 0.040116512081435615, 0.05376234598037216, 0.09180255294326814, 0.026971343454093705, 0.07615867746813644, 0.1907754743531827, 0.17630565160464856, 0.11242526448181561, 0.09279672822524464, 0.10778382886201145, 0.23133658173103488, 0.21748131471535853, 0.1649512020089934, 0.14150299732723545, 0.07348994123599223, 0.0903286687248657, 0.02159732093493785, 0.10800815472799925, 0.0963648286978564, 0.018261153581401995, 0.07101526273594749, 0.14315115888753246, 0.1587191073884887, 0.06188664329989303, 0.05918854674805076, 0.1148732141741822, 0.05244635248316392, 0.07092474944769375, 0.023195870641258456, 0.01768068684595487, 0.12481238527764237, 0.05878936131334594, 0.08286270523263563, 0.11821364097657705, 0.018739117752580393, 0.047852931424014034, 0.0073659234218329435, 0.06539593120255778, 0.07405012004798459, 0.11850427941329057, 0.05255752333229589, 0.021531694012904362, 0.10816276659287753, 0.030840527972266562, 0.009390833137947465, 0.01889771518988475, 0.006784402357880027, 0.05057315259510952, 0.09124675615420265, 0.05927168260959368, 0.08187740890970154, 0.04556553077793891, 0.044354200212945866, 0.0660155201330781, 0.012558016817145532, 0.07123408042975972, 0.05446583302992006, 0.04291025088018468, 0.05905133657037251, 0.047692428342998035, 0.07803492638612948, 0.02609146274476042, 0.04311159027800445, 0.05505756317307392, 0.026259619044139985, 0.07743484971504058, 0.007310195313391066, 0.03628615289926529, 0.06756629659644059, 0.08828594124004727, 0.041854911138333624, 0.054338601147455555, 0.009494740515947342, 0.02129111367638313, 0.04182674591579745, 0.0688167282890889, 0.027110051333663926, 0.03167867221148505, 0.028306816651996587, 0.04408337664039385, 0.026988247184142954, 0.045630583134029186, 0.033669774946306026, 0.04917867722049837, 0.019793601391176065, 0.0501694395807722, 0.04898930411605586, 0.05611848003501373, 0.08138852990082196, 0.030997288713772452, 0.017990096352033077, 0.03152673207824269, 0.012963415224916272, 0.024958721309479688, 0.023570838121456966, 0.08472865792892634, 0.019567873584286823, 0.1826875010925916, 0.0264570111739299, 0.07293409082077204, 0.043569553808699694, 0.021779006347060207, 0.09561583985604587, 0.06797971594477854, 0.15897917891702346, 0.013782611236937586, 0.042522583577421405, 0.05593214829963061, 0.018821995059448867, 0.045909684286603046, 0.03716434246950573, 0.04207631054845068, 0.04368327573061951, 0.005425553902187535, 0.017843624171350273, 0.0942103902719194, 0.0686268380752975, 0.05408559294958269, 0.033039625493749496, 0.05289465181469437, 0.053377677911832455, 0.015865377349508627, 0.09814190753405133, 0.02892308842180477, 0.043577080622555754, 0.03789513289267498, 0.028449785895645622, 0.007501974891525724, 0.053030992482578566, 0.027743031481100668, 0.025441239873367934, 0.0648441257315778, 0.042677226085816665, 0.079040524039057, 0.039307576859550136, 0.05562159923776504, 0.021455807258344946, 0.06041811403608131, 0.015421571123654084, 0.0633563791521855, 0.06298858417017807, 0.07442607769682523, 0.10968196491200118, 0.06066961687118296, 0.038211328022542505, 0.0339590803900313, 0.08359746016081303, 0.012347751537397986, 0.044596395079767516, 0.010424153597634888, 0.04756383665446793, 0.06727521382873097, 0.052910942674404195, 0.07225008155669897, 0.009111079853028059, 0.04554329890637629, 0.009791401361355619, 0.04246254526679555, 0.053076459800884615, 0.07527823559939861, 0.2729832663411095, 0.05908580286608589, 0.037530011557523286, 0.15894657421496608, 0.15582468931473073, 0.06927673344410236, 0.1291031901153826, 0.12534169840716547, 0.07974884893384673, 0.1057311115906604, 0.1416613936664597, 0.13019966111788828, 0.11352232537202298, 0.14664740031284673, 0.02682265919452954, 0.1294782974066273, 0.02427921089674196, 0.07322204794975058, 0.19934497983945956, 0.09205401364353397, 0.3078808695558579, 0.11218863524376385, 0.09925768395224888, 0.13826817574520267, 0.1782803504817909, 0.08451763134930404, 0.3421157147855528, 0.15537357077963893, 0.2307673784032945, 0.12104966016786715, 0.2158683012690275, 0.1705731229195672, 0.026379553939125715, 0.06805899072318308, 0.06869429211703039, 0.03468036749249986, 0.07432765838119292, 0.10792240650663454, 0.0379238611898355, 0.15973354569606243, 0.10659964079217565, 0.03974180698635117, 0.05338530048667904, 0.05546024962959271, 0.10353443107657856, 0.06538867634991485, 0.12130565610864472, 0.057225488576917886, 0.08995481015693757, 0.09066203954599558, 0.027027018893990788, 0.035940233557935686, 0.06737493549383457, 0.038406619156200084, 0.06463655420849401, 0.006006526255664686, 0.08390303731205002, 0.03637505740287804, 0.03101052671310402, 0.00863618482159631, 0.041801346270667936, 0.018810080477006493, 0.03310495364149252, 0.020666924387877508, 0.02353779483406294, 0.08091456662382811, 0.057985968737592625, 0.05526329991557906, 0.03448486951510272, 0.09143816322208413, 0.029535292264735027, 0.0514897384921149, 0.014668688639968395, 0.020344499047965776, 0.023597275815723885, 0.046232578855368404, 0.09512684593397765, 0.024469700574334112, 0.04040846052849966, 0.01735832279307708, 0.059175523253338, 0.049249819975586674, 0.045736364554613836, 0.0554686957489579, 0.01278696219331675, 0.03929505515242777, 0.004403327832058553, 0.042571027147313284, 0.03409478137449872, 0.015997180861661273, 0.06805046416458584, 0.041650147327492316, 0.02331803293688403, 0.05063780275503955, 0.022016060763909932, 0.07270452491338215, 0.06491564770018862, 0.05235797658021893, 0.06307393785626178, 0.020618492309304497, 0.03460249465499674, 0.021818819936485063, 0.027899332569851994, 0.04633626119504052, 0.02985358264507546, 0.019981907718184016, 0.05318041027133023, 0.007656278406014487, 0.06618978981409343, 0.07141434857922216, 0.09866369001927877, 0.1386919909066731, 0.13819941169311925, 0.19836708392587402, 0.1371470826768106, 0.3029870386085203, 0.07376092951744795, 0.1333241507170662, 0.21863361820578578, 0.14995003599793683, 0.31208120707061987, 0.1413157654385413, 0.17292093725935107, 0.16045945996959365, 0.14534840630667825, 0.17610654535312809, 0.1127946261136282, 0.08737457240180624, 0.2198124283383931, 0.12441807982301521, 0.13258348159011335, 0.11894821970453186, 0.13334206185273587, 0.245738283941342, 0.16571902129198277, 0.15589650239675276, 0.19127203722394284, 0.1252751636709417, 0.1907366336954217, 0.13605085682244072, 0.21032087474821076, 0.10626912747900333, 0.11825546937724275, 0.08957715179290503, 0.15023840681439446, 0.19912267644559184, 0.1230212487280369, 0.2038193623264951, 0.13363518241432407, 0.26402285683058924, 0.11733390390872957, 0.11365851282232231, 0.12592793186946263, 0.16291823448433032, 0.07080728518626384, 0.1678146701306105, 0.1342837677727784, 0.10702868833416894, 0.20647252399113872, 0.12623960708057688, 0.15368407111494772, 0.19108909542762464, 0.17367954816549055, 0.07839826656685722, 0.2721980875057559, 0.19752637903776862, 0.16657665672321476, 0.12456425705984717, 0.15662247795731793, 0.13094347120533067, 0.13224746010476543, 0.28096369617889005, 0.20390476580829392, 0.19918616981275622, 0.1526348217720947, 0.12851052917540073, 0.47678968178168424, 0.260686329415729, 0.0974118717074875, 0.26822166216950266, 0.4010146381633897, 0.4764557900207658, 0.4121796648588873, 0.2692006918932161, 0.1811481546610594, 0.16468768308479942, 0.23823174077176282, 0.5187728628516197, 0.5955901537691394, 0.3860697030059753, 0.24614624108277985, 0.17011716270879393, 0.1319506623211407, 0.18937541802804317, 0.15298542957152092, 0.15652331553639906, 0.3915741060289645, 0.2858844627776454, 0.23160537134014794, 0.19469790581253268, 0.23669490710862223, 0.36674970100002907, 0.4997314104149419, 0.26305847470798804, 0.3578427950701406, 0.31319258614413203, 0.3215362335885725, 0.22278694856551387, 0.13078604013689105, 0.18721777735458267, 0.17966366012490567, 0.12049544918080493, 0.20341283010859645, 0.29048393210095746, 0.41378179985669356, 0.35832604333277673, 0.21372743792110876, 0.2029553683654916, 0.06552600527122136, 0.18708450869927484, 0.2735784553712414, 0.29590259456346113, 0.3385233140039829, 0.1320819238260869, 0.1609106091482024, 0.18031048348113415, 0.1457472010365417, 0.1664670295412502, 0.2811273019159994, 0.12424508950883344, 0.24657754858414976, 0.15744430643896903, 0.1659350274431129, 0.08149536086186286, 0.17921745987428775, 0.13528239402559497, 0.14056381949734303, 0.15675663527461792, 0.09973104201978254, 0.12042997930679591, 0.17055112087438185, 0.2281243137774929, 0.19712251280584644, 0.37882729163092954, 0.18901653647903474, 0.14405086786756593, 0.07062419783324003, 0.13905363037220894, 0.07452497964784985, 0.13720369657441495, 0.12658401722869567, 0.17075670822974176, 0.19975745689965066, 0.09217634256328307, 0.1510622577681657, 0.09572775764090401, 0.1466528548588676, 0.17479930824089437, 0.13805590810314303, 0.08618676073608861, 0.18218876253212654, 0.23126859908863423, 0.11884603889719134, 0.23338802729643163, 0.06368464782773968, 0.19562424400881415, 0.14851303891308848, 0.12256097544224993, 0.1713161822408438, 0.09197190433980958, 0.11473120445565832, 0.13146361426240014, 0.12774870836085853, 0.22349170349057645, 0.1894537581791801, 0.11615585220316726, 0.147267808957446, 0.10588204623350214, 0.1305813414435233, 0.25192764617743035, 0.15682356071568307, 0.1394784720914979, 0.1390168275083265, 0.09603371783610314, 0.14793429012981155], [0.0509810101451172, 0.06820211893007641, 0.062343404072547154, 0.07551658087440076, 0.024472437423443603, 0.028593356518315214, 0.015847642414061534, 0.03737475234834898, 0.06174400921971087, 0.015956300494801855, 0.014702174343138695, 0.03964120432013466, 0.04634789807061034, 0.03459594843368377, 0.016035327252240914, 0.03004716540266189, 0.04230046021421591, 0.021976130346076626, 0.04581013499128242, 0.03943838637262102, 0.10404129782992025, 0.06091948027812666, 0.055749279281665245, 0.03798481114509125, 0.02264121915363977, 0.039239575064951376, 0.0860064083169545, 0.012081959247288686, 0.011824547001461109, 0.07464004605407677, 0.016952271295350888, 0.011580398610432543, 0.029373228279573303, 0.022240616456275026, 0.023907637186048013, 0.06536298176093448, 0.05520659791786344, 0.007454058964691697, 0.024406825823168603, 0.0214993248828837, 0.06741053559967587, 0.020308749554979227, 0.05161838763723931, 0.07079047721720512, 0.03743112875869678, 0.04632739372731698, 0.04135639857380621, 0.04409567618201818, 0.006872897483258238, 0.021844616032115394, 0.0654479255899787, 0.02734414099024669, 0.021798773330726454, 0.09199155449506738, 0.024012413116232045, 0.034982868800720865, 0.03909949971843631, 0.04489648704146666, 0.047138512299786654, 0.07927851691361397, 0.02185077729424642, 0.013250002971730165, 0.026883513388794758, 0.03438053600069496, 0.04850310641491125, 0.03173686425021339, 0.036113537968166416, 0.05766566737645096, 0.0998730517383064, 0.005127214845420132, 0.03753143265062282, 0.03812694726812263, 0.039654143545175755, 0.04713950055320898, 0.12722016131925967, 0.08117221731452212, 0.02105028436128651, 0.05307121209860329, 0.10615297322792393, 0.038178213872015476, 0.12616376437607313, 0.012872040087747718, 0.03665066136407756, 0.011481874915320548, 0.08431518495443367, 0.0825046663803439, 0.06246040485078289, 0.04160855258364351, 0.14977889195565255, 0.03076399004297151, 0.03416769762313174, 0.044785350666291295, 0.05884715115591403, 0.1270324544560525, 0.07929812876447555, 0.050624886512636184, 0.11533638327232293, 0.0194179444318457, 0.015222282926251572, 0.01112457438026585, 0.0983053753753343, 0.10452679073017453, 0.03727581592336778, 0.05065295597418182, 0.16204022111431246, 0.17070977768350035, 0.07223711168814091, 0.08721271334516426, 0.060608115332621726, 0.04630212431713458, 0.05220102048629234, 0.05063471159026508, 0.06494940919501167, 0.08575712330639364, 0.05388085212137911, 0.06912539277466075, 0.1399537836832385, 0.03783762267219924, 0.04589600961715464, 0.027769819660592946, 0.027723410054140037, 0.08379784577916707, 0.026768433576029156, 0.03874611101984497, 0.053365684805377844, 0.1067707465300637, 0.02412187750451267, 0.03844039214234199, 0.05084633954890794, 0.030567325696709658, 0.015460842705872512, 0.0662020625426404, 0.031816545055217804, 0.07330179004178894, 0.025275625070677172, 0.018119530737279885, 0.05727534940946968, 0.038241542530276125, 0.03230063409935082, 0.06215229960939577, 0.02857001764970201, 0.022098769531435063, 0.06696102584922506, 0.029827683127575347, 0.012169544164451861, 0.04270401235008913, 0.009257121109253457, 0.062087465588363915, 0.07379305924499228, 0.027327905671911377, 0.005190649798380272, 0.047850974069367495, 0.038182235833617954, 0.11207800448661852, 0.017459973084530043, 0.04435272932413124, 0.0421182653536239, 0.008078157759061264, 0.05806740771438326, 0.05351953824321109, 0.03617032040511409, 0.04616624713244458, 0.01158503152715463, 0.06083331453884321, 0.017393413450448744, 0.07257597535968789, 0.028032396296640078, 0.05421990348446754, 0.06556417177160902, 0.06438643416209568, 0.02278727956206328, 0.05520589694741273, 0.050046980426075964, 0.03685177859639929, 0.0409569833127241, 0.05074617355280826, 0.03033136103993222, 0.08991865846779078, 0.06056926318354184, 0.024025664522102284, 0.00863151360047801, 0.05182250027334498, 0.0849949271087685, 0.01895166501673239, 0.0959019507131269, 0.010099251878507918, 0.06507403637853361, 0.029711389065449758, 0.015269675998077279, 0.028337232257810333, 0.032053547761132645, 0.006237477824587616, 0.028704119425627495, 0.056409930524926995, 0.03453701328966887, 0.06358086972707702, 0.05000936167855417, 0.05839485667585846, 0.018534346280859846, 0.043776861031449614, 0.018180823516881755, 0.02769387161899959, 0.0192606627505513, 0.04867612354217037, 0.0955159419907197, 0.050708133456928116, 0.029106597123186917, 0.07738630272327893, 0.05311330096916326, 0.051367355946211085, 0.01422181614719692, 0.03906419838688547, 0.06515164108526322, 0.0114901888845188, 0.011860002508206714, 0.022805598639552633, 0.06388178523329478, 0.014483864182576299, 0.057695832088469505, 0.05896252782775029, 0.03099163115445164, 0.08087520502627858, 0.0504421400687387, 0.04184673698018155, 0.014980235531355345, 0.010654016364095433, 0.04000367116062872, 0.056388131493041595, 0.01008908684936262, 0.015448911844061749, 0.03243168109967824, 0.049976442880447836, 0.04580357344821096, 0.0512357420408197, 0.07723337625183406, 0.01679238299989412, 0.047380435205395185, 0.024923921765519247, 0.042453470955332445, 0.0443014090940837, 0.02831684665814523, 0.04089915899619941, 0.17988850693068198, 0.02997165977684481, 0.056871080981387254, 0.031705351223448114, 0.12454040874276431, 0.1636435358875221, 0.05177248622320833, 0.057900358412054286, 0.12375126157196299, 0.05557989341116721, 0.012118193290887341, 0.07260121029591368, 0.28266851760206685, 0.033940560214461825, 0.09174465967883026, 0.06433093875286079, 0.05675731309419198, 0.028599854859132922, 0.056124409555547664, 0.20014502078054414, 0.10279839678156762, 0.06173129982104706, 0.1704894048312018, 0.01537690436722891, 0.02561278611181244, 0.04784700573391972, 0.04087759745157054, 0.09334774462566262, 0.015737631230524952, 0.012470453925010179, 0.048276708281088265, 0.055263365033052625, 0.06233186295796787, 0.027747606941228433, 0.10319899947893235, 0.06775308415413865, 0.026670812907057907, 0.049073730835751186, 0.08878301738971665, 0.042278799078156876, 0.10032919581018149, 0.06881641419303995, 0.04700345865961525, 0.05446771377577417, 0.04255010911654081, 0.06580800989702826, 0.08155776638417475, 0.00652322814153928, 0.041472403437740384, 0.1544254603645494, 0.08247808312937137, 0.033470304803021496, 0.03042838224510272, 0.07836031457108837, 0.012422730477767126, 0.00716417751860835, 0.035562716920169136, 0.042162572048724666, 0.03594510204669449, 0.05511625316895305, 0.11394627076844055, 0.05293836862209344, 0.07907472986487613, 0.040308160467013236, 0.021466528658845255, 0.0467636616479966, 0.032226300588057886, 0.05815399097158544, 0.007010880930935063, 0.024938559790532437, 0.07513458645271678, 0.009854169817821634, 0.016675851450512008, 0.06890416956476628, 0.034697359322660395, 0.07225675418251945, 0.02939064528853182, 0.022089674152554046, 0.04839068684246271, 0.023690255907093807, 0.0080913009550122, 0.08701044315051648, 0.08343597648725395, 0.027536385009185444, 0.02755804039958504, 0.029106978251929247, 0.0648884209353597, 0.06797744832452267, 0.028818233967608506, 0.04315609998640515, 0.05942212312572426, 0.022892116779281248, 0.03024360375298608, 0.005352790392334423, 0.03656479822952421, 0.02988660678027138, 0.022532396363995733, 0.051199904447721864, 0.013585244005005206, 0.11133607897546985, 0.020035350011781822, 0.05457432257131704, 0.04992056442725082, 0.07286281400029698, 0.01562959751144292, 0.027153762395403562, 0.0065684134437282, 0.04310809308663011, 0.07254232111717425, 0.12571164992667977, 0.13401340002254133, 0.21788637604444258, 0.1736818617510219, 0.11956490516181915, 0.0530641794114584, 0.20400009778959138, 0.16873619729472747, 0.21200102814022573, 0.1895314701382191, 0.11375235859304668, 0.10587546553823257, 0.14475427447788178, 0.22992391559866168, 0.14271615884236752, 0.05982066887701231, 0.1705428624465581, 0.15445510796721906, 0.1379652186146667, 0.1430513682745157, 0.16161093608506266, 0.13414415590945752, 0.15156055199763468, 0.20659902042919592, 0.16090683999561495, 0.12976581020460976, 0.12776849641194268, 0.14501794661966064, 0.13169943144725216, 0.16597958311678904, 0.21560473637955807, 0.07805394834928936, 0.0731919636769641, 0.17365694857172428, 0.14083524444891563, 0.06821877368155026, 0.12946875195109075, 0.23509249631916326, 0.0782649979115494, 0.05382780053262269, 0.10207767658416303, 0.21154457763318094, 0.10806833859533073, 0.18962894716570455, 0.24489957088183975, 0.1533715225635998, 0.14085012187640514, 0.19302087805924878, 0.10655701566006869, 0.13613596919082827, 0.15017474490788676, 0.13231026399279797, 0.1150484644477406, 0.04435489735295696, 0.18811696539482764, 0.14535966779916518, 0.15860664568120436, 0.15390542455978934, 0.11244249379923267, 0.23909173575380158, 0.19145868688581452, 0.20830177341497716, 0.14464820194388592, 0.10602988588112978, 0.10101762540157765, 0.16364421004489546, 0.1465296679206433, 0.24499206833781736, 0.2553317731907291, 0.31447820425514256, 0.09041413349369842, 0.23773491743110844, 0.293527415563022, 0.19990374904967126, 0.25059872877693945, 0.16723834218517428, 0.11508673820043765, 0.1232261925695404, 0.19693186416501002, 0.38683885528195294, 0.28696041794553884, 0.4051131472712563, 0.20907812691744299, 0.13014689298166385, 0.272948608523415, 0.15166901472595432, 0.2498803374868247, 0.20768959255468464, 0.15866114517613766, 0.2320637677105204, 0.15038195636964616, 0.1681772748669309, 0.1253351330336544, 0.22788697973855082, 0.1956566495280112, 0.15473001095796787, 0.11855577584356071, 0.21322663092324812, 0.16208797903551211, 0.09614246401695475, 0.16360538470889294, 0.2604408748447895, 0.157218616936476, 0.16027858661067101, 0.2645868201169276, 0.4750616632161602, 0.33858031094554936, 0.2732465860824431, 0.250775465261071, 0.15761287642582772, 0.17423001298260304, 0.1665964064699027, 0.108643532730639, 0.21596757094225577, 0.20351226832116806, 0.18517816018673683, 0.29678448433837584, 0.2595410279689297, 0.1695497060615209, 0.12365815890652519, 0.17216022727229904, 0.09459521155804397, 0.21485346459573318, 0.1881806732666108, 0.11976101600955572, 0.15644857599850626, 0.17569019188804014, 0.2681113761519232, 0.16737976201599644, 0.1637260588787256, 0.1506715835702996, 0.1864421286530072, 0.12706744169155437, 0.12796901226524385, 0.185703436032899, 0.09888911139099829, 0.1438270016543327, 0.17707396118390947, 0.1577512165831943, 0.1028942343808951, 0.1266252404199012, 0.15944860695350557, 0.15590333590103736, 0.18503065761779586, 0.057890839769595095, 0.0944471880493145, 0.1722556818276644, 0.05686142061266208, 0.22217366453861037, 0.221618281437024, 0.17575648913700737, 0.15238169100015395, 0.22246349092212417, 0.1486371758003389, 0.22105079414623402, 0.0790110296539722, 0.11293645963192948, 0.1682931226828406, 0.11925805630462787, 0.11576946043679792, 0.20537660457193854, 0.20694458737008034, 0.16330582900874077, 0.14256435085929212, 0.2920246574907534, 0.11141647990312308, 0.15893709004646348, 0.11704995341959501, 0.13975550480667623, 0.21440608456971186, 0.150267640729585, 0.09682951465008721, 0.19823249759933642, 0.06263050318305051, 0.15038482153848295, 0.17269769923821573, 0.18646134213814813], [0.04780715000965903, 0.02518054015273529, 0.13805812975812343, 0.02853903896926392, 0.039059456302634174, 0.04330922947114995, 0.01139548509531925, 0.005358751992800183, 0.057106055469522556, 0.03761517372162592, 0.02690517452485379, 0.036798543146541046, 0.13004272034572018, 0.02662086972005425, 0.00784733786150032, 0.003139492952369995, 0.014416640924830592, 0.024438867450601632, 0.11915947611053145, 0.05639245605937416, 0.04739409455308511, 0.0035002758358454998, 0.020071195265758904, 0.015336559304306585, 0.01390445464846468, 0.03301732467427369, 0.010342581513067408, 0.04756999600137915, 0.02473057649518934, 0.05428050486971775, 0.006789053469190315, 0.029212068278162234, 0.023362893130510085, 0.008909853453177118, 0.015183254576949103, 0.07726940536691297, 0.04388636563934627, 0.028660814390487732, 0.09264639879186308, 0.028195117202196873, 0.025894331084864757, 0.035935449338848555, 0.04521280474540207, 0.02234756041528477, 0.07287001522678523, 0.01789477394683467, 0.020725849955793352, 0.046518689712449435, 0.025477380071195866, 0.015182062352616942, 0.010651797581944736, 0.11104756260230658, 0.013271808706884904, 0.03931407711558765, 0.03179977156011568, 0.03243279192716845, 0.05870229542075146, 0.02851132573860307, 0.07126623313994178, 0.030238040039435993, 0.028174009564663136, 0.037848405359733495, 0.09086263200808918, 0.04167193869849847, 0.07077210642878087, 0.032354742889442754, 0.03609358903861815, 0.04824050679622639, 0.10544177550341814, 0.0334372136351322, 0.042169018678607485, 0.021362846319173134, 0.1799399114304012, 0.09068577294988979, 0.12869310324951527, 0.0639462745147607, 0.043025669686856775, 0.005133563799092607, 0.037761442889008796, 0.057505562661155585, 0.09787078901764848, 0.08915145971602009, 0.05906615654126771, 0.02256759618889661, 0.05511144979766781, 0.07157456820770618, 0.0876271669122, 0.014426093492206308, 0.05050870544847943, 0.030859582494163228, 0.030109752870855794, 0.044982200788874785, 0.08943136526091446, 0.04761638262519433, 0.026816361951791955, 0.09211427411965786, 0.06466944236308336, 0.09458381216973068, 0.016916412634835128, 0.005707484792031709, 0.11944724171752892, 0.11338541013819557, 0.02346912462775025, 0.05520038494479753, 0.15703939832746983, 0.07340703520082659, 0.04683768106324058, 0.04003269823207971, 0.10754918379168357, 0.003880232942455839, 0.007139898755873043, 0.06280800958554592, 0.08420642345182358, 0.05938076203869236, 0.019365459748153246, 0.00969084944846409, 0.07313576346683888, 0.057756479438995166, 0.02941606791629907, 0.08207135172861238, 0.014639907674263082, 0.11665578586079421, 0.037838208729461316, 0.006865030239080831, 0.08201088440874893, 0.04089297283621084, 0.03703913305916133, 0.028712075248721148, 0.1144224020742601, 0.02646115762482007, 0.039212106982426304, 0.06611498898916668, 0.0412040198552272, 0.01333050923647299, 0.03400291594105863, 0.06718723629150661, 0.032284596048656015, 0.011528555525376672, 0.02405039958595749, 0.026503455254339406, 0.055539512916678385, 0.06099462967305895, 0.06690882461806459, 0.055870734861180674, 0.06803933290704604, 0.11163268523711352, 0.08030070803098141, 0.06828445806017808, 0.025888570103674166, 0.027383728583733884, 0.010394804769255703, 0.03504484914423477, 0.006350758288341064, 0.04047393423294829, 0.06380852041465622, 0.05696936240119319, 0.06084690110818033, 0.055633056082672654, 0.0332639322075392, 0.010849793005975024, 0.04147823719728378, 0.04201868924522593, 0.03845883953955866, 0.0750511518168834, 0.036125806866273764, 0.057595156643900185, 0.014889704048513405, 0.018006850694937092, 0.039820694890353954, 0.022268856372383815, 0.1416609340137051, 0.019102994194855134, 0.06966783665120602, 0.07675430316838526, 0.05686028680253414, 0.0047058899485085525, 0.006019312263120928, 0.08480038674127671, 0.0165989457990133, 0.06650099771157389, 0.019580661506962874, 0.0268505716080507, 0.03741919693927612, 0.03296076823326369, 0.02345874605159606, 0.043943917994657834, 0.06003308590621718, 0.05540315692703571, 0.08470654863143161, 0.026576854138364716, 0.09258099020488801, 0.011355632243888273, 0.02537873475962589, 0.04536029965346379, 0.07364685136464334, 0.04357214318588377, 0.04697554241565447, 0.04525702334039154, 0.014359104848887413, 0.008198282260808253, 0.062234113969269304, 0.08013383875931464, 0.03232331796278877, 0.00987274266193591, 0.027063936671061863, 0.03523464359703564, 0.062320409943499876, 0.04207934808707045, 0.020830505227129308, 0.07003234894645792, 0.020321418734027014, 0.06740661322950356, 0.01727537845351523, 0.025653578378560565, 0.013873300725413908, 0.0281061724789681, 0.04677210010648255, 0.03869847950315283, 0.019110444399918762, 0.028652389338540456, 0.027338219130592003, 0.004502233613522783, 0.040036356301918145, 0.0533551357746605, 0.053569805102362755, 0.025124106285793167, 0.031379037987320654, 0.09365691472926448, 0.07778191052737736, 0.04213552148411832, 0.03297641174867749, 0.06296733289115852, 0.007882248967014735, 0.024927390228596427, 0.02703148135614972, 0.012173693488171745, 0.008976118143407569, 0.04128532093619147, 0.04535333591423208, 0.022345195118818554, 0.05705420663880725, 0.027929707956049713, 0.09194743549150806, 0.14154120979289855, 0.053093597187750766, 0.053929016069178624, 0.016591671794172258, 0.08804191159264696, 0.0648518555587338, 0.12178328894679585, 0.14783388664645536, 0.0390935012499892, 0.04122510642534302, 0.05272252334942741, 0.09639892727136613, 0.03584377925782915, 0.06997599551874785, 0.07427518135837971, 0.04130664116312419, 0.010605659936704944, 0.07207303863739775, 0.08804370423838978, 0.04651341519709076, 0.026402101821957097, 0.03185238264831564, 0.06886029570934273, 0.058110438873090094, 0.08077913760057381, 0.03335796183936539, 0.025013925605303338, 0.07853023287269377, 0.030447593815023863, 0.05945123829728654, 0.03772646714482577, 0.048864642458577315, 0.05284693985877018, 0.04714797348565152, 0.09677045693200442, 0.07096254822587775, 0.06802332933030783, 0.08216790178970945, 0.06734437624653501, 0.03351651522661409, 0.10198748505283749, 0.0331967999227345, 0.013843294019029747, 0.05873126886604775, 0.06910031871689905, 0.036383511183122476, 0.02359250883361505, 0.09818162919292528, 0.07415232383796284, 0.015910137951704525, 0.04553495620888087, 0.03002609989996399, 0.07416579932455095, 0.07805762557132591, 0.03332035841360208, 0.08318158167023813, 0.08409581567731597, 0.0790390914546386, 0.032438740599900484, 0.014157682139005874, 0.02217638955992316, 0.02666180371306837, 0.018567921999361248, 0.03502909071563232, 0.06322597949615409, 0.015156841780539724, 0.039157856466068376, 0.07282534463992042, 0.025549436386133877, 0.022509909768198288, 0.021158067186573343, 0.0035244427976243563, 0.02373691449212211, 0.027049825331496618, 0.038336594889481226, 0.056068914146312786, 0.04726813054613529, 0.04329652007248613, 0.05892194431996154, 0.06192249238430973, 0.08775823689516514, 0.06266267121499104, 0.02216327604987929, 0.02892854488304546, 0.01564220923389639, 0.05234354348372548, 0.018338538037853378, 0.10104872857130344, 0.04979264689609409, 0.05866657274084226, 0.052936775159210935, 0.02104825614350698, 0.1074045080871832, 0.03178256331011653, 0.014111234228156749, 0.04546244981728735, 0.07645696912321352, 0.06404362130729903, 0.03104136749771574, 0.06077999098887367, 0.015936411894677628, 0.062289149725749615, 0.07045424122723841, 0.06465428148306186, 0.02897429565388349, 0.054944775878421726, 0.032542698731225346, 0.030664469475948045, 0.012121735489927234, 0.14034543847364767, 0.2013486215183812, 0.28369927358242775, 0.07364963226380848, 0.0863070288793214, 0.14735561795532703, 0.14228426911417516, 0.08039000323943554, 0.1989473648849995, 0.15489154825768164, 0.12870631060532986, 0.10750943148929266, 0.21554461379926051, 0.16765699391403507, 0.17931372648285282, 0.1148299761717358, 0.10882603019596108, 0.08915081620216371, 0.27404337881072877, 0.16915029846131804, 0.14324731824378814, 0.11586394972137867, 0.13439128055207192, 0.09061068101155181, 0.16047551717248656, 0.1872064698968203, 0.14749198160584898, 0.10159125671752038, 0.06255997712874124, 0.16344459817534493, 0.2076304352451717, 0.13955918711520013, 0.0797377483198239, 0.14659372819287164, 0.13307727122258756, 0.1371557241485965, 0.17313162676028668, 0.15657761584847205, 0.14219578595892077, 0.10679756726829276, 0.1632888831438557, 0.18603224097000015, 0.14091684813460997, 0.1828114541187402, 0.09288330382156758, 0.07430133560011465, 0.11417671767694336, 0.1720614478953423, 0.15410378004514402, 0.1210590830493358, 0.1968045250302361, 0.14632527566244527, 0.22788013091250775, 0.1499772014757318, 0.15492255949685652, 0.15008906563443525, 0.14594531137376063, 0.09128087004947086, 0.12333092444966878, 0.1461536106803725, 0.11467127339734186, 0.09994510996846423, 0.22130809243648286, 0.10881055521989062, 0.21131940907047642, 0.13005444149096168, 0.1632590516800842, 0.23764899300952114, 0.21079278490956754, 0.14351262981372495, 0.16455490472576312, 0.17803293472576529, 0.28308634195596943, 0.3582612629378996, 0.25209456141437253, 0.1371465464152636, 0.19759512776809354, 0.1596462576379699, 0.259202080027711, 0.22225367476142224, 0.393557109299206, 0.2629245625388238, 0.12804478602183442, 0.1705015549856809, 0.13334641323214577, 0.18368070344290427, 0.12422940768902341, 0.2220336543095689, 0.1275493646220815, 0.1256914175445995, 0.16917351092542374, 0.16004258556471718, 0.24401135322067047, 0.1300482208570165, 0.17889919630702467, 0.2163599764988307, 0.1454867771075618, 0.1474039121380737, 0.15697708473570887, 0.1126916638966049, 0.22899639762697682, 0.16463223364083998, 0.1495413280903332, 0.16019175820533307, 0.37096701502319307, 0.37368236770552976, 0.18188329263319894, 0.13165323634541806, 0.1553429119409092, 0.09198630679278605, 0.1492105006811119, 0.17835401749658972, 0.15169067969245298, 0.16600855656208532, 0.15384833568767195, 0.12962434440851212, 0.15962993996518274, 0.1075582083074316, 0.1094663418048332, 0.24583257404306244, 0.16258782076258815, 0.16819639642152096, 0.20476874444753895, 0.1455132837497419, 0.15085011270017396, 0.10459089696767832, 0.14987908093438995, 0.12884696434822776, 0.2739370151633217, 0.09601619740527484, 0.1917030842554185, 0.26469333698191955, 0.12163097534569041, 0.13222692894839472, 0.14404829381214035, 0.09471455273488838, 0.1003748699722271, 0.18791991225894422, 0.08584820349971134, 0.10486889495364121, 0.08651158201598352, 0.12615094006422067, 0.20811054254731826, 0.1615794651931332, 0.12013289040975994, 0.25158871355797013, 0.26158317322692565, 0.14452578109358588, 0.08568433729270775, 0.13461697005456494, 0.16324581368075264, 0.1098576135512802, 0.12262929516333727, 0.1896776703576888, 0.19867718099586426, 0.1520868237580984, 0.13119888491928577, 0.08239973531735521, 0.23697989181645457, 0.14521818668130906, 0.10033115699526765, 0.09052475658996452, 0.1765137823719171, 0.16475496092630973, 0.13954257832900172, 0.16436045628882226, 0.10581247778909822, 0.09922327894356944, 0.1159301014136403, 0.19926936696133307, 0.20229676257698767, 0.15993282048692628, 0.1650778976299109, 0.16534293340819498, 0.1684870348582345, 0.1113335125809235], [0.04328117916180242, 0.01149563481205053, 0.0021772532425295083, 0.015944989206599855, 0.053560608216831763, 0.022892084220544468, 0.04997210299235679, 0.05806207574243027, 0.05929689839362137, 0.011191013355499074, 0.05048748864341648, 0.014815584084229365, 0.08887839533628956, 0.06611970809078024, 0.008321569748072615, 0.07359517107327139, 0.030658057320021817, 0.03399749969943397, 0.039507215542178, 0.12681223482133883, 0.09926605729326125, 0.016891815466806293, 0.04462515402044501, 0.03030009316130271, 0.08339649231563653, 0.07297436406295146, 0.09546009418103965, 0.03703610701186042, 0.0362854021330995, 0.007126333732758799, 0.012646828432597462, 0.02102449592653542, 0.05188300589760465, 0.017430036283668973, 0.03935888559827882, 0.028056723418675607, 0.04868681812959333, 0.04040499015020267, 0.08484085150543721, 0.06112473438523951, 0.02140877903589318, 0.08108941853166589, 0.023950061220074856, 0.02306572187902226, 0.06864976708687122, 0.02867597335528943, 0.016725063023547974, 0.12275898618803871, 0.0317047402683285, 0.03516187673554786, 0.012712800094196874, 0.02209367313151879, 0.033634236127498655, 0.01638674710486685, 0.06795247385819113, 0.11302881153120149, 0.023558649662581664, 0.052373953343879794, 0.02726894371481913, 0.04072850141974707, 0.08014511557356005, 0.08071063401838464, 0.02947009626715895, 0.08423682948153827, 0.04817841536996346, 0.0471260288970605, 0.04568773329318051, 0.12241598564170061, 0.02169869160429845, 0.012810800934300549, 0.024255647947410905, 0.05440786315668976, 0.0807571585380262, 0.13503943690128867, 0.08933155932613919, 0.06074969987234762, 0.06776135790372087, 0.012668394765275861, 0.035692469231904514, 0.08440473297190282, 0.06519381422549486, 0.05434257714378257, 0.02352979113047402, 0.02551890586713149, 0.07079084493940876, 0.08909870690155415, 0.046822183104532386, 0.07139334244833839, 0.07103708858091025, 0.04452552428589233, 0.027479049073712482, 0.017444676223901973, 0.04083727058323641, 0.08425771303835415, 0.04030327282605633, 0.021432466474511934, 0.039749624913618456, 0.014224797186832276, 0.04512162496065421, 0.06705550747292657, 0.017997822348749446, 0.06929056899201486, 0.032304675213151404, 0.035490179885058634, 0.07847310569618018, 0.08942112266536682, 0.12410755374378736, 0.024407760450436224, 0.023130737845936132, 0.03317165308662, 0.02731401458262436, 0.04620738222353882, 0.12011644250202565, 0.05900758528901685, 0.037805090748494675, 0.01594301461497502, 0.0723359217086146, 0.03025728416809392, 0.06988735914590859, 0.016475071296876958, 0.033238003961741924, 0.04995547122352066, 0.023155587822979978, 0.0048054339769746995, 0.020744619109938224, 0.05829267586851793, 0.03543620516035346, 0.04150750175599129, 0.08824597443303756, 0.03401046956799204, 0.02337806167141084, 0.09923709150884422, 0.013201057614247887, 0.06606730767675946, 0.03419806534845022, 0.04899500764065212, 0.012954955699012406, 0.028121768113886638, 0.04084952415958528, 0.058157641380544634, 0.021680895381817417, 0.03950600129281802, 0.024367029470722043, 0.05714571201092294, 0.08113429596227023, 0.00713591078942221, 0.030991251940929124, 0.025505459108840556, 0.06947266809161633, 0.05576745854810842, 0.019964295356804808, 0.005982111033517868, 0.04216068364199131, 0.055763517025738, 0.04186383606265149, 0.038378951890814694, 0.10559879288437868, 0.05307524938196425, 0.06144069968872975, 0.06014613367076363, 0.014559519195538616, 0.13782200613810172, 0.012613074598653663, 0.01119294006662864, 0.0542756823462344, 0.011281673158068332, 0.047212443614919344, 0.02538015968316505, 0.045393877287185004, 0.04807591280569473, 0.07715194876636229, 0.011665500445111145, 0.0366911337891173, 0.052154982432482705, 0.023573013811161923, 0.017534433000330484, 0.045832493267352545, 0.017523338131967093, 0.0359655067985577, 0.056621416757303866, 0.02911670948378742, 0.02756137479727547, 0.016515153017075315, 0.02289913989032709, 0.11850721353004057, 0.04892504849140683, 0.01671194759828429, 0.05221140480810597, 0.02724187016757506, 0.053540552034974105, 0.06992056905742615, 0.018044005959264694, 0.015902925233897424, 0.026956184489292004, 0.05806142456769463, 0.05586251090731352, 0.07271148099173462, 0.049759908128649964, 0.03771987495823734, 0.0942066134584527, 0.0490946373752048, 0.011499080292489982, 0.02142588386402255, 0.015268154355937676, 0.10999736331042745, 0.10515553441138999, 0.03669387638388622, 0.006238797411037189, 0.049061753051055056, 0.022482742375183492, 0.012534026773796688, 0.027373106774663734, 0.07005716253432535, 0.04114355636580337, 0.009732509309786462, 0.05120672263024796, 0.040076395887280666, 0.041426851849762664, 0.02242718376369486, 0.05628557913305779, 0.04009966580798069, 0.016973342543708223, 0.03403290062241497, 0.04355423971109333, 0.0273223438735811, 0.08008083313583367, 0.0407242113273711, 0.03558014159000689, 0.11089887259708298, 0.012384705703645464, 0.07708222710437353, 0.015162481145272333, 0.023662711215776303, 0.01156099743375014, 0.004526099646388884, 0.025320079237703356, 0.08720716686859246, 0.06824436101822123, 0.05015401056997719, 0.025393692626347466, 0.03665513914799498, 0.07191163923351035, 0.008288672974994107, 0.02599892123872715, 0.015825167309582954, 0.12516968102464754, 0.05165072037808357, 0.106824456954435, 0.05060936940172988, 0.07663804166499646, 0.040300078239412084, 0.1143161993053171, 0.01914444912765776, 0.03255127891597729, 0.010284432566784804, 0.08500424273792775, 0.04143887943017387, 0.04481094183340188, 0.061114982085963415, 0.03964829063343425, 0.05254770974598585, 0.10749825426647741, 0.04730871405392405, 0.07527336328020019, 0.04854960029103583, 0.029209789166587497, 0.02391693557822897, 0.030825169824604547, 0.043076097424472534, 0.02705526072531939, 0.09571599053038705, 0.07606138430175281, 0.08073361665611306, 0.03232238716596077, 0.011068150089422782, 0.029350383537671262, 0.04368253645577258, 0.05302343885564516, 0.05095303261412248, 0.05761025240644813, 0.07185513258821542, 0.07150140681093739, 0.033925958578625036, 0.03430380846463865, 0.0842849244814246, 0.027145258819444046, 0.03576194191531789, 0.058084334427070235, 0.07607887408906415, 0.09454622789616547, 0.002702813259431071, 0.07583708907928198, 0.08699905142308244, 0.026241073970712965, 0.010083340232320612, 0.06587533370381402, 0.04117105509184542, 0.0290427724229953, 0.03752016732769628, 0.02562046231281373, 0.015655513308311424, 0.03957827019715502, 0.04108950886274538, 0.050130606583890416, 0.016331584943879037, 0.07866632073156296, 0.08839932225284078, 0.062125095827204574, 0.0071998063527468235, 0.04592279588142711, 0.06027048123219322, 0.044464390469534744, 0.049847900987632816, 0.026043873362904115, 0.03581725729389056, 0.024575135340133024, 0.015562220078502453, 0.02642551346892311, 0.06028963343030023, 0.07442019414156675, 0.054993613983594605, 0.007567285802290445, 0.02502087210755675, 0.011153412802565483, 0.04662075943704094, 0.06656760905659007, 0.02916200060187088, 0.009649636790967517, 0.04503318777067527, 0.062495683199696006, 0.03678276939618011, 0.026704750602103533, 0.09882280648115183, 0.021849584112304355, 0.00747044271256234, 0.030407502518726454, 0.06774762960811777, 0.0443173015880729, 0.040421913032450026, 0.026796832455382235, 0.020577050783040545, 0.049012991554674604, 0.033001868850401336, 0.022415500922849583, 0.019532212191411567, 0.05444015376269818, 0.04248385400240941, 0.01616055389956361, 0.027779570044649225, 0.0807062060301823, 0.027834082946121216, 0.03662529236246501, 0.11598527506594697, 0.13896474885123392, 0.06294655275621241, 0.12971630560294276, 0.11041439093288877, 0.13796322678606357, 0.16351101799838005, 0.27855750593927603, 0.27332331744893906, 0.19194377375946892, 0.14483918766340903, 0.16392286686647325, 0.1833253765418645, 0.3051137599733568, 0.22375598850269474, 0.09658225211164645, 0.08832632173453608, 0.1396732269636085, 0.15229277883566197, 0.1895866131470088, 0.29622098070479214, 0.16556201923278072, 0.07993148429499519, 0.1653238731406389, 0.1916035387905375, 0.21412946554201268, 0.25474851981045743, 0.11057478676159536, 0.22532449224062506, 0.12970479896232007, 0.14789416244433773, 0.09361195302898846, 0.27629313389620475, 0.1118205836223018, 0.1088301670707522, 0.17307861347592648, 0.14235925380020373, 0.11194115820070429, 0.13887755272369232, 0.09510600068155797, 0.1362944881041204, 0.14743351377546787, 0.10805269507991691, 0.23232262882013477, 0.1661807578057051, 0.09972227797392877, 0.12753269454884913, 0.19055617402397818, 0.1067689385625624, 0.21690740760776306, 0.15067472453078917, 0.14776712974473355, 0.17523858305667678, 0.12613964792821677, 0.20153545504135473, 0.2935344942154423, 0.1587232749067968, 0.1258312439125392, 0.0939810005647521, 0.11146085937657665, 0.17577296002737938, 0.11882517066213394, 0.2966205108790629, 0.21223537443626314, 0.2017382844801872, 0.11770874306920076, 0.18605523892948705, 0.25976828029078824, 0.1062625697663715, 0.14940113400018987, 0.15519645125154527, 0.2808730526556892, 0.1864047282405438, 0.265427433074482, 0.2341761325876559, 0.1472636874044134, 0.10292353724399883, 0.18394480459392074, 0.21193488410884337, 0.31981563075415553, 0.21922678476379764, 0.08813701374756713, 0.24673260478002412, 0.16825887855262528, 0.12572312592378548, 0.2704734703706157, 0.06118360441178084, 0.22669566705101923, 0.17894594299216426, 0.1562350519722508, 0.12354609556496145, 0.057045074870749835, 0.12964959466649642, 0.25127795765236505, 0.22804932909146433, 0.13337560118206088, 0.13466937046858574, 0.16839997662651926, 0.1739102325612499, 0.1059080625794107, 0.18864132193548067, 0.24404449418427485, 0.20532133898908095, 0.167822606801506, 0.2701225408142613, 0.2967932483842296, 0.2862890184886994, 0.19781352411354744, 0.14225877370805512, 0.1088660506291255, 0.16597305604767415, 0.1285300797392284, 0.2107548022702817, 0.2680916110834768, 0.14349254298835032, 0.15828701847743604, 0.18133080534396634, 0.14704404999652218, 0.16837757621561328, 0.21244712113853426, 0.12239857246318173, 0.2124036073444351, 0.18930412588580964, 0.1460778905499366, 0.14244857965217483, 0.12608550083372863, 0.23418540225153972, 0.08333224818230638, 0.16882874071598056, 0.14605009688004372, 0.1856576392967855, 0.1763927251581223, 0.16058143648889758, 0.16621647282473503, 0.07768595801486124, 0.21459621227075978, 0.22253345007136946, 0.1218755565763962, 0.1356690692444963, 0.10805811898242082, 0.1167829794388625, 0.13001339449997873, 0.1067640892260017, 0.15787987338919796, 0.1139075143803512, 0.0988916548029069, 0.11198216688729103, 0.12010964730213727, 0.25150609863621576, 0.15142572052296133, 0.11693540029227735, 0.16897766820846066, 0.1337967656793133, 0.11547177399118101, 0.14205263476938973, 0.12930171414008065, 0.2517333509580743, 0.14940424431716243, 0.09445339336150116, 0.19517409074450695, 0.17979237821794328, 0.29165531118069926, 0.06820620217871282, 0.18355809873150242, 0.1424313733173955, 0.10588127248469861, 0.13849362009955993, 0.09582567899938553, 0.10784596625354984, 0.08561693687712954, 0.12130642985744823, 0.139433671269686, 0.08043501090498702, 0.17873591232684352, 0.09788745909088081, 0.10448777387219091], [0.03124553375997611, 0.05261853457458558, 0.03873041770871609, 0.04600447234547427, 0.07154742571254892, 0.02031622465790039, 0.038725281089183786, 0.04566371643675431, 0.04837904230601365, 0.04028548043401491, 0.03563305145249732, 0.01879370343240519, 0.024909873628207756, 0.029822025568254536, 0.03491466399282217, 0.05807898713335876, 0.0554435680650415, 0.06333537685174136, 0.014791975169622851, 0.029141687780558586, 0.05323621594617444, 0.04682510572996351, 0.020069046389131297, 0.039756086865259756, 0.03272029706427167, 0.08898473600105894, 0.013202058316598977, 0.02143811828817331, 0.050719804806454535, 0.070984642201614, 0.03899837611243129, 0.04827557830139995, 0.011890434393388851, 0.11636978991690183, 0.05655082558552104, 0.0059043368298350085, 0.02069672903857164, 0.03309134408951767, 0.03161434955414265, 0.042351094795571226, 0.024795102165831674, 0.03869166515106636, 0.035933162566394575, 0.05915961543759031, 0.03723454676688679, 0.07002635813889004, 0.04615809978736986, 0.05357838528711469, 0.07420399646845556, 0.03670785365806472, 0.04545273582240747, 0.019296190078039805, 0.06705173832033912, 0.07088197109800193, 0.05695566091866744, 0.026237957908080953, 0.0710941544703899, 0.04155253623462012, 0.02210170173296525, 0.060421182218218045, 0.015320342180559473, 0.07095192258636798, 0.031176721827397426, 0.03834008441997632, 0.04596876498732356, 0.06513503229906482, 0.05436989966960204, 0.09085607429545733, 0.07279476240998314, 0.036982886883760654, 0.07176412900369014, 0.03846412171579657, 0.09218991764130131, 0.11937075549916876, 0.005860380141154653, 0.0305733643847728, 0.025416334354949575, 0.03613632908391376, 0.07439878198408312, 0.09677224957774724, 0.04704928220880609, 0.03839744908374645, 0.11969543122235807, 0.011000495907219668, 0.0681591107540073, 0.07451633051518472, 0.0860838138408238, 0.01771786126248058, 0.03472674262499617, 0.07175714994269995, 0.038348752704839555, 0.029341485426430742, 0.1165902087344758, 0.08931822173537747, 0.10882419158494282, 0.013462162403870496, 0.001954746715660628, 0.022444801870733503, 0.04476494591442808, 0.0684944887254988, 0.058985303621739156, 0.02952933976156337, 0.041733061023537195, 0.013584597618319096, 0.053802036995729136, 0.05332204077633158, 0.08048705891856263, 0.03781884585717513, 0.030088223884963704, 0.02287933651748444, 0.0662941080067427, 0.0701537968650941, 0.04605322618097548, 0.10397423449302874, 0.04649548107878335, 0.02533052293133111, 0.07297767356278435, 0.015510109820282988, 0.02053184201940894, 0.02097689122292063, 0.07209792883405763, 0.07043004817058963, 0.017624266385551424, 0.02723830211306772, 0.06313047514507367, 0.07227907032375375, 0.025804499614863627, 0.021075814241363157, 0.027008307196440238, 0.020302856423621698, 0.060614512166789467, 0.027317854598344817, 0.01885332997077175, 0.03502171328892151, 0.035038080757423755, 0.03230160320057504, 0.04064867505803704, 0.021162031691581495, 0.03357561507953271, 0.0494683503864273, 0.04331792456909053, 0.05997285607361025, 0.024959837882629326, 0.06130442030787949, 0.05255522123808342, 0.021666173087132555, 0.013385528713584909, 0.05603036843240262, 0.057636893114014986, 0.022570541796965465, 0.061366465768866965, 0.06652907483399877, 0.08821154644172038, 0.08041149200571161, 0.06476114308761974, 0.04877158958885459, 0.05175967340267474, 0.05393755028865511, 0.048608409030543226, 0.0029665299300705235, 0.039725186708833904, 0.05513182773645367, 0.021566022412791368, 0.06129044303370099, 0.13121223017092676, 0.033448593871247385, 0.06357156558923664, 0.04957878579115195, 0.043754027780866435, 0.09539762737169381, 0.056464008671501954, 0.05405996347807589, 0.05172231512504721, 0.009670953187460621, 0.018741506031684337, 0.030117921283348437, 0.0576724395937016, 0.03487507639933498, 0.013951116106322697, 0.007844575156923383, 0.06215385093744244, 0.04215940427515776, 0.04042290128587235, 0.04703673368860637, 0.04329909412791172, 0.07389695608928319, 0.03350852492956385, 0.04022587879350589, 0.054237921872446616, 0.07226757900488955, 0.07491583004593849, 0.013251182747133558, 0.06032514543603025, 0.04262585222961442, 0.04251587264720471, 0.05145184778337998, 0.00813541421291208, 0.02712234896006844, 0.022107068178874832, 0.03748118494366927, 0.05481961243335278, 0.05758599040188617, 0.046034782614198425, 0.028664788471594937, 0.03232568134403518, 0.0372279086150229, 0.034624190265012365, 0.03283909814912946, 0.07072927445293435, 0.047445951044679656, 0.03936991726438846, 0.01545170231932594, 0.01569349786281706, 0.026802214223050305, 0.0630830504721211, 0.0327798297568675, 0.06262387652250548, 0.04445570686291303, 0.03344172589300621, 0.0697813019336712, 0.03271481953561306, 0.08630870661187558, 0.025483077850132704, 0.04774268754127045, 0.044923560588710734, 0.0287494182045902, 0.012232999227220013, 0.04260404170641015, 0.046536501256688956, 0.015155391959143023, 0.07591018152813758, 0.07317729309321412, 0.11200681959669437, 0.08040527137176645, 0.0014794534382094901, 0.03867537812179616, 0.07149265808684212, 0.0522914112004782, 0.04403540038413579, 0.05813806783407927, 0.06201081466110003, 0.04494218035571037, 0.04597278694892603, 0.08027593274751017, 0.012598325490891453, 0.04602763501386489, 0.12579968875093808, 0.050839184287695155, 0.018003914662967288, 0.05106275555707755, 0.06954108740413381, 0.07527353948042279, 0.06764345697217411, 0.05701207563341145, 0.0330662930143937, 0.08806805817350265, 0.07653038332899732, 0.02342880542029537, 0.09476403435391766, 0.015699765419647578, 0.015557921367637334, 0.09750544168655911, 0.09003470546656078, 0.027341959554882302, 0.05948398855604953, 0.051942258968108126, 0.06385736618070834, 0.06868755054329673, 0.06714644977041791, 0.00571971251291313, 0.102393128608744, 0.027149631266271877, 0.0072227253094165325, 0.013974600531641516, 0.04740863107144833, 0.023392711187742894, 0.03769503072685292, 0.012984999752182876, 0.028080998829776244, 0.04342225808349829, 0.10942308848062832, 0.03711219869493958, 0.01910884902181645, 0.0366745250029189, 0.09484576827455914, 0.034917644074847626, 0.06534700116683399, 0.04468399340346937, 0.03529238747432828, 0.05312565030650266, 0.01659003428123411, 0.06742875317051526, 0.02965493413108972, 0.014642807317056484, 0.0449809329133601, 0.00702567600397273, 0.04040924576862205, 0.0496522268100131, 0.047761540965086995, 0.03236621122566923, 0.03161476324162176, 0.039010951445708354, 0.03938767135203366, 0.026439423710408232, 0.019186294765301773, 0.04083026853960849, 0.03954714787523112, 0.10973631118934964, 0.05089299430349662, 0.026888941121738286, 0.03774667654426829, 0.027569106539651275, 0.06872796168130252, 0.0741931026981723, 0.03313054097816348, 0.04029180448982985, 0.028493604209694653, 0.016638860895088124, 0.04237688897598175, 0.04241826921521176, 0.021553064035552166, 0.009872901625180197, 0.0394255314172516, 0.023135885956787297, 0.07555453287016961, 0.05354624406825151, 0.07211591657851973, 0.10361109349516132, 0.01895202124761718, 0.011957723726218027, 0.038837129926128734, 0.057692043783683936, 0.04880984035891391, 0.06913110779057588, 0.02359909527454405, 0.03128369068426471, 0.051410398596236785, 0.023897124544507074, 0.024442604044452313, 0.04747142346816198, 0.030083751846705715, 0.05145999512845471, 0.07499841432417594, 0.03895991466819279, 0.03364714470902278, 0.00584627119561417, 0.07510453282344727, 0.0315653563161651, 0.03334574656741273, 0.04617755842064658, 0.03523373578284537, 0.013327322310707984, 0.16321912317747073, 0.2127403029871564, 0.11328989429579628, 0.10352067979833773, 0.1942325993290832, 0.10451579736846109, 0.09012809158453057, 0.13639645440684212, 0.14007934549402806, 0.11429145466536285, 0.137150943759949, 0.11920233872989494, 0.13602048909712222, 0.12763513582608393, 0.22986003918753517, 0.23686338516493, 0.17978384399846678, 0.17273739791445195, 0.12235109799451406, 0.11793342133563374, 0.08069841491599238, 0.12602648142004205, 0.17585212755347454, 0.10852128808056155, 0.08545749865832829, 0.13840469261330945, 0.12231531402757093, 0.1690221625951029, 0.1402686304983593, 0.11909832697241537, 0.12153439464107638, 0.11765905460643193, 0.12197802083626871, 0.22780271006687997, 0.14225524970360343, 0.057630143879402074, 0.19569259437341846, 0.0879185714368378, 0.13168446208921172, 0.11934633261614269, 0.10348922422816677, 0.16445989450139387, 0.14199312505943162, 0.1440457044349563, 0.14654587834112107, 0.1646164522295998, 0.12070671324768376, 0.1619283722773675, 0.08764942176640035, 0.15469725303832563, 0.17334522739533456, 0.193563636031843, 0.17150476244428467, 0.16120110968908957, 0.1276056874062746, 0.22269157061894096, 0.1742096350438172, 0.2213018871242962, 0.1324702384731462, 0.14396259921693033, 0.22208712724668367, 0.15401578718616118, 0.11529832402424467, 0.11540545375957606, 0.280698660400606, 0.18060991660721842, 0.16322632440395896, 0.2932627168634246, 0.16524871991526696, 0.10338321298120484, 0.26212225397748334, 0.15325903021279844, 0.2641952266135524, 0.3268579706068962, 0.15662583342242628, 0.11034404873968133, 0.09682188441436138, 0.1847591100921554, 0.27643084586147343, 0.19513931035274462, 0.37871630081245977, 0.1465264656731198, 0.32748294513552423, 0.18739760883392828, 0.08004905580873452, 0.15385305478928551, 0.18754135757204027, 0.12354273243897385, 0.1736155185367792, 0.2531234634619567, 0.10299073081583747, 0.1702598542455704, 0.22196744899115256, 0.17101003818454283, 0.20210490351723087, 0.12893958437827327, 0.14886035253444027, 0.07347301069286562, 0.19003751717748182, 0.11994033420999205, 0.16108349987095402, 0.07587943075885696, 0.14689809492518827, 0.18553344112250114, 0.22181135091570117, 0.19218161341644105, 0.2710877196683038, 0.12527750023911077, 0.23917764485363038, 0.13286497293701097, 0.1281894234219386, 0.10628664790983162, 0.15390870341610524, 0.22783123918118017, 0.10050407836153623, 0.264634225637682, 0.20040801876494962, 0.1561136576797693, 0.16852844957142107, 0.20156193104001785, 0.15985233528960138, 0.1949028496540362, 0.17205772470803032, 0.1707651811621843, 0.09100019841665223, 0.17497540121116947, 0.1560189079252943, 0.17620837376002343, 0.12283871295831858, 0.17780301641793023, 0.2523062774731267, 0.14226349280966868, 0.17073433846235278, 0.13173954381096747, 0.1196302907661565, 0.1714327655011608, 0.27378287827295644, 0.17184337330681665, 0.11590157996021933, 0.08988257572655717, 0.06752439158698244, 0.19942430058313956, 0.15653589470011575, 0.13640748607295175, 0.10266377981151305, 0.08530871672255379, 0.09635460142406727, 0.09993162682099689, 0.17217280643601574, 0.13789018796336266, 0.1899831402566164, 0.16942825048200547, 0.2108073252583704, 0.254870864051965, 0.3552598223811196, 0.13008911463041462, 0.15907429639370213, 0.08937744033192435, 0.0954130870260058, 0.15258208427938724, 0.08784543302270674, 0.1758770713762891, 0.10616647169714975, 0.15580366786208846, 0.22766110637495596, 0.10665106061365336, 0.19992984200437225, 0.19929003601353015, 0.10477239851869884, 0.17887918609044245, 0.18136736305971302, 0.14622488750084756, 0.1304074701282286, 0.19966569488808034, 0.07301097540485282, 0.1412413476575767], [0.012579288205973083, 0.015329200072183967, 0.056928307749331004, 0.09094235877836905, 0.035264455908609015, 0.040514988884810484, 0.07917919361423101, 0.0411847259308542, 0.02101523775397049, 0.021435120969169566, 0.022222306954884724, 0.025008174200211803, 0.031794069950739225, 0.08162398702434956, 0.017954551787566275, 0.017841274196642543, 0.06332187455207591, 0.014657086238355167, 0.08804443968279708, 0.07060594961888368, 0.04212249032852631, 0.020872394914828965, 0.03097278156107472, 0.055494823177615484, 0.05670533785896917, 0.033667943996166995, 0.09313162356134384, 0.04784372304716418, 0.038889618440260815, 0.08152266423548422, 0.02803879121558801, 0.017219555541692723, 0.03782432338583373, 0.010985358009835886, 0.016134426470906023, 0.023539983930306572, 0.028172611454201323, 0.0051793423406178915, 0.0059953294018463745, 0.058216476933129375, 0.03280037623499671, 0.014178766793901882, 0.09188779554660283, 0.07219740535102545, 0.05069694091235438, 0.031658910973478234, 0.02040119146958234, 0.03350531119072149, 0.020724484404068322, 0.010300996345317653, 0.050707026459877534, 0.03872801602307347, 0.04289731931602282, 0.047889833879326625, 0.03295984126687531, 0.07186613361080808, 0.030160617278588396, 0.05482281085043665, 0.053051339777847456, 0.1080636271545964, 0.018816661172276063, 0.04270509636450199, 0.02373497245923406, 0.02879186713647458, 0.03640565878501342, 0.04925484551236995, 0.04394954491046168, 0.06782614595947728, 0.05673470583954646, 0.01930198553318699, 0.01914685464374, 0.09741169550726492, 0.09381781617600111, 0.042415940307921944, 0.08887576765470928, 0.05647579876465663, 0.020424675894901156, 0.015694705408907706, 0.02834913534893384, 0.07958934942801153, 0.04160538481007661, 0.06817648562812997, 0.05926596376323893, 0.01914081404045705, 0.03436427578450211, 0.008685340853257766, 0.06445223345391213, 0.07619980872879106, 0.025015086228508624, 0.08299493200836644, 0.03095630875548288, 0.060381632929127065, 0.00392994558487478, 0.016635036201126153, 0.033063527436987046, 0.030670372183404626, 0.03435425918489214, 0.07604621576085206, 0.062234248034656055, 0.04773249857187752, 0.04906190243820029, 0.03534741940036897, 0.0603846628068676, 0.03187061362569371, 0.13639553510133298, 0.1765351562250045, 0.014615834318852473, 0.14203161331674746, 0.02104968681270557, 0.09943561553354226, 0.03631738630393821, 0.05412510010383783, 0.08268969959669537, 0.04495239230774103, 0.03988930572485251, 0.03906411028677418, 0.06367112637587613, 0.04619796317250979, 0.06787650857961948, 0.07260331703770546, 0.06220757285313261, 0.07418986980713184, 0.0930625683958492, 0.06456988157644387, 0.06543107165564453, 0.031231376455135407, 0.01542535559800003, 0.019935620685798988, 0.04840075323778776, 0.049567485994268815, 0.030106008616125876, 0.011216012719688157, 0.010962420379773024, 0.022039901420113542, 0.050554927363390886, 0.041662845234837265, 0.01485258230053249, 0.042630682413977, 0.03357591002338356, 0.03947717340422734, 0.008160238334488484, 0.03489661879176575, 0.08356073390572302, 0.0077389158316016685, 0.07159165196841763, 0.03165652077915448, 0.0103739001450219, 0.023272360690058242, 0.16109128332426473, 0.03321493322390222, 0.09909332744897374, 0.12742987788853147, 0.04421334345674804, 0.0692113095353688, 0.03757397734349774, 0.1142052161477266, 0.0916010948018201, 0.036828646571525646, 0.034171018614283497, 0.06731989207647501, 0.10285234469319544, 0.015543206733831716, 0.008842768091257782, 0.0827719084918499, 0.0679880663031532, 0.027464847718816132, 0.045483689604988026, 0.08677014435130743, 0.05875954900177256, 0.02906181353835329, 0.020865590138841542, 0.01444857817278394, 0.05106632935724432, 0.039455925955647425, 0.02252269577565453, 0.01721102323743605, 0.016238570378552523, 0.10573700280679811, 0.026300512817538074, 0.048569464950912425, 0.03558800548254963, 0.0269250602521483, 0.09544834239228119, 0.07631020965955912, 0.027936468681981488, 0.004476384370542702, 0.07855752092455665, 0.04781241303369884, 0.040113623929961074, 0.01432480613490747, 0.017952207558517976, 0.05018228687526238, 0.008348871206474161, 0.05436346453103808, 0.013120483359201782, 0.034379214499025576, 0.05528649705792627, 0.055887018060011256, 0.01932340918198949, 0.058707746136332714, 0.034522335045039654, 0.04098143300882751, 0.10428793983714235, 0.04504563669944483, 0.013149245172708988, 0.08158030469090709, 0.0408084005598099, 0.042174948199141415, 0.06168818056222893, 0.05170476788114156, 0.06706271636029405, 0.09206929709762336, 0.01867538498293969, 0.03479007894413606, 0.026249489446561185, 0.048794537752626405, 0.02131230749880835, 0.017035353530739105, 0.02725714213034559, 0.035731869133850264, 0.05109812583654158, 0.07842412969518094, 0.03151182783767581, 0.04217990861845113, 0.01780761037802985, 0.0336618421058501, 0.03770811167816001, 0.02941931421387821, 0.014802589317813758, 0.013981014602787554, 0.03537941889296617, 0.04453682791321509, 0.10671935735210296, 0.020839493353700927, 0.0015880446059576747, 0.09530723665750797, 0.05840220345905232, 0.05228414102607677, 0.021681521658695514, 0.05802091383825868, 0.03085935075256613, 0.11011981480424443, 0.10609633634768187, 0.006702063227778362, 0.055254064725651864, 0.13544224593187534, 0.032849183696652615, 0.07690355241779359, 0.09442249703551493, 0.06212008561217978, 0.08418866553373876, 0.0029257180323193394, 0.049002630215498715, 0.06872259906583256, 0.04140071676022584, 0.1235770148735854, 0.048192591827002265, 0.06502011144954352, 0.008915497605959255, 0.06440580086482149, 0.058565108225710934, 0.013317159196782499, 0.011970454192299758, 0.07815829718545561, 0.02504929971520699, 0.01439642386450883, 0.07858087128448872, 0.032595091484366887, 0.02585503460478879, 0.026210275320937077, 0.06919816346658815, 0.031062002075956236, 0.054673891018835775, 0.07358086055084583, 0.04743844721346133, 0.015229800164008574, 0.007222704241998615, 0.056619229576280045, 0.08421265174664798, 0.009096823914367105, 0.07347686411512476, 0.09255660562625817, 0.055894184812542894, 0.1062548935653702, 0.027914344062728268, 0.0279421434782806, 0.030052060704498045, 0.01879212912172079, 0.03701306691753768, 0.08260598916920923, 0.008587933731295409, 0.061591006139473575, 0.07670223217217192, 0.022905088563059128, 0.023838072572083726, 0.041554010953874364, 0.03468069691030729, 0.03985244157393614, 0.017085285226423896, 0.06105518892347332, 0.1337266992777586, 0.08275292483308623, 0.04698325692105198, 0.052230376975550774, 0.06195419310261646, 0.04370549228042365, 0.011353890351470441, 0.0520324734820714, 0.012662504506748051, 0.0453002192080021, 0.03281519237545229, 0.07450173654022717, 0.04511773323399886, 0.03883560924159904, 0.03292788390911395, 0.031075397123312278, 0.031725669790419846, 0.09367378398535714, 0.021132807352490002, 0.06993621257283995, 0.06599492768967344, 0.06020309230793388, 0.026465083825432008, 0.009346647101694779, 0.07986348633083605, 0.022683459326564785, 0.08818637279252853, 0.018643006276819977, 0.07760152746472629, 0.05876973797116549, 0.029893062986253254, 0.03283437521707627, 0.11824796937646405, 0.07600955845367524, 0.008079685146860298, 0.08520363244198023, 0.07189064076350582, 0.01723011414850912, 0.044743120069465334, 0.03766196637204097, 0.0644657778884134, 0.04090046900654993, 0.04187699745319063, 0.03345858748821962, 0.05197378348619227, 0.020021221435238278, 0.05207877583621491, 0.07460250774578703, 0.06677878119291798, 0.037840851732800086, 0.07588922136252926, 0.05019809126914029, 0.14750327374185287, 0.31712381229285275, 0.09392756593203354, 0.13740712356182838, 0.1359901979805962, 0.14885506652776273, 0.24813603189203048, 0.10456904814007784, 0.1173929539659331, 0.14480203239908143, 0.11159818829788316, 0.10374010270161015, 0.08217761578458933, 0.18655492743897825, 0.14483201708043777, 0.1275454116083922, 0.11451688369796162, 0.16552973628765152, 0.14428113857584615, 0.12410419061779977, 0.1359039364803222, 0.07936062621733836, 0.0826965407618592, 0.1518589892094174, 0.21278893424858972, 0.12018221881120436, 0.20585096621465301, 0.238666465025275, 0.2022361803439356, 0.13711823180558222, 0.1512683813850726, 0.1567540918627093, 0.1047446508140814, 0.12263756125204026, 0.13997607684183505, 0.17797841990907348, 0.0659989649730344, 0.14980366723912378, 0.1281496941021854, 0.12722079717223683, 0.08953273401505525, 0.1289275108325866, 0.07942762826719592, 0.13086033534378777, 0.12445842967398706, 0.18707251176238063, 0.12992160184489143, 0.11882900110175533, 0.12015568152550729, 0.13440284847972855, 0.10313218129017662, 0.13000305231300094, 0.12241683599929656, 0.22130470632785754, 0.18712819103271733, 0.2246364227105533, 0.1916809136708898, 0.1197866952767776, 0.09949937703148012, 0.20852939345903937, 0.11079941906275288, 0.15412288627797557, 0.22253685150175329, 0.166562530061891, 0.15729544023352285, 0.15694550659147002, 0.19271787496343737, 0.22252477795606662, 0.2414336512165685, 0.14786316652692136, 0.16550715201564375, 0.2734148496341321, 0.23508757803468938, 0.24965437219267894, 0.25959165105896614, 0.13034799106178746, 0.09557504567407793, 0.23653143926733927, 0.14030932508889707, 0.2710817441824944, 0.17284229067304444, 0.1780413004058984, 0.26289759624388914, 0.104806573701001, 0.16787761191446937, 0.12836019974201918, 0.15641770265515775, 0.17621954332195944, 0.17065311782062056, 0.2751252175338807, 0.1489188969736138, 0.13675737374972913, 0.14322710884434564, 0.10069511770721405, 0.1940706636636488, 0.1569342604207416, 0.15836880602423223, 0.2552510734887854, 0.15632762603702086, 0.20301055733955678, 0.138896536382456, 0.19391228264618307, 0.18304639796335853, 0.12571737260347413, 0.26276659520883716, 0.2602267073046777, 0.1580236834143439, 0.3171024537615238, 0.14779072525280137, 0.207031752854105, 0.11816820430178797, 0.131929564259706, 0.20272065434725056, 0.2704821731294355, 0.1141284388159552, 0.29132567886863986, 0.1619090208964002, 0.16188703417297334, 0.17124846006833738, 0.1616671975822218, 0.11864769107271587, 0.24931119544611824, 0.23728006038694616, 0.21656171809281075, 0.15125840692029846, 0.19218541321254548, 0.13083545280800712, 0.1486125537344525, 0.2207575816540949, 0.13791836467721771, 0.15080673680190118, 0.16572251465291749, 0.12866540151017328, 0.14365522941995051, 0.19027580116545, 0.21110164091712047, 0.14922683367565756, 0.11754162098851897, 0.16645003771108968, 0.16462524691897054, 0.11897420540692345, 0.2631710283458233, 0.17912143841385844, 0.09512722131706054, 0.20684586928015758, 0.13337989127443683, 0.11698956270852398, 0.11453888574314695, 0.3363911380931255, 0.06666769844389732, 0.2524947351024997, 0.1891399838871533, 0.16949810237894136, 0.1326028942581146, 0.16792886319660372, 0.1898307500467185, 0.2622087299823761, 0.2040473347710025, 0.16764875080796982, 0.1511812618663234, 0.17148378695691788, 0.08153394871060887, 0.18513499879308287, 0.16733290807854745, 0.17514017140192373, 0.17092746922806387, 0.10227179560329645, 0.1372801981145336, 0.14587889155072553, 0.07827913223375237, 0.11327146988121733, 0.20245020998822105, 0.2307075162928912, 0.1366352746563573, 0.10248754128453233, 0.10456222995755174], [0.06759735380089091, 0.0516722206356785, 0.02021925516366478, 0.07935784531817322, 0.04603020140841123, 0.0243794783994916, 0.055978335740585486, 0.02199218371852992, 0.017668597978509722, 0.044712066695454626, 0.02755039484210072, 0.029903204075150916, 0.022239415613453717, 0.0361897943601493, 0.039785883855074644, 0.03245981184825782, 0.007626319580125593, 0.025274544886703935, 0.06309788193433516, 0.04178112154946693, 0.05222726665857819, 0.05172925205120156, 0.05589500069618226, 0.014356699332805171, 0.032945431153019594, 0.041882168546679525, 0.03583700321013889, 0.10987016973235916, 0.07066297720396711, 0.040171252894065076, 0.08773095650418151, 0.01490812846309235, 0.02809344584332599, 0.035962905930054766, 0.008278053081143768, 0.033100357113946835, 0.06722135784765405, 0.03277076310628364, 0.010171542807872738, 0.0036000121045001456, 0.02546780397214236, 0.06466752714327266, 0.038524592866099654, 0.06447328555007135, 0.04343998918850576, 0.04141553673112104, 0.03379729028130251, 0.055590821655407074, 0.017457211337563013, 0.044456783216446645, 0.040670244263545166, 0.023876692979566516, 0.0668031964150648, 0.01719925038125967, 0.030122780196008184, 0.04940697908281319, 0.01597473927352938, 0.013450212389861625, 0.018200515806975386, 0.02623325604344568, 0.06858209854051953, 0.044762295250210075, 0.04919086950981329, 0.027023808985588052, 0.09561205538169992, 0.03155418292378947, 0.04482503785120864, 0.03895637151154299, 0.028399291125336484, 0.12026905487742155, 0.04402925635898306, 0.014806923460245374, 0.05766061502659033, 0.058460169501843, 0.019419543640387636, 0.0280659758455811, 0.054953731446256565, 0.07967826159250352, 0.0685402318354576, 0.05928023215082865, 0.07142173366681223, 0.04866174407183163, 0.03943116216349506, 0.045941093891498544, 0.027700961762738806, 0.02649030152467951, 0.03348380710268694, 0.027657585864466046, 0.01932834853388129, 0.06578482807643952, 0.08065215086624508, 0.04634797084896315, 0.038673945537377755, 0.08298553210953552, 0.04680558197921322, 0.0520582638320423, 0.011610537466983642, 0.01714271500766758, 0.029044201176974083, 0.06096723053844706, 0.01036710302991372, 0.021779923737349532, 0.030750535623801332, 0.059879649986302665, 0.030039316831877636, 0.11021043534480757, 0.04021919850680617, 0.020257892808125868, 0.020433903423949115, 0.022831714576891354, 0.005945214802669662, 0.04343253898344213, 0.07244228535602171, 0.04360871239294929, 0.03762163950370685, 0.024117348009660363, 0.07507016611916405, 0.06992927947712523, 0.035110422440113566, 0.023240874476370313, 0.021225571024021315, 0.08754484310385682, 0.015596431649981007, 0.06360795476563996, 0.013157792798724147, 0.05929294154949247, 0.04322181883898955, 0.05251217858805772, 0.01308065253279863, 0.0054588059485409296, 0.012705917751807119, 0.04812561275978242, 0.023164104805478168, 0.004005655421004181, 0.09486683569247685, 0.05569345828506255, 0.0921788170272785, 0.028379108538971316, 0.05195709426076182, 0.04634862585413841, 0.06312759465447838, 0.01909651500623553, 0.01095124986022711, 0.006215205733408972, 0.052508087678542065, 0.014725755487057953, 0.05148588890029539, 0.02870161814855472, 0.08129705900266286, 0.019929463254107584, 0.030785174289297675, 0.04309263726275775, 0.012833008865615534, 0.0943866441206586, 0.055649281824908914, 0.0353634421293053, 0.06667581897589468, 0.029980963914685195, 0.014340695756066953, 0.01973016739582583, 0.05068561430239389, 0.03521683588323574, 0.03263671687173267, 0.0695610210119236, 0.04222910678494842, 0.05303866485314024, 0.06861978240551488, 0.02809992120150597, 0.06039369498349487, 0.0592644200960715, 0.027933105555993896, 0.04576127390347181, 0.04161982173700968, 0.008803632489645915, 0.04430945684772827, 0.023276438193035223, 0.034704162183428006, 0.030759004725804253, 0.010627618889444539, 0.006809737843145887, 0.07115464477289109, 0.04264616888136633, 0.007830507388608831, 0.02347448149756078, 0.04306319650382765, 0.07365588354127062, 0.05377736896456731, 0.02248822756472134, 0.06299736736822995, 0.021182980365870942, 0.051243157771926735, 0.05132505640147194, 0.03990705981249771, 0.020025718371353803, 0.053398220559522036, 0.04824615669466796, 0.030915162173069777, 0.01221534473100497, 0.017852347997588017, 0.007875081256873185, 0.015769581885016974, 0.04975495920065911, 0.06109800940800098, 0.032576858591769016, 0.009744477518383535, 0.09129492776288141, 0.07798239573716156, 0.04641599179576001, 0.039409389944687005, 0.0265406986187783, 0.04142006048031392, 0.028761539630772128, 0.018588321005565026, 0.0796716349319585, 0.06382547010998092, 0.0407893939184085, 0.03036241632916274, 0.007849992834962904, 0.07712611628155555, 0.0212797966425217, 0.014562881363916301, 0.017445359957374392, 0.007598182128276677, 0.05933427199300739, 0.021456971711989854, 0.026978263143269766, 0.09623562030854727, 0.08447096893383611, 0.028482825352600025, 0.03529061015034395, 0.06869744073839919, 0.05368597850564027, 0.0426298588694584, 0.05253267527047185, 0.004245795256968949, 0.03520462444172271, 0.0306511280547467, 0.0490491968699761, 0.029690675963197025, 0.05230417422529671, 0.009133269589754843, 0.027502357298808715, 0.03354075041809871, 0.057306291700731364, 0.01370255217602056, 0.177901734507853, 0.054030354179802446, 0.0650439291231094, 0.0542662134994903, 0.09298162354576973, 0.10346389736139006, 0.06798299480109446, 0.10384629014879466, 0.06396249259611772, 0.05852829770094926, 0.04195563637861802, 0.059894535074671434, 0.02744216768581781, 0.03485112082994273, 0.033674279543300795, 0.03025994632363079, 0.022098394148352168, 0.019047521768257986, 0.06026178996469225, 0.010570964772224186, 0.055847089557397755, 0.059599097097112294, 0.10351384629405315, 0.064089827900452, 0.03054681752297667, 0.04754435120811386, 0.01888346403927332, 0.0720024589569338, 0.03982814509541758, 0.05161570249906471, 0.02658284111549297, 0.03407412764406012, 0.047992367087112325, 0.021608559444787043, 0.07445443061090286, 0.09668332975237601, 0.00145480755177672, 0.02661730932642616, 0.11078391344316545, 0.029573426206385898, 0.165593643342295, 0.024119326431724816, 0.03886625275857026, 0.053733035456389196, 0.04758396944511802, 0.06422655927317758, 0.0469612127410308, 0.00829356157356092, 0.024216966252894174, 0.03820214645877, 0.04803011223914162, 0.03265185093867683, 0.14149412602907227, 0.02286865916703978, 0.09586789044401339, 0.08096935723217265, 0.07254160865540467, 0.06743076798175612, 0.008022864405516415, 0.011647834457577238, 0.012534675075702611, 0.05464517804343374, 0.032635380048304796, 0.06107721395129639, 0.05396642414252124, 0.06385663839718027, 0.06584528773542374, 0.01608751507686271, 0.018754830215907386, 0.02186797979858614, 0.010056660262747638, 0.01118850537515696, 0.07905745458218359, 0.02916610108748559, 0.021235022633787126, 0.03659337330909987, 0.1000227606404693, 0.020560361557610093, 0.04139131686139492, 0.036751995644261765, 0.012814948342800623, 0.020476532386495702, 0.03144605727415652, 0.030375407265138724, 0.030251207175634565, 0.03304291584138428, 0.04885035491878948, 0.08611186798061095, 0.04318439544388845, 0.10027828160673381, 0.0326797480304395, 0.04452840860692724, 0.06150424285160919, 0.020567974556357633, 0.011533034266903998, 0.06635060699115838, 0.008196411091053199, 0.04162773159482787, 0.02532795462156496, 0.011765837853383875, 0.021428678169726365, 0.018777205728955807, 0.023296542255388155, 0.03686379851593125, 0.024192298221732342, 0.030875306448809085, 0.023128267212380326, 0.13581787416290853, 0.11602074493684116, 0.12792480899201286, 0.18006804729661635, 0.13118708716525188, 0.15854439337647733, 0.1512974314391613, 0.11292710569837403, 0.08691474344701537, 0.1135619014741913, 0.18976449876302676, 0.08777355865365075, 0.1637808648088286, 0.10746725068818178, 0.13314470228168274, 0.122610418756883, 0.12158933846700577, 0.15195251322321354, 0.16332245311669766, 0.13306876764662806, 0.10402322581578648, 0.10235948968798884, 0.2383622974758187, 0.15900988372102862, 0.17581912448569653, 0.11381991988708896, 0.11579124031648522, 0.2322491303446793, 0.15165225272217106, 0.12429853180243124, 0.2428500405362537, 0.13439742457722464, 0.09907013030662652, 0.13859626055965502, 0.15026163460025865, 0.09142326281195687, 0.15880543017579665, 0.18623686305457549, 0.10513748537989394, 0.13341434990927098, 0.1113033900037408, 0.13295707202726795, 0.13701047387815293, 0.1425979055103756, 0.09978133569201154, 0.12279225738659022, 0.10146239306777717, 0.13974873258942558, 0.0997124950311357, 0.13639533591847267, 0.2521543622377419, 0.2097180095170775, 0.09530436382779191, 0.11121983279383953, 0.27988709749714025, 0.21142603318777778, 0.15406567483179032, 0.18866367638111117, 0.15754896937118423, 0.1526477073709811, 0.1509337235362299, 0.1114403588637229, 0.09252821440778433, 0.2101959717730361, 0.1381286558124327, 0.11626007080438638, 0.20790471004382258, 0.14877897867512319, 0.11639191453615505, 0.2742823982431043, 0.11983832194199485, 0.10674514387163425, 0.24206316098570826, 0.19447235420586603, 0.23196311907902842, 0.14124317094683647, 0.18148169402153264, 0.16354147765424945, 0.22286109055482575, 0.16098171742933412, 0.18454941650552137, 0.15057300337620322, 0.1408303721297172, 0.13373295055522075, 0.10362339686722526, 0.13091560092664536, 0.058035519304535085, 0.13192934975508722, 0.15891444448742176, 0.19597462198186308, 0.16981754572160784, 0.2117085970577694, 0.1806022710497341, 0.16628813268917222, 0.12760123643543453, 0.15077955600234771, 0.13428232752748076, 0.16563882720806908, 0.1940968638706592, 0.17195485442155795, 0.11267526195414605, 0.08991930198164717, 0.12935667328776854, 0.14036183275522726, 0.22799855278384304, 0.2582328255859114, 0.13602379859695513, 0.18046714846164952, 0.10842716651818446, 0.21459976691872845, 0.12452154765806853, 0.17959932406102458, 0.21302960843088167, 0.15402710996568203, 0.1709456561553863, 0.12744421139359474, 0.1995040043707817, 0.1287810194997057, 0.1864885382594601, 0.11796326046028446, 0.11704246874057478, 0.21627065064685963, 0.11583868414163591, 0.1525327175735466, 0.1445696166446132, 0.193004667638771, 0.17921744455252925, 0.10978364010131168, 0.13786745047377003, 0.12126810247859648, 0.13362001387342332, 0.1548015329265787, 0.16427684545276627, 0.20506537369182035, 0.12377845003239571, 0.1315040177395267, 0.1388826701910265, 0.1291402534491593, 0.19930290629065808, 0.13005293995863007, 0.13215300146370165, 0.22350887918183882, 0.11744546929314253, 0.11880709864800015, 0.1186328213061056, 0.16211667668915566, 0.11857311241328718, 0.11420776722051444, 0.12007959367286776, 0.09580759932437251, 0.14373569929551694, 0.1225654953610032, 0.15193634876801124, 0.1785463208873426, 0.12790574106357752, 0.11558111772061357, 0.1695935722560652, 0.11016676833312358, 0.15038731898511612, 0.11690065820491123, 0.108658961741434, 0.11345604344481423, 0.06552205225753208, 0.11712988703361443, 0.3140643022714123, 0.1078719672776999, 0.16763560473918918, 0.11001970243429947, 0.09962378971038327, 0.09010521619911156, 0.0757440630226366, 0.11983718047098768, 0.11495201397807368, 0.08895858942020325, 0.20158670632348907, 0.3308110762267344], [0.05930280493151757, 0.013239758460962725, 0.10924285863556209, 0.020016567451098276, 0.05989589105029741, 0.037924703886552204, 0.007169452991576926, 0.03648565751650641, 0.07298409337958983, 0.04191643565953259, 0.041404459099735946, 0.011397995948491078, 0.010237531706450448, 0.019928863790306835, 0.04252564409867891, 0.03172615434103195, 0.026593972373032765, 0.015459886053577067, 0.01573602531871368, 0.050162357097912225, 0.016267400182363008, 0.009249354892921065, 0.03802489669572923, 0.06289885612204671, 0.03543880219841677, 0.027645016276848414, 0.04647999461139402, 0.02377734095188639, 0.03835093605542376, 0.02882559415734103, 0.04147122366233699, 0.030020903908617558, 0.06823866132406459, 0.025903506902977828, 0.009091968832146979, 0.02228749337636175, 0.012150139157329837, 0.014430268671393636, 0.035601274125398166, 0.047814301440432194, 0.024055484494554902, 0.01003600365947932, 0.11134775415543588, 0.012960507921243628, 0.013732553136745288, 0.032956206179674596, 0.02624592139205385, 0.0014181043990256807, 0.03349992176217418, 0.01109343673658347, 0.020073344142386512, 0.03150562444070895, 0.017951550638122905, 0.055885842115047484, 0.0200317130093613, 0.047874213346550544, 0.03298838953337362, 0.04178844151958343, 0.0601222891841204, 0.06534831883806376, 0.0048894010439154605, 0.08397065223224702, 0.04331862936998087, 0.05337459823837685, 0.10197681344805226, 0.1018816423452189, 0.020086361891439846, 0.03966073956220381, 0.040497989393770695, 0.029399051188280987, 0.07997704354385216, 0.03541422226736623, 0.059313526332017884, 0.07873299336361309, 0.0560183025475952, 0.05710635424381303, 0.0210395438085881, 0.023343716034545534, 0.061232917491466775, 0.08672601002598963, 0.12698793708677256, 0.06433234835464148, 0.09642930265756385, 0.043188827262530406, 0.06519507060969068, 0.02514541502140703, 0.06987903177017166, 0.0454210082910234, 0.0449905090124136, 0.017124150782042456, 0.055821011924455245, 0.06485225392445441, 0.06198937952097866, 0.06462983561739807, 0.04367079615833298, 0.029079199903794838, 0.07986113444090852, 0.030018165144288254, 0.03555312932979676, 0.03539735684171319, 0.014035229687578978, 0.050420042262562824, 0.02258286815166714, 0.00821044103377649, 0.027630489334584247, 0.07280904994977098, 0.0256948379589425, 0.08786563476127002, 0.06377729084042293, 0.016197134597948002, 0.06600216722055789, 0.02994489074955064, 0.06501720797631048, 0.04306199374578653, 0.032320985225059336, 0.009258920458265612, 0.012982276309612057, 0.017669727958198038, 0.07513037296913325, 0.1037904576608731, 0.04612051934424428, 0.029713480485483047, 0.022684692728122877, 0.02007909937791767, 0.039858091472377705, 0.0629921886138618, 0.008655799545287605, 0.020405895249437422, 0.04813241562055004, 0.03651537023664963, 0.025140513973911444, 0.02566287677074152, 0.028728136282053687, 0.07574661409542446, 0.06016839618584322, 0.017668605639388966, 0.06510715435950026, 0.021355359724933104, 0.054855354265460086, 0.06235264309291398, 0.019366662506194367, 0.060573043827448166, 0.011123272988404478, 0.03112642240950898, 0.025346403934001446, 0.005148499161981407, 0.03681456970591699, 0.05626992795676474, 0.013145883004331302, 0.061201940726248495, 0.029077148703377576, 0.01955087217802723, 0.029625357391553062, 0.07670387926120913, 0.010386128823513226, 0.054111452247466774, 0.019775033335111315, 0.03849607907355793, 0.014839542526451331, 0.03145341554866924, 0.02776501820452752, 0.013537430542431051, 0.011108506643663973, 0.02672858934308733, 0.034906635391375715, 0.03370031504140746, 0.050367645678981665, 0.04487028683445627, 0.04863195091245636, 0.013576361215523174, 0.0344585390731452, 0.024912399803138068, 0.007800392951110319, 0.011811217071578629, 0.026459372639956496, 0.040764047899433685, 0.016320507312493942, 0.01009815158472667, 0.010765003352125567, 0.00833625182314145, 0.09777984672015715, 0.05638352347417705, 0.08195024088866289, 0.03408928469364201, 0.02047598080319022, 0.026909378432338277, 0.05511598886861917, 0.04482036471487053, 0.01687061398350183, 0.03168718727876342, 0.07641186952711114, 0.09577685621597114, 0.052394714326627796, 0.02754167867674222, 0.00936197269062001, 0.013824234709083555, 0.05408868794479678, 0.02676161539350306, 0.06806628388022223, 0.021950483637591525, 0.06804767560454146, 0.03240171557052001, 0.049999456161693226, 0.023437345385431282, 0.047325361144518664, 0.037057997974296736, 0.05987321484773871, 0.011018835094517038, 0.02383240352144405, 0.0408393620032697, 0.04982153607171871, 0.036247775724698464, 0.08689706979860222, 0.042793257762828184, 0.03019870142452419, 0.05430402759943278, 0.07147298494894659, 0.039530006657925346, 0.09181418215795871, 0.05360806736374094, 0.03237404830513462, 0.052633465628229806, 0.05098645319981922, 0.07353698669542229, 0.015331640062222799, 0.03864458904811933, 0.023796485489114158, 0.03212784679846899, 0.03230548343591152, 0.06908182535440692, 0.0055129228783170545, 0.04248171278666105, 0.03583567787802989, 0.03953548418658395, 0.012924808223972158, 0.0702327958518459, 0.030023169613653616, 0.004648921256434293, 0.026610962287973494, 0.0749260496588484, 0.12138923630118371, 0.04336659030448045, 0.017569885634246375, 0.048347544601006855, 0.01890801715724651, 0.04363607322316497, 0.10413845310047751, 0.033088842812444896, 0.030998684909014456, 0.06411207892421274, 0.0877038216699035, 0.02369963665372662, 0.042546198237687356, 0.1112541918372435, 0.036316183545897086, 0.054421415252070275, 0.04139568356256332, 0.040491270802674756, 0.007979884478939518, 0.05413742262809988, 0.026149484328925613, 0.020794491433808883, 0.04877099970115289, 0.021785146541773312, 0.06236338747605201, 0.02853123827897493, 0.05588225299312223, 0.04060618782175645, 0.04698317265138031, 0.04383519479644395, 0.04773598810237262, 0.07670548804585012, 0.10327212257130493, 0.05743135555437016, 0.04907779493218949, 0.04401544379370828, 0.042404165536525755, 0.06116043025207135, 0.046914420090615756, 0.0936453927668833, 0.033654181226607294, 0.04029406444920648, 0.03627516336799149, 0.05132719761722031, 0.05834909058326195, 0.0217308615514588, 0.15679429615697554, 0.01443415848282917, 0.02763337557083897, 0.007901683181238872, 0.044734938250434016, 0.030844766353707642, 0.027860154833404288, 0.02319374474726858, 0.07058859772739873, 0.057372041196832736, 0.06247997073636902, 0.05698911980876038, 0.043099884454521446, 0.028145627922288356, 0.05777719828690733, 0.05002779758445198, 0.012165685954143204, 0.05116223973492461, 0.02913774625818816, 0.009723366050410175, 0.0901866743281003, 0.036558566104260184, 0.03290282517311073, 0.04103307499580326, 0.015996881129760897, 0.032444555207245776, 0.014666569449247853, 0.05241831366513526, 0.07092190726149468, 0.028424648635630167, 0.031070151336250768, 0.033061830552234765, 0.03185999756228299, 0.04018063747113751, 0.017385038194216548, 0.05077915363794854, 0.019909380259172573, 0.03894159750592324, 0.012273369187999879, 0.03947587488519569, 0.004892863761333208, 0.010994363373385803, 0.007490190065225527, 0.03517918649219698, 0.09211318627480539, 0.030436215494128487, 0.05647731178830709, 0.05418248008936644, 0.06535722844062314, 0.043159551212504026, 0.00899574435841773, 0.02033629616151654, 0.029198169527995973, 0.06418203041257878, 0.006179623822155859, 0.0377948404920678, 0.023256357113320022, 0.032737323368388804, 0.009356880121143355, 0.06372051223391487, 0.05849667742187458, 0.030377849170397368, 0.031856105835627646, 0.028787983070698478, 0.03261324010729309, 0.036270731549349525, 0.16825089591645426, 0.14787592955173987, 0.16684702447345182, 0.06581970039875278, 0.23648558124419183, 0.11944920290261508, 0.15008650690076814, 0.10163253353488061, 0.1581647355229624, 0.12975304717979125, 0.16110148761541615, 0.11171796614484442, 0.08194002893663223, 0.09933093727956857, 0.1226464631937204, 0.15753962309850802, 0.1427480127782591, 0.10027065903188721, 0.132209615361306, 0.18047945183371344, 0.13665133185925024, 0.11706638600557082, 0.11761624561322313, 0.19602025017863323, 0.17557774550251423, 0.12136449166122945, 0.15206862150901748, 0.13947568353145354, 0.12361865941314928, 0.18649189372456845, 0.17725402248963235, 0.09063665905306417, 0.1481383299875644, 0.11533426120877267, 0.18016918622437986, 0.08987657725811006, 0.22236564617243507, 0.18821427388296974, 0.13310924773254704, 0.17813833310238777, 0.1458004594690377, 0.12656091201689937, 0.22737590716250483, 0.11026157937463253, 0.09233344421391526, 0.12496374126884247, 0.206698473963526, 0.12812946172010514, 0.2428112918090436, 0.10492886431635388, 0.2409204642378515, 0.14950074075210482, 0.14760036772537619, 0.1866013676889481, 0.06939681772623332, 0.10629212543849023, 0.12708526089667313, 0.12099890684288357, 0.10372428298597375, 0.14260110775789908, 0.08924990201429014, 0.16548274445437616, 0.11372058892682677, 0.23339689859459478, 0.24525014803774897, 0.20665053218122453, 0.06270900804309115, 0.2845234309713687, 0.08127890271885742, 0.07294531400886274, 0.1995915222552515, 0.21758839848541447, 0.21244079325227969, 0.20927468975705488, 0.20128661436178993, 0.16365810687984192, 0.10035392512837726, 0.15317385655737695, 0.2228557126175973, 0.16878822998654458, 0.26413081394087884, 0.1726534346779508, 0.24882220152405002, 0.07412769411119723, 0.1849773838635414, 0.09781163170813553, 0.10520119325167711, 0.09716708363304216, 0.20417113457956623, 0.09510682039563695, 0.15333036832030744, 0.16900635054034574, 0.21722481315655096, 0.13405708235598382, 0.1537995205651368, 0.15081966836606303, 0.23065502394831952, 0.20104768685996535, 0.15880625755075486, 0.19715710933650696, 0.11351746071370379, 0.13871364055141328, 0.09677435631953901, 0.12854043724796466, 0.16637146773357547, 0.20718383662883313, 0.11698882726411666, 0.3480463384860947, 0.15351648172063215, 0.1616020341433825, 0.2359860459522855, 0.07794949226081371, 0.17526559531688693, 0.15430172184301963, 0.1267623318539512, 0.14140620977888185, 0.21918196862022724, 0.056264998180972, 0.18323352259974326, 0.3431992695456551, 0.14366669009529776, 0.17819064158585765, 0.27828692368442015, 0.08875724619194385, 0.12550423162118082, 0.17579096309359998, 0.2129553745110189, 0.15300136420034594, 0.20304244191896534, 0.07242153203415294, 0.21567831146380595, 0.13189728131457684, 0.22616374156167432, 0.16942581432240625, 0.12144490024976193, 0.1490479215018211, 0.17215546220541003, 0.18159908933504937, 0.1385830685255989, 0.1542940916072938, 0.18149778186794252, 0.13363714359941023, 0.15039779906792028, 0.2719251150565763, 0.1208961821131168, 0.07822206634427271, 0.11407596179314199, 0.1625041946047737, 0.06627029033317682, 0.1288551155237421, 0.08258098405936072, 0.061378975984670466, 0.16590878127082703, 0.27921266433212066, 0.20384779951024443, 0.16646937377029852, 0.1762516577277453, 0.17454535009399538, 0.14281075537925766, 0.1782111574204699, 0.11527655180543663, 0.11351943722054844, 0.14823482642250677, 0.1275660270344346, 0.14158158262650813, 0.11409887548295722, 0.14365366660058498, 0.11026420705621282, 0.1464225688288289, 0.17948978880961097, 0.205452217450065, 0.16737956283313615, 0.0635420099171179, 0.1313332414194461, 0.18102535076679724, 0.13474679131421352], [0.019706709783584363, 0.04031982798610003, 0.024678980473489053, 0.06294775551425354, 0.025430922584247687, 0.05876181662202843, 0.054449423426581975, 0.02906694058178654, 0.06239998349619489, 0.036536728767978574, 0.05134302882417556, 0.08979922536039546, 0.052585734520107515, 0.06212305803332598, 0.024412274623530048, 0.09452573504419097, 0.016802499190934243, 0.028571731771432587, 0.043873277027159936, 0.05866830026911152, 0.04345606171315716, 0.03293392068195728, 0.02467679137724542, 0.028028948900980816, 0.034307397586563905, 0.031158797285189072, 0.04779536374694398, 0.09783368737947556, 0.03342115643223928, 0.047924966671534126, 0.016676121496505315, 0.04403559573655648, 0.04218363946664237, 0.011640229119708943, 0.04504375595359072, 0.014729398235137907, 0.033451202400629564, 0.04937234807819609, 0.007526947442637457, 0.013440491691712412, 0.008459146690344619, 0.041369916195230144, 0.03140351832694104, 0.03453609398415974, 0.046467898083069635, 0.042459745215432304, 0.014728120783524168, 0.09798037023433755, 0.018356152314452395, 0.05879553981245526, 0.04727106849332491, 0.015414414904831399, 0.06158254852878952, 0.027216100885022073, 0.09037557628846939, 0.04294358719620974, 0.07000800267222428, 0.04546465232006965, 0.025057839680342905, 0.0007273756460973904, 0.02578005949485927, 0.027618523041206985, 0.02981794231961812, 0.04944052607301743, 0.06622011157413644, 0.04744594338380041, 0.05293928026672333, 0.021789361940576665, 0.06894642697466959, 0.062459650254177476, 0.03533798502758145, 0.005484555121285902, 0.029192900758296735, 0.061392765567307515, 0.02466088930715717, 0.051503535735631184, 0.04169623134657741, 0.0454852064590781, 0.1187107477697634, 0.04434958453320208, 0.043743019097394524, 0.02112744090658042, 0.055659037954624624, 0.015469804976976689, 0.05334739828662527, 0.02440684689058652, 0.06225639946698662, 0.022231925188774065, 0.02062855295897011, 0.052425185473816055, 0.016823095464778524, 0.08510932701850131, 0.029416445214601777, 0.03959056973877934, 0.0014991840326993337, 0.09314801784292345, 0.04632486946760647, 0.038712541047003, 0.02167566300129458, 0.038003446233849374, 0.09242840081212983, 0.10347233965031563, 0.0477086732374324, 0.030063946558643254, 0.03728767879487526, 0.03907344506813153, 0.016057494963939874, 0.02274680522180373, 0.07616442312756855, 0.04118133982222888, 0.07970194903112228, 0.038637682765481934, 0.08765614035749629, 0.041398062265568206, 0.02235906131024803, 0.035585259057341084, 0.03434303982724105, 0.08130260547923465, 0.022372138431115497, 0.04322807394689129, 0.11833120482943713, 0.07473741582925282, 0.05794301418767822, 0.0677285923231994, 0.012402857199401386, 0.06468823449986597, 0.0021562767975528037, 0.013583182270878987, 0.0317391567683268, 0.015970467375741614, 0.04792241559874627, 0.08804381149069918, 0.06578287455223261, 0.0314611051562092, 0.03147227663336502, 0.04351970063702714, 0.03584821107647112, 0.019276022813433123, 0.0612423365424958, 0.04473160959840302, 0.06210074189209169, 0.02276202738885918, 0.0569201106085412, 0.05326400961606734, 0.0353854211918529, 0.04884007018840602, 0.0448676438311175, 0.03450844970141207, 0.05545608977216387, 0.041508922849090836, 0.050540436810303124, 0.020205538359380538, 0.024296966899606972, 0.022740904429566958, 0.040693115818524556, 0.048237836979810274, 0.08177522810236101, 0.05694493568772751, 0.04534813034678659, 0.02626190773181377, 0.010271768175786542, 0.05443543083064499, 0.022202672121385415, 0.03647990419619507, 0.016017035945438813, 0.027086011494600007, 0.01696087446274056, 0.03126889369600723, 0.06275538317558747, 0.05904010572140256, 0.021198771353210175, 0.01504467022905667, 0.08624280006774972, 0.013336869681464329, 0.03771706724599485, 0.012726712250901807, 0.03002058598212898, 0.03399388376443136, 0.024317676171420083, 0.03753882156865251, 0.04389480026739259, 0.043567385779873985, 0.0023470403515778843, 0.06796056374667153, 0.01962260482081723, 0.04739258152943465, 0.03281909942386612, 0.009797698604093205, 0.062123176776954246, 0.04130094912984679, 0.01700359727105787, 0.029236690344048605, 0.004652675087263267, 0.03794842196868793, 0.009280913884961798, 0.08093356560435026, 0.020325457932607784, 0.07922492906331055, 0.033392880126954086, 0.03809568705037236, 0.06682231796965485, 0.056003716233516895, 0.013042792467580689, 0.040397310118761756, 0.059286927759286866, 0.029131477743747736, 0.022322388681312724, 0.06508620951565043, 0.022804803823331193, 0.02508658329926191, 0.014093635273316215, 0.03550701083675508, 0.061056142702939055, 0.01539321054869722, 0.052443835884332664, 0.04885875890331884, 0.0639211085264481, 0.05073366333700476, 0.03057077117714911, 0.029009016673831694, 0.030733624232872844, 0.03750265838818685, 0.028119209380219543, 0.034722996455046444, 0.09095270096534684, 0.01828014107060529, 0.05991826847856564, 0.013626628074674837, 0.05073972692292544, 0.024395840122334422, 0.05507304964046325, 0.013785416076350358, 0.04596921697919888, 0.022776512196287516, 0.057993200607597835, 0.027418463010220762, 0.011640820922630449, 0.024759065389873523, 0.02415812686986981, 0.08602653344672534, 0.02067061310123292, 0.09644190480391826, 0.06697878376730988, 0.013516659983583998, 0.09785683089566809, 0.04872058345485599, 0.027033369762883074, 0.059541414506853595, 0.043874276771901116, 0.04751890559770888, 0.0693082962665827, 0.04172174207445595, 0.05589508496585393, 0.020171568105598132, 0.04962116194468352, 0.06711405957297933, 0.05172758964040587, 0.020587643863813534, 0.002699690732932199, 0.02898527560905824, 0.030212100302319855, 0.03982273268423254, 0.03736504601434835, 0.04955557332704625, 0.04951889686767132, 0.028003899741076657, 0.04001541145806832, 0.014337676412035382, 0.03282445820889646, 0.017767965327948332, 0.014537957650909742, 0.02722793885867202, 0.011100617853263694, 0.027294622982041012, 0.04987485196080901, 0.02572384013253595, 0.04083234463788329, 0.07072630203178815, 0.07081293125426577, 0.03703170966717505, 0.020880894660348856, 0.04695059476240028, 0.016201646855822014, 0.03898206610052336, 0.036311977723192786, 0.04205386034182964, 0.06859241774485958, 0.07689108816726554, 0.10080921118177714, 0.009421851080391676, 0.03555784077053109, 0.034401442540148576, 0.06478140611321696, 0.03552834638544629, 0.005337195236220836, 0.07997402515743049, 0.05983496407767939, 0.03881943329507786, 0.023676937468530192, 0.03716522347061865, 0.09334847240919068, 0.05856348794975108, 0.08199691862588929, 0.029287956947941455, 0.03101557906296465, 0.02035158727648518, 0.05515843780050355, 0.046704692030025106, 0.03865853567878085, 0.029157716255154342, 0.04770280117349279, 0.010277614384258707, 0.013303644448188285, 0.09297082170603738, 0.00510918113568257, 0.021479812623452277, 0.04233658509028535, 0.042526877500237, 0.022738192478315006, 0.023335991953048977, 0.03871084416225072, 0.01811637445503185, 0.027751123284800883, 0.03848213627333603, 0.06122580819552945, 0.01106487985159601, 0.015811456250958145, 0.04653613736492492, 0.005408921654546453, 0.025958431576709115, 0.07761946158303369, 0.04577877901254162, 0.0598004786297679, 0.010849549773059065, 0.03673350228176963, 0.06181769538670779, 0.04530921308023315, 0.06823345192617948, 0.03933709039683304, 0.14135777770030883, 0.009080840447436898, 0.038766565567423264, 0.053668661088111906, 0.022357674691105084, 0.043274016239710396, 0.06868920529321318, 0.03921025688008916, 0.07107045171001265, 0.027988081940660076, 0.016197613402900678, 0.08265312655919022, 0.03067145045215805, 0.07235149627611523, 0.13568751664171297, 0.12438872333375678, 0.1620802109039599, 0.1541160680954495, 0.07837521498121562, 0.12840304703962419, 0.14336365635596937, 0.10942701085080063, 0.145922573884168, 0.1901285590664033, 0.11176976134940503, 0.19293668499637037, 0.15135687986208549, 0.08341549895703794, 0.1467909498680984, 0.09763252035143877, 0.14287187387385678, 0.10364117010706857, 0.26187128357348904, 0.11147894671246891, 0.23708040255212018, 0.08559109673144356, 0.1629513601261762, 0.08573482248691783, 0.19988072044666738, 0.08014163753438382, 0.15869980197279684, 0.1902790340564905, 0.20591524099150013, 0.10223464799984809, 0.23074802702232716, 0.09588104417367328, 0.13587176078750243, 0.13671629611522923, 0.14316243570177786, 0.18361448280272946, 0.1608038318133162, 0.0859959205732711, 0.140827905326601, 0.1399137479283156, 0.2131353132426739, 0.12007289806440954, 0.14797527583376055, 0.14729823796979843, 0.13835092856278344, 0.13196454383432865, 0.18859030047972358, 0.18573764951959734, 0.1417852241185404, 0.11649185070587743, 0.10530430102540601, 0.14636603154001698, 0.11089467443525793, 0.20995198809091123, 0.1489214250637639, 0.1490619562325939, 0.10529903034048696, 0.21057282574474814, 0.07004873556715828, 0.1409352189230342, 0.08004878767796102, 0.08838606127087148, 0.17865816972428755, 0.09115436595053443, 0.17224031410390334, 0.12929714825605193, 0.14246279824404948, 0.20875713607716948, 0.19179476965819636, 0.14352660325746383, 0.1944933756585083, 0.1506495662033558, 0.1994329726984424, 0.1007507510122753, 0.1370795903306815, 0.08052604513302927, 0.08032505430521504, 0.20518420925063474, 0.1585997815334028, 0.14185107703651154, 0.10525228365534738, 0.13811558635244447, 0.07322690494719052, 0.13609403353785315, 0.14129762447649433, 0.13039102988137355, 0.19879080715679354, 0.12444176726163396, 0.11193254737243538, 0.08898371710411965, 0.15325804962025535, 0.13990230257472686, 0.14250539273263949, 0.13332577482346566, 0.24715027591634184, 0.08099796295526528, 0.17430639194865383, 0.13590036651059506, 0.15138007700443268, 0.18819136785403376, 0.14657433084662885, 0.12673948711204913, 0.10633541706709132, 0.10871114765083599, 0.1680166262292093, 0.1495883812106425, 0.16225832634635512, 0.14958073565315816, 0.1851721234138935, 0.16241097702614724, 0.15115800343694227, 0.1888100298181657, 0.17271703529742458, 0.07331462967539988, 0.06745546665643493, 0.17986368568193528, 0.1518131924733039, 0.13825657717402906, 0.168274077737043, 0.13242726094059407, 0.2223496349348176, 0.1498226968631629, 0.1394881094775854, 0.23253239901556125, 0.2168527395734864, 0.1314480167122618, 0.12017684087397591, 0.09880017624386857, 0.11220739673702948, 0.13151630578983214, 0.09315577831359641, 0.27109084530703487, 0.1085526517201816, 0.2191084395012548, 0.16131790745402538, 0.10951825958346167, 0.17780100926756862, 0.15990110444686106, 0.10797858373412203, 0.1514352200132224, 0.1476690092033917, 0.1179258447260626, 0.10864629830804565, 0.11234252698599331, 0.14416359004474458, 0.13551088740989087, 0.14999224744256467, 0.14711040853252336, 0.07779876446171154, 0.125575891485618, 0.12319794690777218, 0.07238609280677573, 0.12059555388987066, 0.13427963089798728, 0.12692822819395413, 0.14865992861169, 0.1625007931743899, 0.16558658001163315, 0.09686335275370268, 0.14295490248309028, 0.18709886518697585, 0.20812921977091223, 0.22791828209113693, 0.08118312640656387, 0.10813212307590632, 0.09125940426583252, 0.11113252175310928, 0.2088508899173429, 0.19204308939797265, 0.15399013856245627, 0.17868895113708513, 0.19409481075502213, 0.14393799247280245, 0.1657398435617647, 0.11140047632638486], [0.02596047320102732, 0.01636055072829608, 0.007264387564763668, 0.10375815939398543, 0.02221391446167423, 0.04046667554986574, 0.07071487966083712, 0.031921280765785806, 0.051254377129577824, 0.0639136276778675, 0.03716369895564933, 0.03948895200606316, 0.07832371089006625, 0.06554911048301766, 0.03489145152871648, 0.041148681494016806, 0.06078856351274637, 0.016061700786644175, 0.038119079545140266, 0.006989755577618077, 0.04087168325279509, 0.044490307224013155, 0.06697757334838952, 0.09298556123770053, 0.04005327152328626, 0.05568732192078906, 0.02967296017994804, 0.05849113860618203, 0.031741334373251565, 0.06449401588930238, 0.03968624645964273, 0.037934885195065896, 0.040907693215675896, 0.05475186344776904, 0.02314562484952471, 0.048498643952752316, 0.02276871342121834, 0.047401851193318446, 0.01425686083929313, 0.010827765105322245, 0.04554815973425585, 0.0486167976933141, 0.0526986826932238, 0.00058331131567097, 0.0998564965782627, 0.008494313956508714, 0.03233965095733443, 0.07121201709754045, 0.0031733308165829872, 0.061428442281941255, 0.06891582176209458, 0.025690419546839212, 0.027089424416302677, 0.01586749366739945, 0.07349758679347654, 0.09016926881046065, 0.06534845673389013, 0.04030070260107037, 0.031188167180986177, 0.04644264782508535, 0.012900012830692916, 0.019969621583098368, 0.06002704147249461, 0.015435686293658952, 0.05789082061739699, 0.01679352255568149, 0.02645889958066325, 0.05919613101850114, 0.06128902194060146, 0.02245952033497874, 0.05245019441410419, 0.06568417944494756, 0.030244059575301026, 0.06172927351848734, 0.06470865074304805, 0.038822244837759964, 0.033976298216129505, 0.012935809246564825, 0.029027678575667164, 0.026121139075727235, 0.06886028804846349, 0.14141976953514163, 0.05223659377905631, 0.03335024350352826, 0.06528587501135565, 0.03834233671847371, 0.09246177926299073, 0.026041157581212542, 0.02119209106651045, 0.0468914489442062, 0.01708521244807109, 0.038047040467180555, 0.04676424004437943, 0.03220509910475343, 0.014778837719331346, 0.027148717706422174, 0.07471575852363341, 0.06628093129444508, 0.09057813759652839, 0.06789287987856135, 0.041981545472217184, 0.0480278178058084, 0.045062816221146815, 0.025941501033582517, 0.07070726474686977, 0.06612138582333442, 0.06764412346866823, 0.03420331688117116, 0.08825458526130646, 0.05669513739825738, 0.056832489302201625, 0.03409337177271805, 0.03713920712471008, 0.04480671302805986, 0.03849713627489344, 0.012017214283978027, 0.03786872201148541, 0.06226704042825488, 0.05356741873847862, 0.04117709569512837, 0.06472594134749905, 0.051080440696809566, 0.014373596359585083, 0.023193896049633626, 0.05013472430648343, 0.04781943805996449, 0.038207884457322865, 0.024726815003481124, 0.028539659500482584, 0.024348126251190424, 0.034797211222711115, 0.07654048036783934, 0.014048982881039623, 0.017301931060970794, 0.02039444031974962, 0.013079390402943378, 0.04549953230326215, 0.022223456086771145, 0.03654866824827848, 0.036124872239006144, 0.08133655083515952, 0.039361302605679924, 0.08719864797087447, 0.024746147232250344, 0.05134530027487105, 0.0255019772392247, 0.06360700864705347, 0.06988482339487923, 0.050116410974653504, 0.03153386818725736, 0.012895087842949697, 0.07172629192110992, 0.03500767472770906, 0.060437185794956265, 0.021066094500823848, 0.04872243738763275, 0.05405267798191598, 0.032759122400274204, 0.021387495198136857, 0.02328252093115401, 0.06298003845938271, 0.0634499989269722, 0.02781473922603313, 0.04319697843804475, 0.05078669194312346, 0.011874374317666216, 0.048631847490586584, 0.062099948991090066, 0.0554564000377732, 0.059050294690795486, 0.03211893336546998, 0.068716807441125, 0.020057028384819146, 0.045229478649074034, 0.06682135269887025, 0.028514616086237857, 0.03780229452757105, 0.031967372445750146, 0.047414549100663395, 0.059027449948893446, 0.039439968344184666, 0.003447861775883564, 0.009592494292695437, 0.02749204767056771, 0.04368821699773112, 0.1133677671332994, 0.016896929103700865, 0.015628622664559274, 0.019542782289546826, 0.08168523575389579, 0.021654946068602226, 0.02732390286250701, 0.023649281694463665, 0.053627552810095014, 0.017553634994152575, 0.017114461685020118, 0.03614410104590558, 0.06122627167872364, 0.031248117391500744, 0.03314246130626529, 0.023990206142526962, 0.04124223232089032, 0.018701610087807623, 0.07464419058974713, 0.010670673988399007, 0.028406092070884285, 0.05391223108275764, 0.05809895521510513, 0.04379160439355239, 0.1819590434071518, 0.023305618482071067, 0.06999095721590905, 0.013360833869345728, 0.03204911019683125, 0.021042813088804967, 0.023275511226646846, 0.026838335268680128, 0.05736817245281512, 0.02288750492997708, 0.021514805604613597, 0.044177425424418146, 0.028355143393480012, 0.04599333342705523, 0.05660956920755487, 0.05405439784930599, 0.0859531115800623, 0.03775089385829145, 0.05351565800787461, 0.029866217350166653, 0.08212443396088578, 0.027417654787460645, 0.04035598350568645, 0.06683980775696617, 0.05912694944849899, 0.05602305995360498, 0.03381021418458512, 0.04293005808346695, 0.045763407458340934, 0.025090946169990688, 0.048908719327300794, 0.04963165734924617, 0.005978187705735646, 0.031168574482322704, 0.04367502879411463, 0.0755476763832473, 0.012610118456875846, 0.05301493527968565, 0.051503999218825376, 0.0417244348735098, 0.022163751024392345, 0.04196762182419339, 0.00845191482033941, 0.07641188484886963, 0.0778039125725627, 0.006934503880104111, 0.07878502605543022, 0.06558807371484657, 0.03369126371258209, 0.050436785114147974, 0.05446937618656986, 0.0342452563645859, 0.07132514530131895, 0.06038813318516459, 0.06634783375287248, 0.027929713701709147, 0.024131365503454884, 0.025366314559153495, 0.0464925354707145, 0.08642368108755158, 0.010638893788470136, 0.03832390847345514, 0.009653987212767525, 0.08681591810478319, 0.03778755499590789, 0.06973614105053487, 0.07438595767223066, 0.054108495148079055, 0.016542686217073953, 0.027731873410483523, 0.039355135597889467, 0.06128568179725159, 0.011950696784732564, 0.09350857712448606, 0.007458779502720122, 0.06984602870239366, 0.08076930103162605, 0.10670166838193133, 0.04919732380057535, 0.019779064872812842, 0.02342629648234335, 0.027860647044895638, 0.05893300662958815, 0.048143665621718096, 0.035535681677321275, 0.04705758277146567, 0.0780923446760543, 0.04208536570771568, 0.07463029375480068, 0.060516690399738095, 0.04452609885183554, 0.09543210132828644, 0.03412166339976173, 0.0292053688392644, 0.03812262653222969, 0.024381650258756937, 0.039753700501375624, 0.05097832883738222, 0.011743382858713309, 0.018099558825093894, 0.040729382420859994, 0.038162738895945014, 0.036041020085254026, 0.015142578180999526, 0.02618398126815596, 0.028543313739881403, 0.10933504965637, 0.022208220513177016, 0.107569768574209, 0.008836877832729972, 0.04303513853360088, 0.06263524143686218, 0.03490120382799256, 0.08145259017305029, 0.20979287162903817, 0.028041608503929553, 0.06218693827489211, 0.022750670135381724, 0.0140355198433803, 0.01933376094506633, 0.01388326465647908, 0.042103253860747626, 0.02132123816878565, 0.0732367108726213, 0.0733674131333828, 0.04306780069225258, 0.061623461454385714, 0.10780413019200487, 0.043362403633974256, 0.030300319157240373, 0.03840993631691222, 0.05762565460416579, 0.01915269223372302, 0.021379615983835632, 0.03596419295776756, 0.06363026324599501, 0.02787794531022589, 0.028004935874994245, 0.05387391136478513, 0.03638016720933299, 0.056118893722492846, 0.04626346369003577, 0.07441319975881808, 0.105631711682485, 0.11968259158874713, 0.12276233399226782, 0.24758959669739972, 0.10996214624854828, 0.115360806155349, 0.13759686821891418, 0.16294645716346082, 0.20262740612510713, 0.30692843840487544, 0.06863607709566433, 0.11068468207433341, 0.2521371252594456, 0.14025683274432538, 0.13634298146972734, 0.137148798713761, 0.17703541163955966, 0.09168744823264499, 0.13159165819806437, 0.16678354642804594, 0.13397921717935993, 0.21637218794034374, 0.1297327611715563, 0.138694227883412, 0.24891629244291016, 0.10651365508355441, 0.0749531998148849, 0.16051406671683635, 0.18794982033150812, 0.16711745351072282, 0.16163650809997515, 0.1851019650817879, 0.14273635292005155, 0.23069076961086643, 0.17863045266318708, 0.08956759867648925, 0.14739692541620425, 0.12388417016594641, 0.1505857970445387, 0.11847280086048188, 0.1268483865104856, 0.13485897722984516, 0.23172045306813335, 0.06657080364323432, 0.14918512784905974, 0.12073472142219545, 0.1060263465549196, 0.20502558308503321, 0.14189278286310936, 0.22357615702334913, 0.23207734278853864, 0.19601905508147133, 0.07914277379431071, 0.20235670129618338, 0.16864642711176028, 0.21610859240735733, 0.13906492250821284, 0.14686274762836196, 0.13447856861016444, 0.0909432627621197, 0.16895830150573485, 0.18390257782753439, 0.11633335477522305, 0.15936510336975898, 0.19928389198837743, 0.06984866404485318, 0.17317584535527616, 0.12045726735865879, 0.13793961595623724, 0.12434225244026993, 0.1774113309840041, 0.18663613275895197, 0.20693605315060387, 0.20960404627746154, 0.16098701875777016, 0.2763424699585284, 0.15827718190848827, 0.15093015356650277, 0.19045307391112853, 0.18139230688252758, 0.24742122589340135, 0.22196148882710168, 0.11641629145390565, 0.1559710121082683, 0.13399360431057794, 0.12452899403269253, 0.12063752784724198, 0.09695535991340877, 0.15296543467669718, 0.15743287640713877, 0.12805012565466667, 0.1104628996202542, 0.23503310918327303, 0.11794327322633998, 0.17624016640888107, 0.23954907492283853, 0.18203756741939053, 0.12896498785384242, 0.2289454374582537, 0.12511489807718223, 0.10896545053730089, 0.09506847003414746, 0.08407425796312672, 0.17182558474521484, 0.1809680933553365, 0.14315273702865647, 0.2839082317246545, 0.12128974446245741, 0.2041265329406146, 0.22126929774399728, 0.167252468846498, 0.1909454232983051, 0.12850768698920167, 0.15511107841326346, 0.11899460632834705, 0.22972732211553284, 0.21710490507464256, 0.12304127426637758, 0.15328241121624747, 0.1197111666683228, 0.16968423110102454, 0.16886548229282902, 0.09002036430061826, 0.11999036741232681, 0.14055166934286395, 0.13771126046776772, 0.08669893647874556, 0.12939387451737158, 0.19089881450899188, 0.15271981156641437, 0.15401612426484787, 0.3249841808311401, 0.11190533592936494, 0.1565504044054016, 0.15503328984543202, 0.1591634537063299, 0.13178647435720892, 0.14962245680151448, 0.11333219001009581, 0.23352388532892351, 0.12096876894394237, 0.13101021278529398, 0.218868653980955, 0.1431804847332739, 0.2873704588461307, 0.10653343547375933, 0.12483919835499219, 0.2819715001650395, 0.12898014107298467, 0.17147571239019596, 0.15359833055446226, 0.15620522050847932, 0.15622328486173384, 0.1249071197103589, 0.1675576323102559, 0.07633394306345333, 0.18406734801828864, 0.14304010678202878, 0.09274280329625453, 0.1475015270613855, 0.2043829578906298, 0.1896786203067149, 0.08955531828706303, 0.15178003618794103, 0.20575911227253177, 0.11299039988267807, 0.07884540144474277, 0.15974278471642928, 0.1019019206925746, 0.14612684356829814, 0.10527284545523506, 0.08147487567076761, 0.11386157974841134, 0.15132095033843673, 0.1927819352356657, 0.12121037775350195], [0.044342877433425, 0.06454205726303401, 0.029655545086209333, 0.0302909096823104, 0.05887570325285197, 0.02757683253636764, 0.05704689432957, 0.09429351847258308, 0.015575848782675402, 0.0288458667590373, 0.011584315234945427, 0.01441215739525374, 0.05010190509980725, 0.03136082807736051, 0.017412186435033238, 0.009780724968520865, 0.005712530438623001, 0.048005137772810076, 0.04398897928636401, 0.0360482634465781, 0.03872233165067531, 0.01998620930187885, 0.038633940425971826, 0.021807213704432213, 0.02099363215928597, 0.09725726750348845, 0.048398359213024385, 0.05881668000872578, 0.06142371168900883, 0.054768100681324164, 0.028580926741743763, 0.008728582686143778, 0.04697040579612217, 0.005031746404711157, 0.06863257607385036, 0.03888170092156337, 0.0485035622372262, 0.00662070373260987, 0.02238238102666313, 0.006566543231583051, 0.05239810426569274, 0.051503692783655665, 0.05462018825534371, 0.016838482340737697, 0.059097930037927245, 0.008456395477086546, 0.022544264981162646, 0.04667591010670989, 0.017929397290572524, 0.012234090902512113, 0.05672300384650308, 0.014264194215948304, 0.10175014335301616, 0.06186314738325535, 0.08789640851318838, 0.04261405064514087, 0.03565322637798325, 0.028477824713674285, 0.04596503796957193, 0.047949573415662014, 0.04734164434334925, 0.025064906841444395, 0.030618475472194054, 0.0168608003971918, 0.08908315531669125, 0.01498276170628566, 0.03029108205209336, 0.026467535306789705, 0.031381456909941575, 0.098421759452791, 0.028388881905665322, 0.032712881333164634, 0.04168297419504773, 0.08299782782072022, 0.05202966576982891, 0.03312404455256558, 0.11879864869819534, 0.06341083268184336, 0.02465220761575526, 0.016671000198731502, 0.05642504160923343, 0.04274667961703193, 0.026298519073715134, 0.01338284070258059, 0.022250395568628466, 0.057448462297719334, 0.08460573146059629, 0.061598080961454305, 0.06885198365536428, 0.0059168571005425155, 0.019604147847501502, 0.08689873220939791, 0.02454330438687917, 0.040918789999259096, 0.03341042354042011, 0.038775126599977096, 0.03365743326984587, 0.033075374986736045, 0.019515434865869825, 0.027602406466499935, 0.01012280716695973, 0.05136226529195424, 0.012922351954564934, 0.03818762909260489, 0.027621529936309785, 0.0297217944546813, 0.022501327668226535, 0.028982341492308245, 0.043844062264167497, 0.04812855453741166, 0.021720551923217795, 0.07757800856545087, 0.08454413799148414, 0.029980012050439275, 0.07544587095898968, 0.06561608188935826, 0.011635250505811025, 0.06739264744664393, 0.02237279726673038, 0.0428684109882001, 0.030709567156830625, 0.09785443304046508, 0.06517364313044856, 0.011539807441764542, 0.041922767376226765, 0.031255332024527654, 0.07262757904226742, 0.028490606890690905, 0.06035864263051941, 0.02606027722058277, 0.013033719113727492, 0.019779700725789995, 0.03530452996792813, 0.011567490028908417, 0.013391719661623001, 0.06277050192077314, 0.05526950905820536, 0.022764118808892467, 0.05982728404623847, 0.025416173476485476, 0.04638275124072548, 0.03499473550266797, 0.019779453662434415, 0.08224226594451936, 0.0203767724169959, 0.01878824888638431, 0.06287322282010029, 0.020913763662740108, 0.051296523456732114, 0.06644634499905572, 0.041057344661244465, 0.04815773482644751, 0.0225140638799677, 0.042034662178447174, 0.026838350590438615, 0.016486941829263684, 0.03398179489698622, 0.05255956495661409, 0.062480763637370644, 0.02537540036193546, 0.04498155727501839, 0.022799479512257442, 0.013835418635168144, 0.028433242226920785, 0.019701994512410417, 0.03447872165951037, 0.05518902386088045, 0.10466674733306132, 0.02805679236658879, 0.030740170454185818, 0.03559609920146965, 0.03077527643331597, 0.02119518606172454, 0.07585099357510768, 0.03939460827818802, 0.10675540178894036, 0.005864150730156971, 0.05358236894432095, 0.02108887412525233, 0.05615559699494512, 0.017019150771140572, 0.027596044106288787, 0.03224094818917013, 0.016108389057579543, 0.007063137224665093, 0.044695546009367516, 0.05408450510473021, 0.04138158371431693, 0.03399570705369115, 0.03700201992966956, 0.013643135354223271, 0.06715819389829714, 0.029224402293743148, 0.03028162278144831, 0.09209542069584133, 0.055753695778548724, 0.01988211327472762, 0.025969980352167642, 0.05827615901287045, 0.033817262193488504, 0.02749108814544255, 0.024506838601683418, 0.03230704625527705, 0.035715988131179925, 0.012175558912267369, 0.03845832626064939, 0.07083162379961822, 0.02292219530640831, 0.05454068365056188, 0.029611443319628318, 0.06289953794029933, 0.07470130244450224, 0.02870107039568886, 0.02286286179667279, 0.01004855122206913, 0.015061497350313492, 0.0346863544696281, 0.07027723661233341, 0.026035511513210596, 0.032824197739002206, 0.05885139911345417, 0.027259536155108965, 0.08128346860288613, 0.03594649632671668, 0.04595613985833141, 0.03244503401219845, 0.04935336441943242, 0.06675608200772155, 0.02119428207797389, 0.08760791512266283, 0.044176628692976894, 0.011240977609920646, 0.03430856970108805, 0.07981709970702087, 0.02549055103783406, 0.01199294270331701, 0.046813281162852244, 0.028846416427122972, 0.03289643983026186, 0.011577872435502227, 0.059018628446445356, 0.020336070165578878, 0.031688987585385485, 0.027138747072087663, 0.01733213599260536, 0.06302504612493419, 0.030145314672300895, 0.06185510729049003, 0.03389719580750793, 0.04815834386634731, 0.036557554868200136, 0.025657736320769595, 0.15417936227975354, 0.0652975884957179, 0.05193925590344495, 0.0538693071763602, 0.055439779760255936, 0.06444665633382336, 0.07563255126437834, 0.0453642564975927, 0.009821307518699718, 0.0428035156801343, 0.05067270189043015, 0.022233568447371645, 0.08180315966808027, 0.02993261227534423, 0.05141337867826224, 0.01820605270744812, 0.04532822738251379, 0.13518235826444241, 0.07235823018896965, 0.060295153093794664, 0.037914698778261105, 0.0498453384235261, 0.026578759782076366, 0.11281344889392776, 0.022025698149997382, 0.06669371478980587, 0.03083060330320751, 0.010633353057557778, 0.02545526694326151, 0.018503271839431217, 0.06323694987522979, 0.015407346786120006, 0.04625215623227339, 0.08717063979636278, 0.02781495181543212, 0.04627898463138169, 0.03634833625607914, 0.08946713390609912, 0.011954512860205387, 0.04032277742460851, 0.05961461803845822, 0.031426225173016714, 0.03604994884001152, 0.1398740645738379, 0.07784724250556001, 0.02691156944380172, 0.02727090298468548, 0.02062522430693911, 0.07775158876733435, 0.054926474037910664, 0.055825907226291396, 0.02094831422812516, 0.032691522801835696, 0.033131173000701016, 0.02692713443520329, 0.024362589991200837, 0.06731359483373743, 0.05212511649475463, 0.02951063955533168, 0.0918218200545638, 0.007962771032320997, 0.030824480345472697, 0.045980861515647946, 0.050182765680215055, 0.05380169225616321, 0.06837174611827058, 0.03304921691456149, 0.08319060618598616, 0.006408910586258337, 0.00227201065788376, 0.04441597371272022, 0.035881037944026535, 0.009605603014689781, 0.07245603663426253, 0.013895207967218614, 0.04079789749436802, 0.012357082488315721, 0.011336495367539747, 0.016378176496213964, 0.03183442171693089, 0.047637610921576146, 0.03971149671762701, 0.012315896643896498, 0.028343893392311952, 0.04584734771220435, 0.07826599382585095, 0.019562899758438432, 0.05203102557589451, 0.012983926271478976, 0.02288340635958218, 0.08952257568917929, 0.02755759223814934, 0.024954170747209462, 0.03439565474588064, 0.04072853589370366, 0.03952734450238847, 0.011245735973540333, 0.04216638333614796, 0.031719449156474684, 0.08118050638586283, 0.11196866075718596, 0.10578586389460873, 0.1528590557075316, 0.12933617277491477, 0.09402580138656402, 0.09682179248381047, 0.13234106072735402, 0.16397460844487916, 0.17540621841626783, 0.14036526482912803, 0.13794815017571374, 0.14289905467341024, 0.07297935895621777, 0.1151050936671034, 0.1030214662633596, 0.10870697247164865, 0.17848590719363383, 0.19690364148587952, 0.2059815995275013, 0.19540503561016054, 0.15355284025351848, 0.11424784127983356, 0.19210779318405738, 0.07816891516408614, 0.05180246707412505, 0.29486589374080785, 0.10477506450467533, 0.1448429261724795, 0.13052393081447772, 0.07269700959084496, 0.14905902977672317, 0.09626343696107788, 0.15942073667482023, 0.1309741147223019, 0.17983523317642752, 0.10450724016634688, 0.1032730112332971, 0.1589143832003878, 0.1484114556543289, 0.11263326501413701, 0.13123073885517736, 0.17413121828388783, 0.06513925344352761, 0.1334355245794981, 0.20370593534842615, 0.13729544326422677, 0.12227408317548615, 0.09673795948225646, 0.23449626540945423, 0.11051259574390228, 0.18819075498369434, 0.220821887074459, 0.1674033575240643, 0.17697988558680783, 0.27373890482610275, 0.09321380181298142, 0.17563066685632353, 0.18054129045096137, 0.17728999797855655, 0.08635610447175081, 0.1597076366024633, 0.14573961676609132, 0.12135041862606041, 0.1264286775802893, 0.18706930951485712, 0.22747171411831535, 0.14508678728053648, 0.1134982395676836, 0.10259700758803277, 0.17479046758624817, 0.09978775550881702, 0.162594347831703, 0.1930248004294211, 0.1424198513550143, 0.15089122097819083, 0.10775431149428892, 0.2242801918257629, 0.15645825934986915, 0.09461914414479848, 0.1232760878760488, 0.23064679616401274, 0.14626426442015558, 0.18011234250039826, 0.06540231271496703, 0.10976186022162439, 0.13681643912869115, 0.2552656444811052, 0.2096862934770123, 0.23943250698428, 0.19435914173241586, 0.12492410387964019, 0.1519814100597174, 0.15714435237309626, 0.19043027513450195, 0.23943983078483613, 0.253180613621108, 0.1193789603008378, 0.12165486196716949, 0.09616805135362572, 0.18648456992401233, 0.16471688635647297, 0.1269392138947883, 0.10668047072906649, 0.12454607779340399, 0.1149285716875907, 0.14833398884342563, 0.15879531781519615, 0.11011000887881364, 0.15276435191833204, 0.2763009786365494, 0.1256772219353626, 0.09590516062152964, 0.13216047848184265, 0.1895148766737792, 0.12054462436466448, 0.20094907602235196, 0.13353035094276552, 0.11931205018153114, 0.17260037542831513, 0.16877171313089712, 0.18347191384002087, 0.17860239852339993, 0.1748385625861345, 0.11910024219222608, 0.19226228247486776, 0.20868466415953255, 0.15871536887941823, 0.09497588064761893, 0.14922035257181815, 0.1420824509114027, 0.08899013692092511, 0.10110177249918062, 0.21445823983559686, 0.13328365530938874, 0.10847380595101465, 0.22352858296325132, 0.12070701202197422, 0.16263458276948622, 0.17206771449456293, 0.14389029583863674, 0.15146155811605916, 0.14789178757177246, 0.08050832551934066, 0.14114262956765392, 0.1078001618565571, 0.10530297569329701, 0.11444444242384165, 0.16238597191629872, 0.22703885911933838, 0.15848142094910145, 0.1476070326903174, 0.1376666894723331, 0.08631362489634946, 0.13065212796772682, 0.1412589063928012, 0.09591966266593627, 0.11435713904399065, 0.12414234945730818, 0.1344409230495653, 0.24204875853273178, 0.12333662414382543, 0.19149242539799985, 0.11955925909381722, 0.10740820829185749, 0.06139700586396841, 0.1775750746169398, 0.1526418544592396, 0.1623516052120155, 0.14779026560004682, 0.1414758931364744, 0.09579538788285949, 0.06822176142445496, 0.13231950301316478, 0.15928700836675783, 0.10246242126149517, 0.1645174277045073], [0.01443943108296803, 0.033575496335904446, 0.04254310324247326, 0.006794752684542008, 0.03205564492682536, 0.056697408848952864, 0.022854109242137884, 0.029272085521370176, 0.04411665166938498, 0.06869483603945664, 0.022617005029573076, 0.0068271007471447515, 0.07390136875572705, 0.06372689757676375, 0.016695645247255603, 0.04800760074548664, 0.047278798320480896, 0.02572927744157853, 0.026048274538029107, 0.06596280562300837, 0.02063481381253129, 0.019630918790015484, 0.024626264048199502, 0.015451815317294773, 0.0116802217821861, 0.08115296552498495, 0.00555300842895503, 0.035963767778969584, 0.028142462063941266, 0.0238012179972664, 0.03837834285091489, 0.02764978517417706, 0.04982747325313188, 0.06835783396156565, 0.03317018985868462, 0.041244170523338744, 0.0097108960542227, 0.038253401571343985, 0.03825281551408191, 0.032186785772923505, 0.011573416676612632, 0.031188138452689015, 0.09027554052731684, 0.03371102112014929, 0.012111914242737958, 0.025554536616489775, 0.031364555095112136, 0.033310150292011044, 0.029097909686125578, 0.09697694061023575, 0.07008369982002244, 0.005680081826980196, 0.04687566753296603, 0.03365287887713602, 0.07659527863706313, 0.04837314725943631, 0.02788558129161116, 0.05387360492961542, 0.03069316712959159, 0.03627137506320592, 0.02398697899714593, 0.03878450351617029, 0.06550169730138394, 0.05698759529379107, 0.08129715093321378, 0.03383599687367678, 0.014330620742252758, 0.035747194722775495, 0.06569156453253762, 0.0723693537856302, 0.018343716792221514, 0.04183329979798967, 0.02005402723537578, 0.032436043970407016, 0.02127679549307833, 0.035308456168540066, 0.050626066288039576, 0.053275562221965486, 0.13731533090674108, 0.051650184116536574, 0.008598527769678304, 0.04647015038156702, 0.04176684933143758, 0.044867731931228796, 0.03597111839260306, 0.13859549447173072, 0.042165659383059516, 0.048237293057384036, 0.056581599337439385, 0.02727533288810763, 0.10850871657772411, 0.029854469391847813, 0.01171848978922372, 0.061200906507550716, 0.036984740816537416, 0.048392762940737515, 0.07155040579457438, 0.014400907394085682, 0.07107308705247219, 0.04251886422054903, 0.04297498530978638, 0.014011830489541736, 0.03970216193626966, 0.026955035357405583, 0.056191967019150336, 0.009255280583015373, 0.04087896491851538, 0.012381817552170927, 0.09376856438334912, 0.045202018227428205, 0.023625381666445927, 0.01164452016969482, 0.042213673943713795, 0.04534932161350885, 0.04880458116531373, 0.041451270902349104, 0.07201162902938743, 0.08091624435638228, 0.013854850455367518, 0.038864142186338865, 0.030751709653545293, 0.08040190058489961, 0.03535101618317347, 0.04457094946936254, 0.03612946493611221, 0.03808906805070658, 0.0355277756499427, 0.08614018259029235, 0.052088539626809864, 0.08166177048077507, 0.045429776167316784, 0.05037087857002213, 0.08708987880738513, 0.015609803714699324, 0.047825559102479494, 0.04825581323295351, 0.03563240793864093, 0.045262654086635004, 0.035503781776154236, 0.021956120129494418, 0.03258342779571972, 0.01732473175281719, 0.029047102734987295, 0.03569883542255529, 0.028767969023676652, 0.05811358366401927, 0.07601320503219482, 0.02662315649250823, 0.01645448268391192, 0.013383468894678499, 0.029744102935036345, 0.03230940580608384, 0.1199281917163922, 0.041068196296691895, 0.07719680321432891, 0.07300947387252124, 0.035925256539016, 0.08575304771863645, 0.09233915156895116, 0.06513387550629916, 0.11604191194618903, 0.010764966005339258, 0.048853522692356384, 0.018425693945778955, 0.04812463982811859, 0.012555840169830669, 0.022275563472160892, 0.0697832707796366, 0.0402750616382447, 0.026955085153120662, 0.03801468474369857, 0.0665614037444034, 0.029614907952265877, 0.023810728978846344, 0.022312069476972667, 0.02018453605893639, 0.039861151993635206, 0.01844602591928936, 0.027490163094273982, 0.04123942843908745, 0.03267248551691732, 0.04859195346192968, 0.03470896555471324, 0.052712728915315483, 0.042338289635916876, 0.02424773808959271, 0.023849023798961314, 0.03315779072563014, 0.033346796107868996, 0.07403207867736779, 0.02083822164774662, 0.03464318924553452, 0.020028476287881215, 0.00990643616645567, 0.03595565490785145, 0.045189236050411585, 0.04810043528015095, 0.01932176017773248, 0.03824757547267983, 0.013588561165717342, 0.01966030592279088, 0.043448492764465274, 0.020016975392917954, 0.006470588803847111, 0.024850333274732676, 0.030765449440467264, 0.025047290649625565, 0.043604782361897736, 0.055449646972720666, 0.031433631328024694, 0.010027003083978931, 0.012616400377854947, 0.05734012597390721, 0.014317563731193304, 0.029958567334218856, 0.031321514360306245, 0.025113884757663456, 0.02562810978551786, 0.03330339339651889, 0.029802821659212633, 0.04103487530242532, 0.030795577763309403, 0.05776099169686918, 0.03242289790162637, 0.03023583753665369, 0.024194820566223036, 0.02595353052921353, 0.03293572864945858, 0.02458206460540814, 0.01086622176151122, 0.04087368657271709, 0.020999730219163244, 0.08428281773963282, 0.07304524251770589, 0.030118057263954997, 0.016345232800250093, 0.044804958686713255, 0.032345503869075934, 0.01495608748237212, 0.023722015997214664, 0.042641231444694346, 0.0171133489423101, 0.028931639878259554, 0.04184217492659246, 0.010066710378704293, 0.04468198625310775, 0.05908552324399353, 0.02194330539374102, 0.02998718071819073, 0.03237915428114995, 0.03449923366368298, 0.004211541071849605, 0.006732798196495541, 0.07238472150939126, 0.07328044683221849, 0.026685713317185163, 0.08799396981034549, 0.040506182704120874, 0.038303407960601395, 0.0251566133116402, 0.08569277958163331, 0.026527663632746667, 0.030928865570815343, 0.020544559078951998, 0.026173060684795343, 0.023918002355663527, 0.0285538187205431, 0.005853375703501966, 0.03591576087919455, 0.03632211306643102, 0.052464983741482424, 0.015872290335415352, 0.057611052968329, 0.01318962566719781, 0.035827499889438195, 0.058449149327052224, 0.07697112137271513, 0.05086236610828389, 0.010417035683208417, 0.12310223954339182, 0.029898421771283594, 0.03485990785843423, 0.021157419842277325, 0.06887468284056072, 0.044460537047275615, 0.0333383499885038, 0.015815083677279615, 0.0626916025254515, 0.05060500270056148, 0.05032035890185545, 0.0485306051409533, 0.12260657299550311, 0.02243078437693898, 0.0907222310742063, 0.032750917598605156, 0.054392775055021055, 0.025206508618148587, 0.07242308719263923, 0.02810286872479464, 0.02793169786943303, 0.0732062818602689, 0.02876392407943645, 0.042073928015006166, 0.06303138933294723, 0.06000129325735954, 0.03994330343219542, 0.012168159460528724, 0.04568669907448273, 0.06479670488906485, 0.04373682144608709, 0.0429316783594268, 0.03240555750146028, 0.010821800153221815, 0.0030529429721120266, 0.03492382640439657, 0.0445045794420425, 0.04868812047906461, 0.05347767153814916, 0.04265639615515548, 0.0781591552039308, 0.0384423992927036, 0.0510400525414415, 0.037503822841831756, 0.06039578640352815, 0.0479035928184467, 0.05498385402343928, 0.01965421169335323, 0.02065244915654823, 0.02800254376545068, 0.034032701439554655, 0.06777264237884553, 0.04646258526331475, 0.04923998340663891, 0.022551745829743244, 0.11152847429677365, 0.009646207589896457, 0.030333205396609924, 0.07645080211542307, 0.06301321006650407, 0.057316917340241136, 0.01902156287894374, 0.03372274226539078, 0.02016438028564857, 0.04919399131810473, 0.015931070346625584, 0.08410896940697586, 0.05165602170651959, 0.04080293452247016, 0.050712021353143844, 0.01312447946533681, 0.01759675233775089, 0.0110746321508721, 0.14725173643279463, 0.14066540275610265, 0.12039045683078228, 0.20263099141659277, 0.09973238267365003, 0.08958704198800749, 0.11157620923533557, 0.11566884244882292, 0.16395734082306587, 0.11328490706340921, 0.11532526733654162, 0.1288130572966991, 0.1798596254159366, 0.09892852661470253, 0.05691108226235356, 0.1508807255736282, 0.12428834283303831, 0.10429606036913973, 0.1601218909866387, 0.12627682363193843, 0.13996296141657139, 0.15841300929746321, 0.16307768802489006, 0.2034242754621852, 0.09420760937275426, 0.1918562865185161, 0.11031804771553125, 0.11981445064227428, 0.1282406670431937, 0.06647171017022864, 0.11957080403883612, 0.06939508636752445, 0.10639381594955923, 0.15579410708479344, 0.10238746721898356, 0.13343707207710515, 0.10573726327669238, 0.11057318563783362, 0.2590920085147504, 0.08365474055491148, 0.07905184681857787, 0.09229027515938205, 0.18724414610093643, 0.11853953477956596, 0.09550824280708067, 0.13649872714473357, 0.17512222962273707, 0.13718503467257948, 0.10416824625985277, 0.22181933355187217, 0.1877702493220568, 0.12970804717511902, 0.22860645887351808, 0.10879253683191155, 0.1423450198865706, 0.12870885401723847, 0.21636006842938163, 0.16487935828345437, 0.20304389748602145, 0.20300741637906722, 0.13644263418691774, 0.14894413190983957, 0.17190358781766507, 0.19225813027831817, 0.10346341472599777, 0.08299187531754856, 0.1667740009725094, 0.11802386567597428, 0.1563179886509334, 0.15005362640705802, 0.08903931210478468, 0.11244168940691218, 0.1389117508886322, 0.10063346295106797, 0.08808000148424218, 0.14387328868671773, 0.10898873961019902, 0.11892846995784391, 0.27637994697978424, 0.17526303658321982, 0.2420243816149812, 0.11052659217027888, 0.08263559846748268, 0.23759723610935674, 0.17965791446547355, 0.22348349102802817, 0.1543963949887022, 0.20805325449234058, 0.2028409148296041, 0.18236367572699824, 0.16014878067278093, 0.13208218429598118, 0.11317819101555694, 0.10327300357241785, 0.18864190416230311, 0.11194115053982505, 0.22184852150178727, 0.09539569683012464, 0.15328533767211824, 0.08546820090663049, 0.23555498359905136, 0.12432490054878498, 0.12340115939056683, 0.19107043352578917, 0.12033056407686203, 0.13018872138232956, 0.150473136154394, 0.12440294958651067, 0.21377971576106167, 0.19090649070999316, 0.10944921207884628, 0.26440145748276866, 0.14850839642026734, 0.06426760626416053, 0.16770948625860677, 0.17141152954389974, 0.1315991965032393, 0.2077607468010918, 0.14145335482974208, 0.19949652735264073, 0.08494464875829798, 0.38404009094642055, 0.13283270531364028, 0.14051619947196978, 0.13024087664821457, 0.10497858342263969, 0.11920044649272196, 0.20093570012719403, 0.11309266495969027, 0.13554298649391822, 0.15982942926066537, 0.19190680235624316, 0.2071538672692353, 0.13386313953707296, 0.10896533562411224, 0.09166796661673055, 0.16177374509073075, 0.09331682531703865, 0.12910698991148703, 0.1225763967921657, 0.1896995038635308, 0.07380753064588194, 0.13011104006680752, 0.2013645867907232, 0.18911818102482827, 0.15137230887288047, 0.1610668297977217, 0.20319584336492325, 0.09965716816124418, 0.15852632902322278, 0.06992695823071465, 0.09534861306629835, 0.24923752843131944, 0.14764999490111105, 0.20229639485478404, 0.14517197625771647, 0.2177332657118959, 0.23787940161362772, 0.13910197052023104, 0.09817578394206301, 0.214006140707962, 0.1598551851366797, 0.1889594016416419, 0.17794305729048868, 0.1254580518411052, 0.09428317628560529, 0.10119057741136321, 0.10590783275303342, 0.1554368496421845, 0.10977375756708846, 0.13136363978828156, 0.1103994905227615, 0.09493830403493297, 0.09779818686506442, 0.11830239226260494, 0.055203836170896414], [0.027932550142248793, 0.03030459201263805, 0.0949836411182919, 0.05428217494139268, 0.036961061038797906, 0.05740304860556799, 0.03890954438717135, 0.03129091297817086, 0.0231912607071741, 0.056996681096573035, 0.05154315397263535, 0.03488041220172759, 0.046595195083007704, 0.018194241546875527, 0.018197826838361162, 0.08212709994686228, 0.05848889396856389, 0.015708923043172448, 0.09599309219347854, 0.02492728297628703, 0.07668663462203357, 0.04220856030681922, 0.03912524027269214, 0.017077773734326326, 0.04917950842589621, 0.04562327465523155, 0.055692879888679714, 0.046996609833572185, 0.016733752375829126, 0.055105949286371476, 0.0899244807360153, 0.05690209988144137, 0.026155421510338787, 0.04559218680726425, 0.026837823904990673, 0.07130060750510424, 0.0334597289592268, 0.0435474521720842, 0.12383836576895368, 0.05841035463456666, 0.037267496208510095, 0.03691689223952351, 0.02291078059633653, 0.02649292537582017, 0.07817421649252215, 0.02920507006497393, 0.03280893343711092, 0.00843193428966427, 0.04559723149624564, 0.0996671579477768, 0.07875271246678407, 0.07318520678147193, 0.13200830277656356, 0.0849601696996439, 0.08472336426136956, 0.09121985880718117, 0.02875567714293157, 0.029516027068659186, 0.029786624645273534, 0.03099504024571469, 0.050971020358584584, 0.04553484895657148, 0.009588615972578768, 0.022175338104247086, 0.05243779145061009, 0.02312090127698837, 0.03521242704723151, 0.0448357324386316, 0.043217057602540146, 0.03649060644449727, 0.07898768695491938, 0.02122366538030967, 0.11749743303704648, 0.0257873488214588, 0.06371995298973014, 0.07181141195037673, 0.04478133636556807, 0.032077081982166536, 0.030029836493814667, 0.1383106170162078, 0.03288838058529842, 0.03619520294089471, 0.08322694173623478, 0.13462441642918896, 0.034797877719205235, 0.1193058678519822, 0.025216657367925492, 0.058893916993251735, 0.046640306170428955, 0.00996327605999766, 0.017398168941238717, 0.09281843915701875, 0.045352688569936066, 0.027008935388538147, 0.06342639575802511, 0.025360974926321257, 0.04867181812803592, 0.04737907539932959, 0.012676566050598219, 0.027828544130428668, 0.027914960763507315, 0.11535794864739142, 0.029696249252846165, 0.02407175811728643, 0.038052368608693925, 0.02152057041624381, 0.043242131660301844, 0.0533807116200126, 0.05307004381451876, 0.05077947539487674, 0.07108961156899891, 0.015718365076839203, 0.019332391562901678, 0.01935434764281156, 0.016769090096556374, 0.09309849025861872, 0.03484321097212453, 0.004588833150093354, 0.05731126361135995, 0.08778519552922057, 0.1101175701666263, 0.04569334105678624, 0.024737902210965276, 0.02993829473252258, 0.017373412809965592, 0.06505201901158979, 0.049220812056333794, 0.02364994627573798, 0.034680187461837646, 0.012809340579194889, 0.027283581739832318, 0.03993655802802213, 0.023063986689873764, 0.056657844238103404, 0.011981242625493438, 0.04219512312462734, 0.003613391830097704, 0.1451259343734672, 0.037007907315367655, 0.03555921589835517, 0.026921227897307085, 0.015354728037040802, 0.024465167249042182, 0.04910419049162058, 0.011770420016780978, 0.038544189395202745, 0.018829937476003845, 0.0380297766758069, 0.05714788387018827, 0.01803410044240375, 0.07353425942241185, 0.037429412721746394, 0.04168890371558167, 0.039601773774671944, 0.02939124475233257, 0.050956453196704395, 0.030025103985662424, 0.04446746631255073, 0.09015348739922048, 0.03960019563354793, 0.021758446462392327, 0.06321043940261006, 0.041794681305726694, 0.012758758666384365, 0.050982791299541155, 0.011830526317710118, 0.04370206403696249, 0.056457140693260785, 0.08297630841092718, 0.07688586344762195, 0.024757755379523003, 0.0378035738944046, 0.040983953438098394, 0.08057522797776807, 0.06577614830025742, 0.053211348732152296, 0.014689657424065857, 0.025837326482419046, 0.05685563281839413, 0.04234668595956699, 0.057282500840242834, 0.0722692184330475, 0.01039453759609211, 0.02627665683957598, 0.038029673253937114, 0.07895450002603954, 0.031211437101686196, 0.03120691526771313, 0.025854917776380337, 0.04982744644005453, 0.03103159221580192, 0.058567613333223335, 0.0408336891221904, 0.03381892843472381, 0.0452225455533593, 0.03859912172981328, 0.10038773258847576, 0.10093343233869922, 0.024077427167926106, 0.03478545943395265, 0.018693811312738447, 0.02158068916610172, 0.026976780763136286, 0.034544769929902214, 0.02360531973892883, 0.03723361213961917, 0.045090935478407534, 0.035206712031316374, 0.033361646722281174, 0.11744901628023195, 0.07203744619243568, 0.02558383181871426, 0.05858231073005065, 0.024731758185812545, 0.0848890997229084, 0.03556353663424811, 0.006743864815366725, 0.0609847050039999, 0.01618445392758135, 0.03330227107770982, 0.0869432036134024, 0.0569322262890637, 0.07948685452462205, 0.05532913751179173, 0.016553840457251476, 0.052677163283430764, 0.04306078332686617, 0.05738623297563004, 0.07366221142752517, 0.028625181725909634, 0.05885327602886866, 0.028049045302454504, 0.06475328302551663, 0.0032226412628416816, 0.036137443741843585, 0.028602614690880143, 0.010030215865211382, 0.04658843818751555, 0.024571205309081464, 0.09052149305540709, 0.022498947050001834, 0.022773269729147998, 0.043314955978383946, 0.04770002410476727, 0.035174858095424796, 0.03320189440743097, 0.0626964518620122, 0.055503430175444776, 0.040392993213308435, 0.1071334508578143, 0.004995279661905502, 0.018024034047078703, 0.010617202966504041, 0.04044600649766865, 0.08964258336251782, 0.057451522818976836, 0.020273950011018785, 0.015570486167205438, 0.057214407115093166, 0.15269802402584784, 0.046473433068322564, 0.08251694676977012, 0.05702699902617643, 0.013032794062558924, 0.052549176804360845, 0.009940309701637636, 0.037260068986084194, 0.01355455260753872, 0.08957221052579342, 0.02354196809803046, 0.06366138939835853, 0.039016386839531125, 0.02793070961601071, 0.05902569560754684, 0.05154190907975839, 0.03175726134119736, 0.025156414128779888, 0.0029196513341664667, 0.06352808243865449, 0.006085195345804096, 0.041862154499657696, 0.04529602104617704, 0.0173416105850089, 0.01804093586190814, 0.020805482880302498, 0.028281489785219875, 0.029667662681951642, 0.028626522379777128, 0.04799375370625527, 0.02738022181626049, 0.06331474610394047, 0.03958495048385474, 0.07115391698936302, 0.01207332447877214, 0.019440814071605285, 0.03756695997811133, 0.07820083038701166, 0.0159601922214572, 0.09290061740865631, 0.024129651381724307, 0.034546049296735756, 0.0862150906675285, 0.03859046493626891, 0.02295625366030201, 0.06699471839613493, 0.03453292621059283, 0.015514538766095235, 0.04845582346822466, 0.06982725188736955, 0.051658940501511104, 0.024965369037442633, 0.06018682826130141, 0.037049119015254324, 0.06796771134700506, 0.041362757103577744, 0.05188406692937978, 0.0463419838718349, 0.05668682151383931, 0.0545178503999787, 0.0963207479986933, 0.06748378892699558, 0.04050732034468844, 0.02625499187307733, 0.015428194911369394, 0.04368295014325169, 0.03996073959335204, 0.07924119310994303, 0.005957063788833518, 0.05887249334444923, 0.07817478339758613, 0.035726134965737025, 0.013843265290732586, 0.07059583725828318, 0.04146119940184778, 0.14395624068715882, 0.0202780868858099, 0.04523543881312494, 0.03398927957600644, 0.04677402681761211, 0.011081613127082106, 0.041501901653264804, 0.041301558169746594, 0.020224510526825345, 0.036865085543644045, 0.02395835412185519, 0.07158474951621986, 0.08372252401445182, 0.10985230456196493, 0.04667227118906956, 0.05421934424028282, 0.044165053104441014, 0.04151618153217339, 0.10187192835033902, 0.08618081589379618, 0.137846183872992, 0.2574838673876178, 0.1583170797675848, 0.20066416792331204, 0.12540506920026195, 0.1335002436873413, 0.17570940537318108, 0.20893451607515737, 0.12144331444775867, 0.16857979278410637, 0.13943489701036485, 0.13867886015965095, 0.1212774487512727, 0.14113899831089283, 0.12896630552507218, 0.1148664496178108, 0.24311594965477146, 0.06883927425670047, 0.16618506321983953, 0.24761320752722604, 0.18632405918211709, 0.12331770177209571, 0.19220701689201017, 0.155802580017236, 0.19315583210799003, 0.10250482422810409, 0.1279634198233966, 0.14473833984905674, 0.15805892345886077, 0.13905310943242044, 0.1300836907279107, 0.20272673708536934, 0.12509576886171295, 0.14374935098232763, 0.12815093516462273, 0.13461750631611194, 0.20697426561626697, 0.11670890639746383, 0.11600467241218976, 0.15312148678687312, 0.11664414898522439, 0.1952997751293644, 0.14913240567811076, 0.22947089716551766, 0.18505252176715484, 0.08963368908171693, 0.21587305101415805, 0.16815749447672598, 0.17620137171639552, 0.2731936647286338, 0.19584601114113487, 0.19243095971403584, 0.16244845404740305, 0.16552564537813588, 0.1309801974604207, 0.15251030184088216, 0.21996379199047245, 0.0747373238987019, 0.13254110160614216, 0.14520392212415897, 0.13603718981387156, 0.21326352571768148, 0.19085752236987316, 0.11621636548830618, 0.15632048609756655, 0.17832594803504406, 0.09537682042367036, 0.13874615332291973, 0.128539533264214, 0.2071074270192654, 0.2647378620120787, 0.2174436691547594, 0.10690502642143158, 0.17113743860635067, 0.0501457444812742, 0.18756124521455458, 0.25829821885112797, 0.22052559490886428, 0.16673888350206037, 0.21237002204983466, 0.22957790432678116, 0.23905484095936824, 0.14694176193687225, 0.32355410918112726, 0.17752206133257958, 0.10617083073743891, 0.09000395469728018, 0.10671915816924266, 0.1495938051131464, 0.14407562782927869, 0.15031264073425724, 0.10448852463835671, 0.12493246189889409, 0.06492373758866903, 0.15818669160287227, 0.22005503306225424, 0.2824440538402527, 0.1158245804629499, 0.11841661597211516, 0.1476875178876423, 0.12930908390591223, 0.13967405433856672, 0.1436679158359766, 0.0953581432000764, 0.15685339217945454, 0.09805587586015464, 0.2572382289555765, 0.15731594074637661, 0.12569555441939062, 0.07599524027037044, 0.16847709103697733, 0.13618473834808797, 0.08005655580951322, 0.13474892103864303, 0.16514102327487162, 0.07038713958595069, 0.10035739550667425, 0.18259878811095992, 0.21006587472173477, 0.16545842882365952, 0.18721373241034248, 0.13279801685242884, 0.17926678061485293, 0.15597214591839623, 0.16939230563659824, 0.1197239296931413, 0.1396679256351725, 0.1038580572593116, 0.11788033910336033, 0.1341772815513034, 0.12086962184478199, 0.13345513643035967, 0.09750017100164006, 0.16578921026760535, 0.13549363510983606, 0.20245882081648997, 0.18261731211696902, 0.21956035476778785, 0.16306394440752847, 0.21588707042317237, 0.15041921888628315, 0.14447627649191888, 0.21635547190183596, 0.11228887784865596, 0.1324343702365314, 0.13689655660381242, 0.0990472166168113, 0.19325548482518043, 0.17597932879242206, 0.1123728947113118, 0.09183027000436861, 0.13420060126771852, 0.1479676762415517, 0.11927658031063697, 0.1345778382833927, 0.13348579526908938, 0.2628520293341529, 0.12301849847238873, 0.11831300258035622, 0.11900890918989336, 0.08678234813194122, 0.13105263873454065, 0.16017557842837227, 0.21185943977006022, 0.11223722053992172, 0.1716925305945258, 0.14984414732504278, 0.2507718186825514, 0.16602659027182287, 0.14656123074312366, 0.13513101505175715, 0.15754811135270905, 0.1575373095129767, 0.13441435512035124], [0.04217882843447789, 0.04194612156659846, 0.05720330650107034, 0.03975286929597778, 0.03732301076994308, 0.021552251982352427, 0.06531479483049724, 0.04078220801367875, 0.030268710369484562, 0.05470826155355862, 0.017712661440694527, 0.0334178124584498, 0.09582815346338096, 0.03777413696591412, 0.05241883460492377, 0.08792387276527383, 0.05372644326980076, 0.04627613478430337, 0.031101631804279266, 0.06724033384553849, 0.031352736273660295, 0.06906995865245981, 0.018539119008628112, 0.03213377631900292, 0.01755971773227136, 0.006880782443218895, 0.027178897740199204, 0.027928618195977424, 0.03682920964614999, 0.03297005321890597, 0.04849157296121121, 0.019406049001601436, 0.02398503696425788, 0.07804028900159944, 0.03936263559866817, 0.024713033081723318, 0.03282875596215168, 0.007158041633139815, 0.08242381346081534, 0.01678967870952141, 0.021565321442340652, 0.11018147722126977, 0.019537747176664493, 0.05467224776023819, 0.04676222140269895, 0.057806324949788476, 0.03791073427325295, 0.03988856645000558, 0.06300320878865258, 0.0434200057850009, 0.026010659620946935, 0.09821748976866085, 0.028676442584143053, 0.04330151496575244, 0.059478024561559005, 0.05758999321129053, 0.049536348350586436, 0.013621339195167587, 0.04788111962918793, 0.026001914727291273, 0.056835932867421265, 0.10461999298704248, 0.010408895041403032, 0.00959247897093695, 0.090100497097498, 0.07535122079594482, 0.015963414578788703, 0.0405931490052852, 0.03361547463423303, 0.04370556505877645, 0.02891037902314096, 0.15522508761815487, 0.15453376987528417, 0.07626407584475894, 0.04593301932477663, 0.024486564084767334, 0.051974070769163876, 0.0693856481642973, 0.018318160099067518, 0.018766126182350903, 0.039809119301818074, 0.03285859891724202, 0.023163168262990735, 0.01562927479690482, 0.024961548173920284, 0.046971489810535026, 0.0534533022812778, 0.04932390450830421, 0.030060225286551064, 0.02903408115549434, 0.05800448891316211, 0.021856902167201046, 0.012036543639917529, 0.03251312773734812, 0.08831396473631745, 0.043979211665329435, 0.07285470879005809, 0.026637896024171385, 0.018157465496070443, 0.04227982563597541, 0.032632032244075695, 0.07168462439890831, 0.04168194380678958, 0.04846419297879742, 0.06096197134484688, 0.010688783349319091, 0.05754111680172144, 0.059407613420438384, 0.030819182847476298, 0.023819552396514246, 0.0870714773754439, 0.08409835142834533, 0.15975369380847101, 0.017606755530822183, 0.0282132696555627, 0.05628134649727614, 0.036377815319405454, 0.05291033363450439, 0.013282739823954481, 0.06333413961974364, 0.030388409692433574, 0.049695376712348194, 0.02298790649811347, 0.07856128241626487, 0.016543111395871928, 0.047209218384758125, 0.022204269414707538, 0.03678991699651365, 0.06956616912277476, 0.006108570124788751, 0.03870499125050922, 0.04645979287283075, 0.031944163812084064, 0.04132712252377983, 0.022840287100764054, 0.03622065621217893, 0.04025640356684885, 0.08375778704160645, 0.03421484650443158, 0.02244040069560851, 0.02642335884663607, 0.038255397230386734, 0.0340640650791747, 0.03109036456613291, 0.01885390453671496, 0.06854310466517365, 0.027791203089779424, 0.04943419052588363, 0.07672634095914903, 0.03070831843351405, 0.014504869355850164, 0.07841298311588266, 0.03428939068990369, 0.024652563846640052, 0.06745204990429264, 0.02579312129396825, 0.03227029701754932, 0.006932735174608928, 0.013777053269046931, 0.021086512659225735, 0.03041530512423525, 0.0663564982072961, 0.07443157820812157, 0.08204409432026648, 0.059399956371635206, 0.032633372897943186, 0.024702976262497327, 0.024852982023730878, 0.011589848304978542, 0.03828815515002897, 0.024540816516345067, 0.021802283928639466, 0.06171691652026869, 0.08290045804554418, 0.043204463117064974, 0.04875188963788171, 0.044353732899312055, 0.048607895751633955, 0.05410323978491849, 0.0332575430342507, 0.012383456980328889, 0.015917239586762603, 0.006910507612290883, 0.01643962632384031, 0.022706455370831876, 0.027880145897788387, 0.028640894189236626, 0.04187242007784305, 0.04797851238700171, 0.07458161652809189, 0.03801337473334805, 0.038145785370180686, 0.05648468921501791, 0.031147005276814587, 0.09293926654443627, 0.0698298029601574, 0.11587850539194, 0.026848083737516598, 0.03222249313107422, 0.03394398845792298, 0.0538027111531025, 0.02173228839021777, 0.04317266280732809, 0.015942255230320078, 0.04073838395397029, 0.04594015926423092, 0.032746217649189696, 0.08778619144352214, 0.01980249567197696, 0.02512364088737917, 0.03104499109359759, 0.02028240379126322, 0.005545773207315154, 0.02839169344834743, 0.004214524984314677, 0.022657753246265556, 0.094726656924092, 0.027522076401979696, 0.050682224363328955, 0.024300638375984087, 0.007487202322320833, 0.06226131392102088, 0.03772888798266649, 0.024294816107759555, 0.04601873307218475, 0.05480283127737142, 0.02727131475694478, 0.014672509503490744, 0.027073840272703, 0.03686696245905854, 0.04532631982358233, 0.04640906253048489, 0.043382371715720625, 0.07307766335866145, 0.057659297355360566, 0.020711978018704443, 0.0825839334978692, 0.06756037473678589, 0.05741047965843351, 0.038069597926111, 0.04974146456187291, 0.0061449813262198965, 0.04184443488596909, 0.14197400350484157, 0.06992477488013045, 0.020616659443945657, 0.030239771398144866, 0.04181209831468521, 0.1105153919648259, 0.08715789975418199, 0.026357705111525236, 0.020714979168147813, 0.07295489010791625, 0.027015067922372012, 0.028638207135842215, 0.04490971737991899, 0.07886093004696793, 0.04885906150804893, 0.026303808910832293, 0.006496454326195583, 0.0487834945951979, 0.005319330544631568, 0.05612379285476862, 0.07823169606948092, 0.0604794470352992, 0.06479943982295452, 0.07377309499368553, 0.025991587862071973, 0.052576844069746234, 0.030435520269337202, 0.0547016731974098, 0.04562361556435785, 0.03015999674736973, 0.020644795938184666, 0.07646849874647395, 0.057899439106545145, 0.02942536439326021, 0.03813158976094377, 0.05823882371788064, 0.0455726707173932, 0.018689404391954025, 0.021648480286521297, 0.04622360796577508, 0.03401794658613301, 0.018149925275675712, 0.04362760795160167, 0.0038455851796653966, 0.03735551205013068, 0.024325513250885472, 0.1186740061929149, 0.031232600280594443, 0.01897234747546815, 0.05720779577630663, 0.038681276998813116, 0.0295000120006021, 0.005780298097599899, 0.05116698181917591, 0.07894349134256763, 0.05482094159590141, 0.07114952730555689, 0.02382286381156695, 0.023982844037574627, 0.040882423805493506, 0.028642284638819196, 0.04104502213698241, 0.031477962920982996, 0.07653553910072773, 0.020031569367875496, 0.07151154215417563, 0.05391550610863394, 0.0156549540641267, 0.06812406989235072, 0.09544812022678315, 0.06856421038748757, 0.03774897863848075, 0.08255592532335751, 0.026283337126275706, 0.04566933186123929, 0.01496730205197368, 0.03694152196628913, 0.0498537500689347, 0.05505714948559481, 0.051157991777384476, 0.021507343908231107, 0.04461732460185886, 0.0114535172131934, 0.035299761070599484, 0.06566141131183793, 0.025720850474411444, 0.033786840842015324, 0.04316281857750109, 0.029109571459552938, 0.0447262201698557, 0.04263140636706545, 0.006884121628958853, 0.023222593703277172, 0.033754500440291824, 0.02815157084936096, 0.05753733232737549, 0.0707735083696823, 0.031144789367493604, 0.04201829470994492, 0.006843971918457218, 0.052907089252145066, 0.02966370392260292, 0.02646052943272216, 0.02622273382580569, 0.04656844712313145, 0.08982134231876943, 0.029304071607428695, 0.038249513675128265, 0.04521792987361551, 0.12589528886300902, 0.1740722908007522, 0.22906347628562684, 0.09186616888450039, 0.1342907085293724, 0.2315746205708673, 0.13532172497962752, 0.09928327894979909, 0.133450003641267, 0.15198430587207118, 0.12608786804541466, 0.13399685252337687, 0.2805545132967734, 0.18061414541256043, 0.18998009122667775, 0.10361683149371417, 0.0872852925151106, 0.18806585200851966, 0.21710521150981227, 0.16756992036056134, 0.17957004418055858, 0.12926638216501282, 0.08023595061874197, 0.1416108931504911, 0.09405589332022975, 0.1312750034154423, 0.20898546092212203, 0.09711063827478117, 0.14165557139823515, 0.1556350672317128, 0.09941429530660953, 0.15294853477708756, 0.18308726109323964, 0.18038153047523192, 0.11460054816017229, 0.09530870754632259, 0.17012551306716858, 0.10905974829990057, 0.1977898213531702, 0.07999739083912104, 0.21817244859712742, 0.171786560226352, 0.16302053786573872, 0.2535032745330565, 0.14257195045150098, 0.1767019029226034, 0.11988046443870953, 0.11273339270584046, 0.11874570436174832, 0.2229455594093569, 0.13721437584007942, 0.2020107666330953, 0.12487666771536875, 0.15699124204054957, 0.16718243308846029, 0.21038170212939863, 0.11066973569893068, 0.12060793387072703, 0.12166571743305653, 0.12567330722606954, 0.20075118018975183, 0.22016723429964435, 0.11187358158490351, 0.19905185927787136, 0.1848053358375065, 0.17493933379169435, 0.16818203993381994, 0.20402582302208871, 0.25895769797986556, 0.1010823674920586, 0.07710799064126707, 0.316931922589579, 0.26874848551327185, 0.26847364380955696, 0.221295666490351, 0.1346743193965766, 0.22745446181826054, 0.12449612119986166, 0.15873305018871062, 0.13471536638755954, 0.15121814133899827, 0.17432735211426215, 0.15558113464184348, 0.055726610739985784, 0.10420290407754722, 0.15031904522930423, 0.1204319634745198, 0.2144100682269181, 0.1099117529848891, 0.17760067727536927, 0.1325723426716943, 0.19085122512713557, 0.09379394487628052, 0.1981566242513157, 0.16849581422584672, 0.15428391795965934, 0.1494564302265644, 0.08804289984606928, 0.12444086327788331, 0.17253977787350455, 0.16256600257850465, 0.17794204605442865, 0.11616647784267703, 0.11625367397021864, 0.12818696427970164, 0.17490568721005995, 0.2128314214848703, 0.11421609459625137, 0.07381352911432905, 0.08257527670432484, 0.12182275779665479, 0.2593354099700528, 0.20749034840733777, 0.26282739194650806, 0.11122036905538653, 0.22119599845140214, 0.12594323064531052, 0.16612445034327047, 0.10743748817232349, 0.20695600208015213, 0.13118869594989285, 0.16849423608472272, 0.12190908824484195, 0.13933990210775407, 0.12089108762842034, 0.12405069469804726, 0.12003551297370466, 0.14166997385121163, 0.14355291071678364, 0.1649172643139478, 0.08766992994013333, 0.11398672021084255, 0.22977779198798443, 0.1573976976496558, 0.10720420673850084, 0.28634702666632594, 0.17554618268003389, 0.13064396147045398, 0.22074253568726204, 0.14981051606516685, 0.1250250436245434, 0.1447957657998608, 0.19726082231969605, 0.0726393691354221, 0.0870014416174062, 0.23364161772112693, 0.10626983994077291, 0.14991291137712617, 0.1445537892680976, 0.15322228863594994, 0.1767692880164231, 0.19689702248621374, 0.11779475942133896, 0.11770475175111525, 0.10076629493625895, 0.11169263161718847, 0.13625684254352124, 0.17976630058500076, 0.11163316021162657, 0.12893961502179024, 0.11004440876985751, 0.15769769768080405, 0.22611825126073054, 0.11458987655538706, 0.1514652506598542, 0.12005587559073203, 0.18270490661023125, 0.13201617816042516, 0.11992651398383802, 0.18085570825684458, 0.08477395670788904, 0.12909764363881082, 0.16853463956184928, 0.1323895387712025, 0.14019828830515185, 0.11960665695369245], [0.02698329442571248, 0.04109647643241671, 0.08256340234149849, 0.06829188145216435, 0.05818576063780535, 0.02229970290265497, 0.016579510148374305, 0.01827105526782332, 0.014004477960688454, 0.006368090070018004, 0.01936263096849284, 0.021249873248199304, 0.031878360689827995, 0.042677003920318625, 0.05691615759485191, 0.014185045842051268, 0.020448246505111456, 0.06367241723402854, 0.0358966201724064, 0.042074134858745726, 0.009576583604118036, 0.04064156576209972, 0.03351745751476096, 0.02929458552370629, 0.048539422812961766, 0.0697621880399604, 0.09286540800765639, 0.011357416271141941, 0.051235826310491374, 0.04957359554546495, 0.025171684176330606, 0.04291918346538179, 0.09626906770732134, 0.020824889802644332, 0.022546421518669497, 0.029563685398428675, 0.060753105133171045, 0.0701052958386079, 0.09314619455366366, 0.019484490659388325, 0.04672161491227247, 0.06952358995594325, 0.028958108216043443, 0.07822920628372701, 0.060253336184447816, 0.1562024779137104, 0.05404409396672442, 0.025984034235138568, 0.01744075959938909, 0.04175402885002475, 0.02082896347518169, 0.007495384620157101, 0.021172098086906538, 0.035035912728598045, 0.04039083284536197, 0.02446777769364417, 0.045976016009526874, 0.0986361338366424, 0.05549174350415988, 0.07487826109413179, 0.0508139570123486, 0.026633286090087027, 0.0171814484131192, 0.033695143947918574, 0.03761765584650059, 0.09254199632954213, 0.027433937986291228, 0.022501057622233228, 0.027019336947330067, 0.018489612491741296, 0.034188301557855266, 0.054140172883748054, 0.03500177202025249, 0.06549669474723839, 0.12974835872169466, 0.040940378356965325, 0.04476485398387717, 0.04076612016726886, 0.05540675754027982, 0.014912123611617475, 0.04459189048277275, 0.017439769430746956, 0.02694030157140186, 0.059311657077482635, 0.03640690367789038, 0.031166255151131944, 0.031622217277125005, 0.008498811850234145, 0.021466453965272636, 0.051712290864557996, 0.02215347203966831, 0.0316506008347196, 0.054322149409281636, 0.02527270053002623, 0.07389442033825383, 0.06302480097679843, 0.02944458745450022, 0.0315180542172804, 0.08373095864249815, 0.044804123650875785, 0.0034052021698200057, 0.05104664472802993, 0.044185557447734385, 0.03621981734590184, 0.038581570655468016, 0.0929700019919584, 0.06493614055216312, 0.056883457131804004, 0.03208995608973407, 0.021926616168310566, 0.019794007417775934, 0.044394048276327314, 0.11439796386947555, 0.028848302918636513, 0.03274385043750367, 0.10604991908034972, 0.04256345053774215, 0.033499312722274376, 0.001369873657935269, 0.02952729813724516, 0.019044512957935373, 0.044718540138414795, 0.013587224342289471, 0.05525889107957483, 0.06108393637283195, 0.02294910031430904, 0.030108906343699466, 0.04279156470851552, 0.056475618733994426, 0.048557000700384385, 0.055614233302373084, 0.05864658550689778, 0.018408619761166554, 0.03238070560919662, 0.03552982876557977, 0.0109304515306928, 0.029890391254617326, 0.058170998123504465, 0.052262510533534715, 0.1369973890964062, 0.035272584101485635, 0.053560765264856244, 0.023669527483082587, 0.07955683665650506, 0.004756621727269264, 0.04133645347469757, 0.01797655000231199, 0.05292261019349099, 0.06690027507682962, 0.023690681085891785, 0.058749938428762465, 0.03712408837952441, 0.04579913779912938, 0.030299503273601015, 0.11231264189606714, 0.007941764422632273, 0.0616759691207159, 0.04034500929617113, 0.045948410031175425, 0.028713569120173494, 0.03121936994214212, 0.09296997134844143, 0.030266528934120174, 0.06768585227790379, 0.014746817159316233, 0.053520921031914415, 0.00967239726319789, 0.06632289759093715, 0.015051196340561636, 0.038112621423938585, 0.04134113427191492, 0.07945781979229181, 0.07516549043958226, 0.019782680807815447, 0.03679061413652474, 0.04494307667858178, 0.03843307217222549, 0.015743571284767843, 0.021179498496255087, 0.0602749168812748, 0.004125310693897548, 0.04444318132535104, 0.03772745922868771, 0.007542779128397665, 0.05448058405290208, 0.0176255687350227, 0.05429907867144193, 0.016737473647921317, 0.02025757296641748, 0.015853412971351177, 0.045415676319070404, 0.06204320485853861, 0.00895769851687815, 0.11197243757065266, 0.01704031203482901, 0.02918098617585436, 0.015786085334125788, 0.033791291812855395, 0.03216044383964712, 0.04234313897247757, 0.013619265969722502, 0.019626766593465884, 0.04236643570625494, 0.016357304430716944, 0.012921665348262798, 0.030103135786409822, 0.009214152195190471, 0.04455188537136682, 0.015944696177968818, 0.06274714389996183, 0.03722621556071024, 0.047971663560958645, 0.020890181561210946, 0.04141888070491053, 0.10377833814991098, 0.04982373857450101, 0.07258036504349402, 0.07984130808542814, 0.035453235294910214, 0.049013838081830935, 0.015177221634545395, 0.08569233525063723, 0.02109886965744438, 0.05709099035049158, 0.0343965778818294, 0.06510633464542127, 0.013655343922906587, 0.007611690652406505, 0.05814621134871437, 0.06903535446092006, 0.05686682919340749, 0.05459426383998606, 0.05403459830690296, 0.06514079328025542, 0.06855549996778851, 0.07231599576170407, 0.07763784769321642, 0.041519713197504325, 0.07439109046132335, 0.02660923092926462, 0.03476593185276274, 0.0552534633466313, 0.0128586852600077, 0.09070674077637735, 0.07270718323847941, 0.008597366188863113, 0.09719281652641874, 0.05828684976985378, 0.018973372118066878, 0.037529348891468785, 0.01102478280963917, 0.039443327639732635, 0.03186261375254441, 0.029366036629184123, 0.0401159375154924, 0.0042856878492109965, 0.05336376575512752, 0.015333640509315077, 0.025545330154859734, 0.032913619351963845, 0.11836029318792206, 0.041116567088230964, 0.051329932551109986, 0.007738260347621456, 0.07907033252019076, 0.03627003440933843, 0.04776561655284417, 0.019060259895218958, 0.04497442116600372, 0.004092570968843516, 0.03204426660592998, 0.02766281249932945, 0.05152308629945882, 0.023449007158858642, 0.007418453591995903, 0.04716296199589007, 0.05282515614864327, 0.017698044483099255, 0.006283930523486267, 0.030229936744416916, 0.0699379745750658, 0.02941123773193648, 0.0210533602043025, 0.038733033898977504, 0.042398186220276746, 0.021803046186124126, 0.05642298466315674, 0.0677623461571432, 0.07925774826998673, 0.024400817778622432, 0.023812801246681524, 0.043289039223905534, 0.05021194979969052, 0.04545620237026484, 0.054055340137452855, 0.10705388496599852, 0.02213833988794396, 0.08039623919513919, 0.023882358199766567, 0.05369986384926785, 0.041416490510586774, 0.04838596774084915, 0.007050823318892189, 0.06958825543763177, 0.02585661657635243, 0.0625197000561222, 0.07500361606118179, 0.01600273212628259, 0.021628343665431586, 0.01844578077115359, 0.052034277619133075, 0.011996632374282326, 0.011968033354459031, 0.09233183542927427, 0.04875672365268392, 0.06932115122195213, 0.009025773089829712, 0.017516950873898405, 0.06276970901977151, 0.06315654894757657, 0.049235574570634676, 0.024969040513819745, 0.08748681960447181, 0.046184625581748066, 0.05410386414657678, 0.035572610945711215, 0.012935195418615496, 0.03190996947758381, 0.054921440840248144, 0.03158906099176215, 0.0714830819877886, 0.00917267523736002, 0.0773999161056934, 0.022472432746942488, 0.018150909698658416, 0.06158387386089852, 0.053321523666982694, 0.08269170674705699, 0.06468898526603176, 0.017254627046866283, 0.014295869078787585, 0.08185956672194504, 0.06820479257693214, 0.048520711115411216, 0.04378909545560037, 0.04087149556125364, 0.054808611410760114, 0.013040922255435539, 0.12426218093042413, 0.04519610785909238, 0.04721156261380642, 0.03981018416403283, 0.15455220195074237, 0.13057599414981183, 0.22855333833684846, 0.2119109821656058, 0.1915826552337216, 0.11615159275430827, 0.11460004254214226, 0.13746317055436874, 0.14893152210260593, 0.12066966523566555, 0.0924302394231481, 0.1479555107653141, 0.10176752588801807, 0.13769993768824687, 0.16108360712326344, 0.226269492338742, 0.052800400017370144, 0.1941903572409384, 0.12680061326752748, 0.0859863827786138, 0.08517290465533735, 0.16818199396854447, 0.30164757983819135, 0.12356850363674665, 0.10796343051497975, 0.15068626181492883, 0.14261472880119277, 0.09674470871686937, 0.11803858988587895, 0.08051032500882303, 0.10221756423913664, 0.09949937703148012, 0.1481737845367001, 0.2569059613010576, 0.13174588701898052, 0.20089600145095782, 0.14058246607742003, 0.15015801354762048, 0.16380061455551656, 0.11067154366643199, 0.13730898769872804, 0.2517207871161161, 0.16404829078143643, 0.13345918137459986, 0.16598053306581514, 0.28268803752237753, 0.18103918631470975, 0.11587836749611363, 0.1716962691035963, 0.1400986968749954, 0.12436662169714129, 0.08684147479793719, 0.19670153216969585, 0.14584584251767205, 0.12334511239802647, 0.15407024071581904, 0.11881473654460524, 0.2898607961833477, 0.1220619381074944, 0.19785853943997816, 0.16846046692902045, 0.2014525336844306, 0.1675862686768655, 0.12036866929021575, 0.19945894307907552, 0.14009730259497322, 0.05439380544327921, 0.1620394397046297, 0.14686011228590243, 0.13508763915348437, 0.09045734085262784, 0.14630284460802234, 0.17158036000065266, 0.2119524275223094, 0.1796374292743783, 0.14208700147367295, 0.11430129123431061, 0.1839149271648738, 0.21356966977398242, 0.11805817875410281, 0.19724931567907336, 0.11228885486601822, 0.11195883950999669, 0.11708844167691086, 0.2532022785876067, 0.10435190817881977, 0.07332950710288941, 0.10408010018328506, 0.14754341674908517, 0.21880070198207133, 0.21117415880003285, 0.1704837970675961, 0.16434216210919042, 0.1270571531307313, 0.12626719390673022, 0.10203852183035306, 0.15549334096572093, 0.15753879572354978, 0.22327313860577924, 0.12678601929256994, 0.12105119234371571, 0.10647317499763544, 0.1295748704503621, 0.1208585825177931, 0.15397641026685316, 0.25772475607452855, 0.2093502566699059, 0.11809148825705053, 0.15468764629575515, 0.0588420260277006, 0.13858142909744095, 0.14835968343240602, 0.29148033669879364, 0.20671154342351422, 0.16746047703969866, 0.14380706804654292, 0.1768135066114126, 0.14142600549084527, 0.10661374447086167, 0.16025416372764498, 0.15642919397402197, 0.17490976279781711, 0.08718348709085295, 0.23365588227827705, 0.09514581427098283, 0.11474605123963087, 0.13299913025431095, 0.1605925754073166, 0.12542966062263136, 0.1901695447703523, 0.18534240943770255, 0.18193714861427585, 0.14420737963049643, 0.10550551401871829, 0.1011831846628939, 0.10714571592548203, 0.12125713976040003, 0.18526140330058916, 0.14459920296024892, 0.18490694973978306, 0.08887552250657352, 0.1452390242728495, 0.16894466514068265, 0.23986841101319561, 0.15587074652073846, 0.12417422637583748, 0.1733661569174259, 0.14750017874663876, 0.15619812653430049, 0.11904569673201731, 0.13774362002168933, 0.08242623429865607, 0.2501123701973308, 0.17532763311699515, 0.25819430668507853, 0.13304943158741922, 0.16935692769625496, 0.14191417203795526, 0.1609817633946096, 0.09042004769247386, 0.13927581119200877, 0.13570253196502888, 0.1845184971968974, 0.13484106609417548, 0.1243694868659781, 0.15714789169930643, 0.20835435769009977, 0.23011632624172398, 0.1539586983140438, 0.22032486455094433, 0.17069562037865962, 0.17050924650844068, 0.1454002244938766, 0.14211263477561936, 0.10586288637451588, 0.10827027171129182], [0.009361159679810367, 0.0403070075046872, 0.06136039069162742, 0.04319435458690409, 0.05874607351518447, 0.030431356581468737, 0.054633985498860005, 0.026685929737023772, 0.06568246340799717, 0.024843367620281158, 0.047932493485390186, 0.022447862391991, 0.042659502641688433, 0.07353743868729762, 0.038600527501154336, 0.031444368050283486, 0.02471562628934701, 0.09249695802047368, 0.02058566352652927, 0.09066004771739246, 0.05775696973526671, 0.09045489703214939, 0.013709029449420351, 0.01650069885316395, 0.0883674683169492, 0.034286533181946126, 0.028874259892730948, 0.03397955025936808, 0.16717412869536108, 0.06983184075403599, 0.04874190751222834, 0.05439599645474265, 0.033513646227337664, 0.07746654277246806, 0.006571674584260872, 0.08994773150451722, 0.05480688005205124, 0.066131689705916, 0.044500760493739966, 0.05586085998783669, 0.01046216400760797, 0.055083476097112706, 0.0750516344522757, 0.018474380748586792, 0.06541511404418177, 0.04287361272520596, 0.01214991220378227, 0.04479819029990224, 0.013238662955231004, 0.02570800126470145, 0.054243039339780814, 0.03425208603843086, 0.06356359061394488, 0.04083577288134445, 0.046785181057789636, 0.0719516137013993, 0.03235332179634321, 0.015224430845269274, 0.026313461618678227, 0.03057642107559068, 0.019379739627061833, 0.028246828137085806, 0.08736177873347076, 0.0739721246364136, 0.053100315778846705, 0.03756912417649742, 0.04822716154458542, 0.11120454933975013, 0.07078083983111767, 0.013324016641314714, 0.013650306894804442, 0.045121295542846766, 0.05432902504840205, 0.02608980607962416, 0.030836659228248946, 0.05103404641211514, 0.04841826983817643, 0.030678827878868872, 0.02017273255924304, 0.05716350440296435, 0.021727172838103388, 0.06067257397057069, 0.058666925141287435, 0.0695775761719673, 0.03257087927552001, 0.06862228751302728, 0.05719438923763172, 0.021426686341123238, 0.0430462736215803, 0.04437874950047943, 0.05165595658904603, 0.029562900158306284, 0.06450426614572925, 0.03343487323652352, 0.04674199668149795, 0.03949515348781021, 0.07590982912769241, 0.046653050043049364, 0.03770198297476576, 0.12171565104396113, 0.040432370132616455, 0.06663770610166174, 0.022314356249426643, 0.03373377393150041, 0.07893920891107091, 0.027841023702715195, 0.026709243707779436, 0.05728766044241287, 0.013377991366019894, 0.014439833279128277, 0.03270767193527953, 0.06998328867578699, 0.0702582452926905, 0.05079309643817045, 0.04597888883924292, 0.12699625680163024, 0.03787215791582581, 0.018978522144137852, 0.007967719002701944, 0.0661393505851588, 0.024783582118670308, 0.014647088790943306, 0.05210137542998118, 0.01914248219691217, 0.036630838839036804, 0.022570943993125713, 0.03191628204207988, 0.03710102530256395, 0.055257841539118564, 0.023769371722254063, 0.021629816469466014, 0.0157542658721908, 0.03980317062908604, 0.06157149388004215, 0.03616095881067938, 0.07506818195144016, 0.04214227454917085, 0.050540387014588045, 0.020983420207255313, 0.05660287359909666, 0.027361979347563563, 0.058988762508717284, 0.047352350422091065, 0.0815709660791101, 0.0428514804450735, 0.13700521851499237, 0.06795118683047834, 0.04053642785537147, 0.008272238473798479, 0.04879919173676641, 0.0591153891817216, 0.09428083971743623, 0.10683816226740038, 0.03195057405279048, 0.07581824331634468, 0.027082236596353115, 0.01926474025352828, 0.02629967969692042, 0.06969952970863351, 0.06316577264618489, 0.009960950983147468, 0.03341896542077584, 0.07249272458495633, 0.034418369252835555, 0.019275080525286255, 0.012311360445774853, 0.023599846040709846, 0.031721331817548604, 0.01472301863794846, 0.02516710297054341, 0.06501973606646061, 0.043853646024100246, 0.03339235535672596, 0.038991994600022034, 0.12091172603710044, 0.058811374849850134, 0.015115411745594635, 0.02517163821105515, 0.025520434212540428, 0.07227459637027595, 0.0104683798535036, 0.08095493179655845, 0.030705250251377304, 0.04099085589029616, 0.04056844266972715, 0.06124611335596251, 0.012928934565054314, 0.026385795640488787, 0.12513673924390348, 0.04144897263857626, 0.028629655679387432, 0.04806208874910109, 0.021303198713388656, 0.07983200777802738, 0.016815913390488397, 0.01229384384538618, 0.015990982252743938, 0.034006095205944394, 0.03024797811503372, 0.044109557695206136, 0.025442936758120215, 0.024222621896995172, 0.08692757541974706, 0.06014360941105312, 0.05148875023869257, 0.09768125886518149, 0.03865355993771265, 0.0398928833554589, 0.021364736641126297, 0.03434798875523191, 0.011337885817122317, 0.06349918560215062, 0.024355978652414297, 0.04060786172387101, 0.015097405806544329, 0.03421547469652949, 0.04076547282297285, 0.02307203827395795, 0.005340806383173914, 0.039983162986895734, 0.03066978421092274, 0.008348052450005085, 0.048399209570620334, 0.023668508586143295, 0.040022712275986715, 0.008335751950770857, 0.03200087921633836, 0.058834426435491735, 0.046387554612010724, 0.023594041009463614, 0.028504241340523286, 0.05002187955523691, 0.04140981788476629, 0.027434763446029638, 0.010431099142278395, 0.04115553032005987, 0.05831819042683609, 0.058861109277894424, 0.05924134552779217, 0.036135497878515915, 0.06877830897968623, 0.010529800952832786, 0.13739344123150074, 0.025751871289685372, 0.02679506853793658, 0.05022418422384128, 0.05361775071510384, 0.04304575268179179, 0.08634330314253608, 0.012992846407747317, 0.033605810435068224, 0.04304502489826372, 0.026011803007173925, 0.04965332231574482, 0.023828831636497093, 0.04319175754884078, 0.04773447124828254, 0.015956234419718385, 0.0429761880678275, 0.029800847067587802, 0.012742387367442492, 0.025742754843386433, 0.04139096829138937, 0.026403835095885782, 0.06927713180982298, 0.06063888142366083, 0.09320506841064462, 0.010058250852800425, 0.04115849891076646, 0.0302242064067433, 0.012279736336260554, 0.03918740064686826, 0.061146410843057025, 0.057577735804502046, 0.050245048628459056, 0.00537943349392604, 0.06857965472004107, 0.03746813846631877, 0.007823379898083307, 0.03518850212135623, 0.06677980008985727, 0.05756465868363458, 0.023988246872660615, 0.027619417448858583, 0.050036427564919, 0.033462004240361914, 0.02233103589875804, 0.027985565341828812, 0.05047587092004476, 0.03610974966338085, 0.0537180929114261, 0.014850141352883752, 0.04044720159483053, 0.03505799138257581, 0.053102196524700815, 0.014198721469109579, 0.04168146117139728, 0.028780845046463995, 0.03568817913952855, 0.037423149952965404, 0.08532575451798978, 0.01511165599954585, 0.017975557918450045, 0.012336598254830368, 0.016711405591077862, 0.021096343482514063, 0.045908971824833465, 0.014776263663905763, 0.03033540789939223, 0.03952356768892177, 0.07484903483982049, 0.0059903718553663745, 0.05067182471975685, 0.049704638715352745, 0.04168696551313324, 0.06185948548297729, 0.012363736919548002, 0.025557373057029424, 0.02178737585763297, 0.026279458806159037, 0.038949503533301816, 0.01993570878591028, 0.053777817126003005, 0.04033699984692278, 0.00532133721618823, 0.04227223370464579, 0.031467078726798776, 0.07360045707994893, 0.058275622751323454, 0.07234405756237046, 0.05643324258046285, 0.02041749765105065, 0.028137626133919246, 0.04714394386316981, 0.061527738768246874, 0.006153277579634901, 0.017882658266312173, 0.01887814164341938, 0.04688661875984362, 0.020566808187492916, 0.045625036657457395, 0.03267575288191438, 0.03399476859598391, 0.06335190136826808, 0.04189506563688478, 0.008211997149872684, 0.11516556098696687, 0.03918847700040187, 0.06485273655984672, 0.04198472090666333, 0.04720924136739585, 0.017585816432631785, 0.12970948742041666, 0.12712345804057776, 0.16966048237537185, 0.10936007774885624, 0.1211270580308572, 0.17460839913016366, 0.09542201195032367, 0.10651830523725479, 0.17318021205644454, 0.09156232309197226, 0.23093628546883985, 0.11582057382310591, 0.18680942184742422, 0.17998434453000947, 0.1828367809855169, 0.17428785262088622, 0.10665227103257373, 0.11209426087237175, 0.0797995486326756, 0.14338326820683095, 0.16098093601965136, 0.18476773624218282, 0.09279914140220612, 0.09839870020627015, 0.1468065167747198, 0.12906483975389313, 0.18035813415002439, 0.1628896287612377, 0.21678392955612755, 0.12975641796665807, 0.1876845087615713, 0.12245282680997926, 0.13143692375911822, 0.1638094092448873, 0.10656669901143159, 0.18248292497329174, 0.09819735697801076, 0.1244091855422143, 0.10408017679207748, 0.15089376439009944, 0.13532849719687817, 0.15688138503220775, 0.1087951415308541, 0.18535550954120775, 0.10394563643081535, 0.09840878192335369, 0.1501327632896362, 0.12202207089191484, 0.13066352735604012, 0.10993500375339102, 0.1741802325892833, 0.15273422934114933, 0.11747530841779326, 0.12288343717133808, 0.06398520710307264, 0.24574560774189813, 0.14115476440037453, 0.12062869485347502, 0.11573081130101798, 0.13199455915920197, 0.15428773307752225, 0.1452698056856471, 0.17716189275585836, 0.11251536408259023, 0.18661031559590371, 0.14974464782543723, 0.3165722289873708, 0.29391180783990895, 0.16705245861122686, 0.1294715711546521, 0.11641020871578686, 0.18841017788696676, 0.1612723099007722, 0.13339145920209347, 0.1355003000747773, 0.11921933822093472, 0.14049706259562125, 0.08568911768135526, 0.11034489143639804, 0.1488386875679416, 0.16100088494919962, 0.15130964288067433, 0.20087202289892783, 0.144797160079883, 0.1087965204891178, 0.1500077377403936, 0.09881630239467468, 0.09623607996130183, 0.10960199299358553, 0.19417954007944754, 0.2878437173222342, 0.1427704897979575, 0.09064709317059287, 0.1177959468576216, 0.1019325259051496, 0.14629876902026517, 0.13519210290283928, 0.13067500335314583, 0.18869566821282913, 0.1382054025006871, 0.1238038075426894, 0.13182868580183676, 0.093417864653372, 0.09773351372249665, 0.15357482697694533, 0.10617664534478419, 0.13587919184036795, 0.2661755945413344, 0.14378370236485236, 0.08544562429550194, 0.1317656367656685, 0.1762921071701473, 0.12361423142494694, 0.2262515045942799, 0.09133289508040875, 0.21665593158573876, 0.11535772648189338, 0.14226585236047545, 0.12846793468681075, 0.10361802659087604, 0.10140305955804164, 0.11105090274565643, 0.1346934869164421, 0.22150623341721876, 0.14765419306293612, 0.10094113918321748, 0.0699167845830802, 0.09966796234009728, 0.12660330732262906, 0.14569634812012797, 0.1326349780203835, 0.10147327917718119, 0.1610795008919893, 0.12046913406060589, 0.19304372280115084, 0.10041568713683276, 0.11372237391169034, 0.19933724235142433, 0.10305558781950705, 0.1373516281525935, 0.09265137070249166, 0.13675404892813775, 0.17625993147732752, 0.1795554425447218, 0.15355310072341274, 0.24308237968192947, 0.11582088025827562, 0.17007499722944153, 0.10920299141998253, 0.15836761092707036, 0.1251623878676084, 0.22780856297862148, 0.1576030858221554, 0.1918177369741663, 0.2477024720921632, 0.09158681492291151, 0.13335946737037552, 0.2648810591668852, 0.2207804723612724, 0.1512082281612581, 0.20106919860887915, 0.11826690706995227, 0.12887463544405278, 0.0806005395227863, 0.11127193443356984, 0.14590040329963933, 0.09208550751810113, 0.15198795245059077, 0.078584288036631, 0.1472349437854944, 0.2107396950164149, 0.1500489532707199, 0.12058665960906975, 0.15922850989285978, 0.16541033382377318, 0.11866277534394495], [0.011875841376041214, 0.019899055309173082, 0.05940349186740576, 0.03223110778978275, 0.029810490199334683, 0.017758239841749592, 0.042492085617155805, 0.01862094102938089, 0.1080522430880416, 0.05040676212839542, 0.04061346948747674, 0.028300781794373068, 0.024588158834845792, 0.017938661208796888, 0.052665005468072436, 0.05339176626875997, 0.025291237942574006, 0.008064668865934497, 0.05704351588182392, 0.029945457654614604, 0.02851126636678894, 0.03448615271237589, 0.005401606472479481, 0.017180935134209933, 0.017999965479717623, 0.040648399266384305, 0.003910054351323315, 0.045945456762227325, 0.013986239322431147, 0.06368949333386076, 0.030388377133696794, 0.022275437067653385, 0.046523290070434736, 0.02878541476093233, 0.02753913526483361, 0.059114140458405025, 0.027508154669175708, 0.0403149901408582, 0.07265467557214922, 0.032241802377205704, 0.03191234243492926, 0.029208502138874708, 0.043443382958010326, 0.03370508776917573, 0.06178588358565204, 0.027019815752282742, 0.07196829909639013, 0.07897041167222685, 0.06104372441768647, 0.014940374061435223, 0.06911028552079393, 0.006785860318960923, 0.10314879007637502, 0.03907706100313414, 0.0417674775235355, 0.02587354520425922, 0.025288493432585272, 0.03585816255860752, 0.053392084195248546, 0.011321842978377978, 0.01397278298804116, 0.034682056716372894, 0.04863511102514402, 0.04057252974880319, 0.030560984403916427, 0.026772145272022294, 0.03241912491859929, 0.05747372021658286, 0.03444738100252805, 0.011158068701925298, 0.03594820087234821, 0.07077051296589837, 0.047970162028627056, 0.005356931576370112, 0.035000117270336036, 0.10479722742832477, 0.09709786758908341, 0.029785969640098275, 0.06303333519627491, 0.08186140533296332, 0.045555789969981685, 0.05986943420383239, 0.06969772940201145, 0.05524205246699914, 0.037049180302288265, 0.03320802694126483, 0.022665732051996935, 0.011535229108807062, 0.06882966751413, 0.032763343544736985, 0.02172837751136432, 0.01088267828773467, 0.041657183845076835, 0.028392706599627292, 0.028036077349116246, 0.018176092923949325, 0.02689733361494878, 0.010610025680263438, 0.05646043487133519, 0.0761991192496592, 0.0314177407492553, 0.042827808328213236, 0.0414020344314556, 0.08128724541635284, 0.03242226970952845, 0.009381288640020836, 0.037478361909668294, 0.03047981355789929, 0.10269250044779432, 0.03214123801538541, 0.030018642034021117, 0.04416399590310551, 0.04038953049589069, 0.01852343144315866, 0.09495803845986243, 0.04269601439215964, 0.00563382160767252, 0.019723933355341998, 0.04668586924972554, 0.07290769909178058, 0.02451066329564539, 0.05112035387766458, 0.055797194250889366, 0.0498465909772823, 0.06082086944051328, 0.032477523801067186, 0.056839112132307024, 0.057072887692840836, 0.032895719707613034, 0.02936690805419799, 0.048330663853595336, 0.07281172359662672, 0.10597140272899021, 0.04298228995814439, 0.03807753459700654, 0.014436202022367188, 0.12904417070169605, 0.04027035402795, 0.0342600763354811, 0.033912563531268994, 0.04926425690251974, 0.05211755137650236, 0.021444856031467358, 0.06260964260887235, 0.018786347073112285, 0.014517778894984195, 0.026437977719451153, 0.04984209021072715, 0.0316514607684146, 0.03983316297132162, 0.0648168146970772, 0.054575824103648626, 0.021359035031749837, 0.01823169175505398, 0.06664990988229552, 0.04030417680980698, 0.02020775618392133, 0.03701116318904585, 0.05317752211985569, 0.08281046569707894, 0.09121466473105455, 0.01725494305813505, 0.04532404454244722, 0.06463783357532756, 0.01092642286582099, 0.015107631165113662, 0.018971060447755362, 0.04474482078465723, 0.0600500202797834, 0.0055713299004691505, 0.018823624911507773, 0.019203901381021547, 0.062410233752621766, 0.03766960809908567, 0.029549677480733203, 0.03779977409830017, 0.021688466245729118, 0.013404323723197225, 0.06702081135083592, 0.06384011771109316, 0.03884565648472598, 0.04119092358216163, 0.0034917442497962546, 0.057551102757814436, 0.04951825718425455, 0.03204967710189521, 0.025657860810057293, 0.02457958056531366, 0.005354630439767554, 0.05597420652667361, 0.012463827264465153, 0.02351029036236146, 0.020828321876545108, 0.031802018112953634, 0.024375234272391088, 0.01850660240668203, 0.054764277902582, 0.04629837048630561, 0.04317706015201346, 0.03257407769260388, 0.03233796556390101, 0.10640696967921912, 0.07181991552633625, 0.033706868923599684, 0.04915848314281433, 0.012557770711399857, 0.050777341840007616, 0.07249507647488387, 0.012521299180544674, 0.057937670724406365, 0.03510464613716449, 0.04740937417673488, 0.03459983632989949, 0.12020967540241058, 0.01158194419281978, 0.014486596243636263, 0.014035405887801562, 0.05742085248892827, 0.08453055525258665, 0.02705908733450117, 0.02628444412332629, 0.08021669882920482, 0.09129400845737227, 0.015893051318163355, 0.022183933610757513, 0.04880386870354415, 0.0227482856867174, 0.0204815789906969, 0.029936209058148727, 0.008933044849864898, 0.008398004255497889, 0.029882276468279383, 0.040140697477205146, 0.04397998924457258, 0.052418336647772984, 0.028421413829369892, 0.012325205569786411, 0.049081108262462, 0.05392104875476611, 0.02851555837438472, 0.029162127006378387, 0.06638198595253691, 0.17664712763601736, 0.05487724139745678, 0.04783633029869488, 0.007279682510171927, 0.007379541113491982, 0.026027369913795305, 0.09489714979164063, 0.0702402958526246, 0.033502108943198, 0.06663660293505078, 0.07218151668747587, 0.06969914666467136, 0.018791979734575557, 0.0800919873760112, 0.08600234805095582, 0.03923377194892495, 0.018446395556712826, 0.05725081161325497, 0.04119362404209472, 0.0522954216707618, 0.04554465105156264, 0.07678709939242372, 0.0953343561700275, 0.03341497793312996, 0.04674966139118037, 0.02489598445414055, 0.021180904267596144, 0.01308739985219173, 0.02846944179656285, 0.010454991509416893, 0.024330538787668752, 0.0027413963201275517, 0.03297446588534982, 0.039349945352202466, 0.021669155084377816, 0.01881678183112414, 0.024297279080436118, 0.06974339590317781, 0.006990032326880723, 0.02911124536166749, 0.021786485280420993, 0.07769875934407597, 0.02207934154167531, 0.059881036605445616, 0.008626487106084824, 0.007956127134797675, 0.05246572684676898, 0.02227403512675195, 0.05912544408572778, 0.05347571801394225, 0.10214764339428756, 0.0030054512664660694, 0.025806215651814016, 0.01654434479743002, 0.008997881743726472, 0.018313634434654828, 0.03205378333316936, 0.0298369815197563, 0.06250221792969012, 0.023258279994009964, 0.0646459847508419, 0.007064948064996111, 0.03860072285357503, 0.04688514021014975, 0.02937261540923388, 0.02529561613506127, 0.008594859166130906, 0.024406917753719518, 0.04351678950291488, 0.02931901989805122, 0.02807576836447322, 0.02111706233042623, 0.009159334773768582, 0.034260467040322484, 0.08268381604143689, 0.043363154400140054, 0.0034960307511350806, 0.04562911990609381, 0.037488029939272714, 0.03748627559792611, 0.005975413031034893, 0.0035226530247112558, 0.015342728227316854, 0.03408332452959111, 0.05909393488940212, 0.0909324532615081, 0.060798239203230034, 0.049578222716527606, 0.016710917210026134, 0.012990117219517068, 0.01997746249300338, 0.03390179233505361, 0.05885773849102759, 0.01805420258953687, 0.023651920867362813, 0.06987966762314882, 0.04171428037807346, 0.049195603933185346, 0.06810353873597999, 0.024597028217789148, 0.04251802535427194, 0.026355054447307225, 0.07311137122732979, 0.015439717831360477, 0.044920140006128824, 0.020535197484517292, 0.033752792064220674, 0.07956407618738952, 0.012363509966000434, 0.03677734166323658, 0.09136965197901573, 0.06708379143909102, 0.10611619334667922, 0.12797044484966225, 0.13596116324826596, 0.1665338017647305, 0.11373525184969749, 0.17694666801441103, 0.16209715676884498, 0.27421813878801565, 0.1191897136009028, 0.10663830524971409, 0.0747519638389349, 0.12812509501893676, 0.14227388096192192, 0.10502090211957694, 0.08673838234596676, 0.13894489185223657, 0.1650579793438796, 0.10975133417354477, 0.14166347742561372, 0.21043463880496643, 0.20563538907276047, 0.22055769399289163, 0.09832966802341324, 0.2340428486105896, 0.20669510317665918, 0.1384090133492024, 0.13084360398352146, 0.12591595025432686, 0.13671793554338718, 0.19113213424721073, 0.2356444779903658, 0.1468077731589156, 0.12896811349257348, 0.14366359510008367, 0.1597035610147061, 0.21227527229535967, 0.13061535574736136, 0.11223954178633229, 0.06765504788246847, 0.10174947685652203, 0.14084999930233727, 0.18971353859430362, 0.14404768094180093, 0.15622644114398188, 0.14751733911614265, 0.18091270519841104, 0.16949436386987088, 0.12981946700282637, 0.19328419780058248, 0.11517555843437872, 0.1449282377237274, 0.14927946391605562, 0.09908987239243523, 0.13140726083469007, 0.16281340301277178, 0.1304513363227729, 0.15371662985172965, 0.14755216547318045, 0.11961243325664152, 0.19279819162141895, 0.13182837936666705, 0.19247421303824072, 0.12974612174495576, 0.11785579364626639, 0.24659818699282987, 0.19700390707340934, 0.14978316672627004, 0.14771964761518663, 0.08964203944009158, 0.14410412630006192, 0.17148760207478078, 0.16059942423335968, 0.18106426803335068, 0.24742476521961151, 0.17134371544084243, 0.10468101189021142, 0.1592941789497291, 0.14845452511743193, 0.37224904784271795, 0.11279468740066213, 0.13492210287480585, 0.10967513906859583, 0.1562627383898343, 0.1316607286853175, 0.11679146003218428, 0.21177143158931888, 0.21350196292323453, 0.17258107001262327, 0.11364413335198358, 0.16737824516190639, 0.0786331108200454, 0.13724053008181436, 0.08083485517530672, 0.1023392956103048, 0.11938401648113806, 0.1300085375025388, 0.09873171862695487, 0.1119660177538472, 0.07091573259282498, 0.1832590333276218, 0.19106623536396414, 0.20870122698045548, 0.08893788972448918, 0.1799809124561087, 0.14660564852097344, 0.12717344527763705, 0.24861244665038204, 0.13404320084279583, 0.11920104404130291, 0.14884631780366744, 0.08566583626933637, 0.1489870175118408, 0.23134025895307142, 0.15464679848763252, 0.20165691062087016, 0.06751152897073377, 0.1490257815608094, 0.13642006523666844, 0.11065889555480211, 0.12230962965517275, 0.12824687235538038, 0.09782787277213029, 0.10557423210552624, 0.20472775874358995, 0.09990762528632918, 0.1424472466591866, 0.211872463264773, 0.15480950024099122, 0.12111355956163138, 0.1664253083928939, 0.14687077622980843, 0.14055283379650887, 0.15430775861586296, 0.17792949753422893, 0.13539018259654123, 0.20701103783663244, 0.07093588070523354, 0.1623432088883654, 0.223666264285003, 0.11638407745668966, 0.12262535747140647, 0.1716091649066056, 0.06547212630750672, 0.16954616673531073, 0.10584752631163406, 0.22832122901754998, 0.11898580397809706, 0.1602751085714948, 0.1707226939259037, 0.17423364423936413, 0.14023429443759305, 0.12459365185350181, 0.1664516924610061, 0.12590404524798357, 0.13331544795824637, 0.11794683553518788, 0.13664065259358577, 0.14759120531380177, 0.20800348942077931, 0.12631604733366159, 0.10927126517579441, 0.16313347454753616, 0.11598636291079945, 0.1904838706456846, 0.11533467489625178, 0.16303520078860945, 0.12491414473662454, 0.06335876168563001, 0.14086257846605393, 0.08840378088456008, 0.17850524325284267, 0.1359358670250062, 0.24821654773287236, 0.1536032948042116], [0.016630345827809746, 0.039400001537174954, 0.053582970323341514, 0.07711612649502293, 0.054514108060468594, 0.037738575164469025, 0.00986705158626841, 0.07784728080995622, 0.017671968765376557, 0.05522908259844107, 0.017913307528942823, 0.02468056052983288, 0.030409337299305107, 0.10263318992069653, 0.07158630467470616, 0.08422618852027002, 0.10221961735477371, 0.028175084002976938, 0.0355115613990253, 0.06446041527294344, 0.029919682626402187, 0.03519777561567965, 0.03686111720819627, 0.040066915549217694, 0.04660068027254555, 0.044885719675690904, 0.04675659448689511, 0.029491834012010408, 0.02340474834425315, 0.07369022726291612, 0.061010824771778244, 0.019483481338548086, 0.0690459034916374, 0.051126658781281406, 0.016818320821790446, 0.016630368810447476, 0.020038253485014843, 0.022048376267775897, 0.12418036274011097, 0.011601055213700862, 0.08594789452129796, 0.02020112377771687, 0.015074756417062976, 0.0066473655075946405, 0.05492297301609671, 0.008273280353375502, 0.02907237597560931, 0.05617920399433183, 0.035008601694097446, 0.06256281931494033, 0.06523768808091841, 0.03863466054862065, 0.06625607174130217, 0.02729751304873536, 0.0692040776653636, 0.06968587802182283, 0.06650571681318745, 0.020454721863291437, 0.024053314550509377, 0.0690214193215774, 0.019866012021779053, 0.04210767801851035, 0.04547663776564502, 0.0713922162990897, 0.09835363125368472, 0.027633166811879606, 0.04588816487681001, 0.01012346025691518, 0.058734831174895655, 0.04461710626680044, 0.036195111010343804, 0.01213866220261421, 0.03629435387049471, 0.05829908419400454, 0.013412193361399396, 0.04014530932650932, 0.057553676813240015, 0.020354435208343694, 0.05682751739157304, 0.03708171222599284, 0.04730127917061891, 0.034732936445863984, 0.057415332825433825, 0.07251596003169976, 0.06661250180895291, 0.019369510438052878, 0.07902068236181814, 0.02789358307998027, 0.0947936283304326, 0.0033710226782732795, 0.0670840059437098, 0.03655947391845046, 0.03097156922693455, 0.049840768709057764, 0.04447063025567801, 0.01278853363117143, 0.015301412147950503, 0.051639255872296716, 0.00831776899435828, 0.02604380441499093, 0.05813528310447451, 0.05514011680779438, 0.017299228685817892, 0.04298949884551187, 0.022420373242048007, 0.02377023548638869, 0.049900060083957455, 0.004938081622258911, 0.04915909984359338, 0.0607618308746286, 0.024978710458643978, 0.0575099331927636, 0.06822312506096018, 0.04566022690625922, 0.053743419778202815, 0.038419278759148814, 0.024924002204751296, 0.004901126019596573, 0.02889770601365355, 0.014517702286191767, 0.027994654975050402, 0.06533134999054094, 0.04452416831026635, 0.03903369276574062, 0.04214887439663853, 0.03313355553414553, 0.05218874392730575, 0.006689235564291238, 0.02113697870123771, 0.02161210068621703, 0.0069598661784473215, 0.06616492260007129, 0.044459066158461, 0.03894933499395847, 0.014023125498375345, 0.09944986476893387, 0.06329750146476493, 0.08227060353683849, 0.0970388022101214, 0.01573348573724469, 0.04379283396467086, 0.04674454392384618, 0.04783996921633521, 0.03371450298976514, 0.06798261175713233, 0.03565388521359813, 0.02141369157470763, 0.07093738223756514, 0.03297697099286222, 0.021862276273989872, 0.06302319219215743, 0.04959604575208599, 0.03952238791351838, 0.0700340803051668, 0.09145253503154363, 0.047327571308180216, 0.025095251584125143, 0.033140955943494074, 0.05576164777120275, 0.007296012153082918, 0.014589314270133694, 0.08579893638530085, 0.10462954610345826, 0.06424687209448988, 0.03435085009362909, 0.04615894631452618, 0.08297492179178423, 0.03185988456431416, 0.05428982815975624, 0.0627376367488215, 0.06183782051647864, 0.027873569032958442, 0.01042121373522546, 0.06526174324174082, 0.06830378645850767, 0.07406923394169539, 0.04908348313502727, 0.05055120800651851, 0.018720455850744923, 0.08301210003874956, 0.032209879493400935, 0.09399996890175728, 0.02538542462242467, 0.08980445008003905, 0.07391460675505862, 0.058764245120748404, 0.03319793756330206, 0.07527042150257096, 0.046979709933962555, 0.03914538072422147, 0.04194167059575839, 0.03863780533954982, 0.09424350825288604, 0.008783996698536701, 0.03600020675108798, 0.05059906934958793, 0.05941331311459503, 0.04025184534369938, 0.04732226614930457, 0.015164961354927191, 0.01444556265919199, 0.04639916467450319, 0.028201998586976723, 0.02080866214518826, 0.04170766137840767, 0.07016733363871613, 0.032131050961212285, 0.05042927362205041, 0.009613022576236438, 0.06161443693863769, 0.04293648173071204, 0.040806267004940784, 0.020145796907825336, 0.047170848871070536, 0.047000091703188036, 0.00357217725738132, 0.021333374916726065, 0.05716722375983673, 0.1898851882546179, 0.005277542363581879, 0.06276227796690599, 0.050030160965698386, 0.01154145357319184, 0.045917877596953226, 0.03983628477961306, 0.030950942309573296, 0.025484062273115404, 0.04765694315034536, 0.08995178410963667, 0.044618921895180984, 0.04689552070152375, 0.10602311366387915, 0.05349672797526564, 0.042516677039525205, 0.014480954963683844, 0.05831801039617389, 0.04682770659846645, 0.059348069236523686, 0.026769383525055264, 0.04235798958688975, 0.0469185263218899, 0.01052175511440803, 0.048000755749883196, 0.031701719966687025, 0.043990319940231504, 0.04427835367800248, 0.05493568241476052, 0.05778279072875458, 0.004929977848434882, 0.023141187285223318, 0.04930807330134896, 0.06609672545305183, 0.026139860349376837, 0.034605907576699416, 0.03030975927568732, 0.06277266611915923, 0.08025713294984833, 0.00345605269220898, 0.06616560441832389, 0.05905319050314927, 0.031542670537507346, 0.06126181049753101, 0.05550303180972415, 0.0334522825846028, 0.047090237269238125, 0.041691680784307183, 0.023157254064215288, 0.03620109415703243, 0.03778790356591344, 0.03245043110162501, 0.03676516469568014, 0.03367231452777501, 0.014340860464970672, 0.07969598886707137, 0.020105860744332595, 0.022460081494383277, 0.019189336134361166, 0.08627668413664065, 0.1335844673937367, 0.07437285756872547, 0.049553029915137645, 0.04029755397970158, 0.011835929152796106, 0.015569268087405833, 0.03366667995109193, 0.012557886582198403, 0.0586393038411775, 0.0568756353740971, 0.048055527206029625, 0.0373701213468467, 0.02121924313776676, 0.05778823761389621, 0.02890636663763754, 0.0168136591767712, 0.03946722192209094, 0.06468430446881442, 0.04320440949091027, 0.12076125870789252, 0.02776605625366492, 0.018922343001430555, 0.046129256577020696, 0.020455539662150607, 0.03993353198072122, 0.05544174477578171, 0.03738313718068023, 0.008279256796794794, 0.05078131017545539, 0.04945480595192602, 0.074697824405326, 0.008995736697538486, 0.030019147652051145, 0.05113404003843185, 0.008218339400275821, 0.03935134346266428, 0.16767040045270998, 0.032364227057945345, 0.010249456822601779, 0.020907418539507255, 0.04023285402405647, 0.025955162296492248, 0.05059879355793519, 0.023299755994230512, 0.038204881392659686, 0.023180343954253103, 0.06895810981551487, 0.024702424679191846, 0.06491399295027218, 0.06813844936268945, 0.06474330089986324, 0.018480243236427347, 0.05836214855193131, 0.03498150899465527, 0.046802885349719756, 0.030018523290392854, 0.015016751112266174, 0.03485813436488952, 0.04148485619694956, 0.03642811282207409, 0.02453865997883822, 0.04091939137827966, 0.1006112770447808, 0.03611445344323593, 0.12805181870897933, 0.022788099276142258, 0.07715734968622846, 0.05167035138114326, 0.08131887718674638, 0.028829907232354728, 0.03580624094953941, 0.06894559193883212, 0.09288296674288089, 0.029096588184456193, 0.19030224652059619, 0.14168684310730428, 0.12564275563964922, 0.2726546759086271, 0.12501043432782735, 0.11795284932539349, 0.24778335565520873, 0.24645828401609776, 0.14994288073672404, 0.2140418097617165, 0.26238588015398673, 0.10071228573759718, 0.10487878514874367, 0.2685132352334838, 0.17683694890189558, 0.27079559502101713, 0.20419656869865235, 0.14851996434792397, 0.14012223109602928, 0.10788180384664767, 0.11678302540413796, 0.12628819237673475, 0.19036289004068221, 0.14286361544603302, 0.17209768385416077, 0.11040446243339008, 0.09437884534558943, 0.11912577590274236, 0.11347686571459617, 0.18004256721225478, 0.1524455061242465, 0.10933674271068267, 0.1360328843997371, 0.08946578559135238, 0.17730063127894558, 0.12730806224769162, 0.10207271999529294, 0.11882057413458826, 0.2048956086077998, 0.12357560527180472, 0.17613862911539693, 0.13875116353794453, 0.3430607914924622, 0.12984441082564094, 0.21414573724952438, 0.13223848155429288, 0.08853940142979545, 0.15540274340779553, 0.14062907486673326, 0.20804740158059906, 0.19799810533802356, 0.14931923920108428, 0.29930794731743876, 0.21713997657981612, 0.13399455425960405, 0.14036238433853274, 0.1503696529975822, 0.17909916057702036, 0.11248780789995387, 0.1927337176617115, 0.09623921326091213, 0.1073264207450613, 0.08944810428205999, 0.10529125454805552, 0.12444691537248513, 0.086360149415991, 0.15509512846267995, 0.13682304280659846, 0.1672860234975815, 0.18236972782160008, 0.24999926497619002, 0.182053042395461, 0.0861994854565109, 0.23779513194195687, 0.10730131604378262, 0.1740070201096035, 0.12821175488493136, 0.20036519444998235, 0.10781338453413018, 0.24057776246580387, 0.08880832127385563, 0.14989579697289776, 0.13094740889726147, 0.13156761835900047, 0.20007293190686934, 0.20401117542097646, 0.16256502198596157, 0.1444368536073354, 0.17724582534884253, 0.1355439670864613, 0.10708916331491164, 0.053724374832405206, 0.1709293844478746, 0.21557433801072262, 0.15876994498314398, 0.08723371947604804, 0.20532357596581985, 0.14064202175265358, 0.1065129732653018, 0.1612114212325504, 0.15097659381647266, 0.19893567438327497, 0.16523808661487796, 0.17791956903473025, 0.18128128542054087, 0.1338112447410822, 0.21211922018518373, 0.08836023644694398, 0.1338647023564385, 0.13735476911308306, 0.16118506780795513, 0.19679861083146066, 0.24055062763152585, 0.11561193743780737, 0.08367567007700283, 0.17982325156129178, 0.10033735464657507, 0.11682819394815354, 0.11842783149932662, 0.16877712171164252, 0.2516062416496777, 0.17490512030499597, 0.11398611500138238, 0.1424535285801657, 0.12568041652200684, 0.15261539378233496, 0.13025247521938818, 0.06235976771060979, 0.12824879523607033, 0.09745016078194303, 0.13940613806968735, 0.17170875633676208, 0.08683002944434844, 0.1211149768242913, 0.15425443889633303, 0.1842381703036447, 0.1049386395982677, 0.1343586145629806, 0.18486893645698027, 0.12238561791638214, 0.11324747600742888, 0.15199965827407377, 0.16469575765152134, 0.08617177605628969, 0.14618495899823405, 0.09107549719872976, 0.17618833289992425, 0.1861107956257559, 0.22382582507787213, 0.2823109690460467, 0.1682564117495091, 0.1493395405310777, 0.13198305251857928, 0.10201240589301433, 0.16362835202486287, 0.09338292338314558, 0.13918642405300372, 0.19587104689450036, 0.11560364070558742, 0.08267388754193822, 0.12544607022596946, 0.13885726671545737, 0.25613069564344426, 0.12242927726718689, 0.17975045788672664, 0.20154668589032468, 0.15347868294244812, 0.12499366466316486, 0.1829891558736563, 0.2573054608318114, 0.13150127514475776, 0.07200830420779605, 0.17851515643058286, 0.1730838075520531, 0.2163590265498046, 0.21562201932312983], [0.05645902909999413, 0.038777834720789425, 0.002877409724826594, 0.05612772288582018, 0.027424926877081878, 0.0802171431602009, 0.036708163923674056, 0.06929839841060101, 0.05364750173964328, 0.021748085123216434, 0.0636718005332495, 0.04526545413799825, 0.014401320123954888, 0.038482998122250846, 0.05515556114034788, 0.018170550277817155, 0.03846644679264676, 0.03723039840077681, 0.032628232447971264, 0.034022355422137246, 0.04948042776255358, 0.0966336642722449, 0.003297764562904054, 0.07533592968097619, 0.008958189770759595, 0.022534047283472556, 0.0401100118253981, 0.08102815448036117, 0.01991847180761397, 0.03467882382533243, 0.06113419940154399, 0.017515263565245177, 0.015178912773638245, 0.05725448117441228, 0.016167835565283895, 0.04640336666676787, 0.026719560996899684, 0.01780415149105172, 0.01404829531712758, 0.03485068415982589, 0.06298817048269896, 0.026495432398552378, 0.08763026956829333, 0.03259059837869099, 0.042216627212661895, 0.047812999090960914, 0.06021990793787184, 0.07110091902676129, 0.1246635573765924, 0.06661776483299271, 0.05387020349923161, 0.06665671274306313, 0.029541344359336846, 0.025743727775050268, 0.052770518757883585, 0.023465305679447712, 0.07382505873758947, 0.054621341217669754, 0.07190638387034978, 0.025344739607985944, 0.006907982394970473, 0.05551155836832139, 0.01212428177466556, 0.03030153723703998, 0.03570271565789177, 0.04014036805939771, 0.0337324639211499, 0.06894461134628904, 0.01711872879475836, 0.05563443504093636, 0.05664488969130382, 0.043102569592696045, 0.02779542040380259, 0.07558480100405794, 0.03109055608811398, 0.05444943108746121, 0.04911063329106377, 0.03644659086280773, 0.07004157264506625, 0.02966020098556915, 0.0791629602111155, 0.03177109305867024, 0.011165458577564888, 0.07133180260538094, 0.022157177990002018, 0.06954147044809596, 0.025429495745488716, 0.06154864913814011, 0.043077100999653346, 0.06507939133312433, 0.031364825141105446, 0.021840075045944225, 0.022144769280848485, 0.017745984350180915, 0.04055024808152549, 0.07185559224096999, 0.02987432256040554, 0.08152899978261802, 0.021518574757201057, 0.030069895231375293, 0.012190573277973361, 0.09111482815276231, 0.11408092604289133, 0.034932885394101186, 0.019728547119865977, 0.19460562286117386, 0.08365280235246306, 0.030402549760295983, 0.022182137134575078, 0.10907778967051737, 0.03547171716608348, 0.059349681851604295, 0.06368274792968746, 0.07756205861486735, 0.08778884210774014, 0.03180825981431671, 0.04110457398177635, 0.05637183680289215, 0.033202966930524956, 0.09109527758893468, 0.06672297934851339, 0.04788869623875907, 0.1037558611302126, 0.10933520287395486, 0.025506545038473223, 0.02281643495324158, 0.003301405635166673, 0.04192478984834687, 0.027648733718500986, 0.03644233141394873, 0.04116339038216299, 0.03886829055244884, 0.005282266732049926, 0.1308639053135149, 0.0430180509424498, 0.01073634687570795, 0.027278052500238823, 0.0225407486375902, 0.018605527340344364, 0.03189730604419545, 0.07595767897944297, 0.05223590429992445, 0.09585753293527711, 0.046745352146606294, 0.031666305637167345, 0.14543129702008542, 0.010217261019973986, 0.02002986099180435, 0.03007728606462479, 0.05009788313820478, 0.02927357364716309, 0.0065639208168572485, 0.006129225770447163, 0.04938874619021531, 0.04147537202844697, 0.005555275570405948, 0.1065798910454877, 0.023099717030662204, 0.02506699634625787, 0.023298869247458154, 0.05314404024712501, 0.05890114503281732, 0.029953045755504604, 0.07696070257694491, 0.04550185738011234, 0.06379686055644866, 0.03743763667561355, 0.03452877401404324, 0.05680435472318242, 0.03841359821719028, 0.05252995565834065, 0.04149537841458956, 0.04522878533950256, 0.03279156622386748, 0.01756946811632764, 0.0494666151972788, 0.062306114742832805, 0.04128824739206222, 0.02055005192936909, 0.019647583117588394, 0.04423282890310211, 0.01957712409597251, 0.04474114739306031, 0.13414846132359198, 0.08954148273915054, 0.018081833465745854, 0.021983325826905428, 0.04514981699626773, 0.03197113202223855, 0.01942495796679249, 0.05277966584769949, 0.02954547931890815, 0.043015044047347004, 0.040456344854206815, 0.033954254036108335, 0.011676541687319837, 0.04429042722368914, 0.05916576329318266, 0.035576387759177916, 0.01378909808643643, 0.015162602761730313, 0.0357921181186553, 0.029351643752306703, 0.010631199392880644, 0.032303211985216025, 0.07831651732445725, 0.07885341472443073, 0.02293243215629651, 0.04439368438456328, 0.010162607349845912, 0.047278465072233836, 0.02844459564995862, 0.03109236214039547, 0.015272683850789984, 0.014158980658037529, 0.03912694481832366, 0.024867531948632775, 0.03904536028482741, 0.02688343486478252, 0.06489216710530943, 0.03437366036157455, 0.019196516293431484, 0.034134177446004846, 0.053920221379807884, 0.046282780597046505, 0.017323879480001428, 0.04981731875769554, 0.019726815761157104, 0.017198084012394952, 0.040934759102040724, 0.04546659818339733, 0.05981705677244933, 0.056690812831924814, 0.04837436533923592, 0.052789130864003976, 0.04228186726029362, 0.0521491295207412, 0.08711382671589814, 0.0710203112553685, 0.0545586560732655, 0.06227830958162105, 0.04507760937896468, 0.04091867125563083, 0.02900791542244054, 0.003446597012601072, 0.0358489963165935, 0.011522488109016371, 0.06601501451504808, 0.04499184966628109, 0.05265948580457799, 0.04188003116137078, 0.027652472227571473, 0.003425925087574269, 0.0166328432744429, 0.035357838196139184, 0.016123716561724583, 0.04431768080159541, 0.027678804584748806, 0.004231972157985213, 0.0593972712334606, 0.022815636306580518, 0.029949284263796387, 0.023859293207586296, 0.02535005434296064, 0.038894295407038544, 0.025963407317777316, 0.04034266889756245, 0.0517277735015077, 0.003224525360330459, 0.06460691426670359, 0.057375205139960014, 0.06535896746021125, 0.03569244624926679, 0.01419701788108796, 0.09527265544860594, 0.028199029996270136, 0.022448682106069984, 0.11027673259377481, 0.0037202086663925124, 0.010833685049757121, 0.044954043227217855, 0.0395580607977125, 0.012920051775572282, 0.04383861920946548, 0.012384224025863073, 0.08503127798077562, 0.03285049370700314, 0.06059210792544389, 0.05773255834355951, 0.013726873552396655, 0.03314721105139583, 0.043426559667193124, 0.06997476211718975, 0.07956923961999916, 0.052309441079776135, 0.028427745546064073, 0.044412894039264614, 0.009551634035644033, 0.015680387225602905, 0.05256619161715912, 0.01802210733594914, 0.023303295320440686, 0.05467820026340985, 0.005048126322142179, 0.10205564389546072, 0.09281672312006836, 0.05583798077197806, 0.048471210344183835, 0.027884560479452054, 0.09235969038620111, 0.06436330596766164, 0.03871359824833851, 0.04434785700493282, 0.033617826524160566, 0.03458847141554279, 0.0740108350592275, 0.043206466436986966, 0.030207105409053546, 0.02494580315185651, 0.03471602505493549, 0.07546205073595047, 0.07336994122353292, 0.04869233013220853, 0.011126431185872325, 0.02639060667265327, 0.03351437784130535, 0.016931175149136016, 0.05401364580217389, 0.02933702679471143, 0.041583670047862877, 0.019036252614891818, 0.0823537393983814, 0.08384831565161867, 0.012536665946695835, 0.0176251569627634, 0.027473353209995457, 0.014269291573474485, 0.013415744178928437, 0.024988887936718045, 0.0017250248375574068, 0.049763439793980895, 0.02758707130147565, 0.019363113603885138, 0.03119481873938874, 0.08308657910674812, 0.12681272511761035, 0.11705638089727972, 0.02153272631638233, 0.018321821999345577, 0.05808018223052064, 0.042082983174271164, 0.05276591456945866, 0.1633750220700618, 0.12975773563788784, 0.1245214174231214, 0.11839975437690174, 0.18058825164071976, 0.12122496406758025, 0.15562801922280944, 0.15630049120274284, 0.2076996436282512, 0.08232541712782077, 0.1103587193234313, 0.10743050911133328, 0.1014536826480781, 0.10553775865945125, 0.1791635272844184, 0.11377003224145983, 0.1130473355372106, 0.17318870031064557, 0.08276275374115476, 0.16932554873487643, 0.14644178231396984, 0.16274698318973665, 0.11279694736003877, 0.23377202120759796, 0.20254670642316344, 0.12781891265823958, 0.16648383751030893, 0.1541506799478685, 0.17216450204291653, 0.280913747246227, 0.17898441592772163, 0.12673056218773127, 0.13321642343315387, 0.1375899121405617, 0.13143068780341458, 0.16019289201546102, 0.06439341322308587, 0.0502375026624049, 0.12596249775660615, 0.12144552844185984, 0.15400731425371864, 0.13967065290818292, 0.08758946772544615, 0.2446170376553651, 0.14878947407968585, 0.1355425574846806, 0.12296462716955332, 0.1286302687179658, 0.1999692802107142, 0.12579796505310845, 0.05920720864988624, 0.14356015790854731, 0.07220478277773627, 0.0907999430332453, 0.1624097666072269, 0.07412802352900467, 0.2169427395828309, 0.1419322363912098, 0.11584728730902558, 0.15792069055380362, 0.1598787040359551, 0.13519855336316172, 0.19835383060478395, 0.13327466143715766, 0.13191529970255592, 0.1339433949080206, 0.17090558975694642, 0.1078574499115348, 0.1603156652662062, 0.1713165806065644, 0.13775874259731463, 0.1937807606713426, 0.10940001391234899, 0.1961598467201956, 0.13847990712571528, 0.1230632916333214, 0.10032917282754376, 0.1621247206123606, 0.16198814245721987, 0.0659650502606265, 0.22449613668985907, 0.11912896282850735, 0.16375334693058846, 0.17170241312874904, 0.1789413158211016, 0.18364491181508188, 0.06960305625632887, 0.16637399582372558, 0.11542266775523463, 0.1274681133368323, 0.07719418319362788, 0.10303976044299142, 0.19586804382983716, 0.08484463597978316, 0.19618892741780128, 0.16887285205866062, 0.08865744791804783, 0.15560492933277162, 0.14041083173886423, 0.16857861300870297, 0.1235255950521077, 0.24429563312761246, 0.1649638884250195, 0.1105704430430647, 0.14162434565444149, 0.29776106258073165, 0.21548884259837292, 0.10446427795555323, 0.15748556793457077, 0.1602982137832911, 0.10072100381817549, 0.12030758143913363, 0.1503952096907362, 0.1991046274140958, 0.16872406246200686, 0.1852522102454978, 0.10794636207602679, 0.16399780558722635, 0.15778492445186262, 0.27330342980642475, 0.16971337308566417, 0.20675691115039013, 0.16138043555040515, 0.181879477515336, 0.1489316599984323, 0.0769737643760539, 0.10845270788957996, 0.1287318213332084, 0.19139448871775983, 0.1340588137146927, 0.11649137573136438, 0.14903282956971278, 0.09546018611159056, 0.20687537898700084, 0.12408465537573062, 0.13391416099283004, 0.10194485225985128, 0.08497089493058382, 0.15138007700443268, 0.21680564048790166, 0.1882736150535845, 0.13388409970268128, 0.14921736482891346, 0.1256331412361995, 0.17064371026091038, 0.2223760343246883, 0.16756229012483553, 0.10991416616185058, 0.1541516145751361, 0.20861959265124416, 0.2725132560778049, 0.21517796411869988, 0.09592743845836771, 0.12914832801588122, 0.09915126667868707, 0.09575664681652862, 0.1743431641690193, 0.09107014224413904, 0.08404084886874884, 0.11736911330972949, 0.15805682437794824, 0.08710798912591512, 0.13267475330541212, 0.1689913505387883, 0.1595878051293473, 0.13802247602612744, 0.08626564480965176, 0.11503551756182026, 0.2711309270272332, 0.2246500590756055, 0.21809230047848918, 0.08339685237696094, 0.20840887250679158, 0.11090602019741652, 0.14881182852531635, 0.0988608350857131], [0.06818455253397265, 0.029795235473542448, 0.03546809740064125, 0.024701823300171285, 0.006416996644299117, 0.029167395776077628, 0.07792813372948477, 0.067132506970196, 0.059949632118185686, 0.004409989924170077, 0.07062045166329031, 0.03833944473655955, 0.028280509192676797, 0.061584697405417124, 0.02388627099383983, 0.019598708623239113, 0.025721507394806515, 0.06836135796601735, 0.03329512347737628, 0.04166034395776449, 0.027300213508668448, 0.09021534133822688, 0.029386885712043415, 0.02759616668035667, 0.03436561260792998, 0.06515592351675996, 0.014010695721803895, 0.08588558859041623, 0.036039166152477264, 0.03161753073424822, 0.0673249022914998, 0.05006869901872931, 0.04495195946806381, 0.0719358629336761, 0.03329080657192296, 0.1271064968539342, 0.042565515144698085, 0.05905785980904776, 0.040666283588976636, 0.03161422506485495, 0.035058634896432204, 0.018027374190428568, 0.02494746939309182, 0.03907447162595007, 0.02333806805132378, 0.03143361217582659, 0.022529397129772172, 0.020363840852834044, 0.024718949195718574, 0.02281329207753222, 0.03272772428669757, 0.09860254854204194, 0.03009424916648817, 0.04228206644315393, 0.022251113776057478, 0.02169707898921784, 0.02216439645346855, 0.10765082067659787, 0.03293747916036556, 0.014799716488097706, 0.05050501290468439, 0.05792635560576474, 0.09202548452923376, 0.011171220516365384, 0.05320004893526916, 0.09066716467420902, 0.041916370542059024, 0.08251922205090523, 0.019498310885542346, 0.011880948309666448, 0.05067202007217754, 0.013827959811615368, 0.059287843234356374, 0.04517902409838093, 0.0630993566535894, 0.03911033603212526, 0.06588027497092563, 0.0536867369326853, 0.039645283738331455, 0.02279728658557419, 0.054987389519209826, 0.03101820482932512, 0.043443605123508366, 0.03203486479187925, 0.046082571178915045, 0.024373790196653818, 0.04722257512771795, 0.02988251395553591, 0.09527585769612944, 0.009169399253873816, 0.057287024589435714, 0.015769096376794963, 0.013919078309329288, 0.03446828754198167, 0.025823169177578344, 0.03804315640140445, 0.02055306265491151, 0.018173674001328407, 0.05593238195644752, 0.028879586119024508, 0.08181502637002738, 0.018864281197649338, 0.03521245002986924, 0.03806530017285578, 0.06210085680528034, 0.06216278735307917, 0.04343592509206745, 0.06968257618286917, 0.019057955885786685, 0.03042558985461872, 0.08005352210133307, 0.09313165420486082, 0.14308080137256654, 0.04525302819186642, 0.07142763254382918, 0.02352438638016822, 0.03638616950821973, 0.033233020559794484, 0.04026567706117227, 0.05956116425354154, 0.028348597172167034, 0.020974926207394853, 0.09147039254105861, 0.023508553257993153, 0.031092963519416032, 0.12316777070443477, 0.06208650797845856, 0.06261494010686874, 0.0574486346675023, 0.04110953057064645, 0.09329892950312746, 0.038814430740932306, 0.014327736421217842, 0.07454593981345815, 0.0190540392612738, 0.03050641979150955, 0.07176770663429653, 0.04627551808352432, 0.011649755423047371, 0.032446118026611306, 0.01725557699589239, 0.024175744976908452, 0.01397296206109346, 0.013678499888027868, 0.0683060847222805, 0.053379708044831796, 0.03514189716248262, 0.01100024214059475, 0.020390358986333013, 0.05087610972564548, 0.05249427894370691, 0.09326576555688536, 0.09530090111037416, 0.03288245489520412, 0.08075819275672398, 0.025622898472412944, 0.09399933304878012, 0.013196326063705549, 0.05616899587274079, 0.060941949636945804, 0.07720031955790135, 0.008169139318558718, 0.041905813850462444, 0.0452956916283696, 0.024403562288611166, 0.021553565823142568, 0.010963634629133008, 0.05933422219729232, 0.04191702937767391, 0.04860783063416039, 0.014698584263603535, 0.020284106421674934, 0.03725366066059759, 0.0636797295432658, 0.038885385804479165, 0.05870659317400667, 0.04475451562733901, 0.04313676392719631, 0.06391539351053296, 0.04676577605066761, 0.010770100709651748, 0.03988877712418476, 0.047953530259790926, 0.031517132996551456, 0.04662077858923905, 0.03650118611873158, 0.04870987737611417, 0.08734053511533045, 0.04201685446464727, 0.0549304883386339, 0.03275231187862735, 0.06456860220961033, 0.020345946954142664, 0.01724743348125729, 0.04795119369162187, 0.04890506891834159, 0.03500387110116501, 0.06052462707063364, 0.02057821523668545, 0.040190259535466476, 0.05239676744226487, 0.055370571377176436, 0.02739789163423402, 0.07742431600608173, 0.03493368978642168, 0.01513699148481171, 0.08257854789976152, 0.06749835225843615, 0.04759702358334776, 0.01917612686332676, 0.03601689214607881, 0.026707165694284826, 0.04824242201603709, 0.01503777064968862, 0.010941860495105146, 0.006477678468781374, 0.08214381598537007, 0.01352813789590953, 0.022317255892220045, 0.008478563188785508, 0.015821016070643262, 0.05296944497874188, 0.12061006359515652, 0.004627320449799299, 0.036215937110565366, 0.01864621235478309, 0.05126826247320541, 0.0887752415972852, 0.01564157433852914, 0.043082321888857314, 0.02919267284713926, 0.05434461876810078, 0.027204002441477873, 0.0638866384002951, 0.05496361781091941, 0.022111549793231874, 0.019350756605666493, 0.028272359932382262, 0.0455216990573512, 0.048315874526217106, 0.008472073466456946, 0.020609969581146876, 0.04712692521993191, 0.04077288472364026, 0.02535868623864747, 0.033343452134079514, 0.031639854536361756, 0.02497072399203335, 0.09823488762542125, 0.02439048708296351, 0.010031636958310922, 0.025476696337723446, 0.03464474057358119, 0.036967530651318456, 0.07432494642994097, 0.04110537454365723, 0.02744778885596222, 0.05686803961232786, 0.06499346691153704, 0.0584976120491422, 0.00996560113684785, 0.025557522444174658, 0.05441239073632225, 0.029884729864856893, 0.04512905218308011, 0.05296904661302125, 0.051270097253784064, 0.02036051794646248, 0.027073980083749182, 0.026839153067539298, 0.03221940962717899, 0.04378894606845514, 0.02294595743859968, 0.053848232097563245, 0.024906481773923003, 0.033752213667837844, 0.06187333635264828, 0.06257965409707639, 0.054878455646816766, 0.039456760991484895, 0.049487414484423016, 0.08081684444820689, 0.09822031663310143, 0.05748269876705543, 0.059739275865497134, 0.03496256364028781, 0.026734890416264537, 0.03365342279956226, 0.1358242020491631, 0.04384778162103988, 0.05420409526015001, 0.013358933013683606, 0.03383203619910825, 0.027059064351863442, 0.02327080744679176, 0.07380196118667241, 0.05067388166583354, 0.025618600719157728, 0.09656421840190889, 0.06568791029313881, 0.01530985730970579, 0.023987038368960063, 0.05950394897691666, 0.01799526936074178, 0.030652767482904658, 0.018163642079959956, 0.07868480643317585, 0.04522067246838443, 0.0371102873055685, 0.033169665088456486, 0.025607798879425374, 0.05558183161361564, 0.01653595421943934, 0.034273517348112605, 0.029169247793634574, 0.07698799062880778, 0.019813349222644203, 0.07203039052265306, 0.05672804470504484, 0.07350012254450591, 0.02926788735954512, 0.061518982383272344, 0.0380593438392445, 0.08111683681847588, 0.02298513134460776, 0.051560161124554374, 0.05683918491065983, 0.05183981386043372, 0.07526344244158076, 0.08050672439557892, 0.02028133892904847, 0.03335425014337225, 0.059642239338568145, 0.03410072621679114, 0.05610377497730717, 0.030489581178933866, 0.08495942659435735, 0.042928070085303444, 0.025008302519939123, 0.05469185578066015, 0.03467345354898322, 0.043949246136171204, 0.11606101051814134, 0.015738021935366334, 0.01930614539061583, 0.03363692509611288, 0.016509665912317655, 0.07631144306111722, 0.011857238846019873, 0.01175264486171786, 0.0743022395838653, 0.006716545162376978, 0.12568780927047615, 0.1933223030139362, 0.15038981643174926, 0.15644989366973602, 0.10952085662152498, 0.115778959927059, 0.2724934603658415, 0.10982990415105898, 0.22137322523180517, 0.11641937112736127, 0.13149499322377867, 0.23795495320472027, 0.10927643626928331, 0.26760824024677277, 0.14427792100656417, 0.14356755831789586, 0.08626716932462108, 0.07506650421888598, 0.08533726881949172, 0.11134052228543068, 0.0838490357742675, 0.1613874069505161, 0.12439373354878157, 0.0947359802141305, 0.15604101722278904, 0.22425947680829034, 0.05791861045685026, 0.12588088641003256, 0.11616816323611046, 0.08581210543671924, 0.193901710632828, 0.12489864677791634, 0.11453002210586302, 0.21360576783697452, 0.14156580121526796, 0.1961220632637701, 0.1796924956743756, 0.16747428194409417, 0.0911751039506447, 0.08713298657488439, 0.17604259233320915, 0.1313972404046405, 0.06248017374966895, 0.2980675590374778, 0.1118512807654277, 0.13155549884803835, 0.27888294008951037, 0.13577193953096867, 0.11428056855595882, 0.05822012351164895, 0.16166025682562785, 0.12341671863630896, 0.14200066336460654, 0.08809663325307832, 0.09555832197469089, 0.11856042599726109, 0.14108252230911486, 0.17564693856383526, 0.15338840714145094, 0.12752627473204367, 0.08583415344718003, 0.1292967498903313, 0.12455363908121664, 0.18103759285182724, 0.21464583944649468, 0.18039478379632198, 0.1213799283329037, 0.22864554467941486, 0.13344166860465081, 0.09263032626721168, 0.13275678600034407, 0.08757469755026602, 0.16963518615211212, 0.1515674467889532, 0.13528882916415894, 0.1507255621254444, 0.16237742237506375, 0.1236758785202138, 0.12079997679158566, 0.09456250726455644, 0.11017731736384093, 0.267203408744066, 0.131633578529281, 0.13007647417966398, 0.26941394012781883, 0.2077772483349808, 0.1690982504477424, 0.08099534293456424, 0.1365116893524124, 0.111749820080736, 0.13985184802403375, 0.08156529702847043, 0.0945960925591569, 0.12481026321409211, 0.12391790101725249, 0.1116707138416748, 0.10169785019130477, 0.29480708883174006, 0.15177013833195935, 0.09989745929957398, 0.20862950582898435, 0.19805479584442032, 0.15439516924802335, 0.145425321534276, 0.1527234428231755, 0.12447945112662932, 0.17967919638801008, 0.24599138406976578, 0.14189416182137307, 0.16941337305451595, 0.1549591018908447, 0.19501592423166, 0.32641137199055764, 0.14327108229119934, 0.15484875458623135, 0.10793192897953334, 0.17162730586865257, 0.17154622312274673, 0.259062621381975, 0.11884700416797593, 0.1341039362934328, 0.1793181238275382, 0.2074830858938156, 0.11175006522887176, 0.08290501626869363, 0.19023768063033783, 0.21034955708009584, 0.137513977505507, 0.1361675779785841, 0.10239852186773094, 0.24346931537072508, 0.19643323285685432, 0.09679618216450177, 0.22434279653093508, 0.07479585301611694, 0.1591221156019357, 0.2165130868313774, 0.11449314263318816, 0.13484793024197703, 0.13085584606855147, 0.1561776566649637, 0.1452330641087986, 0.11311558631038475, 0.14764156793394398, 0.1352739517366694, 0.177920917349477, 0.11936117940011526, 0.11014425300902898, 0.15939119632445997, 0.15968967950151813, 0.13367673502333705, 0.18725436571384632, 0.18781190918337917, 0.12638922405218886, 0.19725722170645194, 0.15223233449843623, 0.16404629895283332, 0.08544201602137859, 0.2312120005127884, 0.18047143855402548, 0.22180676970991398, 0.144069958778639, 0.13266415064854006, 0.10570107328314936, 0.1694012995088293, 0.11835450922409374, 0.18132464599705514, 0.1307903455510255, 0.1272785985061238, 0.15805089485741433, 0.15345111909893253, 0.21702451180786858, 0.08218294009566307, 0.116142813386696, 0.1137081936242119, 0.15679271801585154], [0.09237096720044652, 0.047822816507710565, 0.03974809656820951, 0.026347947066589713, 0.04751771816142625, 0.02996492203355076, 0.02494686801407126, 0.08997860484786573, 0.05858013120990607, 0.012807659973811, 0.018822887551880652, 0.05236238158578354, 0.059358143292727976, 0.053494755298860615, 0.043063855339442535, 0.05681511442807894, 0.0284864719311196, 0.030798848958746083, 0.054703611399858236, 0.025228828589822498, 0.00508593084598561, 0.010443259830466442, 0.01689486832718455, 0.06910984118979785, 0.07333765061752451, 0.01778279487494259, 0.03559826723029537, 0.03736270178530005, 0.027885866659362952, 0.0025379899213270798, 0.024072261820096644, 0.025429993702639497, 0.08435863746149887, 0.05639933935937382, 0.031345220951123104, 0.03328443272039294, 0.05207819743983207, 0.047025311317655354, 0.11244037173568242, 0.03820740182193057, 0.046504271937714475, 0.0341686399112786, 0.03482403196094017, 0.04670322114121049, 0.05856577855264468, 0.05801442890397965, 0.06356129618061167, 0.06705811983274837, 0.04609341515348323, 0.026573242033801736, 0.023952706138633435, 0.037345932120637554, 0.03866677112396687, 0.027434066306018544, 0.02840381104408974, 0.1203965089253841, 0.030499613100302317, 0.015987142237023483, 0.04301458056415281, 0.013518357825946185, 0.025299754925072197, 0.09150826026715579, 0.025526197108950828, 0.0668381683288082, 0.029860220796939348, 0.019251561626010848, 0.04192304699831913, 0.02078456676474983, 0.029259596372984593, 0.04028539616434325, 0.09916550059232021, 0.0031851975185300915, 0.034555349604136525, 0.04066417684718486, 0.08160878017905258, 0.05936475463151451, 0.012755046970391226, 0.05348372363275098, 0.02730469512302549, 0.038716421282339486, 0.05861996395152904, 0.04204345303737829, 0.05942139534219619, 0.03335240387147473, 0.049689125434886065, 0.016035518774221984, 0.02563663825933491, 0.06297365311653384, 0.03620251525013197, 0.02229924516512021, 0.024719663572707967, 0.07470926209803551, 0.07837135389807724, 0.10006661917413436, 0.0041783220630379455, 0.02171960580463131, 0.01862635152534612, 0.02133658099468918, 0.036183619691479596, 0.05035713495266053, 0.03139943699352443, 0.05974275007423374, 0.028220679641010302, 0.017808644596727628, 0.04070478716805097, 0.009100358452527754, 0.0836665383089454, 0.05496007082382998, 0.054681517424121986, 0.02278141707422272, 0.0159940178761439, 0.02773771100046654, 0.018793199729594975, 0.09268240492430427, 0.047346041688034614, 0.032882102494758945, 0.04049220159950276, 0.013822511968863829, 0.07721138952840721, 0.014563263450268538, 0.04158473107963801, 0.016273379498612017, 0.010746184402265617, 0.03046104823419404, 0.08326592795070141, 0.04667745377387732, 0.02354751457460225, 0.0886179254420342, 0.07335619760617133, 0.029389815998353788, 0.07738675471515426, 0.046878157318719936, 0.012870294364890265, 0.028350213617687265, 0.010486863639896676, 0.06503429173702194, 0.01724516011534199, 0.0318725269302846, 0.0348645733338931, 0.021098471291723753, 0.06832727471426611, 0.04368034927474876, 0.04144344148376296, 0.0581412585902839, 0.04648078368195603, 0.06573507066575751, 0.04314823992430203, 0.04369632986884925, 0.017384040364695173, 0.062532692907318, 0.055177130345855994, 0.008703903163663082, 0.030617412525199117, 0.07062279589233861, 0.09612692775385034, 0.04897124359324094, 0.005877159860721159, 0.02896576909528625, 0.017889848001481547, 0.019649952244494232, 0.028716030177630247, 0.04837157294875191, 0.04549817632763617, 0.04491794133378614, 0.04180035035636637, 0.10033051348141125, 0.04752755856081363, 0.02449463673626944, 0.04790477642428972, 0.05466281338745067, 0.015849269393290726, 0.0886858621191594, 0.015243494943264994, 0.03313639388990498, 0.027392839284373388, 0.03868049175869073, 0.114468022610151, 0.02527054016207976, 0.034905896116528785, 0.008336254695971167, 0.012836513717869117, 0.0054103480145004735, 0.06766630171407616, 0.054047062557431004, 0.0262099573944485, 0.05601336128048359, 0.009357829112559557, 0.12305713228641019, 0.06292603309116056, 0.04919487231921765, 0.0455273719384305, 0.04808646949729131, 0.05965361191380409, 0.07319785489310181, 0.020883317413409392, 0.0832843217217634, 0.036328904435879765, 0.06271596412144362, 0.019943151330094666, 0.04558081806246792, 0.010912683078899019, 0.01985274912458995, 0.08445381622521148, 0.036378236667763804, 0.01155658572491619, 0.03805834026406369, 0.03351044397981417, 0.048599947589419545, 0.05113896598378497, 0.06129859803965496, 0.015346001337973342, 0.05652881587945646, 0.0268335338126147, 0.02832249272614718, 0.07645847831642436, 0.04757646561389969, 0.016740164531755353, 0.04126181352823492, 0.03770767883848279, 0.064322458159539, 0.0771518798184491, 0.03160788760250134, 0.02348196043092157, 0.013158300331973983, 0.048578416688307646, 0.007146366453173781, 0.025825720250366196, 0.060113295311889345, 0.019787576109651598, 0.030248349667676998, 0.05375353979968256, 0.025245226701841723, 0.03945773009270911, 0.042532634650987965, 0.023914438131595814, 0.036928341423551884, 0.09206818627013315, 0.06250810148494859, 0.012877035938623934, 0.050521629351762035, 0.06127551581049639, 0.0058947794041746574, 0.04581092406184443, 0.04224692215962757, 0.057931756525630915, 0.10750062913904268, 0.0403352148620592, 0.035085084082017985, 0.030407695955927336, 0.05648080131880218, 0.07595574077699455, 0.04490390660301332, 0.05077149658914536, 0.03560324297136357, 0.0535028949830561, 0.03048910237398119, 0.016712771142802892, 0.007939820953329365, 0.04134590316924357, 0.03121803311871425, 0.016451759241341103, 0.07935474266207988, 0.040080122905032295, 0.03773424293725722, 0.06562267790638632, 0.07606766622273192, 0.029345660605618072, 0.041548560238293106, 0.06169017622127168, 0.04025842986940857, 0.011624560706437597, 0.021291123252482187, 0.03669324819178831, 0.04826548509299756, 0.05214494668067463, 0.08166266680364648, 0.06150574055350116, 0.03063283004467526, 0.05447800616703687, 0.05101459927015728, 0.024131920917199987, 0.0541522809033913, 0.06322493761657708, 0.03335330785522538, 0.0412535589308508, 0.011498725019215096, 0.016785919133033005, 0.0368978472937259, 0.08052679589919506, 0.07028905734900506, 0.0710749333243697, 0.04148853724942573, 0.006025694733140089, 0.02020403874226876, 0.020378369710318023, 0.02488582995870421, 0.09768799277803591, 0.04345939802606741, 0.02217148851242758, 0.03638365290938847, 0.08445883410111552, 0.07124014018524079, 0.06656727197790338, 0.030148788881037506, 0.025356458838007627, 0.02901818291584571, 0.09160479500649438, 0.012729527624023539, 0.03718100105141921, 0.01784948474397102, 0.02336063891679289, 0.042011779132148916, 0.05134502065277869, 0.03228390273908454, 0.031091337497796745, 0.032890418379177014, 0.05540781474161533, 0.0385713663643166, 0.03863495932291112, 0.014440942191398673, 0.08970499654570896, 0.006598035669735363, 0.016225386005375656, 0.03520757004979157, 0.04949620534335414, 0.021937760832389037, 0.06222261498952585, 0.020541513879452983, 0.06799050246275241, 0.031257789251544786, 0.09639605444165007, 0.025924513033861597, 0.030583026668717785, 0.006904051885113962, 0.07598997724633064, 0.008650850617296754, 0.045693360208984346, 0.008473869942639385, 0.04368439038854934, 0.07188844975204238, 0.045794552762902556, 0.04462374824910395, 0.056318823518531944, 0.045672844374372114, 0.03477346249705842, 0.04536631344366939, 0.036207165403832356, 0.01880055608888788, 0.025613782026114005, 0.02217807495335658, 0.022969087548253518, 0.04772951465941245, 0.22771882343917127, 0.19143165930384592, 0.16221056842515547, 0.11865906747839144, 0.13646221539426234, 0.09939919571362196, 0.16300582897759255, 0.1433213683025491, 0.09231236147423906, 0.12749506431000848, 0.10234456629522386, 0.17386160129981656, 0.121147497256677, 0.17459379749432688, 0.11377584684880511, 0.151218417130651, 0.18009384913790613, 0.18690872216416946, 0.11201671745267608, 0.2177442360909716, 0.13968807374758108, 0.07719043702367814, 0.14098147531190228, 0.19293061758001007, 0.09189760913291285, 0.15888617584301581, 0.20023053151465234, 0.15207376961986865, 0.09664703250652361, 0.14440519885430414, 0.08414793263880477, 0.09634048242362277, 0.12646372610282514, 0.13873809407795631, 0.129957209611612, 0.18117122922933873, 0.14135695032535062, 0.12620187725030607, 0.20492027663896162, 0.10231870316690016, 0.11801497905605263, 0.1672966567979705, 0.11943656245186446, 0.16961491546563565, 0.1718611925119354, 0.27350135628254185, 0.12661680579185486, 0.16659755560178913, 0.12363452509406114, 0.1206013608363367, 0.1944932377626819, 0.13515208246967486, 0.12255856226528845, 0.22581117257716196, 0.2228427197664015, 0.1759939763935343, 0.1291682463019125, 0.1207103215218071, 0.16824934841884723, 0.15761807050195434, 0.2094699196036785, 0.21152940909228019, 0.12375033460557462, 0.17345850115581868, 0.1844590794174902, 0.059323431848878824, 0.09943401440978052, 0.13763390090917388, 0.13476546853780746, 0.16034774902847507, 0.3680565857118176, 0.14155527516718835, 0.14790130238379204, 0.15008344254907102, 0.36588687149267046, 0.20885730973414837, 0.07120347521718472, 0.19202018336903667, 0.19422921322045789, 0.21585005305467114, 0.12453921364560244, 0.18941718514167494, 0.14004425866709602, 0.1854553614412585, 0.16947631483837483, 0.20541817250271, 0.07013920289013656, 0.24688479580706169, 0.13914019830765265, 0.1326073682115924, 0.22766489084930192, 0.2060574269102466, 0.19462704267953673, 0.11955522181045626, 0.1088826057891692, 0.08500267991856222, 0.10968650015251291, 0.10119344258020002, 0.1874035689979792, 0.21145390346646312, 0.16442122238297618, 0.12443775296091072, 0.11432786682440389, 0.14839090917619968, 0.16188913325388588, 0.182087117986333, 0.24457049015308582, 0.2606083723085542, 0.1145738653177696, 0.09976851138015909, 0.1136968095576571, 0.14025343131394158, 0.20227463795773445, 0.19283386067517344, 0.11834167725136203, 0.09265648816982586, 0.13455435002763427, 0.12423281678028646, 0.14400867174469656, 0.11749184825607847, 0.14046917699517744, 0.17820967120989678, 0.14433416718196485, 0.15607898454031638, 0.233481842423639, 0.15397910689634664, 0.16810630448162558, 0.21404280567601805, 0.2203142465723138, 0.11139257029900629, 0.1514523803827263, 0.07665750795915242, 0.11650377103397924, 0.1598288776773599, 0.09175500952668729, 0.20474160961326093, 0.12452181578884203, 0.07878046783228075, 0.111475920665168, 0.14915869781567206, 0.11862578095808146, 0.19424920811528162, 0.17913982452404115, 0.09775956837280143, 0.22049049276017377, 0.0890805506177487, 0.1238401201103003, 0.14671722156626565, 0.1037288182264855, 0.2121255327496798, 0.23797854871278812, 0.10530744964677481, 0.1787225364316856, 0.15951980716518818, 0.18306403330737547, 0.05706279448443844, 0.13331049903025552, 0.14529710905926843, 0.19512550544834908, 0.14121314030020468, 0.10059143536754193, 0.11337139072918123, 0.11458118145744647, 0.12468337607119354, 0.17386558495702284, 0.16820745873114756, 0.155075884334022, 0.15020975512602638, 0.20705764662594567, 0.10787444174169533, 0.13037742415983833, 0.1592325395153415, 0.10199867759741123, 0.18901570910407653, 0.1673128672184483, 0.16096550700885637], [0.03291927308084504, 0.036871221907917535, 0.02661106379462346, 0.020867447902057922, 0.07662870305319948, 0.02843774490869574, 0.02985765823283263, 0.052431927047549724, 0.013286103907551979, 0.029828857157319307, 0.01608947817716868, 0.07662329447245406, 0.014238513033506612, 0.07346486717823052, 0.011247369656038862, 0.02933850342918548, 0.03943020838402933, 0.038423262416355075, 0.03168386628761167, 0.017929561999476245, 0.04681411619868971, 0.06236054145941331, 0.082065376242803, 0.0427063872226544, 0.08786989421012902, 0.06479187087426264, 0.03101497385350447, 0.09486627644829213, 0.0214073866710908, 0.02353817979324489, 0.06701894975717991, 0.028369938466517676, 0.022740423709394473, 0.01623899364213069, 0.019847170089281375, 0.03924967976467263, 0.04474518850686089, 0.01861362105926439, 0.026994100095884457, 0.022351856253320174, 0.035870829822435495, 0.07173093441393107, 0.04362063655149072, 0.0722514451932042, 0.07343003316031349, 0.009284930100904839, 0.02817535979462968, 0.06414816166544635, 0.016702990115229643, 0.060964396013127226, 0.038425292549354416, 0.02997469156980515, 0.04344040287598487, 0.06688955750676893, 0.01018793517423253, 0.07276307701343492, 0.06048248840435859, 0.0432457207822271, 0.05258331751270641, 0.04864914958635646, 0.020863136742264036, 0.07720754376702732, 0.025772670576829585, 0.055379714636552724, 0.06190591041118868, 0.011897765854824216, 0.03856693837611425, 0.00281067987558462, 0.038735983337485985, 0.014687791999970234, 0.042578029190941204, 0.020243463542072043, 0.03141065060551609, 0.022537213141819643, 0.05949435755610467, 0.028156226748720776, 0.007857906523220723, 0.04129398539061508, 0.016077757031927188, 0.04187893948607868, 0.02539812444498943, 0.02078096806672552, 0.0037438877259245926, 0.035715455700072556, 0.007532854938143565, 0.05053102925059296, 0.04124032476195886, 0.010369440555692682, 0.06024320850208883, 0.03578018629923463, 0.030961627320897196, 0.06749199372866461, 0.026768448897787643, 0.008471489324414683, 0.045212735797488884, 0.011736772477536673, 0.010996616629493094, 0.004806757872668846, 0.04564002133725632, 0.05032123224208913, 0.08537374992644595, 0.04998750902051407, 0.02036248104676845, 0.02002084796737519, 0.05679204752067885, 0.019665408068366592, 0.03438296832985455, 0.06949665430452555, 0.0422748307427091, 0.03861717076130933, 0.05455656465323222, 0.013484843394478724, 0.017051632899130066, 0.026384255803760984, 0.019069217378273606, 0.08469139541228933, 0.029401002797268094, 0.03255294132677298, 0.016241537054039298, 0.019813510101108302, 0.01197510243078033, 0.02209184792703919, 0.05865670552837753, 0.06677419998713079, 0.05952136598587517, 0.024143293492435932, 0.037334172670999845, 0.052592809342088244, 0.016917873947550694, 0.05109681965663068, 0.05377847213117827, 0.013743409560242248, 0.04186319254879509, 0.013424055275296973, 0.0692655179168909, 0.024901948448631073, 0.025813863124518145, 0.04474678963062264, 0.02992350923558397, 0.015902465581142857, 0.03290476720599878, 0.020919436543819406, 0.033814297433221535, 0.03490775004930554, 0.039581510749074726, 0.03283646663710956, 0.019594347667730144, 0.06338492741868382, 0.05299069625776141, 0.034243502023239294, 0.04524358615819966, 0.02056389896860046, 0.00622892014366845, 0.01504415790775731, 0.03115291756037022, 0.034807951775409525, 0.0845966073534181, 0.006403177375755003, 0.07459755115691694, 0.01985600308304833, 0.04450630697031175, 0.0023481990595633586, 0.017852935970069903, 0.009831252297566784, 0.02924467681065923, 0.04512927817901777, 0.025637932947926947, 0.04774030883826556, 0.028616128481864452, 0.06682313768373382, 0.03661595758110766, 0.02641169707320871, 0.05893565346336654, 0.047781999343104904, 0.03090332419941983, 0.031233239964011218, 0.080150225380015, 0.004698891256515298, 0.03853876166225922, 0.06424787950011031, 0.03787791506657678, 0.04365612557458301, 0.06989760940233547, 0.02748607026953851, 0.0531620777873022, 0.0516752620047379, 0.009331513992360523, 0.08287261841037581, 0.02908363363765661, 0.020098366489213322, 0.06796508366542478, 0.014959309839703625, 0.06245460939563571, 0.010978291806344305, 0.03798038315688891, 0.0249979545873019, 0.018607115057567437, 0.025184849397309368, 0.04962470510133332, 0.04547037499686403, 0.050914640117797165, 0.17586539619632308, 0.04748904732086005, 0.07696770462057284, 0.014586112022610202, 0.023511313089740374, 0.04405616136688379, 0.02311746154220835, 0.05188201381374271, 0.0417533393708929, 0.025240701037429036, 0.043523508094010815, 0.04042537574986777, 0.053813754310531, 0.03426926939057247, 0.021043567685410384, 0.010542668357130983, 0.0803990354160628, 0.022719794876813408, 0.05481580114592949, 0.009102469982369053, 0.046281083712294224, 0.13442422233281598, 0.07638905542872607, 0.0356417810243945, 0.01868543605650625, 0.04419469687667105, 0.03441466138728204, 0.04193967876715526, 0.05653858733093066, 0.07778151216165674, 0.04589898586874047, 0.07545676472927294, 0.05272135506534288, 0.06065728285560205, 0.05324699480326907, 0.03264469567746405, 0.007748035150730322, 0.057394430116419835, 0.046704519660242146, 0.06310686431524735, 0.047546653302326325, 0.020138999792717157, 0.009435855167647524, 0.006646910642889599, 0.1106524680771174, 0.028804505672005397, 0.028010068664086923, 0.018685418819527955, 0.018161152294206045, 0.056918723989398255, 0.019228563666523948, 0.011201222434700018, 0.03018466286331175, 0.039150574800348094, 0.01451136003578863, 0.07706852179140815, 0.027924745621520187, 0.020895871679268537, 0.03873328670799252, 0.035787399017041734, 0.032079883948749596, 0.08927025697043828, 0.10377441577973867, 0.036208755036275235, 0.03979558252819604, 0.024900251563878793, 0.07928750312496578, 0.08065981940636713, 0.026105907332572727, 0.02639418047282004, 0.029939782858315497, 0.05997652946520717, 0.035207880315400904, 0.020781611580581918, 0.017610988166603832, 0.06878803063544535, 0.049654176503780394, 0.004363853236540191, 0.04180370199103509, 0.03033855460554121, 0.014415170036015973, 0.02036568903995137, 0.007108456113435809, 0.030938031812829357, 0.04489149597863998, 0.036826888399739424, 0.05022869265127567, 0.02433728036140242, 0.047882379843823375, 0.04204037719436231, 0.06284593093779779, 0.06500900317464145, 0.04753361831629469, 0.0419673383716614, 0.012665608120451291, 0.030992784116777684, 0.032447313123773185, 0.04500824011742108, 0.06680148037811441, 0.04970555419042226, 0.023529375527775096, 0.012853817728858803, 0.022451824981779344, 0.008791188348925883, 0.019478270025443167, 0.009378002122825673, 0.08136210752831352, 0.11358137542922651, 0.0807350185970145, 0.03310083974933913, 0.024521648996479573, 0.041786622060763265, 0.03176261821100789, 0.043234493763696764, 0.05098785514072065, 0.060714659010691036, 0.07804925223031352, 0.03677955565733775, 0.07672891501457461, 0.03459579521609891, 0.05635470324646562, 0.032552550621931596, 0.008262898904391596, 0.04806576597113763, 0.04600228899489007, 0.04323484233370231, 0.021578490493759032, 0.008036679843620909, 0.012068656130483555, 0.03640403467861395, 0.21914937923992836, 0.071977224020708, 0.011715558545303442, 0.018159604796598998, 0.011834049364551904, 0.020982803506476265, 0.03213438535890272, 0.04794798761365875, 0.004986026756195051, 0.04345462912873876, 0.008129658977380924, 0.03160946382840555, 0.03611908444473821, 0.0446027995748145, 0.11537127091639465, 0.09913283460322889, 0.09077591851593987, 0.01857894025893221, 0.021099235464428222, 0.043443497871198965, 0.02393415531954698, 0.21036448047286083, 0.1604207418859005, 0.12639410403226653, 0.16159946008795695, 0.18582907445248098, 0.11461351036785111, 0.22577265367632915, 0.14292692495209558, 0.11348666397914772, 0.16776295919572154, 0.10780061384843243, 0.20073302390594638, 0.10584967901870128, 0.1435403928401009, 0.1656228312922101, 0.1195559649157428, 0.2044126514585749, 0.17674478852460462, 0.12687690030302734, 0.14485676172039202, 0.14078955496511153, 0.1891673485478086, 0.12666386657304343, 0.15027928526603407, 0.18051162752653324, 0.28784080618812197, 0.20969832105742348, 0.183005427581168, 0.07692347070382488, 0.11049158195213926, 0.12408900675514054, 0.11065279749492485, 0.27701895623918504, 0.16809631469509295, 0.14084305854574328, 0.13188235792181185, 0.08059811102406633, 0.21030362244815598, 0.06840728493707796, 0.11076555031562045, 0.13869975903822532, 0.1351371284333929, 0.16226486873722848, 0.20374287610813496, 0.14479392718884254, 0.11174597431935611, 0.16000570609204232, 0.16641750961782473, 0.1799208511628451, 0.1259000769125358, 0.1317893548478042, 0.11497857424640849, 0.14994295734551646, 0.2429931610822678, 0.11819914659304966, 0.08636073164281347, 0.0980028932193114, 0.12776753114115807, 0.13568880366942576, 0.24517140952089142, 0.194346240811771, 0.15127216585941855, 0.1371742481546056, 0.18665902346612948, 0.1086120158734341, 0.10027311817412415, 0.14566984147794787, 0.08892347961063347, 0.25841613510443323, 0.20883935263320325, 0.13495024894514393, 0.1236166752454254, 0.11888376106658291, 0.13195463065658847, 0.12538058503020194, 0.11646609482986313, 0.09801489781708488, 0.0981219815871408, 0.10846527939241742, 0.09581316112270279, 0.1641264777149885, 0.12142850596818233, 0.11773554082479208, 0.11326638305740011, 0.08689286397589792, 0.11727702188035173, 0.1862057598848497, 0.253267411382929, 0.1400627060643127, 0.14043991243646992, 0.08951205730197892, 0.2763952074512359, 0.14487432045561655, 0.1799525825246688, 0.06604462381332152, 0.09459240001536186, 0.12353314101816186, 0.10884626257804134, 0.10310644839680004, 0.12842482691931148, 0.180138680603235, 0.14775122575942548, 0.07616610086012272, 0.12231156019674194, 0.3543209663081554, 0.09931825086354248, 0.09478285713421722, 0.07812198461784471, 0.11320900307187151, 0.14075704219360508, 0.13118048348734457, 0.11891776004866247, 0.1282007921667349, 0.1397692943893133, 0.08841945504349086, 0.15320525084051395, 0.13526641343149448, 0.10597575410840013, 0.1400144884903585, 0.16515824493140946, 0.1993825334695078, 0.19606800809983285, 0.1238308887508127, 0.1819507390140526, 0.09664099573368028, 0.15495214581249223, 0.1032829090892788, 0.1384346619729073, 0.11789639630625326, 0.15760461799800396, 0.17642862403825407, 0.12702870828610274, 0.2508254908025265, 0.1646649149516898, 0.15479673721617268, 0.1204513991251588, 0.13073558558619794, 0.14758601123767515, 0.11302342593309381, 0.17787271509728125, 0.20771712575468326, 0.17492080978568525, 0.16180340801515888, 0.15180784517959242, 0.13869609713794726, 0.21587272925722986, 0.11022174280256995, 0.14863133821035587, 0.11331335956891699, 0.1363782828012782, 0.1456256075611999, 0.0777234810013925, 0.07346769404267112, 0.139862772437834, 0.12881063645885837, 0.293008865968835, 0.17784135145766122, 0.09056071675713025, 0.24636567930781075, 0.12346108278800404, 0.09685216020912894, 0.16330115587240265, 0.11775941978539191, 0.17998086649083322, 0.16899450682103637, 0.09161432514027243, 0.12710284261453536, 0.13258740396028565, 0.13696017254504467, 0.16890259159188117, 0.21150952144976587, 0.1416303977490433, 0.10523254156953867, 0.2408184672916128, 0.09606701201729237, 0.11127728172728132], [0.03099145878466868, 0.015978704736147438, 0.029223887099614067, 0.11981492561678733, 0.03742914459097289, 0.018677342337586226, 0.06748340588303343, 0.025078832404688004, 0.007775579842047827, 0.0372491522331632, 0.07748277617558356, 0.020570475833430406, 0.0356645108531079, 0.008661005112733091, 0.03021118482725034, 0.0485117057518613, 0.058241497364736376, 0.00991374560286321, 0.05231512162173468, 0.06179420330050973, 0.040218773328008196, 0.03983623115345836, 0.04472254677825878, 0.04363344937202431, 0.05174275818130663, 0.028525184269153306, 0.04973611343772181, 0.04761247174634088, 0.05327018428473704, 0.03063419368118048, 0.019387465623778202, 0.04261275595654884, 0.07100672851647101, 0.049255910374584704, 0.05778364874722977, 0.015419222106556258, 0.04487083075688251, 0.02483518963168946, 0.08076573872277815, 0.029980940932047465, 0.07078568916767836, 0.04620951577840794, 0.028149644138231397, 0.05646262588279863, 0.06545350271006746, 0.050102142587063775, 0.057087033506362676, 0.06478430192557073, 0.0279090695473696, 0.025760493609273148, 0.031468053573682424, 0.033362715414935545, 0.075215807094449, 0.037753816483722585, 0.016091379990440705, 0.0764556208084668, 0.03416048873576426, 0.06505953433412699, 0.026481039521674958, 0.015596487191355517, 0.04678947881104485, 0.061667105483431975, 0.08474159715396744, 0.05153582251119999, 0.05269103330529986, 0.06468101795161925, 0.03585064723607033, 0.0673582424379645, 0.07502151187509298, 0.05231644695384368, 0.03794557212160961, 0.009510348599794652, 0.011522517794923437, 0.0141599239037943, 0.04462260677809677, 0.058874002537660064, 0.10586286339187816, 0.04462349927052856, 0.023378329802184336, 0.05695924237971345, 0.04501873935242334, 0.051426045942090215, 0.023111715882776246, 0.026469232191541986, 0.0380013203398595, 0.018144867180155653, 0.08785486356505463, 0.011133221597711166, 0.03154684954713429, 0.05458073855768289, 0.01975734436493968, 0.009432977549881946, 0.04119431352122657, 0.04706314073935632, 0.015703844837844372, 0.03751216553932717, 0.06882603625736891, 0.017731133735768737, 0.04413905591073056, 0.06756949884396407, 0.027486583548447782, 0.045048088180802526, 0.018989569132005977, 0.034158496907161134, 0.03709617213556363, 0.0461539552516995, 0.07368292644499772, 0.04052074986600107, 0.06297760996066275, 0.026984836177660093, 0.022159889941253973, 0.03675322904581985, 0.048356143937956904, 0.028626711986538385, 0.010291865534870135, 0.04412546934139344, 0.015897683277275535, 0.01541183606135629, 0.0563742078450178, 0.044401575090183366, 0.0881779917906369, 0.06684674851356015, 0.003945542177403226, 0.04262639998248027, 0.07166202480514204, 0.024810006406398553, 0.03486019131096621, 0.013427797614807084, 0.05758234382336659, 0.050095274608822606, 0.05607481302332975, 0.060821375058543306, 0.01694400712186771, 0.044773196681372585, 0.03358576574452943, 0.05870216518580433, 0.07582917539102417, 0.023174556159985163, 0.043297071655791615, 0.07907127480833762, 0.07684346048101302, 0.06195826869037363, 0.06162447652088539, 0.018054823120755535, 0.042095600642384066, 0.05929875615683775, 0.046932974740141825, 0.0454302971071053, 0.03845747207261382, 0.014590944122192601, 0.0321886282143814, 0.04122395346301698, 0.0352718984527934, 0.012296443756279207, 0.0070150901052740315, 0.055978967763123014, 0.015777070394476816, 0.018906100022216, 0.005177393604460503, 0.04455255952874019, 0.03834846542186795, 0.05703502762762289, 0.02662496637522934, 0.02352026099669597, 0.0238584351891111, 0.020944640836528233, 0.03834846542186795, 0.04832632396550429, 0.040425689845916726, 0.03612673766310177, 0.03541409586285872, 0.06418457765492701, 0.006196735353554569, 0.021477924216718926, 0.027981177573242498, 0.03721722934935843, 0.045289187541892456, 0.024758833648276427, 0.05382969660023528, 0.10364473241591647, 0.03619884951941429, 0.026094316422278364, 0.013676684259647324, 0.08046347107137404, 0.06254098197865872, 0.017796823860055978, 0.021196538206910896, 0.027849236165263483, 0.05703996123385526, 0.06413066038681615, 0.01944932530844404, 0.03617130482809679, 0.04269472736444685, 0.037908573905306484, 0.05766448377060795, 0.02175187725844162, 0.056282729285979466, 0.025537634801660335, 0.04010459558377343, 0.061786335577527364, 0.04128664243786086, 0.014256882864320952, 0.023436671228057916, 0.02795545425596497, 0.041743234671171636, 0.10570154825766241, 0.06592419479162463, 0.04973985577723192, 0.012914873978814051, 0.0028517302182022365, 0.0643035740922055, 0.03656791237693641, 0.041915765332598845, 0.021926723420619968, 0.07625383324921131, 0.007667866443479134, 0.028713668711603652, 0.04585943657964949, 0.009335357838520601, 0.04417734881562572, 0.06425741346432798, 0.07736440026952375, 0.027461907856406707, 0.04814913931993708, 0.05886718052469435, 0.023842935315183094, 0.09046405944372378, 0.03441013763808916, 0.059572157615254966, 0.059845241147183606, 0.05348818609490991, 0.025415093292512243, 0.02629064368985353, 0.033054449295084325, 0.026622673857115933, 0.06934427941638617, 0.05149333910535901, 0.017531242244125857, 0.0920243813626228, 0.06842062252783968, 0.012987294185516095, 0.02659682605055071, 0.07858853216373152, 0.028463615697898695, 0.05720357463184384, 0.060505643411869967, 0.0876305683425838, 0.001369965827888659, 0.03516733511200836, 0.009421933434843537, 0.03626945984339522, 0.0324558166997327, 0.057876498603652564, 0.06566000937093651, 0.008075925570371892, 0.028051830032059265, 0.06423379880406203, 0.028881545388890855, 0.05259645975104744, 0.011431586988750967, 0.09197308411521297, 0.012592553975991906, 0.062409387225465435, 0.018773402102411758, 0.03937997599883426, 0.039790380791190176, 0.08458777435965116, 0.048614020624588576, 0.058145154147378864, 0.027552861645216906, 0.03984755776341885, 0.04027671255772153, 0.11975767586620585, 0.052167205365314606, 0.059351673680207426, 0.033961439940838084, 0.05424693106643615, 0.058823195586521784, 0.03217092392245128, 0.01396177430456925, 0.12722203823467418, 0.08604226123181083, 0.0679975351498973, 0.04786234664460344, 0.021526220314685377, 0.009296439614357247, 0.08444904349744321, 0.040119553450495005, 0.04258488184742389, 0.048667409292031685, 0.054783020243649526, 0.10778091772789918, 0.10804272061514278, 0.03938446144363092, 0.03506267601023278, 0.020325735639480334, 0.09131057127829521, 0.04305759640110116, 0.03593711941052349, 0.014175606681214226, 0.06012183719224507, 0.015719316941085124, 0.15826703890437083, 0.004216995139065529, 0.011633594798284673, 0.012298321629303598, 0.04010519313235437, 0.05962685629304859, 0.024962233822612513, 0.04527476210627825, 0.04425358222497087, 0.03669145171560588, 0.05202469768963995, 0.05308628104807389, 0.09172855651066189, 0.030697277191305355, 0.026472480404340935, 0.04640163913849862, 0.01781507015919253, 0.055959624043034936, 0.07090404209110045, 0.029073892829699383, 0.026804541215120305, 0.06261841048516574, 0.03275868573015736, 0.031247127222858613, 0.04228371353219113, 0.04029443983228938, 0.032144455584667386, 0.05829501626712661, 0.05329177264244326, 0.010143842983750567, 0.04222181362790927, 0.0523967904249026, 0.031195845297207276, 0.04424675638156553, 0.011054014809609903, 0.036710699674703424, 0.057767783066317926, 0.028138474576295387, 0.00840931171326027, 0.02007987121150138, 0.03583278589611573, 0.042462847871525634, 0.02623041002680698, 0.023974097228699157, 0.04249931365672139, 0.011518509239859639, 0.009926657057217052, 0.03798052105271528, 0.04724229040044931, 0.022443913208741336, 0.12238518890714455, 0.10180012292919621, 0.148190408644657, 0.21081372975341736, 0.068992032188802, 0.13029234243496773, 0.18291938058551283, 0.20254856035594018, 0.2760394362192, 0.13247835900514357, 0.1758448343964354, 0.086793226580466, 0.12215572259118482, 0.11937723660300817, 0.053714905985661095, 0.1134214775576707, 0.1216275356109104, 0.10128597834057386, 0.15797736573844187, 0.2152839906874203, 0.15985552221536636, 0.10991973562106011, 0.1612374988654929, 0.15226290140661503, 0.17934243945825487, 0.06015819955557104, 0.11643744314149504, 0.08829855870816015, 0.1285241578795737, 0.21901799516091425, 0.11702399069984114, 0.07736283745015822, 0.22435502329420662, 0.07259674400331513, 0.17591068731440654, 0.17179253571216138, 0.16114155401385602, 0.09677666990507035, 0.19669943308878332, 0.1210594967368149, 0.18457698034903697, 0.20115012813720012, 0.10395525849514431, 0.12386921612966446, 0.18543760352317365, 0.19344999454915526, 0.23837671525055365, 0.10975085153815248, 0.14384687397508852, 0.20188220175764254, 0.1778597835331194, 0.15563843801857966, 0.10539017182083861, 0.1193208831752981, 0.2300561423743925, 0.19035754274697075, 0.12466739547709305, 0.19563893757520184, 0.126796621949442, 0.13643943193939426, 0.13295822115915437, 0.08259752389764594, 0.24949409127716096, 0.25711430657294493, 0.15330271254624092, 0.15931838732813636, 0.1314324651273989, 0.1528239382370826, 0.1612381270575908, 0.14097439665948192, 0.15495543999056663, 0.1637217994298666, 0.16022315248847008, 0.14137798709975136, 0.2068893830742567, 0.1547321100388804, 0.15487323875629133, 0.11867200670343254, 0.1089915128484849, 0.17627580481911861, 0.14587864640258974, 0.18790400827363615, 0.10077144304711012, 0.10516579998957534, 0.13339847656747988, 0.1349364440407484, 0.18689666394024126, 0.1387918734502408, 0.12262973949433335, 0.15650267712771893, 0.1270445356626184, 0.09276783138874078, 0.11760683039263373, 0.10000956860641319, 0.09079652628110302, 0.08688450595664401, 0.2229099976079118, 0.14377550522406257, 0.13436123458368165, 0.10864029217871929, 0.14643910100623486, 0.15009435164111276, 0.10774204642662119, 0.10760696980381206, 0.2566194597391352, 0.13243167360703792, 0.19073101061005748, 0.09505062018551173, 0.11422974628306205, 0.09986709923513475, 0.16761872016133803, 0.19088235894037833, 0.07530565388620862, 0.14786212464734433, 0.1330158156493018, 0.15293989330530167, 0.2080986835062504, 0.15993242212120565, 0.12053367696822652, 0.14145223634137263, 0.19754720130755057, 0.17009041091847807, 0.17312324575839505, 0.10535976579112392, 0.23215742962014294, 0.10307326912879945, 0.4540908030204235, 0.08707523886715213, 0.17304041633202186, 0.18087902797325967, 0.23092863991135554, 0.16021363767645053, 0.10933613750122248, 0.07153468567036814, 0.12899760787765827, 0.16481200383315164, 0.1598180145505936, 0.12698888703579866, 0.13988402371685352, 0.1710898032592189, 0.25923695235002425, 0.2237718924880028, 0.2023915889402551, 0.22337289857527903, 0.1318507031687806, 0.13175223022699356, 0.11252623487023578, 0.1631406451305074, 0.1381897743070318, 0.09529216770803738, 0.15439484749109517, 0.1346176442119383, 0.210689025961103, 0.17153100861657053, 0.12841182640723645, 0.1300878582462188, 0.15888717175731737, 0.08030651497744745, 0.12088335014038509, 0.12421131269225191, 0.15155811583803547, 0.14378485149673878, 0.12388622328158348, 0.15802028198396006, 0.06899504291434443, 0.15109729862982227, 0.13989753750783784, 0.1523258585122324, 0.1387385384089524, 0.10208955094698938, 0.19209427939307308, 0.1491647345885154, 0.07512305682945637, 0.12276067924235137, 0.09213521130262844, 0.11083834399018558], [0.06302219244741625, 0.04244995078132038, 0.06866323491258007, 0.07575140214495121, 0.042100300591799526, 0.02524584531784058, 0.06640603345248007, 0.04303442224139168, 0.05354597976791763, 0.054275123102049676, 0.032140065900861256, 0.06951115634893218, 0.07975864719839827, 0.07585162176720558, 0.03896970910230472, 0.11203789212290319, 0.05600024202478029, 0.04028128610262948, 0.033462873750155976, 0.09096020096612555, 0.025504444042340885, 0.03214628653480642, 0.06469197300893646, 0.06695229244688827, 0.07346836053916524, 0.018165124460093437, 0.05969894899716301, 0.05595282884314657, 0.028278921475453724, 0.046859694599744775, 0.07953250570402992, 0.052203487289408525, 0.03274340993694721, 0.02899754067672597, 0.03688771578092729, 0.0328728596439525, 0.04237823729072848, 0.08050683164788831, 0.0387682547912963, 0.011588386992262978, 0.100127155441911, 0.07224641965642091, 0.07821275071511347, 0.038918159045879884, 0.04225311215005575, 0.03547972661533183, 0.04954616959777571, 0.0601102271297526, 0.03930016495888272, 0.04086856527494327, 0.026389991887094035, 0.09815264808674974, 0.03571812551648867, 0.04990452254611639, 0.012003085707434484, 0.01316445106039605, 0.0212614526671748, 0.013836077470783026, 0.014425495943625369, 0.035182243183014855, 0.044769814403186885, 0.03495376895091707, 0.00152687763235712, 0.038599608195645195, 0.06721140636551766, 0.013822245753310142, 0.035763374499736295, 0.014319320945369621, 0.03528583742257568, 0.062372546057186784, 0.022938271661499338, 0.008637728488763735, 0.013914121720459194, 0.04906220121249076, 0.04941027709132722, 0.04066590054501449, 0.07234866941167463, 0.02273817524133671, 0.05942851612945238, 0.026809015168598103, 0.021777236683955117, 0.04633318918246416, 0.10262218123722462, 0.0523097207018685, 0.02839026852480827, 0.06521759359466453, 0.08922493520883784, 0.01853556627587926, 0.055892200644819014, 0.07680146354100398, 0.08999340566656283, 0.022930072605489724, 0.1281719949216612, 0.11437048429563162, 0.08950710071310883, 0.013937675093691197, 0.06658931998836418, 0.04693676687536701, 0.011029483716664536, 0.04937783709817356, 0.02322110940792388, 0.06092109672364689, 0.08208524856355884, 0.10055015088930246, 0.045596928891515544, 0.048954309219674724, 0.020530399858891483, 0.054155686164214734, 0.020101754513058453, 0.055446808616961205, 0.04160710850790624, 0.04925691011932589, 0.03445702987993437, 0.06450238923031477, 0.03209920277098014, 0.0051727324382462095, 0.047790951080500126, 0.027927091765788295, 0.04015881162617476, 0.010856508724241248, 0.040520841796551986, 0.04269476183840344, 0.03982773523837809, 0.03109803693669458, 0.0926036817292052, 0.060325631901862166, 0.036002857415306, 0.02592444025550879, 0.008581416238279594, 0.037158765349416964, 0.032304870565572096, 0.07337199433917001, 0.04233125694877198, 0.06424189252298206, 0.03016291937280086, 0.04732312799821939, 0.06448753478546297, 0.010388247056623862, 0.02989826855369874, 0.024351192518107356, 0.0952008806709801, 0.02980710409070936, 0.06522071157251635, 0.027917778051848856, 0.016029784606108745, 0.10641998551305264, 0.033194923007320014, 0.012239350096112298, 0.06276561427981624, 0.03636186919926155, 0.06136070095723676, 0.08600695223938074, 0.019192509653587497, 0.024305526016940995, 0.041245507346766616, 0.06066945982315849, 0.018927830106188214, 0.09751029868399906, 0.04113262812156351, 0.04314434819764668, 0.05613390521536912, 0.008015149421313959, 0.06885700153126832, 0.07835073081115562, 0.039771515876054764, 0.06577440161979006, 0.03600589112348614, 0.021354359980191917, 0.05851553850657037, 0.05733662878253287, 0.048223798418597835, 0.058585106950974276, 0.05742473272426475, 0.09202094162784277, 0.11680952438543882, 0.052741706191051396, 0.012296507916142865, 0.008800643789131314, 0.02819814133427797, 0.03812019803350972, 0.06816020625973902, 0.11426382953481329, 0.04990897734739608, 0.05268383973969087, 0.05377452677836823, 0.02338294931236775, 0.02167053212742171, 0.004039096595313881, 0.023491781678110845, 0.056041013224110495, 0.08470611196131476, 0.05847045040178684, 0.04635641696832834, 0.02651264064855153, 0.06026747816753003, 0.04935459016011127, 0.03116892305232825, 0.03898464015594894, 0.05153425969183446, 0.029493383424837264, 0.07222731342358936, 0.017363233416671717, 0.023863937615627245, 0.04724526282159552, 0.02770731071641128, 0.08523056043251868, 0.04615380586455426, 0.046056405445861245, 0.07074425147185404, 0.011141896585843736, 0.029422233008869716, 0.06137221525873869, 0.007429372260136711, 0.12904971717826783, 0.03160446127426, 0.07792318480149393, 0.0502149528643537, 0.02268157858071068, 0.006810838136927135, 0.03382691490133444, 0.027720897285748395, 0.0202186499542046, 0.026859712952207175, 0.057782534089299946, 0.03128292842678005, 0.03238892956306377, 0.08603716674711435, 0.028054120634952863, 0.030277648700341105, 0.0010022039432735785, 0.062107479635385744, 0.10719443145658701, 0.027100973191761205, 0.08327733499989395, 0.04037875163879606, 0.010833249337250188, 0.01685676311383084, 0.053415813768703135, 0.05290431984429879, 0.03464916856178353, 0.07528154509923152, 0.07025918758083737, 0.015147614251491765, 0.017574037830795974, 0.05795214212529602, 0.07731264336935936, 0.008745812961170751, 0.007012563930343717, 0.025494046313988588, 0.04488455522204599, 0.08041280201606213, 0.007608489362492918, 0.012164231344696977, 0.018058191992402557, 0.07509493374175603, 0.05731139001586745, 0.050444139558221066, 0.03900610210914766, 0.061431897338479764, 0.02317041545475443, 0.014485928789532233, 0.033154140316670945, 0.06032918271939121, 0.03201057405902013, 0.03661856228005021, 0.05129515215934766, 0.06134437945400996, 0.028160679634780656, 0.07168105442918117, 0.05017568319735508, 0.054606383350948175, 0.04124538860313835, 0.02753006861424975, 0.06560969271606977, 0.03172476580666919, 0.022242194597399043, 0.0068764363306634615, 0.052833230715365186, 0.043414206499414104, 0.08877746325226561, 0.03730354830622673, 0.05091008572508732, 0.019350295037692113, 0.10739942126336599, 0.019345499327286117, 0.017815773044863058, 0.04477456797875705, 0.09175074241694905, 0.0627980925773661, 0.05302652618998001, 0.0029725700545485223, 0.06184352787151452, 0.0803906927185674, 0.05866329388452634, 0.021681081158139055, 0.019599601115670898, 0.034730155546698845, 0.030171380813924537, 0.005157291936132336, 0.013022093729476535, 0.11516523923003867, 0.010874236956419004, 0.06635885009722364, 0.08168148958394605, 0.013855810938102585, 0.02251780621947781, 0.023520239929278052, 0.07877031716728404, 0.020113169223130233, 0.08368780490972343, 0.007796707110584624, 0.01669304054831305, 0.046734623085226745, 0.07292232371025509, 0.032297906826340386, 0.06817430227754578, 0.036946892242638335, 0.030355090613386808, 0.0313636894157577, 0.01653952993482592, 0.022100960542898507, 0.015608320376955935, 0.025419917731215397, 0.021935753682027423, 0.028574347961694006, 0.04223354626446963, 0.009221166687747164, 0.06448414101595841, 0.02954139415505192, 0.030052313513513056, 0.046301580394708344, 0.007755414492660954, 0.023999912476527597, 0.04771765178790496, 0.05909948136597391, 0.04567223150403269, 0.0440971662230309, 0.010646181199849855, 0.0411015747475528, 0.026409339437621738, 0.07053795931560379, 0.02046870488312937, 0.06455600772413515, 0.07444219618675209, 0.041722875884583885, 0.03160294633538973, 0.01738591536488985, 0.04237522656518606, 0.04931277325076442, 0.11351628859917964, 0.029895845800638202, 0.030083311346149253, 0.16661532884163244, 0.13361668905183194, 0.14807811547671595, 0.22500158618054084, 0.16623873533981462, 0.27152331726204965, 0.13941851805054373, 0.12456611099262392, 0.16532060960608144, 0.12095835014817216, 0.08685914844635033, 0.1429787278175354, 0.12859464562948675, 0.13379892604725976, 0.15619008261109554, 0.27633453328763286, 0.13355704144604746, 0.06969127128080976, 0.11989607731060636, 0.3274839563715843, 0.1081905372801327, 0.1681598233840158, 0.2786183026769469, 0.14769735445659007, 0.16756140146284335, 0.21015745287220325, 0.09394990505590554, 0.15289722220791926, 0.10051646600327185, 0.16183789729351, 0.15171805967486676, 0.12050074284836171, 0.28903976443313784, 0.13226849687916617, 0.17873703081521297, 0.32960457967654355, 0.1446795196182305, 0.18685583145387713, 0.23397649007458843, 0.12895843014121056, 0.18578888547997321, 0.161597790016282, 0.1496858735598864, 0.18315000369423823, 0.08729607903308446, 0.1739094971168426, 0.10539407886925245, 0.16348399041641146, 0.09378616142296985, 0.10756358624466004, 0.2523516452000026, 0.1659715391935841, 0.1330628534478526, 0.20778300931617139, 0.14077110756789485, 0.18706042289493546, 0.12555587360815657, 0.18369458495609223, 0.16716435341344726, 0.0989734806540993, 0.1137248024104103, 0.20465352482372717, 0.17153021188512926, 0.1896421238780022, 0.20653721245546497, 0.16264239686631388, 0.11070192671350895, 0.20755520541100733, 0.20269204862415793, 0.1316440432903267, 0.11363082640473882, 0.14921914215289778, 0.0747964199211809, 0.1140257983558601, 0.21926620764838112, 0.1267980775164981, 0.10787504695115552, 0.10306439783063628, 0.11800438406005984, 0.14862387651397338, 0.15942508805423014, 0.16573380678892136, 0.19114895753802794, 0.14078333433116638, 0.13263960519144613, 0.11769469301666945, 0.16486907738351053, 0.11637274701628955, 0.10875107615344948, 0.15565506212653654, 0.17202277577692465, 0.14236682274889562, 0.32486261799931526, 0.3187176735410768, 0.19299069419503215, 0.10922534586561304, 0.24100151634024036, 0.1742056820301279, 0.16999052837491038, 0.10225785280307455, 0.1095810634714942, 0.2542939232361894, 0.19585290593245339, 0.17131221390539603, 0.15300136420034594, 0.17169433856202712, 0.08832082122323975, 0.18805575496967764, 0.14326705266871761, 0.10618911725619148, 0.13245934470286294, 0.24766514828849226, 0.14636989262315536, 0.17097584001960295, 0.08826949333231296, 0.11296026198373688, 0.16274350515056044, 0.17755167829173227, 0.07713183895834992, 0.07442532693065944, 0.12221550809279566, 0.10345334833067271, 0.16626585485233417, 0.11769782631627976, 0.19167938149504124, 0.14589657286001792, 0.1321170719400529, 0.2121651394953651, 0.16270202915033988, 0.08205924753940876, 0.1401292484614157, 0.2477337744447493, 0.19512564334417545, 0.17620818989892162, 0.13516977910072575, 0.22980555501436034, 0.18197719969095724, 0.09730169294221748, 0.11352409503512806, 0.17043518112792125, 0.1988836110479409, 0.10134077660979764, 0.1367824554683701, 0.10371349646799988, 0.10598598138218927, 0.19254248679405261, 0.15055500030998262, 0.09804587075186354, 0.21371761667391947, 0.08433818291392058, 0.11819077325203728, 0.20455839202529003, 0.09734417251761883, 0.1272532409958301, 0.11712963422459942, 0.11875301284054596, 0.12099814841583853, 0.18534509074543754, 0.12867330753755185, 0.23095234267173276, 0.22143471144860793, 0.1675082196391398, 0.1698382454173219, 0.11928778817696918, 0.17385438475156986, 0.1334492375533427, 0.20856935260516984, 0.10172283231851556, 0.14435066871585386, 0.12496276067629938, 0.13308401279632123, 0.17034842933137573, 0.07641144051787353, 0.13181788396210442, 0.17222346016956916, 0.11867483356787313], [0.06866560978514534, 0.015318337903027574, 0.013747784879899794, 0.031135918069330436, 0.05548418604678685, 0.07384257150753852, 0.08379060624828262, 0.027061592442013567, 0.014572752406820657, 0.014650741115122315, 0.04492601207006843, 0.044680626447042154, 0.04122915903046247, 0.0075751683682263385, 0.010966449044644834, 0.06784749682992697, 0.04624796190088795, 0.018884890878032294, 0.04511252766655338, 0.04095376957388174, 0.029152290437430627, 0.0007762347588375692, 0.004362081179410339, 0.0184442256126673, 0.04619037507161979, 0.02658910005383434, 0.019542968065868464, 0.061473725739145474, 0.044509965040150194, 0.02377263717203131, 0.07293645803245806, 0.009139041104654392, 0.032590242147806196, 0.03334321464682299, 0.03626500504211553, 0.012688362847022232, 0.0367101404305187, 0.06443235347227705, 0.04996728429931307, 0.011619891400539107, 0.027741081787333376, 0.07712031699596875, 0.031162595166073694, 0.015857040397672644, 0.01715816700110032, 0.03852627442909345, 0.04532757237733853, 0.036904661645812374, 0.043637961629898324, 0.04115508598906379, 0.061599421615321795, 0.06555323203605029, 0.006259976869313828, 0.10185453049357861, 0.0306342511377748, 0.008906537250074889, 0.029134593806379748, 0.05228868392746776, 0.052006610353747686, 0.030361368703926285, 0.05065572538202809, 0.023889201280150204, 0.11844245611780113, 0.04026157849077736, 0.02272839804420308, 0.013999581701242396, 0.07885228857518205, 0.03239832563145507, 0.004327014462286306, 0.01909000708931877, 0.0646305021138922, 0.055155576462106365, 0.04177519968981224, 0.06070420957140385, 0.0335245514889398, 0.10640074138439472, 0.04652252015207083, 0.020522966890806155, 0.020851564984167778, 0.024265116794155012, 0.06031301826418889, 0.04105236508973664, 0.17110976751052565, 0.06449278248774429, 0.057389756980081724, 0.04296390384796166, 0.022155825844815662, 0.03919274794057973, 0.007009903690026653, 0.05305311710183179, 0.030271181003040368, 0.03105633111009675, 0.0524626893081492, 0.01781187557254828, 0.07337623846627052, 0.02022406236538964, 0.02833863802915139, 0.11172082365280199, 0.07178741807658827, 0.04610958343912517, 0.032401991362172755, 0.034730871838908044, 0.010308092234716302, 0.013310620636348764, 0.15297741629183292, 0.01296174132280172, 0.06888992032937466, 0.005761820535671207, 0.05738463568230791, 0.03305763622084933, 0.018273194568351876, 0.0047545552050935165, 0.018643607655840538, 0.029918296007259242, 0.1122559896940666, 0.06444182231902115, 0.04630311257055691, 0.08746087986735568, 0.027862183051183823, 0.012286813073461095, 0.04602718685242919, 0.036952048014368744, 0.044795535805244605, 0.08966433259868815, 0.12565767137153497, 0.02422664768903727, 0.036351956021521366, 0.018740866348267566, 0.07143310241160855, 0.018210725843786232, 0.011722435142033765, 0.020036269317290956, 0.03705489914864302, 0.011017133421715229, 0.04424345454261188, 0.048100760867518765, 0.03143348577131908, 0.020709825311637214, 0.0682651526444862, 0.057472325936560674, 0.01587474564721267, 0.06278646336267553, 0.04683615654827126, 0.04020725902650626, 0.015380219612721235, 0.020124516900508635, 0.020062429304685325, 0.06996433566054029, 0.03526225340582671, 0.04427946067505306, 0.025305822341432496, 0.06933471863909114, 0.10779535848527186, 0.039067979030791795, 0.013730841887844427, 0.019167184702030594, 0.06188596914251966, 0.014258976199574048, 0.035653900535356615, 0.09849616957287635, 0.03315748429046043, 0.033062619622796774, 0.07309647847808178, 0.034989533765662106, 0.04958580698697798, 0.02885607488062834, 0.03315689057231911, 0.027510073719426032, 0.038146808097559604, 0.02478151751171437, 0.04363508113930303, 0.053012763420420314, 0.04469424749033586, 0.044199101882235664, 0.05062334667590838, 0.04447064174699687, 0.028631817962553714, 0.04626195066638532, 0.008565981481825153, 0.03748190506631809, 0.014773387003750091, 0.023211902946293838, 0.05337833674744733, 0.09187883231788875, 0.014763007469985996, 0.03308456038094817, 0.04418466878574222, 0.010685147304508475, 0.03685121935221457, 0.03724401944407052, 0.03206424426377541, 0.011942940144499224, 0.026431883490013502, 0.05595650606518311, 0.05717453606907399, 0.013645895185970492, 0.036880981868072864, 0.040660737112404845, 0.01992396082759144, 0.022464551617421454, 0.012038205093103311, 0.039070599051492835, 0.0222673318574145, 0.10622304729035786, 0.02947836810152137, 0.014257916125408826, 0.04158478087535308, 0.05431869435274313, 0.024162342268673163, 0.031005838255007422, 0.0442862328923037, 0.025293561104204387, 0.09368600308774941, 0.04882935261834533, 0.046996414481151494, 0.013915413536221511, 0.06520430196917827, 0.027406711221462297, 0.02362263332601757, 0.005944288315086236, 0.014889811300822805, 0.029630118628002466, 0.028371708129622766, 0.12879831776503595, 0.0693131456031434, 0.04094621977738796, 0.06406071655932935, 0.012962805227406565, 0.06602451400530916, 0.004209407516980484, 0.05788533159741952, 0.007586308244255282, 0.035392886718675014, 0.047008714022775816, 0.017589752209342776, 0.03335021286001129, 0.042082623112946756, 0.004093042112916949, 0.05417020736081947, 0.013102098206628957, 0.028407486350906473, 0.04864392103627325, 0.04915262257019359, 0.04493977483962813, 0.03164364667158694, 0.007035083084877942, 0.044247150916846535, 0.04365354385827819, 0.02955667952436113, 0.019019651489572662, 0.016076799422021837, 0.043506749920667186, 0.048391299712802135, 0.016886378157763712, 0.020126072058994925, 0.06136837715823805, 0.12034564834809112, 0.07332890955430847, 0.09069282861967241, 0.05249653124220429, 0.016864747665221655, 0.04450791575495274, 0.033728725412079406, 0.061667756658167615, 0.010554439298087552, 0.08431976616022088, 0.046694100864471934, 0.04700174645310448, 0.015261787207677, 0.03348767201626494, 0.025254415926493468, 0.04092379255340465, 0.07176146301771365, 0.037722671179160956, 0.029951597849327712, 0.05343999150359342, 0.04331357702012024, 0.03338925270063262, 0.010179601095226264, 0.039163575312423135, 0.025987111993374366, 0.03259009276066096, 0.05134769046919481, 0.01028152526311216, 0.09329660825671689, 0.02071183437721864, 0.031023841321228013, 0.029619537038548343, 0.06097813196960957, 0.033697936338402575, 0.08540096903039564, 0.06411035139594348, 0.019369610029483036, 0.053955832976968064, 0.01498765988095153, 0.0020924216932466915, 0.022630243028904644, 0.030274479011554393, 0.06808204230882468, 0.04621216261218633, 0.05870471242815257, 0.019621256506070495, 0.0349621499528087, 0.03476916857424282, 0.044084855190087716, 0.04453885421577481, 0.018692572165520924, 0.038449784380293665, 0.05506516276528278, 0.021258062728109862, 0.06525156959410637, 0.0629902006156983, 0.04091507830326596, 0.0763512260070251, 0.07075162123768561, 0.026730519884656516, 0.04771454530137201, 0.0071883179067123324, 0.027321776968517134, 0.03924613660802284, 0.02509273307007407, 0.03224058046696648, 0.01753630225486573, 0.020397320810344913, 0.056605869002880595, 0.036268318372388045, 0.0821377332472513, 0.09498430761478602, 0.042559045532177535, 0.06291330837073826, 0.0553852228087283, 0.06024506243486559, 0.013279941687811048, 0.026187794470799067, 0.027309820251238924, 0.08514924786023556, 0.04108817970019676, 0.03385632501674756, 0.0369159231382993, 0.04879645297243711, 0.032896753926310814, 0.0448425697733558, 0.020838367204452236, 0.0047992324952276484, 0.05205033482202599, 0.0398143670040994, 0.056582055159754334, 0.03597736200918594, 0.012884979312788817, 0.05446209835128919, 0.10597638996137727, 0.021113475123720787, 0.1424771547317505, 0.10359265375882389, 0.13773102553621416, 0.11110621429378949, 0.19753102153058977, 0.19781367733113228, 0.1971624872737354, 0.2142900069274249, 0.13356462571649783, 0.10525100428851382, 0.11942147051975613, 0.22557760769080734, 0.15592815714978403, 0.11650805346547596, 0.13391056037958593, 0.11774870221533122, 0.1615064263704323, 0.15544634913244557, 0.1738607279595829, 0.13070958456204784, 0.12276274767974693, 0.14850084279333392, 0.13618420208654097, 0.16792006850723298, 0.0779298727490729, 0.11741634263026139, 0.09200760403708105, 0.22300264828147429, 0.17608029918084223, 0.08519696747703899, 0.1323825060840576, 0.16341475138981498, 0.14379677182484057, 0.14922591437014843, 0.15907913806938356, 0.12996067232902975, 0.1632706655730163, 0.1450029619398617, 0.14881233414334638, 0.15358875445540876, 0.22513687730796877, 0.11308485852374185, 0.10400002101256002, 0.11069958248446066, 0.09558037764603093, 0.15600076696324736, 0.10345301891286528, 0.25737627799953183, 0.2079265129061476, 0.16253088510805563, 0.16769782640039924, 0.12405755884584882, 0.19164286974457004, 0.19460422858115167, 0.17790443113734647, 0.0907611406798805, 0.12297570480093842, 0.10109355237575308, 0.11805945046005711, 0.13094596865196384, 0.12267868485181563, 0.11151751923945644, 0.25035172670839295, 0.10775415827670407, 0.17004177965704473, 0.11983374839708691, 0.24037157756186303, 0.19558927975595, 0.11706796414669483, 0.05535903792347639, 0.14276224669189225, 0.2492085090207477, 0.15164226293563843, 0.13750737382759973, 0.08090898950373934, 0.22181286776979126, 0.20427193642864305, 0.22675388973326455, 0.09546362584637058, 0.131047475301931, 0.17418498233441385, 0.13710384467436423, 0.33930999437166803, 0.2028646482334983, 0.21165688612288047, 0.2748728681716227, 0.21835876118031242, 0.17069675418878758, 0.08181442882144645, 0.1850397893858533, 0.10649236550013866, 0.08323645654825435, 0.19579364137063104, 0.16590272917622523, 0.1540583510312342, 0.15728594074326177, 0.15805755982235556, 0.1549899905559517, 0.16306517014820732, 0.09679461168425699, 0.1729150537040926, 0.09686486194691352, 0.0653145190388445, 0.1115686632692814, 0.12972430356087225, 0.08815929924528446, 0.24681057720895738, 0.0663652316096329, 0.1726264990265331, 0.08169454372217579, 0.17156839370727542, 0.13504562689171684, 0.11125997580107182, 0.13767522369180957, 0.1928666798818496, 0.13018731178054888, 0.17585030426421475, 0.127124791033566, 0.08257073380293385, 0.2645074534079721, 0.11695941714870355, 0.08566334648358245, 0.17647806735288712, 0.2580326314895384, 0.18963054062858706, 0.07453472428624669, 0.15035073062585247, 0.10698742683856718, 0.1901791515129228, 0.08593145427444289, 0.0881423227368824, 0.09262379153721756, 0.21318239700650016, 0.07013494344127756, 0.17518324086502676, 0.14899041894222462, 0.10278886664778956, 0.1190909035804291, 0.1857554687247161, 0.14698306939774944, 0.08553278211864733, 0.17561882313701416, 0.08560433473077514, 0.1548643368146112, 0.1115253869624388, 0.09991301088443688, 0.15466896907216118, 0.18724541780689072, 0.12678385892462346, 0.172325303898223, 0.11804130949801016, 0.20165954596332966, 0.16947285212095708, 0.16941390931606296, 0.16610326035128486, 0.10858711035501574, 0.11557010903714166, 0.0669561994953021, 0.16411112531298594, 0.22179431312026518, 0.202603580790662, 0.15576121126932485, 0.2698142057464969, 0.15777445969081696, 0.16849651902673707, 0.23476157697939107, 0.0784068007863337, 0.11875707310654464, 0.2039452458942129, 0.15199023539260512, 0.22143003831226982, 0.1463105361307821, 0.10771531761894304, 0.13273277680479711, 0.2946393462198396, 0.10669286603168135], [0.04141744045961288, 0.05146184140035222, 0.05410613559727227, 0.041963484949402274, 0.05460527252345797, 0.06619992515733165, 0.01744961174535415, 0.045966210084096085, 0.011692848826398053, 0.04337457294065145, 0.03987261266898244, 0.0084048071162655, 0.04775762625579392, 0.029674316155574018, 0.030509748443540548, 0.039652151716572624, 0.036220660042618556, 0.07578858805279579, 0.01764758801718633, 0.025769782425355048, 0.037720552946050326, 0.027453683902539557, 0.036341793865205786, 0.07541136635888009, 0.04046803918637095, 0.025014408240695635, 0.012034099819439073, 0.025717355198256915, 0.05345355892073243, 0.02523053505067383, 0.11205011122529546, 0.07905498777906741, 0.03554287524293027, 0.053416464943438775, 0.07083046700685255, 0.04134144453752426, 0.031540565710935387, 0.06374783092929472, 0.0749694332180004, 0.06854807657580222, 0.0825316556579163, 0.016330929938703775, 0.036584421571704655, 0.013198436635936941, 0.048607535690309546, 0.03998773653180369, 0.021869153828330098, 0.05087918173822184, 0.01985081475258114, 0.04417950918357219, 0.08063018712545596, 0.019613846520622893, 0.003481757814898306, 0.08941955984600129, 0.02474357509204457, 0.025120235626555742, 0.038061818303239923, 0.045620240947051395, 0.027355193723774245, 0.05297861505119551, 0.02807820069363281, 0.030359535838567445, 0.05997693932224667, 0.01722891905134724, 0.06392816036579109, 0.07190728785410043, 0.0417837837050038, 0.031237079979731675, 0.01801432962829788, 0.03405307937834052, 0.030042584196874694, 0.01939466876548625, 0.003965041509100927, 0.054217279633326884, 0.07268095238795204, 0.00841811023307063, 0.015074510311317301, 0.018350820342499404, 0.040538484801448164, 0.058848055139664686, 0.08701880883064964, 0.01641214291955675, 0.03542683207459989, 0.05301929048953518, 0.0773218670679677, 0.05778667479453068, 0.03665299793224662, 0.049318710432177594, 0.051446749468243895, 0.048531390381075686, 0.02469462207368305, 0.02126136073662389, 0.06521738675092498, 0.0659789547564522, 0.052497075164630536, 0.09353910572826864, 0.039154707844699585, 0.03633122185185071, 0.03512414690527705, 0.06234863645306999, 0.029925658112211578, 0.03242004805454805, 0.1308726540376102, 0.06085325580751223, 0.06834346981298539, 0.015056827086805096, 0.02318069635469827, 0.01644588143174206, 0.09338868436433616, 0.044189357243838816, 0.026731149991974238, 0.023742612271058946, 0.03333564569813109, 0.023440212469487905, 0.05169300077062461, 0.04261818368949237, 0.0703783525574592, 0.016893096748859655, 0.07408306182872865, 0.035499265687840606, 0.06677511929263992, 0.03512034327873299, 0.04033216966256019, 0.04614744733478274, 0.02668406431292815, 0.04869512252269253, 0.08499960790598586, 0.025159805983064637, 0.05723079756623315, 0.012140754580257401, 0.012661987397399162, 0.008741038318182673, 0.06552898535324682, 0.06327183751930153, 0.01903524520927139, 0.017929452831947038, 0.04566430632445601, 0.004317225773833812, 0.10186548555089582, 0.034232198395916534, 0.05591917460063293, 0.03727218466660669, 0.024105423851118937, 0.052876009065057, 0.0526307268639005, 0.019513500493861014, 0.004143932854921948, 0.0501414850324152, 0.03474849569160612, 0.025960500014104673, 0.044133643499545516, 0.018379041106410084, 0.06316453924462681, 0.03017403530858217, 0.12860550875625304, 0.1080223733198739, 0.01249454930544861, 0.05487884252121853, 0.10914207210824375, 0.02997188002712304, 0.11694943502305016, 0.015411495152229985, 0.044684230890725894, 0.04071030683154541, 0.011506552522581433, 0.0373492875857459, 0.030465037637059728, 0.030106014361785307, 0.0889109540730715, 0.05715103632199669, 0.051330139394849546, 0.10637552943080665, 0.03306728892869527, 0.09899221150384796, 0.032044971406820326, 0.03689771705877878, 0.015480725560337307, 0.02643608165183856, 0.020814687426712726, 0.05000547761277807, 0.09156221583966287, 0.03709003577129014, 0.018228790197040767, 0.07767712502109428, 0.04926825588148448, 0.012486789792385555, 0.0305512435959592, 0.023021878667115685, 0.024847387666663816, 0.1128076725909787, 0.014813687059006866, 0.04560934717676813, 0.003135576327857111, 0.04396919506571947, 0.010356938000768423, 0.04087722972936688, 0.0445126157043682, 0.020864705307288997, 0.05272667171553739, 0.05009452001221719, 0.06582199100164637, 0.03511539818118176, 0.03327116407754441, 0.0071188251134909454, 0.015037956426010258, 0.08276702085089299, 0.045981516520823204, 0.04009387418327313, 0.07474470898629197, 0.014818094937401194, 0.08200230422399699, 0.04980926717361135, 0.033396695244817004, 0.06027556039513119, 0.024697372329331214, 0.07159810242874008, 0.055645922529360944, 0.022268115182317073, 0.03196490755785377, 0.024751333647497722, 0.08078156609929378, 0.10127510755292832, 0.006432652608641694, 0.04568169652033718, 0.02067255513412097, 0.017564724116856535, 0.04078121592981681, 0.061562431059897914, 0.05024451236691206, 0.05177448571269071, 0.03858571136069875, 0.02258216143555699, 0.04446079368673025, 0.06391360469522976, 0.05113684008979509, 0.03284670540221757, 0.0520351049940913, 0.018415640956992586, 0.05094672388006603, 0.03972161290866714, 0.051105242793358145, 0.015842289374690625, 0.04732407411680587, 0.03589211557541163, 0.04320441715178951, 0.05023327002662325, 0.05247342603040799, 0.036938342701403365, 0.009721132904110898, 0.05436842878078742, 0.0438332527635559, 0.01007782248404598, 0.04490324393695882, 0.03372885947746616, 0.04616327471129837, 0.02912080805418232, 0.07245816635869204, 0.04696876636796421, 0.048420897519756714, 0.051858682606008746, 0.012874831520621816, 0.04483543366434113, 0.004594667388441703, 0.067875420734767, 0.03823506525687633, 0.09770579666139619, 0.008553396572449036, 0.03126917906375903, 0.039237326596893614, 0.05051499503033777, 0.07854428292522508, 0.08419842549389409, 0.060144823660413106, 0.08236809588608243, 0.06702664894081893, 0.026430707545049732, 0.020968619388558214, 0.029834786677853237, 0.061946367514469934, 0.10898058843468467, 0.03407085644862345, 0.03874084799580517, 0.027185223711233948, 0.047180359852650476, 0.0658623561743767, 0.0422599226717026, 0.03317264517048194, 0.03989775950509695, 0.015475199193573527, 0.017442083016278285, 0.014014444764583342, 0.0419370012898599, 0.022843378265538526, 0.007690631224954081, 0.0576724932198563, 0.03383494733322052, 0.07353946115941772, 0.036156113304558306, 0.01596229130236973, 0.04742610936744079, 0.05244360605795538, 0.0443701348417709, 0.05286971182231942, 0.025287286844104532, 0.01795508804911327, 0.05762280475708747, 0.07355730334717421, 0.007450587149979848, 0.05997508921990952, 0.032562739591324524, 0.014656435063619529, 0.03161435721502189, 0.06234358793364898, 0.02103244217353002, 0.03055337715082832, 0.017194921984487486, 0.03680664069590069, 0.021515418474953023, 0.056717533978723714, 0.03354180761943421, 0.01935004605911672, 0.07779862656588517, 0.020892778599274256, 0.027313462999318878, 0.05862739883483418, 0.028953266540361993, 0.030674930406554096, 0.04330033135990943, 0.03307022304544526, 0.072729445753559, 0.044725500047206886, 0.1175913094512878, 0.01878324824745857, 0.03892891492033678, 0.030495129570725466, 0.03754390839246973, 0.03732760346704914, 0.12577006413090613, 0.026511765393098036, 0.03832455964819078, 0.03313847764905903, 0.05441372755975012, 0.04204022014633783, 0.02940607621454664, 0.0068991771718907744, 0.03763796483737327, 0.049307602157275525, 0.024684913824462605, 0.020062592098369234, 0.04036796512082219, 0.05843845473962927, 0.018488482512052984, 0.15414675757769616, 0.11595635524680538, 0.10248381809722032, 0.1313595182352489, 0.16487037973298183, 0.1194960798227018, 0.10958503946782121, 0.15112866226944233, 0.15635068528354168, 0.18197182175372878, 0.1794392882936424, 0.1280081287146576, 0.07366826352212699, 0.14977855487696587, 0.09484326316704673, 0.1997104497446168, 0.15053557232022285, 0.16885814317051442, 0.10455453843479195, 0.09156596967049184, 0.10483465082342587, 0.06425842470038803, 0.08773241207123765, 0.2136346493517199, 0.19085617405512642, 0.1345593142773836, 0.2183841340123646, 0.06793185843214875, 0.12056988228352801, 0.09552857478059108, 0.13504296090574036, 0.27020800558309405, 0.15796838718796932, 0.12783274054527283, 0.207805241187734, 0.1783504015615871, 0.09560149102922409, 0.18393283830054347, 0.16263562464906325, 0.16263062975579695, 0.1348314440298465, 0.12534932098201207, 0.1642348791562742, 0.15669527163188304, 0.20565610409023302, 0.21189820381902882, 0.11520534393287475, 0.13465548895539778, 0.15281716601983195, 0.14878018909404356, 0.2789792833068679, 0.15952414322283962, 0.12918801137035893, 0.1672561154250176, 0.1487504342390645, 0.10365820790250456, 0.11733524456259706, 0.15850786630424762, 0.1302703097462654, 0.33393411025885616, 0.13945823204853844, 0.13223917103342472, 0.134967731071576, 0.07652149670907567, 0.14690946366998459, 0.11119968468143095, 0.24105742543695435, 0.10608657638752654, 0.14009790014355414, 0.1697421167045832, 0.25906832107613165, 0.18877457526903, 0.0869374962583665, 0.18956551508557415, 0.16875502773590628, 0.0658532627107155, 0.11317842084193423, 0.1133331016547257, 0.1758704830201403, 0.08755834923396189, 0.1583590307423184, 0.13227842537866485, 0.24331828879733242, 0.2659538886960476, 0.1688105997539336, 0.16926323514311545, 0.22691389485712976, 0.17080901671321164, 0.2566043065199929, 0.14331834991612744, 0.18079687270425981, 0.10026877445559348, 0.1959920428212612, 0.11559416419796406, 0.17294981877409643, 0.17065783692223413, 0.1549769823829974, 0.14969370297847256, 0.20353238579005967, 0.13250684215416833, 0.14527812540050478, 0.14841876413312652, 0.20352948997770587, 0.1796546815744331, 0.09125648547084102, 0.135544809783178, 0.10745585129986848, 0.27430151979769435, 0.20063380019799357, 0.1450387229241671, 0.18332831831949373, 0.18571132673851906, 0.1382395087350761, 0.22474336858478286, 0.16911502777328416, 0.16834757621249846, 0.18975840070314948, 0.08010552414963323, 0.24009877365202675, 0.11937943527535086, 0.16744818898939318, 0.12756431865836346, 0.14985153241263283, 0.139659927677243, 0.13187567763511213, 0.09427268854192189, 0.12483026576979507, 0.11479793837474239, 0.1251544282140751, 0.10470543477323749, 0.21165262667402146, 0.1689671881256565, 0.15782591015581163, 0.15882095111714256, 0.14475232861455412, 0.09691110301402309, 0.22737385404686775, 0.07517678257558616, 0.18148219963956266, 0.09926981878496947, 0.1393151727895583, 0.1190791977569461, 0.17725123392958797, 0.14664969857661955, 0.13811255264426434, 0.09220591355716029, 0.1761686904055457, 0.099608636491241, 0.133809314199513, 0.13027366521137376, 0.20425034807093684, 0.2853941358625889, 0.14708005612896335, 0.27292639197361085, 0.2184936845855367, 0.25426404580714246, 0.14042508097425585, 0.13569499365985394, 0.17706254647383768, 0.12263440496979222, 0.21294604356010116, 0.2417347390925692, 0.11982365901912413, 0.0699274485269862, 0.1794911371243577, 0.12409456089259156, 0.15821568036992706, 0.13688768530564924, 0.15632243196089424, 0.2390121545402273, 0.11641066836854143, 0.21931149876646458, 0.08717355859135428, 0.13115880319908743, 0.12340765581616472, 0.15348082798863613], [0.022138429903275064, 0.04605830534391346, 0.021473471330659046, 0.0612466496175095, 0.04277826925258964, 0.03208208070587247, 0.04855239268151983, 0.02654480101961282, 0.007620606958235224, 0.04442265399941995, 0.05251189513552574, 0.019918159626784827, 0.015156073777395633, 0.04285741379604705, 0.010921142604802887, 0.06798199888679289, 0.03274115763844983, 0.017442134727213173, 0.08551134697852597, 0.024552047365315022, 0.03326630324966485, 0.060329002688729, 0.04573494729195391, 0.058360260145197955, 0.012834000949477477, 0.07095004567095349, 0.020290723506120906, 0.03651885210626549, 0.03753314102669397, 0.027179780656531937, 0.008577356929890811, 0.028786441318750865, 0.008739237053950709, 0.037025795468399604, 0.07658615452988494, 0.021242072557910316, 0.022941722887598222, 0.08266421185145456, 0.03921464273345567, 0.03190337537577556, 0.006326171175216235, 0.014502209115533099, 0.06515316560023254, 0.04767226107839135, 0.023006022562302893, 0.10356869052855239, 0.028916750959451162, 0.042071591446837114, 0.017152474967822913, 0.024403581440809275, 0.050219698779044614, 0.021080437581986192, 0.03126849724550641, 0.06698976180726482, 0.052778256245918816, 0.06217974470928312, 0.053437750696414904, 0.005573396422644897, 0.07854950764486868, 0.05145035008148802, 0.054855944153161786, 0.020737203378831188, 0.018194130464126507, 0.07235676696103427, 0.04372883114903685, 0.03246858355499083, 0.023661529525153102, 0.04392445553094149, 0.05205026587411281, 0.05823825681281667, 0.08636125258260197, 0.0037337847020206677, 0.05304154151329591, 0.020328005174956015, 0.055800576529075066, 0.011551707660058334, 0.030318931263360768, 0.053872256614868684, 0.03440568666724909, 0.020862508550166123, 0.01380035191804411, 0.03172752563841641, 0.05383747239266673, 0.06494171001137265, 0.025901817679104787, 0.03700731742766596, 0.06059394270602254, 0.032408326909306555, 0.05450191960159329, 0.04765003303726835, 0.03547886859685664, 0.02877945651210124, 0.01469203133902122, 0.023492486479001182, 0.06301610970929747, 0.025801460161024047, 0.02956041994865143, 0.021102317053103642, 0.09278984109480536, 0.048421020093824596, 0.02118013051879262, 0.021876443154929627, 0.02185208730459694, 0.02667677690154843, 0.0696659367531538, 0.024216945185476256, 0.04613486051018681, 0.05179427759421449, 0.03571358644553731, 0.06022978664165544, 0.01404415748472656, 0.024146698753259355, 0.0905089138916904, 0.0053231509293489646, 0.03754962723882448, 0.045960812994669524, 0.013507726440776982, 0.03162970578658485, 0.05639796806198936, 0.047106060815314134, 0.010356034017017773, 0.03375173486288517, 0.023487137270069892, 0.01946264949266709, 0.05851294529894668, 0.008924494351020024, 0.04848821749610286, 0.03774067424538155, 0.06332567817861996, 0.014360881215261837, 0.05946008661281198, 0.0327524995701688, 0.07658173420256184, 0.05132044072172815, 0.03512101360566674, 0.04415396015129743, 0.030397514647413647, 0.005469458401128049, 0.03841273636827546, 0.04496307923428474, 0.06662318873549662, 0.09090858196178753, 0.109075001110473, 0.0849597406904063, 0.043564827046206886, 0.04360464063563174, 0.053264687603880326, 0.04851637888819941, 0.027048348697022568, 0.0486974437691031, 0.02585497906341428, 0.09969523507020167, 0.05460962390286788, 0.014145295454880163, 0.06096965520672741, 0.015982453778926885, 0.007686028951748966, 0.00902340683575359, 0.024358520149103096, 0.04301589440494295, 0.043452464930352666, 0.01627484081132758, 0.02668568075844838, 0.0323034035071971, 0.017594628358980822, 0.03582071618086869, 0.013502999678284172, 0.037402323852743835, 0.0429372976143514, 0.03438315219095638, 0.039807885900259986, 0.05364557502851371, 0.013256375865650274, 0.02353653844986712, 0.03396288401657536, 0.009272399775293327, 0.07497877949067662, 0.02764599112373206, 0.11407193217066028, 0.06508345159912302, 0.11070732763337512, 0.06863462152860819, 0.0335530269770853, 0.038863943003478556, 0.03336978257603703, 0.012444130186321995, 0.03488893109944559, 0.03420283807621848, 0.019295374194400448, 0.05398380284708354, 0.03479671709599995, 0.03447791343675025, 0.013762283093866803, 0.03932378728002791, 0.0456754720559524, 0.053960153712861, 0.016946385824872602, 0.04402293613360774, 0.07362664962608008, 0.03857796238134465, 0.07425675694380077, 0.0502102644062571, 0.058303106155607014, 0.07475872073442706, 0.07593049051901025, 0.028012412893135222, 0.03356080659995637, 0.05355580484554653, 0.006476528858090001, 0.046719021704648776, 0.1574362778375226, 0.07630775051732218, 0.013214375095201597, 0.10569160443640525, 0.033107466409884156, 0.03478036877969581, 0.017880633878972263, 0.022701860758506005, 0.04042205858915564, 0.03668358399262352, 0.09144484350878386, 0.017365692558908657, 0.028263379466689886, 0.08895694233116605, 0.028359247709534345, 0.04992776182329944, 0.04754967934962723, 0.05375414117870312, 0.03962477173415884, 0.04438632994049019, 0.10851661494422345, 0.08146717648712859, 0.07508697408822275, 0.060542312210365656, 0.028181321873900392, 0.02543999689571079, 0.05598697721237137, 0.04268627741464204, 0.026865466272518523, 0.08011378257745698, 0.014301059324474586, 0.021907735931416674, 0.03441525127498373, 0.023608883962996548, 0.04791949680375476, 0.04045540639649957, 0.019202915042819037, 0.07413413691064043, 0.03848137401585137, 0.033118134184229764, 0.0280974026874549, 0.0805007795532865, 0.05394823721519882, 0.08822037177460809, 0.05058229968492543, 0.04209159017210046, 0.030622108644174955, 0.027971756606993657, 0.04826517482738822, 0.036771370007866816, 0.057769361207441944, 0.05678818643754048, 0.05503961756344765, 0.036114350021366155, 0.04927205184714929, 0.013569830315968683, 0.0390418860760908, 0.0407525067848544, 0.03228747270881169, 0.012630584495773, 0.008066090916643941, 0.029145108363140496, 0.015310236523228308, 0.00215999519681528, 0.02741415376564668, 0.02909463082980966, 0.026178337115373825, 0.03633858395680305, 0.006170307714191656, 0.039332478547528874, 0.020841588604173834, 0.03546015306886646, 0.041491582448924744, 0.01864530837103244, 0.036018336221816084, 0.020708950056183725, 0.05969183587078607, 0.042638856572129076, 0.09677717552310038, 0.07217882771886165, 0.05686813154287877, 0.03489688692253924, 0.019298790946542736, 0.03772861602145337, 0.02149505777314546, 0.04531554479692732, 0.019316259666436145, 0.03722442291496742, 0.04112761790653871, 0.03018688068785254, 0.04838360052916312, 0.07567634085013021, 0.04268488313461985, 0.033123607882448745, 0.042534821832011786, 0.07091567896667027, 0.01600689006849162, 0.04002446661733332, 0.04751800927483747, 0.025681167119933714, 0.07334477523522032, 0.06525138573300454, 0.06870464962576667, 0.02505241003217957, 0.006693601786654684, 0.07169103655483454, 0.04423141164044219, 0.04444022422596332, 0.023175048371476513, 0.01575030902806189, 0.018665799307787133, 0.025558910978537415, 0.044319956082730524, 0.039257152952373996, 0.03142461064271629, 0.03371567893472891, 0.061537226767189084, 0.06111421599803914, 0.05161257302989403, 0.0408908354509021, 0.020648390805769353, 0.024266463193681934, 0.032573859357545455, 0.025845598316781467, 0.02504539266679316, 0.037277386403612556, 0.04499829629616392, 0.03305115511700992, 0.05434947576554072, 0.014594379068923094, 0.005677341147431083, 0.08160529447899711, 0.04273307772593633, 0.06572431479130061, 0.05978480830127674, 0.00924360731826915, 0.0821514998472506, 0.0625682202348065, 0.03183949704942925, 0.03719253833555887, 0.05271848606606645, 0.014353612956080227, 0.10646525364849838, 0.07932395358840305, 0.22264565130875957, 0.17662431353763228, 0.18633099993871105, 0.16525038998694191, 0.11784138353241068, 0.12163554122971913, 0.1787649930244492, 0.11605192471535937, 0.11630162341339935, 0.10983976370264446, 0.0797844950049635, 0.28335398243319604, 0.11972869476003033, 0.15860895926673568, 0.11664766532879685, 0.0990524413364549, 0.1496302402548252, 0.18651968739446134, 0.13726820117763935, 0.13883282851067283, 0.12525785008385298, 0.1678949408233166, 0.1359149221811564, 0.13716183753023226, 0.19668285494610188, 0.23033228642757864, 0.26349891397741537, 0.09034904666365155, 0.13535644408435593, 0.08510872946992036, 0.04905951224387654, 0.15080762546389334, 0.2818150650109014, 0.24656434122833515, 0.16408483317542463, 0.1339752182003952, 0.06687243544166127, 0.20355303952049827, 0.1994341677956043, 0.14055591346996446, 0.12514299818224486, 0.13214713323020166, 0.153592738112615, 0.23042001881666724, 0.09554663913384562, 0.15245647650332222, 0.08845965167687786, 0.11693137066979563, 0.234656760829591, 0.20103074099508025, 0.06722131954325784, 0.19731843213160194, 0.16028218722391516, 0.18902816569372533, 0.15047505137420472, 0.110647312305387, 0.17891013604258338, 0.10479587911357803, 0.25934858668235045, 0.08434014409900674, 0.10315765371365894, 0.32400512046390967, 0.13563165351027442, 0.10549684956429467, 0.10019804155754466, 0.14859652717507657, 0.1594602821334716, 0.12202461430382346, 0.1927165726139661, 0.1975739837413834, 0.1881085997146945, 0.11765757605673806, 0.15265086365322914, 0.13734430435203737, 0.16544241758604206, 0.24278734390053058, 0.21906978270459562, 0.2037582591536545, 0.08548125504486023, 0.20015183896307023, 0.12246445602466985, 0.2462521144339154, 0.11954045163527613, 0.17453709166617165, 0.11697409539333276, 0.11686590845666586, 0.23514819091125844, 0.11109984044225947, 0.0983790423901331, 0.11894127128705864, 0.1727024183398293, 0.06447366859403349, 0.1136260460160913, 0.259458719482345, 0.12158247431920421, 0.20982313210204726, 0.18106845087341725, 0.14766586824290215, 0.13453286892223743, 0.08164940582167718, 0.23009369600444074, 0.06858271141085895, 0.16469565039921194, 0.13812157716001236, 0.11984998180020241, 0.17343121310395582, 0.16228020581747257, 0.10759815213180358, 0.15162438244348572, 0.10383408636816087, 0.1561311244844429, 0.18142276653839698, 0.13722903876295015, 0.13413860943288575, 0.11293769303348758, 0.21216601283559877, 0.07821070526035563, 0.17715118284667694, 0.09478045927901423, 0.12810182126779712, 0.07357259446214284, 0.13135936501766407, 0.09869953527325585, 0.11112208763558058, 0.1556107209574792, 0.18090627005984708, 0.19428147573865232, 0.16674841363583842, 0.15145834054677718, 0.08306938043284802, 0.162789209956123, 0.12355250772088767, 0.11122542523568678, 0.27080337847432784, 0.20660942390320763, 0.10238993402209975, 0.10225485739929062, 0.16415606403062422, 0.116420719442108, 0.12198195852819951, 0.15024179292301978, 0.09854179010876725, 0.13521704672565385, 0.2572814669580229, 0.18720075488090518, 0.16829914413392547, 0.10548217131966546, 0.15249240602697098, 0.15332235504061947, 0.14221702191618182, 0.19759001030075937, 0.11096487107175974, 0.14616281905722234, 0.07342048004389772, 0.12566569231210217, 0.15741088968371192, 0.11496859212075511, 0.08056145371688951, 0.08569598949003605, 0.15542669131630854, 0.2038589843939389, 0.07952584073908868, 0.10519565443598455, 0.18107661737069009, 0.09013834950183669, 0.1627792048478319, 0.1806275059859599, 0.09712759946142474, 0.20763219724739754, 0.19674208886440725, 0.158496298376591, 0.14926864675456478, 0.16804892449609696, 0.13713169963129107]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03589683084658558, 0.02518977917310211, 0.07187596251887661, 0.043642366635462934, 0.014299360524502494, 0.04225980009763472, 0.008425933905997345, 0.05962089995943731, 0.02736194678882678, 0.014233179146333808, 0.03137983088832229, 0.040460611963945056, 0.03617958240811864, 0.05777184333231661, 0.10381841987010934, 0.03795611732188733, 0.009262117917739577, 0.011668831969971859, 0.02524519222788513, 0.039291121290936586, 0.01235454961011607, 0.012602859773793289, 0.05076956987801579, 0.004506294358326423, 0.06755828331675261, 0.031211672673722914, 0.02185609777488055, 0.0036147655215069295, 0.06550554306276384, 0.039489607011238416, 0.038149328526830485, 0.013336171583843329, 0.04664184983759638, 0.02722639327628478, 0.0068510917481035, 0.011772007734004048, 0.011694481551286676, 0.012734353977946505, 0.026904703380780357, 0.052280256960300676, 0.017736902377838572, 0.03626992715702903, 0.022144895685355992, 0.03453503295238461, 0.04687577478527542, 0.02753222706697641, 0.05939916347063357, 0.022691916937248844, 0.012525172712611816, 0.02970215387552256, 0.002217129555403165, 0.01686848617429214, 0.028731516645019575, 0.020392161208174883, 0.030795188973687833, 0.039295032169790044, 0.05791339722852554, 0.01393092490146838, 0.02218878294731821, 0.055960585483379906, 0.053777039546759865, 0.037209369287255316, 0.037606765906656944, 0.009474126047514861, 0.024643472298198653, 0.07829346573881565, 0.02643225695787659, 0.019468571352321776, 0.04602537505448826, 0.03436507251594336, 0.04377399969305243, 0.028232406531911225, 0.03472684221642633, 0.04480767063796521, 0.005801633167486157, 0.021909356207376527, 0.04519940969804603, 0.03386251883761537, 0.024611679649341012, 0.003163145677629678, 0.016100774143612193, 0.03984681848857192, 0.05011713875818157, 0.01960660315929882, 0.04922832354843136, 0.028988002882068677, 0.047918680920115406, 0.025920983283750476, 0.04350000451649389, 0.0698015956027854, 0.037210614180132266, 0.02755661547604588, 0.06131660110587555, 0.04941542137173876, 0.11427513699257567, 0.04445241268483862, 0.015761101291695192, 0.018694703805170233, 0.023723224500915217, 0.037403358071441614, 0.05279804429700298, 0.01826499168190264, 0.02925619877304041, 0.004286995465536752, 0.089589960782999, 0.042386082031073115, 0.02500924863852561, 0.028545721171183452, 0.058624794135891625, 0.010512543864728463, 0.03943536798619936, 0.052968242220700755, 0.01858010854301674, 0.05265609203507343, 0.021536727210566885, 0.009417567691285043, 0.04327967762947083, 0.004922266215867093, 0.04431724030103895, 0.029995280182770187, 0.029236226860854416, 0.043135044059806296, 0.054839450280152024, 0.07674395332052823, 0.038072715903962814, 0.022614543972116326, 0.018761571789641055, 0.03822871821842367, 0.020098063884483233, 0.015102149806015435, 0.031332842885486545, 0.07268980836435672, 0.014918103885476389, 0.027237005509255875, 0.07138602630866152, 0.024090077194775787, 0.03744388412263605, 0.046568156009720224, 0.034691452784764196, 0.0452435210407261, 0.017167126399374778, 0.052578996776813464, 0.013439479498042455, 0.05043938981309053, 0.03881844504165553, 0.04143926247413601, 0.050256463338530837, 0.024852711977737568, 0.06854795400173434, 0.0522949198831714, 0.025350456539120887, 0.057879494007436506, 0.04175422420244544, 0.028474817818571484, 0.03538314591071779, 0.022595144710653735, 0.04845483521480234, 0.014196275733411314, 0.04934389940312794, 0.019410111182819934, 0.027194391868467775, 0.057136771764846585, 0.039242049528946804, 0.07147767340704318, 0.04906029748399893, 0.04715586036083199, 0.011526536883696193, 0.035371133652065075, 0.07870257967301915, 0.02184790446453037, 0.04990494006403512, 0.04774986961556058, 0.07554566157200644, 0.04332037605044823, 0.033062508540047754, 0.05351548946853127, 0.04029634356078121, 0.028586377457325018, 0.01971205324685622, 0.0536904409677992, 0.01487685100836379, 0.04089569244834204, 0.007603234478137306, 0.0485958413581454, 0.07445567167334019, 0.0750901839966255, 0.03488210908647987, 0.023162764151610678, 0.0627407125918375, 0.08277948510142104, 0.034607926218379895, 0.03845429280772805, 0.03589347921191685, 0.062343400242107536, 0.01941184445674862, 0.004127422702543799, 0.03256725951007778, 0.05897653957588538, 0.08897144437557267, 0.010316610174824395, 0.024201675137925534, 0.019707272858208707, 0.045510177094970024, 0.051026657494085456, 0.10274526092313951, 0.016229511388847907, 0.00984955509568775, 0.014155868425845139, 0.08572189092275598, 0.03524936780694031, 0.030201775352320367, 0.05141267770781152, 0.004536836847452628, 0.02509502750340729, 0.04905827501187882, 0.025643634557303403, 0.08468552717878934, 0.03416133526292059, 0.06992631471685826, 0.05002960172151366, 0.03133365302346647, 0.01665239766871016, 0.07378058733358499, 0.06416896478303018, 0.047077328687714, 0.061097905986131205, 0.021388983323929772, 0.012317578206890294, 0.05220504627833444, 0.03033221331274798, 0.03749243877527695, 0.02264626575784097, 0.042943039443343885, 0.011774899715918207, 0.04944593465376285, 0.01653983445477582, 0.03523394262658493, 0.006862516034274332, 0.04712002659817377, 0.006872820395660857, 0.008382828053717893, 0.08483109920616112, 0.01829028790516238, 0.009148300234829227, 0.025033391899459308, 0.04950405008369877, 0.04814813957519589, 0.019507293266454534, 0.04260556239093985, 0.02952999668195844, 0.025295955128967765, 0.016426300224397453, 0.04070452286771709, 0.03474217163579118, 0.10151615711830317, 0.006282033498263768, 0.06774703972041607, 0.019616173512692896, 0.008766356566470236, 0.01579885889265326, 0.04219883099018086, 0.10164197173810775, 0.010218059666635049, 0.051251446843267455, 0.031183375301019802, 0.03205400166822778, 0.033512562212924805, 0.04374052165076137, 0.07348982632280358, 0.02898443099712172, 0.08886022373072563, 0.061594304147987604, 0.09267400860065415, 0.027840751741502075, 0.024989692329038537, 0.047630022820686145, 0.023350459523499015, 0.021756228637851534, 0.0035315504177443444, 0.008547297554961857, 0.03412061385930546, 0.061320649880555377, 0.00944885855255228, 0.017159185898039612, 0.009779738630318354, 0.02204225139482127, 0.037690847886786345, 0.03274938925319622, 0.03668219737348057, 0.05931569436084359, 0.041082058657681754, 0.034502700211540345, 0.054025252034226735, 0.024919786805947943, 0.0822504707461884, 0.033099460791075425, 0.050769654147687464, 0.028485244275220943, 0.03949602299760427, 0.024669191785036557, 0.014095421215789694, 0.04044309153311676, 0.03421946218417537, 0.04039609586940177, 0.025878570741042498, 0.019544523224354755, 0.05319527620750089, 0.04319682905089952, 0.014071813258793087, 0.015239054506133883, 0.06109207988746705, 0.12190342685508153, 0.02355374669986627, 0.04634525506727157, 0.050999534151126305, 0.03599774760885104, 0.014242963046736777, 0.027770191213236223, 0.0805868112271832, 0.014484214667801656, 0.027092597935529008, 0.08659254218782149, 0.07237572763716021, 0.002789873406366115, 0.03177780398888694, 0.1024774442456903, 0.019101877621705496, 0.028611449599866907, 0.024865957637948376, 0.04332885281333039, 0.03633496419136082, 0.059459879769072424, 0.025651751258861155, 0.039824467873381036, 0.06279446898148426, 0.023788633087890285, 0.026669960634242144, 0.020896729697743734, 0.026019337481909224, 0.05756589974607191, 0.021693018723219153, 0.03937049566077129, 0.020569742304242907, 0.07843310058477425, 0.00897052570156032, 0.020251047812522422, 0.05949188692254886, 0.03618866438046098, 0.06432756796599397, 0.05644691341947164, 0.0007025374596255021, 0.002897816152507139, 0.11276170731552186, 0.11247672260768952, 0.10456769216445186, 0.14355957568172487, 0.059517328702514215, 0.14972629235877147, 0.14046897781231713, 0.1913908881045157, 0.16328998631046665, 0.1537595001319724, 0.09713264798084575, 0.1406058164373521, 0.11424322943052939, 0.177024946878514, 0.22107795962402899, 0.19441629189156717, 0.15896915848697388, 0.12897185200164396, 0.13265065217931427, 0.09558901911781681, 0.08747099222795618, 0.12831428043183782, 0.17540745947870517, 0.07738595032283375, 0.14212391158986476, 0.08805487380032578, 0.07983486528598494, 0.15051790633268897, 0.15333217628780874, 0.11275524153344094, 0.08836370682524097, 0.10816268232320586, 0.1280913488458722, 0.1564382797768039, 0.14064294105816272, 0.21106707502997693, 0.06391274667675458, 0.09938611093187526, 0.10127207384474816, 0.1437618228937349, 0.14995162946081933, 0.12851733203616836, 0.10618475055502308, 0.12174695339654723, 0.16132495546292874, 0.09784320985237438, 0.17501356771155713, 0.17746377736330035, 0.08755349223652194, 0.11542163353653685, 0.08560006762103689, 0.12451804663625457, 0.14768958632503787, 0.22346256150593682, 0.11735988961112116, 0.12314018387828143, 0.15052778886691218, 0.09081945529267674, 0.13219539676943134, 0.14124828841417067, 0.164578469590314, 0.1267062772005316, 0.10460009768364892, 0.07440222171886314, 0.12835790147824636, 0.13364854298772352, 0.10048089654094751, 0.12362286523585359, 0.17664507452038028, 0.12253808473507244, 0.12895518192841163, 0.14656568937484296, 0.13493437560335284, 0.12164707085297954, 0.1646265645902003, 0.1334461578798871, 0.12467895574387043, 0.1683330511854541, 0.25063439783069397, 0.04527102359720776, 0.15233410161829766, 0.12200108008278955, 0.14026024949646768, 0.09436769876629116, 0.19163890140912226, 0.1171431633373422, 0.12000594964070667, 0.14388637346846445, 0.11492736126867034, 0.13926805838221504, 0.0919952470388624, 0.1454533603523047, 0.21192074212576115, 0.09144910295764286, 0.19535891711711886, 0.1771473830505725, 0.17082188699033954, 0.14574418265012004, 0.11152035376477627, 0.13238180128316726, 0.15056126690920324, 0.15664052698881398, 0.10224375678526779, 0.06238761500665738, 0.1465156025463535, 0.15947011870241937, 0.11479513449293953, 0.12737573079404332, 0.16825071205535244, 0.14275245608821993, 0.08719087217844303, 0.12875881827166005, 0.06861811999471919, 0.16088344367040744, 0.13007786845968616, 0.11570402120630588, 0.16190871446123048, 0.18308183719073573, 0.18722255774323018, 0.1398779563004932, 0.18469511110696102, 0.10046254107428175, 0.1262175054439614, 0.11842160320450222, 0.12361951743162448, 0.18696525945298134, 0.20914053243975486, 0.1688577448047938, 0.12137468063062239, 0.11827524210656844, 0.09994196900797468, 0.15089362649427307, 0.09484651137984569, 0.20343526116301938, 0.21758383260138575, 0.2434299844166925, 0.07674262798841923, 0.10090090424543428, 0.14231336513353934, 0.17602932369036062, 0.15639704892471915, 0.15174107295611214, 0.18442049922962345, 0.17249013537601118, 0.12210962708078085, 0.15077043955604877, 0.23254030504293982, 0.1250916396478011, 0.19069013215841787, 0.18939597982793085, 0.12497416006461268, 0.2048567526282803, 0.19853272745686196, 0.1304099062878278, 0.12186398098786032, 0.17825646386031183, 0.09750655251404933, 0.18521212852529942, 0.174959926235099, 0.14635904481814754, 0.14134297688161174, 0.13262475840747356, 0.16575439923232602, 0.1272014764347865, 0.1561034533886179, 0.15387602210525544, 0.16507342367643313, 0.1341368321089014, 0.15502921425767485, 0.11648111781405827, 0.24051403927226223, 0.19342017840714226, 0.1797549931272384, 0.15430593532660317, 0.10902162776478838, 0.21287836735287022], [0.035571898483941634, 0.07585454822307633, 0.04061400191858411, 0.036975022991217917, 0.02169691236509431, 0.05602267690964284, 0.016863979662077564, 0.016910739753755833, 0.012868206775296601, 0.03898333780647766, 0.03529830550354335, 0.09704405757328195, 0.016637165925555652, 0.038414908227540796, 0.018172896422085263, 0.07105077857211714, 0.023841069891087474, 0.028292473570834246, 0.060466511640697725, 0.021863113225047148, 0.044232193050124956, 0.06399271859517021, 0.02228867889742457, 0.031590635302446546, 0.04379703595693554, 0.025355828730689905, 0.07621241853602471, 0.05461446940898896, 0.04369534161542693, 0.052304001855513746, 0.06690473370854894, 0.033797876338564584, 0.049192447650937304, 0.03526990279375065, 0.01925706405252699, 0.041308050764904874, 0.10969747819246785, 0.027811439302299294, 0.03679745530168857, 0.10845617826787696, 0.018946865475886775, 0.06953816094826307, 0.09867195610798175, 0.04797270544053567, 0.04283752232309311, 0.07770107292960729, 0.011440990718021508, 0.03186760673059091, 0.0033094354336255143, 0.01380206125172516, 0.033895384009567, 0.03448957712539742, 0.03599228540195092, 0.06461076002808348, 0.034931594535948775, 0.07255730579697317, 0.030075506825420647, 0.0231869476321604, 0.06854151886317038, 0.038315979463438836, 0.02136117050183877, 0.06007189975090085, 0.09577750739070678, 0.055151738361605716, 0.049168886616826064, 0.05046984180808068, 0.024539230714341807, 0.0318464148233855, 0.042602988335514264, 0.03363988602594022, 0.055198546333779255, 0.07595330461739533, 0.0735775433901337, 0.020507403814624396, 0.03061215141637912, 0.03085090654842075, 0.02138946021366264, 0.02679273005454771, 0.056205021157380075, 0.03618314088652692, 0.08148422960432307, 0.01971161849195919, 0.008772478566595144, 0.09016700119020478, 0.05873472775302588, 0.025838806947332718, 0.02889366298463316, 0.020410206409231312, 0.03191802489210761, 0.05042886759545054, 0.011772791058906626, 0.04401986029059176, 0.0473288391836949, 0.0502821043013565, 0.047265793977966236, 0.0717951019384688, 0.02534970194251547, 0.054875483225670554, 0.08461718447506429, 0.01927863517325492, 0.07177697629818032, 0.04484984377819685, 0.043670144983597343, 0.021199755776192875, 0.019193578346241868, 0.035145137714402336, 0.08936613287416198, 0.0068087864577049215, 0.010764904718305315, 0.017884433675076694, 0.04006631417019714, 0.135895632087223, 0.03890017896229702, 0.05090876422341793, 0.06712584200525476, 0.06255174934443447, 0.06405400562911265, 0.1010406310219438, 0.026040560032631603, 0.01885942994586883, 0.05378899051837864, 0.014970302243807144, 0.08391059859986268, 0.0110011279297572, 0.029474342309479273, 0.04083000040883499, 0.03857238909169551, 0.0596536502182003, 0.07630674694214137, 0.05824410206367893, 0.028574148778833693, 0.08463478151468501, 0.0386334692818984, 0.008825479402026583, 0.09395280086825933, 0.1053178454599073, 0.02110720852450017, 0.057327286340296275, 0.036358034929200526, 0.060358715408872214, 0.04057765870745625, 0.08807296113621804, 0.046300569158648296, 0.03969178144489566, 0.024294513503029466, 0.0428822273839145, 0.04195191319130602, 0.05050784359956461, 0.04846578261124031, 0.12731685693706238, 0.05947658048582174, 0.05306000806271069, 0.02027475631855909, 0.02704989044897018, 0.029265931920118393, 0.030385441101726987, 0.023742685049411752, 0.1121522384064813, 0.023967958949205857, 0.020066479994584958, 0.03263691605459298, 0.08202481954809158, 0.04099915262251612, 0.03666789834237388, 0.04073456500566775, 0.03080403345877365, 0.008444710721021459, 0.07131348544311139, 0.023126495634055427, 0.11055882148925336, 0.0567126808117234, 0.04069649426627063, 0.015108099436357379, 0.05263885888721674, 0.03641450327009924, 0.059952550913177194, 0.019939182994646892, 0.02733404012096505, 0.07052365645405746, 0.029190441616059794, 0.0423241553137139, 0.05031421870714234, 0.015558175134262251, 0.055335993998714035, 0.03878426985935338, 0.012429134015204206, 0.03227542597620237, 0.03719122449476873, 0.028092675924962087, 0.03484445969544111, 0.01227826448983603, 0.06105708499108592, 0.05990059099971287, 0.022328724228446523, 0.039075659062232704, 0.062052616248688394, 0.05764898198146013, 0.0472821269725119, 0.022283243503601804, 0.03134646392878025, 0.043383379121341055, 0.09877613640480465, 0.024433378430624163, 0.060284408710656635, 0.06170152964430952, 0.0634879432618618, 0.026508101577600165, 0.04679191497064406, 0.008239946910180151, 0.04373360004636549, 0.01581011463948075, 0.03151608154087538, 0.05750295413177341, 0.029569291246814594, 0.025117899058386687, 0.13134652538405311, 0.0434755586508301, 0.01731697128214423, 0.03345937272834201, 0.05548543860054305, 0.03339626623557941, 0.04207600794372059, 0.04215874543954288, 0.06222165354918088, 0.013659086262416697, 0.03359402800279279, 0.03720489916421714, 0.0814448067197396, 0.08689963619314856, 0.04917532558582964, 0.026618935348045443, 0.06799344424038165, 0.06115200711534389, 0.09237547945832053, 0.02053172519100049, 0.018759635502412435, 0.04059133720734427, 0.0652387069778577, 0.03071900152961814, 0.020430885037527453, 0.05813247539223202, 0.011104953910915122, 0.07493447662601549, 0.02243791857073384, 0.004239405604875497, 0.0321418815292418, 0.12921113190391373, 0.04336519602445826, 0.10547104006212567, 0.02622085116473177, 0.022267709155717207, 0.010977716282791188, 0.039947030449947046, 0.03339576444798901, 0.014267236542617603, 0.045008971731388764, 0.029951030944263744, 0.038425503223533594, 0.006642430464947417, 0.02726751879127997, 0.12105537518378227, 0.010537492475592563, 0.044019534703223936, 0.05978682694295722, 0.02799716774344204, 0.03732542777734418, 0.04573993069390136, 0.021329318481167, 0.08417609403090132, 0.01592396488112788, 0.05084190389982635, 0.05774729787522267, 0.03855215287917564, 0.03877176347398951, 0.07837759751466014, 0.01617262553003046, 0.025800962203873262, 0.0401752480425902, 0.04430827324188525, 0.033001244488743045, 0.01706339043354796, 0.026115724749322382, 0.029391016841175097, 0.02997483712651076, 0.01877896007030241, 0.05937003297731281, 0.03884076118288983, 0.07644483429049292, 0.012268219161928903, 0.03901007044459543, 0.10519293482385336, 0.06948422069751448, 0.08018518963287916, 0.023149759809096015, 0.03488075694129352, 0.012489839779934096, 0.09089960341131495, 0.01983972371465737, 0.03013790085641367, 0.13008180615161696, 0.0478834945017532, 0.03243649213184272, 0.03706172882248798, 0.005576676236570723, 0.08927061703176269, 0.05544685075179704, 0.04949078910172947, 0.022006285481996114, 0.0336988173395155, 0.029239097775350657, 0.015602307544360238, 0.09882864407113484, 0.017594693476454388, 0.03930011133272802, 0.05822871518771976, 0.04440730159741737, 0.11988007373386815, 0.08589534855057156, 0.051644116700176275, 0.05423537079965877, 0.013902597842858204, 0.042348118543985395, 0.018458279495638226, 0.04547431268879483, 0.05544290156854738, 0.06879500969643555, 0.02450052986762697, 0.062074817476734045, 0.04160025968186317, 0.05012349345751348, 0.05147247470074123, 0.07643181079578015, 0.02356114519399501, 0.05251459942589845, 0.10152733434111842, 0.03779356112523425, 0.012228834581741644, 0.03138928058286829, 0.0051874336655131515, 0.049223470381431045, 0.011405245055474583, 0.04960272220834609, 0.03596200960718336, 0.028611750289377187, 0.04178909269431907, 0.043143643396756345, 0.03183794572138258, 0.031461114732308254, 0.05501059432243628, 0.05156237894909517, 0.062400998562694564, 0.014815768902941097, 0.12791870327125635, 0.157703627201338, 0.21127515983196998, 0.1653473767181558, 0.1381628386556141, 0.13732144428837684, 0.09546909571414995, 0.2261954882452565, 0.10722008008029192, 0.12067596247840313, 0.1232589811326996, 0.24667401437557515, 0.0669768532257407, 0.12804505415260792, 0.09232273430473383, 0.20673437284365778, 0.09197562752712159, 0.18140263374774687, 0.17654028901409718, 0.1959755412873722, 0.23013641306709862, 0.1421511383546937, 0.12578760754437218, 0.12450824837170302, 0.13282682175838179, 0.16219135494001452, 0.13789826253008458, 0.1545958076753924, 0.20977047121813222, 0.1920780536508368, 0.19806256397597252, 0.1486602503686182, 0.1336329914028606, 0.1271146403685693, 0.13718635234380924, 0.10645727101232737, 0.20422339709776066, 0.10681074398059039, 0.13291119868236204, 0.22575127982324172, 0.08462181930700619, 0.18320628051315585, 0.22089042130016515, 0.1957678242075828, 0.17451305182710772, 0.11447897000658898, 0.11111656414164651, 0.10070789605379106, 0.17046335784177627, 0.10742114751689857, 0.11969123306053302, 0.15785520535803613, 0.13980053545486543, 0.19012978480708217, 0.15256857048840294, 0.18975947322624345, 0.18038490126209875, 0.22976815460189698, 0.1483934372663498, 0.13326117828969034, 0.15731646168616512, 0.15839114514810426, 0.21410298954334953, 0.1412585999576315, 0.19055324756810743, 0.2056896587413165, 0.2669102115736854, 0.11786714706930423, 0.07930455624216026, 0.09719297740488284, 0.1846169854604429, 0.19970461215463378, 0.213488694280386, 0.1180136307413059, 0.1611602925244839, 0.1427828391352969, 0.19515078634985034, 0.12618753608436356, 0.24245902925970095, 0.1594980809116556, 0.1952448159816765, 0.12413210686176054, 0.1535365379024898, 0.1481095863686454, 0.1646321263885306, 0.19194141420866215, 0.1657172746115154, 0.13730544837251787, 0.1356822766003109, 0.15971125253746588, 0.14739211438403976, 0.19509539819292485, 0.16192662559690016, 0.11817815578392438, 0.148078590451229, 0.12969770498814123, 0.12486733676445101, 0.12973006454206285, 0.13390954914352587, 0.1884476089429471, 0.21334840825969176, 0.13157006984035816, 0.207490103259202, 0.17978156105645243, 0.13936601038421356, 0.1575539182991751, 0.1991104037170449, 0.07721913467732168, 0.12148164182661042, 0.16037427099241366, 0.10817418130294931, 0.22823288375812195, 0.06513775957207527, 0.21581545652401066, 0.23003188803070979, 0.16207636514258, 0.13853181724346456, 0.117516033651848, 0.10297592999714036, 0.07891190553744955, 0.1405777929410819, 0.23265293528956754, 0.1399190645785101, 0.149945592687976, 0.14475674128099797, 0.1401565058697616, 0.1565512777456353, 0.06329394298635664, 0.24680591939437777, 0.15398019474119912, 0.1690287509512517, 0.13384896691047377, 0.12567686187403818, 0.09939007926732303, 0.2359751062167268, 0.16287806083358106, 0.1691949307437866, 0.14474872800131, 0.09890215020746955, 0.18738964151951576, 0.2675627959111045, 0.18110732217469525, 0.16142673790454865, 0.10308521243953898, 0.135220616695381, 0.1284427227332227, 0.13102412494199892, 0.09583040576187835, 0.2116988830628895, 0.3196395531056389, 0.1285588233581474, 0.19836974991185052, 0.1617825091365845, 0.110492930266886, 0.1663550274867204, 0.19733710935519588, 0.0772247577626859, 0.13586926334086927, 0.21227070641133094, 0.1165257424356476, 0.14322258892559236, 0.1458225840882909, 0.21000873988434193, 0.20145412714731312, 0.10709291714574061, 0.15465191595496672, 0.10924582339582906, 0.13478149509718343, 0.1307811831394511, 0.22271518144876729, 0.13541788433588323, 0.1662501806934034, 0.11373076257446121, 0.18385157169353578, 0.17896287353529086, 0.09746627161099065], [0.036543926164027185, 0.007192205802928056, 0.013388631369678244, 0.031689860925619165, 0.05625568638225237, 0.025160242653181477, 0.1375259131553673, 0.04107295370270168, 0.04194972984072182, 0.018334083236573685, 0.0063450222050080145, 0.03833950985403311, 0.023247600728345495, 0.03840830071919388, 0.04117273665483921, 0.045220251120026075, 0.05753787624980173, 0.016330330474903027, 0.0686043227512029, 0.01667230254820278, 0.019196705900192745, 0.043290241981946656, 0.07406034732177373, 0.04734742064629832, 0.07353375380438182, 0.05524217887150665, 0.032252749773643674, 0.08544818302916904, 0.05355133472250835, 0.04753973552837007, 0.04017755013680266, 0.029757565015085766, 0.022094431558563825, 0.044352698680614276, 0.03279198374178621, 0.03644616951444938, 0.0019688519504627274, 0.031173002470525044, 0.025935904761295647, 0.06847754286061372, 0.027757736538807233, 0.05056634973434191, 0.023715988800470388, 0.02904870002830942, 0.04969307844857535, 0.03218510804036933, 0.0605763609881603, 0.04063627975542219, 0.02546414015664449, 0.07970976312794993, 0.08536073409261243, 0.12685193349757504, 0.03496277431446699, 0.025559014400407195, 0.0625823583874491, 0.06779949376059156, 0.025079228855188818, 0.03324599425879217, 0.030114519852964632, 0.040945017019346844, 0.1278419336003642, 0.13055820558821002, 0.014904704050070819, 0.054111314351640405, 0.016830518856764804, 0.03119503898966697, 0.023649465555565494, 0.07182199162461105, 0.0237042504182506, 0.030386029074208874, 0.028580227686512857, 0.0397885421801719, 0.06885900868162995, 0.05914114888817553, 0.02600294320032962, 0.04400614731674714, 0.04049857162059315, 0.05694943645428266, 0.02924962190821046, 0.07818486511466965, 0.017345234180890748, 0.014912644551405984, 0.08107482455670834, 0.010126538015150977, 0.07069084748265243, 0.07286033187542232, 0.07099541339782939, 0.11683311989350666, 0.01394510135850719, 0.038961458335360216, 0.02769949087392419, 0.04282993039176349, 0.023982252234653122, 0.04852819962487106, 0.09694202232264704, 0.05454493926898126, 0.04703592929628588, 0.032058799293853586, 0.07597814884877975, 0.06629472087708212, 0.034288172610104084, 0.012230522848004776, 0.05270644316389676, 0.013673411148990835, 0.055880146251330455, 0.03421175917009673, 0.017324825598587914, 0.06545548687779135, 0.03336810101304324, 0.014013879774739186, 0.05110702777822172, 0.026650434968272046, 0.04907538941610725, 0.03876221418801335, 0.021892201583532077, 0.04563509156146357, 0.044363305167925936, 0.03359391308960415, 0.062439540446165114, 0.029867144316555034, 0.03927107276995817, 0.02520403223893335, 0.06265782570886998, 0.03845926471835664, 0.03178192171147995, 0.06096874739253714, 0.02462532750571207, 0.07902783762303092, 0.062389066743273894, 0.05153255514620293, 0.017686501453300158, 0.049176980335746086, 0.059156597051168644, 0.053710661858560584, 0.09313100303012518, 0.043213246315116846, 0.04529037497817509, 0.0288510206155479, 0.08205714079761699, 0.023351386489887393, 0.080494390379998, 0.031137308518913005, 0.12210621032863857, 0.007855587192029964, 0.001999681842261775, 0.06248178636474956, 0.050031972763639306, 0.04686684603051794, 0.01958695300404103, 0.0646066997620848, 0.022754971719076558, 0.004823805244203898, 0.06949182028972334, 0.01423039633194886, 0.018334186658443465, 0.060307659479158546, 0.07656148649872312, 0.06212693826866247, 0.016906325172092167, 0.02507429716417626, 0.005531853389730978, 0.04566594575261397, 0.052248705629139185, 0.043696483086434104, 0.027179119905697244, 0.017460202910907326, 0.046982375919939055, 0.027476643557630243, 0.063386716233987, 0.05470847605817741, 0.02918212764686154, 0.06402916139772823, 0.0267194920489865, 0.038396568082633524, 0.06562782601723749, 0.1026956797126801, 0.05106537174733897, 0.057516552192429383, 0.028254230461654165, 0.05581654180141707, 0.04690071477765038, 0.030948042666779894, 0.03505519899209181, 0.018070441738311804, 0.021018983923920223, 0.02307782415300608, 0.034664528624665354, 0.06438235091345926, 0.0325960950595477, 0.02661660644075563, 0.046506769384347627, 0.044219242333764994, 0.031950263787181146, 0.036695454525010246, 0.03414438173715626, 0.011910589209066765, 0.031013903245630286, 0.057034177270026944, 0.14685052086509046, 0.018378324814200885, 0.05225368520064701, 0.01185204476989325, 0.05673906487983562, 0.02714647115358422, 0.031054034761543718, 0.04884965777877839, 0.0543818314890227, 0.040879068340385155, 0.057579509298046755, 0.038622904929422566, 0.03994738668083184, 0.035728437059949485, 0.026439787602172266, 0.09430713185499753, 0.0376901239336979, 0.06436654651958136, 0.08008963548608365, 0.07264397332384702, 0.04789568296062851, 0.04997585299274614, 0.04719777303116937, 0.004525325418780408, 0.0446804732294573, 0.08246734257667296, 0.028805980391259638, 0.022335687967678233, 0.02510789395009558, 0.07402905263006687, 0.033501086215819084, 0.030278447347002167, 0.050794096182911634, 0.04194266267962033, 0.05169155669488734, 0.027415007953682256, 0.03960343235502801, 0.03115720573752638, 0.045561290481278015, 0.16116473583444474, 0.01676804055610011, 0.04001724240820735, 0.010779402932272324, 0.029750114810022137, 0.018981318365061478, 0.07439943315881876, 0.03931112001619993, 0.043065146197594946, 0.022528776598553506, 0.04189024694384106, 0.03499811395041404, 0.04337129408433553, 0.023719551109318292, 0.021347495832390363, 0.017137888653744614, 0.07474133819942513, 0.026827824542359, 0.04234949367180948, 0.05963549010395523, 0.01149188002361165, 0.11762853366352859, 0.01372258441763059, 0.06314362504429395, 0.11208881398723011, 0.019162984624985727, 0.0350769252456244, 0.03517797990371624, 0.08435417882977955, 0.016670216873828924, 0.07864957404953819, 0.049256128709643125, 0.01700253240884312, 0.03404415062358303, 0.05048013802978301, 0.023834674972139543, 0.04917280515655876, 0.06700757335150434, 0.06233434508284254, 0.07094603137023027, 0.01845386491397456, 0.015492769420116901, 0.013402089619288042, 0.04417905336125724, 0.04431337921790058, 0.03539576337883069, 0.04534854786470533, 0.01943949065471609, 0.028360241708616098, 0.06518670492955754, 0.0634208454510137, 0.012766157160513105, 0.005963117319850192, 0.02447594802135662, 0.03365390160451493, 0.018813518296566703, 0.047056927766290405, 0.10303779925790527, 0.03502455164468096, 0.04059855758603062, 0.01802650468063451, 0.03645634316208382, 0.08120540424340195, 0.054173129986250596, 0.05213600260415866, 0.05991381750772557, 0.0030486964509867493, 0.11714412094724756, 0.04904646576652604, 0.012530054607909295, 0.02202711158221768, 0.01234190341370601, 0.05985115151551943, 0.06303603182576838, 0.03707263408409011, 0.019977596558390126, 0.015320422619791522, 0.010815666661778045, 0.05424413101507291, 0.07528785766372759, 0.0489708605492788, 0.06760834716260433, 0.018618221417249694, 0.12221318684638509, 0.04422979902536158, 0.01796161320300833, 0.05046893016345078, 0.02501840530444057, 0.015608390282479026, 0.018837506424695737, 0.037591953596640984, 0.12092222910254233, 0.02611476522419722, 0.013554724019711778, 0.05598591618059624, 0.01623186902443488, 0.05910046961939624, 0.12975942103132126, 0.05118125786764487, 0.010492821888727768, 0.026393923833365404, 0.0794214306158885, 0.03354635818170444, 0.05430934424962729, 0.03242320433679608, 0.20864750889520492, 0.02573241457162846, 0.04841146697740882, 0.05266014464019288, 0.019003190175299684, 0.03311679736080189, 0.05535642173321498, 0.06034943042322994, 0.07816146112858288, 0.022001980067861658, 0.10655618062423122, 0.08954195005278434, 0.12069316881318247, 0.1351863419216487, 0.15652706936722802, 0.07065746903179154, 0.17311529376574103, 0.11559969535277737, 0.16065024650625645, 0.13577903350514753, 0.1535743366806738, 0.1661905330876189, 0.09959257162746885, 0.1656277342549255, 0.1175113605155099, 0.12263845757491167, 0.14458699151873589, 0.10680207952616677, 0.11080534858328682, 0.08405262364014503, 0.10327441317419853, 0.13472816005589502, 0.2791887623888831, 0.09380348267093783, 0.207753622183396, 0.08937809150666, 0.21002173273553773, 0.12462087861833074, 0.1803043547777399, 0.16343454710177838, 0.1133814418027478, 0.16336153892259445, 0.11131181697090788, 0.162133883023935, 0.14893428001913334, 0.0902168122270415, 0.12354536778143338, 0.17293308741383015, 0.13552323674723027, 0.17533126437375623, 0.0937051859293734, 0.12528437970867082, 0.0907910104480482, 0.17573844010551132, 0.1580376262145658, 0.13092958969214272, 0.13251448771165264, 0.1618047716516641, 0.19342117432144382, 0.21082399533160273, 0.12085282919748176, 0.2513004346720634, 0.1963413789147331, 0.10682002896623266, 0.13281249591419775, 0.13612764947597059, 0.13236425786970124, 0.13143090230803336, 0.1552553021258885, 0.08785002955025242, 0.1996606233860216, 0.28931255302121567, 0.07964796281509823, 0.11893412368672511, 0.056007933547540065, 0.1740663153149428, 0.09388878656130645, 0.15653897437357134, 0.1495762310561634, 0.11203152593225242, 0.15697648718712792, 0.1360189415995152, 0.10897714103902541, 0.1098550011914584, 0.10457603486194726, 0.1474129213320632, 0.12164735430551153, 0.19618043916360026, 0.17428091186429226, 0.15910204409831957, 0.10293960976865023, 0.09546372543780074, 0.19224414151282082, 0.0917802291411546, 0.12137689462472355, 0.23378694460036295, 0.14149738956362973, 0.15128848353220573, 0.0861004609314184, 0.12776048313225472, 0.10638486038172439, 0.13545413561646016, 0.15916156913003615, 0.1607266254723072, 0.193415152870359, 0.182825488849513, 0.1862240540644815, 0.13006512075662613, 0.27775915039162485, 0.11747933804027497, 0.17135304639176016, 0.14314860015386535, 0.0923757399282148, 0.16177863273168766, 0.13578327763224804, 0.11313950357538079, 0.08658127303445533, 0.16632654433769567, 0.17357810280255734, 0.15316918342103883, 0.22589815420008477, 0.11727097744662916, 0.1661317588220681, 0.12903212779952636, 0.10260456121496617, 0.1465376352350558, 0.09928346281090092, 0.11002096647937452, 0.1782611829619254, 0.1574858743697405, 0.1132932421000254, 0.20062400959432128, 0.2165557885722768, 0.15644338192237964, 0.17925568766170935, 0.13398529991747873, 0.08644380621732244, 0.14471595475990928, 0.2375718479555461, 0.16290752457514887, 0.1754026178030237, 0.1334287983275229, 0.10522085872869338, 0.11563466726652077, 0.21912412898194408, 0.14680856989035684, 0.15776125233500235, 0.09918463746866873, 0.12503731635309037, 0.1487817672351676, 0.13841290507585774, 0.13731718483951785, 0.26942711684011644, 0.08616982253208276, 0.2007777174754489, 0.10897445973129043, 0.11830623802398482, 0.14362674627092578, 0.0827969978713701, 0.24922600646893828, 0.10343061084108007, 0.1085470669392136, 0.2533501182352343, 0.08030591742886652, 0.0994398290171258, 0.12476686433318163, 0.12968815953260468, 0.23435473832632267, 0.17061466020682167, 0.13464222031254924, 0.13364212317091803, 0.13746441161680606, 0.16358796386949478, 0.18434257276596563, 0.1326150597343522, 0.08106111924374297, 0.2702158196799217, 0.13879342094784783, 0.10424791174309869, 0.17854924734321334, 0.12161569189160101, 0.19327560229407204, 0.15532391296038706, 0.1385549530987778, 0.19124179207269223, 0.18033953353522286], [0.03313787243959885, 0.11561003753975516, 0.050974119184238297, 0.04328779050058896, 0.10923107620328666, 0.04186752094556728, 0.03850201625497111, 0.1062884328946952, 0.05303617889782595, 0.033920373797657034, 0.054611818744770946, 0.04379893202454813, 0.10746863730732473, 0.035691775922333045, 0.034392142232747815, 0.0469765498212749, 0.018278999599598108, 0.07608425968717183, 0.040272020269185305, 0.011686883874297624, 0.05010061807209446, 0.019908039605305083, 0.03773659099674514, 0.03341989621760384, 0.06772819395747877, 0.04147600788142412, 0.02189775189054349, 0.04504014767946736, 0.0321178091314411, 0.06106568049759634, 0.03517832081284254, 0.0016846778594152704, 0.09457818908436645, 0.019305804481489525, 0.02419720884532698, 0.034294948657794345, 0.048539878635276715, 0.057740180918406096, 0.037136740321593906, 0.029782416907349424, 0.03099359425475761, 0.040943664874160485, 0.011703146963320192, 0.043926462681303104, 0.07540125399827957, 0.06394853830457696, 0.05956388386567274, 0.04853381887979565, 0.021205729346782453, 0.030028185574337844, 0.06309204817479176, 0.015695006098417986, 0.024669559507240212, 0.03266444159371238, 0.06450551486904584, 0.024816217464244655, 0.05068194091079697, 0.0339041901902566, 0.04842222285186572, 0.01518980271348189, 0.020704443543969143, 0.011217432855177793, 0.025248371492770892, 0.025599312540444157, 0.030682828773053426, 0.06427164354752149, 0.0699379209489111, 0.04519472123994943, 0.035886251172351266, 0.0017574592047528697, 0.049687700511346904, 0.0059935185615153565, 0.054294141234769944, 0.031925501910248594, 0.08998648023172733, 0.0190542001397379, 0.029433800936526353, 0.10135007691719841, 0.02154733369787855, 0.010992295893600151, 0.031339423580756115, 0.009535233050795093, 0.0788141220747944, 0.10916687037435271, 0.06266750139935363, 0.011871346355145498, 0.04779713724048869, 0.04155660416149805, 0.0943592411556071, 0.03969766116971451, 0.01960179404235415, 0.007559074297352064, 0.05094998741462346, 0.025926441660210974, 0.020547284436742627, 0.020573503795951124, 0.07091538785325904, 0.04765608130143054, 0.034769988288321806, 0.06060484796762467, 0.06428246070901233, 0.019979322171439568, 0.038936981826179454, 0.05384119557997873, 0.06714941453068488, 0.022478565280776353, 0.08310364754570108, 0.023231020670444257, 0.027289603190917163, 0.005986488747200178, 0.07391672881860888, 0.0678036153136242, 0.020017940663702546, 0.030727949436573736, 0.04084234208529515, 0.0240684773457507, 0.040006057524512854, 0.04900513149257149, 0.03244216501292202, 0.09457522432409948, 0.04432223519430526, 0.11443764722395329, 0.03083019727660764, 0.02432679453293883, 0.022721585607336416, 0.07627497727592146, 0.08436655114975669, 0.04669366036391547, 0.03190834345596452, 0.07426436419688887, 0.06908877377188014, 0.031230091342642426, 0.055464103051851836, 0.015976755042380143, 0.08930342091668038, 0.03469246785126386, 0.012176362346977958, 0.028691900323235223, 0.029635316534568707, 0.07283257650992564, 0.019209459348912203, 0.04061395978374828, 0.07207718317306812, 0.01355794063138385, 0.024252916843960845, 0.028625972711691455, 0.017173952242780118, 0.03027184749953449, 0.030708557835990385, 0.016837848402980356, 0.04226695918928712, 0.055813381688729416, 0.015922073601564814, 0.04870638401517945, 0.009963830516132857, 0.06741703968615302, 0.05185279905075028, 0.09603070711056072, 0.04091294091795722, 0.040208331549600254, 0.04348849404543158, 0.005451658827012345, 0.0335707274385758, 0.007247521660305681, 0.026963437426715132, 0.05872556151101186, 0.042564086390719305, 0.003694264620031801, 0.041158989207038, 0.10052031942553098, 0.0350651849481848, 0.045055274085532275, 0.07140435879268954, 0.05640836004468222, 0.07008536223081813, 0.06583637047198511, 0.024376542367521795, 0.04904453905539648, 0.016536084454386465, 0.004761020029564539, 0.03316678076742157, 0.029288027811074452, 0.019133884775181933, 0.00955524518259711, 0.07422367726723034, 0.011051679199050752, 0.02696343934193494, 0.022244165358584256, 0.021460137570336945, 0.07169873573847356, 0.11044498848458452, 0.0377487909469393, 0.05176071528225176, 0.025287135541739485, 0.027277100635992906, 0.05150337102672747, 0.05146464145171547, 0.02600189940553279, 0.08962702411677569, 0.05395311719527649, 0.014764094357228568, 0.029741442694719282, 0.023039429741460952, 0.004350688494366384, 0.02115596044478157, 0.08054239344933341, 0.03154277204415731, 0.02585096284747124, 0.062446400763527046, 0.045698021854003595, 0.04783630348561753, 0.012371637201267145, 0.060556806593893044, 0.012267201222599515, 0.04727296073049788, 0.023168885194125678, 0.025369181643210115, 0.07921936726498027, 0.030477695324788653, 0.012176761670308489, 0.07569398385502639, 0.05071544576616538, 0.03287835632480922, 0.046490409576724616, 0.0409832026719326, 0.079856354052261, 0.024575979952069543, 0.04421639248668667, 0.04132087890719695, 0.03147633306892409, 0.05467864459440593, 0.05598674355555446, 0.02161445640658419, 0.0233408642722474, 0.08583008552030211, 0.050735513439341906, 0.04722643621085633, 0.040606000130215, 0.042559045532177535, 0.0544320332307008, 0.03470518491080692, 0.06001882134906708, 0.05874782019565183, 0.03134386497549713, 0.03273641555419853, 0.012469633253321294, 0.021736356317095702, 0.01872263728610931, 0.025504308061734326, 0.04210317342151557, 0.05731500595087006, 0.03457019638810908, 0.058823846761257424, 0.026932389798363852, 0.03934989172604777, 0.04385319403222492, 0.027592181107930602, 0.01188521541940469, 0.038246755758600856, 0.018901231533457196, 0.06571782602658195, 0.08043855789207643, 0.033259320358235034, 0.01759574110169084, 0.013149992108435161, 0.034131005841998324, 0.04040843754586193, 0.019386745501129378, 0.09558271421419998, 0.029262501761437427, 0.09957456856124824, 0.015171060372414369, 0.023661929806093537, 0.041764949433385365, 0.03379675018931589, 0.04122278517893246, 0.07912215070738908, 0.023437778225108504, 0.029511407558475772, 0.06809073740676527, 0.07824330996241301, 0.002438508137504781, 0.09011044857963439, 0.01849742658856896, 0.011438643616143496, 0.02317047099612894, 0.0187496246484619, 0.05723637085588229, 0.01129089206862714, 0.05140549180308177, 0.09300521905383757, 0.0395927109545277, 0.016734518463753404, 0.04657763251734357, 0.01630817904257246, 0.07019128920810838, 0.010124159312146086, 0.038387673801832625, 0.07959829733496712, 0.012321737106709231, 0.05828883010713805, 0.03272168368341462, 0.046832372073925314, 0.08983418961325962, 0.05302297920289059, 0.027581758481720765, 0.056065738711866646, 0.048130121187216816, 0.096214598855905, 0.07176142471331744, 0.05472735246463169, 0.05922394001015252, 0.02959328512060306, 0.03838662426137636, 0.036455343417342634, 0.019277313671585534, 0.009593524680953593, 0.06727681495249271, 0.11493530560044513, 0.059460274304353425, 0.013977450378719839, 0.05036416763980543, 0.07735786553952964, 0.05767072738719083, 0.009040637110780564, 0.040309623694948615, 0.04341663499813407, 0.02769722708410794, 0.018913917949483283, 0.019330704254248453, 0.060877594420866626, 0.04668181281416647, 0.04033512676194791, 0.08326484776672818, 0.03197321003573316, 0.0412307754759827, 0.0415171851073542, 0.05616175251141672, 0.01641364062144872, 0.01440590037213218, 0.010470716421672655, 0.07504893016190299, 0.02536584724551968, 0.03293813799598044, 0.043430053028127844, 0.038425192957924265, 0.027895458080174945, 0.030996993769921606, 0.04914487359083949, 0.04774217043192156, 0.025641263515177756, 0.05410756435125105, 0.09813399384579352, 0.21819221366557384, 0.1570185607359294, 0.14376893218967224, 0.1630168606437022, 0.12437579943047417, 0.12084148343532317, 0.16172111485033266, 0.1362720264061805, 0.15147235995579153, 0.15000799821028787, 0.1115159564200909, 0.16444097212966413, 0.13027060085967665, 0.21177219767724315, 0.14633885074046352, 0.09858230083820321, 0.17479877197934737, 0.12782977578500587, 0.10561153292655946, 0.15222206892025086, 0.207814296346999, 0.1885102136481193, 0.09051671266675958, 0.1511730800472921, 0.14885514313655515, 0.11068309627233014, 0.14821544439802248, 0.07733593244225749, 0.24019174608251742, 0.09895555419667114, 0.16448057887534942, 0.18546332875567098, 0.0844667784328903, 0.09389709095440565, 0.19864655280065155, 0.16890636074446863, 0.11891798221416051, 0.12907596335055369, 0.1294229398932188, 0.12214467560331668, 0.12203722411105711, 0.1493184884349185, 0.0753684347916034, 0.2295570973787577, 0.15745045046412176, 0.08254890029709186, 0.11612059683689188, 0.15684202343465822, 0.12877847608779708, 0.15770367316661343, 0.1775024648034765, 0.12963516157000296, 0.08843977169524278, 0.18420034088194373, 0.23676598474623697, 0.12916102975366578, 0.17441125406372934, 0.16286189637837872, 0.07732804939751664, 0.17929215344690508, 0.2073236783185313, 0.1097654608348685, 0.19502099573371873, 0.1192124434296162, 0.12618212750361812, 0.2474610931089809, 0.13065652531241218, 0.12830207665120402, 0.1374212502231521, 0.16034710551461867, 0.11499774176627399, 0.11749766286342375, 0.1108311887289728, 0.2638659620236966, 0.10814066495626204, 0.20133288607241648, 0.15251065424132734, 0.07925934173286923, 0.13841670487196217, 0.18989183789780065, 0.16659907245587918, 0.1859011326826388, 0.16373856143364984, 0.17007675923166737, 0.27650426772813647, 0.23341300176276317, 0.1181301603754682, 0.1622797614864765, 0.11685797944664957, 0.07508307470068817, 0.102289323695004, 0.18601745547306153, 0.19899601146819132, 0.25838236594873093, 0.13863042808107792, 0.13381017221798822, 0.16121702899615611, 0.16335246844157097, 0.2632558496007996, 0.1651560692417045, 0.10889238873196226, 0.16205664603940903, 0.2878509491922394, 0.24058314040303233, 0.10642579245951869, 0.1916188452272646, 0.09854090910765434, 0.11285634215680823, 0.08317436512199142, 0.2532795308938911, 0.14776512259437194, 0.1173122006378347, 0.14504754825705482, 0.1742582969487675, 0.11649437879602756, 0.11018656404508699, 0.2508905010237809, 0.10018877189366088, 0.18536594365873646, 0.26361882205932374, 0.15815180395880055, 0.19076447333059005, 0.1317915765027846, 0.17598021745441422, 0.13997587765897476, 0.24389506107376469, 0.1828310353260848, 0.19662283961811375, 0.19841985206209845, 0.15252609857388083, 0.17184375635077878, 0.12330814099480068, 0.15229340702775987, 0.10366862669827477, 0.12204979561389455, 0.13582391093575186, 0.13875625036176176, 0.12350641221048371, 0.13102869082602764, 0.12629271995636726, 0.1756904370361759, 0.22883643846838708, 0.16405282602194818, 0.14896660892953797, 0.14759040858236053, 0.16211732020301206, 0.13106604527321555, 0.12096604167093193, 0.21682094692462878, 0.1176399177300834, 0.12030924384992932, 0.09149005801807489, 0.1121255555640786, 0.17135025783171579, 0.1091592631212646, 0.1434317768941964, 0.3060288979641853, 0.11331020328666895, 0.1493729879298518, 0.08941209048873956, 0.165245502345985, 0.1212475406787088, 0.0983720786509014, 0.13111951821033033, 0.2087410329090011, 0.11845352608830699, 0.0841653687999614, 0.12700643811014392, 0.16457908246065342, 0.09203325266078596, 0.10938409460528244, 0.16630820419278838, 0.15683584876598852, 0.162196671590209, 0.23510548917035903], [0.06770781601869291, 0.05525588035403241, 0.0746240501382178, 0.02432580627951651, 0.017225563586238894, 0.05123343611616762, 0.044845737546922705, 0.0413316271207746, 0.01647889982127855, 0.04263427536634188, 0.02048766938969493, 0.07277762502311699, 0.13137215868599955, 0.018468537412944342, 0.025095148162255367, 0.01597202061900809, 0.043628144213148666, 0.08442445973595304, 0.00875758390212732, 0.059564554192606485, 0.06959773960613436, 0.023755995827096126, 0.03861632040371338, 0.06246316659774992, 0.053463066071872754, 0.03632628058473911, 0.04101452800715643, 0.09469055120022067, 0.06494395464899079, 0.052126464809501366, 0.07879951277807837, 0.028083674391851794, 0.025592103653076678, 0.08051708190431518, 0.04158461233600975, 0.09617384297833328, 0.053531646262854345, 0.07265974707420796, 0.04271554963422879, 0.060525879624389836, 0.08443059610022653, 0.017321598453206882, 0.0703111130203451, 0.03497748320261317, 0.036387694023189046, 0.06248579683503317, 0.006810160149114147, 0.03433597649657919, 0.05410597088836855, 0.024693896205374793, 0.039982201546550765, 0.011191160827424499, 0.04717613870818769, 0.00797065168303708, 0.03319029966669698, 0.05750427563344279, 0.039432652204507784, 0.032923620629815326, 0.014957693394183394, 0.05253160274737785, 0.036017462881582404, 0.02584588751497288, 0.02247940414705344, 0.011594486009750155, 0.05049188598810185, 0.0351129160563071, 0.03544694571305187, 0.06077395038559072, 0.09979466562189403, 0.11279214398875353, 0.07647273521269522, 0.04723352252415592, 0.03523619109464269, 0.028499487764953126, 0.02758501818583858, 0.03577251009823334, 0.035255350953628944, 0.028341064612651547, 0.0741530133170947, 0.07631663713724383, 0.053123528242952404, 0.08316107349650514, 0.06063539189316573, 0.0262558632980912, 0.05559636047109962, 0.039716637167598934, 0.09333370223401055, 0.05900126506364154, 0.05513089310918605, 0.04437223392268343, 0.0317977165292588, 0.025565968563539848, 0.014844298017241303, 0.027968140671991056, 0.03037058474165538, 0.033207655388621554, 0.05684758889518919, 0.04241717753991966, 0.05464926129207016, 0.01755118925845431, 0.02451364529289065, 0.024723564875462366, 0.023944830754771832, 0.016974062666357044, 0.017252437950622652, 0.06184057460256642, 0.005473243354278947, 0.019924219382265886, 0.053422677916504686, 0.05580114726457865, 0.0471545924853173, 0.03721429906304806, 0.055325249615576, 0.04200397652664012, 0.04411503905430437, 0.010884356020288843, 0.012746376770308182, 0.02133686061678154, 0.043869350826548, 0.022000951594823313, 0.01987637527617476, 0.03827731883634002, 0.02134693275776602, 0.051508810250989856, 0.01565306086934382, 0.03467472908537715, 0.027370643801987175, 0.03498010322331421, 0.047797413032141425, 0.017178200200320255, 0.02078467784749885, 0.014065894271968114, 0.012674912258291678, 0.026625983356948824, 0.08893773650690433, 0.08444951847195627, 0.025358780084418196, 0.024010105276360147, 0.01950856688762865, 0.017627112402190125, 0.05742979273500462, 0.06752152641814563, 0.042288087894238775, 0.016722780081533616, 0.025163917959998214, 0.06780780581457001, 0.1281585347568316, 0.08603803242646879, 0.016943445962463177, 0.04763060887794822, 0.032671830511742064, 0.10141701001914279, 0.04311365871540001, 0.018495666501562924, 0.05232742882423824, 0.07746695645994718, 0.04915052731972068, 0.05003658078250386, 0.0075772382420367535, 0.05051159359995396, 0.046260207816357576, 0.009156002291297961, 0.07413100361103013, 0.03535858513186536, 0.04678188304927561, 0.10241685435175897, 0.02992468518054774, 0.07053094961109661, 0.03052185263274418, 0.02440583373930666, 0.008249510560304889, 0.03933948825203604, 0.08501725857176128, 0.08930013439948521, 0.02064504874719968, 0.02000158468651916, 0.027210441410481453, 0.035485073909043305, 0.024487019907082283, 0.08571707222971224, 0.06620285927408165, 0.018528585299669255, 0.08514241435595098, 0.022979923861942465, 0.019755800697772254, 0.04290422559866021, 0.015602303713920618, 0.07851564655861548, 0.15798047605541446, 0.023687057490009936, 0.031014613792180058, 0.010218233951637823, 0.05377110236534669, 0.04315478614561501, 0.0432025172537373, 0.01792853544165771, 0.07109449154907657, 0.04020784125332871, 0.033745973881694584, 0.023385513791694276, 0.040583752936893897, 0.023930748143503745, 0.037576896138489246, 0.07113897827483955, 0.007269567755546662, 0.02405457859558444, 0.1173201832740057, 0.02079297649493862, 0.05121516491917353, 0.060687424584982864, 0.025416483742094813, 0.07200500236884241, 0.0508640515017173, 0.022287587222132473, 0.05324756936921228, 0.013677060600340128, 0.020672336799062548, 0.03470274109032846, 0.01584548013089525, 0.03958353705163445, 0.06517443220101057, 0.022195765838748025, 0.026740697362730582, 0.01860112041955994, 0.010465549158623383, 0.04995594236759409, 0.035425717416670055, 0.004649260250340787, 0.043830751486483126, 0.05232640609685933, 0.03819781423155819, 0.02409855204243814, 0.08633702122155698, 0.039378780901672385, 0.0411020573829451, 0.04048902999549624, 0.05502076797007073, 0.01699303483380185, 0.03234080775010009, 0.06538989442971445, 0.0069076323885500675, 0.03915155156245155, 0.04503539793433682, 0.019512157924773715, 0.07798775835263153, 0.10949093322720259, 0.10460979635677031, 0.02650761702698806, 0.04326969167337783, 0.04153658245359698, 0.056814627962247025, 0.021173624517095667, 0.027288210826114784, 0.0279529721310903, 0.1128403002756738, 0.029769025690433, 0.12560353193792606, 0.020795866561632965, 0.019475339739132794, 0.04415821960015644, 0.062232857585073485, 0.03559648607587142, 0.05496997634069093, 0.04303379787973339, 0.04811126010252103, 0.01994015592631073, 0.04510977741090521, 0.048347839544857704, 0.03030310005640551, 0.021281033874519413, 0.0681883906344733, 0.02163846368691133, 0.003419599834746952, 0.0359686745721246, 0.030698979821717067, 0.030639529483573093, 0.03461997678142882, 0.04153852831692465, 0.04496890916338852, 0.03301750087449628, 0.03807425574069062, 0.0429886101835197, 0.031831899372440194, 0.06069192152109839, 0.05379396625944684, 0.026014924815465367, 0.021876627016031457, 0.02830824349075556, 0.02771580854671136, 0.09744711941288364, 0.07733659127787237, 0.020287197586449406, 0.0744674158012194, 0.025019874278035377, 0.008524129140911805, 0.03311645262123596, 0.09397632742841398, 0.0206577236719069, 0.013612470769834135, 0.06708951411588539, 0.03386471367951843, 0.03088845826324917, 0.018408920450676835, 0.03906548541459826, 0.056321428217474497, 0.05004550953726134, 0.03272098654340352, 0.04421202195507865, 0.007161548879418162, 0.027369933255437403, 0.04611211919015454, 0.09353601073305454, 0.04259242781347806, 0.042779736310964635, 0.054951444673802585, 0.03433085136836575, 0.06312578668697708, 0.02264441182506421, 0.007625131665038006, 0.023867061339138497, 0.01822451734164309, 0.01225590908659562, 0.10482656859582472, 0.07843630283229774, 0.04162778522098257, 0.052662584630231705, 0.026982949686146555, 0.030476109522785393, 0.009203039132238877, 0.04401351708257872, 0.09002735868336693, 0.07932785297593764, 0.09451666456316749, 0.008887076701578355, 0.06007926185585319, 0.027070385216164495, 0.008789980802835237, 0.06875917976421696, 0.036420268081729455, 0.04023898272745071, 0.046226404186698704, 0.026334693745499658, 0.04103595931683818, 0.14540157280862331, 0.06247627819257398, 0.02318555335213821, 0.009261448548415737, 0.03264683689321241, 0.06551837503549553, 0.0724626173295321, 0.046162914649973956, 0.00911314158715428, 0.2031469363118372, 0.12612575109327032, 0.2367097538925948, 0.2652159928073806, 0.13001454363186515, 0.06422787311396773, 0.15563722759965928, 0.1865067558302995, 0.14528039302076065, 0.17269104959503298, 0.1248775716991194, 0.158091175760473, 0.26738147822118574, 0.1111150396266772, 0.13444908954683812, 0.12629060555369626, 0.1614168860138424, 0.1606465539624614, 0.15432907118191644, 0.15047151204799453, 0.11813605925248516, 0.12235095243780844, 0.15062259990842114, 0.10921238365793422, 0.18274967678852622, 0.10397090967143736, 0.13244941620336426, 0.17893445167330005, 0.19773639438133087, 0.13138694418293814, 0.21295148278436354, 0.09801921855297782, 0.09110248647630216, 0.18299594341266542, 0.12357503836674076, 0.19952513307573336, 0.10138352431597249, 0.11181011120037687, 0.1333566328450557, 0.1630139801531069, 0.20450436750486975, 0.1616550780712597, 0.14711701221043064, 0.16700303061835228, 0.21543503258257143, 0.1554070028566545, 0.12606712238442513, 0.13738319097507384, 0.11014491184464387, 0.14919801344794614, 0.14946683370057615, 0.1178766618813238, 0.15366393832429764, 0.12429914467277066, 0.1071345080591498, 0.26664695311938563, 0.1730846655705283, 0.12920031474242288, 0.14792894283610006, 0.16354475651056538, 0.13174760305593092, 0.11217466180002499, 0.22300744399188027, 0.16384227441683893, 0.11795851071515392, 0.27356469643212133, 0.1361755452929966, 0.21250284637414643, 0.2784604272775112, 0.3511995563824331, 0.1663579079773157, 0.1257711672975171, 0.125460380748395, 0.08224073376867079, 0.15503030210252733, 0.14390973915015498, 0.18837178156020182, 0.12097731848517734, 0.20572731962367413, 0.12348899137108557, 0.1607865948350199, 0.18706000920745636, 0.135163129457543, 0.13499855844964906, 0.20035923428593144, 0.16533093647130076, 0.16871099300201864, 0.2064079427791219, 0.1433782273482892, 0.19167841622425666, 0.22361021729246264, 0.13530936032052965, 0.09267007856960259, 0.14701254846107575, 0.20005022506079367, 0.14889487245630834, 0.18425811923319296, 0.08841256025217234, 0.14729393255566398, 0.15119089925241086, 0.17772191835026588, 0.11580216473028546, 0.0985935393480524, 0.1547478608066036, 0.07351049537500066, 0.12244434621665748, 0.15339413747912453, 0.14441593940700256, 0.1461465626714691, 0.06221270564222529, 0.14303361035643086, 0.10607620355703178, 0.1844701723706338, 0.13961950887835797, 0.13676247589530485, 0.09088465703591224, 0.14328309454985205, 0.13556688843715575, 0.1631518606577189, 0.10210848097959835, 0.1227056128423541, 0.13373707210825336, 0.1051351488117249, 0.20384395374886452, 0.10944221003521835, 0.11776219302367781, 0.1388500961324861, 0.2555356904744141, 0.21946963463579455, 0.11385006544690941, 0.09456678203517392, 0.1350117198401882, 0.06875524207228614, 0.15009798289787385, 0.14805946889663898, 0.16806545667350295, 0.11286490701980169, 0.10117818210874835, 0.07399189736573927, 0.15634881602900644, 0.14619062804887373, 0.18620880891478833, 0.09873862107915264, 0.16129610459170035, 0.15536860652988957, 0.13457105074438358, 0.27857138745246396, 0.22207471662231032, 0.10796429619433419, 0.17913492156132577, 0.10710323635008066, 0.19345917228248813, 0.13693024915072227, 0.12633364437328232, 0.20645896423487894, 0.1751059119499499, 0.208504771393153, 0.19165938660021753, 0.12599495690195792, 0.1691546958060034, 0.12009353647308967, 0.1249848316693979, 0.16204169200312707, 0.16013416371518568, 0.16307014971971512, 0.23680019823293533, 0.1613200218566964, 0.22915716883876633, 0.13592883433786132, 0.1888456069413693, 0.18966568874255305, 0.20024251312978808, 0.17512405291199687, 0.20281647662481955, 0.18993853861766477, 0.06212932846298622], [0.04097660282446493, 0.12327737490376159, 0.08049594553848428, 0.02620642189867795, 0.037411907612676584, 0.1315684150904417, 0.06823124559295755, 0.040858276714120186, 0.07554494144935762, 0.05113565648395208, 0.06050870010268785, 0.04716251766489399, 0.013324864126080948, 0.020106818354237947, 0.026063693972725063, 0.0506174631206499, 0.02536726259295979, 0.041323602349767764, 0.032283994669635455, 0.009916333064827467, 0.04489980037173918, 0.04196841855563464, 0.02398486459447492, 0.0513399759637973, 0.020477317626618093, 0.059365329197457725, 0.059979107351072376, 0.04286185327556826, 0.04614229156305233, 0.040016353746215184, 0.04136569505076736, 0.03311746385729602, 0.021987874473955844, 0.02177636908938087, 0.013227498181344522, 0.07885720685965593, 0.01925796803627764, 0.030709839118043744, 0.06400186568498611, 0.052650269766848896, 0.036147885520251534, 0.05703525745400018, 0.02746079894413631, 0.09253244321312636, 0.03757720640409858, 0.025293277651672403, 0.025543261717464176, 0.021758408157996113, 0.07321162915398037, 0.012249245079264287, 0.08670547886961892, 0.056267939958601236, 0.04916976378749936, 0.06706365864844092, 0.07070986944581233, 0.02476239595712433, 0.021411948724679893, 0.04428216879586539, 0.037461063644338044, 0.06085109160912614, 0.057930300958574786, 0.0895442329947987, 0.03972634350159957, 0.012017521676757644, 0.032954068794365854, 0.04506085503606066, 0.006273971380470622, 0.024302409954308987, 0.07959914003168383, 0.07345089373449165, 0.036093205994656014, 0.06432210575909385, 0.0664329384603808, 0.016543346967908646, 0.022631991624591813, 0.07773887170779128, 0.04366053058014762, 0.015787325438953215, 0.022623827042538795, 0.04148392156968194, 0.03341407777981893, 0.10614115249125228, 0.012966780266123674, 0.03163451298830971, 0.05165585699761587, 0.03831299938141339, 0.017723754393838106, 0.052250356548616005, 0.023042111049195933, 0.06052462707063364, 0.0668753235931358, 0.010044724612887348, 0.01608686390212707, 0.020639854671073057, 0.06046004585861679, 0.026687597893478892, 0.028523378216871814, 0.039042690468411294, 0.007321920767877132, 0.11443878869496046, 0.049740277125590274, 0.04846282551185258, 0.10711121898625167, 0.03738711317700725, 0.05654039146799234, 0.06018307826091206, 0.029931493786974784, 0.009756968581988927, 0.02454182966762493, 0.035144264374168656, 0.039292067409523075, 0.09696566379599034, 0.030736606230118105, 0.04281062880651124, 0.024146995612330014, 0.03295622916231233, 0.0059197553069210585, 0.027590453579661348, 0.01077719372622068, 0.04114437224944273, 0.028543068591745633, 0.02868572756978533, 0.0607094802563229, 0.05769361426392871, 0.05349217741299541, 0.03578062296935147, 0.0486242976940928, 0.013357975403778257, 0.07904399441735399, 0.025156243674216733, 0.04171909141023794, 0.06966816606901347, 0.008925730625407831, 0.013437564278231754, 0.05355970040264149, 0.03238570816334217, 0.026355452813027848, 0.036396450408163576, 0.014928932538286093, 0.03416037382257562, 0.06347202395479526, 0.016925477370199178, 0.022709301387470578, 0.019512412649008538, 0.06431063742286737, 0.014593178226101785, 0.04763890177972856, 0.04889047877382367, 0.05681031488723332, 0.014517904341881795, 0.06486405933936758, 0.030117461630593867, 0.02907789946954337, 0.05082665108925393, 0.015604236170709615, 0.038277671236785195, 0.0337520451284945, 0.011790792209907405, 0.02527163183737186, 0.07063080151114734, 0.05962302968386681, 0.03667674282745969, 0.027537890371956655, 0.07238118984406033, 0.03728993875425189, 0.02045666772661911, 0.029474043535188805, 0.06110590011362107, 0.06804429715679539, 0.04354647924042037, 0.06526402618375517, 0.024845393922840877, 0.060251260086173014, 0.08079302677464101, 0.05469183279802242, 0.0530001076479112, 0.09155784147761523, 0.06100234417845646, 0.036233040023474924, 0.018278888516849088, 0.03575967812550164, 0.12066080159838162, 0.03875187200103556, 0.013876575751290207, 0.040401431671794386, 0.04419500331184076, 0.045980995581034696, 0.03149473833130493, 0.018698338892370946, 0.028219344732802243, 0.06010135583158943, 0.034665486234570705, 0.01102029257679298, 0.028681347462078257, 0.06648517799593749, 0.026914940230668555, 0.022963324651843118, 0.02255983954866327, 0.0745163611587017, 0.03972736622897848, 0.04859080816048288, 0.029181399863333474, 0.023524286788738063, 0.01703740856159599, 0.01206542323944309, 0.08124636696471323, 0.024242806398580154, 0.03691813713240047, 0.08164234249101532, 0.04318280198100594, 0.038071042001848264, 0.06099346138897443, 0.019344838576451428, 0.09566902934062867, 0.0518274070665, 0.042500834341251084, 0.10194155042089763, 0.05917623571510758, 0.03463508403529564, 0.06609316314420392, 0.029447918021751028, 0.004618358178695123, 0.04317850039731111, 0.028380205959922848, 0.043139632926472736, 0.0354844112429888, 0.07748457648220562, 0.06475840049285082, 0.11462009872399992, 0.051233991529912724, 0.0870127184316516, 0.014857613582975202, 0.036153163866049824, 0.031480226710799246, 0.08880374006806843, 0.039572202780794714, 0.04471298600096376, 0.04086529790994622, 0.06037842302072433, 0.05614731941492327, 0.05813786099033971, 0.041006219783617605, 0.018150047849743597, 0.08732956473625476, 0.08421436012271913, 0.011367402227234938, 0.020117602956992005, 0.08178612953352352, 0.012985279374275238, 0.009979059386457647, 0.04049837626817246, 0.05558272410604743, 0.024991735868576555, 0.039625453552411455, 0.027919599425888834, 0.030680097669603366, 0.042131633587902596, 0.023313587711703394, 0.038958459101136655, 0.10453137193596172, 0.03991376691227479, 0.03816432852838789, 0.054587426505261855, 0.027540874284421726, 0.050261052205197276, 0.08312168125543865, 0.04170772649588124, 0.03424626760064595, 0.0316923909309891, 0.06862234880006121, 0.03589077492154414, 0.0735406409348211, 0.06527744038330932, 0.04294311988257593, 0.07603368256241083, 0.028217303108484037, 0.035049361402108785, 0.05910353014065374, 0.052962645948413885, 0.06132066137187424, 0.01822126338318471, 0.09280045141255663, 0.039063589346985665, 0.023906399954050302, 0.03220156743942249, 0.053474113059740876, 0.06788182522981398, 0.03863112888328972, 0.024126636825742263, 0.010979748331010343, 0.03900738147598121, 0.06824623027275648, 0.017742590580676353, 0.021577423716324474, 0.019048979250533928, 0.02182761845629542, 0.016511992904387655, 0.02874084376549769, 0.008302421380405225, 0.10060177755451973, 0.052072237275781176, 0.03221892316134707, 0.015293917892831228, 0.049381487507132754, 0.09003580863317175, 0.10164636908279312, 0.03858546621256298, 0.018007913641932032, 0.05468867268533476, 0.024946500291867603, 0.06002514540488201, 0.04529982467272109, 0.11328217979039877, 0.04129248385828349, 0.018088469702389934, 0.024924126694038994, 0.06280219497820062, 0.027093161010153355, 0.04059131805514617, 0.02183869991812014, 0.03748286650666306, 0.04856506760622706, 0.017365954944022724, 0.03535085530470937, 0.03288242808212677, 0.014880260099626839, 0.02823471820222274, 0.08831047903626196, 0.09028661049782269, 0.03405643484344886, 0.016186292538599625, 0.015909489649798603, 0.026203794217097665, 0.033618688373075384, 0.03231827327380738, 0.0330806456716551, 0.01892585168412376, 0.036046926623150226, 0.033166332605985865, 0.05261058258193155, 0.04429620735707783, 0.0024237980523462137, 0.028102847657376723, 0.010450766534514485, 0.08818796625541103, 0.03985739433236661, 0.0326988619241503, 0.009656138004614942, 0.06178498343234101, 0.04855401678791931, 0.03243142446022361, 0.041964197411171855, 0.16209665115081495, 0.17005350080228623, 0.08462995516076204, 0.11775643970336645, 0.11632965457054878, 0.21584901117509414, 0.15857886733306994, 0.11208743502896641, 0.13535472804740553, 0.10305056228272377, 0.11268306839009447, 0.1251316983853617, 0.1968415730422543, 0.1079286271405797, 0.11739525222970594, 0.13146038137135968, 0.17264778094906963, 0.12396737497540251, 0.11583385778771293, 0.12728220678024715, 0.09509621007788567, 0.13059937515326087, 0.16170410769841365, 0.15654111941975934, 0.13854225136099324, 0.15541185985409445, 0.09647086292745606, 0.1698127806547188, 0.14158208824453816, 0.13033916572889975, 0.07102254057122816, 0.1603451443295325, 0.15650423994708448, 0.1542445870056268, 0.1070523068248745, 0.19310683312435306, 0.14234616901845704, 0.16882947616038785, 0.17493781693760427, 0.13102600951829266, 0.27585287848787926, 0.19142323233667882, 0.1258044921222233, 0.17605019192541801, 0.1997524007193504, 0.11982110028545703, 0.09675917245687977, 0.13482695475461023, 0.2232630722104542, 0.12945154561631142, 0.19846448434456704, 0.15069825875182308, 0.24528704283218233, 0.11372302508642597, 0.21108000659413878, 0.09795765572738263, 0.08579449307534003, 0.20069649683371668, 0.15971125253746588, 0.2330225420695159, 0.14240872775835378, 0.13299375231708252, 0.20496421944229834, 0.14670819705051763, 0.1505142291106524, 0.09875375897653642, 0.08370830542257718, 0.1444631610666552, 0.12602114178720983, 0.18205057559234483, 0.20156920887529853, 0.20760230449659212, 0.1196416365283151, 0.09230830886911962, 0.1423851475720444, 0.1251693516068401, 0.21129397495139032, 0.11940583466522156, 0.18032529962158975, 0.14048684298271133, 0.11670620210709111, 0.20618712559582728, 0.14702462200676242, 0.15120707902937167, 0.2178479337524022, 0.16491216216837207, 0.1204633730794153, 0.12094508150532363, 0.1059715789292128, 0.20905381128672632, 0.1216399385744045, 0.08852883707731964, 0.1564973757992829, 0.20526572100577817, 0.18249539688469904, 0.2421548923537616, 0.1268974774246735, 0.20380943382699646, 0.21066415874708086, 0.231531826899417, 0.08435188822688595, 0.15470471473470812, 0.18488697016671782, 0.11964756604884902, 0.1064865738754311, 0.13122206673987452, 0.10313440294515702, 0.14080208816355275, 0.06824131964916183, 0.25260178822903867, 0.18570288444959349, 0.210631508079748, 0.12604312851063668, 0.06215737494189413, 0.11391845411590992, 0.16560564027918925, 0.08022923968852529, 0.09861889685834609, 0.09168460604644592, 0.14680962709169235, 0.10817068794201459, 0.07328982374841168, 0.14348005575518455, 0.20496731443751245, 0.23532747080729854, 0.12426322281000116, 0.11809550255777375, 0.09609503551356255, 0.19197182789925607, 0.15965336693390725, 0.20989849983203798, 0.12993506967060028, 0.10736444168874335, 0.16724134524983747, 0.1296311013040043, 0.12674008466063008, 0.13738545859532972, 0.13586328785505988, 0.07659233685943388, 0.09688918523850942, 0.15149056220487242, 0.10477338677212115, 0.09821467822597874, 0.08528463857909364, 0.26558414402027286, 0.1426392129712528, 0.13950654155304357, 0.10902001898014739, 0.27254340929850457, 0.18424914068272039, 0.1757053144636654, 0.17919784802342617, 0.17983391550519776, 0.1581548070234637, 0.1212982786819339, 0.08944309406703518, 0.12384303124441255, 0.09219224654859112, 0.17244038562620842, 0.1831435379121573, 0.19420828369836654, 0.15140993911172115, 0.09070435824293284, 0.14313724673082753, 0.11609816578246894, 0.07345488505257715, 0.1437573489402571, 0.1402013373350905, 0.14682813577594298, 0.09008407983328066, 0.17753468646157175, 0.12243513017892839, 0.14010084192118338, 0.09599180516576576, 0.16862621771231776, 0.09641935117542745], [0.03846783724222933, 0.03393718559715537, 0.05574407371421976, 0.05011217450843223, 0.053508927925459804, 0.055559209037211635, 0.011475181222082147, 0.07189362084553128, 0.04675887359846984, 0.01322059860197647, 0.0744511823981039, 0.022892382994834936, 0.09072008602801832, 0.052566065212651614, 0.03889206992161851, 0.10061089400081866, 0.04726851742053705, 0.04317276622919787, 0.08286940084109384, 0.010570951365685512, 0.03891363912712663, 0.03155242475200325, 0.0613134409931879, 0.035325593555406216, 0.040402327994665796, 0.08096701300312435, 0.021828581811860207, 0.03197754034772515, 0.033149168406042366, 0.039852453065255, 0.0541996902545854, 0.04693418898950181, 0.014785224977400035, 0.06845832937547276, 0.04642813811979948, 0.03234363078410107, 0.019986513821828752, 0.04585926420986653, 0.05312241358502258, 0.021602007477814635, 0.08591932710260154, 0.04635395399565178, 0.07825183652101025, 0.004917150184947757, 0.03528854554338801, 0.028032823390657866, 0.010598327517659675, 0.016610915922830184, 0.043094472043336406, 0.04302841994250494, 0.045669419961350585, 0.023444175059276245, 0.02671198247210874, 0.025256440313833377, 0.025464048226093574, 0.04084436838785487, 0.06742266277151723, 0.005562652518311817, 0.03607822514529671, 0.05005942169396628, 0.01219137671268395, 0.06210255752047224, 0.01700966085697855, 0.053607335749773256, 0.06256056701644294, 0.03507643111891324, 0.035353789421459364, 0.09305662355355679, 0.04290501849966184, 0.012387045144644237, 0.10721002900672537, 0.026677290180457697, 0.027009306941181425, 0.014908418618893672, 0.02711688100750889, 0.05069791384401822, 0.027800478499322653, 0.04236747375539234, 0.025497627775034597, 0.06208642370878689, 0.018593697027573665, 0.07410028348526648, 0.027543599642212355, 0.05109513426319726, 0.03300363085262718, 0.10811018231775492, 0.018905870195838715, 0.03504638898096258, 0.05608541951064141, 0.03973670484077546, 0.03047110122298041, 0.05675347116325171, 0.023307529871442148, 0.022765796541446642, 0.03457124975900497, 0.03716266473695155, 0.030121115869992686, 0.04867895040661097, 0.05204773012308344, 0.018630266234639193, 0.014928197093878784, 0.05201210320416478, 0.06047761608516017, 0.014958480549525591, 0.06155444459328729, 0.03792139438671931, 0.05610388222961657, 0.040223745238636775, 0.03875552240999476, 0.014671415912978833, 0.017194320605466926, 0.019073170391962897, 0.026388235630527623, 0.050223621149216933, 0.04149259751542442, 0.05323885894951321, 0.02715832827943227, 0.03868053772396619, 0.0891916027232524, 0.05029282187141719, 0.0037455424758410386, 0.042215409132862286, 0.009536038400725493, 0.016062572211658042, 0.07433330444919486, 0.05345497618339235, 0.06625876837079564, 0.045820523143535664, 0.02297864832554854, 0.05652186746198324, 0.053545742280661106, 0.038834383500920194, 0.06554095930750332, 0.08025858851690447, 0.04665943538589824, 0.004563410043521154, 0.09922109559298524, 0.03332538395038536, 0.030298279448141976, 0.03455549516084214, 0.07650233685008942, 0.03241702966812638, 0.028860922301969225, 0.04395350558503021, 0.05150493001565338, 0.01747776547657146, 0.03595826726767325, 0.033472595405915094, 0.015072778952608426, 0.026529864220309163, 0.042648639514922135, 0.04550304481639497, 0.04327400857883115, 0.017612053028818582, 0.05740817756422105, 0.047064672915204886, 0.00703189711672284, 0.039489767889702515, 0.021752275624162248, 0.06846855664926191, 0.03180528356273088, 0.039006534948824875, 0.08653248855543715, 0.02807582582106754, 0.05052734053723755, 0.11342510115355255, 0.020024567324247573, 0.007132215851602415, 0.04475429346184096, 0.028181348686977744, 0.021448196174817222, 0.060662392662056995, 0.04421943002530644, 0.008857981639824087, 0.04649258143598995, 0.04271526235125719, 0.0415372489500911, 0.05012302231344004, 0.014466788082744085, 0.10733210511745946, 0.019836381656087695, 0.013043512590229513, 0.052831438069622365, 0.03438212180269822, 0.026808233758915338, 0.004116103274657602, 0.03505868086170766, 0.057359075158714294, 0.04259934941787393, 0.09835310265301697, 0.011282245808791731, 0.05262365970279902, 0.014573932182224048, 0.027505103724017262, 0.05632419379488115, 0.025152934174383842, 0.05384383475287788, 0.013516219483027536, 0.05332310180810671, 0.0402100399256714, 0.0425557283714654, 0.05198296888040439, 0.03736683482965154, 0.03195627757738675, 0.012618641185033466, 0.0733307941306022, 0.033399560413653814, 0.01641384171952884, 0.0962613991671993, 0.053789637862674655, 0.11224488141916453, 0.04962784223138325, 0.04399795783683658, 0.040856909247175346, 0.045486370912723006, 0.0021860630142562574, 0.2118048330228175, 0.022517570647441094, 0.04679691369434999, 0.04005665380147196, 0.01642445969815937, 0.017699628369882703, 0.009038919158610366, 0.03575999605199022, 0.006790718274010767, 0.045968163608303, 0.018565585431192192, 0.07590108806447637, 0.021467486268750603, 0.03341357599222853, 0.0032679275928756166, 0.08359148467500364, 0.031184880663791013, 0.014739321946587055, 0.06343655408390107, 0.03687627042733854, 0.033571317326277494, 0.05809602875923438, 0.0044154305848473265, 0.0610350139979874, 0.044756993921774055, 0.025550740650824966, 0.050072065975156524, 0.009279780074833863, 0.05087585691663046, 0.06215670844540001, 0.049443843233729565, 0.019689928627603, 0.026300838404905894, 0.01784927215457203, 0.046913657833131096, 0.027269294200044487, 0.015216160926126666, 0.031093683642064853, 0.08487611453259185, 0.031824332338968114, 0.03757397351305812, 0.01777371290260025, 0.0533887823562949, 0.019623594989459363, 0.07529600883924192, 0.07626789096262186, 0.06884134269409603, 0.12506851145336706, 0.057248459723327434, 0.03162894161388038, 0.04711118594352757, 0.012469406299773726, 0.08038396646659221, 0.03946835573221888, 0.024522698536935835, 0.03510877152063674, 0.08963555067537293, 0.0491738508665754, 0.06132934880893558, 0.022433774035063483, 0.034518837853665316, 0.026245457908859657, 0.03150233217785436, 0.014266740500686631, 0.041798147853584065, 0.025009784900072603, 0.039527053388977246, 0.0749973341402027, 0.032554829733506326, 0.010422215395186459, 0.03667602653525049, 0.02953085086999401, 0.018470986979082227, 0.08964593882762617, 0.0704004924984709, 0.012432203154950854, 0.0037048007230154213, 0.01190788779152377, 0.042049719636598905, 0.0433946444442676, 0.012660328817043095, 0.0767158302328279, 0.047046593240191864, 0.005290733918833036, 0.05795258262585248, 0.0433932654860039, 0.008868074848226482, 0.08087647673223289, 0.06176248343000489, 0.06291804662454994, 0.029564826869435852, 0.021493621358287432, 0.06330313604144801, 0.061812880524103685, 0.03590712706828791, 0.040680004223700494, 0.04223965964610538, 0.00789681277726026, 0.04217186852568581, 0.04383748539933755, 0.08712198555229173, 0.04655865268901952, 0.020371789015048457, 0.020383106048909888, 0.025745824940742987, 0.013538188011866185, 0.04442506334594181, 0.04871980970605247, 0.05279623249906206, 0.02011326689934058, 0.03160936232175558, 0.059816616271892865, 0.059602605779805494, 0.021385129901670644, 0.053001494267054146, 0.04283052794034443, 0.025295767437426314, 0.0054375948891374135, 0.0449191517527065, 0.0439888337296584, 0.044848935964006575, 0.0402548024430871, 0.04183036185080006, 0.023604364044243292, 0.049564325881581155, 0.038533732295036316, 0.03683340780797505, 0.03543744622279079, 0.06678596709764774, 0.07457905013354556, 0.032699424998774644, 0.0733005489793516, 0.03320902285556639, 0.046086937880083445, 0.031335845950149724, 0.008045914075938205, 0.1645811049327735, 0.15613057290113744, 0.0698167028566522, 0.28801550487837485, 0.08688923271913683, 0.17611435944995574, 0.0839521052436002, 0.180453312913737, 0.16520863819506862, 0.06550512171440548, 0.28920468784147696, 0.11504162328257678, 0.21994353662575447, 0.21053236098058764, 0.10367778144896993, 0.13175033032894135, 0.13579836956435634, 0.16560806111702997, 0.20309297307845087, 0.11212394677943761, 0.14540103654707634, 0.0774994615705744, 0.09848111594516425, 0.10924851236444329, 0.15218915778302378, 0.25573191623533925, 0.10327591470653012, 0.09978797767431506, 0.12749452804846148, 0.14112888595029233, 0.1937457351314445, 0.15256055720871495, 0.23006437015869927, 0.18341894652093613, 0.14092804834006295, 0.1924245245754719, 0.21948229040830367, 0.10376472476749651, 0.1603537858013184, 0.09478409053577531, 0.32518578452929375, 0.13152473275699925, 0.2092881882262807, 0.10012297260184443, 0.12527013813415844, 0.11406963390688743, 0.17587008465441967, 0.11807897038036778, 0.11870474930131629, 0.21093864805035054, 0.06815524200998968, 0.1536996533433276, 0.1577862268013339, 0.16283258585439575, 0.15690470474862284, 0.31926974714283024, 0.1423427829098317, 0.12901309817548723, 0.1440812509146429, 0.15825542501143872, 0.08169008509045647, 0.14526151661430636, 0.10245060052482352, 0.15713754951232867, 0.22565354232586202, 0.0866675498564878, 0.16503698853475435, 0.19702102147763778, 0.11395377076921925, 0.15798035348134656, 0.19536686910977288, 0.11228864036139943, 0.09218509894825759, 0.09908638669237976, 0.10232454075688317, 0.10604146146966566, 0.10459781474163456, 0.11082232509168888, 0.20872681431712645, 0.08902638054062283, 0.09403534684210055, 0.14576728786191634, 0.12789275587326096, 0.1702863608877505, 0.17037499726058977, 0.25057415267632854, 0.1038166042417288, 0.13072576433900865, 0.16152534874216204, 0.1293866273256079, 0.13632442682020127, 0.20754754453176455, 0.14208119452720688, 0.09679589105109054, 0.08409096634075527, 0.20187657867227832, 0.27900545287036127, 0.1046099572352344, 0.1556597659063916, 0.1491227529702648, 0.1120973482067066, 0.11827577836811544, 0.09614813306759443, 0.07233606726532021, 0.17511875158356083, 0.06187372705748966, 0.10640280216091103, 0.20603472006417092, 0.15784402047434162, 0.12451997717782376, 0.1133213268833295, 0.07302678745960997, 0.06203175567451024, 0.12613292933712084, 0.20698336674080742, 0.14408848278464811, 0.11465662579622962, 0.1863538446806131, 0.1961027731698367, 0.1669084494032206, 0.08254802695685819, 0.1996111341061131, 0.12313437693181539, 0.12724817715465062, 0.2659338171924314, 0.13635119393227563, 0.15811850977761133, 0.16277929677838282, 0.18595540235119482, 0.1964364657478948, 0.13073379294045512, 0.1216901786204788, 0.1319871893933704, 0.20220287084098787, 0.1512197041583638, 0.08616370148956777, 0.13059960497963813, 0.06728097480992157, 0.1170303568904919, 0.10937906906849916, 0.2431248209529346, 0.1588626569437404, 0.20353857578048784, 0.13214278185079176, 0.13770157711640482, 0.24583032174456507, 0.08335349946132592, 0.1588624577608801, 0.12849700006265796, 0.1331421741915326, 0.17694001837122827, 0.1416916234959518, 0.14984753343366808, 0.06004216021768028, 0.2342791101264377, 0.11020475863328866, 0.0723986336660962, 0.09011634745665136, 0.1237461977307835, 0.1436688657850027, 0.12130694313635751, 0.09730698660977426, 0.1540976360199913, 0.1466592440321561, 0.14522842161597746, 0.20042337116695222, 0.08091918613401153, 0.13049048341570363, 0.14280481053696525, 0.19067333951111765, 0.1266212337800572, 0.14413205786578118, 0.15000410648363252, 0.13747551989170814, 0.1627771517321948, 0.1916017308230362], [0.06639971322710476, 0.04651998823148109, 0.05787935228117051, 0.04979554270844787, 0.013730894556389222, 0.10000229077113253, 0.057778355079672994, 0.023782950630711935, 0.018750436701661637, 0.07193418520112192, 0.005969964709478401, 0.06845492028420971, 0.0538660129982858, 0.030922434262691006, 0.05029551850091066, 0.03046227972053232, 0.03015207539823267, 0.02077754939936342, 0.12181458363850271, 0.03725827634034138, 0.06053655122917506, 0.045984320402626074, 0.13332621915446174, 0.06049028717942777, 0.03668788174587873, 0.027625680217639576, 0.013320217802820188, 0.03494555265792916, 0.021262299194331133, 0.045649382931691025, 0.03475603782722066, 0.052185082027027686, 0.0333541352301836, 0.025592919536716035, 0.044866747508246096, 0.06258469878605778, 0.01855575077746424, 0.028113293266224287, 0.018672828164492405, 0.030755616701959126, 0.05265165255555222, 0.018262547861424186, 0.006996480393178401, 0.09346265015342543, 0.00838343230556817, 0.02176284763751732, 0.06022065104315839, 0.048949203243659395, 0.03795639311354007, 0.04012658230720028, 0.04414867797505952, 0.039848178294637514, 0.01897614344113296, 0.0386668132588027, 0.033662998898615765, 0.042463250067685886, 0.03463085906039323, 0.05097562454700951, 0.0048687233732292255, 0.05876892208752613, 0.043198744270710215, 0.01386479619184449, 0.062269947731927525, 0.01585258463878305, 0.12098716271500434, 0.038553141132597966, 0.06654168464123242, 0.05187981131096041, 0.028762135264133255, 0.025264514880555294, 0.06870650355854342, 0.04284924729877422, 0.02821176812323111, 0.06672831132046639, 0.0506313867686737, 0.028216998588534135, 0.026505121495574716, 0.03195088814883944, 0.04822566384269346, 0.03458393234459143, 0.01395012498007066, 0.02161272887831494, 0.055109212820928906, 0.005127520322979939, 0.04481017957591722, 0.0506970519951034, 0.013889888444194391, 0.03042906980901476, 0.038105412536571105, 0.044235897085238854, 0.013134060352439842, 0.026867385322768843, 0.02539831788219031, 0.010565820491812643, 0.047632949276556896, 0.02179221178765499, 0.04045547917485237, 0.04482158279467014, 0.022526271491041108, 0.04357890008137592, 0.043972516056871226, 0.06265306447242057, 0.04900470248333389, 0.028600921636567484, 0.03856134210382739, 0.04782998326024221, 0.01576213072234344, 0.029788534119424802, 0.06628722087630341, 0.03914827270613563, 0.050831542560650464, 0.04199723112246683, 0.038610000178338065, 0.054526262045387304, 0.03344840617970594, 0.037397857560145284, 0.034162990012837034, 0.04450943260904282, 0.022767581526310216, 0.07378958120581604, 0.015618065015352784, 0.054181725492761026, 0.0537053145648491, 0.01212889745440935, 0.032988056285126556, 0.05030583004437147, 0.03438243589874718, 0.011158551337317595, 0.023229953893009695, 0.01486185292202619, 0.05631842132237169, 0.025936728305814248, 0.01261228457048175, 0.020195012311300924, 0.01911092895053087, 0.045087848144072684, 0.060758506053037224, 0.055126851995385466, 0.11066680158218069, 0.011966079830252116, 0.03383208216438371, 0.04713062159416657, 0.021596813401688012, 0.06992567120300186, 0.00619498867308721, 0.062397788654291825, 0.0853594930301751, 0.07878197702549158, 0.025399941988589785, 0.05713905087642132, 0.027513831380694628, 0.0594568154173753, 0.020792254457069982, 0.05390016519795022, 0.01308884584314881, 0.03952348724968972, 0.04317804457499616, 0.006383954793319948, 0.08715647483064283, 0.06370936948505622, 0.009060244173592618, 0.04469974034075295, 0.03060332799871122, 0.02771446214718444, 0.007855258253027476, 0.06743748657285206, 0.048642549738888784, 0.006936457883115979, 0.04535949909158292, 0.038082874229838776, 0.05668839582452371, 0.05332235487238054, 0.027550913866669424, 0.010591716178873134, 0.02021536918266887, 0.04941426074853347, 0.05337025451984617, 0.09115385267162517, 0.08974083413880679, 0.033712377095775264, 0.0757171273712189, 0.06454906696754117, 0.03795728177553223, 0.027181510100021, 0.02945420185794994, 0.01610153257065723, 0.0968572163894292, 0.03253877253061341, 0.03950491727840516, 0.041912383054413145, 0.0732420045401781, 0.03830870162815817, 0.015300752354725717, 0.0370129979696245, 0.14031816574354328, 0.027182726264600793, 0.09440588058843728, 0.04503160962955125, 0.04907234804704786, 0.061564974471806526, 0.04383347492905394, 0.027339590427976464, 0.023927413745813315, 0.028952429589304714, 0.012986715789133263, 0.05217228452825258, 0.06935906491332477, 0.02204336222231148, 0.07877145097741196, 0.013952704781155675, 0.10576191598609572, 0.026592057153222062, 0.050833365849910245, 0.04522900367456098, 0.005675065387491017, 0.010409089436213817, 0.070423812214886, 0.053284877851124735, 0.06664647780839475, 0.011653827180364921, 0.006556833545947749, 0.0186565947613769, 0.009578270912771265, 0.03681789069706875, 0.03597728923083313, 0.02164553467845244, 0.005340642153075146, 0.04598674890134604, 0.052437082819280126, 0.00646132153398808, 0.009496641371609464, 0.013185778948208018, 0.019982940021661982, 0.057554730184135906, 0.049862563910503546, 0.01779469988128591, 0.07583267641283813, 0.03536749856486436, 0.027476526729221788, 0.03757868878423207, 0.025894302356567596, 0.029913958034388004, 0.03461424261331558, 0.05878452346810411, 0.06289637399717204, 0.05373611129940518, 0.04906543793397085, 0.0758633658950848, 0.012730793584318412, 0.03207394102167699, 0.05992338977633946, 0.03040044301850421, 0.02224747677363696, 0.038198867602454084, 0.09524112326964256, 0.03899876298683305, 0.06942191476663274, 0.021351739959490877, 0.018923660672660318, 0.05096348205340966, 0.04755198910471894, 0.03421763889491558, 0.044216239269101815, 0.021976867705703746, 0.03032216223918142, 0.027552943999668764, 0.04793070467008699, 0.06249122073753707, 0.07643580211386566, 0.01652240978493806, 0.01508110345551564, 0.07057571212851232, 0.03603711303684019, 0.05969083612604488, 0.01131860912972761, 0.05667588177828058, 0.025139083304712852, 0.01602134135957327, 0.05233960579179468, 0.017556503993429003, 0.06587487405105945, 0.03658503444204408, 0.03910103189428488, 0.03615722030160889, 0.08160149468289268, 0.05505546792260101, 0.02991739585394821, 0.06056722155922364, 0.03756675313437178, 0.051600679514869574, 0.0550521009661738, 0.026273174969960126, 0.06251541379418585, 0.019660472546914415, 0.03976379370977802, 0.0387683620436057, 0.04366677802717013, 0.029950013962544264, 0.06012800036959591, 0.051057170776109544, 0.057247536587378675, 0.015443881519228942, 0.06923965478856718, 0.053125815015406384, 0.016036320293712762, 0.04591397437897902, 0.0496720033697784, 0.035769215920158935, 0.021347549458545063, 0.046883826369359616, 0.04400400610099878, 0.025769583242494735, 0.09826990550444012, 0.06967863083005914, 0.049005966528408954, 0.039162675159112106, 0.007161998477268725, 0.03184366073729771, 0.05557635025451741, 0.0749874899103757, 0.011707021452997242, 0.06349833907499429, 0.016202602550507556, 0.07113278828441136, 0.039781697184568456, 0.03273284175403176, 0.01624790324469007, 0.025991857908065283, 0.08072115240558501, 0.03001766718713747, 0.033729047169007605, 0.02410713031197027, 0.04765908819653335, 0.02413064538080606, 0.08734019803664378, 0.04021601158104116, 0.022866018078920823, 0.06578492000699043, 0.06676558915886187, 0.026684625472332683, 0.04067559538769626, 0.021783599044166265, 0.008047126410078377, 0.06628977960997051, 0.05711265148655061, 0.04359842000168659, 0.04699700053841357, 0.01882957358423981, 0.08215620362710568, 0.020186324874239586, 0.02381866181930227, 0.046395675144008094, 0.23355989146136472, 0.2520001640603427, 0.2100362424408236, 0.14742436668565198, 0.08180446201755155, 0.2141801192755661, 0.13147266942166513, 0.15212551119827455, 0.13809723088577872, 0.1474663789474195, 0.2263659428084089, 0.16256823955524355, 0.11783291059996813, 0.16206704951342077, 0.14768341165636817, 0.15017112897288415, 0.06750137064485781, 0.11778355155500675, 0.344021312531925, 0.11444585968650157, 0.2295597940082512, 0.10018223716366677, 0.2897832987289275, 0.17332366968114532, 0.18987555086853045, 0.10364185192532117, 0.16231215168391505, 0.10763126245189099, 0.06934942752723733, 0.10460758236266914, 0.12556460701049338, 0.14284141421798738, 0.26020467461597535, 0.08994334948159034, 0.133714058827008, 0.1335213264270175, 0.12069237974262047, 0.1510230647099595, 0.23256474324772436, 0.07434011497084173, 0.12136236193679995, 0.1379605454783286, 0.17772983969940295, 0.12305471144856946, 0.16246789735892128, 0.16141553769909567, 0.11203974605567994, 0.20659906639447137, 0.1217350100858077, 0.11532669226008078, 0.14980420350067078, 0.16981340884681673, 0.17186603418761687, 0.08324733499677912, 0.17963421170509633, 0.11059868104395368, 0.1569433002582481, 0.12775810825968945, 0.13253302703942024, 0.15582802945808058, 0.10575923467836074, 0.12224065109847054, 0.074326241118533, 0.11082611722691406, 0.17770420639745652, 0.08614298647209521, 0.1843428179141014, 0.17915186742621084, 0.1400290748044368, 0.10048183116821513, 0.13347283306141056, 0.1809086908976878, 0.19642437688044964, 0.1257205135639637, 0.17807300112420515, 0.1965235393013685, 0.07171535984643045, 0.12944333315376313, 0.22063724456294892, 0.16592652386715337, 0.10645655088967855, 0.1325237880190534, 0.1301731238321912, 0.10954686530655432, 0.16001546605219766, 0.19360978516840166, 0.19085634259446976, 0.10626240122702815, 0.15626460764436953, 0.06623296652950587, 0.09045816822758607, 0.1485206997923313, 0.16347423045625611, 0.17696902246004154, 0.16811773451345582, 0.20428834603198115, 0.09961628970960457, 0.15204079719560762, 0.05405467364095873, 0.12174858516382596, 0.10833528193254625, 0.1030263155999203, 0.2012917471508826, 0.08219279198636932, 0.11024760593089367, 0.09908014307579688, 0.03073293475374099, 0.1616609309830012, 0.15875174273406306, 0.14166960612900797, 0.07581890215195956, 0.34246318162448947, 0.11073546604283395, 0.0992902273672723, 0.18592837476922622, 0.16171561433903633, 0.1688371830049061, 0.17961407891444622, 0.094694190117861, 0.16521135014632057, 0.15720337178678284, 0.1400468327225216, 0.2379081911978222, 0.11683996871954973, 0.14879331984106572, 0.1275857537984848, 0.1773945076931869, 0.19830835562559868, 0.10319109345155378, 0.10096085828638847, 0.13137975827820841, 0.09250720061602132, 0.13020033527526165, 0.134222986356866, 0.16974931793107143, 0.1423091363281973, 0.1894994323412257, 0.17632141769413026, 0.17621794985907693, 0.171132842078805, 0.17137388398330058, 0.12626132567323026, 0.17218020684536428, 0.1664756710130361, 0.12420159869737203, 0.17426994148521655, 0.16024481745496874, 0.1573928100086989, 0.19978698192825242, 0.17556688237574794, 0.08951108437031509, 0.16223791776405228, 0.14478637356190913, 0.13631079045514907, 0.1891118684603322, 0.10604254931451813, 0.11902996128605259, 0.17537998756574047, 0.22592649945328314, 0.1374759795444627, 0.09300766287431603, 0.1613557828410018, 0.23947359994053843, 0.13147158157681266, 0.12443541639274168, 0.17884622898793992, 0.2556422533046815, 0.23264098431794877, 0.25244507728324783, 0.15465752371857244, 0.1485788152222672, 0.21450411318050278, 0.21365708040614284, 0.08984123762216299, 0.1166712991412609, 0.17287900160637595], [0.020753990280471986, 0.004497230101767327, 0.037329239064767476, 0.024308312661765565, 0.04909996551671817, 0.02778714665422036, 0.026684194547875274, 0.06473999140003035, 0.027022949051893046, 0.01676998833464759, 0.01715052335883581, 0.02946829979097651, 0.06717943751643743, 0.02607376611370954, 0.014394474170741536, 0.02920514858898617, 0.034718177762002714, 0.02110654011278624, 0.013781357725571482, 0.019680750894270117, 0.08580930921579562, 0.05421929827500736, 0.1264666525586959, 0.00998892659892238, 0.04734209633522457, 0.06859366646817616, 0.019155007734474157, 0.05449724646525518, 0.014653315170547895, 0.006193895561380253, 0.003364537504591769, 0.017863477339908, 0.0030851873734425157, 0.058204127595789974, 0.031809642603020036, 0.01107016107022402, 0.04661364248022438, 0.06254657059006634, 0.015219767285030217, 0.06446956236275934, 0.05347913859652416, 0.028824500566829118, 0.05764333208301856, 0.020192405697138562, 0.017867717636568893, 0.021250139463752992, 0.06447822681718296, 0.03805786145911102, 0.03990843877076142, 0.006694510079649908, 0.03603705558024588, 0.011482721442476878, 0.03916318843802137, 0.042731465110855724, 0.0706956738365754, 0.01804114462086751, 0.05264613289205779, 0.02254261597690563, 0.10315675739078753, 0.06492605117420036, 0.0356027296924543, 0.04010967091627179, 0.0404103106308368, 0.045512479189182484, 0.08440205932504709, 0.025987303515355435, 0.024359169408618927, 0.029377845874536904, 0.031986503576439236, 0.005577859363608784, 0.10288179311300479, 0.02329472662700761, 0.054514648152455214, 0.02153827279295412, 0.021653406231874422, 0.016870862962077224, 0.08528371161270527, 0.01446125309749116, 0.06227259456570591, 0.03139889881675763, 0.025025403517628872, 0.04430345454884153, 0.07140436645356879, 0.16238209551140187, 0.036568751243213495, 0.022860015780034087, 0.05400678165437234, 0.01911369452793752, 0.015613474233466533, 0.018959207152346932, 0.11440895723118899, 0.03888940010520239, 0.040928618907327616, 0.04078238421390134, 0.03720898241285355, 0.06740569392399443, 0.05038045466907563, 0.01727242709978694, 0.043176305555408044, 0.035474111190846855, 0.0791775082207976, 0.046327780601718736, 0.07437790608814648, 0.01631414303706298, 0.043245146216283885, 0.057584147960428274, 0.016912340877517577, 0.009722769459439142, 0.022078962328152794, 0.007999536549417123, 0.04676723161772375, 0.031342671793555064, 0.060040884681286356, 0.08131313152731427, 0.03530446102001494, 0.04881364398545796, 0.023712533743931882, 0.053357713660525705, 0.012343475809170595, 0.042402074116492466, 0.043243533601203275, 0.01598162257352904, 0.03774226004738481, 0.016914574023816856, 0.024542641720824668, 0.06709479246168368, 0.0346720362863233, 0.03986058508857124, 0.025446098786027684, 0.02667436947024638, 0.04231793851020836, 0.0063208894777832736, 0.017725744307221427, 0.06505772636662568, 0.1006757969697637, 0.057491206173454566, 0.01918539078155112, 0.06255718090781762, 0.061219212178501396, 0.050630570885034344, 0.04053018423878858, 0.03168747073129541, 0.02972160484792004, 0.03762983664449665, 0.028416740693031784, 0.053897254063837954, 0.04022150060101863, 0.03680634958248946, 0.0273724383629498, 0.08424457463045275, 0.019987971304104696, 0.027690188651303613, 0.024521062939217495, 0.04946627811859212, 0.040294581558555365, 0.06443033866103619, 0.06590908753775782, 0.044867735761668415, 0.02055461398295818, 0.006572693481200165, 0.025056458806859392, 0.02046114551053653, 0.06441035908797095, 0.05333367382146178, 0.04756652562308216, 0.016163246698617455, 0.05621183933990617, 0.05253121204253647, 0.07696852433465182, 0.06118312560682816, 0.04359914395477503, 0.07411100105532716, 0.04328237425896429, 0.026161148017572782, 0.09811877933961731, 0.024804827652030417, 0.046738127937480334, 0.04506880319827507, 0.017064476363180626, 0.07837590446034748, 0.02631784747204473, 0.0276442080540883, 0.03978375796108477, 0.08475779991356597, 0.028401893909059228, 0.034636122084433035, 0.040190987318994544, 0.012274750061483394, 0.06687751460459924, 0.06959542602060304, 0.016132683620878285, 0.013154066738582427, 0.04962027711313098, 0.020353242026401624, 0.05661409678718737, 0.03225225947737213, 0.02139897119524258, 0.02600536786860997, 0.04875544811629, 0.05877563301774283, 0.14251084727866037, 0.06127900534099149, 0.013793218681859154, 0.04230947706908469, 0.10032861358335904, 0.051724689997612476, 0.06737228482961655, 0.06422862388013352, 0.011928981064908929, 0.031288727712366855, 0.09061774434221369, 0.0340474562929763, 0.010322308911371135, 0.026771762228060155, 0.028372713620023384, 0.023751916408899332, 0.055973084207864544, 0.033259270562519955, 0.07411294691865483, 0.07006286988936125, 0.05452952557994474, 0.05330229102964363, 0.035247061882288225, 0.026002646341258963, 0.018699731257173325, 0.0650891206497627, 0.039142036750431985, 0.10726943912525332, 0.02875239828661565, 0.007057052571326495, 0.08305657144275405, 0.0138475094178331, 0.043240446266868425, 0.0414211483251664, 0.06459770588985374, 0.010938943615333449, 0.010601476139028468, 0.051918835829823255, 0.03953824210311136, 0.045221346625757795, 0.05502972736834519, 0.0281150495227907, 0.043020356867101886, 0.01728095557360399, 0.03363794782349179, 0.010311411310648246, 0.044565533227737875, 0.01834026365090282, 0.09155702176353625, 0.016343085838842298, 0.05860792104935935, 0.01315557593179326, 0.03341857088549483, 0.07982166559104958, 0.04148144710568651, 0.018872217868544885, 0.025401849547521244, 0.02424484227723893, 0.035820674046032855, 0.027418338520933064, 0.027331919972634604, 0.043595309684714006, 0.031005137284556707, 0.10542759521593971, 0.07542052877045448, 0.04005020334114952, 0.05914253550731848, 0.016913250606927662, 0.049116616437752406, 0.03010214178732807, 0.014375171627879385, 0.02858542750829891, 0.030817269542885405, 0.033846365873731916, 0.03399740393844343, 0.015170116169047693, 0.029404894523923437, 0.01769969348735627, 0.03255707054068485, 0.036823237990780223, 0.006821025669905207, 0.059100990559184746, 0.026397832796999046, 0.06467001692902657, 0.06355925838673307, 0.04195888459141697, 0.03999609455105759, 0.05443751458979903, 0.07635304163540564, 0.03422022444166003, 0.059091176972874714, 0.040129711776370966, 0.0793092140567399, 0.014506471437221814, 0.042502948743922096, 0.05121653238611837, 0.021447010653754397, 0.10597238332153329, 0.03607139930189137, 0.02641544324315844, 0.02470964888831781, 0.004459932153563826, 0.034519872072363095, 0.03094533263074775, 0.06590731787465273, 0.05822422974292309, 0.03944582891680541, 0.06503176364687181, 0.021740305500345367, 0.04489677432443827, 0.07049129690013586, 0.022665699493260156, 0.0633813995837925, 0.08022743172102398, 0.05884872546659843, 0.01511355110954854, 0.024625126407631946, 0.059739264374178265, 0.023235362473755114, 0.023570757682224917, 0.0786942293146445, 0.021091572669965607, 0.02276275900282687, 0.06605516518315961, 0.03382142588135696, 0.018034389640595165, 0.015725463839067567, 0.0130218188954337, 0.03529248706575844, 0.03927409881725907, 0.0344182696614054, 0.05719049751097637, 0.10467667583255999, 0.04323404177182144, 0.0393443682321137, 0.027096953145378543, 0.02553256521482141, 0.0319785151946088, 0.02649108868002171, 0.06410173673723495, 0.05277425343651445, 0.03483356592515784, 0.07277688191783044, 0.031162474507225618, 0.07191090378910303, 0.09139952940806266, 0.015582245616843144, 0.04024586219701075, 0.02276377023888692, 0.09202212140324617, 0.023320097543839968, 0.012022370055708434, 0.16046319847866414, 0.09060221573998851, 0.09076208296802737, 0.09560468561586835, 0.14598600596429842, 0.12498522237423929, 0.18415262892601952, 0.1658384237558611, 0.20202804957666706, 0.1221177246301405, 0.0817435120622958, 0.1154655073919604, 0.201669305923485, 0.0828270131962434, 0.05699833201604986, 0.0822289053711199, 0.14221570424495206, 0.09084923313029351, 0.23822210338567537, 0.13250535594359522, 0.19556012244955187, 0.1531078810653379, 0.15148478590192335, 0.13541209271117566, 0.20627844327640152, 0.1484961849787543, 0.18319034588433084, 0.16489204469948046, 0.16166491464020746, 0.15611690589256827, 0.12559117493970742, 0.1197279210112268, 0.08944854095217683, 0.13736990701046684, 0.13725798156472946, 0.09770353670201956, 0.12047778319327102, 0.15725148210842765, 0.1082862140009961, 0.10095808504810257, 0.11783118690213851, 0.10615157894790174, 0.18857136278623537, 0.1352042070920429, 0.12712987019650399, 0.13438930404522728, 0.1807057848500629, 0.2014899187751355, 0.161835215985775, 0.138825734536494, 0.24947785021316624, 0.3383143558617561, 0.1085438110655354, 0.09425849293268497, 0.14609486705833866, 0.08329815726967589, 0.12671963777393103, 0.11621286446649222, 0.20616140036332994, 0.09098082405304717, 0.08777464649850324, 0.126328932932548, 0.14884974987756822, 0.14587417244911194, 0.1412576346868469, 0.08997109718620779, 0.0990711645253243, 0.1296136344993307, 0.1053592065469392, 0.05986665713510687, 0.21121971038801057, 0.20598585897636032, 0.22861618819015644, 0.08909293059860507, 0.17730887438501083, 0.11286247852108172, 0.22487266890464291, 0.1860410203376124, 0.19590411124931228, 0.15747847396039194, 0.11633418215018128, 0.1487537284171389, 0.16424221827858881, 0.1796591402061524, 0.10720206169231285, 0.110119485386437, 0.08992376061336649, 0.16274687593742726, 0.12406769418908704, 0.1174243099446739, 0.19446665451170939, 0.16891224429972712, 0.09729231602602428, 0.12675116995289443, 0.08294746520057802, 0.10399661958217622, 0.08824060415668834, 0.12366689230886199, 0.16867437399923804, 0.18570034103768487, 0.2549755576276972, 0.10722840745602885, 0.16900547720011205, 0.15153568478361254, 0.1668696087454596, 0.15533411725153848, 0.1469369202611908, 0.1322008666372107, 0.1406552291084682, 0.09743405761377466, 0.07608532454938659, 0.11703061736038617, 0.1686888837045239, 0.13416065744334651, 0.1170285642447491, 0.12820591729494835, 0.16132877058079167, 0.1195832759502434, 0.10088205848249698, 0.21774622791957474, 0.17746455877298312, 0.2027166400465273, 0.15905316768875047, 0.1505444589401445, 0.12608768418431282, 0.13293791982916095, 0.1456126453535211, 0.09936700469904369, 0.16709813277327246, 0.10138646609360173, 0.2819611120127863, 0.1321345387447265, 0.12194005351874138, 0.18223653577508467, 0.1562663390030784, 0.12284028343856336, 0.22461569237132228, 0.16976583478671892, 0.2093628051901056, 0.10760312404243216, 0.07765676240406691, 0.2031355369235239, 0.1252073112634882, 0.09649064331766098, 0.14700007654966848, 0.13861360479026072, 0.13468873717131155, 0.11417662574639244, 0.11849327072981866, 0.2164344249233123, 0.10256431861630372, 0.12063476226983533, 0.08707330832558294, 0.20071131297417227, 0.09526926167910138, 0.13343474316981532, 0.19863869273854842, 0.21522535431769588, 0.08154484248089214, 0.11038303495414796, 0.09614503041150109, 0.11538760391094031, 0.1371094064726945, 0.1400016028914721, 0.18336726622956415, 0.16841166712824376, 0.1437166849932363, 0.1649848792341448, 0.19140103110863319, 0.1657547363110127, 0.15348931624283715, 0.12260579158582034, 0.0773463512380277, 0.1500437438728348, 0.13571396199685914, 0.23290074941131378], [0.025181650980225494, 0.01833747700607825, 0.04517156623243805, 0.049180182583269574, 0.022221161653437925, 0.039707187473052935, 0.09858994639568752, 0.00503047086831723, 0.04122736255428003, 0.04360471341398455, 0.057149910172747995, 0.10452171922811579, 0.03306510557811106, 0.010747388117916642, 0.036388751224524556, 0.02528717576135551, 0.03023366376216854, 0.024188873808710806, 0.031339180347840154, 0.029747895070261536, 0.05980973297189321, 0.1176930535885115, 0.059611940561162854, 0.010273961102469795, 0.0474839375144051, 0.0603385596355844, 0.041019603339654785, 0.017316442681476474, 0.06002156011339638, 0.03338061122884674, 0.06103720117901122, 0.04062460074501653, 0.039310062814864426, 0.0380440948591117, 0.06616285416267573, 0.06922198114015403, 0.03896017513808705, 0.03658217693408651, 0.029724864552037853, 0.04255042321258976, 0.03258215608976541, 0.026997511102367314, 0.0068017547281699325, 0.01803880230703902, 0.01775938131275677, 0.02188289361525207, 0.053525130685058334, 0.06987818141257571, 0.04751760707867723, 0.045542774136148156, 0.03571792633362836, 0.036312494832541675, 0.017501270969308192, 0.017222288560362595, 0.021446399698634783, 0.016445293459260178, 0.018922998006605816, 0.03610495012253523, 0.03459186518504735, 0.03053241890043982, 0.012494155727777512, 0.11052995529626647, 0.024388795943870663, 0.07198886855715705, 0.04610630841324887, 0.02542533397284006, 0.03687563074392177, 0.0034041899761500503, 0.03160949830236214, 0.03877487762140171, 0.039655595281792265, 0.026581058045849208, 0.0267996363371851, 0.041921422891919656, 0.06460284633982567, 0.07954745207943263, 0.011952944295180422, 0.04511102996466141, 0.01094829180322948, 0.05587440442233797, 0.02240399045178727, 0.0555462813034894, 0.07220984661891576, 0.03454799132962381, 0.016149650553181287, 0.01564415509722406, 0.007048150150841403, 0.07918178299141508, 0.03995386395423163, 0.024932053788835486, 0.029265958733195742, 0.04661092286809318, 0.036266077565209526, 0.07660830979265514, 0.03779427358700383, 0.03066492529826299, 0.03202247906536345, 0.0433204603201199, 0.012511711590172303, 0.03461211288888608, 0.03855304920204705, 0.04317779559642077, 0.010228784897574976, 0.027672806116301688, 0.05930922474832304, 0.10231895597591516, 0.03379626755392359, 0.038151925564893795, 0.023895914125586712, 0.04497582693734477, 0.04584248688432478, 0.06515660533501257, 0.03907349486384661, 0.021753489873522235, 0.025455858746183016, 0.06357350379168507, 0.06172887898320633, 0.05078998229075825, 0.055497477672273116, 0.021559353617410508, 0.06752904174068282, 0.05005571765885238, 0.09392777277577309, 0.013042778103432108, 0.10068342720548953, 0.04339334975567557, 0.03337707956351581, 0.023964051900792028, 0.017072656266992132, 0.03592378181976176, 0.017508805444043492, 0.0365760367393734, 0.03814120416439349, 0.05454682001483537, 0.014127318244127017, 0.03910205845210341, 0.03407929107666977, 0.023328836691836198, 0.05807974172996418, 0.02082999194822004, 0.09682281138074976, 0.01605757636078183, 0.0468768971040845, 0.04058070007651564, 0.09341563533751235, 0.024634340530141227, 0.0099926526590641, 0.037012113138071956, 0.030616723046067263, 0.016620545648038387, 0.025081513712422985, 0.03000348689965904, 0.04286264234613027, 0.013935965760010145, 0.010854482421681527, 0.008368644893409745, 0.026142263950239268, 0.12284206842342693, 0.04120814523869946, 0.003348099412358997, 0.06716077561460196, 0.04277301005898945, 0.030423391182276032, 0.040948767019736196, 0.04534297840549581, 0.07739334307130306, 0.030354832058712363, 0.03427722904410574, 0.016171219758689404, 0.05590276499729484, 0.054735783262238394, 0.04835393377429536, 0.022111716417355404, 0.03558869496168148, 0.02533391861605548, 0.0265592398617657, 0.02322712319812948, 0.01571952953048411, 0.018988326154348832, 0.0208885804374492, 0.04981498985040573, 0.022329216439937873, 0.08765050195037358, 0.025444850062711105, 0.02839529214637174, 0.042300398927181966, 0.07068398333485089, 0.05262047660747363, 0.0764477990507599, 0.0545178312477806, 0.019529716659998222, 0.04334895113002389, 0.02318287012918342, 0.012344134644785476, 0.021353381302868648, 0.04900416239134727, 0.08600826224973125, 0.01957204301781472, 0.0903198816963742, 0.0032227892135720583, 0.04509239870634291, 0.011082323673631878, 0.058899942274776206, 0.01647848996423906, 0.04064785151351844, 0.023512000653652415, 0.011408977818885639, 0.039904527891907966, 0.07357506126525902, 0.027149160122198444, 0.03742332998362761, 0.02078930310334169, 0.03614332346666244, 0.027216696518383203, 0.059296883071862885, 0.06821588553007572, 0.05148776964614949, 0.047050841197732, 0.017839485381339348, 0.027175590155586123, 0.021421919359014403, 0.004104489860530462, 0.06780081909270057, 0.0197881315233967, 0.03580188573968988, 0.03283041837294737, 0.03402743458507523, 0.03548340383736837, 0.0641352684056807, 0.030516080160234726, 0.024969915769273238, 0.049945849159191695, 0.05251115969111843, 0.03668914196051417, 0.05416445404050812, 0.04515183563794821, 0.045675437581995805, 0.03662368740826365, 0.025632388386574965, 0.013771042351671045, 0.028189386864523255, 0.0812329221216421, 0.04038217222137798, 0.01800179642985665, 0.03158625327951966, 0.039155221123608856, 0.05797058569207307, 0.029194879180361188, 0.047367346593208855, 0.07682735731284465, 0.025040072186159033, 0.09793772211959285, 0.05404396756221691, 0.05240712495100114, 0.04727729295770969, 0.0273500130541863, 0.06376069354554338, 0.03069693436695924, 0.0586156968417908, 0.026334433275605404, 0.029866021997745962, 0.04442764889268626, 0.04114343379173548, 0.0658070522871229, 0.0139849781501858, 0.02973165783670641, 0.049215510727897774, 0.031896762121769215, 0.029954497492121115, 0.021770592786431796, 0.03777464258394415, 0.025426799115995248, 0.031242046144700823, 0.03458235037302779, 0.030247388227332025, 0.02195084561413575, 0.0022809669439260278, 0.03492964484218148, 0.023211893370194782, 0.029086971865786664, 0.04177344151802602, 0.028447698306051955, 0.019695794945883176, 0.04987437698629595, 0.038035675552823854, 0.03926839529266281, 0.0075388797408630775, 0.01046546967700124, 0.00932156251022412, 0.05083673280633746, 0.015596187459455143, 0.045750081358898076, 0.02418642424257292, 0.08536047362271817, 0.03876194222680023, 0.019690309756345326, 0.007332564601975103, 0.012036155807905862, 0.014272065769370287, 0.03352950807780989, 0.016796659685731415, 0.06374351019340177, 0.054761090976816994, 0.05369912840486054, 0.07405746683117843, 0.03653955563241917, 0.05081776063889266, 0.00880944135133177, 0.015108850202523174, 0.043297650052174445, 0.024017314163727627, 0.04345082167175509, 0.029212269376242356, 0.03411297596270039, 0.04213406591706219, 0.02716186760564245, 0.04617198513099744, 0.024453672099738352, 0.030278297959856933, 0.057657723044676173, 0.05044899272522138, 0.04796545441833235, 0.021899713075629646, 0.008034208252455198, 0.037128190780358936, 0.01557398144335997, 0.036077803796938354, 0.03483958354580306, 0.06465462622262778, 0.019013329348977537, 0.018895685056885405, 0.030400921823456887, 0.012462522999774064, 0.022335207247505748, 0.02637329308556453, 0.0058217673945511065, 0.033189989401087645, 0.05750221485692648, 0.04691011084604168, 0.006473485573810796, 0.08601145683637551, 0.052620338711647265, 0.07375435648305763, 0.03491369489159796, 0.02543253711454811, 0.02374294551930601, 0.05498248272605481, 0.04230805980642477, 0.006739939572364693, 0.03136944465128885, 0.05321886405468949, 0.029520094995537115, 0.13411717429276437, 0.06646899821897669, 0.125041437906123, 0.1326840229692959, 0.13127463569323863, 0.0890654816682781, 0.21238854605584376, 0.11955592661134659, 0.08861585700463864, 0.18235730187546823, 0.09625281898244735, 0.13593136242801143, 0.15676979666515706, 0.15211284010400697, 0.12719463526962266, 0.07668613666488279, 0.1190118509675226, 0.14386624067781434, 0.06719816070530685, 0.1255498674788302, 0.12382167271308361, 0.203684285703686, 0.1859454125646622, 0.142152946322195, 0.19319107215250694, 0.15055890735839644, 0.13345214868745497, 0.10593525103984341, 0.156736854884413, 0.11516263453109611, 0.24872397373039878, 0.12375486218520712, 0.17012983380306154, 0.16292862263658356, 0.1471257915780429, 0.22622113686896142, 0.10384992140555575, 0.10522106557243294, 0.13971289499632775, 0.18205702605266727, 0.1415798359460408, 0.10148241094523862, 0.09648253044654286, 0.07485766865072713, 0.17515748498901246, 0.11192972050799478, 0.10911486066517331, 0.14928677239485327, 0.09180602332156512, 0.13125499319886008, 0.18305264924082065, 0.2042155676791745, 0.14097108715964904, 0.08488441892569104, 0.07405331463462884, 0.18537965663258107, 0.17468293948519617, 0.08869965170179644, 0.13076379294356993, 0.1398235640578693, 0.10174496459864801, 0.16281839790603808, 0.1653683675272811, 0.10024856505615097, 0.14160485637764778, 0.21101343355351881, 0.17194218332729033, 0.14430490262325735, 0.27959481963226873, 0.20484486294369544, 0.13183135178781327, 0.08134600436014515, 0.139015770306991, 0.16957042107899345, 0.188938548728343, 0.10652345334810596, 0.20292251851529847, 0.3260930164927437, 0.16363210585569182, 0.08177482973664038, 0.16079591046417915, 0.17538122862817782, 0.13780703678006126, 0.22789367534700902, 0.16099285634775318, 0.15225714042542443, 0.15508147677586925, 0.2647118456661701, 0.11721166691953137, 0.13475679642250463, 0.1255725973075436, 0.11506510387745597, 0.1426269555644643, 0.15320762571307922, 0.17051505345490672, 0.10493732958791718, 0.0916602444504538, 0.12385588619978198, 0.1236105695246689, 0.15470381075095746, 0.10604366780288758, 0.13638747585636957, 0.08971406702673243, 0.160068326118973, 0.1870876496597644, 0.17485236749053004, 0.12812072831776836, 0.1112891790727454, 0.10079979596118774, 0.1662232143984687, 0.09888716552767063, 0.2433684522346143, 0.12537155285357468, 0.11555426633886753, 0.10479217890890376, 0.2076110532206874, 0.16111095646216025, 0.1818003865980333, 0.10814512358798135, 0.0917050759157827, 0.1264566474504048, 0.17403910387187235, 0.18941882456983292, 0.1590656855654332, 0.28111669925912736, 0.1615833262762716, 0.12456169832618007, 0.18160953877433655, 0.13911494804966834, 0.11820288510212015, 0.1408189880631624, 0.14476441748199925, 0.11860467523576752, 0.1356342428874585, 0.08947130142440719, 0.11785334982578793, 0.15481045019001732, 0.12365280395193447, 0.14891909615647408, 0.12542405285902564, 0.2453820224130346, 0.1607615744034129, 0.11537755283737376, 0.10984314215039054, 0.12718196417535507, 0.09166278786236241, 0.12417356754022262, 0.11742313016927051, 0.09585010954329083, 0.14997651199659995, 0.08290267203964534, 0.1161062480100701, 0.1604366152276916, 0.06006389796253174, 0.13702161279657196, 0.1702991698778445, 0.13304725589771427, 0.25518871393174897, 0.10205690794053579, 0.0837002921428892, 0.14251213430637313, 0.1668501347904244, 0.11701456015749324, 0.09294337277571041, 0.22004850599313938, 0.16084693191993624, 0.1930811232136142, 0.15928921469997975, 0.10030399917835191, 0.1867511838434204, 0.14838816658143075, 0.1612084334896457, 0.10895150773707898, 0.09333063022143419, 0.1729051558481109, 0.09946415996960095], [0.0391606335347939, 0.05029484434353729, 0.01880712337761877, 0.010122571594923014, 0.0725323619741586, 0.0711745324154054, 0.014429413525748157, 0.034169471116676446, 0.022122778726982015, 0.04146224511186442, 0.053652818389837785, 0.03148408396349799, 0.0462340995398981, 0.023289634057530956, 0.06612550737636705, 0.07001805374579084, 0.043443474888561234, 0.07803665774483835, 0.05902410597510396, 0.02485039647698643, 0.07977594546372853, 0.06223376156882413, 0.017566313749299418, 0.05600474279133543, 0.017734611774944974, 0.0461937765020036, 0.02695540307960924, 0.043900331422205896, 0.07378000510676254, 0.013080356631337876, 0.03784617221343421, 0.06710293597631878, 0.012042364950532155, 0.011707301075089604, 0.04211035932624533, 0.01895354959302612, 0.058462655457157287, 0.04636620374156102, 0.019235521660096223, 0.08970674322617632, 0.009674452294054772, 0.01903382028573223, 0.05203781311490363, 0.032277180317548976, 0.0019755877785369636, 0.0012462136604177256, 0.02802666595896646, 0.01119173539336771, 0.0380440948591117, 0.056353745636560267, 0.021628044891141115, 0.013720845398042473, 0.02847119996834907, 0.04228401230648161, 0.020758602129776153, 0.031202546651324922, 0.02289216849021614, 0.05586005176507658, 0.039449502308402336, 0.025577019381847595, 0.05484183281359654, 0.06721224906223436, 0.03377050784746966, 0.016914321214801843, 0.058385046919988054, 0.019303508132936496, 0.06618754517647528, 0.06951449649228204, 0.019531400138211828, 0.057091710473140406, 0.06840546164781817, 0.015084441683645693, 0.04234174469245538, 0.02092815462439772, 0.05947152047508186, 0.03874265596330647, 0.09054121215857806, 0.09050626322747239, 0.053115112767104185, 0.08869344638960977, 0.01470926065643829, 0.04171871602715504, 0.04446621758923416, 0.03523936652908883, 0.06924212925256261, 0.006209487844664123, 0.019670688329384695, 0.04188352835274512, 0.011432231460217268, 0.05511093268831892, 0.032658960234614155, 0.03043859228191357, 0.10962286888952218, 0.09147187875163171, 0.07272038293341476, 0.032288844006196145, 0.07367812307371248, 0.0602672751542301, 0.03677275662700977, 0.028076113104039145, 0.022254545849958257, 0.06488585454081336, 0.015279135268722332, 0.07679917293811038, 0.04115832271054387, 0.015971704607739324, 0.09048766261267085, 0.013167666714458216, 0.061070732847456975, 0.08133363970104726, 0.05037464389216997, 0.009634409835862537, 0.014734473567636264, 0.026209005530202584, 0.036608407784613876, 0.02009767509486166, 0.03650748336146917, 0.03657082351104867, 0.03576425550084922, 0.02152497350658861, 0.050363796087162155, 0.07970338161554068, 0.02285197185682914, 0.03065074118034494, 0.0900657243666149, 0.012658507443003118, 0.04638809853443696, 0.04488424112599704, 0.05950274238843591, 0.07702647888612363, 0.022062907040479685, 0.056375866425373865, 0.04551638240715669, 0.05060781807368321, 0.05118442181077215, 0.1283678759430205, 0.028257923005449197, 0.02416915853597945, 0.01459975317571192, 0.014858303062107055, 0.007998091516069948, 0.04338342125617689, 0.11245231504642195, 0.05792843170403954, 0.06536921005575888, 0.027253110592644063, 0.007462865145381301, 0.055823865601973194, 0.034786865205293706, 0.05938251638003896, 0.0839417094304677, 0.12091607741651036, 0.04249446815060031, 0.052518579252665086, 0.051878673670392846, 0.018701995046989574, 0.03888378468071742, 0.016117135866455013, 0.019614260208102006, 0.019079672563220226, 0.07046547973708761, 0.02668560031921633, 0.07177930520547014, 0.03175171294940576, 0.016708450406909953, 0.04807665591098128, 0.023405560397452885, 0.03252495230445939, 0.019207094052445986, 0.09485647052286134, 0.06185312312276614, 0.02391573473540766, 0.0462828150710031, 0.07671090428747478, 0.012656434217558033, 0.09365742800817375, 0.013182061506555447, 0.0411029000796618, 0.036170190170166955, 0.004130699164834955, 0.01704747112648141, 0.07018554354867629, 0.04345084848483244, 0.025081755030119134, 0.053125493258478186, 0.07551998230478457, 0.04442387207921955, 0.05254261143084976, 0.022219288568463058, 0.047812125750727234, 0.05083548791346051, 0.028493523770462603, 0.022975478636761828, 0.08122981946554877, 0.13425928360271838, 0.01453239489496956, 0.09974015080520224, 0.057597726868886145, 0.04439821962507502, 0.04726280240462192, 0.08218320056555733, 0.030571121662374467, 0.009128670189379445, 0.036969415227612185, 0.0012018161120771942, 0.019756507413882404, 0.019198567493848743, 0.04519314309882541, 0.04044082008242127, 0.0448598756995653, 0.02659764576462969, 0.03528033308083973, 0.03276086525030194, 0.04574825806963829, 0.01670683204616991, 0.09878990300480398, 0.028453882550820712, 0.00972331338186538, 0.051398612333521734, 0.03936443207485061, 0.003826421729641997, 0.05431328577199771, 0.07105087816354728, 0.03597145164085012, 0.054811476579596924, 0.05886492439575734, 0.08622673520397756, 0.03567414440875573, 0.054156436930380525, 0.03513194568034622, 0.06748538238987808, 0.01562276592237815, 0.022341002702652928, 0.03559901799646116, 0.03620018634284216, 0.0392272831842063, 0.04061919982515035, 0.03205589390540075, 0.030680260463287274, 0.031633974811542905, 0.04411842133249006, 0.03544927078990206, 0.03328295417069908, 0.03465975206645747, 0.06876780591424435, 0.09944252564661926, 0.04396664782337124, 0.051326833725456274, 0.01519098727693481, 0.04817812808699185, 0.03857435793766091, 0.004731095677632238, 0.005916161396946278, 0.0266877242979864, 0.018007003912521947, 0.03777656163419447, 0.042533864222106435, 0.020128441185900764, 0.08244265922375264, 0.02565002181537209, 0.02533959149713478, 0.026611056133744218, 0.08393144385228235, 0.038659642675831433, 0.02709227617860081, 0.04706579906445357, 0.04830160613862738, 0.003568709512511569, 0.045916069629451925, 0.08495694446948268, 0.0581565075704167, 0.04636596242386488, 0.06536751700144622, 0.02204779404095344, 0.017810352972798774, 0.014754076800008696, 0.02408907170437517, 0.07062442765961732, 0.03066248913866378, 0.05755899346343452, 0.06809282882679855, 0.04403240498035185, 0.022141082482712886, 0.009181255422111963, 0.04867006378668932, 0.06401691931269823, 0.058419057393386487, 0.023762649300718502, 0.061803235477136995, 0.031613196591816606, 0.04377840086817742, 0.03230113588694123, 0.01101979845008182, 0.04688758786106783, 0.009471633388931233, 0.023812919990309787, 0.04586449659038936, 0.060640643425886674, 0.00427803032160286, 0.020912007406173695, 0.03347587426223102, 0.018327615539272948, 0.06964057924286013, 0.037136299821037444, 0.0296341693179021, 0.04987898117472088, 0.042716725579192566, 0.02439883935655798, 0.050489829042025154, 0.005860012418950998, 0.0497574987821281, 0.07728452794253826, 0.02849996082424637, 0.031702668000493324, 0.030949293305316282, 0.010893840188791436, 0.04661702092797045, 0.017270565506130937, 0.11343041780374705, 0.01109567754376199, 0.034158707581340306, 0.056789829696138064, 0.05635790166354949, 0.05740448885086564, 0.018614515466915987, 0.04327069524855864, 0.06246225112268041, 0.0601855565553471, 0.014279284232836819, 0.04301453076843773, 0.051330583725845626, 0.01104092619742357, 0.04042365205203814, 0.01706489196587955, 0.031206597341224555, 0.030473137101639184, 0.03924316035643701, 0.053846424130061944, 0.04827795317396522, 0.02190144251911871, 0.017315446767174912, 0.039687690535379995, 0.015085361946764735, 0.0313530235566319, 0.03794779377659002, 0.08390275385951804, 0.04088018299831499, 0.045081661984084115, 0.06545101292431355, 0.057557442135387854, 0.03119259325396871, 0.05409415781257614, 0.06325670728279699, 0.11791218537837268, 0.21079892893472027, 0.09718677975357541, 0.13712756275649995, 0.3603254408845979, 0.11704786966044096, 0.14897630760265937, 0.1346076544254057, 0.13950942204363886, 0.09861540349741137, 0.09612696605824655, 0.15014837616153304, 0.17823251595179881, 0.17741747500915683, 0.1339290077768026, 0.1514149952920214, 0.2614217125360043, 0.19815910637619036, 0.12518560799259332, 0.1891010206553244, 0.15294773804564632, 0.08293879308527516, 0.16071148757492343, 0.18534060147020126, 0.21153320888838462, 0.08901901077479125, 0.09952328663559691, 0.14939687455133085, 0.10230407854842563, 0.16952122291249616, 0.12712979358771156, 0.07188223677897645, 0.11149669696967449, 0.10533729643230477, 0.0982254800657111, 0.11849919258947335, 0.09515387351594626, 0.08458310122331304, 0.1839678178751661, 0.11381143163288794, 0.13045461517908882, 0.20222257462240037, 0.15745127783908, 0.16266789227243394, 0.18949498903126488, 0.0990916573772988, 0.12518269685848107, 0.1268910116425926, 0.07982014873695951, 0.17877345063513328, 0.1094895389471804, 0.11403701388307157, 0.09716915973131696, 0.18780810938727474, 0.1544279271676656, 0.1441834776872589, 0.11482400834680566, 0.1864578794207304, 0.11924710124731065, 0.23046173996502356, 0.1274327124138513, 0.10222509488343232, 0.2216247931843804, 0.1918097696597538, 0.1338934459753575, 0.17652470678571733, 0.1315615969079156, 0.18769717985583892, 0.18230312413746314, 0.16596553306425774, 0.09396943263709547, 0.19760704809619536, 0.15572705906966042, 0.1253665426385499, 0.08878221299739615, 0.11048218205330834, 0.21362982299779693, 0.1295814588065109, 0.2212191343067154, 0.10206424706285039, 0.14082998908575506, 0.13416461045703582, 0.18229023853857673, 0.15270225283118988, 0.13216133650031783, 0.16016018006109423, 0.11584645227318811, 0.16039907691940186, 0.11735698613788813, 0.1252380773545273, 0.167076253302155, 0.22348171370404385, 0.21508667708164264, 0.13191683187840447, 0.11029521829538769, 0.14018140372730073, 0.1588832187436281, 0.28067239890656165, 0.07352174920660835, 0.12860218393466166, 0.11570534653841488, 0.09376136315686089, 0.16568568114551807, 0.14593466275161313, 0.09378449135129491, 0.23743589799250328, 0.09533219580208102, 0.1407274099126939, 0.20595535335521545, 0.12461684133496978, 0.09003313498631602, 0.07527974479260945, 0.1279043774270723, 0.09921889692064255, 0.09314112305160492, 0.09834713482808682, 0.12299482635552846, 0.12762876197455392, 0.09768142740452483, 0.16238178907623216, 0.15633878027719839, 0.14243699640275972, 0.11682827055694596, 0.16633135536986013, 0.06407755900234466, 0.12796607814849387, 0.08941855627082049, 0.10581987053756753, 0.11176358668073533, 0.13416241944557236, 0.14995348339359607, 0.14472669531260768, 0.14997766112848637, 0.13739770068035972, 0.1716315193522361, 0.131260953362911, 0.1893949839136293, 0.12374895564731091, 0.13754909497595605, 0.0967141647913283, 0.10384493417316869, 0.18906763454358425, 0.08237276902242054, 0.12291048007506518, 0.11019479182939376, 0.15108574602392413, 0.20512327461713747, 0.18651541262384386, 0.21160209551453593, 0.31415512965571496, 0.2120705889237504, 0.10911950315799444, 0.19931557738492567, 0.1580351594114496, 0.15576193139197367, 0.2033490149845039, 0.13930947309540165, 0.13500356866467383, 0.11286605615168811, 0.1449892489660171, 0.1576953994170312, 0.17632311840932216, 0.14393194037820065, 0.06839449892962171, 0.09531469069301121, 0.11774792846652771, 0.16908374074245655, 0.08784091310395349, 0.16930627396270154, 0.1549567576617964, 0.11807258120707928, 0.09447946333356443, 0.13943491233212335, 0.1196436436786767, 0.1301698143323583], [0.03747472299202796, 0.04851488501674706, 0.09559174639082725, 0.0035383791339793995, 0.05581125962517916, 0.06329914472336251, 0.019314112705028346, 0.036205874545679945, 0.048324232545471, 0.025784031660746665, 0.024734111990959897, 0.04427309831484191, 0.07217481341813842, 0.04530271282419563, 0.020815736967168992, 0.011236157959267017, 0.01576573516602718, 0.01158655316929423, 0.040791014194368355, 0.04485793366667725, 0.07933983459107338, 0.07027349044238368, 0.058686755327207435, 0.026138709302270607, 0.06251087089279486, 0.04399443000194527, 0.05183594511641611, 0.07073867435176527, 0.0629700869772463, 0.04287783386966875, 0.04698511468426836, 0.018417692157409845, 0.01570713901591878, 0.04516502001112507, 0.0485252003906475, 0.013145937588095907, 0.010298022008951633, 0.047385296033274744, 0.03946388943962032, 0.015603707570041862, 0.08504994754349032, 0.025482049377094355, 0.07990159920506901, 0.0340561015952018, 0.09265635793487872, 0.01991483480519345, 0.02447876339447835, 0.09824857761662814, 0.09840698161673161, 0.02584780081956377, 0.035095353490642966, 0.02614789661170254, 0.005426531621900898, 0.04155989450913283, 0.0295539541665705, 0.07208411626878285, 0.0450551170375078, 0.022676669872335853, 0.08421610680318649, 0.0172207506388546, 0.07171169794615238, 0.02170092666581754, 0.013259576197953956, 0.0514050857764819, 0.024283623563185818, 0.020373692743540294, 0.05356276092389899, 0.05347508982184434, 0.030631159973000328, 0.022783719168435183, 0.06673805595886323, 0.08800771342770708, 0.038774463933922594, 0.05634058041558151, 0.04522636067122222, 0.02068295669291289, 0.08369666854700736, 0.06916619461750792, 0.15340679325163364, 0.06512839031676132, 0.046780013794740366, 0.0410279268849521, 0.038321353570227666, 0.08339489119187479, 0.04522826056927443, 0.08308418125154511, 0.0618835597959978, 0.04884103928963023, 0.02069274155092576, 0.050652074973068895, 0.07749907852661225, 0.03862514956704071, 0.03052359739799173, 0.038040693428727894, 0.0791019489688258, 0.026746410463425904, 0.04306400089614815, 0.0455361053407673, 0.03541771562830095, 0.03613729818513797, 0.04278542451380242, 0.062057561346239624, 0.033453010368130864, 0.06568744297950499, 0.010749629882705069, 0.010202202604212349, 0.01737666293798435, 0.04156696933111356, 0.019907198823808182, 0.029834317448999614, 0.07062978261420805, 0.041841305416798404, 0.006891838049576168, 0.02804258718125282, 0.04837890441018728, 0.028967188273165977, 0.023971222483763294, 0.030668403337439223, 0.035296191100872336, 0.024947607288918188, 0.01438148514998536, 0.059995815728700934, 0.07892407867456637, 0.02781500352636701, 0.03927068206511679, 0.05366154796173496, 0.03466843184263956, 0.017669249153245362, 0.014405315272480011, 0.025941656166387182, 0.05352077930564842, 0.07149628168272396, 0.021540523176231695, 0.04773472788773718, 0.021102870551628933, 0.056783111105042125, 0.07021774988501303, 0.03767439614861243, 0.05171500281580994, 0.02368872756168487, 0.06054510460084966, 0.016406943097770695, 0.06827076040809194, 0.019883660772334666, 0.020273488443044406, 0.029986692337139003, 0.05305663727584386, 0.01726625243111724, 0.08409160985461167, 0.010862883533381168, 0.010095034564484753, 0.038971697100468224, 0.08822247085552062, 0.05456403018005433, 0.03322068654421357, 0.02247421581658625, 0.009324078151445475, 0.09240320418030025, 0.02127377327621704, 0.016996108761598027, 0.06592632451605412, 0.05180449720712439, 0.07732148402400556, 0.03796440256278842, 0.07659883328503178, 0.08510802466903003, 0.08535380865777693, 0.0618062078982832, 0.032327899168575966, 0.08377431921901242, 0.04096642534639086, 0.039880013078330986, 0.03564005732656487, 0.07590550073092023, 0.06676000437789387, 0.10462255172070958, 0.056463085535553195, 0.024134374313777494, 0.06522264977496478, 0.03869737633654187, 0.012671357610323017, 0.07837169863764318, 0.02536466363967667, 0.036347665929145394, 0.0404792700353409, 0.005727932157535707, 0.030906993760577137, 0.04649355053721417, 0.072870513183936, 0.05073340669755013, 0.06662535676432234, 0.02279744746403829, 0.05595757858827711, 0.08353655617083273, 0.05214780035819258, 0.11533306611161079, 0.03759293418918406, 0.024470746284350756, 0.03246596353428979, 0.04405333067200357, 0.03208692812721335, 0.07067626882945338, 0.04812889927697759, 0.016472958809425755, 0.05391033118470542, 0.03873400683064134, 0.04162537587446071, 0.024150944795579683, 0.03458087182333393, 0.024729383313247276, 0.08426772580752451, 0.02813007059176603, 0.02037974866858173, 0.003163021427744459, 0.032854914034326235, 0.05225922018589993, 0.06738519341114067, 0.023419711956634157, 0.029432008290783535, 0.08728725370019676, 0.05515832671775453, 0.07257746157026099, 0.07310384824391335, 0.09487030607077385, 0.08566380613633702, 0.09760086559840749, 0.05793131602507445, 0.02002857013365194, 0.023563380255514098, 0.03812278741069379, 0.027761775737388, 0.029586330957470403, 0.08036865236898584, 0.02220330797436257, 0.04885498975073138, 0.0369302949477588, 0.040255622157166084, 0.018276890942586527, 0.048769636064647674, 0.054218731369943395, 0.005279701295113492, 0.02679673860961151, 0.0474786936425634, 0.03287451439386895, 0.07527776828576481, 0.05797689825656915, 0.0467858896891196, 0.02027251168094095, 0.10058967336531609, 0.004866710956013131, 0.04935650537992197, 0.03501034071368556, 0.021706369720519553, 0.05854279974535589, 0.05756723656949978, 0.02512618621450759, 0.04900993103341711, 0.05814454510747906, 0.056310442516640316, 0.033900800251191666, 0.03552847662039342, 0.02868369360634637, 0.04034355755955462, 0.004431457144223274, 0.06005270158751838, 0.01191352332581676, 0.07883788612220557, 0.03352542099873385, 0.04621922211240857, 0.048645338298933166, 0.02919742450748961, 0.11873815839569415, 0.034602230354662866, 0.03811630630685437, 0.05018187701822289, 0.0955435211559938, 0.020555313038189086, 0.024461114643922737, 0.043227897746668714, 0.0605108757923928, 0.018694682737752315, 0.07967430857881423, 0.04800168654671119, 0.02181466582471565, 0.05701797451042841, 0.039985706398804347, 0.029912291793152693, 0.07065805891949324, 0.009660986383565733, 0.03704715783016817, 0.018886455612617637, 0.07097356457022891, 0.014501479416785222, 0.03383380586221334, 0.057247942613978545, 0.04741284072459225, 0.043845525492102876, 0.06950927177263845, 0.015798202929868093, 0.022171251025171052, 0.06127193051901075, 0.0493145773878261, 0.0406025450736765, 0.04375934443106094, 0.02403578454358203, 0.007473850846215482, 0.09568816621697719, 0.07382451481516324, 0.029828006799723354, 0.08827134726508971, 0.01619936774424728, 0.030577664053247824, 0.045678570881606116, 0.019833537554668806, 0.01947043869163721, 0.02919515497201393, 0.08198169645883384, 0.033912598005225586, 0.029861561450806838, 0.023691778506843314, 0.037671986802090565, 0.05022049168004625, 0.024196843038343137, 0.060596355882984024, 0.0078895449968836, 0.028296133555892496, 0.0303997612002516, 0.041434562524720546, 0.033710607432670174, 0.10049581227283325, 0.028685018938455372, 0.003585004202661015, 0.061112005834377585, 0.05229943597148504, 0.0301454947029631, 0.05824225579178142, 0.08823059904839724, 0.10514991132602577, 0.04054420747824254, 0.03801393014709315, 0.10555699512722994, 0.04242657743875058, 0.0396696683169613, 0.020495908665320566, 0.11136047121497894, 0.023840931995261102, 0.07486729071505609, 0.09929253329192439, 0.013942884491576303, 0.02894944376161983, 0.029585149266847202, 0.06133029109708244, 0.0836760761036027, 0.13007204619146165, 0.3111763346579767, 0.09225980784263342, 0.17273965021294935, 0.16207942949427714, 0.08685412290956705, 0.19584080174324975, 0.15101854479120624, 0.13333112211717715, 0.11863694285913823, 0.11875896534371762, 0.20252927026200682, 0.17481115196020375, 0.1522961496225288, 0.10361997245420372, 0.26813852630795976, 0.13216026397722383, 0.27769387970047615, 0.19246449904336085, 0.17484535012514363, 0.1590385507311552, 0.15770419410640196, 0.09234838292843874, 0.16196125277107762, 0.16420256556762805, 0.16772523702632997, 0.14692156785918822, 0.15917148230777634, 0.144367017032158, 0.20122100659195455, 0.10028506914574294, 0.16014688077472872, 0.2162633268463035, 0.20673034322117606, 0.07730299832239267, 0.09404569668995758, 0.12616903506099217, 0.08416951333563175, 0.14287775742911524, 0.1830417401487789, 0.09341663125181392, 0.18015688285231593, 0.1151523229876353, 0.1582685251149439, 0.20221918851377504, 0.1656942766520285, 0.21478747378193566, 0.1739874389022589, 0.22811319018083237, 0.2221042110073951, 0.15089500545253678, 0.13205854282263788, 0.1330298657018331, 0.15996203908035833, 0.28441274658806864, 0.12501041900606888, 0.08037015390131744, 0.13900564262463203, 0.11001123716273617, 0.2480223138005503, 0.1335757186696414, 0.1349460201398019, 0.10007441794920353, 0.08227340741864136, 0.11029511870395754, 0.20240173194437258, 0.10578818514101929, 0.18214428346724282, 0.1257869333869988, 0.23596727679814064, 0.13887860992502782, 0.20190509246482005, 0.1273737772698364, 0.17458713252938565, 0.11751872262046223, 0.26513794376965494, 0.12547320506024745, 0.21744095720350745, 0.11626030063076366, 0.16542113566350553, 0.1641409567767574, 0.13799917163147082, 0.15676403568396646, 0.1080391966106911, 0.13848021356088502, 0.2174775149192541, 0.20126090445105108, 0.1812532619242707, 0.13555158200042863, 0.23543412556811688, 0.07959839692639728, 0.11282983551462812, 0.208043739680321, 0.24703399909119456, 0.22138839377270592, 0.20933329548326232, 0.19456345738182146, 0.16198328545977994, 0.18594377313650426, 0.19290993320605448, 0.1299668929629749, 0.13020840984198356, 0.19306226212891842, 0.08252456934461672, 0.13971047415848703, 0.11580391907163205, 0.16185709545689245, 0.1679257988449066, 0.1524760883541838, 0.13527484039866156, 0.11660404428238831, 0.0883500398166718, 0.24041095448117103, 0.08721203152691165, 0.12590723983462782, 0.09127881693383379, 0.1637988525532907, 0.14731863123034278, 0.13696947285244543, 0.1027890888132876, 0.19082248150821657, 0.21061860715910313, 0.14065892165226324, 0.18761248117493046, 0.13386940613629358, 0.10885871916769013, 0.17032366936966298, 0.18772195513931014, 0.15930988375217686, 0.14431679230784217, 0.15732494994036614, 0.07055919527286483, 0.15978855080902576, 0.0713777908634755, 0.12596126435504806, 0.08675006518681204, 0.11769125328188944, 0.1761195075608069, 0.06909091115718888, 0.1485476967307829, 0.14593872301761182, 0.15172564394531712, 0.13828234837180184, 0.120160783671083, 0.15222121090177568, 0.16638626855227256, 0.21533321949743459, 0.1662600632276266, 0.15863050165916645, 0.11655331394004247, 0.1518111700011838, 0.22452990584556135, 0.11075370659631108, 0.20060482675269728, 0.14674725221289744, 0.1556719313826292, 0.1558156494772242, 0.11491279027635053, 0.09439583717574997, 0.18973871224349548, 0.18870979487415285, 0.21685721352696422, 0.12402498478730842, 0.16030880111840465, 0.10598882356838835, 0.1481244944396519, 0.09633492062529249, 0.20632877525302673, 0.15503814684287195, 0.19516831444155788, 0.19864077649770245, 0.1446670477068232, 0.13228004948506433, 0.24055582170765247, 0.28692291028076605], [0.06205899010021841, 0.039283356989824006, 0.07583563351222584, 0.03304219188829584, 0.035929470022599545, 0.03663251274115136, 0.07319889677267882, 0.058227117894397634, 0.044210949431984656, 0.07226901158930794, 0.015333042003124233, 0.06602399306552065, 0.01790250377399066, 0.034741608561166835, 0.021653883121607286, 0.015154403705720701, 0.030786980341579166, 0.03020880995468507, 0.0355751313749821, 0.02184285211466974, 0.04494142575910495, 0.015354097929723082, 0.031798250875585986, 0.017311363518538497, 0.008356102118869464, 0.05988950953788816, 0.03769180166625208, 0.032196323567580794, 0.06741416685643696, 0.015515115247258257, 0.045949444249873204, 0.03284515024373128, 0.04438480925596049, 0.09430202204854259, 0.0324334277801456, 0.008982512104745594, 0.03220266294515422, 0.05315018044183812, 0.02599496630981805, 0.031207495579315774, 0.03811819854402735, 0.04383070935164729, 0.05448964304260669, 0.004950728297473924, 0.02860525386377929, 0.03144504220765685, 0.006760657462666953, 0.02221890552450092, 0.05539464569019695, 0.02595033019690985, 0.10473433927062059, 0.06899752503921909, 0.05847035464079631, 0.05489996356529094, 0.083862082251618, 0.025151788872937043, 0.025807278598808957, 0.0526759528645104, 0.09554175915376795, 0.04428893718267641, 0.05429663102052385, 0.05478970436078887, 0.026321576405016166, 0.07940987034911111, 0.06556996339631659, 0.04705563690813799, 0.0018095550988237526, 0.08795623998007468, 0.01993980161064575, 0.03304749321673186, 0.03516665712419537, 0.06400745429639375, 0.02549042080288693, 0.0748142621089374, 0.037313541923198974, 0.021070175834240455, 0.03818702771358433, 0.04276092119154431, 0.04524066353276853, 0.024697401057628375, 0.029347296203336412, 0.031628893733385115, 0.02662995552283622, 0.028106674266558503, 0.04981182590727845, 0.00652780791091162, 0.051212709607376214, 0.010869563820080893, 0.10198995185595366, 0.0677810846677711, 0.03821962475476246, 0.054269450220970385, 0.03973904523938414, 0.06414616217596397, 0.012950271071355431, 0.034876531966391115, 0.06454090047026835, 0.0066239050225234564, 0.07892833812342537, 0.01581606043938307, 0.04437831666080221, 0.00985207839778835, 0.06694427916720029, 0.01578934120780398, 0.04683749337169913, 0.06901884526615182, 0.08686012137801417, 0.022610602449745904, 0.031189059673417962, 0.01685097148912328, 0.01810738824368004, 0.04390365624379727, 0.02693240895056196, 0.10860626255312275, 0.07182907793791064, 0.013409079213987195, 0.043606567346761306, 0.06328221801067553, 0.06089636740545112, 0.0701709955389942, 0.06761659026866959, 0.08897856899326848, 0.03324826953992729, 0.01806639104841217, 0.08596729952841999, 0.08778721034046143, 0.07036548228033128, 0.010961734731080792, 0.05579632474109531, 0.046924275811761625, 0.042452268197291324, 0.028270858400050673, 0.05206419718301585, 0.09800706839849872, 0.018970531847087607, 0.0576934150810684, 0.06355087738484144, 0.05345853466180064, 0.04332933927916231, 0.056777748489572163, 0.0068858031919526485, 0.11130702126050189, 0.06475899038055251, 0.034674208145588636, 0.011893005575984718, 0.024654643775354472, 0.022661685192536925, 0.04438013611962238, 0.06406300333178332, 0.044970575404623826, 0.03187861541406282, 0.05900988738322931, 0.061985621859710065, 0.04709963333762942, 0.011924307928570818, 0.04569886838115993, 0.025221910815866246, 0.032623708698778384, 0.03239932920663588, 0.036056265234947205, 0.021539785816604574, 0.0259413190877005, 0.04763531648824292, 0.03592827492543767, 0.029658122972074537, 0.05797443528389258, 0.04388557273834463, 0.08102439298865297, 0.06689906465790926, 0.02479855339193056, 0.08715839005045353, 0.03568981856768651, 0.015471583258570924, 0.12525587357700835, 0.08695906929431424, 0.06013658821522709, 0.06295328666906684, 0.03212282892256495, 0.021027265334381692, 0.020279243678575563, 0.0235453580370954, 0.04672344969285112, 0.03429997419457763, 0.05931311264453877, 0.0455351936961374, 0.0577904362862389, 0.06828724662022245, 0.02468108146962139, 0.022515088522566423, 0.03701621553890648, 0.05894000484277645, 0.09582475203299716, 0.03915980232939605, 0.0679253926500678, 0.05213453171534404, 0.03414605563927082, 0.03859161406815533, 0.043799506590491345, 0.04999007541506041, 0.03673953522417334, 0.06701001717198281, 0.04427770633370646, 0.04190827299269938, 0.022131900918940385, 0.017839617531506285, 0.026737286356247725, 0.11816520889800404, 0.009720614837152104, 0.05155032455560662, 0.042027219634262786, 0.023561752318675, 0.03811303128097807, 0.03215869332874014, 0.045893129126559344, 0.014319792089443055, 0.03690381894909567, 0.019422106204494353, 0.023870407228147792, 0.0364675778414934, 0.024362434858396172, 0.03320927949502103, 0.03847639827478317, 0.07262780120776546, 0.030430925657011332, 0.015232071614704065, 0.024548829796033043, 0.01454545094841911, 0.03226164405444457, 0.07722326389123356, 0.09031881683415945, 0.017672667820607463, 0.04692918260491664, 0.06711041299445976, 0.03537258155824196, 0.033201204928299116, 0.03373589216461105, 0.04770638646497842, 0.045223633398211775, 0.044859159407356096, 0.08324393356639533, 0.028716292562744314, 0.0948481431471244, 0.020439873164099072, 0.07240765818184422, 0.06777191459531746, 0.02003682856147568, 0.01774389676058725, 0.0423288973979652, 0.02879726997156057, 0.036510934587568045, 0.020574756349707325, 0.011974344003735291, 0.029295974058069052, 0.017613983570387768, 0.02967093770782794, 0.041640034966891816, 0.07145553346603148, 0.032066393140403014, 0.010897132451646032, 0.03351858366400965, 0.06284561684174884, 0.045003153293603854, 0.022324470525246956, 0.027566249031693708, 0.025235704228942914, 0.04066320391552102, 0.05815156247286547, 0.009604455798023171, 0.02987738308166304, 0.01736132968817988, 0.002818986423306107, 0.022547670241986072, 0.010410972097287736, 0.03075713164082939, 0.026795386464425155, 0.021786092660359798, 0.01791443750863114, 0.057178266917265234, 0.01202767042653455, 0.09888963999166604, 0.0391943528947811, 0.03218529573191078, 0.05625686232721614, 0.07138540577744285, 0.002534427133674223, 0.030156572334348198, 0.05045904379878795, 0.08756954177853563, 0.06498450368282295, 0.061883774300616604, 0.10893027177981793, 0.03194939236216728, 0.023727552897687403, 0.0463232108872504, 0.08201174242722412, 0.027300280541361823, 0.062075361399160284, 0.007147138765562447, 0.052377170913161776, 0.0789895868529716, 0.13946702673790917, 0.05497837649478067, 0.07703413210448719, 0.018353177978086378, 0.06348911537638595, 0.040776619402271126, 0.03336202976624331, 0.05676452198155946, 0.04181455362648253, 0.04588185614275356, 0.06714312494882653, 0.032021724468758034, 0.035729015456332315, 0.012457124952737604, 0.02588275358110907, 0.024694999371985757, 0.038165443186317725, 0.08277403055540017, 0.05875607862347557, 0.04092624020432273, 0.03075019471467503, 0.02216179366974581, 0.07390099337264415, 0.030122081140777277, 0.02459744765092769, 0.04442181513314286, 0.06595224127053254, 0.06193357767657407, 0.020896497956146638, 0.02316739898355257, 0.0334379107751433, 0.0378743757403666, 0.04735522708224674, 0.010677734446231156, 0.019772951491177082, 0.03993690276758806, 0.01708505156960699, 0.011214100372707172, 0.03408793254845566, 0.04128820142678676, 0.024267857473704125, 0.06554688116715801, 0.086661467118369, 0.03592321108425817, 0.009587149871813675, 0.07835186462128356, 0.049865566975166725, 0.016794233102231257, 0.03379606837106328, 0.08130504163883387, 0.04176050229298492, 0.022467259738233783, 0.15549940838208123, 0.20456361674493362, 0.15999985318030083, 0.1263247807359984, 0.20382411207162565, 0.15169622616902476, 0.10101287565644711, 0.1361184870643962, 0.165915216409391, 0.20171202298614288, 0.210672524427214, 0.13260988097998405, 0.10476594039749716, 0.15024003092079394, 0.14077665404446665, 0.1487411798969392, 0.08926302510043306, 0.10883937544760205, 0.32806189310166145, 0.08725784358478363, 0.11509920245096569, 0.12224199175233803, 0.21321487913448967, 0.15709890803742796, 0.09104044867619392, 0.1985623750595316, 0.11933114109260422, 0.14760481103533699, 0.19019410554920474, 0.1437652549676357, 0.1747050334609324, 0.09306180996880417, 0.18017928326322188, 0.13897210329530701, 0.09619789813915569, 0.08022972998479683, 0.0833750801581529, 0.17042379706136643, 0.11648767552669011, 0.17580556472943676, 0.13121230677971918, 0.09496200679531021, 0.11345281821465301, 0.22628038610902526, 0.14233434062090614, 0.11663182263052273, 0.16755705008343344, 0.12117145282606925, 0.13098067243493375, 0.12830913998186588, 0.25820843334640226, 0.21008496563280785, 0.1483757559570574, 0.19663880489045577, 0.3457622320180939, 0.15309663489460945, 0.09951018653209172, 0.10969371670075964, 0.18169763888562881, 0.15238913737477797, 0.16721103881155291, 0.21057772870746352, 0.1753701509967927, 0.20987763159698059, 0.12326386111277728, 0.15772061903149853, 0.06688627098957378, 0.1853958210877834, 0.2070413136314, 0.15578450034222296, 0.1585798632473715, 0.1195028980052279, 0.12251251272015995, 0.1373770929151966, 0.12305415986526398, 0.17175113632073327, 0.23613497344476564, 0.11777186105328223, 0.12006152931961322, 0.1299389920407726, 0.20723582335537483, 0.13449327749831064, 0.0784900209175483, 0.15325264103950995, 0.19146889117696594, 0.06531164620912845, 0.17286485962329373, 0.12570228833224506, 0.2048577025773064, 0.14192785436828292, 0.17052024753103334, 0.13475900275572655, 0.10665496000118795, 0.1543730599505286, 0.0940405255964687, 0.11096053501410831, 0.16291757564871542, 0.0957298337391788, 0.19802943833412665, 0.16636506323852848, 0.12009971114175937, 0.1377834565937519, 0.24869012796590406, 0.23507302236412805, 0.11049773363817124, 0.13281762870329042, 0.1399435640703286, 0.16095750905092687, 0.1954895963952426, 0.11925604915426624, 0.14659489264651654, 0.18226060625766555, 0.11802019611481698, 0.15923633931144593, 0.1528327635699703, 0.12345542905912285, 0.1299303658907452, 0.15687459749319863, 0.15961671728760968, 0.20916858657954202, 0.2450118180845053, 0.15366297305351304, 0.08485918398946525, 0.1012310421755237, 0.27824794513083273, 0.23517766997458475, 0.1657451602119592, 0.07391019408861477, 0.10532461767715794, 0.25070063379262725, 0.11997648589913884, 0.1457313276947506, 0.12600827151008193, 0.15853428101587683, 0.13075993186043156, 0.21326763194895562, 0.09639954780258479, 0.12373933358298195, 0.1294133484724068, 0.2286054629592165, 0.23446294058474804, 0.2445944687051158, 0.1499687898303232, 0.10671430883268196, 0.14801629218122653, 0.10682927564747872, 0.14545769640995612, 0.16925709111796272, 0.16424895985232246, 0.09880609044264402, 0.14581146049163035, 0.12019028571704704, 0.10924562421296874, 0.2015842241986144, 0.09727883287855695, 0.07321627164680151, 0.09703689465118993, 0.11183646462497213, 0.12664780170927126, 0.24238873303176897, 0.1576950929818615, 0.09310248923758346, 0.10388279423838663, 0.09391200668629139, 0.06833377880074325, 0.17550001822171674, 0.21395833682148688, 0.23890592878864658, 0.1512978604483989, 0.17344864926511244, 0.1459062562113808, 0.18807437090623766, 0.10861250616970564, 0.25039755408802344, 0.236902256466208, 0.19953656310756362], [0.00412785075417149, 0.008122182916849852, 0.022221908589164098, 0.10667170668321271, 0.08000537347529205, 0.018633746189035235, 0.0683790316144305, 0.07347942284879184, 0.024954310558255643, 0.04574496006112426, 0.02275295116217627, 0.0329670156802862, 0.009205633297472472, 0.03805735584108099, 0.07551758444958157, 0.041740875120364854, 0.013758813673179719, 0.019022091479611494, 0.005538707003823572, 0.03848613908274039, 0.03825642378820527, 0.026060612384049643, 0.01125948725178117, 0.06718535171521288, 0.07593118765902135, 0.013071851140158552, 0.06640838534240762, 0.06195208636082469, 0.040578118360210816, 0.01686430333422557, 0.0478839235109908, 0.046525630469043414, 0.04571253155928947, 0.013562725808080888, 0.024254311123983036, 0.0233841750530466, 0.017951102476687204, 0.06248986859235072, 0.09432787751598705, 0.021488111270892046, 0.04663761720181473, 0.0463714974091178, 0.013194075680427976, 0.019395277805386052, 0.021535095443288167, 0.024171654067392793, 0.06749461374936566, 0.033058115025802005, 0.04408784676343203, 0.11458178666690666, 0.02798181342621965, 0.049311880758332635, 0.029860230373038404, 0.059304877199352755, 0.03575960151670921, 0.019646181176686962, 0.027530082020788427, 0.09008092355103263, 0.03254234633078018, 0.036227738695038904, 0.10741786866058266, 0.058152068090895494, 0.048865910334091996, 0.01462953388615842, 0.02680747916230992, 0.04274312113862365, 0.056956331245601184, 0.05094190901746193, 0.013576314292637812, 0.025350992800667885, 0.033133842817117135, 0.044356034993524515, 0.07530104203690445, 0.029695444860525673, 0.0498497051246945, 0.08107904570117112, 0.037548501089575796, 0.047581655859586694, 0.03362404715810572, 0.10086571016619283, 0.01985715029971494, 0.03149765521107662, 0.07574675965213007, 0.0724392056825661, 0.010613163767923272, 0.06613840063613269, 0.0225150846921268, 0.06855956789466643, 0.06155463994570798, 0.03242836393896611, 0.014424528757620965, 0.05105021469775708, 0.054267102161482464, 0.04642721881429034, 0.05059140847034512, 0.022835073872439327, 0.07219673119365208, 0.01885262900032103, 0.05533432775747873, 0.04376516286884585, 0.03038544876260623, 0.03811260993261972, 0.050809237910735036, 0.05327458545986203, 0.009269928184127616, 0.053787718812424334, 0.036726274242204045, 0.038488058132990714, 0.041745954283302834, 0.04360728746941013, 0.07725801363947891, 0.0008217388852743522, 0.04995028097783366, 0.03756366963047655, 0.01585065218199405, 0.0680776066597431, 0.03465825053412588, 0.04891653725456807, 0.02024015021179953, 0.057129229629232045, 0.04266044876027492, 0.023835665140781673, 0.04156189016817559, 0.0497736594068908, 0.039121248954606634, 0.03727231490155382, 0.031764052710646105, 0.03458805772806368, 0.03366305635521009, 0.02550748541140028, 0.022434758458046183, 0.06220147096281571, 0.04550697101700691, 0.08143484757672395, 0.038680541554405805, 0.03858032959303068, 0.05548998916281327, 0.05909044152846741, 0.01729476430843915, 0.03384425913194015, 0.02152609391017787, 0.011689792135580173, 0.03658205819045825, 0.03013068813860657, 0.08859561696167916, 0.047420195168665344, 0.04732323908096841, 0.12889591736658929, 0.023247074042897553, 0.09299732068733824, 0.022676836496459383, 0.010088266177673735, 0.05944127532383127, 0.04867234672870367, 0.006683183948494375, 0.04847812811814008, 0.0156369854718627, 0.014244197405904773, 0.03912656943524077, 0.061715342209584294, 0.03018178428793627, 0.054567669097694664, 0.08833120171461376, 0.043545847217882835, 0.024662657055042447, 0.07063566616946651, 0.024874702531604037, 0.011211525359671685, 0.07436774010139127, 0.06827956275834192, 0.0033435328101228566, 0.0589146894673186, 0.037821810617442095, 0.0389296158907875, 0.05336446289513862, 0.04043535404508153, 0.019764221919279908, 0.017588901851746826, 0.03846258187906877, 0.08038271008239639, 0.05658870480293709, 0.008297633330878473, 0.07709953303058302, 0.04232991629490449, 0.05546632470683225, 0.03477276535704732, 0.032732489353586594, 0.0690108243255846, 0.018462577248893438, 0.03543451593648042, 0.02921197634761132, 0.03344359131710183, 0.0382823788470799, 0.03194992862371428, 0.028204903975429556, 0.0250016950115922, 0.04609412761525281, 0.06542270597551139, 0.03967644819509118, 0.05055121566739775, 0.029206037250978333, 0.04054290895921089, 0.0645067635923624, 0.024790670347189712, 0.06728643701682169, 0.03040735313158122, 0.04831187171681274, 0.1304936090544347, 0.07344788300894922, 0.05377363045549682, 0.004943765515852119, 0.048163495807638096, 0.04130040137698093, 0.04328132088806841, 0.022188246685771212, 0.04256872505310082, 0.05242173807815679, 0.009324345324609068, 0.03380846750411776, 0.05032449577664656, 0.025132584963895144, 0.041145371994183916, 0.02171884163192684, 0.06852959853506858, 0.07095631993105335, 0.022523902364135272, 0.0412698268079229, 0.05165546246233487, 0.10116058506912763, 0.08564885976093431, 0.10638800900309317, 0.0404416129834229, 0.031385752747976975, 0.010614893211412334, 0.03403300021384512, 0.054467683132257194, 0.03500878555519927, 0.009328249500193184, 0.007800131044801205, 0.020127127345110622, 0.03419703496019206, 0.05213736624066388, 0.04302836631635024, 0.03670567413792014, 0.03209480734151458, 0.027975081428585034, 0.03607707218297067, 0.04035616736678828, 0.029180990006293983, 0.0447064244578923, 0.025096563509695476, 0.04465677046908006, 0.09391943773915691, 0.053707746894008694, 0.030140836888383475, 0.015947371740044368, 0.01117769683215527, 0.02911297097471693, 0.0375136019541852, 0.05241120819963756, 0.03919161796089142, 0.029757072803594416, 0.014144575332231341, 0.03177084982575428, 0.05532904941168043, 0.03688872318654772, 0.053227428917682944, 0.06659094409476365, 0.11910896793368364, 0.06475531315851597, 0.025290445041572376, 0.027613859480967926, 0.07864777374291614, 0.020977285758201635, 0.013374741238001133, 0.016576043600516937, 0.04672930260459262, 0.03142364728715151, 0.02709692441708138, 0.04266761551280657, 0.018932177655158505, 0.009479859258018194, 0.016467958170500015, 0.028197951727516712, 0.04357196698566118, 0.07437503325843042, 0.04635447493544029, 0.025882583126545917, 0.07011238981278674, 0.08751642124186601, 0.017200545069851705, 0.05127809521171355, 0.050471917906355475, 0.029624648760223103, 0.009907246304435596, 0.021374084829022328, 0.04601019502226864, 0.041033664883504954, 0.026792634293557178, 0.07733352692617525, 0.030291248676216895, 0.06116112356164283, 0.05332924966369906, 0.03506769771657644, 0.05013169825918252, 0.06936068901972425, 0.04368483471954542, 0.03071703842931217, 0.04259346969305508, 0.04054431090011232, 0.02716239046065077, 0.0319844562064616, 0.04157905053767947, 0.06189559503728825, 0.007686974112725547, 0.0071960046414225815, 0.013922970993594538, 0.023444939231980714, 0.041015543073656104, 0.022218250519325657, 0.13662073430755448, 0.046023770100286895, 0.04524716378880605, 0.02355538229758461, 0.03584143502878086, 0.022344415624355598, 0.05428310190778106, 0.032541139742299434, 0.04284887574613095, 0.03584670954413953, 0.01720132647953447, 0.03567999732049723, 0.04300984614078076, 0.02409076667390764, 0.018264570333544287, 0.03808629864286031, 0.06859309190223295, 0.05050579048392754, 0.047255942087259986, 0.02697955591664199, 0.0611678842875746, 0.044426817687288414, 0.01700387306271061, 0.04323422563292327, 0.021081125145898234, 0.027286416265152158, 0.024586799028780193, 0.05606957681236729, 0.024940624397488374, 0.014862496435882585, 0.02464974847351832, 0.03714124108814905, 0.11506753237617594, 0.12609094771887028, 0.10043404260349852, 0.19661324819730175, 0.25220657879066083, 0.09851907560181233, 0.20441623675006054, 0.15906476625992408, 0.1954436157980273, 0.1754716423250014, 0.1371915004546604, 0.13112704119374677, 0.16454123771719395, 0.09730340131828863, 0.1710384906900506, 0.12981387456097912, 0.1315006929179353, 0.08872317060107186, 0.07566190775363676, 0.32470808274322943, 0.1361741663347329, 0.08032675502040694, 0.12809010778343485, 0.15267141013135835, 0.186804871285154, 0.11485219272153993, 0.20048660406422233, 0.12445571006185586, 0.10341292187090843, 0.06921644232446147, 0.08889413844313353, 0.22978837932309798, 0.1485106487187647, 0.14415830403806704, 0.11043496039365569, 0.16212585442248853, 0.15018283479636715, 0.1671269376792254, 0.1432634520554735, 0.16176891873680777, 0.15415254920240373, 0.1805802383610318, 0.12632274294211981, 0.12088748701517621, 0.11521313504706468, 0.11431416917231776, 0.1675135516110928, 0.17941402271389964, 0.28960100044646575, 0.17632163219874905, 0.2009685193338702, 0.21273366866573212, 0.131314717413437, 0.17228609551825833, 0.1663226679327988, 0.16659389370151106, 0.09056257835078625, 0.2522805062753539, 0.10394703837171679, 0.19776827896073942, 0.17772915022027108, 0.21740516557568507, 0.1672613095011442, 0.13600345130168623, 0.19236098524303208, 0.10782047084742978, 0.143467890278947, 0.12531638686214724, 0.0950658806569634, 0.14885845263638806, 0.1431285592937662, 0.12800698724365042, 0.10976994244922554, 0.12675359845161438, 0.1197769966036562, 0.21514290793528482, 0.15233784012736815, 0.10917506751514251, 0.0631633747909819, 0.19625030638229465, 0.11120961318092962, 0.15073415763195486, 0.20978829042325098, 0.23391364022128044, 0.12744047288452426, 0.17740662720414901, 0.121772755237837, 0.1668864320362768, 0.19490409071647352, 0.17834514619842654, 0.1324818676878368, 0.19969440786348236, 0.24220240512682548, 0.24231984640561768, 0.11399940662686864, 0.14842195105889153, 0.1593239797699836, 0.08964973096285137, 0.1252369512052786, 0.08096042464697555, 0.21391186592800004, 0.16582112549053085, 0.12541724233737878, 0.1549184379438239, 0.10903649753139866, 0.12256845246039091, 0.1852350345542354, 0.16499755032841237, 0.16005392366599652, 0.13391501901130523, 0.22301819986633717, 0.22716892552712273, 0.13922603079868903, 0.0859634384452816, 0.05110271470320802, 0.3029646688411313, 0.11826201176811611, 0.09086981025193969, 0.09561971626094273, 0.14519359525893966, 0.11794135034565004, 0.12983288886325975, 0.16120697792258956, 0.1555667475106255, 0.13903968757198704, 0.20415884652926078, 0.08575935262225329, 0.11486014471419397, 0.17189051835767685, 0.11383163337145122, 0.16331696792715983, 0.13197609644022681, 0.21148295352055183, 0.1648080048541869, 0.09566215753194787, 0.12686140234431914, 0.11855962926581984, 0.14375711911387984, 0.08704156164200076, 0.1217467159092907, 0.09985658084793438, 0.08991540259411258, 0.12025786233284783, 0.1365572562621486, 0.1904662046581507, 0.14395705274035855, 0.15433256454285116, 0.18859927903019613, 0.09599954265380099, 0.1148901447173088, 0.08286912504944109, 0.07411665478420836, 0.10044462993861207, 0.10504396136609778, 0.1194866109759577, 0.19160232837161711, 0.13892019317755777, 0.11336042035010555, 0.10982850221015754, 0.12949732703066644, 0.13047589710162533, 0.1353071693090662, 0.18910066825487923, 0.09447610020757684, 0.19040707799215473, 0.15898032804890988, 0.09675600085287325, 0.17606673942458245, 0.19951367240038612, 0.11554255285450529, 0.11311679672930511, 0.1845983695238829, 0.09624217036029986, 0.14775032177567482, 0.17373872079676198, 0.1165550759422683], [0.04981973959553627, 0.018531159355094837, 0.04843970114785818, 0.054384263818182295, 0.057668080553412444, 0.014577697504371887, 0.03335412373886474, 0.04910010724298416, 0.04088086098612797, 0.0628194626000139, 0.023533112121625774, 0.07023477235869055, 0.023059868967280756, 0.004802732080626752, 0.02403037596283661, 0.07295974710535619, 0.024223887857290047, 0.07449707872564755, 0.06823640136468796, 0.058720528313349334, 0.03737441910010192, 0.0908495165828255, 0.048937099054455764, 0.020303689544239355, 0.046206279056927854, 0.046576939207772096, 0.05129112636730556, 0.03972286929286296, 0.01852094740306418, 0.033149206710438577, 0.055076033552928325, 0.05040414210769439, 0.058922124350623745, 0.04779172482930365, 0.06194194335670722, 0.033872485641510255, 0.04973987492943003, 0.03242364100691292, 0.04350800247442338, 0.05506808156027429, 0.023806278008006276, 0.01836820862316076, 0.024840711210403713, 0.03332037756580018, 0.12434376929436, 0.030216225685792106, 0.10479610127907608, 0.05096503338145633, 0.08017740617956846, 0.0348119201108573, 0.03547369750336774, 0.026857920306464358, 0.0592956496703048, 0.038853194789900895, 0.060912313525595015, 0.025913443063355746, 0.056348042111964, 0.05884576070633146, 0.022677577686526125, 0.04467122271777161, 0.018471927352009282, 0.043331832895355846, 0.03927159370974668, 0.0401101382299056, 0.06166612872132852, 0.05385159905399046, 0.062218822854300665, 0.07296950706551153, 0.05369016134570684, 0.04286531599298601, 0.023760644065576698, 0.04398769225865122, 0.0401038371567284, 0.07058691999484455, 0.049286542400237054, 0.04056506422198108, 0.013160712551325561, 0.02084417415091828, 0.027596769974597042, 0.09265156222447272, 0.00819219664985975, 0.030659656528563752, 0.06484760377075403, 0.019691935777964614, 0.048194422777141296, 0.10357753118319858, 0.028965311357751492, 0.027061014045630733, 0.014596621791321426, 0.03998263438622798, 0.059228130511098334, 0.029943195780018167, 0.009474518667576055, 0.039063122033351855, 0.011815623992363052, 0.05539693246265093, 0.05469054577030963, 0.04219446428901246, 0.017417690776769194, 0.03554302079963588, 0.04148312100780107, 0.021197574340828487, 0.014529366932448842, 0.02488822781390721, 0.038468312216742385, 0.04563950422790743, 0.01962853625657097, 0.028185169550500093, 0.016902307040929314, 0.032249673930627686, 0.01502113505041287, 0.02319125879195429, 0.05065667916149382, 0.023154917496046232, 0.044991930105513146, 0.046875859054947094, 0.001285533242832659, 0.01540528217916407, 0.018006699392572045, 0.12037599309077186, 0.045401197257301504, 0.041690102643183166, 0.06948305624386958, 0.044124454274893775, 0.0436207054994039, 0.06572543327967006, 0.026395844798835538, 0.01860780836713891, 0.04774208616224989, 0.0856377055207568, 0.0594970120507623, 0.02178278890618634, 0.05476773678956013, 0.03727637516755251, 0.03875097184772453, 0.029854538339760997, 0.02646503977537636, 0.05987565483777754, 0.06403616344135615, 0.05925754445695108, 0.06829552803068392, 0.06408137412020756, 0.030161274198983467, 0.049706247499993736, 0.03440633401154511, 0.06980113595003082, 0.06258571002211782, 0.04444793107048158, 0.07443193826944598, 0.047147418071906415, 0.038424852048797954, 0.038446317832436294, 0.005481490769588779, 0.04731282794607743, 0.04861525402614667, 0.06017028459257657, 0.03531685249219018, 0.0707330053011256, 0.02230290131973884, 0.03366173868398032, 0.04505727740545427, 0.02014421685148151, 0.024545229182788925, 0.011959511583911316, 0.016276821148611845, 0.03328300779685378, 0.04774315485490426, 0.042380351693399494, 0.09058631175468046, 0.020564785715372815, 0.04911890321020638, 0.016857079125099608, 0.021568121493703896, 0.03360329000579734, 0.1189787406474352, 0.008704030525780494, 0.04577962553969795, 0.01102935922737684, 0.006607949326280505, 0.026616353631740617, 0.04928203014236304, 0.004753139857653408, 0.03613861585636774, 0.02575973518222811, 0.05649807277105509, 0.06749779301425142, 0.04622289933444512, 0.02340876264497638, 0.03167979069985449, 0.013672284999742143, 0.027549203575378465, 0.013050619970947024, 0.0591859765230648, 0.046644672871597355, 0.0901779026213673, 0.0405992700478002, 0.028053107483673, 0.0588676554992074, 0.029348600468027498, 0.08369787896592772, 0.04765675928924353, 0.02469492276319333, 0.0877202695776378, 0.10895428863624412, 0.010041509916435086, 0.05792501495189725, 0.00982717096415018, 0.02455387831545405, 0.14581297734572043, 0.046060366120429776, 0.011758832936926235, 0.03144668738147424, 0.06652973366961365, 0.053188419720578584, 0.0688188580135184, 0.04265189921903995, 0.012574631349003364, 0.05326650323226087, 0.05971224062264927, 0.021131930181816704, 0.07326114907740586, 0.04439951431366705, 0.05309687604406669, 0.039588807736553495, 0.026203328818683664, 0.043234110719734625, 0.05095131274673247, 0.05697525744777053, 0.02401095754917591, 0.056222771414585655, 0.0816219722131087, 0.016280103835367387, 0.03325021540325496, 0.03837282318742045, 0.060928045141120116, 0.028415365565207698, 0.038593111770047296, 0.06797626854911928, 0.05428076533961201, 0.008140818005607975, 0.029794737516391664, 0.08941399804767101, 0.047325545005620494, 0.04178366113093592, 0.062138084847960746, 0.1021997143905009, 0.03408714347789365, 0.013045244906548292, 0.007313640315025564, 0.028506338506216006, 0.04779407288879157, 0.05171960700423487, 0.01609363037371828, 0.023815246982379787, 0.051675606744303826, 0.10788500609417116, 0.01566551554377281, 0.04565190719140153, 0.10109771223318192, 0.06813815824927823, 0.04996623092841718, 0.05724555625009441, 0.02187101925242572, 0.007255931869299422, 0.0381856985510357, 0.00590374646332836, 0.03961141499119901, 0.015420519667978009, 0.07796858317188679, 0.040759125784520185, 0.06660705492381128, 0.036731131239643985, 0.059886368577398603, 0.02757431593753638, 0.0544847400798913, 0.03784703023190941, 0.04486099035749513, 0.027840184836438107, 0.03243205648276114, 0.018046725571395892, 0.039844079724242615, 0.06290285127057184, 0.0369298467863231, 0.07018364365062407, 0.011909806841774093, 0.029669292534010547, 0.027074568056231065, 0.04992256391673319, 0.044245737484626235, 0.03341286736089857, 0.031955088225884304, 0.0629158556130865, 0.015722834242267475, 0.035825668939299164, 0.028009844583369074, 0.10471046031002076, 0.04358668353468661, 0.028453754231093392, 0.027820592137774634, 0.06334952649570282, 0.03809316662110148, 0.05387678036406156, 0.016801545411468517, 0.042184976290070245, 0.026020111230712746, 0.1055227509970146, 0.032727482969001416, 0.027908399220435854, 0.04316654176481309, 0.04427541190037324, 0.0299099303271261, 0.008458008092167157, 0.014612938506498694, 0.02858640618562218, 0.013433910038832937, 0.06375336974498726, 0.13335410475490556, 0.0475607339983746, 0.07001292095669816, 0.02377498714673904, 0.05379479746484468, 0.019949871836410418, 0.09706922356159457, 0.0428940749336635, 0.01765244692984608, 0.02614324645800216, 0.04232335092139341, 0.06970340611353036, 0.10536132861048945, 0.035009540151804686, 0.022700523935078133, 0.0607343398094658, 0.0537164994485436, 0.026434518832473025, 0.06479976924076196, 0.020454647169718822, 0.07278083493151973, 0.07793717356699129, 0.05006868369697083, 0.04146458168003348, 0.05950956057096201, 0.03586102006656509, 0.08038581273848973, 0.01610862846005588, 0.03084861786074696, 0.05182206360322814, 0.047266471965779225, 0.023447672250650586, 0.04678553728867443, 0.03448711032228124, 0.0341916914969202, 0.03225517444192402, 0.16024156924216978, 0.24244016817500516, 0.09939178764339417, 0.09121301764201734, 0.23399043287481033, 0.12425903230905534, 0.08613596144582956, 0.1324045387727599, 0.1477424923570887, 0.10549693383396634, 0.21442152890226535, 0.1989988153499942, 0.1360716331269472, 0.07497411401521775, 0.08955433003364072, 0.1722005234971162, 0.11079089250415565, 0.1651710845650204, 0.22962506469939986, 0.16825241277054434, 0.10566575662984003, 0.1769117497268223, 0.13945084696094837, 0.1473336159101417, 0.10936953893472111, 0.13047084092132508, 0.16606357699680716, 0.16185421496629715, 0.11529250941689938, 0.2745372603737539, 0.07806686459169274, 0.18609455456176113, 0.26215553283691406, 0.10835597396738107, 0.15657088959649687, 0.12367814614046967, 0.17140301064618174, 0.18793155679539328, 0.10655709992974036, 0.20959839254858034, 0.11771822723770335, 0.1481953116073724, 0.14806126154238178, 0.0940390776902918, 0.27838050898525024, 0.16580034918602438, 0.2595448890520681, 0.19611743609270743, 0.15230857556866062, 0.15187054181531554, 0.14313035193950902, 0.18820020850867997, 0.11110239151504733, 0.11124562697425006, 0.18442794560424744, 0.0944216313561605, 0.1297658714916437, 0.24843304418027404, 0.13253010058354947, 0.14413689954146264, 0.1345737014086016, 0.13091730164183726, 0.24201767068476449, 0.12101928478166943, 0.10068895836030284, 0.19610954538708736, 0.19183931001011403, 0.19967997476698893, 0.21552576803632323, 0.2528222530118881, 0.14789857511078158, 0.19144118943762398, 0.09524242561911384, 0.18901590828693685, 0.19231083712750868, 0.15887428615843097, 0.09179454732445941, 0.1380381655068167, 0.13339148984561044, 0.20828531784636362, 0.07648672397819258, 0.12662999016503174, 0.1657524993342738, 0.10159243649292378, 0.10813696475158777, 0.12441556705462357, 0.08031394603031297, 0.13248678597231067, 0.10909553992772296, 0.11183168423632461, 0.11443273660035864, 0.17168332221767596, 0.1334145490921313, 0.12246612609634477, 0.15317944899922417, 0.15060373882372535, 0.15676242689932549, 0.12653301875557632, 0.22475044723720322, 0.11045940625931948, 0.1427511077734732, 0.07135110036019357, 0.13131039667754404, 0.1643064164466435, 0.13575074953898308, 0.11021931430384999, 0.13919362527949197, 0.16972138636535214, 0.14013641904438698, 0.11507532349036587, 0.11153611219337872, 0.13116474804137984, 0.12747788861874612, 0.18342725091403533, 0.11861468800493788, 0.23722450369067732, 0.12417120032853658, 0.13216536612279955, 0.07757793195665845, 0.22217473706170437, 0.16632378642116824, 0.07523115949645158, 0.15880417379160083, 0.15013473979648084, 0.17117185127590934, 0.11131567039316702, 0.15665158929844059, 0.1571198222377608, 0.1237876124439701, 0.269623511140385, 0.11284347954055957, 0.12430633057750042, 0.12023618970546993, 0.10938324424768649, 0.11359546378615404, 0.09511092662691109, 0.07304753312059949, 0.23355443691534383, 0.13195440083021118, 0.19086723636475303, 0.28291654622843193, 0.10504450528852402, 0.242731036438096, 0.13065111673166677, 0.1112721412773094, 0.10692689057079055, 0.14064537721776194, 0.15681544018368568, 0.06875850560684359, 0.20604757501954035, 0.12206984413487297, 0.19158377372209104, 0.16318765228554127, 0.0850216482555674, 0.10949303996899437, 0.23766528003879134, 0.13715950862294243, 0.0986112742834995, 0.12590005392989806, 0.10232130020496347, 0.2079156651011398, 0.2238179803375275, 0.1544985911178012, 0.10451356805260144, 0.1750732306391001, 0.15434332041730806, 0.2653515903699783, 0.10130548293912604, 0.14752495403011, 0.13017572853113377, 0.09334913124480555, 0.03762019159752996, 0.12327844742685558, 0.11992651398383802, 0.23552486102186868, 0.10832567518997578], [0.04202548827555391, 0.046659680534034007, 0.06674452174094415, 0.054292026832098925, 0.027787213686913736, 0.04292576799109098, 0.03471460396183595, 0.045190752904501655, 0.07139518105935666, 0.056449284461597284, 0.03531699038801655, 0.04639864373471468, 0.041220379662850214, 0.03447036747069609, 0.07369554391311062, 0.0307995499291968, 0.014693274316678365, 0.025637059607693267, 0.035372409188459, 0.06550836226632518, 0.023231013009565014, 0.03801840793101057, 0.034272816377661885, 0.06153336185361109, 0.007492502214341996, 0.06483278763029846, 0.0853270109021856, 0.048585690693148685, 0.04037521997346513, 0.06922804089563508, 0.027474624915949764, 0.0502222728344702, 0.034323684615834106, 0.0461241735836431, 0.04021984202066257, 0.049332856245699434, 0.028829518442733154, 0.048309358948421095, 0.09713436401779614, 0.030333046433365637, 0.018174993587777983, 0.011795728688969487, 0.020100850529307802, 0.012427046425610542, 0.0676659339918725, 0.024961251314849626, 0.01532602942578735, 0.035141548592477076, 0.021436620586281343, 0.017821223760444312, 0.041872182590586525, 0.020467680240530643, 0.08362518488279275, 0.02403071112630348, 0.0649388908078113, 0.03862594246804234, 0.07492003586864279, 0.08067248283975548, 0.020845712072426276, 0.0212318318775825, 0.011502611957820914, 0.04432182150682615, 0.04002039102957614, 0.0141828146109718, 0.05385124665354529, 0.004712653068465091, 0.09878433354559446, 0.06062718709149669, 0.047407386178571376, 0.03583061020641077, 0.0604968793660162, 0.0019398514526866137, 0.04194068617277569, 0.030521946478514906, 0.035036652003444975, 0.03485305520195154, 0.03604736712370669, 0.061981523289315166, 0.039636332000936234, 0.06808088551605902, 0.033629095677526734, 0.08956482543820336, 0.02980502224677513, 0.013534356614634877, 0.023387032561004165, 0.02736142584903827, 0.019495510834179098, 0.035014374166606896, 0.086524375684319, 0.05586313526897181, 0.04172276863227448, 0.0629872128727936, 0.04013020973352175, 0.030004561337972843, 0.031709606841867494, 0.08157500336247106, 0.07727250802300631, 0.0018403749357187942, 0.04532783284723278, 0.02884168200375092, 0.010370002672707122, 0.05775177565914008, 0.03290165305858658, 0.02509122770730286, 0.01927063530010562, 0.057756567539106456, 0.05129213377292599, 0.06849247391425795, 0.010927082659045776, 0.07101742310389396, 0.02901185311437134, 0.029791165631444707, 0.025392803964355302, 0.014781903028638374, 0.03673913302801309, 0.05239481774849757, 0.04387322340100523, 0.05083031681997161, 0.025724161889464147, 0.034463445866300214, 0.0473213583351143, 0.07666078681546835, 0.06438012925847884, 0.01573442898300146, 0.07408361341203414, 0.05863823131808351, 0.03610166743577969, 0.016945131355896592, 0.06422935166366159, 0.041638832208850694, 0.08358599182458655, 0.06679120713904982, 0.02864849378144549, 0.023129659577182705, 0.04081425730199103, 0.03088212463133518, 0.068141590323179, 0.016982503040062807, 0.12534065652758847, 0.0461948681772957, 0.006628475694601695, 0.05219443979102278, 0.01037862882273452, 0.02229071669130316, 0.03006199494965615, 0.07184990786857183, 0.033013019260139234, 0.02753012415562426, 0.03904256023346417, 0.051662311288377935, 0.0458513313694106, 0.028748470170783903, 0.04508301795971009, 0.051819183112632845, 0.09355083453438937, 0.031334909407662294, 0.07595863658934832, 0.02913948719299609, 0.03434642210542675, 0.016074587343140476, 0.03353371390051419, 0.07785862657211481, 0.05057895954157557, 0.008277569488141566, 0.06684461878913064, 0.05880695835296666, 0.049435722701732195, 0.08789384211864203, 0.06676166678868956, 0.007048475738209222, 0.037044786788042516, 0.033166688836870656, 0.05343328057337673, 0.09477033159665524, 0.10974295317165314, 0.0435501717842154, 0.03144708957763449, 0.01764625310897827, 0.06092996036093082, 0.018436641342216925, 0.015434156990640107, 0.07337757145925876, 0.011292780475360493, 0.03482920305442906, 0.1309997786677653, 0.041108998139539076, 0.023852222216045185, 0.0418281861610951, 0.025546732095761165, 0.02194738098149819, 0.10419653788689645, 0.037910060115879586, 0.0061187255778349945, 0.021201148140995253, 0.06663130926749398, 0.04207327684027053, 0.015834374728822903, 0.010999471264620943, 0.0586925661041131, 0.04149380793434478, 0.0908445753157139, 0.04381605025921618, 0.020717765812972383, 0.04826741180412712, 0.015008032074077957, 0.016902824150278203, 0.022500948454704017, 0.05055320366556126, 0.06277364288126269, 0.10515356556542459, 0.06932084478678242, 0.07659724748302853, 0.029838611371815208, 0.02483749938678117, 0.04944142622632846, 0.0815090202095528, 0.03425276019580422, 0.049846989343002926, 0.014600570016961186, 0.06852080384569784, 0.10300705614950388, 0.06249210173865, 0.042750100199613845, 0.023919965455969496, 0.017522139204365593, 0.025040903391556877, 0.010772162443777968, 0.04439103372034527, 0.04693336544498321, 0.010321471002703954, 0.029860372099304394, 0.05532730273121307, 0.02440177155808816, 0.06992347253065917, 0.03684665346818586, 0.024021378260165937, 0.035081096594372106, 0.04644575814205793, 0.017239420201569315, 0.028136145669005574, 0.02783565342636599, 0.028905428179930297, 0.014133205629825113, 0.01729741688787697, 0.026520952702529972, 0.1013669538341703, 0.05550334973621273, 0.03837856501641293, 0.016223804033812017, 0.021900178474043647, 0.0281987369676391, 0.04803757393552412, 0.03647603545217745, 0.043775876608466914, 0.019358490263262106, 0.05733745232705147, 0.038445540253193154, 0.06345774790632629, 0.07028738727733012, 0.08677988898970428, 0.02513342191495242, 0.010482696121588591, 0.046138510919146, 0.028885266660983046, 0.08975911299668013, 0.030333393088151372, 0.039045996137804566, 0.09896203530051055, 0.0477673402506738, 0.04875184367260626, 0.02364786826224337, 0.05660280082074385, 0.05718562902221757, 0.0209053501021117, 0.03492817012292724, 0.07261984155423219, 0.04178615857756907, 0.03759016861177741, 0.09994584541287153, 0.03265119210306195, 0.04204260267978234, 0.04276483207039776, 0.039933650724349484, 0.026262516771713575, 0.01668664562936512, 0.08593557582747552, 0.04526534305524923, 0.0077837903893763025, 0.03207287041380281, 0.0072279610415740365, 0.07896032229426407, 0.03968286418145703, 0.014207293992982277, 0.039681941045508276, 0.047254000054371935, 0.049367387658886375, 0.019169105667500727, 0.02856540196995822, 0.009670164116898613, 0.03322786095762446, 0.046480841138550354, 0.010831556282937528, 0.04987271074506064, 0.023295640186857314, 0.05306625934017282, 0.006595162840019311, 0.03046924345976403, 0.035659351250937874, 0.009119388076566882, 0.04789995007036675, 0.04075609590677966, 0.005676431896825952, 0.02307807696202109, 0.03769468981772661, 0.022354347954293894, 0.06398942058665619, 0.030275812004542643, 0.029332742447994893, 0.028036437410440658, 0.038946760938532894, 0.04375947083556845, 0.017549383206172817, 0.016581475163900083, 0.03301609510315522, 0.061277032664586464, 0.05177781819516132, 0.0062405139267925295, 0.0028610764908784583, 0.0420947119803919, 0.049270561806136565, 0.047003251815875696, 0.039617566677230986, 0.044241087330925855, 0.06522890871330615, 0.025642134940191626, 0.024532885591108954, 0.04790748454510205, 0.06336458012341492, 0.04144664373128645, 0.036783711684326974, 0.08527660231676795, 0.02231516638740657, 0.02439556241546187, 0.027314411033125176, 0.04711525003996588, 0.013284520978378433, 0.026047701887305708, 0.052603205155220725, 0.032692288889759974, 0.07143825818333896, 0.09811822009543258, 0.07211865151240941, 0.08959763698400029, 0.09192619187336776, 0.24690966302108383, 0.09806935900762197, 0.10059495937199363, 0.21296533365403453, 0.0944728902991741, 0.11764482835367804, 0.1538267779734827, 0.15269952555817945, 0.10605679854990975, 0.17634265365139132, 0.1277821251161156, 0.07561276321329417, 0.2019487135112286, 0.07324690750289349, 0.11574473111860215, 0.1078691557350178, 0.2127755430316733, 0.14457193023014453, 0.10032397875141713, 0.08272015925256476, 0.1298010042838512, 0.11504458804284373, 0.1499318337488559, 0.13631039208942844, 0.1797100237660831, 0.14460448896692646, 0.09608533684044115, 0.09594303600850607, 0.06041002797804052, 0.12234825580831497, 0.14355565331155254, 0.19237209351793413, 0.15093324856171686, 0.1442685594121295, 0.05237698322162033, 0.11997225709379682, 0.19208773700219972, 0.16023381643237608, 0.1186412865776689, 0.29932005150664237, 0.09599631742363977, 0.22285246440479833, 0.1448570834773202, 0.13931215440313663, 0.12133688185243838, 0.1631780302212123, 0.1769140020253197, 0.14556200694172614, 0.22536673432876989, 0.12285922113205157, 0.17104425167124118, 0.0786244310438633, 0.1642146697568317, 0.1545308740629304, 0.07840899179779715, 0.17568047789316024, 0.13360908945962308, 0.15708560875106245, 0.08463176312826334, 0.21101262150031908, 0.13760478956805122, 0.11701718783907353, 0.19098617917587682, 0.08449063441085239, 0.14496807429578998, 0.10239849888509321, 0.09969066918617296, 0.243314458357711, 0.19064510151022868, 0.11972282652653034, 0.07395176201938622, 0.15950644659178873, 0.09542987201242678, 0.09129899568975934, 0.14186177162393449, 0.12403501287823725, 0.17550839922360836, 0.1858447945766872, 0.09830432583487804, 0.25457768220334287, 0.21487318369890415, 0.1330849167800719, 0.16386557881149555, 0.05806801292384344, 0.13138410965761832, 0.13579156670358875, 0.17859372640809706, 0.11856267063487923, 0.1707769789162182, 0.2896363324215335, 0.1565036730420205, 0.11846149340271951, 0.08638032817191656, 0.1741755594529452, 0.21739497660629212, 0.17145102903727563, 0.16241705976426601, 0.18400005485501983, 0.1527932640765944, 0.09311119199640329, 0.28250573923991573, 0.10330965321871544, 0.14567615404244394, 0.17684234216088252, 0.1588897917780184, 0.1329620362770173, 0.1290705088045328, 0.13784952401634187, 0.11803711899706434, 0.14429990772999104, 0.09331038251759545, 0.14153390131410093, 0.1428091159510997, 0.1444131355251997, 0.17057531393103062, 0.10395614715713648, 0.08193528685238093, 0.13688731758344558, 0.14380582698410557, 0.09203425623596677, 0.09574291086004627, 0.11773873541143634, 0.13079419131240538, 0.11140147990156567, 0.12727808522721454, 0.1699932403261623, 0.16106252438358723, 0.14599832465812085, 0.24684350366794297, 0.14593985682773977, 0.07581107273337341, 0.14634208363150397, 0.24923742117901004, 0.2011920178248998, 0.10271085591446008, 0.10233120572182441, 0.28413674043070886, 0.15390213038171494, 0.08336507504986179, 0.1849409946871381, 0.13280852757874997, 0.2884382321949928, 0.17863497258194033, 0.16754439431092433, 0.1810324140974591, 0.1019138563424349, 0.13278611184608552, 0.16979923622021753, 0.10566502884631196, 0.08195066989790048, 0.15630098149901436, 0.16587265256431796, 0.2922799486306406, 0.17864272539173404, 0.17405108548700812, 0.17981635676997323, 0.1271413844980059, 0.11704929458398013, 0.20704629320290782, 0.24565828904028864, 0.11673933540981625, 0.08330774869048789, 0.2624964113197019, 0.13649141866593592, 0.0929518916734284, 0.16124391868229837, 0.12640831496326194, 0.19419081689369297, 0.2140371059818614, 0.14855025546445003, 0.14384135814203372, 0.22048591155438657, 0.18893157732823204, 0.21145033349673595], [0.09098165142800539, 0.03253339076294534, 0.021678256208918268, 0.05541249170839306, 0.03722639942181207, 0.049358566156438285, 0.040188355806974635, 0.030823928762167215, 0.026705365387662768, 0.0120647088624537, 0.04999877434344061, 0.02645462672526558, 0.018193117312846646, 0.09508077340621142, 0.11001548128983668, 0.0030262804789198267, 0.038583972341110634, 0.014302551280707123, 0.018919757454686107, 0.0011871013585703389, 0.05288358184418852, 0.037046855225438075, 0.04087250296687407, 0.030311952202370575, 0.042974950835829785, 0.0037340952070324773, 0.040754651831042384, 0.009323673082455512, 0.02980773228280727, 0.06158329163407607, 0.02908518688092309, 0.02306075571405311, 0.07491308745116958, 0.018315337065066543, 0.06674780059726008, 0.03820681959510811, 0.03423150508634506, 0.06382630131537877, 0.01885765453710431, 0.015852761796615537, 0.013754190332556685, 0.03146899969226891, 0.009423420603026547, 0.044851042705798344, 0.023231696743037433, 0.03659204031611162, 0.08294389523085087, 0.04770395796625845, 0.015574065713031639, 0.05740742296761563, 0.008943698260061925, 0.01943097175699809, 0.07156316881939288, 0.021499035684692285, 0.03740182206515343, 0.01824734293134703, 0.04229102584142839, 0.0478262409207321, 0.03866118251255924, 0.030087984482487364, 0.01636543645403318, 0.021306462247946092, 0.012228357692008779, 0.013631599985303418, 0.07128935367349656, 0.06350116976987451, 0.02305857236346891, 0.05149942567391742, 0.0345434254455951, 0.030065773678342664, 0.02307214361104754, 0.007552699009407192, 0.07737289618460402, 0.04061243526877896, 0.049401834802401644, 0.05936919794147534, 0.030857565767702558, 0.034005467013846484, 0.052264253383562456, 0.0337036858282743, 0.03806541508604442, 0.04776377028094665, 0.035492466657512614, 0.061668568711367354, 0.014415594257204043, 0.050616237379971056, 0.08179135425316711, 0.010759279717721287, 0.0418639816193571, 0.0179667977030359, 0.0023066921764233663, 0.03840469244507052, 0.045491231740602565, 0.06535309922671126, 0.0641808506371754, 0.09752024250525622, 0.05573832805478766, 0.031060512034943512, 0.018575025549639138, 0.019789887779963114, 0.029344461678016572, 0.037785861941595236, 0.028915519473112883, 0.0661938654018506, 0.08289603771822107, 0.024196979018949696, 0.02837279214403562, 0.0942990189838794, 0.031148499148266933, 0.07234784969759565, 0.05261161680062933, 0.026114150438637986, 0.02411319581311076, 0.05124256405378542, 0.0056994609786347765, 0.02312953508789501, 0.0237466667913982, 0.06556227953443605, 0.01790351884049033, 0.030086858333238674, 0.04855692026115233, 0.03716029752526553, 0.06668900334907156, 0.0571760950579999, 0.060574863286268335, 0.04927093718921946, 0.02890354743407619, 0.025835907304539316, 0.02911802140935775, 0.03165130563560994, 0.06882136312103079, 0.06983836782315085, 0.04401861922815443, 0.06941362569529204, 0.021117638811589252, 0.04655101479241445, 0.07024885305473882, 0.06665199364144957, 0.021251510761137453, 0.04208730774060373, 0.06180485192265722, 0.039094834242977446, 0.014094768125834245, 0.050361781275921294, 0.017426985338510528, 0.03197687385123103, 0.008329232542535231, 0.03393056659748958, 0.04034235863195312, 0.05533902770689419, 0.0500776277734868, 0.019374463196483352, 0.05090398383477042, 0.059826713310734886, 0.06084102904424072, 0.12490228569555668, 0.0315127739562623, 0.054109540858095696, 0.08030955634650686, 0.02793355563264941, 0.02329887499311759, 0.04394779822999432, 0.028016072878193472, 0.038270795597664775, 0.10911829273907409, 0.002577940448968401, 0.010675937012438814, 0.02117729024781335, 0.06886319918257576, 0.021942974060713764, 0.015353822138070341, 0.022984401645859884, 0.025339030337730245, 0.02194565919888837, 0.03243884019133064, 0.028671198712301352, 0.0031088819941355577, 0.0906477979714832, 0.026599220075314085, 0.04011188107993334, 0.08585912025263233, 0.025642460527559443, 0.02120430250802348, 0.014651181615678775, 0.10765344835817815, 0.0900082907549316, 0.051069531604767814, 0.040900817576555476, 0.025136597349398562, 0.07296194577769888, 0.08686412035697892, 0.017025656772837523, 0.09353529827128496, 0.03128178695577287, 0.004800303103101831, 0.03198706473584377, 0.026066467211010958, 0.07228948911952396, 0.02274768047725722, 0.03608329281691582, 0.035235670154854175, 0.013770499386854712, 0.06642057380128293, 0.06477908486680639, 0.04694831182038592, 0.0355421474594022, 0.07472505117015493, 0.07353017617377543, 0.04093566308579138, 0.03950749899470999, 0.05589304334153572, 0.030908817049836924, 0.010860090185287259, 0.008805900109901784, 0.016621576036296545, 0.018939957278029575, 0.03870135999374813, 0.0644715771740002, 0.03525280754172033, 0.043482395985554305, 0.045165801420807845, 0.031165192204137004, 0.04033316557686176, 0.049282777078089215, 0.03580688829383543, 0.06745486144697474, 0.05254955218744375, 0.003154766112152908, 0.06889414147383745, 0.07648232663350721, 0.024975240080346985, 0.0209440088139907, 0.013061300194221399, 0.00949412094233858, 0.08863961339117059, 0.10427706138861757, 0.013675118567452077, 0.042930318553361206, 0.06414345788559125, 0.01581332933593301, 0.08396224058683842, 0.02349185254124384, 0.007795710717478106, 0.027906156498037522, 0.1141589520979793, 0.02827333477926591, 0.01928560657336587, 0.0054458853968929865, 0.04148448847474591, 0.02213140104656979, 0.03603818555993419, 0.06221006646932614, 0.0337718025360617, 0.022645957407451445, 0.008955654019730227, 0.034771072302734664, 0.025770992844275413, 0.04030769698381905, 0.07670557231552179, 0.0009478924989854287, 0.02951478217578223, 0.02912979235031432, 0.09587113865681234, 0.06702052023742469, 0.04179597982475835, 0.0567646368947481, 0.11766115368734445, 0.08542025146344978, 0.028580308125744906, 0.024540724585794156, 0.13577531031783552, 0.047294016657096725, 0.10956889033437738, 0.06524505018587075, 0.022150857764626705, 0.028239475608232523, 0.02827295173530377, 0.005936391863806715, 0.05396166673651146, 0.05999596511584617, 0.05328874659514236, 0.0404350629316703, 0.031218651734713106, 0.04315643706509183, 0.031739683453774745, 0.0858224246410593, 0.05970830293071847, 0.01691439207793484, 0.0012377172665325024, 0.03276384916276701, 0.05217912569341641, 0.026056140345791658, 0.042303356026569684, 0.08480564210443728, 0.061283119233144875, 0.04184949489670896, 0.07721153508511282, 0.014562413092672586, 0.05985609278263104, 0.04557609513041474, 0.06605053035121772, 0.07207125365253418, 0.02656754808530452, 0.03656036641088225, 0.06236404631166689, 0.04908602654693588, 0.06470442959858526, 0.05373917948154192, 0.005536936383108579, 0.030693301194978338, 0.030604488621916504, 0.025532011716296116, 0.07586784750944184, 0.032259234707922704, 0.05827674890057214, 0.024208640792377056, 0.015433023180512172, 0.02518095000977478, 0.02694155795559768, 0.05169236108720784, 0.012456917151388143, 0.06847434827396948, 0.010237001190562884, 0.014739707863378911, 0.033585486122437065, 0.04031249652466467, 0.03892953928199507, 0.004379920494337116, 0.05095034364550825, 0.026701375984797077, 0.08694016990522224, 0.10334994178265335, 0.026501547695407947, 0.01061825537979002, 0.04996802357416, 0.0362967134213015, 0.012727996405784883, 0.04501444926004737, 0.01404802144069465, 0.018642439371756008, 0.029978809292398156, 0.06263085558349568, 0.03443409320748141, 0.022252092453380747, 0.03989760245707247, 0.031142470036302845, 0.03134067230407269, 0.052566900248489076, 0.07870952042961314, 0.05831994859862232, 0.024391486827704697, 0.026498004538758148, 0.1688722238665627, 0.1651558547370857, 0.11629170257477991, 0.1330975572308225, 0.14606175673825128, 0.10557573363785783, 0.16788763234451895, 0.11321441931349617, 0.19599532167757713, 0.18843725143421083, 0.16662718788270028, 0.09829394534350404, 0.09209132212544642, 0.12764424461150362, 0.20764946486921082, 0.11187874501751316, 0.12219290849902939, 0.21692300515790142, 0.10963573150577084, 0.1409995549869153, 0.12641481138885985, 0.13937728719845896, 0.15163038857281208, 0.088345313054179, 0.1305184303031814, 0.08003679074106679, 0.1138299632997763, 0.15526077199366786, 0.09542401143980604, 0.13963348232209682, 0.11243600503451402, 0.15916202878279073, 0.15921983777755694, 0.11661274704120814, 0.14529798239950212, 0.12007809214053616, 0.19778678764499005, 0.1835600292730716, 0.09324148056968566, 0.08562120398686779, 0.09846225486046846, 0.17547250034347658, 0.21533413880294372, 0.12891001338439603, 0.14348270641940256, 0.11343247858026337, 0.15660251370601116, 0.09617712949552844, 0.10195185430347921, 0.1916945653577005, 0.16990155492338443, 0.12160869750885234, 0.12049508145860127, 0.19216069921610818, 0.13259835901760286, 0.07333477012692921, 0.12156527564530412, 0.11381777484090098, 0.25471387731452144, 0.158540471006305, 0.09431448629907063, 0.12587939253858021, 0.14507402425571797, 0.12901626977949374, 0.15782747297517716, 0.12727257705503894, 0.1496276508776411, 0.1478601328187412, 0.14717656788566422, 0.1148659669824185, 0.14014993283537128, 0.15232579722519846, 0.20722040966633828, 0.15099013825097393, 0.12547973979024157, 0.22579949739719593, 0.13273368078854778, 0.17859843018795216, 0.17642462505928933, 0.13135810863346825, 0.11559014223636159, 0.15682754437288932, 0.17384206605774744, 0.14876063853021593, 0.0719679007306695, 0.08017323100038114, 0.2218642416259935, 0.16330415893706585, 0.15275594027292344, 0.13486919684275506, 0.19854621060432928, 0.11587076024302553, 0.18546084663079632, 0.11299606127243851, 0.40295210516741203, 0.2392727163650336, 0.35617860695046766, 0.1506948113561638, 0.10500313654061287, 0.07912503885886363, 0.14712678749234448, 0.10671084611526421, 0.1813820566261007, 0.1660176423648673, 0.15154662451917125, 0.0828344212664712, 0.04631160082475794, 0.10867227634955799, 0.1756339916779149, 0.1689925456359502, 0.11710814545832335, 0.08860230490925813, 0.13150014133462984, 0.1502024926125042, 0.10110334297942539, 0.05906968054571941, 0.10651482719807856, 0.19659409599919475, 0.09653621788827643, 0.11381656442198063, 0.17009151408508902, 0.07172155749773787, 0.10593647678052226, 0.11599140376934122, 0.24270711917309995, 0.19727626665224954, 0.09523097260464584, 0.13852565789655333, 0.10563207940468866, 0.12596635883974452, 0.19038850802087015, 0.12037603139516809, 0.11209934769618897, 0.1488371094268176, 0.12603164485265173, 0.12554328678356064, 0.2194709982722998, 0.2095228409574878, 0.16652748920023444, 0.12089212950799735, 0.09185975672857416, 0.07664089917295402, 0.10420069774432529, 0.13384567273239936, 0.10761943405434009, 0.1482669561500511, 0.07379792390331145, 0.11308903370292918, 0.2033613643218433, 0.21637718283361007, 0.11810019867674959, 0.07454983920099274, 0.10729108110911424, 0.22076870525075545, 0.14115899320571654, 0.29500280897463527, 0.1370969498830457, 0.20066672665697916, 0.14881043424529417, 0.1365606730142909, 0.07665297271864069, 0.14570160348328853, 0.12897062626096512, 0.08056054207225961, 0.11831565324457423, 0.10549416059568044, 0.13200980430889514, 0.09784695602232411, 0.14631635839900664, 0.10857616295857776, 0.13864596434418233, 0.1137979484854206, 0.13945168965766508, 0.10079976531767076, 0.1063399599684823, 0.15384795264370982], [0.019520594468039852, 0.07191989000045484, 0.02420807963297252, 0.022797822847121188, 0.05692352736068349, 0.0709147520002819, 0.11129205190246144, 0.04449891039140282, 0.08188248807263952, 0.029289085012409958, 0.044074401920360905, 0.02669029452297236, 0.04332774581627981, 0.08191919134509179, 0.06152701864559805, 0.010603110779136901, 0.026784046447925994, 0.014144851123884082, 0.001501110624127661, 0.03217388485227862, 0.048435483833835016, 0.04492610017017973, 0.021275121590963775, 0.035821298407691146, 0.02803335390654543, 0.04225236138388996, 0.03785885479902068, 0.01991128398766441, 0.04066282470199851, 0.05743326311330161, 0.03546252028055249, 0.05819749327436571, 0.03256707564897595, 0.07718983947509721, 0.01635601165734472, 0.01602368271579185, 0.02679829568331761, 0.02046590483176612, 0.11867881722507939, 0.04054620696772491, 0.04583146287909439, 0.055362699823754455, 0.06670155186927126, 0.02858203182357454, 0.05591257858360487, 0.021354379132390026, 0.036425190196642955, 0.00898009318212468, 0.017356235203483415, 0.010214959883371429, 0.04118366489907907, 0.032439353470239914, 0.007475392119358144, 0.0045353463276349495, 0.025414093547771056, 0.1058417346869265, 0.04151934930574029, 0.060356987880602966, 0.02728557356843545, 0.012123724445700647, 0.0415067509898255, 0.02954193616225835, 0.033795106930718306, 0.03879491465106126, 0.08096289911097096, 0.01761663614982559, 0.022118705054444653, 0.019973873371078123, 0.020943930289978464, 0.051176948623070796, 0.11768025992017601, 0.04445019486029783, 0.04908285877336899, 0.03942322166215989, 0.014908074836937651, 0.02705032711908702, 0.04095779536592384, 0.005126394173731247, 0.07521313344759327, 0.013231001118378294, 0.04496516682387841, 0.02388610628493611, 0.010309078572918812, 0.03252586011864966, 0.03056546984871309, 0.029619692171353008, 0.0969917873942083, 0.02184752142056823, 0.017571111374925223, 0.04924363764603773, 0.021172463893890384, 0.0629728755372907, 0.028302434629069704, 0.045464070093247204, 0.009209240613985927, 0.012968006964412429, 0.06322541642152975, 0.03885283472857649, 0.0569077612712018, 0.01709673824089189, 0.020053521617345756, 0.044378236221570166, 0.0626171847444869, 0.037925044795678514, 0.05873053725208006, 0.09031952929592903, 0.05562753258873859, 0.021430392291456945, 0.03404765547583661, 0.017013726868636666, 0.004182462768268682, 0.023398073803212856, 0.007493522068891194, 0.0986220301579564, 0.04256518572689064, 0.03938117875687538, 0.08130217646999706, 0.12092320969508541, 0.017500734707761197, 0.03346879944025028, 0.06736388850596643, 0.06282697409211148, 0.018277681928368348, 0.045845715944925626, 0.04204582790994356, 0.0455383078435496, 0.06059545956011261, 0.012036774423904719, 0.010883848487039008, 0.009462383834855452, 0.07370921858255902, 0.02050973655235383, 0.05745315458625556, 0.02166987137658702, 0.07013337296103278, 0.024384825693203077, 0.011761266223695731, 0.025955702388478864, 0.11632364844122242, 0.005673284711872018, 0.03008845754178061, 0.016214540115587654, 0.008945579963525938, 0.11600906209599589, 0.05413698212754342, 0.05609090470017926, 0.06431885754629489, 0.02396755675304561, 0.06076232117090014, 0.027111468596323848, 0.03711829675481685, 0.06585669478461628, 0.01107659716639788, 0.07440170077907463, 0.20307098635502402, 0.013684566346778265, 0.06535166664229286, 0.03338833722556311, 0.03069125190978089, 0.038585964169713764, 0.09560152933362032, 0.05493250314987475, 0.02523017881978904, 0.04436214454472066, 0.040126980672920906, 0.08261931909909172, 0.03229968798076434, 0.03230121632617328, 0.028320027838250803, 0.02782092921646132, 0.11975098025774765, 0.05468994439128907, 0.06165123214164089, 0.006118138562963014, 0.029523561543394482, 0.04062226417684748, 0.06272285508232252, 0.0565356953490165, 0.05106125019430634, 0.01645693799570924, 0.09282872005696259, 0.021603369199100043, 0.026726314061952215, 0.04782257519001442, 0.028779291803197517, 0.08512421976774932, 0.0330736474584668, 0.06244131393970982, 0.054271369271220705, 0.00949526815900519, 0.010745503541622913, 0.06301766869822337, 0.03532408819263501, 0.017973700155233665, 0.035118320806612896, 0.03483594462816273, 0.0550260424854294, 0.055787327038424636, 0.03416978138228578, 0.056228417482587605, 0.020022680832734032, 0.02453008170930609, 0.02535620219855299, 0.03949035394696459, 0.06651900843867371, 0.033670292055654916, 0.04788004710609394, 0.009977750333717034, 0.008050252048809442, 0.05607980791659606, 0.04759800417589084, 0.0249317167101488, 0.03814988777101521, 0.04289621614941186, 0.04747546075152294, 0.0065744243611040865, 0.03326023966374417, 0.025254852596610308, 0.006326680144880929, 0.013670610140017686, 0.04132542563902755, 0.03103950590405974, 0.04039062600162241, 0.0502745506744231, 0.015429532692407169, 0.07616786286234856, 0.05641518205764794, 0.050005006468704635, 0.014360230998136105, 0.0635740821880679, 0.014022326851714284, 0.014016248901645023, 0.07027938931940064, 0.03299303585663438, 0.049088926189729286, 0.0537468710043017, 0.06888943003310312, 0.026365187875325644, 0.0332728456405382, 0.057180637959390886, 0.05060259335403962, 0.044023089351192604, 0.05859478647189756, 0.06293788447134918, 0.045948988427558256, 0.08447276157957893, 0.02216508401738059, 0.03248651384285862, 0.03508089358107217, 0.03950919970990189, 0.017745741117264957, 0.020148081765059504, 0.0628058607089183, 0.032724568004449534, 0.05269928407224436, 0.015302069068345574, 0.04827955812816659, 0.02599428449156544, 0.017303802230725848, 0.01700226044763, 0.02242007446775754, 0.019081028538846204, 0.09064556099474431, 0.07989070543478574, 0.015178349699013898, 0.07592535006903833, 0.0009171310762946134, 0.02194801491925553, 0.07681804934456464, 0.036734073017273224, 0.03985799954182679, 0.03917575994085881, 0.04312125830760887, 0.0601411004731011, 0.08920264205024128, 0.03463511084837299, 0.0725876811831709, 0.01279045363903166, 0.042410623657727436, 0.07297316130491034, 0.028964087532292453, 0.07179874851698838, 0.04113888705990488, 0.04765191378312246, 0.025282707553537145, 0.01912549228197144, 0.010266362467870839, 0.02157380969654168, 0.010653219632654181, 0.10621164790204457, 0.037699075671093124, 0.08858031052495204, 0.043372776464469014, 0.05020837982996337, 0.03806686299222131, 0.033083208235761816, 0.006115358142602828, 0.060864310456259604, 0.04643095732336083, 0.05162973339939791, 0.009037656071145208, 0.025328006332499847, 0.034788834051259106, 0.033972942751021154, 0.14413918248347699, 0.02723567634670725, 0.043513912842759205, 0.022762743681068384, 0.01679743534975475, 0.023340586565374848, 0.04409160825514025, 0.008216430883734457, 0.05857010311897724, 0.01774194898203977, 0.008337560875882066, 0.07786745956588177, 0.12029300278593456, 0.026754622925974192, 0.01575370950083579, 0.036864913173861084, 0.08839794329457706, 0.017668038734325, 0.057530671192873875, 0.05437140503237325, 0.09556662636779009, 0.036685924391232194, 0.02761470983856388, 0.024568876401791652, 0.0027937218011732426, 0.08086942106245026, 0.026601426408536015, 0.024603356104043704, 0.04206877607371538, 0.04562513624888755, 0.0298192274321111, 0.019351174123585224, 0.049732685194260655, 0.057737277445173076, 0.04093240338167356, 0.018370131503850706, 0.023106090882192218, 0.02815880654980579, 0.01565914073463289, 0.024105485138152877, 0.06758246871252215, 0.061650228566460075, 0.07461974472408334, 0.03515059226042321, 0.08978085457197121, 0.029094418240410667, 0.008396459630720558, 0.03138705892788787, 0.2122159158029864, 0.1455207607678829, 0.14091937622476008, 0.11695202440023424, 0.23648962618843203, 0.1525729678330883, 0.2191086540058736, 0.13526694969304148, 0.24234926418191005, 0.17284598321683947, 0.19845588883805662, 0.13391437549744883, 0.2317924806547742, 0.10603557025352794, 0.2055237700621928, 0.14206985642592754, 0.196257921296262, 0.08106205387101059, 0.11312836465696174, 0.1492836773996392, 0.13298681156048853, 0.1300893291350334, 0.1279112645575116, 0.14285207816189335, 0.04304207929019486, 0.10612103502236067, 0.14115448860872176, 0.18855637810643644, 0.22287799045443538, 0.13623882415554217, 0.08385133403804033, 0.13259049895549976, 0.13176914544836169, 0.0940496726862846, 0.07702025059129923, 0.20484870870507535, 0.07059403695166111, 0.1171277343265472, 0.19242924367708547, 0.15893796338669716, 0.12481522746384145, 0.1715972445785038, 0.15907103285914467, 0.08709067553882638, 0.11510595934645784, 0.07112505845725536, 0.11763556635067349, 0.12467681069768245, 0.06941889638021108, 0.14898384590783428, 0.12694611634698608, 0.14800293160782707, 0.08733224604398974, 0.11826315323912329, 0.09230025728503544, 0.15967797367803513, 0.1884935895401624, 0.12860376207578567, 0.1421234519371102, 0.10050327396921574, 0.1668690571621541, 0.14443651652864872, 0.1908563272727113, 0.19672701225405742, 0.19503896815642235, 0.2038879731609937, 0.11682640130241072, 0.09385244335017859, 0.17831534537817204, 0.15600706420598492, 0.21428043082837137, 0.12750349893805482, 0.15988412793845902, 0.14834878966212273, 0.1504407919222309, 0.1311133741851776, 0.09034370703081931, 0.13897719011912424, 0.20391547571747534, 0.12763472213860483, 0.09810652193282882, 0.11183454940516142, 0.15593339719118612, 0.10980990159535602, 0.08171213310091727, 0.05715991528103909, 0.18478955442626632, 0.17125520164207106, 0.14871105731975648, 0.20042842734725247, 0.16651023690017963, 0.14903125142858875, 0.21080239165213802, 0.2488703424892118, 0.11196778741695228, 0.16331753483222378, 0.1433723591147892, 0.2999647911037168, 0.23760659770379144, 0.1515389329964115, 0.10446623147976015, 0.12388908078954106, 0.11029269020523756, 0.16733214199062318, 0.18477352786689036, 0.126077119831837, 0.30947178902645267, 0.10255761534696627, 0.1469327527428827, 0.15956485313513588, 0.13143206676167826, 0.16802614104122887, 0.11675986656618696, 0.22772902773032266, 0.11338000921832939, 0.15061581236941202, 0.15651321849755703, 0.16179968482784687, 0.12055890424357307, 0.15393081271359998, 0.11236546365844627, 0.1343519955633148, 0.13766918691896624, 0.0935405306518078, 0.13753340549526677, 0.1392118888156068, 0.09545362839895873, 0.13242453366758364, 0.18611234312336292, 0.06944092906891339, 0.11959262988379887, 0.11241022617586198, 0.12988061614094243, 0.13724789984764593, 0.1349942377137561, 0.09916386882504148, 0.20704145152722636, 0.10849771555513145, 0.15468925508039613, 0.11276029771374119, 0.16012972040522486, 0.09513580150181249, 0.2830650140681575, 0.14351472889463748, 0.21025967964481926, 0.18728851791351073, 0.1591704557499578, 0.14518585777090443, 0.19124965213479536, 0.11090096401711626, 0.09055947569469291, 0.11763974919074005, 0.12144233385521559, 0.2925473133162145, 0.2195756458827565, 0.11606208304123533, 0.19977850899580987, 0.07922703580510232, 0.16505860753597754, 0.10112853195037573, 0.2582569726772847, 0.2656376782444216, 0.14132370210943684, 0.16637110001137181, 0.12116609021059929, 0.18157884929208987, 0.1369889621292391, 0.06882362308040743, 0.12238260719083971, 0.2698152782695909, 0.17403914983714783, 0.10434502870925974, 0.19712284988453313, 0.11372265736422232, 0.09570138123367103, 0.13400244496522412], [0.04520889769698824, 0.05859522697245402, 0.043088940888523095, 0.06144942926062692, 0.03273321330667504, 0.06384134345177202, 0.020910701226262797, 0.0517426815725142, 0.04047875292599201, 0.02328101365316299, 0.06388663456985547, 0.015116287001048126, 0.038328995297272364, 0.01970593795000065, 0.10360317980690349, 0.06953881978387795, 0.0392330288436384, 0.13732486104051914, 0.006940819796234851, 0.059821477099772424, 0.030068659914597392, 0.06777392940655833, 0.03083386300732532, 0.00534050329963887, 0.043901633771677176, 0.05489335605694402, 0.07967358079528616, 0.042909618857647144, 0.08235693398502567, 0.034599510742531675, 0.04396127754702203, 0.012111503428088562, 0.04738340379610177, 0.04282565562114601, 0.034160193791913415, 0.03796300062188699, 0.061103322227755864, 0.0680048359678157, 0.02786737138165101, 0.04764640178050726, 0.04382025608192048, 0.06533329585386861, 0.031932302855796395, 0.010353134374224372, 0.043735208831006483, 0.02283978722839346, 0.013592166567010986, 0.027579103987063133, 0.03127864791050313, 0.06893164147773097, 0.06712444006435334, 0.06777296413577373, 0.024142291832474932, 0.07658277608213887, 0.07169699671888544, 0.04217704728005394, 0.0226804907358582, 0.07107457326304528, 0.002184219136383505, 0.02805528700381758, 0.048318743525493535, 0.07733991609946375, 0.022789901497984127, 0.05362941440375102, 0.013435719921554049, 0.036120857938282916, 0.04964002302937931, 0.0010195204630426523, 0.03446281001332306, 0.056213949912137566, 0.019953849747957244, 0.06155878448137834, 0.05748581291446763, 0.02568997904628275, 0.03475472781687014, 0.05741179349922365, 0.019690775154759328, 0.045214283295095935, 0.04782932059418771, 0.06642316317846698, 0.07793999277055264, 0.04810894268655008, 0.032899500351519353, 0.07659473471463689, 0.05283409639471962, 0.01987231117973645, 0.08830198312118169, 0.020535203230176723, 0.03162714322247813, 0.05871582070305463, 0.013064876867217884, 0.08080886947291513, 0.01711938188471381, 0.06228215917344056, 0.04903975100586972, 0.05480060196151176, 0.002295655243459248, 0.04238850669935346, 0.1097300599118875, 0.0313822498109432, 0.030003165142730843, 0.06115318306030766, 0.10723778437222205, 0.03734602405118846, 0.00945162891800846, 0.05542527005497006, 0.010612833392505926, 0.011189571194981617, 0.05974709379276442, 0.033040498833983176, 0.052835314474519224, 0.05529191329955094, 0.01318238613631336, 0.055011609388935956, 0.10398024828323435, 0.03639188069369524, 0.035298148455518874, 0.019423693921717427, 0.02673711207124495, 0.031082219136277997, 0.04127053543925285, 0.020299809308902874, 0.04713324927574685, 0.04196395609347571, 0.039157412135072296, 0.035900190142133546, 0.032210174437251785, 0.04170404544340507, 0.05940092930329904, 0.04129725658605176, 0.01927766224159108, 0.016054761945270002, 0.061382530632639126, 0.08080745221025522, 0.06377206995121895, 0.052701383153156894, 0.01315153098755306, 0.0319178965723803, 0.06950652917786952, 0.024829018793459383, 0.03444386465895561, 0.022311297643388954, 0.024886092343818278, 0.053096707504723346, 0.076617234716973, 0.025482271542592395, 0.07063395779339537, 0.03007349201417979, 0.06842678953563014, 0.08033262325390693, 0.09821328394595655, 0.06765878639153897, 0.0631650410322172, 0.019019264615170898, 0.045361398989635135, 0.09149559683376744, 0.058294307635796655, 0.058750344455362334, 0.01670224700994309, 0.025157028914339123, 0.047400472235054746, 0.026056439120082125, 0.053180264714624614, 0.09601317135797394, 0.007807598486843129, 0.009518250796733605, 0.022515668834169066, 0.10487113193038011, 0.05423808658135034, 0.027054023493321675, 0.03998356135261636, 0.013724313861119651, 0.022960262215365807, 0.06378424308833576, 0.024952311068773273, 0.05114609060148078, 0.02080330336015792, 0.005610472684155309, 0.026007049431603764, 0.05270378483879951, 0.020792126137342666, 0.02418235057003556, 0.07486100113319774, 0.050623867615696885, 0.016008587910853807, 0.02446740039534146, 0.03907432606924446, 0.00819182797004619, 0.057269492667288556, 0.06115862228457005, 0.061806345794109575, 0.040231348661285256, 0.03924453931470071, 0.07305193046528487, 0.033612548178362275, 0.027398014208301905, 0.054309937967768604, 0.05050367608125653, 0.014405883135153882, 0.031341097482870665, 0.062402967408659964, 0.0219361079976924, 0.0777599927518637, 0.040255706426837755, 0.041286818638083436, 0.03391048360255457, 0.04706304880880541, 0.05290764083545055, 0.07258971897704948, 0.029467250250520247, 0.0435207310252853, 0.013543544881676715, 0.01666038030488116, 0.005511240836518307, 0.03298171307711351, 0.051654068182312676, 0.017768158765149214, 0.002001913671847433, 0.06220267372085683, 0.015186487467989567, 0.03968160396682159, 0.017110412910340295, 0.04599880712527422, 0.0434368827019728, 0.037682911215890805, 0.052841266977690884, 0.11683215462272206, 0.038592889604549256, 0.04230739330993064, 0.05713926155060049, 0.058797830415348855, 0.03824270315348141, 0.02264194693716784, 0.06294153488030838, 0.03955717596615996, 0.05887259293587939, 0.08244240641473763, 0.01918572019935856, 0.01950248223429005, 0.01295451998650547, 0.06381158859679295, 0.02472996937050935, 0.03712522985053159, 0.04041157467591186, 0.05498618676116871, 0.03266546049065167, 0.05521097994079033, 0.0119498263173286, 0.023376631002212246, 0.011108471212097475, 0.028112303097582156, 0.019668227271927942, 0.039514972182411345, 0.03728890070511449, 0.016908562148831064, 0.09604156257644778, 0.0030516008818296777, 0.04319851444433293, 0.027078611085251458, 0.03491478656689006, 0.013872963646727224, 0.010739832575763426, 0.028054758403149825, 0.031390512069206566, 0.03381283037484654, 0.052518406882882125, 0.05937238869767997, 0.036516592146888856, 0.05282751186901043, 0.0568142295965264, 0.011514402050975592, 0.05387842362265914, 0.021425539124456626, 0.07108765038391275, 0.04215931617504647, 0.019746561677405433, 0.1140131808877472, 0.01864279368742099, 0.08949416914894696, 0.023742248379294912, 0.0605779352988447, 0.05886823772602986, 0.06942933815861903, 0.013821726728741442, 0.03020686600657721, 0.00889624485881218, 0.03316423735551296, 0.0670215238126055, 0.035804015464119376, 0.11560872752940464, 0.0477819801909068, 0.027148058870807294, 0.015780395216068194, 0.03562976110486254, 0.05309771491034378, 0.015592645260415252, 0.04170383859966551, 0.014476241607729708, 0.042733518226492795, 0.023728223224621148, 0.012514754874451507, 0.05466669362278716, 0.03695628448059002, 0.02482663051435544, 0.02155531058839012, 0.0733302578690552, 0.02538411652729396, 0.023527125144497524, 0.06356242616029997, 0.036010981777742986, 0.014093817219198232, 0.045427309364200606, 0.0362593436523551, 0.03779205959290266, 0.07496216304359898, 0.06494337242216834, 0.020598577853712826, 0.05124437968216596, 0.03898640981905403, 0.023298581964486552, 0.034693854470406814, 0.026582479138948747, 0.047355686735001304, 0.01863752683294156, 0.029612975495476878, 0.037962640560562574, 0.013907884807145644, 0.06749000190006149, 0.035437231718171994, 0.018742298932685968, 0.06304902467696417, 0.060666115849369, 0.07715181087053592, 0.059946632883962125, 0.03476609273122684, 0.04556164288172319, 0.03032002293865287, 0.030725070861198252, 0.056145159046976804, 0.01873524709334297, 0.06207276053065735, 0.03705605211096906, 0.09431625596217572, 0.09681497430128437, 0.032618219678800915, 0.07735631038104335, 0.050555406168343565, 0.03229528297519973, 0.09206853100969907, 0.052929359428103895, 0.012253029553610231, 0.039581916775674596, 0.19063554073293365, 0.12373354195827439, 0.12959674992147954, 0.16403270855305657, 0.18480230212932636, 0.15419054716344804, 0.1549127842149427, 0.1027172297659901, 0.1525868033810008, 0.13527018258408194, 0.12676178793152496, 0.14900201751339823, 0.165005395068757, 0.24240112833438382, 0.22453845538679632, 0.21682863844738853, 0.3209951303658947, 0.1827767043704948, 0.09680223425910359, 0.1844107392694681, 0.12890200010470806, 0.1752879497625174, 0.18091803717036403, 0.0638873738447024, 0.22523720418253254, 0.1405000963038014, 0.18524543802824714, 0.13951985616116755, 0.13533773621724499, 0.0922393303124174, 0.12045416470256545, 0.06652227963411039, 0.16385356655284283, 0.18632389064277374, 0.12363054143685488, 0.14144739466569117, 0.17177445603714836, 0.1272111061599947, 0.15554773320834483, 0.12131695590552785, 0.2989427072386588, 0.1603412219593602, 0.14746211949856053, 0.0816973016387032, 0.21923464482590077, 0.16903255074735613, 0.17138215773288282, 0.21776084487716998, 0.09478360023950377, 0.12074972142375286, 0.15294409146712673, 0.08555237098687118, 0.15121000548524244, 0.1434344428801729, 0.1629310128309073, 0.20792878052640348, 0.14255109753820205, 0.1545754603801235, 0.10013150682132091, 0.17472579444368042, 0.15875891331703434, 0.1605904610046456, 0.15391144601087417, 0.1972631052617104, 0.15344543472653435, 0.09019496339944102, 0.12916178051983157, 0.26930533950367286, 0.15962387254882246, 0.16375353079169028, 0.10800643103016962, 0.12547168054527816, 0.1590718449123444, 0.0860459078103304, 0.1634075808068437, 0.08518739137798549, 0.0889510281323906, 0.057296424488266634, 0.1179187047866083, 0.19153226197006243, 0.13175385433339304, 0.14459543380766146, 0.12470648128298983, 0.19899355998683363, 0.114861186593771, 0.0885257344212263, 0.1745989915704535, 0.07012971872163397, 0.11356973089277746, 0.12555796502818986, 0.08140227351818355, 0.20331864725918541, 0.12090414176665007, 0.25989220267341984, 0.182757873929316, 0.15752626252510857, 0.15526386698888195, 0.1857720775109145, 0.2112262681006424, 0.2250326127414742, 0.18968281846853996, 0.11029067539399671, 0.27674567735483574, 0.17779106544631143, 0.11991864626085567, 0.08739147996229511, 0.1751981029707578, 0.055658873245720906, 0.14607202231643662, 0.10564744712844973, 0.11555448084348634, 0.21328152878390205, 0.07650321019032309, 0.13152287882422248, 0.20593836152505493, 0.1820375980629075, 0.1422383344822353, 0.12858261804907553, 0.1320732057455086, 0.11836027020528433, 0.1476340755940445, 0.11244466182805839, 0.14415159310785033, 0.13482631124075384, 0.1432586563450675, 0.16708700917661193, 0.11781251733942379, 0.08748109692767744, 0.1942182275196237, 0.12060439454451685, 0.0896639112503298, 0.08795741209459883, 0.18542303253085385, 0.16028940377216186, 0.18125231197524458, 0.12731664243244356, 0.14316422834752068, 0.11725616896705282, 0.1436992335103212, 0.15177429052850894, 0.1320013620199696, 0.09048179437917087, 0.1965740398173371, 0.1953881203887924, 0.16360579839637204, 0.11307812461088743, 0.1432273386707229, 0.21809190211276855, 0.10796362203696083, 0.1520109197665607, 0.22485780679891187, 0.1490838203819529, 0.14646605197941104, 0.10981173254549505, 0.18536044314744013, 0.2184668715081869, 0.14321676665736785, 0.15399136430313512, 0.1271976459951651, 0.08807136767333554, 0.14595948400035982, 0.08990625550429668, 0.20185313638179533, 0.14448773716726612, 0.09896981875382124, 0.13878657212180479, 0.25293440828400277, 0.3456122932895538, 0.12466238526206826, 0.25576033809733006, 0.23667578555403218, 0.15602074653631257, 0.19694556181709613, 0.16096657953195034, 0.1424470168328093, 0.15782204907267325], [0.0967867746047916, 0.06282043936211737, 0.024861468362712094, 0.032461987537962776, 0.05173385240918687, 0.03333260815951132, 0.014803974021736895, 0.06167334910001486, 0.0320838044037021, 0.04166036694040222, 0.058392646512196916, 0.010820217224048271, 0.021980611960433667, 0.0361435494626001, 0.024521323409111753, 0.055070414298003724, 0.07339251783466147, 0.004083527779702338, 0.035020732696378426, 0.013961439141102377, 0.03601102391257882, 0.03131456977327264, 0.00841523070008524, 0.039724937730258515, 0.018633545090955113, 0.049413134599284786, 0.03688931307424942, 0.05012733155801412, 0.04482623677881015, 0.1162305074713884, 0.02250294411374677, 0.028447426344838836, 0.05532528408953259, 0.05389483705643685, 0.0594121793044671, 0.02400278722146346, 0.07654123113400514, 0.03505099316938751, 0.01718616751473277, 0.038231579556820855, 0.04715239381297462, 0.009438686820137645, 0.06633431996188818, 0.026015028237335147, 0.02711128665044183, 0.03146746751642035, 0.02301385772654847, 0.07962923962622881, 0.029999260009536823, 0.035175578218073614, 0.038284133188426495, 0.022059980584608934, 0.08369948775056871, 0.03774811295912631, 0.06111382146275813, 0.02143759543316499, 0.025355773189315395, 0.07351382019659204, 0.04588583596952019, 0.043736128136515624, 0.028836449623228084, 0.0743902937298821, 0.03538222277476903, 0.11835429471947494, 0.06288758696868055, 0.07190832973367746, 0.024967954584187078, 0.04522963186665889, 0.10113911162461005, 0.08133989097850938, 0.06606211360063284, 0.053679390149491454, 0.064231967853923, 0.08000865233160796, 0.07711352179608039, 0.020565509668461258, 0.006481003290372751, 0.0562495538484185, 0.06454847707983948, 0.07072507629110929, 0.0268402275058531, 0.032041863005067554, 0.05663571578841056, 0.05449612414644611, 0.05695097629101046, 0.023060659953062574, 0.03427816367137336, 0.02419549280837659, 0.17094165717642154, 0.033711457790266124, 0.05512019086088385, 0.03568783439996262, 0.00922243839370147, 0.044052392214296326, 0.0459239756568305, 0.06572429180866288, 0.023771859592788165, 0.020314702058150884, 0.04237835220391712, 0.06144401301900226, 0.02747465364424692, 0.010930827871385601, 0.10417904809958513, 0.020077781706687906, 0.09879597808204352, 0.021704446839829607, 0.05813921696596569, 0.022975141558075146, 0.0031243572096084997, 0.021275226928053365, 0.060316841042931044, 0.03944118259354465, 0.02272856658354642, 0.05942212695616388, 0.01950788315415623, 0.011352256668971912, 0.029927136661905437, 0.04451104522412343, 0.06783589059787412, 0.024096037358826688, 0.03864142893543167, 0.07527246695732878, 0.055060141058939124, 0.025336075153562333, 0.012266672621931762, 0.025519882629234946, 0.05080631911574353, 0.056203776264503125, 0.03300886706358964, 0.04567916076930781, 0.027220122846624544, 0.00917776684922677, 0.01354045658973196, 0.06207123218524841, 0.05124119658684058, 0.0403160281899956, 0.047276143825823264, 0.02374701727662356, 0.049590453310238744, 0.04933153857446967, 0.018744532078985247, 0.012793562998394332, 0.007067859677913329, 0.04599603388698832, 0.04950692674385444, 0.05928138894359431, 0.03993871073508936, 0.01691485364590922, 0.02034060923653024, 0.059576846073351564, 0.02442495337867689, 0.023807430970332315, 0.0727698415698063, 0.06295555428932272, 0.012253403979083224, 0.07464101132486137, 0.04336312375662308, 0.08660067804157735, 0.0495642799163057, 0.03818715028765221, 0.018971366882925073, 0.05079502697973963, 0.016132110970154885, 0.05307050346727333, 0.08887800463144818, 0.05288822433700966, 0.02350425741995775, 0.07199125875148081, 0.035086252366102515, 0.030286175258938345, 0.014433739049690626, 0.05328234976097461, 0.02954158567703299, 0.04995144926191819, 0.030790988896642963, 0.04264753634831117, 0.0488892492027052, 0.054923467142807866, 0.019925293820579688, 0.011801292402519575, 0.05182986620873694, 0.026823111186404864, 0.023872111773779316, 0.036242865101103826, 0.06659942468808544, 0.04466094947870701, 0.06385323313635684, 0.06653470558024223, 0.09966894293264036, 0.04110619042729659, 0.03434153829490946, 0.044469875659072594, 0.054057914192878434, 0.025932510991791086, 0.037686737825072585, 0.010835425984565049, 0.018770364563791983, 0.03125130431726575, 0.02988661635637043, 0.06605636794120073, 0.1374334003776312, 0.04811738114503603, 0.034000027789584095, 0.029132481318928545, 0.03617686662642706, 0.03644098692964162, 0.03714580314173814, 0.06716393189685, 0.03519105319414408, 0.058266996601296056, 0.007252669771156846, 0.027450071797976573, 0.0368367632730834, 0.07847293715683684, 0.047853088472038514, 0.01402322125936588, 0.06714734609328932, 0.026049904390088013, 0.09878836316807617, 0.09437918242427612, 0.08317659443785107, 0.017318853943218148, 0.03090429713108367, 0.042151674448001775, 0.0267229107163486, 0.004872510720404887, 0.034964222220643874, 0.006095648615530903, 0.057314504163279656, 0.08100833578576004, 0.03625501525558291, 0.020475697350658236, 0.04888821498400742, 0.027268466825086265, 0.03054149512712273, 0.03196708707799835, 0.06547623253878086, 0.06472756545389853, 0.09253418223271448, 0.08986819625621842, 0.019255755957396283, 0.01200035939203395, 0.08004183159960855, 0.03555085787910127, 0.02938034906682949, 0.08641050437525397, 0.04066228461001189, 0.019672938712662267, 0.008172063859209659, 0.08308558319244655, 0.08740246566312929, 0.03861777214032989, 0.09034763706187088, 0.05670749822691564, 0.10538281737676553, 0.031208135262732545, 0.07139751762752572, 0.05304524171797018, 0.04089997871027839, 0.012208551446336412, 0.04175316700110993, 0.038191229705849004, 0.027120447146796414, 0.013026554276415659, 0.06774875575736647, 0.033759725159935416, 0.03732467318073877, 0.04743646304573744, 0.0628181181157068, 0.03712428756238472, 0.04835307192538054, 0.02945133477389332, 0.13969682247167634, 0.036778310764460795, 0.01719610750555031, 0.08028376216609633, 0.04482178197753045, 0.06725390892355673, 0.10461196438559603, 0.06970900621625685, 0.05369104234681976, 0.047638989879839846, 0.043268887281057336, 0.050999890382011095, 0.020464163896958196, 0.006117106738289999, 0.050755676873508966, 0.02399620652619389, 0.022899919384790045, 0.016042878963954506, 0.02653354144234571, 0.02300497493706644, 0.03875943711928783, 0.04292739592793007, 0.07812628237109992, 0.04994365048684901, 0.060703106404792886, 0.046540573014006506, 0.10698661478536745, 0.009269666756623456, 0.015462716748457284, 0.015851130986946727, 0.020901165346825318, 0.04747063439759997, 0.04129068738210105, 0.009422415112625928, 0.05768886451879817, 0.06081648741758639, 0.02720306589899044, 0.06528297919900188, 0.04668279723714917, 0.06186605468692799, 0.027639146128128615, 0.022660593517244827, 0.05632189170066869, 0.0137461569430607, 0.05851046317407201, 0.04334620853525497, 0.03344251496356822, 0.03701588229065941, 0.04291240358725191, 0.05535129277456192, 0.05720019235365814, 0.022840785057914835, 0.019602514165002975, 0.03335874324904815, 0.03071166432252334, 0.1019957894459367, 0.03892806456274083, 0.044174004841836235, 0.06611420757948391, 0.1017469487663719, 0.07814586357844454, 0.09621997679313345, 0.027042560902754628, 0.05898518870855051, 0.01331726166104237, 0.05960040327702319, 0.013637699960400502, 0.08080892309906983, 0.057151963288385066, 0.014735275087127042, 0.043444911303419265, 0.05950733125510235, 0.0583039986480388, 0.012879736398557022, 0.0643098023870299, 0.10142969643516887, 0.00476559836252202, 0.021733941224914406, 0.06879254289331936, 0.06221646330349388, 0.1652035513712514, 0.2147783726573952, 0.11071373212842212, 0.11356514968699026, 0.10434889745327736, 0.12996258754884044, 0.1494932943774808, 0.12211004076825997, 0.19131089320346234, 0.11391474625035641, 0.1716026838027662, 0.12270412663178099, 0.24645960168732753, 0.10794820068704505, 0.12127842934381579, 0.14588227765935083, 0.11875865124766866, 0.09371003526593409, 0.05040315385427206, 0.08606641598406338, 0.08831162050726914, 0.13854258843967993, 0.14954613912249767, 0.24565648107278734, 0.24596265577260526, 0.16465061975102271, 0.20852787660494929, 0.176419124547993, 0.26233283622610953, 0.20327637452752362, 0.06086755483861893, 0.12037629952594159, 0.11547775713786965, 0.2290605345079976, 0.13917401342863037, 0.14316850311813817, 0.1454443818018321, 0.13902765999157585, 0.20066467354134207, 0.138276326920717, 0.14375279837798688, 0.12538402476498198, 0.2801464948683016, 0.20811906144503625, 0.16064958767064158, 0.12751161947005218, 0.13543320609436882, 0.25292645629134874, 0.11042280257829737, 0.09653562800057473, 0.1493296579968545, 0.1558224829815088, 0.16736796426196254, 0.11316748876725474, 0.14739381509923166, 0.15020544971189193, 0.1007890324258516, 0.08900355878135852, 0.1700981484065133, 0.19324621516129664, 0.11497032347946398, 0.23075080026061306, 0.3183632199802707, 0.2217288279244977, 0.17528546763764274, 0.16718342900276187, 0.1499793465219198, 0.14531045431090941, 0.17261050311067413, 0.10079231128216752, 0.11643235631767782, 0.26524887330109076, 0.248139234139554, 0.14691484160721302, 0.15474874946859576, 0.09741088345406518, 0.25929189617595366, 0.2054037087626996, 0.1965072675938568, 0.17192067157837654, 0.18176830283576445, 0.1476367569017795, 0.22013918015985723, 0.12030401146940647, 0.1618460637907828, 0.19052432008808662, 0.20347587914476473, 0.11022025659199684, 0.2107446899096812, 0.17388508955557502, 0.17471773519871697, 0.11116151052016406, 0.14758227272860466, 0.15079815661714924, 0.2198655641968212, 0.13105718929681087, 0.2725297116464184, 0.16238168182392276, 0.11761858984227143, 0.22605278138672152, 0.12113540838923186, 0.2742504064113863, 0.2233563357543561, 0.18563988137870066, 0.13693473842595855, 0.1737241344826837, 0.20522738596604717, 0.1965557149941883, 0.118731937761749, 0.17958922702218258, 0.18273153582647925, 0.08468974832325213, 0.08456951848441556, 0.131916280295099, 0.07726830986118124, 0.1408727367919299, 0.11415987140348843, 0.17625656069046067, 0.16154483801895575, 0.07722818217570744, 0.20473301410675052, 0.2845739008438203, 0.30350715102207276, 0.07865103727747356, 0.09754523229334625, 0.09728532930415484, 0.12384034993667757, 0.2259167701366448, 0.11567525460474914, 0.15328976566032057, 0.17633297030002842, 0.16870604407402778, 0.16504890886285614, 0.16831939949864344, 0.21527844421084852, 0.17681476299560842, 0.16779583968943165, 0.16139738141529023, 0.09652408305555583, 0.12206122564572482, 0.09364293362464636, 0.11983421571072071, 0.10740744986481245, 0.1963464810603088, 0.09356968029732667, 0.26795714733100706, 0.1787539307148226, 0.10523667844432978, 0.06028654609596538, 0.1376263472822405, 0.12706689776912813, 0.12040803854864453, 0.201078912603759, 0.16750434323424296, 0.1141643760004832, 0.2659997620409535, 0.16846400625523061, 0.2758293749103623, 0.11697193502538628, 0.20193469410221423, 0.1037838003568111, 0.14285984629344556, 0.13552420201801485, 0.19036033130701513, 0.16461076785720166, 0.16909130969114844, 0.11195912296252866, 0.18225243976039274, 0.19663403982356673, 0.1355152081457838, 0.1616373967619673, 0.2455368487825317, 0.10970762119658532, 0.14432947872386825, 0.15154296261889322, 0.23422490174491561], [0.023472257927360556, 0.05696990632361943, 0.01095042152765898, 0.07558238016621721, 0.07123727501640398, 0.03646505741222251, 0.0701527396637586, 0.11469349760802523, 0.011102467955600832, 0.06020011222590843, 0.05164795863111654, 0.05507049090679615, 0.034035321460255695, 0.03441379187748798, 0.05058972690735133, 0.008418020217739528, 0.015147539557919148, 0.05661169127110512, 0.01959550637571562, 0.049178815116324735, 0.04141225021392588, 0.007863696711513424, 0.056286345220982074, 0.030029851815573154, 0.037645257994412415, 0.020213254779997854, 0.02801366353167161, 0.04767820592068377, 0.05354098487465132, 0.05397345682966614, 0.07006631728502051, 0.06479547148750675, 0.032919817003271276, 0.05696797578205025, 0.0643421236365553, 0.09002921261614369, 0.022550987402698206, 0.06878050765202892, 0.02588166190581697, 0.07631807738254148, 0.03838643656983491, 0.026152286295508666, 0.0259389748586522, 0.06332732526765716, 0.0607101429223774, 0.029328412136002898, 0.008806673858705307, 0.020310383237477754, 0.13186596364023226, 0.070580055847043, 0.00964714221716408, 0.021389923696856827, 0.03364237581169413, 0.0699900379103999, 0.010181881164410904, 0.02809374844805608, 0.014407987961725844, 0.06688393442140472, 0.02635819157735715, 0.05283456370835343, 0.04691991294103284, 0.012097588398553913, 0.037669592777327184, 0.062861965158053, 0.08452212828541956, 0.028448025808639588, 0.07359418281984907, 0.018160786487222202, 0.028192334387811924, 0.04686130721482539, 0.048058059126619375, 0.03723614406020891, 0.042281568486003146, 0.06448738922875735, 0.024471211682764754, 0.02501356745919874, 0.051465399878760504, 0.03731395178023846, 0.053215677128924485, 0.06064525910563046, 0.13458971264621905, 0.052619882889332316, 0.02950670377862069, 0.06452709556587281, 0.011896171434331807, 0.026979925554065455, 0.05792748175501343, 0.014723590331061956, 0.037490626977336024, 0.010989784082818416, 0.023043354026853077, 0.026770105562923897, 0.014577829654538825, 0.05179683632788159, 0.022768242277144905, 0.04143173949071958, 0.0753313867795852, 0.05979103659610114, 0.04922746552995617, 0.02669982848719003, 0.038260254227826675, 0.03548410863825872, 0.028270178497017875, 0.02209217542962682, 0.04311511045201652, 0.10298896881361162, 0.10321940040035595, 0.014411059016692302, 0.01406469630197652, 0.01004771714384157, 0.05000529758211586, 0.013455110564527493, 0.03741854193410085, 0.027927426929255168, 0.05033963367403035, 0.038882804088174336, 0.02914945974255041, 0.06142081970709467, 0.053575627370587284, 0.043699149072410605, 0.022294853566094272, 0.04539193525429695, 0.04356269732177739, 0.02716113790689457, 0.027903657136184555, 0.023917404807082588, 0.040166506979374156, 0.03443600076641287, 0.04029062854486608, 0.015558711395809248, 0.04539735532636124, 0.010955893310658153, 0.024832131025651773, 0.023000403307378296, 0.01134579184450089, 0.04556528946024276, 0.031500920660853866, 0.0793385858677568, 0.016455645222337018, 0.0742787053628314, 0.042294396628295226, 0.03364370497424276, 0.058839283432931676, 0.03761726897209883, 0.049858741131761385, 0.032343228587940816, 0.03178109433652172, 0.09601529342152419, 0.019154151631218773, 0.05850908038536868, 0.030017694000214822, 0.04628657656271131, 0.03028359354263352, 0.07302019910346116, 0.022989354404290358, 0.024944887676786993, 0.02881314331335166, 0.028640547534450892, 0.058820353400322704, 0.021254630654209086, 0.017667335848654472, 0.022168640580569065, 0.009695980322336959, 0.08426230956589983, 0.03822991331558555, 0.049169664196069204, 0.029524061415765076, 0.027236787174197457, 0.06126122827070856, 0.043011068051019986, 0.04052153893656308, 0.03252725056823223, 0.0574822812491367, 0.043630568881429015, 0.05096758445424419, 0.08583842821779751, 0.1049290634992142, 0.05126162815178114, 0.026157057108057123, 0.03438910852456766, 0.05341080355367834, 0.04850573792693116, 0.07532305940384827, 0.04436226328834892, 0.03543096511895138, 0.06921931515417754, 0.022811771393002524, 0.03851415491813133, 0.0921642153914417, 0.045604528483724406, 0.030680999738134207, 0.012158343001388976, 0.02008645382199076, 0.06123115165880131, 0.019323118068578265, 0.0918395932944071, 0.02067534369416535, 0.03907553648816482, 0.05163457507507936, 0.030582528711567004, 0.0381340105987845, 0.013404729749797093, 0.03588165081436596, 0.018937191700622923, 0.023737037066189993, 0.07828914500292271, 0.06103871420266167, 0.04352362683763908, 0.04730540455409116, 0.005289204615814191, 0.05119039346614192, 0.021159582125443607, 0.050939775462592804, 0.0559867320642356, 0.11309330081266743, 0.07511910381576709, 0.03154411844368423, 0.1066581009616775, 0.0684904437812586, 0.0626861977751457, 0.05827627392605909, 0.044474426221342823, 0.05209702788101089, 0.039782164498202266, 0.023185321610541116, 0.035046921412069956, 0.033716720814305934, 0.05927290835027253, 0.05309970673894691, 0.06947109761137156, 0.08406201587809671, 0.003883715769681599, 0.014131460864577564, 0.051265765026572256, 0.03245945178693341, 0.039237449170961496, 0.013332209951664894, 0.0598057225016096, 0.009217825586787395, 0.024694047507739837, 0.08511724070675912, 0.027227877571638075, 0.031764987337913726, 0.009827695734378313, 0.04998857771316844, 0.050083944168422496, 0.005477914575397248, 0.0404724327006167, 0.05885464732625312, 0.052462325416385173, 0.02703371641766881, 0.059576757973240274, 0.03832114289604849, 0.0628644204698503, 0.020906648621143355, 0.05029146206535159, 0.07375122318344732, 0.04683624847882217, 0.07096130716344042, 0.041336717775031444, 0.02331977387169196, 0.04009893802445262, 0.03557233132361885, 0.01364612213951806, 0.019747804655062578, 0.06864357709644303, 0.021517829736694697, 0.03160854069245679, 0.012641869928507556, 0.038682288234873165, 0.042279871601250865, 0.04431574259914699, 0.018406183601567344, 0.06665202428496654, 0.044821923703796444, 0.033700962385703484, 0.03201674681247002, 0.06441444233660737, 0.03944809653706128, 0.0367015142804913, 0.05393698338359114, 0.031546299879048625, 0.09098473876234024, 0.02972311404113087, 0.03849544322058078, 0.039493690259874835, 0.046206118178463755, 0.05879936259119742, 0.018656703928906112, 0.017949830770732898, 0.052533108110149065, 0.07838271498199433, 0.018871319630453666, 0.03797921104236476, 0.07103033934629734, 0.020635834624690395, 0.048542510147296616, 0.021943027686868465, 0.03496694183277507, 0.04386135286861851, 0.027666208184053822, 0.052896796860882354, 0.021361270093268925, 0.06595086997314807, 0.06660671018424534, 0.04414416571718551, 0.029889866484389193, 0.027026250890846697, 0.05302916919331878, 0.036125967744737864, 0.055333776174173246, 0.02281651730769344, 0.051040818629365776, 0.037214670615691336, 0.05649597369014256, 0.05543971847322199, 0.017996221224987702, 0.029103718547811432, 0.041772476247241425, 0.05017084918255287, 0.06890897293605151, 0.040068769481994455, 0.007905447066971853, 0.02648994529379472, 0.05495405703362438, 0.035536532034917225, 0.041469522947145086, 0.01199447104872595, 0.006142715621183837, 0.03362488985482243, 0.03174043805038016, 0.029366321996935917, 0.03800904633657586, 0.059443159900125, 0.028397515716571963, 0.01986167979456725, 0.06133972930030958, 0.035981150313971505, 0.04970899392520228, 0.02142549698962079, 0.011881023003239066, 0.04205636544934204, 0.025651128812422676, 0.006657006245316758, 0.08164127762880057, 0.09090243027575555, 0.012169839108302709, 0.01497856833251013, 0.09883320995516355, 0.011738543098251666, 0.05148035774548208, 0.010534950021293857, 0.2675826529101018, 0.16659516540746536, 0.1556704298502976, 0.17081580425222076, 0.14397706295694077, 0.19385024484607483, 0.2208697982132435, 0.178492633445609, 0.09597639913760847, 0.11486464165030949, 0.13349630599541049, 0.15520005186478938, 0.19429888125629197, 0.10640372146642017, 0.23127023851679218, 0.1120523022367589, 0.11244317561748529, 0.21270192198214993, 0.15402047564425778, 0.11602226179093124, 0.17868277646841543, 0.13577921736624934, 0.1182515393461912, 0.18530986602267913, 0.1345116329649764, 0.11489906198074741, 0.11270349229415579, 0.14890751290705898, 0.11049418665108182, 0.15912668148596443, 0.16347706498157594, 0.12046790831992704, 0.1534374980556388, 0.07903356796070453, 0.15190803415832982, 0.1988018388229032, 0.13687351267905007, 0.21089553262197205, 0.19734267115352616, 0.2073433820999438, 0.19377993329638438, 0.16091709025204182, 0.16319994033584673, 0.31383796925506285, 0.23158366040837383, 0.11442290769229013, 0.1415994937621778, 0.1390171492652547, 0.23504582624281609, 0.19157416697952057, 0.14225817615947417, 0.1793989154600328, 0.3370864701367194, 0.21509836758336714, 0.1446915471986417, 0.11163631649387461, 0.08849920479640846, 0.15184074099506104, 0.1182484443509771, 0.11725039266410375, 0.16410626831554598, 0.13622442170256568, 0.07244911119942704, 0.21748359765737288, 0.16608593144243763, 0.08314380587469186, 0.1599674783046207, 0.1331654785861892, 0.09847799030643317, 0.12943061609422007, 0.1628548943347508, 0.22221855729097323, 0.1260271632382947, 0.2663880766880128, 0.12646259995357645, 0.112070826242768, 0.16235186568190976, 0.10450615998237364, 0.12174542888157791, 0.14696210923214115, 0.15560269235603272, 0.13249953367537068, 0.05482802407876138, 0.2171710950713004, 0.10278106787272039, 0.19027088288097613, 0.1841552029814451, 0.09972954814833018, 0.09902211191553263, 0.10136321532509981, 0.04207540656470003, 0.11877405727582595, 0.26274342871000694, 0.18348121414742163, 0.15577817245596842, 0.1660700274571296, 0.19167211898151906, 0.1129148406307063, 0.11943028053088535, 0.23703313492719205, 0.13844457515064748, 0.17570125419766675, 0.10288247493125739, 0.1434662968160645, 0.1334062293772736, 0.21511217248776268, 0.2087727336273078, 0.1603423864130051, 0.16269639074321718, 0.0970087715634896, 0.1316624447222679, 0.15882822895242324, 0.10064383578156272, 0.1399169348540806, 0.12088738742374605, 0.1473161491054681, 0.21281668195320716, 0.24685021459815965, 0.14216347237027463, 0.13333942651027633, 0.144304197822367, 0.1262694768487446, 0.1594623046055917, 0.1843143654085936, 0.0887322870473708, 0.1027860627659867, 0.0837305219723813, 0.17320526313156853, 0.2016040352323363, 0.13178805249833292, 0.08237636197478541, 0.17010032409621825, 0.2533428863652291, 0.08355117312842801, 0.1703180003190233, 0.11630219797934256, 0.15875019523645603, 0.2660998437673815, 0.13293686262782545, 0.2582092300778435, 0.14522180261631168, 0.09065183525484416, 0.10311908884755067, 0.1664032450606746, 0.18460203142416093, 0.12292647599092416, 0.08955379377209371, 0.21718053327452755, 0.20003782975817883, 0.10782139781381815, 0.12641752334011178, 0.1410829206748355, 0.16852818910152684, 0.1476160725278239, 0.07938270487131611, 0.18896712380791866, 0.11241807091620662, 0.1774112237316947, 0.1060287444101226, 0.11832198879170804, 0.17753683150775973, 0.12641871843727367, 0.11416830603153476, 0.16975630465294086, 0.08999989443128148, 0.14368201185378338, 0.07237887625852901, 0.08109406868536627, 0.12681275576112733, 0.14410556654535955, 0.10127567445799228, 0.09751262759128887, 0.15856737601420573, 0.1796037060839515, 0.14776070992792809, 0.15254670633904396], [0.027135592705059438, 0.018339024503685294, 0.0223969443581037, 0.014172820036389656, 0.060788410295161514, 0.07824827421216235, 0.04771195209374832, 0.04645277550744434, 0.021425715324679212, 0.02689907838019633, 0.033754427661939014, 0.04726136215932427, 0.04128034902556289, 0.03624437429431466, 0.010379940748304851, 0.056647942551682075, 0.12950098893094447, 0.019663624998722828, 0.051042749170934966, 0.007085885247966696, 0.07712644569936299, 0.08760698815627445, 0.02360616243564554, 0.015837723490661912, 0.027665373148216356, 0.048297365841966484, 0.030665528592503363, 0.07054000477036161, 0.016837884792156758, 0.00887902032944464, 0.04499376871653142, 0.03319732852340226, 0.020558532522690874, 0.007718583379286312, 0.04983486983204081, 0.030891978437261238, 0.025029538477200176, 0.04585688933730126, 0.017451050075431986, 0.018809299067323728, 0.05442674722402327, 0.04702484017358192, 0.02796564897101733, 0.03404423872369432, 0.029712434775466402, 0.05435940426503939, 0.024867288715716813, 0.03803507800424292, 0.025352687770200354, 0.028903053307365027, 0.10934502412114414, 0.014512407661025083, 0.033354365056560885, 0.036181689149910407, 0.016560279426255053, 0.0649142993854419, 0.05042119905532849, 0.03821716561252552, 0.08488272587137838, 0.016717752629530527, 0.0483973786204813, 0.01360976743707133, 0.023229739388390895, 0.01720015244979051, 0.039108217799014626, 0.042992900275895675, 0.09101255541487087, 0.014024156844243409, 0.11361862262410503, 0.0482944508774146, 0.019451688689690445, 0.04353059823775003, 0.03631811025702665, 0.06611875814175414, 0.07369678497554795, 0.0327810823106237, 0.01616183901205659, 0.06794362554266568, 0.010520124304739219, 0.04148322059923122, 0.05430434935636098, 0.048272552254099044, 0.06970025749216158, 0.05372599893880468, 0.021790601087794192, 0.03090018132371047, 0.043310612259853276, 0.03758176079680843, 0.09669200952855811, 0.033371498612987424, 0.04013672914175738, 0.06194078656394155, 0.0311037136482135, 0.01665898027919954, 0.09802222927852024, 0.002336623471027481, 0.01668058587388406, 0.059659116255540046, 0.06671072960260414, 0.06085603287623775, 0.03827543809048591, 0.018834863421356967, 0.05352917945973816, 0.03446711925789714, 0.02428537981975223, 0.021317380916086898, 0.0054164700146253795, 0.044848851694334904, 0.056120222885041475, 0.02498489278819292, 0.0561412749812007, 0.011702805096583982, 0.03687984422750531, 0.04967080827261652, 0.02456805477249286, 0.08422119362700371, 0.03973639840560575, 0.028935405200407393, 0.07742553408588133, 0.0420311956305898, 0.029446809109480634, 0.008397553221232468, 0.1036020536576548, 0.015103846690767716, 0.05302778640461545, 0.0310551589955726, 0.03527570590977708, 0.045310703121245875, 0.017315642119595603, 0.03503682054278832, 0.034305490027632446, 0.05489223373813495, 0.018311523862423438, 0.010726016180049027, 0.00532424547747078, 0.02050880767074564, 0.07820908115395615, 0.05761262344857378, 0.08044154563498113, 0.074602538389304, 0.028617032465615103, 0.08907779270122129, 0.11138008306584052, 0.05634938276583149, 0.010230074798117482, 0.0264730473094049, 0.01208669558588055, 0.08212182926194322, 0.10146716579554543, 0.023453678379976944, 0.018678208016940666, 0.029293298495993502, 0.025669198911336642, 0.016311289359545036, 0.053826011717319495, 0.03986903120793643, 0.025750925171098886, 0.02118696019263758, 0.035197974798539956, 0.032128967202058246, 0.012933515770841512, 0.01089908310302323, 0.059638573607850465, 0.00953045936541692, 0.02198848734429527, 0.04356827827230577, 0.09147227711735234, 0.008537885207202165, 0.016327670234585964, 0.05881089221445784, 0.03300043626598293, 0.029945821546378638, 0.04573130837431358, 0.0548588284741967, 0.04288457927384204, 0.03265602611786416, 0.018894106915761388, 0.019523739258969025, 0.04155905947329537, 0.02078607021230123, 0.026140500032793612, 0.059667826675239115, 0.08317546062772313, 0.015146513957710517, 0.019206986800136588, 0.011229111865583447, 0.0105957189882775, 0.11382766503600344, 0.06788999938796605, 0.009008366614580154, 0.018553462089790453, 0.07831873131855842, 0.03594219474302184, 0.06845644479917903, 0.024992162962594343, 0.02334607558535232, 0.020431955645401633, 0.03592191256522652, 0.05073276701413336, 0.044845289385487, 0.048923098797639536, 0.04620692640122387, 0.04840307448419833, 0.017995487695800203, 0.012648583731553968, 0.06631718257502203, 0.049000822247997414, 0.05562744065818768, 0.011258399406928691, 0.018576061683556726, 0.026810949540606914, 0.036901202758834246, 0.040120089712042006, 0.023283932448154496, 0.033947068131378585, 0.04900167260559336, 0.06314051472732136, 0.04890478163536999, 0.027151259203110973, 0.06667755033460356, 0.015377929009827635, 0.03747630113315198, 0.014495950177191727, 0.020682839864504435, 0.025751047745166768, 0.031215870835547967, 0.011300213443445823, 0.04480579372255072, 0.01118170059916954, 0.11321277222445897, 0.0283362957153229, 0.06751141405754513, 0.0386133173390502, 0.0271317737567569, 0.018028483102698962, 0.03442990653697522, 0.025480239494373242, 0.022091372952526136, 0.02506880048331955, 0.042286341213771415, 0.030414272820757284, 0.03146940571886878, 0.04100829971233203, 0.0694188657366941, 0.04620245627818569, 0.01800555600634506, 0.026559781868972128, 0.06526486121959264, 0.019646985569007454, 0.09501486686208556, 0.032066343344687935, 0.02649764447743374, 0.02603331284086791, 0.01804467820141825, 0.08314767461870948, 0.10095172651833105, 0.0565799369266437, 0.039492636888978944, 0.02994239138769767, 0.1290858458847769, 0.014987249066302133, 0.03640525658885318, 0.07256809231494704, 0.037987818040194056, 0.13035701557753548, 0.06678523165324042, 0.04819289826217198, 0.029046861417291146, 0.03740789331195336, 0.01232318309766631, 0.061396936916055224, 0.0844931241966063, 0.021655283147288908, 0.02025921239457544, 0.04171528012281464, 0.033945532125090404, 0.053802305126502636, 0.06674279038223528, 0.018101627262489452, 0.041046447060521574, 0.024147325030137456, 0.012172085661140662, 0.01645029792862554, 0.05960295051937142, 0.007592846325884063, 0.03045239335586948, 0.05067518018486519, 0.026537212918722825, 0.08621644664315448, 0.09197633232801192, 0.07231657798852652, 0.05521798198441825, 0.020868595118724534, 0.018094502644793644, 0.043102730471160144, 0.028323528860064767, 0.07315846265203531, 0.04087205480543837, 0.04746470487706604, 0.022479067068366755, 0.10094753601738524, 0.051765645058044506, 0.06557026217060705, 0.06345552242090625, 0.04171015116416159, 0.07927022018139401, 0.07113602883633106, 0.015746118527116076, 0.057900140076995864, 0.025007831375865687, 0.051594600607190406, 0.056834040630248286, 0.04124575249490239, 0.05978745130461551, 0.019238381083273602, 0.02011578924383127, 0.02638983866950918, 0.06633897011558856, 0.06663350793983668, 0.0626975818417005, 0.05488972096974331, 0.016910852751724662, 0.020918362105505604, 0.0569608626556733, 0.07303404231225291, 0.03588895546272397, 0.00988931027090838, 0.04854405764490367, 0.06766187372587382, 0.0028477774439154254, 0.01318193318682813, 0.03891917411237955, 0.04478556517091009, 0.018505014689458955, 0.019574760714726105, 0.045106594315579826, 0.04121187225645108, 0.05628735645704212, 0.034084994601266044, 0.04905959268310859, 0.028034738610468568, 0.029012278293169318, 0.03732486470271984, 0.027032793281720053, 0.027403049321184238, 0.044407443323683356, 0.03221311621488102, 0.06954864869194646, 0.02774275185900831, 0.0327710963545307, 0.053569659545657136, 0.01804797812515209, 0.08622507279318187, 0.16028784095279633, 0.11570595174787507, 0.14694577623759547, 0.15633743196245165, 0.11949653947545637, 0.1747680518535837, 0.16311870437235604, 0.18364278209065238, 0.12546732916586822, 0.1944198771830528, 0.19244422835688438, 0.16069486346696654, 0.1722288534285561, 0.05219203044450091, 0.13672584157076575, 0.1553901029570449, 0.17318506905388448, 0.12930500831815506, 0.09366360267684345, 0.16013952633065565, 0.16823105423921542, 0.12936519218548653, 0.12597876180323864, 0.15308698218676353, 0.22563690289614663, 0.13801054037626714, 0.18214347141404308, 0.0801984965801239, 0.13451511100415262, 0.16283122221789054, 0.14084177151803048, 0.08351321347177991, 0.06539687349070465, 0.12539578421461967, 0.09334257353217372, 0.09565668000328927, 0.11229571901381978, 0.07191298754825708, 0.1599273659409054, 0.20626276911747074, 0.11217617865411506, 0.08513607114793793, 0.16640733597019028, 0.09771085284169644, 0.12270005870490305, 0.0961805922129462, 0.10790104031442635, 0.09102007073740806, 0.09864217060948573, 0.3456688918653996, 0.15525548598699032, 0.11726005303282892, 0.16739500716568964, 0.13320579013276485, 0.15635373431348032, 0.1711553957072958, 0.12634574856248595, 0.23440631136538523, 0.16142693708740896, 0.07658159630673547, 0.14004409012775268, 0.14310068901508086, 0.1454027985493022, 0.08037933929552955, 0.1273373727716746, 0.17310250009740555, 0.09350123800217144, 0.20771738622457753, 0.10303015370042094, 0.12387343727412725, 0.16545063004859034, 0.16206634471253042, 0.21758689695308286, 0.1749043542170717, 0.13393141329288483, 0.13724757809071772, 0.1815231393782362, 0.13734122467858179, 0.2428248209217864, 0.15171213015433282, 0.11031593331286024, 0.16792032897712725, 0.26574523698899055, 0.1417233242142585, 0.244819974346507, 0.22731466609383785, 0.2311313927413956, 0.28531265475096246, 0.14749515320985548, 0.16224446015492563, 0.10321638967481353, 0.11329149541955803, 0.0681943507985242, 0.1625768963487879, 0.15630323379751176, 0.20791813190425598, 0.20824223306150208, 0.13946163347892224, 0.1963425586901365, 0.14717748719117335, 0.15292711495872469, 0.20275070031564082, 0.10428115995901246, 0.11500403900901157, 0.07994011044502258, 0.13304949287445317, 0.21546907752992647, 0.13081694412375652, 0.21143001684498405, 0.1219705744616447, 0.15038220151778192, 0.1964503932263582, 0.16559954221931197, 0.16688143714301049, 0.25515613987320857, 0.1612337603564224, 0.15235420376543077, 0.14585842168138874, 0.07779604484958035, 0.14425211916527442, 0.13250777678143594, 0.3941327477655103, 0.19482199673450765, 0.22656285804846596, 0.19509956571123294, 0.17166282170482222, 0.13254387484442803, 0.19247749189455665, 0.10702482725103056, 0.19436519382701767, 0.2429166901856661, 0.15590289157004128, 0.10897964614653781, 0.17197857250369367, 0.2257732359031516, 0.18679478956807047, 0.1755729957573837, 0.08751791511331836, 0.16896542612343066, 0.1710677858922751, 0.3103783774760462, 0.13191833341073606, 0.12453762784359917, 0.11666971333925763, 0.10140786292932688, 0.047728878806435296, 0.19713870790456572, 0.15307650210395937, 0.1376361225641543, 0.11177188341295528, 0.09726103665607591, 0.14910994398017086, 0.11851796174361823, 0.13987683781212376, 0.13325756235468772, 0.10923862983022006, 0.08824955972452318, 0.1575015332069128, 0.18140451832404061, 0.14137712908127617, 0.14988228318191346, 0.3024414001453308, 0.17470894050934624, 0.1779861573971087, 0.16733453218494693, 0.2895340443618836, 0.16103235584112907, 0.08334810620233898, 0.07933158382412889, 0.1020767955830501, 0.13611255754386226, 0.16569557900149978, 0.10887545818883566, 0.16174225887704283, 0.13699374251788662], [0.021904662003620498, 0.04666449539663811, 0.014227668101328516, 0.02964425678064506, 0.038014638778423114, 0.019135169887674913, 0.05016263288956496, 0.02804307173186493, 0.02614732396097914, 0.08290259543085292, 0.033194762128855915, 0.011866397427154646, 0.02776643929762706, 0.0317169095750057, 0.10755374201483305, 0.008464051568279824, 0.01541235317070518, 0.02353954534496992, 0.022844715088966395, 0.03475503425203985, 0.01621571989099105, 0.009831777067794915, 0.019065505682280468, 0.018572510866027687, 0.030253179852039586, 0.032287097325728785, 0.036089934799219334, 0.07086019121831463, 0.0540625796683373, 0.08276591002340279, 0.019258820309093403, 0.06115348183459813, 0.010243772450203617, 0.057136338925169367, 0.1331528381354386, 0.046748592698526, 0.026187296513648286, 0.06221073679625989, 0.030143571822273157, 0.010381202878160103, 0.019559504073714058, 0.03872982399057477, 0.047973747320112684, 0.04329751981722732, 0.06568573460343384, 0.03942378473678424, 0.051481549012204336, 0.05812940337965566, 0.027580444640930624, 0.05395567592894358, 0.028057834246165814, 0.10604223521846919, 0.017717648673081593, 0.036696971379100315, 0.02973233773973921, 0.05399815933478456, 0.026336727708938624, 0.015126389785549574, 0.032203348593846444, 0.052316500579998385, 0.07558765085113626, 0.04478075030830599, 0.03271436371329812, 0.011339717724871252, 0.015359902960969316, 0.016602724527699814, 0.12010319684181484, 0.08486453128317673, 0.004978179621825656, 0.09176067091644773, 0.03631015060349338, 0.020158136669065685, 0.04438507355629437, 0.03849706349654063, 0.011495388706304855, 0.06901866140504999, 0.03657440114165506, 0.04591851344993038, 0.046691764296302875, 0.051782338113914576, 0.04892013020693295, 0.01830044431581853, 0.03584250372143523, 0.04437306512808127, 0.1106048250691064, 0.01904944464894793, 0.0179927489314709, 0.028708980253507054, 0.009032413156913414, 0.09667190738142499, 0.058407780579141075, 0.049241048268853664, 0.030624437551464767, 0.06208603683438513, 0.04280982058375113, 0.03213994715723299, 0.05565046543075193, 0.014436121583135139, 0.04772444315735371, 0.024131585753733115, 0.04425340602474828, 0.027208020572640726, 0.015817405881300088, 0.05764631216504401, 0.07085988478314492, 0.05865017845926266, 0.018862394706135797, 0.03313308822051172, 0.05539511683427038, 0.04815124223128923, 0.121253983478152, 0.04891060390359452, 0.07322872057557106, 0.08908856389743668, 0.04681022447203437, 0.020515625853271737, 0.009656109276317782, 0.018917238940635038, 0.039209299270183816, 0.057186950523886955, 0.06849927677502556, 0.019352564573167794, 0.029170621006238847, 0.01620430901135889, 0.030205377880784295, 0.05496492016039068, 0.023866130542310498, 0.04809080938538236, 0.06419020074029123, 0.01851685457832871, 0.048934095989792585, 0.05589099788677789, 0.03550884561733373, 0.02564386821412031, 0.008287420421237908, 0.028052693796193892, 0.04069236122191914, 0.01004474089225574, 0.04275801388787166, 0.06132976632685431, 0.06456683254650523, 0.021924293006680185, 0.01608689071520442, 0.07120273211189816, 0.018975277761778524, 0.022857445555048126, 0.02955047995783389, 0.06098306557584194, 0.044889163240910544, 0.0493482775956152, 0.053419663360522646, 0.03355948509828698, 0.07044968300408895, 0.029159173737430287, 0.051275574782442664, 0.02000338882358084, 0.027939847129727566, 0.0239302386950341, 0.07823302140158993, 0.059727566211574504, 0.017859145112696196, 0.013677081667758046, 0.08529169424887627, 0.05048715156472979, 0.026580891421725674, 0.06424733557768407, 0.059960089218352115, 0.0752552682834287, 0.035921609960496426, 0.02791660976776433, 0.04067752209882583, 0.07761383849766947, 0.05565346849541511, 0.03143096917248782, 0.03845548407445031, 0.06486295617275661, 0.024379131744705865, 0.05775984256498276, 0.06678310958969016, 0.016568334840778864, 0.04457165427025288, 0.04029987905655177, 0.09907753837685432, 0.08729992479446434, 0.023176722273591067, 0.029259623186061942, 0.013010801593472641, 0.06486321664265086, 0.08296626499823986, 0.03706310778075168, 0.09774258420352014, 0.03910997980124047, 0.027720219297935406, 0.027217769041477193, 0.018357366563812382, 0.01711567018872067, 0.06707986140803945, 0.06634316827741361, 0.03736440250049195, 0.06284345264336275, 0.07375084013948519, 0.029508578778815367, 0.040672952384357496, 0.06327323179932372, 0.033534522123274305, 0.10432691839072974, 0.013766599999320124, 0.0994691625237465, 0.06859206534441441, 0.04866703390894879, 0.04915020173235286, 0.0724657123247462, 0.07988990870334449, 0.04595307933707391, 0.054778209211485046, 0.006406204859470769, 0.03808353306545365, 0.027804986926757043, 0.013710677496067459, 0.024915441172197465, 0.03828810918475351, 0.029743989937067516, 0.07623441292033081, 0.032665027650974454, 0.013979760133811544, 0.08396013384504665, 0.07163814584454221, 0.048259180189380725, 0.04862310259693092, 0.06691958815340074, 0.050330666614876646, 0.017231759322326512, 0.034778894060441566, 0.036713109021225286, 0.032276758969190626, 0.09300780843102163, 0.01778451282711279, 0.015330796407896186, 0.024762137402449886, 0.0420845996197914, 0.020109716081811536, 0.037216604987700144, 0.05453016143292189, 0.06345732655796794, 0.007554510807348116, 0.06015768627666178, 0.06260430297604011, 0.01757607179423494, 0.052497136451664476, 0.017112975474447012, 0.037162749006623225, 0.03529046842407796, 0.013326605060888876, 0.01471673288652974, 0.041915175444897146, 0.047276963539902246, 0.05179767519415868, 0.017448692439845013, 0.0022713415279623965, 0.06536074478419558, 0.10106580467113566, 0.03980395969964805, 0.011912602105087811, 0.024023121110193675, 0.034839284771512595, 0.07349756381083881, 0.08320617309260754, 0.09610262744489217, 0.03631110821339873, 0.06785675117205228, 0.03241856950485418, 0.07674444361679977, 0.03251042344697541, 0.061365883542044516, 0.021372102576518254, 0.08916881160750505, 0.06231852536720615, 0.06838258626239915, 0.044733107300294984, 0.08065452573881035, 0.058632297967109955, 0.06066369118108865, 0.02421581520578794, 0.02207255974832562, 0.05135931585344577, 0.015230127666596205, 0.03883776960954551, 0.028695096825099284, 0.0561117078177631, 0.12277397086783765, 0.05969229935398025, 0.011651059687738458, 0.01840213674210733, 0.019229733865828286, 0.03587586685053764, 0.03295270515786063, 0.04924308606273225, 0.013502741123609727, 0.06480233563530831, 0.01850352464844623, 0.053414672297695955, 0.0335893931708509, 0.04971770051446173, 0.07078897568487352, 0.06770870468068509, 0.06692987671422382, 0.016963565346574592, 0.05393578445598964, 0.03192060277797282, 0.03855116462575332, 0.06198552609871953, 0.023626611237564397, 0.021285703180417902, 0.11093551458250131, 0.02856988932997469, 0.05880529211173135, 0.028821104882104747, 0.03759864920509919, 0.018323532290636532, 0.017878540543719165, 0.029851596562131762, 0.019209760038422483, 0.05601929463145714, 0.02787999268020353, 0.02954262372617039, 0.023422169183651288, 0.022833049485099413, 0.03601442151252301, 0.03774973706552579, 0.03781023885934584, 0.07726003611159903, 0.009389130507535752, 0.03731300566165197, 0.007406134419368521, 0.028151358259961973, 0.06372140855678628, 0.018536497072707263, 0.01367336518371538, 0.025732952748395266, 0.04272340203545267, 0.08064065188650163, 0.059360862904859174, 0.055427606623139114, 0.023595768537732865, 0.0403684669084126, 0.07373557200715428, 0.04476857717118917, 0.02871109848661769, 0.06631980259572307, 0.08149886954455607, 0.06987907773544712, 0.03443726864192755, 0.08539155380980623, 0.14414538779566366, 0.16630779050530928, 0.1197154107954233, 0.10093074337008501, 0.11143400033395137, 0.1828368882378263, 0.09840873595807823, 0.2189567387704888, 0.1177736996643005, 0.13171613216400146, 0.11896997660158143, 0.2490331668166384, 0.2194102934651798, 0.19521360555964132, 0.14585661371388745, 0.10530329745022521, 0.14073815046539231, 0.1313639921887267, 0.10922981215821159, 0.22847214833863322, 0.15110943346254288, 0.10021838885281356, 0.16362488930744512, 0.22053373076262014, 0.10475055735197761, 0.10319002858933904, 0.20158036311547603, 0.19508867194094967, 0.3569792301183747, 0.16389993019402027, 0.169253597757028, 0.15779891321735998, 0.13954614829872886, 0.271429211021431, 0.13431269525279924, 0.12364036268404416, 0.21192235091040212, 0.0706555997772563, 0.1200502142009716, 0.12539268155852634, 0.16518654421933238, 0.14560133789575871, 0.10507157117488886, 0.20088379000944478, 0.10403170640910826, 0.18595961583477838, 0.1097622739091035, 0.19580842686756966, 0.14563694566247926, 0.16067327510926033, 0.1643300425982283, 0.3202523315145124, 0.20386819277078877, 0.16207782070963614, 0.11333559910135885, 0.1482901686141568, 0.073748909597916, 0.14560092420827958, 0.23073707196500995, 0.16119812194618488, 0.2036551130755294, 0.19284268600806115, 0.17752016143452737, 0.09092202680485864, 0.17564162191364074, 0.19238707819773307, 0.13306830799387348, 0.10714187016410213, 0.2058449907288436, 0.17958167339524916, 0.20600006224647646, 0.21975426694318173, 0.09620480059135346, 0.09238412093010642, 0.11935127388325431, 0.08537164318465418, 0.06526345161781197, 0.21677755570459753, 0.13251385951955474, 0.1925053468514835, 0.1366007700562477, 0.09938670081957694, 0.1478813228107268, 0.26566550255783145, 0.1301925058566755, 0.19561934104609877, 0.19720898881073923, 0.0961806458391009, 0.2195109267749133, 0.18133848154496762, 0.14365991787804713, 0.11558734601543796, 0.17736067725045068, 0.12004511971627513, 0.17675094787151585, 0.1829089924332596, 0.07399468592578366, 0.22220905780071215, 0.22108004338318304, 0.14635178230462537, 0.14029522907109032, 0.13072277659610396, 0.19639295195379566, 0.13040304214002627, 0.27739247006754725, 0.14575637876987457, 0.18355092814853116, 0.10972234540649, 0.12986167844745422, 0.21645642696849762, 0.13957873767902776, 0.1208627883404974, 0.2244641755016581, 0.16178235591899964, 0.08060925760336461, 0.08308909953601899, 0.08452385964412844, 0.22530940030851673, 0.12616229348725852, 0.21989326593616318, 0.1049933152934236, 0.1922808830896693, 0.12302814351935541, 0.1184579464156301, 0.11404589284211399, 0.1181160566967822, 0.18398758294361253, 0.1680035414474626, 0.16367276980271264, 0.13034757737430835, 0.18962508608256617, 0.07946272275500721, 0.1026837976889745, 0.19673704800586547, 0.10478378258525364, 0.12450133825862601, 0.2260025566624057, 0.1289937621162784, 0.16788849036299414, 0.09964614415601378, 0.08508621414582576, 0.20187081769108775, 0.09499899352029448, 0.11793709089679104, 0.08796929411830441, 0.09862139430497924, 0.1442344531777405, 0.09702604684618213, 0.1078642680940609, 0.13787360982068125, 0.06390521986289852, 0.1498439941074579, 0.11633283383543454, 0.1884693198747212, 0.12401049806466027, 0.07121164171445755, 0.10862934478228131, 0.2044277740342002, 0.2012717522560589, 0.0999694102774224, 0.08489641586258527, 0.1518041373140389, 0.1519027175081353, 0.22580764857271027, 0.23046169399974809, 0.15118100139642918, 0.19146536717251425, 0.18218759807848162, 0.18613423791623887, 0.15805939843337383, 0.16030210550994645, 0.16947724946564244, 0.17773891018042642, 0.17157239268624014, 0.1709722700498758], [0.050220767471698985, 0.05288792173227957, 0.043136545592137886, 0.03461279087669907, 0.008948677831569747, 0.04366437634152751, 0.004819938415406092, 0.018804488035159248, 0.07763461480217596, 0.021898728652646946, 0.010410652255579349, 0.012706454970964022, 0.016236768156710654, 0.030753569331981485, 0.05338775962891598, 0.010890132323237918, 0.05303600269760336, 0.02776990776070424, 0.05349590826118666, 0.05510240229928205, 0.03062580501840961, 0.029749427246110096, 0.03763511115985532, 0.02848185050571638, 0.00958296990457682, 0.022487415511521603, 0.06870704748096966, 0.007157305231122601, 0.04681152682150564, 0.03320025114883338, 0.022911048727110032, 0.028347706594955058, 0.023084630844213312, 0.019157298337367755, 0.06287511122683365, 0.0006860420903502663, 0.05170917288670617, 0.017764167447063713, 0.029176450935342622, 0.0298547356074015, 0.05117348590565305, 0.06705189919880322, 0.005164902062050157, 0.06281991842232885, 0.03846351267589677, 0.021958299649638996, 0.07784546518157567, 0.07016184844917829, 0.020125970552344958, 0.0236859409168603, 0.02278499470482911, 0.05503545770601881, 0.007416280775120663, 0.03208263420439776, 0.02312562420904156, 0.024380865018634547, 0.04202133224856469, 0.03364250604664126, 0.08174145128577948, 0.021588317486607743, 0.021762512474050446, 0.06890220837968011, 0.06704309684855324, 0.0625424107326375, 0.047723665578110565, 0.01849562819716671, 0.015194549585782714, 0.030962221039038514, 0.05700788513246564, 0.025267240238345923, 0.0539282959465298, 0.053285835461030086, 0.05945122680596768, 0.07670842216260011, 0.007181520312799202, 0.026285960977416367, 0.0370039772843161, 0.020565785460114, 0.04329795265690454, 0.011680928498296248, 0.11744161587088339, 0.07192775772343721, 0.05983982107511932, 0.022194101512732527, 0.022334567564088973, 0.07196001768592866, 0.108969051150545, 0.061844079454820004, 0.016491007840921803, 0.034989204347854665, 0.017168352140053626, 0.06211189996270884, 0.03648594862991764, 0.01696370132718115, 0.058289400842641635, 0.0681239243356451, 0.0559886472840463, 0.06817100809947138, 0.03897174306574368, 0.03352878029428182, 0.0853877540137018, 0.027397497098953016, 0.0037069785673426647, 0.03579929636250581, 0.06914685089741984, 0.05508021256255527, 0.062348885431645386, 0.042995064474281766, 0.050761817068222075, 0.03431767848650775, 0.07223966276092876, 0.05894042236069518, 0.017578862269499132, 0.028738643177935196, 0.001715687781876524, 0.05535006320344345, 0.06188833252376607, 0.041932435405831185, 0.03141550185729659, 0.045454597416063475, 0.014698836115008641, 0.02474928244708046, 0.02451266470034757, 0.09813570222186466, 0.011519400774681521, 0.03334899478021168, 0.03148773820289681, 0.02358641651939721, 0.037392100409394315, 0.05598868941888214, 0.030168716743167852, 0.08094536335838419, 0.05736729528214182, 0.060344500647437196, 0.030354481573487004, 0.029558506644060536, 0.05828186636790634, 0.021185717214980436, 0.004342125067787786, 0.11209109692924446, 0.04296991380772764, 0.011671391661248861, 0.06768830375926149, 0.02637698371413975, 0.036323936355690804, 0.03295642068429339, 0.054573621600866325, 0.05142354466501744, 0.04209502224600123, 0.04642515420733441, 0.0123195480104656, 0.029400405248687155, 0.03724338359109337, 0.019486978529922424, 0.03361011584920268, 0.036342326296313156, 0.0128531550628043, 0.0441673590290931, 0.0882180811717145, 0.05097789982814462, 0.059417377211033344, 0.01166283828957427, 0.06564020599809385, 0.02755880074184989, 0.07288369755711287, 0.058079596173258564, 0.0461022328254917, 0.0676074814832499, 0.01801965968503106, 0.03853639445057319, 0.0309695563309135, 0.04165496219009642, 0.14021201660075497, 0.021850210389182455, 0.08888372730824257, 0.04020157082366847, 0.009061718892846859, 0.03547524117053517, 0.09488391179230907, 0.008164613654146032, 0.050470083125776825, 0.008757117546103414, 0.05072086583822966, 0.01975552107567989, 0.01446470719641976, 0.055655923807212425, 0.04521082057767818, 0.09203545133312864, 0.06188647476054969, 0.016552005676672827, 0.03739588105330064, 0.030021932381655902, 0.04905288558333151, 0.047800711040655454, 0.025664069952683586, 0.033542738416262215, 0.04060138062003159, 0.05248247735923337, 0.013512276045437302, 0.03192441406539612, 0.04207488562491152, 0.051869124384416695, 0.09236226444162669, 0.03665227397915818, 0.0453436563933088, 0.04614316490328601, 0.08847541776635955, 0.07017872536615019, 0.02862087631177518, 0.055855922551164706, 0.0530976842668268, 0.02299334380715605, 0.04904382276318727, 0.06513222841726196, 0.06691560449619448, 0.10090933887348061, 0.03322386963953895, 0.082949073985219, 0.04232218263730888, 0.008793323819014815, 0.0401610026376382, 0.0445170360316913, 0.01538483433485512, 0.0050385550111382, 0.059198456095351334, 0.030788546991384322, 0.004886327116119285, 0.04667967542885773, 0.023436835936961636, 0.04921094484386906, 0.019833945496488484, 0.04042456752710766, 0.02796850456375509, 0.0813886294922521, 0.060439043558172645, 0.0374606269742212, 0.041748551321366144, 0.03522144390210029, 0.08541694962449613, 0.02667087227887204, 0.03327559206574675, 0.0391993286358493, 0.06218708000115811, 0.049431551352984486, 0.0834475827193068, 0.061485201736251195, 0.021313786048502214, 0.04716293901325234, 0.0779938181081126, 0.07167934605311002, 0.03417941876837323, 0.05511176389371676, 0.006546623987941853, 0.0017641964692419636, 0.019576208620902993, 0.07353524001495493, 0.029726975124269247, 0.02669218867536514, 0.024275677316191218, 0.05397546781046737, 0.036777559998295004, 0.04540709613431846, 0.04007423551933419, 0.021984710530828566, 0.06147756383964612, 0.11081501661289124, 0.018008515020952593, 0.04188781844512109, 0.01913201360542688, 0.025558428343145118, 0.03535440995267803, 0.08709444469141384, 0.0980613993540887, 0.043588150593061606, 0.0630284667075161, 0.018771100008199294, 0.042378394338752956, 0.03345383008220985, 0.07014943782480494, 0.06880955770611763, 0.06014342938039092, 0.012078484080942168, 0.01930702064606932, 0.020471805624002894, 0.03442897957058684, 0.06714771381549298, 0.0494450306700122, 0.06769630937807022, 0.07819894581071793, 0.0719365983780834, 0.020374545016356056, 0.0705360287740346, 0.01988596478176694, 0.040526196751142704, 0.030477944303364046, 0.03216369588288569, 0.06548515746309873, 0.03719398624173576, 0.09383128400170997, 0.02602954560350026, 0.029749061439126253, 0.034486459147545605, 0.05698201051282306, 0.04039171767691451, 0.014176018453473526, 0.03621573026682581, 0.03142729003523146, 0.051380540319387956, 0.08497307062028878, 0.01293982067445834, 0.08841548670804308, 0.019675217824237003, 0.05978023092592916, 0.012083723164734342, 0.019418670300153956, 0.09827646321707195, 0.02478762897813032, 0.020658857482034835, 0.031537725439956116, 0.0321417206507777, 0.016238011134367798, 0.057773183986184105, 0.011374156249897375, 0.0330476617560752, 0.018671052755727884, 0.03399831558307333, 0.03680344993969606, 0.0455174396084922, 0.03574177465071121, 0.0283777276654878, 0.010309558335481393, 0.04577024862350476, 0.023181552457953655, 0.019611354819649172, 0.02057750277491587, 0.09156812237755907, 0.004824800679700509, 0.040876115071437055, 0.028588024546362223, 0.0291478471274698, 0.05133143025300196, 0.11396617373271335, 0.0492490194137058, 0.07868551123406618, 0.02939083298007327, 0.042210218887175285, 0.004784757742703322, 0.04133827293351774, 0.12030998695521586, 0.04554712168511845, 0.019934402605999383, 0.0765694844566526, 0.16361280043999996, 0.14763640450133433, 0.1342880272216374, 0.09580756868085555, 0.12496939499772365, 0.09018329588035423, 0.1056395870663466, 0.11860237697199469, 0.18183708220960634, 0.14674097029191835, 0.08902437339026122, 0.2764880573076587, 0.18079449783169455, 0.09753033954409823, 0.11038704159399194, 0.09618213971055324, 0.1170965392262705, 0.15597628279318734, 0.14796035244099556, 0.24106053575392694, 0.09740697640565135, 0.14367637344666068, 0.12889104504739085, 0.1930982835831181, 0.12255318432806, 0.10812691367802121, 0.1833551007533266, 0.14662175168914182, 0.16041208509235613, 0.08974196028805549, 0.1564458640472543, 0.15193274815476712, 0.13796253730693173, 0.10481115490678819, 0.3328824247564039, 0.09989610332394801, 0.13482361461126036, 0.1483536313378042, 0.13282453881636744, 0.22786131579308744, 0.1717965500128846, 0.22028671337231515, 0.13571711827910718, 0.12885070285729824, 0.14761625638892575, 0.1144273586631302, 0.1636972846162896, 0.11114716169334228, 0.1832332774516075, 0.14042595431448954, 0.14934522490347588, 0.09024186330216546, 0.1584762728382503, 0.118443934667495, 0.1416161331918932, 0.11665955501338167, 0.09874858022216829, 0.1187693764786086, 0.20368595577536092, 0.15341120591807753, 0.11745057909959748, 0.1593413393223478, 0.2859456885245539, 0.08766336456662224, 0.12866481928335083, 0.16125222307539758, 0.17487383327416836, 0.12975854769108758, 0.24156926410092464, 0.1462850866899375, 0.14184669501358463, 0.0837667809138375, 0.22455475773782502, 0.14782529113994491, 0.14251918231527652, 0.11291087995613776, 0.16579034407773327, 0.06396021348454299, 0.11807062002199313, 0.16745932790781223, 0.2223138739505122, 0.17179193816358046, 0.13826468238426795, 0.12919106040029757, 0.17837972740732855, 0.22327571266120483, 0.17729002862207352, 0.1620629739256636, 0.13243965624320891, 0.285388681316568, 0.10601058046543792, 0.1727074285548541, 0.12844049341736302, 0.13453092305890976, 0.2003924058930528, 0.22424890479493528, 0.18829809922364452, 0.19370812021436232, 0.23563546879637629, 0.12308880236119994, 0.1826670618667718, 0.14843595514614738, 0.10244215057501871, 0.2570552411939829, 0.15672294272770806, 0.16859332189684914, 0.18834585714484417, 0.12147624856762348, 0.15298144591431465, 0.18189106076475114, 0.15870430656979162, 0.2203016674085971, 0.18183859906369643, 0.14281046426584645, 0.09449492298787641, 0.16256037949314042, 0.08764854076528743, 0.14246877372985886, 0.13034630566835403, 0.1269320356509378, 0.15746712053735412, 0.18829600014273198, 0.1697870247787045, 0.1764193237308533, 0.1065832924758715, 0.18682992236027796, 0.1355494829195161, 0.12897491635334107, 0.10921976874552428, 0.19322502516931106, 0.15072369287090917, 0.20467574137353128, 0.21089456735118745, 0.17025128938257697, 0.21930610550747764, 0.1667475709391217, 0.1328623682380684, 0.09742603667320744, 0.12259096778448551, 0.4206907484800585, 0.1261140069653911, 0.09174315814649867, 0.12892769469368842, 0.12367065380057021, 0.10802639528147637, 0.12746821292826246, 0.10264789114796347, 0.08973236120636426, 0.11865208841740124, 0.1931882376271871, 0.0965434420974024, 0.12259081456690066, 0.10258144834229063, 0.07460020948201418, 0.1898312096994731, 0.1685829337445959, 0.10853847143270316, 0.18637008574460784, 0.19099797692991075, 0.15110656829370608, 0.1362534870784129, 0.1334448861739328, 0.12190754840811416, 0.13456427852713293, 0.14401613344107905, 0.20653554238379004, 0.1783997989109447, 0.12550096042574416, 0.07722637420820613, 0.0868627567204737, 0.12834500055760145, 0.1273932665466301, 0.20810544040174256, 0.14838252817430805, 0.2645542460583872, 0.2017447962275436], [0.06244983283742782, 0.0390239711099815, 0.0879234207733985, 0.049735799341672854, 0.08184358612784455, 0.023704501312045802, 0.04107009619474411, 0.022137968335300687, 0.014113407045031988, 0.0375563956256355, 0.04814355070852945, 0.06337949585530066, 0.04163394456789379, 0.015366816904485948, 0.03595582344719479, 0.05368910031393171, 0.01841379276987526, 0.03028847735315081, 0.04131182374793195, 0.035646986591839985, 0.039224728280978824, 0.02258024621574629, 0.03224982714821254, 0.06684216730777295, 0.04484186880290509, 0.039227765819598595, 0.04469443901231693, 0.04634961027712111, 0.10994660998544387, 0.03290705780889238, 0.007575222951990943, 0.07732535276802317, 0.05305146618235496, 0.04911808732656702, 0.017646613170302684, 0.049772950775560834, 0.03359017458053366, 0.08783660768981903, 0.054654371098525105, 0.04987452637344118, 0.039733943093808434, 0.020805835280747666, 0.020035470670629895, 0.03469491550218194, 0.027679469166023117, 0.02268411816217967, 0.024574014936543764, 0.048188435800013044, 0.02442173197895529, 0.03942299949666185, 0.11864323244099656, 0.03266003658814776, 0.026632456799908995, 0.03824242353138905, 0.03478791857618959, 0.02568696640552052, 0.036226126079958294, 0.03557613878060253, 0.06303140848514534, 0.0718361948947272, 0.026024211716327458, 0.05215181848935543, 0.032525400465895096, 0.0649766895859953, 0.03340682292717599, 0.015263400780367515, 0.0239042338404444, 0.05027927743691591, 0.08224577462721257, 0.05897571986180641, 0.015606273964588201, 0.016069391351794044, 0.03762934634822511, 0.028664399681973363, 0.04774144647883312, 0.039643552379622575, 0.03566515053652468, 0.02245058966500144, 0.05620476834836507, 0.030726752424192046, 0.04259071177652767, 0.011414566430293266, 0.03296412752881166, 0.018443176072211038, 0.021233626438545126, 0.015299369566022389, 0.02200264273391616, 0.06059301573963416, 0.047401138731548866, 0.09889233662115951, 0.03074913176768009, 0.030715023618071314, 0.04467956541526703, 0.019346937657363953, 0.0503093425575043, 0.03357110665209832, 0.06725981546145293, 0.021375111386840864, 0.02706599936279799, 0.010713269434598906, 0.03136557973771086, 0.07202183332053885, 0.027736519733744285, 0.024658462723657012, 0.00801156125699861, 0.02416568624246265, 0.04433338177360354, 0.06080630610907271, 0.08013369320260902, 0.036451378912334485, 0.018670979977375077, 0.04416020376788032, 0.05512427793995989, 0.012483883446322815, 0.029696111357019796, 0.054513307498587724, 0.048875800529194456, 0.0479318346497753, 0.03276132107261689, 0.03493829780528623, 0.04949303373934762, 0.09765099839217241, 0.05450637440287298, 0.09314635543212776, 0.02355588025473539, 0.0753856334655035, 0.032371412962675095, 0.06771571438519225, 0.04360949763307168, 0.05985633026988757, 0.03142714639374566, 0.05264314897959271, 0.004623027484593613, 0.029906232037671635, 0.028341438080514633, 0.0737638559733187, 0.06967486167747168, 0.012744613810472432, 0.09315338045839341, 0.032981130850291064, 0.051349935106812954, 0.11547720555456416, 0.024087771270123702, 0.02721896030819945, 0.05783536734299795, 0.014391432801682143, 0.025217101698921576, 0.05201183507339128, 0.01329468600752373, 0.09285088298061202, 0.024137044130193613, 0.0420567523237438, 0.022617918589422782, 0.033700223110856554, 0.03651594480259284, 0.031920123973020145, 0.025522253671360594, 0.08083974281626363, 0.01756577174209299, 0.05136629874487558, 0.10609488844150498, 0.09075419226240727, 0.06612874792828675, 0.05101037429525487, 0.058730663656587564, 0.10572095326478444, 0.03322079762696259, 0.04715461546795503, 0.043542154674087806, 0.01584887485800972, 0.05584016412256226, 0.05804710255395021, 0.032379579459947926, 0.019928448187607913, 0.034599265594395905, 0.03742711828841317, 0.09126343388831423, 0.08580311922536743, 0.04706009170941768, 0.049002936650668426, 0.02024891234243349, 0.047356828206008485, 0.023725266125233426, 0.03540319443169621, 0.035218322093808846, 0.08651574187341236, 0.039914605778551875, 0.021623124691447424, 0.017597859334801475, 0.0059488546779199, 0.03358919398799058, 0.04861687813254614, 0.0290934931892421, 0.07207197377518301, 0.061929302905956586, 0.04737618724785505, 0.03687569586139533, 0.021856848541046345, 0.02051405920346658, 0.026167106266403874, 0.07601759471600095, 0.06707547172423332, 0.055896823985442046, 0.03855199583115117, 0.05121342589958541, 0.014418825233024696, 0.01084765370544647, 0.03002203771874549, 0.050344938832905986, 0.03950256538847762, 0.04567480555945828, 0.05616553315532304, 0.07755841203634778, 0.018396209136793212, 0.011194114096372599, 0.026067987895540656, 0.0953631917194974, 0.02839097907135804, 0.003934699399847417, 0.04050129506316397, 0.07921225030816371, 0.04719940479844809, 0.027682908900803136, 0.03657238633041421, 0.02759531823798053, 0.2008629217743874, 0.07389737743764155, 0.0809054195340122, 0.0590364629733226, 0.06424828169627056, 0.05520729888831416, 0.026388815942130266, 0.025689360430283893, 0.035491888261129784, 0.03192118500479527, 0.016595266661756945, 0.03575921081186783, 0.04798151545166489, 0.05980410988652899, 0.03719366448480756, 0.04167057506199326, 0.04097006426403119, 0.012957726064468584, 0.0579918522928511, 0.07243649373131414, 0.014409941485932758, 0.0477702935196219, 0.03355651267714078, 0.031409030329556234, 0.024088437766617826, 0.06910284680704917, 0.036891167007026174, 0.019900315523808523, 0.05582712913653063, 0.03973763563760346, 0.07320356224813769, 0.05985886602091694, 0.0452105371251462, 0.03907482402639524, 0.035358857093078476, 0.017971671937454133, 0.07792770472024718, 0.015775480762033934, 0.03941780159009561, 0.03314969317627049, 0.04639662892347382, 0.0613309805762143, 0.03932610086555924, 0.03614847923839285, 0.03403000481006119, 0.01676487469775302, 0.05831103133518369, 0.11326846681655416, 0.04377903672115457, 0.05740173476477785, 0.0543841565658729, 0.06905251483042395, 0.044342180293413906, 0.029296722909015034, 0.0022545644418231303, 0.03204685981355367, 0.029978234726454944, 0.01915023500670589, 0.09194738186535337, 0.056539341927536076, 0.1225132175210503, 0.05558793733437216, 0.11820607202788515, 0.05584524711593986, 0.02990968709421014, 0.017504141883804433, 0.0445638899691403, 0.06280018782783901, 0.020646343435791713, 0.0393186851344522, 0.04526909305563858, 0.07445425441068027, 0.04802269650803459, 0.07614553139935579, 0.1098213699315825, 0.03300639259959421, 0.019889856508422284, 0.00619727592434614, 0.05040375523329262, 0.012232137378305198, 0.011468544027828162, 0.04240350670091087, 0.010214289556437684, 0.02592831282996603, 0.009384250527458086, 0.026199067454604853, 0.017690854747929884, 0.054234589389975996, 0.08721204684867014, 0.07605348593525349, 0.05049068323006073, 0.01719555783746464, 0.07459831724484121, 0.08680669440617485, 0.030595410480013782, 0.025447939312265768, 0.04044163979650025, 0.018726274288529833, 0.048003352787946506, 0.07051183571738583, 0.08580957734656912, 0.0022169952506139396, 0.02607422959690373, 0.08680979706226818, 0.05066123355420367, 0.032649158139622984, 0.03922779646311556, 0.03293034688179051, 0.06271725114915641, 0.019273241914267984, 0.031533494719394276, 0.04128378876034291, 0.06417925334385326, 0.012634134355692134, 0.04330259514972568, 0.031041401971672333, 0.021551579740198872, 0.038474069367493355, 0.08641415095377354, 0.05710941093463091, 0.015162643938956243, 0.011968439381058899, 0.04025766761192391, 0.037488987549178066, 0.043450262427570364, 0.07618855489718337, 0.052801200579251015, 0.2401188298338844, 0.1615852261743238, 0.1334483029260751, 0.2065789948908552, 0.15193310055521228, 0.12292274514273291, 0.1430448718489178, 0.07594069481016168, 0.13659674043376602, 0.1898669706837785, 0.11942693272665625, 0.0979123875919369, 0.13945843123139876, 0.11301657710705074, 0.10926619367373568, 0.11170256777756638, 0.130673210707403, 0.2486330390937867, 0.2005410575938802, 0.09517838832952323, 0.12976441592458757, 0.11301274666742933, 0.11643758869820064, 0.12832212517218244, 0.22240761246892715, 0.13060823112966555, 0.15337994953076686, 0.09617314583832219, 0.2631519987217842, 0.18028210758441882, 0.09601009168451834, 0.26248740212571237, 0.1391133239432689, 0.057346603247307004, 0.1952694380475629, 0.1634145215634377, 0.1336331139769285, 0.18593917660895856, 0.19320118451310744, 0.105926908342348, 0.15042456617999464, 0.1639989393973543, 0.12956629026561015, 0.11546261157960662, 0.25996868889178, 0.1012183710812561, 0.1837080374600426, 0.2248600284538923, 0.05772059205018225, 0.24363178729770646, 0.21081533853805837, 0.20039226799722643, 0.2523568699196462, 0.13677258825590535, 0.08369582585029064, 0.1580777232565226, 0.24420941759261394, 0.12670174196001985, 0.1892412453889847, 0.12692746976690908, 0.12688089162111282, 0.16217037945264773, 0.08753284616696258, 0.20073222717450512, 0.17186755104170692, 0.08349535596226493, 0.0942171548282908, 0.1878028233805972, 0.28389579045676416, 0.15888881118547532, 0.09899634071775983, 0.1830504582293572, 0.1365174350118445, 0.09994476522889831, 0.12470709415332926, 0.10118192827869808, 0.14414675143216887, 0.19646971396380858, 0.1980751431396892, 0.16300006799640196, 0.1638418760511183, 0.09357322728441608, 0.13263836412900878, 0.1367407036764968, 0.2324736553935274, 0.1736973980141263, 0.2118395368057874, 0.21388350535304318, 0.15131273787588845, 0.2122932293963048, 0.13137529964648909, 0.12668538598283646, 0.2002934886202697, 0.12512786794574032, 0.10404250058796137, 0.19486256875097754, 0.2570873096344933, 0.15288634375939447, 0.117004708266787, 0.13325305775769297, 0.1212826734709163, 0.15613247279918965, 0.14525215501987165, 0.1632444653660059, 0.08644207485861356, 0.10690390027218288, 0.15311518954413553, 0.14662743606153997, 0.2157674687764337, 0.17602408364895852, 0.08886933251614533, 0.1680316262307667, 0.1319802639585349, 0.08965191431343557, 0.10253395089098524, 0.14015416164071332, 0.14816852917353954, 0.13522919688013293, 0.14865539337117828, 0.16274940402757737, 0.1782622554850194, 0.24281602623241566, 0.15369620594766834, 0.26439122254810027, 0.06974960887624372, 0.15076809532700047, 0.15635911225070878, 0.14150128129028505, 0.09577478777857558, 0.1325745796484332, 0.07523363396044701, 0.11635125058913424, 0.07985196436845488, 0.13708435539757052, 0.12771005156419932, 0.13712357909929368, 0.21262534383323886, 0.15202887686750582, 0.2483940043396527, 0.12306029622953747, 0.18645823182117555, 0.1587870747091309, 0.1939109496531948, 0.1072590739556378, 0.12818009247102086, 0.12106715761605771, 0.06306181834529966, 0.19457265043691283, 0.15455710491345775, 0.19085101062251678, 0.07285860051671345, 0.14935447924560116, 0.14704685387832506, 0.12635979861501725, 0.1235566292739203, 0.1448686207614599, 0.12553261517877543, 0.1492028244801106, 0.10447509511704407, 0.14820963745155644, 0.14926751294443685, 0.2577123760936722, 0.14773242596176364, 0.244635239904446, 0.1506949339302317, 0.22803498792552182, 0.23451486602425578, 0.12782183911411032, 0.14275881461799145, 0.10394960476626312, 0.1495460012266713, 0.08609934244304897, 0.11729622770461345, 0.12587656567413963, 0.17495958915641233, 0.12000947364515836], [0.03896094888689057, 0.036110661308010744, 0.05288671514379883, 0.04520833845280352, 0.03869530789914631, 0.008862935355864465, 0.07985931115164872, 0.016257042673626737, 0.06849578341409084, 0.09153653657244099, 0.08717997840815976, 0.04800802209384499, 0.025152639230532993, 0.06047965387903875, 0.049384620806743065, 0.09371307663499348, 0.030573354808673747, 0.02649940073400015, 0.03965811954150277, 0.08736779252367635, 0.06985526772276049, 0.050395891340749885, 0.04638198898324082, 0.01572891506516645, 0.059682861150753115, 0.09730927721266786, 0.04435580516714723, 0.017483714149303494, 0.04279863570005663, 0.10890551947898443, 0.04550679864722394, 0.04116126448817311, 0.0933242257263872, 0.012037157467866858, 0.09901288821692429, 0.01130920061240754, 0.05567995598539711, 0.0558928441586754, 0.03623811535597329, 0.09750776293296969, 0.08323700813155982, 0.022637233581213702, 0.05122728443013565, 0.013327986891982297, 0.01851610572738273, 0.027179349732074528, 0.081000383793106, 0.011455599057127633, 0.032775838438782005, 0.02712562973160417, 0.06216324700583374, 0.09293871496113078, 0.0712905947359339, 0.04183677017628666, 0.09422793368538541, 0.040336612972521016, 0.03605261865642763, 0.09247511685375245, 0.08360882890560935, 0.03211527529563154, 0.08017539902920685, 0.04063249911151586, 0.03325442122595926, 0.01905313910796277, 0.05218494413120132, 0.07115219329153338, 0.04655151658000485, 0.00873572932886741, 0.10882131109434752, 0.036229309175283685, 0.0455472212765486, 0.03820924809382808, 0.060948932528375625, 0.012086558647664085, 0.03201557852838549, 0.03555352386507777, 0.03288663390483106, 0.03467076074992938, 0.05819502647124952, 0.12124911881983282, 0.04218815555495601, 0.07257275012952667, 0.07163186392356312, 0.006999567727513251, 0.0992079342024461, 0.05351426755829204, 0.0885905224769827, 0.034223093440936464, 0.12822470943173095, 0.03326490896964266, 0.031786564204301086, 0.020952458763795517, 0.03000042063274211, 0.03137616707282442, 0.01875000577720423, 0.11527292820955477, 0.10572385673801746, 0.04767897966948729, 0.027229781300129912, 0.0959112586814069, 0.07799557244945919, 0.036815324302522406, 0.03210966178636638, 0.10495956145947981, 0.0183684307886588, 0.023104244610294703, 0.06353678902791393, 0.015480290805440278, 0.03522207592463782, 0.038004108899903875, 0.05395293716461428, 0.031910258675775224, 0.03623431172942923, 0.06313621697406616, 0.060013945199429035, 0.04182092364757292, 0.033606323713977496, 0.04947345636244263, 0.00984386018958063, 0.06541858442247876, 0.025626895536157875, 0.037831172211876804, 0.07838940292957329, 0.009648913795488977, 0.01724361070251513, 0.0129871160700737, 0.035352893098587954, 0.03257865123751183, 0.020861683090427713, 0.043335870178716804, 0.023276623969356862, 0.062056304962043805, 0.040862302506162275, 0.02727907522761774, 0.03339946465266328, 0.0332547506437667, 0.023363059754633618, 0.06859778802120878, 0.047834683209657676, 0.02871932244048484, 0.0558851105010798, 0.0490930439123223, 0.051258422073818026, 0.0028794070596866793, 0.017982649977409074, 0.06829349789768457, 0.030870311555542776, 0.057189976571187864, 0.030995714403088057, 0.021054949836745378, 0.015243109026473137, 0.004590609995272732, 0.03252191476583962, 0.05439372500404716, 0.03729586827478582, 0.012715335845226243, 0.019859258956726522, 0.03894847697548328, 0.07378560520948903, 0.016627654943975712, 0.08569906916349165, 0.0161284088502608, 0.07006161350516543, 0.02708736555500617, 0.002459939447186527, 0.025637908050069408, 0.05003471152796861, 0.06829828594721134, 0.025012050605108662, 0.05912381614888868, 0.02406252867301866, 0.04590949276462198, 0.04196751074144437, 0.03181288123971993, 0.03651734674349427, 0.04132763197224948, 0.018072659562852596, 0.06128676581166445, 0.06544683008424698, 0.02193025317073109, 0.03290794647088455, 0.01257141282211148, 0.040973335459467866, 0.025456435227346037, 0.030069575389666908, 0.011959398585942485, 0.009924115560528253, 0.023153182306897738, 0.04814935382455588, 0.004079775385288221, 0.039026242560676994, 0.032750718415744846, 0.01166544394612673, 0.019339309336857933, 0.0356571908829914, 0.11952080148001833, 0.0448293968914978, 0.11353334937725337, 0.039913460477105075, 0.08324919659043513, 0.006604101649680806, 0.04745587571373871, 0.03216336263463863, 0.03954279649582121, 0.04694399874537222, 0.043771927425217245, 0.01936156036061866, 0.024291023972534367, 0.11742265519475746, 0.04930847166706959, 0.05109686945234576, 0.07889257713911996, 0.018531890969062527, 0.009815582926685532, 0.07190341911008281, 0.09983551343001666, 0.02111765987900717, 0.03602100986867182, 0.0891571517492975, 0.056413197889924056, 0.031807761857165925, 0.021475352076513153, 0.04231128503658599, 0.057777592822188334, 0.047331106803950765, 0.033068510838934494, 0.08889878859683391, 0.14639267607802345, 0.07562345013983789, 0.07495765844660421, 0.02678627193334603, 0.01707967171715873, 0.08799942435636636, 0.07030475449057356, 0.06992760174457105, 0.042580806259666724, 0.034273678226576704, 0.01538929966984377, 0.01331885608153478, 0.04695172091164897, 0.05611956787986621, 0.07904981668557852, 0.004422838655075118, 0.055316274895543055, 0.017754357691193302, 0.06193946123183255, 0.06083272465114152, 0.08247825166871471, 0.018824017531568968, 0.0680058012386003, 0.024615751406658563, 0.025093422549205924, 0.04027107415059882, 0.02846199159149922, 0.010644003594925087, 0.04835738883083386, 0.07725016123825505, 0.05914431283130281, 0.05780913649247058, 0.08647765198181714, 0.06354751425885385, 0.09099727962166072, 0.056707333518011924, 0.021008116966714303, 0.033146402828635714, 0.011220233864150943, 0.0703478392754351, 0.03337673482394988, 0.02558173656824135, 0.03175378713246075, 0.06724528277352934, 0.10297465063030682, 0.07293526293529619, 0.026441453843407577, 0.04771155372802769, 0.06520863036595045, 0.012835439279555313, 0.021183554931814154, 0.09178511678211151, 0.07913415530516256, 0.0527361405622815, 0.04430020633604258, 0.00751775773918076, 0.021499106547825282, 0.01442379235560375, 0.03511352892664652, 0.0645557472542409, 0.0954602090942283, 0.03274828991702488, 0.010959445085797099, 0.021918242827298182, 0.050671660010853124, 0.029245881483920162, 0.06388042542722917, 0.0939518279365955, 0.04948157689444, 0.006512249143974435, 0.04645668255585817, 0.0558719567714199, 0.01976769804323633, 0.039916892551005854, 0.03456641191376313, 0.01817386552330948, 0.07748699732004635, 0.029117734126386144, 0.00923996169735948, 0.0412645829360812, 0.00789247815602369, 0.04678444944382195, 0.00975618142664673, 0.018233476739917553, 0.03623986203644065, 0.019767079427237474, 0.019026138339071505, 0.01502963479593276, 0.020211013972819335, 0.038714299218789223, 0.05178518413055328, 0.026634701437527136, 0.050346735309088425, 0.034518937445095474, 0.049337996695671356, 0.054666992397077625, 0.07850738046991249, 0.07197141707424196, 0.0768447628304843, 0.033328172510429736, 0.03354117176645706, 0.05303023405553353, 0.011159269544746608, 0.0655676574716645, 0.03638948283849224, 0.03509379833215668, 0.11162513927105935, 0.04929798775382581, 0.01746340707365063, 0.0306572127080853, 0.04781386477031535, 0.1059405293856417, 0.03644668662379827, 0.03727504600500388, 0.05722216375532651, 0.03428261081177381, 0.033074118602540226, 0.05777907903276144, 0.04943977530685164, 0.1012507459569362, 0.10431111399685183, 0.017779251718292796, 0.0431002521767251, 0.0497712079255331, 0.06840380689790172, 0.16579710097322542, 0.11321826507487606, 0.11817822473183756, 0.15768632893600773, 0.07855608834013825, 0.10453962270290622, 0.08958774678889783, 0.08609610189112925, 0.1805386857520188, 0.15547221226076927, 0.14405909565187272, 0.18410412023865408, 0.17604910408056554, 0.11824731054084918, 0.16682385797462157, 0.2600435510037407, 0.13956171520535024, 0.10738383903498612, 0.10960131117533292, 0.20365050122622522, 0.14068303810011956, 0.18339008032794923, 0.12474247975455177, 0.18679236873022972, 0.11054348440900927, 0.15379618042178694, 0.0962484599421582, 0.08887755263957287, 0.13155545288276288, 0.16542778530668828, 0.10233527364870233, 0.10714998303522026, 0.18154213835875835, 0.17248805161685715, 0.24528987735750216, 0.1478865475303704, 0.2369294066222445, 0.11964977238207095, 0.2331705349347284, 0.1405596060137595, 0.14647150652543192, 0.11316079315879654, 0.1808752434989137, 0.149398330118387, 0.09236995596438648, 0.0950214782008721, 0.20114093508210876, 0.2945741981027588, 0.09203919750307837, 0.1499513383474081, 0.12168722152109109, 0.26782124333323976, 0.22298893530762967, 0.21702601334020016, 0.14490232863012822, 0.08991914110318308, 0.19676799795800642, 0.18329608133964, 0.21246883207030837, 0.17577141252977235, 0.1255444588980848, 0.1771172451516313, 0.15326777893689372, 0.17263209146838035, 0.15275425487949004, 0.23740278767241588, 0.1579659510283701, 0.09161672299547542, 0.2404223998347598, 0.1307075927334447, 0.10719884412303086, 0.1996432638336574, 0.10912328763234039, 0.12207261737315886, 0.11863079117310625, 0.20903111976240912, 0.1366040948778391, 0.24174459098327547, 0.12796089173324648, 0.18014468673256137, 0.25622884682830305, 0.21242628354699383, 0.21528670263867225, 0.08505231475517636, 0.20590309083702105, 0.2086563648716096, 0.1942222877856224, 0.20582609900063087, 0.16751463945594527, 0.24765632295560455, 0.18393795576787766, 0.18539847175200141, 0.10753914037899626, 0.0877427312755777, 0.14738393256500845, 0.35783617607047485, 0.23100518741674964, 0.14633475983094785, 0.1433989883310372, 0.25141568493939215, 0.11685547433913716, 0.2501793416036714, 0.21166062463195096, 0.3358140593815235, 0.11667088545378178, 0.16863888880658537, 0.17624293964716697, 0.15875322894463617, 0.13430425296387366, 0.1337790843700209, 0.219025717327191, 0.23799570908229198, 0.13261907403507542, 0.134374150826085, 0.18310005476157512, 0.19787078152500814, 0.2048741121806445, 0.21620151887257255, 0.12892758744137903, 0.25007118531052147, 0.06051806169712256, 0.10923435505960258, 0.2878113577683126, 0.14399114365298904, 0.13182019754763574, 0.12887920132808148, 0.15236062358223623, 0.18871387046191002, 0.17005166219126794, 0.18690832379844882, 0.07978648683356662, 0.175525268479701, 0.11023992206901313, 0.07745105247463911, 0.11247460054413927, 0.19371054105220303, 0.12986331787561217, 0.1481210930092681, 0.1118785917999283, 0.10347391779143965, 0.23532206222655314, 0.16173976143040966, 0.20883487867972544, 0.09808739271735954, 0.1611295264334448, 0.16278012415334103, 0.19678033197358732, 0.14352956035685155, 0.2420540598611678, 0.13506329287925076, 0.057401332568617604, 0.11093275666597391, 0.07341753826626847, 0.14649398354513032, 0.14572392728540207, 0.18603173535197012, 0.12709034005961112, 0.18219918132789675, 0.16924417487555937, 0.0532269194692133, 0.1698281330567214, 0.15399242150447062, 0.18010006977185128, 0.18173666340449166, 0.0787082257410211, 0.11612971328319081, 0.17673815420318037, 0.1710816061184291, 0.19193012207265825, 0.1382496057739181, 0.26774625864721113, 0.14800074059636364, 0.19733335552436693, 0.11210672512289979, 0.15830710530281067, 0.13255440089250767], [0.07465597302202256, 0.06898318387327657, 0.03522143241078143, 0.029353390432774063, 0.03618841540188559, 0.027607543086032235, 0.09040925351362075, 0.04156361003556559, 0.09740859285117158, 0.025444210379294334, 0.054753387962738355, 0.020273478866945353, 0.025579694943923145, 0.10122243900813403, 0.03497019004557402, 0.03901575481699359, 0.0392091537134782, 0.027606581645687262, 0.09017277749315386, 0.019886962611288316, 0.07078352113885265, 0.05426607560366393, 0.02040869721602048, 0.015020541332271552, 0.013732739870676832, 0.041951147103381735, 0.026129857156305548, 0.007558569158126991, 0.01729094536013661, 0.054222014056698936, 0.030524258148826422, 0.04788901416524764, 0.03693788687908842, 0.054321954056860945, 0.031687265802775665, 0.013437296147458257, 0.03635005612346915, 0.04141589679244546, 0.05004590790298197, 0.021054551471024755, 0.05049047638632117, 0.02964829597922583, 0.05268544852433186, 0.06372453802595697, 0.058648412626597195, 0.0856424322832496, 0.07651354471642165, 0.07523404764792613, 0.05762175138619158, 0.008759484757789442, 0.058594173601558136, 0.018598979203811577, 0.029775991344884522, 0.04770257517755513, 0.07168445585956497, 0.03357250093212051, 0.02126354025676847, 0.04555572485250812, 0.045776457766131054, 0.1046955062737388, 0.050643142387871785, 0.007728546831546532, 0.047734452096084436, 0.026309560315923828, 0.143891092570078, 0.053554161586948944, 0.09183401617431834, 0.06428993006627406, 0.08056346086725112, 0.057029461998853, 0.11549638839618814, 0.010606691282573006, 0.053292243786516695, 0.10867332589001426, 0.024727830069980795, 0.18291550418061597, 0.04641407274550969, 0.057484345856092633, 0.051787911403563716, 0.023560147364473632, 0.04258877357407924, 0.029029023059974277, 0.014145941841566275, 0.03365315849922838, 0.03602249990968454, 0.037785486558512334, 0.08792270831162892, 0.022930428836374514, 0.07636935930819282, 0.017034690864684603, 0.08513831578555607, 0.06801572207721972, 0.037839204643762885, 0.05595147669796021, 0.009449574844761482, 0.10504715595274203, 0.11089863510982645, 0.0637183518659684, 0.03479847143734655, 0.12012736691582589, 0.02259016130870629, 0.02205049450088653, 0.06655065553082574, 0.038025624479257294, 0.07495864670002654, 0.013277773658985333, 0.02879836930773191, 0.03412843944745199, 0.06338765852213388, 0.03382603006978189, 0.021426466090845007, 0.04304795135413447, 0.014878073876212924, 0.06521951647535448, 0.08609489147220889, 0.06752354889026574, 0.06151489530419631, 0.06516416662282522, 0.030358664413553574, 0.043579417190724806, 0.041119738692237486, 0.015542425324148951, 0.033391328798907424, 0.08057457680303244, 0.013208924379620342, 0.06876910060283638, 0.06281182470340883, 0.03551289056157393, 0.034101771926807786, 0.011752481110424045, 0.02069336782780386, 0.0549272860911104, 0.01018534005138903, 0.026836879701623996, 0.044452481632751804, 0.039741347333596605, 0.04104303030837928, 0.040652030523145394, 0.02846805134698028, 0.03517528327422277, 0.02122937656578518, 0.01694305334240198, 0.030038786315990072, 0.008501461556842251, 0.02979661060136653, 0.031231648416348526, 0.03796617605633313, 0.09553720859149772, 0.04725566629560725, 0.030539317522197965, 0.04150293204152296, 0.06374398516791482, 0.03559960405372324, 0.04613070448319759, 0.0506937233430724, 0.0055343326417759305, 0.08768952646923643, 0.015795212314133684, 0.04437311109335673, 0.03935354596544658, 0.05522935455965419, 0.04113315289179164, 0.039180367959723364, 0.0353575547436072, 0.031438390649254286, 0.07610492873936892, 0.06359776962668666, 0.011008986076640507, 0.07258446361388891, 0.06225761371634661, 0.07103626120595202, 0.009616259297716522, 0.004085913664781519, 0.02759026397290009, 0.02169876629787107, 0.020122760643942222, 0.0055935679964961545, 0.05255908615166142, 0.04112465697671137, 0.028922511940641753, 0.08820157197694625, 0.03486311393639734, 0.03963313741429199, 0.058516672316698305, 0.07148408556296941, 0.11529041033598686, 0.01723290653899312, 0.038774253259743416, 0.0501975741597914, 0.056942468884611325, 0.02997002609434628, 0.022583998131355452, 0.0068707553098999695, 0.05437487158023062, 0.06110203520004308, 0.03553381242278603, 0.02161983817425226, 0.016697091238212683, 0.04569019243541745, 0.05670659807360461, 0.015355680858896626, 0.021565848127788594, 0.07784320522219905, 0.020120414499674114, 0.025077884370881705, 0.040003054459849675, 0.10498403796866056, 0.023228312549631924, 0.04968672374924345, 0.08065054208160409, 0.03627995907839748, 0.01892734938601573, 0.056749257679668166, 0.04099508086519857, 0.03837038319738161, 0.046114961376353625, 0.0666342816886402, 0.009635004511613761, 0.048568208566716606, 0.11381868648553088, 0.09088174590179998, 0.04139550736234073, 0.0589874410070479, 0.030605547738471822, 0.013660868374450554, 0.06601473872339533, 0.09853516344822223, 0.034496671099576263, 0.06778239467812162, 0.017626421007838462, 0.04063341458658538, 0.029872491610266512, 0.010048767641907739, 0.024750845266445994, 0.04357002878321275, 0.0260219460112914, 0.019815262527235096, 0.04113088144109615, 0.06276228945822486, 0.05727550262705453, 0.09967557725406463, 0.02975252607176381, 0.029944415775037585, 0.045730006024842305, 0.06087739523800631, 0.03514790329180899, 0.10272823844946201, 0.022106508934690107, 0.02140700554234847, 0.05685185600492743, 0.014399905734124684, 0.11426875548016642, 0.04566235280024909, 0.04842394654969535, 0.011100885026427287, 0.01702670631329379, 0.02926772648108102, 0.05754985786493748, 0.061733916011308475, 0.05307524555152463, 0.02642666260080953, 0.025705005860917514, 0.12964179589142724, 0.018357717049037738, 0.09351064556188161, 0.03244311879238775, 0.05339816310292771, 0.045838434279205344, 0.009628129830103247, 0.05492317602939664, 0.015380284730194798, 0.06810844935957464, 0.11533925610203898, 0.09392230290799372, 0.020616385567512725, 0.09754683341710799, 0.024527563195255016, 0.030339621382975773, 0.0914766897837962, 0.06695855904610888, 0.0913019068238716, 0.018561278101837924, 0.06923598522740988, 0.03958801483555187, 0.040453920185926466, 0.05849003160913145, 0.02515551589068867, 0.02356333429023864, 0.012388398247440497, 0.031141407089307908, 0.08594350483749183, 0.009812952372275535, 0.04248403403307161, 0.021435377608624198, 0.015027674568456509, 0.05561020751033099, 0.06860180998281126, 0.015882296401316363, 0.048730121249513286, 0.0062932633896238144, 0.07212067398452951, 0.11899023962717865, 0.06617051504191852, 0.07953131060686805, 0.0476291916152883, 0.03135956786272507, 0.015353701479222267, 0.06873258885236518, 0.05514210480595789, 0.009104943488754574, 0.022456385120148623, 0.050126301169755964, 0.0859520543787268, 0.034716316168346716, 0.018306764541193843, 0.047583126748401317, 0.014010049335117784, 0.024987336608671376, 0.025166698859163353, 0.019370138630150788, 0.03187824003097992, 0.011528500941612068, 0.08124432917083464, 0.08965804301682981, 0.04223798191355121, 0.029251736310881474, 0.046345201441116875, 0.043754939425496325, 0.022898076943332152, 0.04445678704688626, 0.08245822613037403, 0.038944137087392236, 0.055289909979628946, 0.01718679570683068, 0.08928649037355378, 0.0336975839379574, 0.044689582014876994, 0.05573800629785946, 0.06543553794824308, 0.029459156531600222, 0.0430499968088923, 0.07039382753352966, 0.015680557680166057, 0.008578106738446702, 0.05411192722197983, 0.044672050092729836, 0.008354384166699263, 0.013346478339254618, 0.02614063026774074, 0.028201676830048525, 0.10494215594184016, 0.05372538223802563, 0.17686189272471015, 0.1881110511960522, 0.10801950049015785, 0.2078211145295251, 0.15385055734265238, 0.13867766506248905, 0.17844372639252296, 0.14906287553810305, 0.19291846742553098, 0.17309491582695516, 0.13142360915099421, 0.1298073168483473, 0.13850554042766172, 0.19380996394301617, 0.15148382063113874, 0.16256972576581663, 0.12180526034846423, 0.2776326845970846, 0.21578306632657207, 0.21610594174313932, 0.11069487870460558, 0.16789362315208683, 0.1236566037480389, 0.14138354889808163, 0.07243133795958373, 0.10833513637584065, 0.13257301682906766, 0.1201868613040255, 0.19963897374128142, 0.1921883703119332, 0.26071669714104745, 0.1259176739521565, 0.20062485229103796, 0.20255585351297933, 0.07876165271286042, 0.07594346804844757, 0.14688344732407602, 0.1129392175484569, 0.12046282915698907, 0.06709180471877899, 0.18431399768638998, 0.10464037092582834, 0.18511242984283358, 0.15887433212370644, 0.23276525910102555, 0.2347807138557396, 0.17485458914551044, 0.23286929384114283, 0.22302615185899122, 0.14402935611865214, 0.18924401862727058, 0.21060645700462405, 0.17288243368027673, 0.13463190876908843, 0.16814272430154587, 0.13178460510267367, 0.1535143979614781, 0.11121920460174162, 0.12763921907472034, 0.24622243618772877, 0.14143270109930348, 0.1820148299297979, 0.09871191525411221, 0.21943057947341474, 0.22701209200726402, 0.07868316700501789, 0.1426829565917292, 0.20870010849208603, 0.21087585948407653, 0.21048037425404598, 0.2946776506160536, 0.15543830520924062, 0.11567107942556182, 0.25943313214567404, 0.09119526738481176, 0.20640552194128114, 0.21469699879807813, 0.12300362870577844, 0.14322482590233127, 0.06875635289977636, 0.12055182559115273, 0.15794664561267824, 0.16258887796392366, 0.14456425402914325, 0.14765417774117764, 0.21102763682363496, 0.2590320391520377, 0.08146018210437991, 0.16353093628441134, 0.0935688988876439, 0.170330043221193, 0.22792028924149854, 0.21126533858478072, 0.21264471053596468, 0.18164926809408974, 0.2658593534461914, 0.30666021570082636, 0.19484144004602588, 0.1607164058593973, 0.2592379635860843, 0.13149012090458026, 0.06513036682360596, 0.18979506567120555, 0.12257609801787524, 0.1250640834651647, 0.09509120752374012, 0.14911647104928571, 0.16007747320878893, 0.1858461888567094, 0.2011947757414272, 0.11466700628760362, 0.14417140414157223, 0.1062738312588584, 0.07373567925946367, 0.23578873234650782, 0.0814901744466155, 0.09993367993663396, 0.0920690366277291, 0.10622658661656803, 0.09188157491265767, 0.20866738121596076, 0.15475683935707615, 0.12758697953916368, 0.11798221347553116, 0.15765683455092294, 0.17970723520603873, 0.15098295234624418, 0.1333185889187359, 0.15547375975837632, 0.14156929457620268, 0.12607265353923844, 0.18673672010341, 0.12880711245440668, 0.18796929428654333, 0.06433602557667802, 0.21490980270168475, 0.18694872727557538, 0.11686871233846872, 0.06824792332706914, 0.11230893403051362, 0.0716870912020245, 0.11269271343706116, 0.1411635284462283, 0.15279041422951609, 0.11854709606737861, 0.15616628792016737, 0.16505773419574385, 0.18139115775064116, 0.10337354495160042, 0.0878421311837531, 0.1959031459785277, 0.16302050722222175, 0.10049290879960023, 0.13232396164488408, 0.21623185595437405, 0.2511723600928822, 0.20781277949290894, 0.07195350593857228, 0.17829224016637574, 0.14628033694480697, 0.17887252112550123, 0.1113009385223831, 0.14086195027395604, 0.12919225549745944, 0.11819873290557055, 0.2298120974052337, 0.20573041461888822, 0.16109879098592267, 0.1487471247392316, 0.16948383782179127, 0.12088420815886029, 0.1518061751079175, 0.1435626247116635, 0.10950288419882137, 0.18664033092077703, 0.1019069845337541], [0.025875776435338685, 0.04321913370081494, 0.06300529254780662, 0.019727698677489837, 0.020878186539536523, 0.034921669866889715, 0.028253435645432725, 0.03659097162345725, 0.011292945184264214, 0.04527234509887715, 0.01305695839091054, 0.07089618202899733, 0.053380091088793935, 0.046892624889169975, 0.05898668258000286, 0.07789245701485104, 0.03937389326071547, 0.03440740270419948, 0.03980194488840719, 0.01474693111489497, 0.051443995382156105, 0.037822821853502143, 0.04224199621427444, 0.0385196975642635, 0.05055808364563892, 0.04848156402248049, 0.03987313360877095, 0.062190420144507964, 0.03433335264543853, 0.025454655988141898, 0.04355665288805481, 0.020958146966633298, 0.013669157445791268, 0.061813098859162106, 0.015532933494767115, 0.03066361145747285, 0.008214384471366723, 0.07123326071568074, 0.043203846416285926, 0.07672689254245452, 0.11793958068254495, 0.008332198260412102, 0.004283490613283169, 0.03530771306325351, 0.05458161572835619, 0.0668157066308683, 0.022077520167635336, 0.02152581620330532, 0.045545865300922625, 0.043397697304645856, 0.04881443305601997, 0.037582787354626966, 0.031106521360455986, 0.032433251579923016, 0.04840219348308541, 0.02706206933174643, 0.03546098810470393, 0.07477827895913394, 0.027286433502130454, 0.08196148705939132, 0.06519015998609605, 0.04236337135455782, 0.037874498314434485, 0.047998963104140376, 0.05624161334708334, 0.036156362283133694, 0.003830150423210956, 0.022572604488701593, 0.05969007386856022, 0.015273440362615211, 0.10460226571247463, 0.04762386347377493, 0.01222388373853098, 0.1223320990139919, 0.029913477314215516, 0.20028408106055953, 0.19912555693618714, 0.11218092073836636, 0.04410891418134974, 0.015112015103260356, 0.1050826411453947, 0.08152257996581255, 0.034129389396478096, 0.0473749423549781, 0.2723255338928392, 0.03489711674891653, 0.2840483338842469, 0.06197876537278776, 0.06755456779031985, 0.04953028859510537, 0.12885415025295752, 0.09174488950520755, 0.05505898426617346, 0.05132713249974674, 0.03964801101134189, 0.0958045349726754, 0.11997503799296196, 0.0641158136028436, 0.05526950522776573, 0.039879557256016045, 0.02727330850076772, 0.07827386920971256, 0.0582912547754184, 0.051381229798519806, 0.0967076683657304, 0.039657648397429336, 0.0891909055832413, 0.04309756703855049, 0.029476203903135274, 0.041567949923656644, 0.023295259058114984, 0.023844023160035574, 0.041950430811172536, 0.0696844607591629, 0.02824145594551679, 0.0460040663188744, 0.011230016806944004, 0.03265440201146468, 0.037258762806173296, 0.0037889648181942083, 0.00922823193362884, 0.040959545876830816, 0.052508888240422935, 0.024014512197144573, 0.0077786446725499015, 0.016251716447333177, 0.03258948755120078, 0.0847521308629263, 0.028263438838504018, 0.023698138951834653, 0.1126779892271565, 0.1027749851346016, 0.00486827329657371, 0.06374920222667918, 0.0835172584160201, 0.08401451076591208, 0.03904563224604053, 0.00608201225047871, 0.0057024535095889966, 0.0170232359349968, 0.007284933085282965, 0.025112270227363034, 0.014705663873633791, 0.023403976510669437, 0.011727157116477049, 0.029091671815202124, 0.008649683290822132, 0.05223321150087061, 0.042263645859014605, 0.053180115327479384, 0.04549918756369622, 0.031850915589940645, 0.041879215277731426, 0.03482143109243724, 0.027711246493122274, 0.050034359127523444, 0.031973231103151076, 0.025881548907848138, 0.017183206584905426, 0.03872897746341844, 0.03403603009158566, 0.07427459147067801, 0.0320127516639449, 0.046032208558772846, 0.03099069078152459, 0.04803426443569122, 0.018334960407246987, 0.03915713634341955, 0.07855870069996004, 0.11294131662936942, 0.05220233432708248, 0.002371429478854782, 0.004969471117346398, 0.0610477387184097, 0.037361322827036345, 0.04947906795648798, 0.06009768627043213, 0.028697381682333448, 0.061676172134015834, 0.056865791144270095, 0.05596201040691907, 0.05861668509521312, 0.05080159618369034, 0.06741107952210211, 0.0048075464644259025, 0.021650215475669792, 0.049260487749932275, 0.05528100037706956, 0.041476141946810874, 0.07931546533420201, 0.06350252191506087, 0.027511318612302986, 0.03688965398337572, 0.009657237340786285, 0.04106409389585738, 0.012741493917400799, 0.033863947591594154, 0.02600583709746359, 0.05418928678057367, 0.04159896882371076, 0.036629004058458155, 0.02615360396673843, 0.023811108192368865, 0.04573244601488114, 0.05469370971343691, 0.07516478563869193, 0.014711366440620155, 0.01798188005904517, 0.05490804196245248, 0.09391563028217324, 0.024391557690837694, 0.0065365346099790795, 0.041663212957040924, 0.10356560319421754, 0.034582633825559775, 0.031544482335448265, 0.09162810706203023, 0.058138090816716996, 0.03739694591551539, 0.010733573637422054, 0.08656385985593643, 0.02198488481583134, 0.017295982388238755, 0.03886902982729577, 0.028384496052298817, 0.03182172189436613, 0.10152821534223135, 0.04896333373542275, 0.042684140029333295, 0.015473412293490144, 0.023433332999927864, 0.015407303693674266, 0.06000119366592938, 0.09754811278394154, 0.046896424685274406, 0.07620285775872969, 0.07865076148582083, 0.0210074006745051, 0.040158351973420194, 0.12114448653113459, 0.03427260953392233, 0.06797883494366562, 0.030026339302440325, 0.09103529290446351, 0.13129280729880258, 0.04493297580930014, 0.22551445140232965, 0.0283327697956514, 0.11577889864002505, 0.04511932286644175, 0.04346713934454226, 0.06151745020742379, 0.16017421479186705, 0.02608801917954078, 0.09568516315231401, 0.01658884492973166, 0.07610001811577428, 0.05847569427362854, 0.09743440235334058, 0.020082594654072198, 0.171699793108048, 0.025792014296917666, 0.1600525753512498, 0.12694570265950697, 0.0453072901995432, 0.08740873226234991, 0.028085957333866148, 0.0221615236237525, 0.027922635049288793, 0.03225256974298147, 0.033814764746855346, 0.1715378421208551, 0.007837703348242589, 0.03274208843527782, 0.03688346016250792, 0.0015146774427604772, 0.06069257269583403, 0.029852280295604182, 0.07849244941626826, 0.07907579472709088, 0.06772137577495269, 0.02927993983781386, 0.051114198361192985, 0.018154678851245873, 0.06949133765433105, 0.019880136767882976, 0.05068064622220494, 0.02805826325540341, 0.05449954855946764, 0.009273330572121328, 0.07609044967760002, 0.08044035819869849, 0.03209648315884894, 0.023382506896591475, 0.028105178479886347, 0.008482664632010124, 0.013605851770168351, 0.025506523971055305, 0.024869782331910346, 0.08057138987726743, 0.038111453139854055, 0.029028065450068925, 0.13193998305547622, 0.03847197794746007, 0.025060151350654425, 0.007594969347044225, 0.04133058141075796, 0.03467552198637878, 0.022731554326451114, 0.03486013385437189, 0.016815388620260264, 0.06259439745917916, 0.03059235187397609, 0.055759958547329715, 0.058853004067655534, 0.04764370898145342, 0.044794455621271365, 0.04213693491633862, 0.021492619698326436, 0.02619599544202849, 0.013575492663339022, 0.02747103962446413, 0.015221326273956127, 0.10165744671417822, 0.028011384420096878, 0.041486905482147014, 0.08965101799056416, 0.037972396690278284, 0.055505264956023426, 0.029687592459301797, 0.03523947761183785, 0.01715285226612562, 0.06859415676444769, 0.008206531112532943, 0.02188890549023786, 0.07278593707709544, 0.07105988735753684, 0.01467079059371064, 0.033000306031035806, 0.06850584214853664, 0.05173533478932035, 0.02604169767319916, 0.03676640575811748, 0.03991521481845168, 0.018881924202545516, 0.03363163525899572, 0.008656503388568038, 0.02837559602583849, 0.02098715297066637, 0.03284775111223421, 0.0544092497758327, 0.005634312382749012, 0.1438673591661838, 0.16936851094567007, 0.14725464756690687, 0.15208487789477074, 0.24808349358218335, 0.11736556632264007, 0.0717818026521033, 0.2020230240398838, 0.1091058208276668, 0.109550925572553, 0.1569203176205197, 0.1680062840422315, 0.10640082565406639, 0.24686086322030715, 0.1829153509630311, 0.15201565418993274, 0.11172623989442665, 0.12386563083817884, 0.12898164260531628, 0.0735414453271416, 0.18244814458152941, 0.25304431125762006, 0.12334969360381366, 0.1573784381992394, 0.222568015958513, 0.1490270685885222, 0.33924705258780913, 0.251006456092, 0.12683733186173823, 0.082793902876156, 0.11277895961557666, 0.08660404116756494, 0.13541209271117566, 0.17990586648304618, 0.0738090628217305, 0.11527535670827474, 0.09076490983246796, 0.19981056211456177, 0.23795026474662367, 0.2020363080044908, 0.1477499387317127, 0.10187970414277046, 0.09348809193339079, 0.11295004237082698, 0.15152520470080838, 0.16366625805535626, 0.1864037936132762, 0.14536651662520825, 0.13997606152007658, 0.1973393310101763, 0.22904014124745325, 0.0714619992481124, 0.1411476551044372, 0.17074723938299766, 0.07622536542194505, 0.1224818615423095, 0.09753973178204992, 0.25892310144920505, 0.12517649920717364, 0.1729649719932387, 0.244182221471302, 0.15511556768849974, 0.13695130124688148, 0.18411715905512535, 0.09444947099132885, 0.2065405985640903, 0.08870356641108952, 0.14731181304781668, 0.23642562720323765, 0.19658836566152113, 0.2630490365047609, 0.11305689631450562, 0.18599937579804854, 0.29149915181821395, 0.16666034416806313, 0.3554409562099365, 0.2535343930245407, 0.3623116617241214, 0.204901798598228, 0.16511278527398265, 0.309618356968126, 0.13784451380131707, 0.17508182614561052, 0.09221754277185087, 0.3176949461621623, 0.12654677003381715, 0.3207197983659083, 0.2576122637237272, 0.19499458102208955, 0.19359843174536384, 0.19380167487167543, 0.14471687406541842, 0.2650284238399998, 0.11573703193496312, 0.11050845120823193, 0.39209265562315143, 0.24215472381441827, 0.21877580412453224, 0.1377933850932506, 0.1502651126394349, 0.13892210839736846, 0.11231842585989546, 0.18419726120848812, 0.20613933703111065, 0.1752685983815501, 0.16192596676128526, 0.17950216879046735, 0.16102460303133534, 0.19508638899893532, 0.13440401293337345, 0.12608154782003936, 0.12206286507388278, 0.06753186094424418, 0.17123168274279565, 0.1581350419550173, 0.1405858981513208, 0.15425784032671683, 0.07333234162820924, 0.08401257256346364, 0.09045764728779755, 0.21819144757764958, 0.11144663312382276, 0.11468641895560489, 0.09175286448049931, 0.1226058911772505, 0.17172397084293828, 0.22263794446424132, 0.22707029936775086, 0.1550123296798237, 0.10301510773358807, 0.18350186787786024, 0.20092397898195252, 0.07517845264726108, 0.130987306756358, 0.1436093713968031, 0.16787031875743022, 0.1132029356555112, 0.11138678633517797, 0.11605258355097425, 0.11789461132138969, 0.11214453156196302, 0.11900132491944299, 0.09011845419844312, 0.13695934517008646, 0.10619811878930177, 0.117968010205415, 0.09366285191067765, 0.3988834734885924, 0.11435140870631703, 0.14381808439089408, 0.20605839218103117, 0.16447118663739774, 0.17909130051491723, 0.19183702706809969, 0.21167963893423158, 0.10695828485392755, 0.12912968143580422, 0.1345162141707636, 0.12511694353194008, 0.17418047773741907, 0.1358046208418185, 0.1347838699697487, 0.1510049850349465, 0.12470776064982339, 0.1646320957450136, 0.11911754811843557, 0.14201128134323707, 0.086081737742549, 0.10108802122093978, 0.19450433071582549, 0.10640857080298086, 0.18119945190846923, 0.12593826639556116, 0.20621586921474627, 0.12911898684838127, 0.13092879296070145], [0.05476498270347234, 0.03584951342594239, 0.05362557630325037, 0.016072476770909085, 0.040444566252371, 0.029546749109642643, 0.03370320702332162, 0.030067123908309207, 0.08107457940857257, 0.04520266940216384, 0.05652733349932298, 0.09256122513644158, 0.020170918846082304, 0.017636073715684396, 0.027057513023816773, 0.020634470988185178, 0.049438476787819985, 0.01610701776019508, 0.05896229417093339, 0.09392761189730899, 0.00363062713257668, 0.03237630060363201, 0.032852520009562854, 0.024931326005307418, 0.08325356329160352, 0.01257741895143784, 0.05415543718563934, 0.0365082954146689, 0.0296482366074117, 0.037670083073598724, 0.07346124358234868, 0.009419228186860923, 0.02494212401460015, 0.04333067610259018, 0.050125378033807205, 0.056287341135283636, 0.08298253670575158, 0.0262222703426115, 0.02465652260598877, 0.06722082158610707, 0.028948175886105147, 0.02857017852816611, 0.01684343509916817, 0.07079913401074948, 0.04099434925123088, 0.05682526509307566, 0.044400701749949686, 0.045179050911458275, 0.042354480904196544, 0.06721201157497783, 0.024186083333446615, 0.03729733533316082, 0.05359806225544984, 0.014709546024190083, 0.03905423158299058, 0.019198027401862126, 0.05710797451977288, 0.019270462930322658, 0.13424999861707612, 0.03529251004839617, 0.02846000550855552, 0.08777922004341118, 0.02459131894753345, 0.08768741972744466, 0.048365359975686, 0.023852894458198742, 0.03220521784838169, 0.1966872063255118, 0.22628964045115058, 0.0420906670361517, 0.12098368467582811, 1.1079266523161242, 0.5355184417097799, 1.167283634985647, 1.4715939832310525, 8.045397525833499, 12.28893970289538, 13.29701727436435, 10.818262696266176, 10.113619681327574, 7.913801025959754, 7.302389317943204, 12.718684384899756, 16.29567417406267, 30.35466970935945, 29.913224597131055, 26.4514720824457, 24.47588601420003, 22.678732487463183, 6.063264041177689, 4.983752754426772, 1.5644178539514544, 1.9085156220582224, 1.9225163998142367, 1.84655430816835, 0.03181100049386582, 0.2423877524392259, 0.2754972911169452, 0.3080674272871787, 0.31521444539389304, 0.08723748096775624, 0.0550586510179264, 0.06599659010046913, 0.11100444717392807, 0.05953311777463364, 0.046927857272807634, 0.028413994267823237, 0.023687268164189115, 0.09698957340010712, 0.06090518124701996, 0.021425782357372587, 0.09385670279903759, 0.09012191691586087, 0.07327968840517345, 0.026260559417067036, 0.004916720218100255, 0.09911831723706377, 0.0330484661483957, 0.041656448400669524, 0.0168876287963001, 0.009933878393513302, 0.03900601017859675, 0.038889285192013755, 0.06641324233984755, 0.05142014706507326, 0.036807966028009696, 0.0379116191048055, 0.009698745899743611, 0.03783422507225506, 0.01446622309289993, 0.058985636869986216, 0.038993668502136584, 0.030095331265681216, 0.05059778998275438, 0.03633126398668655, 0.044187476497984705, 0.07275586812606744, 0.04997414844711462, 0.054306345015403726, 0.0820347174040733, 0.06471679425768315, 0.025858600744076317, 0.014657893503505378, 0.026141133970550956, 0.06988826312965925, 0.04641436768936054, 0.023019984514722903, 0.02470319651277556, 0.04958445484179163, 0.043874644494104775, 0.02917754069541491, 0.006746169303603952, 0.0041702072767000045, 0.03378825810467524, 0.01940341557436172, 0.05213966833487634, 0.06319026064668452, 0.0836826644597515, 0.04907092695394832, 0.021331467357794606, 0.026303397138572993, 0.02082570568628369, 0.060348959279156504, 0.10053012535096177, 0.04064546131919469, 0.047245366243465294, 0.02603596733552554, 0.038221218217644966, 0.03819186172838654, 0.05250734457325551, 0.050421245020603946, 0.048326913853205984, 0.0833129963927692, 0.0762588051598399, 0.06613359726484745, 0.06668538741406894, 0.03505374342503567, 0.02474441204310185, 0.01915422440957158, 0.07910341985764043, 0.030242506332034548, 0.05142402346997012, 0.04150844404413816, 0.05191058123243913, 0.06337282322948018, 0.04679286108923055, 0.05629982070757016, 0.14800339126058165, 0.05772717657589144, 0.024490587961589618, 0.06638436848598142, 0.014842008371957609, 0.020111905178055167, 0.027448597078722332, 0.07964214820775294, 0.035209171173553315, 0.026482349532025478, 0.0021326954142310687, 0.03356582447586041, 0.02070174882969549, 0.03954651968313321, 0.053815765291332245, 0.052225431877999544, 0.054686424217277, 0.09728541357382652, 0.035641340523838036, 0.02855101100830061, 0.036129591340619716, 0.03712513408954105, 0.05720876870797046, 0.04357321187853814, 0.048091694216934905, 0.0559666337475421, 0.04882711947204606, 0.03286127256409776, 0.05350013323608906, 0.03627414064061257, 0.033661719531782215, 0.025752939982339743, 0.0371099655486403, 0.009969810789991772, 0.06025225217003496, 0.060556438871689384, 0.023924071687243642, 0.0345203738599535, 0.03422002908923934, 0.030648027313873175, 0.031232525587021828, 0.032910014908280105, 0.03281662879031032, 0.035528852003476316, 0.06567131682869888, 0.03194633184090978, 0.02795302958768462, 0.08575477141646609, 0.04654330028701694, 0.03540198401277585, 0.04826604433718228, 0.040735197028205286, 0.20389695171146624, 0.01908274457579659, 0.07510797255822728, 0.10210519446240318, 0.06261032825756459, 0.33183358910103, 0.01614074669628134, 0.14448143992452853, 0.6855124511545705, 0.22264718348460816, 0.7238324755622495, 0.8543420498890262, 6.109151849823614, 10.249563147944789, 10.404593848413038, 9.67396709226793, 8.75656295207239, 6.847396339139631, 6.332671055870672, 12.574309783597148, 17.844015090696274, 31.540064888615763, 31.65883033506332, 28.605023930149695, 27.043338129597327, 22.34333453639861, 6.019963035660406, 3.977598124934781, 1.0836149439696343, 1.2737008472604137, 1.5525230212557701, 1.6488005389128964, 0.14801797757465995, 0.16737560981944685, 0.27924582061748354, 0.1495195865150421, 0.20849459774551854, 0.02465171731948372, 0.04234890378410778, 0.15644059336233526, 0.06609015241866151, 0.05143351529935195, 0.08216724295409457, 0.05091413449976714, 0.027549182507960547, 0.05175811441374883, 0.022349621191801086, 0.027746076680599686, 0.07192143749806189, 0.014136485443750938, 0.029239553597665606, 0.06066548382683147, 0.030138433287521044, 0.06348338886915196, 0.09475395263683412, 0.04545681907104389, 0.020658855566815026, 0.009485693975171496, 0.06452718749642372, 0.01737856666647619, 0.06420524287668448, 0.059869514643064434, 0.04712287644525209, 0.046170652138009194, 0.05128433499785681, 0.02666260810538886, 0.03807212601626112, 0.087275808346608, 0.06813901626775343, 0.0074136449538561855, 0.07250801569992497, 0.019393623055469607, 0.00976470223958454, 0.11062365551028522, 0.05807812911488357, 0.07400460676440308, 0.04949756897985936, 0.04800981473958781, 0.018967605391216856, 0.02864884426667085, 0.10881751895912233, 0.025511267970526413, 0.09657425415371695, 0.011885702842846515, 0.02384644016743668, 0.038644240478113774, 0.032006251407907374, 0.0490272369596266, 0.00816138459354519, 0.0507710024624342, 0.06410341446978912, 0.0035714190697387583, 0.024963821539835587, 0.01807868675959687, 0.008908361496944583, 0.06422221938508653, 0.06647703448130239, 0.060622912320879206, 0.0367770045845499, 0.056117445816315954, 0.06529142148792744, 0.01858412284373997, 0.034615039344756834, 0.05349627215295069, 0.047225727579526366, 0.013603130242817346, 0.04743208485325018, 0.049105423893178665, 0.03251839842226717, 0.05353005663041146, 0.01889146965808205, 0.02858690031233334, 0.06389074846200886, 0.15595637982891453, 0.15347048580165834, 0.22396600384625698, 0.1208287816975386, 0.10853490912385526, 0.16641127366212108, 0.13199886457333643, 0.12893495720721063, 0.1933388811566176, 0.16624330122384334, 0.1553312214391847, 0.2802470056039672, 0.08345496780689686, 0.1854595902466005, 0.13364789947386713, 0.10658550646997268, 0.08158979652028892, 0.14378143474459648, 0.1775580368215038, 0.18386543788496526, 0.07261484666096588, 0.09461226467523845, 0.11818442238314499, 0.11328640859574081, 0.17111251010529457, 0.13108651514255232, 0.22499915002094162, 0.20616049637957928, 0.26397630932830995, 0.12227839625049984, 0.17587563113099144, 0.12981084085279895, 0.16748005824704326, 0.3728469947893774, 0.10275242384523155, 0.1604748583368717, 0.24992869295660528, 0.09463404455492574, 0.12702801114609166, 0.14364064310587224, 0.13992726171929992, 0.11778005053319278, 0.18609225629798828, 0.20548154329580648, 0.09246780071407558, 0.17116731603539762, 0.24217603638047175, 0.1453229109005582, 0.18766201642011443, 0.10942298122831892, 0.16218035391742186, 0.06476984584643956, 0.11234677877397307, 0.14297212413962812, 0.10952816510032262, 0.18539117859496226, 0.16499591090025442, 0.12400356496894553, 0.1117182112929802, 0.15770678348358602, 0.1395840236857053, 0.13066101458764848, 0.09965483925395435, 0.3067390614699933, 0.1537289332237936, 0.1093512447550893, 0.286579059376832, 0.375754022670369, 0.43068663307255317, 0.12935878769043954, 0.20702891832878514, 1.9047773581358696, 1.5041848344187585, 2.3418748907504545, 3.682942568294464, 13.191860491229644, 19.500692852081794, 21.202713212659283, 16.94072461897327, 16.91795918249315, 13.844441886871094, 12.423731953867021, 18.960413817436464, 27.320832090993083, 46.29340133359356, 45.383085896891934, 43.49559037916122, 38.42597007751465, 34.35318093146048, 10.948394190880562, 7.870184759939871, 2.5953690948024875, 3.110629536451832, 2.8652494905456423, 3.017388668752486, 0.2664525812912372, 0.2890365775073728, 0.7321220371992357, 0.5654143794409691, 0.44415357011941176, 0.2200049309120063, 0.21158415373534928, 0.26104305059679095, 0.17422057477937591, 0.1844292632754772, 0.2184895170672286, 0.10760768992646087, 0.07404596019055575, 0.22521547792899996, 0.13521436541791887, 0.10853448011461767, 0.3737201511619553, 0.1490382534722167, 0.1569084739012103, 0.13602562188621492, 0.1017662771647015, 0.16717247394544466, 0.1814075060669453, 0.21478992526329335, 0.1370427721450406, 0.18455317033635033, 0.16219823440957457, 0.15037161418266837, 0.14618445338020403, 0.22742148939399953, 0.11481514470952173, 0.10206538853385758, 0.12811111391431865, 0.1360966688803127, 0.13011206662462604, 0.22215463491457127, 0.15075775314002268, 0.0924547389149666, 0.2342719701869834, 0.08636884451393159, 0.13485546854715194, 0.1965803983471086, 0.13096181135023796, 0.1633591334065122, 0.2875883342517961, 0.1633445624141924, 0.09145366884167157, 0.14047242520797637, 0.15141522511839867, 0.16710475177293824, 0.2121533110978142, 0.13199514138602442, 0.09210277513991441, 0.12013118969456804, 0.19284745107495016, 0.1616552925758785, 0.07916327430716447, 0.1425129310378144, 0.12896193882390378, 0.0913475963076757, 0.12531881536086723, 0.1445941314581902, 0.15787094080400083, 0.16314729477369017, 0.20406723773527533, 0.1772517242258595, 0.1341827054538073, 0.16714742287032067, 0.20014901975950888, 0.2138824021864322, 0.17067657543286202, 0.11749658267945053, 0.10120743900657662, 0.10329131307380815, 0.1643425145096356, 0.22438562084590236, 0.07815798308940665, 0.15969518001281446, 0.10612524850594421, 0.22325440009515132, 0.1386976139920373], [0.025477165566577066, 0.03894331737331325, 0.010074166329427352, 0.10459157112505167, 0.03450795940514054, 0.026829636340299924, 0.01597821827031552, 0.05569971722340392, 0.02260250873082588, 0.023699420233888012, 0.09386585754973274, 0.024351523851134607, 0.05168866471297318, 0.07346855972202555, 0.014642162845590183, 0.04116913604159509, 0.07218042118174416, 0.04889637765084063, 0.07057371263902995, 0.05402290780517844, 0.05061671618492373, 0.04245230650168754, 0.04748502535925758, 0.021686393977893938, 0.04332858085211727, 0.05257543446796556, 0.08756381910174124, 0.048778913389410705, 0.038214285121930223, 0.02373237733639056, 0.02898262302962042, 0.03031024957195886, 0.0904356605643707, 0.06540785919153883, 0.018499968085257758, 0.05376863556223051, 0.0240892919546534, 0.026564202196295225, 0.09610865655685626, 0.05121273642045356, 0.062175619325810866, 0.005634078247127154, 0.10917892859828089, 0.038108844610471884, 0.008482030694252782, 0.05133518025339131, 0.06566886534734119, 0.041900497200267936, 0.07980925496667624, 0.08707171486270043, 0.0327204272992188, 0.037481223248065486, 0.032215854979210326, 0.018012517830356956, 0.012402045146201648, 0.022918351460248235, 0.012002049573516894, 0.014565117383045296, 0.0486019087745057, 0.07805449993259485, 0.01648752405608614, 0.03368502775687845, 0.0318970819634776, 0.17451334294051896, 0.05752734254084288, 0.19067983593671553, 1.069049099760671, 8.930343562556851, 27.26430485325475, 39.386621290637606, 53.58576605396887, 71.23002267652943, 65.98167173324093, 76.6666316986084, 84.94590005566998, 92.4661034922446, 108.7597703933716, 103.6156132913405, 105.82047170208347, 110.12225274116763, 106.64403607768398, 106.21183010839648, 120.56446506131081, 122.1245877973495, 136.83365637256253, 128.66117846581244, 134.5216544981926, 125.65433656015705, 122.84586460359635, 97.42107683612456, 90.8991950558078, 87.74938275737148, 81.71855034366732, 78.03634689700219, 65.61458495355421, 48.53412981956236, 28.071679645969024, 14.688321198186568, 4.979830384254456, 4.322172951313758, 2.3772247616321813, 0.7551600171193, 0.11059086694712601, 0.13659416637834043, 0.09278261688567939, 0.020766778203148036, 0.09903482131419644, 0.04147862790212516, 0.05939093185588718, 0.056106165171630924, 0.005027101517865254, 0.013715395640071123, 0.017166375633208983, 0.06839828340396767, 0.03133666183378908, 0.05666321834489223, 0.0768633404626481, 0.10086488279123461, 0.027927390540078766, 0.11576608964993108, 0.046806922633080714, 0.0042425063457490215, 0.0068377694791002626, 0.007798137300978265, 0.03623856734784861, 0.0487659013860168, 0.052073876703939134, 0.13193760818291095, 0.03841038830878754, 0.0203631168997456, 0.006241730570177278, 0.04813739902249748, 0.017483777351557248, 0.014962350251153113, 0.06563387045096006, 0.03185124500774809, 0.11454443988059798, 0.06120972417955918, 0.03646170960799341, 0.06801698612229479, 0.04199229751623446, 0.12635604478418827, 0.022315673920656406, 0.028973269096064954, 0.012940262132624706, 0.06852236666506337, 0.027211762912150834, 0.04129149560486117, 0.05422919230054944, 0.03631747823448912, 0.04118293711555101, 0.04547269241283498, 0.025096237922327656, 0.046049962646418044, 0.012662413533807043, 0.11193071642229635, 0.02058195949141537, 0.013684892891755989, 0.015615400944596097, 0.030599217936997453, 0.05050731116845723, 0.049203149899239504, 0.030133179839580294, 0.029654210178001277, 0.02989734350253017, 0.04756791607266472, 0.07004524220622356, 0.016549351182015195, 0.09339367159672322, 0.01348894483770334, 0.13663859947794868, 0.03377891183199902, 0.014770043029960607, 0.026151152485380733, 0.052063220420912396, 0.024361998188279332, 0.05076134209370902, 0.056631322274164814, 0.016045266285448546, 0.09606154981039225, 0.011001056109014298, 0.04021368267375135, 0.08883991473985296, 0.0755435241866977, 0.026835504573799913, 0.016229262410272515, 0.032784502893205614, 0.011462783046637573, 0.09368330645825594, 0.05777208465001276, 0.05955522707212837, 0.010195973351778043, 0.05163332252132316, 0.03969410652174585, 0.0324506264540457, 0.058092623498410954, 0.1111015794618476, 0.05632748797295555, 0.03190680936489615, 0.01958382161965053, 0.013508240677296154, 0.060171740159632704, 0.02527362366597499, 0.0540566731304411, 0.03943347957946601, 0.00422352603862002, 0.06610349767030248, 0.021142868002155618, 0.060746413355152455, 0.024612512769958666, 0.10937391329676875, 0.06143317287487369, 0.0059431406196146725, 0.039119908300739144, 0.02704769560706712, 0.047032171635017286, 0.07772249274797018, 0.01661484403866193, 0.08823416135724514, 0.12988764882808732, 0.08396611699173528, 0.09019126319476674, 0.099061373921652, 0.05124632171505401, 0.09124515503044091, 0.0555162315046595, 0.042868836166998076, 0.04037163851241912, 0.04530507620544203, 0.022914745101344683, 0.015006623429907186, 0.07211890432142443, 0.058360099266733856, 0.0075633610380933655, 0.08611605082067751, 0.0637388983440976, 0.04089286558390145, 0.0542437709537485, 0.015473831726628688, 0.20092710462068358, 0.06131966545757267, 0.16934725966665054, 0.36923571760135315, 7.211763445408114, 24.52914591758482, 38.52940297895862, 52.75224670287102, 72.79365985624253, 68.21113124970468, 79.15011175217168, 92.74482711668938, 107.47427632731777, 121.08062544176657, 120.68584672866331, 118.31784125297301, 124.88190420212285, 120.69442102985998, 118.39037372219948, 132.80472324740504, 140.01239222864953, 162.5573758156069, 153.65130486026888, 156.02360140892768, 145.33478183131066, 138.76638074075024, 110.95574855804445, 103.33556390577748, 97.69236364672261, 89.5443299508864, 89.3691647437311, 75.26591408637263, 54.516756303848766, 32.6475166889929, 18.170442581176758, 6.802155721572138, 5.754984867188239, 2.9789224747688543, 1.458128854151695, 0.010555029185789247, 0.23434226641491537, 0.08036441590276458, 0.04329224913230827, 0.03023155510515696, 0.05828053720535771, 0.13325432946364726, 0.027523775201951785, 0.020385913761152376, 0.03374021290050399, 0.037146634347135984, 0.034984347350414724, 0.08970127335839695, 0.01714001071729487, 0.08161336904571903, 0.025754751780280666, 0.01967714262014676, 0.0432698295692042, 0.02432575265336181, 0.0508104138556988, 0.020496946714457967, 0.013572588232496094, 0.05668807406759551, 0.015375771514710881, 0.015796359530800295, 0.02536466555489648, 0.020413029443232283, 0.04203560829703366, 0.018944272268263083, 0.06858754542566116, 0.001839409784635439, 0.05406383605253312, 0.06958598015649665, 0.033659788990213026, 0.051720549292381734, 0.03965273011295546, 0.06499193473568847, 0.04114547924649331, 0.06218738260588819, 0.039129277556053096, 0.01888296416690273, 0.026392230779052745, 0.045813938617826476, 0.036717402944040876, 0.016815112828607523, 0.01854971017418129, 0.04093261405585274, 0.05267689898309689, 0.056549588353523327, 0.009510595663150233, 0.03947817314896853, 0.035332507498922854, 0.04396148822120121, 0.0819242934906675, 0.008617126469260022, 0.04047732417201323, 0.032201299308649, 0.05786724809196688, 0.02098639645884114, 0.038674435833649295, 0.049190528600686984, 0.031068716836612553, 0.0553453479322695, 0.045441508803877144, 0.02659227357306067, 0.01086698976465531, 0.026148863797706944, 0.054660189536310015, 0.04979007667110813, 0.04622709749627017, 0.03202766931105045, 0.09373519359336746, 0.04502946075292365, 0.02997677532895919, 0.10867041475590199, 0.17930710748318704, 0.09080200380976162, 0.27122923142967686, 0.09726377925084484, 0.07200326334925429, 0.0997162871663609, 0.12321706080148298, 0.1269554089935076, 0.13385716405126358, 0.16474449616526404, 0.16477343896704336, 0.1245486748314673, 0.1964964044670905, 0.20252654298899636, 0.08239674757445052, 0.1822597329174319, 0.15278872883608266, 0.25162861141706666, 0.11989722644249279, 0.3130370396519861, 0.12040499717958512, 0.131489860434686, 0.12489516107786088, 0.12214452238573183, 0.13720348206979616, 0.2209169892293792, 0.17759657104409513, 0.2041404144538026, 0.08302693916184288, 0.12018670042556141, 0.11182615308151131, 0.20938065503874134, 0.15470391800326688, 0.18670580079478605, 0.24187885555288485, 0.12888382849914412, 0.11970398842447227, 0.15217500047818308, 0.21340356659023993, 0.13187757753316434, 0.09852580951466676, 0.1359749681526615, 0.29047755824942745, 0.22294077902070938, 0.21568353618344954, 0.26988422618277613, 0.17422713249200777, 0.17604325116882402, 0.15071577152177212, 0.19357635309138607, 0.17877793991036955, 0.0756465936560304, 0.1067856546010702, 0.07327932068296979, 0.15036589916675322, 0.09362263995553217, 0.14287990247530324, 0.11191512653303724, 0.19389932043850425, 0.11478309925164908, 0.11864051282886537, 0.13581997324382106, 0.347652048353226, 0.21347766261427634, 0.42312313892668296, 3.1224324385966025, 16.490609107478974, 42.79040313536122, 59.18030931103615, 78.86650869923254, 99.59834529507546, 92.83509654383506, 104.63104432629001, 119.10480207012547, 134.45670004813903, 151.50879644578504, 145.51147676283315, 145.4454868070541, 152.44509758487825, 149.93923648711174, 148.78660878827498, 162.24896769369803, 164.57590595368418, 185.0913453871204, 175.2738097406203, 180.35108258647304, 169.97837466578332, 165.97429367803758, 135.05202170341246, 128.6725062708701, 121.21635513920938, 113.668318563892, 114.26691147588916, 98.39355007294687, 73.7469134792205, 44.92852241762223, 24.860913715054913, 9.993969740406161, 7.734331998132891, 5.282092642399573, 2.455854064995243, 0.19562013777754, 0.29550971403237314, 0.2575696079481033, 0.1697559369307372, 0.22107871039019478, 0.40750214649784955, 0.1829640128679814, 0.1546612928711599, 0.13218002904567028, 0.09510059210081255, 0.16690756074122845, 0.17870225042345064, 0.16490451661088776, 0.2004389380735736, 0.27086196887877684, 0.15533928068414812, 0.10560268461103402, 0.13977582145842815, 0.07826977830019691, 0.08537747311375796, 0.1142497105343688, 0.1010731514543295, 0.22655375692392551, 0.13228964090587633, 0.12037401658392723, 0.22042280123118432, 0.21318169220560984, 0.17489514584022184, 0.09214137831041891, 0.15136234972986484, 0.11251357909772666, 0.188886362818941, 0.16527833687441965, 0.17662383856311922, 0.12912675497993348, 0.15885623712693492, 0.20118598105205646, 0.15349345311762827, 0.16662588553322902, 0.15518520508081685, 0.13233834877610207, 0.12094850591834515, 0.13426463089642987, 0.2000072781717585, 0.14632412653055885, 0.16169166643052332, 0.1490284475467859, 0.12064968566260031, 0.12498205077023276, 0.13390925803011464, 0.1285999163144058, 0.16099696257902732, 0.10300894838667686, 0.19937350895375977, 0.15933372440838045, 0.08734605860926452, 0.13213286867305157, 0.13860315535097353, 0.24908881544345812, 0.14495115907442185, 0.1139458494200822, 0.10421869314966664, 0.11106173522890576, 0.1863444677644199, 0.15546911726555518, 0.06269403102417147, 0.24332518358865093, 0.09821208118791543, 0.23989839569455196, 0.11890293624732765, 0.07721381802712718, 0.1782635271909737, 0.16396714674849666, 0.15405170138805144], [0.05476869439946548, 0.009874256643196268, 0.03140105343904467, 0.01459182608091543, 0.07192998703929686, 0.016928355945574663, 0.025515996648239034, 0.07136076072891874, 0.04280353483233241, 0.03816140590295677, 0.027132260222588817, 0.04913291112790185, 0.03406765420109995, 0.006494772284396834, 0.03309043244488778, 0.07606293179935987, 0.007482115498503611, 0.026907645158409595, 0.09556670297658253, 0.12537055693927313, 0.028354926973641403, 0.08663976384747414, 0.02913364385735364, 0.04724488743851262, 0.01714215767870267, 0.07352896575485507, 0.01901385411920567, 0.019653815242852417, 0.04167448594084671, 0.0652978030003367, 0.047991126024674986, 0.03189634651907029, 0.05455281082240324, 0.0405656770923205, 0.03165486602923803, 0.03679318819195032, 0.05478685068327093, 0.07638023009583836, 0.05020158079963538, 0.04733177330044489, 0.0035738801271955095, 0.08011303947217042, 0.026212745954492883, 0.05586150350169309, 0.08551504718320024, 0.04587096620290991, 0.07177093952533699, 0.02033148512935206, 0.08098687000212171, 0.06669675615886528, 0.026943542123321566, 0.039172818163229574, 0.05159689504052362, 0.027921401647730704, 0.0349246384575963, 0.036365772417235764, 0.11652432517298769, 0.01704526096281986, 0.020673160343581153, 0.10164587112564234, 0.09533909059339955, 0.6942730036474044, 4.234397171005126, 10.963918932022588, 23.92566377116788, 44.69717318011869, 73.65044670720255, 94.73628505583733, 107.34637568073889, 106.94249706883585, 109.51339106405936, 101.7273921351279, 118.45073899915143, 105.1849457525438, 99.36738829458915, 95.28116503069478, 103.22714959421467, 95.0789668483119, 89.23174842711418, 92.82326667539536, 98.47845369769682, 107.25375283148982, 93.54731267498386, 95.6109186910814, 100.67824440617716, 108.17776910720333, 113.79791367438533, 107.16849619342436, 111.11120777745401, 110.3896564052951, 111.69546834884152, 109.35738271282567, 110.41503414030998, 119.02272255189958, 106.54624354454779, 107.15206146240236, 111.84312205160819, 125.61614051941903, 105.41809143558626, 95.83367793790757, 104.67548478034236, 86.58727861219838, 57.8040280649739, 21.796934643099387, 7.826962692122306, 1.9270739488063322, 0.34519921868078174, 0.0843767018147534, 0.30574743726080467, 0.02514339254928693, 0.07812776858167303, 0.08704169953782713, 0.007718785434976341, 0.018079573506369226, 0.025310784675962022, 0.023582409879553224, 0.029684043556992567, 0.08801422517506347, 0.04091228974322158, 0.07472027844238667, 0.14801410116976307, 0.04008481519356851, 0.03788514693658199, 0.05072533979170746, 0.026101785779540098, 0.053482907749111616, 0.06241211066803625, 0.03440361056897429, 0.03337360535477919, 0.05973248832648801, 0.045095290688257066, 0.060444149534187974, 0.014309515977548736, 0.05760803458190734, 0.04804316637737136, 0.019268003788085717, 0.027692716741453738, 0.043905349298109936, 0.007823079208573027, 0.02854620380657575, 0.03841115439671182, 0.02040837354387247, 0.05774336401373149, 0.0517671657425742, 0.041250318378931096, 0.00991249783715654, 0.10588682662214964, 0.09588186388775226, 0.04340945292384394, 0.07599143281338677, 0.011935370238197428, 0.02709636708811647, 0.015192119171842934, 0.03747573039764839, 0.034893745962049694, 0.046427942767378785, 0.022571855637755607, 0.013233190214621925, 0.023278485563012864, 0.05542377235307809, 0.04586833086045039, 0.058589278299721985, 0.044620657084329475, 0.03023505995741054, 0.07592245425668455, 0.01218805859436191, 0.056120111802292455, 0.06268917785717115, 0.015806636600304517, 0.018411507912641092, 0.037696455650392084, 0.05920648469679779, 0.041705320979798996, 0.015146778258044395, 0.012532927437625345, 0.038145923266007055, 0.054690561092068116, 0.05877468306871672, 0.044761038866014256, 0.08650919182165977, 0.07113964477133367, 0.03681374233095877, 0.0895017993846728, 0.08800638809559808, 0.04543699271556351, 0.01696088020839999, 0.01077999473519383, 0.008373418578787917, 0.03769834405712543, 0.0643513779786806, 0.04222038487393049, 0.041069471833085826, 0.011348019245140737, 0.023357482634544856, 0.10338436211309127, 0.02151584173853119, 0.047162077164337526, 0.042350910934469396, 0.02961169804386314, 0.045486937817786975, 0.09671702996016511, 0.04598667612299324, 0.05623581406149653, 0.03537790586931571, 0.07506511759974303, 0.03618611330767313, 0.040439533054708474, 0.03330700933152149, 0.0701816977872964, 0.014461409187905732, 0.024439966786772977, 0.005108653492624722, 0.04613224431992539, 0.09843655261060885, 0.057304874438071446, 0.038939502255450335, 0.060717049205014785, 0.05817870496802273, 0.005260112905694593, 0.0772582434658562, 0.024867867112099647, 0.01853001596886785, 0.04318873533197949, 0.06980078354958566, 0.1086303100530659, 0.010801626185345794, 0.009770577176353865, 0.09691828125787359, 0.01653601550647328, 0.016243572932698073, 0.015568645640967355, 0.006250141736780924, 0.018782192961342873, 0.040842924312117605, 0.03015611076637382, 0.058762475457643314, 0.09498348790070704, 0.4893564042304793, 4.132812686504857, 10.999536994964847, 26.629071120292913, 49.317878215543686, 81.23048197838568, 106.95332281051144, 118.0261581174789, 124.42916854735344, 126.88814163208009, 118.54458562789426, 134.1321631400816, 130.25906578187022, 114.43443590594877, 112.29705795165032, 124.9768255602929, 108.69159959977674, 110.16117049801736, 111.81018983164142, 117.24696359326764, 127.65604757493543, 118.68621457007625, 116.94542746390067, 118.89804609360235, 124.52588635106241, 132.0632697689918, 122.65303304118495, 125.57046059639224, 130.96784591674805, 127.74061387585057, 131.79052383668963, 135.20697101469963, 138.9270253335276, 124.51235417396792, 127.99452458658527, 132.5722679015129, 149.18763191469256, 131.05947248397337, 113.1149035115396, 125.56443583580756, 100.06188315729942, 65.65211419136294, 27.36769068625666, 9.872575325350608, 2.3195350314340284, 0.5363896368972717, 0.07190571737385566, 0.39883579217618514, 0.028559135370737607, 0.05407126327495902, 0.08288659185411469, 0.056749357271098325, 0.08648917394419832, 0.050367082604357315, 0.05512928049410543, 0.06419212745142079, 0.025057228725223292, 0.027930724937769196, 0.033551556088270686, 0.017882024328554832, 0.10926221767740865, 0.0022542742860218092, 0.1013623190022284, 0.048882024993579236, 0.003495025739539415, 0.016087126287241137, 0.026050802628179232, 0.07035572232017595, 0.04553472638250359, 0.06575679691929011, 0.03651943816352756, 0.06837282630224382, 0.028334730980737556, 0.034272414181501634, 0.01884423267667092, 0.022146044817242413, 0.03546362727760308, 0.0627054035994074, 0.09896159863039371, 0.03307429863320243, 0.018399011103376266, 0.021404285930217277, 0.06836777012194357, 0.055263326728656414, 0.01828315179614771, 0.005547271388012075, 0.04132491236011829, 0.04847932704574159, 0.07971507977814445, 0.04837435001747743, 0.015542821774649766, 0.03758038566898435, 0.02255649174443416, 0.021572863577955195, 0.014027525715890431, 0.0453039079213575, 0.02974780505493043, 0.01516752774947353, 0.0481003203669623, 0.023848887818354755, 0.052207543724967595, 0.05926547346696739, 0.0679932220748836, 0.04172359983767233, 0.055752749659962235, 0.04255791555248922, 0.04724324417991504, 0.013558833123815638, 0.0010863507416234502, 0.03575158440658162, 0.03011377866289789, 0.025917162420228127, 0.05233332387081558, 0.032561215076355204, 0.07054076319740665, 0.12409647611240227, 0.26989721903397196, 0.17985873675394445, 0.17665789883223273, 0.21441048191439724, 0.16048786650982597, 0.12527046755196589, 0.1363675269268213, 0.1499255824713938, 0.11517891389948708, 0.14975848337334974, 0.13537558096070446, 0.17988403297720418, 0.18600193453171562, 0.12001440725139073, 0.21807795931254664, 0.07111472393115682, 0.17763507462316946, 0.317235354694628, 0.3007689382760756, 0.20268659407813705, 0.17774120844419927, 0.13450847668272836, 0.16816273451812808, 0.16605859742529933, 0.19700036774719917, 0.1295453607435188, 0.21762953740694832, 0.17349636122103662, 0.15194027113818354, 0.09748250501410616, 0.12053409065570563, 0.14303682792571284, 0.1870137834621053, 0.13200183699448265, 0.14560541348351588, 0.1286450542149044, 0.21195788206833027, 0.19005587264414758, 0.1996076867104538, 0.34800852438615215, 0.19688370787808973, 0.1612226061162449, 0.17796596331942469, 0.30238501607410373, 0.15598348401967557, 0.25488105302135794, 0.12079842163309937, 0.2724080568840427, 0.18909637816250327, 0.1115535943198108, 0.2891991107213882, 0.18173444174951126, 0.1192209623273342, 0.202808539953924, 0.13826786931003296, 0.24423647581809954, 0.09886638922316414, 0.07145240782730042, 0.18441156664442632, 0.1658979794310947, 1.216373200858793, 7.830221691439229, 21.175556682771255, 42.13013095240439, 68.10956539646273, 107.28681841204244, 128.95377159118652, 138.69359723983274, 140.2924494589529, 142.3189341637396, 131.27691299684588, 148.58247295502696, 136.668728551557, 127.0821342160625, 120.8766386585851, 130.74892274795042, 120.7099614604827, 119.10954029329362, 120.74549813424389, 127.80818062443888, 134.32757562206638, 120.24907512049522, 123.4097445395685, 129.05240351153958, 136.41606515453708, 143.52598867108748, 137.12044439008162, 142.6248319687382, 143.28768114889823, 144.10133761744348, 142.42133940419845, 144.69450981386248, 153.0370460018035, 142.78925772636168, 145.45260983128702, 149.44526887709097, 167.27512421146517, 149.47757351783017, 134.4992812987297, 146.8782658730784, 123.28793925623741, 82.36059527243339, 36.862128934552594, 13.80396204610025, 4.022928466719966, 1.0235800654176743, 0.20087142535034688, 0.6185081949637783, 0.12433869779230126, 0.17326051339266763, 0.22150283198683496, 0.15295498523741, 0.17905702574118493, 0.07348684624077813, 0.1957248007097552, 0.18620102546147763, 0.25194742656763525, 0.15174959185383013, 0.2443529977913826, 0.167596381037466, 0.22612940550090807, 0.1463402603422442, 0.17721302146392484, 0.13955734850418183, 0.1313879554189982, 0.15148041920075495, 0.10499076422063575, 0.12175737219231746, 0.09452984893634435, 0.17248451229064696, 0.12750470169609593, 0.15755128295671555, 0.1838226901787904, 0.16665375581191433, 0.09973186173386152, 0.1567630397696649, 0.21792440464900387, 0.13421773099370543, 0.13661736352068765, 0.09275409543225843, 0.10053939501484556, 0.14391405988604794, 0.234035509488275, 0.09092475407786908, 0.13666282317811443, 0.23582052499536546, 0.1284700720721195, 0.12035160085126279, 0.24174963184181722, 0.07569678773682925, 0.11388472326460386, 0.10905308333495933, 0.10904527689901092, 0.16181675326679984, 0.11180972049553549, 0.1574076261491545, 0.06858774460852146, 0.1024377302476956, 0.14947766618382546, 0.07528547513028307, 0.09414034685300243, 0.1871757191275397, 0.145170888412864, 0.1454887995796819, 0.2588718348453122, 0.17571056982682598, 0.18116277161865466, 0.17074667247793368, 0.14037543847676248, 0.22429108559604616, 0.09341668487796861, 0.12973440059971425, 0.09524401908199634, 0.10634148448345163, 0.14504373313919192], [0.053033172002723145, 0.005999671683962187, 0.026963803233698975, 0.08512428105478326, 0.03106417010478195, 0.027653353228684396, 0.042232251575877594, 0.08070092768438401, 0.029675622335484916, 0.030990821016471715, 0.057752874995311426, 0.020678245252178564, 0.041362561751157045, 0.03401490904751324, 0.021862973414000966, 0.047784546585453135, 0.0977129595834882, 0.011647073157702484, 0.013850860094891922, 0.050003037622739235, 0.07659732409182095, 0.03331198124215007, 0.03555204914582353, 0.061276377659411206, 0.025319372521593206, 0.033830645749525684, 0.05631999946349571, 0.008284812849465637, 0.12982011051668277, 0.03421476223475991, 0.03903479976279121, 0.051773888164109765, 0.025698645415926175, 0.05671540808473384, 0.03609643122481723, 0.016326848605287173, 0.058682660587252154, 0.03825650422743732, 0.03903931968154446, 0.03604980711374552, 0.04818117711693049, 0.02120769053186861, 0.029901424835946773, 0.04331887834855626, 0.0339871421906977, 0.06360043561266315, 0.005630074958917835, 0.05365318994248106, 0.058421865105628974, 0.012834601370888132, 0.023104033936115525, 0.050222671200190826, 0.044141568679122195, 0.07547908087050723, 0.0751523979969563, 0.0710992566159656, 0.05142269813786111, 0.004885647213086486, 0.04610874074240846, 0.2437549589141723, 12.149434724161702, 43.94350936335903, 69.98366602005498, 85.09794681302964, 97.79360786561044, 104.71754827807027, 90.0867231430546, 95.3036480565225, 92.5727213582685, 105.02479537840813, 96.97716651424285, 83.06098153514247, 68.37567467843333, 59.89181157081359, 67.51476149405202, 39.494251128165956, 49.49281200285881, 51.93914328852008, 69.45693092961466, 53.79070205073203, 47.43913742803758, 61.7508424482038, 58.981213723459554, 57.648160919066406, 73.36952655546128, 60.95438165049399, 62.714972803669596, 64.73499736478253, 80.20195807180097, 60.213614586860906, 78.40688536244055, 67.14496827894642, 57.02868138590167, 91.0139322280884, 84.51647896920481, 104.71930549990748, 93.0373888631021, 101.14348457705591, 115.32177802055114, 110.43532848358156, 109.22975663215884, 109.99050032707953, 117.1096492582752, 110.63324343773627, 102.73340948166387, 83.88697778024982, 63.14100888467605, 32.256228885343, 11.354530126817766, 2.1037826086244276, 0.10573615244920216, 0.07507844752962552, 0.015911081197461294, 0.027400551874551083, 0.07703462240075873, 0.03954257049988355, 0.011452576840266345, 0.05398743027340501, 0.10915916352983444, 0.0042804157278770886, 0.07972535301720904, 0.024981985484520276, 0.10010801856556248, 0.010891975722305719, 0.021381044737814416, 0.04934346656345072, 0.03889690393642072, 0.021263433004459067, 0.04282396639727297, 0.0276027224777687, 0.07190993851831845, 0.0355167324925142, 0.04573467533074079, 0.022204916759003556, 0.03167312190447363, 0.04912797752166948, 0.018758591707615603, 0.07849333041738119, 0.004142013804671625, 0.04644969966442836, 0.07049693530725856, 0.06331400682909355, 0.025134777890578396, 0.047569697227088675, 0.06629364835398813, 0.04632219199031111, 0.06845211640240685, 0.03424995248356173, 0.08886367878726414, 0.0483785137053459, 0.00764152642542256, 0.04715862593823864, 0.06019985941689342, 0.07309944323834873, 0.08299303211031422, 0.02955504392664279, 0.048728489482234565, 0.039808885645001166, 0.03233555621737915, 0.021897910853787776, 0.07004563291106494, 0.009095421015855767, 0.05951937415727204, 0.03566685891259582, 0.01395072444387141, 0.07794615211746386, 0.01854004022935706, 0.04587396926757309, 0.01545108466093699, 0.022700882081182736, 0.01716570722149505, 0.018169041084606322, 0.03439868462362117, 0.04570180249790992, 0.039954001850058, 0.04592050527853351, 0.06799513729469431, 0.0663982883035656, 0.04472493314214292, 0.03471341652555331, 0.010223994932828412, 0.04863272849169951, 0.12018959623791518, 0.02596002503959162, 0.08877547142366249, 0.02537827319165151, 0.03852982524662249, 0.05512973248598076, 0.06462204450320813, 0.010111720917085487, 0.05223703427961277, 0.048762193520463286, 0.03645385337632991, 0.033424423797236334, 0.03320678970926712, 0.08220503407139933, 0.015110044342075146, 0.019768720770615245, 0.04550462295751899, 0.051796361353368535, 0.033548422788660374, 0.044115502537498553, 0.027687001725538608, 0.046628420316283746, 0.048519799470781326, 0.0751643872729713, 0.036696086547547774, 0.012331290223125008, 0.044387770185787837, 0.05399376199009919, 0.06398156052455306, 0.035045952310845736, 0.06142156281238122, 0.05569793606897997, 0.02484017877929634, 0.026786727755660975, 0.02104487578054109, 0.02298253047610483, 0.03051122699323441, 0.05629747647852187, 0.041947611607611186, 0.0357032940542746, 0.07819996470765722, 0.09236221847635123, 0.05294435942966131, 0.04281536706032292, 0.018954922805630395, 0.012682471630884515, 0.018507544694828893, 0.06498555322327922, 0.022681546021973895, 0.04580373432667506, 0.033589584692831964, 0.028106488490236864, 0.043316813741600325, 0.14980933628976345, 14.681157969659376, 49.687510613472234, 78.26860612438571, 98.19243446473153, 111.78980919622607, 116.46571374708607, 104.06461484970586, 113.43108577112999, 118.91902292928388, 121.4188906454271, 118.74053939696282, 105.51908462278305, 96.96478751397903, 88.04611006090718, 98.16350306234052, 77.59186390907534, 87.52452896487328, 94.02322169273131, 104.94332774992913, 87.062850306111, 87.8789229546824, 105.23637587024321, 87.97258130965695, 96.12475702839514, 119.89671291843538, 111.19181248449512, 115.92299107582339, 104.76189459523847, 110.76062633145241, 89.44598828592609, 119.20312020086475, 107.75246650941911, 88.15243767153832, 119.53530573075818, 109.45935649256553, 128.43892128236834, 126.7221861500894, 136.76074735579954, 133.1818356052522, 131.83065752829276, 125.47905368189659, 134.98807138012302, 136.93662643432617, 129.57505149226037, 124.60911120137862, 101.91391652630222, 76.4111206608434, 37.82688294687579, 14.067926772179144, 2.9571910731254087, 0.0794308994626326, 0.03281256852431163, 0.03801279633696522, 0.025565162255999543, 0.0355086617562319, 0.05802217788333374, 0.02620371569308543, 0.04614496137946845, 0.05878394507172127, 0.03222697091499164, 0.009475624707016734, 0.032041727024460995, 0.09273071442880938, 0.07766443860506819, 0.013463793213539308, 0.03731912287372736, 0.017581076263600302, 0.01573969392226108, 0.02218441241571019, 0.05487870079495254, 0.08847662052440067, 0.02813559025526047, 0.012739452293082591, 0.022464312214945114, 0.008763967329756388, 0.06344642129636581, 0.037840683193456744, 0.06962083715705142, 0.03523935120733034, 0.020277927922565612, 0.031128511914322456, 0.01714464746445658, 0.01892773626041749, 0.04002098091727784, 0.06710403914292974, 0.04848073281708264, 0.06963621254169172, 0.08185752892806646, 0.031088409126706185, 0.03548582084476948, 0.026529140267220717, 0.06779429968446493, 0.04265366505170542, 0.016283043697776816, 0.0033132352297299454, 0.011271279260155656, 0.070143255495256, 0.007502656709778333, 0.05807844321093252, 0.03751931697010033, 0.05950808202126815, 0.0555265392176807, 0.06733738186378634, 0.06763291560233602, 0.032077828917892716, 0.03681139044103123, 0.0563343865947137, 0.09137446301118021, 0.05023105220208245, 0.006600129004988459, 0.016917021674734932, 0.05779068526481429, 0.012472864229141945, 0.020568116282623623, 0.04259724267608216, 0.09486220086053496, 0.19843282959153577, 0.09506911354800386, 0.14831558741148443, 0.13026162230920407, 0.11214004994760599, 0.10379965837684371, 0.12786800357242747, 0.17893115749522565, 0.16912982859198125, 0.1278395893713159, 0.12988400224956775, 0.16240904648457805, 0.23096872163155388, 0.07804673180104264, 0.22108355206587624, 0.14719314602834566, 0.1306048756645572, 0.11540949870381625, 0.10388710731340033, 0.18141096878436305, 0.11396310172013699, 0.15642134923367731, 0.1748031080369988, 0.18139327215331216, 0.13827215940240892, 0.11025546599299678, 0.11201666382652138, 0.23371721527749495, 0.17071101874593766, 0.09949610583604344, 0.18638502445913133, 0.35766665613459003, 0.2342105452572146, 0.1676330919707975, 0.10297177013971152, 0.08209520004569523, 0.20574785078004484, 0.15493757482017242, 0.12902684179284882, 0.09642774749907757, 0.12232237735823279, 0.07016149604873312, 0.14857596537518888, 0.12148531138776772, 0.17890215340641238, 0.12876877741467568, 0.2172399663756932, 0.20020610863162627, 0.1802983026831381, 0.19385517845230718, 0.1311801310868994, 0.08334462816316275, 0.13580414586730544, 0.17576404276394075, 0.1993275590000614, 0.25175948987805075, 0.1886050859766622, 0.11369065021074588, 0.11822053576789557, 0.35014404044035946, 22.156788572188347, 70.3621276732414, 100.47792896147698, 118.71884868990992, 129.06074247052592, 133.08526685160976, 115.69277148092948, 119.72729006121237, 120.35712857400219, 126.89519405364992, 123.0253444179412, 108.00862866063272, 94.87044580521123, 82.2444538916311, 96.77974577872985, 64.75812758168867, 77.40599847608998, 76.3365093354256, 98.4882753126083, 78.9042732792516, 74.68492477170884, 92.25934751572149, 88.49066365149714, 85.59578188004033, 103.77748950835198, 90.86672567552137, 91.97780762949299, 95.52199855927499, 112.30057239532472, 86.7168031200286, 107.81291807851484, 93.42982199884231, 82.58034213896721, 125.06247443537559, 118.23892316510602, 135.30884281281504, 124.49803752283897, 129.4035105551443, 144.24633979797363, 137.703700834705, 135.61031618425923, 141.05458167291457, 151.10341164373583, 149.19495890217445, 143.29871085382277, 119.0381923798592, 93.27648870406613, 50.948584002833215, 20.415307206492272, 4.3725567767697, 0.22002160098523865, 0.10184412701956688, 0.14618744112310872, 0.11867808944155132, 0.18863356912568693, 0.11505672287556434, 0.09281022669447046, 0.11348235090413403, 0.20477376998432223, 0.22051511482606012, 0.19881325353297497, 0.12040914937613473, 0.1472381153895009, 0.14848518395616164, 0.11748476194277888, 0.0924002240982748, 0.10829612717873628, 0.11876690201461317, 0.13231263886536324, 0.1373080683932189, 0.21067922003567222, 0.11692615361103129, 0.15653057804992124, 0.15551926538107858, 0.10588146400667968, 0.1383427620655106, 0.10301488556809003, 0.2236555237323046, 0.119306618618148, 0.10056696651924042, 0.1037975286524142, 0.22402107024625426, 0.10630632104772715, 0.24560162917740885, 0.17818308795892424, 0.2567099194012342, 0.13974508601090602, 0.21908138127576923, 0.18817721054919306, 0.24034087275785787, 0.11566855133541169, 0.13289019255147827, 0.13452719987159775, 0.17232035497023215, 0.17288883817532372, 0.07714035785606793, 0.14966554158637602, 0.1383600450090824, 0.14680899889959445, 0.1045255879721334, 0.15940509315940643, 0.14312653682164608, 0.1566199651889263, 0.14053853859584178, 0.11092107382512863, 0.13432567278223653, 0.24362627146465166, 0.11220393401961173, 0.20168023033728524, 0.1349535737667353, 0.1128164442977117, 0.17056432823019643, 0.11915730042082649, 0.12661201008144887, 0.13229224560481886, 0.17637507449234688], [0.008826040561431119, 0.03692348825655157, 0.014958854017388678, 0.05671953346820609, 0.035618357886109626, 0.027837739100739844, 0.01661399559628579, 0.07042016563636642, 0.054191347557089986, 0.03342660714782054, 0.02547421995850821, 0.041759966031437924, 0.03472054114324912, 0.014962709354867619, 0.08002051903355507, 0.039436122582804774, 0.03618618608602593, 0.018177755334745013, 0.11395943981985893, 0.072126810348803, 0.03854072284734538, 0.022500659256512602, 0.010206446731312862, 0.06922441729975325, 0.03244174749500329, 0.048317908489656065, 0.0554888476918061, 0.03195244905298516, 0.03394842410700456, 0.050353116821497686, 0.06109514040872455, 0.028504047903322408, 0.08951807109218451, 0.023179667881659927, 0.05600483089144673, 0.04011037188672251, 0.0760043413949109, 0.019501622300595045, 0.012574682102328347, 0.049735121353859865, 0.027429864313753865, 0.03763160630760174, 0.06727871485054493, 0.011351696467177283, 0.08052041438678581, 0.06898032636531899, 0.06010912013270202, 0.012380093854341296, 0.031131871209870425, 0.06614380155599887, 0.05455823472490715, 0.057818973061418345, 0.06953292090686099, 0.04898252040748635, 0.019786480603919878, 0.05947634299856521, 0.031607652030464624, 0.12235762506362893, 4.098040629779139, 41.5109299075219, 84.06714008700463, 90.318660736084, 86.28086305433705, 92.76747488206433, 69.73449353248843, 66.5581738564276, 74.33601425540063, 59.624749152891106, 43.60747991069671, 35.90827518893827, 28.95985330304792, 18.49583064356158, 26.0119410868614, 18.403450981263195, 24.970663593661403, 15.01679910767463, 16.073679789420098, 15.886641567753209, 16.041512431636935, 24.268314184681063, 27.291096602716756, 9.124296922837535, 18.045181689723847, 14.492249758012834, 14.842581152915956, 18.95005483781138, 23.123419438638997, 16.281045694505018, 24.21865305592937, 38.551889927156516, 21.38919249657662, 23.617547865836855, 28.63476137961111, 29.43662524223328, 37.012740104429184, 40.03103533098775, 34.654485640987275, 39.92994408453665, 62.89565286328716, 45.053763697224284, 82.1135957779423, 69.70620539880568, 77.83017927600493, 79.06999341903195, 86.90555541746079, 112.91689442050074, 99.833860089702, 114.96606611436414, 109.01380661995181, 75.98683003456362, 41.727013280314786, 6.737004172417426, 0.10294590701138782, 0.14789181821528943, 0.1258310830340751, 0.0697311538181478, 0.06271335176162182, 0.060035070073941064, 0.03320314696118717, 0.043216521340993144, 0.040226614237913204, 0.04941694588670808, 0.08396048624549182, 0.00823447704240079, 0.04649407913788192, 0.06835305357291814, 0.058734402165658055, 0.029844167424486052, 0.023929790533598394, 0.03385476219738203, 0.03239417343490547, 0.030801256390048132, 0.0477810685462769, 0.04533709485023733, 0.008485491496450719, 0.06946497656885656, 0.08991606909060672, 0.04618176424335088, 0.023306669937747142, 0.028864317986693595, 0.07611416775973574, 0.049799472739499424, 0.014289289341127921, 0.06387857915533167, 0.022086157808981596, 0.04668172088361556, 0.08204037113295448, 0.03391658166243184, 0.06567603593031246, 0.032247471427845384, 0.03611500885698103, 0.028130191250614105, 0.046739725230802456, 0.02332919292272099, 0.04186902247789887, 0.09165821431745445, 0.025254065441268108, 0.06060066895799772, 0.03125064931209049, 0.02997197004245414, 0.01457866277515648, 0.0026768785497669374, 0.01939275737611517, 0.020299167710266287, 0.08369943412441401, 0.029602976132845207, 0.009980818515853777, 0.05459289637304122, 0.02500209529253264, 0.048541414641564896, 0.01754059043202189, 0.07493532698361144, 0.04290255169654566, 0.04223563002362367, 0.042902505731270205, 0.05114723590292758, 0.03094418158364152, 0.036273730783573085, 0.01650277303621894, 0.058941303361808105, 0.045426550937155565, 0.0506684156284938, 0.041143640635475036, 0.06851158780796875, 0.03679898364709751, 0.07492363648188692, 0.04165498517273415, 0.043692116385265704, 0.08486390309107882, 0.04970957232158511, 0.029726239679861936, 0.056295990267948764, 0.024507325067515337, 0.07465523757761525, 0.08074588172378079, 0.036582046699139385, 0.00781170615453213, 0.04199052019225013, 0.053571823744043234, 0.053666447094010736, 0.052106213275223016, 0.016164093225773786, 0.034944415017361605, 0.04476779959194603, 0.032229782457673745, 0.009573402424012462, 0.010166248182706054, 0.02215243016009129, 0.04697863358042894, 0.08830890089513795, 0.05259606521576644, 0.08792888298029862, 0.05116116721183062, 0.00444849637607413, 0.047773717932643435, 0.013267105884639727, 0.04556161223820621, 0.02498690759943378, 0.012650856139859366, 0.05124319607632295, 0.05257286041253998, 0.05114071649469195, 0.09409860272200839, 0.01712203254893182, 0.10098340425400004, 0.08201952588053481, 0.027756026247516278, 0.03358702978960449, 0.05774151774183397, 0.0816236729283006, 0.0950642335679262, 0.025518815851800387, 0.050146169660072175, 0.1327416481029603, 5.188992734878294, 48.194385882346864, 98.05275886289536, 104.76207502426641, 103.19759845733644, 105.0026967448573, 85.52080185182633, 87.49645263917985, 100.21629902624316, 82.34099126631214, 63.98042748051306, 65.99980877291772, 58.78183572523056, 51.75115977564166, 50.294505242378484, 41.29095946588824, 45.2739655586981, 22.21697145892728, 28.944640390334595, 22.85634917597617, 35.40381523870653, 42.195148160380704, 39.57570306716427, 25.052784296774096, 35.742896295362904, 33.73445057099865, 31.63008720644059, 36.93099398766795, 30.520999777701597, 32.62006598134195, 46.81475885452763, 55.18241390105217, 39.36202410728701, 40.44220170667095, 40.78607197730772, 52.94012038938461, 59.85190537668044, 68.48328098174065, 64.65066640607773, 65.96465649143343, 106.98230128134452, 82.86551413997528, 121.22384686623852, 100.40454141555294, 111.03680041528519, 107.3040533065796, 106.22152620746245, 127.76774883270265, 118.74079827339419, 134.05848533876483, 128.09403511785692, 91.51555630468553, 52.56355716336159, 11.641347562113117, 0.07446644286955557, 0.1502150564544624, 0.10595533020433881, 0.058390888340410695, 0.10793646422004509, 0.016839210124265765, 0.09257478489270134, 0.045994271884762475, 0.06843211384670389, 0.03003531210725346, 0.033395105612374125, 0.005907594618733011, 0.07266496413297231, 0.03513895538485339, 0.016903433190178008, 0.05195129497517502, 0.09691082722237034, 0.019899114680987214, 0.007001656753521774, 0.03378599431485899, 0.05860376502237013, 0.018871984211727977, 0.016279759095801462, 0.045551327507822745, 0.014281228180944681, 0.011919472956158703, 0.0321430268306886, 0.01757778974640514, 0.039372617724321546, 0.09019320905809441, 0.03552381114493455, 0.01426915272003821, 0.05542683287433559, 0.05103735591194803, 0.04253483715377027, 0.000492871045172515, 0.07324391975998878, 0.0331834125362577, 0.04393123157863175, 0.04356910564726399, 0.03211955198146884, 0.01890779499174847, 0.12260425174909255, 0.06179110830529563, 0.034708111366677674, 0.06505963392555714, 0.05259156444921129, 0.018679106255031882, 0.009351308746714025, 0.006291439621559074, 0.03533519263709745, 0.034732453810471686, 0.06982780347067503, 0.04672233886536091, 0.0594641890136465, 0.013622258500676724, 0.05271563238854851, 0.09588371015964978, 0.006083530062178691, 0.03695199055777442, 0.040486164826659427, 0.024297133523730502, 0.025774689218510064, 0.01940767885366034, 0.12365928505577388, 0.1626442048338152, 0.10109057229372764, 0.1855600243734737, 0.12377817424074297, 0.1367978691574066, 0.13530638789938343, 0.1906970422714949, 0.14654730326466023, 0.16763324518838238, 0.126233646916526, 0.18936757328769854, 0.20245138976362445, 0.08977611248771991, 0.20197725794728727, 0.18078377260075462, 0.12180282418886501, 0.08783680687267935, 0.18706000920745636, 0.13609646969745237, 0.06854733347051567, 0.10060014578724101, 0.13447067790454434, 0.13088803708312974, 0.11054528471563133, 0.10944521309988153, 0.12967292970466998, 0.14522137360707407, 0.12535074590555123, 0.13002686232568758, 0.15054994412968237, 0.16769820944436137, 0.192426547047592, 0.18145664294640865, 0.10302521243330934, 0.12572878731354592, 0.18013523320757574, 0.12894128509346517, 0.16484840833131345, 0.15989453141247073, 0.151286032050848, 0.10941147458769622, 0.16902795421981043, 0.1583139847723707, 0.23192584124063295, 0.1249308531142531, 0.23258982496636532, 0.07350411386259141, 0.1893831708378369, 0.1776180981147674, 0.12360331467202595, 0.1714351863390015, 0.16434363299800506, 0.21303944499982944, 0.2041230549014384, 0.20898867849140398, 0.18134323129009816, 0.28395962090261523, 7.325161618571128, 66.86093376528832, 116.2921331774804, 119.01336377666844, 112.42095778065344, 115.38099796541276, 94.87563902331938, 90.15371722559776, 98.88257549655054, 81.19994240422403, 61.32015051380281, 55.98972789702877, 44.17770624160767, 34.78893664575393, 42.19025696477583, 31.155070527907345, 39.58218674505911, 26.37944167660129, 30.052013743308287, 25.06321584024737, 30.75984662578952, 39.62485428779356, 39.16224994967061, 19.569593206528697, 37.19766024620303, 24.839636818055187, 23.296352817166238, 27.951098142131684, 32.18186466924606, 28.825412104206702, 41.22262785511632, 57.10630901398198, 31.420599299092448, 32.79814943190544, 43.737349587102095, 47.80854625086631, 55.4314765622539, 56.95706675129553, 51.066835618788204, 58.956181157019834, 88.21615265261742, 65.66089245580858, 107.88608597170924, 95.18650254895611, 105.10909495815154, 106.00115960644138, 109.46293369416269, 144.11448540226107, 131.22198412495277, 148.27706152392975, 145.6073865582866, 109.43911706247638, 66.79631663906959, 15.81042108997222, 0.3780430627446021, 0.2128150425250492, 0.16038470510994235, 0.22845999818415413, 0.3323360508488071, 0.14925919322957917, 0.16335518039282293, 0.26433719802768, 0.16382370444555439, 0.14785260983532475, 0.11662529556140785, 0.09216343398175894, 0.14704815622779632, 0.14132267555161832, 0.12000106966062901, 0.13277976863807248, 0.14365872278088523, 0.17366612630505718, 0.12243972670647407, 0.140284365944324, 0.10618979141356484, 0.16269300463459185, 0.11524813760432506, 0.08979548685132496, 0.13609671484558813, 0.14550292624100564, 0.13175734769432776, 0.10041877447116761, 0.14149778792935033, 0.14023643948378103, 0.07178619233590942, 0.2230098801514795, 0.13238583090564898, 0.11982960386141656, 0.13442394654116324, 0.09000671261380758, 0.17862294500152912, 0.18643892640548368, 0.1148528668789133, 0.18368793531290947, 0.1415399993739782, 0.08108278421024162, 0.22622269968832695, 0.19701342188542892, 0.096069808238216, 0.18063813928634892, 0.2089222586683689, 0.1831546002217839, 0.04680138764782779, 0.09141325004278653, 0.163605323421859, 0.11389434532893282, 0.2245195330150666, 0.13188759796321392, 0.10255460462142384, 0.1548342142374285, 0.0885599019426492, 0.2325247841015939, 0.0812293598127942, 0.2073867120329411, 0.16166267766346856, 0.17128385333043916, 0.10868123191739283, 0.14138526493503203], [0.06526616356906391, 0.053537353617890235, 0.01269881803196885, 0.034750219389435746, 0.044674229612874414, 0.041516468815144994, 0.04177847088524892, 0.0187069037553644, 0.04677646680765095, 0.03936511772354284, 0.03682544432400215, 0.07299336304347362, 0.03478380851447582, 0.049193416752161524, 0.010393318558682599, 0.02775283740653146, 0.009321017630187976, 0.07913675234322587, 0.1056000492685745, 0.015914339943969204, 0.0934038682269954, 0.0012356818666786798, 0.06613555844993362, 0.025986591053585854, 0.02810833284691457, 0.06593927906285371, 0.05470596712022539, 0.03154538440397911, 0.030515496018192464, 0.08775011636316778, 0.054859069791892846, 0.01589981204409513, 0.02045171688340845, 0.021547959974756645, 0.05701707052667776, 0.0426582615792511, 0.02126683060440325, 0.06872380182387368, 0.01846956971642231, 0.0329954911684317, 0.020790595876713915, 0.03995425082863339, 0.024546826476111047, 0.03059738124119899, 0.02492490235806233, 0.07376364912957915, 0.07272698661132206, 0.023838210467910095, 0.05440184936648416, 0.033269949828184424, 0.0880202619479068, 0.026714372666432496, 0.008759239609653672, 0.0740310980848247, 0.04837893888414387, 0.10439310838738758, 0.506304843170989, 12.067273816754742, 47.35154697971959, 52.30535145728819, 71.09286523634388, 84.22536065501552, 70.50875371502292, 48.04811285388086, 54.04371453869728, 32.894178859649166, 24.511356007668283, 28.178483824576105, 59.561551924674745, 40.7908494241776, 50.6357200684086, 37.62129583666402, 64.37988950360206, 83.88975481833182, 92.2990732808267, 120.90072201144312, 118.79247157804429, 128.00991596714144, 114.11397826287055, 122.48100573016752, 144.4641568583827, 122.71156264889626, 84.766553601911, 121.90825339286559, 116.71540398751537, 130.61812739218436, 146.11467453741258, 105.96881574200046, 80.66157356385263, 85.64564304967081, 101.6351850571171, 111.64836068307201, 89.8443598901072, 76.38673920785227, 87.8914745392338, 81.82578794417843, 90.46399239570864, 79.81329825616653, 45.40279188463765, 45.49465771644346, 28.061412842042987, 40.13460159301758, 31.97260818173809, 31.725708707686398, 50.984363863545084, 55.47787820139239, 69.4456188140377, 84.97211717790174, 90.00382777183287, 107.51719490174325, 108.19276825074228, 90.41376252328196, 42.439731474845644, 2.720251722681907, 0.08860906180475028, 0.04208974006976332, 0.04044883719254886, 0.03553684230052656, 0.016960545044933117, 0.024069341109885324, 0.035158992414512945, 0.08441767219694392, 0.01790157872282209, 0.05243771101137804, 0.061567376157449144, 0.01711454595469179, 0.0482907276901026, 0.027470388449728492, 0.029208460004038872, 0.04326564289869801, 0.046289671557925405, 0.03349712937169018, 0.030822538312584646, 0.0461159955950514, 0.02824801174292882, 0.016732940322629387, 0.042046027092803875, 0.027127169568331975, 0.035559633416273904, 0.09931368497951377, 0.006037445085483694, 0.04413356306031347, 0.04771680526074864, 0.017065836169246226, 0.011501052968895004, 0.022691078070971756, 0.04101834312501935, 0.030060208049572767, 0.03528540841333809, 0.055832970556953264, 0.0465973784335919, 0.019310644241951166, 0.05166267518014197, 0.0737195760912953, 0.0619934129739, 0.006800451899893703, 0.025444028433412317, 0.07405118491019934, 0.02316807314092594, 0.03599855966205078, 0.06690602073626173, 0.027010653340708346, 0.021346383089680347, 0.05749859126104463, 0.07334573284512566, 0.07121363354306068, 0.02998386930313803, 0.06067664189744861, 0.08720887524466361, 0.04131687609779258, 0.03778610325929138, 0.011435991036705674, 0.06295551215448687, 0.026462511685226234, 0.05347271494927907, 0.02226610611673565, 0.06275333772082964, 0.03478164048565011, 0.016549079220802072, 0.01909550568539529, 0.03553823275010913, 0.08012967124100655, 0.008865255644665131, 0.05020411655066475, 0.033519598730509324, 0.07480398886987279, 0.040175585121276884, 0.05024110327564901, 0.025121595432621338, 0.05105138298184161, 0.06398965807391271, 0.016925385439648263, 0.04654153062391185, 0.03588287655504481, 0.061698928775806586, 0.05667687386214253, 0.03750093469035722, 0.015186420435296192, 0.06593744811271468, 0.10734600195240591, 0.051592880739800395, 0.0820367245544349, 0.025175932133870742, 0.050877109470386664, 0.052449382360904455, 0.03801528612271913, 0.03590405122527192, 0.08690004221974842, 0.04077164749164255, 0.022366264451956077, 0.0821166888119713, 0.02847987974453117, 0.05908491803453334, 0.07915410423471082, 0.04190939148106883, 0.04682443923346939, 0.06123724588823896, 0.04133184545583302, 0.04214788231277659, 0.08571512636638458, 0.04241118290191216, 0.06904372780193245, 0.07168379702395009, 0.07055652928688834, 0.045922788220547864, 0.05828028822678232, 0.07645720661047005, 0.061598165231125976, 0.02660889576579775, 0.031899679001540907, 0.010960516651281187, 0.17436787816545657, 0.6371825993541749, 15.162009173823943, 62.071025525369954, 63.67585151426254, 81.01657159866826, 93.13653069157755, 84.10794058153706, 74.94748038630333, 79.03903807363203, 50.09496250460225, 50.965877732922955, 53.76203344714258, 72.52125909251552, 41.31675689451156, 36.875284564110544, 21.28547130092498, 44.47881483262585, 36.44775406006844, 58.12783933454945, 60.25636057699881, 61.67319128590246, 55.450653030026345, 57.30498490795013, 63.81573892408802, 86.55382079462852, 58.447081042874245, 42.15349258915071, 60.34892066832512, 48.228490890995154, 64.56645311847811, 75.084025936742, 57.96306840835079, 58.660481514469275, 63.9348691509616, 61.410455242280044, 57.64050053011987, 57.69465277271887, 52.61851741421608, 67.74997034380513, 60.58154859850484, 57.5870817707431, 53.66431151666949, 46.06380931792721, 38.79427671432495, 40.30107482787102, 58.52907426895634, 50.54311290864022, 51.559320572883856, 75.08500652928507, 95.50943912998324, 88.44496019424932, 104.49093726373489, 102.3110721957299, 121.96181727993874, 123.20387501870434, 110.26051628974177, 56.248549415219216, 5.886586760320972, 0.02855919474255174, 0.037113271218033574, 0.13184106578269314, 0.04991971790009449, 0.03624629334456498, 0.10980156655873984, 0.027585064151114034, 0.09831967823688062, 0.016720759524633328, 0.013447653656194528, 0.018600143657456485, 0.03347007880708383, 0.014615010774333873, 0.042449314928343224, 0.027477909517925114, 0.024998272513790477, 0.043201636252624374, 0.06337160131924095, 0.05176695506839503, 0.02906123322675065, 0.012984294951292536, 0.05600102343446305, 0.03784676593157553, 0.05472824878750309, 0.033351706731463635, 0.04738116298892325, 0.036801596006919304, 0.06709752739557336, 0.034008738209283164, 0.03796408080586022, 0.03290583589865315, 0.038544641387078075, 0.012969942294031143, 0.05437829216281253, 0.0448732630860421, 0.06497324985121528, 0.06844670016078219, 0.04369924483340114, 0.03775200468578166, 0.06860072213795877, 0.06350432988256216, 0.016250101917032755, 0.08502918656074232, 0.04818436787313512, 0.00875494760205789, 0.017042895666353645, 0.06074239905442923, 0.03663617847186904, 0.017025114765631098, 0.08401562159340228, 0.06546700884017252, 0.005067801854062465, 0.021903970609268835, 0.0753074771754684, 0.034951980135613875, 0.04605419911263932, 0.017370936430750356, 0.003882648513442086, 0.06355330971400104, 0.04514112189832715, 0.02833795621089878, 0.045420544807829207, 0.11734377112119429, 0.1185747824849621, 0.07131388380883202, 0.09554845476222616, 0.12712163475131796, 0.14440061764851694, 0.16200795349094177, 0.1081398529030623, 0.16617453717175992, 0.15868219727229688, 0.22173313333863215, 0.20183830491958127, 0.14992391239971886, 0.13594156671916285, 0.15749825435059686, 0.1641141283776491, 0.181213517282759, 0.16112364287818634, 0.193371991476705, 0.15473535825167933, 0.2599847767381899, 0.1476124719145798, 0.2084313954917654, 0.17326645823496004, 0.10253104741775221, 0.26225800475766586, 0.13505443690284608, 0.2028190660020036, 0.15761465374981204, 0.21005695745829614, 0.12563028372824192, 0.1297417090785119, 0.06122743996280817, 0.07701861116314128, 0.22502466074882016, 0.1378534157429972, 0.10142844005097305, 0.1752929752993007, 0.11290562459297719, 0.15031751305345567, 0.19977881543097958, 0.12514786284056403, 0.11033864015893591, 0.16755367929656662, 0.16102253459393978, 0.22746397663028012, 0.21018970517381547, 0.16652735130440804, 0.20049895340156174, 0.11006188323541034, 0.17874973255299753, 0.10894498832884336, 0.2098963394640915, 0.11856817880705481, 0.1592242351222423, 0.28041582073896165, 1.1586854318457267, 20.743384053630216, 77.4368675293461, 78.04247363921135, 90.45849323272706, 106.54805567956741, 98.60787622390255, 75.02038940306633, 78.7695320190922, 51.95648800942206, 37.42908793111002, 44.73654985427857, 86.7158539064469, 62.42785530705606, 68.82319358087355, 57.51029745224984, 96.6783917334772, 117.03475552220499, 130.53822086703394, 165.13608317221366, 168.87295661434052, 186.98879980271863, 151.7974672009868, 163.68405311338364, 190.08828809184413, 172.53798792439125, 116.91833173075031, 162.975186686362, 162.31487920207363, 176.18081861926666, 199.9348806565808, 143.7914860633112, 116.4651724600023, 118.82520767950244, 141.5766020744078, 152.85167478745984, 124.52926743415095, 107.8250382023473, 122.20446294353856, 111.11794640941005, 120.73943414995749, 109.92473786877049, 59.608898855024776, 61.65399128390897, 42.630362587590376, 56.23422099697975, 50.834195921497965, 49.221713466029016, 71.81006277761152, 79.64902154860958, 94.37494847082323, 111.67888456775297, 111.56498678268926, 135.13829815772274, 139.05895817664364, 128.08844966273156, 68.9266029480965, 7.0933500316835225, 0.1724499770470204, 0.10930210787562594, 0.1675770143347402, 0.17481643796688126, 0.13415678103844966, 0.21038197792105137, 0.24705272228006395, 0.2331045287991724, 0.08111541955581597, 0.2019993825665405, 0.20022958156562623, 0.11885288772323441, 0.17886645370914092, 0.15434074636188247, 0.08312217921258942, 0.12952187248776037, 0.1379254126861211, 0.13277701072154507, 0.11035385466511212, 0.12872976821757134, 0.23197382898820987, 0.1628565031193918, 0.12904734230570256, 0.13509461055359534, 0.11162743753483219, 0.21703926666129023, 0.15355205884383571, 0.11980225452251973, 0.17885159160340988, 0.2145139037841751, 0.1920524050271319, 0.138695836668053, 0.12757550354205793, 0.16291256543369065, 0.10331214300446934, 0.12371503327402378, 0.16978610547319536, 0.12563603704855328, 0.17531445640469753, 0.21816468046557522, 0.11104503451215644, 0.1055977586656809, 0.19747934123921781, 0.14746763533161533, 0.0914223894717232, 0.1256969103950166, 0.17889570294608995, 0.09289939932885671, 0.1664783369990126, 0.11527021625830282, 0.10073909115406776, 0.15333841224351238, 0.15147927006886852, 0.13785574465028702, 0.18902704720535587, 0.11640064793849185, 0.07520977798248492, 0.1473288355214942, 0.1885327979201271, 0.14622166993156557, 0.10203273786652474, 0.1271987031965006], [0.09169762954115869, 0.018107020521476384, 0.032699719942625494, 0.06972955269438606, 0.08206560606918029, 0.0421043953317548, 0.06867200661931308, 0.03823401188598045, 0.07123779595619248, 0.015452517245355395, 0.11616196558480302, 0.0651580609020687, 0.052611915574919794, 0.04137743917864658, 0.01532044560242925, 0.06330667153721856, 0.05923617060386366, 0.07306313067073784, 0.015877092749090688, 0.039039020907253995, 0.04656249845039941, 0.0337541020745712, 0.033844668988979636, 0.05291114951814375, 0.006696172490445597, 0.07941991376179842, 0.007539049716621278, 0.0699884444475174, 0.03124531542491769, 0.03255500210328929, 0.0385638510417794, 0.0587566570198584, 0.02692200739177004, 0.04463561878149067, 0.07334338095519813, 0.04533810608629738, 0.08998614315304065, 0.026230938627474734, 0.04991619772608242, 0.04666515040181337, 0.04000057999585425, 0.052062707142003124, 0.10336124157953648, 0.015116550343772097, 0.0043332236049126, 0.023248943297432798, 0.06788549479097128, 0.04285753637011494, 0.05879269762625618, 0.0015435083238821057, 0.048477764226376056, 0.10394155318217893, 0.10699166330478846, 0.2776665456833378, 0.3834275576856829, 10.091614204068339, 46.19777002642232, 81.09461892035701, 71.13506209465766, 40.71916026453818, 52.091166511658706, 32.52821583901682, 31.701386090247865, 22.143068121325587, 11.370647145855813, 27.35620990876229, 50.32482124144032, 46.08148744029384, 47.33279412792575, 90.16375064849855, 109.54142032131072, 131.64737301488077, 87.67546961384436, 82.55673731527021, 53.342759532313195, 36.84406641990908, 40.79993755586686, 31.92720674699353, 56.80819711377544, 47.250134098914366, 32.624457074749856, 53.0542339048078, 60.148487552519775, 76.03101945692494, 69.34344891578921, 80.14153003692627, 47.39739948703397, 63.07948650852327, 72.76956081390381, 68.23464193651753, 74.81830104704827, 76.73065262456095, 47.790166024238836, 43.41798628530195, 38.65760564804077, 45.37897133058118, 51.58676931934973, 54.29162402306834, 109.7840738296509, 111.24999692363124, 125.70840251061225, 96.7725129281321, 84.88870405381726, 66.06864636944186, 34.296902764228086, 25.407472464346117, 37.272989365362356, 48.387354727714296, 63.7080345615264, 82.80987924145114, 70.14821729352398, 93.71661001636137, 101.96585655212404, 74.35659885406494, 17.176004071389478, 1.0199609434893055, 0.16267664099652923, 0.021674234247315797, 0.018465021069371895, 0.05795027287076077, 0.03024701858990856, 0.02681990319322194, 0.024413751258004098, 0.03437700816580365, 0.050600961586760904, 0.06853689169210773, 0.030632291867908452, 0.03743839510265858, 0.03882020321344176, 0.0867835432291031, 0.007009984608063655, 0.06197724085781844, 0.05700656363079625, 0.08524044296674191, 0.026473916819198962, 0.023463018906993732, 0.011538180462535352, 0.06317589266766464, 0.07641323316361635, 0.029022718156357447, 0.018392168022992633, 0.02184979095604391, 0.02907363235980513, 0.03698240041792874, 0.008379424708114277, 0.049481312594106125, 0.06764315819788365, 0.0735525229585267, 0.027935850065982634, 0.04142545373930086, 0.014416377582106621, 0.03748610705858277, 0.009262142815597115, 0.07497028357559636, 0.0320760017981933, 0.024422951973974708, 0.0372502439084553, 0.018463689991603457, 0.02930389157676649, 0.005558098604406921, 0.030506325945738825, 0.02490917840341647, 0.07111402679114573, 0.03805850880340703, 0.006361469633937363, 0.04426851710905472, 0.08694998349153227, 0.10417370080587365, 0.04041110736227805, 0.06291171490785576, 0.10908897455421188, 0.049035748196465355, 0.05285021105420686, 0.02190390166135565, 0.02087653945049932, 0.08294965621204146, 0.037777745240037484, 0.01513731707217953, 0.02854489762666485, 0.028178110050277847, 0.05722782131464732, 0.02474586952537779, 0.039410925950975194, 0.07887378500233735, 0.02128043441071866, 0.03255731568882062, 0.029243297852395527, 0.027560750435617183, 0.028178920188257774, 0.04051915257267895, 0.023927011549653068, 0.03407298234261332, 0.0678754743609217, 0.02337093513849522, 0.09005597972821805, 0.06622109982755876, 0.03010279870772314, 0.044217530127254226, 0.07622604724019766, 0.007392988350587867, 0.0687138886461335, 0.12330889942184572, 0.030485513252055937, 0.030585047225618077, 0.03994713770225644, 0.04270132338147491, 0.07633578933535085, 0.048410612789373246, 0.01160436088309413, 0.06554742508958425, 0.01815758998535814, 0.06859975686717419, 0.021558882473337076, 0.0451785912587037, 0.017920686870873455, 0.059641588163832505, 0.057491428338952606, 0.03935824208442242, 0.0752983683900487, 0.02062478572160246, 0.09535733114687667, 0.04864081071930067, 0.07905278144584549, 0.03236496250235266, 0.03856465926453952, 0.0569987686861667, 0.05789258261962284, 0.0817037980643011, 0.0838022354629732, 0.1700790728171987, 0.417103220017687, 14.273909061185776, 60.396208763122566, 98.70366050351052, 82.26449720321163, 54.598200398106734, 73.14919917814194, 65.48753546130273, 61.519155886865434, 39.21779855605095, 34.17349323149651, 48.295900744776574, 32.37759682439989, 31.67075041801699, 45.27864886868385, 71.27811093484202, 81.91347645175073, 84.39971785391532, 74.20699965569281, 67.65912040587395, 53.10886467656782, 37.52627249686949, 37.308828061626805, 33.92145349133399, 49.1737703354128, 42.17246117130403, 36.06430315202282, 47.5329722896699, 48.46814770852366, 54.64277421274493, 58.410191151403616, 55.24939229411464, 45.518878352257516, 51.795043253129535, 52.58022331422376, 47.67313034303727, 56.59371406801286, 56.037749475048436, 35.092877188036525, 34.233277997662945, 33.17062554820892, 32.554327057253936, 36.91678324053365, 42.540512854053134, 63.27436162579445, 76.50935249943888, 78.85397280416181, 63.37521360766504, 48.01784392326109, 42.1966504281567, 40.38700219123594, 30.28135668846869, 65.41332029527234, 80.07765031629994, 83.9262407056747, 103.30087446397351, 81.96318857131466, 106.60318066996913, 116.65880418592884, 96.88901516699023, 26.751147047165905, 2.1004449167559227, 0.12583991602784203, 0.0661922719389681, 0.0561460898438048, 0.04585691615037861, 0.04932878065794226, 0.008615245723405914, 0.09098224897658633, 0.06750349270840807, 0.023812891262012626, 0.044870440052041126, 0.008941473732251794, 0.026440842888287963, 0.03301624449030046, 0.05854941491458205, 0.025358969691179456, 0.01260683672773021, 0.014793989023253804, 0.0812946305039429, 0.03569608516690712, 0.026317636797865553, 0.014523395277079076, 0.07137694050587955, 0.014509209243941211, 0.025610918772497007, 0.02066947163022574, 0.032658125198776686, 0.013408964300798553, 0.019707328399583217, 0.03640666619063385, 0.093131723152774, 0.020301854763660702, 0.006989614330157037, 0.03226365886568543, 0.021525749170611945, 0.04117994554220669, 0.024073929976551764, 0.025869800949529297, 0.0792246685934163, 0.04710730187775147, 0.02518622069469383, 0.03284808053004165, 0.03437930642957649, 0.03156927677111761, 0.019961665760004715, 0.036441377634483005, 0.05530144726376861, 0.053226222329202204, 0.05500712777457892, 0.02960431295627308, 0.03410498183521052, 0.06308770445626109, 0.04743350977678934, 0.06196424800662264, 0.04253316708209534, 0.026172279275112578, 0.013612327128348332, 0.025138326792887626, 0.06108623080616517, 0.03694728294747972, 0.03074028919781408, 0.16992280620240396, 0.11246330840813537, 0.1213576811395826, 0.14461233370727108, 0.25114464303178174, 0.2789636551132125, 0.12892916558250306, 0.20550660969268894, 0.1959257302505355, 0.10680052436768048, 0.15086376438698462, 0.14828092959378997, 0.12689926240953708, 0.21677318900342912, 0.11568177401298478, 0.09618190988417595, 0.19700154752260257, 0.14659507650761835, 0.24566432581313197, 0.12843033509148707, 0.20158070019416272, 0.19156025482281563, 0.18107853259050077, 0.13411198021663776, 0.15016823316053038, 0.2397038246835432, 0.09759252290091208, 0.10061791136620507, 0.18318838469924467, 0.15129041407377491, 0.14695291617704978, 0.13739285900467826, 0.15682673231968958, 0.10374660678808728, 0.16148923535741147, 0.1243204495779449, 0.14121830373281433, 0.14987794712426203, 0.21376523669929276, 0.11535718255946714, 0.2269298141641963, 0.09036082143504774, 0.21058004229299485, 0.13921409514882874, 0.19791507672879005, 0.19176450918518728, 0.23574633704077816, 0.14537909578892494, 0.21046964902310603, 0.11877565073870844, 0.2574447049729286, 0.1762870969551225, 0.33593243528758326, 0.3148190827379304, 0.7790458418669239, 19.198211431503296, 73.86971504457536, 112.93613756856611, 96.39047407334851, 64.01110826000091, 80.21139529443558, 57.43214422656644, 52.70484485933858, 37.59280766210249, 19.195675619186897, 44.078525189430486, 73.39746952056885, 67.00064074608588, 68.6826236786381, 121.66843968053018, 155.81413115224532, 186.49026655381726, 133.01910431154315, 124.07860279083253, 82.5865630180605, 55.4144456309657, 60.299063421064815, 48.043272649088216, 80.42459964752197, 68.4375539902718, 53.95815980049872, 81.37692759113928, 86.92086050587316, 116.47523726186445, 105.74515435003467, 122.295273657768, 71.7461673675045, 93.53613391999276, 106.54735749767673, 97.36970163160755, 109.79606059289749, 105.4193465940414, 68.83632567621046, 62.282037273530044, 55.34347034269764, 67.44345280431932, 72.0026433083319, 79.03194642836048, 151.22877059444306, 162.186209770941, 173.8711701670001, 132.07528791119975, 116.38106115402715, 92.64240618674987, 49.67291155169087, 38.072513534176736, 52.71308183670045, 69.69537181238975, 86.10697653985794, 106.83716574022847, 93.9318932256391, 114.58774566650392, 132.11200129601264, 110.88169420919111, 34.50715749494491, 2.1079444885253906, 0.20284734996816806, 0.17720963535529954, 0.09903881263228194, 0.1597555170977308, 0.1112664875484282, 0.11145768777257013, 0.12155725470473691, 0.10551662995449959, 0.22206829680550486, 0.26598024212064286, 0.11351301740374296, 0.1413684569659733, 0.1724438943089016, 0.14574740021940202, 0.16049310655122803, 0.16224988405742954, 0.09028345421557465, 0.1784318520296966, 0.12055629188375128, 0.17006837822977575, 0.06174395942399579, 0.14776113893716566, 0.17868423203547157, 0.153127983212471, 0.16370195775262772, 0.12499754872894096, 0.0764113792308396, 0.13501230206701065, 0.13470243482339767, 0.19884061819363028, 0.21287148788331017, 0.05705465480024296, 0.13915086225155862, 0.16603336248907352, 0.14076416681130088, 0.11102815759518456, 0.13653333899715256, 0.2109497716470111, 0.18312875241521867, 0.17676944123400798, 0.11699493298487318, 0.17439133577769803, 0.11502251704974521, 0.08229312652181234, 0.1469012512074363, 0.1553901029570449, 0.1784666630649759, 0.18736855877983957, 0.07960094799918514, 0.15045599110664862, 0.16270938359441298, 0.18072299118484222, 0.2005376255199794, 0.25293466875389703, 0.23113508528519064, 0.17094164185466307, 0.12155838851486483, 0.13203410461785334, 0.17334602412677583, 0.18476192929571678], [0.024716463240404284, 0.04119316821977977, 0.07022161096815141, 0.012517585569331724, 0.030462584240482222, 0.03524929119814788, 0.05270058259127602, 0.030886123610299923, 0.02052486870407818, 0.08634861979273059, 0.01469999003494459, 0.07884606028035765, 0.02477610510052933, 0.1118388778019336, 0.019553737346864036, 0.040411689589100505, 0.018154125352720582, 0.033623461100843646, 0.036850005102854584, 0.011573270162297113, 0.04761804503599002, 0.03614025145408607, 0.0060961149715548085, 0.026364475413556063, 0.028133496920007373, 0.0508229240715023, 0.029743262153539448, 0.07521505632828321, 0.03540889795629248, 0.02654717206173847, 0.03082962462588424, 0.05515859484852803, 0.028137030500558116, 0.05828563935093342, 0.07938535553553412, 0.03739373983755227, 0.04784149756174415, 0.05721986166111404, 0.044007430514020306, 0.05335615850203941, 0.04392375073005115, 0.003895326071576546, 0.05787597000298481, 0.07698209941267006, 0.017481528883499485, 0.025801073286622286, 0.01794268700083898, 0.07813242639625266, 0.004998889851248673, 0.13286998315203574, 0.0787672681373454, 0.1426842589412005, 0.14290268593017133, 7.781232268579545, 36.57319145817911, 72.43692028907039, 90.3688435400686, 65.64123353650494, 71.3997907023276, 40.02974879357123, 23.180066308667584, 17.543614487494192, 19.16485755674301, 48.53730301703177, 74.94293828164378, 67.20413331062564, 89.25244285214333, 123.07270311540174, 97.72525664298766, 56.033525082372854, 28.328620387661843, 14.353504738500042, 5.4908696201539815, 1.3895083363017728, 0.4793811427249063, 0.11634383485802721, 0.4978156696644522, 0.11998625352017342, 0.592938325097484, 0.42911333362421683, 0.10155011013510729, 0.2738112848131888, 0.6756859945674097, 0.06729873272800638, 0.3644529081160023, 0.11332304292027989, 0.26669521665861534, 0.05561774964594553, 0.1971856078072902, 0.39243240029581133, 0.1742807739684659, 0.26066953676842874, 0.3736937364503261, 0.3745037671779433, 0.4661796398220524, 0.5344968481409935, 1.0501612939180867, 0.20611635439338225, 0.7382291062704979, 3.6188990887134307, 18.47689736273981, 47.19778614659464, 53.90989895789854, 68.77817261603572, 108.67656123253607, 99.66675927562099, 48.273347116285755, 36.206747947200654, 30.984061071949622, 39.00407645010179, 65.20314008958879, 78.44747404898368, 81.13113618666127, 90.99224152103548, 89.85506796067762, 59.959115520600356, 17.657018053916193, 2.0326109566996178, 0.5404627731730861, 0.11808074004347287, 0.06071967688659507, 0.030483892976096084, 0.10179912701489464, 0.06696055853559126, 0.053353369941995035, 0.026613691476203745, 0.02476244000717998, 0.019773987625094674, 0.05283685431124703, 0.016820804861884926, 0.03131071635101351, 0.05455408252835755, 0.01008284802082926, 0.023063481071843736, 0.021958531391236092, 0.030161371875193813, 0.0281957664617127, 0.013513807263675959, 0.02685942566923557, 0.022364753343525435, 0.012071247422887434, 0.016660433931035862, 0.0468346243724227, 0.04037292554013191, 0.05467278402178519, 0.05682583199813963, 0.04751062035680779, 0.013263583795407848, 0.04214851816575374, 0.01813118101938838, 0.07831765113458519, 0.08019013856087001, 0.012630269442114138, 0.08073275097675862, 0.06673576535596963, 0.0473967413868635, 0.046202758882915786, 0.08837080079941981, 0.03083998213462051, 0.05585941208165981, 0.06389226914653856, 0.04674224566007334, 0.07012350574856804, 0.05881162382842553, 0.020947063589588772, 0.03576053997441646, 0.03209851520706809, 0.04508371893016081, 0.030255776890102896, 0.038669578836209355, 0.021763768858246265, 0.055353794051634694, 0.05105062072435695, 0.03144591171745091, 0.10869187287866108, 0.05324198458824427, 0.009598218884709622, 0.06098042257250317, 0.04735283688792298, 0.021362576273179824, 0.03861745804428093, 0.04928398749700958, 0.04381082937001221, 0.11164688850722967, 0.02842697754291998, 0.04986424164305772, 0.11078065756948725, 0.03081593463467735, 0.05139139578527501, 0.03818128205415222, 0.06437039228096124, 0.03175943511568251, 0.020866808218641147, 0.06211813591841248, 0.06595562737915786, 0.08274259796786694, 0.02502534414581474, 0.026503212021423445, 0.029149256729250474, 0.01742566575206095, 0.060884584973175684, 0.010785595795530225, 0.014839955256320538, 0.08920503990544427, 0.046026118159774816, 0.0265311052827465, 0.022596952678155036, 0.03181653356389894, 0.019495171840272604, 0.04681548749607417, 0.07757810815688103, 0.01505530831749521, 0.03887993125845829, 0.07248058209135648, 0.03333635815990067, 0.03191708068874094, 0.08170998805472929, 0.02249573522637929, 0.027821764252298785, 0.019951601279899478, 0.06859322213718007, 0.03336819677403377, 0.09871611341593728, 0.060615596181202325, 0.04115128619295936, 0.10781195194971178, 0.02883264408146422, 0.18725327786899384, 0.15470563404021725, 12.036921535768817, 50.182199939604736, 89.0109032969321, 103.24321562244047, 83.3850242245582, 94.21927744342436, 55.57452932480843, 39.642246077137614, 27.395692486916822, 22.96873684852354, 33.23756471756966, 28.947625314035726, 42.88982345211891, 71.78055086443501, 76.91134052891886, 66.77237449153778, 52.35870745874221, 34.67661565349948, 20.2972379807503, 8.501322557849269, 1.8455723673105242, 0.2755744514926788, 0.08586161003838624, 0.26450114084347603, 0.16907152930094352, 0.3140642103408614, 0.4379476144188835, 0.2491744334298757, 0.3512148781409187, 0.2800151873980799, 0.23096282275453692, 0.1812757849092445, 0.09043525453777083, 0.40814572164127905, 0.03699188841687095, 0.35016190561075367, 0.4831631655894941, 0.14099187878591402, 0.1443309342909244, 0.399077630812122, 0.2770356263124174, 0.5020302564146057, 0.5795298252374895, 0.7752844114457408, 0.22640530440595844, 1.357457056160896, 4.871644550754178, 18.063110843781505, 39.038032408683534, 57.777971759919204, 70.49118934139129, 74.83130762653967, 59.41727538262645, 39.530054523098855, 35.96988777960501, 50.056048670122706, 70.93924953091529, 93.31486517383208, 100.05325394292032, 89.22817907025738, 104.76256924290811, 107.73228199251237, 78.92747017645067, 28.251396763709288, 5.1448082154796975, 0.4191294306468579, 0.12736214039426658, 0.03127987556640179, 0.013086023766757741, 0.05791361556358396, 0.06352457375596128, 0.018666846933023586, 0.02776996138685894, 0.05386639604224794, 0.04882277192307576, 0.03538437548183626, 0.014463756289783747, 0.03789900929757184, 0.060987390142174504, 0.019381405868297143, 0.06399867492878149, 0.03971561444022002, 0.10955168399959804, 0.04625865648831091, 0.015196124854077016, 0.026646328736997904, 0.06463840048039152, 0.025445085634747823, 0.018373527188575076, 0.039169508663396684, 0.04742594465853707, 0.03460634807725588, 0.04355899328666349, 0.012308112232975904, 0.06345211716008282, 0.01908329041344264, 0.028368201362149372, 0.031645023714630835, 0.04549823761467011, 0.10679064183345727, 0.014665024824470524, 0.036595690725070816, 0.03908811565188151, 0.028290060393872763, 0.012862451539765443, 0.09132000948152236, 0.06192796608252872, 0.013507102079118692, 0.01731918719146521, 0.025193973504487547, 0.01145900431795106, 0.029453014421667305, 0.05650813533594051, 0.10244768172983201, 0.07557129487395287, 0.04230219157292478, 0.005292999145064143, 0.04070587884334307, 0.03595145674602639, 0.027284411030010353, 0.01918995858079964, 0.0949089398847953, 0.03837678003154936, 0.10333900204709462, 0.13073713308380497, 0.2400445499487462, 0.07957392041721652, 0.10517602726336449, 0.15391510791115223, 0.10894331825716842, 0.18878295627092162, 0.15757454138609672, 0.25874834147191816, 0.3364218735406476, 0.14959397365248975, 0.23050336918282896, 0.22706148935662163, 0.18535028482156415, 0.10071656050821466, 0.2484763894350298, 0.08968784383708432, 0.14251319150770866, 0.18281151540577414, 0.1675875403828198, 0.21141448058187964, 0.10848145916937821, 0.1543015073384008, 0.23530637274586388, 0.20040978076717547, 0.06352515981322335, 0.2277045129167457, 0.1391263167944647, 0.12434390719018637, 0.07576304668140027, 0.1755978016843719, 0.136327920181136, 0.11845249953048846, 0.2271187008028069, 0.1430576348737363, 0.1640561048782641, 0.14735489783267822, 0.17133207090439337, 0.10798603010874604, 0.22725523299267217, 0.09562727754875537, 0.09143981031112133, 0.19232344693474232, 0.2468924566863045, 0.13835121967619465, 0.2060940152695102, 0.22889973265269112, 0.12496789346539205, 0.17374224480121367, 0.20974040992798346, 0.4221658354565021, 0.6196440275638335, 14.57679742766965, 61.40838030845889, 104.1757748203893, 117.18273870406614, 89.56277293543663, 98.76356294078212, 61.65000223344373, 40.63622174724456, 31.867204289282526, 32.98454438486407, 70.13256703653644, 100.05642321801956, 90.6416992987356, 130.58993339538574, 162.33563638502554, 133.37068988430886, 82.67938983055853, 43.802390329299435, 23.431003862811675, 9.527173369161545, 1.9442921732702565, 0.9481741536048152, 0.44289136365536724, 0.730088165690822, 0.28869704733933177, 0.8070287661206338, 0.888588754159789, 0.3820307342515838, 0.7417417113338748, 0.8457739386827716, 0.6586410285484406, 0.6328250299538336, 0.3761968827776371, 0.3683215295595508, 0.12274022469477308, 1.0310486872350018, 1.5071038132713688, 1.1137112903018151, 0.8040275400684727, 1.0167244365138393, 0.8175564076631301, 0.9335041827251835, 1.117022873893861, 1.6355982086350842, 0.9231238752122849, 1.8316437856804941, 6.19519688429371, 27.598983049392704, 68.8557884770055, 83.77493135390743, 103.48928943757089, 150.14469023673766, 146.80719252555602, 70.53526893738778, 52.64019243178829, 50.09306015506868, 59.33324252405475, 86.78375013412969, 103.38939451402234, 103.38733919205205, 113.13807687451764, 118.76616816366874, 88.21766668750395, 30.54655009700406, 5.457566736205932, 0.6175562234655504, 0.33475884987461957, 0.18051363467689485, 0.08811284367355608, 0.30620439338587946, 0.1367314186908545, 0.3076536478775163, 0.07015591892864435, 0.1933706278401998, 0.21091966439158688, 0.15867373966161283, 0.1577169264877035, 0.15284825386779924, 0.1135797972881025, 0.1999751331224557, 0.20439061876987258, 0.13066645381191086, 0.26482599276688795, 0.15971735059734316, 0.12530913967038357, 0.10208543705483598, 0.2076573708965894, 0.16569927154529482, 0.1967744177748119, 0.10359846836616916, 0.1351862193475808, 0.15038862133458739, 0.1760041960064442, 0.14856930041024763, 0.16060699318205157, 0.06903480287761458, 0.07943271509101314, 0.2147810386433717, 0.2043341734116116, 0.10247718377579605, 0.1270493849991791, 0.17284642754783555, 0.09600707329809667, 0.21410410803171898, 0.18849380404478122, 0.15753024618231481, 0.1910442333187788, 0.19484061267106764, 0.1330543345501346, 0.12997216364789393, 0.15455474536265099, 0.11681264236329064, 0.123117484693085, 0.19376646547067553, 0.12052231588430944, 0.15104534254679758, 0.056591255875724944, 0.17058665203230997, 0.09298906992039374, 0.0879347665355571, 0.15436994963355605, 0.21477302536368373, 0.1696002678645234], [0.06251760480564929, 0.03307860021689727, 0.03695324311153062, 0.020269717375237136, 0.04773088978723653, 0.043137541506439454, 0.057941290489848585, 0.02160726667141482, 0.06767374042782091, 0.014017014989569304, 0.027430594012501742, 0.02504604192630899, 0.06001274244138791, 0.0433127994408771, 0.01584110768406742, 0.014511398340184844, 0.027592412849527695, 0.023593506663136428, 0.08025385409353242, 0.012180775971031718, 0.049111464496461615, 0.03918531688771421, 0.07565796240082673, 0.02536332107058937, 0.0889624275207039, 0.022256083771466248, 0.02616570432550244, 0.014175069462057325, 0.06307768019577188, 0.042130564895248225, 0.03789180424064398, 0.035887844635233764, 0.017832782112001892, 0.01436073661616613, 0.041361588819493214, 0.057449630581803864, 0.02127122220342919, 0.030454457962825417, 0.02324247176969244, 0.03109650859128564, 0.029708073819957437, 0.033945359755307436, 0.044182776548569246, 0.06479622225367254, 0.06112963351751528, 0.03256994464825238, 0.08464642605113407, 0.01151328164738633, 0.2064048171403908, 0.29784548546998735, 0.08548871674124273, 1.682842912212495, 36.180840692212506, 77.23267678291568, 78.67042156957811, 66.6261249972928, 69.45091401377033, 45.431809579172445, 31.544752120971683, 40.80065534960839, 37.64209224331764, 74.91890984196817, 81.57529754023399, 74.4644561890633, 118.93162158227737, 104.12297187312957, 33.12250591093494, 14.248644094313345, 6.715650789199337, 2.2690761906485406, 0.12635732415102183, 0.03478527557285082, 0.09554677702967199, 0.11562286951248685, 0.06956242295282503, 0.10315585340703688, 0.16441866364930907, 0.27766387969736134, 0.5090845472389652, 0.30296666066973443, 0.10334917569472905, 0.06593854361844641, 0.494441818445921, 0.11843014508485795, 0.3858502647809444, 0.14220609750238158, 0.25544159955555396, 0.12849424214613053, 0.06938524979857669, 0.041993538578671795, 0.1383009336648449, 0.16104645185893582, 0.0860808260979191, 0.20902139044577078, 0.366612387400481, 0.3375592076730344, 0.496803330437791, 0.27946844576827945, 0.046980763304858446, 0.09941042656259191, 0.5045086121366871, 0.8468407007955736, 0.12234788808611133, 2.515150986371502, 19.268937649265414, 37.446820966659054, 99.56958647697203, 96.29385825126403, 48.343945857017275, 29.96681005724015, 20.7833549668712, 37.489535577835575, 72.2379933634112, 84.52128779503607, 69.351411327239, 87.42124511349587, 94.16044973557996, 59.83247395484679, 14.825460007113797, 3.221409772672961, 0.09950496947332736, 0.05174942314624787, 0.056709068707160415, 0.11106689100063617, 0.07970667579361508, 0.03292665433799548, 0.039308737482755415, 0.03957536672392199, 0.08594580310126466, 0.028417751929091833, 0.014345568075265377, 0.03204278997145593, 0.08705181955930688, 0.01585618525202717, 0.08383256488389547, 0.042538725049985994, 0.06981294902582323, 0.04124760642767914, 0.027652163877181953, 0.024531012506134087, 0.12284863379693801, 0.02541388478881169, 0.028753045630911668, 0.05668872524233115, 0.03945492621090624, 0.05966543265047574, 0.11605664381697295, 0.015260243540509574, 0.015677058573571906, 0.08486892096698286, 0.11018051195048517, 0.08642337465238187, 0.029477571370080117, 0.03485739892048221, 0.014226805294803796, 0.10265379002498043, 0.04692924389195058, 0.04933893898381822, 0.019041923580751307, 0.07637065399678485, 0.022930055368511428, 0.04059868399053812, 0.05338742638066892, 0.028998212918879527, 0.02735104918810389, 0.05298922153850717, 0.052137756945505265, 0.02939741750578246, 0.026178080475919192, 0.012881852716447846, 0.021431893823788534, 0.0569479234306322, 0.04440474669418989, 0.019649115293436957, 0.04309646387193953, 0.0531782039381083, 0.027803795660034786, 0.022722365101799372, 0.030394689698192864, 0.08533632653134485, 0.0490305656116576, 0.041468550015481255, 0.04833108903239331, 0.018116271033162074, 0.026073105362874847, 0.07946138976201897, 0.06544810945108052, 0.04700594461492954, 0.020379457555170503, 0.07405564354191865, 0.05025802232745675, 0.03057973440586319, 0.022966293242549705, 0.029485481227898312, 0.076262689225616, 0.020246089308432514, 0.02580425638194767, 0.07014834997995247, 0.01311220194874031, 0.03205873417638002, 0.04081676623994305, 0.044964178570456086, 0.03362824148949116, 0.10991631120803858, 0.054893562900683576, 0.016707075279085867, 0.04522453738196243, 0.013491531342057692, 0.023569348080444242, 0.04706713971832106, 0.05553616128200966, 0.00718919268336087, 0.0608776786905383, 0.022388848723963867, 0.05172675460456841, 0.03741614790933748, 0.05354198461939251, 0.05714008509511909, 0.03182216814058202, 0.03137891924369239, 0.08613703396892355, 0.03980839534872963, 0.03441170045745469, 0.044211244375835505, 0.2068321103410375, 0.4273292374226355, 0.39141123573626246, 4.400217821521144, 53.48932673854213, 92.2343227940221, 93.03553750438076, 79.97046762897124, 94.09016086209206, 68.85296437048143, 46.46382831758069, 43.65967881294989, 26.71291570509634, 39.80393402038082, 42.55241332515594, 50.056017291161325, 87.34793601497528, 76.71821086637436, 33.51655898555633, 20.38085114571356, 10.779200792312624, 3.6957611191657285, 0.3470062055895406, 0.11000949048226881, 0.20362852982455687, 0.039444116710294644, 0.07265879712518185, 0.15947309112356556, 0.13364181673574832, 0.28401808873299633, 0.3201140679659382, 0.292514831188225, 0.34368196622498576, 0.4367356020356379, 0.4404699435878185, 0.2935630539732595, 0.9331453471414505, 0.9248980122708506, 0.9393807512617881, 0.5386285748212569, 0.23726312984381956, 0.0830514463145406, 0.2091421871896713, 0.20459213053747533, 0.010129831235615477, 0.02342499604809188, 0.29338461677393607, 0.09779876143100763, 0.07463808486899061, 0.15901368351713305, 0.16641899582839784, 0.20132015369111494, 0.6871105105646196, 0.5190011570530554, 0.13715509595649858, 3.801643050486042, 22.4512428622092, 50.2869233008354, 74.88098052240188, 69.38790505932224, 41.98198303099602, 30.079888066937848, 42.02791398571384, 61.24947332566785, 96.6734181680987, 106.89502854501049, 86.34731584979643, 103.64789439785866, 112.1037635495586, 82.95657588589577, 29.066857522533788, 7.6814555064324415, 0.19659728292495976, 0.15961256509106006, 0.057682486836828535, 0.06838044887709041, 0.07174684606011837, 0.027085389048161528, 0.048617962146959, 0.006580758471823028, 0.035713712850044814, 0.04827760077352005, 0.06576858701244478, 0.04134574612121909, 0.04049907340818355, 0.0651848356750223, 0.10805457965621065, 0.04530185097528081, 0.014554410346693572, 0.035562487093791846, 0.024279959747687947, 0.015882627734343614, 0.10451788878849438, 0.04970765710177441, 0.09906157310451232, 0.04712114508654322, 0.014900390975057118, 0.06519513189672463, 0.05682028169112821, 0.045908343632735556, 0.02891229232773185, 0.04950701867440536, 0.11795395249200445, 0.07903490861457202, 0.09519353388778626, 0.009738580556586385, 0.06922309962852348, 0.0803946304104982, 0.08614303243737068, 0.03766462469713823, 0.01666769835977785, 0.051688745152205236, 0.04989110068568299, 0.04046152743901457, 0.03788243881576965, 0.017186217310447848, 0.07177862338721752, 0.05074962477890715, 0.04453983097787827, 0.03809595901158549, 0.021834948002510977, 0.03108787861081862, 0.027760170783186634, 0.008105846091864571, 0.04031545745449201, 0.06025936912685152, 0.03761270308807012, 0.02316242132726456, 0.12179890947957193, 0.0734924080391084, 0.16251052249102824, 0.14963515853929907, 0.1968790347417516, 0.1720920148035211, 0.18128695447118054, 0.10623850694466984, 0.1496985599759125, 0.19183736414678637, 0.12772256944088206, 0.10155002586543561, 0.1683547774389867, 0.22983124960334073, 0.0849062447706538, 0.07157918005701035, 0.0912784798551471, 0.15768343312365396, 0.274950243051975, 0.19224702200341612, 0.18896116364386775, 0.11841285448040693, 0.10712191357367462, 0.08656600490212442, 0.19341663908093207, 0.09358882483455444, 0.11879631979090553, 0.12835722732087299, 0.14637311019243734, 0.21629148823840005, 0.12789791164499137, 0.13836530037224293, 0.11225064240035512, 0.13057242418008466, 0.1644639854109095, 0.1944264042521677, 0.1725912743037747, 0.2468501839546427, 0.21028342837047195, 0.14822203275417128, 0.11154900545314436, 0.08784503465698612, 0.1701812842680562, 0.1406398920282241, 0.1670516772015441, 0.1989624874606248, 0.2361833595580632, 0.3507400262019327, 0.4286098606403797, 0.47324024321090796, 0.4189280720968401, 6.353375286825242, 64.22528143851989, 107.5778425893476, 109.14559825774163, 89.52032504543182, 92.37844636363369, 65.31051105068576, 45.64780665982155, 59.53879825530514, 57.22464299971058, 106.09669285435831, 113.15276222844278, 105.67515573193951, 168.35689821550923, 147.3931161818966, 48.57287106975433, 22.2800745502595, 11.606404146840497, 4.829002993722116, 0.5706707231940762, 0.3809957801093979, 0.4046379582535836, 0.3016805522624524, 0.19565065872044335, 0.4886911947640681, 0.7826738504152145, 0.7292424046224164, 1.0051443740244836, 0.9307660619097372, 0.6697051154990351, 1.321179422159349, 1.073732532320484, 0.5494139283414811, 0.8677410502587596, 0.4213533532475272, 0.561933888783378, 0.4148026886245897, 0.19426218564471892, 0.23309400275109277, 0.456048280241028, 0.5267912293634107, 0.25441062907057427, 0.44726296778648134, 1.0300888097093952, 0.6454984531287224, 0.6294416179580073, 0.419407275415236, 0.15469763608228776, 0.17293275033514346, 0.8155323420801471, 1.252321355765866, 0.2780361064980107, 4.720345004912346, 30.833585223843976, 60.66676601286858, 145.23220400656425, 137.08779458076725, 72.88182689297584, 44.05311215308405, 30.262956849990356, 52.35336126819734, 97.58236469761019, 111.74700829290576, 89.78723449091758, 109.89790885679184, 125.67794138385405, 95.55445225008073, 33.549051900063795, 6.617632719778246, 0.18489122961557683, 0.21443666679964912, 0.1731384296210543, 0.17205289835410734, 0.22739761809427894, 0.18415353290977018, 0.20546594574566812, 0.10552312638009749, 0.19973669591690266, 0.17375111609937685, 0.12661184154210553, 0.14552028579336984, 0.20187975027628485, 0.21702058943769625, 0.25485735026098066, 0.24020362044534377, 0.15626725830858754, 0.189844616238148, 0.12676576392785197, 0.1343555195677665, 0.1742660650803197, 0.12277783961185526, 0.21559154434550196, 0.18186099947460238, 0.09525988476290818, 0.1781509582313799, 0.16875312783785407, 0.1808895233778223, 0.08173176793441658, 0.15288615989829266, 0.29307833482180873, 0.19767967323141714, 0.18619227673738234, 0.15081858052121055, 0.16275571659207344, 0.23002009027667586, 0.1760518773188514, 0.0879033952350578, 0.1747262387746765, 0.2460933810160045, 0.08414170434398037, 0.20472938284998943, 0.09878028094047502, 0.11263235336950711, 0.19997948450186562, 0.0880356909587018, 0.22132036516502981, 0.17524722452846267, 0.1443230435853043, 0.097494111246159, 0.1084957390482868, 0.1654614165665642, 0.10149340430695204, 0.14701553620398045, 0.17446843486639763, 0.18234714354959228], [0.020984419951996496, 0.0039072799160250376, 0.0728047751791535, 0.031279329728755745, 0.010542889565019118, 0.01158304161377131, 0.05230771355150689, 0.01570534732778587, 0.08294554231988807, 0.08528242458499248, 0.033928387077345, 0.05059556832777397, 0.045735062205142556, 0.02788525761946315, 0.0403416385093043, 0.06136853420626252, 0.06809158010348197, 0.012720054946839811, 0.05367713019011482, 0.019891961334994244, 0.0353330897257453, 0.13296375231396768, 0.03295241787488903, 0.06439692956665832, 0.004319784986305862, 0.055667939896304766, 0.04885473311127675, 0.05020849091271239, 0.047634293760864005, 0.04148245834174656, 0.049849858342279355, 0.018299578636464094, 0.026267270347283735, 0.09928085811195836, 0.009850404495673796, 0.016245920992185994, 0.10493835614573573, 0.02407047108957364, 0.031578680500388145, 0.023492172382952228, 0.033754155700725895, 0.06644338789966799, 0.074739882632369, 0.04797098174270603, 0.07071291847575097, 0.05508647150089664, 0.09689078636227116, 0.059385136400739995, 0.16921129438184923, 4.293422958543224, 42.42131594688662, 80.27094471839168, 88.12028992560603, 82.39934044499552, 63.61860059922742, 46.59057578732891, 15.789439351327959, 29.768412651554232, 50.37165826366794, 35.70393147007112, 33.659729419216035, 39.119523571383574, 41.24689555937245, 22.062865457227154, 6.074291294620884, 0.7876185496007243, 0.1701812842680562, 0.20793486326452226, 0.24790514831341084, 0.12119781391154374, 0.043129876796757026, 0.1327641098009002, 0.0864689262403596, 0.19628455051250998, 0.09641730572066962, 0.053216094646843216, 0.08333013377963536, 0.08551986587624397, 0.10400539894978847, 0.20370326936244967, 0.04143785287235533, 0.22518618272677546, 0.10923690613239043, 0.042783696985533165, 0.1432395807557529, 0.8348375739109132, 1.3138420158816924, 0.046710793920342004, 0.10187830220186904, 0.14737668537324475, 0.027992563555017117, 0.11723088040467232, 0.1243971196574069, 0.0901032013878707, 0.21920197883680945, 0.17049574803921486, 0.2684545528984839, 0.1907927572967545, 0.10945121156832865, 0.10535264117342812, 0.18619814497088233, 0.27841838437222666, 0.10260345038747597, 0.04274729248737136, 0.39280119502255995, 0.06755784664663576, 5.816073821436975, 27.65025431110013, 75.38367932842624, 115.23474847116779, 63.93048394110895, 40.42551986632809, 18.940674489544286, 40.82443275759297, 44.56668769159625, 58.21542193812709, 84.1161540246779, 76.87872209856587, 84.92579398616668, 54.81060066530782, 16.42194703702004, 1.0878351691269106, 0.15257463790476322, 0.05879774997611681, 0.07401527836918831, 0.0667048307255872, 0.03633705944183373, 0.04760187291990846, 0.03569179507453115, 0.008075879605096436, 0.05734962546416829, 0.039439478047913125, 0.025979926088644613, 0.006775086728720776, 0.042979673767882975, 0.03853786916982743, 0.01881384196871471, 0.06567688628790841, 0.058724864371000766, 0.025348148699248993, 0.06196624749610501, 0.016359709946799184, 0.06670344410644424, 0.02444757212464127, 0.04688735420425092, 0.012219588858105484, 0.07267735177470792, 0.0835698580129012, 0.06340962226292299, 0.040041102216609066, 0.014861256331055155, 0.015570266874537114, 0.0382362948279948, 0.055353767238557346, 0.02372055276927929, 0.03859516488568437, 0.02877621979062115, 0.04435791190893901, 0.03136530969171755, 0.06197370536204788, 0.0791378478489576, 0.03780783717370322, 0.027316630772885778, 0.03528638134500192, 0.02404334774661449, 0.0411144794986373, 0.07487795465896208, 0.03994029653709262, 0.012152831956383683, 0.039520461202388814, 0.036700219591899265, 0.019210468669752442, 0.025255475043048783, 0.029250556535478082, 0.01980994587704059, 0.018464099848642945, 0.02832132252684284, 0.052938571635393374, 0.10145321533444429, 0.030915962734950647, 0.04463029830085655, 0.05514743677791088, 0.035679756002801086, 0.0017207922017757572, 0.08153446198951814, 0.06262876033302277, 0.033014651027417956, 0.033436872726005894, 0.02736705851050154, 0.1265616857657029, 0.016181810924242583, 0.03511558587272321, 0.055023751882535804, 0.03121002558468571, 0.06686387057866781, 0.02108912693426734, 0.04689789557408902, 0.07297439470646844, 0.03611700451602379, 0.060106243472546346, 0.012602784122610766, 0.07779978335865083, 0.019682740807653438, 0.01318070170048985, 0.01573722616153499, 0.08870264710558039, 0.04105257576391582, 0.08604124233487152, 0.005326564329856586, 0.08317452600045551, 0.06289867992182413, 0.07385610062028132, 0.03543285352568473, 0.04289599398391382, 0.025800500635898886, 0.017732570150626764, 0.10706305503845216, 0.018640219631995407, 0.0271546644639344, 0.010380688641640929, 0.18941366113722327, 0.0562828595209266, 0.0905842969434396, 0.07125017593704885, 0.130174410859904, 8.173787488091378, 60.97705687246015, 98.51111919649186, 100.0325281389298, 91.30883955186414, 86.20129385302144, 75.57014096167781, 37.39331983750866, 38.46684901945053, 41.503595075299664, 35.513767119376894, 33.99296222194549, 46.517078415040054, 51.18495387415732, 32.1365063805734, 10.173421117567248, 1.6973461210727694, 0.5008937803006942, 0.5082186533799095, 0.3284541301188931, 0.2629945216880691, 0.062309657899482604, 0.11816386824413655, 0.11923020134770101, 0.1711989248231534, 0.3717020610647817, 0.05220855879146726, 0.19321482087815964, 0.3494589433314339, 0.5619896599842656, 0.8067138733402376, 0.28052975333506064, 0.747597380991905, 0.3206940578116525, 0.6101347313773248, 0.8122311772838716, 0.849923683751014, 2.7779887664702634, 2.1522579558434027, 0.9322891672772746, 1.398427560925484, 1.2541304264337787, 0.5334088194274134, 0.5389396065185147, 0.3494011190149092, 0.6429728757469886, 0.42139067705119815, 0.6503399449490732, 0.2973622065638342, 0.04502658026232835, 0.07840442591376844, 0.2798343293609158, 0.06667525973170996, 0.08787791515069623, 0.042768455666279605, 0.4653128573010045, 0.13833609710056938, 6.711288132975179, 29.303315647186775, 61.452550118969334, 71.00112884275376, 33.57569263827416, 36.06338139503233, 43.627813477669996, 68.84686900723365, 74.18303397393997, 78.718470604189, 90.5092800817182, 89.31474577996039, 107.51894427884011, 76.35284992956346, 29.27036185418406, 3.5849107705777694, 0.193232532830969, 0.027990263376024463, 0.16505689149902714, 0.059372453815153534, 0.047714832584343614, 0.10922736833773314, 0.05215340046091907, 0.007654627965342615, 0.026693831933962724, 0.03489281133478207, 0.021778870366453644, 0.04153966978793183, 0.04586157779539785, 0.025788019148392544, 0.04629489244712938, 0.02869790453734177, 0.15224761029164638, 0.016508080110314394, 0.013428318554595595, 0.058826888130316814, 0.011790086451407162, 0.03285232465714216, 0.018254208994368394, 0.01878171032595058, 0.04307635789436679, 0.026584177938920837, 0.1138211762712848, 0.07047235920664764, 0.0772466831990788, 0.014107984100137989, 0.018170831815129327, 0.0490600599967424, 0.0395141946031682, 0.08552281531475245, 0.045209794019859646, 0.04383713299889238, 0.02003621569113626, 0.030670291744172577, 0.040232244984156666, 0.016962268742762746, 0.03918437459956735, 0.03235126485026652, 0.019595471901759025, 0.03204650741310851, 0.005795253570296712, 0.005134839335486534, 0.019171564809737668, 0.05675149848684669, 0.08908589791146018, 0.018444917007018963, 0.010679934076183747, 0.02776351667219593, 0.016114701622075612, 0.06409234449928326, 0.11244022617897681, 0.1374116741240986, 0.16388799454416, 0.0958708628651596, 0.1107435635921936, 0.11567505542188884, 0.15578347378440444, 0.24066980026902693, 0.19118917715405265, 0.179639344494189, 0.10670935224381187, 0.16411740723396503, 0.09707687677995813, 0.24538010719322392, 0.1368374759030919, 0.14448214472541887, 0.23439181698185785, 0.08152485524694766, 0.14062165913562621, 0.13230738350220267, 0.20358863196546034, 0.16808493062853816, 0.12654494674455735, 0.18435961056140163, 0.2153579794591473, 0.2574423760656388, 0.13018554977832303, 0.19650106228167014, 0.07485726262412726, 0.18015657641714622, 0.14739903981887525, 0.18214747039300783, 0.12139408563774441, 0.13976134239665924, 0.17426534495767088, 0.14560651665012683, 0.2243420610865278, 0.14465425403848772, 0.09746289316324458, 0.09105392416278202, 0.2224250179865668, 0.15491411720793094, 0.16392868913469777, 0.11177121691646115, 0.2820179250932509, 0.14922140977315365, 0.2840324911859728, 0.15285548573780447, 0.28112929374460255, 7.920910321897077, 69.1655380495133, 114.33570200397124, 109.84192878969255, 104.79566620242213, 84.28022676898588, 70.09879542935279, 26.44062672891925, 39.441510938829, 73.132811515562, 56.62474393844605, 55.54356613466817, 62.199063454904866, 64.90782876168528, 37.033395305756606, 9.678912220462676, 1.1951819831325163, 1.2932928411229965, 0.6186510550398981, 0.3364017407499975, 0.3181990013728219, 0.13046221477129769, 0.20506728891163103, 0.3269897990169064, 0.3201827400874707, 0.38897881464612105, 0.1507258072735802, 0.20548836147833258, 0.1767592982298905, 0.22092524765720292, 0.34956591984918045, 0.21197629882202995, 0.637840454376513, 0.26487303056543876, 0.21920017086930815, 0.2787409380318657, 1.167797955774492, 2.0184047448058284, 0.9751692534454408, 0.35952806592948977, 0.8681798041347535, 0.5075733928430466, 0.4280833743752972, 0.3597542763717713, 0.2504619974042139, 0.4176854161966232, 0.31457874563432514, 0.5581698843067693, 0.4254512801285713, 0.437748002549333, 0.308169316981108, 0.6110507886736625, 0.6206580828274451, 0.3987751486560991, 0.0936731864367762, 0.717605529052596, 0.6537047869736149, 9.685628298790226, 43.44150873922533, 107.27737334466751, 157.51745962327527, 88.37680509013515, 60.07061281511861, 34.20421323468609, 57.63562110162551, 62.67518428064162, 79.31295287224555, 103.82638577492007, 99.94523186837473, 123.99012980922576, 84.98389213315903, 29.228525853926136, 2.977046601233944, 0.3282406980231885, 0.14302228757691, 0.24711448428851945, 0.2844109692640843, 0.22464426745089794, 0.24295880969974304, 0.1692231381011586, 0.16611263726747807, 0.23478906421411425, 0.12247555663869267, 0.11809904188398393, 0.1564085862088588, 0.2377187529759061, 0.09765693557358558, 0.15347972482202515, 0.17633136151538742, 0.1782656569154032, 0.06353118126430819, 0.10490838678613787, 0.10978998330932473, 0.09520700171349511, 0.11257040749994979, 0.19376352369304628, 0.09121248138047035, 0.15108399934345676, 0.15250815679469418, 0.16189976655427488, 0.14049272653796982, 0.2087062984825142, 0.14386642453891618, 0.09363562514584872, 0.1760856771180707, 0.13073443645431151, 0.17613508978918677, 0.06261605476479858, 0.0976733681595614, 0.16613254023175086, 0.13329672476937696, 0.24493553104900548, 0.09946670338150956, 0.11156905397412278, 0.12650432110193277, 0.10644343546441487, 0.1332142783869659, 0.06793186609302798, 0.10837347141557163, 0.1639612325497212, 0.1649686534919085, 0.15011564888540777, 0.09575748185236609, 0.08148021530359983, 0.19117817613146, 0.20422194153070453, 0.12005794402812758], [0.04529569545880922, 0.029786057740209565, 0.08055191592223222, 0.051838369784696456, 0.0835624116382772, 0.03158541632846239, 0.030599710148488803, 0.019938836339861155, 0.02987508290267039, 0.03453411747731509, 0.05246136780647982, 0.05699251740870457, 0.0640431693154237, 0.06260818704181621, 0.050459886495504654, 0.025860027582835288, 0.1042837416753173, 0.036311399326809955, 0.038148593082423174, 0.011418672661567408, 0.0763209808557745, 0.03288874064662284, 0.049402125915812875, 0.05469601563808899, 0.016736209602846254, 0.020863745782163837, 0.01621110995690669, 0.029832850390624617, 0.13483691389762587, 0.0944355205302277, 0.026946052976493395, 0.06290890719561328, 0.01723039568582129, 0.025273213808935498, 0.021467947836724982, 0.05984329145341631, 0.03360733111959792, 0.08165090735400878, 0.038801897542491075, 0.06927717777509844, 0.06498050470385822, 0.023003301034951885, 0.016482881563265, 0.04841944195270058, 0.06225670207171671, 0.13738418688937543, 0.12659157851650832, 0.0645810358166214, 19.30463514020366, 78.58929910967427, 84.51713792739376, 78.02141835612636, 75.14759186775454, 65.03217181851788, 31.974998866358114, 19.69021785643793, 36.09945151113695, 60.861864705239576, 48.80332992922876, 29.225725281623106, 30.290231050983554, 14.18458688643671, 2.905343468150785, 0.13626569851992593, 0.142823732908695, 0.1129222870053303, 0.009999938155224007, 0.09051297415768908, 0.1324297737089857, 0.20626351988363653, 0.07299878694597753, 0.04596393863340059, 0.03890950608277514, 0.10593069281669394, 0.14727266595488595, 0.0446338337966271, 0.26761574790843073, 0.1667530408069011, 0.5185258761048317, 0.34308527566252217, 0.019668851633586233, 0.22113376146843358, 0.2874360359724491, 1.503927796598404, 1.0709628486825575, 2.742049559470146, 3.2735856310013807, 1.308311228790591, 1.0253550604947153, 0.4906593359285786, 0.2964551584614862, 0.8168300337368443, 0.09500094704450139, 0.21296485867952147, 0.3631706301483416, 0.37764239876020345, 0.20758659969414436, 0.19601458112799353, 0.011279796242653843, 0.12488111102532957, 0.08760789980090435, 0.13194920675408456, 0.0642230888948806, 0.04907094610614642, 0.1515264610850042, 0.04104987530398273, 0.16336864821853178, 0.11580981028776978, 2.9727435160067777, 29.404059763877626, 91.74026104711717, 85.21881072751938, 58.432548661385816, 31.42390193477754, 25.738463632522095, 49.88803394379155, 60.36047597085277, 78.82948936954622, 74.86034101055515, 78.7437463575794, 83.09094059851863, 48.817336713114095, 12.939920771506525, 0.34570465284970503, 0.19280340101930404, 0.1648740416332599, 0.018122259925510135, 0.011860492804478253, 0.08477273862808944, 0.09191361270965108, 0.0468882275444846, 0.0687491133688919, 0.03823306193695434, 0.02129517394238182, 0.03905284496384763, 0.02748499774644452, 0.04465633379896322, 0.01408258637022828, 0.044519633069754615, 0.03887621956246515, 0.024863795354782094, 0.036202354371667876, 0.0007271553359685406, 0.0924423895776272, 0.03460516064097324, 0.04819895801765304, 0.021714568776529164, 0.06196974468747936, 0.008014006513891923, 0.032853722767603975, 0.02477009131032373, 0.017566915128319975, 0.021196898268235308, 0.01906352151455658, 0.016308839793407148, 0.03201112564232561, 0.07226836807545155, 0.029852565663355975, 0.10117304165877643, 0.00990225907204853, 0.024240400882497914, 0.050364830305859934, 0.03391247160071808, 0.05179728831975691, 0.03716331591168719, 0.06680423829464183, 0.05074684771018163, 0.05772666712742179, 0.08280683444031785, 0.0640577747817001, 0.10295208934093676, 0.05465419489830252, 0.03859363654027543, 0.07725636655044171, 0.025539048233880632, 0.03239081796979712, 0.07885941319287786, 0.014079002036352553, 0.0405259630943258, 0.05224210961211113, 0.05612168611297685, 0.091462264348182, 0.024304518611320568, 0.03250937773695877, 0.02165310171192452, 0.052952744261992556, 0.03654234419246355, 0.04215138716503017, 0.025128225923605987, 0.030277518465393977, 0.052084356786743294, 0.027984661358078162, 0.05810644372456497, 0.061968507455481645, 0.006558566819876433, 0.057463787886644566, 0.06255931446268674, 0.048620428950075185, 0.035832314752042294, 0.03237741909200146, 0.006179572111220971, 0.0193240910002421, 0.04650315727978464, 0.06171967826723572, 0.08007700269621226, 0.04741647581179296, 0.05426708683972398, 0.04412804339681903, 0.04019311704342404, 0.05395205999394098, 0.02633846098286731, 0.04122749661966678, 0.039474365691984856, 0.04523035581974734, 0.07177397323351714, 0.02475050818775931, 0.04881574689681011, 0.03776952128617033, 0.00805120199783555, 0.031350731038518494, 0.19632385082302556, 0.05755096103154844, 0.25791171217157, 0.05189136008641893, 29.733164272000714, 100.75174962320636, 95.38781427568006, 90.78398719910653, 104.11779434450212, 89.050872248988, 49.55999043680007, 36.440509442360174, 20.83798966100139, 44.69164656054589, 45.296028890917384, 35.07505786034369, 40.34085550615865, 19.940596472832468, 4.100742897679729, 0.1120000780229607, 0.20613277931847881, 0.043876417987649484, 0.049405462228723114, 0.14277298724459064, 0.10748323894316152, 0.22276336837920452, 0.5829625120086055, 0.194963232704228, 0.3354134260406417, 0.4262998604005383, 0.9623102531317742, 1.282138478371405, 1.6165152648764274, 2.3534880482381393, 4.692603551572369, 3.1305541963346544, 2.099567286429867, 1.3798472934192227, 1.8986870204248738, 2.585238838388074, 7.740499925228858, 8.090451340521536, 9.044673788932062, 7.600431105782909, 4.584831037829, 3.151059121854844, 3.452819806914176, 1.901303976774216, 0.8974927183120482, 1.7422746650634275, 1.3309268797597578, 1.1778610415997044, 1.1391590151094622, 0.7134471425125677, 0.5317382574562104, 0.415781963496439, 0.563046616171637, 0.0854029838416365, 0.06136582225501057, 0.045908577289552464, 0.05169679673628942, 0.0714133526649206, 0.23395697015427777, 0.08783319859855598, 3.883073416448409, 32.98609764345231, 71.70790072410338, 68.38529233009585, 40.61163633100448, 30.103804719063547, 32.77382485328182, 68.72228668582055, 86.42397465244417, 91.25678185493716, 86.17343718005766, 91.94314172191005, 103.39799234944006, 71.45635912495275, 25.069636760219453, 0.9442595668858098, 0.16250073188735595, 0.040174416837192355, 0.04537420031884986, 0.047109722715592196, 0.07347249741395635, 0.0519686890014958, 0.09579015550233665, 0.08392585907131435, 0.04826088090457263, 0.06247208769162817, 0.0425408203004589, 0.02387141271854841, 0.02969872180162178, 0.06739141404508583, 0.04193445787795129, 0.028286352528319247, 0.014815962340141979, 0.015424138475810329, 0.03244262466567659, 0.047970606359623136, 0.03193152144611363, 0.05286064900217518, 0.028530435801874247, 0.033863809695767785, 0.09762334261810589, 0.013740422774947459, 0.06839082936846441, 0.037824357859790325, 0.026553980668165514, 0.05150843869834658, 0.022385380260886687, 0.026907710275883158, 0.03932447292872014, 0.07792399685469367, 0.05793860152123436, 0.01770278465213074, 0.0306129711304581, 0.06920537235395563, 0.02965254776720559, 0.030301795791714426, 0.06493905934715463, 0.08073622135505562, 0.03492039433049579, 0.03950028244646327, 0.07855008221081189, 0.08076316466735256, 0.04541473020048392, 0.021414413612576264, 0.029319111828602133, 0.020104439651233055, 0.047165574355711865, 0.05418001711668988, 0.15372280452039935, 0.11891872531944707, 0.13070129549070714, 0.12388686679543988, 0.22463050851177788, 0.2057351183987433, 0.10398102203203786, 0.07808865213225927, 0.085618844436061, 0.15560142065007843, 0.10782775634358968, 0.1267671658687534, 0.1614702670204063, 0.14254662358472425, 0.16060648756402154, 0.13697786917609556, 0.1491194741139489, 0.1400508776667618, 0.11395334175998166, 0.1482399285680825, 0.13194222003221512, 0.15492933171410717, 0.07814513579491647, 0.24729782445055826, 0.12570156054871698, 0.20385349920440107, 0.0973090703689283, 0.14709042895945812, 0.20991308614611628, 0.17158768380120878, 0.23684673041345614, 0.17553611628470883, 0.14959630255977954, 0.10696377004346541, 0.20533344317828456, 0.10892053480230032, 0.13602870155967053, 0.252966093680551, 0.12053430516032443, 0.0884385229719262, 0.17841219421355956, 0.08849142134309777, 0.12568640732957473, 0.137330346230057, 0.47958676072378315, 0.2075436374833507, 0.3852791921986688, 0.19311161351300057, 30.643666021285522, 115.69775289104832, 107.70375067187895, 97.21504257571314, 99.51690904555782, 87.37525924559563, 47.54498258713753, 29.97872425663856, 53.7192835346345, 87.24189081499654, 71.54551459896949, 47.75603355899934, 51.87007034978559, 24.55749092563506, 5.125181165433699, 0.6009488468689304, 0.4448398316819822, 0.19403419787845305, 0.20163270224246288, 0.31438621241719494, 0.5233011166414907, 0.6888277119686527, 0.5651963201742018, 0.19147302805175706, 0.1939136156391713, 0.3167967846797359, 0.6432669309358443, 0.7876536670711733, 1.8157128340774968, 1.49517796933651, 1.6695794174748084, 1.5212152754106831, 1.0944507367187932, 0.5742035529786541, 1.6882709822347088, 3.1362014287902467, 5.835246366839256, 8.292580881426412, 10.58187811605392, 9.726940662630144, 5.291751969245173, 1.9464727659379284, 2.459634494396948, 2.779565068983263, 0.5659280873594746, 1.351638465158401, 1.1197088394434223, 0.8355432941067604, 0.6272218628756462, 0.585771848357493, 0.2504093058767819, 0.222775120167963, 0.30597355577253527, 0.19967773779025003, 0.0967739426320599, 0.20838703900094957, 0.5537372382898484, 0.1912582169977888, 0.2803788340139774, 0.2756420817346342, 6.203661359125569, 47.798567741147934, 137.66049200488675, 123.82622964920537, 79.31496897051412, 46.14272740579421, 35.324234270280414, 65.06503735819172, 82.66632833788472, 104.50653260754001, 91.42846399737944, 108.25686762409826, 116.17811772131152, 77.57478590934508, 23.720170797840243, 0.773016423467667, 0.32553459968297715, 0.20135205359228198, 0.11475961099589065, 0.1745779088307773, 0.2613758085475814, 0.3029618802810869, 0.21792408289207568, 0.1477588713169098, 0.15742100204431242, 0.14522089863256102, 0.10305675227315196, 0.08173101716825078, 0.15635540438515527, 0.22394389454876223, 0.15503646144943853, 0.1221199462851209, 0.1666080050410763, 0.057849505495640545, 0.09082933016602071, 0.17157550300321273, 0.07413833507246549, 0.10921495771335979, 0.09872689993391115, 0.08137333071640424, 0.1771120357537462, 0.1007287719497277, 0.14463833473142118, 0.09295534672996691, 0.14324229270700486, 0.11216848713135529, 0.1028547348875192, 0.18645726655039097, 0.13410749094140145, 0.16508424083792395, 0.1588687396818592, 0.1351740691931017, 0.1947684778321174, 0.16911289804885465, 0.15821725851105106, 0.2433825022871456, 0.144563993559249, 0.2391102444380522, 0.13512600483673234, 0.15824295310003145, 0.2547485504539744, 0.17390388935323686, 0.15790651792720442, 0.2392432219799488, 0.09057334188612239, 0.15049277864877256, 0.1587127335369587, 0.16467666674044826], [0.010681974742892049, 0.04993388286581443, 0.03724234554195597, 0.09694728534668685, 0.024850522881493937, 0.05674831922196093, 0.01036578918912358, 0.024887722195877184, 0.030280603884509018, 0.07053883265583746, 0.07927551384895079, 0.06721946561048109, 0.03612942280127637, 0.04898009956964562, 0.01210381094771888, 0.029805667675851338, 0.024114703091101784, 0.027867103250877514, 0.055394350746346105, 0.02475556819849918, 0.08111437767623894, 0.02721161927066503, 0.02261034581029127, 0.07914219156748827, 0.033170074945495974, 0.01595407883982144, 0.04109630023219413, 0.04055077668219324, 0.021847324152927727, 0.07802839165613537, 0.05661290552046511, 0.031457261310049126, 0.04611732092716041, 0.05487184813846985, 0.014846584789695279, 0.017730856028896187, 0.051868622596826286, 0.08474975599036103, 0.08709579300616058, 0.018181120375952414, 0.034458362872922615, 0.043798955007185864, 0.0945360312658933, 0.03991765863893013, 0.19114178695505668, 0.2677543485356916, 9.120119598604019, 42.3807547169347, 81.51420270243, 78.48828238825645, 75.22682374523532, 53.30778375748665, 24.039422312090476, 24.18462649468453, 42.93350688872799, 64.413280640879, 81.3416027253674, 58.4039585051998, 33.57246452762235, 11.866363152380913, 2.0089202085810323, 0.4229494514724901, 0.14149242531388037, 0.045143822358260234, 0.05632649205865399, 0.01991568899322902, 0.03949105108697568, 0.07255332980064616, 0.27482684160913196, 0.22692019209986736, 0.06477340049440823, 0.4533337549336495, 0.06188506898920863, 0.1614270136962014, 1.608640003588892, 1.5583926030705053, 1.0454332443975634, 2.5413862495653095, 5.2533715771090606, 5.6309786438941964, 1.7617473943579582, 1.6684848310485965, 2.0446541040174426, 4.904005085268329, 11.586406923109486, 1.9510711320946295, 6.555854899267997, 7.90382202594511, 4.326942063147023, 6.077696892522997, 6.231462138314401, 1.3301006079681459, 1.941848046356632, 2.2809560693079427, 3.234486709679327, 1.9588849837741547, 2.8140331420206257, 0.708136008151116, 0.07698581493910282, 0.12012967284047797, 0.1844851723721912, 0.19015938644447636, 0.1462838456275002, 0.11142940380640569, 0.08120597880934516, 0.08397713333608643, 0.06723806622528261, 0.019462074926723878, 0.10738579255919303, 0.11239486611298016, 2.4182851131885283, 29.535596447606242, 92.84424351107691, 92.63019192603328, 66.06466908608714, 30.33735832860393, 21.912085625433154, 49.40363691699121, 50.0384097714578, 58.94179782559795, 74.7749823908652, 84.44766490690171, 80.62944150740101, 49.275410713688025, 12.913152556265555, 0.2638036943972111, 0.07655696657996985, 0.10641695946575173, 0.08982397000034971, 0.09801891977868735, 0.07209962954924953, 0.07138607227393697, 0.030778907690077063, 0.0201205906998967, 0.03723517112854508, 0.02279272261676529, 0.010433298772230986, 0.06398660138309484, 0.039262385332896825, 0.001376645635783432, 0.03437317772618225, 0.0746769714920271, 0.05889206306047498, 0.03473379446433918, 0.04580484515416526, 0.06551485103104385, 0.05116521981695006, 0.009954962090799406, 0.04022481010085152, 0.03378272311942231, 0.028118422224877343, 0.037678789662858175, 0.07692396866097566, 0.013627757096753247, 0.07242723938918884, 0.058476042843634085, 0.10608841499854481, 0.023388775411031903, 0.016711955259163535, 0.04007694747058615, 0.05877526146509956, 0.027655693627293074, 0.018055673478351488, 0.048104744524725025, 0.03755917652480064, 0.05149749896278785, 0.06789435076737596, 0.024616933097281767, 0.049805141790139104, 0.048165686819101536, 0.057289460749034925, 0.0498025639042739, 0.03317364874566275, 0.05290237398097112, 0.051440547986496846, 0.07768512297902377, 0.009979846541799847, 0.04702803476022617, 0.022380680311471227, 0.026285053163226095, 0.02608892124807162, 0.04401131457979641, 0.09858597039936051, 0.03221663255845347, 0.06996197610973351, 0.0373721782929234, 0.02160873756022944, 0.07615703037909924, 0.052777099453153155, 0.0195290501635041, 0.038267620163218635, 0.01601515136914508, 0.04422757737038117, 0.04505076565809789, 0.06151298391482523, 0.056342959118586396, 0.047039407335462115, 0.026050396601579366, 0.08847984575456189, 0.03613396570266735, 0.03974798548546049, 0.043357152101253314, 0.09580134038603115, 0.06170986851136531, 0.05350971699602181, 0.028785489454504945, 0.026741333215707735, 0.03256419898882028, 0.0379558798346308, 0.014610823146217774, 0.008433539243865638, 0.027625871739620646, 0.023934036575918718, 0.049799557009171096, 0.08622550946329871, 0.023906432512787082, 0.05856802702070244, 0.07489132289324077, 0.06523162832543736, 0.04082567584250243, 0.31315697837741147, 0.9010982958059158, 17.58098683049602, 59.83871444579094, 98.42954958638838, 88.74368006183256, 95.12168930422877, 69.28132641700007, 49.877451389066636, 36.46442413330078, 34.69192074191186, 31.916400617168797, 56.129564316042014, 59.023390969922474, 38.73572357239262, 17.47617913830665, 3.0978347649497375, 0.15042747731410688, 0.2640938272158946, 0.07370389427148527, 0.04144119684614482, 0.014148142429128771, 0.3423187893725211, 0.49807059308213575, 1.5436837149243203, 1.3859290509454667, 1.2437319779588332, 2.3680966707967945, 1.71158469252048, 3.982743048860181, 4.385530016114635, 4.602415513607764, 6.438423548975299, 8.61203439774052, 10.8017671685065, 8.066642063279307, 6.167522111246663, 7.306879941494235, 5.435172944299636, 9.787918809921512, 11.814303494268849, 11.41729393313008, 14.974990564007914, 16.209192775910903, 8.964904546737671, 8.609887880663718, 6.798686875450996, 5.880412949669746, 5.614272779034031, 6.8261297383616055, 7.160931489159984, 4.80850713868295, 7.244126921699894, 4.6960415090284044, 2.378781452294319, 2.1204467983015123, 0.854821437068524, 1.386386619940881, 0.9108600332852334, 0.38485450369696467, 0.424083476105044, 0.30272623163557827, 0.07916770995624604, 0.055472372970994444, 0.1790560911139173, 0.1301724649965763, 3.235073349168224, 30.90795728468126, 74.39335146257955, 58.21569258166898, 37.99954960423131, 38.66102987720121, 37.58488447435441, 77.70848381903865, 80.57397134842412, 75.15893536229288, 81.7956719859954, 95.55824910440754, 98.85143972212269, 73.70737598788354, 26.15912606639247, 0.2066728406615796, 0.028604307745192802, 0.1279497451539482, 0.004442926916864611, 0.05566563397165268, 0.029956876195126006, 0.05273838136946002, 0.01770363117928707, 0.05762123044640307, 0.03666129083402696, 0.06500132697364015, 0.023103269763411056, 0.06150006384198224, 0.0231497215046998, 0.018324361580814567, 0.04210777377950088, 0.005611078372420443, 0.0191227286197846, 0.019570907292466973, 0.060304744514606656, 0.03660306432134202, 0.022370437715923595, 0.0727261515754846, 0.042973230968439774, 0.014410539034513697, 0.06151692160675603, 0.06150850996134743, 0.027335556975055127, 0.029868486885642333, 0.0027858203224417183, 0.008933721880067982, 0.08039908138133826, 0.025858981872818647, 0.0118506035669857, 0.08916581620372112, 0.06661304573137915, 0.0541774622134624, 0.05726984506773372, 0.0753509833086883, 0.05474957667531506, 0.02475878768300097, 0.05351838911132467, 0.05720426411097569, 0.05442566320961041, 0.09867453782428658, 0.005899179142884791, 0.011787619648290979, 0.025741672744193388, 0.02034741401251766, 0.02604401508917011, 0.03530822634216278, 0.07921734479286018, 0.10647788643836976, 0.10608912746031439, 0.15141280428055795, 0.1001933760820858, 0.15029947934371812, 0.11002437557063757, 0.11479963908993429, 0.1527505470139365, 0.20486200799144086, 0.21899999209469367, 0.16800809200973282, 0.1462681714685694, 0.17753954345901168, 0.1361794829849274, 0.13667771592736244, 0.21640586516549512, 0.10810847394168378, 0.16255065017650205, 0.10004393531069641, 0.19855122081935409, 0.09212491508092611, 0.12321580441728716, 0.27422282724611224, 0.12019610798527157, 0.11667291558678113, 0.12274374869922478, 0.14714607758627785, 0.11850704499069722, 0.17246863894885586, 0.20833735053818073, 0.12148043140769006, 0.16445128367312495, 0.21034093093006842, 0.10330694892834272, 0.1312667756311355, 0.12949135154485703, 0.14797947399558561, 0.20820516972772538, 0.09158478478991217, 0.20606760055788104, 0.16673270883339067, 0.16178212609262238, 0.15553887723194015, 0.4503074624846059, 0.8493239901238873, 18.045234641721173, 67.91194069770076, 111.86402828462663, 97.10017988758703, 94.5286661578763, 73.06751974167364, 34.953534987664995, 37.1840770782963, 60.55139341662007, 90.30994522956111, 111.84702088755947, 82.34164237976074, 51.41938609461631, 20.8947189008036, 4.576620046169528, 0.7719800597237003, 0.5321814852856821, 0.15969496550819567, 0.13754699589504352, 0.14085960604490774, 0.41784519149411115, 0.4354786662565124, 1.0586412130824983, 0.9230443246422276, 1.2274226402082753, 2.066641685462767, 1.1546841239736927, 1.6940247315552928, 6.808870329010872, 7.337389117287052, 5.144047275666268, 9.852647723690156, 10.42839086824848, 9.077450094684478, 6.758199189939807, 6.308611237233685, 7.340818739706471, 12.92662589780746, 23.189064225842877, 11.872777208205193, 21.82146122378688, 20.73108350076983, 15.495748942898167, 16.241114004965752, 14.064350551174535, 6.51683270931244, 7.725394877695269, 8.619910517046529, 7.9839884081194485, 5.75628170082646, 6.9541779641182195, 5.10563305308742, 1.9065631397308844, 2.038722867446561, 0.4381127829753584, 0.8420744081658702, 0.5386611182362803, 0.24426103659695197, 0.21455790787454576, 0.3247041603730571, 0.33929764503432863, 0.1436346063330289, 0.48169172519157016, 0.4097733520452054, 4.091829066315006, 45.1624329628483, 138.916654586792, 132.17121339613394, 93.61988436791205, 45.17694965485604, 31.97470468859519, 68.7911948850078, 72.2328079900434, 82.17357666261735, 90.00178813934328, 107.10445957799112, 113.58281089413552, 79.24875936200543, 22.438351992637884, 0.20000571535239298, 0.1517959554950076, 0.32238472192998857, 0.07273121541666408, 0.22659299594740714, 0.1623408646593171, 0.15604420414855405, 0.18348967175810568, 0.15787814203048908, 0.08533991948370973, 0.09282137327376874, 0.14779726764367473, 0.2437565523770548, 0.1491265068010938, 0.06866275993806702, 0.11415908233292642, 0.1880871798963316, 0.18935044356171163, 0.14102013210856146, 0.15914966412369283, 0.2300354886439539, 0.23344749104111429, 0.1406199890639513, 0.1269512031708033, 0.13755700100333462, 0.12240876143257465, 0.15049302379690832, 0.14823144031388147, 0.06755878127390338, 0.11760390393676297, 0.08558338222604606, 0.27885389003542166, 0.12341153988194083, 0.21519291815498184, 0.18849504510721854, 0.21081982781329464, 0.11003308599033665, 0.18855717483787768, 0.16461128879699016, 0.16959055386964353, 0.15377765641577784, 0.1388337324944235, 0.09921429273221763, 0.0917114497673127, 0.25991258061220573, 0.14349228251845608, 0.09157313259258386, 0.08351985545408341, 0.16836375598945927, 0.22483211220993152, 0.22425429805392222], [0.10106612642806384, 0.06308619909348988, 0.0372283567764586, 0.01944277142625182, 0.056030605919659145, 0.02279389856172906, 0.05959596379750198, 0.038842481050279834, 0.023632485216723818, 0.05713872911949312, 0.03267885936844734, 0.03339740387614697, 0.019882509725228436, 0.02856602824683632, 0.0888575347621114, 0.014000986514973545, 0.015140413982613433, 0.03890957503068832, 0.1396073127586034, 0.0401978169928395, 0.017952343539124536, 0.07365206076252846, 0.046052222605794675, 0.07157136596018268, 0.0446651897753679, 0.022484531190486687, 0.06473660529140504, 0.03776270693408386, 0.012187495519737563, 0.022691947580765814, 0.08510347410675981, 0.0070667435835686425, 0.00958458443487724, 0.028569561827387062, 0.06457655420226437, 0.05922371784465448, 0.06469696790220276, 0.03541404989758327, 0.05550215080861123, 0.02276721954976599, 0.06420220533806471, 0.016826042988067193, 0.15358340716169727, 0.6140768972616042, 15.057492717619866, 49.03719732838292, 75.03609457323628, 85.31346536451771, 75.32169019022297, 59.90031526934717, 34.200651722569624, 31.330692691187707, 44.50947992263302, 46.56808099439068, 54.207532328944055, 63.9528061497596, 25.213989788486113, 10.881317738563785, 0.6245948554527375, 0.3913356688234114, 0.08844648262545948, 0.18677837996473237, 0.05243275825294757, 0.08028683417867269, 0.07499852923736458, 0.07535834541364063, 0.22933899214671505, 0.271219548078314, 0.4696100283293955, 0.582598957323259, 1.731116992812003, 1.6595314082599457, 1.2989694913548808, 1.988403761098462, 3.3337332164087607, 2.828382888147908, 7.492122698214747, 8.645666760783042, 22.75927639776661, 7.832985981818169, 6.586809754371644, 8.244127842687792, 2.25185600499953, 5.0276548631729625, 14.163724780082704, 18.581734472705474, 10.017536320993978, 10.08475790100713, 5.305709233207088, 6.993133473780848, 6.730042945954108, 2.336484818689285, 2.78303710203017, 4.181593733449136, 1.2854331467420825, 3.949062391634911, 5.745289748714817, 2.6090601278889567, 2.1472792423540548, 2.3040262249208268, 4.362895488739014, 0.5893107455584311, 0.37365656586424, 0.09013674837807495, 0.11178668423165238, 0.045604551466362137, 0.04017066300636338, 0.05094896851768417, 0.05278982800401507, 0.0794261727001398, 0.05780458593020036, 0.10186352436580967, 6.186443134661644, 38.51319182303644, 68.42414732902282, 71.282731486905, 45.472045252400065, 18.3665414779417, 19.879707559462517, 46.18167261923514, 64.39916403062882, 72.53998448771816, 75.85669363698652, 80.05216275492023, 80.73274889299947, 37.31848493699105, 1.2457859516143799, 0.17550196408504443, 0.05873437152214109, 0.03362809593278555, 0.053829505078254215, 0.02618452902102182, 0.05239341580759614, 0.01888100681225619, 0.010553926019178284, 0.011576357496631964, 0.034315050804927465, 0.06111808091161713, 0.03183163698732613, 0.010015542408631695, 0.029051773956105597, 0.012372207936770734, 0.014655383607943454, 0.04982838489776177, 0.033110986583896225, 0.14471714985707115, 0.024234153435475404, 0.06326067178780514, 0.0507481309074548, 0.0650801727428071, 0.027205071134132244, 0.02230566689714549, 0.023077655613662738, 0.028386049295565294, 0.050354606862510407, 0.04321959718400913, 0.020031303152321808, 0.07981061860318146, 0.044409622843827934, 0.07614756919323437, 0.046119588547416275, 0.010543561807172674, 0.040254227877143896, 0.03493095102209238, 0.038979518858175126, 0.012644693920118435, 0.012525375725911751, 0.043388741736811016, 0.028170809232359453, 0.05840181658465055, 0.045261547089584415, 0.02759720281427426, 0.054701424218834414, 0.009253010089929787, 0.007670594674099478, 0.019008656212639426, 0.10645254424983457, 0.022873663636405143, 0.03403587304356118, 0.010085009346385638, 0.04002659634176282, 0.04418025228885874, 0.02312543268706049, 0.0671217510957391, 0.05885897189258568, 0.014493198963933656, 0.04303603485647229, 0.026344296657630516, 0.01456996480438618, 0.07193838336294697, 0.031085247098798716, 0.02901600531092094, 0.026945939978524566, 0.06507315537742069, 0.02229003870349017, 0.026487369323149327, 0.06050542124637193, 0.009266356299180658, 0.03471366933456833, 0.0776948293130244, 0.014183356618178228, 0.027519841340460607, 0.0712832402918608, 0.018985631440075177, 0.024757219117976004, 0.07738521487842645, 0.1214566520385204, 0.023708574984583165, 0.049942918872881326, 0.03746177993654724, 0.07238483642257991, 0.010918059100907658, 0.017353697537234234, 0.04035378100290414, 0.047310020233834946, 0.024630611597169793, 0.053679991528512015, 0.06389893028104017, 0.1278488743569582, 1.5903883571586304, 27.610975696194558, 67.6926645155876, 93.97933037050309, 95.22773450420749, 88.36069199346727, 92.05940861855784, 62.282072574861594, 42.763327014061716, 19.793550737442512, 31.775309039700417, 46.818049723102206, 54.23125090137605, 34.464560554873565, 13.334798524456641, 1.576513462970334, 0.4495455114351165, 0.15174828950435887, 0.0657519629044879, 0.10606083583327071, 0.4141267539272386, 0.5547746439133922, 0.9936271307449188, 1.4338357770635237, 4.109287535951984, 2.9546594283273144, 4.141495833473821, 5.77189322440855, 5.265736849077287, 6.073722550945898, 6.358290506947426, 9.37181907315408, 4.906031970054873, 9.317010814143766, 6.57149633092265, 15.716736258998996, 14.831072918830381, 13.332351946061658, 10.861738247256126, 10.32284478987417, 11.100948895177535, 13.344181814501363, 19.019065018623106, 19.781981706619263, 13.693688531075756, 10.463281331523772, 10.196287555079307, 3.5376057605589595, 4.310932909288715, 3.5510857211005304, 5.194976310576163, 5.453596807295277, 3.522031499493507, 4.81317279800292, 5.957707176285406, 3.3743527916169938, 4.180134611745035, 5.36780329481248, 2.8644860992508554, 2.1832787557955715, 1.1705165260261106, 1.2613939205485007, 0.5110773564346376, 0.3113637504077727, 0.21316715185680699, 0.04270412343283815, 0.04550096871812017, 0.01760095433001557, 0.09192014743964519, 7.520884458095797, 41.987415513684674, 63.62468027299451, 51.08792228083457, 40.640175496378255, 32.881240921635786, 33.17237492530577, 71.66232278270107, 89.75228617268225, 83.43138663999497, 85.62947503982052, 90.19530219416465, 98.36361454379175, 63.69729511199459, 3.9494051087287168, 0.3775288032427911, 0.06322134083377258, 0.07257027566553124, 0.04446106947838299, 0.05030493755193968, 0.04598097642883659, 0.03510868342052545, 0.0174569049023933, 0.021425452939565146, 0.032456686209526756, 0.018471119129249168, 0.052177612669765956, 0.02127051548731904, 0.02571400930924762, 0.029562386879397017, 0.05803727747632131, 0.008993363740193027, 0.06255691660748375, 0.05575917713764695, 0.015710000354315967, 0.07694921891895995, 0.03276671433160382, 0.042694780990601554, 0.04075130019637366, 0.01631245189797013, 0.020120745832701365, 0.0535874059724231, 0.05359514346045833, 0.03023795768498413, 0.049092090132856564, 0.041940739798930385, 0.05180061314134829, 0.10470465336355472, 0.02641261637871785, 0.04859781403455043, 0.028542472958384503, 0.0646116410291964, 0.0343632185831666, 0.0450039844990017, 0.06174155007747393, 0.07040982344938863, 0.06619881432984145, 0.0038295753784627928, 0.03129644796342379, 0.0270779024539215, 0.02935707914612947, 0.040122380314935605, 0.021531136683939446, 0.04368127241069752, 0.17869458954420783, 0.13957251704508258, 0.2446165013938181, 0.12358068443474271, 0.11526037202847582, 0.12164039056627982, 0.07760767148987902, 0.19181807405285298, 0.10196349117904903, 0.1407710616026194, 0.11558723110224932, 0.14617924398231893, 0.09035464676637804, 0.25355418873650415, 0.17161687175112386, 0.1253819716493449, 0.1389442176948632, 0.14502868717235906, 0.23282783316268077, 0.24314503035237714, 0.2677854210619004, 0.23810438631523043, 0.12773264349708635, 0.21267719266395416, 0.11186334665023512, 0.13169851214174302, 0.15429465851235777, 0.08029767432280126, 0.21631162102905013, 0.15998151303539354, 0.29500268640056737, 0.12045041853261572, 0.1833526492719689, 0.16211143664775357, 0.2261687670984576, 0.1903102138350087, 0.17214512001843224, 0.1854668221166057, 0.23976874297424672, 0.1236841292871583, 0.1620146337776415, 0.12430315131261466, 0.29002164400392966, 1.866707078391506, 28.913316342138476, 76.13364435011341, 107.8712829466789, 107.43011828391784, 96.87241569642099, 81.42720453200802, 47.27064809491558, 40.31521104997204, 61.547161609895774, 66.59034513658094, 78.93616999349287, 86.29707028788906, 42.2054639939339, 18.14955399882409, 2.149188210887294, 0.7892038000206795, 0.21750558438079975, 0.19771367221349673, 0.3170688378234064, 0.3556295057698604, 0.49223946888119946, 0.4785381089295111, 1.223600535623489, 3.2308648911214646, 1.7074246512305353, 4.013995268652517, 7.716056694907527, 6.211672800202524, 7.036378095226904, 7.8240694538239515, 12.156121384712959, 13.88334591542521, 21.520554634832568, 21.964143322360133, 45.704418228518584, 26.365325066351122, 24.229304252132295, 21.053933789653165, 13.427553753699026, 14.45395173565034, 31.478448375578854, 41.51777836584276, 27.425867280652447, 28.78644531772983, 16.21725618839264, 20.042815400708108, 16.508934420924035, 11.645098328590395, 12.342360423457238, 13.203049052146174, 10.471403579558096, 14.770769419208651, 18.502802656542872, 13.11810032013924, 8.943282481162779, 7.808567756606688, 9.556007692890784, 2.866335006490831, 1.2601151052982578, 0.7628378728705069, 0.6629690575984217, 0.2714185164340081, 0.37396860879755794, 0.3034495718536839, 0.35503063951769187, 0.24575225738508089, 0.14592206826613796, 0.36614047723912424, 10.358363812969579, 61.246806113950676, 100.58224047383955, 95.1276905305924, 64.30953394982123, 28.413969201426355, 25.72239172074103, 65.01028891532653, 86.2053103600779, 92.69559352628647, 93.75122885550223, 100.83592368710427, 110.413190626329, 62.04593020100748, 2.5940859894598685, 0.44711413222455215, 0.1716120607189594, 0.29700245167459216, 0.23123743463187452, 0.12341429013758899, 0.1414771801641872, 0.11306236618228498, 0.13437254204144403, 0.07228555142759316, 0.1708579390880562, 0.1376290898770094, 0.11025781788292432, 0.1154255252631922, 0.07384123085367103, 0.1889985946998481, 0.18035229656004137, 0.30279447474787313, 0.14031309424148453, 0.21171320890707357, 0.14702001015745825, 0.13534193437907005, 0.11410377078479338, 0.10600501100622839, 0.12048613355164567, 0.13378086169400524, 0.07882986518163836, 0.12113239766368944, 0.150519990091843, 0.1423629310222403, 0.10456382342043424, 0.1943698669633558, 0.15709089475773996, 0.18596837988063214, 0.2031472427470069, 0.11106064738405329, 0.11499630152097634, 0.17997112185243638, 0.11770269863547818, 0.13114983997037336, 0.0887247180986789, 0.22108888403782923, 0.1464316086663354, 0.1205433373369517, 0.11159038952281398, 0.09730601367811043, 0.12790515883675507, 0.129985953230531, 0.11763724408322766, 0.09382207562486011], [0.007375022631153585, 0.05009711321984088, 0.04510180626605307, 0.052557530993175124, 0.005564494480964758, 0.01799723820670718, 0.02703584614209831, 0.033097599197419426, 0.06387658732672853, 0.03420240906698089, 0.04542293883259258, 0.04928978295215676, 0.029566768902323903, 0.079939397983253, 0.02640838948859563, 0.04146298438671135, 0.058793498188137054, 0.056310247164219625, 0.029387655630407315, 0.05680881718534136, 0.020621464730450706, 0.03426998951322129, 0.030543274366326874, 0.10124680060412615, 0.03366857601870452, 0.03576922358103818, 0.011068305222227449, 0.048275160783481215, 0.07425322527846984, 0.03991068723881918, 0.08896882435487163, 0.029310273089175744, 0.0581451962822147, 0.05203399033616147, 0.07479049040064698, 0.054234734946681615, 0.0788324698805809, 0.05417550868925549, 0.0887929229065776, 0.14008722087788966, 0.232408614528756, 0.7003084281759878, 10.488590425060643, 52.50906759692777, 78.03714706051734, 78.20606000961797, 83.26556451859014, 70.71103034480926, 47.14978418042583, 17.576650650270526, 48.311837334786695, 45.23192951756139, 69.04469766924458, 51.98497226161342, 28.338981328472016, 10.153958316772215, 0.9443035709761805, 0.07129322241751418, 0.08854140091927783, 0.30884139059532073, 0.1039779500194615, 0.04270576286099611, 0.1010061800479889, 0.05342869936758953, 0.2209665857615971, 0.21486190688465873, 1.3408494957031742, 2.449834452521417, 2.8905701060448927, 2.9402559947582985, 1.828967135760092, 3.467471085248455, 5.3964145337381675, 13.82922407119505, 4.701963307396059, 3.9546404923162157, 11.856527809173832, 8.254326985728357, 10.400370436329997, 8.599661281031947, 8.562878274148511, 12.726914498113818, 7.550982765613064, 12.265205440982697, 6.657108924081249, 10.195060833807915, 14.389585641122634, 15.710029006004335, 9.862711544959776, 5.422495843902712, 2.909191803586099, 11.284218699701372, 16.383849055536334, 22.944220073761482, 19.594992514579527, 8.514346788006446, 9.448962288518107, 8.582185160729194, 4.965344580911822, 4.3935821517821285, 3.234011857740341, 3.70260099730184, 2.503807246685028, 1.3385030603216541, 1.1165465510660604, 0.30270940834476107, 0.10571032762527467, 0.06521078307301768, 0.09789218585337363, 0.07404347040480183, 0.038704734611054586, 0.03315487193063863, 0.14415667993166756, 0.14454432042135348, 9.966150329959008, 64.81713179619082, 65.86566371302452, 60.99630002052554, 66.91169708005845, 22.49840347997604, 21.005627839796006, 61.550530925873794, 53.78718368468746, 73.1881404692127, 78.14002298539685, 82.6390443309661, 53.69152099855485, 2.7471003465114103, 0.31261719282596345, 0.08793461331797224, 0.030939491210325114, 0.07988174220607167, 0.08872367621910188, 0.026927743475103093, 0.031039793187031345, 0.030933594248527964, 0.02015687453921043, 0.06758704225743009, 0.07616411669239884, 0.07041021415423002, 0.013625229006603122, 0.059286720915547306, 0.016766562006406246, 0.06555007575380226, 0.07456854706810367, 0.040740808622250636, 0.03850308111718586, 0.05949284453245421, 0.028966406863483212, 0.02913651477184988, 0.03260308178141713, 0.0387284143887941, 0.043090354320743395, 0.04484923856873666, 0.02465586377037389, 0.055749118403201146, 0.007683206875357898, 0.004143246248619811, 0.030929524406430223, 0.05576683035601051, 0.08955826772557152, 0.05648729008352084, 0.07547401702932774, 0.01776278848880001, 0.03482810754869734, 0.038256450601282625, 0.002271820572317548, 0.02321625624092356, 0.1344982877133354, 0.020623138632565256, 0.03944662181780704, 0.052673961035907275, 0.11896234636585559, 0.03418160211895743, 0.06166931564709353, 0.06647541037490291, 0.03915794839661929, 0.013796179611686499, 0.026613049877567158, 0.04537120874550554, 0.12865364972141483, 0.1315688440996793, 0.022471394697805087, 0.011901961143819556, 0.05609309188120308, 0.05738715611157879, 0.00947647219178297, 0.04057517658258158, 0.0027765128329666636, 0.025397023193598278, 0.04068836990383364, 0.06017910992546428, 0.01255651145437432, 0.12111749725356219, 0.01733916101887101, 0.05592859748210158, 0.03417882505023191, 0.050459281286044474, 0.03018810642853139, 0.06929981567326092, 0.003952252389412493, 0.03239628017669724, 0.032670367283806685, 0.09701280884685055, 0.044391868756182735, 0.026760339857109135, 0.042438612680041024, 0.011143457489989458, 0.1292319235301787, 0.062288992677725134, 0.028418692302018888, 0.02642125018962449, 0.10277454080360551, 0.07382348059646546, 0.02412269147293222, 0.13807660779885708, 0.2813342069425891, 0.9308220782587606, 18.06883358186291, 72.12662942947881, 90.21108581173806, 90.03796023707237, 94.93671032690233, 92.50131853165166, 69.63457507471885, 26.422905460480724, 41.40667330834174, 35.34279100356564, 53.294710497702326, 53.77855839267854, 36.188238282357496, 13.472187384482353, 1.3895512372255328, 0.1473044586037436, 0.04713306541464502, 0.17943723517800533, 0.011499637621454896, 0.3027257719828237, 0.5037870798860827, 1.2528305284438597, 1.6464205182367757, 3.800934082077396, 5.1926331846944755, 8.076525455520999, 6.251837380470769, 5.558901169607717, 8.199348593911818, 3.9078843689733938, 5.499763104223437, 0.8137259067546937, 6.289654912487154, 4.752689359649535, 6.430763160028766, 4.0886872478069805, 8.773254598340682, 11.913308039788278, 19.49344038963318, 15.762118081892691, 14.119692252528283, 15.251150919545083, 14.8206070546181, 11.628527295204902, 16.20821120277528, 11.563496358932989, 4.620854575787821, 3.4048296078558895, 3.4347670981960916, 13.68688419941933, 16.53184694628562, 14.890297766654724, 13.610091055593184, 9.001553212442706, 6.341077185446217, 6.763177658281019, 3.9684778788397392, 2.034927484008574, 7.078702920867551, 5.816621972668556, 3.525244410960905, 2.390346315599257, 4.122615994945649, 1.7744787950669567, 0.9004298381267056, 0.2608147257518384, 0.19986054169074183, 0.3002341169743769, 0.03316531370904657, 0.038165508303791285, 0.1947841213475312, 0.18427921729462762, 12.147943242903679, 47.06786547937701, 49.533812538270034, 43.58435361616073, 46.31169134570707, 39.14355985579952, 38.72099899476574, 87.5041404847176, 69.99504089355469, 83.36752260884931, 86.8658531865766, 92.70707822615101, 80.49644962433847, 9.839799019598193, 0.22471050341283122, 0.03100179139554741, 0.06911436876943035, 0.14626257902672216, 0.04971581976860762, 0.0954765497496532, 0.05086970140015887, 0.11356489687797525, 0.06396557226957333, 0.033308169954726775, 0.08301740136718558, 0.12247263784370116, 0.03432045938567289, 0.030964073056595463, 0.031162459185467135, 0.08332739884574568, 0.060163853284452236, 0.02816683898169187, 0.050863994045122984, 0.03482183328859749, 0.023300535488693465, 0.07061374073307361, 0.022657940937807004, 0.009480865706028718, 0.017381527596303535, 0.023310665086272265, 0.013218217983751768, 0.023745207393902446, 0.0464606432304267, 0.043295263688290314, 0.008379675601909478, 0.03416812280192971, 0.02893580931178745, 0.09910122581547308, 0.031917036638685295, 0.06807612044917, 0.04225842496981064, 0.01666062545301693, 0.013562901050693566, 0.01635287452729479, 0.0710260032886459, 0.014255290359048354, 0.05659497906303695, 0.004216593421710235, 0.04111667817097999, 0.028412486989832217, 0.09879872067681245, 0.02391601627271983, 0.09186909534037115, 0.16597523173737913, 0.17101661121893316, 0.21461660553130413, 0.16543043597090631, 0.2159958702301787, 0.17622078438439678, 0.12318485446514622, 0.12270303878692851, 0.2123166410432708, 0.10751068787348848, 0.1068545948533762, 0.11580679190134811, 0.11136948806984771, 0.1338842988855416, 0.10520352981984617, 0.1963965219235228, 0.1593871360584613, 0.14495885059718164, 0.14385511708115378, 0.14556383023098593, 0.12421328153821731, 0.2122981323590202, 0.19329617941571822, 0.12117909072267434, 0.1325545541100925, 0.15745147702194032, 0.1972782278373357, 0.1546666401648714, 0.11101683481566368, 0.1969792390422475, 0.11350666653485068, 0.2324746359860705, 0.18583131142921988, 0.12071494103199053, 0.14112418217043723, 0.29428498458958446, 0.180402199527429, 0.1445521498399396, 0.2144183879417758, 0.43856927944767865, 1.3000385823749727, 21.523053184632335, 82.3840275118428, 107.22449195000434, 103.15169888157999, 109.72542655083441, 92.93598774940737, 67.82686448866322, 21.25179186944039, 59.9689136012908, 64.94500890854867, 97.17479905774518, 75.3987333851476, 45.59549400883336, 17.56886278429339, 1.9209817724843181, 0.7939132795699182, 0.2040214563209203, 0.5574332754458151, 0.23476222049324746, 0.31857147332160707, 0.2678575865443676, 0.9752287631553989, 0.7678995077167788, 2.1194733150543708, 3.997078086099317, 8.009048431150376, 7.992862280338042, 10.353951146525722, 11.361232476849711, 11.299516923965948, 18.233849656197336, 28.77725128204592, 17.78175727013619, 14.891703936361498, 29.405358068404663, 24.556694684490083, 29.960202824684885, 26.953072624821818, 21.120955328787527, 34.17117511072467, 24.922840095335438, 28.95052786796324, 25.51042683662907, 25.417662782053796, 26.99155107621224, 33.34872076588292, 23.98561327688156, 17.249683833891346, 13.447839271637703, 23.400538813683298, 26.53292206025893, 34.42975344196443, 33.117567646888, 17.851612721720052, 18.77749800682068, 19.540395082965976, 16.635358295133038, 13.858518292826991, 17.352328338930686, 14.006659350087567, 8.992011066406004, 6.189286853036573, 4.283932783911306, 1.0682587421709493, 0.4435007406338569, 0.215775681238982, 0.2399551934532581, 0.2847886506107546, 0.1040878223495618, 0.1459828037167749, 0.29847619033628897, 0.42105938998922227, 18.48498332885004, 98.07618325756442, 87.44957247088033, 82.31356605406731, 86.5933661307058, 29.899810091141735, 29.850025407729614, 81.3056424356276, 75.07696567043182, 91.4697273315922, 96.87679306153329, 106.94896113487982, 84.32243931678035, 6.447536195478132, 0.31429792844480087, 0.11062006255792034, 0.18613645957121927, 0.265554205304192, 0.16793609506660895, 0.2488148930452524, 0.17228304648831969, 0.12940265388498384, 0.146898906978388, 0.20653604800182007, 0.13659563726715504, 0.18913109726723165, 0.1366267557586393, 0.14539731335976433, 0.12466878975711523, 0.16548928684524952, 0.1853439416135511, 0.10704978639560361, 0.13549685267911804, 0.14939152725761937, 0.07632815909962501, 0.12995003902864072, 0.11219869397820965, 0.08685872709799199, 0.20555832062757787, 0.10114253603763158, 0.11039221268748084, 0.08427563949578232, 0.10614227097962173, 0.07326467308185755, 0.10802302449460953, 0.18873725146535905, 0.20739638006254552, 0.14378331932089022, 0.20378329490702, 0.11127606364748172, 0.07832518177888087, 0.12258931303456908, 0.11834307153138424, 0.21067053259861088, 0.20832444961753585, 0.08094665038609698, 0.12753059546793663, 0.08574830563438517, 0.17361155020133143, 0.16732068131527594, 0.23407009069717702, 0.11834961392225758], [0.032916116798597, 0.03874300070287239, 0.027684494702806397, 0.015851782161682364, 0.053021324452974146, 0.04252450645811135, 0.056905757951279806, 0.05016069085667691, 0.04511178456126683, 0.009664718189366884, 0.030992914351724812, 0.03993776461650287, 0.013266854990844526, 0.0634859744158964, 0.05588206530158078, 0.03973550208273434, 0.022407001177329692, 0.002340743108840299, 0.09530136842400798, 0.023716728075317318, 0.08624858403157803, 0.06306238525036363, 0.031353657494389245, 0.0163158648196728, 0.02359456194925212, 0.06465105625290064, 0.07123719840761154, 0.08540991693735124, 0.08186390277959647, 0.0736916215429383, 0.023141288791873285, 0.032096358669561245, 0.012035814898779557, 0.037235500546352523, 0.05482238184119906, 0.010174506610529798, 0.061739343744252, 0.044121432058032484, 0.1428070015484287, 2.1306133366400197, 10.296821824965939, 31.361134206095052, 80.1478607423844, 80.97282932650658, 76.54747793751379, 64.56467628479004, 48.041668399687744, 25.36343405323644, 25.80528316959258, 62.808321291400546, 95.24822496598767, 57.920510691981164, 20.991913272488503, 9.457767028962413, 1.1941606959988995, 0.18872862531533166, 0.07014648072541722, 0.09191979503920002, 0.047989724083773555, 0.07214574804229122, 0.0978187103605559, 0.42609638744784945, 0.150682891028062, 0.8194149369674345, 0.7166063665382324, 3.4536101645038975, 2.9046957867760814, 8.620745001300689, 7.684919449590868, 4.064789472087737, 6.7574970856789625, 4.548404476334972, 8.747946485396355, 9.243787027174427, 27.22316311251733, 19.218244937158403, 16.00791536992596, 6.479643737116168, 10.569388308832723, 11.33550565088949, 15.016835389598725, 5.3427721992615735, 10.208150763665477, 6.077231601361306, 9.850690460974171, 7.55932564696958, 21.18411529448725, 4.60299063113428, 5.6890674752573815, 7.802139482190532, 18.159869832377282, 48.80420854014736, 50.49719764340309, 54.55509747228315, 58.20009723786385, 46.551646263368674, 33.610346778746575, 36.392938936910326, 23.836576938629154, 15.093396132992162, 8.296646418110017, 8.525385318263885, 3.592762620218339, 2.382997509933287, 3.3367791819957, 3.589564907935358, 0.3943608887493611, 0.32501917572752126, 0.15550012850473005, 0.08577878061201304, 0.017528323449134346, 0.03894584163302376, 0.07897854752598271, 0.023873693745342955, 0.03425665575289919, 2.074596252172224, 32.979708102441606, 69.78569615271785, 78.3711290359497, 49.81516807310043, 33.58662428394441, 15.748970297075088, 31.47121160261093, 49.096421195614724, 69.69405389601185, 78.33448625379994, 83.161331453631, 64.29972802439045, 6.181841704153246, 0.3503242243201502, 0.03808609179912075, 0.08072704362172274, 0.09507750221077474, 0.06038642097865382, 0.04885778214121538, 0.04117278645055429, 0.02463866126603417, 0.03845178770021566, 0.04348464062317245, 0.010751825682218037, 0.06517637806433825, 0.025096753116456733, 0.03428642976007635, 0.04196544230404881, 0.04354718021087108, 0.03249888999327537, 0.023640923675209768, 0.019083750066197207, 0.05885927066687615, 0.024274491795128392, 0.02680165497886558, 0.04567734897136689, 0.009274336062521945, 0.030577198654833822, 0.024982067838972135, 0.06789431246297975, 0.09324335748510015, 0.0782021097538452, 0.03003598434940702, 0.11398482031279034, 0.04779004709674947, 0.11470994551575954, 0.05229192830982709, 0.04767380091511915, 0.042857042243403774, 0.04731837825308885, 0.006860947948054321, 0.07322843712303909, 0.02050732720583197, 0.007919285487714074, 0.005084723299894963, 0.045472975865366964, 0.09528676678817119, 0.026286248260387973, 0.007483494935572268, 0.022127970887888825, 0.06964610273679418, 0.016069705447843, 0.029043934961420395, 0.06833973130391491, 0.019211974032523654, 0.032923743203883214, 0.07350346268785578, 0.03395128927584137, 0.07391567161727337, 0.02946255413154441, 0.03838391997100365, 0.020068006424774087, 0.05013633692156404, 0.04994986729035455, 0.05674894741405884, 0.09063878877749366, 0.01718253817319149, 0.019040906599031824, 0.007469362049784152, 0.07405812566679332, 0.07058036994309196, 0.040356849185040886, 0.050834951651913506, 0.05434181488629791, 0.015357107697655598, 0.0369638879032385, 0.028641792427327846, 0.029053445943000338, 0.05046215411576052, 0.035229024342111045, 0.1072022149098977, 0.021830816873379295, 0.022976202589850274, 0.023192609021920833, 0.11352432486150535, 0.06853191978147916, 0.056128454499787865, 0.018578296745075815, 0.13464942153903747, 3.9136375054236385, 18.40736354551008, 52.228873083668375, 106.26012232995804, 100.36935775510727, 99.23750292870307, 83.55547474276635, 76.19773587872906, 47.81026424900178, 24.107718621530843, 33.965913557237194, 65.53498045090707, 52.54266269745366, 29.709565331858975, 14.162591215102905, 1.9360235717988785, 0.1274063130239806, 0.15262115476352556, 0.07487535762089877, 0.02048618700956145, 0.2707900485444454, 0.6641822344353122, 1.4832714921043766, 1.6799089793236026, 5.273540894831381, 9.232531785964966, 9.282534160921651, 8.184606365619167, 8.864729173721807, 6.8507249605271126, 4.63386066498295, 4.422559642022656, 4.432015005619296, 6.842467390721844, 10.801679895770166, 22.51592862990595, 23.7285077956415, 21.768668082452592, 12.142719626426699, 7.0655968112330285, 8.708513917461518, 13.70461723496837, 15.767162249934291, 13.710052659434657, 10.787995726831499, 6.700695772324839, 1.959253931718488, 4.456146897808198, 2.415244786008712, 1.2613213567003128, 5.8936303565579085, 21.28584980964661, 50.538817913301536, 57.36178475041544, 61.105110491475756, 61.92583899344168, 55.35988153949861, 42.86931337848787, 38.611133406239176, 27.5030634480138, 16.75249791914417, 9.306567503559975, 7.203812801068829, 5.953958861289486, 3.5497655983894103, 5.474398116911612, 4.5042763410076025, 5.75293444818066, 1.2878096127702345, 0.8414625184189889, 0.42979561152958107, 0.4388982376023647, 0.21184054804184746, 0.17701264350645005, 0.17061032414917024, 0.09950749756347749, 2.819378842269221, 28.401860844704416, 51.301405122203214, 60.730116213521654, 28.37746370223261, 30.469310783570815, 31.278876220026326, 53.40527426811957, 66.63163200501474, 95.0824656025056, 89.29751088542324, 91.94258474534558, 85.31176305586293, 16.282717604790967, 0.256814444437623, 0.045779005008479284, 0.16413868915650154, 0.024113538637456876, 0.050015869595470934, 0.04857399636098454, 0.050648075994104154, 0.13523694968992664, 0.038763700398586454, 0.04053712882582219, 0.027812670788637577, 0.031899669425441854, 0.07345584266248249, 0.05321071287917514, 0.05842171571848374, 0.029580232897593133, 0.02215455605408117, 0.044695239574197805, 0.006729513594520189, 0.05261390357308331, 0.012254605779514439, 0.03097075142807538, 0.04263272020785559, 0.03922126173312145, 0.012349371813357839, 0.05441366627271618, 0.012881745464138448, 0.06918422832724548, 0.05339922796514246, 0.03836636123577914, 0.05910837564677481, 0.029152185100341038, 0.0743380158899292, 0.04645317770360459, 0.09080436336056841, 0.03359312401904214, 0.08097637459755906, 0.010943186784824057, 0.0354255641990852, 0.05162687206100072, 0.04853666489643436, 0.024793049050194603, 0.06001288033721428, 0.044582498244821064, 0.0188530350269209, 0.022896226840995015, 0.03482014789516407, 0.15646080276177776, 0.15332629273255027, 0.1513016142792279, 0.22245556957298712, 0.17003034962521446, 0.11479692713868235, 0.0909840492832084, 0.14063996863701653, 0.13082544769971602, 0.12753236513104171, 0.14130082672401784, 0.2066124576113878, 0.17612572819475206, 0.14498832966050795, 0.2780125109899429, 0.19571822767536487, 0.15560964843438518, 0.11507619683059955, 0.21430494564194835, 0.13924098483497097, 0.18268160221557464, 0.13895364057633186, 0.10985660997609939, 0.10397110119341843, 0.11649026490387418, 0.1982573494916001, 0.13621406419382942, 0.1705175049362644, 0.14314639382064342, 0.18832523405792254, 0.19739301845190987, 0.09750049275856826, 0.13008534547782716, 0.19464876893306934, 0.2276671431477993, 0.2428515267468268, 0.15278224773224325, 0.15913844859648138, 0.34541467324860636, 4.682067084696985, 21.389198380131877, 64.99949847498249, 125.57954480571132, 112.31166485817202, 104.97831529186618, 88.55726549702307, 69.50296386595696, 40.495036032892045, 38.10552420154695, 85.91680434442337, 127.09620768024077, 80.23783206939697, 35.83291861318773, 18.928560249267086, 2.6223476471439486, 0.595963207944747, 0.3721398649917495, 0.4420331919625883, 0.24493606731055245, 0.1807806316402651, 0.3951518285659052, 1.0557510391358407, 0.9725208568476862, 3.7242997942432283, 5.88678680119976, 13.724052579172197, 11.154367654554306, 20.410806286719538, 21.01493170184474, 17.168053427050193, 17.557917410327544, 14.723230292720181, 15.76380862343696, 19.111062249829693, 38.40341252665366, 29.504288088890817, 26.59603495751658, 17.548566479836744, 27.999394286063414, 32.36889896854278, 35.493621826171875, 19.34822443992861, 30.219108673834032, 23.24161418022648, 27.47414185154823, 23.130187488371327, 46.00167112965738, 20.981285610506614, 16.6247796627783, 18.460111579587384, 26.70828142473775, 61.2652490985009, 64.22141790390015, 67.33732915693714, 66.45048910571684, 56.42846461265319, 42.722271565468084, 46.599448188658684, 32.867918591345514, 23.342454394986554, 16.231198253170138, 21.484604151018207, 21.503164806673606, 12.089664666883408, 16.005527627083563, 10.235269050444327, 4.678779157900042, 0.6737287931384579, 0.700986446632493, 0.23303398742310463, 0.332134906803408, 0.30983871449866607, 0.25401903556719907, 0.20617695194819283, 0.3278735886898733, 3.8259166382974197, 53.785214654860965, 103.88765319701164, 106.46230482286023, 64.95198680508521, 48.01851857093073, 23.53186368942261, 43.88503466883014, 65.17700141476047, 92.22064941160141, 96.9588255113171, 102.13232978697746, 95.47012129137593, 11.342450207279576, 0.28196221517939724, 0.13628046869510604, 0.35312583850276086, 0.19091792074182343, 0.13967549458386438, 0.1691296600526379, 0.1953533246752716, 0.20469909173346337, 0.11549518563814702, 0.24592680285774896, 0.11242162556417527, 0.2176039960355528, 0.15819344849836442, 0.15115621079119945, 0.18945624030405478, 0.18003732717085272, 0.17737082025456816, 0.14927459159685721, 0.16778860781942645, 0.13113582056135903, 0.07634971681381426, 0.09884906797519616, 0.11684276494047335, 0.17105601878175813, 0.1117280018966525, 0.10374312108803181, 0.16045763668033386, 0.21106563478467927, 0.16239617620745014, 0.18302192911505702, 0.1754523675528265, 0.16298664613596855, 0.39825803930720977, 0.14657589366599438, 0.15463081789353203, 0.10796914553089489, 0.2209387920917042, 0.04608411867652209, 0.31864762246128053, 0.14127428943832077, 0.1417204743671802, 0.16730205005695745, 0.06272182852450399, 0.16750394486852233, 0.12543359831456216, 0.08331976861001984, 0.17849954355868602], [0.0366433835287969, 0.09317036462767471, 0.0447283307420871, 0.008968722522108546, 0.026647278686024012, 0.029622578407607736, 0.027216708009702065, 0.05706824903045932, 0.09085006050525174, 0.038636254011503154, 0.021346559289902933, 0.03780085045183378, 0.05816036482311546, 0.020573471237214345, 0.014427689827918528, 0.08659957487496638, 0.04046671385426195, 0.04566673099273636, 0.016674635285932212, 0.0023065875575412065, 0.12579080213101643, 0.007701536486556213, 0.022173472680151466, 0.020106628747476686, 0.06993176160199989, 0.04607121009499796, 0.05221081108996465, 0.06240240816447524, 0.040419576464280974, 0.05803661097982719, 0.03122286138785703, 0.022478764463636666, 0.02081740129318449, 0.03667118102912942, 0.03981173549207949, 0.13723331353356763, 0.029188336789487835, 0.05483746611242814, 5.698843492615608, 41.69117458405034, 69.41782489899667, 80.71680053587883, 75.66520352517405, 58.64916155415197, 28.213485094808764, 25.764765085712558, 28.136789029644383, 43.32490844111289, 56.49852991104127, 47.266039309963105, 29.56359628708132, 11.628873444372609, 2.958213095703433, 0.05360862660792567, 0.10142526844696653, 0.01836618806626047, 0.11142299931135871, 0.081356001807557, 0.06989289030072189, 0.0826864820274134, 0.4415084830214901, 0.8709410301619961, 3.1333317247129258, 3.9908535297839878, 10.043746579077936, 9.151816271966505, 11.374223366860422, 8.308007563314131, 3.7720058666121576, 3.1343064337007465, 6.0437085743873356, 8.629499731525298, 25.156323102212724, 37.41368086107316, 53.38586245813678, 51.96384637586532, 53.342363372925796, 36.11467815214588, 25.168237301611132, 9.477693650030321, 20.833602489963656, 16.793072877391694, 12.80472549699968, 13.005813648623805, 3.7286305812097367, 5.583598863693976, 10.399386902009288, 12.689343094825746, 7.58187682397904, 21.86805505906382, 70.38475190439533, 85.15724520529471, 97.25854950566446, 101.21810374721404, 109.51132005260838, 106.87156492663969, 101.26668622416835, 96.33182679453205, 77.57866121107533, 61.674877905076556, 51.3715841693263, 35.57046105784755, 16.441013678427666, 6.96291700486214, 5.917498469352723, 3.682221832775301, 4.899780202296473, 2.2833305741510084, 1.089907774040776, 0.5629215906223943, 0.09585562537634566, 0.049044493090121016, 0.08068661716195845, 0.055242638524261214, 0.08292409185800823, 0.16982220353618746, 0.2433887075993323, 9.305624173533532, 40.31586216342065, 90.91908147258144, 81.08848433340751, 45.18590834832961, 40.90251930298344, 76.90562955794796, 45.17997380225889, 55.805498092405266, 67.82031413047545, 83.50824156115132, 88.26638252504411, 20.52043849422086, 0.24012593912982175, 0.13823823702912177, 0.0983202834463408, 0.023152550284360206, 0.0013797506859015314, 0.02791988862408025, 0.007906781017570006, 0.03850808750177103, 0.025098281461865674, 0.05452973625412392, 0.05073550960890228, 0.03293449141746087, 0.04478984760240682, 0.032945871653576056, 0.030612768117158167, 0.022992202336148872, 0.05492550110624683, 0.026512144606620557, 0.032987148470936284, 0.03222509783001677, 0.02394712327288524, 0.06418516371218909, 0.03053700585188645, 0.010717454189885288, 0.014047087771036934, 0.03577847026228424, 0.017262657563532555, 0.05189239430511671, 0.025276808676520185, 0.044521000536699454, 0.025844719230888352, 0.047028754882874994, 0.06052657676440093, 0.022000091661128308, 0.02221612654055559, 0.0186829749990495, 0.031044196277376146, 0.06300868248687157, 0.011706812694037875, 0.06367814374126254, 0.03756184251077714, 0.06986995362826894, 0.04958700208413986, 0.046980227043311444, 0.02330295632653419, 0.01116299273205861, 0.06862234880006121, 0.09505435103370298, 0.016082158207052177, 0.028395079556972753, 0.04805674145538961, 0.02652343291218483, 0.023335411641446334, 0.07197197631842668, 0.060311980215051485, 0.0595173440242727, 0.03835621440122205, 0.02978467686672605, 0.06561376064294769, 0.04970191527278193, 0.07894962770684112, 0.02765729666627463, 0.023534502571208343, 0.041112173573985215, 0.06396755643729722, 0.044068656260928804, 0.0314885598321956, 0.055100195966060125, 0.033328157188671256, 0.046650874353344404, 0.09130823471012617, 0.016874034566083745, 0.038302212863439516, 0.03162861028085313, 0.07824490342529551, 0.04490447733851691, 0.008470451275277282, 0.04964045203861691, 0.032219509218609145, 0.02797025890510169, 0.021858671830306133, 0.11349413333640945, 0.029004935340415088, 0.10143420869304288, 9.773785529598113, 53.37979062911003, 85.79768980703047, 96.56659633882585, 92.40405944085892, 74.16667769032141, 53.28709325482769, 49.63105201721192, 31.765832593364102, 33.48019076931861, 48.88536237901258, 49.99945671327653, 35.67783986368487, 17.36629786029939, 3.515674808332997, 0.03469982612577658, 0.3161677345633507, 0.031866871286183596, 0.1243699005534572, 0.21659628397995428, 0.6582207833566974, 0.940093151744335, 2.039801886966152, 3.6114752677179154, 6.262196850392127, 9.379798154677115, 12.507874638803544, 12.592724330963629, 9.222127699082899, 7.093010746663617, 3.073810983088709, 1.9887573872843098, 2.241079047802956, 10.328833268534753, 25.766914544566987, 44.66501366707587, 60.923053679927705, 59.76458164953417, 55.060075175377634, 42.63276307813583, 26.423623254222257, 10.837144986275705, 7.479447068706636, 5.980639803794123, 5.085609353357746, 1.878350634248026, 1.6624508774088276, 3.4158737765204523, 5.31861775344418, 9.467295446703512, 8.21242577606632, 27.60833594106859, 73.51932971708237, 92.09471779484903, 103.86746083536457, 106.93617420811808, 114.55074987103863, 112.99509863699637, 107.01770459451984, 102.24645506951117, 85.75677948613321, 68.41330589786654, 54.45190383541969, 36.1446411378922, 19.8005796247913, 9.73505800770175, 6.1022881923183325, 5.448547245994692, 6.516182576456378, 6.150953039046257, 4.15696075847072, 1.5150140081682515, 1.0968084489145586, 0.14966160389444522, 0.35630844353187474, 0.05540982572241657, 0.0654447922903684, 0.3267345078770192, 0.378642603154144, 10.563443956836577, 36.45069583769768, 67.589262993105, 55.6398367881775, 36.69354938691662, 35.71801277898973, 75.23094223391625, 63.46453382122902, 74.65116100926554, 82.52582903831237, 96.3074218073199, 108.55279476411881, 41.176716512249364, 1.182160939901106, 0.16556782617924676, 0.031933471139880924, 0.059593669364168766, 0.026979709134226846, 0.06418504879900044, 0.11043525916794616, 0.012746874727458965, 0.03632504335274139, 0.0570325225201105, 0.039947574372373285, 0.008710841047427347, 0.051810472692933776, 0.020697142726050752, 0.027549904545829184, 0.02284537967024071, 0.048616422310231194, 0.05731274599149343, 0.04563334488099621, 0.04374629412327082, 0.0304285220561489, 0.03369995114964343, 0.06714726182361765, 0.018372090773717053, 0.03259829373189038, 0.017007218951719905, 0.08396630851371635, 0.0948703367142908, 0.028349725236635537, 0.04638393101612887, 0.05402098875492812, 0.10201126442200716, 0.053115308119524876, 0.06403911671030425, 0.09650357488182285, 0.04245479628744145, 0.042750383652145826, 0.003845544481244419, 0.04485045281809665, 0.011189174744480801, 0.03054195286465749, 0.016897988220256184, 0.018718416141646526, 0.04778952998740058, 0.008163286406817216, 0.034761021229168104, 0.18725482536660087, 0.2011161904421545, 0.14857765076862228, 0.10589238075960068, 0.11722338806477287, 0.1814854631741201, 0.13173981960262024, 0.12418519675491319, 0.17286029373926504, 0.0849806089254637, 0.10938116048853244, 0.14314493825358732, 0.21697482334509974, 0.1947062868144243, 0.10101636901738183, 0.17457682098592484, 0.13207853771746159, 0.16378274938512236, 0.13862318088931425, 0.19862856505618942, 0.21927489508544246, 0.19537989260448566, 0.1671463350254682, 0.1513071454340412, 0.17910043228297465, 0.19159940191574637, 0.09368320686682578, 0.15200954080829698, 0.15126675727867311, 0.11544011923814974, 0.12158876390106256, 0.16509288230970984, 0.16682131456271296, 0.22258692300848423, 0.13957800223462044, 0.29417788549777, 0.16048916885929723, 0.30077705880807293, 12.23364212820607, 67.75401038508262, 110.90135312849476, 112.9406169153029, 101.83619083896761, 80.23807525634766, 42.73031242432133, 40.19662211018224, 41.94260635683614, 58.26440841920915, 81.25407111260199, 70.33019958003875, 49.36800218397572, 21.482293874986713, 6.077990579989649, 0.4869666389159618, 0.49642846829468207, 0.18641824203152813, 0.4227468671817934, 0.21509680476400161, 0.4476942752878513, 0.895990695684187, 1.2532377194973732, 2.502079687772259, 9.09633630706418, 15.684714028912207, 26.076232656355828, 22.928316823897823, 26.789513711006414, 20.167211409538023, 11.304283584317854, 9.296961619007973, 15.356863698651715, 15.946151768007587, 32.829087126639585, 44.8763313601094, 63.759723555657175, 58.78002751258112, 63.46074088927239, 44.36616436127694, 38.99467845116892, 25.28412961190747, 45.62338206075853, 32.85057387044353, 28.024303297842703, 27.035358067481752, 17.97944276563583, 16.136424964474095, 19.961049672096006, 22.939566181552028, 10.262813894979416, 34.091131302618216, 75.49322328259869, 97.33505141350531, 106.50357600181334, 107.59709358215333, 118.34848280875914, 115.49906915233983, 106.84764631332891, 102.3376109523158, 81.234631846028, 69.16062724205756, 59.56259919751076, 44.65568234843593, 26.81888245767163, 17.888035851140177, 19.832839158273515, 15.394740066220685, 16.349982330876013, 9.962442709553628, 3.1845429251270914, 1.955915014109304, 0.7915954652332491, 0.15262478602028665, 0.35755453150599237, 0.1503302454347572, 0.30000597599052614, 0.45523628832832463, 0.938730311970557, 15.786628973099495, 63.15936165471231, 127.50721716111707, 102.82035273890342, 60.84000533626926, 54.63199161714124, 87.67538332170056, 53.61921602679838, 75.22337990422403, 87.7694574479134, 106.78957170055759, 123.45202769002609, 37.11798514089277, 0.47843606601799693, 0.24093439171631492, 0.19309713445123167, 0.11773677422635018, 0.16364356653103906, 0.19458636341075744, 0.18177358884244196, 0.09354503524880256, 0.13217373180293268, 0.19634502549325267, 0.10511948231367335, 0.14890339135402633, 0.14157176137931887, 0.16869075295905914, 0.14625908566578744, 0.07205626131185601, 0.10469571311747837, 0.1784135425283063, 0.1860018426011647, 0.14133091865768357, 0.14832781417475593, 0.1922480025959592, 0.19068875320015416, 0.11040329797974519, 0.20131355001320764, 0.18255361956694435, 0.1390518683699831, 0.23219780245375252, 0.1539270742045295, 0.13795921248534035, 0.15461825405157384, 0.18855550476620275, 0.22038929254537631, 0.1660988630065995, 0.20695710524676308, 0.16284867370080564, 0.11807759908298332, 0.09978665234220606, 0.20881227908595917, 0.13803151586363394, 0.16915567639854648, 0.17951548339859133, 0.16733640143948217, 0.2313091864268626, 0.12987709213649073, 0.154874142740042], [0.05041630758393196, 0.04012887291009388, 0.12945448739394066, 0.10237439775899534, 0.03275968547489855, 0.057152480397733955, 0.0393571465786907, 0.046831471920614286, 0.05003073170120197, 0.05424886160800534, 0.02818849437209147, 0.06549470291863527, 0.029739368511664293, 0.07757467608298026, 0.013666480926105814, 0.023790080994067174, 0.09907330191063304, 0.080432107431754, 0.01616492060073201, 0.026649486934465748, 0.07120773466604371, 0.12615745181157706, 0.05546391536031039, 0.05967905369376945, 0.05407156204924949, 0.14394980554859485, 0.01822273044155971, 0.03779556827559587, 0.06447390608129001, 0.018311445338411197, 0.05145859318755327, 0.04400931892075366, 0.05767252769381289, 0.0812468266174678, 0.16274948063636982, 0.04105603082045432, 0.26636956800376216, 11.390155053907826, 83.36187439580118, 26.815662191760158, 40.24312573094522, 76.27524975807437, 43.62151807354343, 40.78651912750737, 56.87046866263113, 47.813437446471184, 46.863745335609686, 66.76901694267028, 30.221283628094582, 23.397308741846395, 5.06213887083915, 0.19643995910882953, 0.1597762627587203, 0.03136378900718785, 0.07246846258039437, 0.242036271299566, 0.41861743876530283, 0.12712212504758952, 0.281435453122662, 0.4987862417774816, 2.1077670012750933, 3.084379074073607, 4.636442565148877, 9.641419264578051, 17.411214882327666, 8.972519828427224, 4.43623939829488, 4.363391668565812, 4.981743030009731, 10.179026184543487, 24.764892132051532, 55.81946957495905, 72.33234205553609, 86.36298179626466, 92.05525090617519, 97.38061366542694, 83.13858955137192, 76.9326860673966, 54.093767904466205, 37.117616438096576, 21.561612044611287, 13.967799448197889, 7.067121632637517, 7.961771122870907, 17.809225628452918, 52.651810492238695, 79.6272994625953, 102.29542193874236, 93.60313584727626, 57.97883633644351, 96.32958319879349, 104.82498984183036, 114.55114210805586, 108.09536795462333, 109.6081006142401, 107.85020412937288, 113.21643014107983, 115.43054534542946, 117.28495567075669, 110.85481028403007, 99.39055381282684, 80.53185293751379, 56.65220445202243, 35.93380589638987, 21.96899921663346, 9.939842012620742, 11.779658179129324, 6.764830447012379, 3.017962560538323, 2.1989648044109344, 2.3172823652144405, 0.7561591183466296, 0.5317600756402939, 0.4195162131180687, 0.025036850786437432, 0.07125497164745485, 0.0360856868416792, 0.09856731615840428, 1.6758631770649266, 21.956812412508075, 59.494287198589696, 77.27959617491692, 102.61248280925136, 168.9564246516074, 45.460191849739324, 12.910529471212818, 58.685847482373646, 74.68934920526321, 71.88052423538701, 92.4798474773284, 42.03079692779049, 4.63530017483619, 0.3181968563266339, 0.1135521644966737, 0.05072141359109552, 0.047393868557147445, 0.0541831887206964, 0.09565356202543744, 0.06706583433814588, 0.04130348488087616, 0.057746072134543816, 0.061850932111302694, 0.04467365121649158, 0.01203064476290057, 0.04553959487126239, 0.02339421080485467, 0.04091573330844122, 0.03591603284040767, 0.05167947548832144, 0.11855462671167429, 0.04290749296365727, 0.07828330741293969, 0.22372583528199505, 0.04219975412612961, 0.03635210157822698, 0.03855067432948178, 0.008731913253394587, 0.03577340259066513, 0.06668286698479807, 0.04989552484344571, 0.1064330626339201, 0.020701222144247546, 0.05150659242644907, 0.04569350193525034, 0.05292395850823772, 0.06202597554112154, 0.08718870414961731, 0.016994358250691045, 0.019695842826378443, 0.07796888194617727, 0.1311856928852297, 0.11381610476922606, 0.09355385292081103, 0.033197654110770074, 0.015031002262877602, 0.07007109767366802, 0.027789893079428907, 0.036420333199203014, 0.17011651919493753, 0.10888976105038198, 0.017737766141973196, 0.043051011875391974, 0.03440877017114432, 0.06710835987882269, 0.022968595336762168, 0.022348092846392144, 0.08012654560227549, 0.02297332209925498, 0.029598546229423057, 0.042176583796859755, 0.016209753981280713, 0.051480342423723596, 0.05195828552748408, 0.05190720661513267, 0.09168255293080885, 0.01812719161652269, 0.09933293676905094, 0.058579150617363, 0.0396007280646553, 0.016542546406027772, 0.018747391502162623, 0.024280699022534876, 0.011578283250151623, 0.12839229882604655, 0.091566605523469, 0.030266389123073993, 0.09379899339570154, 0.03539548375673833, 0.032172433115662105, 0.047327035046633215, 0.2355706884014991, 0.022996126621540998, 0.32757092267274857, 15.867378807836964, 107.78936816800027, 36.10235406506446, 48.90571163546655, 96.20398890587592, 70.3627944761707, 68.55196952819824, 53.74274323063513, 41.30975154138381, 46.997298117606874, 54.901831073145715, 38.67708806068667, 27.262388775425574, 7.570571572549882, 0.26277171267617133, 0.19799962219211364, 0.20516511833956166, 0.055604645712000716, 0.8894291219692078, 1.1441046336004812, 1.460118844143806, 1.612233262388937, 2.7335909681935466, 4.032441930424783, 6.097757364473035, 6.965338578147273, 8.148550958402696, 5.752457880204724, 4.667683262978831, 0.3917946167770894, 1.0209361427733976, 4.328537487214612, 11.528698071356743, 27.248083891407138, 57.829139078817065, 77.04590136005034, 94.65159323907669, 96.14161537539576, 103.46223292812225, 91.54036137365526, 82.91402601426648, 61.26595904750209, 39.99509857546899, 20.64547973294412, 12.092016127801712, 4.668092660365566, 7.416021852724015, 19.5867927997343, 54.270392233325595, 83.29062061925089, 104.20113686592349, 98.31993502955284, 62.68410767278364, 100.76236355689265, 110.96030635218467, 118.78312064755349, 114.9409943242227, 113.68595354018674, 116.30283340331047, 119.94238499672183, 120.4272448632025, 119.55920080984794, 117.93114262242472, 104.10954167765956, 87.32018916837632, 59.33331312671785, 40.98206104770784, 23.328014189197173, 9.83034218511274, 5.994900070851849, 5.846250576357688, 2.536491867034666, 3.251044259917352, 3.1605843526701776, 1.898034068365251, 0.6237367756905094, 0.3746445128513921, 0.0760347321028671, 0.1269118109297368, 0.04443622141655895, 0.19451281897002654, 2.49322640799707, 20.866452340156805, 50.69683844043363, 54.743371240554325, 79.81865621382191, 154.79605643979966, 52.839864607780214, 31.490421410529848, 78.96304607391357, 83.40733466609832, 76.86509578458725, 109.42873847100043, 72.95573219176262, 13.00304739705978, 0.22589133601755867, 0.10725414034940543, 0.03479573267301725, 0.07432055674613484, 0.0525202110199438, 0.09683218829694296, 0.033269654884333574, 0.08272611941661566, 0.017794050621770082, 0.057118343519828016, 0.012133755409459194, 0.08780437070996532, 0.0432113234344269, 0.031029931720226046, 0.034986067217804735, 0.027138394671642495, 0.052520352746209795, 0.11039568306577784, 0.06358023387409988, 0.013134563097640151, 0.1939287228930381, 0.07488782953230605, 0.0410455392463313, 0.057647783053858634, 0.016136117609998873, 0.041427771155271804, 0.05019013927648625, 0.02887430011234697, 0.1413669707554002, 0.03728157307411875, 0.052752408439353596, 0.032692844303505074, 0.04550724680865965, 0.06415756156427727, 0.05238393163909355, 0.07333971139404082, 0.07322545704101363, 0.06213268775853419, 0.057431064440958926, 0.23590666392157156, 0.11895444799935627, 0.047361217889814615, 0.0706887637234984, 0.06401224617636012, 0.08909835450110898, 0.11857507359837333, 0.2681047877957744, 0.16376007318256364, 0.13585194975378054, 0.24880357026573152, 0.24243212425180022, 0.17053320973871217, 0.2188321575522423, 0.13771881409470113, 0.18669548925132523, 0.11956974683750062, 0.13177746516321936, 0.17492988026670872, 0.1244054776766608, 0.15888119627150799, 0.14531520405603995, 0.208766145271159, 0.14946088885828374, 0.14943033727186342, 0.2316052947313555, 0.20443597117499, 0.1066570820647382, 0.12543653243131217, 0.150921895138679, 0.2313230372965336, 0.10148184404017464, 0.25635010322495816, 0.1913980433657285, 0.10885823653229784, 0.18796180194664389, 0.11412885250343431, 0.2777766171962984, 0.1466073645579238, 0.24512737478700378, 0.12023367693707829, 0.6922716142669801, 22.904013818310155, 129.0805269056751, 47.251153915159165, 60.97902590228666, 106.19548951425861, 72.6771576173844, 60.41229440319923, 65.78793018094956, 65.71993981638263, 67.84886114058956, 92.62322579660724, 48.920220482733946, 39.315132171876975, 10.715662317891276, 0.8134812489151956, 0.44641043450082507, 0.2905608779720722, 0.2661858294760027, 0.7841507453591593, 0.9143713513208974, 0.9902121559266122, 1.0666260555867226, 3.110474602830026, 6.961751080328419, 12.166687269364635, 13.958795647467337, 25.355189231134233, 33.231798833416356, 27.578880902259584, 18.548910117918446, 16.433484688881908, 14.500620095960556, 19.60605752083563, 32.86287834567408, 67.00526914288922, 84.33367298495385, 99.11374430502616, 104.23124497936618, 108.00304320550735, 93.87290862298782, 84.95225429534912, 64.72302236864644, 47.21206749639204, 35.603138323753114, 36.30137120523761, 20.214566184628396, 17.88697681119365, 23.02166335044369, 57.49581606157365, 81.06260453501056, 102.332425578948, 103.48932866127261, 74.03729438781738, 104.3281824358048, 116.99928160636657, 124.42782709675451, 122.44980719781692, 118.94912319798624, 120.57285893347957, 125.3070342156195, 125.56726778707198, 128.94354204977714, 120.38715039530109, 104.19524546592467, 86.2988510439473, 63.82157541090443, 49.31302232127036, 31.58817275877922, 21.50522405101407, 24.760571641306726, 18.04852354911066, 8.65442443278528, 8.757482747877798, 6.679428190954271, 3.88053392690997, 1.05367353125926, 0.909183526471738, 0.11627691707784131, 0.3003240556966874, 0.150760602987101, 0.23526197028977258, 3.875285060175004, 34.8466621675799, 85.28696583163354, 105.26170653681602, 119.5520934750957, 167.9803349894862, 55.21134922581335, 20.894901291016613, 75.04845003927909, 89.32398688408637, 86.40597097335323, 123.17081728289206, 73.53130863558862, 8.703327563501174, 0.3385337634432701, 0.2009728860350386, 0.17448467593039238, 0.25313035825327523, 0.20864628315452607, 0.19773489284899928, 0.2044245871084352, 0.21201910781523875, 0.12426613394411341, 0.2030410782824601, 0.20789694191227037, 0.18439503446702035, 0.18992631185439326, 0.28061549389554613, 0.12924061096724004, 0.12684651725595036, 0.09506123050326303, 0.17526009480559057, 0.1995060115211433, 0.1272471199533151, 0.29658643528819084, 0.15614413265739718, 0.1447383092055398, 0.22650242903299872, 0.07664899672231368, 0.13292596885754218, 0.12214490542969397, 0.14210612302826298, 0.3139654156421462, 0.11495658752298164, 0.21041066025293645, 0.11625810195842098, 0.10952847919637158, 0.20561027671060256, 0.16547390379972998, 0.2526486881317631, 0.19151243561458206, 0.1522941271504087, 0.2842016127561369, 0.34128613349410797, 0.2019721251581946, 0.14667701727199942, 0.1431976451027778, 0.16663330126433604], [0.01565744576510042, 0.11023874995448898, 0.052143969918571176, 0.25796196753940276, 0.10002776319461484, 0.12990932911634445, 0.0781699110783877, 0.21138944482851416, 0.06526816305854628, 0.06126843715807604, 0.05220709556353189, 0.04990213618223226, 0.03651571114577594, 0.08987476162972952, 0.07374259703341993, 0.07574593227717184, 0.008699521140736199, 0.10201473480030414, 0.059039224720289635, 0.2096502873445711, 0.16960619738505733, 0.4045051186075134, 0.04443328346936934, 0.28036182686205835, 0.18125074915587905, 0.1278832410612414, 0.11758112048189487, 0.14146175115339218, 0.0007634736492388672, 0.08428412774998335, 0.02908210529224767, 0.03747119515713665, 0.057754181175222324, 0.07561716821885879, 0.07343412406982915, 1.2172608822584152, 21.97904636782985, 68.22558910615983, 87.56682780481155, 72.34273633649273, 35.91463727335776, 45.06147507698306, 17.27095288615073, 18.281869273031912, 53.25125063619306, 74.60205293470814, 42.53251514127178, 32.89222355811827, 13.431764418079009, 1.7588628588184234, 0.3029977638394602, 0.05726242933662669, 0.1032328682260648, 0.1442213683959938, 0.3298723120843211, 0.31397994066919055, 0.6153507482620978, 1.7238498214752445, 1.402316713525403, 1.6189030077188247, 3.3183864528133027, 6.693594321127861, 5.085372540258593, 3.4659148848825887, 6.79042685416437, 10.64153148281959, 18.52822942118491, 32.84647499361346, 61.158258607310636, 82.74118285025321, 90.43669269930932, 94.33406168414702, 100.27096117696455, 101.66941165924074, 98.7819274779289, 105.85753810021185, 101.6285562515259, 95.71914472887593, 95.8589066228559, 85.79839583366149, 55.950288464946134, 29.14457928749823, 28.052618888116655, 60.176583490064075, 122.7489742155998, 126.35996310941636, 147.31470015741164, 133.8257005137782, 156.12801490291474, 50.789182801400464, 93.94613142936461, 115.0915898046186, 105.83654557504963, 96.84601030042096, 86.31471310892414, 94.09196515237132, 97.03913996296545, 108.64246799099831, 106.70708425583379, 107.08189810475996, 111.2069606781006, 102.59205510539394, 92.43016673672585, 75.098844651253, 52.145636466241655, 34.25735350578062, 24.833684621318696, 12.507926610208328, 7.005508061378234, 1.4642472613242365, 1.063197291185779, 0.6388483196496964, 0.9317935390337821, 0.9233806678845037, 0.13774741981779376, 0.240368957541162, 0.0308275772559066, 0.4777676696258207, 0.05045583005994559, 1.7409116414285477, 13.569137588624033, 46.34135623132029, 48.874830815099905, 30.917521984346454, 39.85428548628285, 23.631364414768836, 17.478130517467378, 54.67018765787925, 76.97578507085001, 77.84207974710773, 80.21758479456749, 64.12398230644965, 13.192147804844765, 0.6552114674160558, 0.05617618560791016, 0.04247653403229291, 0.04284932007712703, 0.07647504113734731, 0.1978938560932875, 0.020321905199858933, 0.22133861337938618, 0.07167662644097883, 0.05647843027667654, 0.04407200406515791, 0.029741856382198395, 0.10973810383509244, 0.1790293699671184, 0.27943317508024557, 0.14448655739186272, 0.23381662284654958, 0.18391462072970408, 0.45559003708824036, 0.3333341408400767, 0.23393826228716683, 0.09753707345695266, 0.059222641491120866, 0.09413808689362581, 0.05676906488295044, 0.17267033457756045, 0.05919664812785003, 0.1645676983940986, 0.2234035114487333, 0.041195665666412924, 0.07708228073052822, 0.06796476956937583, 0.14184212912955593, 0.13296848673733974, 0.042917946233384074, 0.052055582524307316, 0.01898469298236793, 0.11332405415633995, 0.12796504392979607, 0.03556390435645177, 0.04120610361438125, 0.06556005021857639, 0.07608027602996557, 0.0357589541724132, 0.0644584923922535, 0.06532107675147635, 0.25958399017972333, 0.10442605782901088, 0.07540857013795646, 0.009691876963892532, 0.10257543455208502, 0.08437411243756933, 0.009437621957922896, 0.09352717773928758, 0.0238548556432849, 0.012551371004402399, 0.08017532242041442, 0.044194191258641026, 0.014567732615696808, 0.05396436336600492, 0.04971518774607009, 0.02002545790145955, 0.2065758079650902, 0.0617300549281701, 0.30990006281964244, 0.1131278743606902, 0.22674599902764445, 0.14805193059146404, 0.07023838829369315, 0.042562071579478444, 0.04573176802706815, 0.06326244145091023, 0.05842076576945763, 0.07067904972861852, 0.08529006248159755, 0.05291954967223349, 0.13925679688972814, 0.10190385889502303, 1.34840949648811, 29.304049130409, 94.92003240892964, 101.35897959432295, 85.16888679996615, 45.72209242851504, 68.08181070512342, 32.35707106128816, 27.283389145328155, 61.96057550368771, 59.429944638283025, 45.341112613677986, 38.31646142467376, 16.49530222339015, 2.4358690986710214, 0.16616140642473776, 0.12973501347005367, 0.19969635372681005, 0.2627338372891949, 0.6840521037097901, 1.3620409585775868, 2.8345608663174415, 4.49154285653945, 5.042828552184567, 5.129636977949451, 5.654841853726295, 5.277471109744042, 2.558752053206967, 2.1183321504823627, 1.7437035109727614, 7.346346339871807, 18.624649124760783, 38.03720043551537, 66.66283053736534, 91.98657020445793, 99.15270913031794, 99.84274818051247, 107.76440620422365, 103.16041438810288, 105.18210595653903, 110.04105183386035, 103.73894829903881, 99.13158324456985, 100.36159146216609, 90.99854869227256, 62.86224603652955, 31.1681398653215, 31.888812626561812, 66.23293092173915, 133.3309013612809, 142.33175246946274, 158.95373744349328, 145.73211792976628, 165.73571943467664, 60.32991678484025, 91.40470227887555, 117.7462891609438, 109.40241936714419, 101.68415192634829, 94.7937007104197, 99.07778401528635, 101.65538526350453, 113.67594365150698, 113.00054288679554, 112.9380673746909, 119.07391732738866, 108.98481245963805, 101.27879065852012, 75.89987893258372, 56.18600722282164, 38.29022076822097, 26.526169700007287, 8.605818421609941, 3.2798503916109762, 0.5775077821266267, 2.7063111287932244, 1.532530087617136, 2.130012478559248, 2.672413270319662, 0.23419955955638042, 0.4474663794521363, 0.08005117021140554, 0.11111533074008842, 0.03106791435951187, 1.076181439622756, 13.705443874482187, 39.55305922415949, 52.77138786931192, 41.57799459272816, 34.5523000532581, 21.228867576968288, 30.306677549116074, 80.7208719561177, 96.36393531676262, 86.94699918070148, 90.53743485481509, 89.58871549175632, 31.855203797740323, 1.7440420605482596, 0.15887442405425733, 0.03783976771838723, 0.029099351846643036, 0.03831497588825803, 0.1504489584195037, 0.012043666342393526, 0.2202453293026455, 0.054919732464177, 0.055300612227931145, 0.0670270013412641, 0.028489059393083858, 0.1673731123728137, 0.11383046125692707, 0.17395702521166495, 0.21366334700536346, 0.020457014381404848, 0.06702481032980066, 0.09518900630815376, 0.27542083554210206, 0.1562894442148747, 0.06759923837718464, 0.011985343111108148, 0.06500383208115255, 0.05115755893770726, 0.06309579051430188, 0.040700462601718404, 0.13801651586207653, 0.1491615476627504, 0.033977037490976435, 0.10712890029554406, 0.09655848806423527, 0.15858035354364305, 0.22952401770218728, 0.01886666181587404, 0.08809370679720756, 0.08781894936316437, 0.08586924793499132, 0.09010367636238376, 0.02535499944051187, 0.018285183844366865, 0.07066525248510223, 0.04340221339295949, 0.13550544818562849, 0.23456723579475958, 0.16475624795402252, 0.40005466870723233, 0.28617505524908343, 0.23497412041310342, 0.17013355699037352, 0.2692946449162499, 0.18072090742568817, 0.08714023376664809, 0.21078584415297355, 0.17179514041110394, 0.16386931732056603, 0.21697588054643524, 0.14439743072275193, 0.23037526396013078, 0.17325988520056973, 0.15242223237310687, 0.2607530709956923, 0.33527105626079345, 0.31301399572722377, 0.5733197939492042, 0.34792045491837686, 0.27128825084336344, 0.19331338575049756, 0.25564910213072456, 0.32627513091410365, 0.387873686850071, 0.11954025245241581, 0.1948940243211485, 0.10818064708503024, 0.1680854056030512, 0.21881793896036766, 0.28727586230924057, 0.2875016743858015, 2.350775238967711, 40.939671993255615, 117.54343986511232, 118.69216872799782, 96.15071527419552, 60.619238653490626, 70.60567548198085, 30.75239020009195, 31.34451904604512, 75.48096195344003, 97.25902019008514, 62.515975275347316, 49.69634379110029, 23.12262123630893, 3.2297301004009866, 0.6102774075923428, 0.1932246574471074, 0.5347988706442618, 0.5772808362399379, 0.735920668850022, 1.317085448291994, 3.602861007375102, 6.156690486015813, 7.25446972154802, 8.430057994781002, 13.975808928089759, 18.348824131873346, 18.92502031018657, 16.64373451663602, 20.6235360330151, 24.190974850808423, 28.653451473482196, 41.453761362260394, 68.07129875306161, 96.28054572689919, 99.53146103889712, 103.80399688597649, 110.99512130983415, 107.36588554997599, 106.87940966698432, 114.66606755410473, 103.49251362585254, 98.86580344169371, 102.14586980881231, 95.47437314064273, 67.90505301567816, 39.46615126825149, 38.87712501710461, 74.45313622874599, 133.05853197651527, 136.78205367057555, 154.38971457942841, 144.72557498562722, 159.07037304293726, 69.57570814317273, 97.03204047295355, 122.11737063623245, 112.09040395675167, 106.2986086260888, 97.79582792712797, 102.13548337259601, 102.91051233968427, 117.18815941964428, 114.04203414916994, 117.00202726548719, 122.41298398663922, 110.6519688329389, 102.69087529951527, 79.93381700208111, 64.10044416304558, 43.05254690108761, 34.99695170310236, 24.584300325762843, 17.577207626834994, 5.734931749682273, 6.53663577571992, 4.970773631526578, 3.8275125526612808, 3.4629721266608087, 0.17327673913490388, 0.4691913766005347, 0.13328097400165376, 0.7645749312735374, 0.2043110835215738, 2.834778557862005, 21.486894815198838, 66.41585457709529, 67.26925250022643, 45.056528968195764, 52.269183281929266, 29.81859153316867, 23.328890838930686, 67.73250795179798, 98.6702811333441, 91.5370979616719, 103.63477799200244, 102.47525476640271, 26.530607861857263, 0.9441984637129692, 0.34749500032874847, 0.2067976057409279, 0.2569129173794101, 0.24778212991452989, 0.3132889600050065, 0.21301833161663628, 0.41092600793607775, 0.19904442822500584, 0.3396002497644194, 0.14322346226582605, 0.11274711334056432, 0.2221125460440113, 0.26475011941886717, 0.4227912389943677, 0.33377050452174684, 0.32836682673904205, 0.2990376408542356, 0.5336008929917889, 0.6918002556889289, 0.27809748546250407, 0.1857801673993949, 0.10710232470545078, 0.14788679267850616, 0.11570436594587181, 0.30714931687520397, 0.15801516451662587, 0.34005496891275533, 0.35050701289888353, 0.16821070694394652, 0.16013014941446244, 0.13962631173912557, 0.3278807286293276, 0.29792356515123003, 0.14303500463645305, 0.11379850772960533, 0.2310644060132965, 0.274588251185994, 0.2462107916512797, 0.09782270167864139, 0.1379843708127737, 0.13671442686069396, 0.22300246442037247], [0.00900586725272719, 0.07333278595920532, 0.04088420112947783, 0.13481151042205675, 0.1137590925059011, 0.17419330204927153, 0.060007831817793275, 0.1706153803294705, 0.03244374315404604, 0.10479026368909305, 0.025028785795814572, 0.012783192083119385, 0.17662321037102133, 0.12863229119008587, 0.10407213286887254, 0.042099971173992085, 0.07016996898117565, 0.06685411827939172, 0.10076957379257488, 0.28755851810978306, 0.11904434841727057, 0.2583384231453942, 0.3370880635996019, 0.3380519860694486, 0.47451274589665476, 0.12843997247757452, 0.2582550421357155, 0.05068916895036256, 0.0735347343969249, 0.10413115994343836, 0.034014667729817094, 0.04871665725424405, 0.04178614708625021, 0.12883945668656982, 5.661502528575159, 39.30715407094648, 77.10385045697613, 86.88759880681192, 81.01172354913528, 65.67235754382226, 53.94880102526758, 38.64570909930814, 65.89052369517665, 79.68813542396792, 62.302143343033336, 37.136981179637296, 30.17362879168603, 7.385267038499156, 0.088528974973146, 0.028393036017434734, 0.20949115556093956, 0.027602299214190537, 0.26556382736852097, 0.18650143918010498, 0.5822812453393014, 2.0360926730978877, 3.0805670205623876, 1.9753615125533075, 5.067347288131714, 3.4731028733714937, 5.773039046795138, 5.224895659954318, 7.601768634011669, 13.240195858863093, 47.57252939285771, 56.90302825743153, 81.78255558013916, 107.84997663190289, 104.4026368664157, 100.86416475234493, 94.74905629311839, 96.6653694645051, 94.80029029230919, 96.2950663412771, 99.69659282315163, 102.79654395195746, 99.02390633859943, 99.03412019052814, 96.8870226029427, 95.82702559809532, 94.58458346705284, 74.2148365512971, 62.0014662127341, 107.25125820406022, 110.93874116097729, 82.78457210909936, 83.47690182347452, 78.95353824861589, 96.13624172825968, 47.98511566654329, 76.87603919736802, 100.33235411490165, 110.75424855755223, 97.1470679006269, 87.35416473880892, 89.25455308729603, 89.37667216024091, 90.98056854740267, 89.6478726786952, 96.48368527812343, 100.14476283904045, 104.35856511515956, 102.85241419269194, 94.01245870897847, 86.66747539274155, 83.32774193056169, 66.44971247642272, 43.96623557613742, 9.194085694128468, 0.8993608696806816, 1.9376919274368596, 0.32567041175019357, 2.313756399577664, 1.9116203006236785, 0.6224110145722667, 0.08279247795261684, 0.10987228413503017, 0.07558936688808665, 0.03320315845250603, 0.0278127646344083, 0.062093257213071476, 6.746398248980123, 30.498918794816543, 44.90248180204823, 61.34518308024253, 72.01281793655889, 45.86518833714147, 12.909305691719057, 24.88404981551632, 63.23388668798632, 66.33503021732454, 71.6559999219833, 76.53873105202952, 36.410252278850926, 1.8358581272825119, 0.14690885079964516, 0.06188680417835713, 0.13666334411790296, 0.034101369730647535, 0.05368641900619673, 0.1835917606348953, 0.1193810363991126, 0.07463949447077128, 0.04528271409893229, 0.007590346964031098, 0.0740568156564428, 0.30153312630230383, 0.11317228447766074, 0.06886100051023307, 0.16189947544086367, 0.2556220285834805, 0.20274579735292544, 0.13663755759837168, 0.252593437870664, 0.07858651735249066, 0.02091296693129886, 0.06021638776385977, 0.07655391755003123, 0.06825851832306193, 0.06898549745880789, 0.15320416299566147, 0.07436964766032274, 0.05816157907247544, 0.039451570745797894, 0.030697552982958096, 0.05213088513682446, 0.03926289478136648, 0.03863687837316144, 0.12768027372658253, 0.0473518907693365, 0.011253801921773101, 0.06311029255870851, 0.0884489034633002, 0.08300956428772019, 0.009003464609474666, 0.04985584148896798, 0.03933221041675537, 0.014660012694225918, 0.04211664890810367, 0.09949608285340572, 0.20316794244272096, 0.10292328443498382, 0.019461569308693853, 0.16565618676043328, 0.024749481629940773, 0.07541941028208503, 0.026097616346012202, 0.013263778190218635, 0.17923999818102007, 0.055096752400840485, 0.1507163231050776, 0.02701814759582762, 0.05838136203707226, 0.06661565809120094, 0.09629370509496621, 0.24512890696285233, 0.09633400131978336, 0.21394523671798168, 0.2722493234661318, 0.3147733932541263, 0.2559497150322122, 0.056503458369162776, 0.2565054045689683, 0.05221958662713728, 0.05758260046282123, 0.11053061413188135, 0.009661957400009758, 0.12139642220591346, 0.07427050056116236, 0.21089539472614566, 6.946644561906015, 52.74420976638795, 103.07602851621567, 104.0001859972554, 101.69966097800963, 94.11819796408378, 77.7684097905313, 38.66138289051671, 37.25736656496602, 48.486979007720954, 41.93490282181771, 41.15609268988333, 33.09588870694561, 8.886820943124834, 0.14821539843274703, 0.07699121585896901, 0.22213748986682585, 0.1593707264551232, 0.2405186357998079, 0.7327162149933077, 1.609062761549027, 3.8514412170456307, 5.402610898017884, 3.638105219410312, 2.9393599783220603, 3.174264354090537, 3.5727421074144305, 3.483907287159274, 6.929315530484723, 16.033701031438767, 49.85661183634112, 67.69450018482824, 92.91402247644241, 115.19693682270666, 113.06636810302736, 105.2705083354827, 102.0652807912519, 101.13449450462096, 98.45002435868787, 100.81470366447203, 100.40455710503363, 103.36730372521185, 99.57157904101958, 99.60062811451574, 101.6899021210209, 97.0294124849381, 97.84529685974123, 84.8115667220085, 70.33460047937209, 119.20565405199606, 124.81945222423924, 95.43997395423152, 94.59142408063336, 93.65667620012837, 109.92343564187328, 58.43644357496693, 77.15856752087994, 106.42817235762074, 115.91132594693093, 105.666471604378, 93.01649831956433, 95.8457588380383, 94.72526319565313, 98.59506576291977, 96.19109999748969, 101.0934586678782, 102.63811157595728, 107.11242983418127, 104.59862201444565, 95.00035470531833, 93.81122542965798, 86.04259475584954, 72.65095618463332, 47.73310730534215, 13.474944810713492, 1.22871873840209, 1.0021557118142805, 1.2679668323647593, 0.8189727510175397, 1.5274607918916212, 1.1513627344562163, 1.4496381484693097, 0.2884662403695045, 0.04089485741250458, 0.031075778252054608, 0.06692940173971076, 0.008416912263079036, 6.114626988287895, 29.591082296063824, 43.97373122553672, 40.15281315772764, 32.85297043861882, 26.936912459711877, 20.244425227565152, 49.52126879845896, 93.23913989528533, 79.75278392914804, 77.64699674421742, 99.01859544938611, 63.02283963849468, 8.585921218318324, 0.15597347891138447, 0.009686568932187174, 0.0768656846916964, 0.06905352606648399, 0.1330359331181934, 0.15585928584539122, 0.13604238388999818, 0.009640991488742012, 0.08599472547610922, 0.03216344307387068, 0.07717413467264946, 0.17659964550647045, 0.16797836779827074, 0.04060586606482825, 0.18260251129827193, 0.1739112897625854, 0.16951711668122202, 0.05350714677103585, 0.29323663923048204, 0.030964408220062335, 0.08397250616502377, 0.14736427474887143, 0.030265600052511984, 0.05567021517743988, 0.12518668817656656, 0.13795371197404402, 0.06333004104934874, 0.06082742715314512, 0.048255380393276294, 0.07917673447199407, 0.011686815883994344, 0.044754753114595536, 0.06297861736628317, 0.11446759360091341, 0.12016416977970831, 0.07237950445062692, 0.02543753583825404, 0.01641129447718061, 0.07259514287955339, 0.014004092043896597, 0.06999463443794558, 0.30763112489254246, 0.11596615351135693, 0.21418790272887678, 0.28916423839907496, 0.32299799063513357, 0.30052449494119615, 0.10869655367587844, 0.38809995857938645, 0.19172405974278528, 0.14187614343339397, 0.15214138454006565, 0.08155658660877137, 0.28445966181255156, 0.28311667903777094, 0.2977473342851285, 0.16148615568395586, 0.23533661789711446, 0.13841477433039298, 0.198802589589069, 0.5469186880415486, 0.20491235528982457, 0.44669250807454514, 0.6710644006248444, 0.6245658053986488, 0.644751486759032, 0.28736049970311506, 0.30018346324082346, 0.24041309952735904, 0.16267720790159318, 0.35611624739343123, 0.17992527915104745, 0.2521860629560486, 0.2512885143439616, 0.6513630706937082, 11.879504073050715, 70.89436977140366, 125.33232565849059, 120.03016764117827, 112.50025241605698, 97.65417545072495, 79.8191661219443, 58.1062113854193, 90.11158312520674, 104.5051597779797, 79.88416764043993, 56.550909242322376, 48.57052941476145, 13.70967709249066, 0.29931061330341524, 0.18463480466556165, 0.5896043717380494, 0.4335827825050201, 0.49269231877500014, 1.2696560255942808, 3.516667167986593, 6.3845424402144655, 10.103623520943428, 7.298325252148413, 9.380550269157657, 12.14043386520878, 13.623627155057846, 18.189673962131625, 18.6790818168271, 22.77922361127792, 52.61210041661417, 73.05919647216797, 97.89012170607045, 116.78774033823322, 119.28577238513579, 108.61031240032567, 109.0909125727992, 106.41369096694454, 102.56160182337608, 103.92660233282275, 105.85745965280842, 102.11345534170829, 97.09434340077063, 99.6190397201046, 109.03587387454127, 99.58493863382648, 103.64976144606068, 92.44769188665575, 84.73127580458119, 130.81447339827017, 129.07615738530313, 101.45096701960411, 105.7181449090281, 105.06268547427271, 118.70015467366865, 62.22534725742956, 83.90852728197652, 106.65955297408566, 118.17134857177736, 107.48984029216152, 92.89582267884286, 97.91409523256364, 98.72583758446478, 103.25264500033472, 101.95619183201944, 106.84861121639129, 108.093061600962, 109.51486587524415, 106.61748947635775, 96.52740401606407, 94.37705870597594, 88.3880622925297, 79.08890708800286, 54.422074210259225, 16.40678511511895, 5.011118150526478, 5.199765034260289, 5.181616227472983, 6.311682453078609, 4.391787667428294, 2.0464370664088958, 2.096130554714511, 0.28678780301443996, 0.2305646408950129, 0.17548866479867892, 0.13461110182106495, 0.17969756717643431, 10.814930642804793, 46.242202635734316, 68.65282935480919, 84.14301441561791, 94.99856610451975, 58.25834835729292, 18.395280684194258, 35.0660873997596, 87.92443813816195, 85.24112901379986, 87.27281478143509, 111.78261556933003, 65.04883404700988, 5.6172224014036125, 0.3335931092020004, 0.2432698567187594, 0.30776007281195733, 0.32136677493972166, 0.23124178601128442, 0.30421660972699044, 0.305894005202478, 0.15968296857130143, 0.2223538024531257, 0.18346621414586423, 0.22729673963640967, 0.4836357499082243, 0.26946257138925217, 0.19020285427330003, 0.47968613764932083, 0.3900595808461789, 0.3897163428125843, 0.22906793491734614, 0.5658760546676574, 0.26179966967432733, 0.24727729329418754, 0.2931548823272028, 0.1871778335302107, 0.19432137359774884, 0.30885334156693955, 0.22500177004164268, 0.22753919114268598, 0.253944602464476, 0.1714583068725563, 0.2760906721795759, 0.2980889482123237, 0.2036738362643988, 0.2247812286500008, 0.3725028680937906, 0.2735357995956175, 0.31223782608585976, 0.19997444364332384, 0.11735088807801086, 0.24979095034781965, 0.11095090528890011, 0.1901980125976186], [0.027597999545715513, 0.06464356391300118, 0.03885177369680136, 0.12397079172754481, 0.09260323739820912, 0.15923492970966524, 0.0723144099597008, 0.10429119571082054, 0.06915692495362413, 0.023082514526322487, 0.023710947941928625, 0.07140582968150416, 0.014977743830381623, 0.11621321686693739, 0.0897332651901149, 0.09009115082482178, 0.04456462924398723, 0.04902529492673855, 0.058802246912232334, 0.14678033188946787, 0.06320069476421322, 0.12690912962200182, 0.075080860706587, 0.23088313428865326, 0.145891685219061, 0.24118177682882358, 0.04560008134332396, 0.05198554293582997, 0.016323054554842172, 0.023440430804546324, 0.012425348583248355, 0.10660995233563647, 1.5924300734073886, 19.55564525819594, 74.22105743039039, 95.30734292922482, 91.17726756680398, 83.4856330194781, 45.978207511286584, 32.23049617582752, 28.14550453616727, 37.72169674596479, 71.6423422290433, 84.54740293564336, 52.91336198006907, 17.34608196443127, 1.5684217358789139, 0.08457364769832743, 0.13498640829516997, 0.08819713632786468, 0.033747253248528127, 0.11323786160397915, 0.2812748810937328, 0.4084921466006387, 0.4848686918135613, 2.5787796753068126, 6.257246328938392, 6.36740658552416, 4.930626701924109, 3.6876192592805435, 5.387915738167302, 17.35910619458845, 57.04466112198369, 96.01587987715199, 107.50690260241109, 99.9050275741085, 96.53025165680917, 97.15469298824188, 89.73611031809162, 86.76409121482604, 83.84941716347971, 89.84601513031991, 91.97541498368787, 99.8708245062059, 97.10298045989006, 106.3805155600271, 95.47929963757916, 93.42532696262484, 90.37777869932114, 99.66503343274518, 99.99547743028211, 94.17933987032984, 46.16760307742704, 62.06087050899383, 81.15546272646996, 77.5812578201294, 80.4882989391204, 73.86320391008931, 90.87928510481312, 34.18967300845731, 63.13155989493094, 109.04396180183657, 103.54566174168741, 100.94545979653635, 98.06079972174861, 100.61727508421868, 92.06053826116747, 79.66159666738203, 80.33888801451653, 88.03234254160236, 97.61879567177066, 97.8237630474952, 100.46864078890894, 97.56949147870465, 98.67026544386341, 99.37006335104667, 95.0684392067694, 83.69079651371126, 55.401517498877745, 12.776982572770889, 0.39779780432581907, 1.3580754423333754, 0.23634075998298584, 0.777525371841846, 2.0725377432761656, 1.589410216096909, 0.8981719012221984, 0.03308814950287342, 0.03883110847504389, 0.24324117438687434, 0.09916917015347751, 0.04609721878002729, 2.577917979609582, 19.077727986920266, 52.47392708255399, 82.23333789456277, 127.31498179897186, 80.71148964666551, 28.371564457493445, 15.421972101734532, 43.696403964873284, 74.03514492896296, 63.44076033561461, 79.24813178277786, 53.41153044854441, 8.702912772855452, 0.3381369911855267, 0.037498360634931636, 0.13004970706758961, 0.06799824761166688, 0.21532508364367872, 0.03126509581512261, 0.11165913059225968, 0.02120308251300406, 0.055112618081752336, 0.03589448661753728, 0.13783561185963694, 0.054652892548831246, 0.06758304327846536, 0.21733609508843194, 0.07280723432139044, 0.0694731124226124, 0.03138047248695887, 0.21324133981139431, 0.10310349895829156, 0.032347016892726385, 0.10624609121512021, 0.046785996941428994, 0.02491477276048353, 0.1773339407818933, 0.0828936628456558, 0.005890286777303705, 0.021391203063690377, 0.17654981914787524, 0.03352370113134384, 0.06345122849809066, 0.018444819330808618, 0.054073128699054646, 0.040959974886068416, 0.06240981240426341, 0.08746481755928648, 0.029854251056789394, 0.037890475078095356, 0.05956979806444818, 0.049467545994106805, 0.014383029774762692, 0.061553157565574494, 0.016154034491327983, 0.022014564977237777, 0.023968259638716138, 0.017489988409403353, 0.13314108634668012, 0.07169560243886325, 0.04783016712134404, 0.017123830940334067, 0.014138084652292875, 0.014955159558373836, 0.021326137301061424, 0.010155086281649288, 0.13046524847947782, 0.07227733130416564, 0.0658054971286366, 0.08506543018044004, 0.044968694658769716, 0.086897567755753, 0.13060760293756762, 0.11320246834187739, 0.1186980230493411, 0.024981374529400663, 0.24774206351609002, 0.10590387973934413, 0.18165467667483515, 0.12297578907061009, 0.07253547229113118, 0.06594723105550775, 0.015661918760968313, 0.029377219597658807, 0.09378007102397182, 1.7414270653840036, 22.383211312755463, 97.45210278418757, 116.36904301181917, 112.01285085370465, 100.83875563836868, 67.04661876924577, 54.888726434400006, 52.02374881313693, 45.29191432460662, 71.01012675992905, 79.57376695448353, 51.37035646746236, 22.228326720576135, 2.8408317556304317, 0.010045151706905136, 0.013345364638934694, 0.09812947392704026, 0.1628656348874492, 0.36842207093873336, 0.23022889520131776, 0.4258156621888761, 0.3351709438908485, 3.6576614216450727, 5.7447072767442275, 3.762995201733805, 5.303089089931981, 0.25817291751023264, 1.82851581804214, 22.92818738568214, 62.63215195748114, 103.40614303465813, 110.38488680316557, 106.11451610442131, 104.88305660986133, 102.73878312879994, 95.73018227854084, 92.76771022427468, 89.12755458585679, 93.65930418814384, 96.3731764208886, 102.0584950908538, 102.53307050274265, 108.55020599980509, 95.90972485080843, 94.74783251362463, 92.66153166371008, 101.06074610064107, 100.86134064582087, 96.06545079138972, 52.344151543032744, 71.53365335156842, 90.77979026302215, 86.28733496512137, 87.9153617735832, 78.80617480124198, 99.72028393899241, 40.01004280582551, 68.7153519353559, 109.0629146945092, 103.90961846997662, 105.87287456758561, 101.37513191469255, 104.39368601768248, 95.20577707598287, 84.52705367918938, 83.4439931377288, 91.68311211370653, 102.42762934777045, 102.76350190562587, 104.21779124967514, 100.35684539425759, 99.5569250660558, 102.57428676851335, 99.31698583787488, 90.86533715648036, 59.42242937703287, 17.16423499968744, 0.47437092770011197, 0.9617690886220626, 0.41527800021633027, 2.3108803216488134, 5.246714824630368, 3.393536368685384, 2.4443769647229106, 0.31475620224110545, 0.2911431660815593, 0.1886747080472208, 0.06893197855641765, 0.07662389968191424, 1.9443751559142146, 19.542968157799013, 40.59072617561587, 70.90244200921828, 102.29013458375009, 57.41303836145709, 27.150091317392167, 24.759006615607973, 63.15307017295592, 96.3451236294162, 69.04689419654109, 91.09186187867196, 77.45365527368362, 21.02643209118997, 0.6044381015723752, 0.07568672900238345, 0.2346235432571942, 0.07473848069146757, 0.18037541709359617, 0.0704996089541143, 0.07026390668245093, 0.08910420741285048, 0.10426091991605298, 0.009819860570132732, 0.07046094449657588, 0.09469319420355944, 0.03403136844656641, 0.2160299458210507, 0.10044269173616364, 0.06252217835055725, 0.03095311225361882, 0.10753118838634222, 0.11808693003390106, 0.046553619491357, 0.05227087238322824, 0.0393911876956061, 0.054687033257176804, 0.11502431735636727, 0.06159284475049185, 0.017334606626161167, 0.03110538563510824, 0.05310380147890218, 0.05505980398025244, 0.08631926330347216, 0.05864701834657501, 0.08146043491339491, 0.07903290912508965, 0.03341662885260678, 0.07144270915417902, 0.03730794182047248, 0.05034000905711324, 0.07920717880610498, 0.07321949687696273, 0.06496717477397573, 0.10940000625146974, 0.20258844289327824, 0.13761002960945332, 0.254952804816346, 0.2802470056039672, 0.2864148407693832, 0.26005884211870933, 0.20422198749597997, 0.1336259740374742, 0.16975939964815495, 0.13991883475213282, 0.16997640171358663, 0.1529850312058003, 0.1875963626850036, 0.12929455887886787, 0.28857009124851996, 0.16058692167843544, 0.21073594118558595, 0.2982752607955087, 0.2985806234421269, 0.329922444878086, 0.38146661774766066, 0.22454449215963965, 0.62027589688378, 0.39188896816584373, 0.45109564438462263, 0.2775249726349308, 0.16076995540530453, 0.22595702039618648, 0.14183359491007944, 0.1342752641968189, 0.28785389096986863, 3.7050811609914227, 35.47373540939824, 123.1056353353685, 137.97646245648787, 129.12830921911424, 112.36365979717625, 65.99037155028313, 44.98534971667875, 46.87227649073447, 60.40178245113742, 93.2116440803774, 110.48497000048238, 77.47482038313343, 31.03788579663923, 3.3904676043218185, 0.2640905483595787, 0.37741542222999763, 0.24242135305558485, 0.28724273666739464, 0.5752203048717591, 1.4064268671697187, 3.696054561484245, 4.447644179867161, 6.57750883410054, 13.517458400418683, 16.546989256335845, 17.274969393207183, 12.150802650759298, 13.234295633531387, 24.43381859410194, 66.539017000506, 103.51827575314431, 112.8277938596664, 104.4176987678774, 108.3723343572309, 109.72839186268469, 100.73965303359493, 95.513439947559, 91.92855050486904, 97.34897582761704, 100.4136570038334, 104.96830540318643, 101.61405132662867, 107.72864203299247, 94.86927693889987, 95.32286767036685, 93.7918410762664, 102.97666703501056, 105.81513727864912, 99.44525518724996, 62.24396282626737, 79.43970818673411, 106.82063687232234, 92.8157514141452, 98.30750896084695, 89.25609850114392, 107.59069227403211, 45.38651797079271, 71.20904584084788, 113.13714335041662, 108.10733902838923, 106.26526063488376, 102.45172839010917, 105.37349408672702, 97.72751592820691, 86.40029138134372, 88.25284250320928, 93.77759502780054, 108.3783277388542, 107.21605885413386, 109.41310390349358, 101.05635304604807, 99.77333791794317, 105.66723254419144, 101.93723893934681, 92.2993713809598, 65.25611169876592, 19.133184417601555, 4.899101632256662, 7.175770305818127, 3.0385983951630133, 3.085527102793417, 7.641965083537563, 4.922223514126194, 3.443649550599437, 0.8185325875397652, 0.3660175967360697, 0.3735893033444882, 0.29639874374674213, 0.14140181243419647, 4.3450496850475195, 30.500054320981427, 73.94875080354753, 103.72487483486053, 143.8331416345412, 94.79526965848862, 36.668760007427586, 19.227752762456095, 57.13675052888932, 96.57386841312533, 75.55350226740684, 109.76490912898895, 88.30669664567517, 18.199393595418623, 0.3935808580248587, 0.2973546989021763, 0.47653616796578135, 0.35395434727111175, 0.3541581573024873, 0.09114790782933274, 0.25988316283591334, 0.17125616691285567, 0.16078261117781364, 0.14332365124456345, 0.20202766653270493, 0.19513180269108665, 0.2067377589522831, 0.47160427777036545, 0.2706114581275371, 0.2838877618553177, 0.16536597733295735, 0.5223059990713673, 0.2928955768865924, 0.3425901070717843, 0.2187386488602046, 0.12483408854853724, 0.17049835273815742, 0.3249500133097172, 0.30645125755859964, 0.1766119488785344, 0.0776168875276081, 0.20977416376192726, 0.1223396143365291, 0.14619133284976407, 0.18563245032583514, 0.1620275193765279, 0.13649554021896856, 0.11006395933368515, 0.14558223166292714, 0.20483675773345655, 0.14525152682777376, 0.13773079570983687, 0.1848302490168041, 0.12090741296208675], [0.05566817738356129, 0.10069167031155479, 0.013095447605836296, 0.02964419932405074, 0.056043426401071975, 0.04967530903917167, 0.05509497124641653, 0.11551976173875794, 0.05104816541255963, 0.019257774599076762, 0.020375607963350993, 0.059565255163057204, 0.03668556432990778, 0.0032442487727460125, 0.08310876501303527, 0.15644335127886266, 0.06418492622493256, 0.023844862026312662, 0.08166618314721892, 0.0414724953682913, 0.06184403348954455, 0.049759046279735146, 0.0630480287626626, 0.16280580342056292, 0.07432245664418706, 0.1293284659303965, 0.10912806036010866, 0.11544234855400941, 0.010648369338483581, 0.03635375632814342, 0.1786979143657992, 5.79690961107131, 42.818757949336884, 84.10090384944793, 94.93256045926003, 74.22348929989722, 58.19096203773253, 39.184646683354536, 26.25898372742438, 32.95187496369885, 38.410410035041075, 38.91395999539284, 35.075046093233176, 26.847862889689786, 7.798282321422332, 0.5333475936805049, 0.12315871554516977, 0.19427977502346042, 0.018438970249506737, 0.17133318939276282, 0.6541802517829404, 0.33096083109417274, 0.39108509678513775, 0.4389257861241218, 0.4993548322348826, 2.961665762047614, 2.181807621832817, 2.097893414958831, 2.4668702867723282, 1.8652824000004802, 38.30702812440934, 91.90734617171749, 100.20831308057232, 91.37510407355525, 93.46894371894099, 103.47680845568257, 103.18750227651289, 92.36252154073408, 80.85966110229492, 79.5293265004312, 83.20872937479328, 93.12026854484313, 99.23813835267099, 100.01727796369984, 98.7729452502343, 95.1309068741337, 98.69124227954497, 97.48728644463324, 96.05909655171057, 97.46063001694219, 95.0756092994444, 101.52567248190604, 63.95104108318206, 46.08407228223739, 79.21593696840348, 69.53488411441927, 72.57337954736525, 73.21026263698455, 83.71699010172199, 29.41353228784377, 85.73355120997276, 101.24173994987243, 97.19114749662339, 100.77351093292238, 100.59272104693999, 103.70069734511837, 97.64960196710403, 86.48899186042048, 79.76313898640295, 82.64111534241708, 88.95668045167001, 96.16729905528408, 97.96381519686793, 97.94573307037355, 96.84524936060753, 94.91370170347153, 90.84898871760215, 98.38011987747686, 97.19636424895256, 56.75526865067021, 10.988915216538215, 0.6133453139374333, 1.2335106490119812, 2.030355593850536, 2.214984989935352, 1.152781038995712, 0.8666853810991011, 1.3477357068369467, 0.2083910533016728, 0.02723958147990127, 0.03355244858070247, 0.02907224574066218, 0.09230781857284809, 1.0126150183139309, 15.339548395526025, 33.805225818387925, 41.19608517616026, 70.14902530177947, 105.20400847158125, 64.78624313108384, 26.939012888939153, 24.334637541924756, 51.70509153796781, 56.61305135296237, 70.19381092440698, 67.99223161512806, 25.9896541795423, 3.114794848426696, 0.18139161740339574, 0.0722866852377211, 0.0670480840809403, 0.05801187017031255, 0.05791416714688944, 0.005182881666828068, 0.1479839785925804, 0.014405524031439377, 0.046173038501893325, 0.12031764783445867, 0.15182803925727645, 0.028771787971979188, 0.10248097591102125, 0.16064036397203324, 0.04636504694879536, 0.16040663054633528, 0.03236795790613659, 0.08362137742580907, 0.05430295507633879, 0.028395123607028398, 0.06229033716203225, 0.10133454831497324, 0.02757128031413642, 0.0706522902774234, 0.01904977023631575, 0.043930802569394155, 0.04234903401905491, 0.07909194386053471, 0.13796653628589647, 0.13414847664535046, 0.10207420620586603, 0.02000183366509455, 0.06994742043917218, 0.12175796208001914, 0.023724193602139433, 0.03999505650192019, 0.014538288983936994, 0.034637428264343934, 0.0787813181898767, 0.06595280051471726, 0.02715095468316107, 0.08590253445530131, 0.0508314238170222, 0.06734053814603437, 0.08557330816984178, 0.06570900069369424, 0.08605913814878272, 0.011357119412071282, 0.036772381243926865, 0.08370607610671751, 0.08786896724374064, 0.04419870351651504, 0.04114695396574755, 0.12477319221943618, 0.042914391585415414, 0.06809886559964189, 0.048438230259043556, 0.1588650931033396, 0.09247109489214998, 0.10164175723348895, 0.11933726979599846, 0.19760147097610659, 0.041604963461718256, 0.13726199586545268, 0.12680162450358753, 0.10679231190513219, 0.020535925268045357, 0.15725362715461563, 0.10878242447131103, 6.692423003335153, 52.91592721016177, 111.8654638721097, 113.24687557835733, 93.90525248742874, 75.8824400747976, 69.97659790900447, 50.11903409034976, 42.92809009552003, 39.34644445296257, 42.516566784151145, 45.49588934067757, 36.30233218592983, 13.437235143876846, 0.7847144634973618, 0.02724264583159839, 0.23025697998462186, 0.05888797981183856, 0.6816918787456329, 0.9846851686316153, 0.5260297992537099, 0.20271777385665526, 0.45007196705668207, 0.3243494923076322, 2.1387853497459046, 2.7430080886810058, 2.66401915300277, 0.9356747243192889, 2.818933653254663, 43.613853762226725, 97.18324784309634, 102.64593278208088, 93.42236949551491, 97.14505180235832, 107.11913708717593, 105.62394526696976, 97.68131825231738, 85.19203662872316, 83.56799494835639, 85.16921627906062, 96.89996642451133, 103.58028842556863, 105.39558487553751, 102.18411291799238, 94.18210121893114, 98.71294867607855, 98.09207670150265, 96.49441688291489, 96.16964463264712, 96.48918444110502, 104.52441077078544, 67.85190489984328, 55.13733410066175, 90.98554211278116, 79.1595019063642, 82.1936591978996, 82.12446858805995, 94.41862798506214, 36.789353278375444, 87.77935751022832, 108.00119184678601, 100.3612776725523, 103.77773269530266, 103.92128359886908, 107.19881611485636, 103.92969316051853, 89.02227817043182, 83.64555589614376, 85.01082312676215, 92.46046312393682, 96.51324425974201, 100.24130805846184, 95.6869028460595, 98.7128859181558, 97.61127256578015, 93.49474506993448, 104.71636372227823, 104.20612612078267, 65.73039293289185, 16.812519988706036, 1.8034935478241214, 0.4786229301844874, 0.22738333821537035, 2.788626724673856, 2.316343693002578, 0.3484254907215795, 1.9505277612516958, 0.6769801928631721, 0.4046781319043329, 0.09712985942080136, 0.06983179478876053, 0.040804642898541306, 0.7682327253203239, 17.19067373583394, 36.25727591976043, 45.72553234715616, 63.7504393054593, 86.6149313219132, 55.62335498871342, 43.89752349545879, 42.37541637113018, 71.90414474856469, 75.5556203472999, 83.70497980425435, 96.01196535172002, 45.69099980015909, 6.996071819336184, 0.1494549746595083, 0.050128082324179916, 0.052425185473816055, 0.028943033520913417, 0.05503315944224597, 0.022513180963634964, 0.06993949142915588, 0.01364400103357771, 0.006296615503097494, 0.13916137297787975, 0.05846937787869285, 0.07333915981073534, 0.09216501212288296, 0.16785855164691327, 0.056019876858279596, 0.04927400154091659, 0.05704454243964246, 0.06344743253242585, 0.019672735699362332, 0.08343560110417106, 0.034427474207815625, 0.036916493873802886, 0.03465117571214515, 0.08409893365516778, 0.04901139043091286, 0.06540130913978623, 0.030554170051829952, 0.06119227652708369, 0.1059956494117937, 0.05545653027272033, 0.09788205051013539, 0.06535548942103502, 0.09527767332450998, 0.026314763968149503, 0.04132815674247761, 0.050621626808518366, 0.12588701511342681, 0.047755814457853, 0.1863008467180114, 0.17981424236730223, 0.1414979411469352, 0.22755114211430474, 0.11501916924551611, 0.16068101259729556, 0.2693836949765682, 0.25481553718207345, 0.23626473341738027, 0.07148029342774423, 0.10370803426109976, 0.19040802794118084, 0.20187317724189452, 0.10236207140429367, 0.1924519811666781, 0.30430103261624614, 0.12577553399868552, 0.24047191975818527, 0.2684248593305388, 0.41233646773522903, 0.1386881451452932, 0.38346114298028333, 0.19886012279218246, 0.39795813120661244, 0.21245246843224574, 0.373240243042669, 0.2675130308395432, 0.14658211429993953, 0.12256552600452017, 0.2519365481191105, 0.3107775092845963, 10.65877422209709, 73.22929397706064, 129.8137277172458, 131.4606446604575, 104.99781731636294, 83.60057415500765, 59.92430448532105, 40.86403300685268, 47.24817683619838, 53.48150161004836, 54.174384378617816, 56.09507883748701, 47.23646463886384, 16.531415485566665, 1.3647755860320985, 0.3728481898865392, 0.794236017090659, 0.11536833679964466, 1.3166447945179478, 2.8216364114515247, 1.8844679382539566, 1.1430736631155014, 1.6079588594936556, 2.668369306672004, 9.489300923962748, 6.748363356436453, 10.535637294092487, 9.046168211967714, 5.515864433780794, 45.27093748892508, 100.78081438618322, 107.13789386133995, 98.54442011925482, 102.85695629735147, 113.06173970622402, 111.97900079911756, 102.56140570486747, 90.51765041966593, 87.85027396294379, 91.46443997659992, 101.86194512151904, 104.54515226425664, 109.01052751848775, 105.7645308586859, 95.32835898860809, 99.73416912940242, 101.8081537369759, 97.38084900763728, 100.16461787685272, 99.70195862554736, 109.22201387343868, 74.68743508861911, 62.99500649975192, 101.12051517732682, 88.78755569458009, 88.55874030820786, 91.69341225777903, 103.9210404119184, 42.600254474147675, 91.87065632112565, 116.28765383074361, 106.76420181028305, 107.85736637730753, 104.11839054476832, 111.40169851241573, 106.36832483353155, 94.54249643510389, 87.02838836177703, 90.51593242153045, 96.76568015929192, 104.28452645578693, 103.72225469158542, 98.67308170564714, 101.53809855061193, 102.86230641026651, 98.16677431906425, 107.60828018188478, 108.98902508520312, 65.7914799259555, 15.883058482600799, 3.286975131880853, 4.854427306882797, 6.333540841456383, 5.9893347178736045, 7.328397083667017, 4.865311393814703, 3.978828278280074, 1.6494277504182633, 0.4252854374147231, 0.1363596362212012, 0.26733753541784905, 0.182358619546698, 1.9074277772057442, 26.344828721015688, 49.02579499829201, 56.837854154648326, 82.23144731213971, 123.1463416930168, 84.07681265184956, 34.969506879006666, 32.854054973971465, 75.22185017985683, 78.4992414905179, 96.08819269364881, 111.41363820722027, 43.55155083440965, 5.0022839923058795, 0.39508162426852417, 0.1906044835284833, 0.25588003167461965, 0.1613448431054431, 0.14294050003011383, 0.09539797211125975, 0.236320918305747, 0.12499245424424449, 0.16407669732166877, 0.3582655223867586, 0.25851869895573587, 0.2629341233161188, 0.2235632101374288, 0.2823067402407047, 0.24585748722236006, 0.37688997784449213, 0.2506901690315816, 0.27421749527415923, 0.1724996808315477, 0.13326456439831566, 0.2138271519253331, 0.2570649092235873, 0.14032545890058243, 0.28693645471526735, 0.19573270673713378, 0.18576980989065864, 0.17517507436775392, 0.26307609473024646, 0.22187858279193604, 0.2755391808046449, 0.2913057605826086, 0.17511747987760654, 0.20372193126428514, 0.25812024130455913, 0.10792414552622265, 0.2054721357360963, 0.29168739494296814, 0.21790087042797], [0.08937423808440086, 0.09114839046472505, 0.035369992181057894, 0.06878831408797734, 0.02122793823570734, 0.028015879440992594, 0.031010655032831336, 0.03718116959076255, 0.03489348932259506, 0.031167241489334457, 0.01943828598145516, 0.06411560675910404, 0.023439180166009935, 0.027234442945149158, 0.05023896205990065, 0.13266729160902963, 0.020996240688668146, 0.010307099193244452, 0.056391647836614045, 0.05596570678115372, 0.08835541009302102, 0.12413264312330755, 0.07295479817736535, 0.12981001347784074, 0.05722356569622794, 0.09631419794694071, 0.10275503620505334, 0.039978083823957754, 0.09502914674099415, 0.14796614406570313, 12.164519179251887, 56.293048704824145, 103.71758707108037, 102.98991680145265, 92.65490285811886, 51.294034988649436, 37.04583706394319, 19.426705183521396, 26.87185406684876, 61.05750468469436, 66.15623289538969, 48.210730398854906, 34.382120178591826, 12.283740601231976, 1.5995604520843876, 0.04537041201406429, 0.09963515845517959, 0.09102681231114174, 0.07610158093513981, 0.8925912877725017, 0.6867830539422651, 0.5050160381342135, 0.06589346700498173, 0.028383775929649992, 0.14146262449362587, 1.412335672686177, 0.2346887066960335, 1.3471631633658565, 4.6498301048432635, 56.7210538156571, 98.93788876072054, 94.54830154295891, 85.35516800418978, 87.87633419036867, 96.46193181314777, 92.09834206488826, 89.3804454803467, 76.55717403657975, 76.19692787047356, 85.27144893523186, 92.89327313823085, 97.4252345485072, 100.35701013380482, 99.86520767211915, 92.72400717581473, 92.04042434692384, 96.78153437952842, 97.71231282141902, 98.31972322156354, 94.9442805013349, 99.25459661791402, 95.88396272351666, 94.25760684474822, 44.27912304478307, 49.62985569430936, 76.70246647250268, 81.21746755415394, 85.5641754211918, 64.23974713971539, 41.0476234651381, 97.7878184472361, 89.57933318230414, 85.41283469046317, 91.32326602935792, 101.4672762347806, 100.87223699015956, 93.70785528613676, 78.3175180804345, 74.99812602996826, 82.96995116818337, 89.27369425373693, 91.43432401841687, 95.76466775709584, 93.67542512955205, 94.18837701120685, 89.5368617580783, 80.10985297541465, 87.72336175364833, 92.87774839708882, 99.98651873680853, 63.64388027498799, 26.10180062632407, 1.9867731582733894, 3.8867074924130596, 2.6709774376884585, 6.798731492411706, 1.5635181602931794, 0.23365309371823267, 0.287269028804956, 0.14612364132077466, 0.09527994860564509, 0.06361879107932891, 0.041897030652410565, 0.03337707573307618, 0.4684837871501523, 10.492755982183642, 35.49366497224377, 52.007945583712676, 41.87700471570415, 56.177256414967204, 45.467605129365005, 27.042575228598814, 17.213354841355358, 28.63785416849198, 69.29690607132451, 70.91568393092003, 76.04739927476453, 42.08705940554219, 15.77848417143668, 1.123730494610725, 0.07103010951992005, 0.08377688561355875, 0.04531008642046683, 0.12606923678709617, 0.10594967647545761, 0.015405787797194096, 0.030741028472661015, 0.021794596236319314, 0.11862712161194895, 0.1972245403956021, 0.13032189810708647, 0.09279451423114346, 0.09188316837554017, 0.07998351698681232, 0.061738171629727855, 0.04224920893208154, 0.01422520608626186, 0.048278393674521684, 0.03368214343584353, 0.01249476955572684, 0.029346250493319768, 0.061806089154654936, 0.05016361731254766, 0.05040467453880176, 0.007185378523107859, 0.12934901240852573, 0.08058101194159639, 0.0886986404657364, 0.0692132783813342, 0.10464260790256724, 0.04057963521430089, 0.013354092295612059, 0.04765827997377323, 0.0346433271413609, 0.02962505095638335, 0.054351406307109905, 0.011459044537567084, 0.05559272155345929, 0.02120088958632081, 0.0693270500989691, 0.055021059083481955, 0.03354758009194367, 0.041233736405810045, 0.01688016901513742, 0.03511966912135963, 0.03671396320926086, 0.04118833420497756, 0.004451926055950143, 0.08760631399890108, 0.00448609501378791, 0.04424294892458185, 0.1262944666368346, 0.1013909170644418, 0.037032805172906774, 0.05129513683758917, 0.04628498309982881, 0.016258074977104704, 0.1994421504317753, 0.09338069406728591, 0.07091541083589678, 0.025668674141108513, 0.09013159260634454, 0.053635079623951074, 0.0673484901386884, 0.08391522577092533, 0.4457451637473799, 13.389245925411103, 68.15581014079433, 123.65887780343334, 114.03556223838561, 112.91480771956907, 76.00372760526596, 62.799284150523526, 33.52446256145355, 34.44370923503753, 52.69123815721082, 53.54666394572104, 53.40038699488486, 37.92100806390086, 16.65525059546194, 1.2464586380989322, 0.11471804306511918, 0.048083707750324285, 0.03184282570146024, 0.5744716837521523, 1.5063528019574381, 0.7394495149773936, 0.34743064894310893, 0.1437886512928432, 0.18349232242232372, 0.5385512305844216, 0.3202691548053296, 0.8318655204869086, 0.5518715384025727, 6.06965946574365, 63.13902024299868, 103.93247804334088, 98.54041930167907, 88.4402298158215, 91.05948663526966, 100.18332758257466, 100.19764423370363, 93.38002358713459, 80.4263960930609, 79.52464319044545, 89.62615843742125, 98.37287133739841, 101.11120347053775, 102.70625099059075, 102.76493749310895, 95.70784830277967, 94.62951029500654, 98.54360426625898, 99.70456307934177, 98.81005871680476, 97.24374648063414, 101.31406061110958, 97.78035025442801, 98.96299192982336, 48.131788776766875, 57.63191446181267, 84.80719720163654, 88.03486854799333, 94.77251206674885, 70.59587740129041, 49.43509040340301, 100.48964115881152, 93.17460121647005, 89.43760225849768, 96.36011492821478, 104.40763396601524, 104.52182985121205, 94.45519231980848, 79.07538275564872, 77.5941937969577, 86.62320752297678, 93.23211100793655, 94.32118062050112, 100.90934261198967, 96.3782362784109, 94.53046260341522, 95.731460971217, 84.24108935940652, 92.4392117223432, 95.49584419496598, 103.6468824263542, 69.66885659002489, 31.46592424761865, 4.768403845448648, 1.6212900151168148, 0.7199141503341737, 8.49040562106717, 1.7155294937472192, 0.13195797079993835, 0.3526031520337828, 0.2559763136049432, 0.20773068551094304, 0.1258019870147109, 0.050318217686107086, 0.06610140625026918, 0.4523832236807193, 13.008202372058747, 30.736461454822173, 40.57359326270319, 35.78387329655309, 51.46027288129253, 37.323874273607814, 25.335673478341874, 36.37164831161499, 51.72424054914906, 84.91782372997653, 83.95996524441628, 95.11531937506892, 69.84694004058838, 30.003172389922607, 2.196710422154396, 0.1219740984660964, 0.07542010742209612, 0.06745838545142643, 0.20911370404064658, 0.0657107090697654, 0.12417583516047848, 0.06659887310477995, 0.013570510219001483, 0.04916140193780584, 0.10042977549376027, 0.05789088190443093, 0.10768180127225577, 0.08046007730186948, 0.04858202879287062, 0.03502011599559938, 0.07523420852639022, 0.029537289838997588, 0.05890746525819263, 0.022133166879235257, 0.10205405809345747, 0.028619639079777465, 0.11254083650607256, 0.0732690474439052, 0.06574521366987499, 0.06653128882809993, 0.11306976659163354, 0.061784611879697734, 0.03220717903346785, 0.026296743664950616, 0.04525093294139351, 0.05867298872720811, 0.02350196107140472, 0.038784154946164745, 0.033527175340080456, 0.019021932516367208, 0.07951100161599536, 0.20468121124131067, 0.1174841414115602, 0.10146816937072624, 0.20897326480236747, 0.15664947489576955, 0.13813711342311677, 0.13976540266265794, 0.1899070217604599, 0.11195714645568403, 0.12315096273537605, 0.2650571061718849, 0.19363014778542906, 0.17455999769510763, 0.12638449728969606, 0.14382361554570738, 0.23700800724327567, 0.2385230686876082, 0.13597659225906097, 0.16493269332474278, 0.21275950115053885, 0.2418603928339097, 0.4108641080317959, 0.17619280685340205, 0.21824930253769123, 0.21064018019505087, 0.23135067774884163, 0.2694681485093409, 0.19526764540182007, 0.23572640343298837, 1.2555655236205747, 26.07693279943159, 94.02723819978776, 142.1606586825463, 132.28590349997245, 124.44254382964104, 82.3220697526009, 60.36746171212966, 32.8600424720395, 36.768458812467514, 79.14834668559413, 89.9195360368298, 72.0444949980705, 55.29024377945931, 22.862222925309215, 3.1842671334743504, 0.24027262964556295, 0.3441458171413791, 0.2789681903537243, 0.6384980029636814, 5.130952442845991, 3.0292401102281388, 1.753936974752334, 0.4084018401561245, 0.5064480403257955, 1.4857137804069829, 5.403716516110205, 4.182136001125459, 4.301217688668159, 6.04493284417737, 66.77529273494598, 108.24091142223729, 103.87084976319345, 93.01277991264098, 94.50890525694817, 105.2254952153852, 103.61009843887823, 99.0397370246149, 85.83243416201684, 83.77040493872859, 94.33053155099192, 100.11305439856746, 104.77487764050885, 106.26246006258073, 105.37140738579535, 98.30946230119275, 94.0809040684854, 103.70185836668938, 102.48659041620071, 102.03285847940754, 100.25939802969657, 105.8845083175167, 102.26715733928066, 101.70119854711719, 54.34683530561386, 65.45980430418446, 95.54793327085434, 95.66679677655621, 105.03590353073614, 79.82930937120992, 57.45140698648269, 106.04310543306413, 100.17393742838215, 93.89584664375552, 100.42088200969081, 106.13731291986282, 107.00469801502844, 98.60803311870944, 82.48440096455236, 80.94903622904133, 90.68594363427933, 97.34775989286362, 101.50706475780856, 105.37409028699322, 97.85932325547742, 97.09608493312713, 100.05259498473137, 87.56730633397257, 99.0826948227421, 99.85915937731343, 109.2811083024548, 67.71040931824716, 31.300339429609238, 4.341271952275307, 11.298032306855726, 8.787230003264643, 18.44669903478315, 6.351273877005424, 1.9458698240980028, 2.5123364406247295, 1.368424861181167, 0.746426247060299, 0.1538689281310766, 0.259431017743003, 0.13641120926026376, 0.8826341059419417, 21.121624092901907, 53.24370007361136, 69.26507995974633, 57.47297610006025, 73.7397433865455, 58.97979382545718, 38.64026092713879, 24.697127303769513, 46.05568216693017, 92.68062576170891, 92.47008077559933, 117.08861750941124, 75.32816210100728, 28.752161841238703, 1.487089184022719, 0.2123694551447707, 0.17567058003717856, 0.1917177625000477, 0.27477848613935135, 0.2518325746660271, 0.1717103038343691, 0.13119485529680408, 0.11107090530135941, 0.18569422765604912, 0.2769668009733, 0.2752924392059926, 0.29470967309128854, 0.28391052998842736, 0.3771643598954524, 0.15610254940486726, 0.2815878433325599, 0.062309512342776985, 0.12844024826922726, 0.14945839141165057, 0.1917616133728335, 0.10286711486837558, 0.23361958503242464, 0.2840902235719466, 0.1931824766459965, 0.13063207178586914, 0.37450615737226706, 0.16330118651591963, 0.21163155925610375, 0.2550005474157872, 0.2249379855610671, 0.08758736098365438, 0.10854628552953083, 0.1545672785610922, 0.13685915619134903, 0.1175726245668146, 0.2889142792311407], [0.05419864071412914, 0.012607237966280552, 0.06300018274135168, 0.038831039527130705, 0.06121935390476739, 0.049398314628389575, 0.011994886651424872, 0.020573115006329554, 0.03692050817452612, 0.06550094653521815, 0.08697389309564907, 0.04168853599337801, 0.05646171040772911, 0.03531622813053189, 0.04452848138528005, 0.012113823716889226, 0.02657800901591057, 0.08383555262680016, 0.05206955213760657, 0.12889072329046267, 0.09525477495645324, 0.09419883766602125, 0.10367628757751758, 0.06851809955532513, 0.032612623406514045, 0.013310247168485678, 0.08668778989944728, 0.04138082145683227, 0.16246230491707403, 12.65715612519172, 66.47418022155762, 106.62261993654313, 89.55538319003198, 93.64732526963758, 44.543004420495805, 32.97339700883435, 18.850324653810073, 53.3048302127469, 83.62744239068802, 69.5535545964395, 56.14508513481387, 30.193489713053552, 12.887317865125596, 0.3602782805119792, 0.07513046489968415, 0.015583864935193092, 0.07106797724601722, 0.36088174329169337, 0.2870684363428624, 0.5523487192488487, 0.2305719800173275, 0.21679626357170845, 0.1941302806259163, 0.11505924330483522, 0.04416970708858102, 1.1207161531333, 2.4290662379034105, 15.624746872532754, 70.3169184346353, 96.37358434738653, 84.10112350217759, 83.0765925684283, 79.21633705016106, 75.37683087010538, 75.88550736827236, 77.10840040637602, 75.34025869061871, 72.3673217527328, 83.68295961810698, 92.17881341134348, 94.24910314621465, 99.01250008613833, 96.00791746570219, 92.62925055719192, 94.47798129050963, 93.51095230348649, 94.5120039293843, 89.68178549120503, 84.13866058472665, 86.20633802106305, 87.54146575927736, 96.92556381225587, 95.37397615371212, 90.34934936031219, 35.44179947145524, 51.9461957100899, 71.1945644501717, 79.94253250860399, 38.92666455238096, 74.46753917201873, 95.66179967695668, 80.17820419803743, 75.18289319930538, 85.68119541291269, 96.39759709758144, 93.60508918762208, 82.79822195729902, 72.24531250615274, 83.05505875618228, 91.83029513205253, 92.5228209649363, 89.70923423767091, 95.53399316726193, 92.94693900692849, 93.06508079651864, 84.24421156606367, 72.65554535773494, 82.24338700694423, 91.64730871877363, 96.40697156229328, 95.18047778837143, 90.71683622175648, 68.13849679885372, 19.125863313674927, 1.4209509136215335, 3.5929339787652417, 1.1996103390570612, 0.17830310329314203, 0.11012290979945853, 0.49403027601299754, 0.1718396807630216, 0.2598118860154383, 0.08771247846344787, 0.0773312976103156, 0.2942944227928116, 0.444131997083464, 6.787542441198903, 30.66628044651401, 60.47012190664969, 49.756916953671364, 67.25913278518185, 64.63385512751918, 27.472147326315604, 21.7772247329835, 24.287251387873006, 56.90901379431448, 65.42916274839833, 63.92927977346606, 64.49137110863963, 27.540392644943733, 1.91612477504438, 0.055819828318612236, 0.02802772699074159, 0.09643689458889347, 0.05068483672315075, 0.01293419758909412, 0.0634462604179017, 0.017631766386330128, 0.10558162485399555, 0.014424342981299326, 0.01865495150277932, 0.1253345814503489, 0.08140493950416004, 0.016611166816625385, 0.04096388576492187, 0.024262912376152895, 0.0156702566704142, 0.055584524412669485, 0.04749319951740965, 0.017483735216721412, 0.03773946765690081, 0.04267492016116458, 0.09116054828008337, 0.005808719480785752, 0.025944862244350296, 0.03826865821235603, 0.08259880326447949, 0.021113228060365207, 0.037134863406179414, 0.04101134108139142, 0.016826050648946437, 0.06946814817286308, 0.10708972255909636, 0.041332741778704433, 0.0603961004995771, 0.05888078241578995, 0.03305020899842343, 0.030802552993859977, 0.050447632919155785, 0.0820456724613905, 0.05284896233089028, 0.014489014208647273, 0.030181613833373113, 0.04194589557066079, 0.03898362508944927, 0.08522625501838424, 0.02352479815242752, 0.044844779937017354, 0.05856010567156538, 0.06033051188193983, 0.037704760043491284, 0.021733414539466464, 0.06304078157089892, 0.06658709833338376, 0.0728694559826005, 0.05478446431938679, 0.06341321138484825, 0.06522602822271086, 0.04608125350768528, 0.017150981096370567, 0.012122889409863181, 0.11279808117016671, 0.09192320413046307, 0.050939821427868265, 0.1851224043076077, 14.159126781648206, 80.307736550608, 122.7073892470329, 105.81243868797057, 111.06135445256388, 67.71761078988352, 52.684256338304095, 35.32652493446104, 46.2656387975139, 44.03801887266098, 48.03155652938351, 51.923316524874785, 34.03406081661102, 17.65635713454216, 0.44624106778252515, 0.010019569158283694, 0.009824309625752993, 0.1685183065673036, 0.6206772043820351, 0.6262326901478152, 1.223297042231406, 0.3656881789286291, 0.14327638361963535, 0.20946019028704013, 0.19279325801518657, 0.1201451937818239, 0.41400322991032756, 2.3844987971167413, 18.703881002241566, 77.65665361958166, 100.26019034847137, 87.5314558705976, 87.35057969247141, 82.473967459894, 79.0232309218376, 78.6783447573262, 80.4580339308708, 77.58014386700046, 76.86266391508042, 88.78886576621764, 99.83959459489392, 97.8475247659991, 102.24396044208159, 97.91775872630458, 97.68981410611062, 98.31276493687784, 98.32286896244173, 97.28712789473995, 92.49491722353044, 87.20099618357997, 89.25594945107737, 91.14910494896674, 101.90389094814178, 97.60506737616755, 94.9412759657829, 43.689249561678984, 60.76713946557815, 82.8668006773918, 90.20946979522706, 49.16852220412224, 80.6878455992668, 98.85343228617023, 83.84391800049814, 79.14698954551451, 90.17908711587229, 100.7144400381273, 96.46835665549003, 86.02783879926129, 77.39114838261759, 86.94248061026298, 95.32416989726406, 95.8165293355142, 94.9087595170544, 96.40515942727366, 94.0145375651698, 97.08238801648541, 89.91235809941446, 75.08965846030944, 85.60504651838734, 95.90185657624276, 101.05650994085498, 100.6185459321545, 95.46051932919411, 74.18073546501898, 26.785228521593158, 3.402498003936583, 1.1788552398643186, 0.7840954031675094, 0.5631024486595585, 0.6522813343232678, 0.11415913595908111, 0.6508260737023046, 0.3673179850222603, 0.08382142596547643, 0.08174781747643026, 0.19198178704227173, 0.3676216009884112, 7.964968344857616, 30.55055287576491, 46.43436739521642, 35.16677071971279, 37.54798673814343, 41.501755483688854, 23.30082824153285, 27.299321812968103, 47.659857042374156, 75.14017074338852, 78.8040174976472, 82.00915874973421, 83.70601530997985, 45.98320853325629, 4.462440831045951, 0.17937098389431355, 0.06694383483620421, 0.08690591811412766, 0.02664864040730942, 0.07941974522245508, 0.028939894475643674, 0.055039954642134334, 0.029835570002755815, 0.011234711968309937, 0.04047420236372179, 0.0898195649947851, 0.08038080252346494, 0.016196918178109393, 0.06037245902623381, 0.026274341338824843, 0.04142963657936743, 0.04406392183755675, 0.00928831812474997, 0.024485715642391194, 0.0998116804346923, 0.03989405546998305, 0.08120096859432037, 0.060087045309163874, 0.017778297938827067, 0.07995390768853888, 0.1107212474509593, 0.030905304536704096, 0.048493392420031374, 0.0610994802968156, 0.02169822620588445, 0.032381241870743614, 0.04423007481701432, 0.023488263419318586, 0.09372899594206004, 0.0762648725762002, 0.14900816153855095, 0.1383953769841502, 0.161883142446318, 0.2008272220771159, 0.13528207226866676, 0.16800839844490253, 0.08858562717514654, 0.17722120328295618, 0.09837003319614357, 0.21423463409225788, 0.21560119705334788, 0.26537429721605393, 0.16406350528761265, 0.13182362962153651, 0.20626531252937935, 0.18345414060017756, 0.18091823635322435, 0.16778952712493558, 0.14313554601563563, 0.2592219063831914, 0.1929649689625348, 0.2304571281157194, 0.3007643417485299, 0.13484319581860496, 0.19362904461881808, 0.1974927630996512, 0.21298462374796792, 0.22690912979024075, 1.090986425838163, 25.77781677246094, 101.53102259482108, 139.06666171166205, 116.96529034645327, 124.9510242092994, 70.30431978164181, 45.909617024083296, 25.82161395780502, 76.09078068887034, 106.27873789879584, 92.66176700592042, 81.28330845986643, 48.63347953365695, 24.089203073132424, 0.6461595563638596, 0.3074973352974461, 0.1061847735376608, 0.34405063837766653, 1.2344800873148827, 2.1195681873829137, 3.103507737959585, 1.792368847996958, 0.6217485630223829, 0.4806216229354182, 0.26310998646001665, 0.4923505822737371, 4.374680249921737, 4.384923029330469, 20.240038056527418, 84.64459142377301, 105.49623289415914, 91.56487618723224, 89.8462426277899, 86.59929675440635, 84.41317942834671, 83.57318816646453, 85.60099863236951, 81.82143411328717, 80.8542952998992, 93.54368840494465, 103.5115449659286, 103.76176864870133, 108.10697032559304, 104.37578432021603, 100.61563553348665, 101.35966208673294, 101.59925614633869, 101.6654500653667, 94.67886940125497, 90.24657541705717, 93.16675647612541, 97.40965489418276, 110.84904439987676, 103.79145314616542, 98.08136863093223, 49.31898824630245, 67.13113800171884, 93.42491903612691, 101.5964477292953, 57.13908826151202, 83.50941827220302, 105.55520180732974, 89.61154368615921, 82.41788541117023, 94.32372231637278, 104.46185681127734, 100.2181346954838, 90.69083875225436, 81.63687875193935, 91.08793950849964, 102.25086381358486, 101.90252596332182, 96.9421789723058, 100.85121308603595, 97.0825449112923, 100.59683953562092, 93.3045885639806, 79.21347371993527, 91.52278131054294, 100.08178526355375, 105.67631675351052, 104.77491686421057, 98.7053628121653, 71.34088454707977, 22.847108071850194, 3.492094499449576, 9.09826611318896, 3.254975700570691, 1.7691060059493589, 2.1514180783302557, 2.1073311278896947, 2.0819551089117607, 0.7330473488376987, 0.29841340177001496, 0.28166432955092, 0.6201526486585217, 1.098085793275987, 12.987914892934985, 47.27505291661909, 85.69781841770296, 70.10327477608958, 90.5127239227295, 83.79877936455512, 36.33422105543075, 28.6899628562312, 38.82578903628934, 79.80178217734061, 88.27162281159433, 99.73609109078684, 104.04973337727209, 47.637079838783514, 4.0141308355715974, 0.21997816379993196, 0.20292818756593814, 0.19105747131811035, 0.1545434532266471, 0.1572331113200034, 0.1307431851784068, 0.23702931980932915, 0.22505196412244152, 0.08866274924648386, 0.11562790271014937, 0.24519503567247625, 0.2008511699856289, 0.08969498377653862, 0.14318603120984572, 0.08160588436669881, 0.11940214212142652, 0.24671424931335836, 0.17412652982579124, 0.12532004110154607, 0.20113488298750695, 0.0775842215385168, 0.3348306782784001, 0.15941774893191554, 0.09126839047718434, 0.17082239260836957, 0.22931274597442922, 0.11143983792393439, 0.15621976085728215, 0.11419321921083236, 0.11449287450241466, 0.1499612208816313, 0.202688769767842, 0.14218611792931635, 0.0994937539461159, 0.1273633278305492], [0.04307514364500681, 0.04315152261105757, 0.03866329691523025, 0.04239281977436716, 0.06874983349154073, 0.06450381415385394, 0.029251016188232653, 0.039659467856249506, 0.03032071624822434, 0.03519418649375439, 0.027975433829030203, 0.05091428005647275, 0.020473121380012844, 0.027766029440587568, 0.09968390462980156, 0.05480615226852317, 0.07466227792563938, 0.05914225588522612, 0.051080245344388875, 0.03904544072405946, 0.09574890166761414, 0.09081921780542021, 0.06643120710167193, 0.017995169769311627, 0.02396148933668531, 0.04544730808946394, 0.09704408821679893, 1.8119831503398958, 27.381846520208544, 66.67047915920135, 96.79093237846129, 94.32491471690517, 70.01735133509483, 54.38061867990802, 28.190796144547004, 22.4568675410363, 60.16757380577826, 51.44865089847196, 64.47659554020052, 56.162131755582756, 31.539105869108635, 13.204691544655832, 0.577505330645269, 0.08618797881588822, 0.27395472711613106, 0.03245449136762369, 0.1389403872552418, 0.16171710054960944, 1.60248163727022, 2.9067648370419783, 0.4185799004570131, 0.1489626405940902, 0.16389061456486104, 0.061905144323264404, 2.286593250689968, 17.318091930881625, 54.589786914087114, 86.01450274067541, 85.98441816145375, 93.2411559935539, 88.22327567685036, 80.80332017713978, 72.71411418914795, 70.91333050881663, 67.39434472976193, 68.20940540682885, 66.04932477397304, 74.8019604529104, 89.98196448049238, 95.16264669356808, 93.53351377671765, 91.05568193620252, 83.6765661547261, 84.27174660467333, 93.67899448640885, 92.87584212518509, 85.82466002433532, 83.94007098290228, 81.58806093277471, 80.85492287912678, 81.27344762125324, 81.51945083372055, 88.2467471399615, 91.43917206794985, 90.48178426681027, 31.47785217531266, 67.78680139972319, 61.05853626804968, 59.04323816299439, 99.27954289220996, 82.47788198532598, 75.87962381301388, 65.62054303384596, 74.55567482979068, 79.36653244879939, 78.93632688829976, 72.00355329821187, 84.23456253543978, 89.68050679852887, 95.25382611059374, 96.14851090215869, 95.36023216862833, 90.48150970089821, 90.16445667512956, 90.72134694745465, 88.4813754789291, 69.92019422592656, 72.23873861374395, 84.04331561057799, 91.91319050327425, 93.73595514605123, 93.79544181208458, 94.22012467538157, 100.29294213941021, 67.50644606928672, 23.573107411784513, 1.1156023630211431, 0.3878084161589223, 0.5979429017151556, 0.10052883832324898, 0.15719764144910922, 0.2399884110256549, 0.20797215642467623, 0.09820835033972418, 0.051548114391945066, 0.10193438749880561, 0.15863914313095231, 1.5462513964983726, 11.372231783405429, 45.801618483758745, 48.318579889112904, 48.67309939476752, 83.69626429773147, 43.08254518816548, 13.670184708410694, 23.715348243713382, 40.97323179244995, 56.28728282067084, 69.12047001623338, 74.32973061838459, 36.22887795971286, 6.229266101314176, 0.21164496579477865, 0.08895664355687558, 0.06573022899007605, 0.029870969010517005, 0.10567819789773035, 0.092110144905746, 0.02625982397265973, 0.009865401624401492, 0.07502803894420786, 0.0212673228158946, 0.0793501997606889, 0.010983527059696857, 0.018058132620588425, 0.07786783494896467, 0.039713879251071525, 0.08001321821563667, 0.022138048774532737, 0.024224517964607766, 0.01685723042746465, 0.014166126343151255, 0.015270754266830703, 0.0365750331641926, 0.06081633803044116, 0.025415053072896217, 0.10462320289544522, 0.09243519601201819, 0.039639197169773044, 0.041087222090291406, 0.023664350643934264, 0.015822059865440094, 0.07557734696855468, 0.023150774875595685, 0.03179427487925897, 0.09147427660683471, 0.04846776294852457, 0.04393046166026785, 0.051358829387613845, 0.04227868033452861, 0.010181019315496087, 0.0184379436916882, 0.0107687677166635, 0.09370112566337471, 0.02288720041002718, 0.025562549896177747, 0.06059392738426405, 0.027090303502195788, 0.0438964128824732, 0.03706488510473602, 0.04500657770662539, 0.09855142749485471, 0.09086670759584635, 0.10993428363074219, 0.040568829544128916, 0.02039736294518075, 0.05351337506586025, 0.06275472817041221, 0.07593244404321717, 0.025598435369770856, 0.04098018428551094, 0.01459076121870068, 0.07307895038637423, 2.6098789226624275, 32.823142774643436, 79.80880321994906, 114.52291673229588, 111.21529963708694, 84.33679519161102, 76.77620703174223, 42.321134690315496, 29.751611178921117, 22.317923461237264, 50.28057690589659, 60.68629549395654, 48.943201649573545, 40.30359298952165, 16.3300351173647, 1.003925681354538, 0.11393740713115662, 0.3371705865908054, 0.06067838857791597, 0.11772047187532149, 0.6383597394151073, 3.0964945400914843, 4.846764466454906, 0.4455054088705971, 0.24444972405270224, 0.2649594146397806, 0.3047662624909032, 2.8105407616784497, 19.783144689375355, 58.30307122199767, 89.71497658760318, 87.49693116834088, 96.21876055194487, 92.84465928231516, 84.07364337675034, 75.19280110636066, 74.27022826287055, 70.01918700433546, 70.35005461785101, 69.58636130056074, 76.83442284983974, 91.32362688741377, 98.15932181573685, 96.91527935766406, 93.25668857943629, 86.08344231882404, 86.74317713706725, 97.69234011250158, 97.09549657760128, 90.63041071737968, 87.59015806259649, 85.3191920249693, 83.80426283805602, 83.37641854440012, 83.50100086581323, 92.39693641662599, 93.18367758104878, 93.59795047390847, 40.2702332312061, 75.92602545215239, 69.4055792593187, 66.7527469511955, 100.87217423223682, 84.97628273502474, 79.21801582459481, 68.43914647256175, 76.88261308977681, 79.57861500401651, 81.75263574046474, 74.96938290134554, 86.34387200878513, 92.1820297548848, 99.38662359791418, 97.44936496980729, 99.98238455864691, 93.34054885372039, 93.36142370777746, 95.05842931808965, 92.633008187817, 72.5025180078322, 74.29256223863172, 86.80527610163536, 96.31659230878277, 95.7765054702759, 96.51052213484242, 101.06585302660542, 105.3533801724834, 77.29228896479454, 32.98980820563532, 4.191329056216825, 0.3469805263223187, 0.4557205478270208, 0.540540668993227, 0.17835939543381815, 0.39110192007595496, 0.26167455219453384, 0.021464967754699533, 0.05410487538263683, 0.1257449977340237, 0.035921966191381216, 2.1964812086474512, 14.8342510192625, 43.785790858730195, 43.85727605512066, 47.51135610765027, 53.01764995821061, 31.71747957506488, 16.046076109332425, 43.54130168114939, 64.74435614001366, 72.00261192937052, 85.66364672876175, 92.72801583813083, 58.59611934231174, 13.327854948659098, 0.6768689568965667, 0.16035688079653249, 0.021577697592757402, 0.028192253948579875, 0.039988035306094155, 0.019028448094163212, 0.04901746167771278, 0.025882496941654433, 0.06102857885942344, 0.033521173041193716, 0.09107894459438902, 0.03514075952191507, 0.025045576527894988, 0.02949362091209379, 0.03625378185402482, 0.06276882801865859, 0.034991579220419934, 0.01878602914662371, 0.015373832354652546, 0.028463527597787402, 0.047635079000986395, 0.00917935456644984, 0.001556135487795297, 0.05075962605675863, 0.08678424802999343, 0.1374894014048961, 0.02060187011656742, 0.07335979821941546, 0.03563859026818987, 0.017350278869872133, 0.044639119803304636, 0.01798262316433172, 0.1377501624125627, 0.04833948152560381, 0.20250014359912566, 0.13650674042442154, 0.1697879747277306, 0.19413788021812517, 0.1446261845769421, 0.14040761416958225, 0.14573926436564616, 0.1205185697143597, 0.1339080476111943, 0.09497456297638918, 0.1333884408156718, 0.15660675783311168, 0.2130033929021128, 0.21400140628458994, 0.26360944514313056, 0.19006008612773112, 0.3171940472337508, 0.30571391325323816, 0.1928254030644894, 0.18063381855045596, 0.2643780764793196, 0.16321170744636368, 0.1308675212485175, 0.1287260603520178, 0.08894417164546829, 0.17142898102681484, 0.14862602156016136, 4.398837147220489, 53.576073877273075, 105.45045883424821, 132.4198602860974, 120.55611825758412, 101.47286953464632, 78.11886572068738, 46.477995918643096, 37.40027419982418, 85.59492680334276, 72.22394343345397, 88.53622590341877, 82.59472939275926, 52.20902196822628, 23.330618642991592, 1.5284225080282459, 0.5173059576942075, 0.613342433446838, 0.4218801765912964, 0.5189925155812695, 1.587431993215315, 4.282665368049376, 7.812381771302993, 0.6764613368338155, 0.3845431349210201, 0.3634336128109886, 0.6728867705791228, 4.220333022456016, 20.73584133578885, 64.05624297357375, 95.62953425991921, 87.36691244186895, 100.87201733742991, 98.11404197446763, 90.02770716144194, 79.75618854645761, 78.73048874639696, 73.60126802998205, 73.62411191386562, 74.17322020376884, 82.35793590545654, 96.77303068099484, 102.7633136318576, 99.82490924096878, 96.99922592409196, 91.11592954204929, 91.56784934382286, 100.54503287038496, 100.3715072139617, 95.63249172702913, 91.60238189081993, 88.13736792533629, 86.78216549658006, 88.12609503346106, 89.23429012298585, 99.43367635050129, 100.19762069948258, 98.5707078441497, 46.78516849394768, 85.7908413487096, 78.72981409872733, 70.73950675226027, 108.93419819493448, 91.80030468971499, 83.48626059870567, 71.18850831062564, 80.21816530535298, 84.36641693115234, 84.73530015637799, 78.69554042816162, 90.47192342819707, 97.08509445190431, 102.29222128468176, 101.18334370274698, 104.06619948725547, 95.36884569352674, 95.28693875958844, 98.96962858015492, 96.04760400710568, 76.18654143425726, 79.19491306427987, 93.70878096549743, 100.07812961455315, 97.71049284165906, 103.23866567304059, 104.60586270978375, 112.8986789334205, 80.18881813172372, 30.371420191180324, 3.700027922468801, 1.4372057059118826, 1.8959299619159393, 2.1459105803120524, 2.1492164029229075, 1.4823557412432087, 0.8379353883285677, 0.33309429403274293, 0.24979203819267212, 0.4430956946265313, 0.2665214372738715, 4.7012298241738355, 23.967287963436497, 68.76374613854193, 72.21991123691683, 71.14623300490841, 104.55543671884845, 61.76299787336781, 20.185128796485163, 36.45759920920096, 60.34732034129482, 78.74711175118723, 96.55307985121205, 110.12688113797097, 63.784363885079664, 11.729440073813162, 1.2722672209624322, 0.2228298494892736, 0.1384629919043472, 0.12758304184723285, 0.09880962210797495, 0.2565922636178232, 0.2481586927728307, 0.08976494292578391, 0.1259542010243862, 0.16162316284833417, 0.17872299608444014, 0.1600175651331102, 0.12378631009449884, 0.25082786567509174, 0.195711164344703, 0.13293586671352386, 0.22162560523758013, 0.09863581974059345, 0.07606568971588727, 0.13141231701499032, 0.20156893308364576, 0.13658744012636526, 0.23747492251136612, 0.1419883293490256, 0.18458028984886987, 0.28623294085264206, 0.08262000857822357, 0.16823557415796866, 0.11265263937774206, 0.14534279854307253, 0.12169097535192006, 0.17164187686097238, 0.22825419632417543, 0.16291582896824808], [0.035962204959604054, 0.010220933453961006, 0.04132061077642345, 0.043099604832429084, 0.09403214459457705, 0.015955763275644953, 0.006927015370644269, 0.045348275903492205, 0.034331215260129784, 0.030842316787569758, 0.04844649251730693, 0.08716433489274594, 0.031616167097743, 0.058428997384204026, 0.01843641343105945, 0.06014128816464256, 0.041080311977214394, 0.04813184105460683, 0.010423035109265438, 0.018428193307631922, 0.07971273554909615, 0.03501597912080827, 0.0448928251411886, 0.0225428611250414, 0.05497440432889327, 0.07080471879171749, 1.401243577561071, 33.42107672845164, 83.74981249532392, 113.60570184646116, 95.59026348975398, 82.55252468970515, 57.79552436644032, 22.588400302394746, 29.678398178469752, 81.09369324099633, 126.55174347662158, 56.043974276511904, 46.70429706573487, 30.911275609847042, 13.015051810972153, 0.09821301581518305, 0.14921641487988735, 0.07687562851295357, 0.0651041359730786, 0.041035875047166506, 0.5977407157901795, 0.23264771056992395, 2.167192625422632, 2.4950890435326487, 0.451236819067309, 0.6628508349099468, 0.8749708977918472, 11.97378412369759, 44.762217844686205, 89.59478732078307, 90.79100039697464, 88.997175001329, 85.55320062944966, 90.1980007848432, 86.949901734629, 84.05594564253285, 82.51392072246921, 71.19259542034519, 66.59136495282574, 69.18681298532795, 71.76272761437201, 67.66726324635168, 80.6277862671883, 88.38193555032053, 84.5874503351027, 82.1872422002977, 71.99274324601697, 77.74722114686044, 90.85339746167584, 90.8931859847038, 82.92154912025698, 85.70727132981824, 81.86616482273226, 76.69262132337018, 76.10377157888105, 75.7440431656376, 78.48290874112037, 83.74760027854674, 88.71902404292938, 75.27791653909992, 26.03856613559108, 39.39424637825259, 86.34386416404479, 85.83688212979226, 78.24241253637499, 69.76622550718247, 68.87006590443274, 68.49500886855587, 69.5805718821864, 65.83976038040655, 74.96816696659212, 85.71586916523596, 90.76049220177435, 90.07727023093932, 89.98933853641634, 93.57814250453826, 91.21803668237503, 84.81631278991699, 91.51655258670931, 85.98944664001466, 68.42232734926286, 69.03140867910078, 74.89720344543457, 86.75228488060736, 87.4189858282766, 85.3258365200412, 80.30283358789261, 83.01401507469916, 93.13887626894059, 97.1978625943584, 46.93005300337269, 7.4421664111075865, 0.420855304166194, 0.34144419275464555, 0.3370855201876933, 0.2441847802049691, 0.11510759111373656, 0.0835978125612582, 0.04582131604453729, 0.0692692794085991, 0.10525287354304906, 0.2262997374899926, 1.5285079421535617, 5.783026381846398, 22.944202423095707, 36.883286199262066, 50.450462602799945, 57.33969396160495, 55.87623803846298, 26.2281499754998, 13.17957562784995, 36.9300094727547, 50.00280641740369, 61.643557779250614, 74.09849120724586, 67.41065394493842, 15.739484044813342, 1.5612333796678053, 0.07008697867633835, 0.09503545930549022, 0.022204428377951828, 0.003404170105744514, 0.021120636130592996, 0.04059544726905804, 0.1206781764725043, 0.05828425273179047, 0.07271846005272481, 0.0014950199857271548, 0.026721267457751018, 0.03299229658178745, 0.040920892910611247, 0.047396515390925834, 0.017584096565241777, 0.090549539534315, 0.02901610873279072, 0.05234014971422092, 0.01521851856171364, 0.06409409884062987, 0.03858001549698172, 0.04431855414182909, 0.029677704179419145, 0.05605148947647503, 0.03015379526562268, 0.050908009626812516, 0.015208887878895528, 0.04591002136528973, 0.06082324431307855, 0.013468134059240262, 0.07645131539433234, 0.06564469527333014, 0.03192860648156174, 0.05007562828400443, 0.0465480002364324, 0.0237038022568149, 0.055028218175134355, 0.043591915915209445, 0.03873066668729148, 0.008748099733624727, 0.02007682984244199, 0.008134121439539859, 0.04492328096661837, 0.008277123241925673, 0.005525204704158129, 0.09920202000367065, 0.03531997430048162, 0.06268171616078866, 0.004997336129177242, 0.017951594688178554, 0.06464610732490979, 0.04199576789453145, 0.039615873622918324, 0.029143687270040956, 0.052131149437158346, 0.039781524814785495, 0.043945036483027285, 0.031050610348522186, 2.00339934998943, 39.49840491817844, 100.44001533139138, 131.05351832605177, 111.04047959850682, 97.79394518944525, 77.25409292405652, 47.09960922118157, 47.63566386315131, 64.1564634538466, 103.20578052151589, 46.00359701341199, 43.305229909958385, 38.89345384413196, 17.27000955612429, 0.09512080150025506, 0.12642090178785786, 0.04147073336606545, 0.0341686207590805, 0.07400799287302841, 0.6684225004526877, 0.32753963564192096, 3.3903518944017352, 2.1394891700436993, 0.28144210276584475, 1.1973573051152693, 1.8394203748433822, 14.569619490254311, 47.87614830078618, 95.85963618370795, 94.75114299405007, 92.00965727529218, 86.9194092289094, 92.4419181577621, 91.7954723296627, 90.40769853899556, 86.53561315228863, 73.6359888507474, 68.7060010048651, 72.24236288378316, 73.72483053515035, 69.54110499351256, 84.57972326586324, 91.93266114880963, 88.3744045995897, 85.05699726843065, 75.65751567963632, 82.10609620617282, 93.62907055885562, 93.22315231446298, 88.7276061888664, 88.3358947692379, 85.88571563843759, 81.30445003509521, 78.62380027770996, 80.48657309624457, 83.76912624605241, 86.28250260506907, 91.49748202293151, 78.75261091416883, 33.77654937005813, 46.58773599132415, 89.16244799090971, 88.94390921438895, 80.76351596463113, 72.31525621106549, 72.6418641305739, 72.35101253755631, 73.23759371234526, 67.7136178170481, 77.7921558195545, 89.32760330938524, 95.97862520525533, 92.43306144591301, 91.7781589877221, 95.83045374962592, 92.24648998629664, 87.75212057175176, 94.99738939346807, 88.64636605785739, 72.58761775109076, 72.22009166594475, 78.98263439055413, 90.06858610337781, 92.92760172197896, 90.74535185290922, 86.523602854821, 86.48001747746622, 96.62690670259538, 104.89735757150959, 57.33903892578618, 10.692225175519145, 0.4941846886950155, 0.34192492824889004, 0.4958112465758478, 0.2952173135934338, 0.13374476363101315, 0.07547025553761952, 0.09743224198539412, 0.05571788882896785, 0.12281380743990022, 0.16621604381549746, 1.0282744683565632, 7.704858818361837, 26.669165588194325, 39.08053521187075, 45.332789344172326, 48.629251218611195, 43.50241530326105, 23.968864756245768, 28.537886681095248, 57.04162128510014, 61.40128866318734, 74.78823215730729, 89.76580266029605, 95.41177995743291, 29.869048903065345, 3.0967333143757236, 0.034911247240679885, 0.07070086025182279, 0.021682697603659287, 0.00617945384639766, 0.04078576649208704, 0.03746136624906813, 0.10354761544975544, 0.007796197183310025, 0.10373520739977399, 0.0284259069350458, 0.02578280783528763, 0.01244629821514771, 0.025157657106437033, 0.04376839959032593, 0.025273416822235432, 0.05744999830400752, 0.045705947033580274, 0.046701922622178836, 0.019953311571190437, 0.04231251077726484, 0.03958536800177347, 0.00810703065531749, 0.020691366423101678, 0.014569808713971608, 0.03818799681480854, 0.05690730161844723, 0.011558310380355727, 0.07825686205779353, 0.03409314194634076, 0.05567625961116245, 0.04872141082981422, 0.08205031495421164, 0.1344249577772233, 0.09868740044053524, 0.1528781006533292, 0.17466475255787375, 0.24257495368440307, 0.13445494245857964, 0.1572302308294081, 0.13251404338065656, 0.08079025353635512, 0.08940248374616908, 0.0977666317034633, 0.15804194695045873, 0.14933356504526832, 0.3097537093825879, 0.19406288021033813, 0.1890585334190438, 0.27738566720677965, 0.18577253716366907, 0.10593927300144589, 0.0945691415859807, 0.2227346554038025, 0.10318623645411384, 0.11660142426168728, 0.1585114209522163, 0.11665446818956446, 0.1391741053591813, 3.1576960173345383, 54.88305468713084, 118.53890603588475, 143.07825796065794, 123.41616938191076, 113.74275730502222, 84.39573272582024, 37.84040335685977, 44.87122443414504, 106.21826279547908, 149.84418961309618, 74.15347499232139, 70.46090864366101, 48.449543906796364, 24.05992650216626, 0.280182286496124, 0.29968403520122655, 0.18128203618670666, 0.26496873026893986, 0.19363164931776064, 2.751729723907286, 2.2407579037450978, 5.137896018643533, 5.200101377502565, 1.2199367967344101, 1.7797283972463303, 2.685698828389568, 16.498659772257653, 55.33689645028884, 104.71403383439588, 101.27029480472689, 95.61308383941652, 90.88186602438651, 95.0481919319399, 95.19644183497276, 94.87501144409181, 94.16402693717711, 78.57716329636114, 73.75430322462513, 78.59429620927381, 77.06995333394697, 73.70288095166607, 88.3365458826865, 98.16664880321872, 93.75935600649927, 89.43179715064265, 78.6882761986025, 86.52663876933437, 100.7681215963056, 96.99688819146927, 93.70223060730966, 92.7188531814083, 92.08303697647588, 84.64048077983242, 83.84801295495804, 85.85708233617967, 89.09489693180208, 90.93860703129923, 99.12351885149556, 82.4662874590966, 41.367920291039255, 55.58924213532479, 92.99284642742526, 95.29004527676491, 85.99889170738959, 77.30917869075653, 75.15789201182704, 77.64625933862503, 75.51902463359218, 70.72109514667143, 83.69919823062035, 94.96025239267658, 99.39748071855115, 94.9685521279612, 95.61848102077361, 100.16254686540174, 97.955303653594, 90.92764008429744, 98.70027157568164, 93.84174146959859, 75.74075621943321, 76.38735109759916, 83.66019418162685, 93.97237208581741, 97.00023789559641, 95.23727370846657, 89.51175074423514, 90.51215125668435, 102.20459553503223, 115.7137090929093, 62.57196710955713, 10.285980393809657, 1.2834664458228697, 0.9539655944512737, 1.1392006902925431, 1.0210749579052771, 1.1852162211172044, 0.503311860224893, 0.33554727692277203, 0.15513236033579997, 0.33698035163744805, 0.4928112156208485, 2.7184189952188924, 13.582854117116621, 38.698457133385446, 55.72033951359411, 72.1039032167004, 72.462109750317, 75.38418923654865, 37.682669162750244, 19.723591343049083, 56.104998511652795, 72.91302542532645, 83.99496063109368, 106.20651921918316, 108.23711456791048, 33.19166514181322, 3.8368610316707246, 0.20520495491162424, 0.18455505491264407, 0.1036112696953839, 0.11443169472078163, 0.1731321477000752, 0.1443153827060615, 0.2340653103085295, 0.11444154661148788, 0.17979921172222785, 0.07002965997784369, 0.07143500997054, 0.12695519448888878, 0.1861403819413916, 0.1539338770652971, 0.09884536777052189, 0.14696744120409413, 0.16746876611103936, 0.08997770086411508, 0.17793467628859705, 0.22840981942511376, 0.08660084658092068, 0.13392436528398147, 0.14602582721460253, 0.15843211553029476, 0.07264551316057483, 0.13242462559813453, 0.11911528815905895, 0.15808734532085159, 0.14210592384540266, 0.1358973328024149, 0.19889597570703876, 0.19801882035549612], [0.0572056430692394, 0.02370033762417734, 0.027958899736404422, 0.027083427863075372, 0.012346295012731948, 0.040031702317778146, 0.09123089813417004, 0.02835526979798752, 0.023278807319941062, 0.01787515826553347, 0.03743964382597516, 0.011885136895392452, 0.01696956381502171, 0.04091194117321603, 0.021094043303521413, 0.09620490784366285, 0.05182186058992821, 0.039962915283057, 0.025013925605303338, 0.012454313410055495, 0.09260843913521498, 0.05433742903293141, 0.061150926931370655, 0.04714232741764957, 0.0011541771739082892, 1.9626086613824292, 48.69716705814485, 97.35386310085174, 105.78877110635082, 93.94325240965813, 71.91093829370314, 57.16634873420962, 35.33076893898749, 34.82210028556086, 44.430189209599654, 80.07567344173309, 62.20636690816572, 63.86780054338517, 41.458327001140965, 17.149906581447972, 1.0488009669127003, 0.03704586314157613, 0.06084755228291597, 0.02083097445598293, 0.21773832189219616, 0.062303433435097824, 0.15814798884093761, 0.2654099969133254, 3.215660313444753, 1.4660368427153558, 0.3097101649449718, 1.0753049124633114, 16.15187223880522, 59.337255108741026, 85.28062728143509, 79.54800482719176, 81.68237040119787, 87.24974340008151, 87.8400287320537, 85.97138020300096, 89.15693313844743, 89.50381186700638, 84.21480163451164, 83.95971421272525, 73.3794423072569, 66.75215075092932, 65.26109703125493, 67.55282417420419, 64.13949528048116, 71.48820092601161, 68.35330932371079, 70.06839706051734, 63.7169736431491, 66.0363103497413, 74.56673591367661, 85.46380981322258, 79.21339527253183, 86.02830163894161, 82.75896687661448, 87.93305166306035, 76.69058953562092, 75.63984932438021, 62.331098279645374, 76.80563265277495, 72.73004685678791, 101.90541282776864, 45.35490758957402, 42.09452367598011, 97.83867589889034, 73.36258396025627, 85.86593904802876, 71.97477094588741, 70.29652210973924, 66.9332387370448, 71.36623874787362, 64.37666923769059, 71.69859686205464, 80.27537699668639, 92.23919437777613, 85.22972276133876, 90.10777058139925, 84.04981105558335, 86.54490132485667, 87.06976152235463, 91.9626751253682, 80.53063700276037, 67.37482701578449, 66.71510004228162, 68.53293034338182, 69.42105693201866, 71.71800474966727, 69.34093075413858, 71.7552908005253, 81.03342210092853, 89.72548853966498, 88.31054841318439, 79.42145347595215, 60.478150998392415, 20.669280675149736, 0.6656204572608394, 0.12101035219647231, 0.16110677362209366, 0.17662978340541163, 0.059901422205110716, 0.06976668497607594, 0.035474900261408863, 0.13091701052842603, 0.11490359722125916, 0.14085845691302132, 1.9286589540781516, 10.544330246986883, 26.319490209702526, 41.957762395181966, 40.17873610219648, 56.49192856204126, 86.99915885925294, 37.20508921530939, 18.700311645384758, 40.604838863495864, 45.28169655030774, 48.64638805389405, 64.2474232181426, 69.79939306935957, 27.210352651534546, 5.576687647450355, 0.08530130865232599, 0.018020517703506257, 0.050131407145771294, 0.07102119991736067, 0.04211004906063599, 0.04053289619004054, 0.03286147940783732, 0.005254523815482014, 0.05872314067317113, 0.034224139150953105, 0.03506516196554707, 0.03894472697509393, 0.02875919540172383, 0.08834073950927104, 0.022640096834830703, 0.13576345127676764, 0.033052246792302016, 0.06032251775444997, 0.035035778663211295, 0.037330997236553705, 0.028780377732830185, 0.020642225713198705, 0.04534332314506174, 0.022724538876284516, 0.07125878676531777, 0.07419940760178913, 0.061506851380991365, 0.030998612130661646, 0.019207067239368637, 0.044249475993696726, 0.01530668762091908, 0.07018768859486427, 0.06369214016763915, 0.03150863708147118, 0.02737508519672819, 0.015213140624485191, 0.009332916890871863, 0.022696268316658757, 0.07047433571349229, 0.041640862341850035, 0.008997561902018085, 0.0392606271611106, 0.03843500271379467, 0.03398634162881682, 0.03702162795009152, 0.004686159354018709, 0.0715733731105443, 0.05184744792659918, 0.06463878352435366, 0.09275330636169642, 0.035576288167747765, 0.009647914050747792, 0.05632548465303356, 0.06578324227443626, 0.04633200557662114, 0.0043457941501401365, 2.2949138235661293, 58.499491753116736, 113.67388048479634, 120.73382516061108, 106.28060494699787, 86.66852658794772, 80.13172411149549, 54.99936080748036, 33.82015043689359, 41.809022195877574, 77.70698547363281, 72.98202776139783, 58.261611769276286, 49.176712113042036, 22.776387737643336, 1.2783365985078197, 0.1361100907407461, 0.06990700164028714, 0.045565117090459795, 0.24178539282612263, 0.13354726616413365, 0.03208931832153711, 0.4000721967989399, 3.4080010892883426, 2.572284720597729, 0.3030264768148622, 1.6067973476263786, 17.87040871958579, 63.68780297617759, 91.9790392537271, 87.4634184375886, 87.31680024054744, 92.41770928905856, 91.29697045972271, 86.88329988910307, 91.7240224346038, 93.69743747095909, 88.72771601523124, 89.75697732740834, 75.52138590043592, 69.12719295870873, 69.23577200981879, 68.66178804828276, 67.45207417395808, 72.65545906559115, 72.99359090866582, 72.5729480866463, 66.69191098982289, 68.31810997378442, 78.78530779192525, 89.05323351583174, 83.45572102454402, 89.79274934337985, 86.47946050090175, 91.71325945085096, 78.92723483424034, 77.61772017325126, 64.73714290126678, 80.40960050398304, 76.56096304616621, 104.01434575357746, 51.69572099562615, 46.39719117072321, 103.41579991002237, 78.23013551773565, 89.51815989709671, 74.40391048308342, 73.88273731354745, 71.10283590132191, 74.38207072596397, 67.25045650236069, 75.09931533567368, 83.57962085354714, 93.93545473775556, 90.15017924770233, 94.85111636500206, 88.19192024969286, 92.85729715901037, 90.60928483163157, 96.51775498544016, 84.4623031923848, 70.8012762377339, 68.6458553806428, 72.64964611299577, 72.24827781800302, 74.54430780103131, 70.92103404383506, 76.50044871914771, 84.65806868768509, 92.41698757294687, 87.92646208117085, 79.87476179676672, 67.31315951193532, 25.4239248460339, 1.2668102234601974, 0.11975577596815364, 0.15033412183965408, 0.3885011435035737, 0.0716901172493254, 0.2155364473019877, 0.026215536429757075, 0.22218549293616127, 0.08551956710195349, 0.15397564417892887, 1.6523417037340904, 12.760009496442734, 31.545348321237874, 42.36926609469999, 37.96596627081595, 49.68853042971704, 64.14952478101178, 25.33614416276255, 30.67439583040053, 67.80168287215695, 62.57424600662724, 62.673631022053385, 74.2546486085461, 94.43571382953276, 45.72062938444076, 7.931488463955541, 0.22328384851496066, 0.04476698753874629, 0.03821814237462898, 0.057776704160196174, 0.03709065247206919, 0.05858318023984471, 0.03595134566327737, 0.031099661043094053, 0.103380914717432, 0.04136855638916454, 0.055783293585503296, 0.062259640018906326, 0.036061060945353204, 0.05645732455436261, 0.07417423395259727, 0.013294583543263858, 0.08916900312948613, 0.01592657532572987, 0.027467456248198307, 0.04510815330450574, 0.060990956281462026, 0.038652135014173486, 0.0452362202228077, 0.01728474579360937, 0.04706577608181585, 0.025618983763119867, 0.08011975040238711, 0.0310086440520301, 0.034700224491497206, 0.03766174803698256, 0.07776647385570311, 0.181734717541164, 0.18756489179307417, 0.11565273161977531, 0.10901217423980275, 0.08221700036477658, 0.12956298076577727, 0.25293059316613986, 0.20381796804647292, 0.16773721864146574, 0.14851965791275426, 0.08938481775863517, 0.11419753228584606, 0.14971179797524406, 0.15811806544661522, 0.10541845578700305, 0.25703714619721135, 0.12168535226655584, 0.12535646858234561, 0.1694755027851751, 0.0962115191824494, 0.13020493180280732, 0.12102835526269291, 0.12975318507561762, 0.14442965238084718, 0.12159973428013826, 2.763901819144526, 78.73972985052293, 135.69591799089986, 134.53649674692463, 119.21902148954331, 99.98896629579606, 85.98231577104139, 54.80860417889011, 48.697900541367076, 62.13821180405156, 97.94759227383523, 76.47544753166937, 91.992626344004, 66.96365279536094, 30.961013224817094, 2.220066665641723, 0.13832290506651326, 0.254016446190015, 0.17812250572587215, 0.6320010870695114, 0.3569738675029047, 0.3708532356446789, 2.310230188792752, 7.550903337617075, 5.861336012040415, 0.9835536874109699, 1.658243890250883, 19.260535932356312, 74.14203736089891, 97.70032605817242, 93.39640340497418, 92.00593886836883, 96.90319061279298, 92.90993536672285, 88.13702275676113, 94.28398086178689, 96.75734904504593, 93.07174098107123, 94.71187222388484, 79.35081943388909, 73.25213001620385, 72.5199019524359, 72.51484209491362, 70.33966033689438, 76.32460101958245, 75.19129491621449, 76.07268287289527, 70.03514320619645, 71.9307227288523, 83.59911503330355, 93.0026601975964, 85.97964071458387, 93.67401307629001, 89.5095463721983, 94.97565946271344, 83.71131835445281, 81.42846753520351, 69.57355083957796, 83.78341936296033, 79.61641096299695, 108.56542479607367, 55.9782196629432, 52.54443953114172, 105.35967949898013, 83.17535784936722, 92.86694618963426, 79.59261002079134, 73.97840392205023, 74.33810880107265, 78.31870263622653, 70.77214087209394, 77.13945773340042, 87.35176424826346, 98.13615629749914, 95.11626858865061, 103.72026997227823, 94.45971873498733, 96.96401872942525, 97.764143020876, 100.56298163629349, 89.77359248745827, 73.6410879319714, 72.71827190153061, 76.55311046108123, 76.46011106429562, 77.46870148566462, 74.92974342838411, 78.94443050507577, 89.01782235791607, 98.47930877439438, 89.80007633086174, 81.19969921727335, 73.21179236135175, 27.046564279064057, 1.503871167379041, 0.5505188722764293, 0.7319509238004686, 0.8044471723898765, 0.2596486173570156, 0.42660804225071786, 0.27492912966878186, 0.38940555626346224, 0.25027649687422865, 0.2554814974146505, 3.129180386181801, 20.834133971122004, 44.21228585704681, 60.60798537346625, 56.338136349954915, 75.69988512223767, 102.78750681108045, 49.71953284355902, 26.488815007671235, 59.44457900139594, 66.58918411500993, 75.20335228212419, 92.93976106951314, 111.63249077335482, 54.03624634588919, 9.464971442376415, 0.3807170773225446, 0.174595819966447, 0.1341033081013349, 0.1672792053150554, 0.13857513185470335, 0.2200844661603051, 0.1423996419555718, 0.16249729981345518, 0.1772890786730474, 0.17342499247001064, 0.19040672559170954, 0.14651321235202974, 0.17399249508255915, 0.17531562085834243, 0.24010208315185963, 0.24244602108674668, 0.18022154067312518, 0.17044411371311835, 0.10622207435869402, 0.13418668911101359, 0.108590021489128, 0.12899416048199902, 0.2234391651807293, 0.08773205967079248, 0.11569514990814271, 0.2040068853286005, 0.11213067303141279, 0.1481522727877863, 0.0866630222768553, 0.14031606666263075, 0.226429206349196], [0.0704205716629663, 0.04634895144150623, 0.05848006097479694, 0.035265486296867175, 0.0493109269788669, 0.01580748887312028, 0.02011649404472161, 0.04184813509064336, 0.03351317891370385, 0.06582120193108436, 0.015324255932242641, 0.008982612653785657, 0.06453986625157057, 0.030736830310835957, 0.0701545323095014, 0.04466225565861791, 0.013518470823915016, 0.003328120318098715, 0.02403111523768354, 0.053204105370828224, 0.059850075161985816, 0.024548149893000245, 0.04779718320576414, 0.08236424246382329, 0.20736932183705992, 25.874434555730513, 98.17435233823716, 98.38024539332237, 100.91247266338718, 86.89368632531936, 52.037916414199344, 22.901689813983058, 24.885501092480077, 56.54251144778345, 79.69758049134286, 57.690899064463956, 47.87682294845582, 38.76744377997614, 15.376057817089944, 1.0164237623253176, 0.03227844436262404, 0.11296451377171664, 0.0830594978986248, 0.12778508221550336, 0.07694433893888228, 0.18833715438602433, 0.11276172263728035, 0.1579889336660985, 0.7220562547445298, 1.2404202717927195, 3.616344399990574, 19.6056652838184, 49.87551766057169, 79.5355160005631, 79.74755933207851, 78.48357554404967, 79.5976306546119, 81.89952065867763, 90.0030746767598, 84.16252428485502, 81.75369478041127, 85.10100626176404, 89.22358989715578, 85.23935610248198, 81.97502628449472, 68.27761542412543, 65.42048646557716, 65.44368728514641, 64.78630981137677, 64.12165634093746, 62.57298300343176, 65.38701295852661, 64.05554871405324, 63.9537279067501, 64.09453707356607, 75.33554400167158, 81.56267535301947, 85.3348893503989, 85.9602092927502, 83.23442874416229, 77.3070998345652, 74.36503194993543, 65.27914777878793, 67.93986797332764, 67.02767372131348, 86.1609640429097, 69.96160661020588, 34.689179005161414, 93.63622496204992, 78.89727577086418, 87.37276461816604, 75.69262873741889, 72.04892727636522, 68.02550900367, 66.71760251445156, 61.965247046562936, 68.451125391068, 77.86184064803585, 87.7538150356662, 86.62722403003325, 88.07697911416331, 77.69120970079976, 79.28246036652597, 81.87511567146548, 80.76016626050396, 67.27756792499174, 66.45657662422427, 66.59678566840388, 67.07169840412756, 66.45529793154809, 66.83467741935485, 71.98616935360816, 80.27875807977493, 79.55255477659165, 89.00159943488337, 87.22394989382836, 80.74550444079985, 90.48464759703606, 92.09786353572723, 56.3287305062817, 3.543291971568139, 0.3752617652137434, 0.25612378553036724, 0.0864543782306775, 0.16187755000447074, 0.03857361100193474, 0.07379322778433561, 0.09377203476164611, 0.09427551540636248, 0.201884929030653, 1.2364013132549103, 10.217742919921875, 25.620802333278043, 39.163312911987305, 44.98715008458784, 45.85646890824842, 82.42757366549584, 28.772414999623454, 10.302632816376226, 20.072954893112183, 39.220077453121064, 60.409776241548606, 65.69086328629525, 61.98833019502702, 38.564782757912916, 13.143057380953143, 0.0716065906829411, 0.0402284566793711, 0.025205991508799697, 0.039021492815546455, 0.04804724196512853, 0.029431493096654455, 0.04017337878805496, 0.04476054473930309, 0.05093509466537545, 0.06660251202242029, 0.055429196255582, 0.0178867970563231, 0.02123158672944673, 0.02288285669149651, 0.02306657415183802, 0.04063249145063662, 0.04280987420990583, 0.04011524037548131, 0.02538963427556859, 0.06502682237976021, 0.029210905739737135, 0.00921158580064413, 0.11547051760698519, 0.038478056855139234, 0.06096222415386189, 0.08167277150336774, 0.028731708167000648, 0.0776851995878162, 0.029111829503709753, 0.03420311386787123, 0.08065606557553814, 0.08690868369153432, 0.04790799399357169, 0.029924340440981814, 0.018815410533739675, 0.026237590185877298, 0.022843073745588624, 0.024809198183638435, 0.0317614384356045, 0.04258772403362297, 0.01867290094284521, 0.024642030137681195, 0.009622414814188116, 0.023845222087637074, 0.12898764873464263, 0.06711422045144343, 0.01995012273020562, 0.05934379063546658, 0.05851184213233571, 0.04804687424292488, 0.036233763976563374, 0.015773250488564372, 0.07200212953912635, 0.1010268874045822, 0.09741290592618528, 34.61946279771867, 118.84341532184233, 112.00279389658283, 113.78329107838293, 97.47373073331772, 70.26579426180932, 46.04742557771745, 42.2041735341472, 60.956425205353774, 54.93027610163535, 49.74505178390011, 48.431567684296645, 50.63251941434799, 18.870599385230772, 1.0529329387410995, 0.1022250182746399, 0.041855156286469394, 0.033503790506191795, 0.13086289407745486, 0.12447820240331274, 0.24974542940335892, 0.23163379320213873, 0.3084275192551075, 0.837198289171342, 2.205221720280186, 5.873028107227818, 19.919239167244207, 55.99547416933122, 87.99871998448526, 86.58198341246575, 85.57079638204267, 83.22350102086222, 85.62409354794411, 93.82140005788496, 85.96387278649115, 82.78223437647667, 89.71307031569943, 93.42393844358384, 90.28613644261515, 86.87997371919694, 70.66014151419364, 69.23661139703566, 69.19262593792331, 67.30549520061862, 68.14003436796128, 65.25046348571777, 65.95883569409771, 67.81249292435186, 66.23412332227154, 66.59356932486257, 78.85543192586591, 85.29517143003403, 90.80664280922183, 89.0019053797568, 87.75589389185753, 82.8846239274548, 78.6898608361521, 67.8111122500512, 70.95344851093908, 70.54531020502891, 89.45002048246323, 74.7373668609127, 37.31694344551333, 96.80701409616779, 83.957227430036, 90.17260736034763, 80.64286385813068, 74.01287371112456, 70.44041818188083, 68.59294260701826, 66.7700053799537, 71.38846289726996, 81.62651584994408, 91.8742335227228, 91.81247188198952, 91.83813202765681, 80.06167842495827, 81.68071516098516, 85.00378639467301, 84.64324212843373, 71.67102259974327, 70.50381937334615, 70.35076064448204, 70.02466263309603, 68.15948932401596, 70.46225009425994, 74.91462661374, 84.41763524086245, 84.18394827073621, 91.81516262792772, 87.33870275558965, 81.08736253553822, 95.95684820605864, 98.6254405975342, 64.61517287838844, 4.946066131514888, 0.3668663608691385, 0.3203828422532928, 0.03359091002494097, 0.18296085658573336, 0.09017542815737187, 0.03100408199844101, 0.10821139019343162, 0.02265426754621008, 0.15346092502436331, 0.6993278969199427, 10.585458259428702, 30.061541180456842, 43.50678090126284, 41.888054032479566, 42.512507131022794, 55.781524565912065, 27.665637846915956, 21.53844064281833, 39.49253313003048, 60.22123967447589, 76.2127899354504, 77.95392221020114, 79.95615882258262, 57.70449399948121, 21.89781015919101, 0.29668642508406795, 0.033992144744843245, 0.04034275699767374, 0.028482999637602802, 0.02489052224724043, 0.0307637736231329, 0.03209268336274451, 0.038410127838893283, 0.0431617115804505, 0.0275899077420153, 0.03775746689268178, 0.03470153833228735, 0.0192178346051444, 0.02584930235189536, 0.06275568578031755, 0.018050144238757993, 0.015137103525170637, 0.05330348229636589, 0.02407692154989608, 0.019706031795771375, 0.0625390476066499, 0.047430414781575246, 0.05199400437695365, 0.014028653780358934, 0.02041880766140117, 0.2516483151984792, 0.05179100639877781, 0.09533726730413976, 0.03413805002046209, 0.009328813532427436, 0.1831515052265698, 0.15809929629247035, 0.15182414753062112, 0.15970719227146718, 0.14097358460628218, 0.09997955328153987, 0.12173929251730443, 0.13714032578131846, 0.1681290572929767, 0.0892364188668228, 0.10407423194978507, 0.1267757000882299, 0.19050354378358011, 0.10290728851912484, 0.22426854728931384, 0.22442790889932265, 0.1647391182280356, 0.12050481077523963, 0.11792753778037526, 0.15803390302725379, 0.14394572996083768, 0.20042507188214412, 0.1189333346161631, 0.2510892242313393, 0.3040051388163721, 49.4940318599824, 134.45688832190731, 124.11963078283496, 130.27834815363732, 114.33309755017682, 73.90076452685942, 39.58939606143583, 35.90961271716703, 78.7797458710209, 104.8214283297139, 78.83898150536322, 75.23845749516641, 61.70947320999638, 26.34714880297261, 2.514287084341049, 0.21515193245103284, 0.21051677875220778, 0.25052806482680384, 0.3470054701451333, 0.23834446294894143, 0.5846828390513698, 0.45724337740290555, 1.3532800996495833, 2.938389436852548, 4.239495271636594, 6.739731690576, 22.30804693314337, 67.77069614779565, 92.65004696384554, 91.83847719623198, 88.19739587845342, 88.6133240115258, 90.19942068284558, 101.06052644791143, 90.08087881149785, 83.96869644041985, 90.66192303934406, 97.50604321879726, 93.60501074021863, 92.72835316196566, 75.46352309565391, 72.13419175917103, 71.07628929999568, 71.6646997390255, 72.22487695755498, 68.75770568847656, 70.2362274354504, 71.80297113233998, 69.855467273343, 71.87509567506852, 84.39905889572637, 91.83742600102579, 94.50914844389885, 94.8251267402403, 92.1323097905805, 86.69133124812957, 83.39162949592837, 70.76580232189548, 76.75763853134649, 75.48884591748639, 94.03845617848059, 80.31198839987479, 43.830823590678555, 99.77124337227114, 86.8131051524993, 93.52315087472239, 84.61565217664166, 76.7682759992538, 73.52658610190116, 73.95876853696763, 69.24652714883128, 76.01555747370567, 87.36819897928547, 97.40665035863077, 93.32550264173939, 97.42359499777518, 85.19152672060075, 85.30904093096333, 90.02281204346689, 89.57621882038733, 74.1010799715596, 74.15474584025722, 74.64247688170403, 73.86694585123371, 72.27061179376417, 75.43223827115952, 80.51760688904794, 88.3925808629682, 87.51142824849775, 98.52001513204267, 93.03654163114487, 83.90909994802168, 99.7594056590911, 104.35224225444179, 67.94531222312682, 5.583445400960985, 0.689650429112296, 0.9232778895285823, 0.26449176392728285, 0.43140975878604, 0.19673770684148037, 0.26747996648473127, 0.3718546964228154, 0.46304968035509514, 0.38148693439941256, 2.2672150260017765, 17.59240681125272, 43.770634820384366, 61.66950033557031, 64.85724195357292, 61.76095039613786, 104.27727007096814, 40.82054568875221, 17.096529006958008, 32.5572354947367, 62.489875824220725, 85.77264155111006, 92.13366693066013, 97.75738869943928, 67.89580406681185, 25.19556837697183, 0.54699597099135, 0.26207123252172626, 0.16809369467439192, 0.2028790506864748, 0.24479300805157234, 0.09370666447906725, 0.16293948576334985, 0.17367964009604148, 0.09433008384920898, 0.09657577866868627, 0.10491525859481866, 0.13633055552359552, 0.125747594772087, 0.13509959012510317, 0.1533093162241482, 0.12930151495722034, 0.2035518291015779, 0.23429541247746638, 0.11249864038320319, 0.14647516842570998, 0.1961777272123483, 0.1118510662608089, 0.2842413880411656, 0.1472255668693012, 0.1860308313682195, 0.26435454225828575, 0.0968897904479696, 0.3056157927118963, 0.13836084174052363, 0.1260405927596073], [0.03329466382462171, 0.04353039139401048, 0.041345830390890764, 0.028880095567494154, 0.13109937009792175, 0.18591791000818053, 0.019646432070482164, 0.11995163400687518, 0.00787994639399732, 0.09550190725994688, 0.027199733416519822, 0.015473214068239736, 0.04254311856423174, 0.027692373917107622, 0.027434186964866616, 0.014018212001950992, 0.04572484259223265, 0.1425608574983574, 0.027245246700101325, 0.08460531011223794, 0.054382210702545224, 0.06723966734904437, 0.07265746413219361, 0.14448101091529095, 13.486104934446274, 99.50597347751741, 108.85559389668127, 117.14038495094546, 85.79646602753671, 68.98139061466341, 35.38617241767145, 28.902761244004775, 46.490476900531405, 45.466377427501065, 73.754436585211, 55.47800371723791, 40.823624749337476, 17.97828958880517, 0.3607882805649312, 0.09363239225480827, 0.04269208053066846, 0.07054894501643796, 0.016546572198069865, 0.09784928492961392, 0.0924187864086801, 0.2941652910122949, 0.06288960944080065, 0.28855385018452523, 0.18614042790666704, 1.4101522608149437, 18.7273250087615, 43.52793424360214, 74.09512581363802, 76.99525571638539, 79.33379634734123, 70.17397942081575, 72.80427378992881, 83.40225127435501, 85.34066307929255, 87.92560700447329, 87.6722611150434, 78.08427041576755, 80.56230621953165, 88.77478445729902, 82.83076194024856, 72.71856215692335, 66.1420339153659, 67.65807705540811, 66.67651960926672, 68.27736439243441, 66.10284943734446, 64.3198968518165, 62.5520493138221, 62.196549215624415, 63.10586837030227, 63.864176273345954, 68.56412887573242, 78.6614550313642, 84.39674469732469, 83.5669751321116, 82.62397458476406, 72.62721800035047, 64.34296431079989, 71.49706548260104, 76.06638354639854, 83.82054067427113, 76.42302897668655, 22.739440971805205, 77.90157425788142, 85.70531014473208, 85.89304262591948, 75.85850577200614, 64.33323291040236, 65.63733077818348, 64.80960869020032, 62.13674483760711, 64.77355426357639, 70.6691708103303, 83.36091733747914, 83.96841402976744, 85.33107680659141, 70.71129706598097, 62.85583688366798, 65.081091619307, 64.02080435906687, 65.34365507864183, 68.40805776657598, 62.6943999721158, 65.69628792424356, 62.4856435868048, 73.45287692162299, 82.93848591466104, 85.52372793997489, 86.9629789167835, 83.70224983461442, 75.84491083698889, 87.24269882325204, 83.43935689618512, 82.32425843515705, 93.47967532373245, 79.49724935716199, 6.847900363706774, 0.3510045103969113, 0.05564987171261061, 0.1314725928128727, 0.13723935030641096, 0.038090194199955275, 0.05788597128083629, 0.15386353487208967, 0.20647347394016483, 0.04956948931419081, 0.08036856043843493, 2.46669574129966, 12.598245066981162, 30.822586897880804, 41.80776703742243, 32.36801447406892, 63.12824549213533, 62.60819804283881, 15.571005498209308, 25.806461841829364, 39.00446476474885, 60.43030592703051, 60.260431997237674, 76.33237515726398, 58.561002362158995, 10.11744595343067, 0.15423638986483698, 0.030636714110451362, 0.019435623825918284, 0.00491662637232953, 0.06407954317006855, 0.043944764521814166, 0.032800594570055124, 0.0673780917760826, 0.04904955693130051, 0.04330826036992573, 0.08281374455339487, 0.042203304943658655, 0.06605612279306497, 0.01749842112222987, 0.024112387590350646, 0.026760155996007305, 0.09608817136576099, 0.011308354085251208, 0.03726343211207179, 0.013037993884344977, 0.027251609060312473, 0.0033034707209275618, 0.014329202521982935, 0.04082011404417215, 0.04209687234833837, 0.05980052842548298, 0.02122836916016475, 0.034553468858282414, 0.0046949176542130456, 0.054697498018222476, 0.012785223173728634, 0.028797166549690792, 0.05041776698142771, 0.026774817003658222, 0.047508977098210205, 0.02297826719680621, 0.004401916793863019, 0.04448774082946681, 0.044539490068751963, 0.029507582864513802, 0.02554780461885516, 0.03557548760586689, 0.04120861255233327, 0.056856441041154254, 0.08511148738644778, 0.058629022941233656, 0.07315123078203009, 0.01854725869282359, 0.06425820636532961, 0.05147447419022361, 0.1635564316905314, 0.06656560956710769, 0.044899103231728084, 19.86540267544408, 123.12889499049034, 121.7809332570722, 131.16008127889327, 98.01137785757743, 92.0836410214824, 54.524781473221324, 39.713770497229795, 44.997458073400686, 37.78914974581811, 61.842535695722034, 54.02517349489274, 49.34729599183606, 20.455274197363085, 0.6561007422785605, 0.10015887914285546, 0.14842587342906385, 0.19927495940318032, 0.046519222143556804, 0.273947342028541, 0.2971219307472629, 0.2900100607545145, 0.08058986791800107, 0.3017210936354053, 0.6629662383948604, 1.7398424278343878, 20.42132019996643, 49.01584394516484, 83.43224956143288, 84.6001745039417, 87.03045937322801, 76.83555249244937, 76.44595915271391, 86.7976745482414, 87.68757404819613, 91.60926172810217, 90.43131905217325, 79.42858434492543, 83.897976106213, 93.02901852515437, 87.83707126494377, 77.46356318073889, 69.25215182765838, 71.1552466115644, 70.21510154970231, 70.60394179436469, 71.76245304845995, 68.49647583500033, 66.28633791400541, 65.0557021171816, 66.31854057312012, 67.46672814892185, 70.84304163532873, 81.39297008514404, 87.66651876511114, 86.23231980108446, 84.35344957536267, 75.88217335362589, 67.64969887272005, 74.45195167295395, 82.0290373217675, 88.44788628239786, 80.14299700337072, 25.16232825094654, 80.74624969113259, 88.51109135535457, 87.65140979520737, 80.94468239815005, 68.48291227894445, 67.0707570352862, 69.09069138188516, 66.59725635282456, 66.6260543946297, 73.76552120331796, 84.56368077185847, 86.42813236482682, 89.10893117227863, 74.32744779894429, 66.49924416695872, 68.83383889352122, 68.96115118457426, 67.76419285804995, 72.56843736094814, 64.74595646704397, 67.63751599096483, 64.90702075342979, 75.32528308130081, 87.48605051348287, 89.4524758861911, 90.08856665703559, 86.1501226117534, 76.62260701579433, 91.75405210064304, 87.87834244389688, 85.82178100462883, 96.88995653583159, 88.92454055047806, 8.811530067074685, 0.47272629014426665, 0.1147114776916081, 0.15747240654403166, 0.29048546427680605, 0.2733524287900617, 0.0755726431886996, 0.1237745276622234, 0.09195198605377829, 0.03213646911805676, 0.07731873376835739, 1.56213773114066, 12.760876340250816, 37.52013398754982, 43.11337894009006, 33.86936049307547, 49.37249722019319, 36.536442772034675, 14.22099530696869, 41.13698682477398, 58.173225079813314, 74.84050166222357, 74.32949527617424, 88.31900504327591, 73.0631031528596, 16.368460616757794, 0.2486326100845491, 0.03806395185810905, 0.034006240762650006, 0.002002629245849206, 0.07248848045785582, 0.05347573333570073, 0.03784020821894369, 0.019718407946188125, 0.024287572746435483, 0.016695352218624566, 0.019697894026795705, 0.03600046722098224, 0.017424056967419964, 0.03837770316749811, 0.031571544391373475, 0.018089984641260198, 0.01971271591291072, 0.010210491675553064, 0.03061054263173813, 0.06059889929489263, 0.015501549745339061, 0.050191694434972546, 0.036410707304434436, 0.01714478727550276, 0.12704846569366995, 0.03354136328843813, 0.059809763615410176, 0.05997464871935307, 0.03851793173159804, 0.09544343176868655, 0.14582825313893058, 0.1194501911560374, 0.15377751851995147, 0.1507087541563857, 0.27814437004347004, 0.21533036965035626, 0.26200510381210235, 0.13511351760356657, 0.18724996836916094, 0.17015149876956018, 0.1501503220248607, 0.22154842954008813, 0.16245465935958972, 0.12956426779349006, 0.16994411876845747, 0.18775187853363254, 0.2761271992518056, 0.15489784550041924, 0.19781386119223413, 0.17942125458390484, 0.2672238479698858, 0.16536594668944038, 0.24896441808631345, 24.873745749073645, 141.89057996196132, 135.74377090700213, 145.57600759690808, 109.31116934745543, 95.96226892163678, 54.57212448120118, 40.82179692483718, 61.949824287045395, 60.979618180182676, 96.39193319505262, 81.1365725917201, 61.28750070448845, 30.10410478038173, 1.1767774868396021, 0.3027036780070874, 0.3442007609673085, 0.4491733152779841, 0.34950873904651214, 0.5884479466945894, 0.5167907175998534, 0.8249368987256481, 0.24552169556338943, 0.8784129001921224, 1.9585015720898107, 3.0567930446517084, 23.441504047762965, 57.607854643175685, 93.60296326298868, 90.29740933449038, 92.5122933233938, 79.67880802769815, 81.23293738211356, 91.37413132575251, 92.15050174343972, 95.4780601686047, 93.26754570007326, 79.50248179897186, 85.75882696336316, 98.36076690304665, 90.9000736667264, 81.26651287078857, 72.78430108101138, 74.67770761059177, 74.38251787616362, 73.35510792270784, 73.96123178543584, 71.51304521868306, 68.55933573938185, 69.07328390306043, 68.86062868179815, 70.34967807031447, 75.41095549060454, 85.92563752205142, 91.4521002000378, 90.7511491160239, 87.30053024907266, 78.82180936874883, 71.55399476328205, 78.13013076782227, 85.37111636131041, 92.33658682915473, 84.45477224165394, 32.0606908875127, 84.48844971195345, 91.68296306363999, 92.79133858219271, 83.58064851453229, 70.79188608354139, 72.36394851438462, 72.94973096539898, 69.65340245154597, 71.39659789300734, 78.82728499750938, 90.20418244023477, 91.27540526851531, 94.5700942316363, 78.34685740932342, 70.1295389667634, 72.86890660562824, 71.86729015842562, 72.44735379372874, 74.04250329540622, 67.80177700904109, 71.33502452604233, 67.36919449221703, 81.24763058077905, 91.31757859260806, 93.24112461459254, 94.35874908201157, 88.37791119852375, 76.36231853115943, 94.58510121991559, 93.56443774315619, 88.94366602743827, 100.5044049601401, 91.74712519491874, 9.40710275403915, 1.0232563473043903, 0.47662420679003964, 0.3582462782581007, 0.3591193427001277, 0.3299830577546551, 0.13257690855572302, 0.3048161194930154, 0.3619695575006547, 0.1485787999005087, 0.364098638416298, 3.829781153509694, 22.294204888805268, 49.894760808637066, 60.555649188257036, 48.14338722536641, 81.46742451575496, 80.51718327306932, 24.273976126024802, 38.1231003422891, 57.66829052279073, 84.61972359688052, 86.9548439210461, 103.74207835043632, 86.34355821917134, 21.884544703268237, 0.509079521702182, 0.1519130750168716, 0.1362327414174234, 0.10238856272471529, 0.2107127593649972, 0.17575435941257786, 0.15900772335308214, 0.1282964688875983, 0.16915570704206345, 0.1347002591336927, 0.19559510202417452, 0.13360679119585023, 0.1771193901978193, 0.13779568335702344, 0.10374165786009643, 0.09902024266099739, 0.11338562464281438, 0.0950233014901319, 0.11384887034974753, 0.11388443981207187, 0.14996025561084672, 0.24408344209434527, 0.08161688538929147, 0.15725754952478796, 0.12719065927329565, 0.1360258517125922, 0.1264239125134003, 0.11464171006434387, 0.08151000846297511], [0.052877372701562224, 0.03924044074430581, 0.022036272078572262, 0.0060868036516401325, 0.017246439482175538, 0.05684000079429919, 0.04723502405648751, 0.05920422090698154, 0.05455864841238626, 0.02310620771060067, 0.026638506979291, 0.016040931185407024, 0.038380169970614296, 0.015385474975881799, 0.03432302961065885, 0.02238443222708039, 0.01663306352472113, 0.004936924829493247, 0.02768567064777017, 0.037100098336175565, 0.09032000427044208, 0.036348110260141474, 0.09426142704943496, 3.935549826391282, 76.65710818383002, 112.56110406691029, 99.76743082846366, 79.1330494419221, 71.14941796948834, 31.684623841316473, 23.63856000284995, 45.84458804899647, 65.81602219612368, 83.01747460519114, 57.544331858235026, 34.8833441734314, 16.279893498266897, 0.4279950597593862, 0.09076193741132176, 0.10528681123809469, 0.0540084402347284, 0.06713800748149235, 0.1425938299226184, 0.04174102833794971, 0.26583394997062226, 0.04924998468449039, 0.2293466070606824, 0.09284852342980524, 0.4671218360383665, 13.84931641240274, 45.538435289936686, 69.21340665509625, 78.97436603423088, 80.0743398358745, 77.28557386705953, 64.74716063468688, 70.68451512244441, 76.56036684590002, 84.34359658148982, 83.22196345175468, 86.14427828019666, 85.77490083632931, 80.10399295437722, 84.40648786483273, 84.13796240283598, 72.50987637427546, 65.0781027732357, 64.0692848543967, 71.00312925154164, 73.33239739941013, 74.78951869472381, 70.2548037805865, 68.40387651997229, 61.120729369501916, 63.747403390945934, 60.93857057632939, 60.00481897784818, 64.85382556915283, 83.31971676118913, 81.63920079508136, 83.71440133740826, 72.097839232414, 71.59494430788102, 76.57971982033023, 83.18725047572967, 79.11592437374976, 85.38658618927003, 27.10761400961107, 75.43441910897532, 80.80832512147965, 74.49845529371693, 66.48040110065092, 63.01333965793733, 66.35876055686705, 62.279593636912686, 64.0145521010122, 62.31243171999532, 64.15702435278124, 70.38393605139949, 80.27540053090742, 81.15559608705583, 68.27128471866732, 60.80913628301313, 62.99254717365388, 62.75960545386038, 65.39092356158842, 61.032032812795336, 64.11464314306936, 61.60685616154825, 63.1541213681621, 70.95667269922072, 84.58042929249426, 83.19478142646052, 81.98232973775556, 76.47161145364085, 82.4829496875886, 86.02343789992794, 80.36891768055578, 81.72546940465128, 79.34216668528896, 86.0547697928644, 86.06994936543127, 6.715798368377071, 0.11486991233522854, 0.31615523200842643, 0.17760141271977656, 0.03961985344968496, 0.1101102693487079, 0.0743921553235381, 0.19896173669445902, 0.018684164350551945, 0.06084636484663333, 0.10419030959207205, 0.07727065409022955, 4.116863839087948, 21.85675863296755, 43.04532973997055, 42.383253266734464, 77.36198163801625, 92.55485888450377, 29.544072689548617, 15.659340216267495, 29.52180539408038, 62.14792359259821, 73.00957064474784, 71.30954480940296, 52.20049865784184, 8.797787062583431, 0.08458297098836592, 0.06792543095446403, 0.10768843559368003, 0.011388806723839334, 0.03698292901859649, 0.027418581753849026, 0.04242935067703647, 0.05799977747242778, 0.1235756895414764, 0.116112744435668, 0.07658438486677986, 0.030250575153097033, 0.053366481536819096, 0.07343650660327367, 0.03136414715329246, 0.020307784284194632, 0.040257970216654004, 0.010577711134007382, 0.024356984142814914, 0.07995214568631304, 0.057902377053734765, 0.016754927046056238, 0.04223292956369058, 0.07254612091327868, 0.06964445564775698, 0.07317259697423828, 0.05062362246756112, 0.0214074402972455, 0.05930715248048787, 0.04995360196898541, 0.043570105392005176, 0.03864894042752924, 0.009350440194529873, 0.09096776991481743, 0.057750664831649874, 0.028616498119287917, 0.029078979653516607, 0.029261320070814223, 0.01393270222545271, 0.03348603258810697, 0.12398884075904086, 0.052468243445600235, 0.005060232905370574, 0.057977446009435, 0.06988097763349933, 0.02203973671120982, 0.03478241806489325, 0.013801931016778034, 0.006849737687697334, 0.05294329073700694, 0.06361965675868335, 6.304650133655918, 100.04371473866125, 124.2676688778785, 113.43542391254057, 88.26175412824078, 81.81687631914693, 49.50031941936862, 38.427954796821844, 43.4620854931493, 52.217306014030214, 53.64957124956193, 52.49435870878158, 45.18470025831654, 20.707535551440333, 0.6527301392728283, 0.1817618370536835, 0.05532051902264357, 0.13820531057013621, 0.13366012623713863, 0.17902860387919411, 0.12151229300446088, 0.3426227730608756, 0.018535688849947145, 0.32870739878666017, 0.4610761765751147, 0.9184663670678294, 15.625033205555333, 48.596158181467366, 77.22144311474216, 86.53865691154235, 85.663128975899, 81.26612063377135, 70.91595849683209, 74.8552889977732, 81.39491558074951, 88.42853330796765, 86.6047017805038, 91.12560995163457, 87.67150017522997, 80.07409664892381, 88.08327059591971, 86.54985135601413, 74.85874068352484, 68.78625269859069, 67.42001272016957, 73.53953776821014, 76.16509391415504, 78.37791473634782, 75.57069793824228, 71.37853145599365, 64.86017196409165, 66.54340221035865, 62.590049236051506, 61.68188325820431, 67.3941799902147, 85.21640239223358, 83.27639810500607, 86.31373251638105, 76.41442329652848, 75.6078427837741, 81.05704261410622, 87.69197494752946, 81.08839804126372, 86.8067273785991, 29.946664764035134, 77.3342034124559, 85.51451821481028, 78.40605381996401, 70.05484919394218, 65.3573323834327, 69.31296425480997, 66.16318333533503, 68.70392999341412, 65.895858118611, 68.24684050775343, 72.16683372374504, 82.27865695953369, 84.34404373168945, 70.1658836487801, 63.324928822055945, 65.905805249368, 65.01549390054518, 67.63181286473429, 64.4955248986521, 65.9324852112801, 65.65010201546454, 67.66082271452873, 76.04964287050309, 87.87547911367109, 86.35258751530802, 84.51446287093624, 75.91598418451126, 85.35449335652014, 89.64405229014736, 84.0747808641003, 86.65253900712537, 84.35825055645358, 91.20482613963466, 95.13086765043198, 9.554267141126818, 0.09562153188932328, 0.34167594967349885, 0.41338040042788754, 0.23050649482156002, 0.36536314314411533, 0.17009215759894541, 0.23977392172861486, 0.10041983167250311, 0.04366377879294657, 0.032640424737286185, 0.08181291962823561, 2.586449625030641, 25.84516190713452, 42.057425898890344, 40.95462406835249, 70.76446087129655, 54.20566920311221, 24.25251683881206, 24.61943691776645, 42.06049711473527, 73.87847761954032, 82.67493401804279, 82.5433777224633, 70.26307213690974, 14.945296260618395, 0.10241533749766889, 0.1338043346280052, 0.046478638635768045, 0.11827586263778711, 0.04896177091605721, 0.047035975261561336, 0.11534877091405854, 0.05953208738637548, 0.022437895588096113, 0.03962675207144311, 0.0022577480159534685, 0.03912600636061642, 0.06489798171265472, 0.03258399087034407, 0.025455726596016078, 0.06698865097977462, 0.03740829167767398, 0.028740797800222234, 0.021262193857241544, 0.02269878874592964, 0.0549728530008466, 0.07129008911790387, 0.025040307758195747, 0.04057898020912563, 0.0275038396789422, 0.037707613721009225, 0.014102936538326886, 0.06387450356757449, 0.1280031338213913, 0.14089225671224057, 0.06443322681251072, 0.12405550573021175, 0.15184895345760932, 0.15107575623739153, 0.10527932655907447, 0.12237849329868633, 0.14449270141701545, 0.12196265311250765, 0.09730327874422075, 0.11756736154277479, 0.17385027852029572, 0.12473609058126328, 0.11139987111692468, 0.17254451229687662, 0.1301509838911795, 0.14135883490164436, 0.07796593250766878, 0.10545211769039593, 0.2799078738016467, 0.11742022669603748, 0.44336682846469266, 8.565535679940256, 122.64660035410236, 135.933927412956, 126.50338849713727, 104.47421227732013, 95.57617433609502, 49.07565616792249, 39.314524204500266, 62.02970335560461, 92.72297951482958, 113.91702036703788, 83.9069583339076, 55.87377086762459, 30.111445496159217, 1.1871793673884485, 0.28889200139430266, 0.4297553153047639, 0.27172394036766023, 0.2998138717826336, 0.425106663136713, 0.5521400368982746, 0.6619076274575726, 0.142062992278126, 0.7957514615789537, 1.4913250986606845, 2.4777107373360665, 17.831714537835893, 57.41542316252186, 86.96430467790174, 91.96236918049475, 93.22428980181294, 86.22443583703811, 75.00811238442698, 78.06956152762137, 84.87851373610958, 92.46798622992732, 90.2167889379686, 96.0515106877973, 89.9507345691804, 81.35124391125095, 92.24539956738873, 92.92015706339191, 79.54769888231831, 71.71030905938917, 71.37569950472924, 79.51337029857021, 80.70271922696023, 83.37600277316186, 77.49786038552561, 75.94408404442572, 69.18470275017523, 70.29682805461269, 66.94707685901274, 64.853237213627, 71.96505131260042, 89.96525518355831, 87.17048014363935, 93.35670117408999, 79.01552738681917, 79.0529546430034, 85.15067915762626, 90.63714150459536, 84.16268117966192, 90.8916562603366, 35.46694578662996, 80.2653435737856, 89.1910969826483, 84.84140811427947, 73.9508375044792, 70.30567692172143, 74.08942268740746, 71.93393907239361, 72.18273501242362, 70.4156837155742, 72.72738748981108, 76.0876977059149, 86.84251508405133, 87.36334308501213, 74.7999914230839, 66.29200181653424, 69.22031002659952, 69.49158899245724, 71.4635919755505, 69.06578433129096, 70.02612959954047, 68.04859607450425, 69.06989497523155, 78.56126985242291, 93.83916839476555, 90.57019449049427, 87.94057476905085, 74.48345615017799, 87.50981223198676, 92.48707248318581, 88.47144403765279, 90.59816883456324, 87.2241852360387, 91.25837433722712, 93.54606536126907, 8.71390913763354, 0.3551830603711067, 0.5651890270171628, 0.5841933395112715, 0.2724946248194864, 0.31175506811949516, 0.1955730999789892, 0.35723268264724367, 0.14337330906381532, 0.12400214004540637, 0.3194989912932919, 0.3672465549842004, 7.323630913611382, 36.375507923864554, 63.92738134630265, 57.26867160489483, 101.08325266068982, 118.00944882054483, 43.47790833442442, 25.95789278707197, 44.33788407233454, 85.87510954949164, 95.02737199106525, 94.26713035952662, 81.52489508351972, 17.417941747173188, 0.4190728627145291, 0.23528544322377254, 0.25833569587238375, 0.1992951075155889, 0.1264981694159008, 0.16267849492930597, 0.27397139718936336, 0.09530018098772534, 0.24343355438641964, 0.23162619360992986, 0.16343630910400422, 0.1021532894622895, 0.17438002831993565, 0.22608172418850087, 0.08193962291003236, 0.17557062088481842, 0.10740882116219691, 0.1508762516201504, 0.14345195565012195, 0.15385613446274113, 0.22563354743103828, 0.16486651864984345, 0.13128327716502453, 0.10652526131560726, 0.16917668252943024, 0.18822067837801673, 0.08947893166013303, 0.1585747457800373], [0.059969178851573705, 0.019232551154169827, 0.011272134405801134, 0.01935225430755846, 0.05672819409219008, 0.04472314815727934, 0.08146749824405679, 0.029999654544817827, 0.025781850225382277, 0.019128299994213928, 0.032146880252947735, 0.06841994070958707, 0.037931391834131176, 0.03125275222344264, 0.013714500274809619, 0.05324842355724785, 0.06706357437876925, 0.014588836422790925, 0.04631593305196974, 0.02546218088677814, 0.00399764980219545, 0.0316878097252019, 0.04683116165500495, 48.24842045384069, 117.26234712908345, 99.06481665949669, 95.31207330765264, 65.37350039328298, 50.06841982564619, 31.179000908328643, 47.7091141669981, 76.52723850742464, 67.5576957579582, 52.665342669333185, 39.782423742355846, 15.872324916624255, 0.6270296054501688, 0.03315874067465625, 0.13414139799293012, 0.04087536047483164, 0.0629435228784719, 0.025365330136170792, 0.10656119850013526, 0.05138125278115754, 0.2878169348884014, 0.16082491455299242, 0.13007716365879582, 0.24227571974117912, 6.635241220074316, 29.80924060267787, 65.70379926312354, 77.11591566762617, 80.47241333992251, 80.71302721577307, 71.47077775770619, 64.63058779316565, 68.9045278487667, 71.47934421416252, 75.49151312920355, 79.64184361119425, 82.43737959092664, 84.64006500859415, 83.19612287705945, 81.21476111873504, 82.30784723835608, 74.70979259860131, 71.39916312310004, 67.86256590197164, 72.59827875321912, 75.87486205562469, 81.73960562675231, 79.28532369675176, 78.69900780339395, 70.6715948350968, 63.99320264016429, 59.97944908757364, 62.03516329488447, 59.68958593183949, 77.46758753253569, 81.89604543870496, 78.58373718876993, 74.43585426576676, 70.24343675182712, 74.19267515982352, 81.61376030214372, 79.05308015884893, 73.60220155408307, 37.670788303498306, 72.45708911649643, 82.06235393401116, 68.83455276489258, 66.08855632043654, 60.19248477874264, 67.40342893908101, 61.36848195906609, 64.71282420619842, 66.04365302670386, 63.776354405187796, 61.05606125247095, 68.83250528766264, 70.11435939419654, 62.06461245013822, 61.69285412757628, 62.68149929661905, 61.323347245493245, 64.32551368590325, 62.619059085845954, 62.619757267736624, 63.438708936014486, 61.70730413929109, 67.09228300279187, 80.2966127087993, 80.03193116957142, 86.28731927564068, 82.3923586260888, 76.15225991895123, 84.14335958419308, 78.48781170383577, 69.1346219278151, 79.57336687272596, 83.84832674457182, 87.34264081524265, 82.28901201678862, 8.013299790120895, 0.025376338819642703, 0.5765164030655738, 0.7060314726925666, 0.059700768455983176, 0.014913303387020866, 0.07564672389097753, 0.08362569816170201, 0.12528709165992277, 0.08659498600829994, 0.03892695756569024, 0.05872697877367178, 1.1441167684332019, 24.075716003294914, 57.30287467279742, 28.428721235644435, 84.8395332213371, 112.57946075931673, 34.705276412348596, 24.286410039471043, 45.24681883473551, 57.357583891960886, 71.98227051765689, 80.62147125121086, 53.72326081798923, 2.4652111241894388, 0.07976905067241, 0.020070421516955383, 0.05811885434893831, 0.07422037542827668, 0.06568997106965511, 0.03261882871870072, 0.061757534502014044, 0.0769719410867941, 0.03034316645484538, 0.04234191323179872, 0.05048304533345565, 0.04426359116370159, 0.05082729460311033, 0.10394284020989172, 0.04276318498136055, 0.003744046210363928, 0.02224789046111607, 0.03880911792117742, 0.08669987876689242, 0.08506421210064043, 0.02211118015580841, 0.023444908588463743, 0.06245683871149536, 0.02437939221460012, 0.027003844734281305, 0.045105858871172515, 0.08212629555454178, 0.0750578091209454, 0.07091790062165068, 0.018919380156383402, 0.026238723996005235, 0.04103950247348797, 0.03269991912548581, 0.03360027928025492, 0.016501932254722042, 0.003192229248065081, 0.05310730633115577, 0.09261407754233769, 0.021988401159403786, 0.021976540203116113, 0.03949260241502235, 0.044740178291836095, 0.017078650904999628, 0.06336110974511792, 0.012361918418337742, 0.055848859220502846, 0.02691396921422453, 0.031795362724111445, 0.03103737809485005, 0.0827209176796098, 65.15232186163625, 131.3855940295804, 110.69386759111958, 108.8348602479504, 83.5719173185287, 75.66525059361612, 43.243672232474054, 42.78513539221979, 45.38883609156455, 55.20413598706646, 50.84914799659483, 48.78665593362624, 18.193160949214814, 0.4734907233186307, 0.05134988914153749, 0.09505402927677478, 0.03321117939307325, 0.24824834038173002, 0.07035746133976406, 0.0862309640093196, 0.06907281616041738, 0.4715087312844492, 0.342457328712748, 0.4461706796240422, 0.6939183968690135, 6.421588245899447, 36.510876763251524, 74.59230192245977, 83.98504487929806, 88.71689027355563, 85.47098775063792, 76.42657479932232, 66.87674091708276, 73.26381867931735, 75.50276248685776, 78.79300348220333, 84.43929456895398, 85.88748070501512, 86.41039540690761, 83.2313379164665, 86.14329768765359, 86.1494165851224, 78.56811831074377, 75.8035376764113, 71.22791244137672, 77.02327712889641, 79.46663918033724, 84.50143275722381, 82.19969964796498, 82.93872910161173, 73.80136382195258, 68.78100456730013, 63.94296884536744, 64.81096975265011, 62.20659048326554, 81.09709001356556, 83.37681078141736, 83.28639230420514, 76.16023017514136, 74.05786329700102, 77.20152531900715, 83.73806891902801, 80.55952918144965, 80.3308157767019, 42.068977279047814, 73.01081795846262, 86.93961728003718, 72.73847210791804, 69.17907022660779, 62.10220836823987, 70.02417625919466, 63.669920890562004, 67.12679986030825, 67.37477210260207, 67.91798114776611, 64.32178351186937, 71.96388244628906, 71.11365379825716, 65.45187719406621, 65.01077136685772, 65.83371993034118, 64.99765103863132, 66.72136014507663, 66.14256735770934, 65.51279552521245, 65.94542118810838, 66.1769743888609, 69.28316208624071, 83.47865904531172, 81.97360638649234, 89.75027791915402, 82.19172939177483, 76.81062975237447, 87.59557877817463, 82.25935105354556, 73.45175512375371, 83.46062398725941, 88.27843204621347, 91.35756323414465, 91.03952177109258, 11.219932033169655, 0.09105754775866386, 0.3157219633219704, 1.0179466225447193, 0.7917271710691914, 0.1848174553484686, 0.21129638046747257, 0.08762963371531618, 0.09073494813374935, 0.05456586879107261, 0.018316154863925713, 0.1630789137655689, 0.2900918789448277, 24.15150207857932, 43.144926563386, 24.682334084664625, 84.24986762385215, 93.90551920860045, 34.14240452551073, 37.820014876704064, 62.63428180448471, 67.19093061262562, 81.89815567385766, 90.59314820074266, 71.86682731874528, 5.629073352582994, 0.04672308580108708, 0.03277602613032345, 0.10026885872526516, 0.024505268121438644, 0.033437803522833896, 0.065591873510951, 0.02102146221835527, 0.037030752057269696, 0.04088232421406335, 0.021766927055714112, 0.012947096594519193, 0.03420902423620705, 0.05042502949494989, 0.017565354224174254, 0.05229763566486297, 0.0402871773187672, 0.024193230933780153, 0.053470029811104464, 0.044123335786524324, 0.01752114712050365, 0.026720853770271908, 0.07045286992985396, 0.014294512145551703, 0.08524506247692532, 0.01099458841171356, 0.04040526594185541, 0.046088454734173515, 0.12077309476632266, 0.11872908025379143, 0.07161886341148807, 0.1438907861349083, 0.13580054525406132, 0.09234004789182255, 0.1508028910405213, 0.06497815281393067, 0.07969290919361577, 0.16488757074600266, 0.31311993036539326, 0.18820262934652068, 0.09513234644527398, 0.18015944158598302, 0.15571449522770223, 0.10718257241551915, 0.17272013029263866, 0.15514549108282213, 0.17072660097431752, 0.09098744305271296, 0.14503516827619847, 0.22956757746156187, 0.2889775274501693, 78.10891858993038, 148.29977989196777, 124.78434701119701, 124.02060662546467, 92.75286013080229, 75.3709473148469, 43.89582903154435, 67.98507721193376, 104.1028344246649, 90.46816579757198, 75.40810000511908, 61.34546549089494, 25.963493931678038, 0.9327824053264434, 0.17240139175086253, 0.47887331836165925, 0.16019235575391402, 0.36005822941660887, 0.3157545373805108, 0.3264596661733043, 0.3966943925667194, 0.9601240833440136, 0.4030409407231116, 0.7506129482100088, 0.8758300807206862, 7.575843728357746, 41.07496238523915, 82.30015154807799, 91.21256105361446, 91.96556198981501, 89.93497448582804, 80.69769859313965, 70.87211424304594, 77.99037671858265, 77.90296277692242, 83.80186234751056, 89.11756823139807, 90.05415178114369, 91.37473537075905, 84.97116796432003, 86.50540305722146, 90.8902834307763, 82.49292035256663, 80.36718399293962, 75.00307606112573, 79.46071640137704, 83.03567440279069, 88.85809559975901, 86.63682599221507, 86.16884800695604, 77.02431263462191, 72.0442125874181, 67.85856508439588, 68.26320463611235, 64.4256204174411, 84.29183698469593, 87.55903797764933, 86.3026165193127, 79.60213353556972, 76.65847316864999, 80.60313024828511, 89.34462639593309, 83.98722571711387, 85.13491907427388, 48.98903062266689, 77.66923658309445, 88.83688342186713, 76.34910014367874, 73.24245745135893, 64.33839867191931, 74.01215199501284, 67.05807993488928, 71.90124219463718, 70.35982916432043, 70.99695544089042, 67.43359196570613, 76.63497817131781, 77.38730445984872, 68.4966641087686, 69.41365149713332, 69.07297795818698, 65.00379347032117, 69.96509751965924, 69.45030996876379, 68.10775326144311, 68.97098064422607, 68.76944926477248, 73.93652869809058, 87.40055068846672, 88.34351201211253, 95.44864239231234, 84.92562924661945, 77.28625635946952, 91.88092508623677, 85.82228306801089, 77.33452504681003, 87.04465050851145, 92.61753051511704, 94.24973857018256, 92.85284919123497, 9.78062222080846, 0.382254094846787, 1.8342729994366247, 2.3263023457219525, 0.6749472406602676, 0.16891861815125714, 0.26982554384777624, 0.3435959192293306, 0.32912344581657843, 0.22797244450738355, 0.15241631817433143, 0.256506814170749, 2.078910614213636, 40.55527187162831, 80.4307185449908, 33.11678317285354, 93.92717853669198, 131.31889020243, 48.4908974555231, 37.13468267071632, 63.27342025695309, 78.58001093710624, 94.77988612267279, 100.47885464083765, 84.64727432497087, 6.231797010667863, 0.2583752566527936, 0.1243681462121106, 0.146282451347478, 0.09134329089354123, 0.1840351263601934, 0.20128045501487873, 0.11218420725556151, 0.16487715195023245, 0.16785743315854382, 0.1368646567026454, 0.1928169914190808, 0.1687498796250551, 0.20074903514356385, 0.16371004764110814, 0.0990645761691755, 0.13877060684946277, 0.10124275565988596, 0.17100121285165512, 0.1852313266886819, 0.12550701252034596, 0.08046776116375001, 0.2493023088261966, 0.23469759331595516, 0.2017573600695018, 0.10097911416162407, 0.14426572488680964, 0.2402537379173502], [0.03943319612693402, 0.014097670641457363, 0.0303484141571267, 0.087081765936267, 0.043139904887685855, 0.02840995123880285, 0.019858485207923, 0.04446281998928997, 0.08418855828142936, 0.03718308481057325, 0.008980602630594326, 0.04751324420794845, 0.07525582752761341, 0.04577914290430565, 0.08091879542917013, 0.07374858018010855, 0.027251949969438777, 0.04184479111685388, 0.04767920949586457, 0.046183805867669084, 0.17085947126390474, 0.4158824129450706, 13.812641270699041, 109.49131596472957, 101.58372356045632, 92.41279848160283, 71.71455306391563, 37.42396923803514, 19.9890338220904, 39.277838276278594, 61.06538472637054, 72.2661324470274, 63.04318105020831, 49.61428780709544, 12.6830800502531, 0.12887213799741962, 0.047723565986680413, 0.14834875901860578, 0.06058269270485448, 0.14527985675921365, 0.01270690217478982, 0.18163279720371772, 0.010109768350488477, 0.1877085792441522, 0.07823508217810624, 0.07151420814015212, 0.34819967864501866, 2.802431506495322, 27.41072693178731, 61.40411669208158, 73.0772864434027, 82.63745184867614, 79.5177633531632, 79.35027814680531, 65.38369855573102, 66.72187789793938, 61.93580181367936, 66.73970114800238, 68.91860131294497, 69.00424234328732, 75.7367475571171, 80.90434474329795, 82.45352406655589, 82.28125356858777, 80.38321864220404, 76.23673992772257, 74.25082037525793, 70.56233329157676, 72.28237890428113, 77.37734163961103, 77.71120594393823, 79.51253091135334, 83.19785656467562, 77.55920625502064, 67.11304803048411, 61.22424856308968, 58.13078111217868, 57.47599240272277, 73.28025341033936, 79.75795361303514, 80.43968508320471, 77.19971318398753, 69.8107522533786, 69.27233634456512, 74.22069657233455, 75.34302003922002, 72.34671361984746, 39.60420693120649, 66.15387162854596, 85.55449501160653, 69.75044973434942, 71.52587136914654, 60.577520324337875, 65.80910313513972, 59.40320976318852, 63.51022158899615, 63.06434223728796, 64.20699534877654, 61.83203158840057, 61.85621692288307, 58.363765978044086, 62.58379305562666, 60.61246079783286, 62.38295593569356, 61.22541350703086, 63.001843190962276, 63.06279290106989, 66.30227058164536, 66.06481029141334, 64.9905711604703, 61.78683411690497, 69.40776794187485, 77.51471088778588, 78.72391485398816, 80.68241703894832, 84.95724355020832, 80.15497592187698, 79.31006600779872, 72.51498330023982, 62.430361701596176, 79.46445834252143, 82.33651191957536, 84.1072267101657, 75.95822811126709, 18.71730923652649, 0.9187574804790559, 1.8010075005792805, 1.0632009684078156, 0.4847981504374935, 0.06604172800096773, 0.1028058737997086, 0.07634967850941805, 0.14927986228177625, 0.20597133394931594, 0.05177805951285747, 0.007053017203185347, 0.408594066938085, 30.945392385605846, 63.550241531864295, 75.62993357258459, 120.28308991462954, 83.92852352511498, 18.459668351757912, 14.80637473444785, 48.85690558341242, 68.14285847448534, 74.19359299444383, 80.18722564943376, 35.138341380703835, 0.39161568928149443, 0.03561274629206427, 0.06614422290435722, 0.029129723402401133, 0.05590923077937576, 0.07274174912562294, 0.07375266342874497, 0.057148519723165425, 0.05881493715869804, 0.016401254894932913, 0.012143793076487079, 0.05659564172909145, 0.06689738692535509, 0.02971889672710771, 0.052215039895306674, 0.04293850803327176, 0.02812864758344668, 0.025882477789456328, 0.006806681631132961, 0.022423937466115724, 0.04239233713897486, 0.031921908957883716, 0.0179379832209839, 0.0267165215430601, 0.023400630621660142, 0.035294689568540746, 0.05663519101818243, 0.051370232606366764, 0.04798260329651737, 0.009331956408136796, 0.03488715377546126, 0.0046839171104253305, 0.020571222769156582, 0.04430423978896392, 0.04725441757229067, 0.06472998629173925, 0.08036833061205764, 0.03139787608937871, 0.06118055155140258, 0.026686973531820604, 0.05194704318719526, 0.0684157578695205, 0.09593172855074368, 0.10866532027120553, 0.03748216936665197, 0.026783058194503672, 0.06980857466377559, 0.16087817298548837, 0.5509370337090185, 19.75020266348316, 130.32027829077938, 113.40795947659402, 105.7627030341856, 86.92823456179711, 53.46348224147674, 41.1212424309023, 44.14591935373122, 41.81499204327984, 76.6551705329649, 54.71653046146516, 53.96860899463777, 17.022721767425537, 0.01805188900400554, 0.09789669811124764, 0.10132419080623697, 0.057642692399601785, 0.17094492071097897, 0.06576494809480445, 0.42298956383620545, 0.30090527128308053, 0.5579749915388323, 0.07010213189548062, 0.24948537319658265, 0.41690213725932185, 3.8065884238289254, 29.617646548055834, 72.55151625602477, 82.13221134678011, 88.45993580356722, 84.32686375033471, 83.17705231328165, 68.76333036730367, 68.46090778227776, 63.608790751426454, 69.59919529576456, 73.92252583657542, 73.6803351679156, 78.85901697220342, 84.72756524239817, 83.5748512514176, 82.82736516767933, 85.75538312235187, 81.02680114007767, 78.08376050764515, 73.55280322413292, 77.02926266577937, 81.1899168260636, 81.68030723448723, 82.3532525954708, 86.08174001016926, 81.3913619133734, 71.31748368663173, 63.43005226504419, 61.85848013047249, 60.06481555200393, 76.72402381896973, 83.925291492093, 85.254880843624, 80.23336056740054, 72.80690177794426, 72.88879302240187, 77.3839626004619, 78.3767694042575, 78.2969727054719, 44.187582769701564, 65.8711628760061, 88.97244053502237, 73.48331451416016, 75.794767256706, 64.07145392510199, 68.07248330885365, 63.84931833513322, 65.6124198052191, 66.74811070965183, 67.75936049799766, 64.73608778369042, 65.55654171974429, 62.35687217404766, 65.44284789792954, 62.028663927508944, 64.74020235000118, 64.84766352561213, 66.85209274291992, 67.78316928494361, 72.21933857087167, 68.17920315650203, 66.87800392027825, 64.62801471833261, 72.90074056194675, 79.85067059916835, 82.94391447497954, 82.98034544914, 87.17286494470413, 83.71659001996441, 83.37087231297647, 76.18648652107485, 65.77589242689072, 81.01498696111864, 88.2593850166567, 89.4733742744692, 84.28461982357888, 24.455995675056215, 2.1745502564214894, 0.65046270287806, 1.2487305484471785, 0.6687891807767653, 0.45263643106145246, 0.3944814097016089, 0.13558809375089986, 0.23875615859944976, 0.24565223694568683, 0.03948748877812778, 0.022636151482020656, 0.2041026003538601, 29.4285745774546, 55.08271901838241, 78.14716169911047, 121.26904826010428, 75.77686555923955, 31.35415238718833, 24.90339690639127, 56.43570138562111, 79.32684590739589, 80.08621677275627, 92.99863584579961, 48.45434488788728, 0.7195746201661326, 0.0776282869159214, 0.058168255528735544, 0.016447911564741406, 0.03325478894816291, 0.057939099478385145, 0.046310624062654474, 0.03420885569686371, 0.08355075944094889, 0.019949435166293578, 0.03648212585117548, 0.06437903375274713, 0.02994978605138679, 0.014623995070465872, 0.07049541845316849, 0.051954355496432514, 0.06725808410274406, 0.07034347257426671, 0.06702168469106959, 0.06708965201171176, 0.007388409538825433, 0.06617935569656473, 0.061893074608017365, 0.01889946570079173, 0.04762225468913394, 0.018558382289484143, 0.073930426470695, 0.19222834477982215, 0.139875014522864, 0.07487964771327472, 0.14856416762115496, 0.08049616004310309, 0.08920228964979611, 0.1838169598411168, 0.1096149628621436, 0.16795635043132692, 0.15855694189667702, 0.09403733100982443, 0.14775481105091112, 0.1794167193433931, 0.13947971315393526, 0.17654886919884913, 0.33605439648512875, 0.1528385245511609, 0.20235328454404108, 0.14010254263637528, 0.24462434613416273, 0.42849589740076377, 0.7891027377017084, 23.941006122096894, 148.45883984719555, 127.28239474758026, 119.42995871267011, 96.260510260059, 58.45514543594853, 33.61288847461824, 56.35535163264121, 86.16956187832741, 98.05697933320077, 87.73352853713497, 76.95174094169371, 22.7127629710782, 0.39423476003350755, 0.18914130155838307, 0.33940728753805166, 0.176034226653076, 0.4250501564914181, 0.17046325058946687, 0.4206606565463928, 0.26623856696871023, 0.5564555633933314, 0.28633645465297086, 0.6644638483562778, 1.3823133610909986, 6.021190247228069, 38.24572540098621, 79.24419372312485, 83.69429526790496, 94.12259886341711, 88.98915767669679, 88.05733588434036, 71.47357048526888, 72.70519471937611, 67.18368991728752, 74.484617171749, 78.13035042055192, 76.52337889517509, 80.84299887380293, 91.19774233910346, 86.7217766854071, 85.4510699549029, 89.19845534909157, 85.58606224675333, 79.92641941193612, 79.33916214973696, 79.81871897174467, 85.65359761638027, 81.75349866190265, 85.7087932094451, 90.21842064396029, 84.03273305585309, 75.71715924047655, 66.64508573470577, 64.98202823823499, 64.11499615638488, 80.411647981213, 87.5975948764432, 87.60610641971712, 87.08977345497378, 78.1108719302762, 76.05573038901053, 82.4383758729504, 82.66948976824361, 81.89805369223319, 47.968555419675766, 71.14530732554775, 92.34998564566337, 78.39433377788913, 79.92157136240314, 68.34431925127583, 73.9446323148666, 67.37500744481241, 70.67743916665354, 70.54122309530936, 69.94966691540134, 70.00173245706867, 69.81552185550814, 66.42908865405668, 68.6264318035495, 64.66813272045505, 68.64552590154833, 67.86516251102572, 68.98148475154754, 73.31918685666977, 73.69646395406416, 71.69143461412, 71.1857234278033, 67.4268219547887, 77.79969461502569, 84.52541412845736, 88.55590835694345, 87.53202069190242, 90.49407697493031, 87.41196478566816, 85.7671110091671, 81.5510259136077, 68.06766663828205, 85.08657193952992, 91.6412212002662, 91.29799812070786, 85.32795459993424, 22.9755009758857, 2.486305385828018, 4.428771695783062, 3.997752243472684, 1.0780872212302302, 0.22459058000916438, 0.5031143014709796, 0.23016681143593407, 0.4609495575629896, 0.49144831456003657, 0.10894885707286098, 0.16155890339324552, 0.8334070119646289, 48.3559993005568, 83.86715412139893, 79.87700539250528, 122.64848309178507, 99.05210818013838, 27.222923847936816, 23.379487452968476, 65.05816928801998, 90.78699173465853, 92.12148404890492, 105.17863073656636, 56.9052993097613, 0.8112733835174192, 0.16734515016357746, 0.14554542879904472, 0.11128652840852739, 0.1603325038787819, 0.17601191817272097, 0.13509476377118018, 0.12203548509146898, 0.2191354824049819, 0.1173435566165755, 0.0865579839615572, 0.28939765006784474, 0.13603645436946424, 0.13837679169110714, 0.2228804112922761, 0.1426461230843298, 0.10610855545007414, 0.1365389314389998, 0.18423576478756246, 0.19233175132784153, 0.14767702248307968, 0.12186720621802154, 0.17381641743404252, 0.14531028577156607, 0.1644465339279944, 0.2030900619443386, 0.18784318089244828], [0.027711870854780562, 0.006912579880126062, 0.03414339731417356, 0.03596187937223623, 0.06469254757487966, 0.040031817230966785, 0.0320997869130224, 0.012632031444339983, 0.024127073495859103, 0.033948853116242156, 0.05602589830936444, 0.06774938394946438, 0.04349382984782419, 0.045711983806423606, 0.017016406261151838, 0.0201399554874027, 0.05483288107620132, 0.03647061538011317, 0.10472832548041498, 0.12366255625121056, 0.006550330895885465, 0.12046527297746752, 63.685288736897135, 109.64524545977193, 95.4112857387912, 72.92779707139539, 54.00400054070258, 53.44636109567458, 34.502584011324, 55.472598691140455, 60.57562581954464, 29.386077657822643, 54.06928446985061, 16.26559743958135, 0.18017344567323887, 0.038893663384501016, 0.0891393631876957, 0.04600354537908589, 0.17656193865883738, 0.061931049586423946, 0.1639160793274641, 0.016756374952233127, 0.010752886713993166, 0.08486053230421198, 1.0250936100079169, 0.8370325690315616, 14.532619772418855, 61.19114768120551, 83.0611619641704, 73.67519686298986, 78.94376370214647, 84.01157579114361, 80.83187503199424, 75.83093150969475, 63.6227975353118, 62.40195981917843, 61.52529047381494, 65.6939148902893, 65.12517121530348, 67.37010448209702, 77.06138687749063, 76.86599008498654, 84.58618733190721, 76.32659358362999, 79.01758270878946, 78.16935446954544, 76.458526426746, 74.00611154494747, 75.68337978855257, 81.10150660237959, 80.0090794409475, 76.98155879974365, 81.10908462155251, 81.58473476286858, 69.6102406901698, 57.082657121842914, 60.110087548532796, 54.774679599269746, 67.97341992778163, 78.80042460656936, 80.88904749962592, 75.44025559579173, 70.67579961592152, 60.64251792046332, 70.76158185159007, 67.91791838984336, 88.24319347258538, 41.402703869727354, 46.578118339661636, 91.77833941675003, 71.82898429132277, 81.08963751023816, 66.54541830862722, 62.88987913439351, 57.76892285193167, 65.27555488771009, 63.877190697577696, 65.78121508321455, 60.813603862639404, 60.09712019274312, 59.83438022675053, 59.04909033929149, 57.02375488896524, 59.92026444404357, 62.25972683198991, 67.55229857660109, 69.3301599256454, 71.4005437974007, 68.84227983413204, 67.64009691053822, 63.74012347190612, 65.21010621901482, 68.52394811568722, 77.18014840156802, 80.52973485762074, 79.86202978318738, 80.02101913575204, 81.86163056281306, 70.05053458675262, 65.69993572850382, 67.27688543258175, 78.48422665749827, 82.26606615128057, 83.57884422425302, 78.41609508760514, 31.173941050806356, 1.2086705238588396, 1.8922906152663694, 0.8326100353752414, 0.41097047167920303, 0.18098358365316547, 0.12876658640321226, 0.16803983869331499, 0.07726057237314601, 0.0874886965198863, 0.05669908658150704, 0.06508184281448204, 1.0168371433692596, 20.126153999759307, 40.12457209248697, 73.29640573070895, 75.318936686362, 45.91160566576066, 27.175267050343177, 36.89588877462572, 61.20360120650261, 73.29687641512963, 80.09811724385908, 72.8908718785932, 12.51435733610584, 0.3038876515723044, 0.06049255096924402, 0.09408066094282175, 0.055694534638596166, 0.08923899292224839, 0.025417232593040795, 0.032841185738723126, 0.0549462735803137, 0.05941224059150104, 0.04989865814305602, 0.024250451956064473, 0.027654433412657633, 0.06932381720792863, 0.06044794549985279, 0.07062407525917215, 0.03479382511408579, 0.00616145987747117, 0.021508050624341257, 0.02564785953220581, 0.04360556760202012, 0.07753255656890332, 0.05568125067398914, 0.05178909500940673, 0.05018096154315337, 0.04110175860865463, 0.028731001450890498, 0.030188386050623753, 0.02247721696602962, 0.02700964593508792, 0.038829277524904865, 0.042781571091543284, 0.007168474314253658, 0.021929393237036084, 0.024930171127761566, 0.01675032285763131, 0.03915021473902368, 0.028334826741728093, 0.05431833812185834, 0.04218740478879021, 0.05405255540784809, 0.06593404668233087, 0.06151281537548189, 0.04977752815090841, 0.045541644156459844, 0.05843530611826047, 0.0838099652901292, 0.013742282453383652, 0.23133098928918763, 81.99095895213466, 122.1941706442064, 108.50890344189061, 84.93917711319463, 68.74373420592278, 71.04254122703307, 43.4814541570602, 51.04989490201397, 57.885350565756525, 33.80550430667016, 57.1228967174407, 20.296794752920828, 0.3608392407336543, 0.028210856478601217, 0.055367081846681335, 0.34829433646894276, 0.185993553529824, 0.36807687172005255, 1.007054997307639, 0.896584812191225, 0.5645108859865897, 0.14389037244742917, 1.130904509655891, 0.7590060236473238, 16.26615833851599, 63.84507433060677, 88.89581311133601, 77.80415827228178, 82.52222045775383, 89.20546070221933, 85.11344017521029, 76.56679168824228, 66.20395245090609, 66.28395311294064, 65.76321140412362, 69.68094533489597, 68.16800871203023, 71.72024050066548, 80.83680152893066, 80.92350944395989, 86.54338728997016, 76.66617670366841, 81.35795900898596, 81.64393901824951, 81.07350087934925, 78.56905183484479, 79.62373010573849, 83.21953942698818, 82.6819315264302, 79.15601099691084, 85.72058385418308, 83.89306529875725, 73.75713517588954, 60.43850760306082, 62.29623233118365, 58.17662185238254, 71.33846052231328, 82.08293068793513, 85.47874619883876, 78.52666670276274, 72.8029009603685, 62.28440246274395, 72.07245365265878, 70.71453694374331, 93.03126996563327, 44.90025781816052, 49.262200170947665, 96.57111490926435, 75.57427513983943, 85.69477465844925, 70.32124873130553, 64.2882864705978, 61.33762467292048, 69.79532164912071, 66.11366733427971, 67.99794258609896, 64.0065465434905, 61.82320625551286, 62.97751665115357, 62.18118136928928, 59.12185422835812, 62.85573882441368, 64.86168599897816, 70.11286889353107, 72.57501125335693, 76.8423617270685, 70.95087543610605, 69.692077021445, 66.31762273849981, 68.92066447965561, 71.8632971855902, 81.39008322069722, 83.16935662300357, 80.42234820704307, 82.21440069137081, 84.7435998916626, 72.15686305876702, 69.46914519033125, 70.58520070968136, 80.41626853327598, 87.09666113699637, 87.42635203946023, 83.49265406208654, 38.99738096421765, 1.9262270845713156, 0.8044363858719027, 0.5565553386845897, 1.0944629941255817, 0.8671538591865571, 0.8314550812205961, 0.1028235397872425, 0.10981724071767061, 0.11171794316220669, 0.10956989390955818, 0.0884164902832239, 0.7624808758977921, 24.308834229746175, 41.851489697733236, 87.70670736989668, 73.74809803501253, 36.58465654619279, 37.2242578383415, 54.143546704323064, 70.13921153160834, 81.4569753216159, 87.09974411995181, 88.43830785443707, 18.775081826794533, 0.27214942560080563, 0.09313876350079814, 0.013172554355415126, 0.0419150069055538, 0.07358893511756774, 0.04794294675511699, 0.0569584648004703, 0.03777884457620882, 0.03760704169830969, 0.0425540276562735, 0.00978489057160914, 0.021779713063170354, 0.06255505884426736, 0.07921786573264869, 0.018067360149636384, 0.02945124858900184, 0.025083306358165802, 0.021430099262825904, 0.06584248385362088, 0.03151367410957333, 0.05572667585745935, 0.07016529584483755, 0.12872429834979196, 0.04093608443414973, 0.05856117819465938, 0.06599344913997958, 0.2160905127323443, 0.09301559954521157, 0.17423339909122837, 0.11973868454656295, 0.13701839522728998, 0.1425300454420428, 0.14653460152687567, 0.10298673949775197, 0.0785313283784255, 0.2573507825934118, 0.12672812602813208, 0.1731934653775346, 0.11736419502525561, 0.10889189077481147, 0.10382041935959171, 0.1366761684297554, 0.15372082801355472, 0.21048867864714516, 0.19867220142435646, 0.15277299339011793, 0.12580164993602422, 0.3698393948856862, 95.77719580742621, 139.09946841578332, 121.7665695375012, 100.52008659608903, 76.93843626206922, 73.67655400306948, 49.82950433608025, 76.5335770576231, 84.77406886316116, 42.07285258077806, 80.7540552077755, 25.48011083756724, 0.7827995501218304, 0.1349408107419168, 0.32432157606367146, 0.28074695458335264, 0.8318699944403865, 0.3331390642110379, 0.8618467084823117, 0.6311699123151842, 0.4093880098192923, 0.37046078412282857, 2.062655576775151, 3.3440007557792053, 21.66180310710784, 71.02816181798136, 93.28450602869835, 77.89023076334308, 84.42513481263192, 92.72985935211183, 90.27446346898233, 81.75121584246236, 70.0064863697175, 70.76431966597035, 69.39083899221113, 73.80352112554735, 70.73101089846703, 75.0759772331484, 86.72107850351642, 82.4585525451168, 90.99974109280495, 78.13577898087041, 82.31493888362762, 85.64229334554365, 85.76599705603816, 81.73457714819139, 83.11372172447943, 88.0223326529226, 85.50621847952567, 80.10003136050317, 89.25626324069115, 87.58549828683176, 75.75514347322526, 64.0105434386961, 66.02509237104847, 60.26464462280274, 73.34005386598649, 86.28114546498945, 89.09707776961788, 79.86766230675482, 75.29041321046891, 64.99759612544891, 76.28769151626095, 75.7535509909353, 96.1790269420993, 49.665227628523304, 55.76652150000296, 100.21691091599004, 77.85089723525509, 87.33511770925215, 73.95220248929917, 68.35326225526872, 64.71838612710276, 72.76334777955087, 70.37954299680649, 72.95720700294741, 67.11668014526367, 64.99609385767292, 68.22668736980808, 64.8079103039157, 62.966651685776256, 66.31759135953843, 68.11157364999094, 74.33701838216474, 75.751723166435, 79.76619059039702, 75.78161162714805, 75.27219772338867, 68.63067580807594, 71.69266623835411, 76.3961293620448, 84.56318655321675, 86.52866271234329, 83.44654267834079, 86.89030524223082, 88.95682165699621, 75.77842666256812, 72.36215206884569, 74.51663155709544, 84.50828121554467, 90.09529744425129, 89.06471821569627, 86.36572745538528, 35.1849312936106, 2.1579522567410625, 5.841859973246052, 4.77082787021514, 1.1392842858068406, 0.560335706799261, 1.2433718553473874, 0.3716679854739097, 0.3112481324182403, 0.39446780398007364, 0.17409332757515295, 0.13434790465379917, 2.4858050384829125, 35.905321644198516, 54.32664686633695, 82.89265694156771, 86.70541255704819, 59.627090807883974, 38.063170448426284, 53.83966107522288, 78.6257928417575, 95.17401372232746, 97.98662770179011, 99.97454766304263, 20.126928667868338, 0.49427119534342523, 0.2158029386473279, 0.19629313069726192, 0.14901836582970235, 0.1974923647339306, 0.13875476415118865, 0.1730916676141562, 0.1647643531642614, 0.095869897594375, 0.11381745308397279, 0.20493196714068615, 0.16714274973398255, 0.1394573127430293, 0.13958215443117006, 0.2363958723482586, 0.11676816329840692, 0.07680858815869979, 0.1112614390290072, 0.2283181033788189, 0.18492677609526342, 0.13448866564900647, 0.12738113937478873, 0.1918251680270318, 0.1217114375603776, 0.14884962730350035, 0.15276180850642343], [0.04277180347050871, 0.03229070943029177, 0.051158865117618156, 0.048673472877952366, 0.06824901117192161, 0.04943214890156542, 0.008602832226202855, 0.026674606957502907, 0.05013696894410157, 0.10175172149414018, 0.05186900181034881, 0.05077057728363622, 0.056191131983312874, 0.016552653020968842, 0.05550388982819934, 0.09372862055897714, 0.05548494830427151, 0.06308313857223238, 0.03304878407488427, 0.1833728586714114, 0.35505025136855345, 6.896305843707054, 94.84625262598838, 89.13035515815982, 89.46283878818636, 68.24738963957756, 42.50933785592356, 14.80250237449523, 53.301680549498535, 32.25101213301382, 35.94780483553487, 60.69952957091793, 27.686010637590964, 0.19632277829993158, 0.011994656825047589, 0.09054095168868381, 0.08003967889254132, 0.16515177914932852, 0.054942144366401824, 0.33481934017712073, 0.20818773356656875, 1.6616116127660199, 2.213533958119731, 0.3858350962400437, 0.1838709383962616, 25.653618843324725, 87.20671499929121, 91.77047114218436, 86.74528737221995, 83.56025218963623, 84.79701472866921, 84.27400588989258, 80.75193712788244, 69.1257809054467, 63.20187622501005, 60.82414719366259, 67.0170440981465, 66.42253045112857, 70.20269901521745, 71.46420386529738, 73.88274515828779, 75.90527611394083, 86.16065809803625, 76.88915560322424, 72.93254313930389, 78.25577997392224, 79.57840319602721, 76.24029359509869, 79.5301031297253, 76.92673975421538, 74.0580358812886, 75.10581078067904, 76.3291980374244, 77.62717308536654, 73.19618917280629, 57.84857834539106, 60.10649857982513, 56.91618780935965, 64.64743829542591, 75.47703173852737, 80.11122580497496, 76.28414569362518, 71.27360020914386, 59.705997128640455, 63.94565566893547, 63.53084933373236, 86.38824186017438, 53.79672681131671, 32.92897616663287, 70.08743624533378, 73.61041499722388, 80.61020620407598, 73.13838912594703, 63.20249595949727, 55.476309253323464, 60.76182857636483, 60.547478891188106, 62.290964588042236, 57.43976539181125, 60.94714487752607, 59.842789788399976, 61.50576099272698, 57.6263839198697, 59.48559522628785, 63.03303387857253, 70.86825463079637, 70.35415741705125, 72.37831223395564, 70.99027172211679, 71.73607118668096, 70.6651621480142, 66.61658579303374, 71.09682683021792, 74.83916021162464, 79.25650996546592, 78.56061089423396, 77.92472408663842, 78.19942335928641, 76.45105823393791, 63.34198720993535, 62.51984665470739, 73.79662559878442, 78.32298586445471, 84.15768408006238, 81.26397117491692, 79.35644411271619, 25.5396092707111, 0.7759521949675776, 0.8236666023731233, 2.8685550680083614, 0.02952215577205343, 0.026369290276160164, 0.12777642542195897, 0.14941406556435172, 0.11406587241517921, 0.14253715473798015, 0.0820240687819258, 0.05951218825254229, 7.8414744811673325, 27.08725690841675, 30.255712232282086, 56.08735176824755, 64.56319755123508, 24.105320092170473, 16.429856496472514, 53.41431140899659, 66.24437639790197, 72.27165514423002, 75.93069307265743, 61.754321590546645, 4.845777009764026, 0.10788243203874558, 0.07781124403399807, 0.030299865250145237, 0.04120602700558882, 0.046657884057851574, 0.05770120236481871, 0.024247048610460856, 0.02533030268105288, 0.08865974618182068, 0.03529547097822351, 0.021620910697346254, 0.06416150308664768, 0.049245943570689815, 0.030407853003951813, 0.060665280813531536, 0.026334975282811833, 0.03954574210389007, 0.03757360196041484, 0.04211680595612815, 0.05157835571275604, 0.11765867922334902, 0.03281602741128976, 0.021302369423210624, 0.019780217835138884, 0.004682637743591782, 0.03629986587310991, 0.06459177636931981, 0.0677777215417835, 0.017452024922315634, 0.02157810361935727, 0.06037545059957813, 0.056315391444631165, 0.06579842613709551, 0.08132588689125354, 0.05673956666742602, 0.048792097762587576, 0.056367535219197316, 0.048573452438558304, 0.016333515485448223, 0.06683137312891983, 0.08878487898337264, 0.05478522657687145, 0.05328190542997853, 0.12843339178230495, 0.17880564164971152, 0.5148161719402959, 10.421943472277734, 117.49615177031487, 100.51576414415914, 101.10960314350744, 80.71223489699825, 62.60699387519591, 23.318002339332338, 32.16300787464265, 18.804795742034912, 37.18075090839017, 49.592342145981334, 32.12680439795218, 0.2566948121473674, 0.061843547023712635, 0.16193983295271475, 0.2861779663831957, 0.24055563784655065, 0.5506085352070871, 1.7590472102165224, 1.4721286513151661, 1.6894584798043775, 3.973407562701933, 0.4517278814267728, 1.232292753073477, 28.771348114936586, 94.53633831393336, 96.73827063652777, 93.0302187704271, 87.19821914549797, 89.03767739572834, 89.32634030618976, 86.70608720471783, 72.08706055918049, 67.61602140242054, 65.09053276431176, 69.64909568909677, 69.1727787448514, 74.6485173317694, 75.45195210364558, 79.62059220960064, 80.4965280717419, 86.71918792109336, 77.34878678475657, 76.7139825513286, 82.27353434408866, 83.50569202053933, 78.07793186556908, 84.53281171860235, 80.97596722264444, 78.20683663891208, 75.49301147460938, 79.04114046404439, 81.10444053526848, 77.08103795205393, 60.1966699477165, 64.30801991493472, 58.86572737847605, 67.83936900477256, 78.33613364927231, 84.51862842805924, 79.77323516722649, 73.47295945690524, 64.37743802224436, 66.83289666329661, 68.78527995078795, 88.92068093822849, 55.01864710161763, 36.08681755681192, 75.25591988717356, 75.6419046463505, 83.89009214216664, 74.94345603450653, 66.37510899574526, 59.65225673490956, 65.62098233930527, 63.88768696015882, 64.10064812629454, 60.36834424541843, 62.83882948660082, 61.53727331469136, 62.521023365759085, 58.51694237801337, 61.06113287710375, 65.96751197691887, 72.45428069945305, 73.60562186087333, 75.29133104508924, 76.85266971588135, 74.6853562324278, 75.18835313858526, 69.45465595491471, 74.82944842307799, 78.57834785215317, 84.55444751247283, 79.45338941389515, 80.02432177143713, 82.11783978246874, 80.36938836497646, 66.56378284577401, 64.16041328061011, 76.00557896398729, 83.5482418921686, 88.09744604172246, 85.3401453264298, 80.17794532160606, 33.24355417682279, 1.505399175709294, 0.33078266968650205, 1.3446545624925246, 1.4927923102532665, 0.8120835981061383, 0.6784882216203598, 0.19616692537261596, 0.032346281448319074, 0.23390740426557682, 0.08195179604714917, 0.10336687232577994, 7.900727275879153, 32.087019797294374, 31.00363369910948, 58.277713098833644, 40.24846015437957, 27.934700673626317, 24.603798427889426, 62.97814030801097, 74.87019400442801, 79.40161412762058, 86.49209837759696, 77.85969903392177, 7.520618227220352, 0.1882822718471289, 0.05450737414761417, 0.059000399384287104, 0.09221653153579082, 0.052226749549229304, 0.043326186827353896, 0.019478729678197734, 0.02275997044278249, 0.06845424612683636, 0.03969775693070504, 0.048229976917707154, 0.04325150091561579, 0.017175892360448357, 0.03514975722458574, 0.031469032251005696, 0.018578727669533224, 0.014149868999788118, 0.05593253517403238, 0.06530661301146592, 0.036272099016294364, 0.043787574771070675, 0.009503419334519534, 0.0600513264596943, 0.050659429417141986, 0.058021825482888575, 0.13450152060437587, 0.1526952967528374, 0.11643756571556292, 0.10335575638999862, 0.13201786355385858, 0.16893970089093333, 0.14730787535588588, 0.15548204882971703, 0.1253103960545794, 0.23892630672743245, 0.12004135056368767, 0.16614190182618557, 0.1341634613251494, 0.09805606738213571, 0.15085182873712433, 0.2599132547695791, 0.18660256278611, 0.13722260362438618, 0.1582833412553995, 0.3317768373075993, 0.8099918103506489, 13.462736433552159, 143.22230308286606, 112.60250076170891, 122.03477336514382, 89.27226651099421, 62.70783408995598, 26.26778356490597, 78.09659450284897, 49.279941051237046, 52.71512931393039, 92.34480811703591, 42.898966496990575, 0.8650300183123159, 0.14825454552567777, 0.24747541895316494, 0.32986400769122187, 0.8257642736838711, 0.4756898859575872, 2.6711892456777635, 2.2458817449308213, 4.461808348855665, 6.282072970944067, 1.6686265266710714, 3.083589451928293, 34.997642040252686, 99.72932892460977, 97.45681747313469, 93.17981796879923, 88.90503068124094, 90.77400868938815, 93.84674641393846, 89.50855793491488, 76.49162338626, 71.13277143047702, 67.62314442665347, 73.96944522857666, 72.52165132953276, 78.3227740564654, 79.05755166084536, 81.83572723019509, 83.28698850447132, 89.26670459008987, 77.9966054424163, 77.51829593412339, 85.27236676985218, 85.37419149952551, 83.20122980302381, 87.5923938135947, 83.6943894047891, 79.12430255643784, 80.6953687052573, 82.87812848244944, 84.66246958701842, 80.78381030790268, 62.257538149433756, 68.01599333363195, 63.047542725839925, 70.96413304728847, 82.13455692414315, 89.11705047853532, 81.29930388542914, 79.04358017829158, 67.46384912921538, 71.15036718307003, 72.22515152346703, 91.44147842161118, 60.57873233672112, 41.79774538163216, 79.62762109694943, 80.62009057691021, 89.00361553315194, 79.84399472513508, 70.61745043723815, 64.16001712122272, 69.46488549632411, 67.47760880377986, 68.52197908586072, 62.86345412654262, 66.60375179782991, 65.65580121932491, 67.02019768376505, 62.33651115048317, 65.25848081035, 70.05423730419528, 78.3867871376776, 79.35608325466033, 79.23400340541717, 78.17039782001127, 77.1300518897272, 79.36020958808162, 73.86690662753198, 76.42091874153384, 81.63095597297915, 87.96670559913882, 82.17447880775698, 82.13921669990786, 85.32286336345058, 86.94615194874426, 69.6588545460855, 69.65416339135939, 80.13275177248063, 86.83894572719451, 91.31284821418025, 87.59425301705637, 84.152553619877, 30.461381712267478, 2.572680879985133, 6.048024652465698, 6.757327933465281, 1.7592208976707153, 0.5761100700305355, 0.957088168830641, 0.8979181729016766, 0.3552547968443363, 0.3432544278762033, 0.3618153593232555, 0.34616081224333856, 12.793407497867463, 47.94007116748441, 43.7223308317123, 71.84094752034834, 84.42805305604013, 33.74306017352689, 26.154674176246893, 73.21657765296199, 85.7977290307322, 94.14333251214798, 96.40565364591538, 87.22518936280282, 8.150537148598703, 0.2951255975471389, 0.13647565257645425, 0.17574363418163794, 0.24013956017311544, 0.10446027131570924, 0.12396029632298217, 0.06601448591438032, 0.08078967130953267, 0.2223137666982028, 0.13125205142123084, 0.09536119989089428, 0.21606843407836654, 0.12428474221979419, 0.08343399231953007, 0.20553650244349436, 0.2065953278854009, 0.17550029401336947, 0.1860475320849688, 0.18317932953997967, 0.14093506570544936, 0.24915108306994363, 0.10134708151341447, 0.16529719795911543, 0.17104313318287173, 0.14509925919194377], [0.11076853039764589, 0.03242351077196579, 0.04022258078499187, 0.017764261292834437, 0.05144005002934606, 0.05369491109083738, 0.05585812888438663, 0.045227165063542706, 0.03844958136699373, 0.032786751361263376, 0.034049333208390785, 0.037487486016846476, 0.06270467198543972, 0.030954498872761766, 0.08271629050854715, 0.02814113864705207, 0.04495272938642771, 0.05060604841057813, 0.11853574264434077, 0.04710304242889247, 0.3470741116231488, 38.13498904628139, 110.4441773506903, 91.44829550097066, 95.09746474604454, 53.50910725132112, 30.29716972381838, 112.70256826954504, 161.94562727405182, 113.71878377852903, 62.626225256150775, 48.593361531534505, 4.731536507606506, 0.18576277720351375, 0.07759952797524391, 0.061438110311545675, 0.06537481015848537, 0.3504031620198681, 0.15532081796517297, 1.6956333936222139, 1.5675479053489625, 1.9533079862594607, 1.1970324838353743, 0.5065525347186673, 43.170967178960005, 97.17430483910346, 85.46672021189045, 79.85093732034007, 86.08785106289773, 83.4284213281447, 88.37703258760514, 84.57158827012586, 80.82985108898532, 64.2504277536946, 60.99186381986065, 62.93166414383919, 72.98673460560461, 72.50962534258443, 77.81154017294608, 78.18210217260545, 77.9480778786444, 77.6848005479382, 81.17468234031432, 74.33952869907503, 73.66091943556263, 75.92317781140729, 78.7709205381332, 75.40624864639776, 79.44688612414946, 79.30018947970483, 78.52676083964687, 71.87191855522894, 73.66663825127387, 77.17700266068982, 70.89946885262766, 55.57028139791181, 59.91883277893067, 56.51986368240849, 62.74237055932323, 74.5804798987604, 78.83680851228776, 69.44106886463781, 64.23525994823825, 60.94907076128068, 64.76192051364531, 67.81580340477728, 79.30521011352539, 59.01895869162775, 37.95958849691576, 68.30780198497158, 73.50668399564682, 74.27877902984619, 71.55696791987266, 61.77460024433752, 54.257307206430745, 60.27865140668808, 56.707945254541215, 56.78917754080988, 54.48787589227, 57.79550475458945, 59.339267284639426, 58.37061835873512, 56.378340644221154, 60.21009229844617, 66.87994941588371, 69.90676403045654, 74.28566671186879, 74.53316826974192, 73.23326341567501, 74.23259704343735, 73.35972063003048, 72.26519107818604, 73.6304190851027, 77.04395586444487, 78.8580991375831, 71.50314515636813, 71.94045805162, 78.11053460644138, 78.95586813649824, 69.12898940424766, 61.994625599153586, 69.16938981702252, 75.24882824190202, 79.28505697558003, 84.34518121903943, 83.81451591368645, 74.45211641250118, 15.879822527208637, 1.0493938576790596, 1.0135143442500023, 1.882188060591298, 0.11209976138366808, 0.021709031876056425, 0.13500839501859682, 0.16615682521895056, 0.016230557098864548, 0.07402040349740176, 0.029368526414938034, 0.12097013258044759, 15.326505534110533, 55.636491006420506, 39.67676293465399, 45.23886034565587, 50.065093655740064, 38.8532534722359, 40.880726614306056, 58.5016922027834, 67.95891500288441, 71.71296842636602, 81.62206003742834, 46.071995304476836, 0.47937332862807863, 0.048978651663468736, 0.044682162453330336, 0.002116976965842168, 0.0069259663089929575, 0.028901976953831413, 0.026213669090441642, 0.04942960548965682, 0.01664256493020202, 0.029127762217314977, 0.04135233064692828, 0.07532115950579606, 0.05696609120575651, 0.042233419859962124, 0.11187948046192048, 0.04142455358598982, 0.02084755451388417, 0.04025262675338215, 0.02963799784230369, 0.06421381540055718, 0.04820229050012366, 0.026222482932010488, 0.03755586702496775, 0.0727891699681359, 0.030967384471648166, 0.047278468902673454, 0.017934807786537756, 0.00926290220025206, 0.054433285784457004, 0.09450543371419753, 0.009852593591917428, 0.07192008152243591, 0.005211502711679186, 0.05051851137391022, 0.012216553234705522, 0.02436125699821259, 0.03891459673703198, 0.056972239061348864, 0.04622181148959264, 0.021843106838904565, 0.03508308076209599, 0.05116578289157441, 0.10239791665827075, 0.1470805464252349, 0.09699501262436952, 0.3783766174268338, 50.77448960273497, 125.99234288738622, 103.54570881012948, 107.54696569135113, 67.68104645513719, 42.02956922592656, 81.7887137013097, 131.79196726891303, 89.86074755268713, 59.92477516974173, 56.629642978791274, 4.995159497184138, 0.15541107844441168, 0.16517557384025666, 0.25424709994225736, 0.11046156662726596, 0.9210404837804457, 1.5829983666058511, 3.0871112500467612, 2.3065613017928217, 1.9788689695058332, 0.9746209796397918, 1.3827200618482407, 48.52379829652848, 100.4859305966285, 90.57261067052042, 84.56237070022091, 88.4726050592238, 87.97782159620716, 91.2044103683964, 87.21326535747897, 86.19819518058532, 68.27610923397926, 64.03042985546973, 66.30897783464002, 77.57295024010443, 76.96645767458024, 82.73909614932153, 82.10154625677293, 82.44224332994031, 82.18919554064351, 84.27641422517839, 75.29506514149328, 76.29261016845703, 77.36641391631096, 81.94102717984109, 78.94392844169371, 81.66462559853831, 81.77275749944872, 80.47297031648698, 76.18138743985084, 78.5466786353819, 80.54064689144012, 75.0089753058649, 59.303095186910326, 64.17446321056735, 57.57329463958741, 67.34060041366085, 79.81038001275833, 80.29589883742794, 71.20837119317824, 68.13860662521856, 63.160589356576246, 67.65342512438374, 69.24098876214796, 83.61325125540458, 63.74942733395485, 40.91325875251524, 74.9678845559397, 75.64556814009144, 78.24323623411118, 75.53830700535929, 64.57963620462726, 55.969147220734634, 63.61270135448825, 59.67202155820785, 60.91806834743869, 57.45374471910539, 60.75066551085442, 61.86066489065848, 61.45732756583922, 59.55993198579358, 62.74485734201247, 69.15468092887633, 74.24722748418009, 76.41936548294561, 77.75257125977548, 76.56071985921552, 76.93381571000623, 75.25162881420505, 74.81488858499836, 77.8796874323199, 79.34488881018855, 81.06063550518405, 72.51892920463317, 73.36841260233234, 81.74753665924072, 82.05603891803374, 73.27415804709159, 64.49949825963667, 73.29955147158715, 78.29061846579276, 81.85482917293426, 86.35492524793072, 86.90367267977807, 76.95412574275848, 20.81572432671824, 0.08583857377450313, 0.8230538546077667, 3.2713187461899174, 1.7030648142099383, 1.0501410691968858, 0.5976772224230151, 0.7484934587151774, 0.5308750295831312, 0.14929535257960522, 0.06685178171122266, 0.13083891552542487, 16.46716510095904, 50.8662965989882, 35.45221336426274, 39.83219861984253, 40.305079567816954, 38.08765780541205, 50.886983179276996, 70.25094416833693, 74.75135403294718, 81.83633911994197, 92.6428690264302, 60.18545981376403, 1.0510244605041321, 0.0222536763401642, 0.01576279051556823, 0.010511282692483116, 0.02430602397409178, 0.04047593372243066, 0.014294034298208934, 0.01611739825156908, 0.037477817987242056, 0.033184983016502474, 0.06810794374154461, 0.044526095021395914, 0.11323734066419064, 0.0076831867655498855, 0.12147305398097924, 0.026903548503234506, 0.0456843854889514, 0.05988017092609118, 0.009091685379614994, 0.03727984171540987, 0.018047568268112598, 0.028070591525324894, 0.015561540175469653, 0.027631900851584734, 0.051225453479996616, 0.18853425348718322, 0.07673532717050084, 0.23783060181285107, 0.1504777173601812, 0.2104942710889924, 0.15388112425083114, 0.16560427664268404, 0.11768150864349258, 0.14962803392160326, 0.18697132686934165, 0.1468212716281414, 0.1674562635561151, 0.19264813031881087, 0.11365202405760366, 0.16136753462976025, 0.13502791493890748, 0.14280585241654228, 0.27169666763755584, 0.26807898595448465, 0.19718297246483066, 0.34693523520423525, 64.6669207080718, 141.63741450155936, 119.83096614960702, 118.53208895652526, 75.09909568294403, 43.1912850564526, 129.61002334471672, 174.91641905999955, 123.16266659767398, 84.7216267739573, 77.05533858268493, 6.973817761867278, 0.2313203866323156, 0.32843788905489835, 0.32807813416565623, 0.5790955453149734, 1.4027312590229897, 1.8190723441300856, 5.528816100089781, 6.79930268756805, 6.902452688063345, 7.534225419644387, 2.9996522011295443, 56.11792664374075, 104.77075130708756, 91.63745572490078, 85.85463477719216, 94.08003330230714, 91.96349882310437, 91.19741286000898, 91.76956899704473, 88.85738172838765, 71.75450632649084, 67.77903510678199, 71.2788797193958, 80.89207556939895, 79.98566289101878, 87.29934569328063, 87.35592980538645, 86.44426899571573, 83.37958781949936, 87.74407971289851, 77.89585544217017, 77.7522574701617, 79.51308004317745, 85.60186155380742, 81.45051125557193, 83.0149721330212, 85.83416000489267, 83.60731278696369, 79.22108311806956, 79.26579813803397, 85.51900540628742, 76.7125940322876, 62.120368942137695, 67.8596947270055, 60.40111172583796, 70.84788184012137, 84.4599497702814, 85.72556526430192, 75.72298788255262, 70.89420503185642, 66.81214732508506, 72.33076526272681, 72.87804572812973, 86.71496745078795, 68.7174778599893, 47.38789950647662, 75.71766914859896, 81.75713077668222, 81.0471425517913, 79.8257557038338, 67.51359262774068, 59.322652124589496, 67.91183871607628, 63.383136795413115, 63.99284962684878, 60.4091251281, 62.86018679218908, 65.59235688178771, 65.11772263434626, 63.564609173805486, 67.34475028130316, 73.11712987961309, 77.20050550276234, 80.74785786290323, 81.04951166337537, 80.16236566728162, 81.42806745344593, 77.78362074205953, 78.26156154755624, 82.95655235167473, 82.73864899912189, 82.12022458353351, 72.25802098551105, 73.53632142466884, 85.32419696930917, 85.20699654856037, 76.45643188107398, 68.97323208470499, 77.36364472296931, 81.87092658012145, 85.99201187010735, 91.91169215786843, 90.76312803453015, 79.88723493391468, 18.832252333241126, 3.1675563656514694, 7.719844723901442, 8.136197453544986, 2.3291210589870333, 0.7462928251874063, 0.9225437321489858, 1.3808183251850068, 0.7030076317248807, 0.3544314668303536, 0.10708430631747169, 0.18446019790585966, 25.843359578040342, 78.88905448298301, 54.11578024587324, 66.95717303983628, 64.84601220776959, 55.479835464108376, 56.185403177815104, 78.1610861132222, 86.37722784473051, 92.30709060545891, 104.58044575106715, 68.22544790083363, 1.199534956005312, 0.16564034406215916, 0.19442974439551755, 0.14061251204581032, 0.15633164033774408, 0.1268699365637956, 0.1272617215891519, 0.11834831157278632, 0.08281942126491378, 0.1149808495275436, 0.15894991435831593, 0.1875744372486107, 0.3281476643056639, 0.14381489746512907, 0.22432323064534898, 0.07447041886588258, 0.136842685300977, 0.184348042633745, 0.07937059302123324, 0.24478050549664807, 0.13434503948496235, 0.14813111343931767, 0.1470626506113237, 0.1418870065601603, 0.13290683198119366], [0.02784144696629336, 0.031121048302720153, 0.026214471567542325, 0.03213402146713869, 0.03394468176749445, 0.13142488085694853, 0.04539837039286091, 0.039451827385252526, 0.0732353319143576, 0.0486651033673796, 0.023475942810276346, 0.06851879669533623, 0.05447186597232377, 0.0936371036955426, 0.01841617721853958, 0.01204561603616082, 0.02934185123341459, 0.07108699154829787, 0.08972820900981465, 0.06931886061905854, 1.3487441236934354, 76.58804308983588, 94.08998043306413, 86.01009399660173, 70.29123475474697, 53.15157928774434, 37.19073726284889, 105.88446909381499, 135.72878745294386, 82.23074128550869, 49.67917949922624, 16.612241806522494, 0.1265559937324255, 0.03699847294258014, 0.08334197749894473, 0.1557401591731656, 0.4234301256797006, 0.04768693932302056, 2.499527695678896, 2.2274760228972283, 1.509245795107657, 0.7227540076259644, 3.194269422561892, 42.46128097657235, 94.27834833821943, 79.58794240028628, 87.2809733113935, 76.52257088691958, 77.9486426999492, 83.78753000690092, 87.40160188367291, 84.92173041066816, 78.39998199093726, 66.46175415285173, 56.537808525946836, 67.37986333908574, 76.32859399241786, 75.97002660074543, 78.18720909856981, 79.69155573075818, 80.09837612029045, 77.85500003445533, 76.97456129135625, 77.7779725290114, 77.54446598791307, 72.36785519507625, 75.61556200827323, 75.64693312491141, 79.7784205405943, 75.58129618244787, 74.60010743910267, 76.053737824963, 78.44574036136751, 77.59765332744968, 66.54463383459276, 57.30358069942844, 59.20673039651687, 54.29398921228225, 61.742499566847286, 70.41973160159203, 70.03771628102949, 64.66782285321143, 68.54910619797246, 65.69410708642775, 68.84519807754025, 66.61787233045025, 81.65114833462624, 59.89834623952066, 41.95762903459611, 82.1762046506328, 62.83491496116885, 68.32544480600666, 63.301645632713075, 58.70474153949369, 54.39519420746834, 59.59319368485482, 55.826486695197325, 59.70691104089061, 52.40560723889259, 56.79315090179444, 56.75656695519724, 57.4466452290935, 55.85841871077015, 60.4768919175671, 65.43683490445538, 73.4631613762148, 73.01054339255057, 76.44171514818746, 73.16920326602074, 75.03796162143831, 74.39101372995685, 75.17991219797443, 74.75169920152234, 75.1336125404604, 72.23911516128048, 75.76204684472854, 72.90773807033416, 75.27506889835482, 81.20229582632743, 73.0950390908026, 56.985315661276545, 68.33019087391516, 74.98685313809302, 78.68185135626024, 79.09545744619062, 80.9294871361025, 77.85841249650525, 70.19745088392689, 7.421371965639054, 1.6162649686298065, 1.9378050633015174, 1.1901234739249753, 0.07177945076217575, 0.14750947905403955, 0.19195901890916212, 0.2051058997430148, 0.1614778972561321, 0.04104443224928072, 0.13672342073292504, 0.6079861305413709, 26.91593170166016, 39.65781788672171, 47.1935539091787, 40.90829695424726, 56.09525534414477, 33.63857607687674, 33.77901261852634, 57.46459791737219, 67.85190489984328, 75.77925036030432, 84.49199553458922, 16.055019113325304, 0.25773839243958074, 0.07733325113452251, 0.0650904459818717, 0.1049819159051103, 0.12928554968487832, 0.04349384516958268, 0.03407000226058787, 0.03801615946295281, 0.028984570808167902, 0.03286894493465943, 0.03463554751848982, 0.08732806320392317, 0.0658236610733213, 0.07125985928841176, 0.03078696310460087, 0.06618117898582451, 0.0012579765813913377, 0.07301514292316091, 0.08207554989043744, 0.037900369103637435, 0.050814481782576734, 0.014810864982615798, 0.054610811339150515, 0.03422071473793157, 0.02514956530273682, 0.031970254851565245, 0.009937175444417424, 0.031183382961899046, 0.022939822989546006, 0.0759254879648647, 0.04390464066677997, 0.009385517445362864, 0.08100462792020652, 0.04066079456899916, 0.017884297694470135, 0.08542669426289298, 0.08342306790572983, 0.06931264764599263, 0.04631870629025563, 0.051401492824117025, 0.05046006652616686, 0.05442593517082353, 0.07480513034087997, 0.10583599668837364, 2.5645350977297756, 96.46002554124402, 105.99620173054358, 98.67317584253128, 80.35935494207567, 68.41457674580236, 42.49643718042682, 121.49453747657039, 167.19372718564927, 95.93818556877875, 60.751469596739746, 18.681831398317893, 0.10945236836109432, 0.08491618093103172, 0.40984398535182404, 0.5629317029829949, 1.2577201305858552, 0.8642633175176959, 2.092330023165672, 1.8159782069344677, 1.0849753935490887, 0.41910791889794413, 3.2544601540411673, 47.319716945771255, 99.12486814683484, 84.58604612658101, 92.09866369924238, 80.3394293016003, 81.053418344067, 88.11963881215742, 90.26308075074228, 88.66855098355202, 82.15747141068982, 69.17033903060421, 59.80379358414681, 72.10732352349066, 81.38019100312265, 79.47802974331763, 81.1492104684153, 83.49771391960883, 79.8549146036948, 81.09628985005041, 77.35216002310477, 80.42732961716192, 80.7408054413334, 76.65074609941053, 79.37526364480296, 78.89281211360809, 81.62361329601657, 77.84106777560326, 78.17247667620259, 79.27039515587592, 79.80028383193478, 81.26081758929838, 69.99172256838891, 58.90155430762999, 62.285049653822384, 57.23458228572723, 64.25515420975225, 73.03093187270626, 72.27407916899651, 70.27412537605532, 70.44439546523556, 68.45124306217318, 73.37823421724381, 69.47743708087553, 87.16063499450685, 63.27754659037437, 44.97693231028896, 83.15802881794592, 66.11130606743598, 70.38642283408873, 65.11976618920603, 62.26703420762093, 58.00589676826232, 61.817899288669715, 60.22064739657987, 60.91848411867696, 57.31618327479209, 60.76216197782948, 58.406005982429754, 61.34556747251942, 58.55418528279951, 64.34109334022769, 69.11075822768673, 77.05827251557382, 75.26662795774399, 77.84247982886531, 76.21418629923176, 78.35642014780353, 76.14065754798152, 77.79059471622591, 79.18542092846286, 76.76803281230312, 72.03545785719349, 77.77989449039583, 75.49631411029448, 77.74143957322644, 83.71643312515752, 77.55169099377048, 59.808814217967374, 70.98427049575314, 77.47391039325346, 83.11147028400053, 83.42751918300506, 82.87003271041378, 79.9269606990199, 75.17092212553948, 10.624809438182462, 1.1868645971821201, 0.9750160358605847, 1.4018075408474093, 2.0270616609242658, 0.6662724287279191, 0.39837304442640276, 0.23012302185018219, 0.32772193392438276, 0.31203956253105597, 0.06028587959947125, 0.19941383582209388, 29.452777562602876, 37.8058276637908, 46.031226188905784, 34.095767544161895, 62.20544122880506, 46.59759290756718, 39.63662139831051, 67.88773967373756, 76.34827644594255, 84.5789623260498, 99.14713936467325, 25.471609100218743, 0.3303513928286491, 0.15179534262466818, 0.1512167164154591, 0.10143617753900828, 0.05901422344088074, 0.07086586026895432, 0.009141618990519596, 0.025547398592255292, 0.01501815879882704, 0.056689054660138585, 0.03380728389827475, 0.02265721506949875, 0.02076367746227451, 0.07611126428650272, 0.010493140772826249, 0.1251173802020569, 0.06804577570648924, 0.03136957105579636, 0.030541713462181153, 0.010731359643320884, 0.03849569986003541, 0.022419488410495465, 0.03828661148286155, 0.06700087774304614, 0.10733217406537264, 0.1816716838267542, 0.11096713103113637, 0.17827745466943712, 0.18943659780967623, 0.19955741602086252, 0.12319207101339295, 0.17762614203797233, 0.19558325830486514, 0.2259395229479959, 0.10456933159260981, 0.1341347177062304, 0.20783662014911253, 0.19467504574887215, 0.0784250566615693, 0.21066215159671925, 0.12463459159217535, 0.3484063385234725, 0.2860057191743005, 0.23315507528041643, 3.9557669480000777, 114.02703500563099, 119.36044646847634, 112.0995823029549, 94.63402886544505, 72.61134024589293, 50.618312589583866, 114.68302788272982, 142.77220326085245, 92.88030578244118, 75.83468129557949, 25.410951606688965, 0.3643564116810599, 0.2635145421710707, 0.5005803890526295, 0.9446239795896315, 2.4794939448756557, 0.36087282602825477, 6.010832248195526, 6.722030033988338, 5.4134067316209125, 3.5422983861738637, 7.140590567742625, 53.962925480258086, 101.49229311173963, 89.42719228806035, 97.4833405402399, 83.46807649058681, 83.60614392065233, 94.14620368711411, 91.47029215289702, 91.62528853262626, 84.90902193130987, 74.10279796969506, 63.47217459832469, 74.89754861400974, 84.84637383491763, 81.65044230799522, 84.40771948906684, 85.27849351206135, 82.31917504341372, 84.23325246380222, 80.16245980416575, 83.65143945140224, 84.38711920092183, 78.06256401923396, 81.11587816669096, 82.54986532272832, 87.18286698864353, 83.14382983792214, 81.16246023485738, 83.1788016903785, 83.81071905935966, 84.99976204287621, 72.53040605975737, 63.29756636773387, 64.45487345418623, 60.04336018716136, 67.80376172834828, 77.13929299385318, 75.36129828422301, 73.18868175629648, 73.03161436511625, 72.04118451764508, 74.83209210057413, 73.87632816068589, 90.18261724902739, 69.30527640927222, 49.584336588459635, 85.55612671759822, 72.37387995566093, 74.04798676890712, 69.42784263241676, 65.42179653721472, 61.54540438805858, 67.20086205390193, 63.5506376912517, 65.81413945844098, 57.53471420657251, 62.98548690734371, 61.1028943523284, 63.55372851894748, 60.37765987457768, 67.01556928696172, 72.18790469631072, 79.48128531056066, 79.12074104432138, 81.96377692684051, 76.92818318643879, 82.90613420547979, 76.96309228097239, 81.33025138608872, 80.79713852174821, 79.4166446501209, 72.8504087078956, 81.28993726545765, 76.42928123474121, 80.81063147514098, 88.77735753213206, 79.95011052777691, 62.80559916650096, 74.87486946967341, 81.97828185173773, 87.0320204765566, 85.70449429173624, 86.63197009794175, 83.26672554016113, 77.14006177840695, 8.830132888209436, 3.9242931142930066, 9.907241232933538, 6.176440110129695, 2.7698594091400026, 0.3876203568952699, 0.8386461953482321, 0.785324392059157, 0.963415748650028, 0.37043329688810533, 0.3507839383617524, 0.9994905225692258, 44.039697647094734, 59.33148530221755, 64.72157501405286, 57.74662417750205, 72.11827478101178, 45.82014776045277, 49.85241490025675, 78.41721688547443, 90.10823342107958, 93.28783219860446, 110.85641061106037, 27.643103830276, 0.5948630443984463, 0.24342653702103326, 0.19093573994694218, 0.16507317852829734, 0.2477498469694007, 0.17902442103912755, 0.1278565735405972, 0.19286870235396972, 0.1748278986422285, 0.1437828137028602, 0.09050806353409445, 0.14705005612584854, 0.21283385764446952, 0.1668811153860823, 0.10259363680116593, 0.17282739792379642, 0.14754211439961387, 0.1319325520026107, 0.12867487035691738, 0.08700986092369403, 0.18953609730928175, 0.09070134751739041, 0.17002471121809176, 0.13712125019200389], [0.050271310122503396, 0.07045083979685461, 0.028369080448042483, 0.022396065272210587, 0.03912580334731648, 0.04164778011580629, 0.03487983763578438, 0.07744263316835127, 0.0632638855266475, 0.04003221559668741, 0.07271486710035995, 0.019292828867272026, 0.1174412404878005, 0.035028864719694665, 0.11718902902136888, 0.029058396786211, 0.1201985288231123, 0.09483240004028044, 0.28175151035670315, 0.8990485509557109, 16.09634618605337, 101.3034466774233, 87.2434989867672, 86.9979586139802, 74.07612585252332, 37.915450065366684, 71.14736264751804, 92.99514493634625, 45.074838592160134, 49.202442861372425, 35.74903480468258, 1.97595709994916, 0.031443852856154406, 0.23213374218152416, 0.5960155470717339, 0.05604123155916891, 0.26861720868656713, 1.1285990140130444, 1.1319114556235652, 1.8411163096466374, 0.5907003064790081, 2.043308976196474, 34.52662814048029, 94.64712173708024, 84.00810841591128, 87.79276417147729, 76.58599561260593, 71.81193767055389, 69.4086543975338, 83.91364205268123, 83.13354538333031, 84.27901083423247, 75.55392588338545, 63.200754427140765, 57.85606222767984, 72.40960490319037, 77.63686133969215, 82.90452603370913, 79.08508669945502, 78.6950069858182, 77.63466481239566, 76.85572131987541, 74.96926523024037, 76.24864039882537, 73.66229226512294, 71.2069748293969, 71.78018216163882, 76.83159089857533, 73.05391696191603, 71.00125435859927, 69.41700120126048, 70.81855820071313, 72.96313762664795, 67.42062460991644, 58.16759255624587, 57.68698453903199, 59.5258544337365, 55.79641388308618, 56.65616604589648, 65.25284828678255, 68.52162607254522, 67.70737340373378, 73.35993243801978, 73.46687193839782, 78.07077746237479, 70.39374197683027, 81.6487164651194, 51.97024376161637, 46.02064363418087, 79.1695902424474, 59.92967028771678, 61.72498226165772, 51.97905340502339, 55.97974154257006, 53.74012700973019, 58.4335567105201, 56.26656878379084, 57.63959446261006, 54.773287157858576, 56.56734789571455, 56.53848317361648, 55.45162185545891, 53.73336484355312, 60.16137253853583, 66.66896512431484, 73.2275681341848, 75.06643018414898, 71.78918792355445, 69.32298198823007, 70.89444037406676, 73.82169738892587, 76.36688417004001, 73.29972405587473, 69.8317918469829, 76.0310116121846, 76.52804651568013, 75.16801172687163, 78.13999160643547, 75.57134905169087, 75.75532390225318, 58.74369459767496, 61.551456605234456, 75.00717101558563, 72.94008193477508, 81.39024011550411, 78.01450713988274, 83.71144387029833, 75.63517385913481, 71.76250011690202, 6.840441976824115, 2.9137231217276667, 0.8541434798990527, 1.1875619210543171, 0.14133192989374363, 0.20576819807531374, 0.728927634416088, 0.4275883896456611, 0.1039351410262527, 0.1283756440745727, 0.04641442897639448, 8.23179591086603, 31.044320444906916, 35.59302253107871, 50.08912994015602, 36.42390212705059, 52.24981461801837, 33.89677393820978, 43.20801396523753, 58.11278920019827, 69.72247539028045, 79.15018235483478, 58.75085684560961, 0.5596739906937845, 0.044921515133952906, 0.0791350592889132, 0.04392885670606648, 0.01473992811365714, 0.01273417586250411, 0.013230010949736162, 0.020284705885475682, 0.002983511465924582, 0.04717371020946772, 0.05567461252212525, 0.027607135144212556, 0.026366944131892056, 0.0500281767979745, 0.02877850273263551, 0.028518117108051817, 0.029031890144030896, 0.09644725209762973, 0.02268046200756104, 0.04059434027200745, 0.019529119111417283, 0.07909135397283301, 0.020458471863680792, 0.05705085117369891, 0.057230460487546465, 0.053452570667310115, 0.027907456932288986, 0.14187068888737311, 0.09441080653379041, 0.012828751331976345, 0.06638676634118443, 0.11076525920220923, 0.046357512474060066, 0.07145818413024949, 0.09541518610691833, 0.08327011079076799, 0.03506709250711626, 0.0876179508744709, 0.13375041735989432, 0.06413393158225283, 0.14743895299973028, 0.20244066453268453, 0.2463786108719726, 0.9434988722205163, 22.463694426321215, 120.09956221426688, 97.57570451305759, 99.5628321555353, 83.32774193056169, 48.28655765902612, 57.44892412616361, 91.07267364378899, 47.38198849462694, 50.80266398768271, 41.784048464990434, 2.1016429556954295, 0.14504937154631461, 0.22608579977625803, 0.7001297764720456, 0.4510503226230222, 0.6320354690955532, 2.0096739165244566, 0.6542066052075356, 1.9889048438879753, 0.6749127973471919, 2.9979802908435946, 40.316379916283395, 98.88332074688327, 88.36049587495866, 93.28919718342443, 81.67446290293049, 75.20722758385443, 75.43916517688383, 87.94215940660047, 87.04338750531598, 87.75526631262996, 81.62660998682823, 66.30458478004702, 61.08873851837651, 75.37992169780117, 83.42202002002348, 85.03984866603729, 82.71644053920623, 81.33677821005546, 78.87192157007034, 78.64052526412472, 77.86554336547852, 78.39881312462592, 75.6079839891003, 74.75488416610226, 74.98374662091656, 78.50179103112991, 75.31049574575117, 74.79109548753308, 72.30974920334356, 72.82285797980525, 77.63186424009263, 70.2358038194718, 60.49622528014645, 60.21114349365235, 61.61341436447636, 56.98539803105017, 59.64986801147462, 67.70724788788827, 70.10195685971168, 69.18544015576764, 74.66251234854423, 76.32339292956938, 81.20377848225256, 74.64494797491258, 85.2618077493483, 54.99354785488498, 50.00523044217018, 82.59244657331898, 63.52198477714293, 63.86920082953669, 53.87078508254021, 59.90781484111663, 55.765564441680915, 61.612323945568455, 58.74788761138917, 61.34271983177432, 57.613220445571415, 59.299992592104026, 58.58739206867834, 58.26032130948959, 57.06726574128675, 63.60156574556905, 70.05820674280967, 77.37691802363243, 76.46928941049885, 72.65747516385971, 73.8863145151446, 74.29464109482305, 77.1369944849322, 77.58883583930232, 75.59609920747819, 70.02568244934082, 79.22558599902739, 76.84866889830559, 79.57211171427082, 79.85143153898179, 78.82365288272982, 79.408384138538, 61.95807695388795, 63.52436173346735, 77.84472342460387, 74.64279067131781, 84.08672840364518, 79.56850313371228, 87.63887390013664, 78.0350289806243, 78.46937656402588, 10.437561369711354, 1.155219404928146, 1.3153651212492299, 3.1077291888575402, 1.6193989423974868, 0.5329230583963857, 1.602073833346367, 0.5862099893631474, 0.31510572219567917, 0.10417904809958513, 0.09284705254099063, 7.634244388149631, 36.376916054756414, 35.856833304128344, 43.28149957041587, 36.904914148392216, 49.629604662618334, 44.722888238968395, 54.087711764920144, 63.227175512621486, 78.08072459313178, 87.91925276479414, 77.5317104401127, 0.7332650403822623, 0.04549196335457025, 0.019136338171759443, 0.07316761740273045, 0.05923763383179904, 0.031935022467927586, 0.062460378037705544, 0.059085404500365264, 0.011106253387556683, 0.04329492660960363, 0.04037523529522362, 0.05065536532070368, 0.03697734806806811, 0.03299537242480344, 0.04923317288499206, 0.03256663514841949, 0.05826698127953757, 0.09577480310033407, 0.03281256469387201, 0.018645296879713575, 0.062063000570502014, 0.040476531271011605, 0.023633992494714838, 0.024516106350347403, 0.14706779872217488, 0.1558540917692646, 0.1180493534212151, 0.15798285092797973, 0.2347774962864576, 0.1189338708777101, 0.08534655380513399, 0.24208740000763249, 0.26221390873674427, 0.14688217561812172, 0.23725959051760936, 0.23321528979126485, 0.2523633510234856, 0.14962601144948315, 0.28419980478863566, 0.21900273468946257, 0.30913504741845593, 0.4718489356098637, 0.44011297725862075, 1.4178899939983123, 26.61672938254572, 132.03634662012902, 113.61033024326449, 111.14727004881829, 96.49327939556491, 52.908823797779704, 87.1129232837308, 105.6151670025241, 60.385783103204545, 72.19210163239511, 56.00071445588143, 3.488384427562837, 0.18569401315143033, 0.8919556186564508, 2.143259548371838, 1.6646371084836222, 0.599630072472557, 3.657455497211026, 5.976815492876115, 6.930457430501138, 4.164628501861326, 3.6718170104488252, 47.808083411185976, 102.4786436942316, 93.76673006242322, 96.71603079765075, 83.70044554433515, 78.82930109577795, 77.779557166561, 90.10900220563336, 89.75744801182901, 91.04764892208962, 83.32815770179995, 70.52882840556484, 65.62992926566832, 79.90552886839836, 86.80697056554979, 90.11046132733746, 85.86517810821535, 83.48042411188926, 81.50131379404377, 80.92245824875371, 80.99654397656842, 80.79178056409283, 77.89628690288913, 77.10654120291434, 79.49374275822794, 84.3427493495326, 79.32789710260208, 77.99201626931468, 77.13939497547766, 78.36020131264964, 81.40036767528903, 73.93619137425577, 65.10433558494815, 62.42477232410062, 64.46051774486419, 59.72175328962265, 61.44623118062174, 71.23131705868629, 74.72365425479028, 72.93750885994204, 77.28471094562163, 80.26155456419914, 81.76151598653486, 78.94594453996228, 87.57466470041584, 58.63968510781565, 54.314679714941214, 85.90134236120409, 68.84055399125623, 66.327256079643, 58.015177096090014, 61.52443539711737, 59.63255466953401, 64.03140260327247, 62.0265301581352, 64.20903890363633, 60.41457722263952, 61.415020881160615, 62.957100714406664, 62.75127041724421, 60.52228158520114, 67.4180672245641, 72.49311216415899, 79.75347426629837, 80.78047629325621, 75.20986341661023, 76.56668186187744, 76.9321761592742, 80.06133325638311, 82.07023789805751, 77.90519852792063, 71.34722309727823, 80.58105514895531, 82.14832444344798, 83.98041648249473, 85.09501288014074, 83.24709015507852, 82.88208223158314, 64.62141729170277, 67.53598151668426, 82.62376277677475, 77.46566557115125, 89.50749889496835, 83.75943799172678, 93.12277101701306, 80.73529843361148, 79.65473251958048, 9.254658856699544, 6.9219346104129675, 6.537390341681819, 5.455001506113238, 2.4345806000694155, 0.483074942904134, 4.0578027502183, 1.4986824845114064, 0.4695802121873825, 0.2936810315135987, 0.23478318065885576, 12.128078399165986, 48.577711274546964, 51.9959274415047, 67.41856928794616, 47.85268468241538, 65.73794741784373, 48.361541609610285, 62.04706768835745, 76.91010105994441, 89.67549400944864, 97.09260971315446, 85.43440772641091, 1.4150696872703492, 0.19153459087735225, 0.2204797981727508, 0.11959837554323098, 0.21107609954572495, 0.09277737684427731, 0.13338595869079714, 0.12663227310704608, 0.08072102983151713, 0.1581218345992027, 0.2010008635660333, 0.225622684304272, 0.07171437159300813, 0.1609969932225443, 0.09650370511676996, 0.1117679840254207, 0.12226442280676096, 0.24654832999071769, 0.10067828675551761, 0.21855609010784857, 0.09756768633040691, 0.1434707554477838, 0.18033478379009232, 0.14446438680733406], [0.11405873247572493, 0.060091523093081294, 0.04012273271538077, 0.00421535044405309, 0.04901290728500293, 0.04509510299671562, 0.03486727379382618, 0.01978690195227823, 0.07906594283638463, 0.040659902076567375, 0.06429680187495486, 0.029267272573985884, 0.03838710689676866, 0.04156165268091906, 0.08086795783451489, 0.10590821579699555, 0.06231262649018919, 0.2564994903701929, 0.06589359723992887, 0.21522932265314365, 51.72213031399635, 107.23377227783205, 77.76402458067864, 78.89159617885467, 48.33870949283723, 39.93954996908865, 55.63698522506222, 80.1951959056239, 74.10053083973547, 56.267306189383234, 13.525281567727367, 0.11998619223313949, 0.024092082429917592, 0.11220862247770834, 0.2449108936613606, 0.22826032502756965, 0.6024190002391415, 3.3348285382793796, 1.1661783846155291, 0.43595961625537566, 1.007924844180384, 21.632326495262888, 83.64212774461316, 83.97317578715663, 88.6688804626465, 79.03386838974492, 83.57396479575866, 71.59069245861423, 67.21506887866606, 81.46476514877813, 85.37078688221594, 85.03342382369503, 78.39857778241559, 60.4372916683074, 55.10136988855178, 72.13311702974381, 79.38128840538764, 75.4946824043028, 79.22484074869465, 78.53728063644903, 79.99578260606336, 76.14889452534338, 73.3284044265747, 74.30261135101318, 74.8892802576865, 72.86463906688076, 66.60648176746984, 63.3225832446929, 64.88500841202276, 61.56512214291481, 58.55686818399737, 60.092170161585656, 58.811398629219305, 53.03920338230749, 57.6539699492916, 58.70439637091852, 57.43340330739176, 57.763298173104566, 55.539577084202925, 56.3419920398343, 65.34357663123839, 71.40548598381781, 78.03619784693565, 73.75379331650274, 76.86166763305664, 70.03867333935153, 76.52879961075323, 51.65585402519473, 48.4523170225082, 78.28214614622055, 62.360214033434474, 64.97486991267051, 59.64994645887806, 56.545210038461995, 50.34041266287527, 53.460136459719756, 51.98879265016126, 54.62087954244306, 54.48479290931456, 56.68723906240156, 55.54422117048695, 54.9670365548903, 52.271124855164565, 58.07103556971396, 63.92247838358726, 70.34100178749331, 66.61052180874732, 74.89845075914937, 69.66751513942596, 73.84313706428775, 68.45222365471625, 72.79647611802625, 66.41775300425869, 74.2879887550108, 74.20341460935532, 73.92735035188737, 72.95082922904723, 73.3244977458831, 73.44140791123914, 71.58234565488755, 55.60844213731828, 59.061598777771, 64.90519685129966, 75.0369574946742, 74.97667850986605, 78.59079745508011, 75.54004069297545, 80.3957780714958, 80.5256320584205, 80.79937427274643, 4.822544320937126, 0.5651466776767086, 2.677899930746325, 1.1782470273394738, 0.1170817384075734, 0.20362047057959343, 0.43509669481746616, 0.8488908133679821, 0.12055448391624998, 0.050578817815309575, 0.06892153677800972, 23.12649065448392, 32.9625516553079, 43.1191683584644, 70.01773572737171, 114.65084875783613, 45.02075302985407, 25.76192725089289, 50.89774616302983, 66.50436678240376, 74.74974586117652, 80.58872730501237, 9.234501796384013, 0.5311568273651985, 0.18839664877422396, 0.09974134590236411, 0.07468120029736912, 0.026492572975375002, 0.022011016074928547, 0.012137478596771197, 0.04069383594117338, 0.05024075087520385, 0.00495808513557178, 0.07602023005846047, 0.045731702909594586, 0.04627224688808765, 0.054120465271895936, 0.07377191521828214, 0.05629879798019125, 0.03101159349053858, 0.05614252370451728, 0.03781332619368069, 0.03423597903982286, 0.025509467663904353, 0.04077079330360697, 0.04547043628389797, 0.05855580025743093, 0.03785441148905985, 0.04434856180582316, 0.02632059964291271, 0.019477549902794343, 0.08382351738550971, 0.042623542474522706, 0.027507733320817355, 0.09915806953945469, 0.01609284130315627, 0.04614578492398705, 0.03168877308076668, 0.0223171946051861, 0.017205156919155872, 0.040373726102012786, 0.14334168495430102, 0.02183973605203773, 0.06864235901664342, 0.14514698646962643, 0.17281780650298442, 66.67378179488644, 118.65981701881655, 88.10450630803263, 88.58306684801656, 64.26205365888535, 41.66407492852981, 50.28758225902435, 86.91572220094743, 58.374321076177786, 63.92327854710241, 16.171742966098172, 0.11326303525317101, 0.32286404782245237, 0.3400692794351809, 0.8506838268330021, 0.7030963140629953, 1.3125031393381859, 2.2875211363838566, 2.320475909979113, 0.06884249182598245, 1.3967034340866151, 24.419056753958426, 89.70248776097452, 89.25117984894784, 92.51714921766713, 83.82293332007625, 88.12877008991858, 75.5354436751335, 69.42366138581308, 84.03208194240447, 87.10030109651628, 86.74699752561509, 82.11210527727681, 65.69846876205938, 60.141662628419944, 75.8318728785361, 83.01094778122442, 80.54715018118583, 82.03144565705331, 80.09774854106288, 81.87451947119929, 79.65697611531904, 77.14851056375812, 78.6317862233808, 77.4761853679534, 75.61024327431956, 68.98512471106746, 66.6534403831728, 68.98665443543466, 61.551939056765654, 61.148735092532256, 61.44871011857064, 59.10017136604556, 56.19584060484364, 59.55893570376981, 60.048439656534505, 57.6956961231847, 59.46636384533298, 57.46548437303113, 58.501386257909964, 67.92741052566036, 74.88673856181484, 80.54042723871048, 75.83117469664543, 78.74729218021517, 71.12099647521973, 77.90620265468475, 55.0087901853746, 50.86184470884262, 82.52552309343892, 64.26232430242723, 68.59693557985368, 61.39640923469298, 58.82381293081469, 54.16102870818108, 56.20358728593396, 56.080499387556515, 57.76451803022816, 57.924978271607436, 60.42740729547317, 57.0458496001459, 59.6487932820474, 54.72870157610986, 62.46197992755521, 65.53032067514235, 73.98841381072998, 71.32256707837506, 77.40058560525218, 72.16591588912472, 76.5597314219321, 72.6508306687878, 75.67555858242896, 66.53788735789638, 75.5585385907081, 76.84358550656226, 77.37864386650824, 74.19250257553594, 76.3500258230394, 76.80163183519917, 74.47121051050003, 58.63495080701767, 61.01002439375847, 66.9108969165433, 79.94278354029503, 77.15877148412889, 81.73239631037559, 79.26524900620984, 84.55056436600225, 80.39272646750175, 88.4035634994507, 7.476143452429003, 0.4070041280600333, 0.8902682640379476, 1.5440478824800061, 0.7944263746180843, 0.9834013278445891, 1.6173557552599138, 1.597021820564424, 0.4878350148998922, 0.13953160794992603, 0.01843031345596237, 24.231524313649825, 38.66242231861238, 37.368263736847915, 63.83503306296564, 102.7492872361214, 48.27162911815029, 40.80190266332319, 62.38033579241846, 74.2586023576798, 82.534834800228, 95.0535342001146, 16.226056025874232, 0.7768828998650275, 0.20409189044467865, 0.09948020185073538, 0.09005588779766714, 0.0486825356980966, 0.04139420501286945, 0.03385644759081545, 0.059708582552810835, 0.09469582954601896, 0.023073005459962354, 0.08597843844683901, 0.0019475556637776356, 0.024007040924663027, 0.040380889024104805, 0.05108587609063234, 0.013173050397346097, 0.02166785081968673, 0.06360328545974148, 0.026665400495872866, 0.03012077687608619, 0.019654309369563576, 0.022419224110161586, 0.024659000900423816, 0.26513114090888734, 0.13748796115959847, 0.10886111702289313, 0.16469689146164926, 0.126567967686682, 0.13588244005316688, 0.12841224009471555, 0.10506839957088233, 0.2326334919780493, 0.16973391956379338, 0.16055442422868746, 0.19943865707084057, 0.17731653526425364, 0.12782275075874022, 0.23114345096532377, 0.2443965422289987, 0.1578048887031694, 0.33837916690015024, 0.30911436304450035, 0.2660925812538593, 78.10028153081095, 137.61860109144644, 100.15653779429775, 101.83106822352256, 69.67712494634813, 58.32013745461741, 66.55247073019704, 93.43620761748284, 108.44779291460591, 80.13247720656857, 22.452872607015795, 0.23600813992802175, 0.5960943009103499, 0.31501654956129294, 1.8771505115493652, 0.9699702743561038, 2.8644368244755656, 9.647321451094843, 4.723418181942356, 3.3798632314128265, 2.325474480467458, 31.137986644621822, 91.2431163172568, 92.56276638277116, 94.78078042307209, 86.96122953968664, 92.73035357075354, 80.62239693057153, 74.30716130041307, 87.53387205062374, 91.65771868921097, 91.78841990809288, 85.4066530350716, 68.74455790365897, 61.10548311664213, 79.69069280932027, 87.17230012339931, 83.0947139186244, 84.07622429632372, 82.22210422638925, 85.3672645938012, 83.4537676841982, 80.92713371399911, 80.33385169121527, 81.70038976976949, 79.6070678772465, 72.08798623854115, 70.60256896480438, 72.31625249308925, 67.38541741524973, 64.05498781511861, 65.01358370627126, 63.779331484148585, 59.18207045524352, 62.02048186332949, 64.5703794110206, 62.61588196600638, 62.713474458263775, 62.845509283004276, 63.488766224153586, 71.03216263555711, 78.94068856393137, 83.57362747192383, 78.87755409363778, 82.81333877194314, 76.15449566994944, 78.9860939210461, 58.579257072940955, 55.857951948719645, 84.92626467058736, 70.18507188366306, 71.0381167934787, 66.66220295813777, 61.13960381477111, 58.00207637971448, 60.662157227916104, 60.31851445474933, 62.692850635897734, 62.36639176645587, 64.0730111060604, 59.736921095079, 60.194806821884654, 57.40549172124555, 65.61046646487328, 68.72686016944148, 77.0200215616534, 75.2457844826483, 80.63425817797261, 76.50630874018516, 80.43107940304665, 75.97897744947865, 76.65299753988944, 68.05205560499623, 78.92310850081905, 80.43404471489691, 81.95896810100925, 76.74484375984439, 78.76640196769469, 79.85700130462646, 78.1468165305353, 61.62765256820187, 64.38693408043154, 71.66584507111581, 82.43406126576086, 80.39362861264138, 85.57518159189533, 82.67372592802971, 88.54538071540095, 86.2327120381017, 89.68256212049916, 6.371200988369604, 3.290389555115854, 8.619910517046529, 6.970688200766041, 1.6703501632136684, 0.7313957245599839, 2.349070723979704, 3.991144765769282, 1.1330452657515004, 0.2066272584300849, 0.1720244152050826, 34.45398192251883, 53.47710071071502, 58.791092518837225, 80.41757076017319, 129.04496669769287, 54.76931379687402, 41.377710526989354, 67.82286367108746, 89.03759110358455, 89.98926793375324, 105.10245830781999, 16.42207451405064, 0.8575150634973281, 0.2436912816859061, 0.18452683223351357, 0.232130202855314, 0.14799235959447202, 0.15613233490336328, 0.15605621640720677, 0.13506094865020246, 0.25395088438545504, 0.09588089861696768, 0.20839287659093259, 0.13007547826536242, 0.14714106737125307, 0.1868871491282217, 0.19370608242048373, 0.12769888200226331, 0.10275025581640583, 0.1719581945649078, 0.12410269674634743, 0.12626392271129355, 0.08924140609920987, 0.15131068476025136, 0.11953250730350135], [0.02257986700222377, 0.06395931333123196, 0.0390024938350243, 0.04072696158301927, 0.006024547995278432, 0.04014104604721069, 0.03208970902637849, 0.0065804582611177, 0.037862884421502395, 0.04547644241322433, 0.005391219756641095, 0.010464339697312926, 0.01927151247077892, 0.04083236762052102, 0.013923863486026325, 0.029089702969236724, 0.07013518092853409, 0.06264751416540916, 0.21969720871458132, 2.8085109351142763, 79.03475484540387, 82.52910029503607, 84.8867428687311, 64.99927489988266, 47.1002132661881, 29.61435764066635, 22.843417121518044, 40.286283569951216, 52.2090768814087, 28.491318341224428, 0.7419419360737647, 0.05906751251689369, 0.03349013115850187, 0.4233948243481498, 0.19339592406345954, 0.27340584044014254, 1.0623650132648408, 2.104021137760532, 0.4748469440927429, 1.74855817950541, 11.167957686608839, 83.51900454490416, 83.27937910633703, 89.42909855996409, 85.35238312136742, 84.88934732252552, 79.29573366718908, 74.56822641434209, 62.271360581921, 79.82645388572448, 82.02177309220838, 78.9710633985458, 78.85389435675837, 58.11053383734919, 55.94480499144524, 68.03241237517327, 80.15532109045213, 76.7021369934082, 74.37805421890752, 75.01382335539788, 75.34154522803523, 74.84622832267516, 74.25771590202086, 72.11401508700463, 67.99150205427601, 65.49492520670738, 60.56486283579181, 58.31579539083666, 57.215739219419426, 55.48307534187071, 55.55620401136337, 52.808199313379106, 53.88023799465549, 53.764912466849054, 55.24611711502076, 55.59612197260703, 58.70047400074621, 54.20193510670816, 57.922860191714385, 51.97557426268055, 56.434159894143384, 59.742898787221606, 64.53986729345014, 64.88868367287421, 72.61908300461309, 68.69140194308373, 76.16971446621802, 58.63417417772355, 41.08975364315895, 77.19046423512121, 66.73240553948187, 71.29191767784857, 68.28298122652116, 68.54996911941036, 54.22835226981871, 54.07141823922434, 51.129166003196474, 53.757157941018384, 54.78685855865479, 55.68250433091195, 53.58443637048045, 55.517223496590894, 53.625515353295114, 54.84733758434173, 60.69500315573908, 72.78588571856099, 69.3878972145819, 64.14812841723042, 71.0132646560669, 69.8697054770685, 72.61444676306941, 70.12513806743007, 71.92796138025099, 74.715362364246, 72.59900831407117, 69.39540463109171, 68.85818112281062, 68.8840687659479, 67.40486452656408, 62.8622813378611, 58.28183943225492, 58.38921823809224, 59.05966112690588, 59.95424393684634, 64.63362370767902, 69.83331372660976, 70.99649260121008, 74.83707351069297, 74.21868047406598, 82.06056533321258, 72.00340424814533, 1.791100696690621, 2.5408582004808613, 1.5495525612946481, 0.7480760940140294, 0.7647737464116466, 0.5547777695521232, 0.5611528468228156, 0.6323678899676569, 0.19724713998936838, 0.03033827498344885, 2.824046462774277, 29.368662334257557, 39.50485329474173, 98.51126040181806, 115.17376345972862, 109.35478610377159, 32.131781885700846, 47.64978047340147, 60.535982424213046, 65.3863932240394, 77.26575805294898, 43.14963340759278, 0.2402372517052197, 0.12587370816618204, 0.04159305079449569, 0.03614774379398554, 0.04533257493148408, 0.022357132683898655, 0.10069668052657958, 0.049260472428173795, 0.03572696617113487, 0.06061381502677837, 0.08279691360169843, 0.02894344912361234, 0.020213701026213747, 0.07792245701796587, 0.020863981354200554, 0.016344227309849475, 0.025481528437305844, 0.11771612815679082, 0.03431717286847773, 0.05582549736925191, 0.03222671044509738, 0.025638201078700445, 0.03323000217337282, 0.029102873935874914, 0.03298523325112558, 0.03753619388707223, 0.013811022565219433, 0.06472560426881237, 0.01565993650846424, 0.020928874747046543, 0.06662721069709909, 0.05252830856930345, 0.06056961941442663, 0.06183236214001814, 0.023986695544613947, 0.026410561347860965, 0.08055145626947766, 0.02545119518594396, 0.051228368444548505, 0.03487945076138262, 0.1536110782575223, 0.297988529407209, 4.213201172890202, 99.42080313159575, 93.70468601103752, 93.82500079370315, 73.60850872532015, 58.0728869284353, 40.02354360395863, 35.45918733842912, 39.91941252062398, 58.264628071938795, 32.44126277585184, 0.7149633837323035, 0.06159668285099249, 0.18209471757854187, 0.9882858431627675, 0.6857492642537241, 0.9695104377404337, 2.5630423907310735, 4.496623306505142, 0.5656272293098512, 1.5992558555256937, 14.59228196451741, 91.09830241049491, 89.6617421796245, 91.99777249367007, 90.8375197072183, 88.32143691278274, 85.02695191291072, 77.696928516511, 65.6911103956161, 80.63256371405818, 87.87421611047561, 83.41597172521776, 82.91578323610368, 61.36306516585812, 57.87277152461391, 72.22933277007073, 84.9820956876201, 78.98849441159156, 75.14576404325425, 78.2716969520815, 78.3087319712485, 76.61958679076164, 76.85878076860982, 75.31620671672206, 73.07868280718404, 67.77425765991211, 63.96936639662712, 60.366543877509336, 60.15110377342471, 57.725019762592936, 59.21884659797915, 55.025056254479196, 56.763799805794996, 55.646167493635616, 56.981373679253366, 57.60936475569203, 60.48256758720645, 57.29028778691446, 58.62728257333079, 54.373385829310266, 58.71949749608194, 63.095748655257694, 67.11468758121615, 69.17150005217522, 75.42807271403652, 70.85477736688429, 80.56443214416504, 62.66248364602367, 45.35628041913433, 78.70689961218065, 70.66263614162322, 73.07057919040804, 70.33194111239526, 70.82076257274997, 57.37657993070541, 56.25366418592392, 53.9323623718754, 56.359721153013176, 57.60046097540087, 58.156641298724765, 57.181814639799065, 58.72047024388468, 55.854602244592485, 57.131753429289795, 63.24909763951456, 74.2262977169406, 72.36595676791283, 69.75085766084733, 72.45941115963844, 72.63987156652635, 73.71060802090552, 74.28527447485155, 74.31698291532456, 76.01639686092254, 75.39360292496221, 72.7088503683767, 71.16397780756797, 69.40966636903825, 68.99329893050655, 65.11749905924644, 60.79656900898103, 60.28730415528821, 61.457166748662154, 64.22432045782766, 68.48324960277927, 72.94998984183036, 74.22575642985683, 76.86901031001922, 79.05548849413472, 84.23002043078023, 80.03892867795884, 3.8642190733263573, 0.1513346173470059, 0.47054202025455816, 2.094839849779683, 2.143239201076569, 0.8327415573500818, 2.23733980328806, 0.9763009798142218, 0.463225482211959, 0.04313319395746916, 1.6145132626256637, 34.481583641421416, 32.86304504640641, 74.0005966924852, 111.57695001171483, 90.3976494266141, 38.69953970755301, 54.477430620501124, 66.84930001535724, 73.4796823993806, 87.2510220927577, 57.975078705818426, 0.2564629326544462, 0.05088277469058672, 0.0154326343908906, 0.04842397719321232, 0.07479705577415806, 0.021473300876095894, 0.024142918109353033, 0.0022670710665894855, 0.0680553058402673, 0.06328899022792617, 0.07447556697673376, 0.05210698702402654, 0.0339581495932033, 0.03910165242550354, 0.04719949289855938, 0.00610196405285669, 0.03202892378002646, 0.01180560835036299, 0.02667754873513214, 0.07744034256545768, 0.01590297119917288, 0.05549005044984722, 0.05707265020558431, 0.1499062004469095, 0.16029206975813837, 0.15333588415336225, 0.12352132794236946, 0.21414221324507268, 0.08300492179489906, 0.0966969124912735, 0.1414185131509458, 0.133794957711812, 0.13377212829166843, 0.18547144928766837, 0.13316132638963962, 0.10944334384534629, 0.23908998907333423, 0.1203598362964488, 0.14076269592248625, 0.2109011097420608, 0.3226878475998679, 0.575138486681446, 5.479892376930484, 116.58697774333339, 106.79266252825337, 109.57752181637673, 87.34238193881127, 63.86081480210828, 46.873159024023245, 38.76997370873728, 61.79796188108383, 73.8189281955842, 43.91853563247189, 2.0176594944730883, 0.13523147982214728, 0.4112392459665576, 1.5499374438678066, 1.9838545471429827, 0.9024149251561012, 4.803806178031429, 7.689821922009991, 3.2859945393377736, 4.803112408807201, 18.164037350685366, 98.57262196079378, 92.1941577234576, 97.21571722338277, 93.96846540512578, 92.38680101210072, 87.74907681249803, 82.29541332490983, 70.39769572596397, 85.33222998342207, 90.65993047529652, 86.99369891997307, 86.40160929772162, 64.37417068789082, 60.973397301089385, 76.02408470646029, 88.16090999111053, 81.28531671339466, 77.38768100738525, 77.78204394925025, 81.46216069498371, 81.78832146429247, 81.38506258687666, 79.57427686260593, 75.29744209781771, 70.77305086197393, 66.2085965371901, 62.88163823466148, 62.75593803774927, 60.08436856731292, 63.89784197653494, 58.516840396388886, 60.17422222322034, 58.825374034143266, 59.38596702391102, 59.91136458612258, 62.72981897477181, 59.807100142202074, 62.8803595419853, 58.668898920859064, 63.1755296645626, 66.03978556971397, 70.3870504133163, 71.7224056490006, 81.0006389310283, 75.76853444499355, 83.76182279279156, 66.75656733974334, 50.755721061460434, 81.391079502721, 75.52020134464388, 76.63772383043843, 75.8109038875949, 75.61891171240038, 61.42299113735076, 60.74316593908495, 56.509983231944425, 59.214775177740286, 59.85895387588009, 60.44269669440485, 59.79252069227157, 61.5925395104193, 59.570714581397276, 61.79312559866137, 67.14849056736116, 79.78191145004766, 75.77393162635066, 73.13454520317816, 76.71231946637555, 76.67479807330717, 78.1622314453125, 77.94592057504963, 78.28005944528888, 78.55173064816383, 79.60579702931066, 74.34088583915465, 74.29992844981533, 74.30388219894903, 73.37395098901564, 68.93206288737636, 64.24818415795603, 64.35228778469947, 64.27109079976236, 66.4846686393984, 70.88155931042087, 76.00503767690351, 78.00562689381262, 80.56090985575031, 82.23100016194006, 88.20058084303334, 82.64347660926082, 3.7482885199208416, 7.912007031902191, 6.816510615810272, 4.292980221010024, 3.6076990058345184, 0.9056379489841, 3.6861616084652566, 1.87417502605146, 1.136887227335284, 0.1405834313482046, 4.573843988680071, 45.50913126237931, 58.837447089533654, 103.08307309304516, 120.57092912735479, 113.4282930435673, 43.34336711514381, 62.758868048267985, 79.88839595548569, 83.11300785310807, 97.93742549034857, 61.035045193087676, 0.6947968239265104, 0.17318062574392365, 0.11383999905158436, 0.12890829734744566, 0.11735224405363684, 0.17678678546461368, 0.2156029896990907, 0.15172840186184453, 0.1440535798188179, 0.11002665851265193, 0.18485744513811606, 0.11689652133012012, 0.11385905165826121, 0.1880813423063486, 0.1421682987241976, 0.125436432839882, 0.14686947388033714, 0.22927977355016818, 0.17010737210512164, 0.23349117337455674, 0.1272466679614398, 0.19486289050790573, 0.19219115887197757], [0.06910417980003743, 0.007025068400487785, 0.06722822965633485, 0.046603759946001154, 0.03717889430962744, 0.06085803236572012, 0.005440592208141161, 0.07451717321190142, 0.03723804395826113, 0.02574982200448792, 0.03517922096615357, 0.026880305395611835, 0.02070113212891644, 0.06842280587842388, 0.011533087893058697, 0.12960335359938685, 0.05939123446061727, 0.06626759370368335, 0.4552649706602097, 15.921108415049893, 98.1111551100208, 74.91610142492479, 82.01220250898793, 64.92000772107032, 37.65056848526001, 25.806589318859963, 38.04713972153203, 55.419379972642474, 47.614400694447184, 12.983360040572382, 0.027688420903418335, 0.09625674901349891, 0.1388210460783974, 0.615414425490364, 0.8219022099529544, 0.5824868633381782, 1.3823742804027375, 0.9821005718361948, 2.6172201287361885, 3.668469757803025, 85.74486332554972, 85.58995323796427, 84.80505558752245, 83.6904513451361, 86.49195717227074, 80.59942753084245, 81.09571718400525, 75.09908783820369, 60.21179068473078, 72.12668434266122, 84.31059375885995, 80.63315206958403, 74.80578084145823, 55.605665099236276, 56.74617267424061, 64.70025693216633, 77.70751891597625, 73.25107882099768, 73.37425693388909, 76.8768472056235, 73.65137238656321, 68.19006812187934, 66.88300886461812, 65.66207308923045, 65.83267657987534, 63.099620034617764, 60.51422111449703, 53.9526371032961, 54.877547679408906, 53.15619591743716, 53.928035997575336, 53.29940949716876, 54.05379503004013, 53.662079688041445, 53.47038561298002, 55.517309788734686, 56.03403499049526, 52.96727103571738, 53.53557540524391, 52.50779674899194, 52.9228658829966, 51.42064517544162, 54.64312722606044, 53.72993669202251, 58.992333642898075, 62.67326231925719, 71.32470869248914, 64.83237020431027, 40.528944923031716, 69.04725505459693, 67.386060683958, 69.20516183299404, 69.73842374740109, 71.57954508258452, 59.67329240614369, 50.91573415264007, 53.02619680281609, 52.95349174930204, 53.8507103919983, 52.17081416037775, 55.66585779190064, 54.024859705278956, 55.703418408670736, 53.69636904808783, 53.154171974428245, 59.07383657270863, 69.95421686480123, 66.72703973708614, 65.0764867567247, 68.43097225312265, 66.78062715838033, 69.17268460796726, 73.35547662550404, 72.45839918813398, 71.31714636279692, 69.4308707021898, 65.23246372899702, 59.2395684795995, 61.08617328828382, 57.34791524948613, 59.07714705313406, 56.74733369581161, 60.51208342275312, 55.91023322074644, 57.824416545129594, 59.67193918843424, 59.23614817280924, 65.1061830212993, 76.91823605568179, 72.01829356531944, 85.80294578306138, 48.55665599146197, 0.18178180130499025, 0.29558463743136776, 0.9120728423999203, 1.8644660567083668, 0.6044081934998112, 0.2097362117661584, 0.06270490564225663, 0.2458401889570298, 0.055653242499477444, 0.0699818943957648, 8.23471611545932, 32.236901406318914, 74.9551917660621, 101.78601587972334, 71.74139776537496, 38.225332998460345, 35.420685352817664, 52.11721104960288, 57.76555745832382, 69.08709064606698, 63.88840083153018, 2.4846942722797394, 0.1799209584151545, 0.04940027198303611, 0.12162350598842868, 0.059138348836812286, 0.027901475700820168, 0.04931975997263386, 0.032472800869013996, 0.02912700187505013, 0.06201229321079389, 0.054741283773534724, 0.03745269030332565, 0.05320701267450087, 0.021273673684786887, 0.07835917310008118, 0.02413075071789565, 0.041922652463038126, 0.012539919905154216, 0.018542654504398667, 0.0318992653140618, 0.032173674178099444, 0.04658311004600218, 0.01249847933650017, 0.02782385950277169, 0.10775804234248017, 0.031924419811055545, 0.04188239837305681, 0.04165382071908924, 0.023847171781404365, 0.029191828235202742, 0.0831855117012897, 0.07384617978166189, 0.037342722212234815, 0.03449040450035565, 0.019162699257233934, 0.04168372879165315, 0.138487690579026, 0.02947572701340241, 0.01492904840908464, 0.09509663908712326, 0.047346960993543755, 0.5691449211970453, 22.530800296414284, 115.2079979065926, 84.34784843075661, 96.04639591709261, 74.35886598402455, 50.995452404022224, 33.19272810412992, 41.12561195127426, 70.3099601499496, 54.31370696713848, 15.991001129150392, 0.10712639518803167, 0.01933622008730327, 0.9115874490910961, 0.7995849042650193, 2.0692787439592424, 2.318416665638647, 2.7053712308406834, 1.8090886863008624, 0.8592399870676379, 5.218139377332503, 92.53150509249781, 89.61613285926082, 91.45827401068904, 88.59307673669632, 90.96063506218695, 83.12937982620733, 86.36625305298837, 78.86919944517075, 63.564020818279644, 73.76840022302443, 86.39181121703118, 82.59681609369095, 77.9325766717234, 59.65291177072833, 59.91902889743928, 70.36671684634301, 80.92580010814052, 74.80465904358896, 76.70380792310162, 79.2031971100838, 78.40549684339955, 70.95668054396107, 69.30836723696801, 68.99234971692486, 69.4485527469266, 66.15850002534928, 63.92326677999189, 57.66571744795769, 56.878968438794544, 56.206274109502, 57.2835805339198, 56.04013427611321, 56.77362926544682, 56.20562299605339, 57.074882984161384, 56.45914931451121, 58.07596598902057, 55.459086125896825, 55.93446562367102, 54.27836248951574, 56.99321923717376, 53.51475938673943, 58.211805512828214, 56.19560918500347, 62.020246521119155, 65.47812177288917, 72.24841902332922, 67.56878822080552, 42.71303830608245, 71.2565928120767, 71.31257287917599, 72.72503406770768, 71.1604319849322, 73.21495379171064, 63.227979598506806, 54.51006474033479, 56.6418101710658, 56.18925886769449, 56.84669517701673, 55.49419133893905, 57.794461404123616, 55.03059071879233, 59.03285957151844, 55.14200564353697, 56.086312340151885, 61.85537753566619, 71.7879641440607, 69.80738685977074, 69.43424394053798, 71.05932112663024, 71.06213738841396, 72.56050632845971, 73.95015501206922, 73.39509256424444, 73.5448565021638, 73.38533370725571, 69.35247036718553, 62.08682091005387, 63.50937043466876, 59.526089775946836, 61.94576855628722, 58.48443769639539, 63.44956997902163, 57.833539978150405, 59.58246992480371, 60.42342216737809, 63.77078856191328, 69.09241722476098, 80.03997202842467, 75.96514717225106, 89.96101902377221, 54.185100293928585, 0.47108493144473723, 0.4202020763149185, 0.9208805859088899, 1.2010640675021758, 2.01690137386322, 0.8828814604109334, 0.8154669488149305, 1.0221700346277607, 0.1709329697393602, 0.07100538786260352, 8.284430196208339, 35.86133226271599, 60.546106061627796, 101.63352981690439, 64.9393803073514, 28.608055922292895, 47.20671346110683, 58.80104357196439, 70.0472790195096, 74.42047072995094, 79.83942124151415, 6.8733070262016795, 0.31830708105717936, 0.09285298206152455, 0.07680342472609013, 0.04296617529865715, 0.01236084781046356, 0.06768419752798735, 0.0061263955543719, 0.056595323802602876, 0.057320931640964363, 0.028348081978037957, 0.021426648036727024, 0.037238197175845984, 0.05093564241824131, 0.060243434498026494, 0.04667442772657641, 0.03851893913721846, 0.016443272902359887, 0.047301482183918844, 0.03571909078727326, 0.02657197224306724, 0.045363934740664504, 0.025414591504921837, 0.2373515363902815, 0.25535532273352146, 0.12081236443332127, 0.14701703773631206, 0.14698112353442178, 0.11167985327061146, 0.1344051467435014, 0.184056821970209, 0.11090724593809537, 0.11003742970886732, 0.09955419828334164, 0.10903377791926747, 0.09497368197527625, 0.24409499470024343, 0.12935891026450744, 0.2668541032941111, 0.2043091529800046, 0.19741866707561478, 0.7603380360430287, 27.407926359484275, 131.9610998707433, 97.28433516717728, 106.66923338367094, 84.05963267049482, 52.61801927320419, 35.09746243876796, 55.91126872647194, 79.35500852523312, 72.06656225265996, 21.90759058921568, 0.3110916359770683, 0.4422362971930735, 1.1560997318836952, 1.8160828851884412, 2.114235970281786, 3.7982916303219336, 6.7866000917650044, 8.39969688846219, 9.802651232288731, 6.485394422085055, 98.71740448859431, 91.07746678013956, 91.38598472841325, 94.13534656647714, 93.98649261843775, 85.83169675642445, 89.02562787455898, 82.14856763039866, 66.88753527979698, 79.87780555602043, 90.75141583719562, 86.56421507558515, 81.90460405042096, 61.878425382798724, 61.83773863700129, 72.00920151126, 84.85347332492952, 78.32623358695739, 76.64716105307303, 81.70792856524068, 82.07804341470042, 73.42506731710127, 74.1167066943261, 73.67694624008672, 72.70045649620795, 69.5394968217419, 66.73048357809743, 59.95548732819096, 59.88048768812611, 60.68583657664638, 58.51094899639007, 59.70621678137011, 59.41476114334599, 58.770660892609634, 59.93420454763598, 61.67999267578126, 60.129699399394376, 58.024049497419796, 57.80223946417532, 58.367562832370886, 59.540477029738895, 57.44959877383325, 60.47398936363959, 59.68568317351803, 65.91507773245534, 69.93898237905195, 75.32004279475059, 71.62753920401298, 47.98307211168351, 72.38849470692297, 74.46535048946258, 74.68995325026974, 76.74449859126922, 77.71449289014264, 67.39874562909527, 57.5406801316046, 60.63438684709611, 59.837977040198545, 61.147723121027795, 57.4766670503924, 60.27527032359954, 57.836552358442745, 60.48557212275844, 58.916514227467204, 59.494852019894516, 65.75346039187524, 76.20239565449377, 75.11577360091671, 74.45307347082323, 76.77801132202148, 75.03610241797664, 75.7645179379371, 79.19460711940643, 75.8361090383222, 78.05675106663858, 77.99349892523982, 71.81327912115282, 65.10414731117987, 66.13869990071943, 62.31157272092758, 65.28683170195549, 61.722162077503825, 65.66612489761846, 61.13958420292024, 63.559349275404415, 67.1466705876012, 65.7880517744249, 73.07576456377583, 84.01637677223452, 78.91622081879648, 90.95832086378529, 56.616165714879195, 0.5538978716058116, 4.741932259451959, 6.074626657270617, 6.387094432307828, 3.830573472284502, 1.570067660462472, 2.0899265908425857, 1.5993811262230722, 0.3115511355140517, 0.2662703749393263, 15.074103955299625, 53.307791602227, 88.52808306294104, 104.34666464405676, 79.22785312898698, 50.1439921317562, 53.14409148308539, 68.37041870240243, 80.28759910214333, 84.79994866155809, 91.99684681430941, 6.576446362080113, 0.45939651347937127, 0.27873367551834355, 0.24485794166403435, 0.22712473757565024, 0.11971769373743765, 0.21517660048219467, 0.06110184750850163, 0.12223318940208805, 0.15612724807954606, 0.12394714259332228, 0.07291110818304362, 0.2289588593186871, 0.1928163325834659, 0.16941764782513344, 0.10887548117147339, 0.1495907254396908, 0.06828902394420679, 0.11993253543492287, 0.13178282777868933, 0.09481255070216234, 0.09332292337691592, 0.12053905490545497], [0.04694017979706969, 0.03350914546078251, 0.04877982120360098, 0.004224603828568493, 0.0198449733321585, 0.042016073054964506, 0.031280377353992195, 0.07475848324717053, 0.035781749118600166, 0.08697824447505897, 0.026994619120453155, 0.025971554662852038, 0.021216037059803645, 0.031071467092260722, 0.025980613652556658, 0.04470640530569419, 0.060510554035464605, 0.19081342634895157, 0.1229649795699985, 49.822483293471805, 100.02306738207417, 76.38191469254033, 80.71387444773029, 62.21020298619425, 36.378033930255526, 34.817432665055804, 57.38216146346062, 32.77597627332134, 35.28561069119361, 0.9832462716487147, 0.17774252611542904, 0.06407746707179374, 0.22037455301371314, 1.1974413909258381, 0.5471935603887804, 1.2531108553371122, 2.244439048151816, 4.209440600487494, 0.7916802252011915, 72.60700210448235, 89.94400378196471, 82.28623497870662, 85.68572967283188, 81.8693890110139, 85.28218054002332, 83.04921442462553, 82.17004652946227, 74.42362431556948, 60.529498746318204, 59.95210232273225, 71.14813143207182, 74.14791307141705, 62.49004448613813, 56.53829882221838, 56.75807314534342, 61.519418685666984, 77.04075521038425, 74.01588609141689, 75.9451509291126, 73.40360410751836, 71.9958262289724, 63.33006712698168, 60.95381682918918, 61.55137815783101, 58.28843293651458, 57.77432787802912, 54.87919899725146, 52.8911848991148, 53.74962306791737, 51.89990389731623, 53.12312249214419, 50.496581831286036, 53.95992878944644, 52.53024839585828, 55.80121486417709, 53.85007496803038, 53.79558932396674, 50.10138342457433, 52.72584522924116, 50.11293872710198, 51.746370561661266, 52.95884970695742, 53.78993718854843, 51.601933202435895, 55.393849265190866, 54.95186482706378, 68.86312330922773, 64.18480650071176, 44.56582869252851, 61.55337464424872, 64.09215227250131, 66.48441760770737, 63.67916591705815, 66.03390985919584, 59.808045433413604, 53.399112224578865, 52.79076830033333, 54.44375707257179, 53.932495732461255, 53.54300829672045, 54.906981145181966, 54.48742089733001, 52.81148625958351, 54.479995850593816, 51.361464454281716, 53.81046295166016, 61.08873459600634, 70.1638126373291, 63.61811030295588, 63.767544761780776, 68.21900736901068, 66.77286086543914, 68.03390287583875, 73.8321622725456, 70.78531219113258, 70.92424254263602, 69.34202901778683, 62.56018038718932, 55.24302628732497, 58.062684843617106, 56.81877574613018, 56.052760385697894, 56.694040452280355, 58.73184119501422, 60.975076075523134, 64.78245412149738, 67.98438687478343, 70.92114387019988, 72.06617001564273, 77.4963463506391, 73.46069028300624, 62.17018696569628, 27.40102887153626, 0.13333228657082205, 1.8066769189411596, 1.3149451824926561, 1.444239741371524, 1.4710530638694765, 0.2140975962843626, 0.12826640759744953, 0.4318151418720523, 0.021893479035145814, 0.1012720968273859, 16.834224424054547, 30.45485292711566, 51.709508126781834, 62.338982243691724, 38.053188016337735, 20.95895947948579, 44.17649815159459, 62.5053927206224, 65.356610667321, 70.32464550387475, 34.503819557928274, 0.2994988564281695, 0.11056582353288129, 0.017985942240263668, 0.05208442190421685, 0.023922466733042273, 0.029347210018444928, 0.017215347803768613, 0.02419956265047433, 0.045814321661788615, 0.06088207986566329, 0.049932955899426056, 0.042734812915084824, 0.019090901496970368, 0.06921009911644845, 0.055829684039758104, 0.052063913730483864, 0.04021065279601082, 0.05961852508687204, 0.01983210305503059, 0.02154021099540255, 0.07113797469965874, 0.022413729344524687, 0.008658913692699806, 0.005993791480338382, 0.054039937939735196, 0.0175790001653255, 0.056678639694808, 0.012677784130397825, 0.04716537134241193, 0.06080809109393628, 0.04317002363442894, 0.041663814336061485, 0.0296597624002325, 0.038673784658913656, 0.05304508850038533, 0.021270044343245607, 0.04174632583594611, 0.07538960946183051, 0.027333113154576674, 0.10606131846866301, 0.06333077649375604, 63.53530906861829, 111.71430357040899, 83.550822811742, 89.25868726545765, 77.72170220651935, 49.02555573371149, 30.434121239569883, 40.64857721328735, 31.408318358082926, 39.22867136616861, 0.93815642018472, 0.2561157416071623, 0.029895416791400606, 0.44912131322968396, 1.6298891988492783, 2.0586753516427936, 3.817183235960622, 2.61154372365244, 0.6841311639835758, 1.0807370274297654, 78.83222718392649, 94.63409946810816, 87.98941612243654, 89.25884416026454, 88.50867517532842, 86.54402271393808, 87.40852878939721, 86.18372163464947, 77.47922128246677, 63.00398872744653, 63.29781739942489, 74.76840065371606, 78.40373962156235, 65.71382876365416, 59.71975288083477, 59.439785865045366, 65.64959995208248, 80.13884713572841, 77.20226272459954, 78.54009689823275, 75.39300672469601, 73.89444166614165, 65.71499370759534, 63.463717968233176, 64.7372252710404, 60.904971553433334, 61.47495861976378, 57.854167722886615, 56.07272524987498, 55.61036409870271, 55.36405101899178, 56.36417304315875, 55.25260863765594, 57.021883918393044, 55.476395545467255, 57.311017513275154, 55.576980806166134, 56.31254288458056, 54.46680099733415, 56.39626587590864, 54.14029505945022, 54.51023732462237, 55.30466633458292, 56.57423950010731, 53.8100746370131, 55.930390281061975, 59.40743807823428, 74.46401688360399, 68.81823570497575, 47.14435169773717, 63.08178109507408, 63.89915989291284, 68.94918011080834, 68.86734377953314, 70.27956178111415, 63.388145662123165, 55.505472075554636, 55.52903375317974, 56.08828136997839, 57.56672859191895, 55.4725359332177, 56.8477895182948, 58.19089927980977, 56.225678074744444, 55.64237063930881, 55.23280459065592, 56.113145274500695, 63.20798727773852, 71.10006670798026, 67.76326717868929, 66.87740772001206, 68.98295956273233, 70.12356911936115, 72.82559579418552, 74.51602751208891, 75.96242504735147, 73.36736140712615, 71.4279454754245, 63.82926325644217, 58.080264906729425, 60.46745861730268, 58.90256627913445, 58.84040063427341, 58.76829570339572, 61.11353182023572, 62.998713139564764, 68.5021318927888, 69.71090439827212, 75.4604087337371, 77.41113678101571, 80.36795277749339, 76.01798149847215, 71.29522815827401, 35.4795640514743, 0.7310319860135356, 0.5066442814084792, 0.7170961112264664, 0.8718996206598898, 2.165449377029173, 1.8184371653103062, 1.115634600000997, 0.8000995927760679, 0.11423289490443085, 0.18607039214862933, 19.078112379197155, 33.3390756576292, 57.08295129960584, 71.0021565037389, 30.35674660436569, 29.27280156843124, 52.086961730833984, 72.06249083242109, 71.85718613286173, 80.52931124164213, 52.26277805143788, 0.29057414661492076, 0.03059311987712018, 0.07032671823136269, 0.11583511417190875, 0.01352473933835544, 0.0028264335161375426, 0.030253449898032896, 0.04434675766876148, 0.02111135689061015, 0.03242174493930033, 0.06060915721219875, 0.014020147331569706, 0.05271052258209356, 0.04453036596157378, 0.09171626079947719, 0.03415548618161871, 0.04283874423333234, 0.060324563209207795, 0.03159693637562375, 0.013896009486709392, 0.04822716537502505, 0.051623240804239634, 0.09570848286872911, 0.06835655459473211, 0.16318743778092248, 0.18295189335701928, 0.19474929499049343, 0.08581148490550057, 0.17785820539199537, 0.2264502584453552, 0.13205641309820837, 0.14090698092214524, 0.1122318272809348, 0.1362546668538163, 0.17988884400936866, 0.12166389414379675, 0.17891048844302856, 0.1758317342929302, 0.24514067407336929, 0.2686609063417681, 0.13363957975900945, 71.08883303980674, 128.18068027496338, 98.10667576328402, 103.544445806934, 84.37276332609116, 52.174979717500754, 49.830684969502116, 79.353298371838, 46.36098769403274, 56.561291756168494, 1.5879958339275855, 0.37792015159803055, 0.13779090296837593, 1.9184150715028088, 3.6003119570593682, 1.1234918429005532, 8.70048874808896, 8.828426657184478, 12.08253477850268, 1.670356904787402, 83.15676581475043, 96.47926084456905, 91.7221083179597, 94.21481378616826, 90.60840622071298, 90.56447567478304, 89.45830452826716, 89.50167025289228, 80.95568856885357, 65.3423136280429, 67.58741947912401, 77.19532797413488, 83.45920408925703, 69.15242164365708, 63.48779347635085, 61.43848057716124, 68.39900493621826, 85.12545831741826, 81.14749247027983, 80.55829755721554, 80.93901065088089, 78.39099191850232, 68.61193472339262, 66.75178204813312, 67.3712811931487, 64.33133448323896, 63.9472677630763, 60.7099630755763, 58.493678800521366, 58.018330681708555, 58.87035185290922, 58.90478634065198, 57.48933238367881, 59.28658985322522, 59.034428519587365, 60.08205044654108, 60.142447102454405, 57.504664928682395, 56.11365910499327, 58.65490390408424, 56.866593360900886, 57.75379034780688, 58.05163552684169, 57.912305093580684, 57.11678174234206, 59.94132364949873, 63.447997108582534, 75.72014024180751, 73.6994763343565, 51.26907302487282, 62.11840383468136, 68.82069895344397, 71.04419646724578, 70.58762473444786, 73.47474021296348, 66.11052943814185, 58.42875572942919, 59.86999142554499, 59.75863141398276, 60.732822648940555, 58.4805114038529, 60.36403748296923, 59.33819255521221, 59.45826022855697, 59.6620548156, 57.024876686834524, 59.066874365652765, 67.91265456907212, 75.52261752467003, 72.43580633594145, 71.17188530583536, 73.96506001872402, 72.05717209846743, 75.58811326180735, 79.76549240850633, 77.19979163139098, 77.82969290210356, 74.8314017634238, 68.50925491702172, 61.15079433687272, 63.4563321451987, 62.35746445194368, 62.470232594397764, 62.115007062112134, 63.80689005697928, 66.10499105145855, 71.94128959409653, 73.27287150967506, 78.22146707965483, 81.213576562943, 83.34288227942683, 79.20493079769996, 74.98621771412512, 36.487628875240205, 0.6762612346679934, 4.353081718567879, 5.987088180357411, 4.738727683021176, 5.568820353477232, 2.002318491858821, 1.3946435768758099, 1.815277083266166, 0.18820618399448935, 0.5291238751622939, 26.446422030848844, 46.57174448813162, 62.83451487941127, 77.72877031756987, 50.23826237647764, 34.75208205561484, 59.70623639322097, 82.97778806378766, 81.89456278277983, 92.84804821014406, 55.052442243022305, 0.6524615794900925, 0.2053773859816213, 0.1980923035091931, 0.15141064391261147, 0.142833324329507, 0.13280367058131004, 0.10369072833489026, 0.16785392447585062, 0.14642635330317483, 0.16164865825445424, 0.15536083839833736, 0.09511238985484648, 0.17812071308012933, 0.14758800306627828, 0.18584975882643656, 0.1386647334983272, 0.11125394668910774, 0.15579738594110937, 0.10901356851982494, 0.09441882747435763, 0.12147336807702819, 0.13947697055916633], [0.036719931034191, 0.04642737969275444, 0.07139299004789322, 0.036105616619029356, 0.06611519583290623, 0.049126288297796444, 0.018021908153088826, 0.017769026359723463, 0.03655496549101607, 0.04093143045000973, 0.004807815552809306, 0.03660802474065173, 0.04473599162132991, 0.041047542566253294, 0.06569358700465772, 0.02132366858272543, 0.09984127441120726, 0.03970815657427715, 2.6012477470982462, 86.76519732321464, 80.94897347111856, 84.91761976672758, 55.33364088304582, 42.61582628373177, 33.169456681897564, 65.9165446988998, 46.89430059925203, 65.27220518358293, 18.074740671342422, 0.06717231289874162, 0.19052462652325633, 0.10353362668425807, 0.15352167579675877, 0.16951506356558493, 3.13551623975077, 3.7492470491317014, 0.23797363042831424, 2.1659261901532454, 50.631652570539906, 95.76405586734896, 79.76551594272738, 83.04839857162969, 78.33456470120338, 81.68033076870827, 84.4263272131643, 79.91493471207158, 79.59412405567785, 75.93597258290937, 60.724679808462824, 59.1043447679089, 58.72754227730536, 61.44999273361699, 57.624595319071126, 58.721117434963105, 54.95190012839533, 60.620203556553015, 70.06768318914598, 74.26855733317714, 76.18383499883836, 70.52613765962663, 69.38522215812438, 58.87066172015283, 54.654890414207216, 54.466004756189164, 55.70444214728571, 53.112045718777566, 52.41661733196628, 50.56899662940733, 51.47473466011786, 52.547126354709754, 50.56790621049943, 52.751560288090865, 50.859177497125444, 53.735157366721864, 52.8762092897969, 53.575524745448945, 54.69620866160239, 53.83673498707434, 52.96594135222897, 51.51987721843105, 51.72590755647229, 56.60601069850307, 57.99004647039599, 55.4297899430798, 55.89544196282664, 53.79726025366015, 68.32269130214569, 63.97530486506801, 45.45089191006076, 67.26389454257104, 64.98708025101693, 67.26866414470058, 66.91376809150943, 65.43981198341616, 54.98313396207748, 50.88433557941068, 52.16363230059224, 51.15497127656014, 52.98419606301093, 52.02077957891649, 51.80442556258171, 52.645695517140055, 55.27935135749079, 51.9318437576294, 52.0749161320348, 50.44562632037748, 51.03377396060575, 56.840231110972745, 63.380391136292495, 63.750968825432565, 61.76017768921391, 67.55336546128797, 68.0982062124437, 69.37805991018973, 70.94714918444234, 72.69550646505049, 69.5427131652832, 64.98626832039126, 54.660154234978464, 56.688819777581, 56.198594108704604, 55.80998528388239, 56.809189473429036, 68.31521526459726, 71.18863382647115, 73.27811964096563, 75.08277077828684, 77.35805926784393, 79.07950908906999, 75.20321107679798, 74.92520916846492, 70.44772163514169, 70.0567711553266, 44.71189383537539, 4.25878401725523, 0.48700089836793564, 1.3863724013490062, 0.6576908956612311, 0.6768055861034702, 0.1632611814045137, 0.46469630973954357, 0.24439520923601044, 0.2831096003853506, 4.571242966959554, 24.09378440149369, 35.86165389707012, 55.47150042749221, 60.698290101943485, 41.306233175339244, 41.6293070393224, 48.076295083568944, 53.30111965056389, 62.75059969194474, 70.05812829540622, 5.949659943580628, 0.3340080837088247, 0.07554252827239614, 0.08896297910400937, 0.024166661089346297, 0.03212972371388347, 0.0033930733221613114, 0.041785097545793945, 0.035785759588883775, 0.07328046981485621, 0.0036661793579227265, 0.07513021975154839, 0.04296871104968652, 0.0414367726883821, 0.02270373384348087, 0.053218534636882045, 0.08953082645612379, 0.06374439502495431, 0.0994733683464508, 0.12535211720293568, 0.0366632137147169, 0.05935446990113105, 0.062009707664049445, 0.04262453455838465, 0.03974994284010703, 0.030890273891629714, 0.013739315777896874, 0.02132369539580278, 0.06294057343996341, 0.06474914615072551, 0.046150450399445916, 0.004732295084038689, 0.018304807186547308, 0.0476338800733849, 0.037815168635138584, 0.02405291235434913, 0.09570904977379308, 0.023903534785213492, 0.18380073409888054, 0.23339181177077756, 4.039841481754857, 103.69470396349507, 89.92498028662898, 94.84080053144886, 66.5074654548399, 50.58835744857789, 41.424720133504565, 49.3920345460215, 45.919371958701845, 66.02669269807878, 18.637930270164244, 0.07960456393418774, 0.04369559059400232, 0.3686112027254797, 1.0428883616001376, 1.4815397656732991, 3.9023418147717757, 2.488191310436495, 0.11257908727613189, 0.6875606025418928, 52.692960077716464, 102.83296708137759, 82.1916352548907, 86.63802623748781, 81.77353412874284, 87.17026833565005, 85.27479863935902, 83.49011236621489, 83.23431107305711, 81.42069339752197, 62.4081846206419, 61.1973254142269, 61.73822810572963, 63.21500439797679, 58.42753194993543, 61.24810441847771, 57.516082948254, 63.254275168142016, 73.78336798760199, 76.46515523233722, 77.47951153785952, 72.40544719080772, 71.38386587942801, 61.74793204953594, 58.3946938668528, 56.59043104417863, 57.7296010909542, 57.1146518953385, 55.37562593337029, 54.210576088197776, 53.07787402983635, 54.05352438649824, 53.23871866349251, 56.250424308161584, 53.765685173773, 55.42032134148383, 56.47284230878277, 57.74083083675754, 58.76627176038681, 55.82735746137558, 54.38086971159905, 53.34265755068872, 53.85646058667091, 61.31242736693352, 61.46623134613038, 58.9111170461101, 57.90367195683142, 56.185403177815104, 70.53431187906574, 66.81412419965191, 48.46592372463596, 69.52390147793677, 68.34926143769296, 70.16905292387932, 68.33521935247606, 69.74701373807846, 57.45327795705488, 53.5936107943135, 55.493222513506495, 53.84079071783251, 55.50075346423734, 55.90686390476843, 54.24133923745925, 55.86524363486998, 56.121221434685495, 55.5501086481156, 54.717005068256015, 54.15352129167127, 53.01255479935677, 60.415589194143976, 65.20558764857631, 67.11003565019178, 64.61223894549956, 71.0729003721668, 70.42582696483981, 74.50189913472822, 74.55393329743417, 75.22024200808617, 72.48134505364203, 69.2577608170048, 58.71786971246043, 57.63065930335753, 59.4459871322878, 57.033702019722234, 59.22737383073377, 72.70230785492929, 74.9491983844388, 76.58563475455009, 79.32795201578449, 77.71457918228643, 82.11046572654479, 76.93944038883333, 77.95893499928137, 73.30195980687296, 76.74972318833875, 53.71601227791079, 8.102340044513825, 0.2181136896533351, 0.6065401855495669, 0.6561547974424978, 1.645047566102397, 1.1851565275461444, 0.9038880815909756, 0.3143945474538111, 0.3245545587232036, 4.816224892293254, 41.73086897019417, 36.66141340809484, 66.0667008738364, 58.06690923629269, 34.67255992274131, 53.833926570030954, 52.65290875588694, 60.64851130208662, 66.2409717805924, 86.9322902925553, 10.366446837302178, 0.5161750280568677, 0.06601047927453634, 0.04071943476916321, 0.04664812409769624, 0.07755917812427206, 0.08317047339533606, 0.04533347891523473, 0.05810740516490995, 0.05016906802812892, 0.03477170049483257, 0.1419078747952177, 0.041598972654150385, 0.044760797548318104, 0.022862880948870894, 0.07595931840760094, 0.12346500515817635, 0.07405573547246956, 0.02842716714968124, 0.03855072795563648, 0.037882886977205356, 0.0513581590606801, 0.14916076625306762, 0.09793858013806805, 0.17051987980882968, 0.10738675782997763, 0.12348935909328923, 0.1586329071752487, 0.08127328729437244, 0.1670319887418901, 0.1695438531497794, 0.11171079556187315, 0.0919602214989643, 0.12185273481713188, 0.16990353143022907, 0.14857703789828286, 0.18563435022388736, 0.1466882021556939, 0.2641525708379284, 0.34387725735864333, 4.752610421949818, 118.13272107032039, 100.21458887284803, 109.8537821923533, 77.77883545044931, 61.98848708983391, 43.65486998711863, 89.10355752514255, 68.20476916528517, 98.22736709348618, 30.658845593852384, 0.24762025553612943, 0.5890828190791992, 0.4159457530946501, 3.1388833493955675, 1.604402250339908, 6.919165417071312, 8.490657633350741, 5.038920400604125, 4.916061470585485, 59.471466848927165, 103.40737465889224, 86.99289875645792, 89.67654520465483, 85.85919257133239, 89.03490820238667, 88.66826072815927, 85.3821539109753, 87.23063361260199, 86.87068554662889, 66.33176680534118, 64.33539805873748, 64.98965724822014, 67.28500473883845, 61.42496408954744, 63.628951734112164, 61.26193861807547, 67.40991653934603, 78.00254391085717, 79.85049017014043, 79.13584216948479, 76.3001254297072, 76.58540725708008, 65.22774119530955, 61.149645082412235, 61.33357286453248, 61.48649431044056, 59.750064957526426, 57.966186692637784, 56.195048286068825, 54.93276680669477, 58.46848933927475, 54.6286105340527, 59.31725886560256, 55.691113933440185, 59.81611374885806, 58.79663875026088, 60.19723869139149, 61.371235462927054, 60.77428602403211, 57.31441428584438, 56.624312477727095, 57.17699012448711, 65.12754032688757, 63.642950673257154, 62.117717419901204, 61.83172564352713, 59.266424948169345, 75.5293640013664, 70.87373025955694, 52.416605564855764, 70.25498420961442, 72.21458465822282, 73.16617519624772, 72.81764122747606, 71.67808286605343, 61.49432728367468, 56.11949951417985, 58.622665943637976, 55.59292131854642, 57.74779696618357, 57.82969213301136, 57.04074659655171, 57.86103971542851, 59.1122365766956, 57.19439368094168, 56.737986687690984, 56.75847714947116, 58.022288353212424, 63.325964327781435, 70.38019411025509, 70.9338366600775, 68.51673095457016, 75.16016698652699, 74.18017064371418, 77.08521919865763, 75.27950117664953, 79.09997601662913, 75.57069009350192, 71.63400327005695, 61.11269635538901, 60.540191127407944, 61.64987279522804, 62.69263882790843, 62.23128180350027, 76.45683196283157, 77.92133515880954, 78.75508200737738, 82.72081790431854, 81.28959209688249, 88.10067807474445, 78.63420240340695, 80.4479455947876, 73.67754244035291, 75.79031928893059, 51.32530020129297, 5.914529725428551, 3.338058364968146, 5.332858408651044, 4.413755391874622, 2.79396090296007, 2.2394414582560143, 1.5276484527895529, 0.7972200214862825, 0.7526780148186992, 8.645256873100035, 48.428861248877745, 52.11290428715368, 71.0916022331484, 75.05416885499032, 55.07945952876922, 58.23454349271713, 64.52694700610253, 72.98114130573889, 79.83785229344522, 98.45151485935335, 11.175237605648658, 0.7129496143710229, 0.2066640766157258, 0.18034089717172808, 0.23003775626420978, 0.23004972255758702, 0.23670169464763136, 0.15606357085127986, 0.1658801602259759, 0.2345101775661592, 0.1904811893379496, 0.18956464174534046, 0.14246046933675968, 0.17504365964522287, 0.06676893696309098, 0.15660550144891586, 0.19331569933602888, 0.22049467560024033, 0.13068569794056878, 0.2548552052147927, 0.1948475687494201, 0.21322424072892437], [0.09251307651040055, 0.06767776238942338, 0.017858206654988953, 0.04662624845701841, 0.022749655068882053, 0.011115564228666407, 0.042850335143626704, 0.03899459546852497, 0.03553148734593584, 0.10789952346033628, 0.06740462906177967, 0.05247703430453136, 0.057457548100501306, 0.08274902544555165, 0.08709465919603264, 0.03193537678359257, 0.12925199503379484, 0.4996484890580178, 19.378952287858535, 94.19433116912843, 72.89612785462411, 83.61794241013067, 55.909134957098196, 49.269366341252486, 39.21182086390834, 75.6561585395567, 52.39009034249091, 34.871616286616174, 1.3290290654666963, 0.04058407852426171, 0.0772332230342492, 0.12046336541853606, 0.3373182883426067, 0.9750298867302557, 5.681466412159705, 1.2646073223121705, 3.137677956011988, 16.85243598876461, 103.32723279153149, 78.04988691883703, 83.1238728184854, 73.08341318561186, 76.60580358197613, 80.18266785529353, 86.58708249368976, 80.34778395006734, 80.14524844384964, 70.57976430462253, 67.32014133084205, 58.17207190298266, 62.80218278208087, 60.98301103038173, 57.16713713061426, 56.06110718942458, 56.41432839055216, 58.14472513814127, 70.76166814373386, 71.52488293186312, 73.44193350884223, 70.5991094343124, 69.30990480607556, 57.930975575600904, 56.33254305008919, 52.76235857317525, 53.50151354266752, 50.44304147843392, 50.761690908862704, 50.87774599752119, 50.47275735485939, 50.83283485904817, 50.9182091682188, 49.18171313501174, 53.02239602611911, 51.89204346749091, 58.148247426556004, 58.13376995824999, 59.15848524339738, 53.702048640097345, 52.993845093634825, 52.514072541267645, 56.75959894734045, 61.928506205158854, 65.51080688353508, 63.17614939904983, 63.794577737008375, 58.70743620780207, 65.19319295883179, 61.765163021702925, 45.515709077158284, 70.65585828596546, 63.56597023625528, 70.44230091956355, 66.37884309214931, 64.57368596907585, 51.96452886827531, 50.517841077619984, 49.453254899671, 52.76773614268149, 53.77906437843077, 54.128637775298095, 52.00461941380655, 52.307120446235906, 51.61713238685362, 52.294910107889486, 49.134978094408595, 51.93017282793599, 52.717027741093794, 50.460986321972264, 54.28413229603922, 57.66480745807771, 60.05905359022079, 59.799290703188994, 64.15514161509853, 67.05383593036284, 68.73989028315391, 70.4517302974578, 70.61390461460238, 69.73361492156982, 58.60382679970034, 54.306493728391594, 54.17698098767189, 53.441489511920565, 63.92197239783503, 70.18928450922813, 72.08417369473365, 74.68607010379915, 73.48651516822078, 72.40285842649399, 69.28313855201968, 71.48733015983336, 80.67745131831016, 79.47141662720712, 76.18414878845215, 82.21036065009334, 73.12939120877174, 23.921761012846424, 0.1856191816829866, 1.492821605455491, 1.7355997716226887, 1.949817444528303, 0.38761395240022295, 0.27054349080689494, 0.08439851233795767, 0.18498864535602833, 9.865743537102977, 26.35336575969573, 43.444697626175426, 53.37416595028293, 30.342237757098292, 32.58879684632824, 39.72033654489825, 49.625843109623084, 59.673119821856105, 65.10264504340388, 32.826476789289906, 0.4740432259296218, 0.05978890304123202, 0.09832568436620698, 0.057212216103629726, 0.062169846853301416, 0.04519788135263709, 0.007829052300357651, 0.031727969969412496, 0.06695297426514088, 0.029990187613293532, 0.047719823647170305, 0.08842196015100326, 0.06114678622613992, 0.05019032696802771, 0.02359520354788871, 0.04737891835130511, 0.030529264533411593, 0.02150222069523748, 0.04250836115510714, 0.012148295758262038, 0.05272785149094078, 0.05845673742794222, 0.0936798437408382, 0.049157728546208916, 0.05798459744020816, 0.017256954038936286, 0.12499789346850688, 0.04207529548195101, 0.04388920782554535, 0.024711387907905925, 0.07668140990238997, 0.0339625162943717, 0.05384915906395163, 0.04707147194553287, 0.07205338082126073, 0.02373531145314055, 0.061722685162338524, 0.0764697091653943, 0.45487880105933837, 25.355048025808028, 109.23833093335553, 79.2068527590844, 95.41161521788567, 63.85294652754261, 63.06484430067001, 31.541049403529016, 63.640950264469275, 49.30918232087166, 38.584645640465524, 1.9300896385985038, 0.059816938028821064, 0.2951099693534836, 0.9462273709716337, 1.1574538076116194, 3.103272886045518, 3.290558707329535, 1.0820616853813971, 1.3484606098744178, 19.130776082315755, 108.82582310707339, 80.49761064590948, 89.26100146385932, 74.73346018022107, 82.63322353363037, 83.28359957664244, 90.1353919121527, 84.0387656611781, 85.64333669600948, 73.12346842981154, 69.64199619908487, 59.65135851214009, 65.42462456610896, 63.00296106646138, 61.55941509431409, 58.186184590862645, 60.79977750778199, 62.639761355615434, 73.91456342512562, 75.44370728154337, 76.13209893626552, 75.22887906720563, 72.47268446030156, 60.65289651193927, 61.28850483125257, 56.11600468235632, 56.60917212886196, 53.31205129623414, 55.64921125288933, 54.330333894298924, 52.836507058912716, 54.12574306611092, 55.71801354808193, 51.36475140048612, 55.851891886803415, 55.51443076902821, 61.15088847375686, 60.717007652405776, 62.07033518821963, 54.5380037830722, 54.30233601600894, 54.059345183833955, 58.36342080946892, 64.5375217160871, 67.06553243821668, 66.77386499220326, 66.93279943158551, 63.05936474953929, 69.55518630243117, 63.616168729720584, 48.374532499621, 72.66187606319305, 68.4753107255505, 69.93562483018445, 69.1585954543083, 68.8309520290744, 54.01592846839659, 53.24475519118771, 53.37641346839167, 57.13508744393626, 57.055357425443596, 55.30632157479563, 54.94364353918261, 54.955795041976444, 53.82863137029833, 54.57408174391716, 51.783205539949485, 55.07683546312394, 54.11245799833729, 51.64929189989644, 57.61146322373421, 61.12203944113947, 61.55540250962781, 64.28084181201073, 67.84956716722058, 72.43271550824566, 72.27634629895611, 72.26053130242133, 72.17576103825724, 71.51257453426238, 60.5785362182125, 56.55302339984525, 58.75218260672785, 55.60098963399088, 67.78680924446353, 73.68294746645036, 74.74822398154967, 77.431242850519, 77.19753234617173, 73.062224541941, 72.05255154640444, 71.7970012849377, 78.89752680255522, 80.665543002467, 80.51691655189761, 86.6757437490648, 82.3248467906829, 32.42879552225913, 1.2268476452558272, 1.0799447086549576, 0.47715740398533885, 1.979330215723284, 1.4185863372779663, 0.592805209659761, 0.09271007602012928, 0.3312566329634959, 14.89914761435601, 37.47882358489498, 44.6842215138097, 58.30767608457997, 27.054003054095855, 42.06816142605197, 48.265839699775945, 58.802628209514005, 66.3789999869562, 72.84093226155927, 49.842557984013716, 0.7772098049040764, 0.05279619802510547, 0.05538459078619077, 0.09005510638798438, 0.04285631062943609, 0.054457888698145274, 0.06860999946272181, 0.01737050550629295, 0.03494224315809627, 0.07610142005667572, 0.043979862840065075, 0.04513794263344138, 0.028783578065133868, 0.02690471678731903, 0.022877176149537968, 0.0303362256982514, 0.018537180806179682, 0.0048325204519524935, 0.023514860076829795, 0.037629438278776024, 0.030754934883706515, 0.184000943517012, 0.1800728123635054, 0.2776595896049854, 0.2583292607338198, 0.07922175745930403, 0.20194031718757846, 0.1118162015993749, 0.11843185346092909, 0.14390549502305447, 0.2875967918624801, 0.13352270538528122, 0.14406024478375912, 0.1873198509096138, 0.21176985344819485, 0.22234641736553562, 0.13347857872084265, 0.2812788034639051, 0.6898184168723323, 32.21914287536375, 125.1604473975397, 92.56179363496842, 107.47055792039441, 75.29370015667331, 69.20825266068982, 52.89415413333524, 104.97335741596838, 66.66046142578125, 55.357535962135564, 3.1164552367502645, 0.22112599333688138, 0.49723788615195985, 1.8115154076968472, 1.327819872287012, 4.607119416036914, 14.008011587204473, 10.047935670421971, 8.12586396932602, 21.438863431253743, 111.0538705702751, 84.52599463924285, 91.54001620508011, 79.00871815220003, 85.84239698225453, 86.72787204865487, 94.99265901504025, 86.82513113944762, 88.0842198095014, 75.60064915687808, 74.1137178482548, 64.36571013542914, 69.60449834023753, 66.9754591295796, 65.05069717284172, 62.28262955142606, 62.49147615125103, 64.31830044715636, 77.54927481374433, 78.4162441376717, 78.27394054782006, 77.32174596478863, 76.95618106472877, 62.7986644160363, 63.6196949405055, 59.859514774814734, 60.78085991644091, 55.57020295050837, 57.420745818845695, 56.59362777586907, 55.73433060799876, 56.272491562751036, 58.38961047510947, 54.63360763365223, 57.958067386381096, 57.47194451670493, 63.32177915880757, 63.67027390387751, 65.3268555671938, 58.835736936138524, 58.444849214246204, 57.28282743884672, 62.2818450773916, 67.4437665939331, 70.2704148138723, 69.81458048666678, 70.83096857993834, 65.83085660011538, 72.26711303957048, 69.33440393017185, 51.96488188159082, 74.46539755790465, 71.9167120225968, 74.05636495159519, 72.38422716817549, 71.54258851082095, 57.50976008753623, 56.18457163533857, 55.55925169298726, 58.83968284053188, 58.52852513713222, 59.17866583793395, 57.73624950839628, 57.812221896263864, 57.95616503684752, 57.42379350046958, 54.354613365665564, 58.63972825388755, 58.18184644945207, 55.32319561127694, 60.92644260775659, 64.96435403823853, 66.90203235995385, 68.0500316619873, 71.1418556397961, 76.28394957511657, 75.13427149864935, 75.77779908334055, 76.40321316257601, 75.56865046101233, 62.91168751255159, 61.445733039609856, 60.39806404421407, 58.49203140504899, 71.7956284553774, 76.70439627862747, 78.39503980452015, 81.0122726809594, 79.54599657366353, 77.44985841935681, 72.14100099379017, 74.13247462241881, 79.04901658335041, 81.90240752312445, 84.25366447817895, 90.84199905395509, 81.88055992126465, 28.078794825461607, 1.2962103490867924, 4.869248472875165, 7.853481346561064, 4.738691891393354, 1.754481081039675, 1.2347642140042399, 0.1854828027107062, 0.49719170637188426, 16.14914324975783, 43.43138902418075, 57.780807633553785, 69.11843822848412, 39.708373315872684, 45.48811912536622, 55.00472268750591, 65.59583210176038, 76.39696874926167, 85.44213479565036, 53.895323430338216, 0.8747571899044899, 0.23087605563623292, 0.2488125334944456, 0.1951989579585291, 0.11392249139927088, 0.10645386958194357, 0.12156533693233806, 0.09770850861264814, 0.16424226424386426, 0.22671959963777374, 0.1546711141183492, 0.11715992534112547, 0.23476105603960254, 0.1049778862826286, 0.12429972689959312, 0.13607328787686365, 0.09615311263910226, 0.09544570704982167, 0.09702089107445172, 0.11416237651100082, 0.14216385541423676], [0.028318359681795684, 0.047838846897526134, 0.12460193326396328, 0.045005428574738965, 0.06973136066188736, 0.04406819660817424, 0.017440307607513764, 0.04553281882357213, 0.021302189392548417, 0.07080916976255756, 0.027630573604255918, 0.0334220910595069, 0.07538066155487493, 0.010577522484856028, 0.02128419398720707, 0.03778688849941377, 0.032677488071062875, 0.04621637609576987, 59.49704462482084, 87.56514118563744, 85.128980605833, 61.62184353797667, 50.95807613865022, 22.480070321790635, 71.6350152415614, 112.00117788007184, 69.12844811716388, 24.253411139211348, 0.0414187504699634, 0.40830417926753726, 0.20177104239982946, 0.6795904689258145, 0.40965381168550064, 1.472244974105589, 2.6286604567881557, 0.7332540700031865, 1.4904320240020754, 81.98401635692966, 89.50567107046805, 87.48938452812934, 70.9202495698006, 68.00506561033188, 72.7678192815473, 78.79099522867511, 79.40454021576913, 83.25073011459844, 80.65186177530597, 76.33516004008632, 65.97991451140373, 63.94672647599251, 54.17370188620783, 60.34255858390563, 56.68469344415973, 56.425687574571185, 55.45988628941198, 60.3015305919032, 68.2730027168028, 75.00826927923387, 72.98627176592427, 71.50565547327842, 68.29251258603989, 60.66370656413417, 55.965185626860595, 52.43264021412019, 53.68187589030112, 52.90532896595617, 51.1476952798905, 50.314579932920395, 51.73812966192923, 50.269829611624445, 49.4770009286942, 52.14391846810618, 49.93917772846837, 56.764192042812226, 63.60145591920423, 61.7515641643155, 61.78938365751698, 53.72753620147706, 51.9637365495005, 48.19544884466356, 52.50490203980477, 63.28548154523296, 67.90273097253615, 68.33387790187713, 71.08437722729099, 63.38605896119149, 71.91019304337041, 57.05617720080961, 46.65840533471877, 71.80610118373748, 60.049683047879135, 64.40503974114695, 62.94372935448924, 60.845410362366714, 50.999072751691266, 51.217839025682025, 49.52091578514346, 54.11815327982749, 51.8997234682883, 51.434185197276456, 51.20485598041166, 53.05211190254458, 51.508168943466686, 51.76382510892807, 47.53838908287787, 48.630996673337876, 49.83581542968751, 52.41040429761333, 50.76073777291083, 52.5251297027834, 55.069182918917754, 57.65145178764098, 59.92651670209823, 63.89522183325983, 66.611219990638, 69.7819620563138, 71.15636056469333, 68.5033635170229, 58.85928684665311, 50.18884051230646, 54.898422533465975, 53.62280891787622, 63.66483357644851, 74.2396180860458, 73.44099998474121, 68.77018667036488, 72.5511004847865, 72.13343866409795, 72.96851127378403, 71.82284185963293, 73.45095496023856, 69.515256574077, 75.78070948200842, 70.14398897847822, 75.58157859310028, 83.05778088108187, 47.91764697720928, 1.1640403251494131, 0.9522016310403425, 1.823556226107382, 0.5188299823672541, 0.25696839746688643, 0.2660324893170788, 0.04239208432995985, 7.660110948547241, 15.717957096715129, 37.723257849293375, 35.001548720944314, 29.947612016431748, 27.65591625244387, 26.257326526026574, 48.53972311942808, 58.38196185327346, 62.0970465290931, 71.79256900664299, 12.755093786024279, 0.5454371965700581, 0.19199284935189834, 0.06171772474302881, 0.04127193738015429, 0.021202869923605074, 0.08562174790929403, 0.03948908607144991, 0.06845930230713661, 0.02605445878279786, 0.025904135095075737, 0.028513936183205055, 0.00968651626364238, 0.02212934984615253, 0.05730860911670232, 0.02788982350349186, 0.036650247676598455, 0.029311885704256357, 0.02843388765599699, 0.006856787133015573, 0.15581318267410801, 0.043729114601568836, 0.032358002593560566, 0.06154810521571387, 0.049206850103913784, 0.052330485515056126, 0.049707503884189555, 0.014303611354872346, 0.07041472641210403, 0.028986541569353114, 0.03663980206775089, 0.04864490545925595, 0.07758296515432096, 0.09768737224681724, 0.05755306777334022, 0.011230446773791506, 0.07833221446602576, 0.0646754791359267, 0.28528250153026274, 74.577192952556, 96.27946315273162, 92.56824201153171, 71.78860741276895, 62.21060699032199, 36.72932140288815, 61.445003478757805, 89.23894205401021, 65.86716205843034, 26.525383264787738, 0.03993876819168368, 0.13473730714571092, 0.41637203505923676, 1.6856011964621085, 1.3477776271681632, 5.061143079111654, 4.70092240841158, 0.3993901333981945, 1.9154957249279947, 89.50958559590002, 91.32297577396517, 93.1855054055491, 75.0178869308964, 72.12493496556436, 74.17700136861494, 84.38912745445006, 81.86762394443636, 86.5967550585347, 83.6525063360891, 79.74680623700543, 69.81461186562815, 67.41062256597704, 57.62398735169442, 63.183907847250666, 58.6821133859696, 59.41914635319864, 58.402668045413115, 62.08215328954882, 72.72309641684257, 78.18399275502851, 76.10686240657684, 73.78470159346058, 72.0282877645185, 63.29137294523178, 57.1292156557883, 54.89355094971196, 55.47562283854331, 54.69233728224232, 54.3403830066804, 52.90327364398588, 53.17028114872595, 52.869831515896706, 51.73055164275631, 53.90214835443805, 53.65565092332902, 60.55238969864384, 66.91309344383978, 65.78934223421159, 61.73039513249552, 57.22780443006947, 52.72979505600468, 51.654696925993896, 56.846593195392245, 66.43803165804955, 69.84455523952361, 70.60379274429815, 73.40758139087309, 65.84075666243031, 76.42874779239779, 59.2555207590903, 46.21046673867011, 74.96859058257073, 62.814471567830736, 66.60986285055837, 67.12479160678002, 65.9204984480335, 53.82653682462631, 53.58053753452917, 53.04987615154636, 55.03028869628907, 55.140566133683734, 53.54816229112687, 54.10205587264031, 54.800669224031516, 54.04392634668658, 54.67221944562851, 49.8854334123673, 52.37965291546237, 51.65508131827078, 54.312381206020234, 52.4459566608552, 54.34942014755742, 57.294527869070734, 60.179666473019516, 62.03258237531109, 67.70817356724893, 71.2939259313768, 72.69243132683539, 73.07665101943478, 69.92493244909471, 61.52878530563847, 53.274992742846095, 56.383451492555686, 56.28282700815509, 66.42475835738644, 76.82341667913622, 76.96961126019879, 71.33901749887775, 73.75938661636846, 75.01601203795403, 74.63115692138672, 74.3848006956039, 74.1224725784794, 73.23163955442368, 78.76725704439225, 73.02780182130876, 76.5093054309968, 88.55922668210923, 58.22712236835111, 2.9482885185749304, 0.792000204805405, 0.3839338498730814, 1.1356064508999548, 1.4264613534173658, 0.4075081526271759, 0.1071045846648274, 2.272452125626226, 24.23698817529986, 40.04518332019929, 39.83517177643315, 32.681272606695856, 34.747512494364095, 42.31436860176825, 52.83812699779388, 65.31755562751525, 68.46235905924152, 87.35100330845003, 22.472684498756163, 0.45012344816519373, 0.21772575805023794, 0.11602239202587836, 0.07919512824305604, 0.01855662220247811, 0.06783235893254319, 0.020016073324387113, 0.13046806768303917, 0.05157480106478737, 0.0825971944798385, 0.021701537620937152, 0.03161499115277923, 0.01651817331871679, 0.06471959047860677, 0.012450473394335039, 0.03733129218040455, 0.019062406856626756, 0.05537907878357557, 0.021328617510716283, 0.07255598812574342, 0.08555587966956439, 0.18981043339496662, 0.23194724573723732, 0.13850005523812386, 0.19899930564626572, 0.13970914116549876, 0.11106096914098149, 0.14480500482022762, 0.1056930446817029, 0.20016535275405456, 0.24386976485050496, 0.11549854876413462, 0.3555879531608474, 0.16490918974722588, 0.17716158632068865, 0.1569747098631436, 0.13925731782951664, 0.5076648024541717, 89.88620373510545, 106.60609891337734, 108.00978968220373, 81.52183563478532, 72.20912471894296, 33.72119295981623, 97.2904226856847, 135.28830528259277, 93.4349524590277, 39.85443061397922, 0.19095803310553874, 0.6462237238883972, 0.5624947877180192, 4.265990391854317, 0.8806163529234549, 8.861944290899462, 11.118486792810502, 6.648111006905956, 1.6408595779249746, 91.36000294839182, 92.73974372494607, 97.83411810475012, 76.54022939743535, 75.1181427125008, 79.33344333402573, 87.2286645827755, 83.10837945630475, 89.31960167423372, 87.39904449832055, 83.56277819602721, 72.16096585796726, 71.52042711934736, 60.13548881776872, 67.38439759900494, 61.67513678150793, 62.10574242376513, 62.3067521279858, 65.2456585822567, 77.47328281402588, 82.20291599150627, 78.06272091404085, 77.05974732675861, 75.36874294281006, 67.52421440616732, 60.082454450668834, 56.82578109925794, 60.039559410464385, 58.767056234421275, 56.00027122805196, 56.02861819728729, 57.054008130104314, 56.759626403931655, 56.32470223211474, 55.82617290558354, 54.80148507702736, 62.8708242600964, 69.95811570075251, 68.99773905354162, 66.00192685281077, 60.351823222252634, 56.915517084060184, 54.57214801542221, 57.308111036977465, 70.11225700378418, 72.87220924131333, 74.56391180715254, 75.60912147645028, 69.54375651574904, 79.13005275111045, 62.01684974854993, 52.396017043821274, 77.80359345097696, 65.55203883878647, 69.19994508066486, 70.79343934212962, 67.56141416488155, 57.32502429716049, 56.20983562161846, 55.45011174294257, 58.396211824109486, 56.760661909657145, 56.385824526509936, 56.370350776180146, 57.07742075766287, 57.87573683646418, 59.21084496282763, 54.266862100170506, 56.04450771885534, 53.75434952397501, 57.81037053754253, 56.19103177901238, 57.819101733546105, 61.767520366176484, 64.30379159988897, 64.91255521774292, 70.4010768090525, 75.34778964134955, 75.20201083152526, 76.77190811403337, 73.72173186271422, 64.85963852174821, 55.7459996592614, 61.023438899747795, 61.741201262320246, 68.88006794837214, 81.36546642549577, 78.71530917383011, 72.1668258790047, 77.08930630837718, 77.18892666601366, 76.17040480336836, 78.29155983463411, 78.70558169580276, 77.6123151471538, 84.05929534666001, 76.15409558819186, 83.23534657878261, 91.1186752011699, 55.34187393803751, 1.5833261296633752, 4.644125998020172, 6.960061029080422, 1.779623228696085, 1.4664312860658093, 0.7925506849442759, 0.17893267434931573, 11.562584407867925, 28.57875189473552, 54.91774412893481, 47.182402610778816, 38.201728174763346, 35.02136845742503, 43.01230338311965, 63.34776878356934, 75.95482349395752, 78.92805853197652, 99.6406598244944, 22.612030621497862, 0.9075222188426603, 0.2858395087382486, 0.259009393592996, 0.22439907334985273, 0.10944525140427774, 0.17665688759617268, 0.15201576144224213, 0.2224052222746034, 0.13745007045086355, 0.20227477585356082, 0.08360178089670597, 0.1665069733656222, 0.13198224046537954, 0.25687294291152113, 0.1750945125616366, 0.13762944227745458, 0.11660522405779171, 0.26411582926107996, 0.08033565696208708, 0.18779715432995753], [0.008968949475656114, 0.03762524394739059, 0.08221690843422567, 0.020040362142026424, 0.0026529093344335357, 0.049171950968523184, 0.008915999393549659, 0.010336979495121107, 0.07849052653557832, 0.03785203278605496, 0.022373479084982988, 0.0268281462992872, 0.034129343431202636, 0.16092986859861882, 0.11246817306645455, 0.19165243052186506, 0.3663350942154085, 18.226573659527688, 96.01277335997551, 76.47482779718216, 82.39864226310485, 66.74415696051814, 43.90417583527104, 21.763388572200654, 50.6333117331228, 64.18286100510629, 43.83204737017232, 2.107932721414874, 0.06096161511396209, 0.005587933898618024, 0.3456097192341282, 1.1466671670636823, 1.0868748013050327, 1.9572775474479123, 2.2397091600202748, 1.2290045811283974, 43.03415882971979, 97.34162530591412, 81.87139726454213, 81.71419651277604, 70.29833424475886, 65.40014897623371, 70.41536992596042, 77.66711065846106, 80.30748551891696, 78.43999801143524, 78.22720158484675, 75.50446479551255, 66.62046109476398, 60.00456010141681, 56.51662772701633, 55.23347531595538, 58.95588305688674, 54.488997690139286, 54.0079503674661, 57.4980753467929, 66.9057507668772, 71.60965319602721, 72.02660899008475, 73.00389889747866, 71.20308383818596, 63.88229370117188, 57.169051247258345, 53.24697917507541, 52.92377587287657, 53.257361688921534, 51.785574651533565, 49.83565461251044, 50.798788685952466, 51.25024172567552, 51.087675171513716, 49.689507099889944, 55.33583348797214, 65.30471770994126, 66.53322758213167, 67.95300006866455, 62.75471818062567, 55.52747657222133, 52.86453239379391, 50.04318721832768, 53.04689122784523, 62.06791116345314, 70.493527074014, 63.78590537655739, 70.21115564530896, 62.901383446108916, 70.23954576061618, 49.24108997468026, 42.12732253536102, 68.99158093237108, 56.01171670421478, 61.35455362258419, 56.822862855849735, 58.83949848913378, 50.983473485515965, 54.336339043032744, 55.44823292763003, 56.09565934827251, 56.10432778635333, 56.133682804722945, 51.51731198833835, 51.01527998524328, 49.23029168959587, 50.89436115757112, 46.95690162720219, 46.95205750003938, 47.67472282532723, 48.1260895729065, 49.894953004775516, 49.95478091701385, 48.66429367373067, 53.35196141273745, 52.798644419639345, 58.47492987109769, 67.00849333117085, 65.84201182088545, 65.9908422347038, 69.86395528239589, 59.50905492228847, 50.6555986404419, 52.47580589786653, 52.90416009964482, 62.151516483676055, 73.0573215792256, 71.81657391209757, 70.76061694852768, 70.79296865770894, 73.40244308594735, 72.12886518047702, 74.758633951987, 72.07645447023454, 72.83912797128, 68.55617430902296, 72.40073250186059, 72.13602742841168, 70.9315538406372, 80.97049159388389, 60.31068148151521, 2.399873507599677, 1.1867198372079482, 1.3546600385058312, 0.3268828224991599, 0.9832837793134874, 0.024746919065834056, 2.3670099291109272, 24.129407367398663, 33.22235768841159, 36.996925107894405, 28.841884097745343, 19.38085855976228, 16.510813236236572, 35.18708859720538, 56.957376618539136, 63.53175932361234, 67.04973313116258, 50.78180482310634, 1.5472866570757282, 0.08856946271994422, 0.010503635219778987, 0.07671367752576068, 0.024217573377574166, 0.04004934915311394, 0.03264382616766999, 0.09528205534743686, 0.029772365833782864, 0.09733560765462537, 0.034191074796141155, 0.025146284531201088, 0.06248663187087063, 0.02766406313786584, 0.025131882078224616, 0.01996799173103946, 0.03640803365757869, 0.02350447575501617, 0.08874917162522193, 0.05406020862621166, 0.021085578031958114, 0.07147661620570768, 0.015114806536134454, 0.01262288339691417, 0.019031725035259323, 0.06980295923929061, 0.043137824958971435, 0.055760793583167184, 0.019994906315039244, 0.010980457919950207, 0.04249562494336598, 0.05881390294000026, 0.06093806940160933, 0.14852816148871376, 0.04475556899823489, 0.1091023504493698, 0.35978807617099057, 23.432592422731464, 113.11010253044867, 83.02363272636168, 94.82849213384813, 71.7731846532514, 57.19105574392504, 32.127310383704405, 45.162656537948116, 70.80546532907795, 47.28466272354127, 2.815484909280654, 0.05420835087856939, 0.04757676055775054, 0.7034805837658145, 1.5365114159161046, 3.98283816633686, 3.599490220508268, 1.5680340341021939, 0.5589055125751804, 47.260865703705825, 100.80244233531337, 84.68914170419016, 87.42981941469255, 71.26972490741362, 69.26124388171782, 72.58566441074495, 81.27224737598051, 82.75218117621638, 82.02543658594932, 79.99188377011208, 79.70224811184792, 69.78413504938926, 62.98502014529321, 58.07186318982033, 58.41288974208217, 62.049750589555316, 57.810558811310806, 58.16493318926904, 60.38345321532219, 69.66681695753529, 74.97727471013224, 74.05980879260649, 73.65635379668205, 73.84541988372803, 67.34884523576306, 60.285676371666696, 55.19161578147642, 55.69274956180204, 54.69649891699515, 53.75733052530597, 53.129586558188166, 54.100255504731216, 54.00486738451066, 51.78508043289185, 53.29652263272194, 57.77678328175699, 67.80166718267625, 71.19162267254245, 70.1346851164295, 64.1900154083006, 58.73262566904868, 54.30944727313135, 52.69124600195116, 56.28308588458646, 65.26027333351874, 72.12092630324825, 68.5303415790681, 71.53731684530936, 64.61004241820305, 72.07550525665283, 51.88901147534771, 45.293087113288145, 73.89381408691406, 59.40905409474527, 63.72314353143016, 60.48055933367822, 60.53853980956539, 52.519293215967, 55.87293148040772, 57.21450759518532, 58.38078514222176, 59.17939147641582, 59.14783993074971, 53.907714197712565, 55.38582017344814, 51.651009898031916, 53.39482115161035, 49.59543297367711, 49.952721672673384, 49.68858534289945, 50.43709908762286, 52.63004918252268, 52.00440368344707, 50.630185604095466, 55.654212274859034, 56.04186796372937, 61.98960496533302, 67.69540232996788, 71.16370324165591, 71.38438363229075, 73.2590804561492, 62.27375322772611, 53.31782110275761, 55.62412377326719, 55.78475659893405, 65.48622931203535, 74.65687982497677, 74.20858429324242, 74.60037416027438, 74.05754950738724, 75.50885785010554, 73.58295056127733, 77.36879871737573, 73.98926888742756, 76.93023850840908, 69.6601567729827, 74.57498858051916, 75.85397935682728, 74.58454347425892, 81.51605406115132, 68.08020253335276, 4.578204193422872, 0.12816280186656984, 1.0998667944823544, 1.267598742438901, 1.2786402144739706, 0.09436989743863383, 0.6074464982075076, 20.39754475316694, 44.72150756466774, 35.08092572612148, 31.49086463835932, 21.825887618526338, 26.831000620319, 46.342379969935266, 63.324042366397, 69.73607817003804, 73.08252672995292, 66.9555413338446, 2.9971127115911056, 0.1350140640692365, 0.08587173772074523, 0.04407737434150712, 0.05868478265080241, 0.040918816812336445, 0.06539795367467789, 0.03232671173229333, 0.026422383999752424, 0.06423810804863611, 0.033267107641985344, 0.03949821783950733, 0.06384722317659086, 0.02612063537291702, 0.029766980235675172, 0.051445493084048076, 0.010292153775451646, 0.016015247130135617, 0.08849034115912453, 0.005468139772288381, 0.1432226502126263, 0.1709126224440913, 0.12201135332185416, 0.15802293264817807, 0.09519613858672882, 0.13288885955849003, 0.1494285599478791, 0.18061543244027323, 0.136673916131258, 0.18628691923954796, 0.12330207357844039, 0.1608760279393004, 0.13564217955835406, 0.29911847845200573, 0.24767616463284342, 0.3776784048926446, 0.6491662982490756, 27.84684938769187, 126.20855962076496, 96.09248376661732, 105.6829063354, 87.9375780782392, 61.843873223950794, 35.10134166286838, 67.61551149429815, 76.76036065624606, 63.94866804922781, 3.8693005038845927, 0.174195998678765, 0.127046290003965, 1.9081911685005313, 2.8889146206840395, 8.267129601970796, 11.036711258272971, 8.946628262919765, 3.148534341204551, 51.451012165315696, 103.19357410553964, 88.90754884289157, 91.41071919471987, 75.32821701418969, 72.48352589145784, 77.46658340577157, 84.64508564241471, 89.04351388254474, 84.53647521234329, 84.94946941252678, 81.97182563043411, 73.12055018640334, 67.797085854315, 62.96819317725397, 63.566499756228545, 64.98389920880719, 60.72632328156502, 60.702106568121145, 63.459905424425685, 73.37576312403526, 78.2198118394421, 76.82802154171851, 77.18531024071478, 77.6861184643161, 71.26421789969169, 62.56235730263495, 60.885897067285356, 58.30762117139755, 57.820509864437966, 57.123108525430005, 53.882348229808194, 57.45757295239357, 56.80241946251162, 55.875924248849195, 55.63876598112045, 59.95176499889743, 71.64775509988108, 73.55262279510498, 73.27476993683847, 69.03464855686312, 61.65024542039441, 58.5716280629558, 56.61439672593148, 59.18548291729343, 68.76795876410701, 75.1536480073006, 70.32491222504648, 74.6500470561366, 69.73525447230186, 74.17841342187698, 55.742261640487186, 49.59804919458205, 74.9449622246527, 62.926255195371574, 66.34426347671017, 64.0275743699843, 65.2269959449768, 57.27616725429412, 59.604250846370576, 60.35724393783077, 59.90239020316832, 62.058493552669404, 61.22799834897442, 57.2298401401889, 58.49700889279766, 55.14968956670454, 56.55179569798132, 53.25909929890787, 54.49100594366751, 53.03257457671627, 53.903223083865264, 55.97502293125276, 55.25410698306177, 52.8912829583691, 57.575797111757346, 58.35612912331858, 65.99775345094743, 73.34374873868882, 72.19207809817406, 75.65619776325842, 76.02267265319824, 66.22702383225965, 56.031081445755504, 59.48509316290579, 58.37299923742972, 68.71982343735235, 77.82027921369, 79.58412201173844, 76.71658700512302, 78.0953001206921, 79.15728184484666, 76.63459377904093, 82.28323828789496, 76.35186933702039, 81.3842624233615, 74.390425374431, 77.67402971944502, 77.97345561365928, 76.75992135078677, 88.71912602455386, 69.35737332990094, 2.9726854158986002, 4.761324947880161, 8.5347274234218, 1.407128113412088, 2.700696255891554, 0.19341283928482764, 4.4305897143579305, 32.47616794801528, 52.834569408047585, 50.26859406502017, 37.52897893228839, 27.895824101663408, 25.00161893906132, 51.03574691280242, 72.33708027870425, 82.0227772189725, 82.58730826839324, 76.06965480312225, 2.5035966644364023, 0.2583397714601409, 0.17433853699795662, 0.20998062445752083, 0.10149076130361327, 0.1438624562034684, 0.13316915580822578, 0.1895354078301499, 0.11556600280586751, 0.19029587266906617, 0.14577050543119832, 0.10303121090175645, 0.10533702064065203, 0.15393773814843548, 0.13654815513760815, 0.16035349468790716, 0.15357684944906544, 0.11731845191529683, 0.30185935718397944, 0.12604036293323004], [0.023430670844390992, 0.040404541988766966, 0.040645311932049455, 0.025556484395037257, 0.028555674568539666, 0.02655337545870533, 0.10036922390422515, 0.0413202622064179, 0.02241464290437439, 0.048993107742599906, 0.009928055167678865, 0.0471677462149772, 0.025104490604491967, 0.0379050154268982, 0.08226796819437897, 0.042155585326855226, 0.06910235651077763, 43.394636415666156, 90.35867675658196, 77.3335522990073, 73.44176092455464, 45.36037537359422, 20.19581529401964, 36.348208227465236, 43.25389392914311, 32.91767189579625, 26.547042592879265, 0.9714306218008842, 0.026478781477518143, 0.15796889280599935, 1.3194432830618275, 0.3061797559982346, 2.3519985281652023, 3.993935532146885, 1.9961401459670838, 8.152958231587565, 88.1719083170737, 85.69624946963403, 83.76969106735723, 75.78820120903754, 65.39270431764665, 63.280178500759995, 64.72233987623646, 66.54506529531172, 73.21011358691801, 71.44354081922963, 76.12598003879671, 70.33367480001142, 67.81883931929066, 59.239807744180005, 56.575957498242786, 53.4260275287013, 53.57257512307937, 54.421642749540275, 53.610304401766875, 55.27116537094117, 64.23593067353772, 69.77441541610226, 72.72681482376592, 71.57287705329158, 72.9982977528726, 68.01950777730634, 58.39529398948916, 52.28589257886333, 52.956974814015055, 48.70785943923458, 51.2151365126333, 51.13452396085186, 49.59878267780427, 49.423668461461226, 53.43845359740719, 56.64198275535338, 64.11610226477346, 63.84389761955508, 68.98275559948337, 67.03898583689045, 61.27031287839336, 52.63486977546446, 49.77532855926022, 51.35036022432389, 52.06554558969314, 60.31376446447065, 69.31579620607438, 65.75474300692159, 65.48699025184878, 60.62779726520662, 69.69829005579795, 48.06319436719341, 45.11930258043351, 69.23056310222995, 56.777563402729655, 56.64610124403431, 51.639474207355136, 52.89568778007261, 54.378998741026855, 57.91565479770784, 56.74877712803503, 62.29287870468632, 57.72373322517642, 56.6761112982227, 54.49392810944588, 50.949239038651996, 48.90161668100665, 47.97676101807625, 47.6545226189398, 46.290749811357074, 44.871200899924006, 46.916152123482, 48.670844031918435, 49.962688415281235, 49.25071154871295, 49.787633034490774, 48.2599090760754, 51.50597241617019, 58.397588576039965, 66.62052385268673, 65.95268541766752, 68.83094418433406, 56.05268193829445, 49.534024346259336, 51.27756103392571, 51.63818766993862, 60.29640405408798, 67.38188728209465, 67.69357450546758, 68.95915862052672, 68.79183030897572, 72.40734561797112, 69.77714538574219, 67.19763786562028, 64.29233043424546, 63.51221807541386, 57.6126987703385, 60.08139541072231, 61.348285675048835, 73.70171993009507, 70.38303390625985, 82.19114888098933, 52.86104540671072, 1.2668294675888554, 0.46746032432683055, 1.5537224085100236, 0.5957690506212173, 0.6541212323692538, 0.06341256404055223, 7.865465168030032, 36.07909048757246, 28.393208096104285, 49.23453569412232, 46.67574221088041, 26.852620724708807, 30.017275271877168, 49.37062232725082, 57.253307680929865, 59.301130079454, 60.478060783878455, 20.33368072202129, 0.2889829513526732, 0.04073322818223988, 0.025474294652080825, 0.009622702097159722, 0.02306468766032448, 0.03364777673156031, 0.06857251478058678, 0.06673390376231363, 0.05129907069908035, 0.09183350289540906, 0.05619796165715783, 0.032812993703109604, 0.01398071678610699, 0.04504926795620592, 0.039082925406194506, 0.05566033264321666, 0.03755446125362669, 0.011159469685216826, 0.04988853812157627, 0.0464368217264212, 0.06278723328103943, 0.03348948764464548, 0.050750524932218176, 0.0530416832395619, 0.05536771003877925, 0.04897620401255066, 0.006993122055240337, 0.06994691482114215, 0.03319398838005239, 0.024609061543859785, 0.034276148860132506, 0.08718473581416954, 0.0068204266849094105, 0.022553000298719254, 0.01570793383214022, 0.027364181850345868, 54.23002319951212, 100.48079229170277, 85.17620594270768, 82.89794429655998, 57.88231072887298, 30.248224427623136, 32.93993134652415, 40.92047983600248, 40.603571937930205, 33.495586072244954, 0.6595653595943606, 0.020435062131934592, 0.4087366205790351, 1.3692908469707736, 1.931451068770501, 7.113847847907775, 10.008268740869338, 0.891770041517673, 10.551443465294378, 93.81423780995031, 89.10538534964286, 87.49339319044545, 78.87151364357241, 68.18414534291914, 65.23141253379085, 68.4457282097109, 70.74624538421631, 76.43691416709655, 75.00133452876922, 80.57299860062139, 72.95818759549049, 71.12421281876104, 62.140765267033736, 59.408622634026315, 56.86677378992881, 56.90080427354383, 57.08236686645016, 57.21218947441348, 57.848393993992964, 68.44485744353264, 73.27740576959425, 73.66463784248599, 74.4130652950656, 74.51118730729627, 70.43941405511671, 60.09811647476689, 54.73220033030356, 54.434484589484434, 52.58551459158621, 53.942874323937204, 52.560034874946844, 53.007341969397764, 53.40447802697459, 54.565715328339614, 60.35540826859013, 66.3112606540803, 68.53135355057256, 71.93801833737281, 67.62643137285787, 63.87462938985517, 53.86976526629541, 51.308245735783736, 53.38482303004111, 52.94868684584095, 64.18453585716986, 71.90491353311847, 67.42191899207332, 68.58974979769799, 64.41577526830858, 70.52744773126417, 50.27224186928042, 48.184364226556596, 72.16271523506411, 60.972448087507686, 58.98177070002402, 54.68539860940749, 57.40175370247134, 57.595306980994444, 61.68424844741822, 58.74050178835469, 64.8518761511772, 59.85009324166083, 59.352320932572894, 55.99428961353918, 53.694474543294604, 52.347842493364894, 50.58912623313166, 51.333741141903786, 48.874779824287664, 48.24287030004686, 49.71374734755486, 51.62517324570687, 52.32517511613908, 52.19341877968081, 52.57699912594211, 50.64716554457142, 52.700036033507324, 60.13654393534507, 68.76655455558532, 70.0532017984698, 70.93971237059563, 59.68871516566123, 52.66106728584536, 53.532500267028816, 54.89372353399954, 63.080541626099624, 70.68901015866187, 71.17728248719247, 72.94770702239006, 71.18979484804215, 74.84078407287598, 72.15290146489298, 69.84539462674049, 67.47554563706922, 65.02720217550954, 59.95729161847023, 61.98843609902167, 63.6443470370385, 75.5237393225393, 74.3483304977417, 82.98669968881916, 61.989526517929576, 2.3236138061169656, 0.7641650435905304, 1.5794413897298998, 0.8997293273287436, 0.4937558326750033, 0.08213953355387335, 2.791172097767553, 44.68768496667185, 35.613834627213016, 42.8470931514617, 36.506954393079205, 28.677454417751683, 42.260451701379594, 55.99544671274001, 64.5822367360515, 65.58039757513231, 70.84494790723248, 34.16398148382864, 0.3892581303033137, 0.0410962236234017, 0.028763332276514945, 0.02282082655226752, 0.037976652308697664, 0.0062879912682899065, 0.10978809873303098, 0.011763987751046737, 0.05999331062118854, 0.05229550594043347, 0.013094448818705015, 0.024323829772671866, 0.017556279912711154, 0.01808755614254023, 0.008015300244874051, 0.009220278983364904, 0.045073698500111226, 0.07496312065350433, 0.05086952903037591, 0.10805408169905986, 0.18253678095436868, 0.20255766148048066, 0.13463624482673986, 0.12910104506919462, 0.1409467562071739, 0.12339686929819085, 0.05243973348349814, 0.1405416182692974, 0.2570407468104555, 0.14641300805153387, 0.16872567124664786, 0.25193806497320054, 0.1495730441303984, 0.24564515829326647, 0.13813856899017288, 0.10183892528256101, 66.32453395474342, 113.05202791767736, 98.88665476152974, 93.05181534059587, 64.6781857552067, 31.814009105005574, 50.69261404775804, 62.311917889502745, 52.57857591875138, 43.013346733585486, 1.4798104907235792, 0.12430534998495733, 0.6337985132009752, 3.231626811527437, 3.526710151664673, 6.925636347263091, 8.985577398730863, 7.741039741423823, 10.724311144121232, 99.45764987699448, 90.29835854807209, 91.83424888118621, 82.33000078508931, 71.61666639389531, 69.29798864549207, 72.0754268092494, 73.06769232596122, 79.89092980661701, 77.51025507527014, 84.53063872552688, 76.15921820363691, 75.87835296507805, 65.3790936931487, 63.05341059161771, 59.07086341611801, 58.63465270688457, 60.94675656287902, 60.12067010325771, 61.65904721906109, 70.71349359327748, 77.56778055621733, 77.57479375408542, 75.55658525036228, 77.59300139642532, 75.29170759262578, 63.138663307313, 58.21232718806113, 57.0735336888221, 54.47258257096814, 56.40938228176486, 55.23333803299935, 55.801846365774836, 56.01299147452078, 58.77195135239632, 61.78647718121929, 70.9175588238624, 70.4879023951869, 75.51491398965159, 72.1901169130879, 67.01176458789458, 57.33541857811713, 54.24162164811165, 55.81419006470711, 55.493881471695445, 68.54059465469854, 75.63768417604508, 71.72091514833512, 70.59532826946628, 66.03569061525407, 73.64357471466064, 50.907257910697695, 51.96601936894079, 75.1288115593695, 64.45797604899253, 61.93867691101567, 58.549839296648585, 59.635963209213756, 58.95114091134841, 67.01388266778761, 62.58137687560051, 67.15377792235344, 64.22148066182291, 63.19766752181515, 59.841365968027425, 56.583398234459665, 54.2577818132216, 53.63149304543772, 53.60100446208831, 51.37403957305416, 51.29350939104634, 53.76342196618357, 55.68123740534629, 53.124063860985544, 55.407652085827245, 55.142095858050936, 53.488985492337136, 56.24723934358167, 64.94066292239775, 72.03772498715308, 73.2078464569584, 75.30938963736259, 63.05348903902116, 54.53662310877154, 57.18824732688166, 58.120092653459125, 65.2720522111462, 73.82230927867275, 74.33877560400194, 75.51290573612337, 75.83292407374229, 80.50834225070092, 77.01987251158684, 72.6804445635888, 70.66734298583, 69.92333212206441, 64.14886190045264, 66.41015929560508, 68.22678150669222, 79.36995275558965, 77.12283472861014, 88.11399844384964, 60.93092195449337, 1.623559841705907, 4.8070592937930945, 7.227179831074131, 2.004759676994816, 1.4293938154174437, 0.10811641827345857, 12.383032460366527, 55.06324837284704, 44.0515039813134, 63.269446895968535, 61.82249630651167, 35.374491599298295, 42.678697955223825, 67.35214002670781, 75.46846528207102, 76.81288119285338, 84.95561184421663, 37.47692123536141, 0.6532812935690726, 0.15230161949030815, 0.1518548216911093, 0.12874400213120446, 0.18927751199132015, 0.09155696813738154, 0.24368195073498836, 0.22002731600115377, 0.15033147117543608, 0.2664525812912372, 0.14649669549638225, 0.15681337174629012, 0.1467490142151233, 0.157761620057206, 0.10666227614086483, 0.14593627153625413, 0.17618068734243994, 0.11115259325672543, 0.14421712426889327], [0.029786073061968052, 0.04970586062559197, 0.01609120762065774, 0.09037886280566455, 0.08750734309996329, 0.07602187714749768, 0.021125847443697915, 0.03425621908278235, 0.024903804296627644, 0.04797160993480394, 0.0631330377091804, 0.009278198103270224, 0.06042050039996544, 0.06645602068953937, 0.08524412018877846, 0.20075927007823222, 4.090864653548887, 79.39532264586418, 81.22612814749442, 76.80871563573038, 55.70374396539504, 30.137686152612012, 19.65338876170497, 59.80963791570356, 48.7773952176494, 44.688834221132346, 7.104877387323688, 0.701726426280314, 0.24583787537149845, 0.32778248551391787, 0.6805502851643871, 0.6260409843056434, 5.7189961402646965, 4.647933148568677, 0.9734181603116374, 46.71551504442769, 91.63841278322282, 82.48673869717507, 82.42176071290048, 68.9546557395689, 63.95421820302164, 61.43112221071797, 57.0131213434281, 55.83713593021516, 59.32724914243145, 61.57468095902474, 62.805575632279925, 62.7891722802193, 59.12233275751914, 54.48216099892893, 52.508079159644346, 54.05767033177038, 56.53072864778581, 54.58867296095818, 53.065032189892186, 53.637690390309984, 57.847464392262125, 69.16515365723642, 70.28328018803751, 70.12632262322211, 74.03473700246504, 67.80988062581709, 57.638413829188195, 51.06436060320947, 50.9510943197435, 51.23019841409499, 51.788571342345215, 51.84405719080279, 52.36235918537263, 59.38950107943628, 63.51287703360281, 62.40000255646245, 66.60868613950669, 69.13159385804208, 69.84682236948322, 62.29032916407432, 55.84644371463407, 50.6106286664163, 50.08043012311382, 48.09974301245905, 51.29700422286988, 54.28662692346881, 65.67221241612589, 64.61610640248945, 67.29520290128647, 61.312164568131976, 73.39251948941138, 53.25027396602016, 49.05636595141504, 68.9906866319718, 54.5087742805481, 54.4757479236972, 51.7514657205151, 60.27871808698101, 59.08721969973657, 59.51114554559032, 58.63804163471345, 58.60397192739672, 55.45909397063717, 54.13827896118165, 52.736314035231075, 49.507226713242076, 48.823075140676195, 47.71968495461249, 48.22085403626966, 45.70207657352571, 46.685355940172755, 44.339280436115885, 46.971661506160615, 48.25624165996429, 49.34836287652293, 47.580954643987845, 50.446202908792806, 50.528494235008, 53.61060250189997, 61.081384074303415, 62.75432594360844, 62.74688128502139, 56.08400206412039, 48.28656550376646, 51.67090023717573, 50.7826598998039, 59.83504702967983, 61.77476106151458, 64.41385722929432, 65.8323000323388, 65.50644913027364, 65.69890806751867, 64.0121163091352, 59.640760267934496, 58.575440606763294, 53.464439299798784, 58.48805804406443, 57.449473257987734, 61.36252387877434, 57.965574802890906, 73.31619016585812, 71.5995099467616, 80.28916805021225, 25.618947052186538, 0.13028773058566356, 1.5263893719642394, 0.6965481622084495, 0.2812956267547223, 0.24964712500091524, 0.34238225209616846, 39.995577104630016, 48.023448990237334, 40.08335974908645, 66.12723089033558, 25.35932537048094, 20.302462577819824, 34.12718572924214, 51.03948493157664, 63.177400635134795, 57.518659945457216, 63.10582522423037, 7.1352272168282544, 0.2806640332264285, 0.038778401625853394, 0.07273661633653027, 0.04390207044179401, 0.04754337061557078, 0.02430435773285647, 0.03958108940071637, 0.06678504779213859, 0.09035791796181472, 0.05673282892413198, 0.00675007252157816, 0.029944743277625214, 0.02879549073235643, 0.05419572191913763, 0.06555163091228855, 0.08162810091650294, 0.01932247455472187, 0.01749167188761696, 0.028349309633936615, 0.030807461702234806, 0.05386916161965459, 0.03688883426929674, 0.05311346567806698, 0.041182657493458646, 0.10594220711819588, 0.03774638160041744, 0.012324674096288941, 0.08176061880564497, 0.024976000422611836, 0.0627652159140956, 0.08973871973613579, 0.056099879420212204, 0.06857522673183872, 0.2332876391348339, 6.366701539485685, 93.15684856907015, 90.89454312478343, 86.13819860642957, 63.280319706086196, 45.49171593881423, 32.126365092492875, 45.2991001067623, 41.32438590449672, 52.1925558582429, 8.556373023217725, 0.47918811921150456, 0.3074122076073001, 1.499300380387614, 2.2153198622888137, 2.23651978277391, 3.7780002288279997, 0.7087826476462427, 0.42242471188787495, 48.73087982977591, 95.21464947731265, 84.47785146774785, 87.78695906362226, 71.81722502554618, 67.59457388231831, 64.34279957125264, 61.58216876368369, 57.132145666307025, 64.5370824106278, 65.16161787894465, 66.40367954008042, 66.18892192840576, 63.056666158860736, 57.13917847602599, 56.52024022994503, 56.54639067188386, 59.24631495629588, 56.7734762930101, 55.05187349934732, 54.665657320330226, 61.35653834189139, 70.94451335168654, 73.19256490276706, 72.97338285753804, 76.31496767843925, 69.57409212666174, 60.8322782670298, 53.80216321637554, 53.63517615102953, 52.46537239320817, 55.41095472151234, 53.03983096153506, 55.900239021547385, 61.125667633548865, 65.93088488424978, 65.60063308285129, 69.09080120824999, 71.14541715191257, 71.83363622234714, 63.19804014698152, 59.176783100251235, 53.49074271417434, 52.369572424119525, 51.20385185364754, 53.01444930415, 57.260344413019, 68.32808063876244, 64.54815133925408, 69.18605204551451, 65.12411609772714, 74.48711964391893, 54.813130594068966, 52.885466083403564, 70.94028503664079, 59.032373197617076, 57.92030672873221, 56.47330122609293, 62.51397486655944, 61.00829855088265, 62.24400597233927, 62.7185853065983, 60.86879161096389, 58.285110688978634, 58.1064231934086, 56.14605396024643, 51.6040434375886, 51.367508826717255, 50.90792471362699, 50.857938028151, 49.44726544041788, 50.249307770882886, 47.46033783881895, 49.058189853545166, 49.77425775220318, 51.39946437651112, 50.43470644181775, 51.51828865851126, 53.01482192931637, 55.85579856749504, 63.9156573818576, 65.82698914312547, 65.24726675402734, 57.92648838412378, 52.19324227302305, 54.65010904496717, 53.54378100364439, 63.70255501039567, 64.80752591163882, 68.65290780221262, 68.2892099503548, 69.43301231630387, 68.4740634118357, 67.13882584725657, 60.8708587000447, 60.54880857467652, 55.97951796747024, 61.365869660531324, 60.15219419233261, 65.16801918706587, 61.10196867296773, 73.6962599908152, 73.90325130954866, 84.40473064299553, 29.914301287743356, 0.32723804214789026, 1.362169538774798, 1.1114520050825611, 0.7826705409153816, 0.1500133914692748, 0.3561337448416218, 36.193141245072894, 58.66131305694581, 39.003197839183194, 53.48275284613333, 24.105804504886752, 32.9377701205592, 44.96439641521823, 59.089694715315304, 70.47352298613518, 66.61364401540449, 78.66683652324062, 15.685155295556592, 0.3983054754714812, 0.07808417051790223, 0.007516720168848312, 0.06658145992626106, 0.10210845033608137, 0.028415465156637856, 0.05585505304137065, 0.06864084982343259, 0.0339332364139057, 0.13509082607924938, 0.07076505841987749, 0.031138882829597404, 0.030600744367186582, 0.020593412505883365, 0.0888464188263301, 0.09042060693665858, 0.0021758012665105205, 0.03861988271256128, 0.11400369671924461, 0.1504690758883953, 0.1304635784078029, 0.16932594710059706, 0.22121649896425588, 0.12367898883718638, 0.15342010785975765, 0.1142549352540124, 0.08250984513471205, 0.12590019182572443, 0.21679194283581552, 0.11296018537494446, 0.15605146666207623, 0.24799790623928272, 0.2879456070161635, 0.43130213875443707, 8.879383148685578, 105.54182652504214, 101.14267656880041, 98.75142712746897, 73.91049200488676, 46.62959552580311, 31.09363836626853, 87.82626121274888, 69.31215624655448, 67.07444406324818, 12.227860554572075, 0.9269852034987943, 0.6605851145521288, 1.9594310512465818, 4.945633199907118, 4.449068980832254, 15.37220604958073, 14.211465908635049, 1.505191535238297, 55.045864428243334, 96.1840005074778, 90.76896452134656, 90.22484548630254, 75.72515303088774, 70.72045972270351, 68.19476712134578, 64.88215684890747, 61.09674407589821, 68.55411898705268, 69.49006711283039, 69.92589735215711, 71.20299754604217, 65.74201099334225, 60.099214738415135, 59.09421328575381, 60.402272747408965, 63.64584538244433, 59.76458164953417, 56.565837783198205, 59.389599138690585, 66.39474438082787, 74.78531391389909, 76.54277893804735, 78.08359576809791, 78.88966637272989, 75.15851959105461, 65.4413495525237, 55.9134417195474, 55.945738515546246, 56.02944973976382, 57.62118677939139, 57.01249376420052, 59.07298149601106, 64.15351383147701, 70.58912307985368, 68.277309479252, 71.3558993800994, 75.42222053773942, 75.49061098406392, 68.93333373531219, 61.19694102195002, 56.218170658234634, 55.4075030357607, 53.307583716607866, 53.964051200497536, 59.84065994139641, 72.51113937747094, 68.93001541014641, 71.65662750121086, 67.71861491664764, 77.89275676973405, 58.37064189295615, 57.17893954246276, 73.98686055214175, 61.25921649317588, 60.88175504438339, 57.626936974064, 66.50597495417442, 66.29945431986164, 64.937140633983, 63.60164419297249, 64.17839342548002, 61.68919847857568, 59.64592602945144, 59.00839182638354, 54.12909669260825, 53.745018205335064, 55.48152600565265, 53.15551342502717, 52.88422661442911, 53.43062454654325, 49.66006578937654, 52.92260700656522, 52.4115849310352, 55.43999202789799, 52.688629781046224, 55.23383225164106, 57.3890648349639, 57.62949435941635, 66.83653662281652, 68.39042279028124, 69.54294066275321, 61.801958776289425, 53.31240823191982, 57.47204649832941, 56.52147185417914, 66.10028420725178, 68.08410136930405, 71.42008504559918, 72.32512489441903, 73.12655925750732, 71.80246906895792, 70.06132894946684, 63.42756940472511, 65.63867615115258, 60.40363380985876, 64.24410097060665, 63.095140687880985, 67.06768189707111, 63.47435935851067, 79.51803007433492, 78.17923099763932, 87.2094371241908, 29.974627340993575, 1.140470067339559, 8.81143298841292, 2.7197660842249474, 0.8582010492682458, 0.43319137286274667, 1.6551985375342833, 50.671696047629084, 67.03001929867652, 56.48904169759443, 86.06258315424766, 37.4211843552128, 29.755592384646018, 49.86608436030727, 66.1208531164354, 80.47739475004136, 74.72177936184791, 90.46351386654763, 15.207989158168917, 0.4408010774322095, 0.29184827340706704, 0.183781597222532, 0.2784123169558664, 0.1539144184320204, 0.128549124685026, 0.15715322367125945, 0.10247156069043184, 0.15215822315264135, 0.2116791946032355, 0.18547753202578715, 0.10538078724376618, 0.11146074446338801, 0.17828228102336008, 0.25706926060299723, 0.2471784066649214, 0.14629590385142835, 0.13906714416319324], [0.027366924445114793, 0.02660242806849701, 0.011546544227448684, 0.026739190084739562, 0.015043313295820789, 0.01496124038127281, 0.051067267814951564, 0.04594980814163724, 0.04688169664493011, 0.0371809818992211, 0.02828865079209209, 0.02895771559598225, 0.05244144569000891, 0.01021461801663522, 0.030198929335681662, 0.22920486547293203, 31.318239165890603, 85.20749076720207, 70.2697087872413, 75.97416862364739, 62.76675593468451, 26.05850354317696, 25.754078588178082, 51.64846820216025, 42.102635137496456, 29.31664974458756, 1.5366071462631228, 0.13029660188382672, 0.36253355143050997, 0.8654995995663828, 0.3287902588565504, 1.8888776629201829, 9.977794866408072, 9.433484615818147, 4.317661735319323, 90.87976363397415, 80.49250371994512, 84.04771650991133, 70.84302594584804, 68.19056234052105, 59.40195852710355, 63.084358092277284, 58.687239923784816, 58.722968793684444, 54.35398186406782, 54.87789677035425, 53.80073939600299, 54.85586481709635, 54.38527453330256, 55.236091536860314, 51.21954525670698, 54.47810134580059, 51.89672677747665, 55.43099018835253, 51.90204158906014, 52.49372328481367, 52.07190375174246, 67.03922117910078, 67.75372012968987, 70.53445308439194, 70.20482493985084, 69.95153396360337, 56.56480619984289, 50.94732884437808, 50.974930563280665, 50.57070286043229, 49.207079102916104, 56.1703569658341, 63.25360444284255, 65.6641048769797, 65.33079754921698, 68.16258015171175, 67.19245249225249, 66.15332249672183, 63.55181440230339, 55.92269851315407, 52.35053716167327, 49.207094792396795, 49.02406131067584, 48.25311553093695, 49.16350941504202, 51.0017321186681, 62.53445748359927, 62.07432816105505, 65.02076556605678, 61.180796546320764, 66.43756881836923, 58.05327899994389, 52.450373249669234, 67.81684675524312, 51.261679357098, 53.0287031973562, 56.34674203011298, 59.64232137126308, 57.834681387870546, 57.60445787060646, 56.112043088482274, 55.11385479281026, 50.90498293599775, 53.58806064051967, 50.861903544395204, 50.58529015510313, 46.59814988413165, 47.8525120981278, 45.5191921418713, 47.10814037630635, 44.44788302144697, 45.527868424692464, 43.83085104726976, 45.93904656748618, 47.71260899882163, 49.9705292332557, 48.87027302095967, 50.01014517199609, 51.4201666462806, 57.93430174550703, 59.10336025299565, 57.87505042168402, 52.384638247951386, 49.7912416150493, 52.509969742067405, 52.860684548654866, 59.290775022199085, 65.87608937294253, 65.1308939533849, 63.27875860275761, 61.50456074745425, 59.20352189771591, 57.37019038969471, 56.15349861883349, 53.28899168199109, 58.378686674179576, 59.75665846178609, 64.10866152855658, 67.60349335209017, 69.38191167769894, 68.41468657216718, 72.25507136314147, 78.64967223136657, 55.43578724707327, 1.4267598212726655, 0.7227933539017555, 1.367227189963864, 0.08987876060869425, 0.12088420815886029, 0.10798377781024865, 7.024852700771825, 68.20993884917229, 38.89295178074991, 46.215746248922045, 38.59014088107694, 21.4788951412324, 25.254796166573804, 57.50693205864199, 71.41849256330921, 70.98297611359628, 62.899014334524836, 57.51229393866755, 3.070667938840005, 0.10086688228071698, 0.09236611020300659, 0.03196973008133712, 0.053196475135102395, 0.08328832836160738, 0.04530458590917049, 0.08761657957708643, 0.042742561894438924, 0.03212613650717803, 0.039455899142570076, 0.0542444144676049, 0.026681354276896007, 0.04974474341818883, 0.09118671018269756, 0.026601945433104714, 0.04926418029372731, 0.026869758280114304, 0.022708523808227434, 0.06367712484432325, 0.03293278687182934, 0.06248655143163859, 0.02500239981248254, 0.03247267063406687, 0.0584028278207106, 0.014849078405888812, 0.03694458248754663, 0.10243269705003309, 0.02170144952082586, 0.03531373068389874, 0.09063524179040425, 0.05868677830984516, 0.04737387366232373, 0.13143657135867304, 42.66023143645256, 98.90456430373654, 77.81353273699361, 82.43742665936871, 73.26841569715931, 41.58778482867826, 30.274769067764286, 50.9865996145433, 48.09195318529683, 39.2892994419221, 2.089197765434942, 0.08332644123584033, 1.1065475714783515, 1.9208645916754201, 2.1140312715884177, 2.4960110456712785, 5.976407566378194, 2.8249456661362804, 6.613938337372196, 94.56102571179791, 86.03240443814187, 88.72664128580402, 74.7135502292264, 71.33060793722831, 62.53953303060224, 66.10070782323038, 60.67113553324054, 62.38827859201739, 59.17889333540394, 55.74287745260424, 57.619802182720555, 58.899055757830226, 56.40421259787775, 59.26584051501367, 55.397147978505785, 58.25570860216695, 55.763677781628026, 58.08624652124221, 53.84596040171962, 55.491477058779815, 55.684410602815696, 69.86237064484628, 72.38659627975957, 73.50782932773714, 72.77466773986816, 72.90969925542032, 58.0052613442944, 53.351153404481956, 51.58662811402352, 54.233204241721864, 52.50703973154868, 57.30699316147835, 66.46591970997473, 68.0291489631899, 68.06892964147752, 73.02034931798136, 69.46403041962655, 70.71729829234462, 65.39673259181362, 58.81496798607611, 55.09373695619645, 51.11239394833965, 50.26567974398213, 48.70072857026131, 51.370838918993556, 53.01419827245897, 65.9364075814524, 64.47395970744472, 66.20730999977359, 62.86133604664957, 68.12535685877647, 59.807739488540165, 56.08758318808771, 71.89407994670253, 54.47243352090159, 56.168536986074145, 58.979911496562345, 61.01961458882978, 60.14498487595589, 60.26313843265657, 59.060371075907064, 58.04030379941387, 53.81310270678613, 55.522659901649725, 54.240441014689786, 53.43267594614337, 49.36370718863703, 49.05342809615597, 49.051129587234996, 50.734269618988044, 48.04061328211139, 47.895764074017926, 47.145249920506636, 48.65455442859281, 50.65865416680613, 52.0361513476218, 50.392219328111224, 52.37854288470361, 53.213364462698664, 59.76604861597861, 61.71382704088765, 61.202844189059356, 53.6358037302571, 51.47778626411192, 53.74512803169989, 54.62334671328145, 61.29743214576476, 67.87313276721586, 67.93821273311492, 67.40877905199605, 64.18344936063214, 61.50680434319281, 58.69202521539504, 58.79111997542843, 57.63799021320959, 60.23762733705583, 60.89542842680409, 66.9205145682058, 69.34413140819919, 71.42252475984635, 70.76479819513136, 73.08140493208363, 82.32683150999009, 60.220639551839525, 2.011949626668807, 1.539399506103608, 3.3477225947764615, 1.4811732692103234, 0.25718757522202307, 0.20642684982909312, 5.275867840936107, 73.22483031980454, 41.29150075297202, 39.91159915924072, 28.855531984759917, 23.471478800619803, 42.22991997195829, 68.308790422255, 77.86439803338821, 76.99196092544064, 67.98459083803239, 74.18300259497859, 5.686012929485691, 0.16011498087356169, 0.05514364847312531, 0.06398339913557134, 0.053296043582621126, 0.030954269046384483, 0.011477003553732028, 0.07747650957636296, 0.04576989239261997, 0.030179206402071064, 0.04239250950875782, 0.01707641775870035, 0.01798141466063117, 0.0118928772562574, 0.05218116731773462, 0.03897317948060171, 0.07497278102222951, 0.06989712676694317, 0.16708305616292263, 0.1257870406393082, 0.1772804678447785, 0.09933210939409272, 0.1046836548935502, 0.13845721560139812, 0.1410544834910862, 0.12752746982920554, 0.10388464051028413, 0.21088710565480495, 0.13368312419662554, 0.1195848311087297, 0.12047277297824623, 0.1606803537616807, 0.2302000749736063, 0.2746909376113646, 51.820130732751664, 110.10375484343498, 88.48379165895524, 93.7709976011707, 83.56662996353643, 39.14978857963316, 37.80663174967612, 73.80761608000725, 63.702888411860314, 51.595386766618304, 3.0461617054477816, 0.34882443866902785, 1.6141486047737061, 2.7227833674800013, 4.62265053103047, 5.068136174832621, 22.61265427835526, 19.766641316875337, 6.455553029814075, 100.97880778774139, 85.75044093593475, 93.87933346533006, 76.96903074941328, 75.12161008773312, 65.25289535522461, 67.33572098516649, 64.54367591488746, 66.4067154545938, 64.45326528241559, 61.30144080808086, 62.78828974693053, 62.74622232683244, 58.99446741227181, 63.099867143938624, 57.157837190935695, 62.82933342841364, 59.11333091797368, 62.66351130700881, 55.704504905208466, 58.87139128100488, 57.65406408617574, 72.91897173850768, 74.05057553322085, 75.52435121228619, 74.671157252404, 78.18917812839632, 62.99692453876619, 56.672730215134166, 55.18520270624469, 57.915391998906294, 54.68302557545324, 61.96889485082319, 68.40426091224917, 72.74667770631852, 71.26732441686815, 74.92621329522903, 72.43428445631459, 72.3796772187756, 69.09336643834268, 63.76427350505706, 57.830064758177734, 54.45053885059973, 53.61318342147335, 51.601807686590384, 54.68663415601177, 56.4206551736401, 67.02193137138121, 67.40965766291465, 69.812878178012, 66.55891126201999, 68.85560804797758, 62.54980571808354, 58.793496931752856, 73.66937606565415, 56.209435539860884, 59.492114205514234, 60.498759131277765, 64.85459043133643, 63.194655141522816, 63.34046925267866, 63.86679249425089, 62.02421595973354, 56.24827877167733, 58.69673205960182, 56.51788680784164, 56.61197662353516, 52.232030591657086, 51.604031670478086, 51.55332719126056, 52.94152852027647, 49.8568707127725, 51.84150765019079, 48.874528792596635, 53.86354046483194, 52.87629950431086, 55.95849014097645, 54.065366022048465, 55.710749318522794, 56.85225709792107, 63.71309441904869, 65.53142286116078, 63.833134635802246, 59.36459795121224, 55.03896497911023, 57.204835030340384, 59.108090631423465, 65.41989811005132, 71.76263347748788, 71.54949188232422, 70.71820043748426, 67.16373289785078, 64.98369916792839, 63.65212117472003, 61.972217098359145, 60.956766451558764, 63.39763779794017, 65.68203795340754, 70.23774147033691, 74.29899492571431, 74.24006523624544, 74.51186979970625, 77.34621370992353, 84.34580095352666, 61.69149306512649, 1.9756811857223513, 3.416172612097956, 7.478733197335274, 1.783258040105143, 0.44872500062469517, 0.19699816141397725, 8.98657956430989, 85.155134970142, 52.44892197270548, 61.916472373470185, 51.74667258416453, 28.48268520447516, 39.233354676154356, 73.79890841822471, 88.56877373110864, 88.2446055258474, 78.1776620495704, 80.32379473409345, 5.269842099758887, 0.28003844582746107, 0.1680479285817954, 0.09653783433379666, 0.17408522236491406, 0.26559364351053394, 0.14452763502636265, 0.21146588508159886, 0.2156716618206232, 0.09819723440394287, 0.1552924573902161, 0.13914644958511477, 0.12766006432714003, 0.1292904832911107, 0.20239413235216372, 0.10709894625770469, 0.2332894624240937, 0.16543431237580317], [0.009941562255393836, 0.03141183612657891, 0.05402099258536774, 0.041451466254769795, 0.026736660079369624, 0.025356186876794504, 0.05964749470172871, 0.11537263455289988, 0.051577972668793895, 0.019864949074784116, 0.024161419132724408, 0.0641722627915442, 0.043644151620326505, 0.05166016624218995, 0.03305543754850665, 0.872283706501607, 70.07895608102122, 81.70419446883663, 72.17944022147887, 50.580434260829804, 28.829485485630652, 27.279382444197132, 59.189852437665394, 46.38001903410881, 34.272729196856105, 19.498272749685473, 0.49942427044433935, 0.07786067202687263, 0.6789791920492727, 0.9345660418752701, 1.036842395701716, 1.6854820544681244, 0.923243997798812, 1.0680947380681192, 43.25975787255072, 95.33518391270792, 77.20118799517232, 82.83077762972924, 65.71928870293402, 62.37188308469711, 61.106483321036066, 58.99600105900919, 57.09814263928322, 55.07601568775793, 55.934042007692405, 56.007190289035925, 51.67838804183468, 55.45823497156943, 52.30524555329354, 54.820179093268614, 52.621074799568426, 52.30175072147001, 52.275780708559104, 53.7390483579328, 51.475938827760764, 51.152323676693825, 53.101796565517304, 63.46940148261286, 70.3723729041315, 69.24618982499646, 67.91476480422482, 65.32294888650218, 54.284371560619725, 50.46997247203704, 51.31985987386396, 47.50566867090041, 52.706880569458015, 64.32640014156219, 65.38049005693006, 67.40364074707031, 64.8272515112354, 64.76570952323176, 62.30805043251284, 64.54567240130517, 58.201960363695704, 53.41085972324495, 48.49063073435138, 48.221481615497225, 47.417434953874164, 49.06838017125284, 47.9308771318005, 47.76151311013007, 56.61303958585186, 62.1858686016452, 60.6950580689215, 58.57946103618991, 65.65823308883175, 57.8776744873293, 55.35721825015161, 66.69647662870346, 51.17954100331953, 53.295961733787294, 56.18150041949365, 59.35799267984206, 58.49162740092124, 57.02915991506269, 50.6934848139363, 50.49642101410897, 47.08273518470026, 48.12346942963139, 45.40333317172143, 47.35277075921336, 46.406345982705396, 47.23733932741227, 45.81265995579381, 47.53483149313158, 46.90598926236553, 46.42813082664244, 45.54575443267823, 44.82232424520677, 46.038443350022845, 47.30154068239274, 47.85614029053719, 51.00492885035854, 49.6024344044347, 50.59382523259809, 53.89432714831445, 54.216032105107466, 51.49919456051242, 51.24924936602193, 48.79136670020319, 50.79394848115983, 52.41240470640121, 63.87878710223783, 64.28899641959899, 67.78521676217356, 61.436982231755415, 58.86266400737148, 52.947843536253906, 55.6446809153403, 55.69120022558398, 60.13108791843538, 61.89649574218258, 68.56019866081976, 68.29295973623952, 71.28583015934115, 69.97057314841979, 74.38225115499189, 71.89704525855281, 70.6778000247094, 8.143683787315123, 0.30183772286099775, 0.5947635142553238, 1.1936912373189004, 0.10011826882198935, 0.2171137304075303, 0.06640308401397159, 34.26728102468675, 64.06324832670151, 31.5501336128481, 62.13096718634329, 45.76384998136952, 14.129368739743388, 33.77413711240215, 60.86050364278979, 60.12821282109907, 57.922828812753, 65.48091842282203, 31.48615583296745, 1.3511612843121252, 0.02316309931507755, 0.120933230125135, 0.006183640995708805, 0.006449355240610819, 0.010578692684160366, 0.06101714116671394, 0.018289311143058925, 0.014524169983492504, 0.005914642627636392, 0.08575722289782378, 0.011652153278250369, 0.052855569839237206, 0.01647163347731675, 0.051571832474080787, 0.03923465295003788, 0.02242909706828575, 0.04147400456150213, 0.019317496898433855, 0.07396981871176152, 0.08969165129406799, 0.04442369970943659, 0.014308534427395752, 0.002055867329134696, 0.035858093610694336, 0.03137941337040356, 0.03318933439591239, 0.020005367245645295, 0.028667441051032756, 0.029696873614504456, 0.03616994885247081, 0.04033707262527558, 1.3104822606809678, 85.23823430461269, 89.4804580750004, 81.16736319757278, 58.27447322107131, 41.828488919042776, 29.096418465337447, 40.24796985810803, 40.30315760643252, 43.85125129453598, 27.49136301778978, 0.30954729465226977, 0.1083107517972108, 1.387014689464723, 1.822141476215855, 3.0676030968466117, 3.196732180733835, 1.1496343175249717, 0.5122580817870556, 46.90411829179334, 100.13790653597925, 81.23019172299294, 85.84532307040307, 71.06056059560468, 68.25128847552885, 64.4376346372789, 61.95645701500678, 61.01047154395812, 59.849728461234804, 59.57992822893205, 60.45505608281782, 56.154310549459154, 57.6469567514235, 56.656189580117505, 57.52275882228729, 56.05541190793438, 56.37513606779037, 54.832797358112956, 57.27945027812835, 53.386666544022106, 52.29845200815509, 56.24169311215801, 67.47716165358021, 72.28065306140532, 72.16966567500945, 70.95050673330985, 68.93207857685705, 56.948767016010905, 53.10025507403959, 52.54078780451129, 50.37113266606485, 56.28594529244208, 67.70872269907306, 69.8628334845266, 71.56279656194872, 67.28837797718664, 66.56519489903604, 66.14500707195651, 65.0657904532648, 62.62958280501827, 55.67116083637361, 50.13016969926896, 50.843252674225845, 49.2715040329964, 51.16187464806342, 48.770127065720104, 50.95038044837214, 58.49962903607277, 63.81608409266319, 62.04368268289874, 61.57653231774608, 68.80187157661685, 61.55515147793678, 57.69257783889771, 69.58565527392973, 53.25328242394232, 54.58259328719109, 59.49429112095987, 62.83243994559012, 60.18256510457685, 61.38433225693242, 52.74224073656144, 52.397813489360196, 49.89598066576066, 51.32402935335713, 48.52104087029734, 48.82894300645398, 49.25028008799399, 49.709777908940474, 47.928959092786236, 50.30884935009865, 49.84481726923297, 50.73274773936118, 48.03055632498957, 48.78663239940521, 49.47074082589919, 49.63642174197782, 50.229821435866825, 53.05524587631226, 52.31904052918958, 54.49117068321475, 55.52815514226114, 56.811382078355365, 52.62433036681145, 53.81516979586694, 52.248481012159786, 51.756521655667214, 55.29920639530305, 67.25828555322462, 65.83753247414866, 70.80221760657527, 63.92393358292119, 61.66844914036413, 57.46283677316482, 57.58124136155652, 59.11740233821254, 62.88213637567336, 66.35115115873276, 71.58144350974791, 73.1751888029037, 73.09629424925774, 73.14860297787574, 78.62709506865471, 74.50670011581914, 74.95253239908527, 10.53464493443889, 0.7063984594518139, 2.0926428321869146, 2.695270637350698, 0.6523955733545366, 0.22328222440856121, 0.08917991988240712, 34.072119574393, 72.19653391068982, 35.44335273004348, 43.546836145462535, 34.1626557227104, 21.502898085501887, 44.24316667741345, 68.35138736232635, 66.50184862075314, 66.82395365930373, 69.82517873087238, 47.50436252163303, 1.03959369322946, 0.03713938332493267, 0.156885904950961, 0.041235548203750964, 0.054673251335419, 0.03782384841132068, 0.02676546498532257, 0.04977098959047468, 0.050475840276527795, 0.0062703769916908885, 0.19329437144821693, 0.007550581733906462, 0.04954523880094771, 0.014151197204726839, 0.04324410816714649, 0.029212263630582925, 0.025582977630678686, 0.10324085852311504, 0.11646643956942905, 0.09041549713020364, 0.17815019214345565, 0.21511221845303813, 0.08573323668491456, 0.18417979440381452, 0.20760665587600202, 0.2132239802590301, 0.1271176664158702, 0.22498424194993513, 0.13377005985427287, 0.2732642061047016, 0.20476396405889144, 0.20937823420090063, 2.452461950240597, 95.9479836494692, 101.69071012927641, 93.10941142420616, 68.37056775246897, 42.82872861431491, 38.28616895983296, 84.5882740328389, 66.7249765703755, 51.78077759281282, 33.966176356038744, 1.119388430829971, 0.16562578839159783, 2.751816261199213, 3.4257914895011536, 5.514429826890269, 6.942465766783684, 7.02434475383451, 1.7868456604980656, 51.165192973229196, 104.16506674981888, 86.62506672643846, 90.36784725804483, 75.35817607756584, 69.08493334247221, 67.26144698358351, 66.02271541472405, 65.03002235966345, 63.67689486472838, 64.40329820879045, 63.577321575533965, 58.86214625450873, 60.82714780684441, 60.09233882350307, 60.66792311206941, 59.487634858777454, 58.75168838808614, 59.81097544393232, 59.993526474122085, 55.570312776873195, 55.46283983415174, 59.73937257643669, 70.12082346024053, 74.96120868190643, 74.27389960135184, 72.06267126144903, 72.54134162779778, 58.33910211440056, 54.78877659766905, 55.586943626403816, 52.04450207371866, 59.118520213711655, 69.60281172106343, 71.66721005593577, 71.51718724158503, 69.77940467096144, 69.0579003672446, 68.38161314687422, 68.87952666128837, 64.06882201471637, 59.26688386547951, 54.25888792161019, 52.01995588118031, 49.16310541091427, 53.802578987613806, 52.88046506143386, 53.46524338568411, 63.05042174554641, 67.37059870073873, 66.22604323971656, 65.21263222540578, 72.16452737008372, 63.1959181447183, 63.32915321473153, 72.18216234637846, 56.99902042265862, 58.22108584065592, 64.3037994446293, 64.44555782502698, 63.97277885867704, 63.91466109983383, 55.727678268186516, 55.91737585683023, 54.50505979599492, 53.1041068415488, 51.03521347045899, 51.66948426154352, 53.25888749091856, 53.254294395446784, 51.794937349134884, 53.462815438547445, 52.200082886603575, 52.17821175052274, 51.73288937537901, 52.234635045451505, 51.82004836297805, 51.694528595093765, 52.94609415915705, 55.82941278334587, 55.664853665136526, 55.833244939004224, 59.301298741371404, 60.81904811243857, 56.371135250214614, 56.29633957339872, 53.756079289221, 55.07427415540142, 58.5707063059653, 70.98467842225106, 70.72067937543316, 74.11742056569746, 67.48830118486958, 65.51638841629028, 59.23532055270288, 61.60325150335989, 62.49615946123677, 65.80656143926805, 69.60431006646925, 75.18093201421922, 76.07749169872653, 78.3835001914732, 77.18809512353714, 80.96185453476446, 76.89883601280951, 77.08456808520903, 11.231220614525581, 1.4081509940085875, 4.387829015331884, 4.874807942298151, 0.4770041557569658, 0.5700720714465265, 0.2078842401744858, 42.835247593541304, 78.54816129130703, 47.0625545901637, 83.82156049051594, 63.421344603261645, 23.284681804718513, 47.25399371116392, 76.9043508652718, 76.4083985359438, 74.41031963594499, 84.48782213272588, 49.29180622100831, 1.457004604801055, 0.18407473310587869, 0.3057188775029875, 0.10314349640881824, 0.12957056503622763, 0.11597992011135626, 0.1344601824999817, 0.33862793097092264, 0.1654090621178189, 0.21471039001499453, 0.26635862826820345, 0.1216790626846975, 0.16733278550447958, 0.10871185245172632, 0.10525423717955429, 0.1168614038596711, 0.1034033917371304], [0.06019468832340452, 0.071909072838964, 0.03631927088023194, 0.020854401424707427, 0.11065767747500252, 0.0416031631550962, 0.028534340935068268, 0.07650197678876501, 0.013838056850457385, 0.006429154938462401, 0.05910109398105453, 0.0367088878767625, 0.1363592072119636, 0.15575404068635357, 0.17981500845522652, 14.885844895916602, 85.77458704671552, 68.30539364968577, 75.16518762034755, 49.664298026792466, 23.223373197740127, 28.313130947851366, 61.69405829521918, 46.495560292274725, 49.54689364279471, 16.10921940495891, 0.04410998287400411, 0.4863626551964591, 0.689152165526344, 0.9046113911655642, 1.9305356856315368, 1.5615144420054652, 2.9301931540812216, 8.296038450733308, 92.42404783925703, 78.27240297871252, 82.7176800081807, 69.86820713166269, 67.0589977695096, 61.12542052422801, 61.466058761842795, 55.72409322184902, 56.60644215922202, 53.25603200543312, 53.80363018281999, 50.67411222765523, 54.712780675580426, 52.43511522969892, 53.87842978200605, 51.96823943045832, 55.75081240746283, 53.162287358314764, 53.655697991771085, 53.06747974887971, 51.30701018917946, 50.347280733047, 57.75020922383955, 64.1286656164354, 68.8268413851338, 68.55463673991542, 69.27933385295253, 59.04124559894685, 52.79178419420796, 50.666028222730084, 50.67184509769563, 47.87308100731143, 63.17902057401596, 67.36438566638579, 67.832732354441, 63.56502494504375, 59.39343913908928, 57.45510970392535, 64.55251301488569, 61.16201623793572, 57.91946341914516, 51.86775615138393, 49.55778606476323, 48.74833437704271, 56.57989948026596, 60.178332867160925, 54.23285122840635, 46.18664226224346, 49.99532645748508, 54.38244650440832, 56.24669021175754, 55.62187625515846, 64.9591725872409, 58.09993951551376, 54.03513631513042, 67.14791005657565, 52.707574828978515, 54.7320826591984, 58.28683653185445, 58.83166159352949, 54.91480235130557, 51.579787500443004, 47.304906076000584, 47.18363423501292, 49.201477958310036, 51.892459238729174, 45.83138535099645, 47.16543835978354, 45.42623981352776, 47.872069035806966, 45.38213276094007, 46.56905374219341, 47.4667783706419, 48.13204765319825, 46.05803166666339, 45.96656591661515, 46.25827650870047, 46.57673766536098, 47.75523339548419, 49.8142659279608, 50.87052099166378, 51.4435165159164, 50.799612383688654, 48.87499947701731, 48.50556711996756, 49.673331245299316, 50.960080469808275, 51.14840915126186, 53.97463375522245, 65.2835290662704, 65.47965934199672, 66.63469929848948, 63.122114827556, 61.24097747187461, 57.117652508520315, 57.57987245436638, 58.93277637420162, 60.96234798431397, 63.05430096964683, 69.4388174241589, 71.63730590574204, 72.8686712634179, 69.99797482644358, 74.06801439100697, 73.99018672204787, 69.63432404302782, 14.851869325484, 0.7591506610474279, 1.1407391174185662, 1.0682581293006097, 0.45573648245584586, 0.066516587600833, 0.07683350133799738, 3.5113400989963166, 72.90002669057539, 41.515821103126775, 35.34490516108852, 49.90090716269709, 29.664010924677697, 19.822250719993345, 40.35362674343971, 52.67000636746807, 64.18661079099103, 53.98358460395567, 67.07465587123748, 15.856066692260006, 0.40356408684484424, 0.04277087267368071, 0.05876400380305225, 0.018290487088022694, 0.08781818327524009, 0.05909503039513385, 0.06889140653994776, 0.026456149325015086, 0.029496499487469276, 0.02710850192083707, 0.031102035915659323, 0.09499095725796877, 0.07790781707773287, 0.05897158681745491, 0.033818936095603054, 0.021100329054940133, 0.05636760033667088, 0.074435630813241, 0.04376089958954723, 0.054864348137691143, 0.03928330336366931, 0.047354208185307445, 0.07922099137137975, 0.07543133061018682, 0.07215381494813389, 0.011464367891030927, 0.11573196043290439, 0.054863574388887615, 0.1160325656735128, 0.22075966541324893, 0.24935334560371217, 22.65619258726797, 99.0984235271331, 77.2137160455027, 82.54868861167662, 56.71551935134396, 31.21223907316885, 34.09431626719813, 60.013205005276596, 41.668789617476925, 56.67098083803731, 14.510911414700171, 0.22181757154964635, 0.23997719549844343, 1.600517142684229, 2.499064365702291, 5.1902121017056135, 2.883868246309219, 1.9669526863482691, 10.058525089294681, 96.95418142503308, 80.84667805702456, 89.1884062367101, 72.94846011746314, 71.66646480560303, 63.48203935930806, 65.10704202036705, 59.16710661303613, 61.36885066186229, 56.9460331240008, 58.86105583560083, 54.35351902438749, 59.933627959220644, 56.541785809301565, 56.81306477515929, 53.53095093081075, 57.93085005975539, 55.83741049612723, 55.48673099087131, 54.492461143001435, 54.529668746456025, 52.91575070350401, 59.84140519172915, 66.51619665084347, 71.3199390903596, 71.30925455401021, 72.17987952693817, 61.657909731711115, 53.99905835428546, 53.75768746099165, 53.31814665948191, 50.67025653777584, 65.67895889282227, 69.52222270350303, 70.13040973294166, 67.20086205390193, 62.98304719309654, 62.45613559599846, 67.00578689575195, 64.59003833032423, 61.988585149088216, 55.24486980130596, 51.64005079577046, 51.3323094767909, 59.59404483918221, 63.56856292293918, 58.00294714589273, 48.62496799038303, 53.13488960266114, 57.880569196516475, 57.85779983766618, 58.39306608323128, 67.49102330976918, 60.89136092893539, 57.89717651182606, 70.22273448205763, 54.39384098975889, 57.53617332827661, 61.62684455994637, 61.15395184486144, 56.85446146995791, 54.65679276374079, 49.59092224797895, 50.41091334435248, 52.26874789884014, 53.672560261141875, 48.778811193281605, 49.85370928241361, 48.9564553383858, 51.21434419385849, 49.215472975084865, 49.107270471511356, 50.86089941763109, 50.305668307888894, 49.49553020538823, 47.713683728248846, 48.01665152272871, 48.07680499169135, 49.33616038291685, 51.49070655145953, 52.35081172758534, 54.02642473097771, 53.7472657234438, 52.03851653683571, 51.7600517888223, 51.69844704289591, 53.98669112113215, 51.93120441129131, 56.279677344906716, 67.36088691219207, 67.99634225906865, 68.15638280683949, 66.55724033232659, 63.48101954306326, 60.63262570288874, 60.17572841336651, 62.77515765159362, 61.624051832383685, 67.37953385999127, 71.18143235483478, 72.68067206105879, 74.69903745958882, 71.98255292830929, 75.1881334858556, 73.11164640611219, 73.38600835492535, 19.00654677421816, 0.40929436323142826, 0.8659590684598493, 3.426057475228464, 2.7712469475884594, 0.2017675796824117, 0.08475541738012145, 2.866266365012815, 74.92851964889034, 51.35698118517476, 37.632266706035985, 43.52979344706382, 31.47144106126601, 32.96520709991455, 56.587300992781124, 61.73121098549136, 71.23061103205528, 60.857459883536066, 79.87602479996221, 27.890589698668453, 0.399710082358891, 0.08362949029692719, 0.09518383521466486, 0.04265431239600143, 0.01688349575194861, 0.03099629662991051, 0.08744902848716705, 0.015597347125050523, 0.014377578101571531, 0.0737981460688095, 0.04932320736829312, 0.026737487454327847, 0.04386656992738286, 0.040755119144676194, 0.04447881973558857, 0.029696684007743196, 0.15259763586425013, 0.17049564078690546, 0.16777129423233772, 0.07944787597103466, 0.26231193734753516, 0.07795326907428042, 0.107033139305009, 0.1689936028372857, 0.1466575433169642, 0.1756458047537073, 0.3650810082833613, 0.1779067447228778, 0.2247376995341432, 0.32092728561932043, 0.3589583416619609, 24.982995525483165, 110.44772317332607, 87.17345330022997, 92.74426229538457, 68.01196113709481, 36.49228472863474, 46.04535456626646, 87.02935326483943, 69.2787141184653, 71.6391101960213, 21.493547155011086, 0.4171219738500734, 1.3033903702612848, 4.155171177079601, 4.111215871187949, 6.009025016138631, 7.364970243746235, 6.816917561715649, 10.325913063941464, 100.98364014779368, 82.79688050670009, 90.98615400252804, 76.0046297504056, 74.12378265011695, 65.43893729486774, 68.25723478871008, 62.33522461306665, 64.65198040008545, 60.31785549656038, 62.162656014965435, 57.077738469646825, 63.314840485972745, 59.47405169087072, 60.06585890246976, 58.261148929595954, 62.77750715132683, 59.1484792770878, 60.95754308085288, 57.33379471686579, 56.3475186594071, 56.92389526674825, 64.50689192741149, 71.51608113319644, 75.70428602157101, 74.99121481372465, 75.56234328977524, 64.75635467037078, 57.53532609631939, 55.72377550986506, 56.67959044056555, 54.4032193768409, 69.35663592430853, 72.54374996308358, 72.27366339775824, 70.11012323441045, 64.76930633667978, 65.2006729187504, 70.36025278029904, 67.97909951979115, 65.89892541208576, 59.07060846205681, 54.79468368714856, 54.64545319157263, 60.339020606010195, 67.20489425043907, 61.66544068244196, 51.29051270023469, 55.22228087148359, 62.072339519377685, 61.66670368563745, 62.61102999410322, 71.54957817446801, 64.59435685988396, 60.208727313626206, 75.13198083446872, 59.7026905705852, 60.59400212380194, 64.86742050417008, 64.23846844703921, 60.928184140113096, 57.95893815255935, 51.00596435608403, 53.13470917363321, 55.864368946321555, 56.761646424570394, 51.500736051990145, 51.986003844968735, 51.49993981084516, 54.81012605851697, 51.98310913578157, 51.51062826956473, 55.6595584654039, 54.602067855096635, 52.341405883912124, 50.72222402018886, 51.56681229991298, 51.268363075871626, 53.1643230684342, 55.45798393987841, 55.71610335380801, 57.722831080036784, 57.31209616507254, 53.14911603927613, 54.4274478573953, 53.422822952270515, 56.904891383263376, 54.78076319540701, 59.39094451165969, 72.25389465208977, 71.51575165410196, 73.23368703165363, 68.42915227336269, 66.44003206683745, 63.094783752195305, 65.71898275806059, 65.96165980062177, 66.51228997015184, 71.01620643369614, 76.07076091151085, 76.63812391219601, 78.69274770059894, 75.57902905248827, 80.73868736144036, 74.75066369579685, 77.67462591971122, 21.291482333214056, 1.9962980213665196, 5.535775855664284, 6.231982832954777, 4.027623053519957, 0.24502021440815544, 0.15361117018807321, 5.054259809755511, 87.81534133418914, 55.523636571822635, 52.98740063944171, 66.9951415831043, 44.285085047444994, 31.428085142566314, 57.726447505335656, 69.46581902042513, 80.81049026981478, 69.0438739715084, 93.07469060344081, 25.997040002576767, 0.7745106013551836, 0.3229384502816585, 0.12088743338902151, 0.2750108865720611, 0.1724062487483025, 0.09210737932833934, 0.17585146871785964, 0.17649282220630877, 0.10105385369951687, 0.20499244212142884, 0.17560849627179487, 0.2419691007103651, 0.18011200542171157, 0.19473544412082244, 0.1159735922251017, 0.12547429290509995], [0.045324013898930246, 0.0651936227035138, 0.024121268464612867, 0.016841833975406426, 0.009206699117297127, 0.02350914123047504, 0.028863002230683645, 0.011281058372509097, 0.028078401791712934, 0.0379145723737536, 0.05173793565782328, 0.03194232137062617, 0.06800354894010291, 0.05958890429727974, 0.03649770424911573, 46.76479570327267, 92.59343931751867, 69.76667265738212, 65.81788139958536, 37.90736606044155, 20.91641745259685, 30.618402035005634, 48.13937071830996, 36.13520391525761, 56.869307641060125, 5.0195046682511615, 0.0785516756736944, 0.19601363117896742, 1.5125445084225748, 1.6245119970652366, 2.3819698489481405, 2.407647890429343, 0.6552986788653559, 47.07503949442218, 87.19373979876119, 77.74372239266673, 74.81393937141665, 62.48193694699196, 63.12758261157621, 62.2092890739441, 63.544165780467374, 58.790398259316724, 55.47934124546667, 53.251991964155636, 54.06262036292784, 52.26013045157156, 52.45573512969479, 54.34002607099472, 53.432311165717344, 51.363888479048214, 52.76978361991144, 54.59448591355355, 53.05423782717798, 52.80813263308618, 52.074696479305146, 50.07364050034554, 55.496984066501746, 62.93209168218798, 63.49834857448455, 64.3020147662009, 60.102278109519716, 53.3053832669412, 51.49991627662413, 48.59722506615424, 48.63760586707823, 51.482446039876635, 65.42591894826582, 68.26126698524722, 65.97980468503891, 61.9650823070157, 67.93238409103887, 65.14956051303496, 65.26255615295904, 60.544148798911806, 58.25195881628222, 52.23064991735643, 45.68138999323691, 55.313981963742165, 66.89035938632104, 65.78686329626268, 59.384856993152255, 50.304789696970296, 51.729759323981504, 46.26742739831248, 51.995111588508856, 56.25365634118357, 65.35621450793359, 58.58897670622795, 55.11465103395524, 66.83077858340356, 52.24175022494409, 53.68004022106048, 54.07885113070088, 54.01213945881013, 49.32498162792575, 46.36283905275407, 45.9786585838564, 48.141935948402654, 53.1669157551181, 55.87655967281711, 53.171414713705744, 46.44774659987419, 48.274504215486594, 45.56398168686898, 45.41635544069352, 47.139993944475734, 47.84420059573266, 46.764121055603034, 48.215194056111, 47.338383505421305, 45.07972586539484, 46.502993183751265, 45.57259128939721, 49.14736493941277, 49.56784302188505, 48.66284239676691, 49.00371597659204, 50.75604269581457, 48.9024599905937, 50.962794749967514, 49.44895598196214, 51.300008758421875, 53.16316204686319, 63.59027716421313, 63.89335478505781, 66.73423336398217, 64.37188002371019, 59.22366719092093, 60.90063341202275, 59.378761629904474, 60.4610376973306, 63.35691575081118, 63.51762310151131, 66.07918185572471, 70.03488432976508, 67.97901322764736, 62.67969892870996, 63.96812692765267, 61.255262744042184, 73.60300956233856, 30.20516857024162, 0.3545559407962907, 1.1065639964034482, 1.6566218676105624, 1.8511035221238292, 0.16929873565752662, 0.039933095310604384, 0.030650296849348856, 26.77649340321941, 81.59006134156259, 30.02715572234123, 50.91558510257352, 39.227506422227435, 15.823593389603401, 14.307622813409376, 31.43226246679983, 53.79478131571124, 52.45370334194553, 65.46864140418269, 57.183187469359375, 2.0442922653690463, 0.11821256079260381, 0.06350749382568945, 0.03381145141658283, 0.04818154866957376, 0.032228640986666564, 0.05850975454274205, 0.046101593142074924, 0.048919827602202856, 0.012760498643582387, 0.013701881849086814, 0.006111001496338436, 0.05621779184307783, 0.03408289935079313, 0.030139310458194346, 0.0595442260495357, 0.0494888240862037, 0.038133753959329865, 0.029962836359176907, 0.02690550394266123, 0.04037347329299777, 0.07352109037099347, 0.09173454731822976, 0.0633685867632589, 0.03516114129114055, 0.04792034716135071, 0.0273438383855166, 0.04126411562244739, 0.01792334902641033, 0.03626808088513152, 0.030643061148904027, 57.68749052478422, 100.92438882397067, 76.92890490255049, 84.19762949789725, 49.32063564177483, 32.63028963919609, 30.86353840366487, 38.14882716824932, 43.05926984356296, 62.84090834279215, 4.998033613927904, 0.10224546516133894, 0.851571937241862, 1.6638853617252845, 3.762961371291069, 5.69844586233939, 2.4914125569405097, 0.6176319129524693, 52.860453128814704, 91.09247376841884, 80.3860035250264, 78.88216680096042, 64.91182957926105, 65.96455450980895, 63.70550071039508, 67.12639977855068, 60.97253830202165, 59.274924724332756, 56.81158211923415, 57.07090177843648, 56.954776087114894, 56.25717078485797, 57.602881077797186, 57.82459305178735, 57.4433425934084, 55.75487598296135, 56.9884104113425, 58.31000597246232, 54.85753574678975, 54.56772750423801, 54.09329329767535, 60.96745098790815, 65.78147395964592, 66.74243896238266, 67.56843520749, 61.05231538895638, 56.25947321614912, 52.25348595649966, 51.69055915647938, 51.03965751586422, 55.00000015381844, 69.06843585352745, 71.05988594793504, 67.0623553183771, 65.42937455638763, 70.9285649945659, 67.46622608553979, 66.71150715120378, 63.64548844675865, 59.30961416613672, 54.70488886679373, 49.181383655917266, 56.03902032298427, 69.41816222283148, 69.90613645122897, 63.04695044794391, 54.25536955556562, 51.95521716148623, 48.78594990699522, 53.865121180011386, 58.33430897804999, 67.35333242724019, 59.15988945191907, 58.37524283316828, 68.7629851987285, 53.843410861107614, 56.07739679275021, 57.80725225325554, 55.22753684751449, 52.22400542228453, 48.58494020277455, 48.587266168286725, 51.77540786804692, 54.73704837983655, 58.673370422855506, 55.77008301211942, 48.75619088449786, 49.03199234316426, 47.301885850967906, 49.053522233040106, 49.903817561364946, 49.10853347470684, 49.40433509888188, 51.0394770868363, 51.27868283179499, 47.452842189419655, 46.74534074721798, 48.03119174895748, 53.6444604012274, 52.024490141099506, 51.997076695965184, 50.781765599404615, 52.565839982801876, 50.71625809515677, 54.800943789943574, 52.220761622152025, 53.139074771634995, 56.48433877575783, 66.0364515550675, 66.65256177225422, 70.07684584586852, 67.11546421051025, 62.354220651811175, 62.112916438810295, 62.17794541389712, 61.64282821839856, 65.78924809732746, 65.84354154525265, 71.21511766987463, 73.043012772837, 71.36309300699543, 63.113399321033114, 64.53172053060224, 59.91740895855812, 72.33263231092884, 37.24126131303849, 0.334538002047808, 0.8152425156966333, 3.536071868673448, 2.643176168203354, 0.9051388886667068, 0.2020942395733249, 0.12399840153633587, 25.03181726701798, 88.29115621505245, 37.71092199510144, 45.86866355711415, 37.26100652448593, 23.44708558051817, 26.924737422697007, 42.53436257762294, 58.95622038072156, 59.915028079863525, 70.40380677869244, 68.4018918006651, 3.853372248911089, 0.14938861612350712, 0.0590898861147223, 0.07306297745315299, 0.0697558524928266, 0.005500491186525794, 0.044421615950282545, 0.037794767713715, 0.030524171963934938, 0.03763692678823587, 0.07048520650113783, 0.0638665592357997, 0.05146739936824288, 0.06029145288912039, 0.04300278281011889, 0.01806445284596374, 0.16490344408779375, 0.14182899838253377, 0.08595100483827053, 0.10188698963893038, 0.203519239721279, 0.12307641471946433, 0.25839640067950376, 0.25952539977527433, 0.14306022425092038, 0.16675506327902118, 0.108409546495926, 0.10095554163619395, 0.13174351214641525, 0.13156533541698612, 0.13450766462952862, 69.55478622067359, 115.1723357169859, 89.14298519011467, 88.2446055258474, 56.26620792573499, 34.03027180702456, 45.50258874893189, 65.62870940854474, 55.89696776482367, 73.49679177807224, 6.624114436487998, 0.08395696224104013, 0.5067280301403615, 3.64132278869229, 5.226594536535202, 7.184210265836409, 10.157624752290788, 1.9323717225943844, 57.302282394901404, 92.89390856219877, 82.82928712906377, 81.80674091462167, 70.042007353998, 68.48383795830512, 68.40806561131632, 71.49420215237525, 64.9220512759301, 61.62286727659164, 60.485066137006214, 60.8222605336097, 59.946850269071525, 59.531369286198775, 60.70773124694825, 60.338804875650716, 59.13701418907412, 57.72243099827921, 61.08888364607289, 59.82513520025439, 57.73136223516157, 57.668416038636245, 55.797496457253736, 62.20951657141409, 69.7822601564469, 66.68022232670938, 70.2525915638093, 64.90878582000732, 57.89881998492826, 54.81303253481465, 54.56062016948577, 54.63531386467719, 56.82367870884558, 72.31961004195675, 73.7057521266322, 70.00618042484408, 67.40914775479224, 73.79740222807854, 72.86090497047671, 70.51134247933665, 66.09587546317809, 63.223162927935206, 57.153557885077696, 51.19978043340868, 59.26001579530778, 71.6399731174592, 73.81701407894012, 64.14639080724409, 56.1995433222863, 56.76876944880332, 50.68491835747996, 57.348754636703006, 63.651022911071784, 71.74914052409511, 63.074265833823915, 61.905646631794596, 72.14514301669213, 56.45814911011727, 58.3772510866965, 59.573373948374105, 57.98462575481784, 53.2654417714765, 51.479006121235514, 52.17322249566355, 53.59562689258207, 57.87412866469353, 61.70239333183535, 60.90544223785401, 52.20966915930472, 53.7071987121336, 49.75301027297974, 51.85714614006781, 53.948044007824315, 53.27302371301959, 50.89505149472145, 54.141781637745524, 53.93130333192887, 50.655131878391394, 49.71426117804743, 50.07064380953389, 55.618130391643895, 54.65855783031833, 54.51300259559385, 53.68153072172596, 56.08344900992609, 55.17940936550018, 58.97056448844172, 54.85441354013259, 54.753659617516306, 59.557539339988466, 68.4991273572368, 71.08438507203134, 74.3479617949455, 70.37696992197345, 65.78565128387945, 66.66818065028038, 66.05665960619527, 66.27599070149084, 69.45449906010782, 71.43296610924506, 74.28334466872677, 77.35085779620756, 72.8132873965848, 64.77279332376295, 65.68294794328752, 62.61252833950905, 73.0258249467419, 42.38779144902384, 1.0198701161050028, 5.3526962860938045, 7.330409749861687, 6.678869253204716, 1.315703425676592, 0.3110188576242616, 0.23273980966018093, 31.95403575897217, 96.13923057433098, 45.60349564398489, 66.99008957032235, 50.67389257492558, 23.763950332518547, 23.956464182945993, 46.64928190169796, 68.18982493492865, 71.56225527486494, 79.62533827750914, 81.29995499887775, 4.042707753758277, 0.27198094754449786, 0.18083637219763574, 0.14039249159395695, 0.14642845238408736, 0.14142845697220296, 0.18548769035166313, 0.19244065838715724, 0.15328889232008688, 0.1062783205340947, 0.11621620460984208, 0.125488618749284, 0.10582080516483515, 0.18401551450933182, 0.12048553600306473, 0.06578696546174827], [0.025364845585558685, 0.015479911591917759, 0.03239048089111044, 0.013586925567999003, 0.04464996760831245, 0.041564146297112595, 0.018820686964318156, 0.04342668990214025, 0.07491725496947765, 0.02295666160212169, 0.031049792549663016, 0.09885341169372683, 0.09117810701530787, 0.13342289945050595, 1.4643241152648003, 63.12133819826188, 72.80849426023423, 66.17499751429405, 28.274770167566118, 66.57518125349476, 27.680048634929044, 57.669792790566724, 58.262643352631606, 47.23144400504328, 48.075008546152425, 0.5213899417750297, 0.6460584940448885, 0.49133628186198974, 0.4732545230898165, 0.717933414684188, 6.869076259674565, 4.52236189957588, 5.172640863926181, 77.47784845290646, 83.93224977677869, 76.61463675960418, 66.94100502998599, 66.21502137953236, 69.09989326230942, 73.67341610693163, 70.91165173438289, 69.24739007026919, 68.66811875374087, 63.30599946360435, 60.045035039224935, 57.75351970426498, 55.56212679032357, 53.674199811873905, 53.19181888334213, 55.56886149990944, 55.27639389038087, 55.29987712060252, 52.93163630270189, 51.81932272449617, 52.25914593665831, 50.80416625545871, 53.86254418280817, 59.34477821473153, 60.58009339917091, 59.576080383793006, 51.94368931554979, 51.71747838297198, 51.04244632105674, 50.82684147742487, 50.38696335208032, 51.007803947694846, 63.185567009833555, 64.52689209292012, 66.5585974724062, 65.3608311376264, 66.56302975070092, 61.28217412579445, 63.168288969224506, 62.52544779931346, 56.189878602181714, 52.18658993321081, 50.611236633793006, 58.50937612595097, 66.47890275524509, 63.65006585274974, 62.002670380377005, 56.49324647841915, 54.672666595828154, 54.01205316666634, 56.12305710392614, 58.516004931542184, 66.43069682582733, 54.91885808206374, 50.9900003094827, 65.40821729167816, 51.27263453698928, 50.97748010389267, 51.17154721290835, 49.41342715294131, 43.488596793143984, 44.892417000186065, 45.6911253160046, 48.84558562309512, 52.1120374433456, 58.80514244879446, 58.92910895809051, 50.91255703280049, 45.74534423889653, 46.33530401414441, 45.57089682548277, 46.08304854362242, 46.16210783681562, 48.602006435394294, 48.88848066329957, 48.120257008460264, 45.41406085414272, 47.17881756444132, 45.10420145527009, 46.51566243940785, 48.53758542768417, 49.36315021207256, 49.12026528389224, 48.535133946326475, 48.46996376591344, 50.1614192224318, 51.94707039863833, 51.729382776444965, 54.935598757959184, 63.72848972197502, 66.19213827194707, 64.77696672562631, 63.249427118609034, 60.65889773830291, 60.25862770695841, 60.598171603295114, 62.841214287665586, 64.3232112546121, 62.32323000507971, 63.04371449255175, 66.01145036758916, 72.50324756868424, 66.76426303002143, 67.48961125650715, 62.67201500554239, 63.08507588601882, 47.92845310703401, 1.8156676042464472, 0.6020697254327037, 1.9144396267590986, 2.0741282643810397, 1.931566165820245, 0.12772552654026978, 0.09454992043996051, 3.4438775383657028, 61.621008073129964, 59.94898011607509, 38.079091348955714, 44.91975984265728, 33.406728698361306, 14.919710639984379, 29.68311090623179, 44.12278913682507, 54.375935369922274, 57.56396724331764, 59.57826122160881, 16.877798034298806, 0.38355405412374005, 0.039859615987347025, 0.07183754320947394, 0.025782032171264294, 0.04076797793048524, 0.03938525434463255, 0.048400094402172876, 0.030582478915851925, 0.06269653613168387, 0.05172031180512521, 0.04857660872080634, 0.0031980776111595337, 0.04631456175458528, 0.09608625614595029, 0.05646343793599837, 0.03160635159621316, 0.05865605435364189, 0.05122010618628514, 0.036083438373621435, 0.05568094040837981, 0.055709040513442415, 0.015573391555658272, 0.002966397061696156, 0.027013690879328117, 0.017814139362364527, 0.08981318348237584, 0.044242918281064886, 0.06446767778646562, 0.17736317469708382, 3.3114178719059115, 81.6726193889495, 81.27782498636554, 77.24583241247362, 36.59945172648276, 71.02704002011207, 24.70611345383429, 31.716395039712232, 51.850560480548495, 56.57862470995996, 53.65251694956134, 0.7068235463192386, 1.5920694604996712, 4.666160402759429, 1.3603718674951986, 5.379520885406002, 14.442952429094623, 2.1501563008754485, 7.202588531278796, 85.41339951176798, 86.2281777781825, 81.55725463744133, 68.78639390391689, 70.32700677071848, 72.77101209086757, 76.39947906617196, 74.3513350332937, 74.59772263803791, 72.15598444784843, 67.22667124963576, 61.72986953489242, 60.389458364056004, 58.27989393664945, 54.55431299824869, 55.50853544665922, 59.05625258722613, 56.146179476091945, 56.96731198218561, 55.36173682059012, 54.95374756474649, 56.004142607412035, 55.83883823886995, 55.38220374814926, 61.19618008213659, 61.99695940940612, 62.36628978483139, 56.224018912161554, 52.32821495302262, 52.398417534366736, 51.266566630332704, 51.65469300362372, 53.916131604102354, 65.39522247929727, 67.81633684712072, 68.53137708479359, 68.72813101737731, 68.2891393476917, 65.85904275217365, 66.248792986716, 64.97941593970022, 59.97092969955937, 55.29010649650328, 51.50498790125693, 61.906595845376295, 68.19311188113305, 66.09513805758569, 67.42337811377742, 59.293736411679184, 59.025171725980705, 57.785243834218676, 59.21890151116156, 59.762063487883545, 68.56891416734265, 57.43384261285105, 52.875499340795706, 68.33907896472563, 53.16275804273544, 54.43943069827173, 55.36255659595613, 53.01220178604127, 46.770345857066495, 49.48230397316718, 48.2767281993743, 52.417617536360225, 55.37828922271729, 59.607886883520315, 60.39721681225685, 54.28072767872965, 48.22657677435106, 47.454179717648415, 48.52442195338588, 47.67714685009372, 49.811359451663115, 52.26388808219664, 52.13170028501942, 50.21788174106229, 48.884668119492076, 48.74951108809441, 48.290821275403424, 49.91609850237447, 49.73162943317045, 51.503858258647305, 51.48427386437693, 51.57192707061768, 51.14336106085008, 52.62181612753099, 53.033527712668146, 53.82733698814146, 57.35949800860498, 67.74171767696258, 68.2826203684653, 67.23027983019429, 65.11755005005868, 64.09895758475027, 63.44732246091289, 63.02997442983813, 66.34491459015878, 67.8624717650875, 64.50486013966223, 66.53698521275675, 67.74247861677601, 72.83821013665968, 68.30617812372023, 68.49952743899438, 67.63885744156377, 63.65868722238849, 51.56704764212332, 4.627932002467494, 0.8496886479758448, 2.266538171998916, 3.6863881253427078, 2.412300802046253, 0.5648092925548553, 0.08771242483729318, 2.7752563453489736, 65.17192979012766, 67.46733219392839, 41.29949846575337, 38.085190634573664, 16.270090514613738, 9.13817426850719, 36.99284976528537, 52.181737961307654, 63.27348693724602, 63.52126306103122, 70.80098598234116, 27.227171774833437, 0.3621328568025943, 0.07988335099071264, 0.06508607161982406, 0.005755047360810662, 0.0921521878110305, 0.0681007118715394, 0.031241341343810482, 0.012342997004217919, 0.009467239874685484, 0.047518534045065605, 0.06283571898576713, 0.056028342129842895, 0.05956279602082026, 0.02740172207385542, 0.020540339849709023, 0.12460981630870413, 0.12871079988056613, 0.11987001499942235, 0.08029510792825492, 0.14167047946924163, 0.17985853757108414, 0.1049922044659334, 0.13006524333069402, 0.171315400831161, 0.15749306027447024, 0.12360974214971067, 0.17412090674042704, 0.18693594892899837, 0.3980359350962024, 4.061077193867776, 96.41309045976209, 89.40515641243228, 88.71648234705772, 42.307606435591175, 78.4271247925297, 37.091893534506525, 77.58048119083529, 82.4304840641637, 63.06393823316021, 61.68646850893575, 0.6100645577234607, 1.034720516012561, 2.550256689710002, 3.3206871680675016, 7.063601795704135, 21.282941372163837, 9.385858216593343, 8.169973963691342, 94.28918976937571, 86.97713867310556, 84.44241677561115, 73.04859038322203, 73.19118422846641, 75.90138512272989, 82.21029789217057, 77.82478209464782, 77.95838586745724, 74.64068828090545, 70.53011494298136, 64.22344184690907, 64.29655090455087, 59.67102135381391, 59.02556004062776, 57.23218571755194, 61.716780585627404, 59.62444320801766, 60.492326444195164, 57.22238371449133, 56.57674981701759, 58.002962835373424, 59.09034975113408, 59.88846971142677, 64.86827558086765, 65.29855958877071, 65.53682788725823, 56.99306626473704, 54.842297338670306, 55.57899298206453, 55.7463252159857, 55.782842482289965, 56.05034028330157, 68.2531084552888, 70.31679291878977, 70.06955808208835, 71.23290169623591, 71.27512993351107, 68.60608254709553, 68.94876433957008, 69.82007180490803, 61.8190485431302, 57.414901487288944, 54.70559881579492, 66.02480996039607, 71.59273209110384, 68.41493760385822, 68.48656792794505, 61.52650248619818, 61.85373798493416, 60.14327080019059, 62.447977066040046, 64.2117492614254, 73.21655411874094, 60.83177228127757, 56.20888640803676, 69.24435415575581, 57.48259767409294, 56.576565465619495, 59.16567102555306, 55.66199817965108, 48.284686688453924, 52.19968672721617, 51.72935139748358, 56.56042491236041, 56.78969137130245, 63.52078060950003, 64.16168412854596, 57.92340147879816, 50.318890617739775, 50.999872915206424, 51.345367047094534, 51.989016225261075, 53.052786550214215, 56.18576403587095, 56.1623239517212, 52.451514659389375, 50.85801255318427, 50.84037757688954, 51.91805662647371, 51.60115657314178, 52.67042998344668, 54.81003976637318, 54.4762578318196, 54.19824807874618, 53.55756421242991, 55.918764375871234, 57.85204964299356, 57.518569730943256, 60.34095433450515, 69.66901348483178, 72.59168132658928, 70.57787372219947, 70.36065286205661, 66.33000173876363, 66.82447141216647, 66.12130026663503, 68.3776750872212, 69.11191924925774, 67.39843968422183, 68.99465607058617, 72.57503478757798, 77.26171016693115, 71.26755191433814, 71.51088791508829, 71.16229118839388, 65.40474599407565, 56.57239206375615, 6.273615360260011, 2.964576651011744, 7.745987321099928, 7.536034122590096, 5.352305029669116, 0.5622815088398996, 0.31594369981077414, 4.544171748622771, 74.6703649336292, 73.53610177193919, 54.14344864506876, 58.938314760884936, 44.778177968917355, 21.952821400857744, 42.8407310670422, 57.17515445524647, 74.35247252064367, 72.21953468938028, 82.26677217791158, 32.19415345499593, 0.6301355710433376, 0.2696188533258054, 0.19354993837975687, 0.10634850184883803, 0.17390378210092747, 0.19604311024229373, 0.1530303682891592, 0.18977085729279827, 0.15081579196116618, 0.10131816169427288, 0.21966993598447693, 0.1648289956633122, 0.13756230233177064, 0.1930647289320346, 0.2052218241677169], [0.05225768801005137, 0.09377555110521855, 0.06639329341029929, 0.0056730936686959004, 0.017429540241738, 0.09563726733528799, 0.025862318185728886, 0.04590479664564614, 0.03483741168653773, 0.04667035979969848, 0.03879502190337066, 0.0734080924021621, 0.11194905656720362, 0.3675386183444531, 8.636972827296104, 83.5317365584835, 70.22771589217648, 81.42532963906565, 66.19275800643429, 100.89646939308413, 62.392769705864694, 64.48402843167706, 34.55847386390933, 71.55045678538661, 20.96147764113642, 0.11075638790404606, 0.972202715854491, 5.831957459449769, 0.6104873769706296, 2.447363849609129, 10.270273262454618, 2.7060946629893396, 38.40266727632092, 87.04551342994937, 75.705196011451, 72.24830135222405, 63.28750941061205, 73.13500019811815, 74.36032510572865, 77.47926835090884, 76.57283998304798, 73.73820581743794, 73.81022053380167, 73.02567589667537, 71.98366688143823, 69.62263537991431, 62.415782251665675, 58.11264799487207, 54.845886307377974, 53.939250053897986, 54.883643042656686, 55.741088851805664, 52.988369464874275, 52.11342988475677, 51.97493883871263, 50.275964198573945, 50.74452661698865, 54.73344372164819, 57.11999416351319, 55.15956217242826, 51.24639780290666, 50.53936312275548, 49.708103056876894, 49.53132575558078, 48.60982764151789, 47.86469497988301, 56.00415437452255, 64.11063448075326, 60.04023013576385, 62.90390553012971, 65.01477610680365, 62.86058295157648, 63.347462838695904, 62.973500144097116, 56.50306024859029, 51.42963524787657, 55.25667613552463, 60.20828016342656, 64.92330643438524, 63.622766156350416, 64.74918457769579, 61.703977969384965, 62.53953303060224, 62.66520184855308, 62.87313453612789, 60.26403665542603, 64.5792478899802, 53.42142266611899, 51.10084649055235, 65.81501022461923, 48.488442051795225, 51.051950223984264, 48.14011989101287, 45.60325637940438, 45.91521032394902, 49.60451326062603, 48.175770313509055, 49.78556986778013, 53.83078475152293, 60.546482609164336, 57.91110484830795, 55.26613689238026, 47.78281158016574, 46.664998838978434, 44.7505017249815, 45.86470588561028, 47.367479647359545, 49.842969832881806, 51.87239631529778, 50.62415299877044, 46.940890512158795, 45.11297971971574, 45.95714438346125, 46.562236662833925, 47.464322966914025, 47.44436202510711, 49.219952321821644, 48.77110373589301, 48.61111417893441, 50.0278546733241, 48.39123002944454, 50.234241947051025, 55.30500365841774, 65.48264426569786, 64.24501488285681, 65.0626721689778, 63.131834460843, 64.26480324037614, 63.64318601546749, 62.78777591643795, 68.82336616516113, 69.41397313148745, 64.83188775277907, 68.25627773038804, 67.08018641318044, 66.86585241748442, 69.84554367680704, 67.95018380688083, 68.10253650911393, 64.73530723202613, 62.79898997276061, 17.613450327227195, 0.8260094218196408, 1.6181539575899802, 1.0025557935718568, 0.9990788575622344, 0.4881339117644295, 0.2291552995842311, 0.12919859870547248, 26.30008036090482, 76.08090416077646, 50.25508149977654, 39.10523045447565, 71.09246515458631, 49.50502234120523, 16.69667474685177, 25.86316950859562, 39.77569295514015, 56.75409586198869, 63.627076841169796, 50.59955581541985, 1.464001868040331, 0.055754791284280444, 0.028314615427065763, 0.02514582296322671, 0.05280134613595663, 0.05895863993153457, 0.032523542702678716, 0.002168249075991973, 0.08190377765605528, 0.05349727189769188, 0.04306012066081167, 0.037198804934779485, 0.004431658721108351, 0.06370032581711008, 0.021493540919055382, 0.0258677612404309, 0.06473932490353623, 0.07385852911900129, 0.03856573178763351, 0.05209970535830625, 0.04830037273706929, 0.02162152931334511, 0.02091401647175512, 0.08509665592423371, 0.04642847519848616, 0.06397160138153742, 0.049955973011111064, 0.04442410956647608, 0.4481978402022393, 13.60680018701861, 100.00424784998741, 75.89160273152014, 92.09859309657928, 63.3991635999372, 114.61865394346177, 54.711313709135986, 56.0211068584073, 41.34432723445278, 79.30160153296687, 23.152046857341645, 0.198716864350342, 6.835425265373723, 7.559466852295784, 2.906545429460464, 3.363755528003939, 9.183718869763037, 3.433234432051259, 44.989970268741736, 91.71230239252891, 78.33368609028479, 74.58842662072952, 65.59958188764512, 78.78657079512074, 78.68011766864409, 79.17118272473736, 78.6475698409542, 77.69651274527274, 77.36879087263539, 76.62033204109439, 75.28201933830016, 73.00580516938241, 66.6314515759868, 62.100086365976644, 57.17879833713655, 57.377121217789195, 56.35778742451822, 58.3120769839133, 56.65723293058334, 53.2629353769364, 54.70903873443604, 52.891279035998934, 53.824136334080855, 57.2759005331224, 59.282400761881185, 58.612793337914255, 54.70661863203972, 54.29542872213549, 52.727653441890595, 52.68447991340391, 52.236274596183534, 52.81630293015511, 56.83205689153364, 63.855476456303755, 63.70656367271178, 65.26298369130781, 67.53144725676506, 67.29278672126033, 67.19508832500827, 65.75172670425908, 59.384802079969845, 54.41192311625327, 58.69884229475453, 63.11567821810323, 66.22542350522934, 64.27918657179802, 66.26973059869582, 64.31447221386817, 63.406086583291334, 65.28254455135715, 66.85903533812493, 64.84756154398765, 67.61617829722744, 55.327298410477184, 52.59783083392728, 68.66481611805578, 53.34194760168753, 53.867082365097545, 49.090302298145915, 47.11661269587856, 48.2855966783339, 53.20535106043662, 50.27270078659058, 51.87292583527104, 56.67325581273725, 62.228606747042754, 64.14768126703078, 57.3935834054024, 48.52322170811315, 49.38591172618251, 46.912755350912775, 47.794464941947695, 50.37632980654317, 52.51532377735261, 52.09936426531885, 53.042894332639634, 49.50470855159145, 48.21494302441997, 47.90597400357647, 48.39617221586166, 49.55634263253982, 49.21734002328689, 50.69150401699928, 50.49516585565383, 50.84991678114861, 53.935755222074455, 50.417553917054214, 50.57684136975197, 58.895917861692375, 66.7795681184338, 66.50517479065927, 66.74775769633632, 64.46073347522368, 66.41801188069006, 66.05467488688808, 65.74874962529829, 68.86684171615109, 72.36608228375836, 67.63336612332252, 70.65031205454181, 71.09021371410739, 68.05868441058745, 72.55322640941989, 73.1169572953255, 70.92077516740369, 69.92641510501986, 66.04219390499976, 25.55700106005515, 0.7598237152541838, 1.144170823597139, 2.7055820582374452, 2.9457720729612538, 1.7951919739284825, 0.16161611483943078, 0.15524731948971748, 23.214075219246652, 83.15965267919725, 54.3394337930987, 32.58954405784607, 53.33367924536429, 37.23021984100342, 21.690383457368423, 42.893133932544345, 48.22984018633443, 62.75901317596436, 69.47144369925223, 65.60915639323574, 2.65069559697182, 0.1863595903400452, 0.06830943252650962, 0.03148789525092129, 0.03503010195169238, 0.02022430751352541, 0.031184534009005276, 0.030507739377959125, 0.05919536493057686, 0.04376264627001459, 0.09394546174594472, 0.012026543319675953, 0.04377738197123812, 0.015876296017649436, 0.0513310625307983, 0.15057124137397737, 0.28666924324727827, 0.18817491228542021, 0.19505827357211422, 0.1996939328889693, 0.13158218935132027, 0.17655516644158673, 0.12570673930308512, 0.16109561938191616, 0.18331572383401856, 0.18445779238977741, 0.31067926616918656, 0.26644485912496046, 0.8851773339894511, 20.000041953979, 115.30827722241803, 84.74791449885215, 102.17762531772738, 82.04618592416087, 108.59150855771958, 82.68699922869283, 90.56604462285196, 49.09801367790469, 90.27137264128655, 28.227921378227975, 0.24364121017917512, 5.274259178869186, 15.81326480834715, 6.077313971134925, 11.772397871940367, 21.766699052626088, 6.2935125635516265, 45.85921064499886, 95.3110299571868, 79.8786449432373, 78.56718478664276, 67.89634535389563, 82.75454244306012, 79.81985645909464, 83.52233855955063, 80.72363330471902, 80.33267498016357, 78.48552888439548, 80.55190409383466, 78.8039468949841, 75.92224428730627, 67.41201108501804, 66.3906180474066, 60.6320648039541, 60.41664431172033, 61.275992470402876, 61.23135589784192, 59.21353570876583, 56.77504524107903, 58.03256496306389, 55.77664121504753, 56.944111162616366, 61.75220743302376, 62.82944325477847, 61.87939028586111, 57.83674063221101, 56.937949119075654, 55.66800725075507, 56.11140374214419, 53.622852063948116, 53.93847342460386, 58.34767249322707, 68.21962710349791, 65.2744056332496, 69.10401959573069, 68.61228773670813, 68.13772016955961, 68.45971538174537, 69.61109576686736, 63.94391413657897, 56.21454246582524, 62.97213123690698, 68.07049858954646, 69.28023599809217, 65.41244560672392, 69.1759950883927, 67.18851443259948, 65.64756816433322, 68.80738642907912, 69.36162517916772, 67.5874351686047, 69.58829895142587, 60.21505801908432, 55.48256935611848, 72.46841692155408, 54.9292915867221, 55.78978507749496, 53.84557993181291, 50.00404588637814, 50.67390826440627, 55.95078660595802, 55.59705157433787, 55.86404338959725, 59.33021837665189, 66.66891021113243, 66.03164272923624, 62.201150155836544, 53.27494567440402, 52.832074780617994, 50.54914159159507, 50.52020234446372, 52.366454139832534, 55.51030443560693, 57.02340972039008, 56.269514483790246, 51.352266496227635, 49.57742144984584, 50.59265244391657, 52.537677364964644, 51.91303991502332, 52.45500949121291, 52.971275775663315, 52.64135737572947, 53.1752743259553, 56.93240681002217, 54.56855904671454, 52.986039576991914, 61.42877663335493, 69.40737570485761, 69.44037068274714, 70.36065286205661, 67.03412994261711, 69.7191099966726, 68.27570915222168, 68.93487130441974, 70.7619034859442, 74.3185910870952, 69.79774567388719, 75.07396113487982, 72.71016044001426, 71.28904650288244, 76.61812766905754, 76.03391416611211, 73.73354604167324, 72.62326425121677, 68.47087844725579, 32.10061080994145, 1.6238116088413423, 8.070763984034139, 4.846230043518928, 5.543674528598786, 2.2162421095755795, 0.5327463065904956, 0.17454410903155806, 32.17593208436043, 89.85182808291528, 64.99385026193434, 58.80730759712958, 89.17329726680633, 63.66711247351862, 28.41306313391655, 41.25494818533621, 55.264917035256666, 75.75643001064178, 79.77049735284622, 75.71049121118362, 3.3107660230128997, 0.3184021372468241, 0.19636593969358554, 0.10117661162850358, 0.2710298647082621, 0.11523086232163253, 0.12491107272404818, 0.1417166286058003, 0.20112175224048479, 0.1895295702401669, 0.2186105742810234, 0.13073650489170707, 0.15701486819213437, 0.14884257929459696, 0.12936182139861968], [0.017241120916761218, 0.040120645125787106, 0.021269454455543912, 0.05147538200441388, 0.021539132726649125, 0.03245387466684465, 0.045700346930853786, 0.04410756969704263, 0.025256225809214577, 0.014383150433610766, 0.045772692443983215, 0.025448722637168346, 0.17386696391528653, 0.11880617168161178, 30.661336298911806, 80.6034440378989, 62.34614056925621, 65.08656332569738, 52.473746653526064, 9.805027208020611, 26.15169317491593, 49.00328059350291, 43.386830899023245, 75.21631963791387, 3.699414561833105, 0.21702281109267668, 7.3601016017698475, 8.778876335390153, 2.9489906228357747, 5.1888559422185345, 11.905430939889724, 4.605269528204396, 80.41753938121181, 85.11247527214789, 76.701289761451, 67.06250436844365, 72.72987427250033, 74.52024798239432, 75.77353154459308, 79.48719240004017, 78.93048255674302, 74.06924601524108, 73.906263689841, 72.34987505020635, 74.24338356141122, 71.30506546266618, 70.33351006046419, 69.1900057946482, 62.3734010419538, 56.46243626071561, 52.66827660222208, 52.993437167136904, 57.28627912459835, 53.141620389876834, 51.07950095207461, 51.260875271212676, 48.885527118559814, 49.734594745020715, 53.71105832438315, 52.13859973415252, 51.55386063360399, 49.77641113342778, 50.284373760223396, 49.22343146416449, 50.373909704146854, 48.62260280116912, 49.73756397924116, 54.17238396982993, 57.44294251165083, 61.60995483398438, 63.08506019653813, 65.58222932200279, 62.65876916147048, 62.21162288419662, 60.45266735938288, 56.95797281880533, 57.93128544284452, 61.463564134413204, 63.339743614196784, 58.4747729762908, 59.542548041189875, 62.53751693233367, 62.35139654528711, 62.1466645117729, 63.064620725570194, 60.03324439448696, 65.82050154286047, 50.581712953505985, 51.899397911564, 63.59663924863262, 52.948420124669234, 50.29734503838324, 43.76331175527265, 49.031490279782204, 48.50503367762412, 51.131052663249356, 52.024827464934326, 48.629816039916015, 52.40370881172919, 60.52578033939485, 59.43065458728422, 58.1440269562506, 50.360985494429066, 45.33322864963163, 44.80852926931074, 45.56158904106387, 45.751890674714126, 50.36001274662633, 49.06548938443584, 50.40462970733643, 48.58194743433307, 44.82640351018598, 46.365949492300714, 46.39943476646177, 47.63057654903781, 49.14295227296891, 49.36370326626686, 47.736664895088445, 49.170514768169774, 50.17089566876812, 48.156193763979026, 50.706922854146654, 55.36853036572857, 65.3279616755824, 63.24668930422876, 66.43915345591884, 67.8833858428463, 65.24617633511944, 63.30072387572258, 69.15529281862321, 66.33091957338395, 65.93888651940131, 68.53903355136995, 70.79543190617716, 66.70258768143194, 69.85600856042677, 66.7846279759561, 67.83810600157707, 66.29426894649383, 70.95931637671687, 61.41394222936323, 50.145761120703916, 4.975695225500292, 1.172907578368341, 3.7732892171029127, 1.1026750889516648, 1.3047857534500862, 0.17402965034688675, 0.11037370400323022, 1.7188872877628574, 62.54573822021485, 66.3150731978878, 56.591203751102576, 45.59469776768839, 78.92090412878221, 75.56839942932129, 16.1499620445313, 21.93912840658619, 53.27682448971657, 49.754932234364176, 65.97213252898186, 7.312365376180218, 0.34288900393632155, 0.07827013070064207, 0.022688241630432107, 0.05067603054246114, 0.005006965854385447, 0.027124718086974278, 0.04997402587304673, 0.07138676175306882, 0.029152150626384446, 0.020130023157464403, 0.05776392581361917, 0.06728943242060562, 0.02732780608048122, 0.033859887325595465, 0.058317853348149415, 0.04715532409928499, 0.04858279488079491, 0.04463387210102332, 0.04728498831090908, 0.03229596862389195, 0.011368141502081867, 0.03586847410206834, 0.021389914120757775, 0.07597765089162896, 0.0982401046841856, 0.07814443099402613, 0.18672579568960976, 0.047533170154858986, 43.87082784406601, 90.63471747982888, 69.6752892771075, 70.61822706653227, 62.058258210459066, 19.125771137975878, 25.963591990932343, 53.27249419304633, 51.86095083913496, 82.84322723265618, 3.8205133282369186, 0.406768050405287, 5.406470510267443, 6.691685597742758, 5.13890112600019, 4.743695364844415, 9.769654293214122, 7.379949285138038, 82.9384074672576, 86.96530880466585, 79.32219397637152, 70.63211225694226, 75.42872382748511, 78.88422212293072, 77.79217150903519, 83.38870340777983, 82.86711446700558, 76.54839577213411, 77.12696890677176, 73.54867689071163, 76.39944768721058, 72.02461642603721, 75.22213259050923, 73.07130090651974, 66.54031138266286, 60.23942378259475, 54.37640605434295, 54.420862197875984, 59.87160351968581, 56.05405084548458, 53.186833550853116, 53.31956655748429, 51.43849195972566, 52.94322298419092, 55.44812702363538, 54.48508708707748, 53.96403943338702, 52.143600756122225, 50.58293673299974, 51.11479836125528, 52.8423317786186, 51.340942613540165, 51.50570569499847, 57.00427247631935, 60.17361425584363, 62.28509279989428, 66.43813363967404, 67.47478469725579, 65.89068058998355, 64.16445724425778, 62.33200434715518, 60.441265029291955, 61.14332614406463, 63.61379569576633, 65.8756971359253, 58.11106335732245, 60.554668595713956, 62.5902335874496, 62.457484891337735, 64.42565571877265, 64.00611116040137, 61.964050723660385, 66.12013140032369, 51.658658519867934, 54.07300287677396, 68.18886787660661, 54.556713488794145, 52.56905632634317, 46.88663236556515, 51.96943575336088, 52.180824049057506, 53.863269821290054, 54.91962686661751, 50.69192763297789, 56.31819501999886, 64.84359210537326, 61.90712144297939, 60.290544033050544, 52.177850892466886, 48.97582792466687, 48.80270627237136, 46.86744413068218, 48.038977653749534, 52.96201505968648, 54.530006070290845, 53.09864690226894, 50.80577050485919, 47.68945524769445, 47.405718834169456, 46.67038033085485, 48.605889581864886, 51.65956066500757, 51.54310157222133, 50.72730348956201, 51.65390460721908, 51.51129899486419, 50.84482554466494, 52.35555779549384, 58.664478409674864, 67.67988543356618, 63.99672100620886, 68.45816212315714, 70.0935394533219, 68.31854143450337, 66.7569281977992, 69.40888973974413, 69.02478771824991, 67.74232956670946, 70.91940233784338, 72.69514560699463, 70.20139678832024, 73.66901520759829, 70.07959150498914, 71.26606925841301, 71.14816281103319, 71.54441633532124, 65.54991291415307, 58.54346544511857, 11.123372104860122, 1.2780588456699926, 0.8594877092588333, 1.7113340285516556, 2.251358109135782, 0.47602880325528885, 0.15320319772487687, 1.1766351783467879, 64.89477511375182, 71.90622360475602, 55.52144004452614, 51.86362589559248, 83.38593421443817, 72.11730987794938, 23.882988383693082, 29.572384357452396, 61.90553680542977, 57.904283846578295, 75.76674584419497, 12.25547109880755, 0.5871653316482421, 0.13448783827404823, 0.04224144463096896, 0.12174329915714842, 0.06883816342921027, 0.0358582123543226, 0.02080748428500468, 0.11145555038726139, 0.021035948941003413, 0.03452281768043195, 0.017473879495575544, 0.059785306258427526, 0.06016740410198128, 0.01699277819434722, 0.09131981029866204, 0.13427838983554996, 0.13839274164169066, 0.1216952041572621, 0.1042073933527835, 0.14114218523665784, 0.09684824549983587, 0.15813337188334237, 0.22573854744194016, 0.18335969728087226, 0.24450511220962773, 0.12691120572027662, 0.41360452711101503, 0.1558549497877398, 51.922069211159986, 103.35692513373591, 79.5695072604764, 83.75866136243268, 70.12045475744432, 19.424198788981286, 41.437326631238385, 68.3672494273032, 61.81050954326507, 92.21026297538512, 5.945466439570151, 0.5730449216019723, 15.054445035995977, 21.096160065743234, 9.603805695810626, 17.00201165291571, 33.59254314053443, 8.312869341142717, 87.21950977079331, 92.82829515395626, 81.84312482034007, 74.55062281700873, 80.62018471379434, 81.87059710102697, 82.9084405591411, 86.03939410178893, 84.14186123878726, 81.46934647713938, 78.26589184422647, 76.25300207445699, 79.7410717318135, 74.42536584792599, 76.34236935646304, 76.88370350868472, 67.87851425909227, 62.060184094213675, 55.72455998389952, 58.87259544864778, 60.130644690605905, 59.37628269195557, 57.015498299752515, 56.27788482173797, 53.03888567032353, 55.76480742423765, 59.54610170856599, 56.79037386371244, 55.273263838983354, 56.09061910260109, 53.858362936204486, 54.38544711759014, 56.04161300966817, 52.69879656453287, 55.07184620826475, 59.10883195938603, 63.858614352441606, 66.29910915128647, 69.00108875766878, 71.1208160461918, 67.0476778091923, 68.08741184972948, 66.1253873763546, 63.08518963475382, 63.391601270244976, 67.31138660061744, 67.78846448467624, 59.89250975270426, 63.506220771420395, 65.53767904158562, 65.38849561445176, 67.59995537419474, 65.95236378331339, 65.1937852367278, 67.51154515051073, 54.467161855389996, 57.45903207409767, 71.63477989935106, 58.730260479834776, 55.608626488716375, 48.31415937792871, 55.01638781639838, 54.73483224068919, 56.57942487347511, 57.75190368775399, 52.46110093209052, 60.39437701625209, 67.20913041022517, 65.76020294620146, 63.57053979750603, 55.0962943415488, 51.07718283130277, 51.982434488111934, 50.47340062356765, 50.77319914294828, 55.6724944422322, 56.856701143326305, 55.88366700756935, 53.18520968960178, 48.50550828441497, 50.81835739074215, 49.4386479931493, 53.39844934401974, 55.0931486006706, 55.08127166378883, 51.310210843240064, 53.994375044299716, 54.2854659018978, 53.63330910282751, 56.24488984384845, 59.126455168570246, 70.85721708113148, 68.4058298603181, 71.41051446237873, 72.78998067302089, 71.01871675060642, 67.53396541841569, 74.4814008282077, 70.55584569131175, 70.7412169056554, 72.45551232368716, 74.82438856555571, 74.34863644261515, 75.47328195264264, 73.08742969266831, 74.3923944042575, 74.00316976731824, 75.07936616097727, 71.44227781603414, 60.049753650542236, 13.153286922362543, 5.489839507687477, 11.387994808535423, 5.71035074610864, 5.996716618537904, 0.6057215746371978, 0.1708816418484334, 2.345320692946834, 73.7802222467238, 81.81258524617841, 74.57291756906818, 55.795339153658965, 88.45533094098492, 82.94542850986605, 24.3360339057061, 32.41294130202263, 74.5061117602933, 65.378940720712, 87.53191871027794, 15.425651284956164, 0.7741601620951007, 0.20308151240310363, 0.13966562737139965, 0.21136761132267215, 0.11300407455212648, 0.07363731356998605, 0.15052046506635605, 0.19991980625256417, 0.14350196586981898, 0.10314436208817268, 0.1923159086295674, 0.19792235456407073, 0.10300556993893079, 0.08174602483068744], [0.03899607784865845, 0.02830876060010445, 0.09262375323282135, 0.076425053900288, 0.08424350210735876, 0.049967659682395964, 0.01282414714355142, 0.064367733955864, 0.027415249271378405, 0.010463474017958488, 0.024449357109504844, 0.004347165447524599, 0.07126518359948551, 0.7088620143551981, 62.98300404702464, 76.43223870185115, 67.87216786415347, 65.2228029312626, 35.93362546736194, 33.371125344307195, 57.33129224469585, 37.0018006140186, 59.541904772481615, 53.66879086340628, 0.5187573572320323, 0.09464779583316657, 8.042965656326663, 2.6538057913703303, 2.341345861073463, 13.298653883318748, 1.9678836363938548, 20.72365845403364, 86.21259027911772, 74.04813581897368, 75.60060993317636, 66.39506601518201, 68.84027942534416, 67.35136339741369, 72.26249248750749, 69.25374430994835, 76.06042154373662, 72.24868574450093, 73.6154434757848, 71.23607097133514, 70.31206254036196, 70.976527737033, 71.71815379973381, 70.20272254943848, 71.70666909986927, 64.15709495544434, 55.06364060986427, 52.2253704071045, 56.15754650485132, 55.058517994419226, 48.944327369813, 49.99180809144051, 48.981393767941384, 48.855258187940045, 49.2123076223558, 51.15281005059519, 50.786115507925714, 49.31146906268213, 48.553141547787575, 48.58317121382683, 49.50554793880832, 48.765937974376065, 51.08763202544182, 53.949432526865316, 58.373038461131436, 63.13144614619594, 64.30650980241838, 62.894503608826675, 64.3186769946929, 66.85992179378387, 63.999905970788774, 58.7477267942121, 59.28404815735356, 63.43871285838466, 62.63106153857324, 59.84000098320746, 61.146314990135934, 62.6013142831864, 61.21973391502135, 62.53746594152143, 63.254530122203214, 60.00642322724866, 63.395598165450565, 46.48943747243574, 47.810060285752826, 63.86618060450401, 51.584615938125125, 51.28717084084788, 46.85662231137676, 51.028400313469675, 51.53005184665803, 55.06161274448518, 50.931929619081565, 49.81587802210162, 51.87644420131561, 59.17005623540571, 60.68717410487514, 58.875043007635306, 53.50721274652789, 47.55452179139661, 45.52337731084516, 46.39370026126985, 47.295633592913234, 50.92947421535369, 51.45851565945534, 52.45766885818974, 54.028911513666955, 46.016462387577185, 45.75573067511282, 44.373173636774865, 43.47726898808634, 45.255251930605986, 47.08642613503241, 48.73479827757805, 50.63217424577283, 48.508140194800596, 49.020629236775065, 48.40039268616707, 57.63293427805747, 64.67789157744377, 61.47549990684756, 68.2958544454267, 66.10370451404204, 63.654925669393236, 65.9609616187311, 69.73932589254072, 64.87128796116, 62.121408370233354, 67.6542095984182, 68.07597421830701, 70.58633819703134, 66.78831500391807, 64.01486981299617, 64.11996972176337, 64.42677751664193, 71.26968568371188, 65.89909799637334, 64.68955670633625, 51.340334646163456, 0.8061581838034815, 1.1983501550651368, 2.802641108151405, 1.1384401182013175, 0.2847747997410836, 0.05498799472867001, 0.10622109376615095, 21.171710798817298, 75.65809619042182, 41.35863211847121, 62.6815071413594, 72.13834162681334, 113.00138227401243, 76.32862537137925, 23.834105845420595, 43.59670908220353, 50.70443607145741, 66.3479426599318, 17.407237598972937, 0.3504091068621605, 0.21133185033836674, 0.032293505651215394, 0.05361752088872656, 0.07273350601955768, 0.03651460031828573, 0.07954683154821396, 0.0526547437203267, 0.012179811657857031, 0.07705257184082463, 0.06525840309839095, 0.01377274881252238, 0.019237649469305913, 0.029880855375179843, 0.07545487249209996, 0.017237208122687957, 0.14755700714886189, 0.055592323187738664, 0.03412644761884886, 0.03391761205069, 0.004743071547108553, 0.10108514839122373, 0.028781714556258053, 0.018191332327983072, 0.015058229985316435, 0.024323303087223924, 0.13324368084149976, 1.5776288869880861, 76.85056732546899, 82.8472908081547, 76.99660501172467, 69.89371822726342, 44.36566229789488, 20.495809931908887, 42.20014525998024, 43.3017978360576, 67.46261750498127, 54.74030394707957, 0.24556779873467263, 0.1061589104093371, 6.446131986956443, 3.2752102276971264, 5.574147912763781, 20.290666049526585, 2.6999473283367776, 23.89997224653921, 93.09579295496788, 75.65942195154007, 78.73845115784677, 69.55031471867716, 72.03200617144185, 69.48056713227304, 75.73906175551876, 73.82900084218672, 81.68732043235534, 73.05736864766767, 75.78924455950337, 73.14798324338852, 75.3206782187185, 74.2946881632651, 73.52124383372646, 71.01549256232478, 75.25099339023714, 67.24013282406715, 56.78969137130245, 54.147680882484686, 58.11729992589643, 56.435834746206964, 52.63949817226779, 53.7042647792447, 52.23171287967313, 51.579897326807824, 52.142251460782944, 53.54748764345723, 52.263358562223374, 50.708260382375414, 51.33538853737616, 50.77960437343967, 51.151841225162634, 52.11982334813764, 53.270054478799146, 55.860324982673895, 61.20760986881872, 65.17193371249785, 65.23693523099347, 66.99562011226531, 66.51094067481257, 67.87898494351295, 66.00200530021422, 62.39763736724854, 62.53746201915126, 65.34835800047844, 62.959791460344874, 62.29809153464533, 63.880026571212284, 62.91642573571975, 64.86275288366502, 64.59288204869917, 65.46726857462238, 62.58899411847515, 64.97587011706445, 47.8974546155622, 52.4550683267655, 67.60674107459285, 54.13159132003785, 54.484883123828524, 51.09626908456126, 53.52285515877509, 54.651717216737815, 57.22092067041705, 53.12314210399505, 52.43173414661039, 55.18608916190363, 62.17301107222035, 63.73327109121508, 62.26415126554428, 55.2432067163529, 49.94183709544521, 48.35013927951936, 48.72964428317163, 49.100555373776345, 53.6954669029482, 55.31384860315631, 56.49399565112207, 56.495737183478575, 47.949798645511756, 47.817069561250754, 46.79112657423943, 47.05893816486482, 48.04133107585292, 49.68990325927735, 50.84444507475823, 52.69614111992621, 51.06151688483454, 52.55506915430869, 49.54530116050474, 59.04734880693498, 67.15348766696069, 63.78499538667741, 69.39660487636444, 67.23867370236304, 64.46119239253383, 66.59692687373008, 69.6415961173273, 67.63094994329637, 64.67535380394229, 69.73813349200834, 70.1282367398662, 71.77442412222587, 68.24677774983068, 67.81565435471074, 66.35675230333882, 67.4345019555861, 73.04720186418103, 69.00101815500568, 65.38299645147016, 60.24240478392571, 3.4254497529998904, 1.355499180574571, 0.8082649868822868, 1.6739849746227267, 1.1474408545801718, 0.2909850761775048, 0.08154853502468717, 21.394293538985714, 83.96107919754522, 49.71147629522508, 73.57202283797726, 77.11636281782582, 103.9157138332244, 73.08626082635695, 30.39320307393228, 51.1002306784353, 57.66345424036826, 76.78912731908983, 29.29855585098267, 0.22104118740366352, 0.06529938114146072, 0.024916710962931958, 0.025515477623670332, 0.04267988824135354, 0.02851189838932647, 0.06516857162838982, 0.03514358638635567, 0.04034184152260423, 0.008461810761101304, 0.045975215447645996, 0.027556659526101528, 0.027832933814234795, 0.06711222096196107, 0.22846053444570114, 0.13942988679534005, 0.300781256969898, 0.22366192822735156, 0.2770376181410205, 0.1633009873330593, 0.04613269631180071, 0.18750613284928186, 0.09593548238157265, 0.1263913614374976, 0.1319327971507465, 0.13977834954857826, 0.19859263553254067, 1.6293776972639946, 85.30561277943274, 93.71831232501616, 87.4380563920544, 80.93475095687374, 51.97327967612974, 50.566364719021706, 79.97025582098192, 55.322269931916274, 77.10940453314012, 61.05885398003363, 0.8224049474923842, 0.29302501510227885, 16.227298436626313, 10.286442252897448, 5.636557725168044, 30.689610704298946, 6.017193352022479, 24.722112801767167, 95.81852974430208, 76.93775376965924, 80.81348696062642, 74.08518652762137, 77.42069167475547, 73.17035644285141, 77.64538072770642, 76.87965562266689, 83.09469038440336, 76.10469725824173, 80.38274795778337, 76.31743092690745, 78.4643167065036, 77.77997293779927, 77.37102662363361, 73.84942854604414, 78.69699954986572, 72.05676417196952, 60.50085367694978, 55.57556090816375, 63.587680555159054, 59.51255759885235, 54.49972929493074, 54.670313173724765, 52.894452233468336, 53.08074912717266, 54.48889963088497, 57.07337679401521, 56.08084847850185, 54.473990701860004, 54.15181898301648, 54.03548148370559, 54.70237854988345, 53.18782591050672, 55.59481190096948, 61.143816440336174, 63.168900858971384, 68.81337196596208, 69.01426007670742, 70.38638361038701, 67.79105324898997, 71.12014924326252, 67.93495716587191, 65.02555870240735, 63.60168733904439, 67.61769233211395, 65.70572122450798, 63.59262666394634, 66.11244355478595, 67.04879960706158, 65.06355470226657, 67.50859552814116, 69.18396534458284, 66.57828777067124, 66.29476316513555, 51.87736203593593, 54.28728195928759, 69.66091771279612, 57.17141251410208, 56.29978341441001, 51.830042562177105, 55.36242715774044, 58.29588936221216, 60.67443424655546, 55.94372241727768, 55.724595285231075, 58.21326855690249, 63.71927607444025, 66.18686660643547, 65.64395173903435, 60.45183189453618, 52.29493756448069, 50.94423801668229, 51.82736358334942, 52.29841670682354, 55.230455090922696, 58.85039483347247, 58.26840139204457, 62.41145587736561, 49.69925026739798, 51.00636836021177, 50.61144451941214, 51.86000554792343, 50.66209408544725, 53.496975360378144, 52.83096474985923, 56.784800175697576, 54.30550921347834, 56.44557399134482, 50.14660835266114, 63.05636805872764, 69.21364984204693, 67.9294187791886, 71.81014122501497, 71.59377544156968, 66.40665269667103, 71.88853371527888, 73.48344003000568, 71.20670026348483, 67.84068692115046, 72.42104253461285, 73.8348137947821, 77.15629254618, 69.60678115967782, 72.2089913583571, 69.65117454528809, 68.9006603917768, 78.10900488207417, 70.98031674661945, 65.0933764826867, 61.221420534195445, 3.579940392125038, 8.155390101094401, 9.875038573818824, 3.9035067587129535, 1.5727108476623413, 0.379535922960889, 0.2498069615854371, 25.811949237700432, 90.87279750454812, 54.438206918777965, 74.38488698774769, 80.91757882025935, 115.36872879151376, 87.77123035923128, 34.39849999643142, 62.175544923351666, 67.22085045230004, 86.72771515384798, 34.346234413885306, 0.32610603998745646, 0.42545250586925015, 0.15843101236368382, 0.21052597180729915, 0.1358507240131017, 0.08693117603299119, 0.1506879931736377, 0.09995483162422335, 0.09895616706701056, 0.15067804935238055, 0.14498086796412546, 0.1464984574986081, 0.23456271587600633, 0.1500322525539706], [0.08086657121537194, 0.025063240600209084, 0.06041003946935939, 0.07386501788371995, 0.049271768394617305, 0.032531023551259315, 0.016186765597892866, 0.028492018407691392, 0.03650519275857556, 0.09810040855119306, 0.07343136615330174, 0.21952388898259212, 0.3575686888108331, 8.898936163994575, 79.58560466766357, 61.445360414443485, 75.1575154642905, 58.32935110215218, 23.20407513649233, 22.501058924582697, 38.824969260923325, 37.190501920638546, 84.4746978821293, 27.110389086507983, 0.295234106240734, 0.12236809748555384, 3.1850545492864426, 1.7154744579907388, 5.349871198977194, 9.907202989824357, 3.155780920097905, 40.81807067317348, 89.51401787419474, 72.58640181633734, 76.43304671010664, 64.75899834786692, 67.91248198478453, 61.36882320527108, 73.63800494901596, 68.24382028272076, 73.41173125851539, 69.23801560555735, 73.58448028564453, 69.72742542143791, 69.54824370722618, 68.06885903881442, 69.06085783435454, 69.01669194621425, 69.14097616749426, 63.6573536165299, 57.58117075889342, 53.2603270007718, 51.90827815763412, 52.98221918844408, 52.05564552737821, 50.90947797221523, 52.42673704701086, 50.131432702464444, 49.998538878656205, 47.97671002726401, 48.04486905374835, 47.6471407182755, 48.30362781401604, 47.01137942652549, 47.62494794784054, 50.060528016859486, 56.1470070961983, 57.77155868468746, 62.52466724764917, 61.05679473569317, 65.07109349773776, 60.19500686276344, 60.791819018702355, 60.90256321814753, 71.21503137773084, 62.97472000122071, 61.84814860743862, 63.24606564737136, 64.3848591466104, 62.05929763855473, 62.49011901117141, 62.489467897722804, 66.18063003786149, 63.285920850692264, 65.9609616187311, 61.19687041928692, 65.78523943501135, 38.729263428718816, 45.04285558577507, 63.87705733699184, 53.138035343539336, 53.593759844380045, 51.115025858725275, 52.61948623964864, 51.67590910388578, 53.265971291449766, 52.31318835289248, 50.035228729248054, 50.98665060535554, 60.163537686870946, 61.65196341852988, 60.99962619043166, 52.92931818193006, 52.45410734607328, 48.80911150286275, 50.241431651576875, 52.7974324072561, 55.92445573499126, 55.68210817152455, 56.77481382123886, 53.38515643150576, 48.08301802604429, 44.507365765110144, 44.899296837468306, 45.163209592142415, 48.84929618527813, 46.14423359594038, 46.473610708790446, 48.313814209353545, 47.79074653502434, 48.533333578417384, 46.7271605614693, 54.827341341203265, 66.164320822685, 60.78246024347121, 64.3809053974767, 63.04669549388271, 66.30466322745046, 62.60285969703429, 69.55323296208536, 58.8162309892716, 60.98214418657365, 67.69548077737132, 64.5865434985007, 65.66355182278541, 61.87045904897875, 60.1548457145691, 61.36419873083792, 67.35633696279218, 69.08829873608005, 67.8502731938516, 67.42912046370968, 75.10299451889531, 49.900483546718476, 0.18577694983011295, 0.7431637543824412, 0.9876545867131603, 0.9126942316370626, 0.6045367736970225, 0.15287753374826524, 2.11800487772111, 61.447200006054295, 60.52256791822372, 41.53590756077921, 67.32597781765845, 89.06717361942415, 38.905585735074936, 18.0228732093688, 31.326762476275047, 51.46072003149217, 58.902056371012044, 42.54627481583626, 0.5931028807836195, 0.09878952762172108, 0.04508339717323261, 0.08932933001027954, 0.10205995697047442, 0.02376708878023971, 0.06250087727582262, 0.034811199988208474, 0.008994624912438375, 0.044277698672827215, 0.008483803230187586, 0.07030954254010031, 0.036353779310781154, 0.027292123620188045, 0.09511194552385038, 0.02999340709779532, 0.10168641249859527, 0.09507255328278388, 0.03793867349985146, 0.11975593684661774, 0.04477178707959191, 0.06207264561746871, 0.058957100094806765, 0.09319547698983262, 0.03537073145590482, 0.10631082564472191, 0.4296413827086649, 13.861615984670578, 93.1716594388408, 70.00825143629505, 83.70267345059304, 68.53994354124993, 43.918112016493275, 26.15791601519431, 44.91401357035483, 45.43268426772087, 92.92160834035566, 26.48502403689969, 0.2791478226502096, 0.1318433180811905, 4.704290253500785, 2.463697579599196, 6.215099971140585, 19.49836688656961, 4.483756951747402, 45.16407251358033, 92.93472474621188, 77.23839559862691, 78.66558920952582, 70.42769401304184, 69.74098897749379, 66.57735424657022, 75.72115221331197, 73.18540265483242, 77.81259921289261, 74.04016556278353, 74.23027500029534, 72.942333375254, 73.11685531370102, 71.39830804640248, 74.19272222826558, 72.24034678551459, 72.34966324221703, 66.882004737854, 58.377011822115996, 56.98020481294202, 54.10884157303841, 53.69511781200286, 55.346855348156346, 53.578074286060954, 54.12784545652328, 52.228194513628566, 51.04113232704901, 50.397816550347116, 52.28786160868984, 49.781498447541274, 51.49651558168473, 49.47115659713746, 50.59022449677991, 52.05179768223917, 59.79804731184437, 61.13985484646213, 64.8026268712936, 61.73956955632856, 67.51535769431823, 63.22984664670883, 61.980312870394805, 63.77501295458887, 71.76203727722168, 65.75644531557637, 65.1078696404734, 65.61496542346093, 65.76143064806539, 64.4222903251648, 67.51814257714057, 62.93373515529018, 68.45980951862951, 64.36294878682783, 68.61524520381805, 64.43637163408341, 68.38390381105485, 41.391591795029186, 46.75857090180921, 68.14005005744197, 56.97034397432881, 56.99488232212683, 54.96181588019095, 55.481722124161266, 54.925537878467196, 57.12236719746744, 54.476414726626494, 53.41325629142023, 54.13760039114184, 61.14322416244015, 63.49433991216845, 64.37952080080586, 57.244478425671986, 54.930868379531375, 50.8587028903346, 53.043690573784616, 54.47900349094022, 57.79375929986277, 56.73391134508195, 59.16987972874796, 57.48107187209591, 51.87751108600248, 47.456509605530776, 47.05160725501276, 47.06002466140255, 50.29337952213903, 47.73309161586147, 50.38023256486463, 50.26172207247827, 49.505504792736424, 50.48290844886534, 48.68794164349956, 56.68105740700999, 69.68536976845034, 63.50535392761231, 65.83244908240535, 65.01215988589873, 69.2103236721408, 64.84765175850161, 71.33715829541607, 61.87076499385219, 63.90289398931689, 69.71024544008317, 66.16553675743842, 66.17046325437485, 63.31609564442789, 62.73960136598157, 65.3558301156567, 68.50100225017917, 74.66448137837072, 68.9814925962879, 72.08632315358808, 75.89992600102579, 62.99930933983096, 3.070232555750878, 1.258862766046678, 0.3505882182188573, 1.4175770624030022, 1.168280284731619, 0.08299500861715886, 1.191372748824858, 62.369000142620465, 67.1702911007789, 42.70383250328803, 68.8281043883293, 91.2725733172509, 46.100291282899924, 25.45750229589401, 43.43271086292882, 58.49380823873705, 65.07585917749714, 53.778942784955426, 1.0987805430927584, 0.11843409809854724, 0.02893165903045766, 0.03638484417611072, 0.13672522870042633, 0.007063677795456663, 0.05877966647066417, 0.03777947276830673, 0.01521054358642188, 0.04461093542857036, 0.00868917512331879, 0.045103043498050784, 0.030814050058383616, 0.02121445700345982, 0.22681298575574355, 0.139473584450541, 0.28927507599995983, 0.2551617169932973, 0.2052676055820719, 0.11829493822710169, 0.10750509543164123, 0.16748546682778867, 0.13587588234053505, 0.2762141655529699, 0.19594846774012814, 0.2206351608037949, 0.7081947824166668, 16.075856704865735, 107.7578950697376, 76.69166426504813, 96.5238425039476, 74.06232695425712, 38.87578748887585, 39.448841848681056, 58.95797368018859, 53.30545779197447, 102.0959694154801, 31.443178422989387, 0.47107534002392526, 0.3565235610210127, 7.696286968646511, 10.695079680412046, 11.40949430004243, 21.08556966627798, 5.304445249419059, 49.24906807561075, 98.1975257012152, 81.43083664678758, 84.03714964466711, 72.54198489650604, 75.33843871085875, 68.65764602538079, 78.6639496587938, 74.14225701362857, 79.7462571051813, 76.19615908591979, 78.36632021011846, 75.65867670120733, 74.5038995435161, 72.99774862104847, 78.47662510410433, 75.3256674735777, 74.39176682502993, 68.15441377701299, 62.289238745166415, 59.779714153658965, 56.21367954438733, 57.52062897528372, 58.71071530926613, 56.716056716057565, 57.111129606923754, 56.41132777737033, 53.98677349090577, 53.59494832254226, 55.11292519107942, 54.53761154605497, 53.67978918936945, 53.06999398816017, 53.148794404922, 54.84181488713911, 64.15798533347346, 62.66069896759526, 66.96813998683807, 63.80226558254611, 72.11294035757743, 64.70086489954303, 64.80625898607316, 65.55890690895819, 73.08940656723516, 66.96069532825102, 68.04753703455772, 67.57833526980492, 71.79711895604288, 67.74738942423176, 69.27994574269941, 67.12194396603492, 70.68401305906235, 68.61521382485667, 71.98908759701636, 68.94457524822604, 68.60907923790717, 43.435091741623424, 50.86815188007971, 70.0761947324199, 61.69497220746933, 60.10768313561717, 57.361914188631125, 59.127082747797814, 59.73993739774151, 60.60372175708894, 59.32908088930192, 55.65154898551203, 56.119809381423465, 65.74367015592514, 65.3059022657333, 67.2016308384557, 58.79877251963462, 57.15670362595589, 53.4227680390881, 55.256374113021366, 59.527195884335434, 62.2376674221408, 61.963501591836255, 62.20400956369216, 58.88328390736734, 52.61947839490829, 51.25283441235943, 51.53877912029144, 49.803318592809866, 55.21691506908786, 50.51326367162889, 51.64776217552924, 52.81035269460371, 51.885383282938314, 53.802763339011904, 50.6654594790551, 60.966552765138694, 72.86057549138224, 66.79433976450275, 70.99295462331465, 68.65367658676641, 72.15389774691674, 67.04894081238778, 73.26372454243322, 63.95249236014582, 65.60074290921612, 74.02897896305208, 69.39061149474114, 70.24593922399706, 67.67506091825425, 66.32348275953724, 67.53045881948164, 72.94555756353563, 76.54008819210914, 72.80966312654557, 71.57248481627434, 78.31426251319148, 62.78034694733159, 3.3218638791191966, 5.222818274651805, 7.221860116527927, 3.5923360624620995, 1.9642974868897471, 0.31292531338910906, 2.850778150943018, 72.46698917881136, 72.95685398963191, 55.69310649748772, 74.18967846901187, 94.91428221425703, 47.130399827034246, 28.754501535046487, 50.118845816581484, 68.85478435024139, 73.68528519907306, 63.32372857678322, 1.711099299211656, 0.2370925220630823, 0.14211246623627602, 0.1761861725319778, 0.22612699998482583, 0.11735996621991358, 0.13035025868204334, 0.17127902697651617, 0.08341279466666522, 0.1425103876259058, 0.1070207899676696, 0.20994866326931985, 0.12034004058448539, 0.14545723675720154], [0.030179097234541853, 0.009542992563858148, 0.05932626254375904, 0.03383859774217971, 0.029719582375799938, 0.04592400246990785, 0.06633000688687449, 0.06029342173508579, 0.04789646820075089, 0.056661977282454895, 0.011821468285615406, 0.06578153389836512, 0.03185390716328496, 27.973806704244307, 78.809430368485, 63.859877355637096, 73.89680293298537, 40.03038813990932, 14.697479932538926, 22.368453394982126, 30.56481657489654, 49.88760640544277, 79.61289651932256, 5.939005315303803, 0.2547481214447368, 0.21143374003229604, 2.730625166047004, 1.8259112416736543, 9.145142359118308, 2.764137406503001, 7.500114527440841, 57.250667925803896, 80.87674694676554, 72.76496379606186, 70.93046342172931, 67.0012761700538, 70.34470450493598, 69.81072871915757, 68.78360902109455, 68.37601200226815, 68.39614945073282, 71.42485464772871, 69.60828734982398, 71.9340959672005, 73.75431891410582, 73.5062054664858, 67.77714452435895, 68.09763354639854, 69.54854965209961, 68.52798031222436, 59.88074264218731, 50.54516430824034, 51.73663523889358, 50.36329577046056, 50.63515132473361, 50.43424752450759, 50.52979646190521, 50.64510237786078, 51.047364973252826, 48.47991481904061, 48.04268821593254, 47.53179557861821, 47.09373743303361, 48.87169684133222, 46.63658911182035, 54.92703230150285, 63.99395965760755, 64.18498692973968, 65.61582442252868, 63.52214951669017, 66.37070025167158, 59.515393472486934, 60.62849936946746, 56.68059848969983, 59.21659123513007, 61.19023769132553, 59.06884339547927, 62.13496408154888, 64.67952720580563, 63.57018678419052, 63.10954363115373, 59.7696924978687, 62.57292809024934, 60.27862787246705, 64.5867435393795, 60.5247252218185, 68.14322717728155, 36.04540517253261, 40.36121652972314, 67.4983581419914, 54.136200104990316, 60.015009295555856, 51.6939716185293, 54.88294093839584, 52.65374029836347, 55.20506166642713, 48.579935258434666, 52.00168548091766, 53.94220359863774, 59.58663155955654, 56.4860999199652, 58.483912098792295, 55.74542307084607, 56.21757053559827, 52.547106742858894, 56.60559100489463, 56.00654309795749, 57.69748472398328, 57.09111375193442, 58.93085833518737, 55.551167688062115, 49.77404986658404, 44.85787268607847, 45.47277089088194, 45.73967249162736, 44.2779855574331, 44.9730295519675, 47.1486702272969, 46.71710360434748, 48.66730997639318, 47.71390730334867, 48.03320392485588, 55.00591901040847, 64.45734062502461, 60.70830783536358, 62.98169789775726, 64.12262516637003, 65.92407564963064, 63.900171864417295, 67.46403740298364, 57.795908758717204, 66.68645105054303, 63.08500920572589, 61.42611334400793, 58.50714821969309, 55.42394953389322, 57.67458984928747, 63.06045124607702, 64.74517591537969, 71.3015902426935, 67.36328740273753, 72.82450537527762, 64.32225419629005, 79.73101477469169, 43.989883545906316, 0.16068003200475248, 0.924382281880225, 1.495106386080865, 0.17243008940450608, 0.2463169561158265, 0.08659457998170007, 21.46863422086162, 72.68253910926082, 52.098226777968875, 61.921194907157656, 43.150366890815, 22.430001266541023, 21.187704263194917, 26.89633946264944, 56.340811406412435, 54.683468803282715, 54.972731836380504, 4.012714859939391, 0.22549036559799027, 0.007800444662045207, 0.02563635480680293, 0.016782264893634186, 0.08460936271735738, 0.05821697489028016, 0.0515241205181566, 0.029111042348367554, 0.09501518861901376, 0.04086744678657382, 0.05376500813590904, 0.1120523022367589, 0.04192732176893661, 0.05068825730573266, 0.060721415906183185, 0.005945843952377477, 0.03481644386005017, 0.09298117921477364, 0.011667051773157813, 0.07478513544605625, 0.030529528833745472, 0.027182234053109443, 0.04321286327115471, 0.04385377625904737, 0.08549545065409715, 0.0790885424301509, 38.99119930882608, 90.22501807059012, 71.15814132075157, 81.61325823876166, 50.6865422187313, 22.989484225550008, 29.76894021034241, 38.06736738451066, 57.99751466320407, 85.10280270730296, 5.672801406152788, 0.23655195510195148, 0.6836496317578901, 3.541938263562418, 5.508164330836266, 12.318826202423343, 2.2958294518532294, 8.548748916195285, 61.772988150196696, 83.70066519706481, 79.02713760252922, 72.67786364401542, 71.51495149058681, 72.85961058831984, 73.20569699810397, 72.90780867299726, 72.0280602670485, 72.51218272793677, 74.75544898740708, 72.90046599603468, 74.8560420928463, 74.6566209485454, 74.81353928965908, 71.404921162513, 70.71279541138681, 69.97393854202764, 71.89528803671561, 62.4001359170483, 52.88697227354973, 53.9706878508291, 52.904473889258604, 53.4003399264428, 52.68066344722625, 53.11253993741928, 53.34701530395016, 53.246971330335064, 51.41913114055511, 51.20584049532491, 50.9474386707429, 50.60128558066584, 50.445171325437485, 48.90802191149805, 57.25229570942541, 66.87543084544521, 64.95788997219455, 67.02483392530873, 67.07882927310082, 67.08456377829275, 63.28684260768276, 63.34837675094605, 57.90794341794906, 59.61277023438485, 59.388744061993016, 61.37920964148737, 65.74589413981285, 65.81274309465962, 67.10228504673128, 66.20341900856265, 63.124632989206624, 65.32976596586167, 61.488063258509484, 66.30245101067328, 63.1023500042577, 69.96797653936571, 39.15109080653037, 43.6173995848625, 71.4820820285428, 56.19944134066182, 62.67305051126788, 55.10702202397009, 55.64393174263739, 54.72355542644378, 57.767204853796194, 52.65527786747102, 53.369694448286495, 55.67181587219239, 62.541258873478064, 58.69033467385077, 60.790748211645315, 57.500369933343705, 57.91838868971794, 56.76716127703267, 60.2937093857796, 58.811986984745154, 61.63968247752036, 60.96537997645717, 61.03210341545844, 56.194926692593484, 53.53171187062418, 47.235460512099735, 48.40245193050754, 47.12393576099027, 45.920458455239576, 46.99962408311906, 49.50528514000678, 50.955252032126154, 50.338200446098085, 50.48137480212797, 49.92996015856343, 55.337049422725556, 66.14287330258277, 65.6571505146642, 66.1172680700979, 68.42046814580118, 68.55241667839789, 68.98048062478343, 68.54801577906456, 60.68560123443604, 67.89808688625213, 65.1831320793398, 63.256165750565074, 60.617069582785334, 58.836752830013154, 60.23264592693698, 64.9909947764489, 68.03244375413465, 73.0893987224948, 71.7164985595211, 75.27440209542551, 68.93326313264909, 78.6181991331039, 56.08056214547927, 0.48140965161785004, 0.19395959623638662, 1.188978264408727, 1.6168229257868183, 0.6442935500414141, 0.17211272982099365, 22.17215249615331, 77.41433743507632, 57.777257888547844, 60.96097907712383, 49.770515811058786, 29.225372268307595, 28.194453754732688, 35.601749804712114, 61.265029445771255, 59.5442307379938, 65.97556068051246, 7.309434875365227, 0.3166922596433471, 0.04518539794991094, 0.0934729157316108, 0.015207302076892268, 0.03203468859165667, 0.016883647054313652, 0.07376829928327953, 0.07793487530321845, 0.05720742805410297, 0.05260697813824781, 0.08727491968461583, 0.08771636252922398, 0.044847855780033336, 0.09276906479029887, 0.20696197756596152, 0.15215180333583586, 0.12353596788260246, 0.16732794382879812, 0.1434470220438896, 0.16560668215876626, 0.1007927556131636, 0.19329074019145584, 0.19706874875532043, 0.12252865419272455, 0.2114761659815427, 0.16456711616727615, 46.23452263493692, 100.78415624557003, 79.61788577418174, 89.70575117295789, 55.679386046624955, 24.524819543284757, 34.19609392842939, 49.69746558896957, 65.7718563079834, 95.35186967542096, 7.570465178258958, 0.343570975406516, 0.7018505938110814, 7.883672320073652, 6.108783637323688, 18.929695775431973, 8.606955908959913, 11.261969054898909, 65.01583906912035, 87.31600007703229, 82.79481733998945, 76.71798336890437, 74.88331825502458, 76.25440628297868, 75.5152120897847, 74.04878693242227, 74.26413289962277, 72.74350058647894, 77.14330165616929, 73.96580526905676, 77.63234276925364, 79.73583144526329, 78.48753713792371, 72.40252894739952, 74.85170395143571, 72.78997282828055, 76.29757588909519, 64.77711577569285, 57.14096315445439, 57.482401555584325, 55.23802918772544, 55.863655074950195, 55.659597689105624, 56.86398498473629, 56.33948172292402, 56.7492203558645, 54.17110135478359, 52.88893738100606, 53.26709701168922, 52.41478558509581, 53.963572671336514, 50.66102720076039, 61.008192646888, 71.45864194439304, 69.57806156527612, 69.91711124297112, 68.39876959400793, 70.00095582777455, 64.73924136930897, 65.04672381185716, 57.54139008060579, 63.57471319936938, 60.2770903033595, 62.483600031945016, 67.5051752213509, 69.98249715374362, 71.25318035002678, 67.75945463488179, 65.31410786413377, 67.70829908309445, 64.98995534835323, 69.91954311247795, 66.08239819926601, 70.70336603349256, 44.409451638498616, 48.49073663834603, 71.77593031237203, 60.753113069841945, 66.18542317421206, 57.69117755274619, 60.10487079620362, 59.81662365698046, 60.81648288234588, 55.46918230672037, 56.495807786141675, 57.97006199436804, 65.52289562840616, 61.76122888442009, 61.950204756952104, 61.456182233748905, 61.4178567547952, 58.824958262905, 63.28420677492696, 61.350960731506355, 62.55332800649828, 62.48148979679231, 64.36470208629486, 62.3914949355587, 56.7090239063386, 50.48942742809173, 50.309123916010705, 50.44052331678329, 48.581861142189275, 50.06440331858974, 52.28823423385621, 53.606221214417495, 54.269819567280436, 53.249893496113444, 53.507083308312204, 59.34686099329303, 69.37811482337214, 68.58902023684594, 67.28741307412425, 68.62461966852989, 69.43696606543757, 68.88536314810477, 70.88077483638641, 65.67065523516747, 73.37599846624559, 67.06357909787086, 66.93042247526108, 64.48115725671092, 62.1702967920611, 64.63802460701235, 69.10048946257561, 70.28918727751702, 77.51372245050247, 73.59234071546986, 77.79443079425444, 71.79277296989196, 82.27152609056043, 56.847181550918094, 0.5668928678477965, 5.120908233427233, 5.548983456627016, 1.729731660696768, 0.7549738883972169, 0.21175122218987635, 28.91097272596052, 85.35730961830386, 73.37998359434067, 71.61450909030053, 53.14256175871819, 30.491113278173632, 31.581553759113437, 39.75664592558338, 72.99912145060878, 68.06534459514003, 79.51853213771697, 9.334110386909979, 0.5603421419378251, 0.23207916607779844, 0.19420261464772687, 0.1447653367875084, 0.1945133552315735, 0.13013365498233226, 0.21973111576610999, 0.17828772024762246, 0.1717116061838404, 0.16015368363549634, 0.2452905821583925, 0.22977319546043876, 0.1371075065746423], [0.04424747267377473, 0.06664710600049266, 0.09972550320408999, 0.09199651108393747, 0.05004876924137916, 0.043090327507666046, 0.06465782080927203, 0.013012842260180943, 0.10029692052593155, 0.08191914537981634, 0.013595053760875619, 0.0456151771058719, 0.18965919231695516, 58.50676382741621, 67.4016874067245, 62.790886355984604, 45.54600546436925, 24.50115784522026, 36.765101263600016, 35.71516121587446, 33.497457042817146, 72.51073929571336, 56.25713156115625, 0.17614360868690476, 0.09894656798531933, 0.8166356312651789, 2.19497918601959, 4.679172865806088, 5.305158140197878, 1.9434522957571092, 17.101584942110126, 73.8334801889235, 76.62463880354359, 74.90800565288913, 71.06981738921135, 68.57302481128325, 68.99164369029384, 67.74119992409983, 69.52581559458088, 65.65860179162794, 69.93490311407274, 72.02351816238897, 68.76074944773029, 69.73967106111589, 70.79864040497812, 68.97498930654218, 70.74541384173979, 67.53532255849531, 68.58238358651438, 67.8256485539098, 63.27704060462214, 52.553559041792354, 51.511844204318145, 50.79177156571419, 50.81348972935831, 51.216254388132405, 50.87468262641661, 48.955321773406006, 52.65679974709788, 48.17329922030049, 47.40394200048139, 46.828122369704715, 46.24782339219124, 48.237763374082505, 53.17209720611573, 63.08174579374252, 62.08875071617865, 61.73483917790075, 63.6599463032138, 63.530539466488754, 63.3333226942247, 62.22992074105048, 58.280297940777196, 61.16206330637778, 57.8887826396573, 51.974056305423865, 61.09684997989286, 57.074620185359834, 66.35705040347192, 61.80089581397272, 66.32954674382364, 58.626611848031324, 61.804276897061264, 59.254175386121204, 63.638722358211396, 57.45464686424502, 68.62637689036708, 31.098580552685647, 35.22363332010085, 67.69121323862385, 56.474748580686516, 59.31414450368574, 53.058811310798895, 55.10827326005506, 51.45307140965616, 52.480355847266416, 50.72269862697971, 51.647840622932684, 54.27842132506832, 59.77415615512479, 58.227651888324374, 59.507321234672304, 57.406593907263975, 54.78016699514082, 54.32332854117117, 57.17120070611277, 61.4665686699652, 60.664114490632095, 57.414579852934814, 58.584375766015825, 59.10574897643059, 52.871063140130815, 46.25183597687752, 44.22458640990719, 46.99623515529018, 43.211116560043834, 43.882755771760024, 45.24415946775868, 47.614381082596324, 47.67314995488813, 46.627222491848855, 48.504311961512414, 51.217642907173406, 62.72970914840699, 62.27269811014976, 61.70555083982406, 63.72916044727449, 64.60496687120008, 63.75662488322105, 61.526835887662834, 60.58644371647989, 61.87825279851114, 58.21265274478544, 57.38563668343329, 54.35031052558653, 57.47309377116542, 61.446003683151744, 64.4852835901322, 70.38479112809705, 65.18269669625067, 71.93597870488321, 65.99563537105438, 70.52616903858801, 65.23554671195247, 81.66287622144146, 25.527206736226237, 1.0556491800854284, 1.204574221084195, 0.7976841481943285, 0.2290002587101152, 0.11380330344001133, 2.776222719300178, 56.43435993502217, 58.23119378858998, 37.30961253566127, 38.07935414775726, 36.503745894278254, 22.610655830752467, 27.118661365201397, 41.50790968248921, 53.79248280679026, 62.937877178192146, 12.515012371924616, 0.4336306170350121, 0.11909510174225416, 0.06368367872651547, 0.05624545910846322, 0.00741328249850701, 0.02483645942242396, 0.01296300153743716, 0.023509487885260777, 0.023627023009823698, 0.08267138243442582, 0.028207382269864602, 0.09370822729843278, 0.07307397847574565, 0.05450412593481522, 0.0588986705688219, 0.05886760570349232, 0.056030556123944066, 0.024938994545429468, 0.02102212488440977, 0.04032532849739637, 0.04119054436863911, 0.05603026884097246, 0.06965645258465121, 0.03498960654401491, 0.09810312816332425, 1.1335252658013375, 74.36246671984273, 74.14897211136358, 70.81544383879631, 59.75421482516874, 38.195970135350386, 39.80651886232438, 36.719535089308216, 40.83392489340998, 79.22222845015988, 57.37623868450042, 0.22538052391140695, 0.0571711729430864, 1.7421428979404512, 3.4324590284978194, 7.018359216951556, 8.236517463960956, 1.0780390496215513, 20.437478403891287, 75.714233152328, 79.35894658488613, 77.00310045673002, 73.86135255136799, 70.55700671288275, 73.13088955417757, 70.25870261653778, 73.26042975148847, 69.649032931174, 74.57134077625891, 74.63844468516689, 73.26309696320565, 73.82392529518374, 72.6001928698632, 72.45145659292899, 74.50457419118574, 70.41020808681365, 70.39196122077205, 69.00697231292725, 66.83875668433406, 55.15041912755659, 54.55883549105737, 53.069205591755534, 53.152281392005186, 53.50362770019039, 52.97614735941733, 52.20697056862616, 54.21037996968916, 50.7476370565353, 49.21835591716152, 50.51828822781963, 49.11186356698313, 50.62895790223153, 53.73977007404451, 64.27020434410342, 66.35585800293954, 64.67548716452815, 65.76220335498934, 64.94996678444647, 65.5944553498299, 65.16671696016866, 62.83093767781412, 60.757227636152706, 58.66814582578598, 53.27185876907841, 62.01769698050715, 61.15680733034688, 68.15173872055547, 64.97241058657247, 67.71212731638263, 62.56260441195581, 63.367266885695926, 60.75857693149198, 65.60719913051975, 61.25549024151218, 66.40331083728422, 38.878113454388036, 40.455051391355454, 67.04574015832716, 60.921374905493956, 61.091527323569025, 55.13432172036941, 56.33477880108742, 54.67866389982162, 54.36276797325381, 54.29766447313371, 53.776106911320845, 56.36767179735246, 61.93276982153616, 58.965947858748905, 61.461995186344275, 59.95307899290516, 59.21749730263988, 56.58975247413882, 59.34380154455862, 60.896342339054236, 62.54092547201342, 61.2547646030303, 61.396687722975216, 60.455009014375754, 55.044256256472686, 49.58101041855351, 45.802991313319055, 47.96039296734718, 46.315696085653, 46.73175757931125, 47.103661029569565, 50.172790173561346, 49.44040913735667, 48.730032597818685, 51.23612511542536, 52.81402795545517, 62.74692050872311, 65.60788554529991, 63.32383448077787, 66.29914837498819, 68.8695324620893, 65.61250217499273, 62.81729959672498, 62.479430552451845, 65.11567123474615, 60.16633825917398, 59.09399755539433, 55.99030056307393, 61.27639255216045, 63.80015926976358, 66.02409608902471, 71.93977555921002, 67.56921183678412, 73.81176594764956, 68.42319027070077, 72.01230802843648, 71.00257227497717, 83.72652930598106, 35.006663491649014, 0.8852376404308504, 0.5986086014778383, 2.219611425553599, 0.8506885459346156, 0.2111896337761033, 1.898288409556112, 58.10045334600634, 67.62173237339144, 45.079612116659845, 42.70784116560414, 34.37867633758053, 26.458699049488192, 33.41410275428526, 47.81865419880037, 58.61670001860588, 74.15939777128159, 20.68475050310935, 0.4459770738838181, 0.12048811005849032, 0.0938652600011518, 0.13084774085831258, 0.02493868427982013, 0.041549276530502305, 0.0162164093701229, 0.018253728274195906, 0.01692043651165741, 0.0377588841553417, 0.05474506441744105, 0.03454471247330789, 0.07118939452113644, 0.08265706425112102, 0.2627995369895812, 0.14981295222476607, 0.22604337382701137, 0.13652247587038627, 0.11587020865972004, 0.19437020404204247, 0.04854241438630608, 0.23471561170393423, 0.16621276495918152, 0.21797763243798288, 0.2095979941828597, 2.208453263005903, 85.3067502667827, 85.31665032909763, 82.54933188038488, 64.3805641512717, 37.34991881155199, 55.600177703365205, 56.177413309774096, 49.72678922837781, 88.52619248051798, 66.3807415193127, 0.6366471958256538, 0.27887006981238244, 1.6655377827344404, 8.193320891549511, 10.138881706422376, 10.897526933300881, 4.70105625929371, 24.597593238276822, 79.44824326422908, 84.69491543308382, 82.36770260718562, 76.75720707062753, 73.97973752790882, 76.73331199153778, 75.85473245190036, 74.87917623212262, 71.8491138950471, 75.90792763617732, 77.26585218983313, 74.97034780440792, 77.39780072242984, 76.16857697886806, 75.16434038839033, 79.07548473727319, 74.28722781519737, 73.78547037801435, 73.34111290593302, 69.22496195762389, 57.31479083338092, 56.248529803368356, 55.402800113924094, 54.38836928336851, 56.11934261937296, 56.974454618269405, 54.33132233158235, 55.39013478063769, 53.58293410270445, 51.6531946582179, 52.122976933756185, 50.9480897841915, 53.083251599342596, 59.850442332606164, 67.98554789635443, 68.93699722905313, 68.94657565701392, 70.26781820481824, 68.33040268190446, 68.83957339871314, 65.72671374967022, 66.55295710409841, 61.050256144615915, 60.11988170685307, 57.44228355346188, 62.85052991682484, 63.098670821036066, 69.5110047248102, 68.13213471443423, 69.78389186243858, 64.30357194715931, 66.13828412948116, 63.93833260382376, 68.2940423104071, 63.20390409038913, 70.66926494721444, 41.49197309247909, 42.099854177044286, 70.08599281311035, 63.15008132688461, 61.895448469346576, 59.45502427316482, 60.24531910496374, 57.87631342487951, 56.97029690588675, 57.370563014861084, 55.992253903419744, 59.83543534432689, 64.72958449394473, 61.23585877879974, 63.01733263077275, 64.15614574186264, 59.62091307486258, 59.47008225225634, 63.161785679478804, 65.10672823075326, 65.49401521682739, 61.940626328991314, 63.98407528477331, 63.21451410170525, 57.44823378901328, 51.37914257664835, 48.23390376183295, 51.14187056018461, 48.463837023704286, 50.761012338822894, 50.298141279528224, 52.35875844955445, 51.29853394723708, 51.35970723244452, 53.820818008915076, 55.95230848558488, 66.64785492804744, 68.50292421156361, 66.40193016298356, 68.0157030782392, 71.59505413424584, 68.8423582815355, 66.86216538952243, 65.10109178481564, 67.17521759771532, 63.373974138690585, 61.441277227094105, 60.6017017364502, 64.46976277136034, 65.28210524589785, 69.17130393366661, 76.81378333799302, 70.9708167660621, 76.81102983413204, 71.63205777445148, 74.5319680244692, 75.14130823073849, 87.32665323442029, 37.66322597380608, 1.3197093913632056, 5.935287398676719, 4.402494757406173, 0.7185985628635653, 0.20490918368581804, 3.2435147800753197, 67.03779343635806, 70.75339978741061, 52.60136881182271, 53.01570838497531, 46.2779942635567, 32.34885369577716, 38.92180473573747, 59.133052595200084, 67.54924697260704, 85.25965829049387, 25.7335606698067, 1.00082547674256, 0.22687186727360373, 0.23421060654424855, 0.40496608903331144, 0.21891664172853195, 0.11335945507932095, 0.1774343136217325, 0.18999870716323777, 0.12762225022719753, 0.20135934674932113, 0.14491636336090105, 0.21669028296826348, 0.15762511851085773], [0.07806089676676259, 0.048587965974283796, 0.11138215916411531, 0.03216980543408183, 0.00939513089120268, 0.034332873840485854, 0.04987166120460437, 0.046570603660638296, 0.09860068694838593, 0.023116438814829436, 0.0597831727035584, 0.1450374818617298, 5.159014549947554, 67.8374078196864, 62.39332668242916, 69.30629622551703, 34.400045410279304, 22.118847485511534, 37.89580683554373, 39.06319833570911, 38.45949849774761, 88.71870240857525, 18.690542982470607, 0.19030567859449696, 0.07640298290718948, 0.9502916819145604, 2.15838935586714, 8.922055594382748, 4.426118702657761, 0.8221264592101498, 29.424789490238314, 73.87430421767696, 74.72007705319312, 70.18325190390311, 69.9702750482867, 71.82372047055152, 73.63410611306468, 68.57559004137593, 72.17703188619306, 68.52398733938894, 67.38792773216002, 74.9589729309082, 69.98883570394209, 68.13680233493929, 71.88402298958071, 70.22316594277659, 69.02464651292371, 67.43997758434665, 66.04832849194928, 67.364299374242, 67.4028641177762, 54.672968618331424, 51.23883155084426, 51.27942808212773, 50.06394832364975, 51.601109504699714, 50.902908002176595, 48.82054913428522, 50.956283615481475, 49.17109527895528, 48.056083110071, 45.61977740257017, 46.73322846812587, 48.458722252999586, 56.565676966021144, 60.165836195791925, 61.294486445765344, 63.916088842576556, 62.61500727745795, 62.709771740821104, 65.19835479797857, 58.10889428661716, 61.0186771423586, 52.42381095886231, 62.392855998008486, 52.666076152555405, 52.95125992067399, 58.56645053432834, 60.951914479655606, 62.67177574096188, 60.1134176408091, 58.25345323931787, 58.327911592298946, 57.11762897429928, 63.85287592487951, 56.20017090151387, 70.3621433627221, 24.454895450222878, 23.430437080321774, 60.30884973464474, 52.35692670268398, 63.26432428052349, 53.62686072626422, 57.10990974980017, 52.31920134636664, 54.80357177795903, 49.53483235451483, 53.177117839936294, 52.62780558678412, 60.935264018274125, 58.81368537102976, 54.45434354966687, 57.48732805252076, 55.05687059894685, 51.506498013773275, 56.40096879774525, 56.53984423606627, 60.56754573698967, 57.15157708814068, 59.67502609375985, 59.941096152028734, 56.595110431794204, 47.003754338910504, 45.891005377615656, 44.71068574536232, 44.766128447748, 44.474288417447, 47.05355667298841, 44.29824852174328, 47.91901980676959, 48.06930541992188, 47.357010841369636, 49.26834260263751, 57.62120246887208, 59.643415712541156, 61.606507070602916, 61.47391919166812, 61.28852052073325, 60.923340012950284, 60.05707279328377, 59.20083899651805, 57.6563939740581, 52.18900219086678, 54.37273471586166, 57.154040336608894, 60.06214049554641, 64.06123222843294, 68.67549280966483, 66.15662513240692, 69.20570312007781, 67.8159995232859, 66.82516959405714, 65.23386793751871, 69.12971896509971, 69.61204498044907, 71.09493624779486, 4.276426347994035, 1.244541211955009, 1.5891175092227998, 1.0035582042990192, 0.24695264055363594, 0.2128638116823089, 23.36585133306442, 73.54921033305507, 54.13405456850606, 44.47560241145473, 49.32924524430306, 30.017791063554828, 25.320287981340964, 38.31300189418178, 52.29750279457339, 57.80464387709095, 31.247922835811494, 1.4270707916828895, 0.10217143808521571, 0.04308901749731552, 0.03781026950286281, 0.00971237077347694, 0.021907193924210245, 0.045470309879390464, 0.053005431958984946, 0.06453678657811496, 0.01859361084268218, 0.07695568470104087, 0.04511359252876813, 0.0872423762695924, 0.10317974002851595, 0.03193070747769408, 0.01405837320377149, 0.03578125116144938, 0.049845985767822114, 0.08838937077070437, 0.03457700690975593, 0.028204379205201423, 0.0898775884941701, 0.10353330492732987, 0.03413993842719543, 0.16274667675456694, 9.721239497584682, 83.15051355669576, 70.42124563647856, 78.90634429070258, 41.469254724441036, 24.32255271942385, 31.296983841926824, 38.07535333018149, 47.18901180451917, 97.17149642206009, 19.78352515928207, 0.4596236432271619, 0.19475211419405478, 3.009853795651467, 4.5062247783907, 10.583646124409093, 3.645278253862935, 1.8282264206678638, 33.34450421794769, 78.22583660002678, 78.73009650937973, 74.32937760506907, 72.11869839699038, 73.9707866791756, 75.9127050830472, 72.69177236864644, 74.82320400976366, 70.3253750647268, 73.07522327669206, 75.60860372358754, 72.62678653963151, 72.3881495383478, 75.14109642274919, 71.64961430334276, 70.75395676397508, 69.95709588450771, 68.97998640614172, 71.47029922854516, 67.0255164177187, 57.24264667880151, 52.64513069583524, 53.105252173639116, 52.17208108594341, 53.49396298008581, 51.29062644896969, 50.438962213454715, 52.54582020544237, 53.224398089993386, 49.74524790240873, 49.473674758788086, 49.47300795585879, 49.71921120920489, 58.508909363900464, 63.542059467684844, 64.92544020375898, 66.72939315918954, 65.92286755961757, 65.47694506183748, 65.69102018110215, 63.10406015765283, 62.23554541987758, 57.14860393155006, 62.83278903653545, 53.96313728824739, 57.64106142905451, 60.972110763672866, 62.86501130750103, 66.03586319954165, 62.66267191979193, 61.528957889926055, 61.65556807671825, 59.90067220503285, 65.34892282178326, 60.667593632974935, 67.34527587890625, 31.103544312138713, 29.77101710534865, 58.76034898142661, 56.28050888738325, 64.48825282435264, 57.39189678622831, 58.64390950049124, 56.73648049754482, 57.2254470855959, 52.183895264902425, 56.41341447830201, 56.64476371580555, 62.8239833154986, 58.194990311899495, 57.92081663685461, 61.23294445776171, 59.61367630189466, 57.07865238189698, 58.51469093753446, 59.65890515235163, 61.675454493491884, 59.63732819403372, 62.58702901101882, 62.562294544712195, 59.03904122691001, 51.31376451061618, 47.555976990730535, 46.51143412436209, 47.32894236041654, 48.06096646093553, 49.00794821400797, 49.213476488667155, 49.867967097989975, 50.33519198817592, 48.85286161976476, 49.927104673077984, 59.45990762402935, 61.98268982671923, 64.38668304874052, 63.27462050222582, 62.82549735038512, 62.585365926065755, 62.20704155583536, 61.673077537167465, 60.07780644201464, 55.45424199873402, 56.517055265365116, 60.290293001359515, 63.451542931218306, 66.74382748142366, 72.13159515011695, 67.40668450632404, 72.919889573128, 71.68712000693046, 67.77883114353304, 65.7857414983934, 72.52817815349948, 70.86600319031747, 78.69809781351398, 8.06349632240111, 1.3808112158890695, 1.3620746664462553, 1.8130171851765726, 0.35622763657762163, 0.28797355390364127, 22.155354945890366, 78.11921873400289, 60.19789764958044, 45.96158450649631, 34.770046511004054, 30.640396725746896, 35.22648880558629, 45.50675430605489, 59.73149645713068, 64.588598820471, 45.107304050076394, 1.719881118305268, 0.038922338055506836, 0.03563970875655932, 0.018223494614264178, 0.05716877125744378, 0.022328015597116564, 0.03557343832066944, 0.06622209574186033, 0.05798431015723656, 0.02616674237463984, 0.030551641961679827, 0.037236902487253955, 0.03898000149356742, 0.16127758058569125, 0.06346379234004887, 0.18974851816892627, 0.18294889029235611, 0.09565388378236564, 0.1621954305277717, 0.16983556410958692, 0.09980798789089727, 0.19467561265393613, 0.18841817584489623, 0.2298296867839752, 0.48235846683382994, 11.978152663477006, 94.51502415441698, 79.6354736820344, 89.5844244187878, 48.98136631135018, 33.65545795809838, 51.000782905086396, 56.420000137821326, 53.64504483438308, 107.29237248820644, 24.13138424196551, 0.6110721165614744, 0.31156811202245377, 4.4634861426968735, 7.907383047765302, 21.204117421180975, 10.716368344522293, 1.6139518733947509, 35.47577504188784, 80.28479068509995, 82.6790995751658, 77.72987642595845, 76.65639431245866, 77.94541066692722, 78.04171269939792, 77.04037866284771, 78.60054062258813, 71.89787680102934, 73.97616817105201, 76.04610489260766, 76.99883291798254, 74.77517850937383, 80.15634090669694, 75.3694175904797, 73.24510112885507, 71.97787746306389, 70.98478040387555, 74.6273914460213, 72.25303173065186, 58.91310961015763, 55.724720801076586, 56.61028608199089, 54.88942853866085, 56.799258032152736, 53.94778120902277, 54.30880792679326, 54.570814409563624, 55.849173684274, 52.63650148145614, 52.72598251219719, 51.277027591582275, 54.22330025703677, 60.607812789178666, 64.62482975375268, 66.88265585130262, 70.22646857846168, 67.38446035692769, 67.99003508783156, 68.35432913995558, 65.7462549978687, 63.619624337842396, 58.86118135144634, 63.820210426084465, 55.25608385762861, 59.21711683273316, 60.44275160758727, 65.80195657668575, 67.12887087175923, 65.24009666135235, 64.23641704743909, 64.52939456509006, 62.656125483974336, 69.35833038822298, 63.477230533476806, 69.99619407038536, 31.410024589107884, 32.83122089601333, 58.78803699247299, 58.08658384507703, 66.89234410562824, 60.01389142005675, 60.86642249937981, 58.11099667702952, 59.91815420889086, 55.15746370438607, 59.31824338051581, 58.16903206609911, 67.005582932503, 61.78499452529415, 59.72855075713127, 62.8814931069651, 61.317820625920454, 57.884726908899125, 61.65400697338966, 61.21634890956264, 65.62881923490956, 61.90439539570963, 63.89397844191521, 63.21109379491499, 63.123934807315955, 53.558587951044885, 50.71335161885908, 48.84056106690438, 50.010627623527284, 50.355050948358354, 52.33764433091687, 50.438573898807654, 52.60352611541749, 52.68042810501591, 51.688950984708725, 54.96797007899131, 62.885070308562256, 67.21458250476469, 67.11780194313296, 65.40082754627352, 65.7304007776322, 66.80408293201079, 65.28552555268811, 64.65629108490484, 63.18843034005935, 60.002814646690126, 60.44747414127473, 64.54496245230398, 67.04528516338718, 70.5209836652202, 74.76021074479627, 71.31185116306429, 76.83431302347492, 73.20251203352406, 71.49522196862006, 71.49746556435862, 75.31593999555035, 72.24703834902856, 79.5419486876457, 8.60039476425417, 3.7521929942792465, 7.872119959323638, 2.5719027798021994, 0.8506477900570439, 0.30924714140353665, 28.51147932391013, 86.755736566359, 67.23177033085977, 59.884170793717914, 63.38329761259018, 40.25204912308724, 36.660311222076416, 54.81715886823593, 68.81499582721342, 76.00874823908653, 54.858151558906805, 2.284521503794578, 0.2446944585009929, 0.1429623488577143, 0.1282632513152015, 0.11310827783158711, 0.12249366695722266, 0.16449740216616662, 0.16399543071466108, 0.214660395117056, 0.20969461319186997, 0.22720801133301952, 0.13503870145688135, 0.11426312473392296], [0.03128001537744797, 0.07976804709722919, 0.026360497502009236, 0.028348549291671767, 0.03206973902941231, 0.04722990275871369, 0.0564888222593694, 0.00635422962424796, 0.04417852859102911, 0.05352686970464645, 0.15676981198691553, 0.3041716250440767, 29.2097298560604, 74.77153070511358, 64.81324864972022, 51.149146556854255, 30.965714185468613, 33.39518124057401, 70.0413719300301, 41.15675557044245, 56.34800895567864, 77.82689232980051, 3.5919006793729724, 0.12486902215788442, 0.24171981569980425, 2.336753010749817, 1.4579438898832568, 2.307077338618617, 4.587527177026195, 4.599273204803467, 45.42170555360856, 81.2520863932948, 71.33085112417899, 72.50735036788448, 71.29289042565131, 74.47831784525226, 75.77846588626986, 72.7494312101795, 70.92231273651123, 74.58438657945203, 67.860730232731, 75.32195691139468, 70.2984832948254, 69.16504383087158, 68.8933490937756, 68.26306343078613, 68.69148823522752, 68.48716412821125, 67.33335187358242, 67.30001957185807, 64.98123591946018, 58.864558512164706, 49.57735476955291, 53.68232304050077, 48.653919004624896, 49.49160783521591, 51.475385773566465, 48.201959979149606, 51.057425852744814, 49.98982729450349, 47.26003416122929, 46.00412653338525, 45.029923531316946, 50.82211502136723, 62.42864762583087, 60.729523935625636, 59.51393042841266, 62.724978769979174, 60.58085041661417, 62.35129456366263, 58.452089909584295, 59.23013910170525, 63.34064968170659, 62.882073617750606, 54.3929192327684, 59.824762575088016, 59.399546269447576, 57.614255951296904, 62.67853790713895, 62.79620508993826, 58.39911045566682, 53.19348981303554, 58.78555020978374, 56.323945214671475, 60.69321847731068, 57.869837591725016, 66.00596689408826, 19.371790039923884, 18.56336012963326, 56.578546262556515, 46.7831680851598, 58.82563683294482, 58.89705534904235, 61.02498823596586, 57.22567850543607, 55.27266371634699, 53.881242121419604, 55.14018566377702, 51.006419351024014, 58.88384480630198, 57.15982583261306, 60.430992341810665, 59.83978917521816, 54.02490285135085, 50.42528490866385, 52.02437246999433, 51.663133944234545, 54.51763099239719, 56.9138147754054, 58.25048008272725, 58.924370734922356, 57.71588456246161, 49.65246423598259, 45.74732503583355, 43.872377180284076, 46.10560217211324, 47.163787041941, 46.594686431269494, 43.732336798021876, 46.37177028963643, 47.210039631012954, 48.407288212930005, 45.14965388082689, 54.03868606013637, 58.77371249660369, 58.49806008800384, 61.39398913229666, 59.47494991364018, 58.457738122632435, 58.28217675608974, 53.682315195760424, 52.832141460910925, 51.71380704449069, 56.34299224422824, 61.546628167552335, 63.66819897005635, 65.74789454860073, 67.42275053454985, 66.18249708606352, 66.97705161186957, 64.31096169256395, 62.80632088261267, 57.8011804242288, 66.4541918231595, 66.81153543533819, 78.70034925399288, 38.59957810371153, 0.5746818369915409, 1.4674840747348725, 2.2686778249279147, 0.17274348065257075, 0.10080203293792664, 2.9707538937368705, 55.01797637631817, 65.66778798257151, 49.04474004622429, 66.79191573973625, 32.25901965172061, 13.855187219958152, 29.92252257562453, 48.12212013429212, 54.98306728178456, 56.56810883552798, 9.975499299264724, 0.5436075334587406, 0.13507141341124812, 0.045761166651162415, 0.11612966731791535, 0.03158165483675417, 0.03603365798030169, 0.037287437477179115, 0.01496084105794228, 0.008554471010762838, 0.04164922802198318, 0.03165443702000043, 0.07423976511364022, 0.05191022117111472, 0.07026045928679167, 0.10435265894498556, 0.037836534827346766, 0.02525164460342738, 0.05557153539191331, 0.06063516972766769, 0.05029560277058233, 0.01288012806100831, 0.03376691872554441, 0.09245139111073748, 0.14392086274681554, 38.50715137297107, 90.03630499685966, 71.25916588690974, 61.84288086429719, 40.43597690520748, 41.755022925715295, 48.63063581528203, 45.87497072835123, 65.88451462407266, 82.9439615434216, 4.074549309669003, 0.1924337942393557, 0.700852228028159, 3.655690185485348, 2.744735892741911, 5.0359722491233585, 4.077841403984254, 6.314115303177988, 48.837866398596, 82.57684338477351, 75.86058462819746, 74.04673945519232, 75.91235206973168, 76.36791183102515, 78.5232150170111, 76.89766714649816, 73.15906786149549, 75.14294778147053, 69.80710444911834, 75.7381360761581, 73.46502842441683, 73.27800196986045, 72.41035799826346, 69.98591746053388, 69.73923960039693, 70.57109586654171, 71.1549485114313, 70.00769445973059, 68.8543293553014, 61.540493580602835, 52.587813100507184, 55.84999345964002, 52.15473244267126, 52.49015000558669, 51.05992440254458, 51.71079858656853, 51.712626411068825, 52.97285256847259, 49.902393740992395, 48.97455315436087, 47.30876961062032, 51.912122080402995, 65.15296513034453, 63.67681249495476, 60.23309307713663, 66.20769439205047, 64.59916568571522, 65.40827220486057, 61.318228552418375, 61.81248641783192, 66.65313443829938, 64.63376883537539, 56.82365909699471, 59.67801493983115, 59.864633467889604, 59.63742233091786, 64.85592011482485, 64.71590718915387, 60.07556284627607, 56.431139669110706, 59.16614170997374, 61.31657723457583, 62.599211892774036, 62.834012816029215, 64.81884194958594, 25.51855202644102, 25.19586451591984, 54.27172583918418, 51.169417365904785, 57.64215184796242, 63.309772783710116, 62.44846343994141, 60.85922495011361, 59.04778811239428, 57.03957773024037, 56.7723858741022, 55.63437684889763, 59.907061746043546, 58.84132631363408, 62.31384769562752, 61.69843958270166, 55.82909114899174, 53.82334793767622, 54.69195288996543, 53.995947914738814, 58.45898543634723, 59.94566571327948, 60.01075352391889, 61.28615140914918, 61.168327331542976, 52.60003128359395, 47.45016321059197, 47.6137182020372, 46.09733773816017, 49.688954045695645, 48.32157657992456, 46.92833108286704, 47.7587596062691, 50.123654642412745, 49.7530024282394, 47.760108901608376, 55.70643863370342, 62.46600820172218, 61.69319929615144, 62.819021517230624, 60.95076522519512, 61.32348060607911, 58.89330556315761, 55.56740237820534, 55.83929323380994, 54.99533645568356, 59.86816360104469, 63.925216197967536, 66.74539642949259, 66.98872458550238, 68.43744416390696, 67.85286195816533, 68.45307873141381, 66.86460510376962, 65.43218689580118, 61.36191591139763, 69.29688253710347, 72.39266810878631, 80.71076793055381, 48.19648042801888, 0.27487688247234593, 1.8117007396874891, 2.2234727538401082, 0.6943072018123443, 0.10623101460477037, 2.4021313219301166, 57.47985593734249, 73.58844972425892, 53.8006531038592, 49.18694165445144, 21.64818856023973, 22.631936650122366, 39.92508034552298, 54.324928868201475, 61.24058523485738, 68.94297492119574, 17.386476493650868, 0.7097701043371232, 0.07823396368973679, 0.037415155825475534, 0.07282247947108361, 0.033724236136843125, 0.04953556694090367, 0.053276596440663265, 0.05000618241366841, 0.02768747861527147, 0.022126061413737557, 0.05825863858204215, 0.10894812928933291, 0.1414579053920123, 0.2389053772053411, 0.24823563864394543, 0.07698767653275883, 0.15899652314762916, 0.16137332625446782, 0.14547556158035033, 0.12941947717580105, 0.08949500418478444, 0.2160762481751942, 0.2944890397690958, 0.30952832631526456, 48.790950928964925, 101.79624542113274, 82.7848074513097, 72.09015138687627, 45.865855140070764, 46.150850634421076, 90.45694781887917, 63.90055233432401, 70.54011698692076, 92.02122826730051, 5.823241462630611, 0.2385932116979553, 0.5277083285393254, 7.708907194675938, 9.59006759428209, 10.245906518351648, 11.195416239000137, 7.515471587258001, 52.9787871145433, 88.36320231037756, 79.37700517715948, 77.89484347066572, 80.51631250689107, 81.40121490724626, 81.53630918072116, 80.09495581350019, 75.5261633473058, 77.68958583954843, 73.91250025841498, 76.44799878520351, 74.34952289827409, 73.54822189577165, 77.3749646832866, 72.2528434568836, 73.24743101673742, 74.01023787836876, 72.96032920960458, 72.47501434818392, 71.9243057312504, 63.78574063701015, 54.43840303728658, 59.813266108112956, 54.986958272995494, 54.26040195649671, 56.09321963402533, 54.222860951577466, 55.391119295550936, 55.0154072238553, 52.117822939349765, 51.6909670829773, 50.31198332386632, 55.00686822399017, 68.54214791328677, 66.72937746970885, 63.86268577268047, 68.23670510322818, 64.88072126142441, 68.35589808802452, 64.34701219681772, 63.82457602408625, 68.77931794812604, 66.60103751767066, 60.159666307510875, 60.28915159163937, 62.51644203739782, 60.939845346635394, 66.36327128256521, 65.99590209222609, 61.829078043660815, 57.78499280252765, 63.28408125908145, 63.068503872040786, 65.33149573110765, 64.65831502791374, 67.89846343378868, 25.357883899442612, 25.167711704008042, 57.38780183176841, 51.41927234588131, 60.639458471728915, 65.63552648790422, 65.04712389361474, 63.18958351689001, 58.78371846291327, 60.08484709647394, 60.984360325721006, 57.59114142387145, 64.37982674567931, 60.29052442119968, 63.352326577709576, 65.02764540333902, 58.42228774101504, 56.36223146992346, 58.00124875960812, 57.29639099490259, 60.6820789460213, 60.96905131493846, 62.111170984083614, 62.29446334223594, 63.49970963693435, 55.59002268698908, 50.75920804854363, 51.25648613898985, 49.22856584672005, 52.7835197602549, 50.597316142051454, 49.62791804344424, 49.82205967749319, 53.97769320395685, 52.323649314142045, 49.79771352583363, 59.01769961080244, 66.3356185728504, 65.1621630883986, 67.99039594588741, 62.31080785874398, 63.84381524978146, 61.856726831005474, 60.430062740079826, 60.33585525328114, 57.33668158131262, 62.59945900209489, 69.05661382982808, 67.13292660251741, 68.8600403262723, 72.76480690125497, 70.96457235274777, 72.12201672215616, 68.88595934837096, 69.7273155950731, 63.43028760725453, 71.9789521924911, 74.90888426380774, 83.31320562670308, 51.67345762252808, 0.7144871834785708, 5.7858372503711335, 6.368382275104524, 0.901726181468656, 0.17012539049310071, 3.8683682055242605, 66.76696946544033, 77.5392492355839, 62.67460769222629, 84.55633025015555, 43.09466138962777, 23.415220245238274, 46.999490722533196, 66.06615958675262, 69.7798204421997, 80.6858765694403, 20.26139928448585, 0.7989143015396211, 0.2660734290557523, 0.2457213533982154, 0.132515698130573, 0.19564587833179584, 0.13800658736257784, 0.13422706194462317, 0.15706942897410164, 0.07330019657890643, 0.1408594221838059, 0.1105188470213644, 0.2088057826603613], [0.03171484113761014, 0.010877663284660348, 0.027301008324889887, 0.03039965203272239, 0.07245818168045053, 0.027003624484003074, 0.030383131346635284, 0.10776315980981435, 0.13470405892979714, 0.038729578842439, 0.053048329052305034, 0.5102546086474773, 35.25330997282459, 69.47509934825283, 64.61514542179724, 47.45421894135014, 19.893573138021655, 23.147122321590302, 48.115550164253484, 39.992192099171305, 79.0181161511329, 42.833980667975645, 0.05792344064121285, 0.10072447419647249, 0.39538900938726246, 2.447951959986841, 2.4944131701223315, 4.409889896069804, 2.1042351520830587, 10.348528469762496, 54.96720913917788, 79.59094693583828, 71.11639161263743, 74.48700197281377, 71.50556918113463, 77.06089265884893, 74.99158351652085, 73.09521951983052, 72.58529570794875, 73.81924982993834, 59.56418383506037, 73.97343820141208, 76.18504308885144, 67.76398889480099, 70.56256078904676, 66.57478901647752, 67.71803440586214, 67.92893240528723, 68.46997630211615, 65.36498100526872, 65.93308141154628, 60.243993343845496, 52.22731982508014, 49.352677483712476, 48.54819936137046, 48.266839904169885, 50.96570514863538, 48.4067508482164, 49.29204940795899, 47.3437963762591, 47.83948982915571, 45.95691296362108, 44.650277322338475, 53.00531802638885, 62.94095231640724, 63.454610224693056, 63.369643842020345, 65.04100499614593, 65.77451175259006, 57.111255122769265, 61.77150549427156, 63.41366460246425, 60.952557748363866, 61.371627699944284, 61.267135758553785, 54.84991065917477, 62.14668804599393, 59.52576814159271, 61.57174310376568, 58.216284859565, 56.74130501285676, 54.088084390086514, 55.16893271476992, 55.10867334181263, 63.15565501489947, 56.35413962025797, 65.6644029771128, 18.22677173922139, 18.125758940173736, 60.859742702976355, 56.38684826512491, 62.654623216198345, 56.12406515306043, 58.08574445786015, 59.88987391994846, 61.45736286717077, 53.67276422439083, 55.41209220886231, 55.67483609722507, 55.872696138197384, 55.28467401381462, 55.09402328921903, 55.88354541409401, 53.93996000289918, 50.10727090220298, 52.26116203492688, 49.67614358471286, 51.576559389791186, 55.32144623418009, 57.01751832039126, 59.59679442067301, 57.51736556330035, 53.09213184541272, 46.497074327161236, 42.69411287000103, 45.60947725849767, 45.1030953468815, 45.84209734393705, 45.14004799627489, 44.9291499968498, 46.207960344129994, 48.13787629527431, 47.34194109516759, 46.910260723483184, 56.403404589622255, 55.784446731690444, 59.122015045535186, 54.90171732441072, 53.890530293987645, 53.19707485937303, 52.03586109222905, 49.98072739570372, 55.92665226228776, 57.475929644800004, 62.07136677157495, 63.09521913528443, 66.33627753103933, 64.94956278031873, 65.715919386956, 64.62267637252808, 62.72519450033865, 59.07105168988628, 61.60079217726185, 61.70628432304629, 70.79982496077015, 69.98172836918985, 75.75901093021517, 4.850095539323745, 4.307441999835353, 1.3344750313028213, 0.6987287548761214, 0.07273922103547281, 0.2119499607191932, 26.543026085822817, 74.56793615894934, 58.6212028995637, 50.780102514451556, 53.328478182515795, 22.10641553325038, 19.898525130364206, 37.88393382103213, 51.994378105286636, 58.39412512317781, 32.93582070258356, 1.387466129756743, 0.0693475429509436, 0.08291260053914401, 0.020876801835613388, 0.07024735918328648, 0.06171022091181048, 0.0884459693465502, 0.02723882496807604, 0.06211256262876334, 0.06590304310403525, 0.014023405120467708, 0.0711007964526934, 0.09012038474001231, 0.042036397367595665, 0.023508806067008167, 0.12876454860933367, 0.09036436842213716, 0.039717951008389075, 0.025609853910282258, 0.05905903575401153, 0.04109169221332958, 0.003743603076380227, 0.0661750196389133, 0.517153169118589, 49.03869959615892, 76.45754583420293, 73.8823058528285, 53.382963826579434, 28.266323343400035, 22.73516951068755, 42.973668036922334, 47.10138605486962, 84.65653896331787, 48.90670399512015, 0.06130851887827439, 0.06456849495730092, 2.160242920921695, 5.706581348373044, 4.8064527973052, 6.468191396805548, 1.8465176585220524, 11.72184342338193, 61.42365009553971, 80.53917992499568, 74.01954174041748, 75.64735674089002, 74.27313866153841, 77.11020469665527, 75.67991241332024, 76.86022420083323, 75.35798780379757, 75.40795879979288, 64.34934208470007, 74.34178798429429, 75.06875222729099, 69.62492604409495, 73.8310718536377, 70.08722443734446, 70.99460986352736, 68.74942948741298, 70.87511093385758, 69.01866097604075, 67.44073852416008, 62.39892390466506, 54.89137011189615, 53.079505735828036, 52.5145040019866, 50.85596899832449, 52.644895353624904, 49.96262565735848, 52.653846202358125, 49.29916850982174, 50.86418636383549, 48.56775629904963, 47.86043920824605, 54.82769435451877, 65.55128966608356, 66.31028006153723, 64.46789572315832, 67.03510269041985, 66.6382686553463, 59.859887399981105, 65.13552627255841, 64.05401898968604, 63.291059155617994, 63.47191179952314, 65.06042465086907, 57.172455864567915, 60.52317980797061, 61.327308839367284, 63.7578918087867, 62.98852674422726, 59.07142823742282, 57.95858513924384, 57.00281727698542, 56.961726527060236, 65.02016152105024, 59.65245285341817, 65.20144954804452, 23.873078515452725, 25.677984606835153, 61.97226024443104, 61.42904335452665, 62.077014984623084, 57.37494430234356, 59.435953709387014, 62.40213240346601, 61.15985501197077, 57.489104886208814, 57.2570574668146, 57.44038512629848, 58.397623877371515, 58.255767437719534, 57.578672209093654, 59.80603717988538, 55.38232141925443, 51.487243098597375, 54.71747967504687, 52.70430749462497, 54.33749221986341, 58.09835487796415, 60.176250088599424, 61.227433527669604, 59.92748944990097, 56.275272523203206, 47.84008995179207, 45.540824013371626, 47.576942059301565, 47.64264568205803, 47.96890451062111, 46.73934736559468, 47.85706989226803, 48.51317651810185, 50.81565095532326, 49.42059332324613, 49.16772596297726, 59.89227833286409, 60.498437496923636, 60.837051791529504, 57.5890939466415, 56.937603950500495, 54.42932275033767, 54.37615502265192, 53.35860198543918, 57.68934188350555, 59.81669818201373, 65.57999749337473, 65.65170626486501, 68.68947213695895, 66.77799132562453, 68.57504875429215, 66.46630410225161, 66.1217866405364, 62.506506673751346, 64.39188018921884, 64.37917170986053, 73.38076806837513, 70.51160135576802, 80.09329272854714, 8.176534618100813, 4.933820491836918, 1.0426115893548535, 1.7486094154657859, 0.6254212498184174, 0.2503541475462337, 26.04778370549602, 80.12930008672899, 67.08432059134206, 48.25873236502371, 40.78034531685614, 25.56741495286265, 29.78519843470666, 47.221555709838874, 58.79836067076653, 67.68369013263334, 43.857903634348226, 1.3561375463201155, 0.015899784273407873, 0.07427010219544172, 0.027745921547795017, 0.07854701019823551, 0.06863821448097307, 0.04146952677758471, 0.05424706896226253, 0.02989712325225194, 0.05321881808941403, 0.058424695800509185, 0.062459075688234264, 0.07306934364380376, 0.18998194515945452, 0.22666589687428168, 0.34517936168178437, 0.24404480061944456, 0.1642133827291189, 0.21135625789963433, 0.1763703707124918, 0.21138153880113558, 0.1288757539324222, 0.12548154009686363, 0.8149675207753336, 65.28412134416642, 90.01480256357502, 85.33156318049278, 65.98545289808705, 33.76798683597196, 35.135972269119755, 67.90329579384097, 54.86423515504407, 92.5532114890314, 54.12620982816143, 0.36040710585732616, 0.22890072856699267, 2.1953500951490095, 10.067621065724282, 7.074843798914264, 10.507821806015508, 7.654748578225413, 13.580032952370184, 64.59577675788634, 85.45508646195935, 79.62405174009263, 79.51872825622559, 79.04993441797073, 80.79098040057768, 80.96757335047569, 78.67622667743315, 78.9868470161192, 75.57988412918584, 69.0058034466159, 75.29958371193179, 74.76134823214623, 71.77621272302443, 76.1743507077617, 73.01102976645194, 72.97987045780306, 72.9194502676687, 74.84574979351413, 72.64447642910865, 71.89659026361281, 66.4028166186425, 58.90803014078448, 54.87733979378977, 54.459815256057254, 52.200012283940474, 57.12651706510975, 52.756000411125925, 54.73093340473791, 52.14942155345794, 54.120153688615375, 49.839922151257916, 49.3571803646703, 58.554922688391905, 71.32841925467216, 69.34746542284566, 68.92291592013451, 70.20214988339332, 70.70919467556861, 63.56932778512279, 68.80813952415221, 66.92003603904479, 66.2803602218628, 65.61677755848055, 66.38116513529133, 61.31445915468278, 66.52517887853807, 64.07351316944246, 65.40653459487423, 63.2087403728116, 61.8498940621653, 59.66063099522745, 60.374976973379816, 60.23514447673675, 68.09619795891547, 60.22432265743133, 69.61677535887688, 21.55126875446689, 24.972581632675666, 66.89774128698534, 61.45302472576019, 65.02274244062363, 60.681459211534076, 60.54055590783397, 63.64848905994047, 64.00177694136097, 58.46145260718561, 58.654692096094934, 61.00235616007159, 62.58221626281739, 61.31522009449621, 59.40171926252304, 61.615195120534594, 59.060453445680686, 54.15415671563918, 58.26764829697148, 51.947313585589015, 57.4718503798208, 61.63409702239498, 64.35212696752241, 64.67780528529998, 62.86677637407857, 59.84124829692226, 49.706514496957105, 47.13863288202594, 51.00464643970613, 51.831431081218106, 53.46086602057181, 50.79731779713785, 51.1386267600521, 49.72656173090781, 53.71557297245149, 54.180789609109205, 50.99311074902935, 63.55153983639133, 62.21172878819128, 65.68017482757568, 60.14031725545084, 61.74481376524895, 57.967610513010335, 58.07500108595818, 56.091038796209524, 62.39138510919387, 62.860524116023896, 69.15148027481573, 68.87569058325984, 73.26539547212663, 69.21627783006238, 71.79950375710764, 69.06952627243535, 70.14350260457685, 63.72491644274805, 67.77322999892696, 65.51390163360104, 77.97191019981139, 75.03247814793741, 84.60686606745567, 8.596307654534618, 7.781736783442959, 6.137951852813845, 1.7845543834470936, 0.6938339433362407, 0.3170991749052079, 33.26764537442115, 88.24278554608746, 74.02634313029628, 65.30157589143323, 70.53825778345909, 30.295059488665675, 32.559108426493985, 57.79628530625374, 69.7699046904041, 76.96797170946675, 55.21698174938079, 2.680112147523511, 0.232380943432931, 0.1519441628648389, 0.19267161857456933, 0.2284852484421384, 0.15585574651918105, 0.24250897819236403, 0.11810570684892517, 0.20795288165250134, 0.1765905290601715, 0.15346397405430195, 0.24468485175842242], [0.05351003492251039, 0.044810754141860434, 0.0652071901206528, 0.03683374488666173, 0.0653291589790775, 0.03760243750988476, 0.03163222430063592, 0.12734738554084493, 0.038044225094058824, 0.04811551955138003, 0.04183352196348771, 2.239619435802583, 55.49202226823377, 69.74228335965064, 67.27022524802916, 46.8612075621082, 25.316810800183205, 54.994571593499955, 54.3640584330405, 47.424887457201564, 87.88826604043284, 15.728884820015201, 0.15259922932713263, 0.06511208030485338, 1.0569854825735092, 2.0842504309069727, 1.1013826679798866, 4.116426494813735, 3.142258058632574, 15.22979655573445, 65.1312351995899, 74.19355377074211, 71.1786945404545, 72.55496794177641, 74.3305072476787, 72.28826245953961, 72.01518704814296, 71.67265430573495, 67.71462194381222, 71.66939873849192, 66.51645552727484, 56.206383935866825, 78.12056802934217, 68.28157701799947, 72.57059466454291, 68.8897640474381, 70.06216049194336, 66.04464146398729, 66.48936763886483, 65.68008461306172, 62.889475130265765, 58.26678929790374, 54.67456502299155, 50.18372181923159, 51.78103254687402, 46.842348806319706, 51.53637078500564, 47.5866852268096, 49.12842773622083, 46.49665071118263, 49.508517173028764, 47.266647277339814, 47.18057086390834, 54.746689565720104, 61.85876646349507, 61.71049302624118, 54.93021726608277, 57.554675148379424, 59.9288034439087, 57.923840784257465, 62.74865811870944, 58.89140321362404, 63.353973973181944, 57.9896189320472, 62.226951506830034, 58.90739471681657, 59.289472795301876, 56.33524164076775, 62.26750096967144, 54.90511409697994, 54.87054624865132, 49.36164009955622, 52.844661666500954, 49.53343599073349, 63.422289894473174, 55.93896458225866, 67.2653458195348, 19.489955363735078, 25.129549003416493, 69.07620999120897, 56.0045309220591, 63.577286274202415, 60.38106841425742, 58.09779790139968, 54.46117631850704, 58.59273041448286, 58.68172507132254, 58.12692934466947, 58.32701729189966, 59.54539175956481, 57.73852448309622, 60.647911179450254, 55.63771478591427, 53.046636273784024, 51.4891101467994, 50.882617581275206, 52.30069168152348, 51.01440137432468, 51.30385268119074, 52.387615326912176, 53.99160585095806, 56.71039281352874, 55.21707588626493, 48.646666542176284, 44.511872568438136, 44.67984022632722, 46.413245431838504, 46.1807704740955, 44.38886311746413, 44.31850364131313, 47.65258104570451, 46.111505339222575, 46.319755738781346, 46.01809801593904, 52.43263629175002, 54.99900387179468, 54.68463766959406, 52.35490668204523, 51.15087239973007, 49.48497118488435, 49.18667493327972, 50.933376973675145, 54.60038515829272, 61.120799972165024, 62.93624547220046, 63.40564727783204, 64.64175085867605, 66.59042358398438, 64.58074623538603, 62.22069140403502, 57.73876374767673, 57.24467062181043, 62.58674267799624, 62.63504274429814, 65.94706858358076, 66.30538494356217, 77.08868657388996, 35.13974166685535, 2.9232042258785618, 0.51927094257647, 1.3152058975350474, 0.1043059888686384, 0.048564703714463024, 3.341514708534364, 60.167601262369466, 68.66942882537842, 49.61461728618991, 45.56291872455228, 27.45334544489461, 28.542111073770833, 38.66410109304613, 41.965391405167125, 55.988633555750695, 49.19833221743184, 9.124152775733702, 0.586370132382839, 0.08648023369812197, 0.06124987484767072, 0.0411503630570106, 0.08316946982015526, 0.03361866539043765, 0.021417024057178248, 0.07329045960138883, 0.035044623148297115, 0.07971000061520646, 0.04355786330697518, 0.04017474242456017, 0.11311399284750225, 0.014071284658125332, 0.06652375052292502, 0.11720063525342173, 0.07943810835000008, 0.06701476691711335, 0.04820062808932797, 0.0034971695887150186, 0.11017998334981742, 0.1338254173676814, 4.910068088962186, 77.7572702592419, 77.81064587254679, 79.72870057629001, 55.684500817329656, 34.88258323361797, 46.027088088373986, 55.566978762226725, 55.33733183337797, 95.17765368184736, 17.875601937693936, 0.3003796430364732, 0.09244694780077665, 2.7542657813718243, 3.3560774883916302, 5.077919546634921, 3.60338096657107, 2.051560539872416, 17.931507479759958, 68.4614412246212, 76.88331127166748, 72.76561490951046, 75.63242035527384, 78.22945302532565, 73.25008253897391, 74.77452739592522, 71.72727723275462, 70.4132910697691, 73.67216094847649, 68.44329634020406, 59.1623644674978, 75.84027459544521, 69.36282542444044, 70.85849577380766, 71.25711056493944, 74.63295336692565, 70.15862726396131, 68.01140416053035, 67.87878882500434, 65.2848469826483, 60.277812019471206, 56.15433800605036, 52.10192557304136, 51.72464847564698, 49.55257715717439, 53.78983912929412, 48.56643446030156, 51.111625163785874, 48.88276969232867, 50.19660288287748, 49.388386741761245, 50.42708135420277, 57.053651194418634, 65.12917987761959, 63.62419782146331, 57.0969973071929, 59.64559262798679, 60.11086810019709, 61.04769483689339, 66.57008217227074, 61.5439413439843, 65.80218799652593, 62.778566191273356, 64.51573687215006, 62.470997456581365, 61.09293153209072, 60.29768274676416, 62.81689559259723, 58.50903880211615, 56.61284346734324, 54.13480374120898, 54.80384634387109, 53.15607432396182, 65.08901088468491, 59.540406427075794, 65.83754031888901, 23.60192898781069, 33.44164563763526, 66.29835605621338, 59.54239506875316, 62.825544418827185, 63.118886716904186, 59.020143247419796, 56.66708984682637, 59.191084061899495, 60.11486499540268, 60.18020383773312, 58.873760392588956, 59.64488660135577, 61.088142318110314, 61.6062678060224, 58.172526897922644, 54.2430886145561, 53.04466332158735, 52.31609482919016, 55.19759347361904, 53.399198516722656, 54.20081330883888, 54.90461595596806, 57.52335894492365, 59.07192637843471, 58.46145260718561, 52.175673977021255, 45.417602754408314, 46.44775836698471, 50.45717770053495, 47.758720382567375, 47.116832348608206, 47.03475283038232, 51.57975612148162, 47.56799121056834, 46.924020398047666, 49.203042984008796, 52.59106474538004, 56.230777155968454, 57.25563756881222, 55.14766562369562, 53.99659118344707, 51.38752075933641, 51.44923925399781, 54.26221409151631, 56.848377873820645, 61.667735268992764, 66.32097244262695, 67.14805126190186, 67.75950170332386, 67.79614448547363, 67.25781486880395, 63.410875797271736, 59.42513581245177, 58.170173475819254, 63.81063592049384, 65.01440740400746, 68.64088181526431, 69.42403793334961, 80.83382052759971, 43.28645352394351, 2.479398827398977, 2.257999662430056, 2.2481194571141274, 0.5908440245736031, 0.07860275075560616, 3.4396541262826617, 64.35141309615105, 74.79397450723957, 55.539879106706195, 43.2602560135626, 22.904172674302135, 36.98527174611246, 49.21158198387393, 49.964826107025154, 62.853930611764234, 60.254673957824714, 14.336980773556618, 0.7874625740993408, 0.18822915131045928, 0.05714750465666575, 0.04219133098940215, 0.058879932058193994, 0.007850325604405014, 0.008697116582263863, 0.007739243812994251, 0.0557877866911792, 0.02959148098354138, 0.04473052558399016, 0.2481191932794548, 0.19648082223871063, 0.12505926477212098, 0.1003419052088453, 0.21337493022363033, 0.1019135882116614, 0.1420953518320476, 0.16960613609802339, 0.177458813113551, 0.24662677739416403, 0.3489112823961243, 8.980824466674559, 92.91393618429862, 88.9778926295619, 88.92589769055768, 62.214125356366566, 37.85897970199585, 73.39623789633475, 72.57290886294457, 61.636552426122854, 102.79570456474059, 21.344079356039725, 0.4172997981790574, 0.1664262736636785, 4.763956858265785, 6.196237783278189, 7.2368509250302475, 14.500566163370687, 6.558058781008567, 20.648301878283103, 74.63336129342356, 80.67587452550089, 76.58260668477705, 78.94640737964262, 81.84372102060627, 77.07643308947164, 78.83042289364722, 74.89174350615471, 71.95880689928609, 77.45695006462836, 70.97993235434257, 65.69276955819899, 76.74361998035063, 70.96795343583631, 76.4820606477799, 72.19870690376528, 77.85991868665143, 74.51605104630994, 70.02385462484052, 72.50405557693975, 67.00787359668364, 63.02529504222255, 60.76651580872075, 55.6593741140058, 56.79584949247299, 51.17576376084359, 56.34450627911476, 49.89316832634711, 53.63482313771402, 50.682572780116914, 53.28833272380214, 51.418570241620465, 53.346446560275176, 59.82310341250513, 66.80920554745582, 66.4514304745582, 58.56315966575377, 60.342868451149236, 63.72148829121744, 63.35415440220987, 68.00767790886664, 64.9978667689908, 69.3371182103311, 64.75748431298041, 68.6362220394996, 65.69463268403085, 64.09197576584356, 62.41283655166627, 65.39299849540957, 60.40856422916536, 58.45117599733415, 54.596270591981956, 59.366296337496856, 56.04310743270382, 69.47230662069013, 62.80068835904522, 69.90102952526462, 23.40112913039423, 31.94313745344839, 71.61817258404147, 60.877354145050056, 68.85763983572684, 66.8401530481154, 60.46641918920702, 57.41093204867456, 58.82234988674041, 61.82648535697692, 63.49901537741385, 61.97202097985053, 65.10248814859699, 63.691439013327326, 65.38502039447908, 60.82764594785629, 57.027175195755504, 56.05734563642933, 54.559372855770974, 57.69461354901714, 54.98323986607214, 55.91423796069238, 56.394594946215236, 61.30209192152947, 63.64549236912882, 62.28023690562095, 54.92974658166209, 48.80835448541949, 47.75546089295418, 54.0015882830466, 49.5299921497222, 49.383381797421364, 48.23990891056676, 52.23044595410747, 49.85769048813851, 51.16759346377466, 51.75332884634695, 57.63734694450133, 58.88495483706075, 61.54007780936457, 56.9416832154797, 57.361223851480794, 55.31857505921395, 54.91006020576724, 56.27784559803625, 60.70186730354064, 64.36720063609462, 68.84100898619621, 68.53767641129033, 70.37249057523667, 71.00491785234021, 70.91704891573998, 68.1597952688894, 62.19677671309441, 62.385940859394694, 68.00847807238179, 68.08740400498914, 71.32171200167748, 72.36239525579637, 82.10341330497496, 45.50164345772036, 3.201440250681293, 11.116460888616501, 4.47971789106246, 0.7086142308769688, 0.1541319261154821, 4.793996330230467, 73.88090948904716, 81.00508689880371, 64.07278360859041, 60.34519049429125, 37.32964800250146, 38.20068482429751, 53.40585870127524, 62.05343761751729, 72.88602382906022, 73.41462596770256, 18.435098624998524, 0.9434006903921405, 0.27093465530103256, 0.23020939060276557, 0.16942189195223395, 0.17083783694092305, 0.17173890955746177, 0.10186416021878682, 0.10556880820302234, 0.21096970525480088, 0.1330439157543644, 0.19700370789054902], [0.03783180806485396, 0.02500915479275488, 0.028563128604042917, 0.00993666120789825, 0.01945039591631822, 0.10217536811626728, 0.05503298324202338, 0.03454124592545052, 0.07743268168621487, 0.04259523169528093, 0.04381251859388525, 25.444099557015207, 77.23503804975941, 57.761427202532374, 57.86221250411003, 31.099047314736154, 19.946187811513102, 57.60873717646445, 46.74209694708548, 63.07906289254466, 71.70219759787284, 3.530674932464477, 0.16950659063314238, 0.10556120861081347, 1.76511658776191, 2.986846643109476, 4.669065408168301, 4.355121841353755, 2.6649391939563136, 27.607908402719808, 70.26650028844034, 70.90549361321234, 73.46429101882443, 69.35884029634538, 75.97314096266224, 72.68552011059177, 71.8636501989057, 70.11251588021555, 70.65393632458103, 64.10323689060827, 70.24215805915095, 55.27180079490908, 51.28979882886333, 65.21966895749493, 67.24231366188296, 70.0946298722298, 69.05018114274549, 68.16184274611935, 65.41717206278156, 64.9756504643348, 65.45079069752848, 57.74339998922041, 53.67401938284598, 49.04387320241621, 49.304863791311945, 48.76027799421742, 47.95340722607028, 50.570949969753144, 48.98500627087009, 48.18142637129753, 50.02878819742511, 48.473909670306796, 46.33668468844506, 50.58497244311918, 63.09167331264865, 58.99107848444293, 59.35843198530136, 55.93804282526816, 57.769997581358886, 60.32196221813079, 61.95546465535318, 59.45983702136625, 58.61498202047041, 58.141700990738414, 59.835643229946015, 58.391453989090465, 61.62006670428861, 54.935206520941954, 60.01541722205378, 53.54155701975669, 55.49237920391945, 49.43310960646599, 49.6619838283908, 51.91412248919087, 63.0344694660556, 58.35850607964301, 60.6409489723944, 18.572505135690015, 25.781770521594634, 69.02110069028794, 54.398292879904474, 57.8498766499181, 57.89490153712612, 62.84266948699952, 57.39225764428416, 53.51771685384936, 45.6770557741965, 57.89332866668702, 55.806498296799205, 60.65121381513534, 56.18813706982521, 53.48427472576019, 59.26091401807724, 55.64999964929397, 54.43137807230796, 52.678482609410445, 55.02443651999197, 53.63037516993862, 54.85635511336788, 51.30487249743555, 53.05775227085237, 54.97403406327771, 52.68604886147284, 50.588969338324766, 45.94696191049392, 45.61419586981497, 45.77305970653411, 44.88000269859068, 46.09322709421958, 42.90703089006486, 46.658417101829286, 46.09760445933188, 45.69676176194222, 46.463914609724476, 47.288592938453924, 51.09412747044718, 50.14446673854705, 48.708887100219734, 49.682211491369436, 47.616397180864894, 48.33476751081405, 51.13852870079779, 53.153599308383086, 56.24627836288945, 59.29627810755084, 58.359631799882465, 59.05544065660047, 58.637214014607096, 56.515419637003255, 55.1691915912013, 53.642718868870894, 54.07626628875733, 60.177262060103885, 62.72478657384073, 63.801759596793886, 67.30525201366794, 72.30262617911063, 63.79675857482418, 1.634121681413343, 2.1017459179124525, 2.2985280425317827, 0.5966985297779883, 0.13856416147562767, 0.0365709001198411, 32.98062593706193, 74.46251853819817, 61.15114735018823, 48.31346511840821, 51.00183802266275, 20.595691127161828, 19.794284220664732, 44.68645334243775, 49.493949490208784, 53.16274235325476, 35.995948007029874, 1.311268941048653, 0.11331005772996335, 0.05593433931109406, 0.06590465188867624, 0.003311709278345769, 0.037723249575543794, 0.0369361823334569, 0.03864457372636084, 0.10280094785435547, 0.04177738304039644, 0.04832795190234338, 0.019229105673730373, 0.09416629425099782, 0.019517735044862476, 0.030638826597902565, 0.0867624604894269, 0.05847889269071241, 0.08976472076028587, 0.01663620640043049, 0.08275741410832252, 0.09709498709848813, 0.0835001823161879, 39.67226397606635, 88.51918712739023, 68.04731738182807, 66.68811413549608, 40.53952747775663, 25.144938422787575, 46.918482011364354, 57.716531753540046, 67.83202632780998, 81.71836991463938, 3.3157261052439293, 0.09960484435601581, 0.5868015931017938, 2.9589884992568725, 6.123206682743565, 5.213840459623645, 2.064261297064443, 3.252473963845161, 30.608298009441747, 73.60530807125953, 72.31473845820274, 74.98447618176861, 72.46881700331166, 78.32651599760979, 74.1971545065603, 74.2322204959008, 71.4568768778155, 73.06144006790655, 67.81422661196801, 73.28763531100365, 60.55842622633904, 51.328053705153934, 67.7136178170481, 70.45094582342333, 71.93677102365803, 70.84767003213206, 70.09634002562493, 68.35427422677317, 66.87550144810831, 68.05271456318518, 60.95943366327594, 56.38229047098468, 49.884829367360766, 50.88541423120807, 50.10974199541154, 49.46705379793721, 52.50601991530388, 48.85730958754017, 49.47771480006557, 51.15261393208658, 49.53711517395512, 47.32333337107013, 53.66599813584359, 64.42937804806617, 61.3138472649359, 60.05149910526892, 55.40011329035605, 60.861311651045284, 62.84805882361628, 63.844329080274036, 61.98192496453563, 60.5517150509742, 62.96341965275427, 59.58132067034322, 60.13718328168316, 62.80860370205295, 58.559664833930235, 61.47448401297293, 56.11385914587206, 58.55876661116078, 51.57096608992546, 50.2698217668841, 53.956865418341856, 64.37304889002155, 62.80490882935063, 61.765539569239465, 20.122623866604222, 32.17584186984647, 67.24974263098933, 57.6819952841728, 62.08127860100039, 61.13723078081685, 64.98196155794206, 59.52688209472164, 53.652932720799605, 45.77309500786566, 57.44120097929432, 61.563812071277255, 61.734697972574544, 59.39019926132695, 57.140684666172156, 61.52924030057846, 57.83182198001493, 58.4865753881393, 55.424569268380445, 58.426308170441665, 57.068269868050855, 55.48233793627832, 54.16172689007175, 54.087739221511356, 55.659315278453214, 53.730411298813365, 53.76458298775458, 48.446386398807654, 48.81739162629651, 47.206811520361136, 46.385149494294204, 48.60147691542103, 45.34588221580752, 48.270562233463416, 50.7223887597361, 48.898757273151034, 49.009470093634825, 48.582535789858916, 54.14645710299092, 52.86623470244869, 51.98367003471621, 51.954428765081595, 50.12542755373063, 50.86275077635243, 52.84568148274576, 57.15200070411929, 57.370974863729174, 62.71305476465533, 60.36178212012015, 60.23204580430062, 60.388830784828436, 57.41145372390748, 56.13285126224641, 56.07665546478764, 57.676900125318966, 61.15944316310268, 65.53103846888389, 66.92682173944289, 71.40969076464253, 74.23513089456867, 73.32645893096924, 2.4406303657639414, 3.3087827745945226, 1.2726935335705358, 1.332218197564925, 0.2148096750099813, 0.04119591847542794, 34.45216194275887, 78.36330782982611, 69.29325826706426, 48.61795087014475, 41.8333448133161, 28.337526129138087, 26.921870170101045, 55.12806553994456, 56.27222091920915, 63.199075652707016, 43.56969964119696, 1.8178778598385474, 0.08720476901338947, 0.12805486773891797, 0.045594305040374886, 0.05342050988767898, 0.06191374749065407, 0.0919566055639617, 0.021356972340013713, 0.014985810736224297, 0.02190243077254103, 0.07447021968302227, 0.27191484947839095, 0.16949778062201318, 0.16035723319697767, 0.09590239504412298, 0.15660315721986756, 0.1685932912533322, 0.16298814766830014, 0.11615936088586047, 0.15115778893232346, 0.13218940596186346, 0.12431967582914139, 48.18484275571762, 105.81712984269666, 74.53589823938186, 80.95876370706867, 47.23659407707953, 30.776353920659712, 72.38713756684335, 65.36154500899777, 76.54042551594397, 88.30974824966924, 5.962929321873573, 0.25040846318006516, 0.9149834862159145, 8.067759448482144, 13.243154306565563, 12.99907893903794, 13.558794298479635, 4.791827259525176, 34.98609850483556, 80.0659381189654, 76.35351673249276, 80.16647631122221, 76.66300742856919, 83.02405634234029, 76.27690499828708, 75.98623383429744, 75.13366745364281, 73.47263782255112, 68.65473562671293, 72.8525738562307, 65.14689330131777, 58.92571610789145, 68.61402142432429, 74.1026096959268, 73.341567900873, 74.04431543042584, 73.24078652166551, 70.79938565531086, 69.95324411699849, 72.12504479192918, 63.09500732729512, 59.31770993817238, 54.10560169527608, 53.019305198423325, 52.746194485695135, 52.70107546160298, 54.89721052108273, 53.65320336434149, 51.66026669163858, 55.991987182248025, 51.42109624801144, 49.991443311014486, 55.24705848386211, 68.28464431147422, 63.247018783323234, 63.76053156391267, 55.95731342992475, 64.22243379777478, 64.88838557274111, 68.94345345035677, 64.90891133585285, 63.30754879982241, 65.58462589017807, 63.3118006490892, 62.44477641197943, 64.5337680078322, 60.48842760824389, 64.47953731782975, 58.2029527233493, 61.61545399696597, 54.38783191865491, 55.3754964951546, 57.90717855576546, 68.16982869179019, 64.6976799349631, 64.92400461627592, 23.11653175661641, 34.100952917529696, 73.14527680796962, 61.176105391594675, 66.33788570280998, 64.05815709021785, 68.98408920534196, 60.87827982441072, 55.830228636341715, 47.68936895555066, 60.04069297544418, 62.21078741934992, 63.09196356804141, 61.53453157794092, 61.369591989824855, 63.32882373563705, 61.046121966454294, 58.600277054694395, 58.01519670794087, 61.213544414889434, 58.6389555469636, 58.221658506701075, 55.81108354753064, 56.91718016901324, 60.35117210880403, 56.46595462676018, 58.41595703555692, 52.19985538913358, 52.04940111406388, 49.31998452832622, 49.51169037049817, 49.88271520983789, 49.37796892658357, 50.937048312156435, 51.76713951172368, 51.20819783979847, 50.445743991482644, 50.574797814892186, 57.78463586684197, 55.495132707780414, 54.87115421602803, 55.1094421263664, 53.214113635401574, 53.341010155216345, 57.07513793822258, 59.614896159018244, 60.85851500111242, 65.69409139694707, 62.406866704264, 62.95830880441974, 66.3518964090655, 59.84515105524371, 59.47527547036449, 60.66080793257683, 59.39714577890212, 66.67891225507184, 69.5064861543717, 67.8651075978433, 74.78664751975768, 77.5685493407711, 77.97019220167591, 2.7332749722465395, 7.332415551908555, 6.885440388033468, 1.8032914231861792, 0.5293812194178181, 0.1577308692879254, 41.26488354898269, 87.65883876431374, 76.76602455877489, 64.74191642576649, 66.12585806077527, 28.087555439241473, 32.80072250673848, 65.08471196697604, 67.69391967404273, 74.95910629149407, 54.826611780351215, 2.6397622352646244, 0.21838994095883063, 0.31041983815450824, 0.1989359808184447, 0.16894063551820096, 0.09797894531079838, 0.15500201813636288, 0.08808655919687403, 0.18788315536033726, 0.199167232119268, 0.13941917688615862], [0.0348390166407391, 0.01771974966921393, 0.09985455837581428, 0.015707110287621617, 0.08692217449988089, 0.05350782092840922, 0.05389995452377105, 0.051824116718865214, 0.10076502323030465, 0.12771643307660857, 2.4025394935761732, 66.48447252088978, 78.67191991498395, 47.35928973843975, 59.100657739946925, 60.08917739314418, 39.163611012120406, 86.85966368644469, 47.210894707710516, 85.70614168720861, 38.69581737825948, 0.6891440756378636, 0.054234796233715556, 0.8355648058556742, 2.0491460758832196, 2.9898075422933026, 4.879298565849181, 1.2898293882608414, 5.627038132759833, 50.33979685075822, 65.5314463953818, 69.434949967169, 72.65334883043843, 73.34185815626576, 71.94359594775786, 73.45529310164913, 70.96434485527777, 68.75865490205827, 67.38850824294552, 70.21900823039394, 67.02197843982329, 70.10984082375803, 56.637150395301084, 56.77610820339572, 66.78508297089608, 65.54191520137172, 68.49886063606509, 68.08972604813115, 66.54049965643114, 68.10041842922088, 64.33025975381175, 61.27830666880454, 57.529823010967625, 51.05097747618153, 50.02631710421655, 48.75392375453826, 47.8112683757659, 48.98294702652962, 48.28649097873319, 49.38376618969826, 48.52484556936449, 49.3525323560161, 47.243058143123505, 47.477494285952666, 58.0609001651887, 64.09387811537712, 64.35136602770898, 62.32534808497276, 61.87492662860502, 59.80599795618365, 57.01891468417261, 58.307056350092736, 56.47585076670493, 57.55956242161413, 59.9385936798588, 57.70590605274324, 55.10934014474192, 57.47791044173702, 60.93924522399903, 56.78687903188891, 54.22767762214907, 48.86159673813851, 47.08919140600389, 49.21440609039799, 59.66561240534629, 59.87196830011184, 57.859855159636474, 16.758471688916607, 26.223813795274307, 65.66603468310448, 53.765265480164565, 56.075980817118, 54.15485881990003, 61.25140313179263, 57.24929117387342, 62.522035337263546, 44.05962720994027, 44.18160507755895, 55.14587702289705, 53.69719666819419, 53.72801473063808, 70.46833761276739, 58.61085960941931, 57.127015206121634, 59.01389098936512, 54.330275058746345, 56.287718203759965, 56.14502237689111, 56.600637051366995, 56.513364315032966, 55.342897676652484, 52.22720607634514, 49.170153910113925, 47.82298057310043, 43.93278168093774, 46.12742231738183, 45.85322903048608, 44.862375567036295, 46.909244829608554, 44.45638671998055, 47.83527328122047, 47.59771885410432, 47.12708150186847, 46.459780431562855, 44.97188814224736, 47.00271098844467, 47.051030666597434, 47.20852951849661, 45.51115128301805, 45.90963271356399, 47.592164777940326, 47.208058834075935, 49.88465678307318, 50.0439207015499, 49.295026486919774, 48.9031542501142, 49.717210800417014, 49.36152242845105, 51.24649586216096, 51.11052690013763, 54.1886265047135, 55.19117255364695, 57.65427197179487, 61.20737452660838, 61.77016012130245, 70.16254178939327, 67.22420800116755, 82.03506208235218, 19.677770214696086, 1.8760987034728451, 1.6705630743695845, 0.5823451677157033, 0.2700062793108725, 0.3125309313256895, 6.978111776613421, 61.59553620123095, 65.20808227600591, 53.15689409932783, 46.50559371517551, 22.737924975733605, 13.125006633420146, 33.03437417553317, 45.466518632827274, 54.4497347647144, 49.32722914603449, 10.03005946836164, 0.5212787058084242, 0.10962483007460834, 0.010350269205387562, 0.03243351204981727, 0.0797806645653421, 0.08125542978485746, 0.020745789309242563, 0.04791346003091143, 0.07894517673600106, 0.0505107585641165, 0.042535388737075755, 0.06419018158809313, 0.08744932726145753, 0.02294911946650715, 0.1458737894051498, 0.021097963758473916, 0.03146320615234154, 0.014807168608381143, 0.09589778319481881, 0.2181697060023585, 3.2164060540737647, 80.52209408052506, 85.06700715711041, 58.82813146037441, 63.219977963355284, 71.45420182135798, 40.42377833397158, 79.41302822482201, 55.72690163889239, 91.71131395524549, 45.73063927312052, 0.3101839750043808, 0.09709148607667416, 1.6986917391900094, 4.57036925900367, 5.915977570318407, 1.5566618572319708, 1.3384057365117537, 8.328868689075593, 53.482850905387636, 68.33924370427286, 71.56540886048349, 76.51645198945077, 76.12697632082048, 75.35383009141492, 76.03680103055893, 72.63853796066778, 71.00089350054341, 69.69436768562564, 71.41198142882317, 68.0776765269618, 71.09211998601114, 59.73293988935409, 59.35700032018847, 68.16630640337544, 67.48671654731997, 69.71512486857753, 70.97999511226531, 68.32524868749803, 70.05233103229155, 67.85762371555452, 65.73959089094593, 61.89491502700314, 51.88194336429719, 52.06323139129147, 51.064960725845836, 51.58696543785834, 49.2042040055798, 50.88970530417658, 50.10697280206988, 51.941963472673976, 50.496977990673436, 48.59506384018929, 49.74365934248894, 61.4123026786312, 66.9215500739313, 63.68804616312828, 64.822462297255, 63.31831178357525, 64.24182599590671, 58.7522179080594, 58.349594454611506, 58.587121425136445, 60.36926208003875, 61.55027597181259, 61.50891065597535, 59.95742890142626, 60.986219529182684, 62.98819726513278, 61.08497696538126, 56.97416044050648, 52.47807302782613, 48.19671184785905, 51.74413873303322, 62.219620596977975, 64.22635224557692, 58.19474320257864, 17.8530934164601, 32.24076297975356, 65.72060661931192, 56.82381991417178, 58.16324264772477, 57.1123847653789, 64.3351274151956, 58.10436002669796, 63.51657190630513, 46.74261077757805, 44.86457601670296, 54.72887416039744, 54.53395589705437, 54.58581747547273, 64.95832535528368, 61.1919282328698, 59.5808695977734, 62.238851977932846, 58.323761724656634, 59.20543993673017, 59.7442598496714, 60.40313959121705, 57.90021242633943, 56.543068424347915, 53.36007679662397, 52.570193813693145, 49.988376017539736, 46.17988401843656, 48.27384917966781, 48.68119124443301, 45.71184719762495, 49.95910729131391, 46.040459448291415, 49.16507836311094, 50.65992109237179, 47.41934907051825, 49.69775192199215, 47.88698580957229, 48.84924911683606, 49.168604573895855, 50.9169343979128, 49.694033515068796, 49.75069607457807, 51.6482210928394, 50.27063369750977, 51.69991793171052, 53.09133952663791, 51.59027591828377, 50.72379296825778, 52.39249475540654, 51.53171100924092, 53.413322971713164, 54.44942881984096, 56.87971368912728, 58.51008215258199, 60.9267524750002, 64.80516856716525, 63.48379265877509, 73.90161175881663, 70.62222788410803, 84.36228275299072, 26.09213786740457, 1.814188012673009, 1.950676688744176, 2.421955716225409, 0.35438087438383414, 0.16083979198048193, 6.668605881352579, 66.92679820522186, 71.18912020037251, 58.07502854254938, 43.01134240242743, 25.001338489594, 19.32848511203643, 40.90158577888243, 55.41789339434717, 63.0761093478049, 61.7090888177195, 14.219778391622729, 0.42720133138279764, 0.059770179852362604, 0.027648810327293414, 0.054884902276699586, 0.020913807712795756, 0.030068594797123826, 0.05625624179599747, 0.05810408034331857, 0.034775523273574735, 0.06914332689296815, 0.13439518760048574, 0.11959990005820029, 0.2293600289211158, 0.11447221311109682, 0.3421433245943439, 0.22470998247304272, 0.1374523533928779, 0.1109851417582362, 0.3621092612945265, 0.469857566659489, 4.224021521306807, 92.67066294147124, 97.76348406268706, 68.22415351867676, 74.24314037446054, 70.53309594431232, 54.59919275776033, 104.09644880602437, 63.18595532448062, 101.67749958653604, 51.87319255644276, 1.6064377153112044, 0.16766991015643845, 3.4737620767085784, 7.955390897489364, 11.110114493677694, 14.234762826273519, 7.770138334843421, 9.685886194629054, 61.80667346523654, 69.75201083767799, 74.83959951708394, 79.24815531699889, 80.18824546567856, 76.84681753958426, 77.1843610271331, 76.42116192848452, 72.03761516078826, 71.41719818115234, 74.52252295709427, 71.59364992572416, 72.38392122330205, 61.71458798070108, 62.322437686304895, 69.43354575864731, 69.19033527374268, 71.674317390688, 74.42040012728783, 70.94947122758435, 73.32131278130316, 70.46752960451188, 67.25744616600775, 63.27879782645934, 54.42914624367991, 56.83402984373031, 52.99639071187666, 54.168877370895885, 51.96616841900734, 54.61270924537413, 53.454664753329375, 53.394083746017955, 54.04385182165331, 52.088122752404985, 51.77428999254781, 62.768030704990515, 69.59964244596421, 68.15404507421678, 66.97494137671687, 65.97443103790283, 66.73357440579322, 62.802457347992934, 62.55574026415425, 60.72932389474685, 61.62657391640448, 63.23294531914496, 60.54239157707461, 62.244970875401656, 64.44796616031279, 66.79302184812485, 62.78712872535952, 58.753830002200225, 54.61077551687918, 51.81685947602796, 55.842995951252604, 64.59985210049537, 68.31224210800664, 61.954268332450624, 22.162364221388295, 33.98488606176069, 68.78151447542253, 61.0734804984062, 61.167672295724195, 59.67712063943187, 64.6038136943694, 61.242726848971465, 67.22710271035471, 49.87885167521816, 46.73018470887215, 56.02327592911259, 57.726659313324966, 54.60571173698672, 65.09484737150132, 63.589143599233324, 61.748532172172304, 65.05874195406514, 60.18249450191375, 59.70580101013184, 61.68344043916272, 60.78760247076712, 60.93835484596991, 60.03952018676266, 57.12457941424463, 53.901665902906856, 52.04589843750001, 49.9153297178207, 50.56767871302944, 50.725644326979115, 48.908316089260964, 53.64235408844487, 47.896693675748764, 52.08911511205858, 53.00856574889153, 50.48634444513629, 51.44070025413267, 50.27565433133034, 52.27093265902612, 53.66600598058393, 52.155105067837624, 51.96477205522599, 53.29153337786275, 53.93971289357832, 52.463438664713216, 55.702794751813336, 55.85855207135601, 54.48013705592002, 53.599427669279045, 56.059271520183934, 53.77711103808496, 57.233021182398645, 56.5176946117032, 60.733964058660696, 61.024548930506555, 64.95645046234131, 67.33358721579275, 68.0383429988738, 76.22145837353122, 72.86386243758663, 87.88595968677153, 28.715911296106157, 3.9240119293812787, 11.189304205679125, 3.7968190254703647, 0.5075940159299682, 0.22406610089444348, 9.228001448415942, 75.60747408097791, 75.86756644710418, 69.33918137704173, 59.493840048390055, 35.354507123270345, 23.95941968887083, 49.29637185988888, 66.4275981533912, 72.72684620272729, 74.58058188038488, 19.221482853735647, 0.8144053348129796, 0.21905694307098467, 0.16449574741625017, 0.09620226484032408, 0.1739864889532328, 0.13486973310430206, 0.21102307093960626, 0.1603995672156734, 0.1838294317525241, 0.22669148421095264], [0.05487022403207037, 0.014593789181221398, 0.06388694483546481, 0.09398916706202493, 0.0742248876861507, 0.001083112464027269, 0.12411516099687546, 0.12524555437266827, 0.1754503604024649, 0.3740102533371218, 14.498756970128706, 76.40882215192242, 63.3433404276448, 43.06632226513278, 57.90010652234478, 47.042652483909364, 38.1613120725078, 56.725078167453894, 49.90288403726394, 87.18038020595428, 17.94181742975789, 0.1288736548515097, 0.09922013798307988, 0.3551434383036629, 1.5676166694010458, 4.72768719157865, 2.289518113097837, 0.7802565672224568, 32.8198617119943, 72.09049655545142, 65.35452396638932, 69.56036383105864, 69.69177107657157, 72.0493273581228, 70.70390732057633, 73.33532348755868, 71.70889700612715, 72.80692531216529, 72.72896428262034, 70.97186011652794, 68.82248755424254, 67.13557812475389, 70.35632256538638, 67.29818390261742, 65.2814462877089, 65.92352651780652, 69.32824580900132, 66.22456842853178, 65.79161720891153, 63.29464027958532, 66.7960185389365, 66.35524611319265, 61.66781371639621, 52.69938099768854, 47.97125008798415, 48.535847817697835, 47.96066753325924, 47.50000476837159, 46.69325167132963, 48.07347097704488, 48.32715811267976, 49.04486948443998, 47.72236393344018, 46.01767047759026, 50.21373187341998, 56.610493967610026, 60.9886827776509, 60.73985938102969, 60.49791582169072, 59.42492792683264, 57.695550995488325, 53.418955495280606, 55.645210435313565, 57.87756466096448, 56.93708227526758, 57.147784156184045, 59.36905376372799, 56.70368163816391, 58.08959230299919, 56.97933012439359, 54.669920936707534, 45.04977856912921, 46.9834521508986, 51.389740820853945, 59.81331317655502, 56.51772599066458, 59.289084480654815, 16.730730725872903, 25.590127437345444, 64.32461546313378, 54.45016622543336, 53.36937281393236, 48.42400535460442, 56.857450316029215, 56.800705386746316, 60.663435920592285, 59.364641097284135, 61.09961132849417, 57.93112070329728, 42.59153896762479, 46.54958309665803, 58.61585278664866, 55.327690647494414, 58.950580012413766, 55.221115927542414, 60.234779696310724, 58.84854739712131, 59.619351971533995, 59.177265551782426, 58.153679909244666, 56.19482471096901, 58.39157558256581, 50.37414504635719, 46.01329703484812, 44.552096474555235, 47.04929697898127, 44.92205050683791, 46.662912138046764, 47.195240528352805, 46.17365921697309, 47.010951888176706, 46.51411310318978, 47.33825014483544, 47.61332596501997, 48.185274216436575, 46.572007286933164, 48.25292725716868, 46.28011626581992, 46.560844221422755, 48.16656451071463, 50.322918891906745, 47.1162518378227, 48.536757807577814, 48.00916764043993, 49.14110483661775, 47.814233687616166, 47.68728617698916, 48.292205872074256, 49.73270808496783, 49.709311146889966, 55.88762467907321, 57.191298930875725, 59.731598438755164, 63.07406579294513, 64.5830604337877, 66.53963673499324, 75.9172236534857, 70.79287452082481, 61.78466504619968, 12.255649566650392, 4.306355503297621, 3.44406777331906, 0.1329470209537014, 0.027058418922787233, 0.6566653184352383, 39.62257539072345, 74.05743183628206, 56.7629486514676, 53.58020021069435, 44.429667534366736, 13.839452632011907, 30.055712538380778, 48.11913521059098, 50.30472693904754, 57.89070460104174, 30.302282533337994, 0.5302951316679678, 0.030387310356262232, 0.02124619985660238, 0.07780256425781597, 0.09814686412292142, 0.03223965733101772, 0.03474004957224092, 0.04969242727383972, 0.024554763147006595, 0.06976678456750608, 0.01660470294976427, 0.010125914611102594, 0.03268277024730079, 0.015527989354825791, 0.03890610465239133, 0.14424310997128487, 0.06645367646049108, 0.05121621062919017, 0.19333598534426383, 0.5976201641944148, 19.084902001965432, 90.74342989152478, 70.77876967768516, 49.28912724218061, 64.3447607563388, 55.850840691597234, 40.392434673924605, 62.55304559584587, 56.47323062342983, 92.96461320692494, 18.787890326592233, 0.09178078838533933, 0.0323130332324053, 0.7746601417180031, 4.074797889878673, 4.099121487909748, 0.4506807005213153, 1.0632944924216117, 37.390087804486676, 74.67005898875576, 68.40975223049041, 73.4119430665047, 74.0255194325601, 75.20234031061973, 73.42226674479824, 75.58019007405927, 73.96838618863013, 73.39118588355281, 74.60999181193691, 73.58162480015909, 72.63274069755309, 70.28038547885033, 72.94746383543938, 69.6787017391574, 68.68882102351036, 67.40646485359439, 69.89764844217609, 68.02661511205858, 69.06100688442108, 66.23018526261853, 69.1923435272709, 68.37449796738164, 65.1179305199654, 54.43686154580886, 51.269308367083156, 49.44055818742322, 50.045572019392445, 51.292395437917406, 48.28996227633569, 49.581928253173835, 51.34273905907908, 50.68905253564158, 48.53473778693907, 48.25490413173553, 51.49932007635794, 59.302349936577585, 62.21606300723169, 63.161805291329664, 63.8495340654927, 62.90488612267279, 60.06225032191123, 57.4379022659794, 57.740179723308934, 60.22856666195778, 61.14897827948294, 57.92632364457654, 59.74394213768744, 61.26331144763578, 59.871689811829604, 58.94419439377324, 58.17255043214368, 48.487120213047156, 47.5203618695659, 52.51306056976319, 60.746370515515736, 59.123568304123424, 59.30395810834823, 19.21199267910373, 30.626837092061198, 65.83268442461568, 57.37193976679156, 56.52828108879828, 49.53889985238352, 57.92038125376548, 58.325083563404704, 63.46117627236151, 60.05602944281794, 63.389914651070875, 59.89703224551294, 48.33500677539457, 45.400893457474254, 56.48486829573109, 58.444049050731046, 60.4776567797507, 58.92709678219211, 61.8480230915931, 61.52587882934078, 62.447133756453, 62.68963036998626, 61.38422243056759, 59.05283620280605, 59.184933785469305, 54.5304375310098, 48.67748852699034, 47.05396459948632, 48.117652554665845, 47.293852836855, 48.91233259631742, 49.692217457679014, 48.08022137611143, 49.81223806258171, 49.28226701674923, 49.7460872896256, 49.775277568447976, 49.44531994481241, 49.67537872252926, 50.31326986128285, 47.34414938957461, 50.37287419842136, 50.67324930621732, 51.91739766828476, 51.29886734870173, 50.3419384648723, 49.29244556734639, 50.3169882682062, 50.27679181868031, 51.53499795544533, 51.112652824771025, 52.20678229485789, 53.92443133938698, 59.07791976005801, 59.97349885202224, 61.909282668944336, 66.32800917471609, 67.84278931156283, 70.01004003709363, 80.09646200364637, 72.23192153438445, 73.46413412401753, 20.486084415066628, 4.388602702848373, 4.580441905606178, 0.7412531310992857, 0.3008732488078456, 0.39450344239031115, 41.18506331597605, 82.2294625928325, 63.322610701284106, 51.22847257121917, 34.02192892566804, 21.774704610147786, 42.401005914134366, 56.76616499500891, 57.904087728069676, 66.80835831549861, 39.23675537109375, 0.9729627976494452, 0.035264651261029706, 0.051469226487942284, 0.0487970237079407, 0.08715344878334193, 0.04564128155189176, 0.0211933168071893, 0.05777943909408585, 0.07025482854054821, 0.10023400172471039, 0.18183787894104758, 0.1041177993700389, 0.1893070370199219, 0.2130880302959873, 0.2860108672851517, 0.13845404399739158, 0.2480081564957096, 0.21110099740326407, 0.3278734967593224, 0.6724189053620062, 25.504708020917832, 100.94691107350012, 80.73040331563642, 60.35304307937623, 73.41098600818266, 58.2436865375888, 51.53775930404664, 74.57516900954708, 62.46111308374713, 103.29140586237754, 22.923441317773637, 0.15302730393746208, 0.29048684323506974, 3.8875527631851936, 7.264528149558652, 13.464739784117668, 9.768052985591273, 1.4915676727410287, 41.561120556246856, 79.75882437921341, 70.10794239659464, 73.54229127207111, 75.46444877501457, 78.32987354647729, 75.2221247457689, 79.28659454468759, 76.60250879103138, 76.89788679922782, 78.17526155902495, 76.78894689006191, 75.33630494148501, 72.65219565360778, 76.38193822676136, 72.33546426219326, 71.47322531669371, 70.62288684229698, 74.93161047658613, 71.10707206110801, 71.84195949185279, 69.0440151768346, 70.74021277889129, 71.66837107750678, 67.10899229972594, 56.920953489119015, 54.33756674489668, 53.201918986535844, 52.768155836289935, 52.11068030326597, 50.92748557367633, 53.06037241412748, 52.2894109449079, 53.0853618344953, 54.013967283310436, 52.82923890698341, 55.77443292064052, 62.92350953625095, 66.5925181296564, 67.51851127993676, 66.53449058532715, 63.3090667570791, 63.16002453527143, 59.486422846394206, 59.824711584275775, 62.300009573659594, 62.91598250789028, 62.84907471749091, 65.11756966190954, 61.25894192726382, 62.02804419302172, 61.735709944079005, 60.311866037307254, 51.53053429818923, 51.04511353277391, 57.89301095470306, 64.29262853437855, 62.22995212001186, 63.841497129009625, 23.86642029208522, 34.648300063225534, 69.74847285978257, 59.319573064004224, 58.903943031064934, 52.572527623945675, 62.721856563322014, 61.17377942608249, 66.75599467369818, 63.702919790821696, 64.50376972075432, 62.58549144191127, 50.899805407370295, 47.92319713100311, 66.25522567379859, 61.459198536411414, 64.42052525858726, 60.07819867903187, 63.58901023864747, 63.57287360775856, 64.01417555347567, 65.07270951424876, 63.85817896935248, 60.518833821819676, 63.14952042794997, 56.176934780613074, 49.447296819379254, 49.06350074275848, 51.27170885762861, 50.72210242671352, 52.30149968977898, 53.54414186170025, 51.517013888205256, 50.91548704331922, 51.1760030254241, 51.58221936994984, 51.5709464780746, 54.03278289302703, 51.59257834957492, 54.20298630191434, 50.277317416283395, 52.249842074609575, 55.334841128318544, 56.18614450577767, 53.71165844701952, 54.33626844036964, 53.020536822657434, 56.52968921969014, 53.27102722660188, 55.13339604100874, 55.219849001976755, 55.726685908532914, 54.71592641645863, 62.24648491028817, 63.79041610225555, 66.7581049088509, 69.81208585923719, 69.75857688534644, 70.7715525165681, 82.81682968139648, 74.5698973440355, 75.75847748787173, 19.82189182312258, 9.57657660207441, 9.13903130638984, 1.2031365498419733, 0.37648076431885846, 0.7290663269738997, 50.57926931688863, 87.57511185061547, 70.43685666976437, 67.53004304824337, 56.447029190678755, 24.739069208022087, 45.76058656938615, 67.2953127276513, 70.42790582103115, 77.12514108227145, 47.775872907330914, 1.5929551807142075, 0.13770378344962675, 0.14289853373362174, 0.17407947670548193, 0.3240229243472699, 0.19908303905638958, 0.12408174424161836, 0.24710170594194245, 0.14592859533525285, 0.32043708127833187], [0.021740631087713187, 0.03164425762670656, 0.031423838809132576, 0.007280961877005476, 0.05046220008103598, 0.039852491369651216, 0.034656913710698005, 0.08905836471146153, 0.11277811691885996, 0.022778722359949065, 30.692958447241015, 79.4066975193639, 62.48294891849641, 39.43586272578086, 22.490825460803126, 50.7266955221853, 60.28781406341061, 56.060656116854766, 61.79609091051164, 77.88818328611313, 6.624568941131716, 0.07486758948934656, 0.11707104382015045, 1.2865967423685136, 3.074729798301574, 3.4799738853208484, 0.43570407996735266, 24.317526202048025, 79.27728283789851, 74.35482594274706, 75.4666139233497, 72.27159238630726, 70.93936720202046, 71.07681489759877, 70.57668916640743, 64.66208050327917, 66.90453483212379, 70.22044381787701, 68.05066708595523, 70.93150677219515, 70.25887520082536, 70.30495520560973, 68.63320181446691, 67.66094038563391, 66.0814489856843, 66.50831268679711, 65.31245262392106, 64.27895122958769, 66.20197557633924, 65.47061043400919, 69.19780346655077, 63.22089579797561, 63.46253341244113, 56.028123978645574, 47.847875856584125, 48.734786510467536, 47.70927106180499, 48.008081143902196, 48.29903864091443, 50.364209682710715, 50.468309387083984, 51.541438487268266, 49.400726518323346, 48.6885456885061, 46.19698555238786, 49.08032771079771, 52.01578247931696, 55.704132280042096, 59.309335677854484, 58.6372846172702, 57.26535720209922, 56.24190884251749, 58.58487782939788, 57.28261170848724, 58.630389090507265, 59.352109124583585, 60.975464390170195, 60.15737172096007, 60.48436403274537, 54.92401207647016, 49.070282520786414, 46.44357712038102, 45.273894956035, 47.7175864865703, 58.74073713056503, 57.69127168963033, 54.330267214006, 18.602258274632117, 22.41080910928788, 58.17907333374024, 56.819764183413604, 53.893805473081535, 46.97898064890216, 47.72501153330649, 49.74436929149013, 53.803634105190156, 56.194318725216775, 60.06297988276328, 57.15026701650312, 58.12650180632069, 46.37296661253899, 46.65773853178948, 60.885685259296054, 56.01297970741026, 58.00268434709119, 56.973085711079264, 57.817262141935295, 56.269141858623875, 59.7511592988045, 54.76849794387818, 59.19180185564103, 57.9417307146134, 52.091417543349735, 46.355484608680975, 45.23783268467073, 46.42730320653608, 47.521856292601555, 46.434406618918146, 46.66748169929751, 44.32590907619846, 43.46498020233647, 46.54659032821656, 45.37076965455086, 47.3420116978307, 46.985829107223026, 46.99953386860509, 46.13927572004257, 46.27219700044202, 47.47720795293009, 46.52235008055165, 44.86519967356036, 46.23306351323282, 46.43828584301857, 47.05143467072518, 47.12412403475854, 47.79644966125489, 46.549041809574256, 48.43370537604056, 50.31956526540941, 53.37445228330551, 55.40468677397698, 60.1651458586416, 61.11274734620125, 64.43814062303113, 68.54258721874606, 71.59314786234211, 67.46766167302286, 73.74922767762216, 75.04414327682989, 72.90934624210482, 2.0893720657594743, 5.387035166063617, 1.8039176540990032, 0.07802577929631357, 0.10988367586246423, 14.332399445195353, 70.61682285801058, 61.03450782837407, 57.35394001007081, 58.122944216574396, 23.262071301860196, 5.867046492715036, 32.83182101864969, 55.90978999291697, 51.89808391755628, 54.024455701151204, 5.852588145963608, 0.22909929855696617, 0.08375243974789497, 0.0452240853900871, 0.06073530508025039, 0.0735596092718263, 0.022306762402877215, 0.04446082816068684, 0.07787569501106778, 0.026003600120724692, 0.02842623252241362, 0.136278415579469, 0.03464877402650253, 0.06915873292112543, 0.04821764673256586, 0.04512039538953574, 0.07124160341317616, 0.0656116692229144, 0.10712677057111457, 0.0848319189202401, 41.133750869381814, 88.86619137179467, 73.10744162528746, 48.750122977841286, 37.68531284024639, 48.54717170038531, 49.94309617627052, 62.73012099727508, 66.94993234449818, 85.15593513365715, 6.365271835557877, 0.221508638933301, 0.3193662129342556, 2.782033220414193, 4.8852698841402615, 0.5252452639322127, 0.43573889100263197, 28.299277136402747, 83.11653014152282, 77.39454515518682, 77.12860061276344, 72.94368267059326, 73.72519923794654, 74.3101344570037, 72.71388669167796, 68.10745516131001, 69.1893703706803, 71.75370616297569, 71.93564922578874, 75.73100520718482, 73.17079574831071, 71.01327250080725, 70.27291728604224, 69.43980586144232, 69.10811455019059, 68.0640894366849, 69.5035679109635, 66.04653204641035, 67.41579224986415, 69.0521187936106, 71.22858708904636, 67.2126526986399, 65.54379793905443, 57.64391299216979, 50.27563471947947, 51.807559536349395, 50.6603447083504, 50.64827557533018, 49.13771590878887, 51.614178842113866, 52.64698989929692, 52.335090867934696, 49.758568271513916, 50.54677640238116, 48.83158668395012, 52.19156742095948, 55.470743410048954, 58.79990216224425, 61.985035404082275, 62.214862761958955, 59.20302375670403, 58.75466154467676, 59.677187319724794, 60.15610479539441, 60.663526135106245, 61.98411364709178, 61.43051816571144, 62.510095642459014, 62.47369212488975, 57.44569993788197, 53.597933246243386, 48.80458116531373, 48.60528945922852, 50.67401809077109, 60.108216577960604, 61.35961348010648, 55.69123552691553, 20.540428853804066, 26.279872309777048, 58.690005194756296, 57.63697824170513, 55.36294491060319, 49.36391115188599, 49.61944572387203, 52.47575490705429, 55.033332455542784, 56.9822052217299, 59.76928849374095, 61.133747716103834, 60.796098324560354, 51.00012786926762, 51.88945470317718, 61.065106238088305, 58.62587444243893, 59.82887714139877, 59.18254898440454, 59.33669813217656, 56.653710642168605, 59.89820503419446, 58.79482661524127, 61.025152975513095, 60.865500742389315, 55.088277016916585, 48.622598878798954, 46.283764070080174, 47.084778739560036, 48.75188412204866, 49.37545076493294, 49.77443033649076, 48.40000437152002, 46.47770174088017, 48.35563452013078, 47.88749964006486, 49.75788577910393, 49.25227265204153, 48.69334666959701, 49.81954936058291, 50.053663869057935, 48.738485305540024, 49.644631262748476, 46.203908535741995, 48.17185578807708, 50.7434989560035, 48.905888142124304, 50.88519065610824, 50.78780212709981, 49.756485492952415, 50.317733518538944, 51.64172564783404, 56.46146743528305, 57.938510448701926, 63.82931424725441, 62.80765448847125, 66.88665666887837, 70.10977022109493, 73.5167174185476, 70.40819983328544, 77.40595925238826, 76.14289329897973, 80.05217844440092, 5.906080940077382, 4.190465644482644, 2.2303494041965854, 0.11690823481448236, 0.1096519189436109, 15.101386981625712, 74.68618777490433, 69.96123006266933, 58.95029367939119, 50.2969684908467, 24.822919676380774, 16.136348478255734, 45.25163550530711, 63.263673167074884, 58.34181639455981, 64.37348819548085, 8.46185370799034, 0.2752690582025436, 0.03981906312307523, 0.07832464551733387, 0.046197013223483685, 0.0500007048850098, 0.07341825072803805, 0.030003435188724153, 0.019752818700526992, 0.06917103629318938, 0.16116046106382725, 0.1684714679516131, 0.18409915598890475, 0.22100113632698215, 0.15938336690587385, 0.16384031323175277, 0.13318971760811346, 0.2150744656401296, 0.24871389201331526, 0.22398147882232744, 51.04122646393315, 103.1709655638664, 82.60909311233029, 58.5109450740199, 35.88565095778435, 60.732289206597116, 80.6652605918146, 73.84611022087836, 74.14388871962025, 93.7880128429782, 8.949875985422443, 0.3146084698457872, 0.651229219811578, 5.074038361349414, 11.613575220108034, 12.767705186720818, 2.7399295183920094, 32.54126360339503, 86.22010554036787, 80.3982570094447, 82.09023414119598, 76.01431800473121, 74.99556864461591, 78.21698773291804, 76.63573911113124, 69.0961827001264, 73.57536469736408, 76.58335193510979, 74.6148947746523, 78.80871649711364, 75.81829363299956, 72.74248077023414, 74.53936561461418, 73.14180943273729, 74.12590857475035, 72.19009337886688, 72.73154520219373, 69.73368552423292, 71.62498181866061, 71.0097659018732, 76.03137247024044, 69.94802736466931, 67.43203086237754, 61.311101605815274, 52.60051765749532, 54.3778298747155, 53.08814671731765, 52.57251977920533, 51.829650325159875, 55.17204707668674, 56.608407266678356, 56.89085714278683, 52.47302885978453, 53.890189047782656, 51.77632962503741, 54.282908516545454, 58.080496326569595, 60.82181730578023, 64.9429928102801, 64.27328732705885, 63.24892505522698, 62.08502446451495, 63.07775282090711, 63.76959223901073, 64.86193310829901, 65.83828556922175, 65.55968353825232, 64.94437348458075, 65.4652956224257, 60.539622383732954, 55.86705184751942, 52.85493043161208, 51.70850007764755, 53.259393476670795, 64.0669902678459, 63.7105841021384, 59.29112803551459, 25.698241687590077, 31.654172520483698, 61.21379936895063, 63.55303033705681, 57.18607041143603, 50.91873084345172, 52.349019204416585, 55.333523211940644, 57.64018674050608, 61.0213835777775, 63.75104335046584, 63.55946694650958, 60.92621903265677, 55.9311943669473, 54.26811725862565, 62.35972765953311, 62.209171402838926, 63.04883710799679, 61.88779592514039, 63.74589327842959, 60.42492051278392, 63.77739383328346, 59.0937190671121, 63.42484335745535, 62.90934977992889, 55.754781846077215, 51.20793111862675, 50.32676673704579, 51.05557449402348, 50.425559474575905, 52.22156570803735, 53.53352792801396, 49.92531214990924, 47.61779354464623, 51.45221633295859, 48.544724141397786, 54.05318314029325, 52.84594820391748, 51.39160786905597, 51.7323245540742, 51.16867211557204, 51.44572873269358, 52.34313172678794, 48.750319096349905, 51.93794696561752, 52.69823174322806, 52.361802208808164, 52.683173764136534, 54.09137133629092, 53.481638893004394, 54.54789992301695, 55.30498796893705, 59.87334505204232, 62.516030188529726, 68.04168485826062, 65.03596867284467, 70.19470522480627, 71.81429893739762, 76.58098282352572, 74.25235794436547, 80.01548859380907, 79.09886206350019, 85.936918258667, 4.737854465361565, 10.128092246670878, 6.183321908597024, 0.28889454480621124, 0.17068647328884373, 18.578957434623472, 84.35889382516184, 75.56323759017452, 73.38239192962646, 71.46968733879828, 32.88272357756092, 12.95704976204903, 50.45111371624855, 74.09024638514366, 69.18649919571416, 76.48586534684705, 11.91010150217241, 0.39048555637559584, 0.25470488344229036, 0.17429024281521, 0.2315597431433778, 0.16688401119843607, 0.1735006206698956, 0.10907161500184767, 0.15011765603576938, 0.22139872063792523], [0.025528395781293515, 0.034862780688150276, 0.005248268707580264, 0.015556606569237288, 0.042764989118422234, 0.07129627910833206, 0.017347275805208954, 0.06953282131543083, 0.07664565657896381, 1.8449441752126141, 49.32273803218719, 66.7065022068639, 51.49879055638468, 30.967567505375033, 18.64094461164167, 43.68411125675325, 59.29905906800301, 48.750981976909024, 77.38406458208638, 55.76137535033688, 1.4516786389773892, 0.03623895805268999, 0.2798156368155634, 0.6027190002702898, 2.4085537127910124, 2.1119173592136753, 5.74489604080877, 75.18531722407188, 71.577803550228, 73.35064426545175, 69.8144079023792, 75.10243754233085, 71.5554460402458, 72.76668963893768, 68.12298774719238, 65.36072915600192, 63.63583941613475, 61.01819469082741, 65.54080909298312, 62.054386831098995, 64.37292337417603, 61.74490005739274, 63.13599609559583, 64.26869815395725, 65.01667845633723, 62.10572673428444, 62.90112849204772, 65.52288386129564, 62.69617288343368, 64.83850479125977, 65.32714582258656, 62.56904494377875, 65.97494094602524, 53.836974251654844, 46.87550852375646, 48.23246032960954, 49.216559471622595, 47.9094962919912, 45.880383599189024, 48.67978703591132, 49.39496063417005, 50.18900917422388, 47.89502274605536, 47.640515835054465, 45.48407123934838, 45.29178096402077, 46.86498088221396, 46.06738651952436, 51.19956078067903, 54.212199949449115, 55.38772644535188, 56.580636885858354, 57.22046175310689, 60.384072949809415, 57.784408369371974, 58.61104003844723, 58.43490992822955, 55.42619705200196, 52.52594947814942, 49.83980840252292, 44.49956417083741, 45.60057740057669, 48.67772779157085, 54.04797423270441, 57.52174292841266, 57.142987097463305, 51.6000622318637, 19.506148868991485, 23.268166665107977, 52.79712646238266, 58.7513392971408, 55.241402426073634, 55.60739878685244, 50.77710582363991, 45.47220214720696, 47.13862503728559, 48.954435317747055, 52.578375877872595, 56.19434618180799, 55.02069065647741, 60.27013986341415, 61.16988451250138, 55.058270885098366, 57.749997415850245, 56.21064755224413, 58.52918409532117, 55.87938377934118, 57.12988638108777, 57.28581236254785, 58.530176454974765, 61.225115406897764, 58.88582168086883, 49.60657250496649, 43.52559651097944, 45.16737907163559, 45.4540454956793, 45.326517474266794, 47.311342685453354, 48.39253617871193, 46.30196779004989, 43.522752792604514, 46.024236525258715, 48.34131394663165, 46.536513759243874, 46.850785824560354, 47.445672096744666, 46.72326564788819, 47.86305935152116, 46.37972485634589, 48.400051439962084, 46.1317486916819, 47.70752952944848, 44.887870973156346, 49.2558616207492, 46.419858547949026, 47.90520129665252, 46.704932489702784, 49.79895691717825, 50.98049640655518, 53.833961871362504, 55.04938671665808, 60.65465765614664, 60.88665016235844, 65.22921992886451, 63.6632763954901, 72.52785651914536, 67.96144100927538, 73.95308894495811, 64.83346846795851, 79.21391302539458, 44.89340935983966, 1.5408864521211194, 3.3578097051189792, 0.26942432828007207, 0.06729033640435628, 1.4473354720300244, 54.594278027934415, 69.00173987111738, 56.216264386330884, 51.77635315925845, 45.633246821741906, 14.183985783207802, 19.104839409551314, 39.93087760863766, 51.135135850598736, 54.750255000206735, 19.451820119734734, 0.10808946730028238, 0.02603744013955997, 0.06390275689022196, 0.0641744269899303, 0.05766910711123098, 0.06123107121956926, 0.0835159330839111, 0.052186250311112216, 0.03833772869960916, 0.040035728109820236, 0.06259491456852806, 0.03099102786021127, 0.028871387063014894, 0.03652388147348839, 0.030738630617458015, 0.07592387151934447, 0.07898072321568766, 0.19697729317891985, 2.2543927979084755, 65.6239672630064, 74.70856881910755, 59.15086407815257, 35.19483135592553, 26.708818789451357, 44.90090893160912, 54.71647554828275, 57.192318747120524, 82.53407386041458, 61.057402703069876, 1.3769714606385077, 0.31537946073278306, 0.30048475029968447, 2.27004575152551, 2.6102620891986357, 0.6717022147870834, 6.791909019793234, 79.44555251829087, 76.22694969177246, 76.66942442617109, 71.40153223468413, 75.72163858721333, 74.05303093694872, 74.53440773871638, 70.98263878976145, 69.08225044127434, 66.4373726998606, 62.10456571271343, 68.56427008105864, 63.54908835503363, 65.89506579983619, 64.3675301151891, 66.20249332920199, 67.46480618753742, 67.86199323592648, 65.32515718090919, 66.16193602162024, 65.79875200025498, 66.13218876623338, 68.44083309173584, 68.84355852680822, 66.8464994430542, 66.51905213632892, 56.60357098425589, 49.54292812655049, 49.815054324365434, 50.49796642795686, 51.469874843474365, 48.84806063867385, 50.25410090723346, 51.20303207828153, 52.12564414547336, 50.576382452441806, 48.66391712619413, 46.7560919638603, 48.57384381755706, 49.02598327206027, 48.339897970999445, 55.138569647266024, 56.076153401405584, 56.94113800602575, 57.40132616412256, 58.844589725617446, 60.97086737232824, 60.42116680452901, 60.69444225680444, 59.55505255729922, 57.351041378513465, 56.41821545939292, 52.565541882668775, 47.548198930678836, 48.537840381745376, 50.133923407523866, 56.72604307051628, 59.25919209757159, 62.09673666184949, 53.62935535369381, 22.440056262477754, 26.23099957742999, 54.67680861873012, 61.033193834366344, 55.82264669479863, 58.51372995684224, 53.52449470950712, 47.934662219016786, 48.3663857367731, 52.196407625752116, 58.186451312034364, 58.59047897400395, 57.299925050427845, 61.5815019607544, 62.5490173216789, 58.18710242548297, 60.92818806248327, 59.553028614290305, 60.12136044040803, 61.33601650114983, 59.93988021727532, 58.47989559173585, 59.91920540409704, 61.318601177584746, 60.52387406749111, 51.05637465753863, 47.35317084097093, 47.990363797833844, 47.26365450889834, 47.57265490870322, 49.63868887193742, 50.474157641010905, 48.487516372434555, 46.086833630838704, 47.02044402399371, 50.222886685402166, 50.00136298518027, 48.03215665201987, 49.58639975517027, 48.789684003399266, 49.96510851767756, 48.42435836791993, 49.58331284984466, 48.805816711918006, 50.2266364712869, 48.77461033482706, 51.608973856895204, 49.3424165633417, 49.615911668346776, 49.716163527581, 53.52997033826767, 54.35231877911476, 56.98191888870732, 58.87755332454559, 63.58404844037948, 63.29774679676179, 66.08133131457915, 67.57784105116322, 72.56481309090891, 70.35064297337686, 75.14366165284189, 69.8938358983686, 78.63764624441825, 55.003769551554036, 0.3538387599250963, 3.909840160800565, 0.4802249119647088, 0.14444256862325056, 1.2434037246050373, 56.5765929222107, 75.56710504716443, 60.99893193091116, 51.3871128328385, 40.73612451553345, 18.14703779835855, 31.395380420069543, 48.90513504705122, 58.80407948647776, 65.41954901910597, 25.888570777831543, 0.25688716150339574, 0.030909878081612052, 0.10079277093492209, 0.015694116478815915, 0.009086995963908492, 0.02131134797368319, 0.054456532722519296, 0.04227793339880244, 0.027895350827865546, 0.14767101635375332, 0.22010403204589124, 0.23554896214796653, 0.08208328737847267, 0.10316270989395919, 0.1775126997381449, 0.1953568486797233, 0.23968473377247013, 0.24458058719192785, 3.633822236330279, 83.64646588602375, 83.6151026141259, 71.98429446066581, 46.23211037728095, 30.17011630919672, 53.135219081755615, 79.09947395324707, 65.73865736684492, 90.84123811414166, 69.09579830784952, 2.1014948862214244, 0.3493774009327735, 0.9473233057125923, 3.082309288363303, 8.560392472051806, 6.806900808888098, 7.9116407805873505, 83.71113008068454, 77.93283554815477, 80.36556013168828, 76.10548173227619, 79.32129967597224, 76.79846256009995, 78.49483274644422, 74.18775650762743, 72.34385813436201, 70.76969331310642, 65.82116834578976, 73.40896206517374, 66.97862055993849, 69.99617053616431, 67.13816688906762, 70.62928030567785, 70.34677551638696, 70.04021090845909, 66.91769046168174, 68.95296912039481, 70.080658389676, 69.23579554403983, 70.17714869591498, 72.68860309354721, 69.58162307739258, 70.59470069023871, 59.27514045469223, 52.602443541249926, 52.81537332842427, 54.59934573019705, 54.25681691015921, 51.1888958561805, 53.26420230250205, 52.87285958566974, 54.52168280078519, 53.879065205973966, 50.49320467056767, 49.45816178475657, 50.060076944289676, 51.1312448593878, 49.169102714907744, 58.51174523753505, 58.244745577535326, 59.70001551412768, 60.521026426746005, 63.022404255405554, 64.27264013598042, 62.47723794752552, 64.00174948476976, 63.195298410231075, 60.58282336881084, 58.77619927929294, 56.40017255660027, 48.99792263584752, 53.652987633982015, 53.236361319018954, 59.32938291180519, 62.431326604658565, 65.78984429759365, 56.77974816291564, 27.726518915545558, 31.210315150599328, 55.52625671509774, 64.95943930841261, 57.86378929691931, 62.670814760269664, 55.311185313809304, 50.30413466115152, 51.927333031931234, 54.469495665642526, 57.99145067891767, 60.100407138947524, 60.96262255022603, 65.6253283254562, 66.60994129796183, 60.882370856500444, 61.934636869738185, 62.14612322468912, 62.195447029605994, 63.63924795581449, 61.33292175108387, 60.51243251369846, 62.64676670874319, 65.911586823002, 64.23918624078074, 53.94405495735907, 50.4725573139806, 50.58418796908472, 49.86262482981528, 49.397835731506355, 51.564007805239775, 54.65699672698975, 51.2008394733552, 47.47515655332997, 49.247044132601836, 51.78646502956268, 51.78137379307901, 52.02771040701097, 52.262836886990456, 50.702145407276774, 53.00337645315355, 51.77996958455732, 52.297561630125976, 51.40823871858659, 54.260052865551366, 52.895825063028646, 54.56556627827307, 52.54048578200802, 53.836613393598995, 52.05816761139901, 57.90793165083855, 56.72771400020969, 59.591950293510195, 59.343640727381555, 66.72784774534165, 66.6074074468305, 69.34459424787953, 71.49883054917859, 75.29286861419678, 71.84028856215939, 79.49405654784172, 72.60449963231241, 82.77682935037922, 53.63110080842049, 2.326728903478192, 12.230125723346589, 0.925416071568766, 0.23210268497707384, 2.2398638484939455, 64.81878311403337, 80.57635614948889, 69.98336007518154, 65.83585369971492, 60.28264830189367, 21.79568340701442, 31.14283273296972, 59.11762591331237, 71.2128113162133, 74.91887846300679, 33.286837531674294, 0.42509523310488273, 0.13444381886191908, 0.2050755473394548, 0.17584284256783225, 0.22400053908988354, 0.14956369785772217, 0.15876902567763485, 0.18066600956503423, 0.10580668616439066], [0.06503577794759505, 0.03978295739920389, 0.04325563395996729, 0.031083215050579562, 0.07147462437710456, 0.02358633224972554, 0.011370008841397302, 0.1635383520155184, 0.3023608383392134, 7.314831566426062, 64.87028383439588, 63.50988426516133, 55.903004292518865, 39.99736962779876, 17.608247303193618, 20.22951433735509, 48.91388585490566, 58.24220780403384, 84.54870516254057, 31.3690613162133, 0.048834604151066274, 0.08750007292556186, 0.375544298440218, 1.5553238387069397, 2.0139903623250226, 0.26977709644744474, 42.501697078827895, 86.65577888488771, 71.52099978539252, 72.13718844998267, 68.84281327647548, 72.45671256895989, 73.2099723815918, 75.03902066138484, 72.08264397036645, 71.38180271271737, 65.35759518223425, 59.38499427610829, 58.28678161867204, 52.42500728176486, 51.181419818632065, 51.461088734288374, 50.34890067192816, 52.826740357183645, 51.766664904932824, 52.54744798906388, 54.82061055398757, 55.833868595861624, 60.635410585711085, 62.992001964199936, 66.51201540423979, 65.50659818034019, 59.794936872297725, 50.46932135858844, 46.6885801284544, 47.076455470054384, 49.1659491292892, 47.67280870868314, 45.101169463126894, 47.81595168575164, 49.334991516605506, 50.08424658929148, 47.81827765126383, 45.13647471704791, 46.40899750494188, 44.80670928955079, 46.83313123641476, 48.250511077142534, 47.31219383978075, 50.683533760809134, 51.63228450282928, 52.015080375056115, 53.06195312930692, 56.040083285300966, 55.578475229201786, 54.21820117581276, 48.35466177232804, 46.76693339501658, 46.34673772319671, 47.69187535009077, 44.6304105174157, 47.158056459119244, 53.26361002460603, 59.926834414082194, 56.96830041946904, 62.80477939113494, 45.53756060138826, 19.32653961643096, 23.780930272994503, 44.02591051593904, 59.56400340603244, 55.456305165444654, 58.38324839068998, 57.529626892459014, 50.37922843810051, 41.622113412426366, 45.25562063340218, 48.64052018811626, 54.80615269753241, 53.43630021618259, 55.174616229149606, 51.835926117435584, 58.363499256872366, 55.582880050905295, 59.666185071391446, 56.29763787792575, 60.08241522696711, 59.6456906872411, 59.624807988443685, 58.07504815440024, 58.44067189001269, 51.48601539673344, 42.760275410067656, 42.525250911712654, 44.30834078019665, 44.003662832321666, 46.07642758277155, 46.84804801018008, 47.32229002060429, 45.73105504435878, 45.01560295781782, 44.81666034267795, 46.22935295104981, 47.459082680363814, 46.59922069118869, 46.327098415743926, 46.569136111967026, 47.81834040918658, 46.45181802011306, 46.19253758461245, 43.77028572943903, 45.317103785853234, 46.583291945918916, 45.56662536436512, 46.197989679151966, 48.412673627176595, 49.900609062563994, 45.31637814737136, 51.282150207027314, 50.53427580864199, 59.62707904077346, 57.83746627069289, 63.766371973099254, 59.34377801033759, 68.26506383957403, 65.38611865812733, 70.23488598485147, 62.97419048124745, 74.90545611227714, 64.87932882001324, 83.73468783593948, 11.80520849843179, 3.135048742255857, 0.905636845817489, 0.0878740617284371, 0.0418862977605914, 21.046516587657315, 74.9213574009557, 58.293990935048754, 60.7128813189845, 62.67647866279849, 37.11396078909598, 11.206645004210934, 26.201073854200303, 46.117636003801906, 55.26552892500355, 38.52634745259439, 0.5788366688836006, 0.03385255203372048, 0.11392262929509725, 0.048608163882407456, 0.06886552808986557, 0.023851076914598385, 0.05224797401517149, 0.036225363822473634, 0.013757568780302763, 0.02846644639277891, 0.060461666134576646, 0.007856410257743612, 0.045540698037873355, 0.11533356406876158, 0.03434685494510397, 0.04570816868856069, 0.24531479053679975, 0.6096788784188609, 10.303240783752935, 82.45832504764681, 71.29557332684918, 66.20420348259711, 47.186152396663545, 29.409476557085593, 28.6770131511073, 50.142591845604684, 65.88350265256821, 89.66128718468451, 35.451923108869984, 0.09869391218789163, 0.09639246915016444, 1.1126641400398747, 3.0242417848879293, 0.59072163436682, 0.25385605802218764, 48.347436766470636, 90.4791876577562, 73.75211454206898, 74.9239932337115, 69.93748403364613, 75.70125795179798, 74.21063177047238, 74.66423034667969, 74.27375839602563, 73.38446294107746, 69.50250102627662, 62.073390714583866, 60.235438654499674, 56.25857499337966, 52.83120401443974, 53.186319720360544, 52.586165705034816, 53.22278207348239, 55.78867896910637, 54.34251285368397, 56.91640353971913, 60.19450872175155, 62.86872971442438, 64.82991872295257, 68.37459210426577, 66.98360981479769, 63.44154873201924, 51.38844251632691, 49.42353902324554, 49.39940467957528, 51.6517355365138, 50.23910176369452, 48.58339871129682, 50.400169972450506, 49.65664548258628, 52.09446522497362, 50.31740011707429, 48.71031876533262, 49.61659808312693, 47.30390979397682, 49.7633025723119, 50.46077451398296, 49.744757606137185, 53.49402573800857, 54.436955682693, 57.00233482545423, 55.07336024315127, 58.83864733480639, 56.535117780008626, 55.32797305814682, 50.35546279722645, 50.16886780338903, 48.69297796680082, 51.09519435513405, 47.92995145243984, 52.54242343287314, 55.88736188027167, 63.12205599200342, 58.61461331767421, 65.42444413708103, 47.159354763646284, 21.67865949292337, 25.860272838223366, 47.11907594434677, 62.25273716834284, 56.41893717550463, 61.33497315068399, 59.76564461185087, 52.3259792020244, 44.31431847233927, 48.56089999598842, 51.671994578453806, 57.799399668170565, 55.063299363659276, 56.98605698923911, 55.11039918468845, 60.21255946928456, 58.18583549991731, 60.68309091752576, 58.34830399482482, 61.974645045495805, 61.5893937695411, 60.777518057054095, 58.25791297420379, 60.867928689525975, 53.28409264164587, 43.71386243451027, 43.92306204765074, 45.865815916369044, 46.57257995297832, 49.25905443006947, 47.98779856774115, 50.30352669377481, 47.36328271127517, 46.96201639790689, 46.43286120507025, 49.580237711629565, 49.043394673255186, 47.859305643266254, 48.660704705023, 50.76537009208433, 49.282792614352324, 49.07834299149052, 48.79628535239927, 47.3978348701231, 47.99847918172037, 48.817066069572206, 47.141256947671216, 49.53679353960099, 50.822911262512214, 53.394479905405355, 48.27973273492629, 52.78999951577956, 52.892114500845636, 60.58972674031412, 61.62880574503253, 66.61817827532369, 61.03293495793497, 71.26973275215396, 66.2772144809846, 71.74386101384317, 64.68511658330118, 75.80047038293655, 67.87055184764247, 88.96822790945731, 16.189161231440885, 2.28328007363504, 2.7440264340369933, 0.19383742053422237, 0.05159357787981149, 21.638539529615834, 82.20008404024186, 64.34500002091931, 63.66547292278659, 55.695895302680235, 29.550652465512677, 15.076468163920989, 32.72202603278622, 53.79696999826739, 63.099918134750865, 48.210659796191806, 1.1954620648776333, 0.02866146556522337, 0.07791175476966367, 0.044309598573994254, 0.06633688635643452, 0.05090448945280045, 0.039805599127806006, 0.059714856812910694, 0.040062211769362616, 0.14989317695219673, 0.24016923841930207, 0.09807169557579103, 0.12534834805034822, 0.231831566460671, 0.13625472814085024, 0.10883554500798065, 0.3291384917834113, 0.8242291560576809, 13.779953218275502, 96.34531974792482, 80.37142799746606, 78.37168601251419, 57.01716530707575, 29.494952847880704, 28.63607733480392, 69.16827586389357, 73.42913873734014, 99.47839137046569, 40.001370445374526, 0.3131857219963305, 0.13943737913523951, 2.4171927330955385, 6.1334715254845165, 11.063417696183729, 1.064203501709046, 51.2994517818574, 91.67425540185745, 78.41927220744472, 77.41418054026943, 76.32910390054026, 76.10116712508663, 76.1975319154801, 78.37037594087663, 77.66965235433271, 76.16645105423467, 72.12010260551207, 64.23142387020972, 64.11165037462789, 59.326790225121286, 55.15468666630407, 54.862893704445135, 54.67468661646689, 56.054851008999734, 56.963989734649665, 57.74465514767555, 59.97176516440607, 61.62368705195766, 67.49914261602586, 68.32882588909519, 71.91580987745716, 69.22317335682531, 66.53591832806988, 54.96922915981662, 51.89378892221759, 52.050252268391276, 55.10623754993562, 53.07019010666878, 50.905869391656694, 53.95293128105902, 52.85255347528766, 55.62526910535751, 53.04960550800447, 51.18244747961722, 51.71047302984422, 49.96075860915646, 51.32650829130604, 53.22815964298864, 52.731379693554295, 56.26609417699999, 56.89913726622059, 58.142038314573234, 58.45587891917075, 62.945529722398334, 60.63907015708185, 59.34205608983194, 54.22659504798151, 52.4270429918843, 50.278101890317856, 53.237804751242365, 50.36246030561386, 54.12103622190414, 59.71358691492389, 65.08729288654943, 63.3213359309781, 70.51127187667355, 51.862770818894916, 26.5084150914223, 31.15329565540437, 49.47321976384809, 64.88219999497937, 60.9563781369117, 63.02662472571097, 62.40885142357119, 55.663068986708126, 46.732389080908995, 52.20757853600287, 53.14631546697309, 61.60567552812638, 58.57339312953334, 60.9952566700597, 56.72549786106233, 63.29372636733517, 61.02711023822908, 63.79395800252115, 59.954730310747706, 65.81711261503159, 64.17344731669273, 64.75061232043852, 61.88482276854977, 63.417347708056056, 56.53833412354993, 46.77192264987577, 47.501189324163626, 49.77934506631667, 48.5734986489819, 51.14972314526958, 51.437181888088105, 53.2204717974509, 50.96460688498713, 49.77728582197621, 49.48723831484395, 51.30258183325491, 50.91188630750103, 51.02336399016842, 51.15774439227197, 50.30740591787523, 53.32656406587171, 51.49520158767701, 51.01867283544233, 49.86752779253068, 50.684279011141875, 53.15306586603965, 51.53176200005316, 52.45432307643276, 54.30813720149379, 56.98178160575129, 51.52166189685945, 54.5552033762778, 55.809134129555, 65.46819817635321, 63.77416572263164, 70.2203026125508, 63.270117621268, 74.15297292893933, 69.14730687295237, 77.20884446174868, 68.30713518204229, 79.32235087117841, 69.90674049623551, 93.34678542229437, 15.272180707223955, 4.401540150565486, 4.495484348266356, 0.4486785756964838, 0.28340022350030564, 26.29222385344967, 88.39038433567171, 70.4075957882789, 76.55103944963025, 76.04048021378057, 51.78107177057574, 18.56379747390747, 41.85374113821214, 64.493359750317, 74.55690645402478, 60.09494327729749, 2.1287717838441176, 0.16666749942927592, 0.2205574335229974, 0.16738625844159435, 0.3166011258238747, 0.10271919095107626, 0.23051987071671795, 0.12326871044933797, 0.11036203648414343], [0.07168754319389982, 0.011864170026514801, 0.08892313487106755, 0.059618142042909904, 0.06754974143639689, 0.04865980203894358, 0.0494822204082964, 0.15538637976973288, 0.3691818156550008, 16.217960253838573, 69.27796886813256, 57.66886711120606, 40.7825183099316, 14.924995053199032, 15.931903758356649, 18.292608722563713, 45.642695811487016, 63.46590665078933, 75.95425082791236, 20.1534713468244, 0.13695583648739323, 0.18771876821354513, 0.9946259255370787, 1.237460966071775, 3.20073226286519, 10.144212207486554, 73.94179251886183, 70.39149053635137, 70.12661287861486, 59.660940862471065, 70.00715317264681, 72.35894357004474, 73.5691281287901, 65.69160069188764, 72.77789977289015, 68.6034231801187, 67.70675366924655, 65.35276674455213, 67.2959638410999, 61.81988793034708, 57.391582996614524, 54.83116565212127, 52.17252039140271, 50.74657801658877, 50.310853681256695, 50.11425664347988, 51.315713928591826, 51.11635554221369, 51.91774283685992, 55.81208375192458, 58.25165679377895, 54.24870937101303, 46.84753417968751, 48.51093684473346, 46.359206937974506, 51.43481277650403, 48.28888754690848, 47.817120552062995, 43.96502748612435, 48.50351572036744, 50.707405305677845, 47.87180623700542, 48.08089602378107, 45.71441635008782, 44.6470295998358, 45.75842142105103, 41.791606872312485, 43.23769061796127, 42.96622337833528, 44.723355001018895, 46.460988521575935, 47.82030159427274, 48.85847060911117, 48.85490909699471, 46.46429900200137, 46.557153271090606, 48.211373667563166, 47.99358014137515, 46.229635361702215, 47.651929932255904, 45.22469274459347, 54.85561378540532, 57.839976587603175, 61.09199408561953, 58.993635869795284, 64.24929811108497, 46.55930272994503, 27.169452136562718, 32.70030983032719, 35.12228711958855, 56.26351717979678, 51.743111072048066, 59.70300828256915, 58.68860490860478, 55.09053237976567, 44.78331627384309, 48.57052157002111, 45.36069700794835, 50.30527999324184, 49.20995027788224, 53.28901129384195, 48.55704038373886, 47.29842632047592, 50.199748623755674, 52.02991870141799, 51.34731646507017, 53.179973325421734, 53.58890395010672, 53.714478631173414, 49.13348759374311, 46.51995351237636, 39.99812664524202, 39.78667166925246, 40.24150971443423, 42.136045886624245, 45.38503923723775, 47.83774045205886, 45.763516579904866, 46.63788741634738, 46.56616295537641, 43.60744853173533, 43.5853224415933, 46.92986472960442, 46.00582884204003, 46.05585475121775, 47.874296942064845, 48.05985643017677, 44.31378502999583, 47.83810131011471, 46.64911716215072, 47.122845342082364, 44.84635660725255, 48.01743599676317, 46.517843277223655, 47.03377616020941, 46.41808563663114, 48.49617304340486, 47.08824219242219, 50.9943227614126, 52.73099137890724, 55.17465153048116, 57.49850288514168, 60.73650575453236, 60.62590276041339, 62.60272633644843, 55.51093593720467, 58.47972692981843, 58.582646000769834, 68.71287299740699, 70.68479753309681, 78.95251843237108, 52.62324387027372, 0.5946039841059716, 3.5477745052306884, 0.2782946152071799, 0.06796758877293718, 3.7711436806186556, 61.051844704535704, 69.02624683995401, 52.30207235582414, 64.46030985924506, 52.80892495186099, 22.15400957292126, 17.36927886163035, 34.53752056244881, 54.92855810349988, 50.71585016865885, 5.958316124254658, 0.3882415009842765, 0.19791346794414907, 0.03403952345252037, 0.24722428000982732, 0.088747785006079, 0.06172880620485353, 0.004447709220731932, 0.042379945666799625, 0.06013492963487103, 0.017353605606683323, 0.07326084264223615, 0.039143614891556, 0.128937745767255, 0.06502024168449064, 0.08389814967109312, 0.14426220088235794, 0.45439052725991896, 20.347103072750954, 82.3960848777525, 64.11035599247103, 50.74978651538972, 24.814996488632698, 25.47618650620984, 21.23912653615398, 49.73887797324888, 70.76776350698164, 83.71512305351996, 21.943513616438835, 0.16981369996022794, 0.31629944039929303, 1.8430202526430932, 1.6264060115621937, 3.285315233853556, 11.768511783692146, 81.69416104593586, 73.96261245973649, 73.89435537399785, 62.55204146908176, 72.58898273591073, 74.78683579352595, 76.57498944190242, 68.99587985007994, 75.32643625813147, 71.83286743779337, 70.16327135024532, 68.01524808329921, 70.71037923136066, 64.20356719724595, 60.91583651881064, 57.12386554287326, 54.20896007168678, 53.388647340959125, 49.707228368328465, 52.66617813417989, 53.449047919242616, 51.794866746471776, 53.98199996640606, 57.18816887947821, 59.8505796155622, 57.938404544707275, 51.6603765180034, 51.42242200912968, 48.179943715372396, 50.13247605293028, 49.815211219172326, 48.819701902328006, 48.433654385228316, 52.05553570101338, 52.31280003824542, 51.92166912940241, 49.00004463811075, 48.67924574882754, 47.7015479149357, 47.93579578399659, 44.51910934140606, 45.894519821290054, 46.34612975582, 47.82446322902557, 47.90925310504052, 49.26583228572723, 50.59644929824337, 51.350928967998875, 47.914607140325735, 49.66410583065402, 49.03716987179172, 49.970835178129136, 46.93405382094845, 50.897095049581225, 47.25333867534515, 56.44580148881482, 59.965414847097094, 64.69093345826673, 61.01720233117381, 64.57700037187146, 47.51557265558551, 29.93587628487618, 36.84035978009624, 37.18140202183878, 57.40090254814395, 53.656035315605905, 61.238000392913825, 60.47653498188142, 59.419318937486224, 45.292106520745065, 48.43881622437508, 48.077377657736506, 49.85242666736726, 51.302813253095074, 55.78908297323412, 51.66432634476693, 51.0510088551429, 51.961987172403646, 54.150712874627885, 54.09893366598315, 53.98622043671147, 55.56520977327901, 54.66584167172832, 50.53330698320943, 48.941471884327555, 44.09875677477929, 43.49348798874886, 42.93006697008687, 43.440284959731564, 47.137711125035445, 50.258956801506784, 48.50781071570612, 49.61536253652265, 49.25556352061611, 45.45283348329606, 46.18923494892736, 50.6535864645435, 48.43669814448203, 47.637628970607636, 49.1577749098501, 51.65898799896241, 47.28014415310275, 50.1944455792827, 49.31245749996555, 50.171080020166215, 48.00434312512798, 50.842574104186035, 50.34208359256868, 50.57216590450656, 49.72924070973551, 49.68045819190241, 49.39543524096089, 53.094767678168516, 55.63241958618165, 58.624662430055686, 58.06694453762424, 62.51197838014173, 60.683137985967825, 63.56012590469853, 57.546936312029445, 61.18872365643902, 60.07759855639551, 71.22550410609092, 71.97732833123976, 79.87912347239833, 60.21636809072187, 1.2422219880165593, 3.954395344180446, 0.5418287998726291, 0.08861162819929662, 3.771702128071939, 65.72271293209445, 76.88270722666095, 58.560751330467966, 64.74368541471421, 44.114983620182166, 21.522225564525975, 26.28025866323902, 42.53035783767701, 64.28205774676415, 61.818911260174175, 9.245549151974341, 0.4362493200648216, 0.12173717811463342, 0.01240766344351634, 0.04225215837059002, 0.06358882171973106, 0.038207317552258896, 0.028118968062523394, 0.06750772151375009, 0.15070968878365334, 0.20969317294657233, 0.21066958264958477, 0.14767121553661364, 0.29333086804516856, 0.2882468021444736, 0.21839832196072226, 0.3582058288156987, 0.5364088197388958, 25.57962529120907, 94.97893071943714, 75.51150937234202, 61.32174299609277, 26.47284115514448, 22.761753374530425, 27.12111088537401, 64.65584393470519, 77.47686001562303, 90.8784378728559, 25.019950136061638, 0.24893470919660984, 0.739931476212317, 3.51206892440396, 6.440437686058783, 9.15841369859634, 11.630553199398904, 85.93926383603005, 75.74386273660969, 78.32280543542679, 63.82552131529778, 76.65591578329764, 78.06973411190894, 78.75628225265011, 68.78104379100185, 79.28105615800428, 72.62036954202961, 72.3619951740388, 70.19858052653652, 74.46506023406982, 67.87911830409881, 63.42004629873461, 59.851422925149244, 58.622967966141246, 55.589924627734774, 53.79686801664291, 56.15547549340033, 56.94303643318915, 55.82409012702204, 57.333888853749926, 61.601462902561316, 63.545409171812004, 59.79163423661263, 52.76114263842183, 54.291141571537146, 51.962630441111905, 56.33557111986222, 52.90551331735427, 51.74490359521682, 50.617853672273704, 53.11824306364983, 55.9521359012973, 52.31793049843081, 52.617654492778165, 51.27844356721448, 50.72973535906885, 51.10722818682271, 47.48393874014578, 46.61566326695104, 48.90962223852835, 50.88037790790681, 52.126295258921964, 51.348873646028586, 55.212361197317804, 52.7504502573321, 50.7450286803707, 52.00297201833418, 52.54274898959745, 51.871886407175374, 48.58060990610431, 52.91023585104173, 50.142587923234515, 59.65987790015436, 62.25799314437374, 67.78501279892461, 65.96158135321834, 68.64248998703496, 50.971169010285415, 34.4733388193192, 40.32012970216813, 40.031149079722745, 59.62763209496776, 56.15326719899332, 67.4795856783467, 65.42970795785227, 60.68658967171947, 48.99139973425096, 54.20737543413716, 49.86611966163882, 55.46042757649576, 54.92330212746897, 59.50438730178341, 54.1813152067123, 53.06514986099736, 54.06441680846676, 56.438972642344815, 55.50867272961525, 57.171279153516224, 58.907798720944314, 58.32192997778616, 53.39506041619086, 51.36249211526687, 46.452324005865286, 46.250690644787205, 43.49759078794911, 46.8103854117855, 49.88391153274044, 53.54650312854398, 50.842931039871715, 51.87929576443088, 52.69907897518527, 48.75494749315324, 48.302458947704686, 53.10801352224043, 50.58523524192072, 50.920091905901515, 52.74502561938379, 54.48997043794202, 48.990556424663914, 52.65078283125355, 51.98270905402399, 53.00039937419277, 50.90357088273572, 54.36077540920627, 54.50610314646075, 53.107248660056825, 53.195819700917895, 55.06642157031644, 53.09687006858088, 57.404522895812995, 58.364068000547356, 60.333309635039306, 63.86842812261274, 67.66219554408904, 64.75457783668273, 67.09273015299152, 60.24784903372488, 64.3348724611344, 63.530629681002715, 75.26833811113912, 74.17489113346224, 84.72211314785866, 60.625620349760986, 2.1139403216300474, 7.709985356177054, 0.5419057763872609, 0.14834973961114883, 4.8423821983798865, 75.29712830820392, 81.22772062978437, 67.73497904500654, 79.18821365602555, 69.98888277238416, 32.72993353105361, 30.31583824465352, 54.21061923426967, 74.35478671904534, 76.53077648532006, 14.709692232070433, 0.6023521360851104, 0.31890027825870826, 0.14058680213507146, 0.34265016836504786, 0.2027092243154203, 0.18389880867494693, 0.0750714837903938, 0.24389006618049838], [0.08345201070750914, 0.07376371807749234, 0.053900647833342516, 0.08744269294003326, 0.0682483829798237, 0.05703854014075572, 0.05979160733160473, 0.060970214450912136, 0.07724787829624069, 33.84397883569041, 69.76224822382774, 58.28777005595546, 43.15013154860466, 17.579968975436305, 29.33474756056263, 42.13022116691836, 55.169144522759225, 72.00057229688092, 72.12728054292741, 7.4928414725488235, 0.2293559839768756, 0.14080187365893396, 1.199260144945114, 1.3769091930120223, 0.43353510119261285, 44.20516675518405, 74.25055365408622, 77.90242933457898, 78.41498897921655, 59.57657068006454, 62.32726220161685, 72.56319707439792, 69.42909779087191, 72.31757040946715, 70.30157412252119, 70.7966713751516, 65.71584093955256, 68.23741897459954, 65.88090604351413, 65.90160831328362, 63.921050640844534, 63.54147503452917, 59.150487530616026, 60.026544986232636, 52.67209306839974, 49.40280537451468, 47.511513002457164, 50.679274066802, 47.33163702872492, 48.35108849310106, 48.361094459410644, 47.08558674781553, 45.25332212448121, 50.08249721219463, 45.185567102124615, 48.62019838825349, 47.022722921063824, 46.65644807200278, 46.81324874201129, 51.358306946293006, 48.56572451130037, 48.33630900229178, 46.70753302112703, 46.04852384136569, 44.13618010859336, 43.48938911191879, 42.41799762172084, 44.940552326940725, 43.825418564581106, 43.932263928074995, 44.425282324514086, 46.65487912393386, 45.090186826644405, 46.49856482782672, 43.29183501581992, 47.53874994093373, 47.69855122412405, 43.0168297982985, 44.83225568648308, 46.16075461910617, 44.96309418832102, 54.9440553880507, 58.474588624892704, 59.428532585020996, 59.460766623097086, 60.11135839646863, 55.91287297587241, 33.72773155089348, 37.150583959394886, 38.8081266034034, 60.40996843768705, 55.62881492799329, 56.556565300110854, 57.44258165359498, 55.92490288519091, 48.563143591726984, 41.74542488590364, 44.34599945622106, 46.31488415502733, 47.658774468206595, 47.14410066604615, 46.24454821309736, 44.212654559843, 44.160341908854825, 45.66939930762015, 44.87233054253363, 44.375099520529474, 44.64506449237947, 43.10882506832, 40.86065976850448, 40.140720490486395, 40.07010606027419, 40.15912032896473, 40.25808957315261, 42.63770526455295, 42.49932012250347, 46.88634603254257, 47.66840388697963, 46.98241664517311, 48.387323348752915, 45.17626716244606, 42.75192076160062, 46.1539924529291, 46.50125557376493, 45.83637068348546, 48.01086602672454, 45.808141385355306, 47.458098165450565, 46.751785201411096, 46.535031103318744, 44.51464568414996, 46.80520788315804, 46.922294555171845, 50.8181377380125, 48.118919480231504, 51.10632996405325, 48.20321513760475, 48.85578770791331, 48.62527393525647, 51.70570342771469, 49.79119454660724, 53.57608564438359, 51.07777118682862, 53.10829593289284, 50.928827024275265, 56.56699096002887, 52.804386769571614, 59.382181936694735, 61.74814385752525, 74.00122427171277, 67.06916455299624, 81.50953508192494, 10.058109318056415, 1.6223425586377422, 0.5034172126362401, 0.09570296703567428, 0.13146923734776436, 30.790515638166863, 72.54194567280432, 59.115880458585686, 63.23417694337907, 62.78721109513314, 24.364188678802986, 14.917344470177929, 34.022046596773215, 51.51187166090935, 55.98432679330149, 20.700740045116795, 0.1202336616153198, 0.02130774352999945, 0.03457513765522069, 0.15188806990702308, 0.020616019760528882, 0.043208216947893945, 0.045901322436909524, 0.03275160707773701, 0.03575635330391026, 0.054247666510843465, 0.08146097883582115, 0.07118748696220499, 0.029394510202109817, 0.02883220549612757, 0.0454566237186232, 0.06375300585322323, 0.04864483268090314, 40.665506162951075, 80.42805133327361, 62.843779517758286, 52.760260105133064, 18.99975715144988, 24.278482929352794, 35.72579083904144, 61.647421313870346, 77.3236914603941, 79.51293099311091, 7.760928119382552, 0.11496156709448946, 0.2922728699782203, 2.0455541653979212, 0.4730600286876002, 1.2958178669214249, 50.12644344760526, 77.75718396709811, 81.75859774312666, 80.02600839061122, 62.187582677410504, 67.19552763046758, 73.6101718102732, 69.75958885685091, 74.02496245599562, 73.14001298719838, 72.63545497771233, 68.12341920791134, 70.73908313628166, 68.32981432637861, 68.89161540615943, 65.97529395934075, 66.93518423265027, 60.955460302291385, 62.189900798182336, 55.62297844117688, 51.869564364033366, 49.48060166451239, 51.821181927957845, 50.98193199403825, 51.71877668749902, 50.26906867181101, 50.531012396658625, 47.51208566850232, 51.6031373700788, 47.26953021941647, 51.47667623335316, 50.58709052301223, 49.33615253817651, 48.18182253068494, 52.61963921208536, 51.74064390120968, 49.207808663768155, 47.27888114990727, 48.36559341799829, 47.398944900881865, 47.25686488613006, 44.73413367425242, 45.51063745252548, 46.31018907793107, 44.66335842686315, 46.33026376847298, 48.6672079947687, 46.02394234749579, 47.410731623249674, 46.29925743226082, 49.114817111722886, 48.92275825623543, 45.86864002289311, 46.62453959065099, 48.74504743083831, 49.0786293245131, 57.516553632674686, 60.166820710705174, 62.673183871853745, 61.265009833920395, 62.543682898244555, 57.112926052462676, 38.72090878025178, 39.654934944645056, 42.94930227341191, 63.372334587958555, 58.95222740788614, 58.150310593266646, 57.1820931280813, 56.024789963999105, 50.260576740387954, 45.012629801227206, 45.64997965289701, 48.22230139086324, 49.412242597149266, 50.76813144068564, 46.50879829160629, 46.1110621113931, 45.56602131935858, 47.02530776300738, 47.22861205377887, 47.60004481961651, 46.35078953158471, 45.381979788503344, 42.242530392062285, 41.87456500145697, 41.90969374872024, 43.54256860671505, 41.227844607445505, 44.3532911423714, 46.5786478596349, 47.85526560198876, 50.367865331711315, 49.376317608741026, 49.2862952909162, 47.55045429352791, 45.685645764873875, 49.07423626992011, 48.15449145532424, 47.57655766702468, 48.59649158293202, 48.25716341695478, 48.614020655232096, 50.307362771803334, 48.214174239866196, 47.20929438068021, 49.54378320324806, 48.75453956665532, 53.51752465771091, 50.28553870416457, 52.13396741497902, 50.775097570111676, 52.35416535408267, 50.502916459114324, 54.393927281902684, 50.49633079959501, 54.851303100585945, 53.55020976835682, 55.396842033632346, 52.46916924753497, 60.99677462731639, 55.6280618329202, 63.19607896189537, 62.72889329541115, 76.74905638540946, 69.1854872242097, 87.03149487895351, 13.021065785038857, 0.257480465957234, 0.9747257191807994, 0.10213869548733197, 0.14954370296289846, 32.924853755581765, 80.82446175236856, 63.5989377575536, 65.96044386586836, 58.29963522572672, 22.4694916894359, 17.882324880169286, 41.71253973437894, 57.88011812394666, 66.00007549408944, 26.264845709646902, 0.16787989485648372, 0.045507802222404754, 0.08290898460414141, 0.13604739410502298, 0.12132683843975106, 0.04029103840190557, 0.09945124372719757, 0.04830677723211627, 0.10244855507006569, 0.2985160881953855, 0.14970842718837724, 0.27748617794244523, 0.20053152746010214, 0.16767338819561467, 0.1732535113490397, 0.170698408938704, 0.11687720059266976, 51.02888668737104, 92.00899831710323, 74.93776075301632, 61.75725552343554, 30.35622492913277, 42.977586484724476, 59.1762065118359, 72.57348937373008, 83.6436104005383, 88.81313739284393, 9.945646139883227, 0.22096883806009449, 0.9098220760783843, 4.579964357037698, 8.027152130680701, 1.0987389904837455, 56.8268205273536, 79.45109090497418, 85.87616074469783, 82.44767189025879, 66.22700029803862, 69.97542904269311, 76.94280578244117, 73.60387248377647, 77.73718772395965, 75.2173786778604, 76.42564127522131, 71.93502164656117, 75.21207563338741, 69.93856660781368, 71.64149499708607, 69.1602663840017, 68.1982894097605, 65.25926136201429, 65.96335426453622, 59.1728489629684, 55.42741690912555, 53.96039947386711, 54.865992376881266, 53.51575959113337, 53.33565611993113, 52.8651285940601, 53.22307625124532, 50.33212861707134, 53.84277151476953, 49.5620261469195, 53.947345825933645, 51.621113592578524, 51.45444423921647, 52.30697531853953, 55.6138510857859, 54.68647726120488, 50.41615755327287, 48.24872639871413, 50.25444999817879, 49.039617430779245, 48.573730068822066, 48.33047251547537, 48.94018142454086, 47.876316962703584, 47.17783697189824, 48.75275488822691, 51.63757970256191, 49.256140109031435, 50.179422901522734, 47.874708790932935, 52.58569502061414, 52.77965230326499, 47.59297278619582, 49.44079745200373, 49.08244579069076, 51.086694578970636, 62.52830720716908, 63.6929452034735, 67.00500242171749, 64.37376668376308, 63.81899449133105, 60.59845793631769, 41.81576082783361, 43.50357632483206, 45.84737685418899, 66.06488089407644, 61.306359460276944, 62.623765930052734, 61.16664071236888, 59.15157402715376, 53.5641969403913, 46.13986407556842, 49.48802671124859, 50.039472733774495, 52.962069972868896, 53.36454829862041, 50.799647685020204, 47.73905754089356, 48.405629050347116, 49.29897239131313, 49.686832043432425, 48.868041192331624, 48.62096325043709, 46.56438612168836, 45.073155895356216, 45.648387170607045, 44.718683458143666, 44.899230157175374, 43.36697978358115, 48.1643013031252, 47.725878377114576, 49.94629683033113, 52.95516660136562, 51.349179590902025, 52.64385592552924, 51.01025542905254, 49.005331993103034, 52.20266380617696, 52.41999841505482, 50.14168577809488, 52.348874076720215, 48.985131786715606, 51.882312067093395, 52.52028557562059, 52.569319125144716, 48.869108077018495, 51.49070655145953, 50.6086439471091, 56.20915705157865, 51.77395659108316, 57.202673804375436, 52.659227694234545, 55.17896221530054, 54.438030412120206, 58.718332552140765, 54.87435094771847, 59.40063668835548, 55.110846334888095, 58.41259556431925, 56.27973225808913, 64.63817365707891, 58.6157625721347, 65.2521893285936, 66.45088918747442, 81.47707354637885, 73.20917221807665, 91.23094912498229, 12.573957750874182, 6.221562566295748, 2.15635119426635, 0.17762094796184572, 0.44153299783506705, 40.726389192765765, 86.38722204392957, 70.65359115600586, 79.16578554338025, 75.05583978468373, 37.78465470960064, 25.832218085565877, 54.094089538820334, 71.04666756045434, 76.70774598275462, 35.92992274991928, 0.220719660301843, 0.13027106051243123, 0.12897133106185546, 0.22409582510590556, 0.20890431688918223, 0.09442245873111872, 0.15863204915677348, 0.18487777711162645], [0.12931202568354147, 0.014199211765381118, 0.03152780843177631, 0.059796207689590035, 0.01938505819247615, 0.04679499081366005, 0.019650101631639466, 0.05522919751162972, 0.06480125545133507, 47.034968560741795, 72.33994360893004, 50.03071015880954, 33.46468956239762, 19.648448536472937, 44.10982178103539, 48.37586218310941, 56.4619420420739, 73.80918502807617, 57.34527157198999, 1.2305112615708382, 0.08890009860718444, 0.3207381231890571, 0.6237585325875591, 0.9437348885882286, 16.083802446242302, 77.00019005806216, 69.62286287738432, 76.48846980064147, 71.55768179124402, 63.44108589233891, 53.352137919395204, 67.82167127055507, 65.22501907040997, 69.24773523884436, 68.4664697031821, 67.99178446492841, 59.68988010960241, 60.61486128837832, 64.19629904531664, 69.1883191754741, 64.22495980416575, 65.46228716450354, 64.75927291377899, 64.13426283867129, 62.942246698564105, 55.314244762543716, 47.681787014007575, 49.213762821689734, 48.51870706004482, 50.30482892067202, 48.812880900598344, 47.96692763605426, 46.77393874814434, 46.15088201338246, 46.8146921742347, 46.792287595810436, 46.1100422951483, 47.192718444332, 46.705018781846576, 49.511666836277136, 48.31453592546525, 48.071533326179754, 46.13691837556901, 45.375951105548495, 44.69804394629694, 44.3267249291943, 41.95502850317186, 43.19700779453401, 43.709163435043834, 41.460252884895574, 43.45529587038102, 45.243755463630926, 45.861732729019664, 46.71449522818289, 46.760269288093816, 45.142421030229144, 47.611368702303984, 46.012826350427446, 45.43454347118255, 45.88636521370181, 45.12774352104434, 51.12298827017508, 56.13157649194041, 58.836395894327474, 57.51884821922549, 57.06317863156719, 60.408407334358465, 45.49259454973283, 43.27618083646221, 46.797724000869266, 60.83855013693533, 54.74955289594589, 55.993995435776256, 55.809157663776034, 51.898323182136785, 45.76342244302073, 46.83729679353776, 45.048680305480964, 44.80649748156148, 45.26184935723582, 45.80450927057574, 44.90071281310051, 44.514069095734634, 44.83952383841238, 46.35157792798935, 44.876531400988185, 44.93758701509045, 42.28769256222633, 41.86553178295013, 41.622470348112046, 41.53284418967463, 40.861526612312566, 41.206232347796046, 42.38939177605414, 41.616296537460826, 46.17731878834386, 46.031653727254565, 45.69980552119594, 45.17903635578771, 45.65454136940741, 43.155367912784705, 44.48522006311725, 45.96456943019744, 47.03905959283152, 45.879257878949566, 46.703002683578006, 45.31347167107367, 46.581260158169655, 47.23486431183354, 46.86896208793887, 46.58940299864739, 47.515917824160674, 49.4819038914096, 48.56259838227303, 48.69609625108781, 48.885672246256185, 48.64729804377402, 49.24810709491853, 46.556439399719245, 49.17336633128505, 48.03512196387015, 50.36371938643917, 49.391850194623395, 55.85944244938513, 54.38163457378265, 61.31014846986341, 61.99744970567765, 67.58401486181444, 62.15279125398206, 73.21818582473263, 67.30466365814209, 85.5449636520878, 32.93073338847007, 0.7837073949556198, 2.7276478419380807, 0.09798921854986299, 0.1272410142325586, 23.163970862665487, 72.33746467098113, 61.65488558430826, 56.883443863161155, 63.41487661484749, 40.8877476569145, 28.995466463027466, 34.04444725282731, 46.16967016650785, 58.41424295979162, 39.143304901738325, 0.33046581572101963, 0.05551162731623458, 0.03778575851972546, 0.06621741494464298, 0.10707792480506244, 0.01800084265039092, 0.05841983114219001, 0.018196625995539853, 0.014747524833036287, 0.03981051358184026, 0.002856845530914143, 0.02484567162971343, 0.0401286622359147, 0.04508141683594835, 0.05654060214217152, 0.09876887389128247, 0.2544146433712975, 57.44883783401982, 80.43458600198069, 58.225992725741484, 42.502736506923554, 22.620146005384385, 36.97980396209225, 40.28642085290725, 65.59949559550132, 78.398632695598, 64.2545933108176, 1.2707155558370775, 0.022153232637191975, 0.5120146803317532, 0.08635199824047667, 0.521358746674753, 20.235444961055634, 79.07732825125419, 70.96379572345366, 77.83756902140956, 74.76248571949621, 65.90543654657179, 55.9234869095587, 68.9999669597995, 68.79380718354257, 71.28174304962158, 71.51324918193203, 72.16946171176049, 66.52508474165394, 65.70197536099342, 66.80605980657762, 71.35680936997937, 66.68572933443131, 67.5009390615648, 67.46247629965505, 67.62085376247283, 65.00599391998784, 57.17412287189115, 50.112832823107325, 50.219074141594675, 51.49743341630506, 51.00155561201034, 48.836179779421904, 50.41753430520335, 48.44065189361573, 46.75424452750914, 48.8290528328188, 49.288625178798554, 48.86849618727162, 49.61969283319289, 49.664168588576786, 53.31217288970948, 48.906276456771366, 48.685835330717026, 48.9026011959199, 46.85408846024544, 46.77718254827684, 48.596981879203554, 42.36115463318364, 44.614069923277825, 46.92990395330614, 44.000348429526056, 46.92971567953787, 47.676742845965975, 47.89263010025025, 47.276076655234064, 47.26070096415859, 48.48694762875957, 49.20312143141224, 47.95474083192887, 48.91250910297517, 48.702360276252996, 48.358525306947776, 53.22935988826137, 58.52257882395099, 61.10938195259341, 60.23553279138381, 60.793882185413, 63.02325148736278, 49.166196238610056, 48.47351351091939, 50.06039465627363, 62.91025192506852, 56.50429579519457, 58.856427438797496, 56.84235311323597, 54.76498350020378, 49.16403109027494, 47.89208096842612, 47.72248160454535, 46.609230579868445, 46.44809176844936, 48.4140190001457, 46.28835324318179, 46.602542938724646, 46.02743717931932, 47.402639773584184, 46.59790669718097, 45.56492305571034, 47.15938614260766, 45.3042580235389, 43.63641523545788, 45.56452689632293, 43.292486129268525, 42.0348761927697, 44.97253925569596, 44.179843933351584, 47.19097298960532, 46.93548156369118, 47.58279423559866, 46.412657076312655, 46.44981761132517, 45.77736646898332, 46.69633465428507, 46.60643000756541, 49.85135978268039, 47.86795839186638, 49.691519275788345, 47.712542318528705, 47.51797314613096, 50.655830060282064, 50.65765004004202, 49.468293266911665, 49.926692824209894, 51.21019432621618, 51.52146577835084, 52.548938489729366, 52.57760317094865, 50.47621688535137, 52.73462741605697, 49.300227549768266, 51.865767509706565, 50.08332483230099, 52.96083834863479, 52.97955982146725, 56.46689599560153, 57.33878397172498, 65.23564477120676, 64.47934119932114, 69.266233136577, 64.34414886659192, 76.58295969809257, 70.25801227938744, 87.33448228528424, 36.80379544534991, 0.4691727453422162, 2.290365590203193, 0.35254082312026336, 0.07635733938866085, 24.909678582222234, 78.39080364473405, 66.73908141351515, 63.336107577047045, 60.1076360671751, 40.64127376002651, 36.9628789347987, 44.49471219893425, 54.91524557913504, 69.17270029744795, 46.42237278722948, 0.9849786109501316, 0.017454974360824112, 0.07612879237821026, 0.0447741121564421, 0.04387898438219582, 0.07286531144693013, 0.01532094834762956, 0.013548196950596909, 0.23101536106438408, 0.1460762204782617, 0.0670022490404306, 0.18723109196270668, 0.1372509029123091, 0.08570122187055888, 0.17621433392407435, 0.2935610621446564, 0.8108952425179944, 70.75954221910047, 92.55588654548892, 68.44541442009711, 50.28623688605524, 31.200275844143285, 62.54680510490172, 66.50309593446794, 71.04731867390295, 83.25448774522351, 69.71551710559477, 2.070442707307877, 0.19939652223500515, 1.2848900210472847, 4.139284597289178, 3.562982514981301, 21.09350265995149, 80.05304921057918, 70.30283712571668, 82.1628999710083, 76.46841079958024, 69.56302319803547, 57.43485458435551, 72.09601925265405, 71.92221118557838, 75.19733536627986, 74.61908386599633, 74.55440398185485, 67.33926680780226, 70.05040907090711, 69.0676200005316, 74.66110029528218, 68.7597845446679, 71.61201446287095, 69.28764927771785, 70.54329410676034, 67.27911333883962, 61.084714166579715, 53.406870672779704, 53.14870811277821, 55.05412886219641, 53.72610845873433, 53.8818383216858, 52.512429068165446, 50.84427641284082, 48.95287421441848, 52.59549702367475, 50.73053160021382, 51.7053190354378, 53.669814602021255, 52.34069593491093, 55.77318560692572, 51.01519369309949, 51.69099453956851, 51.513291558911725, 50.50388136217671, 49.14774148694931, 50.92963503253076, 45.72084903717042, 47.33782260648666, 49.560676851580226, 46.242363452911384, 47.78580434860722, 49.16079905725295, 49.64810256035098, 50.406806622782064, 50.385496385635875, 49.49744824440249, 53.24612802074802, 51.3369417959644, 50.27873731428578, 50.27593674198274, 50.9984451724637, 55.97345790555401, 60.67674844495712, 64.5199534200853, 63.690368206270286, 62.79171397609096, 67.05463609387799, 54.04612287398308, 50.35865560654671, 52.904509190590154, 65.89637587147375, 61.074374798805486, 62.46073261384041, 62.52641270237585, 57.3762700634618, 51.68832732785133, 51.651668856220866, 51.15085278787921, 47.598213072746034, 50.52442673713931, 52.0472163538779, 47.440965252537886, 47.884444113700624, 48.428233669650176, 51.720773173916726, 47.87470094619259, 48.87439935438095, 48.59014518799321, 48.86125941430369, 46.01588579916185, 46.95607008472566, 46.543017048989576, 45.64714377926242, 47.47138715559437, 46.49174774846723, 50.927705226405976, 49.2082283573766, 50.2689863020374, 48.37472861812961, 50.069816189427534, 47.4773334687756, 49.53018434586064, 49.00580267752371, 52.48661202769126, 50.14894216291366, 51.36177039915516, 49.87291712914744, 50.35669834383073, 53.91902631328952, 53.25243126961493, 52.51637497255879, 54.6614250829143, 54.832373742134344, 54.64236236387684, 54.72827796013125, 55.825219769631666, 53.48393740192537, 55.686175669393236, 51.94370500503048, 54.76328903628934, 52.16249481324227, 56.14492039526663, 54.30424228791268, 61.25163062926262, 58.9973032859064, 68.84122863892587, 67.47072112175726, 72.20459045902376, 67.79097480158653, 79.64131016885081, 73.40416108408283, 91.36316437875071, 38.38966854156987, 1.38847638522425, 9.080970421914133, 0.5736739717183575, 0.2877551269146704, 29.182034000273678, 86.4017975714899, 72.54953938145792, 73.23101197519611, 74.45792152035621, 59.77519950559063, 43.16240464487384, 52.21719226529522, 63.96243556853264, 80.50703217906337, 58.60219509370866, 1.7297613236211962, 0.1639589955729823, 0.24920523016443177, 0.22543418070962354, 0.16426313247892166, 0.22480555960247595, 0.2130670548086205, 0.1090564771044639], [0.02479716294234799, 0.02086396411722226, 0.06320328797183691, 0.08350292491095682, 0.0945617871419076, 0.04537420031884986, 0.08685793036655073, 0.22052758673746742, 3.3542128916709655, 64.93565013331752, 66.1808261563701, 46.99131258072392, 36.204159182886926, 19.372672573212657, 37.28179116402903, 50.348363307214555, 59.626502452358125, 83.52386043917748, 38.31050334438201, 0.08970446794504121, 0.08462311399559821, 0.3474163997077173, 1.1757215112447739, 6.533573385207884, 82.07086547728508, 82.23136886473625, 76.34340486218854, 72.71139206424837, 73.56460955835158, 67.9613390276509, 55.48368330924742, 55.1818294678965, 65.76414885059481, 67.49940149245724, 67.21043263712238, 67.43520013747677, 68.19528487420851, 64.03878450393677, 67.2918139734576, 68.62755360141878, 68.00923116745489, 65.69079268363215, 67.95685183617377, 63.66320579282699, 61.54238416302589, 60.61257454656786, 51.477864711515366, 48.50831670145835, 47.0297674978933, 46.48083571464785, 46.4883666653787, 46.866392935476, 47.03616488364435, 45.74665038816391, 47.138766242611794, 47.913916803175404, 45.52015312256352, 46.92972352427822, 46.65354551807527, 47.72155592518468, 48.17694310219058, 47.82336496537732, 47.267372915821696, 44.6366431636195, 46.574482302511896, 42.65407331528203, 42.048133803952126, 43.161839823569025, 41.935302903575284, 42.36240194689843, 43.97566887640184, 46.03118696520406, 44.210614927353404, 44.388361054082075, 46.40286291799238, 45.802975623838364, 46.57894595976799, 45.000388083919404, 45.95508906149095, 44.3161972876518, 46.585916011564194, 45.83254637256746, 48.58708966162897, 51.71581922038909, 52.82954485185685, 56.14483018075266, 58.67887350820727, 49.213425497854914, 48.771550886092655, 51.26908479198333, 56.799222730821185, 53.99959964136924, 52.60273771901285, 48.742897971983886, 47.071301475647964, 45.2740793074331, 46.49827457243397, 45.959988101836174, 45.32936119264173, 43.45868087583973, 43.823084754328576, 44.62267952580606, 46.86220384413197, 44.65898890649119, 44.53386529799431, 42.55109148640787, 42.68574645442348, 39.90588034352949, 42.05224052552254, 41.831112984688055, 41.53174984839655, 41.97422850516535, 41.712747619998076, 41.438962259600245, 41.76671943356914, 46.202539628551854, 45.931264585064305, 45.67269409856489, 47.48683344933295, 44.83737045718778, 46.50258133488317, 42.415377478445734, 46.34835766207787, 47.852641536343484, 46.81768886504635, 46.3216188646132, 46.978953192310954, 46.08065982018748, 46.793648658260224, 45.51579144693191, 46.98063588911488, 45.85961857149678, 47.92972395496984, 49.21253904219597, 49.83685878015334, 47.73919874621976, 50.820059699396936, 49.37990657744869, 51.09511983010077, 50.527713683343705, 49.75599519668087, 49.576888007502404, 54.01251600634668, 60.08558057969617, 61.517834048117365, 67.84016132354736, 63.35892792670958, 68.71452823761972, 68.4302270027899, 70.22908087699645, 68.31073591786047, 77.42227631230509, 55.92722492833292, 1.1881119108969167, 1.5982607992426043, 0.03255677942727362, 0.0773784579829343, 6.6543676776270715, 61.97256618930448, 70.45486819359564, 59.49837038593908, 56.966080357951505, 34.576414785077496, 8.028305797807633, 18.717934854568977, 45.166931921435946, 58.46667720425514, 53.87429168147426, 5.850742670797533, 0.24786221674613415, 0.03822818578731629, 0.06206663948814235, 0.060045906387630014, 0.03719942163555853, 0.027187102541868246, 0.027211862503580993, 0.06328484186181618, 0.03663588352801819, 0.024555672876416676, 0.04512742424624101, 0.037793637734026685, 0.04283859101574748, 0.09581473160294757, 0.1622194856885941, 5.043847387836826, 74.94331482918032, 72.41904997056531, 58.351465425183704, 44.676984740841775, 24.89257508708585, 33.36222156401604, 53.54301221909062, 65.23872383179204, 91.1671478517594, 41.61271149112333, 0.09182573476385686, 0.1675342972720823, 0.5612264525505805, 0.8324848259648969, 7.445177320511111, 87.67317110492338, 84.6094391422887, 80.94239957870977, 74.32900890227288, 76.74245111403927, 69.05698253262427, 59.50486190857426, 58.999515502683586, 68.23190412213727, 70.41096902662709, 69.89243953458725, 69.60532988271406, 70.67226948276644, 66.5546594127532, 69.25894537279683, 71.19547444005167, 70.1050869111092, 67.07440483954646, 69.62765601373488, 67.78247110305294, 65.56808133279124, 62.84432080484206, 52.49599041477327, 48.03531023763841, 48.87705087661744, 47.2887812122222, 48.71656317864695, 49.36547225521457, 48.82964511071482, 47.96444085336501, 50.00626594789567, 50.03177312112624, 48.86256948594124, 48.18343070245559, 48.222909358239946, 49.10321866312335, 48.624097224204775, 48.85202223254789, 49.36524868011475, 46.474167685354914, 49.679108896563136, 45.82341509480631, 46.12369214334796, 45.32436409304219, 46.711439701818655, 44.67347814190773, 47.31452372766311, 46.94335768299718, 48.21437820311516, 46.965687736388176, 49.447524316849254, 48.97965615795505, 48.6423284007657, 47.358654314471835, 47.23842974632017, 48.26133289644795, 48.09394967171454, 47.700759518531065, 52.678859156946984, 54.12659814280849, 54.828643568100475, 56.47260696657243, 61.67570552518291, 51.828348098262666, 51.83550250145697, 53.228626405039144, 57.649176812941036, 55.69912733570222, 54.931213548106534, 51.07961077843943, 47.79425705632856, 48.77994868063158, 47.86406347828527, 46.37290385461623, 48.08563032457906, 45.97404587653376, 47.32489447439871, 46.670148911014685, 49.24177638946041, 47.26437622501005, 46.74824330114549, 46.147661747470984, 44.704049095030754, 44.65679237919469, 44.299131055032056, 43.00300736581126, 44.84152424720026, 44.56659747708229, 45.28836850197085, 43.3402802098182, 46.36105437432566, 47.49660015106202, 46.79253862750146, 47.089717003606985, 49.879608692661414, 48.108274167583836, 47.645724742643296, 44.400234068593676, 49.561943777145885, 49.85086164166851, 48.7992859655811, 48.01020314616542, 48.54885439718924, 48.54626955524568, 48.05377675640968, 48.177092152257124, 48.289107199638124, 48.30210593438918, 51.072291635697894, 49.5991749148215, 52.693509209540586, 51.76109906165831, 52.90725877208095, 53.175956818365286, 52.799891733354144, 51.45831169620637, 53.54369078913043, 52.69478397984659, 57.1843877146321, 62.04784824002174, 66.06138998462309, 70.34624991878387, 67.98234724229383, 70.8880155317245, 69.45209856956237, 74.08291155292143, 70.91973181693785, 78.60959345294584, 59.79198332755797, 1.2773134727631847, 1.4831085911681576, 0.5942998165565153, 0.12738090954841147, 6.169548505736936, 67.03046644887617, 75.20955747173679, 64.96676237352433, 62.146864552651685, 46.19944880085607, 19.24197331551583, 30.10304181806503, 55.070998976307536, 66.89152040789205, 65.28294855548491, 8.044256606409627, 0.2548033257405604, 0.12476350886807328, 0.059133392247942194, 0.02355831449911479, 0.023528130634898142, 0.14116358973326223, 0.069562989857889, 0.13255050916585231, 0.1880360971535406, 0.160000711198776, 0.1726447165973725, 0.23362114785179017, 0.18026989614290578, 0.3251894923948473, 0.42648657134944395, 7.7626956374414515, 90.76622670696628, 81.80388542913622, 67.25376698278612, 50.87867559925203, 30.086969906283965, 51.392470790493874, 67.69059350413661, 71.21405078518775, 101.23817059301562, 48.092619988226126, 0.30970602807018066, 0.1819446869194508, 1.4798864866456678, 5.010878395649695, 6.8243553561549035, 88.32460618788197, 87.68398115711828, 82.89591250881072, 77.69533603422104, 79.7827979057066, 73.44248264066636, 61.78298627176593, 59.671586175118726, 71.43249542482438, 75.04514740359399, 73.77000055005475, 73.17571440050679, 72.62498224935224, 67.60842769376694, 70.36251991025864, 73.58663758923932, 72.90643584343695, 71.18487619584607, 73.98144768130395, 69.00304209801459, 66.73027961484848, 66.55600086335214, 55.17627931410267, 52.810803767173525, 50.810132180490804, 49.532918237870746, 51.350105270262695, 51.034495676717455, 50.92506547128001, 49.83727062902143, 52.68001233377765, 50.72498536879017, 50.54945145883868, 51.913726329803474, 53.81957853994062, 52.32201368578019, 50.63980325575798, 51.87006250504525, 51.82835986537319, 47.54129163680538, 54.030602055211226, 47.2908639907837, 46.603452928604625, 47.8510098303518, 48.035427908743586, 48.6881495291187, 50.21815630697435, 50.788414016846694, 51.089369635428156, 48.574000712363954, 51.580889686461425, 52.128680059986735, 51.4256932658534, 50.19991336330291, 49.734575133169855, 48.99984851960213, 51.03511148883451, 51.85809143127934, 55.07128138695994, 56.72690206958402, 57.39597997357769, 61.217015712491936, 65.40034509474232, 57.19937509106052, 55.20440663060835, 57.50690852442096, 58.62057139796596, 59.728833167783684, 56.89178674451767, 55.23107482540993, 51.354816036839644, 48.476337617443455, 50.919162304170676, 49.574283553707986, 51.41564807584209, 48.19332684240034, 51.30510391727571, 49.95994667853079, 50.33569405155797, 49.31118272965955, 48.795547946806884, 47.144892984820956, 47.81845023555141, 46.58932455124394, 47.64380278125886, 46.08634333456717, 48.310856742243615, 48.225866825349875, 48.71720644735521, 45.28093561049431, 48.67941833311512, 52.08080753203362, 50.21303369152931, 50.77457197250859, 52.95108341401624, 49.776187558327955, 50.56442706815658, 47.86914294765842, 51.849136660175944, 53.612908855561294, 50.52073186443698, 49.439161823641875, 50.10021063589281, 51.387030463064875, 52.11377113096176, 50.17449640458631, 51.370752626849765, 50.425755593084524, 53.24358632487636, 51.85909163567328, 56.44448357243692, 54.347462884841434, 55.906836448177216, 56.64357523764334, 57.04105646379533, 55.095992319045536, 57.33591671912902, 55.82668673607611, 59.23586183978666, 66.23216213718538, 67.12174000278597, 73.71580908375402, 71.47380582747921, 74.71080457010578, 72.52243580356722, 77.82010662940242, 74.41484605112385, 82.07803556996008, 64.40067806551534, 1.735012764411588, 5.072886165111296, 1.023007583233618, 0.15976634958098013, 9.6124662891511, 76.76476940031975, 81.34945531045237, 73.64435918869512, 72.91128389296993, 47.834418204522905, 18.420919256825602, 35.03968984849992, 66.24654154623708, 76.71258618754726, 76.83280683332875, 10.31256425765253, 0.40436366813317426, 0.32022242344194846, 0.22111197392786705, 0.1927080383944896, 0.2027307207425756, 0.255691773228107, 0.15937979693614668], [0.05685362949847214, 0.0384934245789003, 0.02010185793492823, 0.12255795705582827, 0.060284853041652715, 0.06727556622917615, 0.1834561171070222, 0.3277192985819232, 8.773508571809339, 72.77793899659189, 62.901603098838564, 35.44957753150694, 35.02884057260329, 26.40278566268183, 46.75246769382108, 50.80931240512479, 65.20252427747174, 76.8665627510317, 21.259919020437426, 0.1515954549634649, 0.3205975000896762, 0.55006884158619, 0.8900312057906582, 44.229603121357584, 70.92712156234249, 71.72772438295426, 73.14773221169749, 70.38925478535315, 75.4248171467935, 63.33117323537027, 59.30724505455264, 53.44789866478213, 56.996184549024036, 59.49357724958851, 63.69257257830713, 62.68337026719124, 65.87052745203819, 64.96234186234014, 67.49196467861053, 64.5246288853307, 68.21342975862565, 65.40619727103942, 64.81278973241007, 65.2348328405811, 64.90383971122004, 63.928252112480905, 57.31663826973208, 45.67989164783109, 50.103756458528586, 44.96840507753434, 47.36212168970416, 44.2999743646191, 48.09302791472405, 45.39548450900663, 46.88451036330193, 46.8962735514487, 48.74000718516689, 44.51303359000914, 45.37310346480339, 45.18185261757144, 46.80649049820439, 47.6855093433011, 47.155965835817405, 42.91372245357883, 45.07568582411736, 41.41285496373331, 43.686931440907145, 40.40557853637203, 42.03873188264909, 42.38608914036905, 42.7284610656, 40.84364452669698, 43.40129660021874, 42.9271016582366, 44.34526597299884, 42.56376466443462, 44.424999913861676, 44.739609303012976, 43.255529557504964, 43.764719886164514, 43.246437503445534, 43.94054405150875, 43.50254866384691, 44.13383453123031, 51.346041694764175, 50.06847081645843, 58.87813775770126, 49.5513298434596, 49.31751735748784, 53.823724485212765, 56.06506878329862, 53.285241896106356, 47.16517163861183, 43.78262550600114, 45.045130560475016, 42.849474030156294, 43.20717065565048, 42.39691095967447, 44.858951337875865, 43.74125626779372, 45.30410897347235, 45.41518657438217, 45.35881034789547, 42.80712812177597, 40.86422520299112, 41.044834659945586, 41.68547145781979, 42.74575871805991, 42.75936542018768, 39.54337881457421, 41.416714575982866, 40.19337438767956, 42.14662451897898, 43.205021196796054, 44.138557064917784, 45.370353883312596, 45.264598938726614, 46.64207650769142, 47.30938934510755, 44.8481922764932, 45.80501525632797, 44.37050250268752, 44.54105500252017, 47.12014282903364, 46.7672001161883, 46.6563892364502, 47.06485309908467, 46.889417248387495, 45.49797996397942, 45.63058353239491, 47.08110347870858, 46.15310991964033, 48.09011751605619, 48.18232851643717, 50.61789289597542, 47.835665518237704, 49.969729069740545, 48.39850994848436, 49.577009600977746, 51.45640542430263, 54.94969183398832, 56.67184768184539, 62.43913212130147, 61.808430687073745, 68.19958379191738, 67.07614637190296, 78.53204819463915, 73.77350714898878, 70.2686026788527, 71.82176713020571, 73.58669250242173, 73.04640170066588, 67.56166519657259, 4.600316555269303, 1.0644517141965129, 0.25671437803295355, 0.061301152942882436, 0.16450863301513657, 40.110996769320586, 73.3042347815729, 60.37394931239467, 56.59527517134144, 53.30370057013727, 18.863645022915257, 13.098556130163132, 38.657754698107325, 52.58301604178644, 58.80246739233694, 10.9248266297002, 0.3316181345332054, 0.2500333558888205, 0.045100691608123245, 0.060425866845875024, 0.07408696121626324, 0.06238052486291817, 0.027857142192642056, 0.16094519035710445, 0.07364122827927913, 0.055531331097647074, 0.05990146817038617, 0.03013352840958584, 0.1370099529383644, 0.13227919146658915, 0.4744229910354461, 13.415158083361964, 85.2681698337678, 68.79940832814863, 44.91957941362935, 45.528009630018666, 35.054214385248, 38.08172325934134, 57.4551450052569, 69.81587486882364, 83.73748840824251, 22.35575079917908, 0.2202734447294666, 0.11110505750102383, 0.39786255407717924, 0.8288657040365282, 55.200578397320164, 78.63241380260837, 76.09768406037362, 76.41677671863188, 72.41165238042032, 77.39468636051302, 65.92482089996338, 60.88928599511424, 56.29994030921691, 59.3135561481599, 61.771136791475364, 66.55350623592254, 66.75506114959717, 69.1112446015881, 68.66869926452637, 68.20991531495126, 66.23044413904991, 68.99540916565927, 66.35264165939824, 67.03184712317683, 66.30532218563941, 66.0322153952814, 67.1370215569773, 59.08051636911208, 49.70724798017933, 52.55431605923561, 47.56206843160814, 48.544884958574855, 48.030579859210604, 48.61293023632419, 47.962973886920565, 49.025355692832704, 48.79049201165476, 50.158618650128766, 46.4008625092045, 47.93280301555511, 47.07962082278344, 49.48960742642803, 49.025532199490456, 48.49344307376493, 45.17034438348586, 48.379462918927594, 44.218483201919064, 45.59990275290705, 45.77631135140696, 44.78548926691855, 44.702797858945786, 45.86813011477071, 44.337876227594194, 45.30650946401781, 44.90471363067628, 45.493406480358495, 45.58798659232355, 48.00546100062709, 45.9921750714702, 46.28439557167792, 45.47989391511487, 46.111434736559474, 45.800633968845496, 47.16939210891724, 46.481863375633, 51.78406061664705, 55.167720702386674, 62.08671500605922, 51.220553305841264, 51.123474644076445, 53.86418765591037, 60.462390915040054, 54.1121873547954, 48.35646998497748, 46.62141738399383, 48.136275968244, 45.316476206625666, 44.86511730378674, 43.65314022187264, 46.30322294850504, 45.74896850893575, 48.325702913345836, 48.014698182382894, 48.06175093497, 44.21146215931062, 42.461375113456484, 44.220224734275575, 44.02951125175723, 44.38618413863644, 44.419861608935946, 43.901069318094564, 44.60135752154935, 43.59059410710489, 44.017897113676995, 44.48351383209229, 46.758382628040934, 47.81614780426026, 46.81465295053298, 50.14862445092971, 49.26552241848361, 47.746439441557854, 48.47781242862825, 47.6143418588946, 46.6670580833189, 48.14079846105268, 48.76638904694588, 48.124018561455514, 50.37620429069766, 49.284628283592966, 48.907970920685806, 49.260827341387355, 50.16209779247161, 49.02080182106265, 51.09799100506691, 48.99367863132108, 53.348035120194965, 50.99571520282377, 53.539686049184496, 51.94348535230083, 52.805524256921586, 52.79783641138385, 58.51751504405853, 58.37176369082544, 64.30463490947601, 63.50402816649407, 69.11141718587568, 69.14224701543009, 78.57822233630766, 75.01034029068487, 75.65684887670702, 71.76431225192162, 76.14694902973791, 74.01365818515902, 72.30310470827165, 5.27928275446738, 1.6140396364273566, 1.2521265855719967, 0.11737665927578365, 0.4146866416258197, 44.49994464074412, 81.5103901586225, 65.50678253173828, 65.30108951753186, 51.12237638042819, 17.021656843923754, 17.988211224156043, 46.08418210860222, 59.77376784047773, 67.81185750038394, 15.20490715580602, 0.3401379515567134, 0.18537806316969857, 0.09303368688110383, 0.038249908210409266, 0.11283787177695383, 0.019309527668801528, 0.04911996041154189, 0.18425819584198538, 0.16747294895110593, 0.17542013057297276, 0.236034493352617, 0.22466703558400755, 0.2685889247204027, 0.33717993286348164, 0.7421947450887773, 18.64164475471743, 97.82791291513752, 77.90807754762712, 53.876676482539025, 45.01098632812501, 32.91398486783428, 63.92045444057834, 67.88743372886412, 76.5801199020878, 90.9445768787015, 27.283242056446692, 0.2881137786373016, 0.5310723125453919, 1.5898500118524799, 1.293837437706609, 56.1366638060539, 83.39160596170734, 78.36963853528424, 79.41127100298482, 74.31752420240834, 79.69485836644327, 69.83034057001915, 64.60967763777703, 58.552263321415076, 63.05278693476031, 64.85402561003163, 68.6881777548021, 69.24527199037614, 71.54818965542701, 71.03077411651611, 71.47178972921064, 70.49229544977989, 71.24359407732564, 71.06393383395287, 68.68351797903739, 66.9705718563449, 70.16877835796726, 70.1869232423844, 62.93040506301388, 50.6587012352482, 54.769047075702304, 50.20584006463328, 51.70400504143008, 49.3332068381771, 52.49286036337576, 50.972647743840376, 51.4822106976663, 52.68417396853047, 54.754946154932824, 47.85264938108383, 50.203419962236964, 51.45391471924321, 52.614210651766875, 50.51931196643461, 49.3506339288527, 47.19660943554294, 51.835102419699396, 46.16733635625532, 49.68088573025119, 48.14527780778947, 47.68157912838844, 47.26876927960304, 47.868146665634654, 46.834884535881784, 48.939812721744666, 47.963777972805886, 48.74275676665768, 49.188479223558986, 49.045340168860655, 49.1935351587111, 48.60972565989341, 47.42607593536378, 50.962488805094075, 48.31710900029829, 49.35605856680101, 48.309836925998816, 57.69454686872421, 56.32582010761384, 66.34591087218254, 56.25502132600354, 57.990250433644945, 58.45798915432346, 62.741699834023755, 57.53769128553329, 52.3624493998866, 50.11169141338718, 50.6026231088946, 50.20380435451385, 48.06271191566221, 46.37075047339163, 48.214209541197754, 46.88901716662992, 51.67884695914484, 50.29160268845097, 49.12130078961773, 46.405153582173014, 44.60892769598192, 46.48588772742979, 45.80510547084194, 46.62981910090293, 47.67973561440745, 45.38610219955445, 47.12476338109663, 46.674910668403875, 49.22143105537661, 46.67783675655242, 48.56716009878343, 50.02013544882498, 48.227616202446725, 52.43321288016535, 53.30304945668867, 50.49303600865026, 52.035527690764404, 51.07172681439308, 48.84908045491865, 51.76108337217762, 51.66531870442053, 50.61535120010377, 53.77599708495602, 51.33941681154313, 51.278847571342226, 51.154461368437744, 52.31168216274631, 51.12575354114656, 53.77759348961615, 53.389255308335834, 56.668446986906, 53.809623564443285, 55.43708947397048, 53.587660558762096, 55.18473986656436, 56.59565564124816, 61.12088626430881, 61.51802624425581, 67.8159132311421, 67.4800406732867, 71.26759898278021, 72.50713855989518, 80.60931974841704, 74.65665232750678, 76.44967755963727, 74.30694164768343, 79.53528065835276, 75.87547394537157, 72.49854856921782, 6.143223518325437, 4.412897373399427, 2.4472334308008996, 0.20833480712627211, 0.9063000328117802, 51.698717686437796, 87.99869645026423, 72.73774254706599, 76.5666740171371, 65.22270094963812, 31.378553452030307, 24.514380155071137, 57.621155400430005, 67.72034075952345, 81.25269043830134, 23.07155001548029, 0.5655137257229897, 0.5370783805847168, 0.15621516432973648, 0.16026812184962536, 0.24688177742064002, 0.12323995916953973, 0.13249794021248817], [0.047989992214547056, 0.0063998415416497145, 0.020856416235948284, 0.023017935229525454, 0.05996853533771731, 0.02411873845924293, 0.16453451146521877, 0.4403498822883253, 17.50270416659694, 72.72202168741535, 53.52743256476618, 43.465611703934215, 28.059571289247085, 17.12780402552697, 47.35522224057106, 57.59911168006159, 69.60064657272832, 71.63856890893751, 11.613274178197308, 0.4800645237968814, 0.3498263590999188, 1.9912189197155739, 14.494836561141478, 59.039111829573116, 71.31607947811004, 78.97445232637467, 71.57619537845736, 74.20746249537315, 65.47677639992007, 61.01256216725996, 54.220315333335634, 55.073979977638494, 55.659378036375976, 55.49945123734013, 56.026798217527336, 57.81378692196262, 61.06425508376091, 63.423694102994865, 62.23558072120913, 63.52235347993913, 63.895390495177246, 64.99705483836513, 62.28150775355678, 62.28306101214502, 63.81404838254375, 65.2988459217933, 58.96952898271623, 46.81489221511349, 46.03431309423139, 46.791008903134255, 47.40676610700546, 45.57444264811855, 48.746824264526374, 47.31043661794355, 47.8052749941426, 46.60214677933724, 44.861751910178896, 45.86705146297332, 47.17257707349716, 46.05990655960576, 46.81677103042603, 48.30164701707902, 46.511214471632435, 45.893684356443345, 43.67641948884533, 44.123169606731786, 42.83681261924006, 41.82206407670052, 44.6688772016956, 40.63464103206512, 40.102300874648556, 41.581077575683594, 40.69810498145319, 41.9869016831921, 42.592056720487534, 39.576338491132184, 40.317270294312515, 45.462866906196844, 47.59947999831169, 50.24958625916512, 49.735485123049834, 46.888311139998905, 50.1353786068578, 49.70466706060594, 53.754788829434304, 56.65031779196955, 57.94009508625154, 49.6666592936362, 40.72483593417753, 48.841259248795055, 56.37668540400844, 53.99486534057125, 51.867850288268066, 48.279870017882324, 46.152443116711034, 46.352778173262074, 46.85555542668989, 42.14728347716793, 45.54007091829854, 45.72182570734332, 43.09196279894921, 43.167617474832845, 43.28857552620673, 42.18301234706756, 43.197105853788315, 41.200246810913086, 41.64827954384589, 41.91742866270004, 40.2148062183011, 40.149989051203576, 41.30323256215742, 41.228789898657034, 42.33141522253714, 42.68864116361065, 47.68274799469979, 47.84236492649202, 45.216228269761615, 47.74397227071947, 46.474701127698346, 45.25399677215084, 46.455728623174856, 45.34851020382297, 45.41002081286523, 46.88377295770953, 46.76714912537606, 46.05460743750296, 49.55578173360517, 48.23363311829106, 47.02741407578992, 45.97612865509526, 46.515670284148186, 46.067508112999704, 46.50103984340545, 48.807581778495546, 53.71877754888227, 51.19370075964159, 54.614564526465635, 54.794236536948915, 57.834826515566924, 57.56674820376981, 64.22472053958525, 61.08094084647394, 64.21818587087816, 63.98310253697058, 68.5583943705405, 65.84028597800963, 70.05903044054585, 76.18363103558941, 74.19010992973082, 69.16149800823581, 78.18535773984848, 67.75013508335238, 77.12137560690604, 8.381659869224794, 0.7465843063208365, 0.917024099298062, 0.029997053676314896, 0.11527183270382306, 22.259835120170347, 77.11313078480383, 60.73489758276171, 61.41546803136026, 57.33516362405593, 29.56390811551002, 22.416810335651522, 31.443731477183682, 44.24118195810626, 62.80180623454433, 22.634001778018092, 0.29107850826075005, 0.0955977142157574, 0.015457546612578294, 0.022856702449761575, 0.11929925651319566, 0.09647113105822956, 0.028358102408087546, 0.010225085650510606, 0.0696704643327863, 0.041057612792017965, 0.06734192476517732, 0.06604201911437897, 0.10330287334058555, 0.12793682891154481, 0.33968231310286834, 22.683717819952196, 85.88168344190045, 59.17857562341998, 44.97306485329905, 35.43479411832748, 24.37944473758821, 48.46668466444939, 62.74031523735293, 73.35616696265437, 80.69441164693525, 11.47810047672641, 0.49422008195711725, 0.4700879139765617, 2.393779124944441, 24.90195739653803, 69.06741603728264, 73.09638054140153, 81.59387388537007, 73.69769557829827, 77.17093083166307, 69.6580308483493, 64.05983194228142, 55.53042619459091, 59.479507707780414, 57.50423346796344, 59.1904604050421, 58.089392262120406, 62.089648938948116, 62.59231244364093, 66.74071311950684, 64.3321228796436, 67.67686520853351, 68.04833719807287, 68.637892969193, 63.39255832856702, 65.35216269954559, 65.54124839844243, 69.5183160228114, 61.69297179868145, 49.57988862068423, 47.818528682954856, 49.62556069897067, 50.03167506187193, 46.7951823049976, 49.45425902643512, 49.76464010054066, 48.643407052563084, 48.77414357277655, 46.63037999983757, 46.872605969828946, 48.017781165338334, 49.084956107601045, 48.729585447619044, 48.991282063145796, 49.467171469042384, 47.81723430079799, 45.9112173511136, 47.1255753117223, 45.899316880010794, 45.72289259203019, 46.09358402990526, 42.78804971325783, 43.11175115646855, 44.828164654393355, 45.19553384473247, 42.661812151632006, 44.653360305293916, 44.50258047349992, 42.55759869852374, 47.1966721934657, 50.20092925717754, 50.62957763671876, 51.849473984010764, 49.647019986183416, 52.05442174788445, 51.72262061026789, 54.37256997631442, 59.18487494991672, 60.13395124866117, 52.20690388833323, 45.65349017420123, 51.18829181117397, 57.694072261933364, 57.171761605047415, 54.4576265735011, 50.16288618887625, 47.546261279813706, 49.56441094798427, 47.69613896646808, 43.24189932115617, 46.4422905829645, 47.523386016968765, 45.02557754516602, 45.04361260321833, 46.365325835443315, 45.04724079562772, 45.88334498866912, 44.68574731580673, 44.79415770499937, 43.73076392758278, 42.86722275518602, 42.438782261263945, 44.54920176536807, 44.57710158440375, 43.88547789665961, 45.29109454924061, 48.30178430003505, 49.36534673936906, 48.205898038802616, 47.5788208746141, 47.78237227470645, 47.865793243531265, 47.5191733914037, 47.08310780986663, 47.30862056055377, 49.96477511621291, 49.90597878732989, 48.4503048466098, 48.68685514696183, 49.33913746187764, 49.063614491493475, 49.15901830119472, 47.6966880982922, 47.023719203087595, 49.545865981809555, 51.11550046551613, 54.753518412190104, 52.997336003088186, 56.91536803399363, 58.83514858061268, 61.43969651191466, 60.28437022239932, 66.52621438426357, 63.89442559211486, 65.91666237000497, 66.17965729005876, 69.99457805387436, 64.91115885396158, 69.91533833165323, 70.94816900068714, 75.84158466708276, 70.86994909471082, 79.26751613616943, 69.30904188463765, 79.0781754832114, 9.932146322342659, 1.132240689569904, 1.8581961479879197, 0.06382205335783862, 0.11992879692585239, 23.463634060275172, 83.40820543227657, 66.42668816351122, 68.11538619379844, 62.22478635849492, 40.84290712110458, 27.737964391708378, 39.94570024551884, 53.89158933393417, 73.39421395332583, 30.39147330868629, 0.3893991824119322, 0.08610770812318211, 0.1024971480271028, 0.09178027510643007, 0.021289395724212932, 0.03758549930587892, 0.053043200093651974, 0.1603708389185129, 0.26633043623258995, 0.1461987485808711, 0.1299038592485651, 0.20242082285544566, 0.2986856694183042, 0.25625558329686043, 0.591176261584605, 30.934364641866377, 96.80073045915174, 67.0986686214324, 58.43348218548683, 37.41765422205771, 30.667261039057088, 63.636404237439564, 74.64156689182406, 79.46886708659511, 89.89946919102823, 14.515562365131995, 0.5935584885939476, 1.3603901310313133, 4.924299918836163, 22.902848874368978, 77.46540669471987, 74.34415709587836, 86.3820602047828, 74.84372585050522, 81.93285296040197, 71.8992417858493, 67.02434755140736, 59.34025964429302, 62.733815869977406, 62.06263557557137, 63.75345953049199, 60.771297177960804, 65.62349265621555, 65.91319499477264, 71.09746225418584, 67.26484375615274, 71.53838372999623, 69.58705948245141, 70.98569039375552, 65.82400814179452, 68.483516323951, 68.3687634621897, 73.12932060610864, 64.18468098486623, 52.30071129337434, 50.68976248464277, 51.62347878179243, 52.9676789622153, 48.7735277606595, 51.912941855769006, 53.21347428906349, 51.213791139664195, 51.55846941855646, 48.60916476095877, 49.95423178518973, 50.14500410326066, 51.428984134427964, 50.99830004476732, 51.70164769695651, 49.92956399917603, 51.66489508844192, 47.67078476567423, 49.53533834026706, 48.20972234972062, 49.44182511298887, 50.49745259746429, 46.1853047340147, 46.57108552994267, 47.242273669089045, 46.17499674520185, 45.95743856122417, 49.602842330932624, 47.67286754423573, 45.44176063229961, 49.01167054330149, 54.51861158494027, 53.782810241945334, 54.96580885302637, 52.045011981841064, 54.56361293792725, 56.100950625634965, 58.20767133466659, 63.38030092177853, 64.08108334387502, 57.20262673593337, 49.39524304482245, 54.617631819940385, 61.78248813075405, 59.265711076797984, 56.61409078105804, 53.29719728039157, 49.481519499132716, 53.84405412981587, 52.31760886407668, 47.508127996998454, 51.397158022849794, 49.284251736056426, 47.80911107217112, 47.992713297567065, 49.91152501875355, 46.87679113880281, 48.04703812445364, 47.23229515937067, 48.22807119738672, 46.105692386627204, 44.964623912688225, 46.43527346272623, 47.63023530283282, 46.81704559633809, 46.44264751865018, 48.317575762348795, 50.539586697855306, 52.511825023158906, 50.031376961738836, 51.43034519687776, 52.372745621588926, 51.01743336646788, 49.281278579465805, 49.941291885991255, 49.996718898896255, 52.64425600728681, 52.71293670900407, 49.54866655411259, 54.06500516399261, 52.833192656117106, 51.77793779680806, 51.535629457043065, 50.12993043468845, 51.05151091852496, 51.731202756204915, 52.52915797695037, 60.01302457624867, 55.62249991201586, 59.95319666401033, 60.91560902134065, 64.53524674138716, 62.96138394263483, 69.22441282579976, 66.41166548575124, 69.70090235433271, 70.6959762880879, 73.11727892967963, 69.12791467482045, 75.31897591006371, 74.45139469638949, 76.09810767635223, 76.0824260404033, 83.00468767842939, 71.72807739626977, 83.99646682123985, 10.663501658747274, 2.998224948683093, 5.22324973537076, 0.15864612985282175, 0.36532952720599793, 27.375207908691902, 93.0014991760254, 71.35877839980587, 79.7133876431373, 71.27672241580102, 47.155573598800174, 36.80306588449786, 51.981191096767304, 64.0026084838375, 81.6124031620641, 43.687649234648674, 0.49536146103374423, 0.20044387167980596, 0.19253666452582807, 0.19498169542320315, 0.2884541055367839, 0.14393167990830638, 0.21175220278241944], [0.0770928910482795, 0.028057399491268783, 0.040571169942737594, 0.08722143908662182, 0.047143396110303944, 0.08542035871575918, 0.11187240180950012, 0.28006679108065946, 22.449646457549065, 74.66520309448242, 52.99540227459323, 43.77152127604331, 16.701312949580533, 33.35473375935709, 42.20689565904679, 58.23501809950798, 69.44499123481013, 60.28459379749914, 2.3835500738313122, 0.08611186798061095, 0.5130325966785031, 8.391669757904547, 55.91032735763058, 66.07348657423451, 82.91081751546552, 66.71244852004513, 73.51277151415425, 62.83454233600248, 64.69817023123464, 54.05106113803003, 51.892831863895545, 51.46653298408755, 54.84476843187886, 51.07875962411204, 56.770452145607244, 52.4877259808202, 56.63676208065402, 55.45289270339474, 57.28337264830067, 57.88049074911303, 61.80968584552888, 61.87929222660681, 65.55747132147512, 61.556088924407966, 61.47805729219991, 62.676627712865034, 56.615220423667665, 48.46010292730024, 49.10173600719821, 47.29301737200829, 47.67071024064095, 46.160158418839984, 46.56812414046257, 44.41064011666083, 47.96606863698652, 47.59262369525048, 48.010630684514204, 45.20306087309315, 46.42291407431326, 46.75612726519185, 48.3848326436935, 46.34033641507549, 49.227326377745605, 47.46693134307862, 45.207865776554236, 46.4738146720394, 44.13878064001761, 41.87899335738152, 43.49370764147851, 40.44497874475295, 40.467493149542044, 41.48980009940363, 42.06252890248453, 38.42639369349326, 43.512087868105986, 39.9643942617601, 39.95435691648915, 40.60740017121838, 46.254664005771765, 49.783706741948286, 56.96507230881722, 55.08736310466644, 58.76349864467498, 54.8951042083002, 54.662182100357555, 53.94675354803763, 63.66252722278718, 48.01233299316899, 37.88042722209808, 42.794117619914395, 53.56691514292071, 55.51156351643225, 53.37253816666142, 52.48308973927652, 54.30329307433098, 53.56860960683515, 49.45274106917843, 43.496261104460686, 42.15378284454346, 40.47238042277675, 41.12361546485655, 43.749618761001095, 42.00688615922005, 41.0246148417073, 42.63828577533845, 41.63676346501997, 42.36140174250449, 38.73844569729221, 39.71677503278179, 43.45940651432161, 41.41520446346652, 40.647647611556515, 44.1337090153848, 45.99710941314698, 46.616004513156035, 46.97719204810358, 45.424341386364354, 46.185006633881606, 46.33158168485088, 45.27043934791319, 45.56520154399257, 43.371286546030355, 43.55874053893551, 46.46703681638164, 49.77460684314851, 46.24296357554775, 45.63701229710733, 46.29653922973141, 47.705772307611284, 45.193180422629084, 45.97233572313863, 49.645937412015854, 56.73834754574684, 56.16790156210623, 57.96785369996102, 58.84503295344692, 62.67323094029581, 59.977660486775065, 61.69447798882762, 62.53478304032357, 63.480337050653276, 63.52669162134971, 67.06602665685838, 64.60060519556846, 64.82172096929243, 57.147748854852495, 57.49231338500977, 45.049268661006806, 71.82664655870008, 67.03359650027367, 77.28622498050814, 68.18196450510334, 85.5831204691241, 18.390414983995502, 1.2003756915369344, 0.6650445430028824, 0.1578971563327697, 0.09678159585042347, 9.656367417304747, 71.48899324478643, 65.14241787695116, 61.709018215056396, 43.44692161006313, 19.568379232960364, 9.45360637480213, 31.245538034746726, 46.01969834296934, 66.46552747295749, 48.46433516471617, 0.5807552594811686, 0.021350721062551585, 0.03950366089420934, 0.11262614805732044, 0.04489712672488344, 0.05629434700935118, 0.026570593284803535, 0.027199932599380135, 0.04071167429849025, 0.05802973151026715, 0.10800843051965199, 0.03506720358986528, 0.045910967483876214, 0.003210912217318471, 0.17609047282847667, 29.5844123055858, 85.2482363485521, 58.14297183867424, 52.8822301280114, 21.03467102973692, 32.523867891680815, 45.0720105632659, 66.7254472547962, 75.40696251776912, 67.14769824858635, 2.539973706007004, 0.12205672870960929, 0.4804151775615831, 11.990017833248263, 66.6447562556113, 66.02127982724097, 85.41683550803893, 70.09037802296301, 75.97932261805381, 64.45452828561106, 65.93199099263838, 56.90702907500729, 56.24468980296966, 53.435535353998986, 58.8981810692818, 55.864957301847404, 59.1849769315412, 55.838355787338756, 58.692319393157966, 57.165219091599994, 61.05131518456244, 60.44987070945002, 64.74608982762983, 65.82315306509695, 67.43265844160511, 65.39556372550227, 64.58371939197664, 63.131352009311804, 61.16351066097137, 49.53895868793611, 53.17039097509077, 48.471238536219445, 50.37052077631797, 49.10835696804909, 48.807122861185384, 49.2271420263475, 49.52086087196104, 50.255387444649976, 48.84264776783605, 46.94278501695203, 49.07531099934732, 48.34743284410047, 50.606188543381236, 48.089984155470326, 50.87361181935957, 49.78155728309385, 48.032717550954516, 46.507146973763746, 46.52211866071148, 45.67259996168075, 46.48816662449991, 43.56058797528667, 43.77705574035645, 43.57376321669548, 44.84694888514858, 41.363888094502116, 45.553163789933734, 41.88990146883073, 41.88545742342549, 43.36288090675108, 47.40471078503517, 52.051805526979514, 56.990446121461936, 58.06205726438954, 58.30148266207788, 56.45714890572333, 57.51432572641681, 56.61244730795584, 63.45470436157719, 49.37623523896741, 41.866218197730284, 45.2798883376583, 56.670612135241115, 59.66485931027321, 54.57100268333189, 55.52293054519161, 56.17029028554117, 55.91429679624496, 50.79869454906833, 46.29074196661673, 44.2213975229571, 43.2472925801431, 43.54962495065505, 46.028637424592056, 43.438939586762466, 42.23693709219656, 44.6957964281882, 42.96577230576546, 44.30303381335351, 39.88415041277486, 43.45808075320336, 43.94128145710115, 43.643659853166156, 44.09055117637881, 45.796982242215066, 49.14315623621787, 48.1264857322939, 46.915736352243734, 48.28112517633746, 48.69504113351145, 49.465924155327585, 48.654848606355735, 47.48311896477976, 44.98641267899544, 46.08029896213163, 48.558754459504165, 51.79485497936126, 49.542441752649125, 48.74214879928097, 47.31427269597208, 50.23402229432137, 48.173350211112734, 48.97074845529372, 54.010970592498786, 60.12875803055302, 59.46966648101807, 61.31823639715872, 62.756710744673214, 64.10240142576157, 61.30595937851937, 65.00756286805677, 65.30810271539997, 65.6634694530118, 65.60581061147874, 68.82936739152478, 64.37268018722534, 64.9248440034928, 57.39007680646835, 60.31501177818545, 47.498463276893865, 72.86976952706614, 69.08662780638664, 80.47464124618038, 69.20611889131608, 85.90648066612982, 20.446376300627186, 0.6551129791525103, 1.457833082925889, 0.14636030120234336, 0.10540542463141103, 9.96823997266831, 79.6212354783089, 69.0863218615132, 69.69064143396193, 48.77144105972783, 26.70888743092937, 20.401537726002356, 40.456506590689386, 53.64098125888456, 75.43223042641917, 54.92360807234242, 0.7916145867878391, 0.05812064316424151, 0.03998298295623353, 0.07362014553960293, 0.05820686636011928, 0.026262210336543863, 0.06279826494714906, 0.20263972481892956, 0.21289165131747725, 0.0917079410846195, 0.27589623906439353, 0.1245201457171671, 0.22345571267989375, 0.27093667777315267, 0.19291753279826335, 41.2517475312756, 97.05985792221563, 66.46615505218506, 63.22228823938678, 26.50857786978445, 48.166893989809104, 57.56689725383636, 74.61951532671529, 81.90101115934311, 74.30029715261152, 3.6228592116986555, 0.21418920507834804, 1.4043008199622555, 13.772198692444833, 71.09667778015137, 69.89808774763539, 87.9629401237734, 73.04410319174491, 81.24203728091332, 68.96836834569132, 68.35090098842498, 60.43107471158428, 56.52403708427184, 56.138158229089555, 61.042442783232666, 58.43973836591167, 64.05263439301523, 58.04310437171691, 62.72686150766189, 59.812230602387466, 65.85541063739409, 61.61602274064095, 67.45976986423616, 69.63227656579787, 69.93783704696163, 67.60082614037299, 67.72723628628638, 67.41828687729375, 63.2723847512276, 52.24946160470286, 54.523910707043065, 52.15913726437477, 52.524000060173776, 51.54971861070203, 51.511220547460745, 50.81436834027691, 53.52922508793493, 52.66888849196896, 53.689034215865604, 49.131981403596946, 51.449984504330544, 52.29750279457339, 53.056759911198775, 49.84073015951341, 54.89987381042973, 53.19976560531124, 51.34740275721396, 49.74894669748122, 50.19463777542115, 47.9885712746651, 48.510830940738806, 46.430601919851, 45.62018532906809, 46.61775781262306, 46.96827650070191, 43.861861305852095, 50.33161870894894, 45.23038802608367, 43.08877391199912, 46.60375495110789, 49.14634904553814, 56.662567354017696, 60.10758115399269, 61.6834718181241, 62.10803701031593, 60.69448148050616, 59.01593846659507, 60.955872151159475, 64.39379430586293, 51.97520948225453, 45.55335598607218, 48.84059636823593, 57.191067511035556, 61.59635597659696, 56.407860402138006, 57.48691228128249, 60.133017724560155, 61.21696079930952, 56.369585913996545, 48.095561765855365, 45.82278751557874, 46.644547600899976, 46.440792237558675, 48.76063100753292, 47.56049163879887, 44.62138906601937, 47.89053555457823, 46.602742979603434, 48.75382961765413, 41.278705981469926, 45.44947985679873, 48.533066857245664, 47.55474536649643, 46.5726544780116, 49.33954538837556, 53.677784858211396, 51.36056230914209, 50.57080876442694, 49.618802455163774, 50.92469284611364, 52.303751130257886, 51.256490061360026, 50.56863577135148, 49.315097255091516, 47.73130693743306, 50.42017798269949, 54.94327091401624, 51.35389427984915, 50.87612213626985, 51.03400930281609, 51.73645873223582, 49.845197739139685, 51.145479140743134, 54.97801919137278, 64.16063685570994, 63.40282317130797, 64.21671890443372, 65.6920321526066, 67.91591013631513, 63.85768867308094, 67.7948187243554, 67.93559258983981, 69.79417631703039, 67.36999465573219, 72.18156614611226, 66.95448229389807, 68.86849695636381, 57.16311670118763, 62.71972279394827, 53.69489031453287, 75.84797813046363, 72.82377581442557, 83.36496522349697, 71.11365379825716, 90.91701046113046, 22.004877136599635, 2.955575546910686, 5.647122138930905, 0.32801194416899837, 0.19895712484515485, 12.262589220077762, 86.75150825131325, 76.47554951329386, 78.52476043085899, 56.76656899913665, 28.262728491137107, 20.839809640761345, 50.138951886084776, 65.87055098625922, 84.1277014824652, 67.23566916681105, 1.4691302444665664, 0.1933271753331346, 0.1469638559126085, 0.17348408849248964, 0.137333533155822, 0.15872129839995217, 0.1463583400172572], [0.07335808218246506, 0.03346828233090139, 0.04296243678958666, 0.07497170849913552, 0.019467496914007974, 0.09826186924211441, 0.07074512481208771, 0.17646941055934276, 30.473817586898807, 69.32757116133168, 47.872033734475416, 32.28848449645504, 22.461623414870232, 42.26289926036712, 49.366460692497995, 64.10209548088812, 71.40529771004954, 50.943661428266964, 0.25559112459661504, 0.19778099602028248, 0.5034056600303419, 10.18856538880256, 64.77089489659956, 72.60435842698621, 75.16710958173199, 68.6392265750516, 65.59005052812638, 56.86723270723897, 55.51464649938769, 48.68640015202184, 50.708958564266084, 48.88589189898584, 52.608025074005134, 54.46924071158133, 56.331997840635246, 52.71281511552873, 53.37430715560914, 51.25853753858998, 53.81385580185921, 53.949628645373934, 56.76964805972192, 57.55594207394508, 59.55729615303778, 58.54228873406687, 61.2186356513731, 59.546270370483406, 52.59685416375437, 45.90815005763885, 47.790064042614354, 45.994128411816014, 48.66448194749894, 45.124844889486994, 45.776550615987475, 44.63026146734915, 46.96246747047671, 47.081283907736506, 46.169054354390795, 44.910671710968025, 45.90912672781175, 46.370401382446296, 46.36853433424427, 47.45413264920635, 47.38283572658416, 48.46224454141433, 53.61343445316438, 49.35774910834528, 52.4774964394108, 47.454677858660304, 45.41325284588722, 40.74618539502544, 39.14781954980666, 41.108035810532115, 41.258701893591116, 40.27425366063272, 42.214524669031945, 39.672142382591005, 38.234232856381325, 40.718744493299916, 38.94313850710469, 44.6585770576231, 45.552520521225475, 50.64206646334741, 56.00855919622607, 56.92741755516299, 57.46596290219215, 58.1144993535934, 58.51966450291296, 37.550398995799405, 39.577707398322325, 39.6685298796623, 53.85454254765665, 55.44949985319569, 54.01048421859742, 56.76437639421033, 55.80845163714502, 47.66608576620779, 44.19631396570514, 41.18818944500339, 39.02602603358608, 41.26172996336415, 38.712279565872684, 41.558661230148815, 40.75683855241345, 40.5615633533847, 41.187463806521514, 40.96916821695144, 42.05272689942391, 41.40155461526687, 40.02561853777978, 41.03682518005371, 44.28892504784369, 47.26739645004273, 49.793194955395116, 47.15333784780195, 45.59326610257549, 46.70595622831776, 48.7091459766511, 45.503439903259284, 46.21097664679251, 43.615030473278416, 43.68749626221196, 42.5716878521827, 46.02140849636447, 45.91968182594546, 46.306388301234094, 44.606668410762666, 47.090646605337824, 46.908366218689956, 45.73832319628808, 44.364061970864576, 55.08989303342758, 60.732826571310724, 61.64500905621437, 66.52078582394508, 59.85755751209875, 59.96711323338171, 60.80897546583607, 62.42233260985344, 62.08512252376926, 64.10332710512223, 65.75949299720027, 62.64925349143244, 62.813294856779045, 62.04105469488329, 64.60766153950846, 63.93094678078929, 67.62672947299096, 54.800975168904955, 67.02813656099381, 69.2962706473566, 75.3063694123299, 67.91052079969838, 85.53231793065225, 35.48767159062047, 0.6633829902256689, 0.5568631221690487, 0.2836570161725244, 0.026718090108085065, 3.3484075386678023, 64.66734824642059, 66.7526763485324, 64.13567489193332, 62.13568972003076, 56.80683605132565, 11.815244863110205, 25.75404328684653, 40.17417830805625, 56.4916108500573, 54.30118676154844, 1.7055791760644607, 0.15762262106422456, 0.12647126440800008, 0.07168640172289265, 0.03980430060877435, 0.0503526188643469, 0.03976084810170916, 0.021043473839639656, 0.05091500784000082, 0.03269637979927563, 0.07130291342975632, 0.01675613171931717, 0.04380984877746913, 0.02627304665023281, 0.06020290461639243, 41.884170886008974, 79.21032797905707, 53.79627966111707, 40.38163638884022, 24.9258779710339, 42.91943734691989, 49.984618386914654, 72.20568872267201, 75.97264674402054, 58.03778563776324, 0.3399810873933377, 0.2473105721536183, 0.5046244139873213, 11.42633205459964, 71.01778322650541, 74.36944853874945, 77.68014861691383, 71.98944845507222, 66.79825428993472, 58.353603116927616, 58.95724019696636, 53.418029815919944, 53.48694585984754, 51.11695958722023, 54.81393860232446, 55.79365253448487, 57.15522489240093, 55.45514022150348, 55.57965586262365, 55.42305523349393, 57.754406159923924, 57.871802699181345, 59.148345916501945, 59.54443470124276, 61.40838815319923, 61.99195838743641, 63.90036013818557, 62.60296952339911, 54.00367498397828, 48.71948142205515, 48.67061261207827, 49.17914790491904, 49.34555053710938, 47.55377261869369, 48.41733732531148, 48.12353610992432, 49.4500110995385, 48.005602205953295, 47.69185966061008, 47.73412712158696, 48.27179778006769, 47.80254894687284, 49.100551451406176, 48.94309182320872, 48.55352201769429, 50.86409222695136, 55.16301778055007, 53.131226108920195, 54.61783970555952, 50.85804000977547, 48.149098196337306, 43.96951467760148, 41.324864433657744, 43.58194528087493, 43.248771313698064, 43.96588648519209, 43.86171617815572, 43.2245663673647, 41.06188912545481, 43.20229907189646, 43.701373607881614, 46.452818224507, 49.845233040471236, 53.574897166221376, 58.89011667620752, 58.12682736304499, 60.02289718197238, 60.54733376349173, 62.18898296356202, 40.449595374445764, 40.886739607780214, 41.96257122101323, 54.70588907118767, 59.02756829415599, 56.29631603917768, 60.05087152604134, 58.77093938089187, 50.05529557504962, 45.99931770755399, 41.76937880054597, 41.968815634327555, 43.368595800092145, 40.58809426523025, 42.528082862977065, 45.06762535341325, 43.05971307139243, 42.73233636733025, 43.325379125533566, 44.750380131506155, 43.50917746943813, 42.75390548090781, 44.04327092632171, 46.202661222027196, 51.31725542006954, 51.58537295556838, 50.69287684655959, 47.93035937893776, 48.35767807499055, 49.715053496822236, 49.33066906467561, 48.49398828321888, 47.48231880126461, 46.20990583973546, 44.53498317349342, 48.28636546288767, 47.38536957771548, 49.27941545363396, 46.448189827703665, 46.87222157755206, 49.43895393802274, 47.43354020580169, 46.279304335194254, 56.91616035276844, 64.09081866664272, 64.93000976500973, 65.71053789507958, 64.04373453509423, 63.38642374161751, 63.35913581232872, 63.51485390816966, 64.68479494894704, 66.4315362130442, 66.44911627615652, 65.55617693931826, 63.949946741903986, 63.06444814128261, 66.66117529715261, 65.10848153022029, 67.70155260639807, 58.15319745771347, 68.02737605187201, 71.81888811049923, 77.84993233219271, 69.21166512273973, 89.1799025381765, 39.358811686115885, 0.4563798124511396, 1.8433762077362308, 0.5339699635101903, 0.03812033592933609, 3.4523827077880984, 70.6286213474889, 72.71639700858825, 73.32450559062343, 58.21738312321325, 36.60116972461824, 15.668644078316229, 32.965195332804036, 47.913622625412486, 64.61580437998619, 63.57388557926301, 2.711456052718624, 0.23098684727184235, 0.06746256063061376, 0.011288163838006798, 0.05793156117321022, 0.01664190992502676, 0.04080719397132916, 0.20204390759669966, 0.1288869388161167, 0.155835583085014, 0.13267303726846172, 0.11614461369331806, 0.15911577239392266, 0.11282880895680959, 0.2571807110742215, 57.975059093967566, 89.39087898500505, 63.092414640611224, 47.422267313926454, 33.99347213006789, 61.326053680912146, 63.66481004222747, 80.28661066485991, 83.6284778964135, 66.44414271077802, 0.8319860720826734, 0.6682564125907037, 1.2632069135865858, 13.896559399943198, 73.15977388812651, 78.24112599895847, 81.50953508192494, 75.04168002836167, 70.82360236875473, 61.0461494230455, 64.45618744819396, 55.97918848837576, 56.797230166773645, 53.30711303218719, 59.00953323610368, 61.164922714233406, 61.267814328593595, 61.00068130800801, 58.81013954839399, 58.49385530717912, 61.014582187898704, 60.38964663782428, 62.1758234116339, 62.87951231002808, 63.7739029238301, 65.68589364328693, 67.31637585547664, 65.09993076324463, 57.26556901008853, 50.836765073960834, 51.93977086774765, 51.60045839125111, 52.13972937676215, 50.15260565665461, 51.07764174861293, 49.49945257556055, 52.46134804141138, 50.128541915647446, 50.80500564267559, 49.41965195440477, 51.092009390554125, 51.2668647304658, 51.559355874215406, 51.34118580049085, 50.7102176450914, 52.242620991122344, 57.737269324641076, 53.539329113498816, 57.0255317226533, 52.727598528708185, 52.357448377916896, 46.404918239962676, 43.87490710904522, 46.36187414969168, 48.07491440926829, 46.468139002400065, 47.631408091514345, 43.83753476604339, 43.950130324209894, 45.58141269991475, 44.56156899852138, 50.225577431340376, 52.481018727825536, 55.59140728365991, 60.517923831939704, 61.301652616070164, 62.88832979817545, 61.6442245821799, 67.35144968955748, 46.3547589701991, 44.79517752124418, 45.23615391023698, 59.36102467198526, 62.620910444567286, 57.91797684084985, 62.46337629133656, 61.871847568019746, 53.414429080101755, 48.82870766424364, 44.40270516180223, 43.70610398630942, 47.419376527109456, 42.92286157608033, 46.76840820620137, 47.309593308356504, 45.5933641618298, 46.01460710648568, 46.3291419706037, 50.08952609954342, 45.777350779502626, 45.92734221489199, 46.94509137061335, 50.38597099242672, 55.23336941196073, 54.4162691024042, 52.57318658213462, 50.13443331564627, 50.245479537594704, 53.35695458996681, 51.568110604440015, 50.497460442204634, 50.43707163103166, 49.405237244021514, 47.65622884996476, 50.300227980459894, 49.21049156496602, 51.35048966253958, 48.676637372662945, 51.309634254824736, 52.779138472772416, 49.45316076278687, 48.705623688236365, 59.46251992256411, 66.00081289968183, 68.28615050162038, 69.43163164200323, 65.56674772693266, 65.4705790550478, 67.63675505115141, 66.62164565055602, 68.36884190959316, 68.47185903979887, 69.96855705015122, 68.48594034871748, 66.04137020726358, 64.9703081961601, 67.71706165805941, 68.12778088354295, 68.91522022985643, 59.52963559858261, 70.52299191874843, 74.20335185143256, 82.38427854353382, 72.10642137835103, 91.84020303910779, 40.46015439494964, 1.5022671631266995, 6.586718559265138, 0.7159705135610797, 0.13803716959251514, 5.0474804832089335, 77.90494749622961, 80.9474515914917, 78.65490467317643, 78.87244716767343, 70.11878382775092, 22.1309950659352, 41.00980004956646, 59.66578498963387, 73.69272985766011, 76.09616218074676, 4.576593570170864, 0.5503442042296933, 0.26859162134989617, 0.2859395904646766, 0.16754660064414625, 0.13902687858189308, 0.102983774737485], [0.03475411494653072, 0.039958793730024374, 0.013850459813951485, 0.07320123334084788, 0.010159353391387531, 0.06781954994244922, 0.12275679517657527, 0.462318403466094, 50.03746448024627, 69.31949892351705, 51.715779996687374, 26.272064831949052, 14.947645760351612, 43.41546812365132, 55.13477671530939, 60.18665221429641, 70.90981606514224, 32.3229621302697, 0.059333823831571694, 0.3357385843992234, 0.38377245046919395, 13.768876444908882, 65.3870011914161, 73.26327739223358, 75.2641176408337, 68.03092971924814, 62.39769620280113, 57.66191667126071, 57.78704420212777, 55.27529954910279, 53.47901090498894, 51.91402442993657, 51.957637263882546, 51.383590544423754, 50.51319306896579, 47.92135753939229, 48.88316977408625, 50.334493806285245, 51.87921731702743, 51.68228295541579, 52.2056761864693, 54.208101072619044, 56.60610483538721, 54.99875284010365, 53.18120887202602, 50.50966685818088, 47.62979599737352, 46.08488421286307, 46.212729946259536, 47.47250895346365, 45.2161733565792, 46.74311676333028, 46.99371699363955, 46.59620831089635, 47.46466813548919, 46.956007326802904, 44.95930910110474, 44.95177422800372, 46.57226616336454, 46.4481427592616, 46.68318294709729, 47.26518815563571, 46.03326974376556, 46.795394112986905, 50.075232982635505, 48.791880530695764, 47.04630421053979, 45.93057424791398, 50.58707483353154, 48.55656577694801, 43.07598698523737, 40.73663050128568, 41.3366590007659, 40.68553378505092, 39.92825746536255, 40.40031863797096, 37.342650659622684, 41.13921473103185, 40.12629009062245, 40.58534076136928, 38.772052564928615, 42.85509086424305, 46.54114215604721, 52.30440224370649, 54.47729333754509, 55.22671707214848, 41.77656850507183, 37.85746566710934, 44.1829151491965, 41.96456378506076, 41.92518318853071, 44.136093816449566, 50.7962195334896, 48.949689249838556, 45.85633554766255, 44.119459044548776, 41.85667114873087, 39.69735537805865, 41.6143157405238, 40.38631185408562, 43.18824914193923, 39.531654850129165, 40.5536283985261, 41.271806532336825, 41.4086344934279, 40.36525264863045, 41.69944686274375, 41.42053888690087, 44.413424999483176, 47.55998173067647, 50.820953999796224, 48.44487236392114, 46.82502761963875, 46.904483072219364, 46.8773167364059, 44.68317816334386, 44.13821974108296, 45.630838486456106, 45.513104623363866, 44.81616220166607, 44.12508372337588, 43.10155299402053, 43.002599439313336, 44.33682895475819, 45.802277441947695, 49.36175777066139, 45.453468907263975, 44.51195101584158, 44.083498754808986, 47.821509684285815, 58.666686704081876, 59.83206210597869, 59.585835318411554, 52.54094469931818, 58.20368228420135, 64.64144883617278, 63.72751697417229, 64.22091584051809, 66.63290285295056, 64.59252903538366, 63.91168009850287, 61.58933885635869, 62.92578058858072, 65.72236776351929, 65.59672247978949, 67.17579810850083, 66.70627470939391, 65.5784010887146, 68.42831288614582, 68.662886311931, 67.22060726534936, 70.1034865840789, 75.064131675228, 66.57252973125827, 0.39056881481120664, 0.9800085389325697, 0.09939724218941505, 0.06560819884461742, 0.5152148440960915, 46.71016885388283, 70.93423674183508, 62.32238669549266, 68.62651025095295, 63.50649533733245, 19.507996305342644, 16.795677331186113, 38.242344317897675, 50.10778081032538, 65.096137831288, 6.608275905732186, 0.25096012309433957, 0.03126259262283002, 0.06704005547949383, 0.005738728730413582, 0.09095251710424501, 0.12038094967964197, 0.05125254617943879, 0.018463912157101497, 0.022311010360417348, 0.05442803042129644, 0.08891626306238676, 0.009854776942501626, 0.049254002815653244, 0.5864838811178362, 61.86094730131088, 77.45308260763846, 58.389563406667406, 34.28275477501654, 24.301799458842126, 46.240869029875725, 63.04254170387023, 67.18192485070998, 77.23392409663047, 36.59314455524568, 0.11745909033643624, 0.32639988067169345, 0.3125906555402664, 18.255334438816195, 68.3875516153151, 77.31965141911661, 79.105663453379, 70.16385186103084, 65.07500802316974, 61.28932068424841, 60.07067557304137, 57.32060378597629, 57.49301941164079, 54.50631887682023, 53.92824780556464, 54.58177351182508, 53.430655925504624, 50.73204563510034, 52.27390189324656, 53.25910322127804, 54.05808218063847, 54.10045946798017, 54.2847716423773, 55.71292231159826, 57.61860978218817, 57.02010316233481, 55.4820006124435, 53.331988703820016, 50.356776791234175, 47.146269736751435, 47.82745991983722, 49.33065337519492, 47.72727866326609, 49.53060796183925, 47.74170514075987, 48.69772403470932, 50.03901381646433, 49.14293266111805, 46.76275999315324, 46.82464714973204, 48.064720169190444, 47.27134627680625, 48.20643148114605, 47.13905649800455, 49.875043053780836, 50.06932197078582, 50.86230362615278, 51.27662358745452, 49.328966756020826, 49.37419168410763, 53.070382302807225, 50.59872819531349, 45.274918694649976, 42.95122031242617, 43.2854337076987, 44.915986522551506, 43.19097518920899, 42.2100257104443, 42.26025950524115, 44.416813927312056, 43.22644126030707, 43.03118959549935, 42.93299698060559, 44.547087607845185, 48.60997276921427, 55.41093510966147, 57.878204007302564, 57.22076377561016, 49.09627999028852, 43.24222487788047, 46.63615372873122, 45.09246180134435, 44.841018261448035, 50.59220137134675, 51.94519942806613, 51.83225870132447, 47.15045882809547, 47.31263314524005, 43.776894923179384, 42.21503849952452, 44.61493676708591, 42.39797784436134, 42.74707271206764, 43.02431760295745, 43.16242033435453, 43.77531813037011, 44.07919591472995, 45.00110980003111, 44.69733791966593, 44.71835005667902, 46.409005349682225, 50.8820370704897, 53.02602814089868, 50.89826391589258, 48.365958198424316, 49.51807991150887, 49.20511007308961, 47.99095999810004, 46.06812392511676, 45.721194205745576, 49.82386396777246, 47.46882584787185, 45.60820248819167, 45.10584885074247, 44.44348212211363, 46.88544780977311, 47.590705656236224, 50.41804029095558, 47.67850399017335, 46.332825076195505, 45.395704161736276, 51.36932488410704, 60.741306735623276, 63.18391961436119, 61.22666474311583, 54.97490090708579, 60.97926908923734, 67.47771078540434, 65.81123690451345, 67.89911454723728, 66.51580441382625, 65.36316887024911, 64.3904406793656, 64.39395512303999, 66.26047380508916, 67.04846228322675, 69.42784263241676, 67.49323552654636, 71.05120966511389, 68.38230348402455, 69.37081921485164, 72.18275854664465, 70.34588121598767, 73.40709501697172, 76.59745677824944, 70.62574232778242, 0.629512220621109, 0.2568119316692314, 1.4517145531792797, 0.08699240944077892, 0.8837511847096106, 51.53007145850889, 78.197752429593, 69.22499333658527, 71.07603826830464, 46.83522578208677, 22.848065130172238, 25.683995639124227, 45.64499039803782, 57.02484530787314, 76.90545697366038, 10.08257902437641, 0.29706119529662595, 0.10850556029547608, 0.09133909273171618, 0.08323662508759769, 0.09068286181577752, 0.020128609725244103, 0.14061732307797478, 0.19854863144217, 0.10764420167693209, 0.2289879093727758, 0.23307938579349752, 0.29275005082449607, 0.2913859546665223, 1.7370694346966284, 78.34277029960387, 83.80995811954622, 69.73105753621748, 42.22788818420903, 26.67727508852559, 56.77159747769756, 74.55128177519768, 74.30775750067927, 83.24905134016468, 41.067337297624164, 0.18941343131084598, 0.8992382343257628, 1.6634535332841258, 16.356588582838736, 69.144498455909, 78.10701231802665, 83.04049891810264, 73.49647798845845, 69.1603369866648, 64.23300458538917, 63.69211366099697, 61.70135782610986, 60.863202233468336, 58.15733163587509, 58.96583018764373, 57.923915309290734, 56.781379868907315, 52.60328685083697, 55.40414940926337, 56.29177393451814, 59.19625374578661, 57.86576224911598, 56.723136594218595, 60.09297816984115, 62.7363811000701, 61.11973308747815, 57.70823986299577, 56.1953071625002, 51.19367722542056, 49.94943472646898, 50.095150778370524, 52.15327724333733, 50.25600717913721, 52.8312942289537, 50.219999820955344, 51.22720172328334, 54.59643533152919, 51.72555846552695, 50.598685049241595, 49.22735775670698, 51.344492358546105, 50.94463025369952, 51.54045397235502, 50.85729475944273, 52.51224079439717, 52.02918914056594, 51.30153848278908, 50.06825900846913, 52.6001371875886, 48.87432482934768, 56.46903760971562, 54.2771073310606, 50.32043210921749, 47.10985052970148, 45.34866317625969, 47.072709606539824, 46.98091829976728, 44.786913087291104, 43.67408960096298, 47.55265474319459, 46.83369998008975, 45.32061822952763, 45.86743585525021, 48.041848828715665, 52.13163360472649, 58.03360439115956, 61.16060418467368, 59.442355017508234, 53.830145405184844, 47.90741743579988, 48.940561894447576, 48.70107766120665, 49.53243578633955, 52.97843802359797, 54.479034869901604, 54.78937279793524, 51.55602578193911, 50.64915026387861, 47.51521571989983, 45.58118520244476, 48.174256278622536, 45.63294872160881, 47.8826202115705, 45.52574642242924, 46.26656839924474, 47.81069570972074, 46.37592015727874, 48.409943657536665, 47.36623625601492, 47.82625967456449, 49.79197117590135, 53.79056869014617, 54.87683773040772, 52.497488760179095, 49.06080999682027, 50.929258484994214, 51.476742913646085, 49.458859966647246, 48.460789342080396, 48.08333966039842, 51.20795465284779, 50.2364698533089, 49.81595646950507, 49.33004148544804, 48.306416619208555, 48.35206516327397, 48.58356345084406, 52.734890214858524, 49.55735852641445, 47.626395302434126, 47.356642138573434, 54.28728588165776, 64.16641842934393, 64.34477644581949, 65.94742944163661, 63.5780825153474, 64.86699688819148, 68.57234231887325, 70.1103271976594, 68.55782954923569, 70.50641598240023, 66.91844355675482, 67.36306775000789, 65.44243604906144, 68.72435769727154, 71.11809392129221, 73.36781640206614, 71.52724419870685, 74.51845938159575, 72.15138743000647, 71.64780216832315, 75.60417144529282, 73.91715218943935, 76.86090669324322, 79.09996032714844, 72.89024429936563, 0.5751496409216236, 5.528891115419326, 2.400272853912846, 0.1976224464634734, 1.109456989553667, 56.58164493499264, 85.70920113594302, 76.38117728694793, 86.04071201816683, 80.74655563600602, 30.55819561404567, 28.14233918343821, 58.844397529479004, 65.98640211166875, 89.84037476201212, 13.846856105712153, 0.6598359418492163, 0.25800937306015725, 0.275809487267848, 0.18028091248725692, 0.15391008237436896, 0.20279965333400235], [0.03417730053526259, 0.08868501176156345, 0.0811133664401789, 0.07838599383831024, 0.08718409996119239, 0.11589715197201698, 0.07166192521371188, 3.261573862644934, 66.34092161732336, 58.977130536110174, 39.07008209536153, 28.145231931440293, 25.404279655025853, 52.900830007368526, 55.89181769278742, 62.06531063202889, 73.42236872642272, 35.30016268453291, 0.08552045576394567, 0.30871066535192154, 0.2692175458275503, 24.522350411261282, 71.50986025410315, 72.80301863147368, 71.4593401262837, 68.76788031670355, 66.79150781323834, 68.46839166456654, 64.87592028033349, 67.5340909342612, 64.99867085487612, 60.155583120161495, 57.13269479813115, 52.278922527067124, 49.94948571728122, 46.7437796438894, 48.61351859185004, 46.27518976888349, 47.03179928564256, 47.30916969237789, 48.96866959910239, 49.06142188656715, 48.10380658795757, 50.866155393662, 48.790146843079604, 46.6295680692119, 45.305564172806285, 47.48706486917312, 46.54901827535322, 46.93859984797817, 46.20340254998977, 46.78465074108493, 46.702951692765765, 47.249122127409905, 47.49418789340604, 47.695005401488274, 44.68080905175979, 45.69286684836111, 42.48170083568942, 45.03501869017079, 45.98787223139117, 46.781116685559674, 45.71152164090065, 47.48369947556527, 47.39450085547663, 47.10004852664086, 44.938771570882494, 44.590873026078754, 42.99893986794257, 45.86724758148194, 47.184920772429436, 45.512571181020434, 41.28149086429227, 42.43943729708272, 39.37461099316997, 40.80789604494649, 38.07976599662535, 38.10755991166638, 38.3701116038907, 40.946249808034594, 40.39874968990203, 39.84139265552644, 40.36359740841774, 42.86352396011353, 46.15273729447396, 47.002432500162435, 45.60542545010967, 42.29764753772367, 50.50756054539835, 43.32851702167142, 37.98719806055869, 47.70534084689233, 40.47182736858245, 40.76662094362321, 40.28269460124355, 40.196449525894664, 40.51548334860033, 40.54962365858017, 39.436988446020315, 43.35962926187823, 38.51108158788374, 39.25752432115617, 42.33387847100535, 40.533255607851096, 43.22599018773725, 43.06751466566517, 43.625675785926084, 47.40380079515519, 46.63047805909188, 46.40692257112073, 42.96754521708335, 42.06812612472042, 41.73488155488045, 43.41549558024253, 49.160010660848315, 46.0970357156569, 43.55388856703236, 44.50690684779998, 46.15954260672293, 43.781013411860314, 42.02683533391645, 42.67924316467778, 43.537799004585516, 46.68384975002658, 44.78690132018059, 46.72310483071112, 44.256310539860884, 44.512947297865345, 43.32768940156506, 47.479157370905725, 56.2498555644866, 62.420453794540904, 56.75821435066962, 45.154188140746086, 58.732186363589385, 64.17607922707835, 60.764633071038034, 62.24221737154069, 63.73043913995067, 65.73129900040166, 63.26056664989841, 65.52997942893737, 62.89855541721467, 62.80890572455622, 60.62668723444785, 65.8826240416496, 63.28359488518008, 70.02408996705087, 63.963318101821415, 68.77634479153541, 60.81523164626091, 74.52953615496236, 65.5438881535684, 86.00143340326126, 9.33703157209581, 2.350969151143105, 0.393744494405485, 0.05349960080498169, 0.03937364045170046, 30.532700207925615, 72.14881435517343, 63.99821542924451, 61.099493657389, 60.510879255110225, 30.56978229553469, 14.507961792330589, 32.04435029337483, 48.81877622296734, 70.92450926380774, 15.217131222448042, 0.677150632104566, 0.1703322801979319, 0.09452191226544882, 0.030022131564516216, 0.04258298194937168, 0.1137718708524781, 0.033365986610372225, 0.07491661145562127, 0.08719977412012317, 0.019377182808614547, 0.07066511458927585, 0.09225185584997939, 0.15843150265995534, 4.234358437599675, 77.47005078100389, 65.63223954169982, 48.05360809449227, 33.722412816939816, 23.233536058856597, 43.33982521487821, 61.708755416254846, 68.02866258928853, 79.83450258931806, 37.99903185136857, 0.08078693637564298, 0.23704275699152103, 0.47225811849198035, 29.22210689513914, 72.57687830155896, 75.37522269833472, 75.71786526710757, 71.49552006875315, 69.53257776075795, 70.609252683578, 68.64667123363864, 70.33467892677554, 68.80571549938571, 63.45613994906026, 58.50644219306208, 55.40411018556165, 52.303806043440304, 49.73408483689832, 52.062129205273045, 50.25969812946935, 49.51159231124386, 49.44848921991164, 51.56268204412153, 51.949737610355506, 50.66079185855005, 53.52469082801573, 50.77659983788767, 48.312923831324426, 48.1360210141828, 49.50149613042032, 48.857894020695845, 49.18037560678298, 49.22231358866538, 48.24060709245744, 47.86712684938985, 49.00765011387487, 47.766188575375466, 48.909594781937145, 47.14126087004139, 47.987633828193914, 46.00162013884514, 47.962365919543856, 47.71378570987333, 48.23976770524056, 47.42341264601677, 49.02825040201987, 49.03651091360277, 49.06126499176026, 45.8057055934783, 44.5866015649611, 42.46063378549392, 47.23659015470936, 49.512933761842795, 48.613495057629, 43.54905620698006, 43.98485114497524, 40.973788769014426, 44.68423720329039, 40.98892519550939, 40.998735043310354, 42.03013404723137, 42.75503512351744, 42.51290721278037, 41.920801901048236, 42.722338245761016, 46.08352315041327, 48.424581943019746, 48.560499914230846, 47.47939663548624, 45.63787129617507, 50.94999997846542, 46.007978300894464, 41.801997230898955, 48.04227636706445, 42.8855323791504, 42.63841521355414, 42.9751467704773, 42.78708873256561, 42.061112926852324, 42.17575988461895, 42.04585098451184, 43.98247418865081, 41.09543323516846, 42.31490988885203, 43.27811064258699, 43.92601951476067, 44.97677149311189, 46.883984765698834, 47.842564967370805, 49.690252350222686, 48.75977985320553, 47.76572965806531, 42.96137925117247, 43.025878706286036, 43.055598505081676, 44.15823167370212, 48.42577042118196, 49.235516286665394, 45.340120254024384, 47.691310528785955, 47.54611222974716, 46.80864387942899, 44.07990194136097, 45.487075774900376, 44.90914983134116, 48.95461966914516, 45.039125411741196, 49.16265433834445, 46.785694091550766, 46.56065594765448, 46.03824330914406, 49.12129294487738, 59.92198636454921, 62.709395193284564, 58.819208068232385, 52.10950359221428, 62.864415107234834, 66.45266994353264, 64.1557535048454, 65.04638256565218, 64.75060839806834, 66.03547880726477, 64.31144022172498, 65.68434430706886, 63.893343017947295, 64.84834994039228, 64.78333273241597, 68.96994513850059, 64.92949593451716, 71.46613367142217, 66.87474835303523, 70.66051021698983, 63.40993835080055, 78.53581367000457, 68.18583980683358, 90.55240261939265, 10.996575605484749, 1.644214185014848, 1.1903178763966407, 0.0931303441945103, 0.04662179748617834, 31.130526296554077, 80.96573768123504, 68.53189483765634, 69.43015683081843, 54.92986817513743, 26.372026435790527, 17.925631769241825, 45.66424531321372, 56.80274109686575, 81.50872707366943, 19.815986694828158, 0.5580563194328739, 0.16956862843325063, 0.08408722017080554, 0.060600573197007186, 0.04314815182419073, 0.04403848771847064, 0.20267678815270626, 0.2096174987814119, 0.2748264125998943, 0.18908954465821867, 0.24648643008643584, 0.2960220736361319, 0.44523712487951406, 6.854459056931158, 88.75076386236375, 74.73631566570651, 55.51741569272934, 42.26044385663925, 36.63897745070919, 67.84066338692942, 72.14959882920789, 76.39287379480179, 88.06957367927798, 45.72014693290957, 0.22035101879267927, 0.909897888139371, 1.695703628563112, 28.309763593058435, 75.65532699708017, 77.1545353243428, 78.75787473494007, 73.24934513338151, 72.6189104203255, 73.18770900849374, 72.68861093828755, 72.71365134946763, 72.21558094024658, 64.88758540922596, 64.56575493658742, 57.61858232559697, 55.630572149830485, 52.53305289053148, 54.038431106075166, 54.11142641498197, 54.61191300422915, 50.668165914474, 53.60611923279301, 54.063620567321784, 52.630790510485255, 56.932132244110115, 52.61614438026182, 50.27405008192986, 49.83871798361502, 52.66453073870752, 52.513107638205256, 53.36104169968636, 51.73937697564402, 50.875165077947806, 50.50380291477327, 52.91972014211839, 52.08305112777218, 53.1658527928014, 49.755559813591745, 50.6386108552256, 47.66633679789882, 50.26298115330358, 50.434812345812404, 51.42556382763771, 49.07667206179712, 51.725048557404556, 50.78502116664764, 50.57429182913996, 48.26799308100055, 44.75769535187752, 43.02831449816304, 48.38315386925974, 50.67184509769563, 51.890498053643014, 48.29628513705347, 48.45967538895146, 44.057579732710316, 47.45992598995086, 44.470958325170706, 44.0958228418904, 43.962752511424405, 46.52619792569069, 45.1994130688329, 44.03685000634963, 45.49105698062528, 48.80817797876174, 51.44795663895146, 51.56072085903537, 49.36809632085985, 48.590937506768014, 54.43461795007029, 49.63220127167241, 45.27555411861789, 51.40611279395319, 43.74965406233265, 45.66753618178829, 46.55046170757663, 45.501800352527255, 45.83806906977008, 45.29047481475338, 45.16018544473956, 47.5145253827495, 43.42515245560677, 43.14329093502414, 47.7867849411503, 45.094175877109656, 49.38552733390562, 50.21827790044969, 50.878836416429095, 53.519168130813114, 49.696402626652876, 48.04583003444057, 43.698055282715835, 43.5706998455909, 43.05971307139243, 46.34078748764531, 51.33773019236904, 51.995166501691266, 46.575094192258774, 48.697673043897076, 50.37150136886105, 48.816297285018436, 48.06231967864498, 48.489046096801765, 47.170659034482895, 53.03872877551664, 46.86509070857879, 51.646095168206, 49.04926253903297, 48.87134382801671, 49.232660801179954, 50.512773375357355, 61.378221204203946, 67.2447455313898, 63.48306702029321, 54.00998607758553, 63.859077192121944, 69.36343731418734, 65.8472756416567, 68.72834282536661, 68.92362194676554, 71.02990335033786, 67.35840797424316, 71.42783564905967, 68.18664781508907, 67.13945342648414, 67.35198313190092, 72.00880142950243, 66.84580126116353, 75.77188414912071, 70.93837876473704, 73.93368890208583, 66.62921582498859, 82.74496401509931, 70.99082869868126, 94.23956394195558, 11.269402926967992, 5.699244064669456, 2.6028529770912665, 0.25298455639952616, 0.2133589955948053, 37.8023563661883, 88.63262991751395, 77.99800180619764, 77.0357031976023, 76.59150262032786, 44.46855783462525, 24.57506118282195, 51.88869376336375, 66.38738601438462, 93.80840132313391, 26.070702114412864, 0.709964139086585, 0.23672277738730754, 0.18922189400801737, 0.15954370910842575, 0.1613539748735005, 0.2605633263386065], [0.0356322777036938, 0.02960592557135369, 0.024037713169931404, 0.05193770074495866, 0.08968117121126383, 0.08726637780426011, 0.33203700076668496, 4.749516162180132, 72.08788425691667, 53.13248126737533, 43.89012982768398, 25.934193826490834, 28.455183506011966, 49.97772286015172, 51.840864381482525, 61.70134605899934, 75.15652702700707, 23.905722441211825, 0.4920178856099806, 0.32464860367678827, 0.7228259586038128, 33.925438619429066, 68.27424218577724, 70.1672564783404, 72.05647391657676, 69.54521563745314, 69.4343694563835, 69.78383694925617, 65.98437032391949, 68.37216807949927, 66.03286650873, 64.78688247742193, 57.155213125290416, 53.516587211239724, 48.62481501794631, 48.12561104374547, 46.311463848237075, 45.802987390948886, 48.59272610756659, 46.850056263708304, 46.01690561540666, 47.622990685124556, 46.834649193671446, 45.53399124453145, 44.666696363879794, 45.390911025385705, 45.273188929403986, 47.397250436967425, 46.29494674744145, 45.855460859114125, 44.744304380109234, 46.667509155888716, 44.009797419271166, 45.44752259408274, 44.57196720184819, 46.32758086727512, 45.20543782941757, 45.68228821600638, 41.79624703622634, 44.88087346476894, 46.26327753067017, 48.21419385171706, 43.75807146872244, 45.61827905716435, 46.00465605335851, 47.555016010038315, 42.96729026302215, 39.82998640306535, 43.60327512987199, 41.51506800805369, 40.48770120066982, 45.50027455053022, 45.45303352417485, 41.95520893219979, 39.09448316020351, 39.41122239635837, 40.5235359745641, 39.4199888936935, 38.73952042671942, 40.413454655678045, 42.02599986906975, 39.75552020534393, 38.70340324217273, 41.3918859727921, 41.890352541400546, 44.57441083846554, 41.48122187583677, 41.287299894517474, 45.99969425509053, 41.705283349560155, 42.33801264916697, 42.57968164259388, 39.91482334752237, 42.37667545195549, 40.6707582166118, 38.382369010679184, 41.54314433374713, 37.88896229959304, 40.85016350592337, 40.33017489217943, 40.581963600650916, 40.869088942004794, 39.599527543590916, 42.497978671904534, 41.53856300538586, 47.25658247547765, 47.03809861213931, 45.366592330317346, 42.84313155758766, 43.277310479071836, 39.783800494286325, 42.745354713932166, 44.01472391620759, 44.64635102979599, 47.13325139014952, 44.85442884506718, 42.92123771482899, 44.742876637366514, 42.74375438690186, 42.04047341500559, 41.146600554066325, 40.41941273596979, 41.01859400349279, 46.395688902947214, 44.88123432282479, 44.01450034110777, 45.143935065115656, 46.269498409763465, 44.82572886251634, 45.446334115920536, 51.424524399542044, 61.39627195173695, 59.888269670547984, 65.39304948622181, 59.382487881568174, 61.01342901106804, 60.945320975395944, 62.79208660125733, 62.11619946264452, 62.2522900181432, 60.00034355348157, 61.16930400171588, 57.34617763949979, 58.851653914297785, 55.02399721453267, 61.30179774376654, 56.80201938075405, 61.344222099550315, 59.42095456584808, 59.971278790504705, 56.12341796198199, 69.95135353457543, 64.85246450670304, 86.45901710756364, 33.51993222390452, 0.27347442063112415, 1.4913857728242876, 0.08179235016746868, 0.1061567270587529, 18.41758720336422, 72.31841764142438, 61.828842701450476, 67.57234188818163, 51.43637387983261, 56.697660799949404, 17.62165004207242, 20.431088862880586, 43.81475756245275, 64.74779998102497, 26.515179218784457, 0.2372851012454879, 0.08704171485958562, 0.017709459193171035, 0.037715155856623765, 0.09356763484256883, 0.032558801899393724, 0.021635962409838554, 0.08984379635583009, 0.03611884695748168, 0.07657554421213365, 0.04370984365983356, 0.07596503342351607, 0.5451698012409673, 7.4192058367113916, 82.7863528651576, 60.049432016188106, 49.32985321167977, 33.77181899163031, 36.92416121882778, 52.59388100716376, 61.17025321529758, 68.40036992103823, 80.81234947327646, 27.2277012948067, 0.46515173368876983, 0.2381740237075475, 0.5008579273858379, 40.57901790065151, 69.63552428830054, 73.13381564232611, 73.93705429569368, 72.81694304558539, 72.39865364566927, 70.71655304201188, 71.10739369546214, 70.00642361179476, 68.87482766182193, 65.51535683293497, 60.55775942340974, 55.82551786976477, 52.18668407009494, 52.54392570064914, 49.533549739468484, 48.79502234920379, 51.09630438589281, 50.17568880511869, 48.852759638140284, 49.641410996837, 50.25346940563571, 47.595467413625414, 47.52400967382616, 47.04628067631876, 47.742356254208474, 49.15515084420481, 48.09311028449766, 47.19954729080201, 47.14238659028084, 49.56113184652021, 47.29175044644264, 46.84412564000776, 47.389229189965036, 48.42286394488428, 46.353794067136704, 47.31182905935472, 44.74166854735344, 47.206721305847175, 47.998914564809496, 50.528639362704375, 45.48984496824203, 48.684352674791896, 47.91049649638515, 47.69045545208839, 43.20697845951204, 39.50690469434185, 42.520042004123816, 41.6427529242731, 41.833054557923354, 45.30124172087639, 47.653851893640336, 42.91004719272737, 41.66790316181798, 42.604565158967056, 42.82807357849614, 42.47300101864723, 41.311387169745664, 43.62919807434083, 44.272286353572724, 41.72132192119476, 41.02589353438347, 44.12395800313642, 44.96483179830736, 47.46948088369062, 46.530124218233176, 43.826081445140225, 48.22493722361904, 43.53479054666335, 43.43381304894724, 45.07735675381076, 43.20899848015078, 43.829662569107555, 42.92364997248496, 43.18688023474909, 43.405728878513465, 42.31658081854544, 42.917950768624586, 41.368940107284054, 43.70170308697609, 43.320797797172304, 42.54619636843282, 44.771419725110455, 44.96559273812079, 48.49418832409767, 48.886637149318574, 44.69915005468553, 43.754317760467536, 43.38064139889133, 40.329645372206166, 43.970471735923525, 44.960983953168316, 46.29374257979855, 49.76859777204452, 46.26444639698152, 44.6331444094258, 47.19032579852689, 46.63699703831827, 44.48655366897584, 42.56736932262298, 44.48130946005545, 44.37311087885211, 47.936235089455884, 46.238762717093195, 46.5623817905303, 46.65067826547931, 50.37716527138987, 48.58635617840675, 46.61213313379596, 54.233380748379616, 63.419681518308586, 61.15372434739144, 66.79797187928231, 63.3388767703887, 64.41828558521887, 61.11727768375028, 65.63016853024884, 62.40076349627588, 64.08815145492554, 63.05264572943411, 63.63823598431003, 57.769573965380275, 59.911729366548606, 57.63851188844251, 62.52463586868779, 58.423621346873624, 63.53216725011026, 61.95293472659204, 63.71427113010038, 59.0572214126587, 73.90606757133239, 67.74607150785386, 89.59343018070345, 36.3705422032264, 0.34809147638659327, 2.5407589154858745, 0.10637633382312714, 0.1879476293200447, 20.618442835346347, 82.24881556726272, 67.85407789291875, 72.95089198696998, 56.309859983382694, 45.59481936116373, 17.026065587997437, 25.980573892593387, 49.41908321072979, 74.6615239112608, 32.837498649474114, 0.10883307820486446, 0.04697485293652262, 0.03276289538330129, 0.05512487548854082, 0.07337063836354403, 0.024941716072780472, 0.11919133004642303, 0.24351246144262054, 0.15458266160661174, 0.14983008195075298, 0.293788222535964, 0.36723895539199153, 0.8060599406880717, 11.1999269646983, 96.58242702484132, 67.1492358176939, 62.87206765144103, 36.04006290435791, 40.848261156389796, 65.52190326875257, 67.03777774687737, 75.5431079864502, 92.18108054130309, 34.042674341509425, 0.6940517574548722, 1.0781380894684023, 1.2738253825133847, 39.40703722738451, 70.0521113795619, 76.6656118823636, 74.97048900973412, 76.73772073561146, 75.4504616029801, 74.92031405048986, 72.38781221451299, 73.23198472299885, 71.02234886538598, 69.85282359584686, 62.967973524524325, 60.12109764160649, 54.788690305525265, 56.68405017545147, 51.57896380270682, 50.4182638660554, 55.06564494102232, 54.147021924295736, 53.14692735671998, 54.58959864031885, 53.78511659560665, 49.89677690690564, 50.3155997491652, 51.11259006684827, 49.57291856888802, 51.034213266065045, 49.478616945205204, 48.02413932738766, 48.334779277924575, 53.27527123112833, 49.8540505286186, 49.981943330457135, 48.77712457410751, 51.23794509518532, 49.940534868548, 49.48204901910598, 45.89559455071726, 49.24355714551864, 52.19391692069269, 51.68695449829102, 46.65585971647694, 50.125337339216664, 50.479417539411976, 49.05874290773946, 45.18760673461422, 40.47863268083142, 44.310968768212106, 42.1715158800925, 41.515322962114894, 46.852284169966175, 49.63357410123272, 46.7932132751711, 44.40803958523659, 44.728073612336196, 45.52669171364077, 45.744869632105676, 43.079740693492276, 47.75473917684248, 48.386287843027425, 46.33834777339813, 43.36700331780219, 47.603523961959354, 48.372112397224676, 51.210849362034956, 48.18437991603729, 47.67474243717809, 51.05032244036275, 46.13021896731469, 47.447456775173066, 47.507947567970525, 45.45064480073991, 46.4904494439402, 45.576839216293834, 44.840982960116484, 45.52875488035141, 43.16859022263558, 45.578086530008626, 44.928075267422585, 46.43764649668048, 48.423369930636504, 43.30435129903978, 48.31932906181582, 48.45856535819269, 54.095442756529785, 50.41616147564304, 45.53918054026943, 44.30135503891976, 42.88894091883014, 40.80715471698392, 43.488361450933645, 46.973689371539706, 47.250506724080736, 50.30217347606536, 47.733507387099735, 48.01086210435437, 49.15408003714777, 47.98222487972629, 47.58058986356182, 45.08640958416847, 45.18808134140507, 47.05565906340077, 50.95682098019508, 48.951615133593165, 47.95665102620279, 48.31715606874036, 51.89173360024729, 50.47762893861341, 48.60893726348878, 58.06612476225823, 67.18836538253292, 63.829106361635276, 67.90368018611785, 65.66246532624768, 66.38167504341372, 64.61307441034626, 68.99189472198486, 66.46971656430152, 66.57858587080433, 67.46240569699195, 66.86740567607265, 62.25444732173797, 62.88475651894847, 61.36811717864006, 68.4994254573699, 63.14747295072002, 67.01345120706867, 67.6407088002851, 67.68230945833268, 63.35560567917363, 76.59086719635995, 72.65025800274265, 92.30432141211726, 37.43286909595613, 1.577804903349569, 6.280813890118753, 0.17568380271475162, 0.2721547882162756, 23.18514773922582, 89.9828274019303, 73.89408865282613, 83.11190958945983, 65.66342238456973, 76.99487916884884, 29.465937114530995, 35.722637253422896, 60.71890607956917, 85.75555570663946, 43.182165545801965, 0.2845087527267395, 0.17470468106048723, 0.1496765119654517, 0.17455909371135697, 0.19444819179273423, 0.12267267872248927], [0.01503912375248488, 0.10603694155091241, 0.02134955852412649, 0.025251931886398987, 0.09421961397052774, 0.1734323928793592, 0.3805169138696886, 11.327767795132054, 71.89861420662173, 53.95534746108517, 46.90241990550872, 17.004284666430568, 26.964068989599905, 36.38356839456866, 53.948593139648445, 65.32505912165489, 72.04019608036165, 15.193933344656422, 0.5398000764750666, 0.41949626418852043, 0.5606079438040333, 39.995314305828465, 67.8645820002402, 66.83594042255034, 69.77743564113494, 71.5148259747413, 70.77504342602145, 72.24857591813611, 67.92595924869661, 67.4651356666319, 66.21672368818714, 63.21647528679141, 59.40472379807503, 58.09362057716616, 49.113016743813795, 46.96991997380411, 45.54087500418387, 45.50225142509707, 47.03212091999669, 46.6308153829267, 45.56180084905317, 46.45212788735667, 44.516222476959236, 44.66089910076511, 45.161852452062796, 44.93366464491814, 43.046510373392415, 45.45044868223129, 45.340834125395745, 46.52662546403947, 47.52336248274773, 46.37114271040886, 43.198137437143636, 46.71426380834272, 44.70388435548352, 47.476125378762525, 42.675846392108554, 43.07949750654159, 43.71615702106107, 45.46294143123012, 44.644770314616544, 44.87388380112187, 44.56998248254099, 47.47374057769776, 47.26445859478366, 46.179519238010535, 43.01965782719274, 42.91822925690682, 42.77552558529762, 42.790305076106904, 41.283075501841886, 42.30740639471239, 44.04593029329854, 44.977453985521876, 39.49780479554207, 38.7367041649357, 41.26081605111399, 36.618145742724025, 40.18494913654943, 40.17569234294277, 41.67143721734324, 41.41818546479748, 39.186662781623106, 40.25003694718884, 40.598633673883256, 42.52556862369661, 43.65008861787858, 44.2725726865953, 42.14358468209544, 39.7957480338312, 42.51946149333831, 42.49969274766984, 41.34917136161558, 41.12464704821187, 40.5015314778974, 39.763439470721835, 39.33563440076767, 39.971140738456484, 39.81916458375993, 41.60431761895457, 38.720296890504905, 40.44009931625859, 40.429606976047644, 41.421115475316206, 45.85928124766196, 45.88702024952058, 41.50547781298238, 40.55844506909771, 43.09934077724334, 45.66139767246862, 42.17722292869322, 41.81532544474448, 41.419766179976925, 41.91104696642968, 44.22919127248949, 45.454398508994814, 42.94775685956402, 44.722052774121686, 42.85101552163401, 42.47315791345412, 42.77401939515145, 42.5566416402017, 42.691269151626095, 46.1470067116522, 43.91068304738691, 46.96435805289976, 45.096780330904075, 46.475289483224195, 43.17124174487206, 44.84737250112718, 46.93679948006907, 50.70217286386798, 54.64317037213234, 54.20716362614786, 58.32986885501493, 56.01221484522666, 53.675431436108006, 54.798229509784335, 53.326728805418945, 52.376134549417806, 50.96828999057893, 50.921770680335264, 48.80737389287641, 49.36649991619972, 50.417338186694735, 49.48056636318084, 52.62745257346861, 52.82901533188359, 52.713799630441976, 55.942514327264604, 54.673109823657626, 63.477450186206454, 68.09882594693092, 75.62263796406408, 53.72355891812233, 0.3523905473130365, 1.793295140227964, 0.20498332567512992, 0.27466501319600695, 11.465564581655688, 70.7481751903411, 61.303111737774266, 68.09418970538725, 48.881957761703006, 72.25460852346113, 31.08338332945301, 44.71183107745263, 40.9090853506519, 70.27233677525675, 35.101486790564756, 0.4896661489000244, 0.09188500698655845, 0.045428849200928406, 0.01996244142402805, 0.033416410517548366, 0.01329688372225651, 0.05289505401085462, 0.057287897929669394, 0.05340766642362841, 0.028195592176709926, 0.14452866158418118, 0.16502090068834444, 0.3721570253612534, 14.887983568253057, 84.91965939921718, 57.69205224129462, 54.554395368022305, 19.789922545033118, 29.164897164990826, 44.04741294922368, 61.77873834486931, 71.36990224161457, 80.35726039640366, 15.942920715578142, 0.5505815076251184, 0.24113438662982759, 0.5194434655770179, 45.50468721697408, 69.31832221246535, 71.23391366774037, 69.66399285101122, 74.00944555959394, 73.82995005576842, 73.56085977246686, 70.14962150204566, 70.24619025568809, 70.49849279465215, 65.2460547416441, 61.80158222875288, 60.31320748790618, 52.304986676862164, 48.793339652399865, 47.51882822282853, 48.093314247746626, 47.41992565893358, 50.12522751285184, 49.42036974814631, 49.105654455000355, 47.98637866973878, 48.888649325216974, 46.46083554913921, 47.971552110487416, 47.33971711127989, 49.22123885923817, 46.57453329332414, 48.62073967533727, 49.08189665886664, 49.51866434466455, 46.91261806795674, 47.950728247242594, 45.82013207097208, 48.71320562977945, 44.94152507474346, 44.68110715189288, 46.943565568616314, 47.12914074620893, 48.16248132336525, 46.734369877846014, 48.3269972955027, 47.89878822142079, 50.69331615201889, 49.787401614650605, 43.72134239442887, 44.0142414646764, 42.15545769660704, 44.318385970207956, 40.99633063039472, 42.762652366392075, 44.98700495689146, 47.9238639339324, 42.51322492476433, 42.46978467510593, 43.11574412930397, 39.79154325300648, 41.53294224892893, 42.20380090898083, 43.65904338898198, 43.37679747612246, 41.8739099656382, 42.29934592400828, 43.24908118094168, 44.12203996412216, 44.40346610161566, 47.76929901492211, 44.305159737986905, 44.948000907897956, 44.515265418637185, 44.68661023724464, 44.85568008115215, 41.87246261104461, 42.707507764139486, 42.19178276677286, 40.70832667812225, 42.49182839547434, 42.37096840335477, 43.225809758709325, 42.68191429876512, 45.848592788942405, 42.141698022042554, 44.40954577538275, 47.798689334623276, 46.83562586384435, 41.66991926008656, 40.729279979582756, 42.942551874345355, 45.168610695869695, 42.59401790557369, 42.30060892720377, 41.677893438646876, 43.722695612138324, 45.57249715251308, 45.821814767776004, 44.1173448870259, 45.96935472180767, 42.33688300655734, 44.4778303177126, 44.480744638750636, 44.91855959738455, 45.009299708950905, 49.223066683738466, 45.561490981809555, 47.02190706806798, 46.08791228263609, 47.24377985923521, 45.10817873862482, 47.22226565884006, 48.75104081246161, 52.91173419644756, 56.20333233187276, 56.24507811761672, 57.88931608200074, 57.567403239588586, 56.80327846157936, 55.70119442478303, 53.80677984606836, 53.79381641264885, 54.36965173290622, 53.19641982355426, 52.162875283148985, 51.751744208797334, 52.2575887556999, 51.587275305101954, 55.63176455036287, 54.90423940843152, 56.626006941641535, 57.14151228627851, 56.10685771511447, 67.71077802104335, 70.96480769495811, 81.16280540343254, 58.36290697897635, 0.5281358668881079, 2.2284007216653516, 0.16147636508028354, 0.24129806897572934, 11.274270588351834, 80.10251814319243, 67.44864602242747, 76.94476696752733, 53.46231729753556, 73.35906951658188, 33.39224730768512, 49.27408103019961, 48.05693426439839, 76.87347396727532, 45.48376921684512, 0.29468644530542437, 0.13688308877810357, 0.06595787967765523, 0.07666362900166743, 0.015088291275465201, 0.03196595326787041, 0.13404747561341332, 0.16654293353278793, 0.10774920168783396, 0.1098801441971333, 0.30179289139566884, 0.2690032557133706, 0.627907726072496, 20.594683078027543, 95.16315660169049, 67.93270572539299, 64.89047619604295, 27.879195213317875, 36.47144517590923, 48.32857801068214, 73.12750847108903, 74.17430277793639, 89.85637018757483, 17.90600815126973, 0.536174274259998, 0.6122868255742135, 0.8720453612266049, 47.19605245897847, 66.97163874103178, 71.4110714389432, 73.84740460303523, 77.68554579827094, 77.25383404762515, 77.33130870326873, 71.38580353029313, 73.1417231405935, 74.22903553132089, 69.51405632880427, 65.63180808098086, 65.5990170663403, 55.50817458860336, 52.24457040909798, 51.01501718644173, 52.914954462359034, 52.5480834130318, 52.889706165559836, 52.974268544104795, 53.13739207483108, 48.905617498582416, 50.802338430958415, 49.08289294089041, 50.451282378165956, 49.17231905844904, 51.398573998482, 48.34142769536665, 51.014158187373994, 51.68402056540213, 52.787877513516335, 47.45538388529132, 50.97526004237514, 50.032734101818455, 52.00867122219455, 46.98857084397347, 46.682096450559555, 49.51071762269544, 51.87975860411122, 50.18734216690064, 49.751476626242365, 48.796995301400464, 51.20975502075688, 53.07748571518929, 52.58564010743172, 45.39466473364061, 43.554433776486306, 43.55021722855107, 44.526424561777425, 42.02818070688556, 43.21191280118881, 45.094823068188084, 49.74612259095716, 44.366325178454005, 45.36785141114266, 46.200590210576216, 42.034123097696614, 44.48706357709823, 45.38321141273745, 47.529873617233775, 46.10053446985061, 44.30146094291441, 45.71752678963446, 46.56680622408467, 47.2976928372537, 47.81746964300833, 51.57253503799439, 46.64592827520063, 46.276680269548976, 48.97227033492058, 48.13843327183878, 47.23533891862439, 44.60511515217443, 47.26946746149371, 45.97898021821053, 44.38778054329657, 44.684503924462106, 44.15165385892315, 46.258515773280976, 43.29880506761613, 47.527508428019864, 46.335319703625096, 48.90003204345704, 49.81733714380572, 47.8075421241022, 41.995472062018614, 41.22050977522328, 43.101705966457246, 46.647901227397305, 43.0297657751268, 42.513162166841575, 43.6447581168144, 43.6735914599511, 48.81805450685563, 49.22106235258041, 46.63679699743948, 48.27905808725665, 44.4228151536757, 47.04185232039421, 46.295562559558505, 47.93965147387597, 47.600833216021144, 51.68165145381805, 47.35248442619078, 49.470627077164195, 47.83564982875701, 50.3599617558141, 46.6270459851911, 50.50094742928782, 50.50192409946073, 54.761108198473536, 59.258403701166955, 59.639638470065215, 61.87738595470306, 61.12718166843538, 60.23363436422041, 58.82378547422348, 57.16790591516803, 57.69181297671411, 54.54420505031463, 55.38376092910767, 53.56416163905975, 56.034023223384736, 56.071481858530355, 53.61664687433551, 58.942790185251546, 57.10873303874847, 60.01236169568954, 60.533629002109656, 60.16778561376757, 70.32700677071848, 76.71906594307193, 83.58864230494346, 61.45902595212383, 0.48422680206356516, 6.928034876623462, 0.4634546344318698, 0.2465221297837073, 13.871064974415688, 86.51407149530228, 74.97347001106509, 84.11828779405164, 64.37330776645292, 84.81985076781243, 46.44338492424258, 61.8384172070411, 58.594554316612985, 89.06182350650911, 58.61978692393149, 0.7752822051125189, 0.2189369124150084, 0.19187942237382938, 0.1767461061958344, 0.14548951970233073, 0.13563608149847678], [0.04644950431200766, 0.04742466912214314, 0.009474333848864322, 0.08191740636022822, 0.07517610841821279, 0.16666834212599263, 0.3652738479356612, 13.058760742987356, 68.52411285523446, 52.27540808339273, 48.12453239194809, 36.05943941300915, 46.91501463613203, 37.467837026042325, 58.0800138750384, 64.92760142972394, 69.64093715913835, 10.348626529016803, 0.6095203901490858, 0.3327607699940282, 1.3235219351706968, 35.68277028299148, 70.9587594001524, 66.3784900788338, 67.4721331750193, 69.29012821566674, 69.26453867266255, 68.22769934131254, 67.74992327536306, 68.81723942295199, 64.84548661016649, 63.41128372376966, 58.97023108697707, 54.3250112379751, 50.54062612595097, 47.61122357460761, 46.767313864923295, 44.70346466187508, 43.86458343075168, 44.197514210977864, 44.25796185770343, 43.76032683157152, 46.16437104440505, 44.75449469781692, 42.9739426028344, 44.53885847522367, 45.903556962167066, 43.92367001502745, 43.752223214795514, 43.70956351680141, 43.41076127944454, 44.69492173963978, 43.886768356446304, 44.87456629353185, 46.14480233961537, 45.65436094037948, 44.60672724631525, 43.63616420376686, 43.841449291475364, 43.13570899348105, 44.047275666267645, 43.759687485233435, 43.86647793554491, 45.03565803650887, 48.178194338275546, 45.83596667935772, 45.08800206645843, 42.82098585559476, 43.986031778397106, 45.4174772385628, 41.74196927778183, 42.99354660895563, 41.02876078697943, 41.80662955007246, 44.627974725538685, 40.41025007924726, 37.91693664366199, 39.749899448887, 39.62689784265334, 39.90370342808385, 39.24598470810921, 39.667364935721125, 41.24427541609734, 39.52460635092951, 42.25661562335107, 43.389149019795084, 43.12953126045966, 40.93737740670481, 42.49791199161161, 37.72540338577763, 43.20886119719475, 39.982029238054835, 38.810362354401626, 41.36109536693942, 40.25841120750674, 40.96439469245173, 40.16330157556842, 40.4386245050738, 40.24525165557861, 39.39010827772079, 40.060351125655636, 40.793959863724254, 39.783463170451505, 43.25526675870342, 45.44744806904947, 41.46213954494846, 42.267543346651145, 41.44341414974582, 43.15484231518161, 40.79281060926376, 42.55285263061524, 43.23556861569805, 42.75331712538197, 42.769230181171054, 46.83550427036901, 44.29316905237014, 43.06027789269724, 44.405513578845614, 43.24044019945207, 40.53785262569305, 42.29053235823109, 42.717384292233376, 43.727245561538204, 45.52070225438764, 43.68740212532782, 44.78694054388231, 44.9132957766133, 44.10747620367235, 45.4049531106026, 45.14784566817745, 43.65927088645197, 45.05835287032589, 45.616776789388354, 47.94817478426042, 48.57661693326889, 46.85221748967325, 47.96471541927707, 46.64461820356308, 46.8324448216346, 46.37308820601433, 47.09605947617562, 45.50683667582851, 48.19537039726011, 48.928300565288914, 48.77349638169812, 49.380722430444536, 51.25597230849728, 51.56078361695813, 53.96800102726106, 54.335036816135535, 54.271482652233495, 61.72680224141767, 68.71237093402495, 73.2178798798592, 71.28311587918189, 2.5786338121660295, 2.1357592411579627, 0.2893940647763591, 0.18753188872529616, 4.917947640342097, 72.46779718706685, 58.66191317958217, 64.00730748330393, 55.334574407146825, 62.674882258138354, 20.961514903653054, 22.655363005976525, 39.13425599375079, 65.45996904373169, 51.42203369448262, 1.3104370308499182, 0.15913527699247484, 0.06965596228837967, 0.03675569967937566, 0.037101845016642925, 0.07060637096724204, 0.12736603212092193, 0.04895859931205069, 0.04207242265223496, 0.0083455492577125, 0.08476015946437275, 0.20216242139858587, 0.4913288354873658, 19.184406649681833, 80.37680948934248, 60.10831071484474, 55.7233440491461, 40.80087107996787, 34.50452558455929, 35.88595298028762, 69.32347620687177, 68.55089479877104, 79.36673641204834, 10.986869700493353, 0.4116095728691547, 0.082396762896209, 0.787909601724917, 43.88199090957642, 74.50074595789756, 67.6433995462233, 69.33994231685516, 71.31034497291812, 72.6856299369566, 70.64465599675333, 69.9142949811874, 70.26075793850806, 68.10658439513176, 65.21901784404632, 61.183271561899495, 56.47636459719751, 53.55750537687733, 50.28349907167497, 49.32363625495665, 47.75062068816155, 46.358563669266246, 46.75723337358045, 47.488068995937226, 47.721030327581595, 48.43234431359076, 46.979721976864724, 46.142668570241625, 47.329542483052904, 48.31171966368153, 44.733831651749156, 47.174008738610056, 46.377124324921645, 46.16008389380671, 45.61268575729863, 44.73272554336056, 46.63580856015606, 47.28667489943966, 47.933544343517674, 45.899815021022675, 46.94430689657889, 47.46313448875181, 46.99485840335969, 46.14580254400931, 45.67554173930999, 44.72480235561248, 44.94304695437032, 49.83477600159184, 47.17456571517452, 46.54538223820348, 43.97966184923726, 43.32517123991444, 45.63905192959694, 42.79207406505462, 42.81085437343967, 41.023069427859404, 41.4192601942247, 46.102503499677105, 42.785049100076, 41.12931466871693, 42.458680445148104, 41.351144313812256, 41.50984733335434, 41.30584486069218, 42.018841543505275, 44.192089573029556, 42.28970081575456, 44.703617634311804, 45.931119457367934, 46.109920701672955, 42.13139787797005, 44.93153479791457, 41.24889204579015, 45.374346856148016, 43.59864281069848, 41.37356850408739, 43.72500981053999, 41.84835964633573, 43.78888560879616, 42.137599145212484, 42.502822799067346, 42.238772761437204, 42.099175607004476, 39.95399605843329, 43.09713248283633, 44.04853474709296, 46.19872708474436, 44.60278918666225, 40.48395925952543, 41.650107368346184, 41.00507359350882, 43.11138245367235, 40.09056122072282, 44.47890112476964, 43.305747662821126, 43.64891190682688, 44.34706241853776, 47.34941321034586, 46.056541165997906, 46.04587624149938, 46.20760733081449, 45.84332896817116, 42.77334082511164, 44.97601055329846, 45.30723902486986, 46.15371004227669, 47.45153604015228, 45.678499206419914, 47.693036371661776, 47.20972191902899, 45.93460252208095, 48.19407209273308, 46.85278623334823, 46.661041167474565, 47.07295279349051, 47.77726927111226, 47.75673174089002, 49.963272848436915, 47.655817001096665, 50.54842772022371, 49.36481329702562, 50.03791163044591, 48.82948429353776, 50.50846661290815, 47.68506219310146, 51.924654053103545, 51.41436546079574, 52.532076220358576, 51.7748155901509, 54.05108467225106, 55.72651724661551, 56.58357866348759, 57.77988195419312, 56.905675857297844, 64.35062862211659, 72.37880645259735, 76.77807407994425, 71.73444732542961, 3.2440933296757364, 1.646788608162634, 0.06606330103691548, 0.2942529008273156, 5.520562452654685, 76.59666445947464, 65.80398444206484, 70.40998058934366, 62.28511241174514, 65.27802598091864, 27.082120564676103, 35.116944851413855, 47.394951928046446, 73.05084966844129, 60.82031896037441, 1.7555764029102943, 0.10132100388047197, 0.11135641094898024, 0.014642624413564563, 0.01921387776101549, 0.022913318262585712, 0.2669587815480848, 0.18346052977346605, 0.09225592377685732, 0.18869618915261763, 0.1594893321875603, 0.33447987129611356, 0.751218525392394, 27.388763620007424, 91.9017920955535, 67.79761929665843, 67.43439997396162, 48.69559418770575, 65.61826805914602, 52.837224852654245, 76.04989390219413, 74.62214331473075, 87.88954473310902, 13.303009675395105, 0.6833555765690342, 0.5838368941218622, 1.7346834078911813, 43.47737881445116, 71.50181155050956, 71.65918488656321, 71.32816037824078, 74.41974116909888, 74.44780180531164, 73.62124073889949, 72.15121484571888, 73.30573312697872, 70.20804912813249, 69.75137541371008, 66.09830733268493, 59.73433625313544, 55.67456153131301, 53.45284477356942, 52.78728915799049, 51.49614687888853, 47.2471256409922, 51.258776803170484, 49.33492875868275, 50.4819788471345, 51.09521396698491, 49.35500737159483, 49.109110063122166, 51.659493984714636, 51.44472852829964, 47.64722701041929, 50.08950648769256, 48.09332209248697, 48.27754012999996, 49.17221707682456, 46.32379185768866, 48.3266285927065, 51.553758651979514, 49.04230425434728, 48.57017640144595, 48.13322044187977, 47.8215685198384, 47.98566087599724, 46.43072351332634, 48.61067487347511, 47.6501021077556, 47.18869409253521, 52.068150043487556, 47.99621597413094, 47.088932529572524, 44.062572909939675, 43.910373180143296, 47.035039163404896, 43.34362599157518, 43.49443720233056, 40.53682888707807, 43.24155807495118, 49.17998729213592, 45.484400718442856, 41.874117851257324, 44.91168760484265, 44.456351418649, 44.36493273704283, 44.64461341980965, 45.38557267958119, 46.70983937478835, 44.90662382495019, 46.00030222246724, 49.45373342883203, 48.17535846464096, 46.384921996824204, 49.01230596726941, 43.79494567071238, 48.67938695415374, 46.60374710636754, 43.97703778359198, 49.552298668892156, 44.23047780990601, 46.59318808586367, 45.572363791927216, 45.161409224233324, 45.57265796969014, 44.59005717308291, 43.236968901849565, 45.56515055318033, 45.99413233418619, 46.70272811766594, 45.89268807441958, 40.5398295002599, 43.74884213170698, 41.036315271931315, 45.23711489092919, 41.687973929989724, 43.59945866369432, 43.74368813730056, 44.595972107302764, 45.931798027407744, 49.711986203347486, 47.14857609041276, 47.4722461546621, 49.14850634913291, 48.61083961302235, 45.028468331983014, 47.73148344409081, 47.507861275826734, 49.32967670502202, 50.0247089324459, 48.48660246018441, 49.73610485753706, 50.473067222103, 49.04878793224212, 50.534742570692494, 49.2350338351342, 50.00210039077267, 51.134727924100815, 50.210978369559015, 51.50123027063186, 53.774428136887096, 50.90200585703696, 54.84816128207792, 51.09999925859513, 55.25319699318179, 52.42149676046064, 53.67214841227378, 51.312634868006555, 55.059733929172644, 53.88943595270957, 55.29696672193466, 55.68517154262912, 57.87380310796923, 59.569200546510764, 60.643843681581565, 60.11947378035515, 58.90801837367397, 66.16133982135405, 75.17567603818833, 78.77130493041008, 76.36841389440721, 3.4720014227974803, 5.252536112262357, 1.7792247404013912, 0.3503804551737924, 6.8007309206070445, 85.10856859145626, 73.61363918550553, 78.03830808208835, 72.51830947014594, 75.13632682061966, 35.556497420034106, 38.96386431109521, 57.94820654776789, 83.77623358080464, 75.58076274010443, 3.9310891109128154, 0.47369551394254933, 0.24662634838492642, 0.312384485958084, 0.098885158377309, 0.14440264012063705], [0.030276836647141366, 0.07362894022897368, 0.04523789795536188, 0.04204896120955387, 0.06486074217865545, 0.10444534026206502, 0.2620913040253424, 20.14371248983568, 72.3016534313079, 49.0118117486277, 49.58447779378584, 19.43882138498368, 44.829863040677964, 52.49373505192419, 59.759749289481874, 66.89152040789205, 66.76939349020681, 9.511710405349731, 0.3668474844626842, 0.1366766893695439, 1.836252080336694, 36.85183271285027, 63.240103644709436, 73.33957533682548, 66.86670749418198, 72.84804744105186, 69.61543390827795, 74.43437945458197, 62.94509041693903, 67.5915301230646, 60.262283355959006, 62.27553398378434, 56.790220891275716, 53.997999314338934, 50.05458170367826, 47.8118488865514, 43.701565804020056, 47.41110032604587, 43.434985837628766, 43.708324047826956, 44.03149989343459, 45.21272951556791, 43.526588870633034, 44.74315120327858, 43.153257677632, 44.60228712328019, 42.94776470430436, 45.05734089882144, 45.82356022250268, 47.12202948908652, 48.494804136214725, 46.360509164871715, 42.443897031968646, 45.27895481355729, 44.236306451982074, 44.38380325994184, 45.7419906123992, 44.25838547368204, 42.00054760902159, 45.61091676835091, 44.562828079346694, 42.92055914478917, 42.24431899286086, 44.8728875190981, 51.284229063218646, 47.24993013566541, 44.70080137252808, 44.68388811234505, 42.89480093986758, 45.579514272751354, 41.7023298048204, 43.800515436357074, 47.17649159892913, 41.98631332766625, 41.02783510761876, 43.444972192087484, 39.239701071093165, 39.367495813677394, 37.6347299545042, 40.122093154538064, 39.382561637509255, 42.52123048228603, 39.48367249581122, 42.378471897494414, 41.16062694980253, 42.19262999873008, 42.697435117536976, 40.420460008805804, 40.39465081307196, 42.49553503528718, 42.19235935518819, 41.089604593092396, 40.321090682860344, 38.976757141851614, 39.98803438678865, 41.058923813604544, 40.74232578277588, 39.933968436333444, 38.226337125224454, 40.10091235560756, 38.05118368517968, 43.350764705288796, 45.25065099039386, 43.39746444456039, 42.285821591654134, 40.997876044242616, 40.43960509761688, 45.7807553968122, 45.57445833759923, 42.526156979222456, 43.41859425267866, 40.17968139340801, 41.420374147353634, 42.90267705917359, 45.33107526840703, 42.537912322628884, 41.84866951357934, 44.06117262378816, 43.94700027281239, 41.52550543508222, 43.32533597946168, 41.1813449090527, 43.774270857534106, 44.741476351215, 44.65199532047395, 44.839661121368415, 43.0804741767145, 44.320386378995835, 44.033315950824374, 43.50083066571144, 44.59560340450656, 43.88382265644689, 45.81666469573975, 43.8802650667006, 44.71312938197967, 45.96332996122299, 45.47378678475657, 46.17197652016917, 46.28840423399403, 45.130673531563055, 47.96551558279222, 48.771299854401626, 46.6270459851911, 47.52197396370673, 50.626145562817975, 51.0080079109438, 55.34697301926152, 56.660539488638605, 60.46471688055224, 58.272668930792044, 60.349556092293035, 62.05368472683815, 71.33270248290032, 70.29509436699652, 73.72024136204874, 4.936004761726626, 1.0452571054620128, 0.2850452287783546, 0.07734764592661973, 1.3147931906484789, 61.786555628622736, 65.29638267332508, 60.47942184632825, 58.81170849646292, 50.885986897253225, 20.32361395897404, 17.318264515169208, 42.53643358907392, 57.80218847336308, 63.74321822197207, 2.7043487179663876, 0.2403531914516803, 0.04778897074321586, 0.07595620042974911, 0.029507862486606164, 0.0458701771323479, 0.02914511985445936, 0.11628686089909847, 0.14636840641258225, 0.0406832447756202, 0.045587812445216605, 0.18040177051819142, 0.2434083654154693, 25.27337447289498, 84.48632378732005, 55.379281582370886, 60.042375672248106, 27.193327603801606, 36.56153025165681, 53.35551900248374, 68.31079867578322, 71.1344031364687, 75.27022084882184, 9.914290712725732, 0.4113671826499124, 0.10940543015397365, 1.9934498903251465, 41.74870790973787, 68.5634385385821, 73.64274317218413, 67.35321475613502, 73.02057681545135, 70.6183918060795, 75.08591651916504, 65.59145473664807, 70.47747673526888, 62.134583611642164, 63.9182226119503, 58.320074696694654, 56.77069141018776, 52.55716762235088, 50.013016346962225, 47.509983278089955, 49.45967581964309, 47.70301880375032, 47.50321326717254, 46.2454346687563, 46.735703483704604, 45.26691313712828, 46.48389908575243, 45.64844600615963, 46.60463356202649, 44.85196951896914, 47.35685002419257, 47.48373477689682, 49.11937490586312, 50.41070153636318, 51.05757098044119, 43.891369296658425, 49.29637185988888, 47.235178101447325, 46.17843666384297, 46.89393189645583, 45.995411026862364, 44.53941545178814, 46.78751799368089, 48.28254507433984, 46.987209781523674, 44.75625191965411, 47.09733816885179, 50.77923567064347, 49.753669231168686, 45.37753182072794, 44.719287503150206, 42.53104033008699, 46.5478729432629, 43.05065631866456, 42.17538333708241, 46.2880825996399, 41.31255211368684, 43.6661664132149, 45.98037658199188, 42.95599383692588, 43.18877081717215, 40.64091290197065, 43.48785546518142, 41.68792686154766, 44.82569356118479, 42.885022471027995, 45.5168269526574, 43.07845023370559, 44.559278334340746, 44.236784981143096, 42.76957927211639, 40.78877841272662, 43.776996904803866, 44.28799936848302, 44.96976613998414, 41.85891082209926, 41.73008449615971, 42.51449577270016, 41.11018919175671, 43.85528741344329, 42.01558597626225, 41.66067815596058, 44.36287349270236, 41.51270674120995, 46.521393022229596, 48.11209455613167, 43.201651880818034, 42.517300267373365, 42.28159719897855, 40.36006335289248, 46.127692960923724, 45.52831949726228, 42.3586953070856, 43.61134736768661, 39.68663161800754, 41.84930493754726, 43.393373412470666, 46.724701235371256, 44.17327396331295, 43.104294730770974, 46.144735659322436, 47.13889568082748, 44.120992691286155, 45.15949510758923, 44.35859810921454, 47.28780846441946, 48.63400120888987, 46.421105861663825, 46.534399601721, 45.69586746154293, 46.579475479741255, 46.08571967770977, 44.458751909194454, 46.715146341631495, 46.871856797126036, 48.041844906345496, 45.109045582432906, 46.61243123392905, 47.95546647041075, 46.72761555640928, 47.97392906681184, 51.05667275767173, 48.22222686582997, 50.006811157349624, 50.567031521951, 49.564689436266505, 51.63661872186969, 54.830039931881814, 53.69877346100346, 58.575938747775176, 57.61887650335989, 63.930334891042406, 61.252960312751036, 63.78546999346826, 65.57611434690415, 73.44418494932114, 72.67326662617346, 77.9024685582807, 5.674089904754393, 0.8528223153083556, 1.2153311987077038, 0.0818012674309073, 1.5565948092168378, 67.32460498809814, 72.71883672283542, 67.84627237627583, 62.49883844006447, 60.56340763645788, 27.067872555025165, 20.8220491486211, 49.20043068547403, 64.88883272294076, 76.31083350027762, 5.274602386259264, 0.3815981397225011, 0.1102498122641156, 0.033250475873149214, 0.06853399587975395, 0.06618647265338129, 0.163933775958515, 0.17246555927540028, 0.38406469769054846, 0.2711926124268963, 0.3427783195530215, 0.22032831194660357, 0.478449824957117, 33.30713187494586, 96.1924022243869, 61.916401770807084, 68.81989878992881, 30.098282021860925, 62.68566877611222, 69.43668365478516, 73.3172413610643, 77.8309480605587, 82.82485485076904, 10.708769732905973, 0.6028043118215377, 1.1355813232160386, 2.4248197818956068, 44.44325854701381, 68.50201422168364, 76.44741827441801, 70.60187862765405, 74.60702650008663, 73.93120996413693, 78.56107373391428, 67.31499518117597, 73.12561004392563, 63.351063574514086, 66.6085841578822, 62.39427589601087, 59.488866483011556, 56.59016040063674, 53.41345240992885, 49.4116424745129, 52.962717163947325, 49.77303397270941, 50.38400588497039, 48.19719037702007, 49.05490682971094, 48.586265963892785, 49.32449917639456, 46.68069224203787, 48.71553944003198, 46.77215406971593, 50.030333611273, 50.022284907679406, 52.333129682848536, 53.992398169732866, 52.50370179453204, 46.36403145328645, 51.180274486541755, 50.40181736792288, 47.77525317284369, 50.235367667290475, 49.04321424422726, 47.76566297777238, 50.453278864583666, 50.320479177659564, 49.84507614566434, 48.183262040538175, 47.36128230248728, 54.02962930740849, 51.37713040074995, 47.484578086483864, 46.18471637848885, 43.17351671957201, 47.66809009736585, 41.816560991348766, 44.29357697886806, 47.975796115013864, 43.23949883061071, 44.686876958416356, 48.76462005799817, 47.09931896578881, 44.70969338570872, 42.259490720687374, 45.15405085779006, 44.21540806370397, 48.17122036410917, 46.24107691549486, 48.226867029743815, 46.13100736371933, 45.95679137014574, 47.14506949147871, 46.021173154154134, 46.84009736584079, 48.89050852867865, 48.61317342327487, 47.08997195766818, 45.44427879395024, 45.069202146222516, 45.596682486995576, 44.23416091549782, 47.24407011462797, 44.39601359828826, 43.95548043712493, 47.289306809825284, 43.76647318563154, 49.858067035675056, 50.13741431697723, 43.53644970924624, 44.25212537088702, 41.44741104495141, 41.428768019522394, 47.500867689809496, 47.30740070343018, 41.525983964243245, 42.41972346459666, 39.353143861216886, 43.20929265791371, 45.48308280206496, 49.351944000490256, 47.09740484914472, 46.13376478995047, 48.55808373420469, 50.439393674173665, 46.98567221241613, 47.398682102080315, 47.006727495501124, 50.55566057082146, 50.82301324413669, 49.319607980789684, 49.50465756077921, 46.454214588288345, 48.15327944294099, 49.250789996116396, 48.0803821932885, 49.75212773969097, 50.227597451979115, 52.20952010923817, 49.60514868459394, 51.832109651257916, 52.03278595401395, 48.70985200328212, 52.04105038796702, 53.07448902437764, 50.07135768090525, 54.977046443570046, 55.03340698057606, 52.4591907378166, 55.03366193463726, 58.064022371845866, 54.96422029310658, 61.716670759262584, 60.79171703707788, 66.98886579082858, 64.26309700935118, 67.23356677639869, 69.23563080449259, 76.62035557531541, 76.45492569092782, 79.6329398309031, 6.866841489268888, 2.641489794177394, 2.1926318926195947, 0.18687273135348675, 2.2691764562360706, 74.66798797730478, 79.57166456407117, 75.70299163941415, 72.59163425814721, 65.96466433617377, 34.60803301103654, 29.006978619483213, 62.400771341016224, 73.53402291574787, 87.82150730010002, 7.847065819847969, 0.7481873912676689, 0.3752763515278217, 0.16658994068782176, 0.1807460197878461, 0.14734797239784272], [0.015134698966698302, 0.05790018604227132, 0.057639601234827316, 0.020936346019528086, 0.059666796286980954, 0.05697941730519938, 0.23375214888684212, 28.40123130429176, 73.91725417106383, 57.468100593936065, 47.4025809380316, 31.095050419530562, 37.30745915443667, 42.11117021499142, 66.5003110516456, 61.13227290491904, 68.67333550607005, 7.983708448948399, 0.21830409314603577, 0.3718777709910947, 1.5814459660360891, 46.64739131927491, 56.870786374615086, 71.76950547002977, 67.60408955235636, 70.76266442575763, 67.59280881574078, 64.22669741415208, 62.85113396183137, 61.576716669144176, 59.191299792258974, 55.171482255381925, 50.70621682751564, 48.46040887217368, 46.14754407636581, 46.614313971611764, 42.70307548584477, 45.0996671953509, 42.79105817117999, 44.651273604362245, 43.75841271492743, 44.57129255417855, 44.21814980045442, 43.644056012553555, 44.3467447065538, 46.7967983215086, 52.566985314892186, 54.33966129056869, 56.86687184918312, 57.415348637488584, 56.05842036585654, 56.145485216571444, 49.92164081142795, 41.881758628353, 43.50985211710776, 41.864986573496175, 44.74359443110805, 44.85211072429534, 44.3911341697939, 42.79449416745094, 43.881504535675056, 43.91122433447069, 43.3739302235265, 42.43862144408688, 49.6290712202749, 48.76104285640102, 45.410181630042295, 43.33212952460013, 46.138232369576734, 43.428564917656686, 39.59147491762715, 47.074368769122714, 44.485777039681714, 43.815565570708245, 45.3914366229888, 46.082817123782256, 44.54779363447621, 41.949227317687004, 40.561732015302105, 41.26284783886325, 40.586603764564764, 39.412603070659024, 40.41152484955327, 40.07792334402762, 41.26122005524174, 42.893545781412435, 40.91198398220924, 39.471897540553925, 38.99363510070309, 40.921111337600216, 42.24853161842593, 42.09904224641862, 40.108306023382376, 40.26625987022154, 39.54257472868889, 41.18807177389822, 41.3501323423078, 40.699826901958836, 41.43710305613857, 39.18325031957319, 43.91482899265905, 44.26027213373492, 42.24751180218112, 45.38390567225795, 43.200031941936864, 45.53530523853917, 44.10498157624276, 44.56578946882679, 42.742432548153786, 40.78771545040993, 42.14776592869913, 40.53450292156589, 42.121870440821496, 42.61404160530337, 43.921014570420795, 42.44392841093002, 44.30768182200771, 42.05386438677388, 41.560477287538596, 40.708456116337935, 42.151609851467995, 42.94992200789913, 45.52103565585229, 45.4559164662515, 43.068154012003255, 44.22257031163862, 45.33374640249437, 42.135885069447184, 44.66195814071163, 43.61211222987021, 41.8897641858747, 41.7345206968246, 42.98258750669418, 43.97300558705484, 43.18049853847873, 44.03832873990459, 43.836883652594786, 42.17696797463202, 47.571184019888605, 44.603067674944484, 46.09281916772166, 43.78654395380328, 48.053721843227265, 51.18089422102898, 52.97134245595625, 53.44256424134778, 58.196880894322554, 59.10942031491188, 62.480120889602176, 62.47153482129497, 64.66633235254596, 65.06359000359812, 71.91255431021415, 70.98932250853508, 77.09348755498087, 6.797080174569161, 0.7389841012416348, 0.5975369976893549, 0.06714346968839247, 0.16274304549780585, 49.300066732591205, 71.8557740795997, 60.03478588596467, 55.91433601994669, 52.65742340395528, 22.85990676572246, 15.995656001952389, 41.31564294138263, 50.57475859119047, 64.09696109833257, 5.5980268120765695, 0.4035005321906459, 0.16203608423952134, 0.11703214953623473, 0.10701674502342941, 0.02155507118591378, 0.019838277723700292, 0.09542689193040134, 0.0664648843268233, 0.09189332670141613, 0.03296039668062041, 0.02905115150966712, 0.17734406846425227, 34.68637058811803, 83.54220144210323, 63.04569136711859, 53.04878181026828, 31.68539654824042, 39.75011910161665, 49.811053506789676, 73.81618253646359, 66.69897125613305, 77.30890412484446, 8.405812844153374, 0.37281460459193877, 0.040491025654538985, 1.7344539492361009, 48.86091424572853, 59.900534922076815, 74.10100152415615, 68.40805776657598, 71.980725103809, 71.66382112810689, 68.23488512346822, 64.5284257396575, 65.50210314412271, 61.30395896973149, 59.24384386308732, 52.597881824739524, 51.79272120998752, 48.47046190692533, 48.61069840769614, 47.18974136537122, 48.61107103286251, 46.829479509784335, 47.54913637715001, 46.566853292526744, 47.764297992952415, 45.757938969519834, 45.77260078922395, 45.47928594773816, 48.290836964884114, 53.28965456255021, 55.78579602702972, 58.593589413550596, 60.24062010549731, 59.12929888694518, 60.33073263783609, 52.17321072855304, 44.98152932813091, 44.6675592853177, 44.44456861865136, 45.5822560095018, 46.30807492040819, 46.723383318993356, 43.64823725915725, 46.05963199369369, 45.901136859770745, 44.23088573640393, 44.000724977062596, 51.07360170733545, 51.35862073590679, 44.38728240228469, 43.62921768619169, 46.951908449972834, 44.717271404881636, 40.64774567081083, 47.658935285383656, 45.10565273223385, 46.024205146297334, 45.4170379331035, 45.10455839095577, 47.08716746299498, 44.403591617461174, 43.30415125816099, 44.586648633403165, 43.64513466435094, 41.96598368306314, 43.53588096557125, 43.55490053853681, 43.21789049333142, 45.09022212797596, 45.166849551662324, 41.08799249895158, 41.3022715814652, 43.004831267941384, 45.27525209611463, 44.77577355600173, 41.71289667006462, 43.25978532914193, 41.403272613402336, 43.58291018393732, 43.71051273038311, 42.45927664541429, 44.26455928433327, 42.984607527332926, 46.42993903929188, 46.14310003096058, 41.47277701285578, 46.121707424040764, 42.84755206877186, 45.414641364928215, 44.734569057341545, 46.024946474259906, 42.81942475226618, 39.03811085608698, 42.86085282602618, 40.315650355431345, 42.65938420449534, 44.85641356437437, 46.41015460414272, 44.445808087625814, 46.562789717028224, 45.85484896936725, 44.9714292249372, 43.23202671543245, 45.115697922245154, 43.9242152244814, 46.63083499477756, 47.05897738856655, 44.195392208714644, 44.66826138957855, 46.432625862859915, 45.66679485382573, 46.17981733814363, 45.942086404369725, 45.73755833410448, 43.699498714939246, 45.03424990561701, 45.686979370732466, 45.74018632211993, 45.82479184673679, 46.71927659742294, 45.70401422439083, 49.30458530302971, 47.22974561875867, 49.6021363043016, 45.668403025596376, 51.858620951252604, 52.52752627095869, 55.03574471319876, 58.3475548221219, 61.51461378220589, 62.639988853085434, 64.41200587057298, 65.34062308649864, 68.13630811629757, 67.95974654536094, 76.55159642619472, 74.56766159303727, 81.60239327338435, 7.327856777175781, 1.039637207023559, 1.1286375022703603, 0.08803008319509607, 0.2543064717563891, 51.42495978263117, 80.85006698485344, 65.90633869171143, 64.77577040272375, 57.18381897095711, 31.901354405187796, 19.110269931054887, 48.26930707500827, 58.248220797508, 74.74310136610463, 7.767957497027613, 0.39373024517009336, 0.1024637695762419, 0.045270429879066446, 0.1073249881606429, 0.03427572751177415, 0.1358036402492754, 0.21724822480351696, 0.1702306816174138, 0.12765548312135283, 0.1666987251730696, 0.15371430094443983, 0.2759211522436911, 44.507824682420306, 96.13793619217412, 70.8823202502343, 64.97041017778459, 40.03934291101272, 50.70754258863388, 56.24297572720436, 83.2683023329704, 70.72283667902794, 88.52796539183586, 10.319093042804349, 0.4218108609559075, 0.6820146162663737, 2.134070415650645, 53.27794628758585, 62.89941441628241, 76.57945309915851, 71.76806988254671, 74.57764794749599, 74.63999794375512, 68.81118328340592, 68.4116663471345, 68.83379182507916, 65.20752137707126, 61.529279524280184, 56.585269205031864, 54.78419134693762, 51.908235011562226, 53.44539619261219, 49.709722995758064, 51.288065141247166, 48.99678122612738, 51.778161371907885, 48.28100750523229, 48.63751957493444, 48.82763293481643, 49.90156612088604, 48.1788807530557, 50.1745395506582, 57.28634972726145, 59.395208128037, 61.071417331695564, 63.53786253160047, 61.52854604105796, 63.151316873488895, 57.8464759549787, 47.559240402713904, 47.01192855834962, 46.51986722023257, 48.9918625739313, 49.06101396006923, 48.91190505796864, 46.002573274797015, 48.40740980640535, 48.26434919911046, 48.316273535451586, 46.580205040593306, 53.87538994512251, 50.584372320482814, 45.44889542364305, 43.66130267420123, 48.39906300267866, 44.09490892964025, 42.11284114468483, 49.26344748466246, 46.320399007489605, 44.49018970612557, 46.65459671328145, 48.8765880369371, 48.319662463280466, 47.60649711854997, 46.30359557367141, 48.390261204011985, 45.149320479362245, 44.593151923148866, 45.69153324250252, 45.88711438640472, 46.19626775864632, 46.17965652096657, 47.05869890028431, 43.37839388078259, 44.810015847606046, 46.13098775186847, 48.263058739323775, 48.29929359497563, 45.706826563804384, 45.9472482435165, 43.93355831023186, 46.87265303827102, 48.54249231276974, 46.67298870701944, 46.876924499388664, 43.543380537340724, 49.464264992744695, 48.84860977049797, 44.17693353468373, 47.222414708906605, 42.15100972883163, 47.12032718043174, 44.75256881406231, 47.04562564049998, 44.194462606983805, 40.44743807085099, 43.97253098026399, 41.35598059623472, 44.46765961185579, 46.08634333456717, 47.43589362790508, 46.99974959896457, 48.78638921245452, 46.72050429928688, 47.38352998610466, 46.62243327786846, 48.30986046021985, 47.6492666429089, 50.43511829068584, 50.35823591293828, 46.0863237227163, 47.727749347686775, 48.5261477962617, 47.655334549565474, 48.92413500816592, 47.92419341302688, 47.721708897621404, 46.11741242870208, 47.90404811982186, 47.92135361702212, 46.874833876086825, 49.677649774859034, 48.84504825838151, 47.63329082919706, 55.119440247935636, 50.87359612987888, 53.09440682011267, 49.09097302344538, 54.551218248182735, 56.94799430908696, 57.374375558668575, 60.140776172761, 64.47569339506089, 65.30335272512129, 68.51773508133428, 69.52408975170505, 71.49364517581078, 69.58073662173364, 79.77104648467034, 76.5506785915744, 84.1766526622157, 8.8842115863677, 1.9920623518766898, 1.7912638427749759, 0.22119428241445174, 0.4021847915024527, 58.433439039414935, 86.07059263413953, 72.67820096785023, 73.25846072166198, 66.19797475876348, 41.9819006612224, 30.302498263697473, 62.724566921111084, 68.43112914792954, 89.74454341396209, 12.884866383767898, 0.7534928259349639, 0.23570406430911636, 0.2673059419518517, 0.254053678063135, 0.1501471350990957], [0.027978138119402914, 0.01540683542243055, 0.01737196298856889, 0.08901233814897076, 0.035160762077618035, 0.1337889975477611, 0.058013597698581804, 34.10497726932649, 65.71162046924715, 46.63346298279301, 43.81882113795127, 48.78309442150978, 35.110653369657456, 36.230670482881614, 65.81368446350098, 60.981261653284875, 63.88027760290331, 6.08208014119056, 0.29596850876846625, 0.13154759282065978, 1.182125883717691, 45.0880059888286, 75.0292931833575, 69.61173119083529, 67.30050594575944, 66.90294234983384, 65.71323648575815, 66.2334643640826, 59.38561401059551, 55.64037023052093, 53.47647313148745, 51.94987489331154, 49.18714954007057, 46.73218119528986, 45.74013925367787, 47.2354369778787, 46.21130220351681, 45.70521446966356, 45.237930743925034, 45.46210204401324, 44.51270803328484, 46.135698518445416, 43.361817944434385, 46.71691925294938, 54.18849706649781, 58.73160585280388, 57.89256772687359, 61.25508623738443, 57.64135952918761, 59.39208984375001, 61.2279865818639, 57.332496412338756, 54.97577167326405, 50.92576757554085, 46.409609394688765, 45.405384571321555, 44.250250477944654, 43.585400888996745, 43.32918382460072, 42.656732682258856, 45.03497554409889, 41.14065424088509, 41.37912258025139, 41.07094980055287, 43.5526216414667, 50.79521148435531, 44.6747293779927, 43.243260383605964, 41.551028297793486, 46.738751165328495, 48.304655475001184, 46.24264586356379, 45.0523163426307, 46.57487061715896, 45.119122151405584, 45.85937146217593, 44.08821344375611, 43.99482965469361, 40.10812559435445, 40.524449886814246, 40.185470811782345, 42.26279335637247, 40.067215273457194, 41.705655974726525, 41.530365251725726, 42.3126623707433, 42.12326680460284, 39.27995243380147, 38.106669533637266, 39.80452629827684, 42.2877670872596, 41.376780925258515, 39.393810995163456, 40.27229639791673, 38.87208869380336, 39.76188228976342, 40.63082064351728, 39.9354197132972, 38.188164618707475, 42.11503767198132, 43.14485596072289, 42.46689388828893, 43.409863056675086, 46.598840221281975, 45.386145345626346, 48.55762481689454, 47.57764808593258, 44.16831608741514, 42.30013824278309, 40.904017648389264, 42.41052942891275, 39.29248440650202, 39.229200886141875, 43.458786779834384, 43.265370784267304, 41.767468606272054, 40.8335248116524, 42.02312477173344, 42.016272391042406, 43.2741843500445, 43.60286328100389, 42.451981036893784, 41.89528296070714, 44.42099909628592, 44.170536148932676, 42.87631480924545, 45.137894615050286, 44.35925706740349, 42.14375334401285, 42.30735932627032, 43.06711066153742, 43.756490753543, 43.64824118152742, 42.67336353178948, 42.898307538801625, 44.65128537147276, 44.185374475294545, 43.22647263926845, 43.916825479076756, 44.6256919060984, 46.44730337204472, 45.617859363555915, 46.67755826827019, 47.86175320225377, 53.55092756209835, 54.47473202982257, 60.03523303616432, 62.462419233014515, 65.31823419755506, 65.40477737303704, 68.8805700117542, 64.1583893376012, 73.98578582271453, 68.92460253930861, 77.4837947660877, 8.642741653227038, 0.5150455693083426, 1.388182820331666, 0.05569402902056614, 0.03207193387131537, 39.897349188404704, 74.3145824247791, 65.20984734258344, 56.81132324280278, 55.66086069230111, 23.74876291521134, 9.392772374614593, 30.000395351840606, 50.11513917676864, 73.49476783506333, 13.130128268272648, 0.4070649247977042, 0.17613619295579774, 0.07308879461620124, 0.022530871849026413, 0.07161512490241759, 0.007787556190329094, 0.015753895277157426, 0.05043131524636861, 0.06774049732954272, 0.07181962441292501, 0.07447735962247656, 0.04242205751999732, 43.128876224640884, 76.44170730344712, 55.609944405094275, 56.933913000168346, 50.37319191040532, 38.56908559799194, 41.59076583000922, 74.49963984950897, 68.17047196049845, 70.8918986781951, 6.530240351153958, 0.37028636122422837, 0.20998816276269577, 1.384191195810995, 49.565368006306315, 77.86249176148446, 72.44576131143879, 69.71711743262507, 69.33736924202212, 66.69198943722633, 66.82627570244574, 62.08322409660586, 58.41671013063001, 56.199362893258375, 53.07263374328614, 53.33408324949203, 48.93862816595262, 46.90754644332394, 49.67055028484714, 48.56744250943584, 48.49833034699964, 48.724647183572095, 47.87268092555385, 47.90101220530849, 47.618836895112075, 45.877080963503936, 50.38969332172025, 57.07086255473476, 61.399135281962735, 58.98428493930448, 63.522624123481016, 61.108032657254135, 61.55956022201046, 61.55203711601996, 61.494084096723995, 57.714452897348714, 53.20389193873252, 49.002052891638975, 47.807047905460486, 46.37084461027577, 46.01553278584635, 46.584449045119754, 45.11982425566643, 47.50100105039535, 43.928773018621634, 44.8732993679662, 43.773682502008256, 45.98394201647851, 51.72721370573967, 46.9163639314713, 44.07612469888503, 42.414714597886615, 47.79975229693998, 49.458134328165364, 46.62959552580311, 46.219084185938684, 47.73672373064103, 46.19084312069801, 46.01028857692596, 44.84704302203271, 44.3016178377213, 43.198761094001036, 42.44176718496507, 40.951917632933586, 44.51144110771918, 41.77424646192982, 42.74859066932432, 43.02236034024147, 43.519862005787516, 42.87770725065663, 43.30550447587044, 40.64634930702948, 41.915012482673895, 44.79863312936599, 44.704994386242284, 42.53304466124504, 42.5591480347418, 41.61274679245488, 43.13508533662365, 43.37431069343321, 43.31062709131549, 41.653861076601096, 43.73276041400048, 46.014183490507065, 43.35669532898934, 47.10378262304491, 47.19953552369149, 46.55143837774954, 50.04270476679648, 47.438207826306744, 44.18227580285842, 42.73832582658337, 40.35853362852528, 42.952451936660275, 38.45151647444695, 39.49479633761991, 45.759735415058756, 45.61676894464801, 42.04005764376733, 42.44406569388605, 43.77376879415205, 45.41188786106725, 43.69524294330228, 45.85428414806243, 44.63796500236758, 45.623997872875584, 45.229815360038515, 47.11682058149769, 45.49434392682968, 46.15060352510022, 46.4323159956163, 45.21249417335757, 45.56891995091593, 45.55197923414169, 45.87252709173387, 46.98636254956646, 45.048142940767356, 46.1543611557253, 46.83114259473739, 47.144057519974254, 46.04865327958138, 48.01622398437993, 45.209936788005216, 48.547862037535644, 47.89239083566974, 50.59116194325109, 49.65109140642228, 54.59100284884053, 56.03465080261231, 62.761931419372566, 63.46879743760633, 69.29883587744929, 68.10925160684894, 71.18237372367614, 66.36924897470783, 76.4163766368743, 70.02816923203008, 80.07808962175923, 9.007910393899488, 0.4932913382447535, 1.4713264040408598, 0.19400795170616722, 0.047131954587154815, 41.76835898430117, 83.45232425197479, 70.5927630393736, 66.01978148183515, 59.03188682371571, 31.559064849730465, 15.503967289001713, 37.09214848856772, 57.52175469552317, 84.79242555556759, 17.52995091099893, 0.5781964645270379, 0.17370481374523333, 0.14372258387025327, 0.05910900766931235, 0.03604450961574912, 0.17769164255549832, 0.0999314659425328, 0.08977785150730803, 0.21583140647459417, 0.1061410682215806, 0.2341033235913323, 0.13681219500159064, 54.92460435436618, 88.40796439878403, 61.09904258481918, 58.1886713735519, 58.929830674202215, 43.57043704678936, 50.73388914908133, 81.7766720248807, 71.81603262501379, 81.77088260650635, 7.4480357477741865, 0.4153505947080351, 0.6312581043570273, 1.8938525766134264, 51.14169013115668, 81.4324369738179, 76.49586739078646, 72.66478646186091, 72.77731141736432, 69.36888940872686, 71.39042408235612, 65.20488162194529, 60.84506911616172, 59.32991243177845, 57.51152515411378, 54.8783556876644, 52.89393055823542, 49.290347099304206, 51.42748186665197, 52.66445229130407, 51.47347950166272, 51.840327016768924, 51.47405216770788, 50.00952543750886, 49.24354537840813, 49.280866730597715, 52.05530428117322, 59.19390032368322, 62.166060632275006, 62.40730993209347, 66.56634023112636, 62.65460360434748, 63.025828484565984, 66.25878718591505, 63.98842911566458, 59.2922890570856, 56.43229676831154, 51.28939482473558, 49.321090636714814, 49.17877527975267, 47.643516448236284, 48.656849015143614, 48.446547215984715, 49.22145066722747, 44.05825045800979, 44.85882974440052, 44.28702662068029, 47.9360625051683, 55.05725891359391, 46.1798644065857, 43.66267158139137, 42.428427204009026, 47.76185435633506, 50.19850915478122, 47.43322249381773, 45.345340928723736, 47.55661241469845, 46.337477007219874, 48.97088181587958, 47.60943105143886, 47.24891816416095, 44.81757817729827, 45.879971750320934, 44.10882157664145, 47.60176281775198, 43.57266103067706, 46.84662026743735, 46.8168180988681, 48.059103335103686, 46.704348056547104, 45.52567974213631, 43.994821809953265, 44.70741056626843, 47.424295179305545, 45.96348685602988, 44.262139181936945, 46.22235152029222, 44.40604309881888, 46.10017361179475, 47.18754876044489, 45.912331304242535, 43.71648650015555, 48.05898958636869, 47.47383863695207, 43.00548238138999, 44.73194891406644, 47.560468104577836, 47.222144065364716, 51.88987831915579, 50.21522629645563, 44.67502355575562, 45.39268393670359, 40.8876064515883, 43.467376770511756, 37.992932565750614, 39.31736007813485, 45.12452717750303, 44.94807151056106, 45.36738857146233, 44.309168400303015, 47.21495436083886, 49.09642904035507, 45.55760783533896, 49.55363227475075, 47.33798342366373, 47.25093818479969, 48.841922129354174, 49.45295679953791, 48.97005419577322, 49.70108201426845, 49.0467796787139, 47.482487463182025, 47.01882016274237, 47.61886827407345, 48.60727810090589, 50.40999943210233, 48.647521618873846, 49.1073489189148, 49.6033130153533, 49.56723113213816, 48.44587649068525, 49.85753359333162, 48.82374194360549, 52.41005912903817, 50.607388788653964, 53.19548629945325, 54.67297254070159, 58.91903238911783, 58.95103500735376, 67.24293339637019, 66.9407618430353, 72.04338888968192, 73.91094699982675, 76.23459831360849, 69.50174793120354, 81.86330149250647, 73.53268930988928, 85.60206551705637, 11.090587954367361, 1.6700007045461287, 3.7211984251776054, 0.3187330565865963, 0.1570428457231291, 47.588226718287316, 90.2747223454137, 77.65947772610572, 73.52372277167537, 72.92554563091647, 39.152487170311716, 21.888547482029086, 49.301012023802734, 67.55666025223272, 99.97958398634388, 23.99259117341811, 0.7186248550011266, 0.3709835012353236, 0.2516003887379362, 0.14479571983458536, 0.11981172336926384], [0.04678027809507424, 0.06730160555772244, 0.05341171136786861, 0.02115858238070242, 0.034710988026833346, 0.06520040258164368, 0.06507481012733714, 39.26210172714726, 63.186222045652336, 46.84029740671958, 25.124893150021954, 45.97832518239176, 56.792523322566865, 45.74167290041524, 66.377470262589, 64.21167473639211, 61.828022926084465, 4.191404561842642, 0.23146703118278136, 0.2789718675757608, 0.9368412617233493, 41.35134435469105, 70.68758241591915, 66.32201579309279, 64.49567394871866, 68.17544552587694, 60.17894867927798, 56.33364915847779, 55.36119553350634, 53.65241889030703, 50.91811895370484, 47.29608466548305, 46.207222938537605, 47.34962501833516, 46.324996025331565, 46.416371560865834, 45.38889100474697, 46.92142378899359, 46.2015982597105, 46.042506925521366, 44.18930076783703, 46.13634570952385, 52.74468829554897, 55.98191453564552, 58.61161662686256, 59.73255157470704, 61.02902827724334, 55.36178388903218, 55.971837966672844, 58.40130698296332, 57.33056660621398, 56.83081350018902, 53.62232254397485, 48.85289299872614, 46.163935661315925, 46.61380798585954, 44.06176097931401, 44.748666055740856, 45.45701865226992, 45.05035907991471, 44.50787567323254, 42.258741547984464, 43.84213178388534, 42.71568590594877, 43.561690161305094, 48.81937242323353, 46.630246639251716, 43.67325805848645, 42.505713585884344, 48.16608598155361, 48.610263024607015, 47.401321857206284, 46.49045336631037, 48.13473447676628, 46.66823871674077, 44.79247500819545, 41.5762883617032, 42.36314719723117, 41.32677462793166, 39.84112593435472, 40.68452181354646, 42.43052174968105, 41.563438677018695, 40.409606810539, 41.76861393836237, 40.69515535908361, 41.05957100468297, 40.12090075400568, 38.98018529338222, 39.931579712898504, 43.633806859293294, 40.76599336439564, 39.34790749703684, 40.24213337129162, 39.31464579797561, 42.61696377108174, 41.59787708713163, 42.6454205666819, 43.33228249703684, 42.29699250190489, 40.23362967275804, 42.912051523885424, 45.929817230470725, 47.13101171678113, 45.56298540484521, 45.446624371313284, 43.325253609688055, 39.352783003161036, 41.060975213204664, 41.23002152289114, 40.788044929504395, 37.648987770080566, 38.22053201736943, 42.55941475591352, 45.28191620303739, 40.59625279518866, 42.15813667543473, 42.421210042891964, 41.5340522796877, 42.817396886887096, 42.44336751199538, 41.68929576873779, 44.52666382635794, 43.29989156415386, 43.967082808094645, 43.74162497058992, 41.97326360210296, 41.85449423328523, 42.146863783559496, 41.8320700430101, 42.98553320669359, 41.92443009345762, 43.78053488269929, 46.07208159662063, 45.118067033829234, 43.708276979384884, 45.40529043443742, 44.23331760591076, 45.861854322495006, 43.85255352143319, 46.782465980898955, 45.02183560402163, 47.56254303839899, 44.31226707273915, 49.022449216535016, 52.049130470521995, 58.94148011361399, 61.02494508989396, 65.63732685581331, 63.225822294912035, 69.75135187948905, 66.07168228395524, 74.05246611564391, 67.80625635577788, 79.36264930232879, 8.736334308501213, 0.35295674757611367, 0.8851684473695294, 0.09665192014748052, 0.04420027399675981, 28.39800515482503, 80.41526440651187, 63.50282792122134, 66.10729740511987, 44.961819418015025, 33.961308694654896, 7.212192454645711, 24.469643562070786, 48.031576141234375, 69.89714637879403, 16.73938935802829, 0.36415287744133706, 0.05097166004200136, 0.030572393368328774, 0.053710489488777616, 0.0976081510945674, 0.042254268942821416, 0.05397260647207018, 0.02013334414861616, 0.07194745384397046, 0.03441170045745469, 0.06192616960634628, 0.0640750615557115, 47.92311868359966, 75.15192216442478, 52.77392956518358, 33.46965920540595, 48.17357378621256, 58.4014795672509, 50.94395168365971, 72.66613575720018, 70.305143479378, 72.32495231013145, 4.599679660412574, 0.15824643113920767, 0.05521803178013333, 0.9068744148938888, 43.98527083858367, 73.31048703962757, 68.12938905531361, 69.03485252011207, 71.08300439773068, 63.459532799259314, 60.09640632137176, 58.45043859174175, 56.01090477358911, 54.70268841712706, 49.36014567652057, 49.679446220397956, 49.36489958916941, 48.3381760504938, 49.32175743964411, 47.24643922621205, 48.42837487497638, 49.37015948757049, 47.82131748814737, 45.70453589962375, 48.236904375014774, 54.79900613907845, 60.41258465859198, 61.02656502877513, 62.54620498226535, 64.22579526901245, 56.9421931236021, 56.164116474889944, 60.630013404353974, 59.00166103916784, 60.381433194683446, 56.01612544828846, 50.51927666510306, 47.41841554641724, 47.640449154761534, 46.749274884500814, 45.56948869459091, 47.71588810028569, 45.385505999288256, 45.94549494404947, 44.57601901023619, 45.26417924511818, 43.435915439359604, 43.632755664087114, 50.404559104673325, 45.58213833839663, 42.47856293955157, 41.54373268927298, 47.35979964656215, 48.88726472854615, 46.952383056763686, 45.670756447699766, 47.756492476309504, 46.360030635710686, 46.01217915934902, 44.577556579343735, 44.14264417463734, 44.30887422254009, 42.851470516574004, 44.92367829045942, 44.8101217516007, 42.757266952145486, 42.666205206225, 45.27131403646162, 43.91293056549565, 43.56797772069132, 43.20192644673009, 41.72058843797253, 42.2863511116274, 44.916806297917525, 43.36804666826802, 43.683224801094305, 42.417942708538426, 43.82310828854961, 43.57638728234076, 43.569997741330056, 44.68120521114719, 45.22654018094463, 45.15681220639137, 42.670547270005756, 44.76613237011818, 45.39413913603752, 46.497878413046564, 43.71043820534983, 45.98960199663716, 43.745194327446725, 38.49661980905841, 41.294838689988666, 40.20971105944726, 41.08793366339899, 38.3600232678075, 39.74909536300167, 43.8966723411314, 47.89585036616172, 41.98263806681479, 44.430310803074995, 44.763861317788404, 43.12617763396233, 44.84697241936961, 44.316981761686264, 43.7642962701859, 46.95293611095798, 46.38008179203157, 44.84436796557519, 44.41233458057527, 45.15751038828204, 44.06743272658318, 45.70564200801235, 44.40871031053605, 44.81990414281046, 45.43603397184803, 45.65376081774312, 48.66575279543477, 47.64858415049892, 45.77718603995539, 47.74037937964163, 44.954410060759514, 48.4626877692438, 45.578619972352065, 49.349417994099284, 47.914944464160556, 50.06264609675254, 47.19952375658097, 52.183212772492446, 55.687732850351644, 60.9814146257216, 62.361586862994784, 66.8845150547643, 67.7771209901379, 71.65003007458103, 68.38286046058901, 76.59296174203196, 69.31925573656636, 82.750761278214, 9.563563158435207, 0.39073925405260057, 2.561888968752277, 0.2605954101008754, 0.02725378666523724, 30.236484773697395, 88.37576173966931, 69.19614822633805, 74.3012934346353, 50.99669187299667, 38.7577869046119, 16.233111389221683, 34.341425588054044, 54.7756366575918, 81.90661230394917, 22.615847087675526, 0.5649973211749908, 0.08001626724557531, 0.04494555114257721, 0.0450014257653346, 0.053731449654385935, 0.15939753953247301, 0.1088946869957351, 0.15938898999123804, 0.210815736903779, 0.13620090280329028, 0.18485413563828315, 0.1223673390585088, 55.46367529899844, 87.26544072551113, 63.70543010773198, 38.943934748249674, 54.71312976652577, 74.17593448392807, 60.04272868556362, 82.40207041463545, 73.89635578278573, 81.60242465234573, 5.263871271764079, 0.34701190528369724, 0.546974643103538, 1.877336211262211, 47.30321553445632, 75.73793211290914, 70.07914435478949, 72.85711596089025, 75.71697096670829, 67.01638513995756, 61.60597755062965, 61.531260321217204, 59.962775091971125, 57.881283067887836, 53.57366554198727, 53.97685381673998, 53.34526592685331, 49.57545242001934, 51.92508943619267, 49.954949578931256, 52.33844057206185, 52.18376190431657, 50.72548743217222, 49.98062933644941, 51.55158958127422, 56.33189978138093, 62.36259883449924, 62.98298835754395, 66.03910307730398, 65.24950642739573, 58.115491713246996, 58.082331995810236, 61.6725911632661, 62.309133006680405, 61.40960801032282, 58.61056935402655, 53.1406476420741, 48.838929360912694, 50.08754138023623, 48.26213698233328, 47.67099265129336, 50.73228489968085, 48.227565211634484, 46.15581243268905, 46.95537582520516, 48.415364373114805, 46.28399548992034, 46.278684600707024, 52.16261248434744, 48.49003453408518, 42.49777470865558, 41.914977181342344, 48.99223519909767, 49.41121101379395, 49.91778904391874, 46.01956106001332, 49.28843690503029, 47.2404379998484, 45.315746645773615, 44.060199875985425, 47.05561591732887, 46.050708601551676, 46.4662209633858, 44.68009518038842, 48.300568365281634, 46.52970844699491, 46.27681755250501, 47.78010514474685, 45.9876839576229, 45.79165958589124, 46.61794608639133, 44.78616783695836, 44.824422713248964, 48.42009475154262, 45.3125891377849, 46.715111040299945, 45.3884046308456, 46.324337067142615, 47.4505123015373, 44.84484649473622, 49.90521392514629, 49.052184704811346, 47.19379317375922, 42.65659539930282, 45.545071940268244, 46.61938559624457, 47.97571374524025, 46.17662452882337, 47.62059411694927, 43.8423082905431, 40.08233993284164, 40.85707864453716, 40.85673739833217, 41.64252150443293, 38.19030623282156, 39.8323162909477, 45.021384531451815, 50.85408626064178, 45.06698208470499, 44.84563096877068, 47.68436008884061, 45.04191813930389, 47.16872922835812, 46.508861049529045, 45.97605413006198, 49.98859959263956, 48.81618353628343, 48.13941386438186, 47.48636668728244, 46.96785680709347, 45.97851345616002, 47.88627193820092, 46.630517282793605, 49.075895432502996, 46.25559752987277, 49.20139558853642, 51.31191315189485, 50.43852683036558, 49.9981858653407, 49.95199995656168, 49.64341532799506, 51.81512186604162, 47.18846267269504, 52.226845218289284, 51.53351137715002, 52.961630667409594, 49.10566622211088, 55.4971605731595, 56.51595700171686, 66.0157649747787, 65.60585767992082, 71.43153836650234, 71.4472984498547, 74.33491599175238, 73.65283935300766, 79.64355376458938, 73.55174418418639, 86.63113855546521, 11.461693202295612, 1.2750777217649645, 5.746267889776538, 0.5867652498906659, 0.1754774799149844, 34.842249501136045, 95.47227075023036, 74.19401661042245, 80.16879050962388, 62.8061875220268, 46.76071251592329, 18.986360296126335, 42.50899660971857, 64.62280581074377, 94.63733934587049, 30.898221961913574, 0.6890188049404853, 0.1872040030937041, 0.1246159679947361, 0.1852824400749899, 0.12024575048276495], [0.028045528958882057, 0.10181064131639658, 0.07384146068004832, 0.00752328266952968, 0.040638949571838306, 0.06600957529078569, 0.10162670360577684, 45.50298490831929, 63.86906746895083, 45.50700926011609, 53.093006533961145, 20.49484306766141, 27.03918826195502, 44.47801074674053, 68.08444653787922, 61.131998339006984, 59.22719340170584, 3.4954554803909796, 0.21338809161416947, 0.2177702217933632, 0.4589711814638107, 31.70947990109844, 73.98388739555114, 66.49491387028849, 64.29788451040945, 61.61329669337119, 61.52114060617263, 57.53124683134018, 55.142044867238695, 51.347791071861025, 50.561908906505955, 52.55431998160578, 55.313177877856845, 55.112148561785304, 57.00409596966159, 56.065213910995, 56.025837236835116, 53.83179280065722, 53.30752095868511, 49.542979117362734, 50.44841120319982, 57.468457529621745, 57.28385509983186, 55.96232621900497, 63.96708749955701, 52.194022824687345, 43.222150187338556, 52.8466816871397, 53.85891206802861, 63.312663570527114, 56.8086991771575, 56.42815474540957, 48.89089684332571, 53.07523035234021, 51.763809419447384, 51.31921268278553, 46.482773365512976, 44.78714450713127, 44.57355576176798, 44.079203759470296, 42.81218013455791, 42.546180678952126, 42.425536417192035, 43.95320154005482, 40.549713873094134, 45.65927174783523, 45.886816286271625, 45.25018030597318, 41.66997025089879, 50.111142281563055, 47.880270711837284, 42.794737354401626, 44.06107848690402, 46.557208184273016, 47.125551777501265, 45.28746635683122, 44.072374913000296, 40.9766403321297, 41.2037024190349, 40.84436624280868, 38.822596226969075, 39.83283796618062, 38.85999602656211, 41.031969285780384, 41.67905446021788, 42.759192835900095, 39.95729869411838, 42.053162282513036, 40.18898525545674, 39.09671106646138, 41.63146434291717, 42.05574320208642, 41.18518883182157, 40.60454468573294, 40.311743674739716, 38.11627934055944, 39.14751752730339, 43.6987260080153, 43.1701317141133, 41.90114690411476, 41.0402415644738, 44.550794247658025, 46.20552455225299, 47.965688167079804, 44.95304115356938, 43.12203953343053, 42.8330236096536, 40.25260609965171, 39.83611706764468, 39.62093191762125, 38.274507753310665, 40.99959404237809, 41.16131336458268, 46.606841856433505, 40.70968774057204, 39.96720267880348, 39.21789269293509, 39.15871981651553, 39.98678707307385, 41.320891072673184, 41.866379014907345, 42.69197125588694, 41.9899336753353, 43.60827615184169, 44.344716841174716, 43.73778104782105, 43.448678831900324, 43.48792606784452, 46.98831588991227, 48.20120296170635, 45.83826126590852, 44.01781474390338, 43.07896798656833, 43.04489043451125, 45.13080689214891, 44.431330619319795, 44.106307337361, 44.467502717048895, 43.66344821068549, 44.55752503487372, 46.66158245455834, 45.66750088045674, 47.90982184871551, 44.58105141116727, 47.397575993691724, 47.88303990517893, 53.07179043369909, 56.29909699962985, 62.49870900184878, 62.12063174093924, 66.46692383673884, 63.42458055865381, 73.52145564171576, 66.16497978087395, 79.31256063522832, 9.905976268552966, 0.1841701263742101, 0.42877021816469013, 0.2129311967761286, 0.1119888395131115, 17.979536902519968, 78.26217343730312, 66.65540156825897, 69.01316965779951, 52.27775758312595, 53.89799456442557, 14.845776904013851, 33.95667245311122, 46.10135032284645, 74.64344962950676, 21.75985843904557, 0.25351213050946114, 0.09614386595785619, 0.06205327508430328, 0.03406997927795014, 0.031337219162754, 0.047738776662417, 0.04394168867879818, 0.05056566408564968, 0.05186988281146173, 0.09126541039515888, 0.09988204561053746, 0.033108182702093356, 54.94932705356229, 73.96873920194565, 53.26289615323467, 46.512583378822576, 28.899187964777795, 31.08885503584339, 50.40642223050518, 76.16516451681815, 65.25838667346586, 67.24863652260073, 4.208891958959641, 0.2604410280623744, 0.19901779900875785, 0.3743808560313717, 34.2781420676939, 75.87547394537157, 69.57293110509073, 68.71094319128221, 63.82561937455208, 63.88928336481895, 59.39376469581359, 57.04852465660342, 54.39803008110293, 53.734031646482414, 54.7893924097861, 55.86926798666678, 56.134126032552416, 58.78046681804042, 56.94926123465262, 58.705392652942294, 57.66236382146036, 55.214389062696895, 52.58920554191836, 52.66702928850728, 56.33670076247185, 61.98087769169962, 58.585066103166156, 64.99708229495634, 54.171034674490656, 43.847956503591234, 52.94070482254029, 53.73603205527029, 63.91294702406853, 57.887386275875954, 58.711844951875754, 51.28235417027628, 56.49337199426467, 51.7699126274355, 51.48095161684098, 47.978859486118445, 46.122413450671786, 45.89849710464478, 46.24171233946278, 43.600376498314645, 44.38144983783845, 44.331902457821755, 46.312467975001184, 43.12872717457433, 48.01940502658967, 46.11703980353571, 44.012119462413175, 40.91092494226272, 49.586050664224935, 49.5775548104317, 43.15250066018874, 44.93430399125622, 47.734507591493674, 47.72787094116212, 45.353703421931115, 44.424658667656686, 41.59185232654695, 43.68429953052152, 43.57760321709418, 40.300082468217425, 41.87078775898103, 42.84389641977126, 43.82385746125252, 44.821669209388, 46.21498530910861, 41.78945349108788, 43.64433057846562, 42.13077422111265, 41.82163653835174, 43.79319629361553, 45.17156031823928, 44.002242934319284, 42.96347771921466, 42.62881325137231, 41.566631486338956, 42.79410977517405, 44.9225055017779, 44.79970001405285, 41.790183051939934, 42.678713644704516, 46.106798495015795, 45.36601181953184, 47.68910223437894, 45.30487775802613, 43.29153691568683, 42.950506441054806, 38.78440410860124, 40.66007760263259, 40.22676552495649, 38.61257683846259, 39.40661753377607, 40.83946720246346, 47.16145323168847, 42.83967987183602, 41.52371291191348, 42.03282479316958, 41.64169780669674, 42.57093083473944, 44.362210612143244, 43.52486695012739, 45.137804400536325, 44.70759491766653, 45.081969461133404, 46.484397226764315, 45.32798444071124, 45.57414062561528, 46.44121585353729, 49.30808405722342, 50.07348360553865, 48.20714535251741, 46.87925046490085, 45.114164275507775, 45.712423786040276, 47.57414933173887, 46.25955520137664, 47.380694112470074, 46.627771623672984, 46.7909461452115, 47.66334402945734, 49.67587686354115, 48.51945231037755, 49.086952594018754, 45.896979147388095, 51.0915034048019, 51.26388372913484, 54.96513028298655, 59.54037504811441, 65.4890847975208, 64.0544935964769, 70.1071265435988, 67.17619034551805, 75.48613948206749, 69.59520232292914, 83.54606889909314, 11.563638544851734, 0.3280842935125674, 1.7967733019782652, 0.39063258397002376, 0.19290973402319417, 20.707527706699988, 84.04156623348113, 71.67157957630774, 76.02940344041394, 57.67183242305633, 46.685536369200676, 20.627240711642852, 43.07539862971152, 52.6900653685293, 85.90077753989928, 27.826802153741163, 0.27915223531665345, 0.044462233932027896, 0.0439648704993869, 0.007285697736792387, 0.027797571195650007, 0.15568973526598948, 0.14793703272458048, 0.19244147044035698, 0.1915206940424058, 0.20999413824850516, 0.22577176501433696, 0.2573032238550725, 66.985916168459, 84.83072357793009, 61.48647077621953, 70.72309555545931, 30.073043530987157, 38.130595991688395, 60.14296093294698, 80.48480802966704, 72.87845365462765, 72.76057074146887, 5.266194295498633, 0.4807913267324048, 0.48896995883795524, 0.7506775447437841, 36.34561554078133, 78.18407120243197, 73.62974443743306, 71.6281432490195, 68.11503318048292, 68.06346970219766, 63.51234751362955, 59.735359991750414, 57.18670583540394, 56.010575294494636, 57.892034284530155, 58.88323683892527, 60.93718205728839, 61.57079781255415, 58.81902371683429, 60.91222401588195, 59.912447160290135, 57.82308293927101, 55.39401792710828, 54.7190329336351, 62.58789977719707, 64.01358327557965, 60.81729089060138, 69.40164904440604, 57.387837133099964, 45.25696208400112, 54.40628667031565, 56.422584979764885, 66.78294920152234, 62.23246635929231, 61.52095625477453, 53.85710385537917, 58.66762022818289, 55.330299023659, 57.28663606028403, 51.716211457406324, 49.545650251450084, 51.09989335460048, 47.85803087296025, 46.11641614667831, 46.320701029992875, 47.54452759219755, 48.93542358952184, 46.27790404904274, 51.48433662229969, 47.89031197947841, 46.544123157378166, 41.931596263762444, 50.41112907471196, 49.579633666623025, 44.697985110744355, 44.25088590191257, 49.20496102302305, 47.941620503702474, 44.56837823314052, 45.066064250084665, 43.81193345592868, 45.5343952486592, 46.9805613640816, 42.879354646128995, 43.1280799834959, 45.165865036749075, 45.82698052929294, 47.77568071119247, 48.111753309926684, 43.36865071327456, 47.0067863310537, 45.257252339393865, 45.04119642319218, 46.40807182558122, 46.946040584195046, 46.59788316295993, 46.201770843998084, 45.11077142530873, 43.51262131044942, 45.18116620279128, 48.9365767663525, 47.422608560131444, 43.19477988827614, 44.01488865575483, 44.0079225263288, 46.63122330942462, 49.45785976225331, 46.623747271876184, 44.1079939565351, 41.973271446843306, 39.63880615849649, 40.80470323562622, 39.76590664156022, 38.74109721952869, 41.415075025250836, 41.980708260690015, 48.95253689058366, 44.92882051775533, 44.07961560833839, 43.99208791794316, 44.09181810194447, 46.16981137183405, 48.01338811074534, 46.956395641449966, 47.33648900062808, 46.081146194088845, 46.70958442072715, 48.04901892139066, 47.959730086788056, 48.08674427770799, 49.97846026574412, 51.778961535423036, 53.55485385464084, 51.88289650024907, 49.97495366681007, 47.652067215211936, 48.778450335225756, 51.70103188483946, 50.175837855185236, 50.6312721006332, 49.077927220252256, 49.99932335269067, 49.227777450315415, 53.11825483076034, 49.91304297601023, 54.066099505270685, 48.933999769149295, 52.53960324871925, 54.083569742018184, 58.68049344708843, 62.267328385383856, 67.02711674474901, 68.22070967766547, 74.19315368898454, 69.88687761368291, 82.09301902401833, 72.82594096276068, 88.90150839282622, 12.742639280134632, 0.5803409591317177, 3.175773976310607, 0.9520194859754656, 0.30348340229642007, 22.894921764250725, 92.40429478306925, 76.24882082785331, 85.44860670643469, 69.4651992859379, 71.60859415608068, 27.775334773525117, 54.7331730781063, 63.201397695849025, 98.25762425699543, 37.354904144041, 0.44664733953052954, 0.386574769452695, 0.1200781687493286, 0.1723629954240976, 0.0701199357788409], [0.0698622697663884, 0.014617357876211887, 0.009380184515799967, 0.03647041619725285, 0.11052617848279978, 0.056415009687864975, 0.0966988277110842, 35.10568764901931, 61.540442589790594, 49.99076866334485, 44.79123161685082, 21.384720994580178, 37.00717818352484, 47.904197169888405, 68.5500083431121, 57.77516334287582, 60.30807702772079, 4.1239236151018455, 0.34405370272936364, 0.23587248107839018, 0.1906965060099479, 24.929476745667, 70.2862847235895, 66.37130429667812, 64.0566469777015, 63.37444874548144, 58.020970436834524, 54.97774070309055, 54.749435224840724, 53.81316154233871, 56.91890993425923, 58.43236430998772, 62.49517886869369, 61.56674600416615, 61.43704498967817, 60.27787085502379, 62.36483458549746, 59.39207023189914, 60.737031352135446, 58.90543353173041, 56.74451743402789, 57.16473271769863, 61.70068710081039, 60.57028355136995, 55.85376677974578, 57.854206946588334, 49.70193709096601, 60.24779412054247, 59.34553130980461, 55.858697199052386, 54.10775507650068, 51.07611202424573, 52.432291123174856, 51.20082378387452, 54.16113068980556, 56.865597078877116, 56.43971397030739, 45.9198034194208, 44.81643676757813, 41.795784196546, 42.18756621883762, 43.83143548042544, 41.70782896780199, 43.29197622114613, 42.2230322899357, 41.688221039310584, 46.28260304850917, 45.22382197841522, 40.962045192718506, 44.533233796396566, 44.780939317518666, 44.44500400174049, 46.305529302166356, 48.67526846547281, 45.74844291133266, 46.547719970826186, 45.416229924848004, 39.236386668297556, 41.80086758828933, 43.893722718761815, 40.257497295256584, 41.58661203999674, 38.980463781664454, 41.4789939695789, 42.755858821253625, 42.71436798957087, 39.98754801288728, 39.92261317468459, 39.984543477335286, 41.657250004429976, 42.676364144971295, 40.791535838957756, 40.633648672411525, 40.33647814104634, 40.71151164270217, 40.40877919043265, 41.89861697535361, 44.935417944385165, 42.14684024933846, 43.92567042381533, 46.441078570581254, 47.74904389535227, 49.76798980466781, 48.94146403958721, 42.42920775567332, 39.35489716068391, 38.83392010965655, 38.36490661867204, 37.27854736389653, 36.827055100471746, 38.98972449764129, 37.623868911497055, 41.512451787148755, 48.879914206843225, 39.00416274224558, 40.70603993631179, 38.05001089649816, 40.198053775295136, 40.48101748189619, 42.3312936290618, 42.268935788062315, 42.48740396191997, 42.071934746157744, 44.06675023417319, 43.27502765963155, 42.379864338905584, 47.48718646264846, 54.80688225838446, 54.02718959316131, 58.17454691856139, 53.01554756779825, 52.69793756546513, 48.37505025248374, 48.30629502573321, 48.36925298936906, 46.901929609237186, 47.7728997507403, 46.873194325354795, 47.05030110574538, 46.58141705297655, 48.66455255016204, 48.047195019260535, 47.772715399342204, 46.715134574520974, 47.69141251041044, 47.67242039403608, 46.406914726380386, 49.45771071218675, 51.309277319139056, 52.86895290497811, 62.247700845041585, 63.03352417484407, 70.04633765066825, 65.51722780350717, 83.26148525361093, 13.944302489680629, 0.5910074158060936, 1.3984034138341106, 0.6660131232873087, 0.04475772553574174, 10.535962850816789, 81.90720065947502, 62.53678737148162, 78.03470734627017, 47.657130995104396, 69.0515539723058, 29.544980718243508, 29.93732560065485, 45.743994943557254, 69.51615087447628, 24.68375006029683, 0.44751807506526675, 0.13348348168355803, 0.04691063178583019, 0.0590102972402688, 0.030292704243273027, 0.04023080856929864, 0.06965405472944822, 0.06376176223819775, 0.030088995718547416, 0.018423123720792994, 0.047231082534117085, 0.22591001324115262, 47.187113377355764, 70.49308776855469, 55.375449426712535, 52.43281672077795, 28.349014751372803, 34.88166147662748, 53.66770436686855, 75.94461748676916, 65.90990020382789, 67.1626973921253, 4.79866297014298, 0.257037544562932, 0.1089247176423669, 0.4018823706334637, 27.310131865163005, 73.79743360703992, 69.47372651869252, 69.53542540150305, 65.2331187648158, 60.662800496624364, 57.197829677212624, 58.16922033986738, 57.0535845141257, 59.55979470283755, 61.15671711583292, 63.16171115444553, 65.10474743381624, 64.01914911885416, 62.62642921939973, 64.97149667432232, 61.98738490381549, 63.324340466530096, 59.86003252767748, 59.13347228880852, 59.871921231669766, 63.93041726081603, 62.55813683232954, 59.353666305542, 56.10917583588631, 51.021320435308645, 61.368897730304354, 61.669833737034956, 58.353034373252626, 56.29929311813847, 51.83197236830189, 53.366274141496234, 52.20084382641701, 56.679433545758656, 57.8259462694968, 56.34479261213734, 47.593859241854766, 45.298562742048695, 42.527392525826734, 45.98505596960745, 45.333056065344046, 44.19237198368196, 45.51384595132644, 43.25640816842356, 42.911816181675086, 47.71713933637066, 44.22511200751028, 39.64762364664386, 45.169273576428814, 47.47275998515468, 45.66373540509132, 45.03135519642984, 47.42707221738754, 47.362741424191384, 46.370334702153365, 45.801312538885306, 40.93434933693179, 43.77093292051747, 46.08388400846913, 42.047243425923014, 42.21257917342648, 41.91002322781471, 43.16689183635097, 45.66252731507825, 44.75819741525958, 42.76457040540634, 43.27832245057629, 43.69561949083882, 44.9263023561047, 44.08422439329086, 43.19962401543894, 43.880367048325084, 42.69641137892201, 42.97893578006376, 41.82374285113427, 43.61415186235982, 46.69574237638905, 44.1132067864941, 44.91640229378977, 47.07324697125343, 47.90240464671966, 48.708494863202496, 49.78291442317348, 42.572762581609915, 37.75227162145799, 38.82298454161614, 39.08290432345483, 39.357564372401086, 37.53962424493606, 37.97387376908333, 38.209878859981416, 43.24075398906585, 51.32262906720562, 41.91383969399237, 42.623592576672955, 40.79994147823703, 42.44415983077019, 41.94650911515759, 43.96753388066446, 45.64208784411031, 43.52848729779644, 43.85574240838328, 47.307683114082586, 44.587715518090036, 45.27429896016275, 49.49190985771918, 56.61159223125827, 57.400137685960345, 57.38334994162283, 55.86973082634711, 54.341900963937086, 51.297835765346406, 50.691821728983236, 50.95629146022182, 49.75251605433803, 50.25161804691438, 49.71038195394701, 48.45742394847255, 49.64269361188335, 52.45511931757773, 49.64136785076511, 52.15621117622622, 50.30535451827511, 49.94233915882726, 49.49605972536149, 49.85410936417119, 51.0548488555416, 53.78636390932145, 55.62071915595762, 65.23509171701247, 64.22171992640342, 72.22042114503923, 67.8631228785361, 85.3229025871523, 15.592700127632389, 0.8898551894291755, 2.724979159332091, 0.5846507859326179, 0.06042921081966451, 11.236724680469884, 89.88388953670379, 68.30049068697038, 84.64066905360069, 56.13232174227315, 62.8580726346662, 26.52077251865018, 36.910597662771906, 51.57974043200093, 80.06149015119, 34.031264166678156, 0.3846629510723776, 0.05531954992141935, 0.01038872298874682, 0.03568126519601192, 0.04417099411629381, 0.1685468510033623, 0.08059690060514597, 0.12712581759138455, 0.12183804125074418, 0.3150932809277889, 0.10510659671478695, 0.3305753050071578, 56.882392667954974, 82.01380283601823, 67.22861674524123, 63.165205986269065, 31.574311102590254, 52.753678367983916, 61.878174351107695, 82.36767907296458, 74.4350148785499, 74.74423100871425, 6.372268853649017, 0.6754043806464441, 0.5266815868596877, 0.49110382014224613, 29.59556164280061, 78.13869722427862, 71.46054821629679, 72.72326900113013, 69.7158230504682, 64.59168572579661, 60.74686865652762, 61.15282612462198, 61.07035436937886, 63.245469447105165, 65.09394914873185, 67.67456669961253, 68.40909327230146, 66.45417613367881, 65.70285789428219, 68.68983299501481, 64.50682524711856, 68.15340965024888, 63.41246827956169, 61.563580651437086, 62.802578941468276, 67.34025524508569, 64.60595923085367, 61.29798519995905, 57.499691363303896, 51.23030039571947, 62.85011806795674, 64.2896749896388, 63.61002237566056, 58.88197383572979, 55.93396748265913, 58.55839398599441, 54.960984337714414, 59.709668467121745, 61.49415077701692, 60.86777571708926, 50.04328135521182, 46.88582827967983, 43.785037763657115, 47.56597511229977, 47.939780912091656, 47.28712204963931, 47.855057716369636, 45.03914502359206, 44.489856304660925, 49.1955473346095, 43.969083216882524, 40.957640371014996, 45.822352132489605, 47.46416999447731, 49.47209796597881, 47.40701713869649, 49.571286862896336, 49.005139796964585, 46.07682374215896, 47.65729573465163, 40.37779246607135, 45.18068767363026, 48.28233718872071, 43.069809252215975, 45.79480140439926, 43.52407070898241, 45.9334336557696, 47.91316763047249, 48.39041025407853, 44.915911997518236, 46.29444076168922, 45.81414261171895, 48.40872772278325, 47.56072698100921, 46.58339000517323, 45.09515254728256, 45.598255357434674, 45.76068855101063, 45.12549208056542, 46.37289993224606, 51.11115055699503, 45.09691369148993, 46.8662085840779, 47.32589860116282, 49.624893896041385, 52.20971230537661, 49.952502019943736, 43.7932002159857, 40.03928407546013, 38.891880973692864, 39.252268345125266, 38.56976416803176, 37.10732806113459, 39.10317905487553, 39.12523454235446, 43.897358755911554, 54.36128923969885, 43.719793058210804, 45.26368110410629, 42.70712729423277, 44.426227615725615, 45.37753182072794, 46.47694080106674, 48.125391391015825, 46.313483868875814, 45.20406499985726, 49.45489837277321, 45.90119961769351, 46.492634204126176, 53.68050306074081, 61.68720591452814, 60.47430707562355, 61.477170836540964, 58.63964588411393, 58.34801373943206, 53.942658593577725, 53.16964572475803, 52.971895510150546, 52.305873132521114, 52.70195799489176, 53.701797608406316, 53.37494650194722, 51.98650983072097, 54.35525663437382, 53.63137145196238, 53.15799628534625, 53.29923691288118, 53.49421401177683, 51.96805507906022, 52.70065184562437, 54.8432896983239, 57.19798264964935, 57.718120313459835, 70.08975828847578, 68.73302613535236, 76.18243863505703, 70.91973181693785, 92.82108583757955, 16.99477684113287, 1.35937386943448, 5.030409837922742, 2.3318875556991947, 0.19786453024754602, 12.133377521268784, 98.78322970482611, 73.31178926652478, 93.54028378763508, 63.940799774662146, 89.589413673647, 42.84360616437851, 47.21071427868259, 62.93938336833831, 89.64232644727154, 46.17005848115491, 0.6170644563051962, 0.21879206051028546, 0.19965098599993414, 0.1663358599668549, 0.11868728249664269], [0.00522876171500332, 0.061772936699731704, 0.045498195479834275, 0.03421624844533301, 0.04293592248652731, 0.08133741651451395, 0.23397498854225685, 25.018634180868826, 65.97848676866101, 41.63664971628497, 23.630844700721003, 21.62262451264166, 35.18145999600811, 48.3893237575408, 69.46497963320824, 55.100130419577326, 63.78836470265543, 5.205108773323798, 0.28329438079268704, 0.42035875661719235, 0.3279937112764005, 13.469511347432292, 69.57012268804735, 66.8636872691493, 65.73857891944148, 63.85914387241487, 59.61170334969798, 59.44280216770788, 55.91944686828121, 60.80675148194837, 59.81434475991034, 63.83095772035661, 64.58959510249477, 63.859932268819506, 65.28638455175584, 64.23222403372488, 62.21447836968207, 61.154351926619015, 59.607635851829286, 61.90626244391165, 58.73621071538618, 60.656324663469874, 59.25796831807783, 56.200359175282145, 58.62877307399627, 59.722129837159194, 61.422022311918205, 57.373434189827215, 56.365090877779075, 55.24701533779022, 50.680591983179895, 50.806688339479514, 57.971603485845755, 65.77510795285626, 60.62909164736348, 54.570171140855365, 57.26818523099346, 54.71228645693872, 44.239750292993364, 44.07478717065627, 45.23480069252753, 43.93858286642259, 41.38735955761325, 42.466113336624645, 44.21154060671407, 42.74245608237482, 45.560992840797674, 47.42631912231446, 42.539312608780406, 44.51955256923553, 43.0088673868487, 46.530857701455396, 43.843712499064786, 42.656073724069905, 46.57291335444297, 47.47379941325034, 45.4938457858178, 38.55465127575783, 38.34853856794296, 40.91157605571132, 45.5091900979319, 41.4893372597233, 41.1394775298334, 41.44049590633762, 42.85766393907609, 41.31829446361911, 44.13432482750186, 38.677672493842344, 39.12306547164917, 42.82371974760487, 41.946803292920514, 39.471466079834975, 39.737838160607126, 41.10656492171749, 42.51920261690694, 41.15231936977756, 40.922021327480195, 41.25801940118113, 42.753226910868, 44.46685160360029, 43.19572517948766, 45.49831336544406, 46.27455826728575, 41.3776046229947, 38.94415047860915, 38.704093579323064, 39.65673139018398, 39.24356068334272, 39.32979791395126, 40.26711102454893, 38.50813196551415, 34.4613952021445, 46.384153212270434, 45.10176566339309, 39.873814967370805, 41.96228488799065, 41.203510222896455, 39.71997176447223, 40.46004849095499, 42.14303947264149, 41.95773493859076, 45.47903099367696, 42.88550884492936, 42.203185096863784, 44.00731063658192, 49.47110560632522, 53.18078133367723, 58.66608658144551, 56.39678362877139, 56.43658784128005, 59.435737979027536, 57.44710806877383, 54.249850780733176, 53.4552138851535, 53.34607001273863, 53.89835934485159, 53.47423345811906, 54.046805366393066, 55.66074302119594, 54.53595630584225, 55.536941251447125, 56.065241367586204, 56.17247896809732, 57.0764244756391, 56.669380511007006, 55.56360160150836, 54.838590698857466, 49.79573272889661, 49.92868146588726, 50.52224982169367, 57.188310084804414, 62.35917460533881, 71.91708072539299, 65.75677479467085, 79.27631009009578, 18.422941238649432, 0.5565675348043442, 0.7801517051073813, 0.3541771256394925, 0.01921660503402593, 5.64517762391798, 75.99734198662543, 64.213788893915, 75.99807939221783, 51.91854692274525, 63.66730859202724, 43.4454232646573, 31.965755801047052, 46.105476656267726, 72.70402585306476, 36.6738159425797, 0.1741586442315771, 0.05528199629137113, 0.020540320697510918, 0.021355714040598082, 0.07347422111178599, 0.046734105975877856, 0.08732147484777436, 0.03690675689628528, 0.032295669849601485, 0.029325355445185018, 0.04956400029421334, 0.1938698566969364, 35.43477450647662, 80.49551610023745, 49.52670520351779, 34.45280521146713, 20.65262040784282, 41.543869972229004, 53.381339965328095, 75.25343310448432, 62.83481690191454, 68.97192985780778, 5.816896538580618, 0.5548339084752145, 0.4704195687607412, 0.38052604563774606, 13.500896192366078, 71.24916384297033, 68.89552993159141, 68.3204241721861, 66.04715962563792, 62.59293217812816, 61.58703250269736, 60.61434353551557, 61.98299577159267, 61.572366760623076, 65.0554903091923, 66.67119303057271, 65.45685860418504, 66.65735490860479, 65.6083679968311, 63.622644562875074, 63.213949280400435, 63.17799291303081, 64.25326754969936, 60.7458370731723, 62.65374068290957, 60.01152623084284, 57.03547100866995, 60.35762440773749, 63.3716481731784, 65.14523806110506, 58.38218542837328, 58.23446896768386, 58.42287217417071, 54.1471121388097, 52.7450805325662, 61.08724409534086, 67.75470072223295, 62.44862817948865, 57.86991996149863, 59.44794047263361, 53.90703170530258, 45.759378479373076, 45.593991741057366, 46.979416031991285, 44.8373390782264, 43.529632629886756, 43.74870877112112, 47.59115672880604, 44.16630391151675, 48.513776640738214, 50.33629809656451, 41.37383914762928, 43.8722595091789, 42.6481113126201, 48.16963572655955, 45.01482240615353, 42.45623680853075, 45.36993811207433, 47.81461415752288, 46.51793741410779, 39.98904243592293, 38.73964986493511, 42.20277717036586, 47.363541587706536, 44.24355499206051, 43.84683078335178, 43.49109926531392, 45.495489258919996, 42.923583292192035, 45.97704256734541, 43.14660926018992, 42.31410580296671, 44.1130655811679, 43.60091778539842, 42.66465979237711, 43.43089872790922, 43.37933132725377, 44.39364448670418, 41.72631509842412, 43.50642004320699, 42.71177922525714, 42.31069334091679, 45.383529124721406, 44.70427267013058, 45.7467366803077, 47.01744733318206, 41.62157604771276, 38.576087028749534, 39.60832541988742, 40.01523994630383, 38.43638397032215, 39.64730985703007, 39.30009380463631, 39.13697027391003, 33.8069438165234, 46.39819137511715, 47.64391652999386, 40.113032479440015, 43.015974721600934, 42.33912660229591, 42.15982329460883, 42.722000921926195, 44.518560209581935, 42.5797640123675, 45.91228423580047, 44.73142331646335, 44.71589465295115, 45.29779003512475, 50.49134938947616, 57.72517273502966, 60.35988761532692, 58.8233853924659, 58.844915282341745, 62.13652126250729, 60.56926373512515, 57.86310288213915, 55.861395789730935, 55.713169420919115, 57.029548229709754, 54.90409820310531, 57.13871171397548, 58.34455420894008, 56.315774917602546, 57.80910361197687, 57.25618277826617, 58.98178638950471, 60.20511873306767, 59.9505372970335, 56.97739247352847, 56.83649309219853, 52.8607080828759, 52.13599135798793, 52.56393371089813, 60.43558151491227, 63.726293194678526, 74.74179129446708, 69.01518575606808, 83.04937916417276, 20.448362981119466, 0.6801894883955679, 0.9629751561630158, 1.0652483230636967, 0.12130180268638557, 5.281568025389026, 84.13009412827031, 69.91471075242566, 82.02097292869323, 58.05483225853213, 67.99505572165212, 37.518541505259854, 39.46115416865195, 53.70464132678125, 79.36432807676255, 46.58463339651785, 0.35695762643891, 0.07700787061044286, 0.052089474254077485, 0.020084343249759367, 0.06291721924959172, 0.14198953976794598, 0.1610758696352282, 0.11936688675515114, 0.14169102594737085, 0.13511851249683288, 0.2727813562077861, 0.31525915428515405, 47.13892705978886, 90.48294528838127, 57.19393476363152, 39.50827360153198, 32.6022917609061, 51.74934764062205, 63.83184025364538, 80.81722890177082, 68.44109981290757, 75.95192094003, 8.19138422127693, 1.0018809620411167, 1.6589978433424428, 0.47498241908127264, 15.210816206470614, 74.59711859303137, 71.59853719895887, 71.59815280668198, 70.14902530177947, 67.92904223165205, 64.39619871877855, 64.78052823774277, 64.40206266218617, 65.41367330858785, 69.61342565474972, 68.78317756037559, 68.15124450191375, 71.84446980876308, 68.55016523791899, 66.85905102760562, 65.99668656626056, 65.5781892807253, 66.79144505531558, 63.760453116509225, 65.7993717347422, 62.68059322910925, 58.462907806519546, 61.56822081535094, 63.50136095477689, 68.67899940859887, 60.832980371290645, 62.350765043689364, 60.23435215796194, 57.87357561049923, 54.736934631101555, 62.20558635650143, 67.12414049333142, 65.87541472527289, 60.599238487981985, 62.031193856270086, 58.883385888991825, 50.654916148031916, 47.115102583362216, 49.835764438875266, 47.06332337471747, 44.79189057503977, 45.63862046887798, 49.28592266574983, 47.15786034061063, 50.90920340630316, 49.93224297800372, 42.47403652437272, 45.76627400613601, 44.30932137273973, 49.50167655944825, 46.55403106443344, 42.808540175038004, 47.60241000883041, 47.46929260992235, 47.294205850170506, 39.315881344579886, 38.64616409424813, 43.39955899023241, 48.86747244865664, 45.583275825746604, 46.085154856404955, 47.49803966091525, 47.57087415264499, 46.216530722956506, 49.786993688152684, 45.627488782328946, 45.78548577524001, 47.094427770183934, 47.54362544705791, 43.32492413059358, 45.16201719161003, 44.09734864388743, 48.868413817497995, 43.895236753648334, 45.03568941547025, 43.36400270462037, 43.561046892596835, 47.30652993725192, 45.309313958691014, 46.40715791333107, 48.89179898846535, 42.06537654322963, 39.297304999443796, 39.50322551112021, 41.179760271503085, 39.407143131379165, 41.24773494658932, 41.20129016137893, 38.8878958455978, 34.00678465443273, 47.20170459439678, 51.37354535441245, 42.15884270206575, 45.61801625836281, 44.269470091789, 44.78328097251154, 45.74402240014846, 47.66379510202716, 44.42004596033404, 48.66785126347696, 46.91300246023363, 45.893327420757664, 46.792915175038004, 52.74518643656085, 59.705871612794944, 64.50517392927601, 61.392290746012044, 63.29726826760077, 62.8654545353305, 62.96703215568297, 62.16727264465825, 59.045854383899325, 60.00257538210962, 57.53416115237821, 58.453674547133915, 60.44519916657479, 62.05773653522615, 58.508336697855306, 61.72955182290847, 59.63075822399509, 62.62164785015968, 64.29966526646768, 61.85693863899478, 59.76970818734939, 60.266939209353545, 53.83277339320029, 55.70852925700527, 54.16610817755423, 65.17102764498803, 68.56933778332126, 78.62088987904211, 71.38680765705725, 89.24713980767035, 23.217668110324492, 1.6726001328037632, 5.062024631807882, 1.2531809677039425, 0.3387206888967945, 6.901466211965007, 91.24707791113084, 75.74103078534527, 89.67383876923593, 68.06842757809547, 80.87585264636625, 58.520743154710345, 47.85828582702145, 64.17143514079433, 90.66566498048844, 58.93680464836859, 0.5124905128632823, 0.11208880632635086, 0.21446004780309819, 0.1278784606725939, 0.1471880898480454], [0.018853013959502982, 0.0341960390458905, 0.01827934816960366, 0.06312189879076135, 0.06009358003915799, 0.08005031985380957, 0.23030437018361785, 23.70821149118485, 66.18668617740755, 39.21654731996598, 38.18378725359517, 28.95423450777608, 39.06930938843758, 47.317845975199056, 72.29175336899297, 58.8661039260126, 65.70991423822218, 5.7134680498030885, 0.10823562155447661, 0.37110742361795523, 0.23266015183781427, 5.683526637092714, 61.88790182913504, 70.56438861354705, 65.69742933396371, 66.68694526918473, 60.39529092850224, 59.219305515289314, 57.3090837847802, 59.966520955485684, 59.00781131559803, 61.663703072455625, 61.06216838282924, 59.02146116379769, 55.187006996523955, 49.15249539959816, 44.317315163150916, 48.97419229630501, 55.05382683969314, 57.14012376723751, 57.641120264607096, 62.570052992913034, 61.00521164555704, 61.26129142699703, 58.391136277106504, 55.67896635301652, 55.32851826760077, 56.461969498665106, 56.54715945643764, 53.867207880943056, 49.44150347863474, 54.00076850768059, 57.40594279381537, 47.37403785028766, 51.44956481072211, 59.90462595416654, 55.08192277723744, 50.976377917874245, 43.995268960152906, 42.52876927775722, 42.82980334374213, 43.91154596882482, 42.2633267987159, 41.820271553531775, 41.07301688963368, 44.17819653787921, 42.334184415878795, 51.9492983048962, 46.89078615557763, 40.97269442773635, 42.0053917361844, 42.753913325648156, 49.75321815859888, 44.743927832572695, 47.167842772699174, 46.90420458393712, 49.27112356308968, 40.74041166613179, 40.281851291656494, 38.665497456827474, 41.8593579722989, 43.831019709187174, 36.88597694520028, 39.77596359868204, 43.31300012526974, 37.876563687478345, 38.350221264746885, 44.075708927646765, 41.54067324053857, 44.82872163095782, 42.294376280999955, 41.70542063251619, 39.974937592783284, 40.862777848397535, 41.37227412193052, 40.83090859074747, 42.13244515080606, 41.954342088391705, 43.699820349293375, 43.24224056736116, 42.92745859392228, 46.235397323485344, 42.32088365862447, 39.27912873606528, 39.35598757959182, 40.35529375076294, 38.81984272310811, 37.492493044945505, 37.019404211351954, 36.87550029447002, 37.08307604635916, 37.831068115849654, 44.76650499528454, 39.48052283256285, 39.54944279886062, 41.86237427496141, 40.659446101034845, 41.15238605007049, 42.0332327196675, 42.30440185916039, 43.4373902505444, 42.946066318019746, 43.477629846142186, 43.811815784823516, 45.12303667683756, 54.68126835361604, 56.75518235852642, 57.329487954416585, 55.892876732733946, 53.272694233925115, 56.05330951752202, 56.644155748428844, 57.39234001405778, 57.3063773493613, 56.43584259094731, 57.841333727682795, 58.810292520830714, 59.59761027366885, 58.4428801844197, 58.88533138459729, 59.336890328315, 60.353192129442775, 60.302758293767134, 63.15119920238372, 62.242170303098625, 63.847113963096376, 61.16277325537897, 59.032910562330684, 56.75022448262861, 50.09822591658562, 56.858022982074374, 59.43599685545891, 70.58920937199747, 69.12095639013475, 78.9980806842927, 22.84734537524562, 0.5850311945522986, 1.3824687850090767, 0.6504027028718303, 0.09717172612586329, 2.6053039681526924, 70.50454108945786, 65.60357093811035, 77.20764421647596, 57.789260341275124, 54.34102235301849, 26.639571305244203, 27.801434224651707, 43.745461048618445, 69.70462860599642, 41.59178564625402, 0.25951743246086184, 0.03501119107128151, 0.05814792738566476, 0.044961374688653216, 0.018218704649517616, 0.010742088704700432, 0.03685485060897566, 0.020624553980005365, 0.03807112244108031, 0.06446054550789057, 0.10947507520717, 0.18184057557054106, 29.95561953513853, 78.63955251632198, 44.634034787454915, 41.51405211417906, 23.11256035681694, 39.40954362192462, 55.374170734036355, 77.81175982567572, 65.55493747034382, 73.41339434346845, 6.658740139776661, 0.31537109505264993, 0.22210589640082853, 0.7723499269735429, 5.7313638637142805, 64.46285939985707, 73.06578605405747, 69.8895134464387, 66.08981147889169, 61.89858244311426, 62.0945244450723, 60.44808210865144, 62.767305066508634, 61.89440511888074, 65.39635604427707, 64.81859876263526, 63.22524570649671, 58.51407120304724, 52.54232537361884, 49.355336850689305, 52.87971588873094, 56.17001179725894, 59.95449496853737, 58.64166982712285, 60.874326075277025, 61.90936896108813, 63.528939139458444, 61.237702292780725, 59.447791422567065, 57.27586523179085, 58.467026295200476, 59.09880638122559, 56.45925129613569, 49.904833455239576, 56.034258565595074, 61.0824627261008, 53.16165193434685, 56.72481536865235, 59.887041968684045, 57.89783547001501, 53.33202400515157, 45.98618953458725, 43.94404280570246, 44.38428963384321, 45.597039422681256, 44.78843104454779, 44.01906597998835, 42.68455405389109, 47.615812747709214, 46.65111757093861, 54.62824575362667, 47.60975268579299, 40.56111620318505, 42.45560138456283, 43.793294352869836, 50.14623572749477, 43.97408423885223, 46.42102741426038, 48.061692099417414, 48.75024457131663, 41.5641603931304, 41.13730845912811, 38.47181866245885, 43.26013442008726, 46.8626666838123, 40.40487250974102, 40.76851544841644, 44.26489268579791, 41.07366015834194, 41.46652867717128, 46.61374522793678, 43.24564518467073, 46.947840952104144, 44.45825376818257, 43.26327623859529, 40.61898685270741, 42.195913022564305, 42.911996610703014, 42.90430876516527, 44.46337638362762, 40.29045304944439, 45.11799250879596, 42.90459117581768, 45.199719013706336, 46.33610025528939, 41.6683110883159, 39.99441216068883, 40.097574418590916, 40.19465308035574, 39.67377016621251, 38.5326507014613, 38.13422810646796, 37.09938918390582, 36.32729414970645, 38.12885445933188, 48.24459222055251, 42.400849019327474, 41.341977734719556, 44.90210525451168, 42.55922255977508, 41.66343558219172, 42.37646364396618, 44.72403749342888, 44.94922076502154, 44.844226760248986, 46.959019707095244, 47.21716265524588, 47.287337779998786, 55.98571138997232, 58.91312137726815, 58.34229100135065, 56.5451668923901, 56.134765378890506, 58.85795324079452, 57.8314297429977, 60.56458826987975, 59.71480677204748, 60.900037211756555, 60.20477748686268, 59.69226883303735, 59.92772479211131, 61.349944837631725, 61.372031704072036, 61.7471436531313, 62.67494501606111, 62.77669914307133, 63.480548858642585, 64.26984740841773, 65.23138507719963, 65.87862322407385, 62.215839432131865, 58.67798313017815, 52.65849028864215, 59.32098511726626, 62.84375598353725, 73.83710445896273, 70.03365270553097, 83.63307491425546, 24.904318663381762, 0.6318815160662897, 0.9645629806383964, 0.6966554145178487, 0.08089367540613299, 3.021325992961084, 77.92037025574716, 70.5452552918465, 83.92436581273233, 64.33033035647485, 63.835440989463564, 47.98481364404002, 36.544338503191554, 53.58578174344955, 77.97820952630813, 52.6205256677443, 0.24773754359733677, 0.022267525294615377, 0.036479245360580184, 0.01130181073676795, 0.028962396393199603, 0.17198798006340382, 0.2029585706130151, 0.2020127891052154, 0.14126929454505444, 0.14249831408021912, 0.3149773565030867, 0.2797034508999317, 44.128174551071666, 89.17234805322464, 56.34608307192403, 53.68627678963446, 42.51880253514936, 58.382079524378625, 61.243334816348174, 83.66000590785858, 72.25072537699054, 81.24096255148612, 6.933162395031222, 0.4376859187839493, 0.6442087900734718, 0.9619179548275087, 7.172371572063816, 68.90413561174947, 73.56848486008184, 72.6800052581295, 70.1440203574396, 67.08152001903903, 65.04587657989995, 64.0077232545422, 64.96691926833122, 64.28759613344747, 68.73471275452646, 66.88177724038401, 66.69691593416276, 61.64416574662732, 55.557549384332475, 49.78766049108198, 53.303088680390395, 58.52327700584166, 59.090836125035445, 60.49368750664496, 67.07927642330047, 65.86851919850996, 64.89559096674766, 64.63573002046155, 61.162871314633286, 60.10826364640267, 59.440786069439305, 61.98820467918151, 59.22015274724653, 54.13462331218105, 58.31633667792044, 65.58238229443951, 51.775380411455714, 54.01391237012802, 63.56421301441809, 62.16701769059705, 56.236244939988666, 47.63915477260467, 46.833954934150945, 46.04556637425577, 46.55900855218211, 47.40189844562162, 45.47970171897642, 45.540855392333, 49.14022622569915, 47.85911736949798, 57.585869758359856, 49.42452353815879, 40.338113769408196, 42.60789132887318, 42.88577556610108, 52.15419507795765, 45.293444048973825, 46.92374975450578, 48.15237729780136, 49.1528719471347, 40.94948184105658, 42.89145123574042, 40.677594907822154, 44.506475387081025, 47.6985159227925, 41.46878011765019, 44.587895947117964, 47.64747019736998, 44.043976952952725, 43.21562336337182, 49.368461101285874, 47.45716856371972, 49.12737261864447, 45.456869602203376, 46.32212485036543, 44.96994656901206, 46.055168336437596, 45.73550301213419, 44.93102881216234, 47.32399232925908, 42.73832974895355, 45.92263929305538, 43.634199096310525, 43.86288896683724, 47.97396044577322, 42.025262463477354, 38.7110597087491, 40.68050922886018, 40.48832093515704, 38.74831830301593, 38.63728384817801, 38.31794015822872, 37.397112769465295, 37.17695797643354, 37.9211296573762, 49.42923822710591, 44.583259705574285, 44.06923309449227, 48.52276279080299, 44.548731080947384, 43.19226564899568, 43.268343940857925, 47.75788491772067, 48.413650297349506, 47.39032353124311, 48.18191666756907, 49.14386226284889, 50.47318881557834, 59.75059447749969, 61.281970162545484, 61.08433761904317, 61.48108143960277, 57.805749985479544, 60.90359087913268, 59.615692400163226, 61.86340270503875, 64.48150242528608, 63.411020924968106, 63.93719119410362, 62.5852325654799, 64.35923822464483, 64.42072922183623, 64.88222745157057, 64.67288271073373, 65.13168234978953, 66.52788531395697, 68.602246469067, 66.15831175158101, 68.3264881564725, 69.7761961721605, 66.40664485193068, 62.48767929692423, 55.12391567230225, 64.13780081656672, 64.87479848246421, 75.42220484825873, 75.85586993925034, 85.44265254851311, 26.92843229539933, 1.2864318802472086, 4.356893281782828, 1.6088510761337897, 0.3986528810233839, 3.6167616421176545, 84.98793217443651, 77.64028949122276, 91.64017000506001, 74.10752050338253, 70.93078505608344, 41.134409827570764, 42.875196933746345, 63.66712031825897, 88.66622894041001, 63.54413047913582, 0.7111115549360553, 0.08948107670632102, 0.20719402559822608, 0.11846690198346493, 0.16962588584471136], [0.09814317924000564, 0.07401754598944418, 0.015596220018191925, 0.08299089472500548, 0.11752008625696744, 0.08959279530831883, 0.06979172839032066, 32.06250694490249, 70.0001556642594, 47.259281066156205, 36.110014454010994, 27.657434209700558, 51.34649276733399, 42.59306476962182, 74.50315429318336, 57.49322729725992, 70.87827236421647, 8.328741212044994, 0.10117855749183124, 0.26943670826092847, 0.07235312804339394, 0.5538440615900102, 42.4472467360958, 72.9884369142594, 64.58233087293564, 64.93153556700676, 63.05372045886133, 60.40513215526458, 57.527273470355624, 61.67186552478422, 60.64538909542946, 60.688272368523386, 61.83437324339344, 60.58958161261774, 55.53605479578818, 54.37182864835186, 54.53195941063666, 52.3060731733999, 52.46419568215647, 56.77875188089187, 57.99585550062118, 61.19272447401478, 59.154837439137125, 57.590239278731815, 55.73309113902431, 52.34898782545521, 53.784626299335116, 50.56286204245783, 48.007171154022224, 48.54026440651187, 53.86269323287472, 53.606134922273704, 57.479083230418546, 38.7866477043398, 34.78615568530175, 54.585880233395486, 54.56862572700747, 51.88114712315222, 46.8317231055229, 47.51735341164374, 41.219764524890536, 42.21800773374496, 43.88714098161267, 45.25437331968739, 42.00013183778332, 43.29791468958701, 42.42194352611419, 45.382638746692294, 55.54038509245842, 44.49259019667103, 42.34792055622224, 43.63208493878765, 47.355214395830714, 50.13561394906814, 47.09990732131466, 47.94847288439351, 46.398199219857496, 42.018574822333555, 38.83223741285263, 39.11083159908172, 41.39286656533518, 42.284962592586396, 43.21075177961781, 39.73982680228449, 43.51441383361817, 39.98355111768169, 41.65688914637412, 41.05640172958374, 39.67779059563914, 41.196289139409224, 44.348431325727894, 40.669879605693204, 41.74845295567667, 39.06973300441619, 41.07109492824924, 40.808249058262, 39.47301933842321, 42.32794000256447, 47.28347816774922, 45.2605196737474, 44.16122836451377, 40.519460631955056, 37.9168934975901, 38.0408247055546, 38.350903757156864, 40.27415560137841, 40.63761811102591, 42.66359290769024, 36.75256144615912, 37.66859962094215, 37.95442665776899, 46.26530147367909, 47.038584986040675, 39.237739886007006, 41.36721818677841, 41.72190243198026, 38.8838283477291, 38.877277989541334, 41.239019440066436, 39.2300755746903, 41.24968828693513, 41.336729603429, 44.105499329105506, 44.68971675442111, 48.25124456036476, 53.7986409279608, 53.91264853938934, 54.82070861324188, 49.868853553648925, 50.52522690065446, 52.16423634559878, 56.65865675095589, 58.20403529751686, 58.578990351769235, 59.561124386325965, 58.64563534336706, 60.19859190910094, 62.68369974628572, 61.158917565499586, 61.46689030431933, 61.774380591607866, 60.644914488638605, 63.9797410657329, 63.08789999254289, 65.82436899985036, 63.73156486019012, 70.47844163833126, 67.15733158972957, 62.599827704891084, 58.84477799938571, 57.63370306261125, 58.222050743718306, 68.56601945815548, 65.53366253452917, 80.11252018713182, 27.685392864288826, 0.2984875284375683, 0.18693155158431302, 0.8866046477229366, 0.1315137930214405, 2.0034420057650535, 66.91404265742149, 69.25133597466254, 74.45476793473767, 60.7673159722359, 56.04219352045367, 18.107184556222734, 14.308122915606345, 40.70056430755123, 63.58155381294989, 49.132840402664684, 0.3841497334501436, 0.027384829835125038, 0.024324115140423663, 0.02177508397688789, 0.025225049861135985, 0.08121301149649006, 0.034225456822182865, 0.02416536640075426, 0.06218810655897664, 0.027495039243912025, 0.06203025797261827, 0.06266097816067838, 39.803855572977376, 78.49522498346145, 52.938771094045336, 41.79213246991558, 28.5854571865451, 54.09255196971279, 49.335438666805146, 81.43005217275312, 62.24458648312477, 77.24801325028943, 8.93095152993356, 0.24999834567068085, 0.6039097460527575, 0.5825304997063453, 0.7496709052112795, 42.370074102955485, 76.29382610321045, 65.68356767777475, 68.18183114451747, 66.912552156756, 62.24193103851811, 59.78686855685327, 62.60150647932484, 62.107887960249386, 63.933633604357325, 63.458159969699004, 63.81011424526092, 56.990148021328835, 54.400740438892, 54.09908663841986, 54.252204202836566, 51.37937007411834, 56.5395853596349, 59.589969496573175, 63.35672747704291, 61.604514506555375, 59.822409152984626, 58.62545082646032, 53.90834962168048, 57.603822446638546, 51.865465487203295, 50.40319019748319, 50.29390511974212, 56.16453224612821, 56.29666513012302, 59.48110411244055, 40.40181698337678, 40.802498863589385, 58.229538548377256, 57.34018818024666, 53.007965626255164, 48.275504419880534, 49.67466092878773, 43.515496407785726, 45.21201564419655, 45.77803719428278, 47.90434621995496, 44.015594682385846, 45.16910491451141, 43.256204205174605, 46.8054549924789, 57.79820726763818, 45.62054618712395, 43.17179872143654, 42.95601737114691, 50.16543572948825, 50.079461297681256, 45.7982530901509, 46.85939934945876, 47.07744390733781, 43.66381299111151, 39.310801875206735, 38.45692934528474, 41.27234389705043, 44.12156927970148, 45.38608651007376, 41.67808171241514, 44.4283260837678, 41.440358623381584, 43.753576432504964, 42.286178527339814, 42.274070170617875, 42.26534289698447, 45.982255397304414, 42.981081316548014, 44.044977157346665, 40.61675502407936, 44.13632131391957, 40.14779252390708, 40.72948786520189, 43.917700167625185, 48.9104655481154, 45.55406593507337, 44.37531525088895, 39.49971106744582, 40.12840032577515, 38.71289145561957, 39.094514539164884, 39.840047282557336, 40.56792151543402, 42.7059898068828, 37.73904931160712, 36.36832606407904, 37.40276098251343, 46.41940747537921, 48.47510991557952, 43.371608180384484, 43.16840979360765, 42.81706740779262, 41.431690185300766, 42.797326118715354, 43.88848635458177, 41.83065406737789, 43.903936570690526, 45.457748213121974, 46.39159394848732, 46.167053945602916, 51.431015922177224, 55.36386666759368, 57.13530709666591, 56.822956992733864, 52.70177756586383, 51.928466596911036, 55.01758021693076, 58.03572639342278, 60.69890591406054, 59.875576880670366, 59.85574145470897, 61.46858084586359, 62.88365041055987, 64.93519121600737, 64.2797710049537, 63.92394927240188, 65.81311179745582, 64.05017506691718, 65.87270044511365, 64.58181704244306, 66.97885590214884, 64.8283419301433, 73.3268197890251, 69.45373812029439, 66.46027934166693, 60.38288054927703, 60.09522961032007, 62.33298101732808, 73.91783468184933, 68.61853215002245, 83.33117008209229, 30.275247596925308, 0.1709163762749203, 1.359595115627012, 1.372205658305076, 0.13163408414731104, 2.027167810067054, 73.29932397411716, 74.01157148422735, 79.63118260906589, 67.93122306946786, 63.269552799963186, 25.592592646998746, 23.695508895381806, 48.461452222639515, 72.78428539153069, 58.58253225203484, 0.47642563680006617, 0.02819387805497935, 0.028441803259474617, 0.020694392470402584, 0.01800028532142601, 0.20430901508417823, 0.1524679831439449, 0.13014244967170302, 0.20888182454772536, 0.2525275389874174, 0.1742783071653497, 0.15711605308517335, 51.49523296663838, 89.58063540920135, 62.796005049059474, 51.67970203584241, 41.14682805153632, 68.84706512574228, 56.92873547154089, 89.61171627044679, 70.51127187667355, 84.54159782778832, 10.932059480297951, 0.33995782896395654, 1.6992988485482432, 0.779592093200453, 0.8665447273562032, 47.74887131106469, 80.07423000950968, 71.41051446237873, 69.8991075638802, 72.52644446588332, 64.37306065713206, 64.04497008169851, 65.66707411120015, 65.41683473894673, 65.55784002427133, 67.06257497110676, 64.55151673286193, 58.48079773687548, 54.398575290556884, 52.490248064841, 52.234576209898925, 52.297800894706484, 60.15075860484954, 61.132994621030754, 66.07753446025234, 64.21518525769635, 63.551167211224964, 60.07463716691541, 56.5809428307318, 59.81994590451641, 55.10131105299919, 54.68444939582579, 52.765516081163966, 59.96895282499252, 60.285982316540135, 63.1082021805548, 43.39789982764952, 42.40453996965962, 59.51066701642929, 59.34542540580996, 56.43032773848503, 51.90550111955213, 50.8851122087048, 45.32610954776887, 46.09473720673592, 48.83374790991507, 50.119591066914225, 45.52718200991231, 47.726380440496634, 46.71773902831539, 48.68421146946569, 60.561964204234464, 45.56592326010428, 44.37402479110226, 43.84777215219314, 48.91171286183019, 50.193312014302904, 46.43022929468463, 46.424961551543205, 47.70347379869031, 45.04365967166039, 39.37559158571305, 40.57973961676321, 42.87490275598342, 45.719409527317175, 48.14383045319588, 44.505102557520715, 47.332519562013694, 44.415409718790364, 46.13234096957792, 45.74836838629938, 44.64215801608178, 45.80254808548958, 47.970069454562285, 44.663464330857806, 47.02794751813335, 42.92554447727819, 46.362670390836655, 43.426980280107074, 42.88672477968278, 43.899123822489095, 49.684494310809725, 45.45925440326814, 45.8058899448764, 40.54931771370673, 39.602665439728774, 37.79209544581752, 39.37121029823057, 40.729064249223285, 39.943111481205115, 42.64193357959871, 38.0140466843882, 37.72164967752273, 37.5594675156378, 46.47108862476964, 52.86709762388661, 45.099851546748994, 45.56834728487077, 46.413319956871774, 43.07322563663606, 45.29015710276943, 46.97885121068647, 43.01201705009707, 46.2633716675543, 46.33946564889724, 48.09948805839785, 48.08560286798785, 53.713086189762244, 57.86610349532097, 57.82870369572794, 58.534400847650346, 54.76658774960426, 54.70195493390484, 56.54978744445309, 60.371697871915764, 64.46334577375843, 62.20753577447707, 63.17774972608013, 64.32599613743444, 65.60648525914839, 67.19755157347649, 65.89487752606793, 66.68921239914434, 65.8904452477732, 65.94853555002521, 68.21046444677538, 69.47880991043584, 68.46927027548513, 68.92317479656589, 74.39364956271264, 70.56885227080315, 69.71033173222696, 62.745653583157456, 64.29237358031735, 65.64261421080559, 77.84594720409763, 71.21810651594593, 86.28003151186051, 32.667618836126024, 0.717370309416325, 3.1914291362608633, 3.276786775358262, 0.3639539397291599, 2.6154646229359413, 80.8825912783223, 80.64259713695895, 87.31578042430263, 75.93590982498662, 72.09947093840569, 23.829226416926232, 27.461602034107333, 59.69573620826968, 81.49104502893265, 75.2751708799793, 1.3274905157666053, 0.22847473771581728, 0.2173941492313339, 0.15803998576537256, 0.3337129253533579], [0.09167583433971291, 0.006787756386573517, 0.03635498972970151, 0.03264346610634558, 0.09192871996351788, 0.007697308160019138, 0.11086989915178669, 37.28589396322928, 69.36417471977973, 47.80548287976173, 53.110598364183986, 26.92011098707876, 36.23195702029813, 49.08200648523147, 72.88381945702338, 57.26322343272548, 68.71173551005703, 11.79014071341484, 0.12218286508634207, 0.18286331827121396, 1.5108393805642284, 0.3922412460369449, 14.044515125213133, 73.57810251174435, 64.99063391839304, 67.69655550679853, 61.41870006438225, 62.2054922196173, 56.65829589290004, 61.30888154429775, 58.44967372955815, 62.74612426757813, 59.18964455204626, 60.39705991744996, 59.11853198082217, 61.50566293347267, 56.62146875935217, 57.65597820281983, 59.38144845347251, 61.05763020053987, 57.515918208706765, 59.308766934179495, 58.170938338002856, 56.99945972811792, 52.97062466221472, 50.80313074973322, 45.582973803243334, 47.86728374419674, 48.47089336764429, 54.153670341737815, 52.83883694679507, 58.71301774055728, 55.596714250503055, 55.73908844301778, 51.13821098881384, 48.48562971238167, 49.95820514617428, 53.03800705940493, 58.199359832271455, 50.91803266156105, 51.26589590503324, 43.44476822883853, 40.4351100613994, 43.26134643247051, 41.45189823642854, 42.44934912650816, 41.867642018102835, 42.65621100702594, 49.79944721344979, 56.74260723975397, 48.0652928352356, 42.06004211979528, 44.918320332804036, 52.925470336791015, 49.13320910546088, 53.20351539119598, 49.12559578495641, 44.04689519636093, 41.19203729014243, 39.41645483816824, 37.39963093111592, 44.55953721077212, 40.602893367890395, 41.83880475259597, 41.618014535596295, 41.73216335235104, 41.334168295706476, 41.13750065526655, 39.970764190919944, 41.40417475854197, 43.43609194601736, 42.4456032629936, 39.577389686338364, 44.21465889100106, 39.80842513422812, 40.11830414495161, 39.08450072811496, 42.44543067870602, 48.01382349383447, 45.08517403756419, 40.72132149050313, 37.863710080423665, 38.606646214762044, 36.91029171789847, 39.590541393526145, 39.406664602218136, 40.51030974234305, 37.67676599564091, 37.70704669337119, 34.82482633283062, 44.0799686216539, 50.743432275710575, 43.34553226347893, 40.35201072692871, 39.918173051649525, 42.3460848869816, 42.03124800036031, 41.176477247668856, 42.320832667812226, 41.42073500540949, 41.4523571537387, 43.528440229354366, 43.09335131799021, 43.62871562280963, 45.045456117199315, 52.644004975595784, 54.16222110871346, 53.86062614379391, 55.952390855358495, 55.99379931726764, 56.03223462258616, 53.82348914300242, 56.21278132161787, 57.04034259242397, 58.16033617142708, 58.16410164679251, 59.755721015314904, 58.93709490376135, 60.734877970910844, 58.623379815009336, 63.4922924349385, 58.27876821640999, 63.30828228304463, 60.369058116789795, 66.22414481255316, 60.54995390676684, 87.52876512465939, 79.52201520243, 61.38914500513385, 62.94589450282436, 56.8715080907268, 59.475977574625325, 70.1991767268027, 67.97731876373291, 82.18524963625016, 30.77655003916833, 0.22501327668226537, 0.6116739552347892, 0.39168957080091205, 0.07777811073127293, 1.194289031047975, 63.83028307268697, 68.80239717421993, 76.10447760551207, 65.96418580701275, 54.467997320236705, 71.66921046472365, 24.220490686355102, 37.26907483993038, 59.68254135501001, 61.43441307929255, 0.9994570598486932, 0.044917359106963685, 0.056114714712865894, 0.038061140315426935, 0.10016836331135805, 0.05886762102525081, 0.03634033063727041, 0.06551704204250729, 0.017237753960334005, 0.029395161376845454, 0.02827472331362867, 0.03966450871479127, 47.15989605073006, 80.49052684537827, 53.808948916773645, 58.26743648898218, 31.802412617591123, 47.07321951466222, 54.444427797871256, 79.93364441779353, 62.76342976477839, 77.58242668644075, 12.395452645517166, 0.08108584856193873, 0.4710950438053378, 2.872713025539152, 1.026776735821078, 13.83765716706553, 76.7961875854, 64.13354112255958, 72.72670499740109, 61.540936808432306, 64.30798853597334, 60.02143021552794, 64.29307176220802, 61.20146743712887, 65.7717582487291, 61.61860366021434, 61.90379919544343, 60.12194879593388, 61.972452440569484, 57.12373610465758, 56.79081709154191, 59.58232087473716, 65.06158567244007, 60.08707892510199, 62.90663157739947, 60.0940489768982, 58.3105041134742, 54.35957908630372, 54.850648064767164, 47.5588010972546, 49.597460839056204, 51.603302109626036, 54.90261946955035, 55.37331957970896, 59.62563953092022, 56.74165018143193, 56.159464543865575, 52.11871331737888, 50.86917169632451, 52.37313001386581, 57.30200390661917, 56.98980285275368, 52.382751587898504, 52.23841621029762, 45.02185913824266, 43.36956462552471, 45.80515646165418, 43.70584510987805, 44.71277636866416, 43.49135421937512, 43.84685431757281, 51.9031673092996, 56.86354175690682, 48.722846815663004, 41.42743833603398, 44.99420250615766, 55.499019776621175, 49.04486948443998, 52.814584932019635, 50.22028223160775, 43.308046171742106, 41.472910373441636, 39.331715952965524, 37.62038192441387, 45.36585492472495, 44.25544761842297, 43.4706990180477, 44.74067226532967, 43.62080420217207, 45.42784014055806, 43.01041280069659, 42.52030872529553, 43.623408655966486, 45.52320080418741, 44.17872998022264, 42.71303438371228, 47.10539471718573, 40.61898685270741, 40.72353370728032, 40.91700069365963, 42.59814423899497, 49.3077467333886, 45.27404008373138, 42.088640120721635, 38.487637581363806, 40.197645848797215, 37.22385383421375, 39.79300629708075, 39.43228944655388, 39.71426863824168, 37.11818125940139, 37.86179596377958, 35.83590745925903, 44.5454990479254, 52.14872729393744, 43.74493937338553, 42.82979549900178, 42.35024259936425, 42.705546579053326, 43.089491705740656, 43.09833272810906, 42.869835053720784, 43.66731174530522, 42.67248884324105, 44.949393349309126, 45.446977384628795, 46.15460434267598, 47.23670782581453, 52.752344762125325, 56.488622003985995, 56.52057755377985, 57.17868851077173, 57.50821075131817, 56.01340332338887, 55.36784002857824, 59.60987552519768, 59.71322605686804, 62.055441948675345, 60.69701533163748, 62.37370698682724, 61.883885322078584, 63.37376233070128, 60.771191273966146, 65.5141761995131, 60.01573101166756, 65.054368511323, 62.26808148045694, 64.93224551600795, 63.964620328718624, 82.11281914864817, 78.60715373869866, 65.19328317334576, 66.42096934779998, 60.427175875633, 61.43709205812024, 73.57464298125237, 71.4652629052439, 84.46541755430161, 35.26426907508604, 0.6300226803268156, 1.5472555232624856, 0.4054657009340102, 0.09362949644245448, 1.3100781339791514, 70.57209999330583, 76.33736441212316, 80.93253874009656, 70.93474664995748, 60.558590965886275, 45.52539340911373, 22.774606981585105, 47.603649477804865, 65.95704709329914, 73.77797865098523, 1.8664486922564048, 0.0979302834058481, 0.07102732095987567, 0.05869675277461929, 0.0989841445980053, 0.20557664545072665, 0.16721983350092368, 0.1952575177194611, 0.0805120180631357, 0.20748163032675945, 0.08173167600386566, 0.18944143948535766, 57.68343479402604, 91.38848720058319, 62.29187065555204, 69.95073380008822, 39.37332053338328, 52.217462908837106, 62.116964324828125, 86.01325542696061, 68.32570368243803, 84.17013368298932, 14.48410495635002, 0.20468269745188378, 1.0062070299060115, 5.135952484223151, 1.326483569798931, 16.880604490157097, 80.42435646057129, 67.11699393487746, 74.03768662483462, 67.54031965809484, 69.32913226466026, 61.19525440277592, 67.33817638889437, 62.97855215687906, 70.09204895265641, 62.763253258120635, 65.05139143236222, 62.24675555383006, 62.270250551162235, 58.47694989173644, 56.88962551855273, 61.8245045600399, 65.71209115366783, 63.237710998904326, 67.04177856445312, 64.66866616279849, 59.822785700521166, 56.99634144383093, 56.63423607426306, 50.78717454787224, 52.686880403949374, 52.047028080109634, 59.1697463681621, 57.4951571033847, 61.901708572141594, 59.318180622593054, 57.19243249585552, 53.82747427109749, 52.79369438848188, 57.26047777360486, 59.618320388178674, 58.420852153531975, 56.271495280727265, 54.81114587476177, 46.93187690550282, 44.34217514530305, 47.805161245407604, 45.45927009274883, 46.193176930950536, 46.389695521323915, 47.699708323324884, 55.1159179595209, 61.19420712993991, 47.864922477353005, 42.582262562167266, 45.624668598175056, 56.40906456978091, 51.57468057447865, 55.574344973410334, 49.39468606825798, 45.46117636465257, 42.45689184434953, 38.44305592198526, 37.73883358124764, 47.55878540777391, 45.89858339678857, 46.345729674062426, 47.904840438596665, 47.309648221538914, 47.31688499450684, 44.73192537984541, 43.92343467281711, 47.66405397845853, 47.592184389791186, 46.82631807942545, 43.93096954591813, 49.29450088931669, 40.55404809213454, 40.60964768932712, 41.500025718442856, 42.538873303321104, 50.306746959686286, 45.24117062168737, 43.46480369567872, 38.743815422058105, 39.8650876937374, 37.18659131757675, 41.35785941154727, 39.056016475923606, 40.95496923692765, 37.71664081081268, 37.78315636419481, 35.50261189860683, 45.743732144755704, 55.02319705101752, 45.48640897197109, 46.144061011652795, 44.63204614577755, 46.78436048569218, 46.617679365219615, 44.7663127991461, 45.55510144079886, 45.45121746678507, 43.80574395579677, 49.35339919982418, 48.625524966947495, 49.00029959217195, 50.38466876552951, 56.25055374637727, 58.75782689740581, 59.158834334342714, 58.56465016641925, 61.421331974767874, 59.93958211714222, 58.39966350986112, 60.952875460347826, 62.09526577303487, 63.51591294811618, 63.74342218522103, 65.27177764523414, 65.20431287827031, 62.9181319667447, 64.98649189549108, 67.94288819836032, 62.05453588116554, 66.97579645341443, 64.90194520642682, 65.53324284092074, 66.29071527911772, 82.22277887405889, 77.53170259537237, 69.20978238505703, 67.91144647905904, 63.92212537027175, 64.50009445990285, 77.36471945239653, 76.60419541020548, 87.66690315738802, 38.296041565556685, 1.0849821351228224, 4.183013631451515, 1.3963733421218012, 0.3955259552646068, 1.5484018359453449, 75.98574746039607, 81.50909577646564, 87.92141791312926, 78.22370283065304, 73.49766254425049, 93.48861048298498, 38.31078967740459, 59.53769214691655, 75.30718526532574, 87.22677400035244, 4.284897686973695, 0.1955257097799932, 0.23367972293448067, 0.1428122262680723, 0.25587724311457527], [0.012831504460454229, 0.014439677188713706, 0.08682614537857233, 0.027435027746363517, 0.006116603035479785, 0.06792740746130867, 0.053990314594439925, 30.828444957733158, 65.46269116863128, 40.27595204691733, 37.57487850804483, 27.635659171688943, 42.560160006246264, 43.96861253246185, 75.73339785298994, 55.92674247680172, 75.33142551299065, 14.464893187246016, 0.12427289850048481, 0.5935315222990128, 1.8250891374003504, 1.7149882066634394, 1.3931417993960844, 58.47408263914047, 67.1468980850712, 69.8851909945088, 62.46137980491885, 66.12644641630112, 56.98683361853323, 63.526942653040734, 60.65371236493511, 66.15330680724114, 59.46684237449401, 62.266845933852665, 55.46094140698833, 55.274385636852635, 53.57676029205323, 59.22026257361136, 60.53286021755588, 60.436522883753625, 54.02267494509297, 54.92421211734895, 51.41616582870484, 49.492666875162435, 49.69434730468258, 49.75802306205996, 51.62559686168548, 49.26604017134636, 50.635610242043775, 54.132101228160245, 55.5038482143033, 58.863456326146284, 54.91482980789677, 48.82458525319254, 51.738796464858524, 51.071040399612926, 50.37460788603752, 48.718426304478804, 67.80400491529896, 63.846333411432084, 52.54323144112864, 53.26142134204988, 40.29793693173317, 42.28055384851272, 41.16457677656605, 41.79780421718475, 42.67963147932484, 44.586075967358006, 44.420504877644206, 52.557179389461396, 52.96390171973936, 46.39595562411893, 45.296421127934615, 55.284062124067745, 51.73839638310095, 50.33790234596499, 47.70832969296364, 49.93498471475417, 48.04128400741085, 42.9637405180162, 41.57461350963962, 40.25763850058279, 42.08383521726055, 44.73543590114963, 39.744561103082475, 42.644541955763295, 41.94929792035011, 41.475514827236054, 40.459448368318625, 42.800483626704064, 40.35678425142842, 42.61572430210729, 45.49070396730977, 43.78781480173911, 39.17804141198435, 40.507870028095866, 39.256069121822236, 43.853059507185414, 44.489558204527825, 45.56195774386006, 40.97185896288964, 41.58734552321896, 38.93396016090147, 41.73789393517279, 43.09477513836276, 40.38462131254135, 40.10203023110667, 39.41919265254852, 37.06147163145004, 38.80067802244617, 52.81656572895666, 44.840735850795625, 38.76113660873906, 41.39001500221991, 41.24228677441997, 41.08312091519756, 40.504575237151116, 43.13473232330815, 41.993757986253314, 42.91032960337978, 44.618360996246345, 49.04762691067111, 53.06713850267472, 49.26715020210513, 45.001882506955056, 44.862069622162856, 50.588526110495295, 54.66553964922505, 52.2364354133606, 54.5588315686872, 54.128551483154304, 56.02081660301455, 54.59405837520477, 55.78265813089187, 56.59935835869082, 59.14413329093688, 62.79179242349441, 61.393996977037006, 58.870677409633515, 61.40739579354564, 59.490023582212395, 63.380285232297844, 60.402002103867076, 61.508400747852946, 59.11768082649478, 61.965050928054325, 65.70654884461435, 59.83276813260971, 72.33251463982367, 69.14177633100941, 64.66644217891078, 58.18984416223342, 68.14675731043663, 64.90796996701148, 79.90649377146076, 32.943500703380955, 0.13704966693635912, 0.9559863505344238, 0.441089065204705, 0.06715330625734023, 1.0403096483599756, 56.568599131799516, 72.85768078219506, 70.05976784613826, 72.17052075170702, 47.48604897529849, 37.974991644582445, 20.747226015214, 41.883366800123646, 52.61265739317864, 68.7911242823447, 3.8721052437059345, 0.20514814183115962, 0.05049463241331039, 0.021845045041352994, 0.01663795308089785, 0.031241132584851117, 0.011886703545197606, 0.0384599925018847, 0.0011568612347717488, 0.11135746815031576, 0.051973331494316946, 0.034289019137260415, 39.10693276313044, 73.28209692432036, 46.8500994097802, 49.74930755553707, 33.4071405472294, 46.376057440234774, 50.46603833475421, 82.52127908891248, 60.81556112535539, 83.36806389593309, 14.47905098238299, 0.054210047763321674, 0.9409902713471844, 5.824162239028562, 5.420835210431007, 0.6487729580652329, 63.354809438028646, 68.39562385312973, 74.5148664905179, 62.263884544372566, 68.12687873840332, 59.9461873885124, 65.67418536832257, 63.89276250716179, 67.3176702376335, 61.466721642401914, 63.59920840109549, 56.2566138082935, 56.563802073078776, 53.9001008772081, 64.12160142775505, 62.06772681205504, 61.09392781411449, 57.85194373899891, 57.44873193002517, 53.137898060583304, 53.79471463541831, 52.39482856565907, 54.33090656034408, 54.40228977511006, 52.0554768654608, 52.33719325834706, 58.20088171189832, 56.734829179702274, 59.577774847707445, 54.96660117180117, 51.099140259527395, 53.603565769810835, 54.40076005074286, 52.754588357863895, 53.977457861746515, 65.62519496487033, 63.645390387504335, 55.568657536660474, 54.559965133667, 41.90118612781648, 44.72206454123221, 42.77091680034515, 43.933350424612726, 44.313965459023755, 46.17296103508242, 46.752569675445564, 54.48438498281664, 53.828827488806944, 45.81538992543375, 46.12299396145729, 54.54127896216608, 53.19543138627083, 51.424826422045314, 49.6264353875191, 52.82042141883604, 49.40091086972145, 44.78032350540162, 42.57870497242097, 42.183894880356334, 45.49733669527116, 44.79003529394827, 41.336200083455736, 45.39302126053841, 43.217698297192975, 45.03643074343282, 42.57451980344711, 44.924741252776116, 42.810179725770034, 43.60284366915303, 46.08495089315599, 45.70253941320604, 39.86384038002261, 40.30908430776289, 38.60002525391118, 45.12080092583933, 44.75711484109202, 46.84009344347062, 41.294489599043324, 41.61861073586249, 37.99685885829311, 41.940127418887236, 42.268527861564394, 40.440252288695305, 39.820309915850245, 38.18648192190355, 37.02640956447971, 41.19964668827672, 54.27860567646643, 46.8218622669097, 40.72540467785251, 42.817757744942945, 44.191073679154925, 45.87905783807078, 42.95532311162641, 43.85807621863581, 44.4896052729699, 43.86725064246885, 45.86448623288063, 52.81375731191328, 54.21661653826314, 51.464477662117254, 46.27231859391736, 48.676633450292776, 53.02027010148572, 55.748772774973226, 55.1083948535304, 56.680151339500185, 57.08375538549116, 57.5079361854061, 56.280230399101015, 58.60869838345436, 60.88706593359671, 61.73420767630301, 64.75661354680216, 63.20155066828575, 62.91517449963478, 63.03243767830634, 60.604965148433564, 66.04637515160346, 62.58152200329689, 60.49522115338234, 61.10018399453933, 61.84111579771965, 65.90233787413567, 61.948969210347826, 72.82477209644934, 71.06789542782691, 69.30282885028471, 61.08616936591364, 70.29517281439998, 67.1545623963879, 82.75749206542969, 36.92915047368696, 0.23466877308824372, 2.3398136852249025, 0.4883578239429382, 0.02321317273702833, 1.2960454869654872, 61.47877900831161, 78.3362905440792, 76.39724331517374, 76.22005416500953, 55.19409079705515, 54.40382734421761, 33.54248193002517, 54.13082253548407, 62.38530935779695, 81.6141603839013, 5.565177942475965, 0.25212753383863357, 0.12243481608287943, 0.05083277979264817, 0.056914579453727895, 0.1883256017801262, 0.17284379220537602, 0.16365663599102728, 0.12940915031058173, 0.17362109565686795, 0.19383008141190777, 0.2398234876173158, 49.42237800167453, 85.78890369784448, 54.8349585840779, 51.91762124338458, 37.46768013123543, 57.36089437238632, 59.136512125692065, 89.57989800360896, 66.26595727859005, 91.90914261725642, 17.33810974705604, 0.2946726863663043, 2.3846838839592475, 8.79334399777074, 5.73769849154257, 1.5775696837132978, 70.42706643381428, 68.15836752614668, 77.37658854453795, 65.70480338988766, 71.71649071478075, 62.09060991964033, 69.56190924490653, 65.6001074852482, 72.46361594046317, 61.42553283322243, 64.63866003098028, 55.57604335969495, 57.416862672375096, 55.73389522490963, 65.15007826589769, 65.45372463041737, 65.95232455961167, 58.73543016372189, 60.58387456401702, 55.89674418972385, 56.56787741568781, 55.22064132075156, 54.909244352771395, 57.95382338185465, 53.392797208601436, 55.00737813211257, 61.15938824992026, 58.22589466648718, 63.45005243055282, 57.5997196474383, 55.02781760308051, 56.25220898658999, 55.10657095140027, 53.693258608541186, 57.583414354631984, 67.03843670506632, 64.23799384024836, 59.028846986832164, 57.96167988930979, 44.15332478861655, 46.3996857981528, 44.3923108808456, 45.59201878886069, 47.763835153272076, 50.15707715865105, 50.50383429373465, 56.71042027011995, 55.97279894736506, 47.078149933968824, 45.543538293530865, 55.913108318082756, 54.514795118762606, 52.68545658357682, 50.94755634184807, 52.16345971630466, 49.98100196161578, 45.0405845334453, 42.04668252698837, 41.963665562291304, 47.72467813184185, 48.1735816309529, 42.95812368392945, 45.8909426196929, 45.740339294556655, 48.170012274096095, 45.8813367351409, 47.369872293164654, 45.53495614759384, 45.16058160412697, 50.07447204282207, 47.91976505710233, 39.972348828469556, 41.5860079949902, 39.211358024228005, 46.21349088607296, 44.394530942363126, 47.190164981349824, 43.28519444311819, 42.34286462107013, 40.395505889769524, 43.49433129833591, 44.55752895724389, 42.0143033612159, 41.95167487667453, 39.261631042726584, 36.794593564925655, 41.210158640338534, 56.22425425437189, 48.47286631984096, 42.7714620097991, 44.81080424401068, 45.03952941586895, 47.675013080719985, 46.33755937699349, 46.64899164630521, 45.72258272478658, 47.14537151398198, 47.36322779809275, 54.69221961113715, 58.10266556278352, 54.5322222094382, 49.67154656687091, 50.976962351029925, 54.90067397394488, 59.69484583024056, 57.722631039157996, 60.46196729906144, 59.407547904599106, 59.19352769851685, 57.05032502451251, 62.726363366650006, 61.78834030705114, 64.91827403345417, 67.49966036888861, 63.551700653568396, 65.92519744749993, 64.6805234878294, 65.18305755430653, 69.16131757920789, 64.96304004423081, 63.82989083566974, 62.98135665155227, 62.18599019512054, 70.2656138327814, 69.71823138575401, 74.23754707459481, 76.4811820368613, 72.18448438952046, 66.27752042585804, 74.3421253081291, 72.69391398276053, 85.83605058731573, 39.5706549767525, 0.5367238963803938, 5.615855945694832, 2.2040626598942668, 0.22950595334893276, 1.8122522004189032, 68.2130689005698, 84.20585863051876, 83.3795956642397, 86.59473896026613, 66.9716779647335, 55.08830055113762, 32.527292120841246, 59.333387651751124, 69.46808615038472, 95.9593192992672, 9.190186858177185, 0.6210782054451205, 0.42067475256419956, 0.13589249112673346, 0.16867097256885422], [0.040562252679298964, 0.025108633224942514, 0.03236572092939769, 0.029337779476097035, 0.031930176961806514, 0.08660341297546703, 0.03906146345299579, 28.67297310982981, 69.67838010480328, 39.44940666998587, 42.65353595056842, 27.773567745762488, 48.281725298973825, 47.830974363511615, 72.22161354557161, 57.98306072911909, 71.42254044932704, 18.769745442175097, 0.3122189190358885, 0.8284509746778397, 1.3981371829586646, 2.1231608333126193, 0.29864690536933564, 21.214395992217526, 70.67989457038142, 68.00438311792189, 64.3132798133358, 59.223490684263176, 63.58988492719589, 64.26024152386573, 63.632909405616026, 63.64220934529459, 61.32759517238986, 60.687840907804436, 57.66585473091372, 58.824593482478974, 61.43434639899962, 62.60718999370452, 58.842542248387495, 57.53024662694624, 54.2983744221349, 51.86584987948018, 52.468698563114295, 54.04786440633959, 55.49671342295986, 57.62357550282633, 55.03194785887196, 52.82803473934051, 54.71155297371649, 56.052156340691354, 53.5673701378607, 55.2662310292644, 52.49479016950054, 58.64594521061067, 53.88945164219026, 49.688079357147224, 53.393228669320386, 51.62686770962131, 59.95417725655341, 59.63128774396835, 55.64137043491487, 54.53523851210072, 42.86697564586517, 41.357486786380896, 42.502716895072695, 41.36853218078613, 40.99227489963655, 43.749293204276796, 40.924747374749955, 43.35865259170533, 53.47874418381722, 49.43714180300313, 43.48212488235966, 49.35787070182062, 49.23678713460123, 51.96638414936682, 47.55200755211615, 48.2618231927195, 51.913192887460035, 45.282928174541844, 38.713879892902995, 40.7800119153915, 44.63635683059693, 45.14421747576806, 41.74000024795532, 43.642577278998594, 41.78935150946341, 45.190881913708104, 42.25569778873075, 42.027808081719186, 41.384853163073146, 42.37935835315336, 46.081781618056766, 43.43886506172919, 39.177198102397305, 40.373540616804554, 37.57079139832528, 46.940584567285356, 44.2475518872661, 44.39118908297631, 43.198957212509654, 42.771116841223936, 41.72595424036826, 43.298263780532345, 44.15722754693801, 40.30767225450085, 37.53621178288614, 39.4563727994119, 40.11087125347507, 50.724585287032596, 49.50470462922127, 40.68978171194754, 39.51160369380828, 42.231477152916696, 39.797367972712365, 41.73932167791551, 40.811018251603656, 41.7165405519547, 41.665898830659934, 44.61113991275911, 49.31822338411885, 55.54617058846259, 53.21702011169926, 52.61755643352386, 49.49405931657361, 50.782420635223396, 50.48989811251241, 51.27250509877359, 53.71097595460954, 56.23238925010928, 55.419117173840924, 59.78467987429712, 56.57034066415603, 58.18565114851921, 53.026361542363325, 62.405980248605054, 55.55892613626296, 46.073285764263524, 61.99912455774123, 59.45674619367046, 60.67950587118826, 60.574029414884514, 63.341547904476045, 63.05029230733072, 57.02246442917855, 61.21518396562146, 51.92613670902868, 50.313101199365434, 63.193643170018355, 64.52852772128198, 68.70224337424003, 56.804969003123624, 66.48807325670796, 66.3141082948254, 80.46448230743408, 35.14156556898548, 0.17277721916475605, 0.5539136223735348, 0.26750990520081214, 0.03802896845304678, 1.393827846454036, 60.151378339336766, 69.54461943718695, 75.26429022512129, 67.21810479317942, 55.10429205433015, 29.035374618345692, 7.764707323043578, 29.846563916052546, 52.92644308459375, 75.64906689428514, 6.654938382487144, 0.4006714307733121, 0.12346836828416395, 0.016562435963761904, 0.02223497230349289, 0.1356459793544585, 0.04761759304411469, 0.06984328610762473, 0.08301638247024629, 0.07359392234995481, 0.04106418582640829, 0.1908525734418823, 39.02533177406558, 76.11968071229997, 44.97419449590868, 40.103387371186294, 36.01513624191284, 55.04797858576621, 53.71699287045387, 77.23145300342192, 64.19212956582346, 79.03536673515075, 20.834545819990097, 0.35072568503599016, 1.0429145924506649, 2.1098463477626925, 4.8194378037606525, 0.6320241922813078, 20.396562199438772, 75.66733729454779, 67.69312735526793, 66.94429197619039, 61.33233731792819, 66.98381377804664, 65.24412493551931, 66.0958597736974, 64.70292022151332, 63.808070690401145, 60.77975773042249, 60.87596170363888, 60.66359281539918, 62.4850199299474, 64.80085788234588, 61.11196287216679, 60.354941506539625, 55.832601670295965, 52.54616929638771, 54.16580223268079, 56.19950802095475, 56.08204087903423, 60.73240295533211, 57.78004669374036, 54.06840978130218, 58.1138050940729, 59.39101511432279, 57.47575706051242, 57.05308637311382, 54.812012718569854, 59.51449524971747, 56.271546271539506, 51.9178173618932, 56.466288028224824, 52.54520831569549, 62.9833492155998, 61.78768919360254, 57.99373742072814, 56.65648375788043, 44.967954004964525, 44.028303161744155, 44.9802702473056, 44.10508748023741, 41.128432135428156, 44.39633915501256, 43.655109251699145, 46.73868056266539, 57.35602671100248, 48.84741736996559, 43.875856322626916, 50.28254985809327, 50.65190769010975, 53.28509676840998, 49.41986376239408, 50.602681944447184, 55.35467655427995, 47.57815407168481, 39.659308387387185, 41.05258526340608, 45.29347150556503, 46.81084432909566, 43.27714181715443, 45.45637146119149, 44.356291755553215, 45.87637885924309, 44.50757365072928, 44.666449254558934, 43.42652920753726, 43.59015480164559, 48.34799766540528, 43.63325772746917, 39.83264184767201, 40.35690976727394, 37.88056842742428, 47.6816418863112, 45.80034371345274, 44.80930982097503, 43.79240005247055, 43.2824448616274, 41.73085328071348, 41.56865935171805, 45.478944701533166, 40.09762540940316, 37.85211163182413, 38.63799379717919, 39.30093319185319, 52.26707304677656, 52.823139621365456, 43.91485252688008, 42.098057731505364, 43.82977631784255, 43.170112102262436, 42.92444229125977, 42.59056621982206, 43.00367024637038, 42.12015244268602, 47.38592263190977, 52.59637563459335, 56.918407870877175, 55.26978077427034, 55.478368497663936, 51.530797096990774, 52.92501141948085, 53.20287604485789, 54.96021163079047, 55.601746651434134, 59.97440884190222, 55.714510871518044, 62.899261443845695, 59.502590856244495, 60.44220247576314, 54.15940876929991, 63.26446940821987, 60.22518165649907, 47.25745324165591, 63.988833119792325, 61.980689417931345, 61.26631990555794, 60.990263492830344, 64.99886697338474, 63.82073602368755, 60.451298452192745, 59.652852935175744, 54.87915585117956, 51.96575657013924, 63.38631391525269, 68.0466741131198, 71.3319964562693, 59.523826568357414, 69.10843618454473, 68.78946119739165, 84.24752989122945, 35.99462224591163, 0.2838303971915476, 1.2970568455996052, 1.452197372432678, 0.04878828264472466, 1.6484313458204272, 66.73775565239691, 76.03991539247575, 80.80047253639468, 73.76732549359723, 61.077869630629024, 35.09546595235025, 16.01412546250128, 37.89130003221574, 59.15190350624823, 86.75561889525383, 9.826608088708694, 0.48520635272706714, 0.2260615301108168, 0.09799680282031337, 0.04043918448470293, 0.22662437490878568, 0.16218953165075473, 0.201975419336269, 0.3136932399244078, 0.2022023192576824, 0.12098874851700761, 0.3560235201110763, 50.49369496683921, 86.1793678037582, 55.19978607854536, 59.02136702691356, 40.09385601166756, 62.34128859735305, 63.5557524619564, 83.88063923005136, 68.79884350684382, 85.950803449077, 24.063031058157645, 0.43092522349569107, 2.577549276813384, 4.053850717121556, 6.6708862493115095, 0.7808788757651084, 26.567227109786003, 75.72953039600004, 71.5151789880568, 69.40215895252844, 66.33060578377017, 69.12037587934925, 69.27935738717356, 68.69828178036597, 66.67182060980028, 64.24508940789008, 62.66313868184244, 60.59297838518697, 62.279734842238895, 65.54798703039846, 66.0333921063331, 62.80277113760672, 62.767301144138465, 59.1812506798775, 58.64813389316682, 58.21503362348003, 58.513561294924834, 59.04247330081079, 62.41680991265082, 61.335004529645374, 57.23947740370228, 59.43278443428778, 59.51361663879887, 59.97888426626883, 61.510934598984264, 58.79753697303034, 64.9179994675421, 59.56841999484647, 55.68894486273489, 59.64918159669446, 56.50864962608584, 64.60164070129395, 61.42375992190454, 59.96527364177089, 60.64075285388578, 46.918462399513494, 46.37939537725141, 47.672483151958836, 46.36527876700125, 44.619431803303385, 49.38170694535779, 46.24603871376284, 48.54786988227598, 57.89947894311721, 52.287775316546046, 45.216891150320734, 50.38288408710111, 51.578559798579064, 56.10721857317033, 49.82236169999646, 51.39130976892287, 56.33755976153959, 48.54562628653742, 38.79024451778781, 41.021504402160645, 46.40751877138692, 49.95297270436441, 45.099831934898134, 47.8297858853494, 46.16248046198199, 50.10714146398729, 47.84946049413374, 48.08726987531109, 46.04214998983568, 46.38854626686343, 51.58307836901758, 45.811134153796786, 40.55770374113514, 42.74140488716864, 37.157926636357466, 47.677315512011134, 45.650842574334916, 46.23591899871827, 43.21297968587568, 43.92253645004765, 44.543600620762, 43.15090033315843, 45.081181064728774, 40.33218706807783, 38.27249949978244, 40.572428318762014, 40.08494046426589, 56.20675263866302, 54.369675267127256, 46.49349712556409, 44.44227010973039, 47.3876327853049, 45.318139291578724, 45.24583431982225, 46.19333382575743, 45.04801742492184, 43.746814266327895, 50.17968570032428, 53.448016335887296, 59.40033858822238, 56.832060813903816, 57.27468852073916, 55.43031554068289, 55.320042025658395, 57.083390605065134, 57.321627524591264, 58.38220111785397, 63.55563086848106, 58.77832912629651, 65.37831314148443, 59.98185742285944, 62.14704498167961, 56.321128952887754, 68.56121847706457, 56.177072063569106, 46.16419453774729, 65.33298623177313, 64.74217922456803, 65.87360259025328, 62.70056593802668, 68.38767713116061, 65.95558797159504, 62.957563554086995, 58.28945667512956, 57.15609565857918, 54.37415069149387, 64.25400887766193, 71.1715244477795, 74.9068210970971, 63.51910575743645, 70.66864521272721, 72.67637314334993, 87.69483827775525, 41.140242392017, 0.5813930736434075, 3.601024602690051, 2.3979297280311584, 0.29598812061932783, 2.4070590446072244, 74.84877786328717, 81.33621338875064, 90.10160461548837, 82.80189329578032, 73.99965532364385, 38.63815461435626, 16.63826673261581, 47.48401718754923, 70.25763573185091, 100.84042656806209, 14.831561253916833, 0.7411131515137611, 0.3579519166340751, 0.24341579646833483, 0.17071826593770137], [0.019592765696166504, 0.015296564726609618, 0.0429040264157999, 0.058298846706748016, 0.11477350783083709, 0.04852762888936747, 0.06330651065875446, 31.889716732886534, 67.01209406698904, 41.8988876188955, 55.56646100936398, 23.609405025359123, 40.849790880757, 47.801595810920965, 73.63725969868322, 59.360518686233036, 71.44754948154574, 22.6860555525749, 0.1722384295276096, 0.2271745945777624, 0.6117780206184233, 5.336945028074327, 0.6099261103137847, 1.3585194056072545, 48.0178713798523, 57.882589217155214, 62.932676115343654, 65.88529125336679, 62.21123456954957, 62.4287849087869, 61.06321957803542, 61.28218197053479, 60.08015986411803, 61.448086461713245, 59.423402124835604, 59.76871190532562, 60.06654139487975, 59.44568118741436, 56.09730282137471, 54.108264984623084, 52.27347435489778, 53.14336192223334, 53.00377653491113, 57.80038810545399, 61.56297660643055, 63.715812621578095, 57.37413237171789, 56.7990932926055, 52.76668102510514, 54.044389186366914, 54.44225088242562, 56.898615590987674, 53.463121383420884, 53.02165077578638, 51.84501817149501, 53.693846964067035, 50.584831237792976, 61.60682478258687, 56.89011581482426, 47.37136279383014, 56.805910371964984, 50.56852594498665, 44.61935335589994, 41.21114707762196, 40.90958741403396, 39.6174527752784, 42.85551055785149, 41.63991705063851, 42.70452676280853, 42.66932741288216, 51.04379561639602, 53.764375102135446, 47.10215091705323, 42.52543918548092, 42.985286097372736, 51.34415895708146, 52.28692023984848, 47.61954292174309, 54.38121488017421, 52.750705211393296, 47.808942410253714, 42.754858616859686, 40.467850085227724, 44.831514358520515, 43.52449040259085, 40.65540605975736, 44.71651830980855, 44.028911129120864, 44.70425698064989, 46.40065854595554, 44.83726063082295, 42.75705514415618, 45.91226854631978, 42.103188191690755, 39.155825107328354, 39.691428676728286, 39.583073200718054, 44.24239004811933, 43.61789772587438, 43.87235364606304, 42.85247856570829, 43.5639141451928, 46.883353264101096, 49.67377055075861, 43.12916648003363, 41.36784184363581, 37.19232582276867, 43.29171342234458, 48.58666604565036, 52.591962968149495, 43.17596427855953, 39.253323462701616, 39.58055111669725, 44.69608276121078, 40.22943665904384, 40.53135325831752, 40.28077263985911, 41.797525728902514, 41.3109713985074, 46.33571978538267, 53.43216996039114, 54.44368646990869, 50.180544699392016, 50.16741652642527, 55.15640074206937, 54.60748072593443, 52.53966600664201, 53.31493423831079, 50.65043680129513, 52.804316166908514, 52.688057115001065, 58.21045229511877, 55.68543826380084, 59.303738455618586, 57.520499537068034, 61.57890142933015, 37.30805143233269, 47.69276572811989, 58.04889771246142, 56.82948773907077, 64.20077054731308, 62.701028777707016, 60.96962790335379, 59.404096218847464, 59.50282227608466, 57.33153935401671, 52.99550817858789, 54.85807311150336, 67.88866535309823, 80.23671811626804, 71.32743866212907, 60.883367138524214, 66.67225991525959, 64.65320025720905, 79.71741199493408, 33.06137184942923, 0.16111403613561587, 0.7644721529176159, 0.5602545627663212, 0.10266930330544712, 1.736058443784714, 64.86236849138814, 69.14664791476342, 73.30639208516767, 67.61957506979665, 49.61362100416615, 52.45816699920162, 33.97662555017779, 33.345402440717145, 43.64824118152742, 66.77413955811532, 10.207816381608287, 0.3879835745019298, 0.0333127549909536, 0.13054009526968002, 0.08397346377492913, 0.00619491350070964, 0.04855280253855933, 0.04808636990586116, 0.07686890992185763, 0.04026549703051006, 0.054600561082723646, 0.06339314754211134, 41.25718001396426, 76.03903678155716, 48.43722766445529, 60.58316853738601, 30.281309620026622, 48.96606906767815, 52.82927420831496, 77.84027545682846, 63.90745570582729, 81.03421441970333, 24.276829650325162, 0.1286631338899174, 0.6534823150404039, 3.8771378897851516, 10.204633378213453, 0.5718276385338076, 1.1273112508558458, 53.47314303921115, 57.14439915072534, 65.79198591170773, 66.4585848777525, 65.31040906906128, 64.83816746742495, 61.954515441771484, 62.02953861605737, 62.59086116667717, 61.707206080036784, 60.079681334957, 61.03649254768126, 61.2658727553583, 58.73267273749075, 57.63032197952271, 54.33492306740054, 53.503713992334184, 56.09100741724814, 56.95348170495803, 58.28982145555558, 62.96159967299431, 66.48223676989156, 57.73064836379021, 59.04172805047805, 56.92686057859852, 57.24375670956027, 55.91530092300908, 58.36538591692525, 54.96364762706142, 54.85934003706902, 55.4137945175171, 54.19861285917221, 53.62500544517271, 58.678540106742616, 58.9070495482414, 50.44019776005899, 59.40727726105721, 53.87002414272678, 45.56835120724094, 44.102310442155414, 43.9617052385884, 42.29449002973495, 44.805293313918575, 42.59439445311024, 43.94295238679455, 44.644715401434134, 52.20595859712171, 57.36038054189375, 48.480973858987134, 42.26493104811638, 43.7402678305103, 52.482940689209975, 52.09270800313642, 48.84389115918068, 54.35859849376064, 53.79860562662925, 48.41875722331386, 43.04336463251422, 40.376909932782574, 45.45568896878151, 45.44012892630793, 42.689056934848914, 48.74585936146398, 48.0577265831732, 46.38944841200306, 47.93440334258541, 47.765725735695135, 44.29831912440639, 46.74853747890842, 43.84169247842605, 38.26085790511101, 40.92065634266023, 38.32170171122397, 46.61917378825527, 45.48583238355575, 44.90156788979807, 42.35616145595428, 45.00551069936445, 49.235473140593506, 52.2634683885882, 46.24697616023403, 41.82257006245275, 36.403141021728516, 43.3939931469579, 49.83453281464116, 54.68321384922151, 46.00206336667461, 41.896522429681596, 41.308515994779526, 45.83764937616164, 43.2655982817373, 43.9262705464517, 41.27397560304211, 45.33116156055082, 43.84390469520323, 48.6021750973117, 55.463436034417924, 56.64506181593865, 50.997962720932506, 51.73187348150438, 58.96355129057362, 56.078149887823294, 54.86812222388483, 54.09842375786074, 52.70922614682106, 55.039851434769176, 55.07217176498906, 60.56171709491361, 57.89086149584863, 60.8132351598432, 59.16395694978776, 62.75527123481997, 41.98318327626875, 48.78933099008376, 59.23441448519307, 58.4990720595083, 64.80657669805711, 65.22621147094235, 63.59282278245496, 61.05447661492133, 60.153857277285674, 56.43482277470251, 55.28038294084611, 58.2347317664854, 63.64520995847641, 74.94405223477271, 74.60368464069983, 62.652952286504934, 70.77085433467742, 69.0294082703129, 83.53045002106698, 36.408432299090975, 0.1201653648768702, 1.7194747852702297, 1.3173996056279829, 0.18411248591878723, 2.6598170688075404, 69.91832717772454, 75.63642901758995, 78.20586389110935, 74.70598005479383, 58.005139750819055, 45.428048026177194, 22.970652926352717, 38.13717772883754, 52.89119274385514, 80.60707615267846, 14.026318269391215, 0.5308559080285411, 0.12667526596135673, 0.07032592916080067, 0.05046093986640054, 0.21718128404069334, 0.11007188834370145, 0.2562309765527325, 0.19492480573394608, 0.1881898356781852, 0.15690545551478863, 0.35973772887260685, 54.04410677571451, 85.74888767734652, 54.72184135067848, 73.22924690861856, 32.95888031682661, 54.12613138075798, 63.03862325606808, 84.74117586689611, 70.57897198584773, 87.50977300828504, 28.15837383270264, 0.3042150469076249, 1.0449820492536792, 8.045486269458648, 13.450731039047243, 0.9809107453592363, 1.8959930875609, 58.310586483247825, 58.349774883639434, 68.67575953083654, 68.67394739581694, 69.03973979334678, 66.1916518980457, 64.69339670673494, 64.78571753348074, 65.68164179402014, 63.813522784940666, 64.73015323761972, 63.90473750329787, 66.06913274334323, 61.841484500515854, 61.20635863273375, 57.69687675660657, 58.50923492062477, 59.84445287335304, 58.81426588181527, 60.582195789583274, 64.6667089000825, 64.35819095180881, 63.07240270799207, 61.20591540490428, 59.65337068803849, 58.94284902080413, 58.49728738107989, 61.4526834795552, 59.156194579216745, 61.43082411058488, 57.23160128439627, 56.38781709055747, 54.986711163674634, 61.35474581872264, 58.68494925960418, 53.925435466151086, 60.844053222287094, 54.70026831473074, 47.81531233941355, 46.826271010983376, 45.36587061420564, 45.23687954871885, 47.0714662151952, 44.444113623711374, 46.71374997785015, 47.3274322479002, 55.10224849947038, 60.265229055958415, 50.33328963864235, 43.615873782865464, 44.78133547690607, 53.5535712395945, 54.654749208881015, 49.8697635435289, 55.921223701969275, 54.556960598115005, 47.36152941180814, 43.11543033969018, 41.99978666920816, 47.1127099375571, 47.81810898934641, 44.86762369832685, 49.923001873877745, 49.85490952768634, 48.725537561601215, 51.8619510435289, 49.67657896780199, 48.74614569448656, 51.407340495817124, 43.733729239433046, 40.13236191964919, 41.34786128997803, 39.24816554592502, 46.256001534000525, 46.050908642430464, 46.44371048096688, 42.19021381870393, 45.05340283916843, 50.208519043460974, 55.167697168165645, 46.03659591367168, 42.432224058335834, 38.63493434844479, 44.436657198013805, 51.599097328801314, 57.32043120168871, 47.05628272025816, 46.050783126584946, 42.63552834910732, 47.93552906282487, 43.52117599979524, 45.84135209360431, 43.090582124648556, 46.57126203660042, 46.27774323186567, 50.95468328845117, 58.11452681018461, 59.21393579052341, 52.51328022249284, 54.326513505751095, 61.148699791200706, 59.15935993194581, 57.22414485869869, 55.9163325063644, 56.063903839357444, 59.10681978348763, 57.417698137221805, 63.39164833868704, 61.230069360425404, 65.03719637470861, 64.11008142655896, 61.65508170281688, 39.10300254821777, 52.83072940764889, 60.326735742630504, 60.25755297753119, 69.69949814581102, 67.88699442340483, 66.59304372725948, 63.93065260302637, 61.94309742219987, 57.012784019593276, 57.842349621557425, 58.05023524069018, 63.97956848144532, 77.80617437055035, 80.30528899162047, 66.23664148392217, 73.96096506426412, 71.69200728016516, 86.50551288358628, 39.29722655204035, 0.28393574960289464, 4.612336168366094, 2.026796165493227, 0.3292955398078888, 3.406744459944387, 80.33613451065557, 78.95986895407401, 85.40549985824093, 82.80543127367574, 68.27095523957284, 70.92942791600382, 49.411830748281176, 51.46167316744405, 62.246469220807484, 95.26881740939234, 20.87322823462948, 0.7387679418729198, 0.2826121335308398, 0.32567758233316485, 0.2745656056269523], [0.06724879145622253, 0.0979904366296626, 0.028578682104125622, 0.045445752930977655, 0.04136830741058915, 0.04061240845570161, 0.3383728849791712, 37.686779806690836, 66.36428325406968, 46.296668667947095, 42.558143907977694, 25.448994674990256, 41.71215926447223, 48.51871882715533, 75.37740353615054, 59.86002468293714, 76.15502911229288, 25.124265570794385, 0.24497941256530825, 0.27666851697910216, 1.0893248117739156, 4.501779262096652, 0.8096940166527226, 0.19965208916654512, 21.527693348546183, 73.54138128219113, 55.945271753495746, 62.77176480139456, 59.680321293492476, 62.76784243122224, 59.99653493204425, 64.55046946002592, 61.4842075686301, 60.612609847899414, 59.95896254816363, 61.986121900620006, 57.54669312507876, 55.33009113803987, 53.17105385564989, 53.53735616130214, 51.847100950056515, 56.498784865102465, 55.85535533966557, 56.98530389416603, 54.59271692460584, 52.668053027122255, 53.10683288881856, 59.28923353072136, 57.33487729103335, 56.432088882692405, 49.3689396304469, 56.6289016508287, 53.17766697176042, 58.145811634679, 51.931251479733376, 54.30556412666075, 51.933906924340036, 64.78435254866078, 47.110988017051454, 45.28425393566009, 59.4404330561238, 48.37058659522764, 43.40598775494484, 39.655221277667636, 42.8284618931432, 40.97644029125091, 42.10114855920115, 42.860315461312574, 42.33765571348129, 39.734343328783595, 44.85797859007313, 51.28744540675994, 49.01723638657601, 44.62263245736399, 43.54401596130864, 43.3042924634872, 50.33973801520563, 52.59925857667, 54.6147684897146, 55.88008196123185, 54.247034518949455, 51.414498821381606, 41.35527064723354, 43.01070305608934, 43.07977599482383, 42.234152209374216, 46.47036298628777, 48.75851292763987, 47.08466106845487, 45.484541923769065, 46.51453671916839, 39.90591564486104, 44.718930567464525, 43.827634703728464, 39.507394990613385, 38.42746057818013, 39.77990950307539, 45.82996937536424, 43.77702436139507, 42.814655150136645, 43.45214228476248, 45.737985872453265, 49.05668758576917, 52.036437680644376, 44.80464220046998, 39.25026793633738, 41.20106266390893, 44.46014435060563, 50.629832590779955, 45.622193582596324, 43.40742726479807, 38.10499860394386, 40.433066506539625, 43.563792551717455, 41.42876409715222, 41.57855156929263, 41.96602682913504, 41.11375462624335, 42.01469167586296, 48.92609619325208, 50.68436530328567, 55.165488873758626, 55.39439055227465, 50.88367269885156, 57.056059529704434, 55.38423161352835, 57.025555256874334, 53.64426428271879, 62.4917075710912, 58.18194843107655, 54.4806508864126, 55.27968475895544, 56.88766433346657, 53.043584669789965, 57.83306929372973, 53.282460935654186, 45.58144407887613, 55.91422619358186, 55.74389726884904, 57.81978422595609, 57.39501899288547, 58.48506135325278, 62.10116109540386, 60.159364285007605, 60.60746369823333, 60.732595151470555, 51.25802763046757, 58.42273881358486, 48.84540911643736, 53.720962309068256, 70.3126116721861, 62.40608615259971, 68.27716042918544, 68.7000076232418, 81.4522998563705, 30.57914499313601, 0.011922432928376142, 0.6200049469067205, 1.2631342271643302, 0.3240886853346902, 3.7734108105782544, 73.59237209443124, 66.76131340765184, 75.621429874051, 63.78351273075227, 49.13514283395583, 31.932549015168224, 20.206654763990834, 36.90214495505057, 51.148558201328406, 68.8703404703448, 10.445603209157145, 0.6074143838017219, 0.1444495400233615, 0.08810280026086877, 0.04123002854025653, 0.02936193614356941, 0.04315245723832519, 0.033055207722129366, 0.061521636877929976, 0.03271855804468355, 0.055568700866593476, 0.2681647878020041, 47.83244525232623, 75.68239919600948, 51.96955734683622, 48.2196145672952, 21.331094349584273, 52.58664031182566, 55.05862389841388, 81.88088940035912, 63.512763284867816, 82.10675516436177, 27.78061624496214, 0.20414038381028562, 0.3771833282324576, 2.79827305866826, 6.258399996065325, 2.3168884121602584, 0.5519673913236588, 27.61485492029498, 72.51066084830993, 55.86313339971728, 64.52475832354638, 62.60721352792556, 64.98067502052554, 62.2911960078824, 65.08810873954528, 61.630794386709894, 64.38960129214873, 61.996288684106645, 63.75624049094416, 58.967634477923, 58.95298050295923, 53.880951866026855, 56.579024791717536, 53.132206701463275, 57.419035665450565, 59.040449357801876, 56.73407608462919, 59.2818320182062, 58.12983582096716, 52.96225040189682, 58.512345360171416, 57.14721541250906, 58.50256296896166, 53.61753725236463, 60.12092897968908, 55.557580763293856, 61.36641486998528, 53.88059493034117, 57.856882003045854, 53.516261654515425, 62.030997737761474, 53.59537586089104, 47.10184889454996, 59.58552152879777, 49.58352858020414, 45.101930402940326, 40.95895436502273, 44.74332770993633, 42.10906390220889, 42.76346429701775, 44.86076347289547, 43.857460406518754, 40.83972215652466, 47.323823667341664, 51.38718735787177, 50.492506488677, 47.05403127977925, 44.85584874306956, 43.23643545950613, 50.99546809350291, 55.41061739767752, 55.22039813380088, 57.71533935300766, 55.19651482182165, 52.30100939350744, 41.53128308634604, 44.5276326517905, 43.73323894316151, 45.216836237138324, 50.77291673229587, 51.1044942948126, 49.51672669379942, 47.84626768481347, 47.24316796948833, 44.62639793272942, 46.619091418481645, 45.28370088146579, 39.65196963279478, 38.2343779840777, 41.57724542002524, 47.4810165743674, 44.03601454150292, 42.66248287693147, 44.13619187570388, 47.13504783568844, 51.344829682380926, 54.05850971898725, 46.3842002807125, 38.26110501443186, 40.4018287504873, 45.637220182726466, 52.98360378511491, 47.98985781208162, 45.360069428720784, 41.814674331295876, 40.988309383392334, 46.94544830629903, 42.0689655119373, 43.479912665582475, 42.760083213929214, 43.43905725786763, 43.1083151601976, 51.05563332957607, 54.20208415677471, 58.46876390518681, 57.14165741397489, 53.69650240867369, 57.33492043710525, 56.753621255197835, 59.827151298522956, 56.68178304549187, 62.761915729891875, 60.21045315650202, 56.50129910438292, 57.49577683787192, 58.14092828381447, 56.76853410659298, 59.41659681258663, 55.96521700582197, 47.42469526106312, 57.787240320636386, 57.65775111413772, 60.4334948139806, 59.64950323104859, 61.04507469361829, 63.30263014762633, 61.8774369455153, 58.30703281587171, 61.14484017895114, 54.214000317358206, 58.69190754428987, 49.53282410098661, 56.01807094389393, 73.96557777158677, 63.530249211096, 70.1652168458508, 70.61126878184658, 82.80895356209048, 33.27848680557744, 0.11861739229531058, 1.4910558034335415, 0.8981198685303812, 0.31595663137493596, 4.526599039954524, 80.29395334182247, 72.56736263152092, 79.98894983722319, 72.18890097833449, 55.864729804377404, 33.167742606132265, 23.615469009645526, 42.68268700568907, 56.6820340771829, 79.77832640371015, 15.290869820502499, 0.499576905802373, 0.201814127184691, 0.07423819463339544, 0.07682225516726894, 0.17151170320087866, 0.16555259635131206, 0.11319015730893421, 0.17511607027582585, 0.1824888238503087, 0.18432574947514843, 0.47740592290797546, 64.03550932484289, 83.24277554788898, 60.00399920248217, 59.646698736375384, 36.62537859332177, 57.65027507658928, 60.64140004496421, 88.07322148353823, 71.06478891065045, 92.13254513279085, 29.934676039603453, 0.2811817860891742, 2.259261194736727, 6.4830807139796605, 17.15138335381785, 4.567152915462371, 0.33043174013014764, 29.79805596413151, 76.07555404786142, 59.1024188841543, 66.22772201415032, 65.81405316629719, 65.83648912368282, 63.069488386954035, 69.1023329765566, 65.47996136449999, 68.07227934560468, 65.48090273334135, 65.51390947834139, 60.908756640649614, 60.83758131150277, 55.68793681360061, 59.89772258266326, 55.59513745769378, 64.28537214955976, 60.568753827002745, 60.800322717235936, 60.25220678698633, 54.02128642605197, 55.348122273722005, 60.5006810926622, 60.29823580095845, 60.68687208237187, 55.95273602393366, 60.91533445542859, 60.99288755847562, 60.61293932699389, 56.05020300034554, 58.20796551242952, 58.468669768302675, 60.57036984351374, 57.704678350879306, 51.972577571868904, 61.40609356664843, 53.64508013571463, 45.90969939385691, 44.456253359394694, 46.59799691169493, 44.08625225866995, 45.095850729173236, 47.2664511588312, 48.498244054855846, 42.25149300790603, 50.34735525808027, 54.96318086501091, 51.76615107444025, 47.894281418092795, 44.02020346733832, 45.017269965141054, 52.03424115334788, 55.68796034782164, 57.36110618037563, 59.355443139230054, 56.68579170780798, 53.17412899386499, 41.4258340866335, 44.883768173956106, 44.58891576336276, 48.0945929404228, 52.92758841668406, 53.20112274539087, 51.59910517354166, 47.51973821270851, 50.299243465546645, 45.4311074749116, 48.52041721343995, 46.08631195560579, 40.87958520458591, 38.71187163937477, 42.266884388462195, 46.95437954318139, 45.86792615152175, 45.2973585744058, 43.93999099731446, 46.84376870432208, 54.7997788460024, 56.33395510335123, 47.03886347432291, 40.124050417254054, 40.8068173931491, 48.29497506541591, 55.474881510580744, 49.28661692527033, 46.735095516327895, 43.615030473278416, 43.156081784156065, 47.90258899811776, 45.92512215337446, 45.65438055223035, 46.3373593361147, 45.85794764180338, 46.69122772832071, 54.33292658098283, 55.13272923807944, 61.28005212353122, 59.00641495181669, 54.582385401571955, 57.64469746620425, 60.00016704682381, 62.13580739113593, 57.625501386580936, 66.4774279440603, 63.31409915801018, 59.01040792465211, 61.76540228628344, 60.981222429583156, 57.34749555587769, 60.47516215232111, 54.74387722630655, 48.84756642003214, 57.456317793938425, 60.462461517703154, 61.524874702576675, 62.03976031272643, 64.70445779062086, 63.95488108358076, 63.49888986156833, 60.47400897549045, 60.96791382758849, 57.62756455329157, 59.320408528850926, 52.81059588155439, 62.51981527574601, 79.05226430585309, 65.96585673670616, 76.61720983443722, 75.20142247599941, 87.36369609832765, 36.85082074134581, 0.31002824465113304, 3.2001448879318857, 3.1428743610458993, 0.6007339745279282, 5.334741636630028, 88.20554656367149, 77.96222194548577, 87.02941602276218, 79.56316086553758, 68.30546425234887, 50.4888939857483, 34.04095242100377, 55.91993324218258, 65.07710256884175, 96.60601615905763, 22.75726814423838, 0.9464006907036229, 0.31563499702080605, 0.1834939312069647, 0.2599919166776442], [0.04570284820792656, 0.08312309085721932, 0.04583796696557153, 0.007512993151096688, 0.1028623421406073, 0.09939790102502993, 0.36683678987526125, 46.33430773212064, 60.26879841281522, 40.33922380016696, 34.06489456853559, 56.393202504804066, 28.02833941675002, 47.56108391669489, 74.42278492835261, 59.10879665805448, 70.76386467103036, 32.359506853165165, 0.06689272911077546, 0.6126446805654034, 2.016549095992119, 9.116174674803212, 0.5957229014846587, 0.10907995769934309, 4.9649969608552995, 61.08157627044186, 62.842783235734515, 67.84395033313383, 60.306982686442716, 65.72942802982946, 62.65638043803554, 62.77746792762511, 58.75599122816517, 62.73685962923112, 56.03810248836395, 58.88292697168166, 57.69188357937721, 54.1074687434781, 47.68785884303432, 51.56117977634553, 55.150474040739006, 57.975259134846354, 53.91970488332934, 58.23162524930893, 54.31916298404817, 46.14320201258506, 46.83836367822463, 49.747679771915564, 52.214591733870975, 56.39674048269949, 54.01198648637342, 52.390537492690555, 53.18873197801652, 51.44319880393244, 55.782238437283425, 53.82063365751698, 56.46124386018323, 58.316787750490256, 39.54714821230981, 59.82682181942848, 51.72671948709796, 47.600939120015795, 40.45493764262046, 41.72616212598739, 38.63521283672702, 41.37092090422108, 42.05035778783983, 43.84177484819966, 41.81474493395898, 44.335875818806315, 41.83958922663043, 50.15734780219294, 46.69144738105036, 45.195620136876265, 44.14228723895165, 46.28533694051927, 45.358731900492025, 50.379899163399976, 53.8685336420613, 60.24308727633569, 51.30979114963163, 53.19908311290126, 41.3346036787956, 42.976660805363814, 43.71214443637479, 42.57286064086422, 42.452032027706025, 47.43099850993003, 44.02432195601925, 46.49223804473878, 45.91538683060677, 43.20529968507829, 45.55506613946731, 40.299392131067094, 38.881059154387444, 39.981711526070875, 40.26202371043544, 50.17771667049777, 42.48900428895028, 45.93007218453192, 50.13156606305031, 46.459760819711995, 50.450980355662686, 47.012187434780984, 39.874826938875266, 45.83492332889188, 44.27695005170761, 46.05584298410724, 48.19169905877883, 44.482886252864716, 38.841388302464644, 41.72087477099511, 40.273755519620835, 43.42262252684563, 41.27503856535881, 38.75204063230945, 42.7150583267212, 42.86144902629238, 42.23799220977291, 50.23517547115203, 52.756357346811605, 51.045764646222516, 50.166890928822184, 53.44652975759199, 56.158068180084236, 54.99201420814761, 54.70635583323818, 51.42883116199125, 33.58004646916544, 47.11672252224338, 57.498977491932536, 54.341402822925204, 54.679993583310036, 57.1382841756267, 56.47093211450885, 53.17847890238608, 48.63868451887562, 56.957321705356726, 54.57203818905739, 62.553630029001546, 60.86970944558421, 65.20884713818951, 58.60017899544009, 60.41415360666091, 65.42109443295386, 55.06894365433724, 59.86546108799597, 60.39132541225803, 52.33107043850807, 55.774405464049316, 71.1686062043713, 62.49412767348751, 68.3855825854886, 65.75924981024959, 75.88944542792537, 25.687074699709495, 0.12616764844184922, 0.7158759476677065, 1.0581936951606505, 0.37188889458775526, 6.753328586778333, 76.68258005572905, 66.46901838241085, 71.6559842325026, 68.85989127620574, 46.80026569674092, 39.33464596348424, 18.6741651258161, 29.432591084511053, 61.03353508057133, 68.02993343722436, 10.644788030655155, 0.3954372729264921, 0.1413204692183964, 0.141684468234739, 0.051264363085670825, 0.06726557644264353, 0.03783602537887712, 0.15177479614653897, 0.03568045314281218, 0.02073737191817453, 0.028055980313389052, 0.11371990710857416, 55.02984154608942, 69.53596668858683, 48.89477214505596, 54.01201786533479, 44.15617635173183, 30.924554794065415, 53.185445031812115, 78.92359487472042, 63.18277820464104, 77.43377670165032, 36.014614566679924, 0.11926862065710368, 0.06972317884285605, 4.894110906508661, 6.386017741695528, 6.096457589057184, 1.0446586988625988, 6.081696239209944, 65.02970857004966, 62.62625271274198, 68.2259185852543, 61.73069323262861, 68.66737350340813, 62.712195765587595, 65.03390550613403, 61.10501243222145, 64.06334638595581, 58.70531420553885, 61.12572646910145, 59.13100511797013, 56.56607704777872, 50.460413655927105, 53.392051958268695, 57.4140581777019, 60.03168721352855, 56.97951055342152, 59.45338864480296, 57.49851857462237, 49.75239446086269, 48.82325164733395, 54.24126471242597, 53.29067045642484, 59.43901315812142, 55.98606048091766, 53.02183904955464, 53.085840363656324, 55.22450485537129, 56.857685658239554, 56.89949812427644, 53.81079243075464, 62.416551036219445, 43.161125952197665, 60.90091974504533, 55.0532227946866, 48.67757481913413, 43.388952901286466, 44.160286995672415, 41.322240368012466, 43.26832432900706, 44.57396761063607, 47.30461189823766, 42.792066220314275, 46.04159301327121, 45.07648991000268, 50.04127310168359, 49.80922568228937, 48.00363317612679, 47.121452900671194, 46.09184641991892, 48.28643606555078, 52.430133819580085, 54.91239793838994, 63.15338004019953, 53.6071978845904, 55.22092373140397, 42.294411582331506, 43.38499915215277, 45.62118553346204, 44.529221211710286, 44.77181980686803, 48.43575677564068, 45.1642882439398, 46.43568531159432, 47.38078432698404, 46.3582577243928, 47.09496121252737, 39.96729289331744, 39.093122097753714, 38.750071602482954, 41.487117198205766, 49.77253583169753, 43.9966300226027, 44.24027196822628, 50.931894317750015, 47.655817001096665, 52.740079510596495, 50.00046084004064, 40.67531993312221, 45.331612633120635, 44.82899619686989, 49.797615466579316, 51.58833434504848, 46.73627222737959, 42.34759499949794, 43.34945071128107, 41.66356109803723, 44.11481103589458, 41.94099426269531, 40.08403439675608, 44.344042193505075, 45.01470865741853, 45.02149828018681, 52.011248219397764, 54.0226435661316, 52.81617349193942, 53.513355178217736, 54.24124117820494, 58.291382558884166, 56.80583192456154, 55.35987761712844, 53.22684564898091, 37.4456246437565, 48.09878595413701, 57.82287897602205, 57.08751693848641, 56.403938031965694, 58.51720125444474, 58.102441987683704, 56.015305672922445, 49.74854269335347, 57.60133958631947, 57.617268331589244, 64.25624462866014, 63.17105031782582, 69.07312700825354, 60.23442668299521, 59.80588028507849, 69.7639819114439, 55.79556272875879, 63.03663853676089, 59.21374751675514, 56.28989904157577, 58.60649401141752, 75.43099095744472, 67.0092228920229, 71.02296075513287, 65.95028492712206, 81.41838704386066, 26.451399518597512, 0.11830761698224854, 1.4788508583461086, 1.350496197419782, 0.35865665623737925, 7.458585942945174, 84.46204431595342, 69.9397825425671, 78.53440161674254, 73.90632644776376, 55.30695307639338, 33.39254540781821, 19.564360764718828, 36.35861427553239, 62.653607322323715, 79.88179068411551, 14.624235553126182, 0.6585027037128326, 0.11434423046246653, 0.06356939372997131, 0.062483827989067764, 0.1729342059021996, 0.15644793248464986, 0.2501314917519208, 0.08993089289194153, 0.2318207033339047, 0.152682411153951, 1.0269416592294172, 70.40565813741377, 78.11216631243306, 55.88024670077909, 48.32252187113608, 70.08388257795765, 44.948954043849824, 59.00963521772816, 88.4547661196801, 67.98678736532888, 87.15956810981997, 40.113228597948634, 0.16964388891093193, 1.2133242934942245, 11.199652398786238, 17.958301190407045, 7.914306521415711, 0.852597208032685, 7.4634766482537795, 69.72890807736304, 61.44786680898359, 72.84029683759137, 63.443964912045395, 72.64966180247646, 65.88751915962466, 66.12519125784597, 61.662561662735484, 67.31508147331976, 61.225507643914995, 65.39940372590097, 62.27120760948428, 59.39350189701204, 53.668716338373, 56.5074219242219, 61.171649579078924, 62.70758698063513, 58.47929546909948, 62.86163414678266, 56.22748236502371, 46.606865390654534, 51.08388616192726, 55.80848301610639, 55.940160905161214, 60.89545980576546, 57.11482840199625, 57.09314161731351, 54.821563689939445, 59.035797426777506, 59.601414972735995, 60.84476317128828, 54.72270427211639, 62.664146730976725, 49.300117723403446, 59.783758117306625, 58.18197981003792, 50.03524441872874, 45.60691202840498, 46.229988375017726, 42.122015568517874, 44.38616452678558, 48.254249095916755, 51.07271132930633, 45.33645283791327, 48.302745280727265, 47.10376693356422, 53.23087000077771, 50.783185497407, 48.55756990371212, 46.87267265012188, 48.780431132162775, 48.033713832978286, 54.75504421418714, 56.39911351665374, 64.80425073254493, 56.218594274213245, 54.930801699238444, 42.60707155350716, 45.58034189285771, 48.77584588143134, 46.30388190669399, 46.061463740564164, 49.80344803102555, 46.61098387933547, 49.120575151135846, 50.24176113067135, 47.891214124618045, 48.56765823979532, 40.44697915354083, 39.410230036704775, 39.42138525747484, 41.390242499689904, 49.878279009173, 44.039862386641964, 45.35074595482119, 53.466592681023386, 48.76434941445628, 53.472939075962195, 50.431411650873, 43.29734202354185, 48.52819135112148, 48.44546856418733, 52.86683874745523, 51.92921184724378, 47.82663229973086, 43.45743356212493, 43.9440937965147, 43.68740997006817, 48.15294604147635, 46.8161238393476, 41.68988020189347, 46.474269666979396, 48.72274483403852, 46.787247350139005, 54.47392794393725, 57.16629774339738, 54.2147377229506, 54.18878339952039, 56.54267226496051, 60.210817936928045, 60.49306384978756, 58.897224010959754, 54.031441442428104, 40.86532738900954, 52.51861464592719, 61.99207605854158, 57.87931403806133, 59.25520304710635, 61.96019111141082, 60.916115007092884, 55.241457339256044, 51.260059418216834, 60.72270685626615, 59.548090350243356, 66.83843504997992, 65.57433751321608, 68.3454724281065, 62.59596809264153, 62.18831616063272, 66.38253796485164, 59.06925132197719, 64.73442077636719, 62.13406585877942, 59.22531850876347, 58.35945921559488, 78.35920503062587, 66.20391322720435, 73.44061559246433, 69.40452806411251, 85.02751673421552, 30.105575669196348, 0.37938221507976133, 3.378007705173185, 3.263652473688126, 0.6980535556231776, 9.3474680185318, 91.90131356639247, 77.9303801444269, 81.30255945267217, 82.51804705589049, 66.91522721321353, 55.14075832982218, 27.849669571845766, 47.62078631308771, 72.83515853266563, 97.21968666199716, 23.368447942118493, 1.107873822892866, 0.32174932860559036, 0.341664059988914, 0.32473563126498656], [0.07824786052468323, 0.07747034256857249, 0.04967004218469224, 0.11935860534468967, 0.009533172274278778, 0.15227872878313065, 0.9876778757860585, 57.857682166561005, 55.15508282569147, 38.07397265588084, 18.224694844215147, 33.59983874905494, 41.53367965452133, 50.77306578236242, 73.35189942390689, 62.23364699271418, 64.48922557215538, 40.89094831097511, 0.08733887270453476, 0.4406606075504134, 2.4931278584464907, 1.9939642111139915, 2.0062978589727036, 0.5396746832036203, 0.045892880147983955, 42.14578513176211, 64.83203288047545, 61.37899391112789, 67.0565188315607, 58.52464199066163, 59.756697685487815, 58.468685457783366, 59.25466568239274, 55.77223247097385, 59.87114460237565, 59.28853534883069, 55.835919995461744, 52.0063413343122, 55.587947753167924, 56.727608096215036, 55.98706853005194, 54.81858268860848, 59.19005247854418, 57.68765918670162, 45.88556112781648, 41.215524442734264, 48.01831853005194, 47.08135058802944, 48.3427809130761, 50.02727024016842, 49.54636020045127, 54.58829641342164, 59.40212326665079, 64.03270483016968, 55.88675391289496, 49.47761674081126, 64.07033212723272, 40.50959194860151, 52.977547645568855, 58.56388530423565, 50.694390881446104, 42.99557055196455, 42.93192225117838, 41.109075238627774, 41.5705067880692, 45.830644023033884, 44.08306729409003, 42.812552759724284, 43.296851727270315, 43.831196215844926, 44.143385502599905, 45.967083669477894, 47.8816709979888, 46.824631460251354, 46.144331655194684, 44.175227303658765, 46.15232544560587, 43.92661571502686, 49.6226816792642, 57.2608268645502, 57.36254961259904, 54.729697858133626, 44.825203264913256, 41.38027575708205, 45.79126342650383, 41.134476507863695, 42.09850488170501, 45.68088008511452, 43.681189090974875, 44.72916795361427, 41.97222809637747, 45.345999886912686, 46.44434982730497, 42.147169728432935, 41.27057098573254, 41.04323825528545, 45.422666534300774, 47.24454864378899, 39.86032201397804, 48.52259412888558, 53.49366487995271, 48.73092689821797, 51.801585766576956, 44.48015628322479, 41.53753926677089, 43.14812721744661, 44.21941280364991, 46.417093276977546, 47.70682742518764, 41.65353944224697, 39.75043681360061, 40.71026825135754, 38.98302508938698, 38.77664173803022, 41.638497152636134, 40.703733582650464, 42.12062704947687, 40.46746569295084, 43.713442740901826, 50.26489919231784, 51.92853719957414, 50.048811897154785, 47.70974566859584, 48.3496097595461, 53.53648539512388, 55.73522883076822, 53.975959516340694, 50.98941195395685, 42.69851769170454, 43.92126560211182, 51.631754982856016, 54.29994337020382, 56.209219809501406, 56.04499409275671, 57.3781684906252, 52.85791143294304, 50.564438835267104, 54.39788887577673, 54.62115018598495, 56.703842455340975, 57.16310101170694, 53.894468353640654, 59.028313544488725, 67.57586417659637, 51.54349380923856, 59.891976310360825, 63.35150287997339, 64.51906696442636, 68.85296437048143, 65.32496106240058, 69.3526037277714, 67.40601770339474, 73.45503422521776, 67.92809301807036, 75.00552362011325, 17.179092937900176, 0.13398024373717848, 0.6297815158482521, 0.3784819391946639, 0.3379996469424617, 8.64553241960464, 77.71810147070116, 64.58031869703724, 75.14000600384128, 68.25715634130663, 51.94475620023666, 35.623511114428126, 20.576126344742317, 26.932033031217514, 51.7018908839072, 74.16280238859116, 13.789577734085823, 1.004792463875586, 0.22575411434856155, 0.08537350477831018, 0.05221982028395419, 0.06852455767652682, 0.04127688247770552, 0.06240839514160349, 0.025193370210247177, 0.025695814721045956, 0.1929554694722737, 1.3972388376151363, 68.5158758778726, 61.46728254133656, 45.85259360651816, 27.015826625208703, 47.489677167707875, 39.91024594153128, 56.31658684822821, 78.13730870523761, 68.29059062465545, 72.93608111719932, 43.73557667578421, 0.11594221326372317, 0.1303141759408097, 2.4141627021374243, 3.7557876013940383, 6.162516186314245, 1.1824809807923533, 0.17398573818706697, 45.639255892845895, 66.16395996462914, 63.98103152551959, 67.26525952739101, 62.18688841789, 61.061984031431145, 62.90446642906436, 62.05830135653096, 60.912176947439875, 60.41250228881837, 59.982084920329434, 56.96444865195983, 54.07650555333784, 56.94188717872866, 59.36236612258419, 59.730613923841915, 57.98138195468534, 60.53779848160283, 59.65857959562733, 47.58581446063134, 46.6588407178079, 48.930328430668006, 48.81221017529888, 50.373980306809955, 51.332925288907944, 52.96516864530502, 56.21684097474622, 59.89263526854977, 62.76340623055736, 57.68595295567667, 48.30606752826322, 63.22690094670942, 46.41641470693773, 54.840183181147424, 59.94139425216183, 54.05995707358084, 46.77646475453531, 42.77249751552459, 43.006502197634795, 41.58923218327184, 46.609246269349136, 45.858418326224054, 44.23615347954535, 44.599196295584406, 46.492190976296705, 45.19177621410739, 47.671753591106786, 50.79967514161141, 49.10499549681141, 46.65989583538425, 48.19935552535519, 46.034740632580174, 44.5850992971851, 50.66415332978772, 57.60530902493385, 59.048870686561834, 56.178001665299945, 44.678106538711056, 41.00439502346901, 44.45834790506671, 45.34342681207965, 43.950910875874186, 47.754495989891794, 44.4822233723056, 46.92882137913858, 43.950397045381614, 48.05324723643642, 45.94149804884388, 42.05423308957008, 40.385982374991144, 42.21966297395768, 46.703296861340924, 45.92244317454677, 39.1095882077371, 49.94616346974527, 54.90128194132159, 51.48477592775899, 53.56346345716908, 46.89461046649564, 42.44362246605658, 44.218710699389064, 46.79561768808673, 48.54754040318151, 48.82419301617531, 44.350529793770086, 42.03158140182495, 44.191148204188195, 42.59393945817025, 41.638728572476296, 42.36391990415512, 41.691747250095496, 43.8445754205027, 42.79038352351035, 46.03849041846491, 52.42396000892886, 53.57337136422434, 53.24426489491617, 49.09803721212572, 50.887928470488525, 54.90653007261215, 56.811433069167606, 59.397836116052446, 53.405011469318026, 44.41827304901616, 53.107946841947495, 53.370392630177165, 54.887636015492106, 55.55816519644953, 58.287891649430804, 58.76114130020142, 55.34927545055267, 53.385674184368504, 56.575357375606416, 53.906678691987075, 60.17854467515023, 59.657595080714074, 55.702986947951786, 58.15631181963029, 70.76133866463938, 56.24114790270406, 63.760256998000614, 67.0066027487478, 66.88843742493661, 69.73837667895903, 67.0876467612482, 74.31431570360738, 69.14620076456379, 74.08683392309374, 68.52606619558027, 76.46081709092664, 19.64166871963009, 0.2954722676546343, 1.734355889981793, 1.087416333536948, 0.5427023239674107, 9.472195467641278, 83.94763331259452, 70.46316008413993, 82.2855289520756, 73.73245562276533, 60.22586022653888, 36.562683428487475, 18.510576794224402, 36.30860797820553, 60.8013346887404, 85.72289805258475, 19.59686544633681, 1.0576446859105941, 0.19377784953723032, 0.1790229961155884, 0.03923976658693245, 0.25728823917527355, 0.29359195080976336, 0.15686491414183573, 0.23099041724156952, 0.3919652398795851, 0.4351289624408369, 2.331379363613744, 83.22155552525675, 72.05668572456607, 53.655372435046786, 29.342315773810114, 42.83014458994712, 59.806150928620376, 61.413624517379276, 84.7690482293406, 74.01984768529093, 81.81427971009286, 49.62882803332422, 0.2075771921344342, 1.4732464042402085, 8.675656222528028, 12.69424899931877, 11.327895272162653, 1.9488704372798245, 0.2544827639095245, 49.88263676243444, 71.04084676311862, 66.65464062844553, 69.69752911598452, 63.72051162104454, 63.225430057894805, 63.8520130034416, 66.06650475532778, 63.35120085747012, 64.53205785443707, 62.64872397145918, 58.37573705180999, 56.7804894908782, 59.56431719564623, 59.92476732500138, 61.31755782711891, 63.06447167550365, 62.909479218144575, 61.056567238223174, 50.62196431621429, 46.84007775398993, 53.082522038490545, 49.51002728554511, 50.44902701531687, 53.49662626943281, 55.35192305041898, 57.98357063724149, 60.97805315448392, 62.943211601626494, 61.08625173568726, 51.192720167098514, 64.41450049800258, 52.88388929059429, 55.72002180161015, 63.74477540293048, 57.3596078349698, 47.54950115757604, 45.501043335084, 45.6760791040236, 44.95992883559197, 49.23177434552101, 48.83854104626564, 47.17479713501469, 46.46237704061693, 48.31317878538563, 49.14875738082394, 49.90737907348141, 54.24152358885735, 50.52448949506206, 48.07166668676561, 49.69415118617397, 46.40063108936433, 45.853123126491425, 52.95787303678451, 59.16975029053227, 60.33026979815576, 58.9807116600775, 46.6760403110135, 42.16323575665874, 46.788631946809836, 46.73232632298624, 46.810656055327385, 49.30471866361557, 44.600875070018155, 48.00953634323613, 46.40433772917717, 49.02147254636211, 46.8804193312122, 42.14748351804672, 41.30902198053176, 40.94390815304172, 46.13216054054999, 48.84007469300301, 39.329684165216264, 50.13260941351614, 57.061813646747225, 50.91748352973692, 56.25486835356682, 48.440628359394694, 44.112704723112046, 46.207666166367076, 47.61369074544599, 51.4113256239122, 52.30543774943198, 47.54319790870913, 45.11328566458918, 45.884906091997706, 45.256165842856134, 44.090225619654504, 45.89251156776182, 42.695850479987364, 45.293549952968476, 46.12811265453216, 47.87493236603276, 55.74445032304334, 56.057839855071045, 55.92440082180885, 51.65353198205271, 54.799319928692235, 57.28092508931314, 60.19242202081988, 59.91682452540244, 57.66946331147225, 43.4233913113994, 48.97530232706378, 55.81866548907373, 56.3463419483554, 55.92338492793422, 62.70860287450976, 59.794513256319114, 57.09640502929688, 55.37032288889731, 55.53745115956953, 56.65591501420545, 60.06879283535866, 61.70838279108848, 57.55215306435862, 59.19077419465589, 67.04612455060406, 60.71594861245925, 65.98936742351901, 68.54858060036936, 68.96838403517201, 73.94184743204426, 68.42444542915591, 75.05893845711985, 70.11021737129458, 80.6054287572061, 72.04357716345018, 81.28012349528652, 22.18860487784109, 0.522051903028642, 3.4487510833048054, 3.151664882898331, 0.9223070416239001, 10.970248656888163, 91.24117866639169, 75.77703814352714, 88.6296332267023, 82.17208616195187, 71.3772370738368, 53.909408661627005, 34.01278588079637, 46.00327930142803, 70.22699417606478, 99.98124707129695, 24.748677053759177, 1.5798078861928757, 0.3649449817115261, 0.323140237840914, 0.18346642865048302], [0.04950296989972553, 0.031621305632495114, 0.1453066085495295, 0.025326240499834382, 0.09947647100254413, 0.09096423058860725, 0.38243262397666133, 53.7046060254497, 54.907785231067294, 40.884154765836655, 26.795683599287464, 32.0594867198698, 39.33597172460249, 46.542605200121486, 69.86601844910653, 61.37500093829248, 63.03291620746736, 44.87117736570297, 0.044161222664819616, 0.1273757231331641, 2.146592092129492, 1.7309597302829067, 7.226510086367208, 0.2665489551521117, 0.36098534902257307, 20.61213762529435, 75.99591424388271, 54.89419814079039, 63.647335883109804, 58.435541429827296, 59.783711048864554, 56.010610595826186, 57.40975141525269, 56.57317261542044, 53.07116677684169, 53.63778844956429, 56.13989583907589, 54.882874258102916, 56.81427286517236, 54.54887659318986, 57.813198566436775, 57.89940441808393, 45.63068551401938, 42.11422966372582, 45.750506078043294, 53.660526429453206, 61.66000427738313, 55.04711174195813, 51.94464637387184, 47.35813263923892, 46.90577745437623, 45.80851008815151, 46.3798503721914, 52.763343088088504, 64.0923366238994, 58.66310950248473, 43.43675874894665, 50.15349211231355, 60.50519966310071, 53.82478744752946, 49.2783328794664, 38.40439311919674, 42.266904000313055, 41.20537334872831, 42.00860415735553, 40.883746839338734, 41.04115547672395, 37.706728981387236, 40.50737580945415, 40.42130331839285, 41.63262928685835, 43.779016925442605, 45.99528943338702, 46.790185205398075, 46.11849892523981, 46.34399206407609, 49.48772468874532, 46.42991158270067, 49.71992900294643, 55.23098068852579, 55.00726830574774, 58.89203079285161, 50.31399157739455, 43.59136681402884, 43.23444681782877, 40.26913104518768, 39.59688778846495, 44.82542684001308, 44.823783366910874, 42.97520560602988, 40.548823495065015, 44.529134919566495, 39.287891311030236, 41.16385506045434, 39.840619948602495, 39.62310491069671, 45.694008258081254, 49.607011810425796, 49.12660775646087, 49.86799063221101, 48.60157105230516, 46.411856912797504, 49.92246843153431, 45.35377010222405, 44.60277741955173, 45.495222537748276, 44.692599696497766, 47.25565287374681, 43.990440522470784, 41.806527568447976, 36.91256669259841, 41.116272787893976, 37.16722265366585, 38.77637893922868, 38.78981305706886, 38.55504743514523, 41.44932123922533, 42.925042413896136, 45.403639116594874, 48.82928425265897, 52.964446929193315, 53.3723851942247, 51.6043846837936, 50.12048928968368, 48.56676001702586, 50.30315406860844, 53.754835897876376, 56.663159631913715, 60.15145286437004, 56.6692118490896, 51.55736331016787, 50.16170555545438, 49.219285518892356, 52.89356185543922, 58.81099854746173, 52.829737047995295, 52.45820230053317, 53.88323076309697, 54.55425808506628, 59.13631208481328, 56.549579558833955, 61.84890562488187, 65.718582676303, 46.036215443764966, 56.41680732850106, 64.84662801988664, 61.575116342113866, 64.4925242854703, 62.16188723041166, 62.43766123248685, 66.76686748381584, 67.55902936381679, 75.92696682099374, 71.77121562342491, 68.83908702481177, 10.312719191274336, 0.09931770694111625, 0.5157084498674639, 0.7933169567296583, 0.30475320835267344, 8.905298248414072, 78.32254655899541, 66.37762715739589, 75.68794542743315, 71.25808331274217, 50.528749189069195, 65.99267790394445, 30.47704765873571, 28.638107161368097, 52.33380433051817, 68.44321789280062, 7.820912926427781, 0.42029333270845876, 0.13506309369639044, 0.08051467638823294, 0.03354412120496554, 0.012801469983382812, 0.10188647636002111, 0.07731782978460675, 0.09203895235494261, 0.0894307983558505, 0.21494723375766508, 1.402540411199293, 66.562849321673, 61.901159440317464, 46.949998255698915, 32.09019691713395, 27.248738927225915, 40.52699550505608, 52.80213532909271, 75.02602977137413, 67.03267866565336, 69.49857081136396, 49.64069712546564, 0.2415074254836767, 0.07536251293194872, 3.387219881819141, 1.8985959478924352, 3.620512408594932, 2.5069586259703485, 0.7861604084891658, 23.42360627266669, 73.53857286514776, 59.517978314430486, 64.36348615154144, 60.339628573386904, 63.42188589034542, 58.978287635311005, 61.10995854100874, 57.53024662694624, 56.29300555875225, 54.09984365586312, 58.993298545960464, 58.047316997281975, 59.53524458792902, 58.31961970175467, 59.74968448761971, 59.38861070140716, 49.259136799843084, 44.71658891247165, 49.256583336860906, 56.319395265271595, 57.46988919473464, 54.05479915680424, 50.751986965056396, 49.99199244283861, 47.75815948363274, 48.8490020075152, 47.701202746360536, 56.956450939178474, 64.76707843042189, 56.193640155176965, 47.6255480704769, 51.964626927529615, 62.48396873474122, 55.48022377875544, 51.25697251289122, 42.034852658548665, 43.59907034904727, 42.042893517401914, 45.510978698730476, 41.31500359504454, 42.13767759261593, 38.47110871345767, 42.244264079678445, 42.76304460340931, 42.58753815004903, 43.591213841592115, 48.043096142430464, 47.923844322081536, 49.032537552618216, 48.46488037417012, 50.77005732444025, 47.0584596357038, 51.1219645315601, 57.03393736193257, 57.360812002612704, 59.753045958857385, 52.63917653791366, 45.268003556036184, 43.93183246735604, 42.060187247491655, 41.212370857115715, 44.26853264531782, 44.57428532262003, 44.460513053401826, 44.80274769567674, 44.93028748419977, 41.55913191456949, 43.35659334736486, 40.910807271157545, 39.21981857668969, 46.08721017837525, 50.72429110926967, 47.97703558398832, 52.394679515592514, 52.2098417435923, 49.32584062699349, 49.95237650409822, 44.39626855234946, 45.45571250300254, 48.594663758431714, 47.0297400413021, 48.66922409303727, 47.591097893253455, 42.955746727605025, 41.349343945903165, 43.11426147337883, 39.1549543411501, 41.091389271520804, 39.08907028936571, 41.35965585708618, 43.485258856127345, 43.53032296703708, 45.94489089904293, 49.6724408672702, 54.44118007536858, 53.442485793944336, 53.42500379008632, 53.402909078905665, 50.878714822953754, 53.53246104332709, 55.20964299478839, 59.508348895657456, 59.36804963696388, 54.47592050798478, 53.39277759675057, 52.03723784415953, 52.55110363806448, 53.686751396425315, 58.55904509944301, 55.30090870395784, 53.59419914983935, 55.34445877998106, 57.17852769359466, 59.4333767121838, 58.99385552252493, 62.68949308703023, 73.22752891048309, 52.00843195761404, 57.589529329730624, 67.17026756655785, 61.98215638437579, 67.97454957039126, 66.20398382986745, 66.4645782593758, 68.90874047433176, 69.55092660842404, 76.95012492518272, 74.98307197324692, 72.74139819606658, 11.746213109262529, 0.32840562143152763, 1.397026171607356, 0.6704799674691693, 0.2676349613935717, 9.857187867164612, 86.83226200842088, 71.77789149745819, 83.45143779631584, 73.14547292647823, 61.71432518189954, 60.20494614878009, 26.183309439689886, 36.31338150270524, 58.03067830301101, 81.77297715217837, 12.699513800682562, 0.7668253298728698, 0.12592378733379225, 0.08099683680601659, 0.03972558507455453, 0.20957491961458038, 0.18210121400413976, 0.26156432746398833, 0.24591561797405445, 0.21765988981050832, 0.42492678569209197, 2.152376117244844, 79.85611484896752, 72.29966086726036, 55.44571084360923, 39.557754301255756, 44.1454408245702, 54.7432614141895, 58.25195489391204, 82.93293183849704, 73.37769293016004, 79.66304794434579, 55.30359552752588, 0.4215587873853022, 0.45499169177586035, 9.551413616826459, 11.699461398586152, 19.21340080999559, 4.114387842916673, 0.716357786328562, 27.234092797002486, 76.37672147443219, 62.90711402893067, 66.86405597194549, 63.45894836610364, 64.6408094898347, 62.94612592266452, 63.67829122850972, 61.85651894538634, 60.35090146526214, 56.73312294867731, 62.382391114388746, 60.146063527753284, 60.92351259723787, 60.03396611059866, 63.25899377945931, 59.34756309755387, 51.285550901966715, 49.52391639832528, 52.90904737287953, 52.031197394094164, 57.964150982518355, 54.13631777609549, 51.92494823086647, 51.496994110845755, 52.87221239459131, 51.99756306986655, 52.683707206479966, 59.4070379964767, 59.18525934219361, 55.51084964506088, 53.14018872476394, 56.91081416222357, 64.30809443996799, 60.287370835581136, 52.85837427262337, 41.546827439338934, 47.54934034039898, 44.209975581015314, 47.2103730324776, 44.407510065263324, 46.72297931486561, 41.072204959008005, 45.32272846468034, 44.46599652690273, 45.72838391027143, 45.60659039405085, 50.94702682187481, 52.55086437348397, 49.35159490954492, 50.04390108969904, 54.40127388123543, 50.18226661989766, 54.34693336486817, 59.30890421713553, 60.011871399418006, 61.58035270629391, 53.1366232902773, 47.04428811227122, 45.39559433537145, 45.36389766200897, 42.55906566496819, 44.92287812694427, 45.55611341230331, 46.709945278783, 46.53047723154868, 45.85095405578614, 42.54323497895272, 44.48155264700613, 41.514824821103005, 40.282561240657685, 46.983569822003766, 53.17835338654057, 49.07211034528671, 52.48176790052845, 53.13040633355418, 49.505661687543316, 52.4161897936175, 46.07862411006805, 47.015517527057284, 51.174732177488266, 50.63558278545257, 50.94593248059673, 48.886240989931174, 46.53298362608879, 41.27496796269571, 46.129814963186945, 41.161183926366995, 43.49070310592652, 40.76200431393039, 41.89104287855087, 45.129692939019975, 46.09722791179534, 48.535008430480964, 51.871278439798665, 57.86962186136554, 56.70061434468916, 55.306741268404075, 55.32468218957224, 54.2935420620826, 54.009597762938476, 57.41957695253434, 60.589648292910674, 62.189826273149066, 53.554681270353264, 52.81669908954252, 51.34567691433815, 51.984003436180856, 54.426816355797556, 59.04641920520414, 58.5115255848054, 53.64972029962848, 57.36673870394307, 61.41887657104, 61.79414933727634, 59.956711107684725, 60.99205601599909, 68.33637252930673, 53.07479104688091, 62.36921195060977, 67.4950162826046, 68.31957694022887, 69.36971310646304, 69.40353178208875, 67.01999372051608, 69.72011412343672, 71.93804187159385, 82.91182164222964, 74.74382308221634, 76.95387471106746, 14.387573465224236, 0.37557926269308217, 3.475223649894038, 5.215084831560812, 0.6762254430401711, 10.821721246165614, 93.59092943130001, 79.42404224026588, 88.47140481395107, 82.88459254849343, 67.26511832206481, 79.19718803897982, 44.52072928028722, 47.43125346399123, 68.48596388293852, 94.96241754101169, 18.81026940961038, 1.3590530930988252, 0.5077963550725292, 0.217867300455128, 0.3228336800971339], [0.10239225526851031, 0.050490587469070196, 0.05023028228371855, 0.10766806531577341, 0.06200738641763888, 0.1053432949007519, 1.1222065312247123, 53.87926916922293, 55.638758136380105, 42.853306185814645, 27.661456600312267, 74.68350487370645, 61.12522440571939, 47.077592957404356, 66.5199621262089, 66.87060633013326, 61.245119494776574, 59.919201481726866, 1.641470364505245, 0.08293361433090703, 1.0377891578020588, 1.741352050054458, 2.5256933368021444, 0.8073428621695888, 0.40191512855310596, 6.85744398063229, 71.78033121170537, 58.246640082328554, 64.30252075195312, 57.49052086184102, 61.16693096776163, 53.141247764710464, 55.15872670758156, 52.37986472345168, 55.52033001376737, 56.641264961611846, 59.45580090245893, 57.837340754847375, 60.680000089829974, 61.51245255624095, 54.35289536753009, 42.50473691571144, 42.411058948886016, 55.640287860747314, 55.19876626230056, 43.46560778156404, 56.40526771545411, 47.84310233208441, 53.73743234142181, 57.19742959545505, 55.750447627036806, 48.64226956521311, 47.53142295345184, 40.09196935161468, 44.490428970706084, 53.47293123122185, 48.6146717686807, 58.15017723268079, 56.369440786300174, 51.83825600531794, 42.576649650450676, 39.44833194055865, 39.32745625895839, 40.31475213266189, 36.69407106214954, 39.598174325881466, 41.080959689232614, 43.03945795182259, 40.68133292659637, 42.15133528555594, 40.85796117782593, 43.158097882424634, 46.744850450946444, 45.90010527641543, 44.945012061826645, 47.65957070935158, 48.02222521074357, 49.06579925167946, 48.05070161819459, 54.82176373081823, 55.70918037045387, 57.05993483143469, 51.92157499251827, 46.92106293093774, 46.000576788379306, 41.35293683698101, 41.02598767126761, 44.23603188607001, 47.29143665682885, 43.0349080024227, 42.738882803147845, 45.293177327802105, 41.01791935582315, 41.5419440884744, 40.352979552361276, 41.477221058261016, 50.643682479858406, 49.204580553116344, 47.098703153671764, 49.608388562356275, 50.302244078728464, 43.932962109965665, 43.587201256905836, 45.597502262361594, 46.96593092333886, 46.909060478210456, 43.38008442232686, 42.814745364650605, 40.56300286323794, 39.698579157552416, 38.70701182273127, 42.39096072412307, 42.03792387439359, 42.683079242706306, 40.64333692673714, 40.64059518998669, 40.73439082791729, 39.27948959412114, 43.30727738718833, 46.55893402714884, 53.401163624178984, 55.78923202330067, 55.16710489026962, 53.752839411458666, 48.809209562117054, 47.49034397063717, 50.254300948112245, 57.372559501278786, 54.66363729969148, 55.38004252218432, 56.54260558466758, 56.7236739589322, 53.261766510625044, 52.811372510848514, 51.12623207030758, 46.31452329697148, 51.345669069597804, 55.02249494675667, 53.645087980454974, 54.13925563135455, 52.21318360297911, 48.76301580859769, 40.39613739136727, 54.059953151210664, 63.56330302453811, 63.28111594723117, 64.34326241093298, 61.06292147790233, 63.46580074679468, 63.889989391449966, 65.73766108482116, 64.41854053928007, 76.061613944269, 76.7886644794095, 59.17926596057031, 6.2314351720194665, 0.2923026554767163, 1.268616474924549, 0.10386452304139253, 0.5222279806771587, 9.768209880398167, 77.12576866149902, 69.63039382811516, 72.28101391946116, 75.65873161438974, 49.217563598386704, 73.04326380452802, 37.85174292902793, 22.210660365320024, 62.25902865009924, 72.14265623400289, 9.756378050773375, 0.6296615158357929, 0.07921284019586541, 0.1502498828115002, 0.24892162441486315, 0.12833419105698987, 0.026129692447401827, 0.01792842435890869, 0.11678258107314188, 0.05099157449759303, 0.12025562535610893, 1.5683157093101934, 65.97385837185767, 62.2523606208063, 48.73558275161251, 21.20359770713314, 51.09550814474783, 56.58843455776092, 51.488153088477354, 74.60741873710387, 70.9409361500894, 65.51272100017917, 66.25935985196021, 2.0974756825354794, 0.10487384388163205, 1.135014295578003, 2.0292999859779113, 5.874924573206133, 4.612558762873373, 1.0522562073123072, 8.628351457657354, 72.62147565041819, 60.857036267557454, 67.53642082214355, 58.88138548020394, 63.03836830200688, 55.52187934998543, 58.917600724004934, 54.99028444290162, 59.4706117722296, 57.179214108374815, 61.72484890107186, 59.65775982026131, 64.53876510743173, 62.31611482558712, 53.11854900852327, 46.86517700072258, 46.61405901755057, 55.663374931581565, 54.69354537225539, 48.088379906069854, 56.035572559602805, 48.35063742053125, 55.88995456695557, 55.229313681202555, 55.148481476691465, 49.75179041585615, 51.366508622323316, 40.29461860656738, 49.984543861881384, 58.33077100015456, 51.066286486964074, 61.26874785269461, 57.28977003405171, 52.0182143488238, 43.90258727535125, 41.74424817485195, 42.04124612192954, 42.39636575022052, 39.66813764264507, 41.52977689619988, 41.968423397310325, 41.871509475092736, 43.042074172727524, 43.76416683197022, 42.065976665865996, 44.51515166990219, 48.5812492524424, 48.030681840835086, 46.13676932550246, 48.21332700790898, 52.343939735043435, 52.37144731706189, 50.55774334938296, 58.53549126655825, 57.905903785459465, 56.48891618174892, 53.76629314114971, 46.98099282480056, 45.21576543008128, 44.71375696120724, 42.83984068901309, 45.40454126173451, 46.985836951963364, 43.73388613423994, 44.97712842879757, 47.73856724462202, 40.65687302620181, 40.4274457500827, 39.59905685917024, 42.11821871419107, 51.68915494795769, 51.03602147871449, 46.86468670445104, 53.80676807895784, 52.09346502057968, 45.519133306318714, 45.97250438505604, 46.36173294436547, 47.40190236799179, 47.44611140220396, 46.93842334132041, 44.14295011951078, 43.97986973485639, 40.41616893583729, 41.44727768436555, 43.38195147052888, 42.68398923258628, 44.50641655152844, 44.14050256052325, 43.0387480028214, 43.07641844595633, 41.02934914250528, 43.59662671242991, 47.93353257640716, 55.75566045699581, 56.3683464450221, 55.53813757434968, 55.797978908784934, 52.330493850092736, 50.93224733106552, 54.08317358263078, 59.70435757790843, 55.32135601966612, 54.87329975251229, 56.669988478383715, 56.40289075912968, 53.9225015332622, 53.111637792279645, 50.176751767435384, 48.19468398247996, 51.70375793210922, 54.475881284283055, 54.2651637138859, 55.56600601442399, 53.48172126277801, 55.59225451561713, 44.94469827221286, 56.051905309000325, 67.86968108146422, 64.7392374469388, 66.75279401963758, 65.26070087186753, 66.73719867583245, 64.53287762980308, 71.07366131198022, 65.70284612717168, 78.72650361830189, 74.71934749234107, 65.26789449876355, 6.295666925368771, 0.41738112607309896, 3.2174900991301385, 1.297514904891291, 0.4709913155003902, 11.508029141733724, 82.19169801281345, 74.48438182953866, 78.43118836802822, 82.85238988937871, 54.47287674873106, 85.94349999581614, 49.474125831357895, 28.929229397927564, 69.70036106724893, 82.49237122074251, 13.847458189533604, 0.8522299761253019, 0.24044999432179237, 0.19822460689371635, 0.17587180069137007, 0.25790834138470314, 0.2228135624600034, 0.1697038735954031, 0.18002890020368562, 0.11609371481162888, 0.3871936152779287, 2.514974479713748, 82.91418290907338, 69.61655570614722, 60.10491001990534, 41.42837970487533, 86.01492635665402, 70.44044171610187, 60.543689881601644, 80.81669545942738, 78.68423615732502, 71.89809645375898, 73.85025224378033, 2.171275812772013, 0.39936696689936424, 4.073033803893674, 6.008629347047498, 9.359739153615891, 7.23094726762464, 1.6113692377844167, 11.328458132282382, 75.65171841652163, 63.43987387995567, 69.99955161925286, 64.18757569405341, 68.9179737337174, 58.12584284813174, 61.006804127847, 56.080569990219615, 60.94856477552845, 59.967623141504106, 65.78882055897867, 63.477112862371634, 67.43430583707749, 62.94639656620642, 56.385059664326334, 51.22826468560004, 48.920844139591345, 54.487362061777425, 54.92869146408574, 48.83910586757045, 54.34615281320388, 52.07533190327307, 56.66986688490837, 58.09922956651258, 53.073426062060946, 52.08075261885121, 51.76238559907483, 46.80208959887105, 49.04621877977925, 55.88438087894071, 55.95960017173521, 63.19285085124355, 62.899332046508796, 55.51902778687016, 47.40298101978917, 43.46406629008632, 43.66372277659755, 43.423344242957334, 40.969387869681086, 43.64686050722676, 46.39699505221459, 45.82774931384672, 47.149690043541696, 45.63954614823865, 44.23894620710804, 46.60025227454401, 50.50374800159086, 49.92243705257293, 48.566297177345525, 51.37268635534471, 54.02865655960576, 56.333998249423125, 54.03851347584879, 61.23753755323349, 58.79764287702499, 58.733861215652965, 56.53744374552081, 47.837771831020234, 49.08599161332654, 47.275876614355276, 46.23956288060835, 47.416791685165904, 47.38030972019319, 45.77262040107481, 45.71922909828925, 47.834116182019635, 43.212363873758626, 40.597817820887414, 42.0483926803835, 44.007036070669855, 52.01259751473704, 50.92902706515405, 50.56700014298963, 55.51401499778994, 55.52666464159566, 46.75074577331544, 47.243948521152625, 48.04260584615892, 48.70597670155187, 52.098819055864894, 49.26471048785795, 46.037772624723374, 45.84079119466966, 42.67646220422561, 43.337734591576364, 46.418454339427335, 46.2334204489185, 46.71532284828925, 46.189058442269605, 45.84541174673265, 46.748953250146684, 43.612214211494695, 47.43411287184685, 50.44528507417249, 58.640104801424094, 60.41844075725925, 58.61196964017807, 57.17287555817635, 54.29229474836781, 52.93972815236738, 56.166881745861424, 61.69625090014551, 60.03266780607162, 59.62895393371583, 60.34659078044277, 57.74922863129647, 56.65341254203551, 54.745689361326164, 51.81002670718778, 50.59549223992133, 53.61418754823747, 55.826125837141475, 55.19328671116983, 55.37061706666024, 53.38580362258419, 53.06683648017145, 49.11933175979122, 60.51336603779947, 69.09301342502718, 68.51041593859273, 68.60535298624347, 66.7230232300297, 69.04775711797899, 67.48684990790584, 72.07422656397667, 67.58981212492913, 80.4924488067627, 76.17158151442005, 67.7062359163838, 8.378018929112343, 0.5363157247343372, 4.459788818513194, 2.4229135099918615, 1.0271346520993019, 13.41287918629185, 90.51396339170395, 82.47541873685776, 84.84263189377324, 88.57682243470224, 63.42673786224858, 87.91524410247804, 51.89218075044694, 38.18910598754883, 80.8295294546312, 94.8773648661952, 20.99433337488482, 1.6075399013296252, 0.44441122081010576, 0.3526732950441299, 0.31541120741636525], [0.05486385018054036, 0.0076869540029175345, 0.0671336867455994, 0.08078843024709532, 0.05555994065117933, 0.08902446532081212, 1.1448943783198635, 56.878046681804044, 55.42857400832638, 39.38284012579149, 42.64756218079598, 94.07809565144201, 83.00325209094633, 50.34398986447243, 56.76710244148009, 71.98946414455291, 58.770072537083784, 70.15261819285732, 5.96258121152078, 0.26324552273558033, 0.5788594676602272, 0.3767020105113907, 1.3076270203436575, 2.8758403803071673, 0.4397129567880785, 3.2618878974068553, 66.8833226542319, 61.88918444418139, 66.38154168282786, 59.688723010401574, 59.852274079476636, 54.31862954170474, 53.82636424033873, 52.95791226048624, 56.0151566228559, 55.69570310654179, 57.471077672896854, 60.91480493545533, 57.11948033302062, 43.07502208217498, 42.83441605106477, 53.73300006312709, 62.856542910299, 52.08196463123445, 54.721978633634514, 42.336596673534764, 57.63704884436823, 60.97423668830626, 48.999307232518355, 53.055740094953975, 48.960012928132095, 48.70342716093987, 49.78079634328043, 52.86953733813379, 33.3486109395181, 44.64402114191363, 59.085505623971265, 54.23233347554361, 55.93694456161992, 44.00811472246724, 41.97080035363474, 38.838834839482466, 40.23473578114664, 39.30782871861612, 36.71580099290417, 37.502565691548014, 39.70445094570037, 40.2259849732922, 39.608180292191044, 41.03586812173167, 39.131859425575506, 41.312438364951845, 43.28360196082823, 44.484670931293124, 46.67098045349122, 44.6355958907835, 48.56099805524273, 49.348488392368445, 47.91099071502686, 50.25879598432972, 53.01281759815832, 55.71127883849606, 57.27233902100594, 47.526492534145234, 45.871695549257346, 42.621894190388346, 40.835407549335116, 44.28077436262562, 46.636722472406205, 43.162894941145375, 43.40462669249504, 44.47872461811189, 39.73932473890243, 41.85931090385684, 38.61678161928731, 45.252314075346916, 50.5925779188833, 48.349809800424886, 49.83823160971365, 52.02711812911495, 50.36526872265724, 42.76059312205161, 46.4896414356847, 49.103140215719904, 44.957187098841516, 44.62578604298253, 43.2418522527141, 42.501504882689446, 39.28592620357391, 40.25932119738671, 39.40358554163287, 38.29275069698211, 38.24468597289055, 41.220376414637414, 39.38203603990617, 40.407712305745775, 41.53684892962056, 39.07653047192482, 43.85700541157877, 48.880306443860455, 52.15954519087269, 55.11974619280908, 55.87620273713143, 54.97141784237277, 53.422450327104144, 52.525729825419766, 45.42727531925325, 50.536040875219534, 56.36558117405061, 56.82005443880635, 55.26439143765358, 56.63622471594042, 57.15226350292083, 56.925217105496316, 50.742522285830596, 44.38195582359068, 51.245154411562034, 51.45284391218617, 51.491557705786924, 49.24049377441407, 48.25500611336001, 52.809395636281664, 61.92588998425392, 62.055920477836366, 60.27423874024422, 65.27459782938804, 62.90529797154089, 64.4927635500508, 64.03589371711978, 61.09057418761715, 68.22654616448187, 62.55856044830815, 65.81650072528471, 73.08389171477288, 52.31649491094774, 3.165546396086293, 0.4083773866295815, 1.4230974306983333, 0.5232302688302533, 0.3790805602986967, 16.80619908917335, 78.58973841513358, 65.04614330107167, 80.03011118981146, 69.95050630261822, 60.05727283416256, 30.799758703477924, 16.3160155857763, 30.61692330145067, 56.73372699368385, 70.25498420961442, 9.511730997793137, 0.4227401562515767, 0.1914298666581031, 0.11654316327504574, 0.06296696133851525, 0.02724192953938919, 0.015305886101428301, 0.08679167908285895, 0.06109243611835184, 0.022181070357140516, 0.0717919533171, 1.4466468509166472, 67.31182590607675, 60.80879111443797, 47.896976086401175, 43.26287615683771, 92.94098484900691, 88.50875362273186, 54.13481943068966, 63.3020810158022, 75.91785123271328, 63.63262307259345, 75.46108338140672, 6.988684525412898, 0.40205942887452345, 0.36710715762549834, 2.623888158029126, 1.9719999187415647, 4.493388822001796, 0.7790348714878483, 4.301394685622185, 70.08771865598618, 62.40056345539709, 68.06466994747039, 60.838134365697066, 60.85311389738514, 55.207638663630334, 58.392971946347146, 54.28738786328224, 56.51414486669726, 57.14144952835576, 61.24049502034342, 61.608119164743734, 59.32058111313851, 45.89880697188839, 45.8169274945413, 54.121220573302246, 61.718416213989265, 52.34604604782597, 53.49316281657065, 44.58172213646674, 61.9917191228559, 58.754849818445024, 51.72434645314371, 53.29618530888712, 51.257596169748616, 49.94819525749453, 51.59959939218337, 51.43817032537153, 37.19770731464509, 52.03414701646375, 60.302864197761785, 58.324314778850926, 56.57087410649946, 46.39490442891275, 43.58125886609478, 40.49895055832402, 41.647644119877974, 40.957373649843284, 38.37023711973621, 39.60165739059448, 41.63036607926892, 43.49701812190395, 42.6351204226094, 41.75409724635463, 41.83267408801664, 43.79663621225665, 45.77000025779971, 48.52961517149403, 48.535702690001465, 47.666230893904164, 50.07260499462005, 51.14022708708241, 48.47051289773757, 54.638185039643325, 53.982270609947946, 56.23984175343668, 58.02843470727244, 48.08362207105083, 46.37278618351106, 43.58933894864975, 42.336377020805116, 44.869173034544914, 46.036737118997884, 45.98789184324203, 45.2263322953255, 44.816487758390366, 40.94308837767571, 41.65007598938481, 38.93406214252595, 44.88339162641957, 50.129130271173295, 50.026054305415, 53.497332296063824, 52.4926132540549, 53.28485750382947, 43.489749969974646, 47.70204997831776, 52.36280633557228, 46.56476659159507, 46.96929631694671, 44.323434060619725, 45.98058838998118, 41.356435591174716, 41.19795222436228, 40.558539205981845, 40.665172761486424, 39.92604132621519, 42.823908021373136, 41.489258812319854, 41.960311935793975, 41.62124656861828, 41.45985672550817, 44.15671763881561, 49.0556207010823, 53.958136266277684, 56.43612892396989, 55.38334515786941, 58.3611850584707, 56.21084759312292, 53.594030487921934, 47.66884319243893, 53.8188450567184, 57.123787095469815, 58.90987365476547, 56.767239724436116, 58.10790584933374, 58.88931651269236, 58.45910702982257, 51.443136046009684, 45.635274687121, 51.13743043714955, 52.143891011514974, 54.064385429505386, 51.92292036548738, 52.2655511671497, 55.37668889568698, 63.08855502836166, 62.39525256618377, 61.18981407534692, 66.96059334662654, 66.5388914846605, 65.55199961508474, 67.38666472896453, 64.6342355974259, 71.46834588819935, 63.16052267628332, 71.18714332580566, 71.86853747214042, 60.00085346160397, 3.6561687146463706, 0.26127027227513255, 5.087657320883967, 1.2534843385219574, 0.575204492817002, 19.4517965855137, 84.5942517249815, 71.4717269712879, 83.18522653272076, 78.37290194726761, 62.649402541498986, 53.82804693714265, 25.945247065636423, 31.903868644468247, 66.35361440720098, 81.14083228572723, 13.490833351689002, 0.6964653634255933, 0.22849912995532637, 0.2026165736418578, 0.08736837475049881, 0.1612659360492422, 0.14259291061710927, 0.18779540764949015, 0.24573333501335115, 0.2641997924975811, 0.32121227032715277, 2.1053819550621897, 81.1397889352614, 69.80438232421875, 55.281445903162805, 58.58873351927727, 102.04711237261373, 88.92138696485951, 66.07223141577937, 70.7892345613049, 83.8852362478933, 71.61266557631954, 84.22048122652116, 8.477442187647666, 0.6221962648053324, 1.3543659833169754, 3.5361870882972597, 8.200246326385006, 8.883024088798031, 1.2715854639968565, 6.528174732961963, 72.8995716956354, 64.92933119496992, 70.82701483080464, 65.41411261404714, 64.37096218908987, 59.30442094802857, 59.26385187333631, 56.49093228001749, 58.98390839176794, 59.08653328495642, 60.6737203751841, 64.73276945852464, 62.092096497935636, 49.44963847437213, 50.50446971770256, 57.05366296152915, 59.870281680937744, 53.403603338426166, 55.57929108219763, 50.71108056652931, 62.617847073462706, 58.40701403156404, 54.407510449809415, 55.8507740113043, 54.26495190589659, 50.01722897252729, 51.67357137126308, 52.123953603929095, 38.91227729858891, 47.63216903132778, 63.85050681329543, 60.82652414998701, 60.78075009007608, 48.954662815217056, 45.88960901383431, 41.78262856698806, 45.016571783250384, 42.035601831251576, 40.32548373745334, 40.77067275201121, 44.36496411600421, 46.20408896476992, 43.62180832893618, 44.51435150638704, 42.2008591313516, 45.70261393823932, 45.38390174988778, 51.253924831267334, 51.900351047515876, 48.83299481484198, 54.189258006311235, 53.66638252812048, 51.03296987472042, 57.15574264526368, 58.36330313836375, 58.750084138685665, 62.989385743294996, 49.904762852576475, 45.54866090897591, 46.338332083917436, 45.39078943191036, 47.6497059483682, 46.52325614806145, 48.49164270585584, 47.028567252620576, 45.7702983579328, 40.89645924106721, 41.98996505429668, 38.301109267819314, 45.7443283450219, 52.66011022752332, 49.43230552058066, 54.02150607878163, 53.73787556925128, 56.44325979294316, 45.785019013189505, 50.01254958491172, 54.30054741521036, 48.88527216449861, 49.287515148039795, 48.44368388575893, 48.68689044829338, 43.543792386208814, 44.72487295827558, 44.34106119217412, 41.219874351255356, 42.035421402223655, 45.853370235812285, 42.89879783507317, 42.08946381845782, 44.997709105091715, 43.16127500226421, 48.16453272296537, 52.73459995946577, 56.011006755213586, 60.460531711578376, 58.52326523873114, 60.05139320127426, 56.7191553884937, 54.24740322174565, 52.30786177419847, 55.68246510721023, 59.94097063618322, 60.62281977745795, 59.872470363493896, 61.30730867385865, 62.05564591192431, 59.57544495982509, 53.289913438981586, 49.54283791203653, 52.455272290014456, 53.720377875912575, 54.982996679121456, 53.95938750236265, 54.20705379978303, 60.25511326328401, 65.8345671622984, 65.21247925296908, 64.54824155376804, 68.89933463065856, 67.74378868841356, 69.10702413128269, 69.27420339276715, 67.89843989956763, 74.64897232670938, 64.40268631904357, 71.54230610016855, 76.35054357590215, 61.62418911533972, 4.868078135675, 0.6828590903070666, 3.8746540488735324, 2.7834352226026597, 0.6618639298023716, 20.909121844076342, 96.47263203897785, 75.26657304456158, 91.99341081803846, 82.58864187425183, 76.40682958787488, 45.53587790458433, 26.069960786450295, 48.864954287006015, 71.44347021656652, 96.83107391480478, 21.66492335257992, 0.9021338015314072, 0.4455860932507823, 0.30198285055737345, 0.2165784647748355], [0.0686829999810265, 0.03765936167309842, 0.13215038144300062, 0.13272680131898773, 0.03044209904938696, 0.09161803300582594, 1.237468320515848, 58.34635457684917, 56.33917185568041, 34.117395493292044, 19.307735773824877, 82.9913123961418, 72.39452731224799, 49.94478279544462, 53.47966594080771, 73.74883544060492, 58.8259506225586, 72.27028231466971, 10.35218313817055, 0.24223471871547161, 0.549763141860885, 1.806477245784575, 3.889882160771278, 4.710580754664637, 0.4422487384609638, 2.649572328213723, 61.03895579614947, 60.40768169587659, 64.23390280815863, 58.401954174041755, 59.87688695230792, 55.23649161861789, 55.9445696492349, 56.30853029989428, 61.49213467874835, 61.034405846749586, 60.21409311602193, 48.48803804766748, 45.45062911125922, 53.799550917840776, 66.8872920928463, 63.15351340078539, 54.98001175542032, 54.561153611829205, 56.29336249443793, 53.45890483548565, 43.05099364249937, 57.57079216741747, 58.61850430888515, 57.609513805758574, 55.13331367123512, 52.22043214305755, 43.771540887894176, 37.94305178426927, 44.058740754281324, 39.74545932585193, 56.802293946666104, 53.741574364323775, 48.76601249940934, 43.816616765914425, 41.24645233154297, 36.10406029608942, 39.90177362195907, 36.97814479950936, 36.848361415247766, 40.52976077602756, 40.85458793947774, 39.24229768014724, 41.11762600560343, 40.43688689508746, 40.80215761738439, 40.113781652142926, 43.3979312066109, 45.155419764980195, 45.3947235691932, 45.38305451793056, 49.11043974661058, 46.7795124361592, 47.018192583514804, 47.687494062608295, 53.51242165411673, 56.27077356461556, 54.018427018196356, 49.693033310674856, 48.66555275455598, 43.53504550072455, 39.35732510782058, 44.967314658626435, 44.77624816279258, 41.50486200086532, 45.1565101838881, 42.62810722474129, 41.438895579307314, 41.779125890424176, 41.06825905461466, 49.80059646791028, 51.995684254554014, 52.56083896083217, 52.94230514957059, 55.5562706916563, 47.04965391466695, 47.670059127192346, 47.46771581711308, 46.322607301896625, 47.34670285255679, 46.61672622926774, 41.876055502122455, 43.04487474503056, 41.37344298824188, 36.193321674100815, 38.15401254161712, 39.120861099612334, 39.7447846781823, 38.26081083666894, 36.704218233785326, 39.597083906973566, 40.64893807134321, 40.252790451049805, 42.28144422654183, 45.00849170069541, 51.277102116615545, 55.916834569746456, 54.73439685760006, 57.830617812372026, 54.273137892446215, 50.50290861437398, 48.28263921122397, 47.89612885444395, 47.98513527839415, 52.42901986645114, 53.78568533928164, 56.81093492815572, 55.67302396220546, 57.590937460622484, 55.32461158690914, 45.384831351618615, 53.38308934242495, 60.5568023650877, 61.779766005854455, 64.20865058898926, 63.804701374423125, 63.03611686152797, 60.54286226149529, 61.068240211855986, 61.635281578187026, 61.0251098294412, 61.76398238828106, 63.03286521665512, 60.470106217169, 62.4571358003924, 67.02814440573415, 66.38929228628835, 55.29775119596913, 66.37966678988549, 44.12369912670505, 1.1471080659858643, 0.148655699806348, 3.3590371618347787, 1.4132923632860186, 0.271142877998852, 28.53213452523755, 78.23516399629655, 66.31399846846058, 76.9772598820348, 69.63700694422569, 60.6630083822435, 36.85399001644504, 27.222117800866407, 41.68007819883285, 61.686896047284534, 66.44161670438706, 6.84324598120105, 0.3771842781814837, 0.1046590481494223, 0.05004179401082858, 0.05212496327716978, 0.06865556637245802, 0.028013809088377223, 0.06840559954364454, 0.018171992438334613, 0.015108600266337877, 0.11798487946150765, 1.4289884629749483, 65.49041055863904, 65.45162224000501, 36.97365368566206, 29.572835430022213, 102.06394718539332, 79.91649581540017, 58.208855890458636, 61.685974290294034, 79.86556776108281, 62.98807959402762, 78.63100959408668, 11.808537610115545, 0.47736709757197293, 1.111388266567261, 1.8704894689782974, 2.54710947794299, 3.203459045579357, 0.5145475508705263, 3.536057895229709, 63.451790040539166, 61.24214633818596, 66.03809895053988, 61.09290407549951, 63.018497574713926, 55.79627267775997, 59.130699173096694, 58.51450266376619, 63.51918812721007, 61.52319200577275, 60.9776177713948, 49.51509891017791, 48.33115108551518, 54.305548437180065, 65.22578393259357, 59.830877550186656, 55.696248315995746, 54.91344128885577, 59.13202101184476, 55.10531579294513, 45.34608225668631, 58.76346334334343, 57.409802406064934, 56.203422546386726, 56.563805995448945, 52.75567093203145, 48.068838657871375, 39.82629153036302, 51.371250767861646, 47.58362577807519, 58.47903659266811, 56.51750633793493, 50.585121493185724, 45.5708929031126, 42.65144532726657, 38.47443488336379, 40.958067909363784, 37.87159404447002, 37.728447145031346, 42.42793690773749, 42.83279611218361, 42.066639546425115, 42.02517224896339, 41.677289393640336, 41.75590545900407, 42.52082647815828, 47.614541899773386, 48.009524576125614, 47.935234885061945, 46.25277342334871, 50.47782505712202, 49.06797224475492, 47.868217268297755, 49.072435902011016, 54.54200067827779, 58.52681498373709, 54.72399473190308, 50.897863834134995, 48.8763330828759, 44.61873362141271, 43.32158619357694, 45.62754369551136, 46.54193839719219, 41.80588037736955, 45.386521893162886, 44.75124305294406, 42.61680295390468, 41.18078401011806, 42.128130543616514, 50.632990098768666, 54.59808272700156, 54.12549203441989, 51.86431231037263, 55.70589342424947, 49.93198017920218, 50.810057655457534, 48.38272240854079, 49.41287802111719, 47.12465747710198, 48.86070243773922, 44.71392954549482, 43.36701116254253, 42.71926702991609, 36.93683047448435, 38.47647451585339, 38.59937414046257, 40.96365336448916, 39.84089843688473, 39.47254473163236, 41.580748096589126, 41.85226632702736, 42.75273269222629, 43.986302421938994, 45.8919624359377, 51.75494094048777, 58.002021466532064, 60.122905854255926, 59.669126849020685, 56.08640647703602, 56.32261553118306, 51.0650509403598, 48.29207251148839, 53.16243640838131, 55.30530960329118, 54.4428353155813, 58.782588820303644, 59.5883221011008, 58.66423130035401, 57.67715115700999, 47.857093426489065, 56.67060821287094, 62.20222488526375, 61.90306963459138, 65.48498592069073, 66.2633449800553, 67.28954684349799, 63.55759597593739, 63.14040091729934, 63.828039476948405, 64.54800228918752, 63.439026647998446, 65.24317179956745, 64.30879262185866, 66.1476742836737, 71.87588799384334, 66.90381311601209, 60.85775406129899, 70.41342443035495, 48.63658212846326, 1.2146869494069008, 0.23654418697039928, 5.077550353542452, 1.2521542873113387, 0.2592020187406771, 29.83162556925128, 87.40448090337938, 70.29983259016468, 85.78133352341192, 74.83401406195857, 67.04980373382568, 36.664229669878566, 20.199667061528853, 46.814362695140225, 66.91111656927293, 82.28189683729603, 9.978695050362619, 0.5748708462042194, 0.12388064616149473, 0.12801885394559753, 0.04074848865369155, 0.19107409542606724, 0.2698291291392619, 0.24459569444579465, 0.30209902013021134, 0.13925976931087433, 0.3828500499648433, 2.1041544983463902, 80.37664474979525, 72.61523908184421, 47.44633889967396, 30.587595739672263, 93.70244241529896, 78.2695161142657, 65.6180719406374, 66.98976009122788, 85.45922848486131, 69.85229799824377, 87.15759907999347, 13.834124092132816, 0.6299427620345547, 5.281247371627439, 4.6909041846952135, 11.811102840208239, 11.43412874590966, 1.1435888419228217, 5.763327258248483, 67.74742864793348, 62.59556408851378, 68.50550513113699, 63.51570114012688, 64.89353172240719, 59.42146839634065, 62.50074078959804, 60.45811553155223, 66.89651750749158, 62.16928089818647, 65.06844982024163, 53.1011454520687, 53.01373151040847, 58.02532819009597, 62.49723419066399, 59.14913823527675, 58.35504654915103, 58.57153000370149, 61.808858225422526, 57.982135049758426, 53.91973626229071, 59.8163059449965, 57.29179397706063, 59.51972376915717, 56.72393283536358, 54.32967885848015, 50.20097632561961, 45.859308704253166, 44.488173607857, 44.33543651334701, 62.01492778716549, 57.86893152421521, 53.033461032375214, 48.69359377891787, 45.06412659921954, 40.24436519991967, 43.15755659534086, 41.23818397521973, 40.84793167729532, 45.14707296125351, 44.78026466984903, 43.155407136486424, 43.942195369351296, 44.79232203575873, 44.47528469947077, 43.90734903274044, 48.8988749442562, 50.93623245916059, 51.638066076463275, 49.13516636817686, 53.040909613332445, 52.240836312693936, 49.75344173369869, 54.12692369953279, 57.161614433411636, 61.953966309947354, 57.960852269203436, 52.782417574236476, 52.43437782410653, 46.9151754533091, 44.615991884662265, 48.3399607289222, 47.65389111734206, 42.859707493935865, 48.28147034491263, 45.92813845603697, 44.5258754299533, 41.575939270757864, 40.20662415412165, 51.84957596563524, 55.690792299086056, 57.23251127427625, 54.969699844237304, 59.319639744297156, 54.5169641894679, 52.17963557089529, 52.32865033611175, 52.51252712741975, 49.71890134196128, 52.40169271346062, 45.552646037070986, 46.81597871165122, 45.65066214530699, 39.28177241356143, 42.30860663998512, 40.94759125863352, 42.30863017420615, 42.848242405922186, 40.324487455429576, 43.182557782819195, 43.0545041638036, 46.778790720047496, 46.188003324693256, 48.983813870337706, 55.432712108858176, 60.442457429824344, 60.0200338517466, 61.338146348153394, 60.05401334454937, 57.26838134950208, 52.2273668935222, 52.27163868565714, 57.05547509654876, 59.77325400998516, 57.85469724285988, 61.30590446533696, 59.6221996122791, 62.1212318635756, 60.53351133100448, 50.4299525291689, 56.15218070245559, 64.7302120731723, 65.05369386365338, 68.97266726340018, 66.81492436316707, 68.00893306732178, 67.20761637533865, 64.64600270794284, 64.47913331370201, 66.94528041347381, 66.29519462585449, 67.48721076596168, 66.69566077570762, 70.2351370165425, 76.01100752430578, 68.15436670857092, 63.184515814627375, 73.40545546623969, 53.34652500767862, 1.5780907460758764, 0.6501280756727342, 6.893895056939895, 6.502438591372583, 0.581351092025157, 34.84299475146879, 94.4429623696112, 75.9949807197817, 89.31767971284928, 81.41326442841562, 78.69878030592396, 51.37429452711537, 39.47697308755691, 62.5462128270057, 78.04357974759995, 99.02858180384483, 14.289845651195897, 1.0947952924236175, 0.2905761690870408, 0.22538666793655968, 0.1834294266037403], [0.08328241416283193, 0.015774174582123036, 0.04116612531605267, 0.1009603450074792, 0.06134388149685918, 0.1006109552878526, 0.5853460873326948, 50.52139474499611, 57.2967714648093, 45.46611462869952, 32.40722640868157, 45.75928042011876, 55.46882537103469, 48.21644529219597, 56.13185498022265, 71.59659954809374, 57.61160835143059, 73.06636656484297, 23.29199898627497, 0.29592398373830703, 0.038755097231196786, 2.4010443350961133, 0.2841982419692701, 3.2867410154111925, 0.24730059768884416, 4.614125259460942, 70.91206750562115, 62.059183889819735, 63.318296094094556, 63.73830741451633, 60.11392362656132, 57.72734965047529, 59.914086711022165, 60.70999837690785, 58.66943628557267, 52.260055926538286, 54.46076054726878, 59.34159717252178, 65.09874620745259, 67.03688344647809, 57.128776350329005, 54.80139094014322, 56.057612357601045, 58.1811482675614, 54.374829261533684, 57.150419988939845, 54.528221391862445, 47.20183011024229, 54.07363045600153, 56.32670264090262, 52.346650092832505, 50.28546810150147, 48.804161471705285, 63.406831833624075, 43.758118537164506, 41.721204250089585, 60.18895072321738, 50.352999548758234, 47.744795968455655, 41.62596125756541, 40.23784229832311, 40.69101725855182, 40.41365469655683, 39.30185494884368, 43.746527933305316, 41.06208524396343, 38.67022783525529, 38.90713114892283, 39.12989431811918, 40.46913270027407, 40.070082526053156, 40.638802666817945, 44.456806413588986, 44.268893503373675, 49.306613168408795, 47.212228313569106, 45.25473417774324, 46.141703667179236, 46.16464168794694, 49.74881333689536, 47.00952022306381, 51.349159979051166, 52.83384376956571, 51.92623476828299, 49.474051306324625, 44.36786274756155, 41.25315566216746, 41.83985594780215, 45.80911021078787, 42.453722569250296, 43.67608608738069, 44.879614383943625, 40.79653686092746, 42.13263342457433, 44.49366100372807, 52.551970481872566, 51.16764053221672, 51.11714393861833, 55.83988158933578, 49.97152159290929, 48.01967567013156, 48.88660184798702, 45.20343742062969, 46.83033066411173, 43.66915918165638, 46.59526301968483, 41.68193347992436, 41.8106617466096, 38.788295099812174, 38.13163934215423, 40.55086312755462, 38.93328159086166, 38.496788470975815, 39.872712781352384, 40.5023669427441, 37.935038382007235, 38.426362314531886, 39.849335455125384, 38.44642916033345, 44.247893133471095, 45.24779158253824, 54.57087716748638, 54.770988648937596, 54.53834110690702, 55.25091809611167, 55.51201851137223, 52.827689570765344, 55.6675208768537, 49.65581394010975, 51.17459881690241, 49.08002961066462, 53.9708015995641, 52.69399950581213, 56.787494844005955, 54.80517210498933, 52.39387150733702, 58.257422677932254, 57.488830320296756, 58.218877546248905, 58.61497809810024, 53.721931134500814, 56.881035527875355, 59.398047924041755, 62.25150162173856, 60.45699765605312, 65.11374142862135, 63.91539066068588, 67.90292709104477, 61.575437976468, 63.26857220742011, 62.24781459377658, 67.37750991698235, 49.6013008394549, 56.95530168471798, 32.70474995336225, 0.06992766303160498, 0.05752631981346396, 5.98103694377407, 1.791241166572417, 0.21279676366717587, 35.98643625936201, 75.67946526312059, 69.79015196523359, 68.95732295128607, 68.67966621152817, 59.201599936331476, 49.79865881704515, 45.59006544851488, 34.337358090185354, 64.75654686650923, 58.676386725518014, 2.54245019247455, 0.169308970592195, 0.062045736779128356, 0.11633271126136666, 0.09125732050667848, 0.04788829404259882, 0.0737149948855081, 0.04599655482677683, 0.13657106116654413, 0.0818216530305724, 0.1272374902281069, 0.7288591767991743, 64.25928446554369, 66.61801353577646, 48.74972289608371, 30.703148764948693, 65.93790592685824, 63.812189179082075, 55.43612457090809, 60.97658226566931, 77.78510339798467, 62.90920857460269, 78.25564661333638, 24.792480122658517, 0.31044328044499125, 0.5829827367298065, 2.0309065642856785, 4.338621410631365, 4.284789331497685, 0.6659982305380606, 5.3035887018326795, 72.71247463841593, 61.79167824406778, 67.6379317622031, 64.43424570945002, 62.06816219514417, 59.535895701377626, 63.49182175051782, 60.87627941562284, 59.790677178290586, 55.32122265908026, 59.07045156724992, 62.03904644135506, 64.19298072015086, 65.70000633116692, 60.25345017833095, 57.48826549899194, 59.65268427325834, 58.91127786328716, 55.43717576611427, 60.74133419221448, 55.64264520522087, 50.34508812812067, 56.47600373914165, 57.95251331021709, 55.06420150879891, 52.39578562398111, 48.307401134121804, 66.87103779085221, 50.784723066514545, 43.61887047367711, 61.99224472045899, 53.240154250975586, 50.509745305584325, 44.402501198553274, 43.07771675048336, 41.46853300832933, 42.48838847683322, 42.205534596597, 46.33623753824542, 43.17398740399269, 40.62616871249291, 38.55126627029912, 40.26952328220491, 42.08883231686008, 40.75371634575629, 44.58902951209776, 47.021809008813676, 46.74027696732552, 50.89485929858301, 50.10326616225704, 47.84109407855619, 47.4816402312248, 47.83725800052766, 50.00382623364849, 50.97806453704835, 55.111709256326, 54.61934981807586, 54.53971393646733, 51.38180194362518, 44.836597750263834, 43.93869269278742, 44.85270692456154, 46.19111768661007, 43.71821234303136, 45.547868590201105, 44.69238396613829, 42.231979216298754, 41.308390478934015, 47.38490281566497, 53.74744615247173, 53.7843595781634, 52.00248564443281, 56.37034293143981, 51.81158388814619, 49.25623816828574, 48.695927589170395, 48.7549945615953, 47.70566640361663, 47.87307316257108, 47.6069874148215, 45.34268156174691, 42.76744158037248, 41.152111484158425, 40.66829496814359, 41.58862421589513, 40.07161225042036, 40.872544550126605, 42.29868696581933, 41.19987418574672, 39.260422952713505, 41.55326797116188, 41.65367672520299, 41.855463058717795, 46.25641730523879, 46.807804492212114, 56.480439939806544, 57.61046694171045, 55.944008750300256, 57.76190180932322, 56.30441965595369, 54.33606447712068, 56.279677344906716, 50.8570162711605, 52.877087900715495, 51.49309527489447, 57.09723264940324, 55.572344564622455, 58.005406471990774, 57.97547486520583, 53.40014380793418, 59.06894537710375, 58.78733881058232, 62.6906737204521, 59.61686126647457, 59.62627495488813, 60.22385589538082, 61.27188574883246, 64.7316437382852, 63.22426511395363, 67.8853391831921, 66.66029668623402, 70.09852870818108, 66.46475084366338, 67.1028341785554, 67.19434307467553, 67.2702330927695, 56.2343700470463, 63.53252418579594, 34.90877289925852, 0.08149094053453977, 0.09408659046335567, 4.788614838354049, 1.6828316353982495, 0.22177474723467905, 39.44812405493952, 81.73887606590026, 73.79782584405714, 76.34117695593065, 74.72473682895784, 71.27427485681349, 47.666226971533995, 33.21290477629631, 44.690512995566095, 69.32536678929483, 74.0468571262975, 5.1025794879082715, 0.23278929894008946, 0.049878678569990786, 0.07760623124458137, 0.022952913516952146, 0.2858329510256168, 0.21462342371383022, 0.08505517226313392, 0.2729169231268668, 0.15141597588456449, 0.27291321526131324, 1.1097456514835358, 74.3821648628481, 73.70286526218538, 62.490213148055545, 48.65729616534326, 57.792002078025575, 65.13391810078775, 65.14523021636471, 68.8815192253359, 84.92796697924214, 68.08238337116858, 86.83084211041852, 28.193912467648907, 0.6167469894693745, 2.0947817496715055, 6.665347862628199, 4.911719406804731, 11.526680011903087, 1.311841729667879, 8.231956728043096, 74.871582523469, 61.45008294813095, 68.61711225202008, 67.01314526219522, 64.563832975203, 61.93461333551715, 63.36547828489735, 63.91153889317667, 63.9789762035493, 56.40489509028774, 61.15113558307771, 61.904273802234286, 64.11784771950015, 65.1122195489945, 61.23214821661673, 59.39617303109939, 59.50666619885353, 61.43322852350051, 59.207554094253055, 63.11665096590596, 58.07673869594451, 54.60135790609545, 59.398455850539676, 59.75933351824361, 58.50976051822786, 54.089825922443026, 51.50003787009947, 58.882742620283565, 45.559510184872536, 47.40496573909637, 65.27482140448787, 57.18725888959823, 51.39329841060024, 45.45012312550699, 44.39113024742373, 45.31941406188473, 45.58339349685177, 45.2362205905299, 47.273346685594134, 46.658256284652225, 42.4298627914921, 41.05131833784042, 43.71199146393807, 47.778167493881725, 43.21860828707295, 46.87867387648552, 51.82798724020682, 49.926402568817146, 53.60496605596235, 53.83554258654195, 49.78776639507663, 49.87437232848137, 50.14632201963856, 54.27266720802554, 52.58582053645965, 58.15446046090896, 55.40983684601323, 57.27768913392098, 52.57441036162838, 47.30643580036779, 47.304298108623875, 47.3833260228557, 47.91535239065848, 43.314682822073664, 47.66010415169501, 48.796618753863925, 41.81780830506356, 40.767381883436634, 47.31726938678373, 53.477932253191554, 53.81480501544092, 54.333734589238325, 58.17216603986679, 52.926847088721495, 50.508709799858835, 52.64284787639495, 50.180760429751494, 50.749653154803866, 49.108878643282004, 52.653179399428836, 47.25127158626434, 45.04856263437579, 43.99995227013865, 42.12832273975496, 45.27402439425069, 42.15914472456902, 41.488784205529, 46.18537141430763, 44.262884432269686, 42.01635083844585, 42.68192998824581, 44.245598546920284, 43.48454498475598, 48.783890662654755, 49.46964256225094, 59.86930893313501, 62.540384184929636, 57.2152606902584, 59.839545988267474, 59.92373181927589, 57.54284920230989, 60.3131055062817, 53.758134611191295, 56.639558730586884, 54.23729135144142, 58.92567296181956, 57.326793286108206, 60.53021261768957, 60.02970641659152, 55.99137529250115, 62.91920669617192, 61.64691140574794, 63.55041411615188, 62.40780807310536, 61.40042181937926, 63.900544489583666, 64.80263079366377, 65.64348105461367, 65.05307020679598, 70.87991975968885, 71.35261243389499, 73.27580544256395, 69.17361813206827, 68.75593277715868, 71.02634968296175, 71.89680991634246, 61.65419524715793, 67.35989847490865, 39.273884527144894, 0.3144927292821869, 0.3213362846403353, 15.637466138409032, 6.066883408254193, 0.6471136729082754, 44.88115587542134, 88.88380281386837, 80.32821132290749, 80.52021134284236, 82.3615131070537, 78.21911365755143, 72.40800457616007, 61.63083753278179, 54.28275162173856, 80.76123314519083, 89.42616462707521, 6.899447171918808, 0.8709877921688942, 0.25353972499649374, 0.2093929584108053, 0.1779545486093529], [0.07712720412640803, 0.11269878085342147, 0.0297237633006467, 0.04043009868192096, 0.08076296548449224, 0.02785668253988749, 0.18856357933292467, 41.997323420739946, 60.59174283858269, 41.50885889607091, 19.379271961027577, 22.937887407118275, 37.202841697200654, 47.74139919588643, 65.57478466341573, 71.43304455664851, 62.558921306364006, 68.77221061337379, 30.6702773417196, 0.1597258235297857, 0.7766164238414457, 0.6529336122255172, 1.2030576121422554, 1.478016619240084, 0.4186046604187258, 5.736182005174699, 69.74049475885207, 62.24686538019488, 62.59442660116381, 60.73215584601126, 62.966922329318145, 58.69498660487514, 57.59791927952921, 50.86147600604642, 56.84075278620566, 62.1590474344069, 65.13067822302541, 62.67856536373016, 59.23519895922754, 51.57161720337407, 55.514242495259936, 56.09394527250721, 55.7264897900243, 51.61356302999681, 57.079005395212484, 54.47627744367046, 55.8900487038397, 53.59940805742818, 52.621392511552386, 53.44549032949632, 57.907225624207534, 57.256284759890654, 64.24007661880987, 46.208383960108605, 36.70251984750071, 53.23751449584962, 54.78465418661795, 51.46296754960091, 44.416531516659646, 44.35592697512719, 39.37374414936189, 39.74160363597255, 37.65081951695104, 40.283577134532315, 36.75234571579964, 38.89545817529002, 39.51698126331453, 40.87313290565245, 37.18208451424876, 39.043202092570645, 39.338062347904334, 41.81209341172249, 44.20817913547639, 43.95475872101323, 44.705990668266054, 46.52035359413394, 46.83314300352528, 48.495164994270574, 47.35006432379446, 47.36696973923714, 46.82913434120917, 48.199143717365885, 53.16639015751501, 52.42233222530734, 49.79726245326381, 43.827132640346406, 38.47634507763771, 43.01389194303944, 44.743002153212025, 42.17206108954645, 43.750171815195394, 45.49852909580354, 42.301416935459265, 43.903705150850364, 48.34429102559244, 53.25017590676585, 51.808881375097464, 53.632336355024776, 53.14991620279128, 49.47729118408696, 47.84008210705173, 49.21532392501832, 43.1417102198447, 46.1399660571929, 45.679420963410415, 46.1445709197752, 41.82145218695364, 42.67376753591722, 40.09490328450357, 39.41701573710288, 37.444157677312056, 37.24938454166536, 35.147484425575506, 38.784251136164514, 39.30264726761849, 39.2209364521888, 38.81848558302849, 40.960939084329915, 38.93335611589494, 41.598383072883856, 43.17671737363262, 47.75576683782762, 53.96159579676967, 55.74660370426794, 55.4933205727608, 54.861214930011386, 56.0668142380253, 54.9712727146764, 53.7044491306428, 53.030127017728745, 51.08887541678644, 51.82901097882179, 50.965018733855224, 57.2292439399227, 55.13820878921017, 55.79109122676235, 56.60636763418875, 53.60304801694809, 56.64202590142527, 55.912096346578295, 56.98162863331457, 59.17846971942533, 55.77363275712537, 58.06136300486904, 59.21341411529049, 60.718953148011245, 61.79185867309571, 62.456343481617594, 60.779996995002996, 66.14528948260893, 60.15497123041461, 66.3257263552758, 52.62087083631947, 51.97914754190753, 22.29792525691371, 0.15232880028986162, 0.39058870245372096, 6.418943587810763, 0.3986567421065223, 0.15740448518866496, 39.52047609513806, 73.2956055671938, 69.57664166727375, 66.92056948138823, 63.04272213289815, 57.448131807388805, 54.970762806554, 46.95800773559078, 39.874779870433194, 64.69118841232793, 58.16745919566001, 1.1539642464730049, 0.12590902481949137, 0.060352720770864725, 0.051072335486570676, 0.09190480269852186, 0.05368301757581292, 0.06126822265345724, 0.027517085339153008, 0.02092791713714119, 0.07316274508353203, 0.020273599525793426, 0.3198377860169257, 55.16833259213356, 68.39057184034779, 48.36856265221873, 27.267038745264855, 33.37668726521154, 41.19890536031416, 54.845721567830736, 68.19759122786984, 77.76688791090443, 65.00782566685831, 75.36289076651298, 32.97640938912669, 0.12878638211517565, 0.26317004775328023, 1.5999308709175357, 3.7293348918038034, 1.339848801012962, 0.35795234564331274, 6.910595528541073, 74.75602949819258, 64.08922226198258, 64.9526143843128, 61.726939524373705, 64.43057829333891, 61.45673136557303, 61.860864931537265, 53.73088198323404, 59.046478040756725, 61.968063308346665, 64.75753530379265, 63.763430195470015, 61.238945684125355, 55.10119338189402, 58.82133791523596, 58.14796893827377, 58.42793987643335, 55.749345441018384, 59.667699106277965, 55.64040553185248, 57.39083382391161, 56.79327249526978, 54.65532971966652, 56.6941188996838, 58.07235740846204, 56.67866083883471, 63.90927176321707, 51.1081499438132, 39.86114571171422, 56.202461565694506, 56.7168451124622, 55.67739740494759, 47.82932696803924, 46.6693526698697, 40.10874532884167, 40.42462164355863, 39.83314391105406, 40.08701539808705, 39.399066971194365, 40.72144700634865, 40.525363799064394, 41.98923549344463, 40.25691286210091, 41.71919207419119, 40.58057115923974, 45.86330952182893, 45.081643904409106, 44.48852662117251, 46.16411216797368, 48.73152309848417, 49.2136255387337, 49.64916552266767, 49.69381778470932, 49.34518183431318, 51.29962044377481, 51.57437855197538, 56.39372025766681, 54.843980035474225, 51.30138943272253, 44.80814095466368, 40.45385899082307, 44.16316993774907, 43.53298233401391, 44.93790080470424, 46.12706538169615, 45.464616283293694, 43.69653340308897, 43.89289117628529, 49.14092440758982, 55.13740470332485, 53.300382244971495, 54.197330244125865, 56.033525082372854, 51.37728729555684, 49.22386292488345, 49.242980557103316, 45.946220582531346, 48.515290675624726, 47.33966219809748, 49.000076017072125, 44.98966040149812, 44.33813510402557, 42.027647264542125, 40.212868567435976, 39.39865512232627, 39.94051487215104, 37.600868132806596, 38.90586422335717, 42.3513134064213, 40.19946975092734, 40.465210330101755, 42.627962097044914, 39.927496525549124, 44.27270212481099, 43.8636734408717, 48.741101526444965, 56.60057821581441, 57.76282356631372, 58.834732809374415, 56.23812767767138, 57.97114456853559, 56.25068318459296, 57.33582650461505, 55.61703605036582, 55.220813905039144, 55.479353012577185, 53.77782883182649, 60.09454711791008, 60.03657056439308, 56.09803630459694, 58.653601677187034, 57.82289858787291, 59.20428283752934, 59.261396469608435, 59.86877549079157, 61.111190165242846, 60.50197547481906, 60.57539832207465, 61.420865212717366, 62.183730909901286, 63.489982158907004, 62.65630983537244, 63.50813488806448, 67.514510462361, 66.31174702798167, 68.7051067044658, 56.27282496421569, 58.27865054530483, 23.615876936143447, 0.07374894024143297, 0.22048520675349623, 4.138377058890558, 0.41746677470303356, 0.11041691902303889, 46.19394179313414, 78.1138764658282, 76.31838798522949, 72.91622607938706, 68.26933922306185, 66.60812916294222, 54.82906718407908, 46.11440397077992, 48.84465602136428, 72.46179596070321, 69.3262767791748, 2.38681691788858, 0.2422303673360617, 0.2074887089791798, 0.060316752942819754, 0.07595835313681634, 0.12441768145729458, 0.2315835531560644, 0.20705141067024202, 0.14711276808333013, 0.12205556425596438, 0.25738427595746133, 0.42530103496486144, 66.4247505126461, 77.34127936824676, 58.53111390144595, 32.17925629308147, 37.225638512642156, 53.06942132211501, 61.42736065772272, 77.54091232053696, 81.97614808236399, 71.35191425200432, 79.95718648356777, 37.08711216526647, 0.47792655626131647, 2.5974582472155174, 3.352086721889435, 5.541826601951353, 5.406016495919997, 1.1246080023627127, 10.809798221434317, 77.99364013056602, 62.201663986329116, 65.85675208799302, 65.17640913686445, 68.36120897723784, 61.39001969368228, 64.1723333635638, 56.67596617052632, 60.75154019940285, 63.90998563458843, 66.29812071400305, 65.08452369320777, 63.77661328161917, 57.04091525846913, 59.66906409109793, 61.13444589799451, 61.95192275508758, 55.71908435513897, 63.448514861445275, 58.046716874645604, 58.753120053199034, 58.550498254837535, 58.28849961680751, 60.1549869198953, 57.3743010336353, 57.13484425698557, 61.33674213963171, 50.49841750052668, 44.167723809519124, 58.99049405128726, 58.988348514803, 57.17523290264992, 48.044112036305094, 47.34973092232981, 42.82905024866904, 42.519900798797615, 41.85166228202082, 42.775772694618475, 41.0414457321167, 43.07003282731579, 44.19094424093924, 43.25219946522867, 41.820291165382635, 43.43832377464541, 43.794290634893606, 47.37322591966199, 47.48713939420639, 48.05331783909952, 49.11715876671576, 50.9996493401066, 52.16085134014007, 53.07395950440438, 51.59468073998728, 51.3597111548147, 53.6803069422322, 51.782923129297075, 59.27237518372075, 56.6270463697372, 53.408655351208104, 47.59432992627544, 44.240942693525746, 47.969339893710234, 45.332099007022, 45.48910364027947, 47.88801347055743, 48.46181308069537, 43.36911747532506, 44.852981490473596, 49.21418251529817, 55.38102311472739, 54.85352708447365, 57.35542266599594, 58.31215935368692, 52.9098436140245, 51.53673556543166, 52.64766454696656, 48.389672848486136, 50.65449645442348, 50.561783390660445, 51.96957695868708, 47.033572196960456, 46.64204512873004, 45.334644625263834, 42.90649352535125, 41.47900965905959, 41.043712862076305, 38.50542945246543, 42.844429862114694, 44.32740349923411, 42.52132069679999, 43.21545470145441, 44.454594196811804, 41.93712680570541, 46.39715194702149, 46.463663578033454, 52.591943356298636, 59.6320173048204, 60.62372976733793, 61.27505502393169, 57.92844956920993, 59.99688402298958, 60.692335944021906, 59.79175583008797, 59.73108460826259, 57.339882235373224, 56.756543420976215, 57.72255651412472, 63.625723623460345, 61.68639398390248, 60.12760093135219, 60.65214341686618, 58.869998839593705, 61.2998208691997, 61.71996555020733, 63.60917514370334, 63.64229955980855, 62.43660219254033, 61.88738799864247, 63.90462375456288, 64.61237622845557, 67.40852802030503, 66.17386787168442, 67.9991114524103, 70.18886089324951, 68.2278170124177, 70.3071125092045, 62.87279721229308, 66.75798723774572, 26.63201682029232, 0.2670472187380637, 0.6512670339115205, 12.041335182805216, 2.427660558492907, 0.2022188361133299, 50.63319013964746, 85.65120497057515, 79.50784760136759, 81.76131202328591, 75.50161715476744, 73.38744394240841, 71.98176845427483, 62.8888044049663, 59.25612872646701, 83.80416085643154, 83.22431687385806, 4.893595605127273, 0.5278506370321397, 0.3732262389554132, 0.25075703318561277, 0.19819134335604408], [0.01257463613705289, 0.060259671731581615, 0.04626548999259549, 0.14044905952628584, 0.042191936198862336, 0.13813853834665593, 0.09002679177830297, 38.21065941164571, 68.5507849724062, 43.69110092040032, 32.49505808276515, 23.981781121223207, 29.8984549122472, 45.86845567149501, 60.48372076403711, 69.06982437256845, 58.586282037919574, 68.72405959713844, 36.00720520942442, 0.052932741706289595, 0.330449452082957, 0.8656095485052756, 4.299084899886962, 1.2105153861545748, 0.24974739058844506, 11.006954196960697, 60.887913165553925, 49.9079752737476, 59.55246771535566, 56.01046939049998, 59.22219630210631, 49.612201106163766, 54.62928518172234, 58.83311679286342, 65.69778626964938, 57.26554939823767, 58.82540149073447, 54.14836337489467, 55.736844847279215, 56.26590590323172, 55.77256195006832, 49.47014854800317, 50.98011593664847, 51.23509353207004, 53.10233000786074, 51.16399272795647, 52.82599902922108, 51.03454274515952, 57.66259131893035, 54.893947109099365, 50.116559074771025, 43.41583290407735, 40.746322677981475, 39.887900198659594, 54.604170245508996, 56.12270409061063, 56.51392913633778, 48.8398079718313, 45.48125497756466, 43.901151687868186, 37.92508732888007, 37.625755571549945, 37.99550564058366, 38.13745621711978, 36.62247603939426, 39.90640986350275, 38.063241051089385, 37.498553106861735, 37.86165475845337, 37.747592233842425, 39.29505355896489, 40.105932989428126, 42.443598931835545, 42.86485364360195, 46.57756528546734, 48.37327734116585, 48.76374144707957, 46.735130817659446, 45.864905926489065, 45.91406891422887, 47.819583800531205, 50.55460937561528, 51.31477648212064, 52.43114186871437, 47.49818086624146, 44.58824111569313, 41.60849886555826, 41.14070130932716, 43.86474817029892, 42.89910770231678, 45.515693387677594, 44.5296448276889, 41.690519548231556, 47.35044871607135, 51.46827843881423, 52.679639708611276, 52.867991924285896, 54.871397402978715, 49.00749714143815, 47.9377059782705, 47.58670091629029, 45.48740133162468, 48.04591632658436, 46.98884148751536, 43.7263826401003, 44.35744493238388, 43.05003266180716, 40.53203182835733, 38.47774144141905, 38.07378438211257, 36.63019526389338, 39.68671791015133, 37.064099619465495, 38.63169839305263, 39.10339870760518, 38.38966461919969, 37.76819252198742, 41.57838682974539, 38.04258977213214, 40.36209514064174, 43.17800783341931, 43.358126994102236, 49.935800567750015, 56.16798000950968, 54.475022285215324, 55.540236042391875, 56.85062931429956, 56.54102879185831, 55.20338289199337, 56.27065197114022, 54.20708910111458, 56.293656672200854, 52.990809179121456, 53.54839371096704, 55.603150859955825, 56.10602617263795, 53.911087436060754, 51.03332288803593, 50.39041111546178, 49.14344256924045, 51.64383196061658, 58.35115163556991, 60.43087467070549, 61.222616857098, 59.34181682525143, 61.758051764580514, 60.30138938657699, 66.60225345242408, 61.53666926968483, 65.13478102222567, 61.8284426196929, 67.84185578746181, 50.52226943354453, 53.45175043229134, 15.159324311440992, 0.21948063565838724, 0.11599447578191759, 1.9383478212741114, 0.18272983511128735, 0.018992194898366448, 50.49240842942269, 71.70796348202613, 70.11663436889648, 63.833993634869984, 67.72990349800357, 58.139900622829316, 39.863758010248986, 28.276072394463327, 39.599813876613496, 67.04042926911386, 53.00811075395154, 1.051405788429322, 0.24438287522042954, 0.06942284939390037, 0.04035348605905329, 0.029092485783621672, 0.015855442146740614, 0.05168491854302345, 0.029416765056310162, 0.060459107400909554, 0.05795522945963087, 0.0690688631467281, 0.11695689671943266, 46.39884641093593, 74.9462095383675, 53.132257692275516, 29.447250943030085, 27.44811692545491, 43.76868148003855, 48.949599035324596, 66.01364689488565, 75.77363352621757, 64.5739330783967, 74.97136762065273, 40.418126198553274, 0.009684503367621332, 0.5392624053262896, 1.1317821399819468, 4.8004373523496815, 0.6212740788056005, 0.43073308864428156, 11.631733832820771, 67.5180092165547, 51.13448473715013, 62.23085818752166, 58.126568486613614, 62.791364885145626, 52.143655669304636, 59.19683425657211, 59.69488113157211, 66.09249438008955, 57.078754363521455, 61.876428896381015, 55.88618516921998, 58.7928105169727, 58.24998586408554, 57.037192929175596, 52.783366787818174, 54.40645140986289, 53.132579326629646, 54.833766183545514, 52.670053435910134, 55.16977994672714, 54.08098097770445, 59.13917149266889, 54.347482496692294, 51.88859178173927, 47.64227305689166, 44.738189405010594, 42.16280037356962, 57.19771200610746, 57.59985693039433, 57.82378112116168, 50.91869946449034, 47.10819136711859, 45.42072888343565, 40.598814102911184, 38.56771669080181, 40.64711416921308, 38.91798434718963, 38.13170994481733, 42.07282120181669, 39.163218775103175, 39.61658593147032, 38.973474118017386, 40.589773039663996, 39.89016732861919, 42.43089045247724, 44.00620452819332, 45.078168684436434, 47.94757466162405, 49.90446475244338, 50.79302672416934, 48.67717865974673, 47.63249066568191, 49.001746946765536, 49.644615573267785, 51.47231063535137, 55.30973011447538, 53.69266240827499, 51.38615185214628, 45.318049077064764, 43.48202290073518, 42.788610612192464, 45.27082766256025, 43.69119897965462, 46.186724632017075, 45.600318524145315, 42.176548281023585, 47.92713126828594, 51.6457421548905, 54.44456508082729, 54.97999214356946, 56.51587070957307, 50.7331556658591, 49.37696872218963, 48.30680493385562, 46.23626024492326, 50.35263869070238, 49.263180763490745, 46.48930411184988, 46.518717965772076, 45.46663238156227, 41.01127486075125, 40.047638723927165, 39.64671365676388, 40.67851274244247, 41.169938656591604, 39.93538441196565, 40.4269632985515, 40.06696031939599, 40.07335770514704, 40.33881587366904, 41.33072445469518, 39.87651748041953, 40.93051325890326, 44.7772091434848, 45.71335338777112, 54.04813504988148, 58.85377983893118, 57.23347225496846, 57.98397071899907, 57.6167780353177, 57.71799479761432, 56.15114127435992, 57.5448025426557, 57.0503407139932, 58.55575423086844, 56.00677451779766, 55.64399057818998, 59.134264607583326, 59.65391197512227, 57.452626843606275, 54.0144536572118, 53.16156956457323, 51.51222467422486, 55.067288414124526, 59.598041734387806, 63.51935678912748, 64.21521663665771, 61.25984015003328, 65.77996776949975, 63.13286996656849, 68.14888323507002, 65.12697550558275, 66.45534499999016, 64.6543259774485, 68.7939719230898, 55.16223722888578, 58.83259119526033, 17.114158099697484, 0.5316938856436361, 1.1075069587076865, 6.498421103723588, 0.5673939506373098, 0.055686356650004466, 57.30729518398162, 76.63837494388704, 77.67577125180152, 69.17082540450558, 74.71784914693525, 64.21684442027923, 58.99120792265862, 42.81519251485025, 46.256429072349306, 78.62758928729643, 65.98145992525163, 1.673758702893411, 0.27889274601494113, 0.0274155346391302, 0.029850947302615935, 0.07336082477723399, 0.19205949900131072, 0.1727422242683749, 0.14353959610865963, 0.22676922681350864, 0.18622155661784834, 0.1582614004972481, 0.2786153302558007, 52.9318481106912, 86.47496546468427, 60.11726940831831, 47.20691350198562, 35.45061303723243, 43.18009061198081, 60.55813204857611, 72.23464365928405, 81.27816231020036, 70.61621881300404, 81.98185120859455, 46.52578607682259, 0.1558161857387712, 2.1138069610441885, 5.370130731213478, 14.199110442592254, 8.116409096025652, 0.9113136799104753, 16.213679967388032, 71.35866857344105, 54.89335483120334, 62.0757951274995, 58.084865846941554, 64.17057614172658, 53.26579086242184, 60.57280955776092, 60.91655039018201, 67.98009580181491, 59.644004068067005, 64.1108698229636, 60.663506523255386, 61.7308226708443, 59.85005794032928, 60.45722123115294, 56.316865336510446, 55.256040711556714, 55.49943554785944, 57.183724834072976, 56.45448561637633, 57.86489932767807, 54.897512543586, 58.833434504847375, 54.73258080021028, 54.624366529526256, 52.76449234254899, 48.84389115918068, 46.481635878163004, 57.78248640798754, 59.63845783664335, 60.09496681151852, 53.92116400503344, 50.68804840887747, 48.209537998322524, 42.63029982966762, 41.373286093434984, 42.95306774877733, 41.03161627246488, 41.11510392158262, 43.42090452871015, 41.602536862896336, 41.91486735497752, 41.2231416856089, 41.631742831199404, 41.502826290745894, 45.21846009838966, 47.077490975779874, 48.09927625040854, 50.86637112402147, 54.81795903175108, 53.968954163212935, 51.029008280846384, 49.21590835817399, 51.435860049340036, 52.79840515505884, 53.775498943944136, 57.829923552851525, 56.30077577406361, 51.50693731923258, 47.25027922661074, 46.795641222307765, 46.58003245630572, 48.369386349954915, 46.88012515344928, 49.081908425977154, 48.15659776810677, 43.11597947151431, 48.6486904851852, 50.949599896707845, 54.816629348262666, 56.75728082656861, 60.72381688702492, 52.45815915446128, 51.90489315217542, 50.066835188096576, 49.6848943925673, 53.55160613213816, 49.8058916676429, 47.30293704617409, 49.388888805143296, 46.31345248991444, 44.10072972697597, 44.028966042303274, 42.01719022566273, 42.37025060961324, 43.999689471337106, 41.58403504279352, 42.987337496972856, 42.44542675633585, 41.304024880932225, 43.180812328092514, 44.589943424347915, 41.02431281920403, 45.115752835427564, 47.236927478544175, 49.317933128726104, 57.154110939271995, 62.93257413371917, 59.584513479663485, 60.07946560459753, 59.12906746710501, 60.33480798044513, 59.81228943794005, 61.49482150231639, 59.83363889878797, 59.35481163763232, 56.96759831520819, 57.5949029768667, 61.69060268709737, 61.38714067397579, 58.62253650542229, 57.17900622275568, 56.19778217807893, 53.71760476020075, 55.786282400931086, 64.00693485813757, 64.7558996754308, 68.31550551999, 64.22865859923824, 67.43943629726287, 65.70150075420257, 72.1259077133671, 65.6962957689839, 70.51261332727248, 67.72065454913725, 74.73025168142011, 59.30522895628407, 66.59103547373127, 19.076308088917887, 0.431708962085747, 1.147470272356464, 4.582587442090435, 1.1777091723295952, 0.1469354187288592, 61.67290495287988, 84.22547048138034, 82.32043804660921, 78.53967328225413, 80.08008218580677, 75.66972994035291, 58.31927845554968, 45.00615396807271, 61.379484207399436, 85.127819584262, 82.14971296248898, 3.3632046801428643, 0.5278103101638056, 0.38820325787509646, 0.20373435721041697, 0.21639584473544554], [0.02139071468263865, 0.08061415290520077, 0.04994438976169594, 0.10465203078403588, 0.041553850075410265, 0.08376622166965278, 0.41936112627867733, 23.76525648178593, 73.35761039487778, 46.49281071078393, 49.92643002540835, 23.685032244651552, 16.093337728131203, 45.313424602631606, 66.50846173686367, 67.58031998911213, 62.95637899829496, 66.48368804685532, 50.04416781087076, 0.5960066604518122, 0.29871793704167493, 0.3737281184763678, 3.9468658643384136, 0.6245545285844034, 0.33364762401869225, 15.700259362497638, 59.11522934513708, 49.24591448999221, 56.71960253869334, 47.33419833644744, 52.18558188407652, 53.81865286057996, 65.85970955510294, 59.91016434084985, 60.75249333535472, 58.17582953360773, 58.5654503299344, 55.714879574314246, 53.11445797643354, 45.545248446925996, 47.386428617662006, 44.8891810447939, 46.950315967682876, 46.38448269136491, 52.22389167354953, 50.706299197289255, 52.77984057703326, 53.56277312001875, 47.81806192090435, 39.550427313773866, 45.79870024035054, 48.96468839337749, 56.214871944919715, 58.732166751738525, 51.785292240881155, 53.73796578376524, 52.22120092761133, 43.20840620225476, 44.709375673724765, 40.63657868293024, 38.552125269366854, 37.80203473183417, 40.24514967395414, 38.75150718996602, 37.18073914127965, 37.80292903223346, 38.68238326041929, 38.18226145159814, 39.532458936014486, 37.44809181459489, 39.615589649446555, 38.55955031610305, 41.54815320045718, 44.38014761094124, 45.619946064487586, 46.48882950505903, 47.4857783317566, 47.71324442278954, 46.96338138272686, 46.973352047704886, 45.063801042495236, 47.35694023870653, 49.239846583335634, 51.31102277386574, 46.53463102156117, 42.288551561294064, 42.97080862906672, 40.93627522068639, 46.95321067687004, 42.48441511584867, 44.294871361024924, 42.871207883281095, 45.73206309349307, 51.390776326579434, 51.736533257269095, 52.223118966625584, 52.692367799820445, 51.76636680479973, 48.22913023733324, 49.09120836565572, 47.78687123329409, 44.4239055725836, 46.06573912405199, 45.57713339405675, 47.6426496044282, 44.2271359505192, 44.43151497071789, 40.17069916571341, 37.968111807300204, 36.61018725364439, 38.287357437995176, 38.0363610482985, 39.00737516341671, 36.640146317020545, 39.27921502820907, 39.17309138082689, 38.303031229203754, 39.922040508639434, 38.87514422016759, 38.01990670542563, 41.90690886589789, 44.64700606561477, 46.07176388463667, 53.20636695431125, 55.52245986077094, 56.139460455986764, 53.940642495309156, 56.28341928605111, 55.22746232248122, 56.33142909696026, 57.75635165552939, 53.912083718084524, 56.03030089409121, 56.7403793334961, 54.86785942508329, 56.28315648724956, 56.47758837669127, 53.8344874689656, 43.754000048483576, 49.689220766867365, 56.937749078196866, 63.06278897869972, 61.64145538883825, 63.17575323966242, 59.728942994148504, 60.85245886156636, 55.38987198183614, 52.000171446031146, 59.69197073290425, 69.99373866665748, 60.13957592748827, 58.551427856568374, 48.2314169791437, 62.864054249178984, 10.208765595189988, 0.24783923410840575, 0.2896572619436249, 0.26870273474243384, 0.2424747340621487, 0.2672063811652122, 54.493724146196925, 69.80668867788008, 62.03097420354044, 66.1985944932507, 67.74215698242188, 64.1177418155055, 31.95748744472381, 16.14740465917895, 43.45655102883616, 64.52405229691537, 49.41073248463292, 0.915361994937543, 0.022460167679274758, 0.05438069767889477, 0.06304029510506699, 0.050287872943426334, 0.04617092026878269, 0.024638594233340794, 0.06271573429506633, 0.09187299472790572, 0.05262976159311591, 0.10466244957980611, 0.518291391912968, 31.084175648227816, 80.41546052502048, 55.26534065123528, 47.906193656306115, 25.913664141008933, 30.584477455385272, 48.19022424759404, 70.89200065981957, 71.81662882527998, 69.45803703800325, 70.1679781944521, 55.86696163300545, 0.3355123126699079, 0.36486475698409543, 1.2885009305131052, 4.201390426005087, 1.3110722096696978, 0.4295805246839601, 18.552754040687315, 62.90237580576251, 49.25152347933862, 58.254908438651796, 49.528129023890344, 56.46127916151478, 56.70864343643189, 68.24592267313312, 60.76601374533869, 63.413464561585464, 60.90025686448621, 60.06148153735746, 57.48355473241499, 56.11313350739018, 47.60793662840321, 49.689628693365286, 48.18732953840687, 48.68822797652214, 48.22091679419241, 55.08695910053869, 53.59051212187737, 54.51630523127895, 55.99212446520406, 47.900094370688166, 42.78784967237904, 48.61332247334142, 48.98715572972452, 56.28385859151041, 60.24075346608316, 55.746992018914995, 56.86711895850397, 54.87492361376363, 44.78377911352342, 45.29194178119783, 43.933515164159964, 41.04340299483269, 40.95260797008392, 41.78325222384545, 41.2373524327432, 39.47256826585339, 39.532298118837424, 40.444637498547955, 40.38322494876, 40.17375861444781, 39.29182544831307, 40.74513812218943, 41.95969612367692, 44.57450105297951, 47.77031490879674, 47.813821838748076, 48.08463012018512, 49.477867772502286, 47.730620522652906, 48.49264683261995, 49.43386270153908, 47.39701117238691, 50.04727432804723, 52.64656628331831, 52.387293692558046, 47.54368036024032, 46.179589840673636, 45.52673093734249, 41.54607826663602, 47.2475649464515, 43.98137592500256, 44.33984917979087, 45.54023958021595, 48.79493213468983, 51.541685596589126, 53.96853839197467, 55.32463904350035, 54.83870052522229, 52.907325452373875, 50.32214226261262, 50.3068018728687, 49.07637396166402, 48.00067570901687, 47.512101357983006, 46.77849654228457, 48.82603260778612, 46.602405655768614, 46.36199966553719, 42.08351358290642, 39.85927081877186, 39.27536718307003, 39.90759441929479, 38.542405636079856, 40.053133964538574, 38.61494202767649, 41.91802094059606, 40.3632483174724, 39.571592423223684, 40.49533413302514, 41.21633245098976, 40.986505093113074, 44.41804162917599, 45.444055218850416, 48.18398375664988, 55.856347699319166, 58.84615867368637, 58.35222244262696, 54.801865546934074, 58.16493318926904, 58.361467469123106, 57.26149366747949, 58.1663138635697, 57.76114871425014, 62.67174043963033, 60.10091312469975, 55.85379423633699, 57.086575569645056, 58.29833299882951, 55.487680204453014, 47.5392637714263, 52.169664905917266, 58.87482335490566, 65.79358623873803, 63.60324059763263, 63.866674823145715, 62.83684476729363, 62.54224338839131, 57.02431578789988, 56.251863818014826, 61.91287556002217, 72.24896815515334, 62.76832488275344, 63.09384630572412, 51.90671313193537, 67.19623365709859, 11.486055043435867, 0.5063756909822265, 0.26978169297499044, 4.656958032038904, 0.7855601632787336, 0.25693833617673767, 62.22415485689717, 74.5699679466986, 69.3878972145819, 73.33771613336378, 74.64432824042537, 69.24650361461025, 47.683038250092544, 25.955937485541067, 50.020217818598596, 74.74332886357462, 59.34944583523659, 0.9925575494285553, 0.06186110575893714, 0.0817288184959081, 0.08705217962063129, 0.07259363368634256, 0.14860120031141466, 0.18084346617181457, 0.1907150146941985, 0.15886759054997276, 0.2133946799703183, 0.3532794544533376, 0.9056631992420844, 32.85663000998959, 93.03560026230352, 62.26486121454547, 65.83833263766381, 33.377632556423066, 29.317663677277107, 58.19047174146099, 76.2689268973566, 79.04656117962253, 74.83564576795025, 78.8077437493109, 60.46175549107214, 0.7223941914496884, 0.9153484505030417, 3.9070922953467218, 9.266102371677276, 3.5267486399219887, 0.8945560275066284, 21.514457310399703, 68.66357664908134, 52.16382449673068, 60.079744092879764, 52.43586440240183, 59.64889526367188, 58.776791557188965, 68.22574600096672, 64.0565920645191, 66.33315532438218, 64.58955587879305, 61.725904018648215, 58.56978062660464, 59.677167707873934, 50.47529512836088, 51.38340619302566, 49.52644240471625, 50.437648219446984, 50.784487724304206, 57.847072155244895, 53.906631623545, 57.61863723877938, 57.50087984146611, 52.524145187870154, 47.02392316633656, 49.79423046112061, 50.17009550525297, 57.714837289625606, 63.01881528669789, 56.91832942347373, 60.135029900458555, 57.59451858458981, 47.285862968813994, 47.985300017941384, 44.28061354544855, 43.91251479425738, 41.55397007542272, 44.95535927434122, 44.3010804730077, 41.712269090837054, 40.7728418227165, 43.327528584388, 42.67963147932484, 41.87907964952531, 41.50165742443454, 45.936983400775546, 42.302828988721295, 46.88307477581886, 51.257525567085516, 50.24378899605044, 51.04823573943108, 52.32649303251698, 50.669397538708104, 51.845822257380334, 52.155673811512614, 49.7710806323636, 52.872365367028024, 54.3209437401064, 57.033090129975356, 50.52602314179944, 48.05658125108289, 49.676508365138886, 46.457587826636534, 50.07248340114471, 45.69655387632309, 47.95131660276844, 46.95246934890748, 49.912764487728, 54.51068839719219, 56.137750302591634, 55.84772632968042, 58.62109699556905, 56.545547362296816, 52.34902312678676, 54.35282868723716, 51.95701752939532, 50.57363287095101, 50.718740955475845, 51.31046187493109, 50.89696561136554, 49.0118823512908, 50.55830817068777, 43.264923634067664, 41.05074174942509, 39.3399803869186, 40.4261278337048, 41.184914265909505, 41.83827131025253, 41.042434169400124, 44.68359001221196, 42.58557696496287, 41.56914964798958, 43.48382719101445, 41.85794984140704, 41.98389322526994, 46.10684556345786, 48.70823598677113, 50.5837368965149, 58.43292520892236, 59.94442232193486, 61.11760324047458, 58.501503929015136, 61.477508160375784, 59.781534133418916, 61.47952425864435, 60.91341249404415, 59.64626727565643, 60.48462683154691, 62.54618929278467, 60.435161821303836, 59.71072750706827, 61.830737206243704, 58.468916877623535, 49.031129421726355, 54.24506941149312, 62.22295853399462, 67.81943551955685, 66.43931035072573, 65.80655359452771, 65.20941195949432, 64.34954212557885, 58.05536177850539, 59.152786039537006, 65.5018638795422, 73.84588272340837, 65.56951692027431, 66.77247647316226, 56.455658405057854, 69.47276946037047, 14.440157740346848, 0.5835116438327298, 1.160569517843185, 3.2777016682009545, 1.617260760357303, 0.321896631991671, 67.79961186070597, 79.99149153309484, 78.04713341497606, 81.21843245721634, 80.73752633986935, 80.73540041523596, 48.16476414280553, 25.93798871963255, 65.0114695487484, 82.83750057220459, 77.00459880213585, 1.6903129436316031, 0.18998511676346103, 0.20179822319938293, 0.20045614440835294, 0.1687386028108097], [0.03310396921850982, 0.026261375300706397, 0.042783267976295565, 0.06562677647678122, 0.10548219430230318, 0.11094889047765925, 0.3449584525679389, 7.908279309349676, 70.15705831589239, 55.14260968854351, 53.885733235266905, 34.02640435003465, 27.66609480304103, 49.00808941933417, 70.00118332524454, 64.17529867541406, 66.19227947727327, 59.27849800355973, 60.086055186487016, 2.3224824474703882, 0.7154159884779685, 0.6136416980335789, 3.0298294463465294, 0.38581585211138575, 0.5219322707383863, 21.278418879355154, 58.144497640671275, 45.703825950622566, 59.491769036939075, 55.9137672762717, 64.52252257254817, 61.81949177095967, 61.90822755136798, 58.36302857245169, 59.9423905341856, 54.630661933652824, 54.158773345331994, 49.34340107825495, 46.34420779443557, 45.48136480392949, 44.941658435329316, 43.51453542709351, 48.57009010930216, 49.78715450532975, 51.799820699999415, 54.23811112680743, 58.290547094037464, 56.08518269754226, 55.84043464353008, 55.31743364949381, 53.78613641185146, 53.541294220955145, 53.71275671066777, 51.26885337214316, 51.04825535128194, 49.340765245499156, 46.293475858626834, 42.82074659101425, 44.44297221399123, 40.43371761998823, 41.562866010973536, 39.216115859247026, 38.62347710517145, 37.919423426351244, 37.22773305831417, 40.70163511460827, 41.28789217241349, 37.27964954991495, 39.198143559117476, 39.28296089172363, 37.94611907774402, 38.29252712188229, 40.94851693799419, 45.17379214686733, 45.25817017401419, 46.35461384250272, 47.007974809215916, 47.684497371796645, 46.0817620062059, 48.21392713054534, 47.51529808967344, 48.474246994141616, 49.915957297048266, 51.04249731186898, 46.53019482089628, 45.314020802897794, 40.85782781724007, 40.81607810912594, 45.668885477127574, 43.73769867804743, 41.09481742305141, 45.297884172008885, 49.80472280133156, 52.585451833663456, 54.65921678850728, 56.74250133575932, 50.870583749586544, 51.440817925237845, 44.5928773572368, 44.642377668811434, 47.09058384741507, 45.28790566229051, 44.19516863361482, 46.189627185944595, 44.34870196926979, 44.62029080237112, 43.706170666602354, 42.284825309630364, 37.64833273426179, 38.005209584389966, 39.122233929172644, 40.00418278478807, 38.744348864401545, 39.933450683470696, 38.48472718269595, 36.95690516502627, 39.927633808505156, 40.89776931270477, 41.2806789336666, 40.696657626859604, 40.85456832762688, 45.533963787940245, 43.24415860637542, 47.651996612548835, 53.18142068001532, 53.67252103744015, 55.696573872720045, 56.71367583736297, 56.88626796968522, 59.01424400268063, 57.68783961572955, 54.131975712314734, 53.552131729741255, 59.92650493498772, 53.89571174498528, 58.15370736583587, 52.737455444951216, 50.566474545386534, 42.7195494405685, 44.36727831440587, 48.88549573959843, 59.94477925762054, 58.48971328427715, 63.52724859791418, 61.27198773045694, 66.57590296960646, 57.24225836415445, 61.603424087647475, 47.7996071692436, 58.32406766953007, 60.014260122852946, 66.5910433184716, 43.73420776859407, 59.13126399440151, 8.57055043020556, 0.9716507648268055, 1.6884939444641915, 17.2873640829517, 1.0676505296461045, 1.0214491152474958, 63.277170042837824, 68.01670720500331, 63.45143310485348, 61.9663296207305, 75.20202652100595, 61.65805878177766, 38.6607474665488, 34.801958914726015, 43.93845735057708, 74.25719814915811, 39.09540883956417, 0.19238148575588582, 0.07021337552296539, 0.038504785662817384, 0.07522635612516634, 0.027822968925559716, 0.010099795800934156, 0.06824608471605086, 0.013612876796434003, 0.10955725345880755, 0.21698504295800963, 0.08106491137896815, 0.3693266675597237, 12.246615367551005, 81.23203523697393, 61.02333299575314, 58.34427964302802, 26.324573601445845, 30.57457543188526, 55.77961829400832, 73.7753192840084, 70.85346729524674, 71.42182657795568, 65.78830280611592, 65.64651304675688, 2.5787710951220606, 0.8436391887164886, 0.5922336467812138, 2.5937592069948874, 0.39728375932862686, 0.5317497794185916, 22.704369098909442, 60.66858207025836, 47.82610670212777, 59.95201603058846, 58.643223085711085, 67.7003131374236, 64.79482919939103, 64.78236782935359, 59.79847485019315, 61.3675170560037, 55.22309672447943, 57.86809998173868, 49.49654609926286, 51.85347087921635, 47.04875569189749, 46.10837528782506, 43.95741808799006, 49.918346020483206, 51.54175619925223, 56.120044723633804, 55.892845353772564, 60.78235433947656, 57.41189695173695, 58.21846177501064, 55.13949924899686, 52.29266651215092, 54.39015003942675, 57.211303018754535, 52.772490055330344, 53.912507334063136, 52.851345385274584, 49.06980399162539, 45.57279917501634, 48.41107722251646, 42.18613455372472, 42.11994063469672, 40.90761838420745, 41.01693091853973, 40.25372005278065, 40.45552599814631, 42.503018917575965, 42.86131566570651, 38.988645845843905, 39.93786334991455, 40.114099364126886, 40.35244218764767, 40.717371663739605, 43.970146179199226, 47.05415679562477, 48.11411849914059, 48.09658550447034, 49.47154883415469, 50.18989562988282, 49.55846855717321, 49.38730808996385, 48.67094209117275, 49.73723842251686, 53.91713965323664, 53.855425080945416, 47.46493485666091, 46.265077898579264, 43.115806887226725, 42.684083369470414, 48.49605929466986, 45.15480395286314, 44.162926750798384, 45.44698522936913, 49.70858943077826, 51.73071638230355, 55.041475296020515, 58.348276538233605, 53.71203107218589, 54.29816261414559, 47.6951858305162, 47.98276616681007, 49.02992525408345, 47.40624835414272, 48.25690061815324, 47.685819210544715, 47.03413309589509, 47.15558928828086, 45.49467340592415, 43.14554237550305, 40.89316052775229, 38.50765343635313, 40.90383721936134, 42.194877516838815, 41.400472041099306, 41.000460886186175, 41.084646717194595, 38.32469055729528, 41.84936377309984, 42.413522197354226, 42.882382715902025, 41.147298735956994, 42.74968108823223, 46.975674090846894, 45.32878068185622, 48.03071321979646, 54.685590805545935, 57.02228007778045, 56.95856509670135, 59.42021716025568, 58.893156513091064, 58.12388166304558, 60.267421660884736, 57.547332471416844, 57.35311631233462, 59.93105096201743, 56.86906053173927, 59.5761235298649, 57.20741987228394, 51.28555874670706, 46.067272770789366, 46.575431516093595, 50.23670911788941, 62.89710806262109, 59.67469661466537, 63.719397667915594, 64.25409516980572, 67.76172960958174, 59.73909016578429, 61.94880054843042, 49.95171754590927, 60.54962835004253, 61.22693930902789, 66.79175100018902, 47.51651794679704, 63.7706865802888, 9.292184172138091, 0.9117439761757852, 3.7184498242793547, 18.893870807463124, 1.1464764418140536, 1.1542987511042626, 68.85033638246598, 72.54837051514657, 69.66201597644438, 71.32720331991874, 80.85836672013806, 71.92950679409888, 47.24731391476047, 29.4324283061489, 54.12881035958567, 77.89180755615234, 51.10872260985836, 0.47811587190916466, 0.18710441166354766, 0.027843578605942672, 0.0649431502566703, 0.03363119475843926, 0.1846659844440799, 0.0788727737662773, 0.1853481091318592, 0.23470549934333373, 0.4158663557421777, 0.25214526111320146, 0.6610333066313498, 13.560743716455276, 94.2330135837678, 67.70387464954008, 69.89952333511846, 44.21696132229221, 40.93102708939583, 63.91171539983442, 82.49056693046325, 74.38340433182256, 77.45334932881018, 69.6056515170682, 75.34110592257592, 3.000947563878952, 1.4233431917044426, 1.9552734614379945, 8.023128269180175, 2.0035936298870274, 0.6689118161316842, 27.662509756703532, 64.44540877496043, 51.96376008372153, 62.70703392644083, 58.576299605831025, 66.69412320660007, 64.47133171942927, 66.26223102692636, 64.58236225189702, 63.44249794560095, 59.44626954294021, 60.22826463945451, 52.86681913560437, 53.7377029849637, 50.00268090155817, 48.339486122131355, 46.384847471790934, 54.43007584541075, 52.94153244264665, 58.15187169659523, 58.08418335453157, 63.35963787571077, 61.13672479506462, 59.85226623473629, 54.7103056600017, 54.57003385789933, 56.87495193173809, 60.75566653282412, 56.43204181425033, 55.89581066562284, 55.631282098831676, 51.48405813401746, 48.30020750722578, 48.54654804352791, 43.90084182062457, 45.48343581538047, 42.30222494371476, 43.928168973615094, 44.176670735882176, 40.61126762820829, 44.36573290055798, 44.5184229266259, 42.71914543644075, 42.5986933708191, 41.8409816680416, 43.5853930442564, 41.80326807883478, 45.360657784246634, 51.00061816553916, 50.705946183973744, 51.55176608793197, 52.564063149113814, 53.68986575834213, 52.297243918142016, 52.41096519654798, 51.78162874714021, 52.65453261713828, 56.147622908315356, 56.414583344613355, 48.30314928485502, 49.907202566823656, 45.97640714337749, 44.301056938786665, 50.57676684471869, 48.42078901106312, 44.791235539221, 47.49431733162173, 50.213978982740834, 52.91469558592766, 56.14069600259104, 60.793317364108184, 55.790079255257886, 57.4344309683769, 49.36466424695907, 50.0254031919664, 50.80048707223708, 50.89450236289732, 49.51920170937815, 51.378295344691125, 47.86116484672793, 49.53164346756474, 47.928107938458844, 45.60983419418336, 42.913745987799864, 42.134210217383604, 44.105107092088275, 43.89868843939997, 43.24553143593573, 43.5178380627786, 44.022866756685325, 41.641474231596916, 45.18170748987506, 44.484580716779156, 45.550527957177934, 44.77063917344616, 43.84972549253895, 51.81817347003568, 46.64832484337592, 50.24874687194825, 58.12675283801172, 59.00440277591829, 60.132888286344475, 61.944176073997255, 63.764783413179465, 60.62051342379663, 60.06151291631884, 60.134778868767526, 59.835964864300145, 58.179136091663, 59.019896138098936, 64.62934047945085, 57.98651241487073, 55.468142878624704, 47.39530494136196, 49.79042576205347, 53.777569955395116, 66.49582386016846, 63.50842514345723, 67.40338971537929, 67.12901992182579, 70.25521955182477, 60.11926197236585, 61.772152685349994, 51.26180095057334, 64.00268300887078, 64.38275283382785, 67.63921829961961, 51.94589760995681, 69.38668127982848, 10.59466504281567, 1.303752086335613, 6.923584947662969, 40.604995758302756, 2.6511076909880487, 1.1149001361862307, 77.28649170167985, 77.13417822314848, 80.26539064222767, 75.23655906800302, 88.48858479530581, 78.43351041117023, 53.323092768269206, 47.03382322865148, 64.81152280684441, 88.96621181118874, 62.72000912697085, 0.7580945015914979, 0.29707048028226823, 0.2125206502575067, 0.15064699214793023, 0.14628183847713858], [0.02217824732313954, 0.057538190345850684, 0.06708779041805575, 0.045172064189588836, 0.05187377070767745, 0.04655748823537462, 0.19850534747444815, 2.528312254336573, 67.65175419469034, 55.24880393858879, 43.686825536912494, 32.99398552986884, 39.99125465270012, 45.41193492950932, 76.12719597355013, 65.74075975725728, 71.30837594309162, 60.13561041124406, 68.72989608395484, 6.477755115878198, 0.6406624771414265, 0.17755710219423618, 3.6632949258050616, 0.20129654286128862, 0.46918785259608303, 21.874836837091756, 63.56091430110317, 52.977975183917636, 65.99994213350358, 63.77032572223295, 63.9267223881137, 57.77881506950625, 61.40753699887184, 59.23641097161078, 54.5493237433895, 50.99318135169245, 49.2346376757468, 46.07300335361112, 45.99042177200318, 44.418457400414255, 46.80064616664764, 47.56119374305972, 49.842204970698205, 54.98696611773584, 54.66097401034448, 55.22555997294765, 51.78824578562091, 56.19835092175392, 51.10503558189639, 45.05676038803593, 54.70615579235939, 56.56650850849768, 52.60662871022379, 52.53251552581788, 47.55416485571092, 43.04354113917197, 40.926386925481985, 46.19627952575684, 44.36933363637617, 41.51415801817372, 39.5897686866022, 39.5957620682255, 39.9855907501713, 36.96575403213501, 42.21183784546391, 39.490367981695364, 38.52402148708221, 38.71513505135813, 36.96264751495854, 39.38896686800065, 37.737115583112164, 39.3506766903785, 41.16737734886908, 42.004242481723914, 43.004062483387614, 46.07666292498189, 45.557905935472064, 48.67307586054648, 47.61527538299561, 45.77839412996846, 45.05429321719755, 47.833472913311375, 48.654934898499526, 52.140517773166785, 49.38078126599712, 45.77481300600114, 41.384464848426084, 38.43299504249327, 43.43484855467274, 40.00119393871677, 41.7588472366333, 44.652591520740145, 49.64444691135038, 55.0673197930859, 52.47864961624146, 53.2668028339263, 52.340746925723174, 48.09783674055531, 45.25185515803676, 46.904337944522986, 45.30377164963753, 48.07041545068064, 46.310216534522276, 47.603241551306944, 44.15853369620539, 44.39454270947365, 42.3246765905811, 39.9406482327369, 37.17771107150663, 39.27302160570699, 36.806356753072436, 37.39310410714919, 37.47101806825207, 38.93231668779927, 39.693444774996856, 39.22208178427912, 37.055454715605705, 39.87570947216403, 39.74620849855485, 39.18909465112994, 40.59958680983513, 45.80048099640877, 43.64108285596294, 43.75603968097318, 44.10231436452558, 48.92019302614274, 49.20724384246334, 52.03545316573113, 54.34350129096739, 53.88747084525324, 54.08789611631825, 60.644231996228626, 51.29043033046108, 57.997400914469075, 57.922095329530784, 52.850505998057706, 52.95324071761101, 47.93541923646004, 45.65084649670509, 46.846063290872884, 43.69936927672356, 52.06418844961351, 57.970226733915275, 61.87466775217364, 61.35354557344991, 67.69016988815801, 61.88648585350283, 66.21499000057098, 67.07249072290236, 69.1239687704271, 63.117835521698005, 70.18299302747174, 58.07943728662307, 63.66906973623461, 4.644702096139231, 0.22073017102816414, 0.7279621184833589, 3.3041021612382706, 1.0078030055569065, 1.8038759789159222, 63.95915646706859, 66.00824971352854, 62.299597724791504, 64.16501814319243, 74.66605817118, 59.61990502572829, 47.526061073426284, 45.29346758319486, 43.96385077507266, 74.03962427569975, 29.45315803250959, 0.06255266481950399, 0.04004026335033198, 0.00623184995117387, 0.044901255938795306, 0.003991338195309284, 0.020821999735949982, 0.06765759129437708, 0.10459383874530755, 0.05504362420329163, 0.04217772526786693, 0.04254812877925654, 0.307797703050798, 4.1915183105776395, 77.35703945159912, 58.823985515102265, 57.89405430516889, 37.638024745448945, 40.32790383984966, 54.706489193824034, 83.62654809028872, 70.43584469825991, 77.29870596239644, 64.28361885009274, 71.46035209778817, 7.170217700542943, 0.7774697232150263, 0.4881360261671005, 3.536756322268517, 0.502845649757693, 0.39695774295157005, 23.917520930690152, 65.29983435907673, 56.19095333160893, 68.87441189058366, 66.67579004841467, 66.71361738635649, 61.47910848740609, 62.86415623080347, 59.42164098062823, 58.06091193229922, 52.776196695143184, 52.38723485700546, 48.82535011537614, 48.54437505045245, 47.142810206259455, 48.33866242439517, 50.90023686808925, 52.922924718549176, 57.098770218510786, 57.75213510759416, 57.52460625863845, 56.157358231083045, 58.162438561839444, 52.900551519086285, 48.28609874171596, 57.72880484980922, 56.655609069332, 54.85133447954732, 55.650893949693256, 49.077735024113814, 43.90585460970479, 43.697200206018266, 47.94645286375477, 46.630179958958784, 44.50461618361935, 40.014243664280066, 39.85402660985147, 41.14124259641094, 40.23215486157326, 43.39068658890263, 41.667628595905924, 41.63513175902828, 39.663246447040194, 39.10432438696585, 40.52781528042209, 40.167533812984345, 40.954839798711966, 42.51638635512322, 45.54081616863128, 44.32154347819667, 48.309036762483665, 48.10294758888983, 50.3522111523536, 50.74577393070344, 47.330625057220466, 48.06176662445069, 49.21404915471231, 52.75547481352284, 56.301144476859804, 51.31523147706063, 46.12692025399978, 43.88996508813674, 42.196250346399125, 45.64045613811862, 41.2752386062376, 43.90095556935957, 45.30482284484371, 51.5654630045737, 55.106582718510786, 54.66510426613593, 56.278265291644686, 54.06493456132951, 50.60067761328913, 46.6861011905055, 48.64759614390712, 48.39435223610171, 48.637609789448405, 50.18400815225417, 48.925676499643636, 46.814668640013664, 47.072462497218964, 42.85232951564174, 42.36405326474098, 40.22735388048234, 39.26283128799931, 38.85539508634998, 38.83596366451633, 40.995295124669234, 40.36564880801786, 41.16855405992077, 41.56174029073408, 39.702662344901796, 41.24148661090482, 42.63147261834914, 41.92532831622709, 43.05420214130033, 48.217543555844216, 45.92960150011125, 44.40279929868637, 45.9338729612289, 50.82965773920859, 51.560348233869, 54.10788451471637, 56.948429692176084, 56.2820464564908, 55.01337151373587, 60.719325773177616, 53.63551739723452, 59.77856882156865, 61.22749628559236, 53.47345290645477, 56.33346872944986, 49.863844686938876, 47.360046755883005, 50.38554345407794, 47.33395907186693, 54.79032985625729, 62.10347529380553, 62.419881128495746, 62.950362082450624, 68.02506969821069, 66.22183845889184, 67.30155714096563, 68.02720346758443, 71.86612913685461, 66.97124650401454, 72.6688814163208, 60.84935626676006, 65.93805497692478, 6.0695089447882875, 0.6705383127254825, 4.381177165815908, 7.581371328523082, 0.6904565374697409, 2.0765581727027893, 72.14036556982225, 70.26080500695014, 70.07099366957142, 70.53806166495048, 82.3603520854827, 70.4834387379308, 40.058068306215354, 35.00299999790807, 55.45222982283562, 79.22815122912007, 39.745561307476414, 0.2983021658034094, 0.08356399744028047, 0.08083206661526235, 0.0615661159428137, 0.04879391339096812, 0.23496678129078882, 0.19803547510696998, 0.17292435401149336, 0.07590791390788171, 0.2522114051445838, 0.11812136568609746, 0.39933757976658885, 4.958273037787407, 88.28481766485399, 67.96292366520052, 64.1101598739624, 46.59023454112392, 58.23406496355611, 58.86706098433464, 89.20567251020863, 78.51533105296474, 83.65670327217349, 69.67637969601539, 81.64277015193817, 8.397097337630488, 1.0349993720169992, 2.7054165832458006, 9.845845353218818, 2.0866646497480335, 0.7698858204868533, 27.946556037472142, 65.9613303215273, 61.79128600705055, 68.62368614442887, 68.42611635884931, 70.0658945883474, 62.59132792872768, 63.22889743312713, 62.197855364891794, 60.25723134317706, 55.81930875778199, 55.01793715261645, 51.14273740399269, 51.03274237725043, 51.07837523183515, 52.06334906239664, 52.86354395651048, 54.60179721155475, 59.994279569195164, 59.00017446087253, 58.283490750097464, 57.75961898988294, 60.36938759588427, 55.598432248638524, 49.84456231517177, 54.61740040010022, 59.14432940944549, 57.21596279451924, 57.27115838758407, 52.21367389925065, 45.687571648628484, 46.27499365037488, 51.032267770459576, 50.09836712191182, 47.373559321126635, 41.85731049506895, 41.44702665267452, 44.36821183850689, 40.24445541443364, 45.58730409991357, 42.96431318406136, 43.57422997874599, 41.89665579026745, 40.61382893593081, 42.51338181957122, 42.06913417385471, 43.618384099775746, 45.90827557348436, 48.07116854575373, 47.26790635816513, 51.09228787883636, 50.00937246507215, 55.07110880267236, 53.612053778863725, 49.33408937146587, 50.63289203951436, 53.197514164832334, 53.75843663369456, 59.13879102276218, 53.833016580150975, 48.47567081451417, 45.980274600367395, 45.33036139703567, 49.376925576117735, 43.25247403114073, 45.95170797840242, 46.81289572869578, 53.98127825029435, 57.72046589082288, 54.196388875284505, 56.73340928169989, 58.075483537489376, 52.405446421715524, 49.92450806402391, 52.066318296617084, 49.914211842321585, 51.275282136855594, 53.88738063073928, 53.48799313268354, 48.855254265569876, 47.880486442196755, 45.60129519431822, 44.5884999921245, 41.32394659903742, 42.10141920274304, 41.630440604302194, 41.21410846710205, 42.05618642991589, 44.55615220531341, 42.66043539970152, 42.95291477634061, 42.541007072694846, 42.720306458011756, 44.89805344612368, 43.62441670510077, 45.73439298137542, 49.38955168570242, 49.131875499602295, 46.582095623016365, 48.57497346016669, 52.3745067657963, 55.914159513288936, 56.16093935505037, 60.121603627358716, 59.39456485932874, 57.10448511185185, 64.00731532804429, 56.106904783556544, 63.92659687226819, 60.72552704042005, 56.9447152076229, 58.927810653563476, 53.223527323815134, 50.3829429226537, 52.925580163155836, 48.49156818082256, 56.94917102013865, 63.53530514624811, 65.25153821514499, 65.50196586116668, 71.83690747907086, 67.17287202035227, 68.72659344826975, 66.22728270869102, 72.79455415664181, 68.91321982106855, 76.52895650556012, 61.552637238656324, 70.39162389693722, 6.861685533677378, 0.5769011017776305, 5.080953499963207, 16.085647921408377, 1.8939204826470346, 2.2158052555976377, 80.3615750035932, 75.83450086655156, 78.6184109410932, 78.07873202908424, 88.94652935766405, 75.49891071934854, 67.4175573164417, 58.815136647993526, 64.20291216142716, 90.39622952861171, 53.14238132969026, 0.41785061539661505, 0.2990380085764393, 0.2294878889956782, 0.25656983256340027, 0.17830402259865116], [0.07816785796275062, 0.03240994718526641, 0.048911055895469846, 0.07400552606991223, 0.02395031594430968, 0.01586662319999549, 0.02516598256695415, 1.1754579769988214, 58.30881749430011, 57.097919064183394, 45.67694202546151, 18.06356779990658, 26.28495962389054, 42.92295179059429, 56.99509413011613, 65.70763534115207, 70.71784742416875, 57.34013326706425, 69.84264896761987, 15.83351698613936, 0.7927756696458786, 0.48547016276467236, 1.5319001794822755, 0.38522234847468717, 0.5924240655956731, 21.680632445120043, 75.96111497571393, 62.37912378003521, 63.971213832978286, 56.92561326488372, 60.61737945002895, 59.04983558962422, 56.02118530581075, 50.63510425629155, 52.41473459428357, 48.79769348329114, 47.691973409345074, 48.98102114277501, 50.1158255915488, 51.55202496436335, 51.84254707828645, 49.48545363641555, 54.35131857472082, 53.31698956028108, 58.560912147645034, 54.00194521873228, 54.652089841904186, 52.12509109127907, 50.96231622080649, 45.392495662935325, 41.113189804938536, 54.03716810287968, 54.98042360428841, 51.378879777846805, 52.02853410474716, 48.12136703921903, 48.55869562395158, 44.285779306965495, 46.06910844003001, 42.121074199676514, 41.51495033694852, 40.4562359471475, 39.10707004608647, 39.313441630332704, 40.064344098491055, 38.27093839645386, 37.21268684633317, 38.878078153056485, 39.68192477380076, 37.71182806261125, 38.19980229100874, 37.630219228806034, 41.144035323973625, 43.98146221714635, 44.1686337993991, 44.003662832321666, 45.88798515258297, 44.97473970536263, 47.00124009963005, 47.505594145867136, 46.624437609026515, 47.35117435455323, 48.33919194436843, 51.63880348205567, 50.34516265315395, 45.35826906081169, 42.86399072216403, 39.70689458231772, 43.89715087029242, 42.50955750865322, 44.82541507290256, 44.291270625206735, 48.713805752415816, 52.80004078342069, 54.46290608375303, 55.215640298781864, 51.218678412898896, 47.62385752893264, 45.61574520603303, 44.57396761063607, 45.25690324844853, 47.22762361649544, 47.49178348049041, 45.34532916161322, 44.94312540177376, 43.632469331064534, 40.38932031200778, 39.579452853049006, 36.61629830637286, 38.79094269967849, 37.4396744082051, 38.08855602818151, 37.44333005720569, 37.1360319660556, 37.68623459723688, 40.70730293950727, 37.83496302943076, 38.0062960809277, 39.31421433725665, 42.19046092802479, 42.604063095585, 45.76654072730772, 42.90984322947841, 42.3648298940351, 41.501206351864724, 43.499846150798184, 48.68286217412641, 51.00252443744291, 52.08941713456185, 56.88331834731564, 57.315438024459354, 55.759555370576926, 57.88210676562402, 48.51596532329437, 55.78199525033274, 55.714381433302364, 54.47808173394973, 56.23372285596786, 56.16119430911157, 53.8494630782835, 50.86909717129123, 44.757012859467544, 48.357654540769516, 54.65786357079783, 59.66948770707654, 61.1131944964009, 60.88560288952243, 62.23935796368507, 63.78301851211056, 67.1972377838627, 64.72830580126855, 68.86973642533826, 66.65261668543663, 69.34298607610887, 2.7537323390283897, 0.8304369197257104, 4.1817167978132925, 8.889378328477184, 0.8002388369171851, 5.894775198351953, 73.22712882872551, 63.65500803916686, 64.6909805267088, 63.250121378129535, 79.58447502505395, 52.77353732816635, 76.51911920116794, 40.76943328303676, 42.46030822876961, 73.53633711414953, 25.319630984337103, 0.20961394413344323, 0.1870143810106862, 0.04460345457998976, 0.11508608702570201, 0.023488148506129944, 0.045115488596380725, 0.06777966740511118, 0.035477282794853376, 0.06653135011513388, 0.058623292603560036, 0.02942399501109556, 0.015522901573398662, 1.6160480125296501, 69.33952654561689, 63.76818018574869, 50.14211723881383, 24.962724716432636, 43.453848515787435, 50.03986104842156, 65.50320140777096, 68.97207890787433, 74.96188332957607, 61.68443279881632, 76.88966551134664, 16.368668502376927, 0.8743338190740155, 0.1105193832829114, 1.4694366796362786, 0.44318924928384446, 0.6729915101201304, 24.27837702535814, 79.04378414154053, 64.25837055329355, 64.56655902247276, 59.96798399955996, 63.47701088074715, 62.80088055518366, 59.197857995187086, 54.86580018074282, 55.69986474129462, 51.62207065090057, 51.30793194616995, 50.21913297714726, 52.06499253549884, 53.367325336702415, 54.31495820322345, 52.43536233901978, 57.777332413581114, 56.37924278936079, 58.65948915481568, 56.07287429994153, 54.91395904171852, 51.03744137671686, 52.19802364226311, 46.91043330777077, 45.023082917736424, 58.74153337171001, 56.567312594383, 52.51391172409058, 53.02675770175073, 48.1710164008602, 49.855713613571666, 45.667908806954664, 47.44837460979339, 45.213361017165646, 42.92048069738573, 43.0748063518155, 41.15128386405207, 40.44886581359371, 43.353706482918035, 40.28094522414669, 40.45490234128891, 39.07304348484163, 39.73792445275092, 38.71474673671108, 39.63332660736577, 41.281561466955374, 42.74087144482521, 45.2382759125002, 46.31163643252465, 46.1911569103118, 48.36749184516169, 48.88418174559071, 49.14427411171698, 48.59181611768661, 47.793841285090295, 48.17327568607946, 50.76058872284428, 53.212109304243526, 50.66420824297013, 48.6607753076861, 44.02610271207748, 41.542724640138694, 44.87000457702145, 43.34674427586217, 46.47848229254446, 46.025040611144036, 49.357921692632864, 54.64001286414362, 56.51749064845424, 55.52111056543166, 52.88341468380344, 49.77181019321565, 48.719210778513265, 48.43154807244578, 47.68156343890775, 49.59660576235864, 49.794869807458696, 47.44896296531924, 45.3626032798521, 46.08127955467471, 43.326610749767674, 40.03455761940249, 38.34633027353595, 39.69461756367838, 38.66108479038362, 40.06365376134073, 38.704234784649266, 38.973583944382206, 40.45967978815879, 41.65633216980965, 38.73584908823813, 39.98727736934539, 40.59817867894327, 43.88743515937559, 43.38327330927695, 48.688329958146625, 44.32252014836958, 44.64094992606871, 43.59209637488089, 45.57171660084879, 49.39770629329067, 53.12087889640562, 53.42415263575893, 58.62134410488991, 58.449363862314534, 56.371276455540816, 60.154979075154955, 50.98212419017669, 57.85177115471133, 57.64283041800223, 56.7198771046054, 58.20121903573313, 57.709742130771765, 55.91275138239707, 54.83872013707315, 46.88381610378143, 51.158419039941606, 57.775402607456336, 60.96545057912027, 63.503902650648556, 63.00713054595455, 64.85746945104292, 65.68001008802845, 68.56765116414716, 69.3808840167138, 70.60197276453819, 70.24499001041536, 70.66528766385971, 3.516778955536504, 0.7844913786938115, 3.9096585060319597, 4.473839729062973, 0.6759821948024535, 5.680297055552083, 79.24734730874339, 68.71704639927034, 72.02277291205623, 69.66149822358163, 86.18343137925672, 61.72977539800829, 65.521275689525, 41.537460819367446, 51.95601340263121, 82.75735086010349, 36.30652519964403, 0.25451527668103097, 0.22088538044162337, 0.07248943040688192, 0.08958785404120723, 0.06616689144603669, 0.17511449213470184, 0.1711178267554891, 0.09616590630743774, 0.10734066231957368, 0.12779125688417306, 0.1683186793759946, 0.18367115798736774, 1.8940635265842563, 79.40702699845838, 72.06663285532306, 64.1169181177693, 29.38656403172401, 36.565178055917066, 61.12862510065879, 74.0915564567812, 74.40260041144587, 82.33443306338403, 68.17266848779494, 83.50089888418876, 19.719025704168505, 1.298603240040041, 0.7527701292307146, 5.587003971299818, 1.9634682733205058, 0.892034188633965, 26.655933472418017, 81.63108933356501, 66.5944008673391, 68.6925708093951, 63.98848795121717, 65.76544715512183, 64.32872610707437, 62.42477232410062, 55.85694782195553, 57.725286483764656, 54.467393275230165, 51.74941039854481, 55.1970874878668, 55.667387516267844, 56.88673080936555, 57.90379747267693, 54.60998712047454, 59.27211630728937, 57.919545788918775, 62.41313465179936, 58.775759973833644, 56.78379212656329, 55.43165306891165, 53.288952458289366, 50.493930309049546, 47.36761693031558, 58.16457625358336, 59.78130663594892, 55.157930466436575, 55.23529529571534, 50.3407068406382, 52.1442126458691, 48.98147221534483, 49.61811604038362, 47.81340606750981, 45.53880791510306, 45.401944652680434, 42.981865790582475, 42.268594541857325, 43.725170627717056, 42.27787486968502, 43.13349677670387, 42.79840869288291, 42.69651728291666, 40.80407173402848, 42.93396580603815, 42.587757802778675, 46.05686672272221, 50.033302845493445, 49.95661266388432, 49.300509960420676, 52.2475435656886, 51.37833849076302, 54.03654836839246, 52.826006873961425, 49.55384408274005, 52.27271733745452, 53.427247385824884, 57.86618194272442, 55.010347366333015, 49.70700087085847, 48.42349936885219, 44.798358563453924, 48.02712817345896, 44.95477091881537, 46.858610953054125, 48.01624359623079, 53.040501686834524, 54.9090874579645, 60.08080313282629, 58.9119250543656, 56.2853334026952, 52.01857520687965, 51.381935304211034, 49.45465126345235, 50.07752756918631, 52.99644562505907, 55.07986353289697, 50.351693399490856, 48.48047964034542, 47.51294466757005, 44.15098313362368, 44.87452314745995, 41.685883306687884, 42.205573820298724, 41.09780234675254, 43.01338987965738, 40.48840330493066, 40.67735172087147, 41.96119054671257, 43.81518117843136, 41.46177868689261, 41.854149064710064, 44.62487605310256, 46.54615494512743, 45.60315832015007, 49.86169522808444, 47.15289069760231, 46.938266446513516, 45.939709448045306, 48.391049600416615, 52.942834669543856, 56.949712307222434, 57.625179752226806, 59.01991967231997, 60.697133002742646, 60.42845849067935, 62.65458399249662, 56.72877304015621, 59.891866483996, 59.46254737915532, 59.07913569481143, 60.77474886371244, 58.82688022428944, 58.19082867714667, 55.481365188475586, 49.567811642923665, 52.53457869252851, 60.459409913709095, 63.22369637027864, 65.65822524409141, 67.40537443468648, 67.61781784795946, 69.21947063938265, 72.11015547475508, 71.7848184031825, 75.27384511886105, 69.44875671017554, 76.42523334872338, 4.771102926423473, 1.7337041636628492, 8.639219364812298, 17.971558801589474, 1.38393648689793, 7.464661694342091, 87.25013563709875, 74.31563361998528, 78.36923845352666, 77.09054577735164, 90.73702073866322, 69.43317705585112, 95.36297782774895, 55.66827397192679, 61.87922162394371, 92.36474944699196, 45.049837404681796, 0.4269119646520384, 0.37857705667134256, 0.18446090270675, 0.20110449994042998, 0.19708227786806323], [0.041480853387545195, 0.10347753372644225, 0.043763105922769156, 0.030230484497282776, 0.08450008793583802, 0.06879005310756546, 0.11827521146305146, 0.08953749908194428, 46.06360927704842, 60.83092504932035, 49.797846886419485, 31.219866121968916, 30.33306137208016, 39.925566719424346, 66.70405464787638, 67.33918051565847, 68.07824919300695, 60.9944643512849, 69.97774324109479, 23.052149972608014, 0.5058701342392353, 0.4280299933687334, 1.0186739157765143, 0.46191764755114434, 0.3864070268407945, 23.937034722297426, 74.60720692911457, 57.77859149440643, 62.13196346836706, 56.994764651021654, 58.82711948886995, 55.901556937925285, 55.23664851342478, 50.67535561899985, 49.52210426330567, 52.13633652656309, 51.41186691099598, 51.567714445052616, 53.017395004149414, 54.88883626076483, 55.022600850751324, 56.06663380899737, 54.55395606256301, 54.76122194720853, 56.596447960022964, 55.015269940899266, 56.93313637087422, 55.73527197684012, 54.11622347370271, 53.513904310041866, 50.397353710666785, 44.79564036092451, 54.83637063733993, 52.85143952215872, 52.78060543921686, 52.55529665177869, 57.8642992050417, 54.823297377555605, 47.2239601227545, 44.061878650419175, 40.29184156848539, 41.60516877328196, 40.08046896226945, 38.2397202522524, 35.145029021847634, 39.63620954944242, 43.76568871159708, 41.129702983363984, 41.87637321410641, 37.87170387083484, 39.45530591472503, 37.729392436242875, 41.44576364947904, 40.535738468170166, 42.179242949331964, 42.80908146212178, 45.63306247034381, 44.168127813646876, 43.96460779251591, 43.806414681096236, 47.37887021033995, 47.986668925131525, 46.1956480241591, 50.440158536357266, 52.48382714486892, 47.151706141810266, 42.479519997873616, 39.312959178801506, 42.938900147714925, 40.80882172430716, 45.319151263083185, 43.446964756135024, 50.05131436932472, 50.64982883391842, 55.23411466229347, 53.34298702978319, 50.45149418615526, 46.271314467153246, 43.979132329264, 43.878013626221694, 44.80783500979024, 45.252812216358805, 43.006576722668065, 45.194608165371804, 47.40236128530195, 41.43218440394248, 41.12095609787972, 38.929508270755896, 39.379545334846746, 37.38032110275761, 38.286019909766416, 37.879882012644124, 39.623132367287916, 37.521553885552194, 37.86140372676235, 37.217440758982015, 38.62328490903301, 38.750695259340354, 41.09170306113459, 40.973812303235455, 45.86930290345223, 44.698926479585715, 43.279950234197806, 48.111894515252885, 47.71497811040571, 51.27823175922517, 53.46122295625749, 51.50283452003233, 69.98270896173292, 63.53324590190765, 57.581739502568404, 56.19884514039563, 57.03654966046734, 53.71963654795001, 53.198886994392645, 58.470560350725734, 56.53886756589336, 55.837967472691695, 58.45227426098239, 58.698328464261955, 59.24455773445868, 60.343496030376805, 47.16536775712044, 47.933544343517674, 50.651174206887525, 56.943754226930686, 61.7602639813577, 62.08671500605922, 61.16445987455307, 63.99775651193435, 60.99591562824865, 65.82270591489731, 63.6944474712495, 72.37709629920222, 3.445215311742598, 0.9172797275166359, 3.590240045901268, 5.441459523093316, 0.5483518240432586, 9.685029156746404, 75.58675612172773, 62.53786602327901, 60.80684954120267, 64.51030831183157, 70.00787488875851, 60.909105731594956, 54.60068718079598, 22.610712705119965, 46.81237797583304, 71.85837068865376, 18.51485217771223, 0.364174205329149, 0.15012314122530723, 0.09615250742964207, 0.09749386609802324, 0.008682345449473829, 0.02708773710764945, 0.09577899360127988, 0.05758492553967142, 0.08493933976898271, 0.09497792610237676, 0.0628461645946147, 0.12202115924728495, 0.14931969885383883, 58.27167657113845, 68.20908377247473, 57.246871071477095, 32.49456778649361, 32.3595303873862, 48.58830951875257, 74.0103712389546, 73.75407572715514, 74.12200189405873, 65.37183730832993, 74.98431144222137, 24.86783277603888, 0.5057429023567708, 0.20424743693682457, 3.5791632725346476, 0.5652118870808233, 0.3839812860373528, 26.899008635551702, 75.15374214418473, 61.10242366790772, 65.41018239913448, 59.208307189326135, 58.876772772881296, 57.72219565606887, 58.42657489161338, 52.92905930549868, 51.31773787160074, 54.17592979246571, 52.880190495521795, 53.2481009729447, 55.61127801095286, 55.319241862143244, 56.817144040138494, 58.91231729138283, 55.61117210695821, 55.915606867882516, 56.93264607460269, 56.885048112561634, 59.27315181301486, 57.55644805969731, 57.64780006101055, 55.27486024364349, 50.961508212550996, 47.15483619320778, 57.57857022746917, 55.29113023511825, 55.94150627813032, 57.07526345406809, 59.741686774838364, 55.696879817593484, 48.55340042421895, 46.0863237227163, 42.71454449622862, 44.50726770585583, 43.50780463987782, 39.2382929402013, 36.38938526953421, 41.822001318777765, 44.284779102571555, 42.7029578147396, 42.5605796998547, 39.24930695564517, 41.19864648388278, 39.56224149273288, 44.22599454079905, 41.384037310077304, 45.81119298934937, 45.53074744439895, 47.397340651481386, 47.005319364609264, 46.45429695806196, 46.82275264493881, 49.009913321464296, 48.879376842129616, 47.162190637280865, 53.10565617776687, 55.03620363050892, 47.00444075369066, 44.41402904448971, 43.04301161919871, 43.981277865748254, 43.37220438065068, 47.43742335227228, 45.49579912616361, 50.25761142853768, 51.11040530666229, 55.85794018160913, 55.93497553179341, 52.31370610575522, 46.76181470194171, 46.20785444013534, 45.902470465629335, 46.55438800011912, 47.3672599946299, 44.843391295402284, 46.791365838819935, 47.45512893123012, 44.31595410070112, 42.9065719727547, 40.878051557848536, 40.26809946183236, 38.965774505369126, 39.28061531436059, 39.90141668627339, 42.86764244879446, 39.86990828667918, 41.10722387990644, 39.626929221614716, 41.68304351068313, 41.349696959218676, 42.947709791121945, 43.04611029163484, 48.64326976960706, 46.42940559694844, 44.63581162114298, 48.4748157378166, 50.16043078514838, 53.150461412245235, 55.27831192939512, 54.122652238415135, 66.17206358140515, 65.33369618077433, 58.84843757075649, 56.96867304463541, 56.71931228330059, 55.981486997296734, 55.045005429175596, 62.45864983527892, 58.04797203310075, 59.68418482811221, 58.88565694132159, 60.79721227768929, 60.52286994072699, 63.854389959766024, 50.32048702239991, 51.007611751556404, 52.75743992097917, 58.86807687820927, 62.125844570898245, 66.02875586478942, 62.65565087718349, 66.98553177618211, 63.29840967732092, 70.05176621098673, 67.127317613171, 75.16156335030833, 4.232604647836378, 0.650149648708682, 3.8465122686278437, 2.5036910464686732, 0.5043317684002462, 10.969340628193272, 85.01699693741338, 67.82732732834356, 69.22271051714498, 72.10738628141343, 78.47485219278644, 63.589410320405044, 61.36615991592408, 31.370447874069217, 52.82031551484139, 82.91069984436035, 24.251514673233036, 0.6434019462716195, 0.2507270944695319, 0.06233754733036603, 0.0409160167609732, 0.032990120892082496, 0.13517838992899464, 0.2269018366332016, 0.08578048132720494, 0.1488761799109559, 0.2651301296728273, 0.27353895587786553, 0.1494369562715292, 0.5524858183437779, 68.2908808800482, 78.06361521444013, 66.33455168816351, 44.45571207231091, 44.36100252213017, 56.98354667232883, 79.8102544969128, 78.76455060897335, 78.82995220922655, 70.38113547909644, 83.4759839888542, 26.84383853789299, 0.6276498915207002, 0.6927587236127546, 2.075670736451303, 1.3787113995321336, 0.5152508808720497, 29.522258427835283, 77.09051439839025, 62.523431701044885, 67.60625470069148, 60.64390251713415, 62.03758339728079, 60.16806017967963, 61.87966485177318, 55.45892923108993, 53.88123035430909, 55.61360789883522, 55.850464144060695, 56.23509960789835, 57.34368693444037, 60.750473314715975, 59.54817272001698, 60.24791179164764, 58.1175038891454, 56.37412409628592, 60.75905153828283, 60.05677469315068, 63.001792200150035, 61.295835741104625, 60.392733543149895, 56.69110259702129, 53.32754465841478, 51.085145242752574, 58.32095722998343, 56.42342044461159, 58.038919202743045, 60.22632306621921, 64.50740968027424, 58.01569877132293, 51.74145583183535, 47.7719505371586, 45.05676823277628, 46.078380923117365, 44.05661090727776, 41.78319338829287, 39.37465806161204, 45.27830370010869, 46.52061639293548, 45.642876240514944, 46.70275949662732, 41.795348813456876, 45.22054287695116, 41.799934064188314, 46.985158381923554, 43.97395872300671, 48.26053665530298, 49.25430051742062, 50.029290260807166, 48.119543137088904, 48.37552878164476, 48.933666367684644, 50.81572548035653, 51.99382112872217, 49.66514525874969, 56.275025413882354, 58.919220662886104, 50.12384291618101, 47.14101376072053, 45.89905800357942, 47.01066555515413, 44.69389407865463, 49.978872114612216, 46.64595965416201, 53.119408007591005, 52.4795792179723, 58.56421478333012, 59.09287967989522, 54.19623982521796, 50.91553411176128, 50.41490239481772, 48.35504224223476, 49.35208520581646, 49.734253498815725, 47.71303261480024, 50.46033128615349, 51.90950978186823, 45.735240213332645, 45.42265084482009, 42.35416496953657, 44.0163242432379, 43.112876876708, 42.61368859198786, 43.28275865124118, 46.29441330509801, 41.92421828546832, 42.848332620436146, 40.84039288182413, 42.96579191761632, 43.89814715231619, 45.14686899800455, 44.479767968577725, 52.27100718405939, 47.37564994442848, 47.4899281993989, 53.129088417176284, 53.6687869410361, 54.441737051933046, 58.34264401466616, 56.640162775593424, 66.82303582468342, 67.35272838223365, 62.69427053390011, 58.2049217531758, 58.53450282927483, 60.020022084636075, 59.21294735323999, 63.991519943360366, 60.690229631239376, 62.240479761554354, 63.594650606955256, 63.88693386508573, 63.88881268039827, 66.63078477305751, 53.5736616196171, 54.68546921207059, 55.80754556963521, 62.19542349538496, 67.39204622084095, 66.67927311312768, 66.26146224237257, 69.07240529214182, 66.6027476710658, 72.82584682587655, 69.67649736712056, 78.7288256614439, 5.752964846549496, 1.7292402612586177, 10.875138044357302, 15.90537186591856, 1.499414129122611, 12.444175347205132, 89.82181410635673, 74.74097544147124, 72.85890456168883, 80.21247786860313, 82.53703917226484, 77.18505136428341, 68.32558601133286, 35.88143048747894, 65.10883062116562, 91.83554326334308, 34.586165797325876, 0.7098577447956609, 0.5565006706503131, 0.18066654582658123, 0.15046807997409375, 0.1644069425040676], [0.04654110161467426, 0.023700021612908573, 0.038703332670153155, 0.03481055647435208, 0.09565367693862609, 0.04328652262507428, 0.07653757689460632, 0.09297969300420054, 38.68057504776986, 63.5899123837871, 47.08909726911976, 33.78000497817993, 45.22091550211753, 43.96963627107682, 57.49089348700739, 69.22995121248307, 61.5489149093628, 59.683729833172215, 69.0498673531317, 33.22547989506876, 0.41740585539129477, 0.4845074966790215, 1.8613107550528742, 0.4112498486234296, 0.4239251716963707, 26.068013329659742, 73.04353052569975, 60.153229698058105, 61.626099309613636, 56.12365722656251, 56.17626013294343, 53.057756193222545, 49.04310441786244, 47.5066767200347, 49.19414704845798, 50.11107560127012, 54.330361350890136, 53.747367705068285, 54.34041046327161, 57.62583478804558, 55.54588425544001, 51.46394814214399, 53.678961569263095, 53.87886516509518, 53.722017426644605, 54.65814598145024, 54.23375729591616, 53.342704619130785, 53.54959003386959, 54.14595896197904, 49.9333373192818, 48.61618580356721, 48.366515174988784, 52.703315134971376, 55.43720714507565, 56.05374882298132, 56.968520072198686, 55.33846932072794, 50.82686108927573, 43.06083094689154, 42.27359556382702, 42.72609587638609, 40.52364580092892, 40.6417130654858, 47.04733579389511, 46.26406984944498, 41.88451213221396, 37.104143096554665, 39.549415342269405, 37.885730266571045, 37.45841157051825, 37.4527515903596, 39.66792191228559, 40.897310395394605, 40.582732385204686, 42.880711786208614, 43.76889721039803, 43.631151414686634, 45.52376954786239, 43.87833133820565, 47.71773553663685, 44.36251655701668, 50.27197122573853, 52.94910261707922, 52.48865950492121, 48.21693558846751, 42.94632127208095, 42.03731982938705, 41.64474941069081, 41.18873073208717, 46.00377352006974, 47.38982539023123, 50.49520507935555, 51.16539693647816, 52.96461559111073, 50.69932914549305, 48.59506776255947, 44.79450287357454, 46.91529704678444, 47.459792629365005, 45.14268382903069, 44.035865491436375, 45.53661138780656, 43.47597852829964, 43.85145525778494, 41.02132789550289, 40.30001186555432, 38.80195671512235, 39.06918387259207, 38.85902720112955, 36.59858488267468, 37.488445158927675, 39.11605619615124, 38.13474193696053, 41.049098276322894, 40.09688800381076, 37.73569176273961, 39.75422974555723, 42.761867892357614, 42.1425138750384, 43.84337909760014, 43.886823269628714, 51.284393802765884, 54.7403706273725, 53.89112257188367, 54.5950742690794, 54.40621214528238, 60.13780301617038, 51.37477697864656, 44.44260351119503, 52.7450099299031, 48.94365272214336, 49.42389595893122, 49.354015011941236, 52.19185767635223, 51.55575121602705, 54.106017466514345, 59.42869732456823, 58.66248584562733, 57.53302758739841, 59.57122841188985, 60.22472666155908, 62.09725441471223, 56.13081947449715, 45.19829127096361, 47.78483944554483, 52.71562745494228, 56.39983523276545, 56.46679401397706, 61.53442567394626, 58.667545703149614, 64.72412847703504, 64.0092255223182, 73.31588422098469, 4.091750373763423, 0.36480212163540626, 1.7866857013394757, 1.2662235839713005, 0.5341546826304928, 10.794886350631716, 73.76843160198581, 64.09786324347219, 57.77080951198455, 65.89579536068824, 71.79391830198227, 56.12710498994397, 36.40212905022406, 25.814665479044763, 48.31257866274927, 74.31653576512491, 19.68562279978106, 0.5201447731064213, 0.2604452568677164, 0.11829923598035691, 0.134996474690495, 0.03125280584959734, 0.03983905801789896, 0.03176474793543739, 0.08465950317200154, 0.04335794117181532, 0.025641150517208923, 0.04991807847193653, 0.0882336710609736, 0.02987347028758978, 47.553035213101296, 70.91290689283802, 54.98684844663067, 42.646805163352724, 48.40098496406309, 49.68634566953106, 70.71645890512775, 73.57729450348886, 68.92146464317076, 63.49744250697475, 75.15824502514255, 34.30628899605044, 0.3922765473684957, 0.5672260241643076, 5.127878285223439, 0.3358969500949306, 0.5236609941048007, 27.236999273300174, 75.85802724284511, 62.991040983507716, 63.840889161632916, 57.23788099904215, 58.471823353921216, 55.59643968459099, 50.62423929091423, 48.97227033492058, 50.77080649714316, 53.63687061494397, 56.359050427713704, 56.13083908634802, 56.99454499829201, 58.38806113889141, 60.302401358081454, 54.7838108770309, 55.332503395695845, 56.36635388097456, 58.59897875016736, 58.26358079910279, 56.451987066576564, 55.113521391345614, 56.56468852873772, 54.605900010754986, 50.27247328912058, 50.024638329782796, 50.807441434552594, 56.20582695930235, 58.016600916462565, 58.62953793617987, 56.582092085192286, 56.17316538287748, 53.21569042821085, 46.01053176387664, 43.665268190445445, 44.497238205325225, 44.770988264391505, 41.643078480997396, 46.97226162879698, 47.85040578534527, 43.97841845789264, 40.176680780226185, 41.671339158088934, 39.61475810697002, 40.70390224456787, 39.57706020724389, 43.15296742223924, 43.31944457946285, 44.54520879253265, 44.19857717329457, 46.84932278048608, 44.63363470569734, 47.65245945222917, 46.006707452958636, 49.50607745878158, 45.24650896749189, 50.78689213721983, 53.68713971107237, 54.68177433936827, 49.25943489997618, 44.06566766000564, 43.31944850183303, 44.19438415958036, 44.244225717359974, 47.344478868669086, 49.632436613882746, 52.981524928923584, 50.950529498438684, 52.82489292083248, 52.04860879528908, 51.59235085210493, 47.76865966858403, 48.68929878357918, 50.53323245817616, 47.03449395395095, 46.78985964867377, 47.55596522362002, 46.19528324373307, 45.08723328190465, 42.11649287131525, 41.557464907246256, 40.77328897291615, 40.083293068793516, 41.43787184069234, 39.64154789524694, 40.18803996424521, 42.38293947712068, 39.317791538853804, 40.62377998905797, 41.75743518337127, 40.37510172013314, 40.73066065388341, 43.21595676483647, 43.675913503093106, 47.434159940288914, 44.69330964549896, 52.92644700696392, 56.74799265400056, 56.06064827211442, 56.587677540317664, 57.09136086125528, 58.19517074092742, 53.26578301768149, 47.20241846576814, 52.261691554900146, 49.780482553666644, 48.278265768481845, 50.512185019831506, 52.60766029357911, 55.1189499516641, 56.54734773020591, 59.98614065108761, 59.782373520635794, 60.651849239103264, 62.23925598206059, 60.959971027989546, 64.50850794392248, 57.790644937945956, 47.35923874762751, 51.50163819712978, 53.23513753952519, 58.63009099037417, 59.28909624776533, 65.21925710862683, 61.32372771539996, 68.21508499883836, 65.16881150584068, 79.38073142882317, 5.090988393752806, 0.2979713996812221, 1.740815420785258, 1.4147736708964072, 0.575906168068609, 12.06485861732114, 81.59934951413064, 66.58592854776691, 64.24517962240404, 74.62463009742, 77.83317596681657, 64.6844340908912, 48.707035741498395, 24.22949056471548, 56.43377942423667, 84.71291126743441, 25.35527160090785, 0.4590685359172283, 0.15430912225236817, 0.06965713440290383, 0.21662582433031452, 0.10740992432880787, 0.19420132762001407, 0.1451285084288928, 0.24957279915050154, 0.1540909404115331, 0.20532582826431722, 0.10996144144765793, 0.17743429829997404, 0.269290232249806, 57.872567561364946, 80.21731022865542, 63.911064286385816, 43.894915119294204, 62.53319448040378, 59.64789898164811, 70.16655829644972, 80.10096488460418, 74.79984237301734, 69.22377740183185, 81.29709166865196, 40.06249273976972, 0.4689669741257545, 1.5714555666331322, 6.896354383037937, 1.6770864662624176, 0.8628178628221636, 31.216488961250555, 76.41801618760633, 66.1326829848751, 66.24759274144327, 63.400712936155266, 60.56500011874784, 58.1789517402649, 52.62985306401407, 51.93342055043867, 52.95074609018142, 54.26514017966486, 58.08711728742046, 60.89449882507325, 57.37168089036019, 61.71962822637251, 60.65289651193927, 55.728788298945275, 57.53018386902348, 60.227644904967285, 61.072539129564845, 61.2497204349887, 59.21217856868621, 57.19783752195297, 58.052631808865456, 57.604516706159046, 52.09573999527962, 50.78311097237372, 52.858813578082675, 56.80992687902143, 59.71944693596133, 60.2329832507718, 57.89392094458304, 58.37761586712253, 57.12387730998378, 47.61114904957433, 45.411130843623994, 47.98419783192296, 45.48815834906794, 45.38874587705059, 51.21675645151446, 49.58173997940556, 46.51885132635794, 41.80242084687756, 43.82475568402199, 40.16046570193383, 42.53856343607749, 42.13859934960642, 44.633320916083555, 44.78883112630537, 46.85293136104461, 47.67319310096003, 51.46355982749693, 48.489673676029334, 52.83787204373268, 47.49786707662767, 50.80294639833512, 47.72812197285314, 54.39127183729603, 58.27729732759538, 57.81413209053778, 50.13436271298317, 47.66576805422383, 46.95135931814871, 47.21332265484718, 45.66450811201527, 48.62920022779896, 51.403896654805834, 53.57246921908472, 52.11629321498256, 55.49479930631576, 55.37802642391574, 53.64970068777762, 50.65604186827137, 53.28029578731906, 53.257648021944114, 49.24427886163035, 47.249133894520426, 49.228004947785415, 48.48306840465915, 50.06457198050715, 45.8160057375508, 44.38855717259069, 42.91993941030195, 43.156725052864324, 44.432934868720274, 40.914780632142104, 41.30387583086568, 44.1173448870259, 42.536139411311, 45.11128917817147, 44.68530408797726, 41.26192215950259, 44.03125278411373, 46.14557112416914, 46.90308670843802, 48.60456382074664, 47.91108877428117, 55.97321471860332, 58.29394778897686, 57.946586608886726, 58.514679170423946, 59.9629633657394, 61.13458710332071, 57.206564795586374, 51.73437595367432, 54.05410881965391, 50.966105230392955, 49.77070408482706, 50.917150128272276, 53.16165193434685, 56.39185713183496, 57.94507257400021, 60.46498360172395, 61.21749031928278, 63.228995492381436, 64.30545076247185, 66.0881091702369, 68.47080784459268, 61.693473862063506, 50.529925900120894, 53.83633882768693, 55.62756369190832, 62.22859105756206, 62.7674658836857, 68.15477463506883, 63.04737406392252, 70.80111934292701, 67.32007072817895, 82.4614864780057, 6.48314445249496, 0.6473160426943534, 7.817474968971745, 7.541147912702254, 0.9321480845251392, 14.31801317199584, 86.86233089816186, 73.90910348584576, 73.80921640703755, 79.61256704022809, 83.33473159420876, 71.08504403022029, 54.44499654154624, 38.91580743174399, 66.58595208198794, 93.3217763900757, 35.56081987196399, 0.7897317265310596, 0.4538591380321211, 0.2718895379333727, 0.23687374267366626, 0.24788349866867068], [0.01938519417308271, 0.10052363658624311, 0.03420830411355823, 0.04515257491279514, 0.06123508935073211, 0.07668275055625746, 0.12767021499213674, 0.18352932446906645, 31.073030233383182, 65.73092245286512, 49.79776843901604, 23.031869357632054, 21.691265990657193, 40.55819795977685, 55.6143609939083, 72.86451355103524, 61.79835019573089, 64.09665515345912, 61.30131529223535, 46.330844279258486, 0.05391420758960228, 0.24357485164317394, 7.193672493580849, 0.08431496278893563, 0.22048273995038004, 22.652266294725482, 71.97774410247803, 58.85057134013022, 59.933675027662716, 49.73428095540693, 51.812799822899606, 47.9411066732099, 47.845310626491425, 43.60664836822018, 46.60553178479595, 46.76607439594884, 51.666271840372396, 54.9667816008291, 52.808466034550825, 54.87919899725146, 55.603511718011674, 53.72567699801538, 54.59093224617743, 50.95936267606674, 55.3739942273786, 54.22585372001895, 49.9647908056936, 51.293023017144975, 53.156584232084214, 54.24255517221267, 51.805221803726695, 46.969272782725675, 45.566444935337195, 48.17215781058035, 45.26488134937902, 50.20829546836115, 42.91254182015696, 50.59928909424813, 53.521466639734086, 43.62297327287736, 43.91615475377729, 41.91669517947782, 44.838719752527055, 45.907212611167665, 42.373302213607296, 34.930926445991766, 38.55955816084339, 38.29371167767433, 40.02766209263956, 37.777939611865634, 39.37006888851043, 37.550230333882, 39.282313700645204, 40.21370403228268, 42.11888159475019, 42.79794585320258, 43.00163845862112, 43.401308367329264, 46.046982349887976, 44.60886493805916, 45.60240130270682, 43.176156474697976, 48.19279340005691, 50.28200072626914, 53.52870341270201, 49.42547667411066, 43.47510776212139, 42.942963723213445, 43.26353511502666, 42.42137870480938, 45.93446523912492, 45.96937433365853, 51.9190921321992, 49.4974757009937, 52.292235051431966, 47.04330751972814, 46.66011941048407, 44.42247390747071, 46.12495514654344, 46.25802547700944, 47.00766101960213, 45.88691434552593, 42.54290549985824, 42.45227129228654, 42.08399211206744, 38.52617879067698, 41.92673644711895, 38.025786338313935, 38.76357240061606, 37.002863576335294, 38.33181750389838, 37.75386410374796, 37.811923027038574, 36.661648750305176, 36.99504629258187, 37.38228621021394, 40.498373969908684, 40.56077495698006, 42.018590511814246, 43.58147459645426, 42.61867784684704, 47.88331054872083, 55.55142656449349, 53.635568388046764, 54.16887344852571, 53.160588972030155, 58.06936464002056, 44.809231373571585, 33.10236061772993, 51.79414503036007, 50.34644526820029, 54.22677939937961, 55.04978287604548, 55.252934194380245, 52.2047975755507, 50.67881514949184, 44.59790975816789, 41.608098783800685, 48.860263132279925, 56.54765759744952, 59.68477318363806, 62.399575018113666, 57.580578480997396, 55.80069318894417, 48.593275239390714, 48.12545414893858, 47.709565239567915, 51.94290091914516, 53.984890753223056, 57.09904478442285, 53.9734923455023, 68.49983338386782, 59.70926054062382, 72.5538775228685, 7.153268158435822, 0.2191173874082104, 1.9188585444804163, 0.4422927425513345, 0.3005913590952274, 15.234199416252876, 77.0680078383415, 61.150527615701, 63.87518244404947, 65.00233827098724, 71.83915891954976, 51.141462633686686, 29.34126065623376, 30.77474182651889, 54.10477799753989, 69.99142446825581, 10.165984303720537, 0.5572921314066457, 0.09917176719154082, 0.0586628572144095, 0.03146929846655938, 0.01391345905440469, 0.06429293313093724, 0.11883143726135455, 0.10217509232461454, 0.026211123763313218, 0.058114728965466066, 0.11682251723663462, 0.12353457360258027, 0.12348265582395178, 39.12286935314056, 73.79075773300664, 58.18417241496425, 28.098810680450935, 34.09030368251185, 49.81136729640346, 57.84899411662933, 79.10549871383175, 66.1526321595715, 68.87368232973161, 67.2790035124748, 51.0571159855012, 0.11539832914188025, 0.20489430625832852, 6.319798817557674, 0.5654505387909952, 0.29153004048332093, 26.131385103348766, 74.12076242508428, 60.84946609312489, 62.37981803955571, 53.68481766793036, 52.398048831570534, 50.89864830816946, 51.781907235422445, 46.84027387249855, 48.8993142497155, 50.58976557946975, 54.31893156420801, 57.70624337657806, 55.275989886253114, 56.92122021029073, 57.927029671207556, 54.576682275341405, 55.16231175391905, 54.395904156469534, 57.911328423407774, 55.99803547705374, 52.367595549552675, 53.21496871209914, 54.22748542601063, 56.49162653953799, 53.018144176852324, 47.56775194598783, 45.60647272294568, 49.377533543494444, 46.719947322722405, 50.980719981655, 45.52207508394795, 51.02290507285826, 55.88007019412134, 44.589088347650346, 45.353613207417155, 43.628382221344985, 45.51659553281723, 48.94595515343451, 45.5078015788909, 38.065402277054325, 40.07382054482737, 39.45618452564363, 40.38565681826684, 40.29745840257214, 39.98320202673636, 40.20259195758451, 41.483516462387584, 43.32078603006179, 44.41133437618133, 43.841127657121234, 46.42613041785456, 44.71943655321675, 48.440714651538485, 45.930068262161754, 47.166736664310584, 44.402999339565156, 48.586242429671756, 52.28739484663933, 53.76637551092333, 51.15785421863679, 44.33371851521154, 43.737741824119325, 46.25620157487931, 43.746543622786, 46.7990929080594, 48.213389765831735, 52.289450168609626, 49.44979144680885, 52.57640292567592, 49.3712067604065, 48.81507350552467, 46.49169283528482, 48.51922481290756, 47.06884607192009, 48.31963108431909, 47.87902732049265, 46.477517389482074, 44.37384436207433, 44.25188610630651, 42.381413675123646, 44.74323749542237, 41.31738055136896, 42.15873287570092, 37.196189357388405, 40.337042962351155, 40.37378380375524, 37.706728981387236, 37.34810667653238, 38.62875661542339, 39.64002601562008, 42.24656651096959, 43.827987717043975, 42.88239056064237, 45.83519397243377, 44.363403012675626, 48.19031053973783, 57.437380590746486, 55.11993446657735, 54.89752038832634, 54.64746144510085, 57.70213665500764, 47.521785689938454, 34.844583311388575, 51.753077814655924, 51.06948321865451, 55.08290336978052, 57.27772443525253, 55.872539243390484, 52.72282892657865, 50.966093463282434, 45.42859715800132, 43.300170052436094, 49.463500130561094, 58.21191926156321, 61.27947945748607, 63.80190080212009, 61.04689859574842, 56.74745921165713, 50.1938650684972, 50.13501382643177, 49.536220873555834, 54.0361600537454, 55.54208740111321, 60.76690804573798, 56.5896701043652, 73.26249291819911, 64.33056962105536, 78.65135885054066, 8.083849010928985, 0.1941885339516786, 3.3820202898594642, 1.5018924542011753, 0.3534027333221128, 17.571282886689712, 84.57109405148415, 66.01461179794805, 68.1912919013731, 72.27444002705236, 80.10570310777234, 59.58896144743889, 38.336669475801536, 34.31685978366483, 60.66427138543899, 80.78176283067273, 15.083075396476255, 0.6640064019349314, 0.22410135626071886, 0.05604285566556839, 0.12355578657720359, 0.02473611531088189, 0.12561463255194888, 0.25750216156724964, 0.17826193372809118, 0.1423511792334818, 0.22400757177702843, 0.30458466900933173, 0.40109467902971857, 0.21539619192481044, 47.07961690041327, 83.93745868436753, 64.90606761747792, 32.72010014903161, 31.676531991650982, 55.84493360211773, 68.17260572987219, 82.13747516755136, 71.61674484129875, 73.63079563263925, 72.37377797403644, 59.56940058738955, 0.18227874721971252, 1.1357767062802469, 18.545787911261282, 1.141426022494993, 0.40702750906348234, 27.755575833782075, 75.12769760624056, 64.02031014042517, 66.20003008073377, 54.87490792428294, 54.764783459324995, 52.6147166375191, 55.657012847162065, 47.106155656999164, 52.11765427743235, 51.65315935688635, 55.780041909986934, 59.46204139340309, 57.26236835602791, 59.76669188468688, 60.308920337307846, 57.297257838710664, 57.789272108385646, 55.09937732450424, 58.85011242282007, 59.53598983826176, 55.88589099145705, 56.19449130950436, 57.894175898644235, 58.93401976554625, 53.75354936045986, 50.64285485975204, 46.79245233535767, 50.51397362063008, 47.49192860818679, 52.71509401259884, 47.603578875141764, 55.10061679347869, 56.62768963844546, 48.01352931607155, 49.70789124888759, 45.57015941989037, 49.219520861102694, 51.19246521303731, 47.2032029398026, 39.1704830046623, 42.16421242683165, 41.75064948297317, 42.504121103594386, 42.47864138695502, 41.60006576968778, 44.53619910824684, 43.70778276074318, 45.43573587171493, 47.00161272479642, 48.47053250958843, 49.24230983180385, 46.56352712262062, 50.85023841550274, 48.172989353056884, 49.92800681821762, 46.37863443743798, 50.880534802713704, 55.11509033941454, 56.46949652702578, 50.44626566671556, 46.939756947179, 47.55497286396642, 49.79843131957516, 47.31749688425372, 49.320086509950706, 50.07009467770977, 55.712424170586374, 52.68590373377646, 54.406671062592544, 49.61017324078468, 51.153606291740175, 48.506700684947354, 51.23696842501241, 50.59580995190529, 51.76218163582587, 52.626675944174494, 49.08796064315304, 49.02823471253919, 47.50435467689268, 44.1355642964763, 46.242877283403956, 43.2779106017082, 43.167221315445445, 40.73974878557267, 42.70846482246153, 41.94495977893953, 41.01682501454508, 40.64361149264921, 40.6403676925167, 41.11757109242101, 44.27617342241349, 45.61211701362364, 46.916375698581824, 46.267807868219194, 46.03551333950412, 52.806045932154504, 61.748865573636955, 57.60763106807586, 57.090658756994436, 56.1751736364057, 61.15394007775092, 48.2338959170926, 36.9732222249431, 50.80018504973381, 54.01681100168536, 55.414018092616914, 58.91894217460387, 57.61382449057795, 54.46356896431216, 52.582741475874386, 48.58264953859391, 46.658421024199455, 50.30914745023174, 59.77706263142248, 64.18863473399993, 66.45037143461167, 62.47567292182677, 59.61518249204082, 54.65469037332843, 53.74636357830417, 52.10205108888688, 58.448324434218875, 57.872959798382176, 64.01609751486009, 58.668643966797866, 74.72605474533574, 65.51680418752855, 80.17761584251159, 11.160048227156363, 0.502343126722882, 7.918900107183765, 4.00822889420294, 0.7918381006006272, 20.466537283312892, 91.98693106251379, 70.37120403782015, 77.79824333806192, 76.98397497976981, 86.15644547247118, 71.02394134767594, 45.57807476289811, 46.644065149368785, 71.30395935427758, 92.60781088183003, 22.593093418305923, 1.1126976027604074, 0.419104854546247, 0.2017692037888112, 0.24545308472889088, 0.21772447102252515], [0.08364342543626986, 0.09071035671137995, 0.03462377657753325, 0.07025039289146662, 0.013839208855173521, 0.12011530869189771, 0.09547428979027657, 0.3240552532576746, 21.268320737346528, 70.78214291603335, 43.61275942094865, 43.72450382478776, 41.42959563962875, 43.993876518741736, 60.19080208193872, 63.46690685518327, 61.334133763467115, 64.5513794499059, 60.77933411444388, 53.59185749484647, 0.453621773349662, 0.1988210982733196, 2.346682735989171, 0.282425637086553, 0.2175666415883649, 19.213481218584125, 73.91226491620465, 58.05023916306035, 61.576308742646255, 47.461294897141, 52.09635188502651, 48.037498920194565, 47.05998543770083, 44.03288056773525, 43.23077940171765, 40.15571571165516, 45.72045680015318, 48.51909537469187, 53.32505003098519, 53.19531763753584, 56.10482984973539, 55.72273608176939, 54.39528834435248, 54.41971686578567, 52.31626349110758, 50.733308638295824, 44.81744481671242, 46.537153105581964, 53.24803037028159, 54.1948591509173, 55.6312075737984, 53.613101051699736, 51.90586197760798, 51.3364593444332, 52.6519791541561, 49.351861630716634, 50.891066366626376, 56.06453534095518, 50.78631162643433, 45.792200872975016, 42.71878065601472, 40.8061662797005, 44.07406153217439, 42.67181419557141, 42.305876670345185, 41.46215523442915, 41.4250692244499, 39.21357024100519, 40.71980745561662, 39.51139973055932, 38.60548911556121, 36.83902617423765, 39.31081364231725, 38.41485408044631, 40.19225651218046, 41.038743219067975, 42.483497281228345, 41.05577807272635, 45.224088699586936, 48.45865949507683, 46.08253863550002, 43.29137217613959, 45.94043508652718, 48.947551558094645, 52.71047738290603, 48.767279424975, 43.71272102479012, 42.19692107169859, 41.35489017732682, 44.37366393304641, 47.93014757094845, 43.75767923170521, 49.8385924677695, 48.04978770594443, 48.23800656103319, 44.680314833118075, 46.235660122286895, 43.39846464895433, 46.81540996797624, 46.39859930161507, 45.48845644920103, 45.38193664243145, 43.028502771931315, 42.64495772700156, 42.434330371118364, 39.75356686499811, 40.49240412250642, 39.39545446826566, 39.69372718564926, 37.77316216499575, 39.65623324917209, 42.014150388779186, 39.74567505621141, 38.27636695677234, 38.32660467393937, 38.333072662353516, 38.80876987211166, 42.559838371892134, 41.74437369069746, 44.208924385809134, 44.634246595444225, 51.602964785791215, 56.355308486569314, 53.09763100839431, 51.91052567574286, 54.203535433738466, 53.617223462750836, 54.39762215460501, 56.11313350739018, 53.24774795962919, 55.10790847962903, 58.14235210418702, 56.16990197089411, 56.514435122090006, 56.20597208699873, 57.631973297365256, 54.4455692075914, 52.767163476636334, 52.74261728409798, 56.97679627326227, 55.850158199187256, 57.39244984042261, 56.000506570262296, 51.40086074029246, 45.74335167484899, 47.131898172440074, 50.008642904220096, 52.218855350248276, 49.04322993370795, 56.49421530385172, 51.27749827600295, 69.17175108386625, 60.96546234623079, 80.43755915857132, 10.060293097649852, 0.05900264402190524, 0.42753457962985963, 0.7877012870965466, 0.507532361173822, 25.395122881858583, 75.78988782821163, 59.50841557595038, 68.74532668821274, 69.36988569075062, 70.79416105824133, 52.26727308765535, 32.8072944379622, 36.08350707638648, 57.629608108151345, 67.62334838990243, 6.21621000189935, 0.37431013079420217, 0.05054126418526134, 0.07726775827787577, 0.01879463422923319, 0.042493219427283735, 0.022695958051049424, 0.0661272693785929, 0.1068766811682332, 0.17504088640693696, 0.0319644651420775, 0.06470714921071645, 0.19454848802378102, 0.274816147021709, 27.199466113121282, 79.60979784688642, 49.026512792033536, 33.624659507505356, 31.235075112312074, 53.08284759521485, 62.39957109574349, 73.37396667849633, 66.34838981013145, 71.0351828605898, 64.89660686062228, 60.08371745386432, 0.3482677685397287, 0.15526576688693416, 4.857760831232994, 1.5595573018635474, 0.32420712252778394, 20.4600614501584, 79.26190714682303, 60.80550416823357, 63.09418362955894, 49.35363454203452, 55.01109261666575, 49.18327031597015, 50.88872863400368, 45.91433955777077, 47.11804436099145, 43.83138841198337, 48.02509246333953, 50.35292894609513, 55.27002396122102, 55.68974894862021, 57.345655964266875, 57.12272413315312, 57.08466145300097, 55.45072755505962, 55.48845291137696, 51.4083642344321, 48.95116013865317, 46.67483222100043, 54.80900818301786, 56.23706079298451, 56.40203960480229, 56.248745533727835, 54.61147369876985, 52.17725076983052, 52.60380852606989, 50.24369093679613, 54.61792599770331, 57.21386040410688, 52.32404547352945, 46.581189555506555, 45.781614395879934, 43.44916912817186, 45.542498865435206, 45.68165279203846, 45.08448762278403, 42.108322574246316, 42.387956188571074, 41.525897672099454, 41.95932742088072, 40.45464738722771, 40.18726725732127, 38.6043712400621, 41.3702658684023, 39.651640153700306, 42.52472531410956, 44.18895952163204, 45.39836745108328, 45.10212259907877, 47.568116726413855, 49.517091474225445, 47.03328586393788, 43.54089767702165, 48.848998085145034, 50.10477235240322, 54.28567770988711, 50.88286076822589, 45.78630555060602, 43.37910382978378, 43.78865026658581, 45.49894094467164, 48.89042223653486, 46.51303837376256, 50.82262100711946, 48.86655461403632, 50.364225372191406, 47.534301973158314, 47.585355543321185, 45.309682661487216, 48.30416125635947, 48.27026805570049, 46.70654850621378, 46.56624140277986, 45.35649614949381, 43.04894616526943, 43.9636742684149, 41.348881106222834, 42.096108313529726, 39.02980327606201, 41.11599822198191, 39.35934905082949, 41.42088405547604, 43.87083176643618, 42.79341159328338, 38.349848639580514, 39.93082661782542, 37.58965015411377, 41.156190749137636, 43.08930343197238, 43.749512857006444, 46.60047192727366, 47.55390205690938, 52.119854727099025, 58.66532564163209, 54.78379518755021, 53.592673347842315, 55.14371187456193, 54.93556737899781, 54.3194414723304, 56.47870232982021, 55.699833362333244, 56.97696493517969, 60.155743937338556, 58.14433682349421, 58.67938733869984, 59.25361840955673, 59.6908175560736, 55.86771865044871, 53.78373984367617, 55.110579613716375, 57.28191352659657, 57.75706552690076, 59.45039979873165, 58.004351354414425, 53.93106014497819, 48.07907604402112, 49.31457165748843, 52.38331248683315, 55.2016648938579, 51.245668242054606, 59.71882327910393, 54.067131088626006, 72.5527871039606, 65.83440242275115, 83.07425483580559, 13.211536080606523, 0.03718339890662221, 3.014231896208179, 2.490150534337567, 0.19377035719733085, 27.769049175323982, 84.22172854023596, 65.09421586990356, 75.05998180758569, 75.121288453379, 78.07627662535637, 59.51600536223381, 39.245090407709924, 36.622013199713926, 66.17020437794348, 77.62161900920253, 10.614933890681113, 0.5790504380579918, 0.18020798091686543, 0.08806889320934012, 0.1385331502364528, 0.034171313558134346, 0.16794127382097707, 0.2453002655097554, 0.20849131888920264, 0.3427337025923114, 0.1292274342549424, 0.27456364444186615, 0.213332167195697, 0.6358872366047675, 32.11253873763546, 90.77698184597878, 58.275426357023186, 57.621045574065185, 55.49389323880596, 62.76700696637554, 70.66409526332733, 76.75210798940351, 72.77441670817714, 76.34189082730201, 70.01383689142042, 64.57823199610557, 0.6744360455101537, 0.7506799349381078, 10.586031906066403, 2.2429867905955163, 0.4464091781166292, 22.810618262137137, 81.21842461247599, 62.255345544507435, 66.97077581959387, 53.72678310640397, 58.30926072212958, 52.097889454134055, 51.06069710946853, 48.67542928264987, 48.5732436949207, 44.45385286884923, 50.021716164004424, 52.8148594979317, 56.37144511745822, 57.2021129054408, 60.38392389974287, 61.255851099568034, 60.11819508767898, 56.72257569528396, 56.99149731666812, 56.36058015208091, 50.26730752760365, 49.159975359516764, 56.99945972811792, 59.44214320951893, 58.26556159603981, 57.920793102633574, 55.99580757079586, 56.03615699275848, 54.68636743484005, 52.532593973221324, 56.99621200561524, 58.82180075491629, 54.09105362430696, 50.34708853690855, 46.78876922976586, 44.14270301018992, 47.10650082557432, 48.2168375292132, 47.48816313282136, 46.52646856923258, 47.00089885342506, 44.87413091044272, 45.333001152161636, 43.86059045791627, 43.423395233769575, 40.09733123164023, 44.30536370123587, 40.67544152659755, 45.51254372442923, 46.32982054064351, 48.30573412679857, 47.62466161481796, 49.67862644503194, 52.01867718850413, 49.72792279335761, 45.63141899724161, 50.48869394486951, 51.52292097768476, 55.84735370451405, 52.91358555516889, 47.454089503134455, 46.20611683014901, 44.39384452758297, 48.016086701423895, 51.959512156824914, 47.754241035830596, 51.6724064273219, 50.19676370005454, 52.13305742509904, 47.772715399342204, 49.849175022494414, 46.48357352902813, 51.286511882658935, 52.475633313578946, 51.1926652539161, 49.721666612932765, 47.9453859790679, 46.926271838526574, 47.51132472868889, 43.37396944722822, 45.24157854818529, 42.98472912080827, 43.59459100231048, 41.35618063711351, 44.052747372658025, 47.529642197393606, 45.688869953155525, 42.13004858263078, 41.67467709510557, 41.66194900389641, 43.579627160103094, 44.43353106898647, 46.075015529509514, 48.763902264256636, 50.278709857694565, 54.63519619357202, 62.80908223121398, 57.11707984247516, 55.083821204400834, 58.45043466937158, 57.16875314712525, 55.97353635295745, 58.83203421869586, 59.02221818124095, 58.97430250721594, 62.72211936212356, 62.229046052502056, 59.85608662328413, 61.4073722593246, 62.47547680331815, 57.101021658989694, 57.81448510385329, 57.935376474934245, 59.9640106385754, 59.40374712790213, 62.77740516970235, 59.511365198319965, 56.832386370628114, 50.17996418860651, 52.830839234013716, 55.095321593746064, 57.77037020652526, 54.74971763549313, 61.94300720768591, 56.21519750164401, 75.0105050302321, 65.49131270377868, 87.01891191544073, 16.777234346635883, 0.24690791634061646, 3.674291780879421, 3.9847255618341513, 0.7745215104472253, 30.292168701848677, 89.21500775121874, 69.45833513813635, 82.26437168736612, 82.29438566392469, 83.72907884659307, 68.74206327622937, 47.303529324070105, 50.498848961245635, 73.02592692836639, 92.40357306695755, 16.378627400244437, 1.0022473972170585, 0.37525349146416115, 0.24609981615456844, 0.21906717800565306, 0.1349179966435317], [0.03887840291304935, 0.07361310519157879, 0.17287244389374412, 0.07409656029795447, 0.049768139743396354, 0.036051526981135534, 0.17236391472960674, 0.28702262428499037, 14.955839591641581, 70.1739715760754, 49.22910321143366, 62.19443505810153, 46.431641347946666, 43.21260313833914, 55.213467305706395, 54.58015749531408, 56.16938029566119, 69.44290453387846, 55.674573298423525, 66.86911582946777, 2.7977276040661723, 0.05073743248959223, 1.2784666495938457, 0.857244726390608, 0.11788777015622585, 11.413894218783225, 71.7803547459264, 57.29903075002856, 63.188222454440215, 49.62747873798494, 50.07663719115719, 46.33086781347952, 48.98903062266689, 46.22334780231599, 47.94704906402096, 42.57298615670974, 42.52240327096755, 42.699188417004, 44.64549203072825, 43.86438731224307, 50.33521944476713, 49.28802505616219, 49.684051082980254, 49.71584189322687, 46.17774632669265, 45.02724455248925, 42.58609079545544, 43.57652064292662, 47.93612134072089, 55.28194404417469, 53.64819842000162, 53.457751658654985, 54.19222724053168, 53.83817449692757, 54.410518907731586, 52.9202300502408, 54.32137912319553, 53.39592725999894, 47.159586183486454, 45.209207227153165, 44.04669515548214, 42.205413003121656, 45.554073779813706, 43.543435450523134, 43.466898241350734, 45.40920495986939, 40.062006365868356, 37.46975898742676, 38.65054145936043, 39.610941640792355, 39.50045631777856, 38.495913782427394, 39.4578750671879, 39.07674227991412, 41.55608815531577, 42.23399923693749, 43.11599908336517, 42.00246564803585, 45.243900591327304, 46.40870332717896, 42.46051219201858, 42.26197358100645, 44.163236618042, 48.19601366596837, 55.28911413684968, 51.57951685690111, 46.2401786927254, 43.09219421878938, 42.08882839448991, 43.46443891525269, 49.17812808867424, 45.32040642153832, 50.23790936316214, 47.93537609038815, 46.47588960586056, 46.91757594385455, 47.557742057308076, 43.08213726166756, 44.24553578899753, 44.46414124581122, 43.65029258112754, 44.49497892010597, 42.78948530074089, 42.84035059713548, 40.71668917132963, 40.38713162945163, 38.87837233081941, 38.90679382508801, 38.83990172416934, 38.51143852356942, 37.96470326762046, 40.92732829432334, 45.60930075183992, 48.31186086900773, 46.90988025357647, 42.90277119605772, 43.18266760918402, 41.124262655934984, 40.30566007860246, 43.31543983951692, 45.86802028840589, 50.223745684469904, 52.7398520131265, 52.473068083486254, 54.24812886022753, 50.625443458557136, 54.36436045554377, 55.239778564822295, 53.84702336403632, 56.11190188315607, 55.84483554286342, 54.87572377727878, 53.04405927658082, 53.38892582924136, 53.20748482981036, 57.375077662929414, 50.8400990886073, 59.278066542840776, 60.10364309433968, 57.48151902229556, 57.57790734691005, 54.22483782614432, 46.74582319874918, 49.550357095656864, 46.193176930950536, 49.299411696772424, 48.1678432033908, 51.55063644532235, 50.107008103401434, 55.66075871067663, 54.20823051083473, 69.952436108743, 59.1152685688388, 77.10270512488582, 12.016815466265525, 0.391945168375969, 2.5616519105049873, 1.5264071452040828, 0.2198686591920353, 25.82798977052012, 75.19476229144682, 61.10303163528443, 67.15351120118173, 69.43298878208284, 71.24493552792457, 45.033457586842204, 31.080333686644035, 46.08389969794981, 53.481321181020434, 65.7056898455466, 3.3145430203407042, 0.17332183107012705, 0.04533954633159503, 0.06861852602131906, 0.07789024302074987, 0.0543306453243619, 0.09256772156203948, 0.013019976453975806, 0.08012697461151308, 0.07296720880173868, 0.06737419238854801, 0.06728456776228643, 0.13851657209377136, 0.285980683420935, 18.86355676958638, 79.29615728316769, 56.07172112311087, 55.81422928840884, 39.35719959197506, 53.34874506919615, 56.76787514840403, 59.76701351904101, 59.95751127119988, 74.99453313889043, 60.93205944184334, 73.25798219250095, 3.2450619099601625, 0.215767162341264, 2.264152635489741, 2.7134319466929284, 0.06940158279312235, 12.264239557327764, 77.25504998237857, 59.35630606066797, 65.85570873752718, 50.05527596319876, 52.52369411530034, 49.50584996131159, 50.78101250433153, 48.06844249848397, 51.08577674435031, 43.795647774973226, 44.60188311915244, 43.95762597360919, 46.54167559839065, 46.618416770812004, 54.26430079244799, 51.02343459283152, 53.167398206649295, 52.018147668530865, 49.46035831205307, 46.008692172265825, 44.62299723779002, 46.05051248304306, 51.68737026952928, 55.754766156596524, 56.503546622491655, 54.96429089576968, 57.36843316785751, 55.397379398345954, 57.87570153513263, 54.383454553542606, 56.26909871255198, 53.52014480098602, 49.36893178570656, 47.369154499423125, 45.25441254338911, 44.34316358258648, 48.21224443374142, 44.87076943920505, 45.85530396430723, 45.46378081844699, 43.15849796418221, 39.1003353365006, 41.21382605644965, 40.391685501221694, 41.503822572769664, 39.540123247331195, 40.392685705615634, 42.06882038424092, 41.983026381461855, 44.370514269798036, 45.229081876816295, 45.87202502835182, 46.38336873823597, 48.72554932871173, 45.359088836177705, 42.894867620160504, 44.28228839751213, 49.19034627176101, 57.1650621967931, 51.63324940589167, 47.60665401335686, 45.722567035305886, 44.24848541136711, 45.06710367818033, 49.86323279719199, 46.15451412816202, 52.59746213113108, 49.38572345241424, 45.73994705753942, 46.20376340804562, 48.30842487273678, 45.328066810484856, 45.26321434205579, 48.543265019693685, 45.597843508566584, 48.02761454736033, 45.230454706376605, 43.57475949871925, 42.91351849032987, 41.015063870337706, 39.710491395765736, 41.144035323973625, 40.695728025128766, 40.56869814472814, 40.91032874199652, 43.04701243677447, 47.99564723045596, 49.621293160223196, 48.99305105209351, 45.11046548043528, 43.7804917366274, 42.20091012216384, 43.24167966842652, 44.846152644003595, 47.73551564062796, 52.7611191042008, 55.744901395613155, 55.26109664670883, 55.83008350864534, 54.849702773555634, 55.223861586663034, 57.614522672468624, 54.124754628827496, 57.28869138225433, 56.36115674049624, 58.0433318691869, 53.91805356548679, 54.54582891156597, 55.065593950210086, 59.82904972568635, 55.87286480011479, 61.18067495284542, 61.09910534274194, 59.59855948725055, 59.08295216098909, 58.30159641081288, 50.392897898151034, 50.66589093977406, 47.76421170080862, 51.22435408253824, 50.322283467938824, 53.511146883810724, 53.05015463982859, 57.5346161473182, 55.99539964429794, 73.79020075644218, 63.98513040234966, 82.0779178988549, 17.801933942302583, 0.3551812830471224, 4.216045871857674, 2.0941196045567914, 0.18477973317907703, 28.484758177111228, 83.38838961816604, 65.60414360415551, 74.20655250549316, 76.5551265593498, 78.38014264260569, 53.31850751753777, 32.57954005272158, 45.396975009672104, 63.696502793219786, 75.16392461715206, 6.010536599543787, 0.40068423976340606, 0.250283544883132, 0.07443501028202235, 0.10167783231384332, 0.10519085872557857, 0.14902539851684726, 0.21887680515646937, 0.24181975953040585, 0.17268902712291287, 0.2553088365182761, 0.25044235490983535, 0.23324311410467471, 0.6318465824569426, 21.48221738876835, 91.49927062373008, 63.182358511032604, 78.12623193187099, 59.83579228001257, 59.056044701607, 67.21732816388531, 67.8805931152836, 66.55222754324636, 78.57027561433854, 66.42899451717254, 78.08470972122686, 4.914446924963306, 0.6492441327821824, 7.939839190052402, 5.244128511797998, 0.2503570893238629, 13.135699014509878, 79.17343416521626, 61.93386024044406, 68.1494951248169, 54.01082546480241, 55.652247167402706, 52.0551787653277, 52.879864938797496, 49.43665935147194, 53.420473452537294, 45.561294863300944, 47.95724722646898, 46.662712097167976, 48.93335650044103, 49.10532497590589, 56.55143876229563, 52.745245272113436, 54.58356603499382, 53.83815096270654, 50.90553991256222, 48.63616243485482, 47.83966241344329, 47.89758797614805, 53.96425908611667, 59.013322245690134, 58.12836885452271, 56.42174559254801, 58.87915757394607, 57.97214085055936, 59.54986718393142, 57.206584407437234, 58.85394065610824, 57.620602346235714, 51.51178929113573, 48.91926734678207, 47.3112799275306, 46.447617161658506, 48.787063860124164, 49.1398222215714, 48.295273165549006, 48.8371289930036, 43.999332535651426, 41.085062488432854, 43.37567960062335, 43.74543359202724, 45.17483549733316, 42.77631398170225, 42.82843443655199, 42.22289500697967, 44.00772248545001, 47.594137730137, 47.57906013919462, 48.48174656591108, 49.19032273753997, 52.55210384245842, 48.86123588008266, 45.5537639125701, 44.92602779019264, 48.894583871287686, 60.066553161990264, 53.00174866953204, 49.73212365181216, 48.300305566480084, 47.60474381908294, 46.24063368766539, 51.88006062661448, 47.34329039050687, 52.94179916381837, 50.18205873427853, 48.097938722179784, 50.883366753978116, 51.40965861658896, 45.44912292111305, 48.292064666748054, 49.4477439695789, 48.60586604764385, 49.6839883250575, 50.908222813760084, 47.38724839302802, 45.84779262542725, 44.29169424118535, 42.01922985815233, 43.91485252688008, 43.614602934929636, 41.92599119678621, 42.606581257235625, 45.09042216885475, 48.67366813844251, 53.72229591492684, 52.41034938443092, 47.910649468821866, 46.87923477542016, 44.67381938811272, 44.22741443880143, 47.19464040571644, 49.997895609947946, 53.9621017825219, 56.71708045467254, 54.439634661520685, 59.33507034855505, 54.09494069314773, 59.19183323460241, 60.560638443116225, 56.26437617886452, 59.01063934449227, 59.95180422259916, 60.0152014916943, 56.57247835589994, 57.84927652728174, 59.48188074173466, 61.14939012835103, 56.51081477442096, 61.65777637112526, 64.7672470923393, 63.05172789481379, 63.83676282821163, 60.78206800645398, 53.31224741474275, 54.569406278671764, 50.96445391255041, 52.8237711229632, 52.22544493213777, 55.55554505317442, 55.93830170169954, 59.54171649871334, 59.03272621093258, 76.41441545178814, 65.92703311674057, 82.77738632694368, 21.622469579019857, 0.3655641033284126, 7.377658130661135, 5.716894730444878, 0.6991023606350345, 31.700283904229444, 89.87739409169843, 72.20193109204693, 82.14094254278368, 79.89601319836032, 83.22718804882419, 61.551189884062744, 46.92555012241487, 61.49910473054456, 69.47094948061051, 89.06625578480383, 9.173740360044665, 0.6577882194711316, 0.4351922413033824, 0.2659484035065097, 0.32632777647626016, 0.2471859756136133], [0.07620971424565201, 0.021542629918023463, 0.02355755224163013, 0.015660836661775267, 0.052913892112912676, 0.009860690183667167, 0.0885371184877811, 0.33436235340852893, 10.733554209432295, 73.59040306460473, 45.56114189086422, 40.1910601892779, 23.730951432258856, 38.447099885632916, 60.764272212982185, 62.21184253692628, 54.051657338296216, 70.62143556533321, 54.32477589576475, 71.56211406953874, 7.441515787955254, 0.22929431389897104, 1.4379040103766227, 1.902336540722078, 0.033874749431326505, 4.663560851927727, 69.92718388957363, 59.9696784634744, 64.60930501261066, 48.99129775262649, 48.20783568966774, 48.361133683112364, 52.48174044393724, 50.242161212428925, 55.708462576712336, 51.22344017028809, 47.723438662867395, 41.82589623235887, 41.662423610687256, 41.561210770760816, 42.31474907167497, 39.8371055049281, 43.5980740670235, 40.2917121302697, 41.380401272927564, 40.75992153536889, 43.31538100396433, 41.864076583616196, 44.093304680239775, 45.66775975688812, 49.23699894259053, 51.89826042421403, 51.90475194684921, 49.96171958984868, 52.98540023065383, 51.68459323144729, 52.88400696169946, 50.63259001701109, 47.192318362574426, 44.40923590813914, 44.45384110173872, 42.446948635962706, 41.51917865199428, 43.47087552470546, 40.08845098557011, 39.36208686520977, 39.610188545719275, 40.56406190318447, 40.20842452203074, 37.794625374578665, 38.34659307233749, 38.71506837106521, 39.94649256429365, 37.899897867633456, 40.429430469389885, 42.81268612031014, 47.23196175790603, 45.58701384452082, 41.51495033694852, 41.63745772454047, 43.131033528235655, 42.63809357920001, 40.99350652387066, 40.99118448072865, 48.44520184301561, 54.109775097139426, 49.18916563833914, 45.95237085896154, 41.40468858903454, 46.6817081359125, 46.51793741410779, 45.89314306935957, 52.656180012610655, 46.42076069308866, 45.82990269507132, 47.10506131572109, 43.33011734870173, 43.607417152773955, 43.606546386595696, 43.54748725891114, 45.890613140598425, 42.85060367276592, 43.160125747803725, 41.441723608201556, 42.76979500247587, 39.09948810454338, 37.63071344744775, 39.315312600904896, 39.21733963874079, 37.12880696019819, 38.93626259219262, 36.8530604147142, 36.88188199074038, 38.50271909467636, 46.2642934245448, 37.206599327825735, 41.62482769258561, 41.48246918955157, 40.79448938369751, 43.6557250638162, 43.54296084373228, 49.34913950581705, 49.24449066961966, 50.75596032604095, 50.40370795034593, 50.02926280421596, 48.90923000151112, 52.37755052505001, 54.007820929250414, 53.61906697673183, 51.490216255187995, 51.33784001873386, 50.391882004276404, 50.586780655768614, 52.98284676767165, 55.91654823672388, 55.44028620566092, 53.265135826603064, 53.43019308582429, 55.76545461531609, 53.242244874277425, 49.15466839267362, 48.15204781870688, 46.13713410592849, 44.459712889886674, 46.11312527810374, 44.68854788810977, 47.463679698205766, 46.82509037756151, 52.99743406234249, 54.001419621129195, 68.45466336896344, 60.43726028934602, 75.72214065059539, 20.411078891446515, 0.2040635298697218, 3.868611147326808, 2.48273897074884, 0.15010116982363886, 27.75936092099836, 74.92262040415119, 58.1186217646445, 70.3483993776383, 66.55250210915843, 65.60027222479543, 43.09943491412748, 26.831457576444073, 38.26003420737482, 56.80318432469522, 52.71546663776521, 0.40674773375353507, 0.06567724634923282, 0.07266848813742399, 0.005820488506522511, 0.0573334112132509, 0.07945323858650462, 0.027004612737425396, 0.035374860669816696, 0.03352316870023647, 0.01731137309463755, 0.05407607813756313, 0.09933557211151046, 0.12482288068220501, 0.47734442136941424, 13.306870268237207, 82.44588328946023, 52.58572639957551, 51.30939106787405, 32.670378223542244, 51.53643354292839, 63.67722434382286, 64.69199642058342, 58.41443123355989, 77.24841333204701, 59.21032720996488, 77.84855165789205, 8.752191470515344, 0.13437156144890094, 0.9324835697489401, 2.712724449173097, 0.05060680300718354, 4.6923265341789495, 74.79810084066084, 59.819616425421934, 67.86120876189202, 50.37763987818072, 51.24278529997795, 48.202160020028394, 53.47102888168828, 53.579658923610566, 57.81239840292162, 52.2449783355959, 48.96059736128777, 44.57472462807932, 42.85372980179326, 43.84132769800002, 44.18810836730465, 43.39693492458713, 44.38387386260494, 41.324225087319654, 44.31176108698691, 42.91801744891752, 43.699451646497174, 43.114543884031235, 48.08303763789516, 47.11265502437469, 53.112473257126354, 53.35642506999355, 54.48997043794202, 53.38682736119917, 53.5715788410556, 53.34443830674695, 53.22894019465293, 52.713352480242335, 50.49792720425514, 46.36149760215513, 45.70610484769268, 42.68864116361065, 46.08462925880186, 45.26978038972425, 43.07849730214765, 40.25382987914547, 41.21929384046986, 42.90859983813378, 41.360699207552024, 38.777971421518636, 40.49545180413031, 41.69423795515492, 39.66380342360466, 39.3411688650808, 42.96405038525982, 46.42429474861392, 48.6011552810669, 48.401086945687574, 45.91109575763826, 45.79535053622338, 44.11695265000866, 43.42515245560677, 41.43340426106607, 42.58512197002288, 50.88433950178085, 53.665433314538774, 49.39943605853666, 46.55151290278281, 43.62079243506155, 48.1424537012654, 47.5938396300039, 46.514140559780984, 52.70295427691553, 45.997187860550426, 47.025178324791696, 47.4906656049913, 44.56905680318033, 44.570923851382354, 45.33727653564946, 45.97716023845058, 47.58204898526592, 43.47323286917902, 44.9049215162954, 43.03776741027833, 44.344736453025575, 41.329559510754, 39.177429522237475, 39.146662450605824, 41.1049489052065, 37.88427898960729, 40.87596485691686, 39.258010695057536, 39.58222204639066, 40.38971254902501, 48.00342136813749, 40.743023964666556, 42.74060472365349, 43.291842860560266, 42.68331850728681, 46.498894306921194, 45.825897955125384, 50.472953473368, 53.188433877883426, 53.67680034329815, 51.45194961178688, 50.2907201551622, 50.51030620451897, 54.050484549614694, 55.67312202145977, 55.64124491906936, 54.618235864946925, 53.95631628651773, 52.57542233313284, 53.90427820144161, 54.40932258482903, 58.157798397925596, 57.850461083073775, 56.17090217528805, 56.698994405807994, 60.47163201916603, 55.03667823729977, 51.67452450721495, 51.519692867032944, 48.151741873833444, 46.368322526254964, 49.64555301973897, 47.77839891372189, 52.54957783606745, 47.733974149150235, 54.53394020757368, 55.68397914209674, 72.68358245972665, 63.62181302039855, 78.40630485165504, 28.032322583660005, 0.11515831379520318, 1.4078243341176742, 1.2904960686160674, 0.23612899795895625, 30.542423763582786, 81.4401718877977, 63.063463626369355, 78.68320849633987, 72.3484080837619, 71.32242587304884, 54.16548059832666, 33.12951518643287, 47.027265025723366, 67.1899421753422, 61.03895971851965, 1.4308024366055767, 0.1868961123569358, 0.10024727036755893, 0.0958254951382837, 0.05769202846192545, 0.059000866697920915, 0.1067489666503764, 0.16666251985776812, 0.11106185014209441, 0.24870707383078916, 0.11655371230576309, 0.39884449493500496, 0.29809642523046465, 0.5602684136359923, 14.7700329942088, 96.96632508308657, 59.04428935820057, 57.625548455023, 33.05280931534306, 55.29452308531731, 70.93795514875843, 73.00498147164622, 64.81973232761507, 82.44232177734375, 64.3822076243739, 84.10463010111164, 11.696750060204538, 0.447403866677515, 4.078069636898657, 6.0630316407449785, 0.12061001762988106, 6.06197162020591, 75.15537385017642, 63.25931541381344, 69.91405963897705, 53.063835866989635, 53.69344688230946, 51.21996887268559, 55.862337158572295, 52.72293090820313, 61.03124049402053, 56.31864217019851, 52.8795236925925, 47.559985653046645, 47.09927974208709, 45.96067059424616, 46.76662745014314, 43.692689480320105, 47.97742389863538, 43.21180689719416, 46.58817921915362, 44.78037057384368, 47.19596224446451, 45.5999380542386, 49.12171263848582, 48.81750145266133, 53.98021528797766, 55.16449651410503, 57.33566176506781, 55.12770860425888, 56.35725005980461, 54.96931545196041, 55.97218705761818, 54.585182051504816, 51.84512015311949, 48.22989117714667, 48.379835544093964, 44.28834061468802, 48.38427566712903, 47.07222323263846, 45.66268813225531, 42.691571174129365, 42.70154183910739, 45.49497935079759, 44.97253141095562, 40.39932235594719, 43.07135074369369, 44.316911159023164, 42.36040546048073, 41.567929790865996, 44.83745674933157, 49.018828868865974, 53.33485595641598, 50.90378661309519, 49.84366409240231, 49.55125139605615, 46.16683429287326, 45.31058480662685, 44.20336246490479, 41.38138578784081, 51.83522401317474, 55.7364643773725, 51.078108510663434, 48.914356539326334, 45.80008483702137, 49.794352054595954, 48.15984549060945, 45.844654729289395, 54.34596846180578, 47.80710674101307, 50.514412926089385, 50.11118542763495, 45.05521889655821, 45.52646421617078, 47.134361420908284, 46.981820444906916, 49.45557694281302, 46.49603882143575, 49.97307092912736, 45.1930784410046, 47.676389832650464, 44.54014109027001, 41.90738347268874, 41.980778863353116, 44.379233698691095, 40.17874002456665, 44.10579350686843, 41.52750976624028, 42.41527941919143, 40.495734214782715, 50.991247623197495, 41.21246891637003, 47.59538112148162, 44.90813785983671, 43.99842254577145, 49.73231977032077, 48.42502517084922, 53.337303515403505, 55.96090239863242, 54.65669470448648, 55.060824348080544, 52.029126382643184, 53.07428898349885, 54.6794326843754, 58.50660301023915, 57.84826847814745, 55.50708416969546, 55.30496443471601, 56.4876296443324, 55.07343084581437, 58.18401159778718, 60.993648498289055, 61.50242305571034, 60.830238634540194, 59.168279401717655, 59.75522679667319, 59.573530843181, 53.83005911304105, 54.444000259522475, 50.38220943943147, 49.69622219762495, 50.99638200575306, 50.39855003356934, 53.57252020989695, 51.40800337637625, 54.99149253291469, 59.0109178327745, 74.7141307400119, 65.9554781452302, 78.95393048563312, 33.30974025111045, 0.1442736309141882, 7.400391207587335, 6.861990497958276, 0.37228931342401816, 35.40165793511176, 88.92046913023918, 68.41052885978453, 82.35856348468413, 76.40151869866156, 78.62743239248954, 59.138649817435976, 40.12627440114176, 55.85459047748197, 75.10640698094522, 73.77596255271666, 3.6056368197164232, 0.5236464077907225, 0.2693971781240356, 0.18215868592021928, 0.18582262399215854, 0.20327884133063978], [0.0718472725261123, 0.048985875872594696, 0.04390032759176628, 0.04125568482484068, 0.037855870886555607, 0.035789762398288134, 0.07578585311890611, 0.2787368318005916, 4.90137170399389, 62.6229775336481, 50.130055950533965, 29.16627980047657, 17.956930322031823, 35.84773340532857, 58.80083176397509, 70.06539252496535, 46.76635288423108, 66.09832302216562, 54.586911816750806, 69.37820111551594, 16.733227314487582, 0.35049824885302977, 0.5062152415273652, 2.745715259544311, 0.29058481055882673, 0.12689800602534126, 54.136772771035474, 64.17478876729166, 62.26223322653002, 54.976136453690074, 50.61032664391303, 47.36109010634884, 51.902331844452895, 54.78786660778908, 56.04943421579177, 56.26979297207248, 58.078550830964126, 52.54725971529561, 47.1112782724442, 39.058338519065614, 43.24519803447109, 41.744507051283314, 42.634343793315274, 39.88174599985923, 43.31617332273915, 40.74875454748831, 40.69915617665937, 43.02398812386298, 41.00972160216301, 41.42813259555448, 42.965282009493926, 43.72249164888936, 49.59044371881793, 49.67580233850787, 49.40672774468699, 51.10234875832835, 53.67541966899749, 44.875958734943026, 46.11920495187083, 44.53313965951243, 41.89962894685807, 41.96909412260979, 43.747563439030806, 39.0169692808582, 40.84213833655081, 39.46052658942438, 36.92230201536609, 39.90992822954732, 39.211106992536976, 40.9840928354571, 39.970226826206336, 39.85725864287346, 38.80658118955551, 39.71770071214245, 40.39841628843739, 44.7580522875632, 47.78942861864644, 50.59188758173297, 49.5858859246777, 51.68788410002186, 44.417155173517045, 42.02245796880415, 41.542367704453014, 39.5639673356087, 47.48134605346188, 53.936880942313906, 48.04741859436036, 48.43727081052719, 43.83532647163638, 49.57038864012688, 46.49846284620224, 49.717422608406316, 51.246170305436664, 40.9725022315979, 45.62058541082567, 42.62206285230575, 42.79107778303085, 41.05687633637459, 42.39786409562634, 43.36099032432803, 49.36643323590679, 41.6026702234822, 41.17680672676333, 42.14595379367952, 42.38517915048907, 38.84369073375579, 38.52043644074471, 39.92293480903872, 37.059981130784564, 38.2657608678264, 38.634706850974794, 39.56161391350531, 38.56354328893846, 35.7726788520813, 38.28983637594408, 42.418833086567545, 39.45942048103579, 40.620798987727014, 39.55928402562296, 42.33146621334938, 45.42190951685752, 44.84994557596023, 47.53657694785826, 48.49984830425632, 48.37833719868814, 47.14199827563378, 47.67190264117333, 46.34645923491448, 45.84132855938327, 48.433513179902114, 48.22585898060953, 47.42317338143626, 46.31812403278966, 44.240389639331454, 49.437400679434504, 52.51435102954988, 53.74882290440222, 56.839191682877086, 55.50528380178637, 56.37753263596566, 56.79677517183366, 51.821464338610255, 49.705051452882834, 45.834417343139656, 46.966844835589015, 47.39321824043028, 46.64300610942226, 49.703729614134765, 44.39618226020567, 52.130284309387214, 49.7021371318448, 67.53333783918812, 58.686596655076556, 76.78006664399179, 30.241283793603223, 1.2151864387335316, 3.2578620747212446, 1.3424739698248527, 0.06838805613017852, 30.199775311254687, 74.66060607664048, 55.069414338757916, 62.60295383391842, 67.97269036692958, 61.30565343364593, 46.57607870717203, 22.122797312275058, 28.129407128980084, 61.30518667159542, 46.515419252457164, 0.20299739594901764, 0.06876478752782268, 0.15166375936279375, 0.0070266513296613296, 0.061468619763130145, 0.041095786953284856, 0.021665127377115914, 0.05280107417474351, 0.015462510862327633, 0.044269762001931674, 0.02009204626383801, 0.02280698142825596, 0.09487281117828623, 0.34114900375566176, 7.115691361888763, 73.70833304620558, 56.98090299483269, 36.357657217210345, 27.127382755279545, 52.464081933421475, 62.93104833172214, 74.91399118977209, 54.27885278578728, 74.01672547863376, 59.05382856245964, 77.74733097322526, 18.137790810677316, 0.4579029178186771, 0.117326786951913, 4.427568999028975, 0.37847308321825923, 0.31820595745117436, 57.52901500271213, 66.4668296998547, 64.17035256662678, 56.86860161442911, 51.6410235435732, 50.3066175214706, 53.7569579001396, 55.83690843274517, 57.678198429846, 58.20154459245744, 58.795140404855054, 54.148626173696215, 47.845859758315555, 41.10963613756242, 44.72515144655782, 44.591316253908225, 43.84207687070293, 43.266633787462794, 43.97620624111545, 42.548459576022246, 42.821444772904925, 42.56644364326231, 44.913205562099336, 44.54768380811138, 45.44825999967514, 46.217817260373025, 52.32675583131852, 51.61933283652029, 52.09590473482686, 52.88993366302983, 53.29963699463875, 48.67469579942765, 46.00982181487545, 45.46491046105662, 44.16936728262132, 44.900359799785, 47.18894512422624, 40.69917186614006, 41.85210158748012, 41.199513327690866, 39.34391452420143, 41.29764710703204, 42.280420487926854, 41.095237116659845, 42.307822165950654, 40.943735568754136, 40.2609097573065, 40.56886680664555, 42.60992311662243, 46.59388626775434, 50.03641328504009, 52.03650436093731, 52.01904589130033, 51.72638216326314, 44.529064316903394, 41.60485106129801, 41.46919196651828, 40.085599422454834, 47.7794736431491, 54.64839104683169, 48.99987989856351, 49.92085241502332, 47.635008827332534, 53.72218608856202, 47.176417073895855, 49.66870284849598, 50.34936743397867, 41.81917328988352, 46.025915299692464, 43.683279714276715, 44.29366719338202, 43.281950642985684, 44.35406777166551, 44.338782295104, 50.74194961978544, 44.573453780143495, 44.104185335097775, 43.92299928972798, 43.56444366516606, 42.285515646780695, 39.34953920302853, 39.71933634050431, 39.14262240932834, 38.593043435004454, 40.13250312497539, 38.879478439208, 40.35787467033633, 38.18920796917331, 42.34098580575759, 44.212666326953524, 40.47236865566623, 42.633751515419256, 41.89617333873626, 44.971593964484434, 46.962122301901545, 48.47846746444703, 50.74700555493755, 51.14215297083701, 49.909630513960316, 49.15522144686792, 48.64196362033967, 49.82417383501607, 49.76906061172486, 51.33588667838804, 50.534970068162494, 49.45540043615526, 48.59723291089458, 46.7098746761199, 52.008271140436975, 55.50140065531577, 55.20941157494822, 57.90783359158424, 57.57698951228973, 58.70097998649844, 58.68867158889771, 54.32068094130486, 52.04165835534373, 49.36076933337797, 49.680018886443115, 52.23412121495893, 47.88457355191631, 51.68138081027616, 46.971747798304406, 53.37630756439702, 52.697400200751524, 70.60915854669386, 60.701745710065296, 78.57460591100877, 35.298330937662435, 1.0289926298203007, 1.4849977027023993, 0.7426663488149644, 0.20956054780512087, 34.408458894298924, 81.42844400098248, 59.765146470838985, 69.1422156364687, 72.03913704041513, 66.11534610871347, 52.42963960093837, 25.73509627772916, 34.360339257024954, 67.1598497513802, 57.31102143564532, 0.6569419681064544, 0.07714235734555029, 0.07745551876723766, 0.044547288843821135, 0.06583561970581932, 0.04431932022975338, 0.16489219791706533, 0.1303561575590603, 0.11777209087965951, 0.1594538623166661, 0.14412024478998878, 0.136912445267362, 0.2805518473107969, 0.5296369089234261, 8.029552130929886, 85.10570526123048, 63.35895146093061, 43.12890368123209, 27.644623748717773, 53.55709352800923, 71.2427076216667, 81.39398205664851, 57.98180557066395, 78.40892499493015, 63.147555320493645, 85.54392814636232, 22.22111740419942, 0.4186429341714229, 2.211244519679777, 10.005497586342598, 0.4431724872800612, 0.4526310684459825, 61.882528181998964, 68.90158607113746, 67.49791099179176, 58.536895475079945, 54.81911220858174, 50.94875266475063, 56.95104199071085, 58.18028926849366, 60.10160346185008, 61.29746744709631, 62.62566435721613, 56.32660458164831, 51.64573823252032, 42.22473459859049, 48.843330260246034, 47.67450709496775, 46.67345939144012, 45.201809637008175, 47.77974428669099, 43.97409208359257, 44.75814250207717, 46.79921057916457, 45.999917830190356, 46.1740553763605, 48.46903024181243, 46.25413840816867, 53.74746968669277, 54.134470339744325, 54.50651891769902, 54.1772908549155, 57.900789014754764, 49.41911066732099, 49.09273416765275, 48.141669227230935, 46.3681342524867, 46.883627830013154, 49.23892482634514, 41.37892646174277, 45.12451541039252, 43.90980051409814, 40.627392491986676, 43.89384038986699, 42.91557381230016, 43.42604675600606, 45.45440243136498, 42.82459051378312, 41.8672223244944, 42.56804397029262, 47.07369804382325, 50.90738342654321, 54.33108306700184, 55.02573090214884, 55.27147131581461, 53.861112517695275, 45.80215584847235, 42.61757566082863, 42.70782155375327, 39.60865097661173, 49.52132371164138, 56.50519009559386, 49.82615070958292, 49.972329601164795, 50.06080650514173, 54.558458943520826, 48.27844619750977, 51.30123646028581, 51.52814949712446, 42.54102276217553, 49.17235828215077, 44.394032801351244, 43.64506406168784, 43.930859719553304, 46.334876475795625, 45.185547490273755, 54.444015949003166, 47.62049213532479, 49.473302133621715, 46.608536320347945, 48.28159193838797, 42.96826693319505, 41.44472814375355, 41.63022879631289, 40.62435265510313, 41.42143318730016, 42.034138787177305, 42.52589418042091, 41.93803287321522, 38.32746759537728, 44.91823796303042, 45.723798659539995, 42.235772148255386, 44.13797655413228, 44.2731257407896, 48.336956193370206, 49.52226115811256, 49.634754734654585, 52.27837731761318, 54.11374845812398, 52.48547846271146, 50.36300943743799, 52.56831107601043, 51.36098984749087, 52.51573954859088, 53.01644579056771, 53.97897189663303, 52.17035132069742, 52.82618338061918, 47.74719645900112, 54.76312037437193, 56.720834162927446, 58.94734405702161, 59.15908928840392, 59.23816819344798, 60.9290196049598, 61.97262110248689, 56.493972116901034, 57.68279152531778, 49.72721676672659, 53.060541076044885, 53.839308061907374, 51.89286324285692, 55.34227009742491, 49.25903089584843, 55.751016370711795, 55.778810285752826, 72.93271572359147, 65.17783687960717, 80.64262067118, 45.6225230616908, 0.9022750068576106, 6.729953712032688, 4.288848984626032, 0.36594886332750326, 40.55532286244054, 88.63007253216159, 64.30156369363108, 75.64502685300766, 78.61109179835167, 72.68806180646344, 60.36434342784267, 35.2565537729571, 46.556066774552875, 79.3973622783538, 69.9301492014239, 1.990307458946782, 0.3356022513922184, 0.27963526907467073, 0.09044098487544446, 0.19987480624789195, 0.16087873989055235], [0.05708599545722527, 0.04532020261150695, 0.05084381145875781, 0.11368713386717344, 0.06289754228125657, 0.08422873959305786, 0.0634536876403276, 0.07332395296543837, 1.5681928900941726, 54.69659305387928, 51.00635267073109, 31.705002515546738, 25.210145865717244, 39.40738631832985, 60.170648943993356, 68.88265671268587, 43.22088718414307, 59.93751502806141, 57.69881048510152, 62.80053930897867, 30.567193531220962, 0.18274897198763587, 0.06095260591997255, 1.917952844692815, 0.21261771359751303, 0.08029205123743705, 29.075663243570638, 72.67837355213781, 59.35525486546179, 58.389280996015, 47.517718192069765, 45.76712908283357, 49.73129210933563, 54.44880908535373, 56.80924830898162, 58.50918000744235, 58.01937403217439, 58.86436631602626, 54.105966475702104, 44.211348410575624, 41.20578127522623, 41.41796973443801, 40.50111962902931, 41.58521959858556, 42.504109336483864, 42.76834372551211, 42.40613245194958, 41.297250947644635, 42.04560779756115, 44.23798130404565, 45.23640494192801, 47.398501673052394, 50.126937666246974, 49.54588951603059, 51.78399393635412, 51.99679820768295, 49.637520005626065, 44.323128115746286, 43.634889433460856, 45.991327839512984, 41.79000654528218, 43.40162607931322, 39.64352476981379, 39.637303890720496, 40.24243539379489, 40.29879200843073, 39.158068703066924, 40.88934013920446, 38.3480090479697, 40.79964337810394, 37.448868443889005, 38.76446277864518, 37.47875690460205, 38.32696553199522, 40.125882164124526, 46.106088546014604, 48.09853884481615, 52.01073438890519, 44.83479738235474, 42.6508608941109, 47.908209754574685, 40.59964564538772, 41.996236924202215, 38.708141465340894, 43.30814815336659, 49.25748155963037, 47.240645885467536, 51.08700836858442, 44.1993224236273, 53.20653953859883, 48.42009867391279, 46.47420690905663, 49.26211387880387, 43.312046989317864, 41.3726742036881, 41.80422513715683, 40.777913447349306, 42.73798850274856, 40.176519963049124, 47.07700852424868, 43.635568003500666, 39.46534325999599, 45.858755650058875, 47.19742136616861, 42.75939679914906, 38.88165143228347, 40.66150142300514, 37.323980177602465, 39.9403932786757, 40.23006423827141, 37.45715641206311, 40.92614766090147, 37.93801153859785, 37.204606763778195, 37.376128089043405, 38.04834388917492, 41.43530268822947, 40.2968975036375, 40.90729282748315, 42.201918171298125, 45.190928982150176, 44.56513835537819, 48.277606810292895, 48.478283113048924, 49.66199559550132, 48.919616437727406, 49.38651969355922, 46.31133048765121, 44.74031925201417, 42.469004123441636, 43.27660837481099, 42.168079883821555, 42.83006614254367, 42.62721684671218, 44.75202752697853, 52.90702342987061, 54.93224905383203, 52.23913400403915, 56.00900634642571, 56.66102978491015, 54.56315794298726, 52.6986788934277, 50.0213082375065, 51.92088465536795, 46.37910119948849, 49.16600404247161, 47.34659694856214, 47.412210356804636, 44.04753454269902, 50.72687595121322, 46.036748886108406, 62.317083651019686, 58.181171801782426, 69.04651764900454, 24.640637328547818, 1.1055702884351055, 0.5493165432445465, 0.6364422519841503, 0.14346692500816238, 37.24002576643421, 69.82424520677137, 59.32193040847779, 64.71706428835469, 63.03402231585596, 60.63324151500579, 49.84300121184319, 32.83278003815682, 35.998317118613954, 65.65211811373311, 30.449179218661403, 0.1778196711694041, 0.05022207365160988, 0.024018237299676386, 0.09370854905536098, 0.04839296978447707, 0.10254249277134096, 0.03403093560688919, 0.05558737042930819, 0.044944103236400315, 0.07083005331937345, 0.11864406747683404, 0.0755496452292127, 0.0794819055966312, 0.14426826829871825, 2.148480223071191, 68.00250822497954, 56.517427890531486, 35.966922467754735, 25.878880562320834, 44.711481986507295, 65.97545869888799, 76.17256995170348, 49.28652278838619, 67.04544205819407, 63.473472902851725, 71.5605608109505, 35.09277520641204, 0.29512789581091176, 0.3423019660817039, 3.8588091442661905, 0.8267328539682973, 0.35372127268102865, 31.531041476034353, 76.36583297483384, 60.395177179767245, 61.182840101180545, 48.538538563636045, 48.64692934097783, 51.62809933385542, 55.90815044218495, 59.10170109041276, 61.591217671671224, 60.406018610923525, 60.56341548119823, 55.281998957357104, 46.733114719390876, 42.3505485442377, 44.76871328969156, 43.06882081493255, 42.31151703865298, 43.55684211177211, 43.69476441414126, 44.83471893495129, 42.78431561685378, 44.74468485001595, 45.32998092712895, 48.198896608045025, 49.239470035799094, 51.8556321051813, 50.946069763552764, 52.64214577213411, 51.96884347546486, 51.76861432290847, 46.50945332742507, 47.075792589495265, 47.51657285997945, 42.69722723191784, 43.77611044914492, 41.29505834271831, 41.65444550975677, 41.23862328067903, 41.61172697621007, 40.38320141453897, 42.485458466314505, 39.586120882341945, 41.72887248377646, 39.418788648420765, 40.65167980809366, 39.583873364233206, 40.74736602844731, 42.75403099675333, 49.030042925188624, 50.75827452444261, 54.661150517002234, 46.66596374204082, 46.17087041178058, 48.393367721188454, 40.68436884110974, 40.58252449958555, 39.73889720055365, 42.81503954241353, 49.0341692586099, 47.987382796502885, 52.77316078062981, 47.58954071229505, 54.39759077564363, 48.939479320280014, 48.38035721932688, 48.55790330517677, 42.02448583418324, 41.69065290881742, 42.53300151517315, 41.43875829635128, 42.33853432439989, 41.764522906272646, 47.97929879157774, 45.92682838439942, 41.33004588465537, 47.55981306875906, 48.11096491352205, 44.198490881150775, 40.17931269061181, 40.715747802488266, 40.15148347423923, 40.45890315886467, 41.98817253112793, 39.6797086346534, 42.78371941658759, 40.27759944238971, 39.729067740901826, 38.00240508971676, 40.272751392856726, 44.492264639946725, 41.42186464801912, 43.74864209082819, 44.47193499534361, 45.930746832201564, 46.63561244164744, 50.20678143347464, 50.202827684340946, 52.44789038935016, 50.702180708608324, 52.6097156155494, 47.76957750320435, 47.61476155250303, 44.89502145398048, 44.82457568568569, 45.18812840984714, 44.16426820139731, 44.29556169817525, 45.48526363988077, 56.18978054292741, 58.139704504320704, 56.21380506023284, 57.70217980107954, 58.42901068349039, 57.764796518510394, 56.75523727170883, 52.49555110931397, 54.77788025333036, 48.811555139480106, 52.282680157692205, 50.367865331711315, 49.589133647180375, 48.01891473031814, 52.714333072785415, 47.95889854431153, 65.89082179530975, 60.02831397518035, 72.02108629288213, 32.45544214402476, 0.866115840692674, 1.3566438997945478, 0.19319520902729806, 0.03905699716039723, 42.35669489829771, 75.99332547956898, 61.2416442748039, 67.715163230896, 69.53998319564327, 66.28103486953243, 58.50044488906861, 35.822747907330914, 39.613059720685406, 75.07002307522681, 40.72246290022328, 0.10333111134147453, 0.0674215289613893, 0.008263466767065467, 0.03038629145932294, 0.04413686106882749, 0.10705196208530858, 0.12437067430226073, 0.1908495090901852, 0.13065925258542263, 0.2107565183072321, 0.2335488291517381, 0.16261887796703847, 0.11420184536085976, 0.23871014735871748, 2.305046776610036, 78.90178649656235, 65.27281315095964, 47.00030657552904, 34.29604768753052, 54.13363487489762, 73.65204703423285, 81.5551051785869, 55.97082991753855, 73.88806389224145, 68.21800324224657, 76.40355048641082, 40.8725876961985, 0.3399608320286197, 1.18937736557376, 9.344707650523032, 1.183930419145092, 0.3805147075364667, 35.087652590967, 77.8805346642771, 64.26089655968451, 64.43062536178097, 51.47109862296812, 49.327684140974476, 56.10547704081382, 58.891281620148696, 61.247755327532374, 65.89396753618794, 62.491017233940866, 63.09103396631057, 58.9232724712741, 51.01521330495035, 45.73378893636888, 46.4966546335528, 46.212180814435406, 46.91502640324254, 46.4064871880316, 44.93810084558303, 47.154239992941584, 45.87331548813851, 45.61829866901521, 48.82852723521572, 50.44254725979221, 51.72995152011995, 55.99044176840014, 53.80585024433752, 54.427369409991854, 56.45439932423254, 53.82021788627871, 50.23564615557271, 49.056193367127456, 49.17544518747638, 47.769828534895375, 47.54399414985411, 43.30364919477894, 44.90205034132927, 42.22007482282577, 44.52466733994023, 43.6507514984377, 44.93699865956461, 40.47359635753017, 44.385705609475416, 41.29720780157274, 42.896542472224084, 41.768519801478234, 42.82461797037433, 46.11044237690587, 51.05328382984285, 53.812667323697, 57.22457631941765, 52.28398630695959, 52.936401982461255, 48.20226984639322, 41.08936140614171, 42.083129190629535, 38.70776884017452, 45.172909613578554, 50.87150158420686, 48.2449060101663, 53.834350186009566, 49.641744398301654, 57.02564939375847, 50.473494760451786, 48.483382194272934, 50.31237556088356, 43.516386785814845, 44.069276240564164, 41.85489823741298, 41.00505790402813, 42.64823682846562, 42.86176673827633, 48.814355711783136, 49.83296386657223, 45.75773892864105, 49.76393407390964, 51.99394272219751, 47.09028574728197, 43.292839142584036, 44.763323953074796, 41.587843664230846, 43.70235420042469, 44.61316385576802, 42.06136788091352, 45.532324237208215, 42.573064604113185, 40.23595563827023, 41.00128850629253, 44.05999983510664, 47.70716867139263, 44.0878604304406, 44.42575300893476, 46.24557979645268, 48.0998214598625, 49.49960554799726, 51.827618537410615, 53.05040567151962, 53.59259490043887, 52.89809611535842, 55.148767809714045, 50.861762339069, 48.20259540311752, 46.51410918081961, 47.33864238185268, 46.54705316789689, 47.80144283848424, 48.642438227130526, 49.57944931522493, 58.179340054911954, 60.176709005909586, 56.897329053571156, 61.22508402793639, 60.22285961335706, 59.89141541142618, 57.44096171471381, 55.30170886747299, 57.95621210528959, 51.897840730605594, 55.62317848205567, 53.14370316843833, 52.43782166511782, 52.37168265927223, 53.17872993407711, 51.236776228873964, 67.59133400455599, 66.1657799443891, 75.33373186665197, 45.27765258666008, 1.0349586774264614, 3.0403328182235843, 2.03254476670296, 0.22756505427100968, 48.726306346154985, 83.23355797798403, 69.38381010486235, 77.30342849608391, 76.24619283983785, 73.37159756691226, 67.96233530967467, 46.22379887488581, 51.11462969933787, 84.86657404130506, 52.73019513776226, 0.22810108599162873, 0.1605659921563441, 0.1118757649354877, 0.18174219455930496, 0.17474254112570517, 0.20782370390670918], [0.06704804577654408, 0.08612998596002018, 0.047538475313734625, 0.06084799661391205, 0.0641178360749637, 0.06396824591642906, 0.00919718909332709, 0.07173496403641279, 1.156423449996979, 48.120990491682484, 61.58430645542761, 38.4366467691237, 33.618846554909986, 43.66552706687681, 51.54453323733423, 64.4399723699016, 52.079438624843476, 58.16223067622031, 57.76866789787047, 57.110180393342056, 52.489079198529645, 0.7812341567008727, 0.03462162770090565, 3.341664739193455, 0.7197100032241114, 0.22503201519289326, 8.825593725327524, 74.8624590904482, 57.91999293911842, 61.22836312940044, 48.98776369710123, 44.07624629236037, 44.55374779239778, 53.569174428139966, 51.81555724913075, 55.10662586458268, 54.21044664998209, 59.95078832872453, 53.01685371706563, 53.1886496082429, 45.0380624494245, 43.351121640974476, 40.4024524073447, 41.66175288538779, 42.034299604354366, 45.857880961510446, 41.52927483281782, 43.52406286424206, 42.371019394167014, 47.58186463386782, 48.16823544040803, 50.77243428076468, 52.39143963783018, 52.964443006823146, 52.67363063750729, 49.59174986808531, 48.958675399903335, 43.79069774381576, 46.917568099114206, 44.1692574562565, 41.01387146980532, 44.011370289710264, 42.75965175321026, 47.372523815401145, 46.71319692365585, 45.763143954738496, 44.652607210220836, 43.18111827296596, 39.338434973070704, 40.029811551493985, 37.67871149124638, 40.26996258766421, 40.467116602005504, 41.77469753449963, 40.44298225833524, 44.23687911802723, 47.68483469563146, 54.759331364785474, 46.93926272853729, 51.571479920418035, 45.62046381735033, 42.18715044759935, 39.49947180286531, 38.9645036574333, 41.02828225781841, 45.001451046236106, 43.70660604969148, 55.759845625969675, 46.87502999459544, 55.1832179869375, 45.1558590704395, 43.31030937933153, 42.50140682343514, 43.367827015538374, 42.85782867862333, 41.51993174706736, 42.322848766080796, 41.397942112338164, 41.87022686004639, 48.34450675595192, 38.12370438729563, 47.620292094446, 48.89971040910291, 45.875531627285866, 42.56586705484698, 38.84781706717707, 39.22619635058988, 39.13802539148639, 37.29084791675691, 39.089235028912945, 36.832016898739724, 38.57720490424864, 40.31510122360722, 37.521710780359086, 36.71947233138546, 37.693612575531006, 39.68780048431889, 41.33640404670469, 40.02893686294556, 43.16025910838958, 44.132206747608805, 43.881916384543146, 46.442451400141564, 49.32102395642189, 49.787040756594756, 52.06591821485951, 51.963501207290165, 51.82562989573325, 44.839755258252545, 43.16018850572648, 41.505732767043575, 43.013280053292554, 40.490254663651996, 40.87582365159066, 41.82115016445037, 43.87888439239995, 50.06836883483395, 57.28048186148367, 52.64713110462312, 56.40667192397579, 55.250317973475305, 55.045899729574884, 49.873364279347086, 52.26924211748185, 48.00606112326346, 51.06308975527364, 46.289608401636926, 50.421084050209295, 45.45530849887479, 48.98491213398595, 46.21700140737718, 56.64628951780258, 55.27233815962269, 66.62268900102185, 20.219072987956388, 0.930579994474688, 0.5895053931782323, 0.24072374818065476, 0.5082075297832489, 48.4334582667197, 66.11153356490597, 61.056331896012836, 68.7548266687701, 69.9961156229819, 63.77092976723949, 39.71950108005155, 19.962510754985196, 36.945742099515854, 64.30359548138034, 22.807321510007306, 0.1344898760679268, 0.0618938330350624, 0.02159522759968475, 0.051325259414771875, 0.05459699494343612, 0.04703823522093797, 0.06831761434554093, 0.09701440997061231, 0.0585594813099071, 0.032184682861571355, 0.11023980715582449, 0.03177329939189217, 0.035125690572444475, 0.06255407059084504, 1.2507652779740672, 58.71848552457748, 66.55041540822675, 43.808077766049294, 22.76555807359757, 42.026454864009736, 60.99089107205791, 71.12165543340868, 53.96448266121649, 64.9045104365195, 65.15417714272776, 61.04328217044954, 57.39609764468286, 0.7458478813209842, 0.10675810607931308, 1.855721377557324, 2.1718641682978603, 0.19141215470529374, 9.798174827329575, 75.5923729558145, 61.01150704968361, 66.06273143522202, 49.637500393775206, 46.63935046042166, 48.368531273257354, 56.38327498589793, 54.42036797923427, 55.72603087271414, 57.31814053750808, 61.53189182281495, 54.77709970166607, 56.63686798464868, 47.05053644795572, 44.82250075186453, 42.29676892680507, 43.93412705390684, 43.90016717295493, 47.53017563973704, 41.28611533872543, 43.984109817012666, 44.30767005489719, 49.681411327854285, 49.9366948681493, 51.57369213719522, 52.299813070604884, 53.46272914640365, 53.960556368674006, 51.73741971292804, 50.06477594375611, 45.86957354699412, 49.12642340506277, 44.394374047556234, 42.424257724515854, 46.72081024416032, 44.657549396637954, 49.03225906433598, 48.07772282631167, 47.34967208677723, 46.681343355486476, 45.68076633637952, 40.672425223935036, 42.53644927855461, 38.974117386725645, 42.01812767213391, 41.45394963602866, 44.20616303720782, 40.76615810394287, 47.78101513462682, 50.4744125950721, 57.801451067770685, 50.25172395090903, 50.581305027008064, 48.15880606251378, 43.01337811254686, 37.71591124996063, 39.70893421480733, 41.18624394939792, 45.96475770396572, 44.02320015814997, 54.36624319322648, 48.7242078781128, 56.932685298304406, 44.91227988273867, 45.227728659106845, 42.77269755640338, 44.159981050798976, 41.85508651118125, 42.372976656883, 41.727993872857866, 42.42884297524729, 41.30520159198392, 50.51733116949759, 40.34873162546466, 50.69297098344373, 50.696548185040875, 48.63943369157853, 45.23696976323282, 41.8644727430036, 41.525019061180856, 39.31195897440757, 39.03529851667343, 41.01628764983147, 39.57469894040016, 40.26593823586741, 40.51649139773461, 40.00849739197762, 39.071031308943226, 41.217591531815074, 39.70942451107887, 42.60876209505143, 42.09911677145189, 44.82568963881462, 45.774624732232866, 46.40734226472917, 47.66376372306578, 53.17491346789945, 52.14887634400399, 53.829623729951926, 53.61521913159279, 53.40208538116948, 47.45948668449156, 44.77687574202015, 43.593461359700854, 45.07876096233245, 44.14717451218636, 42.38531251107493, 44.08001569009597, 46.2129613660997, 51.847544177885986, 59.596064859820956, 57.68919675580917, 58.35420716193415, 57.594287164749645, 57.13096111051498, 51.74383671052995, 54.88778506555865, 49.330249371067175, 52.82110391124603, 48.11411065440024, 52.71109711739325, 49.00191168631277, 51.76582159534578, 49.55514238726709, 59.537805895651545, 59.61755552599507, 72.0017490079326, 28.233995168439805, 0.6923093670798887, 0.638200393126857, 0.4107164062799946, 0.8775901830484791, 54.77671530938918, 72.72005265758884, 68.08188915252686, 76.47037982940674, 75.32117243736022, 67.95691459409653, 48.69777502552156, 24.246003743140932, 41.00393610615885, 73.43324938128072, 29.99248197001796, 0.15396183927453336, 0.07610497470464438, 0.025378993314300335, 0.04797313444977326, 0.043735254796281944, 0.03583935510006643, 0.2029008535487998, 0.18943817595080023, 0.17783934430729958, 0.14931108802556992, 0.29911449479479946, 0.1290392217737052, 0.1488552044235891, 0.20820500118838203, 1.5583914999038944, 68.2970860696608, 79.02136387363558, 53.69410976286858, 47.55878540777391, 61.93478984217491, 65.10654387935516, 75.70485868761617, 62.17033601576283, 73.74486600199054, 70.05968155399447, 65.95965154709356, 63.82371702501851, 1.5873260892206624, 0.648768606685823, 10.06642964578444, 3.2117793733073823, 0.3848976804123771, 11.526740808640758, 80.38868642622425, 62.44502352130029, 68.74110621790733, 53.26703425376646, 47.023130847561745, 49.855913654450454, 58.53180423859627, 56.118887624432965, 58.997558239967596, 59.103399476697376, 64.7854821912704, 58.3524146387654, 60.043838716322384, 49.456169220709036, 48.41317961292882, 45.148877251532774, 47.222198978547134, 45.84071666963639, 51.024246523457194, 43.819221219708844, 48.40904935713738, 47.100181887226725, 53.08944109947451, 51.80408431637672, 55.13413736897131, 54.985797251424486, 55.00898630388322, 58.22307840470345, 54.08612712737053, 52.255866835194254, 49.01635385328724, 51.44170438089679, 48.66111263152092, 43.965423645511756, 48.24638474372126, 47.05879695953862, 53.43888113575598, 51.5303538691613, 48.7755673931491, 50.74588375706827, 47.69010243877288, 42.6077462011768, 43.332043232456336, 41.22118834526309, 43.82375547962804, 45.52439320471979, 46.90414574838454, 44.77296513895835, 50.9286230610263, 50.71051182285432, 58.71096634095716, 54.11507814161239, 55.96081610648863, 50.69260228064753, 42.93193401828889, 40.322192868878766, 38.95667852893953, 40.6425916764044, 45.90241163007675, 44.82489339766964, 56.53723193753151, 52.36202578390799, 56.317740025058875, 46.319061479260846, 44.45147983489498, 43.388172349622174, 44.96442779417961, 42.859723183416556, 42.456703570581254, 43.317228440315496, 41.890230947925204, 42.099995382370494, 52.421045687890825, 46.55592949159684, 50.92036647181357, 53.40266589195498, 51.045705810669936, 47.634369480994444, 42.41891153397099, 44.290274343182965, 43.169241336084184, 42.183914492207194, 42.75913400034751, 41.07975159921954, 43.022583915341286, 43.0936219615321, 42.16721696238364, 40.30801350070585, 42.91093757075649, 42.9531854198825, 45.78599568336241, 46.27480145423643, 48.13341656038838, 48.006316077324655, 48.52521427216069, 50.15524148941041, 53.31720529064056, 54.34235595887708, 56.48211086949995, 58.32408728138093, 56.075918059195246, 51.96373262713033, 46.86680870671427, 48.161241854390795, 47.28701614564466, 45.46046641565139, 43.7557258913594, 45.502871159584295, 47.96511157866448, 53.309097751494384, 62.11187308834445, 59.87529839238813, 61.55926212187737, 59.681729424384336, 59.203027679074204, 54.80075943854548, 57.35910577158774, 52.954621391911665, 57.03495717817738, 52.78777553189186, 55.659385881116314, 50.66285894763086, 54.02892328077748, 51.92746247014692, 60.58954238891602, 64.53359542354461, 77.64095629415205, 36.95330050683791, 1.1572831845091236, 3.336768640625862, 1.2257227830348478, 1.4831201131305387, 61.13870166963147, 80.58958238170993, 71.52499275822794, 81.91602599236273, 81.5400432771252, 77.88584555349043, 56.98557061533774, 33.777106346622595, 51.101140668315274, 82.99185368322557, 42.176622806056855, 0.23901206260967642, 0.15339669621279164, 0.11390557617790277, 0.14509907533084193, 0.21952355190390543, 0.0995507738703201], [0.04990570998239902, 0.038512389085465865, 0.06344699586230902, 0.0233130514501564, 0.06952395001726766, 0.05431325512848074, 0.01641546774114813, 0.0774059145741405, 0.3253373167207164, 43.26940690317462, 58.678347910604174, 46.26763920630179, 50.831097249061834, 26.88695323082709, 44.30611679630895, 58.64024992912047, 63.94031340076078, 54.364489893759455, 65.27938704336843, 54.47547728015531, 60.0453802078001, 4.247396886348724, 0.38571929438940944, 0.9400220587849618, 1.4543745330264493, 0.17659932374954226, 1.5673512965440752, 61.9801010624055, 62.69438820500528, 58.571871249906486, 47.406111071186686, 45.19310589759581, 44.6946785526891, 49.03406727698542, 52.569840800377634, 50.77731370925904, 52.568236550977154, 56.9208985759366, 57.31881910754789, 53.15516433408184, 49.92495521422356, 43.88886682448849, 39.737018385241115, 42.27910649391913, 40.73194719129994, 40.35928672359836, 40.45336477218136, 43.381680826986994, 46.08701405986663, 49.90148767348259, 52.371984681775494, 52.254992146645826, 50.94698759817308, 53.23010513859411, 53.66083629669682, 48.62414429264684, 46.316280518808675, 43.231638400785386, 46.441007967918154, 44.83000424600417, 42.03395835814938, 43.02909504982733, 43.75887555460776, 48.17262849500103, 42.75383095587454, 43.86427356350807, 40.231735167964814, 39.06989774396343, 37.82090917710335, 40.56319898174655, 42.273250395251864, 40.63691600676506, 40.38488411134289, 43.020285406420314, 40.60151269358974, 45.84515679267145, 48.62455221914476, 56.519412609838675, 55.11034034913587, 59.19119388826432, 53.59118284717683, 41.4585348867601, 41.71745054183468, 37.71244779709847, 40.20038366317749, 40.79504243789181, 41.832434823436124, 50.44860339933827, 53.016916474988385, 50.95424398299187, 42.526533526758996, 41.16846776777699, 43.02243094290457, 39.440059661865234, 43.14271826897898, 40.491301936488, 41.67630880109726, 39.71772032399332, 45.5633697971221, 42.571476044193396, 50.673190470664736, 52.60199246868011, 50.150448353059836, 47.25373091236238, 41.04248908258254, 39.37462276028049, 40.25064099219538, 39.81768585020497, 38.590117346855905, 38.568669826753684, 36.806286150409335, 38.53883627922305, 39.65822581321963, 43.31005442527033, 36.72834865508541, 38.8207644800986, 40.273025958768784, 39.08934877764794, 39.607552712963475, 41.46543041352303, 43.44507025134179, 43.89988083993235, 44.431597340491514, 52.65965131021316, 51.944999387187345, 52.48758477549399, 52.44135964301325, 53.45583361964072, 51.463104832556944, 45.664323760617165, 41.26309887055428, 41.60113265437465, 44.53140989426644, 42.24733529552337, 41.62208203346499, 40.90151125384916, 42.46385797377556, 47.97923995602516, 51.23642321555845, 52.04206628184165, 51.339820815670876, 49.89127382155388, 52.168637244932114, 50.80186382416756, 46.96060042227469, 47.123927916249926, 46.524319110378144, 46.81275452336958, 46.4622397576609, 52.67661163883825, 53.504086617500555, 57.13860580998083, 54.96334560455815, 65.12417493327972, 26.53896643269447, 0.4000043214088486, 0.9627320304993661, 0.3487992496980775, 2.8207470140149518, 60.68357336905695, 61.00799260600921, 63.572026375801336, 64.35040896938693, 69.62892686167072, 56.1745499795483, 41.24990793966478, 38.00051842966388, 37.71449527432842, 57.81768183554373, 13.139267390774144, 0.29199879436242965, 0.110163405207136, 0.06485395463964631, 0.009178114461622412, 0.05839886331570245, 0.03295624065363119, 0.04777250368328345, 0.043565838282266935, 0.06259437447654144, 0.027124089894876368, 0.04510940585826193, 0.04449479266880982, 0.044007848031939044, 0.07361319712212971, 0.26917850598692894, 51.403947645618075, 67.36659788316297, 52.261016907230506, 39.814218474972634, 43.416229063464755, 54.27179251947711, 64.92199636274769, 68.22904079191147, 60.79426265531971, 69.60795002598917, 57.927888670275294, 65.35557516159551, 5.148090749017654, 0.4146636283445743, 1.638095164971967, 4.476108329911386, 0.14147220059267937, 1.9076522103240414, 64.50991215244417, 64.43516746644052, 61.74315068029589, 49.31997276121571, 46.666567787047356, 46.83831268741239, 50.98829015608757, 55.11549826591246, 52.83814660964474, 54.59781208345967, 59.44678729580295, 58.33013557618665, 54.830769492733864, 52.45626464966805, 45.64031885516259, 43.208857274824574, 43.07058195913992, 42.34434335462509, 42.72629591726488, 42.654936236719934, 44.81841756451515, 46.597110456035985, 51.15156665925057, 53.642342321334354, 54.58781396189044, 53.130516159919004, 53.70694768044257, 54.08498964002056, 50.35079125435122, 47.82456913302022, 44.44622385886408, 50.120304938285585, 47.3343316970333, 41.67158234503962, 45.35719825375465, 45.49368104627056, 48.6079841275369, 44.54214934379824, 45.661252544772246, 42.1201132189843, 41.3583497078188, 40.34519364756923, 41.03445214609946, 42.83078001391503, 41.77046921945388, 42.03218936920166, 43.771132961396255, 44.38591349509455, 47.74534117790961, 51.16195309546686, 58.87653743067096, 56.46483675126107, 60.68231428823164, 53.26712054591025, 42.209335373293975, 41.62269392321187, 37.92782906563052, 39.63548391096054, 43.30456310702909, 42.25265010710686, 53.038501278046645, 52.928168927469564, 53.84029257682062, 41.558414120827955, 41.64381196421962, 42.58745578027541, 39.67527635635869, 40.97533418286232, 40.79259880127446, 41.627157580467966, 39.58223773587135, 47.610105699108495, 45.36568626280754, 52.60766421594928, 54.925502577135646, 52.56338850144417, 49.327182077592425, 43.53634380525158, 42.47268722903344, 42.55832825937579, 41.52670960272513, 40.81354033562445, 40.287981956235825, 39.51159192669777, 40.288229065556685, 40.945053485132036, 44.12156927970148, 37.2062502368804, 40.24909950071766, 43.42893362045289, 41.987482193977606, 42.17430860765519, 42.459323713856364, 45.23564792448475, 45.10310319162185, 45.651058304694395, 54.459936849532596, 54.061231843886844, 55.69777411799277, 53.84897670438213, 56.29437446594239, 53.66464099576397, 48.499228569769095, 42.85608322389665, 43.266367066291075, 45.08919054462064, 45.153795903728856, 43.264280365359404, 44.32137089390909, 44.555163768029985, 50.324617278191354, 52.37493430414508, 56.0878969777015, 54.051853456804835, 51.469894455325225, 53.61594869244484, 53.624836783255304, 50.92960757593955, 51.468631452129735, 51.04508999855288, 50.479558744738185, 48.81968229047714, 56.05778494188863, 56.19589159565588, 60.484477781480365, 60.46940411290815, 71.04122331065517, 29.596008793000255, 0.2792284763868778, 0.823432608477531, 0.5017336271703243, 3.1475378140326473, 67.53653849324873, 68.00807799062422, 68.73128460299584, 72.25040374263641, 74.73606463401549, 63.09769415086316, 47.703736597491854, 29.521750480897968, 40.968607318016794, 68.05360101884412, 19.22681139361474, 0.15288703323852632, 0.0780913947270282, 0.0448633116039057, 0.0723935851466752, 0.08053196699268396, 0.05461711241232772, 0.08709037676453592, 0.18562327259250228, 0.20924781539267112, 0.2589130503756385, 0.12511187202988133, 0.17198039579295343, 0.10309299589284968, 0.21363740726824731, 0.5179602580685769, 61.25871050742365, 77.72353787575999, 61.75159162090671, 63.15693370757565, 41.97020023099838, 58.999480201352036, 69.43105113121771, 78.53094208625056, 66.61593467958512, 76.23320194982713, 64.02215365440615, 73.51852170882687, 7.09221842788881, 0.9857394281894931, 5.614863586041236, 6.406118908236104, 0.1822829147380206, 2.433683357892498, 67.03528311944777, 66.71917930726083, 63.59870633771343, 52.46112446631155, 50.52209684925695, 48.86283228474279, 54.57476423632715, 57.05206655686902, 56.06518253203362, 56.733938801673155, 61.744394071640514, 61.12564017695766, 56.570438723410334, 56.02763368237404, 47.74559220960064, 46.428809396682254, 45.66557891907231, 44.58553468027423, 45.2107330291502, 43.47926155213387, 46.50464450159381, 51.46394421977382, 54.155792344001036, 56.018706367861846, 56.059895177041334, 55.13541606164748, 57.97012867466096, 58.68603183377174, 52.91040451295915, 50.68842887878419, 46.682704417936264, 51.31516087439753, 49.90257417002032, 44.84893752682594, 47.783286186956595, 46.68176304909491, 52.25259950084072, 46.37955619442848, 47.79396287856564, 42.897840776751124, 43.91167932941068, 41.45032536598944, 43.200745813308224, 44.1208436412196, 43.68869258511452, 44.214074457845385, 48.05909156799317, 47.130952881228545, 49.87649040837442, 53.39837874135664, 62.142675461307654, 61.08198027456961, 60.97332277605611, 55.85575542142315, 42.6969644331163, 42.644196787188136, 38.01329751168528, 39.101464979110226, 43.16632309267598, 42.55276633847145, 54.68980735348117, 57.63668798631238, 56.427044714650805, 41.805456761390936, 40.341785107889486, 42.27579209112352, 40.08243406972578, 43.08391801772579, 41.393199966799834, 43.15177894407704, 40.203419577690866, 48.650035858154304, 51.03326405248335, 53.34526984922348, 55.934759801433934, 56.0943296647841, 50.96320659883561, 44.92248196755686, 44.358484360479544, 44.312596551833614, 43.706668807614236, 42.08187403217439, 40.70986032485962, 41.5399750586479, 41.500166923769065, 44.08843701885593, 47.3305348427065, 39.174719164448405, 42.920484619755904, 46.62218224617743, 45.122989608395486, 43.39641717172439, 46.030084779185636, 46.63403957120834, 47.414634381571126, 49.65016180469144, 58.81071221443915, 57.415042692615145, 57.560091941587395, 56.26052048898513, 59.59961852719707, 55.5757374148215, 50.86947371882778, 45.79098886059177, 46.168415008052705, 49.36159695348432, 47.13105094048285, 46.092732875577866, 45.433574645749985, 48.23282511003556, 51.82839516670474, 55.103217324902936, 57.40906892284271, 55.76877294048187, 53.46679272190217, 56.9241580655498, 54.321865497096894, 54.14387226104737, 53.74361791918355, 54.27878610549435, 53.24206836761967, 51.99008703231812, 56.745796126704064, 60.09773992723035, 64.02239291898667, 64.82941273720034, 73.78346996922647, 36.75369108876875, 0.41286007350971626, 2.6169762063410977, 0.9101603805057464, 4.282567799091339, 72.17540802494173, 74.31192305780228, 74.26761596433579, 79.63020201652282, 80.11421465104627, 71.64244421066778, 58.03126665853686, 54.94136071974232, 51.89421646056637, 79.12275714258995, 28.495432907535186, 0.3981669667747713, 0.3183929748352497, 0.2745774033809862, 0.10819149489003806, 0.18920539247412838, 0.13172512603623251], [0.0038731377712646203, 0.008206602933275844, 0.007030460701864814, 0.04310450779514448, 0.003989595105879069, 0.06183583634875475, 0.13075432409682583, 0.044597345028793624, 0.08608100229814168, 32.00167490590003, 60.206060101909024, 46.24832153320313, 25.863179314521055, 15.363178714629143, 41.54948288394559, 55.603099869143584, 65.54303307687083, 56.170353043463926, 62.41828864620578, 52.57259038186843, 63.99235540820707, 11.263368360457882, 0.39784796776310094, 0.920098931077988, 2.8683675296844977, 0.2855726037054293, 0.12600948192900227, 43.08335319642098, 65.87298285576605, 57.77731672410042, 51.2849586240707, 43.27548265457154, 48.228224169823434, 48.0154905011577, 54.47289243821175, 52.028251694094756, 53.34587389423002, 57.31133130288894, 54.769545216714185, 53.89911636229485, 51.358699183310236, 47.681437923062234, 41.113923288160755, 41.581983643193404, 40.17039714321014, 40.00033101727886, 41.575025358507716, 44.09006480247744, 48.613346007562455, 51.149562328092514, 51.61489271348523, 52.1667270506582, 51.45457367743216, 53.37953175267866, 48.1300001759683, 43.326873548569225, 40.706565533914876, 43.93088717614451, 46.74550548676522, 45.72612854742235, 43.32092723538799, 43.065016115865404, 45.878473404915106, 42.48094381824617, 40.08658393736809, 37.75154206060594, 40.273378972084295, 38.622225869086485, 40.89706720844392, 42.68887258345082, 41.83780454820202, 41.01412250149635, 39.65453878525765, 40.604536840992594, 43.18184783381801, 47.42528753895914, 48.646666542176284, 54.85366828979985, 51.43129048808929, 51.11120547017744, 50.027886052285474, 43.945368566820704, 38.59954280237998, 41.01487951893961, 39.89448585817891, 41.278223529938735, 41.78391902677475, 49.3087665496334, 55.75091831145748, 48.4078844131962, 42.151590239617136, 41.9598687079645, 40.86065976850448, 41.1014344615321, 41.00890967153734, 40.113828720585, 40.31462661681637, 43.03674759403352, 46.90857018193891, 57.041793869387725, 54.767831140948886, 52.98020309017551, 52.548565864562995, 46.80507060020201, 41.45001157637566, 39.374485477324455, 41.3108301931812, 40.24718538407357, 40.99588740256525, 39.377136999560946, 39.74724008191017, 39.60938445983395, 39.37972968624484, 43.954570447244954, 47.35173917585804, 39.26390209505635, 38.36285521907192, 40.075793497024044, 40.05681314776021, 42.838012864512784, 43.80163331185618, 44.81986884147891, 43.70778276074318, 49.71788152571648, 53.912048416752974, 51.81334503235356, 51.64707968311926, 52.63882744696833, 50.4634181914791, 50.57071854991298, 45.77649178043489, 44.17008115399269, 44.598929574412686, 43.381178763604936, 42.650311762286776, 40.01538507400021, 40.40955581972676, 43.18497788521552, 42.80540620127032, 48.718583199285696, 48.13003939967002, 50.51689970877863, 46.94164752960206, 46.72462278796781, 47.3744850004873, 48.1243323510693, 45.670097489510816, 46.879595633476015, 48.70643954123221, 55.13460020865164, 54.81873958341537, 64.39357857550344, 56.67072980634628, 71.92358401513869, 18.34618045437721, 0.4664168512869266, 1.8419555742894451, 0.9595331537627405, 8.057065106207325, 63.27087856108143, 58.80894322549143, 62.12098083188457, 67.3039968552128, 66.34213755207678, 57.76363157456922, 35.141000747680664, 25.55592829181302, 40.877055275824766, 57.60305366208477, 6.215880032508604, 0.24470928996320696, 0.0937402650954262, 0.05085582371741053, 0.07090873054919705, 0.03723379983116062, 0.06987098018608748, 0.05882424512697805, 0.05888516060827721, 0.04239349776218015, 0.07860891776339662, 0.042688027925549016, 0.027073775155229435, 0.07042589597404003, 0.028944590594619516, 0.06263013546084685, 40.160724578365205, 68.58450166640743, 55.97020626068116, 34.47898703236734, 25.88577020552851, 52.36905467125678, 58.75511653961674, 73.280928058009, 60.57162892433905, 69.42107262149935, 55.609944405094275, 70.55039359677222, 13.451326258720892, 0.36017026211465564, 0.8635243184624181, 5.426953617603549, 0.3661817234129675, 0.07005702463849899, 47.45327757250878, 67.98513212511617, 60.88547345130675, 52.344649684044626, 46.06197364868657, 49.20018749852335, 50.276583933061175, 55.29240108305409, 55.07529397164622, 54.95637947513212, 57.90054582780408, 56.40881746046005, 57.015211966729936, 52.97679847286594, 48.75158994428573, 43.08508296166697, 45.2779899104949, 42.6680330307253, 41.57571177328787, 44.54081966030983, 47.25322884898032, 51.0738488166563, 51.57952470164145, 52.55415916442872, 53.71563965274442, 52.05950906199794, 55.57212098952263, 51.37860521193474, 45.78590939121862, 43.441704857733946, 46.26333636622275, 48.463323193211714, 45.58051055477512, 43.474260530164166, 45.20022107708839, 44.77426344348539, 44.834173725497344, 41.413258967861054, 39.83013153076172, 41.458542731500444, 40.53065507642685, 43.19402679320305, 44.653893747637355, 41.181442968307, 45.05161423836985, 42.14287865546442, 42.37875823051699, 46.3869773187945, 48.93880859498055, 50.11380949328023, 57.08799939001761, 54.08514261245728, 53.5241573856723, 51.88879182261806, 43.898853178947206, 40.75900370074857, 41.1046233484822, 37.28526246163153, 40.08110830860753, 42.42414005341069, 49.10850209574546, 55.62872079110915, 48.81513234107725, 41.39198010967624, 40.525218671368016, 40.6966301702684, 40.959887889123735, 40.31690943625666, 39.82471081518358, 40.99276911827826, 42.329481494042184, 47.821133136749275, 56.93986715808992, 57.89550165976248, 55.83007958627517, 54.79238517822758, 48.8814478535806, 42.65431650223271, 42.07920289808705, 42.43792718456638, 41.0668077776509, 43.09476337125225, 40.8499320860832, 41.34257393498575, 41.060935989502944, 40.253410185537035, 45.3786849975586, 48.20325436130647, 41.26606026003438, 42.21594064466415, 41.916954055909194, 41.85670252769224, 43.94314850530317, 46.06532335281373, 46.85051125864829, 43.98460403565438, 49.959511295441665, 55.469123471167784, 54.66637903644193, 53.69145431826192, 55.94678186601209, 53.472280117773245, 53.75944860519902, 48.050972261736476, 46.248196017357614, 46.65104304590533, 45.89190360038511, 44.607935336328325, 44.336593612547844, 42.23354031962734, 44.68558257625949, 44.966404668746456, 49.51626385411909, 52.54747152328492, 53.774306543411754, 50.40463755207677, 50.557131459636075, 49.9889329941042, 50.683549450289824, 47.034913647559385, 50.89187437488187, 51.36033088930192, 58.05904096172702, 59.18472197748, 68.58982824510144, 60.85558106822353, 73.58469993837419, 21.02068581888753, 0.649395879478224, 1.102840931665513, 1.0751569655633744, 9.043641224984201, 72.15635315064462, 64.83511194106072, 68.86774386129072, 72.6754003955472, 72.53938044271162, 62.39759422117665, 49.72686375341108, 33.2315517240955, 47.75261325220908, 69.55792411681145, 9.692749361838064, 0.5312980939784359, 0.07539861099494082, 0.028638517401451548, 0.032616239341516653, 0.014766406027540086, 0.1049111830070615, 0.18387821623154227, 0.0710367055369481, 0.14810718085256316, 0.23239779736726518, 0.19136956021670373, 0.07579056455964044, 0.21481719799339774, 0.17182826605294982, 0.15717484267248263, 47.701806791367076, 80.33833888269241, 64.332519039031, 36.00835054151474, 23.477026993228545, 58.429053829562285, 66.40390703755041, 79.53592392706102, 67.24214107759538, 74.82462390776604, 61.938433724064986, 78.6442122920867, 18.933508319239465, 0.39767535283200206, 4.401273429393768, 9.93221398322813, 0.5015649652529148, 0.15096095030105885, 49.71652830800703, 70.1078639491912, 62.66484883523757, 56.097185150269546, 47.79918355326499, 53.93255456801384, 52.21467410364459, 60.6777290375002, 57.040440651678274, 54.76042570606355, 57.916090180796964, 60.59875211408062, 59.53655073719641, 56.17558940764397, 51.87860934965072, 46.51293246976791, 46.83915207462926, 45.30637218106178, 42.15768168049474, 47.30448246002198, 48.376854542763006, 53.69416075368082, 52.955296039581306, 54.5697553696171, 54.962019843439904, 54.04764475360994, 55.703881248351074, 54.20960334039504, 46.15194497569915, 45.163888162182225, 47.67189871880316, 50.98767434397052, 49.89954217787712, 46.17801697023454, 48.327652331321474, 48.65498588931177, 47.24385830663866, 42.17919588088989, 41.457809248278224, 44.932440865424375, 41.80048711838261, 46.026640938174346, 47.631070767679525, 45.35515469889487, 45.86015985858056, 44.3676430948319, 45.55134773254395, 49.20545916403494, 52.21658429791851, 53.020709406945016, 59.661780249687936, 56.436066166047134, 55.871750846985854, 50.504767817835656, 45.13918899720715, 39.789362415190666, 41.653170739450765, 36.74762710448235, 41.432211860533684, 42.0295770706669, 51.35206645534885, 57.83407342049384, 49.07791937551191, 41.792481560860914, 40.652942811289144, 42.056853232845185, 41.97927267320695, 41.18841302010321, 40.995738352498705, 41.42293153270599, 42.81972677476945, 50.819969484882975, 57.1044498105203, 58.14296007156373, 59.114362501329, 56.33411984289847, 53.75812676645095, 46.428526986029844, 44.47644964341195, 45.93264133699479, 45.20148015791371, 44.810800321640514, 42.50217560798892, 43.219981116633264, 43.302523474539484, 42.273662244119954, 46.83706929606777, 52.337518815071356, 42.8826415923334, 43.497814363048924, 45.15991872356784, 42.70717436267484, 47.091748791356245, 47.68027297912106, 49.99918606973464, 47.61724049045194, 53.260444671876975, 58.4755809845463, 56.55286650503836, 55.8691934616335, 57.83604245032034, 56.081962431630785, 57.33174723963584, 49.30061194204515, 48.30705204317647, 48.842259453188994, 48.751374213926255, 47.91019447388188, 46.11048552297777, 44.74954466665945, 48.21164823347523, 45.85719846910047, 54.438567776833814, 54.455218238215295, 55.94030995522776, 52.51331160145422, 51.85376505697928, 52.88021402974283, 53.07317110799974, 51.462014413649044, 53.72133101186445, 55.62916009656845, 60.67269663656912, 60.09615136731056, 73.0270016577936, 63.061271021443034, 79.26778285734116, 23.765203529788604, 0.6172458046386319, 5.514731359097266, 2.1313877596009165, 10.723102073515616, 76.17737093279439, 72.20749301295128, 72.05073156664449, 80.05807768914008, 76.84887286155455, 72.2472030885758, 49.625344968611195, 39.68003811374788, 58.07724075932657, 81.4169357668969, 17.13865722379377, 0.8126882559830143, 0.2449712920333109, 0.20278482187178828, 0.13109489614444395, 0.13906041791121806, 0.18043848145152294], [0.025954424936865127, 0.06273236606390246, 0.09129313511713859, 0.040143968672641826, 0.016473152246626637, 0.03275381724139856, 0.08869762922967635, 0.13627780270912956, 0.07877910419577554, 21.744435679528024, 64.44536955125871, 46.14796769234442, 43.1729087521953, 54.20497102122153, 36.58384853793729, 57.91828670809346, 65.22001412607008, 57.29113501887168, 61.48989108300979, 55.81875962595786, 60.46571708494618, 24.136701014734086, 0.39814030691500635, 0.741014295528012, 6.279244451753556, 0.5168222191352998, 0.02595585943650334, 24.097477313010927, 69.30995187451764, 52.85465194332985, 51.05985379988148, 47.297163317280436, 48.77109589115266, 46.39702643117597, 52.86347335384738, 52.55961910370858, 52.20422883187571, 58.48673620531636, 56.123586623899406, 55.654694726390225, 50.48110415858608, 49.09701347351075, 41.45425165853193, 41.32938300409625, 41.536574363708496, 39.393414835776056, 40.845680236816406, 42.56241144672517, 47.21538189918765, 50.41028576512491, 51.459429571705485, 53.357162475585945, 51.47426005332701, 50.90191956489317, 49.56798422721125, 44.84020633082236, 42.742609054811545, 44.161855943741344, 43.40279886799474, 43.49232696717785, 41.80542930479973, 42.78618658742597, 43.343669137647076, 43.50538061511132, 39.848515679759366, 40.633327038057395, 39.733437261273785, 39.71363713664394, 38.74178755667902, 40.68286265096357, 41.67731292786137, 41.014459825331166, 40.173527194607644, 42.66692692233671, 43.99485318891464, 45.24578332901002, 50.48190039973105, 52.91413076462285, 53.355793568395804, 53.12156923355595, 43.85622485991448, 42.61061737614293, 39.3492881713375, 39.6482982943135, 39.513435440678755, 38.97489401601976, 41.42928969475531, 46.725258211935724, 56.12313947369976, 46.90324360324491, 40.520978589211744, 39.369904148963194, 42.31885971561555, 41.203490611045595, 39.22106196803432, 39.687976990976644, 41.969725624207534, 40.67065623498733, 51.42124922044816, 50.25985110190607, 50.691464793297556, 54.35173042358891, 53.13108098122382, 47.667917513078265, 42.74064394735521, 38.23530758580854, 37.413618103150405, 36.93649315064953, 40.27955670510569, 38.90929237488778, 41.28315002687516, 40.591683233937914, 40.360235937180065, 41.651778298039595, 44.418900628243726, 44.873895568232385, 40.78631908662858, 42.337930279393355, 41.702110152090754, 40.71021333817513, 44.4630390597928, 46.63379246188749, 42.17770145785424, 47.04385272918209, 50.963077160619925, 55.215228449913766, 49.80249097270351, 53.43878699887184, 53.99567334882675, 51.903720363493896, 48.76412583935646, 48.282058700438476, 45.770223832899525, 43.802868858460464, 41.870725001058275, 43.55204897542154, 41.529086559049546, 41.124388171780495, 41.984807137520086, 40.61311898692962, 42.48139881318615, 43.95845751608572, 45.05530911107218, 47.0003693334518, 44.38551733570714, 47.849107480818226, 45.15450193035988, 47.342447080919825, 46.67755434590001, 55.70247703982938, 58.544955945784054, 61.53730469365274, 58.10198307037354, 70.53530031634916, 7.6591136859309294, 0.5904816343419014, 1.0176240688850804, 0.8078930971603241, 11.595948088553644, 65.83692842914213, 57.60169652200515, 64.0052011705214, 64.80478417488837, 63.73314165299939, 58.78891168102142, 32.78025165680916, 26.102865549825854, 35.36397964723649, 54.49685027522426, 7.893525804242781, 0.34150544914507097, 0.07734439005294154, 0.1305340738185952, 0.0566493253403854, 0.048709111288189895, 0.022093412661624533, 0.010318047547292326, 0.04307280707683775, 0.04565627006213031, 0.006154572268226935, 0.027665670007287015, 0.015351662727733775, 0.04848539063166227, 0.13501293025910854, 0.10992611713346936, 28.498996380836736, 76.0202407836914, 54.7942247698384, 40.34507989883423, 39.76273344409081, 48.77826598382766, 61.97186800741381, 73.35876357170844, 61.294835536710686, 68.8571220828641, 61.035633548613525, 66.94074615355461, 26.52107257996836, 0.41996501806762915, 0.2985096224133046, 5.246975171950556, 1.3009138837937386, 0.026963623203036767, 27.358259347177324, 72.17545509338379, 56.07770273762365, 53.92574141102453, 48.08534399155648, 52.4195904885569, 48.229079246521, 55.754621028900154, 55.98192630275604, 53.62611155356131, 58.88768480670068, 59.54514072787378, 56.99161891014346, 54.00272969276675, 51.004324805352, 42.67209268385365, 43.53248419300203, 43.773737415190666, 43.002383708953865, 43.44161072084981, 43.735156982175766, 47.13567149254584, 51.45522479088076, 53.72703806046517, 55.47558753721176, 52.271517092181796, 52.89893158020512, 49.86067148946947, 46.633674790782315, 44.57986293300506, 46.21943327688402, 45.885345397457, 43.58794650723858, 43.99709678465321, 44.48447873515468, 45.771541749277425, 44.645923491447206, 41.317537446175855, 41.87911495085686, 41.2254794182316, 42.81476497650147, 40.75595601912468, 42.02507811207926, 42.47017298975299, 41.440374312862275, 43.31413761261971, 44.21047764439737, 45.86343503767445, 48.31310818272252, 53.55488131123205, 56.3980427095967, 55.805823649129565, 54.36095976060437, 42.058806573191, 41.18983291810559, 39.3839580012906, 38.64958832340856, 40.08731742059031, 38.85342605652348, 39.504359076100016, 46.78372113935409, 57.17594677402128, 48.52271179999075, 40.134589825907064, 40.321408394844305, 41.583176043725786, 40.75604231126847, 39.04479457486061, 38.49264644807385, 41.27512093513243, 41.724514730515025, 50.1357041635821, 53.14760984912996, 55.32597264935894, 56.84380046782955, 54.62316628425352, 50.07246378929385, 43.8806337694968, 42.33938547872728, 40.483198319711995, 40.53617777362947, 42.87629911976476, 42.02153228944348, 43.868082184945386, 42.91722513014271, 43.94516852594192, 44.58658979785058, 46.35735950162334, 46.26263426196191, 42.02655684563422, 43.456845206599084, 42.24543686835997, 42.1679739798269, 46.95900009524438, 47.82300410732147, 45.354648713142645, 48.65308746214836, 51.936652583460656, 57.48111894053798, 53.229979622748594, 56.08777930659633, 55.17840131636589, 53.96682431620937, 50.216967828812145, 52.064321810199374, 47.771538688290505, 44.60829619438418, 44.50613021850587, 45.718789792829945, 43.10954678443171, 43.9773751074268, 43.23845548014487, 43.99567688665083, 44.25596537128572, 47.90992775271016, 47.42489922431208, 49.328162670135505, 46.96335392613565, 50.989553159283055, 46.20941162109376, 50.03997871952672, 51.43464019221645, 57.34254160235005, 60.20490692507837, 64.76712942123413, 61.741397380828865, 74.2382138775241, 8.36607825371527, 0.8557878723067622, 1.614658635470175, 0.8331967974382063, 12.795259837181339, 73.02318911398612, 63.63318397152809, 69.46467368833481, 72.20962678232502, 68.57955947999032, 65.96063213963663, 43.02301537606024, 26.459350162936797, 44.1287785960782, 65.20212027334398, 11.035739491062781, 0.5817634924765557, 0.15838520030581182, 0.06452083662753144, 0.07886823852576556, 0.06737796920201472, 0.05821777545216103, 0.15992921987368217, 0.11658240229852739, 0.2945156076983098, 0.12038787511447746, 0.10456894088776843, 0.18147294529743735, 0.11675915410441738, 0.17476783734896492, 0.26727876115229826, 34.35635020655971, 88.0179552878103, 61.484690020161295, 56.357230447953754, 64.09457629726779, 55.01173196300384, 69.0150837744436, 78.24968461067446, 69.40834060792001, 75.22940466480871, 66.27160549163818, 73.26825880235242, 31.202511595141505, 0.5517118243921189, 3.7841463377398834, 12.187267945658776, 2.437750610613054, 0.11836154957211788, 28.50002992537714, 75.47560399578464, 58.17783386476579, 58.05064708955827, 51.427909405000754, 55.102111216514345, 48.66200693192021, 58.176892495924434, 54.75009810539984, 56.24945156035885, 61.77348236883841, 61.586812849967714, 59.88411980290567, 53.54214929765271, 52.989385358748905, 45.032135748094134, 46.183210188342684, 44.16200891617806, 43.34011154790079, 44.60486019811323, 46.232726189398, 51.46841179940009, 54.737130749610166, 54.42488262730261, 56.65081985535161, 55.516187990865404, 52.61539128518874, 53.060435172050234, 49.387060980643, 46.896261784338186, 48.584783307967655, 47.86404386643441, 48.30620088884908, 46.69966474656136, 46.36887950281943, 47.474042600201024, 47.850339105052335, 43.796538153002345, 43.9753354749372, 43.661934175798976, 43.546161497792895, 42.724715202085434, 44.63928684111565, 45.234843838599424, 45.235287066428896, 46.84952282136487, 47.597801223877944, 48.90215012335008, 52.54147814166162, 54.83373088221396, 58.379788860198, 58.749142769844305, 57.858341124749955, 42.95042407128119, 42.21053954093687, 38.314315888189505, 39.0964953361019, 39.91847899652297, 38.24098325544788, 41.24098846989293, 46.89705410311299, 59.31838458584201, 50.32215795209331, 40.07086700008762, 39.43867898756458, 42.03051059476791, 40.539856956851104, 38.99352919670844, 38.8901904321486, 42.6077187445856, 40.67916777826125, 51.65554415795111, 51.05391925381076, 58.21295476728871, 58.08656815559634, 58.203066472084295, 53.04179214662122, 46.81373511591266, 44.6520306218055, 41.450497950277025, 42.19024912003548, 46.30505469537551, 43.520987726026966, 45.081000635700846, 44.09285360766996, 45.09094384408767, 46.38063484622587, 49.41109726505895, 49.4663046252343, 45.564417069958104, 45.83180896697506, 44.658565290512584, 44.22164070990778, 49.23506129172541, 52.622392715946326, 46.786176543081964, 52.23285428939327, 53.157882536611254, 59.673939597222116, 55.76636068282589, 59.82605695724488, 56.912896940785075, 56.281850337982185, 52.37391448790028, 53.92544723326161, 51.34967380954374, 46.06700212724748, 47.6098075989754, 47.7763435917516, 46.72587402405278, 46.206297259176935, 46.12325676025883, 47.86048627668812, 46.81386063175817, 51.06554515900151, 49.302204424335116, 51.41242388756045, 49.793355772572184, 54.47058216218026, 48.88004364505891, 52.75818517131191, 53.16708833940568, 61.70198540533743, 64.8111854830096, 67.24241564350744, 63.4140254605201, 76.33765466751592, 9.843556650223272, 0.7221495948972241, 4.953163660341694, 1.8721670176713698, 15.316237749591952, 78.37109765698834, 70.1399254029797, 74.475125035932, 78.56977355095648, 73.58505295168969, 73.79879074711954, 46.38881298803514, 37.35356661581224, 52.13669346224878, 76.62135970207953, 17.300225534746726, 0.8083013913804485, 0.2863788346369421, 0.192145454066415, 0.34682353958487516, 0.13673515719992502, 0.12906641789501713], [0.025859251918811953, 0.041368403171579686, 0.055397503198154514, 0.043683183800068595, 0.03448261721660534, 0.03958627964640337, 0.12249896828565868, 0.053180693723862214, 0.2381344476053792, 14.108845918409287, 56.603418011819166, 46.54354656896284, 50.883919808172415, 67.74873087483068, 41.30186365496728, 50.931286350373306, 64.98470721706268, 60.813121411108206, 58.7470599912828, 54.350636082310835, 61.22719034071892, 30.412093208682155, 0.021715744721492933, 0.37509025344925545, 3.780385029892768, 0.5199234656268551, 0.28257772086128113, 12.239005969416711, 65.37530468356225, 57.06264518922376, 51.20518153713596, 51.9224496810667, 48.47537663675124, 47.08860305047805, 53.660314621463904, 58.9282891827245, 53.633446385783536, 54.88180345104587, 55.081518773109686, 54.460187881223625, 55.12757524367302, 50.32344056713966, 42.39735026513377, 40.35161848991148, 39.85041802929294, 39.63512305290469, 39.764863291094386, 43.881614362039876, 45.86787908307968, 49.37370138783609, 48.34687978990617, 50.721215971054576, 51.487325468371, 50.87251747808149, 47.40782906932216, 46.329491061549035, 43.99925408824798, 43.43970444894607, 44.989813373934844, 44.69899315987864, 41.834568592809866, 42.82473956384967, 40.352791278593, 39.8249069336922, 40.33335985675935, 41.26593082181869, 39.87503874686457, 38.93603509472263, 38.241701049189416, 38.99370178099602, 39.808115266984515, 39.45713373922533, 40.145446946544034, 41.53278927649222, 44.676376773465066, 48.16792165079425, 50.68514585494996, 53.33275356600362, 51.76383295366841, 52.15646220791725, 43.617991862758515, 39.587854569958104, 40.99185912839828, 40.27453607128513, 40.65590027839907, 42.063838974122085, 41.2242321045168, 42.8165457325597, 55.08324461598551, 44.69494527386081, 42.1453615157835, 43.3573660542888, 38.14254745360344, 42.34007973824778, 42.132249032297445, 42.65486563405683, 40.72822486200641, 42.602592206770375, 44.58680552821006, 50.56912214525285, 52.70325629941879, 55.849146227682795, 52.429298354733376, 48.095228364390714, 46.167053945602916, 41.698223083249985, 38.8511275476025, 36.3227951911188, 36.490515739687034, 40.6078080977163, 38.61636192567887, 42.01062417799427, 40.678293089712824, 40.494730088018606, 40.7316255569458, 44.68888521194459, 42.25087719578897, 41.57797890324747, 41.260596398384344, 42.41598152345227, 42.33415695928758, 44.40038704103039, 41.54790609113632, 46.91817998886109, 50.825660844003, 52.84557950112128, 50.59231119771158, 50.52438359106741, 50.791245968111106, 53.09643860786192, 50.8388949209644, 49.14363476537889, 44.33483639071065, 44.64488406335154, 40.8559529242977, 40.42920297191989, 42.29349374771118, 42.95395420443627, 43.09478298310311, 41.40908948836788, 40.78496194654896, 42.038116070532034, 42.71202241220782, 43.31702839943671, 45.43436304215462, 45.004518339710856, 47.76454510227327, 48.58421848666284, 51.55312715038177, 50.858208671692886, 60.39222755739766, 62.93931668804538, 66.7603406598491, 55.79745723355202, 1.2290970019755827, 0.5870778137637723, 1.2302346118996221, 0.4408933144182928, 19.243775644610007, 71.83456190170781, 58.11145559433968, 66.32307483303931, 61.6874255672578, 68.99127498749765, 55.56937533040201, 42.48336784301266, 34.014276381461855, 42.35154482626146, 51.82008758667977, 3.056075986354582, 0.22955343547847964, 0.12922170391726878, 0.07833261283174639, 0.11370065531903699, 0.019431552068600734, 0.030506023341008735, 0.13699757295750803, 0.04035267783629318, 0.043299040501757015, 0.043170732265758904, 0.041982759721577174, 0.08916894184245218, 0.05910520021232867, 0.091830913518225, 0.20972400032464536, 19.245654459922545, 69.82036990504112, 50.984885538778, 53.78721898601901, 57.22239940397201, 47.34051727479505, 57.08666578415902, 70.85865266861455, 64.79817890351819, 65.02004777231525, 61.169974727015344, 67.47451013134372, 34.713011326328406, 0.074981315241706, 0.30993557865581206, 6.7779968630883, 3.1511338920362535, 0.2563038315143316, 15.497954295527553, 67.79197892835064, 58.97632252785468, 54.613242687717566, 53.88023014991514, 48.942099463555124, 49.11224403688985, 54.212168570487734, 60.58357646388393, 54.6217816875827, 57.77850912463281, 58.45453354620165, 57.40182038276427, 56.283117263547844, 52.978944009350194, 44.89475081043859, 42.26045562374977, 43.17204190838722, 42.89063930511475, 42.206766220831106, 43.91223238360497, 49.70323539549305, 51.10198397790232, 49.95713433911724, 53.84951799146591, 52.57262568319998, 52.39268302917481, 49.11054172823506, 47.965774459223596, 45.053567578715665, 44.18204830538842, 47.24381123819659, 45.2432063318068, 43.33633430542485, 45.329580845371375, 42.6814357696041, 44.09843121805499, 42.64063527507167, 42.49222847723192, 40.94113503732989, 41.258670514629735, 41.13557869388212, 40.82854340153356, 40.59633516496228, 41.497993930693596, 42.284911601774155, 44.38255594622704, 46.83806557809153, 48.93049709258541, 52.217572735201934, 55.16766971157443, 53.68234265235163, 55.98792360674951, 44.003290207155295, 39.81207293848838, 40.32464827260664, 39.74444343197731, 40.51144722969302, 41.83124634527391, 42.10120347238357, 43.46915360419981, 55.883215934999534, 46.20660712642055, 41.79054783236596, 43.033229227988954, 39.03756564663303, 42.10185850820234, 41.07187547991353, 42.748869157606556, 39.59401269112864, 41.34375064603744, 43.82429284434165, 48.65068304923273, 54.29138083611765, 57.23828892554007, 54.23700894078901, 50.00925871633714, 47.69012597299392, 44.80432448848602, 40.766291464528734, 39.80131387710571, 39.70026969909668, 41.662580505494155, 40.89514524705949, 44.33133763651694, 41.73582292372181, 42.48643121411724, 42.45413049574822, 45.52593077382734, 43.794223954600675, 42.17100989434027, 43.42613304814985, 44.302822005364206, 44.65914580129808, 48.556883488931966, 43.11037832690824, 48.541162629281324, 52.816224482751664, 54.838202384210405, 53.13918459799982, 53.14482104393744, 53.94137205616121, 55.01429327072636, 53.814350020500925, 52.00854570634904, 46.0163329493615, 46.88894656396682, 42.55684952582083, 42.10588678236931, 43.48136786491641, 44.26981133799399, 44.51266880958311, 43.6298962562315, 42.305162798973825, 45.225536054180516, 46.06141274975192, 45.514069526426255, 47.97775730010002, 48.02172314736151, 51.12608694261121, 51.065211757536865, 53.76723450999106, 56.185830716163885, 63.50513427488266, 66.62687024762555, 68.81744338620094, 55.84092493980162, 1.4746824820195477, 1.591306559501156, 0.8405164917630534, 0.3873145039523802, 22.20738518622614, 77.29796855680405, 62.957383125059074, 72.18527670829528, 68.96798395341443, 73.07927116270989, 62.11519141351024, 40.82058491245393, 31.942429465632287, 49.72209022891138, 61.54238416302589, 5.490235667074881, 0.523291249429026, 0.09398991016731148, 0.1658760386729433, 0.04852139676410345, 0.08275462554827814, 0.03095726828060804, 0.20150357046194617, 0.14369045414270895, 0.21284769319238203, 0.11879664154783373, 0.13552795584884383, 0.19889853444070588, 0.3287389003221066, 0.3320907801389695, 0.3599855736378701, 23.55538025979073, 83.3130330424155, 59.37114046465967, 67.51383581469136, 75.02921473595404, 55.68894878510506, 62.735745676102184, 75.48613163732713, 68.95962146020705, 71.99985842550956, 65.00643714781731, 75.10341813487392, 39.89558412182716, 0.1134402160682986, 1.6446256661607375, 11.908282503004997, 3.546298713453355, 0.2575132851639102, 17.133503229387347, 71.294067136703, 63.2327845019679, 56.92561326488372, 56.69408359835225, 52.5362103985202, 51.17994500744728, 58.08579937104256, 61.01763771426294, 58.67177794056555, 59.159512904382524, 59.03088269695159, 59.09795914926837, 58.76621292483423, 56.450665227828495, 47.292013245244185, 45.46010947996571, 43.41501312871134, 46.016568291571836, 43.338805398633404, 48.44464878882132, 51.937546883859945, 54.77544053908318, 52.22429567767728, 55.90216098293182, 54.98639345169068, 55.09833789640858, 52.20650772894583, 50.2584586604949, 48.54210792049285, 47.17027071983584, 49.406378653741655, 49.72233733823223, 45.305085643645256, 47.15902136218163, 44.44256820986348, 46.32928709830008, 45.66315097193564, 45.07721947085473, 43.039053947694846, 44.17123825319352, 41.48463041551652, 44.582494843390684, 42.746707931641616, 44.4809329125189, 44.90648654199416, 44.9132251739502, 50.99103581520819, 53.40006928290091, 54.18976791443364, 57.405883958262784, 57.01618863690285, 58.32869214396323, 43.15380680945612, 39.79229634807956, 42.37384350069108, 40.12841993762601, 40.94538688659668, 43.31934652020855, 42.87590688274753, 44.18202477116739, 59.5543896767401, 45.46206674268169, 43.76816372717581, 44.600110207834554, 38.82848762696789, 41.33901634523946, 42.4869607340905, 43.11361035993023, 41.456240300209295, 43.48877722217191, 45.29953156748126, 50.838275186477176, 56.93097122253911, 59.87032482700964, 57.25126412607009, 53.14065548681444, 50.40834811425979, 45.652446823735396, 44.32430090442781, 40.49695407190631, 42.2203690005887, 45.65457667073896, 42.898644862636445, 47.538934292331824, 43.37895870208741, 45.336962746035674, 44.65676884497366, 49.196559306113954, 46.06695898117558, 44.766050000344556, 46.183833845200084, 46.012379200227805, 46.34174454596735, 51.799075449666674, 44.17194820219471, 51.37076047159011, 55.51580752095869, 57.11473426511211, 54.71164318823046, 56.04210330593971, 53.843104916234175, 59.787809925694624, 56.87514020550636, 55.460686452927135, 48.88877876343266, 50.40105250573928, 44.38283051213911, 44.7717256699839, 47.372594418064246, 47.107171550873794, 47.8488995951991, 46.59960508346558, 43.88024545484974, 47.58490054838119, 48.29279030522993, 49.71741868603615, 52.0489735757151, 50.906900975012014, 54.315460266605506, 54.31447182932208, 55.77047917150683, 57.87892572341427, 65.10989750585249, 69.43334964013869, 69.90848987333237, 60.88745424824377, 1.441782376458568, 1.3656008772311674, 3.4388919607285535, 1.135397829836415, 25.71350362993056, 83.99463899673955, 69.19177086122575, 76.40949679959205, 74.71224015758884, 78.25390508097988, 70.35631472064604, 58.219893440123535, 45.154776496271936, 59.21454375790012, 76.27235504888719, 8.488810196999582, 0.8872252402286377, 0.39660181850194937, 0.34063394752240955, 0.3087071107039529, 0.15856627284759478, 0.10133371327913578], [0.053339473107048584, 0.06629411566762194, 0.11348463384614838, 0.026673572738805128, 0.08414461547809263, 0.050600888808408094, 0.03386849432342476, 0.1151304894817933, 0.37017769931304845, 8.941320315484079, 55.45976861830681, 46.982177380592596, 39.90746890344928, 88.63635616917765, 68.71750139421033, 42.249700484737275, 69.19872914591144, 58.72895040819722, 59.62450988831059, 57.35742699715399, 58.08920791072231, 46.77650005586686, 0.2756621532382504, 0.0643925245610937, 1.9513959533745244, 1.5076135988197021, 0.14515264019850763, 6.208012738535482, 53.42987537384034, 57.70949894382108, 55.965546484916445, 56.82806391869822, 48.607070215286754, 49.46297061058783, 54.10696668009604, 56.82982506290559, 55.443482937351355, 54.63345073884534, 57.1435832977295, 56.160229406049176, 53.35534641819616, 47.95261882966565, 40.573463824487504, 40.03507929463541, 40.106988107004476, 41.21100194992558, 41.34553532446585, 40.203976554255334, 42.119160083032426, 43.91066735790622, 45.57776881802467, 46.619875892516106, 47.29553553365892, 49.40242098223779, 48.195276260375984, 45.80134391784669, 45.45348067437449, 44.37685674236667, 44.121651649475105, 43.01521770415768, 41.731935854881044, 42.12769123815721, 41.32305229863813, 40.956142025609175, 41.48371650326637, 42.857887514175914, 38.7660042701229, 38.82263937304097, 40.07066695920883, 38.15192584068545, 38.443730569654896, 38.58001332129202, 39.23114245937717, 42.15162161857852, 45.57533302614766, 51.687452639302904, 50.17848545505155, 54.171375920695645, 49.8912424425925, 56.71320123057212, 47.472771752265196, 40.71611650528447, 39.74148988723755, 39.2492167411312, 39.70417245741814, 40.2097620502595, 40.83381114467498, 40.64886746868011, 52.385760045820675, 43.0489500876396, 39.39747056653423, 41.61177796702231, 39.70816543025356, 41.83938918575164, 40.09667619582146, 40.363409134649466, 40.63151098066761, 43.94792595217305, 41.15932080053514, 47.78643192783479, 53.923207559893214, 54.98352619909472, 50.94812900789323, 49.648267299898215, 43.895307356311434, 44.63316794364683, 41.15474339454405, 38.547485105453, 37.88149018441477, 36.5266211571232, 37.85165663688414, 37.6990685924407, 38.87444211590675, 39.43468209235899, 41.82970877616636, 42.77171304149013, 42.33199965569281, 41.99833539224441, 39.16041820280014, 41.48331249913862, 45.2623906443196, 44.77400848942418, 44.76190797744259, 50.27385396342124, 50.86024830418249, 53.822712513708304, 49.32453447772611, 48.22010094119657, 53.230407161097375, 50.97353419949932, 51.29692185309626, 48.591255218751975, 46.03031227665563, 42.43841748083792, 43.188904177758005, 41.07212651160456, 39.7588110739185, 39.61040819844892, 40.440464096684615, 41.81101475992511, 41.264177522351666, 41.114778364858324, 43.99540232073876, 41.10460373663133, 43.723962537703976, 45.7731185420867, 50.84212303161622, 50.022873263205256, 53.37498180327877, 55.142115469901796, 60.83591430417953, 56.8119155206988, 60.942108554224816, 26.87990277044235, 0.16119110458079847, 1.0089564888227371, 1.066249998346452, 0.17966631078912368, 32.23764861783674, 68.63513946533203, 54.598969182660504, 66.57255326547931, 57.5718080612921, 58.784385265842566, 50.16341963121968, 34.651543863358036, 29.067492946501705, 50.54798841476441, 41.55040464093609, 0.716456703601345, 0.07291038039951556, 0.05923718567036333, 0.08051526627593464, 0.021666366524333437, 0.07408812566990815, 0.06948088055416461, 0.049032105448385405, 0.01773435896592996, 0.06705456518477972, 0.042029311054296074, 0.13947620447124207, 0.012763873260888844, 0.13627320618158387, 0.09939020950227015, 0.45134673736268477, 12.393455178506914, 66.7999722880702, 52.75686725493401, 47.69399735235399, 76.78134533666795, 64.18230402854182, 50.117920137220814, 73.2976608891641, 66.9921370475523, 65.32074451446533, 62.84489739325739, 63.352040244687, 51.16429082808956, 0.1137871543065675, 0.11873413643409168, 4.074870208578726, 5.233440543374708, 0.16635614597508985, 7.338642314557107, 57.36350667092108, 60.30230722119732, 59.52321075624036, 57.21027928013956, 51.44470499407861, 51.24079273593042, 55.57996965223744, 59.47027837076495, 57.982052679984804, 55.95400687186949, 58.98892510321833, 59.281239740310184, 56.36519285940356, 51.660141175793065, 42.7799343293713, 42.618167938724646, 42.22169476170694, 41.92330437321817, 43.20593903141637, 43.08336888590167, 43.99069547653199, 45.53681927342569, 48.89760409632037, 50.17592414732903, 47.918972738327525, 50.69987043257683, 48.27385702440816, 49.405111728175996, 46.038466884243874, 45.51840766783684, 46.62941901914535, 46.107210343883885, 44.902344519092196, 43.84308099746705, 42.72042020674675, 43.09887793756301, 43.88673697748492, 43.21761984978953, 40.115044655338416, 41.37749871900005, 40.83756877530006, 40.39054016913138, 39.27729306682464, 40.33446596514794, 39.542511970766135, 43.512821351328206, 48.91114411815521, 52.54427871396465, 52.989491262743556, 55.55723951708887, 52.70854757678125, 58.45402756044942, 46.486146603861165, 39.27305690703854, 41.39450611606721, 39.79377115926435, 38.98344478299541, 39.382236080784956, 39.63873555583339, 41.735677796025435, 53.06101568283574, 43.45331115107383, 39.09393010600921, 41.10264255154518, 39.783569074446156, 42.169240905392556, 39.94928921422651, 39.460110818186116, 40.21306076357442, 43.115595079237416, 40.277387634400405, 48.69202483084894, 57.150137578287435, 57.00961082212387, 54.63375668371878, 51.00615655222247, 47.089003132235625, 47.98591583005844, 42.82838736810992, 40.53843705884872, 40.28855854465116, 38.29313901162917, 39.93669056123303, 39.98829326322002, 40.04283774283625, 41.558182700987786, 43.57931337048931, 45.48909971790929, 44.06086667891472, 43.28182512714017, 43.524878717237904, 42.506172503194506, 46.23092582148891, 46.00802536933653, 46.63281579171458, 52.55941906282979, 52.86150040165071, 54.16080905545143, 52.68016922858454, 51.072628959532715, 53.54789556995515, 54.63332522299982, 55.123448910251746, 50.53350310171805, 48.02617111513692, 46.324301765811065, 45.88845975937382, 43.685205598031324, 42.12227052257907, 42.68530714896418, 43.64983758618755, 45.14189151025588, 43.81827592849732, 42.75630989382344, 44.09207305600567, 43.29067791661909, 44.76602646612352, 49.63273471401584, 52.81985267516106, 52.11299842403781, 55.60011494544245, 57.906958903035815, 63.62762205062374, 59.52754105291059, 65.72451722237372, 31.896590686613518, 0.037851308832966515, 2.646817598612078, 1.7449684753533334, 0.15977344355515896, 36.75789586959347, 75.01045011704969, 61.76160935432681, 72.60813174709197, 70.07759109620126, 66.01194458623087, 56.88730739778089, 39.990230914085146, 31.118443435238255, 60.794992216171764, 52.80751289859895, 1.9898639859691745, 0.1524542701701003, 0.11568349004993517, 0.07686005394545294, 0.05774947739536724, 0.017357550959493366, 0.11494994554067813, 0.14586563822963547, 0.18223950819623086, 0.3888563018652701, 0.14213422313332558, 0.27091078400131197, 0.16018117087021952, 0.1934895553295651, 0.21164580849149536, 0.5889826760657373, 14.203393670820422, 80.15509359298214, 59.71891741598807, 54.84880455078618, 91.95492452190769, 79.97383302257907, 55.23164356908491, 80.59906667278659, 70.89359314210954, 71.43167957182854, 66.25033840056389, 69.72465622809626, 56.76554526052168, 0.87538740447452, 0.910806223269432, 10.436564107095043, 6.505995690822602, 0.521871964296987, 10.457571341145425, 59.97287911753501, 62.63688625827913, 63.51197096609301, 61.08520838522143, 53.70745758856497, 53.52074884599256, 59.51663686383156, 60.928650902163604, 61.20569182980446, 58.54925486349291, 62.157717750918486, 61.50893026782621, 56.985350962608095, 54.75185140486687, 44.691462209147794, 44.705402312740205, 45.3072468696102, 45.599251639458444, 45.81713145779025, 43.86752520838092, 46.45634835766208, 48.2051488660997, 50.85659657755206, 50.3144230381135, 51.083242893219, 53.749450483629786, 51.8219389454011, 51.30189541847476, 48.13063952230638, 47.886707321290054, 49.29586979650682, 47.011453951558764, 46.105747299809615, 46.99991433851181, 46.96662126048919, 45.30859224257931, 45.834205535150346, 47.09123888323384, 42.908376263033965, 43.53333142495925, 43.77299216485793, 43.71343097379131, 43.25202688094109, 41.076731374186856, 41.7983925727106, 46.118906851737734, 51.063466302810184, 56.10420619287799, 56.662626189570275, 59.94741116800616, 53.438492821108916, 60.37081141625682, 49.306236620872255, 39.751625291762814, 41.067886429448286, 40.225902603518584, 39.957141799311486, 39.434866443757095, 40.04969796826763, 41.04939245408581, 56.04462538996051, 44.233737299519206, 39.04871694503292, 42.32699078898276, 39.20945175232426, 43.54740881150769, 40.20037974080732, 39.24411765990719, 39.8703162131771, 43.651881141047326, 39.97032096309047, 49.21051117681688, 61.07877177576865, 59.892760784395286, 57.93359571887601, 53.99991343098303, 49.255747872014204, 48.868072571293006, 45.22354349013298, 42.80582197250859, 43.40564258636967, 40.419283297754106, 42.7441034778472, 43.2905916244753, 41.95392239478327, 43.7662378434212, 45.773981463524606, 48.81408899061142, 45.33135375668926, 47.2084314592423, 43.88601526137322, 46.02875117332705, 49.41785158649568, 50.60176410982686, 49.276034370545425, 54.013021992098906, 55.656993235311205, 57.758826671108125, 52.70259341885967, 52.552315650447724, 56.72476830021028, 56.87595213613203, 58.892925093250895, 52.01763383803829, 51.07087173769551, 47.616930623208326, 48.83678774679861, 46.02825303231516, 43.68848469949538, 44.393048286437995, 45.46442800952543, 48.16677631870393, 45.93440640357233, 45.25425172621205, 47.780579751537694, 44.828058750398704, 48.5345495131708, 51.94653303392472, 56.00138910355107, 55.326886561609086, 58.581736010889855, 60.69011980487455, 66.88892379883798, 63.89249970836025, 70.50410178399855, 37.60715569219282, 0.1758063767826365, 2.6270802319049835, 5.049278399636669, 0.3709489353481801, 39.83910983608615, 80.45945382887318, 66.10247288980793, 78.30317789508452, 72.10748041829756, 70.59139805455362, 62.48025425018803, 50.297195988316695, 41.5575865007216, 70.16874697900587, 66.4693243272843, 4.172234958217991, 0.4429067467008868, 0.17878602979884994, 0.4052261605618462, 0.18001714841492716, 0.2627930712075003, 0.24609575588856977], [0.03254923346121946, 0.06380533348889121, 0.02863664431647668, 0.08789180432476344, 0.0936231991997169, 0.05162324846511887, 0.05024339387854261, 0.06630279544380403, 0.1674944913435367, 3.9506129535936543, 58.856717694190245, 46.63677346321845, 47.44568386385518, 82.49981587932956, 76.68866757423648, 45.830746004658366, 61.28479819143973, 63.723884859392726, 51.03703737258912, 57.53619294012747, 52.237769019219186, 60.36488471492645, 7.352402969714134, 0.5465505981156903, 3.560407969259447, 5.488584839528607, 0.043144076236433564, 0.6178883991895184, 38.32684001614971, 59.66834629735639, 59.7071110817694, 55.68204933597196, 47.36465946320565, 48.45545491864605, 55.71809591785554, 58.20966389871413, 55.17615772062733, 52.42190860932874, 55.24592491888232, 58.66984421207059, 54.07133194708056, 47.57908759578582, 40.46073882810531, 40.54217899999311, 40.44107206406132, 37.6658578841917, 40.927261614030414, 39.261415312367106, 43.233917297855506, 42.286139303638095, 39.9680773673519, 43.400433678780836, 46.45603849041847, 45.30738807493641, 45.88503945258356, 45.44354923309819, 43.0093772949711, 42.97372687247492, 42.62997819531349, 41.9090897037137, 42.70564071593746, 40.83985551711052, 42.62915841994747, 41.53515054333595, 40.90398234705771, 40.456832147413685, 40.42487659761983, 36.58670402342273, 39.95512570104292, 38.88751537569108, 38.07682029662594, 38.50868501970845, 37.79827317883892, 44.95556715996035, 49.96109201062111, 48.9051664260126, 50.78646067650088, 52.61753289930282, 55.152192038874475, 55.016752596824404, 49.57303623999319, 40.003037452697754, 39.2777519841348, 39.21243275365522, 38.635542315821496, 38.234123030016505, 41.396961519795084, 42.57181336802822, 51.949027661354314, 43.777640173512125, 40.250844955444336, 40.012835533388206, 40.67314301767657, 39.83596017283779, 41.2999338488425, 41.39980131579984, 39.60022180311142, 43.984823688384026, 42.83926017822758, 50.28589171748008, 55.03378745048277, 53.226594617289884, 50.28188697753414, 50.199693710573264, 46.99989080429078, 45.01008810535554, 46.154737703261844, 40.59476229452318, 38.2354409463944, 37.72312448870751, 37.78520384142476, 37.704308878990915, 38.15587958981914, 38.42032578683669, 38.63282019092191, 37.87010354380454, 42.3760086490262, 41.44827396638932, 39.91286216243621, 39.78596172025127, 44.83835497210103, 45.112006971913004, 49.18484710877942, 49.36902200022052, 55.305333137512214, 54.1861318772839, 52.09123711432181, 56.13109404040922, 52.970703109618164, 50.486352289876635, 51.278745589717744, 45.68567714383526, 45.58205204625284, 39.78700114834694, 41.40636344109812, 40.170581494608236, 40.004367136186175, 40.940491768621634, 40.81743524920556, 42.372749159413004, 42.85407889273859, 42.99966550642445, 43.30030341302195, 40.168906642544655, 44.5621181303455, 46.83005609819966, 51.26259326934815, 54.56697440916493, 56.65316151034448, 55.801791452592425, 62.35813125487297, 58.53156105164559, 65.50154616755825, 15.713684655004933, 0.17970087667626722, 1.3753789783485475, 1.7317220184110826, 0.4174277655059292, 44.29993121854721, 62.66812793670162, 54.91305297420871, 63.539364799376465, 46.49166145632344, 56.95171271601031, 46.2113178929975, 28.31568244964846, 27.894068841011297, 50.468760459653794, 37.672110142246375, 0.05758240894084016, 0.06132361081038272, 0.06917053833603859, 0.10129870306099616, 0.046456272698818676, 0.10027113400640027, 0.025925131649860454, 0.06545244550873196, 0.012065988229287249, 0.05682009783002639, 0.0889805225174754, 0.039457829684139266, 0.019987276079313412, 0.07828459444065249, 0.10316843257075357, 0.25350477606538807, 5.995982645019408, 69.73773341025077, 55.312895467204434, 52.268061484059984, 83.7999011624244, 75.21853969943139, 50.283773637587025, 69.31807902551466, 70.48840445856895, 61.03919898310016, 65.18937257028395, 58.431371950334125, 67.10277142063265, 6.630498093943443, 0.4550743986281657, 0.5968536472608966, 5.516849929286588, 0.09187217501382675, 1.0354212719586589, 43.415821136966834, 61.978689009143466, 61.229233895578695, 57.31443389769524, 50.43712654421407, 50.73428138609856, 57.82800943620744, 59.44824641750705, 56.99299566207394, 56.04405272391535, 57.645313278321304, 59.32997518970121, 56.498800554583156, 49.83923965884794, 42.861649067171165, 42.48732551451653, 40.94114680444041, 41.104329170719275, 42.95965733066682, 41.952573099443995, 45.27199260650143, 44.24432377661429, 42.101623165992, 46.707466340834095, 48.07929569675077, 47.498890815242646, 47.50688460565383, 46.911488425347116, 44.593351964027654, 43.85042367442962, 46.1573500017966, 45.620981570213075, 45.949538907697125, 43.03268009616483, 44.01362565255935, 43.48555303389027, 41.06688622505435, 41.97536991488549, 41.67348077220302, 38.37083724237258, 41.61650442307995, 42.069800976784, 40.192652671567856, 41.0258464659414, 40.77831352910688, 47.1001701201162, 53.43784170766031, 51.806739760983376, 52.860915968495036, 55.39758728396509, 55.87716764019382, 58.116315410983184, 50.47655420918619, 41.18839733062252, 38.97433703945529, 40.39281906620149, 38.714860485446074, 39.818352653134255, 41.732575201219134, 42.9695220916502, 51.607942273539884, 42.53728866577149, 39.9419661491148, 38.8866053858111, 41.044395354486284, 39.72276056966474, 41.147420329432336, 39.86751171850389, 40.18255256837414, 44.22495903507356, 41.27247333526611, 50.439609404533144, 57.31459079250213, 56.045092152011016, 52.62302813991424, 50.8462336755568, 49.38429178730134, 47.774637360726636, 47.65087089230938, 41.91083908081055, 39.336799344708844, 38.76047372817993, 39.349343084519916, 39.87685088188418, 40.85734928807905, 41.46514015813028, 40.54543064486596, 41.099610559401974, 44.064553706876694, 43.18588395272532, 41.69587358351677, 42.552723192399554, 46.91426154105894, 46.75073792857509, 50.91042326342676, 53.15914161743657, 56.87100602734474, 55.02381678550474, 52.975264826128566, 55.7922875496649, 56.100005334423436, 52.49224847362888, 54.74026472337785, 48.7055334737224, 47.403318343623994, 42.606494965091834, 42.86386912868869, 41.56598037289035, 44.18746509859639, 43.22384072888283, 42.83920918741534, 43.35688752512778, 46.62661844684232, 44.83856678009034, 45.485663721638346, 44.64714334857079, 47.24574104432137, 47.64341054424163, 55.29319732419906, 55.91624229185043, 60.254779861819365, 57.47397238208402, 66.54974076055711, 61.1669348901318, 69.6192229178644, 17.595056372304118, 0.2400664753851391, 3.4259037673473363, 1.2446098534330245, 0.3905465369743686, 49.88362519971786, 67.51042335264145, 61.20618997081634, 72.29356550401258, 55.28719609783542, 65.02163240986486, 55.77350331890968, 32.599675540001165, 30.026400666083063, 60.35872267138574, 46.58870089438654, 0.325371851964343, 0.0768459962320424, 0.11927687142404819, 0.07870159908047608, 0.019118185718393615, 0.030495376634081046, 0.05243797148127229, 0.11032823668492418, 0.12335912414616156, 0.1735233121942128, 0.26242013960596056, 0.18175380845223704, 0.11059200841813319, 0.12256914960040201, 0.23162443160770402, 0.40699649782430747, 5.912320940725266, 80.65496829248245, 63.394284171442834, 59.81810239053542, 89.38739592029204, 82.5272254020937, 59.12234844699983, 73.87222536148565, 74.45131624898603, 65.99594131592782, 71.15621151462679, 61.61545791933614, 74.19236137020972, 9.055034729742236, 1.607902230274293, 9.677534487939651, 10.05508811243119, 0.2234720609961979, 1.9148283091283615, 47.786047535557906, 61.56862874184886, 65.55449424251434, 59.847696673485544, 52.6309121039606, 51.978923966807706, 62.920265736118445, 60.275066360350586, 58.64790247332666, 57.143414635812086, 59.57618628778766, 64.59693777945735, 58.26063509910338, 52.581815796513716, 45.29229479451334, 44.71368635854414, 43.133010402802505, 41.60638470803538, 47.45133599927349, 41.881225186009566, 48.874760212436804, 46.796429618712395, 42.9708400080281, 48.76014855600173, 51.445866015649614, 50.6511781292577, 50.687491432313, 50.2160813731532, 48.198108211640395, 45.35130685375583, 48.29118605582945, 46.123095943081765, 47.9282138424535, 44.64125587094215, 45.48529894121232, 45.76970215766661, 44.68796345495409, 44.2927768153529, 45.210791864702784, 39.38046709183724, 43.3788174967612, 43.273960774944676, 42.69073570928266, 43.80623425206831, 42.90918427128946, 48.814842085684504, 56.15683263347995, 53.07732489801223, 56.062048558265936, 58.23753233878844, 59.62969526167839, 62.77484778435, 52.51433141769902, 41.09115000694029, 39.06982321893015, 39.909645818894916, 38.16834095985659, 38.731479567866174, 41.998249100100615, 43.754968873916134, 53.84234789879092, 43.939288893053615, 39.60406572588029, 38.69689210768669, 41.94422237334713, 39.819886299871634, 41.91894269758656, 41.10655707697715, 40.79867455267137, 44.87069883654195, 43.20834736670218, 53.673842876188225, 60.37437292837328, 59.42775987809705, 55.067488455003314, 55.99858460887786, 51.80815965898576, 52.24855945956323, 51.14994279799923, 44.88267383267803, 40.362448153957246, 42.36705780029297, 42.22654281123992, 42.3492306278598, 41.477864326969275, 43.846724879357126, 43.20114589506581, 43.137897676037205, 46.72961204282699, 45.976101198504054, 44.27831895889775, 43.28083276748658, 49.43299193536082, 49.256850058032626, 52.063341217656294, 54.340814467399355, 59.536574271417436, 57.075294833029474, 54.831055825756444, 57.543159069553504, 57.68363483490483, 53.99250799609769, 55.46827231684039, 50.04680364362655, 50.113491781296275, 44.72200962804979, 45.29129851248957, 44.08649152325046, 44.620482998509566, 44.89886537674935, 46.41781499308925, 45.71104311173963, 47.96557049597464, 48.254233406436065, 48.35491672638924, 46.417061898016165, 49.40764950167749, 51.889121301712535, 57.03705956858974, 58.50468497122488, 61.46656474759502, 62.21517262920257, 69.7443308368806, 64.5285826344644, 70.62509905907416, 19.7668590084199, 0.2702169841335666, 5.486804573766647, 3.7505125038085447, 0.5025329020234847, 54.295385576063595, 74.24266184529951, 67.57930017286732, 73.50572693732478, 59.83398014499296, 72.78870198034471, 59.13365664020662, 41.52957685532109, 42.16780531790949, 69.1524451778781, 56.778720501930486, 0.7905967930151571, 0.2212933682265782, 0.26910900649043823, 0.1750342367637542, 0.23482985073520293, 0.3503419975599935, 0.16076652333140373], [0.046011750180754936, 0.07309890697680174, 0.029901457394683556, 0.06014994495818692, 0.052265735763695934, 0.0474631765316571, 0.06751773428292045, 0.03402819301212027, 0.026108644181682218, 0.18445682711899283, 45.4028703320411, 56.515670668694284, 43.75501201998803, 60.051769748810806, 61.075339701867875, 43.8829283560476, 64.03811377863731, 62.85437776196388, 46.03474847732052, 56.554694329538655, 53.13045732436642, 63.39987747130856, 25.35783486981546, 0.7094752524168261, 2.6684882035178523, 4.74686267875856, 0.778053482213328, 0.221785978083649, 17.142507030117898, 51.36524561912783, 62.07503026531589, 55.313785845233554, 46.40403962904408, 50.3515443494243, 56.39087653929188, 56.77817921484671, 51.21792139545564, 54.38560793476721, 55.13472572449715, 56.74285434907483, 51.68563658191312, 43.08151360481016, 40.42772423836493, 39.32585593192808, 41.22500481144075, 40.58914153806625, 40.05772706001036, 38.97379183000134, 40.26372601909023, 38.97769066595262, 44.12047101605324, 41.37573365242251, 41.663529719075854, 45.016748289908136, 41.06872189429499, 43.27653384977772, 43.33440449930007, 43.07373162238829, 43.56500848647087, 43.76073083569927, 43.334467257222826, 41.39736160155266, 40.11205973163728, 39.420020272654874, 40.74240423017933, 40.25343371975807, 40.16388208635392, 39.161438019044944, 38.79462972764046, 38.533690129556966, 37.99637248439174, 38.17129450459635, 44.319970607757575, 51.61630084437709, 50.29765490562686, 49.881193330211026, 49.773190867516306, 52.264676478601274, 54.272710354097434, 55.19737774325956, 49.39676492444931, 41.42476327957646, 42.087930171720444, 40.50602651411488, 41.093275931573686, 39.14445023382864, 41.264534458037346, 40.64770252473893, 49.38193052045761, 40.873152517503314, 39.322000242048695, 39.15877865206811, 41.061489043697236, 41.311171439386186, 39.62259500257431, 41.30385621901482, 40.432729182704804, 41.770994817056966, 42.346382987114694, 49.284271347907286, 53.747748174975, 51.66220042013353, 52.89281660510648, 51.71303433756675, 50.0932131275054, 44.20708871656849, 41.93120794911539, 42.203306690339126, 39.34021180675876, 39.59783700204665, 38.14301813802412, 38.98857132081063, 40.56238312875071, 38.38225133957402, 38.52959517509707, 36.870307076361875, 40.61891232767413, 41.51871581231394, 40.46618307790449, 41.44838379275414, 44.23474927102366, 43.78295890746578, 47.33463371953657, 51.389740820853945, 53.01603394169962, 52.56191369025938, 51.85400824392996, 49.812732281223425, 50.41815796206075, 49.05668758576917, 45.363579950025006, 44.64138530915783, 41.74841373197494, 38.91004154759069, 40.66500409956902, 39.81609729028518, 40.82292264507663, 41.50140247037334, 40.114942673713934, 39.181779430758574, 41.21827794659523, 41.44266497704291, 43.936664827408336, 43.45091066052837, 42.17281418461954, 46.125068895278446, 52.67649004536291, 55.95015510436028, 59.58582747367121, 56.98142074769544, 62.55891346162366, 61.05806950599917, 60.523148429009225, 3.8531790721801022, 0.12602798295237366, 3.5803429253639716, 1.1482875962411205, 1.5709338914002142, 56.03787891326412, 57.90213831009404, 55.52257753187611, 44.82644665625788, 55.0243188488868, 46.30914180509506, 40.46905033050045, 34.86854507077125, 27.71808974204525, 58.48151160824684, 22.740992269208355, 0.049821356041056496, 0.0320289659148623, 0.04456202071460505, 0.024935694621695627, 0.11516684801467966, 0.048738329881621946, 0.04860025785502888, 0.014953583332469628, 0.058874408564259934, 0.028280158707451437, 0.08473372943098507, 0.023669787952976844, 0.01237300179538227, 0.035070038115185116, 0.0382465680670594, 0.009201294366991328, 0.653074388542483, 55.65315323491251, 63.99864688996346, 49.33268124057401, 68.19146448566069, 68.10157160605154, 51.1100640604573, 69.3801466111214, 70.44101438214703, 51.23758815949964, 63.73940960053475, 57.83652882422171, 69.75794146137854, 26.760411685512913, 0.7726164029971246, 0.6333088910868091, 6.13412901278465, 1.1370653274559206, 0.20339225298695027, 22.380285224606915, 53.24613586548836, 64.05417588449293, 57.84280461649741, 48.84642108794182, 52.62491479996712, 58.981476522261104, 58.691413325648156, 55.65436524729575, 55.147626399993904, 56.061977955602835, 58.88324076129545, 54.085032786092455, 46.34962066527336, 42.1457576751709, 39.72458839416504, 42.195230530154326, 41.55499773640787, 42.98649810975598, 40.49310622676727, 44.42630606312906, 40.884350884345274, 44.47506504674112, 43.62297719524753, 44.72098981180499, 45.369443893432624, 44.97787367913031, 46.011633949895064, 45.053351848356186, 45.01686203864313, 44.84668216397686, 47.12801894833965, 45.07506216725996, 44.325057921871064, 43.69666284130466, 41.594248894722234, 41.20647553474673, 42.87340833294777, 42.094041224448915, 41.59102862881076, 40.926712482206284, 39.576279655579604, 40.12425830287319, 39.68998524450487, 45.37445276014267, 52.14757019473661, 53.53463795877273, 51.90446953619681, 51.875679339132006, 54.402411368585405, 57.12856846470987, 57.242164227270315, 50.53998677961288, 40.32034935489778, 40.391685501221694, 40.919652215896114, 40.31319887407365, 38.65787629158267, 40.33803532200475, 42.16408298861596, 51.0120754088125, 41.582819108040106, 38.70154011634089, 39.96420598799183, 41.32877503671954, 40.03145894696636, 40.15023223815426, 40.27267686782345, 40.92590839632096, 40.74936251486502, 42.07967750487789, 51.357973544828354, 56.66996494416268, 54.761418065717145, 57.30651463231733, 54.06786064947806, 52.26664943079795, 46.01782737239715, 42.91740163680046, 43.18766078641338, 42.245868329078924, 41.582069935337195, 41.22025874353225, 40.77899994388704, 41.591589527745406, 40.50159031344999, 40.008238515546246, 40.00275504204535, 41.68401625848586, 43.40528172831382, 42.5566416402017, 43.998571595837994, 45.63524723052979, 45.94283557707264, 49.85514879226685, 51.565008009633715, 53.56196118939308, 53.78410070173202, 55.49041017409294, 53.353259717264486, 52.76558276145689, 51.92983550410117, 47.32070930542485, 45.5986201378607, 43.34139024057696, 42.31170139005108, 42.98812197100732, 41.48780361298592, 42.80209964321506, 42.49036927377024, 42.19214362482871, 42.128197223909446, 43.58753073600031, 43.56229420631163, 45.84259156257876, 45.7474309398282, 44.70517481527021, 49.923107777872396, 56.799081525494984, 58.05090988835981, 60.51978303540138, 60.518653392791755, 64.50461303034137, 63.878704732464215, 63.215161292783684, 4.320067619123767, 0.19808318706289416, 5.001032265924639, 1.6827824831970277, 1.9282922124670399, 61.46316013028545, 64.26302248431791, 62.249410998436716, 49.74043123183712, 55.506005517898075, 50.00163755109234, 47.14343778548702, 35.26856407042473, 33.07071493517968, 66.56125683938303, 30.347095612556707, 0.06218909481239896, 0.03758170717065373, 0.06210656416031623, 0.04317254406369982, 0.0353816980045409, 0.07607738021761179, 0.05594959212166648, 0.1549901744170535, 0.16785631467017437, 0.12096892982240647, 0.19830051088525405, 0.1099816968123759, 0.10635983995011739, 0.16003877044685427, 0.10052152984445134, 0.13854695514084833, 0.6545382293481982, 62.52998598160283, 73.8961047510947, 55.634192497499534, 70.83747186968404, 68.68308651831843, 58.639194811544115, 77.32751969368228, 76.60363843364101, 58.27111959457398, 69.70065132264169, 62.73087016997799, 75.8645462220715, 30.588754800058183, 1.3371608742783148, 5.879724573704505, 13.456035064112756, 1.3559105391463926, 0.2755637262617388, 27.64410403466994, 54.99488538311374, 68.20911515143611, 60.48763921183925, 51.075233413327126, 54.57301878160047, 60.666628729912546, 60.05972039315009, 55.26431299025013, 57.559417293917754, 57.07606753995342, 62.9193518238683, 56.87740733546596, 50.57193840703657, 45.11465849414949, 42.573747096523164, 45.22354741250315, 44.155650754128736, 45.37833590661326, 43.902740247787975, 47.84367499812957, 43.80413186165595, 47.69285986500402, 47.87472055804345, 47.07703990321006, 48.992478386048354, 45.76579155460481, 48.96829305156585, 47.10040153995637, 46.979788657157656, 47.55929923826649, 48.78050957956622, 44.86874941856631, 42.962520660892615, 43.55388464466218, 42.78913620979556, 44.212631025621974, 45.4280754827684, 43.92599205816946, 45.356001930852095, 42.809018704199026, 42.48644690359793, 42.89941756956039, 41.22100399386498, 49.9483403851909, 55.117012300798976, 55.131952608785326, 56.041263918722834, 54.833848553319136, 56.53660828067411, 61.14651110864455, 60.78717885478851, 53.33125129822762, 41.50199474826936, 41.135421799075225, 41.68382406234741, 41.91728353500366, 38.43931790321104, 40.83696473029352, 41.97313808625744, 52.2343251782079, 42.74326409063032, 37.98793938852126, 39.967983230467766, 41.1278869259742, 41.21362993794103, 39.8070405375573, 41.247797704512074, 40.95483587634179, 43.105000757401996, 43.47773182776667, 52.279506960222804, 57.44573131684334, 55.69489117591612, 60.1686446128353, 57.32293367385865, 55.33239356933102, 49.67539833438013, 45.47448104427707, 45.71319257059405, 46.037909907679406, 44.06855844682263, 44.43782214195498, 46.08857124082504, 44.28776402627268, 42.51585291277978, 42.756321660933956, 41.392615533644154, 43.100529255405554, 45.471354915249734, 45.1940276545863, 45.73888409522272, 47.50568828275127, 48.058981741628344, 52.31244310255974, 56.3945008093311, 56.52588844299317, 56.981338377921816, 58.2968464205342, 56.606446081592196, 55.62535147513113, 54.48790727123138, 49.323832373465265, 48.96426477739888, 46.19800536863266, 44.129712120179214, 45.8666866825473, 44.72464938317576, 45.416779056672134, 45.72330444089828, 45.25127072488108, 45.34935743578019, 45.543553983011556, 47.39471266346593, 48.882620642262125, 48.08070382764263, 46.99174796381305, 51.51483305038945, 59.512789018692516, 60.61006815202775, 63.65823614981867, 62.91530393785047, 68.72722102749732, 67.2299660405805, 66.39451688335788, 6.087379263293359, 0.2652046853496183, 9.880014100382406, 3.384266337079387, 2.249316760609227, 67.09653485205867, 70.36505376138996, 65.0594283688453, 56.47164206351004, 67.27216289889428, 57.05245094914591, 54.81096544573384, 48.503401971632435, 40.24640091003911, 76.68562381498276, 38.52639452103646, 0.21723017577202092, 0.11271207247890773, 0.18719951381846783, 0.14434273204495832, 0.15123805962502956, 0.15311797810417993, 0.1560092245739314], [0.0682796317062551, 0.12579765861793873, 0.009846507023359019, 0.07226223937205731, 0.07861501582327389, 0.05880729160121372, 0.06381657582918002, 0.06464465941873289, 0.10290126706804, 0.04562702082518128, 24.527061177838235, 57.106509054860766, 43.33181965735651, 32.769549469794, 30.053627798634192, 39.52965444134128, 54.452543181757775, 64.18665393706291, 56.94355810842207, 60.625016304754446, 53.59026109018634, 59.986717239502944, 48.7180301450914, 0.2962213790705127, 0.546759648188468, 1.166143328432114, 0.9126351509363422, 0.2889361280587412, 6.459369005695467, 60.154265203783595, 58.44872451597645, 54.687626515665364, 50.44560278615644, 58.13976333987329, 57.926908077732215, 56.46243233834544, 53.39785706612372, 58.80548369499945, 53.715259182837706, 55.14790488827614, 51.531475667030584, 43.280597425276234, 39.263913862166866, 37.634726032134026, 38.464593656601444, 39.16955340293146, 41.06745104635916, 41.51648790605607, 40.532082819169574, 39.197523824630245, 38.60597548946258, 40.38448010721515, 39.80869577777001, 39.3494293766637, 38.70413672539496, 42.55218190531577, 40.29048835077594, 44.24805002827799, 44.19738085039201, 43.05180165075487, 42.10558475986604, 42.00570944816836, 41.011588650365034, 40.393611384976296, 38.634863745781686, 38.94161270510766, 37.788761431171054, 39.09170219975133, 37.89942718321277, 38.742050355480565, 37.07532544289866, 39.39185373244747, 48.98187621947258, 51.61819927154049, 50.42900723795737, 49.43497665466801, 48.777418751870435, 49.428390995148696, 54.81972409832863, 55.6045707579582, 51.41239250859907, 42.59815992847566, 38.01814163884809, 41.22808779439619, 40.71406118331417, 40.78986883163452, 40.00242164058071, 41.513361777028734, 50.474138029160045, 44.931142560897335, 40.65802620303246, 43.05593582891649, 41.239592106111594, 41.05333835847917, 43.570389978347286, 40.91574161283432, 39.962417387193256, 42.054158564536806, 46.26060639658282, 54.02394579302881, 51.84267259413197, 52.974429361281864, 49.78733885672785, 52.29955811654368, 50.55810028506864, 48.67328766853579, 42.42871745940178, 42.38695206180696, 40.11279713722968, 39.521260569172526, 40.19302529673423, 42.15396719594156, 41.90259033633817, 40.275822608701645, 40.95814635676723, 41.192276554722945, 40.21933655585013, 41.364260719668486, 43.21842001330468, 42.49824539307625, 43.178062746601725, 45.7618260383606, 48.45857320293304, 49.45637318395799, 50.892301913230654, 49.30822918491979, 49.046195245558216, 48.28087414464643, 47.01590584170434, 43.9199359186234, 42.845120199265025, 41.97708006828062, 39.843361685352946, 39.5207114373484, 41.16704002503426, 41.29020244844499, 43.17661146963797, 42.087271213531494, 40.73495957159227, 42.100477833901685, 41.12615323835804, 40.392701395096324, 40.98301810602988, 43.19235586350964, 43.53372366197648, 45.10813167018276, 52.441061542880156, 57.6122163188073, 56.8015722305544, 61.33487509142969, 60.3299520861718, 65.54955990083756, 37.47944724175238, 0.14313105674039933, 0.08435943419294012, 1.278047814003883, 1.0260653159310742, 5.23398575282866, 62.57793695695939, 53.03670875487789, 57.612028045039025, 54.23405931841943, 69.68524425260483, 58.89423124251827, 37.46921770034298, 31.185053125504528, 30.718143986117457, 56.00051441500264, 16.885291722513017, 0.4502321713634076, 0.010223967162141157, 0.09845241063064146, 0.07251782162535576, 0.0819359993141505, 0.010447905196117298, 0.04760135964099919, 0.029563313845785397, 0.13630240945325744, 0.033711565042575525, 0.09471979277629046, 0.04463846096768976, 0.0705587049765933, 0.019766158206508528, 0.07871480643629067, 0.09597904980182649, 0.06465344644722439, 33.169433147676536, 66.1318043739565, 45.627186759825676, 45.68799134223692, 46.69327912792083, 45.57745895078106, 65.1246456177004, 69.27365426094302, 61.39559338169714, 65.23100460729292, 61.848132917957926, 63.94933485215711, 52.126310948402654, 0.231694727835636, 0.5747708870518593, 5.403176209618969, 4.139911195924205, 0.30066091987875204, 9.10050186418718, 63.446945913376354, 59.96055110808342, 57.4197809157833, 49.7475895574016, 58.11805694333969, 58.57747239451255, 56.7629211948764, 55.79599026710757, 59.66462004569269, 56.28742794836722, 57.39153592817245, 52.57803070929743, 46.535654760176136, 41.8183692039982, 40.02167263338643, 39.13287139707996, 43.04830681893134, 42.63475956455354, 43.46110490060622, 41.78795514568206, 41.09869272478166, 40.5267091720335, 42.61126848959154, 41.76625659388881, 40.45269012451172, 41.76807657364876, 43.98867153352307, 42.93063963613203, 45.21853854579311, 45.26315158413303, 44.69241926746984, 44.70469628610919, 42.383873001221694, 41.97775079358009, 43.679447558618364, 40.04329666014641, 41.060065223324685, 41.18353359160885, 40.10169290727185, 39.484233394745864, 41.17066429507348, 39.42394656519736, 42.056107982512444, 50.61850870809248, 53.57440686994984, 53.66349566367365, 52.72971660860124, 51.988498472398334, 52.96062654064548, 56.800670085414765, 56.56167222607521, 52.04477663963072, 42.57158979292839, 38.58384939932054, 41.16984451970747, 40.70125856707173, 41.26423243553408, 41.34592756148308, 41.40646934509277, 51.420476513524214, 44.249250273550714, 39.302976746712964, 43.0851496419599, 41.28866487933744, 40.639787181731194, 42.19128854813115, 39.42974775068222, 39.37515620262393, 41.01819392173521, 45.44110559648084, 56.30791056540705, 55.062907126642045, 53.52641667089155, 51.806629934618556, 54.25401633785617, 53.16461332382695, 50.198799410173976, 44.53178251943281, 42.90512461816111, 42.2449504944586, 41.59087173400387, 41.93743275057885, 42.77086580953291, 43.21356804140153, 42.181717964910696, 41.10526661719046, 41.91553808027699, 42.29137566781814, 43.65364620762487, 44.862077466903195, 43.55765404239778, 44.90005385491156, 48.05714999475787, 51.10804011744838, 50.390685681373846, 52.348995670195556, 50.00037847026702, 50.72171018969629, 49.0305567556812, 49.03172562199254, 46.76343464082288, 46.40393372504942, 43.869262818367254, 40.991086421474336, 40.95978982986943, 43.03377835981308, 43.655607392711026, 45.7972607304973, 43.66733135715608, 43.73775359122984, 43.35742096747122, 43.42262252684563, 41.464336072244954, 43.6151324549029, 44.84719207209926, 44.16757083708241, 47.13995864314418, 53.723139224513886, 60.55701809544718, 60.799855955185436, 63.3227244500191, 62.55381830276982, 66.74800872802734, 39.47740847064603, 0.4011819517660526, 0.4533568907889628, 1.0803797240218809, 1.0470251138171842, 5.869188597125392, 68.8463669438516, 60.275725318539536, 63.960964679718025, 57.50895600165091, 73.99079861179476, 59.93257676401446, 46.021796811011534, 31.81118892085168, 35.21419217509609, 66.21775134917229, 21.857531339891498, 0.3543553789777141, 0.1535649750862391, 0.10466890770100779, 0.1052539001008676, 0.08944518548706848, 0.03000711624120032, 0.044341678505823504, 0.21966610554485555, 0.28984887585524594, 0.16412877597876135, 0.20442596606669888, 0.23231936528557734, 0.17431347060107416, 0.30504242186584785, 0.17650946163602416, 0.2645911714963375, 0.233357812788698, 35.73919357792024, 76.60223422511932, 57.76055643635412, 43.86973742515811, 42.896275751052364, 55.080808824108495, 65.64509707112467, 76.45493353566816, 68.11151873680853, 69.99980265094389, 66.09747579020839, 70.30588088497039, 58.82917873321041, 0.5095542510671001, 2.931177668994473, 11.19490731147028, 3.57745532547274, 0.4389016696762654, 11.890561234566475, 66.17123203892862, 61.08388654647335, 60.917880073670425, 54.82774534533101, 64.50629964951547, 59.79905143860848, 59.78608800518898, 56.48256586443994, 61.549495420148304, 58.40415462370842, 60.03868864428613, 55.68668949988581, 49.18154447309433, 44.54604425737935, 41.727652626652876, 42.71463078837241, 45.427796994486165, 46.01423840368948, 46.65508308718282, 44.822175195140225, 43.36970583085091, 42.15648927996236, 45.11948693183161, 43.42720777757707, 42.96312470589915, 43.16158094713765, 48.17837868967364, 46.176895172365256, 47.49085387875957, 48.42833172890448, 48.448614305065526, 46.16474366957142, 44.873879878751694, 45.30304993352583, 45.73788389082878, 43.10318862238238, 43.03008740948093, 42.69650551580614, 45.10564880986368, 41.13521391345609, 44.877990522692286, 41.84308013608379, 45.78121823649253, 54.590175228734175, 56.89141019698113, 56.63525196813769, 55.51203027848275, 55.30969089077365, 57.51571032308764, 60.65696008743779, 60.91123557859852, 55.18381810957386, 44.75326307358281, 39.08523028896701, 41.37518844296856, 42.96546243852185, 41.24767611103673, 41.342852423267985, 42.06070107798423, 55.77830822237077, 47.63405961375083, 40.70399638145201, 44.24399821988998, 40.986987544644265, 41.56068517315773, 44.411644243424945, 39.15139675140381, 39.45680426013085, 41.91220798800069, 47.23303256496307, 59.29985923151816, 55.81121298574633, 57.82227100864534, 54.130959818440104, 57.68726694968439, 57.1991515159607, 53.21254860970282, 47.57201163999496, 46.47375191411665, 43.9250232327369, 43.94785927188012, 44.42412130294308, 46.30157555303266, 44.52331412223078, 46.122648792882124, 45.41824994548675, 45.57349343453684, 44.80370867636896, 45.47635593721944, 46.08011461073353, 45.8024461038651, 48.258402885929236, 50.89104283240534, 52.99411573717671, 53.31252982539516, 55.31452325082595, 52.5122800180989, 52.700483183706964, 52.73752212524415, 50.365955137437396, 49.21981111649544, 47.25608433446577, 47.40974710833642, 42.49276584194553, 44.613999320614724, 44.61019462154758, 46.558490799319365, 50.02534827878399, 46.62974849823983, 46.367392924524125, 46.93569729405065, 46.480659207990094, 44.70326854336647, 45.36480372951877, 47.43028463855867, 46.929550939990634, 50.828100558250185, 57.32141571660196, 62.754125902729655, 61.60460864343951, 65.98029890368062, 64.8100087719579, 68.3239935290429, 43.19592522036645, 0.703711023013438, 0.6732147174977487, 4.972981435637321, 2.6104160422278992, 6.96602842500133, 75.66066926525485, 64.36944423183319, 68.70596178116338, 64.96865687831756, 81.24963883430728, 70.25347801946825, 52.30448069110994, 43.08152929429085, 43.013276130922385, 75.63416188763034, 31.122446213999105, 0.4750709482018025, 0.36251461373702176, 0.2800575060950172, 0.23453737368747113, 0.22592625430514737, 0.13151973786373294, 0.1267979855859472], [0.07256495901533673, 0.024255069551028074, 0.031102556855447834, 0.04904450075100026, 0.10719900500149497, 0.056412033436279145, 0.16128493502976435, 0.04016525442561796, 0.1037071455991076, 0.15505218157364478, 4.598834389640439, 56.67863730461367, 50.631079904494754, 31.676363329733576, 12.815654200892295, 26.7595350357794, 46.63039961168843, 60.673920416062884, 60.48230086603473, 60.71779212644024, 59.78932003821097, 51.76966944048482, 62.356040631571126, 7.8090855094694325, 1.2109914638342396, 1.9059731907421544, 3.035621561350361, 0.1624180556785676, 0.7363990141499428, 46.20070395931121, 62.80535597955028, 56.5736315327306, 55.117514364181034, 59.05242435393795, 57.85952175817182, 54.07925121245846, 59.87423543007144, 55.45338299966628, 55.57219551455591, 52.29785973025907, 43.24136195644256, 40.11146745374126, 39.461377743751775, 39.41489765720983, 45.87655928827102, 46.92233770124374, 47.337493127392186, 47.38244348956693, 41.949850974544404, 40.53927252369542, 40.25687756076936, 40.01527132526521, 39.61526409272225, 39.829421581760535, 38.86229845785326, 40.413027117329264, 39.749620960604766, 40.25907016569569, 40.94719509924612, 41.670715501231534, 42.317961492846095, 42.231743874088416, 40.806299640286355, 37.43078239502446, 38.15963329807405, 38.62473618599677, 37.94755074285692, 40.22016809832665, 39.06575964343163, 36.35819850429412, 36.9684761570346, 44.758350387696304, 49.02910940108761, 49.924053069083925, 51.132319588815015, 49.98895260595506, 51.41831920992944, 53.00985620867822, 53.93218194284747, 57.36495794788484, 54.471225430888516, 42.402967099220525, 38.40929608191214, 38.53563954753261, 39.97249003379576, 39.807471998276256, 40.51404383874709, 42.3012129722103, 50.676418581316554, 41.65262552999681, 39.97001109584686, 39.98874825816001, 41.497174155327585, 41.19438678987565, 40.93217634385632, 42.77741616772067, 41.55196966663484, 40.72502813031597, 44.36925911134289, 51.058688855940304, 53.62675874463974, 53.3427163862413, 49.37288945721042, 48.445582312922326, 50.3253193824522, 48.52583400664791, 44.11486594907699, 38.9660333818005, 38.56286864126883, 39.61799406236218, 39.19640594913114, 41.544219063174346, 42.28226400190785, 43.022117153290786, 42.10165846732355, 41.21317886537121, 40.578523682009795, 41.32312682367141, 41.233194720360544, 41.01753888591644, 42.718635528318345, 46.744513127111624, 46.16394742842644, 45.2598254142269, 47.39339082471786, 46.79167178369338, 45.10207160826653, 44.35143193890972, 42.54833406017673, 39.59871953533542, 39.61368729991298, 39.52355515572333, 38.05671814949282, 41.11271519814768, 40.55977083021595, 41.71521871320663, 43.52429428408223, 45.34659608717888, 43.95473518679219, 43.03076990189091, 40.572589135939076, 41.09979491080008, 41.35942835961619, 43.01039318884573, 43.04637701280656, 44.08612674282443, 48.6688514678709, 57.19731192434988, 56.99266618297946, 63.77229867442962, 57.026626063931374, 64.5006710483182, 17.348164742992772, 0.07262534206552852, 0.37424283763093336, 1.6574227665701222, 1.7543357081951636, 12.003127374956685, 66.066418463184, 51.44337531059019, 63.22929359251454, 60.19139043746456, 62.964604208546305, 55.431696214983546, 35.72990932772237, 59.65070739869149, 56.06142882377871, 50.19818752042709, 10.299541008087898, 0.5719391196485489, 0.12054203498748042, 0.14582040839858595, 0.1324047839208957, 0.038213185785758885, 0.05867107733783703, 0.021931316117726026, 0.01785779296750984, 0.03729908967450742, 0.03246200669016088, 0.05329364189697851, 0.04742889409704555, 0.010963483326767963, 0.10457971974486306, 0.15047675208939662, 0.048914330921346144, 0.40125822347979395, 9.384078441127654, 67.48044075504427, 55.1631550635061, 30.697957508025635, 26.233629526630526, 40.181744560118645, 50.207377633740826, 70.07835988075503, 65.61360436101114, 66.43365429293725, 64.75035344400715, 56.12390041351319, 71.02670269627725, 8.176464996030255, 1.0301776759086116, 3.0647750679523718, 4.2907258387534855, 0.20335106810014095, 0.6481038875156834, 51.48038679553617, 60.84134678686819, 59.257242679595954, 56.98892816420525, 61.9813052300484, 57.697602395088445, 56.459851418772054, 59.747570330096835, 58.37131261825562, 57.17943768347464, 57.36640138010825, 45.34203829303865, 42.26371511336296, 40.771049299547755, 40.915584718027425, 47.353414027921616, 48.615201288653964, 49.41886355800014, 48.33335153518185, 44.98964078964726, 42.326751524402255, 41.06624687871626, 40.45261952184862, 39.76544772425006, 41.11071871172997, 41.45986849261869, 42.988922134522475, 41.612891920151256, 43.888251012371434, 42.708735466003425, 42.36122131347656, 44.180200869037265, 43.319742679595954, 42.52874182116601, 39.62232828140259, 40.04290442312918, 40.7093111930355, 42.122392116054414, 40.57201254752375, 40.42517469775292, 37.33517069970408, 39.946551399846236, 44.94621622946955, 52.484227226626494, 52.30211550189603, 52.217729630008826, 52.51191916004304, 52.746194485695135, 54.06320871845369, 56.44473852649812, 58.68217222152218, 56.1296231515946, 45.06416190055109, 38.86797804986277, 39.19214233275383, 38.054062704886164, 39.91335245870775, 39.22296823993806, 42.75772194708548, 52.209241620955936, 42.533519268035896, 41.277529270418235, 40.484053396409564, 40.04454789623138, 40.94356690683673, 41.771155634234034, 41.78594296978366, 40.686224122201246, 40.417557454878285, 44.71268223178002, 55.23353415150797, 54.99375574050411, 57.40942978089856, 53.0215762507531, 52.26082078872189, 53.23401574165591, 50.841879844665534, 46.57176409998248, 40.23687347289055, 41.0097804377156, 41.750900514664195, 40.3340894176114, 42.70626437279486, 43.43513096532514, 43.620643384995006, 42.768586912462794, 42.97522914025092, 42.53277009533298, 42.488882695474935, 43.04929525621476, 43.01456659070907, 43.77178015247468, 48.7443414042073, 49.55635832202051, 49.328292108351185, 49.48134691484513, 48.68365449290122, 48.11573843802176, 47.004817301227206, 44.386368490034535, 42.67125721900694, 42.160058636819166, 40.71442204137003, 40.86036559074156, 44.09265356679117, 43.23066173061248, 44.247324389796105, 45.92920141835367, 46.89742672827936, 46.73319316679432, 45.72223363384124, 43.766496719852576, 43.570225238800056, 43.31192539584252, 45.597184550377634, 44.364022747162856, 46.122091816317656, 51.840436843133745, 60.639458471728915, 58.956428266340694, 67.45352545092183, 56.04226804548695, 65.3168535232544, 19.993636723487608, 0.10207864185494762, 1.6235689121869303, 2.045289282837222, 0.8396260524469038, 13.086532104399897, 72.88922448312083, 54.39031085660381, 70.30209972012427, 65.21233412527269, 71.74869337389546, 59.22146674125426, 46.82203877356745, 59.90745006069061, 54.86712986423124, 59.48832519592778, 15.852160011568378, 0.6841687329353825, 0.24839238023325322, 0.07586635363798949, 0.16134752441317807, 0.09988252824592976, 0.07890160165486798, 0.0507280670647179, 0.1795625671624176, 0.13108257745062152, 0.07606361361761248, 0.16146249888885408, 0.2539937853092148, 0.15782502149381947, 0.3507117115922513, 0.3708818260460131, 0.315319920379308, 0.5535060635978176, 10.681025828084639, 78.402570755251, 63.89992475509644, 44.16347196025234, 21.829988456541493, 41.07182056673112, 65.01369745500627, 75.28178399608981, 72.34620371172505, 71.78999593180995, 70.95575486460041, 62.45556685232348, 76.59289113936886, 10.051590338830026, 2.9714469275166913, 9.661844026657844, 7.608223874722758, 0.25105977581152994, 1.2756486717731723, 54.083605043349735, 63.3027752753227, 63.702135316787235, 61.35871133496685, 66.26093664476949, 59.866712324080936, 59.89061132554085, 61.40951779580886, 60.46664276430684, 59.0016100483556, 58.65012645721436, 48.62197129957138, 43.65563484930223, 43.20583312742172, 43.36712491127753, 50.488364465775035, 52.18999847289055, 51.23658403273552, 52.716635504076564, 48.10723866185835, 44.10329887943883, 44.2728001840653, 44.14451514520953, 42.574100109838675, 44.16209913069203, 43.9588144517714, 45.42589464495259, 44.62127531728437, 46.86366688820624, 46.5246093657709, 44.657957323135875, 45.917838311964466, 44.9731001546306, 46.3456904503607, 40.761945478377804, 41.70613842625772, 41.893400223024436, 43.023172270867136, 44.34290862852528, 43.96498826242263, 39.538095381952104, 42.015366323532604, 48.68946352312642, 55.72579945287397, 53.97491224350468, 55.36525910900485, 56.65263199037122, 57.45080294147615, 58.033553400347316, 59.384872682632945, 63.19814605097618, 61.038504723579656, 44.749313246819284, 38.82274135466545, 37.883725935413, 38.68300691727669, 38.95872992853965, 40.15339366851315, 42.899409724820046, 55.32600795069049, 42.773760518720074, 40.92319411616172, 39.9762241301998, 42.05349568397769, 40.6461061200788, 41.70240432985368, 41.77628609441942, 41.0943506610009, 39.63311479937646, 46.40887198909637, 55.74849036432082, 57.61606416394634, 59.327037334442146, 54.12146376025293, 55.956525033520116, 56.81430816650391, 54.33624098377844, 50.9966173479634, 42.439194110132036, 44.76566953043784, 45.45391997983379, 43.739310772188254, 46.30758462413665, 46.0999265024739, 44.865729193533625, 45.84246996910342, 45.86919307708741, 45.90918164099417, 45.55103786530034, 44.89124421150454, 44.2812725036375, 45.802701057926306, 51.02579193730509, 50.606549401437086, 51.21308511303317, 49.907147653641246, 50.577755282002116, 51.167420879487075, 49.33940418304936, 47.8180266195728, 44.702370320597005, 44.549135085075136, 42.51853581397764, 43.42818444774997, 47.40566392098704, 47.445872137623454, 46.62532406468546, 48.74138393709737, 50.57144026602469, 47.90311459572085, 48.79202958076231, 46.20852124306464, 46.310161621339866, 47.72091265647642, 48.341109983382694, 47.77776741212415, 48.23210731629403, 53.75948390653057, 63.51043339698546, 60.45248693035495, 69.15856407534692, 57.933309385853434, 66.55030558186193, 23.243153710519117, 0.1196364654348262, 1.1400822429887711, 9.869461944026332, 3.8415146787320418, 15.322432152686583, 79.69383855019846, 61.48512148088025, 73.97495223629859, 69.7981143766834, 74.7480200183007, 68.05616624893682, 49.257567851774155, 68.26112577992102, 64.61583183657739, 68.39001486378332, 21.67045585570797, 0.867305238160395, 0.45575042525606774, 0.22948491657453202, 0.27315149924928145, 0.1853340744010864, 0.17875492662912418, 0.12655913469291505], [0.060541381413537654, 0.05599284544587136, 0.061745958913478165, 0.01624086098144612, 0.04256901999695167, 0.023012700933782805, 0.03820580835904806, 0.011891819097311988, 0.07979787856100068, 0.05500968267780639, 0.5987155473520679, 47.09765980320592, 49.62065773625528, 45.4988468077875, 22.75674450782038, 28.932128029484904, 44.12199681805026, 56.1280071350836, 61.82890153700306, 58.45730666191348, 59.82511558840352, 53.57632098659393, 61.72301323183122, 23.10694548391527, 0.5821181605419805, 2.0854974994736333, 4.69530459373228, 0.30235731433476176, 0.18310783821488583, 10.384030822784672, 65.22037890649611, 58.92530425902336, 58.53932734458678, 58.6823251939589, 51.359503269195564, 61.04994235500213, 58.86355046303042, 58.137688406052135, 54.81728046171127, 49.21486108533798, 42.19568160272414, 39.549988008314564, 40.50288861797702, 46.697550589038485, 54.14687287422919, 53.36982780887235, 53.724457140891786, 49.95133707600255, 43.56939369632352, 39.66717273958268, 39.27885809252339, 38.98708474251532, 40.01613032433295, 39.11646804501934, 39.385413200624534, 38.16847824281262, 39.329182101834206, 40.44300579255627, 40.62836131741924, 42.129413158662864, 42.17493226451259, 43.211548020762784, 41.76603301878899, 40.12750210300569, 38.48070283089915, 39.58334384425994, 40.78709179355253, 39.870406427691066, 37.80957352730536, 39.140241530633745, 41.26766843180503, 46.229976607907204, 50.26871958086568, 51.483728654922984, 49.5439047967234, 50.92918003759077, 52.44748638522241, 50.07797471938595, 51.60447097593739, 52.71657666852398, 51.07199745793497, 43.038610719865375, 41.157547889217255, 40.45222336246122, 38.97793777527348, 39.74780098084481, 42.24380123999811, 42.780138292620265, 50.88409239246, 44.92657299964659, 42.659639158556544, 42.1812629699707, 41.17865808548466, 41.88002101836666, 41.44674816439229, 40.64015196215722, 42.36509661520682, 41.07752369296166, 44.06511460581134, 54.719413403541814, 54.190360192329656, 53.68959903717042, 52.4878671861464, 49.944323878134455, 51.28559404803861, 52.85432638660554, 48.560735256441184, 43.29170557760423, 37.21560508974137, 37.00542096168765, 36.45907402038574, 37.90946845085391, 40.58820801396524, 40.21384523760888, 41.319106394244784, 41.73140241253761, 37.391264515538374, 39.50785783029372, 39.570039164635446, 40.91303517741542, 42.749045664264315, 46.455783536357266, 45.89353138400663, 46.47531301744523, 43.173285299731845, 43.388882298623365, 43.41741754162697, 40.36990850202499, 37.729608166602354, 41.01857439164193, 37.546974766638975, 37.86503976391208, 39.1698593478049, 39.663368040515536, 40.337898039048724, 45.98889989237632, 48.3718966668652, 51.10302340599799, 51.47596628435197, 50.38511591572916, 49.70720091173726, 49.062382867259366, 44.2793740764741, 40.797384092884684, 41.75446594915083, 45.169999214910696, 43.098654362463186, 57.038263736232636, 56.84571458447365, 64.52339726109659, 53.642718868870894, 64.87268432494133, 9.31628909803206, 0.10142061829326615, 1.0701156167253372, 0.47310096842627375, 0.39967331013852553, 21.10707013837753, 61.81367097362396, 51.67446174929219, 62.140231824690304, 58.25666566048899, 63.7407628182442, 54.2394329655555, 31.236487165574108, 42.43178475287653, 56.39246902158184, 41.44957619328653, 3.1039644489365243, 0.34067439696481155, 0.04289651875414195, 0.049056087830855, 0.040916047404490175, 0.025774671981531768, 0.06997461656048413, 0.05631926018864878, 0.0076011847141349035, 0.03543799780609627, 0.06216649904907231, 0.02858981910732485, 0.046582478023464644, 0.01459614107114894, 0.03747339765991896, 0.04537555629447584, 0.054007459642185326, 0.07928933407510481, 1.2672826239178259, 58.26409462959536, 57.83040208201255, 42.56254088494086, 19.3066983069143, 36.55474847362888, 53.62127527113884, 63.277844690507465, 68.80761392654912, 63.08663306697723, 67.00920720254221, 57.951991634984175, 68.39483153435492, 23.729406018410963, 0.5407460418439681, 3.0455836461436365, 6.9446779835608705, 1.9775097456670578, 0.19917166010747034, 14.177438366797663, 67.17267590184366, 60.72215772444203, 60.178015155176965, 59.99943356360159, 54.27949213212537, 61.70266789774742, 61.452193183283654, 59.41213315533054, 56.94369146900793, 50.637304705958215, 43.57579892681491, 42.751826624716486, 41.09648050800447, 47.595161468751975, 55.96538566773938, 55.91192376229071, 55.6435630398412, 52.9520090933769, 46.61784410476685, 41.21321024433259, 40.713841530584524, 41.531726314175515, 42.316965210822325, 40.663725406892844, 41.4776054505379, 41.52353640525572, 43.46248949727705, 40.724714340702185, 42.4084819516828, 43.771313390424176, 42.13562227064564, 43.86442653594479, 43.76300188802904, 42.09254680141326, 42.30714751828102, 41.9580408834642, 41.9942835838564, 42.062862303949174, 40.558986356181485, 41.03213402532762, 41.51841771218085, 47.879113612636445, 52.6140223779986, 53.05341412944179, 52.119941019242816, 53.89531950796805, 54.1056134623866, 51.009055183779815, 55.87693229798348, 55.15339228414721, 55.29386412712836, 43.02796540721771, 39.36955898038803, 39.86229104380454, 39.17603315845613, 39.67433106514716, 42.441123916256814, 41.51959442323254, 54.2366990735454, 45.290788604367165, 41.53709603894142, 41.63382168739073, 41.68615395022977, 42.07727701433244, 42.59282550504131, 40.477424590818345, 40.75474400674143, 41.70127860961422, 43.70494688710859, 56.59032906255415, 55.37817155161212, 55.73680562357749, 55.32003418091805, 52.855071636938284, 54.582793328069876, 55.644335746765144, 52.37219256739463, 46.169128879424065, 39.18636468149001, 40.40007545102028, 41.646392883793006, 42.54342325272099, 42.142729605397875, 42.76104027225126, 43.57068807848039, 43.280252256701075, 40.49487129334481, 41.567451261704974, 41.04361088045182, 42.987839560354914, 46.123343052402625, 47.67786464383526, 47.100911448078776, 48.31406916341474, 45.19334516217632, 45.907145930874734, 45.36220319809453, 42.2181018706291, 41.43733055360856, 42.71149681460473, 39.298932783065304, 40.163411401933246, 41.43139208516767, 41.813215209591775, 42.75878883177235, 48.45495285526399, 52.1878372469256, 52.63809788611628, 52.56346694884762, 52.19406989312942, 51.34417856893232, 50.368920449287664, 47.761050270449736, 44.275365414157996, 44.958438334926484, 47.50565690378989, 47.10882286871634, 59.36550401872205, 61.43482885053081, 66.47676898587135, 56.13748358141992, 66.93654921747023, 11.15874796144424, 0.1373518426572123, 3.399617268193153, 1.0915892451040208, 0.6668751254197091, 24.70292260569911, 70.82212755756994, 56.80384720525434, 68.33715700334119, 64.53897299305086, 70.7787069197624, 59.47335743135022, 43.810815580429576, 51.993613243103034, 62.36910212424494, 52.277992925336285, 6.046119851450767, 0.6759522254428556, 0.16534751461398217, 0.09264401625841857, 0.03744553121167325, 0.04233198856273967, 0.033620990467287844, 0.04429214326063952, 0.1991911953495395, 0.14194190442081422, 0.21577879155595459, 0.1183665827697804, 0.1289602074651949, 0.15386537348310794, 0.23319445219972443, 0.13101480931283968, 0.20831410743055806, 0.23497142378360997, 1.7467046144508547, 67.24496518411945, 64.07151276065458, 62.116234763976074, 30.963474512100223, 44.32827426541237, 59.81605491330547, 69.78408798094719, 73.47269273573353, 68.6916059063327, 72.33999067737211, 63.21851491928101, 73.94121200807633, 28.92584635365394, 0.8323972467933932, 11.020960980846036, 14.386355569285733, 1.6601437883030985, 0.3352020777040913, 16.307129456150918, 71.29660098783432, 63.78893736870059, 65.74101078894832, 61.35223942418253, 56.77872442430066, 62.069221235090694, 62.90391337487006, 64.28557219043856, 60.72129480300411, 53.81546789600004, 45.884835489334606, 44.15028102936284, 44.476720286953835, 50.20977027954594, 57.9241898752028, 57.322408076255556, 57.99352561273883, 58.476302700658, 48.35022949403333, 44.38036334130072, 43.29706353525962, 43.67472502493089, 45.24955664911578, 44.243205901115175, 44.14624491045552, 43.412094885303134, 45.58048309818391, 45.07985530361053, 44.30729350736065, 46.9232790700851, 46.7751350710469, 47.4761293011327, 45.504902947333555, 44.65447818079303, 42.935205275012606, 43.4180921892966, 43.93539790184268, 45.10563704275316, 44.019520974928334, 43.5040234750317, 44.866905904585316, 50.865559193395804, 54.87934412494783, 56.29892441534228, 56.61763268132364, 56.89602290430377, 55.789259479891875, 52.91040059058897, 56.287110236383256, 58.59935137533373, 57.64815699669623, 42.97180491109049, 39.747357753015336, 40.187129974365234, 38.81983880073794, 39.868107918770086, 43.002116987782145, 42.29653358459473, 56.77823412802912, 45.17411770359163, 42.80072681365475, 42.11142516905262, 41.89602036629954, 41.550675284477975, 43.884681655514626, 40.70062314310382, 41.68783664703369, 41.66077621521489, 44.73570262232135, 58.90630822027884, 59.942680789578354, 59.2264756079643, 58.725573247478856, 54.40560810027584, 57.679865437169234, 58.19387243640039, 53.73938960413779, 48.72561600900466, 40.926783084869385, 39.930595197985255, 42.036441218468454, 43.10326706978583, 44.43404489947904, 44.96691457686886, 44.63935352140858, 45.68650476394161, 41.13292324927546, 42.627958174674745, 44.30932137273973, 44.81726046531431, 46.92629537274761, 50.390972014396425, 50.78496625346523, 51.329516749228205, 46.814970662516934, 46.87054280311831, 48.27064852560721, 44.88488997182539, 42.47298532916654, 45.51536390858312, 41.36407244590021, 42.44722712424494, 43.13845465260167, 43.93416627760857, 45.788796255665446, 51.506352886076904, 53.86878467375233, 55.418775927635934, 55.294173994371974, 55.2415906998419, 54.65983652299451, 54.373326993757686, 50.894349390460604, 45.40332924935126, 46.65642453778175, 51.08522369015602, 49.548772458107244, 64.42256489107686, 61.768191091475956, 72.73318475292575, 55.05237948509955, 67.0367265516712, 13.732857319616503, 0.23014882369147194, 4.255467653274536, 3.9907576768629016, 1.5536839202527077, 28.27633519326487, 76.24263917246174, 62.586009194774014, 72.48776205124395, 70.40043354034424, 75.47063043040615, 69.24858247080158, 44.177635638944565, 50.8473672405366, 65.79146423647481, 64.3024972177321, 11.139468531454764, 0.9357104546600773, 0.3161232095331915, 0.20448829498021834, 0.16639829613268378, 0.1714537409885276, 0.15586713058573587, 0.24320233372911332], [0.08399640044738209, 0.10306100406113172, 0.018986874417732322, 0.12885945158139353, 0.060786663614694154, 0.04758361321423323, 0.11073669178351281, 0.02544882414381831, 0.008484028268515343, 0.079459750333861, 0.21817862326579712, 22.38484105756206, 63.55859225796115, 34.088958309542754, 36.54906103687902, 32.17408464800927, 47.88056881197038, 56.685940757874526, 62.526153825944476, 58.08597587770032, 58.75312397556921, 49.583626639458444, 62.53048020024454, 33.0889186551494, 0.0652789572373994, 2.174529173681813, 2.6283525507296286, 0.5153445887469477, 0.12031393996890515, 0.6843458524634761, 41.383252836042836, 62.103200727893466, 57.62134759656845, 54.39043637244932, 58.74183931658345, 61.09071539294336, 56.76557663948306, 55.0041147201292, 46.73758622138731, 43.36346533990676, 40.39305440841183, 40.98717189604237, 45.77429133076822, 52.91527217434299, 54.64256240475563, 57.70875369348834, 55.40865621259136, 53.98310607479465, 49.122869737686656, 42.2340698396006, 40.207345870233354, 40.37514878857521, 38.17919023575322, 40.35803940988357, 39.92583344059606, 38.386683617868734, 39.66122250403128, 40.01411422606438, 40.86349956450924, 40.18278791058449, 39.69244457060291, 39.46409986865136, 40.412705482975134, 40.23700291110624, 40.79570531845093, 39.52909746477681, 37.54320536890338, 38.134428147346746, 39.003550852498705, 38.18699183002595, 42.95634685024139, 47.92560154391874, 50.15013848581622, 51.32794387878911, 51.58776167900332, 52.2636527399863, 50.91456920869889, 54.10317374813942, 54.077203735228515, 54.88399213360202, 51.40440656292824, 43.01390763252012, 39.86731559999528, 41.327127641247166, 39.794994938758116, 40.85734536570888, 41.546129257448264, 42.826120238150324, 52.106993275304, 45.05435205275013, 39.98672823752127, 42.59607714991416, 41.4241200108682, 41.32997528199227, 39.10558739016133, 41.8912233075788, 40.909430519227065, 41.2728302709518, 47.55944828833304, 56.14803867955362, 53.83751553873862, 53.762735551403416, 53.025612369660415, 54.65791456161007, 51.67815662199452, 50.46097063249158, 50.45008213289323, 49.21573577388641, 38.237813980348655, 39.23515896643362, 37.299610491721864, 37.81748887031309, 38.978537897909845, 40.29968238645985, 37.75802966087095, 40.90007958873626, 39.975059186258626, 39.10241419269193, 39.39030831859958, 39.783714202142534, 39.79031555114254, 44.3608417049531, 45.16013445392732, 43.749136309469904, 42.279008434664824, 40.81928268555672, 40.57418554059921, 39.26677327002249, 39.49117991232103, 38.953203308966856, 38.76454907078897, 39.95420002168225, 38.94409164305657, 42.56414121197116, 51.72549962997437, 55.17030554433023, 54.15300353880852, 54.228603301509736, 57.126783786281464, 54.459277891343646, 52.80867784254013, 55.21482444578602, 52.88032385610765, 47.15815059600338, 41.57416635943998, 41.96873326455393, 43.96243872181062, 52.54752251409715, 55.41039774494787, 61.30142119623, 56.94036137673163, 50.82040094560193, 8.902007379839498, 0.2875591922671564, 3.5417610214602564, 0.43110819593552624, 0.16443010900289784, 37.07130893584221, 57.94440577107092, 53.13373642583048, 62.31560099509455, 59.32708048051404, 63.70330026072841, 45.14194250106812, 29.784098209873324, 23.49270470680729, 45.95674822407384, 45.775872045947665, 1.216202945478501, 0.09997453540563585, 0.05008579810119925, 0.04497241784608172, 0.05956522451954023, 0.10911839233050424, 0.008120328026463189, 0.01959433426119147, 0.03292244851529118, 0.10335881308081651, 0.0695972646316213, 0.03972246326626309, 0.024762566411687482, 0.01709170887366899, 0.03513933842881553, 0.03761487877777508, 0.009392249442997479, 0.007859765244047008, 0.054234911146904194, 31.678379428002145, 70.8091131333382, 36.65352159930814, 31.412058338042232, 43.0014148835213, 51.62809541148525, 61.019500840094786, 67.53125898299679, 63.99211614362655, 66.20252470816335, 55.90289054378387, 67.16032828054121, 36.77229096812587, 0.10980234030754336, 1.840090364698441, 5.624394945559963, 3.672499502858808, 0.3212594919868054, 1.3463926627751321, 47.43845885799777, 63.475861626286665, 59.388206697279415, 59.056036856866655, 61.036669054339015, 61.17355977335284, 59.31822376866495, 57.789632966441495, 50.763079427903705, 47.035254893764375, 43.7538823773784, 43.22473110691194, 47.79270379774032, 54.97483030442269, 57.30541244629891, 59.79254030412244, 57.606905429593986, 57.25487270662862, 50.432211814388154, 45.55409339166457, 41.519865066774436, 41.138830338754964, 39.763745415595274, 40.474353374973425, 43.39820969489313, 40.52025295072987, 41.16826772689819, 41.311744105431345, 42.49557425898891, 42.63090387467415, 40.99486758632045, 42.546110076289025, 40.95210198433169, 41.93246310757053, 43.27330966149607, 41.52121436211371, 39.94909701808807, 41.55167941124209, 39.97685563179755, 40.853666182487245, 43.93384072088426, 50.15189178528325, 51.579179533066295, 53.57029622600925, 53.45423329261042, 53.25303531462147, 54.615192105693204, 54.71252179914906, 57.25883037813249, 56.46934355458906, 56.14094703428207, 42.824245345207956, 39.512384245472575, 41.40609671992641, 39.87767457962036, 39.94467258453369, 40.43616125660558, 42.89354970378261, 53.25729893099878, 46.02479350182318, 38.545045391205825, 43.44282273323306, 42.58377659705378, 40.597425583870184, 40.86663746064709, 41.92024100211359, 44.313267277133086, 39.083331861803615, 47.307863543110514, 57.33947823124548, 56.599762362818566, 56.46657828361758, 53.3053401208693, 56.22434446888586, 55.1658889555162, 53.450173639482074, 52.67603112805275, 50.47103151198357, 40.98538721761396, 40.21461009979248, 39.26823631409676, 41.16812652157199, 40.55954333274595, 41.905563492928785, 41.05854334369783, 43.54196456170852, 41.34679440529116, 41.06968679735738, 40.912109498054754, 42.006988140844534, 43.329211281191924, 46.74605461858934, 47.618891808294485, 43.619968737325365, 45.21242749306464, 42.744017185703406, 42.340695550364835, 40.822542175169914, 42.58067400224748, 42.37306294902679, 41.031361318403675, 41.13134645646618, 40.44345294275592, 43.51927757263184, 53.51798357502107, 57.97799302685646, 55.662092316535215, 58.35450918443742, 59.060743701073434, 57.98521018797352, 56.577585281864295, 58.26374161627985, 54.74947837091262, 49.44302143589143, 43.335628278793834, 44.78603055400234, 44.83605254080988, 55.37765772111955, 58.197320199781856, 63.1316501094449, 58.51248656549762, 51.36688124748969, 10.829269847562237, 0.316191881654724, 5.57466370444144, 1.1328503729835635, 0.06947817626379191, 39.83473639334402, 65.44234975691765, 59.19994077374859, 66.26607494969522, 64.92116482027116, 68.90386889057775, 54.30076314556984, 34.93137751856158, 22.781620179453206, 52.46445848095802, 52.96197975835493, 2.641233124079243, 0.10051425967004993, 0.16720150867777486, 0.01718228727939629, 0.05069700602982795, 0.06939547707236583, 0.05235233051221698, 0.031148887937888507, 0.10497974021540535, 0.18207198008894923, 0.17955761823442676, 0.18517186294399923, 0.2120164111857453, 0.23045234772707188, 0.1536367115594687, 0.12029261974197243, 0.11088100742668876, 0.140103921594639, 0.46125197843197857, 36.17004240712812, 81.34776869127828, 46.08229544854934, 44.94573770030853, 46.2379115627658, 61.12193353714482, 67.74643236590971, 73.06235790252686, 69.72904928268926, 70.75140722336309, 59.135994372829316, 73.8698797841226, 41.04528181014523, 0.2630508751157792, 5.506262961895236, 10.506444073492482, 5.176013121681829, 0.356315583471329, 1.7161869810473536, 50.405108236497455, 65.07295662356962, 60.9904674560793, 60.992597303082874, 62.631414551888746, 63.38478811325566, 61.65261845434866, 60.03129889888149, 53.5621847644929, 48.939600913755356, 45.83293860958469, 43.59291222787673, 51.377687377314416, 57.33443798557405, 59.717513207466375, 61.861563113427934, 60.33785566206902, 59.68974282664638, 53.78341428695187, 47.68944740295411, 43.75862844528691, 43.15940795406219, 42.74980660407774, 46.33878315648725, 45.96283182021111, 42.58979351289811, 43.75730660653884, 43.916272424882465, 45.94053706815166, 44.054496749754875, 41.88877967096145, 43.60696215783396, 43.20782569146926, 43.72810456060594, 45.11288166046143, 44.05528514615951, 42.03282871553975, 43.26386067175096, 43.22667268014724, 42.236007490465724, 47.48085967956051, 52.406509384032226, 55.69517358656853, 56.343839476185465, 56.36168233809933, 56.88225930736911, 57.264894362418886, 59.01969609722015, 58.302047483382694, 60.13197045172415, 57.87395608040595, 43.36653263338151, 39.287146060697495, 41.54760014626288, 40.31947074397918, 40.10075938317084, 40.83586646664528, 42.91979820497575, 59.934035885718565, 46.939780481400035, 37.846079026499105, 43.894703311304895, 43.149645174703295, 41.09717476752497, 39.42535077371905, 42.37679312306066, 42.19127285865046, 40.51277299081126, 50.59175422114711, 59.52374419858379, 59.45474970725275, 61.091797967110914, 56.412782976704264, 59.4277951794286, 56.4958470098434, 56.18783896969211, 55.74496415353591, 55.38726752804172, 44.06687967238888, 44.58511498666579, 41.486281733359064, 42.636410882396085, 44.06316911020587, 45.13018715766169, 42.663847861751435, 45.29229087214316, 43.35093728957638, 41.5885732250829, 43.1580312021317, 43.43061239488664, 44.83673503321987, 49.482468712714414, 50.14953051843951, 46.6922632340462, 47.31587302300238, 44.902650463965635, 44.86472114439934, 44.02952301886774, 44.68244075775147, 43.274906066156205, 42.73896517292146, 44.05000955827775, 42.87114512535834, 47.5706035091031, 57.556114658232666, 60.827904824287664, 57.7253649311681, 60.66416155907416, 63.279252821399325, 59.015299120256984, 59.843680166429095, 59.79718046803629, 57.153875597061656, 52.798236493141424, 45.994485347501694, 46.87616355957524, 48.56670118147328, 57.922824890382834, 60.36410808563233, 65.4106060151131, 60.08112868955059, 54.75482848382766, 14.931987658623727, 0.46313621764702184, 9.95461561987477, 3.031200069573618, 0.242691628875271, 49.36354244908979, 69.47740570191415, 65.61689522958571, 72.15259552001953, 71.53902699870449, 74.55696921194755, 59.37122675680346, 42.88799170524844, 33.79927558283652, 58.08208880885955, 66.71273093069753, 4.305228802465624, 0.48118362503667034, 0.2894553824538185, 0.15429047567229118, 0.21342273411010543, 0.2005598727133005, 0.10073636388105732, 0.07309717561809287], [0.07049014776824944, 0.03564359665277504, 0.006627987792354919, 0.027190120928289912, 0.12440429024037816, 0.03731593594796235, 0.07175910346690687, 0.0299570006844137, 0.12991763350944366, 0.10722172716932912, 0.2780878633981751, 4.592835614758154, 57.31637939330071, 47.59711873146796, 30.522521657328454, 18.028986223282352, 45.61897723905502, 60.247378349304206, 64.6230136963629, 54.411593637158795, 59.83601977748256, 55.73589563369752, 58.619586883052705, 42.1529552244371, 0.7070599304091546, 2.410547257431092, 4.342234894152611, 4.383534510289469, 0.4930233300453233, 0.04240770869317555, 17.66302320265001, 62.60986897253222, 50.06303048902943, 63.10620569413709, 57.21490375457272, 56.76953038861675, 55.1320271338186, 49.7169009331734, 42.49389548455515, 43.23733760464577, 43.23230912608486, 48.258085173945275, 53.25847956442064, 55.9107352841285, 54.361120577781435, 56.92680958778628, 55.18183339026667, 57.48994819579586, 49.153307330223825, 41.76281667524769, 39.58704263933244, 39.29475153646162, 38.534988434084006, 38.003177796640706, 38.526218014378706, 37.70230062546269, 39.06734035861108, 40.897628107378566, 41.36953630755025, 40.44778716179633, 40.85381523255379, 41.028148897232555, 40.35271675355973, 39.659022054364605, 39.20031262982277, 39.66785130962249, 36.86619643242129, 35.278770077613096, 39.12065713636337, 39.688330004292155, 44.42468612424789, 50.35740829283192, 49.41230535507203, 51.83775394193588, 49.85802781197333, 50.72043934176045, 51.987996409016276, 53.53311607914587, 54.92736962533767, 54.2304507378609, 51.17083334153699, 43.37164740408621, 40.75893309808547, 40.47946030093778, 41.0183233599509, 42.005595699433364, 40.06568947146016, 42.42351639655329, 52.68249127172655, 46.06559007398544, 42.17304952682988, 42.49879060253021, 42.698027395433, 39.883314947928156, 40.33466600602673, 41.40948172538511, 40.36429166793823, 41.07932406087076, 47.08296660454043, 53.808944994403475, 52.746445517386164, 54.604056496774, 52.541293790263516, 49.40750829635128, 51.30299760449318, 51.16357303434803, 49.54483439845424, 48.77289625906175, 42.431831821318596, 36.078525666267645, 36.9628083321356, 38.93510157062162, 36.43841489668816, 37.82014823728992, 37.90814268973566, 39.436333410201534, 38.90558181270477, 40.47227451878209, 38.631619945649184, 40.845197785285215, 40.61630002913937, 43.71485479416386, 43.05750477698542, 43.0778814900306, 41.73086897019417, 41.766178146485366, 40.62583531102827, 36.42869526340116, 38.61906836109777, 37.53904373415055, 37.372668558551425, 40.43220358510172, 39.00750067926223, 47.242022637398016, 54.51746625284995, 52.8978999968498, 54.31053376966908, 52.55766968573294, 57.92611968132758, 55.397112677174235, 58.972133436510646, 55.249980649640484, 56.05604733190229, 55.12359796031829, 47.86669146630072, 39.74568682332193, 41.271041670153224, 47.83314735658708, 56.02807298783333, 58.44108373888078, 55.89030365790091, 27.51137887277911, 24.91682121830602, 0.12486581991036093, 4.187562109962586, 1.2038516469540135, 0.7285003412154414, 53.50156845584993, 52.44408176791284, 57.86567595697219, 56.52255835071687, 60.44625036178097, 61.02945581559212, 40.88884984293292, 31.536344520507324, 28.34741246315741, 53.191042254048014, 28.754223046764253, 0.24531662914781804, 0.0561962188071301, 0.031170112403830698, 0.11367788718592738, 0.006555693511355429, 0.0562887852110209, 0.02336702425964177, 0.017936885800032366, 0.03262721738147159, 0.05896821220014846, 0.023860053549851143, 0.01918848194632559, 0.04189130414517657, 0.062203382352186795, 0.020428425895290512, 0.02389399890577601, 0.05883971244216927, 0.02863835652298745, 0.24678333512236997, 8.298830197703454, 68.63040124216388, 51.04054789389334, 33.03193446128599, 29.980354001445157, 54.788082338148556, 63.85359764099122, 71.31048617824432, 60.79187393188477, 66.46444489878994, 61.568585595776966, 64.52639002953806, 47.06760268057547, 0.9541465750625058, 2.2969066327618015, 3.617423051787961, 7.693920798840062, 1.5757188152882362, 0.02456229187608246, 22.331434065295806, 62.8517262397274, 51.56789487408054, 65.55188978871992, 58.97929176207512, 58.7164145131265, 56.42485995446482, 53.05054687684583, 44.37280493397867, 44.023545326725134, 44.501015447801166, 50.62524734004852, 55.62352365063083, 58.027673767459014, 57.15061218507829, 57.47085409779703, 57.47842819459977, 58.016138076782234, 51.520900957046024, 43.207229491203066, 41.62612991948282, 41.45875846185992, 40.215861335877456, 38.771789766127064, 41.1877775961353, 40.321090682860344, 40.98153545010475, 41.891603777485514, 44.563663544193396, 42.59734015310965, 41.97697416428597, 42.789340173044515, 43.83940965898576, 42.76526466492684, 40.80107112084666, 42.040128246430434, 39.17318159534086, 39.359886415543095, 42.148130709125155, 41.213171020630874, 45.519145073429236, 51.97870823644823, 52.1395803266956, 53.7758872585912, 53.179204540867964, 52.93447217633648, 53.1022084143854, 57.28023867453299, 55.494363923226636, 55.94364789224441, 54.835142935476, 44.24479053866479, 39.8615026473999, 39.161618448072865, 40.56120249532884, 40.65847727560228, 39.86918657056747, 43.232654294660016, 52.89153399006013, 46.71294196959465, 42.50498402503229, 42.24649590830649, 41.97597395989203, 41.81450566937847, 41.02812144064134, 40.53135325831752, 40.430085505208666, 41.67541450069797, 47.10475929321782, 56.47555658894201, 55.2171504112982, 58.54694850983159, 54.16440979126961, 53.792651468707675, 53.6514735990955, 54.48483605538645, 51.21204176256734, 51.04969486113518, 43.921053794122514, 39.100319647019916, 39.77947804235643, 39.562551359976496, 38.847538578894834, 39.07977427205732, 40.654613740982555, 40.43760861119917, 41.6946654935037, 41.85684373301845, 41.44803077943864, 42.15183342656782, 44.2671049025751, 46.80227002789898, 45.67558096301171, 45.771577050608975, 44.845831009649466, 43.55925436942808, 41.86772046550628, 39.381490830452215, 40.10093588982859, 41.25337531489711, 39.89931037349086, 43.07099380800801, 42.14454566278766, 48.66628623777821, 58.19359002574798, 55.87377478999477, 54.57627827121366, 56.276378631591804, 58.522170897453066, 57.54934856968542, 61.79647138041835, 56.387821012927645, 57.779521096137266, 57.3700923304404, 50.36698279842254, 43.4178097786442, 44.605950617021136, 51.476417356921786, 60.87073710656936, 60.43336145339474, 59.24461657001127, 32.032483162418494, 28.395112406822946, 0.4000110016955484, 4.431524219051484, 1.4732179670564591, 0.8419046430818496, 58.28570688924482, 58.07765260819466, 62.99037025820825, 62.4617406629747, 67.25259811647477, 65.69696649428337, 50.51370689945836, 35.52072540406258, 28.638581768158947, 61.440335858252745, 35.93460213753485, 0.08322743969338556, 0.033676631433228334, 0.02094345723068522, 0.07120773466604371, 0.12439777849302178, 0.016083004734208508, 0.0287255794636064, 0.005887066813996963, 0.1413174661537332, 0.28110539180136496, 0.1046002738838715, 0.08982275958142935, 0.2569279633462429, 0.2785218368855215, 0.2370032728199036, 0.1595867479280118, 0.28748463659036544, 0.3397303621374792, 0.6319271749065769, 11.106812838585148, 78.2296177648729, 60.76743364334107, 41.72814684529459, 27.149520612532093, 60.11189968355241, 70.08189001391011, 77.9211155060799, 64.68511266093101, 71.73743617150092, 66.36304378509521, 69.53165992613762, 54.73553434495003, 1.332370557131306, 6.834283365357307, 11.655239616670917, 10.328219417602787, 1.4415730199506207, 0.12248268891726771, 26.020695817086008, 63.993924356276, 54.12115781537948, 64.52191068280128, 61.012303290828584, 60.75579204866963, 60.473299026489265, 56.11801685825471, 47.7273061198573, 46.63765991887739, 45.751572962730165, 54.12040079793623, 58.219858138791984, 59.444967316043, 60.33868720454555, 58.859659471819484, 60.687076045620834, 61.45697847489388, 54.066758463459635, 44.918296798583, 45.042730069929554, 44.1072565509427, 44.076513013532086, 42.14924466225409, 43.63965511322022, 42.878068108712476, 43.16339700452743, 45.04291442132766, 47.57429838180543, 44.64900255203248, 45.924773062429125, 45.10408378416493, 45.11934964887558, 43.47646097983084, 44.284959531599476, 43.88492092009514, 41.76338934129284, 40.31114355210335, 44.278401328671364, 42.3693210078824, 48.6512400257972, 56.217029248514486, 53.87344052714687, 55.4586781993989, 56.76088156238679, 55.31056165695191, 55.06591166219404, 59.29795688198459, 60.19170814944852, 59.29428162113313, 56.20196734705279, 45.72109614649127, 40.99489504291166, 40.55957078933716, 42.57798325630927, 42.281432459431315, 39.06297083823912, 43.402288959872344, 57.20983605231009, 50.02363812538886, 42.9757272812628, 42.84692056717412, 43.306281105164565, 40.418145810404134, 41.66000350829094, 41.216273615437174, 42.98253259351177, 40.03322009117373, 47.42038457624374, 57.72525902717345, 58.43301542343632, 60.19451264412173, 59.37687889222176, 55.703343883637466, 57.82462443074873, 57.27326862273678, 53.345167867599, 52.32342181667205, 46.44029409654679, 40.51247489067816, 41.25873327255249, 43.85516974233812, 39.779344681770574, 41.14318416964623, 43.38167690461682, 41.91771107335245, 44.203503670230994, 45.610446083930235, 44.20285255678239, 46.26601534505045, 46.24520324891614, 47.425742533899125, 46.54521357628607, 48.80616972523351, 47.10404542184646, 46.668403456288004, 45.06587989868657, 40.85474483428463, 44.009801341641335, 42.245279973553075, 42.22829611070695, 44.65123045829035, 43.263637096651145, 51.45398532190631, 60.30741414716167, 56.234107248244754, 58.86758265956756, 57.2636313592234, 63.61769453171761, 60.207040694452104, 64.72432459554365, 57.407201874640684, 60.876644196048865, 59.85391755257884, 53.04296885767291, 45.427389067988244, 47.66010415169501, 53.37981024096089, 62.8297217430607, 63.070810225702104, 61.76908931424541, 35.52056850925569, 35.90749463727398, 0.49851375962457356, 11.717398397384152, 4.37400266047447, 0.7229357849686378, 65.05307020679598, 61.62487553011987, 67.58442278831237, 66.46333879040134, 72.52263192207583, 70.5891466140747, 54.77885300113309, 42.85834643148607, 39.30590283486151, 69.7871317402009, 48.138139094075854, 0.4730610399236603, 0.14373338570998562, 0.12214848306030036, 0.2604546644274266, 0.2238434451001306, 0.1065602408902299, 0.13321777174790062, 0.07804621086125413], [0.05467928810826233, 0.02885080802614891, 0.03879584161744964, 0.014057906847747584, 0.07347686411512476, 0.015552146979908069, 0.10710499835230651, 0.029731866595665776, 0.03034092947810648, 0.06355540496447394, 0.025628963973553433, 0.6374256024437567, 46.748306059068256, 48.90700209525324, 34.70513912939256, 35.68955598338958, 36.457477615725615, 59.3689243255123, 59.76959836098456, 60.76761014999882, 58.132252000993304, 57.49527477448987, 53.35549546826271, 56.53085024126115, 6.9935394390936825, 2.2489637472937187, 2.2643266906661372, 3.886423856019974, 3.3923849078916737, 0.02161734838849835, 8.128582662151706, 54.28113560522757, 57.829923552851525, 58.99219635994204, 55.94578558398832, 57.29098989117531, 52.224346668489524, 48.92591576422415, 49.55159264226114, 52.26695929804156, 52.314074808551425, 52.411631999477265, 53.43233469993838, 54.334730871262096, 56.0790128092612, 52.30414728964529, 56.636511048963, 53.97666946534188, 47.930029899843284, 40.39365453104819, 39.81713671838084, 39.13955903822376, 38.66006105176864, 37.44601295840356, 37.60195070697416, 38.962958243585405, 37.55675715784873, 38.74579621899513, 39.34186704697148, 38.47012027617424, 39.85052001091742, 42.127930502737726, 40.00425338745117, 41.3452725256643, 38.3610862301242, 41.121250275642645, 38.484130982429754, 40.63174632287795, 39.20662372343002, 40.856447142939416, 47.01982428950649, 48.0587895454899, 48.15262440712222, 51.43790752656999, 49.9804332179408, 50.04050039475965, 51.914742223678104, 52.08387482550837, 55.81956763421336, 56.35482995740829, 47.618574096310525, 41.07849251839423, 40.96490460057413, 41.17700676764212, 40.259097622286895, 41.72241234010266, 39.48749288435906, 43.295941737390336, 52.16648778607769, 44.89866925824074, 41.697171888043805, 41.04203408764255, 41.972149648974025, 41.52232439287248, 40.195574837346236, 40.87469793135121, 39.1776099512654, 40.32706837500296, 47.11695001971337, 52.855373659441554, 53.56302807407995, 53.73767160600232, 54.16909310125536, 50.95762898845058, 49.6405049293272, 52.193344254647535, 49.099927794548776, 50.08986342337824, 47.237551135401574, 39.573675201785186, 37.48171044934181, 38.37060582253241, 37.55641198927356, 38.04792027319632, 36.89993273827338, 37.84794215233096, 39.75578692651565, 40.550765068300315, 38.49546270985758, 39.45640025600311, 41.41441998943206, 41.17226462210379, 41.88804618773922, 44.957810755698915, 41.391007361873505, 41.03110244197231, 39.34199648518717, 37.570595279816665, 39.45510587384624, 38.26348589312646, 37.56429595331992, 39.70283885155955, 40.13235407490885, 50.29000628379084, 55.8302168692312, 55.93670921940958, 57.77805020732265, 54.58843369637766, 57.428555257858775, 55.93171996455039, 52.95138151414933, 54.55665465324156, 61.17457566722747, 54.514155772424516, 55.4125040577304, 44.50318844087663, 41.570479331478, 43.239051680411066, 54.74261814548124, 54.8205203394736, 64.7087606306999, 52.50284671783448, 18.502418264265984, 0.0691182604960857, 2.4420664435432804, 0.9255304944611366, 3.465535395568417, 56.686266314598825, 51.94709393285936, 57.464142922432195, 57.87091232115223, 64.94770357685705, 53.16020457975326, 37.172776729829856, 21.88085767530626, 26.50528504002479, 56.09816182044245, 20.17790182944267, 0.13125851720331178, 0.04601632755610251, 0.053430158765085285, 0.022886750333371664, 0.055246844346965515, 0.020444283915323117, 0.029832300722538948, 0.051809921109628294, 0.054283956095816634, 0.038657474647005724, 0.012703850272021467, 0.0741639836961704, 0.07584815904978784, 0.06604812483513547, 0.02995126077064103, 0.04811401801904844, 0.05684077837354234, 0.06272501545026898, 0.09743458621444241, 1.094975721451544, 55.758865033426595, 56.640927637777025, 29.267525980549475, 33.148774023978945, 47.78524344967258, 63.08753913448703, 67.4328859390751, 65.07457264008062, 64.18490848233624, 63.34670582125264, 57.412281344013834, 62.71505517344322, 7.444137402119176, 1.7799954861402514, 2.626381314569904, 5.830656213145103, 2.6964578897722307, 0.06589535158127546, 10.382722712332203, 57.79447317123414, 59.89464744444817, 57.98860303817257, 58.69930905680503, 57.30801690009333, 56.1551970051181, 50.450144890815984, 50.8664809503863, 54.39783396259431, 53.439406733359064, 55.297307968139656, 55.93664253911665, 56.077557609927275, 57.711487585498446, 54.12667266784176, 58.6714719956921, 55.887330501310295, 50.44241782157652, 43.246539485070016, 41.35150517186811, 41.992867608224195, 39.907347309973936, 40.262200217093195, 39.22300354126961, 41.741133812935125, 41.069549514401345, 40.923570663698264, 41.53358551763719, 41.29716465550084, 40.68094068957914, 42.537527930352, 42.771528690092026, 44.14773148875083, 41.94488525390625, 43.14207107790055, 41.521010398864746, 41.837298562449796, 40.7774466852988, 42.03699427266275, 50.04798427704842, 51.487188185414965, 50.69030377172655, 53.37436206879155, 52.735925720584014, 53.515139856646144, 53.63958097273304, 55.72853334488408, 56.088395118713386, 56.47283446404242, 49.010536978321696, 41.8551924151759, 40.6082905492475, 40.81739210313366, 39.56379867369129, 41.439621217789195, 41.176838105724705, 44.40392109655565, 54.02220033830213, 47.58488878127068, 40.77443430500646, 42.63557541754938, 41.281683060430716, 42.11567309594924, 40.12166561618928, 40.166623823104366, 40.585705541795306, 40.161258020708644, 47.86951165045462, 54.78247727117231, 55.172392245261904, 55.56955183705976, 55.00751933743877, 54.33887289416406, 52.342798325323294, 55.14683015884892, 49.502794434947354, 54.25800931069159, 49.188569438072946, 40.456400686694735, 40.234798539069395, 41.36710051567324, 40.62570587281258, 39.83438730239868, 37.970633891321, 41.19528501264511, 41.101669803742446, 42.03535079956055, 40.21182913934031, 40.72299242019653, 43.62592681761711, 44.48015236085461, 44.369466996962025, 46.51512507469424, 44.95744597527289, 44.308548665815785, 41.302577526338645, 41.02534048018917, 42.30187193039925, 40.740031196225075, 40.768052608736106, 41.41269022418607, 42.93431881935366, 52.260252045046904, 57.28461603964529, 57.06699117537468, 58.01451029316072, 56.771522952664284, 58.94187235063123, 56.85382212361982, 57.056035995483406, 57.134283358050936, 61.82260221050632, 57.07698145220357, 58.03372990700507, 47.924856293586, 42.944618963426166, 46.22033149965348, 56.914960107495716, 57.61708005782097, 66.64998085268083, 56.50492337442214, 19.420462731392153, 0.3760743699967862, 2.282671125665788, 0.5650380770525625, 4.182817512942899, 63.52882539072345, 56.00416614163307, 65.88434203978508, 60.655504888103856, 73.52062409923923, 57.34147079529301, 49.80703307736305, 25.16510921139871, 26.701695765218428, 64.74805101271599, 26.05796421727827, 0.15499420403953523, 0.11677898045989776, 0.06442299187784234, 0.031656560998770504, 0.06953822223529701, 0.06720568368872328, 0.013324065479419887, 0.0927433165751638, 0.11710877365042126, 0.09659473934481222, 0.09233462398931866, 0.11437197050620472, 0.22300811814925364, 0.19395348285475086, 0.19233516807998383, 0.12889191838762454, 0.16564612036510823, 0.1833905399807038, 0.27850593290021347, 1.4745900611723624, 66.15537781869212, 63.274122361213934, 46.97204589843751, 48.843828401257916, 51.97585275096279, 70.90238709603587, 70.61811724016744, 70.19069656249016, 70.41056894486951, 69.93863721047678, 63.14043621863089, 70.94089692638767, 10.892186626311272, 5.02103635380345, 11.033737121089812, 11.059407072682536, 8.011760259828261, 0.1122846796868309, 13.491230491668949, 62.4010576740388, 58.34101230867448, 59.784150354323856, 60.98813756819695, 60.72421696878249, 59.45220408901092, 53.22241729305637, 53.534939981276, 57.1694552513861, 56.23452694185319, 56.054490150943884, 58.568384262823294, 59.82710815245106, 58.06464210633309, 55.09072849827429, 62.69004614122453, 58.33380299229776, 54.65370585841518, 45.68572028990715, 42.97837880349929, 44.022902058016875, 42.0305262842486, 42.58143886443108, 40.65449214750721, 44.8145422627849, 42.3402052540933, 42.61519085976386, 41.48888618715348, 43.42496025946833, 43.614426428271884, 47.18099447988695, 43.83315347856091, 45.22839938440631, 42.641792374272505, 45.450079979435095, 43.119446846746634, 45.432076300344164, 44.863179652921616, 43.85005497163342, 52.109852683159616, 51.76519009374803, 53.736883209597686, 55.93447739078153, 56.28918517020441, 55.14799118041993, 56.97432910242389, 58.452662575629454, 58.77734068901309, 59.67472799362675, 51.24369528985793, 42.558842089868364, 40.961531362225934, 41.76762157870878, 40.021201948965754, 42.410058744492076, 38.16793695572884, 44.59158297507994, 56.69190276053644, 47.80338048934937, 41.41153704735541, 41.310426189053445, 42.501112645672215, 41.27024150663807, 39.16291283022973, 40.527717221167784, 39.661591206827474, 41.43601655960083, 48.86213410285212, 56.713542476777114, 57.62683107006935, 59.20136459412114, 58.431673972837395, 57.4870103405368, 54.888691133068455, 57.5734946804662, 52.0908409549344, 56.77467261591266, 51.3280301709329, 41.820322544344016, 42.22111032855126, 44.051354931246856, 42.954193469016786, 43.31187832740046, 39.96532386349094, 43.48624729341076, 44.216231761440156, 44.94323522813859, 43.56092922149166, 43.50728688701507, 45.094889748481016, 46.8122838389489, 46.68857620608422, 50.55722951889039, 46.90725226556101, 45.30967481674687, 44.19554518115136, 43.23227382475331, 44.52725218188378, 43.06253325554633, 42.13571640752977, 44.166562787948116, 45.623284001504224, 54.39220143902687, 60.45124353901033, 60.86836799498528, 63.09488573381978, 58.43795760985344, 62.3503767290423, 57.468386926958644, 61.5863892339891, 60.282161927992306, 65.3565126080667, 60.63321013604442, 59.216716750975586, 49.857223726088, 46.254985640125895, 48.3532928651379, 60.15508105677944, 61.155226615167436, 69.39294138262349, 57.179265099187056, 25.648411896920976, 0.3697968616841301, 10.75057827657269, 3.0651096951576973, 4.475696481043293, 67.76129814886278, 62.52094099598547, 68.95626391133955, 67.6758453922887, 77.26819776719617, 63.51825068073889, 50.6967286140688, 34.06462784736387, 38.137479751340805, 73.86032489038283, 33.96157149345645, 0.25378107333615907, 0.177575932635415, 0.16618377619212674, 0.16372608952224255, 0.1620509157017354, 0.12635439003427185, 0.0851475011797682, 0.16183844887681548], [0.03571405375917112, 0.09062734342390492, 0.02795952409806271, 0.006237895821311301, 0.06512567836550937, 0.0517183774331164, 0.048264726665952516, 0.1311935682690913, 0.022353972571211, 0.04152525201319687, 0.12285243359304245, 0.050174461287115855, 26.034386850172474, 58.11814323548348, 32.12277220141503, 22.182711516657186, 32.12235446899168, 55.59232511828023, 55.20338681436355, 62.353546004141535, 56.94584485023253, 58.68457271206764, 53.1837191889363, 56.553392102641446, 16.552002045416064, 0.894551247117981, 1.8607172514161758, 4.272840321063995, 3.785399780158074, 0.27166633055575434, 9.945680460622235, 66.61460891846689, 53.64218542652746, 57.426397954264, 55.87359043859667, 57.17730783647107, 58.472345029154134, 58.158069041467485, 55.60138187100811, 54.3538288916311, 54.458371823833836, 57.00819876886184, 52.92505456555275, 57.58713668392551, 47.93843946149273, 50.63732431780908, 57.62577987486317, 54.58285608599263, 48.38544453344038, 39.04415915089269, 39.29205294578306, 39.360917998898415, 38.38073338231733, 38.38251413837556, 39.95267814205539, 36.88324697556035, 37.2837366596345, 39.02606133491763, 40.41836546313378, 41.56236786996165, 39.08455956366755, 41.807119846343994, 40.30712312267673, 40.88864980205413, 40.26538518167312, 39.25653980624291, 39.701560158883375, 39.690718727727095, 42.65046473472349, 41.928917284934755, 48.998432543969926, 49.91343913539764, 51.1021997082618, 50.98359115662114, 51.168876078821, 51.52689433866932, 50.85963249206544, 52.16440500751619, 53.74066829681397, 52.57437113792666, 48.47666709653793, 41.204969344600556, 41.91371810051703, 40.92935223733225, 40.59773937348397, 40.863523098730276, 41.42340613949684, 44.20311535558393, 51.91034524671493, 46.8611369594451, 43.25305454192623, 43.53686548048451, 40.86139325172671, 42.40645800867389, 40.6163235633604, 41.520245536681145, 42.041916847229004, 42.89054124586044, 48.66651765761837, 50.64265874124343, 52.856887694328066, 52.06659286252914, 51.94480326867873, 50.26020019285141, 52.39727220227642, 52.86237116782896, 50.8135760215021, 49.62558423319171, 51.03495459402762, 42.830964365313136, 36.6011461903972, 39.24487859972062, 36.587119794661, 38.50307210799187, 36.45161759468817, 40.2706293905935, 37.29274242155014, 39.105065714928415, 38.27495098114014, 40.39293673730666, 40.187000536149554, 42.93284400816887, 45.119443785759714, 44.28197853026852, 43.55114683028191, 42.314556875536525, 40.948654220950225, 38.96090292161511, 38.381706130120065, 38.456191939692346, 38.17242806957614, 39.647184341184555, 38.25770824186264, 44.444199915855165, 53.531162738800056, 55.72790576565651, 53.79638556511172, 55.59242709990471, 54.178330283011164, 55.847416462436804, 50.28027096102315, 48.66112047626127, 57.256551481062374, 58.222140958232266, 58.050423514458444, 54.425674946077415, 43.26824980397379, 43.198670879487075, 51.29015968691919, 57.37759190220987, 58.279584069405836, 60.39367491199125, 5.802929958989544, 0.3985662518009063, 4.728182390812905, 1.0291063785552979, 7.9573172715402425, 54.89131519871374, 53.791043296937026, 55.24682706402194, 57.87730578453311, 63.6433703668656, 53.431397253467196, 39.11001574608588, 27.53804706758069, 36.35670408125847, 49.90153081955449, 5.697542246310942, 0.3525174421168143, 0.0033671570464878556, 0.05303193477072543, 0.017163926067071098, 0.016636631579228466, 0.10890237085761563, 0.04287753126493866, 0.07585099357510768, 0.016565808665848548, 0.016249014072180275, 0.027397499014172825, 0.03742848192491839, 0.06603745323035025, 0.047674540189966086, 0.09157176895607864, 0.05235003607888376, 0.03801078152572436, 0.0392348368111397, 0.024157891297833096, 0.04543173735240295, 33.49051052524198, 67.52080978885775, 34.05475524164016, 28.570697307586673, 44.933688179139175, 62.52267076123146, 63.81137724845641, 65.9582002701298, 63.318150966398186, 63.195051300910215, 56.89720353772564, 62.522753131005075, 17.078727329930953, 1.0860319820142563, 1.0199556115173525, 4.919665638477572, 3.106458095773574, 0.34309385584727414, 11.925793924639303, 67.14471724725539, 53.82360289173742, 57.911042090385195, 58.322726218931145, 58.545881625144716, 59.05791174980902, 59.249166519411155, 55.532089279543975, 57.1446737166374, 56.30582778684555, 57.990321036308046, 54.99529330961166, 60.31310158391153, 49.92483362074822, 51.586843844383, 59.0364367731156, 57.830617812372026, 51.51445650285291, 40.844770246936434, 40.47363165886172, 40.66929517253753, 40.844891840411776, 41.92530085963588, 42.50061058229016, 39.8167170247724, 39.13415008975614, 42.114543453339614, 42.4617555833632, 43.577642440795906, 41.37090129237021, 44.09527763243645, 41.02028062266689, 42.93022778726394, 40.738960389168035, 40.09476992391771, 42.68221632126839, 43.11592063596172, 43.56171369552613, 44.615085817152455, 49.54457159965269, 51.67448528351323, 54.14587266983525, 52.79025839221094, 53.59025716781617, 53.58144752440914, 53.049754558071015, 55.514242495259936, 56.07933444361533, 55.09280735446561, 49.92545727760562, 40.95255305690151, 41.704997016537575, 40.947375528274044, 39.90480561410227, 42.19205733268492, 41.392964624589496, 44.073747742560606, 53.43934397543631, 47.49404668807984, 41.6042430939213, 42.492620714249156, 41.07683335581134, 42.47407574807444, 40.72905248211276, 40.389418371262096, 40.641261992915986, 42.295447088056996, 49.76767209268386, 51.653735945301676, 55.31590000275643, 54.17215647235994, 54.92159981881419, 54.669336503551854, 54.59619214457851, 55.52972409033007, 52.37726026965726, 51.174924373626716, 53.01757935554751, 44.50530652076968, 39.11237701292961, 40.00328063964844, 39.26114466882522, 40.07185935974121, 38.58344147282262, 42.39973114382836, 39.928296689064275, 42.239788655311834, 39.38260870595133, 43.040717032647905, 42.34881485662153, 45.39141308876776, 45.217279464967795, 48.01048555681783, 47.5024248707679, 44.27828757993637, 41.3674888303203, 42.86181772908857, 41.53807663148449, 41.84604152556389, 38.81768541951334, 41.77473675820136, 40.327542981793805, 46.133486301668235, 55.57133651548817, 56.11627140352803, 55.07778467670564, 56.63550299982871, 56.664195137639204, 57.58440671428558, 52.299958198301255, 52.0449492239183, 57.68163442611695, 61.24424872859832, 61.10338857097011, 56.770628652265, 43.74506096686087, 46.01297932286417, 53.068044570184526, 60.90319471974527, 61.309673863072554, 61.51122485437701, 6.538198349937317, 0.5990225341050857, 3.3089734998441513, 1.4433445829537608, 9.723864543822504, 62.06240807810138, 58.514683092794115, 62.91158945329728, 63.02692674821424, 68.15858717887633, 58.742223708860344, 48.299411266080796, 26.712009637586533, 38.547669456851104, 61.68717453556677, 9.547394167992378, 0.3625853696177083, 0.09765728797403075, 0.04123130790709008, 0.05922290579145474, 0.04136513963702225, 0.055869060959066116, 0.08771284618565152, 0.08978067837174862, 0.1286372860833522, 0.13004391544288205, 0.181201811459276, 0.1832597840937876, 0.12966024328864392, 0.15169705354398297, 0.251485031218298, 0.14340274216186616, 0.10136729857373623, 0.12087449416398041, 0.32669715342983124, 0.17214462972216069, 41.29463864910988, 75.78925240424373, 45.338406178259085, 32.16117024421692, 43.91439360956992, 68.99860981971987, 67.91645926813926, 72.39550790479107, 69.30231109742196, 67.9781424614691, 63.759099898799775, 69.2674804502918, 22.733063197905018, 3.217784767189334, 10.466478063214211, 12.63229908481721, 12.108315537052771, 0.4021430856758549, 15.28680722559652, 67.05209439800632, 52.624357823402654, 60.912498581794004, 60.700125771184126, 63.02544016991893, 63.036328669517275, 62.80769371217298, 57.401031986359634, 60.1290169069844, 59.64052884809433, 61.85434987468105, 57.365373719123106, 61.84395559372441, 52.16252619220365, 54.32040637539279, 61.011852218258774, 62.0988468970022, 51.36830899023241, 42.9414261541059, 41.73506198390838, 43.13373604128438, 43.62080420217207, 44.2566204071045, 45.30183007640224, 42.70593489370039, 39.72196040614959, 43.72800257898147, 44.33817040535712, 47.79974052982946, 44.30942727673439, 45.631093440517304, 43.632873335192286, 45.281853445114635, 44.32557959710398, 42.45553862664008, 43.62625629671159, 45.3010416799976, 46.86512600991034, 47.21471901862852, 53.393797412995376, 52.761793751870435, 58.41524316418556, 55.82979717562276, 57.394077624044115, 54.76220646212178, 56.827318668365486, 57.08391228029805, 60.63046447692379, 56.7971791759614, 49.633276001099624, 42.69015519849716, 42.31746727420438, 40.03652272685882, 40.714163164938654, 41.04064556860155, 41.14825579427904, 44.31411843146048, 56.96038507646131, 51.23431690277592, 43.76293520773611, 43.335079146969704, 41.09727674914945, 42.70945718211513, 40.0750207901001, 40.27205321096605, 42.63646971794867, 43.82769746165122, 51.942234116215865, 54.451401772037634, 58.185098094324914, 56.081052441750806, 55.66407703584241, 56.904448155433904, 58.1941117009809, 58.688914775848396, 55.07272481918336, 55.480031582616995, 56.441180936751834, 47.01281109163838, 43.732254428248254, 43.115826499077585, 40.374929135845555, 43.00640413838048, 40.565171933943226, 45.94744043965494, 41.45346718449747, 43.90865518200783, 41.600505075147076, 45.3837566221914, 45.968397663485625, 48.654652487847116, 49.98199824363955, 50.1716919099131, 50.4226412311677, 47.54878336383451, 45.931994145916356, 44.08564821366341, 43.31727943112774, 42.64052152633668, 42.18819772043536, 43.278491112493704, 43.441363611528956, 49.42504913576188, 57.076346028235655, 60.2049304592994, 57.49119550951066, 60.06750629794214, 60.338291045158144, 57.84105131703039, 55.89826606935071, 52.71724739382344, 59.2501941803963, 63.446353635480335, 63.59265804290772, 59.45501642842447, 46.16312373069025, 48.54227266004009, 54.800567242407034, 61.53890894305322, 63.32446990474578, 64.90347493079402, 9.836160040670826, 1.0992747617344703, 13.106631309755388, 3.2065864003473714, 11.730629532567917, 66.03268607970207, 65.29457053830548, 64.30689811706543, 71.1904694957118, 71.135524934338, 65.66691329402309, 50.89300793986167, 39.97933064737628, 48.6105768142208, 69.79635715484619, 14.587234854698183, 0.5433099236219161, 0.200449678626272, 0.2828739517398419, 0.19308490768796016, 0.1235040296770392, 0.22470051362629861, 0.16457681484039755, 0.23545032066683616], [0.06726330882238765, 0.08347657914724081, 0.05387469660490752, 0.09321391672617005, 0.03459712820908716, 0.028314923777455286, 0.05628290548620205, 0.07489336834799859, 0.06404511900919099, 0.06979471613322535, 0.09444685863150705, 0.10641057029246323, 8.738196453740521, 56.389425262328125, 33.77795357857981, 21.060548866948775, 28.62233138853504, 48.597801654569565, 60.279133858219275, 59.903213900904504, 57.76203909227925, 54.709211318723625, 54.96010572679582, 58.521390345788774, 41.882798056448664, 0.22632820531725886, 0.5184721886630982, 2.3184924164126, 4.025044830576066, 0.35178273315391234, 14.326495297493475, 48.794316322572776, 49.954878976268155, 57.33594809809039, 57.602896767277876, 57.73393923236478, 55.46706422682732, 59.518888304310465, 53.69825963051089, 57.82620514592817, 55.79331521065005, 55.77600971344979, 53.10138863901938, 55.06443292863908, 48.32998221920383, 57.496588768497595, 55.89917605923068, 53.403603338426166, 42.80096607823526, 39.02328037446545, 39.4943727216413, 40.69008765682098, 37.679315536252915, 38.4397062178581, 38.002789481993645, 38.8372855032644, 39.561857100455995, 39.46732797930318, 40.069443179715066, 40.90459815917477, 40.11827276599023, 41.26352640890306, 39.532117689809496, 41.752332179777085, 40.70753435934744, 39.801823785228116, 40.60580768892842, 38.17650733455535, 38.60542635763846, 41.82065986817883, 47.53339198327834, 48.510281808914684, 49.63891636940741, 50.040182682775686, 51.40965077184862, 50.634625727130526, 51.815137555522305, 52.90968671921761, 53.43597858182846, 51.91092967987061, 47.38718955747543, 42.49485646524737, 41.12272508682744, 43.3803903672003, 41.068784652217744, 41.46505778835666, 41.25930201622748, 42.151056797273704, 51.91405973126812, 48.747934295285134, 42.44157498882663, 41.41606738490444, 42.26735899525304, 45.44365513709284, 41.91070964259487, 41.53800210645122, 40.82466809980331, 41.81735723249374, 47.374469311006614, 52.45203241225212, 54.0104018488238, 52.97627287526285, 51.89653065896804, 53.216765157638065, 52.307367555556766, 51.52765920085292, 52.92184998912197, 50.298855150899584, 49.41001076852122, 49.37517227665071, 36.42689097312189, 37.72352064809492, 37.30102646735407, 36.76274391912645, 35.071362987641365, 39.194774243139456, 38.04602969077326, 38.94248347128592, 37.785729439027854, 40.92376285983671, 40.19563759526899, 41.5451604320157, 40.47090168922178, 43.732623131044456, 42.419170410402366, 41.04798040082378, 39.82507951797978, 37.21327127948884, 38.554529682282485, 38.00866519251178, 38.51754173155754, 41.88499850611533, 40.00667741221767, 41.482355440816576, 40.74551859209615, 50.21963504052932, 54.397131858333466, 55.446424714980594, 53.87508792261924, 54.96731504317253, 55.155490752189394, 58.481856776822, 52.40791751492409, 56.47811397429436, 57.92846133632045, 57.29584186307846, 47.50843786424207, 43.50169358714935, 47.44942580499957, 58.83496422921458, 59.193986615827015, 57.05551432025049, 3.6698952942125262, 1.1089049159519135, 0.2748194258780249, 0.32556772532482303, 18.70426735570354, 55.97976507679109, 51.178960492534024, 56.43348916884392, 58.90921469657653, 63.343866025247884, 44.75945257371472, 39.75545744742117, 27.415286687112626, 44.31409489723944, 45.724579211204286, 0.7138876737125459, 0.16574520617723465, 0.08610208503781788, 0.0770831004446072, 0.06300104459026648, 0.05062081092487901, 0.026909501006406163, 0.017114668528759674, 0.055845047933079546, 0.1019488129344198, 0.00724441469496777, 0.033628946290381496, 0.019343438550769802, 0.06938013999212174, 0.02357644396984289, 0.08956219009574383, 0.0500869165895687, 0.053031532574565186, 0.05172857406338857, 0.09187441199056565, 0.1920357962409335, 14.37595638536638, 65.8507900853311, 39.051297864606305, 18.902486293546616, 36.27342824013003, 56.815359361710094, 67.07049031411448, 66.11565989832725, 62.79909587675526, 61.26861449210875, 60.40075086778211, 65.01962023396646, 44.787607346811605, 0.12357264051153777, 1.1530116008174036, 3.6129946958634163, 5.674508617770288, 0.4392792590923848, 16.033950101944708, 51.65258669084119, 50.19821889938847, 57.88602129105599, 59.04269687591061, 60.655650015800234, 59.7549992992032, 61.93481337639594, 56.35118215314804, 59.61172296154884, 58.74385541485202, 59.855517879609145, 55.59962857154108, 58.81727826210761, 49.05204742185531, 58.67664167957922, 56.91978854517783, 57.009755949820246, 45.010527410814845, 43.11519107510967, 42.187421091141246, 42.84536338621571, 40.677755724999216, 41.1347157724442, 38.55143493221652, 40.0614611564144, 40.8252799895502, 42.526753179488644, 41.84925786910519, 43.438304162794545, 42.23696062641759, 43.93555871901974, 40.25069198300762, 42.39929183836907, 43.83118837110458, 39.55112941803471, 40.51378496231572, 40.75879581512944, 40.26908789911578, 46.512069548330004, 48.21623740657684, 52.15432451617334, 53.050448817591516, 52.925419345978774, 54.10544872283936, 53.218796945387325, 52.57803070929743, 56.74681986531904, 54.55121040344239, 54.06188295733545, 49.2393131409922, 42.81186634494413, 40.70321190741755, 42.3033663534349, 42.287245412026685, 42.537253364439934, 41.140536569779925, 42.67128859796832, 52.94931442506852, 49.63435465289701, 42.23201059526013, 42.83542802256923, 40.99478913891701, 44.616031108363984, 40.103901201678866, 40.87275635811591, 41.34195027812835, 42.556182722891535, 48.53563208733836, 54.4492523131832, 54.761790690883515, 54.85115797288957, 52.28873237486809, 54.52364790824152, 54.8939549538397, 54.96573040562292, 55.28522706800892, 52.63331259450605, 52.07112712244834, 50.43886023183023, 37.85781868042485, 40.7720063578698, 39.58809775690879, 40.3193256162828, 38.17530316691245, 40.32833922293879, 39.02705369457122, 41.72491873464277, 38.94723346156459, 43.45302089568108, 42.56398431716427, 44.89679436529837, 42.72247160634687, 45.94961735510057, 44.09546198383455, 43.31161160622874, 42.486191949536725, 40.110604532303356, 40.961703946513516, 40.12992220540201, 40.15550390366585, 42.35435324330484, 42.371772489240094, 42.353866869403475, 44.39378961440056, 54.226069450378425, 56.64091979303668, 57.55091359538417, 56.01279143364199, 57.35359876386581, 58.967697235845755, 59.93271012460033, 54.04787225107993, 57.63339711773781, 60.46307340745003, 60.50716869292721, 50.10256798036637, 45.65582790682393, 51.57580237234793, 62.26676356407904, 60.25562709377658, 60.51726095138058, 4.444098847527658, 1.8747572528739131, 0.7595574230917039, 0.36930037542216243, 22.949933005917458, 60.21166909125544, 57.170373086006414, 63.11636463288338, 65.13868378054711, 68.40222127975957, 50.29291276008853, 50.81530578674809, 25.963762614034838, 48.70285057252454, 52.433593350072066, 1.64673320468395, 0.21487041046061825, 0.05538259895758764, 0.03697271706656583, 0.04879529234923182, 0.11156192169554772, 0.0280168293900187, 0.0031633063166913006, 0.013879987715382971, 0.21373261667547688, 0.17863587656569097, 0.15085253353801467, 0.16986309730958554, 0.1190541236991844, 0.19416418767744498, 0.2042701897481757, 0.1308322965257591, 0.10914945719583381, 0.17480657075441655, 0.29276475971264226, 0.3385990034909018, 16.185731118725194, 77.18480033259239, 45.06391479123024, 30.151171261264434, 40.426363175915135, 64.78571753348074, 73.80830641715758, 71.13055921369984, 67.2049726978425, 66.11893115505096, 65.74766705113073, 69.2216593219388, 52.53304504579114, 0.34009881978554113, 4.966771833358273, 8.129369097371256, 9.207950292095061, 0.9665390584738025, 19.04801603286497, 54.74045691951629, 50.479633269771455, 58.337968549420765, 61.361892377176595, 63.18341755097913, 61.717349329302394, 64.54952024644422, 57.197500198118156, 64.58439403964628, 60.48147716829854, 62.43023618575066, 57.17800994073191, 59.18712246802546, 50.759674810594134, 60.9906949535493, 60.67319869995118, 56.97161482226465, 46.91406150018015, 44.65383883445494, 44.004788552561116, 46.42450263423305, 42.42504219855032, 43.69052825435516, 40.241592084207845, 44.0459499051494, 44.10398529421899, 45.073246109870176, 44.77933506811819, 44.52363183421474, 44.706367215802594, 45.63645139817269, 41.99031806761219, 45.05418339083272, 46.17033304706697, 42.87904477888539, 43.03986195595034, 43.43763343749508, 43.80888969667497, 48.00598659823018, 50.37338018417359, 54.80225386158113, 55.199146732207275, 55.630678053825136, 56.57575745736399, 56.392975007334066, 56.70167338463568, 58.501492161904615, 58.1648115957937, 56.12202944294099, 50.026870158410844, 42.18604041684059, 40.2567873462554, 44.6795735051555, 41.559822251719815, 41.93935863433346, 42.94486607274702, 44.59256356762302, 56.41670534687658, 51.76640602850145, 43.96766724125032, 42.78335463616156, 41.871172151257916, 46.580134437930205, 41.982743970809445, 41.491145472372736, 40.50458308189146, 42.754858616859686, 49.43292917743806, 55.68629334049841, 58.03217664841683, 56.641602285446666, 55.05539186539189, 58.39987531785042, 57.77157829653833, 57.24238387999996, 57.55249038819344, 55.89295125776722, 52.49866154886062, 54.72066463962678, 38.91705866782896, 42.42590119761806, 42.51046749853319, 41.36115420249201, 38.66723506681381, 42.36489265195785, 42.66020005749118, 42.81748317903088, 41.744220718260735, 45.93093510596983, 44.03232751354095, 48.11576981698313, 44.75457706759053, 48.763117790222175, 47.92861784658125, 47.11015255220475, 47.05819291453208, 40.63606485243767, 44.371534086042836, 41.89618118347661, 41.62534544544835, 46.20352414346511, 44.38548987911594, 44.67000684430523, 46.840713177957845, 54.673254951354004, 59.36609237424789, 61.37319272564304, 58.592483305162006, 59.27211630728937, 59.86999142554499, 62.35487568762995, 52.65643888904203, 57.54946231842042, 64.4620317797507, 63.8264116933269, 51.788108502664876, 49.040311690299745, 52.52784006057247, 65.62521849909137, 64.36763994155392, 63.12872009892618, 6.806658112233685, 1.9203442647572488, 2.798607195577314, 1.1789164043241933, 27.266440583813576, 66.50775571023264, 62.80663467222645, 67.07638955885365, 69.32651996612549, 71.82787818293419, 57.59486375316497, 50.93058816848263, 39.405523192497995, 56.97221494490101, 65.22248129690847, 3.684822854495818, 0.47838706703435996, 0.218733991045625, 0.1590762422570298, 0.14024282865706952, 0.27806855798248326, 0.12515854976710775, 0.10947455426738148, 0.21230920999040528], [0.10661158410291519, 0.0372212857849175, 0.08036641539224694, 0.057028592489058935, 0.013754879811688537, 0.04966989279754701, 0.055278522082634514, 0.031193744301074938, 0.16815697353693748, 0.028285151685497938, 0.023302954411314383, 0.022241217835295587, 1.4039264787589352, 48.213405455312426, 44.1406516105898, 35.98702069251768, 33.466470318455855, 40.04401445388794, 59.32822189023418, 59.489509751719815, 56.26121082613545, 56.38572646725563, 53.93415881741432, 39.814324378967285, 57.74111716978012, 2.9384173837400254, 0.7193031186057676, 1.6202226401336732, 11.83885851214009, 0.41136044107617875, 15.632897557750827, 60.88872901854977, 50.5053993194334, 60.67091980288106, 57.19518992208666, 61.24464096561555, 58.059476344816154, 57.416678320977, 55.7218143247789, 58.27423787886097, 55.22010787840813, 55.41320223962107, 49.34390314163701, 52.45748058442147, 57.663603290434814, 57.51029745224984, 55.83106802355859, 49.751566840756325, 38.01545089290988, 40.807939191018384, 37.70699570255895, 41.0146245648784, 39.500977993011475, 38.392531871795654, 39.70256428564749, 41.16100741970924, 39.2886051824016, 42.4826814282325, 38.38540884756273, 41.02612887659381, 40.23106052029518, 39.982778410757746, 38.918247145991174, 41.45519694974346, 40.00799532859556, 40.772657471318404, 37.78368588416807, 37.619393487130445, 38.79122511033089, 42.20846852948589, 50.749280529637495, 49.51210614173643, 49.29154342220676, 51.25731375909621, 48.49829112329791, 50.66785604723039, 51.59625753279656, 51.33977766959898, 51.5577280905939, 51.35949150208504, 44.63512520636282, 43.99882262752902, 41.77648613529821, 43.26528449212351, 41.23728575245027, 41.65492403891779, 40.92386091909101, 44.18917525199152, 48.985080795903365, 50.42267653249925, 42.17534411338068, 41.22768771263861, 41.405465218328665, 43.83668753408617, 43.0060197461036, 42.0898639002154, 41.45980181232576, 41.91708741649505, 44.856652828954886, 52.47593925845239, 52.35230615062099, 51.44810568901801, 53.252388123543035, 52.08901705280427, 51.13819529933315, 51.49969270152431, 49.1453488411442, 50.660301562278505, 48.92278179045647, 49.093047957266535, 39.396321312073745, 36.9038119623738, 36.446800924116566, 34.660918328069876, 36.937646327480195, 38.99669062706732, 37.72440318138369, 38.83572832230599, 39.72704772026309, 39.46036969461749, 39.80052940307125, 41.25754871676045, 42.6874291512274, 40.21565345025832, 40.430607180441584, 38.50084420173399, 37.28415635324294, 39.11655433716313, 37.55233272429436, 38.43728219309161, 38.5961538745511, 39.47482755107265, 38.19899428275324, 40.750390175850164, 40.11706859834733, 39.72930700548234, 40.784565787161554, 44.8469175061872, 46.750431983701645, 50.85425100018902, 53.64021639670096, 54.568821845516084, 57.56750522121307, 42.73917698091076, 49.50504979779644, 60.454067645534394, 50.83267404187111, 46.5221578844132, 48.18469370565107, 59.37990303962462, 60.91530307646721, 48.16474845332485, 1.3317308430710149, 4.518956301673766, 1.315859830187213, 0.02333867134556415, 30.169512264190185, 57.50160547994799, 53.838366693066014, 57.82287897602205, 50.70206303750315, 55.14911297828921, 42.51597450625512, 33.89128261996854, 28.196864051203576, 54.905843657831994, 27.073244240976152, 0.2276545639840826, 0.04841239011335758, 0.022664749544234048, 0.033491364560059966, 0.049985827457520275, 0.03387936894150992, 0.04133312865310619, 0.06852264245671612, 0.11015821879188861, 0.05951521813028282, 0.030742882405437773, 0.06585743788990282, 0.05865803852136578, 0.04675164172846464, 0.06825494069245554, 0.04577417482411669, 0.03505324163744527, 0.068661970867505, 0.0869403767489618, 0.07609764324320901, 0.1692581789628152, 2.974049910422295, 57.0815392463438, 46.907354247185495, 29.236170553391982, 39.72771844556255, 49.70618109549246, 66.40771173661756, 64.94354194210422, 63.57323446581441, 62.20215036023048, 60.01616639475669, 46.71333812898206, 63.216388994647616, 2.915966472318096, 1.1397886780961868, 3.640269632301023, 16.02772137811107, 0.9677659636062961, 19.02443474338901, 60.69685059209024, 51.38923875747189, 62.241260313218646, 59.14631020638251, 63.0573368841602, 60.220659163690385, 59.572977788986705, 56.23128314172068, 59.45812686797112, 56.85862310471074, 57.268102861219845, 52.1590195932696, 55.51833352734966, 58.942735272069136, 58.763977173836004, 55.85719885364656, 54.24587349737845, 39.580402066630704, 42.15713254867062, 40.58921214072935, 42.65193170116794, 40.24254129778954, 42.76011459289059, 42.218109715369444, 43.32863469277659, 40.42719864076184, 44.53748172329318, 41.271967349513886, 43.03264871720345, 41.63914826608474, 43.64807644198018, 41.596657230008034, 42.36522997579267, 40.78378523549726, 41.84389206670946, 40.45185858203519, 39.97713412007978, 41.058712005615234, 44.04607149862474, 51.79291732849614, 51.331085697297134, 51.96053589543989, 54.515830624488096, 51.1131941118548, 53.36996901419855, 54.4028232174535, 54.48990768001926, 53.869741732074374, 52.82383780325613, 45.4732298081921, 42.53706509067167, 41.901837241265085, 42.54692592928487, 42.28694731189359, 42.47544465526458, 40.639512615819136, 44.780460788357644, 49.71046432372063, 52.57240210810016, 42.975091857294885, 41.39846378757108, 42.80870883695541, 42.845979198332756, 42.199121521365264, 42.56344303008049, 41.91685599665488, 42.34818727739396, 46.36159173903927, 53.020117129049, 55.80021465978315, 54.95144121108517, 55.22627776668918, 54.57918474751135, 55.128140064977835, 54.610908877465036, 50.538747310638435, 54.12302094121134, 53.65893002479307, 52.29472183412122, 42.13111546731765, 39.21240137469384, 38.37053521986931, 37.76103419642295, 38.30873043306413, 41.17101730838899, 39.4975027730388, 40.541978959114324, 42.34284893158944, 41.33366230995425, 40.3592239656756, 43.042744898026996, 44.686147397564305, 43.018665467539144, 43.10999001226118, 40.81315594334757, 39.317862141516905, 40.55838231117495, 39.26078773313953, 41.903637609174176, 40.097052743358, 42.24862183293989, 42.24896307914488, 41.650138747307565, 42.202683033481726, 42.01304035802042, 43.888192176818855, 47.7583203008098, 49.57206349219046, 54.21472987821026, 55.38110940687118, 57.36682499608686, 58.352520542760054, 45.30813332526915, 52.626013063615375, 63.53819985543529, 55.29376999024422, 47.9091432786757, 50.660980132318315, 63.688603139692745, 63.883588083328746, 51.595512282463815, 2.095029594436769, 6.325540677193673, 2.3060278594493866, 0.023315878314596993, 36.35762191587879, 62.108354722299886, 59.78630765791863, 61.571566597107925, 62.88437212667158, 60.83566719485868, 48.73982675613896, 40.11065160074542, 28.215297229828376, 61.539811088192856, 34.72160916174612, 0.2621490057677992, 0.07904658379453806, 0.08823262152051733, 0.031849931166957945, 0.04416383885508103, 0.02129134924841985, 0.04718258150763089, 0.014560582142533555, 0.07524423661731905, 0.14759128192259421, 0.10807121142504678, 0.1771923370899693, 0.14643265054591242, 0.25728686021700986, 0.2062110428608233, 0.14838539334314485, 0.17297627945100108, 0.2078976773566777, 0.323391484036561, 0.21443686598250944, 0.1277137900732698, 3.211711467273774, 66.57616184603783, 56.102574486886304, 47.28219555270287, 45.810333990281634, 54.71309054282404, 73.67911923316218, 70.22989672999229, 68.53886881182271, 66.41510932676255, 68.73236717716341, 53.959560086650235, 68.405304262715, 4.4019220913610155, 4.622180827202336, 12.133358890010465, 19.13546527585676, 1.6481625408895555, 22.320657353247366, 63.068080256062174, 51.24441700596964, 64.76837281257876, 60.73779229194888, 65.19281248892507, 62.231991752501465, 59.853521393191436, 57.772727550998816, 61.865552163893184, 58.347225343027425, 58.85326208606843, 53.838951126221694, 56.33270778963643, 61.8245045600399, 63.18025612062024, 59.989105962937884, 56.73784548236478, 40.07391468171151, 44.75732272671115, 42.843625776229366, 45.672395998431796, 43.42130461046773, 43.63541895343412, 44.668747763479914, 46.51917688308224, 43.45975168289677, 48.11744466904671, 42.80912068582351, 44.92698092614451, 43.074163083107244, 44.209226408312404, 42.61614399571573, 45.789765081098004, 43.48353693562169, 44.39537425195017, 42.128185456798924, 41.27599170131069, 42.3512428037582, 47.0648491767145, 56.348083480711914, 53.0013446654043, 53.41262478982249, 56.78288998142366, 54.04278493696644, 56.22431701229465, 57.26247426002257, 57.34546376812843, 55.03437188363845, 55.16576343967069, 45.89512778866676, 43.17033175499209, 41.61388427980485, 43.47409186824676, 42.84123313042426, 42.54561585764731, 42.31697305556267, 47.28777316308791, 53.21869104139267, 54.13856137183405, 43.1521947153153, 42.86240608461442, 42.401237333974535, 44.51737957616007, 42.90499517994542, 43.43056924881474, 40.017648281589636, 43.48784762044107, 45.45579879514633, 54.183566647191206, 58.5401314304721, 57.29340607120145, 58.01479270381313, 56.16430082628804, 56.073780367451334, 57.01195247711674, 53.03097424968597, 56.682234118061686, 54.71274929661905, 53.123451971238666, 44.83171047702913, 42.67667008984474, 41.58569812774658, 39.64498781388806, 41.21321808907294, 43.73067371306881, 41.4500625671879, 42.62791895097302, 43.736886747421764, 43.36152768904164, 44.33798605395902, 46.129140315517304, 47.33213909210698, 45.22650880198325, 45.00361619457122, 43.81674620413011, 42.629617337257635, 42.49434655712497, 41.614676598579656, 45.129779231163766, 41.77267751386089, 45.10488787005025, 42.52317990026167, 44.94507874211958, 44.368502093899636, 44.49351979840187, 45.90498078253962, 50.717426961468114, 50.62246637959635, 56.27952829484017, 56.52231908613636, 60.114347242539935, 60.729920095013036, 46.33600219603508, 54.8815877206864, 66.32481636539583, 56.56223312500985, 52.82960760977961, 52.993397943435184, 67.33908637877434, 64.82648272668162, 57.098021045807876, 3.026818536943005, 7.66823172569275, 5.5311459879721365, 0.1633941742681688, 43.16844117256903, 67.77963915178853, 65.57973861694336, 65.31360187838155, 65.80070534060079, 64.66326113670104, 55.0510262673901, 45.623852745179214, 38.39511671373921, 66.9582320797828, 42.849493642007154, 0.5499831010257045, 0.16102820364457948, 0.20684611442829334, 0.14015567849480337, 0.18363196492916156, 0.19254188924547166, 0.15073120053256714, 0.16761360269400383, 0.2826287423170382], [0.075487308654814, 0.05250522634014488, 0.05425201405981376, 0.06415804419966956, 0.06437210065703239, 0.056077375587436466, 0.02133087363965329, 0.07516640208421216, 0.02278086932135686, 0.05172118131491927, 0.018347160357441154, 0.10181955857983521, 0.12614504884808295, 27.009678309963597, 57.14891772116385, 26.862907140485703, 19.52684525520571, 36.571100834877264, 52.913652235461825, 58.37649406925325, 61.663416739433046, 56.65063942632368, 57.92707673964962, 51.25580756895004, 60.04646670433783, 10.705061131908048, 1.7924816161394121, 2.126289168673177, 3.228857373037646, 1.7960181231460266, 24.89602088928223, 60.584686494642696, 58.16001845944313, 63.005855775648556, 56.171031613503736, 60.57753601381856, 56.93048484863774, 59.409226679032855, 53.97084866800616, 59.18887968986266, 56.101233036287375, 56.81910914759482, 58.68333716546336, 59.767217482289965, 55.080498956864886, 53.89892024378623, 51.39504778769709, 39.94884598639704, 39.65228734477874, 40.85071656011766, 41.73672114649127, 41.242835906244096, 38.53596902662708, 40.06983933910247, 38.14135897544123, 41.86776361157818, 39.13344014075495, 43.32481038185858, 42.240267184472856, 41.79456041705224, 40.37467418178436, 40.90194271456811, 40.095366124183904, 42.12834627397599, 39.80824862757037, 39.85415604806716, 36.92765605065131, 38.57406700811079, 36.94134904492286, 43.37528736360612, 48.1374095332238, 48.79041748662149, 50.69697180101949, 51.34125640315395, 52.08349827797183, 51.18873896137361, 52.77326276225429, 53.135721145137666, 51.41320443922474, 49.92413936122772, 44.353632388576386, 41.78189116139566, 43.9299967981154, 41.16253322170627, 39.463303627506384, 41.09663740281136, 40.748052443227465, 44.00529453831334, 47.41395973390149, 48.3569210575473, 44.296028460225756, 40.880981568367254, 41.7407690325091, 42.79174066358998, 41.02346950961698, 43.820821546739154, 42.68544835429038, 42.33735369097802, 43.49269959234422, 49.12903962596771, 52.36047252531975, 52.16630735704976, 51.46295186012022, 51.244797475876354, 48.77730108076527, 50.54515254112982, 50.983116549830285, 50.565097793456054, 48.75231166039744, 49.15292293794694, 42.861754971165816, 36.48854670986053, 36.87417453335178, 36.92162344532628, 37.49431694707563, 38.575941901053156, 40.66770269024757, 37.95135936429424, 40.360290850362475, 38.86573053175403, 40.19466484746626, 36.21676568062075, 38.32671842267437, 39.65306005170269, 39.748557998288064, 38.44372272491455, 38.521550393873646, 38.29140140164284, 40.04863108358076, 38.39421064622941, 38.25313475824172, 38.90205167954968, 39.97331765390212, 38.20656837955598, 38.92129874998523, 41.48592872004355, 40.580932017295595, 41.64554957420596, 42.78950491259175, 48.12612879660822, 53.22033843686504, 54.100792869444824, 55.345733550287065, 46.76883966692033, 53.70493942691434, 58.947355824132124, 52.96143847127115, 51.07543737657609, 50.53396594139838, 59.706989488294056, 59.695124318522794, 41.10823192904073, 2.355078814491149, 2.0340133266102884, 0.9042364370919044, 1.1154156827157544, 38.49206593728835, 52.912652031067886, 52.02545112179172, 58.129004278490626, 44.69389015628446, 47.20572110145323, 38.97883207567277, 32.21401829873362, 33.68186335409842, 49.44170744188371, 11.713745690161183, 0.5268621384616822, 0.1479807610232984, 0.061502829419388894, 0.11944686633444603, 0.03464292877564027, 0.05236047019641246, 0.024213472891959454, 0.017185820859947035, 0.019574624734119545, 0.02331288674125268, 0.033321557341203574, 0.042493759519270355, 0.06989160327300911, 0.0005575153397418739, 0.04673559601689058, 0.04927797370680398, 0.014320671175336166, 0.03331323379590627, 0.04707250233379103, 0.007967010371371984, 0.10189809791383245, 0.0042682981321347825, 35.55139049406975, 63.072818479230335, 31.607304119294692, 30.700546272339363, 44.0664521340401, 58.62750614843061, 67.04341811518516, 65.00373463476858, 61.856056105706, 62.843265687265706, 53.53979195317915, 66.34019990121165, 13.614206602496486, 1.8564650344271816, 4.051987100993434, 4.489059015627831, 1.5873643323298425, 27.760884761810306, 62.69853022790725, 59.34726891979095, 65.70331681159236, 59.85404306842435, 61.02077953277096, 59.341840359472464, 60.130621156384876, 57.53266280697238, 61.07036613648938, 58.35603890880462, 59.686420579110425, 59.19421411329701, 61.89041606841549, 58.68598476532967, 56.847040345591886, 55.986276211277136, 43.363743828188994, 41.12957746751847, 43.116022617586204, 44.048397464136926, 43.409796376382154, 41.86342547016759, 41.5540720570472, 40.15812404694096, 44.386741115200905, 41.90362976443383, 46.00759783098775, 43.684738835980816, 43.49490788675124, 41.23999218786917, 41.747766540896514, 41.535127009114916, 42.76658258130474, 42.60980152314709, 41.57951254998484, 37.6267243969825, 38.71692365215671, 39.417431508341146, 43.481964065182595, 50.06903563776324, 50.35691015182003, 53.90244253220097, 53.659353640771684, 54.06263605240853, 53.37615851433047, 55.46214165226106, 55.59499625236758, 52.60021955736222, 50.013035958813084, 44.31604039284491, 42.158846624435924, 41.72258884676042, 41.05649194409771, 40.116684206070445, 40.14689430113762, 40.22913855891074, 46.15661651857438, 50.0572253811744, 50.84366844546411, 44.72004452059346, 42.191061050661155, 42.863272928422504, 43.51315475279286, 41.657218625468595, 43.142820250603464, 43.061752703882036, 40.60621953779652, 43.85741333807669, 50.628153816346206, 53.75558114820912, 52.767163476636334, 52.16498551830169, 53.417708181565814, 52.077312700210086, 52.191669402583955, 53.15892196470692, 53.20918713846515, 51.49698234373524, 52.37013332305416, 44.88520376143917, 39.71330373517929, 38.67929243272351, 39.263074474949995, 38.398639002153956, 39.34543640382829, 42.02603909277147, 39.56714445544828, 41.39478852671962, 41.46077063775832, 41.519837610183224, 41.54577624413275, 41.15560239361179, 41.54886314945836, 42.80715950073735, 40.133656301806056, 40.839118111518125, 40.02964288957658, 40.87731807462631, 40.29095119045627, 41.37961287652293, 40.50053911824381, 41.84056981917351, 39.68422328272174, 40.857412046001805, 43.31676167826499, 41.994526770807084, 42.46250867843628, 45.367874945363695, 50.1377163394805, 54.17685547182637, 55.80878503860966, 57.45641585319274, 50.02857246706563, 54.395578599745235, 61.09370031664449, 57.01093658324211, 53.2297952713505, 51.41108635933169, 62.12902169073782, 60.55549621582032, 45.36943997106245, 2.9935053567732535, 2.1941812288376594, 1.5029787055907713, 1.629683887285571, 45.004055500030525, 55.97048474896339, 59.109498762315326, 61.320562362670906, 50.76266365666544, 50.695708797824004, 50.52682330531459, 33.337287056830625, 32.35290550416516, 58.59635468452208, 14.9807309527551, 0.42780672470408104, 0.1521506235604325, 0.03454716395466559, 0.13074939049059345, 0.048702396527533574, 0.020991760989530914, 0.029051955901987614, 0.12430164978028306, 0.03841582370261031, 0.12164023734869496, 0.16994808710390524, 0.21636365372086727, 0.12489362124113307, 0.13660265463254145, 0.12092658814283148, 0.15107263059866044, 0.11931794139766887, 0.12342610321338139, 0.1556148425105118, 0.08801785643182455, 0.26640673858984826, 0.1928980894867451, 40.563677510907574, 73.36791838369062, 37.35798320462627, 29.75916370268791, 49.81204978881344, 65.79046403208088, 71.05812088135751, 72.2286267434397, 64.47427741942867, 69.42965476743638, 60.599756240844734, 70.58993108810918, 15.059622564623433, 3.3940808426949287, 11.327591288474299, 6.465431519093053, 2.9476097033869837, 34.59466165111911, 63.04190235753214, 64.00084341725996, 66.52649679491597, 62.351208271518836, 64.89382982254028, 60.341997684970984, 62.1287275129749, 58.23997597540579, 63.627755411209606, 59.00537552372102, 60.85674208979453, 62.913456501499304, 64.50512293846377, 61.29980517971901, 59.74816653036303, 57.461805189809496, 43.76048764874859, 43.82478314061319, 46.454002780299035, 45.70077042425833, 46.176149922032515, 46.477572302664484, 45.28913728652462, 41.94328884924612, 46.49761953661519, 44.70155446760116, 48.14014342523391, 47.587803102308705, 46.141668365847686, 45.137059150203584, 43.980720889183786, 45.85486073647776, 46.17636173002182, 45.54269498394382, 43.6357758891198, 40.94593994079098, 39.90906923047958, 41.602646689261164, 46.52257757802164, 53.84170855245283, 50.44229622810118, 54.31878643651163, 57.26670257506832, 58.553212534996774, 54.77712715825727, 57.75562209467734, 56.85752484106249, 54.332095038506296, 51.45457367743216, 43.97544922367219, 42.18174934387207, 44.37648019483013, 40.43074054102744, 40.19602590991605, 40.324781633192494, 42.13817965599799, 48.37206532878261, 53.25909929890787, 51.67936471200759, 46.04211076613396, 43.22130687775151, 44.469942431296076, 43.99842646814162, 43.524502169701364, 44.246575217093195, 43.17402662769441, 41.48334780047017, 45.164084280690844, 50.73309683030652, 54.67894631047403, 54.761731855330936, 56.00194215774537, 56.25474283772131, 54.64733985162551, 56.33600258058118, 56.125320311515566, 56.39215130959788, 55.354433367329264, 56.17007063281152, 48.175684021365264, 43.023776315873675, 41.8725214465972, 41.37192503098519, 40.377619881783765, 42.53217389506679, 44.53928993594262, 39.69877135369086, 44.7082930995572, 44.43999905740061, 44.99069198485344, 42.138701331230905, 42.89302410617952, 45.11715312157908, 45.3513970682698, 41.54980844066989, 42.22376185078775, 43.81536160745929, 43.33827587866014, 42.90227697741601, 43.11499887897123, 43.72698276273666, 45.15427443288988, 41.680839138646284, 43.63451288592431, 46.25078478167134, 44.657212072803134, 45.73780152105516, 48.960385553298465, 54.04993934016074, 58.582340055896395, 59.3198319404356, 59.72138458682645, 49.55657013000981, 55.689086068061094, 65.82178023553664, 57.490830729084635, 56.31605340588478, 54.53667802195395, 66.7336920768984, 61.992950747090006, 49.228969850847804, 6.302204535853479, 4.122820938787153, 2.61679700305385, 1.674154984854883, 49.7610354423523, 62.075657844543464, 64.42088611664312, 67.6163116578133, 58.78611895345873, 59.40898349208217, 50.755022879569765, 45.1023304846979, 43.14553453076271, 66.28385113131615, 20.818624919460667, 0.6073654767486357, 0.28425012144350237, 0.14002222597839373, 0.18851713908295478, 0.22658812362820874, 0.17290339384588505, 0.12071682560828426, 0.1863325474363181, 0.16123121694451378], [0.013604900863532339, 0.034091613600931825, 0.030554258151941245, 0.05897687282413245, 0.037075813348975875, 0.030993170991179445, 0.04162832914340881, 0.14925314113497734, 0.02470333632382174, 0.0647954638266275, 0.10096364684643284, 0.0690425556874083, 0.21668176407054549, 9.793568984154733, 57.060797752872595, 27.567543291276504, 24.70763533346115, 31.4242471033527, 50.35932240947601, 57.097397388950476, 53.13491313688217, 57.94952446414579, 60.88144517713978, 52.114383020708644, 56.748537863454516, 21.81616798523934, 0.7138475919923475, 0.1847854175514752, 2.9081634071565445, 22.35166172827444, 34.175352434958185, 66.01357629222255, 58.5210177206224, 57.8086603841474, 55.45157086464667, 57.37119059408865, 55.671274585108605, 58.13625281856906, 58.22129764864522, 58.582108636056226, 57.453572134817804, 55.04562516366282, 54.24001739871118, 55.55489393972582, 54.77499338888354, 51.55562177781136, 41.1011089048078, 41.592621111100726, 41.50912561724263, 39.167090154463246, 38.570866354050175, 38.24282676942887, 37.92682886123657, 36.68751285922143, 38.653479314619496, 38.5124465727037, 41.39429430807791, 41.93390653979394, 47.442985273176625, 44.535904930483916, 43.46810240899363, 41.61278209378643, 39.88352675591746, 42.57740666789394, 40.16816531458209, 39.45239943842734, 39.886221424225845, 37.508688511387, 38.4788828511392, 38.974207601239605, 47.42920598676128, 50.67705400528447, 52.65568579396894, 50.48751723381781, 50.54679209186185, 53.31846437146587, 51.81428640119491, 51.26891220769575, 51.03269923117853, 45.7557189080023, 42.073036932176166, 42.96108115103937, 43.65064167207287, 39.83508940665953, 40.43081506606072, 42.040022342435776, 41.99799022366924, 45.76744679481753, 44.527762090006185, 43.07312365501158, 44.82321462323589, 40.86468019793111, 40.965037961159986, 40.50429674886888, 40.139810500606416, 40.934192442124896, 41.22854671170635, 42.24170277195592, 42.8151297569275, 47.63605610016854, 53.86333650158298, 53.33845276986399, 52.858225222556825, 50.95582077580114, 50.853395923491455, 50.258435126273866, 49.99644041061402, 49.77043344128517, 49.39035577158774, 49.734182896152625, 42.66081194723807, 35.10802145927183, 36.7360718019547, 36.35628046527986, 38.47305028669296, 38.254362460105654, 39.29348461089596, 38.29349594731485, 38.977914241052446, 36.269427422554266, 37.74667832159227, 37.2206021893409, 37.161833317049094, 37.862643195736794, 37.68042164464151, 37.73471901493688, 37.669489998971265, 37.10971286219936, 36.969076279670965, 38.63396552301223, 38.35783458525135, 38.93080657528293, 39.87270101424187, 41.620116926008656, 45.703825950622566, 50.45509099960328, 50.37235252318844, 50.401150564993586, 50.97547185036444, 53.53273953160932, 54.03283780620944, 53.479983652791674, 57.0459908054721, 49.557280079011, 51.50771002615652, 59.00978426779471, 56.59253343459099, 54.88461579045942, 54.497595525557, 59.93494195322837, 58.77026473322223, 25.286179050322502, 1.7081059178998395, 0.7843979159670492, 1.1480189138843169, 1.863258456991565, 51.72499364422214, 56.665191419662975, 57.60388912693147, 57.7702643025306, 59.16563572422151, 51.06381931612569, 31.12075959482501, 32.1582833797701, 46.366784957147416, 44.50451812436504, 3.1334545439289463, 0.3300667145559865, 0.06653488944134404, 0.039609584041059985, 0.038290713883696065, 0.05895348799024379, 0.0370564696288878, 0.03818451877563231, 0.04545203102151713, 0.06285920341108596, 0.07774053411858697, 0.03515220487550382, 0.03674783578683292, 0.08470395159336828, 0.037921099442868464, 0.015384489595289192, 0.04309180222692029, 0.07469509713231556, 0.04308700268607467, 0.07325872823956513, 0.024510473688884128, 0.11997034953486536, 0.3324441305331646, 16.38031303882599, 67.1520128557759, 27.719603776931766, 21.262835302660545, 43.84882726976949, 54.801987140409416, 62.99891710281373, 65.72874553741948, 64.07630589700514, 63.644660826652284, 57.30183132233159, 62.772070746268, 23.075839127263716, 1.1386426105614633, 2.9314036955756526, 5.264732232016902, 26.22431585865636, 36.783681531106275, 64.85927374132218, 62.35036496193179, 60.763240629626864, 57.75151145073676, 60.07846932257376, 58.88863402028238, 61.67222638284007, 59.32147149116763, 62.48494540491412, 59.69903099921442, 57.54200981509302, 56.406311065919944, 56.1409862579838, 57.56120589471633, 53.69916962039087, 44.23325484798801, 44.22158579672537, 43.15380680945612, 41.28873940437071, 41.005332469940186, 40.567741086406095, 41.128377222245746, 39.028956044104795, 41.53137330086001, 40.53560118521414, 41.5607165521191, 44.04672653444352, 47.75341341572423, 46.368765754084436, 43.65185368445612, 43.62123958526119, 44.085820797950994, 43.217662995861424, 41.85476095445695, 40.37760811467325, 41.78260111039685, 40.099076686366914, 41.80400940679735, 42.018006078658566, 48.88532707768102, 54.288631254626864, 52.332474647029755, 52.46869071837395, 54.19684779259467, 53.35580533550632, 55.308702453490234, 53.354773752151004, 52.34429667072912, 46.33465290069581, 40.86736702149914, 42.16072936211863, 43.083431643824426, 42.27842792387932, 42.08305858796643, 41.45000373163531, 43.197996231817434, 47.08410801426057, 46.73565249289236, 47.05203871573172, 46.718143032443145, 42.50430937736265, 41.13842633462722, 40.290743304837136, 41.956695510495095, 42.570158127815496, 41.74138092225598, 41.663317911086544, 43.389858968796275, 49.9227822211481, 54.795468161183024, 55.14814807522682, 55.31374269916166, 54.45256279360864, 53.9222308897203, 51.81154074207429, 52.52736545378163, 51.78582568322459, 50.756340795947665, 50.76027101086032, 45.254506680273245, 37.96125942660917, 39.57646792934787, 38.59642059572282, 41.04589369989211, 41.31540367680211, 41.824319439549605, 38.1526554015375, 40.96982325277021, 40.623842746980735, 40.9938830714072, 38.640837515554125, 39.096275683372255, 39.423781825650124, 39.016835920272335, 38.06166425828011, 40.48951333568942, 38.401212076986994, 37.98865325989262, 40.471270392017985, 40.486406818512954, 39.96594359797817, 40.44977972584386, 43.68941822359639, 48.46124041465021, 52.0692483071358, 53.273282589450965, 52.76921487623646, 52.640008080390196, 53.16887694020426, 55.47620727169899, 56.65288694443242, 58.70509847517937, 51.52843190777687, 52.267457439053445, 61.42184188289028, 57.44023215386176, 57.578103465418664, 56.52082858547088, 64.9731715263859, 60.89047447327645, 31.130367440562097, 1.1525803852465846, 2.127020445562178, 0.7725650444626809, 2.4557650762219585, 55.64945836221018, 59.974989352687714, 61.98997759049939, 62.365740653007265, 63.16497064405873, 53.165460555784165, 45.601761956368726, 33.97573909451885, 48.25963058779317, 53.014951367532056, 4.704449109492764, 0.35445543006062513, 0.20887823925623972, 0.07320923129877738, 0.053131694740225235, 0.05847409314986679, 0.04704288154419872, 0.03565662780836706, 0.06133585289541272, 0.03231602097531, 0.11790808680797778, 0.0907013092129942, 0.2457242338888107, 0.1601976111170746, 0.18496722553766545, 0.12963546800517267, 0.15850562932750872, 0.27294431843103906, 0.25198243678577487, 0.28906991765383755, 0.18020723015069964, 0.14243639885417878, 0.4907092542177247, 18.381315085195727, 76.52135495216616, 36.98299284904234, 37.091893534506525, 47.42469918343329, 62.18746108393516, 70.83937029684745, 65.02619412637526, 67.5112235161566, 72.6682459923529, 60.01002396306684, 71.26632029010405, 28.43973917345847, 1.5875034538968917, 5.59805573955659, 7.390114597735867, 33.98574113845825, 41.53198126823672, 63.059054882295676, 66.49985605670561, 62.60003559051022, 62.10397343481741, 61.873718538591945, 61.93174216055102, 63.50760144572105, 63.35023595440773, 65.93453268851003, 63.1515286814782, 59.8556943862669, 59.119700847133515, 59.22837403512771, 60.411862942480276, 56.29086786700834, 45.21822475617932, 47.640786478596354, 44.96201553652364, 42.218839276221495, 44.390157499621, 43.128680106132265, 43.560438925220126, 41.77369733010569, 44.83613098821333, 42.58655363513578, 45.13669044740739, 47.531160154650294, 51.802821313181234, 48.609976691584436, 47.09655369481733, 46.4788313834898, 45.21741674792382, 45.52985314399966, 44.44058741292646, 42.01474658904537, 44.806128778765284, 41.22689147149363, 42.522736672432195, 43.77674195074266, 52.12604814960111, 57.02196628816667, 57.682968031975534, 55.89365336202807, 55.839567799722, 56.50496652049404, 58.17711214865408, 54.917622535459465, 53.83041212635656, 45.254224269620835, 41.495483613783314, 42.105859325778106, 44.46229773183023, 41.860315030620946, 43.248147656840665, 43.820574437418294, 44.28642649804392, 49.46437874147969, 50.00375955335556, 48.05800507145543, 48.796246128697554, 42.71869828624111, 43.33640883045812, 41.12779671146024, 41.844554947268584, 41.14177996112455, 40.71766584150253, 42.20727612895351, 43.04920896407097, 50.496605365507065, 57.01386267139066, 58.078766561323604, 58.85754923666678, 56.875728561032204, 57.78318851224838, 54.053779340559444, 55.14602607296359, 54.44724013728481, 52.9871613748612, 52.388686133969216, 48.918384813493304, 39.95145044019146, 42.44470896259431, 41.94020586629068, 43.034582445698405, 43.075582981109626, 43.059399281778646, 41.01822530069659, 42.73064190341581, 42.63009194404849, 42.8580875550547, 40.65693186175439, 41.7665978400938, 41.697760243569654, 42.89003918247838, 41.29139484897737, 41.15530429347869, 40.54161810105847, 40.58539567455169, 41.75829418243901, 41.29012792341171, 42.69737235961422, 44.076462022719845, 46.67364766520839, 50.90395135264243, 56.52876354032948, 55.19291016363329, 54.610853964282626, 53.761166603334495, 56.5995034863872, 59.554028818684245, 58.826248722691695, 59.22906829464821, 50.81468605226087, 52.97405673611549, 63.678514803609545, 60.045262536694935, 61.59086858072589, 58.3373252807125, 67.74429859653597, 61.94637652366393, 39.2062157969321, 2.244270876530678, 3.119207269722416, 3.3817202285412824, 2.7763521575158645, 65.59779720921671, 65.66976877950853, 68.19402187101304, 66.9382123024233, 68.61515106693392, 61.240067481994636, 43.61166507967057, 44.21496091350433, 58.1266273221662, 61.9590889253924, 6.3431109343805625, 0.5815503974595378, 0.3407241926798898, 0.155544362421478, 0.2563889132392022, 0.19131228748348453, 0.05802933697498614, 0.12474433368732854, 0.14545064840105273, 0.11982421060242962], [0.04329872640570806, 0.02116696529781386, 0.03616099711507559, 0.04477015914275281, 0.1003477044944321, 0.05596867537186031, 0.03736273242881702, 0.1132596874489419, 0.03417385697004295, 0.054616702555288235, 0.027910456166512547, 0.05868719582776389, 0.10842845354589725, 0.43479068865699155, 39.05658521959859, 43.215894006913715, 27.766970319132653, 22.35667451735466, 47.331378152293546, 55.6214879405114, 43.175120968972486, 54.4369831392842, 59.72200039894351, 53.720126844221554, 59.11016556524462, 34.02528647453555, 0.39167991809306607, 2.5315268818409216, 0.2410789984729021, 13.451482172935242, 27.766448643899736, 60.69923931552518, 59.244549889718336, 59.17589664459229, 54.131669767441295, 52.82343379912838, 50.718544836967226, 52.449482871640114, 49.30566787719727, 51.17090394420009, 51.475954517241455, 52.81286301151399, 52.57892108732655, 49.805621024101015, 45.90312157907794, 40.9541690734125, 40.26670309805101, 41.50883928422005, 40.63947339211741, 40.20697324506698, 39.83175146964289, 39.52308447130265, 40.803373552137806, 38.235962621627316, 38.583645436071585, 39.94869693633049, 41.61083659818096, 45.29924131208851, 43.21469376164098, 44.19894195372059, 43.79978979787519, 42.35874237552766, 41.794332919582246, 40.18032858448644, 38.377356221598966, 38.93967897661271, 39.58057465091829, 39.32691497187461, 39.06374746753324, 37.40060760128883, 44.808231169177645, 49.003853259548066, 50.45111763861872, 52.94943994091403, 51.69448544902187, 53.54814660164618, 51.37514568144276, 51.60783636954523, 47.980251927529615, 42.83641253748248, 44.590123853375836, 43.017112208950905, 39.33136686202019, 39.092318011868386, 40.351394914811664, 41.927971993723226, 41.770994817056966, 42.49932012250347, 41.97265955709642, 42.54987947402462, 40.66982077014062, 40.515714768440496, 38.861906220836026, 40.890999301787346, 38.60919183300388, 41.27479145603795, 41.220517619963616, 40.079978665997906, 40.90452755651167, 43.30573981808078, 51.50379157835438, 53.90625115363829, 52.48451748201924, 52.770297450404016, 50.476495373633604, 51.211029791062884, 51.20245941223637, 53.06800142411263, 51.18353397615495, 49.45915414441017, 44.13252053722259, 37.556208026024606, 36.99862741654919, 36.650505296645626, 36.87493939553538, 38.56809323833835, 39.013945133455344, 39.56710523174655, 37.9701239831986, 38.60341418174006, 38.72503511367306, 38.059228466403106, 37.913061341931744, 37.640072222678896, 36.27962166263212, 36.98400874291697, 36.48168256205898, 39.526504778092914, 38.85654826318064, 38.89884318074873, 40.92238610790622, 40.08654471366636, 42.28129909884545, 49.60619987980012, 53.996375453087595, 54.93815222094136, 52.714799834835915, 53.62665676301526, 53.782861232757575, 53.69206228563863, 53.378606073318, 53.62441708964687, 52.30275877060429, 54.349961434641195, 47.84526748041953, 56.87701509844873, 57.78389846124957, 60.86932505330732, 54.89105632228237, 64.91894475875363, 42.46671738163118, 3.9765064802861985, 0.06447644949319863, 0.39483754865584836, 1.2223367969835959, 10.270588032660946, 56.84581656609812, 50.21952913653467, 56.17888419858871, 56.04790449142457, 59.62601215608659, 42.13278639701105, 29.849948921511253, 31.230687941274336, 51.24431894671533, 25.654287607439105, 0.07750748251114162, 0.012453468798118974, 0.023068665571871306, 0.025309897929189668, 0.015294300936793369, 0.07375250255028087, 0.10906167118059051, 0.021346731659685893, 0.03660454287103588, 0.01980864544278912, 0.043147630884402224, 0.05483993674598394, 0.04047510251703282, 0.01722910482766888, 0.08894736623211254, 0.052993243500109644, 0.13793517264627642, 0.07825654796174458, 0.041763336818304755, 0.02514008304945404, 0.04770105066258581, 0.06382068206045417, 0.016119617991329684, 1.671009734272957, 52.67709801273962, 43.597222912696104, 23.563223038950277, 35.021886210287775, 55.64266873944191, 61.51463731642693, 48.82288686690792, 61.7558866162454, 64.74401881617885, 58.58512493871874, 64.74834126810875, 37.356606452695786, 0.35996669723141583, 1.999777041135296, 1.0287207605377322, 17.564497186291604, 31.531973038950277, 59.24592664164882, 62.71663588862266, 63.02822505274127, 56.06754772124752, 54.19279206183649, 53.370357328845614, 55.842780220893125, 53.89455072341427, 54.729003598613126, 55.00185935728012, 55.443106389814815, 56.99793000375071, 52.188582497258345, 48.42261683556342, 46.553070083741225, 43.26008342927502, 43.33802092459894, 41.37849500102382, 42.69091613831059, 43.371749385710686, 41.58605114106209, 41.83435678482056, 39.42901034508982, 42.6971487845144, 42.133315916984316, 44.95422570936142, 45.195992762042636, 47.02811618005076, 46.43860355500252, 44.31838204783779, 44.836472234418316, 43.67426610762074, 41.604890284999726, 40.95291391495736, 41.67867006794099, 41.53143213641259, 39.94427642514629, 41.187891344870295, 39.63982989711147, 48.090588200476866, 50.84453528927219, 55.05320318283574, 53.32736422938686, 52.16234576317572, 55.49787052216069, 53.24289598772603, 53.0374304709896, 47.81686559800179, 43.65365797473539, 42.843555173566266, 43.062058648755475, 40.78634262084961, 39.35491677253477, 42.60280009238951, 42.00554863099129, 43.48787507703228, 45.22299828067903, 45.16632003168906, 45.08123205554101, 43.39218493430845, 42.750398881973766, 41.26416575524115, 42.25823556223224, 39.726161264604144, 41.26509535697199, 40.86160505971601, 42.482089150336485, 40.236936230813306, 43.75040715740573, 53.64010657033613, 56.72492911738735, 53.37976317251883, 53.85242839013377, 52.717847516459805, 52.17520721497075, 51.77461947164228, 54.229744711229884, 53.02990344262893, 52.34398680348551, 45.95322201328893, 41.120932563658684, 39.3616004913084, 39.08464193344116, 40.013408199433364, 41.90523009146414, 40.944304312429125, 40.703039323129964, 39.86777843967561, 40.962025580867646, 40.32369513665476, 39.893316991867565, 40.96256686795143, 39.446386444953184, 39.70583162000103, 39.58490102521835, 38.51012060719152, 40.94172731522591, 41.76651547032018, 41.72103558817218, 41.29809817960186, 42.682384983185806, 42.53420960518622, 51.6695587865768, 54.86088545091691, 56.417791843414314, 54.53223789891889, 56.468009948730476, 55.439011435354914, 56.19658977754655, 55.70726233143961, 56.129960475429414, 53.794275329959014, 55.66463401240688, 49.16525879213887, 58.23440228739093, 60.14849931963029, 62.88591754051947, 57.8387410409989, 66.93140306780415, 45.39624544882005, 5.723406355227194, 0.041120328579939185, 0.5369722927289625, 1.6550141861361842, 10.495020170365612, 63.330882979977524, 56.26082643385857, 62.630881109545314, 61.38708576079338, 62.8574921238807, 49.042614121590894, 40.477797215984715, 31.58523686470524, 57.78640093341951, 33.36938773432086, 0.11030344607969446, 0.06426650309754957, 0.05124657452406903, 0.025172984610582073, 0.010005132231350628, 0.02817464541764029, 0.031632230046295354, 0.06934787236875103, 0.03011337072107821, 0.006821841074739613, 0.1726103345713308, 0.18290442654923086, 0.12026311769600838, 0.13176502389532904, 0.17699376709999579, 0.11152029247774232, 0.2947628702367506, 0.2166459724427231, 0.179501463989577, 0.2812430424795997, 0.14151568374326154, 0.20539986300131968, 0.24513764036518915, 2.2544045650189926, 62.64852000821022, 55.68936063397316, 36.256220802184075, 36.67003477773359, 60.796114014041045, 68.24249452160251, 55.511230114967596, 66.34243565220987, 72.26323773784023, 64.01648975187733, 70.82252763932752, 42.07171509342809, 0.6256798811016545, 8.467179306091802, 1.9531399372123905, 17.334348194060787, 35.42917728424072, 59.99102400195215, 65.77175432635893, 64.62683408491074, 60.22681336249075, 57.433744553596746, 56.02549206825995, 57.05270982557728, 56.45734894660212, 56.569222788656916, 56.229149372346946, 57.864656140727384, 59.33678050195018, 54.70298651726016, 50.70999799236175, 47.95287378372685, 44.324398963682114, 45.94382793672624, 44.30951356887818, 44.7092854592108, 45.89413150664299, 44.327246604427216, 44.668567334451986, 43.2770751368615, 44.66453121554467, 43.918288523151034, 46.81621013149139, 48.91620005330732, 50.35594132638747, 48.86358930218605, 48.81501074760191, 46.101385624178, 45.13864771012337, 43.14410678801998, 43.17294013115668, 43.24082851409913, 43.988122401698945, 43.39849602791571, 44.15893770033314, 41.415824197953754, 50.57949681435862, 52.55235487414945, 57.421749945609804, 55.84580436829598, 54.87930097887593, 58.056283535495886, 57.69727291599397, 56.01212855308287, 49.09591128749233, 43.89083193194482, 44.420132252477835, 43.25669450144614, 41.142199654732984, 41.263091025813935, 43.06855801613101, 44.96034068446006, 45.85349182928763, 46.93889402574109, 48.575404920885646, 48.56810931236514, 43.815506735155665, 43.668394319472775, 42.44839599055629, 43.93183246735604, 41.49333415492889, 42.902567232808764, 41.87843638081705, 41.40144871127221, 41.98270082473755, 44.84072408368511, 56.88920974731446, 58.96524575448806, 57.44589213402041, 57.875101412496264, 54.1408638031252, 54.64343317093388, 53.3771744082051, 57.90992421488608, 56.06430784348519, 55.16198619719475, 48.33914487592636, 42.65716806534798, 42.68724872219948, 41.70073340016027, 40.80457771978071, 43.94587455257293, 42.85487905625374, 43.56060758713753, 42.399974330779045, 42.67947066214777, 43.893683495060095, 42.21644663041638, 42.4364366839009, 42.61717557907105, 41.69650508511452, 42.21353230937835, 39.723545043699204, 43.661228149167954, 43.118913404403195, 43.284515873078384, 45.5490453012528, 45.8156370347546, 45.70394362172773, 54.17713788247878, 58.16403104412941, 59.57654714584351, 55.3478830091415, 59.419977895675174, 59.3361960687945, 58.53831537308232, 56.61263558172411, 57.63445223531416, 55.832738953252, 54.15446266051262, 48.987520510150546, 60.1655851641009, 62.69342722431306, 63.40292907530262, 61.28943051061323, 69.36620650752899, 47.62742296341927, 8.940901602468184, 0.2989700718993141, 1.7574179557061966, 5.375312672507379, 13.550645574446648, 71.05671667283582, 59.55163225050896, 65.95415238411196, 65.17784472434752, 68.48196306536275, 53.508201183811316, 42.4538637745765, 41.11525297164917, 63.956332360544515, 41.8332467540618, 0.37934623959083713, 0.20139251835644248, 0.13125886960375693, 0.1278786904989712, 0.16115609436265885, 0.1557780805254175, 0.20708928605721844, 0.17214485954853798, 0.14655413676894483, 0.11711497896260793], [0.01720624284878854, 0.07614734702773633, 0.07493184128355596, 0.027481188374241034, 0.031980981997724985, 0.06357647621283127, 0.027303886900265372, 0.015304631632452291, 0.05564304969964489, 0.006943463278378571, 0.046923774024171215, 0.061108240512229746, 0.06855848004981395, 0.12089563819069056, 17.734067132396085, 53.51293156223913, 34.41779805767921, 24.627560146393318, 35.818072442085516, 52.55954850104548, 71.1406083260813, 52.05717525174541, 55.07713748562721, 54.171124889004616, 53.11093176564863, 44.58542093153923, 0.07037295929847226, 3.4794595645320032, 0.5058226061444129, 0.5122013606371418, 20.435821202493486, 50.02760756400324, 61.37593054002332, 56.823078586209206, 54.139141882619555, 47.704536761007006, 42.9144637815414, 41.82255829534223, 41.88504949692757, 40.72617346240629, 43.09095474981493, 41.50319499354209, 42.77806335879911, 40.10963178450062, 40.93176057261806, 40.97328670563237, 40.50052342876312, 41.634574782463815, 40.13704130726476, 40.04481853977327, 38.41619945341541, 38.15675427836757, 38.226474408180486, 38.79863054521623, 39.3285035317944, 39.9445156897268, 41.46708565373575, 44.99832883957894, 42.53351142329555, 45.73400466672836, 42.141380310058594, 42.05821821766515, 40.843271901530606, 40.590969362566554, 39.292758972414084, 39.01050129244405, 41.410368181044056, 37.788278979639855, 38.78377652937366, 38.47303459721227, 41.924371257905044, 46.03246173551006, 49.77019809907483, 51.41064705387239, 51.90890181449152, 52.42825892663772, 52.004062437242084, 50.40774406925325, 44.21545513214604, 41.15213501837946, 43.59906250430692, 39.53929954959501, 40.42523353330551, 41.643455028533936, 39.29271974871236, 42.33045031947475, 39.14809411571872, 41.90722657788185, 40.79418736119425, 41.967764439121375, 39.16581538415725, 41.03218893851004, 41.5063956476027, 42.593978681871974, 40.526073748065585, 39.66259141122141, 41.17781085352744, 41.847532026229366, 40.559555099856475, 40.55291844952492, 45.76238301492507, 51.007470546230195, 51.3143999345841, 50.50156716377505, 51.56307820350894, 51.171790399859034, 49.254822192653535, 51.10065037204374, 50.61413918772052, 45.215553622091974, 41.145372852202385, 37.43988229382423, 36.36677672786098, 37.80168171851866, 36.78416790500764, 38.30397259804511, 38.26440372774678, 39.52259025266094, 38.58326496616487, 36.91576734665902, 38.3580973840529, 37.41375930847661, 36.383760590707105, 38.25698652575093, 37.71158095329039, 37.96165558599657, 37.2203197786885, 38.68477982859458, 38.211734141072924, 37.67054903891779, 39.001856388584265, 42.64398105682866, 47.08735181439308, 52.510330600123254, 52.13353595426006, 51.78606887017527, 53.6531876748608, 55.76907496298514, 53.3556955091415, 56.39509308722712, 53.831263280683956, 57.175162299986816, 54.29033748565182, 57.747075250071866, 53.78008811704574, 51.74837881518949, 50.898895417490316, 59.77885515459123, 58.946320318406634, 59.510400295257575, 16.99115453227874, 3.536949253851368, 0.26713737196499304, 0.5544960943441237, 0.8706785990826545, 22.369963507498465, 51.710092559937515, 45.292483068281605, 54.918336406830825, 58.68028948383947, 52.65011210595408, 35.3167543103618, 30.231395498398815, 27.428877699759703, 48.91868683599657, 11.123994781124978, 0.2470930338266396, 0.06045434999489977, 0.025482018733577385, 0.06437914100505653, 0.03134352598159063, 0.024183463312745578, 0.044199542382792126, 0.03567898608443718, 0.04019775570580556, 0.047813761348445574, 0.053627070174702716, 0.03601614137991302, 0.012702049007789503, 0.041297953726062854, 0.03979485091422835, 0.030606258285021594, 0.09135694258035192, 0.046792818954394716, 0.035549092046435804, 0.06732667961548414, 0.03302617298979913, 0.08429102254130187, 0.10907236576801348, 0.05179920737000723, 26.592534242137788, 60.60210966294812, 32.43056058883667, 36.81271883749193, 47.00605677020165, 56.64364584030644, 64.83395876423006, 53.74388464035527, 62.94008939496933, 60.07411941405266, 58.55845674391716, 47.91617216602449, 0.17333824067346512, 3.97890500964657, 3.0406875475760433, 0.18838098993705166, 23.865237697478264, 52.438535536489184, 62.890122321344194, 59.608761572068744, 56.30108564130722, 48.09170607597598, 45.580639992990804, 44.91879886196506, 45.116839331965295, 44.43950091638873, 44.756510796085486, 43.428870862530125, 45.93462605630198, 43.942446401042325, 43.07135466606387, 42.799197089287546, 42.708719776522734, 43.115116550076394, 42.39675798723775, 42.54067759360037, 40.375227235978656, 40.46206851159373, 40.477781526504025, 40.92546516849149, 42.16298864733788, 43.041642712008574, 43.265939527942294, 45.031104164738814, 44.140604542147734, 46.31988517699703, 45.02309076247677, 43.87062780318722, 42.318357652233495, 42.68900594403667, 42.40554801879391, 40.47263929920812, 44.105020799944484, 41.00635228618499, 42.24609190417875, 41.92127650783908, 44.00990724563599, 48.942577992716146, 52.45759825552664, 52.82017430951519, 53.80445780292634, 53.51040163347798, 54.2435710660873, 50.293842361819365, 45.471331381028705, 41.74175354742235, 42.56940111037224, 40.30091793306413, 42.4366484918902, 42.38899561666673, 41.07793554182976, 43.65405021175262, 42.238737460105654, 42.782174002739694, 43.23411341636412, 42.801213187556115, 41.059939707479174, 42.20205937662433, 42.329140247837195, 43.29740085909444, 40.81969061205464, 42.13935636704968, 41.9795629285997, 42.70797844856016, 39.985171056562855, 41.56815336596581, 46.15498089021253, 54.258001465951246, 54.86602767821282, 54.42408246378745, 52.96087757233651, 53.20613553447109, 50.89803641842258, 52.64247917359876, 53.030715373254594, 49.53355758420883, 43.446772559996575, 40.155088132427586, 38.01445853325629, 40.036197170134514, 38.98840265889322, 39.38763326214206, 39.01909128312142, 40.734500654282115, 38.68008475149832, 39.32792694337907, 39.70251329483525, 40.861405018837225, 39.71647301027852, 40.02958797639416, 40.19459032243298, 42.04905163857245, 40.21859915025773, 40.320996545976215, 41.07249913677093, 39.643454167150686, 40.71091152006581, 44.444898097745835, 48.35390475488479, 52.5211210404673, 55.885816466423776, 53.97431604323849, 55.8006618099828, 57.0417114996141, 57.34793093896682, 58.47892676630328, 55.320449952156316, 57.19784928906349, 57.04417867045249, 56.49569403740668, 55.194177089198945, 51.55440192068777, 52.78779906611289, 60.861044929873565, 61.06633786232241, 60.688484176512695, 21.388445285058793, 4.319177241094651, 0.5403142134028097, 0.6055280301840075, 1.0162547939727384, 25.05929150888997, 57.18939658134215, 50.22756607301774, 60.50807083806684, 65.61150981533912, 57.42438970073577, 43.74698685061547, 34.63872948000508, 23.907944463914443, 58.18667880950436, 14.047018577975612, 0.2565482288839356, 0.03824171873049871, 0.007951464532168523, 0.015102317387748872, 0.04058559537835179, 0.05961800031664391, 0.06782624555090744, 0.04822986966539775, 0.048733802301989454, 0.06044419932990305, 0.12964611662732017, 0.13290958989772106, 0.11261347696305284, 0.14350999447126545, 0.1727776941392691, 0.19392219582392325, 0.11475204204719876, 0.11978392969937095, 0.15016605747082543, 0.12943672947585583, 0.14569420307394, 0.1345825420632478, 0.23511189366540602, 0.19201048469591528, 34.83628357610395, 72.8457332426502, 43.47426445253434, 39.195099799863755, 48.36222410202027, 64.55195996069139, 80.24897160068636, 63.4945870214893, 66.85072775809996, 66.72035601831251, 63.15241905950732, 55.07285033502887, 0.23894362031452118, 9.289736613150566, 2.3310915597023505, 0.5997896026219092, 27.79970249822063, 55.94034917892949, 64.04540154241747, 63.32541127358714, 61.31119574269941, 51.224385461499615, 48.48470403302101, 45.57729028886365, 47.19043170252154, 46.578726307038345, 47.852657225824174, 45.178008694802564, 48.55553811596286, 44.28603033865652, 46.65722077892673, 46.23578956050258, 45.40353321260022, 46.52580961104363, 44.9697426057631, 45.92018388932752, 43.88683111436906, 42.09112298104071, 42.706919408613636, 42.232818603515625, 44.802065203266764, 46.192996501922615, 47.05490596832768, 48.28215675969278, 46.91708172521284, 50.021539657346665, 46.349671656085604, 47.43489342351114, 44.41325633756576, 43.503211544406035, 44.14680188701999, 42.11979942937052, 46.960816152634166, 42.06174835082024, 43.95972444165138, 43.0384930487602, 45.81024377576767, 51.92000604444935, 54.85283282495315, 56.17930781456732, 57.14367351224346, 55.73268713489656, 55.790240072434955, 51.8663715547131, 45.02494604356828, 41.41893071513022, 43.888337304515225, 39.740885842231016, 43.35082354084138, 44.97893664144701, 42.63259049384825, 47.98653556454567, 45.50305551098239, 46.05832192205614, 44.95155457527407, 45.613725185394294, 42.547055367500555, 45.21949560411515, 46.18216683787685, 45.583632761432284, 41.253626346588135, 42.613355190523215, 44.39125968563942, 43.46115196904829, 38.900361138005415, 40.8521560699709, 46.762944344551336, 55.27381689317765, 57.62673301081504, 54.99703876433834, 55.847169353115945, 54.714008377444365, 52.418676576306744, 54.87010694319203, 55.23199658240042, 50.656771429123424, 45.83158539187524, 43.49856353575184, 41.06226959536153, 43.41852365001556, 41.88077411343975, 42.5282907485962, 41.79476045793103, 43.163373470306404, 42.25761582774501, 42.43445980933405, 42.4139654251837, 43.18802164446923, 41.88615952768634, 41.50991401364727, 43.10157652824156, 43.13770940226894, 42.799095107663064, 41.847461423566266, 43.24396641023698, 40.878071169699396, 43.71092065688103, 46.82453340099704, 51.01236174183508, 55.93900772833056, 57.95690636481009, 54.70099395321262, 58.609796647102606, 60.45431083248508, 58.87394866635723, 59.28387949543615, 55.447836768242624, 60.339820769525346, 59.45548711284515, 56.18683876529817, 55.43994495945593, 52.22124799605339, 54.290823859553186, 62.149857321093165, 62.705755233764656, 60.40033901891401, 27.70418690096948, 5.6251607883361086, 0.5264729657961477, 1.0631833177420402, 2.39857986088722, 29.13964298463637, 62.918571272204005, 54.47562633022186, 64.68098632750973, 69.97214209648871, 61.8531378622978, 47.12210009174962, 42.71542702951739, 37.021914528262236, 66.77537902708977, 19.33518648147583, 0.494356660112258, 0.2277972248773421, 0.10087211466123981, 0.12142852128994082, 0.13062439558486785, 0.1277315250087169, 0.13812788972450843, 0.15937293278834513, 0.17934916571023005, 0.24511067407025447], [0.03206782764004123, 0.09542499969322836, 0.045284648470941095, 0.009900991196533846, 0.10707574145447825, 0.02567492733379045, 0.03659297494337924, 0.030931431965361682, 0.03185957046826521, 0.01723191062469156, 0.03091036071700435, 0.03686356485911435, 0.08051512838010827, 0.1953545963812259, 3.6889067772896063, 49.859800723291215, 37.82181916698333, 22.561188859324304, 30.599278519230506, 54.38914199029246, 64.03348930420415, 59.77723913808023, 56.561393737792976, 56.78757721377958, 53.141000655389604, 52.46685504913331, 1.8593123074500792, 2.0957983789905428, 2.464637967848009, 0.2439599027556758, 16.456743363411196, 60.85060750284503, 57.11922537895941, 61.279863849762954, 56.660555178119296, 54.293769559552594, 50.308378665677964, 45.47504586558188, 41.63302544624575, 42.070989454946215, 39.91017533886818, 40.243196333608324, 40.0858033857038, 39.0112583098873, 38.861121746801565, 40.7917711811681, 39.55272190032467, 40.06411267865089, 38.68158309690414, 40.336187885653594, 39.50701452070667, 39.02404131427888, 38.70588610249181, 39.41919265254852, 39.49379613322597, 41.72160433184716, 41.79343861918296, 44.878586722958474, 44.44608265353788, 45.100867440623624, 41.979013796775575, 40.728852441233975, 38.59665201556298, 39.37743509969404, 39.863707019436745, 38.86888411737258, 39.09646003477035, 39.94274277840891, 39.20414870785129, 37.66245326688213, 40.5954683211542, 46.01277928198538, 48.03878545761109, 48.69282891673427, 52.55347667201873, 54.04931568330335, 51.627891448236284, 46.60134661582209, 42.363994429188395, 43.63017082214356, 40.11252257131761, 41.06401112771804, 41.38914031367148, 41.155402352733, 40.82318936624835, 39.972258613955596, 39.77144110587336, 42.17657573761479, 40.84180101271599, 38.7449215304467, 38.77029926546159, 36.60690030743999, 39.27556722394882, 40.53936273820939, 39.80848004741054, 41.023904892706106, 41.84465692889306, 41.18133706431235, 40.98611285609584, 41.487348618045935, 42.03337784736387, 46.37685368137975, 50.85617296157345, 53.40788264428416, 52.24507247248004, 52.2814053873862, 51.26016924458166, 50.219215346920876, 50.97369109430621, 45.90378445963706, 38.58478292342156, 35.668422252901145, 38.86915868328464, 36.94243161909042, 37.559632255185036, 37.7151071640753, 38.8856993183013, 38.03196407133533, 37.670364687519694, 38.06022474842687, 37.71756256780317, 39.05885627192836, 36.708823096367624, 37.35361368425431, 39.07947617192423, 37.29934769292032, 39.02194284623669, 39.41343461313556, 39.787848380304155, 38.49551370066982, 37.271212531674294, 41.17628897390058, 46.955258154099994, 50.34714345009097, 53.548621208437034, 54.36880057857883, 52.55359042075373, 55.77693539281046, 55.772408977631606, 55.301983433385054, 54.62554324057795, 57.51747931203535, 54.795252430823545, 55.06273846472464, 58.21710071256084, 51.83995046923238, 50.51361276257423, 49.160795134882775, 53.46913437689505, 42.2231028925988, 1.849366034711561, 0.06810210615156159, 0.2465931461342881, 0.538169473649994, 0.189709386397754, 26.281780542865878, 55.39498283017067, 52.08549476438954, 56.93410519630679, 57.748895229831824, 47.60889760909542, 30.194295760123964, 27.064283586317494, 34.605601141529704, 43.53888942349342, 1.7267737032905703, 0.15176210973051288, 0.08807548156548893, 0.05192306080472566, 0.06594060439496272, 0.07288319193908284, 0.03433402297237227, 0.09282639114967278, 0.013053476521294686, 0.07459458639664997, 0.04831154995988454, 0.0372590500891449, 0.0827199677305837, 0.038666529806270715, 0.025209371871765585, 0.04602551295031463, 0.014302320496719933, 0.061506751789561206, 0.01485569644794469, 0.06623403905259986, 0.014037748201630049, 0.0874517021340228, 0.10632034045674148, 0.13150895134575907, 0.13851476412627006, 7.9127008011264195, 61.608562392573205, 37.959443369219386, 24.190041326707412, 47.26271314005698, 59.63271548671108, 72.20087989684075, 63.49901537741385, 60.338024323986424, 61.04050905473771, 58.608851355891076, 54.17602000697967, 2.1171522525049027, 3.4607150477747766, 0.9540192206059733, 0.5241321075347163, 18.727770197776056, 61.07039359308059, 60.081705277965916, 63.23054090622933, 59.34005568104406, 56.695409359470496, 53.38598012924195, 46.934438213225334, 43.90162629465903, 43.55657146823022, 42.84768542935772, 43.11858000293855, 43.205499725957075, 41.5599242333443, 40.19121708408479, 43.4944175904797, 41.913302329278764, 42.53444494739656, 40.37161865542012, 41.089745798418605, 41.6038312450532, 41.470756992217034, 39.67535480376213, 40.48471235459851, 41.805044912522845, 41.84595915579027, 44.56178080651068, 46.1155963713123, 46.17502420179306, 46.0214045739943, 44.56121990757604, 41.78405630973078, 40.87199934067265, 41.943481045384566, 41.2782705983808, 41.51772345266035, 41.323648498904326, 41.93716210703696, 40.93723227900844, 41.319859489317864, 43.3128785317944, 47.76194064847885, 50.33305429643201, 52.274819727866884, 54.666586922061065, 56.56055042820593, 54.207171470888206, 46.77526058689241, 43.51445305731989, 44.2230409960593, 41.99008272540185, 42.26530759565292, 41.014016597501694, 42.71737252512286, 43.395726834574056, 40.32471495289957, 41.942504375211655, 43.92875732914094, 42.204322584213756, 41.51194187902635, 40.74951940967191, 40.41364685181649, 42.1164301133925, 42.25753738034157, 43.975264872274096, 42.66587180476035, 42.936385908434474, 42.26670395943427, 41.54130081976614, 41.278651068287516, 42.552495694929554, 48.581931744852376, 52.549264046453665, 55.13103085179483, 53.61470137873004, 53.99721876267464, 53.00219189736151, 52.906270334797526, 51.70110248750257, 48.281744910824685, 39.71297817845499, 38.14759162164504, 40.01383181541197, 39.520585921502885, 39.58708186303416, 39.070442953417384, 41.736015119860255, 40.724380939237534, 39.64656460669733, 39.64055553559334, 40.78143573576405, 39.295594846048665, 39.97574167866861, 38.914465981145064, 39.792841557533514, 41.319835955096835, 41.72218876500284, 41.16130551984234, 41.914016200650124, 40.11109090620472, 40.16927534534086, 43.83097656311528, 50.53633113061228, 52.5990899147526, 53.95535922819569, 57.21020867747646, 54.21808742707776, 57.46866933761105, 57.107740679094874, 56.31055032053302, 56.47408570012739, 58.594907329928496, 56.099919042279645, 58.71685774095597, 57.55189026555708, 52.030248180512466, 52.076889084231475, 50.164341388210175, 54.22108411788941, 45.06807250361289, 2.441389834688556, 0.30670688577717353, 0.6014243116782558, 0.10994802724810378, 0.5309662246896375, 31.34568987354156, 59.76407174141177, 56.854398712035156, 60.75170886132025, 64.66851711273193, 50.87778129885274, 44.94728311415642, 25.737206512881865, 34.2227150547889, 54.53334792967766, 3.2635642203592488, 0.2456652451186411, 0.023558400684006275, 0.052198051895585754, 0.064322205350524, 0.02358518886349855, 0.018850537580287745, 0.045160500092371825, 0.019939408990584558, 0.056516880229596174, 0.07975835608498705, 0.11762301016959453, 0.23103871142431615, 0.15031308506525334, 0.0714279236572404, 0.18850175603743524, 0.14619579148148337, 0.1117479048609253, 0.09950192810426797, 0.10195732417125856, 0.07691280675991889, 0.29096402408134553, 0.24605192033754242, 0.1977357202239575, 0.3787386705798488, 10.190024510506662, 73.3952102353496, 47.58745401136337, 32.64316481928672, 42.7205692568133, 64.91085290908813, 75.56283750841695, 71.08248664486793, 65.6589508825733, 67.77007641330843, 63.74015485086749, 61.52706338513283, 2.789558532737917, 5.809010613349177, 6.612845957279206, 0.3670694048125898, 22.708666055433213, 63.4021524460085, 62.73379233575637, 66.31017023517241, 61.654913040899466, 60.140889921496, 55.63003086274671, 50.98456390442387, 46.84856184067265, 46.73469151220014, 45.00688352892476, 44.75935843683059, 44.307171913885306, 44.07776817198723, 43.65641540096652, 47.2401124431241, 45.08302457870976, 44.55681116350236, 43.026078747164824, 46.147783340946326, 43.59537939871512, 44.4676007763032, 42.689751194369414, 43.20918283154888, 44.21587090338431, 46.413351335833156, 46.39346884142968, 50.41945626658779, 47.228545373485936, 51.011530199358546, 47.330597600629254, 46.47568956498177, 42.448925510529556, 43.2343566033148, 43.28431190982942, 41.8200558231723, 42.38342585102205, 45.0078131306556, 43.334129933388006, 43.37984908011652, 46.455320696676935, 51.77516075872606, 51.58491011588804, 53.05065278084048, 58.58355206827964, 57.34379283843502, 55.16586934366534, 48.0149531364441, 44.297063965951246, 45.46916231032341, 41.51392267596337, 43.81347102503623, 43.010887407487445, 45.43839523869176, 48.50975621131159, 46.239762921487134, 44.278024781134825, 46.49634084393902, 45.68433177086615, 43.594634148382376, 43.387580071726155, 41.33699240223054, 43.7552002937563, 44.18322893881029, 45.40888724788543, 44.70954433564217, 46.6184599168839, 44.39600967591809, 42.49102430958902, 41.49380876171974, 44.73811095760715, 47.09065445007817, 54.208779642658854, 58.9886309254554, 55.45760739234186, 58.22370206156085, 57.538040376478634, 54.88301154105894, 56.315084580452215, 50.66357281900222, 41.54822772549045, 40.22187825172178, 43.047898892433416, 40.68459633857974, 42.1571207815601, 41.952396592786236, 43.468020039220015, 42.605031921017556, 40.50426144753733, 41.062489248091175, 44.009565999431, 44.19727494639736, 41.31517225696195, 41.05536230148808, 42.643451536855395, 42.50944768228839, 44.78806626412177, 43.403077356276974, 44.59694093273532, 42.80121710992629, 42.1067810827686, 45.494100739878995, 53.769136859524636, 54.32944743863998, 56.6066578895815, 57.91416429704236, 54.96517735142862, 60.01840606812508, 58.918098865016816, 57.82823693367743, 58.25352776435114, 63.52587969072404, 60.16208248753702, 60.25004556102138, 59.76589172117172, 51.77663949228103, 51.54188955983808, 50.85734575025497, 56.32557692066316, 50.1045762338946, 5.595066893485285, 0.396082625393906, 0.8687575570037289, 1.045142866430744, 1.149796728164919, 34.00920475682905, 67.5609121014995, 60.22924915436776, 68.6014384608115, 67.14743152741464, 61.75723983395485, 41.61111116409302, 39.88633909533101, 44.90743575557586, 64.18457900324177, 5.189980191569175, 0.41502338323381643, 0.22909719947605367, 0.16743360267531487, 0.15468131840950058, 0.2197194865514194, 0.22191157053795554, 0.17072347533558646, 0.11210099478522617, 0.141945336494715, 0.1643041028611122], [0.02793658359517013, 0.059322420612818776, 0.058993462458132744, 0.05913899235066868, 0.0937544377220254, 0.06293331092644124, 0.014511472076147556, 0.05188766371218428, 0.06651911569098312, 0.007918123906898883, 0.018348686787630283, 0.021184774926833568, 0.015028082510276188, 0.052092205357527545, 0.45036335625956136, 25.377072134325584, 54.99750552638885, 39.21151884140507, 22.683107891390403, 42.729735835906, 58.39683548096688, 63.044043971646225, 55.2077288781443, 58.49776983261109, 50.083438581035985, 58.39850248829011, 4.488803080974087, 5.091111948413234, 2.2208244185293875, 0.0685001271326215, 6.663760283300954, 56.622778830989716, 60.18153744359171, 59.06285001385597, 58.38222857444518, 52.83034893774217, 55.020941688168435, 54.59647847760109, 52.3217430422383, 47.53515704985588, 44.57735653846495, 40.22004650485131, 41.45737778755927, 41.9417473577684, 40.52322610732048, 41.56387798247799, 38.991069870610396, 39.65017318725586, 39.6943312306558, 38.24686681070636, 40.63032642487557, 38.333570803365404, 39.72936191866475, 38.265074453046246, 39.35646610875284, 37.08559420800979, 41.668377768608835, 43.20695100292083, 43.64221249857257, 44.97993292347078, 40.81079467650383, 40.43798123636554, 40.47546732810236, 41.248950881342736, 39.598656777412664, 41.60765947834138, 39.16276770253336, 40.389885133312596, 38.901824182079686, 40.11006716758975, 42.34192717459894, 44.592316458302165, 47.12469277843353, 46.95183000256939, 51.01258139456473, 54.448122670573575, 53.231995721017164, 47.33974849024127, 41.445967612728, 41.00685434956705, 43.32377879850326, 42.21269684453165, 43.34647363232028, 38.31107993279734, 38.39002547725555, 38.16118655666229, 42.033177806485085, 42.14067428342758, 39.655974372740715, 41.10656492171749, 40.867590596598966, 39.35590913218837, 37.7696987121336, 37.82162304847471, 39.66052824451078, 38.5065669398154, 41.290528005169286, 40.549094138606904, 41.37407841220979, 39.44981459648379, 40.66250162739908, 42.00515247160389, 48.363734214536606, 53.16283256776872, 50.878302974085656, 50.6381284036944, 47.93748632554085, 46.75498585547171, 46.29895540975755, 44.6280296387211, 37.28697261502666, 36.63875387560937, 38.112753129774525, 37.88642844846172, 36.83539013708792, 36.598161266696074, 38.996137572873025, 39.56443802002938, 39.86409533408381, 37.52411127090454, 37.603860901248076, 35.925984690266276, 37.84762836271717, 35.616399857305716, 37.08086775195214, 35.97206077268047, 37.84885214221093, 37.406883393564534, 37.68873314703665, 38.02406441780829, 39.6663764984377, 39.91454485924014, 44.1008238638601, 45.99126115922005, 48.51058775378812, 50.086058724311094, 52.3328237379751, 53.19880462461903, 52.02751821087253, 51.526035339601584, 52.031966178647934, 49.87749845750871, 53.486275134548066, 51.580109134797134, 57.67263258657148, 50.68302777505691, 51.808700946069536, 51.165424393069365, 58.65924204549482, 12.571487638258166, 0.7776475169004933, 3.4202793336683706, 0.33225337464001875, 0.37610875202282784, 0.15901513908418918, 34.070236836710286, 54.97780346101331, 53.172752241934504, 54.68072314416209, 57.315312508613836, 40.943574751577074, 27.11474487858434, 24.65522070084849, 45.52776252069781, 24.26471737123305, 0.3197888789638397, 0.03534766454850474, 0.03570050932466984, 0.06000882007121559, 0.0881790489919724, 0.021900858377076445, 0.004572639487788923, 0.05966666222159421, 0.013998521627077173, 0.0805445921216761, 0.04084982293387575, 0.0616663585477058, 0.017090776161621177, 0.013262789936796313, 0.05790977363264369, 0.054012814596776045, 0.006857521619812976, 0.04273722609204631, 0.01563810396023215, 0.02032798985319753, 0.011715736660745837, 0.07668648906532796, 0.009517898396288436, 0.06230413823598816, 0.032383099633959994, 0.5754155040748659, 39.531090028824345, 57.220191109565, 28.123231357143773, 34.81238457464403, 55.93984319317726, 61.598328928793634, 69.15927794671828, 60.236580064219815, 62.50544763380482, 55.06881029375138, 61.31370998197987, 5.41344742621145, 4.187998473644257, 1.0821326557667026, 0.3162943229319588, 8.922139925341453, 60.17195509326074, 61.92949464244228, 62.76311989753478, 59.96105709383565, 54.789066853061804, 57.09158051398493, 56.740622520446784, 51.53112657608525, 49.311245487582305, 46.19229439766177, 43.14953534833847, 42.37323945568454, 43.50944811298002, 43.76741455447289, 44.059129068928385, 41.36650823777722, 41.97973943525746, 41.36206811474216, 41.0880591792445, 41.96067671622, 40.86820248634585, 40.59324825963667, 40.38333085275466, 41.34384086055141, 39.722187903619584, 43.568569998587336, 45.85187581277663, 46.39457887218845, 46.82032862017232, 44.352565503889515, 42.66082371434858, 41.617798805236816, 42.461622222777336, 40.91845981536373, 40.91905601562993, 42.438962690291866, 41.596315983803045, 40.39690225355087, 41.83026967510101, 44.166456883953465, 45.95471251395441, 47.200465125422326, 48.94470391734954, 51.639725239046165, 56.00171466027537, 54.05006877837643, 48.134448143743704, 42.65962739144602, 41.82843008349019, 43.269132337262555, 44.66046371767598, 43.50534531377977, 42.03299345508699, 41.00646995729016, 40.86438994253836, 42.208339091270204, 42.40386924436016, 40.7344025950278, 42.33922466155022, 41.636677172876176, 41.99811573951475, 40.28305153692923, 39.81070010892807, 40.77262216998685, 41.47870763655632, 41.966713243915194, 42.07201711593136, 41.236936661504934, 40.39475671706661, 40.64574918439312, 42.64550685882569, 47.40507164309102, 56.3078046614124, 52.726531644021314, 52.130598099001, 50.733449843622026, 49.76759756765058, 49.527772088204664, 46.968700116680516, 39.40911608357584, 39.60532088433543, 39.81677586032499, 40.060853189037694, 37.7084195229315, 37.75426026313536, 40.44472771306192, 40.46435133103402, 42.288155401906664, 41.03607992972098, 40.80409134587934, 38.90873147595314, 40.7542537104699, 38.46715496432397, 39.52088009926581, 38.25830444212883, 39.06430836646788, 39.386860555218114, 39.78638141385971, 40.977130628401234, 41.91020757921281, 42.73238735814249, 46.373790310275176, 48.6641053999624, 51.788555652864524, 50.99505232226465, 53.68638661599929, 53.613301092578524, 54.98504023398123, 55.262261590650006, 53.96452580728839, 52.058920706472094, 56.038588862265314, 53.286528433522875, 60.53957923766106, 51.96854145296159, 52.96497252679641, 51.36485730448077, 59.95376540768532, 14.287991350696934, 1.6162900963137228, 4.248425037630143, 0.25640141579412645, 0.18500287926966147, 0.16226468487612664, 38.865471655322665, 60.06446253868842, 58.34059261506604, 61.05104846339072, 61.360174379041126, 49.75739940520256, 39.2236428876077, 20.922912897602206, 49.88230336096979, 29.821727468121438, 0.31572518089125234, 0.04227343263224729, 0.012400473708346968, 0.038376887283858754, 0.03081102018064309, 0.0359427961220424, 0.10347261544196837, 0.09075777755389292, 0.044761054187772736, 0.04381647543801416, 0.038315944989482244, 0.1366855453459486, 0.11292789476893603, 0.19974572043265068, 0.18711771094991317, 0.14376831931933282, 0.17065751516530592, 0.09254804076326471, 0.11320900307187151, 0.14970042923044774, 0.05743328609593934, 0.13835943213874294, 0.10430343779585055, 0.1283152610243809, 0.18277408434979378, 1.0920935148192992, 51.143729763646284, 67.12871397695234, 48.61078469983993, 30.2334802381454, 58.30324772865542, 68.43413368348153, 75.11724056736116, 65.88034122220932, 71.24181332126741, 59.79892984513314, 70.09717156810146, 5.915545129006909, 10.422337670480053, 11.093496391850135, 1.1433245722324619, 12.762470783725863, 63.43918746517551, 65.10153893501528, 64.71993154095065, 62.0626316532012, 57.87143791875532, 60.96655668750886, 60.73135960486628, 55.718448931171054, 53.29318469570529, 51.58180359871157, 45.360473432848536, 46.58258984165807, 45.89153489758892, 46.454430318647816, 47.56981903506864, 43.3617591088818, 45.45483389208394, 44.545997188937285, 43.291360409029075, 44.56462452488561, 43.78645766165949, 43.48980880552723, 42.362645133849114, 44.92436078286941, 40.818902215650006, 45.05761938710367, 49.088611756601644, 47.212196934607725, 48.76429842364404, 46.79834765772666, 44.49546921637751, 45.183923629022416, 46.21662093747047, 43.78385713023525, 44.55527359439481, 43.917825683470696, 43.16339308215726, 42.6181600939843, 44.64295817959694, 47.40968435041366, 48.36606410241897, 51.724679854608354, 53.11656428921608, 55.03534855381135, 58.920095351434526, 55.36137596253426, 50.356168823857466, 44.277040266221576, 43.68517421906994, 45.88744778786936, 47.823255139012495, 46.4599020250382, 44.27043499485139, 44.246947842259566, 45.09452104568482, 46.59180348919284, 47.0834529784418, 42.62456140210552, 45.76755269881218, 45.92502017174998, 44.45246042743806, 42.99402906048683, 41.602340744387725, 43.99462569144465, 43.00347805023194, 45.472688521108324, 44.597858767355646, 43.052264490435206, 40.48087235419981, 41.86289595019433, 43.147323131561286, 49.650032366475756, 57.6052031209392, 55.795680399863954, 55.46870377755935, 51.395145846951394, 50.79343465066726, 50.811826644405244, 48.279905319213874, 41.54096349593132, 42.19374002948884, 43.24087558254119, 42.946650751175426, 40.82000047929826, 38.00085967586887, 41.977966523939564, 44.10473838929207, 42.926434855307306, 43.17035528921312, 43.51669665305845, 40.25117443453881, 44.10007469115719, 40.769001822317804, 40.93878945996685, 40.493110149137436, 40.66059143312516, 41.93418895044635, 42.12567121751847, 42.3647867479632, 44.53324164113691, 45.32903171354725, 47.92899831648796, 51.86873674392701, 53.39231475707024, 53.904007557899725, 56.055113807801284, 57.36523643616707, 57.68177955381332, 59.19529276509439, 55.77660591371598, 55.11945201504616, 59.11412323674848, 56.4375017535302, 62.35663683183732, 53.51461425904305, 54.468016932087565, 52.0276790280496, 59.4970916932629, 17.859808514195105, 2.788860841143516, 5.726427560852421, 0.6040209820193629, 0.6286659692564319, 0.5669198954297651, 44.937881192853375, 64.84597690643804, 63.7253047573951, 65.70316383915564, 67.4415151534542, 51.81969534966254, 38.14825842457433, 34.8722360211034, 56.4500690275623, 39.12895294927782, 0.5138915957462403, 0.18316647458461024, 0.3082530963565073, 0.2923390599748781, 0.1682177549528499, 0.11342200615833845, 0.16909674891541082, 0.18931809932954852, 0.13926646491933253, 0.18095712297626082, 0.10762360157264818], [0.058211041539306604, 0.07524637400262779, 0.04797762755544917, 0.0033102261800048577, 0.021935793901643446, 0.04520992425480678, 0.011004492013354697, 0.010844706182157802, 0.07651706105999409, 0.09724795953520844, 0.05893284958156367, 0.15240390754995808, 0.04934629725833093, 0.09002710587435192, 0.12936788881498, 15.209185481071474, 58.171958154247655, 32.76699404562674, 32.60662401876142, 34.58663648174655, 51.784311648338075, 62.624138555219105, 56.43603870945593, 59.46874472402758, 51.193912567630896, 63.78323424247004, 11.296052490511249, 2.3625222473375262, 0.8518528157184202, 0.5780413470441296, 1.2914595007896423, 39.32615403206118, 63.52168275463966, 55.022526325718054, 60.422880880294315, 57.29091928851221, 62.207696591654134, 56.58932101341986, 57.6345306827176, 54.30598774263936, 52.33508694556452, 45.87666519226567, 46.95571314903998, 40.56639571343699, 42.851235174363666, 39.24433339026667, 39.136158343284364, 39.388233384778424, 38.162025943879165, 39.14318723063315, 41.214437946196526, 40.79818033402966, 38.78830686692269, 37.956238792788604, 39.4558628912895, 40.11819039621661, 40.85883194400419, 42.243887532141905, 42.95313835144044, 43.2378710469892, 42.901963187802224, 42.11565740646855, 39.583520350917695, 41.50702714920044, 39.58747410005139, 39.604771752511304, 42.161380475567235, 41.0996497831037, 39.286683221017164, 39.039883767404866, 40.313955891516905, 42.91539730564241, 45.25285928480087, 46.16174697875977, 50.99622511094617, 53.63117141108359, 52.63461482140326, 46.926181624012614, 43.06181546180479, 42.219800256913715, 41.45572254734655, 40.02254339956468, 37.70419120788574, 37.76967517791256, 39.46486865320514, 40.04517939782912, 39.5160634286942, 37.548975175426854, 39.309891885326756, 38.755256975850756, 39.05568699682913, 37.30372113566245, 38.71684912712344, 37.972889254170084, 37.900596049524125, 39.53895438101984, 38.4142892591415, 39.95521199318671, 40.96617937088013, 39.954058816356046, 40.80845694388113, 42.765915778375444, 40.46812857350996, 46.200186206448464, 51.94745479091522, 51.957441145373934, 46.85414337342786, 46.14320593495523, 42.77652578969156, 40.403738944761216, 36.81336995094053, 36.493135882962136, 37.76237172465171, 40.04782307532526, 37.85220184633809, 37.12722624501875, 37.08730043903474, 38.34599294970113, 39.228545850323094, 38.72428986334032, 38.832496289284, 38.44746466605894, 37.47750959088726, 35.6406440273408, 37.09280744675667, 36.580957751120295, 38.72125002645677, 35.69280762826243, 38.70803948371641, 37.334751006095644, 38.75680238969865, 39.43547833350397, 39.4500107149924, 41.14549444567773, 44.004612045903365, 47.221736138866795, 47.584786799646196, 45.467663964917584, 47.621943412288545, 45.10467213969077, 43.84685823994298, 44.25664394132553, 48.64652925922025, 53.705010029577444, 58.08312431458504, 50.9601902961731, 51.67613660135577, 47.01732966207689, 53.63725500722086, 3.0112177998788896, 0.8208089105544553, 7.524085602452678, 0.14943384595455664, 0.167486202272196, 0.4400777678576208, 52.30348833145634, 50.97932361787366, 55.76516435992334, 55.60837937939552, 53.88463497161866, 30.133997163464947, 25.893295272704094, 28.908687945335146, 50.16173693441576, 7.48878917386455, 0.37253433898572, 0.12877018701645637, 0.08474953382486299, 0.04299712142035846, 0.007032142743663563, 0.04069690795374974, 0.08549029488236674, 0.08544456709416644, 0.03496004704145655, 0.052228718395194704, 0.03972060167260709, 0.031787906773388386, 0.026235471952766664, 0.059970435235769524, 0.041253788757228085, 0.04273327690879664, 0.0327881341499667, 0.02001046364556157, 0.05686066601605666, 0.14057224646451014, 0.05393870325098115, 0.02063265344458482, 0.11400476158145936, 0.026229385384208253, 0.062144619577954856, 0.10228563115120896, 22.625196056981242, 68.90641058644941, 31.7818574367031, 29.77388239675953, 51.59029160776446, 59.563120872743674, 69.28972028916883, 59.973200751889145, 63.67520824555428, 55.48168290045954, 69.14434940584245, 11.585480263156276, 4.641926038649775, 0.9655058203685669, 0.8856615628446303, 1.7724056998568198, 45.01954101747082, 64.72363425839332, 57.537969773815526, 61.890494515818936, 58.65264461886499, 63.18189959372244, 58.56805086135865, 59.586906125468595, 56.26429773146107, 54.885568926411295, 47.30165443112774, 47.31823428984612, 44.06123930408109, 44.96886791721467, 40.97426729817545, 41.41565553603634, 40.3121006104254, 41.944500861629365, 40.69042890302597, 43.5751203567751, 42.71889440474972, 40.408767423322125, 40.989784194577126, 42.12629879674604, 42.71743136067545, 42.481500794810636, 44.34637208138743, 45.05783903983332, 46.066170584770944, 45.27991971661968, 45.13362315393264, 42.10504347278226, 43.9170176752152, 41.455173415522424, 42.60716961276147, 42.14492613269437, 43.78130366725307, 40.68298816680908, 41.563650485008, 43.27516886495775, 46.36495713264712, 44.99160589710359, 47.47361898422242, 52.06890706093081, 55.55159130404073, 55.39832076718731, 48.086810958000925, 43.497579020838586, 45.092097020918324, 43.41340887931086, 42.235842750918486, 41.68856620788574, 40.42012660734115, 39.886343017701186, 41.6528255708756, 41.9684547762717, 40.260595967692716, 40.593126666161325, 41.304075871744466, 41.726993668463926, 40.53101201211253, 41.814870449804495, 41.31501143978488, 40.26950759272422, 40.459593496014996, 40.770194222850186, 41.82561774407664, 43.436217461862874, 40.89061490951046, 42.7753020101978, 43.03718297712265, 42.18264364427136, 47.51205428954094, 53.45699464121173, 53.14557413901053, 50.45815829307803, 48.61573080862723, 45.45633223748977, 43.95611978346302, 39.52682641244704, 38.42275373397335, 39.70311341747161, 41.51000422816123, 38.810691833496094, 38.56718717082855, 39.69117764503726, 41.04169284143756, 41.91724038893177, 41.512632216176684, 41.86097791118007, 39.86213022662748, 39.05776193065029, 39.25609265604327, 38.03747107905727, 39.23946180651265, 41.20383577962076, 39.05178423850767, 40.234210183543546, 38.60486545870381, 41.07546837099137, 41.621681951707416, 42.71058290235458, 44.69302723484655, 46.23123568873252, 48.651961741908906, 49.69118587432369, 49.11486418016496, 50.42515547044816, 46.06707272991058, 47.241489195054584, 46.099616635230284, 52.66025535521969, 55.66416725035637, 58.592094990514944, 52.172379186076505, 53.07622271199381, 49.41200333256876, 55.30988700928227, 4.1236608163003, 1.2989284290421395, 11.076877309430031, 0.2884216234087944, 0.5741933793310197, 0.6075120140467921, 55.646473438509055, 57.79961932090021, 59.0952487914793, 63.97477926746492, 58.07326347597184, 39.139100120913604, 31.3223203920549, 27.526189742549775, 59.50226137715002, 9.99583580801564, 0.2957240960771038, 0.10673945949923609, 0.02967801061458886, 0.023367481997176524, 0.009542315533655065, 0.06448216450911376, 0.06147832226669116, 0.03144380114521952, 0.0547059326462688, 0.04759366428779979, 0.010802623057257264, 0.10115267904174906, 0.1347912244138218, 0.1577762216930428, 0.15339893318953055, 0.15208654796644566, 0.09445554606856839, 0.11764106686196982, 0.14936292153452674, 0.34464490810228937, 0.14619165460669226, 0.1221494559919642, 0.34570621566907056, 0.16726795914432696, 0.14738521959272124, 0.16795227484356973, 32.095552913604244, 74.72235202789307, 43.83140410146406, 42.681729947367025, 47.19218500198857, 63.22959169264763, 74.9405691700597, 67.2500877995645, 68.83441155956638, 60.809736405649495, 75.94280535174956, 13.150219628887793, 5.565379944539839, 2.8528092032478702, 2.266826956502853, 3.280233312999049, 47.11934266551849, 66.07666369407409, 57.40069858489498, 64.83527275823778, 60.30638256380635, 64.18267273133802, 60.59136629104615, 62.32020978004702, 60.05667663389637, 58.06085701911681, 50.78158909274686, 49.93472191595262, 44.0951717284418, 48.40753139988069, 44.38532121719853, 43.63267721668367, 43.56363957928073, 44.08400866293138, 42.69106126600697, 45.8930685443263, 46.280657552903705, 42.660831559088926, 41.5808932242855, 45.26800747840635, 44.138678658393125, 44.50757757309945, 47.095388750876154, 48.665721416473396, 49.29474407626737, 48.650573222867905, 47.986331601296705, 44.70517481527021, 46.594349107434674, 43.68075763025592, 42.97852000882549, 45.18020129972889, 45.45771291179042, 42.60315702807519, 43.06799711719636, 43.39627596639818, 48.5109446894738, 46.34064235994893, 48.96537873052782, 53.6264527997663, 56.44191834234423, 56.120221230291556, 50.26999827354185, 45.05785080694383, 46.99144594130978, 44.078744842160134, 43.56811108127717, 43.140251098140595, 44.97963874570785, 43.36842713817474, 44.96134873359434, 44.48966803089265, 42.40133147085867, 43.24202091463151, 43.24002835058397, 43.4738447589259, 40.42035018244098, 44.33025506234939, 44.189775374627885, 42.004881828062, 42.59004846695931, 42.041842322195734, 44.977069593244984, 44.76470070500528, 41.950949238192656, 44.12902178302888, 45.12513906724992, 42.28772001881754, 49.4961577846158, 57.634883696033114, 54.89925407594251, 50.785935078897786, 51.36903855108446, 46.52707261423911, 45.963981074671594, 39.95956190170781, 39.45140315640358, 40.78444811605638, 45.79577415220199, 41.54995749073644, 40.37368966687111, 40.80436198942123, 41.83154444540701, 44.45151905859671, 43.48068537250642, 45.34845921301073, 44.00123880755517, 42.38511247019614, 40.84401322949318, 43.03746931014523, 42.77428611632317, 43.192555904388435, 41.6181988869944, 43.665036770605276, 41.37664364230248, 43.22213842022804, 45.64481389138007, 44.36551717019851, 45.330577127395145, 47.62617564970448, 52.989459883782175, 52.63221040848763, 51.28051065629529, 53.09788596245551, 48.65437399956488, 49.940311293448175, 47.82374151291386, 53.942944926600305, 58.544704914093025, 62.13412077196183, 53.88176379665252, 52.500524674692464, 48.35714855501729, 57.80633834100539, 7.060000569589677, 2.333356483328727, 17.177490649684785, 1.0763312251337114, 1.7029453044937504, 0.686230551331274, 65.47838064932054, 59.74774291438442, 67.31418717292048, 65.65265940081689, 66.48528052914527, 40.27046857341644, 38.483930941550966, 39.042845156884965, 66.36029028123426, 16.494456952618016, 0.6563686891909569, 0.24853384602935086, 0.18627124508061718, 0.09444454504597573, 0.10962519013593275, 0.1872704535602562, 0.1868318988671226, 0.17493453808128837, 0.1803357797043939, 0.1257193720929565, 0.11235346672155204], [0.0230913762483866, 0.05616588172532859, 0.0363182443224134, 0.026641565585328687, 0.02453382979447563, 0.07836648923975807, 0.026062464401606592, 0.0746742365581374, 0.03906997852027416, 0.09033112786710264, 0.047944628318110784, 0.07972611910513333, 0.030861622203261625, 0.02452208758181622, 0.048434637306678685, 2.923604552784274, 50.68703251500284, 46.44973131918138, 30.966141723817397, 27.277697786208126, 36.313032411759906, 60.29299551440824, 58.77261031058527, 59.499829507643184, 51.589824845713956, 58.98646969949046, 13.804117960314597, 2.373452667267092, 0.37147523775216074, 0.29695559773714314, 0.3596187707397246, 31.9683131863994, 64.48163578587194, 51.85145085857761, 62.09039026691068, 57.12767808668075, 61.14685235484954, 56.50168349665981, 61.57706968245968, 54.782751837084376, 56.564017803438254, 50.117574968645656, 50.50260266950054, 44.87908878634053, 46.782611108595326, 40.90671623906782, 41.556005785542155, 38.76525509741999, 39.533102204722745, 38.96380547554263, 40.41160721932688, 38.412888972989975, 37.45226129408806, 40.387351282181285, 39.30454569478189, 38.92110655384679, 40.643631104500066, 39.41605083404049, 42.4269720046751, 41.42549676279868, 42.70287936733615, 40.10100649249169, 39.82843314447711, 39.70504714596657, 40.716940203020656, 39.86790395552113, 41.0521145789854, 41.13328802970148, 41.89442788400958, 40.776877941623816, 42.282040426808024, 43.25388216203259, 45.92954266455866, 46.719319743494836, 52.67568988184775, 53.14287947070215, 48.5366322917323, 43.460159609394694, 42.18110607516381, 40.59775898533483, 38.45663908989199, 38.9508028184214, 39.260007181475245, 38.02210715509231, 37.07980086726528, 38.7583674153974, 39.463162422180176, 40.52592077562886, 39.575385355180316, 38.25992830338017, 37.24510523580736, 38.1531653096599, 36.87481387968987, 36.40564741626863, 37.52738644999843, 38.14506169288389, 37.10941083969609, 40.18227015772174, 40.54514038947321, 39.734402164336174, 40.2251063623736, 40.9269517467868, 39.14482285899501, 41.26723697108608, 49.37713738410704, 48.27561424624536, 48.13072973682035, 46.12845390073715, 42.037241381983605, 42.12334525200629, 38.246662847457394, 38.568579612239716, 38.08125649729083, 39.895227186141476, 37.57231720032231, 38.767651665595274, 37.52658628648327, 39.36732322938981, 37.749286697756865, 37.60337844971688, 37.634475000443, 35.48758529847668, 36.863909690610825, 36.20260200192852, 37.477317394748816, 36.03097477266866, 39.01452956661102, 37.736915542233376, 37.492100807928274, 37.38554962219731, 39.290888001841886, 35.92391367881529, 36.783897261465754, 38.38091773371543, 38.621531609565984, 38.5499365868107, 42.2352740072435, 39.5761659068446, 42.33311360882175, 41.40136241912842, 44.213042874490064, 48.90413092028711, 51.96263828585225, 52.98358025089387, 52.667892209945194, 49.95347869011664, 58.81636827222763, 52.82746599566553, 53.8325733523215, 2.417316532904102, 0.17907433932827366, 1.3547652070560765, 0.2768139204671306, 0.6049449453430792, 3.650170675208492, 57.589309677000976, 49.27739935536539, 55.59967171761298, 46.93651314704649, 45.44323152111423, 29.445752597624256, 26.214288319310835, 33.60684017981253, 39.958055711561634, 0.9369039583590724, 0.1412950197775518, 0.056420632773229194, 0.07869441317574632, 0.08897467726661314, 0.02606917916226291, 0.05457920255139471, 0.027422354736876105, 0.019731228427600958, 0.052626639784824465, 0.046673680790850235, 0.03833287553260884, 0.0185111970190079, 0.05426677657411464, 0.0737616189965798, 0.015434987238428045, 0.06127323286848203, 0.1544496380994397, 0.029272003166918314, 0.03337434846006575, 0.020101970932897062, 0.009951907315201337, 0.05237240201583313, 0.06724358971921668, 0.05573678438762023, 0.022256118245422844, 0.16375271873849054, 6.077157076328032, 61.85347518613262, 42.92560331283077, 28.40669320475671, 41.15523369081559, 42.993985914414935, 67.3739327153852, 63.47945451736451, 63.62787308231477, 56.01072826693135, 66.14390096356793, 16.773455142974854, 2.770231544010101, 1.2616918981075287, 0.3960788868848355, 0.24484801316453567, 34.25462353614069, 66.63622902285668, 53.43570793828657, 65.96824938251127, 58.91095622893303, 62.40418772543631, 58.59969262153872, 62.605566132453184, 57.01169360068537, 59.855929728477236, 54.43826967670072, 51.176728663905976, 45.502121986881384, 48.70848309609198, 42.7055505014235, 43.371015902488466, 40.00255892353673, 41.70982937658987, 40.22571040738014, 41.713088866203066, 42.19239073414957, 40.61016151981969, 41.774383744885846, 41.438895579307314, 41.84240941078433, 43.146593570709236, 42.034370207017474, 45.11859263143232, 44.46572980573101, 45.31912772886215, 43.30816384284727, 42.70886882658928, 41.35998141381049, 42.15442219088155, 40.881016869698804, 44.12221254840974, 43.611249308432306, 43.03439417193013, 42.463104878702474, 44.59147314871512, 44.84430128528226, 45.36467821367326, 46.596380895183934, 53.824528571098085, 54.20368448380501, 50.9917849879111, 45.97841539690572, 44.07795252338533, 43.78433173702609, 39.961189685329316, 40.07164362938174, 40.81857665892571, 39.857611656188965, 40.613271959366344, 40.42475108177432, 41.32043215536302, 39.80306325420257, 40.259544772486535, 41.403182398888376, 40.64016372926774, 39.907959199720814, 39.182508991610625, 40.15344465932539, 40.312869394979174, 39.25918740610923, 40.305526718016594, 39.951246476942494, 42.45275374381773, 42.77012840394051, 42.70619769250193, 41.256634804510306, 39.83466579068092, 41.96003344751174, 52.06705570220948, 50.33607059909452, 49.78327528122933, 46.000455194903964, 44.65981652659755, 44.50322374220818, 40.75435961446455, 40.32356177606891, 39.02442570655577, 41.40910910021874, 39.63599381908294, 39.81270444008612, 39.42771204056279, 41.077692354879076, 39.03688315422305, 39.49631821724677, 40.55676237229378, 37.628218820018155, 38.37445759004162, 37.949837484667384, 37.59280766210249, 38.53500412356469, 41.07811989322786, 39.33459889504218, 40.86173842030187, 40.189036246268984, 40.958915141321, 39.3847660095461, 39.940832584134995, 41.334509541911466, 41.62416873439666, 43.26578655550557, 43.78888168642598, 41.455220483964496, 46.01419133524741, 43.80471237244145, 47.619962615351525, 51.245566260430124, 53.956167236451186, 55.561507055836344, 56.30250161693942, 51.38912500873689, 59.53998673346735, 53.50371791470436, 56.979789041703754, 3.5130983014260573, 0.26572587028626476, 3.5917896272674685, 0.1570010020007049, 0.8241435993582973, 4.2503710235318835, 63.59168137273481, 54.404690265655525, 63.329616054411865, 52.01994803643996, 52.24189143027029, 42.98752577074113, 22.945469348661362, 35.71341183877761, 48.34447537699054, 1.5005712283234445, 0.10503993174361606, 0.06143756255867982, 0.07186902942316187, 0.032779297325760126, 0.02323297227943136, 0.04879012508618255, 0.02635414280267733, 0.03201863330398356, 0.043638133999681285, 0.013145190652369732, 0.035169755949849085, 0.1070838236820794, 0.18836153130377495, 0.19612039319209515, 0.09314752754665191, 0.14510195582143723, 0.1820044877428201, 0.11884817628250008, 0.18598733289587885, 0.1856664493079147, 0.3208769383209367, 0.12734826654195786, 0.35698039457201963, 0.3589914366602898, 0.2208068564293846, 0.31690400634561816, 7.992606345684298, 70.9398300417008, 57.10084515233194, 41.54734519220168, 36.0689825396384, 49.03040770561465, 68.8546274554345, 72.15432136289536, 69.0438739715084, 61.07734403302593, 71.44499994093373, 18.31316194226665, 7.13042623573734, 2.345067454922584, 0.5837462505986614, 0.8667911012326518, 37.855653532089725, 66.58582656614243, 55.889079878407145, 67.78588356510286, 61.46315228554511, 64.53769430037468, 57.641410519999845, 64.72992181777954, 58.24685581268803, 62.75354931431433, 55.976011368536184, 54.852091496990575, 49.071349405473285, 53.09349683023269, 45.99972955642208, 47.19719779106879, 42.06352910687847, 46.09752993429861, 43.33004282366845, 45.77140838869157, 43.52866380445419, 43.08225101040256, 46.478352854328776, 42.978406260090495, 43.340746971868704, 45.79217341638381, 44.83355791338029, 48.06397099648753, 47.00026342945714, 47.95914957600255, 46.403137483904445, 44.005255314611624, 41.96024525550104, 46.27298147447648, 42.59530836536039, 46.293707278467, 44.0246985035558, 46.385647635306086, 43.74602586992326, 46.022098833514804, 47.87826638067923, 47.50293085652013, 50.51198497895272, 55.61820491667717, 54.1841628474574, 52.09798359101819, 46.919474371017955, 46.81057760792394, 43.55558695331697, 40.92119370737384, 44.20458624439855, 43.932283539925855, 41.531600798330004, 42.69030032619354, 42.51306018521709, 42.64260822726835, 42.7526032540106, 43.533609913241484, 43.761507464993386, 42.5006184270305, 42.84354732882592, 41.95905677733883, 42.83076040206417, 43.157183970174486, 42.0529543968939, 40.69479450102776, 43.16020811757734, 43.318550279063565, 43.88915315751107, 43.51360974773284, 42.28268761788645, 40.27670906436059, 43.32663428398871, 54.46144696204893, 53.61856491334977, 52.354792933310236, 49.70498869496007, 45.59020273147091, 47.45554078009821, 43.2785342585656, 44.236412355976725, 40.688934479990316, 45.12830834234915, 42.061524775720414, 42.63736401834796, 41.641223199905895, 44.72723814748949, 40.0404215628101, 41.36665728784377, 42.14733839035034, 40.22654194985667, 40.94497503772859, 40.714645616469845, 40.31998457447175, 40.50376330652545, 43.843661508252545, 42.36377477645874, 41.90889358520508, 42.06001466320407, 44.307085621741514, 39.718551866469845, 42.300150009893606, 45.46415344361336, 44.39012219828945, 44.89558235291512, 45.90731067042197, 43.15531299960229, 47.75644148549726, 46.84892662109868, 50.57448010290823, 55.45231611497941, 55.70848611093337, 58.323189058611476, 57.32181187598937, 51.7475982635252, 63.197620453373084, 53.73947589628158, 59.367684856537856, 5.319016364312941, 0.5118901144352652, 6.597779152854797, 0.9792354029993858, 1.5871406346559527, 4.773392119715291, 70.00297192604312, 57.70625514368857, 68.3787262824274, 57.08155493582449, 57.24987952939926, 42.375902745031546, 36.52371860319568, 43.14764084354524, 59.431815608855224, 3.0339035632148867, 0.3700530721295265, 0.13476398232723438, 0.21121834675150536, 0.13365980448021045, 0.10070163711544969, 0.11861795153949531, 0.10462809819728137, 0.08361705668991612, 0.2872314292096323, 0.12414516099999029, 0.07712574855935189], [0.0319040801766659, 0.005795476214599706, 0.08594016469414197, 0.07636159883751985, 0.042509000838523915, 0.045714297391954935, 0.020174385393939672, 0.015483351326697778, 0.01377462093988734, 0.009239902325545349, 0.014895230415277185, 0.0472558731393468, 0.04037076900262506, 0.12029852627986863, 0.048277225390437155, 0.08822636258217596, 24.027606171946374, 53.66939883078299, 29.210492757058915, 37.16603417550364, 32.6957324243361, 57.20336414152577, 61.47897512682023, 58.812575340271, 51.02343459283152, 58.93035234943513, 22.28938037349332, 3.899124980934205, 0.9751110307631955, 0.08510119882562468, 0.3585175959573638, 26.994192792523293, 67.98685012325164, 57.88419738892586, 61.86103359345467, 55.37380203124016, 59.42123305413031, 55.066986391621256, 58.64052057266236, 58.33038660787768, 59.364962731638265, 54.53402649971747, 52.40689377630911, 47.76279180280624, 44.70172312951858, 40.854897806721354, 39.96999932873634, 39.54107638328306, 41.70411840561898, 39.92196990597633, 41.839542158188365, 39.2158216814841, 41.46114326292469, 39.789613446881695, 41.174017921570815, 40.28171008633029, 41.31092433006533, 39.3955486051498, 41.431141053476644, 41.32546455629411, 41.26373821689237, 41.961351363889634, 42.82110352669993, 40.55510320971089, 39.26252534312587, 40.92331178726689, 41.25172791942474, 41.327700307292325, 41.84167984993228, 42.123851237758515, 42.4439323333002, 44.6255781573634, 45.114536900674146, 48.3376229962995, 50.45093328722062, 49.5447128049789, 47.09951508429743, 43.024086183117284, 42.60404740610431, 40.18383518342049, 39.99653416295206, 38.44720578962757, 39.01388629790276, 39.09909978989632, 38.47183435193954, 37.73832367312524, 40.235728140800234, 37.12706542784168, 39.37631722419493, 39.285063282136, 39.6932957249303, 38.33442980243314, 37.94573860783731, 37.34479227373677, 39.4370472815729, 38.90721351869645, 37.27169890557566, 36.98000792534121, 38.934968210035755, 38.74859286892799, 40.94168024678385, 42.45036502038279, 42.27104602321502, 41.80298959055255, 49.63267587846326, 48.86068674825853, 46.42607942704232, 43.394322626052364, 44.284837938124134, 43.611092413625414, 39.03403159110777, 36.24970182295769, 40.368331709215724, 38.00905742952901, 37.5991815136325, 36.892291961177705, 38.664250143112675, 37.615718226278986, 38.76507074602189, 36.29851571975216, 37.41022525295135, 35.67488631894512, 37.900329328352406, 36.47763859841132, 38.3364615901824, 37.262826504245886, 38.335280956760535, 37.27651165377709, 38.370154749962595, 36.67408266375142, 37.17514191904376, 37.38609090928109, 38.15201213282924, 38.04193473631336, 38.24444278593987, 37.294958560697495, 39.43519984522174, 37.95442665776899, 43.726421863802024, 44.474613974171305, 50.86520225771012, 50.60530208772229, 56.70883171020016, 51.188103537405695, 58.01046240714289, 52.18227532602126, 60.58095632060882, 51.40211197637743, 63.23503202007663, 5.991295412663491, 0.039499056705784415, 0.8268816588867096, 0.11388680702375789, 0.5679739098395071, 8.363818968496016, 58.206631906570934, 46.54889275950771, 54.82175588607789, 54.518756712636645, 43.53188407036566, 24.65889203932978, 28.748500308682843, 48.40718623130552, 16.07971827830038, 0.23005617301790948, 0.06869548721419227, 0.021562429460426493, 0.09235579099866653, 0.0055289661958663455, 0.08180902024070102, 0.03256938923450728, 0.02175530550190278, 0.04223270739819254, 0.054604414504982775, 0.02790271484803769, 0.030488140933636217, 0.03845767508591375, 0.04863504973811008, 0.04120542179612864, 0.046756923904702555, 0.034615024022998354, 0.07669370561357468, 0.05071732651201948, 0.03408265420265737, 0.05030663826713159, 0.07213813312832387, 0.05345145983981991, 0.06760947331185303, 0.037327687736720815, 0.017431876809907057, 0.028095004832251903, 0.0781204447811169, 33.966407775878906, 60.988231705081084, 21.42153439983245, 36.99730165543095, 43.421081035367905, 59.5187274871334, 69.15232750677293, 65.3701820681172, 57.601943631326, 65.47426608300978, 23.82172880634185, 2.4421037060599176, 1.34644377616144, 0.11249408982093297, 0.08596124743381817, 29.17108274275257, 67.56179855715844, 56.920439658626435, 65.14380639599216, 58.872669973681056, 61.51474322042158, 57.66671765235163, 62.048130650674146, 59.49091003787134, 60.33920495740829, 57.4475512966033, 56.12890928022323, 48.93172479444935, 47.83942314886278, 42.83893069913311, 44.74806985547466, 41.30866504484608, 43.975912063352524, 41.58194834186185, 43.94217967987061, 42.825422056259654, 43.55825024266397, 40.44631627298171, 44.88552147342313, 40.515612786816014, 42.33865591787523, 40.86036166837139, 43.36816041700302, 43.041015132781, 44.618219790920136, 43.63194373346145, 44.4097654281124, 41.868638300126605, 40.4591973366276, 41.540230012709095, 40.98916053771973, 42.497978671904534, 43.99123284124559, 43.07033484981906, 45.49292010645713, 47.10040546232655, 47.88689167268815, 48.71688089063091, 52.12506363468786, 50.197104946259536, 48.59720937667355, 44.55469308360931, 43.62386757327665, 41.17184885086552, 41.865339586811686, 39.3515553012971, 41.23247300424884, 41.41786383044335, 39.6894282679404, 41.44631278130316, 41.7478959791122, 39.51469844387424, 42.133798368515514, 40.72296104123516, 42.214595271695046, 40.90223689233103, 39.6705852016326, 40.05666802006383, 41.855894519436745, 40.97986059804117, 39.55719732469128, 40.574142394527314, 40.12000645360639, 41.64727541708177, 42.542615244465495, 43.96675332900017, 42.34266850256151, 42.298443778868645, 49.89271333140712, 48.07648335733722, 49.454086442147535, 44.35284399217175, 46.33741032692694, 44.554179253116736, 41.42734812152001, 38.265239192593484, 42.522289522232555, 40.159277223771625, 39.94969321835426, 38.44131438962875, 40.8912895571801, 39.68511758312103, 41.93829174964659, 38.391853301755845, 40.3091392209453, 39.365212994237105, 40.6627252024989, 38.869378336014286, 39.46923032883675, 38.12923100686843, 40.47977016818139, 39.64959267647036, 41.508992256656775, 38.90761360045403, 40.892674153850926, 38.732193439237534, 40.641191390252885, 39.537004963044204, 41.26797437667847, 38.38671107445994, 41.90096647508683, 39.117617299479825, 45.751231716525176, 45.650207150367, 52.74573949075515, 52.24207970403856, 59.596319813882154, 53.31606388092042, 61.49421353493968, 52.76810092310752, 63.26346135908558, 52.47844173062233, 67.68686725247291, 7.195215455947384, 0.11263105102003583, 1.3364950519415641, 0.08175183177715348, 0.6383742644421516, 9.026801509241904, 68.59909288344845, 51.14740894686792, 61.527530147183334, 54.37520973144039, 51.534166412968794, 32.09842801094055, 23.557863120109808, 55.41915247517248, 21.25167223715013, 0.3861837581761422, 0.04942151560117641, 0.03294679861996443, 0.04955753068169279, 0.017842704865841136, 0.06742363570318108, 0.05057083134869895, 0.04418548083894196, 0.014567984467101915, 0.050947968772942984, 0.010934946551588515, 0.03757698423860054, 0.16612829610465035, 0.15504505695594897, 0.13868396230522664, 0.2313168473061054, 0.16066556826474207, 0.1724333529390635, 0.10798440600234656, 0.1191614526173761, 0.16034139049870355, 0.14158743553824965, 0.1518633405888273, 0.13386431931247636, 0.08189510554075241, 0.22768050372119875, 0.15770898981680795, 0.23684715942269374, 42.43127484475413, 67.06623062010735, 37.588944127482755, 49.96585769038047, 44.84252052922403, 67.04004487683697, 73.0588669930735, 69.39542816531274, 63.662236967394435, 69.97218916493078, 29.13381434256031, 7.968583299267677, 3.9194283946867916, 0.31272879651477264, 0.45345902563102786, 32.75715674123457, 69.63270018177649, 59.68216480747346, 66.10739154200401, 60.37229799455213, 64.27857075968097, 61.04070517324633, 62.90324264957059, 62.33590318310646, 62.926431702029326, 58.81799213347897, 58.3409809297131, 53.86796489838631, 50.62567095602713, 46.22160626995949, 46.13227821165516, 44.591139747250466, 46.64310024630639, 44.67319180888515, 46.157448061050914, 44.312306296440866, 46.21304373587332, 42.762291508336226, 46.337818253424864, 44.663107395172126, 44.70695557132844, 43.46408982430735, 47.06723790014944, 46.64161366801108, 47.613831950772195, 45.74233578097436, 47.87952546150454, 45.77063960413779, 41.2637617511134, 45.60663354012274, 44.293353403768236, 47.03701996034192, 47.441553608063735, 46.009406043637185, 46.885424275552076, 50.505285570698405, 51.243248139658284, 51.79045015765775, 52.65943950222385, 52.37718182225382, 50.11935180233371, 46.11429414441509, 45.94127447374406, 42.44164166911956, 45.18441392529396, 42.52490574313749, 44.690838552290394, 43.55620276543402, 42.72309526320427, 43.17747831344605, 44.78751320992747, 41.862523325027965, 43.639168739318855, 43.98930303512081, 44.80473241498394, 42.385120314936486, 43.08213726166756, 44.07380657811319, 45.14485682210615, 45.74373606712588, 42.32562188179263, 41.975181641117224, 42.18351048807944, 43.446321487426765, 45.98122773631927, 45.929126893320394, 44.93507277581, 44.04092142658849, 51.13623803661716, 50.649530733785326, 51.498170821897446, 46.63993489357733, 48.48326844553794, 46.810295197271536, 42.789693186360026, 39.89578808507612, 45.54356575012208, 41.895757567497995, 42.218411737872714, 39.717088822395574, 43.80545762277419, 41.45416144401797, 44.64782976335095, 40.282580852508545, 42.63189623432775, 40.65927743911743, 43.33057626601189, 41.31062622993223, 41.7896496095965, 41.456244222579464, 42.881598241867565, 40.93325499565371, 43.6717204893789, 41.14878139188213, 43.343241599298295, 41.18102327469857, 43.323202210087935, 41.527050848930116, 43.96395275669713, 40.82466809980331, 45.2303135010504, 41.57797498087729, 48.26096419365176, 47.7000887932316, 56.40689549907562, 54.71507133976106, 62.51405331396288, 54.69013291020548, 65.66365380440989, 57.08795624394571, 68.85301928366385, 54.48233750558669, 70.0659651910105, 8.875002841795645, 0.4301540793911104, 2.328921263256381, 0.30150383110007933, 1.2593560040958467, 9.752256620314814, 73.60939518097909, 55.53852196662657, 66.63210268943541, 64.12270361377348, 57.47501965492003, 36.778511847219164, 40.34724504716935, 62.73051323429231, 30.49845987750638, 0.3783488850439749, 0.16734600818205267, 0.12564978066591487, 0.16564533895542546, 0.14481605180809576, 0.1736499158845794, 0.13074989610862348, 0.1718501302023088, 0.11673460864732343, 0.20149606280028823, 0.2465444689075793, 0.12848679577150654], [0.04463870994626515, 0.07285113882033095, 0.042523690574471994, 0.02277002534678867, 0.015083994479819894, 0.06250911272100865, 0.02954545442105061, 0.00981354225997723, 0.09794416491903606, 0.03764549931210857, 0.0675017077235445, 0.06084117460094633, 0.01716740219102752, 0.030729537153796806, 0.12638540127344672, 0.12185516331585185, 5.582240743021812, 55.7669686502026, 41.41625958104288, 29.25514501910056, 24.718572862686653, 54.16948926064276, 49.02411622385825, 57.556828529604026, 53.91428024538102, 63.118584694400916, 30.00694767121346, 0.3715933991536018, 1.6672954948679095, 0.40928553789854055, 0.07499708133118768, 19.07172283818645, 73.45805445025044, 54.54921391702468, 61.27014029410578, 58.871387358634706, 62.27866011281168, 57.84754676203574, 60.58635350196593, 53.58000016981556, 56.978643709613436, 53.158647398794855, 53.02922879495929, 47.31641431008616, 45.72415951759585, 43.63266544957315, 42.67984720968431, 39.3136259817308, 40.53758590452133, 39.814924501603656, 42.06951856613159, 39.12341456259451, 41.53024758062055, 39.28149784764936, 40.03880946866928, 39.03728715835079, 39.83815670013428, 38.40527173011534, 39.47595719368228, 39.25144856975925, 41.68186679963143, 40.83217159394295, 41.00200237766389, 41.59853604532058, 41.492804634955625, 40.73164124642649, 40.65651609051613, 42.16309455133254, 41.52914147223196, 45.29842545909267, 45.41712814761747, 43.76600250121086, 46.16964663228681, 46.54705316789689, 47.75843797191497, 44.93404119245468, 42.77870662750737, 41.63404526249055, 38.945111459301366, 37.60620647861112, 38.804302292485396, 36.9086286329454, 38.9601812055034, 39.87842767469345, 38.2219244587806, 38.102201954011, 38.51861646098476, 38.71872009769563, 39.6753587261323, 39.40226762525497, 38.10039374136156, 38.77559054282404, 37.279751531539425, 37.58112292135916, 38.75628071446573, 37.135019994551136, 38.29285267860659, 37.682339683655776, 37.513509104328776, 36.820834221378455, 39.32456939451156, 39.80150607324416, 42.622168756300404, 43.217662995861424, 49.96977221581244, 49.73338273263747, 46.491837962981194, 41.82991273941533, 41.19304926164689, 41.93363197388188, 41.749194283639234, 39.08218260734312, 37.86343943688178, 38.5996957748167, 39.83885095965478, 36.64621422367711, 38.84706789447416, 39.45658852977138, 39.149725821710405, 36.97837621934953, 38.966649193917554, 36.31434640576763, 37.83910505233273, 36.88658099020682, 36.81538997157928, 37.3353236721408, 38.650729733128706, 37.41530079995432, 37.08362517818328, 36.36422718724897, 37.081554166732296, 35.530452882089925, 39.03260777073522, 36.55443468401509, 38.842847424168745, 37.47783514761156, 39.90955560438095, 41.31660392207485, 45.6250726023028, 47.32744009264054, 53.75260406924833, 51.92769388998709, 54.6081945973058, 51.089746182964696, 56.21675468260243, 51.97713144363896, 57.64798049003848, 51.60775007740144, 63.85468413752895, 13.485088059979102, 0.13905971311032772, 0.21094670729531398, 0.17002089610022886, 0.2190779798453854, 12.29793958125576, 56.31797928963938, 48.33803484516759, 62.285120256485484, 48.98399037699546, 40.567348849388864, 33.15762681345786, 32.33692184571297, 43.31137234164823, 2.0328197003372255, 0.19270915688285906, 0.05435530952508411, 0.05408375050812479, 0.0018353817182698198, 0.03117629664859945, 0.03695404367341149, 0.015241507902711391, 0.06832610259974195, 0.028144882901781992, 0.033725998139068965, 0.01817286386334848, 0.008354147637052643, 0.026812477886015852, 0.0411659874202263, 0.030629348175059405, 0.07248075063069982, 0.06113083244511678, 0.031196599893812692, 0.04772065485256815, 0.050893086234047535, 0.06276836836590402, 0.04388273055214555, 0.04554245237921996, 0.04138265623741093, 0.05076568581223969, 0.06122023873631993, 0.10810396934468901, 0.21232851540609715, 9.285103313384518, 65.35739906372564, 37.46787624974405, 29.409201991173532, 37.37273523884435, 60.7694693534605, 58.75095098249374, 64.52629589265393, 58.46539851157897, 68.0802260675738, 34.44892206499654, 0.6799249735570724, 2.717518811264346, 0.0959608322309871, 0.04547994726547792, 20.518532222317113, 75.8754425664102, 57.02945409282562, 64.2597355381135, 59.233641778269124, 65.44609954280239, 59.50180638221003, 61.58277280869023, 56.08656729421308, 59.98635638144709, 54.95814061933949, 54.730305825510335, 49.401526681838504, 47.97813777000674, 45.62849683146323, 45.54105151084162, 42.71234404656195, 43.533374571031146, 41.65896800256545, 43.229516398522165, 41.3776046229947, 42.899605843328665, 41.363515469335745, 43.76807351266184, 41.096041202545166, 42.477649027301425, 41.15921881891067, 41.69220224503548, 42.54392139373287, 42.7776671994117, 41.66038397819766, 43.056547718663374, 43.70775922652214, 42.19737214426841, 43.020712944769095, 41.65839533652029, 44.40375635700841, 43.65481115156605, 47.050477612403135, 46.129905177700905, 44.72393158943423, 47.21029458507415, 48.79552441258585, 49.661834778324256, 46.979396420140425, 44.416959055008434, 42.160470485687256, 41.00972160216301, 40.5290469046562, 41.08564299921836, 39.484041198607414, 41.13031879548104, 40.78562874947825, 40.574726827682994, 39.60733306023383, 40.781945643886445, 40.653276212753795, 41.3347174275306, 40.791053387426565, 40.933451114162324, 41.51828435159499, 38.91468171150454, 39.98226850263534, 40.53433425964848, 39.535487005787516, 39.54817587329496, 39.58239070830807, 40.17031085106635, 38.93878075384325, 41.140022739287346, 41.85020316031672, 44.134077718181, 46.073423047219556, 51.30547654244208, 51.66337320881506, 48.15572307955835, 45.23130193833382, 43.369646995298325, 44.182699418837025, 42.50576065432641, 39.7530726463564, 40.43095627138692, 40.54553262649044, 40.812143971843106, 39.1184292301055, 40.74315732525241, 40.69332753458331, 40.938028520153416, 40.35452888857934, 40.90088759699176, 38.18701928661716, 38.79855602018295, 38.881784792869325, 37.944758015294234, 39.879412189606704, 39.277979481604795, 39.981193773208126, 40.50499100838938, 38.68662726494574, 40.31451286808137, 38.14766614667831, 39.5633868248232, 39.439330101013184, 40.57079269040016, 39.47768303655809, 43.00975384250764, 41.74025127964635, 47.279834285859145, 49.73981934209024, 54.75030206864881, 53.572830077140566, 55.58977165529805, 54.84855351909515, 60.41477726351831, 54.16767320325298, 60.4383114845522, 55.04756281452795, 65.04055000120594, 14.825784583245555, 0.21744904709198784, 0.5817351778668742, 0.1299187673195716, 0.323806764978555, 14.82543255052259, 63.399053773572376, 52.373298675783225, 69.83171339957946, 50.85175245038925, 54.523875405711514, 35.82453258575932, 29.040203056027813, 53.66767691027734, 3.249071062572541, 0.14516515807519037, 0.00822675104568442, 0.09084186336446194, 0.073274310467945, 0.03457984143507577, 0.07169249212189067, 0.023983351570824464, 0.0623568527460579, 0.09128749671001589, 0.04751353149092005, 0.03865497336993295, 0.0376157061527333, 0.10590345073010653, 0.2053348068147898, 0.08907953938168865, 0.22181891986439306, 0.20144792183512644, 0.12763791672524907, 0.24511199174148424, 0.13996343639108444, 0.3123488781913635, 0.13319256745519178, 0.20945590019466417, 0.13647382928719445, 0.1510665325387832, 0.20034987269149673, 0.2435584113963189, 0.2513436267092343, 12.80089138015624, 73.95527762751426, 52.31889932386337, 42.143408175437685, 35.14173423090289, 64.7033203032709, 62.77624807050152, 71.4024422245641, 63.66319402571648, 75.22360740169403, 38.503440810788064, 2.096431841773372, 5.322858816192997, 0.6871691009690685, 0.2488337081646727, 23.296486177752097, 77.00686593209544, 60.52325825537405, 66.95356445927774, 64.71928434987223, 66.83983141376127, 62.63646264230052, 64.21685226501958, 59.252072995708836, 62.59315967559815, 56.667740960274976, 57.549685893520234, 52.89007879072621, 50.35731023357761, 48.72959721472956, 47.373006266932336, 45.34249328797864, 44.97896409803822, 43.87351466763405, 47.92235382141606, 43.71160314929101, 46.88831898473924, 44.99584990163004, 44.18583339260471, 42.009443544572406, 43.945815717020345, 43.81473795060189, 43.46823184720932, 43.91307569319203, 45.29949626614971, 45.53040619819395, 44.95295878379576, 47.251487316623816, 45.63667497327251, 46.731177068525746, 44.102239839492306, 46.08734353896111, 43.749136309469904, 49.85262278587588, 48.90291498553369, 48.03973859356296, 50.979959041841575, 50.07302076585832, 52.104396666249926, 47.13577347417032, 45.610465695781095, 43.98073657866448, 43.36685426773564, 42.18903710765224, 43.542152835476784, 40.638410429800714, 43.57562242015716, 43.067510743294996, 43.027879115073915, 42.45876281492172, 41.84003637683007, 44.03226475561819, 45.45037807956819, 43.61698773599441, 45.221935318362334, 43.156991774036044, 41.575547033740634, 42.52403105458906, 42.57553569732174, 40.769088114461596, 42.3754555948319, 41.709703860744355, 42.03591562086537, 41.16830695059992, 44.28870147274387, 44.02423174150529, 45.521251386211766, 45.71317688111336, 51.81010123222105, 53.26855221102315, 50.68056060421852, 45.99529727812737, 44.808894049736764, 45.99072771687662, 45.52503255105788, 42.10934631286129, 42.21700360698085, 43.43540553123721, 44.65091274630639, 40.932078284602014, 44.15831796584591, 43.63206140456661, 42.85504379580098, 43.185907486946356, 44.36002585195726, 40.090247431109034, 41.19527716790476, 41.48253194747433, 41.17615169094455, 41.96931377533944, 43.9605285275367, 42.80985024667556, 42.768743807269686, 41.39702820008801, 43.297204740585826, 40.40357028284381, 42.221620236673665, 42.55833218174596, 43.170610243274325, 41.17957592010498, 46.22941570897257, 44.928608709766024, 50.62156815682688, 51.599524867150095, 57.605230577530406, 55.74647818842242, 58.74892311711466, 55.37093085627402, 62.71878926984726, 58.57498953419348, 64.33861047990861, 57.29768537705945, 68.31203814475768, 16.297476503156847, 0.2300138543209722, 1.2617890993433616, 0.510893679193912, 0.744834500214746, 17.54444799115581, 69.43052553361463, 58.19489617501536, 70.94160295301869, 59.27232027053834, 54.49064508561165, 45.19438066790181, 40.56951399772398, 62.475594474423325, 6.74054705327557, 0.4464699442107832, 0.14414457574246392, 0.16981206053206999, 0.14525494357991606, 0.11538967234833587, 0.1905867256103985, 0.07933510782858057, 0.22100127422280852, 0.1719726736266767, 0.11883337546380297, 0.15991939862649288, 0.10584038637217977], [0.03731847169899172, 0.044307319462419524, 0.06329864676621172, 0.08485159971901486, 0.07313253057579841, 0.04244251206757561, 0.05270278126361871, 0.0682447670448211, 0.04051970415598443, 0.09554680767318896, 0.11368324980139734, 0.03386826832748709, 0.039976114977992354, 0.03524560248479247, 0.042309220429630055, 0.060677139854599396, 0.13312604037984727, 36.06218507212978, 44.894150687802224, 29.98520597334831, 25.002989807436546, 34.506247505064934, 47.93871794977496, 63.71437311172486, 55.64108410189229, 59.66258041320309, 38.079769918995524, 0.15450108856443437, 1.8179407403353722, 0.19668483145294652, 0.156192779240589, 13.35153135561174, 73.26683890435004, 54.89142502507856, 59.21271985576999, 51.66694256567186, 55.006715251553445, 56.21188309884841, 59.76127901384908, 57.230200998244754, 58.161736457578606, 53.14321287216679, 52.15724668195171, 45.98131795083323, 46.295813591249534, 43.37132969210225, 41.62836567048104, 39.78858186352638, 39.56417129885766, 40.87384285465364, 38.84218062123945, 39.92317015124906, 41.272893028874556, 40.071745611006214, 39.76340809176045, 41.637034108561856, 41.06536434542748, 39.10286526526175, 40.575546603049006, 37.28856509731662, 40.95644012574227, 39.23054625911098, 40.12659211312571, 40.17045205639255, 40.101218300481, 39.12421080373949, 41.54740795012444, 40.294077319483605, 42.92015514066143, 46.72268121473251, 45.82706289906656, 42.7111045775875, 43.8156008720398, 44.1422519376201, 44.00822454883207, 42.6488055721406, 40.02048023285405, 39.46994027783794, 39.713821488042036, 36.87822634173978, 39.540284064508256, 38.5561417764233, 37.349656012750444, 38.137409148677705, 38.20455620365758, 37.475897496746434, 39.17127532343711, 38.969092830534905, 38.006445130994244, 39.2114011702999, 39.67432714277698, 38.57361985791115, 37.51402685719152, 38.63216515510313, 37.624723988194624, 36.8370218430796, 37.99464664151592, 36.701782441908314, 38.34518101907546, 36.88267038714501, 36.04531495801864, 37.54316614520165, 38.66611326894453, 41.19310809719948, 44.64327589158089, 46.65207070689048, 44.81853915799049, 43.73117969882104, 42.01929653844526, 42.84641458142189, 41.536056610845755, 38.44348346033404, 36.60755534325877, 37.991038060957386, 37.57190927382439, 36.57194022209414, 38.31919531668387, 40.07100428304365, 38.67485623205862, 36.255185296458585, 37.69920195302656, 37.81039722504155, 36.39599838564473, 36.618753710100734, 37.428166174119525, 35.69868333878056, 37.73500142558929, 35.8197747507403, 36.76589358237482, 37.79043236086446, 37.75015354156494, 35.49077418542678, 38.37450858085386, 37.17908782343711, 37.991897060025124, 38.27887727368263, 38.81408076132498, 39.37047681500835, 45.36464291234171, 47.38960965987175, 54.536795693059126, 51.3204639188705, 54.982412245965776, 52.739848090756325, 54.98231418671147, 45.281535733130674, 54.62293878678353, 49.89714560970184, 64.05275206412038, 21.803118259676044, 0.14598246663808823, 0.38385187846518337, 0.12442558748467315, 0.16444276477540695, 11.551197767257692, 55.666728558078894, 46.23764484159408, 52.99612006833477, 40.615837189459036, 42.024995742305634, 21.733672695775187, 38.69600565202775, 32.65153907960461, 0.18318683720163761, 0.038213813977856795, 0.03376599175915603, 0.004598065945995791, 0.06392714529929143, 0.0248072408289919, 0.054743053436639814, 0.037411179829148516, 0.04630564449114665, 0.03783037548043555, 0.0009802239231160663, 0.07269921592406689, 0.05858773463255456, 0.037029484181755015, 0.03048795324209477, 0.0376088343440525, 0.0329162240509064, 0.04530034944294922, 0.031224198211284897, 0.007467932817000415, 0.044117551822696006, 0.029684579818539565, 0.09539496138571732, 0.032135377442764665, 0.07620809013925253, 0.03192246437162882, 0.021329193991879304, 0.03570156269556573, 0.08308159187436105, 0.996546354745665, 47.54027574293075, 50.49434608028781, 22.029246822480236, 28.31624923213836, 45.514689260913485, 51.66646403651084, 67.15020856549664, 60.4706161252914, 63.6867949270433, 42.339534528793834, 0.4506397607826418, 1.783821267947074, 0.30601520031209917, 0.23053713833853123, 14.655972430782935, 75.32766003762522, 58.410410804133264, 61.57350424797305, 54.40645140986289, 58.51640109092959, 59.201941182536466, 61.603388786315925, 58.103281374900575, 59.14616115631596, 55.14337455072711, 54.05632495880128, 48.47413716777679, 46.83870492442962, 45.32985541128343, 45.5072485246966, 40.91671436063705, 42.095504268523186, 42.646585510623076, 41.347971116342855, 42.41755439389137, 42.98214427886471, 41.00007649390928, 42.82479055466191, 42.513930951395345, 43.95894781235726, 40.52057850745417, 41.541889175291985, 39.22406258121614, 43.9802658942438, 42.27315233599755, 41.557896367965206, 43.09220990827007, 42.0383474903722, 42.66232598212458, 44.10871959501698, 42.64022734857375, 44.31468325276529, 46.781520689687426, 49.29850562926262, 44.54645610624745, 45.733588895490094, 47.00274628977622, 46.7380137597361, 44.37879439323179, 43.177137067241055, 41.85837737975582, 42.722997203949966, 38.67485230968845, 40.51000771983978, 39.95606706988427, 39.20547054659936, 39.95529436296032, 40.075452250819055, 39.78216878829464, 41.089710497087054, 39.91562743340769, 40.94248825503934, 42.110656384498846, 41.7372271322435, 40.30813901655136, 39.628839415888635, 40.945586927475475, 39.92580990637503, 39.86691944060787, 40.81212043762207, 38.62731318319998, 40.21746558527793, 39.661642197639715, 38.218684581018266, 41.53448374040666, 40.51478124433949, 43.475884391415505, 48.13375780659337, 47.86975091503513, 46.31977142826204, 45.83755131690733, 44.317103355161606, 44.15583510552683, 44.354934615473596, 40.888179117633456, 38.388801697761785, 40.28239257874028, 39.20833779919533, 39.052670694166615, 40.218520702854285, 41.614680520949825, 41.1478792467425, 39.08341423157723, 39.65213044997185, 39.27888162674443, 39.018047932655584, 39.129843327306936, 39.76794235167965, 37.559545963041245, 40.288852722414084, 37.97307752793835, 38.78319994095833, 38.50139725592829, 39.33753282793107, 37.38938570022583, 39.921577668959095, 40.57385998387491, 38.27464111389653, 41.261749575215006, 40.315932766083755, 43.55642634053385, 48.777736463854396, 50.12951466345018, 57.752727385490175, 53.822547774161066, 56.60791697040681, 55.65681672865345, 56.55092493180306, 49.45699684081539, 58.56896085123862, 53.67886743237896, 66.01061098037228, 23.914310470704113, 0.028145725598498702, 0.24495569448317253, 0.0854294368576619, 0.43387343626349206, 14.083707447974914, 63.759401921303045, 51.44001383935252, 60.302185627721975, 45.83038122423234, 53.648155273929724, 22.233963166513753, 41.1384851701798, 39.497463549337084, 0.4026073656014858, 0.10871893110414667, 0.0473234344333891, 0.016714485264533473, 0.04974737876064835, 0.027275917030149893, 0.022607354236946955, 0.04620031123199771, 0.04305625957767329, 0.05854116797807717, 0.06638045377668834, 0.055302665343568216, 0.037466487546841946, 0.16125522614006074, 0.09934956087700783, 0.13702994783318814, 0.20196058787405494, 0.16474238176259304, 0.11079052478195199, 0.11440059155105584, 0.20634507760405543, 0.14524973418203094, 0.30889296363438334, 0.25023722720723, 0.11675350803641543, 0.10444218397981699, 0.1344982877133354, 0.14499151658627296, 0.20224390251021232, 1.1614239816704106, 55.387326363594305, 59.1670830788151, 40.61682954911263, 36.1502383601281, 45.90696550184681, 59.49870378740373, 73.03137902290591, 64.8756221802004, 69.7039774925478, 49.81679193435177, 0.7017348226039641, 5.738831566226098, 0.588162103968282, 0.3166914629119058, 15.997236717131832, 78.03186755026542, 59.352430758937714, 64.62923849782636, 56.67748805015319, 60.2826718361147, 62.421485377896225, 64.09760044467065, 60.84085256822648, 64.20936053799045, 59.986787842166045, 57.93068139783798, 50.70928412099039, 50.22444386636057, 49.13776689960111, 46.953116539985906, 43.73885185487809, 43.98448636454921, 45.78057496778427, 42.26020459205874, 44.27716185969692, 45.85999119666315, 44.15783551431472, 45.388753721790934, 46.59890690157491, 47.99092077439832, 42.30365660882766, 45.0905006162582, 41.49158870020221, 48.518177540071555, 44.17774546530939, 44.942282092186716, 44.966208550237845, 44.56804483167587, 46.308702499635764, 45.829463389612016, 43.32736776721093, 47.14872514047931, 49.73244920853646, 51.273748490118216, 46.15162726371519, 47.41128859981414, 48.47132482836324, 48.50645749799667, 47.40911952910885, 44.55277896696522, 43.59901151349468, 45.22098610478063, 39.40509957651938, 43.2013733925358, 42.11813242204728, 41.334744884121804, 42.257423631606564, 42.45521306991577, 41.73654463983352, 42.942642088859316, 41.37705549117058, 43.11220222903837, 44.074351787567146, 44.61998877986785, 43.25924404205815, 42.68598179663382, 44.845011234283454, 42.47328735166981, 42.71381493537657, 42.80349992936657, 40.54294778454689, 42.31816545609505, 41.53588402655817, 41.18698919973066, 41.909379959106445, 41.44719531459194, 44.27308259471771, 51.25288148080149, 49.20640445524647, 49.198002738337365, 47.52878712069604, 46.734938621521, 46.40018393916469, 45.00533811507687, 43.04645153783983, 39.081123567396595, 43.328677838848485, 40.45609474182129, 41.46573635839647, 42.42228084994901, 45.03631307232765, 42.41293776419855, 40.184097982222035, 42.60138019438713, 41.48361844401206, 39.491423099271714, 40.34938273891326, 42.226558500720614, 38.74429002884896, 43.42101435507498, 40.33330494357694, 41.70393797659105, 42.17848593188871, 43.00605112506498, 40.24167445398147, 42.96668229564544, 43.169543358587454, 42.813992269577525, 43.63636424464565, 42.49056539227886, 45.371671799690496, 50.110051862655155, 52.32037805741834, 60.485885912372225, 56.33937974129954, 60.281471590841974, 59.61852435142764, 60.87249432840655, 52.86984328300723, 61.087408834888095, 56.348671836237756, 69.17524983805995, 25.67483494358678, 0.36819451218170507, 1.3276534167028244, 0.5987916658482244, 0.6799822156467746, 16.56532633689142, 67.49892296329622, 55.97863935655164, 67.1186883987919, 52.399719761263945, 53.177725807313, 31.72574204783286, 50.85586309432984, 48.696657150022446, 0.773196300912288, 0.24775689497830408, 0.10764430892924148, 0.12535320504778816, 0.20187221197110994, 0.08841996832240014, 0.23944059687276043, 0.1899272311599024, 0.1996722219571952, 0.12340545714382203, 0.1577677027953248, 0.1775873167019698, 0.17382651447288452], [0.037065183879026485, 0.014477485542996757, 0.04959689227924232, 0.05328943224383458, 0.008629403985856522, 0.051970259481740576, 0.05592013987141752, 0.023308261485409834, 0.05333391513915793, 0.029538691779899023, 0.03307853126898408, 0.04912427348655559, 0.03340904841259603, 0.05277575496884604, 0.07478142758050273, 0.2365920981091838, 0.2641584237496699, 9.590237236792042, 57.098323068311146, 33.34293134750859, 23.172209801212436, 30.169935880168794, 43.13334772663732, 62.84801567754438, 56.411194416784475, 59.64791859349897, 44.705045377054525, 0.3482623446372248, 1.6323283002261193, 0.18396078518802123, 0.069852065475237, 8.55328905966974, 72.38121478788315, 56.79565729633455, 59.74568759241412, 47.56516710404427, 46.123594084093654, 42.81803231085501, 49.61495853239491, 47.20305781210623, 48.928904610295454, 45.566746957840465, 45.17899713208599, 44.38509764209871, 44.10715064694805, 40.257528674217966, 41.6979524397081, 40.11145960900092, 39.72347836340628, 41.48473631951117, 40.93948764185752, 42.812568449204974, 41.2646835081039, 39.909343796391646, 42.12480437371039, 38.82740505280034, 40.96939571442143, 38.62005287601102, 39.651871573540475, 41.27200657321561, 39.85291657909271, 38.805569218051055, 43.01078150349279, 39.581845498854115, 40.45118393436555, 41.839636295072495, 41.976252448174264, 41.93425563073928, 40.93530639525383, 45.73785643423758, 45.80924357137373, 43.21259137122862, 41.905135954580004, 44.443788066987075, 43.68884555755123, 41.71454014316682, 41.709990193766934, 41.419726956275206, 39.670161585653986, 38.34506727034046, 38.51441168016003, 39.39918856466971, 38.91668212029242, 37.83430407124181, 39.9823312605581, 38.635028485328924, 40.12453679115542, 39.03022689204062, 39.304883018616714, 38.773550910334436, 38.83689718861734, 40.20421189646567, 39.747804903214984, 38.89771746050927, 38.28324679405459, 37.87272760944982, 35.75243549962198, 37.38964849902738, 36.581706923823205, 37.6043394304091, 37.54137362203291, 37.650486115486395, 38.550772051657404, 39.56128443441084, 42.11076621086367, 43.77455326818651, 44.547977985874304, 41.34093830662389, 39.99503973991641, 42.673991111017045, 44.10338517158262, 38.27227200231245, 37.90342015604819, 37.89801512995074, 38.129403591156006, 37.400799797427275, 38.25107159153108, 38.03749069090813, 39.16629783568844, 36.95904285677018, 37.08732397325578, 37.08532356446789, 38.68543094204318, 35.81657409667969, 37.62704995370681, 36.26272801429995, 36.80062617025068, 36.49085306352185, 36.31989655956146, 36.361065756890085, 36.66922284710792, 37.25276562475389, 35.905733493066606, 36.18519452310378, 36.84509408089423, 36.9795137066995, 38.029473366275916, 36.659581661224365, 40.77656415201003, 45.014896931186804, 49.36823752618606, 49.47853457543158, 50.38225650787354, 45.60596281482328, 44.27407887674148, 43.04531797286003, 54.92350216834776, 53.690516871790734, 61.75217605406239, 29.023907569146928, 0.09443925903929819, 0.28411663828357575, 0.1632567227727944, 0.18581344625882565, 11.781759588949143, 54.4234666516704, 46.414080896685206, 51.94641536281955, 38.75415086746216, 35.01510443225984, 30.90451148248488, 49.98735227892476, 8.26567832500704, 0.2198834753324909, 0.10084655796808582, 0.01366590923299232, 0.00404500792125961, 0.011262083332234574, 0.020150349385315375, 0.02866491296088263, 0.05623927677891428, 0.040449997815754146, 0.07826996216129872, 0.04560070953542187, 0.07497425191104412, 0.01675118662176594, 0.025993945497658946, 0.025985141232189153, 0.09831057711234016, 0.060189823665085344, 0.009362478308650035, 0.07216557439777159, 0.01540193533254487, 0.041134401615108215, 0.006262190863414998, 0.03616132653288303, 0.026133815915654265, 0.01669003556843006, 0.015582529069375128, 0.06690588284043536, 0.0093045208843485, 0.14514067390513036, 0.1829904275796106, 15.061090511660423, 63.20959152713899, 34.87404815612301, 22.784591374858735, 39.91876925191572, 48.26620840257215, 67.73534774780273, 60.4124120743044, 63.77574643781109, 51.767676876437285, 0.06149535623168754, 2.9272486798224913, 0.1190174510702491, 0.09832471909542238, 9.425399630300461, 73.68440658815446, 58.75970179034818, 61.630594345831106, 48.469187136619325, 49.46613988568706, 47.69484458431121, 51.267868857229914, 50.50315572369484, 52.566840187195815, 47.45522306811425, 48.498157762712054, 45.454359285293094, 45.829322184285815, 42.34151924810102, 43.2384515577747, 42.64404381475141, 42.97732760829311, 43.99645743831512, 44.00764796041673, 44.28399855090726, 43.137701557528594, 41.71059816114364, 43.642734173805486, 40.43002666965608, 42.66355760635869, 40.46303341465612, 42.19244956970215, 42.04522340528427, 43.61350467128139, 41.29383456322455, 44.463348927036414, 41.16906789041335, 42.86595190725019, 42.486548885222405, 45.09666658216908, 43.39810379089848, 44.0904099710526, 49.168157423696215, 48.39431693477016, 44.21811842149304, 44.780904016187115, 45.662201758353945, 46.10099338716077, 43.69933005302183, 42.31834980749315, 43.052429229982444, 41.38299788198164, 40.385413631316155, 41.28380114032377, 41.82999510918894, 41.719776507346864, 40.393117166334584, 42.5407011278214, 41.2084916330153, 40.802538087291104, 40.59267167122134, 40.48767766644878, 41.25240256709438, 40.19437066970333, 41.06392091320407, 40.57811967788204, 40.266012760900686, 40.986881640649614, 39.60707418380245, 37.96473072421166, 39.48254677557176, 39.75522994995117, 39.78028605061193, 38.44876297058598, 41.32979877533452, 40.27561864545269, 40.89708682029478, 43.032566347429835, 44.589253087197584, 46.76393670420493, 43.67951031654112, 43.37333010089013, 43.739240169525154, 46.39302169123004, 41.35220727612896, 38.65075718971991, 39.70742017992082, 40.74491846945978, 39.28074867494645, 40.359682882985766, 40.019295677062004, 39.92544904831917, 39.43794158197219, 39.30259235443608, 38.52004812609765, 39.025873061149355, 38.08853641633065, 38.84280035572667, 38.09387868450534, 39.31088816735053, 38.62143355031168, 38.807263681965495, 38.744650886904815, 38.730228331781205, 38.96856331056164, 38.375395036512806, 39.201854121300485, 39.134554093883885, 38.88260849060551, 39.60369310071392, 39.5653990007216, 42.900923759706565, 47.96478209957, 51.990263538975874, 53.025384872190415, 53.763449422774784, 50.16153689353697, 46.89027624745523, 46.447260225972826, 57.93225034590691, 55.71465599921442, 63.97310441540134, 30.208388836153095, 0.11577444000830574, 0.4124124023702837, 0.21479760146429464, 0.1544231161355011, 15.157866170329434, 59.51027085704189, 53.03886998084284, 57.72273694315265, 46.5488653029165, 46.24637211522749, 24.637622987070394, 57.6772492162643, 11.584701672677072, 0.2688147367969636, 0.07800630534127836, 0.04343410946368691, 0.011731295906487974, 0.024569596524440476, 0.05529601570038546, 0.04107921264104305, 0.025781105204875913, 0.03597304510373262, 0.011517525774486845, 0.07426652456483535, 0.028142956190652428, 0.02015399213339533, 0.10099328678822327, 0.10737218683765781, 0.23846207276707698, 0.2416794888314701, 0.18676521857419323, 0.18513441656626042, 0.1248459475896051, 0.17281711702385258, 0.09641709887693006, 0.11992603900932497, 0.17356926214791116, 0.14947493891081504, 0.13865935556109876, 0.13799888051805959, 0.1840528996000367, 0.5309998712712719, 0.3629468405439008, 20.689382822282855, 74.64681502311461, 46.117585012989665, 31.902472280686904, 43.63417163971932, 52.62804092899446, 73.87439050982076, 67.49386310577393, 71.21399587200534, 56.63292208025533, 1.0038616976911023, 5.089557709232454, 0.2397454539013486, 0.20776299909958917, 9.938267180996558, 74.77111493387531, 62.29682460907967, 64.65010158477291, 51.03017322478756, 53.04568313783216, 48.80859375000001, 54.95972917925928, 52.28626128165953, 52.926847088721495, 50.43304335686469, 50.63776754563855, 48.39681548456992, 49.14430941304853, 44.66035389131115, 46.46925687789918, 45.1645863440729, 44.54346333780597, 46.16159008395287, 46.152223463981386, 47.69497010015672, 46.092521067588564, 44.58547192235147, 48.478867546204604, 42.70248713031892, 44.71138000488282, 43.94174037441131, 43.574971306708555, 46.160338847867905, 45.181342709449034, 43.143796920776374, 47.955858707427986, 44.27001137887278, 45.38080699982182, 46.52222456470613, 46.34640432173207, 46.06735906293316, 45.87056590664772, 51.04613334901872, 50.69403002339025, 47.980553950032885, 47.07978163996051, 49.01975847059681, 48.28303929298155, 45.22796007894701, 44.78170810207244, 46.366267204284675, 43.69544690655124, 41.9544558371267, 42.284570355569166, 45.649987497637355, 44.31604823758526, 43.75483551333028, 44.83267145772135, 43.67843950948408, 43.571601990730535, 42.92364605011479, 43.39588372938095, 43.087691337831565, 43.752360497751546, 44.30382613212832, 43.95769657627229, 43.30215477174328, 43.25826737188524, 42.88938806902978, 41.530741799262266, 41.98994936481599, 41.52397571071502, 42.835765346404045, 39.74377270667784, 43.927596307569935, 42.73028104535995, 44.6186355621584, 46.67143937080137, 46.729929754810954, 48.82529520219373, 46.52312670984576, 44.51836016870315, 45.655474893508426, 49.88485682395197, 44.4108283904291, 42.102882246817316, 41.52344619074176, 44.07519509715419, 42.43558160720333, 42.79646319727744, 40.92905413719916, 42.357204806420114, 42.419511656607355, 40.60374059984761, 41.16267834940265, 42.563568545926, 40.671232823402654, 41.92928206536078, 40.77149252737723, 42.100728865592714, 44.630308535791215, 41.161811505594564, 41.62691831588745, 41.38206435788063, 42.198548855320105, 40.96397499884329, 42.793348835360625, 41.405037679979884, 41.369971690639375, 42.11454737570978, 41.594535227744814, 45.596219647315245, 49.997719103290194, 54.14082457942348, 54.764979577833614, 55.64453578764393, 52.09550857543946, 49.52365359952373, 48.18194412416028, 61.7315169303648, 59.8947141247411, 65.09936986430999, 31.5694591306871, 0.2714020302218776, 1.328487533234781, 0.577054932232826, 0.3781222149489388, 17.20645146985208, 66.89893368751773, 57.13242415458926, 66.55548311048939, 47.99854978438347, 50.84672004945817, 38.64088458399619, 66.35404586791992, 16.79467712679217, 0.25616808073414915, 0.19676277323836283, 0.15707024102730138, 0.15466720706993534, 0.1331458207700522, 0.17541862904064118, 0.12095224442741564, 0.08319451323439998, 0.09826610570833569, 0.147624530138508, 0.1124025499748607, 0.15114430578485613, 0.11578025461565103], [0.10318182378766999, 0.06596374025027599, 0.012839491884674759, 0.06165581334742808, 0.011002199495241288, 0.060965947341173894, 0.02489663371365638, 0.06439430188507804, 0.024763280788676876, 0.04677355184309906, 0.042151134356015155, 0.04024869672233059, 0.059986699282401995, 0.13398557570913147, 0.10239840695454229, 0.011419865843509475, 0.11132358408142483, 0.7449826922628188, 40.35333256567679, 37.90640115737915, 25.68001247221424, 26.41786913717947, 35.8057758115953, 58.9823982792516, 60.32197790761148, 52.185479902452045, 54.244022138657115, 0.30842509841726673, 1.5161166844829437, 0.3149134954137187, 0.07409254599723124, 2.8050043361802257, 64.88273735969298, 61.11328078854469, 59.94876830808578, 57.11233769693683, 48.531690105315185, 44.2673167105644, 44.04786794416366, 44.167025627628455, 43.22496644912228, 41.6767990973688, 41.40119767958119, 41.211496168567294, 40.29532071082823, 40.28771915743428, 40.345225026530606, 39.898219954582956, 40.970764621611565, 39.91023417442076, 39.98666940196868, 41.64806381348641, 41.33791023685087, 40.468383527571156, 40.568219615567116, 41.836674905592396, 41.81520385126914, 38.23530366343837, 40.17384098422143, 40.16583150432956, 39.802094428770005, 39.45680818250103, 40.49194520519626, 41.23375169692501, 42.16114905572707, 42.706295751756244, 44.6646684985007, 41.73953740827499, 41.12487846805204, 44.78771717317643, 41.33999693778254, 39.41991829103039, 41.853470494670255, 42.982242338119015, 43.97818703805247, 40.90236633054672, 39.54877991830149, 40.228844381147816, 40.75139822498445, 40.678238176530414, 38.70737660315729, 40.363981800694624, 39.97528668372862, 38.74131294988817, 38.528414541675204, 39.87143408867621, 40.61221291941982, 39.11883323423324, 41.18374539959816, 40.51952731224799, 41.837671187616166, 41.05570747006325, 38.831582377033854, 37.76681184768677, 37.90199633567564, 38.185469950399096, 37.74871403171171, 37.39664208504462, 38.355641980325025, 37.10888916446317, 37.92622481623004, 38.52262120093069, 41.0625284717929, 38.51337225206437, 41.014565729325824, 40.7499038019488, 44.164460397535755, 40.91467865051762, 41.89349828227874, 41.05009455834666, 43.605757990191066, 40.41738879296088, 37.10377439375847, 38.901078931746945, 36.97629344078803, 36.260245153980875, 38.2416892820789, 37.138910985762074, 38.730161651488274, 39.1771706458061, 39.08070387378816, 36.59090880424746, 38.003699471873624, 38.073847140035326, 36.56320510372039, 35.91875183966852, 35.92781643713675, 36.631662230337824, 38.33743041561496, 37.427597430444536, 36.31951216728457, 35.66690037327428, 38.98637871588431, 36.6453944483111, 37.71055329230524, 38.62634828013759, 39.68957731800695, 38.9955884410489, 38.47119892797163, 37.17561260346444, 40.81488178622338, 39.21225232462729, 42.24159686796127, 39.46586885759908, 43.28592008160007, 47.969751742578325, 57.34489502445344, 51.516158811507694, 65.2549820561563, 23.481406319525934, 0.12289016342331326, 0.16791220844512986, 0.3113923101655899, 0.4246373576742988, 20.31198020904295, 57.37774095227642, 49.535809024687744, 51.97890043258668, 29.89134757749496, 26.986922679408906, 34.58994303980182, 40.206828117370605, 0.5890252705543273, 0.07498917530380911, 0.053892354931562185, 0.023007393859687354, 0.0944538836577727, 0.060043018236155474, 0.0551431620072934, 0.025918761628770062, 0.0333373655655211, 0.05995544672553098, 0.050514987369458524, 0.054181518649021466, 0.04424525867967356, 0.016008448099807625, 0.07189991042738961, 0.025929676466471246, 0.10555558552544926, 0.04305281218201403, 0.03273371509426544, 0.007930805534875442, 0.04548888751155427, 0.03748830573092546, 0.023915531722107725, 0.020596534314174807, 0.04395125711697244, 0.04351951677592532, 0.03325161351371677, 0.07016576315847135, 0.06514418704975998, 0.12211722667298971, 0.1469620479451072, 1.955354115174663, 51.60081532693679, 39.902193315567516, 23.907216864247477, 32.262659611240515, 45.801630250869266, 60.755533172238266, 66.42568403674711, 56.847648312968595, 57.84781348320746, 0.38249096923297454, 2.027968463878478, 0.20796331577003005, 0.09790713988965559, 3.4134887303075487, 66.35909003596153, 63.680193578043294, 61.43594280365975, 59.22705219637964, 50.42869344834359, 45.787815663122366, 46.18974093467959, 45.96913899144819, 45.359461461344075, 45.25566377947408, 44.9012384107036, 45.70792090508246, 44.36416395248906, 42.678980365876235, 42.35537698191982, 42.385245830782004, 42.83005437543316, 41.22734646643362, 42.85328265159361, 43.12840161785003, 43.27102684205578, 41.26509143460182, 41.62263508765928, 42.56381957761703, 42.53643358907392, 41.00075506394909, 42.17803878168906, 42.72602135135282, 40.453333393219985, 40.88050303920623, 42.82026806185323, 42.125341738424, 43.77785982624177, 44.40215210760794, 44.8520322768919, 45.15598066391484, 43.32966235376174, 45.677863782452, 45.076509521853545, 42.59672826336276, 44.24193505317935, 45.50062756384573, 45.55188509725755, 42.84429257915866, 42.06426259010069, 42.73372880874142, 41.49162400153376, 42.2343953963249, 40.9148943808771, 40.9402838830025, 42.12285495573475, 41.63533572227725, 41.3899600890375, 41.10266608576621, 43.26628861888763, 41.177410771769864, 43.71028131054294, 42.545627624757834, 42.92334010524135, 43.17870209293981, 40.37559986114502, 41.37138374390141, 39.72513360361899, 39.373806907284646, 40.852846407121234, 38.82528305053711, 39.19984586777226, 38.66019441235451, 39.20914972982099, 39.8306453612543, 41.78942211212651, 41.085411579378196, 43.41864916586107, 42.60630669132356, 44.81083954534223, 44.17774154293922, 45.71817005834272, 43.138611547408566, 44.22900299872122, 41.571605051717455, 38.46394254315285, 40.372505111079064, 40.03824856973464, 37.207187683351584, 40.43116807937622, 39.55942130857898, 40.27200222015381, 40.347527457821755, 41.91079201236848, 38.02659434656943, 41.937703394120746, 38.935129027212824, 39.41419947531916, 38.781623148149066, 39.96360586535546, 37.65849951774844, 40.702466657084805, 38.456317455537864, 39.373791217803955, 37.442804459602606, 42.22313819393035, 38.3895783270559, 39.39796870754611, 39.68629037180255, 42.740592956542976, 41.203153287210775, 41.10916937551191, 38.41785077125796, 44.31588742040819, 41.38125634962513, 45.188375519168, 41.49798216358308, 47.21805303327499, 50.56259924365629, 60.85413763600012, 54.274189087652395, 66.71475487370645, 25.45596080441629, 0.04231430725344727, 0.0505467685269973, 0.38335168433766215, 0.5795284156357089, 22.840057611465458, 63.43293912949101, 56.1125216176433, 55.07970663809008, 40.69791670768492, 28.476009330441876, 34.506227893214074, 49.42744570393717, 1.6977100434803194, 0.06272776570591716, 0.04141444122538932, 0.0367069726569518, 0.0396208455335469, 0.030783921735541477, 0.04775876389636148, 0.035615825965519876, 0.06942068136507465, 0.041149148807650616, 0.027949894372854504, 0.017983561622038964, 0.024380020406698028, 0.07483677743303199, 0.2178102422265276, 0.13035623416785272, 0.234085014089942, 0.13890565282875492, 0.09740956578283541, 0.15309358586467084, 0.2711682201873872, 0.11464054561069897, 0.13024387971287774, 0.12129120002951353, 0.11644236908684816, 0.0931834647311799, 0.10278251577889728, 0.18653120935684253, 0.14230409546965553, 0.22814600938750854, 0.3490815684199334, 2.4585950663012843, 61.55970142733667, 50.287786222273304, 35.401803062808135, 39.546618692336544, 49.016851994299124, 67.56747814916795, 73.37857154107863, 60.34326068816647, 64.98412670627718, 1.7272556645254937, 6.433696112325115, 0.5548594651683685, 0.4805756270164444, 3.7812695243666252, 67.35211649248677, 63.813546319161695, 64.9875940815095, 60.78033824120799, 54.33791583584201, 49.32944528518185, 48.63435814457555, 49.109969062189904, 47.88470691250217, 47.39182187664894, 46.91429292002032, 47.85242580598401, 45.875017796793294, 44.09313994069254, 44.05302586094026, 45.54094952921714, 45.38680038144512, 43.494531339214696, 44.02453768637873, 46.19571078208185, 47.33111927586217, 45.82196774021272, 43.434809330971014, 46.212322019761615, 47.33461018531553, 43.728308523854906, 44.25573002907538, 45.282335896645826, 44.47872069574172, 42.727115692630896, 45.254416465759284, 45.26066480144378, 45.09806294595042, 45.377649491833104, 48.369602080314394, 46.93544233998945, 46.23053750684185, 47.99125809823313, 45.67338835808539, 44.76439868250201, 47.230490869091405, 47.125300745810236, 48.20294841643303, 43.73279179296186, 43.199957416903594, 45.4407839621267, 45.42112504282306, 45.56827275983749, 44.18653941923573, 44.382979562205655, 46.97138694024856, 45.48911932976016, 44.435429496149865, 43.94001453153549, 46.737095925115774, 43.72021275181925, 47.10553984488211, 46.76366998303322, 46.525080050191576, 48.13717026864329, 44.27054874358639, 42.798553820579286, 42.31348606847948, 43.02146996221235, 43.932244316224136, 42.461532008263376, 41.70342022372831, 40.418800846222915, 41.203886770433, 43.1198626179849, 44.45038941598708, 43.28480220610096, 45.328725768673806, 45.19613004499867, 48.03079951194025, 44.76447320753529, 47.91802352474582, 44.96198807993243, 45.87216623367802, 44.501713629691835, 40.95363170869889, 42.95670378592707, 41.409673921523556, 39.07233745821061, 43.45977129474763, 41.96191226282428, 41.789947709729596, 44.55017843554097, 44.33080419417351, 39.97749497813564, 44.77363194188764, 42.33036794970113, 42.302099427869244, 42.27353280590427, 40.94497503772859, 40.140081144148304, 43.76516703636416, 42.87509887449203, 41.70354573957382, 40.58651747242097, 44.51742272223196, 40.603003194255216, 42.772387689159764, 42.76658650367491, 43.545557452786355, 44.56406362595097, 43.38257904975645, 41.23990589572538, 46.3487224425039, 43.33827587866014, 47.01365832359561, 45.30881189530896, 48.1781864935352, 54.201754677680235, 62.164052378746774, 56.9036558366591, 67.41008127889326, 26.008546275477258, 0.28364144926590307, 0.3473953476115581, 0.5515899244816073, 0.7467002613890557, 27.060469081324918, 73.46859778127363, 59.295450487444484, 60.580552316481075, 42.56360384725755, 37.27456615817162, 45.362493453487275, 57.93966754790276, 1.9891618817083299, 0.20943189099911722, 0.12087833226448107, 0.13875537702152807, 0.0965801147263377, 0.13694420727270265, 0.23156775642306576, 0.15164670624559926, 0.11690743042216187, 0.18146038145547916, 0.14942860591315454, 0.09322443511337043, 0.13986942208101674, 0.15216170119181757], [0.04093000552647057, 0.07132113100059571, 0.08190932413262707, 0.09185393446034963, 0.038521823458253376, 0.038410258073840416, 0.03885565776257746, 0.10079755898444884, 0.0847397278994322, 0.006410661097165318, 0.02722366217283472, 0.07183734402661363, 0.09809433347395352, 0.0365986401635793, 0.035726023882988005, 0.05400497368687103, 0.02105566038329515, 0.1846081448057967, 9.177143996761693, 46.9054558200221, 37.91356732768398, 37.8763440347487, 30.86236953735352, 46.79687676891204, 63.94658527066631, 51.07931660067651, 60.94666634836505, 1.7030867549680895, 1.8668267106817615, 0.1766690071071348, 0.1598695722678977, 0.030290327455487945, 41.30711178625784, 66.23642967593285, 56.8000425061872, 61.013476079510106, 54.83259339486399, 51.343099917134936, 46.065150768526145, 45.09157926805558, 43.30632425123646, 43.62361261921544, 39.147713645812004, 42.140591913653964, 39.499907185954434, 39.86349521144744, 40.16092069687382, 40.549427540071555, 39.97687524364841, 39.457922135629964, 40.42005208230788, 41.703890908148985, 40.92741066409696, 40.5789472979884, 38.997796735455914, 40.24737365784184, 40.52296330851894, 38.76241530141523, 38.82669118142898, 40.47964072996571, 40.45825204541607, 41.15259785805979, 42.32506882759833, 40.94374733586466, 39.7336059231912, 40.55147109493133, 41.75311273144138, 40.98608539950463, 42.85056837143437, 44.30759160749374, 43.355597065341094, 42.03806900208996, 40.110000487296816, 41.73646619243007, 41.48749766811248, 41.46242980034121, 40.047105281583725, 39.03756172426286, 38.716409821664136, 41.1250392852291, 36.867063276229366, 38.29601803133565, 38.03902826001568, 37.907762219828946, 43.049805164337165, 43.570535106043664, 44.304783190450365, 44.22232320231777, 45.250831419421786, 44.63788263259396, 44.962843156629994, 43.373604666802194, 43.961324768681685, 42.632323772676536, 40.64600806082449, 38.92208714638987, 37.877599193203835, 37.69689952173541, 38.256551142661806, 39.07247866353681, 37.23829207881805, 38.647736964687226, 37.45304184575235, 38.80978184361612, 39.50426886158605, 39.23370376709969, 41.98053175403226, 40.76578940114668, 40.610490998914166, 42.21577982748709, 43.764394329440215, 38.88115329127158, 37.10063649762062, 40.7761287689209, 37.31867321075932, 36.63983252740676, 38.80049759341825, 37.747184307344504, 39.854858152328, 38.75244855880737, 39.726255401488274, 37.63003487740794, 37.7415596285174, 37.64593616608651, 36.40427850907849, 35.835974139551965, 36.79711172657628, 36.45944664555211, 37.57470592375725, 37.78905560893398, 39.46942644734537, 36.86425878155616, 38.84697375759002, 38.30049345570226, 37.929092068826, 38.80655765533447, 37.814272526771795, 37.15875425646382, 38.61680123113817, 39.41629794336135, 40.71723438078358, 39.10296724688622, 42.754325174516254, 40.979554653167725, 46.94002759072089, 49.13379746098673, 58.87098335450696, 53.77331418375815, 62.1804988768793, 12.589306965950998, 0.23455641863326873, 0.13887082647171714, 0.026321900077164177, 0.47717916088238843, 30.890287007054976, 51.440496290883715, 54.12218155399446, 42.0779477396319, 30.6258878784795, 33.75702773371051, 46.159856396336714, 21.834167741960098, 0.19279934075330535, 0.13371450315800407, 0.07827423693191621, 0.14759442288308375, 0.016263292035869053, 0.03567043271276259, 0.036547086276714845, 0.04050932749505005, 0.07164746147370146, 0.06826521393152014, 0.08786790238152589, 0.0694089295763162, 0.06597434290714803, 0.048006849979320844, 0.10780897952856557, 0.05654148697372406, 0.054640432128742825, 0.08281496263319447, 0.06194995280595557, 0.0349579977562591, 0.030186281224051793, 0.05713195690224248, 0.04956287797540427, 0.07778441563488976, 0.03906024154275656, 0.012010656571346185, 0.04995515329703208, 0.06472203429908523, 0.020051173557857835, 0.022224677997010372, 0.023400975361226067, 0.2134994501548429, 16.581019739950857, 57.09108629534322, 37.17289440093502, 39.327346432593565, 45.59457225184287, 52.365559839433246, 68.80593515211537, 55.27605264417587, 66.63694289422804, 1.86989473960092, 1.3518448798887193, 0.22145055414688206, 0.12680036811939172, 0.04636777039136618, 45.1765731073195, 67.86084790383616, 59.954396909283055, 62.450008853789306, 57.632973501759196, 52.693368004214385, 48.733382301945845, 45.73337316513062, 46.164649532687285, 44.89009103467388, 42.390027200022054, 44.31695430509506, 42.264903591525176, 42.60176458666402, 42.173073061050914, 43.52027777702578, 43.24989703393752, 42.443955867521225, 42.62180005350421, 43.50158376078452, 42.34664186354607, 42.53476658175069, 40.18460396797427, 42.040932332315755, 43.091009662997344, 43.35254153897686, 40.692374398631436, 43.60491860297419, 43.94623541062878, 43.03810081174297, 43.28707325843073, 41.89761677095967, 42.6095740256771, 43.41407175986998, 44.08124731433007, 44.55665819106564, 44.09053156452794, 45.64334300256545, 45.45169207357591, 43.216356846594046, 43.20748836763444, 42.83958965732206, 43.13735638895343, 43.26946181635703, 42.613449327407345, 42.43155333303636, 41.85210158748012, 42.74450355960477, 40.423723420789166, 40.45311374049033, 40.825656537086736, 40.258826978745006, 44.90510194532333, 44.35514250109273, 43.73555314156317, 44.21015601004324, 45.68043293491487, 46.35948150388656, 48.61461685549829, 45.68256670428861, 43.839472416908514, 44.17858485252627, 40.82916313602079, 41.30911219504572, 39.81474015020555, 39.08119809242987, 39.20715324340328, 41.24915876696187, 39.174075895740145, 40.048062339905776, 39.69577466287921, 40.477334376304384, 41.84289186231552, 41.73458737711753, 43.3640968415045, 42.26478592042, 43.78095457630773, 43.81047433422458, 45.74910971426195, 41.89940144938808, 38.02045191487959, 40.29830563452936, 39.75957985847227, 39.46608066558838, 40.96483007554085, 40.024426137247396, 40.310335543847856, 40.27760336475988, 42.426838644089244, 38.32573390776111, 41.2996514381901, 38.24943204079905, 38.95266202188308, 37.7411203230581, 39.09580499895158, 37.587818407243304, 38.71513112898796, 39.337846617544855, 41.77381500121086, 38.394493056881814, 40.33227728259179, 40.22864434026903, 40.28291033160302, 40.065018746160696, 40.77735647078484, 38.69718628544962, 40.1659530978049, 41.58277203959804, 41.69968220495409, 42.16361622656546, 45.61099129338419, 42.64741313072943, 49.82151839040941, 51.37942106493058, 60.867928689525975, 55.35264084416052, 64.60859506360947, 13.680812370392585, 0.3212053755358342, 0.28664301239675094, 0.045437031019959724, 0.609442433041911, 34.528334371505245, 56.6812260689274, 57.236833726206136, 47.82174502649615, 43.768748160331484, 28.85827176032528, 49.76045885393697, 28.021496841984412, 0.23643030033957577, 0.1133387553836069, 0.04913700586785713, 0.09607867953637916, 0.14130750701071756, 0.052897827249140515, 0.03552723172751646, 0.12126801054804556, 0.038041222029395645, 0.05266670235282472, 0.05012373477520962, 0.05092959798451874, 0.02696688482237439, 0.07562551091635421, 0.24633137389056145, 0.17825315436047895, 0.13433128054584229, 0.22225441020582953, 0.1867522563665144, 0.1322658155714312, 0.1888301626088158, 0.27249293942605296, 0.20902735060982167, 0.12478774022911826, 0.12007332707364714, 0.1686378775705253, 0.18453049413379163, 0.1534589178740017, 0.13524644918018772, 0.12953140262153842, 0.1720639146984585, 0.29301171581591334, 22.15974800048336, 68.53472678892075, 44.62662150782924, 49.62749050509546, 44.289933096977975, 58.93659284037929, 75.11618937215498, 60.66669541020548, 71.31075289941603, 1.761634748789572, 5.229973658438652, 0.5573556247738101, 0.416826386485369, 0.31753774492009995, 45.9318607853305, 68.04057874987203, 61.82020956470121, 65.9112024307251, 59.635323862875666, 56.32423547006423, 51.15650492329752, 47.711922584041474, 48.409625945552705, 47.95264628625686, 43.80962710226736, 47.88113755564536, 45.834385964178274, 46.37146434476299, 44.8321105587867, 46.97099470323133, 45.09804333409956, 44.74317473749961, 45.59845539831346, 47.673734388043805, 44.1223027629237, 45.70605385688044, 43.08659699655349, 44.72138204882222, 45.30510133312595, 45.082306784968225, 43.040144366602746, 48.544292680678836, 46.10190729941092, 46.892539455044655, 45.25492245151151, 44.37768044010286, 45.12050674807641, 45.778998174975, 46.24046894811815, 46.104358780768614, 46.388322691763605, 47.400588373984064, 48.61625640623031, 45.96237682527112, 44.17657267662787, 44.5871114730835, 44.99925451893961, 45.344897700894265, 44.665754995038434, 45.028503633314564, 43.52212521337694, 45.03052757632348, 42.26700205956736, 41.86521407096617, 42.31151703865298, 44.40302287378619, 48.31207267699703, 47.70298350241877, 47.14298279054704, 46.532587466701386, 49.9263241214137, 50.28650360722696, 51.2365016629619, 48.09906444241924, 47.29219367427211, 47.52036971430625, 44.31314960602791, 44.170732267441295, 41.994864094641905, 43.162181069774014, 41.90739131742909, 45.19926009639617, 41.55559001430389, 41.65508485609486, 40.125438936295055, 43.13555209867416, 43.38757222698581, 42.953052059296645, 44.982502075933645, 44.8584649639745, 45.03929799602878, 45.24462230743901, 47.63121981774607, 42.74641375387869, 39.025123888446444, 44.02152138371622, 40.83493294254426, 41.86620250824959, 41.70014112226425, 42.28396631056263, 43.058046064069195, 42.45870790173931, 44.78405760180566, 40.80005130460186, 43.4376452046056, 41.90275899825558, 40.60915739305558, 40.15428012417209, 41.7361641699268, 40.06866655042095, 42.89277307448849, 42.56987963953326, 44.16120875266291, 40.87783190511888, 42.56487861756356, 43.74334689109556, 42.09462173523442, 43.259663735666585, 42.64828781927786, 40.47784036205661, 41.90799144006545, 44.1015181233806, 42.79928338143134, 43.82819952503328, 47.47559978115944, 45.6238684346599, 51.16461246244369, 53.41385249168643, 64.58990889210855, 58.275053731856815, 65.61112542306223, 15.51289068114373, 0.3638762277701209, 0.43354190405338044, 0.1335459178493869, 0.8582863608194936, 39.17437399587324, 63.26079022499823, 61.514805978344334, 53.3397549967612, 45.08648803157192, 43.987086895973455, 58.203654827610144, 35.161750085892216, 0.2959885496285654, 0.15792384683605165, 0.2012308431609023, 0.18632153109196695, 0.216177616929335, 0.15540255954669369, 0.08446877026149342, 0.1440233193458088, 0.16462288736816377, 0.13990360492419812, 0.11912094954881938, 0.2872314292096323, 0.10251841462788083, 0.13036021782505897], [0.038215093344690344, 0.025013423817712935, 0.05716121763051037, 0.06103621675602852, 0.06520122229572266, 0.02559904824011028, 0.10251326651702966, 0.07021169012953198, 0.07642885369639243, 0.010350831322402004, 0.009616563817666424, 0.004990814326916852, 0.05985449931974854, 0.10895072632739622, 0.06361937330615136, 0.11990647312373885, 0.023846786822222417, 0.07820443866113502, 0.49540218626779897, 18.394311858761696, 48.08655600393973, 43.95778286841608, 28.470164998885128, 35.3512554783975, 60.603996323001006, 50.68483991007651, 56.14788178474673, 3.6965500058666354, 0.9510567892462978, 0.2993127277060863, 1.0949231371764214, 0.3722007843034883, 14.223305583000185, 72.11508197169151, 57.92017729051652, 66.17618991482642, 55.883031583601436, 58.4768989009242, 46.850550482350016, 46.492222355258086, 44.02412583751064, 43.504196059319284, 42.38247271507017, 41.781742111329116, 41.34323681554487, 41.23044121649958, 40.65917153512278, 42.10938161419284, 40.24608712042532, 41.26631521409558, 39.53860136770433, 40.246651941730136, 39.725004165403305, 41.42859543523481, 38.68878064617034, 41.755430852213216, 39.5193935209705, 42.21371273840628, 38.85214344147713, 39.70911072146508, 39.83590525965537, 39.694484203092514, 40.586458636868386, 39.52095070192891, 41.43460842870897, 41.904245576550885, 40.59391898493613, 41.8750003845461, 40.546128826756636, 43.6165209739439, 42.327912545973255, 40.04852517958611, 40.613754410897535, 42.77032060007895, 40.962221699376265, 41.211547159379535, 40.0910593617347, 39.47734571272327, 40.4054843994879, 42.30825362666961, 39.38028274043914, 38.33176259071597, 39.04171943664551, 38.577224516099506, 44.31676995369696, 47.09207827045072, 47.54866569272934, 50.31542324250745, 48.94606890216951, 49.531208084475615, 49.279744932728434, 46.068304354144686, 47.90063565777194, 46.11949128489341, 43.554594593663374, 41.240482484140706, 38.356351929326216, 38.51055991265082, 37.40525168757285, 37.992536406363214, 36.8097339137908, 36.79298539315501, 38.29822632574266, 38.8319157784985, 38.88225155491983, 40.113746350811375, 39.05512217552432, 39.567011094862416, 39.13080430799915, 40.83754131870885, 40.4754202596603, 40.11043587038594, 37.89634812262751, 38.83800329700593, 38.010292976133286, 38.94792772108509, 38.65834305363317, 38.302529165821696, 40.10197531792426, 39.8536265280939, 38.90452277275824, 38.40316149496263, 36.05128872779108, 37.00136915329964, 37.55632569712978, 38.334390578731416, 38.89634070857879, 39.54876815119098, 43.16136521677817, 44.14708822004257, 44.6964906877087, 46.99229709563717, 47.251169604639855, 47.081942865925456, 45.267375976808616, 44.78059414894351, 43.07497501373292, 41.29959652500768, 39.45953815214096, 40.72768357492263, 42.29590208299699, 40.645988448973625, 41.31068506548482, 42.67330861860707, 47.84506743954074, 53.29746007919312, 55.80405466018185, 53.20477839439146, 52.483921281753055, 3.1265992214602814, 0.26465978233083604, 0.09849676712145729, 0.13225551934972887, 0.6655650537821555, 35.94682424299179, 53.23505516975157, 50.5518441046438, 37.23848035258632, 19.393714128002046, 29.6166738002531, 42.42597180028116, 4.773374959345787, 0.13495375762783712, 0.010997524443683366, 0.0411221748518367, 0.051450193033463536, 0.062493174261743986, 0.0652938116822512, 0.05120582630737655, 0.022711392807503863, 0.04327504279752893, 0.038384613280575124, 0.05424405823672011, 0.06558141641078458, 0.041300240498516834, 0.07152326329941712, 0.010186293830854759, 0.06808269348356032, 0.06322302622720599, 0.12423147612641897, 0.0592292336777093, 0.04259132847730671, 0.042512398438468095, 0.08046607577031659, 0.09327661336189316, 0.04403960620684009, 0.03570513266529288, 0.01563498981281995, 0.006688796978954587, 0.07819601169396793, 0.10677461527408132, 0.09176885273547904, 0.05144716315572301, 0.08868193208810785, 0.8299130381595704, 35.00144281694966, 53.34237906240648, 43.60954699977752, 36.83674335479736, 44.92012854545347, 64.55738067626953, 56.339187545161096, 61.293054780652454, 4.205641784975606, 1.4330764307129769, 0.29513491317629814, 1.4403216612915841, 0.45111651261968, 17.218583360795055, 72.86627861761278, 61.34413188503635, 68.50400678573116, 57.97870689822782, 60.274481927194905, 49.73945456166422, 49.56976106089931, 47.21236167415496, 45.02422824982674, 44.16202852802892, 44.806466102600105, 41.05282845035676, 44.02547121047974, 42.703385353088386, 45.258358447782456, 42.32156615103445, 44.08768000141267, 42.46451693196451, 44.03860330581666, 41.49122784214635, 42.91065123773391, 41.304095483595326, 44.01024849184098, 42.572244828747166, 43.89793142195671, 41.71413613903908, 42.26235797328334, 42.41188656899237, 42.56223101769724, 43.06427086553266, 42.47072604394729, 43.178651102127574, 43.25359582901002, 42.74010266027143, 44.55292801703177, 42.11910124747984, 45.69338852359403, 44.68087180968254, 42.74952027105516, 42.46815296911424, 43.91856308906309, 43.2317364600397, 43.87385591383904, 41.474922549340036, 42.36305698271721, 42.1753127344193, 44.89230325145107, 41.07149893237699, 41.650460381661695, 40.776148380771765, 42.299083125206735, 46.22652884452574, 49.15245617589643, 49.76154142810453, 50.36087174569407, 50.5222890453954, 51.438837128300825, 49.46206062070785, 47.641641555293916, 49.206933975219734, 47.80030535113427, 45.742873145687966, 43.90173612102386, 40.70552610581921, 40.42353122465072, 39.502307676499896, 40.50187272410239, 38.70341108691308, 38.640123644182765, 39.6309692628922, 41.1561672149166, 40.32592696528281, 42.80501788662326, 40.938279551844445, 41.1913626424728, 40.342267559420684, 42.973785708027506, 43.624714805233864, 41.85463151624126, 40.945320206303755, 40.37080280242428, 40.7452283367034, 40.45707533436437, 40.3919679118741, 41.580324480610514, 41.5543270111084, 41.65595954464328, 40.05230242206205, 40.55604850092242, 37.8878052003922, 40.63125210423624, 38.805212282365375, 39.90953207015991, 40.20392948581327, 41.63129960336993, 45.602350311894575, 45.3021046423143, 46.326494370737386, 49.158382877226806, 49.196963310241706, 49.778415464585834, 48.139315805127545, 46.577447614362164, 45.07646637578165, 44.0693703774483, 41.09617456313103, 41.83325459880214, 42.6892569757277, 41.57477040444651, 43.98932656934185, 43.963784094779726, 50.24824873093636, 56.24360330643193, 58.39664720719861, 55.77021245033511, 53.51100960085469, 3.202519883071223, 0.3739627865293334, 0.1726984806478985, 0.03639594479013355, 1.1083740476639041, 40.801377065720104, 60.56313307054582, 53.959556164280066, 45.66378247353339, 28.166697102208293, 28.047551185854022, 52.8904906395943, 6.461537095808215, 0.08113465602359465, 0.06978081163739966, 0.016583583820911667, 0.04061961734306909, 0.019330790439139933, 0.039045712685272585, 0.08574783832075135, 0.010793858053793591, 0.03371563296945345, 0.024297386332745516, 0.03946289735575838, 0.04945537668742961, 0.04836215389772289, 0.06893387845446987, 0.15229261029631863, 0.14497734395967377, 0.13210689829241845, 0.2596555734353681, 0.10814224309738606, 0.23253451341823225, 0.14039209322823634, 0.251257257956651, 0.20624157912548513, 0.07599425967782736, 0.13679132676653324, 0.1051637315521798, 0.20476987825766688, 0.21555141666002814, 0.30038086877715203, 0.21240212113386203, 0.0933755382955555, 0.2130895011848019, 1.7369967482743727, 47.50460963095389, 59.37336837091754, 52.24259745690131, 41.05541329230032, 46.566621872686575, 72.7337025057885, 60.12792256570632, 71.17553311009561, 4.481557482673276, 3.6386210110879715, 0.5161617900575362, 1.9937694409201223, 0.670572878612626, 18.010694249983757, 72.41863419932704, 62.536355910762666, 71.74955629533338, 59.69393976273076, 64.27312650988179, 51.66246714130525, 49.79281056311823, 49.15420555299329, 48.41886704967868, 48.3775919483554, 48.54631662368775, 45.29926092393937, 46.38176448883549, 46.97935327406853, 47.30085034524241, 45.6749455390438, 46.637863882126354, 45.20933666536885, 45.7586802974824, 46.18416332429456, 46.25891585503855, 43.20374250411988, 47.314009897170536, 43.98668681421588, 47.53692211643342, 43.842908413179465, 45.218354194395005, 44.25414931389594, 44.34784297020205, 45.03736426753383, 44.05755619848929, 46.60808132540795, 46.30055181441769, 44.17298763029037, 47.254217286263746, 43.48876153269122, 48.0636062160615, 46.305831324669626, 43.63698790150304, 45.10680983143468, 47.283866482396284, 44.102804660797126, 44.906678738132605, 41.95946862620693, 44.073375117394235, 42.63765427374071, 47.34516528344924, 42.474385615318056, 43.59794462880781, 43.726798411338564, 41.97184370410058, 48.15445615399269, 52.03313112258912, 52.725943288495465, 53.754125948875185, 53.28193141568092, 53.36217134229599, 53.76176280360068, 50.68722863351145, 52.13846245119649, 52.16365583481328, 48.46666505259853, 47.67094558285129, 43.731164009340354, 42.454008902272875, 43.76325291972007, 44.004004078526656, 41.131754382964104, 40.52688567869125, 42.902990848787375, 44.34392452239991, 43.001814965278875, 44.85840612842191, 42.37638519656274, 42.83921703215569, 44.183691778490626, 44.82705070126442, 45.482223802997225, 42.69712525029337, 41.91259238027757, 42.53742594872752, 42.88770929459603, 43.84976471624067, 42.85277274347121, 42.418711493092204, 43.39728793790264, 43.17210466630998, 43.52810290551955, 43.44052030194191, 39.52586543175482, 42.91575424132809, 42.27014387807539, 43.79301194221743, 45.23312191809378, 44.003737357354936, 48.07931530860163, 50.467760255259854, 50.58003025670206, 52.468416152461884, 51.49098896211194, 52.040007037501184, 53.097121100271906, 49.65148756580968, 49.61193830736222, 45.422948944953184, 43.06648700468002, 43.596967958634906, 48.53499274100027, 43.22453498840333, 46.69257310128982, 45.88900496882778, 53.44781629500851, 58.725165320980935, 61.82180989173151, 56.923538331062566, 56.13172946437713, 3.9587217184805104, 0.4932970992259441, 0.1865391153842211, 0.32087105476567823, 1.8456217646598818, 47.209808211172785, 64.17629495743783, 61.81475354779152, 48.877505871557425, 29.12884077718181, 38.57352964339718, 60.38794432916949, 9.655290726692447, 0.4360639880741797, 0.1849820876433965, 0.12030362842544434, 0.13979463657784846, 0.09505364623281265, 0.1565440305538716, 0.2956042186387124, 0.09622314073626073, 0.05495934687074154, 0.14721497953418763, 0.09936162676181524, 0.19606641463695035, 0.07753699987886414, 0.16153578285969075], [0.018605692049248085, 0.0607812665252676, 0.013514965014051528, 0.09120288229877911, 0.0691395960447769, 0.03683674029044567, 0.026561043998827378, 0.04743570078825278, 0.05815071594570914, 0.038693859992969426, 0.005605057400140551, 0.03321366534838754, 0.02983723049833169, 0.01390496505454423, 0.037046043172238335, 0.07514792404347852, 0.05362713529217628, 0.025700773225135864, 0.11566527247909578, 11.943654437218944, 41.23357911263743, 51.38175879755328, 46.207317075421734, 22.402360323936712, 52.695042856277965, 50.97518943971204, 61.84980384765133, 16.894266105467274, 0.8994501036021018, 0.2024345051857733, 0.4738018163029225, 0.08954090817320733, 0.9113782764442506, 52.773325520177046, 62.22342529604512, 62.34934514568698, 60.18919783253824, 56.391531575110655, 53.44867921644642, 45.083663925047844, 44.12122018875615, 43.04851862692064, 43.145310955662886, 41.581093265164284, 40.51515779187603, 40.52535595432405, 38.674001155361054, 40.96088024877733, 39.677202240113296, 39.92112659638928, 40.27688164864817, 41.11369971306094, 40.894670640268636, 41.19440640172651, 40.33471699683897, 40.261592249716486, 39.42359747425203, 40.64685137041154, 39.275590758169855, 40.7994786385567, 40.525006863378714, 40.86792007569344, 40.7710571442881, 42.267759077010616, 42.47248326578448, 40.07391075934134, 42.89337319712485, 42.22410309699274, 40.10599966972105, 43.062144940899266, 41.64066230097125, 40.99316920003584, 41.751830116395034, 41.56943205864199, 41.46321819674584, 40.61880642367948, 40.40380562505415, 40.641226691584436, 41.687362040242846, 38.13621282577515, 40.1449135042006, 38.74166596320368, 41.59617477847684, 39.98462192473873, 47.87887434805594, 53.9341470503038, 51.63475559603784, 55.44456158914874, 55.45122961844168, 54.85490383640413, 51.18460478321199, 49.28834669051632, 49.62007330309961, 50.06184985560756, 48.36669952638688, 46.90500866982245, 39.006814264482074, 39.38138884882773, 38.73585301060831, 39.2224387199648, 37.0522540615451, 39.03727931361045, 37.035858554224816, 37.64439859697896, 37.506703792079804, 39.896745143398164, 38.300803322945875, 38.63922934378348, 38.91937286623063, 39.697955500695016, 39.664136825069306, 39.41299923004643, 37.66695222546978, 39.28291382328157, 38.8182149394866, 37.95426584059192, 36.3407321899168, 40.84041249367499, 38.854096781822946, 38.3793919317184, 39.70962847432783, 37.94839797481414, 38.586587213700824, 38.29868524305282, 36.74569729835757, 40.48465351904593, 41.666687227064564, 44.26369244052518, 44.19263870485368, 49.19155436177408, 46.28772174158404, 47.29209169264763, 47.81491618002615, 48.26166237554243, 48.48721434993129, 50.777517672508, 49.80598188215687, 46.84967187143142, 42.9805164952432, 41.44313958383376, 39.69766916767244, 40.544705006384085, 41.44321410886703, 45.23351807748118, 46.226925003913145, 54.77576609580748, 50.7245421409607, 61.5810626552951, 33.9373077115705, 0.12534997981762694, 0.18815795109877664, 0.07723310046018132, 0.1452750150835322, 1.326846634188006, 43.87625248201432, 46.956968307495124, 52.74058549634872, 30.09989803837192, 30.3292723624937, 43.77105451399281, 19.59470225918678, 0.11232442432834257, 0.029978862918552854, 0.09745402952596065, 0.021571865748433817, 0.08734424298088397, 0.060074420180171735, 0.018704867876705625, 0.0073526629186686015, 0.05215476409742429, 0.025778379847085284, 0.01635437222918676, 0.05343726040014336, 0.076090480321117, 0.018419496294471528, 0.03206552746104858, 0.035539090768584324, 0.033075148990798386, 0.02035931327320155, 0.009797747442198378, 0.054226495671055974, 0.0701934036107794, 0.02565755629010739, 0.07372246424276983, 0.0353552105145589, 0.019482278580506964, 0.03964616473944437, 0.03252882104847701, 0.043115868879061554, 0.04460456923791959, 0.06261510481577247, 0.030812401054126602, 0.1422598615529076, 0.03654515190470604, 0.18094302695845405, 18.117216017938432, 50.796333282224595, 50.58353685563611, 45.23659713806645, 30.597501685542447, 57.039440447284335, 57.20780426456083, 67.46557497209119, 16.30455343954025, 1.1219297589794284, 0.1049789434839641, 0.8930916351176078, 0.14630364133946358, 1.4295625999089212, 55.85631632035779, 62.030056368920114, 64.44201984713155, 61.19989848905995, 60.407442431296076, 54.036218889297984, 48.665101681986165, 47.3869816718563, 47.044648970327074, 43.81027037097562, 43.51035418048982, 43.990762156824914, 41.79284634128694, 41.069082752350845, 44.51606165978217, 41.766554694021906, 43.177388098932084, 41.52623891830444, 42.607299050977154, 44.99190399723668, 44.44479611612136, 41.251214088932166, 43.34266108851279, 41.53334233068651, 42.909090134405325, 41.12403515846499, 42.27436042601063, 44.43659051772087, 42.37038789256927, 43.03156222066572, 43.1610357376837, 44.4985443545926, 42.52051661091466, 44.418100464728575, 44.387682484042266, 42.84062124067738, 44.339284358486054, 44.759778130439024, 43.298526579333895, 43.15548558388987, 42.85857785132624, 42.79113661858344, 42.69208108225177, 43.1334497082618, 41.843288021702925, 44.064906720192205, 41.57074213027954, 42.68714281820482, 41.25569735803912, 41.90650486177014, 42.02877690715175, 48.17298543068671, 54.6153058544282, 54.11768651777699, 57.03971109082622, 54.6735099054152, 55.32854964656215, 53.39908084561748, 50.949191970209924, 51.743624902540645, 51.14558896710796, 51.093040973909446, 47.67360102745795, 39.93045399265905, 40.57543285431401, 41.61943443359868, 40.89585519606068, 38.23680985358454, 40.433780377910985, 38.75651213430589, 40.618637761762066, 40.008093387849875, 40.809955289286954, 40.00495549171202, 39.746914525185865, 40.44897563995854, 42.306484637721894, 40.243463054780044, 41.587188628412065, 39.29313944232079, 39.850119929159845, 40.09608391792544, 40.520331398133315, 39.79689336592152, 42.078065410737075, 40.7197525424342, 41.96734474551293, 40.66361165815785, 41.20036055964809, 39.70751823917512, 40.811736045345185, 38.400925743964414, 42.55790072102701, 44.89019301629836, 46.32484697526502, 46.66619908425116, 51.04289739362655, 51.21066501063686, 49.410069604073804, 50.87993075770717, 51.22803326575987, 50.094236866120376, 53.222542808901885, 51.83223124473326, 49.89979713193832, 44.59523862408054, 43.5417684431999, 40.99935085542741, 43.42600753230434, 43.44663527704055, 47.773425348343395, 50.45040376724736, 57.23570016122634, 53.86562324339344, 62.31084316007553, 35.52516944946782, 0.2398176347055743, 0.24561886615570516, 0.3812769650211258, 0.22141356742189777, 1.8582685892620396, 49.64303878045852, 53.87290316243326, 53.656219667004, 44.97622628365794, 26.180985435362786, 43.88025722196026, 28.668417276874667, 0.18645060158544974, 0.04534612319642498, 0.0043816379677023625, 0.04011291529863112, 0.12388027077841184, 0.08407755214120112, 0.0762660523516036, 0.026216463396145452, 0.00899086054790044, 0.02001183302772622, 0.04501036601141096, 0.08742359436808095, 0.020331142305005944, 0.016669261179143385, 0.05093507934361697, 0.1180470091921668, 0.10262513833661234, 0.08705008053971876, 0.15582222251161454, 0.17866792968444287, 0.1501120023068882, 0.12619564129460242, 0.19336574019924288, 0.12128952995783861, 0.1359609027783717, 0.21353421522484672, 0.13310733251273632, 0.09659440992700477, 0.1929261895918077, 0.15605433183091302, 0.20127650200118943, 0.2837889671566025, 0.16105046615965907, 0.204058550298214, 28.14247254402407, 60.73113602976645, 57.789236807054095, 60.3655005270435, 32.817641650476766, 66.24444700056507, 61.031821004806034, 74.45559163247385, 22.16782416066816, 1.5609957085501764, 0.2955172216940311, 1.6041347937237833, 0.27798738330602646, 1.6222942644549956, 57.29611642899052, 61.77604367656093, 66.74013260872134, 67.21219770369991, 61.36954884375296, 59.28816272366432, 51.00128889083863, 48.884632818160526, 48.82117671351279, 47.66830190535515, 45.98572277253675, 45.70002125155541, 45.472406110455914, 44.58433835737167, 47.524507814838046, 45.25538136882167, 46.09984805507045, 45.01304949483564, 45.60922622680665, 46.16777566171462, 47.12313951984529, 42.60600859119047, 44.03233143591112, 44.020250535780384, 45.53578769007037, 44.801743568912634, 44.70945412112821, 46.41590479881533, 45.96512248439174, 45.70881520548175, 46.53883972475606, 48.08599510500508, 43.96052068279636, 47.18262618587863, 46.20303776956374, 44.3408925302567, 46.58171907547982, 47.79830494234639, 45.44260394188666, 46.636695015815, 44.76918397411224, 47.565335765961684, 44.13533287663614, 46.46474615220101, 45.15080313528738, 47.17345960678593, 43.094861430506555, 43.57858773200743, 43.28954435163929, 44.43178953662996, 44.26291973360124, 51.057457231706195, 56.83000549193352, 56.54735165257608, 57.85588572102209, 58.65063244296659, 58.103563785552986, 56.6508355448323, 52.14758980658747, 53.95544944270965, 52.96390564210954, 52.08872287504135, 49.907202566823656, 43.751328914396225, 42.356973386579945, 43.30800694804038, 43.64397364277994, 39.92749260317895, 42.95758631921584, 40.67689280356131, 42.343417675264426, 42.7512578810415, 43.94048913832634, 41.78016531851984, 41.09730028337048, 41.58801624851842, 43.588377967957534, 44.004933680257494, 44.47012678269417, 42.22127114572833, 42.14987224148166, 43.13808594980548, 40.48375921864664, 40.35013583398635, 43.2843432887908, 43.721824845960064, 42.10354904974661, 43.586095148517245, 41.453223997546786, 42.41279655887235, 42.966388117882516, 40.40885763783609, 44.05411235747799, 48.09074117291359, 48.68819659756076, 49.08306944754816, 54.3791909371653, 53.11754095938898, 51.53103243920111, 53.45016187237155, 52.88473652255151, 51.735199651410504, 54.677173399156146, 55.235875806500836, 50.993542209748306, 47.495968649464274, 45.01756806527415, 42.91868425184681, 44.84810206197923, 46.014144266805346, 49.224082577613096, 51.65006068445022, 59.377082855470725, 56.49090090105611, 65.82217247255387, 37.75696669855426, 0.36847416491758445, 0.5082834644183036, 0.49935817237823243, 0.3300382160852033, 2.84733921289444, 56.45416790439237, 57.17553100278301, 60.588381367345015, 44.34918049843081, 40.575013160705566, 56.40332614221881, 37.46501291951826, 0.21720382234742566, 0.13315728144539943, 0.17037764792480778, 0.13346774623759333, 0.3023028608051039, 0.2770866477681745, 0.20566341256903065, 0.1160814957092366, 0.11804379162288482, 0.13260490140847622, 0.10361290912354186, 0.17692236770545283, 0.09672796203484459, 0.09274170012964357, 0.14573068418089422], [0.04806425294748718, 0.07569818201685145, 0.04859073921256969, 0.06639777502465634, 0.0360790295376172, 0.03971969002797719, 0.042083182357131474, 0.058855179757360494, 0.04185824745124386, 0.04489213183161713, 0.014264641419774102, 0.07271732624259687, 0.012084780366069848, 0.03768560401494465, 0.015800179436712736, 0.08261649989553037, 0.06613709062578217, 0.10233303667196345, 0.20549530223492654, 2.2785107166536394, 38.02867712513093, 52.910408435329316, 50.631170119008715, 33.04845940682196, 47.14727778588572, 48.030654384243874, 59.781443918904955, 33.7327443399737, 0.5282947228800866, 0.293551899733082, 0.4920991215734713, 0.17739099901049368, 0.2807078534556974, 21.875958634961037, 71.64482901173254, 56.25915158179499, 65.04747690693026, 55.175490917698035, 57.30886805442072, 47.19210655458512, 46.329596965543686, 44.47709683449038, 47.238170869888805, 43.03222117885467, 42.99610007193781, 41.722828111340924, 42.99194235955515, 39.900914622891335, 41.46266906492172, 41.956016940455285, 42.17501463428621, 40.24940936796127, 42.043254375457764, 39.720156115870324, 40.20480417436169, 40.30607977221089, 40.37578029017295, 41.22495382062851, 40.38873587885211, 41.619634474477465, 40.82356199141472, 42.18154930299328, 42.18225925199447, 40.55343620238766, 41.48630918995027, 41.54339928780833, 41.31540367680211, 42.43604444688366, 40.94049961336198, 42.59534366669194, 40.09866091512865, 41.41515739502446, 40.70538097812284, 41.35829087226622, 41.068262976984826, 41.12032851865215, 40.989325277266964, 41.353140800229966, 40.88424890272079, 41.45241598929129, 39.374006948163434, 38.24741594253048, 40.274736112163914, 40.43081506606072, 48.071854960533884, 53.928039919945505, 56.296072852227, 56.9687593367792, 54.6063942293967, 58.89920480789677, 53.18858292794997, 52.88166530670659, 57.384683547481416, 54.46309043515114, 53.221275883336226, 49.737662038495465, 41.600359947450706, 39.998522804629424, 39.85326959240822, 40.52805846737277, 38.27329966329759, 38.15228277637113, 39.701273825860795, 39.09942534662063, 39.191942291875044, 39.087254231975926, 39.63532309378348, 40.40818299016645, 36.87072284760014, 40.27545782827562, 38.219312160245835, 38.86868799886396, 38.95700408566383, 38.18001001111923, 40.2799803210843, 38.89337147435835, 37.33716718612179, 38.97860457820278, 38.40243193411058, 37.98375814191757, 38.071748671993134, 38.83964284773796, 36.45686180360856, 37.804090053804465, 37.71829212865522, 40.96663436582012, 42.784201868118785, 44.50010545792119, 48.88222056050455, 49.047246440764404, 49.349453295430834, 51.11847362210674, 51.79554531651159, 49.6163901975078, 50.21612844159527, 50.90852875863352, 49.647267095504276, 49.17780645432011, 47.63624829630698, 46.38273331426805, 43.19719999067245, 41.964822661492136, 43.51267230126166, 50.05413847584879, 51.85372583327755, 53.77318866791264, 50.65417482006935, 59.17955229359289, 16.442319827695048, 0.058191196031628124, 0.3380646111984407, 0.20217512313637043, 0.33329176085610546, 5.963815287236245, 50.32806111920265, 50.515377829151774, 43.91758641889019, 21.53920746618702, 30.223691963380386, 38.07565927505493, 4.924253830986639, 0.06566048434544956, 0.06413245303255898, 0.01270860767803125, 0.0446757847713607, 0.018222466141225833, 0.08001792199549176, 0.04580260051654712, 0.019252622657785975, 0.041760628697492426, 0.042818366294546474, 0.015010162756117362, 0.02857070138317443, 0.03859894936003032, 0.08267529714371889, 0.0477735149193435, 0.027622453072258545, 0.0359143206338969, 0.044327076869986715, 0.07791513321740974, 0.044500676224068295, 0.02628795855167893, 0.03644500123036485, 0.0333677907474339, 0.03763450595039514, 0.02135573319279619, 0.06009978152090504, 0.07080798232627493, 0.004261796918487357, 0.026674603127063285, 0.03705903985387376, 0.020632885186181917, 0.03600495649621852, 0.09501911865006532, 0.16868263242706177, 5.374879740899609, 50.20203536556613, 54.03786628477035, 50.91395731895201, 37.85404536031908, 56.55716150037704, 57.04601433969314, 64.18974084238853, 35.70950515808598, 0.5567870036728921, 0.4680291599323673, 0.43160498863266367, 0.12087470100771998, 0.349150117967398, 25.684705588125414, 72.8674945523662, 60.21885095104095, 65.1530239658971, 57.37890197384743, 59.25493240356446, 50.86091118474161, 49.16877323581327, 45.92704803712907, 48.37974925195017, 45.09727454954579, 45.81900635073262, 43.67902002026958, 42.57230758666993, 41.603160519753736, 43.5174693599824, 44.75592244055964, 43.35305144709926, 43.253474235534675, 43.772866649012414, 42.18796237822502, 43.750932755008826, 42.41968031852476, 43.80313165726201, 43.062894113602184, 42.593837476545765, 43.81443592809862, 43.16572297003962, 43.32955252739691, 43.880920102519376, 43.72994022984659, 43.0659653294471, 43.62573462147867, 44.46123084714336, 44.16974383015787, 43.425607450546764, 44.752894370786606, 44.7059279103433, 43.15172403089462, 44.08189058303834, 42.90483828513853, 44.292643454767045, 43.23875358027797, 44.69323119809551, 43.11119417990408, 42.86324547183129, 45.1153370641893, 41.53664888874177, 40.46007202517602, 42.891278651452836, 41.80767682290847, 47.85268468241538, 57.55181574052381, 57.41648220246839, 58.631601102890514, 56.77996389327511, 60.392737465520064, 54.43284896112258, 54.081894889954604, 56.37158632278443, 55.97211645495508, 55.410338909395286, 52.66421302672356, 44.159357393941576, 42.507153095737586, 42.8796096001902, 41.42617141046832, 40.60654117215065, 41.38200159995787, 41.43152152338336, 40.69910518584713, 40.615213532601636, 39.81746227510514, 41.30240494205106, 41.58147765744118, 38.85121383974629, 40.797760640421224, 39.079374190299745, 40.35145767273442, 40.598849404242735, 41.295909497045706, 40.85292485452468, 39.47522371046005, 39.70321147672592, 40.7326179165994, 40.29421460243964, 40.0477760068832, 38.913128452916304, 40.473663037823094, 39.22566683061662, 39.64063398299679, 40.26156871549545, 43.1114177550039, 46.056184230312226, 46.32942438125611, 50.11857125066942, 51.388101270121915, 50.69675214828984, 52.89648794358777, 51.93353822154384, 51.356188866399954, 52.80697945625552, 53.11446189880372, 52.23820047993814, 52.4725228740323, 50.39247035980225, 47.866883662439164, 44.55431653607277, 43.90316386376658, 46.36843627498996, 52.20804529805338, 54.10927303375737, 59.19118212115381, 52.822241398596, 63.0875862029291, 18.175341621521984, 0.09294314294933312, 0.9837732788535857, 0.7242125777467605, 0.3517322326379438, 7.364929058859426, 57.249542205564445, 56.07596905000749, 51.39431430447487, 34.52016015206614, 28.92462649653035, 46.07578039169312, 8.450864207360054, 0.10618143339431095, 0.06242123477521443, 0.02591174617860346, 0.07230333998919496, 0.08076218407480948, 0.04801598174737827, 0.023015816996414817, 0.024954580604248953, 0.11124528223468412, 0.029457869503887433, 0.025986734695071657, 0.018252272707139774, 0.04938316523968693, 0.030312837033923117, 0.01537415315397084, 0.15670185998803185, 0.24387878936625298, 0.18570323685003867, 0.1555578762124623, 0.13013068256118607, 0.09505379178951825, 0.12342630239624171, 0.11736485386087049, 0.1846462653409089, 0.13223149483242344, 0.14859315638820972, 0.17438752065983512, 0.10398613183849281, 0.272859190740893, 0.13658871183231955, 0.22371651965283582, 0.1441028699158661, 0.18973118926007904, 0.5272625879414621, 6.555876472303945, 62.1478686794158, 58.548807713293264, 60.458770567371005, 48.370421855680405, 61.059595307996204, 61.93025950462588, 68.26001967153242, 43.73556098630352, 0.8449826005005068, 1.7683378342659244, 1.9019984814428517, 0.45578609430982225, 0.4601883113143906, 25.777151930716734, 74.83358260123961, 61.305473004618, 67.44782232469129, 61.082376433957016, 62.999352485902854, 51.88801127095377, 51.47929245425809, 49.55186328580303, 51.56362341296289, 48.73833625547348, 49.24759718679613, 46.34023443345101, 48.0042411435035, 44.423164244621034, 45.782343956731985, 47.6317689495702, 45.45749325906077, 44.36694099057106, 45.74945880520729, 43.80849353728756, 45.41412753443564, 45.479407541213504, 45.13222286778112, 45.91075451143327, 45.62755938499205, 48.06480253896406, 45.514940292604514, 46.55306616137105, 47.81544177762924, 45.211219403051565, 45.28139845017464, 45.2032373797509, 45.325638863348196, 47.577012661964666, 46.793025001402825, 47.3777719466917, 46.65849162686256, 44.36012391121157, 44.97748144211308, 45.12631185593144, 47.5476654883354, 45.19935815565048, 45.220582100652884, 45.18861870611868, 46.00986103857718, 46.37733221054078, 43.99257036947435, 42.07340171260219, 44.474292339817175, 44.22768115997315, 51.16145495445498, 59.33454082858179, 62.136560486209014, 59.683533714663604, 58.2874248873803, 62.41509975925569, 57.55126268632951, 56.43949823994791, 59.643505927055116, 59.91439657826578, 57.762941237418886, 55.00707218723913, 45.63795758831886, 45.61769854637885, 45.897708708240145, 45.20705776829874, 44.66194245123094, 42.8074497561301, 44.6112536614941, 44.17889471976988, 43.57095479965211, 42.834674927496145, 45.49828983122303, 43.205287917967766, 40.64718869424636, 43.230245959374216, 41.91590678307318, 42.44670937138219, 43.359982275193744, 42.23042203534035, 44.24758326622748, 42.19657590312343, 41.04932185142271, 43.458198424308534, 41.91158433114329, 41.354137082253736, 41.86631233461442, 43.48442731365081, 41.77867089548419, 42.46999648309524, 42.31885187087521, 46.10283297877158, 47.46554282403762, 49.38321705787413, 52.19542311083887, 54.10491528049592, 51.33959724057106, 55.772106955128336, 54.28515995702436, 52.61034711714714, 56.1367069521258, 54.70043697664815, 54.47426134540189, 54.81505647782357, 53.34324982858474, 51.98427800209292, 48.28327071282172, 47.12528897869972, 49.5164756621084, 55.48689965278872, 58.257457979263805, 60.92074340389621, 55.19272188986502, 65.3878091996716, 19.505368317327193, 0.21745001236277245, 0.9937229223789709, 1.5292397093388344, 0.6597691389822191, 10.923924484560567, 65.36033299661452, 59.77726267230127, 56.81597517382715, 34.167029165452526, 40.112087188228486, 57.671804966465125, 12.489098252788668, 0.25298095578628205, 0.1736523673659371, 0.07749344011948955, 0.16446979235737555, 0.22840045783067905, 0.1401232882973648, 0.12755367003621595, 0.14810460679713758, 0.1645981427282095, 0.1364754687153524, 0.06098152573911413, 0.12106879704421568, 0.11845727225825672, 0.10815875229215431, 0.19707215018570426], [0.026804269253907186, 0.08378515170226175, 0.11678096462762165, 0.07535331987685735, 0.11863102866036278, 0.03555115282295212, 0.07528956603979872, 0.027781877884521123, 0.06994015026477075, 0.0587203253000494, 0.05808656757336952, 0.015339051962890213, 0.02308140369883228, 0.04197907866910101, 0.04670808196909005, 0.03252690965910593, 0.03811512653145098, 0.013944537326272939, 0.07628614683785746, 0.11540708552685477, 11.125419582090071, 54.00622452459028, 52.64487966414421, 45.479529134688846, 36.37658265329177, 53.681758219195956, 56.382333617056574, 47.608783860360425, 0.7087616874806343, 0.46643441002215114, 0.3397514142336384, 0.040821730489692384, 0.0773930979231673, 2.258912594087662, 64.15572604825421, 62.11048456930346, 60.589452174402055, 57.37044142138574, 58.32033357312603, 49.87044603593888, 50.29255582440285, 48.17141648261778, 46.27431900270524, 45.708234694696245, 45.8251448600523, 41.89066633101433, 45.05377154196463, 42.5006615731024, 42.31360373958465, 41.647875539718136, 40.023068997167776, 42.497347170306796, 40.06687010488203, 42.069440118728146, 41.0491257329141, 40.07597392605197, 42.4671527647203, 41.18227058841337, 43.279291276008856, 43.404767897821245, 42.8123095727736, 41.99573878319033, 43.09649313649824, 43.27706729212115, 42.963230609893806, 41.658854253830455, 42.75806711566064, 42.70284798837478, 41.27536019971294, 41.16144672516854, 39.87761574406778, 42.58107016163488, 41.53185967476138, 42.78715541285854, 41.8880775667006, 40.83793355572609, 40.33433652693226, 40.805299435892415, 44.823442120705884, 40.55609164699432, 41.36991285508679, 39.591914223086455, 41.2981491704141, 42.90974124785393, 45.73043530987155, 50.61248002513763, 50.368508600419574, 53.76039781878072, 56.827856033079094, 57.76373355619369, 54.44003474327826, 55.10403317789878, 58.37608222038516, 56.782909593274525, 51.24850803805936, 48.2322955900623, 41.954714713558076, 40.46808934980824, 39.502009576366795, 41.0662272668654, 40.73664619076637, 39.714107821064616, 40.11050255067887, 40.52765446324503, 39.24650246097196, 38.420608197489095, 38.3463224287956, 39.335783450834214, 38.09254507864676, 38.995353098838564, 39.96046404684744, 38.71052234403549, 40.226239927353404, 39.986414447907485, 38.90331076037499, 37.807529972445586, 38.71403678770989, 38.580185905579604, 37.933759689331055, 38.01644717493365, 38.79717926825247, 38.71313072020008, 37.32156791994649, 36.295087568221554, 36.668371692780525, 39.024194286715606, 43.77643208349905, 46.890060517095755, 46.28892590922695, 49.998146641638975, 50.20651078993275, 53.42143835559968, 49.89177980730611, 52.8912555017779, 53.542678817625976, 53.32989808051817, 51.321832826060636, 50.189887785142474, 50.7665507255062, 49.66875776167839, 44.73985641233383, 46.041491031646736, 48.232946703510905, 52.34301405568277, 50.379455935570505, 54.62398998198971, 52.910177015489154, 48.409390603342366, 4.423416679905308, 0.21345055842351532, 0.5555257778013907, 0.9478519676673798, 0.3728656873347298, 19.235660260723485, 56.872214117357814, 44.49142133035968, 31.473708191225608, 22.093701170336818, 35.570978810710294, 30.936902415367868, 0.6704639102662764, 0.161347585700212, 0.06385999769272824, 0.06721404170797718, 0.05723129169294431, 0.07109364119148062, 0.0182416106784536, 0.04193699362898066, 0.03311668627805287, 0.03790870797069323, 0.034519328149936856, 0.029174045419260383, 0.0821248323266064, 0.0026218317807727167, 0.05102304155908285, 0.06390216700252026, 0.05486625186618298, 0.07919836879497574, 0.03692952885983452, 0.047776644388514186, 0.09097356153952499, 0.08086880819211084, 0.02616340797694941, 0.018635264958345124, 0.04515509534206602, 0.049104684618331736, 0.03821536147546384, 0.011026784214341353, 0.044363354963641015, 0.015351125508576874, 0.023178026538282152, 0.038566735362814325, 0.04375592001803941, 0.07161202224632425, 0.041048193740988934, 0.09738118222524082, 22.600575339409616, 61.46498403241558, 48.91266992015224, 51.807916472035075, 50.38700257578204, 58.43633767097228, 61.77275280798636, 51.79593755352882, 0.45061212033033377, 0.8283853975515213, 0.5412538662072152, 0.017407781429468625, 0.1340364286255452, 2.9915159796514823, 66.65715879009616, 62.80059814453126, 65.08270371344783, 59.13486473021969, 59.473212303653845, 52.859190125619214, 52.96540006514519, 51.03571553384104, 50.04001402085828, 47.708588569395005, 47.547477214567124, 44.34112395009687, 46.24466196183236, 43.83498914780156, 45.0142458177382, 43.48035197104178, 42.712516630849535, 43.22426826723161, 43.343100393972094, 44.689924640040246, 43.12442825686547, 40.98805835170131, 43.5934260583693, 41.631527100839925, 45.53588574932468, 44.71109367186024, 43.55665383800384, 44.45506880360265, 44.663127007022986, 45.77750375193935, 43.55451222388975, 43.418547184236594, 44.58672708080661, 44.7699684481467, 44.470279755130896, 43.30512400596373, 43.02054820522186, 44.13143404068486, 43.55874053893551, 43.20675488441221, 43.99947374097763, 42.998477028262236, 42.22618587555424, 43.23714148613715, 45.650595465014064, 44.68275062499508, 43.62180832893618, 42.385673369130785, 43.70393491560414, 42.63277876761652, 46.75193032910747, 53.16014966657085, 53.308583921001805, 55.70721918536771, 57.24600422766901, 61.19975728373374, 56.04582955760341, 56.947303971936634, 61.811266560708326, 57.83778006030668, 53.5283935454584, 50.51025521370673, 43.5140412084518, 42.05001654163484, 41.143537182961744, 43.50657693801388, 41.52296373921056, 42.35493375409035, 42.570389547655665, 42.75570192644673, 40.75940770487632, 40.39630997565485, 41.13608860200451, 41.3035894978431, 40.00482605349633, 41.23067263633975, 41.51588386104953, 40.21211547236289, 42.787304462925086, 41.86395891251103, 41.05758236300561, 38.87715247369582, 40.06392832725279, 40.80911590207008, 41.41148605654317, 40.60075175377631, 39.84648781438028, 41.38686533897154, 38.48834360799482, 39.28116052381454, 39.32075685070407, 42.418456539031, 45.967432760423236, 48.52963870571506, 47.77342142597322, 51.83359622955323, 52.10300030246858, 54.07440316292548, 52.51964230691233, 55.22379098399993, 55.50772743840372, 54.26061376448601, 52.357628806944824, 52.54092508746732, 53.35515422205771, 51.9634815954393, 46.74914152391496, 48.15540536757439, 49.86263267455563, 55.09219154234856, 54.67584371566773, 57.67409170827558, 55.09981662996354, 51.837706873493815, 5.64283057566612, 0.2604548789320454, 1.8220923240146332, 0.6216988592378555, 0.2303605244284676, 20.141551263870735, 65.81421006110408, 46.2890592698128, 42.71623111540272, 24.022479634131155, 31.870455934155373, 42.20047473907471, 0.7631288024206316, 0.07828034265267272, 0.019759644543932333, 0.05533378766549211, 0.08578793536270819, 0.020432813663876826, 0.03746752559597935, 0.04051353331775435, 0.02006257677661075, 0.025468227235720526, 0.04529670286442965, 0.010510844107146465, 0.05568946696697705, 0.024224238342515404, 0.029936209058148727, 0.032931970988189986, 0.15518330518276463, 0.13807077020887407, 0.22674645868039903, 0.10972322640760292, 0.2990901944858413, 0.10284895858457012, 0.17178118228912356, 0.11983067638451055, 0.1764522348680804, 0.1537281977793863, 0.2046528506663538, 0.12115468316140676, 0.1190223923373607, 0.1625080097226366, 0.14597042373591854, 0.25167572582440995, 0.19003249164069855, 0.11916889133112085, 0.12877530448379057, 0.2554219570611754, 25.819660617459206, 70.02827121365455, 58.998785941831535, 57.43882010059973, 48.49709480039535, 66.1996849121586, 66.38672705619567, 59.718242768318426, 2.353375525243821, 1.5164853872791415, 2.0617149433782025, 0.42096074850809195, 0.2146822133011395, 3.926368538410433, 67.3406788610643, 67.2330568682763, 68.81848673666678, 61.93309537826046, 63.62646102905274, 56.412908492549775, 55.12203293461954, 53.86821200770717, 51.08866753116731, 51.11393543981737, 50.64152517626363, 46.75730005387337, 49.7379405267777, 46.83405299340525, 48.491187710915845, 45.71471445022091, 45.50152186424502, 47.130968570709236, 43.077657914930775, 48.62700370050246, 44.747281459070024, 43.0483970334453, 46.438419203604425, 45.36055972499233, 49.25667355137487, 49.509552678754254, 46.631674381994436, 47.066504416927216, 47.88181612568517, 47.79604173475697, 47.65160045316143, 46.49604666617609, 46.346780869268606, 46.550649981344904, 45.492119942941976, 43.71558043264574, 44.916810220287694, 46.21820949739026, 47.16090409986435, 45.726363889632694, 46.69246719729516, 45.11962421478764, 45.02616982306204, 44.22050322255781, 47.50233073388377, 46.4818908322242, 44.99239037113805, 45.52425199939359, 46.34479614996141, 45.24415946775868, 48.82671902256627, 54.847757277950166, 54.85536275371429, 57.70074813596664, 60.401272543015025, 64.3881304033341, 57.176166426750925, 58.387978769117794, 64.02209481885357, 60.44005301690871, 56.05097962963966, 51.539567516696074, 44.8927660911314, 43.660616259421076, 43.32299824683897, 46.79787697330598, 44.59525039119106, 44.22541795238372, 44.005004282920595, 44.69440006440686, 42.44628183303341, 42.853357176626886, 42.94969843279931, 42.97663727114278, 41.53734707063244, 42.886791459975704, 44.395158521590695, 42.11132318742814, 44.38168125767862, 45.02603254010601, 41.791583338091456, 40.91272531017181, 43.18842564859698, 42.7560745516131, 42.836389003261445, 42.34153493758171, 42.027992433117284, 43.32115865522816, 40.60818072288267, 42.3387735889804, 41.17592027110439, 43.27518063206827, 48.279764113887666, 51.92637205123902, 48.731989860534675, 54.82091649886101, 54.39415870174285, 56.462895178025775, 53.64056548764629, 58.010431028181515, 56.023044509272424, 56.87006073613321, 54.98348305302282, 53.563918452109064, 55.305191932186005, 55.20575200357745, 48.860318045462336, 52.07781476359214, 51.627459987517334, 59.357420013796904, 56.410496234893806, 61.29918544523178, 57.21295433659708, 52.83844470977784, 7.039567472473268, 0.5803070061149136, 1.6649870574474337, 4.429510572264272, 0.3977895918632708, 26.771329602887555, 68.97950787698069, 54.12366028754942, 42.51473895965084, 32.636545819620935, 44.94713406408987, 51.62832290895524, 1.8818864058102331, 0.29592622071504593, 0.12968437505825875, 0.17308524779735074, 0.18850760894917673, 0.1136469295729072, 0.10696027668253069, 0.15476580258579026, 0.16595039516687393, 0.14271249694208946, 0.12224516335634455, 0.10057343230132135, 0.14082140890100311, 0.10107376432466893, 0.2131444603324898, 0.22095757656760756], [0.01810823477083637, 0.04365937378738196, 0.040419526668565894, 0.06798425884616953, 0.058154967733688896, 0.019511380345530568, 0.031869807318153406, 0.03468519767686244, 0.03854684388986038, 0.09409006084165267, 0.048683156229315266, 0.03855154383927584, 0.04759484406320318, 0.053024262400163766, 0.030669638654217127, 0.03497735296766605, 0.017564655168943347, 0.05268976542978518, 0.03506555267038845, 0.08315120628404041, 0.7910191832530884, 42.13961916585123, 48.03889920634609, 39.475996417383996, 32.30745307860836, 44.63381121235509, 53.82703104326802, 56.02371131220172, 5.484546759436208, 0.6583545729517937, 0.8105440065264703, 0.5320927416605334, 0.04583995879417466, 0.2796742782717751, 22.995095176081506, 67.48275495344593, 60.18905662721204, 61.38169250180645, 52.519454033144065, 52.82315531084615, 49.24370227321502, 50.14251339820124, 51.758478918383204, 49.966355831392356, 48.820309869704715, 50.40966210826751, 46.535423340335974, 46.14562603735155, 40.94145667168402, 41.37927947505828, 41.80865741545155, 43.18469155219294, 41.52302649713332, 42.52889087123256, 42.07973634043048, 44.41455071972263, 42.44177110733525, 41.89227842515515, 41.93156880717124, 42.06573740128548, 43.39490313683787, 42.733128686105054, 42.31469023612238, 43.08587528044178, 42.61659506828555, 43.43643319222235, 42.814419807926306, 43.4359585854315, 42.537641679086995, 41.70112171480733, 42.380307566735056, 42.40680709961922, 42.25283838087513, 42.95799424571376, 43.21429760225358, 42.744770280776486, 42.056410005015714, 42.91657009432393, 41.95272999425089, 44.6792910945031, 42.89289466796383, 39.75902680427798, 39.99192930036976, 42.646640423805486, 41.82591584420974, 45.39828508130966, 49.39645113483552, 53.20838305257982, 58.0752952637211, 61.61229256660708, 55.38769114402033, 58.728424810594134, 57.86016110450991, 53.33673477172852, 49.62569405955654, 44.67135221727433, 43.62729180243708, 43.42494456998764, 41.21105686310799, 40.9373656395943, 39.96335483366444, 39.33707783299108, 41.18075655352685, 39.00587681801089, 39.73428449323101, 40.52758386058193, 38.91948269259545, 39.41493295854138, 38.54687713807629, 37.15873856698313, 38.40596598963584, 39.00159751215289, 39.619064869419226, 37.82635342690253, 39.95932655949747, 39.127831151408536, 38.81894842270882, 37.62027209804904, 39.93823205271075, 39.536491132551625, 38.52467260053081, 36.15456081205799, 37.40166664123535, 36.56359734073762, 37.71280473278415, 39.73268024383053, 42.81382360766011, 42.73993007598385, 49.68968752891787, 50.929242795513524, 51.63184127499981, 51.61056633918516, 52.76218991125784, 52.8351342293524, 50.78004760126914, 51.7452173848306, 52.32417883411531, 53.54638153506864, 52.858421341065444, 51.18967640784479, 52.4285021135884, 48.154769943606475, 52.121745309522076, 51.76793967523883, 55.14128784979544, 54.13152463974492, 58.779019463446836, 26.225316063050304, 0.6529345928180603, 0.15989399515092373, 1.21704735823216, 2.1185491065825186, 0.7551632040450651, 45.8494007971979, 52.7813938356215, 44.01993282379643, 19.778371164875647, 25.408164762681533, 38.120468431903475, 9.062069500646285, 0.02030545537690482, 0.06457664613281527, 0.050240421457396406, 0.03217879930631288, 0.025477537119220343, 0.06840212150446831, 0.03433106970342417, 0.061340150648667935, 0.029981586361123674, 0.04173670760205677, 0.03359468300796805, 0.06530954712821592, 0.06769994063483131, 0.04673234014321239, 0.03720034860194691, 0.040706526187639085, 0.016622257854549155, 0.039896204346610654, 0.07288739776178714, 0.0679397797812858, 0.023902692088496783, 0.000527383784966303, 0.07934405573553617, 0.015125227247124479, 0.05913016701778097, 0.08508424529986036, 0.008639474211621189, 0.024111949005013993, 0.04384902651391683, 0.03179188468493521, 0.07195792626589537, 0.043911550779856985, 0.02662812840313681, 0.033708895226159406, 0.07795669348730196, 0.12077352377556025, 2.749430234393766, 55.02666834862002, 51.66862918484596, 46.754852494885846, 44.44127775007679, 55.50265189140074, 58.45083867349933, 59.57285619551136, 6.5329129561301205, 0.47516073370652817, 0.6734213773762027, 0.9611535216531447, 0.07449455829637666, 0.19494221125158573, 28.909627352991414, 66.50625736482682, 63.16152680304743, 63.37277781578803, 54.701531317926225, 56.34767947658416, 53.26325308892035, 49.6799914298519, 53.0502958451548, 53.30404181634226, 51.17659138094995, 52.00739252951838, 49.09888444408294, 47.86043920824605, 42.41297698790028, 43.78084867231308, 43.92792578666441, 44.178294597133515, 43.6571135828572, 44.100753261197, 46.43276314581595, 46.05514087984639, 43.14056488775438, 43.65012391921013, 43.735102068993356, 43.81410644900414, 44.76012722138436, 45.58224424239128, 44.99412013638405, 46.16128806144961, 44.52855048641082, 45.47865444614042, 45.55261858047978, 44.470942635690015, 46.543711308510076, 44.23736156955842, 44.79928424281459, 44.730430956809755, 42.66009415349653, 45.275189338191865, 44.84033576903805, 43.507294731755415, 42.721714588903616, 44.89670807315458, 44.557191633409076, 46.48865299840128, 43.139482313586825, 40.56708605058732, 43.32644208785027, 43.32099391568092, 45.47004092124201, 47.84023507948845, 52.17424231190836, 56.6817791231217, 58.454015793338904, 59.54537607008412, 57.61271838218936, 60.062199331098995, 59.875823989991225, 54.9940695301179, 51.54168167421895, 47.98419390955279, 44.38708628377607, 44.5064793094512, 43.24763774871827, 42.915652259703606, 42.22409132988223, 42.0773672288464, 43.45874755613266, 43.045102242500555, 40.24687551682995, 41.18097228388633, 42.51567248375186, 41.061010514536214, 39.91606281649682, 40.131271500741285, 41.314756485723684, 40.17780650046564, 41.71498729336647, 39.755065210403934, 40.76555405893634, 40.45951112624138, 40.53673082782377, 40.166121759722316, 40.811218292482444, 40.136299979302194, 40.26036847022272, 39.37862357785625, 39.32763668798631, 38.8646440352163, 41.53275397516067, 41.81852217643492, 44.118086214988466, 43.04521991360573, 50.433898433562256, 52.14539720166115, 53.86037511210288, 55.399383729504, 54.37152270347842, 53.51672057182559, 52.33351015275525, 53.70177799655546, 54.694027823786584, 55.416453884493926, 54.326160492435584, 52.82863878434705, 53.49468469619752, 51.16078030678534, 54.00051747598956, 54.51011573114703, 58.48827377442391, 56.30070124903033, 61.91204009517547, 27.97437740910438, 0.6587655025143778, 0.32191477295371795, 3.901962325457604, 1.7451668001951712, 0.9788850250263369, 50.358130008943625, 57.1602729828127, 50.92769345929546, 31.793428428711433, 22.40563746421568, 44.69056006400816, 14.392636264524153, 0.0722194840050032, 0.15420833572504983, 0.038297922771063544, 0.07178025515449625, 0.018457563203429023, 0.014418007434165526, 0.09982502568633327, 0.03390582961841457, 0.01943780526128267, 0.030815961447754697, 0.015177209185616625, 0.03631001270766701, 0.01590778223133736, 0.05504067093434353, 0.05217272119836942, 0.03695828013963277, 0.09468816100589691, 0.16425351041459268, 0.12495679285136924, 0.1389513882778345, 0.10973959004566555, 0.11366011394608407, 0.13726170475204147, 0.09706058208980868, 0.14620147585388155, 0.18989998907331498, 0.1503219563634165, 0.14031303295445058, 0.14509768105081974, 0.1824173784904903, 0.19037435071602946, 0.17844371107076445, 0.09598676430722398, 0.1546794031896899, 0.1794549318090562, 0.19037208309577358, 3.82152971240782, 65.0760199946742, 57.74180750693045, 52.10124700300155, 44.684060696632635, 56.207580258769376, 63.58491920655774, 68.28820582359069, 10.346766344962582, 0.8192308920045054, 1.8235363691083848, 1.4735943920189336, 0.14207619963394058, 0.4102468250259277, 28.27319533594193, 67.33743898330196, 65.13723642595353, 68.6144293508222, 55.90450656029486, 58.88541375437091, 55.791616824365434, 54.303712767939416, 55.81166405831614, 55.45739558435256, 53.51471231829736, 56.22554079178841, 52.99158580841557, 50.13909309141098, 45.13654139734084, 46.40675390920332, 46.56705333340553, 47.73804164701893, 46.88778946476598, 45.434567005403586, 47.58542222361411, 49.297148489183, 45.74083743556854, 45.77408344514909, 47.16059815499091, 47.07634564368956, 47.342823628456365, 48.16518383641397, 46.76807088236655, 47.673000904821585, 46.66495569290654, 48.59994719105382, 47.00944177566036, 47.547155580212994, 47.346389062943004, 48.91441537487892, 47.846220616371404, 47.10708525873, 45.73211016193513, 46.64830523152506, 47.714613329979684, 45.687265703755045, 45.072485170056744, 46.43001748669533, 47.314402134187766, 49.13138912570093, 45.15526679254348, 43.20630773421257, 46.35176620175762, 45.809192580561486, 46.856575242934696, 50.35021466593589, 51.55646508739841, 60.365116134766616, 59.5358996237478, 61.067173327169115, 59.68024284608903, 63.16990890810567, 62.39587622304117, 58.17012248500701, 52.41039645287299, 49.50449674360214, 46.123766668381236, 48.2338959170926, 45.45553207397462, 46.28825910629765, 45.087758879507746, 43.954746953902706, 47.42649562897221, 44.563647854712706, 42.56911869971983, 43.556732285407286, 43.23751018893334, 43.287406659895375, 42.81053273908554, 41.56114801283806, 43.17792938601586, 43.052233111473825, 44.45721434008691, 40.733523984109205, 45.02410273398123, 43.77270190946518, 43.66436996767598, 41.68164714690178, 43.09089199189217, 42.7539917730516, 43.851616074962, 41.14019532357493, 40.86096179100775, 39.867252842072524, 43.788442380966686, 45.46609501684866, 46.152223463981386, 46.54764544579291, 53.63067719244189, 54.43885803222657, 57.135216882151944, 56.26937720083422, 56.595569349104366, 56.047696605805434, 54.71616960340931, 55.707929134368904, 55.74533677870228, 56.409178318515906, 56.97427418924148, 56.86178845743979, 57.51993471576322, 52.29403149697089, 57.47104629393547, 57.524351304577245, 59.99980618876796, 57.94910869290752, 64.04112615892964, 29.54003853182639, 1.8357495266583659, 0.6205789612666254, 4.525511562824249, 5.841731025326637, 1.3067167853155446, 55.33837126147363, 60.58122696415071, 55.95774881301388, 32.934373347989975, 36.203158978492986, 55.721229891623224, 22.029191909297822, 0.16109900549054146, 0.17905541695654395, 0.1588085558145277, 0.24776009722582756, 0.13602165355076715, 0.210269010595737, 0.21373512944386852, 0.12825257971041626, 0.1001774108097438, 0.09739271184850125, 0.09801593203578265, 0.11389934022219912, 0.1552437035547149, 0.13308261851629904, 0.14292355416522873, 0.0669950018486669], [0.054951850700402455, 0.03566645288599595, 0.019526299907855933, 0.043543817084883495, 0.09857499235940557, 0.08029814163643507, 0.015789598804868517, 0.0654462785009415, 0.010217945711056312, 0.028464962097425616, 0.09425313797809425, 0.03957407203532996, 0.046529158303934726, 0.03737360321646256, 0.05766826824495389, 0.01696107173038106, 0.027581838920952815, 0.04147289756445154, 0.12871643828768886, 0.036212581645457015, 0.015560713758121337, 18.952465134282267, 49.42415483536259, 40.17309965625886, 38.760967946821644, 33.22282052809192, 51.11403742144185, 63.09290885925294, 21.565053924437493, 0.3400268075206588, 0.1332605960628679, 0.3870710105665269, 0.2806439310792954, 0.12100577865156437, 1.9343564419015764, 55.88244322807559, 63.705645838091456, 60.58472964071459, 59.26865677679739, 54.641546510881, 53.490001386211766, 53.737185232100956, 54.40261925420454, 50.541457668427505, 47.88059234619141, 49.73459866739089, 48.15611531657558, 47.495360682087565, 44.95596724171793, 41.18636162050309, 44.69944815481863, 40.82812370792512, 43.1169443745767, 44.0446751348434, 43.426340933768984, 42.63218256735033, 45.457532482762495, 41.178709076296904, 41.3923684243233, 43.41134179023005, 42.97288356288787, 41.194025931819795, 42.607561849778705, 42.6700020605518, 45.72045680015318, 41.7838837254432, 42.15816020965576, 43.42600753230434, 44.684347029655214, 41.0741896783152, 42.969369119213475, 42.22887269912228, 43.09471630281018, 44.36656444303451, 43.15379504234561, 42.344417879658366, 42.02112436294556, 41.47465975053849, 42.96681173386113, 44.69800864496539, 46.01254393977504, 41.8885168721599, 44.098407683833955, 39.67983807286909, 46.006283836980025, 47.83471238228583, 58.164948878749726, 52.377381863132605, 74.70728228169104, 90.73505955357706, 53.817770327291186, 58.8461547513162, 54.14650024906282, 50.31530164903211, 47.25733557055074, 48.7072200928965, 47.278535981332105, 50.291881176733206, 47.42007470900013, 45.465945966782115, 41.48215932230796, 39.96580239265196, 41.270257196118756, 40.14124608808949, 39.773712158203125, 39.94332721156459, 40.1859454185732, 39.713076237709295, 39.65022810043828, 38.25121671922746, 39.1712910129178, 38.567975567233184, 38.06988162379111, 39.96660255616711, 39.33664244990195, 38.5546826547192, 39.60319103733186, 38.636130671347345, 39.11950003716254, 37.98500937800254, 38.58813262754871, 37.318010330200195, 40.45526712171493, 38.96452326928416, 38.72132062911987, 36.742057338837654, 43.162926320106756, 45.69248245608422, 51.78182486564883, 52.30208020056448, 52.57572435563611, 51.798090934753425, 54.79340499447238, 52.796306687016646, 55.16766971157443, 51.13992506457914, 53.06433400800152, 51.01867675781251, 55.04048685873709, 51.860099684807565, 51.4765428727673, 50.24394589085733, 56.114769135752034, 52.155097223097286, 56.15386732162968, 57.600884591379476, 47.726858969657656, 10.859874140831733, 0.04027834815543987, 0.14904977543459785, 2.1398331128781845, 1.605540473134287, 11.742782996546838, 57.28664782739455, 47.77105231438914, 36.90971512948313, 32.439325124986716, 35.365113212216286, 33.199011741145966, 2.348755463477104, 0.18863079588740103, 0.056682213494974765, 0.02704145007526442, 0.03869763297599651, 0.01825378956122985, 0.10146367243461071, 0.10624869591406277, 0.027747162610232353, 0.045510211568926616, 0.04923336823741275, 0.028792399567581957, 0.026857633023492755, 0.027713623280907353, 0.03638214371617764, 0.09773120779784457, 0.03882623232540585, 0.07183119234058165, 0.038924751232468316, 0.04471705775828131, 0.06642411312749309, 0.03174654185591686, 0.054535941566310586, 0.057791516470212134, 0.06319147872648413, 0.02092116790252828, 0.018201281894899664, 0.07429269412832876, 0.08727967709062562, 0.05927136468310511, 0.03644521190454403, 0.006486152358833821, 0.04795401672562284, 0.05641858348803175, 0.05213898268618411, 0.145582921142059, 0.04464871888499587, 0.09601026788474092, 31.05951374576938, 54.788156863181825, 40.41816934462517, 39.07708744848929, 43.816204917046335, 56.19740955291256, 70.4905382279427, 19.427156256091212, 0.2801760045751449, 0.25219387705287627, 0.7467459815163767, 0.1047050440683961, 0.782665821813768, 2.915737258811151, 57.43647844560685, 63.84439576056696, 61.476809978485115, 60.55717499025407, 56.49328962449105, 55.81822618361443, 56.8375599768854, 54.62969703059043, 52.18976313068021, 51.20821745164933, 52.27985212879797, 50.54203033447266, 48.96371172320459, 47.74036369016094, 44.74108803656794, 46.208776197125836, 41.139077448075824, 44.70751254789291, 44.83817846544328, 45.091418450878514, 45.20499067921793, 46.543519112371634, 44.202981994998076, 44.59834514125701, 44.77379275906471, 44.10233789874662, 43.97122483099661, 43.6585727045613, 44.33441277473204, 46.45973728549096, 43.99950511993901, 45.20502598054948, 44.10564837917205, 47.03308582305909, 43.450836135495095, 44.262103880605395, 41.84158963541831, 45.00135690935197, 44.90296033120925, 45.03478334796044, 44.56066293101157, 43.69221487352925, 45.37386048224665, 44.91874787115282, 47.10370025327129, 45.995783652028734, 42.42453621279809, 44.44738488043509, 43.18014160279305, 46.2122945631704, 51.65140997978949, 55.350134449620406, 56.948249263148156, 64.7872394131076, 64.28162628604521, 58.878949688326934, 58.382758094418435, 57.55629116489042, 54.14809665372295, 50.49207110558787, 47.56895219126056, 48.2214423917955, 49.517389574358546, 46.206352172359345, 46.98099282480056, 43.56027810804306, 43.29442378013365, 42.94587804425148, 40.279117399646395, 41.758086296819876, 41.65781090336461, 42.96579976235667, 41.468717359727435, 42.423877254609145, 41.973169465218824, 41.19998793448172, 41.06008875754572, 40.875027410445675, 41.487438832559896, 40.6724448357859, 40.32447961068923, 42.21903147235994, 41.08508210028372, 40.79621914894351, 39.722846861808534, 40.92453948913082, 39.30979774844262, 40.663850922738355, 41.02368131760628, 41.094131008271255, 37.948715686798096, 45.47877211724558, 48.629870953098425, 53.968577615676395, 53.41667267584032, 54.519827519693685, 54.551273161365145, 55.83657110891035, 53.65222669416859, 55.882396159633515, 51.61488879111506, 53.881293112231845, 51.90947448053668, 57.518146114964644, 53.414378089289514, 56.33355894396382, 52.58683643033428, 58.37984769575058, 55.267697995708836, 58.35239502691454, 55.173047281080684, 51.28256597826558, 11.37719456226595, 0.14972765599527668, 1.9057251008287555, 3.583041516042525, 1.9108877979939984, 12.537907246620426, 66.50173094964796, 50.03951195747622, 41.71927444396481, 30.86745292909684, 35.210991521035474, 43.641078933592766, 3.2172966772510163, 0.4955588665700728, 0.14991677246026455, 0.08836552245362152, 0.046991591957668145, 0.044140362090641455, 0.025004680839277087, 0.10610023573521646, 0.041965292916903575, 0.051858376170839035, 0.06409417927986191, 0.033689831128163684, 0.04504511959009594, 0.02567476262488673, 0.011740963936092393, 0.05150527092477968, 0.028684915516585596, 0.1184530434529147, 0.1537200925691474, 0.10518639243298, 0.16969126378816946, 0.1558684482569656, 0.15084524038097552, 0.1513109605519041, 0.16524956261198367, 0.10725493708084669, 0.14834791632188907, 0.17853798585072642, 0.23270073917604264, 0.1540377892313465, 0.09835175433827024, 0.14267099029835195, 0.15016495430421445, 0.16020269794089181, 0.17574565665375802, 0.3288089820454198, 0.11169742732759445, 0.18429840013625162, 38.20731755225889, 63.0593490600586, 50.2466562486464, 52.16731932855422, 45.51190045572097, 62.718291128835375, 75.36860173748386, 31.36941040715864, 0.4495217933529808, 0.6346029668085037, 1.224664110810526, 0.3238634554849517, 0.4595608240173709, 3.2620847513598785, 60.8447749383988, 67.00570060360816, 65.02803371798608, 65.81047596470003, 60.40440259441253, 59.558806265554125, 60.811105312839636, 59.03450304462064, 55.56926942640736, 53.826219112642356, 55.1529961247598, 53.09964710666288, 53.1356740766956, 51.2356936547064, 45.878544007578206, 50.19208823480914, 43.0169004009616, 46.95432462999898, 47.39633652471727, 48.49002668934484, 46.510802622764345, 49.431038595015, 46.31820248019311, 47.46748831964309, 46.73403647638137, 46.68540300861482, 48.19026347129576, 46.25005129844912, 46.312640559288766, 49.265518496113444, 45.40975016932334, 46.72079063230946, 46.10684164108769, 48.78689127583658, 45.920085830073205, 47.74123837870937, 46.110560048011045, 47.94339341502036, 47.800152378697554, 48.44950076072447, 47.369636950954316, 44.40840436566261, 46.97972982160507, 47.502813185414965, 48.081445155605195, 49.3613302323126, 45.6800603097485, 49.17723771064512, 44.80887051551573, 49.378369008341146, 51.81106221291327, 58.56208101395638, 57.70412529668501, 68.92945843358194, 69.27374839782715, 59.2077462903915, 60.8438531814083, 58.646058959345666, 54.45330412157121, 52.68963783018051, 49.97083910049931, 51.06871443410074, 53.45975206744287, 50.77541135972547, 50.39717720400903, 46.532752206248624, 44.84655272576117, 44.5708179473877, 43.22057731689946, 45.90568680917063, 42.591268324082904, 44.907376920023275, 43.88805881623299, 44.28837983838974, 44.17062636344664, 44.212756541467485, 43.030860116404874, 42.85422009806479, 44.007483220869496, 43.381359192632864, 42.58681251156715, 44.74674017198625, 43.02883225102579, 41.97021592047907, 41.95050208799301, 42.74409563310685, 41.67288064956665, 44.1143128948827, 45.20584575591549, 43.14528742144185, 39.14670167430755, 48.94303691002631, 50.748621571448545, 57.01228195621122, 55.73348337604154, 56.661771112872714, 54.50371442302581, 56.5258413745511, 54.5674176369944, 59.0336165889617, 53.796875861383256, 56.50562155631281, 54.20830111349783, 59.207342286263746, 56.04846931272938, 58.97897405009116, 56.11487111737652, 61.979618610874304, 57.61645640096357, 61.75784780133156, 56.615879381856615, 52.73404690527147, 13.214007173815082, 0.21265531319283673, 1.184971563277706, 7.610605243713626, 2.958711481863453, 14.21506860563832, 69.15581057148596, 56.008296397424516, 47.173655725294545, 45.73862521879135, 47.93421114644697, 55.180268364567915, 6.932914795414095, 0.7066903695944817, 0.322471565657085, 0.17332403740334898, 0.2157982655109898, 0.2372508111499971, 0.14719343714175687, 0.18209379827303274, 0.19559989773458053, 0.14862340153946033, 0.17076554888438794, 0.1422981812708801, 0.2245688231121148, 0.15084471944118702, 0.10527303697721613, 0.20848646189176268, 0.13612035631893143], [0.015555671941969666, 0.04173153267812826, 0.05405303804324039, 0.030165089316846385, 0.03810368500830185, 0.02096134729893698, 0.005142341730290003, 0.05301110867050387, 0.06101222288224006, 0.04684331563992366, 0.1466866853016038, 0.04787574552239911, 0.0050166310111601515, 0.024092764248170202, 0.025110088791998646, 0.036266793857418725, 0.019015508869122115, 0.07877476047724485, 0.12843862416282778, 0.05918386595083341, 0.10622831031439767, 1.7390160334687081, 44.71729886147284, 47.43871381205898, 40.03746409570017, 30.633599258238274, 43.742487892027825, 55.5208634561108, 54.1705600676998, 1.744843327230023, 0.0930523487829393, 0.3100023202357754, 0.19451225206496256, 0.1576177947103016, 0.07491239797203772, 23.015613094452892, 70.29140733903455, 62.14485237675329, 60.188154482072406, 55.92110995323428, 55.32884382432508, 52.13900766065044, 50.451192163651996, 50.38461777471727, 51.06042646592664, 49.60675293399442, 51.788575264715384, 45.445749682764855, 46.770361546547186, 44.850204452391594, 44.02628314110541, 41.77740004754836, 43.709626274724165, 45.85748480212304, 47.95635684843987, 48.475568832889685, 46.21798984466061, 42.32802629470825, 41.598708629608154, 41.951882762293664, 41.85501590851815, 41.86639862675821, 43.079685780309866, 43.25931072235108, 47.28612576761554, 43.2035699198323, 45.0840953857668, 43.06084271400206, 44.53945075311969, 43.72610415181806, 44.08566782551427, 42.594708242724025, 44.48450226937571, 41.1953007021258, 44.561619989333614, 42.63799944231587, 43.03975997432586, 41.67899170229512, 44.22781844292918, 42.88579517795194, 45.02449889336863, 44.65305436042048, 45.303167604631, 43.487008233224195, 50.73204955747051, 52.415644584163545, 58.722741296214444, 56.465911480688284, 74.50853578505978, 112.39940043418639, 57.14003355272355, 58.26580870536066, 56.56825788559453, 53.68043638044789, 50.584140900642645, 54.57315998692667, 55.41523794974051, 57.52423755584225, 55.11759673395465, 51.95227930622717, 41.78434656512353, 40.72898580181984, 41.433192453076764, 38.50671206751178, 38.80441996359056, 40.7842755317688, 39.35120228798159, 41.06440336473527, 41.344350768673806, 40.966622598709606, 41.284715052573915, 38.566371317832704, 39.60208885131344, 39.46720246345767, 37.06689234702818, 40.738944699687345, 37.945307147118356, 40.1748372662452, 39.46796732564127, 37.80456858296549, 36.803662084764056, 36.865211917508034, 37.59738114572341, 38.09625171845959, 37.53653341724027, 38.87357134972849, 37.54957137569305, 41.72495011360415, 49.35632528797273, 51.73481525913362, 50.927152172211684, 52.90095552321404, 53.248218644049864, 51.84051529053719, 53.09155525699739, 53.490146513908144, 54.84700026050691, 53.99887400288736, 52.46016740798951, 53.75666764474685, 56.27700621081937, 52.9751314655427, 54.50482445378458, 52.346614791500954, 55.96393046840545, 47.99797319596814, 29.696221428532755, 2.875580523283251, 0.2226418208691382, 1.6635154331884079, 3.5220795485281178, 1.220513017427537, 27.08799235282406, 59.981743674124445, 43.303751176403416, 46.83173879500359, 44.5765132288779, 31.250817544998664, 26.323793049781557, 0.1567674217925918, 0.11487621723884538, 0.02508094872257883, 0.06720857184019781, 0.043414976417778, 0.06124098439730945, 0.03362952851720395, 0.034486842191507744, 0.06405745302477191, 0.019621174151618636, 0.0654693683909793, 0.08118974540622965, 0.0362947101013795, 0.030583156903664914, 0.038787464445997635, 0.06360025558200094, 0.02304862854221175, 0.08726388035762696, 0.045879534896342986, 0.046603599067537055, 0.02357767928662079, 0.06964010426834708, 0.03687991317541849, 0.03566202489779361, 0.05400799973417194, 0.013241768484154056, 0.03300816609313892, 0.05752551542114347, 0.12347802865288912, 0.0326802306658318, 0.025472869728541663, 0.028251574051776723, 0.04708206311108605, 0.07021795672875258, 0.09392123804577897, 0.0979156970917698, 0.0124727129267769, 0.24753149658922227, 5.635584977365309, 58.917600724004934, 48.13366366970924, 43.32893671527986, 43.19012795725177, 50.77481515945927, 60.27949471627513, 55.420109533494525, 0.8737654431212334, 0.09138593900828593, 0.1611781883383951, 0.36853290853961823, 0.653237350765736, 0.09842705312034777, 25.845269772314257, 70.8305214297387, 62.16900240990424, 61.80902296496976, 57.59755842147335, 57.273845211152114, 54.56391888280069, 52.965855060085175, 50.8517446056489, 52.761150483162176, 54.471421549397135, 53.152442209182254, 47.818618897468816, 48.40626447431503, 48.3309353551557, 45.35591956107847, 43.24637082315261, 47.80645170519429, 49.270260641651774, 47.88906466576361, 49.06528149881671, 47.51960485212265, 43.491389520706676, 44.87911624293174, 43.61643860417028, 43.4032577853049, 43.22346025897611, 45.90935422528175, 45.300202292780725, 49.72179605114845, 44.24831282707953, 47.3918414884998, 45.409805082505756, 46.432355219318026, 44.29061558938796, 45.332738353360085, 43.98158773299187, 44.47996016471617, 43.90374437455208, 47.057698695890366, 45.80887486857753, 45.42605546212966, 45.06479340214884, 45.82865145898635, 43.8261559701735, 46.36634565168812, 45.49415957543158, 46.63605566947691, 43.9928763143478, 51.2717951497724, 57.17309128853583, 60.526019603975364, 55.74091626751808, 77.11278561622866, 95.08088096495598, 54.456842099466634, 59.48311236596877, 56.977168898428644, 55.82564338561028, 54.83535082109513, 56.21186348699755, 56.80752638847598, 57.56062146156066, 55.52241279232887, 51.596814509361025, 44.11088082098192, 41.99294213325747, 41.97429518545828, 40.18357238461895, 41.15027189254761, 41.45091372151529, 41.743475467928, 43.69468204436764, 43.309995589717744, 42.34676345702141, 42.854322079689275, 39.62398744398548, 41.54639597861998, 41.55657845158731, 37.45745451219621, 42.706150624059866, 39.883962139006584, 41.59236615703952, 40.85225020685504, 40.57099273127895, 39.91004590065249, 39.763513995755105, 39.526696974231356, 39.285177030871, 39.573071156778646, 40.19995612482871, 40.01466728025868, 45.671635058618364, 52.27908726661436, 52.70844167278659, 51.74809248216691, 54.72858390500469, 54.4522137026633, 55.89723448599539, 54.54609171036751, 55.29642935722105, 53.68761431786322, 54.22352775450676, 53.77374564447711, 55.098651686022365, 60.23004931788291, 55.00366756992956, 55.693255547554266, 54.46212945445892, 55.98487984749579, 49.52452828807216, 32.607741894260535, 3.7795127928256993, 0.3061161094134854, 3.9272873536232984, 4.259472883516743, 0.31679862329075414, 29.86581883122844, 66.90368760016658, 49.5113177453318, 57.1923932721538, 48.50390795738467, 36.469852693619266, 32.89181955399052, 0.04667702859507934, 0.10011733419472173, 0.10498740109464816, 0.04323133748144873, 0.029156766306128235, 0.028345973321026372, 0.02913845488951812, 0.10764528952178457, 0.0469555207077534, 0.03968090299637087, 0.042675123174464515, 0.026281098234316996, 0.05588792587420153, 0.05189925079203902, 0.029808992497442715, 0.0473256369361714, 0.10246976804468902, 0.15440160438658732, 0.09383903681150368, 0.2253982205424578, 0.09720482112419221, 0.06928250974705143, 0.07917602201022449, 0.07115357991067633, 0.16192739168482442, 0.0859694522354872, 0.12489958906606322, 0.1641859108161542, 0.20634526146515725, 0.20375824383189603, 0.09285306633119622, 0.12401259714557279, 0.18752148525128443, 0.20056471438898196, 0.26190342862279187, 0.2743976178669161, 0.13836553019862022, 0.47604532011093637, 6.800056763233678, 66.40007880426222, 57.274986620872255, 52.90297946622295, 43.00690227939237, 57.39959639887656, 64.44659333075246, 65.10519066164571, 2.4440864641820235, 0.17159047236125316, 0.47850311403312995, 0.34817917813216487, 0.27671858848583314, 0.1501432740159573, 28.445093208743682, 71.94773012591948, 65.28279950541835, 65.38462423509168, 61.51661811336395, 60.45233003554806, 56.81517108794182, 56.12737563348586, 54.8150094093815, 54.54074551982265, 58.56443443605977, 57.63890020308956, 50.957887864881954, 52.94225415875835, 51.22840196855607, 48.52595952249343, 45.660169970604684, 49.58821973493023, 50.73382639115857, 51.43490691338816, 53.631606794172725, 50.35962835434945, 47.716464688701016, 48.187643328020656, 45.11525861678585, 44.58171036935622, 45.28376756175872, 47.43424231006254, 47.191855522894095, 53.30466547319966, 46.52716675112325, 50.210386091663, 47.43330486359135, 49.40633550766976, 49.407037611930605, 48.70040301353701, 47.856383477487874, 49.774834340618504, 46.35166422013314, 47.90862160344278, 47.11853465726299, 46.33436264530305, 48.36254965874457, 49.31379895056448, 47.322713636582904, 49.97201973392118, 49.824926930089156, 49.453835410456506, 47.28944801515149, 54.578678761759114, 55.22636798120315, 64.89885045636085, 56.5370907322053, 83.84835027879285, 104.4344472885132, 51.862362892396995, 64.9229455763294, 57.38465216852004, 57.807103203188994, 56.451775258587254, 59.951651250162435, 60.872207995383974, 63.05980797736876, 58.92959925436205, 55.08714345193679, 45.75341647671115, 44.898512363433845, 46.554431146191014, 42.45111419308571, 43.56535365504604, 45.546444769828554, 43.35400066068096, 46.10072666598905, 45.14724162317092, 44.76341024521859, 45.37688855201968, 41.791500968317834, 43.517904743071526, 44.7034764289856, 40.687079198898815, 44.065546066530295, 43.244492007840066, 45.23927219452397, 43.626028799241595, 41.83691809254308, 41.590910957705596, 41.124725495615316, 42.59455134791713, 42.075374664798865, 42.3775383733934, 45.16899508814658, 41.8104773952115, 47.214318936870946, 55.73890409161968, 54.88037570830315, 53.563969442921305, 56.75497055053712, 55.941172876665675, 56.209612046518636, 57.68048124928629, 58.2830749788592, 57.30083896267799, 58.28036069869996, 54.27631501228579, 55.59715355596235, 63.41035019966864, 54.82214420072494, 58.04933701792071, 53.56580511216195, 57.47353307662472, 51.29960475429412, 34.5101777199776, 4.137870582842058, 0.43516123006420754, 4.1868879525892195, 13.174783472091923, 3.642488958374147, 31.952288343060403, 72.35503688935312, 54.48282387948806, 55.6883486624687, 55.115941493741936, 46.20370457249303, 44.39956726566438, 0.3328795442658086, 0.39928361653320255, 0.31713910340782137, 0.15584512854055052, 0.10294532478456536, 0.20377053188220148, 0.10094685419913262, 0.12899615231060213, 0.17091660610129758, 0.08336987076026779, 0.2142445013047226, 0.16476366368512954, 0.16736473137092206, 0.09102298953239957, 0.18950759883849852, 0.1317329248113017, 0.12468470140330254], [0.09940318703170746, 0.035472253427630475, 0.013165420161620265, 0.028215734543459072, 0.029034862565177105, 0.058823708865431056, 0.009695869239587939, 0.03254021660635068, 0.04684071477142073, 0.12705925221164382, 0.07270880734487888, 0.009416262468984051, 0.06552109464762673, 0.02846119869049759, 0.04310444267767091, 0.025642950823830984, 0.09350924362098018, 0.03886988784577097, 0.06385875279985129, 0.04196884373443262, 0.14648947894813555, 0.03678179263407665, 16.727788948243667, 51.27035563991916, 35.752415887771114, 24.957504041733284, 31.977683728741063, 49.74779744302073, 65.56204088272588, 19.754874206358387, 0.5748921128049974, 0.3108860179781914, 0.23483069343191965, 0.3761109583560498, 0.20384159419805775, 4.006981335340008, 57.64368157232962, 63.75420085845455, 61.12679727615849, 57.95943237120106, 55.936681762818374, 53.43773972603583, 53.09550508376091, 51.420225481833185, 52.302578341576364, 52.06826771459272, 49.729829065261356, 46.852507745066, 48.48759874220818, 45.88647504006663, 44.826995788082, 46.1919923751585, 49.66442746500815, 50.16807156224405, 51.02154008803829, 50.806154897136075, 47.74095596805696, 49.49051741630801, 46.71405592272359, 49.63560981135215, 46.332150428525864, 43.00364278977917, 44.07565009209418, 44.88123040045462, 45.23822099931779, 44.45916768043272, 43.34660307053597, 42.94510533732753, 43.697361023195334, 43.759381540359996, 41.325703820874615, 43.15751737163913, 42.78592378862443, 41.6979524397081, 43.75273312291792, 43.98891472047375, 43.53351577635735, 43.8763976097107, 42.0914642272457, 42.44346557124969, 42.46037098669237, 44.92169357115223, 44.76345731366066, 45.82777284806775, 53.94064641767933, 57.49583175105434, 52.99439814782912, 60.953452048763154, 47.90279296136672, 43.74644948590187, 86.98740743821668, 58.43652986711072, 56.00053010448333, 56.16625808900403, 56.581362524340236, 58.35437974622173, 58.830649622025035, 56.971552064341886, 57.08867796005742, 57.168066732345096, 48.00538255322365, 42.19186905891665, 40.56682325178578, 39.47806350646481, 39.37397556920206, 39.52500251031692, 41.97087880103819, 39.517251906856416, 42.16621283561953, 40.73094306453582, 40.694319894236905, 40.76422829781809, 38.48155006285637, 38.76383127704744, 39.42660593217419, 38.52434704380651, 39.70194062879009, 39.464692146547385, 39.794853733431914, 40.74651487411992, 38.48258556858186, 37.49956115599602, 38.69645280222739, 39.17462110519409, 37.10388814249347, 37.44846443976126, 39.68926745076334, 39.71091501174435, 41.21732088827318, 48.62591720396473, 49.858016044862815, 52.391396491758286, 50.90701472374701, 52.68379349862376, 51.70307543969924, 51.42233963935606, 52.45276981784452, 52.98694956687189, 52.59851724870744, 52.215556636933364, 50.27785870336717, 52.60655810756069, 50.108784937089496, 57.24264275643134, 49.68932274849185, 46.64049579251198, 17.87574706539031, 0.05181689634017887, 0.7994551596141631, 5.910353381787577, 3.6564535767801347, 0.32908995245252887, 37.40714619236608, 54.99573261507096, 31.380940214280162, 27.275640503052745, 27.79377187452009, 48.02049936786775, 11.212885495155088, 0.4668705591992025, 0.1396198766005616, 0.032828085635217934, 0.07070595473651925, 0.04748448143683134, 0.06602293586418514, 0.017638940799741015, 0.046456234394422466, 0.038173253452705766, 0.10804166341380728, 0.03426608246480746, 0.05797249325100453, 0.024210343422788768, 0.016706851198368015, 0.05164150434035448, 0.08834005769101844, 0.0031321507178231956, 0.04128676118148912, 0.01391915396051181, 0.018388908318874818, 0.02411816580851953, 0.011189738776715053, 0.026626921814656066, 0.05486394594153089, 0.04852533062559463, 0.061337948145885626, 0.12666936708433976, 0.053395470303873864, 0.0617852324109164, 0.034149468560973485, 0.047600034308890184, 0.043041784346344016, 0.03526176693999479, 0.09943612115157228, 0.044996790933392705, 0.07863052144286134, 0.1066524089284001, 0.1094924730639304, 0.05533587142464615, 27.45179806986163, 57.66110474063505, 36.63357242461174, 31.320859309165712, 44.51442210905014, 56.18597976623043, 72.08662125372118, 18.22203939960849, 0.6506286068789421, 0.6836386613788143, 1.7235994026545556, 1.438900292400391, 0.8311339371627378, 5.63757558022776, 57.47305846983387, 65.70012400227209, 62.91873993412141, 59.65155855301888, 59.91361210423132, 55.067523756334865, 54.75482848382766, 54.48940561663721, 54.70568510793871, 54.67895415521438, 52.890961324014974, 49.89024223819856, 49.31494820502497, 46.968307879663286, 45.639965841847086, 46.335135352227, 51.31251327453121, 53.53298664093018, 53.434072309924716, 51.80162891264885, 50.64488272513113, 49.586690010563025, 47.86332999506305, 50.21401820644256, 46.694506829784764, 45.25704445377473, 46.398038402680434, 46.50269508361817, 46.729321787434245, 46.83295080738683, 44.358876597496774, 45.079274792825025, 46.71362838437481, 43.77928756898449, 43.05739495062059, 44.262170560898326, 44.0153750296562, 44.569798131142896, 43.71796523371051, 46.357088858081454, 45.40168577624906, 46.33623753824542, 45.18577498774375, 44.16917116411271, 44.97926219817131, 46.581456276678274, 47.45222245493243, 46.88962513400663, 55.00392252399076, 60.69405394215738, 56.85814065317954, 61.77380400319254, 51.95529953125985, 60.31098742638866, 68.47840155324629, 56.109403333356305, 60.65320245681271, 57.63853934503371, 59.40572792483915, 59.24790743858584, 60.95666054756411, 56.89574049365137, 57.69565689948298, 55.50335791803176, 49.15707280558925, 43.682491317872085, 40.78516590979792, 40.38324063824069, 39.35660731407904, 41.13377440360285, 43.19187341197845, 41.25070418080976, 43.92526249731741, 44.56371453500564, 42.44257519322057, 42.117108683432306, 39.3313511725395, 40.82336195053593, 41.09850445101338, 40.017244277461884, 40.733912298756266, 40.95302766369235, 41.670495848501886, 42.521418756054295, 40.847892453593595, 40.79671336758522, 40.98109614464545, 42.288531949443204, 39.7420350966915, 40.380793079253166, 40.653437029930856, 41.04265774449995, 45.44925235932874, 52.753678367983916, 51.870882280411266, 53.72562992957331, 53.65998514236943, 55.13178002449774, 53.66688459150253, 53.25177623379616, 54.76942362323884, 55.599373617479884, 52.858582158242505, 54.074014848278416, 51.884810616893155, 54.78760380898753, 49.643132917342655, 58.11554270405924, 50.44286104940599, 50.19708533440867, 18.565442908194758, 0.17915578979638316, 1.9730648422433485, 4.730794199051396, 2.9379104173952535, 0.32973625486896885, 43.111759001208895, 58.099802232557735, 38.43772149855091, 43.60206311748874, 36.775209211534076, 50.14553362323392, 15.8719503302728, 0.7293687171993718, 0.20497019492810775, 0.18824614314061983, 0.059370251312371225, 0.05725675645554739, 0.05350754130631686, 0.07403299032199769, 0.02016140211884293, 0.054644530699137724, 0.052593671191003055, 0.09611536748707296, 0.018855756554271907, 0.009724002860997234, 0.020400842899576794, 0.02063669647360521, 0.0027369520525568195, 0.046968636133017085, 0.1734828627518108, 0.15083525059444292, 0.09973269676969898, 0.13217016183320554, 0.15808880088790772, 0.12013530358672143, 0.10862774365851957, 0.10400762060476888, 0.21838301552399514, 0.24177920283569446, 0.17643038604047992, 0.1355380069224104, 0.12679780172484537, 0.08533231223062163, 0.12348697655984472, 0.13888910532959048, 0.22661983966827395, 0.11922355170451826, 0.3391433855698955, 0.18343736327463583, 0.20442420406447304, 0.17103320468337307, 34.6697554280681, 65.01481533050537, 45.467965987420854, 34.65178705030872, 44.724943560938684, 59.67033101666359, 79.65775274461316, 24.27906147895321, 1.0353715068870977, 0.7545885155277868, 1.3146659587660146, 2.0129966543566797, 0.6680062389181507, 6.844141752489152, 59.54348548766106, 67.6547351960213, 64.92747591387841, 62.316585510007805, 62.00709873630155, 59.38023251871909, 57.58652479417863, 58.892497554902114, 59.32486041899651, 57.96715944044052, 54.752824152669604, 53.90344273659491, 53.67863209016862, 51.734285739160356, 48.94357035236974, 48.50845006204421, 56.266537404829464, 57.467763270101244, 56.06007168369909, 55.48212612828901, 51.31829877053538, 52.98996979190458, 52.39112977058657, 53.92308988878804, 50.87440806050455, 47.68573684077109, 48.339576336645315, 48.354677461808734, 49.29187290130123, 48.74164673589891, 46.88684025118428, 47.60621863026773, 49.05374580813993, 46.283442435726045, 45.06327936726232, 46.88584396916051, 48.45701602197463, 47.0712387177252, 47.13579700839135, 47.58797568659629, 47.96421727826519, 47.679527728788315, 45.729862643826394, 47.40766825214509, 47.285898270145545, 49.802287009454545, 50.41509851332634, 48.25447267101657, 58.438910745805316, 59.33607447531916, 58.40223266232399, 63.11010453008837, 59.06627816538657, 66.28407078404581, 69.16240015337544, 59.938060237515366, 60.660407850819254, 58.79917652376237, 59.9237161297952, 61.18040823167371, 62.950730785246826, 59.71682287031605, 60.82812055464714, 59.374749045218195, 51.64506358485068, 44.78812509967435, 44.81753895359655, 43.081662654876716, 42.11288036838655, 44.23328230457921, 45.60178941295993, 43.270791499845444, 45.570065283006244, 47.44708807237687, 45.25842120570522, 44.766677579572125, 41.360471710082024, 42.63221002394154, 43.636960444911836, 41.64084272999918, 42.86263358208441, 42.693563738176906, 43.38167690461682, 45.68706566287626, 42.84411999487108, 43.54127814692836, 43.071491949019894, 44.136556656129905, 41.97917461395264, 43.52495324227118, 43.96595708785519, 42.79932652750323, 46.27308737847113, 54.73616584654778, 54.97152374636743, 56.39645414967691, 54.531327909038914, 58.05427528196766, 55.71049044209143, 56.587532412621286, 58.21093866902014, 57.534851489528535, 56.39710134075534, 56.38005471998646, 52.04461582245366, 55.10521773369082, 50.76426790606592, 57.12634840319234, 52.662345978521536, 49.961613685854026, 19.952783276957852, 0.24003575525937543, 2.153860244058794, 11.73969413003614, 11.230754833067618, 0.7840452090867105, 46.87496723667268, 65.3062984251207, 40.02213939543694, 38.12911333576326, 39.851120133553785, 63.02509107897359, 22.769823651159964, 0.7847239629876229, 0.2263776792754089, 0.31329092119009266, 0.21471016018861727, 0.12038010698292526, 0.17204179007920528, 0.26927818934763637, 0.19435397829980622, 0.12451509719774609, 0.1558208741968678, 0.14978557224235228, 0.15012514837566884, 0.08921807106103628, 0.11496406454112261, 0.0740677860355185, 0.20930314226256264, 0.15546436752042464], [0.06543760638563864, 0.03251401639934028, 0.03441940730197295, 0.05665500588234394, 0.016618523175918287, 0.029108889641300328, 0.04058766381574735, 0.029227784571928844, 0.07258352132574206, 0.018018792090456814, 0.02974769397218141, 0.03220727862489801, 0.053597154441259565, 0.05161148518504155, 0.05286600012632628, 0.01208095088405835, 0.033029735298647035, 0.027469681733618342, 0.091897455915328, 0.03870732398823865, 0.012228447707339883, 0.18615997847049467, 4.207139149788888, 51.35551421873031, 53.21852237947526, 47.06592782851189, 35.90381545405234, 38.55097993727654, 57.728000763923895, 45.69552621533794, 0.11464267533512847, 0.6345202293126815, 0.2441205820369144, 2.7276149920878874, 0.5460099851892841, 0.08648061674208411, 33.537088671038234, 69.16480848866125, 61.166566187335604, 60.21974525144024, 57.56171188046856, 55.61081517127253, 53.74356692837131, 53.4929157072498, 50.318321874064786, 52.65946303644488, 49.90826945151053, 48.94241325316891, 45.8094749912139, 45.464596671442834, 44.01885024962887, 49.487834515110144, 50.42806979148619, 50.51181631703531, 52.27932260882471, 51.447038804331136, 52.161784864241085, 53.402163828572924, 57.64906306420603, 57.156942890536406, 57.822753460176536, 49.6095182049659, 42.96336789284983, 45.26448911236179, 46.14282546504852, 47.36569496893114, 43.37778591340588, 42.63210411994688, 39.90604508307673, 43.60981764331941, 41.89964463633876, 42.369721089639974, 41.24243582448652, 42.21938840804562, 45.056187721990774, 45.2418178127658, 44.573453780143495, 44.775087141221576, 43.68905736554054, 42.58762444219282, 42.20331845744964, 42.35889142559421, 41.54974176037697, 47.73739837831067, 56.62722287639495, 58.360380972585375, 58.64211305495232, 56.767365240281634, 46.05584298410724, 21.44155417719195, 66.67662943563154, 64.94158075701806, 54.75728388755552, 57.350704054678644, 57.008543937437004, 60.57692804644185, 58.44109158362112, 55.40108211578862, 55.71610335380801, 56.20789012601299, 47.38928802551762, 41.52718420951597, 40.70537705575266, 40.32782147007604, 40.204670813775834, 41.768872814793745, 40.423562603612105, 40.05549523138231, 40.24104687475389, 40.86702185292398, 40.87991468368038, 39.21819471543835, 39.02343334690217, 38.44762940560618, 39.621437903373476, 39.59758989272579, 38.18089646677817, 38.25110689286263, 38.90532293627339, 38.50615509094731, 36.54699394779821, 37.88921725365424, 38.084351247356786, 39.896046961507494, 37.3805917462995, 38.03231708465084, 38.22313254879367, 37.192659224233324, 36.8845570471979, 38.85222973362092, 41.17196652197069, 43.70327595741519, 46.960161116815385, 47.03197579230032, 47.33853647785802, 50.45831518788492, 49.76485583090013, 50.111052067049094, 51.919147045381614, 53.355507235373224, 54.62475484417331, 53.692972275518606, 53.72988962358045, 54.751541537623254, 55.21425177974086, 43.45224818875713, 1.7329063290549864, 0.04279513467824267, 1.0663098144915797, 1.4652057905350964, 2.6358455034994313, 2.649656168876156, 54.373189710801654, 48.60412451528734, 27.135823695890366, 29.13868788749941, 33.45491501592821, 43.03348418205015, 2.097382771392023, 0.2118087860365068, 0.036561848791015726, 0.0037077290941059833, 0.10559179084075075, 0.07141060240927243, 0.02250324480325705, 0.05343739829596974, 0.09832649641940672, 0.07912591985997655, 0.0959446907584225, 0.05349163349056917, 0.061891059796776504, 0.023819477702941627, 0.05383630027814258, 0.07042054868032856, 0.052542975322613795, 0.049575407343405875, 0.025172252996614384, 0.002587716449089649, 0.053684335247042685, 0.017889062761359157, 0.08872734578025919, 0.07166461418232611, 0.023519837733117804, 0.05513374678670399, 0.02359171401739361, 0.007944218776819688, 0.01537793858592669, 0.08657956465838418, 0.13044764377897786, 0.08238049118869728, 0.0517430033294424, 0.02149609965272248, 0.03743871302914716, 0.024127299491796764, 0.11048929134924566, 0.03273219057929612, 0.04151320145014794, 0.333032486059012, 7.957310407392441, 60.58532191861061, 49.47603994800199, 41.05948471253918, 42.00572906001922, 45.40905198743267, 66.35603843196746, 49.1998540970587, 0.049052820465857946, 0.7839558525912224, 3.5543452107137252, 5.180387054720233, 1.9819783058858689, 0.13800369155022407, 38.54838725059263, 66.81516755011775, 63.2376717752026, 63.24028799610754, 58.99139619642689, 55.91835252700314, 56.600672352698545, 54.69525160328035, 53.56611890177573, 53.80230442170174, 53.66393104676278, 52.67070454935874, 47.19603284712761, 46.14960724307645, 47.68701553344727, 50.59541771488805, 50.85565913108088, 51.675967939438365, 57.0118308836414, 52.7582714634557, 54.6646688830468, 55.81693964619791, 58.192907533338, 59.27356758425313, 56.77879894933393, 50.48350857150171, 45.993053682388805, 45.432378322847434, 48.01603571061165, 48.24527471296249, 45.27420090090844, 45.436214400875954, 42.368650282582934, 44.796075744013635, 43.56853077488561, 44.11777634774485, 43.17794899786673, 43.823939831026145, 43.9413442150239, 46.641178284921956, 45.0121904957679, 46.83561801910401, 46.902094348784416, 43.551491998857074, 42.696972277856645, 46.27853162827031, 44.72737543044552, 48.88752752734769, 57.65430727312642, 59.09495853608655, 60.0051288450918, 61.19163797747705, 45.13890658655475, 25.94259946577011, 73.24784678797569, 61.93496634883266, 58.813446106449256, 59.524234494855335, 59.72073739574802, 62.67385067478303, 60.50249715005199, 59.28492284590199, 57.505202293396, 55.45654050765499, 48.58927049944478, 43.407599849085656, 40.945037795651345, 40.4105991701926, 41.21957232875209, 42.335667071803925, 42.7513716297765, 42.32974429284373, 42.17786619740148, 42.62543216828377, 43.00385852013865, 41.2432046090403, 40.91071313427341, 41.481233642947295, 41.78997124395063, 38.87278687569403, 39.58703479459209, 39.46559429168701, 40.00588901581303, 41.22291811050908, 40.92236649605536, 40.181226807255904, 40.65670828665457, 41.48712896531628, 39.45990685493716, 40.512686698667466, 40.15857511951078, 37.86455731238089, 38.7285574020878, 42.0662159304465, 44.843155953191946, 47.84893489653065, 49.4673950441422, 49.07613469708351, 51.07283684515184, 50.22838584838375, 52.064266897016964, 53.04963688696585, 55.049943693222545, 54.93556737899781, 55.50124376050888, 55.05083799362183, 56.22864338659472, 53.806148344470614, 57.187023547387895, 44.551421826885594, 2.817235021821914, 0.8143201458357996, 3.3116769934854204, 3.216216309416679, 1.1997845168075254, 3.3598441894977324, 59.19653223406885, 51.51322880098897, 34.618062511567146, 32.4560736456225, 33.2179214877467, 52.986459270600356, 3.991987094763787, 0.21049967966973784, 0.11339176100708785, 0.043039853804774826, 0.0745603729099516, 0.06139841929618871, 0.04149180844486241, 0.08150601714488961, 0.038645002735598434, 0.1472975331689081, 0.05403184039037555, 0.04316582930304351, 0.09184709329518581, 0.011893179860987492, 0.043487942462126096, 0.04557540182084326, 0.014341864997761385, 0.04068491867773476, 0.11274558116471577, 0.14577363106992938, 0.12239900147241932, 0.23802600019881803, 0.11052618614367901, 0.13748149537751753, 0.1438054899054189, 0.15334506188669514, 0.1602955324755561, 0.1932912151659689, 0.07168594207013808, 0.1392126395817726, 0.2263337824373476, 0.14577003045668527, 0.1451099844228837, 0.1721728370795327, 0.13896324731890233, 0.08677693189031656, 0.24107227222092692, 0.17872238321410072, 0.24420641452795078, 0.5462967472211008, 9.182928512173316, 69.52414466488746, 59.96665823844172, 60.2343011671497, 47.942703077870036, 51.02069285608108, 67.36168707570722, 57.35516771193474, 0.13503349205899623, 2.106474825451451, 4.488171579376344, 12.67067849636078, 1.4960975199937823, 0.4019997659469805, 40.2906060218811, 70.78862267155802, 65.22432481088947, 65.82374926536315, 61.91935139317667, 60.78696312442903, 59.67464562385314, 59.54783931855233, 55.28293248145811, 56.77642591537968, 57.24896561714911, 55.30714135016165, 50.737423204606586, 49.70614579416091, 48.935447123742875, 55.12839501903903, 56.47725497522662, 54.309058958484286, 58.10248513375559, 56.86641293187296, 57.43667456411547, 58.48945048547561, 61.4048501753038, 61.761346555525265, 60.31041083797332, 54.32379922559185, 48.12156315772764, 49.224011974949995, 49.207381125419374, 50.33435652332921, 47.00466825116066, 49.11618209654286, 44.33567185555735, 48.37249678950156, 44.91322909632037, 46.27757064757809, 47.153506509719364, 45.4001638966222, 48.42471530360561, 49.661034614809104, 46.1451514305607, 50.547631479078724, 48.401228151013775, 47.00912798604658, 45.53861179659444, 48.35742704329952, 47.48441334693663, 52.95463315902218, 60.04756889035625, 60.76091074174451, 61.35216097677908, 62.015484763729965, 48.657860986648075, 33.651865067020545, 79.6273857547391, 63.674396314928615, 59.896165401704856, 60.249716081926906, 60.2716342864498, 65.35960735813265, 63.60844558285129, 59.446242086349, 61.08893463688513, 61.095861542609434, 51.15309638361777, 45.543040152518984, 44.521643192537375, 43.83040781944029, 44.698126316070564, 46.21252990538075, 46.24827446476106, 44.42504305993357, 45.79199690972605, 43.44993791272564, 45.965879501835, 42.16751506251674, 42.47376588083083, 42.78952844681279, 44.495226029426824, 42.83079570339572, 41.66140771681263, 42.036617725126206, 43.919645663230654, 43.76594758802845, 42.99269937699841, 42.44235161812075, 42.7096729124746, 43.858209579221665, 42.00314814044584, 42.552938922759026, 42.0959984871649, 38.924432723752915, 41.021339662613414, 44.27653035809917, 46.250831850113414, 48.329127142506266, 51.970420268274125, 50.33395644157164, 52.74568065520256, 54.320222023994695, 54.23218050310689, 56.67759787651801, 56.589403383193485, 56.38672667164957, 59.269150995439105, 58.19599836103378, 55.97544654723137, 55.441364857458304, 56.027723896888, 44.96725190070368, 3.310488025026937, 0.7800757091852927, 4.281760771428385, 8.273340675138659, 8.117371547606684, 3.685294274360903, 67.70737340373378, 56.53106597162063, 38.72150498051798, 41.65439059657436, 42.59624973420174, 63.00775420281195, 5.379919496274764, 0.6181042521230636, 0.24929618012280236, 0.10070171372424211, 0.19609232373054952, 0.15115463265007542, 0.14958041389622997, 0.1775844668548915, 0.2641687506148892, 0.2288775007811285, 0.23237790972475084, 0.12302008427439198, 0.27885054989207175, 0.09727495647366009, 0.1336237523824938, 0.12126969594147899, 0.14914976523047493, 0.15518921938154007], [0.017685082275420427, 0.07385168795383747, 0.03142674994324485, 0.04886948413425877, 0.06848721089021814, 0.07684203555747386, 0.05835351474102467, 0.05073483162108929, 0.08702900546092181, 0.06683102838935391, 0.04995369389953633, 0.033064228407437765, 0.08229211528575228, 0.036991003585318406, 0.040714803767660936, 0.016037278861228018, 0.03544132645812727, 0.029091903556799217, 0.10109191294759513, 0.05531380809242687, 0.049448738535565716, 0.036911927989774176, 0.08568366313533438, 17.15236198517584, 50.55902988679948, 40.017954226463075, 33.940112206243704, 42.198886179154925, 38.50395856365081, 60.32675927685153, 7.726342620388155, 2.7648252921719707, 3.6269438699368513, 2.2050881145461916, 1.1202574809712749, 0.048724230033375567, 2.815105174818347, 56.04173460314351, 66.62815678504207, 61.1584625705596, 59.266848564147956, 53.999368221529075, 57.18726673433858, 53.7308741384937, 52.30342165116341, 52.7578596145876, 48.253947073413485, 50.52936107881608, 45.67729896114719, 45.59933400923207, 47.1880155224954, 47.56507688953031, 49.68969145128804, 52.365991300152196, 51.48335995212678, 50.79647840992097, 52.667394068933305, 56.32391775808027, 57.02570430694088, 58.69003657371768, 59.78120857669462, 56.37777974528652, 42.61751682527604, 44.21869893227854, 45.22599497149068, 44.659894974001, 43.92498400903518, 44.587276212630734, 42.76554707557925, 41.8146429523345, 43.292435138456284, 42.91397740764003, 40.80476991591915, 41.48713288768646, 42.84565364160846, 43.44243049621583, 43.40755670301376, 45.23533805724114, 46.84320388301727, 45.2072891881389, 43.67127333917926, 45.33238926241475, 44.31544419257872, 45.89764987268756, 55.24919617560602, 59.9140396425801, 57.19585672501595, 58.09092983122795, 55.47078263375067, 37.81518643902194, 27.598859494732274, 52.82308078581288, 56.280885434919796, 59.1337154757592, 58.08975312017626, 57.213409331537065, 56.78953447649556, 57.74570634288173, 54.75532270246937, 51.853270838337565, 45.61347023133309, 43.57955263506982, 40.461589982432706, 40.319466821609005, 40.10208122191891, 38.51512947390157, 39.82611894607544, 39.55334555718207, 39.22682392981745, 38.895085550123646, 41.0980063100015, 41.13461379081973, 38.644830488389545, 38.00126367999662, 39.07886428217734, 39.80673851505403, 39.059691736775065, 39.13810383888983, 38.339450436253706, 37.54611576757124, 38.61509107774304, 36.48487537137924, 40.14609805999264, 38.11539680727067, 38.16654843668784, 37.60315879698723, 37.962212562561035, 37.59865199365924, 37.11163482358379, 39.34946860036543, 40.27383788939446, 40.87749065891389, 40.852811105789684, 43.596152105639064, 43.584781154509514, 45.71349459309732, 46.058808295957505, 48.67640203045261, 49.683851042101466, 51.46690560925392, 52.655285712211366, 55.82837727762038, 52.63033159317509, 52.228053308302364, 52.5963403332618, 13.138579995401445, 0.220807499943241, 0.5982702357634422, 1.939365186037556, 3.6459046073498267, 1.594265252351761, 8.561417191259324, 65.09262730998378, 37.13405116911858, 23.826025762865623, 21.78741897306135, 46.77342491765177, 26.029430935459754, 0.07706666019775214, 0.03140532054878291, 0.08504106858444792, 0.05649033911345948, 0.04127352318215755, 0.01805256699181853, 0.09185377358188553, 0.07626352426145347, 0.02206302578410795, 0.01955762332785995, 0.01862761365520137, 0.03202994459218556, 0.04810174912094109, 0.04551381218217073, 0.11297667158707497, 0.026808973033762267, 0.024646157436373255, 0.06332642894478575, 0.04075206245385832, 0.08586434497227592, 0.04574700168544247, 0.04462571326462973, 0.1243525563228515, 0.0950902728964725, 0.048206542288103414, 0.022401812846862504, 0.037976035607918616, 0.014951815584584352, 0.03976879626392357, 0.14468491287721744, 0.10032279897601375, 0.08592770810449317, 0.016345725011741443, 0.028525942696198344, 0.021442193875930483, 0.03220566217937777, 0.013719944287121538, 0.06230442168852014, 0.08955574729630063, 0.01990478373162689, 0.06821436867598565, 29.678627637124833, 60.62808752059937, 40.676402507289765, 42.35325105728642, 46.99579977220105, 45.56020444439304, 67.30930774442612, 7.331253059448735, 0.9599630823058467, 2.473819746125129, 5.278071232380406, 3.122956320162743, 0.5321521900834576, 4.727477835070703, 60.529549737130445, 65.28055983204996, 62.36530134754797, 60.22056502680625, 57.44548812989266, 58.059350828970636, 55.27530347147296, 53.55569324185772, 53.43415860206851, 50.93992340949274, 53.42581179834182, 48.20481938700522, 47.5770361961857, 50.83983628980575, 49.04752885141681, 50.35458810867802, 55.406275333896765, 55.17784041743125, 53.55319469205795, 55.81681413035239, 57.616409332521506, 59.0209787122665, 61.220694895713564, 60.6533162055477, 57.280442637781945, 46.5655275314085, 46.47556797150643, 46.535905791867165, 45.31125160955614, 46.62029166375437, 45.31871195762388, 43.28095828333209, 44.797750596077215, 43.88067299319852, 43.8099761932127, 44.549080171892726, 43.37115710781467, 44.945655330534905, 43.94864374591459, 45.50942936251241, 48.04393945201751, 49.405111728175996, 47.23562917401714, 45.924074880538456, 45.5604790103051, 46.668097511414565, 49.55643284705378, 57.97076017625871, 59.391897647611565, 59.21948986668741, 59.97752320381903, 53.28130775882352, 35.659742047709805, 34.9459255895307, 55.77802581171836, 58.49570274353028, 59.83547064565844, 60.53813972780782, 59.451513751860595, 57.63975527978713, 58.73770121605166, 55.23454612301242, 53.53699138087612, 48.328754517339895, 44.3197823339893, 44.11013949301935, 43.189135597598174, 43.40384221846058, 39.81064127337548, 42.09652800713816, 41.3378200223369, 42.03391521207748, 41.77532119135703, 42.533095652057284, 41.92349264698644, 40.51012931331512, 40.056801380649695, 41.08822391879174, 41.69724641307708, 41.07964961759506, 41.2436713710908, 41.732002535173976, 41.15755965632778, 40.846143076496745, 38.89821560152116, 41.26577000464163, 40.17859489687028, 40.92830104212607, 39.748055934906006, 39.65801008286015, 39.87292851171186, 39.91321517575172, 42.71231658997075, 43.27213687281455, 43.179098252327215, 43.56964472801455, 45.41769296892228, 46.987099955158854, 46.842384107651256, 48.83176711297805, 52.01599428730627, 51.03761003863428, 52.62897445309547, 56.29641017606182, 56.78256050232918, 55.15485925059165, 52.74770067584131, 52.61849780236521, 14.507040035340095, 0.3888421139169124, 2.8970616286800754, 5.901747701629516, 1.904170126203568, 0.9904426564612697, 8.99701895252351, 71.14360501689296, 41.64192922653691, 32.470370684900594, 24.741640321670044, 47.66490121041575, 33.05194247153498, 0.16930389909013627, 0.05823000987631179, 0.01886582103437714, 0.08301245243919474, 0.043921356705287774, 0.021449515761266795, 0.026733074787883993, 0.028908425498934045, 0.022581922033080654, 0.04861618099253505, 0.04599928209978727, 0.028681065924766085, 0.05888323389714765, 0.0600602398926933, 0.07905353987289053, 0.09014730506967153, 0.04273490101519612, 0.052823646955432436, 0.11481436329983896, 0.24237857470589302, 0.1112978588489275, 0.26110087491331563, 0.24306017845388384, 0.23872554572599552, 0.12640630781290033, 0.10838467928190386, 0.1729526226558993, 0.11872632999814327, 0.20302646132486485, 0.21912668771561117, 0.25149627738902647, 0.2409334264455303, 0.16519512440408432, 0.09670456570963706, 0.11744301781178483, 0.26183803535757527, 0.20679392851889136, 0.21572637582017531, 0.15507476584565255, 0.1535072580220238, 0.15926379590265213, 34.01926563632104, 67.27188048824188, 51.49512314027356, 48.8195606970018, 52.39526002637802, 50.23131585890248, 74.9396042669973, 9.608584123273051, 5.4509604842432084, 10.981387207584998, 7.4002446090021445, 3.9550672952205908, 0.3677024079426643, 5.077314521035841, 61.302272350557395, 68.12364670538133, 64.6170203147396, 63.78701932968632, 59.87833822927168, 61.468808343333585, 57.781572495737386, 56.22385025024415, 56.38045087937386, 53.45664162789622, 56.43155936271914, 51.02916125328311, 52.017751509143466, 53.544000656374045, 52.8048849105835, 54.45874837137038, 59.77786279493763, 57.84934320757466, 54.42220757084509, 59.88723024245232, 59.958029024062625, 62.483423525287265, 62.36446196033109, 64.37444133143272, 61.49550399472637, 47.39870171393118, 48.24413330324235, 49.1352173589891, 48.35936469416465, 49.70885615194998, 49.17770839506581, 45.88076799146591, 45.95588922500611, 47.05288987005911, 46.76220693895894, 46.24715658926195, 47.3654596267208, 47.59369057993735, 46.86288633654195, 47.97636093631868, 51.51478205957721, 51.254101337925086, 49.72942898350377, 49.04979990374658, 49.53768784000028, 48.56432422514885, 50.05607612671391, 60.075409873839355, 61.84392421476303, 60.07816730007049, 61.99583761153683, 57.718763582168094, 41.77611743250201, 40.8335954143155, 56.252809109226355, 57.99684001553444, 63.12201284593152, 60.781514952259684, 61.30627709050333, 58.77091584667083, 61.25811822952763, 56.87041374944872, 54.977976045300885, 50.10829071844778, 47.33020536361202, 44.98017218805129, 44.142459823239236, 46.10758689142043, 41.76564078177176, 47.46301681764665, 45.313981579196074, 43.47207969234836, 44.33395777979205, 45.00126277246783, 46.95921190323369, 44.52729532795568, 43.770921153406945, 41.09775920068064, 43.21804346576814, 44.6702382641454, 42.10143096985356, 43.2347684521829, 43.607487755437056, 41.66449462213824, 41.79471338948896, 45.27457744844499, 42.62813075896233, 43.189221889741965, 42.400221440099905, 40.783957819784845, 42.82294704068092, 40.93272939805062, 46.12555919154998, 45.398716542028616, 44.102863496349705, 46.86915820644748, 50.08964377064859, 48.464354776567035, 50.62725559357674, 50.071255699280776, 54.85974404119677, 55.04397776819045, 55.15538877056491, 56.264878242246574, 61.4142442518665, 54.7136632088692, 56.0131013008856, 53.32962743697628, 16.769826950565463, 0.3180085212713288, 3.0719257939246396, 8.718782682572643, 11.094198496110979, 3.2162560234146738, 11.014568498057704, 78.66916641112297, 47.87034711530132, 36.26890574732135, 30.747012630585704, 60.31471367805236, 39.451199193154615, 0.20068111378819714, 0.09713592683716167, 0.15821373450659937, 0.18662998873379924, 0.1487818285222015, 0.09625010703119541, 0.23202250621491866, 0.2090218041332499, 0.12684547537637333, 0.09495492814288986, 0.13339623959074098, 0.11400493778168194, 0.2619541742868962, 0.15777599186666552, 0.10737093811434124, 0.14184666437006768, 0.15040029651455342, 0.09345007865058799], [0.038998253538363406, 0.030302887467006524, 0.0357533885436433, 0.0925729156381661, 0.1252723138238634, 0.009756264738708494, 0.1068765739159238, 0.0030467955953246287, 0.034107900630202026, 0.035873606891161015, 0.07269071234810738, 0.03173929083371355, 0.01727938317813941, 0.0343082556050391, 0.035400620376270626, 0.04376412098926883, 0.043706553312198776, 0.003609949461890445, 0.02069252513108715, 0.028719205612076387, 0.05598747899996177, 0.11330321656479952, 0.06059026931442561, 0.9031766004139378, 36.108261154543975, 43.91049477361864, 32.68843093226033, 43.38426959130072, 33.158187712392504, 57.483005600590865, 31.983741829472205, 0.2393985692892344, 3.125532336773411, 2.377879797450958, 3.4963860627143615, 0.07928818494321839, 0.08837573440565218, 17.978779885076708, 73.39863838688021, 62.446553245667495, 64.72117493229528, 55.90733066681893, 56.4323869828255, 52.2991580347861, 53.83951594752651, 49.9623393243359, 50.697760197424124, 47.6656307712678, 49.96423382912913, 47.10506916046143, 48.095954002872595, 48.074934021119155, 48.91661974691576, 49.27026456402194, 51.55804972494803, 55.318951606750495, 57.62532880229335, 57.065257487758515, 59.86963448985931, 58.28144719523769, 58.44918735565678, 54.919101269014426, 46.10766926119405, 43.419029635767785, 45.77637410932972, 44.7587896931556, 43.19525841743716, 43.388580276120095, 43.142890853266564, 42.40372019429361, 43.49334678342266, 42.30725342227567, 42.50862006218203, 42.018861155356134, 44.357127220399924, 43.50578461923907, 44.991986367010306, 50.14737321484474, 49.97325135815529, 48.53209410944293, 48.47928331744287, 45.72727780188284, 43.166334859786495, 44.43268775939942, 47.24924764325542, 55.355268832175966, 58.807582163041644, 58.31501483917237, 54.671329067599395, 57.86776265790386, 33.090601351953325, 40.89387439912365, 57.80104706364294, 56.44074555366271, 60.448337062712646, 57.073419940087106, 56.724434898745635, 54.03349676439839, 53.090935522510165, 47.81718330998575, 42.56820478746968, 42.233332434008204, 40.74857411846038, 41.43426326013381, 39.93000292008923, 39.23721036603374, 38.748537955745576, 40.5973942049088, 39.65234225796115, 38.59429859345959, 39.87352471197806, 38.72665505255423, 40.005261436585464, 39.64422295170446, 40.150950031895796, 40.60073606429562, 40.04814470967939, 39.08427715301514, 40.482845306396484, 38.488304384293095, 39.18153624380789, 39.42486047744751, 37.64062135450302, 38.57911117615239, 39.47097578356343, 39.28335705111104, 36.2817632767462, 39.41221867838214, 38.04670826081307, 40.13937511751729, 40.0924478807757, 41.86822252888834, 40.72647156253938, 43.17900019307291, 43.1037534436872, 43.50749085026403, 43.68963787632604, 45.771647653272076, 48.20812202269032, 50.321479382053504, 53.98933872099846, 56.25358966089065, 53.328866497162856, 53.97903073218561, 32.10032447691887, 1.4985128420014537, 0.22552093250616906, 2.1959730165620006, 4.016061377140784, 0.9405113131769243, 0.18105876752205435, 23.94557176097747, 57.87837266921998, 30.571759170101537, 26.856872573975597, 26.03210795310236, 45.24579509612053, 9.480957062013688, 0.11044360186544158, 0.03355074020463132, 0.02196537447161973, 0.05714092396139618, 0.03189896845499114, 0.0861341228348113, 0.05162997471709406, 0.022076842179822347, 0.06450455725914048, 0.012596509862510909, 0.05679297448706724, 0.10389083816159157, 0.02114389264475434, 0.03927908604964614, 0.08784522617896719, 0.04496220589405106, 0.048775113593306274, 0.02235600078899053, 0.04028335454002504, 0.0418711751849661, 0.03546906267142585, 0.019027316199255087, 0.0330803775408816, 0.04811460790675014, 0.09495956297483175, 0.0974742619080409, 0.05324327927683631, 0.043217260615840074, 0.04501506596082642, 0.01822942796523773, 0.017605342098601887, 0.014964953992485762, 0.051782460687982465, 0.023070226476017027, 0.07056319425182958, 0.01707341660925698, 0.011507878812300342, 0.02195112715144792, 0.013380494558312481, 0.09465731064518614, 0.05487185579934909, 4.507744206536201, 46.563950738599225, 45.329227832055864, 34.289081558104485, 53.51844641470141, 38.38629922559185, 65.35643023829307, 30.689689151702392, 0.1135433774681822, 1.6363250728576415, 2.7666876825594136, 7.437479669047941, 1.8570770467481308, 0.12616263056594518, 21.660398898586152, 72.65546691033148, 63.88114444671139, 66.12882337262555, 58.15797490458335, 59.870367973081535, 56.45021415525868, 54.974300784449426, 53.06079995247626, 54.52116897029262, 50.6156728344579, 52.31021519630186, 51.23052004844912, 49.706443894294004, 51.76956745886034, 50.942143471010276, 52.95937530456051, 55.22370469185614, 57.74724391198928, 58.987787615868356, 57.756010409324404, 60.700482706869806, 59.974648106482725, 61.84712879119381, 58.02384945654101, 47.813519816244806, 46.377249840767156, 46.525044748860026, 45.368588816735056, 45.399340198886016, 46.729070755743216, 45.567833454378196, 44.43282504235545, 45.1753963962678, 43.75024634022867, 44.889157510572865, 44.27957019498272, 46.25800586515858, 44.428549658867624, 46.953418562489176, 50.665455556684925, 52.50746334752729, 51.62237267340384, 50.93930759737569, 46.751075252409905, 44.57429316736037, 46.582079933535674, 50.8161255621141, 58.01323944522489, 60.3627234889615, 62.10593461990357, 58.437381021438114, 56.59208628439135, 33.35311382047592, 42.88561867129418, 60.16960559352752, 56.54763798559866, 61.53766947407877, 59.49039620737876, 57.76816975685858, 56.49264635578279, 57.158531450456195, 50.4070851110643, 44.547660273890344, 44.9281733266769, 43.65336771934263, 43.19115561823691, 41.525274015242054, 40.95121160630257, 40.53405184899607, 40.82586050033569, 42.131193914721095, 40.57561328334194, 41.56345436649938, 40.48712461225448, 42.42848996193179, 41.20794250119118, 42.4003783349068, 42.112566578772764, 41.88339817908503, 41.589793082206484, 40.762580902345725, 40.99552262213923, 41.5827210487858, 41.543293383813676, 40.39390164036905, 42.08836555480957, 41.59481763839722, 41.911627477215184, 37.84542399068033, 40.10237539968183, 40.927669540528335, 43.708579001888154, 41.86977578747658, 44.515849851792865, 42.70975920461839, 43.68658234996181, 46.878218881545536, 45.286956448708814, 47.310071837517526, 49.97760126667638, 50.290155333857385, 51.786359125568026, 55.70565808203913, 58.637872972796046, 55.31632754110522, 54.11376414760467, 34.83418510806176, 1.588915016862654, 1.2033184497587144, 5.990359437081122, 4.6288655265685055, 2.1220672274789503, 0.4181459269696667, 26.557270173103582, 64.09661985212757, 37.681970980859575, 33.97293852221581, 24.774741203554218, 54.832154089404696, 13.312773435346543, 0.160071543688255, 0.08149485524383285, 0.021143034626279148, 0.021603124050964272, 0.017838003001205863, 0.048301705730057536, 0.08569787406632978, 0.025684101236683708, 0.034075606193753986, 0.060086417117065964, 0.07448130497528661, 0.0673866106738006, 0.044871558540410576, 0.03323482086641654, 0.05334176370994218, 0.03658411130609532, 0.06942976716785662, 0.049342608544975526, 0.10145775823583526, 0.19369512736316652, 0.10934619623566828, 0.13891696028651732, 0.22191497196833934, 0.12768434931433972, 0.18293853278361982, 0.21536259130845148, 0.14888621566276397, 0.19596645548459024, 0.23628308888404603, 0.1163460718347661, 0.13817374774765584, 0.1142700425078792, 0.17594318476415452, 0.08637583889668027, 0.19593654741202632, 0.1992056744113084, 0.13331026920387823, 0.1066414921754791, 0.17428281176234448, 0.33046272072580557, 0.18332831831949373, 3.442011961052495, 54.50728770225279, 52.24109126675514, 43.79697353609147, 58.02739527917678, 44.66392717053814, 68.99646036086544, 38.53420396004954, 1.2720954946933256, 10.274933038219329, 9.71762405287835, 11.051770217957037, 1.2902970083298222, 0.2126726880669594, 21.484810075452252, 75.7811801664291, 66.94556282412621, 69.62938970135104, 59.69733653529998, 61.64122789136825, 58.50567340850831, 57.14139461517335, 55.92873504084926, 57.95286240116243, 52.233548548913774, 54.74151595946282, 53.795146096137266, 53.63255993012459, 53.94552584617369, 51.25312859012235, 54.283085023203206, 55.90936245456819, 60.56266238612514, 62.429581149931884, 61.55563785183815, 63.498313273153, 61.768249927028535, 62.5884057629493, 59.54739216835269, 50.007630932715635, 48.88657439139582, 49.27475960023942, 46.70925886400285, 46.23498939698743, 48.76203521605461, 49.46435128488849, 48.43924768509404, 48.84909614439934, 46.57222301729264, 47.19996306204027, 46.54248752901631, 48.90518603786346, 45.7657366414224, 48.6098825547003, 54.434519890815984, 55.55657663652974, 54.10172639354583, 54.55864329491892, 49.15499002702775, 47.975258750300256, 49.54455198780183, 52.46585092236919, 59.16366669439501, 63.26936844856509, 61.834443846056544, 58.86023998260499, 57.65398956114247, 39.230004972027196, 45.50954703361758, 59.85271338493594, 58.7402311448128, 65.78084245804818, 61.32472399742373, 59.83836143247543, 58.56357935936221, 57.774618133421875, 52.08474559168662, 47.99702398238644, 46.6033431022398, 44.89920662295434, 45.677675508683734, 43.915095713830766, 43.467110049340036, 43.039289289905184, 44.595007204240375, 42.96921222440658, 42.47257348029844, 44.91117769672025, 42.02712166693903, 44.666841491576164, 43.45217758609403, 45.37367613084855, 44.90587072987711, 43.349839025928134, 43.52456492762412, 44.92496090550577, 44.059788027117335, 44.327854571803925, 45.052920387637236, 43.14461277377221, 44.52729532795568, 44.047616912472634, 44.26179401336178, 38.915940792329856, 43.89251855111892, 43.29152514857631, 46.44225920400312, 43.60578544678227, 47.4824050934084, 45.38127376187233, 46.38734994396087, 49.16869871077999, 47.53371361763247, 50.38268404622232, 53.310235238844356, 53.579196083930235, 55.26805885376469, 60.068047585025916, 60.63306893071821, 57.19246779718707, 54.86406257075649, 36.37278579896496, 1.9703103577898395, 0.9400475541910819, 9.439153421309687, 9.346658049091216, 6.285041714868238, 1.289582891810325, 28.96371291529748, 69.5010732835339, 41.83872630519252, 41.2515631798775, 37.71735075981387, 63.10935927975563, 17.104161939313336, 0.4270745897966047, 0.16990046707853196, 0.08440699293127946, 0.18569462602176975, 0.11306419713242401, 0.18878177649551825, 0.15722966392434415, 0.13381502921542815, 0.18246415581914688, 0.1615541383263565, 0.13164214339227448, 0.17769216349528683, 0.15039704830175446, 0.1593718909087681, 0.2654724484009128, 0.11328421758427737, 0.18087463062857428, 0.12335224467660151], [0.12807801125511048, 0.044931642816311894, 0.025920964131552367, 0.037668175514667265, 0.04965387006861068, 0.0547823001210007, 0.04178742645308376, 0.022194304526032462, 0.012351868302381087, 0.05876498056515571, 0.05580155712161815, 0.07153352121672324, 0.04602886075454374, 0.037695593801477266, 0.05464880930019483, 0.009218182775282092, 0.05315109974734726, 0.029114734892162587, 0.0937289729594223, 0.005722363177131141, 0.010633656619897774, 0.05778605043287239, 0.06033471770464413, 0.07234626389559239, 12.68416262442066, 48.8676332658337, 38.67563286135274, 43.103471033034786, 35.26612043380737, 36.954865532536665, 63.082734231025945, 0.88527649641037, 1.7271685143632276, 3.316168352480858, 4.647016784837169, 1.280110122696046, 0.09578900637045022, 0.37741848658169475, 50.024920740435206, 69.12127017974854, 61.49606881603118, 59.87758121182842, 56.211894865958925, 56.672059489834695, 53.65755719523276, 51.88559116855745, 49.22345107601535, 50.6742024421692, 47.42813517970424, 47.994835299830285, 49.28771518891858, 48.970336606425626, 51.728190375912575, 53.77324358109505, 54.26333981175577, 55.07174422664028, 59.088714122772224, 58.04905852963848, 58.14224620019236, 58.31038644236904, 58.072471157197036, 52.987051548496375, 45.24501454445624, 44.94371375729961, 45.30499935150147, 42.39691488204464, 42.68184369610202, 43.221636356845984, 42.79699663962088, 44.12357753322971, 43.93011839159074, 44.33290658458587, 44.63377198865337, 43.02947159736387, 42.4264189504808, 45.557548999786384, 52.44943972556822, 55.72348917684248, 53.99896421740132, 54.327619614139685, 53.081431619582645, 50.06848650593912, 48.35976477592222, 46.688427156017674, 45.958340706363806, 51.910678648179584, 56.01235605055287, 57.52136245850594, 57.56217079777872, 59.596814032523866, 51.341640795430834, 45.93851312514275, 57.48073062589092, 55.42301600979221, 57.06743440320415, 56.635510844569055, 54.91414731548679, 54.1654178404039, 48.9253274086983, 43.13457542850126, 41.28720575763334, 40.0065871977037, 42.736533303414625, 40.49743260106733, 39.53368663787842, 39.71722218298143, 40.58739608333957, 39.538377792604514, 39.97993077001264, 38.72861231527021, 40.18964421364569, 38.89138283268098, 40.451054496149865, 39.35974521021689, 40.700399568003995, 40.32309109164823, 39.0783465293146, 40.447022299612726, 37.641052815221975, 39.35355571008498, 37.52514285425986, 39.580402066630704, 40.581092834472656, 37.72337552039854, 37.55387813814225, 39.042080294701364, 42.26840234571888, 39.09741317072223, 38.72654914855957, 38.960565597780295, 40.13448784428258, 42.20154946850192, 41.82894391398276, 45.020101916405466, 45.43891299155451, 46.15116442403486, 47.56532399885116, 48.04295493710426, 49.28809173645512, 52.825030203788515, 52.48028132223314, 56.68429336240215, 51.73969468762798, 51.030467402550485, 13.031703252946178, 0.06510297918031294, 1.1868805318109452, 3.517745329487709, 3.869161750039747, 0.6461248066156142, 0.06172400666400791, 37.582417303516024, 46.23864112361785, 26.150518425049324, 27.88221347716547, 33.91367543128229, 35.86246190532562, 1.2220862555888392, 0.07849251070330221, 0.07747498506139364, 0.09215393449149786, 0.013402397969677566, 0.024937224882324378, 0.06987705526332702, 0.01990517252124846, 0.028302430798630082, 0.04293452437606551, 0.024219787371675336, 0.025261029180499817, 0.03674698159879735, 0.02176868905793996, 0.039624691294926795, 0.051754207365335, 0.050274462574311805, 0.07689162442881255, 0.06626447572583152, 0.052056528642893805, 0.04537116661066971, 0.05982674395425185, 0.04466630060285811, 0.017736561468712265, 0.048540640892761375, 0.04905867337759945, 0.013500519468629313, 0.0422919221642998, 0.0560941337607801, 0.03415226861233673, 0.049818908390138424, 0.061019236417186845, 0.04089804050782996, 0.054254408084577134, 0.021814623689879815, 0.08311388248036947, 0.09886187696529013, 0.06068405762855565, 0.041666545439511544, 0.07449714767356073, 0.04513256852665255, 0.016359460968223792, 0.025182058922045177, 20.983980278814993, 56.62030773778116, 39.717822305617794, 53.18746113008069, 39.524543593006754, 43.94280725909818, 64.40108599201326, 0.9891852916729067, 0.8646613155161181, 1.256344849544187, 4.211296371875271, 2.9826877049861418, 0.38288844629160823, 0.8996563344713181, 55.573772307365175, 67.8064916979882, 65.89263393032935, 62.99668527418568, 58.820545596461145, 57.05686361558976, 56.42454224248087, 52.61281428798553, 51.93487967214277, 52.51212312329201, 51.61452401068903, 50.02352045428369, 50.28932771375103, 51.3980209442877, 55.285972318341656, 54.90925219751174, 54.66190753444549, 57.1182643982672, 60.9902125020181, 60.038916141756125, 61.94761207026821, 62.076728651600504, 60.56352138519288, 55.22537562154955, 46.84869127888834, 48.2747160234759, 45.4354142373608, 44.91130713493594, 46.827126087680945, 46.203339792067005, 43.88117897895075, 45.13975381851197, 44.64282874138125, 44.38694900082004, 44.974108203764885, 44.13683514441214, 46.302407095509196, 47.53303504759266, 54.14719058621315, 55.10077761065576, 56.25531158139629, 54.70235109329224, 52.92301493306314, 51.04299153051069, 48.84198488727693, 47.51922830458611, 48.180869394733065, 56.007158910074544, 57.924860600502264, 59.02106892678046, 58.289660638378514, 60.263373774866906, 48.06939563443584, 45.77354215806531, 57.784773149798, 58.54193179838119, 58.88910078233289, 57.126069914910104, 57.74989935659594, 55.44903701351535, 50.73253985374205, 46.27127132108135, 42.42192391426333, 42.40737584329421, 44.84799223561441, 42.99980671175065, 40.18725549021075, 41.800840131698116, 42.695866169468054, 41.36587673617948, 41.99061224537511, 42.264899669155, 41.07263641972696, 41.330818591579316, 41.47762114001859, 40.663831310887495, 42.32149554837135, 42.44390879907916, 42.23565447715021, 42.765594144021314, 40.69391981247933, 41.08066551146969, 40.15301712097661, 40.68780091501052, 43.28206831409086, 39.944095996118364, 39.67138536514775, 41.176143846204205, 42.13068400659869, 41.79794542251095, 41.45300042244696, 40.538397835147, 41.727244700154955, 43.98103467879757, 44.31001170989006, 47.761748452340406, 47.53730650871031, 48.25450012760778, 48.376466228115945, 51.590381822278424, 50.617657553765085, 55.62184095382691, 53.66659433610978, 58.914619722673976, 53.621734188449004, 55.77526054074688, 15.295497236713288, 0.24228220084501853, 3.5451524007704953, 8.82135364317125, 5.093657076358795, 0.8702578635946397, 0.17090165206501562, 40.23680679259762, 52.31513384849795, 33.09360980987549, 28.969733753511985, 36.06169869822841, 45.93266094884565, 1.5111195848834131, 0.11705476445175948, 0.0838899678520618, 0.024147851715585398, 0.030338416709714842, 0.020008199855745323, 0.06475738925679077, 0.04432753269230166, 0.018367693429031683, 0.04161157480050479, 0.0468843971048632, 0.03392190214306597, 0.04953365172109297, 0.046710154236925226, 0.04967739279832571, 0.03496566246594152, 0.006026206575634499, 0.015055859900800692, 0.07602966826168761, 0.21467286702846328, 0.17554996715437982, 0.1400591054510686, 0.12163944827813296, 0.11798186873596524, 0.1482478805607365, 0.13191148458469298, 0.23776162325614886, 0.20566267712462336, 0.2727939200497443, 0.16165903108494897, 0.14249051530514995, 0.19232632742533762, 0.09119047933528501, 0.12683262042100393, 0.12055976226204827, 0.19534073018979645, 0.1791870615054523, 0.27226970140491763, 0.0730415040086354, 0.15467373413905022, 0.15018868770810867, 0.10704304482186995, 0.1950928854245332, 22.93219800918333, 66.67977517650974, 48.211624699254195, 58.59434643099385, 47.390280385171216, 47.42143577144992, 77.63128372930711, 1.7424257988891296, 4.93383078805862, 12.760991069578356, 11.372989781441229, 3.7063380354835145, 0.3395790750941923, 1.3296061441782983, 54.13018711151616, 74.47318738506686, 67.57991990735455, 66.3259538527458, 62.43144427576373, 61.56927201055712, 60.75033995413012, 54.975497107351984, 54.45335119001327, 58.12065355239376, 53.54289454798545, 53.6724151334455, 52.91684896715226, 54.64620628664571, 57.23266816908314, 58.40087552224436, 57.287142046036266, 59.03065912185177, 63.907318422871256, 61.839578228612105, 62.2456023769994, 62.920959995638945, 64.85702230084327, 58.44667311637633, 49.513294619898645, 49.088199907733554, 48.610655261624245, 46.63646751834501, 48.50629668081961, 48.68691790488459, 46.27139683692686, 47.5962636547704, 47.05829097378639, 47.4035732976852, 46.74241465906943, 47.140758806659335, 47.20432866004206, 49.903444936198575, 58.4389695813579, 59.819024147525916, 59.35637274096089, 59.277262456955455, 56.76043441218715, 54.7837834204397, 52.720165637231645, 51.27390538492511, 50.19110371989589, 57.16342264606107, 58.866755039461204, 62.42578037323491, 60.86738348007203, 60.89910368765555, 52.30861486927156, 47.80208610719251, 58.84838265757407, 59.509098068360366, 59.64198404742826, 61.06422762716971, 59.22218061262562, 59.0165856576735, 52.59963512420655, 47.88227504299533, 45.349926179455174, 43.711359962340325, 48.252613467554895, 44.00989940089565, 42.58938558640019, 43.431455704473684, 44.536869833546305, 44.07788976546257, 43.64360493998374, 43.714744967799035, 44.37603696700066, 44.30459883905227, 44.298205375671394, 41.84046391517886, 43.58405943839781, 45.711423581646336, 43.51877158687961, 43.609770574877345, 41.78586844475039, 43.549958352119695, 41.62105045010967, 44.300041044912035, 45.2714866207492, 42.36996035422049, 41.45842898276545, 43.661777280992084, 46.22890972322034, 42.93262043306905, 43.88472087921635, 43.949934205701275, 46.241135751047445, 47.43129268769295, 47.35042518185031, 50.33490957752351, 50.313136500696984, 50.12720046504852, 52.36727783756872, 52.87656622548258, 54.82106554892756, 58.032180570787006, 55.90940952301026, 61.11221782622799, 55.21277696855607, 54.90542788659373, 16.463742832983694, 0.2762272503347166, 4.811800458738881, 11.051053404808046, 9.151067099263592, 3.2194159828847457, 0.28597694491186454, 45.06902956193493, 56.48961044126942, 38.345839977264404, 41.25364988080917, 44.9485186607607, 54.84289746130667, 2.9693354666233067, 0.28597118393067394, 0.21809148842528944, 0.18711723597540011, 0.20802253436657692, 0.11265116082804819, 0.12211316640699103, 0.15206385644212847, 0.1145648637846593, 0.2163199867091833, 0.11636077306203305, 0.09493381475969669, 0.11511273156370848, 0.14591547990998915, 0.19449650129723936, 0.12572733174648978, 0.19118119451788165, 0.15275996989540516, 0.19961105749732067], [0.009666192908621123, 0.041347726458503355, 0.03633319069781611, 0.08271947743431216, 0.015781101932178344, 0.03914313608660333, 0.06298744652961051, 0.0729976914402458, 0.03315230553609229, 0.03851896595029581, 0.08852536669902264, 0.064347762043678, 0.04152006559794949, 0.07523933365460365, 0.017276012391272574, 0.02342780376033437, 0.06141546858294357, 0.042600502380199974, 0.018637559391678344, 0.04765940612302192, 0.08170945945406154, 0.01403193359428476, 0.088412927974376, 0.006583441215972867, 0.8329688709589743, 35.721927304421705, 42.53155416057956, 34.087428585175545, 46.827894872234715, 26.930230702123335, 66.37795663649037, 17.163838840300038, 1.1883635554582843, 0.12932714825916675, 7.11658223021415, 4.432234658348945, 0.5686925615995162, 0.15890635459894137, 5.815778663081508, 72.84834554118495, 65.82792266722649, 68.42590455086001, 60.18284751522926, 60.83805984066379, 53.21518444245862, 56.69664490607477, 50.24131790284188, 51.22458942474858, 49.804871851398104, 49.491380337745916, 53.45310365000079, 53.32171209396855, 54.97434000815115, 56.703560044688565, 54.88700451389436, 58.179496949718846, 56.400588327838534, 59.86829696163055, 59.9109370477738, 58.412658322242, 54.601353983725275, 52.73878512843963, 47.45520737863357, 47.39261419542375, 44.642448271474535, 43.36535199995964, 42.2034086719636, 44.77933899048836, 43.94637661595499, 44.61042211901757, 42.37252558431318, 42.249339626681426, 42.03268751021355, 43.35958611580634, 43.5357044589135, 50.56299932541386, 57.84183971343502, 57.511462396191014, 60.56818508332776, 56.53596501196585, 56.77947751937374, 55.68694053157684, 52.13308880406042, 49.23222541809083, 45.50362425465738, 44.55192781263783, 51.13550847576511, 54.76896078355851, 58.416219834358465, 59.974487289305664, 56.52344872874599, 52.373459492960286, 59.16413737881569, 57.48320956383982, 56.051905309000325, 53.88169711635959, 49.61490361921249, 47.26634917720672, 44.27145873346637, 42.65533239610734, 44.69575328211631, 43.30104866335469, 45.34967907013432, 42.59917189998012, 43.238326041929184, 41.45542836958363, 42.60504368812808, 42.840327062914454, 40.77201812498031, 40.9279284169597, 41.03078472998835, 40.05729167692123, 40.03260820142685, 42.60376891782207, 39.22802809746035, 40.37641963651104, 40.40237003757108, 38.836893266247166, 39.557844515769716, 38.95354847754202, 39.34988044923352, 39.781321556337424, 39.26407075697376, 39.59187499938473, 39.260258213166274, 38.7789833930231, 38.55978565831339, 38.864494985149754, 39.83606607683244, 37.74809037485431, 41.00778395129789, 44.006647756022794, 44.88492527315694, 46.29160881042481, 48.67675112139795, 51.13734022263558, 49.95980939557476, 50.711410045623786, 52.490326512244444, 52.53929338147564, 55.75460533941946, 53.96528674710182, 55.310914670267415, 44.81488743136006, 2.481108000201564, 0.2600759105576623, 2.7176009358898288, 4.144763658123632, 3.9114463713861283, 1.385498570819055, 1.7310305780941442, 57.030873990828, 31.110133894028206, 33.84224514807425, 35.55949018847558, 33.09927763477449, 23.990294625682218, 0.03773298272262177, 0.08024272283599262, 0.03684081204776322, 0.04350971468093415, 0.017267022349481142, 0.00923738285388437, 0.04914418794214726, 0.02509595063935605, 0.09115238178281054, 0.03195102795988562, 0.08408374213162931, 0.018328831703852744, 0.02892472018908349, 0.07030243324416299, 0.05292138445281214, 0.0465334675485088, 0.06998281370127393, 0.004097637204047774, 0.03278488593716775, 0.0558448793937362, 0.03733241832965324, 0.026693563803189227, 0.030417143735253525, 0.067669672500943, 0.016093235838437275, 0.02172299382847644, 0.03719968210545279, 0.04543069930326554, 0.04085399045218383, 0.058564008889539595, 0.10181371332897295, 0.09578607991457948, 0.0031649921889296707, 0.08488441892569104, 0.035574606604753964, 0.04705074543674146, 0.026320210853291136, 0.03846067815057693, 0.029694602163808963, 0.06062988755142978, 0.09970275039273886, 0.05399601428859657, 0.05865726094212263, 3.0100371664570225, 47.197291927952925, 45.330188812748084, 38.600743047652706, 55.7415791480772, 28.564041045404252, 73.63933855487456, 14.71758992441239, 0.4641665752616621, 1.4391219063151268, 2.6909229351628214, 7.0157645690825685, 1.0875074060693866, 0.2517614817066539, 8.847743349690592, 76.79308891296387, 65.62286115461781, 68.45724428853681, 62.12609952495944, 62.2107481956482, 54.01444581247146, 58.99209045594739, 51.15408089853103, 54.56800207015007, 52.109460446142386, 52.175995611375384, 53.78820350093227, 54.60104019411149, 58.962225529455374, 57.95521582326582, 57.82938618813792, 61.82621471343502, 59.47760928061701, 61.02485879775017, 62.05692460460048, 59.19191560437603, 57.016812293760246, 53.980364338044204, 47.91952579252182, 49.92673204791162, 45.27707207587458, 46.17227069793209, 43.83133349880096, 45.79905717603622, 47.08393150760282, 45.61644731029388, 45.05734089882144, 45.25672674179078, 44.70109947266118, 46.055564495825, 44.77287492444439, 52.50031678907333, 60.186479630008826, 60.547431822746034, 63.12604504246866, 58.38862596019622, 58.330394452618016, 58.848747438000096, 52.09015846252442, 49.19935203367665, 47.94123218905541, 48.74216056639149, 53.331757283979854, 56.728572999277425, 60.88917224637924, 60.64408294616207, 57.491917225622366, 53.13408159440564, 60.55981866775021, 58.98961151799848, 57.20312487694525, 56.705450627111624, 52.15261436277821, 51.88366528480284, 46.71466781247047, 44.714741476120494, 44.566197395324714, 46.52750407495807, 45.35642554683071, 45.135968731295684, 44.230779832409276, 43.044407982980054, 42.732681535905414, 44.22379801350255, 42.300863881264966, 41.257615397053385, 41.63812452746976, 42.24211462082402, 41.96894899491341, 45.08158114648635, 43.52884031111195, 43.22934773660476, 42.7225108300486, 40.73974094083233, 40.602505053243334, 41.667291272071104, 41.48224169208158, 41.28315394924533, 41.811057905997004, 41.62711443439607, 39.42088319409279, 41.84873619387227, 39.96697125896331, 40.97230219071911, 42.487741285754794, 41.250868920357, 43.02462747020107, 46.61760484018634, 47.72644319841939, 48.77992514641055, 49.72123122984364, 51.73313648469987, 52.730897242023104, 53.999352532048384, 53.67444692119476, 54.26058238552463, 58.384252517454094, 56.43310085419686, 53.132242002794825, 46.82595722136959, 2.387378061971357, 0.662407668367509, 6.692538713255237, 12.356741793694036, 5.306890356925226, 1.752008762090437, 1.7747632894785175, 60.613111911281464, 35.9108208071801, 38.616397227010424, 34.35673067646642, 37.49296372936618, 33.04325834397347, 0.05456362415345446, 0.09043359212697515, 0.0066603516555211, 0.035721473320717775, 0.034480529627011675, 0.03739416884678987, 0.048017632666855097, 0.059812261062043334, 0.08794095652598528, 0.035122936486356685, 0.0781465377358179, 0.021396142415582173, 0.04436278039769781, 0.03696693310273751, 0.054197315382020134, 0.02228496337099181, 0.06107739781239822, 0.03231014125049114, 0.05790045417304482, 0.12003355944949774, 0.1473218028343493, 0.11164683488107498, 0.17709459959258958, 0.21165757560201232, 0.12527215294539928, 0.1351767658225952, 0.17847683671261036, 0.11321779010036301, 0.17787870590484914, 0.3072896641829322, 0.18936170505419855, 0.18224240400858466, 0.17452527859037922, 0.1637923867712098, 0.12017310236490543, 0.14618204786412178, 0.19660658323236052, 0.1596209154494347, 0.11041678112721252, 0.20362836128521353, 0.2552924728802135, 0.24854705338516545, 0.15337762062347707, 2.557752339109298, 52.86792916636313, 54.624582259885734, 44.83165164147654, 59.101406912649836, 36.022153362151116, 77.52698790642523, 21.195188145483694, 2.764251155237998, 1.0579779648011731, 14.326765941035363, 16.466341403222856, 1.1123460603337134, 0.5264466736585863, 8.419384244949587, 77.25472834802444, 70.17024532441171, 71.42745910152313, 67.44598665545064, 66.57684433844783, 57.48105618261523, 64.27391098391625, 54.01811715095274, 56.62851725855182, 54.611155986785896, 54.996262135044226, 58.83985934718963, 58.915494411222404, 61.821570627151004, 60.61620273897725, 58.42713186817785, 63.21131344764464, 62.05706973229686, 62.643213041367076, 63.24691680169875, 64.01234772897536, 59.21341019292032, 55.96731547386416, 52.58912317214474, 54.547621434734715, 48.43037920613443, 48.2682401903214, 45.45462208409464, 47.874673489601385, 48.84921773787468, 49.45753028315883, 47.81692443355438, 47.516666996863584, 47.59378471682149, 47.72219919389295, 46.14152716052148, 55.97286170528781, 62.50866789971629, 62.13462283534389, 66.06260591937651, 59.11598636258034, 59.78649985405707, 61.38301826292469, 56.80910710365542, 54.56966515510313, 50.53210281556653, 50.57655895909956, 55.89078218706193, 60.14805609180082, 63.654035291364124, 62.79492247489191, 59.984595237239716, 54.633815519271366, 64.17747951322987, 61.94388581860451, 60.156281302052165, 59.16258804259762, 54.50265930544946, 51.91086692194785, 49.33719588864235, 47.683501089772875, 49.4498267481404, 48.944503876470755, 48.4634526314274, 46.64297865283105, 48.24359593852874, 45.55921600710961, 45.29665647014495, 46.636545965748454, 44.707826337506695, 44.484812136619325, 44.21962461163921, 43.068561938501176, 44.117909708330714, 47.85628541823357, 45.62238577873477, 44.672615220469815, 44.61501913685953, 42.96839244904057, 43.89000038946829, 42.34453162839336, 44.14422881218695, 43.50080320912023, 43.1806593556558, 43.0368927217299, 43.29996216681696, 44.092202494221354, 43.080278058205884, 42.6433652447116, 45.237177648851954, 41.11600214435209, 44.806179769577525, 49.57174185783633, 51.142372623566665, 50.31870626634168, 53.26971323259416, 55.51037111589986, 55.61614567233671, 57.35734854975055, 56.990736376854684, 57.18109684605753, 61.174430539531095, 57.37630928716352, 54.352079514534246, 49.24175677760955, 3.3967154497100465, 0.8785640340178245, 7.243151722415802, 8.48736676477617, 10.430004923574387, 5.7998332477385, 2.517794909015779, 67.91881269024265, 41.36436662366314, 47.437293914056596, 45.03165721893311, 49.429379432432114, 41.96869796322238, 0.15642632880518514, 0.1457944839832283, 0.12658825369491694, 0.1449633398724179, 0.16582302538858307, 0.14393564824375416, 0.13644281804801958, 0.20528153306053532, 0.17775014102939637, 0.1312900187387582, 0.19743510732246985, 0.15906861202130396, 0.12846730649471283, 0.12734809034173528, 0.20093721698128408, 0.10087658861471761, 0.19940554675075317, 0.12656418321233603, 0.16877603386679005], [0.07370326607938736, 0.019361679104246923, 0.032540285554263866, 0.05175116216583599, 0.05928328501120691, 0.02647551985818052, 0.05512479121886915, 0.02995863628213204, 0.0541365492878662, 0.05281480247034662, 0.009440068651231067, 0.05171607533890394, 0.02883988552756848, 0.03677676326685375, 0.019118436612188816, 0.028809027505978465, 0.017587446284690694, 0.019980187850794005, 0.017811266532648477, 0.011195013292073723, 0.06703899827815833, 0.034755965048867854, 0.04693811135967413, 0.0829717118833815, 0.07423289330495943, 10.109620824936899, 46.72008068330827, 38.45721567830732, 36.020349071871856, 36.171591743346184, 41.25505801170103, 43.228853517963046, 0.0358062026451432, 3.557841023129802, 1.2485005994958263, 2.5099670838925148, 1.2831589074865466, 0.17069082466825364, 0.11896439182061343, 21.693725316755234, 74.67745657890075, 60.562277993848255, 61.28183287958945, 57.85125340184858, 63.65327827392086, 57.180939951250636, 53.59510913971932, 52.43559768123012, 53.11874120466171, 54.755032447076616, 59.55922988153274, 56.809691536811094, 58.8002630203001, 57.50533173161169, 62.84147708646713, 57.18754522262081, 58.33430505567982, 61.75158769853654, 58.044787068520826, 55.60401770376391, 55.363917658405924, 51.37966032951109, 45.007228697499926, 46.123107710192286, 45.412229107272246, 44.59290089145784, 44.44845568749213, 43.48223863109466, 44.60726853339903, 44.72209984256376, 44.3078387168146, 42.31606306568269, 42.82206842976232, 42.93164768526631, 45.04644063211257, 55.081126536092455, 60.23936494704216, 58.17182087129163, 60.0956924500004, 61.05932466445431, 61.135097011443115, 58.971831414007376, 64.63400025521555, 60.432420084553385, 52.53445709905317, 46.69069428597727, 47.68681157019831, 52.03496286945959, 55.60957570229807, 57.755061195742705, 57.24071295030656, 58.39092839148737, 58.61582925242763, 56.65358120395292, 52.15659556850311, 50.28102013372606, 46.88286689019973, 44.20699065731418, 43.60295741788803, 44.26491229764877, 47.72640397471767, 46.7282941264491, 49.42843414122059, 46.786815889420055, 45.48665215892177, 41.42626162498228, 42.02676473125335, 40.30123956741826, 39.70429797326365, 39.576495385939076, 41.40901104096444, 40.87623157808858, 42.82250773522162, 42.30197391202373, 38.847950427762925, 39.75091142039145, 41.04705079909294, 41.40579469742314, 41.228236844462735, 38.168140918977805, 40.177269135752034, 38.72889472592262, 42.18256519686791, 38.182783126831055, 39.59043156716132, 37.96135748586347, 40.64055988865514, 38.67448360689225, 38.449331714260964, 40.29619539937666, 45.45324925453433, 44.41387999442316, 47.58487701416016, 46.68408116986675, 48.59818604684646, 50.373407640764796, 53.016932164469075, 51.50194806437339, 53.10117683103008, 51.34739099010345, 59.02860379988148, 52.473224978293146, 58.224745412026685, 26.192026907397857, 0.29117846741311015, 0.8986871413165524, 7.820251026461202, 21.65801998107664, 3.5663177553684484, 1.703172434241541, 5.467266267345798, 43.57660693507041, 28.781106971925308, 48.8387450095146, 45.79508381505167, 41.26614655217817, 12.74379441815038, 0.5132603086531162, 0.085660113592542, 0.044405708134534864, 0.07782085843744778, 0.015158844142851811, 0.01794276552485122, 0.023727284766913905, 0.08101169125086839, 0.008871779840950285, 0.027769409803553458, 0.06646632457212096, 0.07236750751373268, 0.07317894784313056, 0.06710851309640754, 0.04473016552266575, 0.012983071125833499, 0.06109586053137338, 0.027101524775066686, 0.036107968508956895, 0.04673364632312329, 0.03981642395017609, 0.005060943451920344, 0.025960321898662278, 0.03447366930964974, 0.03310804480626699, 0.021936088845494296, 0.022607109088811184, 0.045444684238323284, 0.036877733655273914, 0.011406945770666485, 0.07000473147678761, 0.054625072065861, 0.022508052004981908, 0.06630779799794959, 0.04528283284256055, 0.043468434033134294, 0.04877252038568259, 0.010908041543687784, 0.07104149358647485, 0.037864286362403826, 0.04914599590964856, 0.03998668699134742, 0.031476290934088255, 0.020488605932182363, 17.13551148291557, 58.30553054809571, 39.10916066938831, 49.73246882038732, 43.065533868728146, 48.84078856437437, 44.80527762443789, 0.12792462513091105, 1.0803420937830404, 1.8582645443177994, 2.3799895423073925, 3.497798606272667, 0.39064900889512033, 0.20828548638570696, 29.32798735557064, 77.8576123329901, 62.80936464186638, 62.884999705899155, 59.18267842262023, 65.5278338924531, 58.73976830513247, 55.273244227132494, 53.88953401196388, 54.42496891944639, 55.57441949844361, 62.51142532594743, 58.778858646269775, 62.33987654409101, 58.644509623127604, 62.931036564611624, 60.92395190269717, 59.76842164993287, 62.958724575658, 59.35423897158716, 58.26380045183244, 56.82961717728646, 52.990762110679384, 47.2035010399357, 47.575859485134, 48.075416472650346, 46.90794652508151, 46.16907788861183, 45.319861212084376, 46.631658692513746, 46.659629114212535, 45.83560582130186, 42.69892561820246, 44.77494593589537, 45.32568985416044, 47.04000096167288, 55.65804050814722, 62.642754124056914, 60.26771191627749, 61.07196254114951, 63.456771450658, 61.65361473637243, 60.59370402366885, 67.44844990391886, 60.58411382859754, 52.06578877664382, 48.75189981152935, 49.235496674814534, 52.53429235950593, 58.43375282902872, 59.899432736058394, 58.30968826047836, 60.7723169942056, 61.109531002659956, 59.38870091592113, 54.37758668776482, 52.11643834267893, 49.88542948999713, 46.52735502489152, 45.327529445771255, 45.50982552189981, 49.577186107635505, 48.59926469864384, 50.805582231090916, 49.192209397592855, 47.67290676793745, 43.04097983144945, 44.349870835581136, 43.80484965539748, 41.36185238438268, 43.3754324913025, 43.44831012910412, 44.0400271261892, 42.87374173441241, 43.88194384113435, 40.26005860297911, 40.87453711417414, 43.160772938882154, 43.16067880199802, 43.399739419260335, 41.1213130335654, 41.97326360210296, 41.09412316353091, 44.46026986645114, 41.2361482651003, 42.12228228968959, 40.13656277810374, 41.55314637768654, 39.74449834515972, 41.2220355772203, 43.273086086396255, 47.550932822688935, 48.019918857082246, 50.141254317375925, 47.747792659267304, 50.72613462325066, 52.28217417193998, 54.72619125919958, 55.48575039832823, 54.62666503844723, 54.21536530217817, 61.56321194864089, 53.7766089747029, 58.46619475272394, 29.77594948584034, 0.450670404299613, 1.4959543534824926, 8.230057320287152, 11.51601508740456, 1.6524863411341946, 1.3640400190507214, 6.31333573210624, 51.986286255621145, 33.17727396565099, 61.04646713502946, 49.048548667661606, 49.6774418892399, 18.020996355241348, 0.44389282443350364, 0.07128568411233925, 0.034777369545472246, 0.0661856146349061, 0.04775931164922734, 0.023826334189863938, 0.06416125027763267, 0.08093026376539662, 0.03532251388195061, 0.052503337933411526, 0.0418794259519106, 0.020188690170705802, 0.046030465708745104, 0.040901495564368465, 0.029812748243491498, 0.013316224569514876, 0.10948617582119281, 0.029602037675137964, 0.03942138688158124, 0.2092180298941751, 0.10768089728850512, 0.0922150070208215, 0.10155584047278089, 0.1557295258727766, 0.16187353570374752, 0.20707437798621195, 0.1419718431368951, 0.12683882573319058, 0.127191080621654, 0.1616363242388733, 0.14744900407329684, 0.10622392063059154, 0.12002063554621513, 0.21285775958770708, 0.1835078586854281, 0.16109272356956236, 0.10954826724745574, 0.08328553214068375, 0.19098457039123584, 0.14984938736644485, 0.0872787960895127, 0.10278369555430067, 0.21011295848556105, 0.1399973281208546, 17.36395424412143, 66.96235056846373, 49.29515984750564, 50.556452889596265, 50.422707911460634, 52.25741224904215, 52.3998531218498, 0.3074784282474749, 7.924546849343085, 3.9104505796586317, 10.294546850265997, 3.8027346951346246, 0.1900131402597312, 0.1229146169498563, 26.820196451679355, 78.98374834368306, 65.25439370063044, 67.84124389771493, 62.124059892469845, 71.009397199077, 60.39222755739766, 60.925312965146965, 56.35845422744752, 58.82226359459662, 59.00882328710249, 66.3180620439591, 61.847740680940696, 64.75190278022521, 61.371051111528956, 66.58126092726185, 60.942932251961004, 61.68991627231721, 64.64806979702365, 61.36669728063769, 62.45882634193667, 58.371187102410104, 55.70510110547466, 49.718567940496634, 48.69714744629399, 51.22204380650675, 48.98632418724799, 49.417910422048266, 46.765317378505586, 46.517627546864176, 47.810381920106956, 48.95626706461753, 45.520125665972316, 47.60818766009423, 46.86082709220148, 50.55336206190048, 59.649695427187034, 64.86359227088191, 62.44136394992952, 64.28791384543142, 65.86728757427585, 65.76698472422939, 63.04498534048758, 68.90120952360093, 65.1771112411253, 55.14243318188576, 50.50661525418682, 50.970866987782145, 55.145398493736025, 58.71189202031782, 62.11506589766472, 59.46597160831575, 62.834048117360766, 62.462544748860026, 61.21219119717998, 56.42962563422419, 54.337119594697036, 51.035848894426906, 48.821706233486054, 48.727251637366514, 47.50959888581307, 51.933126372675744, 50.69342205601354, 53.64939474290418, 50.895918338529526, 51.50718050618326, 45.145860948870265, 46.002573274797015, 45.153670387883345, 43.733282089233406, 45.00231789004418, 46.69014123178298, 47.684462070465095, 46.65165493565221, 45.93190000903222, 42.1957443606469, 42.71301084949125, 46.68827026121078, 44.52720119107155, 46.53682754885766, 42.54185822702224, 42.77018331712292, 43.0667733377026, 46.226536689266084, 43.02799678617909, 44.38219116580102, 42.59699890690465, 45.001133334252145, 42.02408967479583, 44.01267643897764, 45.38078738797096, 49.29485782500237, 47.51690233907392, 53.85764122009278, 50.79598026890909, 53.05266495673887, 54.62166401647753, 56.6208686367158, 55.972696965740575, 55.43937229341077, 56.09394135013704, 63.076583954595755, 54.54617015777096, 58.52128444179412, 31.406349328256425, 0.7818354437908819, 1.6117672357828388, 16.361832791759124, 32.11337224129708, 10.763396582295819, 2.686555621124083, 7.564278129608401, 55.974760132451216, 37.997953199571185, 61.91864928891582, 50.28011014384609, 60.438891995337706, 21.185254743022305, 0.6841166389565314, 0.19458959630179792, 0.16961125356535758, 0.22357339910682172, 0.12401527845330777, 0.08929072683977504, 0.18197560622807474, 0.23917203709002466, 0.14152791050653304, 0.10724254177823182, 0.13140146920998252, 0.22505171897430576, 0.20613699280206235, 0.13793154138951533, 0.101409065687368, 0.14683382014834112, 0.37401527887390507, 0.11203200856764471, 0.11800806128209639], [0.023854675612622694, 0.029307229804896542, 0.05551783262842125, 0.05041736478526747, 0.052939234301447875, 0.06389550203757902, 0.05622495859560948, 0.07593307989619433, 0.06309900808358385, 0.028470966311532165, 0.01569340688987605, 0.03699172753840685, 0.016411133598716512, 0.013368214168886264, 0.02287283817666673, 0.04565125601666589, 0.04068239441802425, 0.031730383146373976, 0.038283516487647454, 0.007461032758827412, 0.06357470654972619, 0.032395717102072896, 0.030757064608136014, 0.06589369683135902, 0.16223211081758623, 0.6217974087884349, 18.793003136111846, 35.841143823439076, 26.155876382704704, 46.195993192734264, 29.147893690293838, 63.287023036710686, 6.6962512366233335, 0.5816389572235846, 0.5791548711638297, 3.2647634850394343, 1.975045884328504, 0.7451458996342075, 0.1354320569624824, 0.04926349464503508, 46.48660159880116, 70.38569327323668, 61.7915056597802, 64.41247263262349, 63.28378315894835, 64.87348056608631, 60.71931792843727, 59.823730991732695, 56.18566989898682, 61.52921284398725, 58.34911984782065, 62.21390962600709, 59.9595626708, 62.091955292609434, 60.17698357182165, 56.41059429414811, 62.2329645003042, 58.895031406033425, 58.57911586761475, 56.227086205636304, 57.12850570678712, 52.2790401981723, 44.5189759808202, 44.78495974694529, 43.80746195393224, 43.312482372407, 44.24363736183413, 45.40075617451822, 46.23933930550852, 43.45638236691875, 46.100432488226126, 45.42319605427404, 43.28997973472842, 44.049895809542754, 43.88763520025438, 51.623984767544655, 60.85360419365668, 57.84194953979985, 59.01878218497, 57.444833094073886, 57.52588495131462, 56.11241963601882, 40.46386495713265, 54.107762921241026, 58.8230598357416, 54.68992110221617, 53.63043792786137, 50.9350557481089, 57.71723778017106, 60.37083102810768, 61.60641293371878, 58.16970671376875, 58.76530685732442, 55.03327754236037, 53.89361719931326, 47.520444239339525, 44.88057144226567, 45.412805695687574, 46.57764765524095, 47.077490975779874, 50.665792880519746, 50.42783444927585, 53.50462790458433, 54.48811515685051, 51.039649671123875, 41.38703007851878, 42.8071948020689, 41.80197761904809, 39.395662353884795, 41.167655837151315, 42.80628481218892, 40.038601583050145, 43.24175419345979, 40.01778556454567, 40.53106300292477, 40.79898441991499, 41.24546781662972, 39.98145657200968, 42.320440430794996, 40.76106294508904, 42.117042003139375, 40.26527143293812, 38.0442528570852, 38.95239922308153, 40.22943665904384, 41.432309919788, 41.82393112490254, 38.47595676299065, 40.24747563946632, 40.33316373825073, 47.04909693810248, 47.16770156737297, 49.86821028494066, 48.47736135605843, 51.21005704326015, 52.78002100606119, 51.684028410142474, 53.79793097895961, 54.54626821702527, 56.41096691931448, 59.409920938553356, 51.06774168629801, 49.621971730263006, 7.633728596471972, 0.33819846208057097, 0.956781427225759, 7.157631795252524, 16.907915953666933, 4.168369952709445, 0.9373857970199279, 14.882594231636295, 37.75365229575865, 27.514891355268418, 39.48489627530498, 36.35140888152584, 34.062784333382886, 1.4670571492564295, 0.18226943159055325, 0.054435660657022274, 0.017788519466956778, 0.04317989084689368, 0.04513678967111534, 0.01609942391364565, 0.017719586875530022, 0.05598453339189292, 0.06834432017058134, 0.027129521458259514, 0.024635374748839006, 0.05754781241017965, 0.03898600762289378, 0.0376988573360347, 0.05815979408761186, 0.02201742056997553, 0.06821472873731006, 0.035412962052730784, 0.04507524216727865, 0.04843325451797536, 0.029219836409714435, 0.023119302068446434, 0.05206884733671623, 0.06593297415923688, 0.07333378187350689, 0.021950874342432907, 0.027141106622894446, 0.061836242375354615, 0.06293712604430414, 0.09942915741234057, 0.046911865187388276, 0.0020443614067194326, 0.023743052771615408, 0.055957118935522535, 0.14294877377969606, 0.024920935937834364, 0.011608864522478994, 0.05557520112263099, 0.02629563475268022, 0.04254536703228951, 0.06780988957372404, 0.08858720531627055, 0.07671566169348455, 0.08275883137098244, 2.064238743435952, 32.30852976922066, 42.644412517547615, 29.260063671296646, 56.02727674668836, 33.82008767897083, 67.10469338201708, 5.2993545032316645, 0.4268633333906051, 0.8318617206908042, 2.1086613016743816, 8.068845454723604, 2.6715729025102433, 0.8295244170773415, 0.12031998440262773, 52.4719423632468, 71.59401078378, 62.77021938754667, 65.0721799942755, 64.85027190177672, 67.29604228850334, 60.56660044577814, 60.818365620028594, 59.99985325721003, 62.32332021959367, 61.12956254712997, 64.27266759257164, 62.51799921835623, 63.623797739705736, 62.304496765136726, 57.394042322712565, 63.70553208935646, 60.685722827911384, 60.57038553299443, 60.099069610718765, 58.96153126993487, 54.05223392671155, 47.47246188502158, 46.80097172337194, 46.468213527433335, 45.11158335593439, 46.28090466222456, 47.074368769122714, 47.97587456241731, 45.34584691447597, 48.9139368457179, 47.83023303554904, 45.686465540239894, 45.88662801250335, 43.595795169953384, 53.143495282819195, 62.64162840381746, 59.64049746913295, 60.79745938701015, 58.51300039599019, 58.93918160469302, 58.462660697198686, 47.0100183640757, 58.83938474039878, 61.36741507437922, 55.71930793023879, 54.95503802453318, 53.19857712714903, 59.697564032769975, 60.490914390933135, 61.97093056094263, 58.693656921386726, 61.39799779461276, 57.22076377561016, 56.02379760434551, 49.16498030385664, 47.182708555652255, 47.97150504204535, 47.924856293586, 48.98900708844585, 51.38395140247961, 52.10395736079062, 55.28057905935473, 55.778472961918006, 50.39878929814985, 42.7000670279226, 44.5415452987917, 43.46035965027348, 41.9880783942438, 43.048538238771506, 43.562666831478, 42.472314603867076, 46.32150119350803, 42.585345545122706, 42.53776327256234, 42.730806642963046, 42.174767524965354, 42.47919444114932, 43.673328661149554, 41.80559796671714, 43.80508891997799, 42.439621648480816, 40.98624229431152, 40.29436757487636, 42.992381665014456, 42.522328745934274, 41.85592589839813, 38.87081000112718, 42.22822943041402, 42.535825621697214, 48.75544171179495, 47.887848731010195, 52.69544293803554, 49.419232260796335, 53.85147917655207, 52.840790287140884, 55.691953320657056, 56.11735790006576, 58.677830157741425, 57.023574459937315, 60.62129789783109, 53.546067745454856, 52.92860038818852, 8.343733491436128, 0.7835965879982518, 2.203994263564387, 6.595817477472368, 8.898870464294188, 0.706797683190915, 0.9729074554577951, 14.972157632150958, 42.036135273595015, 36.080220130182084, 46.04216567931637, 39.574749931212395, 43.95479402234478, 4.2856125389376, 0.25066868792618474, 0.06330069605140917, 0.05101222056715239, 0.05407649182504224, 0.03694886491904336, 0.044179712196872126, 0.026988745141293735, 0.05879441749364619, 0.11033228929004363, 0.0439178173790776, 0.0650078310601173, 0.007466624721869707, 0.019546601237849365, 0.04527567758134777, 0.046969413712260225, 0.010915872877493743, 0.019395737458140622, 0.013191281374724162, 0.037314059032547864, 0.14723267616523852, 0.11054780514490221, 0.13112941606631204, 0.19689807968754924, 0.15002535776265208, 0.14597903456418745, 0.1549524982129374, 0.15880317787729925, 0.12925375703602068, 0.15064244158565998, 0.22264813343363427, 0.23564086205536322, 0.14514877911536925, 0.15267036825178132, 0.21281807623322935, 0.2847619907509896, 0.23127760828262378, 0.19161358986410404, 0.150384760251449, 0.14455613349714588, 0.19339315082517364, 0.13890156191923927, 0.18571956984458432, 0.13808037695144454, 0.21787543630888387, 1.2133942832869868, 36.54665270159322, 54.47977227549399, 35.87983800518897, 59.288511814609656, 39.7371478234568, 75.31409648156936, 8.946716516248642, 3.2969418744887076, 3.998129281305498, 8.183898868099336, 10.364139503048314, 5.272372518816303, 0.5326611789003496, 0.23720286936769563, 53.37064758423836, 73.46931949738534, 67.12618012582102, 68.40951688828008, 68.09132637516146, 69.6359557490195, 65.30019521713257, 65.16362613247287, 64.61158390968077, 64.23347919218003, 63.13224630971109, 66.09742087702598, 66.71023630326795, 63.83355040704051, 64.1549180399987, 60.29914186846826, 67.00379433170443, 65.17223181263094, 62.16434263413953, 63.76170827496437, 61.93102828917965, 56.64466565655124, 50.53838253021241, 48.68084999822801, 47.80962882503387, 47.076651588563, 48.55425550091652, 50.176728233214355, 50.71525396839265, 47.47523107836324, 51.15619897842408, 51.224314858836514, 48.593981266021736, 48.538471883343114, 46.341846527591834, 54.475932275095296, 65.591748914411, 60.81259581350512, 62.00274882778045, 60.543168206368726, 58.756595273171705, 59.06767060679775, 47.32465913218837, 60.282130549030924, 63.288148756950136, 60.25745099590671, 59.30216166280932, 55.83439419346472, 61.52261541735742, 63.018748606404955, 66.71101293256207, 61.60655413904498, 62.13794116050967, 60.502379478946814, 58.998483919328265, 50.68308268823932, 49.30235347440166, 51.19175134166595, 50.871595721091, 51.44240256278746, 55.86751468719975, 55.4783449634429, 57.25752030649493, 58.9713607295867, 55.11208188149237, 44.96333345290154, 46.02677822113038, 44.04977421606741, 43.036312210944395, 44.341276922533595, 46.353896048761186, 44.527401231950336, 49.427328032831994, 44.86028102136428, 44.98398865422895, 46.02171836360809, 44.720001374521566, 44.19299171816918, 47.45900031059019, 45.46256880606375, 46.37490426340411, 45.61741221335627, 42.10230958077216, 41.48696814813922, 44.063620182775686, 44.34928248005529, 45.072285129177956, 41.12894204355056, 45.01792500095983, 44.482372422372144, 49.97743652712915, 49.91964432501024, 53.99873671993133, 51.45168681298533, 55.58215833479359, 56.94049473731749, 56.634349822998054, 60.12190957223216, 59.13958726390716, 58.26695011508081, 61.414911054795795, 54.71197266732493, 53.04412987924392, 8.940318149905051, 0.9786776297034757, 5.094574910979118, 15.584780862254483, 33.26336214619298, 9.704753775750438, 1.3889288061088132, 18.531192771850094, 50.9464463110893, 38.678025507157855, 49.65388805635514, 44.83275382749496, 57.57113341362246, 4.388530629296457, 0.3824075575797789, 0.20440016422540913, 0.09399058432468484, 0.1044968826576106, 0.12936761302332725, 0.1485460419808665, 0.12066361314106373, 0.19198644485685135, 0.11643149063832338, 0.12029966008999657, 0.18229350207313416, 0.16272965428088942, 0.20878828521217072, 0.1819171690412106, 0.19100111789040028, 0.10648293495779076, 0.14697859544427166, 0.09897711957173963, 0.0790606951341033], [0.03623088348596808, 0.03264808944696861, 0.00991406927501122, 0.06196538947762982, 0.050493058102626, 0.023692079196353594, 0.07540879996433374, 0.02948938444587252, 0.043870994085145575, 0.018238563563734777, 0.06183990044519306, 0.11218590797075342, 0.04908836311510494, 0.022585038095712665, 0.00840992937164922, 0.012368658076851599, 0.021304093121040254, 0.011039117272312363, 0.010598286340433744, 0.01555105721983578, 0.03324189568839727, 0.07724502078828312, 0.0064454371796830775, 0.028170832214997183, 0.06863703470556967, 0.07316653721875722, 1.735739751208213, 41.70801331920009, 26.19006964468187, 32.7741817889675, 37.70528162679365, 37.3548335413779, 24.271732530286236, 0.9267146825309723, 1.3034473672028513, 1.6439336129734594, 8.169674392669432, 5.691280672627111, 0.5094675299140715, 0.21021913827186633, 3.7115207122218226, 70.94618428137996, 64.58708086321431, 67.87235613792174, 63.1553961384681, 61.59661093065816, 63.20841089371712, 61.49113055198424, 61.07854035592849, 61.27047369557043, 63.93938772140011, 61.07195469640917, 60.358291210666785, 59.74985707190729, 56.940973266478515, 60.78063241897091, 62.49215472129084, 59.647122352353996, 59.50074341989333, 58.052204270516675, 60.87924080510294, 53.45830863521945, 44.075371603811945, 45.03273194836032, 45.072140001481586, 44.30809759324597, 45.83937914140763, 46.12180548329508, 45.99812922939178, 44.94644372693954, 50.68325135015672, 45.219119056578606, 42.64135699118338, 43.387187834708925, 43.09681477085237, 47.16228085179483, 57.35025298210883, 56.06926964175317, 58.92731251255159, 58.62068514670096, 54.39139735314154, 48.565653908637266, 41.47094134361514, 41.11826535194151, 62.974021819330034, 58.21837548286685, 58.821918426021455, 55.26731752580213, 57.8149950119757, 58.1139462993991, 59.518939295122706, 58.12048096810618, 57.492791914170795, 52.188209872091974, 48.96706927207209, 48.47217206032046, 46.6803196168715, 47.96653147666685, 50.01944118930448, 52.59320243712395, 56.23427591016216, 54.9432905258671, 58.715610427241174, 55.97894530142508, 54.72241793909381, 45.85378992942072, 43.27799297148182, 40.84267177889424, 39.34467938638503, 40.678614724066954, 42.81374908262684, 42.06293682898245, 41.28759014991022, 41.71101393238191, 39.77401810307657, 38.83267671831193, 40.20426288727791, 45.33702158158826, 48.284521948906686, 47.67088282492853, 50.06771379901517, 48.04466509049939, 44.95125647514097, 41.0737503728559, 38.599299615429295, 40.53173765059441, 41.924802718623994, 40.41620423716884, 38.256853165165076, 39.2735864270118, 41.47430673722298, 48.549987962169034, 48.316293147302446, 51.669268531184045, 52.01949696387015, 52.47135793009112, 53.50667930418446, 55.96220462552963, 56.61913887146981, 58.32175739349858, 59.104846831290956, 56.62617952592912, 20.658851092861546, 0.30620040972867324, 0.297116506844759, 1.983097161977522, 6.422533046814704, 4.3311924415249985, 0.29684699711299717, 0.10279055204122298, 24.248355204059234, 38.793927623379616, 37.82292135300175, 33.25797673194639, 47.63626790815785, 16.202634572982788, 0.12724530432493458, 0.04740154858858836, 0.07804521494695256, 0.06357717335284238, 0.06492363033635963, 0.013975587827453931, 0.03254109377702398, 0.03839768274056335, 0.038966001236751195, 0.04051503485008594, 0.048895841389293634, 0.0365958477730953, 0.0666694144808477, 0.058882440996146014, 0.03505558969693319, 0.016139340924940283, 0.0751627784883303, 0.047735865528304736, 0.028701583674598127, 0.07202056161458455, 0.03632022849013729, 0.022599879134025787, 0.017201676964759827, 0.0809955880827, 0.03251334990284616, 0.025723093196809776, 0.04868340520789066, 0.04183925613160095, 0.007103009228294175, 0.04969099851986093, 0.01510523809796019, 0.03530228533030998, 0.046842189490674965, 0.04653487715028948, 0.01611256232154706, 0.0036037230822858553, 0.015510423916331945, 0.028730034264886094, 0.09012118147145357, 0.04037559152610841, 0.13840746585159533, 0.10079255643030328, 0.013962038604903125, 0.07271840642657011, 0.06093829539754699, 0.10994503950519909, 4.662251270586445, 53.0219018074774, 23.502181153143606, 47.85984693035003, 44.22864606303554, 48.46946170253139, 24.089412919936645, 0.8443626208651451, 1.5602488647545538, 2.6036087687938445, 6.053768963583055, 4.294350599088977, 1.4957837303799968, 0.6185647628961072, 5.8071803373675195, 76.10683887235581, 66.6222418508222, 71.03195867230816, 63.25416141940702, 63.29653870674872, 66.37350866871496, 62.191524659433675, 63.50629921882384, 64.84274487341604, 66.07147047596594, 62.96016016314107, 63.512049413496456, 63.52737019138952, 58.727408916719504, 62.454331305719194, 65.16210033047584, 61.32785797119141, 61.843967360834924, 61.284782501959036, 61.466450998860026, 55.95451285762172, 45.78046121904927, 46.209133132811516, 46.8541512181682, 47.2466863355329, 48.67978311354115, 47.68610162119712, 49.57103190883514, 46.82106994813489, 51.210888585736676, 47.121805913986705, 44.88870643800305, 44.84560743454964, 45.424694399679865, 51.52786316410188, 60.32937549775647, 58.55899410863077, 60.33736536579748, 61.02826733742992, 55.10737111491542, 50.919436870082734, 45.383317316732104, 44.10092192311441, 64.34210923410231, 58.16911051350256, 58.67222509076519, 56.27526075609269, 59.640383720397956, 59.274289300364835, 61.708947612393295, 60.45265166990219, 59.71654438203382, 53.7813981886833, 52.8102546353494, 49.85579206097511, 49.22787550956973, 48.24256043280325, 51.41099614481772, 54.2931459026952, 56.21398941163094, 56.474768192537375, 59.184945552579826, 58.759195804595954, 58.757717071040986, 46.68167283458095, 44.48309021611368, 42.81391774454425, 43.70653544702838, 41.44803077943864, 44.7001894827812, 42.95632331602035, 43.97075022420576, 42.43231819521996, 42.08607096825877, 41.05416597858552, 40.73449280954177, 46.909009487398215, 51.37791095241424, 49.58213613879297, 50.91866024078862, 47.91815688533168, 45.63371750616258, 42.620952821546986, 41.761545827311856, 43.17504252156904, 44.25974653613183, 41.22300440265287, 40.1255605297704, 41.42056242112191, 43.788858152204945, 50.64931500342585, 52.207551079411665, 53.72963466951924, 53.46640440725511, 54.72428106492566, 55.61663596860824, 58.43986780412736, 59.45145099393783, 58.139080847463305, 59.510831755976525, 56.39392422091577, 24.153955521122104, 0.3244286138684519, 2.0077054995682935, 5.6922524398373024, 8.135591447353363, 3.9048759110512274, 0.15958066518989303, 0.14904349351361876, 28.948543148656046, 42.2949371799346, 49.17472347136467, 29.60388295112118, 50.1346412012654, 25.671275392655406, 0.19418870249102194, 0.016927266185502374, 0.06227539078662954, 0.03364424506622938, 0.008557334264379837, 0.01786175555729818, 0.07535876676199899, 0.07383593718611425, 0.04136653008660482, 0.011276614104938364, 0.027903113213758317, 0.09026835462258709, 0.08702388799358761, 0.018295326848484336, 0.015984031920050903, 0.06230714130065134, 0.03791086450820008, 0.0618156575928292, 0.05060043681653277, 0.08135139761913208, 0.24519540339467988, 0.07198620257118056, 0.12738697696477175, 0.16940981840654729, 0.1461774360148176, 0.1960393257679478, 0.1888530379942348, 0.1201973490477089, 0.13537976380077102, 0.11448002720792448, 0.21190100770083167, 0.18420021830787583, 0.1436356482126059, 0.17565619290596055, 0.14016464172351745, 0.1558241683749422, 0.24246551036354036, 0.11429811963030409, 0.20883363761728813, 0.12618591197796408, 0.23531728183790562, 0.1826803764748958, 0.11426323198623235, 0.14263029570781416, 0.14030146502679394, 0.22454395589809265, 3.938035873636123, 64.00800174282443, 36.555697687210575, 45.44935826332339, 48.25175054611699, 50.88533186143445, 27.12683950701068, 1.2467567382320281, 4.586369587529091, 4.4014141444237005, 19.771318743305823, 10.942104670309252, 2.8003207810463446, 0.24084281356584644, 4.966471281743819, 76.99439279494747, 66.46027934166693, 75.19343653032857, 66.33519495687177, 66.97829108084402, 68.85896559684508, 66.50642210437407, 65.70884343116515, 68.48776817321777, 69.91548738171979, 66.10965082722326, 63.07910996098673, 65.04659829601165, 60.37700483875891, 64.51705478852796, 66.69661783402967, 64.77119299673265, 64.09798875931772, 63.494991025617054, 66.04253907357493, 59.165019912104455, 48.112518172110285, 49.88537065444454, 50.38313511879214, 50.36631991786342, 51.30611588878017, 50.67034675228981, 50.699093803282715, 50.84217794479863, 54.32695281121039, 49.70633406792918, 47.81739904034523, 48.365660098291215, 47.35390824656333, 53.47102103694793, 62.27769520974929, 61.01673164675313, 62.01385698010845, 64.2531891022959, 57.19513893127442, 50.950651091914025, 43.46030865946124, 45.94407112367692, 68.05461299034857, 60.86270801482662, 61.324614171058904, 61.16735458374024, 62.915966818409586, 61.632590832248816, 61.296282891304266, 62.412448237019206, 63.27165911274572, 55.65489476726901, 53.65634518284952, 52.81267081537555, 50.454832123171904, 51.578504885396654, 54.754695123241795, 57.47750643760928, 60.97105564609651, 58.33221835474814, 62.67187772258636, 59.314399457746944, 59.80535468747539, 50.7232948272459, 46.86318835904522, 44.62860230476626, 45.45745011298887, 45.03464214263424, 47.817446108787294, 46.11208977237825, 46.38487100601197, 45.74503437165291, 43.57711684319281, 42.34988566367857, 42.33381571308259, 49.89327423034176, 53.26911310995779, 50.25936865037488, 55.96462080555578, 52.213971999383745, 49.45716158036263, 45.378932106879454, 42.992617007224794, 45.51670143681188, 45.486236387683505, 44.007251801029334, 42.25172442774619, 43.96661212367397, 45.60251112907164, 52.22231880311043, 52.96810650056409, 56.72286987304688, 55.194479111702215, 55.33162478477725, 58.76549905346286, 60.758977013249556, 61.459300518035896, 59.268797982123594, 58.71578301152876, 55.96162019237396, 24.34835603160243, 0.8174188795589632, 2.6099558991770593, 5.500603472032855, 18.60594138022392, 11.522112411837425, 1.299796621164968, 0.364338209431979, 31.54881177410003, 50.94629333865259, 50.73182206000052, 41.564438881412634, 61.33857780887235, 31.214266938547937, 0.2397154079329583, 0.14679321748835428, 0.16105962857123346, 0.13899375294004718, 0.2066651491388198, 0.10424596587977103, 0.32492519206097054, 0.13092407385908789, 0.12299067415897885, 0.1951780897234717, 0.13100379296848852, 0.20827479179828398, 0.16889482346032897, 0.08737889313769918, 0.11974835257616737, 0.10680685991481428, 0.07846149946412734, 0.16895905227190064, 0.26190434792830103, 0.2032992805564596], [0.03881346547014771, 0.08009231679381863, 0.08764704689383508, 0.06984328610762473, 0.013898791343484436, 0.028630199601813674, 0.046870124886833855, 0.08269225066948323, 0.01931144863427166, 0.054100462716192975, 0.03132889944789631, 0.028758779799024907, 0.010409050174207698, 0.05483715201637918, 0.03671913430274975, 0.041390474164678205, 0.06164089761554234, 0.0645674683994824, 0.09069429950848704, 0.06311136125136288, 0.05119325480453911, 0.026026372084273927, 0.04009112392762496, 0.05536035559470615, 0.025485680633855444, 0.09210878126924077, 0.080477888846109, 11.46070182323456, 48.313190552496145, 24.991342329209854, 46.66726596893803, 31.484047558999833, 39.71001678897489, 0.5778170977869342, 0.47152187735322987, 0.6728711423854674, 5.202726423740387, 2.2451428684496113, 2.345180223065038, 0.5067534336159306, 0.1327389974387423, 16.46689053504698, 77.48319072108116, 57.411265450139204, 68.59754746960056, 61.468180764106016, 68.08062614933138, 63.71673045619842, 67.21853625389838, 63.150320591465125, 63.776640738210375, 60.18625213253883, 58.223282367952415, 55.4835028802195, 65.19641322474327, 60.66340846400107, 60.20050210337485, 57.328805462006606, 63.724567351802705, 62.19560000204272, 62.58697409783641, 53.77984100772489, 44.75005457478185, 43.29914239145095, 45.51623859713155, 45.809102366047526, 46.43398692530971, 45.70367297818584, 46.58198579665154, 45.13982442117507, 47.019949805352, 43.87361664925852, 43.094218161798295, 43.48346241058842, 44.68670829649895, 43.22244828747165, 52.39135726805657, 57.33506948717179, 57.00559823743759, 61.847046421420195, 62.15878855797553, 58.302886870599565, 61.58807193079303, 56.59301980849236, 55.57819674091955, 59.09901034447455, 59.83847125884026, 60.072075859192886, 60.85405918859667, 59.95490681740546, 58.253515997240626, 58.06147675360403, 56.74252094761018, 56.13186282496299, 52.134814646936235, 50.78205977716754, 50.82340155878375, 52.120619589282626, 56.23054573612829, 55.69848798936414, 57.83560314486104, 57.221854194518066, 58.190463896720644, 57.5214683625006, 58.68562782964399, 48.23075017621441, 39.516236012981786, 41.06135960548155, 40.09794312138712, 41.516750704857614, 39.76982116699219, 41.91990760064895, 40.772830055605986, 40.347045006290564, 41.42106056213379, 39.87122620305708, 43.62998254837529, 53.2766636725395, 54.48493019227059, 54.89260173613026, 52.342688498958466, 53.7065750552762, 53.21440389079433, 49.81221452836068, 46.95555233186292, 44.0715237586729, 40.53970006204421, 39.73927767046037, 40.269350697917325, 36.525083588015654, 38.77581019555369, 42.00730585282849, 47.324498315011304, 49.41326241339407, 50.07937892790764, 55.01495615128548, 55.20099416855843, 57.79461045419016, 57.49850680751186, 54.00298464682795, 58.535989407570135, 34.887784296466464, 2.4821560084819794, 0.24358548494356297, 1.251237188135424, 3.691806144291355, 3.7856603726263973, 1.3630232671576163, 0.1455364042832967, 0.46459867949447325, 19.70744686741983, 39.81846247949908, 26.392103087517526, 34.22051068275206, 40.89460788234588, 1.3443356247678881, 0.0890675041403982, 0.02815323900581608, 0.009846611402838702, 0.05302575627161611, 0.03696711696383934, 0.05535018194707171, 0.010415920067668684, 0.0474296372023321, 0.038428023652804476, 0.02084241597913206, 0.06284396209183239, 0.024704447151311947, 0.041347554088720394, 0.025443448121809674, 0.04137971445978169, 0.09459616916794931, 0.04198173316375863, 0.07211450697673906, 0.05454889994354979, 0.01719255860324108, 0.047508444667102835, 0.06817394221622138, 0.008361850651131283, 0.04694522065561145, 0.04178860239804753, 0.028591470026801673, 0.05977065482687566, 0.04072392787483912, 0.026312149693107894, 0.0185812653357824, 0.09820165473126596, 0.03924508323712696, 0.05119252702101104, 0.03387694044278995, 0.08090088429350047, 0.11035193944530142, 0.041542557939406366, 0.03832165617495775, 0.05378243663618642, 0.028774850408456502, 0.012492683881352986, 0.047995419947490583, 0.014996809843597154, 0.041155154936976975, 0.08264672206414324, 0.12397828406744427, 0.2184501248261621, 22.754367551495953, 45.47894862390334, 24.84875240633565, 61.88476393299719, 33.80914818856024, 45.442631398477864, 0.13788883964861595, 0.2203997419846635, 1.1028497569984006, 3.791484602036015, 5.064295684137653, 5.254361485281299, 2.873455824390535, 0.240462634772543, 21.05728349378032, 76.90056970042568, 60.722004752005304, 72.1852453293339, 63.51610514425463, 70.5537276114187, 65.71126353356146, 69.62258831147226, 65.11415719985962, 65.30326251060733, 61.961128557882006, 60.23699191308791, 55.664763450622566, 67.43049329326999, 62.682389674648164, 62.803794876221694, 59.79488195911531, 64.8655613007084, 62.040913489557084, 65.85051551941903, 55.36544738277313, 46.83084057223412, 47.300869957093276, 46.469425539816584, 47.825718387480705, 49.79275957230599, 47.92801772394488, 47.73847703010806, 46.085205847217196, 49.58354426968483, 46.69380472552392, 44.48199195246543, 45.16998744780018, 47.7327189906951, 45.94305915217246, 54.82594105505175, 60.87786797554263, 59.46426145492062, 61.99985019622311, 64.1333959948632, 56.33528870920981, 61.901508531262806, 62.19730623306767, 56.8770190208189, 60.907521094045336, 61.059916942350334, 61.51848516156597, 61.92598019876788, 59.67397882092384, 60.63078611127792, 61.9936175500193, 58.81635650511711, 58.43181125579342, 52.01084813764019, 53.08770741185835, 51.20223191476638, 53.09276726938064, 57.36657396439583, 56.86704835584087, 59.44457507902577, 60.08447839367775, 59.206883368953584, 59.7194077122596, 59.45250611151419, 50.10776119847452, 40.89828314319734, 42.919303986334036, 42.71632132991668, 43.50838907303349, 43.544592549723966, 43.04702028151482, 43.98328219690631, 43.75842840440812, 44.54529508467644, 43.1691393544597, 45.51917253002044, 54.46308651278096, 55.158307013973115, 56.59460444604197, 54.25812305942659, 55.4392114762337, 55.25838628891976, 50.47365949999902, 47.61744053133073, 45.37266023697392, 41.711982757814475, 41.281616380137784, 41.89979368640531, 39.621281008566584, 40.990960905628825, 44.78215917464226, 49.42243683722712, 53.789348833022586, 52.72844183829523, 56.54578662687733, 57.05960535234021, 58.78958240632088, 58.948689429990715, 57.10807408055952, 58.12576047835812, 37.122770432502996, 2.32374741185096, 1.1432141329972976, 4.953438226253756, 9.15095531171368, 10.41883401332363, 0.21359475149262339, 0.2560116149364941, 0.5926095201603828, 21.81057272418853, 48.46552756524856, 36.77316957904447, 33.97047135137743, 51.590252384062744, 3.293618646360213, 0.1352068577562609, 0.08100660442705117, 0.02960164697029658, 0.0681366490560674, 0.08882737388053248, 0.03687702885438358, 0.04244685195566666, 0.02176039232572, 0.01601211383052531, 0.03539998452329347, 0.06164419179361674, 0.10430916813352417, 0.0565050020363302, 0.020707697502427527, 0.029996733834606507, 0.13024942618944954, 0.052042765873334104, 0.046239381716136015, 0.028141692145577366, 0.08267937273147606, 0.14284263995866622, 0.11845874314707135, 0.16169761127281576, 0.11436149042340056, 0.13792967213498009, 0.08684787163210493, 0.23672990200500335, 0.23411240939411426, 0.0854773633182049, 0.138759697757421, 0.24980152236117473, 0.148976169706833, 0.13172529457557586, 0.1001486671908248, 0.14800775796175003, 0.17581613674279184, 0.20020750291164846, 0.1497258480277754, 0.2387055201876548, 0.2188601504049955, 0.09417695819490379, 0.14016133222368457, 0.10937140818925635, 0.12074484910455444, 0.15494822344231993, 0.18632317052012493, 0.2012679218164375, 25.142959587035644, 63.743430029961374, 35.61013190977035, 60.92717216860864, 41.15937571371756, 52.02074427758494, 1.130355255257699, 3.6489439539371, 4.516006679304184, 17.759717472137943, 11.484461580553363, 6.0930220830825075, 2.637964318836889, 0.164775951735435, 21.092969217608054, 79.06869903687509, 60.64165499902541, 73.74638003687706, 66.00104039715183, 72.83369156622118, 69.83955029518374, 72.38296416498, 66.15828037261963, 66.59105116321196, 63.96967234150056, 65.13346702821794, 58.19940297834335, 68.12367808434271, 65.44753513028546, 65.96676672658613, 62.64268744376398, 67.86283262314336, 66.72467062550207, 67.92647700155935, 58.82276958034885, 47.834045579356534, 50.70373788956673, 51.21771350983651, 50.781800900736165, 51.33999339995846, 50.1675538093813, 51.40096664428712, 49.885527549251435, 53.26049174031904, 49.183705699059274, 46.051316568928385, 48.073333694088845, 48.881236045591294, 45.991896583187966, 56.76968728342364, 62.75609101018598, 61.94770620715234, 64.71645632097798, 64.92254157220164, 60.60184686414657, 61.947867024329405, 58.89088546076129, 60.46532092555877, 64.19651085330595, 63.717126615585826, 64.94929605914702, 65.53398809125348, 62.19163056342833, 62.16334242974559, 64.70303397024831, 59.697775840759284, 60.05328770606749, 56.61526356973956, 55.33802609289847, 56.14695610538606, 57.02112690094979, 60.32524131959485, 59.651405580582164, 61.33756975973807, 60.7840919494629, 61.04894215060819, 61.800695773093935, 63.63797710787866, 51.71230869908487, 43.7240449074776, 45.353366098096295, 44.77638544574861, 45.51590911803707, 46.22985109206169, 45.637114278731815, 45.5532814610389, 46.39045253876717, 46.26263818433208, 45.11135193609422, 46.82173675106418, 57.05749119481733, 58.85969085078086, 58.95065453744704, 56.48954768334666, 57.306722517936464, 56.941334124534364, 52.640847467607074, 51.22230268293812, 47.60380245024159, 44.634799649638516, 43.70077740761542, 45.988597869873054, 40.366743149295935, 43.38724667026151, 46.48331465259675, 52.701887392228656, 54.69079971313477, 55.427973885690015, 59.668307073654674, 58.51682078453803, 60.8322782670298, 61.21628222926971, 56.98528428231516, 59.91935445416359, 37.242081088404504, 4.350981779636876, 1.1310691266290605, 5.736911075730478, 11.387412336564834, 10.816204432518253, 7.872887763284869, 0.3445401379177648, 0.5295217505866482, 29.961436410104078, 50.91003102640952, 39.24162695484777, 44.79832718449254, 60.431015876031694, 3.760600594743606, 0.2949378140751393, 0.22402307739661587, 0.09009423049827738, 0.20087128745452051, 0.16915008395669923, 0.14386815589762506, 0.11430378868094376, 0.23226794546409962, 0.13704251167514633, 0.1742825512924502, 0.1451673644084123, 0.18060896665819232, 0.13554719997750175, 0.06492869417753912, 0.18460521834992594, 0.26554158017519985, 0.12498410388586983, 0.12624126183049333, 0.177645156340253, 0.1875081093561265], [0.04981282565201964, 0.03742507666409497, 0.025071523925890366, 0.02444953714016705, 0.02327757391838297, 0.02259005405639689, 0.07973414770657979, 0.048216344383094585, 0.04270910300434597, 0.06519023659488847, 0.02184908040949414, 0.09311545144526229, 0.09570957071358159, 0.058400376339352904, 0.04402404696109795, 0.037000610327888886, 0.02684956611765008, 0.018490736725770177, 0.0660237862217811, 0.05032833770758683, 0.018213319051409924, 0.034949026866665775, 0.023968315180090648, 0.028564522884065108, 0.07057513756256911, 0.043974040571840546, 0.05138915114765687, 0.2830409282638181, 47.778634255932225, 31.911115223361602, 35.78273580920312, 35.47840695227347, 38.05048158091884, 11.19255094758926, 1.2138608001893567, 0.7056627698963689, 1.0954292455027181, 5.489713991841962, 4.086244101485899, 4.529701144464554, 0.466715656220913, 0.08603522088378669, 40.395929505748136, 73.79290719186106, 61.08731469800396, 65.65874299695416, 62.28603416873563, 68.25256716820502, 63.03844282704016, 64.0617617484062, 60.63376319023871, 60.84754413174045, 62.9990190844382, 64.81600607595136, 60.080332448405606, 61.35038022072085, 61.71553719428278, 63.618094613475186, 60.29552152079921, 63.86165811169533, 61.58695797766409, 50.85896568913614, 45.20246075045678, 46.549328142596835, 44.12733516385479, 46.00548759583504, 48.53040356789866, 52.76595538662326, 51.798879331158055, 51.83488668933992, 45.59778859538417, 45.92997020290744, 43.62124743000154, 41.69624620868314, 43.08404353357131, 44.50194897190217, 45.5030123649105, 52.872541873685776, 57.7965324155746, 57.75458658895185, 58.45661240239298, 58.74171772310811, 56.13604799393685, 57.50306852402226, 57.89332866668702, 60.11734001098141, 59.19454751476165, 59.2818751642781, 57.2335232457807, 59.918075761487415, 57.398678564256244, 58.02636761819163, 56.31521009629773, 55.78675308535176, 53.935060962553955, 55.54529589991416, 53.94213691834481, 54.61423112500099, 57.15777835538311, 58.38313856432515, 58.745628326169914, 59.53269504731702, 60.63270807266236, 57.15696642475744, 57.70339965820313, 45.640824840914824, 39.24596901862852, 42.23399923693749, 41.05265978843936, 41.18715001690773, 41.13152296312394, 41.63638299511325, 41.15807740919052, 39.40371890221873, 41.62293711016255, 42.970690957961544, 51.07745739721483, 57.737520356332105, 57.17296969506049, 55.4705237573193, 52.97249563278691, 53.72377072611163, 54.19445906915973, 53.877511947385734, 54.66890112046273, 53.884340793855735, 50.39893442584623, 43.18708812036822, 40.376156837709495, 40.12797670979654, 37.94057676869054, 39.62299508433188, 41.874470864572835, 47.082091915992, 50.359451847691695, 50.52100250797887, 52.08858951445549, 56.51778482621717, 59.3763493722485, 59.223118059096805, 42.71666257612167, 7.012201095781019, 0.024054584341243874, 1.1879580804417211, 3.1611646183075446, 8.965912595871957, 5.734797898800143, 1.0095591855145272, 0.10390648167700538, 0.6066220037398801, 24.94762751363939, 46.312962193642896, 22.546395640219412, 44.24191544132848, 21.20818099667949, 0.2060796587818092, 0.05073096287707168, 0.046845261503251336, 0.05366940802383808, 0.03790811425255191, 0.046830709663129626, 0.02436778598254727, 0.05422955236187386, 0.011984454449115983, 0.07014861044984672, 0.03884164984488199, 0.026166049065068368, 0.048474814787867575, 0.0172308266102787, 0.009059591083637169, 0.039880947705598614, 0.03828224095125352, 0.10378710219576474, 0.018925805718848304, 0.07829571037643379, 0.06148933478060269, 0.045324642091028156, 0.039783470678113164, 0.028753468894489834, 0.019771425060987956, 0.05549513344322482, 0.013808200488828365, 0.060925130176568226, 0.035252413006439325, 0.012572398202704086, 0.09103091854241588, 0.022409906565782525, 0.043767583706686576, 0.03047651746460507, 0.040470122945524996, 0.034453283709984635, 0.014538198010995986, 0.01419425996456055, 0.06318316284206606, 0.02162933766451334, 0.06351383703370249, 0.005598406799347891, 0.044482431840151555, 0.06067094603373159, 0.05308954458263132, 0.05777934333309532, 0.05349794222462562, 0.06625879901431261, 0.6813492229388607, 63.22852480796076, 24.40405761041949, 51.04309351213517, 44.71164280368436, 44.47765381105485, 11.665505440004411, 0.9308265522122384, 0.18896641900702832, 2.0182652555165754, 3.9638717905167615, 7.618232782809966, 6.136607950733555, 1.906029942535585, 0.18012456926366976, 45.63158765915902, 70.3209114074707, 61.88873337161157, 66.6474626910302, 63.828643521954945, 68.00132366918749, 64.96568372172695, 67.15577048640098, 63.37172269821168, 61.4662274237602, 64.03453657704016, 67.35191252923781, 61.57521832373835, 62.594010829925544, 62.54424771954937, 67.44966583867227, 61.98007752818447, 63.75506377989247, 62.84520333813083, 53.47810483747914, 48.008775403422696, 49.04865064928609, 46.68766229383407, 48.39230475887176, 50.739427535764634, 55.81426458974039, 53.63824344450428, 53.03120959189631, 46.99441517553022, 45.92229020211005, 45.51651708541378, 43.99095827533353, 46.54288368840372, 46.9308727787387, 49.73231977032077, 56.5778676925167, 59.72957841811642, 60.76378583908082, 61.46253255105788, 62.51027607148694, 57.57378885822912, 62.2612447892466, 60.03871217850716, 59.94160213778096, 60.473710875357355, 59.095488056059814, 58.89168954664662, 60.950753458084606, 59.2489900127534, 60.51219324911795, 59.48420278487667, 57.58388503905266, 55.93982750369657, 56.51273281343522, 55.83656326417, 57.451697241875436, 57.43923587183799, 58.930164075666866, 59.698470100279785, 59.71652084781278, 62.384960266851614, 59.11024009027789, 59.83323881703039, 47.938906223543235, 40.925531848784416, 43.82463016817647, 43.378005566135535, 44.06189826227004, 43.1244949371584, 43.098266047816125, 42.695250357351, 42.196854391405665, 43.15075912783223, 43.793514005599484, 51.290685284522276, 58.30590709563225, 58.010434950551684, 57.81120992475941, 55.541377452112016, 55.9223258879877, 57.35558348317301, 55.972034085181456, 57.8835972662895, 54.928887582594356, 50.981441697766705, 44.41522144502209, 42.14528699075022, 42.75357207944317, 41.11936753795993, 42.648546695709236, 45.04890388058078, 49.2356300354004, 51.60424347846739, 53.345701309942434, 54.364917432108236, 57.87763526362758, 60.69902750753588, 60.29316417632565, 46.10730055839785, 8.476982289744962, 0.3441918437038699, 3.9497036991580843, 6.862146902468897, 13.287395700331658, 5.120588069961918, 0.6928218492577154, 0.15511106309150496, 1.0331960623302767, 27.74961186993507, 57.34478519808862, 21.61208902635882, 47.84075675472137, 29.90840204300419, 0.13325955418329086, 0.06001101108267904, 0.06499022635961733, 0.05873331432080558, 0.07283724964626374, 0.08365463330260209, 0.03462313306367686, 0.01959687958831989, 0.025045758473777005, 0.050425083121104594, 0.009876756005049234, 0.023796362915046276, 0.08223940077568255, 0.04985580701501139, 0.033796669750083844, 0.08069016414904788, 0.01994980097327742, 0.052903316269117984, 0.02908676885248673, 0.03395074535341513, 0.04787804761661157, 0.24314781891242152, 0.1662661153222284, 0.11153703149888786, 0.10781019760836517, 0.10245162708264205, 0.10676107850045928, 0.16794855165625774, 0.1252628296553608, 0.17016524238692177, 0.18886682757687187, 0.15966545580135239, 0.20903643641260364, 0.09946165486208855, 0.12638422915892256, 0.18433396193769672, 0.11133689102866959, 0.13889391636175497, 0.21259067069378593, 0.23922264485830264, 0.17494339405769305, 0.2115837094043532, 0.07528105480295998, 0.10283097850098726, 0.18017718418230935, 0.10958801954984666, 0.11429749143820618, 0.20213530188606632, 2.7061392799500497, 68.36246413569297, 44.49102517097227, 48.67496252059937, 48.32334556887227, 50.72815072151923, 14.209393916591523, 1.506833292303547, 4.852882383331176, 3.4891524766722037, 14.932844696506379, 13.842617984740967, 9.600820772109493, 1.6539916732618887, 0.32497140248456313, 46.38180763490739, 71.72123678268926, 62.837488036001886, 67.31304184083017, 65.01729426845428, 71.10122772955125, 66.93467432452788, 67.09094939693328, 65.87841926082488, 67.1870788451164, 65.98437816865983, 68.8008439156317, 63.769101942739184, 65.05030885819467, 64.06810029860466, 71.410247741207, 65.31160146959367, 69.12459634965467, 67.00985831599083, 56.858838835070216, 49.975447885451786, 51.70186342731599, 49.76719748589301, 51.52303080404959, 54.648387124461514, 58.361059542625185, 57.6663254153344, 56.575906507430545, 48.381973235837876, 49.484555413646085, 48.564281079076956, 45.51290066011491, 49.63535485729095, 50.716371843891764, 50.37283105234946, 58.53457343193793, 62.72653987330776, 62.25613786328224, 63.17522764205933, 64.05034765120476, 59.45824453907629, 60.953769760747115, 61.036316041023504, 63.96014882672218, 61.96060296027892, 63.52273002747567, 59.680964562200735, 63.448318742936664, 58.705569159600046, 60.924261769940784, 60.227664516818145, 61.18706057148596, 57.766220338882945, 60.50301098054456, 58.36459359815044, 59.07215779827487, 61.35569503230434, 62.46874209373229, 61.484705709641986, 62.61347363072058, 63.54565628113286, 59.97050608358076, 61.811246948857466, 49.75352018110214, 44.159557434820364, 46.731373187034364, 45.14788489187918, 46.21127866929578, 45.042639855415594, 46.46392245446482, 44.49239015579224, 42.34119761374689, 45.15945980625768, 46.34105028644685, 55.25865301009148, 61.06126231531943, 60.91478532360446, 58.57577008585776, 56.603578828996234, 56.56614765044182, 60.63338664270217, 57.92221300063595, 60.36053872877552, 57.003535070726954, 54.43305292437154, 47.01382698551301, 45.06295381053802, 45.38999319076539, 44.24985431855725, 44.86311297262869, 47.46281285439768, 51.30368009690316, 55.53926329458914, 55.534744724150634, 56.171247343863214, 58.89505101788429, 63.13780038587509, 60.015315240429295, 46.366949696694654, 9.009556808779317, 0.5519584434167032, 1.9182687180657543, 10.408772153239097, 16.83839390354772, 16.507049722056237, 3.729234135920002, 0.17812826670706275, 1.8480668721660491, 37.69845670269382, 58.74669128848661, 32.53051827030797, 56.10563001325054, 35.723355047164425, 0.2743059018206212, 0.15976412792599973, 0.1611786173476327, 0.12557285011655864, 0.2148930406979015, 0.13141665307264175, 0.15215469914818966, 0.1257690145904499, 0.1283116833937745, 0.15997086441324604, 0.15399076675455417, 0.06747423581057979, 0.11783681764838197, 0.18471948802471164, 0.1279146353443784, 0.1546730140164014, 0.13608902332282838, 0.24105020888870765, 0.1076764386567858, 0.19051860507217147, 0.12252000506005942], [0.013281017083734756, 0.04998117347338027, 0.09497597257816985, 0.031566848272397634, 0.07533641997724771, 0.03908817693891545, 0.03439388125233593, 0.01936782312939965, 0.006013176377652394, 0.03506850593933656, 0.02656112635327924, 0.03580687680251656, 0.025395906620448636, 0.040989093888070316, 0.05648780336243011, 0.0623620966178996, 0.02506128516078236, 0.08877287438559918, 0.048432239451475685, 0.10706897689810685, 0.01969589453731333, 0.055781378365692594, 0.037147484704731934, 0.028806030186974717, 0.026952039953621647, 0.012735799968903585, 0.03993867626113277, 0.1240049745707262, 10.917876189754857, 40.59389937308527, 24.991407048317697, 62.91303288552069, 33.02891423625331, 18.521545702411284, 0.05365471445745038, 0.41615422094060533, 1.6182241925308782, 2.088204425188803, 5.808465894191496, 4.048476824837347, 1.275411490951815, 0.10692839210312213, 3.867842853069306, 63.022439556737105, 63.92523188744823, 68.47304359559091, 65.27551566400837, 67.93187418291646, 67.18751030583536, 64.2712123932377, 58.37876512158302, 62.82692901549801, 63.402729034423835, 61.42973369167697, 59.55057713293261, 62.890028184460064, 61.59870939870035, 61.51796348633305, 63.726238281496116, 62.85509163333524, 59.97248295814761, 47.99771824190694, 44.31158065795899, 44.76819553682881, 45.25367121542654, 47.25945365044379, 55.19568720171529, 62.14517401110742, 61.194038468022505, 53.48403938354985, 46.7175821335085, 46.037662798358554, 42.850756645202644, 43.498559613381666, 40.83443480153238, 43.47576279794016, 44.58247915390999, 48.846770178887155, 54.04345173989573, 57.825801141800426, 60.60054855961954, 58.60005347959457, 63.27906847000123, 61.4866590499878, 59.38759088516236, 59.456703047598566, 58.38283261945171, 59.025532584036554, 54.19205857861427, 54.03053929728847, 55.81321731690438, 60.91556979763893, 60.89804464770902, 59.71700329934398, 59.102065870838786, 58.197324122152025, 58.276889401097456, 57.584214518147135, 58.067301473309925, 60.50117923367409, 59.542312698979536, 58.32662113251225, 58.0627985923521, 58.41405860839352, 51.80944619640228, 41.82875171784432, 39.324585083992254, 40.555311095330026, 39.53832680179227, 41.41820899901852, 41.94267695949924, 40.64877725416615, 40.75813293457031, 41.44715609089021, 42.5851337371334, 44.8497220008604, 53.546428603510705, 58.43157983595326, 58.20774585969987, 57.31204125189013, 56.09464345439788, 57.478741984213556, 55.02049846033896, 55.60711245382986, 51.9474155672135, 55.48720559766216, 55.34003434642669, 52.15840378115254, 45.74649741572719, 41.49324394041493, 38.83901134614022, 40.46516326165969, 42.31103850949196, 41.59584922175254, 44.61534077121366, 50.988411749562914, 54.011884504748934, 56.77464515932145, 59.564850637989665, 57.27511213671777, 24.164587105474165, 0.41352742802231546, 0.4862318993095429, 2.612741272295675, 5.8280831383120635, 10.62196473921499, 10.696909466097432, 0.034241617446945566, 0.08203447991681677, 6.239066143189707, 45.08441702012093, 35.771968903080115, 35.54146689753379, 43.65761172386908, 2.1561700297940165, 0.02036994082793113, 0.1391965670571212, 0.13322227634489536, 0.09881071761370668, 0.04223875183191511, 0.0373846348825722, 0.041692504328825784, 0.06130323670203648, 0.010621471033852187, 0.011538492643364496, 0.004590561157167559, 0.04914019662406176, 0.011006206135085274, 0.025826536134005557, 0.05604415418460004, 0.03606107626711169, 0.0025504287951926313, 0.04154721575398599, 0.02469184117451791, 0.05581380686752739, 0.03299738723604429, 0.026891340892161095, 0.1255751713629692, 0.07483752053831855, 0.0743374643066237, 0.008661937824780903, 0.02682989872541399, 0.016613955376669765, 0.036601581941208536, 0.031316458180005995, 0.026845046198896827, 0.03236744462722733, 0.024360381742759098, 0.020671936518122113, 0.0199323475751425, 0.038112449054155624, 0.06109456967322096, 0.018305368345951843, 0.06773776239565305, 0.039586459677065575, 0.030868323557379267, 0.04134604489550956, 0.01039873288508745, 0.08371670940710653, 0.02447791495210221, 0.05862447237896343, 0.04000859327554222, 0.14500406510647268, 0.009469509410161165, 21.447698570066883, 45.098137470983694, 21.91768677003922, 60.6907356169916, 34.11641882311913, 24.531332638955888, 0.09936791634367359, 0.24100784422649493, 0.34203018872968616, 2.9537406131144497, 7.12565222094136, 7.256289211011703, 4.247305691242218, 0.8511432344394346, 5.372900905147676, 69.06865550625709, 62.55976461595105, 68.17466889658283, 66.08992914999685, 68.35006160120811, 68.5233989838631, 67.49240398406982, 60.644561475323094, 65.91095924377441, 64.16065254519063, 62.05264922111266, 62.44543537016838, 64.80119912855088, 63.89784197653494, 65.39143739208099, 64.90306308192592, 64.48112980011972, 61.55959160097184, 51.15510071477583, 46.31339365436185, 46.742959868523386, 45.67055248445081, 48.61013358639133, 57.170051451652284, 63.98009800141858, 63.72511256125666, 54.95521845356111, 49.755222489756925, 49.58145756875315, 42.83226266984017, 45.17965609027494, 43.29184678293044, 46.607359609296246, 46.13204679181499, 50.43409455207087, 56.582472555099, 60.78241709739932, 61.99834008370677, 61.357483633102916, 66.04527688795521, 61.57147246022379, 61.35054496026809, 60.11643786584178, 60.523752474015765, 61.2071313396577, 57.60447748245732, 55.2774803869186, 56.561644769484005, 63.79412666443856, 62.37602510759908, 61.59710907167005, 62.46434511676912, 61.02966762358143, 60.63374750075802, 60.308943871528875, 59.65210768484301, 60.220278693783676, 61.14471466310563, 59.91168622047671, 59.62220745701944, 59.08102235486431, 55.03285392638176, 43.31121936921151, 43.05901488950176, 42.28799850709977, 41.418334514864036, 42.85008984227335, 44.19539613108481, 43.17013563648347, 43.751591713197776, 43.881437855382124, 44.383960154748735, 46.518965075092936, 55.59527866301998, 59.5494592574335, 58.617409967607074, 57.65136941786736, 58.230930989788426, 59.22790335070703, 55.755095635691, 56.52100901449881, 54.628524241908906, 60.038935753606985, 56.43054739121468, 53.58499334704492, 47.27551183392925, 43.27072089718234, 42.33534151507963, 42.56574153900147, 43.23244640904088, 43.67081834423927, 49.027866009742986, 53.86703529665547, 58.19172297754596, 58.33212814023418, 60.45634262023434, 58.90138564571258, 26.844811285695723, 0.984013646600708, 1.4954169887688853, 5.444624875822376, 9.688212160141239, 5.654635438995977, 2.9502296015139553, 0.15587146664338727, 0.09600314326704511, 7.989614557835364, 48.77935248036539, 45.69421222133022, 29.077116481719482, 52.46282285259616, 5.048634150335866, 0.33371274149225605, 0.0695104438871626, 0.06786552287878529, 0.07078355178236961, 0.03954477300266585, 0.03366127903122575, 0.0219654415043131, 0.059751353241623416, 0.02135062530156105, 0.02187868779254777, 0.017038580676120137, 0.06424033736449576, 0.0589732492282506, 0.02842168004492358, 0.030748413560251077, 0.030792999877444202, 0.01818695988115524, 0.022043978923090526, 0.03770407439479905, 0.05641881714484865, 0.03452523851827268, 0.1540482539923922, 0.20744167118062898, 0.17943656102063196, 0.1648160028121164, 0.1461915320326244, 0.08253644370744306, 0.164001390878712, 0.13367419161142843, 0.15276350922161533, 0.13944085717441576, 0.17100231601826607, 0.15961716161860576, 0.17869265900263864, 0.16533199367263626, 0.14413070955103444, 0.29781652734644953, 0.09653015047191613, 0.19873854463859913, 0.11675733847603684, 0.23176502406356797, 0.08314041976606654, 0.1414940953855553, 0.19351811508738226, 0.11194400804778261, 0.14872650165231, 0.06718251718989304, 0.23601523390220058, 0.15369435201489157, 27.641952614630423, 61.1903985085026, 35.707206649165, 72.64219360966837, 44.36311667965305, 27.261292472962413, 0.21883428727667179, 2.101304651268067, 7.403719338678545, 7.814382670387146, 14.66218448454334, 11.693599416363625, 5.06866422391707, 0.4690458811819554, 5.8816700693099735, 69.28042427186044, 63.851769816490915, 69.04971830306515, 69.16927214591735, 71.18106365203857, 71.21944796654486, 67.22715762353712, 66.04389621365455, 66.42760599813154, 66.69358976425664, 63.65408628217636, 65.23218524071478, 68.77451696703511, 67.37459167357414, 67.31667395560973, 67.620971433578, 68.42118201717254, 62.95941099043816, 52.31904052918958, 49.25552429691438, 50.048831509005645, 48.92199731642201, 52.12317697463497, 60.75520761551396, 67.840835971217, 66.3157243113364, 57.06565756951609, 52.03170730221657, 51.866038153248454, 46.7456780710528, 48.19178535092262, 44.42910663543209, 48.699512635507894, 49.31151220875402, 52.71083039622153, 60.05381330367058, 62.60328723538307, 63.487091372090006, 63.092787265777595, 67.96540260314941, 64.27085545755202, 62.50960926855765, 62.40154797031034, 61.55420618672525, 62.02099961619224, 55.578439927870235, 53.609037476201216, 55.28230097986037, 67.64219145621023, 66.27817153930664, 65.05973431371874, 65.62157853957146, 62.51750107734435, 62.062160968780525, 61.96378008011849, 61.87482856935071, 64.93450087885704, 62.3257246325093, 62.163993543194195, 62.75821693481938, 63.64532370721141, 57.27066416894236, 46.26253228033743, 44.81029433588828, 44.19636495651738, 43.409109961602, 45.29700556109029, 47.7395478371651, 45.28240649930893, 45.8321149118485, 46.628305066016416, 46.69009416334091, 49.71945439615558, 59.229248723676136, 63.1128344997283, 60.299032042103434, 59.77941605352587, 61.390580592616914, 63.415974878495746, 58.59413462300455, 59.335952881843816, 57.220555889991026, 61.7392675338253, 59.18214498027679, 55.26663503339214, 50.15404124413767, 46.216742530945815, 42.81737335266606, 47.04652386326944, 46.701206238039084, 45.68435138271701, 50.99284402785763, 56.321732997894294, 58.57386773632419, 61.13776814553046, 61.74852432743196, 59.07003579601165, 25.22313871691304, 1.0429020898957406, 2.3637288664617846, 11.164467757748021, 15.63020779240516, 19.219147082298033, 20.75270752752981, 0.7367280642351797, 0.29277640424909135, 11.848073140267404, 59.02554435114707, 45.572226508971184, 47.24993798040575, 59.25854098412299, 6.7659267494755415, 0.5032058642996896, 0.22934078479245787, 0.3196432916147094, 0.1842614900200598, 0.1622843426922637, 0.2852691716003803, 0.2046163235941241, 0.1702716979648798, 0.06710593904098196, 0.07710488798517375, 0.07333883039292789, 0.15331254911518868, 0.14022746093330846, 0.12095113359992543, 0.13886302769664796, 0.1881245649870365, 0.11734791565686466, 0.14261264504203874, 0.06646960342843687, 0.179810228066579, 0.1024979370976648], [0.06618123261197921, 0.05096208011250823, 0.02225965948685283, 0.027617540533444094, 0.09353690705592595, 0.029602713747731144, 0.0792996073141694, 0.04977286650588916, 0.049024015559905, 0.016365857802391533, 0.01385502090993067, 0.011634908639074815, 0.013191201893102019, 0.05927505722690014, 0.0442377854919722, 0.03605037018836987, 0.024365104674812288, 0.04966397859877156, 0.011425009166311112, 0.05806828105461694, 0.09487678717461326, 0.10584355031530704, 0.017786485503517815, 0.030126196948150476, 0.11585864073206341, 0.10078324080114404, 0.027825991142421003, 0.1253008429381636, 0.47113625933566405, 48.198810315901234, 39.99993878026163, 54.991472921063824, 50.27147700709682, 24.59344337063451, 1.0352174312837663, 0.9569494149857952, 0.43141809382265617, 1.2440320392770152, 3.086604773998261, 6.1376836607533125, 4.298996646558085, 2.44759036648658, 0.029287072116388913, 18.511100430642408, 73.64792070081158, 62.31103535621398, 68.85662786422238, 65.07418432543355, 65.70168902797084, 58.315348240637014, 66.26317239576771, 62.686751350279785, 66.48072273500505, 65.38905259101622, 60.473706952987186, 61.44184204839892, 63.13811809785905, 62.74851691338324, 63.78303420159125, 62.24054251947711, 58.516091223685976, 45.87449612156038, 45.96240428186233, 46.544837028749534, 46.260731912428334, 53.082898586027085, 61.11099404673423, 60.226970257297644, 61.34266884096208, 58.019542694091804, 52.015025461873705, 43.980920930062574, 43.9232660108997, 42.914495160502774, 43.343151384784335, 43.47797109234718, 43.79183915353591, 44.780119542152654, 48.187341305517386, 51.53020089672458, 54.761680864518695, 57.292119533784934, 56.36842097005537, 58.34702530214864, 60.348877522253225, 59.98190056893134, 58.525147976413855, 59.30374237798876, 60.47007876057779, 56.977878847429835, 52.059685568655695, 57.34481265467983, 60.992028559407885, 57.75212334048364, 59.32628816173923, 59.801071459247225, 59.789771110780784, 59.734591207196644, 58.61679415549002, 58.2665971017653, 57.5981467769992, 57.08216682557137, 56.45611339999784, 52.81391812909035, 43.00648258578393, 41.25815668413716, 41.537076427090554, 39.81061773915445, 41.360518778524096, 41.6278479176183, 41.6895781793902, 40.73417117518764, 42.092793910734116, 42.43200440560618, 42.77137571765531, 46.84629078834288, 52.60507152926538, 55.68433215541225, 56.15762887462493, 57.311229321264456, 52.61916460529451, 55.208776150980306, 56.187485956376605, 54.537509564430486, 54.02833492525163, 53.97570063990932, 55.464859854790475, 57.425546799936605, 52.89756659538516, 46.241527988064675, 42.4717576273026, 41.48418326531687, 40.65857533485659, 44.679942207951704, 45.991520035651426, 51.21573271289949, 56.65876657732072, 56.69873552937662, 60.677933000749164, 45.88678490731024, 3.9292080892670542, 0.376554676481793, 0.9820615319955734, 7.995690309232282, 6.603170940952917, 8.909808974112234, 1.1036060389972504, 0.10457236530078996, 0.11741789778874767, 20.600894151195405, 47.4018866785111, 26.631091140931655, 44.233027350518014, 28.687840853967977, 0.05131713122189526, 0.01599470160961632, 0.05795701827493407, 0.052425480417666905, 0.08195931903056561, 0.00752372652172081, 0.02989567917651467, 0.03983356899792149, 0.021965131238703767, 0.042337492904475624, 0.0294132104083415, 0.03312201441956624, 0.009794609354538544, 0.04965300055881662, 0.01466247566690248, 0.06404746323823929, 0.049118719349104556, 0.048700783912452965, 0.0504341765847658, 0.03592226496567169, 0.03978494156692778, 0.01892844680696726, 0.03851186048479811, 0.010600706220664566, 0.024038140263949192, 0.0377427771567337, 0.034865718635339896, 0.044369173401425925, 0.0081206162670447, 0.03703645175142634, 0.0627227976257282, 0.027759082938334154, 0.027559580236312844, 0.010751909951889708, 0.0075506827617514765, 0.013183661672707288, 0.03731561419103415, 0.07159959630019243, 0.024832571526208234, 0.0481893589359618, 0.020983104195986545, 0.018409336053375757, 0.09241452695982111, 0.05116846802974901, 0.0377297115271851, 0.02664342526376488, 0.0918061612173915, 0.015059518928249038, 0.03423294533164271, 0.10976009055851929, 3.2567907773679305, 59.12434101104737, 32.47692692664362, 67.72478872729887, 57.94173463698357, 26.459432532710416, 1.6938640369522957, 0.6744879556279029, 0.796770052083077, 1.4052328731744521, 4.002016350146263, 5.274297912274638, 8.4023876344004, 4.235358151697343, 0.578086699449247, 22.340724199048935, 71.63145372944494, 63.272137641906745, 72.33794320014216, 64.02609563642933, 67.42447637742566, 60.208087967288115, 66.13160041070753, 63.74104915126678, 67.44361754386657, 65.51160312468006, 63.066154372307565, 64.4669621990573, 65.91528169570431, 66.7354336092549, 64.87313147514098, 63.868310451507575, 61.07027199960525, 48.7480951124622, 48.397003758338194, 48.937412231199204, 48.30384746674569, 55.41881515133766, 63.37337401605422, 63.53923536116078, 64.28801974942608, 60.733909145478286, 53.03845420960457, 45.59501547967234, 45.3822268978242, 45.611799301639685, 44.94980912054739, 45.54848047994798, 45.79693909614317, 47.15178458921371, 51.703142119992165, 54.65629462272891, 57.121896513046764, 61.69098707937426, 60.16104698181153, 60.19102173466837, 61.14249067921793, 60.02676463896229, 60.57590823019705, 59.91771882580173, 58.764298808190134, 57.36071002098822, 54.38633357324908, 59.23197084857572, 61.660263153814505, 61.4875376609064, 60.09484129567301, 61.486721807910556, 63.14976361490066, 60.18621683120728, 59.730092248609, 60.25683518378966, 58.87190118912728, 59.07089871744956, 58.142132451457364, 55.14503371331, 46.7455368657266, 42.60548691595755, 44.49264903222361, 42.62644021741806, 43.4214654276448, 44.071292338832734, 44.8609007558515, 44.117999922844675, 43.450141875974595, 44.30081375183598, 43.343955470669655, 47.21845311503257, 54.05922359035861, 56.73651579887637, 57.849209846988806, 59.823075955913914, 56.38557741718908, 57.381988879173036, 57.40102414161929, 56.86913505677254, 56.681508479579804, 55.7778924511325, 57.64229697565879, 59.027917385101325, 53.86157143500544, 47.34121545668572, 44.73518094708843, 44.00599272020402, 43.57324938620291, 47.094047300277225, 47.678739332383685, 53.825203218767726, 58.601983285719356, 59.97942947572278, 60.933393047701934, 47.283136921544234, 5.5954154941343495, 1.0705381295373364, 2.457266853701684, 12.272919762519098, 10.121957659721375, 4.976358596355685, 0.27665451289184634, 0.09958475753064118, 0.3912101529778973, 21.793885000290413, 60.72360507903561, 29.984280293987645, 42.08947950793851, 36.962926003240774, 0.05491545386311989, 0.031768484529288064, 0.04342400476396565, 0.07851456637464224, 0.03073563521367408, 0.015176356912800863, 0.04790481089824631, 0.07301433853084043, 0.030746180413951798, 0.038422339280406316, 0.035888691162390095, 0.03585978666500699, 0.012887558156263926, 0.05778509665340666, 0.059860038135441086, 0.020787012500448093, 0.13476634187804115, 0.03529875749541867, 0.05227713515200923, 0.04374909800507369, 0.018072129046965032, 0.03233154191665592, 0.15788710525920316, 0.107603024451002, 0.10336775332689287, 0.21404481282637966, 0.2485686264211132, 0.1710489248075793, 0.111272570286547, 0.15486070555785011, 0.1131587093996425, 0.12738486256210074, 0.14609252282929036, 0.11941252261280053, 0.11603530826828173, 0.16329749397212462, 0.12513185160294657, 0.15012044459581375, 0.15761799389316192, 0.25009113424006973, 0.09847301073492536, 0.1446462867240752, 0.18902461104575666, 0.22389786798627148, 0.15510957688093185, 0.11120876282333367, 0.22526639213244762, 0.1352058158766839, 0.12641115714946102, 0.41618112594850604, 4.983237453045384, 68.68040361712056, 52.590550914887466, 65.80771461609872, 59.684384868990996, 41.29287358253233, 2.217122191382993, 1.9830049862784727, 2.7473079869824075, 7.451135400802859, 9.122651488550249, 15.614025073666728, 13.0786540239088, 5.722602759638141, 0.36778045698038997, 22.636561124555527, 74.1996334445092, 64.93290839656707, 73.05015148655062, 68.8931921989687, 69.37519657996394, 64.5190042065036, 70.59614412246212, 66.91361119670253, 68.15159751522926, 68.23873689097744, 65.50189918087375, 65.71440927443966, 68.19381006302373, 67.63683349855485, 67.53566772707048, 66.75082498981108, 64.58748094497189, 52.06632614135743, 52.35136478177963, 52.2872144176114, 50.70760534655664, 61.28500999942903, 67.05571082330519, 64.69088638982466, 66.28381975235479, 62.14093000658097, 56.736770752937566, 47.8931047070411, 49.03848778816962, 49.06173959855111, 48.444550729567005, 47.79702624967022, 48.896847078877116, 51.65282987779187, 54.22361404665055, 55.36921285813855, 59.85099538680046, 64.61818133631061, 61.45087918927593, 62.171481347853145, 63.14276218414307, 63.94033301261164, 65.6451206053457, 62.882038316419056, 60.98638034635975, 59.021249355808386, 51.1992391463249, 57.79739533701251, 62.27063886580929, 61.073237311455514, 61.212701105302386, 61.54308626728674, 64.17775015677175, 62.72468459221625, 60.668837024319565, 61.922493211684696, 59.299337556285245, 61.375655974111254, 60.57053850543115, 56.23640183479556, 47.19849609559583, 45.72291612625123, 46.734793493824625, 45.05167307392244, 46.15009361697782, 46.620781960025916, 47.23370721263271, 45.80907490945632, 46.18275911577287, 45.34158722046883, 46.290785112688624, 50.67877984816029, 56.838054195527114, 59.299635656418346, 59.60201117300219, 62.553469211824485, 56.67311460741105, 59.281361333785526, 59.9428298396449, 58.42553938588789, 59.469791996863584, 59.221176485861506, 59.2073344415234, 61.93058113898001, 57.01817727858021, 51.784170443011874, 46.97200275236561, 46.52500160278813, 45.75991976645685, 49.07496583077216, 50.09448005307106, 56.84786404332807, 61.67148897724768, 63.12638236630348, 65.86449484671316, 48.164701384882775, 5.436222178320731, 1.610607439952512, 4.906457056922298, 21.95923839845965, 18.149289238837458, 23.05770208758693, 2.7108907411175394, 0.24732529636352296, 0.38551153134434457, 30.97654973306964, 57.79610879959599, 37.85064466537968, 56.446993889347205, 41.674104429060414, 0.11302328037638819, 0.11268141364017803, 0.12996767437265766, 0.2508810934640708, 0.08505907931154774, 0.09388961393626467, 0.20996450596759397, 0.11372531568931957, 0.12611780676149553, 0.1486220225811966, 0.14579900390198156, 0.1350153510969493, 0.08094688021247426, 0.17325651441370288, 0.13949348741481382, 0.12070164174562502, 0.24738682854560115, 0.23972748147864498, 0.11636721586147625, 0.18446286389183614, 0.12952306758492224, 0.1474583197024561], [0.07533760741353035, 0.08210074652226702, 0.05442630289302719, 0.0492267377464281, 0.025921469749582392, 0.06466948832835882, 0.05600751986006095, 0.005348893877629552, 0.0615985444446485, 0.00384647527807242, 0.03413497800788572, 0.06592173564938769, 0.05580328081944778, 0.06740050750874704, 0.08609275408690015, 0.01287367951590568, 0.027404930067038345, 0.08090741136261533, 0.0272706386843516, 0.016767184452844724, 0.08556007783138946, 0.03436881485545347, 0.01793639933420045, 0.04178400970094147, 0.04048053791085559, 0.0379381257469856, 0.006530662546039469, 0.05029066916434996, 0.09701421078775199, 14.599501086819558, 45.049394176852324, 23.067056940447902, 39.98701064817367, 43.0011599294601, 5.501924330188382, 0.04730114893567178, 0.3320662346818755, 0.7478164208512152, 3.390623763684304, 4.61584767026286, 4.729127191728161, 3.594968708292131, 0.39516341181532033, 1.3492117437624163, 31.631142324016942, 70.38718377390217, 68.33968300973216, 68.7635970884754, 66.32396128869826, 60.87251786262759, 61.52125043253745, 66.00343304295694, 63.826486218360166, 62.89168342467278, 64.69276520513719, 64.31060083450811, 64.98927677831342, 63.292137807415386, 64.58898321274789, 63.285724732183645, 57.26902461821034, 46.45173957270961, 47.51875762016543, 46.783501486624445, 48.49915404473582, 55.73260084275277, 61.2879047086162, 63.192109523280976, 62.870867406168294, 61.0399716900241, 57.116707217308786, 46.32681208272135, 43.34543812659479, 45.0750425554091, 44.99901917672927, 44.344469731853856, 44.38436023650631, 44.26339041802191, 44.268195321483, 50.53669198866814, 50.5193982585784, 52.19125363134569, 55.90584016615345, 56.744756698608406, 55.846435869893725, 58.92464530083441, 58.89664350017425, 56.365859662332845, 61.81186668334469, 59.93502824537216, 56.78209766264885, 54.71294541512766, 57.234213582931034, 59.81642361610167, 62.403913159524244, 60.32811641693116, 60.540955989591545, 60.82432370032034, 61.30168791740172, 59.12587073541457, 56.86345154239286, 56.496400064037694, 51.9649407171434, 45.792024366317264, 40.869998931884766, 40.34264410695722, 42.29716900856265, 39.969869890520656, 42.550691404650294, 40.94268829591813, 42.25825909645327, 41.218144586009366, 43.01323298485049, 41.41622427971133, 48.545630208907596, 52.70514295947168, 53.00596129509711, 54.38708666832217, 57.35095900873984, 56.32096421334052, 57.21487629798151, 56.19685649871827, 57.92715518705307, 54.66759104882517, 57.47471763241676, 55.315978450159875, 55.79847312742665, 56.32068964742846, 55.158216799459154, 50.190993893531065, 45.80987899534164, 43.02339584596696, 45.26792118626256, 42.17557553322085, 52.242420950243556, 52.98724374463482, 59.40460220459969, 56.41274375300254, 65.70583497324299, 19.808687163937478, 0.17758524826457425, 0.8963126364734866, 1.2901477131151384, 3.5880334675312047, 5.562547502979156, 0.7756321540763302, 0.5905877221976558, 0.2440738353517748, 1.5319107208521137, 45.66213900043119, 39.326683552034446, 24.966972643329253, 50.217771914697465, 7.909948277857996, 0.20316947461856952, 0.0931994300035219, 0.031038061828322472, 0.06490916659634921, 0.06761144981869767, 0.038520360230318004, 0.023742309666328856, 0.0717107173536093, 0.037646204112998904, 0.05214483559792561, 0.045120828229212956, 0.04756598936153516, 0.07964677537881559, 0.026626829884105155, 0.021640913253049218, 0.0374082227297608, 0.0751949924855463, 0.009556885568364974, 0.0330669901544048, 0.11144954425793503, 0.019699244256762248, 0.036223774190030755, 0.016522373395761656, 0.08399581055968039, 0.04898342056079738, 0.04225122757376202, 0.0495913228200328, 0.042156462497528524, 0.006607529414337009, 0.011295293243752133, 0.05758369596855295, 0.03753447401968222, 0.03720252429165187, 0.08447140560395296, 0.028479489039689786, 0.01968618437287308, 0.020002061576252023, 0.04815602645037636, 0.018667013557147116, 0.06481658487069993, 0.03258058943996026, 0.027748622007728107, 0.0212950628596328, 0.07687067192408346, 0.01934761564517694, 0.004993441529692181, 0.032670133626989784, 0.04058961350951464, 0.009852337910072699, 0.03772670080164268, 0.018430351760358583, 24.511491329439227, 53.147127397598766, 28.75527031960026, 54.30536016341179, 48.87064564612604, 7.421750964656954, 0.16028742726531722, 1.3863446996096642, 1.371656281332816, 2.687157459797398, 4.703779855082113, 6.614360482461992, 5.406282236499171, 2.3629201227618806, 2.4895940480693697, 38.358101306423066, 70.6905947962115, 70.51862239837646, 69.94821563843759, 67.48274710870558, 64.46593061570199, 64.84679275943388, 68.60202681633734, 66.89141842626756, 64.46804477322486, 66.52954055416969, 66.23493133052703, 65.17846838120492, 64.34171307471492, 66.66012410194644, 64.89876416421706, 58.76924491697743, 50.12001076052266, 49.075558108668176, 48.98603000948506, 51.39437314002745, 57.746306465518096, 64.49270863686839, 64.69376148716097, 63.556552625471554, 62.662365974918494, 57.93367416627946, 46.787992600471746, 46.19759351976457, 45.52498940498599, 46.86182337422525, 44.975708530795195, 46.49629769786712, 45.782077235560266, 45.376825794096916, 50.760388681965495, 53.254168879601266, 54.7719104059281, 56.8582465571742, 58.83895327967983, 58.624913461746715, 61.216035119948856, 60.064537063721694, 60.11578675239318, 64.89880338791879, 63.261660991176484, 54.45872091477918, 54.08670371578586, 56.41068450866207, 58.35885124821817, 60.957923550759595, 60.76804161071778, 61.28114254243913, 61.478892757046616, 62.24894031401604, 59.92368475083382, 59.2011292519108, 58.592753948703894, 53.92400380103819, 46.76730602018295, 44.3073994113553, 43.640627861022956, 44.30932137273973, 41.16143888042819, 43.23539603141047, 42.03577441553916, 43.4026341284475, 42.17613643215549, 46.50313831144764, 43.93620983246834, 49.5244223840775, 54.405082502672755, 55.685320592695675, 57.06078990813225, 59.67985453144197, 57.74198009121803, 57.44304057090514, 56.861282471687566, 59.60976177646268, 57.41182634907385, 58.65424494589529, 56.45691356351299, 56.80675368155203, 57.493435182879054, 58.21708894545033, 51.74756296219365, 47.648258593774614, 46.44748380107265, 46.56026763300742, 45.10142441718809, 53.62175772267004, 56.88358114611719, 60.229751217749815, 58.378906326909224, 65.00026333716609, 22.366829533730787, 0.37677739356313983, 3.23281406394897, 3.567426315238399, 7.90548756237953, 6.1157546697124365, 1.7119570725387143, 0.4064896234100865, 0.18176318536843025, 2.1845378366208847, 50.99510331307688, 49.91682806322652, 24.153947676381758, 56.27191105196553, 12.36965129452367, 0.27118924164002944, 0.046271231821587974, 0.03477812414207766, 0.057109575643534624, 0.10429232952094848, 0.00378441114369179, 0.01904944847938755, 0.03212455070517477, 0.03426257761255388, 0.11573014480452384, 0.013077304728569524, 0.02897502726785118, 0.06270173020781049, 0.03992675593303096, 0.05528571181780389, 0.06515450625410003, 0.011361071468150664, 0.04798774757692891, 0.053510245596689564, 0.020395396014435158, 0.033640767027053146, 0.03489185755531635, 0.206879990836305, 0.22076490545465102, 0.19310163904822644, 0.2216962079006818, 0.11008207731309438, 0.11142061677791419, 0.1095276594822926, 0.08025412988518515, 0.16843258132857664, 0.1879016027575539, 0.20176548060149918, 0.1410228593815719, 0.1778787212266076, 0.2150498742177602, 0.292470122296964, 0.13827756798315433, 0.11217041001204522, 0.1938572775332197, 0.20339102724627142, 0.20029831497419268, 0.21022538954932846, 0.13491836436573537, 0.13519361975692934, 0.15938846905144954, 0.13492699051576276, 0.15570393853610562, 0.15063006160480363, 0.21124794838889954, 0.2756791910336864, 29.108038486972934, 62.0332609453509, 36.10021637332055, 50.70852318117696, 57.71559430706886, 11.383377198250065, 0.7727685174153698, 2.970352586238615, 4.341940716389687, 10.93776652889867, 13.743643837590373, 12.065794102607235, 8.563453881971299, 2.5210053690018195, 2.781433342925964, 37.21628758215135, 72.53418722460347, 71.41183237875663, 72.34209306778448, 69.9840739465529, 66.01056391193022, 67.02285705074188, 69.51344443905738, 71.20077748452464, 66.97462758710309, 68.21510068831905, 69.3130583916941, 69.0652822679089, 66.59749169503489, 70.48521164924868, 69.30239738956575, 63.17600427135345, 52.077834375443004, 52.20306388793453, 50.69441833803731, 53.697761489499, 60.429713649134484, 67.04799944354643, 67.87958898851949, 66.98481790481075, 66.69805342151274, 63.00861712424987, 51.066604198948035, 47.79178204074983, 49.386123534171816, 48.316634393507435, 49.39169722218668, 47.49605101923789, 49.07528746512629, 47.36201186333933, 54.48986453394736, 55.02559754156298, 57.23575899677893, 61.47901435052196, 60.17777589059646, 61.484815536006806, 64.73982188009447, 62.827485992062485, 61.70876326099519, 67.72161945219963, 64.61763612685665, 56.00122436400383, 55.11689855206398, 56.96637453571443, 59.065250504401426, 59.961488554554606, 61.769497240743334, 63.191285825544796, 63.94230596480831, 66.7575087085847, 63.20495528559532, 61.2136620859946, 61.60141583411925, 54.95347299883443, 51.375816406742224, 46.75564873603083, 45.295456224872225, 46.46971971757951, 43.40449333190919, 45.778923649941724, 43.71144233211395, 45.563879705244496, 45.67818541680613, 47.945805672676336, 45.706846175655244, 52.43101635286885, 58.328343053017896, 58.712947137894176, 59.89754999837568, 62.1506888635697, 59.57078518406038, 60.68841749621976, 59.86279387627879, 62.89980665329964, 60.534946918487556, 62.28990554809571, 58.96706573424801, 58.45793031877088, 58.10381089487384, 60.31785941893055, 55.77668043874926, 51.28129513032975, 48.624595365216656, 49.62961250735868, 45.357410061743956, 57.372736007936545, 59.516731000715694, 62.97147227871803, 58.59907288705149, 66.48975203114172, 22.433870684716013, 0.7652340733235883, 4.299155502550064, 6.146782088664271, 9.476160983885489, 19.573454779963342, 6.0259073876565505, 1.4911016461349305, 0.44759281460315953, 3.1983018642471683, 61.08746767044068, 49.13327970812398, 36.730164712475194, 65.00686076379591, 15.155675526588196, 0.6198307691562561, 0.22236075853147816, 0.14084682769833073, 0.20900931690008412, 0.1681391696535772, 0.14134000446046555, 0.13131517706619156, 0.2848100397856005, 0.13589232258739012, 0.28055304240795875, 0.09410683050631516, 0.22424720407974338, 0.09927050060322208, 0.11982784952006995, 0.10890279220597399, 0.24715672637666428, 0.1971422625525344, 0.18941173059565408, 0.09425227229873981, 0.17803468140623263, 0.17265614662920276, 0.11746261434088792], [0.045827437087052295, 0.04956140708658965, 0.042490833063399604, 0.04660533808712517, 0.10300818995963182, 0.02187076644341071, 0.0599810800274774, 0.05562698483587273, 0.0590346013796666, 0.02236070073840599, 0.06722858971765927, 0.04187743029286785, 0.03178678445457932, 0.007686632245989337, 0.04041113034491578, 0.06385515218660717, 0.044918489086652, 0.0974251326894568, 0.021498129785721822, 0.012215248970014435, 0.04912233528410716, 0.06162869000446893, 0.05796875091149442, 0.02112850385357536, 0.04504957056093601, 0.09346549233962452, 0.059823131849688876, 0.05667600052190885, 0.10063773772168545, 0.11985195064616781, 28.902820079557358, 40.6135190686872, 30.372532183124175, 57.14878436057799, 25.608870483213856, 0.4358289522990104, 0.7232067962327312, 0.7693837571047968, 2.3313386690232063, 1.6316276668540894, 7.278116220428098, 5.394305769474276, 2.152362879245512, 0.8831058322421966, 3.35942939885201, 46.96300483519032, 68.82506062907558, 71.11349690345027, 66.90699023585167, 60.45366364140665, 68.86219762986707, 66.00791238969373, 65.42770362669422, 69.251186924596, 67.73906615472609, 65.53848312747094, 65.6895806712489, 66.04305682643768, 62.233870567814, 59.7120689576672, 54.644621649096095, 47.831656855921594, 47.075294448483376, 47.129419234491166, 51.10933449960525, 57.73774393143193, 63.00672261945663, 64.75564472136959, 60.47074556350709, 61.03120519268898, 60.00235965175014, 52.79468282576531, 42.99342501548029, 44.43391938363352, 44.36575251240885, 46.67590302805747, 45.00286702186831, 44.422948514261556, 44.08040400474302, 49.52544612269248, 46.807839793543664, 50.95538147034184, 50.99335001360986, 51.699753192163286, 56.56678699677991, 54.36399567511774, 52.5985368605583, 56.110274099534564, 59.24856639677479, 59.723541890421224, 53.67716512372417, 57.801090209714836, 64.36963642797163, 60.56528645177042, 57.000185366599794, 58.33687420814269, 60.61684600768551, 60.732873639752796, 59.075362374705655, 58.21382945583713, 55.146947829954094, 52.47737876830563, 44.568586118759654, 40.252378602181714, 41.23938814286263, 41.78799044701361, 42.50843178841376, 41.65759909537531, 43.43761382564422, 42.636708982529186, 41.05077312838647, 41.72171415821199, 45.52713101910007, 48.93239159737864, 54.03412042125579, 54.88527474864837, 54.18562981390185, 54.30876478072136, 56.15365943601055, 58.36976328203755, 56.95724325795328, 54.48080385884931, 55.97352458584694, 56.51001068853564, 54.5283547524483, 56.15775439047045, 60.07232296851374, 58.715014226974986, 56.86770731402982, 53.26300990196967, 49.71006031959288, 45.71454186593333, 47.351629349493216, 48.77881903802195, 50.30788052466608, 55.62040144397367, 58.01251380674301, 61.69214810094526, 50.956071807492165, 2.8589979679353776, 0.26915582978437025, 0.40786821395158773, 2.8642424220039002, 14.770059470207462, 6.808893863231906, 1.1436899655288266, 0.09598517084434148, 0.09064229746018687, 9.451556936387094, 50.167012522297526, 25.27451196024495, 36.7121414215334, 33.17270832677042, 0.09823096525524894, 0.03241717905527161, 0.055543274408386606, 0.07505122842567583, 0.10768528697231125, 0.04474249953824667, 0.04839323408481094, 0.012051628868756516, 0.010398643827366253, 0.056803113660745086, 0.03639513273693381, 0.008819744276303438, 0.050063489620844205, 0.05697066475066447, 0.014741953458606958, 0.055166857106791395, 0.06337328671267436, 0.012984356238326479, 0.026213102185377674, 0.05558079356447824, 0.0483479812711237, 0.05480971457737108, 0.11833906489154024, 0.08976765487703586, 0.04199904292040775, 0.059249274537808476, 0.021943498830941897, 0.08563586690973851, 0.03392479412498013, 0.04163134752983048, 0.034679302630285104, 0.037170252837841554, 0.033039269262864705, 0.03699948417864019, 0.04081261021295383, 0.036672985166191094, 0.023125898085474487, 0.06195703911925517, 0.00359082359805583, 0.040892785144669395, 0.0540853631232054, 0.017800935836989554, 0.028856339180962216, 0.015749950881957287, 0.05359798181621779, 0.04184195276109442, 0.02464903792696855, 0.04825137375343231, 0.032806987573783246, 0.1038309224250336, 0.04009229604214911, 0.02888713208507867, 0.7247363980258665, 42.30915184943907, 38.284313678741455, 32.31110480523879, 64.30939274449503, 28.91181015199231, 0.34129863604903227, 0.2862461482084567, 1.6959312486071743, 0.6415754087990331, 3.795658003899359, 4.2882439590269525, 7.977978846719188, 4.004557065425381, 0.8527119986472592, 4.233258703062612, 53.29211388864825, 68.2900728717927, 74.45073573820054, 66.62435208597492, 64.06221282097601, 69.83239589198944, 69.29885941167032, 66.56496740156605, 70.35213347404235, 70.7736784412015, 68.78862965491511, 66.3985098561933, 67.53009796142578, 64.44542838681129, 63.236483297040394, 57.04241360387495, 49.69251163544194, 49.05568738137522, 50.6533315104823, 53.3844425601344, 60.86837976209579, 64.7380607358871, 67.5217511576991, 62.392138204266956, 64.1811155503796, 61.6993691844325, 53.701028823852546, 45.27897834777833, 47.44591920606552, 47.052744742362734, 48.88655870191513, 46.43588535247311, 46.27246372161373, 45.52753894559799, 51.6334572915108, 50.377373157009, 54.23282377181515, 51.75899274887578, 54.58730013139787, 59.003512397889175, 57.348774248553866, 55.832813478285274, 58.085669932826875, 60.479821928085826, 61.015350972452474, 55.21949991103142, 55.33733183337797, 61.274533348698775, 62.74464945639334, 59.206859834732555, 57.71188374488585, 61.56690682134321, 60.40057436112435, 60.30511956061087, 61.49926162535145, 57.82400077389133, 54.07050824934437, 46.44429883649273, 43.63252816661712, 43.439637768653135, 43.09485358576621, 43.624922690853, 42.77875761831961, 44.26865031642299, 45.11676088456185, 44.34388529869818, 45.286391627404, 46.83721442376414, 49.95376502313922, 54.70981536373016, 54.03989807251961, 56.588497315683675, 55.979164954154726, 57.9574711861149, 61.17346955883888, 58.77201803268925, 54.83429178114861, 57.86935514019382, 58.539052778674716, 57.59700536727906, 58.7828790756964, 60.70487968383297, 61.73558442823349, 58.58969449996949, 53.75281195486746, 51.71405415381155, 47.28243873965356, 49.63644135382868, 50.876663423353634, 53.31874678211828, 55.696216937034364, 60.835157286736276, 61.848956615694114, 53.52548706916071, 2.6841021785812997, 0.9916245156238157, 3.5081438576021506, 4.215577148622082, 7.6913570396361814, 2.874446958303452, 0.662362928832731, 0.3841626037272715, 0.03382673104023261, 9.077157878106641, 63.33026716786047, 32.82852230533477, 34.54402385219451, 42.60716176802113, 0.4982734225209683, 0.07128128676765388, 0.07976581778136954, 0.029368101236140056, 0.06647401609488073, 0.04583998943769163, 0.03999433637927136, 0.05875744992086004, 0.06440197042520009, 0.04200621350337902, 0.04270686602760707, 0.11156088747684995, 0.07865774820769027, 0.02612271913207106, 0.009356143719126141, 0.04109034389858285, 0.03409308065930682, 0.023913107053827376, 0.040996268301481203, 0.02608214520038136, 0.04275704861708707, 0.07109254568574891, 0.05967929884190521, 0.22845106559895703, 0.18110574403357121, 0.11302354850716169, 0.14411836021369503, 0.27478979359711375, 0.09572137612849475, 0.17400455330648731, 0.18609908980227288, 0.12187526546298497, 0.11012473308871831, 0.24857421886296044, 0.09541108753652343, 0.15035584809318667, 0.08098343026734169, 0.12982611664600913, 0.2062104146687254, 0.1616481526364242, 0.19654448414521833, 0.15822562419118422, 0.1057767704309475, 0.15092656827501713, 0.16836993065812897, 0.16692312764784983, 0.10503532755519114, 0.120870410915344, 0.170744220996576, 0.235312624023326, 0.06495497865422119, 0.2176749051338242, 1.2030946295107565, 55.23110228200113, 54.092449988088305, 44.45206819042083, 70.10677353028329, 41.480378566249726, 0.7707429809435722, 1.2356643979587865, 2.235043255552169, 5.111070438738793, 8.39252777637974, 18.75617992493414, 13.815291812342982, 7.476927926463466, 1.8024042320828286, 4.953060207828399, 52.51690841490223, 69.96726266799435, 76.12036320470995, 72.16870861668741, 65.22124967267438, 72.98964500427246, 72.93893660268476, 68.6028112903718, 73.89058989863243, 73.94195725840908, 68.42308044433594, 67.80495412888067, 71.45195038087907, 68.1753670784735, 65.5674066851216, 60.699376598481216, 53.909494953770796, 52.34385736526982, 52.04938934695337, 56.44953558521887, 64.2285252386524, 68.4904432296753, 69.37398848995086, 64.53239517827188, 66.0341687356272, 63.37748073762464, 56.45597219467164, 48.46026374447731, 48.63818245549356, 51.27156372993223, 54.013594658144065, 49.62615689923687, 48.48541790439237, 48.57923315417383, 55.8290401581795, 52.576806929803666, 56.70827473363569, 54.03856446666103, 55.67542445275092, 62.227335899106926, 59.76750773768271, 56.84523213294245, 61.77345883461737, 63.98327904362833, 62.61097508092081, 55.99665088038291, 51.941284902634166, 60.25257156741235, 61.52039535583989, 59.80122050931377, 59.74042769401305, 64.54285221715128, 62.8096313630381, 62.65870248117755, 64.01717616665748, 60.08433326598137, 54.42532977750225, 49.38311507624965, 44.40823178137503, 45.97529319024856, 46.78859272310811, 47.465287869976414, 45.04255748564198, 47.156483588680146, 48.021436814338934, 47.40560900780463, 48.612028091184555, 49.07600525886782, 52.07490436492428, 57.99414142485588, 55.72647802291378, 59.02738002038772, 58.01842481859269, 60.55854389744421, 64.81726515677668, 60.210531603905466, 57.35185723150931, 60.57972077400454, 61.242887666148526, 58.56883533539311, 60.798769458647705, 63.47426129925636, 62.6947961315032, 60.96538389882734, 57.61016491920718, 54.94289436647969, 50.02138276253977, 53.495935932282485, 53.66989697179487, 54.5677706503099, 59.81735321783251, 63.05475988695699, 64.4345751885445, 55.04178516326412, 3.349078263967268, 0.9317717821367326, 6.42778362958662, 6.940466828884618, 33.737761051424094, 17.95924452043349, 3.7337831047273453, 0.4972800209877953, 0.19257107719538674, 15.329258057378954, 64.15243517967963, 34.94656885823896, 47.62592854038362, 48.94114240523308, 0.9246158467665796, 0.21095815264890272, 0.19387595475681368, 0.11831892444001091, 0.22811294503269658, 0.19533870771767634, 0.12358144286178774, 0.10539409419101094, 0.11434994547838166, 0.1342364848260918, 0.1537075287271892, 0.19962662440394202, 0.21792625858178064, 0.1310837878695419, 0.18939947318886557, 0.1951089732709431, 0.28208947770537873, 0.11474594398732148, 0.1382376701240578, 0.2362142329014117, 0.1445475992776694, 0.14414181782593652, 0.23442031545264108], [0.07303233393618176, 0.045556000644160856, 0.042614291962837024, 0.05127700353642145, 0.03609764930461684, 0.02811114630481649, 0.03137579935062076, 0.08519737350363886, 0.04191738177811907, 0.032746294257982124, 0.03350340363179003, 0.060399750908536304, 0.0719876581382367, 0.027022485568698858, 0.05435059042347055, 0.07473342451116732, 0.030178961253935294, 0.05916112463080114, 0.024123819537400722, 0.052082426245174104, 0.03737121685257843, 0.04747983511357058, 0.02304286564580135, 0.0412409414627379, 0.10288432120315491, 0.05226609965545997, 0.14885934129838022, 0.03131761688799147, 0.029940054819528616, 0.04435414275635154, 12.427210115617322, 51.04890254236037, 33.44876473949802, 46.34597286101311, 51.87508313886581, 6.895032544289866, 0.1911323793953465, 0.8684335937423091, 0.9055618917749775, 2.409601475923292, 2.2020333236263645, 6.148203457555463, 3.260177008567318, 0.2721698648266254, 0.2686448491388752, 13.1383809351152, 65.41147285892119, 68.67737554734754, 67.20701233033212, 66.33221395554082, 62.63946717785251, 67.89509804018083, 68.04566998635569, 65.96952807518744, 65.9462684200656, 68.09094198288457, 64.85132701935308, 63.06835874434441, 62.624232692103234, 59.97747221300679, 49.22288233234037, 49.430716960660874, 48.60401076655234, 47.3479619333821, 53.81655831490794, 59.8681910576359, 61.922528513016246, 65.34394925640476, 61.8622769847993, 63.42491396011845, 61.438339371835035, 57.34797016266854, 48.3077423803268, 44.22724185451385, 45.26737205443844, 44.68262903151974, 46.18126077036704, 45.30514447919784, 44.82031599167855, 44.978791513750636, 46.15800503761538, 46.64362584390948, 52.5979132037009, 52.64050229903191, 49.5420769722231, 49.636645317077644, 51.498115908715036, 58.12408170392437, 62.2795073447689, 63.273836028191354, 45.25763673167075, 40.75797603976342, 53.13916890851913, 53.76545375393283, 60.2767216005633, 59.05147906272643, 60.52736497694447, 59.69122548257152, 59.75989441717825, 54.452456889613984, 50.80002815492692, 47.27326431582051, 42.73982809435937, 41.45230224055629, 40.41793400241483, 41.020539499098255, 41.40513573923419, 42.51004780492475, 42.69299891687209, 42.88699934559484, 41.573978085671705, 45.69731873850669, 54.98751917193013, 56.04720238716372, 55.51480731656475, 57.50359019925518, 57.63544459496775, 55.688070174186464, 55.95781941567698, 58.008399240432254, 60.08210143735332, 57.55097243093676, 54.84481157795076, 57.6564214306493, 58.01677742312032, 59.208624901310095, 57.537471632803644, 57.21959883166898, 57.122998699065185, 53.01823831373646, 50.782565762919766, 47.12650491345314, 46.37192326207315, 54.554767993188676, 55.85834810810705, 63.37141283096806, 58.207522284600046, 65.49062236662834, 20.48093826540055, 0.49559131805454537, 1.0272138962341895, 3.5581182856713576, 1.3297115578766794, 3.080511126787432, 0.26204582904615714, 0.18352711813584452, 0.4726294872741546, 0.029225116670732538, 29.95279346742938, 50.189330808578006, 21.013845205307007, 47.428750991821296, 18.694453585532404, 0.08917762161863428, 0.011092952185971363, 0.075083511370805, 0.04279447201218817, 0.020747195080583616, 0.05317853335591574, 0.059618203329943845, 0.05781726085490758, 0.044849426260278116, 0.011855535257998253, 0.035973202151757096, 0.0758784884707101, 0.03251426537791568, 0.0754818847523101, 0.048823886581005595, 0.020793190999557416, 0.052313646902480436, 0.06338031556937965, 0.04184041675480624, 0.08926228965602576, 0.05613864729962042, 0.0486964593461204, 0.04041386910924508, 0.021696132870631355, 0.04181420122603736, 0.07220637624061878, 0.042094819232701294, 0.10661861679006009, 0.08485924527649918, 0.05045616330819265, 0.08720639311978895, 0.017022875873672388, 0.010357839111689358, 0.08667583126694926, 0.07516617225783487, 0.044988513353370854, 0.01807307899599114, 0.0075492913545590025, 0.019309952847599503, 0.06535525193377849, 0.06830778543747242, 0.06224874624862306, 0.053536786712826266, 0.06940451690987234, 0.12169889670105712, 0.020377354643818353, 0.0847964643711044, 0.024558312049315825, 0.10506040927383209, 0.031011901840928103, 0.013888103459330817, 0.012038779659046522, 0.02182776784344066, 18.173054879711522, 61.29059937692458, 29.95613140444602, 63.11918481703728, 60.06048525533369, 7.627878871656234, 0.3793764234550538, 0.6015738520410754, 0.5092622796373983, 1.9758101336417662, 4.2005054412349585, 8.563134208802255, 5.009528610014147, 3.3912935083912266, 0.6686574749408231, 16.02344403343816, 70.32893657684326, 69.97797858330512, 70.37994307856407, 69.35833823296332, 67.33736838063886, 69.23771750542426, 70.39058054647138, 67.95194102871802, 70.17565035050916, 70.69171659408077, 66.17791575770225, 63.54436582134616, 65.03416830493559, 59.896220314887266, 51.40152754322175, 50.71121392711517, 51.106588840484626, 49.523312353318744, 56.15699345065702, 61.32033878757108, 63.625688322128795, 66.18965148925781, 63.18636325097854, 65.75670419200775, 64.1122583420046, 59.49203183574062, 49.813701106655984, 46.49501508282077, 46.694130282248224, 47.597922817353286, 48.61406772367416, 48.46796727949574, 48.472552530227176, 48.290119171142585, 47.0747100153277, 49.510246938274754, 54.985444238108975, 56.0389732545422, 53.095022632229714, 52.61269269451019, 51.871529471489694, 58.99716992532054, 63.22302956734935, 67.11512688667544, 45.88274878840293, 45.22854451210269, 58.28544801281345, 56.510249953116144, 61.076426198405606, 63.38580792950046, 64.4926223447246, 61.76240951784196, 62.77636181923651, 57.64321873264929, 52.93955949044997, 50.92564598206551, 45.45668525080527, 43.00182673238939, 42.70614670168969, 42.57767731143583, 44.21916569432905, 43.05061317259266, 45.224288740465724, 45.345533124862186, 43.3274579817249, 46.6638848858495, 55.72526208816036, 59.69875251093219, 58.37192058563233, 58.86774347674463, 58.552926201974195, 57.73604554514731, 57.50314697142571, 58.67744184309437, 60.59810100063201, 58.18210532588344, 57.419000364119015, 58.00529272325578, 56.809299299793864, 61.73597274288055, 58.00279417345601, 58.81565440085627, 60.07968525732718, 57.06436318735923, 52.83133345265543, 48.94339384571199, 49.07717412517917, 55.879721103175996, 59.12077165419056, 63.679620911998136, 61.18067495284542, 65.23712350476173, 22.35605674405252, 0.7892463945092694, 0.8283423740536937, 7.068593502044679, 5.58177201978622, 3.2333565767734282, 0.5073661813812872, 0.04924378320274334, 0.08001619829766213, 0.08331915573968042, 30.3988395198699, 64.22620319551038, 19.66103934472607, 50.83525888381466, 24.243848400731242, 0.18521998858740255, 0.011572053997717317, 0.009741177594649696, 0.04446423342151027, 0.061466585799691185, 0.05106488528150705, 0.014570012684881449, 0.03289022302675632, 0.006672802978315421, 0.036657900894962014, 0.09609050027305081, 0.008466042439273049, 0.023704399805395834, 0.10231163217535905, 0.04681804622974127, 0.020442991141950893, 0.030889295214306445, 0.1355723889484521, 0.15367329991873235, 0.1422212966867993, 0.03736444846576741, 0.0474278292348308, 0.02697458017557379, 0.13867620949543294, 0.13505201606500533, 0.22882166829320694, 0.15298696174736948, 0.2159193227247846, 0.11463100781604169, 0.17888410437491634, 0.13450325196308477, 0.1619217839212187, 0.14573195588684854, 0.21776967021005772, 0.10210884104092276, 0.203778499196614, 0.12912474782957187, 0.12127721892489542, 0.12178735687367379, 0.13177898201730945, 0.1227189657548743, 0.1280765327054166, 0.13794459552774507, 0.10074612384121265, 0.22079268380278544, 0.14109468778535245, 0.13717217971721005, 0.20660750868339695, 0.1644157678369553, 0.2746746965473698, 0.18816751187607167, 0.11552066572250859, 0.2017787645661062, 22.655876836469098, 71.75556536643737, 47.09623598283338, 57.87236752048616, 67.07750351198258, 12.709572718989465, 1.0856271198680325, 2.72974165216569, 2.643015351026289, 8.424350946180283, 11.844199799722242, 14.999630893430403, 6.811275722519045, 2.668818908353006, 0.5996462522495178, 17.01973488253932, 68.94062149909236, 70.45519767269012, 70.07126039074313, 71.14147124751922, 68.43792269306799, 69.37073292270784, 73.6854342491396, 70.70822977250623, 70.23699622000419, 72.66952468502906, 69.18120399598153, 68.8087200349377, 66.89881601641255, 65.1981665242103, 52.411184849277625, 52.86336744985273, 54.4148099807001, 53.21530995830413, 59.338451431643584, 63.48186677502048, 66.03487476225823, 69.37841292350524, 66.07775411298199, 68.93182754516602, 68.56718832446684, 62.29493010428644, 51.99011056653915, 48.22303095171529, 50.53120851516724, 49.643529076730054, 52.02198374655939, 50.06376397225165, 48.85053565425258, 49.80977089174333, 48.63851193458804, 52.665503486510254, 59.567223671943914, 57.30280799250449, 56.42549930080291, 55.41496730619862, 55.511783169161895, 61.73405862623646, 67.64172077178955, 68.86262909058603, 48.88364830324727, 44.1198669710467, 60.70345194109025, 60.45149064833119, 65.74345050319549, 64.71755066225606, 67.66645523809618, 64.25445995023175, 63.000564498286096, 61.39795464854087, 55.191839356576246, 52.46628238308815, 48.1013080381578, 46.616400672543435, 44.00511410928542, 44.113273466787035, 46.121793716184555, 45.73786035660775, 48.518750206116714, 47.48604113055814, 44.61853358053392, 49.91898144445112, 59.43886410805487, 62.82053162974697, 59.912305954963934, 60.662580843894716, 61.52127788912866, 59.92890542553317, 60.23134370003978, 62.01142903297179, 65.71743342184251, 60.512542340063284, 58.74642064494472, 60.12443165625296, 60.84652039312548, 63.6707720448894, 58.4407974058582, 60.46200652276317, 61.160965042729536, 56.95777277792654, 56.22675280417166, 52.95393889950168, 52.95251115675896, 58.07511875706335, 61.70679030879852, 67.99927619195753, 60.58150937480312, 66.77805408354729, 22.610673481418242, 0.6206555700590534, 3.3771197786254272, 6.882947721788961, 7.773994024722808, 11.535928960769407, 6.559739026331133, 0.7270448967333764, 1.5050234861912266, 0.18582548916099534, 39.61968460390645, 63.297295724191976, 29.928570870430242, 60.28908883371661, 28.833925608665716, 0.26604091628424587, 0.2426814092623611, 0.13655056065369037, 0.16451497622314962, 0.17644092741031803, 0.18367043786471893, 0.112367884496287, 0.22175729575176395, 0.17544286806256543, 0.09691541608903678, 0.16709131459074636, 0.17815871104117365, 0.14562729295463334, 0.20556461787031544, 0.14599104682284017, 0.10102867238944578, 0.1620858493110826, 0.2820683030351516, 0.18377545319737928, 0.2014569157073575, 0.14990574079415492, 0.16457018051897326, 0.13388279735321], [0.014648510841652753, 0.0249516005222235, 0.01648018684899134, 0.06350721420359708, 0.020854569964050766, 0.01680715892073368, 0.02716389007776255, 0.04745435885964863, 0.011236406937842409, 0.01049197727679125, 0.04985455063081557, 0.03403542488212547, 0.03942266624841479, 0.10157513056671429, 0.04980400798001117, 0.07334247697144747, 0.015932906084814142, 0.006691939375858995, 0.12992517181461857, 0.04803880350664259, 0.007371530706633724, 0.011294143154255806, 0.04153729108492694, 0.019158899461129503, 0.05237715176096367, 0.028903648940726157, 0.07203250492532408, 0.008296128925717166, 0.07906173701368033, 0.05267982160852802, 0.42889910479707105, 39.04901896753619, 46.36383141240766, 22.017042367689072, 55.38990336079752, 28.418077884181855, 0.002807082374572694, 0.7369908017496909, 0.129164002174812, 0.9978349759213387, 1.59007775447061, 5.651891741060442, 2.327473418366525, 1.840155451528488, 0.43440335460247537, 0.3116670905822708, 20.364396802840695, 70.85606390430083, 69.56870279004498, 66.53466316961473, 66.28063478777486, 68.13115412189116, 66.18418370523761, 68.9899492263794, 65.80765185817596, 65.54170731575259, 65.94047900169127, 63.173705762432476, 56.233734623078384, 57.719904991888235, 51.44528550486411, 48.2168806752851, 47.84607548867503, 50.46050387044107, 57.86513859225858, 60.89330642454086, 61.732446532095636, 65.32716543443742, 61.79100751876832, 62.12094553055302, 61.079634697206565, 58.101998759854226, 51.205001108108036, 44.83937086597566, 45.093446316257605, 45.05645052079232, 45.6521487236023, 46.81355468688473, 46.118302806731194, 45.61129723825763, 44.399041668061294, 45.72227285754296, 44.11112793030278, 46.878579739601385, 50.83361541071246, 50.266923135326756, 56.64179055921493, 62.75090563681818, 62.86805898912492, 58.29197875915035, 55.08439387044599, 61.52576115823562, 63.67925613157211, 61.30449241207492, 59.56061840057374, 61.05391571598669, 56.66873724229875, 57.60766244703724, 52.483587880288404, 55.91581083113148, 45.764552085630356, 42.809630593945904, 40.26067049272599, 43.04798518457721, 41.67468493984592, 43.54968378620763, 44.74692844575451, 41.76760196685791, 41.704655770332586, 43.31062316894532, 41.469364550805864, 51.30638653232206, 57.80169425472137, 57.523668812167266, 55.386396761863466, 57.87104175936792, 57.269581594774806, 57.29844631687288, 55.12877548894575, 57.585622649038996, 57.990481853485115, 58.4768557548523, 56.242203020280414, 55.89192751915225, 55.744638596811605, 57.08437511997839, 58.87432521389377, 58.39816516445529, 57.4108692907518, 54.41792826498709, 52.02143853710544, 46.93289279937745, 50.45318080532936, 55.40300799954323, 60.31787118604107, 57.462432769037065, 61.08328250146682, 46.84243117609332, 1.4169249683618548, 0.8011563038153033, 0.37949127535666194, 4.592803255204232, 6.3888099789619455, 1.857683665810093, 0.3758857285063113, 0.05028580067559116, 0.1753610958375277, 2.7820109119338374, 47.23735501689296, 27.54210868189412, 33.42921564655919, 48.16791772842408, 2.1384436132446414, 0.16048040481344347, 0.006689088571170766, 0.014554806797194385, 0.07063349047976156, 0.008791677687587518, 0.10821460776271359, 0.03751975747065679, 0.0029836314065652273, 0.07156203500926495, 0.04488365889917459, 0.09185819390920863, 0.05934503935878316, 0.028230114013797818, 0.07060539037469896, 0.04898477653642336, 0.025061528393698317, 0.049722500055307345, 0.013764218423485517, 0.05438246351156024, 0.06279206346540202, 0.011529085083654331, 0.020219927405818336, 0.021945009939372543, 0.03155795016115712, 0.09674343701091506, 0.06800684311817731, 0.051278030094239986, 0.020811263013691194, 0.04155760773667886, 0.029474652575088606, 0.034476005877818794, 0.025986976012767806, 0.011482311585437388, 0.01402006401950794, 0.10737460001461929, 0.007872597216778706, 0.08819223336514928, 0.04988309123643464, 0.061410983138146906, 0.030126654685685234, 0.03417428214884093, 0.03222206412183662, 0.0475571908417248, 0.017616699352079344, 0.019430661491388758, 0.081589168328191, 0.013164581295343177, 0.116910747582874, 0.013217365710936008, 0.03629164574968238, 0.00397485318019115, 0.0168269393109386, 0.023119823008234945, 1.0358497908999844, 52.050985751613496, 45.72799559562437, 28.328602736996068, 72.53966285336402, 29.0422309214069, 0.48602946823643106, 0.4273621792033796, 0.2968861595276864, 0.6075418608323221, 1.8989302073755574, 5.293231683392679, 6.288599304614529, 4.350926376158192, 1.9301081472827544, 0.4306007086509659, 25.007171054040235, 72.38708265366094, 70.27140325115573, 69.50776484704787, 70.71414470672607, 70.35765617124497, 70.17149263812651, 69.55746912187146, 68.57932413777998, 67.41753378222066, 66.30402780348255, 65.01945157204905, 59.98798808743877, 58.40802992543867, 53.79703275619015, 49.751492315723056, 50.38572780547604, 52.97378217020343, 60.52301506842337, 63.65321943836828, 64.78801996477189, 67.05382808562248, 62.684382238695704, 63.33991619848437, 64.28056724609868, 59.66218425381569, 54.913653096845074, 48.635809421539314, 48.09086276638893, 48.273900170480054, 49.52217878833894, 48.52870910398422, 48.109109632430545, 47.424440307001916, 48.018793136842795, 48.402185209335826, 47.31578280848842, 50.042398821923044, 51.657677927324855, 49.871532532476614, 56.43969043608635, 63.297848778386275, 62.682330839095584, 60.642631669198316, 54.71369851020075, 57.233911560427764, 60.144212169031945, 60.8165652521195, 62.9941749572754, 61.42506999354209, 58.4062687812313, 60.61118994989703, 54.439277725835005, 58.81534453361266, 49.094436476307536, 44.64193836335213, 41.69524992665937, 43.95840652527348, 45.713851528783, 45.11595679867653, 45.74465782411637, 45.29189079038559, 43.40869419036373, 46.77342099528159, 43.72736323264338, 53.431561993014434, 59.060688787891024, 59.915082993045935, 57.325902908079094, 57.74379222623764, 57.844793258174775, 59.0919618452749, 58.31414407299411, 59.988890232578406, 59.59337019151258, 59.16406285378241, 56.805392619102236, 59.109894921702725, 57.49112882921773, 58.70946015081098, 60.683353716327304, 61.04864012810492, 58.03913885547269, 57.6550054550171, 56.15652668860651, 49.5218728434655, 52.09901909674368, 56.01580381393433, 60.450372772832075, 61.240679371741514, 60.7798126436049, 50.39822447684504, 1.7197518026636494, 2.0883870605499517, 2.8762338430650773, 8.808295092275067, 6.860166595828149, 3.026233368342923, 0.3119419935730196, 0.07450778097394975, 0.05910421195890635, 2.5622625745111898, 57.34322409476004, 37.052693367004395, 30.502272421313872, 57.97915797079764, 3.8391178654086207, 0.21897826584116106, 0.09880226766390186, 0.02387711432792487, 0.020736651795525706, 0.03596193682883055, 0.07171188946813345, 0.01359925096509077, 0.06354554924332807, 0.0418757755429514, 0.010823037385219529, 0.05553266409063532, 0.20716080802582926, 0.04797165206963978, 0.03109735703366178, 0.02479582037326069, 0.023096905487980095, 0.07234339872675558, 0.06792602850304497, 0.017054201208896214, 0.04782907161561232, 0.05673728372541167, 0.05194926484217567, 0.029509666623667847, 0.16017602275936835, 0.2819417146665435, 0.17745654549329512, 0.15852079786840947, 0.10058637918724168, 0.1323745234478866, 0.10928652564724607, 0.1307983281871965, 0.09798456839616261, 0.13156622407897828, 0.18263056543805908, 0.13282984014480345, 0.11378487902543238, 0.30816775416174247, 0.1358283389239542, 0.15770822372888366, 0.1371316689877741, 0.08922180190922753, 0.27158803636989287, 0.0972167567740525, 0.08693795591112106, 0.06324538450327612, 0.20773638520509968, 0.11260495040445559, 0.23210639284262735, 0.12514695119593414, 0.1332558003524619, 0.16174746827492792, 0.17740820534527305, 0.18205662768694664, 1.1291383399117378, 58.502684562437004, 60.32669259655861, 35.002188067282404, 66.4534544175671, 42.75190114974976, 0.6713274445745253, 3.0794967038016168, 0.7893243516164442, 4.883050803215274, 6.883462532874077, 14.073730899441628, 10.474601291841077, 5.644751556458012, 1.8684406434336018, 0.44135762498744074, 23.974971886604067, 73.09041853873961, 73.68079800759593, 72.05384592856132, 73.6062337506202, 75.10560681743007, 70.71387014081402, 72.3435757237096, 72.2794371266519, 69.16469866229643, 69.58675353757798, 69.12010131343719, 62.96027783424624, 62.52778553193616, 57.254056853632775, 51.555664923883256, 52.52631033620527, 56.65336155122327, 64.02633882338002, 65.89217109064903, 68.68533795879733, 68.82383684958182, 64.2646816469008, 66.06124877929688, 65.36823657251173, 62.28054677286456, 58.37428185247607, 51.740043778573316, 50.45463208229312, 50.1468829185732, 51.04381522824688, 51.941288825004335, 50.48976475192655, 48.814661656656575, 49.16061862822502, 51.43560509527884, 46.7066151865067, 52.59204533792312, 54.82827486530427, 55.854563020890765, 60.72452291365593, 66.98095044782086, 65.9630718538838, 63.766517100795625, 57.443213155192716, 64.00155728863132, 67.20709862247591, 64.93930185994795, 64.64176654815674, 65.01773357391357, 60.90740734531034, 63.55288913173061, 56.524707809571304, 61.73869879015031, 51.15819154247161, 46.7992772594575, 43.829721404660134, 47.41665832458004, 46.74955337278305, 48.43001442570841, 50.51804111849878, 46.91030386955508, 47.35633227132982, 48.47709855725689, 46.52347187842093, 57.60212406035393, 61.64770764689292, 60.858730731471894, 59.15799102475567, 61.4035048023347, 60.321244424389256, 61.68692742624591, 59.788182550860995, 61.34464179315875, 61.25563929157873, 61.43415420286117, 59.68692656486266, 61.84254354046237, 58.649640083312995, 59.88513177441013, 62.30310040135538, 63.715651804401034, 58.939703279925936, 60.09018151990829, 59.175414193061094, 51.91104342860561, 54.19887565797376, 60.534276193188084, 63.07335976631411, 62.990315345025834, 61.50177978700208, 50.910376194984686, 2.0362043380737305, 2.2787779281216283, 3.6425661800369142, 11.46954970975076, 14.76761975596028, 11.020277507843511, 2.212057185749854, 0.4905016137467277, 0.8985319012595762, 5.217754985055616, 59.5271998067056, 38.05820472778813, 45.06061607791532, 67.01348258603004, 4.924823064957896, 0.43132352792928297, 0.38071971266500415, 0.2266669234321002, 0.16654515518776833, 0.13146182161665734, 0.15221549588586056, 0.19759106750209487, 0.12188133287934527, 0.19979879500404482, 0.1824721231335594, 0.27780946704649156, 0.3199773059496957, 0.1465151888588744, 0.17949449258946604, 0.11042747571463547, 0.147369530112032, 0.23841311974871546, 0.1941166749043811, 0.1655046545690106, 0.11806983861231035, 0.11252097950707521, 0.1739731437015918, 0.11726224404429236], [0.018273215635769793, 0.0718285876416391, 0.020826328132722168, 0.017557836986417254, 0.026450348124208472, 0.03243603630952778, 0.1268043747592357, 0.02165823641623701, 0.016916945065942504, 0.0015777532920061101, 0.07755697179105013, 0.02031935604229089, 0.028019319175772613, 0.06332511893443524, 0.018795386910618796, 0.04406092643377282, 0.04972021711329299, 0.009417127190728583, 0.017475651073900443, 0.05031249500931271, 0.018452708121208895, 0.03799477411854652, 0.07724644571182228, 0.04814771822683754, 0.08367195455057007, 0.0589546179699321, 0.03450199158021039, 0.0229362070545434, 0.10323611643886375, 0.13557563716125104, 0.14054593900519033, 7.88107963338975, 54.97713273571384, 39.967288970947266, 35.4567240899609, 60.0738017020687, 7.5638280376311275, 0.26670085506573804, 0.3506557565302618, 0.3157667947872993, 1.2351630700211371, 3.5479581211843803, 5.589667750943092, 8.006933783331226, 1.4750989887022203, 0.08288056274215061, 1.0828834219324974, 39.62998082560878, 74.89849782759144, 69.47865301562895, 69.72749602410101, 66.23719846048664, 66.20134015237132, 62.43939099773284, 66.09483995745259, 66.98400205181491, 63.579871116145966, 59.45522039167343, 59.605125534919004, 56.6356324380444, 50.67370430115731, 50.92230020030853, 52.06016409781672, 50.923159199376265, 56.621245184252345, 63.045456024908255, 67.09612692556074, 64.33579814049506, 64.0968434272274, 64.14347648620605, 63.77046300518898, 60.924779522803526, 50.59534711222495, 44.40365437538394, 45.27700147321148, 44.94831861988191, 46.646544087317686, 45.49278674587127, 45.9415804186175, 44.60945329358501, 46.714185360939275, 47.55186634678995, 48.34833891161027, 48.5160320035873, 50.210178206043864, 55.89233152327999, 62.57957650769142, 60.42168063502158, 62.93974422639417, 59.450129155189764, 56.27044800789126, 65.36416907464304, 62.38972986898115, 63.884466694247344, 57.87331673406786, 58.04352406532534, 57.15971600624823, 54.79098096970589, 52.580674386793575, 46.790259730431345, 44.60587609198786, 42.64811523499028, 43.91029473273985, 43.88776463847007, 40.35445436354607, 42.90926271869291, 44.13779612510435, 44.47503366777974, 43.23245033141106, 41.744809073786584, 43.54747156943045, 51.582909707100164, 61.293890245499156, 58.73583024547946, 58.53168656749111, 58.09567197676628, 58.17856734798801, 58.745043893014234, 59.271233774000606, 56.61385151647753, 59.338325915798066, 59.31059083630962, 55.431504018845104, 55.60537092147335, 59.80992424872614, 59.41252931471794, 55.525331035737075, 57.89890627707205, 57.75031120546403, 53.499234645597404, 51.45591905040126, 48.53511041210544, 52.345289030382716, 52.825336148661954, 60.74383666438442, 58.78777027130128, 66.00311925334316, 17.904327415650894, 0.12353485705511225, 0.9043644044187762, 0.20867591543543726, 11.993035116503316, 5.653920587032072, 1.1256823640677238, 0.031337134893082326, 0.07224300290427862, 0.0404509745778576, 23.57839672796188, 49.7960739751016, 23.224336139617428, 43.669833829326016, 19.346573122086067, 0.09804726503188572, 0.04338648560787401, 0.02598135675784321, 0.02284846891979537, 0.01226247733293642, 0.026189481779452295, 0.025439299755699696, 0.004784695019254521, 0.024721890973347812, 0.11325128346441254, 0.019243609633356817, 0.02692560225935473, 0.021443695408262072, 0.0064663140332296256, 0.047917206200861165, 0.07776393810467375, 0.014282014378676973, 0.02054339271008728, 0.032767871124369484, 0.036068304306677276, 0.04182792952164047, 0.04975141604400931, 0.09123499670456495, 0.1110687755769299, 0.06252829939307225, 0.021562854639224468, 0.05401597853990332, 0.0434058484801602, 0.04447136953052494, 0.014254372968759029, 0.09781687941041686, 0.050605745805848035, 0.06250566532534939, 0.018725389456977288, 0.06603063504782415, 0.048401975148026986, 0.05520716099248779, 0.028714024942488443, 0.0502258887694728, 0.09601959117477941, 0.03595100092371145, 0.012872606992811687, 0.04523946077472741, 0.020151065677524577, 0.016325168957513188, 0.08365721501890691, 0.03907007811170432, 0.06113005869631326, 0.026971701600198305, 0.0944582656806996, 0.04113665774404522, 0.005816351152926443, 0.028641022508963946, 0.09444742553657103, 0.11230781554214417, 13.348516033541772, 64.20665410257155, 28.794443030511182, 45.2017076553837, 71.41253840538764, 6.725916612532831, 0.18614255763109655, 0.11759946828768139, 0.18996478478995063, 0.2475687437841008, 2.0026395133426114, 4.764342721431486, 6.0326185630213836, 3.414408035816685, 1.206473628840139, 1.170211684319281, 48.12048058356009, 75.89035541780534, 74.41657973874, 68.74561694360548, 68.99615441599201, 67.56775271508002, 66.14783902322093, 68.65967781313005, 69.44109239885884, 63.65655345301475, 62.78074702908916, 59.602113154626664, 58.33443841626568, 52.5621804114311, 54.48865644393429, 52.84514019566198, 53.83075337256155, 58.622720856820386, 64.81488427808209, 67.83282649132514, 66.50700261515956, 65.5412091747407, 66.87883546275478, 66.77747357276179, 63.82776098866617, 53.598753021609404, 47.977216013016246, 46.13984054134738, 46.07470173989573, 48.522562749924205, 47.318987384919204, 48.008653809947354, 45.308454959623276, 48.9959849849824, 48.40435035767094, 51.12358839281144, 48.44277781824912, 50.91348663453133, 56.54876762820829, 63.0693236474068, 62.60315387479721, 65.83266873513499, 60.36626931159728, 58.01898179515716, 67.73541835046584, 67.5451441734068, 66.55760119038244, 60.23262239271595, 62.62176552126485, 61.22554686761672, 57.38411088143626, 54.47332389893071, 49.90386855217719, 46.960267020810036, 45.308776593977406, 45.6597149756647, 44.83558577875937, 43.25635717761132, 43.78444548576109, 45.89624566416587, 45.51535998621295, 43.86026097882179, 43.33296498944683, 44.115058145215436, 53.76655986232143, 63.04593063169911, 60.21328903013661, 60.31321533264653, 59.76393053608557, 60.4010489679152, 60.209441184997566, 60.969404328253965, 59.29942777079921, 61.30660264722763, 60.79387826304282, 57.28977395642189, 57.26157603725311, 61.825402782809356, 60.91036089005009, 58.18450189405873, 59.15374702022922, 59.47806819792717, 55.97553283937516, 53.151512607451416, 48.58492059092368, 54.932884477799945, 55.25105145669753, 61.83814264112904, 58.73832879527923, 68.2366580347861, 21.92440971251457, 0.1418504794879306, 0.632489177007829, 4.0810025891950055, 10.048459306839975, 2.147801162735109, 0.3949474363077072, 0.10268061076320949, 0.07609682352913004, 0.24928491863031543, 24.230157367644775, 58.622167802626095, 19.872021675109863, 45.749839275114, 27.819375145819883, 0.06620142668966325, 0.02597144166488321, 0.0143626460903174, 0.023733154915633704, 0.0774962056968962, 0.042052607788073446, 0.05016789974404439, 0.03457395404937767, 0.025139094796031717, 0.07030378155890973, 0.009387928707104538, 0.05979418521746994, 0.04146760006645515, 0.05615921292994773, 0.04129831378738727, 0.01715227961540222, 0.07013374068323644, 0.015019859514018942, 0.05031840920808816, 0.013230572109140698, 0.04493846482927761, 0.05675236416620113, 0.05015411016140735, 0.02300918650543017, 0.17147583496426383, 0.14565150133304058, 0.13881536170599923, 0.10509420907305134, 0.13525093845542402, 0.14600479044020176, 0.20795861199017496, 0.12762444889954022, 0.18727414610405124, 0.08877318848164813, 0.14307674110656785, 0.15788181925252562, 0.17603516128034363, 0.13487888019411795, 0.0988527988233874, 0.17033840890132612, 0.2414997799261924, 0.1347987627189967, 0.08480543526069773, 0.1476525996000536, 0.12205204025151269, 0.1780582462707835, 0.15533828476984657, 0.1976776967245725, 0.10830836926376629, 0.29229223668094606, 0.2276909684822444, 0.3419841315236784, 0.3172062739970223, 0.21895876124260888, 0.3350757957706529, 15.350447681642349, 73.95819587092247, 53.14077708028978, 47.210930009042066, 77.91456514789213, 13.836950159841969, 0.4896171805599044, 1.4697912864146696, 0.668074083664725, 4.897172806724425, 11.176755562905344, 15.261510879762712, 20.792052822728312, 3.917933726503003, 0.9862006131199099, 2.533620446920395, 42.91938635610765, 76.99342004714474, 74.15373386875277, 72.07158288648053, 69.57991292399745, 69.5361549623551, 68.06267738342285, 72.76988244825795, 72.44361969732469, 68.56936916228264, 64.11281924093923, 64.49478357068955, 61.82652850304881, 55.341254203550285, 56.84364749539284, 56.46054960066273, 57.58834477393859, 59.18886792275214, 67.08354396204795, 72.19683985556327, 67.04921537829985, 66.68050473736179, 70.9596929242534, 70.69166952563872, 66.9525367982926, 55.748341314254276, 50.12377623588809, 47.30414513618716, 48.21036954079905, 51.34739099010345, 50.13111499048049, 50.22948803440217, 48.32211002226799, 51.50306201750233, 51.76512733582528, 54.711266640693914, 52.543113770023474, 54.78861970286216, 61.89879425110356, 66.01163864135742, 65.53836545636578, 68.48222194179412, 62.07245719048285, 60.27664315315985, 68.7122767971408, 68.78962593693888, 71.31133341020154, 62.724370802602465, 63.70840326432259, 63.362458059864665, 59.70773081625662, 57.88220482487833, 50.072208835232644, 49.798843168443256, 48.54007613274359, 48.57743278626473, 49.14569793208953, 45.20906602182696, 47.26412911568919, 47.346871514474195, 48.11309476052561, 47.05303892012566, 44.98729128991404, 47.58590467514531, 55.383811919919914, 66.79369649579449, 62.724566921111084, 63.20650462181338, 63.231082193313114, 62.82401469445998, 63.21862474564583, 63.838167036733324, 60.43298098348803, 65.61709919283467, 63.07295968455654, 57.11074913701704, 59.07773540865991, 63.17241530264578, 63.87083253552837, 58.63468016347578, 61.37937438103461, 61.294141277190185, 58.066987683696134, 56.36918583223897, 52.29014050575995, 56.51596092408704, 57.35126887598346, 65.99491365494268, 61.86918035630257, 68.18758918393043, 22.594460364310972, 0.36340836255300435, 3.595222191464517, 6.7084453951927925, 26.978024782673007, 13.690153494957956, 4.176456899412217, 0.2179736794242936, 0.37409535038375086, 0.3766626029485657, 35.07366934130269, 63.60755128245201, 34.669425948973625, 56.426436747274096, 32.19693637663318, 0.16492069638784856, 0.15596272303692757, 0.11243982781325618, 0.09069349511616653, 0.1514305621986428, 0.1435330230742693, 0.07980465843913057, 0.12979682144378463, 0.12981013605190864, 0.16776118187173722, 0.10255078950356092, 0.15146669090515183, 0.08787915621313357, 0.12250425429233622, 0.11128537161576171, 0.11543438890047612, 0.16869266817886985, 0.19315716510097827, 0.156573417686647, 0.07982643065793861, 0.10031297772882447, 0.14104573476699092, 0.18082924757993993, 0.13277884933256334], [0.06490740459412336, 0.027490465699004072, 0.05533350421296013, 0.10073153752713435, 0.027236649278371085, 0.03155132924627153, 0.014092330051015222, 0.04229813130692609, 0.068632690987039, 0.027847410960783883, 0.010631111292769353, 0.02503086572452899, 0.05392097980685292, 0.07877856793422854, 0.06550756553488393, 0.06579972848656677, 0.07646138945053663, 0.0586781406684989, 0.04454890911978099, 0.01286633464793164, 0.011914705974049868, 0.061141270393085104, 0.04019051234448149, 0.03722697015731566, 0.010316235749351402, 0.00967460934207925, 0.018797409382738897, 0.023761159259705775, 0.06330036663360174, 0.007130607545766379, 0.02350198596926226, 0.2861273126496423, 31.690766273006318, 55.70734470121322, 25.39757828558645, 49.32965709317116, 40.405629527184274, 0.7870029213447726, 0.062496989379606904, 0.17951457941484067, 0.018107560613463004, 1.6641495088415763, 3.233195269300092, 2.9452962404297245, 1.9821413293961558, 0.8460277895773611, 0.6581343073518046, 8.404586122881982, 57.77313547749674, 59.65874825754474, 71.4219364043205, 68.92436719709828, 67.39257966318439, 67.19945784538024, 65.73502132969519, 63.05503445286905, 61.92494861541256, 59.94504205642208, 55.783893677496145, 54.907695016553326, 55.09003031638361, 54.110383064516135, 54.21592227874264, 57.399172782897956, 62.68517847984069, 62.950985739308024, 68.11302492695471, 63.68666548882762, 60.29125398205173, 63.857116007035785, 64.6875915988799, 61.122172801725334, 55.37150744468936, 48.00043644443635, 46.700339394231, 46.20512839286558, 46.8073808762335, 49.00471618098598, 46.725328814598825, 47.05777714329381, 46.55217578334194, 47.30575723032798, 46.80347419554188, 50.08843568063552, 51.79580027057279, 58.058268254803075, 60.692371245353456, 61.77211346164827, 60.875914635196814, 58.95696955342447, 64.56316224990353, 62.25648303185741, 57.59081194477697, 54.400108937294256, 57.36336546559488, 55.74705477683775, 53.59460315396709, 52.26534720390074, 47.368907390102265, 44.45809295100551, 43.35888793391567, 44.86372486237557, 44.1022123829011, 43.65261854663972, 43.198694413708104, 46.13849516837828, 45.31506023099346, 46.0173527656063, 43.2522229994497, 43.70549994130289, 42.27929869005757, 51.85800513913555, 58.556883873478064, 59.93700119756884, 57.4244289244375, 60.04420349674841, 61.59502237073837, 60.05404080114057, 57.6475098056178, 58.6083100688073, 59.29170070155975, 58.74981349514377, 58.78569925985029, 57.77417098322223, 56.7182767775751, 57.4219342970079, 59.73898426178963, 58.95810311840427, 56.727843438425374, 53.80690536191387, 50.08524679368543, 50.70083141326905, 54.934508339051284, 61.83059992328767, 59.06940037204374, 68.32174208856398, 33.02072432733352, 0.21459900083080416, 0.413458694613749, 1.1517148897532494, 3.361606314297646, 5.552642537701515, 1.688919153905684, 0.2037673143129195, 0.07227239003705402, 0.07257167760643267, 5.965182723537569, 53.90165805816651, 31.4879483561362, 33.71010441933909, 44.75230209289059, 1.3201553158221708, 0.12475082245204719, 0.022561275963521293, 0.08728664082985732, 0.057195806500291636, 0.010324512371763347, 0.016464891903583082, 0.04908140320631285, 0.044426063090683, 0.028439719500320575, 0.05870878418547012, 0.06931159810553636, 0.04701597653629799, 0.056903766122676676, 0.15366033771105353, 0.0567457911318108, 0.017897326934842334, 0.03406169786748867, 0.01415999189409758, 0.08995336991163994, 0.05491806622294169, 0.012150709892833426, 0.050861473615852096, 0.025161317091495283, 0.03698791242054394, 0.05492082030902948, 0.02511211509455837, 0.11185245287995185, 0.06256565000982055, 0.011226540682987582, 0.021499075904308308, 0.05473115992161536, 0.03322352873041265, 0.013517173262493265, 0.012040186387997483, 0.023207584125620705, 0.008974708541626892, 0.06041916740697719, 0.03729326357584327, 0.050908304570663365, 0.033014674010055686, 0.06565084695936212, 0.04589212938181816, 0.03254642191853735, 0.030392774478382165, 0.050807112016745155, 0.02854636660025966, 0.0788245408705646, 0.04298895875352525, 0.0767346223696105, 0.037347617514070966, 0.04333969295745896, 0.0009497958683735511, 0.05442221964439077, 0.02861038856809178, 0.019142851834335638, 0.4362728542858555, 44.450601223976385, 57.16240282981627, 24.050846215217348, 68.83470965969947, 42.08251730088265, 0.7946968955859062, 0.05614581022171244, 0.2465925179421902, 0.22486156062974086, 0.9732361378208284, 2.0226380853883685, 5.555908401166239, 7.8159864294913515, 5.276269393582498, 1.1779847188342003, 9.858935283076379, 66.13367142215853, 61.73722005659535, 72.55787049570392, 72.32412861239526, 68.82313866769114, 71.67365058775871, 67.46784210205078, 64.9563955491589, 64.6401426869054, 60.81086604825912, 57.74948358535767, 57.59934309990176, 56.839497627750525, 56.30521589709867, 56.262564043844904, 59.260698287717766, 62.38799618136499, 66.02271541472405, 69.1415802125008, 66.2056076911188, 63.959364352687714, 66.07005842270391, 68.5385864011703, 61.50557664132888, 57.247871275871034, 49.3199453046245, 49.142771843940984, 49.222729359903646, 48.47538840386176, 49.381079366130216, 49.899557867357814, 50.326990312145604, 49.881338457907404, 50.28950029803861, 49.47170572896158, 51.665432453155525, 52.260981605898955, 60.93680158738167, 63.18033849039386, 63.45946219659621, 61.96288185734903, 58.37223045287594, 64.2735226692692, 64.30251290721279, 59.08104196671517, 58.608070804226784, 61.35401625787059, 57.53704801682503, 57.53832278713104, 54.78597210299585, 50.33833380668394, 47.38087846386818, 44.66251903964628, 46.411907903609745, 45.708285685508486, 44.967208754631784, 45.123240640086514, 47.578475706038944, 45.67449446647398, 47.25155399691674, 45.80114779933807, 45.72850942611695, 42.87961352256037, 53.90614132727347, 61.26060108984671, 60.49990446336808, 56.96817098125335, 60.70689578210155, 62.32619139455981, 60.40381423888668, 59.14237214672951, 61.99236631393433, 61.88495612913563, 60.821860451852125, 60.25424249710576, 60.977872725455995, 59.07337373302829, 58.12073199979721, 60.9405670627471, 61.77855007110104, 57.15276164393271, 54.923831647442235, 53.21126991702665, 53.638686672333755, 56.07104255307106, 64.0720344358875, 60.98654116353681, 68.66113693483415, 36.32426215756324, 0.26539231560403304, 1.5835059458209624, 1.748125738193912, 5.198895248674578, 4.21383414537676, 0.534231107561819, 0.2083356957882643, 0.19812058747535755, 0.10089793182428806, 7.423578298860981, 60.640795999957675, 43.375079477986986, 29.313825638063495, 54.563507033932595, 2.5944436605899566, 0.14635501519566582, 0.08700753967728346, 0.034705690528836944, 0.045589781291182005, 0.05011152333369659, 0.057900312446778825, 0.0602535123846704, 0.0941731277552824, 0.03231766423390758, 0.04920821757085862, 0.0072960346569156944, 0.029625334408915335, 0.04867505101907638, 0.09538104156813315, 0.022067497822365934, 0.04976855343087547, 0.021584345320720347, 0.06998359511095671, 0.12461805941476939, 0.038351234829714226, 0.016959068410459067, 0.008244728256437567, 0.042524291953492555, 0.06294751802699701, 0.1553215074443048, 0.0884419397240685, 0.14073868672693932, 0.16254202402647466, 0.11778922826652566, 0.11454520596852226, 0.14109960606982633, 0.11907442502917782, 0.13529731741835996, 0.13773592849892957, 0.08714593346080474, 0.14421390669961132, 0.10549457428315956, 0.23043910972774032, 0.2123400833337538, 0.26567549234436405, 0.17926399205480853, 0.1595931524230588, 0.1513330085623649, 0.10980098433191739, 0.09606106717499996, 0.14469839602468476, 0.29997000050160194, 0.1338524296278915, 0.1484866088797008, 0.16354644190399878, 0.15417205380095592, 0.08928140354973656, 0.14991914733282982, 0.12662886401578305, 0.07688731135379884, 0.5657709474044462, 49.951454747107725, 75.40731553108462, 38.21533095452094, 61.80243338308027, 57.17483282089234, 1.197559674901347, 0.27124556442422254, 0.7392505159781826, 1.050443214274222, 8.026541711822633, 12.445142211452609, 11.825672484213307, 9.11748670762585, 1.638150568450651, 0.8400633354340831, 10.147798234416593, 66.04945028981855, 66.80059202255742, 75.95676898956299, 77.25845459968814, 72.27062748324487, 74.35965830279936, 71.81171801782423, 67.68990316698628, 68.80377000378024, 64.84286254452121, 59.34505670301376, 60.990636117996715, 60.11635157369799, 61.09443772223688, 58.153075864238126, 62.543165145381806, 65.76133651118126, 68.0302393820978, 73.06500942476335, 66.10307693481445, 64.28972598045104, 66.92079697885822, 68.7087937324278, 65.55052872627013, 59.9657404038214, 53.7225430242477, 54.68143309316328, 52.86337137222291, 51.139289640611224, 52.95295438458843, 51.77456848083004, 52.00360744230209, 52.57348468226772, 52.682565796759825, 51.452726241080995, 55.44195321298415, 56.99468228124804, 62.491338868294996, 65.18517955656975, 65.08633582822739, 63.3487807550738, 59.18874240690663, 67.31005299475886, 68.70953898276053, 62.55069217374248, 59.64798919616207, 63.16169938733501, 59.73550904181696, 59.3264764355075, 56.972556191106, 51.79094045392929, 49.77162191944738, 47.21193413580618, 50.31517221081642, 48.86031412309217, 46.35595529310165, 47.39347711686165, 50.76659779394827, 48.98498273664906, 50.62531402034145, 49.793426375235285, 48.30388276807724, 45.57273641709359, 56.92951994557535, 64.26995723478257, 59.86040123047368, 57.62398342932425, 62.2948791134742, 65.98149914895335, 64.19258063839328, 62.16289527954594, 63.73860159227925, 63.53312038606214, 63.22362184524537, 63.20835598053471, 62.43658650305964, 58.75720716291859, 60.92116309750465, 64.88797764624319, 63.13201488987092, 60.91838605942265, 57.72646711718652, 55.59761247327251, 55.18017030531361, 59.989906126453036, 65.84079588613203, 62.86456415730139, 69.23808620822045, 38.34532222440166, 0.253977007983673, 1.1117045076624041, 2.4402158202663546, 8.902215265458631, 15.30196620571998, 7.649194502061413, 0.8988904304081394, 0.4181270505632124, 0.4131731276790942, 11.892693042755129, 65.41728188914638, 44.72641052738313, 44.87918684559484, 63.28679946161086, 3.896408004145469, 0.39178260451843666, 0.13225746521305654, 0.13861377332960406, 0.3025872326425968, 0.11495864829949795, 0.11469820904875956, 0.15599856063002543, 0.1844845288583348, 0.10933882646983671, 0.17787602459711416, 0.17850476827832962, 0.13160636708621057, 0.13448816003097644, 0.2262147630174314, 0.09099693488209479, 0.14027333427821437, 0.14657434616838733, 0.19779401951499526, 0.15823783563269725, 0.2212261516721018, 0.2970023597440412, 0.1381211941160502, 0.15017509730833192, 0.19450811519017144], [0.061611081473529346, 0.03990726665623727, 0.02166460452210759, 0.07993794241619688, 0.026960872947388602, 0.08184485783379886, 0.023342153215180003, 0.007603441800681815, 0.03827234309527182, 0.03652445986987122, 0.02447715652505717, 0.028393934255525954, 0.03995861752980179, 0.04598688296673279, 0.03803156166067047, 0.03602836814318453, 0.0358502297181516, 0.014080409722913419, 0.07778243912804512, 0.10972501139246649, 0.01280053344089538, 0.024130034425686446, 0.0413930865245, 0.058576411853033694, 0.025682113238520203, 0.06104769275313424, 0.05444394206748374, 0.029276685879355478, 0.094771649267885, 0.04815490796200691, 0.00586815066673162, 0.06981022941369204, 3.7840367565231943, 46.32691014197565, 36.213859204323064, 32.35860078565536, 69.94165743550947, 21.610861324494888, 0.09079241238894964, 0.1541136012923333, 0.13286071348815195, 0.7464115994591868, 1.5815049241627417, 4.501132071018219, 6.991942053841007, 10.386987309302054, 0.3354069602585608, 0.2642418966898995, 18.743942129996515, 66.72066980792631, 71.52747169617685, 70.96887127045663, 65.62623831533617, 63.59877301800636, 63.29531492725496, 62.25769504424065, 56.1105094417449, 56.893300779404186, 58.00024071047383, 58.16441935877646, 53.80201024393882, 57.278089215678555, 58.891446359695934, 59.846625866428504, 62.78572843920801, 65.70292457457512, 67.70642419015208, 66.79011929419734, 65.13986833633916, 69.55371933598673, 63.04884887510731, 59.42938766171856, 50.35851440122051, 47.16058638788039, 45.49578735905309, 47.76755748256561, 47.54234675438174, 46.47697218002812, 49.28526370756088, 47.672396859815045, 48.44121279255037, 46.45989810266803, 49.05509902584938, 50.13170334600633, 54.86277211096979, 62.53563027228079, 63.3432972815729, 64.20280625743251, 63.585758593774614, 60.87387108033704, 62.86281085783436, 61.2154624539037, 58.951368408818404, 54.31011799843081, 51.64703261467719, 50.12974608329035, 44.78863108542658, 45.12392705486667, 46.12277823109781, 45.40909121113439, 45.42251748423423, 46.767364855735536, 44.44255252038279, 44.43311922011837, 44.34610143784554, 47.040318673656834, 48.89114787501674, 49.063383071653305, 45.00065480509112, 44.14219310206752, 43.57517526995751, 49.27188058053294, 60.31372524076893, 61.07273132570329, 60.57546500236758, 60.640799922327844, 59.77553682942545, 60.69995318689654, 60.804586333613244, 58.5460542094323, 60.81402747861801, 61.30393935788063, 57.347758354679236, 58.58892179304554, 59.67058597072479, 60.736297868913226, 58.78881362176711, 56.8146494127089, 55.816053190538966, 52.900798628407145, 52.510165860576016, 56.66541499476279, 58.23538287993401, 57.87258717321581, 62.28148814170592, 44.026294908215924, 2.1982046000419126, 0.1097516099651975, 0.3890569862579146, 0.39697162446475803, 3.2604182343329153, 3.634101214908785, 0.05054301852660795, 0.05772642197928602, 0.08674075721853203, 2.4976331908856673, 42.87432224519792, 39.359490256155695, 19.419919483123287, 49.7348653885626, 12.948493111518122, 0.0066340815429876175, 0.008735125077017134, 0.047623691103991964, 0.005365966625827095, 0.03537420183420181, 0.04089579970065144, 0.020611379182927554, 0.021638664784991456, 0.032137273510377255, 0.040365314456604184, 0.03408225583693674, 0.03671305922551021, 0.03716590528887126, 0.03250229142365917, 0.021283881806377924, 0.047537724547568834, 0.049915734242888234, 0.036986732645140546, 0.009926948170628279, 0.04039766251920693, 0.04649365395908395, 0.026120643033796263, 0.02849722972079631, 0.08377973546063708, 0.017362919320622762, 0.0473731535396749, 0.014872737116210405, 0.011156207108269296, 0.040008367279604565, 0.04054766636522066, 0.036761567912875645, 0.022347121829948118, 0.02380170254787851, 0.058111863796629255, 0.009088659332314087, 0.021706817881955255, 0.05390892541336437, 0.03276944543505388, 0.008085263224558966, 0.011003038361518374, 0.015721892911730515, 0.024711958643409516, 0.0578083512523482, 0.013822974494448113, 0.08323957452610617, 0.009614119039578064, 0.06713513465177628, 0.04018814130235584, 0.03570342045878211, 0.061899004128551295, 0.07505527336991603, 0.04572830147921078, 0.012293021258477484, 0.07806763067961701, 0.009008713269365892, 0.03103100424332004, 0.020818152059350285, 7.313244967691361, 59.44643036011727, 28.990841988594305, 37.50229112563595, 80.29483979748142, 21.08496169890127, 0.13256080538755463, 0.1937853265553713, 0.0076342667847300975, 0.32398630534448936, 0.1755153859454778, 2.5219582598055563, 14.285622239112856, 15.21652521625642, 0.982448437040852, 0.6706472197847982, 26.28562838800492, 68.39630634553971, 75.41895712575605, 74.86838971414875, 67.41876540645477, 66.96413916926231, 67.01600859242102, 65.55769097420477, 60.59382953951436, 58.950438807087565, 60.16973110937304, 59.88083285670127, 56.97802005275604, 59.80821017296084, 59.13579040958036, 61.95315830169186, 66.62005316826605, 66.42282070652132, 69.7720149255568, 66.8409610563709, 65.89727017187303, 70.40071595099666, 65.84435739824849, 62.82047279419438, 53.87538602275234, 49.995808909016276, 47.77464520546698, 48.236139512831166, 49.37930253244216, 47.61780138938658, 49.441927094613355, 49.128886653530984, 48.097864197146514, 49.33745084270355, 51.661439480320105, 52.053354863197576, 56.6450539711983, 65.35672833842617, 65.88039613539173, 66.60852139995944, 64.67184328263806, 60.93845290522422, 63.24426135709209, 62.27496916247953, 60.90919202373874, 56.24938095769575, 54.87688087647962, 52.56458090197656, 48.606536772943315, 49.382342369325706, 47.689172837042044, 48.18007707595826, 47.26074018786031, 49.66825962066651, 46.270937919616706, 45.58018892042099, 46.5535839142338, 48.63671156667894, 49.90752027880762, 50.58848688679357, 46.700245257346864, 45.20397086297312, 45.018407452491026, 51.50220694080476, 62.049326973576704, 64.64972503723638, 62.26726170509093, 61.5201953149611, 62.56292604630994, 63.966118674124445, 62.798460452787346, 60.95417376487487, 61.95359368478099, 64.80511365398284, 59.54049271921958, 57.86952380211123, 61.18675070424234, 62.75680880392752, 60.94008068884573, 57.69609620494228, 58.16015574239916, 56.131333304989724, 53.15138316923573, 56.979290900691865, 60.75176377450267, 59.432635384221236, 64.96201630561583, 47.25221295510569, 4.112143756881837, 0.29679943837465783, 2.2156093822371576, 4.032968263472281, 4.103291457699192, 0.9146489202976228, 0.07831190547515308, 0.0462451235451285, 0.14197144477117446, 3.562087724285741, 43.06199589083272, 56.87816043053904, 20.757547732322447, 51.508478810710294, 21.51911512497933, 0.10307686208116432, 0.05640166060578439, 0.012099119616792569, 0.0833445668761288, 0.059707659416862076, 0.01837776173957654, 0.04410688787879002, 0.04044891380134129, 0.046116685074183254, 0.04984749496103295, 0.008097876862232244, 0.05565614980315009, 0.006163078238211212, 0.06180940248492745, 0.026270775199537317, 0.06933337798522365, 0.033017087187017166, 0.0546780661980231, 0.05710123677647883, 0.00496506706939169, 0.06046371158933448, 0.034960468389814904, 0.10160800339954515, 0.04232987032962903, 0.0733003881008875, 0.202436451049101, 0.16479858197271824, 0.07363190498924063, 0.15149263064226798, 0.13961710336227573, 0.2046872326923955, 0.1995753271565322, 0.07760510509533268, 0.11308960826887239, 0.12493263809911667, 0.09845207355195477, 0.08809515470338446, 0.13886134230321454, 0.1249259118471415, 0.15962037918788774, 0.135302588103279, 0.10929136732292753, 0.23945501464749538, 0.11269609954568649, 0.17901619325482077, 0.121029588664251, 0.14267589326106733, 0.09716313061935287, 0.10845470737906233, 0.1716314427434437, 0.14979266621653112, 0.17956098902129358, 0.12716252852471607, 0.12483026576979507, 0.1528066706152693, 0.27407086604545194, 0.2911384163364288, 8.624504593110855, 71.4535036394673, 47.80417673049435, 43.254870599316014, 86.87223096047678, 33.39542050515452, 0.5529987295308422, 0.7404692086481279, 0.3340831296818872, 1.779328315488754, 7.3864319824403335, 12.524352515897444, 13.893224404704187, 21.58003149494048, 0.7114415243268014, 0.47081989566645316, 25.463925177051177, 73.85692027307326, 73.90659316893547, 78.83731057566982, 70.07966995239258, 70.12298860857564, 67.95424738237935, 69.34574742471018, 62.69789088156916, 62.51984665470739, 63.853319152708984, 64.75136933788177, 59.12751420851677, 63.40512560259912, 64.27071032985565, 65.60443385954827, 69.58290177006876, 68.52921978119882, 71.93046385242094, 69.12682425591254, 69.70725659401187, 73.76453276603453, 68.78473866370418, 65.82815016469648, 55.815072597995886, 51.99906533764255, 48.839031342537176, 51.312897666808105, 52.109370231628425, 48.76247059914374, 52.936029357294885, 52.42460720000729, 51.54278386023737, 51.31592573658113, 54.62320158558508, 56.780254148667865, 60.957370496565304, 68.49814676469373, 69.93287132632348, 69.50729416262719, 66.6056816039547, 62.22398227260959, 66.24838506021808, 64.55994590636223, 65.07681623581918, 60.836698778214, 58.15524101257325, 55.62842269097605, 50.17609673161661, 50.83568249979327, 51.27347784657633, 51.53637862974598, 50.17306473947341, 55.28055552513369, 48.49032871184811, 50.13740647223688, 50.45632262383738, 50.510616071762584, 53.98227845468829, 52.97444505076255, 49.24654991396012, 47.240598817025464, 47.47687062909527, 52.73811048076999, 65.79491984459662, 66.77490049792875, 65.58736370455834, 63.74819963209091, 64.73084749714022, 66.36065898403045, 65.02971249241983, 62.73502788236065, 66.11275734439974, 68.29852165714388, 59.56379159804314, 60.18518524785196, 63.707842365387954, 65.83530456789079, 63.253988835119436, 60.543489840722856, 62.671971859470496, 59.73066491465415, 57.46360948008876, 61.80366108494421, 61.841358984670336, 61.13595993288102, 66.30445926420151, 45.8679614528533, 3.543375812230572, 0.15894275909710318, 1.5674613680570357, 5.0062166586998975, 17.37162640017848, 8.960850777164582, 0.5554760740168634, 0.14021437615156174, 0.21901168259641818, 4.702798772242762, 56.79806955399052, 52.26487259710989, 30.600006118897472, 63.41330766677857, 24.77091100908095, 0.4228997476879628, 0.2300218369571432, 0.135257342950471, 0.2700254315089795, 0.15937235056152269, 0.07869447446278027, 0.13827876308031622, 0.12292708886126358, 0.17660984979762187, 0.11959784694256322, 0.08548375249149338, 0.1764409427320765, 0.14408324274324602, 0.1668879182468499, 0.07660246454179287, 0.15907254971323476, 0.17826729634356114, 0.23702038722413205, 0.08798126041168168, 0.1612639901859145, 0.12285667005926372, 0.1427896419960645, 0.23395200590452842, 0.12929426776545663, 0.10671916583012189], [0.0633440642888027, 0.04741289052030733, 0.09185115356118449, 0.008148285447649898, 0.05723643214291623, 0.039450180296215324, 0.03713711953511642, 0.018037674242570516, 0.06317986100311242, 0.004879308793122971, 0.11231214393891635, 0.06846629668988528, 0.025786552090017546, 0.0682185285334145, 0.012024751631543042, 0.023654447042293126, 0.021475758103113023, 0.04968871557784658, 0.06546620444785203, 0.042980792256252426, 0.04060599246933576, 0.008922118520844848, 0.04441303576553061, 0.04352968659312014, 0.1216900866899279, 0.02489487171143053, 0.04176864580762002, 0.03614405508063013, 0.03257485910228664, 0.039557413453416485, 0.03828394549688505, 0.13551079547933995, 0.010337986900741536, 16.518656015396118, 55.53345034199377, 33.750242033312404, 41.234936252717056, 59.540069103240974, 10.709134513331998, 0.09311611794175641, 0.08476168397934207, 0.06907050257488605, 0.05352941311655506, 1.500178868732145, 24.369160282996393, 16.343475118760143, 1.4966348847073894, 0.3871678440801559, 0.935866246300359, 31.963084666959702, 74.74150103907432, 69.95050630261822, 70.71012035492929, 73.97292829328968, 66.82870757195258, 59.064395427703865, 59.3712346015438, 61.45751583960749, 60.315666814004224, 61.3625434906252, 62.06405547357375, 58.44704966391287, 57.35807418823243, 64.93122177739298, 66.54668915656306, 70.53737917254048, 69.21130426468389, 68.08911415838426, 68.48479501662716, 66.12746623254591, 63.79376972875288, 59.52527784532117, 52.044372635502974, 46.633529663085945, 48.44356621465376, 48.11058836598551, 45.874103884543146, 47.27870856561969, 50.28016113465833, 53.467910597401286, 53.23700066535704, 53.59937275609663, 51.13414349094514, 53.420865689554525, 56.7232777995448, 62.596383863879794, 64.31482522718369, 62.648971080780036, 60.49039271570022, 62.23218394863991, 62.44406646297824, 63.48300426237045, 60.4277563864185, 58.276442250897816, 55.59902060416437, 54.871311110834924, 50.613001700370546, 48.9548824679467, 45.655408213215495, 45.699405439438365, 46.123841193414506, 47.941616581332305, 44.00895018731394, 44.72188411220428, 48.080017412862475, 49.53336146570022, 54.89408046968522, 51.44435982550345, 46.138479478897594, 45.61600408246441, 44.24603393000942, 46.872802088337565, 55.574054718017585, 60.5497891672196, 61.528389146251065, 62.98520449669131, 58.02496733204011, 62.829647218027425, 60.032036304473884, 63.1630055366024, 59.291277085581136, 61.25840456255021, 59.6997291811051, 58.837729500186065, 58.51993514645485, 60.3794563201166, 61.865230529539055, 58.18752604146158, 53.63174407712875, 54.411805445148104, 57.96845382259738, 56.939729875133885, 57.794269207985174, 62.93478635049636, 49.988089684517156, 6.018708367501536, 0.11358683763612663, 0.2826525216862079, 2.36082288046037, 3.3958338970138184, 2.25553126585099, 0.6824919809737514, 0.04550640028150332, 0.08162831542112174, 3.3763485425902955, 27.483484937298684, 53.77620104820498, 29.982430896451397, 38.5921020661631, 43.68342876434327, 1.568037221027959, 0.18440303242494985, 0.046003606666119835, 0.10553694660625151, 0.020803299529718298, 0.046202747391596924, 0.04692282790558473, 0.015087235989349504, 0.11391999395263773, 0.054194488517579534, 0.01925159801518725, 0.008607856805376228, 0.025965268911433317, 0.03578012501220069, 0.05626932657774418, 0.0170460730160196, 0.04348621493385684, 0.042459990363568074, 0.022740823990334908, 0.02911291351812261, 0.07168648599256432, 0.04815952747219032, 0.07669054933132664, 0.05151348338732797, 0.07961899703068119, 0.015912792446362158, 0.056664819468653975, 0.039892668850840106, 0.02936611132275674, 0.013874611693374334, 0.025019615723360932, 0.06488714922940539, 0.0401843032018552, 0.06653439148419327, 0.039307235950423826, 0.061822621332060915, 0.012488314307354873, 0.04458833583480409, 0.06934421046847297, 0.0673221980011271, 0.026252756811558243, 0.02256924902359324, 0.03399195322286218, 0.08751005505121524, 0.05313086736526701, 0.025597144511618444, 0.030480730948188615, 0.00659536489570934, 0.0670052750877315, 0.029796350131472273, 0.047224632073794647, 0.04890801069597083, 0.04160947571959227, 0.051656626915979775, 0.03375807424045859, 0.09929117731629841, 0.08706573171601181, 0.05762194673861227, 0.056992030942872654, 25.828697758336222, 59.9062890391196, 29.68010440949471, 58.967622710812485, 64.57459595895583, 8.49779438587927, 0.05386386029121857, 0.12388295974702605, 0.13825116859328362, 0.46736603422511014, 1.6913885310772927, 8.644229212114888, 15.38834366106218, 5.436236887208877, 1.1566081691172816, 1.5362548683920216, 36.188151990213704, 78.99865335033786, 72.58675482965285, 73.27958660741007, 73.88700485229492, 68.66398457557925, 62.1165995444021, 60.70121226772186, 62.07434385053573, 63.082055660986136, 64.24511686448129, 65.24753347519906, 62.57724661980907, 61.124028082816835, 67.34848437770721, 68.88002087993007, 72.87308000749158, 70.74433126757222, 65.75272690865302, 68.8432212029734, 67.13100464113298, 65.67037282451507, 60.92657989071262, 53.79618552423293, 48.69552750741282, 49.13662548988096, 50.05524458423738, 49.0654815396955, 49.61184024810792, 50.706048165598226, 56.52949310118153, 55.58029128659157, 53.85254606123894, 52.236274596183534, 54.448154049534956, 59.29459933311709, 63.30585825827814, 65.88445971089025, 64.3151350944273, 60.11915606837119, 61.039610831968254, 65.45253222988498, 65.69158108003678, 62.58207897986136, 60.89622466794906, 58.57652318093085, 54.569174858831595, 50.89967596915461, 49.23144094405636, 47.13670699827133, 46.084244866524976, 49.57930418752855, 49.64194443918044, 46.413963225580034, 47.902306587465354, 49.20398827522032, 53.07954888189993, 55.57170914065454, 54.55925126229563, 48.92062056449152, 46.95214771455335, 46.72776068410566, 49.738317074314246, 58.75329263748662, 61.680639866859686, 63.42006591058547, 60.54422724631525, 60.246076122407, 64.56841430356427, 61.42554460033294, 63.99872141499674, 62.25378444117885, 61.309709164404104, 59.681603908538825, 60.691712287164506, 60.578897076268355, 60.86537914891397, 64.5705206163468, 61.13030779746271, 55.7724246671123, 56.802807777158684, 60.92010013518795, 61.28357833431613, 60.03000059435445, 63.13425456323932, 53.319029192770685, 7.948557148056646, 0.01733751967549324, 1.7018195842542958, 5.184659986726699, 4.97662139515723, 0.3916572725340244, 0.2781878225505352, 0.09849307457766227, 0.10396961498284533, 4.34877299493359, 27.72775838452001, 65.02523314568305, 32.67665597700304, 32.58059713148302, 55.71701334368799, 2.507671026452895, 0.10363822832943932, 0.0384893068563073, 0.11459215949740141, 0.13223370116564537, 0.02991973433733708, 0.11334708275934381, 0.022890959986515587, 0.10354399185387358, 0.02781508396559906, 0.015580393599286197, 0.016595061733237198, 0.03267649981764055, 0.029513456843673225, 0.049208941523947065, 0.03018875568804722, 0.0501301201180585, 0.021722459482149254, 0.03130252495588314, 0.03750897095268292, 0.02088773582551268, 0.07429526818375434, 0.04143565803045227, 0.01988132994982504, 0.05486850033424074, 0.03093032688353091, 0.16654478746556467, 0.16271001178651087, 0.15227711999848967, 0.08225339720205915, 0.1360341561056914, 0.16661531351987394, 0.22887478882987655, 0.12128851872177855, 0.11522526987978529, 0.12727695907796585, 0.3332667863897739, 0.15174701779840455, 0.19942008709955603, 0.1850862909228571, 0.1298457284968707, 0.13878073453182174, 0.19551467811388357, 0.1701722291087912, 0.16794599292259063, 0.08378537386775979, 0.11190551979046677, 0.10092266114248384, 0.07765898405904732, 0.07872027630407004, 0.1880078591526516, 0.10286044990343433, 0.14776974976543458, 0.11581632203512615, 0.1362899068983332, 0.2334023378188572, 0.16404347974927197, 0.1693385722295892, 0.1024315019528712, 31.706551851764804, 74.78893818393831, 47.78832251025785, 53.00018756620346, 72.674576697811, 17.82547796926191, 0.4782332672226814, 0.2482348419125042, 0.4225759989311619, 1.6039323013636375, 7.143870159502953, 42.22850399632608, 33.36892489464053, 4.750925763960808, 0.8193726489140142, 1.6537001921284584, 33.30865767694289, 77.28602101725917, 74.71687639913252, 75.27078567012664, 77.89229393005371, 73.75617027282715, 64.74996905173025, 65.16127271036949, 67.00694007258262, 67.27638336919969, 66.20131661815029, 68.6865068251087, 65.15437718360656, 64.56687281208654, 70.67244991179436, 72.26733269230013, 75.81121767720869, 73.18160580050561, 68.40756354793426, 71.31636188876244, 69.04356802663496, 66.46908898507395, 64.32647074422529, 57.001930821326475, 51.230818148582216, 53.04183137032294, 54.4856087623104, 52.030252102882635, 52.627727139380674, 54.593226832728234, 59.68514580880443, 57.84144747641779, 57.33702282751761, 55.47404604573404, 58.47141934979347, 61.56654596328736, 67.61779431373843, 68.21842685822519, 65.76074423328524, 62.125789657715835, 62.14011023121496, 67.2881975481587, 68.43508289706323, 65.11739315525179, 62.256200621205, 61.795667294533025, 59.26657792060607, 56.48517424060453, 53.30636778185445, 48.100676536560066, 48.41652147231564, 52.186280065967196, 53.122043840346805, 48.4303125258415, 49.980519510084584, 52.22504485038019, 55.664445738638605, 59.74962565206713, 56.81684986237557, 51.44648182776667, 51.35809906067387, 49.619637920010476, 53.69232900681035, 59.55318158672702, 63.58890041228264, 64.44621286084576, 63.86683564032278, 61.28489232832386, 65.6655090855014, 62.5221686978494, 66.87341474717664, 61.63285363105036, 64.11162291803669, 63.47124499659385, 61.20598600756738, 59.191315481739665, 64.88947599164902, 67.87590980529785, 62.7319880454771, 56.84544001856158, 60.92787819523966, 62.53094303992487, 62.33624050694128, 61.97272308411137, 67.46082105944234, 51.55006377927719, 8.597415724108297, 0.29356397327876865, 1.1900424524661035, 4.266415478721742, 10.779316502232707, 9.391036725813343, 2.0280038877840965, 0.23138167366625803, 0.209580113690707, 5.707722758093189, 38.8785292256263, 65.33829712098645, 43.06347854675786, 50.64262343991188, 60.1549163172322, 3.075463036375661, 0.4990069670302253, 0.18281533052363705, 0.2755785577239529, 0.17750084069707703, 0.15239929570065391, 0.20670866293291892, 0.13307345610472465, 0.21554429204233233, 0.1403769246873356, 0.11647907235930044, 0.08036066973281485, 0.12436068451572811, 0.1822656624379658, 0.13035255694581618, 0.08550145678342351, 0.1401319144473922, 0.12425934640510429, 0.08200357592995129, 0.1144737299651869, 0.1562700775121489, 0.2039282080987769, 0.17825853229770738, 0.1874490133336475, 0.1527103120761533, 0.08167847885840362], [0.024796793304924524, 0.027148884330545704, 0.06741929964552965, 0.015743134614651003, 0.05546686862925849, 0.05322766257449985, 0.034622087353660215, 0.012552489492771848, 0.012666194177713367, 0.08936071663253731, 0.027057036134083907, 0.030671816259141893, 0.007396799638011163, 0.035270764642665466, 0.009209702181960306, 0.02985096262437442, 0.03636057834110914, 0.054571200763025594, 0.019870553007950226, 0.011794048083585598, 0.0603502463068693, 0.04552464083498044, 0.0037173293728095993, 0.03713580186388666, 0.028241331456229094, 0.04029490714592319, 0.024678494007657134, 0.10612993696404081, 0.09643258151387978, 0.045121418116914655, 0.02619089521167259, 0.032652800887702935, 0.09162917958512422, 1.3002573770861472, 31.775407098954727, 47.31912466787523, 25.111459032181774, 49.98924678371799, 51.574582515224336, 11.466219617474465, 0.1073326490398857, 0.09895387646411696, 0.04379836894992379, 0.21716272939116726, 10.682801681180155, 14.40218919707883, 1.9204775027690397, 1.006795262857791, 0.1363071438766295, 1.601309216310901, 44.13648213109663, 73.49784297327842, 76.89537648231753, 67.55422053798553, 67.41936945146131, 60.65079412152691, 62.52791104778167, 62.463454738740005, 66.26980120135893, 62.60236547839258, 61.81371411969585, 62.44374482862411, 64.72224573935232, 68.03998254960584, 67.5065480509112, 67.83144581702449, 63.48899372162358, 73.91105682619157, 72.01822296265634, 67.27810136733517, 68.02342230273833, 57.402742139754764, 50.71751717598208, 46.021259446297925, 46.86589087209394, 46.39035055714269, 48.20119903933618, 48.251966276476466, 56.98793188218148, 56.42503646112258, 58.777293620571015, 53.63522714184177, 58.37930248629663, 55.12133475272886, 60.716403607399236, 60.369097340491514, 66.75645751337852, 62.466824054718025, 70.95212274982084, 49.97278459610478, 43.90417975764121, 72.19521599431192, 61.69434462824176, 67.02364152477634, 62.09015492470034, 67.13607234339561, 62.00217616173529, 59.68571455247941, 50.62948349983462, 49.36511531952889, 45.16292718149001, 46.194777257980846, 46.9780824261327, 47.4798986988683, 49.73480263063985, 54.185421928282715, 56.81748920871366, 56.885993403773156, 50.21663442734749, 46.29270707407306, 45.37670812299175, 47.68898456327377, 50.38914418989613, 61.02253675460816, 62.49188407774895, 64.14168396303731, 63.20208803299935, 59.836674813301336, 63.67972289362262, 62.80835267036193, 62.75946817090435, 65.00907690294328, 61.315769226320334, 57.222230742054606, 61.17170449226134, 63.37271505786527, 60.756804020174094, 59.008631090964045, 57.07675003236341, 57.79524195578791, 58.88059708379931, 61.098516987216094, 62.06880546385243, 49.17485290958036, 11.359772374553065, 0.04889309113364547, 0.4624786077728195, 3.6022770645156985, 5.835338052242033, 3.6628965600844356, 0.4734942473230824, 0.045062701307958176, 0.08066972492322808, 4.585963622216256, 29.747263231585105, 59.13770844859462, 31.972480704707486, 35.105754329312234, 52.34677168630785, 7.7401640722828535, 0.1522527124372221, 0.1070423553427381, 0.041702245136783014, 0.029053467010418256, 0.0469508667236134, 0.038181377815142754, 0.058511187127160455, 0.009944888034595117, 0.057714693173165285, 0.020161743027969234, 0.02329975216379089, 0.05092754103844205, 0.045643304024011865, 0.08026708443198474, 0.0757414506628148, 0.038353019814577796, 0.07869257456472806, 0.04173794100361486, 0.027627241121785297, 0.019094835358461546, 0.023911331645062855, 0.03209190195306175, 0.11657811986703066, 0.04053487269688518, 0.01427821266735273, 0.07047357728644725, 0.04714358380184539, 0.0009279769062319951, 0.03505374342503567, 0.031782653325447635, 0.043740104132842635, 0.0636473163631895, 0.02399601500421282, 0.0361983324100654, 0.016815223911356543, 0.05627195808976408, 0.036913517622217056, 0.032288200492339755, 0.05534829354033836, 0.014127341226764746, 0.02722620366952352, 0.06482471306357654, 0.04300529174807091, 0.0644866461234708, 0.01295429782100743, 0.04487108739633714, 0.028600168955181877, 0.0037736399474764064, 0.0371216522199252, 0.03171093025875669, 0.04268921153139203, 0.05005665611655963, 0.014351051349583414, 0.050166677833805164, 0.07703553404538863, 0.02565687255663497, 0.023846940039807273, 0.035532594342986425, 0.04855278721680084, 3.1283642880378233, 47.71844940800821, 46.5069979236972, 27.44966430048789, 71.96994643057548, 58.80271842402797, 9.793693519407704, 0.1265356847415528, 0.10567390780535438, 0.10806761081180266, 0.3751076896104121, 3.0554984173467084, 7.5825882438690435, 4.89581125397836, 3.257667427101443, 0.24128665426565757, 3.2701954774318205, 48.08493214268839, 78.633543445218, 77.16114844045332, 70.15372430124592, 70.16321643706291, 62.86733335064304, 64.20679138552758, 65.95940051540252, 67.0565188315607, 62.44595312303113, 64.45614430212206, 66.3744108138546, 66.71260541485202, 70.1941482482418, 67.7384699544599, 69.83452966136318, 65.9373567950341, 71.35829987064486, 71.6999775363553, 69.48918850191178, 69.3449394164547, 60.21232020470404, 51.865504710905014, 49.20086999093333, 48.73796755267728, 48.02867750967703, 50.1729235341472, 49.98926247319868, 56.984331146363296, 57.752390061655355, 60.207429009099165, 55.82637294646233, 58.82632324772497, 58.448022411715606, 62.256416351564475, 63.77319297482891, 69.09841060638428, 65.37736000553255, 69.19706606095838, 51.17579906217514, 47.396716994623986, 71.95017768490699, 63.44374133694557, 68.76500914173742, 63.45048389127178, 69.00325390600389, 64.2404257097552, 59.82402516949562, 50.77296380073794, 51.93698990729548, 47.67936298924108, 49.826354672831876, 47.9130813383287, 48.50853243181783, 51.47544853148922, 56.25921826208792, 58.673746970392045, 58.355442708538426, 52.57079001395933, 48.00709662898895, 47.10513584075436, 48.50595543461461, 54.6436292894425, 63.38714545772922, 65.12625378947105, 67.34179281419324, 60.01349133829917, 61.31470626400363, 63.947130480120265, 65.2465489602858, 62.74743041684551, 65.0189220520758, 60.85836595104587, 59.72885670200471, 61.558497259693766, 62.57787027666646, 62.49950524299376, 59.35758475334414, 60.41967630386353, 60.540814784265336, 61.44966717689269, 63.67993470161193, 63.630732490170395, 53.7789192507344, 13.32360702176248, 0.07238482876170067, 2.0973531084675945, 3.3439598160405315, 4.80665970233179, 0.8889566602245454, 0.3413773286006143, 0.1110900728212249, 0.07549281682698958, 5.616914005048814, 30.811162994753932, 62.287599194434385, 41.32757871381698, 29.916438979487268, 61.75577678988057, 13.605873527065402, 0.12099596506525433, 0.05562788881962338, 0.0799794490599344, 0.011825020060754352, 0.015848216022394838, 0.036902420838633855, 0.05303033747740331, 0.027425219905712915, 0.03163800826446424, 0.054535010769482584, 0.02176375162126797, 0.04671520275634624, 0.03488102890250664, 0.036510934587568045, 0.04617160591747492, 0.07392247447804098, 0.014650837833722754, 0.01758355455803535, 0.08673541758569979, 0.026087925333770055, 0.01872427288382765, 0.04255066069984629, 0.03359064955504672, 0.02143089982470678, 0.03282718165146728, 0.019612454155820514, 0.15770725845809908, 0.1892796876810251, 0.10318492644376333, 0.09589587563588735, 0.20192364711434613, 0.23278022845906599, 0.09844743872001287, 0.1096637320194033, 0.13440799659057973, 0.14827689997130825, 0.12170740027701664, 0.15591645132630103, 0.12131180779467668, 0.16950141187877427, 0.15319979629449307, 0.11160309892147781, 0.11502039498619496, 0.17176347033631417, 0.10862508533342231, 0.10616781235101724, 0.15740244739478634, 0.10007595012505209, 0.14078986140028124, 0.17985384911298755, 0.22582419607187473, 0.21060972053918148, 0.10510811356887703, 0.2235963204575162, 0.15839031777314602, 0.16995999211024854, 0.1459903879872253, 0.16804745360728235, 0.1516604038976854, 3.5903628651172887, 55.61227037060646, 63.167543718891764, 38.59206676483154, 64.51106140690466, 70.50086190623622, 18.05510920862998, 0.2836670059590571, 0.1745428986126377, 0.31566521152853966, 1.494301564751133, 23.19067043642844, 29.660096399245727, 11.732001381535685, 2.882506693563154, 0.16083937829300282, 2.5881845383874835, 47.91237138932752, 77.0667605246267, 84.35060977935791, 72.87805357287007, 74.50832397707048, 66.34191005460679, 68.56454464697069, 66.82199247421758, 73.03946695020123, 65.77066390745102, 67.11431887841994, 68.00638352670978, 70.28309975900959, 73.81383695910054, 71.2975109777143, 69.93516983524447, 64.57574129104614, 71.28609688051286, 75.43094388900265, 73.79105583313974, 73.18413965163693, 64.14982680351504, 55.01879222931401, 51.763970236624445, 50.527890190001465, 50.33367010854906, 52.73143852910688, 52.5600976328696, 61.46230505358789, 61.279526525928134, 66.12264171723398, 57.62367748445081, 64.7005432651889, 62.06405547357375, 65.56571222120716, 66.26998163038685, 71.22093062247001, 68.05259689208, 72.47161757561469, 51.14195292995822, 47.78388630959296, 76.12160267368441, 66.73350380313012, 72.68222531964703, 65.7384887049275, 74.66997269661196, 69.01982984235211, 64.43364950918382, 54.97272006926998, 55.54880642121839, 50.21544987155546, 53.187527810373616, 52.09844250832835, 51.53040878234371, 54.912597979268725, 58.88901841255927, 62.62940629836052, 62.35045517644575, 55.65774633038429, 51.14227848668253, 50.209264293793716, 51.006788053820216, 55.75225191731607, 66.22077941894531, 67.23034258811705, 68.64844414495653, 61.80833655018961, 61.70664518110214, 66.88249111175537, 64.97285773677211, 67.5121021270752, 67.3350541822372, 63.034967607067486, 59.792034318370206, 63.006550035169056, 63.8152329383358, 65.25308755136305, 63.431115227360884, 63.26692088957756, 62.69589047278128, 65.21286756761613, 68.28556214609455, 65.03465467883696, 51.38191961473035, 14.040656493556115, 0.19038797175932318, 2.091434987321977, 9.045424922820061, 14.115882650498422, 11.910316251939344, 2.03344936332395, 0.28482646471069706, 0.12715835334552875, 8.178157498759608, 44.27007021442537, 66.1091487638412, 46.15111343322262, 45.798496277101584, 70.81312964039465, 15.479257337508665, 0.3632040315818402, 0.23871400844185586, 0.17166035490170603, 0.1301618316961873, 0.11087582867232063, 0.13443128566347784, 0.1712295070530907, 0.07585760491389422, 0.1390662248576841, 0.1484694638319554, 0.10614827710894809, 0.18773451898126833, 0.18112564699784403, 0.2641064217013698, 0.1636640823656513, 0.16028197271929634, 0.16411186075739323, 0.14177226191086156, 0.14696295192885786, 0.21442545127243767, 0.1332284203700481, 0.0767540043940948, 0.19194463177794413, 0.1270525719249441, 0.13383906905449208, 0.1567195872625997], [0.018559424169061166, 0.03527434227327186, 0.047974877299801, 0.08513798636774864, 0.07973514362088135, 0.06412335956889777, 0.027416446283760092, 0.023004907904373064, 0.05671220966764996, 0.016459900840756395, 0.05992507133933325, 0.023371377554271492, 0.030557014153248845, 0.06669473368674517, 0.019013672173323653, 0.03389217410116427, 0.00920230751827119, 0.052831043534341364, 0.07754186453718333, 0.03137108407944682, 0.03445905618249409, 0.02492094551393342, 0.02951260265563765, 0.03241597629723049, 0.08546708241826104, 0.044163712450573524, 0.06000950955034745, 0.1008548240567888, 0.08028226063376473, 0.06394172012205086, 0.02646664472957773, 0.0393198840620537, 0.048438019584864385, 0.05300960713817228, 9.584916541653296, 52.06700471139724, 42.40834466872677, 28.058253372869185, 49.024441780582556, 59.608294810018236, 16.046108468886345, 0.9232646515292506, 0.014980390664160013, 0.1291817600928968, 0.8854960265659517, 8.055580489097103, 6.153248115893334, 3.1525724212969504, 1.4455265239361794, 0.2050852306908177, 8.76143257464132, 63.13518808734033, 71.80715237894367, 76.44093851889335, 67.0101877950853, 66.20737275769635, 67.22419231168686, 65.2866748071486, 66.94742202758789, 67.65767697365054, 70.62080014136531, 62.54525969105383, 64.87821486688429, 69.02226955659928, 70.12265912948116, 70.04405483122795, 66.87148494105186, 69.65151186912291, 68.59896736760294, 65.70945532091203, 63.4738729846093, 54.88085423746417, 50.66339238997429, 48.52046428188201, 50.14956581977106, 50.61807332500335, 49.94080551208989, 57.519252223353234, 62.62593500075802, 61.90627813339234, 63.94876218611195, 58.05675814228674, 60.333615579912745, 54.80620368834465, 63.1988089315353, 59.90373557613742, 66.4245387046568, 60.68123171406408, 69.95101621074062, 42.17299069127729, 32.99943762440836, 71.63866304582166, 62.40926719480946, 68.23131576661142, 61.69141854009321, 67.28145107146233, 64.10044024067541, 63.71658140613187, 54.504938202519575, 48.89234812028947, 46.075297940161924, 47.814096404660134, 46.16120569167599, 47.51987941803471, 51.5008419559848, 58.50637943513932, 60.73830220007128, 61.900033720078014, 56.902106500441036, 50.97577387286771, 46.28494078113187, 46.77340530580091, 46.27826490709859, 56.808440300726126, 60.91873122799782, 62.843908955973966, 65.78358419479864, 62.55738373725646, 61.21346204511581, 64.97594071972755, 61.34706581792524, 61.52873823719641, 63.59483888072353, 63.65058360561248, 59.40764988622358, 61.78111137882356, 63.47555175904305, 61.102580562714614, 58.97596951453917, 61.736070802134854, 63.46896609952373, 62.406866704264, 49.6722565158721, 14.287330431322898, 0.2806897737806843, 0.16086554785649623, 0.6517906090424908, 3.6953583407786588, 5.798208405894618, 0.20418519995385603, 0.028279733528653463, 0.10387347860922737, 6.499591931220024, 37.93548160983671, 49.13555468282392, 33.4828148349639, 33.543364463313935, 49.56556412481493, 21.832545841893843, 0.1271677992096351, 0.016403572310903863, 0.02192183961010268, 0.07702377459575092, 0.014415907395643093, 0.034064436631817976, 0.021938028963162534, 0.07008310993232074, 0.0095756106724542, 0.0437908536273866, 0.023117501761824377, 0.05363011537420173, 0.039896315429359674, 0.08756799428092857, 0.04095841972758213, 0.007362161930124726, 0.041247617918998, 0.023239432315852855, 0.015600987000300761, 0.05859339219187537, 0.04837161125314813, 0.0779153400611493, 0.02426685964418275, 0.11905885812255645, 0.0486112856906989, 0.01502288747653966, 0.07485379224583026, 0.025744761993748047, 0.04654862076765107, 0.01595460456765948, 0.10098685931053855, 0.00933121617567996, 0.03615159338580505, 0.017533370053335544, 0.013619815637808175, 0.0834634943654941, 0.02416124484772163, 0.031439227600311564, 0.07225900648101684, 0.03361694552304764, 0.07395458888382682, 0.02621705519906696, 0.04044232544519248, 0.11563639862522965, 0.012705464802321889, 0.04565406372890838, 0.12821489584542092, 0.04653379313587662, 0.03943419204123559, 0.03131261433384592, 0.1054334634494397, 0.08627214889612891, 0.03785679019206474, 0.0485755630107897, 0.027930181015342958, 0.08467045056843951, 0.12307232380994867, 0.02992495905698067, 0.037708942883557854, 0.036281862806889324, 0.09523791336123982, 16.277958789179404, 64.59836552220007, 35.672238719078806, 29.305976975348692, 69.01264406019642, 63.435531816174915, 14.676973781278058, 1.2844091629789722, 0.034029614105219805, 0.07122867950989355, 0.20650005719113737, 3.1683731992398543, 6.799479194225804, 5.5895863617620165, 3.226015860995939, 0.5254672455691523, 11.828285763340613, 66.33248067671254, 76.45032082834553, 80.32025675619803, 72.28896064143028, 67.84427196748796, 70.17000998220136, 68.44782275538292, 68.7260207822246, 71.08878597136467, 71.25438844003986, 64.19867600164106, 67.72156453901722, 70.53344895762783, 71.18508800383538, 69.7013573492727, 64.73438547503564, 71.30607743417063, 70.24651189004221, 66.9036562212052, 66.41207341224917, 59.446222474498136, 53.01397077498898, 51.038845585238555, 51.7970318948069, 52.572225601442405, 52.234207507102724, 58.38447217018374, 64.95181422079763, 64.70484610526793, 66.49438042794505, 60.20776241056381, 62.37229101119503, 55.73236157817226, 65.7979400696293, 61.16471875098444, 68.70895847197502, 61.46015167236329, 71.71973059254309, 42.592496025946836, 34.16138879714474, 74.57666735495292, 63.05410877350838, 68.5798889590848, 62.66573136852634, 67.14430147601713, 66.54004466149115, 66.03964436438777, 56.71760212990546, 51.66500883717691, 48.85152016916583, 48.91971057461154, 47.56962291656002, 49.24295310051211, 53.77051361145512, 60.46839998614404, 63.57618408818399, 62.64042815854473, 58.671644579979684, 52.96587467193604, 47.89499136709398, 48.248797001377234, 50.07292662897418, 59.25650135163338, 62.40618813422419, 63.99557959648871, 66.49813021382978, 63.925204430857015, 63.1315363607099, 64.9607023116081, 64.13325086716684, 61.607028745835834, 65.43494824440249, 63.56185174757435, 61.52846759365451, 62.695043240824056, 63.55137901921427, 62.621126174926765, 62.139965103518584, 63.348976873582416, 65.92993567066809, 64.20306121149372, 53.12147901904199, 16.617272246268488, 0.36950936420790614, 0.7942483357844815, 2.720720445917499, 3.2119078309305253, 0.674201500031256, 0.08525825451098143, 0.014841153226312132, 0.05949062670791342, 6.971930611518122, 38.42088668577133, 57.47534521164433, 48.129203934823316, 30.000885648112146, 56.06487658716018, 32.979672801110056, 0.15095529657217766, 0.014019430081750599, 0.021902361824627847, 0.1060633026363869, 0.023320721905498255, 0.005965860872229021, 0.06658211876187595, 0.09414627637353637, 0.007205202963368427, 0.05794492174660968, 0.0368085750679095, 0.006458199725696638, 0.044900815438238845, 0.06125835161055289, 0.03581835663006191, 0.035622284086721565, 0.04353918608338122, 0.01829025726164541, 0.05778171820566059, 0.07628788585744559, 0.018582533211297086, 0.07873811083094728, 0.0868193731613217, 0.024640745025188215, 0.018111546185889074, 0.03863952903737945, 0.04020571918977846, 0.11780000712362029, 0.14765008683166198, 0.14662192022848516, 0.27069143770683196, 0.13085558559865723, 0.0938004183192407, 0.11532639348579031, 0.16730609500119764, 0.2021184173082152, 0.12931492149589524, 0.15182008726462243, 0.12034567899160808, 0.10900084379940264, 0.11098674288199795, 0.1620218656476467, 0.15342127231340255, 0.15754866293601452, 0.17727905824299783, 0.08490179379981372, 0.2725360548544315, 0.12024671575354955, 0.09868232127759727, 0.11103728170236273, 0.15636861174096986, 0.11839938665469808, 0.13779674055835894, 0.15684680382330574, 0.12049083733150076, 0.13499694966500805, 0.2730180773763888, 0.08884428144102136, 0.19002947325427688, 0.11302507302213101, 0.25261289650394075, 17.632042361843972, 76.11140451123639, 58.30464409243677, 37.756562694426506, 60.20900187953826, 77.91333352365803, 23.358563569284257, 1.8537925520250875, 0.3037461704544483, 0.24148992803548616, 1.6054720768044073, 26.80688784968469, 22.509038986698275, 11.138468327060824, 5.349319615671712, 0.42882690867108686, 12.17043411347174, 66.87780780176963, 75.72370959866431, 82.91635590214884, 75.72913031424247, 71.47458245677333, 73.6841320222424, 70.8775035796627, 73.13248203646752, 73.41725395571801, 75.25572376866495, 69.01047106712096, 70.48505475444179, 73.38025031551238, 74.82298435703402, 72.33844526352422, 65.1509411873356, 73.21460077839514, 72.25128235355501, 69.92221032419513, 68.02899991312336, 60.75583519474153, 55.17684021303731, 55.23675833978961, 56.21870802294824, 55.54535865783692, 55.574662685394294, 63.49634816569667, 68.19310403639271, 68.41944048481604, 69.23539546228224, 65.28765932206186, 65.58781085475799, 59.57283266129033, 70.15775649778305, 63.8352095696234, 72.43678692848452, 65.4628715976592, 71.15431308746338, 46.20979993574081, 36.96513822001796, 74.02511935080253, 65.47988683946672, 69.36330395360147, 66.15697814572242, 70.6387253730528, 68.59269157532724, 67.93728705375426, 59.85503150570778, 54.55678016908708, 51.12612616631293, 50.70262001406763, 49.86164815964238, 50.32683733970889, 55.58644548539193, 64.49883145670738, 65.49482714745307, 66.82420469099476, 61.62428717459402, 57.44015762882849, 51.32164062992219, 52.652077213410415, 51.44133567810059, 61.26213865895426, 65.11059176537299, 64.0139715902267, 68.33473297857469, 65.04011069574665, 66.18955735237368, 68.31679990214687, 63.78027285298994, 63.876068899708415, 68.63487274416032, 66.49407448307161, 61.58506739524103, 63.129355522894095, 64.75841391471126, 62.56753875363258, 62.66147951925955, 67.54680725835985, 66.33321023756459, 64.37636329281715, 53.211399355242335, 17.151879533644646, 0.448448320309962, 0.5771935635036038, 2.2167272577362676, 7.95590227650058, 16.081328411256116, 2.236136616237702, 0.14759315117712946, 0.2631252775749853, 10.35073382239188, 52.21014768846574, 57.17130661010743, 47.718049326250636, 44.816593662385024, 65.73655889880273, 36.803026660796135, 0.21350372492546038, 0.10962835407906002, 0.09845446374627853, 0.2211268207118396, 0.11555785929123241, 0.12563887923475237, 0.1870463575206457, 0.24353938177227977, 0.11978618199786834, 0.13024541188872632, 0.07601644558411452, 0.07140094970142649, 0.09794625633906934, 0.27250317436072136, 0.19269406495075073, 0.1863844115887919, 0.18051769494289355, 0.16237179928969953, 0.12288322266671928, 0.23296879334074838, 0.1711462332957214, 0.15805683969970674, 0.16728800000442615, 0.1959226046118044, 0.10705351724379486, 0.14740755871659325, 0.14187497897974907], [0.02956665015869564, 0.036954702509026376, 0.02180262100732615, 0.06794502748356712, 0.04614518354496649, 0.052668203885156306, 0.013787742110810453, 0.027068512131189628, 0.01329308392615208, 0.01233006256722635, 0.030370058056207436, 0.05717203096156159, 0.07067285973819033, 0.06544188881713538, 0.011317550970782197, 0.039972522025627476, 0.05010518012568355, 0.09026042561257079, 0.03279368445697812, 0.01002996497141618, 0.0357987217965626, 0.014700405637643512, 0.068785211431884, 0.05699022297537135, 0.01888681567394205, 0.04447668618071945, 0.027165874245486436, 0.025052559419324803, 0.08243778690455422, 0.043914910075404955, 0.03460214991543082, 0.024068820170096816, 0.09451459612577193, 0.03166699703151901, 0.1674624382247848, 20.036878893452307, 57.61080818791544, 46.7068858300486, 27.778060820794877, 50.43148617590628, 61.88377157334359, 19.44073550162777, 1.3351612009348408, 0.08688179400539206, 0.16230398518664224, 0.8453776567212997, 5.171314612511666, 4.871081690634451, 1.234801231372741, 1.00081070656738, 0.08338542234513067, 25.272064401257424, 78.00301459527786, 71.7839241027832, 73.95622684109595, 71.6481787158597, 65.69686059028872, 67.76097651450866, 69.23241446095129, 70.73640807982414, 64.63059956027617, 70.176693700975, 72.08677814852807, 70.99520606379356, 71.21971468771659, 65.59410625888457, 65.66111995327857, 69.17244926575692, 70.64667993976225, 69.05446437097365, 65.60992125541934, 53.461348472103, 49.607458960625436, 47.28405475616456, 48.98348439124323, 49.455063112320445, 55.942851651099424, 61.61040198418402, 64.05532513895344, 63.821547954313225, 65.1890274017088, 63.43879130578811, 61.734996072707645, 57.41207738076487, 60.311689530649495, 60.07944599274666, 66.59874685349004, 60.810089418965006, 74.37526933608517, 54.79641345239455, 37.94343225417599, 62.98611056420111, 64.80344272428944, 70.74684158448251, 65.04648846964683, 68.1417445213564, 62.052515860526796, 61.837456226348884, 58.87110887035247, 55.209258602511504, 47.3037136754682, 48.82346345532326, 48.06634010807161, 51.00175957525931, 52.12753080552625, 57.64778437152986, 60.8889369041689, 62.655999968128825, 61.36337111073156, 59.12938517908896, 51.01632333570912, 46.596392662294456, 47.18227317256313, 52.21684317434988, 61.216647009695734, 65.81265680251583, 63.76168866311351, 66.9635586584768, 67.61839835874497, 63.22555949611049, 64.46314965524982, 64.63105455521615, 61.727971107729026, 62.09516771378056, 62.14894340884302, 61.73703962756742, 63.05479126591837, 60.966305655817834, 64.00121604242634, 64.2258031137528, 64.50187129359092, 46.64764627333611, 12.025697673520735, 0.044510727297634854, 0.11077403856982147, 0.46911970141433906, 3.6080353490767942, 1.0796062816535275, 1.6784313489352505, 0.13669271592891988, 0.04112416285000021, 5.732223353078289, 40.31665840456563, 43.72744168004682, 26.64554899738681, 32.72914709583406, 43.36933712805472, 23.55051455959197, 0.5713712952790723, 0.0798585527246037, 0.0992030312397307, 0.029872589286476858, 0.011000246928644278, 0.056042549230398676, 0.03429342031238541, 0.061563453787276824, 0.03477801305932864, 0.02350783505056414, 0.06847201936667965, 0.02675263109737106, 0.050352281785660216, 0.03180534293454501, 0.024696303636676843, 0.08095100942638614, 0.02024138169813781, 0.022212998986604716, 0.05071803131290982, 0.03909249001392915, 0.049310555426223625, 0.03826292787468241, 0.008176860527225561, 0.040450070594106956, 0.04675929111638858, 0.032178925710820386, 0.01226403249142271, 0.03614695472342353, 0.05270013826027994, 0.023212655627679442, 0.006316968544025816, 0.07562011765736727, 0.02461899387379808, 0.07916822323515531, 0.08603535877961306, 0.04286024449092727, 0.03738184632252782, 0.017390492740237427, 0.02914001196322422, 0.0231201371042839, 0.04447498929596717, 0.09036204717572659, 0.058450984107630874, 0.04403297188541582, 0.04604885181892784, 0.08199736295688538, 0.009101377349467048, 0.01289826519261565, 0.07391223188249335, 0.04762247302419236, 0.04130049330753185, 0.0316863599038052, 0.05181452529805322, 0.0883559080501718, 0.03938636517212276, 0.07204195078943046, 0.013661251418412694, 0.02114078041256195, 0.035337870114392815, 0.04061832648491667, 0.09633135831644458, 0.06577764983258902, 0.5624512126368861, 31.038570250234297, 65.0105752483491, 34.91822188900363, 32.479552953473984, 71.81089432008805, 68.03479717623803, 20.734894083392238, 1.6733505312473544, 0.03316655860192353, 0.055907752229681903, 0.4329954995022666, 2.1163900869507946, 5.7910309587755515, 3.744092319280871, 1.2450653386692847, 0.14919750782991612, 30.012907712690293, 81.00152538668725, 75.16146136868385, 78.57554727985014, 72.2472736912389, 68.23234342759656, 70.35684031824913, 72.968715237033, 71.01698306299025, 69.0578297645815, 71.83926090117424, 73.6616176174533, 72.06363616451141, 73.04949252836167, 64.89820326528242, 66.19739424797797, 68.22686779883601, 71.81087863060736, 71.90338380875127, 67.0648499458067, 57.154860111974905, 50.1103421180479, 49.642246461683705, 52.16571507915374, 50.70186691899454, 57.579476294978974, 64.39450817723429, 65.1545262336731, 64.30276786127399, 66.12927052282518, 64.07146569221251, 64.3686479906882, 58.6796619046119, 63.3055248568135, 62.736314419777166, 69.34261737331268, 62.88385045143866, 73.69870754980272, 54.21569870364282, 38.64130427760463, 63.80414439785866, 65.6689803831039, 70.10692258034983, 65.84462411942022, 71.15427386376166, 66.15680556143484, 63.59812190455776, 62.99370819522489, 57.134961928090746, 51.2678570901194, 51.870972494925226, 51.4115805779734, 53.09404988442698, 53.84831774619318, 60.30702191014444, 63.318598116597826, 64.63978575121972, 61.42750970778927, 60.53711991156302, 51.510667493266446, 47.201288823158514, 48.87574472735005, 55.293977875863355, 63.677087060866825, 69.06518028628442, 66.90221278898179, 67.74193732969223, 68.24449493039039, 64.27467192372968, 63.80643898440946, 64.46277703008344, 63.09252838934622, 61.684613227844245, 62.60075338425175, 63.31782540967388, 63.41971289726996, 60.40137844700968, 65.09024250891902, 64.152921553581, 65.6432927808454, 49.29392822327153, 17.42624540482798, 0.22999071846565894, 0.05399846576995427, 0.7530215286439466, 2.3718263545343956, 0.6569596800592639, 0.15805676309091432, 0.0556903709507277, 0.11631318368017675, 5.86230581806552, 41.892796178017896, 49.41759663243448, 33.333870672410534, 29.650541505505963, 47.67963363278297, 39.56035483268, 2.4266878106901726, 0.14020944254532938, 0.027987855944722414, 0.01584859523591736, 0.10284531200605054, 0.03006726754979501, 0.012781455936360986, 0.005108405471659236, 0.07639017391709552, 0.022570539881745656, 0.060672267535400976, 0.09279734875646331, 0.03361224174319256, 0.038672060961084026, 0.01793779169900283, 0.058819786495258736, 0.07799436203053883, 0.04240824495472255, 0.011421276402900056, 0.04569216894226209, 0.065793109486901, 0.025055179440025842, 0.06683344922719464, 0.022846459854213942, 0.07689511012886802, 0.08036788628106156, 0.049013366937757506, 0.02377302213121326, 0.1523356491159047, 0.09983037298004474, 0.1136337222170926, 0.24096809958498325, 0.11496440928068855, 0.23289068301598873, 0.14725965778193167, 0.14183515772944497, 0.07956107312272634, 0.12313476763665678, 0.18021777152053772, 0.13940114317642105, 0.14724033704448133, 0.1557116300588654, 0.17288732132123363, 0.1694843434398213, 0.1824838136352839, 0.16120539978146553, 0.12093119999213565, 0.11898923605199783, 0.11648889360648972, 0.17328027846111407, 0.18435555029540293, 0.1024204932693993, 0.10982448790943432, 0.17588513062125252, 0.15320898934958443, 0.32536373143234565, 0.16506879650537046, 0.1693786079845121, 0.1431529208897583, 0.19732800823065544, 0.1888343148053654, 0.2541683614253998, 0.4358833751851513, 32.14132697351518, 78.59556705720964, 60.42324958309051, 39.25941098120905, 63.12309934246925, 79.09723820224886, 29.105090825788437, 2.3913053351063884, 0.1764230622399238, 0.4308302592365973, 2.4562529210121404, 13.747197504966492, 14.2769234026632, 7.274698365119196, 2.290433496236801, 0.16061695232506723, 28.482345919455256, 83.6499018822947, 76.30874679934594, 79.13305728666245, 77.47489098579653, 71.78637950651108, 73.25734676853304, 75.42056529752671, 76.03879359460647, 68.65377072365054, 75.71571580825314, 78.499539590651, 78.16041146555256, 73.30063404575472, 64.13365094892441, 66.61024724283527, 70.60496945534983, 75.81583822927168, 75.9044288819836, 70.89833921001804, 59.22428300303798, 53.83512289293351, 52.85671903241066, 53.62734317779542, 54.92671458951889, 62.43233465379285, 66.92947326167938, 69.4742678057763, 66.32596169748615, 68.83187770843506, 67.72833454993464, 69.3697052617227, 61.45554680978099, 67.58881584290536, 66.85315178286645, 72.50693459664622, 66.09847207223216, 78.4534203621649, 57.24746727174329, 46.04577033750473, 68.55898272606635, 66.28411000774753, 76.57499728664276, 69.00820393716135, 74.12313153666835, 66.71131103269516, 68.60012838917395, 67.18551774178782, 62.307905304816465, 53.89775529984505, 55.40667149328417, 54.999329428518976, 56.18228097115794, 57.3854797886264, 61.00153638470558, 65.84936234258836, 67.36389929248442, 64.75102024693643, 65.34528286226335, 55.20276315750615, 49.898592964295425, 52.60084713658979, 57.72342728030298, 68.10376813334804, 71.42095581177743, 69.42046073175246, 69.67890570240637, 69.67847424168741, 65.52034608779415, 68.94237872092955, 67.25193915828582, 62.19097944997973, 63.326250660804014, 63.26086867240168, 64.3281848199906, 61.94591760635377, 63.81783346976004, 66.73828125, 64.86962487620693, 65.66714471386325, 51.575417980071045, 14.613338228194946, 0.16550797939060197, 0.24287650121315835, 2.7397593855857854, 7.71605424342617, 6.48769881456129, 4.164854528442506, 0.17607366485941797, 0.17361919575881574, 9.677290320396423, 53.889192765758885, 54.720641105405754, 39.32666001781341, 44.81276935146701, 57.38271059528474, 48.23532365983533, 2.2018068067489134, 0.3367835589714589, 0.19906328930970163, 0.24992311583651652, 0.19148847238431055, 0.20493720718208822, 0.16971875102289263, 0.10378983712965444, 0.19077503002218663, 0.09336136566895632, 0.18795936578704467, 0.14423313550651073, 0.18117792483779693, 0.19620567409982606, 0.0851316814641318, 0.15241809549831575, 0.15196078697279577, 0.06602239960263814, 0.0922156505346779, 0.1500532433630959, 0.12654195134077342, 0.11954738473099087, 0.14881988777027977, 0.11306862512062635, 0.15346155321646124, 0.21256480756546223, 0.11992917996981453, 0.25304887714164875], [0.02470946119677636, 0.020129758857130524, 0.07139207074238409, 0.06722585478376958, 0.05302084947846109, 0.018571461325571425, 0.08361901787500228, 0.020231309557153333, 0.04400448107551183, 0.04962663564290251, 0.02568251734990026, 0.018088287756507917, 0.1200091595491094, 0.10189749270437226, 0.009699770542342336, 0.04435390909953464, 0.03215813025411579, 0.04919908197236158, 0.0272467099280367, 0.014391292033026056, 0.10549645885945329, 0.037698290430970734, 0.011830441090428542, 0.009669056162238121, 0.04872043789815038, 0.02029854717904762, 0.0759577019620807, 0.012881271447235299, 0.024951575624365962, 0.03714130237518299, 0.059124808232750625, 0.08946953942218135, 0.046045461879862894, 0.02662108422467305, 0.09737834769992099, 0.6393071143857895, 23.91762487349972, 48.254001986595895, 43.01817124889743, 23.476846564200617, 41.39478068197928, 68.83125797394784, 31.24365333587893, 3.7097899663832883, 0.048011756772475864, 0.10441851952383596, 0.9007636073135561, 5.599551143184786, 2.6849974595731307, 0.10429395362734796, 0.17021076333138252, 0.6859603367986218, 40.66566305775797, 82.36343506843814, 71.89594699490455, 76.5236299268661, 75.93438794535976, 71.81232990757113, 72.25675013757521, 70.37540097390452, 76.48318244564918, 70.4494474780175, 68.72052946398335, 71.33838991965018, 69.53730029444542, 70.40434806577622, 71.82677207454559, 69.04700402290591, 68.0594139714395, 66.55969573605445, 62.1941134237474, 54.93965448871736, 50.31093605103032, 49.25656372501005, 50.67644603790776, 54.97010384836505, 66.61242808065107, 66.22863984877064, 67.81126130011775, 66.54255497840144, 66.88707244011664, 66.55902108838482, 64.09169727756132, 57.85447759013022, 60.901374739985314, 60.55937936229091, 66.74831467290079, 62.79003520165721, 73.58672388138311, 49.63702970935453, 36.35384859577302, 72.4471341409991, 64.48236926909416, 66.73850090272965, 60.535413680538056, 63.462211778087, 58.44525321837395, 58.262878694841945, 55.68823883610388, 53.56661704278762, 48.28800893598988, 50.19957996183827, 49.05840950627481, 51.305896236050515, 53.29567932313489, 60.784703839209776, 62.0210192280431, 67.190961991587, 63.80507007721932, 59.179764101582194, 61.453507177291385, 51.67111988990538, 47.342662811279304, 47.455493711656146, 53.110935688018806, 59.03543656872165, 62.16597041776104, 62.51679112834316, 61.88965120623189, 66.57327498159101, 62.48162707974834, 61.89970424098354, 63.801657615169404, 64.21433802573912, 62.439226258185606, 55.286544984386815, 57.66529383197908, 64.07842789926838, 65.07555715499386, 60.76107940366192, 37.53090873841317, 5.6631886574529835, 0.16253843873498902, 0.09056685312140374, 0.5177165808216219, 0.9988193069734882, 6.238993579341519, 0.58417575013253, 0.041172993294293844, 0.08477990155018146, 6.878940040065396, 44.614905388124534, 50.4589976802949, 59.92934080862231, 57.604555929860766, 34.863430300066554, 38.6719262215399, 2.894601567137626, 0.049440866982143734, 0.06947097503730366, 0.059150613904480016, 0.06162852912600483, 0.03158259520968122, 0.01828269788905257, 0.05033029506223337, 0.06663853347661995, 0.04174848620389258, 0.015243273735376857, 0.06143998339652054, 0.05654963048835916, 0.03476906898281267, 0.05147605999222687, 0.027240403109200062, 0.027041934625876528, 0.02833148851359804, 0.0759418439420481, 0.06107338351167499, 0.03785096792384021, 0.04529311757294401, 0.0611468896480097, 0.014792084337152062, 0.06052540464987678, 0.022999179481919256, 0.04206439022034888, 0.007982822904934087, 0.05172676609588727, 0.016159743761583682, 0.029190422463861686, 0.06747902386010655, 0.0719672572168131, 0.026405284917282484, 0.027758732453108798, 0.040561651300278403, 0.0103771397393317, 0.003030471458670593, 0.033665189910079205, 0.07757518170101028, 0.04750492449309077, 0.019203460880465085, 0.07066462429300432, 0.03709188587362728, 0.11759639627510503, 0.041829764302219116, 0.06894896272569895, 0.04234089050441981, 0.028476844121131207, 0.05248737649150914, 0.02954403332795107, 0.03261250849332541, 0.012308291306028203, 0.03758438081750947, 0.06027891586023954, 0.016880368197997733, 0.07466207108189983, 0.042156619545553005, 0.05907131231299812, 0.021923519257876663, 0.07148409322384866, 0.057707373203048785, 0.01759468006991571, 0.02227291472316269, 1.8302564923801732, 37.44955485866916, 58.744765404732, 32.2211628960025, 27.836780663459535, 64.23993541348365, 69.68493046299105, 30.52759328196126, 3.922841592181114, 0.02734206489197189, 0.13812300208355152, 0.34304611324783296, 2.357066965872242, 4.957731260407356, 2.6808902477064445, 0.17594001316014798, 1.475028018316915, 48.7929238811616, 86.71481055598106, 75.77863847055744, 78.74460143427696, 77.22844062312957, 75.30565554095854, 71.49315095716908, 74.99814171944895, 75.98573961565572, 72.96295719762003, 72.95581063916607, 75.19169499797206, 71.14045927601477, 69.13654388919954, 69.63856020281392, 71.48652999631821, 70.77769494825795, 68.73325363282235, 65.73882210639216, 55.96177708718085, 54.56620954698133, 51.05855549535444, 54.321900798428445, 56.81046816610522, 68.11276605052333, 66.77276672855501, 68.57844552686139, 68.74149845492455, 69.94157114336568, 67.03188634687855, 65.75473908455142, 60.46138678827594, 63.26610111421155, 62.399896652467795, 68.19490048193163, 63.97191593723913, 73.8026346698884, 50.409564049013206, 38.52533548108993, 70.00004583789458, 65.14354751956078, 69.43614236770138, 63.33694696426392, 67.4437665939331, 61.757071172037435, 62.13056318221554, 60.69083367624591, 55.205708857505556, 50.60640427374071, 50.21335924825361, 50.37561985754198, 53.92858120702929, 55.717056489759884, 63.18470801076582, 63.255883339912664, 68.63808124296128, 66.75376676744031, 61.72977932037846, 62.90078332347255, 53.82450111450688, 50.67023300355481, 51.29662767533333, 56.45871393142208, 60.51231484259329, 66.01054037770918, 64.88816592001146, 66.22419188099524, 68.2928499098747, 66.26387842239873, 63.846902155107074, 65.0905562985328, 65.05407041118991, 64.16579085011637, 57.55033700696884, 59.64389424170218, 66.12785846956315, 66.16945912761074, 62.94698099936209, 44.092312320586174, 10.019155279282602, 0.42993623462896197, 0.3716638485991186, 0.315531789655647, 1.7805614106116758, 0.47813995771350404, 0.2557907671096825, 0.053108037945123455, 0.059408210969019326, 5.914702800012404, 44.49183317922777, 58.617178547766905, 57.51425120138354, 48.77577135639806, 37.34116408132738, 51.29866730782294, 8.300163803562041, 0.11011824432399966, 0.047060356009751565, 0.013588221214200943, 0.06716996100881407, 0.07106276784813212, 0.05973929501769524, 0.052874683732948, 0.052100670629090844, 0.06620417694531142, 0.029773024669397744, 0.026689218169438745, 0.054704611144599416, 0.024927635376732198, 0.04685470736735771, 0.0258961467132453, 0.022972293626216632, 0.051923819231770696, 0.03138355790607391, 0.0717929722140393, 0.04269006188898798, 0.046104408515196656, 0.027459416155432983, 0.06672268057422293, 0.04083740464862316, 0.032066328022929455, 0.027935273584819613, 0.028598456748671112, 0.04947900666945404, 0.10468063650712853, 0.08502851240336896, 0.27306848596180644, 0.28212122438896087, 0.1568050979967079, 0.11202992480849067, 0.24149204243815717, 0.10616882358707729, 0.10549737050408318, 0.2304451924658591, 0.12989655076976747, 0.14418946849482675, 0.2934227985960822, 0.16184283089974236, 0.12249868483312669, 0.2839313369364508, 0.1384079255043499, 0.10280446419792791, 0.07237922865897417, 0.09607200691055867, 0.1374537323511416, 0.15123145594712228, 0.10890539690491655, 0.08861946527876201, 0.13698917663385793, 0.20089165007154788, 0.14404276265732704, 0.1164545652066027, 0.14316539280116558, 0.11576594409322548, 0.19311527541327864, 0.23536929920796426, 0.1237917646405197, 0.16931033422870023, 0.19235951435421744, 1.117529472516429, 38.71827686986616, 70.99861068110313, 55.89069981728831, 36.73784079090242, 54.193266668627345, 82.04178502482753, 44.458406740619296, 5.67985039564871, 0.28354427867358734, 0.5466167881123482, 2.988917899708594, 14.521601834604818, 14.071904055533873, 2.882010513736356, 0.3218152121670785, 1.3036548850997802, 45.056383840499386, 90.1284493169477, 79.35805228448685, 81.98148250579834, 81.70304129200598, 78.56560799383348, 77.83192865310177, 76.39778460225752, 79.97544903909007, 77.60883208244078, 73.55105384703606, 76.0150004971412, 70.20922583918419, 70.56246665216261, 72.05668572456607, 74.7237091679727, 72.13937713253883, 70.60115691154235, 68.27791352425852, 59.72401257484191, 56.09767152417091, 54.02096871406802, 57.83957258347542, 59.84427636669528, 73.42232165798065, 69.96344227944651, 74.01934562190887, 72.39226802702873, 72.78436383893414, 71.29107044589135, 67.75375935339159, 64.93660719163957, 65.35488090207501, 66.0288578464139, 71.96329409076323, 67.4806760972546, 75.83184149957474, 53.515637997658025, 40.657288797440074, 72.78664665837442, 66.04016996199086, 70.1235455851401, 67.32604057558122, 71.0189599375571, 63.47659510950889, 63.79628004566316, 61.54199192600866, 58.45668300505608, 53.444501892212905, 53.47487280445715, 53.20712789412468, 56.305968992171756, 59.822719020228234, 66.2660357259935, 65.07153280319707, 72.23482408831197, 69.819365778277, 62.864446486196215, 67.28628343151462, 58.020256565463164, 52.05947768303656, 52.477916133019235, 57.944076291976444, 61.73179149627686, 69.60839717618882, 67.59289510788457, 67.80380095205, 71.21518827253773, 66.04872857370685, 67.1782535122287, 68.37618458655574, 67.13581346696424, 64.10852424560055, 58.31983150974397, 63.49213161776143, 62.63796098770634, 65.55086997247511, 62.234847237986905, 44.2256768288151, 8.10342114779257, 0.4913715219065067, 0.3557944598217165, 1.3541444919763075, 8.694934671924962, 15.948775833652867, 1.2239127317743919, 0.27182518654773313, 0.15670578235820418, 11.102085401934962, 59.35023030927105, 61.88499927520753, 68.83825548233526, 64.76331687742665, 48.25689277341289, 61.0760731850901, 9.442802206162485, 0.23343112740305164, 0.15852274373173714, 0.1863442839033181, 0.1486437488347292, 0.11709135281102312, 0.14111278278212394, 0.1972457610311047, 0.22875754673394466, 0.15599503662557374, 0.17738220432112295, 0.15324804451196425, 0.10980014163520067, 0.08923059659859828, 0.10892072632428139, 0.06015737601105244, 0.20719140557752502, 0.10461967889099352, 0.16316401081219797, 0.12740509494418098, 0.15389457675478152, 0.14304320177724286, 0.15620741151994275, 0.19901750789534664, 0.19634893254166652, 0.10089194867759944, 0.07355331968996795, 0.1302426539721989, 0.09159294362630575], [0.04935970379700584, 0.05087346289186709, 0.019052719674824227, 0.04572309974220492, 0.027030372443879326, 0.04517906240277714, 0.026794947879088503, 0.05612696445877514, 0.023343409599375822, 0.09528530356023582, 0.12597876180323864, 0.020277029684474392, 0.05222550848679197, 0.09110818617045881, 0.031163397643174377, 0.03640582349391715, 0.03735801715764307, 0.016410290901999802, 0.06848754796890483, 0.022804317357499274, 0.05730447607235082, 0.018563331217474995, 0.03998080343608895, 0.019945909246622075, 0.047743319563807986, 0.030472212050470616, 0.049372382552152684, 0.04334234362167697, 0.04525050776259554, 0.03815324706656318, 0.010949090449890543, 0.0627684181616191, 0.029968013198325233, 0.03154689551240975, 0.03868294707048805, 0.11259369657284791, 1.3500344609060597, 20.91547412257041, 57.00878320201751, 40.785346338825846, 26.560023676964548, 39.82552666817942, 61.89911196308752, 44.86561152242845, 6.31645989994849, 0.0780114304694918, 0.0655859133469001, 0.8105769176636973, 4.4056316729514835, 2.0945003196116416, 0.2383869961504975, 0.08744112245978848, 1.3832774061349131, 40.07755071886125, 83.31806936571675, 76.48449251728674, 72.59647446293985, 77.03200048015964, 78.25727047458773, 73.56516653491606, 70.33306291026454, 74.96902988803002, 76.20339978125789, 67.06298289760467, 68.51113765470444, 68.12818881004088, 71.3057714892972, 68.93452613584458, 72.11723143054594, 70.39424404021233, 65.54643377181023, 59.29527398078673, 50.83524319433397, 51.036456861803615, 52.36184927725023, 57.896403804902114, 64.38228214940717, 65.30869891566616, 65.31295076493295, 68.00119030860164, 66.71943033895185, 67.9036880308582, 70.23008500376056, 63.61196787126603, 66.41459941864014, 60.67564233656853, 73.5343994632844, 62.462191735544515, 78.95780578736337, 44.645174318744296, 43.00443903092415, 78.40904266603532, 64.61376866986676, 71.78000957735124, 63.67259202464935, 65.08852451078354, 61.168994134472264, 61.20993191196073, 57.518232407108435, 57.17321288201117, 50.09811216785062, 52.847619133610884, 49.921699646980535, 53.3479017596091, 52.567091218886844, 60.14573012628863, 59.200140814627375, 65.87150019984092, 62.6312655018222, 65.06342918642106, 58.29627375448904, 59.020861041161325, 50.928901549308534, 50.42866206938221, 53.87986536948912, 59.75788616365003, 58.70016021113242, 62.75827184800179, 61.99771642684937, 60.9598925805861, 65.64284563064575, 65.67783709495299, 60.71548185040874, 62.1100256519933, 70.68295401911583, 59.53999065583753, 56.14384958820959, 64.52917883473059, 54.60823774337769, 22.559113925503148, 2.861287896671603, 0.4509354094343801, 0.36106128365762774, 0.4990508179030111, 0.44921817738682995, 0.31853209640229907, 0.3971236775959692, 0.14507204774887333, 0.08066818508650027, 11.801130214045125, 47.93903566175892, 52.197784377682595, 26.785128501153764, 46.836147539077274, 42.624777132465, 36.569241631415586, 11.914530838689497, 0.04102365211433461, 0.1457648976675926, 0.01119776163250208, 0.04556554226925777, 0.049057213980103695, 0.05745037368709042, 0.071750431351604, 0.07676799315959215, 0.014649832343322136, 0.052963913823928566, 0.01102998933469456, 0.03952846299075792, 0.034383987226793845, 0.05945184733718634, 0.039920784277661193, 0.048563213673450296, 0.03761798143386841, 0.002727945491994521, 0.017688324742559946, 0.016564897021218654, 0.06929701179145806, 0.06594670245484, 0.07183117701882316, 0.026806073390968868, 0.04998973067549448, 0.0410786840403753, 0.06866836770167274, 0.05894764273938152, 0.049695434168942516, 0.06657271120216578, 0.03281289794211907, 0.053924289306685816, 0.011502300734601675, 0.0460644340473077, 0.028761773287589033, 0.06262517887197676, 0.06465963643765257, 0.030429251754896778, 0.0755453857803537, 0.029536782305747755, 0.038019461301906456, 0.06378974743007172, 0.06899155721428894, 0.029926108188867092, 0.01749664571346535, 0.0175450126745648, 0.02881188692915584, 0.04129741746451586, 0.013065972372949606, 0.014102526681287395, 0.04394556125325542, 0.013341178926038406, 0.056276466517198476, 0.02822821220052579, 0.03653351119869659, 0.028833115225537654, 0.07543533725003082, 0.02284494683056349, 0.09108037717880742, 0.02953153460346643, 0.07004052310460998, 0.05047901954141356, 0.036989088365507704, 0.03802821002600174, 0.10996253695338966, 3.327813134078057, 33.69048864610734, 63.566036916548214, 30.843677482297345, 23.98531125437829, 60.42684247416835, 72.64299377318352, 43.75867943609915, 5.888316525566963, 0.0824246101922566, 0.06093660617367395, 0.28624905934256895, 2.099949227225396, 1.310140401605637, 0.2648198947070107, 0.14044712898471665, 3.0798033841194647, 46.70187696333855, 85.79082565922891, 76.43037165364912, 76.97359638829386, 79.4373312304097, 80.75682440111714, 71.55168056488037, 73.96902161259806, 78.21108064343854, 76.52668937560051, 68.10801213787448, 67.46790485997354, 68.55368752633372, 71.53049976594987, 73.19370239011704, 74.33164473502868, 72.10576242016208, 66.04250769461355, 60.70372258463214, 52.509436299723966, 51.597559759693766, 55.0188785214578, 59.70301220493933, 64.31646477791571, 67.93501207905432, 68.2665386507588, 66.9355764696675, 67.76583240878198, 69.85725587414157, 71.20308383818596, 65.27212673617949, 68.64518857771351, 63.95129211487309, 74.6011507895685, 64.81309959965368, 79.40722311696699, 45.995728738846324, 43.36839968158353, 78.24395010548254, 66.73043650965538, 73.3548725804975, 63.866976845648985, 66.17374235583891, 63.95304149196994, 62.78703851084556, 58.84377779499177, 60.213512605236424, 51.708111763000495, 54.494030091070364, 52.47262485565678, 55.11748690758982, 55.829910924357755, 61.90292842926518, 62.550707863223174, 67.35582705466979, 64.92114913079047, 65.31076600474697, 61.18958657787692, 59.14965991050967, 52.854212637870546, 52.156313157850704, 55.13299595925116, 60.93459721534484, 62.42207373342207, 64.02353825107699, 65.05310158575735, 62.989421044626546, 66.56283363219231, 68.04182606358683, 64.97052392651959, 64.36594547763949, 69.3848220763668, 60.50139104166339, 58.20647501176404, 66.57405161088514, 58.84095761083788, 28.551671851065855, 3.906025410659852, 0.4423037742174441, 0.7176207282370137, 1.6554805804644863, 1.0850191524913235, 0.1267911137772664, 0.2261935883472043, 0.12379482133133758, 0.10596474542492822, 10.060589236597862, 47.28849487919962, 60.42985877683086, 34.1654327607924, 55.01663492571924, 51.53022835331579, 43.953676146845666, 20.27245644600161, 0.14061310959439124, 0.19066595442352757, 0.043683195291387464, 0.12476495677425016, 0.05693666193814528, 0.02702920032935518, 0.017052883537666454, 0.0796508739492105, 0.026529370093598004, 0.03542333871366517, 0.037730297584447174, 0.04492349930167679, 0.02451197713643553, 0.10832249592509001, 0.03343381220474839, 0.019656402704816674, 0.04638233755324637, 0.04773490025752014, 0.03845066538140659, 0.051899132048410755, 0.042006389703601606, 0.044717617002466035, 0.014663016716499003, 0.0018102334457404552, 0.01299058261793107, 0.01763763653504993, 0.0075065594489475895, 0.029150532265644402, 0.05913406257487594, 0.12495408090011728, 0.1588501084235407, 0.1944928240752028, 0.11470075246066817, 0.14138215461805945, 0.07866045249806297, 0.17711431869576055, 0.13319478911017218, 0.1700235007991714, 0.2915556584635089, 0.2581688112789585, 0.12163235430395412, 0.1953378956644766, 0.23560130127495338, 0.10587184194235072, 0.13263992694837431, 0.12731826653884304, 0.1928605052131799, 0.14400957572844722, 0.0762481029115377, 0.08778750145387265, 0.13874017783711035, 0.12752152498691313, 0.12386761500590271, 0.11716557140912741, 0.138592001110796, 0.1402163373366479, 0.14560314586326, 0.092300180676243, 0.22701769977086977, 0.17297793420091753, 0.1564328558743, 0.106910971263724, 0.17040997683521242, 0.16566085989677137, 0.20814932191804533, 2.1717327688970873, 34.189461200468, 76.50065268239668, 51.26985749890728, 38.357724758886526, 52.23640795676939, 73.56015374583583, 60.71614080859769, 10.917172124308925, 0.2545388721890988, 0.16550840839983957, 2.4272384134031113, 15.827099007944907, 10.387080465593646, 0.4925101124230893, 0.39995253386516727, 2.545095831155777, 42.691249539775235, 87.14340009996968, 81.42991096742692, 79.99917937863259, 81.58642922678303, 84.22354067525556, 76.30915472584387, 77.5565625775245, 77.49879390962663, 80.07532827315792, 67.94603393923852, 67.38676671058901, 69.2742661506899, 72.44787939133184, 74.999098777771, 76.45418044059508, 77.61382918204032, 73.78135188933342, 65.55000312866704, 56.25562929338025, 55.49045332016484, 57.96951286254391, 63.03913316419048, 69.48842756209835, 69.98601944215837, 69.53035769924041, 71.5605765004312, 69.60682822811988, 73.56038124330583, 77.14122279997795, 70.41376959893012, 72.99865861092844, 66.28229002798757, 78.47115732008412, 68.16279195970105, 80.58555802991314, 48.69454299249957, 47.56413159831878, 76.87836124051002, 69.15255500424293, 77.94821123923026, 68.46105683234431, 70.90405802572928, 69.248409886514, 66.50274292115243, 64.15225867302188, 63.710297769115826, 54.67047006853166, 59.062344028103745, 55.06126365353985, 58.61546054963143, 58.357207775115974, 64.29700589949086, 62.44577661637337, 70.32317069268996, 66.60821545508601, 67.91665538664788, 64.20865451135944, 63.44148205172632, 57.11142378468668, 56.18983153373965, 60.08310948648761, 64.6244296719951, 63.66099749841998, 66.64894534695533, 65.94885718437934, 64.2844464701991, 70.07356674440446, 70.04359199154761, 64.89180587953138, 65.54698682600453, 73.38032876291584, 62.55736020303542, 61.13023327242944, 67.79582285111951, 58.11776668794694, 26.517314949343284, 3.9822657454398374, 0.4516085249281699, 1.0158102791155539, 1.8316455017174444, 1.385943514685477, 3.0579383767420247, 1.205729359099942, 0.6628048696344899, 0.18601658213282787, 18.41600452699969, 60.052860167718705, 62.01237040181314, 38.9002630787511, 54.24408489657987, 53.43500583402572, 58.184988267960094, 20.1859171928898, 0.2895249738808601, 0.37347776094271296, 0.11870592907671967, 0.3890609086280869, 0.125811992123002, 0.11606720816944877, 0.2568578203358958, 0.11468635766857094, 0.16019834656148188, 0.19514907031289994, 0.10147828939220599, 0.13330804754889783, 0.09429297455015684, 0.315492382092822, 0.1854794012803224, 0.11435318603030137, 0.13231896675161778, 0.09939079938997185, 0.11769742028967989, 0.17443544712037812, 0.14061353860362885, 0.09785674662599642, 0.2606658901899092, 0.17515910909541194, 0.11246309390351658, 0.18893879387647877, 0.12770452807026525, 0.15771508787668523, 0.11112365811582535], [0.04594388628198255, 0.016192308244025035, 0.05277634102610811, 0.05518995082726883, 0.03885229846702949, 0.017045358639030207, 0.028665769064138015, 0.00600589327551725, 0.03996976410910007, 0.047735463332144484, 0.02004845586094645, 0.07029563038339538, 0.06804846467510348, 0.0272939411637884, 0.05200994666665793, 0.05190118133360821, 0.00576810485067507, 0.04709339738192578, 0.031691854669442104, 0.07431717063750952, 0.017761930470324813, 0.027986421445084196, 0.056385028836948264, 0.012597729857530326, 0.06717035171365546, 0.0340782760101701, 0.03616784977155828, 0.02102534628413137, 0.05216177380193145, 0.07215053609181797, 0.05368998514548425, 0.05648223007278097, 0.01088933080374714, 0.0721959114795731, 0.08547142613679172, 0.0340917706489563, 0.04817199555315799, 0.7094481022607896, 13.366484411301153, 52.3302859644736, 51.21175150717459, 29.4023633387781, 41.40427674016645, 56.94114192839592, 62.871216497113636, 14.705957155073843, 0.17378194347744988, 0.09705308208902998, 0.2129653642975515, 3.287479646744267, 2.1869125866120864, 1.5617061478476373, 0.35116912737008066, 0.7995733823026381, 23.426165619204124, 78.14989951349075, 86.03064721630466, 74.71774716531077, 73.03776464154645, 81.34821584147792, 81.10245581596129, 72.2550086052187, 65.12564189972417, 70.78342160870953, 70.56572221940564, 75.3936186144429, 73.4563756758167, 71.82761146176246, 70.10442795292025, 62.78337109473444, 63.0101703828381, 52.562278470685406, 53.341994670129594, 52.82195506557342, 57.30680096533991, 62.32328491826212, 69.66401638523226, 70.17277133080268, 72.04920184227728, 71.22691615935295, 70.40510900558965, 68.63941484881987, 68.9615277321108, 66.23061672333749, 66.50717519944715, 63.68011120826968, 73.16602614618117, 63.7035003016072, 74.77713184971964, 44.09795268889397, 34.88503471497567, 70.75395676397508, 66.1566408218876, 68.02374393709245, 63.00483203703358, 62.650010508875695, 56.86974694651943, 60.76786510406002, 56.27244841667914, 54.227838439326135, 50.51859809506325, 49.394913565727975, 51.17308870438607, 50.48302219760034, 54.07868246878348, 56.42330669587659, 57.66899262705157, 61.96464692392657, 61.85234554352299, 64.77290707249796, 65.18036680836832, 62.578466476932654, 57.607462406158454, 53.1408594500634, 52.43104380946006, 56.794570799796816, 61.763080243141424, 62.99344539642335, 63.14931646470101, 67.30597372977965, 64.49272432634908, 66.3568542849633, 68.43159198760986, 65.6933069229126, 63.566766477400265, 69.10072480478595, 61.76024436950684, 36.25798979113179, 9.352351369396333, 0.9781734212752312, 0.04856302215146923, 2.8478390699432743, 0.8464013340492403, 2.2714825647492565, 0.9082621372034474, 0.08745603819167422, 0.2409978697617208, 0.10304368281316373, 16.679959566362445, 59.73745061505226, 35.860696838748076, 31.377047261884137, 28.592564521297334, 38.93046532907794, 38.82986830126855, 9.537774555144772, 0.2372468887798248, 0.04265906214113197, 0.04476697604742743, 0.03274925518780947, 0.012456755315314138, 0.08388524108956899, 0.08354598671318063, 0.017302132159050916, 0.052000508463430795, 0.03965674824411831, 0.09107610240818993, 0.03196877055621195, 0.02662152664044932, 0.08043500324410778, 0.027715948357757543, 0.03733552098574658, 0.05067815643645102, 0.05253510759963144, 0.07012143731117249, 0.04798675549306697, 0.0697236001912144, 0.04988347428039678, 0.0184745071530943, 0.06106938836314987, 0.039228723429503946, 0.06639491751669876, 0.04238018698449578, 0.0635791268770493, 0.045396202364035194, 0.04245652764615032, 0.05995510198596505, 0.03365266820295684, 0.021425487413521738, 0.03347859387436221, 0.02343907674414016, 0.018647679413158088, 0.012693451586059265, 0.01754285996749757, 0.050620508320148916, 0.056712228819848075, 0.03844444091702181, 0.024106128652009274, 0.0016838957315250752, 0.028381893268576073, 0.034053577335491296, 0.07903004395625285, 0.0406248267409542, 0.033152025913999926, 0.09124653398870461, 0.047422026118804375, 0.0267394831133706, 0.019962518032820478, 0.08214291200161943, 0.00783153634045213, 0.06121759190254154, 0.039213757901903123, 0.03201871948887504, 0.024783764064552325, 0.051332318914994124, 0.02772117882306057, 0.034199658811332724, 0.08038875451611896, 0.056951198456508506, 0.037983746282876506, 0.028035901148893663, 0.03945002707863047, 0.019342823765210567, 2.3645479063833914, 27.673537500443, 63.203198063758116, 41.20055275578653, 23.291383174157914, 51.2384000901253, 72.4614429473877, 61.85115706536078, 9.371767101749297, 0.1808739871147179, 0.0533451842925241, 0.05431023674205907, 0.5919303985372667, 0.995833034957609, 0.908733189346329, 0.39660521993233316, 2.13739535981609, 31.86158157164051, 82.54092231873544, 85.45361949551491, 77.91702055162, 77.5225870070919, 84.99596518854942, 83.77602177281534, 73.10671206443541, 68.26212990668513, 73.0504652761644, 71.41099299153974, 73.68250816099106, 74.39598729533535, 72.16172679778069, 72.5076327785369, 65.93756075828307, 67.25794822938981, 57.771354721438506, 56.05412929288803, 54.34000645914386, 57.54284920230989, 63.82974178560319, 70.83761307501024, 69.90519508238762, 72.88867535129671, 74.25784141786637, 72.8156800423899, 70.37823292516893, 69.95576227864912, 66.9695520401001, 66.61258497545796, 62.68964605946695, 73.7701339106406, 66.29756373743858, 77.16942464151691, 44.57099837641562, 38.821474429099794, 72.78468547328826, 66.91839648831275, 71.4010380160424, 65.30848318530668, 65.39212380686115, 58.67007955428093, 63.89055813512495, 58.753865303531775, 55.962137945236705, 52.46184226005308, 52.850933536406494, 52.25070891841766, 54.510162799589104, 55.405455558530754, 60.910890410023356, 60.14867190391787, 64.40514172277143, 64.90559301068707, 68.96378701733005, 67.37417590233588, 65.92336177825928, 60.2247658852608, 55.48160837542627, 54.859544000317975, 58.84272659978559, 62.6933095532079, 65.22881592473676, 64.66131956346574, 70.96715327232116, 68.63202510341522, 67.62298753184658, 67.79582285111951, 66.58991367586198, 65.19069048666185, 68.09867689686438, 66.26088957632741, 45.204017931415194, 12.270797760255876, 2.17759033845317, 0.24474685891501366, 1.3058534961554313, 1.5686401628678845, 1.3748220017840787, 0.9351489428550968, 0.10616622654901398, 0.12943691333695767, 0.1822918473232177, 13.11100475249752, 63.36453299368582, 55.453253561450595, 40.150310685557706, 31.138500475114395, 43.29400408652521, 46.41261785261093, 18.407808734524636, 0.3050229325890541, 0.0914451729265913, 0.11571480006340051, 0.03182252054102719, 0.0578236538586357, 0.005519161706850414, 0.02235368145779977, 0.03114595573635832, 0.021732575673189376, 0.03546213723659035, 0.05538835993877823, 0.03807268143000622, 0.0370098301960576, 0.040736108672835177, 0.09012759362737979, 0.03603626650968387, 0.04573162247036253, 0.0628778423302837, 0.057453484004063, 0.017282945486987313, 0.04869801067416707, 0.014401320123954888, 0.058010337994463985, 0.049720849135830525, 0.04276591608481061, 0.016940931278851726, 0.047342176774456624, 0.028668800857098355, 0.05333413347421635, 0.05278871717652487, 0.2874059440387834, 0.12657846309124463, 0.19077061735574277, 0.1355468322552981, 0.0670773103352516, 0.09874431311243004, 0.11308840551083127, 0.11578927913139905, 0.10042078162152922, 0.10814855566188213, 0.16479760138017518, 0.14718756890825688, 0.1211447393401496, 0.13997834446209093, 0.17713337896331666, 0.11499892154167737, 0.1591486222441158, 0.10717821337523, 0.1705704416118322, 0.1184483549948181, 0.11389930191780291, 0.13979970807990721, 0.144654483864865, 0.13197704638925292, 0.19079802798167353, 0.12671135636346956, 0.11051574436527108, 0.15221598618213208, 0.15980707481503487, 0.22675863947839509, 0.15076098603106317, 0.17791805218064016, 0.20522890282013725, 0.13802224619975015, 0.2091968092586725, 0.15719217158132986, 0.1461358527622877, 1.188062390973491, 28.270588920962428, 73.76516819000244, 64.3160137053459, 44.64282874138125, 60.405391031695956, 68.51307530556956, 80.0009915136522, 21.732682297306678, 0.3031729221824677, 0.18488427353722436, 1.0578186185129228, 9.257019142950735, 4.319217445388917, 2.3369559934062343, 0.5922226764021382, 1.8594364749808467, 28.514615258862896, 83.03382304406936, 86.96992151198849, 79.05883819826188, 79.14132564298569, 86.76353423826157, 85.1999205927695, 74.16624622960245, 65.74173250506001, 70.21940831215151, 72.63315646879136, 75.77736762262161, 77.23605786600422, 76.6729231803648, 76.00231555200394, 67.916043496901, 67.5928480394425, 56.80334906424246, 57.749197252335094, 57.071478366851814, 61.6500336124051, 68.46745029572519, 73.79049885657527, 76.46027580384286, 78.61261367797852, 79.19092793618479, 76.99078421438895, 74.81355497913977, 71.37223997423726, 70.87628764490928, 69.70762529680806, 66.76729109979445, 77.62074824302428, 68.2982784701932, 76.1981830289287, 48.00593560741794, 39.97907961568525, 67.84398955683555, 69.0451369747039, 71.9026699373799, 67.90652782686296, 68.90487301734187, 61.463650426556995, 66.34525975873395, 63.41075028142622, 59.45302386437694, 54.329922045430834, 54.110685087019405, 56.21332260870165, 55.780865607723115, 60.298832001224646, 64.15851093107655, 62.09343794853457, 66.88729993758663, 68.20185876661732, 70.14070987701416, 70.54730276907645, 68.87068563891997, 62.82947463373985, 58.473768849526685, 57.32853481846472, 61.02817712291595, 67.48272357448455, 68.25014314343854, 67.52273959498253, 71.66531947351271, 68.63201725867488, 70.11427310205275, 70.81840915064659, 66.3044043510191, 64.31589603424072, 69.7856177053144, 64.32936937578263, 39.68645511134979, 11.49058145861472, 1.3818304192635322, 0.18148613733149346, 4.854619993317512, 2.7303949719475162, 4.482076706424836, 3.818566606890771, 0.46605151927759575, 0.7376527017162693, 0.34667286541192766, 25.7103382772015, 71.93281727452433, 47.141347162185184, 45.90972685044812, 41.469827390486195, 54.13317595758746, 58.70605945587159, 19.37882088845776, 0.3641109877536374, 0.1446559853971966, 0.1841465002226253, 0.10322452552856938, 0.2239252939339607, 0.2598326623199448, 0.20966367856148752, 0.11125784607664232, 0.13338744490137025, 0.1771603605800098, 0.19790623607414384, 0.16209654389850556, 0.11669032110442078, 0.17262164202909316, 0.15761823904129768, 0.141492823679601, 0.13413281780817818, 0.15692526654851052, 0.14470164423748372, 0.11613476946349106, 0.18950220557951158, 0.11300659498139737, 0.10219847332806357, 0.15624396923568942, 0.15958619634470633, 0.2686735008272433, 0.12036629441765048, 0.16132176853716373, 0.2109372078050529, 0.16137648253671585], [0.053145733301437674, 0.04480601205760914, 0.042908856600162484, 0.04196052401957493, 0.0350385902058934, 0.04393130052654494, 0.06606497110859041, 0.049398437202457464, 0.011487784326046465, 0.031355406090076414, 0.061397316129577745, 0.10450971463034231, 0.012728123767902295, 0.07819109340949405, 0.01654292561955029, 0.07628037819578763, 0.03291258896370569, 0.02527718214438327, 0.029457176194315957, 0.057843882410276326, 0.09167879909997986, 0.0639444473950613, 0.03235743185805698, 0.07117077858457643, 0.046893249250828266, 0.042950642865992365, 0.028586794975243753, 0.03463526023551822, 0.018114639265883355, 0.03359309337552517, 0.14775551585180147, 0.0981762818992138, 0.04191118795725127, 0.02758919528024572, 0.06421252454240477, 0.06561544603638111, 0.10061699206069594, 0.07868724259277506, 0.3403095246082352, 2.7501019402857754, 46.51059865951539, 57.98102501899966, 46.83680257489605, 35.92731437375469, 48.51678117629021, 75.1112707199589, 28.33791248260006, 0.4079177338750132, 0.07051296186663451, 0.13625506521953692, 0.0828480959359196, 1.1980776729122287, 0.0750692468136549, 0.025580754060478463, 0.07899637439198072, 10.211978996953658, 52.579929136460834, 82.28371681705599, 81.57277937858336, 72.62690421073668, 65.61430646527198, 75.06841490345617, 76.30942144701558, 71.40695295026227, 74.58676353577646, 73.32373680606966, 70.65279883723106, 76.78000388606903, 70.46368568174302, 73.85051896495204, 64.46285155511671, 54.47800328654628, 54.78073181644563, 53.764716348340436, 55.19826027654833, 63.95958008304719, 65.86536561289142, 67.73588119014617, 69.33303894535189, 69.23229678984612, 72.00504379887735, 69.7677081631076, 71.93844195335143, 66.75567303934406, 72.40097568881127, 67.49415336116668, 76.41769455325219, 68.75958842615928, 77.59366819935461, 41.9592175945159, 21.190369513727006, 71.6438719534105, 66.0304581734442, 75.0592444019933, 67.36717839394846, 68.93489483864077, 63.24539099970172, 64.8369279984505, 59.255014773338075, 57.01016387631817, 52.09986240633073, 52.75893042164465, 51.09180150493499, 52.76848531538441, 50.95651503532164, 54.50070596510365, 53.22660246203023, 58.87145403892764, 59.4344828205724, 62.917539688848684, 60.208017364625015, 62.160506556111, 61.06916589121665, 60.77385456331315, 59.40497875213624, 61.15109635937599, 62.654431020059896, 67.41356434360628, 67.73777961730957, 63.1497440030498, 70.49625704365393, 71.89124015069777, 65.99660027411677, 70.71233257170647, 70.14369872308546, 46.380175928915705, 14.246020028668067, 1.2007909724789283, 0.07448253837684471, 0.05718476334286313, 3.526958977022479, 3.6528673047019593, 0.6642742262732598, 1.9056768066460088, 0.3287540075759734, 0.10317060059957928, 0.5197232408869652, 29.516953422177224, 58.60587035456012, 26.031472529134444, 23.83100521179938, 31.49100192131535, 45.92545947720928, 41.99156145895682, 6.44776467354067, 0.09945025547377526, 0.027212008060286605, 0.01953863966909628, 0.047319159662771615, 0.06193544693110932, 0.08531412530329921, 0.04399205512938, 0.06924623548383675, 0.019684182968170896, 0.04236909020091257, 0.04938997576133378, 0.03956472959309336, 0.013111161026773194, 0.050300750881433494, 0.035341562658187844, 0.022378060290770187, 0.04744222402692803, 0.13241282784410063, 0.05421380542459027, 0.013131902857323088, 0.0751855236388022, 0.018667997980129816, 0.2212946092890155, 0.016311662827408122, 0.011658249422907831, 0.08630707484459685, 0.059998225075222796, 0.032405300862005645, 0.066830936458803, 0.02179612649694806, 0.04277252359315754, 0.031309655319238384, 0.030799513540020397, 0.029685600630698666, 0.04562748047793585, 0.13916405428561474, 0.07756223481508993, 0.05676906488295044, 0.07148890425601313, 0.006054613594671772, 0.08195210248231888, 0.05347500555217267, 0.03046135275414394, 0.07705696918551, 0.002814639831945721, 0.02754132053063762, 0.04529710506058989, 0.006354340228192028, 0.050369001654607636, 0.006876127501468986, 0.022263555043947794, 0.04600477111976474, 0.05765372023527181, 0.027208453412317944, 0.05280573581976276, 0.0972434779208514, 0.022144524132712715, 0.09370360778824938, 0.06032743986936347, 0.07642775052978147, 0.027966392076303883, 0.07746878741008621, 0.060361335429573254, 0.03661635211638866, 0.01926891734793542, 0.0020682439583564, 0.07054670037881983, 0.03865275937583178, 0.04558643731739252, 1.5421213858550595, 13.179444228449176, 59.89254505403581, 52.50469807655581, 40.90334300071963, 39.855152330090924, 74.87537153305547, 85.86147539077267, 21.85007687537901, 0.2601643783911582, 0.10482940312114455, 0.14872735967078518, 0.3650364526096852, 2.7156571563213103, 0.1260493414837026, 0.13208682678880232, 0.07367243870131432, 17.07800757500433, 62.325140199353626, 82.79662163026872, 79.55449242745676, 72.35984571518438, 68.31892582678026, 76.78694648127403, 76.19494315116637, 71.43870845917733, 71.5192190293343, 75.3204664107292, 73.41843851151006, 79.0104518398162, 75.09959774632608, 74.16299066235943, 66.2512876141456, 55.459796074898016, 54.530982740463756, 54.661632968533425, 59.254818654829464, 63.78258705139161, 68.95686011160575, 70.25329759044033, 71.13717232981037, 68.59866142272949, 72.9575207925612, 71.81210241010113, 74.616071485704, 69.48185366968956, 72.99517554621544, 69.60373740042411, 76.27625388483848, 69.86876410822715, 76.01424740206811, 46.02089074350173, 25.925621486479237, 70.6303628798454, 67.75421434833159, 75.81155500104352, 69.21417543965002, 70.23590580109628, 65.50981060151132, 66.39459533076133, 61.63406564343361, 58.56212023765811, 55.547919965559444, 55.014344261538604, 53.87675492994247, 54.22296293320195, 53.791957209187174, 55.25757043592392, 57.76946806138562, 60.738921934558505, 61.15840373500701, 64.01796064069195, 61.44390129273938, 61.642039821993926, 61.13371241477228, 61.301629081849136, 62.09685825532483, 62.16439754732194, 64.47943925857544, 69.21900779970231, 71.01568868083339, 64.80252096729895, 69.26588796800183, 72.02728363775438, 67.87028512647076, 69.6720729335662, 70.8717926086918, 53.975300558151744, 20.36892321801955, 2.3608140551274825, 0.6106779796461905, 0.22782575399164232, 4.04583118615612, 5.920736876226241, 0.3284442016193944, 0.3427740294606455, 0.12117123066057121, 0.08786589523116428, 0.19733199188786169, 22.728632880795388, 69.57737907286614, 44.22128769659227, 21.92816342076948, 33.81849911905105, 51.446505361987704, 52.718094625780665, 13.969520388110993, 0.09463509409538201, 0.06232588747215848, 0.09118854879371582, 0.051585472669572606, 0.05173265731202499, 0.07448037034801899, 0.038717984101705016, 0.025093757712672797, 0.010015161279889365, 0.020235871610742424, 0.020331372131383228, 0.04984880497138347, 0.030452356966693076, 0.044809876971187136, 0.0518218950638848, 0.049296593473803614, 0.02809937536385992, 0.03467943286523223, 0.02669005320527621, 0.048512755292317564, 0.025949521974149733, 0.025233869448364265, 0.0925193507705004, 0.07884225282337397, 0.047270876971343835, 0.026662288263680476, 0.10110283736139537, 0.05486390763713468, 0.07127648339636865, 0.03138607067446555, 0.06077069834235215, 0.10989080048016003, 0.13705375784587476, 0.10774672722383853, 0.12609926743372796, 0.2592369217065073, 0.13840864562699873, 0.21159091063084143, 0.21248832134710205, 0.08135587923348912, 0.1395481248055735, 0.15514858607803622, 0.16793051794652017, 0.13863975903199566, 0.10683653050012167, 0.16251309654645382, 0.2084144649486388, 0.11490554308458684, 0.1255279037380411, 0.09741396312752078, 0.22481656062506863, 0.12238168022445134, 0.17081983387470248, 0.11942438931474764, 0.1489375282319323, 0.2812594061176623, 0.10204066687654104, 0.11558723110224932, 0.13010100431499944, 0.15011414735307618, 0.2021078759383771, 0.2791404988496535, 0.22038181552723532, 0.1719095326599575, 0.09844729316330726, 0.12202207089191484, 0.21366458806780078, 0.16953403190259012, 0.11257150300568151, 1.023357838632599, 13.135907880721554, 71.29393377611714, 72.47849741289693, 61.612229808684326, 50.1338763390818, 62.72808920952582, 90.87341723903533, 39.658735721342026, 0.8561248284193778, 0.2084287601493059, 0.36859091671724475, 0.3813891509367574, 3.1004953576672465, 0.19722702252047677, 0.1701141136788553, 0.20261475035259802, 14.67877414918715, 60.58083080476331, 83.70173992649202, 83.80601221515288, 76.38544482569542, 67.68368228789299, 76.19116198632025, 77.28387155840474, 70.9354369871078, 71.64797475261074, 73.95088457292127, 74.96538992851012, 82.09559994359171, 78.01293819181382, 80.55424182645737, 71.28374345840948, 60.91981772453555, 58.1863336409292, 59.04001005234257, 60.309955843033336, 68.63106804509317, 70.00560775879892, 73.34020291605304, 72.66986200886389, 73.00277709960938, 75.94130700634372, 74.0562080567883, 79.20035731407904, 73.62473949309319, 76.09214567369031, 72.51890567041212, 79.29124647571196, 73.65194505260837, 77.94541066692722, 46.672839656952895, 26.84610959022276, 72.8963553520941, 69.26034958131852, 81.62227184541764, 72.78366565704346, 74.34961703515823, 71.1501318408597, 71.80810159252536, 65.29575509409752, 62.778601492604906, 59.692033490827015, 58.734273064521055, 56.65373417638964, 57.387017357733946, 55.06057331638952, 58.68623187465053, 60.56510210037232, 65.20707422687163, 63.067990041548214, 67.33909422351469, 66.75642613441714, 67.37006525839529, 65.67744093556558, 68.16359996795654, 68.18125063373198, 66.88136146914574, 66.4234325962682, 73.17005834271832, 72.85372703306138, 66.58530881327968, 74.3063219131962, 73.003906742219, 66.82813490590742, 70.31403157018846, 72.99825068443053, 50.128028085154874, 17.271913866842947, 2.2760928205905424, 0.3527970029221427, 0.16178764192567718, 5.530530666151355, 9.503307707848089, 4.03644593492631, 5.818861155740677, 2.4340299973564767, 0.2627670855051087, 1.2021766723163667, 40.838514066511586, 71.11804685285016, 38.24372106982816, 33.91109843407908, 44.88397998194541, 62.04638911831764, 58.65567268863801, 11.847757389468532, 0.23420913565543391, 0.11413583156442451, 0.2707451557920825, 0.11961569679119896, 0.17809846588680822, 0.17285418035762926, 0.10287317462385663, 0.1427546011344079, 0.12909143832662415, 0.21460042575434332, 0.1090899091814795, 0.23477870670537795, 0.17005330161942592, 0.18423414068116298, 0.11415221818512487, 0.08497765948695522, 0.15725318282361955, 0.1434729924245227, 0.1046167754177605, 0.11609318621096112, 0.1247573035558866, 0.10462153282377029, 0.3654197110764442, 0.1762078834637519, 0.0993573749738355, 0.18739301230638258, 0.21055653871547794, 0.166077044822516, 0.1887020727078761, 0.20940080315114992, 0.10676027410813879], [0.027971258649842876, 0.05282483439171507, 0.02517512965677006, 0.09601602886593151, 0.07660756668736858, 0.008328688620108991, 0.04979272733532614, 0.027035505232972004, 0.02453926327307859, 0.0855387882479737, 0.03239586265877851, 0.037655037106765855, 0.02506727979878985, 0.015147334629399403, 0.06227660503598952, 0.006204022286129335, 0.07416727021336555, 0.009014947309849725, 0.07410177735671883, 0.041701456066221006, 0.030763461442303755, 0.04760295693432132, 0.00992322211048656, 0.042427600166129495, 0.02008189176840167, 0.0670008547604084, 0.062203148695369886, 0.03374913399438224, 0.04936034348042262, 0.0591032007228463, 0.0411611380836656, 0.018082706805979534, 0.04927754086712676, 0.051442137618939725, 0.10227637680908365, 0.04063213521975183, 0.05347278006675263, 0.04029748120134877, 0.018423338225411794, 0.0834465255179713, 5.959318289833685, 36.89720276863345, 55.87688130717124, 42.66397729996712, 21.8645582660552, 38.85384967250209, 70.63419895787393, 50.43129005739766, 2.527254930426998, 0.16155888807148705, 0.2627652468940904, 0.18075689823637087, 0.8403868696862652, 0.3044689284457315, 1.3797233710365913, 0.04927298647441691, 0.6063056400706691, 19.293362248328425, 54.97639533012144, 81.48272960416733, 85.10303020477296, 72.40467840625395, 68.37361935646304, 76.97377681732178, 76.0537221354823, 72.60897113430885, 80.48800083898729, 72.62145211619716, 69.4008331914102, 61.36670120300786, 58.066732729634936, 57.11521671664331, 60.7198513707807, 57.98470027985112, 66.93281512106618, 68.23746604304161, 74.07795367702361, 70.92100266487368, 73.77429162302326, 73.0963570071805, 75.86927660049932, 72.73718557050152, 73.07385829187209, 70.79462389792167, 73.52335406887916, 72.52278097214239, 74.19207895955732, 62.30837991160732, 60.037296202874955, 34.05376288198656, 27.855315823708814, 72.7738283526513, 72.1746470851283, 67.67930492278069, 63.707822753537094, 65.97498016972696, 60.271485236383256, 59.80657062222881, 57.589545019211315, 53.64571948205271, 51.19022946203909, 52.062999971451305, 56.299928542106386, 54.44964455020044, 54.79669978541713, 53.38252452112014, 52.785932017910866, 56.07880492364207, 61.619023353822776, 60.99920649682323, 60.79667099060551, 60.383308087625814, 58.4283007344892, 56.344427831711315, 58.79325374480217, 62.40867883928361, 67.63477033184421, 67.69132306498867, 65.9511007801179, 74.2139736298592, 70.52416078505978, 70.83398096023068, 75.64352066286149, 56.502052199456, 17.67430982282085, 1.9606174456496395, 0.230244584682007, 0.39620351406835747, 0.26959004841985246, 2.7227235513348735, 4.847650431817578, 1.3315683098569995, 1.093431901066534, 0.29201074533404847, 0.051768042913247506, 3.74274326908973, 42.922979247185495, 52.60565204005088, 15.836106731045632, 18.245206879031276, 36.332593271809245, 45.82146175446049, 26.7422785682063, 1.663216107314633, 0.10529198999246282, 0.07766360356923073, 0.009195664578357772, 0.05268201261999146, 0.07422230596984587, 0.0740038406764788, 0.06684350796164044, 0.040782537431486195, 0.06967795667268577, 0.04181021373839148, 0.038894452455063025, 0.039100480310979395, 0.03863425069158116, 0.026061137154277776, 0.03005180406504341, 0.018283266709336353, 0.040412811907909574, 0.051281523455174706, 0.06540600525876207, 0.058308139353269534, 0.04428087410727336, 0.032869776140057275, 0.058073590043932206, 0.06601314526051283, 0.12530727807672756, 0.08325655869538746, 0.032148910385947076, 0.016099113648036317, 0.018855754639052095, 0.07293900910524592, 0.04627182553972929, 0.025053926886269645, 0.007161868242321597, 0.014655352006816577, 0.05777307290343508, 0.11771185338617333, 0.10337761287847835, 0.02383288998727597, 0.022643789378625732, 0.022250282570659634, 0.019913748875560782, 0.018222803219912515, 0.06570110232719491, 0.0627556398150421, 0.024053958064365773, 0.041487679230950536, 0.056410581699662635, 0.021555624684439074, 0.06559055583972125, 0.05191557612570544, 0.03854343479859733, 0.06484774932745965, 0.028867399575369015, 0.06140760852084045, 0.019832081987612674, 0.019597195599588658, 0.04932198545805389, 0.07921925235179164, 0.02427953456888997, 0.02563531675766553, 0.05587336254276096, 0.04179481154067382, 0.05203066168413047, 0.0599390754265891, 0.02666759916821555, 0.02826020020180412, 0.05207167803159645, 0.07326893253071655, 0.04832735052332283, 0.029962767411263722, 0.013325756618512735, 0.21606607452755977, 12.883203298814836, 52.92075957021406, 64.3370376094695, 37.53589407090218, 21.31123931177201, 61.5578265343943, 91.79935547613329, 43.559352428682395, 0.3278458256634974, 0.15087255907635536, 0.24324868204853228, 0.2915269761316238, 0.7494706804713895, 0.708693904021094, 1.7451327246042991, 0.6987910837896409, 2.0935540478075705, 30.00588078652659, 67.00211555727067, 84.64867068875222, 81.64441754741054, 70.37322798082906, 70.11815624852335, 78.09975593320786, 76.8374744538338, 74.50467617281022, 79.44236755371094, 74.9554035740514, 70.75309384253718, 66.71118551684965, 60.366865511863466, 60.55227202753867, 61.636301394431825, 60.9769941145374, 68.24195323451873, 72.46441610397832, 74.5822371205976, 73.03747438615369, 75.75721448467624, 76.23708509629773, 76.61148317398565, 72.64942646026611, 74.03407804427609, 71.55448898192375, 74.39495178960985, 70.73418017356627, 76.97015254728257, 64.54366414777695, 64.65246285161665, 36.83440954454484, 27.09387786926762, 73.95780363390523, 71.56813098538306, 72.32755676392587, 64.90520861841017, 67.91919708251953, 63.75058835552585, 62.87568015436973, 59.791336136479536, 56.50977142395512, 53.91641793712493, 53.648174885780584, 55.87111542301794, 55.11693385339553, 56.11096051431472, 55.42261592803463, 54.78804311444683, 59.4248769360204, 63.00914664422313, 65.50259344039425, 62.014080555208274, 65.90018841528124, 63.013221986832164, 61.799997591203265, 61.00799652837939, 63.761986763246604, 69.02470142610612, 70.94405835674655, 66.08171570685603, 76.10633680897375, 73.89197057293308, 70.15493239125898, 73.0506927736344, 63.693757134099165, 25.17001609648428, 3.44594830466855, 0.6646801915860946, 1.714398747970981, 2.4883337415033773, 4.827988570736301, 2.8331647476842328, 1.537123183088918, 0.5826756274027209, 0.17774021252989772, 0.044289703270600694, 1.9154178903948877, 42.85090961763936, 77.7968155953192, 31.93663024133252, 15.502215950719773, 33.347061603300034, 52.51262126430389, 37.12774007551132, 4.39709561486398, 0.28386793549983735, 0.0977095198487082, 0.08675375773060708, 0.09575755080027927, 0.07636084807135406, 0.0556294669607474, 0.025042912457138303, 0.03390683319359537, 0.038219119136732434, 0.06212257156749407, 0.0225361138056483, 0.03207878269735844, 0.05440429318696261, 0.016788625338625525, 0.0180616891837769, 0.021827480560469053, 0.014981921882398668, 0.08872791268532315, 0.030692226756664536, 0.04762513134928961, 0.042448464570747274, 0.05461923064543836, 0.02519709531277899, 0.08557448794524516, 0.06758626084774733, 0.047762502405431964, 0.005813383998634715, 0.011016470755660727, 0.023156309860848615, 0.036224785426090804, 0.06978077333300345, 0.11121040991237087, 0.0734488636014923, 0.08570948029838263, 0.12774187485657393, 0.14274766037781395, 0.20450095075272745, 0.0920894758535489, 0.16454914374457252, 0.1090827692420252, 0.14110406470154563, 0.24175779833909006, 0.12964541182642983, 0.134686132472369, 0.11486015237507322, 0.10876353274309829, 0.160719393602302, 0.0973188609726006, 0.15905491436921781, 0.049195852911760735, 0.16235189632542674, 0.28594777228370793, 0.12510110083366596, 0.2538591070521263, 0.09860788817487418, 0.08355286618274066, 0.09736540847487989, 0.15329177281068218, 0.16377156450142785, 0.10422659151616598, 0.08385748572407231, 0.16274090045161788, 0.10864656643881913, 0.24126247653076727, 0.16602617658434377, 0.13121245999730405, 0.20501946970339746, 0.19791723709673653, 0.11011283574325424, 0.16870437400235286, 0.14279978500018198, 0.17872664266295973, 12.4362031298299, 61.87119253220097, 76.82991212414157, 56.24375627886865, 36.21834247343002, 51.80537869853359, 87.71295178321101, 63.55590543439312, 4.34729524197117, 0.2677430717214461, 0.41775755103557344, 0.334420851882427, 1.3361040406650113, 1.2197074606533975, 2.1422473317192448, 0.909729716518233, 1.3779672523660045, 24.83473973889505, 62.13400310085666, 81.06484813074913, 83.2350798576109, 72.45997598094326, 67.60426998138428, 77.72350649679862, 77.6655024866904, 80.13693301908432, 84.35280630665441, 80.38609766191053, 73.84041493938815, 65.72877299401068, 60.654916532578014, 62.04412983309839, 64.89322185516357, 64.1246412646386, 72.33267937937092, 77.5299689077562, 78.87754624889743, 77.11570385963687, 79.38357906956827, 81.96901721339073, 80.4477337867983, 78.18706789324361, 75.60073544902187, 74.30115222930908, 76.97329828816076, 76.26104293331024, 76.07323984945975, 67.08071985552388, 61.85823694352181, 42.69738412672474, 37.93260259013022, 71.99809335893201, 77.16049732700472, 73.88512995935255, 69.03754326605028, 70.03904988688808, 65.55121514105028, 65.49261493067588, 63.361442165990034, 58.71859927331248, 57.63233807779128, 55.50176935811197, 61.81559293500839, 58.89839287727111, 60.4863997428648, 58.119810242806714, 57.48645336397233, 62.02885612364739, 68.98587780614054, 69.7735603394047, 64.6858932125953, 68.09335816291072, 64.73573477037492, 61.99008741686421, 61.70917510986329, 66.08791305172828, 72.42697315831339, 73.98107113376741, 70.66440120820077, 79.34958780965498, 71.02765190985896, 70.57880724630049, 75.7712173461914, 62.82115136423419, 21.451819019932902, 3.1557674369504376, 0.4467937236111011, 0.7746420007559561, 1.1330214863823307, 8.184636273691732, 11.138438909284531, 4.737163147618694, 4.645667489497892, 1.2326713843691735, 0.18866925350119992, 6.184545197794515, 58.13175778235159, 62.230477717614946, 27.561340062848984, 27.78032991193956, 48.594236220082934, 64.09938512309905, 38.644865789721095, 3.45056468921323, 0.3328075626444432, 0.2079901748126553, 0.24069526503163002, 0.12622605498519637, 0.2597946643589005, 0.14069166425014698, 0.15798602253198624, 0.1354331294855764, 0.1184486614299878, 0.2083176927220437, 0.14868977539721998, 0.08678720512938115, 0.25597226866070305, 0.09193316327347871, 0.09655669541849245, 0.0692073182172833, 0.12722417561998292, 0.22916558048417493, 0.19739272733849866, 0.127344926398608, 0.09572991034797124, 0.20485658408893695, 0.1053861958245116, 0.19278400367306125, 0.18578194472337925, 0.2250358915977901, 0.13524173007857415, 0.09399485909530232, 0.08015872129509527, 0.09508356962713505, 0.14798678247438324, 0.1966787027495523], [0.013977957911969674, 0.088902956115142, 0.038596049717236916, 0.07516595775321608, 0.03155107835247632, 0.03262005828981919, 0.00255618786116341, 0.029079604015174895, 0.030900459030583024, 0.0785088130543309, 0.03571689211493058, 0.009763251460577932, 0.029566196251600504, 0.029554203145145893, 0.03064372956061796, 0.0352407033525167, 0.01783487353203518, 0.08157671939942145, 0.014718254528669341, 0.062401772311498085, 0.03796695363557628, 0.036207146251634244, 0.058467834211525425, 0.07889653781368848, 0.01925635159075741, 0.016611950141527963, 0.06225598960994713, 0.01592997579850377, 0.038921035706035556, 0.01318916888727296, 0.08214584611836942, 0.05078644679498769, 0.02661679221707727, 0.043630653151100686, 0.05203712363577178, 0.029646428639910398, 0.12115062289540807, 0.04111662071438567, 0.030583589743342132, 0.033776471841960184, 0.0257289499389909, 2.8086202711828294, 20.15231816999374, 57.14823522875386, 52.34414762066257, 35.63910645823325, 29.974103704575572, 56.08694384174963, 70.37227876724737, 15.108756134586951, 0.17581694879599158, 0.052229626209384976, 0.06923894998767684, 0.42914780758080945, 13.380752032802953, 14.096456131627484, 0.18572462602488457, 0.5150000943291573, 1.1738648818385218, 17.708442288060343, 54.612764158556544, 76.8901675747287, 85.56667789336174, 73.51382270936044, 71.9796189954204, 77.85292117826401, 75.6924561531313, 71.07951348827731, 73.81594719425325, 69.11049150651502, 70.1783489411877, 67.19824975536716, 66.61984920501709, 63.7769349159733, 65.11072512595885, 69.14315700531006, 74.66518740500175, 70.38075893155991, 73.98334610846736, 70.75269376077961, 73.62853634742, 72.79182418700188, 74.01682746025824, 69.24877074456984, 73.82248186296033, 73.75133006803452, 62.17941238034157, 72.16065206835347, 61.034762782435266, 43.013958623332364, 59.943014191043, 61.116928592804946, 79.48996943812217, 73.15795390836655, 73.58520200175624, 70.19989844291442, 66.40828440266272, 62.219138145446784, 62.598486254292155, 54.90837358659314, 59.67960349975094, 62.42993024087722, 62.7017387267082, 60.86290021096507, 63.22567716721566, 60.01743332032235, 59.38081695187477, 55.29387589423887, 59.159740401852524, 57.89226178200015, 60.62261973657916, 61.30754009369881, 63.96879765295214, 67.08912157243299, 70.63003340075093, 69.9055951641452, 70.51415874112037, 71.08033718601351, 75.8799768263294, 70.54183498505624, 76.80327138593121, 63.35442504575176, 29.260334314838534, 4.323599223167666, 0.17705035035408315, 0.14066255290902432, 0.36429950667004435, 0.9638925617741001, 5.679714583581494, 1.5048137619610757, 2.533037974949806, 0.1991393311970657, 0.09205084203952744, 0.07916857563560048, 10.693506809972948, 59.70009788390129, 41.34558631527809, 16.58958423522211, 28.844649368716826, 41.427783504609145, 42.1478404537324, 13.531388698085664, 0.09177655191911806, 0.06293929024269024, 0.12941296542844466, 0.041009985105765444, 0.05879524869904403, 0.0523997436938507, 0.009623318797938768, 0.03556132264014694, 0.05869800532837549, 0.011400299957923351, 0.09896899903974227, 0.01429260362901034, 0.015279899441426801, 0.05578364981638809, 0.11896581674415259, 0.016222019048948443, 0.013761250790388835, 0.03911443460252016, 0.02625906171517507, 0.05330511789408423, 0.018437662154376026, 0.06551374020355363, 0.014682253184277686, 0.09990647615444276, 0.020458159682851647, 0.05912974949986224, 0.05948668901598262, 0.018129964854808587, 0.06609197570792129, 0.02855945329722618, 0.08070376220970385, 0.05100240698084236, 0.08997003998487227, 0.029641050702681946, 0.013867402806006854, 0.02368124096744484, 0.08783115314379816, 0.026755668635990833, 0.0075463778264219725, 0.05892609268607152, 0.04608562786973292, 0.05022586195639545, 0.07583630000871998, 0.0427730904982215, 0.030316598525631334, 0.006731393382764392, 0.049251800312870936, 0.024135847117811925, 0.0832829810678959, 0.03535199677571654, 0.03430906765823884, 0.06694935066925903, 0.04362897541854651, 0.031609975192095005, 0.026397016913359685, 0.022074262378737334, 0.05935523598905533, 0.039057253799851865, 0.07978532237992172, 0.025054062866876205, 0.013150026582391753, 0.031928294300732595, 0.024384352633909836, 0.06561550732341505, 0.04244038617358573, 0.029274757253006104, 0.01037368180996348, 0.10521142052546625, 0.02608313919946311, 0.04578822870708762, 0.049450289863612384, 0.05125674434126385, 0.06701097478188815, 0.07218130218285708, 0.08866120940975605, 7.153657453675424, 33.162357191885675, 65.4106334717043, 41.9528555100964, 25.730562017809962, 41.08701582877867, 85.70851864353304, 72.69659688395839, 6.526473404899721, 0.11676939669996501, 0.2196123721378465, 0.2467755363473008, 0.8415073192408009, 15.92203409441056, 14.864545445288382, 0.47858223559394963, 0.7948623092905168, 2.9868385532209953, 26.62992423580539, 64.4980352155624, 81.43617891496228, 79.4688121734127, 73.01090425060642, 74.03455657343711, 78.46018252834197, 80.08232578154534, 76.44261729332709, 76.80593075290804, 69.74762562782534, 70.38057065779164, 67.54418711508474, 65.51230130657073, 63.00402402877808, 67.589717988045, 70.66110641725602, 77.46986250723563, 72.91102501653856, 74.85608916128837, 72.9928848820348, 73.77960251223656, 73.25482860688241, 72.62160116626372, 72.79598974412488, 76.25038193118188, 74.5994249466927, 67.32272225041544, 69.2328223874492, 57.95006967359974, 46.9175837885949, 55.43199039274647, 63.28097474190497, 79.95691976239605, 71.98434937384822, 74.85881128618794, 70.54603976588096, 67.94976803564256, 64.3854671139871, 62.418653426631806, 58.675347297422356, 60.33211331213675, 63.122581589606504, 66.13095714199927, 59.35247390500961, 62.40547034048266, 60.04257963549707, 59.099732060586255, 57.47856155518563, 59.51276548447148, 59.86959918852776, 61.14220434619535, 61.672653921188854, 61.96030486014582, 66.66501921992149, 71.48915013959332, 73.67445945739746, 70.77120734799293, 69.66199244222334, 77.27153962658298, 72.06119645026423, 74.32398042371197, 69.88339454896989, 39.39547800248669, 7.706685662269593, 0.5481232234066533, 0.6745246665612344, 2.1468387111540768, 5.996638661430729, 8.419666655601995, 2.548619835607467, 0.46290188667274296, 0.605397611375778, 0.1790784608813063, 0.15053358049161975, 8.565508223349049, 61.70881817417761, 62.7637121754308, 22.128455331248624, 16.827426956545924, 39.02872070189446, 52.78763040419548, 21.478591157544045, 0.5659067594716626, 0.029398403843984972, 0.1436609904011411, 0.07991436222988753, 0.02395457730838849, 0.09963553383826249, 0.06115604439870485, 0.04162081382087162, 0.03558509051799774, 0.02405517422894557, 0.035874173796224984, 0.059902027414570895, 0.024205750725682706, 0.022903194410666343, 0.07051345982378529, 0.02608643912319695, 0.09178631954015264, 0.049110935895793864, 0.03279197608090697, 0.019346276906529264, 0.08776602034847583, 0.060528572423443686, 0.03186543678654538, 0.04455817878366478, 0.053372254009328546, 0.036393734626471996, 0.09516677443659115, 0.01297725651848821, 0.0031489625173215306, 0.074625697227255, 0.023116063431746537, 0.08887338512126478, 0.14771200205770232, 0.05933999466980177, 0.15816472020120392, 0.15331504656182182, 0.16497668209335498, 0.10932713596811218, 0.1423925020161175, 0.14379511707492415, 0.15274636417386994, 0.14363990766146492, 0.1532456543176405, 0.28563272628572683, 0.15797610935424605, 0.11622324495786622, 0.27723275605709324, 0.08703122711590222, 0.182769579752799, 0.17839304201545256, 0.12103152686669943, 0.15315406084541353, 0.13486570348182034, 0.15325818751608172, 0.17627130022212384, 0.16338908744435157, 0.11514362022881547, 0.15517765145388343, 0.14426194041246368, 0.12724322822665976, 0.15338344289170158, 0.1315642935374091, 0.12153300036105419, 0.18463379342950162, 0.13490636742884113, 0.24716933618389794, 0.2246728425304736, 0.2509316093017978, 0.1583378407503328, 0.2556843115317245, 0.25244340721157293, 0.2501584274033385, 0.2022758636984133, 0.15863710533707373, 0.11772835492006234, 5.837447306802196, 38.509198850201024, 80.6157995039417, 66.63670755201771, 52.24093829431842, 43.89897477242255, 72.82064576302805, 88.15132371840939, 18.89273528129824, 0.26358471582493476, 0.2845240744852251, 1.1105657945717535, 1.7293657771041318, 21.136721295695153, 19.122684232650265, 0.3248657742815633, 0.46446357222814716, 2.3053510054465267, 23.483559700750536, 58.91429416594967, 78.02752940885483, 83.43848613000686, 74.12430824772005, 71.87174597094136, 78.59347251153763, 79.37010965039654, 77.25515980874339, 77.87516101714104, 74.04746117130404, 77.52341854956843, 74.32355680773335, 71.48671827008648, 69.28937512059366, 71.47026000484344, 74.46587608706567, 79.34856014866983, 74.47749414751607, 77.05595831717216, 75.61815077258696, 74.36114880346483, 74.40269454833, 76.67701813482469, 72.7170559667772, 75.57897413930586, 75.2595127782514, 67.3706300797001, 79.27746326692643, 64.78086556157758, 55.41158622311008, 68.35590593276486, 64.41113118202456, 82.75235376050396, 79.51342521175262, 78.486815421812, 77.15019718293222, 73.90952710182437, 67.93018756374236, 67.19428031675278, 60.82044447621992, 65.76471759426978, 68.95778579096641, 71.19508220303443, 64.37595144394906, 65.78265459306779, 64.90320428725212, 66.3579603933519, 62.16152244998563, 64.39678315193423, 63.68271173969392, 65.79525716843145, 66.92315824570196, 68.55391502380371, 73.85934429783975, 79.12295326109856, 77.00174331665039, 75.38333415985107, 73.01918829641035, 79.19028466747653, 70.70506834214734, 78.28122046685989, 66.39905898801743, 34.55499864393665, 6.016302973993364, 0.48321731268398227, 0.5012513901437483, 1.0650247479638746, 2.9994511796582133, 13.016421698754835, 11.391980917223039, 4.428182359664671, 2.4404599878095814, 0.39598260495451193, 0.32816347636042104, 15.845691042561686, 72.71517322909448, 52.364512566597234, 27.10525078158225, 39.9226406312758, 54.42201145233647, 63.97554020727835, 22.33776673193901, 0.33331305810040046, 0.17118315873367174, 0.20744263645141356, 0.11203956219457811, 0.13704186816128994, 0.16558408256499998, 0.11575542570602511, 0.1406844936671757, 0.18129450809811393, 0.09703936145430613, 0.1505100922358613, 0.14039261416802484, 0.10554945682205501, 0.10594039915069457, 0.2374721799165972, 0.11913816354447797, 0.236401280929004, 0.11434291279123676, 0.11665885021249134, 0.07653586085765593, 0.29126767069101334, 0.1284193340688944, 0.15953967948594402, 0.11880892959813918, 0.13153565717079949, 0.21475237163324512, 0.13643632162242167, 0.10508244962341363, 0.1714993998288147, 0.11525146242591644, 0.23490443705551087, 0.20744542501145796, 0.31998193312075834, 0.11676802540258055], [0.08149548343593076, 0.021520537857507026, 0.018677032071976893, 0.058069253986280774, 0.061980699744796565, 0.005401297164480052, 0.043700022412644285, 0.11868290813459505, 0.07762543706884308, 0.07115911872636888, 0.049925846603488734, 0.047694925789631186, 0.05311188370650334, 0.035988382183976715, 0.04580058953574589, 0.07364138915774322, 0.057841940377388275, 0.06471216708662049, 0.03638109417572137, 0.026131527227980476, 0.021518565181102005, 0.04619725071074021, 0.0205016236812357, 0.020478593163012017, 0.02244769002220804, 0.03461174133624281, 0.04729371405236664, 0.06909783659202438, 0.0808581519090841, 0.06129298261516999, 0.017022647962514913, 0.07859503625020867, 0.06796869960042738, 0.04708856719756319, 0.01896499877705449, 0.0857021564978265, 0.04503767321547193, 0.040261720217043356, 0.01697112280394762, 0.030354163646998427, 0.04359378900018431, 0.058120980242928194, 0.2550317271943054, 19.409156499370454, 54.23006242321384, 59.70034891559232, 44.002325304092906, 30.079180079121745, 33.796824101478826, 70.0366101726409, 37.07880458524151, 1.815615755415732, 0.3264851002923904, 0.6204552227450956, 0.3982219106007007, 10.542946630908597, 13.26088930329969, 1.5773540759278883, 0.12131350850986859, 0.4866761383750747, 1.3334382998366512, 14.009896286072271, 53.28080961781164, 84.05108190351918, 76.76316122854911, 84.15236534610872, 79.92546235361408, 76.08066097382577, 74.43231628787133, 67.81794501889136, 68.5593435841222, 72.61796905148414, 71.95963059702228, 70.55011903086017, 72.07740368381624, 77.14061875497141, 80.87395421920284, 79.04944804406936, 79.57768932465585, 72.79957479046237, 73.7726834512526, 73.10460967402305, 72.12460548646989, 72.80171640457647, 71.42268165465325, 70.87060805289977, 64.09226209886613, 74.93035531813099, 53.17340335538311, 33.77663958457209, 53.38570164095972, 61.90510142234064, 72.55016696068549, 71.66222080107659, 66.73363716371598, 71.83263209558302, 66.32796995101437, 60.52076755031463, 55.89259432208154, 57.48561005438528, 64.15816184013121, 66.80416922415456, 67.5471132032333, 66.9596362883045, 72.67006597211285, 74.94614678044474, 72.91129173771029, 71.22989716068392, 66.1114158938008, 66.44100481464018, 66.9351371642082, 71.1006550635061, 70.3472226665866, 65.82113696682838, 67.87004978426042, 72.2901059735206, 75.58046463997134, 76.29485376419561, 67.8393062468498, 79.95291894482028, 54.033579134172015, 6.970006688948601, 0.24316717029338886, 0.12496532707084572, 0.21751816354451642, 0.31264011417665794, 5.118058141200773, 15.515910906176414, 6.559266871021641, 3.475519543693912, 0.6084904615436831, 0.43859704247405457, 0.3780409483419311, 23.33043429159349, 59.87026991382722, 40.591341987732925, 20.364979274811287, 42.40649331000544, 48.172118586878625, 38.70884356960174, 9.803037585750703, 0.0769135575260847, 0.0477392056716546, 0.08169766170002761, 0.027022294046717788, 0.079005659377623, 0.04391933423316768, 0.08270977110031151, 0.04964750004752029, 0.051295956551668145, 0.05387830104859126, 0.10317756433881099, 0.06469538210019951, 0.04335198100776442, 0.006728398936590361, 0.03250616016767679, 0.032997245509778304, 0.03046765574254096, 0.02119990516333811, 0.010941710150350007, 0.04234413871721875, 0.04810778589378442, 0.050162368589231086, 0.0459699715758043, 0.0013604905172776912, 0.0490270760811625, 0.08774739675103657, 0.11576071171270264, 0.024035606428139636, 0.059508668078530225, 0.07232606215702911, 0.0468460429129341, 0.06189192164569132, 0.021269822177747567, 0.05848570704279889, 0.08786303772320671, 0.043368310171870456, 0.0687590265466321, 0.020611141695671027, 0.04445231692384809, 0.05292603460651252, 0.016595075139775872, 0.0010326192498342284, 0.04522468293866804, 0.04861894273950208, 0.021080862760784167, 0.02418131443611797, 0.023932965968044537, 0.021980412777573354, 0.05694948241955811, 0.027872791453715295, 0.034541939235021996, 0.02235718056439392, 0.05716512084848458, 0.08488514670921911, 0.03989588642012208, 0.024916657336777257, 0.03945828550645421, 0.0316231653109313, 0.0236474622356435, 0.05831154844453258, 0.03286145642519959, 0.039070936130179514, 0.02111804675340893, 0.06477047403853747, 0.04327671669964348, 0.02424719416716647, 0.028729605255648497, 0.050687931718364845, 0.019423795428367394, 0.02247017087234605, 0.05011542272123118, 0.10572740372510687, 0.0409744501173977, 0.04798259946607775, 0.026702768349599455, 0.075238713123385, 0.07669974238641801, 1.1917267427329095, 30.60933351516724, 68.10821610112345, 56.32794995461741, 34.451993280841464, 32.317055040790194, 61.13468516257502, 87.52004961813651, 25.439461354286443, 0.5170218922918843, 0.1736027401902022, 0.6819563322970945, 1.3814991015580393, 11.83419873637538, 17.82060834669298, 4.527570316868444, 0.39706229863147585, 0.19131024968960594, 3.2639826882270078, 22.572451945274107, 64.64887780527916, 85.08214750597554, 75.22155207972374, 84.57158042538552, 82.51887075362667, 77.11202467641523, 76.33352833409464, 69.83008169358777, 73.49898046062839, 73.94632677878104, 75.6551936364943, 72.49648540250718, 73.86417665789205, 81.06418132781982, 81.42420784119638, 81.29327128010412, 79.91867665321597, 76.01254509341332, 75.11644824858635, 73.30197549635365, 72.3114985804404, 71.15534859318888, 70.47798664339128, 69.85245489305066, 62.23476879058346, 75.6579000719132, 60.74391118941769, 39.614522764759684, 58.19745748273788, 61.38224555600075, 74.6800845669162, 74.69691153495543, 71.574092988045, 74.28972244262695, 68.43698916896697, 62.50923272102111, 59.12892233940863, 57.55862497514295, 64.98946897445187, 67.5039828208185, 66.15834313054239, 67.20169359637846, 73.33072646971672, 75.21717471461143, 73.10255435205275, 72.22981129923176, 68.64444332738077, 67.59031418831118, 66.45912616483628, 71.74947784792992, 72.79891583227342, 70.54323919357793, 69.65807791679137, 71.63139097152218, 77.08172044446393, 78.45640920823621, 69.03901023249473, 80.906690320661, 66.5081165682885, 13.291815230923316, 1.3012666519611114, 1.0361198215715348, 1.815972323379209, 5.46283349875481, 7.116104681645671, 5.782508628983652, 1.4774565783239182, 0.8333513020507751, 0.470866933465004, 0.3545024985026929, 0.183802388848797, 19.677397589529715, 70.13732094918528, 55.810173557650664, 22.18988160933218, 28.26060256650371, 50.38981099282542, 49.520174457180886, 15.49832594010138, 0.08480613240070882, 0.05944274621264589, 0.05734963695548716, 0.14789785498813277, 0.03566290972934615, 0.011137449445443289, 0.011249485973929687, 0.06514463138075606, 0.060786881949752576, 0.04301106422058037, 0.03395505076754959, 0.05070450603060665, 0.046989500537634864, 0.05497081520696802, 0.03019703135284926, 0.01896292076355988, 0.02123463001372593, 0.013268304812241227, 0.04565691740642633, 0.04073097205330287, 0.0010589786594913852, 0.029804156567420692, 0.020919030517219536, 0.034663138175082785, 0.01754215516660723, 0.0699074612930417, 0.06975270387145781, 0.03127025733251245, 0.06377552883819708, 0.077958777246456, 0.03256799878492471, 0.01145171307613172, 0.03769739793853895, 0.019676543156346007, 0.13024170402317278, 0.24644924417859126, 0.24429152689633832, 0.09484319421913355, 0.15772504701970086, 0.1570256853536252, 0.12209881758016926, 0.15911883674561977, 0.1361986505047929, 0.16684328596438133, 0.16168866336586016, 0.12486882297502411, 0.16924262737795231, 0.11983651397449356, 0.21538799478402063, 0.13042332814826121, 0.12645359075958693, 0.2084789082648293, 0.17443431331025017, 0.16026651306498438, 0.13296687795269874, 0.14559733891679397, 0.11368886522588231, 0.1306233996705663, 0.1812239667220462, 0.10613552174500882, 0.11146943190044935, 0.09053617896091554, 0.1376659233844088, 0.20341719680976486, 0.16528707027675646, 0.15999113509972251, 0.21328845421873757, 0.11596612286783996, 0.14897661403782908, 0.11973164419853881, 0.16709408782903226, 0.18127969195765836, 0.12720051882488112, 0.10673121639317083, 0.23572238913226515, 0.18466747065465297, 0.24353297727723278, 0.7714733385270642, 29.37996856627926, 78.87362387872513, 75.01170527550482, 59.03615044009302, 45.728913430244695, 49.36453088637322, 88.0597677538472, 46.20997644239857, 3.4607309824036014, 0.4087839954562726, 1.3800793261297288, 3.700826615095139, 12.93037372250711, 20.001683465896114, 3.052193330180261, 0.27346397119183696, 0.5083910538063896, 2.6872194822757476, 18.868934339092625, 56.31881475448609, 83.42564429006269, 77.1937668708063, 87.3141565630513, 87.88927016719695, 82.5616559674663, 80.68443313721689, 71.67456842237904, 75.80145097547963, 76.45545128853091, 79.42452861416724, 74.48891608945786, 79.46264620750182, 84.13570311761673, 88.9450074780372, 83.83513973605248, 83.05830647868495, 78.54734543831118, 76.32839787390925, 73.131877991461, 72.12438583374023, 73.77854347229004, 73.70120217723232, 71.6040285172001, 70.91857864010719, 73.59013634343302, 59.87244682927286, 44.314267481527025, 58.58426986202117, 64.68077451952043, 74.52453905536284, 78.46186914751607, 75.13625621795654, 78.16549485729587, 70.5543238116849, 63.83402501383136, 60.72247935879616, 62.6773690408276, 68.292355691233, 70.75740060498639, 70.72751998901367, 71.52673429058444, 79.72717869666316, 80.982831370446, 79.83479284471082, 78.33796147377261, 73.42593023853918, 74.815108237728, 71.18620195696431, 74.44731543141027, 75.98789691925049, 71.72748904074393, 70.50557659518334, 73.20752482260428, 80.66369948848602, 82.18598704184257, 72.82186169778147, 80.02578089314123, 62.41073023888373, 10.866104825850456, 0.7384160930110563, 0.3072552208698565, 0.4281399116641091, 3.4176601709858065, 12.199908764131608, 30.160384908799205, 20.44144980369076, 7.951646504863617, 2.2424182920686664, 0.9816752398206342, 1.2391974728915, 32.411644958680675, 72.0845345527895, 53.10233000786074, 33.45899035853724, 56.146108873428844, 62.66418987704862, 57.52799518646733, 14.90100387604006, 0.1848685534130181, 0.12051617185915671, 0.22833328724147814, 0.2140981325459096, 0.207393208458539, 0.15835092553207952, 0.1325040995593994, 0.14527567391914709, 0.10149990839342918, 0.12888064157337914, 0.16966877144671258, 0.19962339151290157, 0.167861478102784, 0.12247879719061237, 0.1099572279640744, 0.15909680405691748, 0.09734535229302223, 0.22250547254037475, 0.1520993876000566, 0.12304772472670003, 0.12146827359233173, 0.173565692178184, 0.14089944261697032, 0.11562837002378319, 0.1573363952939549, 0.14943672644515194, 0.18347750628186812, 0.09657445333657727, 0.24346557686165457, 0.17824576927288888, 0.23973952438081467, 0.17518722452223304, 0.10839389531963295, 0.14068486138937936, 0.287968497723341], [0.02549814871482311, 0.02385846966306769, 0.023225324806727232, 0.04832394143205978, 0.06236971919274619, 0.02209280170650492, 0.05263679044982118, 0.08291489114203761, 0.05842895907980781, 0.005971532795698412, 0.038224826491768324, 0.01039926244336511, 0.021619298082265644, 0.05103318839363995, 0.06635096705248279, 0.03506331569364956, 0.02370394206786108, 0.0338403137791301, 0.054747002619889476, 0.02398301449213778, 0.014639834895910276, 0.01665958548865972, 0.05435599900421597, 0.060124303995361256, 0.05754950546449231, 0.03761307081027377, 0.029502268129539107, 0.04524819417706421, 0.011864782896854225, 0.017489036545157433, 0.060588174063952706, 0.014897232777589272, 0.07038926164950095, 0.04750588210299612, 0.04788758158082924, 0.012493755446837075, 0.02866450310384314, 0.024493916613620617, 0.01294578945699839, 0.10143823065464536, 0.02419217947810408, 0.04674397701878221, 0.06314947412559582, 0.06995559459732426, 12.826845703586457, 50.03634268237699, 58.32257324649442, 51.27024581355434, 41.90872492328767, 33.037417934786895, 60.33099151426747, 66.2770732756584, 18.980751306779926, 0.3203257533811754, 0.21560174863665335, 0.8046232500383932, 4.326017364378899, 1.5215805461329799, 0.8815369454603043, 0.7276425066013491, 0.22558958930594308, 0.07724350393419305, 1.8525671790684424, 24.633428012171102, 68.5013238845333, 80.91111475421538, 75.04595541184949, 75.99927963749056, 80.45561775084465, 86.70696581563642, 80.44289358200567, 80.11598756236415, 75.17079660969397, 73.52674299670805, 70.6540383062055, 76.72186651537496, 76.01503972084292, 80.84244974197881, 70.12254930311634, 69.25794909077307, 72.66196235533684, 76.83644679284866, 75.71047552170293, 75.75988954113376, 76.9687012703188, 67.40449582376789, 75.96277806066698, 79.69764324926561, 42.82977588715092, 44.22093076090659, 47.30531792486868, 75.88277739863243, 69.68175334315147, 79.40123758008404, 76.0966956230902, 77.14797712141468, 75.89313245588734, 75.30689500993299, 69.54548235862487, 72.0819144095144, 76.69024436704575, 77.89681250049223, 73.07655688255065, 71.75252160718365, 72.73221200512302, 76.07296528354769, 73.29857087904408, 73.96432261313163, 68.85396065250521, 71.5556578482351, 72.75228669566494, 72.65676129248835, 74.42375767615535, 81.34726662789622, 76.1927152449085, 79.15648952607187, 72.4643611907959, 88.67238706158054, 81.11373655257687, 29.569846583950905, 1.9214371351465103, 0.22311244400278216, 0.28290759832147633, 2.017507625202979, 5.279770108961291, 8.446269150703184, 4.941905477354604, 9.570110574845346, 4.052244261387856, 0.12194823533777269, 0.3691083018577868, 6.5847259952176005, 49.75432034461729, 50.081045935230875, 27.63470015218181, 26.228801088948405, 39.967873404102946, 45.492833814313336, 26.92419025205797, 4.762102557766823, 0.13839454960919198, 0.056951179304310394, 0.01593470064577677, 0.03092107637184522, 0.10208535278516431, 0.018429374998255123, 0.059642078460104046, 0.02910619875746629, 0.0868188368997747, 0.02194271933647894, 0.0540954563316078, 0.009041697184945787, 0.04628165827823743, 0.14105336500271676, 0.06423172653622686, 0.03809510865398953, 0.03406996778663128, 0.06277416382105121, 0.024655660757073955, 0.06525657980913116, 0.010050411858115225, 0.012766852385304388, 0.09675295948381386, 0.0810103505970009, 0.03006691514934984, 0.03877841311717226, 0.13075086137940808, 0.02325621730227384, 0.04551303460292759, 0.052314225298863266, 0.09190757593680775, 0.0156967623549844, 0.057708503182737104, 0.004999727759915855, 0.04192745966476299, 0.046663430534423365, 0.014596216722331462, 0.03017909340410223, 0.021154443590691494, 0.04352063526429477, 0.005813067029756044, 0.07978952820262603, 0.04760976745596817, 0.07728930067030654, 0.07864328446767985, 0.06134713737053737, 0.01935782185154817, 0.01767533955224339, 0.02790710261662401, 0.02133218939566324, 0.02150844324440245, 0.009796187495662561, 0.04132758983741364, 0.012957542203366758, 0.036302577824361866, 0.050513125775802525, 0.06875339580038864, 0.02564952960388074, 0.029815657462383953, 0.01337064745565576, 0.012158478024385631, 0.11661863825734585, 0.04648258015813847, 0.11987990519452481, 0.021467379016441204, 0.028118644390375386, 0.055991746109700015, 0.05818741155728217, 0.03566029353908474, 0.04074918196326302, 0.04551533669714005, 0.10662465356290342, 0.05574645624766427, 0.02261378362985148, 0.03826809896817131, 0.04085971312897821, 0.01995239801134073, 0.020786610304287845, 0.13335474826876195, 0.1149730813959914, 19.82704777871409, 67.34432666532456, 62.912244489116055, 43.116524680968254, 28.121607495892434, 50.13566886225055, 84.4021418786818, 73.21139227959418, 11.11698550562705, 0.6741356777568018, 0.23961538749356426, 1.1281964807741105, 3.2886737633136014, 4.298441140882431, 1.8256983305177383, 2.1776464773762614, 0.5414548876785463, 0.1534781926461766, 3.6960047964126836, 33.66964909338182, 74.02533115879183, 81.06664457628804, 81.53993345076039, 79.88592486227714, 82.80507826036023, 83.95713329315186, 78.98560754714474, 78.58034826094105, 74.95008484009774, 73.99098688556303, 73.07169314353698, 76.23389228697746, 79.91745287372221, 81.41141306969428, 71.91143251234486, 67.15590384698683, 70.32746961039882, 76.55711127865699, 74.35538291931152, 74.66056685293876, 75.13398908799695, 69.85540451542025, 75.9794952023414, 77.16119550889539, 49.18900874353225, 44.27159993879257, 57.399337522445194, 74.91366955541795, 69.37760491524973, 80.41029084113337, 76.70905605439218, 80.5554420717301, 74.21642118884672, 72.61333280994047, 66.9114617378481, 71.95185645934075, 73.92389866613573, 77.89849911966633, 76.47562011595696, 74.2360330397083, 73.69094910160189, 77.94941932924333, 75.59790349775746, 77.44112722335323, 70.29288999495968, 71.65633724581811, 73.83182494871079, 72.93339037126111, 73.7233792581866, 76.95468271932295, 74.97335233995992, 80.6246405263101, 73.84319197747016, 86.35112839360391, 85.33399504999961, 42.158348483424035, 3.984780720164699, 0.7139661824030261, 2.0962082666735498, 8.312562415676734, 11.082559843217174, 8.587822587259355, 3.024544542835605, 1.209879594464456, 0.9968798174973458, 0.47591241917783217, 0.28488140853662647, 4.209469037671243, 51.769014404666045, 72.3257524736466, 42.18670721976988, 27.626859334207353, 34.20322479740266, 51.37492995108328, 38.96507240110828, 8.724347545254616, 0.07967612420719478, 0.11780242030058177, 0.06363295221460924, 0.02794584368295487, 0.05776461912319065, 0.053110968231433825, 0.02957905312218974, 0.03165150098803063, 0.03556844342740313, 0.017242915477723848, 0.04684683198349611, 0.07657637158709188, 0.05242360733269204, 0.07204500748024834, 0.04622500607623689, 0.12615909890061425, 0.045651753973816676, 0.05106322287071136, 0.019637591415835966, 0.044535456615830624, 0.053230527743336656, 0.04758682695307559, 0.01624476228420052, 0.03658203520782052, 0.019054722994746223, 0.030999650179799047, 0.08162253911817267, 0.03494897324051108, 0.059419851675028765, 0.04877093841411895, 0.03219492545711898, 0.03686274514503537, 0.028420620928368265, 0.029731606125771522, 0.0427346826801377, 0.08117066215603583, 0.14763029111969858, 0.12038248185549053, 0.11948792864718746, 0.16878050782026785, 0.13044680108226117, 0.1437712304534451, 0.17336022739689197, 0.21023904123613912, 0.19016159277769829, 0.29633359562966133, 0.07508813854186766, 0.11562571169868593, 0.0796290940695232, 0.11125961573974741, 0.1894703669653785, 0.16014453654568042, 0.14949557731949514, 0.11945736173900867, 0.1878794781383007, 0.13406010074240549, 0.2041104910594802, 0.19573606220224213, 0.10142202789504683, 0.12683341715244517, 0.1991098368119809, 0.19323809462929928, 0.18483539712765526, 0.2555593166259989, 0.11771059700197752, 0.12194437425463431, 0.11003715391721457, 0.1509990095491371, 0.14834779374782117, 0.13979731788558347, 0.12076849823877697, 0.23075391057758565, 0.13614545335933087, 0.13564847680109163, 0.11433490717242803, 0.25559696218659805, 0.2022490506210635, 0.15500238585856654, 0.18950885522269434, 0.14295278808041928, 18.43893078065688, 76.75700310737857, 78.70065519886633, 65.98175018064438, 57.914642826203384, 48.99637722199964, 74.05170517583048, 83.49715694304436, 25.94803979319911, 0.8455430091388765, 0.5821520522717507, 1.9430773416834495, 8.376844179245735, 6.276310518864663, 2.0946268160496992, 1.3792377325796312, 0.19255676667296118, 0.22171782690190503, 2.9712125658988957, 28.391472447303038, 72.17514914851036, 81.21569464283606, 80.00046591604911, 81.64905378895422, 84.1890787309216, 91.63532195552703, 85.5168245684716, 85.36698218314879, 79.67778036671301, 79.72262090252292, 75.6039047241211, 78.62444354641822, 83.26996541792347, 83.79138177441013, 71.85404823672387, 65.5523173270687, 72.43546116736628, 76.95652623330393, 78.39806787429318, 76.10768610431303, 76.47684389545073, 71.07340243554884, 77.3415853131202, 78.29920061172979, 60.55880669624575, 51.84431998960434, 62.04708337783814, 82.51771757679602, 68.92194317233178, 85.11973165696668, 80.29017217697637, 83.41123350204961, 80.46558841582268, 81.213576562943, 72.53460299584174, 77.33971042017784, 79.05234275325653, 84.59138055001536, 79.95843379728257, 77.8240603785361, 74.58870118664157, 79.99778301485124, 77.2973095986151, 81.33254205026935, 73.27775093816942, 75.12173560357864, 80.5267930799915, 78.8153374579645, 80.53999577799152, 87.98506229154526, 81.53725839430287, 83.11285095830118, 73.18283742473972, 86.34300124260687, 83.79641025297104, 36.5706419175671, 3.790883743955243, 0.42131400697173615, 1.1504201398741816, 5.878889599154073, 13.453675758454109, 21.059570235590783, 16.407359742349197, 17.633056294533517, 12.302256149630393, 1.069848527831416, 0.671604645829047, 10.407567985596197, 61.54231356036279, 60.52510176935504, 38.60073520291237, 40.10152032298427, 50.94252394091699, 62.95734390135735, 45.76250460840041, 7.752774002090578, 0.1569942910704882, 0.1913493661390197, 0.126046514619262, 0.134335279524807, 0.2265522860351109, 0.127746325827414, 0.10288069760727306, 0.15430113961619718, 0.2808180475427259, 0.16138300960583074, 0.17365795980778434, 0.20829132397568997, 0.07835715828884034, 0.23381977912879762, 0.20630203878446934, 0.2347042736026549, 0.11696535433011672, 0.14707550556669313, 0.09177711882418202, 0.21387981280924814, 0.1734784041200915, 0.11165185275697902, 0.1939593051229754, 0.17291358281527797, 0.17522459429117943, 0.16464729492943134, 0.25021119553956295, 0.14839624114815267, 0.07991713546817342, 0.13019776121983606, 0.1508194998267197, 0.09231409283294793, 0.17368532446843965, 0.09549527293852261, 0.10414563900520725, 0.171907939197075], [0.06629888839539021, 0.02187678214883612, 0.04248139869061209, 0.016158600375356696, 0.021368961616028703, 0.06403429801726053, 0.06231554911562032, 0.01783959454886856, 0.0261276833818204, 0.05113653365462538, 0.004553241662741189, 0.019446967672857068, 0.040082080259678826, 0.03712381641831129, 0.02372158890319688, 0.03536757134321717, 0.08638304012316851, 0.04212351305590522, 0.07210604170517576, 0.08773304026333556, 0.026277748514868082, 0.037680180112440745, 0.05839142843239731, 0.03429874079301953, 0.037538185715675354, 0.06526201137251432, 0.021375798950752905, 0.040693904889086564, 0.036386625330534675, 0.03310676926987306, 0.031546163898442066, 0.0937474050348805, 0.017470730874206752, 0.10793828750930487, 0.0336094570135878, 0.030641360433712125, 0.05667949388284357, 0.010669539220661167, 0.06677133481829398, 0.03680332353518855, 0.06452524163309606, 0.0485813622963765, 0.07022672077460636, 0.012223246927943923, 0.43360144440685555, 3.9738105862371387, 37.8763008886768, 61.90991809291225, 57.69004006539622, 41.62618091029506, 32.24709172402659, 31.366723583590602, 64.1929336517088, 57.70846736046576, 7.752527873362265, 0.021794247666313764, 0.47662858881296655, 5.089433664275754, 1.4746028088754224, 2.736729109479535, 6.060234990812117, 0.3634771878921217, 0.2191476172377025, 0.07253235431327935, 9.660761452490284, 44.18852806091309, 83.08025606216924, 82.42463188786661, 80.91797890201693, 74.25446817951818, 74.90871952426049, 76.8455937600905, 80.3661092635124, 81.32854123269358, 81.31187115946125, 79.44494847328433, 85.27657939541726, 83.95065353762719, 77.85980101554625, 77.44123704971807, 78.78089120311122, 75.76629084925499, 75.28900115720688, 79.59436724262854, 65.03635306512156, 78.82918342467278, 83.81243705749512, 52.7158078839702, 44.076297283172615, 67.41182281124976, 32.829508781433105, 68.514997266954, 60.48467782235915, 76.0304860145815, 74.21737040242841, 72.93692834915655, 72.86890660562824, 73.72753697056925, 73.96138868024273, 73.24738394829535, 70.91604478897588, 71.72216246204992, 76.88601770708638, 79.51729266874253, 78.98290895646619, 81.42603566569667, 83.96318158795758, 81.25128622977965, 80.5040668672131, 77.42641049046671, 78.5129854756017, 81.88800457985171, 72.92731854223436, 68.9406999464958, 78.83981304783975, 82.46647573286488, 86.92243729868244, 53.697553603879875, 8.055857996786795, 0.18931707277173, 0.22890782254117154, 0.2007907256484032, 8.6226277389834, 13.234068136061392, 18.820365590433923, 9.280751443678334, 3.4782370107789196, 1.20879800088944, 0.6670061570982779, 1.1252365621828264, 28.306094215762233, 59.41387468768705, 37.06595097818683, 21.448269274926957, 29.048387081392352, 38.130525389025294, 41.2458953549785, 18.496485679380356, 1.3298830389976504, 0.06333880892564213, 0.053129641624588164, 0.01582258750849794, 0.038746708568425915, 0.03888443202501343, 0.05871006355230367, 0.04011087367431291, 0.04477050005187912, 0.006702354341189588, 0.1289509531230696, 0.03307521793871157, 0.036621205283388976, 0.011350186316356545, 0.08077736793746872, 0.10718897691056614, 0.06424024926438447, 0.051039983593528314, 0.03715453654407494, 0.06326301984729306, 0.07577261511957453, 0.04491224547006911, 0.06693235117821925, 0.0555445269621428, 0.03875189498367329, 0.08361319560677775, 0.026778159062227896, 0.04394630435854197, 0.053253345672161355, 0.029318403197272174, 0.05326991615396354, 0.02125865070059175, 0.04896978802618481, 0.050628345399614305, 0.07553234696388245, 0.07510228052494988, 0.040509810130442345, 0.033562212371297424, 0.06926417726302339, 0.03275375595436462, 0.06082134824546595, 0.06338776960488289, 0.06623417694842623, 0.0014692712917871353, 0.05758555373176933, 0.058056935292458346, 0.02553494583304611, 0.026449568629745516, 0.005766763718002626, 0.02744689636353043, 0.04198639480877788, 0.03903526707642502, 0.027524474257182692, 0.02991020037311941, 0.03064061732842557, 0.03650671727354488, 0.027289664477951107, 0.06065881886189023, 0.048058909484215324, 0.07057635564236872, 0.06939517063719612, 0.03474191499633655, 0.018037591888118657, 0.0545875950446052, 0.06312425451112852, 0.08485131626648289, 0.01986158020313709, 0.05655637206209283, 0.021251505015478022, 0.024583524002903895, 0.0882343682009847, 0.055236130607344454, 0.08352374718073877, 0.03935866343278078, 0.05051266612304796, 0.02716695825989929, 0.026059112766937866, 0.03477283813540013, 0.0359284051603848, 0.025559726862176776, 0.030901995036871206, 0.0453868790739967, 0.2092437704484309, 7.9250739178349905, 51.79447843182472, 71.37047490765973, 58.90284476741668, 33.68464823692076, 33.88621491770591, 55.13414521371165, 96.21041374821817, 53.48238414333713, 2.1140751531047206, 0.0815731111252981, 0.9476505171868109, 1.647711713467875, 3.185309748495779, 4.255560319269858, 10.900476555670462, 1.4678975170658481, 0.5797522971707006, 0.21000507798406387, 15.663712678417085, 56.043327085433475, 85.09207894725185, 80.7203620479953, 79.90642316879766, 77.54799612106817, 79.95073026226413, 80.72769688021752, 83.77150320237683, 82.28054754195675, 83.04524498601114, 84.8011096831291, 86.51194557066887, 84.03565914400163, 75.34519303229548, 80.47784974498134, 78.99501339081796, 75.74480410545104, 77.61357030560895, 76.7460596945978, 65.46454644972279, 71.54029784664031, 83.86450259916245, 66.4514147850775, 56.51315250704366, 64.35990110520395, 44.478379449536725, 77.13762990890011, 62.78106081870295, 77.51507959058209, 76.61616648397138, 77.52238304384294, 77.89206643258372, 78.88383773065384, 78.26466806473272, 75.09339255671348, 73.39245673148864, 75.34218849674349, 75.57238455741637, 78.51921419943534, 78.82890101402037, 81.09204584552397, 82.23434202132687, 81.93074272524926, 82.83006375835788, 80.85177713824858, 81.01675987243652, 84.63226733669158, 78.62283537464758, 74.32512575580229, 77.41218797622189, 79.75501183540591, 85.27657939541726, 68.53336964884113, 17.382644337992517, 0.8078242105341727, 1.1828310523302326, 2.655974862075621, 7.08568032710783, 14.57851738699021, 9.293984540047186, 0.8473951645916509, 0.029649067812809543, 0.21306654919059048, 0.27143926209499764, 0.6523379635426306, 24.19965309481467, 74.72932600205945, 56.61895452007171, 27.85378021578635, 23.27021021996775, 41.8058725326292, 53.89569605550459, 27.26688773401322, 2.5302905997922345, 0.053965512497891346, 0.0499362922123363, 0.04055341202465277, 0.053895825309859174, 0.06083031913505928, 0.11542965447710407, 0.06638355643278168, 0.05103983037594346, 0.03611130482186714, 0.06690968263653979, 0.029844115713551164, 0.024146198880888765, 0.04241631186056522, 0.06219556442491951, 0.04372801143495787, 0.017555960071002765, 0.03544412267905089, 0.007839214456673231, 0.11477876319399766, 0.08425180650045795, 0.016104194726194107, 0.03225692112239138, 0.06897483351490191, 0.04226316705406193, 0.07731725521866353, 0.01664682437906102, 0.04485848908042235, 0.038443153889309016, 0.013265659893682648, 0.028625813748447165, 0.01810547493908915, 0.08180953351961029, 0.02954540462533553, 0.038075182707079, 0.0401284477312959, 0.060071221763087865, 0.0610390053160729, 0.16923608498707896, 0.13187914035252987, 0.1632870598545959, 0.20723652815626514, 0.22305967586655773, 0.17081136094225993, 0.16657195294335966, 0.19751111856631695, 0.15392358084359478, 0.1758169181524746, 0.20038476033556848, 0.1385918938584866, 0.1406816131765804, 0.16784715225859997, 0.23841117388538777, 0.17504726025846698, 0.21320548689653798, 0.23714470797248427, 0.15990300434491328, 0.20017610862851146, 0.07988952565938234, 0.13150829251014418, 0.19582479050563228, 0.15251423953281296, 0.15369707928790202, 0.1918338248205762, 0.155071119267133, 0.17171220373242133, 0.1280200260601217, 0.12063097013461015, 0.13081021787178132, 0.22103528852664658, 0.16058730472239757, 0.23223547865786862, 0.1028904039412737, 0.1399885947185178, 0.19047582672247965, 0.16617067608862154, 0.12780026607816258, 0.10792477371832056, 0.16749473649167246, 0.12701203055199117, 0.21529021132136547, 0.10501530967772969, 0.5902587946864867, 6.144108503095566, 54.97501465582079, 87.44610509564801, 73.69491854021626, 59.525038580740656, 45.6914234161377, 42.215058111375384, 81.59447008563627, 72.89182893691525, 11.63461285252725, 0.2943250969532998, 1.5416348893796246, 14.54184126469397, 13.499556702952232, 4.941388214788129, 11.722494536830533, 0.8124131384876467, 0.4053994802938354, 0.19316677184354877, 12.427727868480067, 48.3986746880316, 89.04713815258395, 85.01119182955834, 87.18103131940289, 77.4674306377288, 79.45798643173711, 78.49736659757554, 85.1045834633612, 86.65963849713727, 88.56838933883175, 84.10928987687635, 89.00140331637475, 86.3069389712426, 80.80853692946896, 83.45142210683515, 80.9781559052006, 74.5667516031573, 75.64342652597736, 77.31339916106194, 68.3441702012093, 76.32111795486944, 85.74443186483076, 62.32207290587887, 58.1763865101722, 78.25594471346948, 46.21928814918765, 81.07643481223815, 68.88060139071557, 77.44986626409715, 82.62342545293993, 80.0224547232351, 79.3795233388101, 79.62740928896012, 81.92123489995157, 78.67788191764586, 76.25741081853067, 79.05611607336229, 81.105727072685, 87.7120888617731, 85.92795172045308, 85.91348601925759, 89.51219004969444, 85.26000345906904, 89.65336399693643, 82.77446808353548, 82.11772211136358, 83.52502146074849, 79.86418708678215, 69.78658260837679, 80.48913832633727, 84.15895492799821, 87.995527175165, 62.06905257317328, 11.788781612150132, 0.9239581143183093, 0.6700236855014678, 1.2382248476628335, 15.201608442491102, 22.49994497145376, 35.56291049526584, 19.732400986456103, 14.73886387963449, 2.9068312721867717, 0.789028641677672, 2.131153888279392, 35.76537539882045, 72.95210007698306, 46.74889049222393, 32.236856299061934, 42.136257694613555, 53.72093485247705, 65.83990943047309, 29.52602194201562, 2.216595858335495, 0.2580183516106298, 0.14018768564827983, 0.15729824411532572, 0.13009182658166657, 0.13828121456167392, 0.29934392280636296, 0.1915410413376747, 0.13791674057081824, 0.08570575711107062, 0.23975060201219975, 0.20468717140536155, 0.0779515990026055, 0.08797905407845975, 0.27739458447021825, 0.15541694667791167, 0.097542037706702, 0.183376474606414, 0.10782717411676723, 0.2860279663676216, 0.2722560343963485, 0.12247719606685063, 0.09328064298437488, 0.26346299977552506, 0.13749752193689346, 0.19896326887030757, 0.12495518406672824, 0.10915282798270065, 0.15987747829527627, 0.11151178124090357, 0.18702650052164832, 0.1398973689684945, 0.27223507423074017, 0.09841370020782757, 0.1320886653998206, 0.13242926809095568, 0.10922430398603601, 0.20435661978779301], [0.00821918592743215, 0.02489505174209274, 0.07027944294555534, 0.06451046379703669, 0.03940810291697422, 0.01071059961818279, 0.0818062776459321, 0.11080628321055444, 0.016233008580222245, 0.10842073904049974, 0.08542239650963776, 0.055205310890150655, 0.08417049392817483, 0.06073560002410124, 0.023390252045505953, 0.06745096205944015, 0.011311462487003977, 0.024346385316382495, 0.04002243648433397, 0.18759863030525947, 0.13716350760190718, 0.06970775749294028, 0.0882962374617496, 0.18430613762428685, 0.13418226112281123, 0.15201786052315466, 0.07756992633784972, 0.057207359106189785, 0.07654984196227405, 0.2065455781355981, 0.14130867146436246, 0.11936756091252451, 0.1971876149576518, 0.16117000651936378, 0.11783767566685716, 0.03761171866508742, 0.06196194208197056, 0.04253793214898437, 0.0392758378368472, 0.046961994150713574, 0.07009880707388924, 0.09009651344029174, 0.0970648798430639, 0.12994642309363813, 0.021480076923786152, 0.2703470965066264, 0.19158155206711064, 17.06403413126546, 47.86878208960257, 62.10761731670749, 49.073330202410304, 36.36500773891326, 21.329725442394135, 36.58454279745779, 73.94988044615715, 36.97404592267929, 3.0150815796467567, 0.5819344833012551, 0.48980729293919384, 4.148662984371185, 10.803473399531457, 1.6827530654207354, 0.28325770050287247, 0.2378073587052284, 0.23709526465785122, 0.41472512988313553, 14.484150063607002, 48.65816300915134, 78.28659411399596, 90.3651172884049, 90.32497575206142, 83.92624855041504, 81.13489381728634, 77.92947799928727, 75.37444606904062, 78.34833222050821, 71.98447488969373, 72.86023032280707, 78.12159569032731, 75.19088698971656, 77.2600470819781, 76.56891761287567, 85.68538450425672, 73.1650298641574, 80.4191004845404, 59.088980843943936, 19.398772024339248, 1.0580371680759615, 3.4470882434998793, 43.24668853513656, 37.24872166110624, 54.58278156095936, 65.69608788336477, 73.84285465363534, 93.9684497156451, 83.18310845282771, 82.3455882841541, 80.75005439019974, 82.88552607259443, 81.90720850421538, 82.80768271415465, 87.78662173978745, 81.11250492834276, 86.27926272730674, 80.02244687849476, 79.39791925491826, 81.80217527574109, 81.01312775765696, 76.82326762906968, 84.08392783134215, 71.8428930159538, 77.10781205085017, 91.9330769200479, 86.77142604704827, 84.72787118727162, 60.32763004302979, 20.18744887844209, 1.0900303481086608, 0.044997737051979195, 0.10060758450098577, 2.703674070296749, 9.046116240562933, 1.191176998038446, 11.381808250181138, 8.441578976569637, 2.0376342871496758, 0.08506702364332254, 0.08616835930414739, 10.756550085160042, 49.75803482917048, 47.94773940117129, 29.825061482767907, 29.30913840570758, 43.6920383668715, 52.82047633201846, 35.14271482344597, 5.43623443572752, 0.0908797081079214, 0.06419295865681864, 0.06750397534380037, 0.0469858922635115, 0.06860691978926621, 0.00717331598993511, 0.1088474729969617, 0.12635835070884036, 0.03725086060923435, 0.011158033270358799, 0.022247993882985848, 0.06693082666324993, 0.03324044395178076, 0.06916335243130885, 0.08790664344785676, 0.05383568740780315, 0.06238861475139857, 0.048205825995894215, 0.0369103383573313, 0.05457312364371554, 0.09848063330977194, 0.030758843847340157, 0.038956919264408855, 0.038592755539162506, 0.006412306749787663, 0.04775841915679555, 0.02890942332845542, 0.07643033990696554, 0.026055389579625863, 0.07578190010521682, 0.07082707323734799, 0.0490886772111539, 0.04075684667294545, 0.04482614101781961, 0.031346153663170916, 0.09645190991220937, 0.036170435318302725, 0.11143764691247095, 0.015910867650452402, 0.026937087832559502, 0.031137411940782785, 0.08595859676960015, 0.09323055615588542, 0.008788589395642763, 0.05884726606910268, 0.031029297782468702, 0.019309573634076985, 0.06195280648347351, 0.13588933484448543, 0.02673766748499005, 0.03168872711549123, 0.023027400245829936, 0.0421493340493931, 0.028875202180877812, 0.049991745486735344, 0.05593009901443317, 0.0849546921709853, 0.04582001369506602, 0.06698973116374786, 0.14440613348157177, 0.022925995102512742, 0.05505071434703085, 0.026298760391411283, 0.01700472725074618, 0.09402798473714821, 0.07492378203859253, 0.0317791925232497, 0.0888248151468654, 0.09772572260830673, 0.11844966500516861, 0.022303351396394354, 0.07927698473776541, 0.09833351378479312, 0.06552130915224552, 0.024872187847992586, 0.056606987491250045, 0.06998845976927588, 0.0639872219143135, 0.05263652614948731, 0.050641399537844044, 0.09141894207606394, 0.044519165756120804, 0.06220614792959345, 0.04331865618305822, 0.30859939874179904, 1.192481186120741, 28.256419358714936, 64.7564095835532, 65.81880707894602, 44.005698542441095, 21.564322402400357, 34.52584366644583, 79.087612705846, 91.9467895261703, 29.393998884385635, 0.8147520968510259, 0.10897006238660506, 1.011273445140931, 4.15549575321136, 5.328633525679189, 1.8028002688961646, 1.1653370362135673, 0.8253562858989163, 0.5918969971037681, 1.057772530663398, 23.22867035865784, 63.233008077067716, 86.61475089288528, 90.29829579014933, 84.91076346366637, 80.61848240513956, 78.94683099562123, 77.66289803289598, 75.91272861726823, 77.2075657690725, 75.08522618201472, 71.8277055986466, 74.73911623800956, 70.65249289235761, 74.25650781200778, 75.07009367788993, 82.1375379254741, 76.26993102412071, 82.58398209848713, 73.10701800930885, 36.458889668987645, 4.94584696908151, 8.527604399188872, 66.6484981967557, 44.771007876242365, 67.22114855243315, 65.05827519201463, 73.8084162435224, 91.32865536597468, 84.595059733237, 83.40316910897532, 81.21353733924128, 81.68718707176947, 82.89701077245897, 82.10968909725067, 89.98230964906755, 87.18032529277187, 83.29320938356462, 79.29541203283495, 78.89438106167701, 79.75190531822943, 80.13723111921742, 80.3726988454019, 78.82870489551176, 79.9635014995452, 76.12484255144673, 87.40509279312627, 82.04660169539913, 98.13798412199944, 74.80650255756994, 32.51579957623636, 2.41505773798112, 0.20386768715275874, 0.42251841976277293, 3.162253076030362, 7.3765078956081025, 3.9275785896085926, 2.9821589204572865, 2.994683293565627, 0.673498721613038, 0.4246182667632257, 0.29133036732673645, 7.013170901806125, 58.43390972383561, 71.08316913727792, 40.48602242623606, 22.02186296063085, 31.953869058239846, 56.67489928583945, 47.40257309329125, 10.139123912780516, 0.12665454328300493, 0.07921598115635496, 0.06967537495638094, 0.03689721527118837, 0.04586656502778492, 0.03945484577167419, 0.07484728815935313, 0.09425518343285208, 0.02351080172605092, 0.03430190473614681, 0.031220503752270055, 0.1020053502232317, 0.045731419457062605, 0.08616098953831582, 0.09574398338314026, 0.028470860974442576, 0.043934027799555374, 0.039295032169790044, 0.03047635084048154, 0.07219584253165992, 0.04608986050551457, 0.011674332481268193, 0.05337399685935629, 0.11273426604607414, 0.0777142649636634, 0.005762160008382654, 0.05087311815230116, 0.1520859657396232, 0.04885181814672486, 0.021573108726090962, 0.05356254258884057, 0.01731858772766446, 0.033065691635373144, 0.07795421902330653, 0.05209978962797792, 0.01557039136382481, 0.045570295844827934, 0.04534167605602453, 0.04345224659529425, 0.1030174213191194, 0.1269613002096453, 0.2065208947826778, 0.11718365108414043, 0.09223391407079275, 0.2638276576274826, 0.19057998403666482, 0.3106848739327923, 0.12359983663284972, 0.3952392545198241, 0.18113084107397065, 0.1308862750809039, 0.17443241341219795, 0.1334669188626351, 0.12182586811362736, 0.2103429840457055, 0.11222211328605491, 0.21753844955275137, 0.14561016322864642, 0.3073278766485953, 0.3245120255216476, 0.11515388580700082, 0.3855876498405011, 0.20858044555831343, 0.16655945038843542, 0.30238559830092615, 0.17692270478413952, 0.2124257626072053, 0.2081519266169879, 0.40479466919937446, 0.2757246353693547, 0.2201361924169525, 0.4242685935910671, 0.23875923827290538, 0.22841165803613203, 0.15434918865080804, 0.1642653234903851, 0.2317691456166006, 0.11006631122361268, 0.2114905224692437, 0.1352822408080101, 0.19490569950111453, 0.19414767082179749, 0.2763622350269749, 0.07595635364733397, 0.30887270826966534, 0.7387656742526639, 30.636227246253725, 80.2071120662074, 82.65163513921922, 63.37112257557531, 56.71692748223582, 33.572456682882006, 50.355082327319735, 89.94799675480013, 50.99082792958906, 5.015468549343848, 0.6845199689269067, 1.912800566323342, 15.28510001397902, 23.166502752611716, 6.006810838176358, 1.4407577798251183, 0.5479479424895779, 0.4802493042042179, 0.552461242243167, 16.533686537896436, 53.34934126946234, 83.86308270116007, 94.35658393367645, 93.41795290670088, 86.98773691731115, 86.5581589360391, 82.86042290349161, 74.70334422203803, 80.7061944469329, 74.19165534357872, 69.21525016907724, 73.53802373332363, 70.43316179706206, 77.26701321140413, 78.53348378212222, 87.55284847751741, 77.1288045760124, 85.81996102486887, 60.763150415112904, 25.93850451131021, 2.066791225825587, 4.329705372933419, 61.55983086555236, 51.12465527749831, 71.07844660359045, 70.63354784442534, 78.47870396029565, 86.73298681935957, 88.52005004882814, 86.90912477431759, 88.54846369835639, 84.52521800994873, 86.79729800070487, 87.70509135338568, 94.34309882502403, 89.46133259804019, 84.64194774627686, 79.84262189557477, 80.69154831670946, 83.73080468946888, 84.19775501374276, 81.5600944334461, 92.29321325978925, 95.0111412232922, 86.02263773641279, 105.23635233602216, 100.28658789973106, 104.29827044087072, 67.21928150423112, 22.026275627074703, 1.1338086570462873, 0.49311617990174605, 0.5334405048239617, 6.865722633177235, 21.517406932769283, 13.030934468392404, 19.906981760455718, 20.355243952043597, 6.239336296435326, 0.9906096636287629, 0.3700886186092131, 15.286920974331519, 62.051625482497684, 58.66937352764992, 40.51007832250288, 40.11300894521898, 56.1246495862161, 71.65080670387515, 56.3626786201231, 10.472312588845531, 0.21210376053087174, 0.18317186784359718, 0.1969004852036315, 0.16249973597305437, 0.21663130951985238, 0.10592224286688913, 0.18423789451199193, 0.28753532096743584, 0.09517680252751998, 0.1777585373530465, 0.1492932228551757, 0.2462566037091517, 0.1570238007773315, 0.27922452337318854, 0.1948606841746838, 0.08955092094237767, 0.10724939826515414, 0.16076777971559958, 0.13569188334288138, 0.16128119652069386, 0.12495889193228177, 0.09150839050210292, 0.130125411876267, 0.16014603807801203, 0.16589396513037144, 0.1090053254137597, 0.3404029260479635, 0.2576953076547192, 0.18395618866047553, 0.169256248421246, 0.2247612337551771, 0.20058737526978218, 0.19461928986974303, 0.1410766387538564, 0.23655842088403242, 0.13122749064237843, 0.31580987957216083, 0.1623435153235351, 0.1399616743888586], [0.08745428385032762, 0.03478914048642882, 0.08701962088384936, 0.09427712419100347, 0.029784213383531863, 0.18125736815554483, 0.09098312231682001, 0.025550033934714816, 0.06933377635094427, 0.02813422661875525, 0.022283639954102617, 0.05787619216848285, 0.07250387116425461, 0.13279493717897323, 0.007838117514526653, 0.14976828929878053, 0.05953145536383795, 0.17441508450335072, 0.12448538064716325, 0.2624151447126942, 0.16155429154394135, 0.021520126085247726, 0.008507538549301606, 0.15140382573008537, 0.03505261344534736, 0.053721731829066435, 0.1537129679514516, 0.02038557093680626, 0.06271381907525563, 0.010619838308963564, 0.036865135339359124, 0.0584154452888235, 0.06467858945289928, 0.02923410671252397, 0.06581888068467379, 0.10970750628339668, 0.033638035923603087, 0.1241876865406671, 0.027230443966184414, 0.010333596259325502, 0.07710433640186826, 0.01273950208879767, 0.09034006045229974, 0.08342760314624156, 0.1349928434337339, 0.0858801417052746, 0.013664465157255052, 0.33959666447293374, 3.16721095192817, 35.046612831854056, 62.201973853572724, 60.08356840379777, 49.90298994125859, 31.51403407896719, 26.78285352645382, 57.27343336228402, 69.80164450983848, 23.724687407093665, 0.6314832729197318, 2.061675229380208, 1.381950051553788, 1.6554029910795152, 2.9393876800614023, 0.5745774651727369, 1.229266889633671, 0.20056405555336707, 0.04814842302772788, 1.4620085685483872, 8.886496366993073, 26.92665742289636, 48.513172595731675, 65.7791519165039, 75.66738436298986, 79.97617075520178, 84.23455469069943, 83.29648848502868, 85.76833478866085, 71.6369999608686, 66.61430297359344, 66.1796651347991, 67.73331596005347, 70.96556079003119, 56.20831766436177, 42.15166476465041, 13.13557545984945, 0.5006627281827312, 0.17456378216945356, 0.17053250493782182, 0.09322771396968635, 0.1422149228352693, 3.2675162534559927, 20.958302482481926, 60.979206331314586, 60.50565073567053, 49.90419803127166, 82.32341120319983, 77.4595780526438, 78.36850889267461, 80.60578961526194, 75.35741513775241, 72.64443720540693, 74.20633285276352, 78.38675575871622, 80.5737595404348, 91.37182497209119, 85.56633272478658, 89.22696313550396, 90.61755318795481, 92.96811980585899, 105.61734784033992, 90.96593810665993, 86.36684140851422, 62.72532001618416, 34.124204727911184, 9.333978987509205, 0.3526808027057879, 0.13076901766321353, 0.05749464973867421, 0.1658372439804577, 0.7502918041521504, 8.248946474444482, 11.250952097677416, 3.3737899314972664, 7.117976632810409, 1.4831800518497344, 0.44301436673248973, 4.157765824948588, 33.918523480815274, 56.05576492124989, 33.54324679220877, 24.248135551329582, 45.38897337452058, 59.05964543742519, 49.33954146600539, 18.180932960202618, 1.4826186626188218, 0.05159317185321162, 0.031923508166425654, 0.012027647443896821, 0.033745334198277806, 0.04533194290894655, 0.030325473654234124, 0.001769659753453227, 0.09610244358379035, 0.04512545540027561, 0.05804954254398904, 0.05264538978677123, 0.04534222380889039, 0.036873389936743245, 0.06738906215515829, 0.03307393857187802, 0.0836864565949767, 0.07468127690616154, 0.05009889437426483, 0.030575982490254026, 0.164851013030256, 0.04790807443280374, 0.09682488747902455, 0.016930499076542836, 0.07821160158322704, 0.20157921398358963, 0.15584532772341084, 0.148303804979209, 0.413645037840451, 0.11656858973325261, 0.1325882313352439, 0.006502921065886415, 0.14614735940291038, 0.018199479673057795, 0.20725632386822856, 0.037937187289278355, 0.12445613141021422, 0.2234887617129472, 0.1640790875159925, 0.21958156008153196, 0.1354579354125646, 0.15503828473869832, 0.027698295776762312, 0.12185732368379833, 0.09667964486946022, 0.141139886972885, 0.1112807138011821, 0.07239311783304138, 0.031701402040198445, 0.08207649983946355, 0.032140498740538474, 0.03999796763603245, 0.106402043733866, 0.05248041658271706, 0.14226007605752639, 0.08604743232529971, 0.1774094157641934, 0.03506186778747267, 0.06757912856917228, 0.12362707871943714, 0.09941948172185691, 0.08992376061336649, 0.024682941148057583, 0.012158568997326638, 0.22299828158030588, 0.24127485651162364, 0.04835419424418961, 0.06683645229185782, 0.06140103931688975, 0.02739122858451259, 0.017067529223558885, 0.10883524623369017, 0.0367864542790959, 0.03000769272236334, 0.10582207687078946, 0.12409730348736049, 0.056656982389188586, 0.07325563324435104, 0.08107316214591265, 0.0562077445999509, 0.06436342854172954, 0.12356468851888373, 0.021987230960099448, 0.07340534980739317, 0.09603080670199088, 0.0882030122222439, 0.06939777533613867, 0.08561013401636193, 0.13262598414815244, 8.721066482605474, 52.02068151966218, 73.02157309747511, 61.49566873427361, 26.884642954795595, 17.113008845236994, 50.408265744486165, 91.7779314902521, 76.98469669588151, 14.892050085529206, 0.8692274446929655, 0.29008106178333687, 1.960878650988302, 1.0798872214171196, 3.5519182441696047, 1.3258297597208333, 0.5266969086181733, 1.1151771535796504, 0.03748921354511573, 3.3361332166579465, 16.261586816080158, 40.516071704126176, 65.23521723285799, 79.75594535950692, 84.21679419855919, 87.98123405825707, 86.98870182037355, 89.60235749521564, 92.03822781962734, 82.07334441523399, 78.88291989603351, 87.61970135473436, 82.15875794810634, 78.07610404106879, 73.00112970413701, 52.23705122547766, 27.464741891430272, 4.064348695739623, 0.040019341489119876, 0.35698744258092296, 0.054207795464824286, 2.7824058455805627, 8.647413196102265, 36.60289948986423, 75.74706339067029, 61.65405011946156, 58.79470502176593, 85.59760970454063, 79.66877460479736, 82.84281146141791, 82.69586378528227, 78.62415329102548, 75.17231064458048, 76.07101978794222, 74.13637345837009, 82.65456907210812, 93.24619231685516, 86.7189133551813, 86.27796834514987, 93.78992695962229, 95.77492867746662, 108.31726428001159, 97.50999696793096, 88.69565456144272, 76.62296787385019, 53.735263270716516, 20.42850402093703, 3.550415976393608, 0.19448091906885948, 0.4477912007320312, 2.063161807675516, 2.23020427650021, 3.9573589399937665, 13.24547831089266, 3.4588774173490466, 3.69626171165897, 0.3207930363714695, 0.3802510507164463, 1.510626837130516, 33.00634099591163, 75.90797470461938, 51.55802619072699, 22.64714171809535, 32.518400107660604, 58.21812445117582, 59.08573312144126, 28.37620854377747, 3.1724424131454962, 0.11781172060798253, 0.055521567307052114, 0.08332327729271305, 0.04085320138162182, 0.03571214236980004, 0.07197768367346256, 0.05192609451290581, 0.04103949481260873, 0.0770857511088252, 0.0068803448154921495, 0.033267574955619154, 0.04091274556553653, 0.040668302230657115, 0.06873356178402901, 0.05756355934746324, 0.06764396259020414, 0.007918965167200734, 0.028097033050031434, 0.028245947135972883, 0.0049095309617358356, 0.02137635627971782, 0.026619163259202917, 0.03523016581311822, 0.0038878078762096388, 0.06233244518479032, 0.10764284570130611, 0.079468269231579, 0.2046887189029686, 0.05458304065189535, 0.04066371719443029, 0.052063948204440456, 0.009808725482153316, 0.033987107716741106, 0.20585603771671174, 0.03977201766364517, 0.1011341473748607, 0.16749922576690876, 0.20578385691248602, 0.15355912217449758, 0.008342559599587995, 0.263027616686398, 0.16471555336348473, 0.32010478298029593, 0.20064444882014107, 0.20925492468860843, 0.22505611631899114, 0.18047361424373043, 0.11530616876458931, 0.1324700392902859, 0.11018893125677302, 0.08580483526231782, 0.1578957926962645, 0.23894112286788805, 0.23521626548421, 0.13188767457200637, 0.26620872018318026, 0.10810927833400427, 0.2223789148152836, 0.4858859952899718, 0.3110981324026662, 0.20417845838012236, 0.11620687365892435, 0.09432038517608758, 0.25614345866826277, 0.2488853884560447, 0.1900028440380289, 0.27905074398844476, 0.09973291893519702, 0.09774647593017548, 0.058263223618268974, 0.1499300564248716, 0.19334435102439698, 0.15891069065659277, 0.13929615848727767, 0.3293703712763325, 0.13615676081709324, 0.1532582181595987, 0.18401226629653286, 0.1491170379543497, 0.1358587066492727, 0.138419539397282, 0.11419647508451056, 0.13421780760249785, 0.21194671250639424, 0.3597795572732726, 0.2662453085424439, 0.19567849835561169, 0.6963664461528102, 7.644783796802645, 59.65808145461544, 89.51592414609848, 76.44475890744117, 64.84325085916828, 48.515365200658, 42.71572905202066, 73.64570848403439, 88.40514029225996, 34.19597233495405, 0.8046080508539755, 2.8836230981734494, 8.3222016403752, 14.08918994088327, 18.927571811983665, 4.305771560438218, 3.8560576015903107, 0.8906965991181712, 0.12428386121868126, 2.39436331295198, 12.276485197005734, 31.29696030770579, 55.0086058339765, 73.66512421638735, 79.63395180240755, 85.06678750438076, 88.06915006329938, 84.45396423339844, 98.64345212136546, 83.39959975211852, 76.24731463770713, 85.03819342582457, 81.65525897856682, 80.56960182805216, 65.83682644751765, 45.59039492760935, 16.331933544528102, 1.8332887296715092, 0.16248024669626068, 0.20025238034225282, 0.23204328251942513, 1.1271656328631987, 5.386738046523064, 34.07486523351362, 79.67260283808555, 60.59398251195108, 52.37727988150812, 85.15530755442958, 74.41845463168237, 86.25522644289079, 85.17466052885979, 83.41295934492543, 71.90077935495685, 75.57313765248945, 78.6469030380249, 86.11647652041528, 104.63867725864534, 88.26442133995795, 82.87462972825574, 91.25428722750758, 98.19128128790088, 99.2790408288279, 96.32846924566455, 82.3637096343502, 58.72584781339092, 40.91779693480461, 13.528274336168844, 2.149137220075054, 0.16909276525820457, 0.27978784314567046, 0.5492380958411002, 5.186466728487323, 16.76024263904941, 25.224729238017915, 14.611822232123345, 18.958115308515488, 4.879377503548899, 0.47250449236842895, 7.452480283475692, 45.110316430368734, 74.83999175410118, 51.8184401912074, 36.21322770272532, 57.995310291167236, 72.74995680778258, 66.6936368326987, 29.985849242056574, 2.6697073251970354, 0.3005137084232223, 0.21175008837974843, 0.18468433991074565, 0.2074480297104005, 0.16847183567381677, 0.20344911203269037, 0.12647232927021482, 0.180720018763696, 0.1398079205424555, 0.10505608853793914, 0.08758150807191288, 0.11827789277078644, 0.18824514722631824, 0.1369113574225095, 0.26410240740064655, 0.2542945820718043, 0.3414133040895385, 0.16677279055358904, 0.1503792444183942, 0.2285976948276643, 0.3496612518304779, 0.14739024512950452, 0.19239124571604116, 0.15026342724600147, 0.299966752288803, 0.29660892762964775, 0.36163355133706526, 0.6753435839087732, 0.2140729129314423, 0.23868292059388854, 0.18374258802542764, 0.25792433730056213, 0.21686092139251772, 0.517361851469163, 0.0849218346599129, 0.2753252584126688, 0.3188720862230947, 0.3184825151918396, 0.2868983648236721, 0.27680975294882254], [0.0679951526164528, 0.04130918074459319, 0.09469540053678137, 0.067426914559497, 0.06353965802719036, 0.11999262737170344, 0.05461573728450364, 0.044960022543466864, 0.20704040964764936, 0.09838779877510764, 0.19594034720813075, 0.12194631245708275, 0.02687510365860597, 0.1531212876040128, 0.11075542263326146, 0.04107950375445428, 0.09608985675919442, 0.03999173934120805, 0.11897392961527072, 0.19657639936814386, 0.06388797522372296, 0.1001411671900461, 0.06641898033840042, 0.007531423311335065, 0.013501663812466208, 0.027621277127294775, 0.07824042947181771, 0.015959188646276393, 0.019613766081390843, 0.0711083500796268, 0.020270584969811385, 0.019003709199868383, 0.06515078306678804, 0.08530928362761775, 0.06788492022502808, 0.0645718197788923, 0.04759826847622472, 0.02003479842847634, 0.025930528739287008, 0.12537432609186058, 0.06038866944671158, 0.029067225949538332, 0.02596175065264106, 0.032061936423903516, 0.07080638120251317, 0.11259827011775587, 0.029213736434617353, 0.048607711890532125, 0.1216227935266591, 0.1274471914756202, 17.282180670768984, 56.92137710509762, 70.13556372734809, 73.01171225886192, 38.648556740053245, 33.75227774343183, 39.56444978713989, 58.379722179905066, 55.50993573281073, 11.928404261988979, 0.2645222848701862, 1.350112785735438, 0.8076835567912748, 3.262231104796933, 0.9501721721983726, 0.42476624430667975, 0.14995915244423574, 0.1220673773317568, 0.03248742165704889, 0.1440148310916078, 1.0890447300287986, 3.8874571554122435, 9.488162456020232, 14.360541470589178, 13.86525986656066, 12.100067773172933, 11.809145577492254, 7.091873749609917, 6.756077187676584, 5.907985741092313, 6.604729592800141, 6.524992710159672, 3.9055155025374506, 0.6654870353879467, 0.30177091999400046, 0.340855990446383, 0.24302429489551053, 0.09990247717547802, 0.2531368393571146, 0.19969934146971474, 0.15742140041003305, 0.994806599713141, 15.444036414546353, 43.45708054880942, 83.63010175766485, 90.3250777336859, 94.8835700558078, 93.72453320410945, 91.32889070818501, 97.2074802460209, 91.89286478104131, 103.8095352726598, 84.66226562376946, 57.028226390961684, 42.54371350811374, 26.84255200047647, 15.905750374640188, 18.46543227472613, 18.48427337984885, 17.935859349466142, 11.294895391310416, 5.685189231749504, 1.5432130305036422, 0.12978070295385777, 0.09174018572535246, 0.30094700775319533, 0.45060329499744606, 1.1904501338158886, 13.24965367394109, 11.026846497289597, 3.529253073277012, 6.049064570857633, 1.374370193769855, 0.7268644064184159, 0.8650875055501539, 24.70762944990589, 58.038275934034786, 44.52878975099133, 28.777600372991255, 42.54552956550352, 55.18343371729697, 54.44128205699306, 25.74119164097694, 4.744469542657176, 0.007431983662348602, 0.10160371330716919, 0.032756169131326104, 0.23161798114738158, 0.09660741809995906, 0.04719648217301696, 0.08680045845047121, 0.07138601864778227, 0.014189787926302563, 0.01953186553662583, 0.04757549268223586, 0.023035394373319806, 0.15067568980157375, 0.029790504880610014, 0.025524553850353248, 0.02457854060095645, 0.05815364240157989, 0.07055994603903064, 0.052847502933394526, 0.06553526727422591, 0.04610184595108994, 0.018897429822132956, 0.029453121673976703, 0.05692135167097854, 0.0661791182093082, 0.037546091743053935, 0.043102102279062235, 0.04718984785159269, 0.1216809242783535, 0.09641407282962915, 0.0924897491331062, 0.06668967750644492, 0.13070661214090165, 0.32218679545387147, 0.12360791119957164, 0.08128303959364853, 0.19334787502884868, 0.07859691316562314, 0.020341254665606448, 0.2141892816871405, 0.14031048954254197, 0.08519187299234253, 0.056257976985145966, 0.03807900548582116, 0.044160782164263154, 0.06648223621830826, 0.06258724985884563, 0.08553688834992149, 0.027346412440942183, 0.04595397949038495, 0.08785621954068061, 0.09260525987032922, 0.044145552336328456, 0.0992417952886993, 0.11247014191241995, 0.021499020362933798, 0.19292413647617065, 0.09251873023928174, 0.057058412461511554, 0.04591336916951884, 0.11534507070938427, 0.15638407139528185, 0.12437091945039651, 0.11488110487980228, 0.046752361851113464, 0.07773229101252171, 0.06439346684924056, 0.08614716165128254, 0.09458554352843955, 0.0380239965424182, 0.05694418492156172, 0.05398098747396181, 0.053217167169937206, 0.08056996495372827, 0.031900588730950995, 0.1192565241287793, 0.0784995433904471, 0.13325710270193317, 0.05552257854311217, 0.0017846574806871134, 0.02614130825555373, 0.03544085914449346, 0.03688907558699289, 0.08947163084221464, 0.03130883943559903, 0.02842468310958676, 0.10391855522269204, 0.12651491609792556, 0.030173477979617256, 0.044922488065616745, 0.2652878212111612, 0.543492007399759, 28.831364300943193, 69.87657746961041, 75.29376291459607, 57.69846531652636, 20.444658302491714, 34.55932894060689, 62.48292146190521, 89.21106969156574, 57.432728659722116, 5.017099274742988, 0.4314180631791392, 0.7633559934554562, 2.9811695025813196, 3.479902547213339, 1.2400614974960205, 0.6259708719388132, 0.4609990468428981, 0.19311823251266635, 0.0745578678024392, 0.2874774660073942, 4.052582320667082, 9.93161484118431, 17.33016106390184, 23.351999482800885, 24.91457566138237, 23.139610982710316, 21.707455573543427, 14.461246363578306, 12.003296036874096, 13.722518932434822, 19.718274570280506, 16.139469704320355, 8.078118428107231, 1.6787515124005659, 0.2315295746009196, 0.983489826321602, 0.8689281801062246, 0.8207868472222359, 0.7953549957563801, 0.18569865564425148, 0.02442452053899967, 2.377130134451774, 28.77863587871675, 58.985685225455995, 70.55828540555893, 87.95450702790292, 87.76920641622236, 84.95037155766641, 87.4745422793973, 88.50464297879128, 88.98230137363558, 102.12923111454134, 96.84670848231163, 70.52034039651194, 61.27034425735474, 44.581208305974165, 31.728054285049442, 34.07854049436508, 32.198838726166755, 33.17819572264148, 22.294134286142167, 14.361597568758073, 6.622910268845097, 0.4772375674257356, 0.22533368529571643, 0.59345577152506, 0.8764080787377974, 4.918253585215538, 11.942069799669328, 9.564324098248637, 5.2542805863964945, 4.583408688345264, 0.3912837587056622, 0.6344613324730628, 0.8756970265699972, 22.698726769416567, 72.37853973142563, 65.8890567287322, 35.9230899810791, 32.62444530763934, 52.63765858065698, 64.26619960415748, 38.799866091820505, 9.185031883178219, 0.06459137034271994, 0.0853263137621745, 0.03590138906973504, 0.010298406968133585, 0.19309937142797057, 0.062343538137933904, 0.06082319451736347, 0.02490923202957117, 0.042194671132752014, 0.02613074581829771, 0.03205851009566217, 0.033613130405184724, 0.14641539824585761, 0.04624458345314188, 0.020771717555039836, 0.052196056236543005, 0.05978150263188347, 0.030895569474406304, 0.14257288507876859, 0.07627106256662838, 0.13954625555103825, 0.0422494694019758, 0.013870851159276021, 0.033404390598016406, 0.06846134776189443, 0.10804029211642281, 0.00853803076390778, 0.0639323508667369, 0.07076495116756809, 0.18921964170952, 0.12856876717940455, 0.10121272501325417, 0.03957698316944223, 0.20828950068643018, 0.02752952469182351, 0.06764504277417738, 0.1876067048719814, 0.12757888965068326, 0.028306410625396718, 0.14500366674075205, 0.19632812559364304, 0.06929427685756838, 0.18508305803181666, 0.10605023317639867, 0.15394702313407777, 0.2238426943339648, 0.13733094377863792, 0.17661656072783857, 0.15403075654420162, 0.12849855522114423, 0.3910249435613233, 0.14362999448372474, 0.31337709075981574, 0.4497456748879725, 0.29539847806576763, 0.11905004045054798, 0.40994854103172984, 0.14148833440436473, 0.13483717436752013, 0.12968874175942716, 0.4050997560543399, 0.2700779238535512, 0.2972919716229362, 0.2352126495492074, 0.11169143652002658, 0.11685905196974355, 0.08980381422706189, 0.13534843080466794, 0.15184924457102053, 0.15208887687373548, 0.1243132713340944, 0.2457185801599295, 0.29326562799753686, 0.13691748612590376, 0.18566229711136512, 0.21509793857412957, 0.16599734103487385, 0.1851435942995933, 0.14026207278572744, 0.1421538043406702, 0.10023273001875609, 0.33486509094795874, 0.14274677171582176, 0.10433542196668925, 0.17608641256247798, 0.0826901515885707, 0.22248803637921813, 0.2435074052623203, 0.12506219122799175, 0.12957104001074068, 0.22816310846997848, 0.21756867938224347, 31.816944999079553, 83.24511328051167, 94.93107780333489, 91.83486077093309, 56.7100868686553, 51.96424253525273, 53.10613470692789, 78.84321766514933, 73.60093070614722, 18.279284431088357, 0.22399018158114728, 2.6340348393686357, 7.693169664952063, 10.344500195595527, 6.838730842836442, 3.4387615419203237, 0.33322943194258603, 0.18593779765069487, 0.4316838956888645, 0.5172034244864218, 3.53395942718752, 7.406393904839793, 12.077791652371808, 17.705386761696108, 17.185580538165187, 16.462252332318215, 12.738821833364426, 10.739462279504346, 9.63306853848119, 11.659367911277279, 14.866559582371867, 8.339864073261138, 4.31347313427156, 0.5513024270053833, 0.22398573827118645, 1.0009886228269147, 0.595792829990387, 0.48339430963800806, 0.9766166693260594, 0.9994639239964948, 0.3903272213234056, 1.4620046461782148, 23.450752996629287, 63.6441352290492, 89.71103068320983, 89.14904917440107, 94.89670999588506, 91.2142868964903, 86.37997350385113, 89.63613694713962, 97.21423456745764, 110.6236336308141, 104.16735741399951, 69.3345529802384, 47.93729412940241, 34.85609154547415, 22.215486841817057, 24.222087091015233, 20.40398136261971, 20.37078046029614, 12.559056666589553, 6.5268999626559605, 4.213758149454671, 0.37455055982835833, 0.26331152887113635, 0.4620237660504157, 0.8087983679386878, 3.3872735692608744, 24.947564755716634, 21.83195552518291, 18.237032659592167, 15.52219650437755, 4.561182577763835, 1.34206383699371, 2.1543907446245996, 31.061763225063203, 73.53793744117984, 57.40906892284271, 43.79238436298986, 59.78130663594892, 71.91300146041378, 74.31156219974642, 43.05024446979646, 8.89909403939401, 0.12624814130005338, 0.15691854029653535, 0.09326590345271173, 0.22203370027484434, 0.2608447563984702, 0.2027511599683954, 0.15734951071921857, 0.17663870066885026, 0.12502801604568958, 0.12379345769483237, 0.08329936768859626, 0.12367420844853887, 0.41333376099505736, 0.095063375549451, 0.1485455057193195, 0.15038290631867227, 0.1346248147949096, 0.10382870843093242, 0.13470044299479456, 0.128476966863438, 0.2936637485700269, 0.08863259602578417, 0.1424734315444385, 0.203189714661529, 0.18269157668034877, 0.16695974665063043, 0.15731385698722256, 0.12912859359095175, 0.11797759396534775, 0.24442468829933675, 0.3106652007948968, 0.21288949094953077, 0.22893166319737512, 0.3400843560455307, 0.2082718040553793, 0.1474836465692328, 0.461670997883043, 0.16703459344083266, 0.20351183931193045, 0.27466666794592337, 0.43235336460413476, 0.2058341429238358], [0.03717301075436896, 0.11956715746031654, 0.036798926190503185, 0.03549463468633833, 0.20185597090711518, 0.04470673472350163, 0.22015205043698513, 0.09581226479983139, 0.27347996710769595, 0.24626455570180572, 0.0824076260229753, 0.5659060240272553, 0.173457627815585, 0.6540319371607997, 0.1877242380813245, 0.6907507765196985, 0.24425245641220003, 0.0829877307818782, 0.13990312994968507, 0.100505396032766, 0.07401693311910476, 0.06339155407922883, 0.13032919126412562, 0.07240824806954592, 0.06764909537929682, 0.07452370028101629, 0.046105515512247244, 0.023531363525938605, 0.11542708808255774, 0.022749689542838646, 0.01732899886255543, 0.032358787833682956, 0.050279369367466825, 0.03374225069438258, 0.04897777449279543, 0.0430362340393326, 0.052208125951790044, 0.029387241942928206, 0.07508765590647537, 0.04517834611056794, 0.02010778362502254, 0.01686238619919506, 0.10132854218564688, 0.07811430075596418, 0.030884154764334523, 0.018367212708859194, 0.05144629747636857, 0.07394397090519629, 0.023144761085390084, 0.07337115930333253, 0.05788586785896652, 2.098573946183728, 26.47724989921816, 57.45206202230146, 71.43407221763366, 57.85259485244752, 42.6804159533593, 34.99359023186469, 42.44876469335249, 63.761751421036266, 43.90637628493771, 9.92478991708448, 0.5183045686252656, 1.5755579981111711, 0.20686800922116927, 3.419667934217761, 0.9510704562548669, 0.522241402537592, 0.14691035233197675, 0.12721846060406777, 0.21128519558377806, 0.23322272084413037, 0.01930824830196798, 0.06341069861645661, 0.027907368832177697, 0.05591322209746127, 0.2883015621093012, 0.07004184077583975, 0.35418579775479536, 0.05596664523886097, 0.07499864415055321, 0.07027507624438695, 0.05846614115721276, 0.25684468958887363, 0.34286890178918844, 0.9033173154438696, 1.035693754111567, 0.6812660564338008, 0.05013324958722919, 0.2624186993606629, 0.1003941830487982, 0.05094753976370539, 0.1285482513447923, 1.4606277716736642, 16.366485703376032, 39.76338455753942, 57.56508904118692, 54.830408634678015, 46.7832818338948, 37.021184967410186, 29.059785489113104, 11.784439548369377, 4.8128271391314845, 0.26464473636400315, 0.5879229619618386, 0.05492260146345343, 0.97188868109257, 0.06290226138287014, 0.13974856405008224, 0.044069295944345575, 0.212949950608515, 0.21506770874463746, 0.048060495286218585, 0.13575655648544913, 0.13442763908495828, 0.18500310909603873, 0.9804189781988821, 9.644368886947632, 18.01241813167449, 3.0771334757727966, 1.8397535311598934, 1.0315931612445464, 1.133015847975208, 22.62521763001719, 48.32144714170887, 42.22125153387747, 24.839044540159165, 28.004920905636205, 55.67142363517515, 58.07578555999264, 36.629089155504786, 9.678658246994019, 0.043562122755834175, 0.13337432947610656, 0.06806053055991089, 0.09401959607437735, 0.07736489056579529, 0.02924145349571782, 0.0579705014224014, 0.03151334086132627, 0.08051157373213962, 0.11217047129907917, 0.10964372946370034, 0.04685567646858193, 0.031503209348527655, 0.05881251249041769, 0.08274350195161759, 0.09810976248474852, 0.05774761197127162, 0.007453385286123282, 0.08709403866481397, 0.029188334874268022, 0.04837918403227964, 0.08108355795904514, 0.024232483363800475, 0.013326100400468756, 0.07914775336581854, 0.03738681440271678, 0.17087033439067104, 0.03757973832468833, 0.09842145301762129, 0.045489718716952114, 0.03762789078116898, 0.07906876203994598, 0.029450907679875533, 0.11489392153077549, 0.049090906527013554, 0.2234519588490648, 0.02947283120104863, 0.07611653497142178, 0.05796913012501694, 0.07569856506081359, 0.09724863369258181, 0.0389593975588439, 0.10058938225190486, 0.059284127707923615, 0.0352044252588624, 0.031655551677930265, 0.04833836303723436, 0.07607545733692185, 0.2511091425173706, 0.03505273601941524, 0.15494849923397266, 0.10319152246079139, 0.17440005385827634, 0.17641515621254522, 0.04894897724772173, 0.4150984598503959, 0.1347334154190556, 0.33749133228294315, 0.078234001994133, 0.30701797876146536, 0.3068691738430531, 0.1812504580424678, 0.1816631649290362, 0.16482838279297277, 0.01748632267868567, 0.08556813707635288, 0.14561779346437226, 0.03439788023130067, 0.016025530902909178, 0.07239351619876201, 0.033928027016020594, 0.07366732123398012, 0.052218996739435586, 0.02719506219540152, 0.07817443865802019, 0.029435156912152326, 0.02538655077167336, 0.09219927157485679, 0.07154443796964423, 0.009147754397183176, 0.02987123139563107, 0.020025666660418915, 0.09139972859092298, 0.031229160545814424, 0.04387858601647519, 0.06028557316430154, 0.02774240711944238, 0.028563613154655023, 0.023271150271137877, 0.03071753255602333, 0.06351338121138754, 0.03275653685352976, 0.022019006371978792, 0.10096155542639956, 0.03778645949017617, 5.764368157232962, 38.45087712810886, 73.50960223905503, 74.16000181628813, 45.687340228788315, 32.36608859031431, 37.97219107227941, 66.72426269900414, 86.8666611948321, 43.51377448728008, 1.7228016906207608, 0.8844763328952174, 0.1847378281696189, 0.9708623684221699, 1.8517548807205695, 1.0606896709049902, 0.8575559419489677, 0.368928148621513, 0.09702610047233683, 0.16457656969226178, 0.04292659919648882, 0.09753213985072029, 0.34296999475167644, 0.4280152538370702, 0.11102281030147307, 0.7458219569056266, 1.257184849631402, 0.7403816907636581, 0.3019724317616032, 0.1373062451039591, 0.8111494611347876, 0.37989543270199533, 1.075369999293358, 1.972241512229366, 2.3989103205742377, 2.535334767833833, 1.8673515728404446, 0.30213570042002585, 0.7196961523544404, 0.5155532098104877, 0.13610607644002284, 0.21064086967418272, 6.147107155092302, 34.4559274181243, 60.01820602724629, 72.94587919788977, 72.24952513171782, 56.328954081381525, 49.83442298827633, 44.92592973093833, 24.837687400079545, 20.607413130421794, 2.230945604462778, 2.0874714322628516, 0.3161522902307972, 1.5742833503792364, 0.6852412560293752, 0.6703735731782452, 0.09636698906580288, 0.5577191794591566, 0.43764917720710084, 0.12013972391404452, 0.1781564127774008, 0.4651333475785871, 0.9860907254680511, 1.8367817228840244, 2.234500252431439, 9.241805249644864, 6.00429856008099, 2.093572924214025, 0.9168298194004644, 0.6000280704709792, 15.02074795384561, 57.84961385111655, 58.874666460098766, 33.361609674269154, 24.002771685200354, 48.14445411005328, 67.48868557714647, 50.60571785896055, 16.82830164509435, 0.5756634714141969, 0.07770827415609553, 0.0581443191115414, 0.07954113185405731, 0.03840965286438023, 0.09680020412610424, 0.07389257406635631, 0.08805486613944655, 0.035524067784389185, 0.025687711426026882, 0.10225843502989701, 0.05861985286878002, 0.0073277918742068356, 0.025243347871207425, 0.06278315386284264, 0.07143736186046755, 0.04485574648565343, 0.04629885695213753, 0.11653740229385516, 0.02190673235623587, 0.013526870978004752, 0.038805636051561565, 0.0501026290528957, 0.02918750175365037, 0.0858608516113412, 0.07129595735140386, 0.23255447766953902, 0.027996551042662996, 0.0411046352688103, 0.08189708204759706, 0.09977220392395413, 0.06259171998188381, 0.10046064117622953, 0.13786052503893453, 0.007509807661746539, 0.2844153512870112, 0.08423181160563424, 0.12040905744558382, 0.04571937272445329, 0.0061915747937746355, 0.09951983923993765, 0.05382720298404175, 0.09818308475998141, 0.06810060461923, 0.14351612317465967, 0.1758703757678309, 0.08293993455628235, 0.22581627472273766, 0.33218338484725646, 0.14292761443122742, 0.3700528576249077, 0.19096445292234424, 0.3635260030146568, 0.3433975637439759, 0.2580804660195305, 0.966430948145928, 0.28400316534023134, 0.7451823654194033, 0.32060059508489025, 0.9916139129669437, 0.36993129479308284, 0.23779834951123885, 0.2729745635822896, 0.32852571337453784, 0.2189131790111142, 0.2680425201692889, 0.38058010080168325, 0.10964081832958807, 0.20584021034019612, 0.1393188959768703, 0.20403368308419184, 0.1955861541172189, 0.3640963095090082, 0.1479723340561313, 0.15155814648155244, 0.18463045328615174, 0.113483170618213, 0.08729307596842129, 0.19091064290654278, 0.10387544745519277, 0.1948729262597138, 0.07908350923248837, 0.17753948217197774, 0.08001648941107335, 0.13277268998565214, 0.22092917002737525, 0.1406504180763037, 0.274306146968757, 0.1589485966870862, 0.26029966951858613, 0.23727947816012368, 0.19253628148186594, 0.22757432393489346, 0.22359362382802273, 0.15054611369006096, 4.527814974707942, 42.05667280381726, 83.08271931063744, 92.67407540352114, 75.82786421622001, 63.56311867314001, 51.19962746097196, 58.11953567689466, 82.45314751901935, 57.966253372930716, 11.649712997098124, 0.7105330053356387, 2.649530407882506, 1.8161305665008485, 9.669735835444543, 4.847312617686487, 1.282516374222694, 0.27269166263361133, 0.2344926954397271, 0.5845386306605032, 0.5102290825978403, 0.1385934107125767, 0.20579098153018183, 0.23232587703293373, 0.14469694045762863, 0.3857007857051588, 0.9206927411498562, 0.5581693940104977, 0.24238634283744523, 0.20905871424944172, 0.4026019416989819, 0.1764298957442084, 0.9299839780695978, 1.5210464909192056, 1.7565756267116917, 2.3825106457356484, 1.8895968049764635, 0.11715917457495967, 0.7297182371539455, 0.5381490650676912, 0.223142444005897, 0.26704167226149195, 3.1614928716613404, 20.537312530702163, 53.13432085898615, 61.054088300274266, 58.53238474938178, 45.536281908712084, 35.4849612328314, 29.354775182662475, 12.904633168251285, 12.962111580756403, 0.524643425258898, 0.8068000429099607, 0.17654503875922772, 1.280918253525611, 0.1884862350960893, 0.32495871606853705, 0.14672017866565337, 0.42156059535280355, 0.26421235633953927, 0.1673941797907314, 0.16683459852732, 0.3400956635032931, 1.3513922138560204, 5.498698180721653, 31.155439230703543, 32.83898718895451, 8.993580995067473, 5.928400206950403, 1.1450750524959257, 2.3022827313792322, 29.449867163935018, 60.59866582193683, 57.36987267771075, 37.32317609171714, 42.84372775785385, 67.63905356007238, 79.45547611482682, 58.70941700473909, 17.78582869037505, 0.5980236167388578, 0.2893959646744113, 0.10517459467894609, 0.24236020391746876, 0.2202359677082108, 0.32493579471784256, 0.15726677322339627, 0.16870576828237505, 0.15140580223693004, 0.23057855305171784, 0.22112060007789444, 0.21572196315373146, 0.16562638594017876, 0.13353557566240912, 0.3351089520560157, 0.195933697564948, 0.19099488193469663, 0.12031775508676806, 0.1997059911128975, 0.1353269803427881, 0.15599978637070427, 0.16821481317522066, 0.1768964126465782, 0.14586874854660806, 0.17319253075026697, 0.2938793869989534, 0.33736103604878154, 0.1343790384670419, 0.149042175842389, 0.13114193394299478, 0.19237834479539626, 0.17175945603559095, 0.18129363475788027, 0.291484167138415, 0.11488580865965736, 0.33106504969539186, 0.16102812703578703, 0.16581813774762616, 0.2593574733022721, 0.17767990608849835, 0.2618970241277449, 0.09636751000559139, 0.2681886897452416, 0.22326618252742678], [0.03949052631674756, 0.031721490780792894, 0.05567485767026102, 0.03543172737643604, 0.06095509570572646, 0.0911719170248797, 0.0797209250290067, 0.026865776538127856, 0.03543050929663643, 0.03927840423139353, 0.026194154915790406, 0.025008202928508964, 0.05293517403544919, 0.008231027731521717, 0.07576092461785001, 0.06852282631781793, 0.027586538870368275, 0.04807606602327959, 0.009582024743600238, 0.09929123094245311, 0.03471755723078405, 0.008796683114562786, 0.05240207643158013, 0.11067668411640391, 0.020828578515999743, 0.09920875391652507, 0.04002121840453437, 0.025269825785090367, 0.051748557466893434, 0.029886242888507344, 0.023116331562520038, 0.041746839114855376, 0.024450866302715677, 0.018419030896057526, 0.052189165275664105, 0.04686771937075162, 0.020717145281753713, 0.04897697776135418, 0.05284824220824146, 0.04490161600011972, 0.02133543569324238, 0.06113665854378093, 0.01962039274193587, 0.027638849269057957, 0.05410127859983233, 0.033477785651602095, 0.010605785383602545, 0.030654858902937947, 0.08557614269516162, 0.13655529507706243, 0.0740464351650688, 0.18093262348444233, 0.10976161507348861, 5.133396569759616, 34.88098682895784, 66.89452494344404, 61.20016521023166, 56.274095812151515, 40.27151976862262, 28.772752323458274, 35.84961614301128, 65.72086157337313, 49.44946589008455, 15.327160569929308, 0.7364044074089297, 1.3888931370550588, 1.5444773820138749, 2.1203563386394135, 0.8175090940729265, 1.6549543699910565, 0.723310248746026, 0.6470344287733878, 0.21339538477120862, 0.11414562216809682, 0.2546017220424068, 0.041019948079220714, 0.8315214550783558, 0.38779275732175, 0.3600875552623503, 0.8336742847196518, 0.6679198854873258, 1.0643011932411501, 1.0442100777741403, 0.9970293578601653, 2.1645175689651124, 5.685793276756041, 5.190671999608317, 4.352612014739744, 3.1703937101748685, 0.37917163283113514, 0.5486010784103025, 0.22915120867471542, 0.028274556689505136, 0.040290950301794276, 0.1345439771971395, 0.4499906391626405, 1.8751411548545285, 1.8207746527848707, 1.1779749129087695, 0.3592922334228793, 0.08823338760844163, 0.08800331608302171, 0.0661743761250569, 0.3263671533955682, 0.27957202085564214, 0.6165555287753383, 2.3962717911889477, 1.781601451577679, 0.43998234394577246, 0.0946549587552586, 0.1936327524843716, 0.5836218992067922, 0.3369643250780721, 0.4094841998190649, 1.663141704855427, 3.288012843939566, 1.9889702984402258, 2.829328424507572, 1.0387027023300048, 0.9071217693628804, 3.259961033059705, 26.673421359831288, 59.13771629333497, 51.64299649576987, 23.475354102350053, 24.87158844547887, 43.40727821473153, 61.251320762019006, 50.38810476180046, 11.769029536554891, 0.521769798811405, 0.07873167569238333, 0.05814222003062887, 0.061160165951737476, 0.056228957574574225, 0.15726210008705818, 0.08433802203545648, 0.10956439339826185, 0.007718949186270156, 0.014692207539243805, 0.0506466702227631, 0.06121716289330394, 0.034347770420173486, 0.11258536919711098, 0.01692518625678795, 0.006066028304743551, 0.03244936240897064, 0.11213205965055574, 0.005623925666910627, 0.07084753544580552, 0.04951145049304732, 0.02765101666051534, 0.014517529916408804, 0.13707039727559014, 0.03776419314465696, 0.013666077772335661, 0.06462612775184455, 0.05747305755052836, 0.02107641753560353, 0.04245968775883798, 0.02878872234554541, 0.07770486506483248, 0.07009795671629329, 0.040436687038069775, 0.01684342360784931, 0.0661164598779813, 0.03800010609049951, 0.009533949853521923, 0.008889790568050117, 0.05681767316174604, 0.06852449638949287, 0.03221651381482521, 0.05462351307693509, 0.11559079341109722, 0.037076380254039844, 0.059152904507373615, 0.06304343989599617, 0.07192340634402729, 0.03269969695998776, 0.04226724647225873, 0.05357553544003637, 0.02773661932517444, 0.07511502056713067, 0.03052324691276637, 0.16819204504211105, 0.09416951182027979, 0.026068349872084878, 0.11899511194637707, 0.08135764123571497, 0.10647441606007277, 0.15074871330251619, 0.21821524226857772, 0.06497133463140457, 0.07067636842088354, 0.040146282258173155, 0.09961756141555887, 0.020153051760468273, 0.08868302759383956, 0.00430767888188242, 0.08465630092447804, 0.043320479472318006, 0.0861197510253518, 0.058154688111596534, 0.019832882549493544, 0.06440455214150491, 0.06404172140924681, 0.027380208409721815, 0.01355001928224679, 0.0440066414434583, 0.008982627017934237, 0.07036064826552907, 0.06043498712261358, 0.01725628371200254, 0.024521704537854083, 0.029136886324493155, 0.06263556319379038, 0.009481844383351987, 0.11210113268105254, 0.02644209544204416, 0.053014544574844266, 0.08572743739932777, 0.01312745954736226, 0.03975425591512073, 0.05923959884732481, 0.03467917239533798, 0.059427052901517, 0.14508756869021924, 0.16759193772750516, 0.11642127868629272, 10.908642930369224, 49.992121881054295, 81.12470349957867, 63.30142205761325, 51.39350629621937, 36.49894883555751, 37.86453377815985, 60.99661773250949, 90.83783349683209, 41.47337713549214, 3.437934902406508, 1.1840235754366846, 0.965067005205539, 1.1286981764339632, 1.760299794616238, 1.7193060007787522, 1.055670875695444, 0.8212680117257181, 1.3087984607104333, 1.1230303515349667, 0.543552681563362, 0.7107682249719097, 0.8495172281419078, 0.9416236728429795, 0.9125103705352353, 2.3937624548712084, 4.408620519022788, 3.855191493226636, 2.112206388865748, 3.553447968536808, 2.6504717767238617, 7.209159481909968, 10.723725730373014, 6.933733099891294, 7.698460452018246, 6.20059798802099, 2.9183988321212033, 2.1328750733406316, 1.0962211965553224, 0.5207852838981537, 0.2741901612570209, 0.3480312005887109, 1.3982487253604399, 5.660834254757051, 5.378711406261691, 2.962294076719592, 0.936576440449684, 0.38112353293165085, 0.3677674334856772, 0.09116512948587056, 1.1152301055769767, 2.087314292307823, 2.3162272476380874, 2.690140422313444, 2.890564222489634, 0.9312908014943524, 0.8069112788765662, 1.9404303546874755, 1.558205555042913, 1.6144983085893816, 2.244456453669456, 1.0741858112235223, 0.9262960920891455, 2.296100340543255, 2.026574674152559, 0.8168480521248234, 1.121666960177883, 2.078088387366264, 19.39220597667079, 58.0452577529415, 70.72925367662984, 36.85899888315509, 24.259416287945164, 37.66848587220715, 64.52285205164264, 64.28634097499233, 20.69468782794091, 1.6105294828453374, 0.092394677621703, 0.07889479879410037, 0.08460671205313937, 0.12748018688251897, 0.06279765973768889, 0.010279633983549093, 0.014155248852236377, 0.00911909600554575, 0.03637513401167047, 0.029664803258774262, 0.03126805291451033, 0.008472448849539843, 0.027922156244336117, 0.010142916974972093, 0.031703932045568387, 0.04906099462401002, 0.043998926938060796, 0.07279571235900925, 0.020690983379139535, 0.03562629455700517, 0.019522875494834398, 0.028731482171062982, 0.09691101874435142, 0.02458361784867462, 0.07607495171889182, 0.035969770077856324, 0.1551488159044135, 0.03375556147206695, 0.0871061428540176, 0.05612789142516352, 0.04267826413495406, 0.16344511911513346, 0.06827358727253253, 0.027743780332046653, 0.033764697070563995, 0.03910855487770131, 0.008239040053599786, 0.010598363906836078, 0.03503113617039016, 0.017333961197084958, 0.05240608307142412, 0.010206681345739673, 0.03338058441576939, 0.026259268558914625, 0.08820685032274454, 0.1954794840346421, 0.21917887362501315, 0.1245469204901207, 0.09629494615740354, 0.22097288300433468, 0.1289538336136649, 0.22798076422224123, 0.09304418994654572, 0.26096680952656653, 0.182943680894471, 0.15596997022869127, 0.356203795921418, 0.23915726691484454, 0.1260556770308364, 0.20333798331839426, 0.23270312937036639, 0.16222881663951183, 0.13205632116765748, 0.2151010795346191, 0.20646985800516224, 0.13665834922463665, 0.11118830827575539, 0.11363258840696466, 0.15151337630325748, 0.12600734454369353, 0.19410002015290723, 0.16378953692413148, 0.12167309485976735, 0.16757555876768407, 0.09638422604409919, 0.15385587399284686, 0.12749115726159466, 0.21750814311446684, 0.06952231824998895, 0.12416706345374547, 0.26109833150140704, 0.08477365793359858, 0.17124593197818727, 0.14166425883529649, 0.13233260311666997, 0.13555559630115188, 0.2022794030246235, 0.09549702727986921, 0.16455891902648634, 0.23856132711854675, 0.14149863062606705, 0.10187512293698327, 0.18369873715264184, 0.2956127068929134, 0.23353260340950183, 0.16731458325539866, 0.345172313672881, 0.18773874778661037, 10.947339073304208, 56.44517390958725, 93.05330584126135, 78.69356355359479, 75.23982247998639, 62.001246560004454, 44.61246567387735, 50.98745469124087, 85.85964756627237, 61.98219953044769, 20.249169334288567, 1.2239427624210235, 1.9910013507450781, 3.2395862811996095, 7.237744735133264, 4.517370683531608, 6.014826201623486, 3.0071912417488718, 2.5315104569158247, 0.969436586864533, 0.5458396072349241, 0.6928242394520391, 1.0958439135743727, 2.5239513141493646, 3.670654763137141, 2.8271250330632736, 4.218302215299299, 3.567008092518776, 2.5415075978925152, 4.962372404913749, 4.384304275435786, 10.592629332696239, 17.637959257248912, 15.27873008481918, 14.162754974057599, 8.421377789589668, 2.3010709641441225, 1.318964876474873, 0.9679633691426247, 0.4931281615168818, 0.20314949504550428, 0.33227381386583854, 0.6997372330196443, 3.166329399231942, 2.840649365417419, 1.7795765279762208, 0.5077598892873334, 0.16737110522245208, 0.25014168072131376, 0.3195065295984668, 0.7475257364492263, 1.595131973585775, 2.1362309061711837, 4.348237591405069, 4.829028979424508, 1.011467112168189, 0.61827426235522, 1.0685724092106665, 1.0797006636857986, 2.096128348381289, 4.008460068894971, 9.857874281944769, 13.604294773071045, 8.396622730839638, 14.700533497718073, 2.7578049850079323, 1.381061879857894, 5.166415081870172, 34.8919302417386, 70.93331106247442, 68.17142901882049, 37.85717933408676, 39.38876682712186, 56.59944857320478, 82.73526791603335, 72.63845951326432, 26.267814943867346, 1.366917200146183, 0.23218050418842226, 0.19142917717897123, 0.3702311722501632, 0.23516046363980542, 0.21914148853430826, 0.10668816991270551, 0.16473867389703953, 0.06144689734003717, 0.14795313589274883, 0.12884229121188964, 0.1028056592950898, 0.096871534572734, 0.14878826366076547, 0.09356274720161192, 0.10205980375288956, 0.14382269624019825, 0.24031640390955636, 0.10485423969164973, 0.1603928409636982, 0.1445605614853482, 0.11688383491409403, 0.1035172553853162, 0.2532779067874916, 0.12938541690668753, 0.08840869916903396, 0.10446380298104017, 0.22900913000827838, 0.13781017774055082, 0.11976914420243233, 0.1401261534662016, 0.17024568161897122, 0.26973545190788084, 0.2598280657923991, 0.11640030319892591, 0.13046129546578855, 0.16378316307260146, 0.1023811010283328, 0.09048914882324396, 0.1709082863864399, 0.12244693559384155, 0.20881122188462367, 0.1411968226274175, 0.3002700618197841, 0.13821582129645732, 0.11430586477921856], [0.06411287565565398, 0.014359638237604692, 0.0507400946451291, 0.0640410740649508, 0.05737978251530759, 0.029039863204102845, 0.05339583036519828, 0.09239201163572651, 0.06686528784132774, 0.018457162922488588, 0.04345323484871657, 0.041538160594721, 0.035653777961288734, 0.06015670185367908, 0.04846184491930951, 0.04673723544504854, 0.04095797539658604, 0.03651853417977691, 0.05390930079644727, 0.05979964742437006, 0.044401747459966334, 0.0005656423954567271, 0.02737569232140818, 0.08949504248918065, 0.02978235178987586, 0.024774726142265627, 0.027481196035120278, 0.01744357688773063, 0.08041680099502688, 0.04674222650787523, 0.028616540254123753, 0.011363108304419346, 0.007218493631244788, 0.03259191604992075, 0.04418518206465148, 0.08924496840805778, 0.03152408907490392, 0.03470668261269889, 0.029651848711974682, 0.05706074136880137, 0.03616991437851422, 0.05324880277077037, 0.03603519398658987, 0.018419766340464837, 0.07362490294561272, 0.06407620302671868, 0.09655821993346177, 0.043944902417640534, 0.09591862078635924, 0.09859274261661115, 0.11844200412592581, 0.04940381130924629, 0.03763607643063992, 0.5826090083968255, 0.06102099458897307, 16.29345215136005, 56.5083868272843, 60.75874559340939, 59.61413129683464, 49.76118449241885, 35.65913015796293, 22.878461537822602, 37.58710453587194, 61.53133876862065, 61.5329037943194, 32.17680677290886, 9.696472671724136, 0.9080701862131396, 0.9180298195250574, 1.5716085390698527, 1.3544427146834712, 1.2535534702962445, 1.4704248717715664, 0.9194535786105741, 0.35223809581610466, 1.319281975588491, 0.5678693541596013, 2.204481863206433, 5.081926247765941, 9.384973722119486, 6.304066190796514, 4.796206095526296, 3.607278821929809, 2.945907149584063, 7.234472988113281, 5.36727475543176, 3.3313295389375384, 3.6831051015084793, 4.058205038309097, 3.465029164668053, 2.1347180970253485, 0.5959322579926061, 0.3398872263008549, 0.18635442690743556, 0.017088721130764293, 0.10712218170444812, 0.16422525709194524, 0.13826177125015568, 0.08416269515310565, 0.11243396724063544, 0.032869814444453485, 0.18055406879753838, 0.17828557520143448, 0.188544090056131, 4.910127905107314, 1.764890806328866, 4.964095306011939, 2.792006091725442, 3.369596427486789, 5.734285539196384, 6.653440037081319, 4.193996758230271, 2.0715990710643033, 2.2566491413501004, 1.2443175142811191, 1.6841676927381948, 0.9154270817675899, 0.04023581878432343, 4.920176036896245, 33.36717551754367, 47.33832074749855, 36.48874675073932, 32.040137667809766, 27.6770087980455, 50.75470516758581, 58.421675851268155, 55.83509237535539, 20.562680459791615, 2.4108595761560627, 0.13815522374164674, 0.07737539363123717, 0.09450181777919493, 0.05013427997548735, 0.06971692756539391, 0.0657820318555159, 0.05110724994371976, 0.01747569320873628, 0.022067057321809476, 0.028952194017268, 0.00476359743662479, 0.056653339641108635, 0.03283483486983084, 0.018771684150241556, 0.06862772673728966, 0.02999108776660456, 0.03482051561736772, 0.06683144973771227, 0.043305337744494604, 0.051421706053999164, 0.08387088460186798, 0.07029634284516496, 0.04858330049882493, 0.02597663957144945, 0.055289247313574444, 0.02497046735257872, 0.0235789337555968, 0.06178543159377672, 0.056240203745302655, 0.02782477880828083, 0.04756755984177993, 0.013237675659418588, 0.051517716023109617, 0.09034888578518745, 0.006548504254991009, 0.0514025078906167, 0.06402151967068354, 0.002877607471272049, 0.026839172219737407, 0.10641541196814469, 0.04894921090453864, 0.06558502468490793, 0.03126367472202307, 0.01777434684035759, 0.03312017197810835, 0.03421001248962937, 0.08887603578548278, 0.04667036746057772, 0.06378512025900906, 0.08790177878953757, 0.06003433845997338, 0.058167232801356626, 0.035738618368463176, 0.05616275991703715, 0.057048740601467515, 0.046297485654753064, 0.041576315603789785, 0.06972381469583319, 0.02276039179114084, 0.04028026337525056, 0.07248517095802293, 0.12030863864046913, 0.03133936420894198, 0.004590714374752415, 0.03886792666068481, 0.026035639832937912, 0.04228865862974236, 0.06224122709564625, 0.02008364227930865, 0.08550888017540978, 0.02713814186262748, 0.022349736104989727, 0.07045302314743881, 0.042045226530923, 0.04211327812123684, 0.08976089032066446, 0.007389080344564132, 0.071963909412584, 0.03276206034746382, 0.022282956220630198, 0.07701998246052573, 0.045998171272297064, 0.11095924798639552, 0.03386080280066498, 0.04004160017375985, 0.04597948638782386, 0.05750250213989808, 0.0675039983264381, 0.028440462605607127, 0.06558274940377282, 0.029672240057299216, 0.01059632228251787, 0.0887222129911665, 0.015081514270165035, 0.022773260153048945, 0.061890592483142694, 0.016185038069623615, 0.029810503605873357, 0.022554729742208318, 0.08592312689870597, 0.5918308683941441, 0.4909266699706355, 24.266009792204827, 71.69126202983242, 70.85832318952008, 61.889047161225356, 39.22781628947104, 26.56046494360893, 36.796943064658876, 66.22135208499047, 84.83776815475957, 59.05783722477575, 15.451787018006849, 1.4104691147804262, 0.8727139414798829, 0.9013650782646672, 0.9343994637170147, 0.4348220369748531, 1.1219070827768696, 1.4161349784943367, 1.6216213328223077, 1.4467396394860361, 0.6691513871473651, 0.12384766607635445, 0.32040128965050946, 1.1464404050380954, 1.2379896280265625, 1.935042611533596, 4.12982629191491, 3.516103082126187, 5.946015571394275, 7.248327289858173, 3.320745513323815, 3.5322301522378003, 3.797740782460859, 3.5788303613662724, 3.8615974591624354, 2.827973000464901, 0.8273067457541343, 0.5714293953872497, 1.0222967762139537, 0.23599166903764973, 0.666969875174184, 0.3347728539618754, 0.3513860834702369, 0.7772571797813139, 0.596793647254667, 0.5132358857700902, 0.891716844372211, 2.1865953649244, 0.9930838824760531, 3.5849507297239, 2.3019208927308363, 2.853783912235691, 5.366537840135637, 1.907200402309818, 1.2135548553159161, 0.7867322778028827, 1.3428272282884968, 2.305687103540667, 2.51235090436474, 1.479935393698754, 1.1109697986995022, 1.3130314335707696, 0.4384817922067258, 2.5077222624132713, 24.351990107567083, 67.77696409533101, 68.85818112281062, 48.80434190073321, 27.94010569972377, 38.44469939508746, 63.25173347227035, 68.8421464735462, 32.69923117852981, 5.754820127641001, 0.2690414681790337, 0.06666516269286794, 0.13990964169704145, 0.05863034444290304, 0.050915034653078166, 0.03903002703502294, 0.07603289349184883, 0.007208912744141756, 0.018727350642063448, 0.061563894287833286, 0.055384341807615374, 0.04987137775207239, 0.05335130150459948, 0.01365788063154586, 0.05348003491939557, 0.029429468709314545, 0.01588132921531196, 0.05498196944714554, 0.047345742913744146, 0.005818338193480046, 0.07952915789980082, 0.03126216935925186, 0.02184315663461964, 0.04577435102433928, 0.01484807195787829, 0.016799459737094662, 0.05285196156511384, 0.036335546418183276, 0.06767063777172758, 0.029937664625204863, 0.0426087033514294, 0.05301966204217846, 0.028804934681242997, 0.09726990795423908, 0.08607754724160319, 0.08244174757912275, 0.04135423437542012, 0.03884595525901645, 0.060011853779395746, 0.0549403325684609, 0.021757517580784137, 0.03496764280322579, 0.0739825587539423, 0.003157431619324451, 0.05246385759223373, 0.08094334854714333, 0.0028072693479067137, 0.20535159946209003, 0.14049220559818132, 0.09875158328683147, 0.12385128201135706, 0.16078616582578228, 0.09519789292807541, 0.2238498342734191, 0.25106716089912, 0.14114474397032492, 0.1834745338607219, 0.10384913999587299, 0.0884480071404288, 0.08795977930628485, 0.12560458913926156, 0.21253994035144008, 0.1481916803506113, 0.11516082656359482, 0.16486405184672726, 0.332673619831762, 0.14059403400507667, 0.11326265987008811, 0.1096282238441129, 0.16498232050047767, 0.2236451662235683, 0.07548635870578789, 0.18232151024764587, 0.1418889064582125, 0.11133384965961018, 0.16648858725543947, 0.21183259604919344, 0.2160597466413052, 0.09165317345891269, 0.15645747794018638, 0.1529320025996816, 0.0844634842548159, 0.13969280817095311, 0.09872776561326559, 0.09962768143703861, 0.28195611711951996, 0.11880458587960852, 0.07601967081427574, 0.17265651435140641, 0.13803277224782975, 0.1036447017723995, 0.2328540946567251, 0.15880956705058777, 0.2060377231288341, 0.15192576143289768, 0.2403329667304793, 0.22963733742794684, 0.2102385509398676, 0.12223086049479824, 0.18442164836150987, 0.743668636968059, 0.403560072544121, 24.2634210278911, 82.59892632884365, 83.07660041316863, 74.98760623316612, 66.92963015648627, 53.68465292838312, 38.52216228362053, 54.861285532674486, 77.99451089674427, 76.14618024518414, 41.1085614081352, 12.188078895691904, 1.4724892642228835, 1.3149396666596014, 2.4616638306648504, 3.391243253023394, 3.538414259110728, 4.198961988572152, 4.431237395732634, 3.9951708336030287, 7.854857608195275, 9.9369433810634, 10.7753784425797, 17.819294352685255, 21.872948215853786, 18.36051279498685, 15.21281171229578, 15.417698679431794, 16.44806904177512, 18.96336736217622, 15.639820541104964, 7.271800714154398, 11.109943870575199, 11.920453617649695, 9.433455198041855, 6.901074465244048, 4.220649753847431, 0.7378385852902167, 0.9396505367852027, 0.21796652416308082, 0.521586673153985, 0.3713011825757642, 0.28455349226151744, 0.54124865680933, 0.39434363644930626, 0.24624235447376008, 0.8296642128017642, 2.9738552628024935, 4.01627833324094, 14.535450743090722, 11.851162006778102, 18.32649015611218, 18.6162729032578, 13.653267525857496, 18.463606411410918, 18.427130329993464, 13.58298747770248, 10.689613857576925, 7.0926077231284115, 4.933441983115289, 3.8564520449407644, 1.182595219823622, 0.5526438163172814, 9.020591416666585, 44.36858838604343, 58.05649534348519, 49.49457706943635, 48.75020142524473, 39.3830519337808, 67.8070878982544, 75.43284231616606, 77.5336794699392, 36.39147589283605, 7.962243768476672, 0.3236651919301479, 0.1944649537965175, 0.2849011736050729, 0.1733834245392392, 0.3157392769090591, 0.15004645582408677, 0.1725270608139615, 0.10845958735914, 0.12510328418425015, 0.17721847600994572, 0.21414480262225677, 0.1696730155738131, 0.10272708165669635, 0.12229161126719368, 0.17890662735989019, 0.1146961942375187, 0.1232327962474477, 0.18080905350225587, 0.12210994117682981, 0.1505328756907294, 0.16741563025261127, 0.15852464362978935, 0.09620025002908322, 0.09585113610110937, 0.11908675904475874, 0.10576157124652978, 0.1475572063317222, 0.11167056828496918, 0.1277092778153958, 0.10127116986099752, 0.1779367447259926, 0.09705165716549082, 0.18172698005312876, 0.2010108839960829, 0.14736156279761947, 0.18225616294770472, 0.11908083718510405, 0.09438907261937858, 0.11591827301608941, 0.17334184128670924, 0.13938275706623832, 0.13783570379018784, 0.15079696151998737, 0.11411879376898851, 0.11343186570992393, 0.16253284629314177, 0.19828382549026322], [0.06361087739107109, 0.06023218449685843, 0.03118000259893316, 0.07827454336708592, 0.005107179252175434, 0.047138447182313095, 0.0290209197649552, 0.018360170445615248, 0.04773849320988502, 0.01637699097515114, 0.02935835851296302, 0.0377716625019187, 0.07715626950225524, 0.07763548814240964, 0.027240039217436028, 0.048928415447834044, 0.021638911848347035, 0.05463005929824807, 0.014243269481906488, 0.02234190477118377, 0.04611618328659285, 0.1276117011964802, 0.08732859180459092, 0.05613005562354961, 0.032445110620990876, 0.05004966939469019, 0.04368312634347428, 0.1469022011564624, 0.024810094506509846, 0.04854598818647285, 0.06998028561112381, 0.08431942142065495, 0.10007147617157429, 0.052830354055209514, 0.04618381735898795, 0.07132677706859766, 0.0505778027488099, 0.03557873581866584, 0.03306695185000858, 0.04019088006668514, 0.10111146351142276, 0.04798315871026247, 0.009040950249219614, 0.0395798598295979, 0.06544129126855443, 0.07510370544848904, 0.04695568541665712, 0.015738911554968406, 0.04019189130274519, 0.00988711064095579, 0.13176649478414368, 0.07167307179301016, 0.08748910254648617, 0.2518158586275193, 0.10893470742889952, 0.5212676741423146, 0.5140045783933133, 20.170698396621212, 71.45266425225043, 70.28189951373686, 61.651367218263694, 60.79592574027277, 28.27195586696748, 23.120960112540956, 28.430135250091556, 47.883051672289454, 62.52247856509302, 50.887646059836115, 42.65485778931649, 27.485026428776404, 12.863664992393987, 4.81276192972737, 1.1759129719388102, 0.1783538183137294, 0.6149824131881038, 1.7526123168007022, 2.0992483487052302, 0.9554205486370672, 2.486010962916959, 0.9257848356519977, 2.0561562093996235, 1.5829638007187075, 1.2940752313983057, 2.3724438826883993, 4.176279902458191, 3.7537080097583035, 7.796604527581123, 5.628876743778106, 3.5012806903931404, 4.089855623822059, 4.787081681912945, 0.8076369173584447, 1.989710155513979, 2.8771484907596343, 0.29266467798621426, 0.5213540888601734, 0.675867833197117, 2.522931988200834, 1.2276734267511678, 0.9948001645745771, 4.359928215703657, 0.6168694409631914, 2.918074255989444, 1.0913383359870603, 0.9063722902247984, 2.4410309378177892, 0.5421067365715581, 1.6283121608918714, 0.5443432230141856, 0.9353421808731173, 0.7332500863459803, 0.8617384755803693, 0.2511803580508117, 0.9705175062821758, 4.98864051795775, 16.747420410956106, 28.517433481831706, 54.91490433293005, 90.34206159653203, 41.081065593227265, 13.225287910430664, 26.95468079659247, 38.29580230097617, 63.40466668528896, 53.052872842358006, 26.278038601721487, 5.60315776255823, 0.03366294144202144, 0.08468374985480502, 0.040458041738959095, 0.03468940349956674, 0.060035276917680624, 0.03187935277368994, 0.04860236076638103, 0.03775493114165241, 0.015087493586414044, 0.06926964713080276, 0.04109605125361874, 0.14704653212139684, 0.016635153029534607, 0.043502249154112035, 0.0719515600752446, 0.029722190905182116, 0.03600792508692511, 0.03088250959051713, 0.00863786159654058, 0.04256601310184887, 0.02801767400195522, 0.016821287497277224, 0.02620826050969622, 0.04164395733706413, 0.05436413485797183, 0.0551805854023945, 0.028189407931941173, 0.0001622225593769878, 0.01716855132291394, 0.04528155730616662, 0.03979974238562488, 0.056534975226367676, 0.047042272504298925, 0.06419528373366883, 0.03817413828425831, 0.029046926534764712, 0.0243313163669119, 0.026251123129059712, 0.009591317390121762, 0.030241535315590522, 0.04927833759856801, 0.016044926333932147, 0.03203987500690405, 0.04553104533002742, 0.015971255488693714, 0.05462879142273338, 0.02999871034145115, 0.03984778375935651, 0.01635243211151852, 0.028458994272495472, 0.03266498168569899, 0.055452155910672686, 0.11225606630285902, 0.017526846814660296, 0.01899078146614615, 0.04378180995944046, 0.03578831449211125, 0.024710955068228707, 0.05479956391237436, 0.027467971442327387, 0.021096431582625357, 0.04933281794130322, 0.04684373315784239, 0.029335454399246844, 0.04816313574631368, 0.028629548427078034, 0.06450782845457716, 0.031241408376503858, 0.0457006533660235, 0.06386879238209899, 0.06651651865291981, 0.05159307992266071, 0.029484560007169366, 0.029814075490820314, 0.054752675500968774, 0.010412448731761788, 0.06828838043035039, 0.040537144147580674, 0.04841600604836018, 0.06743743294669736, 0.04778561910854713, 0.05120211461138341, 0.06314688091797215, 0.05747228763216446, 0.05274601926606509, 0.027220141998822653, 0.03424691494494196, 0.042585429600289756, 0.054917403556887186, 0.05199715682876207, 0.08376215374277485, 0.06041193170653236, 0.015878201661361082, 0.04024712241164619, 0.008103392695287063, 0.05120174688917976, 0.02607146976515651, 0.03982534887449395, 0.02840889403746734, 0.06877218027629199, 0.020672151022740913, 0.06400959168170249, 0.13379442145026502, 0.115922425212639, 0.04289652258458157, 2.7466414292012495, 33.871117714912664, 81.73652264379686, 73.43907802335679, 60.33345476273568, 40.489227002666844, 26.079894188911688, 33.30964611422631, 58.477440188007975, 80.77210595530849, 85.881604994497, 52.98864795315651, 26.688630350174446, 12.226850544252704, 1.7753775081326886, 1.483569224515269, 1.5150403615928467, 0.336306439412217, 1.0874216042218672, 0.6496230092260146, 0.7161465912095962, 0.4763495795909436, 0.5440874109345099, 0.717183874259072, 1.497076273925843, 2.6399541862549323, 1.8418754108490485, 2.2955941096428902, 2.5316276377247227, 2.340076729174583, 1.074014942972891, 1.0566140831478181, 0.5501325188144561, 2.592759002600947, 3.4560197255303784, 1.2521995171423883, 1.0997721673019472, 2.6572628703809555, 1.4440859109163287, 0.6845930843583999, 0.640668360696685, 1.096069082137077, 1.2849551078773316, 0.4883947800244055, 0.7030000321326718, 1.2988296343434242, 1.9634328494148872, 1.2048511159035469, 1.175036935075637, 1.406615998956465, 1.8081633746623995, 1.7840073353821233, 0.8935578455848079, 0.3223287055809652, 0.15168321799607049, 0.8868816038293224, 0.4383015470399011, 1.5153325781706841, 2.0356454003241757, 5.0421543948112, 30.440987348556522, 46.57489022900982, 70.68816292670466, 66.06874050632601, 27.874666836953935, 19.39174705936063, 33.86357891944147, 63.51197096609301, 69.74790803847775, 40.91637311443206, 9.254497058929937, 0.1026743135204719, 0.14777250768196198, 0.06991799500200056, 0.05371803162439216, 0.04506027663967783, 0.02532372581622293, 0.05672120737032064, 0.05081974097617692, 0.01179888975926705, 0.049399394812362815, 0.0786570740503169, 0.09322681764681494, 0.027953284311919447, 0.05930842801688179, 0.07860749283985746, 0.014359969570631943, 0.031724038023141124, 0.025858347935061303, 0.0009816210161173538, 0.055675470540600444, 0.02112755198932944, 0.029209478900978164, 0.06782970060744593, 0.04698657408176411, 0.031157309159396157, 0.041276733090560284, 0.025213547050952915, 0.023859482814347552, 0.029490401427592003, 0.02592233734415664, 0.08058407629329352, 0.0435162915457641, 0.07773161685514836, 0.056659663696923566, 0.033951522932658275, 0.012840580687137141, 0.024522968582929145, 0.01180777733679861, 0.014130415154560922, 0.0323479859939506, 0.07907105264283958, 0.08108511311753143, 0.07115849819515022, 0.09839859295396075, 0.01563696248922497, 0.03797263800797444, 0.060361109433635596, 0.03684384958638299, 0.008843372343108058, 0.1805954681889665, 0.1715865193475639, 0.07290041359562068, 0.1782737314821251, 0.09079025968188241, 0.15062217089918353, 0.15242571041228312, 0.13865128099437685, 0.18526213874499645, 0.18813835456967357, 0.09896695358498443, 0.08972073965255292, 0.26764035465255864, 0.18791361501620663, 0.12861421151507285, 0.11403797149297693, 0.16098844368130932, 0.13344632641923043, 0.13089890020989603, 0.18480167393722843, 0.14289315579639328, 0.21531374554239938, 0.13701194476696754, 0.1369803819444872, 0.08738740437453793, 0.15554828479165034, 0.14884826366699513, 0.3464812515003066, 0.11838131464056431, 0.15927678875384793, 0.23957024959306564, 0.1862096975767805, 0.19318745621750433, 0.20362842257224745, 0.17076521180570128, 0.2321770414710045, 0.12888894596647832, 0.16490183530315278, 0.15472418868974333, 0.18341073405838784, 0.1444268638208028, 0.2303581801994193, 0.1700933373743488, 0.13905211351811886, 0.12965287352281232, 0.1698661310177657, 0.13092324648412967, 0.0988657916745832, 0.15497811619312535, 0.0680752624306948, 0.2063856649422838, 0.20508844826009967, 0.23664039229193043, 0.3544787804205572, 0.2444655514292179, 0.7321001577281183, 1.9142884929333965, 39.109486226112615, 97.93202046425112, 88.36115483314761, 76.21914417512956, 76.95112120720648, 46.67067450861777, 38.03485485815233, 44.85870815092518, 66.79586948886995, 79.07709290904384, 67.94638695255404, 53.145079920368815, 35.26501824778896, 17.309550969831406, 6.8180070000310105, 1.6289754091731965, 0.13872197558802946, 0.8980777030510287, 2.7148876363231293, 4.6607632214023225, 2.0217988207455604, 4.6463431177600745, 2.6766565394017006, 5.871502795527059, 4.832576272949096, 7.566906607920124, 7.903684252692808, 13.752336790484767, 15.719881999877193, 25.185478079703547, 19.930159045803933, 17.951625316373764, 19.95022196923533, 19.176130448618245, 10.816824167005478, 14.046817556504282, 14.175688989700811, 7.176334636826669, 5.052548675767837, 5.837634109681653, 9.19171069898913, 7.932373939021942, 8.301071832256934, 10.699858107874471, 10.503707239704749, 12.713178357770367, 9.383793088697619, 8.367509918828166, 9.941361931062515, 3.9156994463935977, 5.680524062725806, 4.268900300225904, 2.553475239584523, 2.743900182747072, 1.3803095202292166, 0.3081009512947452, 1.5263468387626833, 6.376589834690095, 20.430684858752837, 37.82829500013782, 67.08390482010381, 101.45958838924285, 51.45458936691285, 24.199402063123642, 44.33959030335949, 51.630280171671224, 79.92910231313398, 78.95038466299735, 45.704720251021854, 10.75897312933399, 0.2057752614059756, 0.3050053125667957, 0.19754802868250879, 0.16779135041419538, 0.21906124848511913, 0.21143130387269685, 0.12514716570055293, 0.1755971581705155, 0.09852988510242394, 0.1398513730495207, 0.20540050651517608, 0.19729388667450798, 0.1797633894508885, 0.2189584394856807, 0.3485015479307021, 0.11917853637808755, 0.1502029062999833, 0.1264282102666555, 0.0942991798623435, 0.1467878548728843, 0.08024427033359967, 0.1288933433111637, 0.11834073496321518, 0.1066414921754791, 0.14175798203195297, 0.13123452332952332, 0.16975054367175027, 0.2495208890327523, 0.17648212761888582, 0.10504986024311475, 0.13948665391052925, 0.20259806495760718, 0.13433860434639838, 0.2010200464076573, 0.2405495091431564, 0.08245047332058031, 0.1565747047143598, 0.09910202254691433, 0.1373341613479199, 0.10066850381272455, 0.19062383490945065, 0.13703684262450666, 0.20895348441216255, 0.18487333380166562, 0.12046462946361113, 0.18377592817189234, 0.13675365056241715, 0.15791169668157257, 0.11580552785627304], [0.022176475744814645, 0.07177474698232067, 0.09274576039564225, 0.03363104537129402, 0.031324182261502555, 0.008080767246053345, 0.02741469577285311, 0.02353279994079663, 0.10871936011338428, 0.08542602776639885, 0.0482298237001223, 0.07065979027820211, 0.0973723722141116, 0.007442766349882849, 0.02833937730399832, 0.018741278120526866, 0.02161025441431951, 0.06200535628463953, 0.021842003672293598, 0.03212123545968244, 0.026598760422559518, 0.03364832831486579, 0.06522810432098566, 0.06237497072546713, 0.015472469047733374, 0.015833733130186316, 0.0327585669865291, 0.019394188045313763, 0.009112028844444262, 0.02473003065754329, 0.05122706992551685, 0.03808513035877578, 0.03191447407457858, 0.05838195575521358, 0.02789285146601258, 0.061863871336343794, 0.009212025343590688, 0.05256773145388692, 0.06078086432910735, 0.06644332661263405, 0.021514280834385467, 0.02508298268601779, 0.02957284972522288, 0.04226739202896434, 0.08180734250814685, 0.042724122158101493, 0.014249470963653539, 0.02408448475292854, 0.07056789803168467, 0.02974897908467439, 0.09104055592850333, 0.0476022023377159, 0.03904069097892892, 0.22855759778570747, 0.04944602275387414, 0.15795879576715732, 0.06962517321470284, 0.17252513027239233, 9.166559480851697, 51.756855057131865, 66.07798945519232, 66.49081891582858, 62.901909043712, 56.82483188567623, 39.25270765058456, 23.2113903568637, 23.6947871792701, 24.808120573720625, 24.5847455147774, 30.605589612837765, 55.02978663290701, 55.38005036692466, 57.915839149105935, 48.45276417270784, 44.6944079091472, 31.999913761692664, 20.935382112379997, 12.92161605050487, 9.007655439838286, 4.991157208719562, 4.079734437888669, 0.93655088375653, 0.18455453397285554, 0.10041455332670482, 0.2921371804850717, 0.3219949363941147, 1.3325582180292377, 1.5065942728711714, 1.4153551622744531, 1.5211861027825264, 1.4727661590422354, 1.051071283798064, 1.5974366112101464, 1.1675289056954847, 0.6906698163478606, 1.809875979538887, 1.2413078306182739, 1.2574284043042891, 2.55765256381804, 2.4129592699389306, 1.0666478737708063, 1.7136932116362358, 0.8619857074752931, 0.1546802458864066, 1.4051932817505253, 0.05665820429942781, 0.22107685645741804, 1.3267013839175625, 3.7516058644940777, 8.51954000611459, 13.742440650540015, 32.15664186785298, 42.12098398516255, 50.22041951456378, 58.568148920612956, 49.804142290546054, 19.94253412369759, 56.130368401927335, 58.33753708870181, 22.707497189121863, 67.32245552924373, 76.56580325095885, 60.45420100612026, 29.742005294369115, 6.599338294998293, 0.06128806050025648, 0.4744029808188639, 0.04236414127292172, 0.09527668507108766, 0.06166239787313727, 0.09412900109084384, 0.02732975194380889, 0.0642203348087928, 0.03367164037040165, 0.06608612279617979, 0.06186637261341657, 0.021064748101296927, 0.011317963700651402, 0.04787795951650028, 0.050691980493044665, 0.047201898414641626, 0.012212808022365696, 0.039143009682095824, 0.04746225722614796, 0.05816404970603124, 0.03708449312515798, 0.0052590691108977605, 0.01674812801572825, 0.024559685261920098, 0.030526177199076743, 0.03437893870737284, 0.07863298058509827, 0.06513562218676652, 0.02645172899769199, 0.032099606882360195, 0.0315564792723425, 0.02639333394566371, 0.03789059765216324, 0.136694677114006, 0.08628078270703556, 0.04503096994613448, 0.021404917952754808, 0.04848354819020437, 0.07410798266890549, 0.061869479099949526, 0.035785146718544346, 0.12942928310123183, 0.05802004815890424, 0.0287928190007205, 0.051793680045633554, 0.015580858040090292, 0.1293035680728574, 0.031094064770807183, 0.021733067884680726, 0.053563473385668574, 0.02097380388858578, 0.02509181759500456, 0.054162990812572746, 0.060377802489505666, 0.011654305985317597, 0.003536272152785152, 0.011678262512319753, 0.018126052060735323, 0.02916972085292782, 0.056112696071185415, 0.022301980099009893, 0.006948393532976269, 0.05009089258589572, 0.003063296171603725, 0.036281249936549895, 0.029186728004846844, 0.009595529916095398, 0.05563788243659562, 0.035155636949404594, 0.024987372997847777, 0.05461665659001278, 0.04227728988494604, 0.08789741974924842, 0.02308867004279408, 0.07007848276125808, 0.024016373790800575, 0.05829072617475064, 0.028289784602220022, 0.011638780255922148, 0.01563642527006807, 0.025245694015475533, 0.025300486539039883, 0.03176668422266601, 0.05022534867748619, 0.030247876608383753, 0.05118354847053847, 0.05986327868736079, 0.026122460577396617, 0.03211784360539769, 0.04746373577584182, 0.03495377278135669, 0.028681967993296927, 0.02595385994702097, 0.010850165516228206, 0.05320726165307626, 0.10725439315842045, 0.03917280667191071, 0.041663029095939094, 0.08722924552257023, 0.04128297287670355, 0.041023318866087545, 0.022702824114070787, 0.09567243843189172, 0.06715104629796359, 0.17357133058530672, 0.06385460060330168, 0.023906986011312376, 0.22696054961171844, 0.1436571752832782, 15.0383819495478, 67.18083443180208, 78.74895526516822, 75.33430453269713, 58.957820707751864, 40.1997600063201, 23.234510767844416, 25.657880498516946, 40.61594701582386, 55.6353731309214, 64.6697565817064, 64.75319716238207, 73.44984885184996, 65.8809688014369, 64.12743791457146, 43.57302188873292, 28.569379391208773, 13.418337164386628, 7.1922839745398495, 3.9679655192359804, 1.3926534643096309, 2.0127158371671556, 2.139761774770675, 2.1518831243438106, 0.6208491757992776, 0.24241399861151175, 0.6425617623233026, 0.7416809758832379, 0.4164033527335813, 0.31580365893821566, 0.1782252074730012, 0.9809613684492727, 0.9940429632702182, 0.5288618730921899, 0.38974422841302814, 1.132698503713454, 0.9999602876843946, 0.9067995221384111, 0.517843077259679, 0.8270638652386204, 1.0842099184951475, 0.7610717644133876, 0.9209526594608062, 0.9408285348646103, 0.9729312961139988, 0.7084649356622851, 1.3359462878396435, 0.4648285365152744, 0.7915175081260744, 1.220649074642889, 1.9890717897684345, 0.6270057035069312, 4.258431494235992, 15.908883367815326, 29.525174710058398, 55.708337060866825, 75.6375115917575, 75.30844826852122, 47.578632600845836, 82.53678029583347, 86.27166901865314, 22.924110081888017, 28.52102637290955, 64.06647643735333, 73.27746852751702, 47.92741367893834, 11.771267248738198, 0.33187045325194636, 0.53388943234759, 0.03808225752905973, 0.14308878400873754, 0.038075692155548645, 0.1114383900177575, 0.03950119409109316, 0.027552785036424478, 0.043007647468438076, 0.06988186629549151, 0.05877533424345236, 0.017451096040707444, 0.023897925106387947, 0.03173834854556668, 0.0526462784487634, 0.016817225316058726, 0.040098589454447074, 0.022274548405661218, 0.05613809188587531, 0.011146051655223053, 0.016468921526064797, 0.05846619478336746, 0.02386553873938899, 0.0036577171985916197, 0.03047102461418798, 0.03841230352859824, 0.0571577319304549, 0.004517032995805024, 0.036026617632277554, 0.020729101999031923, 0.026488568250750823, 0.04557810994165559, 0.008667751474516287, 0.06709211881482793, 0.006515642913478998, 0.020181950512191942, 0.02522123857371269, 0.026508917461239526, 0.028347398244565534, 0.05459333687359768, 0.03680145428065331, 0.06487715944287277, 0.042463610129010294, 0.03281886959748884, 0.025458723915019826, 0.040288341772412105, 0.04467137976579609, 0.04433129418400988, 0.03424827092056794, 0.04973652712520092, 0.06612809675355112, 0.1313733691049199, 0.13612809380696667, 0.2500810831665032, 0.2133994450372073, 0.08855499897993381, 0.10875401793107872, 0.10925754454107055, 0.11296494278095423, 0.1682722391260247, 0.2026987595543746, 0.2429918587327965, 0.14827049547626128, 0.18117884414330607, 0.08637343338059802, 0.12907965589434872, 0.0776974952990009, 0.2615825603565862, 0.13325138768601802, 0.21902568668367403, 0.11722948612465013, 0.12748111384890734, 0.2589973506908263, 0.11947089851263071, 0.13997160288835728, 0.14326383509943563, 0.14081730266972897, 0.09684518880901799, 0.122736846247027, 0.169269593672887, 0.1622403539236515, 0.14749962716333329, 0.08806868636560056, 0.10667656368065266, 0.14362761961115947, 0.15377696693664597, 0.20742860172064076, 0.16099860200718527, 0.1488922524356073, 0.2031223142459508, 0.163604756516795, 0.0970933017050547, 0.08171200286597013, 0.17284195359435775, 0.1045156901161517, 0.22473386909452178, 0.13555021836392342, 0.1294217754395739, 0.2636189752769086, 0.16699924614400635, 0.09423240763886322, 0.2640503440653124, 0.19320970341082544, 0.1506344436277305, 0.5512440817490701, 0.15445518457601148, 0.49702350410722923, 0.26478388857456947, 0.34014938158854363, 12.953891273467773, 75.81153146682247, 95.09453865789598, 83.73450740691155, 77.39178380658551, 73.04324811504733, 57.78538503954488, 39.08400650947325, 37.42228654123122, 39.65106748765515, 43.34488899477067, 45.573289471287886, 72.59029280754828, 70.4305338090466, 73.53067321162071, 61.10920544593566, 56.40005880786527, 40.45906789841191, 28.851493904667517, 17.31504228807265, 12.10592975539546, 7.075810172865468, 5.288283123124031, 1.4542019487388673, 0.46352569674772603, 0.1571111960877334, 0.4342358264951937, 0.6379391877881943, 1.5596031445649363, 2.38047763224571, 2.725880814175452, 3.089817195169388, 2.6776476733146177, 2.5462644523189915, 3.0122898326766108, 3.360614690088457, 4.446115926388772, 3.899732703162778, 3.3362780992061865, 4.2063791905680015, 5.275841855233716, 6.352877145813358, 3.1999566141636144, 3.5410878446794327, 1.9238756236530121, 1.1133658765785157, 2.293026428068838, 0.375191897995049, 0.5702114994487455, 1.756540080232005, 5.188885359994827, 10.529320316929972, 19.36859723060362, 40.12960057104788, 52.797165686084384, 61.72879872783538, 73.26687028331142, 63.025593142355646, 29.97065986356428, 67.2939085191296, 71.77647944419616, 37.259264992129424, 89.501003449963, 98.31060763328307, 88.72979487142256, 58.262486457824714, 14.96029834593496, 0.614884170072694, 0.9672394466976967, 0.18705564250628795, 0.273221182606874, 0.1475354953999481, 0.20595949023000656, 0.18338909973540615, 0.13216908931011154, 0.12445538064404843, 0.22949273067135967, 0.19675403983602602, 0.14471086793609206, 0.22185141731414104, 0.1531722018074605, 0.190643661264931, 0.11840798982208776, 0.19558892735550482, 0.12004285209601927, 0.16854979278099153, 0.11420671768005818, 0.19148546931964738, 0.13991949358774772, 0.15427631836745048, 0.08129336645886784, 0.11742689932185797, 0.1608272587820407, 0.1532390659614917, 0.1259385192045762, 0.1447580742739862, 0.1284033534747939, 0.13597801718260014, 0.1040525286788902, 0.14670750757138576, 0.20159033758025016, 0.1632583162356769, 0.10938942657723542, 0.08610314990003264, 0.1089963621850456, 0.1568660019866882, 0.09678008665721263, 0.11532657734689214, 0.2040851335491865, 0.15192580739817313, 0.08952632952000826, 0.1799648092879403, 0.1453836923164706, 0.1576726466056801, 0.1469837588768813, 0.167081615917625, 0.0908727673513274, 0.1853326954428227], [0.02399617971311654, 0.024911808000216563, 0.07920865735579884, 0.010057740446720875, 0.02162576003390695, 0.036845171088052374, 0.05388172929205241, 0.04296884894551289, 0.017583493271001407, 0.049525600137008775, 0.03319201953408699, 0.06812643710403674, 0.017017838845570243, 0.04612193277646457, 0.060862908515358166, 0.04092339801812365, 0.031031318339368993, 0.03536256878907162, 0.023636330978103706, 0.05584012198772642, 0.04707632128209357, 0.033188315498973095, 0.09406525491466446, 0.042986541746124145, 0.03129811228943929, 0.03966653884779062, 0.039553157834997105, 0.01082361386638255, 0.028686526216446396, 0.041350637592615626, 0.06720504783574613, 0.05318784132419575, 0.076928396649178, 0.05262781572978824, 0.029484801324865514, 0.020004354094365434, 0.010688483617418717, 0.04766594085301604, 0.027169695109008785, 0.029339821100415244, 0.022003653969976212, 0.024153620357655232, 0.03507217550049386, 0.06127016085590567, 0.12071780620082734, 0.018454866573935556, 0.033592070648146254, 0.04510853251802825, 0.050399338736409144, 0.016163070498394872, 0.02072529262682844, 0.021528759896154367, 0.042638956163559234, 0.14858500521269538, 0.04514895897779254, 0.07169651408349315, 0.04413258629821001, 0.12846686216371675, 0.3395970934821714, 0.13792792545451274, 11.747572210527236, 45.591759912429325, 62.77835046091388, 65.3107463928961, 68.01174148436516, 66.44196971770256, 60.05109902351134, 41.263997093323745, 28.455654190432643, 30.499581675375666, 30.112069153016616, 18.925651811784316, 14.94483636271569, 20.726160926203576, 28.592423315971132, 50.86168389166556, 59.77849821890555, 54.31372657898934, 56.823949352387466, 61.13557161823396, 45.499250811915246, 52.43841394301384, 53.03990156419816, 33.63131969205795, 31.39871051234584, 29.716664821870868, 27.58093818541496, 16.70025194844892, 12.295931327727533, 8.854447660907622, 7.970895046187986, 6.8411636929358215, 5.23276932777897, 5.680655462126579, 3.821486321187789, 6.04800307942975, 6.6658651251946734, 8.54795071386522, 11.27593171211981, 9.961210104726977, 10.243972789856697, 20.090028970472275, 19.17300431959091, 24.50210313643179, 39.809150772710005, 41.787821785096206, 46.434712563791585, 54.75382827943372, 50.14269382722917, 50.25615230683358, 63.160840388267275, 39.05045455501926, 30.650296788061823, 24.81592805154862, 27.38957358944801, 31.71468684750219, 50.59604137174545, 33.403896747096894, 36.03531291407924, 74.62402605241346, 67.88752002100792, 47.19901384845857, 12.16681278521015, 0.636070913845493, 0.1708169074188317, 0.060779060192045674, 0.07619563354960374, 0.032281596814432455, 0.017011928477234418, 0.061962922674513636, 0.09047517537950509, 0.03368704639855893, 0.03871567817705293, 0.03894187329757599, 0.030242747649730697, 0.057313990884370385, 0.03276995871396315, 0.005016316915111196, 0.00890113249976909, 0.017592264977734418, 0.005063689398323937, 0.01294416822342863, 0.053605186873145645, 0.018972192342663487, 0.003459570711598762, 0.024124160446527026, 0.06311220777851921, 0.03989090684861426, 0.046779745663966865, 0.10752970217576913, 0.07846364451031532, 0.06494115842806716, 0.013857577728377956, 0.001933157041240784, 0.04691522831337587, 0.10434792452161351, 0.03352206553362551, 0.05852907911063202, 0.033022514919960694, 0.05667110905051232, 0.02696225956653155, 0.024254539035140507, 0.01965500076391524, 0.06488406189507054, 0.02605027019707186, 0.05042330962755988, 0.06377617235205348, 0.0906896033895112, 0.04513973144874458, 0.04664230949035095, 0.030380628154342695, 0.14277447345516375, 0.032766836905671705, 0.023502462858995123, 0.10227666026161564, 0.0632048776042798, 0.07917199238774278, 0.07710627460431668, 0.06974283665899308, 0.04328397538272604, 0.060340972812545884, 0.0226774666037771, 0.02404848436614679, 0.01676665393695716, 0.052225286321293925, 0.06726662598309979, 0.019483094464146325, 0.03801562703184543, 0.05534946565486251, 0.08260061123198079, 0.1087487166026427, 0.08216545030835175, 0.07017376111640085, 0.033423374256780075, 0.013579686994724458, 0.022731471971999255, 0.10342701022783596, 0.056510973691699974, 0.06067864521737061, 0.018878329334960833, 0.044678201778761806, 0.059079785245440664, 0.0454780473674257, 0.05298820264156788, 0.002412611014029432, 0.019946313358002135, 0.0661980712245549, 0.07797174711501406, 0.04488903683640304, 0.0352927666878508, 0.04247264230563756, 0.019419926684349775, 0.045300690352075526, 0.05611884392677777, 0.04074273150294058, 0.030501083989116936, 0.05733339206105279, 0.015766653513926414, 0.049814652771719044, 0.026632830267772082, 0.14718899383179604, 0.03494059223861944, 0.03634749355936243, 0.06613788735722342, 0.0156085645674818, 0.029854685811686422, 0.0799190277053464, 0.028323685908089244, 0.0693307732862811, 0.05040404251626423, 0.09383780340994559, 0.16244961850104794, 0.045006547063108415, 0.03948350895136114, 0.4966511853760289, 0.6734962088446463, 23.20256502397599, 60.89887226781538, 75.1412219385947, 75.28286657025738, 68.80553507035779, 51.72832373649844, 31.415247224992324, 20.197939257467947, 12.837029157146333, 18.826780626850745, 43.35001161021572, 40.45755778589557, 42.996288345706084, 53.34303409822526, 62.07821915226599, 78.06879274306759, 85.00628102210261, 74.04850452176987, 78.26811190574401, 72.71125085892217, 62.48562397495393, 63.61033616527435, 45.16416272809429, 32.39627515116046, 28.24468754952954, 20.644585432544833, 8.668966620199143, 2.011051894195618, 2.3193443061843997, 1.929193867310401, 2.2294548586491616, 1.5313137851415144, 1.9225130903144039, 2.162522798584354, 1.4081659480448694, 1.715146204636943, 1.8732185805997543, 1.1529754414673776, 3.428074799237713, 4.269520525009402, 5.176670118685692, 7.463854176382865, 12.385359406471254, 15.625979477359405, 25.033268543981738, 33.34183308386034, 43.11075095207461, 54.68916408477291, 68.28025125688123, 73.74452867815572, 78.46183776855469, 78.90224149150234, 65.1773230491146, 49.62172069857198, 41.61755954065631, 33.4779824749116, 17.861667717656783, 28.42173941673771, 36.95629719764956, 66.88871199084868, 86.85153653544765, 63.847772921285326, 22.439059980453987, 0.9793883754361061, 0.21194188615247128, 0.06503776211531893, 0.09512384286931447, 0.04745990533622042, 0.09432249191787936, 0.0709818153371734, 0.04021482031431891, 0.06758130425887723, 0.018379169426137404, 0.05306973737934905, 0.027759762841366956, 0.025966678513213996, 0.06457371201606528, 0.058431927670514396, 0.019266245616299492, 0.005562414073445384, 0.023546717843160998, 0.05841220090646417, 0.05939689968081732, 0.07836579209974698, 0.026217871082706318, 0.04125235617280968, 0.09436785198387601, 0.08905500158547394, 0.025290349280581843, 0.04838309874157271, 0.04910204544543259, 0.06094397210906591, 0.037577865239713466, 0.018265677330594872, 0.11038843587401415, 0.06415167034813954, 0.023567407962776, 0.050253540713099704, 0.043996847009346376, 0.048509012952807455, 0.0334849638954526, 0.028046197370595993, 0.027270111998903657, 0.07116275764400921, 0.04186256818713681, 0.03435378037993947, 0.0687894172545883, 0.013291403320768188, 0.04757273476570845, 0.07965995975199246, 0.00435829239581982, 0.10782659188994478, 0.024783821521146644, 0.0586939450623768, 0.03616612990416827, 0.008471611898482568, 0.1551153991491564, 0.1592982238939693, 0.28746036692492427, 0.15666855048508416, 0.25558723286995966, 0.11752685847421808, 0.155450685190097, 0.11415702921728935, 0.06449125797277497, 0.13575651052017368, 0.1431973386676081, 0.1500423649145711, 0.1125501674569903, 0.18700549439076455, 0.24644244131782364, 0.1282047298586657, 0.14753532686060475, 0.10633509531016312, 0.13329355316537042, 0.12818227582160505, 0.1728218820907416, 0.2247881540848363, 0.3156249459472395, 0.09920363644919089, 0.08125592774200825, 0.15636583850268396, 0.17348859308948442, 0.1791381850958832, 0.07532294449065963, 0.15667003669565724, 0.24255972385646837, 0.21006587472173477, 0.1114382980872066, 0.16495550742312787, 0.12349226256652225, 0.11699807394536273, 0.156671890628434, 0.1106227208830176, 0.11752235387722332, 0.10279576909998733, 0.08413760577358546, 0.08252682164311409, 0.16393458801171473, 0.15338817731507365, 0.26215216205004727, 0.13763523390216215, 0.23824703188673144, 0.2453073901274512, 0.18295267476670204, 0.0843724959920491, 0.29324525005875096, 0.15868443424903578, 0.22338915496103226, 0.24467136861095506, 0.13505858909939567, 0.44770984219447263, 0.13731625021225022, 0.18969006566030366, 0.4696376381381866, 0.45297452098419594, 22.466314569596324, 72.17775360230478, 91.7877374156829, 87.6572149030624, 83.48739808605563, 81.81351877027943, 78.54818482552805, 57.71906952704153, 43.14338899427845, 46.90931935464182, 47.51157968275009, 33.42029225441718, 26.424835266605502, 32.660170255168794, 41.599991244654504, 68.89400805196455, 74.15027433826079, 72.03665810246622, 75.97289777571156, 81.48229814344838, 65.38045083322834, 70.13401831350019, 73.11381939918765, 50.67772473058393, 46.78296412191084, 44.79252599900769, 38.63432245869791, 24.915864159983975, 20.097306928327008, 14.574999020945642, 12.098932247008047, 9.856991748655997, 8.241204696316874, 7.6178611382361385, 6.942029403102014, 9.054158080008722, 9.79737368322188, 12.042521699782341, 17.03584601802211, 14.237401600806946, 14.851023074119324, 25.75317252066828, 26.89270538668479, 34.70163645282869, 50.3650765265188, 52.49612377535913, 58.972812006550456, 70.05750071617865, 67.35411690127465, 68.85501184771138, 78.69747023428641, 54.23318070750083, 44.34162209110875, 37.446103172917525, 40.76059226066836, 47.143163219574966, 71.82734474059075, 48.48959915099606, 49.77657195060484, 97.40211609871157, 94.79031962733116, 68.34646086538991, 25.98186435238008, 0.836879903030011, 0.6387558375154773, 0.1279437696681388, 0.29184383009710624, 0.16824654453704435, 0.21821466004175527, 0.22114965013198315, 0.12702023535366022, 0.18353836430657297, 0.13966797160044794, 0.18294798630860545, 0.0836001031641518, 0.11708003003150226, 0.17176936921333114, 0.08807321394523306, 0.10568536081982237, 0.10210279660720019, 0.12202050041167006, 0.08398506234610274, 0.1423688605427742, 0.15362646130304183, 0.08703802997666983, 0.0944608627187629, 0.2423415420156333, 0.148856905138781, 0.13865362522342514, 0.23439872709493484, 0.18989176128900823, 0.11914679735538461, 0.18577114288364688, 0.16791248423678262, 0.1315970514570513, 0.13791718490181432, 0.12691378743658144, 0.11787879926663254, 0.18867274686213464, 0.09808561539337521, 0.11112931184470655, 0.12492149151981839, 0.11675263469618176, 0.17437653495900093, 0.08656578273662636, 0.17277251538490096, 0.13822898268699646, 0.1254101253805622, 0.12540228830109681, 0.1629226011854987, 0.1375957803740617, 0.28561614814304537, 0.1108723889375406, 0.13777329826787596, 0.224620763873381, 0.16970626378972686], [0.038479443474282185, 0.0679819835650344, 0.06423138562710055, 0.046700620272707556, 0.018627759211906986, 0.0340743383182393, 0.054828870605917714, 0.07237720618685407, 0.018971441576497692, 0.05433185957372189, 0.02048753149386856, 0.10702786095921071, 0.018342895162922722, 0.032107193068030386, 0.07103007887640307, 0.05697096352495494, 0.1286935016152359, 0.03209153231563828, 0.018736530290616137, 0.013519335545659547, 0.04819182956951761, 0.05194413205308299, 0.019368820958921028, 0.047588588955301436, 0.010019624699658204, 0.037041822027775555, 0.018966134502402237, 0.010628946136773355, 0.03752563719547564, 0.022445931850421815, 0.020177070532114278, 0.037233075878072175, 0.058392585225162975, 0.010387436918643935, 0.036538624835591164, 0.0318390603793124, 0.039315636104513565, 0.03074101889656196, 0.029132241916452205, 0.07840033500425278, 0.08439339487062347, 0.04125543584626529, 0.02092534308171561, 0.04068858057801281, 0.042901199551359306, 0.0384183096579246, 0.12634266888903034, 0.01083971607694102, 0.040014790926849654, 0.0231494169847499, 0.09414298219546195, 0.03925632940785539, 0.03617944451229226, 0.0930384059827174, 0.11510692461724244, 0.08429410987563672, 0.027889622405411738, 0.042402775086943185, 0.05525780706516197, 0.05433136927745035, 0.8569488325907338, 0.2263606414799729, 7.382208570357292, 34.9363197049787, 54.94250212946246, 66.76531422522761, 68.86956384105068, 74.81113095437327, 73.26126913870536, 68.31885522411716, 62.532096216755534, 52.95645313878214, 55.43690904494255, 47.38908013989849, 38.798512874111054, 33.62808373666579, 28.76013013624376, 42.290167577805065, 28.681663120946578, 34.71149729144189, 33.69509350868964, 18.530706397948727, 26.156096035434356, 55.491194648127404, 33.223008801860196, 30.35196327394055, 33.88822317123413, 39.337897608357096, 35.99481836442025, 44.36953367725496, 36.4797096098623, 33.40665025095786, 39.15474645553097, 47.96242475509644, 66.8980158528974, 57.84621315617716, 57.48568457941855, 50.37570614968577, 37.26622327681511, 56.34438860800959, 74.45599955897178, 49.167478853656405, 57.970160053622344, 65.71007897776943, 30.95088762621726, 39.63182433958977, 38.15846835413287, 45.93894066349153, 26.997509156503988, 31.151373694019934, 40.13939472936815, 42.856357789808705, 38.986206131596724, 59.09710015020063, 61.010589215063284, 65.30893818024667, 83.15795037054247, 88.28499809388192, 80.12519728752875, 47.79903842556862, 15.010660598354956, 1.142326819319879, 0.22720830244643075, 0.20861640572547915, 0.06350354081200016, 0.06722180983952938, 0.050480023116594365, 0.011790936809003115, 0.03309188801194391, 0.05041539976974169, 0.042561550639689937, 0.03367329895075771, 0.030381248685561364, 0.04108964292813213, 0.02836795238357398, 0.048034291248768575, 0.04871786767316442, 0.03573288420034993, 0.18877377853758875, 0.07598579440626406, 0.06008732876169586, 0.062097183413683414, 0.049802927796037934, 0.03431369099886187, 0.037517528154797135, 0.07099118459248735, 0.02448993678685398, 0.01999178259152799, 0.005369877504680547, 0.04012815661788468, 0.029498380233323383, 0.04692517596507265, 0.020478775108894034, 0.056606179268489924, 0.07381819458978792, 0.05577883495378399, 0.07018126111717955, 0.04627598156671851, 0.033309043294960455, 0.02066029581211267, 0.043021452372833606, 0.013036908912322214, 0.03545514668428129, 0.06537253487735026, 0.06240574064694586, 0.06177575590329305, 0.0721578598923741, 0.07508114415911898, 0.059602824114863916, 0.04415086132564372, 0.04040985097808223, 0.07991256958414471, 0.019357971238693403, 0.01600654054087617, 0.12037685877012631, 0.06609318612684166, 0.09532115647509214, 0.035534498071478265, 0.04042427258325681, 0.02672528175847425, 0.055795102830856085, 0.04441585879953158, 0.056767019428192615, 0.01223051614473544, 0.003586117902980937, 0.014695842626444517, 0.01599086638194539, 0.027239188859840075, 0.03276639640511524, 0.017438091698192784, 0.02886227636237539, 0.04719758917006755, 0.13299761340022087, 0.022217936423276703, 0.022568329718084108, 0.015171576524153354, 0.03845462605597512, 0.08464604300717193, 0.015363915346472736, 0.03880938605195092, 0.047565131343059966, 0.016180943329668334, 0.009757526868563748, 0.0344260186407595, 0.07775011021764049, 0.07321736715253323, 0.026502179717945478, 0.05000185401689622, 0.014716118100970505, 0.025819070607183442, 0.01497649223423533, 0.10821819305419923, 0.03854031682074551, 0.08978664619667877, 0.045185853772225885, 0.094622315748805, 0.08054332807660103, 0.025893001922316132, 0.03194928127941826, 0.019678527324069894, 0.07790705098980859, 0.02163796764498036, 0.02281793840079298, 0.022194833126700213, 0.05515322457217882, 0.056692153485792304, 0.05186417928686546, 0.02609918874147679, 0.04140748131659724, 0.08630190375110797, 0.012244211881601763, 0.08711640843220296, 0.07467399141000164, 0.12945042712794197, 0.1013082485165327, 0.09318706534442403, 0.62209440575492, 1.2833366398849797, 19.14823062958256, 55.32547450834706, 75.33425746425506, 80.64442496145926, 76.23040922226446, 62.42856917842742, 56.252542388054636, 55.4057889599954, 44.044988924457186, 23.905159581092096, 14.522217646721872, 12.817484967170223, 21.7368870781314, 34.845599205263206, 38.47060665007561, 45.68102913518106, 41.60352922254994, 50.79095963508853, 43.18185567855836, 40.655453128199426, 56.81456312056511, 58.85098318899832, 60.29310141840289, 62.24362942480273, 73.6358476454212, 71.09687389866, 63.93645378851122, 67.49409060324392, 65.51533722108411, 59.271559330724905, 58.403919281498084, 65.28288971993231, 64.78628235478556, 72.39001658654982, 72.69784419767319, 71.135524934338, 68.36560203183082, 62.695843404339215, 67.92345677652668, 77.70206682143673, 71.97238614482265, 76.37351297563123, 66.16361479605398, 66.21771997021091, 61.80255889892579, 61.84711310171313, 38.88776640738211, 36.68696764976748, 44.33427941414618, 24.477553021523264, 18.228326958994714, 23.738745181791245, 35.81378529148717, 51.272736518613755, 71.44216798966931, 78.16746388712238, 88.25159518949448, 64.24912552679739, 23.77300120169117, 4.065495498718755, 0.2976331258973768, 0.13737160772565873, 0.0516184565851525, 0.040610707740509705, 0.03587376010874587, 0.050427779750598055, 0.0707887765020132, 0.1082752972480751, 0.05107385234066075, 0.01097098715798629, 0.02644044835300696, 0.04276554836260696, 0.01955978944146585, 0.05375654669478536, 0.0183533790761665, 0.021223401079975793, 0.0700140011406714, 0.02913292564992463, 0.028706500043852196, 0.0780998983029877, 0.055425143650462555, 0.04453313919985968, 0.04179037206115262, 0.026698173737273585, 0.04264849395821652, 0.02371096709412673, 0.010626824073223098, 0.025621042624416373, 0.04725311522281939, 0.06770001724362373, 0.05879887229492588, 0.027417685430977615, 0.021966487214329745, 0.04450352607114662, 0.039681048553076484, 0.032138468607539133, 0.024498195214677724, 0.008585784854667803, 0.014255100752287095, 0.07545412172593417, 0.024045527266759067, 0.0964364349361389, 0.0040762437199572885, 0.031257923316931537, 0.060512702912092216, 0.027821802556695, 0.02869498191191064, 0.05199530672642493, 0.05729545538704242, 0.04613173104101612, 0.05064550193867857, 0.03816859180768652, 0.04655214477210276, 0.02491826612141825, 0.2005602251137457, 0.16470629902135941, 0.18007547834948187, 0.16446157989482726, 0.09369144997289104, 0.1985492902777849, 0.13864711347606876, 0.10713188037756952, 0.09141359478235246, 0.11905375597698074, 0.1016562822605333, 0.2476343209104192, 0.13686658724421455, 0.09246844422793196, 0.20707252405343518, 0.1544922479097882, 0.26004021086039086, 0.12601133586177904, 0.2410372773245458, 0.16878403182471954, 0.09390086776787236, 0.29219203238045016, 0.1029254294811718, 0.16107185533450497, 0.09086658502177847, 0.13532727145619933, 0.12584655801014555, 0.15640866281765123, 0.14534491294574353, 0.20508262599187516, 0.09420784686001078, 0.10708954635887377, 0.18999994822567512, 0.06842374816657075, 0.14848956597908852, 0.19563215003619272, 0.10669193140441373, 0.1428041210578334, 0.0870560100602527, 0.17016919540061107, 0.22281984438098248, 0.09961493373397859, 0.10498242152314033, 0.19814778359666949, 0.27437708671054534, 0.08037937759992578, 0.19360118966189124, 0.15927239140916258, 0.15072445895883346, 0.13311369104250786, 0.18963360498028417, 0.1250123572085173, 0.16831818907972307, 0.23734977438805566, 0.24061410567693173, 0.2877042586764982, 0.17425440522211214, 0.30019345302735606, 0.12835410934302116, 0.13803223598628275, 0.9552045118424201, 0.6248270107373115, 15.87296622414743, 61.147260281347464, 90.07151219152635, 94.26650278029904, 92.06670422707835, 91.77963379890689, 91.49947458697905, 87.01633884060769, 78.89073325741676, 66.14481879818824, 73.85546899610951, 63.420328709387014, 56.434528596939586, 49.73605778909499, 41.75696057658042, 56.1661914087111, 40.69502199849775, 44.429334132902085, 41.60235643386841, 27.29897076083768, 36.53167316990514, 67.16219532874324, 43.49620226890811, 42.2869747684848, 51.919233337525405, 57.923166136587824, 55.47446573934248, 65.33814414854973, 56.72504678849251, 53.393173756137976, 59.60998142919233, 67.95288239755939, 86.3996010441934, 77.26334187292284, 79.48779644504671, 71.25398835828229, 53.834954231016106, 74.36872682263775, 96.79839272652903, 67.81636038134175, 76.27597147418608, 82.44564010250954, 45.83471936564292, 58.18094822668261, 56.94656264397406, 60.92880387460033, 40.10215182458201, 44.841022183818204, 55.397238193019746, 58.30266721786992, 57.52788928247268, 79.69137530173026, 82.92845249176025, 84.8695001294536, 105.58410183075937, 112.17185589575, 108.14003590614566, 70.122313960906, 28.919388171165224, 4.763791138126004, 0.6105873361229897, 0.2933872827599126, 0.2695155233865784, 0.1918801271747197, 0.2881784364581108, 0.09885125132578035, 0.12492270193873875, 0.2221064633058925, 0.17732672423364657, 0.160035323051195, 0.12767925482964324, 0.07938965328878934, 0.10281986256520595, 0.16026387772252484, 0.09492734897761576, 0.17038011472792397, 0.25501338704939813, 0.1567323962526937, 0.08737352286134997, 0.11558595939629501, 0.15316956646500096, 0.13961981531352768, 0.17159195857182627, 0.23633547397630833, 0.15519188536751657, 0.106951956967673, 0.10672045285783469, 0.1428147543582224, 0.11689321949116646, 0.10912318038003099, 0.09885808483006493, 0.21835450173145343, 0.12855744439988367, 0.2397311893441985, 0.31455662101507187, 0.1636458954383289, 0.16139054791100566, 0.10372884887000246, 0.12033621780574323, 0.2119838371272049, 0.16302349496512644, 0.15629091510368934, 0.15491335112000668, 0.16143715670031888, 0.22556158113143138, 0.1672750684402643, 0.20448375973970662, 0.10696835891013184, 0.12011871012228152, 0.22822468661733214, 0.16577183539348264, 0.1170923870297209, 0.15635797844058083, 0.1533219719966573], [0.06082490289343461, 0.023674773270144098, 0.05726011575109536, 0.048480587260377024, 0.006689003822694143, 0.05729264767479993, 0.04073382956126044, 0.020709777431141947, 0.08278576702240013, 0.029150206678276582, 0.04285870465419946, 0.020505387088163726, 0.12106505853514518, 0.024973305708338178, 0.050620335950365955, 0.06120765574216362, 0.03951989046688523, 0.030462080537672007, 0.01541108816802021, 0.023785298690199855, 0.047391788628433025, 0.0174404397576807, 0.007956913332529968, 0.02736262860707939, 0.029431901038474137, 0.03960656565463832, 0.03539063058973801, 0.03554175675456082, 0.05511068754018315, 0.07361348057466169, 0.08627829292128164, 0.00852246194206659, 0.03724401944407052, 0.008031270305265584, 0.026492477214384465, 0.029619577258164366, 0.024949319495428956, 0.04762991556837674, 0.02931154096469043, 0.0371631205592665, 0.09858350359624433, 0.010728492559264264, 0.05095658343165152, 0.07683795230883746, 0.030574454144845088, 0.01457228413557694, 0.04647196217950794, 0.0609212767543091, 0.015639655288278816, 0.015829575187977285, 0.03462517851843469, 0.08031650476398007, 0.03977764074900939, 0.06945280343173973, 0.011099130685080685, 0.05291131039660785, 0.07446659608714043, 0.06818480534298767, 0.11173592324578956, 0.020254623527909, 0.17112751010685198, 0.04754410222953847, 0.40451535354218177, 0.1461376147645135, 2.4594491624063064, 16.373578329240125, 38.836661846407004, 45.58728841043288, 53.7485836398217, 60.82411189233104, 67.69125246232556, 77.05555823541458, 77.49027452161236, 82.9666171535369, 76.5108508448447, 70.84572453652659, 74.31519431452598, 60.92701919617192, 63.42012082376788, 52.80954468634821, 62.49826185164913, 80.18742961268272, 34.69079894404258, 86.80911217966388, 44.03311198757541, 47.38523229475945, 51.33307041660432, 19.346076942259266, 27.871819196208833, 25.178792399744836, 27.95304167655207, 32.66274136881675, 26.643111244324718, 34.409757198825965, 38.3991842116079, 30.241554437145112, 39.15413848815426, 28.907762265974476, 29.080328902890606, 51.583317633598085, 89.9775557364187, 32.0966786338437, 58.92231149058188, 46.595823918619466, 48.789719304730816, 41.75268127072243, 52.66027104470038, 56.84898976356753, 68.10315624360116, 73.3439213229764, 71.00468251012987, 79.0195046701739, 81.0338378721668, 76.34246349334717, 74.30119929775115, 58.09382061804495, 49.256995185729004, 30.421053863340813, 8.993870269867683, 0.9078325150955109, 0.3163325353976219, 0.32327105501486414, 0.06379414094431747, 0.07002749960989722, 0.0286922182497238, 0.09035142919709606, 0.06188369769182417, 0.04229320919201259, 0.052905859681026596, 0.051776335815027844, 0.03335450678282688, 0.04056091968631072, 0.024491560893253456, 0.05606142946729257, 0.013009697469251772, 0.0463568574688848, 0.042530995222830006, 0.01794681429953104, 0.08876019563045233, 0.070723268323608, 0.06769667710027388, 0.037039768912138483, 0.039040989753219395, 0.009005220866041079, 0.02352096962802593, 0.10021818200907401, 0.0131779006915167, 0.06499623248894369, 0.09031720038863922, 0.0116426557032091, 0.09067779031371878, 0.049630519708678614, 0.03505868086170766, 0.057189080248316454, 0.016424959570529963, 0.06481466965088922, 0.0645125781997077, 0.02397831454272232, 0.04797611070135909, 0.046683260720343366, 0.029200027291212353, 0.021884665193576968, 0.02197095733736792, 0.016562570029148654, 0.024863741728627396, 0.01620199542582756, 0.03609717049966416, 0.03398652548991865, 0.036816825834853996, 0.03658025788383619, 0.01331276951297637, 0.08973730247347586, 0.07058446851348685, 0.06970326055682476, 0.09991199964837683, 0.13489096906156312, 0.037226449217527144, 0.028005617693246856, 0.0193146413056961, 0.03155974089168012, 0.05326070777711369, 0.055862464942038066, 0.04195183275207397, 0.01535878830303949, 0.023462308360443964, 0.024230219573984225, 0.04123709187091839, 0.056864856517002474, 0.06961816351019567, 0.028643709562358358, 0.044782642545478965, 0.018959599772408124, 0.07868436976305901, 0.076698700506841, 0.019542177080086643, 0.017822166048591177, 0.022520795877602313, 0.04133238554781964, 0.026947684743772113, 0.039019573765296134, 0.02971966664547161, 0.06123413174082676, 0.051520830170521816, 0.00645815902727566, 0.07665742368948075, 0.06201821124000896, 0.04779069061060587, 0.014887694025322076, 0.06453693213482058, 0.09347039530233991, 0.03784319596184838, 0.04584976855004507, 0.04671649744493827, 0.022535466461352283, 0.04219369054020893, 0.09071262433163582, 0.026272550608301838, 0.0022744839248668046, 0.011921931140785737, 0.056927472713493535, 0.013520972100987792, 0.03615175809470877, 0.03714621682921725, 0.03393456557645433, 0.01174689632945604, 0.07220668267578849, 0.07987577438114152, 0.07367439222552123, 0.09764211177225075, 0.060262180669533635, 0.09034252725541593, 0.11705581399221575, 0.08244145646571152, 0.07701116478851727, 0.12664348863425756, 0.02696873109427191, 0.11498997363472178, 0.21296553283689484, 0.3912623695308163, 0.2849034105818118, 10.413276995382002, 31.504943986092847, 53.60781369670745, 65.24767860289543, 72.90885986820345, 72.08826864919355, 76.70802839340703, 76.83665075609761, 76.41053230531755, 69.78594718440887, 63.79460519359958, 56.32165847286102, 38.87759177915512, 48.051152690764404, 37.81268788922218, 34.02785170462824, 36.43302163770122, 28.422998497563025, 19.131619391902802, 82.05848647702126, 29.584696677423295, 31.337664704169, 33.485407521647794, 27.519356973709602, 35.9061021958628, 39.50016606238581, 35.31452640410393, 37.14316283502887, 37.90512246470298, 46.206583592199514, 61.51773206649288, 48.15555049527077, 51.86881126896028, 37.99122633472566, 27.613793919163367, 58.57453846162366, 96.9641834689725, 32.706646419340565, 53.301307924332164, 50.14263106930641, 24.120431023259318, 27.675137827473304, 36.02164737639889, 42.13411608049947, 36.90325106343916, 43.7214090747218, 60.154033783943426, 63.14954788454118, 75.04090339906755, 83.03089695592081, 84.22820045102029, 79.32496316971319, 67.25310802459717, 48.730228716327304, 18.52978660214332, 2.3096013838245026, 0.2645587812988989, 0.48205975383039446, 0.15191961740774496, 0.03608262248998208, 0.07998620595542655, 0.10377979371696712, 0.030558912136081248, 0.005750065395278075, 0.06790126854133222, 0.06547787196693883, 0.028445371313981956, 0.014523185560509804, 0.029975235492231387, 0.023308566005359736, 0.030155093784654335, 0.04973177738007038, 0.06824087531816575, 0.036083878874177897, 0.01813726758794679, 0.047286635399946285, 0.10929831574040075, 0.03734038947450538, 0.05138389195405668, 0.027281323695675503, 0.025502321978790626, 0.07777133085314306, 0.029177925654596863, 0.07191676436172378, 0.010838700052831444, 0.017738246862145684, 0.07307522719906223, 0.032171720653892524, 0.07212593700856933, 0.10063039859937084, 0.010493677034373245, 0.027054360572008357, 0.022584306481744976, 0.07410660371064179, 0.0156878134904189, 0.10796310875805155, 0.03667446754632458, 0.02122580276561841, 0.09364030594306608, 0.03249290684658674, 0.05123256277593394, 0.04416201939626087, 0.06148642364649042, 0.044945493685982885, 0.0538732793422476, 0.012401804786115404, 0.019749549420310125, 0.11135764435053834, 0.0550498103632802, 0.03893986231677475, 0.04785462064788707, 0.07603651708773068, 0.14998964274362211, 0.08177888234175983, 0.1678227446973324, 0.19205755313798306, 0.08733568577876977, 0.15050803912022423, 0.09722555912430249, 0.06451503734194464, 0.09760408316768947, 0.22115446116414764, 0.15880303998147288, 0.13842117882543994, 0.20683335140347484, 0.10364102455036295, 0.11056780770060518, 0.14597342680058173, 0.16640909797241613, 0.0973712460648629, 0.09486496643794161, 0.06807955252307077, 0.12726804181452722, 0.13733661282927762, 0.11518913351239697, 0.11225504740591973, 0.14414708851085556, 0.11406787190466158, 0.20328221211750663, 0.08140185216982519, 0.2138478975863226, 0.10216767659350749, 0.1835265052655051, 0.15277627224643386, 0.10821136721079389, 0.17813261808647265, 0.12709197948776907, 0.10567947726456389, 0.07163547985856572, 0.1516314457741476, 0.26102589022728706, 0.1327148963126444, 0.16233102809036934, 0.17506581490799306, 0.10389146635368948, 0.2425067718591421, 0.13262101989840308, 0.11478998638208836, 0.14226770629325222, 0.1522404703521921, 0.06506803024920725, 0.13123205652640713, 0.16994595737947574, 0.22685464561706592, 0.1360966688803127, 0.15778429625976473, 0.17915548336121345, 0.31378569141511, 0.27920653562872644, 0.19705679778370166, 0.22953468164609325, 0.1577790868618796, 0.43988983116803637, 0.15566440839921275, 0.6223015559296454, 0.17865711252295202, 7.0561865548933715, 28.50123017064987, 57.136581866971916, 70.30769301999, 82.53250491234564, 84.7123150671682, 92.17962926433933, 95.32115751697172, 99.09832939024895, 99.70002881942257, 93.92093412337765, 85.24620456080284, 86.64497667743315, 73.63024650081512, 81.62824953756025, 69.27637638584261, 83.03821609866235, 104.55523275559949, 49.96350426827708, 97.86313579928492, 59.878785379471324, 61.33299627611714, 64.86334123919087, 32.18011921451938, 41.17265293675084, 38.973740839189105, 40.06280260701334, 46.68585015881447, 42.874004533213956, 47.52004807995212, 56.21467190404093, 47.475662539082194, 53.39508002804172, 43.23207378387452, 42.02122242219987, 63.93441415602162, 105.89655783868606, 49.01436521160988, 74.15146673879316, 61.21994572301065, 66.17993185597082, 59.31988685361801, 68.94119416513752, 73.65443183529761, 83.95812957517563, 92.32136803288614, 90.45373932007821, 101.80936182698896, 109.12378987958355, 100.09399952427034, 96.94700348761775, 88.3361065772272, 73.87389629117905, 45.53957669965683, 16.833090859074748, 3.0010382686891868, 0.8780636253856844, 0.7355880641168164, 0.35978620691645535, 0.15169460206262528, 0.18088106576713825, 0.1335725317438764, 0.17045094721740292, 0.1585009561911706, 0.1942313429448874, 0.2792257491138674, 0.13218908420493528, 0.09537764779862859, 0.07334305919826993, 0.10612686495146445, 0.1260266499593854, 0.15471571575730078, 0.18187227628884778, 0.1286255802598692, 0.11117048140975738, 0.15453188529899045, 0.23012372665107253, 0.12239240545539126, 0.13627001925581886, 0.12391290612398617, 0.11748636306654062, 0.20408776889164604, 0.09902220384608354, 0.21880994100243817, 0.14623746666456425, 0.11383831365815095, 0.22121322010793995, 0.20056102184518693, 0.2491850820520232, 0.18328786887709173, 0.11515623003604913, 0.16935288275201477, 0.13794779777526855, 0.2571978714437254, 0.13960717486277704, 0.16894540058508997, 0.15202959699015464, 0.14744217056901227, 0.19045641405447838, 0.08516169678900512, 0.09263853872975997, 0.33630935054632927, 0.10258496468586308, 0.13934463653112614, 0.11896960121849853, 0.14278408019773423, 0.17695518691212903, 0.26400664641011146, 0.13944862530596797, 0.11983312786586824, 0.2859228897479273, 0.24412366171037], [0.08867051737803607, 0.04038000802299188, 0.04159331892526919, 0.06001953764127628, 0.05396918205904865, 0.020170888202565334, 0.040362644640188065, 0.04528575546799168, 0.036986786271295244, 0.06927950668238825, 0.030879050703539006, 0.03558225982311753, 0.008642346083727336, 0.020327206528294953, 0.036882395300293164, 0.009870470253630512, 0.03041958181007255, 0.07416612874235838, 0.022149748852356307, 0.04582756732199942, 0.020584903184264418, 0.05988265688140547, 0.05555434437889246, 0.031574078227183035, 0.026618088820889115, 0.03383610029554656, 0.04433220199820015, 0.02723652095864377, 0.030983964529549404, 0.010671197801017234, 0.04755509942169151, 0.10304927525501098, 0.08445415330389816, 0.040063330257732066, 0.044226853417292725, 0.022417408481781042, 0.03165993753129677, 0.05013279759535386, 0.05710289918727452, 0.07494628204092865, 0.05521219419015031, 0.0038091847513456864, 0.07095523208620087, 0.05761910072197357, 0.07341039832681417, 0.05068151956243862, 0.02411133613467457, 0.041866804653358076, 0.09273035436748497, 0.08270179612501975, 0.07178426179434023, 0.0497495697721118, 0.06109158193031627, 0.11069774387344239, 0.019292281114406163, 0.06115860696281157, 0.03331825167181031, 0.017645906454192537, 0.12021048745561032, 0.029025140909417987, 0.12417996437439036, 0.10115379753011851, 0.1496452402563826, 0.11699376087034903, 0.06322023766716162, 0.7381336823586495, 0.19830048024173708, 0.8014504815782271, 3.933525638234231, 17.044294803373276, 24.29926168534064, 34.7626724550801, 41.81864376991026, 46.373880524789136, 61.15647000651206, 68.79678034013318, 76.98657943356422, 71.29835820967152, 76.69353131325015, 79.1891550248669, 74.62775230407715, 72.0283583671816, 80.45464500304192, 54.41106411718554, 69.33463927238219, 67.21307631461852, 87.1392894560291, 87.34248392043575, 86.26736225620394, 77.39692211151123, 89.34902729526644, 86.59958700979911, 80.69652188208796, 82.39197423381191, 69.96359132951306, 74.74781605505174, 81.30916472404235, 73.4418236824774, 84.24628257751465, 64.11618071217691, 57.95535702859202, 83.72323451503631, 71.23996980728643, 80.03332753335276, 97.71071249438872, 82.81556667820101, 79.27034808743385, 76.5785195750575, 67.59422086900281, 61.06216838282924, 39.84141618974748, 38.67001210489581, 23.83203091159944, 21.161365547487815, 15.413231099805525, 2.9435054332979265, 0.5260401567624462, 0.013038246693359989, 0.15624121131916202, 0.18904109725788718, 0.022138154111622323, 0.16086150291225604, 0.08972698326913581, 0.04228282487019897, 0.040231226087217374, 0.013420578193730645, 0.09080301504582168, 0.030586433844761025, 0.05336877597015231, 0.04143954975710761, 0.034274206827244455, 0.06639666419716612, 0.023160362465968056, 0.010710240514468282, 0.06715283128282717, 0.01822754530416381, 0.07140124081483773, 0.03097487681154763, 0.02299799396085643, 0.057176255936464, 0.026449968910685955, 0.023666080087423328, 0.013901580861138721, 0.030665243224751566, 0.006687197291607699, 0.018923727705353693, 0.02661160005617046, 0.036879480335741274, 0.05677483735545989, 0.03515157285296629, 0.03420517464438754, 0.09309795399707171, 0.02078258068180613, 0.08975788725600128, 0.029344490406313734, 0.02666413070513837, 0.020201478093381853, 0.019607302214529727, 0.05319560562530833, 0.008997742890290195, 0.0285977213042638, 0.02239817584444198, 0.04967768008129732, 0.0280994787857297, 0.05427148801484897, 0.007762391638431339, 0.03692942926840436, 0.025198029940046614, 0.03341252645177226, 0.05212207512569524, 0.02123571785857841, 0.010033476526939101, 0.05933248700814382, 0.013096997018663153, 0.01944552934277923, 0.03060194521000789, 0.0762926126199384, 0.0222054970706062, 0.061830941046918594, 0.012443700219474494, 0.05267865332444349, 0.03476941372237859, 0.013690447986816928, 0.0366170032911243, 0.03875686689430187, 0.008820975762641719, 0.010639444414165714, 0.074146302386878, 0.032228120046878056, 0.05869607095636668, 0.04467041066457187, 0.013822825107302879, 0.09135302787105884, 0.010307551185119777, 0.038030542763731176, 0.04549758643993447, 0.030395727747330265, 0.018648654260041735, 0.02378768888452361, 0.04201085599620016, 0.029797683124460524, 0.02132855813890215, 0.02443180795037939, 0.010746912185793683, 0.05355543329290325, 0.026307964937821515, 0.0406601204116258, 0.0452282375866367, 0.0048431417822176895, 0.020300391535725326, 0.05603911332605828, 0.027709995854585886, 0.002875856720962592, 0.030611814337692438, 0.05495634380607836, 0.024489860178061554, 0.04167280054741329, 0.02621901829937293, 0.025626671455440023, 0.010036095590030235, 0.06389795351893672, 0.016804192245246905, 0.08431901539405508, 0.08937586985167958, 0.03470012490006705, 0.05424740604094921, 0.06454673806025137, 0.030705288555773518, 0.09578267848419567, 0.14641965769471663, 0.061432563834973884, 0.11236925579367146, 0.03791841047425424, 0.03204286658024836, 0.07550788577646017, 0.031048511267609658, 0.1393968377622866, 0.04845468582765711, 0.1233447446758228, 0.2005258277659455, 0.13676034617087535, 0.18806959051759015, 0.7087915955531983, 3.427000805254906, 10.363986530611593, 30.699820633857485, 40.703874787976666, 53.10389111118933, 59.84615518200783, 69.38122918528896, 78.96625457271453, 84.24267399695613, 86.89061118710427, 77.62458432105281, 78.42417517016011, 75.73612782262987, 68.40160939001268, 70.42683109160393, 53.31178849743259, 62.45898323674356, 46.45039419974051, 50.743612704738496, 63.468801359976496, 40.580935939665764, 45.75905684501895, 37.691137559952274, 42.596167364428126, 46.50061622742684, 42.3081987134872, 47.41952949954618, 46.46917843049573, 39.118668494686005, 51.4005861743804, 44.53333577802105, 44.14366006851197, 60.674740191428896, 69.13669293926608, 66.4354193595148, 76.29964690054618, 75.60954509242889, 88.94823951105919, 80.75051722988006, 84.72085798940351, 85.74358463287355, 84.39808614792364, 79.67710571904337, 66.45107746124268, 61.06846378695581, 47.01969877366097, 37.99434069664248, 28.242261563577962, 9.672033363772977, 2.8348462187474777, 0.04210878118512131, 0.21370379644776547, 0.23225749602481244, 0.05202261010004629, 0.05947608635911058, 0.1145080047389192, 0.12972091745224693, 0.03147831915186779, 0.021203586215814276, 0.01100013297306554, 0.06119177856993291, 0.029833608817669655, 0.04452740503174644, 0.09337701684524936, 0.037595079235372045, 0.009285993047899777, 0.03543172737643604, 0.01944241519536703, 0.08574236079209274, 0.07079131991392182, 0.060184560641045534, 0.1530313182381853, 0.0622661670880212, 0.11114189866930248, 0.06534438114613295, 0.026372622758630785, 0.0825699906976473, 0.05336858061773162, 0.0496593322755108, 0.01684831890968546, 0.01668421713064515, 0.028404404762231057, 0.00799137148855915, 0.020151510008520657, 0.08172298090592509, 0.05259976542044071, 0.019170180105814533, 0.059238239041259216, 0.02212991483599669, 0.010023390979415948, 0.034475461955392556, 0.022797658138217467, 0.049942589455073884, 0.06639107941619812, 0.04118303670698116, 0.09171701922652223, 0.041396943777198755, 0.024285603900470083, 0.023527699710440733, 0.001976576391063, 0.0396842546310396, 0.02891117575458221, 0.029589994772968274, 0.03506499725664335, 0.01786393890788238, 0.07017798992174287, 0.046113927157655846, 0.020845240928352844, 0.021598523692978967, 0.2156874125883464, 0.07612832506457645, 0.16338263698402913, 0.11948769115993094, 0.17405030407732533, 0.21169183505398614, 0.14973096549510956, 0.07348191263454576, 0.16680452191541273, 0.15024297269842318, 0.1658561050651535, 0.21343730510242526, 0.10577345327023538, 0.11827999951257823, 0.11464989954425443, 0.10418102460642976, 0.14095522913961642, 0.12404197661746895, 0.141048829762205, 0.11721588040311491, 0.1601784435972091, 0.09842827886102662, 0.10892411243290671, 0.1602702209305379, 0.08708876031901568, 0.1775554780878367, 0.1647305073997667, 0.11937882240501144, 0.10308761795562121, 0.10499827954317294, 0.1342273377362759, 0.3283693395074337, 0.15344079223371324, 0.17887390008376491, 0.16218113532710463, 0.13313362465029763, 0.10720789162141663, 0.11462189903062199, 0.21640591113077057, 0.13759115320299903, 0.12668046769836258, 0.12933111659461452, 0.1992441167033488, 0.1655547107539831, 0.23011583594545243, 0.13685026957142737, 0.155018933357731, 0.27939284821191146, 0.17760315940024393, 0.17616009489903528, 0.1699241545171507, 0.13523635214134572, 0.12284502552281465, 0.29319539305663883, 0.17186393510670434, 0.2155662634440007, 0.12311701737945119, 0.1610918349075702, 0.13744113786566642, 0.2281901207301886, 0.3387418329235046, 0.22714485504454185, 0.27182708644578535, 0.20954599213455954, 0.2541438925770983, 1.0026563043075225, 0.3359355915698313, 2.314451394542571, 7.623291169443439, 26.946281040868453, 37.96177717947191, 52.49099331517374, 63.00846807418331, 74.85645786408456, 87.93982951871811, 97.17266528837143, 102.1360089701991, 100.13498829257105, 97.37090972162063, 97.89741731459095, 90.2522942327684, 88.9794929565922, 97.86493224482383, 67.1572845212875, 82.55414070621615, 87.59621420214253, 106.86995675486904, 109.50442452584545, 102.79845806860156, 94.58431674588113, 109.98026294092979, 103.69572377973988, 98.92976945446384, 101.54331530294111, 83.44347538486605, 92.78365858139531, 99.18360956253545, 90.21776168577134, 105.99329133187572, 85.92612389595278, 75.09647553966892, 104.6430467790173, 95.60538814913843, 99.9952656222928, 121.25420601137223, 105.72022376521942, 107.52831874355194, 103.44297409057619, 92.56599841579315, 90.42829098240023, 73.63985630773729, 66.65835119062855, 49.49491831564134, 36.79403658836119, 25.090162523331184, 7.174101337309807, 1.5147786659579126, 0.18563531549467197, 0.2824417555764798, 0.40285603774170725, 0.23112811388507967, 0.26228717738582247, 0.32105421106661525, 0.274937495348915, 0.2173727447347295, 0.1683353954145024, 0.1864900091482747, 0.13427733263421443, 0.10624602992808628, 0.1119618502355391, 0.13864404912437164, 0.25410325927359445, 0.11308370173097619, 0.23517028488699468, 0.1773228325069912, 0.13206719961618224, 0.20399141035253004, 0.20147081254230392, 0.22155071248210248, 0.23567918177333572, 0.19856666515190757, 0.22706843011321562, 0.09774256888176165, 0.23518939111982626, 0.12954588168330733, 0.14817015327993902, 0.0925628952081165, 0.09611124593404033, 0.14296464712148713, 0.08211986041597782, 0.07266473430659502, 0.17917635159627085, 0.10326358069094921, 0.1506506387264498, 0.11389903378702941, 0.09815852398112898, 0.19050328331368585, 0.0533924519174522, 0.1820579453581764, 0.1390219602974192, 0.19132342640190356, 0.1300126743773299, 0.16582674857589508, 0.08475463597043868, 0.09912489793233334, 0.12632264335068966, 0.1518946582631719, 0.11194735585201172, 0.15918876525134812, 0.11623934812603459, 0.17183174409212607, 0.16810823502319475, 0.18947200639353645, 0.2507379882398152, 0.12206115669781163, 0.1399875528389408], [0.0401112835313524, 0.05615118432850127, 0.01583533233872825, 0.07755170110613108, 0.055636143417007504, 0.010111773585630281, 0.029208218686342723, 0.0417756401903687, 0.037235845285918445, 0.061759009221268285, 0.049532560045800866, 0.06197001281825285, 0.020889827245545965, 0.05955932947296289, 0.06283904380735851, 0.012622964793756124, 0.01931275289896275, 0.06548527237628737, 0.03146809187807864, 0.04826392227363202, 0.04879634572012771, 0.02416371739649725, 0.01605981525274054, 0.04955698292882693, 0.013647375650884164, 0.07568869784834885, 0.042420123147988514, 0.055918511934578426, 0.03781311551950151, 0.05405593768603379, 0.00588550207941162, 0.04890262509786314, 0.04439676022757927, 0.024631684120263786, 0.06247042528083248, 0.04086213779725856, 0.03929427757318463, 0.05653983988468686, 0.076559211217588, 0.018103437145210562, 0.09500641691228075, 0.10481868555108387, 0.022018200064438487, 0.09232654176171749, 0.021022538571888884, 0.07064931785627719, 0.06404316548498408, 0.05980684482041867, 0.026753590622496222, 0.04950092827540733, 0.01862480019729945, 0.08816193458774398, 0.019587083238988154, 0.051386508144318103, 0.02508851958649053, 0.013883403509915357, 0.04137438631826832, 0.04563992940670541, 0.14395018859255698, 0.04300900727450367, 0.08024541946548609, 0.01332103081362983, 0.12142148094191668, 0.06769035687489856, 0.09985408340130122, 0.20129635900018678, 0.08070796803240815, 0.06962294389884319, 0.34190743080069946, 0.8147481744808536, 0.3880566899334231, 0.22104213735268963, 0.17298058486513554, 0.7106821779762545, 5.052639870874343, 7.74511851610676, 13.78102598651763, 30.159174857601045, 36.09031631100562, 31.978630981137677, 49.31246926707607, 65.43040613974294, 66.6001824409731, 72.01823080739668, 72.33435030906432, 78.9487058885636, 76.10153582788284, 77.12700813047348, 83.26653726639287, 88.73672962188722, 83.48771972040977, 81.82956910902455, 82.73125925371724, 84.38163572742094, 81.5120061751335, 81.11402680796962, 68.20636949231549, 72.52706420037055, 60.94683108791229, 57.842667333541385, 68.62938927065942, 54.687316648421756, 39.60071602175313, 37.978360960560465, 29.422942053887155, 27.03293992627052, 24.67556211256212, 13.360068394291787, 7.28655323866875, 4.0738592176668105, 1.0819529621831834, 0.8683875058927845, 0.13722683242972822, 0.31614720340698, 0.38306366592164964, 0.25771357119083405, 0.027021822902644356, 0.013841238030562959, 0.033466026201964386, 0.07962908640864395, 0.10487406604713011, 0.11533205487555075, 0.034407176708261815, 0.04561078359162615, 0.06017807187632688, 0.017019369106198994, 0.05902972139958894, 0.04425651251128124, 0.04310300626281289, 0.05093747719881996, 0.037495438009500504, 0.019823051726205215, 0.11557080617715275, 0.025805150789599267, 0.05068587477228815, 0.01922494390108172, 0.019690300180246274, 0.08555008804485684, 0.04877725097861502, 0.03357992049366717, 0.036321423587299166, 0.00545115512420213, 0.052594946727396986, 0.02629061879199599, 0.013794777670785064, 0.030204659673355283, 0.08667539459683242, 0.07816537583787596, 0.02093050842954507, 0.05098202521161688, 0.03960129880015889, 0.05537992148029228, 0.0360472981757935, 0.09200350546668615, 0.041451627133233894, 0.06741294111575812, 0.0338245285374503, 0.04850572643561229, 0.023599706229663665, 0.05624169378631538, 0.08181452075199735, 0.032784832311013055, 0.06447713897233048, 0.029921302902362043, 0.04671442900754271, 0.04567150372050462, 0.018073071335111896, 0.043964422337951205, 0.029936469528042985, 0.05709912237380782, 0.0531483686438972, 0.0260531411115681, 0.03660092310559365, 0.027057953524373235, 0.009195705755583702, 0.008139819218476695, 0.1120460203157798, 0.06695698090498486, 0.04738813055859459, 0.07627982661248216, 0.03434704263664542, 0.057765745272439335, 0.02710511389699194, 0.012325376024349563, 0.021558210231183518, 0.013894549131603732, 0.06627770606428385, 0.05891430259291684, 0.03528857618690499, 0.021724905217847517, 0.04783785098322457, 0.013242201323831275, 0.03742472043321018, 0.012775152947963967, 0.04178610112097475, 0.018787630270385457, 0.03478429881074736, 0.05139131917648258, 0.0588829389532968, 0.06612594404648389, 0.08232641304212232, 0.044278617978336356, 0.035584987096127965, 0.02356194575587588, 0.03076997893531957, 0.05929039047670461, 0.052456491656841776, 0.03935215551586401, 0.03276759150227712, 0.07858257199968062, 0.015219993280967879, 0.036913077121660594, 0.028721086357930498, 0.01810702626713582, 0.08758459540624773, 0.05251226668816902, 0.08918733561351415, 0.03416615395596431, 0.0438671866281619, 0.027385122863756075, 0.01840511299369316, 0.030515333224508553, 0.03532632899981353, 0.018735894437638984, 0.013463107564847076, 0.0216581808748625, 0.04812694192233105, 0.04986716426848885, 0.012046057494327187, 0.033073517223519665, 0.05281874016227742, 0.01818430921693723, 0.07939038873319665, 0.021071334542225928, 0.06494271358655346, 0.0454201847465048, 0.1970279162689563, 0.08753303002806441, 0.10337552911932431, 0.04609095601124629, 0.0429931186109541, 0.13691535640147426, 0.23400789967948393, 0.12045208094341141, 0.45090856571351334, 0.3202816267167369, 0.3426273083013873, 0.8637621734411487, 1.7091257341446418, 3.8853969304792346, 12.967421489377177, 19.398077764818748, 30.027663669278546, 48.117887896876184, 57.71939116139566, 57.98368046360632, 75.0192754499374, 84.71105206397273, 87.60838139441707, 85.38314234825873, 90.26373186419087, 86.70389852216168, 91.46866044690533, 98.7339255117601, 98.79050962386593, 101.4086603349255, 96.5353193590718, 97.79910702859202, 100.62759876251222, 102.01061864053051, 99.51653249802129, 98.2876931467364, 93.43499168272942, 96.56007735959946, 87.79270141355454, 80.24996788271012, 86.18515722213253, 82.82346633172806, 63.64593167458812, 65.21357359424715, 55.64846208018642, 49.086364238492905, 43.00065394370787, 29.589476085478264, 19.344204010501986, 14.544825207802559, 4.885781753447748, 3.714622816731853, 0.7055522693741707, 0.4101929537230923, 0.274393419705091, 0.2891800504538321, 0.076278401688943, 0.023914522401267485, 0.12080805135830758, 0.050387947008975094, 0.12959258240317145, 0.11658611016408091, 0.07038508647031362, 0.03849755762325179, 0.016526717114292325, 0.01168964849409437, 0.013882241929100167, 0.06857197085816054, 0.053109133450855175, 0.071220206577451, 0.07934970180353812, 0.06833417716646387, 0.06880476965659088, 0.06081386356644573, 0.08471148223766396, 0.05053260356127735, 0.014205998346780338, 0.049165527321278095, 0.04983123857527972, 0.032751618569055875, 0.015555470843889542, 0.024804059648886326, 0.029494197393256812, 0.011343669780950633, 0.03061553944022425, 0.03100044116558087, 0.11422036936686886, 0.06889355924701498, 0.0702803852337022, 0.05890883272513748, 0.06159801584398074, 0.07964620847375163, 0.027478476422989083, 0.021479615355811773, 0.017707578447316925, 0.08581091800043661, 0.03229583838894483, 0.037747595849777424, 0.014702525785973957, 0.07838588658600085, 0.031197450251408645, 0.012353848639665353, 0.014540726101146111, 0.028097718698723663, 0.05102817434817553, 0.06416678526288559, 0.03405229413821813, 0.04022674064242071, 0.0488511631415496, 0.08752087221270607, 0.06432909248096329, 0.015205321739608002, 0.06981423605353602, 0.034682742365065126, 0.04849384058146708, 0.06873338558380643, 0.11865265532246522, 0.1364838956825195, 0.12639726031451456, 0.19318765540036464, 0.1707125968870617, 0.09238222103205421, 0.08643831336690534, 0.13961846699878094, 0.12974878773093224, 0.0970628573709438, 0.1285745741258706, 0.11490701397340145, 0.12725011535709904, 0.09860284731633241, 0.21538911327239008, 0.06850102345549292, 0.16431075250429494, 0.13143074909044852, 0.14398334487791986, 0.1664932603917776, 0.20576806017948737, 0.08106690320757129, 0.2052289487854127, 0.2529494848943526, 0.13458746034772168, 0.09431013491966071, 0.07829211742406891, 0.10760768992646087, 0.10393377738974749, 0.1499800819663271, 0.0834976772086755, 0.12944150986450334, 0.15348409152319356, 0.2090888521483829, 0.13398816508631553, 0.10284436971790369, 0.11314468999062816, 0.1318403609818028, 0.15206630792348616, 0.11255962098197592, 0.2055679426919068, 0.21170499644452528, 0.12541466062107395, 0.16846587550976586, 0.09864800819946874, 0.2246680468200676, 0.13067910958441997, 0.13295719460133584, 0.15046598089318122, 0.12920874170958996, 0.15621999068365944, 0.19067245084912549, 0.1048031569488587, 0.15341013339498352, 0.0920558982198277, 0.20562575168667302, 0.17347507929850012, 0.0946008576260459, 0.2311728227763407, 0.135128486961607, 0.38011909973236824, 0.144746077337092, 0.17800526362994026, 0.22428437466582946, 0.1589779378545861, 0.42031806202665456, 0.3063993167973334, 0.2002265325356876, 0.4402508424414743, 1.151897647688466, 0.4972784275249128, 0.36553064060788004, 0.5536339696376555, 2.1148772778049594, 8.331603561678241, 12.91194740803011, 25.000155894987046, 44.284779102571555, 58.336046588036325, 59.96144540848271, 81.64105215380269, 99.01446127122449, 98.09554407673498, 111.09093696840348, 108.66119338620095, 109.38264277673538, 101.04224035816809, 105.35272121429445, 111.47362693663567, 114.56702770725374, 105.71317918838994, 107.27309011643933, 111.17589550633585, 112.26154481211017, 113.1007202209965, 109.02231816322573, 101.6850148477862, 106.17723480347665, 93.89776860513996, 92.39478695777156, 100.87805778749528, 85.78753086828416, 67.90867728571739, 64.14945417834868, 49.34669586919969, 43.39682509822231, 36.52072975712438, 23.258692179956746, 15.410717841117615, 9.98312242569462, 2.6361762083345845, 1.7680861897045568, 0.32675476324173713, 0.3660359828462524, 0.5782725830231944, 0.4812480070658269, 0.13332251128890824, 0.2812809485100931, 0.21842643738754336, 0.24270688934672266, 0.41755318942089237, 0.21366579848672115, 0.20932921989550515, 0.09683002792899648, 0.2491612413958196, 0.1402972668649689, 0.16835735149441228, 0.21796670802418264, 0.15253087896252834, 0.11076785624027254, 0.11622905190433226, 0.10030034493895308, 0.1954012358140561, 0.1657261152661616, 0.2712745531912773, 0.15554879040968034, 0.16757054855265927, 0.2087020543554137, 0.14251682276446975, 0.177252781427195, 0.08812785133599274, 0.10235409642900191, 0.20010173681282228, 0.11467354101759773, 0.08405613998371748, 0.1193226911427994, 0.21839830663896379, 0.16024193696437344, 0.22542779153633505, 0.12173946871752701, 0.14820205318110605, 0.33778645999489293, 0.08261114494093964, 0.1887326089725379, 0.0710691876649376, 0.11058381127734339, 0.1187629719835616, 0.1306319032465258, 0.14503081689678854, 0.21034229456657366, 0.18700664352265098, 0.0902077570677765, 0.1576115127893225, 0.20283120083472422, 0.1504833710890624, 0.18722528501624064, 0.11547018818917776, 0.1739462080501741, 0.25079553676468713, 0.21887850587166127, 0.17379711201835066, 0.14942560284849138, 0.13047808811308878, 0.14164781858844144, 0.14413870750896393, 0.19866219631606535], [0.04582391308260061, 0.08444252408920758, 0.038170499366617976, 0.026036026707339673, 0.04815326087296971, 0.03749595511884939, 0.02902103276292403, 0.06182507281341861, 0.06312127442910306, 0.04967332487144778, 0.015270339621741687, 0.0494094688685671, 0.03395571343360409, 0.0654061354937092, 0.04003682744599158, 0.03130225299467002, 0.0181471845961266, 0.026597519360122182, 0.07460167270994957, 0.042192085586007566, 0.036542769371261524, 0.011269407132790695, 0.03597358902615886, 0.03706568183617727, 0.007441630145730151, 0.029321063437589237, 0.005869950973353679, 0.0498167020569165, 0.026935639926382614, 0.07004670543415893, 0.07410942291420314, 0.018845473739108252, 0.023048611305233453, 0.03735338998658042, 0.06866115115342603, 0.012858720691574198, 0.06720311729417694, 0.04410467388468885, 0.03848786661100965, 0.0164535480566443, 0.07936874674933572, 0.023280944705249804, 0.10231703309522522, 0.03707226253144684, 0.037912890810759804, 0.010105332701406892, 0.03992124393041577, 0.06426958277100517, 0.04616352368987376, 0.11312343105072938, 0.01386501835734253, 0.0631424529297698, 0.05949614254096824, 0.13525162793455586, 0.013482022275697562, 0.06634646245548803, 0.025578162768074585, 0.05418818744440233, 0.04828131246951319, 0.02748234708222651, 0.07828944377721318, 0.03137442613801649, 0.05157042287230011, 0.021827846367452896, 0.07362455820604678, 0.23015296056626305, 0.04100968250103536, 0.058069794078267394, 0.15070178275627477, 0.2451251224885064, 0.08836284880676577, 0.09722211172864323, 0.03179790422080025, 0.07852476300491441, 0.4118724942447678, 0.2677508245312399, 0.31181059417224705, 0.10527369581283101, 0.1038130802372771, 0.06115363122174337, 0.28052239889098757, 0.42623422198718597, 4.17990711427504, 3.039279416684182, 4.836094638993663, 9.29922188481977, 16.905944962655347, 12.08059516645247, 16.23747208426076, 14.344904941897239, 20.966819909311113, 16.04592803985842, 13.484732104885964, 15.905565042649547, 8.405057787895203, 11.24718858349708, 4.503910089692762, 8.246258670283902, 4.841837969518477, 1.7501408558699394, 2.804531445426326, 2.7717325860454194, 0.5221884505402657, 0.22812935463603468, 0.1408116182973308, 0.08802878850650403, 0.19390918765096896, 0.31765054370607104, 0.1897103516685386, 0.2512389790987776, 0.07309968838648451, 0.081818358852498, 0.06222784353960907, 0.13759847700355515, 0.248988320029551, 0.09416751233079741, 0.012951196122524, 0.054176473960040085, 0.07614958400447523, 0.03405603647772824, 0.09537460642956919, 0.03597275399032139, 0.03090230913292016, 0.05465542446942099, 0.025047953315680067, 0.06529002720790525, 0.0543641655014888, 0.0438387111400164, 0.008585192094136392, 0.05396150202760774, 0.030133842505634795, 0.041024142410606146, 0.06412712489104559, 0.10715303972603814, 0.08766763933723973, 0.042467781477758, 0.09176397275540138, 0.051215747145995985, 0.10341210215682946, 0.021054426981737057, 0.042298273033192085, 0.05902039810955044, 0.03723985958664167, 0.07748476034330745, 0.03646748591094248, 0.034422835545434106, 0.043752587535568786, 0.021829342154125055, 0.05767952973744082, 0.033900666185804916, 0.02021114420776646, 0.04793800165756576, 0.016595157494227734, 0.0272355058921441, 0.05333500681445003, 0.05886115141273026, 0.0988390552060258, 0.029377763520085046, 0.027127554527513927, 0.06655266268118736, 0.08562241440578815, 0.06715941197809673, 0.021068388934157068, 0.05757646792898736, 0.03163541122640093, 0.031069071152277535, 0.0333708512686914, 0.05458103350153374, 0.04742102254362357, 0.05713761446156329, 0.08627861467820984, 0.03740627686643312, 0.018129884415576537, 0.03542926440375947, 0.02512723192452423, 0.03714252811586184, 0.055454174552353165, 0.02573425701308635, 0.05165980618086554, 0.04093785409725482, 0.05607389371782061, 0.06381246959790587, 0.0428952930134631, 0.03530184866019315, 0.02860831821547641, 0.0019123838489664901, 0.04719826715788053, 0.016644989598482367, 0.004915847835476481, 0.05530538495569941, 0.020819492713217775, 0.051316127646714456, 0.06312299046605345, 0.059645621616753845, 0.023084594455036907, 0.036291369958029646, 0.05154346040780506, 0.028986275353799426, 0.025953815896965327, 0.048807193525135524, 0.03179667464968178, 0.02558626223265404, 0.04887917897694054, 0.012897230973917873, 0.05396643180340048, 0.03277396152336751, 0.03215291319535144, 0.04636579771496115, 0.021516540793762095, 0.05819000859534549, 0.005802284821026749, 0.05155864044002468, 0.06021732239112739, 0.04530625981128505, 0.019813527338086598, 0.04903188711332698, 0.020846746291124055, 0.055303714884024475, 0.04047038341541925, 0.06968465228114398, 0.020087103081506588, 0.03385355943934091, 0.014013361707780392, 0.021263701135232564, 0.041254110514156284, 0.047421348130991386, 0.01775096966734817, 0.03175856369066864, 0.03798088877491894, 0.05121407707432105, 0.015000729340939753, 0.0655037121126248, 0.11244839267624963, 0.03260281365064364, 0.0947133576377265, 0.03803139695176675, 0.024641026562500386, 0.05009590663136013, 0.1776372809563914, 0.030545181925258333, 0.09327168741654004, 0.09152237160672104, 0.13697998357876656, 0.04277389872098162, 0.14735900406395236, 0.14867243116661427, 0.13911240463775976, 0.16470521117650694, 0.0820281673523207, 0.1440500558143662, 0.3695958402127989, 0.2954359857305404, 0.16194070629294843, 0.27242236740646825, 0.2727777096292665, 0.13535485062147343, 1.9872160183806575, 6.00249279891291, 12.21216715151264, 12.920820789952433, 16.608684216776204, 23.840132567190356, 33.414416543899044, 26.68852052380962, 32.69383203598761, 31.699415099236276, 38.104214129909394, 31.905890626292077, 29.567648095469323, 31.077121265472908, 20.651124023622085, 24.01237560856727, 15.061365077572486, 20.34229620810478, 14.053919988293803, 8.49625583617918, 11.783108884288419, 8.635975564679793, 3.3143500887578536, 0.6751657289362724, 0.23009911990694462, 0.23958570924737763, 0.3506046737874708, 0.14051621479372825, 0.10574644867090449, 0.07858153012010359, 0.05892609651651114, 0.14089889103366485, 0.04833712963567627, 0.07834606533569675, 0.005822757563193239, 0.05913575945962822, 0.0412952417748109, 0.13481105076930217, 0.05228613668511953, 0.0467366915226223, 0.08725491712891287, 0.06450985092669725, 0.05131955972061523, 0.04583985154186526, 0.01309141606813477, 0.037098531686370416, 0.034165253802653284, 0.012124274113786318, 0.051446883533630645, 0.019745801335140582, 0.0989723545048506, 0.015930865418105837, 0.04493051283662358, 0.048314081880474286, 0.04548702974833789, 0.038168779499227964, 0.03349123432511284, 0.03167488199147967, 0.08417417881109061, 0.03154431188088511, 0.012061202094980307, 0.06288251163618219, 0.03344005199089166, 0.017036688438947165, 0.015253226175123166, 0.029353269773925987, 0.02971901738595578, 0.047216649437623645, 0.07163248445478178, 0.040325405106188796, 0.028890996998656663, 0.028824628886556434, 0.006630950637402074, 0.04951612745982505, 0.07339189730344281, 0.03472553603651543, 0.013886519572547367, 0.0647049735210115, 0.06586771112896743, 0.020119389857075388, 0.0317981110645398, 0.014539454395191805, 0.037980291226337996, 0.05368478723891801, 0.020826615415693774, 0.020354875708900152, 0.02253569820294938, 0.028009823515951156, 0.0673722388643411, 0.02364309361925529, 0.0784976817967911, 0.03420288021105432, 0.022502367632583748, 0.004858359161223616, 0.04189157610638969, 0.05321810945808407, 0.13651558107906772, 0.19550306422095146, 0.13956084186511655, 0.1243180670445004, 0.2267354883013233, 0.1753334553852197, 0.08537659977352427, 0.1847526443100745, 0.24457019903967459, 0.11359165632917036, 0.1128351981300981, 0.19487170051903496, 0.08569480971463266, 0.1597416815498183, 0.15986889811052432, 0.1222815218892309, 0.16085011884570122, 0.11820659296767366, 0.10242469143122436, 0.08327824664452384, 0.1593578561779953, 0.12468143786874511, 0.134906520646426, 0.14105756316454182, 0.13124494212529353, 0.10475765898703568, 0.12563530926502522, 0.12387349856116119, 0.1049187902601496, 0.11921550778131332, 0.18657487636852652, 0.13978242513633546, 0.09086208042478369, 0.09078862025372444, 0.1968798008296759, 0.08928747096609685, 0.25510452086887053, 0.15511613459356371, 0.1373838038454133, 0.13657697536531957, 0.18255821609449002, 0.12382790866878726, 0.24966592479857708, 0.1597347561149828, 0.10470004151425055, 0.10186755398829138, 0.087380938592457, 0.09777446878292868, 0.2065670898845119, 0.18277671969225331, 0.10807492695147954, 0.13158520773774193, 0.25533990904448495, 0.17581494164562997, 0.09262938397906481, 0.19655180794577445, 0.1747191141569807, 0.10960872690643995, 0.20099611382090277, 0.2474166906528896, 0.23272352263091073, 0.10708774605225171, 0.251857181410155, 0.09597917237589437, 0.18151085132793074, 0.4477173498561306, 0.29365369749646036, 0.1359248200371381, 0.2576259307322964, 0.2840049733077326, 0.3287173272861589, 0.16059812188388842, 0.18274814461267766, 0.17855179075512195, 0.7673118876353388, 0.5701475157853096, 0.5999417783271882, 0.2423988147488525, 0.20235975032612202, 0.13374401286484736, 0.8727314082845565, 2.92237390914271, 9.253889091553228, 8.760446098542984, 14.963292094968981, 19.633227779019265, 28.069016356622022, 23.505195494621034, 28.53823773322567, 25.68151866236041, 32.75748425914396, 26.794240167064054, 24.38556363505702, 25.24882631917154, 14.937530948269753, 19.006990002047633, 11.598259345177683, 15.927388129695771, 11.44009663212684, 5.801846404229441, 7.392222381407215, 5.959535000785705, 1.7414259622173927, 0.3099941077732271, 0.2019085398604793, 0.17252347552247588, 0.2624637146870936, 0.48015342063961497, 0.34280936143571333, 0.48600271644611515, 0.21620534931219396, 0.1801462495519269, 0.18011989612733165, 0.33259842064111467, 0.2579868194316664, 0.18011660194925724, 0.056950229355284286, 0.12530949207082873, 0.23308975862399225, 0.24992774300757917, 0.3391977471690024, 0.21377067592355514, 0.11799250203635424, 0.106462465088454, 0.2793057286931623, 0.14861762523651123, 0.18170396677188336, 0.20426755440571617, 0.22222094748529697, 0.16250934271562487, 0.17639451780386511, 0.12673588649880502, 0.14587533690275686, 0.20748713083805578, 0.2866413270033175, 0.25539528187965194, 0.2177020706116192, 0.13445589240760575, 0.1935137024209384, 0.15787043518597083, 0.10918328763857003, 0.275284563822131, 0.18700167927290165, 0.10309646627114666, 0.10285100403932795, 0.16699832683849722, 0.1636041589682141, 0.17540131545355245, 0.1970272727550999, 0.13217483496954366, 0.11852698625936625, 0.18538639820631475, 0.1356888649564597, 0.1392365108814932, 0.18379154104378917, 0.17442176479005045, 0.12709731912060132, 0.12643685939932062, 0.15676480177189075, 0.16794950160528385, 0.22512465054469727, 0.28631635250583776, 0.09278373537404884, 0.23799151092046694, 0.1093136068553694, 0.07629988279433982, 0.1302965405967928, 0.11457862272377937, 0.12173844982058772, 0.20163668589966915, 0.1657567587831328, 0.10724612706971746, 0.052205835348896446, 0.09123293592804864, 0.11792539273418727, 0.24494598048829266], [0.0438734493969429, 0.005003919697276527, 0.03164699639103586, 0.04869038043844123, 0.05648851965463931, 0.026535623286279942, 0.019074984105123628, 0.03996276972635139, 0.04505632745642816, 0.008297408292550714, 0.021234557235373125, 0.02300907159224153, 0.05155027859033116, 0.04243447580524991, 0.08959542298989912, 0.034575562834018664, 0.031380746363391804, 0.02238527875423672, 0.014980851274524486, 0.05904991930771259, 0.01958925318303368, 0.007839937930956723, 0.08482875497711283, 0.029760246322820746, 0.009915091044780229, 0.047202036310467994, 0.01769882397756221, 0.03536020540782521, 0.03400223412280602, 0.053617367671141704, 0.0330172902003171, 0.01669667372029395, 0.013710274342297307, 0.027593263207123648, 0.08481606090020749, 0.06848112049122011, 0.02690695567927774, 0.045223924511623, 0.043509496345875726, 0.05469331134771628, 0.07287753821020165, 0.019327051930069443, 0.06189595126817304, 0.06727539002895355, 0.04151723490306928, 0.017267654372018673, 0.028902639619885918, 0.029048249951653907, 0.034421701735306176, 0.018815406703300053, 0.043571361776200995, 0.06075594731937013, 0.03693983274241609, 0.050842011152135755, 0.005284706243283806, 0.03029320986130305, 0.07201851615982671, 0.09973847307264806, 0.048917134803149014, 0.08143878526865475, 0.059907746260925654, 0.03625285871807606, 0.010028383957462446, 0.10057732402797669, 0.015189549904466878, 0.08526830558454798, 0.07925221711517343, 0.02343118603852007, 0.1142953310702597, 0.2167874995258547, 0.050694083404396816, 0.05563757217098629, 0.020522453611896887, 0.056998354998687585, 0.12763978597978431, 0.09007687094591318, 0.11132898500129101, 0.16738190706218445, 0.14161564289562165, 0.14048793082756383, 0.1268285754767637, 0.03401199025252173, 0.13901295110342965, 0.0301980406736895, 0.14230040292586052, 0.36810794424626136, 0.7484165434875797, 0.5419760726151929, 0.7328314346171195, 0.31742981845332735, 0.752742182343237, 0.7422788921863802, 0.4660395989494939, 0.5755353202262233, 0.33447800204157835, 0.4176396960693021, 0.3719031438231469, 0.4360595447642188, 0.5040965794074921, 0.10444533260118578, 0.05918960394938627, 0.3170626171894612, 0.019611285871735985, 0.045017138228661595, 0.07616084549696216, 0.037846696983662345, 0.03077685074400037, 0.04924748723785724, 0.20094719144605822, 0.09884819463496247, 0.034332310765861504, 0.09516908802212247, 0.09584049513984112, 0.040479928870955785, 0.19539260966402872, 0.020344412863074292, 0.04735681671468962, 0.03813183490907954, 0.02701841764182093, 0.06637355898536983, 0.0020679772639977598, 0.08499959258422737, 0.05026482518822436, 0.03398378289514973, 0.03340302313107156, 0.07318195856867299, 0.03247899852032143, 0.021855676426522194, 0.024722724093965465, 0.035626761870638984, 0.1392979204895035, 0.027932630581480843, 0.05759816353900298, 0.05919226227448352, 0.03567881754509384, 0.059848918369220155, 0.022008298378017162, 0.01788071048776469, 0.02352288484783663, 0.04916193436891322, 0.016890748689371734, 0.010794768740813579, 0.032856465362372904, 0.05167164223929567, 0.029536701866515705, 0.06546887809470778, 0.04756975851412262, 0.01718750625338045, 0.017036964230599905, 0.05466429193714454, 0.0350663838757863, 0.024400712441532843, 0.06301050577613135, 0.06562293837628057, 0.09307197595555937, 0.013279763572368652, 0.04605700299444218, 0.025963043426013282, 0.01560430703384261, 0.020510209611647075, 0.012768968703195214, 0.010536563593984373, 0.02268759045569647, 0.06561779792630865, 0.02042585758552436, 0.023526573561192043, 0.03822219881018804, 0.048289145718538956, 0.05811607344977318, 0.031359994956742854, 0.04140501068304143, 0.04403981688101927, 0.027994181915757158, 0.022485157467364784, 0.0396165669324898, 0.04233361266913914, 0.06505276211687634, 0.08892060678091743, 0.024611769664672115, 0.0843582850610537, 0.02177191237288137, 0.0458480371913362, 0.027656352462907954, 0.06277018782472418, 0.0425494464504863, 0.016871226853841258, 0.11479279792477047, 0.028605903123295116, 0.028024984395972667, 0.04314103486737417, 0.01737482624218589, 0.04894743741099392, 0.031169476550853545, 0.04642868970310496, 0.015599410774396553, 0.028187469729492744, 0.12089415198011745, 0.024708850241656748, 0.01629840567587845, 0.14118191455641102, 0.035303694932090665, 0.03433731332000706, 0.022807031223971038, 0.047788775390795166, 0.01485752548286391, 0.06232154375362781, 0.01060822728886119, 0.028503808500846068, 0.027323588766458056, 0.08287704639857815, 0.037211115967722676, 0.06164573929122379, 0.029262949922873132, 0.06555628872686817, 0.055333396960650726, 0.06373994405411425, 0.023348770299625975, 0.06952027279523111, 0.020624308831869595, 0.019213241908038338, 0.02534376859154192, 0.01876619896070371, 0.040998984083172776, 0.029746738277495872, 0.09802323285370104, 0.0011212899769288338, 0.027739612813738566, 0.05615937380841183, 0.04890064476057888, 0.035475428862076615, 0.0017177003187938565, 0.047919125251111486, 0.016069523501960982, 0.07036933570259041, 0.030606650905082786, 0.026037750405169306, 0.02299422097782935, 0.0634899121078272, 0.1475775536269911, 0.018548580194492976, 0.04604795166561681, 0.08361009295068442, 0.053320355382898164, 0.06118341288979977, 0.1645157269893154, 0.27334354217014006, 0.068277072972588, 0.1804186091307671, 0.0860385533662573, 0.06614463659183634, 0.07800774558657601, 0.08774005762872197, 0.04648341902441556, 0.15271536825645357, 0.1030163104916292, 0.1238891957027297, 0.07618084805266512, 0.10819584626944796, 0.17763622375505586, 0.07750913726105806, 0.2881950146007923, 0.35692679906083696, 0.36242059942695404, 0.5378355818890757, 0.4952417368129377, 0.27131509456423025, 0.372642939609866, 0.18518528480443264, 0.5727874547723801, 0.20563584872551505, 0.35370595092254303, 0.20278135915437054, 0.5558953999030976, 0.3803217759536159, 0.7749439619721905, 0.334463446371017, 0.31575190203805126, 0.32975448776156674, 0.26449537986228544, 0.0379417225297901, 0.08043542459246614, 0.05773567632141133, 0.08589501147188487, 0.03437231970770705, 0.041751439472840685, 0.07591182861717478, 0.06109883678295921, 0.04789245006958804, 0.09316651120541558, 0.05525877233594657, 0.07195854679711404, 0.11069804264773285, 0.12781520479268607, 0.006526441401576684, 0.027312834807220968, 0.031810703634795164, 0.09919478813366545, 0.06502036425855852, 0.013583537544153873, 0.029572351768072096, 0.05928063817742852, 0.03663685645968203, 0.016442091211736683, 0.028633074346749533, 0.0715536310247356, 0.052684885449707515, 0.09642745638566633, 0.04444131590125542, 0.04382912738008365, 0.043106763924081484, 0.013429072193591105, 0.058791885573056445, 0.009874155136546301, 0.014552486508393721, 0.019461626765288172, 0.031057258076485128, 0.027897124321410255, 0.031364288879558444, 0.09346180745670873, 0.025233497895720988, 0.06384910009200535, 0.04159958552448981, 0.034943813638341044, 0.04404302295898238, 0.05623435466400078, 0.037386527119745175, 0.04686473162784692, 0.011642284150565825, 0.03187028612310608, 0.043852489231334585, 0.07301291360730126, 0.007235992037045259, 0.005365501227413094, 0.03690067798860612, 0.02207351927345078, 0.0213161283623307, 0.054045978543018146, 0.03890741849318147, 0.02593645634460113, 0.07195814077051417, 0.019562618221126257, 0.04042470159249441, 0.02381640377514545, 0.019205378015495597, 0.0764325155966705, 0.025903211959126978, 0.029729441927385428, 0.04276705755581779, 0.01888605150123758, 0.037716902537091125, 0.06653120455842826, 0.033616347974466707, 0.21315821927160988, 0.14641224196360958, 0.14101309942141657, 0.24338115397239887, 0.12052266062387537, 0.09759225477013858, 0.1256595253043117, 0.15884416358124825, 0.14046110242845553, 0.12738242640250153, 0.2684699972310374, 0.10734002646659652, 0.11153978175453602, 0.11775924358516933, 0.16126256526237534, 0.24230078613806158, 0.1966318488121033, 0.18752435042012125, 0.16048118622312624, 0.16196638556017032, 0.22922643850887978, 0.09628717036497209, 0.16558783639582897, 0.16629043095294507, 0.17526525823820024, 0.1231932431279171, 0.08609144407654963, 0.14432175655759152, 0.11909939949550938, 0.24276836024176693, 0.1808740943670273, 0.10137488284418661, 0.17327893014636733, 0.1736497013799606, 0.09844895557410295, 0.1938583806998307, 0.08951836986647499, 0.20078232932475307, 0.14681698153576545, 0.1448407045174991, 0.11881426157009219, 0.1434448616759431, 0.20360438273318354, 0.1292307437547753, 0.17716959960037665, 0.09658792882316536, 0.12955421671992348, 0.08080506201593146, 0.3622664012495549, 0.07139633785212232, 0.1205807071058981, 0.1440283295608336, 0.11685738955894787, 0.12095077353860102, 0.11122196251826902, 0.1548781570407652, 0.15041402481015653, 0.23608591317409472, 0.21636857200534115, 0.19069135789909672, 0.08907082896198958, 0.14994162435252822, 0.296451082873729, 0.20900894917788046, 0.1027748778822922, 0.23798024942798002, 0.20735996024262524, 0.16796618700027469, 0.23034121901277574, 0.5674131334789339, 0.25986955711437815, 0.2838786913742942, 0.08679521840906913, 0.12146104938320576, 0.23486057086096657, 0.18199367058132926, 0.1802022659009503, 0.2877954231394876, 0.1748045636040549, 0.36878375636954464, 0.17241262259983248, 0.15231896372091386, 0.3760072606946192, 0.1373923993519237, 0.402281349224429, 0.6524756755078993, 1.1030141288234343, 0.8503430709242822, 1.2024377550809615, 0.48336130657023, 0.9134070611288472, 0.9048604003844724, 0.8632370661343298, 0.7735087422113266, 0.49991999061838277, 0.5567328259348869, 0.6373830692422006, 0.8017677032659132, 0.9568789348967615, 0.3291437931118473, 0.43125896203902464, 0.5823079664861003, 0.2205621985898864, 0.10231533238003332, 0.20265797303328592, 0.15876773864992205, 0.22793194909970607, 0.24171508127643218, 0.37949302203712926, 0.23733520339573586, 0.12940092252627497, 0.16484103856548188, 0.16155838245345702, 0.33319253714815267, 0.3873441055897744, 0.18598923279393106, 0.20472225823229362, 0.1009771682982964, 0.10768317256964023, 0.10803500610974529, 0.1954244482781618, 0.1629550067046958, 0.16064140585161027, 0.12233786765606174, 0.09369811493783228, 0.2177324230151792, 0.18359735307674255, 0.19528885071556415, 0.15352181369258514, 0.13183230173683938, 0.288450826680468, 0.140283324064747, 0.1766954984275564, 0.13500450329194147, 0.1530823550157009, 0.1659058548149563, 0.21189995049949617, 0.09418789026958328, 0.0805280905877871, 0.16049198806285858, 0.06762630426354947, 0.11450940667982064, 0.14398844702349556, 0.11843878655664383, 0.1693262075704913, 0.10540783014749328, 0.12760466084845606, 0.13949790008125768, 0.1026401996252037, 0.14663489775792246, 0.14700268124861104, 0.0900809541945496, 0.17601202542503036, 0.20744612981234828, 0.2416573488904584, 0.07352569455941839, 0.16619303053425205, 0.1213061004396408, 0.15238236515752732, 0.15027277351867768, 0.13425165336699257, 0.14121540792046056, 0.09717608516615245, 0.1490825333542401, 0.1251548725450712, 0.10993576218043605, 0.06258747202434367, 0.12699388192906497, 0.16346558898447022, 0.20193768184511893, 0.13874292043187927, 0.11634673067038098, 0.0846586374926471, 0.1190455894797079, 0.1632712018345633, 0.1526043774379838], [0.038895597756509824, 0.017306405014448592, 0.0447603493868824, 0.01955003522696995, 0.035465760832472194, 0.06248257543531157, 0.038304725631831155, 0.03449106716641015, 0.05461750694760873, 0.06759347739599406, 0.05791800524739008, 0.046147562247971376, 0.027018676196495374, 0.041320327323891466, 0.06434703426014993, 0.06404979597596873, 0.03504838464000533, 0.04989626794873227, 0.040529824177464174, 0.030848705960858255, 0.03189693066111255, 0.03934480873267016, 0.09327380181921106, 0.032481967111028014, 0.017610534259508696, 0.0034458275730421227, 0.05039971028905242, 0.0369473863693495, 0.06745952692243361, 0.016525292190753164, 0.022613048185444167, 0.028305738383243163, 0.03856883827416647, 0.06793894474544833, 0.06476735606068565, 0.046693487994132504, 0.045033114992322466, 0.05935954140318979, 0.06516710840045445, 0.0369691854012349, 0.031963526684370254, 0.043920544652088035, 0.0371922931874231, 0.027736031352692557, 0.07354518383621209, 0.014590490215097465, 0.08391501892718577, 0.04457280723257892, 0.031227741367934696, 0.057559123698381655, 0.08075294505444267, 0.03357517074853663, 0.0550240391655074, 0.0962983399269081, 0.076615909384864, 0.04682258147025301, 0.020065685178363518, 0.0607499641726815, 0.05064939749577353, 0.06763936606265845, 0.009518362837092531, 0.05300795621869545, 0.02784379694100109, 0.01874916499570733, 0.04033083283913232, 0.09818785748774968, 0.027665342504699385, 0.04379771777518815, 0.10677984765460415, 0.1496924925595522, 0.058249150583099936, 0.05499727205343305, 0.026743960897288015, 0.024945201772835948, 0.04614658548586792, 0.12986717895875055, 0.16630916946357296, 0.07084504566005162, 0.15479581791066355, 0.08736623736519007, 0.09171050747916584, 0.029040213689328204, 0.06981581419466004, 0.08304118073635525, 0.039565200737166795, 0.010723248687422565, 0.2905790802211531, 0.38482566814749475, 0.2519529883659655, 0.15854479174219793, 0.2964907049411728, 0.4152279593531163, 0.1513181924219093, 0.262659250968887, 0.18921671525364925, 0.21253169724537482, 0.17931075406170663, 0.1798754987577277, 0.13657833900182478, 0.06487525188394132, 0.005129705109978996, 0.17808492145230695, 0.038806509391795245, 0.07986591482955603, 0.03312450037488053, 0.0044136068167825865, 0.035512564974206115, 0.07246874603292636, 0.1576388927717363, 0.11890664411288117, 0.05395048951369621, 0.03574898736851831, 0.04469222501821576, 0.09737317660643209, 0.13702303772011112, 0.08857585189323272, 0.05625281738297594, 0.04733192268759013, 0.04455999058160571, 0.050385867080260674, 0.02588136696196612, 0.13036502885722345, 0.04194536313955342, 0.04342756324237393, 0.031237443871495706, 0.010599388549434803, 0.051405836542647694, 0.042431059053107616, 0.0722577654185795, 0.016538097350407514, 0.042676057801732135, 0.036208509888139465, 0.044184722411896915, 0.05632004542877117, 0.046799181314605864, 0.024987068477897875, 0.04981987749136264, 0.015281124224495745, 0.015847513136724313, 0.040779423284073996, 0.03925112384040991, 0.04240629143051563, 0.02373401676454852, 0.007547751517831198, 0.02155305062901349, 0.0756435139825748, 0.076882362425808, 0.019509162520989776, 0.015793294221493268, 0.04375032374575254, 0.016329422660712755, 0.07601684394983516, 0.06535749657139664, 0.03858569603894026, 0.06259078152417656, 0.02364950769040133, 0.01653475720705765, 0.03408682172096545, 0.032534716095054345, 0.030235527271044352, 0.031174287583018025, 0.03739131899971155, 0.018044931010433266, 0.08789203415114073, 0.0390946657036341, 0.05712312390847553, 0.013254453942570235, 0.0727065550463815, 0.004068887839469338, 0.05352688502640494, 0.041518361052317966, 0.018404174535985918, 0.013246714539315193, 0.06349602548946297, 0.07820489065301034, 0.032643217127770185, 0.05971663413689502, 0.09298280332117312, 0.03302678969057818, 0.07502662168154794, 0.06306196007156564, 0.08840938864816582, 0.06568804818896518, 0.06474600519023596, 0.0374460406601429, 0.02829470097147409, 0.0521875181866269, 0.0721433655088467, 0.048098470264625166, 0.02935478471279625, 0.06094668789075748, 0.0208061991725117, 0.13282993207535437, 0.022877714326304775, 0.03562566636490726, 0.030503991292789582, 0.07973623146573383, 0.04750455677088711, 0.10742939062296383, 0.06325529768101631, 0.04026325239289192, 0.020333295012073174, 0.0657020139718248, 0.047681051937322465, 0.028812538103891477, 0.04406103368608221, 0.07844609343597005, 0.022412601280056184, 0.009735367775353934, 0.022179051715460037, 0.05324283877627985, 0.006695526582564438, 0.037241353458094026, 0.03850519935029649, 0.059474370322160186, 0.018617554920755567, 0.033061056803431244, 0.05537071693388205, 0.01625440733116721, 0.030724457990858826, 0.04708038154809226, 0.03334717149095189, 0.06192487874819387, 0.05152228573757795, 0.024959157979596528, 0.05306080862459156, 0.09984684387041677, 0.027738431123115366, 0.02194164872860476, 0.047560163262871005, 0.07857909396050439, 0.03519661499247436, 0.0733149744149658, 0.028142958105872237, 0.057819662540550196, 0.04341273561059948, 0.06794336507277143, 0.036148686082132404, 0.03502414561808109, 0.01703951721860757, 0.05292931729326806, 0.048862822999757145, 0.03177760480602663, 0.08498548124466213, 0.13307365528758497, 0.14758185904112556, 0.08722857136519686, 0.12590737006957495, 0.06571108445284829, 0.10658769748143612, 0.11326651329234724, 0.08352620632297571, 0.09840840654027078, 0.05682968158995914, 0.020124509239629395, 0.07058232346729887, 0.03741334785797423, 0.12421896591061547, 0.02699749769582864, 0.07886182636983934, 0.08044135411300006, 0.14320267063956107, 0.06708663362529009, 0.20000118011188125, 0.15997867851007372, 0.09176837776096598, 0.07353312561228391, 0.20526884664450923, 0.05764374194005805, 0.01406674367195416, 0.22876275613182978, 0.18505007028579715, 0.09278021136959715, 0.12028739502232884, 0.1594662116540055, 0.1094800701004363, 0.054220880246571, 0.12237118481988869, 0.007413703368060412, 0.07763507445493052, 0.019636335031640147, 0.043484092870306586, 0.04856519784117418, 0.16444478724752704, 0.04510117424351554, 0.0779080928693856, 0.09424979783474438, 0.04278828202175998, 0.011893977550038648, 0.09716549017015966, 0.02766207705492214, 0.05683788639162818, 0.08249856832046663, 0.03614522719515428, 0.07537789597746826, 0.006370793402780809, 0.17729909910309702, 0.14672676702180218, 0.035853420474356225, 0.04008438618433091, 0.02268314523051583, 0.006385618161725542, 0.03856781554678756, 0.06827256837559324, 0.06984584484129183, 0.009736078321903704, 0.025328048467335683, 0.05427223878101476, 0.01579962306535773, 0.0506220979525918, 0.05449983201199963, 0.018181064834577904, 0.018830839544534683, 0.05642555871858232, 0.01989968350127099, 0.030683181173498594, 0.047016551102241205, 0.06255764822145143, 0.04610120243723354, 0.037133541904510035, 0.01616678410960782, 0.018068388622674732, 0.06375111744648988, 0.09889560015571695, 0.011874232591400224, 0.01614622039450032, 0.01939401950597042, 0.08274074403509017, 0.00975514146228952, 0.02120801611923643, 0.06973399600434689, 0.046497212437492226, 0.04018747863630134, 0.03221945559245444, 0.016619771899234866, 0.026683451442588723, 0.021469591095322565, 0.06426199467011517, 0.050350879844758785, 0.04226715837214743, 0.019797518015688947, 0.08866045864359026, 0.06580301500376194, 0.07460813849203049, 0.041053640626130566, 0.0605844508766407, 0.029782129624377818, 0.03040587649710717, 0.04932563969745271, 0.03809834920590924, 0.04405197852681722, 0.030097872762370016, 0.0680899023709278, 0.16900812786433006, 0.14191293097551794, 0.16862848533257363, 0.17064003303887385, 0.1381458008601781, 0.0891008289651044, 0.12996067232902975, 0.08913397758958802, 0.12729766643455914, 0.1383836711606672, 0.16358232546237209, 0.26033392897055996, 0.14124992784232865, 0.12544996195262478, 0.15289336112478089, 0.19563650141560263, 0.25957259079141004, 0.07619333528583089, 0.1313401515325231, 0.21083055304423456, 0.08822384981378432, 0.29914789622829807, 0.16373661557032218, 0.1406328593410792, 0.12528961975007288, 0.13108692883003142, 0.16691736666665924, 0.18888279284921386, 0.13465936536029463, 0.10290137432034939, 0.20419166573593694, 0.1725483580582565, 0.2036670334036312, 0.17220582482555222, 0.16018351509926781, 0.09605662386503913, 0.16700869966899196, 0.12811698980869787, 0.08959986629985994, 0.19189966241678885, 0.10326266904631931, 0.152499285496531, 0.14028522396279922, 0.16592974143643535, 0.08556813707635288, 0.2165468559870797, 0.15544403554691424, 0.1424273130513968, 0.14613959127135817, 0.2421854592619404, 0.07151207075484338, 0.13846974879983934, 0.26443191713863806, 0.20190469409909942, 0.266940456724936, 0.13062225053867987, 0.13840081620841257, 0.2437085186642024, 0.12507676222031155, 0.16005830568892343, 0.13349671968288962, 0.11999687149880395, 0.13490947774581372, 0.10845791728746508, 0.16648135538543427, 0.1319383895925937, 0.16323999141252812, 0.4031476108056884, 0.2594713752548541, 0.27377892525926717, 0.1269680264616205, 0.18288017220554814, 0.15239344278891243, 0.2093818961011787, 0.29590470896613214, 0.3284072148944101, 0.2596065131646972, 0.22564943609458787, 0.2717413458852999, 0.23020955914210892, 0.17453640218703978, 0.2434669404981598, 0.24897771737267896, 0.10847058838173267, 0.28709656709144193, 0.4171974488323735, 0.6420708531814238, 0.46113421539625815, 0.3198271527165367, 0.5140098490782323, 0.6551161047912414, 0.2830534614622593, 0.45217319301539854, 0.4540851952568178, 0.39006371772097004, 0.3199431997153067, 0.40530751909940477, 0.32740042214432075, 0.2933931050281371, 0.19860775810816597, 0.2478023546357309, 0.10747930125123072, 0.2389623435033906, 0.09098562742433242, 0.1654036995023489, 0.33431402858226533, 0.22674550873137292, 0.3950596528668558, 0.26684052821609283, 0.1596172075838812, 0.29111681265696404, 0.16144357651712435, 0.3293761322575231, 0.3688975663915757, 0.21154990960513392, 0.15915565493126071, 0.08402826204415291, 0.23366248595618436, 0.15972372444887317, 0.2959788969207195, 0.32431817463328766, 0.1481130031207877, 0.14608360556585176, 0.20378747774708658, 0.06959770896261738, 0.14741097546873555, 0.17302189232601276, 0.1783246456855728, 0.13291482993912312, 0.1445945604674278, 0.1650408649396512, 0.12702811073752182, 0.1698734854618388, 0.11407150316142267, 0.11566551762723154, 0.08599749871439512, 0.11329577019017552, 0.15505654827481316, 0.1584167631282922, 0.1782178683506866, 0.13604497326718223, 0.13614304784324863, 0.10741811380871844, 0.14515375868687708, 0.19406510186531853, 0.2999396021327665, 0.14882992352208785, 0.07388832227837655, 0.13556881897872494, 0.16259557357238186, 0.22475449218144342, 0.21684077328010914, 0.15606878024916496, 0.14062087772594345, 0.1428601374068568, 0.11392885758992165, 0.17093407290597118, 0.11871109250932933, 0.14232125583915942, 0.12288460928586223, 0.1666596546889313, 0.11495143941213047, 0.20682533812378684, 0.10068015601005285, 0.23830931483497544, 0.16567930729398805, 0.11955490005352806, 0.16445609470528944, 0.2176719173909195, 0.07518547767352673, 0.16786396022765868, 0.10299482938623238, 0.15100979606711096, 0.15424644093840353, 0.07965845055878162], [0.011801770249862346, 0.002494117502318395, 0.07872586108503804, 0.025278940316169493, 0.06162881640897644, 0.05951030750668818, 0.02762211407835205, 0.0587306330130706, 0.02716693336204175, 0.06990976721769379, 0.02780402548641207, 0.05601557144414514, 0.05346063374271316, 0.0305414893814633, 0.031741071988137505, 0.026621869464795438, 0.03691431435365831, 0.07416159350184665, 0.010798590561945834, 0.023170195204476197, 0.07935391528712166, 0.02535004859730121, 0.054373967596479965, 0.012726619362740988, 0.0070012042828414955, 0.03352718683139932, 0.1822608667275598, 0.0500905133723732, 0.03364660844747578, 0.08729627055506553, 0.018534648885589936, 0.028123154733029586, 0.017751701281315858, 0.05816641308727765, 0.06350378979057555, 0.1025137031871465, 0.013044631078598962, 0.09146333687127599, 0.054394376178782795, 0.0553677368518566, 0.03596800807563048, 0.0028023666245937952, 0.05493270999361431, 0.04969661011390629, 0.013405736197807617, 0.015246337129464074, 0.0272959808728868, 0.01000343055854882, 0.10041104464401161, 0.027087700718473044, 0.03433619866207723, 0.04659798364305208, 0.026493310335002122, 0.020136971574937625, 0.01594538374188086, 0.06706251717743374, 0.02691828803489766, 0.027198984565573837, 0.04134100020652817, 0.016832623683336764, 0.0439012085928792, 0.02432354057448045, 0.03754714511394982, 0.053457871995746135, 0.035530564209987084, 0.01789483140342899, 0.07131889402385681, 0.09936819979620558, 0.0256633211017376, 0.12225554384771856, 0.07732595031660411, 0.02471014493024878, 0.058017075737758037, 0.010313110110620338, 0.09722109283170394, 0.0897134694781515, 0.060978357965547236, 0.0790474494738925, 0.03520680396186729, 0.11303257302290971, 0.024684312445442044, 0.0019102763889672896, 0.07669562849426463, 0.03609571876304765, 0.04744949420132945, 0.07440465021758311, 0.2560578253600867, 0.13362902306741284, 0.2187032096328274, 0.09253130174211918, 0.15392410178338328, 0.14176544372833547, 0.1031966629107633, 0.1084823708140081, 0.15124737525418883, 0.07656536290361997, 0.11334525947008403, 0.11272690394112181, 0.17153255611417756, 0.03913244916005962, 0.05308745316259804, 0.047815546333309145, 0.037275494166439584, 0.012223084134260013, 0.022756664773389217, 0.04473617548243173, 0.07966952052928748, 0.06246534994833412, 0.03688633682266359, 0.06020582341138394, 0.042094926485010696, 0.0046463098542224015, 0.060348442169807615, 0.11415156701038923, 0.08603396449959086, 0.006179307810887094, 0.05232439511605809, 0.1466953420951482, 0.016529448217742385, 0.0749617187126029, 0.08504548125089177, 0.03418544788033732, 0.047030650950487585, 0.036205384249408404, 0.03474450820396024, 0.03546154351844903, 0.012403612753616707, 0.05286513827741147, 0.02275836357336131, 0.01085411086903825, 0.026768295680202787, 0.031867608645810716, 0.03225398317520176, 0.052221103481227354, 0.003188247984883586, 0.04503225314340765, 0.05146770580341259, 0.030573301182519046, 0.09689678483071829, 0.03444288789685215, 0.023414971787602674, 0.054623850155621774, 0.013827098920310458, 0.03946990322982592, 0.06612810441443036, 0.03928406562115397, 0.02234608378081072, 0.031191310056695537, 0.030022669741283023, 0.10166866224138968, 0.02090145071457711, 0.07082596240985779, 0.020150899053401044, 0.051160627119844, 0.03938538074914006, 0.031743067647180254, 0.03466937796122605, 0.04134375812305559, 0.02425209138422243, 0.09657247682973262, 0.04717602762543867, 0.04550581422424124, 0.020727906901870045, 0.0243931875428966, 0.056715515337043235, 0.05416759883143729, 0.026998870908432913, 0.09287363579196316, 0.014481012420278164, 0.03364326830412592, 0.05364791542712239, 0.02486201420035814, 0.05960849316550359, 0.06851131201631601, 0.031904141463699846, 0.04301750702002356, 0.021449222732635758, 0.03377069553901111, 0.021862958092242483, 0.039306274510078856, 0.05348136408194419, 0.03252152023055861, 0.026738155866041783, 0.022867910316093795, 0.06003182952202136, 0.0852962984373012, 0.03598626395086608, 0.016848029711494045, 0.016237105235397335, 0.05719944541793197, 0.07550973204835769, 0.04484546175526996, 0.057652678355694785, 0.013931997424562373, 0.04317506449297071, 0.01453560384576239, 0.03914731509623028, 0.03695209781008382, 0.01839232507101711, 0.03456803985060223, 0.01359490533134029, 0.029067938411307913, 0.10535651757832497, 0.0694230715593984, 0.03843984055903651, 0.02043008447564658, 0.05114542410498665, 0.010066860723459433, 0.09212706012711411, 0.05725263490251476, 0.024022569526888193, 0.02786195514002635, 0.08585334394968326, 0.06197694208352797, 0.057800311159582875, 0.04092268172591444, 0.05001762010637791, 0.06466699088172567, 0.027082600488117146, 0.012193586876345499, 0.03533374090048094, 0.10752076192969277, 0.01713568615096231, 0.020805532676017573, 0.08758589775571901, 0.10419319774354659, 0.0339349907552523, 0.12818049083674146, 0.020264502231692596, 0.02534428953133043, 0.09789565623167062, 0.024768285258042238, 0.08179465609212076, 0.13690299174237636, 0.052721002664897716, 0.034698393541358175, 0.016283533994048353, 0.0197726144124904, 0.049320679278142994, 0.02179981137986385, 0.08375206436481207, 0.039043510182490276, 0.06996887856193128, 0.029629159102877303, 0.016363944497800643, 0.13008405845011436, 0.04755666224105705, 0.07054825553730612, 0.11298843869759191, 0.08661655904424768, 0.08088253648771394, 0.0766618516776831, 0.10279828186837897, 0.0727241827295192, 0.09338213431258356, 0.08253254431990847, 0.031010678015469067, 0.02787739372692041, 0.05091530278385167, 0.028673560178327947, 0.06524773915448497, 0.11445244804265038, 0.04838221007958055, 0.1369490489483841, 0.052734079785765185, 0.10592079496071224, 0.05725854144041097, 0.09937299550661158, 0.04398226452570769, 0.0977946935041297, 0.11445514467214385, 0.06166086186684909, 0.190061281224893, 0.10396617524806531, 0.12902393065873655, 0.08001077439515822, 0.08651863768576615, 0.0578353405299206, 0.06675515504133317, 0.02716744472573121, 0.11147828787685403, 0.087507113273586, 0.05173825358431186, 0.021830816873379295, 0.021260334178805355, 0.060191076218841545, 0.08182222759651561, 0.03677290218371538, 0.015439784864053853, 0.05910705031466581, 0.007288036698986206, 0.024023061738379543, 0.007605350317223179, 0.04017399931927362, 0.01367284807436649, 0.08430954654731097, 0.02064049052405021, 0.02497249557035825, 0.013141660902258611, 0.008300450619220013, 0.016458701913154895, 0.016636899710001967, 0.0320520538896803, 0.03495235551869677, 0.02419920258914992, 0.05392777883718091, 0.00932060681553858, 0.031734382125338724, 0.041904434892198736, 0.029763846936064865, 0.02328023032826041, 0.028583500797169346, 0.01719228472680815, 0.031452536462776126, 0.09551096241921188, 0.06348900812407655, 0.0008031154075363321, 0.1130890720073254, 0.04848930917139496, 0.03048707990186109, 0.01150038647240088, 0.05228464281366718, 0.03757520691461621, 0.021407988050111362, 0.06206676589264985, 0.09250149326098543, 0.05529284792681856, 0.027257329821887038, 0.009510562146803545, 0.03724224978096543, 0.03408324025991944, 0.0044140070977230226, 0.037141650945188544, 0.031641700808259274, 0.04545192376920774, 0.05466956645250321, 0.029303433839231733, 0.051216241272707144, 0.015477068448108772, 0.027994639653291915, 0.028980050889414646, 0.04333282880965741, 0.04643491799792936, 0.03852149787088556, 0.01538475389562307, 0.05634991519693887, 0.13357293010959703, 0.03637472415463098, 0.008810331928543746, 0.05012415612356798, 0.022758512960506544, 0.018755860604165543, 0.12733499023823008, 0.10909629069388875, 0.11771785185462046, 0.16088707492716853, 0.13763126556671437, 0.086465310305357, 0.12396100878475175, 0.1304876488903838, 0.12526967082052462, 0.1981821503009527, 0.1585390614045243, 0.1461825534821518, 0.14815423397287247, 0.15108579198919958, 0.1338505450515978, 0.08123497523727917, 0.16448276988681287, 0.15782537389426463, 0.24707498479514356, 0.11688709844865146, 0.19394476477417255, 0.15077233945410098, 0.17321661655460635, 0.1231509320918591, 0.09881110831854806, 0.09736246669725065, 0.2859005199805383, 0.1935407453246655, 0.1232537181086598, 0.20762888774756463, 0.13858875289799708, 0.14164427926223125, 0.23347847163677218, 0.2500741270881507, 0.2401047644595946, 0.431734488135384, 0.1676685465199332, 0.2573608643104953, 0.24237397817834733, 0.19164355922370188, 0.13486591798643913, 0.13477559622016647, 0.11226634720280287, 0.06970460121069225, 0.1383994372501489, 0.23085354797301755, 0.1293789664463651, 0.0826092756864044, 0.20742855575536528, 0.2651587507176784, 0.1439094020714683, 0.2618171364790009, 0.10677075419094294, 0.16322709049188322, 0.13439717942908888, 0.1522625030408944, 0.17461100382910621, 0.23370983018990488, 0.16367932751534447, 0.10763610412757244, 0.1772738794886297, 0.1289424189035931, 0.1638280558249643, 0.17362261251095804, 0.16187477676618486, 0.18178946218423306, 0.1455434369704416, 0.20511239616861268, 0.14170794116873897, 0.3249286241348713, 0.2252890070479724, 0.12889020235067414, 0.16854105937865474, 0.13359045820130458, 0.1374076138580999, 0.2532436320137593, 0.21308194755786852, 0.30637976623350577, 0.22805515135968887, 0.30400495495527025, 0.17253216295953722, 0.09555341135109625, 0.15144905556113492, 0.09648662135605851, 0.1271359759172605, 0.3092514621394296, 0.3845708060168451, 0.42434970698048996, 0.3146176016138446, 0.22662216857556375, 0.35162586899053666, 0.3014992958595676, 0.27803160190101595, 0.37675778171227825, 0.3530208844571345, 0.2973688255635, 0.342132568719887, 0.2808000904417807, 0.359891957693523, 0.20231341732846153, 0.16218213124140618, 0.19274617425136029, 0.14233253265340484, 0.140437706103248, 0.26532116135762585, 0.22523892021948294, 0.16433149816528445, 0.16724745863147322, 0.3021177739625977, 0.20350471469423465, 0.18742394693676503, 0.120022903166471, 0.11458890362372322, 0.27682602465633427, 0.3026369670706411, 0.13960028007145853, 0.16975639658349176, 0.2034705012075363, 0.10146151972754348, 0.19570845239345105, 0.31851827617614503, 0.16248326508268235, 0.15534030724196665, 0.19547134818088627, 0.09043012174867815, 0.24373093439686686, 0.13319503425830795, 0.13919350270542408, 0.08434069568231221, 0.12218955303392104, 0.08664211573740167, 0.12785795249886092, 0.14215791057194435, 0.13507941136917762, 0.11749917971751384, 0.12498347569377193, 0.11597109477846854, 0.10665057797826107, 0.1683719224867321, 0.1709005029331292, 0.11665074500225245, 0.15699092028362138, 0.17810028917606802, 0.16448111513689642, 0.18965739967121234, 0.1496425436268891, 0.11603585985158721, 0.2120673866762269, 0.15934958242841307, 0.1854592991331893, 0.12196592430794433, 0.15471839706503576, 0.09369549491713125, 0.29414696618914604, 0.12956852724234905, 0.13922394703953497, 0.11412175852925548, 0.15246470428762898, 0.09478408287489608, 0.16471679442592208, 0.16947179491962158, 0.15101187982626502, 0.10177812854489011, 0.1079398503286704, 0.09530398078382978, 0.14809642497810627, 0.11074256001701278, 0.1812910147371792, 0.09930308998352098, 0.22418531949722, 0.26860865914533216, 0.13445031528751697, 0.19358812020190302, 0.1746301713489717, 0.2529147811113827, 0.18666902857442058], [0.049165259190504594, 0.08466081318235205, 0.03785907696451872, 0.058169523404250224, 0.04990727280176455, 0.07052948638316124, 0.06347970781667579, 0.0339601184391687, 0.06953712672956529, 0.06417113664229551, 0.04903102909485179, 0.034536503841199225, 0.05741325672715903, 0.05104735718979951, 0.0481164618395269, 0.05401091469872383, 0.06588204463403072, 0.006073268314432954, 0.023570125659687385, 0.021033744523001295, 0.0872415182511172, 0.05433760523315399, 0.0450588938509745, 0.08265355556842782, 0.06163343208872023, 0.03352336022221754, 0.02997404039506951, 0.021660168873026006, 0.01692600214042731, 0.045905279281038436, 0.0502863637502155, 0.0806239664915108, 0.0831651644060208, 0.032872323382405505, 0.05113717333804216, 0.05810275501120956, 0.03265258638308414, 0.007636313675902785, 0.0447543355966768, 0.03351437784130535, 0.028967262966738596, 0.060427379869525476, 0.04110960717943888, 0.0410487606460529, 0.07037878922757602, 0.05933122296306876, 0.012644049448652134, 0.05649724156565725, 0.020448129676703005, 0.06388783732789659, 0.016589099653966485, 0.006551751988985006, 0.021119728316402724, 0.01493324178286017, 0.0586398056287679, 0.06177984681280871, 0.03441018743380424, 0.03777431699657633, 0.09203601823819262, 0.04376980536166699, 0.04125240213808514, 0.047068526337464014, 0.09718346259286327, 0.005870153986653614, 0.08435427842120971, 0.04494231442109712, 0.04009828301927736, 0.07830881814081823, 0.0684094759485414, 0.12559810037454291, 0.04090815286843046, 0.0355568218735918, 0.04783526926691975, 0.05272326262427434, 0.07839999026468686, 0.040566508297718344, 0.03145997517652089, 0.07498263291293576, 0.07691438490104291, 0.040340872421380014, 0.01644180584398489, 0.03951723980266721, 0.01431385682324969, 0.06070208750785359, 0.06568835462413489, 0.03119565569044602, 0.08841141112028592, 0.07932226819496963, 0.14273722626028523, 0.05447008481789982, 0.10139255649259976, 0.1518517266958952, 0.13405735814763656, 0.11750338554021814, 0.1625452875610321, 0.08694419952770395, 0.07671872604518168, 0.1137680787172529, 0.012068326712676115, 0.05515770235609624, 0.03721220764301477, 0.06076870651374902, 0.010786348476915831, 0.006878375969526749, 0.06328005381228943, 0.03218735650842709, 0.06518278255938523, 0.04888933730281649, 0.07608953803297012, 0.06479646740180832, 0.029247607096969604, 0.0637374466074811, 0.0075578107310819535, 0.040781284877729994, 0.050737520589703516, 0.07152461161416385, 0.04202959067638844, 0.02489515707918233, 0.07603621065256096, 0.0162490006656416, 0.02943947956326508, 0.04505829247195394, 0.02085800969883079, 0.049099322002861774, 0.033732552021261186, 0.027538662205540368, 0.06448040250688791, 0.07723728330024789, 0.017748594794782902, 0.03722764814512865, 0.0843200725953906, 0.04763170055324032, 0.11225431962239166, 0.02396679258034114, 0.0419596774924186, 0.02924423822532258, 0.005048900549750655, 0.029306576714941093, 0.07881546272866188, 0.018698495940395424, 0.047548457439388, 0.03454702605883922, 0.028408635482792894, 0.04824274377296529, 0.01333651536579935, 0.06805071697360085, 0.03621524380099389, 0.018280137240165667, 0.05349105509418634, 0.012629922787328402, 0.04847461560500726, 0.0205079056022148, 0.010643586077006354, 0.03922945504347163, 0.025885034607903614, 0.03752517371228145, 0.04491631722738666, 0.041980867484404195, 0.05417956895525417, 0.030379904201254252, 0.04109872107003485, 0.03300697099597704, 0.06587304310092042, 0.05112210438857156, 0.04323710612351856, 0.026623286727455356, 0.03392873564735055, 0.06865860008063816, 0.05496739462438611, 0.08397164048566934, 0.06018824552396133, 0.03625153721640668, 0.07583377957944909, 0.053220733309224735, 0.0445034877667504, 0.039522487504948536, 0.027462396237458435, 0.0635074516908536, 0.08876373495666251, 0.0675356071141939, 0.023891493798263615, 0.11313354341132988, 0.06092824432398043, 0.048347483313972914, 0.0621793118696059, 0.04489411599934102, 0.00904360378626734, 0.03491108253177616, 0.0716353343018601, 0.08808858166899412, 0.02174217858532023, 0.038072654616928873, 0.007185536528742242, 0.03569169931354062, 0.01945650546751436, 0.032109472179605116, 0.020997824575451594, 0.04876437687104748, 0.023368378320047935, 0.019919818207140894, 0.06382548926217903, 0.05802943273597668, 0.05173490578008275, 0.020109384748784286, 0.017940051658379457, 0.07749937730090273, 0.026677039286662495, 0.06510097969083056, 0.05446700897488383, 0.09064377600988073, 0.028013945068983782, 0.03601889929644043, 0.017946988584533814, 0.03756118367516226, 0.024802395322870825, 0.046424460897762934, 0.042841624723927635, 0.019863288579208237, 0.04856464242742908, 0.007279039953925437, 0.03051161003719655, 0.028002244991160212, 0.06225320104990275, 0.038960362829628496, 0.01862064608553004, 0.07424494386800835, 0.022767614085046996, 0.03132496367118532, 0.01771772528187402, 0.01034395089523206, 0.046621092685288, 0.012215607116119036, 0.027042662409404596, 0.03446353779685113, 0.05012735454065185, 0.011258699138829065, 0.09076410544014747, 0.014854127882919727, 0.034059185099097035, 0.03794888928232174, 0.026337951534397663, 0.05703160321460136, 0.10097161416084537, 0.08456146690033137, 0.0990014352024563, 0.09300838299696484, 0.04006902229100947, 0.1090990562712954, 0.010301033692103962, 0.07626917799033466, 0.0483601161038443, 0.0599951300800087, 0.07739586350057395, 0.07203190737674314, 0.021583600300213984, 0.06115260466392483, 0.008689358984420617, 0.014548928987595343, 0.019395532529620875, 0.059440823331955946, 0.038529105123973666, 0.03707131641286035, 0.09772230585616443, 0.11478276983384164, 0.09137566576922133, 0.07507900677381024, 0.029302483890205625, 0.04844780635809706, 0.07285351369289622, 0.04404899461435215, 0.0497492480151836, 0.05218536164912005, 0.14249721091360817, 0.07234512242458521, 0.07401492596874315, 0.0227945861256411, 0.05022121563313469, 0.1058308179340055, 0.046920192563125206, 0.01860783326499645, 0.0761601023916756, 0.04842976498748026, 0.02982668146761435, 0.032824776135385036, 0.012307508938735532, 0.0838200776507297, 0.05824204511760224, 0.026007535897435683, 0.06583044095145119, 0.04377170909015883, 0.049654371856201085, 0.08602829544895119, 0.06520237142760908, 0.04428843539508601, 0.04535483744656367, 0.04023208410569257, 0.037971630602354006, 0.048964655237092126, 0.034709019180867946, 0.07440567677540165, 0.010223969077360968, 0.06618385263268026, 0.10547694660002187, 0.014517764530835614, 0.01643095995419689, 0.05545360381684958, 0.06854801528876828, 0.044126913417130716, 0.05497173451247716, 0.0803944695320341, 0.02874299838778473, 0.02215209882706404, 0.051676483914977124, 0.03229090478271246, 0.047158782986263116, 0.019663676709657716, 0.04312021642803185, 0.07193315864330338, 0.03952940910934441, 0.05119872850275809, 0.07363171346725957, 0.01469309237079635, 0.01954186106881788, 0.008772031362769345, 0.01642754703249422, 0.03069840334055405, 0.03228093797881757, 0.02842467544870752, 0.041726392228156335, 0.027967518225552577, 0.044001635058873126, 0.06629327297090523, 0.04616540443572787, 0.10346945915972033, 0.0007191756923284923, 0.05865566747924013, 0.017407647364081878, 0.03377892715375751, 0.0568724139743755, 0.09056457017938938, 0.05736706545576454, 0.05247630652100329, 0.04236343264159176, 0.02827390742998931, 0.029483600482044202, 0.012562728257879857, 0.018548411655149633, 0.06865933552504548, 0.019269170156950434, 0.048693218794200695, 0.05358645602339699, 0.030219366646281658, 0.1410356377281489, 0.14623325318098068, 0.1077110351874463, 0.13622694979271582, 0.12886069264383088, 0.1790983638455791, 0.24283448895139081, 0.12553089914182503, 0.1302463771595109, 0.13715843609984846, 0.1967415985681357, 0.1622539596451867, 0.19125882986812823, 0.23504375780542053, 0.16867633518432418, 0.10832635700822839, 0.13638595900227948, 0.13547364021501235, 0.07507817173797278, 0.10204759231137653, 0.08064518712701337, 0.18848899301261673, 0.10480106552882541, 0.1480475332467787, 0.14780842188385226, 0.11693723890329562, 0.16311156443290173, 0.0875304329900011, 0.22161054394898877, 0.16744405211460206, 0.17505665249641866, 0.19254538260640638, 0.14080982565158798, 0.13493265956640244, 0.18103013115544475, 0.30219395374578817, 0.12856608587166957, 0.13003723515618232, 0.2042812673795608, 0.13649054532570226, 0.11684453460357844, 0.1346136145894566, 0.2277323065866386, 0.11182247585947476, 0.11558623518794776, 0.1935101171294528, 0.202775536886146, 0.19658943818461513, 0.1577997712358352, 0.2256980673560212, 0.09171164128929378, 0.17395688731583858, 0.1378945393427726, 0.12467307218861197, 0.1637704306912999, 0.08427833612527579, 0.1299850798902973, 0.1821131956192755, 0.18585168936800572, 0.14961582248009023, 0.14354454503665048, 0.10354209195582137, 0.18640100505323182, 0.11250074712499497, 0.1702311412701684, 0.19994324854304715, 0.15758059348069853, 0.18219889021448551, 0.24843558759218265, 0.39139260447794394, 0.15231242133004053, 0.23290833368176417, 0.12183159079042175, 0.12256233141787591, 0.16896577852387584, 0.17725978347082294, 0.15688284059926388, 0.2856417967667503, 0.16933771421111402, 0.20432680364578001, 0.2054661755720454, 0.15102410658953652, 0.11201405912757882, 0.16518784656880364, 0.1623645980632113, 0.21968757132849387, 0.46036889355990196, 0.2844607956226795, 0.44013684855834134, 0.3573011402641574, 0.16047418417949832, 0.27187519676743016, 0.24451646563266557, 0.31903560002965314, 0.31797181033799726, 0.21414438893477764, 0.3814253715738174, 0.24970982163663835, 0.386421429293771, 0.12018023464348047, 0.20668149745512396, 0.18714717469148098, 0.10855278195512873, 0.09069210083614435, 0.13481823667403192, 0.08883449849822829, 0.13139598402044467, 0.20064948967868285, 0.1595890921570601, 0.2276138847153033, 0.11343890605794807, 0.10081940015117008, 0.13950419732399527, 0.15108744673911603, 0.2279918724971433, 0.16980689709946034, 0.1317691148048447, 0.17162407297761212, 0.3072367121856059, 0.08065270244955056, 0.19725752814162165, 0.2488352403405213, 0.15818482234833703, 0.1656835360993301, 0.11425994546903719, 0.1687638377470355, 0.27598210219894687, 0.2103090310289014, 0.15485506715072742, 0.134874053840195, 0.11052040984072994, 0.1165181351825595, 0.13551579037260625, 0.1127822231501341, 0.10108277351865846, 0.15191351934786768, 0.13076771531374226, 0.09824411898490884, 0.18162927319926603, 0.10438995976601878, 0.16097474602922318, 0.13943829844074865, 0.1621688013115237, 0.12710560819194203, 0.12212052851194337, 0.13627415613060997, 0.09001304816094138, 0.1057208230298373, 0.16997523725994174, 0.09954580962057076, 0.15299839177919974, 0.11987468047488122, 0.11892692246023687, 0.07568287558012432, 0.12834110883094613, 0.10960525652814297, 0.1619405377536051, 0.16326680448987793, 0.14174587784274933, 0.10797560365209657, 0.1870365515952149, 0.15839964872406376, 0.15463440318501767, 0.16328241736177476, 0.1460408425379184, 0.09095927399973716, 0.12861612673488357, 0.18247809861936878, 0.1491448163024841, 0.15234933144623233, 0.1552412520733572, 0.21512222356132923, 0.13298872678029922, 0.14462152676236245, 0.17587881805675645, 0.1665330663203232], [0.10016780406717332, 0.03847476650750445, 0.024567708117707122, 0.02813453305392496, 0.018375601371630065, 0.005114448947771903, 0.06327174941919024, 0.0271664411505504, 0.0781102787943617, 0.005405665780868261, 0.040171930881878065, 0.015571767449258797, 0.060962377371446747, 0.056158140406853733, 0.019134461256344954, 0.02651936881574652, 0.05762199270388773, 0.049795535047568625, 0.008899690339251632, 0.07553088373594707, 0.034144573259137334, 0.05340076397143064, 0.030120457034377806, 0.06737848248092398, 0.009284006964956081, 0.09349058938002394, 0.03141724853776395, 0.06561916922369311, 0.04213845560086831, 0.07342051834829393, 0.028867667706142512, 0.02988791487540209, 0.05449249288968502, 0.028234944198160406, 0.021790945827360117, 0.03450001124292612, 0.03450442390936998, 0.08449844850768005, 0.01757197705427966, 0.015586508896141766, 0.02530564231077029, 0.017023992446822026, 0.014008135072916988, 0.01157663616111442, 0.016227845147612597, 0.05788161607098676, 0.03301186246737357, 0.031096567963099772, 0.013648135035539107, 0.02809123376444463, 0.04366562123440447, 0.052184553426359935, 0.018929251199287754, 0.024708838750337882, 0.04576645265783995, 0.07959740101209573, 0.0483683668707888, 0.06506291278187307, 0.039607025307392886, 0.05007603814104392, 0.08623272601154544, 0.028510691800845728, 0.03191420402858527, 0.03560840640397322, 0.04643791723215292, 0.03326750600770597, 0.010790660594319625, 0.03637074049742472, 0.02573146462260235, 0.1307097224578742, 0.03132069847666689, 0.029160897435259917, 0.08486899757577528, 0.055531220014898054, 0.0879408875780721, 0.03517368215046102, 0.04905745529779985, 0.1255714175321402, 0.12420275549013769, 0.020350535820809104, 0.07437740047011646, 0.015737084435268996, 0.06654352325225069, 0.02677172009322432, 0.03921404518487473, 0.0740477604971778, 0.03573187679472951, 0.09340424361007829, 0.0848123377128955, 0.044778815936297185, 0.08099695171920523, 0.042394129784717675, 0.07997097612749185, 0.09113569638781971, 0.12075971887116471, 0.02801945324115936, 0.055378508048071984, 0.0704883704442651, 0.10953895161829649, 0.0027500109788360858, 0.0031329958085646674, 0.07327706072359316, 0.010720749325569599, 0.0444076118630267, 0.025184726823241483, 0.039311897595443075, 0.0925308037849684, 0.030451112073816122, 0.05347515110887828, 0.04192223877555901, 0.014607916800155035, 0.07382984678711622, 0.05193813358463588, 0.07011124068090031, 0.10053405538201333, 0.06283434768838268, 0.049011451717946804, 0.020479974036495534, 0.06008218831172394, 0.04450517316018382, 0.02016206095445781, 0.05311507063226835, 0.03289478124990579, 0.027799785189751177, 0.09554065598715698, 0.019604862224490895, 0.07492965793297177, 0.060061898473049366, 0.07658436954502137, 0.022048412656952298, 0.04154707019728038, 0.020672924771544435, 0.1027911649115624, 0.046084513211803096, 0.013050799043999325, 0.05338227060893851, 0.07718559534799668, 0.02702704762228795, 0.04345716104932851, 0.013049625014255365, 0.01978551150269566, 0.06114195604177733, 0.05144602934559507, 0.027244350377229914, 0.03696299158036709, 0.01957769674669591, 0.1440320527481456, 0.11949498431697009, 0.063797565357339, 0.03598852774068233, 0.037848566238197594, 0.04734342932821282, 0.034640737764176824, 0.036668492060515194, 0.04010862520625515, 0.07292430787797897, 0.03571040718065154, 0.05479286830391615, 0.0388581169048144, 0.04292181114696207, 0.013145973019662404, 0.016701881202959245, 0.03474881361809469, 0.06904591881339589, 0.07914395356971411, 0.050033903305208495, 0.05111745040443155, 0.034793422917925546, 0.043879455526269255, 0.04530619469381148, 0.06687806618790473, 0.035483671968141874, 0.05023852155934419, 0.027814499823556795, 0.02527289013678749, 0.0392485268023466, 0.07836364705355899, 0.02800385569102101, 0.007653057963902792, 0.07144460905223124, 0.044092263260315505, 0.014876702578828461, 0.009375185792094037, 0.060333235324510646, 0.04679701711621977, 0.020415978881740765, 0.01902040608617808, 0.04837584388892978, 0.08940321152969714, 0.02578746181942763, 0.04479957308860556, 0.03271010809487874, 0.056195977489433946, 0.04736700568408255, 0.06792676394745227, 0.06462038209241244, 0.01934621370427551, 0.04328964443336572, 0.05973692780600921, 0.0031762314169862943, 0.01748986966577509, 0.04031715816968391, 0.014271156997570108, 0.01932023949320278, 0.12424902720076424, 0.050990850544504585, 0.029700690647587184, 0.009700657289114692, 0.07022185611628717, 0.023769243402526747, 0.04323193503002967, 0.034822587885202906, 0.06134452118027595, 0.061903455099391366, 0.04284657748235811, 0.04310627745824956, 0.008147364226920951, 0.017817875956215205, 0.05136486616045718, 0.05643240754462539, 0.018201036746763898, 0.008591194393023128, 0.03069349271695941, 0.01450692151387733, 0.030914953414110408, 0.017610122487249396, 0.02602574580739583, 0.034693927248759616, 0.02124917802340802, 0.02410095947374019, 0.04112725018433506, 0.027784735392478686, 0.13450562683565004, 0.07014557674166656, 0.016089196639856505, 0.0054963614938089685, 0.02397156913854903, 0.029881970033109672, 0.029833032336506634, 0.04130949484064214, 0.019110532500030055, 0.07074112583312296, 0.05060510995287088, 0.013395662141603329, 0.07772075372838205, 0.08050559824633022, 0.07968811348320977, 0.12676783236524752, 0.034495908842091604, 0.057443195443239906, 0.09456770900156229, 0.06135913813787122, 0.023930746228283933, 0.018469581207741174, 0.10726187783744066, 0.04654466392352216, 0.042633605039408135, 0.037665268210994626, 0.02006590925908137, 0.07211754068491921, 0.05917948392790653, 0.10972551701049651, 0.05319220802536415, 0.062141762069997296, 0.05071578284485206, 0.012422079303031488, 0.019616169682253274, 0.019165441852002855, 0.03301742426570385, 0.10104432356573882, 0.03642767998239687, 0.030908826625935977, 0.05805252645645411, 0.04185514479515053, 0.05583450273280183, 0.03707683990679441, 0.0423139012268474, 0.14780385599982354, 0.037447136165874625, 0.007580481666786177, 0.042013675199761506, 0.05157513814347406, 0.05058229968492543, 0.033955089071945804, 0.05125953290130823, 0.06592200378016119, 0.045223855563709815, 0.04234352201643971, 0.08533818812500085, 0.061830657594386614, 0.07126657021862846, 0.061405252800473285, 0.09069984598505883, 0.046705998209936005, 0.028854201795653473, 0.05070278999365626, 0.08308081812555752, 0.06008996027371576, 0.043459685309039015, 0.046297531620028524, 0.05829344578688184, 0.034852890493047815, 0.04728754321413656, 0.02838149873329507, 0.06023707979869458, 0.053199217729871316, 0.028037557814029918, 0.05879401146704632, 0.0640187770759146, 0.03084612041411381, 0.0321969326074806, 0.15276122627960098, 0.03526989896331103, 0.033304883437531616, 0.008973069113468932, 0.021622938915125785, 0.024525261101042552, 0.03551541865172406, 0.03144671610977141, 0.055828247624900074, 0.008397357868811777, 0.05583035436669185, 0.0026519014500081543, 0.06335168303320966, 0.01343182532206899, 0.016591660302853393, 0.03840196134162046, 0.030032014098739433, 0.0798847376098556, 0.04334824249869393, 0.07267574299006693, 0.026268992129893556, 0.0487984562923591, 0.07099496906683331, 0.06111865547756034, 0.031158933265795632, 0.004862629143791574, 0.06340183497917268, 0.05415775843204991, 0.03718838996944889, 0.008604274386720312, 0.08145887975490863, 0.024441154223055612, 0.01588880144540341, 0.03370328363211405, 0.06395576251370293, 0.03809639951214194, 0.06004854556052916, 0.02632046749274577, 0.016737718796057087, 0.021982107747105822, 0.007542900266050692, 0.1374444626872578, 0.11863415429909384, 0.11586774185660387, 0.13984875302881966, 0.07584848846759527, 0.09354279827206366, 0.1366996107202384, 0.1855894881150415, 0.142551158825236, 0.13681210307103975, 0.1588338213942705, 0.21502034918915844, 0.19429894254332591, 0.10826102503004575, 0.14621580169806558, 0.14250117924905595, 0.17790813900289998, 0.2027592498568758, 0.09979653487642927, 0.10123809018442709, 0.11407070642998142, 0.2016629473937135, 0.12024155232093989, 0.10422882083202563, 0.0706846115269488, 0.1403091871930707, 0.09090196296212175, 0.22747126978731927, 0.2004283967037355, 0.1421831761516871, 0.11021192921625991, 0.13416681679025774, 0.15646377518292398, 0.17990179089528902, 0.16254277479264045, 0.10139384352031255, 0.17839008491606484, 0.14942669069334386, 0.12208925680287423, 0.15370875446786805, 0.16469126837628503, 0.1180334417750278, 0.11866354909274848, 0.14358599039335407, 0.15541452584007096, 0.1254844129265797, 0.10260093761908431, 0.11663911578756188, 0.12052105183923438, 0.08633792520530763, 0.10316202041482735, 0.16257910268200984, 0.1729068718850613, 0.13369282286974693, 0.09262212146554263, 0.15828881112317886, 0.18031944670984823, 0.0947509955374464, 0.10031010489910842, 0.1407840391320567, 0.1757710294858102, 0.17800757721547159, 0.11860281364211153, 0.06868011949043121, 0.12653300343381782, 0.24555197135815698, 0.17906721471057785, 0.18074785839886437, 0.09011577289070814, 0.19074873788462532, 0.16683599280734218, 0.2687338685556766, 0.13478713350430613, 0.13750139834179034, 0.25206200267759066, 0.18741835449491778, 0.15334838670828652, 0.198591762192307, 0.3782313058693563, 0.18032215866110018, 0.10554161974258962, 0.17046931800582718, 0.12513252576031994, 0.2163030561660567, 0.11990258139708351, 0.2647359314705095, 0.2120221568451774, 0.3882195908696421, 0.31996296478375313, 0.22031761735918062, 0.3219571529376892, 0.2057651643671336, 0.1967974157342988, 0.2780208460265591, 0.21282510892037423, 0.18852783367037776, 0.10951654354651129, 0.18949839046164868, 0.3631790877590257, 0.11786748414799092, 0.16243809653866678, 0.2482389787872953, 0.14782749747316684, 0.09736869499207505, 0.17370127441902317, 0.07934387953531358, 0.16562957286594376, 0.1595649297439283, 0.21563242279714157, 0.15698368841361615, 0.15002284499426044, 0.2554307823940631, 0.1637066615324828, 0.2604603028345493, 0.26130989434257634, 0.12635898656181752, 0.14161967251810337, 0.08302284825232722, 0.13514717950695945, 0.16328683002821862, 0.1406863169564355, 0.1486451431147514, 0.0909464113834885, 0.14815542907003434, 0.22013729558356349, 0.07653029139844642, 0.1394856273527107, 0.14575440226302994, 0.21732693267685754, 0.18249142854925127, 0.08754390081570995, 0.09184407490876415, 0.209434817454988, 0.11381421253205308, 0.2989072220460061, 0.32992336418359514, 0.1716021475412192, 0.14477494353007886, 0.10040504617556449, 0.07993707673684244, 0.16902921060400625, 0.12790590194204163, 0.11925942760201232, 0.11149169441552893, 0.13154953868398744, 0.2638859415967619, 0.28653799706409055, 0.20035040895304373, 0.1568208794079481, 0.10919610428954325, 0.09277360769168985, 0.10518532757076526, 0.16068870412005534, 0.19499998960283496, 0.157089255329582, 0.15729246781237666, 0.1455823695587535, 0.09857784986736313, 0.12514058500528336, 0.11936132495682086, 0.12290324054418073, 0.09023078567078037, 0.08333846881625154, 0.11754665418618149, 0.11807449642688998, 0.13403252157713139, 0.2996826562429628, 0.18530222046519482, 0.09258230787611778, 0.14911550577850113, 0.24083973389239083, 0.23940561729813778, 0.1607532546885552, 0.07695986754110745, 0.16025005749637083, 0.1010849262257257], [0.01938486667049508, 0.04025078048148463, 0.024994059030206937, 0.03874424559574935, 0.031706283935495926, 0.03156051464048365, 0.06820113067665408, 0.051425850589669524, 0.07011076570638726, 0.04181314785514147, 0.03687254724002654, 0.0406820994741734, 0.023347138532347256, 0.04205683276297585, 0.0008223643840944034, 0.05185793567028257, 0.04156196294652839, 0.019809338752360597, 0.019976116093476454, 0.026361284657351436, 0.06021130477048217, 0.045310523090583664, 0.021714766044169668, 0.05719795537691924, 0.06791708059608936, 0.038860070429021315, 0.054572625686564756, 0.04762434610916723, 0.026013547772421472, 0.016111623863839818, 0.030532493594012437, 0.03844035383794577, 0.028684317968004656, 0.04305064798362794, 0.03114032690533467, 0.06861284930980013, 0.047336565180411266, 0.05635328981424532, 0.05081769552141909, 0.026113495433462725, 0.04452298470442334, 0.02027169388208178, 0.04000642141627689, 0.01398877603107042, 0.0233257589336004, 0.010514696571795691, 0.03430198134493924, 0.04328489468823518, 0.05198861111796672, 0.03588770290896778, 0.046314473654473984, 0.02459435648615322, 0.05288149425459485, 0.008987238867238404, 0.0668099609714362, 0.00492651991906666, 0.011953887540937192, 0.014383479851418206, 0.00977268296053573, 0.07594054925345606, 0.03333347000842614, 0.022998802183616548, 0.03379792613427966, 0.04554445569914195, 0.07594044200114666, 0.09841523238367612, 0.0668818200187337, 0.04179375050889869, 0.010013338948239484, 0.13570673012685391, 0.03463442903012037, 0.07723349882590194, 0.04433981308172788, 0.07408147602672539, 0.1190569352418665, 0.038768289265252893, 0.033834399580354654, 0.02121983877112789, 0.0267529777521568, 0.05314533876615667, 0.0458804503714125, 0.038546587250405745, 0.04680666216318646, 0.045387331065872026, 0.03363505584157763, 0.07515438982555944, 0.03775139181544224, 0.039545565903667486, 0.05931284068332565, 0.07113569941852363, 0.04653960774322191, 0.09835081205012337, 0.041259411842592304, 0.07622501302149988, 0.06939514765455838, 0.07667880520344743, 0.09186402383831241, 0.038155123981977665, 0.02879669923605698, 0.02577614670078601, 0.0166392324477314, 0.04242823601910665, 0.001314583416622613, 0.05562468274166027, 0.05415085597985214, 0.055931761425228856, 0.05218915761478486, 0.068592241544637, 0.06832827062856767, 0.018265891835213672, 0.0369524157365724, 0.0449371203449705, 0.06687608968106008, 0.03193653166113842, 0.07863070530396316, 0.0415844974228211, 0.04628919658341235, 0.04555516943876301, 0.029522688203160802, 0.009839412091570276, 0.051356971624397466, 0.07730970925260937, 0.08396920432607013, 0.05820266819829422, 0.010981105264246224, 0.036478839333980315, 0.006706423704482376, 0.10105108812211022, 0.06362268280598425, 0.08501645417944079, 0.05664043105958451, 0.028866524319915526, 0.07121346500371734, 0.05027854965338784, 0.050464571123161626, 0.004905258585143114, 0.043800219052260926, 0.04932148750090311, 0.016816020642797795, 0.007629643444107065, 0.048447825510295174, 0.030845836961581826, 0.03982907589224558, 0.10675960761164466, 0.03632174151378774, 0.030898587860827966, 0.021124753853186004, 0.04382352344691754, 0.08883771606751027, 0.015496739670784484, 0.06718100033580296, 0.019489581313645168, 0.038006851494672804, 0.0351862957881343, 0.03268490763260953, 0.01954956216767671, 0.04796999731972333, 0.012788920505573193, 0.04472043620602739, 0.05016206981494062, 0.04333956655295145, 0.03750316400621687, 0.024735739927798994, 0.0500651175576833, 0.08228852233338742, 0.06158248724175557, 0.03210980159741256, 0.014350146408222858, 0.07601791647292915, 0.03364548229822709, 0.0583272838904973, 0.049698398929209485, 0.029868574985753626, 0.03834567686182357, 0.03713688204785989, 0.02742005264266364, 0.029686824456157706, 0.08687987878558137, 0.04762952103309574, 0.046971872854497165, 0.016476775842508482, 0.030582930907727252, 0.003370388979918414, 0.04401994839070305, 0.03924111490167918, 0.01579291021992122, 0.016621162348817435, 0.004253957923802157, 0.036082882959876335, 0.013667586965546494, 0.04473760040597089, 0.048943629954010255, 0.026098989558616476, 0.0681951551908447, 0.053861148339966615, 0.029420202875870372, 0.08115814427935308, 0.051459581440975594, 0.021386340320591005, 0.04215633609302102, 0.08013977594072781, 0.004942738958033583, 0.08264227875418241, 0.06406238663100428, 0.01469708177366204, 0.10343706130140251, 0.04044391124719574, 0.06255550317526345, 0.05065134335910121, 0.01800285363119216, 0.03444431665083093, 0.03664020043347151, 0.008771737376528402, 0.05137432351588242, 0.05278182621564596, 0.02699129238364197, 0.04532308693254187, 0.05702009657397867, 0.04939615809088273, 0.024113858479165265, 0.02470555606358234, 0.026771928852183685, 0.01653642153307315, 0.03056481867397745, 0.016917496649247986, 0.049341712222104116, 0.006170563874841338, 0.032702696194211324, 0.03473295942850171, 0.058799550282738866, 0.04929299669099912, 0.07675812594712743, 0.026058999768969034, 0.11410501184723071, 0.02120178590919222, 0.07664522756972621, 0.026603320560928796, 0.031741183070886525, 0.019804889696740338, 0.04326803309302177, 0.042790499846300775, 0.0514575244948989, 0.010769096176861035, 0.06115538556308997, 0.07774537579426843, 0.07611019942428797, 0.07308407551458768, 0.02214145403535616, 0.04229024826218525, 0.07532092967941877, 0.02083081549273864, 0.06274843475811424, 0.029634016100317243, 0.1007469741988086, 0.04722152941770131, 0.08749611225099334, 0.02017460181377828, 0.03365786610952309, 0.04058870569532437, 0.039112389147762334, 0.041413058436685996, 0.07058221621498947, 0.047912372186058955, 0.09184101055706702, 0.08111482200723502, 0.1050761447197968, 0.03919621831887672, 0.09845813330743583, 0.06764180222225767, 0.06658890630088507, 0.12792523800125047, 0.06125116953626276, 0.11059197011373698, 0.1126339621541481, 0.058093826256452076, 0.06047102006813211, 0.040310964348816106, 0.03491040454396317, 0.04567592404782773, 0.08294484517987698, 0.05716356185955867, 0.020061803027807225, 0.03854387146871417, 0.02976915975581975, 0.04336799224538188, 0.05699790300681226, 0.08047065697610378, 0.05596462659718049, 0.027681886173424222, 0.0524444870590683, 0.05032836452066418, 0.056220618707518426, 0.04251899828593578, 0.04797841279557155, 0.03828044447507109, 0.11437481269240381, 0.031241483070076476, 0.035520218192569675, 0.05004066403114027, 0.06061039061375684, 0.07193302840835626, 0.04657908808439971, 0.016011173457598254, 0.05300856142815563, 0.1179703008083086, 0.0902329920040023, 0.0344014463705882, 0.03964593491306709, 0.05389632709744958, 0.060951506583801204, 0.04394470706521984, 0.025414170156563484, 0.030684579283960407, 0.07282432574298113, 0.028544769306937536, 0.06647822191758503, 0.059655339442073345, 0.017802464182398493, 0.03505054883839142, 0.11354115581320179, 0.016928572365413272, 0.11174371435997948, 0.04252500058482251, 0.048819742045335235, 0.06342657961912694, 0.07377055158177692, 0.031084789361263958, 0.044166638906444275, 0.029909240847994244, 0.09133124033049231, 0.07508657572250213, 0.03961328424573426, 0.03417593306831775, 0.025233239341046543, 0.05561342507961297, 0.017450280157068086, 0.08709924040181984, 0.07311147847963918, 0.07613643793569458, 0.05597836638410246, 0.034637068203019525, 0.08463354045224768, 0.05235151845901724, 0.08100686489694542, 0.038487429940892805, 0.044047140681575385, 0.018782472583435236, 0.01426186147821887, 0.07428649647702133, 0.059744148184695554, 0.07374407558311379, 0.028002036232200843, 0.1874921134402675, 0.2277729552119009, 0.1519701179237135, 0.13213270013370823, 0.08339079262147989, 0.11349034886206351, 0.07134664172847426, 0.20833139037412984, 0.11730634772609319, 0.18948881436259518, 0.09811157811312907, 0.1343406268185185, 0.13489643892934247, 0.13209018225391067, 0.1598184282380727, 0.1968662717169331, 0.09172984353837468, 0.12793369561193452, 0.14510874336044635, 0.15798104296047843, 0.22191740812793856, 0.10853929114678215, 0.10928284076433029, 0.14697730841655887, 0.12802161186212493, 0.07703665253375808, 0.19293457059369934, 0.13397210788342262, 0.09739592941778322, 0.1509029574451908, 0.16069837214965976, 0.13579472298583678, 0.11386736371223966, 0.18536542271894796, 0.12036862332494029, 0.11826125334107107, 0.13068874697050742, 0.2166297007352114, 0.2432976503886523, 0.17200271959506697, 0.1540566656378008, 0.1028248114931968, 0.18710906947812728, 0.1494973546434795, 0.14049707791737973, 0.08493976111734107, 0.12148372558576447, 0.07712487521911822, 0.16059996049490669, 0.11207340029819358, 0.13010066723631275, 0.16503102837070344, 0.16349077795542058, 0.14540642980606328, 0.1329183845870918, 0.19195269102290755, 0.16157601779747396, 0.15255954597265492, 0.10811913788558976, 0.22412202531291595, 0.18734032077895058, 0.14883401443160352, 0.14612681292478116, 0.12464238270636528, 0.18679984574837072, 0.3172968868767062, 0.12180891458786304, 0.13776978958518277, 0.19926336083200671, 0.2127152825555494, 0.2271515966182755, 0.21405345429816555, 0.22425918569487913, 0.20424890782563918, 0.17784695922126695, 0.15943754464387894, 0.12237595754765695, 0.19704147602521604, 0.24888817701608906, 0.2015765786411301, 0.13878798172358545, 0.1373953870948284, 0.23948293089145617, 0.11040794813344557, 0.10796140804285966, 0.147293901912147, 0.22574292946486707, 0.25783047620807925, 0.264133878292576, 0.27170607519726603, 0.15051266629128687, 0.24808848847544965, 0.14558872808852505, 0.23477343602045891, 0.2781239614611672, 0.3187219023464188, 0.24823663455824702, 0.2444238915678955, 0.32821348658011806, 0.27292053906186936, 0.16126919958379962, 0.17759493161593715, 0.10683860659839646, 0.25359782510467116, 0.2083411043690097, 0.18386873206303966, 0.1785547325327512, 0.1551591580913913, 0.1326606113223299, 0.1518317011575545, 0.1783919082053246, 0.20949883176194084, 0.14919574582769027, 0.11633534660382618, 0.239997343610852, 0.17880240875867107, 0.0977157328217741, 0.2409248309390199, 0.10752178082663207, 0.19721015326438412, 0.15468468919636744, 0.26979453260860137, 0.1299968316790558, 0.1395288653551571, 0.1510799237556996, 0.13327043263181565, 0.11822712412404439, 0.15226682377678735, 0.1792841401672171, 0.20407926531568651, 0.13677905403798626, 0.11445157470241671, 0.10864865785885243, 0.14406926929950714, 0.17121890439621865, 0.10789206176395379, 0.13453084645011734, 0.20401132863856133, 0.11829276253739673, 0.15771076714079227, 0.10697104787874608, 0.13522404876928176, 0.11463971823574075, 0.2857880889167709, 0.1054919159580623, 0.12448577135200463, 0.13224808829686335, 0.15548652278319483, 0.16927101859642615, 0.1410276550919779, 0.15225789119159022, 0.10124061827457721, 0.16881082958031088, 0.2505454397009265, 0.12871548833866275, 0.1378778999130572, 0.12486682348554173, 0.15161520471015286, 0.07921548319920417, 0.1499043618358912, 0.1485693310537646, 0.1852910662250173, 0.11549956000019466, 0.14410663906845356, 0.19663080693252627, 0.16442932759321507, 0.10413860631806236, 0.09897207871319787, 0.22611377730725274, 0.09918565636560803, 0.1478510776594762, 0.08273526650643157, 0.12591935934558993, 0.16205552755103958, 0.11538411821088485, 0.10069574589931196], [0.045737992491452925, 0.05673221222335293, 0.0442604425423328, 0.03549251262278807, 0.04801235049061718, 0.0356598032428132, 0.03077939415590898, 0.038963205015827576, 0.043359071151503635, 0.07261646310648612, 0.05474242141410228, 0.06791882727655672, 0.030186288884931037, 0.03415572366887524, 0.021534796668997696, 0.005781244694991338, 0.022447042677912022, 0.06836114346139854, 0.025554952219188697, 0.02282097210897313, 0.004399134937087976, 0.06533775448558793, 0.03206039658717571, 0.06522131678197654, 0.05965031390529006, 0.17159808727522052, 0.06809456018550743, 0.08657256261475625, 0.07043357983592057, 0.05683083455228517, 0.015561221291371172, 0.07073584748732467, 0.022816224279062405, 0.06118605206269891, 0.12561542928339015, 0.002959944686153904, 0.03370287377507456, 0.07964823860675097, 0.029657736097672777, 0.040699895696654435, 0.026263037711502086, 0.01725404098960421, 0.01805328519924754, 0.04702549134831756, 0.031598510686308146, 0.07615716061404637, 0.039852089173490965, 0.029993692465547114, 0.10884601742990556, 0.004867831359602391, 0.05338029410209387, 0.05743219059020762, 0.05399216852721669, 0.0913920523899217, 0.02273105253886071, 0.04442120226280344, 0.07881567723328069, 0.0348292451892649, 0.04682380338049224, 0.038037889546925024, 0.03133935654806274, 0.0787204295216549, 0.02247592993831683, 0.04044952667168072, 0.03024196624004793, 0.04511233997501193, 0.017097891203217933, 0.021486690177792506, 0.07948637188922975, 0.11422285149174352, 0.0384948380111206, 0.016944872801222147, 0.03736917905869984, 0.05644174998686199, 0.08859549438761127, 0.0280931432385959, 0.024320851605866226, 0.007374140672430757, 0.08919884225413685, 0.045679425069641684, 0.08683456468486017, 0.020754777435814182, 0.023413029754714623, 0.05512718907407215, 0.044858113697339455, 0.053692210630904284, 0.07823217104399398, 0.045533872194468014, 0.08869048162934282, 0.05415373647044744, 0.03598175552343169, 0.06256223708811788, 0.07081763503412086, 0.010875651346249206, 0.15263644587849418, 0.10590233990261633, 0.01673057119572355, 0.07722841200208472, 0.07007251493632793, 0.07171509171565695, 0.04435866650554442, 0.02074963124018283, 0.0303872145952717, 0.04636037381245725, 0.07820947951967679, 0.012220549340840551, 0.03540688697549124, 0.07183969591654117, 0.10751648715907529, 0.03417199537638695, 0.016178566541883255, 0.02451771321976858, 0.03545669801232796, 0.04655278062507991, 0.042240195907652385, 0.11895691480247245, 0.05450667317716345, 0.016722931383898663, 0.06732501720468845, 0.1190643433120943, 0.03120505750449675, 0.11429749909908542, 0.1040859071297511, 0.010596462093564052, 0.04104905175946413, 0.03902649153925238, 0.03138183420824428, 0.0379849988366327, 0.05639318001246261, 0.009910665929407604, 0.032582320798669136, 0.03743466042402772, 0.08336269251641729, 0.022118913813404018, 0.02193997865692983, 0.03371007883200242, 0.022730087268076116, 0.04374707936339321, 0.037145895072289055, 0.032117489289732716, 0.08311122415527221, 0.020763685123153755, 0.013121232210147767, 0.03914916519856742, 0.13798613281499955, 0.0298894202381733, 0.0211296031897467, 0.02008131911767827, 0.04048860864713788, 0.060854703713689125, 0.019736435910266255, 0.09614494614182942, 0.021701167983513688, 0.04228380546274205, 0.046618089620624824, 0.014223538887416644, 0.013755962868491489, 0.0075295234132828496, 0.049249536523054686, 0.1094856012552496, 0.08401471760965164, 0.03767317806881282, 0.039322710926494295, 0.02798290318629194, 0.045139635687754046, 0.03723514048502811, 0.012202146951289428, 0.054347847828701626, 0.05542104124962803, 0.039110508401908224, 0.04944346785064667, 0.0615421335603441, 0.01010153769335199, 0.05723743188765742, 0.027118947529684634, 0.01517092822224743, 0.07426473957997176, 0.04400836514128793, 0.0558217014035871, 0.03248187135003748, 0.06547746594033896, 0.046267734630213636, 0.04907541239874498, 0.020074115975970225, 0.08087479133879946, 0.012635307427826188, 0.07690077917950769, 0.07348680027550267, 0.014963967654283249, 0.02696796692156744, 0.06210226640706101, 0.035186142570549445, 0.025139985373243693, 0.010832969715157825, 0.03834659233689308, 0.031134014340838602, 0.0238211726724741, 0.07585406558768404, 0.04127314779907465, 0.0440032055391179, 0.07967162727107925, 0.031098299321808645, 0.032250869027789564, 0.04832751906266616, 0.05290547663706446, 0.04336309694354573, 0.04732523857045078, 0.02842616165928062, 0.06562601804973618, 0.029955621726149996, 0.04466049365639206, 0.00663171241608178, 0.06604948081076145, 0.026240451524274486, 0.059600502868453344, 0.018845860613510013, 0.06772463930951012, 0.04577942635683764, 0.07857311081381575, 0.0613665079037028, 0.010098178397804018, 0.046171992791876684, 0.05528889491312927, 0.04646042489536828, 0.040756999890530304, 0.03427296959524674, 0.015094405614710866, 0.05728048602900198, 0.0813578250968168, 0.07667240836927969, 0.07615313099156465, 0.040032257731523246, 0.005208051964385255, 0.03261672963778819, 0.03879444733742745, 0.05473882463129778, 0.06620606152160514, 0.05627905972482217, 0.002182439657776887, 0.05020747584621272, 0.06490247098789101, 0.026091977938889496, 0.01756086111849835, 0.03985401588462053, 0.04338587273753459, 0.05954065991024818, 0.038394342597213485, 0.044073279601551836, 0.025021707143394217, 0.1093287141092362, 0.04091751829330479, 0.04198448724984642, 0.031986281410941196, 0.021055219882738688, 0.07589269174082626, 0.04447313919363003, 0.04853298767439781, 0.018563440385004206, 0.037051873101342114, 0.006832623283468908, 0.034327143502812234, 0.04932287412004606, 0.05851847645375998, 0.14920696135490172, 0.0830040178111484, 0.02077019878572995, 0.06861111795109126, 0.013017074895962592, 0.054658113438035213, 0.031625708722839915, 0.11409821664734233, 0.07249464746564627, 0.038263590540736914, 0.04878616441161402, 0.025152922683064977, 0.08307704131209082, 0.03809093730524182, 0.009554070195243245, 0.0805568878328608, 0.07582581992591582, 0.046642003055181236, 0.002029672867783736, 0.02882958356020672, 0.1368607036889561, 0.0253485259975517, 0.07049823765672984, 0.015988066330582144, 0.0442754770178468, 0.05171963381731222, 0.039815205870376486, 0.02457652195927597, 0.02261533878833777, 0.05498064028459692, 0.024521603031204115, 0.06286492608788033, 0.10126259733712482, 0.09399156491722792, 0.07021635560499084, 0.029791282459853158, 0.027840085245007952, 0.04793469598817249, 0.031766295433044434, 0.02166183702948113, 0.046661300809993866, 0.05647147419832407, 0.023328198923639232, 0.04009673552167031, 0.14775128704645943, 0.05675940068378564, 0.04359920524180897, 0.00669123696899342, 0.03216505568895129, 0.05164613151141713, 0.035090921672001, 0.03347726471181359, 0.01681630601054959, 0.013220707769505681, 0.02466225868932182, 0.07339279362631422, 0.03927095402632991, 0.07217152690094325, 0.02243988167103981, 0.02616576178209676, 0.039603853703386364, 0.04581361303045865, 0.08309666082383164, 0.034137425658803795, 0.051245605422844814, 0.047038572299624645, 0.06020000497359903, 0.018640058753531308, 0.03479960524747449, 0.05481241503730417, 0.05675756973364661, 0.041051599001812364, 0.005501250092375783, 0.030308351589126453, 0.028384022993005575, 0.007509028167283584, 0.022044308340897965, 0.06067610946634124, 0.021321657601924195, 0.02648071776474676, 0.04658302194589088, 0.05311564902865118, 0.013649055298658149, 0.04887046855724147, 0.036534736939375444, 0.012719861509638929, 0.11547681484972278, 0.0739746680483222, 0.04262716607040456, 0.13130029963870204, 0.1754070151477091, 0.174990784256689, 0.13356248067030985, 0.12835784785209164, 0.09085720044470603, 0.08949773911867412, 0.12123998705177538, 0.21478264742801267, 0.1736544970903666, 0.13338191374655695, 0.17824465078451943, 0.11077518004082865, 0.18568220007563793, 0.11987563808478656, 0.11452360228905756, 0.11452705734559607, 0.12164740027078699, 0.15814452612351987, 0.16536606926350825, 0.09214265001637321, 0.20544601213787833, 0.1625043784658755, 0.2199212281453994, 0.23396695994081038, 0.24077774205755806, 0.19932792672226507, 0.1713549309680539, 0.21242344902167398, 0.11696395238921528, 0.10838703883271064, 0.1396655814061242, 0.17592833798018195, 0.10310923695684442, 0.22930332309296056, 0.0840983437674661, 0.10191766379941856, 0.11724106937406525, 0.18785600520430074, 0.10853863231116727, 0.13053483990651946, 0.1340228995128024, 0.1455490447340473, 0.13649131141362653, 0.1491924976148913, 0.2687092311680317, 0.1818164591226847, 0.15038846811700254, 0.21369556866345868, 0.15360072074878603, 0.12519550584857503, 0.21970126898058, 0.26677341891392586, 0.29770139965318865, 0.19646047494344174, 0.13711775683106917, 0.19422216521155453, 0.08174550389089892, 0.19944470916544238, 0.14216384009247826, 0.21294512425459203, 0.23848657225889547, 0.17251708634918736, 0.13202866539359093, 0.11565062487798354, 0.2684126325672673, 0.19829065899454779, 0.09714898863627065, 0.1183223565139117, 0.25782557324536387, 0.15310731416027393, 0.1341090384390085, 0.12561749005990644, 0.45172901523690073, 0.14830898373357712, 0.21491076797246936, 0.2724659424876013, 0.1549511192546737, 0.2019226205565276, 0.11474524684731038, 0.22681390506125268, 0.1481973034359755, 0.07324270934106843, 0.1711528369736287, 0.1660760795517314, 0.15158459183669862, 0.3922842082477385, 0.2297102230330629, 0.291527895437133, 0.28385135735715594, 0.17946810852135384, 0.17498572807638876, 0.3245805444255952, 0.252854336774157, 0.31473021653871386, 0.2676081176727049, 0.25118575130979864, 0.1568227793060003, 0.26575203984975815, 0.13079593799287273, 0.17895703594530785, 0.09212202692945158, 0.13320476357494632, 0.12235900402189263, 0.24501145036230165, 0.11167274397467414, 0.1090299551405253, 0.3363354894663057, 0.19161124563505574, 0.20207118032680405, 0.0613983465178359, 0.09171547172891517, 0.09448095720501677, 0.19573730326467947, 0.1345835839428248, 0.20973325466677067, 0.20288704864440427, 0.17569851160289782, 0.14818377432323274, 0.2539540559894616, 0.2042806238657044, 0.19376182297785438, 0.15839427078683532, 0.10803745759110298, 0.23210372685665087, 0.13772465168468415, 0.11630458817366632, 0.14223456532964784, 0.11596624544190785, 0.11160866838068732, 0.12249103927564238, 0.25229708441803533, 0.18882755790987324, 0.08739546361950137, 0.14991779901808308, 0.11686186351242567, 0.17482327147116586, 0.0946661283171946, 0.11209122716419159, 0.11502222593633399, 0.1175335540826763, 0.10802813430106449, 0.11442168195161129, 0.07585784240115075, 0.22176282690657725, 0.11002880355883991, 0.14642195595848947, 0.09173069389597063, 0.15029197168206015, 0.13364531009668304, 0.17077526287926784, 0.2389678899799624, 0.18391207731779546, 0.13851252714953116, 0.10609638997383657, 0.09250659540656114, 0.11759249688757044, 0.1235533350958459, 0.21285991995565354, 0.21254453687898575, 0.17865259260419877, 0.10869796327765911, 0.09999973969834466, 0.10693851212460188, 0.12158409842560369, 0.14082694005581642, 0.0962913072397632, 0.09966669063414298, 0.16935620757360614, 0.15150010766040894, 0.2195109114531548, 0.1873103667411112, 0.10586699260579002, 0.27002316388872366, 0.13937451396017306, 0.12285114656532965], [0.011403659253471322, 0.045245394125700965, 0.029898601801945802, 0.05519052156277242, 0.044861300623104464, 0.04757452741145127, 0.013629158080044775, 0.04469632741905028, 0.061386430020173716, 0.061453673387727434, 0.02809103649680413, 0.08560621164618962, 0.01957464388631765, 0.012754644774230979, 0.03221186749156445, 0.02402572963957585, 0.0727189580098756, 0.0090588451055209, 0.0331297557380411, 0.059572414254709605, 0.06312966692231356, 0.0013394383014172257, 0.025318110391737956, 0.12688803156056713, 0.07321169044101432, 0.022827945424303896, 0.09060517283937625, 0.03242302430613387, 0.05698565709134264, 0.013111073884271808, 0.052765094855379675, 0.05277160277229644, 0.052521877261179115, 0.057061917313765136, 0.054486774043330265, 0.030711175941471613, 0.02062145515435165, 0.11372676359549647, 0.06888859499726566, 0.03688520301253565, 0.014200874176176806, 0.038125981997338035, 0.023662467982860345, 0.06316458520990226, 0.013736681393047255, 0.0329760555177927, 0.09103472599939955, 0.04691547346151164, 0.028289907176287907, 0.04492646023150414, 0.0528309975690659, 0.03474103399522362, 0.050030547840100144, 0.03230049620352445, 0.03057762000319218, 0.027311452018517642, 0.016700628649203048, 0.05276656191375467, 0.04242819388427081, 0.01626795176566849, 0.07589530410064806, 0.07705221944037946, 0.06278928256623688, 0.03319362831872798, 0.03195270760765961, 0.03779887394498914, 0.08591750381334175, 0.12396297763071715, 0.034789339669289134, 0.08361467415647161, 0.054469364695250995, 0.02003236418409694, 0.021269630655766498, 0.023415500388270425, 0.049145873335580674, 0.12205822258106164, 0.06647362539003934, 0.035983548169174505, 0.04692132637325314, 0.031217849257612423, 0.03123892625162919, 0.1100043883366931, 0.042228559032082565, 0.04955254727974535, 0.09860738255684415, 0.03649414194026782, 0.11854586266582051, 0.10768957706468721, 0.09886651945811126, 0.05375420246573706, 0.03114565313162823, 0.015457870284726304, 0.05630636692888314, 0.09789505102221044, 0.07470198426275484, 0.025717992966453877, 0.007526696070037302, 0.05215171506748565, 0.017666370577869878, 0.022686190430014845, 0.01016074575618991, 0.0433930165074285, 0.018608769807483883, 0.04230974136941856, 0.06188081337078925, 0.0199777708433929, 0.03959982408090465, 0.016976077477597905, 0.017627386278623057, 0.03286098911156578, 0.022308999379616112, 0.0407868160325433, 0.0027890862510239166, 0.02145578427570722, 0.04750382515691942, 0.04916082737186263, 0.06176292776100098, 0.04798733005901018, 0.053949152690268336, 0.024062195424771598, 0.07293930021865715, 0.06974017833389583, 0.02587912998522722, 0.00548571095644166, 0.04578339852272503, 0.049425514580141154, 0.042575160191664775, 0.047077592988047874, 0.06303585945598542, 0.033338752184664054, 0.0928571955451081, 0.02917999217677261, 0.041135815047328515, 0.029196938041657693, 0.056903298809042865, 0.02688616213779296, 0.023058670039679256, 0.022235696256581335, 0.03172196384008614, 0.03176177551429118, 0.028391069086689143, 0.03241984887168773, 0.01530453108341223, 0.011442137934688118, 0.018977254268623168, 0.03081899898637447, 0.050993654426307454, 0.05432622116659919, 0.032702339963326534, 0.0226079173115713, 0.0536562925985744, 0.02792257567747466, 0.0638964481561655, 0.01955814043720884, 0.03198132290685129, 0.03648045960994017, 0.04282924857351088, 0.04190645736431883, 0.06494246077753844, 0.043457375553947304, 0.02435595566977657, 0.012556368770498424, 0.015923426704361074, 0.15529230417263123, 0.07996533772036915, 0.032163952522340326, 0.021263116993190303, 0.02665388619437093, 0.017088698148126566, 0.02233166409085595, 0.025570515295370452, 0.023556219248641885, 0.05115223079619389, 0.02401300874959317, 0.05044279124347433, 0.02790273591545561, 0.05363570015516974, 0.018856212376586853, 0.030956982912856246, 0.07880190297240212, 0.026312565295806816, 0.03662717693875875, 0.01911275415501047, 0.029279619996105472, 0.043864903686147545, 0.060853251977072614, 0.001762052021560169, 0.01280247547378343, 0.11285910773421488, 0.05801742430776358, 0.04111091335934978, 0.06787235638306988, 0.043314795099919846, 0.047304374165833, 0.058597153683583585, 0.12697496721821447, 0.07779937733205096, 0.024895672273311405, 0.020263399065081632, 0.04777798121194205, 0.07566847312714785, 0.05112512660543284, 0.020174163228441632, 0.0349142924401789, 0.08022980659358925, 0.0393828833025069, 0.07174108507892779, 0.02587527464774828, 0.053184420741613836, 0.0659714547556735, 0.04091601293053358, 0.010597167852064295, 0.06067453898609646, 0.09070863301355032, 0.015660839534604985, 0.04523130193833382, 0.06700748142095343, 0.07183450184041454, 0.03904248745511136, 0.04667366929953137, 0.036325165926809275, 0.07961400213741487, 0.04855150784996729, 0.05356499023975865, 0.06864518588108402, 0.07512195366284541, 0.07151366421772588, 0.028611824982949806, 0.029474681303385767, 0.055144812926770224, 0.023778177902943665, 0.039701284765596354, 0.05884989375068296, 0.0195174707445286, 0.029197983751674334, 0.032328439260562586, 0.04664455412796909, 0.02962415463351194, 0.023622949337286335, 0.02818688367223067, 0.021404171017028635, 0.01267421990633011, 0.026179582008250782, 0.07349498209453399, 0.06430087746271203, 0.07369287026625487, 0.04220210601605716, 0.01802629017601571, 0.060636839799342625, 0.04532208335736106, 0.014826254731404686, 0.07663894564874711, 0.04936838740362756, 0.07222542884729563, 0.016015846593936366, 0.022105409598518765, 0.02963360241283813, 0.08506926828094068, 0.04396429210300407, 0.0359729340209836, 0.05717680368932986, 0.032533436728220795, 0.019942841064485333, 0.05001624114811421, 0.05955818800195571, 0.12710992126695572, 0.015349733143774493, 0.009488623303871964, 0.0384502210504105, 0.05406688508247176, 0.046136308416363694, 0.007235155085987983, 0.031194554439054865, 0.05639360519126058, 0.07496396335022104, 0.02855617444091026, 0.05170524668609423, 0.00522440554754388, 0.030317144363277385, 0.042837120126932866, 0.13074867036794463, 0.053261956500430266, 0.0781377507073264, 0.026292242898395466, 0.060637035151763316, 0.038993063292676405, 0.06204972043633462, 0.018296996920159268, 0.03820760100479088, 0.006921643657880205, 0.03219973648928347, 0.06152678881922077, 0.05830407142639161, 0.09154877865747099, 0.05018797124766054, 0.04202954088067336, 0.08413993468087527, 0.04455609885495036, 0.025126617138964996, 0.01288079359989253, 0.07810384365579776, 0.01907121112209655, 0.018482116321402214, 0.08126409423928108, 0.045640251163633606, 0.026580186620835337, 0.032264765862736015, 0.027465560180585713, 0.02179693663492799, 0.056475618733994426, 0.060651161813087044, 0.030042473114125674, 0.024535501781370372, 0.02809128930581914, 0.0817064640502776, 0.05200338129314685, 0.0882250602327047, 0.03003038616190034, 0.03158936168127243, 0.0542846838793447, 0.038959332441370335, 0.06908602351623197, 0.048107636506639184, 0.03763862750342777, 0.06594930715378254, 0.05761836527756626, 0.04915600484837929, 0.04019569492928925, 0.03561202999985507, 0.026903770668732545, 0.04518443650956597, 0.04332013090231246, 0.04605468940891085, 0.03779472940931878, 0.023626354598109762, 0.040743922769662835, 0.010310921971986612, 0.038439491989030954, 0.028591835833785516, 0.06834698615655785, 0.05535921412369898, 0.04063875038897799, 0.024936723094733975, 0.03216644996897348, 0.040564849717362274, 0.046884052365297274, 0.037761247536588105, 0.02635509275170344, 0.05189558123088172, 0.03450658044687683, 0.06228639947010144, 0.06900877887082678, 0.11512238427155441, 0.1468817772524011, 0.07738220415288403, 0.17605685689035924, 0.10359771760000337, 0.22511936453801973, 0.1562763441113695, 0.10125577915459873, 0.2258151715561267, 0.1717861312171144, 0.14804998472813638, 0.1741671478075366, 0.18334940105916994, 0.15739337691376287, 0.14094294108931096, 0.15573608358540844, 0.16071871944492863, 0.13880763953972247, 0.1820468677267913, 0.21119331099813987, 0.26100836213557954, 0.06487663084220502, 0.10595503143004834, 0.22180799545059282, 0.2231088893548135, 0.19091500960771116, 0.2585953383916809, 0.1330029453721739, 0.2142167382783467, 0.216572611863094, 0.1332415204735533, 0.12131845743785943, 0.18642441670019783, 0.14675105200900188, 0.23993051010033778, 0.15549891808580968, 0.14765584781285257, 0.21699445051771982, 0.11846376102297537, 0.08160138743058329, 0.15425463807919335, 0.21004076235957686, 0.17987275616295878, 0.1684870961452684, 0.08888551229310614, 0.1779018264384039, 0.2259452839291865, 0.09051430715067733, 0.15669467408330212, 0.17753413487826625, 0.09617365911723146, 0.09929952001379383, 0.21010978688155452, 0.1568356342613697, 0.10143078428002135, 0.1342884409091165, 0.12138646306289781, 0.16395790772812982, 0.2005455928343919, 0.0994596247290892, 0.1958628037884351, 0.1633847054214247, 0.28950407500228575, 0.14823413694337492, 0.09974385867075575, 0.12190212450561025, 0.18310632136079574, 0.1477961185117883, 0.1299429144109449, 0.2593537960802355, 0.14543911111691307, 0.09988042150413799, 0.20532035839653787, 0.06754522917852288, 0.10062401708696159, 0.3354511482100333, 0.20819010843913402, 0.10881714357603943, 0.14869454046410902, 0.14890075601156683, 0.25589365271791337, 0.2693067797489705, 0.15902474582675966, 0.13530435010550484, 0.1711128318622228, 0.18605813474184085, 0.2501086776535357, 0.2816800803186432, 0.19024768573862894, 0.21046816281253294, 0.1707474998528919, 0.13936230251866003, 0.30460927575345964, 0.23082970731681396, 0.2184086028606661, 0.17435781177013152, 0.11240638807536134, 0.14507095990402086, 0.16991076330023427, 0.14170441716428728, 0.10824535853199421, 0.21693043621076694, 0.1775726384573406, 0.23781425349654692, 0.2353544830675087, 0.14228852856303417, 0.13286989122148485, 0.1293289102613926, 0.2422951017656634, 0.2915798055548822, 0.11408514718735412, 0.09534220091037213, 0.25711418399887703, 0.13996694507377763, 0.2216753703091414, 0.19874606762201558, 0.13177034054552356, 0.13503260339700407, 0.30310955138937123, 0.12091427710988831, 0.21256439387798312, 0.13866785913705826, 0.1382879561354076, 0.07588819480471073, 0.1300894363873428, 0.08641934502990016, 0.16784706032804905, 0.2273754015444748, 0.10740681401183529, 0.16193805562873043, 0.14728112356557002, 0.10147265098508328, 0.11565514479673679, 0.09803506125125194, 0.2057102205412042, 0.14403666459744977, 0.10469000576244247, 0.1772508508856258, 0.20174951532915716, 0.14458147568568108, 0.13934607677642377, 0.1458446320987517, 0.11641756315985996, 0.14845864667046457, 0.1149047846575418, 0.09048720295991629, 0.13787475895256768, 0.15017100639881628, 0.11926731830763242, 0.25338195684936743, 0.1155882653209471, 0.12310361850165552, 0.14648264544385095, 0.15060539357364178, 0.13481918662305803, 0.18752078045039408, 0.1781927100232532, 0.1939326605849689, 0.14271998928198892, 0.14527879955787815, 0.07691595538128769, 0.052655992443643274, 0.13116516172885895, 0.22062184619567088, 0.15760057305376377, 0.10897932438960961, 0.1471796782026368, 0.1333162600114461, 0.09880094233179286, 0.3391134468538146, 0.11154148246972792, 0.09387001740716158, 0.227667449582969, 0.11248805304808963, 0.12198311532096517, 0.2049298987032906], [0.02953068616109029, 0.03008455049336678, 0.028440546875278798, 0.010860275003998991, 0.03332135049746402, 0.05977740023104895, 0.06424009604679962, 0.09370541575575068, 0.04448286084938915, 0.02244225462838527, 0.03010489970385548, 0.02885408688246483, 0.06281439492839479, 0.0019125622038113615, 0.033935875586804845, 0.12895320542156696, 0.0647234975270206, 0.035594015442315614, 0.05824748051142501, 0.03986007564010159, 0.010385027572122073, 0.02015981823205948, 0.020473228632322243, 0.06310017636766838, 0.013420416357656641, 0.03417281126002631, 0.033673911821097136, 0.057636896944454605, 0.036674862081605586, 0.024007521644835512, 0.02555788250549907, 0.03992322426770003, 0.05950799775159648, 0.04589961406083838, 0.02256982167431664, 0.06523880656928786, 0.037825415061125835, 0.05807214596819493, 0.031545464843211156, 0.04681498953892339, 0.04535132110299123, 0.041167086756397644, 0.04346641922189344, 0.01101158886036325, 0.03411439322536031, 0.05054590284764286, 0.03725549927161586, 0.043381115331524805, 0.015010156052848025, 0.010929267924849786, 0.019809503461264318, 0.07410165478265093, 0.012421704877558495, 0.09543369479116895, 0.044584279399245016, 0.04348561355483629, 0.018152497415881486, 0.01908687187448865, 0.04435636441133196, 0.01768674660143593, 0.0919776883036379, 0.011870679858651374, 0.03186136311400802, 0.007421963711103966, 0.05061860076121746, 0.07757354227285232, 0.04307209461506817, 0.028468267766818888, 0.09570565600428851, 0.06524405427156918, 0.02819735034849615, 0.014746162154140973, 0.021514133362460042, 0.02770053275350121, 0.028683304816724795, 0.10804139528303378, 0.04594318148109221, 0.053548515518947, 0.04734898346566385, 0.04069678537968186, 0.1000213663604471, 0.06663739200561278, 0.03613895676549404, 0.03409217667555617, 0.012263063390198494, 0.08112157124184793, 0.044909027900787137, 0.11193008823019844, 0.06238725494533297, 0.06347628340365426, 0.02816372483427967, 0.03415827474166309, 0.02965070149530807, 0.08800826501101257, 0.01654136854584419, 0.033680431229332765, 0.04867181046715668, 0.025065230513592402, 0.06466449343509252, 0.02108223214294882, 0.03884346930370216, 0.026906365791576046, 0.023824635389891845, 0.03967559400705561, 0.03972942317505518, 0.023562493508741744, 0.017368467712414362, 0.01963481243189064, 0.05908527809585776, 0.050871302523920615, 0.038065556812310414, 0.029513864785492904, 0.057243192868848006, 0.05836903185193097, 0.024320190855031534, 0.0846381446406726, 0.03426865268979342, 0.08605702374611171, 0.042423861657059005, 0.02691967656926042, 0.03513152050154825, 0.03570191892645052, 0.026510662226487073, 0.021323651345747135, 0.02531541950790392, 0.014768597039003527, 0.017149466157500303, 0.05667539531244867, 0.051078364598534765, 0.10220845545371694, 0.0363595326310925, 0.055427629605776844, 0.04164205743901191, 0.10245652238447821, 0.019623633293855577, 0.02441064860191076, 0.059138915741876255, 0.05240147505255957, 0.03690515577252354, 0.07080104156968094, 0.034858352699947935, 0.015426602406096796, 0.050267977640032775, 0.037003268652986136, 0.017454041648776304, 0.04211628884677926, 0.023963138340942325, 0.023457855474384084, 0.010703692377935494, 0.021912589098416993, 0.07022613088690466, 0.02412365291327719, 0.05315069755118701, 0.03850475501930041, 0.07545975247217764, 0.020212358457126448, 0.0427357743554298, 0.03410708091612305, 0.02187052321049475, 0.04194899822675413, 0.07735155297503357, 0.08694793803677445, 0.059555820790269685, 0.0485926008062257, 0.03217931258522215, 0.050461966424219074, 0.03963784885502631, 0.009461346743327957, 0.016729812768678513, 0.06416523010439931, 0.045495514172099294, 0.04522136194751628, 0.05577024327771318, 0.012432867736225168, 0.03913577015121137, 0.024611989914950345, 0.013655746119066834, 0.027369944746756268, 0.019055443117395043, 0.04150731789488946, 0.03984332895807682, 0.05453099263831974, 0.04366365621887869, 0.05570908264827825, 0.07602619788339061, 0.02773306276198597, 0.01729613752104342, 0.05160912563423476, 0.10887633918994859, 0.01862652389512908, 0.032034790098306634, 0.03686109422555855, 0.03062523428290602, 0.10282302650833323, 0.019580943044275045, 0.029886459308345954, 0.06779690438340749, 0.020986819722419305, 0.055692113800755436, 0.020975653990922917, 0.029486475226980065, 0.04356786075438704, 0.04394825022186964, 0.03844966946710502, 0.05903599182924917, 0.0646023330609164, 0.0424830113056927, 0.029285639531970508, 0.06437694999359309, 0.0801320231309341, 0.025281426271483786, 0.011521894390875054, 0.07550390978013316, 0.053415740990350326, 0.03987132564126965, 0.03759584915373595, 0.020788697893881512, 0.04092701778356587, 0.031519078859879125, 0.04072819115413774, 0.02428747890066476, 0.019418695198011496, 0.04357063016223331, 0.0588033692310414, 0.059948402547067216, 0.04071246336905226, 0.04902865422228652, 0.08607401557627224, 0.044081771686192484, 0.05819460895333079, 0.024772485335087104, 0.0577223195784515, 0.027021884189678297, 0.015203836486644804, 0.04812960790830755, 0.021595344428093206, 0.07477722941867768, 0.05443671402791816, 0.07429942038030395, 0.043326240453508594, 0.02614858417561458, 0.04236466987358947, 0.04049033234496752, 0.015210821293294432, 0.05557129407421716, 0.0295953861167354, 0.029714631532589277, 0.037601832300424576, 0.10180478074377584, 0.027716507601942268, 0.11135017499327661, 0.09160255802975548, 0.02134246071950803, 0.020935321376929363, 0.060355268013212955, 0.11698277516951484, 0.018237935371636864, 0.029427047871473818, 0.042854196226765076, 0.03796147610691767, 0.05278299066929087, 0.02171343688162104, 0.051889241853308295, 0.05564398815735214, 0.08102340473523063, 0.12129978021426548, 0.02982490414363002, 0.051317361048272545, 0.0468878866353583, 0.1604817684499487, 0.03509579399119943, 0.12777656331778536, 0.04130665265444306, 0.034877282732556907, 0.050660341061771884, 0.01275361917402235, 0.0737551761971366, 0.014116810390635604, 0.05420732049031123, 0.015624835317383613, 0.03622665468062605, 0.023337964629454, 0.059475749280423894, 0.026982961177465417, 0.05005756776118952, 0.03549576083558702, 0.06704066834983326, 0.06815670523792505, 0.040283484774972164, 0.05057287297301716, 0.0698739755898714, 0.05386468000529755, 0.062361782521850644, 0.017924210875325145, 0.016352746207567475, 0.06297422768247705, 0.047097978587712974, 0.05756695694740742, 0.05353563758093984, 0.038293441156706506, 0.017110010714180047, 0.01796745845387059, 0.044496864936644995, 0.05718023959367026, 0.04234217370169298, 0.009243248214554644, 0.019271721229738286, 0.019540916865451202, 0.05883551428034421, 0.045164253923200795, 0.0061824688811846565, 0.03976129626314487, 0.05556498150972109, 0.03295974550588477, 0.024030086764645193, 0.03321653817810359, 0.021926545305177573, 0.006114825711495454, 0.07491871053653379, 0.048168050200347944, 0.034024914155804345, 0.05275378356717768, 0.04845715646121291, 0.008522660167316997, 0.04441457560225841, 0.03253260552282295, 0.006909187068231405, 0.029569224214121222, 0.04909899258505433, 0.03523235299414204, 0.04601680253061556, 0.025006682243979266, 0.003990501483654483, 0.040331867057830095, 0.02840274235143537, 0.035511285607372566, 0.06229252817349569, 0.027307472191751007, 0.011773981368018976, 0.02750971748854124, 0.06733893702227263, 0.03289553201607159, 0.036914712719378934, 0.013976839423600226, 0.049372026321267894, 0.05260195643190415, 0.09356641676276924, 0.020089096825329528, 0.0752760139444182, 0.045291232996650284, 0.027091722680075515, 0.025197687115700498, 0.09166425875117702, 0.10615100438195853, 0.10492606043455102, 0.1360085994125374, 0.16599084460927596, 0.17091033950207696, 0.19032444774864182, 0.20043633337463104, 0.12147565101904255, 0.09688514029426921, 0.12590237517630862, 0.16015667137840103, 0.23867141395326585, 0.11731554078118456, 0.15038534247827146, 0.19829537809616138, 0.11438457265255914, 0.178313767237048, 0.08334669660055831, 0.0907519935900646, 0.11925136069616965, 0.08197048093162237, 0.1162016412784015, 0.17320003841192494, 0.07121602373738443, 0.12726668583890124, 0.12612133076594723, 0.1006729854270816, 0.20370256456155933, 0.13360892092027973, 0.11477118658442652, 0.1387846415802356, 0.15622201315577955, 0.2331827770197584, 0.1582575700576267, 0.1195089654215882, 0.14421344704685674, 0.10446374935488548, 0.09343775995676556, 0.13019149462061544, 0.21478059431237562, 0.24450590894106897, 0.0875679100112569, 0.10633756977415855, 0.08883068338036539, 0.13048893591809657, 0.1887350910974126, 0.08514694959646271, 0.15679417358290765, 0.15614724297436977, 0.08342599436160057, 0.16779153427529722, 0.0803120691148985, 0.20848863758146766, 0.12409421615302564, 0.08880053782054494, 0.10795034573323305, 0.11548874283870382, 0.20319018963604205, 0.11406318344656499, 0.20664932176230416, 0.11472327544564202, 0.2574882494105447, 0.2010467828762147, 0.20404494457667877, 0.1914252701305574, 0.17896111153306501, 0.12422406805619118, 0.1865554024134913, 0.22966143855404472, 0.10574059575916299, 0.15727418895450332, 0.1584662677299592, 0.107128425321031, 0.23189495257552595, 0.280528282446246, 0.12124797734882563, 0.132271362048003, 0.16605294369641813, 0.24799406047790284, 0.2341372919298949, 0.12552410394193667, 0.2232875563805142, 0.09296279310459092, 0.14109407491501302, 0.15696678851400653, 0.18942060189381724, 0.30837364795227207, 0.2751953911877448, 0.31290539510307774, 0.1880598458791933, 0.1985905670951451, 0.15784791220099698, 0.24383244104683402, 0.1646924941169639, 0.20787215130704068, 0.1730714428929552, 0.1529083611263383, 0.1346678076492202, 0.1040331619761644, 0.17353540106165796, 0.2385800962726916, 0.173317096646755, 0.1400353567254159, 0.10160447173421422, 0.07782282728341319, 0.15632080785449476, 0.17238795456867065, 0.12017201452005295, 0.1594482392313019, 0.15938587967426548, 0.21119887279647015, 0.2130208290632694, 0.13678086200548759, 0.17686039119237856, 0.18139242945659548, 0.13946129640023555, 0.1941046320022114, 0.11146256775264779, 0.09164476181350409, 0.10583155337841281, 0.1743867852154278, 0.13579653095333807, 0.09403176155061492, 0.07646205594703075, 0.09114943234430206, 0.18177384931233623, 0.22056875630251824, 0.1650583164225663, 0.15604323887776944, 0.19114243046891308, 0.12013886589556934, 0.14096066836387883, 0.32451888966944914, 0.17725261288785166, 0.07099921319393382, 0.13300147448335925, 0.19566067915049293, 0.12324667009975641, 0.13185136200439546, 0.09733214493720763, 0.09979979841098671, 0.13586705700764734, 0.1828146257227467, 0.10533869837320621, 0.11157949575253072, 0.13440799659057973, 0.05736533026661604, 0.15153059795979532, 0.1393889777001835, 0.21024527719184277, 0.058261549716154416, 0.21034587985805928, 0.10763639524098366, 0.12637920362213928, 0.13117997786931454, 0.18440058094359216, 0.127763080170318, 0.1856541152923338, 0.0880857854480705, 0.2850044729007829, 0.21546802032859097, 0.1013068006103558, 0.16212775432054075, 0.0736950765994768, 0.19507685886515727, 0.1412493302937477, 0.10207838904593261, 0.11950883518664107, 0.21772280095085023, 0.2168266619405439, 0.07529986226150105, 0.17730587132034764, 0.19268893216165806, 0.12322197908595686, 0.19725143008174437], [0.012568063102662565, 0.008665787416600413, 0.07766004892126208, 0.015731774488343828, 0.05888800279447629, 0.050311820851939346, 0.022882787743583325, 0.012849948027231281, 0.05886830284350342, 0.02572272355938631, 0.08264043248228489, 0.0436815022370748, 0.07438883816282596, 0.04500764639927976, 0.010554630820068621, 0.0298458049374242, 0.030801116579001954, 0.02466818437941613, 0.06549379893488462, 0.03912500661587523, 0.04056339031986652, 0.055940556114599596, 0.04268990484096351, 0.02862114635776849, 0.050464402583818284, 0.05372984470018456, 0.008354026020594664, 0.025293450021455367, 0.0521863192590254, 0.020451134656585997, 0.0500093310350372, 0.09163716222129523, 0.021655193131957805, 0.024764431835783106, 0.060934319401219975, 0.050557329049033504, 0.09111022396433739, 0.058544623034615675, 0.10567196960290594, 0.06638611516644878, 0.020474299240196427, 0.06875597751669346, 0.1065781367041411, 0.02370995777328649, 0.04938807969372119, 0.052748179634011565, 0.04558380580537262, 0.05298860866816775, 0.03625642868780321, 0.02511490173938294, 0.04266181622721976, 0.028828618289422125, 0.031633160843123356, 0.04834740287474087, 0.04211336239090851, 0.06308446390434139, 0.03575680529578559, 0.050523399014867125, 0.06119604567967116, 0.05373727958348971, 0.06481098476797342, 0.029279644893963012, 0.027460620828693914, 0.08781890339788892, 0.04519705397767886, 0.02175965688131269, 0.06698088284822241, 0.01714863495210246, 0.08798305305742449, 0.04751487597522717, 0.026532263990731973, 0.013664663382505458, 0.10035515086905611, 0.024382383787944436, 0.022516459819950888, 0.028039266190101064, 0.012327070993882035, 0.06545915643894865, 0.023334951988691767, 0.043405316049052824, 0.020172650204791177, 0.04320128385217921, 0.008129206985505599, 0.022633686594124285, 0.029305442904813156, 0.03229072858248988, 0.09160746099247087, 0.03554807314949651, 0.08699640841974367, 0.058692171568832094, 0.0479346270402593, 0.041220008110206936, 0.029852640356928594, 0.025941734690399423, 0.08871082126373246, 0.03692124744937305, 0.041505138374744885, 0.055075248312805934, 0.00599104936437441, 0.004720572981187293, 0.010419852013940053, 0.06664536698090454, 0.040220389773528424, 0.029407188957256657, 0.08565517998630963, 0.0385172997090605, 0.04260216862143528, 0.050568322410746935, 0.030995978703421932, 0.06692858202563179, 0.04753094849987857, 0.01782086561433971, 0.031107478970361334, 0.07605156305456355, 0.05817472897169571, 0.04368649329990149, 0.08227037371046121, 0.05996969979136221, 0.053171443212176525, 0.04274919238542357, 0.03084276303378565, 0.06046869499128192, 0.047086586860278924, 0.008419273729105631, 0.03894953417681879, 0.03826333773172191, 0.06936546174749252, 0.014431690722103081, 0.07043107472840818, 0.012813044614308785, 0.05124195884432524, 0.0019320390316762872, 0.030619373710285273, 0.03317857469101587, 0.07630547523618707, 0.07158839609473944, 0.06695003248751163, 0.0015447769176042188, 0.03944275690422904, 0.0770307689784996, 0.02206532979354022, 0.05284226289199245, 0.06542063753811583, 0.03830187578475283, 0.04319506321823405, 0.015624914799005756, 0.06909042086091734, 0.030295268722599557, 0.014800667394733718, 0.04993541121122338, 0.018511292779998436, 0.040974714417731574, 0.05826764394559207, 0.03190374309797922, 0.03689549923423798, 0.0744905746391704, 0.07206364639944608, 0.03604868096449683, 0.062901625529893, 0.020189437106431975, 0.011612377993221725, 0.017811919622603926, 0.04800098557626048, 0.05446807383709858, 0.03856573178763351, 0.004358552386909123, 0.06466797913514799, 0.03075170582310567, 0.025333123799834042, 0.03634516465207262, 0.03840122206677352, 0.03134703083384422, 0.022164195355388428, 0.031311377101848205, 0.01958821321867647, 0.10717437527472935, 0.043373577026349884, 0.057360404321262916, 0.03557420440859372, 0.01918410949949776, 0.0599862166470097, 0.03460057560474642, 0.028905889747904676, 0.03165337981866493, 0.022203537800739852, 0.07777705352993743, 0.05778282520271117, 0.054261728054693634, 0.03633058216843394, 0.04762168395363035, 0.024185265534587448, 0.01571890325360601, 0.023019003922179825, 0.02953073021114594, 0.07020629687054504, 0.04511703992442739, 0.03614460666393561, 0.024705180680499445, 0.02070825866183206, 0.06068487351219501, 0.007745645435211519, 0.06223889052747719, 0.018714597193343986, 0.003981707273088697, 0.018245988870940862, 0.032323877206973495, 0.05796736429235148, 0.08234610150177633, 0.020881134062825192, 0.009395285066397441, 0.043072021836715366, 0.04322275729669679, 0.11190485329397264, 0.025769228926829757, 0.09215099271386863, 0.07997417837501535, 0.04166451913695182, 0.09275156734210831, 0.044115475724421205, 0.032735454113853556, 0.014462433830504457, 0.020197094155235157, 0.023503719243190946, 0.042575355544085466, 0.0662513143352924, 0.0025817050529088107, 0.11071542518273478, 0.12076480569498194, 0.05195379625224779, 0.05359918840469853, 0.05548035560716545, 0.04501712673734273, 0.06893583963955603, 0.0748114199227383, 0.0674401755414663, 0.0048868044846571024, 0.03602905762231639, 0.026356774314697233, 0.041638253812467864, 0.007904741787276562, 0.03252145128264543, 0.02694541329307662, 0.01826122444453499, 0.04925664964943163, 0.04633033167450659, 0.010303491876730997, 0.03606266589955457, 0.06432308635163693, 0.007712337847483615, 0.06268550829601384, 0.026457323354759046, 0.02889091272898499, 0.044157078129149256, 0.057180614976753155, 0.09291502752251203, 0.02668887917553225, 0.03498279985280768, 0.02106726853056781, 0.01987132675675375, 0.025783709903818466, 0.023459634713588223, 0.06561456503526819, 0.06344218866058415, 0.029847679937618877, 0.0411162146877858, 0.04100624659669496, 0.05993975341440209, 0.048978111571482116, 0.04450693133197004, 0.02679589208245518, 0.050436290987436815, 0.08695057337923397, 0.006552859464840543, 0.0539630342034563, 0.02805730947593768, 0.034710298547701496, 0.03660419813146995, 0.02127278502279472, 0.03600234796683635, 0.04228391654549107, 0.021534059309370576, 0.02887028389640393, 0.05778914542808648, 0.05168875281308448, 0.04696050027926122, 0.04005364690636916, 0.009481156819439944, 0.03002036573185075, 0.025844772857043053, 0.09959810278228215, 0.023857611644592498, 0.020664317773715146, 0.05789329508139242, 0.015212132261254856, 0.06000372175607951, 0.015931282936024572, 0.052908529497442715, 0.0574871497378955, 0.06535356654034508, 0.03306896283080982, 0.04923947778860888, 0.07631837615683194, 0.03334863854932689, 0.02234053730423893, 0.014222287291270352, 0.03228044385210641, 0.019583534336678927, 0.043681889111476566, 0.07565476781418247, 0.029942418200775024, 0.09916595258419553, 0.05165428268693147, 0.01701982301329413, 0.01943296358560122, 0.06025881371310642, 0.024193753788788474, 0.04548287755178829, 0.027636801899080316, 0.03895994914214938, 0.03257736420979904, 0.03029337073976715, 0.03291363467372233, 0.042676797076579065, 0.04029009611375871, 0.021229807490242586, 0.0057454343937758, 0.036390179978503336, 0.0359471436710127, 0.07057374328254692, 0.008694437189748692, 0.06493474627214094, 0.03211581538761816, 0.048437774436728614, 0.047766057053400625, 0.037470574625917984, 0.005332076332471784, 0.06156042007909668, 0.01914995538461353, 0.07112027040772861, 0.018976532230754534, 0.03025169364146648, 0.01532217600352822, 0.043568653655388666, 0.013902345991453097, 0.028973508498541294, 0.07599280411077124, 0.010600952326410241, 0.013977976106557877, 0.07593930819101873, 0.03305385174650339, 0.06453041272658495, 0.004608934339616569, 0.15514326942784173, 0.08068293227904266, 0.18774335963591454, 0.11457919728972259, 0.17018024238847917, 0.06538928922025428, 0.1563372634231083, 0.11905413136006364, 0.15984010852632985, 0.14357180244499637, 0.12934849146873723, 0.12239275019495718, 0.14299222628676123, 0.1858723890637198, 0.08287562913591824, 0.15696421445858094, 0.10191044725117185, 0.08987701392822689, 0.1952076607173489, 0.1126874580739006, 0.1301217959412644, 0.14420915695448078, 0.10873037645773542, 0.1559703685944119, 0.12432869268401016, 0.20345075146084834, 0.12307546477043822, 0.15612684971382543, 0.08813512151039417, 0.06409787182365695, 0.1394032116138166, 0.19709346275175774, 0.09268660308612932, 0.060925091872172016, 0.1612917991775659, 0.14920118505195265, 0.14435050017651052, 0.12544068462786176, 0.17029668775296983, 0.15719002653514186, 0.10387612927344539, 0.14536161366249287, 0.17590062091908149, 0.0836801057260844, 0.14575951973036413, 0.1172609416948211, 0.19301933056164175, 0.1010623419537179, 0.1376270674048893, 0.1544055574002766, 0.23551212864056711, 0.19203077070415023, 0.16445581891363667, 0.14157306372879014, 0.08562762380367325, 0.11796805617069045, 0.1617432241478274, 0.13879129122341835, 0.16904224942047752, 0.2528849496476112, 0.2901761792600155, 0.07185241297608422, 0.1339953203475283, 0.161548285414615, 0.11286048669247858, 0.10864357869591444, 0.10539240113669827, 0.11924391432154564, 0.22358072290737785, 0.2096737296350541, 0.06915944538289501, 0.0821523042395711, 0.20671854546714216, 0.2306200137301799, 0.06992110531897315, 0.1399310002283704, 0.12618328429638379, 0.14880586836126544, 0.13968074994702495, 0.10749594068094608, 0.1169678747593876, 0.13582757283602992, 0.10679321588888284, 0.12591637926356447, 0.1519835551059054, 0.14394897817363664, 0.25643837187559376, 0.1506192291215543, 0.16311703430068109, 0.11935090616105065, 0.2625414572896496, 0.1525015224732699, 0.11936058951241356, 0.25795222290100595, 0.21030095646217947, 0.16015060396204073, 0.12350560015728398, 0.18760739435111323, 0.21320361764200274, 0.10552100431654723, 0.13229698002819093, 0.11009955943952646, 0.21979174396443754, 0.1132679918420411, 0.24776450989227145, 0.09979947665405851, 0.1455163940667145, 0.1473845301135894, 0.14663227773722143, 0.18507695997193938, 0.15141749273865454, 0.14313019872192415, 0.11835490758981436, 0.21687045152629578, 0.10394343775847267, 0.18517897223993657, 0.16325303022899937, 0.2067443932737074, 0.1257162770977424, 0.12124329655160829, 0.10687105808286898, 0.13960374278887627, 0.2193601453496564, 0.06764997638040973, 0.11481801753923779, 0.17707219918168363, 0.15804950057739214, 0.08975236376206722, 0.1579718192618701, 0.08571151043138198, 0.0961531586043777, 0.21764619215842218, 0.18269776667077697, 0.23839258859234475, 0.19526779861940494, 0.13769261388769075, 0.12095940734950766, 0.1504606029559528, 0.13489525915393907, 0.09357861288252378, 0.2009431924670935, 0.13400128051157922, 0.14963980103212018, 0.09917562061379995, 0.1327157696528781, 0.11319939632930102, 0.21345395985389912, 0.12527828930967277, 0.12996051911144488, 0.05136451759045163, 0.12631867501524188, 0.23538589267240417, 0.17144889931284613, 0.1311606571318642, 0.18360386482409893, 0.15647702850401402, 0.17816612677228066, 0.10006098842789089, 0.128551239087697, 0.0859932545872946, 0.20334235001956263, 0.18116076446829305, 0.09716221897472298, 0.15047978579757676, 0.1101238367658469, 0.13212902291167167, 0.09260944271039578, 0.0825561015235801, 0.15781046582325814, 0.21910592673286317, 0.14618249219511786, 0.05009566531366399, 0.1140405455484025, 0.07084062533272852, 0.1329565970527549, 0.15953304516451974], [0.03892560925094351, 0.06758237678197122, 0.018437794304542968, 0.032014551970566955, 0.018641018278656468, 0.0540222030042881, 0.008648535116545616, 0.008570874868441493, 0.03421646678039143, 0.029827026207180276, 0.047459962792814746, 0.0746111492175729, 0.0160674148449494, 0.021660172703465628, 0.03198435278459182, 0.03580071745560535, 0.07406157306245259, 0.008262813677110018, 0.05158434268988429, 0.013826749392695004, 0.022232970898790706, 0.0840886987204994, 0.012406358221215347, 0.013207984006693287, 0.04265503251865026, 0.028192276931217605, 0.025619004830537785, 0.05244845539451607, 0.056885215303590225, 0.08181852739184134, 0.013017529760667635, 0.027075968081912687, 0.04050256676911827, 0.05752737701479947, 0.03740757155502516, 0.03457142212878793, 0.026464122385087035, 0.05486980651415164, 0.02536608473277621, 0.05315930837945593, 0.023325391211396745, 0.04651479798579409, 0.0826813109339245, 0.011576855453782746, 0.05468681875255801, 0.04594872029678476, 0.02218788470922699, 0.017151027061646024, 0.006588211070911418, 0.05075399914095479, 0.07654545227846793, 0.02495206209019788, 0.06697973371633599, 0.07124243078813439, 0.0038812228716954954, 0.05154070249127765, 0.012722687416469619, 0.015982260341726003, 0.05985588976933111, 0.09327246116534357, 0.027902965741832892, 0.0668811382004811, 0.019769343217053724, 0.02069683820610085, 0.012422244969545113, 0.062157386433212995, 0.009925697532091892, 0.027658122126013044, 0.06689859734427545, 0.05176944868458856, 0.11609787466905772, 0.061085813288246436, 0.029455126909118508, 0.02173036933996745, 0.010132753861046607, 0.0745696425738354, 0.020465058304609793, 0.07085189448609468, 0.02184389399424676, 0.05243523271694299, 0.04787149756485897, 0.05731456161987397, 0.04204961621472913, 0.05568801523036054, 0.025615827480871833, 0.01834326863078581, 0.0955302065478698, 0.09316022162355724, 0.0795285986556161, 0.02714873877384009, 0.061622607266350146, 0.02110635050602498, 0.0776889764012829, 0.04360393966518102, 0.042327625692010894, 0.0614808350350828, 0.11728076038942223, 0.03295303074522846, 0.014033772205303033, 0.02616944666501255, 0.04434180874077063, 0.058861331443392464, 0.04935360573712857, 0.036786661122835455, 0.03924461592349314, 0.037264680835388364, 0.051066405966036746, 0.028667839416753382, 0.03530908053019836, 0.05876059854222883, 0.061969614452532226, 0.027671182009902213, 0.044247288812672904, 0.04534470976420468, 0.008523756630658623, 0.018947484091885628, 0.043568565555277376, 0.006366220336677808, 0.03477716270173269, 0.030903040746887846, 0.036840961434908455, 0.02464636044967319, 0.007977798325760711, 0.018615369654951558, 0.020780353281166286, 0.011567445021242866, 0.006136867018686909, 0.07692560808913362, 0.07024847767165593, 0.024910044082770907, 0.020875179644433722, 0.06430733558391372, 0.014102383997411498, 0.06411068847463017, 0.025986089265995452, 0.018331947766484755, 0.024344090883049275, 0.03825156296032571, 0.014977964080659854, 0.0858242326085606, 0.00562122903741716, 0.05123700225545515, 0.05338585590042415, 0.02749191360518096, 0.03346597640624931, 0.020291571948497046, 0.025107300231954264, 0.027397317068290808, 0.04240609224765532, 0.06810197591661446, 0.007698703876456187, 0.05444399569363845, 0.03818629993005626, 0.03630264677227505, 0.06752760915626442, 0.02453921347736351, 0.04635345220806138, 0.0028188533155292634, 0.0577537828095017, 0.029471335414376472, 0.03583654738782394, 0.1058081953576015, 0.10173910402602727, 0.012446155531271812, 0.012103294795979897, 0.031574103125040574, 0.05743788262348502, 0.009669427714881398, 0.022739586758337194, 0.10870199290014083, 0.08680284864479497, 0.03448019254832499, 0.10256555967874105, 0.01987233607759399, 0.1149266028416253, 0.02433632275149707, 0.036825375376088966, 0.022102996421557282, 0.02317465383619551, 0.02697621768851194, 0.018542872839457086, 0.09182605652078506, 0.032284710961844654, 0.09899652457886166, 0.033315823173090335, 0.048099454687607866, 0.04514481061168256, 0.027692519473813237, 0.005616569786422676, 0.05417666548202115, 0.04421465729753818, 0.011775596855929302, 0.07451859047456134, 0.014824608599977388, 0.09062143688600871, 0.07471452512207531, 0.029784010370231928, 0.02660677370224749, 0.022542989444768718, 0.010002702775020755, 0.035132148693646156, 0.043754839834066174, 0.04363889242672632, 0.004283121933469609, 0.019561658696001096, 0.020953190377763203, 0.05000250136119224, 0.008232871130589516, 0.02228542110852657, 0.11485450630707127, 0.020163547165030916, 0.0254964824735878, 0.018485427736454917, 0.0265640183351934, 0.03972413333793802, 0.03100407625278158, 0.028268188583634557, 0.07707728583726191, 0.03906011513824906, 0.014834855983574546, 0.02831053409364916, 0.03193329685487815, 0.003149706580217988, 0.11440272127548534, 0.025120352454964193, 0.02463117467179414, 0.08598911005162424, 0.022334923794973763, 0.052480765152722604, 0.035570925552277796, 0.02705352553617089, 0.028559729088878924, 0.014231880627302154, 0.01289578977101032, 0.05160920224302719, 0.016249132815808538, 0.03923549947719421, 0.007361676900707667, 0.022724393319578904, 0.04944903730985619, 0.05884711285151782, 0.041210550754781694, 0.038465470030543306, 0.009478708210911964, 0.0663051166902146, 0.06900882483610223, 0.10202032724215139, 0.007860346034454603, 0.08482959001295029, 0.036266154174001954, 0.04934245915783029, 0.068401638869076, 0.010394587391807188, 0.06365149920325607, 0.03111535818466256, 0.01947931382024, 0.011075916305755176, 0.0157812733443514, 0.01984541000227534, 0.06058720879316811, 0.05938432434754026, 0.058277790780149163, 0.06226240176587336, 0.04397155461652626, 0.06343343610604925, 0.0281412688819992, 0.1266442470613026, 0.05584892050753679, 0.026902351490852815, 0.06265064363457984, 0.02482497001877956, 0.0317379578407253, 0.02376983137500863, 0.02877004129151183, 0.021538856934996384, 0.06561808903971988, 0.020298309691791094, 0.040608420968055725, 0.0608984051993297, 0.09419149854370663, 0.012968096022133627, 0.012934135344450273, 0.03192040359511251, 0.006985744628529515, 0.030604329658672217, 0.06570443480966554, 0.04587469705110116, 0.04238143187737273, 0.02881150580041351, 0.008075013925741998, 0.06524134232031722, 0.07782126446404765, 0.015236499602906408, 0.07723507696702596, 0.032718623162157116, 0.04203919358851929, 0.04504355677073041, 0.04546571335184478, 0.08098326938887758, 0.03934659371753374, 0.06416943592710361, 0.030965291136395068, 0.041000991233534394, 0.06851542590846939, 0.07247594725941459, 0.015685892524948765, 0.027061617339871107, 0.029978587126900113, 0.04679797855656474, 0.02049895194959977, 0.047145422412863666, 0.036746805398574764, 0.05928888894437302, 0.028093916987399423, 0.043774463176246614, 0.08103385417451782, 0.036049129125932534, 0.10280364448384893, 0.047254995968673504, 0.06240545336397425, 0.032068026822901545, 0.031910367843304435, 0.066531227541066, 0.06877497649721562, 0.04504339589226631, 0.06524281320913185, 0.03126004538048179, 0.05849046444880867, 0.07845999793179574, 0.06839144989968308, 0.07705192066608899, 0.06703116885957218, 0.06728848247157951, 0.00955994704723238, 0.04398079363689308, 0.01822724078421391, 0.05484926769690168, 0.05045147868053568, 0.03473874722276965, 0.02391741246796183, 0.016974834499940757, 0.047237992647194096, 0.00614736050802974, 0.05274477820362776, 0.0421844132154459, 0.04787612473592163, 0.02968229879174502, 0.05958395919972851, 0.034863324610576514, 0.07117647061785383, 0.03278961653010019, 0.026382051385758866, 0.10940384435197038, 0.10298408117265472, 0.10970192150242868, 0.09502557677126701, 0.10304555206769898, 0.14372229275684203, 0.09402229270387082, 0.09771863629500713, 0.12214642994466329, 0.15215823847439983, 0.1132588983783799, 0.17935249053182142, 0.08924771866370594, 0.12049351097835649, 0.08136648189036116, 0.11849071965703081, 0.20047143552332156, 0.09673324804152213, 0.2559963391432839, 0.10913154606016413, 0.09664271177063066, 0.19373885566188445, 0.10524809315440156, 0.14870420849371344, 0.17536245947403295, 0.14306610780617884, 0.14130464184188074, 0.18532538696402506, 0.0982890883460641, 0.19275950418124277, 0.11426982800326041, 0.08554526935181311, 0.13434683213070517, 0.19332784949050796, 0.1065839359897279, 0.0752001635790352, 0.14259669509145523, 0.14641431040100514, 0.11073791752419165, 0.12280616954329515, 0.12789761287070092, 0.11939601341803228, 0.1505570381038612, 0.07605330207415166, 0.12609989562582585, 0.12618975007846472, 0.09863161391788915, 0.22191157053795554, 0.159697815355274, 0.11906866404798724, 0.24132258378930632, 0.04605112326962333, 0.1225778983244973, 0.12667183388745593, 0.14846909610975176, 0.17057347532001235, 0.07423591935226033, 0.13431116307695068, 0.20431636952825133, 0.17963303192969293, 0.1634654970539193, 0.1255530850481122, 0.04660381740259548, 0.13867129121095906, 0.14221028034244815, 0.23865275205143038, 0.19512106213838826, 0.159685573270244, 0.182028021963854, 0.14506202731882373, 0.22633802656444812, 0.22675284785368752, 0.22762176009916493, 0.19455844716679668, 0.18726830851406823, 0.23435069338208248, 0.07673112134779654, 0.20457541449896752, 0.21644769356616084, 0.1266911929293025, 0.25173246229608215, 0.13578099469023366, 0.21093172261551504, 0.17629748510737575, 0.13064348649594093, 0.17782599905565863, 0.13348741937548886, 0.17817384893855742, 0.2100165386594111, 0.09764875375455427, 0.2992329626314102, 0.1136254178239934, 0.10925762881074222, 0.1953012613399375, 0.11626291299058546, 0.10109581999600896, 0.24127392188435604, 0.14524414174018369, 0.16928555894522898, 0.12444001292028736, 0.148126516911772, 0.13634555552515293, 0.18024990124808205, 0.2266281747048901, 0.10212471438271385, 0.07109306662553741, 0.17477931334607064, 0.19803694599578459, 0.12263317922911338, 0.11436476161883724, 0.18182730692769253, 0.12046299003545316, 0.1671284238897985, 0.25578060878380654, 0.1341508974831912, 0.19224113844815763, 0.18220743975572049, 0.2820280680973684, 0.14139160814304508, 0.13332649494611448, 0.12044074284213206, 0.12722196162588176, 0.14501549513830295, 0.11156582108308231, 0.11696898558687781, 0.16463166673577603, 0.08740849477509338, 0.10826816496950005, 0.17489197423621533, 0.17195517617848613, 0.120068148319279, 0.18312591788989885, 0.12729906071458133, 0.14324993826448917, 0.14679992841857095, 0.2677409879622921, 0.17578705604518616, 0.14741661387585825, 0.08612018003458939, 0.1624253948008822, 0.09825566392992774, 0.13073192368591988, 0.3484567471088902, 0.17841613190549035, 0.07365065882162702, 0.15933248334594313, 0.09353486926204736, 0.09319368434408981, 0.17743820534838786, 0.2057323451604574, 0.13167886964736447, 0.17833566202992396, 0.20917911262762165, 0.152180424380687, 0.1765249672556116, 0.19082608212146068, 0.16478577298262428, 0.057645607364153674, 0.13562066780944027, 0.08705838493281796, 0.12860883357784442, 0.18283054502981325, 0.11480060436071889, 0.1128406067108435, 0.13369752664960202, 0.12639083283682986, 0.17718579469909593, 0.1422007502086701, 0.15015258964511657, 0.14750403982977714, 0.1798993394139313, 0.16872184080702646, 0.20473525108348942, 0.19758694594906223, 0.23864662334803613, 0.12295254596298742], [0.09398005827660523, 0.021253288085121783, 0.029123447227081465, 0.036293476699821414, 0.0319985062589929, 0.06440558636020269, 0.02383729116240096, 0.012601937595454436, 0.012808134948324053, 0.06478788721705638, 0.07106514272069739, 0.055907530064183864, 0.014915532702880522, 0.01534642172872179, 0.03307818269897853, 0.042618854016426115, 0.03935497471942537, 0.037015227285484155, 0.039776729104379495, 0.03132134390574309, 0.03561890563897548, 0.011174541507517139, 0.023767939137835658, 0.024895725899466106, 0.027830886444257154, 0.040694127054584604, 0.020842293405064174, 0.054995176802960136, 0.06962308179466956, 0.046360358490698764, 0.0238538712203022, 0.013291003997437658, 0.0693709162935134, 0.054199368497657205, 0.048470199108123786, 0.037778879050165415, 0.015747745506345265, 0.01916509711243693, 0.03811591560201299, 0.06280958772666993, 0.024679093471457882, 0.01746283059248761, 0.012651980373888247, 0.05726098526088942, 0.014461138184302518, 0.021136639707331217, 0.050794295365771944, 0.03063458247080205, 0.03628195473744023, 0.008934968688164749, 0.10847809604339062, 0.00249714570424159, 0.008552334583064002, 0.08108925765320178, 0.019750966682970043, 0.015728244738232706, 0.008049313591102199, 0.005169757623075238, 0.06772889875836911, 0.0545181185307522, 0.025694384051847364, 0.11336926866563098, 0.04307654175546862, 0.018436156791604815, 0.03441503293992531, 0.022355215548868143, 0.06448573447884091, 0.056842038588177775, 0.015040851280754133, 0.07780932881418737, 0.01743059935829332, 0.047231940552592284, 0.035965414868006786, 0.057161707926781914, 0.0014080425523476856, 0.05936321862522633, 0.016353860865497304, 0.07824669607103833, 0.08657687568976995, 0.0163035691084881, 0.05095109441167405, 0.03715403092604491, 0.032321012038136684, 0.055836054060848496, 0.036111622748355714, 0.036731192526677926, 0.054657017932303494, 0.01826339821902014, 0.037281913983245055, 0.045305930393477606, 0.1049082488903115, 0.04735569056544093, 0.03414555002124079, 0.07707615202713398, 0.06267028995939801, 0.044452014319117994, 0.02182891889054689, 0.007692082482765639, 0.1027973395802321, 0.05514970056772713, 0.06390138176239787, 0.07764667302610413, 0.04721328631163605, 0.018083769752974474, 0.0522648700843415, 0.014657156143878258, 0.09576906510178121, 0.022201111217239694, 0.08942388824277347, 0.05074159234702107, 0.01964355157988687, 0.05710748422350134, 0.028058581181891987, 0.08923947555764068, 0.0644735996461203, 0.02032162557776657, 0.010855070394163412, 0.05867092028981256, 0.06115808219258344, 0.043138108411503416, 0.039589658094149445, 0.08947185300771268, 0.00737401761955792, 0.013171901265459677, 0.09681142731419495, 0.013434813064973683, 0.03465690988025839, 0.03351519755538433, 0.04063641382080894, 0.01731053422836046, 0.04285502743216292, 0.029829611753924724, 0.03701610828659708, 0.03381618967039451, 0.01835315116500903, 0.025076687358500018, 0.03438553089396127, 0.03397048360878422, 0.03485079524257491, 0.03752330828818583, 0.019967384606359467, 0.04038507952505062, 0.11722846722771084, 0.030397068401197755, 0.045347915842167796, 0.15824515943325337, 0.10700380579838831, 0.07050078872951769, 0.04366543354286302, 0.053649413129014355, 0.05093203031367833, 0.04614390417813294, 0.030892206348418712, 0.008020794531706, 0.02103771285844907, 0.004730998959031798, 0.062301035579894824, 0.052239282747670535, 0.03368643735865912, 0.013372016837820412, 0.01887767432978557, 0.03256351717056767, 0.034873394836341186, 0.05878770656342949, 0.03838938600834339, 0.03666624742289705, 0.03374081427952455, 0.03609472284874609, 0.029879422790761438, 0.03999590685951614, 0.06140551710080716, 0.08632774389679394, 0.03472861954041066, 0.031963045964197766, 0.0809243725492589, 0.04915860954732184, 0.09828489018423904, 0.030309791834424102, 0.041373309964734706, 0.02489915031248764, 0.05761602487895758, 0.05094468608618744, 0.08093528164130065, 0.067384320070907, 0.005133630352981028, 0.038915650107927864, 0.051702266604068785, 0.050744154911127784, 0.01675400199488767, 0.07482317937237602, 0.03929319738921139, 0.018904634879060814, 0.039493885612295526, 0.024078018970847614, 0.05966674649126588, 0.03680834141109259, 0.0339866595553054, 0.02514904627816812, 0.02189477563895766, 0.01294893041748794, 0.05838243456016626, 0.03044969289593639, 0.04728582717718617, 0.03557330425528269, 0.10381435960411065, 0.04994878327594169, 0.04952302225114358, 0.055654115839711124, 0.014508583924673019, 0.12369585043239979, 0.07391168796006711, 0.036841896062176076, 0.029038409552266522, 0.0726561924262393, 0.04935239914864783, 0.06113084010599602, 0.01841557009385959, 0.08026051905847366, 0.04756932184400578, 0.0335853673788088, 0.03598740925231288, 0.03569254967113657, 0.07724630015511667, 0.05700672450926035, 0.034445668796017286, 0.008597201479959392, 0.07882238816349738, 0.02200244738149547, 0.043359293317001675, 0.08435532796166598, 0.012408301211713303, 0.05041104072945253, 0.06551410026487804, 0.022852448746562008, 0.016073549294003075, 0.022980848913111036, 0.02669888045338373, 0.08901655929343355, 0.05547580887533485, 0.00920468239083646, 0.0074760054685025215, 0.022066833241091623, 0.029036883122077393, 0.02082513112034048, 0.07698139461177973, 0.03106551458908906, 0.01937830321220381, 0.07045779587520708, 0.04429230413910362, 0.016754130314614986, 0.02657251233505386, 0.06517932750284672, 0.031257480901155266, 0.08768963372154583, 0.026919303101397334, 0.006439104026574041, 0.07704410656926132, 0.08315371139155281, 0.01775779551075351, 0.023137490910988663, 0.045983581127779144, 0.008801510426095657, 0.05792144115173048, 0.06732886296606834, 0.04821416486295001, 0.03740299034923796, 0.03546350087309557, 0.009226777324182613, 0.056596335038662925, 0.04784340512067561, 0.023822873387666, 0.07274626138349695, 0.03610507269660312, 0.013970441631822577, 0.03177012970310546, 0.07071301040630187, 0.036455255317231344, 0.004587040983155491, 0.030718765957581422, 0.027210284362456975, 0.038674868673326514, 0.06431537184623942, 0.06300543044363299, 0.044165359539610725, 0.07040213192662886, 0.015636293119901133, 0.030521733889115915, 0.06121347801038816, 0.0638705505538852, 0.019300231191840385, 0.06204565633989631, 0.038076477395671035, 0.07738566687030178, 0.0934033472872069, 0.07379394790698444, 0.0475671423238612, 0.09447291328181183, 0.052894778219201875, 0.11327886262968664, 0.009833845505190474, 0.05399378880317654, 0.03467950947402466, 0.025644980956830328, 0.009984963051524135, 0.013509681880203708, 0.021667075155663396, 0.023395513154325948, 0.07005367683426988, 0.07216291607267435, 0.05954899877730397, 0.02667161538415859, 0.06499652360235492, 0.05207561572352725, 0.02424135274674383, 0.0344690268168286, 0.04922679520302242, 0.03526941249747911, 0.09395496889708504, 0.03277242551707933, 0.06901301533704804, 0.03408985925958522, 0.05076896849899523, 0.10464751086528264, 0.02527419631669839, 0.060836999421759005, 0.05474190047431377, 0.06748244061224884, 0.027209106502273393, 0.013275462946283722, 0.043179381398424026, 0.07572832757667189, 0.011901249639659882, 0.0382473724593799, 0.02044082502834499, 0.09939033973721728, 0.12372850109973263, 0.008421712761534559, 0.059667853488316464, 0.019904440907280774, 0.044830224266456026, 0.010106353513565997, 0.056640266350680785, 0.031637590746545506, 0.03548779735161412, 0.030532554881046378, 0.0347031586082472, 0.02515985769399953, 0.022017117965245442, 0.03385517971530076, 0.026649891045845808, 0.07829863683230455, 0.016908052700361418, 0.20452633890653812, 0.27854411472235957, 0.17630399685473214, 0.08710713110743992, 0.15317043980523465, 0.12062283428085428, 0.1814739412117389, 0.1781314995981032, 0.08468887498301846, 0.13563165351027442, 0.16801025237767928, 0.12883760275379305, 0.12906663239963595, 0.15810111958173015, 0.12468634849233974, 0.07389424413803124, 0.09416989486424193, 0.15999415348614418, 0.1265103425530176, 0.09985292660853556, 0.09463393730261634, 0.09851591165868506, 0.08309997798454377, 0.11391045615798044, 0.19845172131974853, 0.14236412611940216, 0.07004053842636847, 0.09838448927527475, 0.3393778391182423, 0.14651877415036002, 0.10689975573651253, 0.15457938275029584, 0.15076405038276028, 0.14378037754326098, 0.22587999791627933, 0.15445359111312898, 0.11175622457578299, 0.13077612695915083, 0.17317510991086885, 0.1258028603549446, 0.20887258552735855, 0.1127157190574273, 0.09500510690193023, 0.09845025026269498, 0.10812571858085933, 0.11694981040613306, 0.14099557132970902, 0.12157318167268269, 0.13617441148286866, 0.1391885690991917, 0.15308816196216693, 0.16002088995470157, 0.0722518205762871, 0.24421432055532935, 0.1087225317173908, 0.1950704390483518, 0.08823640599486329, 0.16762996633206645, 0.11759612814433153, 0.15016539863521053, 0.13069714329415752, 0.1544483817152439, 0.19728644029988399, 0.12482212991603922, 0.12249218074664955, 0.09912443061869952, 0.15021436697533055, 0.20284914261391088, 0.18066435481511778, 0.17382467586186626, 0.11238044067736595, 0.21966570717913492, 0.11181085430566343, 0.21880140678296167, 0.11443563241271243, 0.17668805205293242, 0.10500996238401822, 0.21502586502221324, 0.1565210325943847, 0.1274196659365008, 0.12953757729020812, 0.15142901470103573, 0.11861848014016306, 0.0631195813747904, 0.12199604688512704, 0.12072156769253554, 0.2657635311686224, 0.26105190657319566, 0.16395482805467423, 0.10903209252583404, 0.17554420617318925, 0.1129541792456181, 0.11458628360302218, 0.18211918642684338, 0.1511926612546367, 0.1384659643254934, 0.1486676048126913, 0.14691197643837622, 0.1913973845301136, 0.24935143038390145, 0.11993062021511218, 0.2093609052920534, 0.1707727501108762, 0.14859831982081936, 0.14607945336930214, 0.1273613589845838, 0.17468456359159562, 0.07255700702268271, 0.2567630705814208, 0.10049253341651733, 0.13329107104049576, 0.19771137394972388, 0.1370096618249532, 0.2559826108476808, 0.20878952627460803, 0.1438596829651825, 0.12836910168369933, 0.1506260319823219, 0.19905457122912332, 0.27430890488528437, 0.18820374783489013, 0.17706731154072672, 0.16743769358483054, 0.13720717461359117, 0.1371942736929463, 0.1603971157343157, 0.10690906370479254, 0.13652725625903378, 0.1416628645552743, 0.13732674561681288, 0.14932213501343805, 0.14329362059793166, 0.12464115696568644, 0.13116611167788506, 0.1319163875474084, 0.12509743127250864, 0.1141172539322607, 0.08814369403426686, 0.10013336075409766, 0.12166593193767533, 0.16364633976932497, 0.15890189596722204, 0.13454895676864734, 0.10871408942846522, 0.10638165047332164, 0.2326792887141628, 0.20093884108768356, 0.16053868878272273, 0.14312137338903644, 0.22741372126244733, 0.19340793632211226, 0.09936590153243273, 0.14376468806257173, 0.10404489844316438, 0.1415922618921726, 0.125330513523471, 0.2477535854784712, 0.22113328649392053, 0.14871101135448103, 0.2589941637650613, 0.09572116162387595, 0.26728473663810765, 0.13011304721716913, 0.12587760755371663, 0.09448507109717016, 0.20970579807556447, 0.12142910351676327, 0.15874071106795343, 0.1133205914389222, 0.1495744230886621, 0.256871962318978, 0.16410205483196244, 0.1101355042849337, 0.18715858940155278, 0.15833695208834064, 0.16020245279275602], [0.016896626498970776, 0.01966360393130491, 0.09375897296253713, 0.020132794480530486, 0.01254328877680124, 0.01380204305713696, 0.07614059779312342, 0.08689836448719425, 0.0907396442527252, 0.064205227554926, 0.019962134988858335, 0.01574143964511853, 0.04663998058306114, 0.02226250741871134, 0.018494387134729375, 0.04217533507354317, 0.05306981398814148, 0.06179154497541248, 0.027513662841351285, 0.006442476249855733, 0.02562991392257954, 0.06936243570019161, 0.050399174027505426, 0.040816402348179015, 0.04030039233546104, 0.039227309997283646, 0.04758676949648127, 0.03305454505607486, 0.026118848472833637, 0.028665443476770195, 0.01532172879970242, 0.03852410256982811, 0.0306688821423919, 0.04818625244942885, 0.05775256472970209, 0.04647835901367568, 0.05098913833799382, 0.042856130598773884, 0.11221378591031798, 0.06809730278027636, 0.03963435166365197, 0.04641912892580994, 0.029345719977432204, 0.03946791523166242, 0.04744767091206966, 0.048929461157850684, 0.022604916162127932, 0.05019941660124929, 0.005994954976373383, 0.015193975977449408, 0.09949805936025036, 0.036476659813835736, 0.034311335278494705, 0.09898900159544523, 0.005853329738226509, 0.048345943477245114, 0.05505690433745904, 0.018905102192694624, 0.014687437684305254, 0.04189242263354602, 0.09871620534648819, 0.027268020578870372, 0.06329233037127603, 0.02781579642736864, 0.01048334921154404, 0.021391304570340344, 0.0870037168985413, 0.03467596248693524, 0.07698064384561393, 0.053154662056195165, 0.06343710949764618, 0.06052001905176909, 0.0174631331972177, 0.05660293871657022, 0.018515797376993205, 0.05441418721250469, 0.018804024551965056, 0.051446331950325164, 0.019311808695596074, 0.05327974123159244, 0.029960103340507038, 0.013351564205461934, 0.06015842555150871, 0.06490376567648304, 0.02113907203649081, 0.0617997114726853, 0.006320973747454945, 0.02819188048071679, 0.018813401468158252, 0.10761375734282118, 0.047065527103240454, 0.014361314054939055, 0.027684052287030126, 0.009158312046389666, 0.011996750160300685, 0.01061125716660172, 0.04480475567341332, 0.03305424245134477, 0.024205285327268705, 0.04246631058894339, 0.023392988894615444, 0.027851296941779798, 0.05452625438450806, 0.018146322747211785, 0.030210466619821328, 0.047865981731804154, 0.04719056797424152, 0.05295550600895959, 0.024810006406398553, 0.07030961914889275, 0.008066866580667275, 0.04221178553698044, 0.027125995538588014, 0.016030684759419773, 0.05960025005943834, 0.02340837768579443, 0.08579143638452215, 0.03850997207806476, 0.04251262060396614, 0.06282976648259549, 0.05206348472124627, 0.048021463106476495, 0.027061690118223913, 0.029015821449819113, 0.06711939920581157, 0.01963721220231345, 0.020512228253327554, 0.04852864395586714, 0.06346195755947022, 0.030150828590135903, 0.014766239403416554, 0.03495726614229141, 0.07078093176166858, 0.06775461632998721, 0.026097028373530316, 0.010267893686109494, 0.0676740775065076, 0.01320262426405304, 0.020088374787460894, 0.05428127095764203, 0.06488770081271088, 0.019310801289975643, 0.06052717048254225, 0.04329407242156806, 0.0686347134591591, 0.05520672432237095, 0.0151951911844193, 0.017374207626187035, 0.0353071729712669, 0.08749228947225117, 0.04327984616881417, 0.046281478247575225, 0.02667991594681817, 0.07751359589277737, 0.042504879285491286, 0.0364583081776096, 0.014980361935862852, 0.05895850969658745, 0.10541048847259053, 0.04650807939469815, 0.021531540795319506, 0.08933510631322862, 0.10122096811931941, 0.0476052092328187, 0.06573751448623597, 0.011867781173467878, 0.07310482883645643, 0.007761855376884342, 0.023758862911152746, 0.04198537591183859, 0.03191977731823441, 0.0577412725936982, 0.040439123197668986, 0.013060282254892011, 0.029515584652882912, 0.03156237240370003, 0.018479927225158583, 0.028586613029361736, 0.0361363175925949, 0.023371873596202464, 0.04956223063110825, 0.09068827039652294, 0.0551184097064599, 0.04694916600842149, 0.04435616522847165, 0.03259873040200722, 0.004482181740909695, 0.03999059787020087, 0.03166059062125222, 0.049551394317419305, 0.020721563693857, 0.06825994324660109, 0.05250249906713444, 0.08983071157408339, 0.060349867093346776, 0.03108607830419656, 0.03723153604134437, 0.054701424218834414, 0.04160401351269215, 0.013210444106540133, 0.03255034428870967, 0.04668799131327579, 0.10152878990817456, 0.014946791005410976, 0.016806890789960182, 0.07937257718895713, 0.05520470185025085, 0.023490919829196027, 0.02843400065396582, 0.045683075478600885, 0.03333221362423032, 0.040509561151866956, 0.08333403316716995, 0.08003656857556875, 0.10588419894056936, 0.06250828917649004, 0.03245546429928753, 0.043663870723497485, 0.10019612633773398, 0.0710770094226445, 0.05394372495732481, 0.05258098094453735, 0.02758760947824246, 0.012187703321087024, 0.01888845893253963, 0.011531113301433865, 0.05998930015090493, 0.015961972418271245, 0.03897211844882658, 0.04913570351838585, 0.019198709220114737, 0.03918570376211598, 0.02376615989863152, 0.0467347035244588, 0.0313986613295011, 0.02200239184012096, 0.0263909341752409, 0.02263839228919918, 0.010369720177785044, 0.022850468409277742, 0.021393976301976272, 0.038722933029695865, 0.03313170160136877, 0.007497926116845901, 0.07241886604817645, 0.018187974947654915, 0.01967373544410352, 0.02755065531199498, 0.020000425978533683, 0.03861456989280639, 0.0118662997509443, 0.036403011951235034, 0.03327524732618082, 0.06850005052382908, 0.017013479805281086, 0.04420673594840112, 0.01222749871592368, 0.01839681434625339, 0.026665402411092675, 0.11501693992965645, 0.05327176625630068, 0.053296020599983396, 0.01468401135606391, 0.038667525720572284, 0.05053106372454955, 0.032696226581690774, 0.03734095637956935, 0.03121245408340568, 0.06305701497401442, 0.007483413538730313, 0.028135791353340593, 0.011878292857398911, 0.01763204217798287, 0.013045427810040214, 0.03242111291676279, 0.051949506159871824, 0.043514897265741904, 0.03739747068574352, 0.03750223320938888, 0.056531026043118014, 0.08840527475601243, 0.0150051400921638, 0.041850789585300995, 0.016884654459934083, 0.010295469978553875, 0.0781854473414921, 0.021887283299058195, 0.036267801263039155, 0.032020615556487636, 0.06670095432069033, 0.07895288358051931, 0.01818041749028189, 0.029851807236310937, 0.05991529222697981, 0.09267718786553991, 0.017267656287238482, 0.04018563236440382, 0.056176821460887316, 0.06815007857738004, 0.04762484023587839, 0.0694542819814336, 0.02270911752636875, 0.018441833503123735, 0.04141353341119905, 0.047785711039098046, 0.04404495733099119, 0.03037463543155501, 0.04253548832850591, 0.039930892807822076, 0.043106963106941794, 0.04608052572415722, 0.027098109938144207, 0.026421684944521517, 0.09534687404671023, 0.027452772257909663, 0.020679911493413874, 0.09346962921441564, 0.040759386254414436, 0.012860220308685976, 0.03881907323375344, 0.06245281674989289, 0.06104614525552719, 0.04486290940774545, 0.047743572372823, 0.06280494140340917, 0.06336877062436073, 0.03166013288371746, 0.004238522209737811, 0.030688214371161118, 0.11526407223315009, 0.018572834538175695, 0.014986150687740696, 0.04871386869419967, 0.020897235315773758, 0.01074446166204589, 0.04086511404884439, 0.0645879076253022, 0.026323493540046677, 0.03214540170325387, 0.07020553078262076, 0.03662479057487461, 0.010932764158614222, 0.04811726240140777, 0.030521950308954528, 0.021637130693923083, 0.07260696361622504, 0.018099208339868535, 0.0670086382137191, 0.07894657101602325, 0.006479457707985515, 0.05630341749037466, 0.028312740426871087, 0.19175839580355153, 0.09883526307080062, 0.23218957466944573, 0.09293408779006812, 0.1732272192114784, 0.15727912256073567, 0.15382490871894747, 0.27469277622238286, 0.1367298405497305, 0.12167975982470859, 0.14678469859063625, 0.1165291591877899, 0.11603072706249454, 0.15286967368616214, 0.12376995411731544, 0.10422614718516988, 0.18273483000455365, 0.2618376982788886, 0.159626477247765, 0.10203784001210045, 0.10094322294237153, 0.11486622745231276, 0.14150342633647306, 0.12050798237924615, 0.11595251714630474, 0.21788046184566714, 0.16649997132199426, 0.17236866447473728, 0.1401426703218491, 0.13701948307214246, 0.1604785662024252, 0.16119749375408696, 0.15779764151140568, 0.15079034252032159, 0.1143915823570663, 0.17258431822542222, 0.23821965190431765, 0.11266812201469176, 0.27388967092960115, 0.24734835561004379, 0.10898577484993205, 0.16407024686134633, 0.19759117475440427, 0.10491364214929844, 0.11145332873228098, 0.07684339919397909, 0.18977425872318207, 0.20696798369528788, 0.09806749741396598, 0.07774710715297731, 0.2322922457730578, 0.14767397345314104, 0.11259395704274217, 0.23224937549281507, 0.12655020210771792, 0.09815467055886985, 0.14535021427417957, 0.13785369153464996, 0.15147669601344294, 0.1896224047748312, 0.1540915839253895, 0.1332876236448365, 0.14961035261231084, 0.14229929975924954, 0.19907773772795356, 0.15868449553606973, 0.22033974197843384, 0.12255368228521078, 0.1989569563058115, 0.09391310219202312, 0.12727244682009184, 0.19856262020766738, 0.13079483482626178, 0.13362634175967786, 0.17904504412604919, 0.18343043783980031, 0.1043804602757577, 0.15662427060306072, 0.10985445726903216, 0.14139182264766387, 0.10531926272256721, 0.21854104414101572, 0.1306673577956615, 0.26296639093948954, 0.15076458664430728, 0.12288231102208938, 0.06865679211313687, 0.13728341568381558, 0.1628184745148305, 0.1845868322397432, 0.12449504867676767, 0.1903603466287736, 0.1835721947493092, 0.11245096673167522, 0.09595466522319664, 0.12392082747312323, 0.21474613567754147, 0.11178412549798528, 0.22121107506175197, 0.22430614688463751, 0.10572908145766105, 0.21140819866090052, 0.09969157316992361, 0.27467509491309045, 0.18728022884217002, 0.14714859035466948, 0.21148805566612752, 0.12705906068966275, 0.09764426447931798, 0.1932910772701425, 0.12290866444668463, 0.19991012290120128, 0.1928089781393928, 0.17435992617280255, 0.24053011179691364, 0.07242165460822082, 0.15237904033593594, 0.1038604704362731, 0.11325785649880288, 0.15424990365582128, 0.1386199326765153, 0.14018958554633204, 0.11214343605623131, 0.26815862845509286, 0.1778897069274418, 0.08253377772146657, 0.16934183576414663, 0.15389451546774757, 0.11231611227436412, 0.09645003299679487, 0.11814514505526713, 0.10020577904557991, 0.17871323612428483, 0.1433422365376065, 0.08023071057733991, 0.09208125573012138, 0.15512794766935611, 0.12907953332028083, 0.11372756798781695, 0.211273551047329, 0.1376670878380537, 0.1362198404967785, 0.08440648731324943, 0.1692649052147904, 0.18259526410650823, 0.13481983013691443, 0.12313207866804254, 0.12084841653103791, 0.16192798923340537, 0.1804808767572526, 0.11283820885564051, 0.12135618726813024, 0.20744188568524777, 0.31501130951989087, 0.12159270159299336, 0.0758931284109431, 0.13881419725235433, 0.13140997278594202, 0.179815023776985, 0.1826689770865825, 0.12253679004648041, 0.16010776432531496, 0.11613533636855504, 0.12819297806990723, 0.12288878446504956, 0.08971291789484602, 0.13876331369242362, 0.17824403791418, 0.07109620758602697, 0.12555536799012654, 0.1337217197062508, 0.21330619681506388, 0.16108262653072036, 0.12625533486566237, 0.12916830758894646, 0.10487248790600609], [0.06716431494081213, 0.03399609392809291, 0.027152352793622884, 0.04848946238897982, 0.040355462565897934, 0.006874788284016353, 0.02404846329872887, 0.06055227518382092, 0.07542962223411569, 0.013502390638384367, 0.050649301734783, 0.07052326574921608, 0.044585229348271124, 0.058760234650464795, 0.0706401554447028, 0.03463801432160601, 0.02188772763005428, 0.06841431762422286, 0.030948477421676925, 0.04491128019928452, 0.008335316238263923, 0.0763199772805937, 0.05290202541096557, 0.017317181956323407, 0.021300764469009255, 0.012993715917541376, 0.029819114434142268, 0.10554575661738073, 0.07418821505721539, 0.050356096903523134, 0.06032699170792776, 0.05472577432350767, 0.03009974201690526, 0.012045054876756285, 0.031243168463509892, 0.0170584759795137, 0.03605808086332775, 0.058164823454834765, 0.012251311601440032, 0.01341768142376696, 0.02674961845660883, 0.014109538301014373, 0.03719914201346617, 0.024118774848419334, 0.04050733566644692, 0.049542254888482636, 0.03577820596195037, 0.014503396551815734, 0.05091377443844273, 0.02982643823469839, 0.06891456537789876, 0.03204080963417167, 0.05176767902148347, 0.032632970701782935, 0.06488963135428007, 0.06829002751938759, 0.00828058595934342, 0.07187722656395167, 0.03191248990685469, 0.01014619870411773, 0.0307138400122283, 0.028690540517169624, 0.021329195907099113, 0.07140627401250024, 0.04889200711923261, 0.027587716730551857, 0.06526856142426692, 0.022682848371445172, 0.06698339561661405, 0.09313156993518915, 0.02407121036442057, 0.010535638542815803, 0.02486331654982942, 0.05882499972358347, 0.019918400944480975, 0.0417985653715028, 0.031782410092531674, 0.05209259989280855, 0.03574082087124548, 0.0030616921750122625, 0.0132384474930023, 0.01125754904933274, 0.035633897979653655, 0.027461871467230302, 0.019300401646403537, 0.02326162396779945, 0.020186330619899016, 0.05951563564820155, 0.05257434662311308, 0.045456696496976, 0.018070849680131482, 0.02039291772000011, 0.04175870198636286, 0.07040095215122547, 0.027827511826950698, 0.02719634539267469, 0.08042942612401902, 0.07205668266021437, 0.007281787815548841, 0.0629594536768573, 0.04197951533921784, 0.07367061541205452, 0.011604104243639496, 0.022880499055909536, 0.027097297884944468, 0.017970122524627277, 0.08956978968795269, 0.054089492337117275, 0.013117420922724471, 0.04952979829883383, 0.004881653500976222, 0.037916322884660576, 0.10032056199927485, 0.07233638136136918, 0.02981411187999672, 0.03431832583080377, 0.019427997420632073, 0.008966640678174313, 0.035968735859158545, 0.014197339638016157, 0.0402355621448688, 0.06266711835539149, 0.0373117033121807, 0.04180363304312191, 0.0189299751523762, 0.02322490920402831, 0.03880432221077142, 0.025110879777780464, 0.028126613620007714, 0.04704485422060375, 0.031045276461349382, 0.03486636981007553, 0.02017289726814676, 0.02804343945406858, 0.0315657853254027, 0.053291320650567936, 0.07784879766404629, 0.030597162906140573, 0.04170304186822426, 0.03909106125995036, 0.021261017912277774, 0.05414980260895626, 0.024490199171968048, 0.04936939863968761, 0.027158912421474536, 0.01235693693161011, 0.07425691016138562, 0.11694528282650056, 0.042487561867962924, 0.05174977937713266, 0.044635346820277554, 0.048923788276771386, 0.038692741504599976, 0.0015161496482887157, 0.032597454865613294, 0.01001625008235175, 0.05345606019780521, 0.012993658460947055, 0.0098700565661514, 0.06731835990062646, 0.04768428865880255, 0.0411570203610726, 0.06367985977821293, 0.01045416221923886, 0.008290587237194903, 0.01791220819277148, 0.029937944247297225, 0.07748611631893343, 0.025109680850178968, 0.03594001905331689, 0.04514792858953438, 0.05148270963540962, 0.04330325015490094, 0.013343391962529672, 0.04631918509520831, 0.09870723445689487, 0.047552533027145176, 0.025856110958322406, 0.030341812394439217, 0.016700297316175797, 0.016005866383502803, 0.022478731904899883, 0.012691497104242446, 0.0384163944381139, 0.06365591186969992, 0.05554079611395156, 0.02587248991814352, 0.056183026773073984, 0.04576117431204166, 0.08911624265414092, 0.07724757952195022, 0.0669183470909634, 0.017682337765431693, 0.0630394179343937, 0.05700781618455245, 0.021454261675957712, 0.0376867416555122, 0.01801765828032888, 0.038653536955074924, 0.021682684197120612, 0.048105234820996566, 0.0031656881319283843, 0.035014937241231246, 0.07562004104857484, 0.024873082255644184, 0.03054492720102351, 0.014813798141755886, 0.07764694881775687, 0.006974480263212877, 0.08151675003670877, 0.04799705937564854, 0.033588956500734055, 0.010568444342953304, 0.03134442613490167, 0.03365607729421989, 0.03519563056949166, 0.03787373988738945, 0.026976734797860828, 0.0751006181141542, 0.034473987236138315, 0.028236137380102472, 0.0393376381496989, 0.02724404011162058, 0.04232668723430365, 0.05930657025366541, 0.07806756939258307, 0.019949465809810548, 0.06579065034466405, 0.024683349089877262, 0.03579192659667423, 0.04532576824027685, 0.04755534840026691, 0.05515795516511125, 0.027044713609821858, 0.08482152310710761, 0.04671982992740889, 0.012992719045629906, 0.030538700821418917, 0.034521595770192724, 0.042190434666530746, 0.0977840448819822, 0.007444184091347721, 0.006893140877852397, 0.05644412485942726, 0.049010616682109334, 0.033711070915864366, 0.05851787507473942, 0.04880379592519134, 0.06989028560177935, 0.03361784184591905, 0.025315917465054703, 0.035271036603878585, 0.021159229724998438, 0.013490889743421108, 0.01308502497962646, 0.037119369277910846, 0.03619195472809576, 0.045212613223421, 0.016869290566612637, 0.04860942409704289, 0.054743965081269705, 0.04554496131717198, 0.08328576196706103, 0.010517859557313065, 0.019141317743267265, 0.03815854073411996, 0.04894428112874589, 0.03760930548812594, 0.07661599365453567, 0.05159704825810848, 0.04407037229787919, 0.05127611870486891, 0.03333021796518757, 0.10154937469069997, 0.04786951722757471, 0.06358533601967559, 0.02338131562986922, 0.06047376649334066, 0.05077478693678014, 0.035599784084385445, 0.06309109056488642, 0.07380176200381211, 0.03684339376406805, 0.07441804909537877, 0.02396332411726396, 0.02701041776867163, 0.07713027613898439, 0.015651937592924846, 0.027534645989597328, 0.08545559109939684, 0.029252174896218126, 0.055263636994265744, 0.03757216554555682, 0.0042903882774314095, 0.05320977059102828, 0.018411894787042853, 0.024512344858639186, 0.04974122707461638, 0.02820264976171236, 0.04254476565326895, 0.09963212474699944, 0.043237247849784555, 0.0589782785954735, 0.09851316906391613, 0.04803488113647027, 0.04963029754318057, 0.06628444763801752, 0.031361898685234695, 0.03422019379814306, 0.0762004982079229, 0.0459681827605011, 0.03222761442884803, 0.023795144835246668, 0.021361538224042426, 0.020611444300401117, 0.05112409621717469, 0.08052611408094246, 0.028196482753921902, 0.05850412379649859, 0.01067475723703542, 0.030987678140762354, 0.06246679019363177, 0.055660240712665746, 0.06603117897025039, 0.07543958137713133, 0.14747963226850958, 0.06787444014222392, 0.018899948336184025, 0.027771453343091473, 0.040165166325506665, 0.029732077269844955, 0.05157606127942282, 0.0748247345308623, 0.01751100986204561, 0.04543962039714379, 0.034343254331859856, 0.032760340480073806, 0.04776127666475312, 0.0333551541271229, 0.02047777153371323, 0.05605296419572927, 0.03743136241551369, 0.028494079184207707, 0.04272807517179078, 0.007864298569338938, 0.003758932016940127, 0.012753466914047398, 0.04210610370782595, 0.03943169842504206, 0.04955133686082498, 0.020548284181483814, 0.011988330854012842, 0.32023425183949933, 0.10013854716934505, 0.12470805176323461, 0.17068851108272232, 0.23986050498581704, 0.09221770365031497, 0.13578749111583158, 0.09515567382256832, 0.12811960216851967, 0.17564079453868253, 0.11734904180611334, 0.20180010777567664, 0.19609754845019312, 0.1759439202085618, 0.20328290159663848, 0.19816554151475432, 0.09611097014238758, 0.14014250178250576, 0.17875953847842832, 0.20565962809468472, 0.16300880139873875, 0.18025641299543843, 0.12023399103312724, 0.10574678574959118, 0.10083216317598859, 0.10630993698272975, 0.21966700952860618, 0.14160220571342977, 0.12332225233436593, 0.12239049789645981, 0.1868024198037963, 0.10566266163462594, 0.11144826489110148, 0.20513065970472752, 0.10471189289443916, 0.12075450181240037, 0.08647939100140527, 0.15978940882750098, 0.10296027882084732, 0.12590703299088826, 0.1643299659894359, 0.12798978856975032, 0.16693644225597384, 0.12928721975655327, 0.12727760259182225, 0.1829925573040401, 0.08467577487951325, 0.10808762102838486, 0.14523982100429075, 0.24478827362820027, 0.13744377320812595, 0.1916679361414525, 0.14577240532925054, 0.08605669432830426, 0.09500938933342697, 0.16884010946077688, 0.08086429593423683, 0.15915519527850613, 0.0939769939249081, 0.2306440535692438, 0.1074263952191799, 0.1752508098199483, 0.12188708619965662, 0.18056465613265194, 0.17817649960277543, 0.17073348044387757, 0.1381204433498844, 0.17231949695175694, 0.15935158957877468, 0.23338439603967054, 0.1488392391512471, 0.11885150876497069, 0.1768303299022298, 0.1278542293115489, 0.11990821980420621, 0.17733869052702383, 0.1551327587015206, 0.368503368189258, 0.16232958784507168, 0.2082251799443076, 0.12277881254351909, 0.08979687347046791, 0.1196745859699384, 0.1560078609374262, 0.09587124590912173, 0.1821080934736998, 0.12880700520209729, 0.16548979246327955, 0.1730841293089813, 0.14193027520612364, 0.13974421267067233, 0.13698511636785923, 0.21947403198047993, 0.1688635211077429, 0.150524249540702, 0.14750609294541422, 0.12746589934273114, 0.2072119826991712, 0.18579126035253848, 0.20373215087719504, 0.1635056707046686, 0.2353279611035701, 0.12607741860612748, 0.09423681264442783, 0.17714398162018868, 0.09705277565386027, 0.17908146394596947, 0.15710273847704934, 0.11132113260006714, 0.23455928380210556, 0.1103242836712349, 0.15102684918430545, 0.15274005160937387, 0.15789145663861306, 0.18387893635419109, 0.34513967832730663, 0.12046203242554782, 0.06261656804370784, 0.13127633640843053, 0.10849356335858185, 0.13303653066677432, 0.2522007871659533, 0.15584053201300485, 0.1290725159548944, 0.22670786317077377, 0.2002087439740858, 0.250293105660427, 0.2177654107611987, 0.16358758082553265, 0.1312277357905142, 0.12902230655233707, 0.14320293110945534, 0.2016124468777449, 0.09672866683573493, 0.097351718483673, 0.12192007394567614, 0.20352561357280902, 0.14338742040338057, 0.12038541597224052, 0.14696711944716592, 0.15918409211501, 0.14363702717086962, 0.18052572354434, 0.23542917664012603, 0.1115499247586535, 0.11662824499991634, 0.1597276161755285, 0.2571134485544697, 0.1222781204588471, 0.1739209731139483, 0.19190586772897553, 0.11968934848423927, 0.12438858543793041, 0.20639380079603967, 0.12008420552217192, 0.1009950487904491, 0.20085903004773203, 0.10310087893759051, 0.19432540322023054, 0.14749809498748473, 0.13930103080647607, 0.19296726722630764, 0.209047743870366, 0.10152241605664454, 0.15974174283685225, 0.2541989436553371, 0.17395941540598872, 0.18081122919196085, 0.09715627413243057, 0.08161276383625884, 0.16260784630092884, 0.13991613812263937, 0.14522385573194874, 0.23093521294574584, 0.19536369750576635, 0.14987688992292653], [0.04356470830257862, 0.07477822533297925, 0.03222677173213132, 0.02401016464817428, 0.09659349062149564, 0.04351868174008785, 0.008573022787459195, 0.06576245830905053, 0.033177640063748244, 0.016160806708578623, 0.06441065786226143, 0.05575892049819232, 0.08430918648598656, 0.03491279090784731, 0.05478188260308197, 0.09250453463004482, 0.03737335040744755, 0.038461264207839005, 0.020991387521667827, 0.028813212261264844, 0.02185757249413479, 0.053485121743212787, 0.03319434461093718, 0.038389504751971656, 0.02075991405534648, 0.009883904562992676, 0.017644914370330594, 0.05025721027425701, 0.034146465496310306, 0.04683504572078105, 0.08347752909626692, 0.04156288991291677, 0.021522972101886428, 0.017706622752631386, 0.0935501986814122, 0.06808685334098917, 0.05544667838201408, 0.0618652158206509, 0.031147528131822907, 0.04282230398647728, 0.03153324574081889, 0.03642162405735543, 0.024799250531941656, 0.033757675874737963, 0.03180542911943649, 0.1136106170052963, 0.05266410531476141, 0.040646162289645404, 0.033555987906912645, 0.03727572399281687, 0.03321117556263362, 0.08898120433572801, 0.07354564348896665, 0.06636399054719556, 0.08384931922679947, 0.04434180874077063, 0.003154562620048021, 0.11329384730948557, 0.01959827003790246, 0.030907589393938263, 0.04753268751946669, 0.019155982581357804, 0.02653310285700906, 0.030423425656232624, 0.0262053934256396, 0.11814159806817771, 0.02482551585642561, 0.06915059706736958, 0.03398434213933445, 0.002756984533569325, 0.010851578948448503, 0.05932815861137164, 0.08382425282991703, 0.049831012579342054, 0.06289632037101735, 0.07152283429017953, 0.05213154014199973, 0.04557636709162786, 0.03264080012036908, 0.018784795745065617, 0.02222079201601446, 0.04563003921160295, 0.08648772603802143, 0.02092416713675184, 0.05903869228918226, 0.042278308781885335, 0.03420509037471587, 0.029964912457451708, 0.05924322627364628, 0.016040343212925138, 0.11073630107867141, 0.031984979061469916, 0.09664233638754777, 0.04225280571488604, 0.014515563943273118, 0.1264182970889153, 0.0410207869454978, 0.005042480732945185, 0.007934904584075295, 0.050860244044733625, 0.025978696517526143, 0.019888119404053977, 0.1209976427978085, 0.06105034341735225, 0.006814399488165134, 0.029188264011135025, 0.018686836082187873, 0.04927556436028212, 0.019126708446551236, 0.0574074536111326, 0.034169080411835064, 0.03415825558946498, 0.0632654062111772, 0.05486038746312261, 0.062361039416564096, 0.06891650358034719, 0.09486537246454148, 0.1030150234639164, 0.020479432029289105, 0.1070382567723432, 0.06098908319648716, 0.018633631275846593, 0.03753356620549195, 0.016318684023234154, 0.02883561841783024, 0.024204459867530295, 0.08206238083901905, 0.017567945516578132, 0.06545207012564906, 0.019959436444145058, 0.0051906617685040886, 0.04711511214413951, 0.054051122823429686, 0.057256419376860705, 0.03278812648908746, 0.06918532383297721, 0.039609204827537464, 0.03731717317996006, 0.02894512302572689, 0.02893510068045749, 0.047183374408632524, 0.010325909524615253, 0.04384497007835777, 0.054347311567154624, 0.06038261735210977, 0.014529885957017543, 0.020312545520644036, 0.059041978806377425, 0.013007770758122207, 0.037902632893453685, 0.06350251425418162, 0.03319696463163822, 0.13298285854679923, 0.02990625502030936, 0.05111617103759801, 0.04379001859154913, 0.07826395603197236, 0.024486117838551442, 0.027183436811150565, 0.06089858139955229, 0.03359383648081172, 0.05980995513739125, 0.07316340391914691, 0.031196709061341903, 0.04265772148726448, 0.06769755810138679, 0.03548862472657235, 0.04375614601397707, 0.051115822467592456, 0.051289364365079713, 0.04579673994392638, 0.047415529693206476, 0.023688446024372697, 0.027442811199674205, 0.0966540651936685, 0.02893302266696288, 0.03820429916583723, 0.02872748127687843, 0.013339512684803097, 0.008190097568947221, 0.07098104158836989, 0.019985056339552807, 0.03878806199457857, 0.005601094810352211, 0.05041830707341433, 0.07413189993390153, 0.038730398556517984, 0.05859608499092921, 0.06955231059222453, 0.0003382174045621087, 0.028609375416811918, 0.039071472391726515, 0.05006807465707103, 0.04623034953950875, 0.05361891133830913, 0.024193073885755676, 0.040416098425104734, 0.04479443263863364, 0.038528059413957025, 0.0026663144366935857, 0.026424772278856368, 0.018831603717239156, 0.0021434575131523514, 0.05311120954912998, 0.034228433073768695, 0.020455482205556288, 0.06178482638431653, 0.03048823477940694, 0.029275525256150195, 0.06942896277553613, 0.024411642600992517, 0.04462985396986047, 0.04782872687604639, 0.026570215986500827, 0.031906654232091484, 0.022826198743836536, 0.043911550779856985, 0.03853821390939336, 0.039700802130204056, 0.04905827501187882, 0.042676980937680895, 0.07386262002851694, 0.0504564582520435, 0.039261780123436646, 0.050538368372907566, 0.04412010672592348, 0.016935413530577096, 0.038819942743547504, 0.006556123957007884, 0.02443295708226581, 0.02614827199478544, 0.03247941986867978, 0.04378752880579522, 0.037892853781100244, 0.034225874340101596, 0.055185902052589005, 0.06379622853391113, 0.011734974086134425, 0.0375150881647583, 0.08762363524686906, 0.08624390323436068, 0.04377280459589055, 0.11519898540310322, 0.09863512260058234, 0.018326813062172265, 0.06465626565078575, 0.023449346152765137, 0.016847317249724464, 0.10252425987874308, 0.037902805263236646, 0.023910119310922684, 0.03156463619351628, 0.02437980398685942, 0.021857712305180972, 0.04049034000584676, 0.014178233405184603, 0.02781875161153655, 0.03651864143208631, 0.06727112291921532, 0.01059830166219223, 0.02310656777192508, 0.014210314294623752, 0.04537503918512695, 0.07482806701333293, 0.06642674846995263, 0.018644099867331888, 0.028090069310799725, 0.05893103395318312, 0.04834585920757344, 0.022190378325420524, 0.050015191607657945, 0.012712105827015496, 0.05176932611052067, 0.03136487493682052, 0.026060028242007382, 0.034422038813992854, 0.029560745536019246, 0.06093654871707963, 0.08341791979487866, 0.030788964509303053, 0.032439721192443566, 0.06437557103532938, 0.04221670382145432, 0.03414846498579268, 0.04759753303181741, 0.03559846641315568, 0.02274932182063499, 0.1326609177574996, 0.05379054950730455, 0.049864065442835136, 0.0910729997520966, 0.04120165264354118, 0.11959686635002015, 0.12910368041165415, 0.05165528243167266, 0.03170280015066026, 0.10424936731015483, 0.03894867232790397, 0.06263773505305571, 0.05118130766335995, 0.04545737065434937, 0.028451595778366732, 0.03499203121229526, 0.011623351245127138, 0.03377897311903296, 0.018840511404578725, 0.02995921276329506, 0.026013162813239524, 0.015284583111473871, 0.05237299956441407, 0.032037680165000984, 0.013449246161467126, 0.042101579958633076, 0.06668370968151478, 0.045193307807729136, 0.016374246465162407, 0.03771052485512149, 0.032043517754984, 0.024398963845845674, 0.11043498337629343, 0.08138152785719403, 0.032480147652207844, 0.05478583178633163, 0.033670219277302106, 0.029978470298491662, 0.03187699896854258, 0.0528137069646149, 0.06293407318392588, 0.07765158364969878, 0.06531331628080338, 0.05940612337942566, 0.019394477243505178, 0.056868644821788036, 0.03241871889199942, 0.0714895784133865, 0.05011025162774229, 0.03259530981942531, 0.05111062839146584, 0.0634200219064951, 0.062042404296657735, 0.05726384276884699, 0.06627824998671009, 0.02109152670469015, 0.08112323365264362, 0.05103459799542062, 0.08390831565784831, 0.030363546308851054, 0.03148984302946877, 0.030721064221354264, 0.06242943191600423, 0.013843105369878393, 0.026374564791518836, 0.09968326111594517, 0.2437071243841802, 0.06720211371899613, 0.11218499632612353, 0.16389283621984144, 0.10429056751872263, 0.13631040741118694, 0.14422165950940502, 0.15400270240441447, 0.1560444799402068, 0.11975985921679005, 0.12916708184826758, 0.19706159349410765, 0.13559874237304734, 0.11720367662248113, 0.19584283953712833, 0.17719691829575648, 0.21603806635304806, 0.18331178614208776, 0.11049152832598456, 0.0911863960866486, 0.1658110744169643, 0.11318751430559544, 0.13555219487076806, 0.14401392710785713, 0.07218724702514949, 0.14359409560359296, 0.24639164968844385, 0.11771717003636784, 0.1582565128562912, 0.17360750525709123, 0.17172985439819677, 0.1824307850291652, 0.1750843848792776, 0.13048109117775195, 0.17713443616465216, 0.16898704512465387, 0.15462672698401636, 0.10534167845523167, 0.07906035039453738, 0.13674002951912342, 0.17017944565703794, 0.13112138746486557, 0.0828634713205599, 0.1391668428456591, 0.21848352625966075, 0.1559057414171196, 0.1138610358259851, 0.196745551581825, 0.12940775603055954, 0.12386119518909725, 0.16810757618757988, 0.1478804494704931, 0.10659237827865348, 0.15609553203948084, 0.11014421470463277, 0.16298240200886804, 0.274549916146263, 0.10714620622175355, 0.18465463102104204, 0.20166674718981792, 0.12052584754964038, 0.15516536340357798, 0.17145930278685786, 0.12155660353000126, 0.25039557758117875, 0.11260206225298106, 0.1870258876513089, 0.09083914375233074, 0.1934712458281748, 0.08831977168278349, 0.1387807038883048, 0.183361581857166, 0.21365012432779037, 0.13665600499558833, 0.13014297061149152, 0.16227053778786815, 0.20563955659106856, 0.22341923157293953, 0.15450214576576987, 0.11722317356015406, 0.10906095871882093, 0.24820441290015177, 0.09427618956373585, 0.14871851901613897, 0.12137605192800685, 0.13946996851553842, 0.1546097811191313, 0.22881975307339625, 0.12564525308628238, 0.24624866703825615, 0.08592793793087045, 0.2197668614286569, 0.15540141041480726, 0.18554741456624002, 0.1820307798803814, 0.19353581171843315, 0.24840449974421533, 0.1029022170170661, 0.13025086643474718, 0.1129567762836814, 0.16617910305578865, 0.23635579062806022, 0.12445250015345313, 0.13053946707758213, 0.1610680095731251, 0.1553561192967238, 0.17649049329901897, 0.151242931944228, 0.12316123597444066, 0.09345101327785561, 0.1855977158993483, 0.1429380485487561, 0.18165309853371114, 0.15660496518736886, 0.1558106392621994, 0.19787569980948203, 0.20986673782669732, 0.25895074190151307, 0.1350264134065759, 0.2088961503919094, 0.14459440724984293, 0.19814136377986402, 0.25825268258490874, 0.1522800464543604, 0.1023059861073571, 0.1333792937258559, 0.14289854905538021, 0.19971250286025388, 0.16729138611305147, 0.10744353260604605, 0.16660593660368075, 0.177476387170534, 0.1425749075508887, 0.0655886176372728, 0.14678667509748092, 0.08596628829235993, 0.13950648026600962, 0.2329343653494312, 0.13980329337139286, 0.15554710501624694, 0.21490848503045498, 0.14619591405555127, 0.17502793952101664, 0.3692385674484315, 0.1606595468136572, 0.13427229177567268, 0.1496414864255536, 0.1391246926880652, 0.1811782925600006, 0.16974393999384296, 0.2010199391553479, 0.411745630084507, 0.16235902094312255, 0.08673753198837081, 0.133026770706619, 0.17622456885874274, 0.10538166058399986, 0.1563250213380783, 0.11836645253483327, 0.1348449731425893, 0.20775789695401348, 0.10310422674181963, 0.22020247434416126, 0.10353703577552112, 0.17425503341421006, 0.11152206980172666, 0.19210901892473622, 0.15273324874860628, 0.24516813066457552, 0.09863565886212934, 0.12163963213923479, 0.08461150776354537, 0.14360836016074305, 0.2140113501058471, 0.1126483339636076], [0.03441593692367596, 0.05821944935427559, 0.04615129309616262, 0.017373747973432465, 0.08630008812272742, 0.06539422282648664, 0.0697808882461921, 0.02141503031335531, 0.03491203248080227, 0.015853124730769667, 0.03146061294471785, 0.023556788068925662, 0.008005320034440487, 0.04625642334201163, 0.01785853607279639, 0.02809483820812837, 0.05279411809639104, 0.029514709397429423, 0.06217530522976191, 0.01646764982011049, 0.024943891762485428, 0.046642704025631955, 0.04980281288284929, 0.01468103510447808, 0.02875002149883057, 0.08651129856345155, 0.03629854820188015, 0.012843368289571618, 0.049052341660905274, 0.06231918420282103, 0.05803345852801877, 0.02086979404632603, 0.05118444862384951, 0.019482531389521978, 0.0513537195811589, 0.04965862364418084, 0.048381386535061945, 0.04330831782652005, 0.03591913932694062, 0.014878591943171718, 0.05224725389252267, 0.0708399971406306, 0.06069517739477658, 0.02559948874066674, 0.08185903812127729, 0.06599968509568323, 0.02725848852987251, 0.006972978730881287, 0.08179601972862598, 0.0187026979326601, 0.029452715647376837, 0.047869080557457866, 0.03793874627820427, 0.04809812169461962, 0.060553864816263805, 0.06986783922559793, 0.015627283925911593, 0.03400652804562161, 0.10867676562479428, 0.011710281157115055, 0.015237478280229675, 0.05439856284928899, 0.06605030052484044, 0.05711531364208749, 0.07040798483837037, 0.07697636907499644, 0.018314082596090533, 0.014988951696713847, 0.04627132758257851, 0.0558150785734817, 0.048736410831371625, 0.018073605681439082, 0.0375072855592495, 0.0190682674292475, 0.04504252255203263, 0.04110202673942812, 0.040871219769600904, 0.01938022800811356, 0.007231608098898564, 0.035316576700537436, 0.05511275980801833, 0.013389250943287006, 0.06331504487823095, 0.010183260122674608, 0.05900848544232788, 0.035253592781842716, 0.06291621950485053, 0.07916571812764292, 0.08647495535232368, 0.012839403784563466, 0.023783613296766436, 0.0733959958738377, 0.05958625746350135, 0.046839366456674, 0.043715868941358024, 0.10910314718081106, 0.049579762553255406, 0.025767353926635077, 0.05532031983978326, 0.02445871104306031, 0.0775613691357355, 0.03491651792559893, 0.04809070596351259, 0.06343466950760734, 0.03243867931286654, 0.10956555785190676, 0.038964438417385665, 0.06377306969596014, 0.0305313233947081, 0.01639053924009204, 0.004158156713651073, 0.040947403383230975, 0.07508338879673712, 0.03346206935783548, 0.030626910100240382, 0.0816386346254618, 0.029601744646506927, 0.056654251285738526, 0.10085542160536974, 0.04841562300439804, 0.017120839366989753, 0.0385301853079469, 0.023854777119272662, 0.02407410426155454, 0.02619654319489435, 0.04720426562632765, 0.03568641330686308, 0.07503121054821438, 0.04205035165913644, 0.03531561142975285, 0.029226390291906656, 0.04212898675412421, 0.01774774252196714, 0.04396451809894174, 0.028801719027180827, 0.08611926072908026, 0.019134020755788492, 0.0014051041263531173, 0.008939880269369292, 0.060166300935370315, 0.020658451455434965, 0.02832930133257422, 0.03213567238661551, 0.04129049202968036, 0.07996376724012437, 0.06463764205334649, 0.04112002597520909, 0.08018580250321858, 0.02073575738787411, 0.02633884785726907, 0.05026576747637122, 0.009553441045535429, 0.037637187258130124, 0.023689282975429972, 0.03684766853468553, 0.00582836867843364, 0.02925620068826022, 0.06301759591987056, 0.01913976833044041, 0.005612608633049194, 0.04964916245831598, 0.020088279026470358, 0.05017294443302578, 0.01876986852186101, 0.016048965532512918, 0.023810313376147422, 0.017041905497711514, 0.048723207305996656, 0.12539769177355115, 0.03860893914656293, 0.04809619881392968, 0.012391746051669603, 0.06487933513257774, 0.017215761491247726, 0.06888566088051566, 0.05756319928613882, 0.009973687194888631, 0.017794874166288686, 0.005710899628954189, 0.07015839339263978, 0.027484794733144587, 0.05377725788181829, 0.03283869978340884, 0.042526283782095685, 0.016754712541437438, 0.03806524271626146, 0.010390169937313806, 0.01614334756478427, 0.06645283376377437, 0.01567905806305428, 0.04601842280657542, 0.03632873589653642, 0.09690427717061774, 0.045162530225371166, 0.0058231075696136446, 0.03782451107737519, 0.04750830677127646, 0.021497511169722965, 0.0037943221668096925, 0.02805879185607116, 0.021401426507039897, 0.037558935207104495, 0.032511258482812874, 0.012603485093061483, 0.03746185654533967, 0.034693199465231556, 0.030319331544301206, 0.051604222671519366, 0.023846539758866834, 0.05847280229171438, 0.046443973157194354, 0.029045536085182143, 0.04891931049285397, 0.033559925598843444, 0.06264934894598781, 0.03961142265207825, 0.07431294949304673, 0.06971773195771441, 0.03933658094836339, 0.012765659203362322, 0.040051758499635805, 0.015552688987114498, 0.0549376474302863, 0.02019723205106153, 0.041112675361575625, 0.07846072571532381, 0.04469139764325754, 0.0855071488167009, 0.03171148375728198, 0.01851709972646448, 0.035256875468598264, 0.07121151914038966, 0.019385833856499484, 0.05088286279069801, 0.07101556151023797, 0.026293550993526177, 0.030804286267788663, 0.0499477107528477, 0.05058659360774102, 0.03755723066147297, 0.05640839834907844, 0.09918934890940305, 0.08110807277262211, 0.046340451695986336, 0.07210386601547081, 0.02812427513661885, 0.052673826970520525, 0.008117027145119445, 0.020318250960460114, 0.018182294405696374, 0.013527028983639134, 0.023577359444912405, 0.08231655349053683, 0.021354467232501315, 0.028520264069459615, 0.021534080376788493, 0.04779204275579222, 0.0404556094097995, 0.05815592917403387, 0.04931856487547198, 0.06202855725742637, 0.0416831465648307, 0.05894670045123466, 0.0572749778568264, 0.09327664400541014, 0.09216632979411273, 0.05241367500275374, 0.11689824502794974, 0.049775383104720426, 0.04421636950404895, 0.02668188479278357, 0.08652016986161472, 0.0911110513392956, 0.021541612936303984, 0.10065065396408882, 0.023561947671095693, 0.08790911025097294, 0.03018883995771889, 0.06668534910967273, 0.04745785222058335, 0.07095449664179357, 0.02568865754461337, 0.07714906061488776, 0.05230813873030486, 0.08102586387746757, 0.0325859482249906, 0.013274466074372252, 0.034725876945641734, 0.015004509984846077, 0.011174995414612275, 0.03953883582125268, 0.04270655576199774, 0.04928390322733791, 0.018649192436808543, 0.07331399382242272, 0.06363800839490949, 0.04319964442402125, 0.01298452286245001, 0.05996382006654336, 0.023177501768054023, 0.05445498905535187, 0.023938613951266296, 0.06652863816388192, 0.0339321983647683, 0.00983217160307592, 0.040151978121890176, 0.023479108668623433, 0.016369163471784805, 0.08697505754929397, 0.08520663550664341, 0.030488481842762524, 0.04343826549067613, 0.06499180450074135, 0.026099301739445618, 0.02615936303270921, 0.03090309628826236, 0.03907981891966155, 0.07466084534122099, 0.016973737078989228, 0.061175483879783464, 0.021342089166864756, 0.03857632678362631, 0.035650319074310606, 0.03394440980628133, 0.04038533616450526, 0.024112613586288308, 0.031225500560756174, 0.03449508146713338, 0.06269611861376513, 0.006017724545897857, 0.023364559371745395, 0.053212428916125536, 0.03190940257251984, 0.057198319268683274, 0.11112750387720524, 0.015914446238668698, 0.05920736952835034, 0.010683121959558659, 0.05170277605253843, 0.020772410864611308, 0.020318747002391085, 0.007027896701343238, 0.04096934797182199, 0.10810514145921316, 0.09420726463318833, 0.024726956729747118, 0.045779238665296186, 0.02168473156709825, 0.0472099653204843, 0.03877939754015496, 0.08065269478867132, 0.07777634106816785, 0.0684244912718573, 0.1892971544856987, 0.15335621612687267, 0.16031497578707435, 0.21542282114105843, 0.24515017356363036, 0.13656189875496974, 0.11229720522439289, 0.09436148579322523, 0.18098798099785082, 0.15104272252609655, 0.12575923930853605, 0.14141632213948235, 0.2086677642599229, 0.15775677838152455, 0.14789978552970195, 0.2575583004903409, 0.14738114400496408, 0.18046143344573437, 0.15846085914921376, 0.1399299430270349, 0.11205587220648605, 0.09371605671701894, 0.1098143755488338, 0.18128909951736852, 0.13599366069801394, 0.09795665215220183, 0.07752365462722317, 0.15467456151400844, 0.10381123396537958, 0.2405417563333627, 0.1073201924502369, 0.16481568105518818, 0.1309008613949822, 0.15130921387143675, 0.14647818681213165, 0.16401136534348612, 0.14117780832513688, 0.12376219364664248, 0.15016365195474318, 0.11560058401476954, 0.17891134646150375, 0.07904142802280766, 0.27962013117728696, 0.10744427571133261, 0.11966561508034507, 0.17579943602604253, 0.07083905485248373, 0.1264101305916425, 0.23583655155474142, 0.14529347780250734, 0.17144725988468817, 0.10466560586205415, 0.16112649272526466, 0.07766504381452838, 0.14017987155145215, 0.16812484380939316, 0.10123307230852305, 0.2206987154579932, 0.16339880143923147, 0.14331409046726842, 0.0787707231938839, 0.14928805942256607, 0.17496136648039665, 0.15713332070698663, 0.16289422528878336, 0.22561998767477853, 0.16716234626308565, 0.19379998947824204, 0.08455785096532877, 0.22088628442537403, 0.15751158428047934, 0.07453336831062071, 0.1273068211852543, 0.16557217755865666, 0.14463502523158828, 0.12421387908679825, 0.09024541795013413, 0.06250541634677399, 0.1289592575161688, 0.161564786948504, 0.15703035848996333, 0.1976128550426614, 0.10558344814325533, 0.1198740522827833, 0.11117043544448192, 0.258880598891166, 0.20598910718915925, 0.2894316337281658, 0.23140137744767053, 0.13171107598370121, 0.2960753320686279, 0.1852280018670905, 0.1430496522375653, 0.13096599419030452, 0.22997749578808585, 0.16304895972772954, 0.15793405112720307, 0.18764560681677636, 0.14598223681171096, 0.14117613825346195, 0.10359194895793354, 0.12822027378264936, 0.1327232313492606, 0.15687562405101715, 0.15278456131777457, 0.13281102502538314, 0.17866956911260085, 0.14569910603665537, 0.05843738221653527, 0.06065772335615851, 0.11909873299901524, 0.14171592380490997, 0.17928866008597036, 0.19931487258403532, 0.18645377318945625, 0.13466996801716669, 0.0872919344974141, 0.18440674029050336, 0.21602007860858596, 0.061031156745288646, 0.11928486938197767, 0.19164856943872668, 0.13312938052319712, 0.20045258976038427, 0.24036229257622074, 0.2869663321443143, 0.13128047328322165, 0.18713220533344055, 0.1343694623679884, 0.1250223240124122, 0.11945233620222538, 0.1523265939566397, 0.13637990690767765, 0.08678696764212462, 0.14439232857717624, 0.10322900714292642, 0.1108077617602483, 0.13870984075530884, 0.1352310508129097, 0.13055648955125965, 0.16066930677381255, 0.20226149188895381, 0.08576112994623762, 0.12122476488471993, 0.07379302860147531, 0.1647468863595878, 0.17018414943689303, 0.09469683312119977, 0.14207195550684007, 0.15507016931810688, 0.12166380987412508, 0.21822650376106464, 0.13822311445349647, 0.152246936134273, 0.19542352897265267, 0.14246684318828967, 0.09940435914623161, 0.20607601220328964, 0.08949769315339866, 0.09037148537895373, 0.09383899084622822, 0.129766101318021, 0.14939760999573817, 0.16556074752682642, 0.09975757930547961, 0.11237819603974782, 0.2122567023240751, 0.18160612202219426, 0.08403869616168161, 0.16867486429550957, 0.07977557008064563, 0.12080805135830758, 0.17456657072949797, 0.19811755376717738, 0.16473419994356173], [0.04740399623950643, 0.03895491977492648, 0.008010417391966668, 0.03596367584841867, 0.019395612968852925, 0.051421568158172795, 0.037951520794341644, 0.0975717849008018, 0.006260646717442621, 0.027041859932303913, 0.026653332695845636, 0.03012021954712128, 0.062009558276904214, 0.004598910557932311, 0.05123245935406416, 0.0323466798140397, 0.022142551456307693, 0.0921083752426409, 0.029947039626178243, 0.03628473180616575, 0.06277479201314912, 0.022033408824955265, 0.009718933274158308, 0.02366062362618264, 0.09959653996291662, 0.04331310970648643, 0.037956389283100446, 0.0369557443886034, 0.0559399126007432, 0.025616122424722682, 0.023417266220935894, 0.008210245681355798, 0.045217163785691225, 0.02161305638090257, 0.02796629823053316, 0.031924628570014914, 0.00921390513183489, 0.00932480018931411, 0.014359201567487852, 0.024583941520822626, 0.10552441340781028, 0.07180334504453406, 0.020917417902138927, 0.008760011443237384, 0.01627543069902928, 0.039570279900104775, 0.02354284143826414, 0.036799087068967284, 0.03148980664029237, 0.06662919486482298, 0.07682256160243865, 0.04577525117765031, 0.10012122592137707, 0.0503854955276174, 0.04866980331679506, 0.05895098671317101, 0.05678214583425753, 0.03634082859442119, 0.10650705140564712, 0.0199855025857687, 0.06052484157525244, 0.052165891524524464, 0.021492757594152805, 0.018804263954441396, 0.12189473175714094, 0.01708395797909508, 0.03565838214971366, 0.05539868680399753, 0.05290889338920674, 0.0318836773400225, 0.04912248084081277, 0.02042169964331533, 0.03752923014784052, 0.09110882202343595, 0.03920633067947723, 0.016223654646666783, 0.021833411996222792, 0.05120735465278549, 0.05456295382652072, 0.06522201392198763, 0.02666005894782082, 0.0011525038702999272, 0.09006687349850133, 0.08032692355975028, 0.014961913581036273, 0.04651314706631726, 0.04189288994717983, 0.021958148347273953, 0.03285484508641305, 0.019421014529202255, 0.020834073281636643, 0.04006649803129896, 0.030133218143976508, 0.04886856099831001, 0.04415070044717962, 0.03569369114214375, 0.03725011367350817, 0.014195794055628923, 0.02460768450081589, 0.017619928412680185, 0.021224988797198863, 0.02136819552810442, 0.033770848756595966, 0.023031546696720105, 0.011834632548984262, 0.06421965682097981, 0.04330307778511797, 0.01564707772265519, 0.009220812372082185, 0.07934544235467911, 0.02027915366324446, 0.04313098379380761, 0.03792720516362498, 0.012350530521343312, 0.06336221674216852, 0.01735942212924842, 0.01900891093687425, 0.007398898240118738, 0.053464985122123075, 0.02681405602713987, 0.039626392010118694, 0.058230067332906116, 0.004875159469403086, 0.04338007728238741, 0.025808268767451088, 0.03218639889852174, 0.09688349320523201, 0.03755872453292532, 0.018812267658030315, 0.00735109483244859, 0.02566855539748025, 0.03655832861700366, 0.043125904630869634, 0.03430937026296893, 0.04248379271537547, 0.015659699021207712, 0.061065653684518995, 0.05082766998619322, 0.02656129489262258, 0.08157621378139143, 0.08471673760082453, 0.011766030332974851, 0.07766629253784496, 0.05641207557111498, 0.014799003068718218, 0.05751934841335301, 0.05099150554967984, 0.0631521362811327, 0.03435885954287744, 0.05832490901793203, 0.014289035574503004, 0.09216827565744039, 0.07641288842405043, 0.07618483937075061, 0.01900577189160451, 0.017737505672078942, 0.020607376373523188, 0.014410473917040133, 0.019585198662694425, 0.0353028790484513, 0.018991631823742104, 0.026114929933100942, 0.049609754895490986, 0.020176727707768162, 0.0565833383570275, 0.030348887216419946, 0.03931229213072408, 0.0491675880977944, 0.0008300214328975868, 0.04730528964090252, 0.04860398870322013, 0.0137162507857166, 0.03324065079552031, 0.061133249452517885, 0.06517663087335325, 0.018937727962169918, 0.03537257772780234, 0.017074462319273623, 0.03373302699577424, 0.050985028276280056, 0.0347682875731299, 0.03471546198031114, 0.027181330069358793, 0.07931973244394026, 0.0274225864784732, 0.0012471819237332732, 0.04090881936492459, 0.04515732082748606, 0.099221877002668, 0.060563559658945575, 0.0677358778193593, 0.035887568843581026, 0.04084288600772139, 0.04255317346823793, 0.027580687873846585, 0.027792396271721493, 0.062074105014964465, 0.04133744172811989, 0.029315926818056937, 0.011671492210288924, 0.05095963629202978, 0.0993757764057767, 0.0722734778819065, 0.048645319146735054, 0.010500048013073544, 0.01826398044584259, 0.08058227598667145, 0.0289082205704143, 0.016057355152893693, 0.014557851996693402, 0.04959921352565289, 0.0023432419918883113, 0.03537264284527591, 0.02594653806168466, 0.031035474366358215, 0.009249952441502002, 0.0845695261452948, 0.08042361917755297, 0.01997422577152329, 0.01851794242318119, 0.025114844282788616, 0.031032115070810242, 0.0397379114292562, 0.07716843497849281, 0.02918750941452961, 0.01371339423536894, 0.04406599027495231, 0.04212865350587715, 0.03526442143465242, 0.027672105145850973, 0.03271380829955301, 0.04271803558954308, 0.028709129640652288, 0.033754473627214475, 0.0503192940396407, 0.0257297734835095, 0.025688203637518232, 0.03234821965076751, 0.03044840969866322, 0.006602870642147478, 0.045055185985420985, 0.03462736952989813, 0.05092375273365648, 0.0641175334702336, 0.013894017658106262, 0.05851710898681514, 0.0757349159328207, 0.007470959343106276, 0.013861412956048886, 0.007885949650493962, 0.09527900631749824, 0.03221946708377331, 0.03558019521616159, 0.030511945200663422, 0.01612696094408391, 0.05297230631713906, 0.047472338943231496, 0.03383597389103905, 0.07891700002214602, 0.035389883654011835, 0.003622195856165021, 0.02398864523838124, 0.04057625676655481, 0.06233831724872994, 0.057226043990662986, 0.03743838361133972, 0.04631415572798541, 0.08196269747831168, 0.02809950751402686, 0.034115086534931775, 0.022731577309088844, 0.03812442300841212, 0.023765640874062816, 0.05181011263160937, 0.005517602717924503, 0.0300686082036625, 0.05003684508283773, 0.029891029022814288, 0.06781620213822012, 0.02344646183173022, 0.018796357927062822, 0.027940722385181055, 0.014527999465504001, 0.02247880085281307, 0.008520939342317083, 0.07064276014364536, 0.0485874297127368, 0.02349581704625199, 0.009131116882687616, 0.07740851927308307, 0.014382998173635815, 0.040717695749575095, 0.014729367591620935, 0.04104299583442269, 0.032954348416458216, 0.03228083838738742, 0.10798218434736614, 0.029242282785895853, 0.033934102093260136, 0.032549539896389174, 0.02510034798404142, 0.07019118961667822, 0.04331067354688722, 0.034982489587198344, 0.027781134779234568, 0.05040536784837323, 0.02120872858100601, 0.07693773526097498, 0.01528090876226704, 0.05826041207558686, 0.050106137735588904, 0.03785152333758531, 0.06766732061101545, 0.04472785576757404, 0.017518124903642365, 0.02779066491301262, 0.10089840679880112, 0.04876944837310622, 0.040620253196046244, 0.059993440856135664, 0.09652266579289591, 0.057021594275870634, 0.13176067251591914, 0.045453969223965565, 0.08226442120728955, 0.017601513574200294, 0.022677796021584543, 0.022869074769738703, 0.013179333275935103, 0.00999393777155708, 0.016517242521888787, 0.06221495794072267, 0.014820898819204061, 0.04549999578645633, 0.04173565040072126, 0.006933928835355947, 0.048559957799772104, 0.008525048446420942, 0.05398667567679959, 0.029458300428344842, 0.04128769580875674, 0.062250094563369794, 0.07515027593340605, 0.08068225812166929, 0.02404343393150597, 0.043599297172359885, 0.05961192140896475, 0.017379039725769433, 0.054512916793746334, 0.018349598432260177, 0.012952050310559573, 0.04368782629288974, 0.18233994232310405, 0.11993366158417157, 0.13864944238335858, 0.10745673996186066, 0.12437758441533774, 0.14607698656618595, 0.07715301362857704, 0.23488094879975244, 0.11588746095977484, 0.1825415613430162, 0.1187800634051523, 0.17286991580359398, 0.286856996075761, 0.10556343026579389, 0.1686654567357994, 0.15815502152808253, 0.11674121232523073, 0.1512949799578036, 0.10802852500590587, 0.125742799061681, 0.1559504656301391, 0.1536508995078264, 0.1964475587010384, 0.10274517665346784, 0.15966139553535372, 0.12790410163541957, 0.12299222931746515, 0.09867373343196609, 0.1313774293709186, 0.06457724368139621, 0.18545482517971149, 0.07589384087271268, 0.1406091106154265, 0.1275672297924757, 0.1276008916958686, 0.10567068257519316, 0.12938650475154, 0.06047727900647348, 0.12406665230951003, 0.1795116989242454, 0.2753764943730447, 0.15584563415858055, 0.07895609348892205, 0.10757787378444787, 0.14978111361063298, 0.19326121516285405, 0.06838574254464719, 0.24081989221515196, 0.1051560017250238, 0.22122091163069973, 0.17256534988841704, 0.10275350402920477, 0.24693984688530046, 0.13515058093734328, 0.13843889077824933, 0.17249336826705164, 0.1333596818749943, 0.10498304971523824, 0.21378887817263606, 0.08638137005149357, 0.27427296003987717, 0.2186017642698942, 0.10144199214635358, 0.10749570319368955, 0.15497761057509532, 0.112362299715319, 0.10619834861567906, 0.171784445823681, 0.09161610246425675, 0.14176089316606522, 0.16856255580581006, 0.10334238815571993, 0.13152609639350446, 0.1421810617490161, 0.22620180080975258, 0.1783404117750545, 0.086499355252712, 0.08168211777604396, 0.1499113025924852, 0.23564616338379923, 0.09550160082477717, 0.055080798619817344, 0.222650523627958, 0.1756963052696759, 0.13345208740042103, 0.21692052303302675, 0.11586012694263652, 0.12496505894007222, 0.09796898616778274, 0.10248125170267398, 0.08463337191290433, 0.14857565894001915, 0.26784048746189765, 0.18795096946339454, 0.11256745040056207, 0.12939005939950868, 0.09020698331897298, 0.09268814292285713, 0.11639839563999446, 0.12313589378590546, 0.10663332567820627, 0.2087625293361564, 0.2102869983401991, 0.09145009121106518, 0.12829718134936788, 0.21372746856462574, 0.1302738337507171, 0.08639779497659014, 0.2184521626200407, 0.20654357098523649, 0.12248099586295506, 0.18426000380948668, 0.10578793999288352, 0.12475531172728348, 0.15982492466367063, 0.1007504828815018, 0.15197014856723048, 0.14504829902322064, 0.0953959956044151, 0.1555014614977183, 0.23593605105434698, 0.10842012617016032, 0.11722158775815081, 0.11120173779706802, 0.0869429737870251, 0.17792675493946, 0.17422097314509655, 0.12093578119792285, 0.06788646772263512, 0.1489731666421698, 0.1136727927012309, 0.1376640234863566, 0.18635626551845383, 0.12407889439454003, 0.09568897827017693, 0.10950663802965034, 0.22765795009270792, 0.1585373913328494, 0.108905695679207, 0.3029398169488676, 0.2104407062213267, 0.23841341086212667, 0.095656955794942, 0.22826870602946128, 0.13132597890592393, 0.2028294235107399, 0.16539852074798078, 0.12377315636483893, 0.24186194033151676, 0.12460272233452528, 0.12316224721050072, 0.20459346353046357, 0.1759489304235866, 0.12439814621522544, 0.11590920253506592, 0.10018798282309886, 0.0992227350211432, 0.09478643476482361, 0.22809523307988722, 0.08263042737399379, 0.10676789668298538, 0.12574819232066795, 0.19910796755744567, 0.16783933816177232, 0.18937163355369724, 0.11696194523885367, 0.14678863628256708, 0.1727985623743265, 0.09258802289203291, 0.21591327063018279, 0.14256022930625947, 0.15482768716831363, 0.3121098894025049, 0.13408335917178663, 0.096437921146712, 0.08104683170395513], [0.08974191432278003, 0.039217986707245155, 0.01820353227817724, 0.016858417863747286, 0.04318154942724974, 0.03758721917326893, 0.03149822211614059, 0.04680027298989796, 0.046074492781753504, 0.03233826050775186, 0.011595525974107367, 0.04174888840005283, 0.02337172803949685, 0.04342998791065428, 0.06043925423235182, 0.015090685300228578, 0.045960046906745246, 0.046716941775934356, 0.04466974416807775, 0.03382591515659325, 0.025397492422451897, 0.014416299058094382, 0.004585841097944086, 0.028306077377149658, 0.06486230499802098, 0.03219229011465946, 0.1041913208281321, 0.06124930794260675, 0.04893036514160134, 0.026123872094397104, 0.04473229907753487, 0.013257109394837773, 0.04370926909389035, 0.0954210160360221, 0.013645469049562611, 0.01079341946845694, 0.08813105358351624, 0.04456177173602966, 0.10371191066599662, 0.06348622722491142, 0.08900063232548776, 0.02960216216442566, 0.043640976185880365, 0.04269035683283883, 0.04650491162113125, 0.056517753569829854, 0.057064537334466175, 0.047175847594776464, 0.03375942638564495, 0.05637814170650898, 0.028424072154467146, 0.0509370366982635, 0.04178705107000086, 0.04484677942649973, 0.04988674930627308, 0.025231010025186885, 0.06841450914620392, 0.03716853680089116, 0.016823068651701176, 0.02061256661921019, 0.044627471436415954, 0.04167826658475303, 0.009304020054368003, 0.01807558793394316, 0.07107871779871565, 0.08977448838132043, 0.02035634085205534, 0.03229158660096507, 0.003362551661050548, 0.06488196281415802, 0.08466904862753807, 0.051362950940646475, 0.040217631857001016, 0.01462901869202934, 0.04290065562893306, 0.04804018246490629, 0.010740134222883611, 0.04320131066525656, 0.010778768036905076, 0.06440338768786, 0.05464872120008354, 0.04353722106785544, 0.06001401414734222, 0.05149079186301078, 0.10546810594537567, 0.03482323905993854, 0.11097037924393532, 0.0388063217002538, 0.011593410613826446, 0.026015305944207697, 0.0052052878233934605, 0.04201385139998409, 0.0782351817695364, 0.022681867778902094, 0.04405506969159169, 0.11220289214003472, 0.04695024236195511, 0.04677817901416172, 0.028726730510712634, 0.022118659089169195, 0.04867467563599349, 0.025895847938954834, 0.05528862678235578, 0.03160544378202289, 0.03176974665914332, 0.045609140333028576, 0.0461681661826949, 0.036213294107226596, 0.017484120175903364, 0.050299965641311103, 0.026590727990673437, 0.015540892190690485, 0.05595237302083162, 0.029710837482144276, 0.008181736676863605, 0.08538700324753601, 0.03935264964257518, 0.030990878473066037, 0.03637978799581047, 0.009206104441545904, 0.06192408584719224, 0.041066939912496075, 0.04163821167763203, 0.03659774001026827, 0.032854511838165984, 0.008652459401937743, 0.031051018290341865, 0.042759695450865456, 0.08524814981126017, 0.025290745731082656, 0.04487214076723303, 0.05845554233078034, 0.047152818991772594, 0.07543765849644139, 0.030160504280619567, 0.07368264299246573, 0.04570757497041937, 0.05708421430280132, 0.048147971035852555, 0.016760689942466638, 0.059638079481139306, 0.047546584354413134, 0.04662711413637285, 0.05956262748147692, 0.012901080565737381, 0.06262034868761417, 0.04401238327245078, 0.03467587821726357, 0.04498807668325402, 0.07303637121954272, 0.06150524642679, 0.07462823297828436, 0.03813394165087131, 0.019311077081628384, 0.040770345142171274, 0.09189544110408715, 0.02685238149077181, 0.05146573695744719, 0.059848512342620286, 0.006226517500415926, 0.047205012562053825, 0.047559768727590004, 0.07323167001407954, 0.03840064367039069, 0.04212413358712389, 0.007317160010232681, 0.010514625708662696, 0.03432544661805995, 0.02992624033903403, 0.02171638823534933, 0.04561005197765847, 0.031482356435228745, 0.05327445905535452, 0.04385967130562471, 0.07916717369469904, 0.02091917798914496, 0.10444060583869297, 0.08407651026162409, 0.03532493855023096, 0.04931506768409764, 0.03736976511596191, 0.0072360844464011255, 0.05590342383290972, 0.04933472166979506, 0.029289368464941942, 0.005632750999798338, 0.06662279803065524, 0.05437053169213957, 0.057235589446199525, 0.07674191552664965, 0.06213263030193987, 0.04526812395441436, 0.03935562589416101, 0.053829677448037176, 0.08195728123668702, 0.05072053642042222, 0.030522517214018493, 0.025804101249143004, 0.02826557813903257, 0.04090071032424608, 0.04891145426119047, 0.029094190329253197, 0.015353456331086496, 0.019504949037406235, 0.07647053654035253, 0.05041366458059319, 0.0752602095505403, 0.023351118359113895, 0.041578353397668376, 0.04173230642693178, 0.028703567842322013, 0.05905391445623771, 0.036598410337202014, 0.04182810189142343, 0.10719338957701, 0.07712926490292435, 0.03775983027392819, 0.011858942434041491, 0.020539361172385757, 0.046970643283378695, 0.0648257089778781, 0.04911159090096912, 0.03542914566013121, 0.04355479895527806, 0.0008205246957649868, 0.15028889200860454, 0.03365316616010762, 0.03638155765891556, 0.02506084657544571, 0.012253364717077104, 0.03188946130385082, 0.057406944162662954, 0.024486949043949286, 0.04992434890159676, 0.040118898445319746, 0.048625128899490645, 0.051234006851671204, 0.06460560425635307, 0.025177843523241823, 0.07806960718646165, 0.060948009392426866, 0.05676501993871024, 0.034224610295026534, 0.005600528384093196, 0.021203247221907782, 0.009389623676637008, 0.03570504073474196, 0.0576892092583641, 0.04272206904246442, 0.013752670605636895, 0.010755508649914015, 0.058270382709921374, 0.06197948166499696, 0.05051699835025976, 0.04807340386774271, 0.0661801371062475, 0.016549588669271722, 0.007308826410031367, 0.01849276685876952, 0.038882275487506585, 0.027815511059616844, 0.03601640184980727, 0.03362235793423268, 0.04264408129177267, 0.04642068791473585, 0.023840031841950073, 0.03955359450511394, 0.07149714736207839, 0.06610385007074764, 0.051326711151388385, 0.05845112200345724, 0.03980309402029361, 0.019428713712841272, 0.022775477977589737, 0.02138493071881033, 0.03007600478257143, 0.06183392495938367, 0.015365216738334107, 0.058010360977101716, 0.020096447438963, 0.014591946739763504, 0.049509519951478134, 0.06639256562677122, 0.029668526446086266, 0.05652100944350805, 0.014207632986888772, 0.007182434830258811, 0.08577509572909725, 0.05422144715163497, 0.057875043036596435, 0.03366211789750284, 0.04262315943056057, 0.02483630428961929, 0.03953784756783036, 0.032020311036537734, 0.021865038020956903, 0.0025337285572482695, 0.04279594673144241, 0.03149981940946272, 0.010659506341682808, 0.0522847538964162, 0.02002434132830991, 0.06796129919107884, 0.06240461066725755, 0.03187759077146409, 0.00811470494109897, 0.028695734593296246, 0.03821448430479054, 0.031782936777979616, 0.04672110546380282, 0.022159742469328548, 0.05469474776257431, 0.08918494541919039, 0.043281397496860836, 0.058302822703075026, 0.02574331791801078, 0.024175419389540632, 0.034855828440237435, 0.03344790056167591, 0.05874294021557416, 0.028433058365818956, 0.042847615531495506, 0.03590857880490442, 0.016828938800420974, 0.033032979681006366, 0.017224427860891147, 0.0849150164773868, 0.08758333902205191, 0.09547023718515713, 0.03434013252356841, 0.024483752542085225, 0.04458175513953452, 0.030678485054522756, 0.027709748791230303, 0.068891414200827, 0.03548346512440232, 0.005071684962228662, 0.027895791328422008, 0.07338223693471763, 0.03410539935312925, 0.05626768714958622, 0.026240641131035747, 0.02731671887299707, 0.0038000539408981683, 0.11119812952294467, 0.01920633945584057, 0.035034460991981535, 0.03540594468734438, 0.04729294030356312, 0.06738133998888154, 0.03733576230344273, 0.038829254542267135, 0.19839305430650714, 0.14986542924757928, 0.14398113854469793, 0.11946535203605892, 0.11353610729378079, 0.11313903626174697, 0.14142413623631, 0.12620784507523622, 0.2657559009328965, 0.0798853658019535, 0.1492041115078234, 0.21531592123210433, 0.17136191768992334, 0.150659479381096, 0.18353697002655078, 0.1434274255147865, 0.22769220954468175, 0.16528156976546013, 0.13205252137155304, 0.17190700456980737, 0.14743613379616893, 0.11472997871497947, 0.08773317815916193, 0.1265370100736618, 0.15220492387250548, 0.10581159678798531, 0.22492939005455664, 0.12300354443610677, 0.14458069427599832, 0.11025253953712602, 0.09421732336763414, 0.15662427060306072, 0.18861153643698464, 0.21059781553283816, 0.10141191553444633, 0.10884977892161378, 0.1647449864615356, 0.10635514383114154, 0.22828304719540382, 0.20105619043592485, 0.27282916009426117, 0.11004237863685816, 0.11473564010473991, 0.15661353005036233, 0.08512688575372582, 0.1250131616008378, 0.2864835435344327, 0.16294950619339943, 0.1861441970592545, 0.3448008529601559, 0.11589391142009728, 0.16223756536360712, 0.1469428651034832, 0.15060660399256215, 0.10682609638259297, 0.17769925746946566, 0.10216343246640698, 0.1290964945069244, 0.19153797698597755, 0.12498740572482349, 0.12412375650338589, 0.13154774603824462, 0.09870564099401237, 0.18922560187357088, 0.14367361553013325, 0.1825941456181388, 0.15180649686484568, 0.09852170328339262, 0.14307321710211618, 0.17359808237562258, 0.2598216000103182, 0.11850244846315154, 0.13492309878910744, 0.1768114534957755, 0.12555784245412197, 0.10130303145776834, 0.16732242799574332, 0.13346321099708158, 0.1807262087541242, 0.24125873802169678, 0.17597234207055262, 0.15070195129561811, 0.1545416452591458, 0.18803029020707454, 0.16065931698727995, 0.13896163853426136, 0.1528192344572275, 0.20091713015590945, 0.1344864899593015, 0.19810020953657168, 0.12051833988798243, 0.15369271258673362, 0.3077185508464613, 0.1714050637618188, 0.10528887967549025, 0.24876083788131517, 0.14108544876498563, 0.14301445815832386, 0.13997946295046038, 0.21205529780878177, 0.13617275673295223, 0.22263524783474786, 0.07776815158825728, 0.12899898683592198, 0.09171321176953855, 0.12813548317119, 0.10878093059985869, 0.1464460724063458, 0.18137510054774825, 0.19602264037295697, 0.1300264179946915, 0.1296054067150239, 0.12854382335658998, 0.18485651051084842, 0.18188845606580858, 0.23873050997574485, 0.14867403995125525, 0.12462394297002785, 0.09807841416688697, 0.10236823075120488, 0.09484477236025757, 0.15832297864460176, 0.1252629215859117, 0.0805590175572903, 0.2160345117050794, 0.06786709335903007, 0.13840489179616974, 0.08429788668910343, 0.1868379816052414, 0.1347533030615699, 0.11945751495659353, 0.21379640115605247, 0.14339149599113774, 0.10668829248677339, 0.1056730727695169, 0.21388503752889174, 0.13554292520688427, 0.1466361234986013, 0.1648543225300889, 0.09975790872328705, 0.13251905359568136, 0.16078846408955513, 0.08335018996149303, 0.25634394387804693, 0.12302029877901079, 0.14996667542765219, 0.17024255598024016, 0.09077770350080344, 0.11358115326372847, 0.15319461754012495, 0.23075749586907127, 0.2846280479383084, 0.14723223183424244, 0.10262664752982317, 0.14822672121226788, 0.196735423899466, 0.09753277570369745, 0.14800083252691454, 0.16146507294427964, 0.17071973682651598, 0.07350543919470041, 0.13096020256559696, 0.1466187792679956, 0.11124240174408882, 0.20426127248473708, 0.27798444152839724, 0.12565257688683848, 0.10191368780309155, 0.15942180919791424, 0.10376115479776937, 0.15708110415406767, 0.17085933336807838, 0.136170887478417, 0.13939391130641585, 0.1264225029116196, 0.24081647546300966], [0.06962089844408535, 0.020211404677660718, 0.026553484626234542, 0.03311536477638349, 0.06615869430524689, 0.05782130579914778, 0.03175050444570521, 0.056662628457190535, 0.08325554745932741, 0.057168989592502197, 0.04114531070714997, 0.04005422530275199, 0.03210814876271592, 0.03241505316128174, 0.010748340939772467, 0.031279197578588804, 0.03106926075903879, 0.018346706450346018, 0.02793196408498672, 0.021867721243911696, 0.023264889417576696, 0.015554274789117759, 0.045176974813183474, 0.02678999320543822, 0.04445824644438202, 0.03656054644154445, 0.0366853881296852, 0.016823480423960476, 0.024221003536255132, 0.07315759697268087, 0.0156179070097184, 0.03171880564261829, 0.03837653871385321, 0.027824535575364868, 0.054254159106001745, 0.10044013300249655, 0.01860969294343264, 0.0736597982505637, 0.04388656099176696, 0.05620695935982851, 0.033602056604239254, 0.015441580382626385, 0.046980433887051004, 0.04339949761126791, 0.013795881795005934, 0.010702749132178726, 0.014706709583650434, 0.05900485801600641, 0.12382658333667826, 0.032067678252896, 0.02969724133670811, 0.03633192665274105, 0.08118285827579037, 0.04455780340058189, 0.008965528893074202, 0.018732119539392092, 0.019701299287619132, 0.056389767090759935, 0.03309592529530487, 0.05845994733634496, 0.015423942165779731, 0.060995177425924814, 0.018994780445110895, 0.027892286476168423, 0.06025578000492627, 0.033248212083332965, 0.030042069002745614, 0.029490301836161848, 0.05647515525080024, 0.03471253169400077, 0.029397455810178674, 0.019546764031533274, 0.07185701716450915, 0.021979003175792676, 0.044187315619520606, 0.021768673736181472, 0.04181605898925374, 0.05141989808649786, 0.0318211798871597, 0.035328064188962026, 0.006692650401213717, 0.03110973509929834, 0.08172527150881868, 0.08311999586200522, 0.04472492165082405, 0.03207430874388064, 0.03655437177287475, 0.01731161824277332, 0.03294283028451666, 0.01659754385811187, 0.02153517971295984, 0.04494185476834255, 0.07913538870672066, 0.02331106153677308, 0.021581200529791175, 0.017452547777323954, 0.021368998005205107, 0.01779849967739034, 0.1146693658384104, 0.03943346808814714, 0.02936540077620697, 0.035350173486456755, 0.02030195818553048, 0.02748499966166433, 0.05033145185499903, 0.04077183901362362, 0.022499194113357414, 0.044058494104613224, 0.009544901080399511, 0.043352463643156716, 0.0582801235178786, 0.031669647695737026, 0.030459514143125668, 0.01231470154673462, 0.10809676045732153, 0.08305179871498578, 0.06736205755582741, 0.008579152448463344, 0.07986210737257235, 0.07183846251498308, 0.026969998969786593, 0.04483013233590511, 0.041806869764601996, 0.0897615951215548, 0.03508429118101636, 0.09231343399733306, 0.052524991408591314, 0.05800069677793692, 0.01185402031912799, 0.016813927307544697, 0.029782972321094527, 0.036745414948992194, 0.13594335936490567, 0.032531605778081764, 0.025866711699974634, 0.01255733308367311, 0.03485971250601354, 0.01986198239929734, 0.04894243485684838, 0.027801687003023205, 0.06359253724616382, 0.018216595992506034, 0.02288152561372807, 0.0781922655240182, 0.05012901695144754, 0.03655612228378173, 0.05770230170099005, 0.04071648150021511, 0.13495498336851597, 0.07077082706194732, 0.022102301196765997, 0.07788977570711605, 0.010432570031093014, 0.09633306669251573, 0.04448770635551022, 0.025055972341027473, 0.015962966417353, 0.019178654953476884, 0.007576251903834243, 0.04539393474377933, 0.0692569300712597, 0.043907896540458166, 0.04187733070143769, 0.06546715439687814, 0.038702796408606153, 0.018617252316025477, 0.024202933437341166, 0.063906702243032, 0.05098635743882868, 0.011944843872991062, 0.07474982645362616, 0.042444185969690164, 0.034631265086993095, 0.008263052121976451, 0.03402666466671132, 0.06684867905512934, 0.062493250870536414, 0.03505796839993808, 0.06858367668164354, 0.025401830395323136, 0.026316104622016993, 0.07577256149341983, 0.04884300047471639, 0.03786546996824684, 0.015256932125456873, 0.045582177868533524, 0.039389360575906696, 0.02592995800378342, 0.08529408444320002, 0.0236068174408208, 0.08730886504054071, 0.03359485537775102, 0.03472219972360519, 0.02324968831793916, 0.08806215163560645, 0.03172680934620721, 0.046652755099198515, 0.013149633004720654, 0.02372942598266227, 0.06124703266147164, 0.005729983357952969, 0.04887195859825419, 0.039681856775836605, 0.05214733687499839, 0.06445229474094606, 0.01853193118867855, 0.043096957998650695, 0.013827187978031655, 0.03453029469857293, 0.009527874776282379, 0.026760504566012856, 0.04615831812242827, 0.06588186077292889, 0.07790366488118326, 0.017396579308795835, 0.03744805164094414, 0.033498550464789716, 0.0215694640627912, 0.022114861208284577, 0.024615464123686957, 0.025479668758869655, 0.018194153446764238, 0.028781712641038244, 0.07347192284801314, 0.010604729139876944, 0.04181433146098449, 0.0401756425778712, 0.06439450106793834, 0.011610001205436645, 0.007943590584721777, 0.05327198076091948, 0.02660795156243107, 0.034327338855232925, 0.07877526609527488, 0.022726609228899883, 0.050851472338000615, 0.023544205074769356, 0.030918680431862033, 0.05808475194498897, 0.03907862382249967, 0.038765240235314254, 0.02590204559026226, 0.0325034597077437, 0.04137409137441747, 0.012278638915309023, 0.030414602238564726, 0.10377284529949389, 0.057195193629952214, 0.026740735667126796, 0.05076642508708662, 0.09193625060781356, 0.026318640373046362, 0.0057617295627301985, 0.07533911660674118, 0.06354980103130783, 0.06892118437756455, 0.0359331127706795, 0.037924761343146526, 0.014376207761796973, 0.025335102221898498, 0.05447781464505581, 0.04942995789010198, 0.00929361945318599, 0.019316238599018227, 0.04827781910857847, 0.0136216456303373, 0.006764801519532358, 0.00928526143393209, 0.03312551927181982, 0.07254183848178195, 0.10234096568197974, 0.05265955475249118, 0.05362925352528692, 0.07265115922857678, 0.06016898990398454, 0.0315278792949093, 0.025000892534491517, 0.045995784908412926, 0.05862035848681004, 0.03455860547781472, 0.04761971510766495, 0.04556165820348167, 0.038763562502760085, 0.03960227173182272, 0.07259686657738301, 0.05374882452850861, 0.046000136287822846, 0.011409149231058697, 0.04754134814345068, 0.04457839201354692, 0.07962517936023013, 0.05504781853467707, 0.034985170894933325, 0.017817900854072744, 0.023765625552304333, 0.06868660059427062, 0.013719589013846652, 0.014061881886464695, 0.056913323069532076, 0.009275520625974863, 0.023828864195233872, 0.05337952801416959, 0.053411519845887545, 0.053433318877772945, 0.026423167324655, 0.018052938544461807, 0.014346454822037731, 0.014380797586073319, 0.03028219543217171, 0.02387771187650581, 0.0060533145968351635, 0.013406111580890515, 0.04516202460734114, 0.04168385902660028, 0.035781703153324705, 0.024844373110681776, 0.06810098000231289, 0.007100682715029126, 0.03197820875943909, 0.053545056631968874, 0.08310711026311883, 0.03742729448863576, 0.04711799646517442, 0.018800148147068197, 0.04318821056175136, 0.021135852551989017, 0.032551887955877094, 0.016137927492719986, 0.05414412972787696, 0.062151878261037415, 0.041690975983416846, 0.03055855973563608, 0.058883103662200516, 0.04595846876562123, 0.04958696761018327, 0.09883639688092856, 0.0782067982119418, 0.06493130653736091, 0.051229663133140535, 0.029485961948070797, 0.02061787369330564, 0.021899787769202265, 0.01031376894623522, 0.029972174970973885, 0.055514109441109245, 0.04462323113975506, 0.10126086597841594, 0.025341378397218166, 0.06700994822406961, 0.02832141445739375, 0.053927047223213224, 0.02792386078996764, 0.22176080443445714, 0.12815227581849023, 0.11120671736857585, 0.11086010854811439, 0.2372155864272387, 0.1849196974428431, 0.18201905873513993, 0.1175279539799498, 0.1858604534138595, 0.1534769056184638, 0.09469464977061558, 0.10764736562005936, 0.1540025645085881, 0.19658291111550025, 0.18450334397775514, 0.1464030795520352, 0.14493425917481223, 0.09691398350461837, 0.16463076275202537, 0.1331431394623172, 0.11204530785401022, 0.13454981478712252, 0.08328167871842462, 0.12367509711053103, 0.11404599243354414, 0.15936027701583602, 0.1283957462217058, 0.18609763423521675, 0.14725374358315624, 0.1916007502304931, 0.0897224710112618, 0.07063993327920476, 0.2343214747886504, 0.19531590894104975, 0.11336412821565905, 0.21573880176630714, 0.11055270044673836, 0.14940445882178124, 0.10885144133240947, 0.12464216820174649, 0.1304475058831515, 0.08480903587394184, 0.17990588180480466, 0.10395589434812147, 0.06894084219370158, 0.1316359227583293, 0.1192308065571612, 0.11417148529642052, 0.24114728755047246, 0.17250652965759078, 0.15325849395125143, 0.203114653366708, 0.18052147941723948, 0.09027883470539125, 0.1296078735181401, 0.1256071555338079, 0.13944481018810503, 0.14493272699896367, 0.14360621511455507, 0.18472428373511762, 0.09063395476269145, 0.09918764053333191, 0.16494357177326757, 0.1400736764433884, 0.17716806742452806, 0.08656437313484569, 0.17886766412806127, 0.20915550179779532, 0.1600371310186963, 0.10799017464441639, 0.15399055224993538, 0.12628600136527132, 0.07489744393575577, 0.15259175230899166, 0.1861511378158485, 0.0939714091439401, 0.10136911420211678, 0.16744651891771825, 0.1346823939632985, 0.18014661727413056, 0.1277223089709878, 0.17846601955111951, 0.18412751656386162, 0.24017565823610754, 0.2031805675717131, 0.2795544314769007, 0.13007933934850077, 0.0842124755464254, 0.15218502090823266, 0.11876838056430702, 0.10154138439364972, 0.1244961441824994, 0.17939076428451847, 0.13488413555727852, 0.18414866059057175, 0.1890569399561613, 0.09595402170934024, 0.1788475313374112, 0.21917058455367244, 0.13760292031351598, 0.13249392591176495, 0.16751879165249486, 0.08564633167078418, 0.18419413556975706, 0.15597688034176826, 0.180273374182082, 0.10897860426696078, 0.1845136861647329, 0.18421641340659511, 0.20496464845153595, 0.10142290889615975, 0.13086300132976425, 0.12111842421995056, 0.0940972620681409, 0.1662680458637976, 0.0968477858470813, 0.17430283730068516, 0.13301678092008637, 0.16345834179270655, 0.15660262095832056, 0.08741467710464232, 0.1200076733385363, 0.1419981352744564, 0.14905443324917747, 0.10298472468651111, 0.14521247166539394, 0.1523127430869687, 0.2836287934933939, 0.14259188405929074, 0.13415731729999666, 0.09299794887943615, 0.1540349087407512, 0.17091142734692943, 0.16696572213643984, 0.1065942628549472, 0.06875835238925873, 0.19043631190734525, 0.1848091662771279, 0.13827222068944287, 0.09620228782296182, 0.16185104336229064, 0.10532402778945624, 0.1697544507201641, 0.15050010244932868, 0.25490662503627043, 0.2623762274461408, 0.17984329242139094, 0.10654729400430957, 0.2264425056355615, 0.1552321969140922, 0.09143345944222905, 0.21915184604304455, 0.16526139100953458, 0.14150580120903833, 0.19596624097997145, 0.11632410043309774, 0.09459066865665298, 0.08981140615839152, 0.08630667647887623, 0.22998163266287697, 0.19898638940386235, 0.14614383539845868, 0.21782432292257586, 0.16865837808337905, 0.12233137889134309, 0.10775792742929152, 0.1121720877445994, 0.1806883180453893, 0.29622956088954405, 0.07115555641752097, 0.12329352403720542, 0.05131887790236262, 0.18530381392807732, 0.07331063069643513, 0.12011031379863141, 0.14848873860413028], [0.010393109799723231, 0.04298644598513361, 0.03665564476602501, 0.10942079021685547, 0.08738358925667503, 0.048776538516845436, 0.023932711243809714, 0.03812385610334816, 0.09093390116768499, 0.028813811725065596, 0.016933414041094722, 0.05901959754766957, 0.021666372269992868, 0.030252296935706854, 0.020648806408468275, 0.0391718375706865, 0.0384054049068401, 0.035108212276452014, 0.05236896611149273, 0.029641883823299603, 0.09375569410622121, 0.034972572579018535, 0.1058680804506425, 0.018606956094323147, 0.0249538547359407, 0.027144573170751817, 0.03857392892842332, 0.03029282873256072, 0.04787605195756882, 0.00408428524913747, 0.03639086179675595, 0.0100599285853546, 0.04246447580836473, 0.021243847966674837, 0.03985796123743057, 0.04988096151200514, 0.015725398721594005, 0.03956626559938154, 0.06393548799678683, 0.06735334713612834, 0.027608571559070583, 0.025022419605163798, 0.08636182714854518, 0.12895188775033722, 0.01655431543176453, 0.03439340244738325, 0.08067343278878158, 0.08818703162814341, 0.055949293347376014, 0.04196217493905176, 0.033920435084690975, 0.04835337836055025, 0.021862666978831255, 0.06026760074159792, 0.047315555219087875, 0.06343620934433515, 0.021048953283518072, 0.07678382819698704, 0.009987798534453878, 0.0887585791849321, 0.0051241825736548395, 0.06223647735051571, 0.09027932500166279, 0.039176246406690735, 0.054223381523643775, 0.05348579590058616, 0.044706899432405356, 0.04396605410522992, 0.04763673375090284, 0.02562791251787736, 0.05768365895135268, 0.062172765648292924, 0.06531460330851617, 0.012168418972813075, 0.028302300563682953, 0.042007952522967136, 0.07615944355606072, 0.014635427975125853, 0.08352969968391043, 0.02568369904052346, 0.06274832367536522, 0.04348183674136958, 0.0605733540930575, 0.029833606902449846, 0.008964189196816616, 0.05556674351194694, 0.008472808910864256, 0.04416835111295504, 0.009662003365285214, 0.02193948836065829, 0.05192883327723511, 0.02934746091224013, 0.036721118470473636, 0.02739827467819616, 0.02886484084170192, 0.013232992946981423, 0.04148256942449559, 0.027780688533018676, 0.04748044032303076, 0.034689755900011915, 0.005568989980665426, 0.04942445737880565, 0.025428166582940087, 0.02933609408266362, 0.03005781785524901, 0.04750194441106531, 0.01640966079468208, 0.09111652886795421, 0.030737349335404656, 0.02041785388193544, 0.046755805416333104, 0.0578616671414385, 0.06618716979339238, 0.04904610570520163, 0.043192213371155724, 0.029230080920481877, 0.034862719401116335, 0.016146235716258808, 0.01647444501999886, 0.01152576121967286, 0.011646016913976882, 0.0318503161261399, 0.04986678888540595, 0.05165210699722652, 0.17645312353007256, 0.04135837508065086, 0.04626993330255632, 0.037622780974714026, 0.06689374800771475, 0.05294576137056274, 0.05640554084112087, 0.02564823874572833, 0.07901729625319281, 0.06750497125810193, 0.09798322008141587, 0.03171091876743782, 0.08404131618238266, 0.05390204594380433, 0.015694098284227714, 0.032902116541780775, 0.036919305416485, 0.011171083578148918, 0.03713868235448196, 0.02581619203180796, 0.06830900351727201, 0.03641320092062797, 0.034816834564891555, 0.033106776930752306, 0.07053807422879242, 0.04868152063159693, 0.05959939970184238, 0.013944995063807697, 0.05473200261833207, 0.059108850621287866, 0.02685808693058789, 0.031307820538659735, 0.03705777197835907, 0.034177354161417296, 0.058738324535830375, 0.02108327785296546, 0.08579510594567946, 0.05422690935853509, 0.1273811317139095, 0.029573627304466023, 0.03690464632405389, 0.01972093986677787, 0.013874148210180143, 0.041920664464874614, 0.029661738907077143, 0.02113023138184461, 0.014555735678802577, 0.039794613426971825, 0.025327801403980103, 0.06613443996156416, 0.042270448719782215, 0.05706971225839469, 0.05982980830594898, 0.02782295743424085, 0.06951997402094065, 0.013306878296838654, 0.05039117606957594, 0.03764110962830244, 0.015437286459810793, 0.03176029504937751, 0.08078955639634403, 0.053981581192103126, 0.0250065271111746, 0.017623753106642156, 0.04847092689165185, 0.04215853476536371, 0.03312279965968863, 0.0027581590421182378, 0.04322297563175521, 0.028689864444576448, 0.04505797071502574, 0.014154915603989316, 0.08765195751742971, 0.02753733687343136, 0.053201891376727053, 0.0964984497536094, 0.0177635028657894, 0.08184913260441634, 0.01170473946859279, 0.025558334497374394, 0.0662580635699053, 0.04080785663738366, 0.06400235598125766, 0.011693693438334572, 0.021346873385951887, 0.04765125111706796, 0.0413870727342944, 0.03885162430965612, 0.06398024668376293, 0.00647405535170448, 0.05427637182536626, 0.055733988166696606, 0.052852436539626894, 0.04130639984542805, 0.01822936667820379, 0.06637611771903693, 0.04944779241697923, 0.031157247872362216, 0.05141953419473383, 0.002114727061369547, 0.028508355232676672, 0.015962325776326322, 0.023416965531425613, 0.060829350033835064, 0.06863407760618195, 0.03257663259583135, 0.04906044687114416, 0.05318598739141899, 0.021337232169424816, 0.04870381379019349, 0.027355846813729694, 0.052825703901509126, 0.035728153607417504, 0.03485584759243554, 0.04328293733358864, 0.021124426350598375, 0.04002162060069461, 0.03195874821094256, 0.046970195121943, 0.0789755214786818, 0.06287414978648867, 0.006788151879464427, 0.019551291611165773, 0.040976277237097104, 0.038179811165337606, 0.04774444571305667, 0.029183418505013953, 0.009629415900206134, 0.10166342986086685, 0.02861992253230945, 0.0223222412093873, 0.0068180182959974535, 0.031675286102859725, 0.04627755970784253, 0.04061718884434912, 0.03634992588852202, 0.014798542458353745, 0.029315612722007982, 0.02806902870595936, 0.02567112562246621, 0.08934100519024557, 0.03876786408645492, 0.07214081443605885, 0.039343659600783745, 0.02504992407686528, 0.026329005542661876, 0.008672225427994085, 0.014649894587965983, 0.01724136414967718, 0.049530273273346886, 0.08721181702229285, 0.0439909098279332, 0.04546682417933499, 0.03996389587560008, 0.05483240610168827, 0.049555037065499255, 0.009813605462230984, 0.01625798687699341, 0.07374987486870059, 0.0029364832434728145, 0.04625423233054819, 0.034119292357636076, 0.015324207094137468, 0.06032620263736575, 0.06200325720372701, 0.02330114835903289, 0.013227154399388501, 0.05287615845220224, 0.06769408006221056, 0.047140542432786, 0.050559837986985524, 0.002587182581567416, 0.08432388771325351, 0.0377702490696984, 0.06070360819238329, 0.0261787622941718, 0.07598336590754409, 0.09679805141903701, 0.059322359325784835, 0.05109831352808303, 0.02759690787042341, 0.0718471652738029, 0.024661835425743656, 0.0954475379999607, 0.023171204525316437, 0.02291571994822833, 0.028157393117585493, 0.037578141031366204, 0.039738987782789816, 0.04236686471549254, 0.05540353614055822, 0.0488774897530675, 0.03907208143162631, 0.06020526799763884, 0.0402954817118664, 0.023251647587805506, 0.07600218102696442, 0.09631439712980101, 0.11008849712989985, 0.022071527444847652, 0.003207598168838529, 0.09150416935764014, 0.05012445872829807, 0.053721793116100376, 0.04309553307511153, 0.022279698431732196, 0.04149511411425568, 0.019476025387825027, 0.0740203039059716, 0.031851614645171555, 0.09744345751260558, 0.02382585730013107, 0.03447020276179237, 0.020946632665131363, 0.06922434835184006, 0.01584540064927311, 0.05973787775503532, 0.02574796424127154, 0.034672672139300455, 0.039644008201937524, 0.034124720090579604, 0.05603665801426096, 0.021665629164706317, 0.04133611639601089, 0.011717877876494202, 0.04449011570203208, 0.0436091069282303, 0.03536878176213753, 0.10039778366204231, 0.12212361584627822, 0.213484971093074, 0.16807671816598985, 0.17628832269580136, 0.18453248596239477, 0.08807964142291777, 0.10373289381424267, 0.11541480769313152, 0.12751211742720298, 0.17829455375190706, 0.10157028123015359, 0.14434495369993872, 0.11613571941251717, 0.10606538639554094, 0.31747333224742647, 0.0685742921045711, 0.10961516970588316, 0.18241296582404645, 0.09736772972129046, 0.18046255193410382, 0.10205948199596136, 0.19101988704454517, 0.18455600486167018, 0.08800219759465226, 0.15991360700178534, 0.1345101161108863, 0.1519047706237724, 0.13170528435899367, 0.10303705615261871, 0.21268923556612385, 0.10271310821295747, 0.12352189484743342, 0.07106443025892781, 0.23168820076652114, 0.13472152573447074, 0.1004654139039978, 0.11571164378115248, 0.20938563461024917, 0.11333254241054097, 0.20131362662200006, 0.14541300284045358, 0.09726372562469014, 0.17774465583985855, 0.12464711712973735, 0.08447905116143727, 0.17400367996625363, 0.18696565781870197, 0.23370670455117382, 0.08318119862627599, 0.12006627906474376, 0.15414304971214265, 0.13515231229605215, 0.17748974774393345, 0.16974913406996958, 0.1258401075498231, 0.13080228120088577, 0.17121734157685312, 0.12627422659387513, 0.19011018827797907, 0.07648901458108619, 0.16814390407694926, 0.1538465890072046, 0.11497154155926359, 0.16228866342815662, 0.148315510802692, 0.15356545006075215, 0.1768472604453564, 0.21619088557218352, 0.15098305959855357, 0.17256420075653062, 0.25308082300809126, 0.1428173437354065, 0.11805235648587828, 0.15075383076985038, 0.16721290806608816, 0.20045387678809706, 0.13095957437349906, 0.15751850971531484, 0.13895238419213604, 0.1299076896881865, 0.14906561813287197, 0.1553574063244366, 0.19787295721471312, 0.1889187223728626, 0.08911313233716835, 0.0946338223894277, 0.11445522894181552, 0.20637411233638564, 0.16085237114419862, 0.12279497699872141, 0.13471723564209478, 0.08771124506188978, 0.12797051379757543, 0.12027645528677011, 0.13766365576415293, 0.2529117320814441, 0.17333031932432807, 0.19127923845043107, 0.10965586429642094, 0.11329546375500579, 0.11605385525692856, 0.08182450287765072, 0.1325675469612883, 0.14681584772563752, 0.06439368901473862, 0.1695594813434347, 0.19564796209094987, 0.15294691067068808, 0.1421867154778973, 0.15095040893122075, 0.1481454852487772, 0.21570362300882417, 0.15337539896849664, 0.10554659931409745, 0.13113160707777546, 0.11313854596547543, 0.13331682691651006, 0.09090688890747486, 0.16994378168977078, 0.2065024780289781, 0.1587191073884887, 0.11125806824214036, 0.17029679500527922, 0.37417097858363585, 0.17849153027899806, 0.28403607647745843, 0.08576162024250916, 0.15833756495868007, 0.14786031667984303, 0.08435800926940096, 0.1981525793070755, 0.28389110199866757, 0.1563964513761382, 0.1728404214185092, 0.12397170337217471, 0.19569156781559993, 0.16745906743791797, 0.09431813287759021, 0.09576638379404623, 0.17352941025409008, 0.13812165376880478, 0.15473253904811798, 0.14961004617714113, 0.13309758787433948, 0.2201963609625255, 0.1353449834090087, 0.13391236834708722, 0.1721178932536033, 0.19699826866628664, 0.20513916328068704, 0.09400006083230819, 0.11165226644445812, 0.1783785016666497, 0.14145041305211284, 0.11850873804500989, 0.275387924404875, 0.10115260243295662, 0.13902179175807586, 0.217461641577463, 0.1938086309500279, 0.17013280622420773, 0.21684903170793288, 0.14246658271839543, 0.18872582143352878, 0.14134165921038197, 0.0925912251395564, 0.12455628974543465, 0.1422598615529076, 0.17722569255819245, 0.12159769648625968, 0.11154495284802492, 0.13052701048793333, 0.19512158307817676, 0.16471870964573276, 0.17351428767846477], [0.03475768108581824, 0.04382273820679515, 0.015478464643350773, 0.03933954953906998, 0.03935579443350434, 0.03407802320115509, 0.03249376103462231, 0.04031916915048515, 0.02979781144418784, 0.0258902938015038, 0.04842142995086409, 0.0473346920954364, 0.04958159350339444, 0.0813232668705525, 0.09395397298278348, 0.036457285450230685, 0.051688048012194135, 0.040832260368211616, 0.09602661620104506, 0.024005591103266326, 0.07318308471792168, 0.01199473247623011, 0.010939419547456407, 0.039194552077641415, 0.030048542445705786, 0.027397217476860653, 0.028501569608887358, 0.036053311965999105, 0.07923538616347699, 0.0478339899000862, 0.015282047360444502, 0.04470189304782018, 0.15434157373684068, 0.03080454865290273, 0.029473296599462632, 0.030144491127782294, 0.04223672552935539, 0.016796950799142642, 0.021953542243629214, 0.08333217157351394, 0.053880017085541645, 0.045959801758609475, 0.02746106707490981, 0.05246962240386394, 0.10546613709941026, 0.04595861049188722, 0.059331916272640235, 0.05014209024187538, 0.07428277328970932, 0.05945123829728654, 0.03366803592671791, 0.04928325205260227, 0.009455246768230873, 0.022437462748418895, 0.07467065892753101, 0.037604502116840695, 0.027955653438825282, 0.03236440708860755, 0.02858919283044675, 0.08356690091351349, 0.04544522816074952, 0.06524918706066186, 0.02445928369378371, 0.06040994370836885, 0.06763597995403313, 0.0828960607008588, 0.027404359331534758, 0.056478817151078296, 0.07102396549476732, 0.023006991663527106, 0.06434898778435684, 0.017803919749454628, 0.037571154309496764, 0.051766752055095094, 0.05274644444486307, 0.010449961184584087, 0.039671403506109794, 0.0482649564923298, 0.05171416011909324, 0.03191841176650938, 0.026662805373029366, 0.07502891994532078, 0.04257460094748005, 0.020612064831619783, 0.033538199345310854, 0.04756672480594247, 0.03734308993443847, 0.019443005083068725, 0.04077320648056846, 0.03209540872053514, 0.018863017152574275, 0.04591036993529528, 0.040570204671953, 0.011987631798781937, 0.013621749052207076, 0.04238543468677709, 0.0212633314978091, 0.0551252470411841, 0.08668320869366009, 0.02590176405295009, 0.016583805986409707, 0.005750312458633656, 0.03733956209954716, 0.0239746775403018, 0.019767039207621448, 0.1162377393413936, 0.0691868789914635, 0.04320265898000329, 0.07433565633912241, 0.05158489427318977, 0.031030697808150324, 0.025789432580612844, 0.050839230252970616, 0.020313958952864333, 0.06699312493325242, 0.025097411952071616, 0.04528308565157556, 0.0654661278390596, 0.03240400234297399, 0.05228501436631045, 0.029367587957230788, 0.014014857494452549, 0.04002091196936466, 0.034657319737297874, 0.02293885197310198, 0.052549467917772076, 0.07852909906256585, 0.027719564292760148, 0.02088508707651448, 0.02556315893607755, 0.04542753919057789, 0.02449493168012029, 0.030416628541124445, 0.0565568317148474, 0.03943509602498624, 0.04047017657167969, 0.037720740637591774, 0.07242667248412486, 0.007670282493270333, 0.036474928455126863, 0.03738029499448115, 0.047490977862429236, 0.024399182180904096, 0.048004965403027115, 0.04754569186198135, 0.039328973695275285, 0.052320204615112276, 0.05356548436646981, 0.05610279055432447, 0.05848136332426822, 0.015399559502369695, 0.05762960761785508, 0.08397067521488474, 0.015579631341801537, 0.12723787327206906, 0.025740309107688167, 0.03033712202112281, 0.028190285102614475, 0.01814614463176939, 0.06160007662049705, 0.03494149239193048, 0.0589913786989787, 0.0676948921154103, 0.0028084361955763833, 0.053477763468700076, 0.0408989061871844, 0.022538444628157926, 0.03201992224691616, 0.0547365187066457, 0.013942440160580221, 0.04316943757716687, 0.09021925604751996, 0.003609100780111828, 0.024798624255063555, 0.0689779821362707, 0.06495699346546205, 0.04735887749120594, 0.06721139870463841, 0.010614372271623825, 0.09087660545182806, 0.07166804625622689, 0.028896731166769902, 0.0018516981940446123, 0.02403852330791133, 0.056786148643661896, 0.04679616675862382, 0.024892558125899206, 0.005214921379041288, 0.06891549234428714, 0.1145129613277893, 0.060730394456655755, 0.02561753394172317, 0.032412559545088204, 0.037177289355426066, 0.05230811574766713, 0.015076723347808567, 0.04667684473397751, 0.060947296930657285, 0.013048564940090141, 0.1405173332820977, 0.03799938979829031, 0.0254792474105113, 0.09602865399492365, 0.05629296805108747, 0.06603748387386722, 0.008369866803648972, 0.018448331843941443, 0.044654728844761855, 0.08777073178921016, 0.026270570271017573, 0.015257104495239836, 0.01371787776494579, 0.09347951174863885, 0.028125010581026157, 0.04890476631361151, 0.05539055861112091, 0.007270454023514064, 0.09508867943358999, 0.010988354371229728, 0.04528574014623319, 0.015038507051705835, 0.05606604131659674, 0.08085007734236219, 0.05018245541460572, 0.027919026775165435, 0.05736687776422309, 0.03939252834947359, 0.021956706186756495, 0.04232940301599522, 0.05431967494528621, 0.04715502532499452, 0.025154033510555184, 0.07580670603220502, 0.0271888300701375, 0.01870400219735119, 0.05674170022229514, 0.03896951374988403, 0.010523903991035637, 0.03693161644942818, 0.01753073471087602, 0.048112493504079125, 0.06222186805379968, 0.042643410964838924, 0.03057773491638082, 0.09816369507461788, 0.04491791069026917, 0.02176093241770662, 0.07820574867148554, 0.06005786502012803, 0.0723566826913626, 0.012797028588641797, 0.008963728586452143, 0.026365760526049043, 0.03127451295093183, 0.05521653024780174, 0.045157768988921765, 0.025785839628247965, 0.053328770858746384, 0.024022713168373993, 0.0888194831749124, 0.03388922083221617, 0.027372608817512953, 0.016097116073773756, 0.06903859501283977, 0.02747762989583275, 0.04726484785937975, 0.006064519590337671, 0.0235031561685666, 0.06657894715786943, 0.016464688890283147, 0.04032807109216529, 0.013555742916651072, 0.03989289867721739, 0.004465110907931963, 0.011754329297541371, 0.03892162942417687, 0.05231007310231367, 0.05306820137306087, 0.03854600502358329, 0.07107662637868235, 0.055858458302194075, 0.022105210415658452, 0.0201586403718759, 0.07518596030891904, 0.03427576198573074, 0.029879411299442573, 0.03577986454230643, 0.04656014656047187, 0.057723533827811487, 0.030717122698983843, 0.05454384759368916, 0.021521361402025627, 0.04754159712202607, 0.013148927246220412, 0.048155191414538896, 0.03113753451485067, 0.00840923318924803, 0.03485906899215714, 0.019277784815658967, 0.02179805703851725, 0.023254943681099725, 0.02667803520096406, 0.023337326861257036, 0.05887369993292998, 0.04349389113485814, 0.03981404907761082, 0.07484533463514621, 0.014686886100999772, 0.08670793035097661, 0.031989629215170304, 0.0351399053338795, 0.06628561209166242, 0.029474455307448105, 0.023549535131502538, 0.011819667021383443, 0.05540465462892767, 0.04509313415075022, 0.015836909522242364, 0.02031866847837885, 0.026059576250132055, 0.042098331745834126, 0.04427748799864804, 0.06059047998860479, 0.01772056172241367, 0.023694919467332865, 0.07396449440068777, 0.03940429929043016, 0.05029285251493416, 0.008098545273946179, 0.025631710398761977, 0.06193714764630122, 0.010354900206889837, 0.04187479878084795, 0.04056196922676698, 0.020373405460568688, 0.09196039003830764, 0.067692547886362, 0.036656177197132385, 0.00846276549817694, 0.030580100212847034, 0.08897336725626262, 0.03793843601259493, 0.013848278378587098, 0.044450378721399654, 0.005699269456653706, 0.037815141822061235, 0.1313239870773208, 0.04296115359231349, 0.04433356180426575, 0.03989900056753428, 0.11325033351538644, 0.039207200189271284, 0.19775891736630472, 0.243664775043726, 0.12767192336820787, 0.19899746703524746, 0.2168651195543428, 0.13731033601347478, 0.12778600918189173, 0.2001511341621799, 0.11457867634993409, 0.1714856868549701, 0.1369844115669689, 0.16638999173958458, 0.18959678679464326, 0.20392561872159282, 0.23955840587375626, 0.13925382446858192, 0.10854677582580237, 0.17558468625910822, 0.1721662334016254, 0.09511111048801292, 0.10411029170838096, 0.11336188357804092, 0.17346349604908498, 0.15276010779123153, 0.16120651826983498, 0.10074757940826878, 0.2029568852195817, 0.0770241269961961, 0.1841375369939112, 0.2597496183889528, 0.15006796757300056, 0.16198230486723686, 0.20398278420250263, 0.16465311719765588, 0.12994011052914206, 0.07966134637113541, 0.22554370063927867, 0.18258660731296386, 0.1368958211594051, 0.11497851295937454, 0.09294008625851524, 0.16922192768223826, 0.1596745875694098, 0.14144911070264157, 0.16554620717802357, 0.20022219647803616, 0.2094816254271615, 0.1805151668527434, 0.14689121545562822, 0.130458154505299, 0.13808601535856724, 0.2024114152957355, 0.12173917760411579, 0.11635300493048084, 0.18907201656651115, 0.09644818672489736, 0.2132297412402207, 0.09207996104152934, 0.12027503036323095, 0.143506225318678, 0.1637460537735493, 0.19865620550849747, 0.1815486960713902, 0.14842467833190195, 0.11751373538807516, 0.18723504497639595, 0.14867924934914037, 0.14205926909081398, 0.11253120678086435, 0.1674871368994636, 0.1438183755043053, 0.2043464308184001, 0.16382108442485332, 0.15976464886578823, 0.16375124784967593, 0.14262295658549956, 0.2252336342128054, 0.154338049732389, 0.3174665600301758, 0.09408112059557631, 0.06490679172378394, 0.20211342241494887, 0.12933500832126987, 0.14320248677845926, 0.1594810277944611, 0.12987327701862783, 0.1530167472458655, 0.16592100803409854, 0.08678385732515205, 0.11634807898512772, 0.1072798885645405, 0.15023901968473388, 0.09329241775577107, 0.10262818736655098, 0.10730658672870168, 0.10574330771041494, 0.133685820826119, 0.11002159467147243, 0.22078693814335332, 0.15829271817159268, 0.11851538768819264, 0.15901759056554687, 0.20472221226701814, 0.12895504403258526, 0.20711559351653824, 0.2070351542844888, 0.15764503679688902, 0.20789568552807455, 0.1738904062057695, 0.13445449812758353, 0.19573227772789617, 0.11385632438525078, 0.16005969996894562, 0.12591159887491696, 0.10387055215335662, 0.12701371594542457, 0.14673926957672642, 0.1253688715458397, 0.12317592187994912, 0.16055647734432452, 0.10450037601854532, 0.15266544996730744, 0.14983112383033, 0.06436450106482353, 0.1239069153164183, 0.10923211808286368, 0.17149245907222072, 0.120880255145171, 0.0889826905463011, 0.09086339809601346, 0.14207555612008418, 0.09303211640085905, 0.19998166019157057, 0.11635679706570604, 0.28226638272885357, 0.18811667428141643, 0.17516676997465475, 0.12767407607527512, 0.15653719704958702, 0.13310978399409404, 0.14979988276477785, 0.14586502535929605, 0.09632016577187086, 0.12259505103312193, 0.15374440819986407, 0.15297007716951833, 0.2099739441708211, 0.07465686168401472, 0.1449340906354689, 0.21830055381982558, 0.1647030201650435, 0.17318375138265474, 0.1477419560955417, 0.07362632786915188, 0.19604660360322845, 0.10324239835984285, 0.10032436179537928, 0.14354664411756302, 0.1616028002313068, 0.155687038636496, 0.1211927577312435, 0.10860980954021217, 0.1180635643522105, 0.1441353214003386, 0.2047399242198275, 0.16850408797542896, 0.08731559129251588, 0.13959067332888805, 0.24073419761994194, 0.21773366407761652, 0.2100532802362596, 0.2556345771036802, 0.08467635710633571, 0.1412734927068795, 0.19456330416423662, 0.2346335330437268], [0.01873186864559689, 0.0445171969101554, 0.00844356733479447, 0.0333302601000234, 0.06393400561665336, 0.04880796344349942, 0.026264560311251593, 0.015344663556935567, 0.040757957500435656, 0.022334981251568086, 0.05707350056318026, 0.02854969908273028, 0.03963714405413597, 0.01053557151012243, 0.041977557984571305, 0.018205100843202204, 0.014487751121182117, 0.04277874422710269, 0.023756122231603633, 0.015458534866000618, 0.03046389233561293, 0.017120071363845663, 0.018299848682457404, 0.06390233937230322, 0.01237207291377408, 0.03049775725230575, 0.01677227510710157, 0.029219778953120116, 0.04484974418676669, 0.03623701601980194, 0.09339703472271081, 0.010604371951382247, 0.03407299383393219, 0.014916329434321774, 0.027372501565203555, 0.032318441813150724, 0.005310513830233005, 0.04252828710201768, 0.01530278248772506, 0.049088803615661404, 0.07219414947734726, 0.021348522390208898, 0.026128905292059627, 0.030516710267552448, 0.03059383233888976, 0.023731841074843562, 0.04756426566370553, 0.030252335240103068, 0.05022098197631779, 0.11949097001624685, 0.008728911146341313, 0.007875232559238231, 0.01614703819335949, 0.03352384668804946, 0.025686899372827143, 0.008102327833072314, 0.05790416969947758, 0.046338777793871785, 0.03026556174811577, 0.019382995500740026, 0.00330872057783117, 0.048736384018294276, 0.047878614521675536, 0.07612581995706405, 0.05735438287017807, 0.03830247716377339, 0.008262036097866875, 0.06331040621584942, 0.08811482784127997, 0.001969760602561667, 0.01812101311741337, 0.052664783302574396, 0.029526348188219052, 0.1204369583677861, 0.014255313341686083, 0.03665434241655373, 0.024898589153083104, 0.03697188203072837, 0.037945798117547266, 0.02496684375669687, 0.07911114202391717, 0.03346886838816347, 0.02942374603252017, 0.04454982842529013, 0.059149031932916374, 0.0019507655721803707, 0.058933922104657664, 0.041879326360480446, 0.040005509771647, 0.032780488592482386, 0.08493721004455321, 0.027540081383420095, 0.0950178086397148, 0.019909089145761345, 0.043767338558550806, 0.04315665540015025, 0.019112533904732238, 0.06593520347509654, 0.05720032641904489, 0.06642160801998069, 0.05177152861330298, 0.022518570392182278, 0.007537545790264924, 0.04486500082777874, 0.08389909195923999, 0.010875068161816848, 0.052570715366351994, 0.035950196531390956, 0.029152949273045507, 0.10581440066978817, 0.0401349977830485, 0.022590557759207104, 0.029926303541287783, 0.040143773320221135, 0.046383682037553484, 0.041573040577913487, 0.012870220628927552, 0.03468266958671232, 0.041627708612190145, 0.05304555198357952, 0.017627960844566266, 0.12363281671799, 0.011004473818766495, 0.008582674537695224, 0.01487601501491642, 0.03040609291694578, 0.01092444731658625, 0.007046577755376818, 0.007325963318092569, 0.07992071309877981, 0.03588741945643579, 0.03664526427465101, 0.027140011117162726, 0.017871902391855276, 0.10024895576099235, 0.05794671822279211, 0.04182747369932552, 0.035106745218077016, 0.026343748904764656, 0.09824904493026196, 0.0694500225325746, 0.038766787732921304, 0.019403011462981665, 0.01359594721091731, 0.019611283956516175, 0.025791133295804746, 0.046931032707253774, 0.053440271125685786, 0.06648797421686112, 0.013473532106276723, 0.028767212511851426, 0.03815442684196657, 0.027677264748021003, 0.03253292727975115, 0.05941343568866292, 0.05160305821787446, 0.036972636627333785, 0.035522899500304655, 0.02319839873140858, 0.012303834589528702, 0.029155287756434375, 0.11879785196675409, 0.08166684964371305, 0.08157594565061793, 0.05053276827018108, 0.025396990634861494, 0.025952751034750574, 0.04976206466615681, 0.030085310835631627, 0.022434505649031173, 0.07315711433728857, 0.023519812835260265, 0.057836945484121965, 0.07952929579562719, 0.03507822759509568, 0.05506308666700798, 0.02739992176723336, 0.07906165274400866, 0.008795758063394216, 0.02116453488387408, 0.07854630539734518, 0.010834611058535596, 0.008783176026847816, 0.06570703950860808, 0.028626265740322492, 0.07861119304453174, 0.0068234599142846086, 0.028096213335952455, 0.0881964238660951, 0.015461333002144051, 0.07184218570229507, 0.042499283013204416, 0.007051580788327322, 0.032178052370586706, 0.05267133718476661, 0.018081890922340176, 0.05589384007297697, 0.018222364634575865, 0.01963188980645951, 0.019890986488110596, 0.04317635918156274, 0.061584203278705965, 0.06719711882572982, 0.045499547625020634, 0.09122596452793769, 0.030049272144453663, 0.07941397658038525, 0.017005039431575327, 0.023999339825804197, 0.034726060806743564, 0.03859447923699214, 0.0775310856800887, 0.04745571483527461, 0.048750177431370945, 0.05967477892315196, 0.0678287813019368, 0.019699477913579153, 0.002164744463140866, 0.023133371273175846, 0.003565507983195506, 0.023000433950895266, 0.02566462919686831, 0.027920097383039615, 0.02457709077955975, 0.029499990933184183, 0.10555837408549364, 0.09613033684511339, 0.03527027817683355, 0.04219799595434339, 0.06195646072287233, 0.03878118635545816, 0.031468766035452005, 0.05374485236262122, 0.030819728685122345, 0.057442034820034626, 0.059594079221208254, 0.04192334194216998, 0.050349604308364854, 0.05769710379442381, 0.06424063230834662, 0.00885556942047251, 0.02122192444550174, 0.06439645459214527, 0.07475950214410983, 0.05225380394427527, 0.03897758831660594, 0.019297364107783765, 0.032959259040052855, 0.04661135187733077, 0.07846617260046544, 0.026961811405095844, 0.029263723671676654, 0.04735513515169582, 0.09422290814860214, 0.04166316699176546, 0.021011646716825424, 0.03696222166200319, 0.03439143360141785, 0.011905685288741464, 0.09780316643657223, 0.06405464531252943, 0.01650012428722074, 0.020683272704181653, 0.06867696320818317, 0.012918268705928519, 0.030264270889963356, 0.04678756359123415, 0.0261820373200481, 0.03566459512277957, 0.01441118542119981, 0.01489120462323509, 0.017923515650533864, 0.025840936671762217, 0.013293964927265001, 0.039611319230208476, 0.023753054049466888, 0.0387413382920767, 0.021009425061845013, 0.037232202537838495, 0.0034073745078902935, 0.06226768777255089, 0.024805723974901824, 0.03610130737445528, 0.01703484408226946, 0.02765161995475571, 0.08226828229042792, 0.017979127888177193, 0.04651574027394095, 0.05833651141954526, 0.09393194795496042, 0.019906304416156585, 0.025985030149440133, 0.03503509301451906, 0.04994101131394987, 0.032033041502619465, 0.03193285060866225, 0.026745540953631845, 0.047359582292096275, 0.021032731371721434, 0.0377440833366446, 0.05315812094317329, 0.013514404812256896, 0.03714470763600642, 0.028076302710800406, 0.020466071455889655, 0.03474242827524582, 0.01030821385117428, 0.020104627342774503, 0.020198400335146055, 0.07992167070868515, 0.05112167154889434, 0.042061417799202666, 0.04525784688491014, 0.026778911743613503, 0.07861445657908916, 0.05129171625500725, 0.07485495669947517, 0.0507234858589307, 0.01357657859297169, 0.03544092426196702, 0.012120121917236718, 0.06888632737700978, 0.08754850500413487, 0.013698320497848816, 0.006275824355637475, 0.04021855116251015, 0.044648037066743265, 0.018573738521926345, 0.06278621055366052, 0.011818470009001754, 0.02858752850443125, 0.02772916145923157, 0.01114114198923832, 0.06723486397775912, 0.027328537694448908, 0.008574592310094066, 0.029190332448530584, 0.10292634112580169, 0.07061472132561669, 0.03322711402189828, 0.014294034298208934, 0.049043853406704245, 0.03595311149594284, 0.04928783325838947, 0.0342152257179541, 0.031649145267663464, 0.10748041973960017, 0.026638223526759014, 0.04144162968582204, 0.03027211946074761, 0.042445005683769146, 0.03098454867159167, 0.1099111094710327, 0.21479112036045522, 0.08284582831566373, 0.1045326589636745, 0.2343712245384532, 0.10865819565350972, 0.1164639421227959, 0.1679548642207538, 0.2845312757117133, 0.12997194914327515, 0.12455198433130019, 0.18584030530145093, 0.1901052546717467, 0.10361505416972984, 0.12106544157910733, 0.1145858928981808, 0.16937612585963743, 0.0903279026369414, 0.13255205666345934, 0.08346500355870494, 0.12009817130503156, 0.12665547791027254, 0.11132242728865917, 0.1176372517441069, 0.14686722158183976, 0.13680134719658282, 0.08985951648003633, 0.14991643538157787, 0.15181098614008198, 0.15733014401649276, 0.22083579923116395, 0.09700311783460841, 0.11342530033641285, 0.11438291790264268, 0.13520992210795804, 0.12927816459728828, 0.13971948335247655, 0.08869722320307648, 0.13257899231487705, 0.12591864688382035, 0.3047156700443837, 0.15739420428872108, 0.1574738467893293, 0.07346528852658887, 0.16174490954126083, 0.1215869099682858, 0.13071733737184157, 0.10243114955242603, 0.09455627896973202, 0.2471091216730495, 0.19275141429276238, 0.14520730823278427, 0.09350214964680134, 0.1517517369000181, 0.16797950160839867, 0.14850167016829216, 0.19431178217693684, 0.08384821606018851, 0.12673410151394146, 0.13620268012727463, 0.14665441767823312, 0.2065058641376034, 0.16145879102330055, 0.178310044049736, 0.19210259910793076, 0.12163615410005855, 0.16693192233722057, 0.15468714067772513, 0.11728357959298358, 0.1446549281958611, 0.12042785724324566, 0.15805293265129292, 0.12308943055329785, 0.24522358010853493, 0.12555772754093333, 0.17150736714322723, 0.08416393621554298, 0.2130950629831322, 0.16068600749056186, 0.1831535430204484, 0.14255816086886391, 0.23925934046987565, 0.11144018266350032, 0.24749020445010356, 0.1418950811268822, 0.08344618843928461, 0.24365749720844532, 0.17709447701852168, 0.09234384768792699, 0.3613027852148779, 0.2088900982973076, 0.09465573250406212, 0.15249070531177908, 0.11664984867938104, 0.10687425266951324, 0.17017175413427815, 0.0886992150316796, 0.27836782256922415, 0.16532217242544697, 0.16623295903686555, 0.13083415045853586, 0.13414219472437136, 0.09174566325401107, 0.15469524588796402, 0.20625359138413785, 0.08103164018041666, 0.14748050560874326, 0.08432969465971955, 0.12833014611274968, 0.1798582464576729, 0.1398486917417857, 0.09030449865085464, 0.16290850516769195, 0.13935799710452557, 0.14136983592423702, 0.1241133070640987, 0.14982566928430913, 0.16390495573080358, 0.10013782704669623, 0.14086349777156307, 0.1289129398402668, 0.22301475247067792, 0.10397183663782575, 0.15937676322796654, 0.166142514696525, 0.11468399045688492, 0.09332013481687154, 0.16882455787591397, 0.0803028377554109, 0.16772324519772686, 0.10664497021465533, 0.1510469053661631, 0.1314381188562801, 0.19108034670352939, 0.15764189583639945, 0.17221846527630286, 0.1876013575782699, 0.08542376780702222, 0.14079251206449925, 0.22860340984357944, 0.13820045357269628, 0.22405038077023723, 0.10841281003048343, 0.11331945762879427, 0.07994030196700366, 0.18712840553733612, 0.208856635576775, 0.11967339087277652, 0.1022666474924453, 0.1456388149170145, 0.07995023812738158, 0.15121339159386774, 0.15923983267238065, 0.15942350991310614, 0.16809895003755249, 0.12593755393379158, 0.08427318035354538, 0.16708587536648398, 0.10335058529650974, 0.04044421002148621, 0.09491074019141736, 0.21454781083570373, 0.16248242238596564, 0.18456771068515318, 0.19233293110324493, 0.16567397532203507, 0.20807963856045278, 0.16370833160415774, 0.11019774126790224, 0.1923278289576692, 0.23468170465240556, 0.0740074719332399, 0.1571027691205663, 0.2494444641014261, 0.1649785819914072, 0.18168712815930768], [0.05010316531444269, 0.02764529781416059, 0.03866033598540291, 0.009150419425549767, 0.007145251795243953, 0.02459944139475063, 0.06913044129408176, 0.02918966212159684, 0.025082199361115217, 0.09093786184225353, 0.05224932616035785, 0.042644663518595124, 0.11133989409333277, 0.03786270822127981, 0.08147555748902022, 0.04244030190391406, 0.05409569764930395, 0.01511959171283149, 0.06530672026377532, 0.011927283222546742, 0.027789345326563044, 0.029433318301134055, 0.010431422814426404, 0.01617560944249553, 0.08425532284403041, 0.0024440275615967453, 0.027399883462837147, 0.06068372821074821, 0.03878352675406683, 0.06331921239653904, 0.01549065022939636, 0.023799789243287617, 0.019408471754661972, 0.04487931901108354, 0.06724364334537138, 0.016291985859072978, 0.04200417570950043, 0.07177949672745121, 0.019939295992615725, 0.03866125529091205, 0.062388411738098636, 0.021999731599803896, 0.04405430360366741, 0.02874972655497972, 0.07430764816461072, 0.06139701352484765, 0.02974204024330022, 0.006554073235395575, 0.029348186780548388, 0.030689771444867217, 0.08409776920152288, 0.02143649992743327, 0.0176279493532474, 0.08129833836949642, 0.02446529748398931, 0.021743230040996306, 0.022393504623323682, 0.04082498636337058, 0.05852404208252988, 0.07895926509292857, 0.038007958491723386, 0.04401674997361918, 0.026989036254704963, 0.04412335493872243, 0.05408245581953276, 0.0313256225068002, 0.007065316266004718, 0.015687649739125085, 0.055476107649625316, 0.037090587354595625, 0.09538859519506655, 0.08702003457132848, 0.05750803329471139, 0.025862046224515767, 0.06173308480591063, 0.047814929632530104, 0.028199543275179404, 0.011254205075543255, 0.048052301975868406, 0.04003901845745502, 0.0537403209525491, 0.10448295517914719, 0.058592254551307815, 0.07201915967368311, 0.02521487238306192, 0.027291436056276003, 0.027753264500549244, 0.03609163934485086, 0.03837795980695275, 0.06287663957224258, 0.05434128245519054, 0.016611176392724438, 0.042949658443009665, 0.08251977363421072, 0.11458570137619974, 0.023222057441730174, 0.026729114113315463, 0.011459672729664994, 0.019412731203520973, 0.02556304785332853, 0.021130985978450027, 0.06413893413639839, 0.05386369558231485, 0.03856848970416092, 0.027251723973501115, 0.07281068937792894, 0.03025406276837232, 0.035050885917078105, 0.021417460727295088, 0.03717894410534251, 0.04258890380902637, 0.043734396777806744, 0.032202176479322296, 0.013943211036554028, 0.01747585791764, 0.040253136201851794, 0.018210421323836334, 0.03344495495360705, 0.053075758830433896, 0.011402647059801365, 0.011784498797609441, 0.0408372322788402, 0.04758066377572475, 0.017377645445747242, 0.08943617629307894, 0.06776403921145586, 0.042486749814763185, 0.04152170119566783, 0.03683102910497016, 0.04761827869280692, 0.03268962290378348, 0.0196222773182296, 0.020846007016277122, 0.026931571999504685, 0.024305713708482446, 0.03998615839067967, 0.031924172747699965, 0.025109893439577955, 0.02754850643536737, 0.06061560001164194, 0.03115034350494464, 0.09013327033889872, 0.026997352139123028, 0.07011404456270319, 0.0687198334884259, 0.04106292561177285, 0.01390033309543205, 0.09555416211726205, 0.00923124744722079, 0.0184963962003108, 0.00951934342963561, 0.055180819059211406, 0.017429881150864305, 0.03314977744594216, 0.02717618961938687, 0.031977055797113046, 0.018910213914369384, 0.014404435228976994, 0.017230232892137383, 0.0014040946858116397, 0.019715401051085324, 0.04232865608026905, 0.05572116385484415, 0.04623947747712655, 0.08713940639168986, 0.0585315267615501, 0.041101911826239484, 0.013390374219705983, 0.06981163901547272, 0.02899598168780006, 0.04898263532067499, 0.06177156157190762, 0.032073341557876237, 0.054066080690151265, 0.029243617694103913, 0.01759782103040526, 0.044512623365247445, 0.08603143640944073, 0.128139711976532, 0.030136353358806624, 0.015052221940770267, 0.012238329283953195, 0.06024277183197199, 0.05884457710048845, 0.03281218548034949, 0.06477498629641149, 0.02874231656953212, 0.05129937713425006, 0.08068245730452961, 0.015239386796771039, 0.05093532449175274, 0.05532731805297156, 0.026143097070856925, 0.04993764818796227, 0.026440938649278496, 0.03374539165487213, 0.07462162163949783, 0.004727121596525033, 0.05230303658472915, 0.01059588369718122, 0.03693608274202674, 0.004348748855503096, 0.05343180968456211, 0.053695922326897426, 0.04558184078984684, 0.06074988373344945, 0.0376986964575706, 0.012149918907051607, 0.041131291298135635, 0.04583487580079706, 0.02164388950463505, 0.09734621031149741, 0.07850620835538834, 0.00857983522432586, 0.039473568960543604, 0.03515332336387327, 0.035843434518263224, 0.06705306365244812, 0.022195241068519896, 0.025770406787013336, 0.014020843513970895, 0.04811661888755137, 0.03098996299799652, 0.07152459629240536, 0.0764966601385705, 0.04961364662214633, 0.06874878395108447, 0.04482173218181537, 0.017714862028257023, 0.019185285444461533, 0.00804243603676197, 0.0487600484742753, 0.01824501402405722, 0.05215105240143115, 0.042369155318386136, 0.021331490340432333, 0.03605734924936006, 0.02106865706493057, 0.02877435053608591, 0.05488655319617641, 0.023017234259074735, 0.07277472921076321, 0.02474843591992413, 0.08565763146766732, 0.05027211834526351, 0.05294177771335649, 0.12557134858422703, 0.03940887666577774, 0.05920467289885687, 0.036422976202541785, 0.0461482095922674, 0.03220985651076321, 0.0968433118936035, 0.040552140318698464, 0.016928984137672572, 0.053040664342622605, 0.025460227362571225, 0.03509384812787175, 0.05207109963521362, 0.0364195786025976, 0.04079283748362814, 0.05689274211744628, 0.03489224826015773, 0.0283261124915894, 0.03877236485301006, 0.048742007103658495, 0.059616751593327334, 0.03954507177695632, 0.030463735287588452, 0.010885782859047816, 0.10095090680425206, 0.010565447981559463, 0.021092792664985024, 0.03117135346626803, 0.01589033745169159, 0.04386690317562992, 0.050340227392171664, 0.013682958519747181, 0.04896821371550041, 0.06142293027932606, 0.0452290419789572, 0.0207030032986715, 0.05625967386989825, 0.018622413833415317, 0.004049785437077404, 0.03481328374736252, 0.04359594936813078, 0.047099143041357885, 0.012166450126847674, 0.03459620124269878, 0.03308459485490476, 0.018590010229438063, 0.011839387082164327, 0.0366172714218978, 0.06374606126618963, 0.0435133038028594, 0.03648809750654525, 0.021655602988997297, 0.05531178945074639, 0.0014004861722858022, 0.02157435361896792, 0.022129773109730695, 0.013655220391228797, 0.025609336800933368, 0.01731017799747567, 0.05566329740348363, 0.049629473998661966, 0.016845285201505307, 0.011861768340872181, 0.04105269067710446, 0.0795820409492139, 0.022091886231435404, 0.01627374147515624, 0.044274140194418936, 0.036034439389984456, 0.042726730687483665, 0.01782611140140122, 0.031314575518932075, 0.014753901557396016, 0.04066069880800863, 0.05513415664374348, 0.05333288092046015, 0.025232159157073306, 0.07912740607054965, 0.033081055528694586, 0.10584834602571304, 0.03228328986874512, 0.10433487038338378, 0.02602276764059019, 0.0654600757444578, 0.02773039294556985, 0.04980980726559797, 0.01613661939758928, 0.028571256796919534, 0.02292244045454408, 0.0553471558997708, 0.014331418431303916, 0.03712144537618564, 0.10414612164059955, 0.10670209739116893, 0.04746781902447824, 0.008807943649439803, 0.01858371873235991, 0.05115215801784108, 0.005397714745824136, 0.05502870464096627, 0.03556879965828792, 0.008483650970212635, 0.011802776697872868, 0.023457660121963392, 0.04241355011359819, 0.07893918592843317, 0.18439541751098248, 0.1997662515890214, 0.14388344701259367, 0.14611936655015717, 0.07485622840542948, 0.10948147970221697, 0.17447424181286367, 0.11429210584009848, 0.16565068624913692, 0.22259527336685891, 0.12453655532050519, 0.13002013607371238, 0.35344082321370807, 0.13647635737734456, 0.18515070359553062, 0.1652862888670737, 0.14313027533071657, 0.07892649185152785, 0.11308642900398663, 0.18015406364875455, 0.16631539009751814, 0.13253627525221917, 0.1625313447608102, 0.12230430534409902, 0.10720202338791664, 0.15013611875474453, 0.17019505852893477, 0.17136916488168702, 0.09395211905000672, 0.11791859753429891, 0.13439993734561628, 0.12725782220161733, 0.11072246553075892, 0.2677291595647412, 0.19752740559558715, 0.13383756752216047, 0.1436147033687561, 0.1500644895338243, 0.0890628310040601, 0.14187032116516946, 0.17589833797706714, 0.11828621248564414, 0.0910250886133121, 0.29177629178570164, 0.10265121596955484, 0.21731190203178316, 0.1275997808683784, 0.18573144420741067, 0.1441111589872068, 0.09178132464688632, 0.14279707304893002, 0.2678680359836548, 0.09399221609196357, 0.14299380442788526, 0.1676242666379098, 0.13287275639032164, 0.0936615342394479, 0.18165012611256492, 0.10493936738179577, 0.16746518081955372, 0.06551871977506146, 0.17099261734514468, 0.24148727737126813, 0.07894743669537768, 0.1528876920741412, 0.184701515602008, 0.1578819418265935, 0.14441488220566703, 0.1300694261707606, 0.1767335423538762, 0.1817268268355439, 0.1613132036741703, 0.2013250872973473, 0.1599700523600463, 0.13211527929431008, 0.15866468450234783, 0.21447762186008118, 0.21263678918682763, 0.12030366672984055, 0.11303007557627656, 0.13805414610091718, 0.21602956277708854, 0.10237174709477734, 0.12424724221590067, 0.18197318539023402, 0.1500336315122343, 0.08877915630657827, 0.1566771306698361, 0.2063822635119, 0.18512263413398497, 0.11741014497895395, 0.05936695713429682, 0.09828870530210196, 0.14861866711608826, 0.25560617056344787, 0.14664128693121095, 0.14793641985424105, 0.14056711367541744, 0.06654827299738122, 0.12957275604769108, 0.1252625921681043, 0.22516171387847395, 0.23426234812265445, 0.3304251211304819, 0.1543607259349477, 0.1549796483689739, 0.18853826778790644, 0.07955563389846394, 0.1089361170306802, 0.17629299583213945, 0.17143671851485007, 0.12566767647982607, 0.09988821261832792, 0.12795667058878368, 0.12406738775391733, 0.16047669694788996, 0.12618401207991187, 0.16471605898151476, 0.215162948795384, 0.06243873605384462, 0.11170057594896325, 0.10833276916415462, 0.17100128946044754, 0.12209406017415947, 0.12827638206222367, 0.18504515200132327, 0.12108355189763731, 0.17131484924785553, 0.15301569004453, 0.16989003296100325, 0.1349312193211048, 0.0819053021710246, 0.05877876631735314, 0.2471598826589123, 0.11473797667290896, 0.17835155069347353, 0.12613023270762738, 0.1629005684967964, 0.10979219730342589, 0.11511519070594542, 0.11306798160676995, 0.1402893914811073, 0.09302089321276835, 0.1584864924511602, 0.14278404955421725, 0.19175082685485964, 0.09698781905876053, 0.2369237682151218, 0.08170867038349952, 0.16245780032007925, 0.14738832990969383, 0.18755006033086008, 0.11037296855882292, 0.1568026618371087, 0.11993875606886803, 0.12554221426046666, 0.08677512392281525, 0.1752205646686977, 0.13057962540657292, 0.13502782300835656, 0.12124826846223687, 0.122380975423561, 0.1747582918934284, 0.1954292593103263, 0.16290217728143738, 0.11892856954927407, 0.08848259601021007, 0.10434590204949341, 0.20684249849329073, 0.11778387331193495, 0.11164760096899926, 0.10414658895423336, 0.14934513297292495, 0.09404302304310184, 0.07830021497342857, 0.10662905856846802], [0.05401682889749927, 0.03916264834603475, 0.032075837089289586, 0.005409221386446828, 0.032189777346267816, 0.09186228481872429, 0.017811561476499323, 0.04257091989500388, 0.06030977388182956, 0.03392301297055618, 0.043144784867763526, 0.046393166206056075, 0.056315636592766935, 0.04120061459440378, 0.06635637563322822, 0.04969210934735114, 0.05452060065562687, 0.06602372493474715, 0.030719160492862427, 0.04467455520024223, 0.030786514943165165, 0.006877890461304736, 0.018969484221851154, 0.0200745947809229, 0.04789862473825774, 0.019422359013509367, 0.07728580730937182, 0.007559038386980613, 0.010810188175509534, 0.13339375746586632, 0.044124871792812506, 0.02694172841016083, 0.05828130329328199, 0.08917458791045413, 0.012777503880281604, 0.02922015050576339, 0.036477310988571376, 0.02410344542905448, 0.05936182817564376, 0.013830008139202913, 0.042538537358444546, 0.005901823582638416, 0.03300715102663925, 0.019308533669719775, 0.05882363225663862, 0.022843399332956444, 0.05808215107648604, 0.017195320350208113, 0.03957727045241383, 0.02245862018166771, 0.030655996543505502, 0.036930000003907955, 0.0878796618311636, 0.041866693570609056, 0.04240041936657602, 0.03316541330047673, 0.05593784033290802, 0.0906605916398187, 0.03365540313684652, 0.05551653793982922, 0.03161640458499953, 0.0425283100846554, 0.05856426552899423, 0.048679452194201375, 0.05108352420070479, 0.020587578746339968, 0.044305231872825854, 0.02867018556102149, 0.03427815984093374, 0.05314729995124283, 0.05876634037122131, 0.05389206764859058, 0.06126310135568343, 0.052748646947645375, 0.011181970645162848, 0.12272031406962103, 0.020824569960935943, 0.012158840958539759, 0.08209429606194459, 0.010700829124318497, 0.03667046856735984, 0.057966678643659245, 0.005815084235021664, 0.042693490132449136, 0.05678204624282737, 0.052770897971406105, 0.0927961843028184, 0.058031497342932614, 0.03286107338123745, 0.025924185531273968, 0.024023027264422948, 0.011944502963864756, 0.01387947922452323, 0.0009616683758307069, 0.02552688850330249, 0.05295074477251019, 0.06499578049706836, 0.03103958634329179, 0.027225506529512427, 0.03173377691587854, 0.06678659528974565, 0.07186811777853197, 0.05218659122023852, 0.11541456254499576, 0.06456891630565928, 0.07663899161402257, 0.012873276362135526, 0.023052665825572707, 0.11336856386474065, 0.02444300815583237, 0.04196868668640814, 0.053501002745883125, 0.056372890173788034, 0.0540555086767962, 0.052161007714007175, 0.05330866488117365, 0.02776777803627474, 0.03212094243105141, 0.07614435928483164, 0.04859314089821232, 0.0587738365415604, 0.03932490959883698, 0.008670640583600729, 0.051662617723547646, 0.043867278558712815, 0.07011482597238596, 0.018851129383209254, 0.05316235740939456, 0.04201186340182059, 0.04803922102456132, 0.009814215459740691, 0.01239113892698961, 0.029269300791765415, 0.02275749023312763, 0.058996342948728034, 0.04759431929297505, 0.01869763983714004, 0.015995526111744825, 0.015939922492590644, 0.02081538265150401, 0.017193970120241566, 0.031722448390698245, 0.054583416034978245, 0.08152287107922378, 0.05407822318375111, 0.015520006718654788, 0.014731565306353715, 0.0386650589174561, 0.029809984581304655, 0.019035314157184575, 0.03366909695849304, 0.038438618648797274, 0.024173540558906335, 0.07546647106327357, 0.01334221218712628, 0.0751714735862709, 0.046433355178563826, 0.0637065196379779, 0.07596242872457351, 0.015653657460314854, 0.03768039844749916, 0.024094246628303683, 0.003968810661688387, 0.03258958714263093, 0.034354293658848734, 0.050639243000337196, 0.07819627216386218, 0.06757419496293991, 0.02867725463734279, 0.03662383296496926, 0.06657202172303392, 0.049856722490080906, 0.09590916726137362, 0.060915446825205326, 0.030648743606082378, 0.03131959914049554, 0.04790891329908083, 0.07536608290167586, 0.0379714314194937, 0.038453928915964025, 0.06545319627489775, 0.05776977489492106, 0.03969780672642012, 0.019826711711263465, 0.06622340575221085, 0.029878564772286245, 0.03576240156807246, 0.03908992361938281, 0.04238199495199708, 0.01401700349825044, 0.053119602042340466, 0.028869893191562548, 0.046315994339003685, 0.04722655878492421, 0.04671040321550062, 0.052046282216906554, 0.06407154904257867, 0.031416013220986055, 0.03619831708830692, 0.02486699760230559, 0.04893821371238559, 0.011322352426847624, 0.04892270426235853, 0.04109889727025744, 0.02253176242623839, 0.01340640077908193, 0.025372962287116437, 0.028790162590843056, 0.053319861256187005, 0.016631182778867024, 0.012734269708274834, 0.00779235908280938, 0.06088324814974781, 0.025041715444756613, 0.027762363709869887, 0.045311787135658727, 0.06234616198907457, 0.09228313521992776, 0.017062507517215227, 0.00917683796761858, 0.050027123427078615, 0.010448640640524608, 0.0880988855515757, 0.030376464466474233, 0.029071801409666097, 0.02780143419400819, 0.04454260038572454, 0.05239352305990554, 0.03715876917985659, 0.027771863200130965, 0.014694984607969322, 0.006301033436395829, 0.02491810524295415, 0.03503787774412382, 0.02005681579542016, 0.03760749752062463, 0.002136043457862651, 0.0587428750981006, 0.0295857927807036, 0.019366765928064144, 0.019595981350228674, 0.022574793584945223, 0.08981771872288759, 0.01043254609084538, 0.07881629010362011, 0.026104453680736404, 0.02405908702301883, 0.010620093033198389, 0.0505478602022894, 0.06674442214951401, 0.006650726718362422, 0.04686319179111912, 0.04814442404876313, 0.014479141250523108, 0.0294264541533325, 0.021775267837989717, 0.036025472330830755, 0.011443125230500535, 0.023555366975826122, 0.020537319548067548, 0.04905427603291408, 0.04587876497797909, 0.01097448243414082, 0.10336807508382106, 0.043548712386719646, 0.012783879647031428, 0.026722043121774352, 0.01710346640808688, 0.025219361658298203, 0.012213929383564862, 0.017011110678375248, 0.05307334182303279, 0.020196921785452196, 0.05235531442468205, 0.0026854956025002346, 0.017322887396139484, 0.06768733082759766, 0.0545947732884557, 0.032701527910126794, 0.06927891679468655, 0.018253159453912128, 0.04365293481837838, 0.05551027517104822, 0.033526807617876804, 0.05295621847072917, 0.015753986250098436, 0.01970694727084089, 0.01242931021542679, 0.04579072232328115, 0.020274053432888562, 0.03282373808624764, 0.019434016956497106, 0.04867847926253754, 0.04035538212666589, 0.03716629982415227, 0.012778751645988275, 0.030834203916451627, 0.07670834555380768, 0.030368261580024997, 0.025392687135946848, 0.020054013828837106, 0.015460254733390627, 0.02604077070681078, 0.07611482659535063, 0.04592222897636314, 0.0285765485492565, 0.03810804404859101, 0.02406022849402601, 0.0207455096871502, 0.02715720979106282, 0.013466211178550317, 0.11350085958838464, 0.020702919028999827, 0.03517699931117316, 0.028251323157981522, 0.049418734702011274, 0.027654299347270882, 0.036722164180490284, 0.026369801639849623, 0.043684129918655085, 0.04313361147538789, 0.05006727026475053, 0.020162014989182353, 0.06138287920264467, 0.06398873876840358, 0.06779123533276782, 0.04312725294561636, 0.021479395105533546, 0.036933704039021846, 0.025712869753460252, 0.023713250036141085, 0.02501646710199214, 0.029696603568511146, 0.007264238177618433, 0.082971443752608, 0.04074129508808255, 0.06504212115560809, 0.002849554767899756, 0.022721608589974143, 0.09808803623121592, 0.008949590433809546, 0.02665994594985199, 0.019803271336000294, 0.006549023758364662, 0.029354604682134047, 0.04776552079185363, 0.03558334383753038, 0.0701537432389394, 0.08383746018573161, 0.033226095124958985, 0.04906007531850089, 0.04039406956684205, 0.1618936684943976, 0.2021987799314722, 0.22212150927272536, 0.0978803880993397, 0.10599248546866641, 0.12610531952832976, 0.08643031540897586, 0.1467437741737212, 0.1792494517060057, 0.11887526515150264, 0.17710135648808173, 0.09996093734497986, 0.14292151637135014, 0.14551256362709308, 0.16093559893629245, 0.11688483848927483, 0.14985257429220986, 0.1641788781290093, 0.17092524757308347, 0.2447092439979315, 0.11646204222474368, 0.15217011283722617, 0.08532616820546889, 0.1348481907118713, 0.10915822124168759, 0.11817751993094722, 0.168656324967742, 0.11618911574083952, 0.08865500409756938, 0.19590608775615695, 0.15013647115518972, 0.09894497452243682, 0.1595556907235615, 0.11069903090115517, 0.0537108265674643, 0.07953941581710693, 0.14332087800627755, 0.08282895905957108, 0.14960756405226647, 0.1285469030300456, 0.24929902996988068, 0.29952677267213024, 0.13237847646157588, 0.0877642430244915, 0.13700088245734093, 0.14318532640895537, 0.1506588205454811, 0.08914430445480732, 0.08624498341833392, 0.10790514654570049, 0.11510831889726462, 0.14025422804538282, 0.1134398943113704, 0.07162068670074787, 0.11833455263366623, 0.08658779244269095, 0.18359215900061593, 0.16378478717900094, 0.11991064064204694, 0.20113008727710094, 0.18324740411293122, 0.14834581724097654, 0.06725459840268859, 0.1204186488663958, 0.1708423721814348, 0.13836548423334477, 0.18276504451228728, 0.07538072284190886, 0.15899073152292162, 0.12439276061711774, 0.14201934058820048, 0.11300507812730728, 0.13037462027803545, 0.13121020769880665, 0.08660384198470462, 0.22962468165543773, 0.1155384925885066, 0.14187179205398406, 0.15904019015931314, 0.11022160490674358, 0.21359830614059203, 0.22002785226270077, 0.12122412137086354, 0.18848065797600055, 0.1184496803269271, 0.15411314163957873, 0.18709230747434402, 0.3508952662589089, 0.16593870466514943, 0.12374164716851328, 0.1415533139821022, 0.10522093533748582, 0.07484979326686553, 0.09189706521048661, 0.13330170434088479, 0.16634111533001547, 0.14101385018758236, 0.108438290114845, 0.08647457230836154, 0.14655741562526073, 0.14242389629925453, 0.15815318291706426, 0.15329506698875658, 0.2846059233190552, 0.17919907376410502, 0.24518616437431306, 0.15217968893627967, 0.11632665916676484, 0.2655444913093121, 0.14312250719916436, 0.09958572280142577, 0.1558348323188482, 0.14878749757284118, 0.19064508618847018, 0.09763826601087086, 0.13587931441443582, 0.21666846478417998, 0.14027825256268825, 0.142981271229444, 0.191865969869879, 0.17698307251257284, 0.1733029393419143, 0.09020084695469949, 0.1811543293297291, 0.18442641342839888, 0.1317803916190901, 0.08624974848522295, 0.16867241281415188, 0.1681606967242495, 0.16669720831897952, 0.18927651607701856, 0.13106878786798448, 0.07432830955592856, 0.11410600010065303, 0.19418952986598018, 0.20078620572964992, 0.10435238315333283, 0.10115653246400819, 0.09987898891971958, 0.1785727049554548, 0.15303084326367225, 0.15818636984594409, 0.14632633286378077, 0.1801803251427989, 0.15955239654548709, 0.16508379650692787, 0.11833069155052786, 0.13824490199406303, 0.1628848177290732, 0.15896584898714097, 0.13836137800207063, 0.16251171758819014, 0.09353836262298208, 0.16128254483544058, 0.1355934716881283, 0.15439530714384972, 0.06882095709443092, 0.203741772941524, 0.2383080890942966, 0.15881830045292455, 0.15452891287784423, 0.14961015342945053, 0.12093391194338761, 0.12230599073753243, 0.11943868451541471, 0.07178884300012743, 0.07008478000399566, 0.2251816628080222, 0.12463835308388357, 0.13196388499871378, 0.18549447789067225, 0.2008274672252517, 0.1663792052216107, 0.16885815849227293, 0.12567911417253558, 0.1622942252264869], [0.022606371729184064, 0.038851949897023945, 0.04697233633769136, 0.0155589536711153, 0.05929902428761125, 0.028863994314545588, 0.023700812598690394, 0.02258421455119406, 0.03730394284150774, 0.021647126226115133, 0.02441738634520481, 0.022861701173467502, 0.031503567494632255, 0.021031065130486123, 0.01898865365693646, 0.027454934541075945, 0.028130852001448794, 0.038137163050592914, 0.0977268640793139, 0.029911973866664117, 0.06375067311549379, 0.026883231851482586, 0.025440743831436963, 0.05242208281772272, 0.04468746378176636, 0.026055837741061568, 0.038751975422905344, 0.023206741428904, 0.007490393557330414, 0.0915133624127315, 0.019143121880328944, 0.2244524390346581, 0.05634255692242615, 0.041361060218825456, 0.022443733178079132, 0.03287578609982326, 0.03734433865775505, 0.007175638672760538, 0.047873692406762036, 0.014188460678973747, 0.03489191501191066, 0.01676162648495407, 0.03908585186206526, 0.053947482618593404, 0.03562319190091184, 0.05587223639351226, 0.050299946489113, 0.030579902945206534, 0.09329673849166402, 0.07885351431586089, 0.020949365683801232, 0.00869311951851893, 0.032065494902311795, 0.08068988835739513, 0.032839059844733245, 0.035004912980742035, 0.04390691594791509, 0.05870162126337809, 0.014009324424419434, 0.021748500725915356, 0.04453906488995399, 0.07540295471347148, 0.013610249114853722, 0.00979592415293859, 0.046280133763268116, 0.036745277053165826, 0.03583942787841924, 0.0891860562466806, 0.08024207166125698, 0.02760684594602114, 0.06007734280560286, 0.02231087246459098, 0.03246885934664357, 0.04774956318039087, 0.013326041028654624, 0.08467052717723193, 0.04448468796908856, 0.05026229326763461, 0.031066039359317194, 0.03185270632046365, 0.07016196336236692, 0.025324122266723745, 0.06470662827092795, 0.0047439788824938725, 0.055048703366229614, 0.07640096043506939, 0.023267921210537036, 0.028074552199893424, 0.04870240035797319, 0.021228365329725128, 0.05083178770878623, 0.007277426381234921, 0.033547227691498496, 0.05840432169216295, 0.02858389150201073, 0.05109321904338656, 0.05207519820560852, 0.055199151543239434, 0.06709262443285796, 0.025273091234867612, 0.06191540607101014, 0.022387757048671766, 0.06343157834283288, 0.0488469573188453, 0.05082832116092886, 0.07542488781074363, 0.06143760086307603, 0.029345666351277503, 0.029311531388591376, 0.018879589549596273, 0.02623732013988399, 0.02753730239947477, 0.041659980066000454, 0.06109889806999315, 0.06917662107415738, 0.06794033136459128, 0.06852043612349419, 0.024005889877556794, 0.05903294662975016, 0.038034281272801666, 0.01904081466848091, 0.025906778098414504, 0.02191780424196153, 0.016958386592206456, 0.041319024974420186, 0.02866939266001986, 0.04400867540689726, 0.01636556668898031, 0.01106685540083075, 0.12624199727490065, 0.003337078998165746, 0.03484468952181839, 0.03838520316827682, 0.03635373334550569, 0.0872718170285225, 0.05545189161033881, 0.058483347491992105, 0.04802496412829046, 0.03825799809888967, 0.044425438729024706, 0.07187061522516512, 0.03209456602381843, 0.023822262432546388, 0.016526048702578393, 0.04717912645109239, 0.07931701283180907, 0.012513263875828877, 0.07660065657429158, 0.07463803890371516, 0.03628211561590433, 0.01565255237848408, 0.03382914804763371, 0.014129429773968315, 0.02043467908797245, 0.02237485229758726, 0.03374258777306926, 0.05189960319248419, 0.040360748572575475, 0.037646181130361174, 0.01017426529283365, 0.02635264318556555, 0.03015237034208352, 0.008008166529884142, 0.027103535755867922, 0.05350915775183709, 0.048782207567485115, 0.0646080250941938, 0.02527251475370459, 0.021750699398258043, 0.017364978181919264, 0.03944899669037231, 0.020373723387057265, 0.03937536031909047, 0.07085780102399088, 0.0635521375994769, 0.04755776540766801, 0.06349528621461603, 0.04643696728312681, 0.020437013740921696, 0.021415013076377012, 0.04206815171205709, 0.045288612975949244, 0.015271767418110564, 0.02319565613663966, 0.06705581390809628, 0.036777793655111905, 0.03572202490402326, 0.015403802671860305, 0.028237456966552044, 0.01771939343832914, 0.039251460919096585, 0.027676979380269206, 0.08046623664878069, 0.02619926855268498, 0.07466492092897815, 0.014712698475998497, 0.04053434792665705, 0.007816074292115387, 0.031620003283023834, 0.0275113569166992, 0.07280590132840219, 0.03658100098912274, 0.019045526109215234, 0.055007204383371346, 0.05669974541712192, 0.05710029065789235, 0.01847544178036192, 0.03456183070797594, 0.05598282884626139, 0.013977619875673086, 0.04788843576886481, 0.06961104655337912, 0.021486766786584933, 0.06675262695118304, 0.023460950469598178, 0.09411581671766697, 0.046772153732637246, 0.058840589612842574, 0.024844235214855404, 0.06539295878141158, 0.018111143989728826, 0.034357599328242006, 0.06556691436637795, 0.016021290606248285, 0.07361173389419433, 0.060924739471726844, 0.020838399763189016, 0.01712228152750721, 0.023982922561586868, 0.018373653593082583, 0.022344700992107395, 0.06948777534548314, 0.013366331507812345, 0.06549477186654845, 0.011307147496770467, 0.0683736460163228, 0.06669826535207611, 0.04502248552237307, 0.022929501869986137, 0.01572970222050865, 0.04045912192293233, 0.03815620799639052, 0.0366935316443203, 0.10305807760526096, 0.03575556806378788, 0.033987935091699326, 0.050890554313457785, 0.029973507963962136, 0.024638373983062567, 0.057269630563114925, 0.05968901283678509, 0.058007541773540366, 0.048123207243700186, 0.011963656119581674, 0.07788588398046072, 0.04881583882736103, 0.056601046479397246, 0.04253208306768248, 0.04565455402517992, 0.002553852011201783, 0.01780669298774052, 0.060421228183493506, 0.017349386377440348, 0.05321851165424432, 0.01458680054413215, 0.0050648318269410205, 0.026936306422876737, 0.007606690492285717, 0.033877465213018085, 0.024749753591153893, 0.029342063822813576, 0.03328038394571312, 0.013459545255999171, 0.024679283078219143, 0.039175729297341845, 0.050982052024694226, 0.02568737817777982, 0.019133335107096264, 0.03616039190561541, 0.03405415956231375, 0.06157174668905716, 0.02522244324697362, 0.028491016747730396, 0.08029828719314068, 0.003263555146047786, 0.06295700602593922, 0.0284822833453936, 0.03980684019024334, 0.050436708505355546, 0.055722424069479595, 0.04857636740311019, 0.037645169894301125, 0.07522121567519442, 0.08108950280133756, 0.02639486612151227, 0.038047936790051966, 0.03316218040943627, 0.012818461813543354, 0.05973675160578663, 0.04074057113499411, 0.046195392947523825, 0.01794508677126179, 0.03636901296915547, 0.026611841373866605, 0.08537271570774817, 0.06491676618855807, 0.036211608713793184, 0.014519140616269603, 0.07512816663591132, 0.03357033673373442, 0.03384017205286411, 0.05118340291383286, 0.017655582144676198, 0.056751766617620186, 0.050041150496972185, 0.02782462942113559, 0.026461686225487824, 0.021571229895456664, 0.010872572630403504, 0.07402136876818634, 0.006445044080816931, 0.05140494021977629, 0.09873364150764481, 0.0219446805215651, 0.0408522476021561, 0.033740239713581345, 0.02719459679698752, 0.030613258413429704, 0.03163997136477021, 0.010366883737245395, 0.0738694841763185, 0.030801359811917912, 0.04030220796384158, 0.008234238597534357, 0.007113153190021554, 0.030970778241152727, 0.04953553246694708, 0.06375762153296702, 0.01757807128371731, 0.026838431029670665, 0.05610079872572134, 0.03291979019019393, 0.12794317978043712, 0.005353429118141292, 0.0700217692722236, 0.032748849161209605, 0.05921734782356409, 0.03068661324739937, 0.042505013350878036, 0.13016082046012725, 0.011650795387404581, 0.04213587771500311, 0.1981916651129723, 0.13312427837762142, 0.09083064783725048, 0.06776630683171173, 0.17625040134354947, 0.14140748148483617, 0.10967226623887978, 0.10042139449186864, 0.11046482250094415, 0.10266675223265925, 0.14367991277287084, 0.07587746191289156, 0.10954872690021031, 0.10869138258238954, 0.18935160801535655, 0.10763173742640404, 0.10019735973929206, 0.19987237008829273, 0.2212630924318106, 0.10837793004729095, 0.13063458455426077, 0.10960449810109793, 0.13431791997244283, 0.1305979349079632, 0.19147984623428316, 0.1582558846641933, 0.06271960303908394, 0.13873122993015474, 0.1075922302721489, 0.18834360484634677, 0.13240184214326645, 0.3715891090612258, 0.18278955932586424, 0.16313784124870456, 0.121014948724018, 0.23092202091168976, 0.1361123890045189, 0.22875832814362743, 0.18428654109518375, 0.1454792388023869, 0.17450330718871088, 0.12038008400028753, 0.13429810893872093, 0.41714713217750676, 0.14421075041736328, 0.31084532338765364, 0.228385059463401, 0.18218660216418006, 0.22565150453198343, 0.29682922387315386, 0.08560343074702448, 0.12114311523375013, 0.14537310498135705, 0.20516406113822616, 0.0919708164949571, 0.2166339295405534, 0.12565662949195794, 0.16147570624466867, 0.11607886036677707, 0.14095837010010598, 0.16505856157070206, 0.14727317157291597, 0.10042430562598091, 0.09623821734661057, 0.21651731563671944, 0.17900496240585081, 0.11881857464510588, 0.22217751029999028, 0.21367977193046003, 0.11283008832364314, 0.13352287392462456, 0.09500696849558624, 0.12892459969847433, 0.14153920264253694, 0.16524214688087666, 0.18369179639604785, 0.12038013762644223, 0.1848648455474646, 0.1591709154027124, 0.15370377489636022, 0.1271756899152552, 0.19741336574717877, 0.13077413513054773, 0.1788143137650144, 0.1535000108302601, 0.17273889944678353, 0.0936685516048343, 0.13781195506453514, 0.17378008954467314, 0.11532588786776028, 0.14454776781701273, 0.19697280390368355, 0.06396474489461511, 0.1696310339555625, 0.12159640179766763, 0.13490589245432807, 0.13740087228436626, 0.13566563717059552, 0.12482631275610578, 0.07899022270594874, 0.11164629095864874, 0.18897001962027243, 0.17993724544442471, 0.2033909353157205, 0.13940500425955943, 0.20068367252186423, 0.1539826462225568, 0.1918420985701584, 0.0921320703421389, 0.16390009873336361, 0.14019027502546388, 0.12995630562786134, 0.13651193450054816, 0.19243471354486483, 0.154178902626999, 0.13460262888862243, 0.2238623827936188, 0.16970404213474644, 0.08456728150767666, 0.11958390414234131, 0.171245135246746, 0.13767770581668423, 0.23704303278317376, 0.09704968831952542, 0.13165001877613608, 0.12520734190700517, 0.15448256455842527, 0.08381073903893271, 0.20058921388080045, 0.21659718796370492, 0.14389146029228164, 0.14486129696090377, 0.16470741750972887, 0.1393353055802084, 0.1759481949791793, 0.14493445835767255, 0.10373554447846067, 0.11761385541889938, 0.1505863179843272, 0.12806462003819405, 0.11275581609938415, 0.14093627612436974, 0.14000007071562354, 0.12237457092851402, 0.15991219740000465, 0.17297298527292668, 0.12738787328764317, 0.2418734929374149, 0.13202186253282333, 0.08606663048868218, 0.11417349244678214, 0.10364527633834271, 0.13209883904745504, 0.09420047709417921, 0.19622979054768241, 0.21799643223564472, 0.24258259924188738, 0.08586396958919303, 0.11192726136575784, 0.10218841459361777, 0.10799302449149471, 0.11382927382064444, 0.07845101172044393, 0.11278878086276593, 0.15719682939590948, 0.13037866522227565, 0.32375212758779526, 0.091738814427968, 0.2099914262972532, 0.1016295074875797, 0.18644865572212205, 0.16976208095588993, 0.12864571305051928, 0.2273658254454213, 0.16709563532663932, 0.15498533274137205], [0.053165379626255845, 0.021197765862809557, 0.046711445095077644, 0.06251614540815353, 0.07762636403523146, 0.1213858348707999, 0.04614748180873933, 0.03929277221041341, 0.06548700373499625, 0.047100303664563165, 0.07771450245091993, 0.049540113672734275, 0.013011328278920584, 0.02144256351335395, 0.06685672297833428, 0.028959935335742853, 0.04532585634038814, 0.03192799552644213, 0.06117509700538171, 0.05789895264071323, 0.037490328203045556, 0.020675445200815316, 0.005061966179299259, 0.05725126743556992, 0.04943344742059708, 0.05624970323556373, 0.02412398233108463, 0.006875035826176886, 0.09451533157017925, 0.03627766081462464, 0.04277927665821007, 0.07320289575164357, 0.02513017561737328, 0.02227184986094794, 0.053609898313879974, 0.09988529382333641, 0.03610555150155579, 0.0272972161896647, 0.021692741016346603, 0.03107782945247187, 0.08072400991354259, 0.02784604157861923, 0.02331455681292761, 0.011914578611932456, 0.029090783153209957, 0.01729621796027547, 0.059552511290436795, 0.03845716180700449, 0.05977517857606854, 0.030927184007821545, 0.030215869454907316, 0.01967288700172738, 0.045064888488982, 0.030079940559282422, 0.023090179236004912, 0.013222525313106036, 0.04933792774775817, 0.02135925719724788, 0.026517438274177334, 0.08017993426971859, 0.06497159510129882, 0.07038975960665173, 0.02129413397802461, 0.10584424745531813, 0.03653030512073348, 0.05059769805220347, 0.05871225073332748, 0.07643774031631409, 0.0651023663099735, 0.017971783020203153, 0.07918146123448688, 0.07500645824738088, 0.022742417453217412, 0.050769987395934524, 0.055666453685731664, 0.04518230295469684, 0.027788090857587038, 0.059537296784260584, 0.015120616355430216, 0.02570440256667714, 0.009520866986995023, 0.04740109276627341, 0.04885897723837726, 0.046120350804900935, 0.022951316223630024, 0.07105300022709755, 0.03706376278592694, 0.07161108761905663, 0.0569244773097096, 0.03983507819113232, 0.06259457748984137, 0.01878360256312355, 0.0283195260506604, 0.015914556363807814, 0.05712048090513676, 0.029188154843605818, 0.09580387613706051, 0.03640671981678855, 0.028648112652703162, 0.010930955233503013, 0.05544404303955455, 0.08570742718274556, 0.01731129457062531, 0.011545139413717534, 0.02500531860747405, 0.057888736858242945, 0.05421853218708308, 0.03124414714083316, 0.03672795197475822, 0.0887924402711853, 0.06784149836147986, 0.06291668298804472, 0.04361899712333276, 0.043091177865261995, 0.04452093158878627, 0.015210130856552673, 0.024692446383978092, 0.0481500739472047, 0.04712478017374393, 0.030069814792143244, 0.07221218318708482, 0.0050007758639572615, 0.029324618085557898, 0.025718782037015886, 0.039390517368672356, 0.041198059691176306, 0.03575442276234108, 0.028292931308369004, 0.06765700906755463, 0.0701790854274746, 0.02233819115997082, 0.016768002251703894, 0.043191140848061735, 0.06701130419969559, 0.026433911707793033, 0.033658103596779614, 0.023897283507751364, 0.03552794801972566, 0.018934085214089964, 0.01921923271560621, 0.05879457454167067, 0.05669367033988238, 0.04521921307088868, 0.055854325257842584, 0.020961414331630356, 0.04455826688377608, 0.04213596198467478, 0.05270710966039089, 0.034280308717561346, 0.05614282630924737, 0.027762195170526544, 0.01700538034070163, 0.02509297247255041, 0.022707512572167382, 0.12300698417088679, 0.09021963909148209, 0.03326689313736654, 0.003177692729701859, 0.0707540880408018, 0.018926659906883875, 0.06358300328194615, 0.04067618527539796, 0.030225974154628577, 0.03246278043896441, 0.0404722181959979, 0.030388011326712948, 0.05467454219357141, 0.0709876835706734, 0.03845140465625352, 0.07789497744412192, 0.03423162766041295, 0.01959479582916585, 0.052415984757845445, 0.06023203894015282, 0.027823487950128414, 0.025708139160527818, 0.04832686022705129, 0.028654128358128573, 0.06685823983242435, 0.02639065838358816, 0.02596038510091603, 0.05888835902536108, 0.039269567407186956, 0.034486225490728696, 0.08760326496896245, 0.05947266577652866, 0.021334830483782197, 0.050764831624204115, 0.04916325204014298, 0.0766146759833059, 0.008665494387969375, 0.03721865044245797, 0.030991579443516753, 0.04114141898049463, 0.08699601005402305, 0.15586691608111705, 0.12040466776177769, 0.04270194391269357, 0.012535716955279632, 0.031214719788441737, 0.044938311611692754, 0.030712294429841063, 0.14561276792758895, 0.004003395461627553, 0.02151879309225948, 0.01809686985647967, 0.0297165333458613, 0.02430824371385238, 0.05691261826864174, 0.007543295280136649, 0.030752538943723328, 0.05122184520587326, 0.02990793658330316, 0.05240121458266532, 0.032326202283823685, 0.01768254460917125, 0.023053018226017876, 0.0644671032205224, 0.06930399085244826, 0.029113773451817614, 0.04838770292999764, 0.029639572152988087, 0.05563901241628393, 0.08305021291298252, 0.046726096526629506, 0.04509700289476783, 0.035946151587150754, 0.042311434423731226, 0.05403220428213958, 0.09673261218854497, 0.051178388868368445, 0.025499581299241514, 0.06416635242320838, 0.024325438557312857, 0.030983970275208838, 0.06736494570730195, 0.04165050355837711, 0.060328707744878154, 0.008334345221819897, 0.03475909451803854, 0.03576849196707049, 0.03076163432260435, 0.014295824071122034, 0.03496556670495099, 0.023922062621662216, 0.014379929991499072, 0.06961592653345677, 0.03662255359813571, 0.030296325923935063, 0.0028921329771213595, 0.03725810780099804, 0.08013368554172978, 0.029576092192362395, 0.04940173904141111, 0.01596760507973452, 0.017798317731508327, 0.04486888872399446, 0.022623614453139807, 0.10936645160038626, 0.027450544857269818, 0.035092515134883505, 0.017645732169189764, 0.021859041467729597, 0.08625252172350885, 0.08712316532769511, 0.024999379510841063, 0.0697542590299441, 0.03836023636282452, 0.0200211180133685, 0.03139011370348594, 0.04373426654285962, 0.017779414511976704, 0.03946441037940883, 0.03845056578997643, 0.03579286122394185, 0.0305908139524681, 0.05508819519872627, 0.054896010551601655, 0.03231037490730805, 0.06059829791587207, 0.01835061158354004, 0.02648721802078428, 0.012454163065300354, 0.05239736882128543, 0.011929689696238888, 0.013697731567757025, 0.03435933834783012, 0.019726486343349663, 0.04557131091132761, 0.03862791514444736, 0.034618433114261396, 0.019818953155810316, 0.02521702892056877, 0.014032743732264687, 0.02097795033947595, 0.018876810565650947, 0.08585499103872046, 0.03502152559738006, 0.07970828457825607, 0.02551961449846145, 0.048627699124476606, 0.020248261167697852, 0.06227439104188835, 0.0207200774832839, 0.01677436078147542, 0.0330118318238566, 0.05078917789843775, 0.004470769424862679, 0.04206681488862923, 0.05229049189496906, 0.013398305144942096, 0.019998210069212704, 0.017082990793090676, 0.019598936534396583, 0.07646604726511626, 0.05023912676880437, 0.060208497058239684, 0.07211500493388984, 0.03689175689472787, 0.025358427683973027, 0.019166956790873123, 0.035275625470545025, 0.05701794769735106, 0.016767420024881442, 0.07003836273666351, 0.03397474305764322, 0.0511777721675894, 0.033944386823643605, 0.05736194798843034, 0.044227887635990504, 0.037390330746289224, 0.035739250391000704, 0.03961403501190005, 0.04897707735278434, 0.023097342158096935, 0.053745193271747524, 0.054840706664347844, 0.09436756853134402, 0.02354251585089632, 0.04908124232784875, 0.028141042886061535, 0.030596406394315344, 0.03822805172192954, 0.05283326135888215, 0.025675266327696945, 0.054047062557431004, 0.0014684562460564438, 0.015337961245208018, 0.009731523929193858, 0.016168871699201486, 0.007300321397656996, 0.030996143412325653, 0.17846844038896023, 0.10846361698162173, 0.2927142285531567, 0.13468073921338206, 0.19380679233900963, 0.1423979259186214, 0.12650347840521606, 0.18687487639967473, 0.193653084457882, 0.15356129786420256, 0.1598805120034564, 0.13437602008062025, 0.12505472953160926, 0.13006700533291987, 0.15575578736682094, 0.16603887832212835, 0.25026696674045057, 0.200447027962054, 0.1556361550765653, 0.36663641191778645, 0.18612369654640076, 0.1989172576295753, 0.15856990410435587, 0.1047953198693933, 0.07051607218360709, 0.1203096345547707, 0.2561244443659821, 0.07383131767593085, 0.1227556537055681, 0.1546293623264759, 0.1933977626744778, 0.18402794045546364, 0.19159773184407144, 0.12498884597012114, 0.11654402129352094, 0.2458123952871369, 0.23202293522415623, 0.15465666570009726, 0.15143217098328376, 0.08329867054858515, 0.13877082135408156, 0.11020128059411242, 0.16821230040682902, 0.10428036322757121, 0.09465157264663328, 0.125119938935724, 0.19208599032173235, 0.1804295641880843, 0.13174343553762283, 0.10944571871791156, 0.10296638454160384, 0.15486513354605244, 0.21738535454196317, 0.1301689869574001, 0.20961579806622, 0.09391682537933511, 0.1426741465806, 0.12186039569637469, 0.10500148179069643, 0.25387839714605964, 0.15416425502588674, 0.1972674719628788, 0.1284898831058414, 0.18216145915850518, 0.18345522844503004, 0.1865320980188347, 0.10879668902846114, 0.16609170774538673, 0.1704683527350426, 0.12451845266285444, 0.19694640451381284, 0.15500160444888378, 0.20562207446463648, 0.1638364674703729, 0.10200317453352675, 0.13087368059542873, 0.10699248301886743, 0.1963025076134551, 0.09120249925481697, 0.13016753139034395, 0.13226763886069098, 0.13501745017786182, 0.24070416697331015, 0.12748616236832835, 0.18881029028805996, 0.16976534449044736, 0.11912271921192447, 0.22917376230320624, 0.15170811585360958, 0.21066535384424273, 0.19483212441686662, 0.15253824872835992, 0.14555615402998465, 0.13418786888641698, 0.2140027239558197, 0.11563501966696595, 0.12815340196773892, 0.1431811282471303, 0.12206920828189581, 0.13318970228635496, 0.10493878515497332, 0.13650458005647506, 0.1672744249264079, 0.203570353107587, 0.0714431534851751, 0.14458788018072807, 0.08380566753687398, 0.07216270156805554, 0.1348872458742511, 0.3112785001435588, 0.1987824414766604, 0.16180653365388994, 0.12861142295502848, 0.16067465406752404, 0.19133655714892572, 0.10563775611620758, 0.08623429649179021, 0.14386146028916683, 0.086159196892573, 0.11657558411600129, 0.2467225077411821, 0.16051205956647474, 0.24777541898431318, 0.0742361261959999, 0.08796099738608446, 0.057891418165977926, 0.14629699169628083, 0.11665567860848482, 0.17925921166616102, 0.23057830790358208, 0.1138372487959362, 0.1079730679010672, 0.3173681024101473, 0.22273191280903357, 0.2236422244459391, 0.14080944260762585, 0.23408996301793286, 0.12783288610197846, 0.1505518287059761, 0.08925645206604274, 0.16087847942065808, 0.20227358075639895, 0.12031251504536598, 0.12459158341610625, 0.17863379280653693, 0.16009284093255, 0.20036807494057765, 0.15536197220846532, 0.1351359486579895, 0.1592454097924694, 0.13315643874868272, 0.14242395758628845, 0.3793968626808736, 0.13974324739988775, 0.15232417311879898, 0.18328246029634632, 0.09004289494647134, 0.09869946632534267, 0.11101355595934777, 0.1754586341520471, 0.3341513727941821, 0.17735963537087365, 0.20870015445736148, 0.14058474901943438, 0.15834513390737195, 0.12280736464045702, 0.15414505686250426, 0.14197392689604915, 0.10830183453377216, 0.258101242324037, 0.12215526293843024, 0.13206261841039504, 0.18172253674316793, 0.13056385931709122, 0.128100365700741, 0.1310307592634232], [0.03418570451979195, 0.031821539948484114, 0.024340078497545856, 0.022721185326395978, 0.02985370330392353, 0.06851577830891456, 0.03966957255597076, 0.03976195892919937, 0.019517623962113456, 0.054904230675029184, 0.02123918440643578, 0.06617637561453928, 0.043677277262172395, 0.02717454253034967, 0.03083071630117634, 0.017423700736535173, 0.04595013755944468, 0.04957927991786311, 0.045177982218803904, 0.09348348008408662, 0.058727289039281115, 0.08669898244402102, 0.024744703156513073, 0.040298182171799486, 0.060353571128460674, 0.05431690553743994, 0.038570404923971624, 0.03622813323031991, 0.03662840650987722, 0.007304234191730259, 0.0394602888263762, 0.05255267399573519, 0.04758014283593624, 0.03484253681475117, 0.0413762440814847, 0.05199328808474445, 0.013533924732567563, 0.05198175463104441, 0.021076384976866747, 0.06815845957927166, 0.041342199134129676, 0.007836639922442696, 0.03277475442436915, 0.03389716516399095, 0.0010107124868344757, 0.014443245243221043, 0.007067832386031026, 0.07071557680084821, 0.01820902895903395, 0.006270757162823312, 0.056274796445523544, 0.1019854472589589, 0.030950798668087493, 0.04643648847817414, 0.046472598032485095, 0.0356326530867767, 0.020113998513308265, 0.0315913439337765, 0.044993508246637164, 0.049115524762460304, 0.038295731759600105, 0.0692015189316965, 0.0317750058527435, 0.06909425896141799, 0.09336577833540018, 0.036591101858404376, 0.026498732322286216, 0.012980204999386784, 0.03244334478832541, 0.03675541239640406, 0.02424087968745059, 0.018147607859704765, 0.029594365304576296, 0.03191079685254203, 0.03921568461303269, 0.02741933443523463, 0.056574781154913295, 0.01984052044609862, 0.04060375166215724, 0.05589861663118486, 0.041162938390287666, 0.047977374746434154, 0.035255324140551596, 0.003933701809728518, 0.011890965866886321, 0.04256951029322321, 0.03722363767484504, 0.0650736226910545, 0.03359822233417823, 0.003184039049947094, 0.020384573107284885, 0.02880478529409776, 0.06462306340014742, 0.07168749722862436, 0.07552280150834592, 0.059626147661718636, 0.03420392209063134, 0.014375502960906636, 0.04075067200427575, 0.03530502409463929, 0.03920058885048475, 0.04767155244706139, 0.025812461183616714, 0.013097743954389326, 0.057661105322861866, 0.03380904973094021, 0.046683042385284944, 0.02665274855380337, 0.022003110047549974, 0.07018186632663974, 0.029516963611146616, 0.1026530852240901, 0.05775826825429836, 0.05580716488522388, 0.08410281772094388, 0.02965318745062236, 0.0548735220405844, 0.031105215180545088, 0.01651514727141588, 0.013188141371844517, 0.03594427467173627, 0.02825842287781979, 0.062349073123186834, 0.043624482312870604, 0.0041059224449488665, 0.03246500592438444, 0.02072814055868695, 0.030669192408001235, 0.05759919775770076, 0.037724689820841435, 0.04202434680454674, 0.03863744910866503, 0.01056430746816219, 0.03832516102721134, 0.016453752985164043, 0.020387821320083835, 0.0519993823141821, 0.04160483322677113, 0.018185023593926625, 0.03371844068169594, 0.03305096359502885, 0.03750768009453051, 0.046456789808167566, 0.023040525247192672, 0.0717661974410857, 0.06686908763743217, 0.011844395381969311, 0.03984096174639079, 0.043814736418426044, 0.04832578387351767, 0.014605787075725536, 0.05111530152780395, 0.035483802203089, 0.05978176693221735, 0.05593415161955261, 0.031256854624277165, 0.05296258083094032, 0.043561900590336135, 0.03196692619953425, 0.0911124992454725, 0.013136038774504297, 0.0188282290999327, 0.04767133028156335, 0.040599484552419, 0.047226604750199665, 0.037313641514629126, 0.043032533834658326, 0.022410113409522082, 0.080662339835638, 0.06452275184734214, 0.016919145653505, 0.027249845142866817, 0.047555133895648104, 0.01554385886617726, 0.02810445644201771, 0.014451820639923457, 0.02205196730492096, 0.027565992392239072, 0.03827644932654597, 0.025119808532537955, 0.03299546435535435, 0.06330382935101948, 0.05235413847971828, 0.10760179104944391, 0.10584007993701006, 0.12332890963842794, 0.020299433925819975, 0.049196404495066216, 0.05278149679783852, 0.02083633324101327, 0.018078560355089365, 0.04716331822677486, 0.011575119307024345, 0.04541931906715036, 0.03436251761271589, 0.046084946051480315, 0.04953329549020818, 0.05421167570016077, 0.04013304808928121, 0.037378939018855174, 0.03788248478104511, 0.08073694913858369, 0.04889083883514808, 0.04469220586601765, 0.04773225725418137, 0.02460416432680382, 0.026603877889893712, 0.0724059881101693, 0.06146973059062035, 0.011991114626007696, 0.04656096244411123, 0.022552352954423236, 0.027616544619142532, 0.018604269040928736, 0.04099607677950014, 0.02393179959917982, 0.06992682033488828, 0.01936337407377939, 0.01199337745821404, 0.014264947854943815, 0.01587819400048184, 0.07788486508352142, 0.032558372890156125, 0.09801993867562664, 0.013956634812207233, 0.04651382505413025, 0.06043273865455582, 0.045809031824671456, 0.007022807962306205, 0.038377626558705684, 0.02431367527723553, 0.02459976506689864, 0.08005947460450473, 0.056396972147687796, 0.03185207812836574, 0.030416149736171773, 0.06876321704757792, 0.017935464706932826, 0.029648700090605887, 0.06125622188612338, 0.028247843203585477, 0.014055821173373732, 0.01453845656567043, 0.07894797295692467, 0.04754048246409624, 0.09178805089886151, 0.10352552147401918, 0.029302190861574588, 0.07786137682776298, 0.022786624556888017, 0.03024824433058741, 0.04644359777411146, 0.06414577913200183, 0.030112286706665353, 0.023369690245618264, 0.06585396751160584, 0.06645377605192124, 0.06285878589316722, 0.02440569584348029, 0.041290273694621946, 0.0486935788555251, 0.07794978337422495, 0.042652646154766126, 0.09311103111793918, 0.07217996152898959, 0.07094720348475442, 0.03365369093033575, 0.010741185678559686, 0.02959812296584489, 0.030132653154132348, 0.1246789480829912, 0.017475695123956088, 0.05045784870162607, 0.011157752690656532, 0.01972882674195834, 0.05163041904809014, 0.046696709393854105, 0.01892724596414595, 0.0038178753006392193, 0.06850739730702293, 0.022184040863066915, 0.060758184296109026, 0.04987926845769248, 0.03138806250306868, 0.043087083125306715, 0.03694202375387953, 0.03277764257584368, 0.04820715898888246, 0.033724768567950494, 0.1141221568949761, 0.021292084692827156, 0.03298775368039647, 0.008794318775706475, 0.1119740540161729, 0.01810837266666274, 0.09757484925249893, 0.004440361001123224, 0.03304290435006542, 0.010144267204938637, 0.04726182947295809, 0.0480474871132643, 0.022623848109956712, 0.029034316727531054, 0.03742668544873595, 0.05512190306739462, 0.06914588562663525, 0.03041863377626625, 0.02263594272306129, 0.021649838177367084, 0.01963863904107242, 0.03014303173028654, 0.03565976110797736, 0.03451718693418849, 0.016604584206136006, 0.03923290626957052, 0.028979759776003422, 0.05300755402253521, 0.024456592809949673, 0.03323917607626608, 0.0485490755208077, 0.007713127396850577, 0.02162732285327248, 0.018746627329458154, 0.021247126822990757, 0.03844603821034393, 0.03097313013108027, 0.06894663381840914, 0.0325641491931052, 0.04637873694000225, 0.0219703808562049, 0.006359210153365689, 0.05388074869950933, 0.00937123086318494, 0.02111681909751027, 0.03057320159108889, 0.019825447666188403, 0.04372074509099607, 0.020778593194160252, 0.05384086999261091, 0.03057268065130038, 0.05656690577105169, 0.07325911128352727, 0.041812715015464255, 0.017959065960660096, 0.012021548426409644, 0.02842372166924179, 0.036613050277435014, 0.032710629034667246, 0.03803422764664696, 0.03279706673516381, 0.04008757311009592, 0.014259073875784395, 0.08512616563107699, 0.12075839353905571, 0.13634512651591532, 0.10820474055024887, 0.12997069275907933, 0.14714275276468647, 0.1694309930767744, 0.24596898365885983, 0.19036454479059867, 0.1438477473153222, 0.1059410273427925, 0.16982327605928146, 0.15267519460570428, 0.14221168994422884, 0.18272687801189963, 0.06202810143511142, 0.1073845514967557, 0.25292123157170515, 0.13581082615400517, 0.17823159664628968, 0.13768453932096883, 0.14985925457890958, 0.12227665723091173, 0.1103698505809711, 0.16447676375748652, 0.22848961514330682, 0.09958713240320645, 0.19933281436322198, 0.16104810660885227, 0.11571214173830326, 0.0842277053743601, 0.17236014557701929, 0.20892143129341065, 0.13355491172161796, 0.17301101387748796, 0.11053036898374559, 0.12069125359337177, 0.16201817310385166, 0.20865654873271144, 0.10600961519465332, 0.09793164704235331, 0.11030642616171991, 0.11402581367761859, 0.09313626605416499, 0.14334438158379448, 0.12154210148559463, 0.10327632073312999, 0.18207931921126383, 0.09670088082672128, 0.17357079432375971, 0.21270647254442016, 0.24989935178910536, 0.10582083580835212, 0.17964459985734957, 0.13141076951738329, 0.10582118054791805, 0.10919317783367251, 0.08467467171290229, 0.25503465365017614, 0.07035577594633065, 0.20394477091969984, 0.07934174215000483, 0.08851974361365841, 0.1178763401243956, 0.155286711730784, 0.08111416317162015, 0.07821917053191893, 0.10367996479955413, 0.13799132689112617, 0.13826094387519744, 0.1983535854566482, 0.1434329566695998, 0.13603849216334282, 0.13410461045080616, 0.15829786628244386, 0.20694012873836104, 0.17846840974544326, 0.20063606781824944, 0.10603606054979949, 0.13583097426641372, 0.0903045982422848, 0.13152675522911933, 0.12315648622931012, 0.09988052875644739, 0.13721028493056375, 0.19948702786237965, 0.17347788318030297, 0.16075936807019098, 0.196497461668426, 0.10346220430707741, 0.1994553271440729, 0.09894937952800144, 0.14190513220044876, 0.15076239563284383, 0.24225215487662824, 0.20353163502389388, 0.11431566304377011, 0.09111202427095945, 0.10291831252435524, 0.1359234257571159, 0.11733094680934184, 0.09990431578649629, 0.19242959607753063, 0.11218858161760915, 0.15063511778510388, 0.16698272928835886, 0.11153338492036828, 0.11853691475886492, 0.13521989657273217, 0.18439469738833367, 0.14603592425344453, 0.1291441911410901, 0.14997966827884798, 0.21724799497713967, 0.151474489680221, 0.12592063105154422, 0.10589446451875473, 0.19043306369454632, 0.11643533639970327, 0.15434868303277802, 0.05047120927502552, 0.1182853468062897, 0.15862477132149283, 0.11880485401038202, 0.12719372362499276, 0.18422730717687838, 0.0894586303301396, 0.1532343621816366, 0.11987047465217691, 0.1848285483016122, 0.17297036525222564, 0.0951271064038719, 0.11146238389154596, 0.1591928101955883, 0.1287432207215217, 0.11286485339364699, 0.16301997096067475, 0.0849670798127209, 0.14636855963016712, 0.10706434206616496, 0.13154866534375376, 0.11494017025876431, 0.15525113460758042, 0.130223379200024, 0.18295786884282866, 0.1452694686069604, 0.1151835717140667, 0.08509758289062208, 0.09463268091842052, 0.12426816407711276, 0.15131070008200986, 0.1543415584150822, 0.13962145474168564, 0.11472882958309305, 0.17634049328344484, 0.15706884674727917, 0.08794844886588474, 0.14144239977242487, 0.14214692487111016, 0.15170707397403257, 0.13366596382712165, 0.09156961624901142, 0.15763481718397912, 0.24932238032981274, 0.1001163459412994, 0.19066914134929258, 0.14738820733562594, 0.09573307429109851, 0.18953225154790188, 0.15594885684549809, 0.13056742928681836, 0.13426731220416485, 0.1277252047833416, 0.11047346397273003, 0.09407178964465858, 0.07592518152969499], [0.015502537041151477, 0.05955678606105428, 0.03226634017342041, 0.13853587750946322, 0.02393928236298023, 0.06962862827124135, 0.003524031982974961, 0.050601712352926695, 0.04211958302485366, 0.03783860709518194, 0.10497633878502155, 0.015049260053333017, 0.022570084059430708, 0.04542031498145192, 0.04412122904473255, 0.0449662929731271, 0.03251356057702534, 0.033863407499607534, 0.039260010460331556, 0.035927167928387085, 0.03289183181139731, 0.030304343034062656, 0.06724645488805349, 0.06967435605944165, 0.040909512674496065, 0.024408516962261453, 0.021889958861133745, 0.014912970138773804, 0.05051244012711029, 0.0495260866028407, 0.05608405204369657, 0.05987450953633074, 0.07284648866663057, 0.09380550514305792, 0.04156395477513152, 0.020498932797401663, 0.059534389480587944, 0.05752229019098225, 0.025462738215743054, 0.033773690942795045, 0.01222832896371162, 0.013802725832999475, 0.07632255133601927, 0.031080618012516253, 0.1092628688521443, 0.03448856971977699, 0.05461980138094195, 0.04208302913954662, 0.020258785300557653, 0.01793391529410597, 0.022164105340057326, 0.014063439917780701, 0.025786927473100445, 0.039825505922518434, 0.11278189373232665, 0.049157334010927915, 0.0705418280596214, 0.03319694164900049, 0.035824401063784476, 0.05929032152879143, 0.025837318821539803, 0.014716209073911512, 0.026891867577609037, 0.011956142712264292, 0.04046790129054458, 0.04960287542593095, 0.029682538194221356, 0.05157165627385821, 0.034140585771491455, 0.04580728131376448, 0.04470889126100848, 0.05926574925862013, 0.011954602875536489, 0.047314413748080694, 0.05584334721788765, 0.024048972747198517, 0.0631543196317169, 0.018293930653242335, 0.03853205073204252, 0.04390556763316836, 0.021171372218598283, 0.0402843504543266, 0.040145791961901614, 0.07256876647232041, 0.08145414533153658, 0.05227156569279971, 0.044259710928365115, 0.0460191007943884, 0.030420119986839356, 0.0342079593739923, 0.04834102519277123, 0.031092863927985874, 0.05663389632959039, 0.03044184815559176, 0.051358139908481995, 0.04822657165688373, 0.02261278388511029, 0.04686208862450816, 0.06367473848043911, 0.041125702686728015, 0.011366966514728002, 0.01584779371642658, 0.06559041794389486, 0.07438441783550286, 0.04631858754662737, 0.008879495303957693, 0.04125606786880282, 0.014260818641031943, 0.032728662744404814, 0.03544514540642981, 0.05367192845310896, 0.046847663188893954, 0.022861277909889337, 0.018974272271377907, 0.016833089081750765, 0.008650034733657396, 0.019517208359414534, 0.037776086659681414, 0.041655758921537674, 0.05757623427217046, 0.03961378603332466, 0.059233998744598323, 0.0410874902210649, 0.05409565934490773, 0.021297652236816865, 0.03179486093652104, 0.04357011305288442, 0.003087080089420441, 0.0178609358432192, 0.02365708046953284, 0.0398714788588545, 0.08404454141254387, 0.03114433354517866, 0.05674530466597888, 0.04587817509027739, 0.08227056523244228, 0.030718742974943695, 0.009547254885546863, 0.08585295324484188, 0.03926033604769938, 0.048538438389979066, 0.06494098222784458, 0.03704756002632841, 0.056051826555161714, 0.060090929374939976, 0.03282769493037655, 0.026766897569740974, 0.03995053530220063, 0.049395962738462036, 0.05090679154701291, 0.030282262464865085, 0.0473897431736752, 0.025439439566745877, 0.0389734284591771, 0.03679359038811057, 0.04409122138073848, 0.046711594482222875, 0.03076936606498015, 0.03077070863406745, 0.04772634305540593, 0.04646099946131149, 0.012256691453888292, 0.07602304926202183, 0.016934335261823672, 0.025698174271852742, 0.03830245801157529, 0.04922538560124175, 0.02021371443275242, 0.04033119290045673, 0.038020985816875776, 0.03806619266528757, 0.024891757564018333, 0.04548069420120409, 0.032465875434178504, 0.08420712825271391, 0.056862052635199604, 0.07383291113881335, 0.028277034983940186, 0.02620850374261218, 0.06806243811884234, 0.0089266556765764, 0.11894488722206124, 0.006229189710856806, 0.03870974482607938, 0.011092736723742658, 0.04265136295749296, 0.025897609941180677, 0.061888780685201775, 0.01938409292169156, 0.08657189611826213, 0.040229919907306476, 0.024181415942767938, 0.04461543619512551, 0.06807362300253685, 0.06446308125891993, 0.017560437854920185, 0.020198967240210024, 0.07674681848936504, 0.0423847911729207, 0.05191548802559415, 0.03364187019366411, 0.1052285579123324, 0.06027343067070169, 0.07015574272842177, 0.04453310089546346, 0.033579426366956, 0.00566050109844054, 0.034528666761733835, 0.07846916800424938, 0.0472636221187009, 0.013511635404410622, 0.06014156778673491, 0.03551711553647634, 0.06585418201622463, 0.06917624569107449, 0.009043540584013588, 0.0790810807337684, 0.056008128899960756, 0.07045359771338201, 0.039984480658125494, 0.05398711234691644, 0.019010263082060604, 0.027061506257122083, 0.010630183368771067, 0.04127971317258574, 0.008370266126979505, 0.01775085475415953, 0.04285801517506761, 0.028636129122347604, 0.021867615906822107, 0.05592749048505099, 0.021711707438131975, 0.08736701111399359, 0.024125516422153003, 0.08424219209700824, 0.03190796041200238, 0.06502397253268188, 0.024255121261962963, 0.008290818978791997, 0.06701550236152065, 0.03325032648600398, 0.03489333227457058, 0.02143379946750018, 0.0559135323630706, 0.03168510351960938, 0.06536724887067272, 0.0272694569937284, 0.016039002559057648, 0.027166619265992797, 0.027981748308746085, 0.05728081544680942, 0.07409527327024168, 0.04627037380311278, 0.05761833846448891, 0.012327456910673891, 0.04173346321969744, 0.028732847722788012, 0.04398708704919104, 0.03024775211909606, 0.025689329786766923, 0.03517408817706089, 0.02777867372177782, 0.016968598544237115, 0.06153700843213066, 0.046584098299424496, 0.03366587172833181, 0.0378313867164956, 0.05068308238180415, 0.1001621809818091, 0.030992274668308038, 0.04489292856305838, 0.03131608662736272, 0.06197300439159717, 0.013810514074359691, 0.08467929888396494, 0.06151866445678377, 0.03751714128039537, 0.12370456085209885, 0.0510684552512342, 0.016616504534237807, 0.03738183483120896, 0.02634429091197108, 0.018558407187341683, 0.05019318830642489, 0.028843987928403002, 0.06482292041783372, 0.034400370017054586, 0.05421385138986572, 0.008688168675308267, 0.07998272791625032, 0.020954672757896687, 0.023081497544603004, 0.031104491227456642, 0.019740446380549864, 0.03751387774583794, 0.011050329926694113, 0.03789504479256369, 0.02896647772661621, 0.08448484278614483, 0.0697297212337294, 0.023175408432800925, 0.029504537665014787, 0.023404851766122926, 0.025096764607775598, 0.045201022313126636, 0.019922549310590953, 0.08356147701100958, 0.028714635897608056, 0.03422927194004578, 0.01428726112334839, 0.01830144789099934, 0.05358083676847239, 0.037313331249019796, 0.06664905952469957, 0.005700049429921614, 0.03593004075810313, 0.0214687024333304, 0.030622263776979623, 0.049262173143365694, 0.02895383344542596, 0.02363028271394151, 0.006152559372205889, 0.032053452000142105, 0.009055616044920058, 0.03886789218672822, 0.03653811538712152, 0.030871299808965098, 0.022072902572671735, 0.05009330193241758, 0.01542795072084353, 0.023244601494121938, 0.01882634069319935, 0.07375019662562879, 0.03257989229994916, 0.06686583176375398, 0.04115864063703245, 0.04678115143530792, 0.0520438920225828, 0.05073729459376586, 0.021292521362943996, 0.04587075935917036, 0.014077639357457239, 0.03271704885147272, 0.04048450241586374, 0.036049029534502376, 0.015355301645374107, 0.07809773027416199, 0.037879788151551644, 0.015625586083549407, 0.032744210498828086, 0.08731782826925479, 0.090148676367056, 0.19213111290047247, 0.16441797417017723, 0.15836758028355338, 0.19671860060864882, 0.09968522230103131, 0.2591525907478025, 0.12885312369513896, 0.14246243052184582, 0.08081773311019906, 0.10659008767575988, 0.20903076736196397, 0.15738787640246654, 0.12357299291198293, 0.14978836080239666, 0.12738604999838338, 0.1619042251859942, 0.13707989676585122, 0.11339678654387114, 0.13565546352296107, 0.19649052091183203, 0.07031797716814665, 0.1856234717753626, 0.15102124142069973, 0.20737295309382103, 0.1507083404689066, 0.17040161115507926, 0.1417731658946122, 0.11341284374676405, 0.10063392260382253, 0.18183305258712462, 0.14529743081619664, 0.10519809825646301, 0.18686450356917997, 0.21513225931313731, 0.13179303206984075, 0.12611584557640937, 0.18309291482212084, 0.14341584226537135, 0.13515192925209, 0.11611886547818301, 0.1617597410034749, 0.16325125290501505, 0.1385239878248784, 0.14943617486184643, 0.16562466990322838, 0.2717160343402817, 0.2632537658416456, 0.13379809867230155, 0.1084260097254188, 0.038975213444040674, 0.0812568317257589, 0.12286317414574086, 0.20606041465315128, 0.1043086012284602, 0.17286386370899218, 0.12965229129598987, 0.21792356195228718, 0.10835952095447049, 0.20281540410172558, 0.18272831825719726, 0.1396962402448539, 0.10333428294548105, 0.08472565486426316, 0.16158182474394, 0.10817229672665558, 0.17801297047445852, 0.13594435527920723, 0.19131322211075216, 0.14880530145620147, 0.10797662254903587, 0.11004839242706377, 0.12503740062276203, 0.1430990495869229, 0.15056984709395518, 0.15480128777844293, 0.13715161791732236, 0.11637375059147036, 0.15793069566209472, 0.1903721750263245, 0.16957161617615532, 0.12051638636377551, 0.13376817527797916, 0.14977955079126745, 0.12611504884496813, 0.20215882078534175, 0.13285392594914283, 0.16943473158584488, 0.15746293769728753, 0.20509914284752262, 0.1258024160239485, 0.06881190193516594, 0.19004926896624028, 0.30227096090393685, 0.07567105484345267, 0.15869572638503968, 0.11651021383342244, 0.2017907768247589, 0.15524626228838198, 0.17511084555618225, 0.18600991716788662, 0.10008165748008799, 0.19406952985352088, 0.2288089359119054, 0.10458993935777296, 0.13589664332328305, 0.1034041271815377, 0.08581890829748685, 0.16730565067020156, 0.10380098370895272, 0.13167015156678616, 0.09031751448468817, 0.19161366647289646, 0.09418536217943316, 0.16935026273131373, 0.1311217858305862, 0.16745537489412293, 0.16791989996788964, 0.17038841912102315, 0.11643379656297546, 0.14187266539421775, 0.16463269329359456, 0.09094548441710011, 0.14264849795689508, 0.20172758989276426, 0.08253534820171134, 0.1631552620881027, 0.17385395574233226, 0.15386825397370324, 0.19532333999391527, 0.1284858381616012, 0.1656482654112962, 0.14250347751282877, 0.0864690181709105, 0.12593547017463755, 0.1083325163551396, 0.29285610803673345, 0.220388020839422, 0.1364013880130745, 0.17808680602860066, 0.20745726873076734, 0.10424831776969856, 0.3487408125112134, 0.18719520840433337, 0.09353382738247033, 0.1743463510947843, 0.08811385490961614, 0.12430730350916425, 0.09370675640961817, 0.1068316888244402, 0.1557926515177373, 0.14800887645011948, 0.13555838486119626, 0.1872469346609808, 0.15225412203900276, 0.13889880400271187, 0.1338502079729111, 0.17370127441902317, 0.10624946966286629, 0.1042997069476593, 0.1410897388573616, 0.18368090262576459, 0.13990378878529997, 0.15261494945133888, 0.10904644901353507, 0.2218968310062924, 0.18400629081072348, 0.1993555824963316, 0.14982997469844359, 0.1194022263910982, 0.14023925868734238, 0.17123698407123167, 0.0752529087326219, 0.12194477262035494, 0.22790515134411476, 0.193506179437522, 0.16584585480872663]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.043056818821858016, 0.05253025443263112, 0.047638744731704076, 0.025873102788482944, 0.09631766066435846, 0.02562542656256307, 0.0486056664357743, 0.03114751089484461, 0.0777440274795217, 0.053755083466849984, 0.05494497123084242, 0.0028168461651676487, 0.05006423655657038, 0.06600604362545476, 0.025775267614892898, 0.011795572598554916, 0.016602563649235715, 0.05122114423542254, 0.06288691664174681, 0.036842007144925096, 0.018164251119859757, 0.11053933987333892, 0.009033511535474851, 0.014282917404817718, 0.046354574526870446, 0.11665273683085559, 0.09185322199858005, 0.056713201751511906, 0.04848231478864628, 0.00482361420102778, 0.04653463200215371, 0.06644255286383052, 0.033078079277108756, 0.02844118464347576, 0.022766487935798305, 0.04175544611268467, 0.004074331851781256, 0.07871444637496626, 0.04425949259330669, 0.08167493187131421, 0.0042707510499073375, 0.04577170419056089, 0.014444801359317236, 0.0380060815763089, 0.0646692891454985, 0.03985190914282876, 0.1665533982938336, 0.05203243517767518, 0.024921368777511582, 0.030493990014938098, 0.02876206440100026, 0.0291359995777208, 0.020775791227577195, 0.10532574382640662, 0.026618770639141722, 0.039300099841409156, 0.0562367755018415, 0.06336711204400466, 0.06006945976086202, 0.03497802712503941, 0.0027847461235303915, 0.06073003439533134, 0.042581740886934345, 0.033825306116693446, 0.013039702260416123, 0.022180087849377625, 0.09257182013243438, 0.02181061896525564, 0.03941056588965078, 0.049043359279993086, 0.05177848086121583, 0.023741516765327226, 0.09534467537436755, 0.05437013715685857, 0.06885819662843021, 0.029564158457721916, 0.03540713212362701, 0.008301270333298994, 0.0315152445898181, 0.018395259187767105, 0.06099059238969799, 0.05009720131995217, 0.008567562495778886, 0.01594664587173611, 0.04584453999996186, 0.03705008428603892, 0.016742188919095263, 0.03771425187287312, 0.022895866779670603, 0.02254943990509116, 0.0511390425925774, 0.016016470955594653, 0.06596099765550706, 0.01076586328582057, 0.02600676597907178, 0.0314199049476414, 0.022479386910075144, 0.02730991792744927, 0.06727196561593203, 0.04634067003104476, 0.03925876939789422, 0.05353184927615428, 0.005964137653204343, 0.053331279796698404, 0.025889883944464308, 0.0032802965612180775, 0.035648415345818765, 0.05211173293871745, 0.03599618861992513, 0.021614224664987098, 0.03315651135879659, 0.06659459833416247, 0.027403118269097422, 0.06025801315122555, 0.04936382151959885, 0.06188894539410549, 0.016373882573398373, 0.00869415756765633, 0.04549805375356828, 0.02205746398577767, 0.011194813151603505, 0.007018421630134747, 0.015538893658818017, 0.008413629576323495, 0.028288227528513923, 0.06195487492086907, 0.005784519242062684, 0.0579344914595206, 0.06976722123762293, 0.007280916869339924, 0.018249675669076464, 0.041251379410706224, 0.053523341869755145, 0.0345179760047505, 0.049665740600997405, 0.025831057967978622, 0.045321692652519674, 0.06682666168818552, 0.07918496225630084, 0.005802292481905991, 0.01974936938964792, 0.02541110388964655, 0.06584828313920768, 0.03451987590280271, 0.03485331184140617, 0.06645088023956745, 0.04262716607040456, 0.0402308009084194, 0.02030990634774489, 0.10861278962223761, 0.008706364221119834, 0.0448308831020709, 0.0859228817505702, 0.02366985881610984, 0.04330980786753278, 0.06749521895882583, 0.04502707055859989, 0.030431460003338517, 0.033987050260146784, 0.01698204530252805, 0.012168731153642219, 0.046378281117687305, 0.053580300506925395, 0.045539441653677536, 0.017973217519841368, 0.02163796956020017, 0.05402741240217321, 0.046961082506083676, 0.00783288034595429, 0.04509875340567482, 0.032469472216983, 0.03316863086975871, 0.014526560177816259, 0.06520049451219459, 0.02035453671499366, 0.04039914106890079, 0.04326548585067353, 0.09778310259383532, 0.016553390380595962, 0.057911776952565684, 0.0056856929422205976, 0.06828735387253185, 0.03886188605740186, 0.06487718242551051, 0.08340785339955362, 0.05978062546121017, 0.012828868160384798, 0.029447667127955827, 0.023663998243489096, 0.008148812133097842, 0.07059443531738174, 0.043061970763148806, 0.009449736680835485, 0.04739480701485469, 0.0361964708164094, 0.06671400079804082, 0.0405792253572614, 0.09234779304073704, 0.06736064795404673, 0.01770043084698339, 0.01709979684692958, 0.024578854697005405, 0.008641958251715669, 0.055029800146698, 0.019175870223872123, 0.0478850688124376, 0.05216055572213185, 0.013987150009451135, 0.017084095874921452, 0.045455037916619936, 0.010940488240110778, 0.03082124745443223, 0.09148481031579357, 0.026712158672331322, 0.030619452234297514, 0.10787182938187354, 0.03216438153157792, 0.04207510395996994, 0.0400936903221713, 0.05175136900957554, 0.017671275455805085, 0.048348808646081924, 0.06882451940327883, 0.07275307190514381, 0.04862369248463262, 0.057036035033243324, 0.03574511096362145, 0.01144040370314953, 0.035534536375874476, 0.03909037178081851, 0.0434652662595674, 0.030661115926059506, 0.04284418345759473, 0.07984255680874472, 0.015583557542413475, 0.07259762500442805, 0.04882980844066028, 0.04602852750629668, 0.053908251255991003, 0.09699239260366849, 0.02332270224278252, 0.0672236561114269, 0.09223349272243439, 0.02419166811441462, 0.0767383991830772, 0.10515019477855776, 0.06740230015448986, 0.06207937953032314, 0.06494756292311415, 0.03640002420833034, 0.08639077761120374, 0.02512788501447968, 0.034269606469259146, 0.04331304458901287, 0.04615582450623474, 0.027199990055974455, 0.04773791481350218, 0.03084388726781453, 0.026515201297438434, 0.09780245397480265, 0.029115033666453058, 0.017751718518294154, 0.0466710799223473, 0.019312505835607167, 0.026771980563118577, 0.018769347582072504, 0.03358020394619915, 0.03611044680339194, 0.031196933142059756, 0.034347034975766175, 0.015444836256304577, 0.021624767950045008, 0.07810684672046093, 0.021864082326271364, 0.027576786571092186, 0.09047814013977205, 0.04908043027464901, 0.002176545568809454, 0.0008914665323250267, 0.033381342842814424, 0.06343150556448006, 0.04291515001246045, 0.01852213100890719, 0.0154422095323342, 0.039020125348601616, 0.03294520515708193, 0.04018857414203306, 0.045743427885275696, 0.038700605397142714, 0.023765301880156322, 0.042724248562609, 0.07529005633607026, 0.009262694398902599, 0.061477881766134695, 0.01502152000959482, 0.018279945718184597, 0.022941025747587124, 0.020533410584433906, 0.02277693354464587, 0.043724295908525106, 0.057589866806783026, 0.050792560176623446, 0.015100505589807947, 0.037282297027207194, 0.046973236491002386, 0.08931263695440947, 0.04641282785263273, 0.05337858572602273, 0.0076328476068503685, 0.02345623711364404, 0.09998372079984796, 0.020257590203395775, 0.046892858545986876, 0.057733611714455395, 0.011123405138571418, 0.024600452630810683, 0.046179462149138414, 0.026500825657539313, 0.02576378204168812, 0.039269912146752885, 0.017622232422112458, 0.022618644457731037, 0.04426768207321725, 0.04430170786837417, 0.011093378322379244, 0.02903745002714136, 0.04493863719906058, 0.053085258320694974, 0.06207193698613875, 0.05487936729144666, 0.010945719663023708, 0.03374231198141652, 0.04243477074910076, 0.05276160149444496, 0.08748884973747116, 0.05592009007570244, 0.03246548855977674, 0.040937957519124595, 0.068808906531382, 0.0731331740896548, 0.021317972719008406, 0.05050190258771182, 0.00621859519366896, 0.019678389428243525, 0.053358376326580206, 0.02510035372970085, 0.06002068294272308, 0.03054916558246459, 0.04321348380237337, 0.06939792089284429, 0.008558240163350299, 0.042841551945574825, 0.1719711874161036, 0.24437622557724678, 0.12980131071902093, 0.15015934654060872, 0.17851550883102804, 0.17916217896967165, 0.08182399725962071, 0.22577438503503802, 0.1314385478655177, 0.13537257789604126, 0.16632079867826355, 0.13618283845003576, 0.1865082267191141, 0.19719533712392856, 0.1024747399553176, 0.23991497383723337, 0.13364339487687235, 0.1016741780744445, 0.0787225439243259, 0.1571825341952424, 0.08540485309617174, 0.20813686532839654, 0.21623472112321088, 0.12121760196262792, 0.15503007227615004, 0.17407668814543756, 0.14572450951222451, 0.08647052736412134, 0.14371394239846738, 0.15813838209836714, 0.1453670069214798, 0.20421985777155047, 0.14284516804881636, 0.1391252289496122, 0.06024412780759796, 0.16694280078574536, 0.16888304102805354, 0.18142661229977686, 0.1160950631263756, 0.24525233904921243, 0.15921674278234282, 0.10686754173929654, 0.10093076635272273, 0.16274185040064398, 0.10649005191460734, 0.18356085664802985, 0.20481516937575034, 0.22001332723565642, 0.08932214410554978, 0.1369152951144403, 0.24276898843386482, 0.1251114889859192, 0.11169898248608075, 0.16078432721476402, 0.13810029523747583, 0.10125132818375865, 0.1087745414265702, 0.13064549364630254, 0.13111213312274025, 0.28753265498145936, 0.15121881549637164, 0.21760473147996012, 0.17063076337499006, 0.23913362544150124, 0.07870376710930178, 0.1495148214481531, 0.24566639425052753, 0.09327720324959486, 0.22849641800407441, 0.22611313379339634, 0.15635713574386415, 0.12906024322634743, 0.2878221136427695, 0.18477959528325066, 0.17945349156375856, 0.13404864006705824, 0.1366100703636485, 0.0992715041784029, 0.1316780882376817, 0.10164960197383359, 0.20725600211130035, 0.10941187295341685, 0.07977276619884276, 0.19415012230315518, 0.20784590513475482, 0.14898266613243089, 0.09479733619598613, 0.16891946084797385, 0.11201387526647699, 0.1515918390284623, 0.20217613437243048, 0.09349625843066363, 0.279687209835937, 0.08259963830031695, 0.09665669287524878, 0.09521533675011128, 0.23930070921778682, 0.07362555412034835, 0.15359528152452362, 0.15731781000091186, 0.13264107608026074, 0.11337776458071125, 0.09606017085212855, 0.1346276952855049, 0.19453489762400428, 0.21399281077807952, 0.1322614335485043, 0.10049997979114134, 0.08359490908802518, 0.09260079357773067, 0.11142735069076862, 0.10914105321130446, 0.16468564529092083, 0.07749727055911096, 0.17720819511000188, 0.15914967944545133, 0.22042434872879138, 0.12835743416461254, 0.084463897942295, 0.11707092124608257, 0.1175241771664831, 0.08649988385337977, 0.15534576178798754, 0.19926009729744928, 0.15488512844087618, 0.10402540916637068, 0.07568161153504926, 0.11957825041346012, 0.17500569232769553, 0.11330493260174991, 0.20737480702659777, 0.16593040027205022, 0.11394025697823494, 0.11578757841620715, 0.3289772455971087, 0.11562958044270355, 0.16361477694684462, 0.15906734031534966, 0.08177779449690735, 0.12257275787452537, 0.10062544967137999, 0.11025433218286884, 0.163275231457045, 0.1496068898948931, 0.09797254081575141, 0.1570486067043197, 0.2622764521548825, 0.10517653288139452, 0.142897185418875, 0.1839749578146204, 0.12859079986810684, 0.14299305366171947, 0.23238406907166206, 0.1103243372973896, 0.10735784567171529, 0.163367361190819, 0.09932323809592955, 0.19419932046965246, 0.16437738683194886, 0.20883999614705964, 0.08472319572202622, 0.15228888710900662, 0.2090968347845539, 0.1531533254010062, 0.12119568418711425, 0.10175058768401224, 0.12194936914790062, 0.16691255563449475, 0.17000439456633984, 0.12342706082328675, 0.15462347877121743, 0.1647338168995996, 0.1297511626034975, 0.16624507854782766, 0.19694603679160919, 0.1369948303627391], [0.013366014538933674, 0.01539955662953998, 0.07076076832750151, 0.041723144015357386, 0.06193149774785965, 0.05070967712409554, 0.0243731964785125, 0.010920659011800685, 0.04874184239475478, 0.027138521076150002, 0.044310900923465533, 0.03626907679943308, 0.003554343209309023, 0.05592159543847365, 0.025626117956914732, 0.045153662757647615, 0.045257969458978024, 0.051577800299010934, 0.018148109647295168, 0.10618671940098848, 0.03454555900046422, 0.01945268651921182, 0.06514869164675474, 0.0560885145058555, 0.024094733094135602, 0.02759657462217635, 0.08283599174671596, 0.05558267431033235, 0.022051078642928795, 0.051861019174177805, 0.03222242418316103, 0.052597348413039605, 0.036708753811375755, 0.06244652333759493, 0.03421951197989045, 0.07721586348188501, 0.01686364449861069, 0.021823257500786456, 0.04663010954015678, 0.03728498599582142, 0.0652618658158087, 0.050627567820371165, 0.01892768071904298, 0.04802232495539131, 0.04100890492179221, 0.04247097223396263, 0.04787013392835375, 0.007822800544090569, 0.015134973800741138, 0.03662220502813016, 0.04745057055486306, 0.06604025711215313, 0.046993204572748755, 0.06068975349227267, 0.01805005230820708, 0.03321372280498186, 0.06263038060898263, 0.03258586778575855, 0.06508461605276793, 0.015283902250831167, 0.001160080240468585, 0.024629429906546593, 0.05266175342483386, 0.051008110505438624, 0.08763416129494868, 0.003214920293577316, 0.03530276796570228, 0.032547559559104905, 0.010800420554474959, 0.05746781750912628, 0.05146082633385255, 0.06004183846075208, 0.03097818631138052, 0.02778886460639056, 0.03798366584364445, 0.014152736083844738, 0.05755246256388003, 0.028615377715698657, 0.06858326299416442, 0.01204178942697904, 0.035595310130907644, 0.04197964174372535, 0.04132901859139243, 0.08280792228517034, 0.00944100327849869, 0.04004025951989236, 0.08548745269616766, 0.039861339685176654, 0.00832782198314465, 0.006403738535159538, 0.06843668739161185, 0.020426803704110846, 0.014666717878783183, 0.04047464669471787, 0.020981077893426823, 0.08042004920782582, 0.0388839417287419, 0.008937035210340494, 0.033414640854443275, 0.03927387665176103, 0.04486646405571411, 0.02378331452247597, 0.10510099661206046, 0.031864128691414674, 0.015989668411953796, 0.09790867206550415, 0.060496270326116396, 0.06811488449813859, 0.012682787642153281, 0.06331585693143069, 0.005405393340850189, 0.09087107429701476, 0.05740135172081571, 0.05197166525308163, 0.031701043894093846, 0.016128529509108876, 0.054907735527282765, 0.053165781822416096, 0.03131284224500339, 0.030966781177407796, 0.03910483169038931, 0.0246192122088565, 0.015060487071863346, 0.0584526350271077, 0.023848631178900122, 0.01821978291827104, 0.09652576078811, 0.03246643467836323, 0.021631147547234452, 0.024354881231462764, 0.03241437900390837, 0.048079206983769135, 0.012864053621137095, 0.019333998432322856, 0.023329206329259663, 0.022533857676711296, 0.013630357007646273, 0.02383368671871722, 0.036497485914057305, 0.012497086014087885, 0.09096861261153415, 0.07363901428517795, 0.01523969131672094, 0.060608092349983995, 0.09351364862654479, 0.047312245719254985, 0.03632865162686475, 0.04811305657870347, 0.062179897926867976, 0.02479030454020587, 0.02688723657610676, 0.021941392089150125, 0.02827986376360059, 0.020471730930430275, 0.08335288659098648, 0.016939816620921897, 0.028049432176856265, 0.08954353585478761, 0.008159059516694999, 0.03255723908002819, 0.033619171008467674, 0.03632497823526783, 0.06823363578728131, 0.049011191248052546, 0.030820083000787327, 0.018392579795251933, 0.1029415556319779, 0.0320350524834207, 0.025846877683615013, 0.08768305302627626, 0.022909097118122924, 0.043762799487599445, 0.028870251337667147, 0.0379568106314588, 0.024873331234219576, 0.0372650638793505, 0.03997947427354032, 0.06524861249471865, 0.03941584423544907, 0.01498246101677538, 0.06421012285676214, 0.07728907084392925, 0.029728930563695972, 0.01968130439279541, 0.06414677887674301, 0.0626433351557822, 0.030368663776185245, 0.020459412236607844, 0.022811436229535652, 0.05040139951292546, 0.04387631456577971, 0.004483578893761601, 0.021495676389144316, 0.02966358900941428, 0.033871439931493615, 0.03009337199581487, 0.039207690485542825, 0.08017906859036415, 0.04376563784335891, 0.021350847467059092, 0.04812993349567537, 0.03618162403243684, 0.04658280361083247, 0.01762482562973615, 0.06818472873419523, 0.02377900910834151, 0.07139527298990758, 0.062116484998935656, 0.05524447713527949, 0.026152715304746266, 0.035873449843136535, 0.017281890200871616, 0.013359065163850546, 0.029866577411491065, 0.12145705040424101, 0.05193162566771911, 0.04831165721219394, 0.04973323294712652, 0.041540405232339137, 0.04371910949327773, 0.0331076349492275, 0.057939256526409626, 0.04027395847163374, 0.03648140189808704, 0.030886479841184714, 0.027824721351686506, 0.016150920343915784, 0.11464916409984713, 0.031587463698440024, 0.036092505024205294, 0.026834389915870085, 0.011701760344177244, 0.035384394634034366, 0.06012968959346895, 0.02923790076296897, 0.04820135970329566, 0.017038787519859693, 0.05153414860908544, 0.06620237663868936, 0.10352485497752506, 0.01200621326138536, 0.0325876834141391, 0.041069927655400774, 0.06574569630526728, 0.0403700948452517, 0.0011981364960158847, 0.046701382530192216, 0.02455975612505309, 0.03527079911662206, 0.0189182348549366, 0.05151125407146831, 0.031493428320954406, 0.05538634129709775, 0.058436382471794085, 0.0782750566459952, 0.04225898804443498, 0.024919177766048142, 0.035391469456015096, 0.06712352841972344, 0.07869998263495584, 0.0502012437209487, 0.035800169702739484, 0.05171795608475805, 0.05534527132347707, 0.0167537568467519, 0.01787641848016891, 0.009904101513506425, 0.04498436115682126, 0.0025784604311470064, 0.07247932570716066, 0.040439356854485894, 0.03542248835606921, 0.026340477709327976, 0.06429529268174403, 0.028898956652189937, 0.04458029574203876, 0.0007840319777906483, 0.015053021545041234, 0.04408271397433935, 0.02896918393220873, 0.02689007876230584, 0.013480530319465025, 0.0671464650921764, 0.03345761838699541, 0.06872167976032342, 0.009612218183915942, 0.05089349992152664, 0.028572808124966202, 0.06930072731789082, 0.023746739569751006, 0.012355176844604075, 0.028945573102382403, 0.17623285793008345, 0.04965498855698013, 0.045597863518783165, 0.015572633128613235, 0.04142989704926168, 0.025657077485154715, 0.02125118134333001, 0.06376601402617751, 0.0182087512521614, 0.035168453600377805, 0.08541157168726768, 0.03446356460992848, 0.01286932526366605, 0.06779665157439248, 0.059849707439782164, 0.017269893263977383, 0.007692569427402511, 0.07536972948019544, 0.040310876248704816, 0.025992790620113095, 0.05681192367187431, 0.023062657527325135, 0.06222097939180751, 0.04277734611664088, 0.1216776837264338, 0.04436214071428103, 0.02592627503608744, 0.07954683920909321, 0.031109602949131402, 0.018891559673413154, 0.030460713070727168, 0.046685922875880234, 0.00037193942790186304, 0.015140164046428137, 0.018718247602303183, 0.014165772027486275, 0.04756142730794607, 0.023023939443632, 0.025442172585415746, 0.06426723854195687, 0.047514868314347924, 0.03776111730164097, 0.04685134424137012, 0.00981043002778484, 0.05965045180111643, 0.08309467665610776, 0.04474215096824112, 0.06192831082209464, 0.012701636277920297, 0.014347702587744402, 0.12277368741530566, 0.02549285504726633, 0.024716024655067635, 0.05064877313411525, 0.030799858279586322, 0.029197928210299824, 0.044143204276840535, 0.017708536057222276, 0.044199806683126, 0.05715804602650385, 0.15539937262092868, 0.1854992889228367, 0.28322960039780987, 0.17201033450903433, 0.19793108796640752, 0.14621851364931754, 0.07623887155205011, 0.10617007231039387, 0.1590550369432857, 0.13295157151597162, 0.13791099491138614, 0.14241833450092425, 0.16013802479832404, 0.15509765655283006, 0.19897184905505952, 0.14136467249162737, 0.12440976010815752, 0.105379645772759, 0.12892775598072237, 0.1981137999363484, 0.1635797514069465, 0.15388794243335724, 0.14682390697060094, 0.08022494193527006, 0.1649401243776083, 0.08060652266947493, 0.1685852932954027, 0.13642104582921152, 0.17590576902993266, 0.10394407361144982, 0.17344530912176256, 0.13289308836383204, 0.13780748111105737, 0.21268221820073746, 0.1015653782674382, 0.11326320379251435, 0.09455987958297615, 0.14058373778337432, 0.2656285158328472, 0.11722863576705418, 0.20800428615222055, 0.1694868715299714, 0.12523649155252403, 0.09319503265883654, 0.12511322034462807, 0.17281616707482647, 0.14223295654500687, 0.143582328493076, 0.09573957837757566, 0.12519343741117947, 0.12877542705785844, 0.12711098612917046, 0.11428717223386611, 0.14576298244778188, 0.07172747169651332, 0.16636693249306372, 0.12067470609420732, 0.1906903160195197, 0.14549347271602, 0.17941920146826776, 0.09879611597786989, 0.11794755565783671, 0.1322266378349835, 0.21028644675689362, 0.1370184718360824, 0.18652189372768327, 0.10041531175374986, 0.11762816594132494, 0.08711337472402281, 0.1290706313786007, 0.1145531962655725, 0.16041208509235613, 0.13269911490140424, 0.08494592812513152, 0.16849601340870704, 0.1617045826729267, 0.14258463686752704, 0.13242396676251966, 0.15030258966069068, 0.14479233372596004, 0.12498241083155717, 0.17417474739974545, 0.1773360398628058, 0.14559876384033313, 0.14315714969510032, 0.10287647646281028, 0.17809800623405367, 0.12475483675277042, 0.09399218544844659, 0.1461952398981779, 0.09029528261312554, 0.1752412183991363, 0.2025497248095851, 0.14711031660197244, 0.09305493049924413, 0.18656566799167665, 0.11107835167598341, 0.14844683359467215, 0.08632365298727829, 0.1254658199726574, 0.11042602780845859, 0.1279698243184436, 0.11828754547863238, 0.14214286460511147, 0.18617998868707689, 0.16350018551513074, 0.15872206448787646, 0.21014023121566544, 0.17329915486756833, 0.2638589446583102, 0.28605113286645184, 0.15506658402662124, 0.1992360114931099, 0.11599639866260752, 0.08896009861341408, 0.08548637251219443, 0.18184279722552146, 0.16738682534665833, 0.3138342920330263, 0.11042769788013351, 0.17576566687034023, 0.12548109576586755, 0.10579010036082999, 0.17563232160623998, 0.1069232669749087, 0.16998493593306313, 0.1326045183645141, 0.08523995267047037, 0.26922027310056074, 0.18188582072334905, 0.23389963613402462, 0.1391203259868968, 0.08287874711377007, 0.1508105672415226, 0.21367025711844045, 0.07937148934410465, 0.15131529660955553, 0.09136107945514303, 0.15207081252048094, 0.13220466643331513, 0.2347790744275816, 0.11178109178980512, 0.0889700194520335, 0.1664117639583926, 0.17400556454254737, 0.15162412197359149, 0.18095605045316682, 0.08010769983933819, 0.10300032223664946, 0.1820468677267913, 0.1484960777264449, 0.13798486110904526, 0.07289491308432433, 0.09716103153844034, 0.17689727066505342, 0.140626163732621, 0.10842684476125626, 0.11195198302307438, 0.15762190094157574, 0.10522160949485918, 0.08203531495265423, 0.21133120682451034, 0.19120270626679545, 0.16058298398650464, 0.13267430897441604, 0.1560736372466049, 0.18822260891958592, 0.09876030902828901, 0.1560660836196715, 0.34291180271294813, 0.1513341883377683, 0.12086945330543865, 0.07902573854211839, 0.12035959114831303, 0.1369960101381425, 0.12865916555446963], [0.005355684289468392, 0.03201848200161851, 0.028383479070579334, 0.005054057757895921, 0.06256001160269783, 0.04226146250843041, 0.058787518871888045, 0.043911799758432374, 0.020818707473095388, 0.06333331224478542, 0.027991069683564768, 0.046078916939516226, 0.025060890625501354, 0.05793968553564722, 0.034900437740068284, 0.017198578139106115, 0.020200899696999022, 0.013561237682287973, 0.014552543007378137, 0.07644760752877883, 0.038348813991873495, 0.023767335843595288, 0.04912693181165284, 0.0843835736234342, 0.05330596442124056, 0.04857408063065621, 0.04969681695764584, 0.030657840900183208, 0.043276122981502164, 0.05993511475202057, 0.016421904794931892, 0.058734670296431556, 0.045530509068480426, 0.04484902789455749, 0.02390181108738386, 0.08073594556340287, 0.029808038717976985, 0.020823198663551482, 0.06789800500677479, 0.023375939607860583, 0.027052274897634506, 0.022487336987509363, 0.05213306465696904, 0.017542136014409123, 0.04598651524452914, 0.10982473305757008, 0.03616491948524791, 0.02684948950885765, 0.011539590064316027, 0.04498226590634835, 0.05482394083012497, 0.048668884011285926, 0.030494880592150074, 0.054643584580551234, 0.038077009826778405, 0.013089361994887793, 0.060606506547980735, 0.0815441913061565, 0.04256371483807603, 0.02759889012292749, 0.006255843824962335, 0.07439131262682139, 0.0737982533211189, 0.059421598355496125, 0.04107341335545625, 0.031244702554578264, 0.02896271431968818, 0.07378257916218812, 0.030757859424357454, 0.04416470836487509, 0.07137148595985866, 0.030908434005874782, 0.04287180475770466, 0.020762987983142658, 0.08057070039813558, 0.011172647355124356, 0.029379109919611967, 0.03761184123915531, 0.027063471272647865, 0.043511537970193935, 0.05242584813987056, 0.04352825017826211, 0.030293705903234023, 0.07036880710192266, 0.0460379274051276, 0.035380705920678955, 0.057957895445607366, 0.06689776996931722, 0.027715352724396417, 0.017667435440084627, 0.06007419035379445, 0.057554783810290604, 0.018953413612419562, 0.049152228034912586, 0.04473092011927117, 0.07557131019571135, 0.029212259800143303, 0.03320690079201614, 0.12012616415778476, 0.04915313584910286, 0.010785734648966502, 0.023289940492700667, 0.04447028934655171, 0.08478132647372062, 0.08034964572758445, 0.043267998619065176, 0.035711088998904156, 0.02360659527532276, 0.013500095247441243, 0.04742315609849269, 0.041818533453249165, 0.018028620998525334, 0.02165337367313764, 0.016480274949102633, 0.0437518022954464, 0.02576421488136534, 0.06960131723674075, 0.03332944804682367, 0.05409033503383399, 0.05287116355893593, 0.039262201471795, 0.035432642851505554, 0.08083123924030412, 0.03368474430434647, 0.03672151683619426, 0.04954217444925059, 0.0277790108004645, 0.016311364053117654, 0.04570396669629601, 0.04654500866308809, 0.04277897788391959, 0.007100178533413958, 0.028842856033494877, 0.03260758254797228, 0.04325704739218758, 0.05621099281274984, 0.03909638940146373, 0.02916683270145328, 0.023755181858676578, 0.013440591283142568, 0.12263693305994235, 0.06982060990506603, 0.02436846780079988, 0.038087413300790136, 0.027592056618642904, 0.03413555257382893, 0.03924386132688772, 0.04233032232150436, 0.06939189178088019, 0.019334364239306703, 0.06830927930892476, 0.0438195436201509, 0.03525176183170369, 0.03540130602496286, 0.0064997236064124496, 0.07078939703323188, 0.03528046331578686, 0.017274430419708935, 0.058137474115937955, 0.05073896466544078, 0.04059032597128422, 0.07110909318491336, 0.02296636027524308, 0.0097586281199549, 0.07451914205786682, 0.0522246542987564, 0.042071568464199384, 0.03766361346107818, 0.03505349444646028, 0.06611036947898327, 0.014398906946993403, 0.024705508183087074, 0.018116987325371276, 0.045932601806857896, 0.054848934448654615, 0.02323346066048309, 0.04335766154972296, 0.07723187471950248, 0.05346661305896217, 0.04067600141429613, 0.04434035317371449, 0.07535213244057472, 0.011205338242073214, 0.02582203919789003, 0.05111436690053633, 0.01886376791874007, 0.06667479241807615, 0.028646925216420527, 0.010769058830074726, 0.08575347672787406, 0.0768539635464549, 0.024972553026952574, 0.036330248920186874, 0.10400751335245949, 0.018859820650710214, 0.05915282789858119, 0.02847062348718605, 0.011447011211496449, 0.07373824565401, 0.06145977144760471, 0.014312982525406106, 0.007758394574686404, 0.02633171557869402, 0.04058472969899735, 0.03201870225189674, 0.047604623175556623, 0.048161492487716104, 0.06071695344402425, 0.045849615332460215, 0.01436148833994183, 0.05583615748271827, 0.06597582145684189, 0.019975809658306743, 0.03756869899769945, 0.011907129364478733, 0.027484905815893607, 0.016290626053007382, 0.013101402024227767, 0.07459182848012255, 0.012527209548880498, 0.02343447447093504, 0.019689426840012594, 0.05666138356431358, 0.054861578729844866, 0.02772623691858063, 0.022461251693687612, 0.014630013648721, 0.09688225214279468, 0.036897092697120486, 0.013775618769408715, 0.03666478419496167, 0.033607798433231736, 0.06500052258131966, 0.06484507568060391, 0.07725348605984643, 0.10687501109655827, 0.013774670735602419, 0.014945421623246325, 0.02323168908215819, 0.04744734915514146, 0.05482315175956296, 0.03320529200737515, 0.022156519154387138, 0.07286848305093666, 0.022150392366212704, 0.030528990656978665, 0.07772767916321754, 0.035729088234685125, 0.04924804265160234, 0.01592763348467528, 0.03946068336165721, 0.08538005483006278, 0.08482303230031844, 0.03470398598320542, 0.020786026162245584, 0.06730195795816761, 0.04762323911211664, 0.042986093584688446, 0.01491442091778041, 0.074184637426609, 0.03570601366640579, 0.03886732528166425, 0.025751250758466702, 0.04172286822370464, 0.007935792288457555, 0.0460863939576572, 0.051795242864999085, 0.05960429117323891, 0.044169971388914896, 0.029362642859679558, 0.04224613691950518, 0.06364261258333441, 0.08185149215522312, 0.07595289859079546, 0.06710339562907335, 0.08176745997080881, 0.022532273789927847, 0.03584824938086733, 0.09134968006682974, 0.019717643773483656, 0.09269424864361364, 0.027332098088077, 0.08685403863989538, 0.08343350202325853, 0.030505527299077764, 0.05746848400562041, 0.07565932603733194, 0.0012190165814958635, 0.023633385370034846, 0.028838223116772792, 0.024966734589167663, 0.03865357908991076, 0.06398889964686767, 0.08395399748077316, 0.10135581491575127, 0.018853071416097305, 0.05288754634919667, 0.03329721489740956, 0.03776750264448985, 0.028904307776341037, 0.009017799072147859, 0.1089046384778715, 0.022259067683931322, 0.04137620960752811, 0.04082636532163428, 0.03763212341695063, 0.019060215845163313, 0.00586663285503164, 0.03259665813417204, 0.0012650036425780385, 0.020433194792619156, 0.01729468578442691, 0.014563758534589603, 0.02398508484475315, 0.04877919684194269, 0.044539735216887734, 0.06609115599384231, 0.07139782406269543, 0.04936714634119023, 0.01267968594366985, 0.07911082026698897, 0.024995866997708237, 0.04251904042077161, 0.047519246506835186, 0.09531064574877102, 0.04233230265878862, 0.09195128891376719, 0.031035861240759976, 0.050051925523627194, 0.014264134844134172, 0.026504029820282615, 0.06053547870608107, 0.05686259655762584, 0.0290556580218817, 0.031973301966284076, 0.041817660113015485, 0.049506248756041454, 0.01469767070375383, 0.055634174571042104, 0.022730949116990935, 0.12294608784178573, 0.03515156519208704, 0.04901864145311618, 0.041300979773363763, 0.07895825385686853, 0.05026604326802397, 0.009087752475733719, 0.032411073334515095, 0.03490859274602225, 0.027250800837552356, 0.0240539810470035, 0.02305397966636285, 0.13298828244930314, 0.26833617699242407, 0.10335271502093923, 0.18340733262800402, 0.11347387797169148, 0.22064847541191887, 0.16204132428092344, 0.13342415583470177, 0.13474217946490935, 0.20270925495893727, 0.11916971104519984, 0.1079940970145887, 0.1997969104277511, 0.15511653295928432, 0.14826694082829261, 0.07291353668176359, 0.10417989845718108, 0.1505652505664095, 0.15435853492348425, 0.14788383557911844, 0.12834524570573724, 0.0701197749003768, 0.11395200110611417, 0.14351433052891685, 0.13427716409487112, 0.1330387063564793, 0.09018324991507877, 0.11201895442941498, 0.18365355328686778, 0.12328563333158532, 0.20269172686722972, 0.1087663979119351, 0.2622742458216606, 0.1115777720547011, 0.09998415746996481, 0.18884680203853116, 0.12842181619376908, 0.07618296245533614, 0.15463886181673697, 0.10272342741729752, 0.11221956221326707, 0.11606589815909825, 0.2059256138219949, 0.089107379016857, 0.0977272394623968, 0.18861601039046244, 0.12386833512855154, 0.12007548744159362, 0.12844563386733496, 0.12490342716656386, 0.13659957495908584, 0.1185209648082814, 0.18574140335042633, 0.08917218239437188, 0.10287076910777439, 0.16424696802371935, 0.15861570084046933, 0.13603714384859608, 0.14643801316138239, 0.18858498382952907, 0.12425543169581121, 0.12906840972362027, 0.15005362640705802, 0.1707234446920695, 0.17532892014470794, 0.12899846589613345, 0.17888451806239544, 0.16463367388613764, 0.2749572910608784, 0.14874226774179167, 0.19186194024739728, 0.23588101529786665, 0.11669462651855524, 0.11725628388024147, 0.10250292433005187, 0.13639665358970243, 0.14404245622215733, 0.12315525282775203, 0.11110343339462435, 0.1039089561410008, 0.15264225282496022, 0.11284970783538396, 0.13078037108625137, 0.18251773600857105, 0.15908522080750237, 0.13030083068916876, 0.10093558504576645, 0.18024571840801548, 0.13464997312234295, 0.0961948567700963, 0.1603990462758849, 0.23961930986373658, 0.09911377433567278, 0.17728316447427198, 0.11982362837560716, 0.15309960731575567, 0.1421972415259769, 0.10752038654660988, 0.21693924622189617, 0.1357636044943525, 0.07043747156257592, 0.13504968715771554, 0.32898009544418705, 0.11309822675802055, 0.19450958607898605, 0.15055657845110665, 0.17583233184151112, 0.16550961881875992, 0.09533316107286562, 0.16169557347893715, 0.2229803704446362, 0.11713848254012486, 0.09116892162109576, 0.11308292798217266, 0.11742761178362755, 0.15186496469522678, 0.17257841934840526, 0.15412579741208784, 0.13197306273204665, 0.06747925368648383, 0.1132457982748747, 0.18549631650169052, 0.23142753168940547, 0.1244357611323076, 0.08572689347690152, 0.18053536093042744, 0.1809414947826055, 0.12981341490822454, 0.08261016434839658, 0.10137318212899471, 0.11133185783100706, 0.11844603374840752, 0.15123931600922538, 0.12230262761154484, 0.07537342968486971, 0.10398427790571606, 0.14028652631227048, 0.0884772870208948, 0.17421976272617617, 0.09380142955530076, 0.16330000674051626, 0.13568969233141792, 0.15491240117098057, 0.10040834035363891, 0.12692120316768848, 0.16069279502957098, 0.10896302969946016, 0.17224115680062002, 0.13284860929894832, 0.0943963810981762, 0.20821436278281674, 0.16270342343036207, 0.14835059762962405, 0.09190572200403099, 0.09678576336873156, 0.15498931639857833, 0.12445740311616853, 0.0714493281538448, 0.27008907809372873, 0.1512183405218586, 0.137937746701702, 0.20108589932562845, 0.1960931051402323, 0.10234612145371015, 0.24251962681451153, 0.09029216463527373, 0.1740542724127731, 0.08312645398320691, 0.1523193620866345, 0.14375282902150385, 0.02622110205852697, 0.17380230609447728, 0.12246245653518747, 0.15366496488211617, 0.0879611122992731, 0.130315478290281], [0.029670409107160185, 0.0903356324640974, 0.04046114822549205, 0.04108031963809364, 0.03462200691442817, 0.08797936051362946, 0.02843142851376005, 0.022347730869847923, 0.016044187059085217, 0.03430597266302474, 0.0788704831633837, 0.07435096277584953, 0.01882208890521959, 0.05176214786667017, 0.06201818442693161, 0.07174949672433638, 0.015246328510974926, 0.04289128254317949, 0.05951712185877466, 0.11928710635871657, 0.03163814807551042, 0.05397847087513055, 0.05020809637743139, 0.04424039402135438, 0.008196378532316416, 0.03391075939420731, 0.025950967965106812, 0.04520015280333258, 0.03855271595379999, 0.06931512210998805, 0.011182968474684224, 0.03947486364913564, 0.019705734936700716, 0.042120517652121284, 0.03280049497862497, 0.06737444519756303, 0.08951308385979745, 0.07146357738923642, 0.037270254125037504, 0.04119779539084242, 0.014032404738358192, 0.00995702095209591, 0.00907247189447404, 0.021898774617922404, 0.09150363309609313, 0.04901634318934334, 0.01873781731832893, 0.028478753595282475, 0.05969768878252757, 0.03395504693710997, 0.057233306504185164, 0.005724853920494957, 0.015274294550650784, 0.05437287592118787, 0.02944199807731615, 0.03535312675540486, 0.017723143438718492, 0.07367413941650622, 0.023710662574176828, 0.05071672513299892, 0.048816371258468404, 0.037023646591772, 0.01661237915076556, 0.022160234680819898, 0.016846091509045615, 0.01803270999282118, 0.05585551652456484, 0.037991644649375836, 0.012291388533588861, 0.009080511987239364, 0.05830450426606883, 0.03590119371731435, 0.029801764457877127, 0.028543474618345503, 0.004524081483513358, 0.013495352205580041, 0.015425111407474166, 0.01988266102759348, 0.007653085255785095, 0.03258333969560843, 0.07617093487492493, 0.044970724791769064, 0.034205404470764825, 0.018645921241371863, 0.03576880606311945, 0.041459483364897395, 0.07044307932618164, 0.021000258819830996, 0.06791365618306784, 0.02509313718145413, 0.0337035785759649, 0.032421220169072194, 0.018353794678865422, 0.07082649101052554, 0.026826880338992325, 0.06309544577473594, 0.02128479536622763, 0.02502807141882518, 0.03286544391284547, 0.0725743665750469, 0.046044672809300885, 0.052588921445872516, 0.06235595642318649, 0.03401431915981155, 0.06513361503640491, 0.12238253824292653, 0.037486773555076895, 0.06977467527312618, 0.04213162592702335, 0.06694471583731713, 0.013416381947125399, 0.06089714881513388, 0.0066255276925080734, 0.017480622984529022, 0.049281976516208345, 0.029315323523816564, 0.005968079654379718, 0.0291973153399604, 0.033573335967957973, 0.021776053078112104, 0.020579119220436103, 0.033434754492895256, 0.05630309190300684, 0.04263552792009808, 0.05824111432077424, 0.04190962130744611, 0.0732236260908746, 0.020077729995753017, 0.04257618674948331, 0.06520190411397526, 0.028547098214227348, 0.0339039565334397, 0.022984100956349604, 0.07714711475156008, 0.06338651322068707, 0.086975279714792, 0.006394909850637159, 0.03806776314553234, 0.03453263509718161, 0.06363494404321236, 0.039271831197003206, 0.024459113239220554, 0.05473619311927788, 0.031963549667007984, 0.05628852857156627, 0.017608615209258372, 0.09553703239127513, 0.02013096927605089, 0.053980535482086485, 0.039019091129903836, 0.04978711191084116, 0.03647365674917256, 0.01779609224608829, 0.035056214058591474, 0.014255421551605387, 0.01669574483868576, 0.08232422203065888, 0.03656761743308556, 0.06916575794739109, 0.023201493726622675, 0.017272381134511485, 0.021148590678949992, 0.023271500756363236, 0.03301009663470811, 0.07985557264257824, 0.006245736731216312, 0.04633482861062212, 0.02959722089731405, 0.04864341924868284, 0.028128825698889075, 0.028010398081894365, 0.060399249120945894, 0.0431168609629235, 0.027291301990889257, 0.034663505897286444, 0.04892619379285363, 0.04501313541925723, 0.09255324250027057, 0.03730889943037783, 0.04972524265007627, 0.007568072957632644, 0.02370949237487249, 0.02614068197867563, 0.007213028551514952, 0.05490737163551873, 0.02758507372721309, 0.02126688040011833, 0.01611348545749582, 0.0374948634435573, 0.035174406103549466, 0.009716593833159535, 0.07988070798737389, 0.06868343665114335, 0.05532149578474703, 0.02492387388502398, 0.053948045693217754, 0.024424415201910084, 0.04440748162807957, 0.06540883212320267, 0.05487436856774073, 0.023323857120328376, 0.02677303010357484, 0.02232349759358312, 0.039472385354700594, 0.04290112294256688, 0.021915716652367866, 0.021022977157225533, 0.042341204600468765, 0.03068797688390459, 0.017555634483634945, 0.012636239182264095, 0.05335810053492746, 0.07514790106084078, 0.09581131485080528, 0.05120961461216212, 0.01438916135098665, 0.06479342603274892, 0.017228265961391792, 0.045489423773101265, 0.07351123848028722, 0.018722995432213913, 0.032426153775304556, 0.07610317439802232, 0.049479182869676626, 0.026342000309077483, 0.02820641316864039, 0.029118551925245314, 0.024530175555076812, 0.051936723982855204, 0.13282720480234395, 0.004982650223668786, 0.007602767643308448, 0.045974024180923743, 0.021404477452198346, 0.08138436238251387, 0.03975438231962823, 0.06401447166178016, 0.03163886628293943, 0.07180688437074423, 0.06634357430401348, 0.01283160500949429, 0.005630365114719157, 0.03630012634300417, 0.059007669558688525, 0.08691882669565179, 0.019067131703899756, 0.01317821957561518, 0.05622362943306085, 0.02612322475010109, 0.01314048687251465, 0.02349873201080388, 0.05425207151640808, 0.013707479078983589, 0.02635531491720148, 0.03606162785041717, 0.051447622808477575, 0.007613114139530809, 0.06018344598311571, 0.050641196524544116, 0.007396232254142243, 0.06360730359090433, 0.02225146234606303, 0.07661348854702327, 0.03631775402614186, 0.04779406905835194, 0.07225107747100054, 0.022420957384090272, 0.03563497816362689, 0.020276627488314145, 0.07825717615384249, 0.015337000762472953, 0.07264031908444821, 0.03984852686464306, 0.05040925957502858, 0.011516295245758468, 0.027341141756023132, 0.043194768274383205, 0.03396405230065988, 0.025253948612859654, 0.03494303988953752, 0.07681364433900004, 0.08291183445121973, 0.04862473053377002, 0.08336298362982851, 0.08268752390699041, 0.004465492515479245, 0.027496056225631508, 0.059835473526149034, 0.05190998751429781, 0.04376016797557954, 0.045377896693084514, 0.049247334020272385, 0.026360053171013153, 0.019454061647035906, 0.07484436936436162, 0.062382263882506284, 0.04661229033503802, 0.031955333374020074, 0.03222157382556508, 0.009865238830717582, 0.025009784900072603, 0.07385167263207898, 0.030461594071840088, 0.008766289533776863, 0.03150152012465462, 0.07737327922856616, 0.03390351986332286, 0.01522779301364696, 0.07425662670885363, 0.04095792560087096, 0.04573094831298917, 0.04780768244076641, 0.05294166280016784, 0.04403775610450295, 0.05632398312070197, 0.0713433398895206, 0.06656699618625064, 0.013872747226888615, 0.06317770829604519, 0.047546630319688594, 0.02898546713103931, 0.01878050565268965, 0.004979034767471134, 0.10725980173916587, 0.04236745460319423, 0.020643292490633267, 0.027900263366679993, 0.056475419551134116, 0.01997449007185717, 0.03160792590689755, 0.014187793224869717, 0.06615822699161307, 0.034967037593765606, 0.02283667116576145, 0.047045003607748985, 0.040106376738197384, 0.03953380645402978, 0.05076876165525568, 0.02320002475302787, 0.013474998207041814, 0.019361357347318725, 0.031017940528991244, 0.0642676369076775, 0.01819194902876212, 0.04319853742697066, 0.00971361470874399, 0.01670478850663189, 0.06469732030264794, 0.019824250653806715, 0.06824820677960111, 0.061812708154320724, 0.06298711711180306, 0.12331935652201215, 0.21582621239846755, 0.16828489489853385, 0.2327085685946288, 0.167462223720166, 0.14592979043241472, 0.10570838942282623, 0.09462837550428607, 0.21747924627796297, 0.13213787888807635, 0.11455823712411428, 0.15456986793827626, 0.10865726868712133, 0.14308438666405218, 0.14620398862227318, 0.2689786796127596, 0.17379646850449426, 0.17483315400538907, 0.20967739153533213, 0.27917212295916777, 0.12524165498513368, 0.18969242521111043, 0.09720338853977381, 0.09009488167301302, 0.19963267649854385, 0.10277789626871386, 0.11766868433164013, 0.08489158950866231, 0.17133401676772103, 0.11661518320080735, 0.1356513879352039, 0.1618822691060843, 0.17435330717313677, 0.16442074740846313, 0.1697562740094239, 0.1837702131559772, 0.1928287891731147, 0.21517249425092053, 0.21092743252313909, 0.10468980657958216, 0.0902830328672163, 0.07223055397550907, 0.13475259826067956, 0.14522615399572159, 0.12194270418295938, 0.1321171791923623, 0.11457117634915537, 0.12125117959634912, 0.12027870758526749, 0.11415403381350542, 0.11713728744296298, 0.10135204576316381, 0.09061288734477374, 0.2657747160523169, 0.17334567172633064, 0.12277578649621819, 0.13616652077724858, 0.17886141285059914, 0.09447398580490582, 0.12638745438908378, 0.12694928795099258, 0.14191907500067066, 0.2075675241048298, 0.11869617677744358, 0.07775252339460197, 0.09066044608311308, 0.153064122123103, 0.1479077222005975, 0.15269845303508545, 0.13335421200721495, 0.1282631670455298, 0.13555453909981635, 0.14226669505719217, 0.10914705167975157, 0.11047658961146109, 0.14599981086869396, 0.14350742041583986, 0.1091290715961687, 0.14428804868892317, 0.12441576623748388, 0.12948068760095105, 0.2333460150346641, 0.12004725710158387, 0.09274675630994382, 0.11530799971472834, 0.15871428103456575, 0.13727310414035476, 0.06928053324020679, 0.19273022430077677, 0.10601341499075775, 0.10456629788442966, 0.12995478877377126, 0.09012240721213241, 0.1837584920107357, 0.11056350994734995, 0.17863313397092206, 0.1293419184343469, 0.10564348645388119, 0.12786817211177082, 0.18785070387586472, 0.14398293119044075, 0.2836150345542739, 0.1308678430054457, 0.16895588066789413, 0.23872436595059213, 0.2014127124341265, 0.13154060609879034, 0.28700616871637685, 0.1881446058471357, 0.1365136811810155, 0.07518507930780612, 0.23413444208281659, 0.14132912601194075, 0.11060852527378068, 0.09882623089417335, 0.11593234605125843, 0.09473965743616705, 0.10112063358387641, 0.10420089692718561, 0.15931471010609982, 0.1340963826664994, 0.1375830020274847, 0.0949691084303683, 0.11074154878095274, 0.09696691251930692, 0.14221005051607086, 0.13293643361858784, 0.08271113473681674, 0.12864031979153234, 0.15829958231939426, 0.10397762060165407, 0.13359802714999647, 0.20066985229571022, 0.19290136834306104, 0.08474198785880882, 0.14989049564446175, 0.15475446448451088, 0.18453421732110364, 0.14774328908852993, 0.2809918882145036, 0.10860493722101373, 0.14794458635151386, 0.16209516494024187, 0.12561978066280005, 0.12498577395754477, 0.13300512106187884, 0.13224297082952916, 0.2007731515914202, 0.10678442886039134, 0.0870406040320954, 0.201393008652714, 0.14015422292774724, 0.11084677095735267, 0.15625615003368548, 0.10017526576355582, 0.1089868397121468, 0.24414402432739737, 0.15297508738454313, 0.17664302140474322, 0.10865553732841246, 0.14107423323777415, 0.175753164315416, 0.13232973794783318, 0.10966540975195747, 0.10456981422800211, 0.0865372229788092, 0.1984881564614273, 0.13702027980358372, 0.14433376881624424, 0.12567844767604144, 0.1549932694122676, 0.17006166729955904, 0.18666725125043623, 0.14758401940907204, 0.14569665455529768, 0.17634847591961586], [0.04640473413371271, 0.014040273418950458, 0.03228097628321379, 0.03959758327372613, 0.023018075040571635, 0.019585028208131273, 0.03433108885562228, 0.010137764076071401, 0.02959276035037493, 0.04242886038076493, 0.07555513041875056, 0.07909613436148052, 0.03423404466781405, 0.03235689176607036, 0.012944923777643953, 0.06424576126699967, 0.017549245310346448, 0.08920084174361922, 0.00978424610014284, 0.021595156736551754, 0.06399240449912126, 0.05940189074364401, 0.07176320203730176, 0.006351827459800388, 0.0019383411821646377, 0.016054670972328995, 0.020825604179633722, 0.0494737015105784, 0.043768690703737165, 0.046327857210511164, 0.04411281356888433, 0.05909946604421543, 0.025195927028694463, 0.08859792288633124, 0.02841979738384966, 0.03321409435762513, 0.044052001509454944, 0.07570142256877116, 0.04728143366294042, 0.038525745828425696, 0.055628133967759154, 0.10918796843578739, 0.08449341531001753, 0.08950826516675373, 0.021008044188361497, 0.03426436259741745, 0.04181749157367214, 0.018313898734988707, 0.0053125401327927275, 0.0242304838743181, 0.011768300826060436, 0.033510041783653924, 0.03449393616568658, 0.019185256716164372, 0.035394357607489636, 0.02260392790870561, 0.025140895102653774, 0.04471028171059105, 0.034195081435985146, 0.03619356734317638, 0.01162204698043605, 0.023221819954473647, 0.0289330264974025, 0.053455929962858084, 0.02745967854054705, 0.04331480659123871, 0.030820548399201328, 0.006108844958831587, 0.05680208710292655, 0.016057577318391733, 0.05409845173539174, 0.03413457581172547, 0.03954228704735156, 0.02191460582487766, 0.05954118851091593, 0.02496806758215591, 0.024823811310794086, 0.07555064880439351, 0.05785394497516175, 0.027817261570523825, 0.07698704067978167, 0.03778051847832338, 0.05232950875295266, 0.10901560631370354, 0.05319444117166343, 0.0650328514917243, 0.0596864196291614, 0.026276746854907083, 0.03966003093087385, 0.01875912988438241, 0.040642052227931644, 0.04764414182113064, 0.030248284550203435, 0.013278051365857885, 0.013563231426110912, 0.0419974226444479, 0.02731562528248516, 0.08042132091378013, 0.03219617418043556, 0.07694977816314467, 0.015559926602779137, 0.05783971872240786, 0.005449734509907543, 0.030599742707225586, 0.04615306658970733, 0.05409648288942633, 0.021444135908818534, 0.022126385085885564, 0.026626144235412923, 0.052423438793348695, 0.02736836852085206, 0.03974701255379666, 0.015724255335367015, 0.06283639697358012, 0.037337175735663024, 0.056528662661871606, 0.035492416861797535, 0.02711429163032482, 0.052042110868158846, 0.01881266602375094, 0.028078336674239368, 0.03032473246416738, 0.04144166415977863, 0.029846906188815355, 0.004202624287215933, 0.08929870947594605, 0.037605597622572415, 0.015777675603937, 0.01853403218481089, 0.04178800484946659, 0.00656990061191121, 0.041656115152422464, 0.015290788423660544, 0.04030406189661834, 0.036556237196970376, 0.0285270803367659, 0.028825640122616486, 0.03093584846224516, 0.04021264462461395, 0.025653695206969016, 0.025859849467392892, 0.05305214800060757, 0.013881527552110775, 0.027507549459715525, 0.023139132254366434, 0.012587639521957647, 0.02630418812435481, 0.020148225406545307, 0.00976125197109556, 0.0154825143756405, 0.07351611846036489, 0.10299068485056201, 0.015010857980908647, 0.013900372357438169, 0.03520016964044302, 0.01696683654201127, 0.025119808532537955, 0.08583495017862128, 0.06842528800329856, 0.03936563866333135, 0.15486799871488927, 0.03211783785973826, 0.06548085970984352, 0.10566353497485961, 0.018412576605295463, 0.044255872827864466, 0.012647241162466667, 0.028891010405195337, 0.056701392506159125, 0.0512086455109379, 0.03656132402078759, 0.041700870008958925, 0.014861592452131934, 0.03248031236111157, 0.04960288308681019, 0.05352755918377831, 0.022861042337852622, 0.055978546414764664, 0.05686443516864412, 0.044792421657832406, 0.05684933940609617, 0.04365904436957452, 0.009161784339906468, 0.03392832579031106, 0.03557456063947851, 0.03638431940588259, 0.10302862918545162, 0.014462809213587354, 0.02341198595991779, 0.03087133428292169, 0.01944445681968524, 0.03327758006391025, 0.043614561474251176, 0.03211911148091238, 0.007220022934263633, 0.033676803803011295, 0.037825610413546526, 0.04694955288282326, 0.021031494139723723, 0.03189222305081785, 0.04506088951001725, 0.034100446594698776, 0.07969683922466733, 0.011593234413603862, 0.007471842738243962, 0.0404379625744637, 0.01563937279335674, 0.032201487000190446, 0.023015016434533943, 0.019486461420573538, 0.06407749771531071, 0.029119241404377168, 0.01669609723913093, 0.04809590770051845, 0.017984923343324376, 0.028645230246888056, 0.011848538002419856, 0.08299182169139385, 0.03393798615903624, 0.04202056233020079, 0.024159720332752314, 0.11146002434073918, 0.012519696141563117, 0.020101306351622748, 0.036877005871745853, 0.022751581780011618, 0.02695139069410582, 0.053281434285905094, 0.03419008654271884, 0.02225824222419291, 0.026075696655278726, 0.023066677573707797, 0.05331868531122323, 0.028478590801598567, 0.02781704706590503, 0.026566059959511605, 0.02378656656571454, 0.022796480278033885, 0.05015635862946511, 0.03429675279485603, 0.05223682743587321, 0.005145219348055581, 0.009880883303741294, 0.04939075334057693, 0.013161071655040067, 0.01517132179991853, 0.09653344464999053, 0.02397536318899403, 0.005485394945172894, 0.029226202600365205, 0.04086664622469295, 0.055884980266132665, 0.07271520417904662, 0.07471720642981029, 0.040907903889855074, 0.03241944284508786, 0.03907541391409693, 0.034591133571079666, 0.026288408628334443, 0.05941567649584144, 0.02396596712060273, 0.025370390146910667, 0.03372281887418321, 0.02080589848300142, 0.03474635064541813, 0.04076307496776985, 0.03357956426278238, 0.012563886008255426, 0.020171037589710568, 0.05926122167898763, 0.050169799642096606, 0.005088520223169678, 0.05925856718433, 0.0596154569047353, 0.060889196822479855, 0.10877356083402712, 0.025520554871388504, 0.009192234419676806, 0.021479781979935306, 0.01622656961121867, 0.016998724951859445, 0.02591233989674478, 0.04237374035461296, 0.03350635690073814, 0.02304452614137723, 0.03591994371926112, 0.04754588338396242, 0.04721907027546437, 0.02047280153830446, 0.02354833428868123, 0.03268766554913694, 0.035481653326461395, 0.019072293221289595, 0.030938543176518816, 0.12224847285617745, 0.017244861341051517, 0.004759695655065439, 0.012047749591029942, 0.03096862936452512, 0.11008303492299973, 0.03167029695525285, 0.02356718388205815, 0.02174345220649435, 0.011495464357487377, 0.06566644450950046, 0.018108031757536436, 0.07794760768451998, 0.03494797349576989, 0.03402954515730662, 0.02069039349143784, 0.08774738142927808, 0.02774920423455056, 0.07075873053362293, 0.03533116684505536, 0.016693308679086548, 0.06031058210458967, 0.019837841053583452, 0.09658532412422281, 0.03120786904717886, 0.03384470346293623, 0.06527382444830672, 0.024720833772012306, 0.07270255606741675, 0.05596184569801535, 0.00462977959203624, 0.028124382388928247, 0.0978164197576623, 0.10022938221452699, 0.036033209818865986, 0.025324668104369796, 0.03363045548359233, 0.025415204375261263, 0.028851279170222344, 0.013189317316808289, 0.03695758683006129, 0.02138610857899391, 0.07619114427436745, 0.058336136036462365, 0.03733064866654816, 0.04160697444251949, 0.04223196429290599, 0.06119235313587612, 0.02615444857867495, 0.010454350868390213, 0.019449712182845802, 0.035470188820674535, 0.014413350577195807, 0.03768525161449948, 0.06373112638210578, 0.04362006581598713, 0.015025842660707573, 0.03969186954500695, 0.18059761323515447, 0.14633701212944525, 0.13282371144140923, 0.14967922391670366, 0.09688753048859297, 0.17017359274529642, 0.25184414259368376, 0.1183472543714508, 0.12435765080754796, 0.1147263321364599, 0.18609691411256793, 0.2803435633259435, 0.10527766414827879, 0.11033571370306516, 0.14798570995128926, 0.18927029544307342, 0.1946942745557716, 0.18021219440044897, 0.10457123915154128, 0.11524243791016842, 0.132700968834181, 0.10761626245033358, 0.11857035449675976, 0.0854776161272199, 0.09920976515258513, 0.20144217617569432, 0.22785253642547518, 0.2026591681304478, 0.14965274791804054, 0.2269428070153921, 0.14734334522678008, 0.13499071370930443, 0.12047504825938134, 0.19568937680413648, 0.1974615679993745, 0.16238243259008855, 0.09818057199158976, 0.14626919802638794, 0.19853507168591025, 0.11950533416482712, 0.22953927817363895, 0.15402522538938831, 0.19904758450725388, 0.09170946559958881, 0.11909850317263797, 0.25830229443888514, 0.14312547962031058, 0.13228213324421836, 0.1163153593698817, 0.08483582596865394, 0.15028795738133693, 0.1157689548187679, 0.09080004262467546, 0.08680225109621402, 0.12527103445702983, 0.11744258114166799, 0.11367517523467542, 0.1149934669956565, 0.10529274075862863, 0.10073523007092938, 0.11118279244270056, 0.16066809635489218, 0.22276687706189774, 0.21596113580369183, 0.18103313422010792, 0.0802155496973184, 0.09137471582019523, 0.12258009699683999, 0.07622684397163891, 0.08887050463066948, 0.13686943709129287, 0.12959065186160226, 0.130604017646082, 0.08230186758502837, 0.15699085899658743, 0.11711002237373784, 0.18643990699802676, 0.16360175345213185, 0.20023325878766277, 0.11101965401922503, 0.18183676045267813, 0.11261742997674212, 0.14180603106656384, 0.1535622171697117, 0.15820300927565945, 0.14178243555849598, 0.11944635305553676, 0.10018762276177445, 0.12103813054460673, 0.12269102652827579, 0.11523187355769259, 0.22091044683850583, 0.15174988296724137, 0.1905448665662158, 0.1177353646245695, 0.135886576927958, 0.17453663201341707, 0.16646869961292515, 0.12655113673498555, 0.2430779057284517, 0.08625279751516159, 0.1663744095112047, 0.2162230765867618, 0.07455330957928974, 0.14323473908007145, 0.12506773770456353, 0.12297693054161726, 0.12093932818501227, 0.12824565427558077, 0.20590094579083307, 0.1438786359804292, 0.17190671345639616, 0.0964483552642407, 0.13397737856834166, 0.15347917323871968, 0.250330398820581, 0.11449366357297668, 0.09772867970769444, 0.15032284502540866, 0.10650338184448982, 0.09783331199639267, 0.12635374652041545, 0.16249273392942645, 0.22737802156517584, 0.0721080182120204, 0.17967824643898397, 0.09484061250282873, 0.11914014771220185, 0.14766288049999746, 0.13294423239365702, 0.11036866314468846, 0.1384521134558224, 0.09313941467553379, 0.11646441709730895, 0.15040811061138107, 0.13901835968417509, 0.2063615944597029, 0.23528181196701145, 0.19287434076109242, 0.19320821720025233, 0.12715357295688123, 0.17120847027868996, 0.12934545776055706, 0.10252733189131945, 0.170772397710431, 0.2186863863420102, 0.14385128664153238, 0.2570531880783458, 0.11953472895848176, 0.08464322380361058, 0.2334232060539146, 0.2383947642820497, 0.08953803534349127, 0.1649763450146683, 0.16520508354709995, 0.10067873874739294, 0.07154979292423495, 0.20740345871496588, 0.16237621195614338, 0.06756330119265665, 0.2603380658453511, 0.12854881824985628, 0.190018686736303, 0.17899788375343048, 0.13576967191071282, 0.12551779903831983, 0.08334616033901131, 0.17038504833415632, 0.1524227379911369, 0.15802660987021463, 0.16741507866930577, 0.18971893185329056, 0.11379264715698459, 0.10230912706784664, 0.205085429873678, 0.16492852580643472], [0.03950515476566169, 0.0453869863263061, 0.019326508007643205, 0.03337029968538592, 0.08049354768328129, 0.035890594890881936, 0.03943719893633839, 0.06262848071093041, 0.04313977465273873, 0.05367372875973102, 0.010350204087913999, 0.060866815563772, 0.04971601895146793, 0.06105503953632809, 0.0284455762425017, 0.061824318216813196, 0.050803323711959586, 0.018308107110281146, 0.0054983308185793224, 0.04690687795500121, 0.06684542318145115, 0.0373212602590361, 0.08687182720149718, 0.009695184548505613, 0.03132425503985536, 0.035857787175524625, 0.04056981013667199, 0.03247635934742228, 0.020123988299840884, 0.04406292975369481, 0.06403714786433885, 0.022874703600762353, 0.010086825932376087, 0.053626713943817926, 0.02491813014081169, 0.03421465115201089, 0.02982998713700762, 0.028007067514643557, 0.040506906657209324, 0.037210353710238016, 0.04159613429839092, 0.03872936816825982, 0.04487088821347683, 0.03536200954488689, 0.06804804332674512, 0.05608166184937281, 0.01849228996903666, 0.028448431835239454, 0.0188180995023539, 0.02914714041135965, 0.032210358298353614, 0.08598798390237555, 0.027194757675451618, 0.012970455572940411, 0.033293445744822105, 0.0084137023546763, 0.01976234500386542, 0.03595622947379466, 0.07049349557247854, 0.09257883749782078, 0.015614374386777562, 0.09867696632300654, 0.05007818701767153, 0.05163234958965933, 0.00966798555436394, 0.02445980654879203, 0.040024853491735075, 0.02849458480223773, 0.02142606964034419, 0.05186080466955901, 0.036178456258869944, 0.03649958499496983, 0.020396125713183035, 0.03535392731728573, 0.049015584762298295, 0.027329970278867313, 0.049864850682957526, 0.048340986888375015, 0.07178606210096229, 0.05438100028362486, 0.02889385642183404, 0.038353448823815396, 0.0260385547974898, 0.06417536927807717, 0.03127809632719765, 0.07971312625393753, 0.04819453769032994, 0.009065013070921264, 0.0642643427296031, 0.08418173243802402, 0.01658832398994315, 0.03750785246431347, 0.0522550258545145, 0.04963714253878401, 0.0816853659888429, 0.08545285616550716, 0.06481800979423909, 0.07199937162259895, 0.04890650150276, 0.09485450167689594, 0.06295063217440922, 0.02665495297180549, 0.035694055033907775, 0.10663938543368733, 0.02909772582502375, 0.06261051977954565, 0.03571379328927687, 0.03247435985793991, 0.029034674873635657, 0.04960767879721619, 0.03258579500740574, 0.06871951939237696, 0.031952604185789824, 0.08982389339155729, 0.0355638200867801, 0.04609796571575346, 0.012528531050549881, 0.11884437648639565, 0.03560850216496376, 0.024900008330962835, 0.012935659859419591, 0.05382989195265597, 0.07588041901227928, 0.02231440412992191, 0.017776470819127657, 0.07699298552207409, 0.14285978500641164, 0.060163309362026, 0.006740285748345477, 0.028502634471102108, 0.02627498676790105, 0.06600406711861011, 0.023600583400336966, 0.05332309031678785, 0.027506704847779007, 0.056367255597104954, 0.007200926277531132, 0.03672987102500854, 0.04889453137894312, 0.06292332497034824, 0.036520242555848056, 0.0034678935386886402, 0.017689826274891535, 0.11207268017554477, 0.028498635492137367, 0.025848545840070136, 0.07064248435199261, 0.023461161143777352, 0.036025334435004386, 0.05594309569606858, 0.03327395646802841, 0.024055227855100267, 0.013659456857450068, 0.0467888429580677, 0.04155903649065764, 0.014692733267081842, 0.1066555958541651, 0.011211356820328342, 0.01540858210289791, 0.037690564434254364, 0.060418190644873734, 0.011027237163826583, 0.015987544433183728, 0.020514593549793767, 0.035240883383178906, 0.03193375842285252, 0.029242884164916414, 0.05881451581033969, 0.034973974519919966, 0.045681416898244814, 0.03882059774872276, 0.02042596866827338, 0.09119885267629739, 0.029764526839097662, 0.07518607522210768, 0.04670184601338641, 0.09695691507189505, 0.03209846732657283, 0.04243611523340787, 0.05789909819741884, 0.062347606064811836, 0.017136909976421345, 0.043732611792943174, 0.03644796982107144, 0.03562688061426725, 0.04362268966712779, 0.06014439848161513, 0.06108492462625427, 0.08415283560152016, 0.06899907253682613, 0.0391780122393562, 0.028008846753847697, 0.008513740988658562, 0.05123092334777598, 0.0635185982701519, 0.05887219457015876, 0.13592285885205194, 0.05895670938996538, 0.06155180542038814, 0.06588575249958424, 0.03300965230371202, 0.040691330833660985, 0.0849814516221804, 0.07946021764749482, 0.04042832901881587, 0.013077568071293495, 0.06264448045722901, 0.02802794724101982, 0.02933327679432208, 0.04862866822570082, 0.02510696123804777, 0.05358630663625175, 0.029114296306825937, 0.0591149065463293, 0.08785531555692996, 0.01713850535452366, 0.015017331423868817, 0.012123649752128028, 0.038430015481407606, 0.025230293732977686, 0.08887009860406961, 0.032516088667175466, 0.018468734680584842, 0.0259818738671921, 0.038911011445546345, 0.056762863401203394, 0.03995379117587882, 0.05878670298824868, 0.02386155699740254, 0.0320067570259374, 0.011776703852979888, 0.07048178974899554, 0.04372405842126858, 0.03259271661180162, 0.0648685562754831, 0.02820551493054917, 0.047715506741716984, 0.016081734943474014, 0.05181105108931661, 0.03151270883878873, 0.07172231592478291, 0.09628857230587352, 0.054957263111587495, 0.048279033357938456, 0.03617480968035037, 0.01933827320294034, 0.02499000067942806, 0.04623910592448327, 0.08924546636520855, 0.05300021106978098, 0.012690912004590276, 0.003054113650221318, 0.02693808183164126, 0.015612647816118215, 0.044210505100988576, 0.02697263814268574, 0.06375482148160377, 0.015269767928628192, 0.06839228493552055, 0.02761334237161904, 0.022740843142533017, 0.08011793477400657, 0.03452376379901844, 0.03868010105384934, 0.09866752811977941, 0.038208278992603865, 0.032508171148478024, 0.057186211249040025, 0.07624789606779814, 0.07692618265507684, 0.012040127973793256, 0.10336159397998165, 0.02724342724128116, 0.05223586216508862, 0.05351923180804138, 0.08476443423499024, 0.07818750045712917, 0.01536777834483092, 0.05432489200405056, 0.035033836630323244, 0.034985550108455846, 0.017504000157538443, 0.02283169925513287, 0.039300122824046886, 0.018116282524480935, 0.07401915477408517, 0.02440485506198339, 0.06863257607385036, 0.045571586702980345, 0.10720822103922406, 0.1413153517510622, 0.02469806946934231, 0.028676419601505323, 0.051876861872451926, 0.013335607551609077, 0.04670351991550096, 0.03937461721380392, 0.023535986866561637, 0.05555340209074559, 0.015928200389739248, 0.00307825930517978, 0.06047596899612297, 0.07867785035482339, 0.044411637655068795, 0.015212586168349992, 0.049774548068882964, 0.06811607193442122, 0.04926647472706053, 0.05876062152486655, 0.05633053700289419, 0.07706759482501976, 0.03663216034070619, 0.022920860398200252, 0.01708344086974619, 0.07027790310882753, 0.04996831468757122, 0.01822254275001826, 0.0291131261075216, 0.049393825353153294, 0.04037124780757774, 0.04102824481144067, 0.09389285448818438, 0.06531520851797636, 0.04054030042982871, 0.03905215548471578, 0.025095278397202495, 0.021930900515027104, 0.03327479916474512, 0.04073111761000849, 0.09697933846543874, 0.03388494223115906, 0.020237210349390106, 0.1002122218450231, 0.04368830126740279, 0.032434358576973604, 0.149250321931416, 0.016708731944222125, 0.045868353843088114, 0.07279578130692244, 0.07599442055629146, 0.06544135255558838, 0.0518493133506948, 0.06103439729720835, 0.06937503784654603, 0.028837767294457847, 0.035717045332515435, 0.0243546724725034, 0.042618290941801765, 0.03443905745723075, 0.02767502202562267, 0.05665715858941117, 0.08485409716564803, 0.17266440505702652, 0.1444995808865755, 0.11090300181099486, 0.15364803433898958, 0.32161713247337653, 0.24883974493751604, 0.11937508389594094, 0.1129609974281442, 0.2102167174340256, 0.1422853109937522, 0.14948100632717534, 0.14066909529989766, 0.1528756798154885, 0.1904236101695607, 0.11195156933559526, 0.13604691913050992, 0.11107007792640118, 0.18924584191653038, 0.21775778052547287, 0.12382743369427421, 0.33652054566529493, 0.13800635753620055, 0.31600167734488366, 0.07813455612068215, 0.11348435805449564, 0.11412023401428616, 0.13477095372734532, 0.13627432466995332, 0.14026155184593894, 0.16731413892440258, 0.13508716417897132, 0.15715665574516022, 0.17000195840674062, 0.17468807227428884, 0.13100206160977965, 0.13818914611493388, 0.15212630792971582, 0.2394401985070398, 0.14743204288665326, 0.13135532007342385, 0.10199751314376632, 0.10978589239980906, 0.19351066871275827, 0.08035241896587034, 0.1709265805660717, 0.19466291091615157, 0.06533380913277788, 0.1426790342215569, 0.1903244783921588, 0.20313162987511005, 0.1488258172908137, 0.22715656086802485, 0.19676669560853513, 0.17173282681934296, 0.13471573410976317, 0.11744884774088861, 0.08954821665200496, 0.1668993176351632, 0.19300408541194855, 0.14301988206082775, 0.08428083357190894, 0.20975991452653564, 0.21559558928974215, 0.12061390169565717, 0.13537453908112743, 0.23910839050527544, 0.13954964165966358, 0.13424364008730458, 0.09146037977188827, 0.1376922461654871, 0.10040464014896464, 0.15366591483114228, 0.09716235687054935, 0.09410664664521333, 0.13895077540749504, 0.1390704996283016, 0.0921870141680683, 0.1293687315116967, 0.0909369272149859, 0.16113513419705053, 0.09630271428895575, 0.11562876838950381, 0.12073423878680314, 0.07722861884582428, 0.09850179265824058, 0.16093665613762795, 0.11767017820309247, 0.1356074144883502, 0.1991881003543254, 0.21780081934505896, 0.07088404719627674, 0.13892246079781365, 0.1906429411422822, 0.16284481261766728, 0.14330284429654, 0.2601922027045681, 0.16988630977369126, 0.1584700828478221, 0.14730330947185719, 0.15169913730313703, 0.222357219205268, 0.162406426463877, 0.15470332045468593, 0.1436856124670275, 0.13600931953518622, 0.1006362438502331, 0.12400416251752647, 0.07503942301076266, 0.1929835082903024, 0.12290765321062458, 0.13898209308183965, 0.13293145404708, 0.1877391308305725, 0.20783680401021437, 0.1545342908150727, 0.08192388746406763, 0.12095478783932426, 0.1304647428614478, 0.05393550100345766, 0.24402305904415347, 0.1429347696924402, 0.06902822984322425, 0.19186189428212183, 0.1173727828708868, 0.10049475507149774, 0.18021133638197379, 0.25969066026230014, 0.11055761873121224, 0.06421047908764693, 0.2062833462391169, 0.1063608818296944, 0.14530648597546164, 0.15624724809200535, 0.17886642306562395, 0.09249419244306703, 0.1752119691621873, 0.12818304190952934, 0.10745062658022489, 0.1916967870126809, 0.2048589896050192, 0.13193434464835352, 0.16101651314285495, 0.15470540421383996, 0.14548084758702787, 0.15400136941142623, 0.16255425078974617, 0.14137887576174352, 0.19935593489677678, 0.09312390905594634, 0.17855935970381384, 0.13542808862703462, 0.12177339875169339, 0.09041722848891251, 0.20716433203028095, 0.16813550775329913, 0.12972677036398841, 0.18148187788263445, 0.13539966676504384, 0.08210132108821024, 0.1447506585428792, 0.17771663234358837, 0.09454413647613219, 0.15351542451929662, 0.13218199023075644, 0.13244046829640865, 0.08397039176235277, 0.2411146522048981, 0.13648415615241374, 0.08454648222053245, 0.144727430757015, 0.1309268470973738, 0.08448943165281127, 0.1917137175558075, 0.14584740533703758, 0.14980803394029218, 0.27066073290282683], [0.04144405052366276, 0.043022310391308806, 0.034769927001287865, 0.07960263339261855, 0.04266692603367471, 0.06466439384366236, 0.006661103858101753, 0.057428678077074795, 0.03742563590827969, 0.005417252381918051, 0.03810341304708873, 0.0309029966968322, 0.00835016493745629, 0.009987499760163408, 0.018570777592099002, 0.07102531380951405, 0.022153039199991093, 0.02478418732813049, 0.042922236325760046, 0.03526422608223173, 0.014826030650686835, 0.010207980822381234, 0.03914215549406025, 0.06315209031585725, 0.03974142777282865, 0.09681413926544691, 0.0155331815157326, 0.026865200056964834, 0.028787613433275013, 0.08455223554084379, 0.0077915882068355724, 0.010894106404345122, 0.005125146408024575, 0.04554756601611453, 0.03244472374658912, 0.024588576352764523, 0.028369861857725248, 0.0766735575011661, 0.014550510959158984, 0.0119272937562557, 0.030236854518373168, 0.044621959433800755, 0.05211315020137737, 0.03528987853637627, 0.06698631441160556, 0.052341858090292064, 0.006693415531528093, 0.03874599993709595, 0.06406266242265701, 0.017527415634944074, 0.03882978697337451, 0.04184196425241329, 0.05034259460385769, 0.06080545575147676, 0.013710793366866007, 0.03409276273281824, 0.09943438213198416, 0.11818278295498703, 0.029644886887962782, 0.03923272240846869, 0.011937970149090454, 0.06507400573501665, 0.0925922440364957, 0.027700844934330355, 0.025198893704181238, 0.03271457438747729, 0.06712909787893295, 0.03149599471550075, 0.09729947894811632, 0.03712774261892323, 0.03428976224254697, 0.01156188322291259, 0.05657001991846389, 0.06377067567119676, 0.010219927963560388, 0.026258360744724353, 0.02935054058569574, 0.06602740981766293, 0.04318955887649809, 0.03603523612142571, 0.030249887589184992, 0.03846023765002047, 0.018397151424940077, 0.06457046380326634, 0.06979948886099362, 0.04562045162123057, 0.061237996654404755, 0.08845290244226495, 0.026326425741576863, 0.04572146414448658, 0.07993500829944689, 0.007840029382702686, 0.05455263845262028, 0.058980569198367104, 0.05491826923624162, 0.06608076784158907, 0.019162218537061446, 0.08679939358825646, 0.04793019139117772, 0.02700801225258939, 0.028109114256597338, 0.09271207550961165, 0.04076952925853191, 0.01109675485490551, 0.06003861323059086, 0.030620632009700905, 0.029676451625662948, 0.015147432305609748, 0.03669921601671846, 0.023856203958031633, 0.04384508116110679, 0.09453201696517007, 0.03490793391040737, 0.012740825505686865, 0.01804082286393931, 0.05934841014564999, 0.01520351568732651, 0.03650577881583764, 0.053273853845894344, 0.059655427542184634, 0.025574043130261764, 0.03352565848599038, 0.053420674596582694, 0.027604310194991773, 0.04757284967889709, 0.03183568959244557, 0.026304339426719857, 0.040577911516471256, 0.038930217269808054, 0.0646649913922433, 0.031163876448127053, 0.00761407366465597, 0.04851349456716449, 0.03537243217109673, 0.04688424005683872, 0.0072087518656776565, 0.03098881961176953, 0.0471958807939964, 0.019112141284671043, 0.04267567092733037, 0.04397808168564112, 0.018063648453643246, 0.0390999976755871, 0.051912967596323266, 0.004743372236618832, 0.04895987867888424, 0.04430945684772827, 0.04618201322192627, 0.006991293977931023, 0.07595657581283201, 0.04155922035175947, 0.03868505764271944, 0.032333717606360876, 0.03815658337947342, 0.05067903360712433, 0.12010423872139185, 0.03288503278106932, 0.03130819592174263, 0.044286493362197955, 0.06034538164855011, 0.03607746288781205, 0.02053865828671523, 0.022839932785099073, 0.044128380475505706, 0.045182632372504285, 0.051718530650701255, 0.058829826077506434, 0.04968114662915469, 0.029011106178645166, 0.0749924311774873, 0.034013315584630735, 0.011498502853717054, 0.053883031641523686, 0.03456466523329577, 0.04413830131412514, 0.05225608305585, 0.06804059695212111, 0.04591766692277405, 0.051844709162269874, 0.045779690657171516, 0.014251419699810928, 0.03149832170757075, 0.01997039341668208, 0.058777996398989237, 0.025966182471283024, 0.025611719334377878, 0.02437575712739941, 0.047142875170515436, 0.047630490134319955, 0.034311568935311614, 0.02752258202000972, 0.014111242846645897, 0.0361290167746765, 0.0538279460893283, 0.032391806223219445, 0.08023231936198089, 0.018293819570493315, 0.020042620186183243, 0.09990461456078677, 0.035772081088995746, 0.07614491852901636, 0.03545208233258417, 0.0237743895981581, 0.0713248158835115, 0.0522904267774955, 0.05421584704890848, 0.06375847572100259, 0.11911516558499106, 0.023444515968402548, 0.059883767708895676, 0.029790941550726854, 0.02298616556330554, 0.017266918927611365, 0.0051832168302949405, 0.028625750546193415, 0.02700669458135963, 0.020564682293503035, 0.09663176437419269, 0.059997022317181674, 0.032572541686315695, 0.04625538146243461, 0.07427974724240842, 0.012258851821834763, 0.05482656468126563, 0.045660958520226905, 0.07157063817665463, 0.05192648138730757, 0.047638622157636194, 0.07948831009167819, 0.012251900531531823, 0.06935836777331368, 0.06083773486616631, 0.08067113452500875, 0.041689095237562736, 0.039629831744898716, 0.0454756495122227, 0.059130894801309036, 0.058440588294498386, 0.052278797562804916, 0.06233173272302074, 0.02781121522158144, 0.05148768537647782, 0.0721413430367266, 0.03878626551839613, 0.03620547234951969, 0.05629078470050328, 0.013138071780333356, 0.025907057720506867, 0.09234012450061499, 0.023241203894177755, 0.12427242352597176, 0.0184346859027902, 0.05739377511124458, 0.03450060496106744, 0.06305457498397558, 0.11762990496091305, 0.042297844023954485, 0.027352194489550688, 0.024987499402355284, 0.060010294790469834, 0.047141067203014135, 0.0363146283874108, 0.04109070779034688, 0.042631414027944695, 0.011133205318342776, 0.04480774724675764, 0.01966321705690315, 0.03826348711886714, 0.05824916973529805, 0.10166884610249151, 0.08766672769260984, 0.04725504193394896, 0.02119026969247047, 0.07515636633240408, 0.03341164545065934, 0.016680298590912454, 0.033021097657300776, 0.026389490099503633, 0.03876114549535898, 0.00530491468511642, 0.05844683191108127, 0.0370561478719596, 0.03303279965034416, 0.021262749270986647, 0.03844690388969837, 0.09921710427489974, 0.028501071651736577, 0.052632396935575435, 0.0622457814883561, 0.011550252093002202, 0.012887635722666258, 0.08805667410694784, 0.008268777671600542, 0.03611058086877869, 0.016408440799662666, 0.05263664106267595, 0.013606783524606259, 0.03638174918089663, 0.02441856037494877, 0.02476269281619499, 0.03288685607032911, 0.05450294615941183, 0.02766824597793241, 0.15335463798574864, 0.03800883949283631, 0.027819849032488082, 0.06456338515084598, 0.038252539722429174, 0.04816670188560121, 0.02567662038810311, 0.019383543253605886, 0.03372209109065514, 0.0877686633518146, 0.07232054632397429, 0.012996150161920777, 0.06155928626896874, 0.04565113344259801, 0.023271422232350996, 0.024085097623267965, 0.036516308694356875, 0.07747039619472719, 0.053358230769874594, 0.04229371864048224, 0.04309585483203973, 0.08303238604698451, 0.05536189160099434, 0.07134922344477908, 0.07171523727236256, 0.042099749008494045, 0.029962855511375015, 0.04766122558184209, 0.05237694108678449, 0.01587049481684282, 0.04752475084857114, 0.04118526602284082, 0.06115944582908865, 0.042429519216379816, 0.05815209490397285, 0.014308194475879353, 0.0714761718747116, 0.08393068542523731, 0.049064472663186254, 0.039170194312088916, 0.0649188269650744, 0.02820059473085548, 0.03723183864607446, 0.02306083615328516, 0.07367765576007866, 0.028855655447489796, 0.02312098363144023, 0.018144495627512375, 0.009554104669199837, 0.22967859892354858, 0.1269103630235599, 0.1702902985796813, 0.21540138600093706, 0.11412698324889907, 0.14520071987663546, 0.13906784896408358, 0.19118649584631767, 0.19618282935792403, 0.055730127083558234, 0.09972347307109064, 0.06583038732529649, 0.173639680949911, 0.17532967091087373, 0.1509190606133592, 0.1377368478044387, 0.17683442081174544, 0.12188704023438117, 0.12567585063797812, 0.17602993656070004, 0.10054195374851266, 0.07849530692422584, 0.15107324346899986, 0.10376412721891558, 0.10347170379733849, 0.1629508391863877, 0.15836656904749333, 0.2172537253148133, 0.10329655311521023, 0.15945381635139066, 0.1312261423276317, 0.1953792031253538, 0.08212366787296149, 0.133746525633239, 0.18004196966367383, 0.2087668041067739, 0.1948745197225963, 0.12229836050180659, 0.20543547076804025, 0.12751397135997974, 0.07057361304759979, 0.14088514741630326, 0.14808516348561934, 0.10698551927963573, 0.1541873908812, 0.12973516668763854, 0.07520879738994184, 0.11058462333054313, 0.15324214563494729, 0.166429981529232, 0.13045864480157054, 0.15491586388839831, 0.17794419110061663, 0.15597363212896934, 0.12070173367617593, 0.21425318874178395, 0.20612937788809502, 0.20120933141198852, 0.0909645600064147, 0.11047062178653096, 0.1088510353058096, 0.12525114681451552, 0.26495901627406, 0.14316686368998022, 0.1428922977779181, 0.23404588231876974, 0.18013109633278462, 0.14110872251612527, 0.16314873501898783, 0.1167792562515505, 0.15108367758652858, 0.20166895352303985, 0.1540255471463165, 0.17940076939280958, 0.18863304818589843, 0.11725886559654629, 0.2151497567613279, 0.12412255374534477, 0.0742518233375684, 0.14382099552500632, 0.12482324840440867, 0.15156493402056156, 0.1518744335419709, 0.1752082153313583, 0.15448585873649967, 0.15533652276762072, 0.11916663903262346, 0.21124158985912803, 0.10701652285793137, 0.1293819388675113, 0.16968116674932743, 0.18551448810725443, 0.19174668998006852, 0.23176811905878208, 0.133928578767565, 0.15790529218652558, 0.16980637615967184, 0.17373631528067976, 0.21381284140290754, 0.16760132996545685, 0.13820227686195605, 0.1555330856072326, 0.14043399823769448, 0.09830147598779972, 0.10340130797797635, 0.14582019389396714, 0.10618097374155637, 0.14024109729836065, 0.13569799672451713, 0.16256068592831013, 0.17673695910601847, 0.30260764122489964, 0.13744214910172647, 0.09281021903359121, 0.13847379374407953, 0.14507667491993598, 0.13746796626477473, 0.11724592637150519, 0.13544158709626045, 0.20774884179474848, 0.13029425765477842, 0.1647189854373855, 0.22165200462745083, 0.10983023356886641, 0.12455211456624732, 0.13969257834457582, 0.16348365333772477, 0.3455522932833241, 0.13358469722011398, 0.19256435094341157, 0.25185894341238085, 0.10338257712822768, 0.14376191482428582, 0.16799779578803048, 0.20501470463650845, 0.11316731256703216, 0.1563548374800913, 0.16011832101691156, 0.07964249294731887, 0.14728089373919273, 0.1810744570027436, 0.08407140045516914, 0.11094131386808812, 0.1447821754000841, 0.16851409308372006, 0.10641230931205135, 0.11980393225507391, 0.14155855402350426, 0.1743648597790349, 0.1640735716829377, 0.12496395577346125, 0.16984530874798376, 0.12707247488921689, 0.07175014023819277, 0.11658905960258939, 0.2959594076439258, 0.09915011754680066, 0.18505509582258042, 0.1441844123145265, 0.1668215903543657, 0.15190766643612616, 0.12156168269293925, 0.06636460341753499, 0.15305457666756647, 0.2263749979676739, 0.27446212247014046, 0.1277734223572958, 0.1397677775352232, 0.10660349421443478, 0.13744982530272778, 0.11363981261609063, 0.1625288932794525, 0.1520694795274927, 0.13103273577026783, 0.1099942223499379, 0.19369155739343938], [0.024868171632049546, 0.09716507648268054, 0.11410977691411973, 0.010266279155809072, 0.052097372620576815, 0.10751501627026067, 0.008308879501606909, 0.04117048818678145, 0.02486799351660715, 0.027650974525679505, 0.06844382733106613, 0.04231578963358076, 0.08627597167487107, 0.06066490926088826, 0.07424804652410169, 0.015039409120236675, 0.018259973805998603, 0.009658699611111755, 0.017263908202068943, 0.06075626141541909, 0.06574640110615762, 0.01839475548495689, 0.030902994781612392, 0.038745011683673634, 0.04720521940579338, 0.012373766925696646, 0.06080852010317388, 0.09694609791040422, 0.04870866312675419, 0.033636231786541404, 0.026624828479402972, 0.0037389349674941193, 0.03646999867933412, 0.048356166920594634, 0.04924850613479653, 0.08307273589795636, 0.04334847615551084, 0.1244601916762129, 0.03258194924602586, 0.048825732852903106, 0.07140921579012949, 0.01869026624086884, 0.0473263340761825, 0.017929516034200788, 0.026872640685929407, 0.021194077149454146, 0.07008611299698392, 0.058824425157640255, 0.05510852717223668, 0.007054513468662458, 0.034161978776776986, 0.04167973364312803, 0.14720279873619158, 0.04145756814508669, 0.03981532844444437, 0.029421491818802974, 0.054792738068969025, 0.04042094776166543, 0.016161860079474507, 0.03536174524455302, 0.022330911409470345, 0.027996401655517762, 0.09739111838561874, 0.06253093473553177, 0.04076072690828193, 0.026450562628827272, 0.001317871370232634, 0.029664485332285686, 0.04280242783528182, 0.04988633944923359, 0.005338165773859909, 0.09960702004572076, 0.0665977009902558, 0.03793675444960114, 0.04456381719078749, 0.014570228147110151, 0.02012349417312972, 0.0315461524071232, 0.005008163824377041, 0.06164406921954886, 0.022887096988157402, 0.061981818233166015, 0.08888132945303956, 0.012501818522240126, 0.09757101881287752, 0.046909452010426796, 0.023416419693779562, 0.1217027960885917, 0.021702468417765155, 0.03706349465515345, 0.015208794033124804, 0.05730117806383679, 0.031909052087294484, 0.009637108380575816, 0.06458225389642101, 0.07486532186909069, 0.029196669910884196, 0.0791074954453976, 0.062197291953188766, 0.03435997803124689, 0.050782754251192656, 0.10646663260676208, 0.055495309643447406, 0.008863346170513861, 0.03695910368415137, 0.05233614307437694, 0.02018454180459582, 0.041915531675781936, 0.012848981798836782, 0.04532239745341001, 0.12774653267115355, 0.09623751254572023, 0.03485452226032654, 0.060909433034999724, 0.02977931808169571, 0.0520722602584189, 0.09049760643392803, 0.030887366587957068, 0.04473982589139093, 0.06550188882336502, 0.05027650036819039, 0.025750733649117813, 0.03489979422621189, 0.014809735002927484, 0.06449799954650864, 0.019359070574864745, 0.03976868518117455, 0.013189908162119889, 0.04688501763608187, 0.026814147957690784, 0.03575026673535186, 0.01849666241586449, 0.05960008535053461, 0.05901089095841012, 0.047502013358978495, 0.05459030699585715, 0.028678104994938742, 0.045170171952415863, 0.058885233386630015, 0.009174811665058858, 0.019893792285133275, 0.021430698726626656, 0.013418333556112504, 0.03846405276788339, 0.08180591758460769, 0.05583423843246795, 0.03761109813386875, 0.0598434676536389, 0.0625269319261274, 0.09296820934621558, 0.06332534876081251, 0.035288158668986255, 0.02669936117355622, 0.03719172245191951, 0.00941979509192489, 0.039583556203832554, 0.044297356488964254, 0.035614006506699714, 0.09637430520547975, 0.043691855915371454, 0.05919068796379913, 0.031181854616490104, 0.024159346864889228, 0.02521121431322348, 0.06939949137308905, 0.03510640047851109, 0.06469652357120668, 0.018686052757285295, 0.005406288706111692, 0.03665983909741044, 0.04261752102343787, 0.046455433832541596, 0.014933866144518458, 0.06435631158491296, 0.07221547736515922, 0.030819190508355538, 0.05475239587887641, 0.016268014967922243, 0.07691156569748156, 0.008358534448029054, 0.0340109100685485, 0.06802258622502128, 0.023137222780215166, 0.02794231393284375, 0.019180782762686574, 0.01866759961440919, 0.06524017020579308, 0.014007819061648222, 0.02507730022883944, 0.03974782843743602, 0.028958096724724578, 0.031248113561061122, 0.023828946549685735, 0.03326082955144587, 0.024704182850978067, 0.05319213524701134, 0.046329366403722, 0.04894861718639732, 0.043512438123504964, 0.0037821049796372295, 0.06432668696488104, 0.03415459368918692, 0.034903743409461556, 0.015183234467141092, 0.03991513054878001, 0.04598633904430655, 0.03825237118308583, 0.027858961651462223, 0.03631700325997607, 0.010968567277755468, 0.015084349753094778, 0.09146828579926684, 0.07113837306537936, 0.04628067385525473, 0.07136695838022618, 0.06752391661246938, 0.08712517247805673, 0.02512965467758477, 0.05531863444634984, 0.024807263811629628, 0.022110590268106713, 0.054491608058132475, 0.07110970605525278, 0.019730619387701154, 0.0695400455245568, 0.06228510861194903, 0.129036754970589, 0.033612479230449084, 0.09369650615319129, 0.01814117846680024, 0.07355726504277799, 0.05542681372213749, 0.06170284348509966, 0.06632299718236731, 0.05353914626363305, 0.02009997910429393, 0.030141493808778546, 0.032190033985722455, 0.036159093386583754, 0.029302817138452685, 0.046028251714643934, 0.0032225407138016197, 0.06487443216986234, 0.015097898975645584, 0.05418243412409098, 0.04225075642968859, 0.0735642824081644, 0.07876501583884801, 0.03507383408084993, 0.009061459380562508, 0.012577636328886354, 0.023007527925074104, 0.047957345377653844, 0.05487993036607101, 0.023206789309399265, 0.024182262469924266, 0.027203086966408357, 0.013317674390911577, 0.03712488128052604, 0.03371583215231377, 0.10817572113967712, 0.05814119730324996, 0.06160296860241121, 0.09165117396943032, 0.06170268260663556, 0.03806440384998437, 0.009228513470941014, 0.046689967820120436, 0.06346344760048293, 0.03847338754924075, 0.007022698315972042, 0.02259349762161653, 0.04266724396016329, 0.014514892658729468, 0.08142066728924552, 0.02673762535015422, 0.025030909774584637, 0.013323818416064306, 0.06283884462449821, 0.011986598537694062, 0.021771609768151276, 0.012738793457467711, 0.08889200105782478, 0.07042856962089578, 0.025866411010464354, 0.04514722378864404, 0.09697133284663001, 0.09631325565879384, 0.00237691275317282, 0.05257586730764278, 0.008221601977223351, 0.11938127388636913, 0.027915451059778853, 0.05382202039923399, 0.04375809570774437, 0.03635706582797631, 0.054883243696343516, 0.03416405104461216, 0.05182103704540961, 0.008803568329782257, 0.04808534717848224, 0.018113880838838317, 0.05778910712369027, 0.039984798584614074, 0.053434831901423396, 0.038722266533201745, 0.06920243823720564, 0.03059887894309096, 0.1076753814554503, 0.0559793584679644, 0.016231049310355898, 0.08103407634001586, 0.04117074865667571, 0.02248652876474925, 0.0818801591653497, 0.022362139068483826, 0.007660863921046258, 0.043259820630473476, 0.017568776721975977, 0.057432504686256575, 0.037882492441924355, 0.027728046801301743, 0.03883662430809871, 0.054681766402697375, 0.031207104874474388, 0.057628324420581904, 0.014345325799959322, 0.059882243193926356, 0.04767035351945989, 0.059347467857503125, 0.034631556200404326, 0.01635095930748409, 0.06695734096630927, 0.06475849242340173, 0.03794756011977311, 0.02915948208781981, 0.021255775955655885, 0.0788340633434634, 0.019879991211177363, 0.02574911720359758, 0.10183022252374119, 0.011171860199782157, 0.04434694919074255, 0.013786693527964095, 0.011874195244613917, 0.03774339768795237, 0.0582258423580037, 0.02994612798154835, 0.030803834275913336, 0.045530290733422005, 0.02555149333221057, 0.020794652312272982, 0.14026711364426922, 0.16996725462377074, 0.2459005566854631, 0.17318520694971087, 0.1437177575163303, 0.193964529842619, 0.0980435035401775, 0.1563962521932779, 0.1350781396632233, 0.11100738129067807, 0.14675675170315852, 0.10520096342529982, 0.1788418622867715, 0.18931376327189708, 0.22455386907583286, 0.0478468218728179, 0.08049703338333676, 0.12278002296243945, 0.15580696204016287, 0.2341488905010685, 0.12512383066237937, 0.2513824367234784, 0.21747179990333898, 0.1274098217066738, 0.1383786456238839, 0.08367437538841078, 0.09158138335952837, 0.22148761748065873, 0.09503151395268018, 0.13169751622744147, 0.12113032922629388, 0.1228960393176925, 0.12190629202391833, 0.09522675146018306, 0.09910718597952398, 0.20491862188904517, 0.1935124153932256, 0.19627373335101914, 0.14579197121483667, 0.11064754979264353, 0.17106656015159624, 0.12928167327998147, 0.1472781511444238, 0.09195271383730635, 0.2149203900367983, 0.13531669944284425, 0.16566536449376615, 0.2288336192648257, 0.18117386457179824, 0.2882475988759149, 0.17767031466768635, 0.08515254969918921, 0.23067648973195787, 0.1919711537418827, 0.1459895146469916, 0.1681007426832953, 0.17479455849576384, 0.14566883024188781, 0.11031036385365071, 0.12234931300965049, 0.1574251695626205, 0.16410681989885148, 0.19796583771465287, 0.15330232950227876, 0.08221281752471002, 0.06654163101507772, 0.186894289067676, 0.10303999793024794, 0.16133169703666242, 0.1083740536423941, 0.17352836837451305, 0.2025787901854323, 0.2220018923042282, 0.11182004736075479, 0.13933063244387028, 0.13139665817781804, 0.12701762299383842, 0.18311289439518608, 0.10523889243843094, 0.11655903661683684, 0.07554859568875644, 0.20256172174647932, 0.2048849753074108, 0.07810664753760062, 0.3053398784850874, 0.09298489474120641, 0.2338499170277388, 0.24787810540968375, 0.14060799212705705, 0.17987608098455016, 0.16886580404975723, 0.13127045285317207, 0.15866797868042223, 0.12885727589168858, 0.08951200367582422, 0.1721144918232195, 0.13598460553874894, 0.1547177229076624, 0.2542628813534975, 0.10229888447229901, 0.19481710909355074, 0.15314221712610415, 0.12946683673128007, 0.07900615733477377, 0.1450550405969543, 0.09332561234553015, 0.12928015642589138, 0.16626639111388117, 0.1181567742699577, 0.08892129626004927, 0.2631252162879513, 0.37923751639262326, 0.07561462480695018, 0.12345391986591202, 0.15901345369075576, 0.19919848850657865, 0.25860569590041715, 0.08692117858557932, 0.0970297470508564, 0.18308007518850988, 0.11089319588556407, 0.06801837274143774, 0.14193030584964061, 0.10496629537233423, 0.15203043968687135, 0.1370246465047521, 0.18316180144827213, 0.12434809003025295, 0.20647324411378754, 0.13543092315235447, 0.17213534473651843, 0.09960597816614375, 0.1903646213993911, 0.21564022157221072, 0.1900824712168786, 0.12911350165884342, 0.11281559394011575, 0.09530524482890483, 0.1396985691521437, 0.12044587563122473, 0.09040691694545169, 0.1617757982063678, 0.17887927802099338, 0.1385897794558156, 0.12908164772295183, 0.16300857157236145, 0.15548658407022878, 0.15277903016296127, 0.13939412581103464, 0.20762075189380877, 0.17869509516223786, 0.1477780541585338, 0.10742001370677065, 0.15334792705553194, 0.1264105289573631, 0.18698776711619672, 0.19678350357759386, 0.09689647839554856, 0.2404117512126123, 0.2681913557312181, 0.17592898149403835, 0.23020067252218726, 0.09350064045359051, 0.11136983280941365, 0.23976463674297258, 0.11317391624493946, 0.13883063749920938, 0.09198286705800603, 0.13310003935569717, 0.12637047788068173, 0.10755515161661372, 0.17363344499420735, 0.14161999427503155, 0.1963169713534655, 0.12039078624858973, 0.1229281154190821], [0.09859576100303281, 0.1190871267669624, 0.03896867871404656, 0.019828418172114802, 0.0774548446098643, 0.04846521187573672, 0.013816691615859108, 0.039419245665832874, 0.05585050247910042, 0.12594008968482096, 0.031083404657340823, 0.02232671133242548, 0.02169917998535018, 0.024452883029176344, 0.01972347753302705, 0.04740412264401394, 0.04006508842951829, 0.02338478792338602, 0.035735952382486676, 0.09010990465720815, 0.04926218846512418, 0.017881662352010608, 0.03503097146148643, 0.06004947635735716, 0.03383041975358802, 0.05019447150369806, 0.030763923010278135, 0.04517907006365638, 0.03479960907791411, 0.03795678764882107, 0.05310404279659833, 0.04337674479991679, 0.025724761353264895, 0.038604223875388984, 0.0885759744673006, 0.05225242498601156, 0.0194045034192142, 0.047530810604052204, 0.05181758581931072, 0.030156101190274766, 0.031899372566371195, 0.018535895693686702, 0.009537341707806674, 0.015841693741329495, 0.051095241515506665, 0.05303014978586186, 0.06715796407191985, 0.027418106779335972, 0.0785684836427531, 0.01174582955202148, 0.03854480992642142, 0.016966530106841557, 0.08367880337661313, 0.06351149663509381, 0.016215049564057303, 0.006187369449875288, 0.031734579392979224, 0.06621984344336294, 0.10054543944856814, 0.027016500506790418, 0.055945612294899846, 0.04892599460999331, 0.04590205405087722, 0.03077789070835758, 0.03524377919553268, 0.042019688989967115, 0.010945802017475569, 0.03773984687042333, 0.051837178517974196, 0.053877285982091586, 0.017806426772186836, 0.028555820125245282, 0.07943060834922137, 0.03534784074872732, 0.06928811751065717, 0.01596290896075868, 0.06019062805740584, 0.05928564456201369, 0.025212154686150533, 0.03958812974874051, 0.06838603365805841, 0.030883172256571632, 0.0335074064411944, 0.042633260299842206, 0.03345060485204862, 0.02123257498286905, 0.04044889464914318, 0.013537876788646945, 0.12455376931616377, 0.043238527216618104, 0.061552192294789906, 0.013431087962441869, 0.06770973889938287, 0.035095319016686374, 0.034306953255567825, 0.06462428914082628, 0.026408397149474874, 0.030433063042320074, 0.024208577590123303, 0.006935370038263501, 0.017545248246601513, 0.04582570955878304, 0.026861222145418008, 0.04998610324917301, 0.11576146247886843, 0.03122057270018324, 0.02853106782441178, 0.02569418103854743, 0.0583312560563847, 0.03824680555431593, 0.05362628876501995, 0.0495990181732322, 0.04280873273889865, 0.1674605076832156, 0.030578045181990154, 0.09920149906388215, 0.042887348681688316, 0.1306991964097946, 0.04248232948744009, 0.026959130097360864, 0.08668884710078278, 0.05090479588797016, 0.059815953605838364, 0.06815088296970052, 0.009231803818575798, 0.013474257974584979, 0.03570404865088002, 0.03213939174348789, 0.09885410117285867, 0.03054485250745089, 0.01249025921307264, 0.05169559014780868, 0.009490808569675973, 0.034983248014243386, 0.06062233009405675, 0.02408301386411392, 0.0447258792607294, 0.041998851398426684, 0.02075928011758914, 0.02107633326593186, 0.019690872830969673, 0.07569212992224963, 0.04865415214050201, 0.019032221077190294, 0.05410641138892501, 0.04420628778696541, 0.06419754369304546, 0.02268180074620872, 0.031798178097233176, 0.031113531064963153, 0.05512230526355486, 0.021621425891475334, 0.025922021332887873, 0.06753258872777224, 0.02179342029135554, 0.02567274398320625, 0.057002943865354025, 0.018979813002290267, 0.07018742046409077, 0.03098594103639405, 0.055419152842894684, 0.01332120797146232, 0.053142891115238594, 0.007027472480155167, 0.05813851216507535, 0.025476010689031214, 0.038403347960763404, 0.07054658546563118, 0.042112297528693755, 0.05574789649296192, 0.02155283229395507, 0.034229145535538276, 0.01067486257412501, 0.05536009895525152, 0.0241999150509195, 0.05186850768363765, 0.11923260686378326, 0.07121777807873103, 0.01238340909983362, 0.01896737173439995, 0.07489801850169897, 0.033504652355106614, 0.04540881217126885, 0.035064836378179254, 0.0377468029487758, 0.036186982817467184, 0.04919513661955153, 0.04606661356745228, 0.05351419477993923, 0.043876100061160904, 0.024877659630991762, 0.018505918673209606, 0.021498076159567125, 0.041380373295396566, 0.03458087182333393, 0.04106661049468864, 0.03414723924511383, 0.02977066511859096, 0.036653783172369, 0.04132692717135914, 0.0672103031989067, 0.057041891775424444, 0.01920117602323092, 0.11288068077016263, 0.0369006205320118, 0.030374922714526617, 0.040105748546099475, 0.010000000399867854, 0.028081473804289298, 0.029791740197387916, 0.050906672803384644, 0.014184621620863197, 0.052835509826939915, 0.10823071859176121, 0.061587462982823776, 0.025177251720320315, 0.05545807010944813, 0.0630475422968307, 0.007700928883071268, 0.026548428445934292, 0.044576135884609916, 0.04426086006025153, 0.014997207251707874, 0.08616788432963433, 0.0410801166247937, 0.02056584483192813, 0.06477892398834229, 0.04377277395237358, 0.05566949888523068, 0.0223387599802546, 0.021557553310788447, 0.04107799456124345, 0.06795709336837454, 0.03950958658430365, 0.03515864001406777, 0.02292901923459384, 0.012876543727132582, 0.03283609125402666, 0.0215252761113187, 0.029415568043928475, 0.026363038998698036, 0.0498496170245832, 0.03972067828139952, 0.083046505047429, 0.03854775170405065, 0.060975630692536795, 0.06178748853985341, 0.03026351054769851, 0.029623032314702872, 0.01477373940419526, 0.03387266567217247, 0.022870687384819312, 0.048463645225931565, 0.04526756087979002, 0.049185579672696135, 0.03621602138023704, 0.047588565972663706, 0.0241307602939947, 0.11653800750331533, 0.03319435227181643, 0.065111153338465, 0.09822384063755313, 0.027041302603338997, 0.027130754859817606, 0.022597193995851184, 0.02710143284451577, 0.028350267243841966, 0.07837111641082072, 0.031148087376007633, 0.04646563812369301, 0.06405444996010873, 0.04378532630301291, 0.08436151795209416, 0.023870899439639142, 0.03309623173047458, 0.040150020767243645, 0.017372051088680184, 0.030822296994888497, 0.08363447752931426, 0.03755251922073864, 0.010013255636177717, 0.0407228515213055, 0.14946281939985293, 0.04843487096349559, 0.06716076795372271, 0.02601818643480299, 0.032310692833796624, 0.030336622148752216, 0.020869539322091207, 0.023835473618800604, 0.04584282013257185, 0.031177754130875392, 0.03967671249542506, 0.09520023715712371, 0.06302998739204581, 0.030114774577199455, 0.05973500492531927, 0.06101833626387581, 0.020927105083941452, 0.0066083601409299, 0.050981067601711526, 0.07666351408847878, 0.018580476265220393, 0.013100362059870556, 0.12275062816878482, 0.05501126464937003, 0.020963775797656948, 0.0669417740596879, 0.028494521599983978, 0.13326755214122035, 0.05088313858235075, 0.0285812733965295, 0.04435155337916748, 0.0240801103908809, 0.013769417287661664, 0.05779767964756297, 0.02114655671551103, 0.044702218635188, 0.02276811395741759, 0.041328597243034074, 0.02724206168955613, 0.03298329121823753, 0.01757045636974996, 0.017489657076376102, 0.03747234045858345, 0.03034965905000366, 0.030887684514445644, 0.021120092208166758, 0.05442855136108495, 0.03942466190745754, 0.03928769687791506, 0.038554041285908995, 0.03694115041364585, 0.01948076172641689, 0.02405198155752113, 0.014785188588223632, 0.042880032542011434, 0.041805395045347755, 0.0313927720285832, 0.04602316106038709, 0.04119442843441521, 0.015520804407705945, 0.031455541442659114, 0.04017621714381441, 0.10140200235670614, 0.04099837504327297, 0.03580258287970097, 0.018402314857549725, 0.019643346651367122, 0.06403347830318155, 0.08276751880804378, 0.03885265086747466, 0.21419274440455824, 0.20406068002264346, 0.13687650042195476, 0.1651435053997463, 0.22046842942795447, 0.1055823679592821, 0.11201104074115716, 0.1288090276742174, 0.1945155309212785, 0.2591110687823065, 0.09643799775550443, 0.12238675938738931, 0.10413689794199121, 0.1550238363204464, 0.07860273543384769, 0.18599873228419214, 0.09984463753719484, 0.1070422480904287, 0.11309607405095332, 0.26927037525080866, 0.10519244452758182, 0.12080392980527495, 0.11366723856377987, 0.19235698626406733, 0.12286901173572387, 0.19647611845885554, 0.11878970845211899, 0.18627429411055582, 0.15960574690853396, 0.19893057223769928, 0.15997745276939485, 0.12638615970049175, 0.15755692136383828, 0.16826925138312002, 0.17786928302338048, 0.10603676535068982, 0.08205542476066659, 0.22466896612557674, 0.12079700437043944, 0.10546735517920987, 0.1608579329425289, 0.17171752038261584, 0.10332712002338902, 0.07349433091979835, 0.12446976011438717, 0.13671188344878538, 0.17493709681495545, 0.14655284974123203, 0.13190615261274, 0.10404627740142808, 0.14577525517632886, 0.17565364949405196, 0.18990024954320925, 0.17604852185374306, 0.11595193491948229, 0.1360503512044107, 0.1993976560451331, 0.16280139075411906, 0.12317332484188581, 0.20908515960458787, 0.1743336953222752, 0.15707089986291625, 0.14054388588955327, 0.12789860878500248, 0.12934345061019545, 0.10569538124987196, 0.07059048996457169, 0.1638085665481706, 0.1707416469411504, 0.08394072117704539, 0.10901327740641371, 0.0962149742389879, 0.12186315361290209, 0.11645521638133835, 0.24244827338524405, 0.18927976428981752, 0.18613301217556003, 0.1798212137674132, 0.18380894656142882, 0.1134289775584494, 0.11873346993759756, 0.2086822433216918, 0.175166999801032, 0.12456766615111022, 0.17454461464958806, 0.19642765573676557, 0.10809883655559634, 0.08200353762555508, 0.18826655172292264, 0.14674213474556325, 0.08705115306281275, 0.24429831443534744, 0.14225679720121046, 0.1246190629899502, 0.13318821607578185, 0.13171884411525342, 0.2172005894563852, 0.24868632816979963, 0.12645593498863522, 0.1380112451771575, 0.12760956381117144, 0.09775206071114349, 0.20978948552041285, 0.14667419806843804, 0.12646445388635322, 0.09152863820594165, 0.28152916099756, 0.1599300166051234, 0.19158309956471767, 0.12116516324421092, 0.17230943055643191, 0.12874518190660786, 0.11889781877999345, 0.191785070985075, 0.08796386255492127, 0.1883395445803481, 0.12391895821858799, 0.24100317109015681, 0.17727476815062185, 0.10920695209455107, 0.21344708038433907, 0.2424597187388328, 0.15521028679945778, 0.10174683385318327, 0.2272694669063053, 0.10209860610625437, 0.10861851995991123, 0.16791626871112855, 0.15787520025285984, 0.14470503034610904, 0.09206487677030026, 0.1453538914962161, 0.12924168349033402, 0.3402545194952719, 0.22285223457842107, 0.09625690223108377, 0.07367675177632801, 0.12693053411860622, 0.11768465726486138, 0.21699523192740258, 0.13540421732731406, 0.17347108031953537, 0.13116626489546993, 0.10601808046621662, 0.08939866862830617, 0.10810500356338679, 0.10713629304401337, 0.12456329944994181, 0.16936529337638812, 0.1735378985082911, 0.11139450084057548, 0.08666165097947083, 0.10978316512679863, 0.11344040759027967, 0.13117936499897512, 0.11999455025239338, 0.1565823502718441, 0.11390749905859271, 0.09820921601907862, 0.2912508167566792, 0.1251157867391744, 0.1400328899222997, 0.11305606127866816, 0.08680545334373752, 0.0870379916722736, 0.1016646556015457, 0.09396189433192054, 0.12038032148754406, 0.1752480365816624, 0.17094697382661606, 0.07064796188065121, 0.18186167363197575, 0.09338938150434725, 0.17588163726031783, 0.16192533856918737, 0.12870225033933116], [0.038810937379997586, 0.031919066771684636, 0.06781644728635589, 0.07271096771282536, 0.05309426751468451, 0.057553048621142106, 0.048094988395009315, 0.016113855094919284, 0.029950831761403434, 0.03920797010763519, 0.07874567977963917, 0.027601581006761522, 0.04225445280392324, 0.035732482004189686, 0.029162322358799078, 0.01709922994186561, 0.03712703015715365, 0.04168607685114107, 0.014661790018210248, 0.07951746739807629, 0.06744931497040295, 0.059054715018118584, 0.03539277946636562, 0.03399265036287327, 0.03996692958378023, 0.05650983605113241, 0.014293004867560683, 0.056603938461311405, 0.06748350547446359, 0.03549166992607136, 0.010797866608857388, 0.06372823440019162, 0.032113396464997244, 0.06440819105914523, 0.06307280404613384, 0.011812332687118362, 0.03617035487907068, 0.12244924151849364, 0.09301887840152749, 0.06730714437341498, 0.01269828272803176, 0.05045767250140348, 0.11163833130511547, 0.011829967073525393, 0.026853940479697722, 0.003779041585550013, 0.018129189190785253, 0.05198651586749381, 0.039054817640252655, 0.04071499145920238, 0.007971777353480819, 0.018289855065485163, 0.036137416928766236, 0.011649814794861503, 0.03701670966561764, 0.05580615364916383, 0.04467010039896254, 0.03393685617934793, 0.0281689380626044, 0.02764300721126699, 0.22844317489333693, 0.05491320156462251, 0.0649721083802081, 0.004181589428035002, 0.027344910908610593, 0.02322927782041652, 0.04010857541054007, 0.03565952745116046, 0.024670727791324742, 0.07896155569582217, 0.03292664284667662, 0.03152705958083032, 0.032488360114756136, 0.05717062135978092, 0.010828646106435167, 0.03193296360663109, 0.06318708521223838, 0.039101441751324365, 0.03954212616888746, 0.0034769841295201336, 0.019378860541168722, 0.035834440646032174, 0.015260020417401628, 0.028173980836365974, 0.10893861447731334, 0.01582019444134447, 0.022598965574176084, 0.028972039524946484, 0.008699492412439037, 0.017718849515902902, 0.041694936657985376, 0.024029458572547284, 0.04026122225989257, 0.04411229645953544, 0.061879629764946244, 0.03813164338709847, 0.05871477499303799, 0.06552497871340283, 0.04112990084855307, 0.12381585810573832, 0.036272528025531964, 0.021964520283584154, 0.015100083283839688, 0.05992659585430257, 0.0290957665551574, 0.010471277581077191, 0.02765939766240697, 0.028842947964045792, 0.008933756354024575, 0.018094127261710745, 0.027024760849833972, 0.020871395170087778, 0.12431020698239728, 0.058962114140271187, 0.03656396702412636, 0.01570687088514528, 0.08500166868250217, 0.04799213726073504, 0.032785483485748695, 0.052371256714386326, 0.04314275473476418, 0.05745354912153656, 0.05243547786507876, 0.02355857496900905, 0.011270949842348214, 0.03859909491673593, 0.03443092160347489, 0.037227724753921075, 0.02216923046827076, 0.058201971058283127, 0.028899429711483182, 0.008082639373418304, 0.0602425420055947, 0.04935070992477479, 0.0023896295733133992, 0.020182726176215277, 0.052926701103006644, 0.01692998962807319, 0.033041172991356546, 0.03649220373781939, 0.03291882108896971, 0.012208970879474956, 0.0243572675953469, 0.05595808420630713, 0.044933094552928404, 0.0773412337706935, 0.03392680510578137, 0.032134324071868774, 0.09331551530668813, 0.047267705367337313, 0.03655786513380947, 0.037692606058572574, 0.0132224831782702, 0.05631267949337921, 0.05844246137947325, 0.05983910478291012, 0.04763381495591133, 0.11233062197965, 0.03649930154243785, 0.01586674673167328, 0.030248723135540084, 0.07709006418383892, 0.016745797193218625, 0.022050381502917698, 0.06948498678543875, 0.03316979532340362, 0.05021903994342974, 0.009582376186435503, 0.04151467616940218, 0.13130717910826206, 0.018893972850374637, 0.048281492500175396, 0.02686606190587965, 0.08672732003634015, 0.03580994498465331, 0.03365331554725286, 0.04760356980466074, 0.06011051824316383, 0.028974584852074905, 0.05967872044552238, 0.026789738481203397, 0.012860756570232973, 0.041665538033891114, 0.0551611305995574, 0.015046930188433299, 0.03279899344629338, 0.016175613272935152, 0.04804605835928552, 0.014994118959763119, 0.07463143522580785, 0.053223035403437195, 0.09223864083328555, 0.035275399474607366, 0.029284025001670086, 0.04303384767544847, 0.044843734227000706, 0.03260640660300851, 0.0414946161571049, 0.05420419868201979, 0.04489959735843924, 0.02986574046043379, 0.06271426723669134, 0.03010340200196351, 0.05428553423694065, 0.05461022528188844, 0.029951678288559762, 0.04025454197319285, 0.03912502193763372, 0.022243998734460726, 0.010537596855072245, 0.055376217445178386, 0.10830897447322646, 0.04519766684801829, 0.0717901606713572, 0.03381178083439027, 0.07049934848422004, 0.0018063712852909382, 0.07559593226159773, 0.045257502145344214, 0.08321434725075962, 0.015512919447745289, 0.049988864996140046, 0.07568502828719155, 0.041415571205077634, 0.04855941004690625, 0.02186314195334431, 0.035436235803870425, 0.016275223855289723, 0.018047503150639035, 0.009756384439946664, 0.0285544277604429, 0.07095298744858274, 0.06124727014872817, 0.06942517064031094, 0.050735329578240076, 0.03254144234702953, 0.07904169615358114, 0.04715497169883982, 0.058031175586004416, 0.0075802992420992065, 0.10850693925373978, 0.022863066725192532, 0.030052966603468505, 0.04701878424854048, 0.023867980644647634, 0.05365302523357734, 0.047083901722104325, 0.06460184276464485, 0.02841031704578669, 0.04275522149738766, 0.00519728938665902, 0.021019024143536246, 0.037622225560968926, 0.05649307021690954, 0.07454297505319118, 0.046022835473019275, 0.03975669590515956, 0.04039105884129963, 0.05528096590311297, 0.046215345707511714, 0.035892835698060455, 0.11299926351996199, 0.1459314145388142, 0.04433780593136626, 0.04994295334683792, 0.05420331002002763, 0.03468081948437518, 0.017151526934016618, 0.038170637262444344, 0.047361524324984326, 0.008269707510818639, 0.01842499297532824, 0.09757325578961643, 0.06565571161768129, 0.06468982796274847, 0.0361281740779598, 0.08273181144989307, 0.02215800153452062, 0.0711623975826848, 0.044236536768655625, 0.025780542130251567, 0.05262571664887571, 0.07340992335230112, 0.03520681545318615, 0.023913719924166802, 0.053198443981067794, 0.03353397437040845, 0.03936097701831211, 0.0012571416652551101, 0.018188737205139572, 0.058084050974538254, 0.03629022082614322, 0.058968809748729395, 0.005115483166469682, 0.03608765185720498, 0.030918477418562098, 0.013554562183637774, 0.04054696539476995, 0.04353677290641973, 0.014002191188234477, 0.027688313651108937, 0.020838369119672046, 0.06185318440980008, 0.08984811709172304, 0.04795092556084837, 0.013019171104045405, 0.06908290553838015, 0.01199368006294413, 0.045763445762737144, 0.04449379675450825, 0.019412957199458635, 0.0264154355822792, 0.03070114018966354, 0.04536131855040308, 0.015106268486218348, 0.05880403572753553, 0.04711816883495739, 0.041340517571135875, 0.03014434174063706, 0.025767045576245557, 0.0452353966782891, 0.011460571925366118, 0.05609791823512605, 0.04673824285066897, 0.059294680569080584, 0.05341411305351123, 0.02322347087395047, 0.0656161584981507, 0.028168920825626102, 0.026923235047668703, 0.04368234876423113, 0.08219071588809453, 0.032929538659030394, 0.09918819211663739, 0.04494191988581612, 0.0739814326046936, 0.032190761769250516, 0.04687215885027282, 0.040884576512560736, 0.05756539412804189, 0.07025073763103255, 0.03616653976120776, 0.037648747524907517, 0.05344720422140053, 0.026072932993091887, 0.016428809162349473, 0.03297099167661321, 0.061622879227563265, 0.021028169318132346, 0.035030454352137544, 0.005557962144995409, 0.03324922331939301, 0.10908712828231436, 0.2277692473463474, 0.22557452801735173, 0.18251180648803714, 0.17852496235601364, 0.09265964445207389, 0.1333097789076067, 0.10730742176453914, 0.10294718637822137, 0.09512227238906969, 0.14067208304280235, 0.11803520377725364, 0.10391345307711633, 0.17365146338218646, 0.19053942734195342, 0.35190484756904267, 0.11172511374517796, 0.13003145885323325, 0.13668507037143554, 0.14794737491155827, 0.1580952973135056, 0.16556581902888515, 0.11174883948819292, 0.17207128446429007, 0.13590104066796843, 0.1478371501810128, 0.09007697053734334, 0.13657806321017205, 0.1472762512463716, 0.18950931487544892, 0.06346284239102276, 0.16278116603291806, 0.09053149050281895, 0.13739610721747722, 0.1510883507228667, 0.1223497266971296, 0.14278990246595877, 0.17748165785545306, 0.1933179209910093, 0.19791794189762688, 0.10159040635992443, 0.24482323788106444, 0.15933413809585958, 0.25239068504062395, 0.0912996851688912, 0.09011836992877145, 0.12136354937308258, 0.08935852562107387, 0.15622539926440487, 0.11448970289840815, 0.10430185965472653, 0.17684634113984724, 0.08176763617103139, 0.1742451968452623, 0.1738153755544655, 0.22172832230646766, 0.19576459131654234, 0.14059392675276727, 0.16627042073636286, 0.1341978586729496, 0.3082303282233977, 0.1718204979213976, 0.209447028896501, 0.2440113225771535, 0.20719828504708507, 0.09915413184752388, 0.15796432692197063, 0.12134345488682871, 0.10861888002123564, 0.11472085460780129, 0.11879158536753348, 0.15625455657080298, 0.08680639563188439, 0.20818028719194476, 0.12211063065596166, 0.12883741889269124, 0.12128952995783861, 0.17609945137894925, 0.10125739560011895, 0.1337412855918369, 0.15454020501384813, 0.20859944453883558, 0.1665839498802539, 0.18201389530253026, 0.22055888909005353, 0.22067093710985877, 0.25107460727374403, 0.10013071008987966, 0.1351805809404581, 0.1643054511758589, 0.1286341910881381, 0.08748787680580732, 0.1579451747238636, 0.35222853503880963, 0.1764342318018598, 0.10157591963727629, 0.13662654125402052, 0.11222728437954381, 0.17325711196228383, 0.13495199562561128, 0.14902139953788252, 0.07726529913563883, 0.0978529851342882, 0.15597315715445628, 0.1573139182742565, 0.18460776176183455, 0.18922102066778368, 0.21397106920278844, 0.2320896461606026, 0.1659978160093869, 0.19290529071323334, 0.09511401396124594, 0.2727390375108488, 0.19768295208773307, 0.1463358783193173, 0.10652503915010922, 0.29905660919124083, 0.08495753435718437, 0.19722087849532405, 0.13503942157953017, 0.10854663026909675, 0.15241743666270088, 0.21401544101536277, 0.12843700771730754, 0.1494812514753111, 0.10951725600828087, 0.1884978643107799, 0.32173146343519615, 0.14936495932840532, 0.11857456031946406, 0.14914241078640186, 0.07058717280385957, 0.18802670491558893, 0.203987181547188, 0.1951533757270344, 0.11153215151881019, 0.10938429378814275, 0.2086970441403889, 0.12220616182011944, 0.11297008323092615, 0.13032534550274574, 0.19412142464951163, 0.07880557253355942, 0.06917403169697331, 0.22045284719957461, 0.1496614047115849, 0.2084008439053451, 0.050834285155419386, 0.1430501884991123, 0.23286083623045878, 0.1303142219060852, 0.09842391982073746, 0.14262697088622278, 0.17363631016304418, 0.1879711482193201, 0.14200092383450078, 0.12591798804820548, 0.17011627404680177, 0.1056823960595554, 0.2059167731673487, 0.2511248166763014, 0.17829436989080522, 0.11770118178138811, 0.16051179909658048, 0.27709872131386115, 0.1189769326799339, 0.17214444586105887, 0.11106609426919492, 0.07975090971036304, 0.23313619887396214, 0.0870920928014863, 0.11571352069656696, 0.1342419240503542, 0.2506708789376482, 0.18370763909432197, 0.10704984002175832], [0.05591568890057745, 0.0249534793528578, 0.03378936893216545, 0.04739126385820489, 0.02891234595388655, 0.01917749624549141, 0.059517600663727334, 0.05214289356503756, 0.027207392380542816, 0.051972423680126674, 0.0728154084795425, 0.02029046495144646, 0.025697982749871673, 0.016829431011912324, 0.019065327566838073, 0.017015770408174685, 0.03151905013158197, 0.05611848003501373, 0.06830031608021067, 0.03259219567201311, 0.03596126650189681, 0.036484864615504785, 0.04596996008448544, 0.06902944792302386, 0.01714522586083941, 0.032531268699395086, 0.031377166817565603, 0.03605715389693937, 0.026526008882830222, 0.07051295420575528, 0.09810352652904489, 0.03897263938861509, 0.02438340651532335, 0.025864832869340337, 0.0679577675257479, 0.03633381122903478, 0.06031709768238568, 0.04540220083248231, 0.0044226720309515875, 0.02396337391297904, 0.03538265178400663, 0.021197267905658772, 0.04278766915142056, 0.023713901210876725, 0.09263976447043881, 0.0329065406995435, 0.049352215287546, 0.01783594413990936, 0.022040627288421797, 0.038546499150294455, 0.025350086901697422, 0.00969918065464064, 0.07002942249058716, 0.09397785960426254, 0.08490420697677521, 0.027255485465209332, 0.058675807930769465, 0.022850022163061846, 0.08294562658955974, 0.05602931123106711, 0.020362142052861954, 0.06310038704184756, 0.048861060997531305, 0.020760182186119983, 0.024349859525119106, 0.05216790633576532, 0.03643533703120005, 0.014375308566095849, 0.049383636383760365, 0.09371440196710248, 0.07554316412537329, 0.09636469846290928, 0.02493695292111126, 0.06854296676934728, 0.027883248553881725, 0.053694474420720534, 0.012476078925594207, 0.0387992698609108, 0.0178642108690955, 0.10100339148794452, 0.0508025193196391, 0.029349575314911145, 0.014637008989079586, 0.05538065309425997, 0.04521991021089977, 0.03188721475101287, 0.07447968086888714, 0.0077024495676009655, 0.04084451777500011, 0.030904666768507134, 0.022884130312670625, 0.008208957696033102, 0.035836003465397705, 0.0156678042314466, 0.04289419367729176, 0.015078358945526905, 0.02765414996012565, 0.02737238090635548, 0.07005177693621767, 0.07808268430732912, 0.07622564887447704, 0.023743506678710544, 0.031558589844573895, 0.01715576340023789, 0.07213287010428406, 0.06397512921642873, 0.01018460460698172, 0.06652156717234081, 0.02571283719472347, 0.04560574273308439, 0.01342541508136257, 0.04609872797323812, 0.0417205163337771, 0.006446666271996595, 0.05938533558360031, 0.033574810687212214, 0.02291757771144471, 0.010545410951899906, 0.02792486244992864, 0.0373827196627615, 0.02791388249475389, 0.10289578953938139, 0.060384398506533724, 0.02075890090406662, 0.07127900382563954, 0.05872643485124554, 0.016717310213754256, 0.007315648422997085, 0.04302331779692923, 0.06199644285164053, 0.04489725312939094, 0.027903168755132827, 0.03539627665773996, 0.00700439982709565, 0.06549563754590289, 0.04429718794962091, 0.04374300377563604, 0.021376423312411196, 0.06075566769727777, 0.03408618203754868, 0.02508832806450946, 0.06522733823306139, 0.024885705469416517, 0.026835481591162183, 0.020853551067111474, 0.03339229406969201, 0.036623469073205225, 0.03726736597356297, 0.059083163693186745, 0.021684381081872893, 0.014226617603262347, 0.029516270301575144, 0.028704952546245152, 0.06569934032496906, 0.02923315101783843, 0.01184263433735337, 0.05873894506704904, 0.04442058556202439, 0.01220051709923052, 0.04158444762710602, 0.014840706980096237, 0.02541121114195595, 0.04338312248188642, 0.02975643312017764, 0.039606952529040076, 0.026601627506616137, 0.061472530641983596, 0.05437819257138237, 0.039411052355482694, 0.03805108541142076, 0.05407880924101319, 0.074536532253748, 0.05158698569322306, 0.021748142579810757, 0.06484168191109935, 0.04352859108738842, 0.03695138917875387, 0.03622904870538943, 0.019643183857683214, 0.042314782227960326, 0.012072347716668682, 0.039727078946006876, 0.017893253262304974, 0.07427188718030531, 0.08362966649714978, 0.03123127877892506, 0.03087190118798566, 0.04638330665447059, 0.010633458394647367, 0.01878532434573337, 0.0394423738602669, 0.02732928079973546, 0.02969218707162767, 0.03679981102205573, 0.12284176964913646, 0.012113239574846963, 0.04963446506148866, 0.030970040881525607, 0.02190976989485564, 0.030701563453241706, 0.03417836922791696, 0.046148263218422095, 0.04536337549647978, 0.06981828099777622, 0.027321455211588935, 0.022472153124850125, 0.039695144570883245, 0.03719394027646031, 0.04631146292893156, 0.04762648349447597, 0.08935968241383953, 0.04813094473173542, 0.04582977748566097, 0.06970791071052514, 0.01886327379202891, 0.012444889570976938, 0.023360219483654347, 0.006961747881911335, 0.006511839765739898, 0.038375803269445896, 0.08692157695129996, 0.02675096677135556, 0.008922419210355128, 0.03789373861265279, 0.028706634109238946, 0.015524874249803684, 0.04346892049896621, 0.026646529835078026, 0.03018676385944409, 0.008139558748582439, 0.069053778875499, 0.030542630852470477, 0.01942752819177845, 0.03221680875867605, 0.03283936244946334, 0.033771978736284285, 0.05777563929798142, 0.048921244864862774, 0.027899581548427383, 0.04803619114682079, 0.023451933614729394, 0.05541037347528243, 0.04761921715051417, 0.01962208388102872, 0.060650223355379805, 0.05751649473583507, 0.06976047966388926, 0.024426552587218826, 0.04318728359536298, 0.027286454569548372, 0.05194498624111857, 0.033569065027780114, 0.11436610993358398, 0.015616710954946617, 0.02272823142007955, 0.07009986427522476, 0.012147565101904255, 0.03106635728580577, 0.01656073524857, 0.0506004597991705, 0.07334437686949968, 0.035675259066685554, 0.07763389467952714, 0.0396912528442279, 0.019975681338579427, 0.02244027237588119, 0.038877292085559144, 0.03315523199196304, 0.031001280031857953, 0.0916103491439454, 0.04458022679412558, 0.009361435471463108, 0.05434688638835665, 0.03812279890201265, 0.04380469300573872, 0.0562749496631084, 0.04308667326826723, 0.03413833730343369, 0.03339848022968058, 0.016896421570451032, 0.019797056447714567, 0.05249995182478621, 0.0314696585278838, 0.04697330160847595, 0.09727347026308698, 0.04749446356248471, 0.02347601750384896, 0.09937767630382892, 0.036744181547434106, 0.006850741262878142, 0.018768759609590617, 0.05195696019537507, 0.03484652813283667, 0.03238840479283564, 0.09304684061076372, 0.014381805949303654, 0.033656728468955524, 0.024884832129182837, 0.0761001636724799, 0.015380260789947165, 0.04770666608707078, 0.037923336419607365, 0.07425943825153575, 0.023115320326459986, 0.03236522680268653, 0.04253359609133294, 0.03731320101407267, 0.010640794644132258, 0.08855928907230978, 0.059713244197830084, 0.05317538856498657, 0.01707275585842229, 0.058513979517644456, 0.02126829574755844, 0.03734134708441073, 0.025125692087796428, 0.07069864625772161, 0.03014729309436535, 0.015807901602989484, 0.056025783396175796, 0.01688145795807002, 0.044662025832240625, 0.020123861895333377, 0.03442924004048109, 0.04095361252585727, 0.05629298337284596, 0.11136953403512317, 0.027292033604856943, 0.023316617589443926, 0.09690403968336121, 0.02937737090002385, 0.020005238925917976, 0.0262728838565489, 0.054188754349466295, 0.0575035784934317, 0.01211161929888711, 0.0457521076614578, 0.04105779282268017, 0.08014218911768929, 0.02006702583223101, 0.01669711422085041, 0.035654819840865756, 0.02777135758210094, 0.04244222095416438, 0.05501725928737752, 0.07861038865221125, 0.08018651496498816, 0.040179706674309514, 0.04839827494335271, 0.019117796928772045, 0.04746302331407224, 0.04314794498045118, 0.1933674102709178, 0.14866734434279705, 0.10982720752156551, 0.17078606471900018, 0.1710773313478116, 0.14510659831425837, 0.11667817861082093, 0.12530605233604872, 0.2198514068919805, 0.1265086035334295, 0.14949228314142074, 0.12472426984459163, 0.08239659435686567, 0.06630643436144437, 0.13193953872448014, 0.11199785636798029, 0.13649321131167874, 0.1833439924784245, 0.24790239039688344, 0.14595289564421102, 0.13396240921030123, 0.1406301780333442, 0.11865909812190842, 0.21858112586121406, 0.169753500771138, 0.1156851447998516, 0.1336575062164376, 0.2136512734596768, 0.11701485893178372, 0.10826343820700723, 0.20026043958721623, 0.14182700655393063, 0.2083656038608282, 0.11541201147220789, 0.2600700882894378, 0.12577610856462873, 0.21044951623245595, 0.21903458862535416, 0.13304812923794793, 0.11869361038289725, 0.14901605224417103, 0.19826186941035334, 0.14882416254089725, 0.13159459997569362, 0.19851630253176536, 0.0949873643056039, 0.09591348033638732, 0.15859740666083752, 0.08747020315739416, 0.13661288956720985, 0.20329070037170766, 0.16505122244838746, 0.14131339056597603, 0.1608410943299532, 0.17337481371097027, 0.12508112126060072, 0.11247804793979853, 0.12091654473014417, 0.23741731269946023, 0.15642589979594754, 0.14493562281131744, 0.15060562340001907, 0.10427413493274681, 0.26044246830767204, 0.11341434527909565, 0.15934457221338827, 0.1692758755938661, 0.16307428659450623, 0.20428912744166391, 0.14216117410650178, 0.14566846251968416, 0.18465748086812037, 0.09153940940215703, 0.18315944189746536, 0.15969605335304815, 0.08307978390685974, 0.26457606424247065, 0.15325910682159086, 0.2795716224899215, 0.2471297754034881, 0.1623448023512479, 0.1120975627113254, 0.07879118540234144, 0.21992032416164878, 0.1832666022763137, 0.16203161028604354, 0.14006330361289365, 0.1847986249072898, 0.12236194579952187, 0.11198983542741307, 0.1006255952280856, 0.07135348289363808, 0.16283949596747277, 0.21853229541692043, 0.09071838531282642, 0.10956708236687607, 0.1134299275074755, 0.10920725086884153, 0.22642198980094927, 0.1821670822438694, 0.1932754337547287, 0.13605188338025925, 0.12329445866447304, 0.09901343980022977, 0.15085478583651205, 0.11495585207857432, 0.161430093369657, 0.14682933087310485, 0.25808806561173936, 0.12906344547387094, 0.12187171847589555, 0.18021132106021528, 0.16873389903095462, 0.13671968222385453, 0.1541802509417457, 0.14448101091529095, 0.09885996940635866, 0.13361708741755257, 0.20228989842918613, 0.19367784441959476, 0.182955386717954, 0.16295908229245296, 0.11673556625722878, 0.13594430931393178, 0.14145306371633085, 0.12462716820018908, 0.15686030229253156, 0.06998574015714469, 0.14091911575486585, 0.15494033273669983, 0.1957509089862147, 0.07676451512041592, 0.22465018164967337, 0.1812685683609978, 0.1331390791963185, 0.12539745428629462, 0.15499697727782114, 0.08690729707239137, 0.1795004987187924, 0.1174322542764487, 0.2110280351893556, 0.1829558004054331, 0.08575702371496348, 0.12429747460109573, 0.09895658841536892, 0.1627773968803306, 0.1044480215698, 0.1760100642399442, 0.12329543925701611, 0.11281090548201916, 0.16682013478730956, 0.05124115828244437, 0.053942633282032706, 0.1315694876135357, 0.17142826090416602, 0.1210841954114937, 0.16504281080297886, 0.10739336916876417, 0.139268655930796, 0.2384453414068107, 0.09666489001603858, 0.11067276940711084, 0.12916502873263053, 0.11257115826611558, 0.25437897431754297, 0.1518485244483717, 0.1261347679481391, 0.17115810765854775, 0.11487545881180034, 0.23833281841249238, 0.1704309676443377, 0.1413912557425999, 0.1600530196822459, 0.1712384396382878, 0.13741484572810514, 0.19400983628246093], [0.03199429852106879, 0.04665048364850302, 0.057984405918227094, 0.0876973252443056, 0.027182222561790582, 0.10232741358659922, 0.012982423781537482, 0.06269265589634739, 0.03325768093007707, 0.04108320778956817, 0.013035519420349551, 0.04529099933983338, 0.06630970555688105, 0.04250123653741133, 0.03361934720869026, 0.007607648102191067, 0.016109741202765898, 0.03961711085491604, 0.021554621109258265, 0.05589386688605432, 0.09006497360044911, 0.043693575782761465, 0.053229432237604936, 0.0649153029606227, 0.02166083919995975, 0.04207605007855643, 0.013715667601284242, 0.05122228953686934, 0.07850365728260049, 0.039121789046593254, 0.06506311962561262, 0.007350286609688474, 0.03970586214094393, 0.06186639942649392, 0.03426530871600394, 0.056204132495387915, 0.02476804777078571, 0.024490628181205645, 0.0034597694156541224, 0.038588151350737586, 0.02847783045933372, 0.03953325104028468, 0.15477087408784898, 0.02492802033591415, 0.014978733999023755, 0.0277293280833551, 0.036605374076433723, 0.06657029036432505, 0.029665297385485425, 0.04220526612874481, 0.06040131755834145, 0.05014347303057871, 0.04619315980122455, 0.05419343514668365, 0.014097165981037243, 0.04392647417262197, 0.0011399159683928555, 0.054728474783440756, 0.030450137226932475, 0.04157373388748496, 0.036778582725673914, 0.04455248291994776, 0.04692561263518949, 0.04966359555480942, 0.016076730474108653, 0.10435933157080605, 0.013819487836782732, 0.03202193897337683, 0.048433001708960345, 0.04926155261214703, 0.02312860620628682, 0.025290885542128837, 0.01700521180135829, 0.02468659730267621, 0.05513049857390504, 0.04268243548370177, 0.005487825359112674, 0.07456542142937261, 0.048856131221738555, 0.016211048669872746, 0.11306842593776603, 0.06521760891642302, 0.017786326540273525, 0.04449821325139173, 0.012884993676937396, 0.06049614392160889, 0.026397221841879433, 0.04096470930944047, 0.01831545963913443, 0.02154720920859085, 0.1076942808445423, 0.06449207002597471, 0.049009984659571806, 0.02569432659525304, 0.03258439689694393, 0.02277379641459594, 0.03737735704729154, 0.022670671403888735, 0.01733524630957794, 0.10546850431109629, 0.03423446984661203, 0.04225057639902638, 0.04600768991475625, 0.05265324984887435, 0.017290522096558444, 0.026699148584157232, 0.017286561421989914, 0.047787905881001104, 0.05185833020556358, 0.03637856991601087, 0.01377656105755558, 0.027151824192955133, 0.029561768263398163, 0.006145913559462756, 0.05960647452382311, 0.029359289309791023, 0.050512497583704616, 0.07963512318148729, 0.02310812293041137, 0.03344138115344029, 0.0554041221978203, 0.03676869636101108, 0.028390774142838297, 0.05544279048579836, 0.06754300752354246, 0.07701327919118828, 0.04168923696382873, 0.051824534236783945, 0.05278896998553988, 0.054795668355279395, 0.0341520311250802, 0.05758325546799649, 0.04929912922483298, 0.03436348288350048, 0.062485187795133366, 0.05403124667223423, 0.015560564370976101, 0.004098178253644297, 0.0065382085120936325, 0.10184881547766347, 0.029906481016247027, 0.04478390659055403, 0.038519241741948554, 0.024422865789083224, 0.03162309444779831, 0.05752453865904001, 0.03763318444872576, 0.059102553378550284, 0.03664958118010433, 0.05666933555696761, 0.10940412014362313, 0.024133864865307848, 0.015707773911286027, 0.0968109523396819, 0.00445284536145928, 0.034917942849138094, 0.04378363324870025, 0.05477145997687213, 0.06883610265269395, 0.007955076636731504, 0.10267268175319319, 0.03998665251739083, 0.02389207985552569, 0.026581467902888695, 0.03840858417172586, 0.012237736523421782, 0.04212826280103576, 0.04116155560158434, 0.015846191635054928, 0.05415034270094288, 0.008221949589618993, 0.03090148941884118, 0.04354261432684237, 0.03737338488140414, 0.06687576792413188, 0.01929865688115599, 0.03406232605958658, 0.03127049481976898, 0.06083232245498127, 0.07745108311815609, 0.025641012621382554, 0.03726555800606166, 0.08775693454569386, 0.055382212083185875, 0.03907162943975099, 0.040602096912240794, 0.03975610601745787, 0.058892174143224, 0.014207581275953882, 0.08515832600213828, 0.08549655382070812, 0.01507915088891863, 0.03693094612249444, 0.009441094251439698, 0.07375063329574562, 0.05431567596632147, 0.11560236133875386, 0.010765703364966378, 0.05178052248553403, 0.03197014759925585, 0.003643536911113188, 0.11920631472622195, 0.0979557711510889, 0.00967316335112217, 0.05749569544869085, 0.00788561113539242, 0.021432744181384484, 0.0879314570357242, 0.04280724652832554, 0.058435003513530384, 0.013156237640237857, 0.05234514460748723, 0.022161973700408014, 0.01895980278570806, 0.029798692445300763, 0.02104886135296716, 0.019531461425245773, 0.10996602265344513, 0.06987128662125719, 0.012088370445605007, 0.00464808478418197, 0.030178693123161796, 0.009000490273108647, 0.036496505321514223, 0.06993137855803774, 0.09097726174419926, 0.052198737544277986, 0.026420229377465385, 0.03390135949537639, 0.013281035278322957, 0.03519175799503442, 0.043849842397556196, 0.028602227816478382, 0.031196925481180512, 0.019196686747994636, 0.06745845439933962, 0.02814897572651746, 0.009468067249643707, 0.033376508828012214, 0.037006922892384955, 0.041440970850207155, 0.02675560543373708, 0.04592126753601817, 0.04775245516230503, 0.04900535365806953, 0.033548606649762204, 0.02081141623127605, 0.015095624652120377, 0.02364735306811429, 0.039452865434389923, 0.02965949618467881, 0.018506265327995344, 0.03978694488684978, 0.010059817502605579, 0.05580074889885803, 0.06311286278369446, 0.07829349638233263, 0.05702789534904784, 0.026734176039275144, 0.009481133836802215, 0.0012030647156925332, 0.03875795090871473, 0.026508473130243442, 0.011744668928816194, 0.03916439119606249, 0.03037025723906775, 0.026028712482882604, 0.026063153880738446, 0.010170314194364174, 0.046341263749186075, 0.0027925669236273896, 0.037797797591455524, 0.0424310743748661, 0.018813250165793206, 0.021340940034978335, 0.08098677041069155, 0.06650413867206344, 0.037796947233859575, 0.009937744264701202, 0.005417569829601674, 0.01396717426682552, 0.029327969720226624, 0.016032310781039057, 0.07135355184155126, 0.10180611373676408, 0.02898890303537971, 0.0353993448398767, 0.011438804494607593, 0.06132511617315393, 0.048954925920453765, 0.016844976851115787, 0.03348391435499634, 0.01515382913977749, 0.10232681603801828, 0.014968827524552903, 0.032067348835088556, 0.0519326254124603, 0.02401664000635426, 0.025657728659890355, 0.017230587207802364, 0.006503191111879724, 0.026625868443760182, 0.05557078845618714, 0.004627892142912794, 0.00270591112747488, 0.03551746793692151, 0.022324277088046077, 0.030369650114387758, 0.05639085110517279, 0.02734796568420866, 0.11042997316126862, 0.19065003511646103, 0.04333137324260127, 0.09346443513828902, 0.04804717684765497, 0.1054973551823247, 0.03270154323188528, 0.03095400857649023, 0.04509203481457887, 0.024883543186250235, 0.04041820899733613, 0.021023733669050762, 0.04298466100027004, 0.01917217576485728, 0.006194288181441446, 0.041528844965561744, 0.0145723664900288, 0.03846868376938566, 0.022004896947633357, 0.03598057957846792, 0.018489461189376253, 0.030059625822750312, 0.03919228445738554, 0.03388572747128145, 0.059108984686674616, 0.09538569938271277, 0.03754900670760582, 0.03258323627373865, 0.03374349175681991, 0.07033306910025497, 0.01736709258459028, 0.03909863020864226, 0.054766771518775535, 0.030367593168311065, 0.03598015056923032, 0.04414966622848184, 0.007970668920015377, 0.0740128039051929, 0.038040620650375084, 0.03158711512843448, 0.01250450557563454, 0.06359872340615239, 0.08674526947640604, 0.11764855154099003, 0.14291596989477837, 0.18735876817616726, 0.07532991589077058, 0.18150836920305607, 0.1779194004953869, 0.18012323627068152, 0.12426292403571068, 0.0969394559281007, 0.13955364063862832, 0.19981793188039335, 0.11688770365811164, 0.1660652164249651, 0.11637084711823734, 0.15189340187897607, 0.1211497495551744, 0.12528261004556573, 0.15613000599607346, 0.21335986893503897, 0.38646267546761426, 0.16899038526800372, 0.14488579645272226, 0.17108272460679855, 0.09155408764678626, 0.20640903062397437, 0.15206800863867806, 0.19894020962378672, 0.16988759680140406, 0.06380406944381614, 0.11056306561635387, 0.21419121222870968, 0.09216094419600503, 0.227039288128576, 0.10399314920387923, 0.13761209804684887, 0.0936206404660498, 0.12572439762973978, 0.1045786702044068, 0.08993912067624832, 0.10964315489775713, 0.24757378464264257, 0.23455042782570087, 0.1201777142142096, 0.0583856099946124, 0.09660910349339248, 0.09471580145820495, 0.12037438430613089, 0.13164421182967004, 0.16791354143811812, 0.277208517035169, 0.10633588438072514, 0.16505329088578302, 0.17057379707694056, 0.14584391197610289, 0.19456589354142068, 0.10058624895229455, 0.17773982948593556, 0.10659349676702293, 0.13909490718956918, 0.0712874997407198, 0.1608469472416947, 0.08017383620984132, 0.11860112058779887, 0.2027560476093523, 0.20770488366965326, 0.08301618328738598, 0.1774871124014739, 0.08212428840418017, 0.10978417636285867, 0.09545055638638236, 0.11990625095824081, 0.07942706136213196, 0.1338711987820364, 0.12901605527487495, 0.08808224612186033, 0.09670540840635378, 0.1671919172569629, 0.14355067374004474, 0.12746915521640934, 0.2138258802193788, 0.20066003104852093, 0.13112722505484858, 0.20057573073333312, 0.12113439715317181, 0.21548254535563532, 0.1169616464645632, 0.07876204341770181, 0.1209596831411604, 0.13700445242706807, 0.23985429967363037, 0.12263152447919692, 0.1869809795771876, 0.12297456332993124, 0.08506562936330035, 0.1198006380769995, 0.08496301954672222, 0.1401700196607459, 0.07884118796115921, 0.16504526228433655, 0.24107211900334208, 0.20278964822571124, 0.09044166669369706, 0.1671435771089408, 0.15269768694716115, 0.18727998369403426, 0.13427891077533846, 0.11359360985337727, 0.20641555769308922, 0.09243872001646988, 0.10791476094915022, 0.0972034957920832, 0.14506682302922974, 0.06583784902167898, 0.11261802752532306, 0.09645267600013364, 0.15166020471482508, 0.16960820453541894, 0.12993188274483528, 0.06881548722665157, 0.14147226187971332, 0.09719028843626862, 0.16409531325822876, 0.2071037191537119, 0.16243052758997487, 0.17635699481733386, 0.11425506548895953, 0.099307065979848, 0.1658138476552502, 0.1468448058491753, 0.11360577532961486, 0.13483800174247834, 0.22352980870393016, 0.09418749190386265, 0.21599015521426357, 0.16636389878488358, 0.15063759990997855, 0.17503121837733254, 0.13656647996075694, 0.20096203823003078, 0.15097634866833687, 0.17376645317962094, 0.21166229470362588, 0.10425512829134542, 0.14845993369817734, 0.21400920505965912, 0.15657164036266266, 0.14141875829908157, 0.15967766724286542, 0.2661849101704936, 0.42125789869216185, 0.16491611518206137, 0.09708854429904493, 0.14878745160756573, 0.10610840989336853, 0.12993191338835225, 0.11419204709630822, 0.13014108603519778, 0.20708680393234377, 0.2726624900054547, 0.20956591042059086, 0.14223879413498988, 0.10982376778678549, 0.09231750958509023, 0.13598949317970585, 0.05993413798991711, 0.19617202751819166, 0.1271873038081873, 0.19912063865171326, 0.16410182500558515, 0.10303087382306976, 0.16440119684463547, 0.17755135653480408, 0.11196370416831587, 0.118847195689957, 0.20719894388269997], [0.012700151982567003, 0.06825819656613373, 0.03442543258349742, 0.04243184812366963, 0.06743115102571827, 0.017438285135393663, 0.03330384155795459, 0.0035165566406513177, 0.032204045733857545, 0.02754410526024238, 0.01675287776085879, 0.014433519757022301, 0.046532406516733675, 0.06695564025111737, 0.03694757789133057, 0.04455098138761617, 0.01426504361593435, 0.03607296595169652, 0.05815868709056128, 0.01557492851955636, 0.040961453435762275, 0.04713546326984802, 0.03723255110784404, 0.04080260893510234, 0.05142359829117214, 0.02000254421164432, 0.035987558639458114, 0.051531260457610896, 0.03146349343531315, 0.08563666364117976, 0.0643668759373888, 0.0330863913310872, 0.05816245241270912, 0.06511931983573784, 0.02474105466277369, 0.1359437577306263, 0.07550528107751762, 0.04432704622646974, 0.016561424727701855, 0.02121164546077771, 0.04260895999088403, 0.03752960553092342, 0.017823340078335137, 0.06216202892603413, 0.05909380848489462, 0.024195017833863536, 0.0025119924882141455, 0.04216083302913655, 0.040021210743655125, 0.05781762091623199, 0.044162394779343764, 0.029590686167319937, 0.0034371664702531795, 0.061340200444383014, 0.032623521007236936, 0.024729795085506576, 0.050425761108917576, 0.01978719306568946, 0.06484185811132193, 0.04361908139300443, 0.050040767453010046, 0.04688672218171339, 0.06476932490665106, 0.10976955174438416, 0.010937963022790369, 0.06804937631973336, 0.023682357540594477, 0.09187516275673144, 0.008292203682715134, 0.03693273876823726, 0.07798228082397292, 0.06211661523388279, 0.0225377953686421, 0.04736572248680938, 0.09773649380452211, 0.06203722937272922, 0.018252113743895487, 0.08211610658514885, 0.040353332841468435, 0.02781357860282785, 0.0034723449883336623, 0.07900305467868045, 0.02477118490083564, 0.09212012703139937, 0.021518758618302887, 0.07131508656687315, 0.031231598620633447, 0.06894312513571593, 0.13669561174127365, 0.062067478354419434, 0.05865628034957956, 0.04985853811846145, 0.020727786243021972, 0.011627622185305003, 0.10093366982595575, 0.03388339090311239, 0.05321737018323714, 0.06518182494947988, 0.05337217740053612, 0.021725359124942653, 0.03037269339866696, 0.04946953399227031, 0.06322865314300984, 0.026960687171066963, 0.029269025000112674, 0.02865702225526254, 0.06743327308926853, 0.014634052847301769, 0.02018570625824073, 0.044328444336931554, 0.03030355587872046, 0.03357774097352259, 0.03505152560049488, 0.02731201892358161, 0.04468789279100396, 0.034130844963534225, 0.0838558539567936, 0.023650013308431354, 0.04317898303270341, 0.029462793534020745, 0.022495995696273544, 0.04730100720940579, 0.010026100057838185, 0.0042298386031160914, 0.025974385357732256, 0.03499675031390882, 0.07800399941662628, 0.009849663305607055, 0.04064674451646786, 0.01950206471637132, 0.02358925870559629, 0.02411305600206458, 0.04328612808979327, 0.01138469666212557, 0.09665683077107515, 0.01305038822934993, 0.07646707382293479, 0.04501605804468836, 0.009938935531423458, 0.050003248296918414, 0.0684694682938918, 0.012917381959156165, 0.027916266943418214, 0.030675568174751058, 0.038615477706996665, 0.0346620311780322, 0.04531854786159051, 0.037234309279630264, 0.05348813246875521, 0.03221274849267737, 0.06347617232090523, 0.028805731412684246, 0.05900578115195517, 0.042242425223512035, 0.030029947576563687, 0.021113858167682926, 0.029414225474841176, 0.02794274677252097, 0.03549321359323879, 0.025413084226930817, 0.05748022813349963, 0.025271055356208837, 0.047322361910295103, 0.03707226636188646, 0.05687558940882164, 0.05830270778988639, 0.03416691621344897, 0.07066552061587572, 0.05015544698483521, 0.042552058810308095, 0.016861143221537915, 0.043201892892079014, 0.048118672003188444, 0.038420014203556126, 0.025099897907385905, 0.03758011753821085, 0.036465095716618726, 0.045668106120560444, 0.020433891932630253, 0.055452515971997095, 0.02223552005635875, 0.029996322062347206, 0.06350812201778736, 0.010187526274802945, 0.03516050160772378, 0.03986853325078565, 0.05008161526113268, 0.029051084476973743, 0.05468121864983151, 0.025423489616162358, 0.06011132263548433, 0.003948188771779139, 0.06844142947586314, 0.06905224669965045, 0.04646737714328113, 0.02951151289556536, 0.03214001227470656, 0.004812353666150762, 0.03507044031134537, 0.02007856311637067, 0.08075695935516589, 0.018147286102776567, 0.03180119456843503, 0.0487302668062189, 0.03440521935361528, 0.02117597832224302, 0.08357856843260028, 0.07654685421936935, 0.03536890050576579, 0.042623638235513246, 0.0427842217557613, 0.09139838793705549, 0.10785633142316535, 0.03748430292152109, 0.011019169300374006, 0.015943573859159746, 0.033723167444188754, 0.09877913180858859, 0.02546182657111316, 0.11559668462723495, 0.0810020845082979, 0.035835313986265854, 0.04264763593974133, 0.0806067678176107, 0.08208931649043676, 0.07599658858511718, 0.056527210925255096, 0.06436656950221908, 0.023037742432807724, 0.020942131898576216, 0.04135483192400106, 0.03289060607071846, 0.041886684634993156, 0.019759872455089804, 0.07325082221218655, 0.016710595453097936, 0.04541120619603223, 0.019157895885948694, 0.049119481606589216, 0.10966151802530212, 0.012106563118586858, 0.022437843877161225, 0.047126898406854564, 0.1219192082663217, 0.0708232274759681, 0.03936237512877391, 0.04353170523480062, 0.06315567560734288, 0.04290908642653977, 0.04722240275793499, 0.05560796670315247, 0.0458819710559422, 0.03949801865664702, 0.04772672226892845, 0.041081407482946114, 0.0240811484400183, 0.020196908378913518, 0.054060702752922817, 0.023112690729659893, 0.031525600183334564, 0.01569243300060231, 0.05002196765534821, 0.012410889631287466, 0.06822897031182243, 0.029015421168878678, 0.04145127856322835, 0.027185758057561134, 0.047561515408057364, 0.004561963573759121, 0.03827749886700223, 0.01483772594046088, 0.07904779421345842, 0.014772290540408465, 0.017685260390862823, 0.08550232246277795, 0.031744617060007106, 0.04311091612063108, 0.06746173325565553, 0.09196671026368296, 0.04268825392148668, 0.03256620230874227, 0.029056922066956762, 0.055942930987164866, 0.05896450816503456, 0.04472964075243762, 0.13354639282389996, 0.02425492782476208, 0.04289143959120397, 0.04604047847791545, 0.052942681697107134, 0.07083654974497135, 0.03739704933738516, 0.021846086920930013, 0.01101418781364637, 0.04555102490309266, 0.003123079039787333, 0.008640024837316766, 0.037687833330804305, 0.05500410938815725, 0.06053354816451188, 0.021510946436695034, 0.09067566058928929, 0.02070875087332341, 0.01314555167130405, 0.06066320854569636, 0.044550119538701353, 0.041652633282806606, 0.02628282767780606, 0.021691499953909267, 0.030016403142062408, 0.015009205146212012, 0.08638376024581733, 0.045750437589782866, 0.055458073939887755, 0.03414231713020033, 0.021762430119598587, 0.028377084151631402, 0.03416118204533573, 0.017546270973980427, 0.016989547218526566, 0.05076983417834967, 0.015356846270151438, 0.05439965835502071, 0.04053359333005163, 0.022285633697925557, 0.034920731409182476, 0.004382379157769104, 0.06152240679629388, 0.015136996272861239, 0.02565892184183242, 0.08857541522311588, 0.007361703234980064, 0.01735979942755113, 0.021221116222741625, 0.022303450987824512, 0.03236890402472308, 0.04175214810417064, 0.020382610006978916, 0.030993381665358623, 0.028266271448604045, 0.06452010118312414, 0.060280532305759776, 0.0151873521897341, 0.06267816534325962, 0.05981490789582172, 0.03375953746839397, 0.028931808417602897, 0.019179497650193594, 0.04866812941468051, 0.023463842451512337, 0.024603325460526734, 0.06306932983739723, 0.11382215686382786, 0.12556098341461153, 0.12310020174951324, 0.12815746989461685, 0.12445870546563981, 0.19894304414910657, 0.3127395830327465, 0.1316076387921649, 0.2501505826629939, 0.1291198908321319, 0.12246369759762481, 0.06606474894309236, 0.14537834502275915, 0.1363102235500851, 0.10407770232808206, 0.13187078999415522, 0.12231609543725369, 0.2029878351717226, 0.17509890990632196, 0.13805538716335453, 0.1500311953526351, 0.10321020734526458, 0.13078902787979574, 0.1161943557822416, 0.15757348418476122, 0.11274984061357476, 0.13981699102347897, 0.15616942888065694, 0.1283490378409624, 0.15203086869610896, 0.20319700781856814, 0.15750571604697935, 0.18200228140959818, 0.18683778242238108, 0.11092006258906857, 0.323983486140928, 0.1935461998706864, 0.16533433790168456, 0.06955130701704372, 0.1334791609476651, 0.17530504884498735, 0.30994284116933424, 0.09100617390246162, 0.19262471867184486, 0.20901389810587132, 0.12144496919767511, 0.142376521422017, 0.17013536495787485, 0.18605292534395573, 0.23216740408491707, 0.14695637889446753, 0.14881170595124846, 0.09087105131437702, 0.12251488759272522, 0.12534516878546248, 0.165318449238135, 0.1188720016169452, 0.07677463514189567, 0.2427410262246286, 0.15040112388951166, 0.19187038253632285, 0.08232757749576723, 0.12643449984851385, 0.29394744625014646, 0.11831763741229812, 0.24003204739382192, 0.1112301213546626, 0.14429886585041402, 0.1724521220932084, 0.12109822248138728, 0.22808265391617055, 0.14142995850453455, 0.12965278159226143, 0.10739617305056703, 0.21871699921546445, 0.12834094795248202, 0.15511080262161073, 0.1721660188970066, 0.10012073562510553, 0.1103661273936591, 0.053092957504333994, 0.18111623943813387, 0.06400145199750701, 0.30686166618139515, 0.10796170681715013, 0.1850466994989303, 0.13975945782036553, 0.18925665907802122, 0.24596961185095773, 0.23200389027835863, 0.16550152893027953, 0.11165345388074076, 0.1027018543813498, 0.11754379667822393, 0.1481564403060944, 0.1615542302569074, 0.15281431617275362, 0.1686994097526035, 0.18184943154694574, 0.1082809356551978, 0.13949612275727336, 0.1337343601570014, 0.17703839938246435, 0.1992175947394102, 0.0903891820100046, 0.11018122441225475, 0.13141239362378276, 0.11272075225508983, 0.09538343176245691, 0.20141545502889543, 0.07175264534570518, 0.1290246354596269, 0.09447442247502266, 0.15010840169364406, 0.1279898345350258, 0.10552878776985793, 0.15406961252372112, 0.12306144536142388, 0.18718796121256967, 0.12171299271886388, 0.09904914715838048, 0.14786273751768375, 0.13883768550811276, 0.14848927486567728, 0.14788784987984166, 0.1800883333048513, 0.18393997823999775, 0.1442202958728998, 0.19779285506135036, 0.10990606861249094, 0.18169619864033115, 0.10839205670861468, 0.15822027689747273, 0.17578435941569268, 0.20924544052010585, 0.21501297942332684, 0.18236304753490035, 0.10818833860779002, 0.11808231052371765, 0.14161052542828745, 0.19745329424979227, 0.11260072925999282, 0.13556904880510223, 0.20310831015869496, 0.126136752115863, 0.1706186745075449, 0.13544308862859203, 0.12108346762796565, 0.11327562207776694, 0.1166093226281866, 0.13472694963697465, 0.16448862279855436, 0.09789316644591671, 0.13226523334460874, 0.12950083571335963, 0.13567368109380046, 0.13028350178032153, 0.09018665134546258, 0.13778033095502085, 0.12330438716397171, 0.11291284880210316, 0.16440510389304933, 0.08861036415422156, 0.12741943611012352, 0.1562324013080328, 0.24115223647846332, 0.07530438218025431, 0.3077982546341035, 0.21623326555615474, 0.056896423169922446, 0.11715686865030758, 0.17653310310936746, 0.2064433820064991, 0.09705341150683743, 0.11511766516994085, 0.13006011054160135], [0.02484880875976336, 0.08167687773464188, 0.05186889838847903, 0.021854222774685874, 0.014850995540919324, 0.02058029325018006, 0.009420513299353903, 0.025560163532293616, 0.046911037812430056, 0.04802251647737238, 0.0604946423892773, 0.0185233490887068, 0.08090939553033921, 0.04095075118746008, 0.0295405667800937, 0.02170606328534984, 0.051767196386091174, 0.12304704290844741, 0.021875807301952474, 0.04036345286294818, 0.03773656801410741, 0.07338671854907468, 0.025771912149784547, 0.04135736384459081, 0.09134388078124293, 0.009574254696828224, 0.03323149987526479, 0.01598349278567419, 0.07460941785886403, 0.06647151864824757, 0.011339070380575234, 0.07074006097090822, 0.034567787041587215, 0.02194014145061374, 0.032834003664432995, 0.05145184395294036, 0.02392573984369876, 0.020389736539894537, 0.05928078756457376, 0.039311648616867687, 0.019657350738622972, 0.031912918916092284, 0.046966778369800705, 0.0800823423290445, 0.09979739289490447, 0.04105787709235184, 0.0247308197281053, 0.0046449998438718824, 0.04420122394578592, 0.04996961320660288, 0.0695797595225515, 0.010258877788850618, 0.06658487667840335, 0.03503351870383467, 0.04880707861194688, 0.037246390486196164, 0.0600661464305895, 0.026405284917282484, 0.12219638653820562, 0.01746289187952155, 0.02478568886046208, 0.11352882945850012, 0.019906890473418662, 0.04261737546673225, 0.02970966345240032, 0.013745961590640008, 0.03282540815792257, 0.02463256512137671, 0.04070355376649288, 0.03674993869818507, 0.030511150384441982, 0.06298097691708995, 0.03417108756219668, 0.045503056307713834, 0.026237555711920706, 0.013504259892919613, 0.04940234425087129, 0.02506245919052632, 0.10946404354106035, 0.0210837145230823, 0.022776996746899623, 0.06126988889469255, 0.010425432006858531, 0.014558883342561463, 0.04238617779206365, 0.040424238109300216, 0.03737187568819331, 0.030941370040959412, 0.012237752802790174, 0.044597490585499236, 0.07215611321190674, 0.041587270661107, 0.04029660786111509, 0.05754136578029683, 0.04912788942155819, 0.035979855625379475, 0.032078139183502045, 0.021238876056046258, 0.055208792759766506, 0.053405701408102635, 0.009046820397939413, 0.05151305820852999, 0.021443067216164163, 0.06879301786783242, 0.03717722040751288, 0.0707402907972855, 0.03573512500752846, 0.01434350346830944, 0.010679822993434725, 0.03420002270309675, 0.008575478099256514, 0.022326786025998094, 0.0696416670877126, 0.03481997935582073, 0.03708291498403396, 0.040851895201710925, 0.02425456967865748, 0.07140400639224438, 0.008995448456956975, 0.029345200952863502, 0.012946030774694538, 0.032847322102996616, 0.07345729056865939, 0.07597378214761134, 0.03579527440090333, 0.06515964670407196, 0.03622955049297983, 0.017868031732617848, 0.06631493793740388, 0.05095627699648181, 0.03583883799071755, 0.014784094040101815, 0.032505620075690175, 0.07949281468867295, 0.015444608345147104, 0.03247456287123984, 0.05498961117419024, 0.0459462036979535, 0.029656320750232668, 0.0257769147039301, 0.0159194938004798, 0.05189788332509418, 0.04621477497200813, 0.04409497521156746, 0.09123263715375816, 0.05517071435949015, 0.021756220976972294, 0.04875057196665195, 0.02364667124986168, 0.056437226237669114, 0.03871301985195568, 0.04272027256628198, 0.04605650886773102, 0.020153296908604044, 0.01119853825413532, 0.028191621926042344, 0.03343892201120335, 0.01536819203231003, 0.003658229280488506, 0.02116674504753563, 0.06519464926133234, 0.010150373883305058, 0.004900537568309735, 0.017831280579670303, 0.02204677514401415, 0.04531474806548608, 0.049291265332290245, 0.009128781272128466, 0.05919416983341498, 0.01353664434469876, 0.07029869473509251, 0.010406058600863383, 0.015110758719064537, 0.02377128119640533, 0.01795622952012045, 0.030624429890585524, 0.04219479753725952, 0.04613213706761599, 0.03227955902055387, 0.058205464419217846, 0.009739362923879056, 0.03484026153361605, 0.04801339620063382, 0.05506469545164897, 0.05921350972306344, 0.05617829618014156, 0.041321939938972076, 0.07015094701801577, 0.0985411542557901, 0.06707255292924182, 0.03430178599251855, 0.04469785576445922, 0.03498392983249599, 0.0052766110879489255, 0.03889064499807935, 0.05355465954409973, 0.06071511100256636, 0.07668030673577901, 0.046725575586841, 0.041874963489751664, 0.03154294632916008, 0.0342941174523965, 0.06454533611934993, 0.037080042154317906, 0.03440657915968088, 0.02747333597301716, 0.07439243877607007, 0.013371990982352967, 0.011188695939528126, 0.0652053821531515, 0.06310305302782405, 0.0130916899445677, 0.04440615629597057, 0.021783122154433402, 0.03434750995027923, 0.03821150805320471, 0.013633277717857592, 0.03449658299946497, 0.026365925234952764, 0.019863715673226024, 0.02023378402114876, 0.024219676288926316, 0.028702121851364934, 0.012277312625590111, 0.04083368146131116, 0.007481636693550935, 0.03783774907670675, 0.07299123331904411, 0.0877188906193741, 0.09182403404866496, 0.06854668229578004, 0.005039673499507649, 0.06869054594708067, 0.03901913709517929, 0.0749347294350305, 0.053275071925693945, 0.07268741050915373, 0.07955998527787386, 0.058073666652724634, 0.03229696836863314, 0.01862826482993701, 0.027709042075120156, 0.024231975830550638, 0.07129765040571652, 0.06860925635743527, 0.014807970127871922, 0.03268540175932069, 0.025684365537017587, 0.11273845654701996, 0.029490826606389978, 0.03627015698340632, 0.0658501294111052, 0.012172241751555235, 0.03690915092104866, 0.006287185439554554, 0.011349714214673207, 0.07980455884770041, 0.05920660344042605, 0.0161207843601944, 0.037582297058355425, 0.0669291029654203, 0.04100617381834215, 0.016897124456121557, 0.06402309781180755, 0.06431378604423615, 0.04249615354403373, 0.033531783358945, 0.010518881327082074, 0.06888091879626436, 0.026473545266555685, 0.044073379192981994, 0.06219358791807487, 0.05273683004141335, 0.01923014946852721, 0.05812530863970038, 0.05277715690974748, 0.015613484767175492, 0.051327569169863585, 0.00873250984436562, 0.021242942067704374, 0.033906266288531405, 0.032296566172472896, 0.028143695465499358, 0.09412494082484515, 0.03020588541403413, 0.05268072559227867, 0.10519495729597346, 0.04150953188899063, 0.02615829817049446, 0.06822600555155547, 0.04295090333588662, 0.07383358529618672, 0.05434480645964223, 0.08855020326952781, 0.04324947844349569, 0.025363887975653334, 0.053235484332206755, 0.0980602349004438, 0.048095589774029876, 0.02027492102746281, 0.015480571385142545, 0.07520424682767161, 0.05951955035749463, 0.013494651235129326, 0.039009928718329444, 0.049961247526469736, 0.018639777216219136, 0.049572025065220175, 0.06868599538481043, 0.046658083240711884, 0.08601819074922994, 0.023114435494907444, 0.04897480973252847, 0.060624122739799564, 0.046533789305437, 0.04583048228655131, 0.02903012622658524, 0.0637011531920683, 0.017534764333357735, 0.0482431574604444, 0.019766148630409472, 0.020342388475734382, 0.05205845918446299, 0.07023795928445555, 0.016291181466752486, 0.021981651924790877, 0.05168240577463181, 0.032386232933570305, 0.03134886369920306, 0.007539797131152404, 0.06141564095272653, 0.04074047154356395, 0.032843005197543296, 0.04644765804011015, 0.07156534450909785, 0.032304625417436325, 0.1838913776220814, 0.03481774237908183, 0.08007614467773708, 0.026904266710663517, 0.05078243249426446, 0.03407996523404314, 0.02127843492123629, 0.023058164421649232, 0.029058923471658945, 0.0515993235392436, 0.013238385248358452, 0.04022259227631073, 0.0332926030481054, 0.03844963116270881, 0.044948960233840256, 0.06401100128348317, 0.06642448084969675, 0.21436031847711534, 0.14174604638209268, 0.14807832998133477, 0.12496030153406244, 0.12572559272690167, 0.2470715067559673, 0.12385878201213577, 0.1097348556222935, 0.19897269175177623, 0.1662187557667494, 0.11681056626501585, 0.2204467951049728, 0.1494690247120396, 0.10226911429556147, 0.1406508624072998, 0.0898155736766996, 0.13714380382049468, 0.1292143494731957, 0.1217663660645485, 0.16339946027484634, 0.2654496189807692, 0.10252293454663408, 0.12003698386251928, 0.21949231083835327, 0.0858792300606447, 0.17721803167894964, 0.18243380341558688, 0.11423447304555487, 0.1839678025534076, 0.09937342451584917, 0.13216866030087396, 0.13254145400658732, 0.1848018118330548, 0.1648812581815066, 0.12403564107033516, 0.07645722959310779, 0.14484257377203436, 0.2756017242227831, 0.1529986369273355, 0.1582738724086554, 0.06596173309991438, 0.13296100971919875, 0.17207706076723916, 0.22259510482751557, 0.173341044555268, 0.13514955437952472, 0.09317571958226543, 0.1557564615241943, 0.12324388153971204, 0.14197558164596558, 0.15014016369898475, 0.1610102925089098, 0.296677875542833, 0.11901599550319296, 0.08783289982426552, 0.17175850608656484, 0.1294890379593257, 0.29031658785477765, 0.1052135042846203, 0.1441368382544287, 0.1203513173987308, 0.11961433315469373, 0.13594777203134953, 0.10721804994729259, 0.18154704132147376, 0.1415850147004089, 0.13960878364741802, 0.11184101518724235, 0.10640353760531834, 0.1958844993984507, 0.1667189345725121, 0.23575968229241911, 0.08944168446525451, 0.1883743556156274, 0.1680572748544716, 0.14053771122088357, 0.11472172028715573, 0.1775607181292388, 0.17859239341510882, 0.12983642818946994, 0.09749560511761135, 0.07175183329250544, 0.15293693620591395, 0.19308397306069253, 0.19409617439152735, 0.13607924804091454, 0.1453006790289956, 0.14992849360550606, 0.1105166789925387, 0.2234706820379342, 0.18754653632640841, 0.18821819625314207, 0.18546829300542034, 0.09911732898364145, 0.08614048902546206, 0.20180733964568187, 0.1002358633183664, 0.15451625710533512, 0.08404529983958892, 0.13035465602672872, 0.17652596316991315, 0.10544714577976735, 0.12718151218347973, 0.15216170119181757, 0.14676222157093788, 0.1341217095332761, 0.12056294152693403, 0.09710739006198223, 0.1805153966791207, 0.13938042815894852, 0.09689950444284948, 0.1517670739802622, 0.10963822129152476, 0.14486983118038024, 0.1501117571587524, 0.09473412628135375, 0.19954523522286646, 0.14064375311136246, 0.09530680764827038, 0.13444205685969324, 0.20864654362442034, 0.16124382675174745, 0.13765280795914514, 0.10206384103625052, 0.16532126844169634, 0.21630063532821595, 0.09192457542784753, 0.11713770113044208, 0.18170389016309094, 0.11406229478457283, 0.19912715039906964, 0.16903829640678822, 0.21517863827607325, 0.17270543672625097, 0.09992856246929976, 0.19142059699421932, 0.1461057914721389, 0.09271354639842626, 0.12015015803157322, 0.09946599091973998, 0.09872686929039418, 0.14025343131394158, 0.10331717620213186, 0.21558719296609202, 0.09534305126796808, 0.10892182949089235, 0.19968907589152937, 0.145053768891, 0.123528728351718, 0.10728564188485185, 0.12959448230122367, 0.17972775104065097, 0.14438422336693735, 0.14238430487532772, 0.1091847815100224, 0.13221752138868456, 0.08749199069796071, 0.18221274108415653, 0.09590725204156292, 0.2715081487211489, 0.15635044013540592, 0.18698739939399306, 0.15983543538999173, 0.11140528735854935, 0.16850462423697596, 0.11748863834767573, 0.15833805525495162, 0.12113906262863068, 0.21162754495538053, 0.23274146441009738, 0.14885218603716743, 0.13358803736346384, 0.10352576662215496, 0.10133413462749413, 0.15602149730247838], [0.037296258979627205, 0.05027192299284282, 0.023561334800756267, 0.009351564428558754, 0.02028401449112402, 0.03118339636843772, 0.06789192992953524, 0.03357085384308331, 0.02215542939431485, 0.01697241174688022, 0.032042244133809884, 0.07275301827898911, 0.052945274904730825, 0.08285422463931384, 0.03243314815805324, 0.041858377686190995, 0.048752931517458735, 0.06904301534016287, 0.046491148851571545, 0.03460797984453459, 0.023922447580844167, 0.06270846412066491, 0.0072088222500056994, 0.05563184566375229, 0.05916402810403417, 0.02925134177560047, 0.008368885253495988, 0.07812901730498961, 0.03061321436337406, 0.04895732760609639, 0.05964787008481161, 0.017905407247223684, 0.058135620183161194, 0.10281546522052058, 0.014855215727772205, 0.020052357163700848, 0.1282284249581637, 0.025437221742205085, 0.013495424983932847, 0.04537040435318505, 0.04909859038889409, 0.002436684608842517, 0.012596691808392926, 0.08154756975390258, 0.08090843792043387, 0.08207358870535128, 0.03570355452416885, 0.06739082415738414, 0.0030702730779716327, 0.06998783923805722, 0.016490546272947423, 0.02655399982036362, 0.006390917574941752, 0.09455063290173009, 0.05808328105617435, 0.04435581665846609, 0.0667278823112288, 0.07466381776236719, 0.06103598692965123, 0.06224563210121086, 0.05377745323423898, 0.020786497306319016, 0.03409715241662437, 0.0704700226384786, 0.02889787072255727, 0.06338215801083753, 0.049389087099341616, 0.07388404750775907, 0.06022795186107678, 0.03044681623578072, 0.043179120928529775, 0.04080746210210266, 0.03372900120373215, 0.08509027441182444, 0.058434436608466415, 0.02264033623730704, 0.024642685142856453, 0.07035419780520663, 0.02109125091303741, 0.08978748889339548, 0.028285314479181846, 0.03773734176291093, 0.0565128582679937, 0.09625152429385532, 0.03526200825769094, 0.03384323257412161, 0.032092309894881425, 0.029694967970792806, 0.09343310980306518, 0.07047903949334737, 0.033840601062101704, 0.016598166304550344, 0.007361833469927192, 0.011364946915437619, 0.09889823549817647, 0.04187365347940115, 0.04519263748079539, 0.08878798930034523, 0.021217670742302172, 0.009787664767504941, 0.020459548217214404, 0.01465426607718391, 0.009450327526147087, 0.022179338998431643, 0.03497951716605214, 0.014475111628041394, 0.03434897317821461, 0.04123578186056787, 0.0668943991824504, 0.025734318300120296, 0.03671321627353469, 0.09233201162949686, 0.03495490276104501, 0.056574624106888814, 0.09682242833678761, 0.047753703885621605, 0.030977075483890313, 0.04507587418981618, 0.01016548305239168, 0.02328339810182731, 0.012660330732262904, 0.03483690606850771, 0.04739789434918954, 0.006609898541242846, 0.0484057366397352, 0.028146146946857055, 0.03055449755441758, 0.031069651463880178, 0.028433169448567976, 0.05070696134240397, 0.0594760901895502, 0.022226840280176654, 0.03252874443968458, 0.032174670092401006, 0.09611873061306055, 0.024428864257530342, 0.02397441132474811, 0.032490405569513964, 0.03466800283340197, 0.07262493603892865, 0.05245144696786039, 0.03078482954973175, 0.04103407474054445, 0.07207165967913405, 0.0484051812259901, 0.09399077584666592, 0.04914195096540836, 0.037983072125503135, 0.022526667941541925, 0.05616114730195654, 0.04188975664756952, 0.013109986997029234, 0.022274554151320652, 0.0033612311169910697, 0.027582377097719622, 0.06566838271194889, 0.0461839514243747, 0.04963161904484995, 0.03507329015842369, 0.030813753199312958, 0.021234670233341957, 0.07132944305457416, 0.08065885413558253, 0.029073373805130684, 0.0916665799975876, 0.05605532374653605, 0.023877133480122974, 0.032630419628995086, 0.04027213518237395, 0.04662850075551579, 0.026308210085957285, 0.08878372219060698, 0.007799991233755024, 0.0076736034844220894, 0.04509076693906419, 0.020451770509563146, 0.014259339133728177, 0.025249409541908293, 0.013674289277274043, 0.02217566943727434, 0.034843184159047184, 0.016163752316647483, 0.049417727296390844, 0.04464500718900273, 0.016380691179825414, 0.02548941722770612, 0.03169970898588579, 0.031039936828517148, 0.07398038306423733, 0.09147573217389085, 0.0470772405876027, 0.07254922356937202, 0.0010890798101524614, 0.029773807994300322, 0.05743391428803725, 0.06484108436251841, 0.05016466685300393, 0.0728263252324635, 0.021038785381543062, 0.04835481477540828, 0.017265329295168483, 0.07619678268149015, 0.054455490842942274, 0.0915684517953665, 0.038298524150084105, 0.018652827524009253, 0.028442921747844067, 0.012673761211185446, 0.03923807353261979, 0.03374290569955784, 0.003012272561224358, 0.029354893880325462, 0.04012836729206386, 0.07644964532265741, 0.016399347336001454, 0.00885813773023866, 0.023157074033553084, 0.030217485900427547, 0.03962243899642941, 0.03324193016235386, 0.0292406261207596, 0.04650793000755291, 0.023051386458739158, 0.027568882458933422, 0.03479940606461417, 0.02021291195565174, 0.029828112136812943, 0.01785137315070437, 0.012605025887399191, 0.07570283983143107, 0.016647142305549596, 0.03140203786202737, 0.0349038238486936, 0.08748727159634714, 0.011894043625122117, 0.07629671885121254, 0.09131721326059873, 0.030050760270246578, 0.08650872450802596, 0.008394951395119631, 0.003586800439440976, 0.022062363118053447, 0.03681402195305113, 0.02276096061142462, 0.033698353856321306, 0.03215765911004236, 0.05765340230878323, 0.01906279756146814, 0.08203440330802433, 0.04692998316679751, 0.08924408740694485, 0.025309250584893653, 0.03348074275098982, 0.0316343138054494, 0.03313189695378946, 0.033904197851135846, 0.011891574906786124, 0.035797289212144194, 0.02405103352371483, 0.0805934532094867, 0.022786180225891933, 0.035649913047710736, 0.05589598511916496, 0.053545635028351704, 0.022981456037791028, 0.04349781733547007, 0.036943743621269544, 0.03101904752604183, 0.009212012894661918, 0.008098759778564977, 0.04499304093300335, 0.03163298655812058, 0.018323509307998805, 0.040937133974605994, 0.014733297622672495, 0.017746447833375107, 0.034909094533612656, 0.046672229054233724, 0.02415410490826734, 0.040607352275401354, 0.011557189976766465, 0.056071154953491305, 0.029122102742774353, 0.058691248432883335, 0.06055808213028697, 0.06343522109091282, 0.040585032303727446, 0.03020481672137976, 0.03419788148734839, 0.042947800679793285, 0.019429811133792805, 0.05905618207649358, 0.05905615909385586, 0.01778620396620564, 0.03820270187251511, 0.008318996650256939, 0.04536744725379733, 0.018871637556942242, 0.053817772441693855, 0.013540898047898327, 0.03261334352916287, 0.03254023192810916, 0.020149232812165734, 0.045611702897135294, 0.04774031266870518, 0.06373572290965146, 0.13925717993369027, 0.028221449559374202, 0.036949041119265946, 0.010630461075643619, 0.011588129395198439, 0.02086948952637613, 0.029676903617538275, 0.026464267941792647, 0.018191424258533987, 0.023039749583169337, 0.038665124034929665, 0.04627324280238921, 0.021589026117937702, 0.054899542216932586, 0.04374802931241932, 0.025855737490459316, 0.011579113497939563, 0.03762052484577702, 0.08163999060108777, 0.018026876233277783, 0.03111721211743932, 0.026034299179070422, 0.03115529243293549, 0.09023889854189851, 0.046471931535990975, 0.04907596398205046, 0.056434089107619184, 0.06952761957842497, 0.05679436110621018, 0.0069084267259665565, 0.04167938507312248, 0.019692479700390852, 0.01684337764257385, 0.08153096096770418, 0.0652622795032878, 0.053224153891806646, 0.02773436894189687, 0.05019135735628586, 0.04023075494314394, 0.030113510532124393, 0.04856029104801917, 0.055336683477845885, 0.06087761740350436, 0.05308612400004941, 0.04158756560495785, 0.05594589574743183, 0.14288114353774056, 0.13703354844643226, 0.12142187164675806, 0.0805740865067609, 0.15602947993864938, 0.10868948268433733, 0.22384709167865016, 0.12636432619464974, 0.14507656766762658, 0.11784858475889891, 0.16386571670732192, 0.15846537906796704, 0.15350094545752774, 0.19952513307573336, 0.1307254119385635, 0.2790165151799879, 0.14803599596263903, 0.14834590917152746, 0.22975778177140221, 0.08939889845468345, 0.1864092021940216, 0.1389913780674819, 0.10552009267191734, 0.26423196819040085, 0.20032358055393543, 0.16881873560768945, 0.09942426211050442, 0.1701555130702834, 0.1386355761919291, 0.11007789447302781, 0.1490390808471749, 0.06138195606669592, 0.21121591059190614, 0.19244599035911022, 0.14681335027900436, 0.17497403757466426, 0.1580390971033804, 0.12103994617298727, 0.1395814496302797, 0.11442872996051466, 0.07903732179153351, 0.18449723059611936, 0.13165197996122222, 0.19987083791244417, 0.23572431967383434, 0.19581516844130334, 0.1292290430395834, 0.14262369202990688, 0.14844370795594108, 0.16882468044998186, 0.13373796077024552, 0.08689960554963158, 0.11715156732187157, 0.3191346705200211, 0.12141179759055377, 0.16425822951620625, 0.15740295301281637, 0.20084283494901276, 0.12707841207063006, 0.14335807923588062, 0.16187725889105953, 0.14312146531958736, 0.184461944586327, 0.162146125108965, 0.13156872152561142, 0.16187627829851645, 0.14246745605862912, 0.11044051453110673, 0.1733347626342889, 0.1342979403993776, 0.2224154265657548, 0.30831809125600323, 0.13024368053001742, 0.1861100295378316, 0.24727858032190034, 0.14374326824420883, 0.14667953004039105, 0.14463286486364182, 0.09346163125648614, 0.15113552641724387, 0.12515609828575006, 0.17713538611367827, 0.23622197038944692, 0.21548107446682072, 0.1621122487009533, 0.11299952398985626, 0.12224827367331713, 0.08763581604486512, 0.1404169297987415, 0.17677725533083563, 0.1338972764149789, 0.07942804195467504, 0.14011544355702016, 0.1782045384208041, 0.19098267049318363, 0.19266432541753017, 0.23371796604366074, 0.16726667211661417, 0.11523951145429766, 0.10487120853917253, 0.071154736703442, 0.0963727730296312, 0.14008841597505156, 0.09991550833107003, 0.11489996596449807, 0.07682734965196542, 0.1284143085321111, 0.15163086354732513, 0.10083911925434105, 0.14002179696915612, 0.1092387983695634, 0.14101852332392048, 0.17135442535002388, 0.19940191549399208, 0.13577195485272717, 0.22301009465609828, 0.21218688107065617, 0.11114642624893498, 0.09574183067607303, 0.12737989831235141, 0.18267953377817908, 0.12887256700665722, 0.14184997386990056, 0.10556291698688462, 0.18025989103461468, 0.10934592810489478, 0.18221505466968785, 0.0988505618466485, 0.11046823925308644, 0.16423141643885644, 0.2667293841800382, 0.14402011709828533, 0.1683137917350377, 0.13295822115915437, 0.12740111894785397, 0.10038837610233216, 0.10551457683886252, 0.181833190482951, 0.09621804625156427, 0.11316410265862943, 0.19512300800171592, 0.12701311839684365, 0.12314221401128078, 0.17263582997745083, 0.14770717570377936, 0.14249549487665777, 0.12427345774466954, 0.15519453603173458, 0.15397248789668083, 0.14925372336179982, 0.13781871196002732, 0.17084574296830163, 0.24138973905674874, 0.14431961151140352, 0.14823496431833313, 0.18282843062714224, 0.1723905592676132, 0.23534266999171627, 0.1411858828918588, 0.16398047667837914, 0.15989960291452948, 0.18866997362384874, 0.17843392046709217, 0.1054849522188306, 0.12666746718628755, 0.16511644717426072, 0.08183571074398295, 0.1558165074956994, 0.22862317491202588, 0.10747362453971179, 0.15127150702380365, 0.18783119927731254, 0.1499632433537514, 0.21593306634214618, 0.12784774054683026, 0.136081439052378], [0.0062185990241085815, 0.02877583100099958, 0.03121767497260965, 0.01887382282274625, 0.04178193360266667, 0.020643870887016098, 0.08147886698885311, 0.006736154140408843, 0.014133782110988133, 0.026203256040330858, 0.03959297525486158, 0.014672574620964307, 0.03875696265529241, 0.03634310770599592, 0.013386714234647733, 0.09559276528776654, 0.03585397205766171, 0.04634968305547391, 0.028069231719259295, 0.019982894056386525, 0.062346441611166925, 0.03282720463410501, 0.01177510081399833, 0.03749173397438661, 0.028833881313461932, 0.081208813334665, 0.020182484858519128, 0.05258572685922827, 0.03706832483951603, 0.029785454445969195, 0.05363362022645531, 0.03530345361439451, 0.058928743350289525, 0.07767631296789454, 0.054676292704478394, 0.05340288986542052, 0.028725102573873538, 0.059200045727794214, 0.01659812416971451, 0.043454284389172836, 0.0113559233572995, 0.016967156383719657, 0.03938864045325787, 0.06598983320497698, 0.059480912713033546, 0.021950012493518092, 0.023011187910132354, 0.028540312590438034, 0.04965534478786492, 0.1240372958202516, 0.03155085044131885, 0.01949494201389532, 0.035273924755353125, 0.05761929990483388, 0.013376716787235872, 0.020424785062430367, 0.014034729815208384, 0.05440809681350666, 0.041763987993040395, 0.02233043260451767, 0.037237925214632865, 0.027400059663059733, 0.02437365613126707, 0.07596242872457351, 0.0300295741087006, 0.03556729429551671, 0.06831982067876285, 0.028925359872500264, 0.061484179008872285, 0.022454128991211617, 0.011888770067373352, 0.045177637479237975, 0.04037472201631435, 0.08572616569337346, 0.06973028813879337, 0.08249027924912591, 0.024159316221372257, 0.022971154070429267, 0.0410222003777181, 0.05785561121639706, 0.07513572792372397, 0.02385265122528278, 0.026850828247505332, 0.012657552705927482, 0.05524589056749979, 0.07089104923990465, 0.06803738704371838, 0.015027075104655759, 0.04560072102674073, 0.04390506584557795, 0.04894506636886828, 0.04910936541554909, 0.07603748235851526, 0.05775526518963518, 0.03432732353347444, 0.037870047343594414, 0.022044802467609127, 0.05415137308920103, 0.03681870275026849, 0.09357640654930184, 0.029345137750609752, 0.046802356749052004, 0.06885829621986037, 0.009004171325584814, 0.015142912386856494, 0.04573194422729073, 0.0261990214893294, 0.02444940499000011, 0.03811432980000973, 0.011521648285129379, 0.04345125068099268, 0.04198852070276776, 0.027476699099004753, 0.02639827712799513, 0.09315057657659055, 0.06476188619290629, 0.0030793734843046557, 0.03902921115138358, 0.09688711680111387, 0.04790118730236446, 0.012239120269735015, 0.04466017189946386, 0.011954188230447473, 0.023193212316161203, 0.07263889416090905, 0.06860918740952207, 0.028353048143007105, 0.028564270075050094, 0.027942930633622794, 0.028049891829610835, 0.06967546688693185, 0.028044328116060748, 0.03639508294121873, 0.02304539948161091, 0.028265490038921277, 0.015784712121521514, 0.03751606875730138, 0.02047783665118679, 0.011583341345671686, 0.05445210090387733, 0.007420215594221748, 0.04988612111417517, 0.07175547987102501, 0.1337464183809296, 0.016539240736634504, 0.0798836267823654, 0.11341003986496119, 0.06604061717347753, 0.013357418074813342, 0.03464124338220685, 0.012817964814002476, 0.01339192363253284, 0.014884128843644455, 0.05333300349452803, 0.00609071022124901, 0.05676525742596677, 0.01696288352832198, 0.034487566144596186, 0.07125431281183997, 0.018022792984641368, 0.015158094334295921, 0.009837751595994398, 0.021590788120163545, 0.009880440887965022, 0.02947394585897846, 0.02576506140852167, 0.04678216267136797, 0.016972564964465076, 0.021560278668579076, 0.038257856372623675, 0.08782494783161149, 0.08061628262963026, 0.049314761248927926, 0.03946195889805113, 0.07652996198063897, 0.02929520222448534, 0.01708330488913963, 0.04554220723108419, 0.032070304019256465, 0.02440244954590115, 0.07227774499164474, 0.025575787895509315, 0.05215044719197097, 0.05374908882884249, 0.02027017319755208, 0.0381377874122512, 0.07499672126986327, 0.02293410414319125, 0.05339858445128607, 0.05290739568731478, 0.03842572921947126, 0.01911016669304621, 0.04040610097769288, 0.04858442664807362, 0.03157283907996551, 0.01884420969403319, 0.03603086942025731, 0.02912894007749856, 0.035599845371419386, 0.0645251956678206, 0.034912453829160625, 0.1016098190279257, 0.038265727926045656, 0.020313275219391913, 0.051014618422355384, 0.04663181408578831, 0.07477238774299622, 0.006988234414283427, 0.022385077656156594, 0.01632241295620559, 0.024581919048702525, 0.05833604027547183, 0.005486477523170893, 0.04253982055571772, 0.012462222310263785, 0.023460345260137995, 0.03917870171848805, 0.08748915617264087, 0.04082448840621979, 0.055780279029521256, 0.037411930595314315, 0.0417173485602102, 0.053910204780197916, 0.003451904086696525, 0.015049322297976864, 0.09729526546453277, 0.009588025127267166, 0.02460534027176759, 0.03681914325082495, 0.01565770144694515, 0.010260015429418174, 0.046538719081229744, 0.02148839855386365, 0.03291346613437899, 0.04957634963155274, 0.07893845814490512, 0.03400831686092481, 0.07747039619472719, 0.05580099021655418, 0.05052522613456653, 0.03823250652320924, 0.04823679510023325, 0.07268231602445727, 0.036016072431999835, 0.03615825068986705, 0.016438427396238815, 0.016663237812838728, 0.077391006503134, 0.04603740646533909, 0.037177745177741015, 0.04711200182716693, 0.049784637446845734, 0.09507396288456456, 0.029303654089509964, 0.01592548748087739, 0.0860792862611913, 0.0334244889147099, 0.021052860331931905, 0.022941058306323907, 0.06270587091304122, 0.06714722351922144, 0.04884332223164459, 0.03946950869454492, 0.020543844701962608, 0.06302793427640874, 0.045209204132157954, 0.03019820729781303, 0.035787973582984946, 0.039043870243814685, 0.046150454229885535, 0.031004126048496658, 0.03560354174565404, 0.040266964088885054, 0.05375341339517505, 0.058966756633092324, 0.09843220889207818, 0.00847437747588922, 0.09991420598159875, 0.048556058412237514, 0.02748956171525342, 0.025756412275856542, 0.061288619744441206, 0.005489476278589498, 0.024652245920151476, 0.05141793690141171, 0.008482948084542108, 0.0894553744564614, 0.023797079207255475, 0.03769503455729254, 0.05402023798876232, 0.09988769933941866, 0.07309350605693556, 0.031297968647953485, 0.016281973089902632, 0.0580419467822198, 0.025223990744580666, 0.037364050100046786, 0.07976009510457516, 0.03606581452092336, 0.015906499991674098, 0.06207870154251015, 0.04726706951436016, 0.07905924722792641, 0.014559998958101197, 0.01723577170782993, 0.0458105065439257, 0.00496099004521966, 0.023395905774387143, 0.0295021953511863, 0.046445738989859826, 0.03243137466450853, 0.041477520905074575, 0.02873587568530873, 0.013795345533458937, 0.037268997740841685, 0.040698555042786945, 0.06800751727555068, 0.011866426155451807, 0.04836284337685474, 0.05454484350799073, 0.07741192836434611, 0.0216764003609217, 0.07245146308935459, 0.07220665969315075, 0.04436735011216614, 0.05674912744472104, 0.028136683845772382, 0.05854363095075373, 0.0449652549239897, 0.05250637930247092, 0.04202241243253793, 0.01655849061095186, 0.03556953893313485, 0.09104227196545371, 0.07461056699075046, 0.048093574962789015, 0.04706176944197186, 0.039173526794559536, 0.04967466552531527, 0.025474888370222142, 0.016016732383098815, 0.06974118190907663, 0.042158971435480544, 0.027070310522591876, 0.005160251429544823, 0.06090716158430423, 0.013612363517524735, 0.04159842873172414, 0.030723772342166597, 0.023993031091747746, 0.06426836469120557, 0.016930939577099298, 0.14059535167630643, 0.15104938749103777, 0.1296870716877522, 0.07501413444838217, 0.1141570368781686, 0.12517220911479768, 0.24164492294432657, 0.11109612491582671, 0.21806806145656496, 0.09768271443223762, 0.16513589048577895, 0.1096372100554647, 0.11742273946442913, 0.25093383095677824, 0.26926265308453196, 0.18268742448379918, 0.14389187397976078, 0.1180778978572738, 0.09565492566194266, 0.19860299304127696, 0.15818866810971693, 0.1448648975741479, 0.09977866204515581, 0.1611256959938234, 0.15766057305999343, 0.21504084970201218, 0.1147202647200996, 0.09162049214806288, 0.16471437358808133, 0.19972857538490527, 0.23013782266887928, 0.11218519550898384, 0.14009765499541837, 0.1359859078882202, 0.15282419870697683, 0.14721052090246833, 0.07745384869556274, 0.1302604425338007, 0.07940020998038592, 0.1240215833569246, 0.1021943977403064, 0.14146031090809455, 0.1278234632205098, 0.1989323648834421, 0.12457735716335236, 0.11807108733562693, 0.16999111060173283, 0.09627989252969142, 0.14757922369866602, 0.24097617415170516, 0.12026356968788371, 0.10544611156106957, 0.09426102868371433, 0.14256234370893048, 0.11082954930081484, 0.12296778345180136, 0.08218532262910759, 0.18174345094350078, 0.10566753395382436, 0.09078334956880539, 0.10113744921381436, 0.09446788774502855, 0.1846941611579349, 0.1717970862744316, 0.11697245596517479, 0.08826622213687628, 0.20946736087001142, 0.13296542238564263, 0.15864686529722907, 0.18359001395442795, 0.1014269078751245, 0.21965185630946393, 0.13081576434835313, 0.19725815633371954, 0.11865155215585425, 0.1982803321293285, 0.16497295890604297, 0.0662101524311208, 0.1424740597365364, 0.17649611638438317, 0.13501763403896364, 0.12036384293629278, 0.06755424603339165, 0.09142448089175648, 0.15175800349923874, 0.15829446485206006, 0.1566677537536429, 0.07856673696228574, 0.1471636056779854, 0.11798444279139081, 0.10789586922093745, 0.13069662235436902, 0.26412839310303815, 0.11865947350499131, 0.16448129899799824, 0.14281378908743783, 0.1142140414806143, 0.12653404531339485, 0.14300040810579254, 0.26715333723733503, 0.1566687190244275, 0.16199125277419246, 0.17768085603752445, 0.13558345125807872, 0.15492251353158107, 0.18174360416108565, 0.14913140976380918, 0.10053116723053879, 0.25566017976210964, 0.09642141961282301, 0.1835502539911578, 0.1343963214106137, 0.1305268266268315, 0.184801061066889, 0.23144584119079575, 0.13685892636497177, 0.18381247056588051, 0.18008212799266463, 0.17098702490329745, 0.14197637837740684, 0.11078432713064457, 0.18612395701629503, 0.14845034227736537, 0.14843365688237453, 0.12716645855576764, 0.12215857243826314, 0.2723931334912777, 0.09890568953367973, 0.16488266778328728, 0.09576878931012847, 0.14109237419982112, 0.1375185587112942, 0.11586024185582516, 0.1209139706747186, 0.06864907760773936, 0.18185988098623293, 0.19064493297088533, 0.12047569943411697, 0.16904370498753366, 0.1776730266189383, 0.11498821929337517, 0.19365003542794337, 0.18270717423048713, 0.17698273543388615, 0.18171965625257264, 0.10167541147600259, 0.25123747756644604, 0.1544243878414554, 0.15050319744454277, 0.15417292714118958, 0.1194961870750112, 0.15221220170778615, 0.08750405658276812, 0.11026610695426503, 0.19214399849935887, 0.1138024760650531, 0.17343645314535788, 0.19802799808882898, 0.10060769175329518, 0.18749356900732364, 0.12200471900042989, 0.12022340369801368, 0.07786042687873687, 0.10724567507784213, 0.0819408486507112, 0.15023897371945844, 0.14976571524335494, 0.12786440295918336, 0.06981317885220051, 0.21444812747499636, 0.16663834212287781, 0.1746808557260421, 0.1514721914164482, 0.11852831159147525, 0.10454680860763597, 0.08310159443006401], [0.05917440476496855, 0.03297375725401986, 0.05364008983897586, 0.02941896372865285, 0.008501462514452156, 0.025979596670837175, 0.026706131475587046, 0.033469297397401065, 0.0353083182727137, 0.028912527899768566, 0.011574336939731674, 0.018939735112531532, 0.03773438466352321, 0.04559799375373029, 0.05636686872270319, 0.09997845777580816, 0.11330945252050316, 0.006429392904523881, 0.07057949660285827, 0.061970736771341295, 0.039800113938268156, 0.10134487518019254, 0.02469203269649898, 0.06026194318227711, 0.03734783201868977, 0.03741730853254276, 0.023620842595494563, 0.07328335796633074, 0.07501988776869352, 0.061498719357675126, 0.031162861381627383, 0.013781905478437342, 0.04544726978506773, 0.030669473945313407, 0.05446656847432737, 0.04265385657368649, 0.023483596028639905, 0.08231519751491086, 0.0251822600201253, 0.02500559822956641, 0.006389000918716193, 0.06465700109519305, 0.030056239714124994, 0.04015374778499527, 0.0885252900902302, 0.02041774279918642, 0.021323375554094394, 0.0260455530106781, 0.023006118323293426, 0.035660013916992375, 0.04738303607389812, 0.02958233389372547, 0.05920224823057652, 0.0027167084185601843, 0.009161175300006666, 0.024779205841402856, 0.012841446366491578, 0.01298805931583047, 0.025257995472319668, 0.02128720088230987, 0.04593295803774269, 0.07308670319616795, 0.055710480758740064, 0.04351575911465672, 0.06471641887460025, 0.04230450515845611, 0.030142302031538663, 0.019511158180032528, 0.023856046910007155, 0.0184484850615263, 0.04920965015527703, 0.053257984334542874, 0.07629624387669949, 0.03170170464492854, 0.027209698305194898, 0.022636574745598822, 0.04766620898378953, 0.03473799645660385, 0.012973838808736014, 0.04378712277919535, 0.052347511819173256, 0.026347389737624797, 0.02174881099152469, 0.07375660878155502, 0.043649966227671796, 0.03785451108049001, 0.033298969238756165, 0.023120686772369572, 0.04590927059912393, 0.038085471267902085, 0.03289483870650011, 0.05904685878645509, 0.07343652958591139, 0.03983357665880073, 0.05328966590065149, 0.049676576914686355, 0.06012335021589553, 0.01386274882186685, 0.05331064521845791, 0.07245133285440745, 0.08057700530175241, 0.03761638797098591, 0.07087357477435181, 0.10653463823180045, 0.0748029699729335, 0.11062503446854892, 0.008317944236970957, 0.022954731060552503, 0.01915720066115741, 0.03675279237570302, 0.025900549803590103, 0.017803098120155837, 0.03235188538148519, 0.016688821319070075, 0.03153164461705714, 0.050709979728825634, 0.08465866813616407, 0.04590465874981977, 0.015836938250539525, 0.05875967540628007, 0.01979231053302365, 0.023323883933405724, 0.043316898011272, 0.06292930045615762, 0.08785599737518257, 0.034445044434359, 0.04737528709454402, 0.055180328762939865, 0.08632658710402828, 0.015072005203804903, 0.026662964336273652, 0.028665420494132468, 0.056159036729725144, 0.03349404586779495, 0.014013396181736984, 0.0416114867003935, 0.017913725046861558, 0.03714553118052502, 0.023305199048932523, 0.06979597251742117, 0.018577848583640113, 0.009567501631775692, 0.04259497505582629, 0.036843780638469804, 0.03404387483193028, 0.020195893312413848, 0.05683399466497283, 0.06856592642443796, 0.05626814297190117, 0.0623365399247456, 0.014634535482694066, 0.09075603853430479, 0.024202803202394037, 0.06339131276153269, 0.07592665241850961, 0.04972316655180147, 0.05388949742360462, 0.032902254437607144, 0.017512605240147923, 0.015192144069700472, 0.033925219303778106, 0.07495899143959246, 0.03709066396338805, 0.02251329587682361, 0.03524503941016813, 0.054319176988135424, 0.056861658099918604, 0.04036112778609799, 0.016159414343776244, 0.07978593525026115, 0.03379519886126922, 0.08209045796144394, 0.0693807068971857, 0.07428096532220803, 0.039249453768734975, 0.015140213842143216, 0.014724426324509326, 0.026385429833504944, 0.06313054409298686, 0.046697927473653714, 0.039775288859081846, 0.0038689262029008883, 0.03266570563878744, 0.04516005959181536, 0.05258666148649589, 0.024937586858868602, 0.053812003799624024, 0.012001758460105668, 0.0410201970577961, 0.039753095291915445, 0.03860532321156033, 0.06389359064820795, 0.07584549306381135, 0.014669619436796396, 0.05628257606839461, 0.03268097760155797, 0.034201221630698254, 0.08563860950450744, 0.0069107235533245395, 0.014167783965897417, 0.0722308833933165, 0.052941563208737684, 0.013036348710527584, 0.039740022001487595, 0.03133992345312671, 0.016617255300403606, 0.07844187995238651, 0.05599461893941607, 0.028115177842518015, 0.04582890414542729, 0.056724359822129054, 0.05153001173429432, 0.028594155164976275, 0.012774126390145432, 0.10492768454095049, 0.016703275482981436, 0.007961985313393658, 0.02707959933867378, 0.02941421398352231, 0.020564193912451307, 0.030346382108907548, 0.04329401879541336, 0.03216508633246826, 0.02189428917312574, 0.02102018285152172, 0.007154202575029265, 0.03470664430830268, 0.007224592169927013, 0.013445918467046033, 0.059276114428235646, 0.0226942535054179, 0.05192027990556052, 0.03201408848737276, 0.02617747909689863, 0.0190223787625831, 0.03632195218796692, 0.006958632298084277, 0.05969644388965061, 0.018765091963653124, 0.04624161486243529, 0.09264459848524102, 0.040320352756328164, 0.05968158561435919, 0.012011413083171413, 0.06451994030466003, 0.045384404610001275, 0.04568065847119978, 0.053624243310262124, 0.027898168116207087, 0.04722595740590365, 0.05033874501203818, 0.010150429424679568, 0.02182509611180473, 0.01721099067869927, 0.028594706748281757, 0.05219798294767257, 0.03177327640925444, 0.036265231038053194, 0.01404284747437604, 0.036346053314064784, 0.029298327863216404, 0.03475098547736003, 0.021620205896455916, 0.03872315519519391, 0.042239188502031955, 0.05488397914075083, 0.03698274515749466, 0.07790892790522307, 0.06588032093620108, 0.06382409881259646, 0.07348167514728923, 0.05425119051529516, 0.04271548068631561, 0.0370103128314499, 0.05129442437581959, 0.019574555786206357, 0.07411300054480953, 0.04157596320334462, 0.08658105852983652, 0.09146599519637325, 0.06533767021591626, 0.079076461223585, 0.00999994390088344, 0.09765197132383624, 0.06217628199186537, 0.029443344476843075, 0.03823747843383782, 0.03533618089051978, 0.029352084252863165, 0.05226881543715155, 0.035768430680036545, 0.10619737568401522, 0.019003352968983592, 0.06136316776035294, 0.05965190353773295, 0.012625228583572373, 0.02675180946807227, 0.06694809428506321, 0.04774896946224955, 0.02050325927895404, 0.01511682996586446, 0.018177163531823505, 0.001392499466272702, 0.11740560207756297, 0.06272044956624027, 0.04211647270788108, 0.06314002826148946, 0.03196247331347437, 0.04136360363073407, 0.008749707560655812, 0.010281396943384842, 0.013136110595247198, 0.02627136125679939, 0.006192965243357204, 0.06435684018558072, 0.041835655518356836, 0.03119968339770792, 0.03315641176736644, 0.033688957787930005, 0.0665453695241482, 0.031262835855745984, 0.03149056889777703, 0.04339117406597061, 0.042478027903745254, 0.024525678618961287, 0.07326799024256968, 0.036242347991754936, 0.06551846696604645, 0.06685912083353727, 0.04542699526815165, 0.05938454268259868, 0.16830606956876096, 0.0649280813071997, 0.03491429627061852, 0.08141847627778208, 0.04432397421389338, 0.012998554720393112, 0.06578590059953351, 0.07611609830130493, 0.03321643092579419, 0.06501516252155266, 0.04021866990613841, 0.06380083272233605, 0.03150387776024159, 0.03198863904652817, 0.04526307926543298, 0.04703271938788314, 0.08703929402174489, 0.08585810901657229, 0.021767658669681802, 0.04337122130598273, 0.06535382701023933, 0.2602121822776333, 0.15365964823192166, 0.24587215014523078, 0.15413347361308916, 0.17588247995703452, 0.16442338275092264, 0.11853222630076832, 0.10702166330790329, 0.2212365857896305, 0.08521138525177395, 0.13837029526550926, 0.13275123952377227, 0.14208199125864815, 0.11875779322919347, 0.17148230074634477, 0.2775665865309777, 0.16001548137395613, 0.0744285061955452, 0.15391967379518096, 0.17755498779156517, 0.11238294578487835, 0.19851021979364658, 0.08482655630477014, 0.24065847748950606, 0.2435023031167446, 0.15413163500207086, 0.056954117251500014, 0.17261839381629424, 0.14545009681774726, 0.12430101392730591, 0.14832036780013194, 0.17187754082823956, 0.12262481354898024, 0.12997464577276863, 0.14314044897835101, 0.17715737283710511, 0.13451411508985106, 0.13818101026117802, 0.22863894100150756, 0.12416095773298895, 0.18395297109119355, 0.12820570279032956, 0.15500017952534462, 0.13620196000462578, 0.33256403861507294, 0.15724808067804383, 0.08620266472139666, 0.13948653133646136, 0.10260334313516656, 0.15124774297639249, 0.14186333444330002, 0.10320591725288861, 0.14064097987307658, 0.15709550660704413, 0.10411638976825822, 0.19199888612474167, 0.11290651325496937, 0.09595242824645774, 0.12666329966797946, 0.19518579656798996, 0.16303193725405202, 0.17680897137090085, 0.19651851376458523, 0.21952267856367175, 0.26554200918443743, 0.1463539886378473, 0.14843163441025442, 0.11038944711007419, 0.08288361943296849, 0.12653669597761286, 0.19902300840664297, 0.1811327256502644, 0.2394520269045907, 0.17046472147828148, 0.15424804972304454, 0.1107802362211289, 0.17831649451005846, 0.10932376518124536, 0.11039365293277849, 0.1593091023424941, 0.14323775746649312, 0.08544811408125585, 0.10898601999806781, 0.15055541399746172, 0.11491372490361815, 0.10656785580419725, 0.10888386217336501, 0.10187012038283771, 0.17959298085301154, 0.24439363109488643, 0.1532857973248728, 0.22712619314270638, 0.1927990802834111, 0.1776711420426446, 0.1423571700410497, 0.2204405285057522, 0.15607903050559183, 0.12214414700264893, 0.1430235592828643, 0.22149938459117569, 0.24968527617954442, 0.1214428011688494, 0.1273724519377274, 0.3758377407587344, 0.20800246286296076, 0.21911038536458247, 0.14484225201510614, 0.23126694433871778, 0.09788170577056947, 0.11382411038803478, 0.12431716306074975, 0.15274403526658012, 0.16342403637545724, 0.14310271148720097, 0.1404936918087544, 0.29085588310995414, 0.13011369073102552, 0.15552429091786185, 0.09790822007362882, 0.1551092244804867, 0.07584331737410638, 0.17448130514352553, 0.18229999849873205, 0.11896281367948941, 0.17035658050689007, 0.09230983338408894, 0.12643374142146882, 0.30613725344019554, 0.3063892044367329, 0.095307742275538, 0.1905688451182458, 0.10300498771210832, 0.1968662870386916, 0.21262474628465794, 0.12879182133943806, 0.12405136885542063, 0.1306030523752974, 0.08512543018666968, 0.200478958506738, 0.1437131763105431, 0.1334551057868427, 0.13597924292327898, 0.11831449645180857, 0.1324355346901763, 0.15020221682085147, 0.13442287401806924, 0.11917334230196093, 0.1444344174477362, 0.1749208557509607, 0.11725015517684723, 0.14294068389121564, 0.2585802004942971, 0.12811374925677815, 0.19464791091459413, 0.11721529817629246, 0.19474831439795035, 0.1315965305172628, 0.14661401420110656, 0.27704966104319023, 0.15317620078642524, 0.18636466184210393, 0.12016934853407646, 0.17796873655771056, 0.08849460826886278, 0.10773645398477394, 0.18280624472085508, 0.13590038183235353, 0.11505414882013876, 0.10123900948993622, 0.1225684677821494, 0.1435241977413816, 0.1794790022916371, 0.17518774546202154, 0.12318894537466189, 0.07774690797011699, 0.07575235975485656], [0.03536523094460849, 0.02334122050313219, 0.05070947794123523, 0.03616940876048419, 0.05051989799305316, 0.024970708670274868, 0.03458416217096871, 0.06316872974557262, 0.016291911165500363, 0.07885681615481455, 0.032772161216745456, 0.03688732124564629, 0.10748660973002834, 0.012744545820169153, 0.03583297358765718, 0.008893808699212968, 0.03415139527210305, 0.0908013373132675, 0.03485920305754389, 0.09116656207028898, 0.101163120820157, 0.0911960794380115, 0.01813494634153622, 0.017224102273523327, 0.022337296752319224, 0.061717517899289254, 0.02033640532904575, 0.021643096603633418, 0.05299440412331493, 0.011709004663111222, 0.048527257336724194, 0.006771312309278837, 0.0370938393978342, 0.059765610137894276, 0.07105679236232273, 0.08973993015505614, 0.08374690093220243, 0.015432519477701958, 0.03698612360524074, 0.036745966532297676, 0.047648401269989635, 0.07664054677250885, 0.04987860579163798, 0.01208874678629781, 0.02026251806396871, 0.03453678346329159, 0.04368437889723047, 0.08005877746449364, 0.0184114198125298, 0.03576940744214001, 0.022051821748215347, 0.029878809920422016, 0.049217023751548225, 0.014642959577031435, 0.10031281685036036, 0.044093274496375554, 0.046196611027323434, 0.06531600524941761, 0.042211559541042776, 0.06625821678749015, 0.05045702132666784, 0.033513217218100064, 0.08937938619525203, 0.012039338903231247, 0.06324232781245824, 0.020181069511079022, 0.04568347384432151, 0.04951109809260215, 0.08700381648997146, 0.062229919637883865, 0.05260879376662835, 0.023635720022984093, 0.04194331385435597, 0.03703028091319627, 0.06393086848660343, 0.046419883522415356, 0.04112114829401817, 0.01176101916034015, 0.026618125210065516, 0.03807156294163677, 0.07542822029321425, 0.04760407542269077, 0.028241827498160066, 0.020384728240089554, 0.017055379069079796, 0.022182543161174944, 0.039365374362997474, 0.02048053328068026, 0.07082443023400922, 0.0689168100155169, 0.028707126320730296, 0.0520674453958148, 0.06181647347646856, 0.09536646291493409, 0.045748384474145795, 0.02958115603354189, 0.03077765130588124, 0.09059599510604337, 0.006982444225990724, 0.016338835966082352, 0.07301326600774642, 0.05659586389458949, 0.050845259364934704, 0.012936899006637114, 0.043360978710435094, 0.0418466029147948, 0.01316000008955598, 0.022606038480937, 0.06243832619680513, 0.04676561900264314, 0.04495311626082948, 0.029083654705074527, 0.009533477751838585, 0.03293074907795076, 0.06182809119984027, 0.02878962249885644, 0.03872932986386361, 0.028990038760727452, 0.04858942154133993, 0.06675069640961385, 0.041233046926678195, 0.04543298990615914, 0.007952334999572486, 0.008997324414761558, 0.02373095624329102, 0.05412888457818378, 0.011168602410884155, 0.0364368845288071, 0.008769183430910833, 0.06193742726839358, 0.018104798866495974, 0.009317013863173705, 0.021995497048802434, 0.03416654849124532, 0.04740382770016309, 0.03136949636222374, 0.038476995823364106, 0.019930520455443093, 0.004904048645027703, 0.0171159976913083, 0.06969152408982478, 0.016225140857239886, 0.03537984790220376, 0.06084580177200898, 0.03637013528796454, 0.02595432151499535, 0.051135725431865266, 0.039420988515860615, 0.024497819831594828, 0.036966768393833796, 0.02908928545131799, 0.028302821503471465, 0.07131297216420213, 0.038124036134010365, 0.05970091018224916, 0.03105408838769842, 0.02318404990458681, 0.008464800419225808, 0.03828692940935012, 0.0547040174264581, 0.07758684922009706, 0.027219253336830486, 0.009685188058703657, 0.015830253175790274, 0.0274234808861248, 0.004876899925406061, 0.040632395689646085, 0.06848653673284477, 0.009973305108536397, 0.08778901064708348, 0.06367212995105694, 0.07403610063897026, 0.04109748766847676, 0.009354135611154621, 0.035826787427668615, 0.0446681966704707, 0.007673076320169194, 0.04097276089352466, 0.04184834576482254, 0.037280255402888984, 0.06113319199592356, 0.006377406656787161, 0.053866166215870655, 0.04053157468837115, 0.054286526320802594, 0.006386921468806724, 0.029928783750942642, 0.03694158325332307, 0.0967332786850391, 0.030280937132756078, 0.03757856237972456, 0.0261274324880252, 0.018483606362414938, 0.08096882097062566, 0.01985199644320434, 0.06990784433700385, 0.05379750941609664, 0.05609775352622232, 0.061123987449513334, 0.04623298871240789, 0.0143366058041612, 0.03265044516733578, 0.0313842186569086, 0.02805562408250426, 0.06269169445600241, 0.030610123198599588, 0.0538734057467551, 0.03610331069437727, 0.04106385640860085, 0.05145764323852716, 0.012300203332767613, 0.03166916314512491, 0.04820323661871014, 0.006453881862633412, 0.04390943637718597, 0.05832924124514384, 0.01982631143032303, 0.01959995543133588, 0.014189709402290324, 0.0323437265450916, 0.04910313712072469, 0.10321874156474106, 0.010493716296379366, 0.05916266829796857, 0.05292349885548315, 0.026868666604822202, 0.03442853907003038, 0.048916184854122906, 0.06533846694735751, 0.04199839174567212, 0.019608108522070032, 0.036703429500302004, 0.07247471385785649, 0.025131906976082155, 0.025585955797484326, 0.03284338058062619, 0.060033062923579454, 0.01210821882611321, 0.12119197632156073, 0.058672743579072345, 0.07705641760220451, 0.032518172426329504, 0.03627742715780774, 0.07499555681621836, 0.01613889467872439, 0.03691022344414265, 0.002277579159483374, 0.00959743651741695, 0.05734826565810269, 0.06201354576455009, 0.04467622527191716, 0.031546029833055315, 0.08861165118193434, 0.045616353050835674, 0.05122955588083114, 0.04908327629128772, 0.09158234863031296, 0.021422530314134016, 0.06375832250341773, 0.07706341964583244, 0.018772904145260973, 0.06140299284109666, 0.11242196264286196, 0.029594886244364807, 0.01295114632680892, 0.043501954210261186, 0.07785725527473035, 0.0469991532454808, 0.0752037795140378, 0.050205043517053134, 0.12580207894526182, 0.01098456032078473, 0.07091576323634194, 0.09118756820117274, 0.04214796658244826, 0.05010161781683565, 0.06885320173516389, 0.054753288371308204, 0.06967794901180653, 0.037288448713239164, 0.05471733586502172, 0.031186868661954522, 0.02435030385611519, 0.025399798347103982, 0.06715067857575995, 0.024748788320369298, 0.052200461242107615, 0.01552335739571361, 0.0526444704812621, 0.026855317522741617, 0.02078822291936846, 0.002823937505919246, 0.01577776849209782, 0.07661918824117991, 0.02663075033905766, 0.031167831377036152, 0.06461295870042617, 0.05430219281885413, 0.04345130430714738, 0.07437582232899244, 0.012538991023546026, 0.04303560201679507, 0.016429393304391735, 0.015508873545895181, 0.04833329153517562, 0.013618747902763708, 0.08512186787782178, 0.03717007663761897, 0.002769902212387552, 0.008623181436691553, 0.04645000226915844, 0.040310117821659774, 0.02944699297058246, 0.043474225657841856, 0.021364286564470782, 0.009818874231930222, 0.044771852197065476, 0.0854665384958348, 0.05739245360957519, 0.042306148417053685, 0.048019505751829956, 0.00504897476451832, 0.04640915829147543, 0.016129136633788867, 0.11559095428956133, 0.057734163297760877, 0.06279006014548003, 0.013689561240044574, 0.014712962776332375, 0.06871170529554929, 0.040590789454478415, 0.0561343495463652, 0.0689613733500723, 0.04397831534245803, 0.0242214631890097, 0.0410211623285807, 0.06326766617055382, 0.03812236606233543, 0.017174852396091147, 0.016029802800696945, 0.011526909393949375, 0.011129180483910586, 0.0904083112254739, 0.05387457020040001, 0.030142717634237585, 0.01276320867961453, 0.030166378259778987, 0.010453942926570533, 0.05428319000789235, 0.02396130547558348, 0.03035510593514529, 0.05024134842378478, 0.09590640168396697, 0.08557604310373146, 0.1197030614580839, 0.11226054791721607, 0.15459291186303864, 0.10899125237859066, 0.20469975056907824, 0.21334339804466695, 0.15048726281571775, 0.24534184876228535, 0.09301448871772136, 0.10387571558596627, 0.17916881329109594, 0.15729704901816385, 0.1425927727212829, 0.15230546525168806, 0.10810783042782739, 0.16075441914220012, 0.2631177086262934, 0.22087336818297065, 0.1419559851168625, 0.2555517323555485, 0.09837367977466314, 0.1590120440889751, 0.11829232586727989, 0.1497641524239894, 0.06413475129633181, 0.12073280620238475, 0.12070630722108389, 0.13816562721565848, 0.15421162990312423, 0.08781000145620878, 0.11811133759516863, 0.18285703635023487, 0.1508237592755787, 0.24952916278233453, 0.14065590326584157, 0.1697946090491549, 0.11227905660146668, 0.1440558167955568, 0.1593221871242408, 0.15859193679305816, 0.15866292250012198, 0.12751722723365794, 0.12265331201976347, 0.19343318658009653, 0.12192033441557039, 0.11631070155530207, 0.1281809045242206, 0.0880387323277612, 0.16228118641001565, 0.16035118110237584, 0.2062088058840844, 0.07226146562325378, 0.219065630508046, 0.1715515857382167, 0.16772994080618506, 0.13186342022832365, 0.13528795582392525, 0.10149918827078036, 0.122008319613674, 0.1674950276050837, 0.16687431252531468, 0.10115463256595597, 0.1690642055003874, 0.1503178960974178, 0.1325415765806552, 0.21279553792649702, 0.10484471721875091, 0.1638303694104956, 0.19465203246762677, 0.11990410591205282, 0.2689209472267859, 0.165970558601041, 0.15748434219389193, 0.13569932971750537, 0.15678734007862308, 0.1307820258361678, 0.1079183539015151, 0.12840223498642445, 0.23728845671059626, 0.11006320090664011, 0.12732500045169748, 0.13759303777929277, 0.10035528876488248, 0.1576330245382363, 0.20223408126302306, 0.16085808616011374, 0.10435695669824079, 0.10891244491381992, 0.10404056238551294, 0.1814005653103513, 0.2744191602593468, 0.16219608936338656, 0.20671244740726488, 0.11338794588922493, 0.18790828304425364, 0.1709734191817622, 0.11413770847983899, 0.1687847979126438, 0.17722503372257759, 0.14949971419428626, 0.1515310422907914, 0.1852596259766048, 0.150920853259102, 0.13829132692227442, 0.08933634737566595, 0.11556679187642953, 0.18589345648163752, 0.12364711191865707, 0.2254508354610974, 0.14122925879013154, 0.13015660697654372, 0.18763555574320978, 0.17076510455339186, 0.09795534214185131, 0.09074116876769452, 0.11314752451594799, 0.11305966955279151, 0.17692682633717216, 0.1272809427351721, 0.10089088381538469, 0.12445155786530626, 0.18398111716153162, 0.13511411515214752, 0.15537174749037913, 0.14117520362619432, 0.1162213067554178, 0.10299696677154112, 0.08494693170031233, 0.15011318208229157, 0.11132582105816373, 0.1129397921144001, 0.13207794016888066, 0.10856460269180038, 0.14625030629817518, 0.1031342190840552, 0.1962304340615388, 0.14090059174885675, 0.146343125511081, 0.14889818195614124, 0.2505616501214043, 0.061883123125880964, 0.12849484735559072, 0.15936108906903576, 0.11665816073335948, 0.16978512488065228, 0.13283944688737392, 0.2867668734923486, 0.22914201561962405, 0.13073694922270315, 0.1348676646669065, 0.17510005903820838, 0.1302166835915658, 0.08921249394094752, 0.19429322752741077, 0.16945938429524823, 0.1878394577051363, 0.19074058670911098, 0.15945635976329928, 0.2816769240363952, 0.12361937187491887, 0.16405129384609962, 0.19191735904783974, 0.10632437774010244, 0.09959721412028998, 0.19046887064412718, 0.25806355079816234, 0.13359560631215572, 0.15615257494632276, 0.18811100523077673, 0.17531868521003954, 0.0861852208993608, 0.07598909624521771, 0.13592236855578038, 0.15674595600895344], [0.028359990814820896, 0.039413990302672314, 0.06775614850583576, 0.009072857811265897, 0.0456995272167748, 0.11950224683049226, 0.02906314844656135, 0.009751856860314167, 0.024442885581764485, 0.010426048707637576, 0.04502813159037502, 0.04279346077612812, 0.019369454896678368, 0.04915506639067204, 0.028993047571050066, 0.01559870118545669, 0.05525731293845081, 0.06960492551086411, 0.040835765220465205, 0.11508084698429993, 0.02438646895180066, 0.03428086030086683, 0.04975688591178867, 0.02536815508539158, 0.03246504805922028, 0.12279516085982324, 0.06278803767335993, 0.011536670311714613, 0.04955426714713535, 0.033428947546429215, 0.059287337616326354, 0.04437535573097487, 0.054731274834804, 0.059078685909269325, 0.042048907583399166, 0.029055541193473245, 0.03642288044155125, 0.05031894930007477, 0.11844926663944799, 0.003949474602479548, 0.05132398770881757, 0.02965209769055007, 0.05622968152766267, 0.05287094139343789, 0.04186948213065344, 0.03210366714835888, 0.02146362327039242, 0.020966752049242778, 0.009879723638145915, 0.011546482940414741, 0.021275688496027744, 0.046523611827362935, 0.01689590637632195, 0.08572061155592242, 0.03436253676491399, 0.06480104094671627, 0.07570362124111384, 0.039749935179227786, 0.026568720199828668, 0.10011116718693126, 0.07047977493775469, 0.04720988105081263, 0.029103385299564372, 0.06822232066863967, 0.018581485586060632, 0.03416170298512425, 0.03690041751871186, 0.028212967050832607, 0.01740473622996961, 0.04588453362004892, 0.03812695492900187, 0.04057519573477968, 0.01775916489291816, 0.029591705064259233, 0.07854514860457952, 0.017627464802635294, 0.04559140539758148, 0.029230381609992157, 0.018685575867552432, 0.03556881498004641, 0.07730803918093443, 0.010078599105679221, 0.06681140887761308, 0.07168454779011589, 0.09754728540898332, 0.018688919841341915, 0.03393489882470139, 0.03461717673006558, 0.03808810661036161, 0.005707180272081808, 0.055512573434821064, 0.0011141405810767245, 0.04632857733315999, 0.10499418863365728, 0.06067376140685332, 0.025343132738564766, 0.020839468455843387, 0.06807153158250355, 0.017054341019942396, 0.05220557104856257, 0.021366094531972083, 0.049620035795434836, 0.09427877894091992, 0.12485674176845821, 0.043305582892630375, 0.029318167625235456, 0.022940753786374005, 0.02513992408620975, 0.021024229710981734, 0.054231601647071304, 0.06825055866952866, 0.024675655651897676, 0.0544458496264152, 0.046639654995693315, 0.012575770904790732, 0.015312236970320586, 0.02861672603044539, 0.05912825562840989, 0.03284876617873388, 0.054619789889623085, 0.10009587607196263, 0.007126994004788539, 0.04817006118114918, 0.029376353918304367, 0.010724311634417503, 0.051833217843405666, 0.02840411173360002, 0.05842381862983589, 0.023335582096009486, 0.02836136785786479, 0.029116759279502497, 0.11227237631476696, 0.05447772271450489, 0.005218183477183865, 0.054833482455221884, 0.010804924193859823, 0.032826978638167345, 0.03833426598219141, 0.026123759096428275, 0.058550380185366645, 0.020459735908755855, 0.05328523025156991, 0.057698157165319695, 0.030092981290973486, 0.024431574293562484, 0.016217920478553544, 0.03670080181872172, 0.10782941109350613, 0.024234419651029092, 0.02621949135866617, 0.03813311044547347, 0.06822014497893472, 0.03467566754308439, 0.0471689987687334, 0.020238005165611545, 0.004316749362905901, 0.011495965187467877, 0.016019071824097588, 0.0675409927123016, 0.029827137289929296, 0.002228467656682516, 0.04055881294451895, 0.003349937305169841, 0.030665149378980842, 0.028002522698032762, 0.03550313826229784, 0.05818607090341468, 0.04625887099292971, 0.04678930644126189, 0.10055586590521759, 0.02938484983338464, 0.02786048233599192, 0.016344926365080382, 0.03476093695949643, 0.07523328922088109, 0.004901623976747356, 0.030891175960160555, 0.10173722711061278, 0.00642860527037673, 0.01452719220035379, 0.031733596885216334, 0.023097382377712958, 0.07346136615641656, 0.03184432723379183, 0.010651642449140068, 0.05206231260672212, 0.031571101975597204, 0.07251756881634075, 0.020055703052710143, 0.03557197509273406, 0.09616849568462181, 0.047392972234276035, 0.04945491703467504, 0.04649036744188878, 0.03170285952247439, 0.038845147036256335, 0.08852319867019692, 0.04751411371774251, 0.03553647840876253, 0.0525740095444264, 0.01145218900825468, 0.07995203843400364, 0.024793761511964184, 0.08268367048473128, 0.023787683138864178, 0.04543972381901357, 0.03830474095358964, 0.029982406075202653, 0.011494725082640447, 0.018512907310298855, 0.05513959969844549, 0.003847723283181568, 0.010104184527130378, 0.030929307986591614, 0.024027911074940237, 0.015970630169425522, 0.04780726109240805, 0.04104779537526831, 0.007158643490965328, 0.013685586201327463, 0.034008232591253136, 0.08186153556791045, 0.025850265707460143, 0.019407098542057702, 0.04125890239412266, 0.029816561446134603, 0.06282821515454881, 0.024408036242088964, 0.010072670542755196, 0.06320789599070145, 0.060277755237034256, 0.06660555339147968, 0.05238539486702892, 0.03136463936478381, 0.03195185916528347, 0.057228652520045165, 0.05378866493101082, 0.06345957119558608, 0.033961991524143566, 0.05264892528254179, 0.01290280043312739, 0.05562173330315179, 0.011805329685880533, 0.020792126137342666, 0.06486657976863847, 0.037996038163621584, 0.04099099378612253, 0.03363604026456033, 0.025348154444908424, 0.0216162471371072, 0.07218400647322978, 0.03974466832474836, 0.03392685107105682, 0.01614343374967575, 0.044036438433273185, 0.03972592981412046, 0.03144918674332721, 0.05461094923497689, 0.038354816290760235, 0.036791828385884726, 0.06953644491131268, 0.050867452932101105, 0.11067489147066109, 0.025436032390702638, 0.06476493522284493, 0.03921179671681697, 0.014634243411672933, 0.03091310331177327, 0.026465985893962846, 0.11216417405634158, 0.011647690816091434, 0.046945718612762234, 0.03568545569695773, 0.012997968663131038, 0.04521080142548008, 0.019816218221920635, 0.04541405604311055, 0.017386200732641646, 0.06917527275941066, 0.029085606314061634, 0.08714535889486152, 0.09001354611809216, 0.005287387072213836, 0.08732175830030635, 0.04300721462876086, 0.04188621349091973, 0.010562501415880698, 0.13215790442641706, 0.03275198629125953, 0.03890376042334303, 0.0039159939267612515, 0.024273112836864688, 0.025396174751222137, 0.03320692377465387, 0.026404988058211825, 0.044164953513010856, 0.05170244280429137, 0.02340220301712473, 0.03427752398795659, 0.06629662843601358, 0.02670890088343332, 0.024590336439770558, 0.04518800264885349, 0.03622815238251802, 0.06385815525127035, 0.004106718218780213, 0.04711508533106216, 0.027546748263581146, 0.07313708879894788, 0.035007019722533804, 0.05940030494164075, 0.04818313830201665, 0.04301034026749192, 0.025884871814219702, 0.0663980201727921, 0.014344557796815231, 0.09238379917317822, 0.06728175621960433, 0.041941735713231953, 0.07753607291247576, 0.07878724771041064, 0.03950985854551677, 0.03794571767831522, 0.0437114256313972, 0.054915844567961274, 0.04955901689226589, 0.11741372260956034, 0.014632563763898949, 0.044272971910334406, 0.018741517523003202, 0.018721292801802198, 0.0264160082330026, 0.05205768926609909, 0.07390303882740198, 0.04555789671177345, 0.008873349363585154, 0.032705572854366996, 0.04482342906656765, 0.01623850143063934, 0.06177241575994319, 0.018857028260226213, 0.035444168644326354, 0.04130460336924561, 0.056954044473147204, 0.07167440478599842, 0.051212368698249904, 0.04520576822781756, 0.020834209262243202, 0.030901378336092158, 0.026757777293002414, 0.0829973222026902, 0.024786278748163776, 0.21874797981112235, 0.21078221289621246, 0.10685182927596955, 0.10825368590773114, 0.11484567331330431, 0.17959737819769692, 0.1364808006873054, 0.09207551007068927, 0.1457762970559059, 0.1138917099864733, 0.12101862594605454, 0.18860824225891024, 0.08640634451782511, 0.1156164343739229, 0.11663930730954294, 0.1381833851337433, 0.12973813910878476, 0.16197827524475514, 0.2226178423171082, 0.16699420528546458, 0.15238912205301947, 0.1272080647909353, 0.10473465336666954, 0.09430857210029518, 0.08338926810651057, 0.25548109904892985, 0.11583466218003344, 0.10433197457103, 0.1413563374550112, 0.12466993122812241, 0.12728511791435942, 0.18123686764269106, 0.17810905322192178, 0.08982373251309318, 0.12050373825214564, 0.08322970731364143, 0.2607425602693712, 0.1529169566328487, 0.20600131863067228, 0.12593848090017998, 0.13132369596390955, 0.11331383454343004, 0.12611625160300924, 0.19389123055002383, 0.09295425122423519, 0.1596389491591723, 0.13165279201442195, 0.08810082375402413, 0.19217114865539536, 0.11589977965359727, 0.17024350592926626, 0.16787273959527094, 0.1235343667588407, 0.22932196967303756, 0.09804608525648233, 0.1542357157074636, 0.1622348993776306, 0.10720642839348125, 0.08371693157260457, 0.358423734864881, 0.15292274825755628, 0.1441118025010632, 0.10396355522736427, 0.1725193080041678, 0.14062227200596564, 0.27710871110039376, 0.11052701351863724, 0.12292737231379557, 0.18691428396249973, 0.12466972438438285, 0.08169666578572604, 0.10399557770259919, 0.08262778437065502, 0.08327892080189721, 0.11641417705123464, 0.12260272723412323, 0.10852019257482984, 0.10927413034463122, 0.09544119479194765, 0.1350764542697899, 0.16499963408756643, 0.16365144191490066, 0.11613025720561705, 0.17938825151612683, 0.2225980619269033, 0.192339779929288, 0.1477454341347179, 0.21392147267057052, 0.21459356160654178, 0.11110618365027251, 0.1279589994960735, 0.1321622404840685, 0.14867574066644715, 0.2588668093085289, 0.15338091480155147, 0.10015305687463093, 0.07413276561325596, 0.2189857888245775, 0.194933416562215, 0.14877415232120023, 0.10690428331614503, 0.1242377810300358, 0.33406253723848256, 0.19941884603711868, 0.21614821447480112, 0.17085489005811755, 0.06960795155816502, 0.1893188500957143, 0.10122231643406615, 0.1445081763930859, 0.15738075178477073, 0.19515840126381767, 0.1981247703154241, 0.10633184709736418, 0.08090459981993323, 0.08238245237378344, 0.12985827701707042, 0.09114781589878183, 0.1611065284739579, 0.2049300978861509, 0.1907944426901879, 0.114179766706882, 0.17637725018205183, 0.16601471590899652, 0.08620482508934314, 0.14607021434893533, 0.10802389017396397, 0.15811697760176274, 0.24803078673299284, 0.08648455443401491, 0.11949436378575141, 0.2095181371776327, 0.21046641613206557, 0.10746342024856037, 0.15724486310876187, 0.11722809950550718, 0.11019910490440746, 0.12250617717302616, 0.13866053533650216, 0.08275552187114954, 0.14213036205018723, 0.2571005782773418, 0.10716190336332207, 0.12533276582196837, 0.12672678537426457, 0.1615983415995875, 0.15735769253824988, 0.16971691241187437, 0.10504599915997637, 0.09734621797237666, 0.18876643941527416, 0.18148164805625716, 0.1020270764767643, 0.0954723439269489, 0.1573712063292342, 0.16119590029120445, 0.14481456559752265, 0.1713575816322719, 0.1551984277583899, 0.08313422211475911, 0.17850332803303198, 0.23704467221133171, 0.08070559315984288, 0.13649083643911347, 0.10691415052860977, 0.2303072966394886, 0.1447607555817212, 0.1945993102966778, 0.18467441141124696, 0.23569810414506545, 0.12124639920770161, 0.17041624343443304, 0.13324824672552849, 0.10770052446112519, 0.1623763192084528, 0.15906701855842145], [0.031969737742216356, 0.04394048209031744, 0.03257521916361105, 0.019601826601090933, 0.04483677431820862, 0.018424523746474616, 0.03523612980760875, 0.05120131787994216, 0.035167676021134665, 0.026291859854433327, 0.011340353577848405, 0.059870901262207385, 0.053941955294219725, 0.08607613763982251, 0.05312645852926278, 0.03314152284855804, 0.02158627203184991, 0.005463246864476992, 0.02062522047649949, 0.0461238518267149, 0.02444645363627182, 0.04947316141859178, 0.030364982723709077, 0.050192671197076, 0.03685201608365582, 0.043536474132129264, 0.04391582172003485, 0.01813950264946588, 0.055676738416115125, 0.039920918343047944, 0.030496684729211757, 0.0212348751618617, 0.030357542094744505, 0.015066895397349954, 0.04984794695290828, 0.06555476421189886, 0.04152674971508884, 0.08749091051398747, 0.03417520145435007, 0.03211056385489722, 0.005850919434094742, 0.011359532589032766, 0.0365264785115517, 0.06165519281620942, 0.07891182126777788, 0.03265370104101396, 0.042748809341461434, 0.030661600476671613, 0.08033391028161972, 0.08065234238822615, 0.011070074885332537, 0.020919158836946856, 0.015120251506056278, 0.02718755070330395, 0.041406588824165445, 0.001354006899712277, 0.03820009334313293, 0.05543126469297756, 0.03498825056838893, 0.109967754012154, 0.04379703978737516, 0.05222684531021984, 0.02605071835850756, 0.0462017055120199, 0.06859724409878254, 0.057232712786043846, 0.046224668997550206, 0.06219399011423511, 0.036159143182298834, 0.05850533421541895, 0.018182493588556687, 0.010573547446138917, 0.026211933901293144, 0.04048226160868522, 0.03378544273155351, 0.06311398893294316, 0.01874462400953616, 0.031187108064430858, 0.05382624920457602, 0.04091361507533058, 0.03494482870484072, 0.029072416195225333, 0.04085529663209473, 0.017874895880419402, 0.042440937756891214, 0.040695578791201115, 0.02488648304865966, 0.07807806479714571, 0.0404188831547095, 0.07693247223693518, 0.03513638515986743, 0.015121949348418463, 0.03797480220636053, 0.02235577479305287, 0.0955173745751381, 0.004921280835274487, 0.09468313546911364, 0.04945255748386826, 0.06392246450207408, 0.051686546479862545, 0.012965962467264506, 0.02848384616475913, 0.06300104459026648, 0.07505707367653809, 0.036594893993629564, 0.028872869443148378, 0.04943170074012972, 0.04349977085967699, 0.03587366051731571, 0.011655249231074367, 0.018664251810180086, 0.0249745448555557, 0.04850954538391483, 0.030087892551936453, 0.05247452536657934, 0.025162098501178048, 0.027610052023984255, 0.0420184517579694, 0.059647134640404297, 0.027829055494118123, 0.03211675767576502, 0.04207398547160049, 0.021418843515998414, 0.05991554120555521, 0.051000495591471275, 0.048649620730429895, 0.04528503534534285, 0.013119207822807856, 0.06398626430440815, 0.049076527056674805, 0.06580644707766271, 0.0491365002498271, 0.021257085966006405, 0.026051545733465784, 0.041193647024732445, 0.011585224006745604, 0.07089306405114551, 0.026479827187534784, 0.034110398076835184, 0.052663603527171, 0.01669601296945926, 0.0629449401411318, 0.06417298291419303, 0.05849324917841343, 0.0268101777070232, 0.08579304516916314, 0.06367290753030008, 0.06091604437378626, 0.019356801039389065, 0.02573747075192871, 0.038402903629767324, 0.03679902961237296, 0.022741226186495156, 0.017097686274698185, 0.044686272515044104, 0.04221790274905582, 0.019830459796433008, 0.040796415114234534, 0.0520321517251432, 0.02280228722449993, 0.00116670761922104, 0.08774879869193801, 0.046704653725628896, 0.026702218681513786, 0.026161645974723563, 0.03323730682173083, 0.03853149531829742, 0.035104040927704305, 0.04477027788638108, 0.021184682996282657, 0.0388975627720356, 0.01745999032150834, 0.11013381889150028, 0.0436951577543251, 0.0482692504151454, 0.013703360398780676, 0.05862433448313706, 0.028541687718262116, 0.0407837555112858, 0.0160906100720768, 0.017676691697429747, 0.07117406510177159, 0.06809214700854595, 0.045583606622512304, 0.037758937781496395, 0.021227884609552643, 0.028906180861315904, 0.08302670167458635, 0.0070543607298825545, 0.01187865770677285, 0.01586060270652055, 0.06920151127081725, 0.04657250738913014, 0.05241436831232521, 0.07283403207698176, 0.025759235309857516, 0.032956393871216044, 0.06519428920000792, 0.04504911090818144, 0.0392663000421899, 0.05899420556341929, 0.07097407784913817, 0.0017007947932260353, 0.01990589838955672, 0.04878501911016722, 0.009340643845198136, 0.031187778391364603, 0.011804983988704701, 0.011535079721661826, 0.05107033982752793, 0.03887090291227064, 0.02805078432204262, 0.021647467135241436, 0.06765452694267997, 0.03757075977421576, 0.011470862401409015, 0.06273446514481498, 0.005909091363015075, 0.03914702398281905, 0.011758741963985226, 0.041110093645270795, 0.021983584381579872, 0.07365247445000757, 0.003595407197867791, 0.0670176244250709, 0.015958421600742206, 0.01513298580257763, 0.019007455369818117, 0.0430225248959276, 0.07527656552772369, 0.07383488764565799, 0.030049938640947786, 0.054423901207384565, 0.09227173583161447, 0.021660645762758873, 0.046843813597074443, 0.043461075758621584, 0.04173540525258549, 0.034919440551030065, 0.09231649834903018, 0.01917842704231941, 0.03629964753805149, 0.0369383312100845, 0.02785793892408331, 0.027232412812149814, 0.034014997147624536, 0.05551833058557203, 0.0457136653694174, 0.01658613297847971, 0.057174723760615435, 0.03733057205775573, 0.02585967901282974, 0.03373339854841752, 0.014013761988720827, 0.05385614578582106, 0.015480004480078578, 0.022603016264075716, 0.019336719959673863, 0.03692996169951174, 0.052511864492008765, 0.036343372006329804, 0.02065826759433314, 0.06552840312642437, 0.06749695031753472, 0.013096857207616972, 0.0221046645780124, 0.03290158028023378, 0.05050624247580286, 0.05475259506173673, 0.05273856523056185, 0.01965910124952995, 0.0366069445566785, 0.09710175165485951, 0.019650915600059014, 0.021156711210947365, 0.07176550796195384, 0.03815685534068654, 0.024347249080517122, 0.042874126004115234, 0.023128311262435974, 0.015211618024735682, 0.0498558261672095, 0.038934779323397145, 0.08355099692820542, 0.024003043860918092, 0.08982763956150702, 0.03592769652905484, 0.04004635757976963, 0.012806873776078706, 0.0593083935429252, 0.055663622990851445, 0.03268676922626553, 0.018213514403830615, 0.07903518440622477, 0.034837266129832116, 0.07773242124746885, 0.03638297492157548, 0.044156721898264466, 0.06862886820829685, 0.018905263071158723, 0.005438332727569486, 0.05582619833970263, 0.029640778741468827, 0.010914424971316852, 0.06238020693642959, 0.013488894084378356, 0.10945128817712108, 0.02183438492788663, 0.04489028172927999, 0.03156500200050012, 0.022708914513068817, 0.02861284771032872, 0.025736290976525317, 0.014828346151437972, 0.05987397710522337, 0.09257401114389782, 0.06840320934932079, 0.050850254258201014, 0.023709666659875263, 0.04883793280309728, 0.05726336013345469, 0.021151103447341633, 0.03856338755858522, 0.08689567551858003, 0.010503715659011035, 0.03338619217937512, 0.03161957810422586, 0.07692432872230008, 0.03219070814309582, 0.023484940512947017, 0.05865105179949634, 0.020842906275403597, 0.08326870118898731, 0.008065369836385212, 0.023298595371025226, 0.025805365294218067, 0.028842834966076963, 0.03676272087520169, 0.050987023935322805, 0.05296351545820794, 0.011712963422459942, 0.012588415185980981, 0.0498644523172369, 0.06377404262762397, 0.020875972545435353, 0.06915284170498771, 0.026654753788945176, 0.012832825004513706, 0.09219357188070014, 0.01229903600629299, 0.07743946922522399, 0.027680549349996354, 0.11599776229911274, 0.11528802780254234, 0.14160245086156553, 0.08572112483483169, 0.1422400505191857, 0.20647134421573532, 0.34610482653783214, 0.13045646911186556, 0.0862050855592374, 0.10704613981708404, 0.11490046392164885, 0.19578968835694177, 0.15281659911476797, 0.18535537164538138, 0.12383812062081792, 0.15653980174852958, 0.11188858924734016, 0.13070671939321105, 0.12456467074732627, 0.15640179866984968, 0.26598330647234, 0.1914362711531501, 0.15527842265944328, 0.14071340582543804, 0.18087879814688237, 0.1607595519312928, 0.09826527833337746, 0.14464476986998512, 0.143380050637549, 0.11114642624893498, 0.21193307614134205, 0.09727899375702105, 0.16749847500074297, 0.17144860819943492, 0.13371954401654582, 0.13541400793098635, 0.10757731454026316, 0.23228921206487765, 0.20341183419429487, 0.09746534464460227, 0.19196543872596758, 0.10547130819289915, 0.13676618376085836, 0.17735399696375095, 0.24218922841452786, 0.09371254037344649, 0.1416028339055277, 0.13988071421702064, 0.2361726036836063, 0.18261001895992987, 0.12546915245512802, 0.07129797216264472, 0.06974306648537036, 0.2319666584052386, 0.2225550231073172, 0.1546884583489549, 0.13897132188562425, 0.193519999663676, 0.13824179167709044, 0.20464382615060578, 0.15846185506351534, 0.12342533712545711, 0.06423825360534173, 0.1980637743948929, 0.1685816467168831, 0.1062575442295882, 0.135729544225239, 0.20867312687539286, 0.1554958384123541, 0.161834710367745, 0.26246178414552446, 0.14626809485977696, 0.08653042777892082, 0.14791639431590034, 0.12172259946143436, 0.16186720781749295, 0.10668089973830408, 0.12803850410085532, 0.1372187425412478, 0.09098690679116596, 0.1343827769761124, 0.11478371978286775, 0.14796534733426187, 0.16332242247318068, 0.1416889728317338, 0.11826437897980215, 0.20473915813190324, 0.17875098893719335, 0.12297630234951935, 0.12172458362915825, 0.1253334553011002, 0.18997218519929918, 0.20491840738442638, 0.16571784151657937, 0.2563354096585705, 0.08562750122960537, 0.2874426243285979, 0.11874468546480903, 0.15442523053817211, 0.258779444641644, 0.10984763142562683, 0.09808943817211736, 0.13854074982866166, 0.12778318231745114, 0.13497180665933317, 0.18925365601335803, 0.17488739303042813, 0.18877325759780025, 0.13679485077098494, 0.16231336210283542, 0.10478844806071251, 0.10154949726476785, 0.13217514140471337, 0.11495424329393333, 0.1812898656052928, 0.15556936753132652, 0.12629740075358462, 0.19100533137398382, 0.1782745895006003, 0.12235676704515373, 0.1514421301262994, 0.14142451928027217, 0.18867164369552367, 0.14141416177153587, 0.10486599148040819, 0.15049461725979082, 0.14757922369866602, 0.07686639715346598, 0.19833663959176312, 0.13534640833254785, 0.18957731283960805, 0.094106730914885, 0.12191720877683933, 0.10159815916971815, 0.1656488016728432, 0.15959437816373764, 0.14337237443654768, 0.14568827355340605, 0.1578170082141315, 0.11309103319241155, 0.11645748400159421, 0.2071490562370708, 0.1820519851941255, 0.1336849781294023, 0.13351288413809193, 0.2693342056966597, 0.1450399026995705, 0.16028978681612402, 0.11744249687199632, 0.17983941601649409, 0.12619164997651694, 0.1602741433007102, 0.13513270044519057, 0.13542030517372394, 0.1599117224254916, 0.1259172066385227, 0.13543936544128005, 0.12083255085012606, 0.17493081489397636, 0.15433633369543862, 0.14306906490556656, 0.15908686023566032, 0.1530506083321187, 0.17013864381419075, 0.186530688417054, 0.15960478163774938, 0.11867991273081112, 0.1700895069347274, 0.14246420784583017, 0.13029084090263615, 0.2208653242597657, 0.07451562571429438, 0.20066931603416321, 0.09060488172596501, 0.17539917040736447, 0.1625508340376039], [0.013886303152708758, 0.052661109910977465, 0.03314384792540823, 0.021181145585292292, 0.024965844011955687, 0.04852564089120396, 0.023955444902962735, 0.06999821206855197, 0.02793871523481944, 0.046479289810503685, 0.03167332108733395, 0.010233604548228605, 0.045723980743317835, 0.028205664317694404, 0.012945804778756875, 0.0656067815819575, 0.0044717184162788816, 0.041112629396300164, 0.027290041776253816, 0.057950131144494786, 0.016775808687652313, 0.046927845781488765, 0.03894117232712527, 0.09540437660630673, 0.021366571421704946, 0.03963712490193787, 0.08279184209963969, 0.026733465492725376, 0.029568898626753402, 0.057983731760853724, 0.05415749030127641, 0.055059761845416604, 0.028823257589171973, 0.031621933824593024, 0.036770274502135096, 0.026603584861262675, 0.027822497781486284, 0.04249287085727819, 0.0716530692373072, 0.05601975811465133, 0.07357457862986673, 0.09927653737606541, 0.03111073867447915, 0.03578798124386418, 0.017552211985833222, 0.022876187896115646, 0.019362217281013727, 0.033680588277357246, 0.040676311679905465, 0.02115947487313421, 0.06866046167429417, 0.041988677750792236, 0.0783340300944063, 0.0435843201534402, 0.10449974782644741, 0.010992455814454344, 0.0236726971718693, 0.025426982977097074, 0.027377783741441467, 0.01948737498042324, 0.044237616952628865, 0.012519303521501922, 0.03605829153750693, 0.03269577458981545, 0.04828535358331377, 0.04705120891993565, 0.06082194196360727, 0.011375365711207832, 0.02751875732604775, 0.04436874439218833, 0.00791039168571813, 0.06758150344173755, 0.022615719917080095, 0.047620243708332705, 0.05376614960691622, 0.031413749431169806, 0.021783623942023805, 0.04844453516266039, 0.012503476144986288, 0.014316959479343028, 0.032040028224488905, 0.037345204337109486, 0.03157448808422252, 0.028676446414582675, 0.04631598667812444, 0.021209103964088906, 0.024185617935032617, 0.038649771632927085, 0.04388022927507278, 0.07657502327234515, 0.03863848715780243, 0.03375164293233426, 0.04438062641589392, 0.0725144278558512, 0.08363134422970396, 0.028698235870369022, 0.05398373772960998, 0.07012480043716009, 0.035975960068284504, 0.020581143607776013, 0.005988253143450787, 0.014502884230516372, 0.01125510427124438, 0.08461499346360084, 0.03207885739093106, 0.009513108431541873, 0.059606244697445826, 0.05966206569404853, 0.034776534509634784, 0.06645137819671823, 0.03096901432370707, 0.013445931873584708, 0.041610207333559954, 0.03531245131706519, 0.021566120089001713, 0.06774847230483448, 0.03314689695534687, 0.06617089042500143, 0.04985853811846145, 0.031813296842418855, 0.02228520468868796, 0.011143033268801388, 0.04528780858362875, 0.0536346199711965, 0.04359357449556551, 0.0285381407311727, 0.02726697869929335, 0.04745869874773968, 0.029137748173407974, 0.03646792258105932, 0.028260242336639957, 0.08578985824339813, 0.04504012086639001, 0.08347804237517618, 0.011630020998117906, 0.06517465436650861, 0.017092831192478057, 0.013644263418691774, 0.05383748005354597, 0.07374220632857854, 0.053441868419007915, 0.09607502529698034, 0.08194611933563026, 0.05353151985834684, 0.061458323541427815, 0.03075538687558184, 0.03133581339141294, 0.027035242847857938, 0.03558554250987307, 0.017576901084412972, 0.04724261215737751, 0.059719307783750765, 0.0631100397496935, 0.0880917609338799, 0.05020659101466018, 0.09595006103477172, 0.09003511149316065, 0.041168404427627404, 0.036045007572899905, 0.05294503358703467, 0.0022124494763932404, 0.04965534861830454, 0.05673254164116037, 0.0236693685198383, 0.07014736938740938, 0.021548923330321428, 0.07154903449718991, 0.02326304506089899, 0.009733902632198747, 0.03859916003420949, 0.04970944208663799, 0.030306265914752602, 0.04556736172807794, 0.09497474683749099, 0.04691058199011511, 0.014954638618585325, 0.05926205288438548, 0.01702427015369458, 0.05644202960895435, 0.06968093675471122, 0.01734191702017861, 0.08159308303748408, 0.049394216057994676, 0.05546857317489001, 0.03915048286979718, 0.010928544929371247, 0.014663809617500634, 0.003429972904644186, 0.06613465446618295, 0.016992523470112396, 0.035079978106002656, 0.03359617304898078, 0.02087643028297011, 0.028502603827585137, 0.03456227886941164, 0.0397404701629233, 0.039884418083895604, 0.14747456076645082, 0.02887241170561362, 0.013344816886068834, 0.010252237721766916, 0.04538068142268927, 0.06368793051449523, 0.079098011276895, 0.008518959962642722, 0.04203923572335513, 0.03716860574880435, 0.06474104094048662, 0.05587964446374005, 0.01701695784445732, 0.04665814069730621, 0.04441154189407826, 0.025531665061510382, 0.04194817468223553, 0.02219260955649999, 0.015134946030053883, 0.03410236181450948, 0.10416403277626923, 0.0467589004115472, 0.06165510471609812, 0.015005826698465934, 0.04708829906678969, 0.07131915449375106, 0.020275210225654226, 0.017743029166013002, 0.08808534111707442, 0.02157121265847837, 0.028917551521332036, 0.011302294329770151, 0.008183849164314808, 0.06701221584432548, 0.01804090521839117, 0.027405429939408938, 0.057731815238272956, 0.02000639380346383, 0.046959052373084335, 0.07385919561549541, 0.04394319787200901, 0.06336572925530135, 0.020908537027876706, 0.05113814243926637, 0.04366967000908429, 0.039969802413496285, 0.09430469569539833, 0.024452664694117925, 0.02836311836877177, 0.05290940283767639, 0.08103494968024955, 0.03288674498758009, 0.030572266963821267, 0.03406717539614728, 0.031093306343762145, 0.05763803075458254, 0.03360256988314852, 0.049522447685200366, 0.04255617270246149, 0.0584954631725146, 0.006146396673660005, 0.07674166271763463, 0.012916940500989798, 0.012332216231903483, 0.03016032808039698, 0.026934056039599162, 0.02253708865253195, 0.03699056691520157, 0.024270211278851476, 0.044630570262069666, 0.01193478896898488, 0.016695752499565, 0.02606821963713775, 0.07110014527795777, 0.05609602216751345, 0.044935637964837016, 0.023397282817431038, 0.035773004224944505, 0.04163666418002498, 0.036424450921796026, 0.027693306629155433, 0.009814421345870341, 0.057065165526564085, 0.03147515903918013, 0.014321126040041208, 0.03416920298590295, 0.01657203887589276, 0.07855803420346591, 0.051264734638314095, 0.016593981549263965, 0.04841399889799857, 0.019954081489554337, 0.060615891125053174, 0.0625192863686431, 0.12233968328444228, 0.06096471010917618, 0.05254955984832299, 0.07945398169179117, 0.0287048184808584, 0.005630020853958183, 0.10362527378263975, 0.053613847497129635, 0.033819365104840654, 0.040434829274853396, 0.005639863647370329, 0.042528880820158994, 0.04519503916643801, 0.058703203234941735, 0.020567277416346536, 0.02078516622855058, 0.04112482168561509, 0.06691620204477541, 0.0424095243215561, 0.02324509179039348, 0.0680903313801654, 0.053649558685719974, 0.0444409366877329, 0.060769070405513055, 0.002800853361540865, 0.024339777808035576, 0.05153650815989222, 0.06430755008853252, 0.003396039040038182, 0.020091975400705012, 0.028997420017877897, 0.03587010586934705, 0.03521596637344168, 0.07857544738198481, 0.0017037022165999178, 0.021138654518572074, 0.08486105324400049, 0.034843000297945355, 0.0969874743191946, 0.07213571229048314, 0.09844052094605663, 0.011469161686217113, 0.04709906260212583, 0.02324712192339282, 0.06792528539775841, 0.0982382430905296, 0.019361139012260303, 0.02001529766036378, 0.007126736407723999, 0.01958160571032955, 0.03310074398834859, 0.016704464834483884, 0.030476255079491005, 0.02577336005596144, 0.09801566390500915, 0.010634046367129252, 0.03925107404469483, 0.05318704842319412, 0.048062379862512314, 0.05621058295571035, 0.022181602788247892, 0.14560164433092843, 0.12401990562437043, 0.1376860561750589, 0.13469321112478935, 0.059631743934005506, 0.14352638875284504, 0.26773853648093443, 0.13216198001417423, 0.08695774396220524, 0.11871234889352515, 0.07915415019998628, 0.1614374631354886, 0.07637387922694606, 0.12640359586164837, 0.08907568595942952, 0.1870841256553127, 0.1570061041462806, 0.1260009094051296, 0.12182545442614826, 0.10954191637856346, 0.16697327576337323, 0.21701102866040123, 0.12380965279355166, 0.16674873539276663, 0.08614399770815527, 0.148953263677897, 0.2570385251554751, 0.160085363914409, 0.09015789240478508, 0.17331412422560877, 0.12905278152996494, 0.19974637926826555, 0.16076612496568313, 0.09259090338262821, 0.08634787668744404, 0.10098555696106727, 0.11790440192506199, 0.12560033735128182, 0.125912610110977, 0.1593711861078778, 0.14830791121048315, 0.1550118087400352, 0.11707863575148007, 0.19387524995592334, 0.11843997399292647, 0.1479373391597502, 0.1396429971341164, 0.07355597035418596, 0.13780769561567616, 0.24086835493724193, 0.16877525245710728, 0.20995356623203526, 0.2237535829866125, 0.14712392232350766, 0.20826566003022656, 0.19499105701763786, 0.11650269851088525, 0.13904380912501968, 0.1052756263544002, 0.10723819805970115, 0.1655699252601593, 0.16340086987662703, 0.11412596435195978, 0.1094505757153515, 0.13717866082104946, 0.17381447157071483, 0.13037241394481353, 0.1718799463443218, 0.09322958322422159, 0.10924744750222853, 0.19032933538959873, 0.15114666533566293, 0.11821285190601503, 0.1124227746960617, 0.16829683054839412, 0.12482743890535448, 0.18626234313893705, 0.15463323873137275, 0.2016736573028949, 0.09397308687649428, 0.20004737521371535, 0.10211178281855199, 0.16185069096184548, 0.20482696712978427, 0.1825262089410136, 0.13315985550082501, 0.16248521094601, 0.1721004417706882, 0.15081424446355912, 0.16613733594215688, 0.2440909497560032, 0.049457720916477904, 0.21497628381175382, 0.12149429759911953, 0.18353500884146462, 0.15688817257121687, 0.15557659940133173, 0.16273782077816226, 0.15247996475908066, 0.13234519760214514, 0.16527847477024601, 0.1655457628470275, 0.1350686861382377, 0.14614513774792995, 0.19361384543440036, 0.08253642072480533, 0.12549171374449808, 0.14359613339747154, 0.3190110545725592, 0.24079458067013373, 0.11586487668776706, 0.20834243736199795, 0.14273220072350196, 0.11051855590795318, 0.19853174686431888, 0.28065759808786456, 0.14709088861221267, 0.09953166763748854, 0.20354173206273588, 0.15007636389665066, 0.13680971287671598, 0.1620799044687902, 0.17239817418158057, 0.14615762498109572, 0.10467951035787983, 0.10225478079049818, 0.19367933063016785, 0.14444482092174793, 0.1682030460647037, 0.10409233460743582, 0.09699263775180425, 0.11381693980506352, 0.1897419757780529, 0.11564025204748878, 0.12302093463198793, 0.2715056053092403, 0.092521388564379, 0.11050871167812618, 0.07994204864747102, 0.12660386656681377, 0.1451315881023484, 0.1774629653101006, 0.22238213238456558, 0.09720103664984626, 0.17553565663195428, 0.14088545385147297, 0.2102100218255674, 0.154956650409487, 0.13952785411909704, 0.10877634939407149, 0.11053512638975536, 0.20245260018254482, 0.07015676162536107, 0.24054178697687967, 0.2225960088112662, 0.28151313443818404, 0.30319553709799246, 0.13564600999797546, 0.10034986486237857, 0.1269577915269521, 0.17566771486834173, 0.13885768040293647, 0.14437227239531858, 0.1634564572164128, 0.17722792953493136, 0.14484428980898473, 0.13093435475903173, 0.07952735759317875, 0.1011096785265592, 0.1583277283897323, 0.10122256158220191, 0.0849434000349814, 0.18525616325918706, 0.11638560963253822, 0.16613650856719864, 0.11716036967212155], [0.07478803125841003, 0.015618247918844705, 0.12999283270009104, 0.023430567422521212, 0.05319501956804626, 0.07838982427793165, 0.028187557829604037, 0.016083571639272477, 0.07438759710038863, 0.06561768301312002, 0.03587480964920214, 0.033210321374598055, 0.022527742379855727, 0.03036750506819977, 0.026962822641155897, 0.012368873539080304, 0.014671437938006656, 0.063932653471467, 0.0490083911966893, 0.05308185689031117, 0.027354605751292362, 0.053667029320833184, 0.14779279369019693, 0.015058072937291958, 0.006586429437682514, 0.046209454491373994, 0.020457010550965226, 0.028853970054056377, 0.03374141565854511, 0.011931582891021766, 0.022425218748169082, 0.03193285060866225, 0.038839884012216525, 0.017199643001320864, 0.025196589694748965, 0.04545256345262451, 0.05093682985452395, 0.03816997459638984, 0.04921852911431943, 0.04395073234674431, 0.05570291181004817, 0.06877448620094408, 0.031736008146958004, 0.03428798108812302, 0.07394296733001549, 0.03893343100865041, 0.03595564341653259, 0.030589599703108112, 0.04284655066928075, 0.07840473234893815, 0.03777974089908023, 0.02201365141738807, 0.041729835793375976, 0.030444945066025665, 0.0338426580081784, 0.05080438474373472, 0.04350332550764565, 0.03534213339369144, 0.022204280906026403, 0.024093195172627608, 0.017111154100407037, 0.059941588194980744, 0.030100956266265244, 0.05829615007725455, 0.05245379885778793, 0.04699613485905913, 0.043708721341024485, 0.05780871897455185, 0.05985565228207458, 0.028792669613575263, 0.09501911098918608, 0.015364012065073176, 0.024378616550576784, 0.04842038424084744, 0.028604110477552302, 0.03961910268351917, 0.020473351206390128, 0.01369052172277964, 0.05838230049477951, 0.024748504867837317, 0.0625036811576255, 0.022663077557339303, 0.04975409352130467, 0.02111121899478378, 0.008881713128498486, 0.04320764621239036, 0.05695043236858422, 0.037370178803441026, 0.04231735628338591, 0.021358542820258487, 0.04063627975542219, 0.06533739442426352, 0.0010164847199414528, 0.05955353401781571, 0.05302270724167747, 0.011811676724333198, 0.058314068873803464, 0.06097407553405051, 0.10736788142352335, 0.07773935434318359, 0.02453704736375761, 0.018108188805560914, 0.04823508672416211, 0.0625178039885096, 0.058280935571078336, 0.05673071452146096, 0.050695362771230365, 0.03567837321409776, 0.0711074690785139, 0.03058095440088261, 0.021169803653573318, 0.059668232701838984, 0.06827229258394049, 0.027442698201705373, 0.018424878062139598, 0.058946053106938644, 0.03154378328021736, 0.05734591759861477, 0.01011644097630896, 0.045616104072260286, 0.04167681484813652, 0.014847459087538865, 0.03607812938430617, 0.03224950922172397, 0.058162755017439206, 0.037150683121815804, 0.07767093503066609, 0.053280446032482776, 0.017325436553707527, 0.020316307012352253, 0.012800727835706165, 0.033905929209844726, 0.00836338569980956, 0.03601158698720317, 0.009262744194617676, 0.026956506246220202, 0.016992467928737882, 0.046533525005103125, 0.07479147099319004, 0.021030701238722093, 0.05639824002320248, 0.02734785651667945, 0.007637695506996205, 0.0377225179615761, 0.0627184500767579, 0.013044700026512148, 0.03725200208024152, 0.009315545847188801, 0.06267280272778965, 0.026716333851518653, 0.05949258789299958, 0.04108083674744253, 0.015951610121485448, 0.02321122878892047, 0.0681777420123258, 0.027707165159705668, 0.022889818515508406, 0.014901125461854523, 0.05661367543882901, 0.021695945179089907, 0.015629110088001098, 0.030419623944908384, 0.048489247884361014, 0.019023275085454507, 0.02641855547535083, 0.014904680109823184, 0.028867108461957787, 0.048439961617752436, 0.022714834457503694, 0.0036447645670118476, 0.03486060499844532, 0.04476907895877958, 0.03878647236213569, 0.014192516156922907, 0.02332876199826358, 0.07558885360917739, 0.07243493091194861, 0.08773008316394784, 0.07875530950484738, 0.06806977724115695, 0.05176089148247435, 0.05485402893335108, 0.039398120791320844, 0.03094926457701912, 0.046669271954846, 0.01391901606468544, 0.05290016764774919, 0.06123908449925723, 0.06170534093173281, 0.024809795732219374, 0.01076954242307693, 0.03964095917199889, 0.055691240460521756, 0.07795215058591097, 0.057570998061208, 0.012713000234667093, 0.02099969957564627, 0.05723793750568744, 0.06532608696650113, 0.023833236642061703, 0.05686002633263988, 0.040897868138047, 0.07187092166033483, 0.033915961131213174, 0.143975209024164, 0.020380164271280653, 0.06524281320913185, 0.023394239533151832, 0.025748766718372226, 0.1065267168826634, 0.0748924567033687, 0.04278706011152075, 0.036379906739438736, 0.01647333227728884, 0.012506245552832562, 0.02446674922060582, 0.13177890540851703, 0.040743677621527065, 0.08740543042339625, 0.05538367148068163, 0.014394792097230113, 0.02806564068211423, 0.045389349707552505, 0.06605505793085022, 0.025917340535670522, 0.06828337021532559, 0.010349054956027578, 0.0018412755678347765, 0.01839218525997093, 0.07524772231737453, 0.07126378165858407, 0.009756681299017323, 0.01575113927584983, 0.03727305034596113, 0.010558904633076202, 0.03136450146895743, 0.06677464431812687, 0.006755072202893996, 0.05329630022207576, 0.02164515546492992, 0.03849135997194437, 0.03663494507031095, 0.01740235561174491, 0.0124068868218831, 0.04849914574034272, 0.019782073683135455, 0.05918026533758929, 0.015741290257973297, 0.0681024125867313, 0.08224260302320605, 0.08949105883197439, 0.06248827512946822, 0.04224047552974474, 0.030057754652995258, 0.014021533950712654, 0.027456116231699145, 0.013828929870449489, 0.07149821222429315, 0.031113431473532994, 0.05948500745298882, 0.03619413041780072, 0.04795729941237838, 0.03479420049716869, 0.0632510535539158, 0.023524097181976806, 0.021402652247718746, 0.0568699624930178, 0.026737125477783626, 0.02784742628254237, 0.007743287799624547, 0.039839000561304634, 0.05712913769868113, 0.02298017858617729, 0.032874376498042576, 0.02166279463938648, 0.027117072529489958, 0.05105375402396725, 0.020751588594829364, 0.007950713766002728, 0.038380219766329375, 0.04065315284195446, 0.03344321976445856, 0.060135385457185976, 0.08366423238429331, 0.018288548885574265, 0.012474340863615997, 0.03460560880240894, 0.07516335305427352, 0.03892405409245722, 0.02875034708619839, 0.012604880330693579, 0.02958563764789893, 0.011946529266424479, 0.05808891563285744, 0.05071456093461283, 0.03883244529847176, 0.010723103130716952, 0.040944978714950626, 0.09101691445516003, 0.06206904500422459, 0.047689425278334856, 0.04394542718786867, 0.05072280404067809, 0.014933101014204085, 0.021229386141884233, 0.019139149714441552, 0.03823584283611948, 0.010102516370675257, 0.06020169802791169, 0.03997332641794797, 0.02937376645634011, 0.024288170295016422, 0.04190510138869286, 0.04201829470994492, 0.04334533902546091, 0.01941996307352618, 0.057879409737764835, 0.04988340150204398, 0.044234150404771494, 0.05474025338527657, 0.04064382572147635, 0.005999879006506695, 0.03164500456243273, 0.03935928013355982, 0.027488567716171666, 0.0621854329121209, 0.026210078053296577, 0.008176974482804297, 0.0225047578269075, 0.036686464483218814, 0.03846244015280278, 0.019804443450524442, 0.029375313953947157, 0.010005767126717876, 0.006590029093316727, 0.012478476780797205, 0.01958182404538797, 0.03337464340391659, 0.010719440272828985, 0.07381549029941521, 0.07124177961339874, 0.01947674742569366, 0.053538242279882395, 0.01551549541839068, 0.01612491357410627, 0.043850118189208934, 0.016902596239120733, 0.07059474941343069, 0.027966526141690633, 0.11870949904644683, 0.012335232703105338, 0.04014039487247506, 0.1315514998690736, 0.17062478788918065, 0.28259665855476934, 0.09864398623786627, 0.20717971507580052, 0.11481160538331156, 0.15108721691273874, 0.13235995245556678, 0.18381954921830088, 0.19291719571957666, 0.10213746974665312, 0.11988822490938249, 0.09051740214589143, 0.08428359148843635, 0.10738544781962711, 0.16348153893505374, 0.16496082407332238, 0.15670282525881646, 0.20890272342629973, 0.11640608716275423, 0.1018267521454442, 0.10960063701795955, 0.2526018495160726, 0.14198762454813527, 0.12397726517050497, 0.15401206399884917, 0.1656050427306083, 0.09280129410927335, 0.3215470813935803, 0.09182271637743519, 0.14257495351616414, 0.1878997181812602, 0.10787179873835658, 0.17317385352667303, 0.09795448412337611, 0.15998756512999535, 0.09922766096649632, 0.12298530388262965, 0.10401030957338311, 0.19758830958556747, 0.19902677755923043, 0.09499830404116262, 0.32033755113520934, 0.16184690648749953, 0.0763073598124808, 0.11578812233863339, 0.1564005269638954, 0.18877455994727152, 0.11647403150075868, 0.16244758070716936, 0.12383442807702288, 0.14575351360103778, 0.13758286413165832, 0.11679212652867842, 0.15412155328498733, 0.12273870017980376, 0.08908931466360247, 0.08607822139897654, 0.12609592729037808, 0.07106558705169348, 0.1435329158219599, 0.17542533997085788, 0.09602826329008227, 0.14427694041402112, 0.16260141116236487, 0.08724639823119487, 0.15266025589118082, 0.13989240471874514, 0.20210268186225047, 0.09896815634302555, 0.1328919851972211, 0.15062399418844333, 0.12704589163824437, 0.15778449544262502, 0.26321956767670573, 0.09270762453877157, 0.1327049065261118, 0.12822028910440783, 0.13033438534025224, 0.15670708470767544, 0.12790749540492413, 0.07830723999969422, 0.16164214650709785, 0.11374138821397098, 0.07666418824585215, 0.14293522934519476, 0.1317561219536489, 0.1551205166164906, 0.16284789229112287, 0.121251049361402, 0.1602501953921972, 0.250701982107374, 0.13550475870649661, 0.13847560171158085, 0.14416892201669756, 0.24278575043764808, 0.21331218762263177, 0.17421801604570883, 0.1850106167576967, 0.25342373928475764, 0.1945890753620094, 0.13886943219169495, 0.10868100209101554, 0.13217791464299927, 0.08243765666960709, 0.15757723801559018, 0.1606637296537238, 0.1785800747212864, 0.157623739552594, 0.08269971236586571, 0.09004523917551964, 0.11972514011206166, 0.1880227978671751, 0.10255401473372214, 0.08507962578967695, 0.13293206691741943, 0.08298375478555119, 0.07862771756105846, 0.09781803620318252, 0.1434358371601951, 0.16700168230360554, 0.15059456109039246, 0.14237889629458228, 0.18586560152471068, 0.1011221734206042, 0.12216814853731664, 0.17683904798280808, 0.12156395031319511, 0.11165484816076295, 0.1091168984590519, 0.14328945307962357, 0.1557273808265886, 0.15225308015942574, 0.14267417722411696, 0.0792973320330343, 0.13013313404254376, 0.14955370807118956, 0.1646590620399483, 0.19484055138403372, 0.0874565897749797, 0.2737342470115231, 0.10776208728672036, 0.16270737644405137, 0.2881097949800953, 0.22562018685763885, 0.10790697749583952, 0.1247782943650119, 0.12310138918579587, 0.13752097954913495, 0.12089418262363442, 0.13179444167162144, 0.0966172699906653, 0.11734907244963032, 0.12835204856650484, 0.1831771691720332, 0.08839068844193414, 0.13106252126876386, 0.04183239964467864, 0.10286757452113014, 0.1172972389406735, 0.12601520460579665, 0.11274833142036393, 0.1556520130965979, 0.2710801813631289, 0.152425296724804, 0.14098691453616466, 0.14520850332994617, 0.1684022442467751, 0.10708240641941948, 0.10552704108939057, 0.060419408724673336, 0.12595166527335683, 0.14112131700160044, 0.12726536050679224, 0.1741737514854439, 0.22977391558308757], [0.04390272544696928, 0.07535051599505448, 0.002788233978208155, 0.05103754360348948, 0.03130963808226009, 0.0835499014224737, 0.038322943202670545, 0.06993648070361345, 0.03764958256074498, 0.05521476441513627, 0.0135828088030159, 0.009478963892756691, 0.05983967168797409, 0.05907629954538519, 0.07648429547947261, 0.02893482680402456, 0.05128548029930361, 0.04693208224771004, 0.05065520444223958, 0.01868605850294473, 0.03114952762130528, 0.024301528953196063, 0.024966736504387473, 0.06280956857447183, 0.029024392058472, 0.015725162191947382, 0.041486327085764184, 0.004630118585942734, 0.010931043333614306, 0.07248528587121157, 0.04241284531270785, 0.02800806534416493, 0.004805288899074039, 0.032843365258867704, 0.035439702351727796, 0.031416568634731155, 0.03661512254527019, 0.02561084982458382, 0.028204798638339967, 0.056584426201879985, 0.04594749838654553, 0.01340835334567894, 0.08394232996168637, 0.10317293716774834, 0.048715718796536814, 0.09195377103864186, 0.022121152705362728, 0.04701667367630909, 0.022701096585801533, 0.028817753247436018, 0.06339145065735906, 0.058262300482320215, 0.051773102923987374, 0.007244324200831715, 0.014290562962302038, 0.05154011643401558, 0.009431506661067327, 0.06729606674202988, 0.058565464456595724, 0.04390507350645719, 0.04327596976391731, 0.029134881089351354, 0.042260309546104366, 0.03506259940144035, 0.05455108329413399, 0.05971593316644431, 0.025870831337787455, 0.033660279286484567, 0.0666851269441747, 0.04715929243473276, 0.031944347673185894, 0.041343639379427324, 0.03961682357194443, 0.04234583943241066, 0.024743990694743492, 0.07851271244186549, 0.010160033294420329, 0.04930503576272919, 0.08004291178358179, 0.026140559404607744, 0.03567098429606807, 0.033633412582980055, 0.02764565979070481, 0.03866574839658795, 0.038658409274273345, 0.04911369381232127, 0.033779091862661224, 0.0035306392519194037, 0.018958450640521703, 0.031246995072691675, 0.031109857673366225, 0.0547932168739217, 0.05010167910386959, 0.02472773622421007, 0.04195536058696528, 0.018623352291122563, 0.018532432976268956, 0.04514552690389176, 0.0056717985012989134, 0.05103034237700124, 0.04025859074787267, 0.04853267357834885, 0.008852189057506621, 0.029838961857040564, 0.05083960946649314, 0.08036296033570844, 0.11642304068851857, 0.029810122477131027, 0.022188302227145722, 0.04082302517828442, 0.0279217234046589, 0.022094255358341242, 0.09572459369777672, 0.04100818096870377, 0.054393882052071636, 0.034096068402211514, 0.029636241585737275, 0.04714358380184539, 0.038531357422471046, 0.06190696378208457, 0.023589297009992505, 0.1060396075368889, 0.04227034529791244, 0.037566527138434114, 0.026848778962307883, 0.08069189550775675, 0.07576200480182325, 0.05247881545895531, 0.0618488560130279, 0.05063379611519556, 0.061531048268079765, 0.07589131278256256, 0.02674186947725473, 0.02544663696279449, 0.024031128644222216, 0.072744874764354, 0.03185938469194357, 0.028087342037789287, 0.03281639130305379, 0.04050474628926285, 0.0295222400417251, 0.023760751317886096, 0.0659939700797681, 0.03687044432867439, 0.04888556431978942, 0.13973396241424546, 0.03946643285152893, 0.06686023932190673, 0.015020143924160831, 0.020005537700208447, 0.020869974076988238, 0.03615211815603318, 0.05547048073382147, 0.024779431837340517, 0.04326643196926002, 0.05577010538188681, 0.016635993811031504, 0.08526010078287895, 0.07387522983575061, 0.027756409291478417, 0.004399418389619959, 0.05550050755001365, 0.03331145647192194, 0.042600525362837705, 0.04602770396177808, 0.037596013862639666, 0.04870224330994872, 0.04708038154809226, 0.034520251285885616, 0.04707869615465884, 0.017142259185352636, 0.037361299844398614, 0.021689465990470305, 0.052507597382270524, 0.01748601432829615, 0.02271324099462119, 0.0470676108623945, 0.019140710618587273, 0.023804445142647433, 0.1033398217611736, 0.08557709264418772, 0.04867977012068995, 0.04716694565309633, 0.039689421894088875, 0.05274677003223089, 0.014794697654583763, 0.020013978073914206, 0.060185050937317075, 0.03421214987493811, 0.01781487863721146, 0.04384564806617076, 0.014748972739213178, 0.020315037221617756, 0.030543768493038033, 0.033853157243180665, 0.07247373326531342, 0.01404340767617067, 0.030803753836681286, 0.017725824746453477, 0.011525345616973938, 0.060967866391424215, 0.04772293013370326, 0.07611960698399814, 0.05598493558805316, 0.03188897292279909, 0.05080744909543184, 0.06997195057450764, 0.023172865020892313, 0.017199518512033166, 0.029539113128257376, 0.05990661245079772, 0.04649506356086462, 0.037064578669566306, 0.03744302610416086, 0.07512800575744721, 0.010315602769203966, 0.047221805209354054, 0.017148225095062967, 0.01160236713927119, 0.024769700605482347, 0.02908988874555836, 0.04550453868784732, 0.031112560048519127, 0.018742856261650884, 0.036000474881861484, 0.02982693427662936, 0.15123668066676588, 0.005613933965158199, 0.02072311310668386, 0.019599160615114436, 0.029336829527070927, 0.07223433078897577, 0.01655324482389035, 0.021215179041328452, 0.01869969295277711, 0.0283582556256724, 0.08517852007982232, 0.07554316412537329, 0.02996804001140258, 0.047421102982855616, 0.03757159864049285, 0.13101802688212166, 0.029515705311730988, 0.13074643339120573, 0.05180409501096414, 0.052661538920215065, 0.11079832355702117, 0.05231456237754995, 0.027981715750009305, 0.05447745458373139, 0.021950418520117962, 0.05349919860882144, 0.01698578572681835, 0.06109795195140666, 0.038398219002110344, 0.02712778052345159, 0.03243809325560447, 0.05395972853406303, 0.04967864535208191, 0.031113653639031034, 0.005433477645349359, 0.032360182113705144, 0.028258373082104712, 0.018048094953560544, 0.034746626437070875, 0.07388010981582827, 0.04582834107080295, 0.02642599993475503, 0.08066813912122481, 0.04324844422479791, 0.020807664315666885, 0.024377105442146142, 0.03630805918346009, 0.018965697832285397, 0.006955560764312865, 0.03350426931114447, 0.08334907913400282, 0.0277893012765074, 0.060434650043926896, 0.0521422194076642, 0.02838715629261588, 0.05437478348011932, 0.10617463053354334, 0.01780668149642166, 0.10609282766498866, 0.032010665989571044, 0.021862224563054984, 0.04395706789387811, 0.060140518246278654, 0.013220270141778935, 0.048912584240878784, 0.06622273925571673, 0.03205798341021423, 0.0638667545882204, 0.019230800643262845, 0.042077226023520195, 0.028795163229768796, 0.05703344182561963, 0.027289285264428587, 0.010141195192362272, 0.0405383660578199, 0.04172630412804504, 0.016092699576890277, 0.02315747814493314, 0.040612615299441164, 0.03132291247076806, 0.0353032544315342, 0.04517667220845338, 0.03306737319836694, 0.00987038598395884, 0.0238336828882776, 0.04931895941075298, 0.03731453017662129, 0.013360311014337406, 0.046882795981101455, 0.07493010226396785, 0.027185459283270666, 0.05536946821056547, 0.03393023334924252, 0.025367335371312597, 0.06363496319541047, 0.0751514480479302, 0.030841048912055073, 0.0630500512347827, 0.01897315952866789, 0.05221377585023161, 0.07079955535910784, 0.04473989100886449, 0.026346732817229726, 0.03631950070660922, 0.02254569756558105, 0.03581608134892679, 0.026706859259115114, 0.05068622717273332, 0.04428260163554261, 0.06833431506229025, 0.05060633186311011, 0.08674200594184861, 0.04931427861353563, 0.08091980666523019, 0.04383015776834181, 0.008067075339626641, 0.02243537132838561, 0.036957410629838705, 0.020925057713963816, 0.029245676555400415, 0.010783519697255425, 0.0765452147912114, 0.05047150804931599, 0.03806482519834273, 0.001936627658940251, 0.048967508914610075, 0.14712363121009644, 0.2572271666459499, 0.07577903493638001, 0.1665741592765816, 0.14663572513288067, 0.16792414409499015, 0.0995762769373194, 0.21745336782788077, 0.0988772829934474, 0.1409785794995485, 0.16776590097335078, 0.11869389383542923, 0.12670753358472742, 0.15104675214857827, 0.2530461651903968, 0.14670231349525914, 0.07193722657018131, 0.12541805439057852, 0.16280851537181487, 0.11990733114221405, 0.1381855301799313, 0.09809199690578446, 0.10012871826127653, 0.16876622794135926, 0.1709546806711343, 0.057656098938276695, 0.17373740312553224, 0.1067120795168223, 0.12692252083891822, 0.15570554732074662, 0.16340633974440638, 0.08033101446926594, 0.06571486892719423, 0.1246923546216661, 0.23210564207646156, 0.10660508001643805, 0.1727791037410498, 0.13049141804297126, 0.14888837603071045, 0.12038734651380971, 0.12245191516534937, 0.08815208269703774, 0.15889547615041658, 0.1857842276653936, 0.10801533297184976, 0.1867239570785915, 0.14780621555063034, 0.20226284020370056, 0.14079890123778774, 0.08793786919165043, 0.3397227012582364, 0.16934471625474193, 0.13696532065589584, 0.11239069093379284, 0.12427183363827006, 0.18961267545819285, 0.15983276940401525, 0.10722368069353605, 0.15955017489050666, 0.14132207800303737, 0.14625713980245977, 0.17751841475406002, 0.11403322174784639, 0.15927092052034794, 0.2158068763392587, 0.15876632904814136, 0.11003449559211732, 0.1557597710240272, 0.1559216147589107, 0.11188628332268809, 0.2733774645434272, 0.09491776521768301, 0.13213766438345756, 0.2294089819394773, 0.21236856648277855, 0.21034696770291175, 0.08533236585677632, 0.1515174059257392, 0.19269041837223116, 0.143612144635089, 0.09748099582089532, 0.142306255837602, 0.0993563024507415, 0.09912752561391362, 0.1790076437135858, 0.08020063396543264, 0.0955881227949454, 0.11613757334529393, 0.19137251731609145, 0.20876122698668512, 0.11190465411111233, 0.1347722713985751, 0.18289207721189146, 0.2503520331435627, 0.12003283166596967, 0.06851148821653859, 0.0709336896937701, 0.127426644997491, 0.11041868868614398, 0.11298516750215523, 0.1418667358736838, 0.14510405490234976, 0.11857635296520688, 0.16661912863773687, 0.24779146086544762, 0.14040951406763447, 0.286149988852201, 0.14577251258155993, 0.17491814379970874, 0.1340154684599369, 0.10815210264897156, 0.09016842611374394, 0.1939382223832992, 0.11897255065700701, 0.12758972979481184, 0.14148073481215587, 0.10347355006923599, 0.14781228296699064, 0.12250182579361624, 0.16435716211074786, 0.14192949379644088, 0.1356609640342574, 0.1410989931994869, 0.20988101770560588, 0.11825933046038113, 0.11497921009938564, 0.14946874892038686, 0.16019944972809286, 0.21227067576781397, 0.11859581925936284, 0.112192741475038, 0.0949751758467286, 0.11624090328452089, 0.10520372134182723, 0.062355849170877095, 0.14839553634726232, 0.17001835268832025, 0.09984515081610411, 0.10775979668382676, 0.11633718521484446, 0.20781103281244157, 0.09680517603673282, 0.13043779188827162, 0.12223813066919967, 0.14342152663776953, 0.2210285469529129, 0.12073286748941868, 0.195493426834864, 0.09960221667443553, 0.13055469690551683, 0.14167674606846226, 0.11315867875612552, 0.13005943638422798, 0.17618160664794907, 0.3128095421819918, 0.17641152495578413, 0.05025240307253215, 0.2137888168856021, 0.20110943354666236, 0.13670754739113394, 0.20516649729782538, 0.23621553525088296, 0.18605586712158498, 0.22538406323761712, 0.1368964646732615, 0.11270046624685488, 0.15340873911496133, 0.1028154498987621, 0.09018157984340384, 0.12268654491391875, 0.07973148172060329, 0.09884510730062762, 0.08985338011576284, 0.13529793028869938, 0.17947000841940605, 0.10057773005457656], [0.06354627319641652, 0.03381997797518008, 0.055042046062167616, 0.08814737125630341, 0.06339079565218379, 0.08966117631644012, 0.12660811835479352, 0.018695805056561387, 0.08733511887370579, 0.0422215684797735, 0.03993317191939681, 0.079617855559674, 0.05435960727833933, 0.027780558298071547, 0.07239100343037037, 0.006452053306519144, 0.021412237922871308, 0.07097327345681768, 0.021647070684740623, 0.022029882905283765, 0.052612394379872474, 0.041173188646714536, 0.02857137937098742, 0.0701569454864629, 0.010531372390687467, 0.07870671654781027, 0.02461923710671404, 0.05441322577215972, 0.041647377919646046, 0.01706191954473334, 0.07048758903458234, 0.05511831777590898, 0.03309534689892204, 0.03051057007283934, 0.021001264310231613, 0.015892329280294718, 0.05776952591634566, 0.027725378900105437, 0.07389406793780866, 0.04685773341465862, 0.0669303210452199, 0.021852458857240218, 0.034179472394527934, 0.06565304563170479, 0.07355679772914418, 0.045263075434993354, 0.025301777397192297, 0.05171845021146921, 0.052872094355763934, 0.05663226073187205, 0.045968190421380346, 0.027541042823765068, 0.042558022804798624, 0.06380695759529068, 0.044453377955623215, 0.03389546827923867, 0.07090690725993726, 0.03059890767138812, 0.028509349231758428, 0.026926979302398624, 0.015305679257688744, 0.019221078987503727, 0.03187365116431348, 0.035651575458506425, 0.021554891155251575, 0.02818874335066686, 0.019005814026440346, 0.04130477190858895, 0.032392717867849335, 0.013207760883585341, 0.05172342212209779, 0.05282191176628394, 0.04824480837992123, 0.007560590672637186, 0.03030025403976681, 0.009685158372796591, 0.045984282098229856, 0.028251083755505182, 0.07208133536961771, 0.008817913326164408, 0.0224698759284952, 0.0542568365832971, 0.008488569254686516, 0.04618869733906562, 0.019269080141619332, 0.03208545340795911, 0.07574228569865227, 0.009319726772035563, 0.026361937747306885, 0.0172206606235235, 0.03295742808991382, 0.06042135458800101, 0.04359516795844801, 0.0154664782401655, 0.012513299307395375, 0.02831192837367135, 0.028954430994006897, 0.012553282393773478, 0.04103774813214137, 0.07847761029317495, 0.07829462253158131, 0.03600152825275737, 0.02483622576560705, 0.018148910209176042, 0.032374733953826854, 0.03260856697095498, 0.06593207783636547, 0.04545796054205106, 0.0362563559094504, 0.034137211154185, 0.022358894686124498, 0.025732156016954014, 0.057492167613799536, 0.04142585210502148, 0.022162981106028445, 0.052200078198145476, 0.02954452745466223, 0.08490344854973017, 0.030775636494640383, 0.06902554853548927, 0.0034150849434457, 0.07767816690067131, 0.042511571063509876, 0.08277213831822719, 0.06306250016355226, 0.051206251486174525, 0.04720140045749084, 0.05133430691315763, 0.03917396346467637, 0.06816510156157517, 0.05123483039618981, 0.1044129960299019, 0.06180347679483314, 0.05124174050926682, 0.055455158975335865, 0.018369507142192414, 0.01746275589891499, 0.03572276417887019, 0.053870705286822015, 0.0650037707941186, 0.0497054890729487, 0.04059913981285307, 0.05697177557815468, 0.025702249859609914, 0.018642778365662502, 0.02506563654019227, 0.039183554885488366, 0.01840663942388229, 0.09396361036887092, 0.0499876047815046, 0.053889995380755396, 0.009593023850973095, 0.009855023048247301, 0.0463432019516345, 0.029225126246831594, 0.03156855090280935, 0.02127002710626731, 0.06510887805732989, 0.02776551424645849, 0.050954273676559816, 0.03937875025815541, 0.02660922901404481, 0.021385999411464702, 0.028064970355180484, 0.03221672448900438, 0.021211222197199543, 0.026752746010559703, 0.02344779290949866, 0.016617582802991235, 0.026905457977385774, 0.05631446064780316, 0.052762792761167215, 0.02369179574382161, 0.0807147249279003, 0.005193761551767709, 0.06521265232755293, 0.016890664419700063, 0.01583360864089862, 0.020174448596193426, 0.058672904457536444, 0.04497664282098413, 0.08470361451468161, 0.027627469032942772, 0.030761948418653304, 0.010170404209695276, 0.026119857793673876, 0.020209623523236766, 0.09304459597314559, 0.009220053945037146, 0.006829555101332165, 0.014354107082791388, 0.008388541154413214, 0.011606275145294926, 0.1077118932059215, 0.03665361463302567, 0.009317261884139191, 0.1237040322514311, 0.14309600055698427, 0.029195124328496958, 0.042038389196198796, 0.07731928535166287, 0.07084491542510449, 0.039350167517700506, 0.060437235590671344, 0.00899174633706289, 0.05774959996943513, 0.025407562648216565, 0.04786289822790892, 0.06078945217473854, 0.05372862662038496, 0.04260740483239774, 0.07286261481743667, 0.0336030678402993, 0.0275130748688694, 0.05159512537741854, 0.02346063445832941, 0.04000799189652166, 0.07840411947859872, 0.02654780216905619, 0.02701814568060781, 0.01803562687259288, 0.027127407055588502, 0.03445438304615598, 0.01969534103878804, 0.033705367391268094, 0.06374755513764198, 0.0389708160993553, 0.03146545845083892, 0.03150487750498278, 0.08501037910220124, 0.031942660364532666, 0.036284544114624305, 0.113710752357879, 0.06954140150018277, 0.034459286008871375, 0.020455078094176227, 0.022183305418659604, 0.03866637275824624, 0.031175944248154282, 0.022256012908333254, 0.07241914183982918, 0.009575182620826508, 0.04022587879350589, 0.054521979613890575, 0.006280698111250756, 0.03455141574264534, 0.011421373121500497, 0.011547153267348486, 0.09009007064084854, 0.07254178485562725, 0.018145665826816714, 0.06611807632350153, 0.07269769140909757, 0.06757607953923364, 0.02125079638414806, 0.07509736990135524, 0.03773389436725167, 0.016702030590104482, 0.03221077964671197, 0.04809935892661733, 0.02726938038493597, 0.025992545471977324, 0.016262035651673234, 0.0664861815711183, 0.01056715156958108, 0.025088808784681945, 0.036479111295193434, 0.021786824274327488, 0.023515011379194838, 0.0057857741898436465, 0.0658828490263512, 0.03875569477977772, 0.030242040933620547, 0.03825440131608517, 0.04767648222285414, 0.08416682436701753, 0.04388996625259038, 0.020708731721125303, 0.021132809267709815, 0.03887381787682253, 0.03947935292437192, 0.020650463073604533, 0.0474811451239211, 0.038495696029595794, 0.01613613484697717, 0.035237240635098956, 0.02095006473903214, 0.05726333715081696, 0.019425021169046243, 0.03335204381015032, 0.04838809746527865, 0.04651551044756367, 0.02204282404554467, 0.07042549760831941, 0.008827074780128896, 0.008809140661821492, 0.05715748678231913, 0.042735460259380846, 0.0298746194194762, 0.04856022976098522, 0.017602260509926467, 0.020846029998914852, 0.044761130796565164, 0.06023930528411462, 0.06239716429263354, 0.04995723705618613, 0.04165421908480987, 0.05008187190058732, 0.007410283264283452, 0.049190957609924583, 0.07540615696099497, 0.037643128269982916, 0.01257339220178584, 0.04204292443671054, 0.007853307601650277, 0.013805767202058868, 0.037282898406227755, 0.009531490711284982, 0.09077410288755933, 0.029368045694765546, 0.041436554353323676, 0.02607080901432182, 0.12049321220406603, 0.03517583868796787, 0.024525217050986908, 0.04743705293343914, 0.10327258988493875, 0.06934535193948016, 0.0416680048370073, 0.04756576719603712, 0.10359553424941917, 0.03899264960519729, 0.0534321659154469, 0.06040682956095665, 0.06783333186420702, 0.02328047164595656, 0.0424129793780946, 0.05344633088116685, 0.0031116753422294656, 0.08733578537019991, 0.011703513727913941, 0.020557322103770512, 0.009154617587374824, 0.013115152344858695, 0.013630438404488228, 0.08483034077911608, 0.017459701123316924, 0.01796227203862321, 0.05736987316800703, 0.04948263409577551, 0.02827027617322822, 0.046967762792783405, 0.11107039202245013, 0.14613502538732945, 0.20167417824268344, 0.16216748364029393, 0.1714378676467365, 0.1356941969284127, 0.23260263395645928, 0.14525895788063928, 0.20743819314145273, 0.11426589031132961, 0.1024891653909318, 0.1661773410535628, 0.1103873556900409, 0.06620148797669718, 0.16039864791016425, 0.0688517155245908, 0.10331823340346737, 0.2172278621864896, 0.120597047761323, 0.060521857662787365, 0.18592557088742334, 0.3019145768015616, 0.11335116600798023, 0.11136973321798349, 0.09557797212994869, 0.24963488291588523, 0.12799337386123597, 0.1475331664926583, 0.1179054055002428, 0.20892487868906992, 0.15734753421237394, 0.17716105005914168, 0.1500625896357721, 0.07924903018940842, 0.14129851313848651, 0.34449723699400503, 0.19233823243168094, 0.12949047820462337, 0.18175356330410128, 0.10528804463965279, 0.2413143253614826, 0.261391160949584, 0.12539717849464188, 0.31849152438582917, 0.21695093672362067, 0.17289303633714878, 0.1307991555621547, 0.1477477936855247, 0.13968896240957324, 0.21313686074028093, 0.18109359387909213, 0.11500705739543324, 0.10952550677522536, 0.30124618040938533, 0.06736591863896578, 0.2064551031517406, 0.30068558790991384, 0.09897918800913519, 0.1120479891617452, 0.10075910903152921, 0.1337425726195497, 0.18432904365322283, 0.16739709092484367, 0.14577217550287325, 0.16513818874955177, 0.27754771012452345, 0.15595101721344456, 0.18587186812393128, 0.15790887747801122, 0.12725963782999786, 0.1736060496900351, 0.12837275592309813, 0.2552282900339173, 0.17360978819910558, 0.09602344459703854, 0.1374301981301077, 0.11602350285336857, 0.1720876634241112, 0.09291110515233972, 0.1498208122868692, 0.18885023411243193, 0.14294831412694148, 0.139543344416926, 0.21184872986087877, 0.09684541863539527, 0.23632274159500677, 0.12567527607203494, 0.17573920619343558, 0.13235641312935661, 0.16510063511950357, 0.1731778065403623, 0.13858886015030647, 0.10481787349788413, 0.09448176925821651, 0.21880535979665097, 0.13147328229200456, 0.10860160473854312, 0.1835886809614397, 0.10927246793383553, 0.19547890180781965, 0.1396607856957182, 0.14560236445357724, 0.089104728352639, 0.07454228557405934, 0.18488051970639538, 0.09622087311600486, 0.17902485004836516, 0.19818443324296706, 0.10654763108299625, 0.10075471934772308, 0.11359215428632115, 0.164652963980071, 0.14329458586871624, 0.12701292687486257, 0.10366806745409005, 0.17772944133368232, 0.15799230445296536, 0.1596391483420326, 0.1663700428100363, 0.13087084607010888, 0.1445432172547425, 0.17540591198109812, 0.14112154682797773, 0.17550371076551177, 0.155064714772086, 0.09480885049748806, 0.13103846610794145, 0.15548387211897682, 0.13634056063188663, 0.23312512124257706, 0.138039942830801, 0.21953204015810646, 0.1924408116047421, 0.10409157618039078, 0.14889569983126658, 0.08078171931687864, 0.11178228688696701, 0.11194638292034788, 0.1416085489214428, 0.12325819972301684, 0.10865531516291442, 0.08736845902017049, 0.17109944064530636, 0.15753242187201977, 0.14627730323662683, 0.11400917424790322, 0.11975332448679595, 0.08288532014816039, 0.13991143434278427, 0.15459570042308302, 0.14997488789020047, 0.11455168707236169, 0.14709825837804427, 0.10677568013629607, 0.13350698526107496, 0.20692552710252426, 0.12976466107272333, 0.12884578457282436, 0.10443317478582745, 0.08085423719979103, 0.17179019148311309, 0.1614846235081073, 0.12016076068844526, 0.20461273830263846, 0.1417960412800312, 0.08732508312189773, 0.09862131769618682, 0.11754239473732249, 0.10995545064009006, 0.16035252941712258, 0.14240083705273368, 0.1432189423470728, 0.15060334045800472, 0.1408733803057863, 0.09343408273472902, 0.14525489761464058], [0.05113947543225462, 0.03506005598953174, 0.0033248922151077782, 0.05294220289215446, 0.0464202320924209, 0.0278223043442854, 0.040567331842236945, 0.050767888315022, 0.03282188032303126, 0.012618323258544891, 0.047765574418008334, 0.063738611061126, 0.022342136512780865, 0.016547405318687522, 0.01746725666547014, 0.0277463658787911, 0.021151959550597017, 0.006795910434917577, 0.02129805060253749, 0.03804280017051966, 0.020647731970154473, 0.061056610016572865, 0.05134665242005741, 0.02489954101732902, 0.029181072360745845, 0.030177463552043326, 0.038365246577849316, 0.023334465522859848, 0.03763084405011708, 0.0849685813450525, 0.03306610532285225, 0.06865371243968126, 0.018126630457118154, 0.11083371681912292, 0.02835360930241164, 0.04282487421146324, 0.06300490184296524, 0.02964875946242002, 0.05076477799804942, 0.04477976971576291, 0.007947353991649805, 0.018654729337281278, 0.012282582352899257, 0.07465879988646315, 0.08559841287112044, 0.021981694059626713, 0.02790208665593978, 0.04901378445567624, 0.007805978210883276, 0.048761542345727646, 0.05823361048955591, 0.026809945965426105, 0.03401641057984483, 0.05273985608871426, 0.07628566420246517, 0.026484222617000345, 0.08396499850336583, 0.04274775980100517, 0.047398786841621326, 0.05950942267513564, 0.08312652293112009, 0.037227268931606126, 0.025809197649059278, 0.05140029389651553, 0.02799514527132194, 0.031267692853185924, 0.03619948537239144, 0.009993120930307816, 0.08291736560603304, 0.05221355368473357, 0.0894371185812258, 0.015402540542005051, 0.02717187079871374, 0.024598238636709513, 0.03164810721852607, 0.02950574042305591, 0.04769639284800618, 0.027255418432515957, 0.01473565047020994, 0.05436796146715361, 0.057738595116402835, 0.04599748562360483, 0.015573192372797959, 0.032057694212022814, 0.038052253695505286, 0.018670667796545935, 0.04630678596215383, 0.058167133209926475, 0.06217792525046295, 0.042264159137923876, 0.02759007628135864, 0.028765310698579398, 0.09150896506804614, 0.021476334584276044, 0.06355234827365606, 0.05356702037275799, 0.047370127492373994, 0.046595807953347126, 0.04217010652345996, 0.11663502487804621, 0.02057613530797103, 0.030284803961553884, 0.050256405881936514, 0.03385233752910168, 0.045900916410309654, 0.028500265344196272, 0.008662987365237167, 0.039642062338609854, 0.04747817653321451, 0.08544704155816187, 0.03859599992152184, 0.0724938660559635, 0.015562258382898667, 0.022340581354294575, 0.05807528692868449, 0.034103805890246745, 0.07276727517525997, 0.07706797020810266, 0.03492817012292724, 0.06815024711672338, 0.06586809417292958, 0.04907592950809387, 0.009660104424842905, 0.03728718849860373, 0.06435148523099, 0.005696362152981062, 0.02521370218375758, 0.08188555242433664, 0.03323152668834214, 0.05031588877881727, 0.042957667892258015, 0.03664177474415591, 0.04701199670953136, 0.028448975757665695, 0.012292335609785252, 0.044267092185515555, 0.03343928590296738, 0.0196306353374835, 0.02203735034732569, 0.03781646715417024, 0.03367496519199303, 0.021828145141743367, 0.0595687446935523, 0.022648895354641062, 0.015414918607641614, 0.028018501376913443, 0.013964409647028775, 0.046560740278613184, 0.02260728720425358, 0.026739423741556467, 0.031995078015531746, 0.03914756790524529, 0.09257407243093176, 0.0046849020122129836, 0.01184967851581713, 0.03532327230899565, 0.05220846686091635, 0.03520692270549555, 0.03802118883017571, 0.0470239055463143, 0.015961803878927906, 0.022796888219853564, 0.03952443719871583, 0.03649560133776358, 0.04110442842507074, 0.042165058004038955, 0.04490396789004726, 0.08208351720484995, 0.062213873926309816, 0.048416174587703524, 0.06491469775116251, 0.03609110308330386, 0.04003636013235777, 0.02017997783578692, 0.03518780498134513, 0.0838620286254633, 0.06712803301671821, 0.010308629453873203, 0.042461262069522374, 0.04370563783712926, 0.007498628523711476, 0.028745442208263184, 0.06562976421968592, 0.060399804534691, 0.04044601798898751, 0.047574653815958774, 0.06164077504147446, 0.048603107702107205, 0.06365099741566567, 0.022463825749113195, 0.05938276535861435, 0.044869260276637735, 0.06833099024069887, 0.07631182610507935, 0.08796560923538863, 0.012284387447570842, 0.08978058644119771, 0.03217722499562848, 0.05502236909383247, 0.036570030610047044, 0.013863063875525711, 0.10767435489763176, 0.023605390602061828, 0.06104030766554418, 0.1002632279790217, 0.119614846433603, 0.04398621370895736, 0.05258685683891658, 0.0160484972612692, 0.05909615271394292, 0.058062163842541564, 0.011366279908425866, 0.05768423734773552, 0.027601559939343604, 0.0198241587232558, 0.02902558140997445, 0.011224658021913662, 0.03888336333235906, 0.010381838731137256, 0.052213760528473124, 0.09305823999907702, 0.08404029728544336, 0.08930542806704199, 0.05550548712152147, 0.019655795580136682, 0.03710606999154534, 0.03231728502038506, 0.056566208631040595, 0.07138316880070394, 0.07967977078571435, 0.07925546532797237, 0.04433569152869525, 0.051725639946638584, 0.06322348587996056, 0.0676263272461872, 0.025556612714764573, 0.04925941139639867, 0.007967451829538352, 0.013066380314769284, 0.042247826143378214, 0.0270139379426837, 0.07299897080707936, 0.02657754744793619, 0.023179773218749512, 0.03889729847170172, 0.1092628688521443, 0.025429758130602782, 0.008863209232297397, 0.030772633429977204, 0.021309346568981008, 0.04963981235520013, 0.041769070986417994, 0.01876980915004688, 0.027862600569102555, 0.024131583838513302, 0.052042470929483255, 0.026249491361780997, 0.017570866226789453, 0.016062043610990288, 0.03506437672542469, 0.019593930149811412, 0.028257344609066367, 0.023210830423199845, 0.0722321550992708, 0.04131131812990193, 0.07960383615065968, 0.024984758722806172, 0.013097309199492297, 0.017665901349016258, 0.04173263967517884, 0.05218590940198591, 0.0477781689034835, 0.059969734265318805, 0.038724480527302915, 0.020799001776463082, 0.0354699321812199, 0.01871528667247584, 0.05814247667008351, 0.07046928719407128, 0.018137041592009125, 0.013349760068400253, 0.04066121974779714, 0.023570018407377987, 0.028189519014690193, 0.06363517770002927, 0.019528305142997734, 0.01961031102485234, 0.1412483803447216, 0.06971115892332408, 0.051973764333994164, 0.031376086633592364, 0.045503830056517355, 0.02851143299091247, 0.04983675440833454, 0.04546580145195608, 0.044546442316664804, 0.027395453559414997, 0.05686882485245025, 0.041883758179122405, 0.03855367739414496, 0.03195522612171068, 0.03015240481604011, 0.023639828169478044, 0.06084032424335038, 0.10668076184247771, 0.04776326849335625, 0.05244719901032025, 0.025125261163339022, 0.05116075352435151, 0.018957383863087145, 0.03305205527032095, 0.05619262968520484, 0.012130540713006932, 0.0388496516332511, 0.0514994218434778, 0.009730633351981882, 0.09342141164046142, 0.03760952382318435, 0.04099002468489832, 0.011771265586327401, 0.03917494788765907, 0.028296049286220825, 0.06355054413659439, 0.01942302359478368, 0.0869676877834624, 0.02970035739934012, 0.014571950887329878, 0.045126401518862096, 0.03610915211479991, 0.03652509572284837, 0.01597305675292568, 0.038032515440136194, 0.057410299627771305, 0.043843621763611035, 0.020436791575423652, 0.053448916427911296, 0.02996946110450212, 0.04453282510381072, 0.07460878966676612, 0.038660178937378435, 0.11810360776801264, 0.013037155018067889, 0.04762080678295705, 0.02950243666888245, 0.04886180793325748, 0.04762132389230594, 0.04456044257348103, 0.027881003916263584, 0.014101548003964128, 0.03884192180609511, 0.052042160663873925, 0.03684586056718423, 0.1452865064023964, 0.16382701394538726, 0.09999109056567955, 0.1949481867373951, 0.12146544672789113, 0.20369573105727473, 0.1363329303961608, 0.15927445984655814, 0.2129460895253766, 0.15230833042052486, 0.13616744008275772, 0.21525405197133943, 0.23725183770781566, 0.1648161866732182, 0.1719814070290135, 0.16606507852913874, 0.2383066028837235, 0.18015843034992296, 0.21744555373105312, 0.1940096677431176, 0.14437671570527938, 0.1362414594980017, 0.19480045434207688, 0.1800951514873774, 0.12974750070321944, 0.20540444420710688, 0.1560930039493307, 0.1332442630683222, 0.10447707162388872, 0.2584042147763314, 0.1608299247680172, 0.10628867804283097, 0.0727717031634623, 0.1544026769096813, 0.13564449314388538, 0.061284325821625615, 0.20849973053461124, 0.08196346356623596, 0.0983020811972599, 0.14424271160556426, 0.19126157246289716, 0.14611008156451488, 0.13507352781391915, 0.1893454639902038, 0.18281362980844515, 0.23367072906224962, 0.2114034335940115, 0.12317758429074481, 0.07621778881237393, 0.1277151154053788, 0.14171892686957313, 0.15425728874341135, 0.13924535153613937, 0.1839555757901361, 0.12596390735838683, 0.17556898145666047, 0.22631035546862313, 0.20458209478566725, 0.18952331896270477, 0.11355679932861559, 0.1761425361638108, 0.0893825501383793, 0.146289361460555, 0.21290672792782708, 0.12440304151706158, 0.1707466571561752, 0.0921352189635077, 0.11304735851984833, 0.22381900689534603, 0.22750231167001111, 0.18639965673848508, 0.16468772905007487, 0.07942895359930494, 0.14574099572435503, 0.1345640027354802, 0.1139298688259817, 0.17599403768056826, 0.15223820273193622, 0.0918784109695304, 0.17721406334350187, 0.13635206727250931, 0.1508783813445799, 0.07332034469131501, 0.17631660666196577, 0.16338940920127978, 0.12343582486914051, 0.2309854223483032, 0.1217456587079552, 0.11492269579321147, 0.08268745495907723, 0.18126795549065838, 0.1805541454063308, 0.2044160528889587, 0.15219251324813213, 0.11465595929973549, 0.09615803092357614, 0.13149333847386221, 0.17306643267793043, 0.08713578279580801, 0.18947096451395945, 0.13244650506925199, 0.15769978143995808, 0.1256206693247922, 0.18899033627202436, 0.1293352075041302, 0.16592215716598496, 0.06603078826540901, 0.1350333081978944, 0.194929126469839, 0.24856729342812495, 0.1523059249044426, 0.3664671064865205, 0.15434856045871012, 0.18359163806082743, 0.2039984583614334, 0.17928470707228109, 0.21394307635003523, 0.16491102835824414, 0.12193792379431187, 0.16255779011595636, 0.10157189767567382, 0.16910186638274502, 0.07103322749777187, 0.11491482040934986, 0.15549643596093501, 0.19568718579267302, 0.22537817968235863, 0.15733866291421075, 0.16248838255001655, 0.14927574072874364, 0.09695731343761568, 0.0892842763794526, 0.09136421275475333, 0.08806148513911233, 0.12222304639797058, 0.16891823510729498, 0.21576953721382927, 0.09281261688879422, 0.2077371053277485, 0.10019553645003228, 0.17628236253175045, 0.20070748253455087, 0.16221919457518286, 0.104351410221669, 0.11176083642508715, 0.11137364792727655, 0.16010800947345075, 0.11205450090910159, 0.24846463764627136, 0.17310124371320973, 0.08782815007913498, 0.16043695230637828, 0.19148284929894632, 0.10803432429149266, 0.13161954379850818, 0.1795649113914659, 0.17351407317384598, 0.1652541284960124, 0.0847970006326514, 0.12413525548312934, 0.06191550949287992, 0.07833026094181884, 0.14791297756375807, 0.1949998517070086, 0.200309147457442, 0.07601218613525552, 0.15825312674766587, 0.19238006083234666, 0.11018161511709613, 0.12486589651915336, 0.18424158705578697, 0.12251137124915278, 0.1448320936892302, 0.10962568043220429, 0.09979257420186075, 0.22176239789733965], [0.036533852107822895, 0.1356606269555707, 0.054328216825641935, 0.04440020762323853, 0.03315045543375515, 0.05791471106931568, 0.03773093343742433, 0.011325435930742853, 0.026451692608515584, 0.038780860768090335, 0.024089366648226015, 0.050355235054608316, 0.031092344903417175, 0.02833426941276318, 0.04580574147703667, 0.020250536448832963, 0.02143757053530745, 0.034747871329947826, 0.008261075615131808, 0.04956859682175902, 0.02893504705430279, 0.046884971670806415, 0.07749789875120887, 0.026618096481768355, 0.013886569368262446, 0.046588319443887284, 0.013652030592634073, 0.040999190926912336, 0.0627335535001851, 0.06468053531622694, 0.05511811093216943, 0.04517695183054574, 0.033894441721420136, 0.03510877918151598, 0.05683096095679268, 0.08085583832355277, 0.0413581682369113, 0.015542016424719366, 0.033577783108358426, 0.02623967202981153, 0.06616899052694922, 0.04151552269655851, 0.05869902422531478, 0.03199977413450759, 0.008072738644606885, 0.022355523899257667, 0.08703545592124425, 0.08325927064663942, 0.10500988577522578, 0.024495986966235984, 0.11982581172619136, 0.0635353870870125, 0.04826682574686505, 0.05658824515018252, 0.0217685530773334, 0.09967098838739819, 0.049394645067232276, 0.02630513998860073, 0.0988671170066922, 0.020014569876835715, 0.027581053680830428, 0.03263818009966805, 0.07720107032406716, 0.023494734947058945, 0.08688597684545864, 0.024410623704053225, 0.060308720510933674, 0.0347275891521525, 0.07478223963370247, 0.01730208427855565, 0.045267882636718215, 0.06355460823303269, 0.04331700526358139, 0.012496380255587641, 0.022167242470107252, 0.05868826452041826, 0.026411789003759626, 0.04334163115990739, 0.03226985651699286, 0.04352849915683751, 0.12788587640370094, 0.05111961460281765, 0.04413167082314049, 0.018547400419089585, 0.016995126253835136, 0.014477517144123634, 0.023550040749532562, 0.020573151395505956, 0.07695709430282155, 0.10700617301007433, 0.01913139498942802, 0.02476329611043536, 0.07127203242552858, 0.061027249696874813, 0.03242470586912767, 0.05438158634088693, 0.02747893990618327, 0.060996629162541324, 0.07640282968960463, 0.04041115715799313, 0.04349183801922106, 0.049606491360933556, 0.015205829272857838, 0.026608522297934662, 0.057117581262343356, 0.06390248875944846, 0.0089229152522861, 0.06100248590472245, 0.01737518247307068, 0.008901294335843095, 0.044749700764734904, 0.0465572354263596, 0.009176408958380983, 0.04453572857704374, 0.034828950245414055, 0.01454126619313273, 0.03586575448993714, 0.03779125903102179, 0.050330509566852165, 0.050037480935814886, 0.08937199344678272, 0.04447420022540516, 0.06576659518384165, 0.04495807284969957, 0.06695300490865785, 0.03601617585386961, 0.014842928635076651, 0.06325137148040437, 0.04337317483018964, 0.06183693568492609, 0.08088929338320609, 0.018894612533791412, 0.08355619866521129, 0.030362102233113784, 0.02910665649500105, 0.020099843123687372, 0.03374306274758231, 0.02662204374979821, 0.06997090869493063, 0.02484154816146099, 0.03150534481861659, 0.03193710814230144, 0.020049725651680943, 0.0637190873103757, 0.02888046520491762, 0.021584609621054223, 0.02071169839661208, 0.08885242495565646, 0.11814285445237353, 0.021846558065003446, 0.050081243708489404, 0.05116481762078982, 0.005668307055584005, 0.060789873523096886, 0.07593072034538755, 0.05471874929724201, 0.03426806663253135, 0.03829992226054592, 0.036954319465064236, 0.01178169395819667, 0.0631706602871418, 0.07661757179565969, 0.012710977762546993, 0.058569214456985076, 0.023264150142729766, 0.04896868485957385, 0.05146003343285092, 0.018063899347438447, 0.037945759813151056, 0.006700129334574506, 0.05577315058138582, 0.028661184027911197, 0.03906506789667953, 0.04293061349721205, 0.026490745855675592, 0.04388326298325293, 0.08496496541004989, 0.054982268221436016, 0.03883400811783729, 0.06281545979060954, 0.05536079992570224, 0.045370798888466055, 0.04986654373727018, 0.09481681781190057, 0.030125733464956287, 0.04836870394947548, 0.038499334947236126, 0.03698502043862978, 0.0658128515727097, 0.027984347262029207, 0.02686344188517861, 0.04799004967114137, 0.02530643712699173, 0.05498035683206493, 0.04378896139021363, 0.046695541109769576, 0.02094015156129195, 0.041084134755956556, 0.029807119412467848, 0.053207058639776324, 0.01918139946346562, 0.04093791538428876, 0.05178247600974095, 0.06211179271039944, 0.1307659686332749, 0.03750511369998417, 0.05818318275194015, 0.0273714539399671, 0.04378528033773746, 0.012170434741663837, 0.013867105946936195, 0.0582387624308467, 0.0712757785954783, 0.03281962419409425, 0.027063942416721297, 0.033010789944279584, 0.01847499936458565, 0.012792312359857946, 0.05023437702367383, 0.03369491795198091, 0.04983122708396085, 0.08937178660304317, 0.034948463792041425, 0.027652464566692233, 0.13188908417378703, 0.030607614260647568, 0.07132967288095145, 0.04799392224559861, 0.07666173676449446, 0.08224111681263294, 0.020919834909540032, 0.03698715782393852, 0.06950186370241065, 0.04500934328403204, 0.058943111329309406, 0.055194769520312555, 0.11964820956270542, 0.028552615962501977, 0.03207662232941197, 0.0362536707712758, 0.05753784177584514, 0.051133327576662266, 0.03521183715952981, 0.030485541980353095, 0.04032901721075177, 0.04166056995370215, 0.054609983964192296, 0.014932866399777273, 0.03657796728094259, 0.021883828242519693, 0.06448923550065487, 0.0937832196453406, 0.02078967465598497, 0.04392824000528744, 0.05925693158661166, 0.09926018905976128, 0.14258941725617455, 0.04358137071493172, 0.041980178005272345, 0.03662941391549764, 0.01736141395785155, 0.03397721752163864, 0.025181459458244425, 0.04014170105238596, 0.032310654529400414, 0.08384417111594832, 0.03330524732929564, 0.08944038211578324, 0.04191563509765171, 0.007082070608908732, 0.01055599445657384, 0.01917009775136267, 0.03931078676795287, 0.05432837004322679, 0.10650052433653225, 0.11482351805053412, 0.07088724944380022, 0.03297936884806522, 0.02147165378705869, 0.02726558250405135, 0.04243882718465982, 0.051648644279808774, 0.038097487356994426, 0.036967718342859904, 0.022143974464627045, 0.021756870236488122, 0.0872753257112157, 0.10020793941352638, 0.029161058313724016, 0.02970098559143803, 0.03336268477141857, 0.058829799264429085, 0.03161592003438742, 0.0908532397701375, 0.06683584708239763, 0.00938259769276145, 0.06273020569595598, 0.04272362420095071, 0.024574397980505903, 0.0978998237499787, 0.08797483293399697, 0.009172454029471885, 0.037841912764575214, 0.04810957470908762, 0.06732648043262382, 0.07987078714875445, 0.014769739467620611, 0.008873904777330258, 0.03368380584663922, 0.025089678294476003, 0.0465968766460015, 0.014276934258129089, 0.02259742573744828, 0.035607326219999985, 0.02431698477706842, 0.04040109076266808, 0.04652481075496443, 0.024856067442845915, 0.03940179035247814, 0.041321028294342185, 0.06762393705186344, 0.02382017484295272, 0.032102399272844195, 0.04014767653819534, 0.028337379729735757, 0.030403357983056097, 0.07024850065429365, 0.023851781715488723, 0.04682919280903955, 0.03089726061349915, 0.034650355998066165, 0.06928711393547636, 0.00568388018666977, 0.06695694260058865, 0.04540151518379008, 0.01561883589132659, 0.1189606303289052, 0.04544592913120024, 0.019335852365099618, 0.04879117462663882, 0.01783552662199063, 0.010465449567193226, 0.07870156843695911, 0.026520307273453763, 0.013359793904988516, 0.033017087187017166, 0.0714924589039818, 0.054056952752533464, 0.045729477424174554, 0.018198060495178067, 0.03010113438170764, 0.05498129528977218, 0.13756037179020145, 0.3345185740580482, 0.15448610388463543, 0.11944404713088468, 0.13811359452384134, 0.16290130394120372, 0.13386309357179751, 0.1736046554100129, 0.12830756950162112, 0.15691118585246225, 0.09586932302843179, 0.1089685838369112, 0.10353031718442518, 0.11957858749214681, 0.10790235032477688, 0.14193168480790433, 0.15656589470323057, 0.09088165397124906, 0.10316370580826076, 0.13726236358765634, 0.12475318200285397, 0.27632972225546837, 0.11714592891474886, 0.13089338437684123, 0.09606077606158872, 0.21016053254565886, 0.16741725435901075, 0.1720759576006282, 0.24805036794033744, 0.127681645023967, 0.1767162900538214, 0.08838466699084929, 0.09463453485119729, 0.09466046692743417, 0.21322100783788392, 0.1067216173114796, 0.19068886045246355, 0.08504706705289503, 0.20708110423818712, 0.12549750536920565, 0.09137886035586558, 0.10356829216283175, 0.16960261209357172, 0.10041097569609843, 0.12402801083460932, 0.17268960934973535, 0.12568609323352575, 0.21869568664941097, 0.37561324635340326, 0.08913022375875905, 0.19663276811761243, 0.15853539950424628, 0.17206166239996112, 0.27773255181889384, 0.05100823307950651, 0.18561999373618635, 0.14199617408937024, 0.18259089740533985, 0.1536983816373733, 0.09477786990183015, 0.13597190380096436, 0.10732471236899015, 0.19816592455871646, 0.14814507156129808, 0.2791949830228283, 0.08765240950930504, 0.15525643593601643, 0.20524638494656933, 0.1731906921392487, 0.10382623396693699, 0.09689471639332273, 0.16775313794853228, 0.1640070446075932, 0.1104193015564834, 0.09744601624627268, 0.11438067326502455, 0.12663865461945534, 0.10120707128437297, 0.1219935877428901, 0.18082212296224412, 0.3583576061552571, 0.13066247015470459, 0.16585950649553732, 0.1241844459887474, 0.0869038649984906, 0.09796348565648641, 0.0865336989743575, 0.2367689418456247, 0.17438439502110406, 0.1997386877455058, 0.2658201910315022, 0.1424549075384294, 0.15099660403305484, 0.15943389806535938, 0.09153180214906893, 0.1626327901237434, 0.1217762639205302, 0.13452180661261082, 0.28285954928686546, 0.16734004801800176, 0.22096640190049527, 0.07408140707881221, 0.08595349462402445, 0.15345965331840902, 0.1432436256999931, 0.20940498599121649, 0.11696330887535888, 0.11056954672019328, 0.10244305455876936, 0.1290158714137731, 0.15735072113813894, 0.14515833989266427, 0.09829694074728797, 0.14669653719231007, 0.07636990323061905, 0.14746135341063624, 0.22764363957028236, 0.20101960207666122, 0.16352122228953148, 0.10871281006163168, 0.14787277326949183, 0.1164534543791125, 0.25515891311149447, 0.19733514817010975, 0.17907011052293165, 0.11099508557949336, 0.1006514200520131, 0.11946463191341009, 0.1534188667973203, 0.24941584305657497, 0.23839824232122592, 0.07158478782061609, 0.18399945730643888, 0.09412853377721003, 0.12209733136959615, 0.0977279212806494, 0.20479270767781044, 0.10391583561056084, 0.18073704123737352, 0.0844084331765771, 0.13594794057069287, 0.13166155606027574, 0.11457116868827613, 0.16026815249314233, 0.16060809634866255, 0.1162094783578669, 0.10060820503220444, 0.2476681973184309, 0.32831859384332934, 0.1404601831229464, 0.13855411040206111, 0.18669449333702365, 0.0938944326293084, 0.16066927613029558, 0.08960289234716086, 0.2379603617854657, 0.11122872707464042, 0.1994822015084567, 0.14259654187387036, 0.10325626455127232, 0.23453086194011474, 0.3680885469000186, 0.14373157774248432, 0.17817447713065535, 0.10307153777009058, 0.15755011850307066, 0.12224417510292224, 0.11745005049892973, 0.13255342029996459, 0.12265648362376999, 0.16949569686285912, 0.16045124750704537, 0.11971726472820006, 0.11647903405490423, 0.08094560084564072, 0.11508690673978099], [0.08699798656086769, 0.04944692290718517, 0.04696009042222173, 0.014465915700120312, 0.05153883706718203, 0.02026823116466403, 0.04913547369200857, 0.038243204941071814, 0.02932716149746651, 0.068505727235348, 0.014698166745684802, 0.07504132290881488, 0.03575344983067724, 0.006115944199864903, 0.009306017628630564, 0.05613202446951501, 0.03593012885821443, 0.030728585289550886, 0.02812897508603431, 0.02694573313478501, 0.09676611321347375, 0.060197250887511246, 0.04701114252149578, 0.012491628595237291, 0.07007121258685667, 0.03810331345565858, 0.04285200521530163, 0.03681557711153742, 0.00960420873466759, 0.01872151113686062, 0.02782841772592116, 0.049886837406384374, 0.017311470770847895, 0.03726191908842133, 0.008445307311992492, 0.07498592709101017, 0.07573735975329915, 0.04248258612689473, 0.06139766469958329, 0.030601926057809786, 0.037382539632099296, 0.026279071931757277, 0.10869480699541108, 0.038835567106763204, 0.04491692626728647, 0.09760494118616467, 0.024876115963824337, 0.01747074619596524, 0.05018108794766088, 0.027058725357956948, 0.04127912328488404, 0.07052564062178135, 0.10572626991497894, 0.04023847710942069, 0.015989014364388442, 0.03028812495270564, 0.06702756058544883, 0.05764259663861125, 0.0419440531292029, 0.06078604308347549, 0.03855165875246448, 0.06431376306159843, 0.02476531283689603, 0.025234949632337498, 0.05517965843600612, 0.06016499092501979, 0.06815721851683433, 0.07443034480656348, 0.029734572801258297, 0.08994970035048262, 0.03266470206360663, 0.04691738485088272, 0.11618805087862477, 0.07241988494511574, 0.03498244745236251, 0.009433102996779547, 0.05286764338492386, 0.028633447814612623, 0.012566128730653756, 0.0669789293240155, 0.03025430791650809, 0.054989775883093964, 0.041868562825144305, 0.016032770433793628, 0.012857186600505825, 0.015429652393645337, 0.045828605371136824, 0.0111542210253256, 0.018863538092362787, 0.05553657113904915, 0.01901732641272247, 0.009116340961848057, 0.024794056455815033, 0.0206354056154528, 0.0253455727286036, 0.024265141692012552, 0.02765369030737108, 0.02934450955851184, 0.19472830418136813, 0.10573459729071587, 0.04341956145400482, 0.06369974359028763, 0.036985407313031536, 0.08597650024439059, 0.023619342978382786, 0.03283285070210695, 0.10398292193009008, 0.04024441429083386, 0.06038041101888784, 0.014694002100206433, 0.10660229911727291, 0.08049121111511223, 0.02010229843548469, 0.07337837585157926, 0.06676038742185601, 0.07406195610641472, 0.01729676188270171, 0.03734143518452202, 0.11783708577915547, 0.022540700757094932, 0.08746391357553583, 0.039199114131230506, 0.060762623775630235, 0.07058046187364286, 0.04093618019514027, 0.00619065931870512, 0.028513158603961912, 0.05733527663734652, 0.022235554530315345, 0.05893932302452384, 0.03236937516879651, 0.06183474850390227, 0.06580999406475214, 0.08224461017356766, 0.035497273859237476, 0.029048864737213142, 0.02045292155666938, 0.018724853195430293, 0.024322540829739264, 0.014002022648891135, 0.045557881390014966, 0.02910356724544639, 0.048210119918709805, 0.039680382056582364, 0.027848648192781596, 0.008529959070015579, 0.0354293410125519, 0.04050456242816102, 0.05980650774173199, 0.030069182769605712, 0.027074215655785897, 0.07941761549802558, 0.031106965691452066, 0.027554231027381557, 0.034728136905018366, 0.02914317782157131, 0.09654143494704077, 0.10789121906723707, 0.03550680399301552, 0.048271495052763534, 0.015910430022725658, 0.021171630773272727, 0.04802383031816252, 0.008974223991014786, 0.004492596227435335, 0.028151697253868468, 0.023175128810708562, 0.03291144749269851, 0.04898124487109242, 0.04358322464770848, 0.032397896622217474, 0.054944787369740594, 0.00666928950757269, 0.08707025163476506, 0.014412397755339984, 0.02661114614907532, 0.09881699953468577, 0.06333549942580924, 0.060942547185526746, 0.010238465376108164, 0.06302419193689862, 0.01897984747624686, 0.021527334972615206, 0.03481537133695618, 0.052453097887337215, 0.013403541355904554, 0.043027343588971326, 0.04821277058292781, 0.050017344314725175, 0.011678927093594065, 0.025743580303124847, 0.03807466559773011, 0.04389713683556165, 0.03102847232273029, 0.05248068471349055, 0.00798533280049601, 0.034047157518685825, 0.06000055398251261, 0.009112364007911135, 0.06332089778997245, 0.051043021132148085, 0.014361308309279624, 0.08263326189931362, 0.019941241855943398, 0.058444326803568876, 0.06793958825930473, 0.038729402642216415, 0.019078249554900874, 0.016600508618378834, 0.027450031578360547, 0.030598670184131593, 0.04776041098539868, 0.09640442778266246, 0.06076919681002056, 0.01216643863552881, 0.023326178366738944, 0.0695431941459256, 0.04537725317922812, 0.04165587766516594, 0.02294486193286796, 0.07870087895782725, 0.02343422357713984, 0.0440146240796293, 0.027646636552808267, 0.04302422178067988, 0.07257933082479624, 0.0540599481563174, 0.05732689563545489, 0.03980538845362683, 0.08442235299416127, 0.03505649751112346, 0.016325979095493114, 0.05797429738806621, 0.027667981677598534, 0.03222137847314439, 0.02728453743451786, 0.028191068427517053, 0.024863626815438754, 0.009701154288655568, 0.04093942840793922, 0.07862692849049646, 0.05236318980854365, 0.10699833593060894, 0.033369801728235136, 0.0066906987922266134, 0.03211313982554261, 0.09114564020907687, 0.04185308401863422, 0.11785832173641651, 0.054078345757818995, 0.03820178256700597, 0.06097854948752831, 0.020488808945482297, 0.0071229179382264135, 0.0752755466307844, 0.023540368889488524, 0.024432828762538494, 0.025823939095942244, 0.042697094576132875, 0.06222042014762279, 0.021076306452854507, 0.049785127743117275, 0.051448473166073524, 0.04462418874966041, 0.016445345170195066, 0.060754323212970654, 0.04628303340606151, 0.01610073009355655, 0.025890749623818744, 0.1072374013282599, 0.08106780719132194, 0.04731113106132515, 0.03891137916775, 0.07384853167158943, 0.02186934151987155, 0.10031726782120044, 0.04032197303228802, 0.011310774923091935, 0.045567403862913775, 0.044240769404437275, 0.06634512946249978, 0.012759835977527886, 0.028176631500583985, 0.04704687286228423, 0.02186554938464636, 0.03971268032347003, 0.054740705377151894, 0.011706967826842541, 0.020825722923261986, 0.025637699291110042, 0.059611507721485636, 0.05487736780196429, 0.05503371868643069, 0.04099410410309511, 0.048579136810956464, 0.023428989281397194, 0.03043520808850806, 0.04091941053047776, 0.025101537335543864, 0.008852904392105919, 0.026893989641159296, 0.04503075161107606, 0.1142908034906272, 0.05013922507303858, 0.03119057461228823, 0.024152316092964143, 0.03699956461787224, 0.010246736252860678, 0.028580817574214552, 0.04381409290456965, 0.053271455990691344, 0.049966491398311434, 0.01324194276915683, 0.03695149643106326, 0.04702516959138936, 0.07773039877534875, 0.044221601884571776, 0.024308142207202413, 0.03800986988109447, 0.04371089320028982, 0.020327300374065677, 0.060161566511998256, 0.09857368234905506, 0.07876372881113522, 0.02706113661969862, 0.029830609583446098, 0.03479379447056882, 0.0029107683052819583, 0.04817293401086523, 0.03560084128572095, 0.024708769802424698, 0.025875627048193447, 0.03425125100259339, 0.050836828567328, 0.031014315017889586, 0.01082771052155764, 0.03606353540934863, 0.054096885085586584, 0.06927632741750249, 0.03225715860964791, 0.05444178169953728, 0.017737509502518563, 0.01921912163285719, 0.04533885302202356, 0.04700084629979345, 0.03003934747539461, 0.009869704165706232, 0.02427625954301367, 0.04277340459427045, 0.02024973588695209, 0.01508715267728774, 0.032585584333226565, 0.32213911414146423, 0.12145742578732392, 0.13372767987030168, 0.10077178012579681, 0.17076927207169995, 0.06739476184931494, 0.13079509529615604, 0.20279666559109766, 0.1032582487189962, 0.19659331458951199, 0.21289626316678142, 0.14535174645002813, 0.10458687500607584, 0.11793476965038047, 0.07794491871590577, 0.14285270635399128, 0.14727110313552041, 0.07825798054616298, 0.15167779409356658, 0.054141352659151445, 0.13576760347331726, 0.10623378784305627, 0.1258650590335169, 0.11732047438741693, 0.2198902781932585, 0.10188928024182398, 0.16565779554507426, 0.08556526424663682, 0.1265363818815639, 0.14051547934932096, 0.16607148302418573, 0.09144878120071466, 0.05852350582098288, 0.18861863041116347, 0.07424464509371789, 0.16264469513008672, 0.18250471251385827, 0.12906182136747146, 0.2759089254804196, 0.1446783398428271, 0.10064978828473438, 0.13556921734444558, 0.1953266188502312, 0.10203540385250123, 0.1706964937188933, 0.1916692997779577, 0.12307940246236902, 0.1201555206470432, 0.3160798183131603, 0.08863330082667452, 0.17681528393539692, 0.15369236018628846, 0.15061703811009086, 0.21943917497992518, 0.10734946466982366, 0.11609110245180708, 0.1870457752938232, 0.14225060721078228, 0.20086131298974638, 0.10185707390548722, 0.2012229830987992, 0.13447194961049866, 0.09764624098616262, 0.1523248932414478, 0.20818764163601786, 0.16820031879169328, 0.14757965270790363, 0.17433334292183, 0.12107658815840561, 0.27883749575384204, 0.16025886750750004, 0.13463354819724638, 0.2429749281896699, 0.12038685621753817, 0.09111341855098164, 0.15344741123337902, 0.14762793156889178, 0.09084133476379419, 0.16690083448925327, 0.23661184785587175, 0.17037922606593178, 0.15572433179665, 0.16141877059013615, 0.08555903595181243, 0.11955889137161356, 0.12179421336059609, 0.15489874948416987, 0.15557670665364112, 0.09134575769665743, 0.13619547890078637, 0.15609317248867405, 0.10541506201749849, 0.10374499800344629, 0.20985785120677566, 0.15983473058910141, 0.1570918293850076, 0.1293722555161484, 0.16151787172402107, 0.3146602880329855, 0.30400143095081855, 0.15148896874198992, 0.1314868573700228, 0.13993124537650617, 0.23917959071695807, 0.15816010835189975, 0.17897776628453888, 0.18673647495527423, 0.1283751997435766, 0.12045593436567054, 0.09153292829831762, 0.2036007974416979, 0.16477152374723267, 0.11068806052207948, 0.26950357241495965, 0.18883606148583276, 0.1979914710165993, 0.18003415556684618, 0.1787180471564493, 0.20114478084348864, 0.11875070691589387, 0.295315035769055, 0.188092113502564, 0.11259841567446148, 0.16890199404330025, 0.10394404296793285, 0.16895873051497245, 0.15877178359416225, 0.14881420339788162, 0.10333851175082308, 0.17138395037862564, 0.11550106153252626, 0.1852079916505083, 0.26248292817223456, 0.13131755193875683, 0.10309578445289405, 0.09290234110648594, 0.11010285361760086, 0.11258153875748958, 0.19245587289333346, 0.1620698993604991, 0.14341840099903846, 0.12167710916049058, 0.17516493136363645, 0.12915928307319843, 0.1484392186807048, 0.1634203591534207, 0.15395255428889107, 0.17752115734882895, 0.16930881737461015, 0.13314081055502738, 0.06516608950351516, 0.16223784115525985, 0.11580456258548845, 0.1591452361354905, 0.09486170290338417, 0.10347630032488417, 0.22075520678152963, 0.191044555075707, 0.17092875625577666, 0.13417778716933343, 0.14642471387501688, 0.19449956564893647, 0.1415096316486597, 0.1139579306266481, 0.13300023342092193, 0.12280518128987282, 0.08801680689136829, 0.17415919581488257, 0.0888556884902139, 0.15667736049621336, 0.12686445903513702, 0.09583981332158852, 0.07638537820668952, 0.17184734164226442, 0.09756405507364581, 0.14868998990183876], [0.05080592458046252, 0.019319354661650235, 0.02419030064746978, 0.03797839132828578, 0.04704377786707013, 0.011035463032913546, 0.029709002701565627, 0.034363283700640165, 0.05712346481760183, 0.04672886593447578, 0.017996156107514136, 0.04496123679282685, 0.025037837124639944, 0.02596756525998635, 0.012966298588341283, 0.052156001329422004, 0.011639672748353935, 0.009722856601940529, 0.06231106367082365, 0.03997033867504328, 0.016723641930448434, 0.10240232166383537, 0.0592885097308505, 0.04623804872314777, 0.09968362883814882, 0.02353437616670084, 0.027656409919502276, 0.029237462177632317, 0.020053826137295654, 0.09267465211451055, 0.05837932424319368, 0.027485905560634794, 0.0512212629790508, 0.03240161980952948, 0.015437219427117418, 0.09513044654722176, 0.054072121293434215, 0.023316288171636484, 0.09259175374022416, 0.010935657098138285, 0.017857884898060755, 0.05191803526794238, 0.08669132922565745, 0.0569605408987451, 0.02507147796061491, 0.01555565662021118, 0.01376702709333791, 0.0364574310069363, 0.1002488025434075, 0.008325197174394084, 0.0392316690375728, 0.05482227075845004, 0.05171990960896496, 0.041028164372208624, 0.03846947283994767, 0.08020213549776424, 0.04029165510268461, 0.0362538316497399, 0.05834533292199335, 0.07773791409788594, 0.0855437295150853, 0.03237525872405499, 0.028173526929270838, 0.08617268770091957, 0.033306484561293356, 0.09340138610212073, 0.0438692627264367, 0.07132425663932677, 0.009984108863488562, 0.00693829984576892, 0.005566000801345875, 0.04085337758184441, 0.06401313866879191, 0.0470545107588893, 0.024421605574447783, 0.06720292577219587, 0.07368114912101338, 0.03278229272954407, 0.06394850766105999, 0.030188309441831325, 0.03842649913783516, 0.10669090484659519, 0.05932515937714808, 0.0329736385103916, 0.032815659689086105, 0.060037444946506334, 0.10817710009794082, 0.01622127402844208, 0.02133576894148944, 0.03114387772286371, 0.025053304439831166, 0.07573021215296562, 0.024263333724511248, 0.048172922519546364, 0.09058550736235996, 0.09470062525642496, 0.06573958292363152, 0.011822548469588643, 0.05437159655435432, 0.1259072015302316, 0.03447652681760731, 0.014604609215541955, 0.008676134391627725, 0.03920356127163095, 0.07359435135919241, 0.02095509219103523, 0.03987940786887081, 0.009870718274595998, 0.03511289690410899, 0.04427913891812486, 0.03478030366222224, 0.06303976267395962, 0.0676158395025038, 0.015875581640660042, 0.04371528288409595, 0.0352007020715504, 0.02199862077231369, 0.01007052741178702, 0.0462564884594852, 0.0410204460363715, 0.05776630068618444, 0.04548938929914467, 0.06970703737029145, 0.060159758544496955, 0.009902891094586062, 0.0334356737984044, 0.03709552096082799, 0.030230802423771352, 0.04817774504302971, 0.027128561933134353, 0.07198624853645602, 0.09646690225288754, 0.008095532633183945, 0.02827448199593252, 0.017703211746148525, 0.027324737898344477, 0.10192564643558957, 0.08830671754455374, 0.08793534876237954, 0.0035042796028597703, 0.04170304186822426, 0.026566215092316273, 0.0766671836496361, 0.008144628335421365, 0.01694878176485579, 0.06255248095840216, 0.050703544590261676, 0.027426010891494733, 0.03952583147873802, 0.06377071014515336, 0.02232033173523603, 0.008275050974090495, 0.08406429882011107, 0.0496914581726155, 0.021087276831930204, 0.08719946002407421, 0.06173087081180946, 0.01814436730778506, 0.07586423923531849, 0.04604111050045298, 0.042213417304259156, 0.06468215942262642, 0.01725474962093417, 0.0845747891693346, 0.04976820486086992, 0.049174827628678856, 0.01805644722715501, 0.07142341906024564, 0.07445750262347922, 0.006323196838850216, 0.0068404536596649605, 0.04457356949006358, 0.038926570691288485, 0.06139293410665086, 0.012495837290771307, 0.03007206517542082, 0.05243446662901871, 0.010070209485298444, 0.04772727385223393, 0.06523018808013971, 0.022113796346069827, 0.023237078510705503, 0.03822008057707741, 0.0715299895513923, 0.03184043359191668, 0.013723357208824206, 0.03663581841054463, 0.12129005855850636, 0.020445454114627455, 0.023708971435083978, 0.033638729233174555, 0.022423152225993337, 0.0676649687210879, 0.033476444997734604, 0.04473114611520883, 0.0505389659214885, 0.05657773059342177, 0.0756571886520232, 0.02301888709377137, 0.027457625424909978, 0.07040605429680118, 0.021058297640974485, 0.007194556735245692, 0.04292247381301657, 0.00408858779044221, 0.08590995784728758, 0.014875106243116241, 0.019287998682909438, 0.052733528202459704, 0.0167112868474496, 0.01619600461825969, 0.04065429814340126, 0.05320623892569735, 0.04507331162570946, 0.07273617966641342, 0.03347942891019968, 0.012595020779108089, 0.03799573555889149, 0.07717812599073495, 0.021463966094738534, 0.05652496628763695, 0.043298680440432606, 0.08757819857207999, 0.029709964141910596, 0.04566285841827912, 0.04318736020415541, 0.04241701666145556, 0.039014088575758284, 0.08190227612372368, 0.025057797545507073, 0.05308164621613199, 0.0687263299140238, 0.01702436016902568, 0.04131000045867216, 0.009030278644434387, 0.037972469468631094, 0.008779250783845782, 0.03688480081637541, 0.07338676451435013, 0.03654418280348182, 0.03312966380749018, 0.0038848658591779254, 0.11985896801155423, 0.08586377806721196, 0.05333634746831752, 0.04666399360904771, 0.03758631135907866, 0.008872433888515639, 0.006407181621574227, 0.021007638161761627, 0.0324966951513723, 0.08207526643790546, 0.12711513832572008, 0.021281891892994606, 0.05772606191796161, 0.037609025866033576, 0.07177630214080696, 0.018209306665906505, 0.05237691810414676, 0.0153040963285152, 0.048062475623502854, 0.03689686670118282, 0.09263477723805175, 0.06612091850970062, 0.025476834233549815, 0.06765373021123872, 0.0623498545328696, 0.09349296425258921, 0.06336081097082746, 0.038575104873387084, 0.0471330079580507, 0.024409645026729956, 0.08163173983414328, 0.051170984628580274, 0.11205619396341425, 0.16988280109099804, 0.09941694597082754, 0.01271586157306428, 0.05208729473393291, 0.032277808509646885, 0.04947944333957088, 0.029446834007338173, 0.05394150713278402, 0.03340757369334179, 0.06483006035728801, 0.03125203976167306, 0.02583170148183502, 0.08625010854654735, 0.03474902812271349, 0.05878730819770887, 0.05718807667313565, 0.04362403032099528, 0.01651754704183869, 0.021402200255843423, 0.05925224695895469, 0.004072751795437428, 0.03855654639342139, 0.05648118436276432, 0.023463108922324838, 0.08320071854658666, 0.06151101889929945, 0.04985151692263542, 0.04501641810601277, 0.03529694952791737, 0.07457532694623356, 0.03871717970938452, 0.018598998356009686, 0.02194943601235507, 0.06015833362095779, 0.019268484508258202, 0.02904812929280583, 0.04285601185514562, 0.05620960236316728, 0.056773270705654744, 0.0518354969549804, 0.0033931094719352383, 0.03297579887833807, 0.02755671889791566, 0.019217505187336958, 0.016222900050061367, 0.031389763218260584, 0.025173375315423456, 0.027732716107200232, 0.05102900555357338, 0.03979207384550283, 0.013034503396239974, 0.035382513888180256, 0.09607047473471012, 0.04535216379970793, 0.045505071118954694, 0.00866940239399311, 0.06354268024405164, 0.023629206360407898, 0.015011110789923659, 0.06331334416303905, 0.0028764353567479, 0.032240791141145655, 0.017230947269126773, 0.023055056019896464, 0.11525369940265534, 0.05572341615334154, 0.042663865512417215, 0.00674238195642829, 0.04389801017579533, 0.08438924267407387, 0.12038372291792786, 0.017003580034079573, 0.011311950868055707, 0.04846246928096779, 0.019392364756053975, 0.021918474568895275, 0.00803557571940004, 0.17467791394841287, 0.1652454870242265, 0.15074488286289478, 0.17852235765707108, 0.1154938756277965, 0.09100498646617898, 0.10294340190387542, 0.1906572056994323, 0.1546945257653152, 0.1576232186128055, 0.19181310980310365, 0.2216429801117028, 0.0937024126910875, 0.11191158720682706, 0.14614182824809707, 0.15609332570625892, 0.1608084283408619, 0.059449951269573746, 0.14821245665511779, 0.16292217217626112, 0.12446218350481604, 0.28856307388313357, 0.14103926898490998, 0.14241991264204826, 0.1774989714425418, 0.09773764293640853, 0.08582093843048619, 0.249929535653322, 0.17766559556607278, 0.21887288278629705, 0.14361589846591796, 0.11387612775809343, 0.2036754297272813, 0.13324466143404284, 0.13129038646096183, 0.15340156853199005, 0.12703240849077702, 0.07618100127024997, 0.14112343140427144, 0.07063029589311731, 0.10857034069035323, 0.15763774363984986, 0.1979222473117613, 0.10690648198848772, 0.12149462701692698, 0.13622135735086857, 0.1655704615217063, 0.10928029735242167, 0.23180553479300392, 0.20398882097534596, 0.16384107931967706, 0.12549385879068606, 0.13099148959642457, 0.11509898028546765, 0.37237756675289524, 0.18160976860071384, 0.08720106114783595, 0.16422046138153923, 0.08725836452457213, 0.2581457060671622, 0.2366849326438481, 0.16330991991825644, 0.1709770657602818, 0.23603970275050212, 0.18641787430932447, 0.19551417249585354, 0.18813354353750908, 0.19999106775128073, 0.1230589402539115, 0.12001319683247036, 0.1639773050743726, 0.16299220793429883, 0.10818345862771235, 0.13567224084850282, 0.11038390829438165, 0.16449110492342905, 0.2679115497777539, 0.15307904551586798, 0.14390901902750616, 0.15904532294840584, 0.16981509424025015, 0.17527308765678637, 0.17696995708730914, 0.12093372042140654, 0.18748380904716833, 0.20528747790282775, 0.18425254211310418, 0.16789498678859205, 0.1493629981433192, 0.18639902854638715, 0.1093132314722865, 0.21797669781071527, 0.2285025160639517, 0.2244185013396125, 0.21098643661506716, 0.193110617598699, 0.1942523031104957, 0.22963833334224842, 0.30782577251234366, 0.3252708815759228, 0.11529609470838502, 0.13962493278086185, 0.0762737668570011, 0.16824386322930937, 0.14064652634964836, 0.13655920212547626, 0.13264243971676598, 0.10503956402141242, 0.10755855304699753, 0.09190102588505515, 0.13610077511158683, 0.15395021005984277, 0.15172838654008605, 0.15011054673983207, 0.14142602081260375, 0.23521237375755466, 0.06752619955448375, 0.1063530064458328, 0.1963991113007069, 0.15917872949954004, 0.17512169336119007, 0.2630101805252414, 0.13272243461781932, 0.14548406515630985, 0.12910173454832646, 0.12886326669925643, 0.08330984011052117, 0.1668076475541438, 0.2535642704535877, 0.1341668780772917, 0.12520651453204695, 0.13168443144569475, 0.17054283180304114, 0.19050426390622893, 0.09103626583612735, 0.1473371245928349, 0.17739754140136704, 0.24159164919007212, 0.15290557256629392, 0.11463505276028188, 0.12095518620504488, 0.08517949301148615, 0.12448128973764759, 0.055447938596649524, 0.08945718242396271, 0.11398115841251229, 0.1343777820828461, 0.10819881869059418, 0.17899599917713674, 0.18410703137276635, 0.07722190025472835, 0.19044484612682175, 0.18603867610856412, 0.16932637610983464, 0.1318085223676697, 0.18717397244707232, 0.24186701183357548, 0.12128653455405466, 0.12037675917869615, 0.18689556077363031, 0.1640851702541113, 0.22734808284909497, 0.1669702267334346, 0.22584685695267495, 0.186647271677371, 0.13544043796437402, 0.08568670450439377, 0.20933495023317877, 0.264713040763332, 0.238292231074264, 0.11761922569524859, 0.12357532181927275, 0.15366424475946736, 0.18346474325704962, 0.09788734417769218, 0.12670734972362557], [0.037580266925356084, 0.02056114296729286, 0.03516241682753448, 0.0176694885557217, 0.040867075233930544, 0.04416301531056243, 0.04946182331731243, 0.030807959659385587, 0.010639913643019335, 0.0314147510911308, 0.003184830993338819, 0.01886371237736556, 0.013897198838211838, 0.04184613560116099, 0.03490263258197135, 0.026747469579981222, 0.03204280720843423, 0.06806233086653295, 0.00846421723479345, 0.10187735991372217, 0.03539331955835223, 0.013427704726646264, 0.05734065840501459, 0.02081358234488195, 0.11388676105848244, 0.08197226591648595, 0.03177218090352272, 0.038038736074081356, 0.006460713451698182, 0.01635426497687736, 0.06188746684441163, 0.016853924758071383, 0.025615865785268047, 0.03416698133092254, 0.052447624189118226, 0.07134049770332153, 0.03909157070842001, 0.07260801315668129, 0.09098331383880108, 0.036639840372147105, 0.020403313533132596, 0.035773199577365196, 0.04196244690026488, 0.024851562845851147, 0.02979492520793311, 0.07117291596988518, 0.01614130019480663, 0.06576142409035275, 0.02761529206538633, 0.010239541729641779, 0.005436675104823325, 0.010488365172228266, 0.028564298803347255, 0.043181357905268676, 0.023937204349485618, 0.061350584766196634, 0.0414268212062457, 0.08451531010289347, 0.07400746427236066, 0.04998379732452093, 0.037404698725309105, 0.014770445226120853, 0.04904769916808413, 0.04459170662167092, 0.050430951354604577, 0.0599374283375519, 0.018069809715774272, 0.01766796595597219, 0.04610744222337681, 0.10496879281896739, 0.05297357419265374, 0.05510422558854184, 0.04296167070166238, 0.10609681132219492, 0.08476241942374937, 0.021551799990477103, 0.14581562800993844, 0.06230377434422413, 0.04853024891006851, 0.05069716307785242, 0.07025748686564547, 0.23183950313156654, 0.1423111894438344, 0.07446937698630557, 0.17042195845034816, 0.12162862345576288, 0.07097705027028438, 0.01770412339077842, 0.05851466516633669, 0.02516390646867935, 0.034155309981396126, 0.03707872448308814, 0.020899591036140922, 0.029001780973386862, 0.02616471990251974, 0.023225661885413914, 0.0530429357933181, 0.07720088646296533, 0.11498629641268523, 0.22361115191973027, 0.019260099675926953, 0.050695646223762346, 0.03050098631290659, 0.085110989429297, 0.06849768331214305, 0.020049974630256335, 0.06381418563485627, 0.05136610722289451, 0.06188403860095048, 0.053320784392135764, 0.024443163288637035, 0.05815255072628779, 0.042805189582248854, 0.0266203775085629, 0.04807543783118168, 0.03801643908504517, 0.05213002711834927, 0.09087936336835546, 0.054670056748774745, 0.03084333951494867, 0.02075237383495175, 0.02235867443584627, 0.03146537609638707, 0.004275763658956895, 0.031008973469837543, 0.0658106145959708, 0.04334574122162115, 0.05212310934439302, 0.06297765592593821, 0.054145389942512404, 0.0163004013349212, 0.013662414914447696, 0.02848476930070789, 0.05664583197945068, 0.04742855318791924, 0.012820891269873227, 0.03237523191097764, 0.028684710588065848, 0.020125689015032786, 0.04844650783906541, 0.12398085046199062, 0.0165754288149577, 0.044890515386096896, 0.02329576659136482, 0.09158837774227704, 0.038283845905454895, 0.025448598147880648, 0.034009600058197975, 0.027274561054523916, 0.028036753421709425, 0.06288507803072853, 0.05135198056157078, 0.02385471966267834, 0.028923011813012343, 0.07624916777375244, 0.04311837015613433, 0.035499058844101046, 0.0020295718399387214, 0.04619548487807474, 0.07124154978702146, 0.06045883927013605, 0.03652836308784543, 0.09503195828367626, 0.025711793399926637, 0.08640298905271677, 0.06610270093886123, 0.019580718963557196, 0.16473438380466354, 0.055902975671474016, 0.04356730917108156, 0.023825340190782182, 0.005625756617049657, 0.00799562758578348, 0.07382230848194131, 0.042278691825847474, 0.013409255414209781, 0.016439465445376212, 0.02742998114216232, 0.00852246768772602, 0.053665772936637365, 0.07259717301255272, 0.030996585828101927, 0.03249256210702081, 0.025494977110816587, 0.017230638918737252, 0.04101059031522563, 0.032747880059985385, 0.04028479478532269, 0.004974731268556488, 0.033056218958189415, 0.0052359490561479285, 0.008715107199555684, 0.05011177997315123, 0.09126176381663931, 0.03768057081728213, 0.04840463347312424, 0.027439612782590335, 0.010779710325051942, 0.11794629161276164, 0.058334879652266546, 0.04669923748400423, 0.051571526038911075, 0.021788873559524937, 0.013562359043487139, 0.01310789940743557, 0.043211277469151446, 0.02350022013659679, 0.061332018625351696, 0.015215740535378218, 0.006093939760654804, 0.014050671147302756, 0.03633341286331415, 0.01378408308336211, 0.011757518138526189, 0.09197966481048254, 0.01719856664778725, 0.006049779579869562, 0.032704416061601335, 0.03741858406893669, 0.0028864521957603436, 0.06661477709008802, 0.0797370128754166, 0.049803774323194265, 0.030115709204467076, 0.044333485195473324, 0.05429509118379605, 0.0700576528305969, 0.035127724535883434, 0.05885626760221297, 0.04500015788981992, 0.009910923526472142, 0.05402750816316374, 0.033954782636776086, 0.08984696029895738, 0.07664096812086721, 0.054779048077762134, 0.06770978486465831, 0.01846665666709023, 0.012822988435565945, 0.061369848047052665, 0.05379637177552908, 0.07586383320871862, 0.04638843178268402, 0.05662973647216155, 0.08824893153242527, 0.06660927657879169, 0.03827412424969577, 0.04982514817628169, 0.07240562804884489, 0.06367914348600373, 0.02303978022668631, 0.042396711501022505, 0.04098263193642901, 0.11832110012971586, 0.06109889806999315, 0.056015513987550815, 0.08938780550153987, 0.033638468763280305, 0.11646225672936249, 0.03457852376384601, 0.09941188979052729, 0.06971891939399705, 0.051915070507675416, 0.01439175647383015, 0.03921940780034469, 0.015304781977207431, 0.05851051680022671, 0.03980841450092774, 0.07516408849868082, 0.017770336370073983, 0.08339089987378928, 0.04068760764634898, 0.11594723113962721, 0.027572230263162526, 0.043334847451337886, 0.13386125496077922, 0.032000944333811926, 0.0361875765356085, 0.016172891745584148, 0.03452832968304715, 0.04332009642835587, 0.012319444588595822, 0.017735239967042883, 0.03972947297077026, 0.07170648854826728, 0.020798157164526564, 0.044833005165621165, 0.03035135784997575, 0.06964047199055072, 0.027659579608288985, 0.011846091309111687, 0.023711528253531265, 0.027544662589207295, 0.05473512059618389, 0.03693518258871571, 0.050089088448834036, 0.045237560876675194, 0.04033989565927656, 0.03376992945108683, 0.014841256648181908, 0.09054509622435417, 0.09786593968108778, 0.0590177053104966, 0.06616339808510197, 0.03120295076270498, 0.060295961316554784, 0.05204461214523162, 0.016859042225405574, 0.06353780026397397, 0.004301277738470104, 0.04606597388403551, 0.04880033320777359, 0.02227402938109252, 0.010578456154513744, 0.012625648016710917, 0.0243356122049473, 0.11511434034834947, 0.02260704205611781, 0.02842006359940335, 0.020610105561753436, 0.06291454177229636, 0.025898268776795557, 0.024411803479456616, 0.023294429767936952, 0.02801194174906179, 0.037173290376461325, 0.05848979795231454, 0.03418093945290293, 0.06105640317283331, 0.05865641824540593, 0.04676518999340554, 0.011533034266903998, 0.025276779948223024, 0.07231504581267796, 0.08126537360611462, 0.04803454405778358, 0.051088438654739055, 0.08058984493536335, 0.0352906369634213, 0.055988930736578284, 0.07203475722382147, 0.08359646424651147, 0.028756094660850304, 0.06774275728891935, 0.03785163442033433, 0.04316671413459605, 0.03309680629641779, 0.04805945340664156, 0.022477531062078573, 0.037527345571546786, 0.018289608002129584, 0.0419038909697725, 0.11335514200430725, 0.14654940234557276, 0.11313859959163013, 0.1021341372641825, 0.1307262393135217, 0.15767989379744377, 0.1002065298117457, 0.14252863584026215, 0.14404322231008163, 0.1267086061078214, 0.12375446381948649, 0.1334979147800515, 0.07502080707420265, 0.08918060170065972, 0.11199754993281058, 0.11522752217828267, 0.20648470478913478, 0.15851754965561052, 0.10376842497217079, 0.2972821044104715, 0.1033422042946181, 0.1099576416515535, 0.36286713675625865, 0.07823286052312582, 0.22115901172641786, 0.28014195962778987, 0.14733321754442108, 0.08228915052548533, 0.15258589939725015, 0.20240974522406058, 0.1902407909473104, 0.14375627641716313, 0.10287149689130246, 0.1178664805728101, 0.2146346392410417, 0.12531056459392273, 0.11511744300444281, 0.10024845014296233, 0.21661125333799472, 0.10118284758420722, 0.18700307355292384, 0.17711418079993418, 0.17259847553026292, 0.11587193235754968, 0.161060088223988, 0.23411594872032446, 0.14740991826740005, 0.13437853284901188, 0.19180508120165718, 0.27539105004360603, 0.16652819400112476, 0.21898232610715976, 0.14008864580142882, 0.15187691566684555, 0.10507286586348089, 0.14385396794926736, 0.10460939799104968, 0.24389354421967463, 0.13509618869471934, 0.15049970408360805, 0.23087099945593267, 0.10541087917743192, 0.13509670963450787, 0.14282076048754877, 0.18438939605989765, 0.2541885248595669, 0.2011070586740971, 0.16268206489903314, 0.14500581178694003, 0.21886087052764433, 0.15960291238321414, 0.19804350370841642, 0.11787069405639365, 0.22401259731381173, 0.2645263911014603, 0.13476347670920436, 0.21425960855858944, 0.21756149347751372, 0.16284740199485134, 0.14331815073326712, 0.22622133605182174, 0.33671436591013787, 0.24109885547189946, 0.1413871035460503, 0.5100454972876657, 0.2974133812371762, 0.18782841071726816, 0.18289786883659903, 0.09761992586596359, 0.1329503151317758, 0.15286113946668564, 0.12464228311493514, 0.1565855525193676, 0.12545047523153405, 0.12210229561934549, 0.20647848415518963, 0.2797723681696, 0.17235289838525558, 0.208831078883621, 0.5286667351761173, 0.19260953480918563, 0.11667128381950241, 0.17775044746456609, 0.15498200791978067, 0.26743878159792195, 0.12798758989740766, 0.18086997281399467, 0.11857953989097189, 0.1833709434516007, 0.16027058865274155, 0.14361189948695322, 0.2146653900103223, 0.14620879965443767, 0.13989546907044229, 0.1815598503115677, 0.11434784639746913, 0.1344727616636984, 0.15742386721314924, 0.09722555146342325, 0.11439302260236395, 0.13677632676497584, 0.0988542850339605, 0.09063313504861248, 0.11815536466817703, 0.20980473067010605, 0.15223143051468557, 0.11789128649979831, 0.1666084340503139, 0.20396894865459014, 0.2506651639217331, 0.15837239131571787, 0.09478953742091695, 0.21329556351467488, 0.14386801800179866, 0.11410862012135406, 0.130616795992659, 0.16733782636302133, 0.11531850278017022, 0.08141689047577881, 0.16394163602061812, 0.21012104837404144, 0.153620439851957, 0.17715573340894716, 0.13003659164232592, 0.16095122712994778, 0.1261428042104648, 0.10842437029726083, 0.11777673337248065, 0.09989274019796042, 0.13999889094022014, 0.1821842426133733, 0.10740872157076675, 0.08254896158412581, 0.12302766088396312, 0.1545092550617072, 0.1847869344055653, 0.10628131593787864, 0.11116642114375869, 0.16466264733143393, 0.12203531655212566, 0.12620622096883674, 0.16178424049529339, 0.19727186930756416, 0.23838004007214503, 0.1359753665183821, 0.236457726287265, 0.1316460504406883, 0.23288247055344044, 0.11975924634645063, 0.1961244074928184, 0.10898231979339354, 0.09252172564306567, 0.14033619945328082, 0.13655653613949978, 0.14800063334405422, 0.1383853412323421], [0.05000395309780875, 0.04994675697338197, 0.0344920247763155, 0.07349322009230815, 0.006208343500827229, 0.021758019368374543, 0.084955787676717, 0.03649080179691796, 0.038348124512741645, 0.043238293559801196, 0.03176051338443593, 0.04639373311112004, 0.021751609127668124, 0.010866587568495062, 0.04320939289285772, 0.07217870514479376, 0.03827528870334068, 0.0014074610437326614, 0.055503813219406915, 0.0364359001058244, 0.06178294563846243, 0.042607056262392196, 0.015156346696218657, 0.06553876063516063, 0.09583499462854478, 0.04570467149718635, 0.04856036382637197, 0.05607141542338556, 0.06703795639858132, 0.08026130046815642, 0.01619119741653483, 0.027957241156048356, 0.05315075500778133, 0.020710857615115184, 0.021900718566030267, 0.062471769765139594, 0.038977572994847456, 0.024575277066399014, 0.04991700594884254, 0.027500861512136557, 0.028522098850038265, 0.013342941885874158, 0.035542124476764476, 0.04177770862776426, 0.06271386121009147, 0.055174510325154955, 0.05652973901540522, 0.029486109419996222, 0.014212109813196285, 0.025254921544523492, 0.02107071592622707, 0.015413836508448568, 0.05775784307550039, 0.11218493503908958, 0.0030937110592100412, 0.10167622352920233, 0.019178679851334424, 0.09640284964153845, 0.017701543589693405, 0.02511501090691215, 0.09718516330805518, 0.05005302869023816, 0.01216236017494192, 0.012549573570610055, 0.10575528166467145, 0.18105703616334548, 0.08989222077352386, 0.15502069535995686, 0.059606991633172, 0.6407639071826012, 2.2602530640940515, 2.2055333035607494, 2.3067745806709414, 2.653881296996148, 8.329663949628031, 6.996941114625623, 15.627569998464278, 11.970168678991257, 13.764693237120106, 13.489761564039416, 15.136464738076734, 15.506665879680266, 18.967097536210094, 32.236026717770486, 48.718849920457416, 55.41851312883439, 39.96188786721999, 20.92578603375343, 14.319063386609479, 6.264325716803151, 1.5056723933066092, 1.5979039861309914, 0.4509162265927561, 0.7128853242724174, 0.5243869390218489, 0.34758788082868824, 0.00878264551096025, 0.06986655219788514, 0.3287354682482058, 0.37819404335271933, 0.2659120602953819, 0.030301924111441742, 0.15352032748201203, 0.06668800743476999, 0.15895043529810446, 0.03932305949649984, 0.01273701804870319, 0.03500109786287912, 0.031290049214036234, 0.10574966624018647, 0.038871217008319595, 0.07237577360243568, 0.1012846989737403, 0.0407215261891965, 0.02457122063083995, 0.05313008978602387, 0.0858985967633705, 0.031797071100182595, 0.007774563339133297, 0.051386435365965294, 0.06624372240396277, 0.027255023897234953, 0.05699036470163734, 0.008392712503160921, 0.01603544312303946, 0.059495173439744024, 0.04607022567201526, 0.06773855912709428, 0.03992435041694872, 0.05386738812610988, 0.011036886998842801, 0.04099130022129224, 0.037345143050075545, 0.0423605406596776, 0.04865383421401343, 0.03215741396190659, 0.04522533411340368, 0.05140604721682687, 0.018339248584403146, 0.024763125655872208, 0.05084751932431133, 0.019718302609098536, 0.042136387163472754, 0.05087849608952961, 0.01685075315406486, 0.08886175590657419, 0.07587414475217943, 0.02098448315425025, 0.05400940167507338, 0.05180777223300069, 0.04045397381208116, 0.05040498863485071, 0.07959000826362642, 0.040141865761289676, 0.05235558638589517, 0.018094843553919947, 0.05720054858454293, 0.021140460570853566, 0.005532280483748765, 0.015114169725547395, 0.03824438854691483, 0.05239678659446297, 0.06448934275296427, 0.06211341298635929, 0.05233864818188933, 0.0611778166175129, 0.02141806593675527, 0.03280791454017162, 0.033351373483216575, 0.056389372555478934, 0.05026737243057259, 0.0753624210013978, 0.07343633806393032, 0.05869648081340617, 0.088202636839161, 0.04604499456622908, 0.06629530310390458, 0.0368853907040771, 0.05472636804164899, 0.11180192938134556, 0.04152925482260124, 0.02550560083510655, 0.02993028719849404, 0.0660327188069782, 0.041903481112733, 0.02460435584878489, 0.05409218896661074, 0.052626984524390394, 0.03069406728290262, 0.017844537731199976, 0.07900650973521894, 0.07222616429170294, 0.05370804566829916, 0.02617304727825667, 0.0062994777991045876, 0.05873897188012639, 0.0965967771386908, 0.01091294259118337, 0.054639302149054506, 0.008782155214688711, 0.03933360086633794, 0.01082286597304647, 0.007702169945508603, 0.004697477824295, 0.07482427487810774, 0.029208835387121768, 0.033084709768093405, 0.07674786802982131, 0.008179399151084645, 0.07924627993376025, 0.04341000450714942, 0.022043375628850153, 0.04377133370707593, 0.06612246600730766, 0.045324423755969734, 0.030764032177807345, 0.02775428339748854, 0.07376325842473777, 0.0486594113341022, 0.04086793325240574, 0.02862286814037831, 0.08242153817968023, 0.0033391000338709887, 0.0299495906989661, 0.024153214331055363, 0.056832906820120356, 0.05532909154651627, 0.018336176571826783, 0.06431196275497637, 0.05063693707568511, 0.0519011085552554, 0.1268579396269014, 0.023631883837703257, 0.027404303790160248, 0.03028634762872131, 0.018636320244460818, 0.07655125156405472, 0.03572827235104577, 0.055172330805010376, 0.06230673144361185, 0.01850182967891376, 0.15705623694004553, 0.14396207827714183, 0.17746406847671156, 0.05112461332652358, 0.17070037012379016, 1.3516445938617954, 1.8123080941938587, 1.531951905738923, 2.2600218894020205, 7.3195795955196505, 6.067455093706808, 12.579494176372407, 10.243859041121699, 12.018894322456854, 12.655018433447808, 13.853734962401854, 13.881951512828952, 19.71645655170564, 34.81057243962442, 57.28110551834107, 63.177012320487734, 46.86214500857938, 23.195373358265048, 14.650914534445732, 6.372580191781444, 1.9777552615250311, 1.9188944586823065, 0.6906503270710669, 0.9202594418198833, 0.40207141048965916, 0.2792423272565488, 0.05439438383966204, 0.08980310176529231, 0.14166588294169596, 0.26582733097095645, 0.1475296424882066, 0.05775188291144948, 0.090822902688336, 0.05173783989683275, 0.043888460889819174, 0.04718671072154276, 0.026487363577489893, 0.06378759472300449, 0.05342968379057223, 0.015889103092523595, 0.02896369874267088, 0.0231177028599045, 0.031988679266144196, 0.07253829149469253, 0.043547827555167104, 0.04279495847802009, 0.03675562690102285, 0.014329866145647342, 0.06565098485518849, 0.0476024359945328, 0.061611192556278366, 0.05159283477452494, 0.03339831935121648, 0.04677154852317707, 0.028095642600448865, 0.024568478036071026, 0.014655382650333547, 0.02723057037069192, 0.03588800934413749, 0.01913715022495918, 0.04580095725794954, 0.01842002489513928, 0.02645904896780849, 0.035294999834150076, 0.05574273306035227, 0.04729125107969007, 0.03639387635273799, 0.02304557568183349, 0.029932468633858428, 0.02963243221353379, 0.09910190763372569, 0.0651636456830367, 0.021504821563740412, 0.002314112695579928, 0.023744383849383845, 0.013840161677029346, 0.07522149146684716, 0.023042450043102427, 0.07838495961961248, 0.00954772315679058, 0.0697036282790284, 0.02851735485056716, 0.03947552631519014, 0.032685631585697976, 0.0578966926813366, 0.025949108286670623, 0.014478945898102417, 0.04550702081272199, 0.0242312174035056, 0.011941284436972873, 0.02683883514105072, 0.03682707609128087, 0.04258469032544283, 0.05479488694559663, 0.1574010071494887, 0.014671523165288232, 0.050310591280820875, 0.04495920282938788, 0.07279999479050599, 0.09253821185519619, 0.02088842338942472, 0.015219683015358546, 0.08540439344341717, 0.05369183524782139, 0.043867067884533636, 0.07155958352790726, 0.13008847111655822, 0.20633876503955936, 0.13021207174226163, 0.14530674644535588, 0.1408801984883124, 0.15269632331065594, 0.32333509996533394, 0.11721134516260318, 0.14246753266742154, 0.08958245312134105, 0.09379356949319763, 0.2052008640021086, 0.13084680623104497, 0.12482538578971741, 0.17318828662316646, 0.24593156792463797, 0.1832177565102616, 0.12519113914740662, 0.13731569862894474, 0.11946008135113986, 0.2432665778624435, 0.14015716470537648, 0.1725623161802369, 0.1546598985911377, 0.2063605525801259, 0.11067300689436736, 0.128488167068891, 0.22131814351004941, 0.1795147939194595, 0.16051990430681937, 0.0767618797779564, 0.16196186564141707, 0.10642376998739858, 0.19706248215609984, 0.11805726710947291, 0.11431311197098225, 0.1550520436778184, 0.164254245859, 0.1981916497912138, 0.17116394524853076, 0.12541571782240946, 0.11967334490750106, 0.11942305632175938, 0.06734226950474324, 0.1966394177607952, 0.1648694604274727, 0.17992593798666232, 0.09691720107390035, 0.07319299023478262, 0.12637994672742583, 0.17975364481249165, 0.11424597968617756, 0.19549803868416818, 0.2748478017747402, 0.13898889594260724, 0.2723048801624006, 0.14244173082613176, 0.2125309618009675, 0.12231822516168318, 0.17795191326689336, 0.2272501921341304, 0.19384771675592471, 0.16300207514676357, 0.14903252313454307, 0.20401267695330805, 0.28026070325605335, 0.18819556601585882, 0.23447392628558222, 0.27849401257211165, 1.137204326448902, 3.0955374817694388, 4.461935335589994, 4.791726258493239, 5.935033425208061, 13.470891041140403, 14.732495911659734, 26.399080984054077, 20.407401669409968, 21.084434140113093, 21.489591444692305, 23.01341852834148, 25.88814323948276, 29.04987365968766, 48.790362573439076, 78.01504058222618, 83.03883583314958, 64.71638964068505, 35.448479267858694, 23.871166359993722, 10.677532957446191, 3.2543473858987135, 3.133790642023087, 1.3731190802589541, 1.9086623432174807, 0.6597082809575143, 0.7276729662572184, 0.1616821209749868, 0.23060363477035878, 0.2701294968926138, 0.5046745774246032, 0.36796223432306324, 0.24750937196996906, 0.3059470184868382, 0.22143682585127894, 0.25715346898763414, 0.19487163923200101, 0.19178108732786872, 0.19910551607608798, 0.14599817144053598, 0.1779900031584886, 0.0917508420083792, 0.19623185898507797, 0.2463773238442598, 0.207865945994854, 0.17454521219816901, 0.15307771252287974, 0.10466229636222125, 0.10492472744156277, 0.06746187881236115, 0.21524338802743345, 0.13257401274336925, 0.22180407308042052, 0.10628756721534076, 0.13920746082740446, 0.09015848229248678, 0.15520732970007006, 0.11521737917416519, 0.1759322143850788, 0.15153352441566606, 0.08548418150073098, 0.11276811947144809, 0.10731276905825061, 0.11792293359195033, 0.1404241923122637, 0.13652462091657425, 0.14812401946513884, 0.22541294475236248, 0.11159396715342038, 0.0983645786501227, 0.09700990537361753, 0.25932673785474997, 0.19369347261325007, 0.13213910462875522, 0.18057430884049785, 0.11125904883468345, 0.14233208832240876, 0.16762446582077012, 0.1293409225200453, 0.21263875037191377, 0.06869453726516617, 0.18329868603858257, 0.15057009224209095, 0.17056809738278392, 0.2222760904940867, 0.19425915193653878, 0.110227013487489, 0.11419957007972464, 0.10265126959570955, 0.08056661714949916, 0.12796922676986264, 0.15591786092808171, 0.15411709465326803, 0.2570112983906462, 0.09511148587109582, 0.22863371628186396, 0.18787567834219626, 0.09161796405791275, 0.20735692653444507, 0.20215883610710023, 0.21195063487656657, 0.17090367453713573, 0.10900434482121661, 0.15790759045029842, 0.11965725706109118, 0.19812329942660947, 0.18118676549244314], [0.05803676036697242, 0.035272400240383806, 0.15958821881682644, 0.010419056240108707, 0.12026577602110564, 0.1056862264991768, 0.05978319568619613, 0.05045692939611693, 0.03776083767954861, 0.0673676576585539, 0.036484998680891535, 0.022510591586450898, 0.042916383414018544, 0.058432973380531036, 0.10322404289317709, 0.020476949904414437, 0.10644974802891094, 0.06153797370291526, 0.07853584829717875, 0.009438268344609008, 0.03530891965173426, 0.03501750746621721, 0.04202454598740705, 0.047035887161450046, 0.02697400177919096, 0.021247046383758707, 0.02668955141768581, 0.03527336934160802, 0.010717343107136268, 0.044231591671104395, 0.03837501802932351, 0.009573749078798198, 0.05835144247318949, 0.060441613783158606, 0.03867246698768389, 0.05699106950252768, 0.006205262869761716, 0.07654842469961413, 0.04760825826275734, 0.06777393706743756, 0.06780158518062485, 0.0566595258010972, 0.06809724915412164, 0.03846991717094376, 0.09129105135798456, 0.03697742850730016, 0.061409037274819236, 0.03271850058808923, 0.04495064562727367, 0.03498112595069312, 0.043412632188729705, 0.09131498394473907, 0.030974905539844787, 0.015658820892924506, 0.022541014853143887, 0.03793929786150975, 0.026154760759504094, 0.049284768906692346, 0.024916638184579152, 0.06655334449943996, 0.029222423871678692, 0.10784880843974891, 0.04038831241609108, 0.10179245438907417, 0.08430894133785079, 1.4919352723706154, 8.582813720549307, 17.74336314970447, 34.226041224695024, 48.5369578484566, 69.2617851688016, 67.03373770559988, 76.54088051088395, 81.75505192049089, 83.29670813775833, 85.04481438667544, 92.20544630481352, 85.84748821873819, 100.90494955739668, 102.28402353102162, 108.19873809814455, 110.05609804584135, 114.97726840357628, 128.24229286563013, 114.38699091634443, 125.83783288155834, 112.3404158315351, 112.85673310679775, 116.8504511925482, 107.46311326180737, 89.89467605467766, 72.81201654864897, 65.8795645929152, 61.763809803993475, 43.52776165931456, 19.196940583567468, 22.600381182086085, 43.19748240132486, 40.88656702349263, 30.84370101651838, 15.395091118351107, 4.108832295863859, 0.8530352877513055, 0.01689701528859235, 0.2643999253069201, 0.2777798654090974, 0.15658893862799292, 0.07377596016252234, 0.03745773116186742, 0.07488529378127667, 0.036723493343038906, 0.04478588309739867, 0.03348197998298753, 0.041525975966285315, 0.005885675406804489, 0.05073718351101683, 0.0301237492972324, 0.062000602709069375, 0.060248119125683466, 0.03254145000790877, 0.05325255277115972, 0.015538628400874235, 0.03331571975122056, 0.05154375535165591, 0.01678367258019505, 0.042017647365648905, 0.029869708795881564, 0.03551114005066695, 0.04247681748482489, 0.032737802173341476, 0.061462786003586754, 0.052779558595390096, 0.10883222784726851, 0.06391802119211325, 0.027627855907344533, 0.02252095101040698, 0.04105085206608619, 0.05246090432328563, 0.010403765125140067, 0.06802796416224972, 0.04929311543462738, 0.028003646932061643, 0.026494442229910244, 0.059910737834269964, 0.05585041820942875, 0.033768619440736315, 0.029867672917222785, 0.03965167291161995, 0.023430500389827837, 0.01850811543033248, 0.03986229346464238, 0.03173320426515514, 0.034976261292373946, 0.03446950562178128, 0.088919457649031, 0.07639544460201457, 0.0632155300568669, 0.05802680122395677, 0.012145149052113056, 0.009243556564944166, 0.03168309253880815, 0.07009008133243169, 0.037992472024334055, 0.07451468342614752, 0.058012984828242374, 0.06912391422496689, 0.09188475417754344, 0.04046579071831319, 0.092070737342921, 0.026245360232649312, 0.07685155803037268, 0.060865245083527225, 0.0320954738380087, 0.09930954044384342, 0.029819779015416582, 0.06564096442513889, 0.03661761616146372, 0.011752905331612115, 0.022905846990104166, 0.044330769413781744, 0.02186931853723382, 0.04773942783715264, 0.02085749833514133, 0.06879312512014182, 0.06431202404201031, 0.11067265449392219, 0.04086465822652944, 0.028985442233181773, 0.04240643315678162, 0.06276775932600422, 0.059846964845013235, 0.0027731719714093714, 0.14163312502205372, 0.02478511620973868, 0.012958018135489717, 0.027819797321553194, 0.0273168491079442, 0.06527429176194054, 0.06205021073260616, 0.0654463857532509, 0.08337584624607718, 0.04032342476890453, 0.05339440161121949, 0.04546406243236796, 0.043182503206715475, 0.06777434309403743, 0.0459192335725792, 0.0572105115579982, 0.07769186455275744, 0.07159829395072115, 0.03623660233232283, 0.04435872396213874, 0.020679762106268637, 0.09283358471528178, 0.10474007726917345, 0.03876552751828586, 0.02074704760865819, 0.07178811521659936, 0.03390127905614434, 0.022177531030930342, 0.032263168569413886, 0.028027531638320898, 0.07198576590106373, 0.03749093724294536, 0.07336382018101793, 0.019901047137776212, 0.04882674791940278, 0.02779946534804279, 0.038337778495324236, 0.04131463912105368, 0.0347571180111939, 0.05228984838111266, 0.0486904455559148, 0.06515171769405566, 0.044750723492113814, 0.018945620583009817, 0.1822057237187701, 0.01565859585459675, 0.03764502050715589, 0.06191887644930713, 0.04698538664548148, 1.0089335061850087, 8.315153141175548, 16.281266327827208, 34.07906609196817, 49.9352357464452, 70.74790062442904, 72.96616569642099, 81.90145046480241, 88.8622768463627, 96.3479006674982, 97.07380587054838, 107.25990310792001, 97.17281433843799, 113.91998567888814, 114.97462472608014, 120.63036088020571, 131.1020145108623, 135.42340740080803, 150.03423629268525, 136.5776981845979, 148.125422693068, 133.2790319381222, 130.46535107397264, 133.78872040779362, 121.61828825550695, 101.75633138225925, 88.44088092927011, 74.92616622678696, 72.05352429420718, 54.51673276962773, 22.112281437843077, 31.33346776808462, 49.142379606923754, 45.247717057504964, 33.419527392233576, 17.73677552900007, 4.813591020722543, 0.6380801479662619, 0.011631265890994861, 0.1864658314133844, 0.2099354405917468, 0.07992315691925826, 0.06065881503145061, 0.051902353448132356, 0.047292982438398946, 0.04545629047037614, 0.12570119282651332, 0.04903093333386126, 0.06794233851495289, 0.06045230837058156, 0.024280371519947247, 0.016067543164676717, 0.010021726653400448, 0.06027764032384562, 0.07074736178882661, 0.03278598144289947, 0.027223420855138573, 0.06201618493744924, 0.07743883337224684, 0.054563424970594146, 0.030108117273137457, 0.03483707460785105, 0.015806634685084704, 0.00665163932060222, 0.03164190190633939, 0.047978849465688395, 0.02174405741595453, 0.06202771839114928, 0.0999822958763088, 0.039180701207970424, 0.014209851769039468, 0.05020759842028061, 0.04828387503361991, 0.02184107862112503, 0.0589442374785581, 0.05598877751899343, 0.08383534578306061, 0.026896973553624366, 0.0585169940736265, 0.04651628802680681, 0.01266533232879855, 0.038375470021198836, 0.024652439357352354, 0.08808540240410836, 0.058115759353724226, 0.09688327870061321, 0.008934019696748546, 0.04321152261728722, 0.03756035630020403, 0.018053258386170192, 0.06157696757826114, 0.04473850055928192, 0.0360470108928219, 0.0347493690318398, 0.05931834119462198, 0.026667907518605073, 0.0960452551202428, 0.02962215705924938, 0.03567088470463792, 0.08128712284228495, 0.044324257666425365, 0.08190368572550435, 0.00728907905736818, 0.0023305428875309807, 0.0289657250452306, 0.04783190997137178, 0.0760389379255714, 0.024336935621836496, 0.08533636483574107, 0.039836415014560186, 0.06161973060619447, 0.16095187064380417, 0.12469246953485474, 0.2269832717795526, 0.14717276808955979, 0.17049865917332713, 0.12187094472709203, 0.18988255291215836, 0.15972536387703112, 0.21719711141720896, 0.22725871103184841, 0.3087619932428483, 0.10188138953620389, 0.09730452746753732, 0.11849952966816003, 0.19104761942740411, 0.1260878374018977, 0.28245955945984014, 0.11142881391870399, 0.15036445892145558, 0.08726565002073204, 0.16281438360531486, 0.19145228239076753, 0.1876998611635739, 0.09991600628822081, 0.15887696746616595, 0.22828263350792471, 0.1979818949175458, 0.09463138622982849, 0.10549077448705513, 0.13959062736361258, 0.11053714120099623, 0.13711873742361225, 0.21677130442713538, 0.1648038526576373, 0.11638373271712374, 0.0895169219602981, 0.15220938250422478, 0.21859218817084067, 0.1918524407571362, 0.17571692835659752, 0.16253203423994203, 0.11890904196808416, 0.11463683774514545, 0.22580862916525335, 0.10200558771048823, 0.16416996086557067, 0.26190247867376576, 0.17799052409827712, 0.15233548057656135, 0.18242917624452423, 0.09026555840166346, 0.285497312584231, 0.0983700715005398, 0.125211532407951, 0.1353539313159643, 0.13076337925609083, 0.09312999945494438, 0.25915816786789125, 0.22480172916285454, 0.22337052370271376, 0.35701437823234067, 0.19335426420213717, 0.18763690405795652, 0.17902966108052962, 0.32475159653732855, 3.745445291842184, 13.367783696420732, 28.210509977033063, 51.89983329465313, 71.54347496647989, 94.29468108761696, 100.54191850846814, 109.69469085816415, 115.19977661871143, 125.01575900662331, 124.7870534466159, 132.25399109625047, 124.56929914412962, 138.29464512486612, 139.3733753696565, 144.11228887496458, 150.19248039491717, 157.43957704113376, 169.62369826532182, 153.80352420191613, 168.88240168171546, 155.11938525784402, 156.6565307494133, 156.8779093219388, 147.98945765341483, 124.56634952176003, 105.39483962520477, 93.57239230986565, 90.8471530483615, 73.72974918734643, 36.67769908905029, 43.10751891905262, 64.50541319385653, 63.98956660301455, 47.007190335181456, 28.79327024182966, 8.794428533123387, 1.3261751734441327, 0.0944074051034066, 0.3641592206493501, 0.6085307884120172, 0.2886349329304311, 0.25226870852132, 0.15178975018282093, 0.17994827711053435, 0.1743543184091968, 0.27027974205632366, 0.1411711893254711, 0.19982467345412702, 0.18759352815968378, 0.07193887365921851, 0.13532642875948261, 0.10260168838525012, 0.11916912115749814, 0.15004461721306847, 0.1513372526894654, 0.1291594056472663, 0.21329326525090203, 0.12689336353252012, 0.14267023953218616, 0.11077431436147421, 0.09818215779359303, 0.16704012459564596, 0.08667690379004325, 0.1487261492518648, 0.11495959058764482, 0.10245842994340967, 0.18797568345983184, 0.15498468922751565, 0.10926671461352419, 0.11384892397590222, 0.18691854341135872, 0.20236557259434657, 0.12604600134035274, 0.13171568783300538, 0.18228198011075297, 0.20011594008293845, 0.13186810868642024, 0.1531829423601589, 0.10738704894338885, 0.13529451353655708, 0.12982409417388902, 0.11656909535128264, 0.14546615402064017, 0.11476259107791609, 0.21301186583455534, 0.1581882544222378, 0.1129022231625934, 0.12775325892312875, 0.19363517332221233, 0.15553032769070518, 0.19458706821164778, 0.13084784811062197, 0.11791724155867293, 0.14808442804121202, 0.10501311866626625, 0.15703302447593984, 0.14260892185472673, 0.26916627922365743, 0.14928482653152558, 0.23410367599177748, 0.20350964830046703, 0.11136301462688755, 0.1453596371556482, 0.09815517617689987, 0.19602691514357445, 0.09979510995289011, 0.08156448497527069, 0.15849088979584558, 0.13039093795082263, 0.21982854682831998], [0.027231773128733042, 0.015468285250056897, 0.023222434740032882, 0.08280475068116382, 0.07710668063091655, 0.020409235392787287, 0.06007100725846906, 0.026338715707102132, 0.035706729958615, 0.013158075293646225, 0.06056090516428794, 0.051655125383648186, 0.03545301695985179, 0.055654004756962104, 0.07497273505695405, 0.04139957145877904, 0.05452856797003939, 0.06406634730557281, 0.023456304146337415, 0.04925505618654913, 0.10605518976526876, 0.10165824344561947, 0.05932556540374795, 0.018743961343481656, 0.03982445638206217, 0.03941335828013478, 0.03820384334352228, 0.06663525462030404, 0.033474426356054125, 0.017575928152749137, 0.0320398137198701, 0.020108589932562846, 0.034311680018060634, 0.03849590670377497, 0.007561059901490808, 0.0606941968022335, 0.04941730977847211, 0.03947068846994831, 0.0335523106848761, 0.033678807122933294, 0.02932713659960897, 0.024020968403126446, 0.0782612057763242, 0.06633426633573349, 0.017579902233856342, 0.03593962068759626, 0.04500193521380425, 0.015000835635639248, 0.050549158721321055, 0.09424751489273003, 0.031763072118103024, 0.006255638417637637, 0.06984233615859863, 0.04465581285917471, 0.05033580706484857, 0.04402994583811491, 0.027337378349095106, 0.16961313814165133, 0.01798701476335766, 0.07897890758730712, 0.08932646484144273, 0.44992239605034556, 2.396423783033125, 17.891628742218018, 38.02380161900675, 65.53334090017503, 82.21540481813493, 96.72023557847547, 108.14948881826093, 112.20321132290749, 102.313213809844, 95.1515777649418, 89.19064983244866, 87.91298481725877, 92.30570208641791, 91.23679345653903, 98.6214005562567, 102.04085226981871, 94.61556234667378, 101.11831865003033, 101.4889826313142, 106.32705365457844, 95.77922759517547, 85.77730132687478, 89.99125265306043, 89.1851192905057, 89.57406936153289, 108.31962554685532, 92.60737942111109, 104.2870367726972, 106.50823577757805, 106.80398248857068, 111.19148300540064, 116.61309288394068, 121.30379261509066, 106.11639099736368, 119.62382578080701, 139.89605472933863, 110.49459549688525, 115.07111503231911, 102.71713164544876, 89.38203796263664, 60.47212623780774, 44.12212625626595, 30.641459688063595, 11.732164159897836, 4.0687385634068525, 0.3070192964326951, 0.022936896533675255, 0.1863595903400452, 0.029197439829248096, 0.08678646202409461, 0.0650482268763646, 0.04494072861909386, 0.037478066965817444, 0.02522161778723521, 0.007176956822795253, 0.03820399273066752, 0.05982377153310565, 0.026729692509698293, 0.09870482894081263, 0.04260314921397836, 0.02405230906010876, 0.06713875824765814, 0.049091507906034115, 0.10730894627950846, 0.05499842884619871, 0.040348904853266095, 0.03955964659971576, 0.015803987851306316, 0.028462386126780224, 0.008145329305872081, 0.0764825028337298, 0.06617832147786695, 0.05910104801577907, 0.025969131909791502, 0.05307871976026124, 0.0751699720539393, 0.024552489781091293, 0.08958254505189196, 0.027301517773359537, 0.05665771400315627, 0.04158746218308807, 0.035572499862962195, 0.04705199032961842, 0.024957367249073523, 0.024786351526516582, 0.037843693918999166, 0.02992449748900629, 0.12443753845629194, 0.03347331552856392, 0.014438510819848989, 0.035101026371722265, 0.003039984834275299, 0.03332600448160403, 0.07075659314831419, 0.06752011681636495, 0.02511917459478061, 0.03924724360507342, 0.007865791961986331, 0.056799681586844314, 0.06465467218790324, 0.05004447914900319, 0.08027051650588551, 0.02430258615453157, 0.07837371344888404, 0.013331124022032225, 0.027296990193727038, 0.010492003132258693, 0.03818483670212088, 0.04065703307729095, 0.0509569741364929, 0.018544887650697943, 0.057533199283024, 0.056770800072098934, 0.018367285487212, 0.021676436750098102, 0.04212165146224922, 0.03596043529649896, 0.019110727852450746, 0.08893322424903032, 0.03216151253230149, 0.003094149165741739, 0.06341424943398564, 0.03449857099762848, 0.0744539020102351, 0.04702562924414393, 0.07856586362205206, 0.04088189520482575, 0.04869161767043895, 0.048149729207638776, 0.022250445364343546, 0.0418501460714446, 0.047197313378414804, 0.013531519216485323, 0.07372536771600285, 0.06377514579423493, 0.03746025542157792, 0.021436819769141656, 0.05400725662888539, 0.02543620093004598, 0.005617819467349159, 0.01573388314535541, 0.08070442104531873, 0.03042552090670553, 0.0259171222006121, 0.03417692898261932, 0.08685060656599461, 0.021451566961684057, 0.03765646586074464, 0.02757094706588936, 0.06362392769886122, 0.012073603143254596, 0.00771127202765896, 0.07608678011644272, 0.03179260289236423, 0.015538840990273223, 0.034681528115705136, 0.02106093681387363, 0.04790353536185238, 0.03413333474928814, 0.05143204441053733, 0.05834846622160366, 0.022648487412821383, 0.03251566348837749, 0.04367035565777652, 0.03603072769399132, 0.046640578131642074, 0.09178202944777666, 0.055813201658067205, 0.025450436758898923, 0.02178808640418274, 0.012774515179767004, 0.08975204966601827, 0.03457241421264987, 0.030249923978361393, 0.069818526145912, 0.38782116386198234, 2.3618946681099557, 17.912442799537413, 39.620759333333666, 72.8251172650245, 92.33450012822306, 112.04313939617528, 122.96839944777952, 128.13702429494552, 123.6258279123614, 116.42487402885192, 106.9365272214336, 108.49272758729997, 109.07567024230958, 104.70073699951173, 118.05564649643438, 122.31613282234439, 113.84036940913047, 122.13175004528416, 123.58837712195613, 124.72362087618922, 115.3739376991026, 111.74642778212025, 110.88560088988274, 110.49053192138673, 111.04122484883955, 125.74470796892722, 108.55822332443731, 126.05710121893115, 127.08906896652715, 127.43487296565887, 132.4768444799608, 138.62619523079167, 141.0830737698463, 126.74024474236273, 138.97203845362512, 164.8979639237927, 133.90468135956797, 138.99329769995907, 124.90918036430114, 101.78751422512917, 73.66354742357808, 51.76022045073971, 31.151175614326235, 13.73536273356407, 4.315933440962146, 0.5828610819674308, 0.0360457583390657, 0.10332161951209269, 0.06067571876149985, 0.09062712125840688, 0.03568975345021294, 0.022423563998252637, 0.03531773732374272, 0.024051066082451614, 0.029305182434918902, 0.06328067817394772, 0.02668940203054057, 0.06107398872113517, 0.043448600016774676, 0.04101389215417928, 0.04581452467508855, 0.04218819385935222, 0.026933404864863526, 0.01898410884032567, 0.032213422650050734, 0.11515719530683373, 0.05709698498849908, 0.035421657150671366, 0.04306926392018796, 0.03932245045660004, 0.04109739573792585, 0.047829826212217735, 0.08320377523740453, 0.14101092373171162, 0.058664906499606956, 0.03043835096421742, 0.02093187972692953, 0.057272016926999056, 0.04625465750934617, 0.032363809540026614, 0.03798857263679947, 0.02651321712971455, 0.032282014332351186, 0.01592088425006237, 0.04652354287944975, 0.034596545982264706, 0.0587362714201933, 0.03712763153617421, 0.020784961300030835, 0.06931915939334901, 0.050573512656433936, 0.008715131139803317, 0.04606957832771925, 0.037053052876745506, 0.024689192425519712, 0.07828283243842664, 0.007860146372789338, 0.0314805580438265, 0.045647019550444624, 0.02300651094335462, 0.030731666878226305, 0.01583455667470492, 0.07326988247974266, 0.06800167968556767, 0.027495004769955433, 0.014632905630635159, 0.04436792467810935, 0.020914491446268176, 0.07964220949478688, 0.11648406725256674, 0.07416586827246413, 0.036128806100497325, 0.0015860391314133943, 0.06528837245798881, 0.10515266924255318, 0.10810242184708196, 0.0977187741908335, 0.2808153509132324, 0.22767592251541155, 0.0791301180218016, 0.0965388608916152, 0.14626542887380048, 0.204567447184555, 0.1810523477052489, 0.13162285329834109, 0.10406693113186669, 0.16401410793825505, 0.202421527656336, 0.22005495645346182, 0.10069171627683025, 0.09378439175986475, 0.1764618262888924, 0.08135671426932659, 0.17557495694246986, 0.13570775668467247, 0.16811706035608248, 0.09715652694144557, 0.14795872833459608, 0.14376572994214876, 0.18302726108701, 0.1272608788924352, 0.232553405146445, 0.12804794230408248, 0.06898597243332094, 0.2080340563289581, 0.16345664107751462, 0.18581462603422905, 0.11974279077783709, 0.12437138676403031, 0.15116119036270728, 0.1305948552345076, 0.18701808887623972, 0.12494350888676221, 0.16621759131310448, 0.09160572197288276, 0.06837851067464198, 0.16791464460472907, 0.13367553992617515, 0.1138974939503016, 0.22595640752584706, 0.13432322130087884, 0.14633574042349093, 0.3052650776601607, 0.22978405858720505, 0.09025543071930447, 0.14054429957703238, 0.14056181234698142, 0.08893111750723855, 0.1512346275511288, 0.1661762685304688, 0.13827373754353295, 0.2850691920086261, 0.13929605123496827, 0.12764054440682934, 0.09129492776288141, 1.361705473353786, 6.308915711218312, 27.212019658857777, 61.33267464176301, 96.5208536578763, 116.20868867443455, 132.4662854594569, 139.07938588050106, 144.06264735806374, 134.73842036339545, 124.10880504115936, 119.89100979220484, 119.86505154640444, 119.82539638396233, 116.71390564210954, 124.71784714729556, 129.3100953871204, 120.5754476977933, 128.8863931163665, 131.34852763145201, 137.83306060298798, 123.62015616509223, 113.7868369010187, 120.03580800948606, 116.51599068795483, 117.09498743857108, 139.1354287055231, 121.78756206266343, 135.3487725411692, 139.2375829142909, 140.769284156061, 147.4374075858824, 151.78706507528983, 159.12341917714767, 146.2811085485643, 159.90262154609928, 177.14332119111094, 147.91766258978075, 157.94717880987352, 144.56551090363536, 123.84513547343593, 95.15302904190557, 69.09084827669206, 44.63380728998492, 22.6289850665677, 8.25175783326549, 1.1199143961552651, 0.16677125837774048, 0.3660029797784744, 0.18086804227242548, 0.2128488882895439, 0.17203894023212696, 0.14447563297806248, 0.16887248433645696, 0.13039921170040486, 0.0864514058095313, 0.12178868220578279, 0.12567906054638087, 0.1464664350233732, 0.24156658279318965, 0.1463315269399074, 0.12714952035176177, 0.10613790427845333, 0.13550759323181646, 0.1599473608357291, 0.13259373184654022, 0.2161952829168689, 0.14834834533112665, 0.10713394881496507, 0.18935174591118292, 0.0849529914557934, 0.15453041441017581, 0.1452545605359539, 0.1349236350506544, 0.26298064017488115, 0.15791545051240152, 0.1814366020863095, 0.10470322844001556, 0.1868854330912713, 0.136465770042231, 0.1238147242956104, 0.15322449496917187, 0.15892585919749352, 0.09320429466184109, 0.09270973128056334, 0.2066510990862885, 0.21120086462507326, 0.16040889816659112, 0.18178616800615865, 0.11128483535421473, 0.1913752292673434, 0.17934086131713084, 0.09652546967469877, 0.13615922762020943, 0.1838831804812916, 0.11903993575082672, 0.3550819367651017, 0.10672914795577527, 0.1683244403571852, 0.19414779339586535, 0.11557647522779242, 0.13563151561444806, 0.1482647191733122, 0.13161166841464658, 0.15066626692010512, 0.11266676603906578, 0.15702383142084847, 0.08583143383504883, 0.1700812025416282, 0.1616404917571814, 0.220850094431831, 0.1221845887841717, 0.3141505024846523, 0.1581138366412732, 0.12619992372609917], [0.029547107255747242, 0.0428810820824677, 0.038087646957607045, 0.08118372395514481, 0.02208438814587651, 0.02440048069993575, 0.09212430987146594, 0.06564183776537258, 0.004092327257122604, 0.04436179980515473, 0.052670900514649774, 0.02050694416186983, 0.024924639972948262, 0.03814535253050347, 0.03316632877554625, 0.045212896675952984, 0.07286958621754762, 0.033486139840416373, 0.06846530843646297, 0.06534738421079613, 0.03156558231210276, 0.023837823593508334, 0.025718038931729335, 0.07055983878672123, 0.004284755615968137, 0.04244348882967907, 0.004825034336517415, 0.02662746956752193, 0.008306422274589779, 0.022505121718671535, 0.04707056030090298, 0.049854535309057084, 0.03576043655254668, 0.024328661872254267, 0.04948792393289266, 0.048817968551790526, 0.03665019405044375, 0.07406779369639774, 0.004674722618919107, 0.03535491557070806, 0.0964513966333001, 0.01714650905811258, 0.0634939378998693, 0.012817694768009168, 0.04619905867824151, 0.02537395245575857, 0.06720898552767693, 0.05092855610494172, 0.05224884735540517, 0.08247092020727935, 0.04136343892183035, 0.10732167099993076, 0.04472178452077412, 0.030966461335699406, 0.03455222396540546, 0.044094534711011, 0.006583473295904697, 0.09617783429641878, 0.12467074328132215, 0.8038713807059873, 21.54740914221733, 42.42866646858954, 65.54798310802829, 79.80264509877851, 95.90427275626891, 96.35755754286244, 85.94076218143587, 82.65121936798096, 80.14458164092034, 75.0642728805542, 84.36975094579881, 56.60553216934205, 79.38543042828961, 53.24943065643311, 61.27271729130899, 60.60301180808776, 30.615934864167247, 43.48584721165319, 48.39585450387771, 50.05105549289335, 43.40195948077787, 47.61801319737589, 51.98483497865739, 45.2669955069019, 41.70604036700341, 45.543734412039484, 46.14727343282392, 73.49672902014949, 80.51703422300278, 83.36754614307036, 73.64227248776344, 61.049620720648, 77.67630469414496, 89.38135547022667, 77.61415081639444, 83.2797948775753, 78.25574859496086, 67.40994007356706, 104.47068214416505, 101.46878242492677, 98.08062338059949, 103.08541082566785, 105.82728878144296, 110.33981092514531, 109.45739530747937, 102.45618420262491, 79.2776672301754, 56.478427763908144, 24.536816112456787, 9.12069324524172, 1.1997050888115361, 0.4030049345906704, 0.035272315970712134, 0.046406365900991425, 0.14811121047504489, 0.030368633132668275, 0.1108136146719898, 0.029488771575533097, 0.09129804574073323, 0.03178915549670497, 0.162644955599981, 0.04481284939233334, 0.008641468913054035, 0.020476930752216328, 0.05606705255265679, 0.08196849676389849, 0.028076986444272825, 0.04836848944485669, 0.007560075957313061, 0.02613502824979444, 0.01597272925033805, 0.0336978520687309, 0.051747228304344806, 0.09307340853997777, 0.026631204246152795, 0.01428644332448922, 0.02970475091358587, 0.024582505105964603, 0.012455904000108282, 0.03832308492893654, 0.05286910661285924, 0.027756298208729397, 0.034467368236472534, 0.06485517271944592, 0.021496296920362982, 0.026681557290195942, 0.07324401935141894, 0.013996216660034994, 0.05685484757827175, 0.008683098130859435, 0.047002451253994826, 0.05130356380475625, 0.060901584464215466, 0.03920789349884276, 0.04903869380453422, 0.0250617218308992, 0.09205680220357834, 0.0631018962350584, 0.02021835309513394, 0.03373997541324746, 0.11277644684718502, 0.05261658105037866, 0.019379069300128088, 0.03142572913108574, 0.020609511843612118, 0.012318035944425052, 0.0618661274652808, 0.02902378684901182, 0.009784535298334255, 0.0551239944874279, 0.02698146156035364, 0.036005914106123874, 0.04272973375214685, 0.05206345024728968, 0.048679034676282644, 0.022240009331595034, 0.041300661846875183, 0.048382650580137014, 0.012235666170806415, 0.049688485751469294, 0.03736462083555037, 0.11769458576436005, 0.05008987368895643, 0.054366804674387946, 0.016556048705693216, 0.0445431481385904, 0.08227428841975429, 0.026477695547885476, 0.006632407640873065, 0.028828993672505025, 0.04892616697977628, 0.023848194508783283, 0.034788822559940244, 0.013969581698127573, 0.016652684951681766, 0.10589158402815943, 0.0624355836020362, 0.004263048993438602, 0.14595959125266922, 0.05378943484937472, 0.04796167377442603, 0.11152057593027431, 0.053682354909758416, 0.06445958023710598, 0.033531323706190434, 0.07672763564774106, 0.028995857198512363, 0.04399825661112705, 0.008789524022910384, 0.09243095188491768, 0.0341914042139486, 0.024502150143586823, 0.048041293292396495, 0.053318497619681784, 0.039506039597214236, 0.058081331362407056, 0.023936645105300892, 0.004488374125362645, 0.01948579109363979, 0.026964416104038397, 0.03167625137364432, 0.025125326280812585, 0.03593514673411846, 0.01933097238502195, 0.03991481645273105, 0.11189784358946547, 0.03201492735364985, 0.1284442319264335, 0.04037700878876833, 0.054463335583286906, 0.04871953008396011, 0.021015936809201396, 0.021210302891690406, 0.15935385719903056, 0.06565313756225571, 0.7821554846821294, 23.03977489471436, 48.25069150617046, 75.61337332571708, 94.77412023851949, 114.62816176875945, 109.11279155362038, 100.74511297287481, 97.8384562461607, 96.36244481609714, 97.16474210062336, 97.89282814148935, 79.88495995921474, 103.42995966634443, 78.38926607562651, 90.61840041991204, 82.41350804605793, 64.13616911057504, 68.80505654119676, 77.630734597483, 80.40164593727359, 77.46159415091239, 94.30542053714876, 92.93819212144422, 87.40346893187493, 84.91742364821896, 85.79441855030676, 77.74389497695431, 114.30178134672104, 117.13753731020036, 108.95331582715436, 105.56146191012476, 91.27326365440123, 105.7452484869188, 117.11474049475886, 107.11164536014681, 121.06287279436667, 121.56983913913851, 96.71370090976839, 123.28102803999379, 119.51637637230658, 111.97825554878482, 127.3532170634116, 122.15577848495977, 127.67369824071085, 132.65071530495922, 123.7744386734501, 95.06938057561075, 65.94513093271564, 30.023729531995713, 12.045578206739119, 1.8052588595497994, 0.29560394284705965, 0.0608185826680593, 0.01991776317628401, 0.1429649229131399, 0.03846100756838437, 0.08235255962297802, 0.0911672668711793, 0.06974556393200351, 0.021013586834493666, 0.046437733371051094, 0.01796234673219583, 0.06247777972490557, 0.0635703590007559, 0.04284529811552456, 0.06427422526382631, 0.08846748875634325, 0.0030699312112354225, 0.025398065073175297, 0.05129896344677095, 0.024839127323620265, 0.01883167841081177, 0.03040972800414649, 0.0646702544162831, 0.02716798864815745, 0.026846271939575676, 0.036562362069925, 0.018645270066636226, 0.05264194622155159, 0.02284085400582802, 0.023223557058841954, 0.0965366239148763, 0.05930157152995948, 0.01537935967902623, 0.04704999467057567, 0.03538770030342764, 0.09919748476315891, 0.10916326210022935, 0.0891560409218073, 0.013859822365996099, 0.0592904785768159, 0.10266256173171344, 0.04511121382576324, 0.027106441144320755, 0.05839760693150663, 0.042215815159462156, 0.02379725732269787, 0.033530691683652906, 0.12431095774856307, 0.04592772565721985, 0.03337383135071686, 0.07470893268022807, 0.05559259514895178, 0.026125457896400365, 0.02502340019770688, 0.06845773182689183, 0.045125493704671824, 0.052290790669259526, 0.020979109047461423, 0.03974386010198824, 0.06882206026104189, 0.0408285525026581, 0.0361948237273722, 0.09997319475176836, 0.13940243020413384, 0.04186629520488843, 0.08161285576680977, 0.27523345043582303, 0.15099908615792954, 0.17767509505633386, 0.12212128693898841, 0.22912631081717633, 0.17432379746629348, 0.1824207952426326, 0.1802253557909881, 0.1297803505534126, 0.20040924450562847, 0.08370415322602758, 0.13413030503978654, 0.08713723070198491, 0.1826671691190812, 0.16097765716333545, 0.20614158932960805, 0.1241695762221371, 0.14015776225395743, 0.2352462961308418, 0.1736612999511342, 0.13969746598553273, 0.2282776386146584, 0.2261799366603936, 0.14155620979445596, 0.1359476954225571, 0.1262013792931553, 0.12787328191822575, 0.11701012450841167, 0.14495083731749367, 0.1215803062903785, 0.20758108386108953, 0.10085120046090695, 0.12243009698126586, 0.15472979645334906, 0.16634073228605334, 0.18624026448495928, 0.19683889173451932, 0.1198530231692618, 0.13032893079423136, 0.17449521730023046, 0.16528664126751885, 0.22358404772896923, 0.162486314112621, 0.11190395697110123, 0.17947488073860446, 0.14103401362174942, 0.1744822857360686, 0.1521731465454063, 0.17780146892032317, 0.13247486564420885, 0.2639759109625893, 0.12995573872279736, 0.18384233267316896, 0.14685378439964789, 0.2076214566946991, 0.11272333397139465, 0.327917562136727, 0.20489234507324236, 1.3686299275967384, 32.058013869870095, 63.99393612338651, 98.34645025191769, 109.71362021661575, 125.20316985345657, 120.67968860749276, 111.54111523782055, 104.92388848335513, 103.37634871082922, 100.8193555954964, 108.76732487832348, 79.34808161950882, 107.9451019533219, 78.2042714088194, 84.0941495280112, 84.83263769457417, 50.35958128590738, 63.57665477260467, 73.13270168919718, 71.10445976257324, 62.92045400988672, 69.37441995066982, 77.00340640160346, 67.96586544282975, 65.04670027763613, 68.40524150479224, 68.07946512776037, 104.91767544900219, 108.29513426749938, 112.0013818433208, 102.44277754137593, 86.49095304550664, 104.76362828285464, 119.12686147997458, 108.71748724291402, 111.81976825960221, 100.28190458974531, 87.25468558649864, 134.36504210195235, 126.41810832485076, 126.73714606992661, 129.62362612447433, 136.35882992898266, 142.3958283085977, 147.10369233162174, 146.01598770387713, 117.04188639117827, 86.25973716858896, 44.5651501224887, 18.1369710353113, 3.2296227255175194, 0.3938928090276257, 0.13815150055433476, 0.1755406208817036, 0.35996115075484403, 0.16676842385242063, 0.30086350416944874, 0.1756101510217113, 0.19786287549762957, 0.15255131818834813, 0.22970706675081487, 0.11887038517142497, 0.21337652368651283, 0.16299070640196725, 0.14019235878461792, 0.2115515490332919, 0.22733507467614067, 0.10732920164422644, 0.08003553435687097, 0.121864854328094, 0.13142488085694853, 0.10553601963986313, 0.15230289119626247, 0.22551841973777742, 0.1398752137057243, 0.17679352703834736, 0.14440167484985245, 0.1452726708544839, 0.09365837029632061, 0.08806953672319652, 0.10953539697032784, 0.16541100798114655, 0.22037092175695205, 0.10204606779640722, 0.10424416557314897, 0.14326167473148915, 0.32260437465963826, 0.1479120735800074, 0.15956001145945442, 0.14218590342469756, 0.20518632365330575, 0.22029851112634907, 0.2742649007949137, 0.19886493382434692, 0.15964910748504824, 0.11058778727367041, 0.18404346139680955, 0.13374986577658884, 0.23325904873349976, 0.22612807250791983, 0.21747143218113532, 0.14151694012745736, 0.10025372848876062, 0.09909825339432686, 0.06532538982649004, 0.20084101165975296, 0.13612268522622126, 0.15653825425092252, 0.11814498417680303, 0.1134627313923932, 0.13011209726814302, 0.1481690194698111, 0.17475325103488662, 0.18888728212445013, 0.19845821774534642, 0.16807889385569483], [0.0070203909549051, 0.047019320510087476, 0.02427339054373724, 0.06008391200955357, 0.009900408969711392, 0.06739008871297683, 0.018150850326844284, 0.10225515617358108, 0.029133136324103803, 0.10744394629352516, 0.018105116792984547, 0.028756257454534213, 0.06320044961607744, 0.05651450918747052, 0.014354460440846461, 0.048402086230776006, 0.05444748905457316, 0.0882829764797803, 0.03700698034897928, 0.0485432226090662, 0.008019901081664308, 0.022905852735763597, 0.02933593894985895, 0.028543474618345503, 0.04007574088210541, 0.05850626884268657, 0.053402269334201856, 0.030020787080209103, 0.09269231810204445, 0.01579124014824629, 0.10267622107940336, 0.01165518890165033, 0.0340724767245833, 0.05188992367156091, 0.01271110799749412, 0.017274028223548687, 0.021891864504845395, 0.018962744563337297, 0.11255613528192045, 0.10985294041494209, 0.02884573077843074, 0.0392048406384645, 0.04373947977118435, 0.0713579798297536, 0.044418057471874266, 0.051969887929097305, 0.04846480584913685, 0.01802427153433523, 0.0285129594211016, 0.048742363334543286, 0.01656445077500276, 0.05718469439494995, 0.062069987292371454, 0.10491414010644921, 0.04879773616971028, 0.11648859483219924, 0.06622383476144846, 0.4482793519573827, 5.0416900842420524, 44.27689906089537, 53.238267590922696, 88.3428373644429, 79.63453231319305, 78.70122786491149, 69.64677364595475, 61.06671440985895, 60.048223926175034, 54.67631832245858, 50.27554842733568, 36.998101818946104, 48.91249341349448, 38.84078817982828, 19.448621426859212, 22.45396890947896, 27.17063669235476, 31.58028683354778, 31.973273023482296, 28.34895395463513, 25.39148488352376, 29.0025031951166, 32.91992725864534, 28.373647236054946, 25.93155211017978, 26.164401654274236, 25.09813277952133, 17.94032104553715, 31.833193417518373, 18.78343843644665, 22.83580380101358, 31.619436010237667, 20.019020342057754, 18.90486717224121, 22.112738393968154, 38.660202257094845, 52.64641331088159, 30.471330804209558, 28.628699356509795, 39.02376282599665, 38.30642015703263, 47.82181562915925, 64.42123912995862, 57.64972202239498, 80.25287828137799, 85.8099276019681, 103.69244467827582, 99.453382338247, 102.25501368122717, 97.94376404054704, 99.67674563007971, 98.25618866951235, 53.76879953568982, 18.235310739086522, 1.9196555210698036, 0.08379726355234463, 0.0727567567880596, 0.03228613971582344, 0.06602197825427979, 0.10128947936238782, 0.05338302520554393, 0.026208865719156402, 0.09883903988426733, 0.015538521148564835, 0.03386400121774885, 0.05915349056463569, 0.009701974960344454, 0.0368733094975112, 0.07915613436771017, 0.0403206630219375, 0.04484982079555912, 0.021559746237471703, 0.0995563586512881, 0.044791942852879726, 0.077733593361993, 0.013995909267255377, 0.07026869473197768, 0.008568292194526763, 0.044650339160955725, 0.035621571624951984, 0.03470841014096814, 0.008946785594396775, 0.07669251817729204, 0.035070382854751045, 0.05142378598271359, 0.01482454444011373, 0.11867154705067796, 0.007145139754885027, 0.09767948920207639, 0.04709474952711214, 0.022358335441939776, 0.01279011177229545, 0.03969065146520734, 0.1139783698524679, 0.017883253899673303, 0.06871542848286129, 0.046360013751132835, 0.007942328454866525, 0.09448733871742603, 0.02427237930767719, 0.05706925260564012, 0.0203542934820777, 0.03469477377591595, 0.06279249247463961, 0.06552041282937413, 0.05047094880513126, 0.0596424998084624, 0.04182803294351024, 0.015196720487438144, 0.033701157738124175, 0.044387011758742795, 0.11287119660166003, 0.025692610558302655, 0.02640696839549609, 0.044321415480226285, 0.05613846343851859, 0.011014007782984165, 0.06736234100835939, 0.0968005718483079, 0.015758764723526136, 0.0038565998481992153, 0.14055364584970859, 0.013789805760156485, 0.0571115215068623, 0.002389142389274052, 0.08297576448850094, 0.010958373520313012, 0.031216657990890167, 0.011121550248184753, 0.052909061928550084, 0.03214913638188474, 0.05387241749333278, 0.04923856614397899, 0.03576663420385411, 0.08428154603367852, 0.062217099156471035, 0.04508070437417877, 0.04034583284068973, 0.015920689855251583, 0.045713267003696774, 0.019602977648197163, 0.03744425184483971, 0.09122290017624056, 0.0124642830867801, 0.048089146974586675, 0.019554281269290277, 0.03446310495717391, 0.061790602687265606, 0.013550521069837194, 0.031754729420607614, 0.037529632344000766, 0.00882179930716032, 0.07371856485523524, 0.02960394331884961, 0.02509351639497665, 0.020160536439488494, 0.05253759355494573, 0.052375857072371634, 0.010088089977451151, 0.01369489225438766, 0.030296873676800923, 0.06263732519601622, 0.055738404663580085, 0.09783438451948667, 0.019969008712758942, 0.01563994735929995, 0.012363325147288702, 0.06414366472933082, 0.02682962867942068, 0.010657920539679547, 0.056618034479118166, 0.08913609965313828, 0.041173751721338886, 0.06265367734275999, 0.02439577692008067, 0.4648154517335277, 6.19467128669062, 52.57824251728674, 67.24402381527808, 101.73225587414157, 92.24250485820156, 89.46239948272706, 81.75507545471191, 83.62208443303263, 86.96381830400037, 77.53390696740921, 78.70940208435059, 67.27506545282179, 84.60016665920135, 58.354979868858095, 45.046362184709125, 39.19546458028978, 33.274411462968395, 46.829283391275716, 31.302282964029622, 32.486050359664425, 34.59538728960099, 39.77697949255667, 44.4417288226466, 33.26930453700404, 34.97289972920572, 36.09641559662358, 39.25083275764219, 30.339325397245346, 46.83482177795903, 40.80890409408077, 47.655401229858406, 59.377510393819506, 43.42074371153309, 34.03321750702397, 54.48067049826346, 66.20144997873615, 70.40529727935791, 51.85418867295789, 40.79155937317879, 58.557970370015795, 78.6656205884872, 80.3134475215789, 91.21609118676956, 83.32983647623371, 114.82650818363314, 112.37501898119527, 111.24546266371205, 112.28581643873646, 113.44278227898383, 119.41409664769327, 117.5073697490077, 114.91480858095231, 66.97003841400146, 23.44238461986665, 2.3669552610766504, 0.08346794533633417, 0.1351012601967781, 0.02375133035163726, 0.033748961624599276, 0.14890104712497804, 0.03562210405605935, 0.04267376336839892, 0.04661974820098089, 0.058892197125861724, 0.0258061945843961, 0.00656519539564127, 0.030935693329440492, 0.045643388293683536, 0.08431947504680964, 0.03500467549348551, 0.03402749587210917, 0.029280736569255113, 0.03908995426289978, 0.015636368771083653, 0.04318212016275333, 0.06433103834429095, 0.056637987239106055, 0.056792928521791776, 0.036433601842051556, 0.05759001236348864, 0.12993745986492405, 0.04470652404932245, 0.018871214293364077, 0.03471612464636564, 0.017699902246315635, 0.01931286589693158, 0.05843616413673567, 0.05320569500327111, 0.06117390956909907, 0.1147974557393501, 0.028894748914265828, 0.014385401774498244, 0.0216169098031617, 0.03475108889922981, 0.061125745621299556, 0.07586551860215203, 0.051501256624056455, 0.05077980481268418, 0.03156262712793485, 0.03398251118919542, 0.06864263480829616, 0.04367387966222821, 0.026130125287079045, 0.051035873531814546, 0.01908385923372642, 0.044770120838356596, 0.03280547071969317, 0.03174709343922234, 0.04094875552841733, 0.07956082031371133, 0.06030198659807925, 0.04186049974974125, 0.0528983979846441, 0.03291798222269262, 0.022160847551159324, 0.041923269163817174, 0.10796118587736162, 0.0632252478821864, 0.18645706736753065, 0.101627592267769, 0.2110592149678738, 0.18847779280716376, 0.1931737432436597, 0.16680257605208507, 0.12284653471602548, 0.21043186556668053, 0.10246948459215703, 0.24864756412083105, 0.1478507405807895, 0.12575818210720055, 0.1727929239672038, 0.18252357359855406, 0.13056350691664603, 0.15538746761458536, 0.21552872513571095, 0.15664170676421735, 0.11725875068335764, 0.08807533600878331, 0.08625478168288547, 0.10762760821249216, 0.14088091861096122, 0.18424969226602586, 0.13029263354837894, 0.12798331512679018, 0.14371377385912404, 0.10413879784004343, 0.21538830121919034, 0.23064371649055715, 0.19210601586007303, 0.142248799243281, 0.15681257501484888, 0.10683042477936515, 0.13517659728325185, 0.11238551217942469, 0.18433809881248783, 0.12000228007954937, 0.1248867187889353, 0.20647430131512307, 0.15488865244532787, 0.14257222624315372, 0.1750047730221864, 0.2107248175889254, 0.131033088170713, 0.1324759994543368, 0.12909905324059148, 0.13652500396053638, 0.10287944122307724, 0.17770840455928158, 0.10636572350537586, 0.13790673546252713, 0.15283493925967526, 0.23919813004472565, 0.15282409145466744, 0.28220025401922966, 0.1924876655421911, 0.655634960820598, 8.366030204680658, 70.20249505196848, 80.85743319603705, 115.02520761182232, 100.84641210494503, 101.57014431491976, 91.67224714832922, 86.9441907636581, 85.86432303151777, 78.63712064681515, 74.62492819755309, 57.176288020226266, 66.2042897747409, 56.212518522816325, 32.34866738319397, 40.64471367866763, 40.354497509617964, 47.11664015246976, 47.89707022328531, 45.89484537801435, 38.84403590233096, 43.42521129115936, 46.078757470653905, 38.88015700924782, 39.44971261485931, 36.168183203666445, 36.33340520243491, 27.575913629224225, 47.32883645642189, 29.119279999886793, 31.051182631523382, 47.58870524744834, 35.11524646512924, 32.583419276822, 38.73643744376398, 55.04421311040079, 74.77618263613793, 42.57779498254099, 40.563320575221894, 57.61868430722145, 60.054554631633145, 67.1714521223499, 88.92966316592309, 79.86515198984455, 107.36712501895045, 112.13307149948614, 126.30570104045253, 122.50175506837907, 130.56568530298048, 127.6482891267346, 137.0541249552081, 131.96277864517705, 83.72651361650037, 30.486692766989435, 3.8083905077749685, 0.2458742645479018, 0.2726085574155854, 0.11183843347093753, 0.19529513263654327, 0.28163800676984174, 0.1070181776078478, 0.21243336219941417, 0.2267857743126731, 0.1503896938576814, 0.14306068390367493, 0.17128872564963757, 0.10146296763372037, 0.11407459049575752, 0.15706555256920476, 0.1206865881179129, 0.09150321174773479, 0.11062122701156525, 0.2516412212243003, 0.11586770355220764, 0.12407569214701654, 0.1875241665590194, 0.15345448988579935, 0.12499118253829018, 0.19888695119129074, 0.1675690163768107, 0.22636226558637237, 0.14560201205313206, 0.13863831878669802, 0.17010136597579525, 0.18766367117003088, 0.1814769289546436, 0.19829327901524885, 0.12044044406784159, 0.1842502744928483, 0.21004194213498026, 0.07326553110033274, 0.13213843047138185, 0.1902745447812542, 0.14375596998199341, 0.1249491626156434, 0.1826235327509142, 0.1344265512401058, 0.17066267859791556, 0.20932974083529365, 0.11724534414468274, 0.21857697366466447, 0.19835140976694324, 0.09701064081802484, 0.1780101359491387, 0.13374986577658884, 0.14435056146354447, 0.1611276418571511, 0.14607071996696536, 0.12236317154020072, 0.157670057228496, 0.11257096674413451, 0.19695974976545383, 0.11834506335998736, 0.14436835002514625, 0.11729091871529819, 0.19031301771681156, 0.1718716266294641, 0.15557188029971816], [0.055018661228278955, 0.024378783174700314, 0.029636201366121252, 0.06508953433724181, 0.0687766389080113, 0.03766895692435004, 0.0398212771171764, 0.02577642249243875, 0.09032046392319665, 0.07081043380763262, 0.052428383890899925, 0.10978166359446703, 0.035643359165518515, 0.02417918471168847, 0.05835713833690651, 0.03437643743030006, 0.012887473886592254, 0.007685326066078439, 0.043344603581053597, 0.03407549128056534, 0.044623323070305976, 0.016740304342801535, 0.02300781903848533, 0.0724450968987038, 0.08502228410854455, 0.039277339369178786, 0.039763211482955564, 0.04191906717155249, 0.02347451022585794, 0.07958436219562447, 0.044194011227978815, 0.03127486343615719, 0.029645790871713432, 0.04354468659467755, 0.05017566021471735, 0.012089848037688963, 0.05394834446750822, 0.017736371861951008, 0.08964757059490489, 0.02031837161930819, 0.06033515054432135, 0.05232692320620822, 0.03608379843494585, 0.03163381967873823, 0.03198361925540432, 0.0779088819399476, 0.03402761078529781, 0.04376797441152796, 0.03595739392743957, 0.03876867613965466, 0.07841639986802494, 0.03959053909526237, 0.020403041571919477, 0.12554666523130673, 0.04522575163132241, 0.18720905927400436, 1.001321595282324, 14.945212910252234, 71.33504806026336, 74.76145805851107, 31.765120683177827, 63.743869335420676, 79.95815138663016, 49.18635329892559, 44.24164872015677, 22.52341055100964, 22.025946147980232, 28.477360586966242, 20.24449190785808, 29.822884567322273, 36.88151721031436, 51.663294761411606, 69.51530364251906, 68.83888306156283, 80.30590088136735, 80.26347652558358, 113.92130359526604, 86.85918515728366, 107.15592891939225, 109.84450970926594, 128.79402129880845, 145.06790376478628, 122.12501925806846, 143.52120337947724, 137.67200808371268, 138.7126599588702, 105.64190187761861, 117.77667184029858, 96.86439052704843, 76.08114734772714, 84.40516210371449, 90.16336625622165, 79.80120951129545, 80.14958658526021, 80.33984507283857, 90.98744053994456, 109.61945979825913, 75.1672350975775, 54.67415709649363, 60.64635007612167, 36.0100136264678, 39.663764199902936, 30.170392836293868, 39.921491376815304, 52.087173538823286, 64.25542093092396, 78.50138310463198, 76.02435927237235, 82.30243436751827, 85.56525799535936, 95.64136412835892, 89.64416211651218, 58.68354505108249, 10.39463593113807, 0.26777429746523984, 0.07361220886870738, 0.08455408947362054, 0.039130556922886646, 0.12138110044742785, 0.10329913483151507, 0.01830323479108272, 0.018741011904973178, 0.014744277577847244, 0.008762949390427, 0.0624090233337014, 0.05947144003584982, 0.08038937504733763, 0.016211544711803718, 0.030759853168180397, 0.07701275059052053, 0.013364780179765678, 0.040678805296099, 0.04363891923980367, 0.019202012974288196, 0.015735764848819424, 0.050311437807977206, 0.07522702262166046, 0.038503858696429, 0.08811180179397907, 0.012801497754070067, 0.004384243145449869, 0.03393640801791222, 0.005488624484578689, 0.08582338225096466, 0.03531564590370944, 0.035938869921430465, 0.06422198955870925, 0.11063254213020687, 0.03478941627808156, 0.033817162602058345, 0.028741410670561657, 0.02703857533032856, 0.0571702421462584, 0.022567063757789232, 0.02428146894089878, 0.05002880882051203, 0.030930355611828067, 0.03205500907384821, 0.02058394748957888, 0.017710780694840417, 0.03468428986267217, 0.051712490047418305, 0.049161838607922684, 0.035559533824843746, 0.03219434323029653, 0.033062320848506306, 0.018907490471798568, 0.09544157783590979, 0.0021922362465111, 0.06922410320370428, 0.07155235165790205, 0.028882529811873555, 0.06458566298768406, 0.08428725338871441, 0.06415878730495611, 0.139724891933222, 0.011860203606286838, 0.0444688376099352, 0.05088578541612914, 0.05273033744625507, 0.018111934975510644, 0.04030442578838237, 0.05590066974682193, 0.033282165100137075, 0.036990463493331786, 0.022832888606635314, 0.045164522053974296, 0.04613818150133856, 0.07009605681824108, 0.05931355314509523, 0.07839976043830957, 0.02488773943285548, 0.06981635811708628, 0.03241834733935614, 0.05283792683434102, 0.02378484478310472, 0.06988264770517427, 0.032311144825671954, 0.07246112345807976, 0.05169701507134784, 0.07619873620569706, 0.035830541258497585, 0.007457129540853203, 0.014173136047658422, 0.04200941575090251, 0.02196598925717896, 0.07335607503210345, 0.024376950309341474, 0.03189816980833008, 0.04206295763593047, 0.02203041725161095, 0.011160659036719272, 0.03019938515799661, 0.022119363890059536, 0.056309193793323734, 0.0789325133026127, 0.06011552845818862, 0.08228866022921379, 0.056471669550744764, 0.07639360599099629, 0.006322707978993535, 0.09866382025422589, 0.04648087178206733, 0.07527887145237577, 0.012879080435771857, 0.0604015052498829, 0.02861896109196448, 0.03628491566726758, 0.056528739270664034, 0.19518058717010484, 0.08837709038127815, 0.23317182196244118, 1.197333158023896, 21.86440137124831, 85.49470240069975, 90.95777173196116, 41.865327819701164, 81.50019199617448, 103.92008335359635, 73.83686127201204, 70.71264636132025, 49.27114317494054, 47.52357036836686, 41.947317123413086, 35.269897676283314, 35.4700993722485, 37.73248326393866, 45.728897740764005, 33.835690867516306, 41.578025971689534, 47.87346147721814, 56.858022982074374, 78.14637722507601, 63.52764475730158, 73.32028512031802, 71.82903135976484, 77.70115683155676, 87.7908500548332, 72.23844835835119, 63.45050350312264, 64.8825922319966, 64.22180621854721, 65.94648807279526, 60.12895807143181, 50.94907429910476, 54.07158690114176, 54.293338098833644, 53.501407638672866, 53.01799512678578, 59.37964416319325, 77.29301852564659, 55.35807724921934, 64.96841369136688, 67.37929067304059, 39.01660842280234, 44.452636934095814, 42.214399153186434, 45.65865593571817, 47.65953148564985, 59.052863659397254, 90.26095482610887, 98.41256572354226, 115.39506358485069, 92.54184446027203, 97.07870883326378, 101.60877966111707, 114.89064678069084, 106.27465863381664, 77.79740395084505, 17.129629888842185, 0.21323352571456664, 0.13136610659139772, 0.09942587089514542, 0.012865894147375179, 0.0417582614858064, 0.055825941700247995, 0.018323641458165743, 0.05355396623452825, 0.04160439272621467, 0.016655764625137372, 0.05390389987658109, 0.04491668878002994, 0.07807608062942183, 0.05947940351982271, 0.07097823004568778, 0.024771198307374315, 0.005134922647548299, 0.033395906174254995, 0.01648130533736079, 0.10181877717015245, 0.09259665670293955, 0.08646999876345358, 0.07052812274665603, 0.06463916656831581, 0.03277065202353462, 0.05900457456347443, 0.07407484170530113, 0.039851598877219424, 0.09735037016892627, 0.14553379958435414, 0.011273131277712603, 0.05737687138119533, 0.04439004929736257, 0.013588712468082386, 0.03378586024947224, 0.013922105314240102, 0.02631828031172195, 0.05288818986305306, 0.0406000935923188, 0.013137651389584908, 0.07958764871281963, 0.033723140631111405, 0.06481826260325409, 0.052972375265052246, 0.020322152263214512, 0.1171742128809133, 0.025383367676347978, 0.018034904834724242, 0.0437614856468093, 0.02642551538414292, 0.01447569098203413, 0.04728280112988526, 0.0399899581867841, 0.034022347761258, 0.012603047465334737, 0.09296565061254848, 0.0325393968922717, 0.006843573552736592, 0.039118268872581186, 0.12532122087694947, 0.09745873330581574, 0.018850250297316143, 0.15056871328382723, 0.1424360617754921, 0.20283978101947617, 0.10919521562755109, 0.1573442706778165, 0.11885271152301181, 0.18863358444744543, 0.17950072854516969, 0.19741483663599338, 0.14672710410048886, 0.1621194039621661, 0.2335827821685422, 0.08401112465728676, 0.1931880078008098, 0.16807176923799902, 0.12735277113895263, 0.11544606408044217, 0.09813535748229874, 0.13477161256296022, 0.09576745631714022, 0.13657165871512505, 0.1008088970857282, 0.11381592090812423, 0.11872172580971835, 0.20900354059713505, 0.17420830205082896, 0.10114924696784827, 0.16370350525023478, 0.13914873252712912, 0.29876583285870095, 0.1435645399314742, 0.13847583153795812, 0.15222942336432396, 0.13731056583985207, 0.16642069654358974, 0.0996205031931881, 0.1333623631827293, 0.10351796018620653, 0.14532933071736368, 0.19740987238624405, 0.26197363292017295, 0.27257187712577086, 0.13695485589485015, 0.18014287876506008, 0.12846497758742303, 0.18426470758934177, 0.15268192085767948, 0.16233646731463172, 0.1942868077106053, 0.11976723664350088, 0.1394313117188792, 0.2492160626476811, 0.21681604396191337, 0.26010833139861783, 0.22141350613486385, 0.28986192999347565, 1.8438310801021516, 30.4109537601471, 106.40656794271162, 99.65020687349381, 54.272439710555545, 88.42869020277455, 106.85447908216908, 71.35932753163, 65.94583695934665, 40.10435619661885, 32.1772539231085, 46.0624364883669, 32.209338911118046, 45.93580668972385, 52.40702713689497, 73.5071546800675, 98.96253693488337, 102.09757758725075, 114.06369347726147, 117.56051786484258, 164.81256608040104, 122.12024965593893, 141.64124273484754, 149.66157974735384, 173.62291551405386, 192.41808183731573, 165.79273500750142, 190.18606493549964, 182.7564682499055, 181.34124571277252, 145.64166807359265, 154.68830108642578, 135.257899069017, 109.62151512022942, 118.73245146966751, 119.2785866029801, 108.4597247646701, 108.88092456325408, 108.03192753945629, 118.64962670110889, 147.97778467978202, 103.42580195396178, 75.70430955579205, 83.33406479127946, 54.62573543671639, 59.14185439386676, 46.30147749377836, 58.2589602470398, 77.594405604947, 88.80482196807863, 104.79464638617732, 98.34626197814943, 105.3744197660877, 108.49426515640752, 126.82620740705921, 121.75303736040671, 94.02395125358336, 22.459719104151574, 0.4268117909950595, 0.2007192802885848, 0.178362229959138, 0.17285773500559792, 0.23760380914374707, 0.18184152551956717, 0.22729876210852978, 0.10480825143355517, 0.20863911257155482, 0.15041410141894895, 0.14775320226627012, 0.20263630806678729, 0.2777442576423768, 0.19152890650495408, 0.15131540386186493, 0.22990503919220742, 0.1723481946054005, 0.12849352968436095, 0.12564235727392858, 0.19482573524357813, 0.17632005405762505, 0.14123756318323075, 0.15572624701646068, 0.17745420126424682, 0.1770094106154096, 0.13772837487199616, 0.241795122142761, 0.1441499230361754, 0.24050262456219043, 0.2756791910336864, 0.05205752455719537, 0.14379977488950377, 0.16129555300839488, 0.1710186949780872, 0.19293648581351006, 0.15912675809475685, 0.2128688065755752, 0.1636039291418368, 0.14064582154875802, 0.11583881437658303, 0.199226833759777, 0.23649327276695162, 0.17612454841934866, 0.19449245635299914, 0.2027416757998928, 0.1736612999511342, 0.07076011715276588, 0.10715107088007274, 0.09298545398539113, 0.12182566893076706, 0.14785515324723336, 0.11573173060652711, 0.18615630124845814, 0.19533377411144395, 0.08582334394656843, 0.16454261667545766, 0.0998426074041955, 0.11662333437632169, 0.19068769599881866, 0.31587361808746095, 0.22246690767426647, 0.2523295818677833], [0.10422399447810266, 0.037308313373115756, 0.0886405633401967, 0.10329309039779248, 0.11843474927328287, 0.06654400588764299, 0.021010124117075916, 0.05771736682002103, 0.060351835939312176, 0.04077061710338439, 0.08524179894236789, 0.09926967322826387, 0.058437194524993824, 0.04774193677510466, 0.06981053584886175, 0.03183708004202814, 0.07688631543949728, 0.04147821421464605, 0.0647602237821106, 0.01273610353124358, 0.06747165409427497, 0.06774178435725552, 0.06483890867281346, 0.06121240548729416, 0.010943769011646511, 0.08784678133745348, 0.05257417808376974, 0.02314193422094949, 0.025058301248317285, 0.057068904035634575, 0.05671306002524592, 0.04992422632752888, 0.05729610656177806, 0.04097110231316859, 0.062043338923925356, 0.06092883804212175, 0.046035138845083215, 0.040540675812911604, 0.029421901675842466, 0.008501102453127744, 0.02914935440546082, 0.05094354461518027, 0.04131937737486536, 0.033942666956253593, 0.031715622547292904, 0.056967401216107036, 0.0700340649834083, 0.0239230796033817, 0.05462988309802548, 0.12195616434778898, 0.0431919222577445, 0.01568679172064989, 0.06090986970511656, 0.2133636687311434, 0.9452770542233222, 16.825487344495713, 52.04902848889751, 90.13259918459, 91.9324101171186, 77.64611028855848, 25.329670290793143, 25.557259936486524, 23.374053009094734, 20.476274567265666, 23.841944702209968, 35.99378285869476, 53.971625297300285, 52.69633331606465, 72.89018938618322, 99.82651741273942, 112.50352367278069, 92.43925094604494, 83.10519449172482, 47.95594499957177, 33.47768045240833, 30.989650449445172, 27.69287478539252, 19.089848110752722, 43.07098596326767, 36.63089736815422, 36.784415014328495, 28.74124784623423, 41.425806630042295, 52.4162603962806, 62.96565932612266, 60.2826718361147, 54.608041624869074, 60.18183162135463, 75.63092200986802, 64.49886675803893, 61.05193491904967, 56.124606440144206, 88.36991740811257, 60.55699063885597, 44.57710158440375, 49.87956554658952, 40.740603862270234, 67.99419280021422, 91.45577938325944, 91.42131743892547, 81.12187154831426, 96.89287477923979, 98.21063426233108, 74.31667697045111, 36.32103404691143, 29.76489624669475, 25.645064153978904, 44.03439068025158, 54.677534257211995, 66.83895280284267, 70.48896143513342, 83.02780612822502, 92.97110080718996, 87.6795724130446, 35.284532039396225, 3.5772810251482072, 0.0897301318905046, 0.17646099891393416, 0.03866954053181314, 0.059728079490483775, 0.0755004623844739, 0.1924522109930554, 0.02953535355176897, 0.1163718430325389, 0.02705805120058358, 0.036415227223187685, 0.04392308806399665, 0.07365435136542206, 0.03878657195356585, 0.02977809617145648, 0.03062310455847652, 0.10562935979255747, 0.04793655758182849, 0.021741333973383712, 0.01908553122062116, 0.01669510898570861, 0.023047295549223502, 0.11481493020490294, 0.03413242693509787, 0.06484710581360326, 0.048222633964952924, 0.02951580107272152, 0.031938992718595176, 0.014273625715906102, 0.05097185922486167, 0.02986276995450739, 0.04229201409485071, 0.03130665800023464, 0.016285251946218552, 0.010459685713172922, 0.02560633948192962, 0.11610184300450549, 0.05724974675104023, 0.05499177154213671, 0.06277873736595915, 0.08969851544186955, 0.048299786679807215, 0.00424398250141812, 0.060043408940996856, 0.007639500122862838, 0.03690155898971904, 0.07270116178739457, 0.04838529358347578, 0.05166909499694744, 0.05207867241434513, 0.08945651592746859, 0.1105558031028317, 0.06133621678717675, 0.08732517505244863, 0.044026919790814, 0.059773646400219975, 0.04007284506975163, 0.1399492024774513, 0.12065473418202131, 0.08751852032277854, 0.054954137472856435, 0.0356846627959561, 0.05366337891187399, 0.0318223251886065, 0.06856624052048692, 0.03566360686935725, 0.09149748907094041, 0.043680931501571214, 0.030912973076826146, 0.030701368100821014, 0.0222147322605334, 0.05388964681074985, 0.07261544420954681, 0.08600393385295907, 0.04068768808558103, 0.08785894681369105, 0.029797568211271882, 0.03218269869384747, 0.05028873479234115, 0.021686359503937346, 0.03073153855849899, 0.09201996869617894, 0.055569011132202806, 0.043719829615926555, 0.013627646971614131, 0.03490881491152029, 0.06514422535415619, 0.06821549482523434, 0.01642746084760274, 0.035368329770262205, 0.01729933402290748, 0.03362325808754371, 0.034529383053943034, 0.05562180225106497, 0.02378837070277622, 0.08914995052280927, 0.01707253943858368, 0.02756713003280663, 0.01772863054347615, 0.021597366900213306, 0.05029495159584669, 0.042354726052332314, 0.046825274269306855, 0.015094174830723676, 0.08911566808819772, 0.035528794546881994, 0.036406773442943255, 0.06300608544880826, 0.002504078560553852, 0.014429412568138253, 0.11013093074002575, 0.011227483928744352, 0.044128736706390496, 0.03326343808082804, 0.20041718117652402, 1.6925106966687788, 24.65003924985086, 66.37761931265554, 104.0643245943131, 101.09996195762389, 91.12654347573557, 49.13030262916319, 38.994611770876, 45.69642051573723, 32.683896672341135, 29.221014515046154, 27.509339240289506, 29.289905063567627, 33.612625675816695, 32.80113827797675, 55.75905722956504, 65.41163759846842, 68.39132493542087, 70.27361546793293, 48.857325277020855, 37.95088475750339, 33.14595383982505, 27.219015206060103, 20.377415149442612, 34.71493721008301, 33.29447438639979, 28.87027813542274, 28.09015597066572, 35.1660882273028, 42.49036927377024, 43.76896781306113, 46.53951045005552, 39.03112511481009, 45.97393605016893, 52.58771504125288, 47.90170646482899, 44.21415290524883, 45.12601375579835, 45.99430491847377, 42.37357677951936, 31.165094144882698, 35.20322915046446, 34.89586045665126, 42.36630078284971, 62.98254512971448, 76.41784360331874, 65.7882792718949, 74.3634786913472, 59.38310369368523, 57.146121071230986, 35.42097560821041, 36.699833023932676, 38.439631692824825, 72.0618946321549, 86.67175077622937, 84.39111217375725, 80.15190862840223, 91.70080200318368, 107.37948048499324, 104.39452540489935, 51.67641116726784, 7.272112542583097, 0.11682453204787548, 0.2093870901773053, 0.04175558017807142, 0.1619527798386351, 0.04855383292681748, 0.1164115034043789, 0.13543967187644976, 0.06965516555693842, 0.07508299809189574, 0.030158271134320288, 0.0425381160100862, 0.036715066375871824, 0.0735058298995418, 0.07981444138192362, 0.017673541160841143, 0.0660019527159391, 0.022367022879001115, 0.011236290109433956, 0.017362681833366235, 0.010920897456667116, 0.058395982825107155, 0.11546865601332919, 0.0097129185263428, 0.021093664089998892, 0.10425752614654842, 0.06404211594452781, 0.04038989438765472, 0.05935178859339607, 0.019913432864292015, 0.03980995050721592, 0.10391413489536894, 0.024728029252841108, 0.0382251980444116, 0.09984200985561456, 0.04541600190643822, 0.06707649062117262, 0.02324241622831793, 0.03282644237662035, 0.01869220827375689, 0.09778523997914407, 0.020609965750707254, 0.023466937446726427, 0.040991185308103605, 0.08233936758892191, 0.0062533617000876665, 0.09293298462345716, 0.03584832598965976, 0.0035980729444418107, 0.03521854042886727, 0.05782185738245326, 0.03235404574943166, 0.028150800930997057, 0.061660474992447326, 0.12991797058813034, 0.061282161623239524, 0.07448803122726179, 0.041340245609922756, 0.08349124973099079, 0.020484055369912137, 0.006514398499406995, 0.20905678370787253, 0.17128875629315454, 0.15063473474114172, 0.1956389988622358, 0.2674407121394911, 0.2119610383505783, 0.2992291934788227, 0.13468872184955305, 0.22315392000300271, 0.16200830589138693, 0.2525691682052228, 0.27917904839400326, 0.15457402013482588, 0.12198090132686401, 0.21557645241339363, 0.1210792005182274, 0.13711020320413575, 0.1159469783306122, 0.12138064079467328, 0.1350446309774153, 0.17220139683734986, 0.32432657095693773, 0.12741534520060788, 0.13165794012527313, 0.11799811746083921, 0.22018961938879184, 0.19832957626110126, 0.14802315632902807, 0.21790385817087468, 0.18044560606921875, 0.18847918708718595, 0.1003528219617663, 0.19979910143921453, 0.14230892182357852, 0.21438587517026933, 0.15394392813886368, 0.16921576833532703, 0.07276481603302302, 0.10837769256003442, 0.12946079995843673, 0.17057839360448623, 0.12037244610368245, 0.05570019219791698, 0.15961950584765405, 0.14521002018403623, 0.10127875413144789, 0.1276714943589703, 0.12605000798019672, 0.1086739081168367, 0.1747441192668292, 0.09668578889461295, 0.09008960332721473, 0.11616034147840355, 0.4456113741522836, 2.2505429915843473, 27.72775838452001, 78.11251148100823, 118.69712660389563, 111.37370847886609, 102.96246805498677, 45.85455086923415, 39.87563886950093, 35.57849407196045, 37.1315683087995, 35.64097350643527, 53.73536132997083, 82.54179308491369, 81.52899788271996, 108.92507476191368, 143.11054691191643, 161.95373873556815, 132.46197085226737, 119.11112493084325, 72.401242409983, 49.34928463351343, 50.53271470531341, 41.83230146285027, 28.885159607856508, 61.64128672692084, 56.04291523656538, 52.277902710822325, 43.2994601034349, 58.95454552865798, 80.1722578848562, 94.46992474217569, 89.48941676847397, 78.72514647822227, 86.69053108461442, 109.25274956610896, 91.71781724499118, 90.03028023627498, 78.71674476131317, 122.05429107912126, 85.35230467396399, 62.23414513372607, 70.7079787408152, 55.122040779359885, 92.98529978721373, 128.34578068025652, 128.5144582871468, 118.34992624098255, 135.55948226682602, 140.86243260291317, 104.27262598468413, 53.213435065361764, 45.03309672878635, 38.73067940435102, 62.55027640250422, 77.79880031462639, 91.90375328063966, 92.36173706669962, 107.40375995635988, 115.74339359037339, 122.43482374375867, 61.344508432572894, 9.966193476030904, 0.2527330190904679, 0.2700891393807627, 0.12714558265983097, 0.27303177502847487, 0.148090863179776, 0.3120698383258235, 0.17038843444278165, 0.23006490642024627, 0.17172478289613802, 0.11050148746900021, 0.12323517878089221, 0.19330646031566207, 0.16494426125239942, 0.13198651523599703, 0.14480520400308794, 0.14196617408625542, 0.1620898942553228, 0.17759981925689405, 0.14078072963222382, 0.16094796359539032, 0.14761090909521427, 0.21548442993192904, 0.15499037359991383, 0.214798811883215, 0.21136857659345676, 0.22682841476653853, 0.16055571125640025, 0.14095996356298848, 0.11892617169407108, 0.16528584453607761, 0.20000778378978853, 0.13693271595383846, 0.20143643051626223, 0.1573441634255071, 0.14324244592458973, 0.2271261471774309, 0.14888546489659818, 0.11284717208435459, 0.10909806035699383, 0.2350100192932352, 0.17284763796675592, 0.14304128655743215, 0.11036545323628573, 0.1841461478221801, 0.20529225829147524, 0.16713020121378286, 0.14094287980227702, 0.09968915999296213, 0.24747681323318715, 0.2040483000417871, 0.28296358402698274, 0.24975083798410433, 0.24947645593314405, 0.3977782537619914, 0.25009971442482165, 0.21430742776682302, 0.24606676712151498, 0.23108248568830952, 0.24659544439806094, 0.21520748914730167], [0.08390915069368579, 0.047040859072078625, 0.04968187441268275, 0.031797710783599366, 0.019631979821790612, 0.03819184640662805, 0.06482623757854586, 0.034967788359931404, 0.06392190525788935, 0.042583158149594263, 0.022982902028748108, 0.04604896290167686, 0.06362658985439809, 0.025154248015173984, 0.03623441898173863, 0.06779690438340749, 0.043368421254619476, 0.013924374849715782, 0.13828098473529662, 0.04042386655665694, 0.014438206299899087, 0.007145215884872502, 0.035691446504525604, 0.06192072655164427, 0.05732978378692943, 0.05722328607413558, 0.03273324778063163, 0.05182505517657246, 0.0579517629117735, 0.016299589281721462, 0.055589852554182854, 0.01562287700512717, 0.03321891305066886, 0.07991848378292016, 0.01693801822951965, 0.008122429022595527, 0.04552663266358357, 0.08062095576596838, 0.01150280443741189, 0.00661528796979016, 0.051804592968114925, 0.060422817815936385, 0.07733680578249116, 0.04933224337536001, 0.03424614885701768, 0.02933715702965856, 0.11067503702736671, 0.06749636042983302, 0.0462180461674448, 0.0942299178531093, 0.2464355771700221, 0.09324831407397025, 1.4259530387578474, 16.45486847046883, 55.75404444048482, 80.95047181652438, 87.00405397722798, 78.58372934402959, 74.89736034024146, 44.6380748287324, 22.37918107740341, 41.871332968434984, 62.824136287935325, 66.00836738463371, 76.30656596153014, 82.81686106035787, 97.05312713499993, 60.98310908963604, 65.90708394204417, 44.856637139474195, 22.868679146612845, 12.172443347592509, 1.106704588859312, 0.32174145322172876, 0.1423090290758879, 0.05873886079737737, 0.042498359877255656, 0.0987542033075325, 0.2007715581285377, 0.06454190404544916, 0.05009307593647992, 0.1281513794956188, 0.13699357397854328, 0.30387974554492586, 0.15361446436614762, 0.1421872364176858, 0.11734847490104938, 0.1766814943403006, 0.20865320858936157, 0.01999333200435485, 0.09913049037418059, 0.2969613893618507, 0.3424336719176462, 0.35478797350679675, 0.9147194616736904, 0.43987015803014085, 0.1517111035965143, 0.6234898502307554, 0.1707450483715342, 0.2678097826578925, 2.935606760363425, 13.865499131141172, 23.417273606023482, 48.78391027450562, 97.90455602830457, 100.50965309143068, 76.84487988871913, 33.193822445407996, 23.712410388454316, 28.126983104213593, 57.946233595571215, 72.91107992972098, 82.19927603198637, 76.96094282211797, 80.62668800354004, 67.42086779686713, 27.379022413684478, 5.429847836494447, 0.19969698191890795, 0.15233145095407963, 0.0795320383903961, 0.046144930735951474, 0.07737203050524959, 0.014518858121347525, 0.06537028257885287, 0.0179839791399577, 0.056298610288649804, 0.040404595614921664, 0.020267499550696344, 0.06259431701994712, 0.048046299676981666, 0.1531654908772438, 0.031887293275025104, 0.06043959514147813, 0.01261860958390659, 0.035539964108818003, 0.01863014749101093, 0.03963072040689088, 0.04713526791742733, 0.10817078753344475, 0.01295992665203108, 0.024786441541847684, 0.013287151532788432, 0.03998258842095252, 0.04987791248206651, 0.022832838810920235, 0.04541286094594867, 0.03197998608342342, 0.024790068968169154, 0.05105576117432887, 0.0829883589739761, 0.05029053126852359, 0.030199390903656042, 0.021849371522905368, 0.04106982040309137, 0.013713939115405084, 0.07649636902515927, 0.08431014409589191, 0.03778770055261351, 0.027299062461562218, 0.020075140618568948, 0.07752044471882044, 0.018446535367759007, 0.06198031287039481, 0.07765500040184106, 0.04900250381099121, 0.0033079961459377724, 0.011070851506965776, 0.09306074510658942, 0.041070214938372374, 0.014545769832517593, 0.0643503590817413, 0.040757834926367774, 0.027765031611066193, 0.05080864419259372, 0.023941971331594453, 0.037618008246945764, 0.023381947652406754, 0.02997385270352806, 0.03205934704671944, 0.048435054824597416, 0.01602720672024354, 0.042219446416223244, 0.029805882180470134, 0.06424960319793994, 0.16439676885643315, 0.027566114966306957, 0.0958480257841368, 0.011653585862668773, 0.02146611497136614, 0.0597400036490252, 0.04371399968682278, 0.09318871243346123, 0.046971650688999125, 0.06254681190776248, 0.08072307528627497, 0.015508699260892407, 0.011386925977985225, 0.04066299324134185, 0.06745588034391403, 0.05609910567140868, 0.0297409983637232, 0.05400618793623102, 0.04240845562890173, 0.030402318018698887, 0.03675401045550262, 0.04849762888625265, 0.037129064120592616, 0.009246392047873909, 0.05395127858425822, 0.078023458049903, 0.05250807235678358, 0.012226935641299333, 0.07847716596217887, 0.0509222167273683, 0.1575106802967287, 0.05031802999456564, 0.04243135782739809, 0.10840135701601544, 0.09608311518546074, 0.03735991705569529, 0.01156003790862498, 0.05743248936449809, 0.043056918413288174, 0.05243798680303078, 0.0699612942914809, 0.16013047117139065, 0.06713811473380174, 2.535606391968266, 24.91482080951814, 70.14504017368441, 93.85595613910307, 96.97620945592081, 98.2917174985332, 98.24883814780944, 66.17222047621205, 34.18801384587442, 36.20169201204854, 34.38846657353063, 39.2121660324835, 47.68983963997134, 55.11313307669855, 73.80266604884979, 62.23560033305999, 61.50676904186126, 47.61296902933429, 29.28350179426132, 15.487775744930392, 2.33031444011196, 0.8138611059515708, 0.09515374328099913, 0.11436126059702328, 0.12238592435155185, 0.031098967733522578, 0.18520684251862188, 0.09711371028735753, 0.04646545043215156, 0.14945299815266364, 0.11638075263509828, 0.20053152746010214, 0.04049375292754943, 0.07069018098615831, 0.07096142207662906, 0.19603013271285644, 0.040793251171107256, 0.05687101203347406, 0.1685635670418701, 0.11038806049093125, 0.3163696140531571, 0.17009519130712555, 0.6045908288609597, 0.2807702130127338, 0.09958362372051324, 0.6088169375734945, 0.4281852027821926, 0.8352744891758889, 5.08738422586072, 16.57275922836796, 30.673489762890725, 50.58129325989754, 74.08655935718168, 65.96114204775903, 52.62805269610498, 39.82588752623528, 34.25865965504801, 51.98841218025454, 88.90591713689989, 101.19223179355745, 97.96201090658866, 94.2961480540614, 93.67123603820802, 87.54764741466892, 42.31034032760128, 11.123644709587099, 0.21257640613663584, 0.13585558101054163, 0.019019917705126347, 0.04802328639573628, 0.05618765777457626, 0.04665941623370013, 0.03466259808309617, 0.03702210675504419, 0.039001612833911375, 0.02210604545149592, 0.062185448233879385, 0.03416364884845192, 0.08464450317044413, 0.05136903367876526, 0.027634750698663058, 0.037578531736207586, 0.03403721369742867, 0.05821414419539994, 0.013015558041872518, 0.08345411744930091, 0.04299904813148803, 0.06250081598878869, 0.060883684819864656, 0.016952778828600724, 0.04836687299933645, 0.00606616045491049, 0.05640756331324097, 0.06797052288968718, 0.11354733814275074, 0.009762374289904632, 0.02958656078384769, 0.0661182678454826, 0.02743329447243483, 0.07549442561163057, 0.0792248141501219, 0.051255001491236116, 0.0749069893912923, 0.019781403356201707, 0.06607529031293047, 0.0528925986990573, 0.06460870691244641, 0.07486303126619709, 0.03700034985799463, 0.08893546888664847, 0.035957811445358305, 0.024195527282333183, 0.04251030318799519, 0.0200010733228297, 0.03970039610360419, 0.023426076232065118, 0.013644801595458582, 0.005616653577289394, 0.015509571643516183, 0.06813288756435917, 0.01939347175310456, 0.06952407259133554, 0.046753959144435586, 0.036744614387111324, 0.18685121960457296, 0.12289051582375843, 0.27353488029010836, 0.12030447878304029, 0.2358187017061057, 0.12333819462407021, 0.31686603902809085, 0.1259078833484842, 0.20442015912023284, 0.2826493041169259, 0.21409212641658323, 0.17401678006975882, 0.0738567594558962, 0.1098333975119937, 0.1899640953108188, 0.17497518670655068, 0.09866126918143804, 0.22135762768166684, 0.26957662655941905, 0.19409646550493856, 0.12262555665426678, 0.11010798640669354, 0.18525061678261528, 0.20860166619381598, 0.1303638184383031, 0.12993373667761204, 0.1187556864874017, 0.08772282065042565, 0.1378704841819502, 0.0825358614806206, 0.2372311380121016, 0.15439654820628707, 0.1674954566143213, 0.21719623807697527, 0.1782359633474581, 0.18075328230136828, 0.14696393252140091, 0.20694179881003597, 0.1522670842466816, 0.24278827852779822, 0.1429555306751882, 0.13308264915981602, 0.2800737778025289, 0.1694474026801125, 0.15669369349075904, 0.12711617254441784, 0.2075968652723297, 0.16093412804747784, 0.13257087178287968, 0.3310469700203788, 0.24598782942179712, 0.3074271003565481, 2.7400753815327925, 28.116314257344893, 83.89521475761168, 109.34009290510609, 109.35229932108234, 97.76952451275241, 97.75687879131686, 62.33409889282719, 33.2400671897396, 62.54426340903006, 88.17580715302499, 92.45225752553633, 109.56175388828402, 118.8612856403474, 143.88898049631428, 88.85844076833418, 93.29936396691107, 67.02605770480248, 34.95539811349685, 21.584957991876912, 2.2014275625828774, 1.043565215602998, 0.39001211403839053, 0.4467583303489993, 0.4656398236270874, 0.20595026653139822, 0.5800401010820943, 0.25771464371392805, 0.20986090023671428, 0.42161330220199406, 0.4317571949814597, 0.6484324473046488, 0.38101818052030384, 0.2609600985963499, 0.27919381856918335, 0.25855651305567834, 0.4828266691296332, 0.28925301266774056, 0.5106612174741684, 0.8329869506339874, 0.7779131961926338, 0.760030007410434, 1.9487139101951354, 0.8183304016147891, 0.6066266615544597, 1.887448694436781, 0.46337532900994827, 0.7725853304709158, 5.40772762990767, 21.63635280824477, 35.89169925259006, 70.20718620669457, 140.43465891192037, 136.8208537563201, 107.48923624715498, 47.661324008818596, 36.46631079335367, 45.98725641927412, 80.65073997743669, 96.10254856847949, 103.18017528903101, 95.49755434836112, 105.48036298444195, 103.40799439337947, 51.79606699174451, 12.614855324068378, 0.24696662931913332, 0.5223902687430382, 0.17809154045197273, 0.18681907455527014, 0.23563718483332666, 0.14349956035373673, 0.11315640347499041, 0.11088908965428991, 0.1191614909217723, 0.1705682046350933, 0.23681369670216115, 0.1852166331222942, 0.19454675666507215, 0.2788003864547899, 0.1360405452789799, 0.12463310538160226, 0.12926164774164078, 0.1459040651999174, 0.10448783515922486, 0.20341880559440584, 0.22600529925717464, 0.16221015473767636, 0.17898286843011457, 0.1022673829368526, 0.07900066448435669, 0.08745680427959851, 0.15340254912453313, 0.141214412006159, 0.20002417807136813, 0.13682592329719376, 0.12184905759509533, 0.13988957019342532, 0.1740224491203985, 0.16065891862155932, 0.12034346499750692, 0.09770693047152412, 0.1516969309699151, 0.10101180313335312, 0.10356159655437355, 0.15073904527291176, 0.1467330336210228, 0.14367553074994396, 0.13655834410700107, 0.2079831727690274, 0.06737541046834762, 0.21573497132668573, 0.2185349920464139, 0.18875248129329375, 0.10039458141451883, 0.13101065711629006, 0.19368510693311694, 0.09205559178465798, 0.16037139050181837, 0.11980894247009871, 0.09551776527997949, 0.20683004190364193, 0.21273265742967207, 0.14246779313731578], [0.02985885332999451, 0.07205525007579597, 0.025349083326516614, 0.05202555953855476, 0.07465522225585676, 0.062059059048131596, 0.020700385193190268, 0.033486641628006776, 0.08989919217363482, 0.03989209811533651, 0.07035351598695402, 0.03683503957525377, 0.022383848085038127, 0.0446120883908964, 0.11077927861122355, 0.04711978911091724, 0.06802722871784242, 0.04199243158162121, 0.022136976251438744, 0.05189263562281286, 0.0344575546501625, 0.043805348010913986, 0.051793423406178915, 0.021910352121678092, 0.030892648764194983, 0.07213849318964828, 0.038783702954289415, 0.08016878769042031, 0.05404300995231156, 0.02640481377320905, 0.05310045367467308, 0.012167726620851506, 0.056960192328739556, 0.12069395022286523, 0.036976624114979664, 0.022582163350776802, 0.008716657569992447, 0.04506386193116346, 0.03904654772111005, 0.03950871324406997, 0.04613112583155594, 0.03989038973926537, 0.04052875165437018, 0.02585096476269105, 0.011019367525624412, 0.033043191633037025, 0.0912811994672783, 0.12302782176242721, 0.1322707185341466, 0.1578526925896445, 4.842083117654247, 28.331642573879613, 56.06975993802471, 79.80375120716711, 66.88754312453732, 78.0725033052506, 64.62779114323278, 31.191083769644464, 32.52951022117369, 39.75542999082996, 66.82207092162102, 38.56799125671387, 61.51819882854339, 52.79336098701724, 37.29610781515799, 34.067777510612245, 15.487703181082203, 4.990601212747636, 0.7312909237319424, 0.13046285828515408, 0.10564994457508288, 0.10186360097460209, 0.1161495779430674, 0.028366155907391544, 0.106982309371233, 0.11841411086460275, 0.028560253859107054, 0.07733105246217982, 0.222735712605138, 0.09391270382630248, 0.06427922781797187, 0.040266175018323046, 0.0770522807274134, 0.273763082560993, 0.16647807652911834, 0.2750016935169697, 0.1334410557343114, 0.17475090680583832, 0.15590079248912875, 0.2818712345775097, 0.1337492988715249, 0.11234080328816369, 0.08112842772877024, 0.22130331204783535, 0.039912096840599855, 0.1294607539931613, 0.049302618755328084, 0.020739122429081512, 0.2131207269285956, 0.23115221501117755, 0.1367810611883479, 0.37078857782386965, 0.1973589428610379, 0.07735620312873395, 1.4854095515704926, 19.99214033926687, 52.696490210871545, 107.63509350438272, 89.0298326553837, 37.11882060573947, 18.707409174211566, 21.032090110163537, 51.10752628695581, 51.573048868486964, 67.52947038219821, 69.80610032235423, 80.49331957294096, 67.7990391946608, 34.58218459160098, 4.0987424888918484, 0.041625249469953204, 0.07253856728634528, 0.028720833548915484, 0.03897072799924401, 0.07750894573907699, 0.04525237701713078, 0.03037536321508308, 0.01891525668813096, 0.063258285423921, 0.03590203258359144, 0.022882075281813744, 0.01289470001093803, 0.07147165961683759, 0.02229610037419104, 0.010678612574514364, 0.05067421874452022, 0.030336137598140106, 0.0988233580644573, 0.05957975720746383, 0.04813218579417275, 0.013978631111733137, 0.06648524694385068, 0.08953936067560027, 0.03973055698518311, 0.00658051906934669, 0.028993342514900915, 0.017285762775328853, 0.03883776577910589, 0.03907684266807572, 0.04060514594217943, 0.05769139643938792, 0.040658607387975346, 0.03579181934436483, 0.029615610837936405, 0.013189339341836111, 0.04679017212061633, 0.014655462131955692, 0.03386209748925702, 0.024634463104209112, 0.07723005909112192, 0.11211160510297745, 0.034648486743530924, 0.02790995054848252, 0.057745555025194927, 0.019354631095343543, 0.007509262781710394, 0.006943902342520174, 0.045682730739034956, 0.07534927493261714, 0.014585506813150021, 0.046479963967877055, 0.04556507112518434, 0.022887411084206357, 0.04925189224342185, 0.060140173506712725, 0.02410901105782438, 0.09016412069960948, 0.07054231835589295, 0.02224054750836184, 0.014577514600879965, 0.04777452998584317, 0.011827861289343527, 0.0635383595081587, 0.016590989975919648, 0.10637093290326097, 0.063316056114291, 0.053506307904758764, 0.061141821976390585, 0.033824421285140904, 0.04618221240478658, 0.03723424033171708, 0.05832701575972381, 0.02115475960196026, 0.042299912461350044, 0.015147346120718268, 0.04810808466807489, 0.051953145077512156, 0.04386632860968671, 0.06609897009066998, 0.04800516458588743, 0.015291947131646017, 0.04026442067697644, 0.02206941687261626, 0.01638124467835071, 0.03758573296269582, 0.03509405114117169, 0.022938369337709683, 0.038398460319806496, 0.07425212211185887, 0.0683359008642935, 0.024581066775886763, 0.027150408845515023, 0.011546368984836004, 0.04668653957665928, 0.01888711636345233, 0.026656550265127615, 0.015039701191257807, 0.027432899937153827, 0.07667557997328621, 0.030915746315112038, 0.031587599679046584, 0.07143680261628282, 0.09030725656738205, 0.14354138875440245, 0.06388838125032283, 0.08565917896527438, 7.736893796151685, 38.431073081108835, 71.39831589114281, 90.53328498717278, 85.5613983831098, 95.43625554730816, 88.1423964038972, 61.59013509750367, 48.799717426300056, 42.67660340955181, 44.60487588759392, 37.71674279243716, 53.46886765572333, 54.251086327337454, 48.47611796471381, 40.9006404876709, 22.80604870088639, 8.130986584771065, 2.254471245311922, 0.3036637700373127, 0.1751438179804433, 0.16689590088302092, 0.06686149570610254, 0.06941955521582596, 0.12128894773101616, 0.08474709766526377, 0.21088051729865614, 0.10107876687881448, 0.04103470676308198, 0.2647703134965512, 0.05105380381968233, 0.10065263047093347, 0.05344006811238585, 0.20834799916032823, 0.41813164709075806, 0.7586823668210738, 0.7560752776841965, 1.0162939563874276, 0.1830483591484447, 0.18917715447323938, 0.14936544962467688, 0.020530041712786884, 0.16849071208027103, 0.07880914250328656, 0.021745953483567126, 0.03881341950487226, 0.10439022023591304, 0.03571655886668352, 0.21185004753210854, 0.23965128637369604, 0.3337204636585328, 0.32454380284874673, 0.29640303383911815, 0.3865692842631571, 4.238431328727353, 25.146597585370465, 54.14833199593329, 71.77532626736549, 54.17669465464931, 38.227011772894095, 33.047094422002, 41.98761555456346, 80.75142721976005, 68.63677901606407, 85.04523800265405, 84.48462147866526, 97.08018364444857, 89.21842021326866, 53.560152976743645, 10.299060517741788, 0.03537920055790775, 0.17003880723589854, 0.04731031134724618, 0.08625085165183391, 0.035945622986483, 0.021033495544425903, 0.027668600293597388, 0.02653001169223459, 0.04583234771064693, 0.04267056878175467, 0.021699842651404684, 0.02533956659927724, 0.04130623513652433, 0.021840921573100552, 0.018901248770435492, 0.01079187484367961, 0.06803618428567726, 0.053190089792253516, 0.017577125165130825, 0.04789567146930964, 0.028371078022305044, 0.02498983980096396, 0.013751820248040943, 0.054426360349621505, 0.028724242640178532, 0.050995573476557775, 0.020867892233054006, 0.07012370493142836, 0.08386032024939215, 0.02067962804088189, 0.040327052195226, 0.02155389715616982, 0.01672917691570136, 0.046476876633542205, 0.020686201075272217, 0.02889637493588511, 0.035369471241269386, 0.01638321735475573, 0.04693679368844436, 0.013102061817452553, 0.07214532669393287, 0.029117215101817445, 0.039972165794742685, 0.08516442406201556, 0.05204840428045681, 0.021130706356357665, 0.01621250232170907, 0.02979849326244045, 0.019256200288392363, 0.041876633561426596, 0.02298466403097395, 0.02527051526422222, 0.02197478011611008, 0.0481059932480416, 0.05331756682285378, 0.0611620313758331, 0.19116073997030336, 0.10101129751532309, 0.05059138165726777, 0.08935011397566527, 0.19997268164109802, 0.14497225713585654, 0.14453892716236655, 0.07419930034947973, 0.19732716553393873, 0.18839674070477488, 0.1476751685503029, 0.10994261100647912, 0.12693600398638558, 0.18551652590113302, 0.17837631065518628, 0.14080179705014154, 0.19877389193542544, 0.12690068733307625, 0.3278746612129673, 0.16630204484587716, 0.22333008958207023, 0.13267522827992517, 0.12025372545805671, 0.14117154172591626, 0.09785963477747095, 0.18388751653894303, 0.1609373609385183, 0.16955309217014622, 0.15814084890148333, 0.2184504619048488, 0.14808013794883607, 0.11173239158045863, 0.15588994468412093, 0.30731347419561883, 0.1959277220791386, 0.15878862220673792, 0.1198032504368213, 0.2020406747056592, 0.08982959308571394, 0.1351502285368981, 0.14985389196343962, 0.15529942879032704, 0.1340484562059564, 0.20022633335282727, 0.15142199733564932, 0.15876617583055652, 0.16409350529072747, 0.3257399418902013, 0.1941914910510663, 0.39745603718103906, 9.905603643386595, 44.07548535254694, 82.43289239944951, 107.66635479465609, 92.16372797566076, 98.97604557775684, 84.02040896877166, 42.36857967991983, 47.31862260449318, 56.6635440241906, 95.67307256883191, 62.915911905227176, 87.48963555982037, 75.97109348543229, 60.429337101597945, 53.25487490623228, 23.401892031392745, 9.53152818064536, 2.0837687148201853, 0.44684787070558923, 0.3298313417021306, 0.5393074512962373, 0.27650564668640015, 0.366925441569859, 0.4624585975562373, 0.4090307676984418, 0.23347200585469124, 0.26561034422728325, 0.4450940809422924, 0.3772313159800345, 0.2135224481143298, 0.22065412914080007, 0.2672646651344915, 0.544586593825971, 0.5569370956190172, 0.8871880389990345, 0.9955677846747061, 1.7899042512139969, 0.7303697183247536, 0.6941683253934307, 0.28438004995546035, 0.323632127575336, 0.3397389116787142, 0.3838590490481546, 0.20871737611389932, 0.3251028325288527, 0.364200895832431, 0.11087231998962742, 0.4305219241688329, 0.5199147628680353, 0.32948758272874745, 0.47048710707214575, 0.45737673798876427, 0.4070877848613647, 3.5217211419536225, 31.065964083517756, 75.39314793002221, 151.1363438637026, 130.56910560977076, 57.39458360979634, 27.923280692869618, 33.874843966576364, 69.26123603697746, 71.81403221622591, 91.02773897109493, 89.27539656239172, 109.6965265274048, 100.82283866020941, 60.16230214026667, 10.399286881569894, 0.1999565171858957, 0.39175045946913384, 0.14467466262079057, 0.1609475805514282, 0.1482900613618474, 0.14570742575151308, 0.21790961915206528, 0.1333027615422203, 0.15692727369887216, 0.12272955308998786, 0.08551494759177009, 0.12402672380689653, 0.19798301340591526, 0.08562410746010081, 0.1355896565702654, 0.16811963441150804, 0.1792798960401166, 0.18996273167431357, 0.2673933679057706, 0.1362467761481962, 0.10535808805856975, 0.09123855901341285, 0.31311824497195984, 0.24277199149852802, 0.1261576433335581, 0.09580515550389405, 0.08194927561787829, 0.16220604850640222, 0.145429611626652, 0.16259036417449677, 0.1865618988390892, 0.13558829293376015, 0.1455202245063359, 0.14567111318390216, 0.08961297406424439, 0.16498037463715, 0.17254704038702673, 0.15977217184920467, 0.17458806715665326, 0.18159057043733137, 0.14008605642424476, 0.11682042581660133, 0.14102923323310193, 0.2374845292539366, 0.13336270026141597, 0.1723798033931563, 0.1098438316295224, 0.14040614328076764, 0.11085941906898253, 0.13997641392052174, 0.13090882870939471, 0.08184301156190135, 0.14053590325338228, 0.10452076927908968, 0.1535177840701034, 0.22976182671564244], [0.01616279470674213, 0.0074252765625715264, 0.04197723239720349, 0.0926483906204662, 0.055701008081556334, 0.028675253232640606, 0.06879384524279064, 0.03066798198908087, 0.05258398400920053, 0.01879058736977318, 0.01526172113259353, 0.0731266929858154, 0.04605091259544415, 0.0582719263770888, 0.055820927654783574, 0.05469130802779429, 0.07709849881188524, 0.01842448161163878, 0.024303486307842598, 0.15550619592109036, 0.01542319714527337, 0.04878239142858694, 0.03939608299744226, 0.04316731168317699, 0.05291610610701385, 0.03803633438843874, 0.02105265348819235, 0.006320654384551511, 0.025095205618849686, 0.008242510431896775, 0.011908913391732402, 0.03779939105433803, 0.049310283465010506, 0.03060052028646873, 0.046762658072815794, 0.030196847491747433, 0.005708772777354406, 0.07957693880363818, 0.0627580376702451, 0.07065672592650499, 0.04433886696314139, 0.031335662089047894, 0.04533828611695959, 0.10779752651409757, 0.03321131728889962, 0.03421336795473772, 0.05739453736872924, 0.4481126818685763, 2.5413708052327557, 35.76340244662377, 74.47947886682327, 87.72527587029242, 86.0014412480016, 73.77495842595255, 45.05869411653088, 37.39777957239459, 28.158593485432288, 46.68021763524702, 49.96576747586651, 55.20491653873075, 51.900621691057765, 31.03999407060685, 21.020446554307018, 10.50138617715528, 2.900491986543902, 0.1871472666220319, 0.15118680834289522, 0.15906573153070866, 0.33084803230820164, 0.05416587513360766, 0.17903669376767453, 0.025460250345208955, 0.07937972478929066, 0.09758802596479656, 0.09298297952139571, 0.07348432581150725, 0.0699627268758993, 0.05536013342920811, 0.09409245869685566, 0.05985193675564182, 0.01693458424039906, 0.05153163967113342, 0.14338720589876175, 0.07206254323283512, 0.04962580060706504, 0.3378497082139215, 0.4167531178362908, 0.7398108020424844, 0.23038836406363597, 0.07271668272874049, 0.08359156128379606, 0.2220646195834683, 0.11591085728498236, 0.08231456166193371, 0.07570634085324503, 0.040413968700675235, 0.11811200409166275, 0.03838582369949549, 0.13648573429353777, 0.07283916486607445, 0.06332812965997765, 0.20275624679221263, 0.23215946741402152, 0.08990057879277775, 0.043486023411875775, 0.09256361533076533, 1.28222685427435, 13.696401830642456, 46.66288075908538, 95.67037397815336, 100.24624240013861, 53.73978968589537, 17.928306825699345, 26.83770787331366, 32.199056417711326, 63.29538160754789, 82.04512688421434, 71.06686776684177, 79.11237070637365, 66.09476151004915, 29.20040442097572, 3.2930825073872847, 0.2551710173006981, 0.21392983835070364, 0.09948438469080195, 0.04592183444108214, 0.12044453497735724, 0.0286292917876234, 0.04133463018543778, 0.019617127292158625, 0.02431479568082479, 0.05587931504593261, 0.08730281294593889, 0.03877092843815204, 0.030892652594634605, 0.06855397545281919, 0.013776767901295136, 0.035921966191381216, 0.03680196755956258, 0.04577722002361571, 0.013652803383827692, 0.04399867412904578, 0.059858122915630384, 0.04512408027245153, 0.024877309145766403, 0.049863119324248646, 0.042530887970520605, 0.05517657110167127, 0.02644052879223901, 0.04984204041501207, 0.042415419368133436, 0.04564763242078405, 0.028763148415413116, 0.012011224434020059, 0.07550651447907572, 0.05999829402313598, 0.05569343913286444, 0.06239771970637864, 0.03960211468379825, 0.06147942543330212, 0.028409326877144557, 0.026680944419856516, 0.021987568038786133, 0.06749715716127427, 0.007912501300339618, 0.045549921736481695, 0.02225155427661394, 0.04710953885449037, 0.0347106394568278, 0.011958274351913604, 0.02464750575111999, 0.04345940951738627, 0.039947846333586404, 0.03538826720849161, 0.06437739432458917, 0.026191504251572396, 0.010661614041084485, 0.05339848869029553, 0.03833919958842378, 0.03299596231250513, 0.09212064031030863, 0.048946498953286684, 0.016780491400089477, 0.10239868274619503, 0.018190591137916334, 0.03140036012947319, 0.010655258384142673, 0.06439664611412634, 0.020591300018432162, 0.04912978931961041, 0.08336082326188203, 0.03132651308401218, 0.05339060564555469, 0.028627091200060906, 0.001341593282807979, 0.09783701986194619, 0.03968086469197466, 0.048973599313608104, 0.09044781071884979, 0.025396553964744654, 0.027992159443637057, 0.021369287203396523, 0.004463455200405611, 0.016815989999280825, 0.09435281367792238, 0.03245589330852513, 0.0025642030560711943, 0.005462398900905805, 0.03119623408682885, 0.021408254265665047, 0.03802397739022009, 0.05003987113013864, 0.03873820116202678, 0.05286713010601459, 0.07509934640819989, 0.06134152577649202, 0.04700744614726113, 0.0738851276917323, 0.09368506846048179, 0.15484000586213606, 0.02715933185461308, 0.03458805772806368, 0.020357313783719175, 0.3801255655144492, 3.7816409237923163, 49.890520726480794, 94.49109769636586, 102.17091021999236, 93.41450906568959, 97.34895229339601, 64.05738046092372, 64.75942980858588, 36.92201568234351, 34.01569235709406, 38.70815323245141, 47.32355694616995, 46.43270431026336, 39.922668087867, 28.790740313068515, 17.0537987063008, 4.50585215322433, 0.7074909621188719, 0.07439415481302046, 0.2944669457933595, 0.18773356903224223, 0.12259992335232035, 0.06193633176266186, 0.07797041412202582, 0.15307383611798286, 0.04504538772086944, 0.13647954430310957, 0.26962872053827014, 0.2350047179647992, 0.22100168791028763, 0.15235965831145165, 0.3330962245743121, 0.6471296075371005, 0.2561541379339272, 0.5323997284135511, 0.40934504760849866, 0.864852102052781, 1.0582706716752823, 2.1699686829120886, 1.9733481109142306, 0.9380368491814983, 0.41669446614480793, 0.5229553351959875, 0.627184784220111, 0.324114425888946, 0.3005116246640682, 0.6264318117210943, 0.37476016148444147, 0.3406445195357646, 0.05151119278443437, 0.06938325796997355, 0.041119282869922544, 0.04094998892997542, 0.1598493322249382, 0.23433062187846632, 0.07503811300041215, 0.2900369657624153, 0.1634916972609297, 1.2534142261551273, 15.335563267430953, 49.23837177215084, 72.87571584024738, 55.312267887976866, 34.65579571262483, 22.333305035868, 50.557166760967625, 54.16726135438489, 73.68565390186926, 96.87302758616786, 78.98525453382923, 94.5101604154033, 84.36314567442864, 47.11902103116436, 8.223561384985524, 0.2921027065284791, 0.16138466435574716, 0.08957162829897097, 0.04258264870112462, 0.0969613277383389, 0.0891718453156852, 0.021065811048291867, 0.056430963468888116, 0.03192692300334814, 0.010495564483496691, 0.04173419100322551, 0.07150489251099287, 0.04328190694533048, 0.030486332966134917, 0.009612233505674429, 0.03674787792166875, 0.017803617144724535, 0.0462855538353324, 0.014386881281802011, 0.04898999359518771, 0.043410467990343614, 0.06392976148955284, 0.03329919523469383, 0.040602135216637004, 0.015245863112560926, 0.023967212013479684, 0.02150792805027337, 0.021464379782217647, 0.02611943644531552, 0.010592596222376151, 0.06157016471749353, 0.03591939213595564, 0.07997274579059693, 0.054787792971417795, 0.006099131442756663, 0.06921476459190731, 0.014551883214153351, 0.019392636717267094, 0.021936966016167597, 0.04649404849436495, 0.06473909507715894, 0.015191291796884712, 0.05330660027421771, 0.02493449186365451, 0.011487997873055359, 0.012706330481676326, 0.04017221050397043, 0.02255443479835747, 0.02239320584903321, 0.07531158340674254, 0.059570694387319593, 0.023281136227230874, 0.05385561335471369, 0.06366559139062321, 0.08948794851500182, 0.07945094032273178, 0.10262509237133688, 0.20922233530830955, 0.21864376120990325, 0.08849565780931905, 0.1370025065637404, 0.15720769252267577, 0.16689220833922588, 0.10635407130804755, 0.0794085986431568, 0.15411781477591685, 0.1511460524653235, 0.2153933573994906, 0.32165457885111537, 0.19019481035009508, 0.18035396663171632, 0.11868034174004871, 0.10773109903018321, 0.34281095489859587, 0.13196463576487957, 0.140871036076738, 0.1197823438973677, 0.1947132275710183, 0.15442444912848935, 0.15939167129897303, 0.16298802509423227, 0.10347868285832867, 0.15674618583533073, 0.14721271191393176, 0.08018256195129887, 0.19771236986402543, 0.07802061586370392, 0.14270141931070437, 0.20070239571073364, 0.11565021119050442, 0.16065013925394706, 0.10811324666945205, 0.2530320385290731, 0.1575727640621124, 0.16505143695300625, 0.12951030456010373, 0.15177346315355073, 0.28520221551579816, 0.16069956724682163, 0.27803481947029796, 0.12504693841741932, 0.4810350346228769, 4.229369182740489, 61.49264066450058, 109.92141169886436, 117.07977648704284, 105.22485979141729, 93.43892189764208, 58.601026227397305, 52.67963578624111, 37.13494546951787, 65.83468483340356, 76.22758511574038, 80.9961203605898, 75.91763157998362, 51.50860824892598, 35.23277244260235, 19.57885000013536, 5.454702425387598, 0.7071745984496609, 0.34089362068522366, 0.40402484276602346, 0.8548883012225552, 0.35425024107098585, 0.4200128525976212, 0.34881634878054746, 0.1755469028026827, 0.18978409529212983, 0.24601721655457254, 0.29326262493287364, 0.2063363748452356, 0.2356759948475707, 0.19596250247090094, 0.1847437730119113, 0.47692187791389806, 0.21436041040766626, 0.3536522941243264, 0.15550215097685016, 0.2630760334432125, 0.6426612924664252, 1.9771843115168235, 1.6571202537705823, 0.6391227017006567, 0.2859055148738046, 0.3477348471360822, 0.5161730668717815, 0.2903065367812111, 0.18039999319420708, 0.560971437202346, 0.37668880315557607, 0.2625194246009473, 0.2942711030763965, 0.2710313662405937, 0.16212836719088017, 0.2310307900751791, 0.4435466139787628, 0.5200352531767661, 0.3166019531988329, 0.3667285876168359, 0.2593728563477916, 2.284715170821836, 22.595386043671642, 69.27927109502977, 138.59625970163654, 141.65220968184934, 74.61531839063092, 29.594363358712968, 36.36128933198991, 46.26666253612888, 86.2558775563394, 103.7044471310031, 89.22406842631679, 105.88983489621071, 95.27401847224083, 50.56273652661232, 7.4398625089276225, 0.3805062805692996, 0.35938413333027597, 0.20626624715664696, 0.07463563338763292, 0.2296216326254991, 0.2153850376846329, 0.23938317092195635, 0.1083619571140697, 0.2612787605293336, 0.14935516872473303, 0.13901296642518815, 0.18201063176797283, 0.11356556337446937, 0.12311078908462679, 0.09027078312130705, 0.12184128946354314, 0.09371541320316254, 0.21637093155614792, 0.13295112718497554, 0.1467064044047748, 0.12359078913446396, 0.18950277248457556, 0.14804895817031785, 0.1635449403716672, 0.12952751089488307, 0.13631273631847676, 0.11566421527776027, 0.11593679702209851, 0.14779617979882226, 0.13535765450327628, 0.13174078487340482, 0.12381887649215999, 0.1688166671702939, 0.18105810868643946, 0.11621915404835056, 0.24469064338312996, 0.11304995555791164, 0.1747980825002155, 0.10270115724133869, 0.13590755241532482, 0.14090678173928492, 0.21359924076785966, 0.18640097440971484, 0.14197864599766272, 0.13730768534925678, 0.10818783298976, 0.0924443967279888, 0.14751501020885285, 0.06387678650958885, 0.17403015596491678, 0.13895261401851333, 0.1307766019336639, 0.11787828598772326, 0.12526211719359123], [0.08505096644042962, 0.05641907378430328, 0.0066860390624271775, 0.0360009077215387, 0.07004468296203883, 0.058238103595231815, 0.05190432612453738, 0.10498637453682962, 0.04240921405594676, 0.03506837953482905, 0.01780680215526973, 0.0668166182754982, 0.02209141508736197, 0.012934217698902134, 0.007857854812285833, 0.039736417557803855, 0.018734781694928967, 0.06536586225152978, 0.07925888208011467, 0.010539521650982, 0.06004395669386272, 0.0681709774559544, 0.07044143989802369, 0.051979391249798, 0.016083724856857332, 0.06893281359225512, 0.01368272390532037, 0.0971804442064416, 0.07358949436175247, 0.03036018701330308, 0.026626759020972158, 0.05275322815343257, 0.008147882293879746, 0.07813051117644196, 0.03676729442010965, 0.04631327472687249, 0.027512484981167703, 0.07828755920091945, 0.017576328433689573, 0.026851289815479712, 0.03287873936877136, 0.08174088438071551, 0.06389256025994978, 0.09575263251580539, 0.05541699247494821, 0.2656784341219933, 0.16838879174282476, 8.256569600874379, 63.3307300075408, 91.01108458734329, 67.9399307312504, 71.64544874621977, 56.77276242163874, 23.961765266233876, 26.937071315703857, 21.59852154793278, 37.675789325468, 71.62906108363983, 54.356590240232414, 39.65068309537826, 22.21539858848818, 5.944066153418634, 0.8919593571655212, 0.22717545259623761, 0.1973377222255353, 0.02059203929327909, 0.07164443542640056, 0.12449104969780292, 0.18114757243423693, 0.07833557759201334, 0.06257398504643671, 0.0492360801886647, 0.06190330571224613, 0.08963567324944081, 0.1387031757903676, 0.14446398844161343, 0.11429860226569638, 0.11879211396820123, 0.0803111038441139, 0.3093345060704216, 0.10563817746456593, 0.3821997332476801, 0.1821342783589517, 0.3454188714104314, 1.2432681576859568, 1.2657825624750507, 0.8506893426660569, 1.2544672599723263, 0.18985426894599394, 0.40404724317692947, 0.43397808387394876, 0.2751126536919225, 0.11910123810652765, 0.2927764348926083, 0.1397678847875326, 0.22432156057367403, 0.0987651736866082, 0.21567299481361143, 0.18182992694839356, 0.3587404356127785, 0.0696104719874359, 0.050748322429435874, 0.21935936393997363, 0.11161403865703654, 0.05751895770851163, 0.12608140992421296, 0.09727793655568555, 0.09641334504610109, 0.05377245834097267, 10.252392157431572, 47.01680798684397, 88.38160607122606, 79.52189753132483, 49.28302011182232, 26.07916266687455, 31.75644047798649, 54.622071942975445, 74.52629627720003, 74.47790991875434, 78.7722384545111, 80.11758004465412, 65.68675656472483, 25.27411383967246, 4.128179386738808, 0.12163715001436011, 0.0950429363236312, 0.09436059713123307, 0.07572304923087358, 0.07176328630697343, 0.02027923410247651, 0.07613616980492108, 0.04068416408112934, 0.0665372260095131, 0.02968658696890118, 0.04714361061492274, 0.04439195302585441, 0.02425345310550784, 0.027395830857717705, 0.03235680749639869, 0.04637096880845005, 0.03514490022714581, 0.017107063190891378, 0.059322577660843256, 0.05212535398201116, 0.014004927079734063, 0.049121155508703766, 0.004652711955244623, 0.032795450289643584, 0.05723855420646649, 0.05726648960262538, 0.0224906905373979, 0.02170682745805431, 0.05546692225541319, 0.022717630678427317, 0.07459893777605987, 0.02038111422030676, 0.019734744771173405, 0.031780475720522866, 0.03882596419463235, 0.07794564649943383, 0.013709065838596754, 0.028495624766594944, 0.03130903287279991, 0.004742403614199571, 0.053945349063724286, 0.007639097447897638, 0.030811947147031466, 0.01767557703949992, 0.061479540346490766, 0.09320181253696642, 0.02787719071362048, 0.015352283258952442, 0.05921252530008074, 0.08682954680895613, 0.01562867054505454, 0.046575671332257415, 0.06520663087646808, 0.02806834114204732, 0.06280538956484487, 0.041659754070062796, 0.03190730923726674, 0.03342710510497132, 0.005422757202458959, 0.03797833387169146, 0.034514566913487456, 0.014928899021939406, 0.010912925354205074, 0.01669255025204151, 0.03415120375012198, 0.01312699223372845, 0.023804964167216135, 0.010181429172535578, 0.019698037668281508, 0.04710604549355565, 0.041302431509980274, 0.020845631633194226, 0.06138750637370733, 0.021649177426532395, 0.0486135954457906, 0.039425121560212106, 0.017070589744816386, 0.041187874552222996, 0.07683477304395168, 0.03948937718486113, 0.06238591046102586, 0.04667033298662113, 0.049681288355420676, 0.030759021962782553, 0.06986367936816908, 0.11454139085065936, 0.019106261559852192, 0.021317319629052957, 0.037781805506036166, 0.06360621574605185, 0.05507616761831507, 0.0315669670160259, 0.016443849383522908, 0.11231798918977862, 0.09495780863348516, 0.1444755257257531, 0.05032195236473795, 0.2979210523828384, 0.2848177925953942, 13.039584275214905, 81.5896769492857, 105.84685356386247, 73.22682288385207, 87.67155508841239, 79.16054525683003, 42.02006140062886, 46.22412050923994, 30.540174284288963, 31.968846628742835, 50.040845563334805, 52.99371173304897, 47.121900050870835, 29.906787987678285, 9.787323590247862, 1.3341301078757932, 0.15866468450234783, 0.16853914415884405, 0.11994738221889543, 0.12868856800900352, 0.006481999204674315, 0.21133347444476622, 0.12849372120634203, 0.3330711275339127, 0.15857866815020963, 0.8754960663856999, 0.4199383582078642, 0.6621167388173842, 0.630900678375075, 1.0154240482276486, 1.0241005761969475, 2.039309752083594, 1.8117813934241573, 0.7059796238618513, 1.9323338472074079, 2.1603137687329323, 2.788697817633229, 4.49575646269706, 5.7044255156670856, 5.010988712310791, 4.023757312567004, 2.409279351272891, 2.111591067044966, 1.9644319506422168, 1.424925868068972, 1.9863203696666227, 1.2864023398968483, 0.9544080255493042, 0.7027695315980143, 0.8789796826820221, 1.1246863271920913, 0.4481488105750853, 0.47053261269484803, 0.3587571669730448, 0.35118840214225555, 0.3819787628468006, 0.08188624956434773, 0.053606799488226255, 0.12563763051143578, 0.05648369713115597, 0.1809987828375832, 0.23694486627655648, 13.30890303657901, 46.50002394953082, 64.92940179763302, 48.34421650055916, 31.590275149191584, 32.34077753559236, 56.48595871463899, 79.99033835626419, 93.8426749936996, 87.52419948577882, 90.02544787622269, 98.09629717180806, 85.46514341908117, 42.066674847756666, 10.54773388370391, 0.20238098628338308, 0.09930555678663716, 0.07691129756670806, 0.028427804917878205, 0.047687743715341055, 0.052640735802631226, 0.03401886972208177, 0.05965127534563503, 0.011668332097601267, 0.043550838280709527, 0.016772265531002514, 0.008892911418731655, 0.023381432458277673, 0.020902272343875903, 0.06051813830591499, 0.043009938071331674, 0.05012432466291132, 0.061195298743944984, 0.031157387683408398, 0.015522336583554506, 0.062327358360973105, 0.022077117971475088, 0.04673622803942812, 0.028909429074114854, 0.057797101251180136, 0.04462915299940975, 0.02786315406762785, 0.018542646843519424, 0.03461384807803458, 0.03152466938650656, 0.040126980672920906, 0.05194621581223704, 0.06411196401102409, 0.07024784181867877, 0.09291743303859427, 0.042914675037947395, 0.04073018681318049, 0.05121997212089839, 0.03353413524887255, 0.07543506145837807, 0.05105990954043885, 0.043960660846242984, 0.0304396897028651, 0.08267580276174892, 0.054299530663317254, 0.054267864418967124, 0.03662371039090138, 0.04179005796510366, 0.07159185115127795, 0.02045546305335818, 0.031818799268935, 0.023049959619980187, 0.24527340646713014, 0.09254637835246902, 0.15064256415972788, 0.15483530208228097, 0.16201843357374593, 0.11915562268827232, 0.06706549725945919, 0.21761524220628126, 0.13077496250550594, 0.09334685596367044, 0.12753085593783087, 0.10734916589553319, 0.15271803424243005, 0.13817239943290913, 0.1362759487763528, 0.11393081877500781, 0.08938155422407774, 0.085420542576861, 0.2214325970459369, 0.14169928437519458, 0.15248488304355454, 0.10540952320180594, 0.1695250073868421, 0.12246508421676776, 0.12027792617558472, 0.17695708681018124, 0.14074132206939882, 0.22940141299078542, 0.1517069207564477, 0.12016750992305818, 0.17771324623496304, 0.15875592557412965, 0.15392489851482455, 0.23996578078837166, 0.141906465193437, 0.21890622293276174, 0.12460731886207096, 0.30002941828100915, 0.15159838141933565, 0.1285607079344411, 0.1378306629316461, 0.31537149341837056, 0.32172122850052776, 0.20065201776883296, 0.18898143433034423, 0.4011661703548124, 0.4930144127818846, 13.741677749541498, 95.60170112117645, 116.76698315528132, 84.9224050583378, 90.40026172514885, 81.59876900334513, 38.52086397909349, 37.740484899090184, 33.85161961278608, 61.8386447045111, 107.41359726075204, 77.07263623514484, 61.41009046185402, 36.31600556835052, 11.005708844430986, 1.9704678654670718, 0.6461542243919065, 0.41100810191804366, 0.24473881499180872, 0.1863584258864003, 0.28194438065252, 0.7492417733996146, 0.2007192802885848, 0.2901399892664725, 0.15485587920392715, 0.6352820884316199, 0.39432117475136635, 1.0308497495228246, 0.5584379537932335, 0.7953135044344011, 1.1804623084683572, 1.4470061155096179, 1.0453191279403626, 0.21903685624561003, 0.9377038154390551, 1.504583567861588, 2.164198140944204, 3.370903067050442, 5.655126225563788, 3.604767034130712, 2.9978611488496107, 1.205602494939681, 0.9421159915866392, 1.668914330582465, 0.6371566136517833, 0.75364604351982, 0.6856893255345283, 0.35560306041471423, 0.4733778326021087, 0.6558668709570362, 0.5053856602359204, 0.4477454193176762, 0.7719599575765672, 0.29481965267369825, 0.32165699968895606, 0.533347471106437, 0.3093943528590664, 0.09251736660277651, 0.5594687404171114, 0.27410196921517777, 0.30831085938599806, 0.39595809014093497, 18.812940543697728, 75.77994069745465, 124.47251073775755, 107.96246236370457, 67.95665571766516, 40.84705306637672, 46.501730180555775, 72.68464149967318, 100.2535693876205, 94.95534942996119, 99.84805906972578, 109.71560493592294, 96.83449422159504, 47.08551222278226, 9.710734409670676, 0.24655067421976598, 0.22708742909373777, 0.17768105522038477, 0.17095664185622048, 0.17060695336230342, 0.12261407299628183, 0.19625655765975678, 0.12464489547475693, 0.16409103848761128, 0.18284081060799862, 0.118295673671509, 0.13639910507106012, 0.17393807219641824, 0.09784776807552385, 0.19955888690967716, 0.15857077744458953, 0.12615657081046414, 0.11475591845209561, 0.16183141618967056, 0.14306566347518276, 0.15266842238845366, 0.23152051944165464, 0.15737617057898354, 0.1654658751982835, 0.17342336836361116, 0.13690573433714529, 0.11375448065659693, 0.21824023205666773, 0.1807163108981425, 0.12652693601745751, 0.22187337339405092, 0.12650233693420887, 0.15749969459589452, 0.19710873854496788, 0.1752746657979104, 0.1807060912852326, 0.13149799628844186, 0.138272603733405, 0.08969152105912086, 0.134213394936054, 0.15186583803546044, 0.11514990214979458, 0.10531614474471539, 0.16622719805567496, 0.17859248534565975, 0.18198046322551467, 0.11680131192289053, 0.14251518333631177, 0.16804690202397687, 0.13484483524676294, 0.11149450595821105, 0.22290103437919773], [0.03324101851772397, 0.05599094937825876, 0.010576655847891685, 0.06108485184790147, 0.062359518732034394, 0.017320970261108973, 0.04449876100425759, 0.04663808451544854, 0.028585067446974498, 0.020989771076147596, 0.053611215985109734, 0.03335525754899268, 0.09653427202494876, 0.04019909252923343, 0.04180990347278215, 0.042234281708876935, 0.043644481038133946, 0.040029304462575147, 0.03665408960753872, 0.06454533611934993, 0.019907438226284522, 0.018083719957259395, 0.030691816899625045, 0.02455668985813616, 0.06854921038593016, 0.06836695806874384, 0.07158721631933605, 0.01678746663064005, 0.043833030598057855, 0.1247634245984016, 0.02406916299444293, 0.026121148651826288, 0.01921215214796605, 0.013832967153810447, 0.02199583221226931, 0.06567128618518192, 0.031429285694274216, 0.07222516071652213, 0.03814568194831091, 0.020038146232705445, 0.0458592412272288, 0.04639224690054694, 0.09897410884619721, 0.26646811755434163, 0.12584114942940014, 4.392937902481326, 38.17799783522083, 74.20949428312241, 76.71789707676058, 80.0592936238935, 88.34082126617433, 46.91645806835544, 30.098868416201686, 37.710694497631444, 45.568817969291445, 71.57213964769917, 45.777637112525206, 26.430960047629576, 16.892367678303874, 5.219106241579979, 0.02069811948815421, 0.07948621867164489, 0.11258194478408945, 0.03836523508653045, 0.09146821685135366, 0.039371300053091786, 0.10250480124546636, 0.04109007959824897, 0.09876050821114933, 0.2577983005152595, 0.09447163391497829, 0.17500849620949838, 0.5586878823176508, 0.28064806795408653, 0.99881311698306, 0.592701941007568, 1.0047870093295652, 1.0537422953113433, 3.1422663936691904, 2.5103306385778614, 2.643874840390298, 1.457968159548698, 1.43813886229069, 4.5547278273490175, 8.035730354247555, 2.835848874622776, 5.7539675024247945, 4.377662722141513, 2.1431453093405697, 2.525798015056118, 1.7715903371572497, 2.5494876600080922, 1.2528356765547108, 1.3492251043358159, 2.145883859165253, 1.5171434874496155, 0.7064973154375631, 0.5071528412161336, 0.27545693360509416, 0.17803550878119084, 0.10713741919326206, 0.15638269243701813, 0.139035995028192, 0.12027393485749922, 0.11317989939162809, 0.029297081055119637, 0.03475257510980291, 0.03760344491550519, 0.10625572094032842, 0.09259751472141474, 0.0198098941661057, 9.53733721087056, 53.2240568437884, 96.86477491932531, 62.43593146724086, 20.313590341998687, 24.934883732949537, 23.81295446426638, 43.67214802772769, 64.87011517247846, 77.27935298796623, 74.89857627499488, 81.73974683207851, 63.604456532386045, 32.87993673355349, 4.603589773178101, 0.48739310474165026, 0.057750871675389434, 0.022320101908858747, 0.09285138093776281, 0.05692858737142337, 0.12657108566453382, 0.01530979123462232, 0.01878174288468736, 0.06597924586986342, 0.076054006875042, 0.10088568207837882, 0.022801957806692492, 0.034415998210709904, 0.020334999557704698, 0.05469585475962489, 0.021679277021077373, 0.007001470977200136, 0.04338796032712825, 0.022606115089729432, 0.009866663754256743, 0.06041464365778431, 0.0832389922992837, 0.04715759938042011, 0.023757604611737114, 0.003410711539007964, 0.0385820341386622, 0.049436327911192374, 0.10204913980898359, 0.03244347502327254, 0.07623238278733147, 0.017671200762232466, 0.021494824116328554, 0.09853576865768242, 0.04943325206817639, 0.052749470492163976, 0.03199209410306667, 0.057629603787415454, 0.03920592848331698, 0.012950466423776123, 0.04732601614969392, 0.020546974171133294, 0.07589298285423748, 0.043397563239259106, 0.038462961092591286, 0.012211018249452596, 0.05374638070803016, 0.02751824404713848, 0.006564509746949039, 0.01610497039021744, 0.02631953669591777, 0.02033028237131094, 0.03253490761703542, 0.012848322005611996, 0.006734737835358829, 0.02055819352878438, 0.04479140659133273, 0.057759884699818596, 0.053055177878348105, 0.08555132910729417, 0.01664933906267247, 0.056926350394684466, 0.04130859468733111, 0.09549031634965251, 0.05919312029295872, 0.05876350201546185, 0.03594888652104043, 0.00983577796197947, 0.04369703083929997, 0.008825535901010999, 0.019458162132650614, 0.015450501476504631, 0.04470039151548859, 0.049199468846763336, 0.03281147301857991, 0.04767493089480747, 0.07203583740779469, 0.0044681158878149526, 0.0014006245469171254, 0.07005780604818175, 0.024924864053666115, 0.04071830861991452, 0.026555189171866066, 0.017934229390154925, 0.008301191809286755, 0.04216179446948152, 0.017273417268429073, 0.018939943871490898, 0.03285988211451519, 0.08195073118493443, 0.006686317726909634, 0.05862275634201304, 0.16158323434572067, 0.09257607192041413, 0.42495617282486736, 0.18267882897728877, 8.37394162531822, 50.89815801189792, 90.26082931026336, 88.62254942617109, 90.61671380073794, 109.85572768795876, 67.46782641257009, 44.75310225640574, 29.308022491393555, 37.75001233623874, 46.5878418953188, 47.77675151824952, 36.50401261544997, 22.348918030338904, 6.769873144165163, 0.2593806091575854, 0.369982285605323, 0.2349715003924024, 0.0437335119462542, 0.0580506801845566, 0.14262980541154263, 0.36209660552201733, 0.6254746921120152, 0.7436652661811921, 1.214195917690954, 0.48002076485464656, 0.967023961486355, 1.9911928114391144, 0.9169816886705737, 4.83510620171024, 5.481606452695785, 4.478967247470733, 5.497750438028767, 7.604256397293461, 5.5740424990654, 7.297595691296363, 5.898386720688113, 7.822472558867547, 8.973947571169946, 12.24540727753793, 12.74174007677263, 11.669517044098148, 8.938012776836272, 7.197438949538816, 6.444297298308342, 5.082795543055381, 5.986576311049923, 5.2530759284573225, 5.522757999358639, 6.881762675700649, 5.559298799883935, 3.5284835532788312, 2.229668872971689, 1.2223109338552722, 0.8831358628888285, 0.8900417471604963, 0.7501808746207146, 0.43524157736570607, 0.20051934666210608, 0.4084594499680304, 0.25155889741595716, 0.11083052223247868, 0.20642130335252132, 0.05237702918689578, 0.3934683043870234, 0.02186131866408452, 12.8426371659002, 51.76611969547888, 72.68620260300176, 47.37526162978142, 22.086589913214407, 39.938404636998335, 50.45785234820459, 68.01166303696172, 85.27477510513799, 84.13859782680389, 84.71575106343916, 97.38598731256302, 85.66688660652407, 54.563895348579656, 11.85204650125196, 0.19653702244883586, 0.021218496202040586, 0.019122573486979932, 0.025745606605684566, 0.03975514074667327, 0.006412235886654667, 0.04119609850609014, 0.008625790923683634, 0.072091409425822, 0.028955786969632875, 0.029120461399396582, 0.06957759149372578, 0.044198339624751004, 0.003416169676065986, 0.012851062685161108, 0.013953688246528468, 0.06415170865253576, 0.013945411624116524, 0.040410142091493455, 0.016531131695955992, 0.12436964008356295, 0.017174316134544152, 0.04043328560768597, 0.023280944705249804, 0.0739640883740879, 0.04069723354111757, 0.07102132249142855, 0.02312450572067211, 0.011655644723965276, 0.06183592827930566, 0.0410410116666988, 0.06844185848510073, 0.022363064119652398, 0.05746300264652218, 0.0509470226543565, 0.02278600019522973, 0.0361487397082871, 0.055974892175365845, 0.04216889227409998, 0.055592005261250084, 0.10522713298879324, 0.04525983871351327, 0.028345674546735904, 0.06365293944855371, 0.05307639468341105, 0.010673071843602005, 0.05451448344355149, 0.040930304300761035, 0.05373345297430793, 0.04719957333779143, 0.13285772574524726, 0.11502227956248869, 0.127007135250155, 0.1594324731418202, 0.15447617538513678, 0.07543097054886241, 0.16382551241305568, 0.11691540539745363, 0.17142738756393233, 0.10412683920754541, 0.1859784462759572, 0.06134871551166139, 0.27203034489385547, 0.15544846353511657, 0.1406409492295596, 0.11871575032390895, 0.12840916042125997, 0.09403363846602941, 0.1322800801285813, 0.11274118382003039, 0.0676562353187511, 0.13048659168904828, 0.11658476184933417, 0.07348854695597003, 0.25041476042280275, 0.1530249443866553, 0.1352390334490807, 0.17381401191796028, 0.158885961338397, 0.17297108537487446, 0.16733209602534774, 0.12777203573815285, 0.1548563541784402, 0.1487473698873674, 0.12251083498760579, 0.27492217359042936, 0.23146850207159597, 0.12414795722091392, 0.18275100978151446, 0.12362191528682748, 0.16831337804755858, 0.2788922863621866, 0.23196045309305194, 0.4435041420642407, 0.25852681948773326, 8.579057070516772, 55.7930955579204, 108.16893592957528, 98.52962493896486, 99.86727868357013, 111.48867314861668, 64.04280885573357, 44.02267456054688, 52.87538166969053, 63.44731069380238, 97.99017352442588, 66.1728088317379, 42.95085160962997, 29.820558601810088, 8.8348985679688, 0.6222548552097813, 0.587170786194263, 0.21175073189360483, 0.17138385844807472, 0.22650719409988773, 0.13731061180512752, 0.3323229047800264, 0.42372215839643634, 0.4742076283981724, 0.8801997849537481, 0.38068900786099896, 0.6460512621748833, 2.1072293914133504, 0.7482689643098462, 1.9754033103104562, 3.6686724953113066, 4.689491641136908, 7.602718337889641, 6.173672877973126, 6.54798956647996, 9.972043691142913, 7.299835854961026, 7.8587789977750475, 10.491795001491424, 17.95965244693141, 16.302173541438197, 18.128039798428937, 12.817646764939832, 8.49965064756332, 7.129797675917226, 6.910389604107027, 6.074313848249375, 3.734708538939876, 3.6117505690743847, 6.014049572329368, 5.767409465005321, 2.681140789101201, 2.3396391397522343, 0.9316509853928321, 0.5632258807459186, 0.6538067073110612, 0.4935741779063979, 0.23908090327055226, 0.2344138037052847, 0.4057066815514719, 0.27434791408238873, 0.28923622002044036, 0.4972450873784481, 0.1887069756705915, 0.6208239868283272, 0.0929234161852829, 15.332063532644703, 78.83862064730737, 136.1975891359391, 88.413039945787, 30.267296952586022, 34.697125727130526, 35.152265794815555, 60.19135513613301, 85.67228378788118, 97.32639082016485, 94.92729663848878, 109.44259228244906, 97.14767194563343, 58.43186616897584, 10.770029310257206, 0.6780426035965643, 0.08608086440231531, 0.14325306390322026, 0.13275848671553597, 0.20378893331414272, 0.2276942013732849, 0.1500987949510736, 0.1201052652792104, 0.17396529896124718, 0.1361842940170919, 0.14715033703513686, 0.17475384858346757, 0.13040595327413854, 0.1738948188722134, 0.13040443642004845, 0.1805537317188517, 0.19794211963251715, 0.08147649211628784, 0.2062793012948767, 0.09425436371877309, 0.2439358322730949, 0.17390174430704888, 0.09674974191453188, 0.10284568738913345, 0.2375276446823151, 0.16699371498919305, 0.18043215356526837, 0.1883167764472385, 0.11085470762824821, 0.11546505540008507, 0.13253095860202468, 0.08596172240833122, 0.2108566000336601, 0.11590309681430941, 0.19749205829876085, 0.12327031157309971, 0.13947883981370157, 0.1373726955705112, 0.16069337725639343, 0.09403474929351961, 0.15225478087461766, 0.15654516436399954, 0.11923256089850781, 0.13537717442358696, 0.12979300632592172, 0.12555819485456715, 0.12207602646442191, 0.07174863870586119, 0.14842394288749466, 0.10154191299431747], [0.018975021122323892, 0.02331099833451933, 0.014200413565812333, 0.014481048809454567, 0.027360736369906415, 0.024295522823869705, 0.04421631970833387, 0.02919617195373341, 0.03862446391834848, 0.05814988090987167, 0.011697933734995464, 0.014651382713758898, 0.025270904053843794, 0.02255252149376658, 0.03655875379580163, 0.057267117794723287, 0.033440806587497075, 0.026077276711622556, 0.031745256743423884, 0.02373549722946219, 0.08292876499434633, 0.025579961159476833, 0.05496984227530419, 0.05975174777690442, 0.04660899232652399, 0.06973130703573266, 0.0864998532098628, 0.047869080557457866, 0.1063202561870698, 0.05250902613624931, 0.03888939244432315, 0.026016966439783577, 0.02061462165006707, 0.03721732127990934, 0.08268059847215492, 0.09206254786301045, 0.017068350852857676, 0.04167251709488131, 0.032655148947190855, 0.055376688589251814, 0.020587812403156873, 0.24576250764150775, 0.06895475435040652, 6.72339697999339, 36.12548820434078, 67.56733694384175, 87.8088301997031, 79.7892855059716, 75.95563150221302, 69.79430967761625, 26.522861180766938, 28.74675681514125, 51.620795880594564, 39.60733306023383, 85.9238567659932, 62.50158802155526, 22.290409995663552, 5.592443318136278, 0.08772161789238454, 0.14075215455264817, 0.018593306322732282, 0.14687805406508908, 0.07062132500352399, 0.19450351866262575, 0.01947128713401335, 0.08198592526417586, 0.09028502469581944, 0.32647219937174554, 0.18430138787915631, 0.5500481265687174, 0.49893342258949436, 1.1679117045094891, 2.655043299159696, 1.1249073282364876, 2.6762542513109024, 3.95683138120559, 1.3929092763893067, 0.7943647811489721, 6.7712096918013795, 5.8531863074148855, 5.131529521557593, 9.267529133827457, 4.620068140568272, 4.536813382179507, 6.734838043489765, 7.502125232450425, 9.32350233677895, 6.42720704117129, 7.025948512938715, 5.798268712336018, 2.928852438926697, 5.082388597150003, 9.075717387660857, 7.041762528880951, 6.4610732755353375, 4.852555846014331, 2.1238876975351766, 4.598978536744272, 1.2094938538728224, 0.08152435728979689, 0.7821944632357167, 1.7205949896766295, 0.12576457128048907, 0.2892690698706335, 0.09826403727094013, 0.06857732581275125, 0.06029869625044446, 0.07735888443646893, 0.0941742922089273, 0.06351505894394172, 0.07569415239436973, 0.16336475649187643, 0.3777544314582502, 17.112722512214415, 62.2176476447813, 83.59597713716569, 52.81206284799884, 25.191304760594523, 23.256568216508438, 35.327391778269124, 64.58412339610439, 80.23725155861148, 74.46412670996882, 66.95296825901156, 80.7905803188201, 68.13662975065171, 15.172843740832421, 0.1565754554805256, 0.03534741940036897, 0.004167725630630289, 0.05762357850589099, 0.028202193939397414, 0.0756896554582542, 0.03358235282282676, 0.035347208726189794, 0.0488997714203452, 0.05416622370361321, 0.05558238702736074, 0.05251646101955445, 0.027413805195641135, 0.04084273279013653, 0.06800578591684181, 0.037564018200482094, 0.07372496935028224, 0.009695949678819989, 0.016447997749632886, 0.05952728401509024, 0.02719169906941393, 0.042428879532963044, 0.07596489552768969, 0.0629537616435799, 0.01472258005261181, 0.04507133511886482, 0.07985445415420879, 0.04684934858232737, 0.04548843168923932, 0.03980208661467318, 0.06869253011480456, 0.03426404084048925, 0.03334016561688435, 0.057996870168755134, 0.013077734695417027, 0.0390231475654629, 0.0772895458184423, 0.07376975485033567, 0.01194038907171137, 0.05399566188815141, 0.003100629551373723, 0.021202379627333536, 0.10145302381246321, 0.03133215915201412, 0.03145239473651013, 0.030043451791448943, 0.07475150418618033, 0.03858858035997518, 0.04247472223435198, 0.022740404557196364, 0.018906082785237702, 0.031918245142385844, 0.0730692976785283, 0.041432448122049534, 0.03540531649524647, 0.05718803070786019, 0.08780788705353776, 0.022010575574372086, 0.007043601503790988, 0.008793027917554062, 0.0764071734081353, 0.039445495668558345, 0.016432172288337064, 0.023623340042127718, 0.047109776341746894, 0.03611740671218403, 0.0344223873839984, 0.09151952175964272, 0.0019657364863369074, 0.06767516535136008, 0.04494850058108569, 0.06298489928726228, 0.010302347532894102, 0.02327724258535572, 0.015087563491937135, 0.034165832199036114, 0.034195958606658444, 0.024452725981151866, 0.06705934557342721, 0.06684821940237476, 0.001979484891748026, 0.04702810753857897, 0.023902981286688198, 0.03850129996276191, 0.07553477546260243, 0.05928164941348857, 0.09328691724447474, 0.07245113367154714, 0.03092842123981926, 0.0279003897711875, 0.3321748659495385, 0.06345892768172968, 14.2061383493485, 49.25411224365235, 92.66563446291032, 103.7420234372539, 88.39272991303476, 81.04489111131238, 92.17082746567266, 46.39965049682125, 30.18700407397363, 42.760526441758685, 37.74054373464277, 53.85072608147898, 49.26697369544737, 27.61438619705939, 6.893725414429942, 0.24394165454131944, 0.2263073677257184, 0.09133114839994139, 0.054379992878004435, 0.09325748414642389, 0.8125912998953174, 0.4041799296054148, 0.9203612395832617, 1.4496293231364221, 2.3461691506447333, 2.6237937759968544, 3.5209420611781463, 4.665324447616454, 5.713096405229261, 7.91972037284605, 4.1951666051341645, 6.4057516763287214, 7.7324546537091665, 7.399784220803169, 6.287672154365048, 13.056849568120896, 12.244630648243813, 12.179121182810876, 10.060963822949319, 11.593096525438371, 14.042889302776707, 14.737403777337844, 13.675837824421546, 17.52603246319679, 15.444814024433015, 13.252524848907226, 10.582612579868687, 7.990400012462371, 7.580044096516025, 7.869543452416697, 9.892879474547602, 8.775909062354796, 12.000209131548482, 4.818416026330763, 4.7049281289500575, 6.0832985274253355, 3.3988661343051545, 3.5302603869668903, 3.6027242147153427, 2.0554249325106224, 0.9355012207261978, 0.022026029483024633, 0.3374355610820555, 0.06024758669457609, 0.2351441000017428, 0.16559139104379764, 0.02288711805557532, 0.046626995392744584, 0.46450435874923585, 1.0242654996052867, 21.7231156364564, 54.12105583375501, 60.89400068406136, 42.906721022821245, 28.18965277364177, 34.89851982362809, 57.853238121155776, 85.73588109785511, 91.82706309903054, 83.47870611375379, 74.92439331546908, 94.59482869794293, 90.8321931285243, 32.107365131378174, 0.06277133312617099, 0.028905815054332058, 0.017570165256338737, 0.056654189998704585, 0.0715669839372558, 0.09607631998557238, 0.05290955988570087, 0.06787452441189559, 0.053224916149291306, 0.04545635941828932, 0.029145305630781, 0.05052716816745458, 0.003579326533532191, 0.020633097775580905, 0.046264612821922194, 0.03019968584750689, 0.0036151756179488956, 0.023292430278454578, 0.022222883436047745, 0.012721209824385663, 0.04237028912851407, 0.06228089129792587, 0.08795615571040301, 0.02031990379515675, 0.031426284544830846, 0.03599097156116078, 0.04072415387077678, 0.052943666120089834, 0.011045736271978147, 0.03603709388464209, 0.052449447478378014, 0.015590205270376419, 0.06175288434831366, 0.016274486495662602, 0.03685570479701123, 0.05014917655517498, 0.021561810844427636, 0.03450287641176293, 0.04411076428368688, 0.0068168820918447556, 0.018308465256385745, 0.046445509163482536, 0.019587177084758878, 0.0510972524963079, 0.04306124681006036, 0.03861287300805411, 0.12088548752569384, 0.0792270664486193, 0.030057095817380378, 0.14202813527757122, 0.09418294134159243, 0.09610186135696788, 0.15883693171124305, 0.1218013379782919, 0.10220295494242061, 0.14336302816387148, 0.11590223879583421, 0.11971443786375946, 0.1336051058024168, 0.14801252302863907, 0.15013930568050954, 0.11776886564949829, 0.13207985538869135, 0.12673194880687422, 0.14398395774825928, 0.1275281899518544, 0.15782139023705838, 0.17833727081456494, 0.10897381621743403, 0.13938387555460777, 0.1924261027165959, 0.15333522531774738, 0.1142807447561814, 0.1750366882451119, 0.16225817312877025, 0.11560894203402343, 0.21570229001583593, 0.16409797924420527, 0.16598584971600966, 0.2416894173309688, 0.16946917489892052, 0.13708392638833294, 0.14181721595025834, 0.18331711811404075, 0.23811730255763378, 0.16966549259039665, 0.16072507797470018, 0.1354754022172382, 0.1300092576251876, 0.33149675556248237, 0.5700463308922706, 0.18097742430625424, 13.793980594604248, 53.76474380493165, 102.23542536458662, 115.94295594000049, 96.90104899867889, 95.18916976067328, 86.78356186036142, 35.77551472571589, 41.741863373787176, 75.85048060263358, 58.796254357984, 113.01352593206592, 83.5250057712678, 36.18628101964151, 10.864613344592433, 0.3291477461255366, 0.5620540726569392, 0.27732168354334374, 0.5471214868368641, 0.20241935196663105, 0.6672579242337136, 0.4126253441697167, 0.3551245925407256, 0.539143692341543, 1.2686385382567684, 1.190109010184965, 2.3569809188765865, 4.8187347189072645, 4.199511120396276, 9.046400612400426, 9.964640217442668, 9.758884445313486, 11.8275365906377, 9.570680299112874, 14.1318251240638, 20.028659566756218, 24.97839850764121, 16.944062555989913, 22.9181049331542, 18.774595452893166, 18.855513949548047, 23.19099795433783, 25.0641042570914, 26.78414006387034, 26.34240273506411, 24.633516265499978, 17.84012802185551, 14.701789636765758, 15.681925223719691, 23.75712344723363, 22.741774782057732, 18.787027405154323, 17.292547495134418, 10.08225444824465, 10.939322729264537, 8.582144956434927, 6.01244189085499, 3.987818350715022, 3.6523488163948064, 1.149922244010433, 0.8455693625634717, 0.14663725730872926, 0.4928535649613027, 0.18014744464908877, 0.39348420837233145, 0.2820407545133945, 0.3254726691351783, 0.23391575462395148, 0.4426226812985636, 0.7925325439822289, 27.069606242641328, 89.09313970996489, 110.44296141593688, 72.68388840460008, 33.95055355564241, 30.81376156499309, 48.3323670202686, 85.14338354910575, 99.20242124988188, 93.42878649311682, 82.88834233437815, 105.46226516846689, 101.76806711381482, 31.79873931792475, 0.17818720951195688, 0.20238673194281517, 0.12844417830027882, 0.19700467316133363, 0.13293055006332938, 0.18683448824430668, 0.2004552097810853, 0.1362398660351192, 0.1799738644472053, 0.20301071055714162, 0.18028233741079608, 0.25598896937745236, 0.1368114902007003, 0.16744213689479137, 0.15693377012447005, 0.15633245239094382, 0.15492298850609412, 0.0821752485729033, 0.16176447542684694, 0.16750443516479385, 0.17684105513316972, 0.13888015742263488, 0.19285935608129348, 0.1361330733784745, 0.09522043123480775, 0.13130002384704928, 0.18837006552325142, 0.20359764115944987, 0.09066308908645185, 0.13349848168511547, 0.2921763428997609, 0.1639772131438217, 0.10325326914748839, 0.11803126608532284, 0.1205734062879797, 0.1252311519196918, 0.18490046863594364, 0.38562816056993704, 0.21882420555958826, 0.12104160092290371, 0.0739314453676343, 0.16234072676349073, 0.14895174682380694, 0.1331873274137897, 0.16141918427761526, 0.12439794703236512, 0.14602749728627745, 0.09883487236595924, 0.10521149713425867], [0.02860331566133086, 0.02298132771806371, 0.11018518508682329, 0.062470206945774064, 0.052824474330390656, 0.029966002217523997, 0.06997670798051743, 0.0458631252930049, 0.06067473433851715, 0.041615776792769475, 0.030564655880293543, 0.03270042474351583, 0.049050051058011676, 0.02619700284764892, 0.0256318578706874, 0.08332126248147219, 0.15329371867400987, 0.031654854537919164, 0.06191127302665865, 0.03103090082145026, 0.04498650620300924, 0.09548642462299717, 0.03581192532193757, 0.08969710584008887, 0.06943822477854068, 0.11173851262297362, 0.06530433773033081, 0.035140108347179434, 0.041376669260282675, 0.05260926491070179, 0.021469805599941362, 0.047297421917920156, 0.08575150022102941, 0.0476851926425532, 0.04053584562854902, 0.04492962800507103, 0.13293894638697948, 0.024662162928331285, 0.10622954371595576, 0.0607099092655605, 0.05549537093048135, 2.671683954615747, 30.83850387604006, 77.63472757031842, 91.906765660932, 80.31486741958126, 64.35375082877376, 63.34189307305121, 57.36008636413082, 31.777160398421753, 73.2306432723999, 62.47113081716723, 39.53368663787842, 41.004736269674, 25.809495795157652, 6.68414140901258, 0.10567137971520425, 0.28151276671598036, 0.026834939583955754, 0.023901184810505762, 0.06786009131540215, 0.038311857910406207, 0.040537201604175, 0.08665746047852502, 0.15058541400057657, 0.8850588048658065, 1.792004680441272, 2.8706290212369736, 3.7999750625702644, 3.504264388353594, 1.711437971361222, 3.866814211491616, 5.351560759928919, 3.158940879567977, 20.42620551201605, 12.124524731789867, 7.543072815864318, 7.115888951286194, 12.596755546908225, 8.542048527348427, 10.644138878391637, 4.98853559455564, 10.783897830593972, 9.707436676948301, 14.402715775274462, 13.889097090690369, 13.416639758694558, 9.109002620943132, 9.482899615841529, 10.017970723490562, 4.771147053087912, 9.171799767401911, 10.581236808530747, 10.358770758874956, 9.706507075217463, 6.048149678014941, 3.3937065014916086, 5.246982036098357, 3.332556505357066, 4.419792900162359, 1.8312054608137378, 2.2072400248819783, 2.5617690913138853, 0.4594843990860447, 0.6367336718305465, 0.2336983082275237, 0.05387275457201947, 0.16839859766825555, 0.05655696578023415, 0.26363117139666314, 0.05030773760330293, 0.09264863576860198, 0.04818544805710835, 0.31982987998954715, 8.986485427425755, 43.811905999337476, 83.86283166946905, 87.5550450048139, 52.90779221442438, 19.53317596066383, 19.544717534895867, 42.589001194123306, 62.29711094210225, 84.2470121383667, 72.99660328895816, 70.3295406218498, 72.97592455340971, 24.26496644173899, 0.5270774398119219, 0.08355825178084836, 0.14233248668812937, 0.02588382610420306, 0.06284165999761994, 0.0184776576896829, 0.05360121853769787, 0.029733718613222725, 0.036630589860461416, 0.059428067968016675, 0.05513252870690438, 0.053105961846848654, 0.08379560114154894, 0.04024595412756166, 0.0458140688527736, 0.040804248363260305, 0.023432517116288507, 0.03230821070892196, 0.048834355172490886, 0.014650724835753923, 0.03377197490584466, 0.07535123611770331, 0.05709032385399746, 0.0862772663634631, 0.03290239616387314, 0.10760972005946022, 0.06487418702172656, 0.03509715762770465, 0.025423300009401097, 0.032086430170062574, 0.10123687976550672, 0.03786845388071191, 0.08736942429095508, 0.03749261114505991, 0.025578530490278237, 0.025253241896749507, 0.04626705281196102, 0.047316784790206345, 0.05143672903819431, 0.03293454887405519, 0.05378693740274157, 0.08615633938461544, 0.03979149544912, 0.02054740318037089, 0.025136524571045756, 0.011886440202473633, 0.05221151206041536, 0.04218195790364858, 0.008324556533367404, 0.052041892533100424, 0.0878596516145814, 0.08143753654533818, 0.028447311431650194, 0.026085575359062325, 0.056869613923012256, 0.013527735699749282, 0.01679581698901471, 0.060238684752895955, 0.030412118198470246, 0.0426485437539316, 0.0722912128173536, 0.045565856365306724, 0.029906207139814095, 0.01597224278450613, 0.07312202751035653, 0.027601125184446577, 0.10454163751414708, 0.07559269937055726, 0.028823703835387866, 0.15657407652226188, 0.012720783687977782, 0.03142870729789138, 0.03291987829030522, 0.022606699231771693, 0.038641593644335386, 0.017291634839268464, 0.04311817097327402, 0.08862393157136056, 0.01824985953017829, 0.012444891486196749, 0.07781112145993017, 0.028189279612213857, 0.03704715783016817, 0.07585899153303716, 0.08642494513262665, 0.10434862932250386, 0.09378490503877403, 0.08053159160960106, 0.14950732910825362, 5.9104882132622505, 48.61221244258266, 94.70363524652298, 107.20689619741133, 85.37400322575724, 78.03375028794812, 92.98771596723988, 74.10383347542056, 39.91473705537858, 49.792908622372536, 50.62578078239195, 40.878020178887155, 41.81313676218833, 32.42261190568247, 9.916394083730637, 0.2952150459731779, 0.3271359685928591, 0.07399481616073078, 0.07003663137795464, 0.22777183672353146, 0.47198906841297306, 0.29788241090793766, 0.735846205103782, 1.5979781434420617, 4.606542337325312, 6.573997332203773, 11.517041767797163, 7.686606068764964, 7.582373003805838, 9.831605188308224, 8.029626165666889, 7.252438424095032, 7.362602603050971, 12.861429241395767, 8.655996322631836, 9.275954384957592, 6.505164638642342, 14.407233365120428, 12.073886932865268, 13.029156654111802, 11.998202839205343, 16.530670235233924, 15.088235274437936, 11.421486946844286, 15.838645485139663, 15.131611785581036, 14.685114660570699, 9.103047482429012, 8.52891545141897, 6.472870784421121, 4.763939697896281, 8.790640504129472, 7.043815889666158, 4.661361873149872, 4.634630430129267, 4.138780082425764, 5.404785852278433, 7.355984093681459, 4.80296237814811, 3.2641265901827046, 5.6480321288108835, 5.962983744759714, 3.4637117385864262, 3.313099588117292, 1.2721347183950487, 0.6944598678138949, 0.22677658125758174, 0.23129118336064203, 0.5266074295486174, 0.04868971011150749, 0.19805671106423103, 0.05122870935367481, 0.0839992656162189, 9.235712828174714, 42.184357720036665, 59.39786749501383, 50.712006245889974, 49.284824402101584, 32.20971741983968, 33.95842575257824, 68.11710419193392, 86.18852261574038, 102.2800148687055, 84.01773391231414, 78.45982951502647, 92.45055521688154, 49.478385525365034, 1.1371110475832418, 0.1521348421491923, 0.024178217525684068, 0.05759322993277062, 0.0827722302487781, 0.05362024050085776, 0.019868528620610316, 0.058811286749738845, 0.030035610881543932, 0.07632800588204015, 0.07265076852373539, 0.02802204644878305, 0.02082879110539873, 0.004520523005105075, 0.016755294768259894, 0.028737553417862906, 0.04957706209332232, 0.02877506874351492, 0.01529339886826253, 0.019456896172355742, 0.04652502909002285, 0.06312129741174079, 0.0480713430912264, 0.010541770119039763, 0.05398509370523596, 0.15270162463909195, 0.06296992992922183, 0.046626367200646675, 0.041352633251658374, 0.04075139595736419, 0.01420421240430686, 0.03404943279982094, 0.06892689939347968, 0.0799913540662777, 0.03575886607230191, 0.04354243046574054, 0.07024450933620816, 0.05847513885988344, 0.07103068408586326, 0.02982713920514911, 0.06339511255763712, 0.028658500804956404, 0.02732223279083208, 0.01164840615069073, 0.0521284030119498, 0.016715469687516173, 0.017884740110246405, 0.03462776406517914, 0.0799266732628307, 0.07560216821730137, 0.20257584840780307, 0.24399189458739376, 0.16311590049055316, 0.11153923017123055, 0.20506014897217675, 0.24495005607604983, 0.13207812402998248, 0.19872883064371927, 0.11531539246319764, 0.10550325405934166, 0.1903106122007293, 0.16818564054706406, 0.16673802548358518, 0.2654997824180511, 0.26914093703512226, 0.23532990696689776, 0.20598227368487468, 0.1369054125802171, 0.10241434924424657, 0.2944862512090514, 0.10041577906738366, 0.17340133567490887, 0.11947407777751647, 0.12936388983601524, 0.13917009105845807, 0.10200872101009854, 0.1628348841181686, 0.2672127856602592, 0.23320186793083147, 0.13043668872166064, 0.188636158502871, 0.09992506910836506, 0.1712544355541468, 0.16186676348649687, 0.2645487302253323, 0.2917489577685633, 0.27632040662630913, 0.22409812336967838, 0.2928824001742948, 5.224843198253263, 53.863069780411266, 109.04154562181043, 121.5683957069151, 96.8262964679349, 80.3569152278285, 84.44422106589042, 75.0040880326302, 44.79485980926022, 90.44870299677696, 84.31081341158959, 58.169942055979085, 60.58674966135333, 39.90930457268992, 11.881725115160789, 0.33798502998486646, 0.8160803094506265, 0.13646904889854694, 0.4629414168096358, 0.2628348383211321, 0.23019952339030084, 0.16484145225296098, 0.19658352398583967, 0.9637636138546852, 4.172341352508915, 6.883422328579811, 12.700080583172461, 11.572078504870015, 14.385084721349902, 9.350285260908066, 11.368105449984151, 14.3941669694839, 13.586170481097314, 41.737352648089015, 24.99107364685305, 20.941642215175015, 20.025537360099054, 32.51670956611633, 24.051928789384906, 26.43224266267592, 23.360836582799113, 27.90600069107548, 29.451871495093073, 34.44587046100248, 32.282606824751824, 31.964690877545266, 21.118674470532326, 22.876168912456883, 21.39509174131578, 22.04671117567247, 27.57205205578958, 22.641003208775675, 28.70593866994304, 26.68637498732536, 20.34704815956854, 14.072185485593735, 14.421395082627575, 13.06723992670736, 12.398532686694978, 8.744833104072079, 10.267177531796118, 5.831126897565781, 3.8673731492411707, 4.2194426444269, 1.0030532604263676, 0.3990070587925373, 0.19593547488893234, 0.2180209470492217, 0.49054417759180075, 0.09390661342730446, 0.4612692000885164, 0.20102661944204764, 0.6312429051726096, 13.765843472173138, 62.74677538102674, 108.58604077369937, 110.65408691283196, 70.22002804663875, 26.51766992384388, 31.139520291359197, 58.523849671886815, 81.65950298309326, 106.00188916729343, 92.65278477822581, 91.56701780134632, 105.00030409905219, 51.75296406592093, 0.7406826101003156, 0.27851282769153196, 0.21994548248908213, 0.18033948756994742, 0.18400491185245976, 0.2241121581004512, 0.14214865622981904, 0.18536071893909287, 0.1305387469549333, 0.16185372467002562, 0.27847014127239106, 0.106102840434159, 0.3178572035845249, 0.11268374254746784, 0.12479396852394267, 0.3557941227430298, 0.13690064751332806, 0.2178341901350406, 0.23825490727059304, 0.1056316197519341, 0.10196846308967761, 0.21550751982196686, 0.1071765126600381, 0.13143021282890152, 0.14465347262880496, 0.19080130683798946, 0.186408267566754, 0.1374679969082917, 0.1740626840581817, 0.17957957431433663, 0.2073729684155795, 0.14097053557634354, 0.15590335122279583, 0.181261980004849, 0.12827843517786072, 0.14005432506242108, 0.14956552114698196, 0.1039636854623114, 0.15562895385007705, 0.17734031463342328, 0.19605129206132507, 0.16595634000916637, 0.20530122152018934, 0.25354962285247545, 0.14279308939172378, 0.08656258048910288, 0.1770081235876968, 0.13332007512930902], [0.03553181293330366, 0.08262298099936978, 0.07317733905848957, 0.0483229608395167, 0.0174875809781013, 0.03180835749052706, 0.04310877490488272, 0.037408659399877635, 0.023441876795503403, 0.01767129269278338, 0.07312442536555952, 0.028325377047182094, 0.0431036344549108, 0.03205161147390402, 0.0398560153741029, 0.049873894350903655, 0.014683758547048897, 0.026431322330608967, 0.019525095234595, 0.04808573022244438, 0.07889856794668783, 0.039165927202350674, 0.06475031826524966, 0.0411594373684737, 0.02589573111054638, 0.029965916032632513, 0.04262637699984255, 0.08953355372913423, 0.048699948876615495, 0.004607815372442166, 0.02512457551464679, 0.05068021338252772, 0.07012185865953084, 0.05137536539545944, 0.025020739957389813, 0.0959110594985466, 0.11249200606177892, 0.07934161191505772, 0.12177665462537159, 0.92677682758339, 21.841645740693618, 70.65009240181216, 82.91369653517201, 88.93461319708055, 71.70571204154723, 52.04260756892543, 33.93380503500662, 24.41348502712865, 21.312619986072665, 42.74456239515736, 77.25833692858296, 48.13005116678054, 26.414184070402577, 10.304872489744618, 0.7909928911155271, 0.08401785857014119, 0.05649045402664812, 0.11658064795718079, 0.0976285903203872, 0.034105732601376317, 0.13279579519744844, 0.13397463597357273, 0.6645408861579434, 2.961332605731103, 0.9216347841485855, 5.381056003032192, 11.493325156550254, 8.865253790732353, 10.524082972157387, 7.273899182196587, 9.455194934721916, 11.08588699371584, 6.125316917896272, 2.02340699251621, 5.710584127133893, 4.833186691807163, 10.287679760686814, 3.280791270156061, 13.78571714124372, 6.682785739821773, 12.901462912559511, 7.524339575921336, 8.990505856852378, 17.127352952957153, 11.005425453186037, 10.964095438680342, 16.550031054404474, 15.744614504998731, 8.33785483914037, 6.853361283579181, 7.052433827231008, 5.787085544678473, 10.503214001655579, 7.109543536939929, 11.341239175488873, 15.299277420966858, 8.923904991918995, 5.346457266038464, 6.012339418934238, 1.72451478579352, 3.396857390480657, 5.058307205477069, 5.08555002750889, 1.8039372659498647, 1.2911355375282227, 0.7680495996629039, 0.16985673877981403, 0.12947750067518604, 0.05769807672608764, 0.20668522064243594, 0.06932116654371062, 0.07998974528163671, 0.03628904488117945, 0.07157852888227471, 0.07781440797712534, 3.8914275746191707, 32.63803632028642, 70.43541323754096, 84.92566847032117, 67.5391507917835, 34.4144130522205, 14.82245154919163, 15.444995434053483, 25.626264233742994, 65.07475306910854, 83.18457541927215, 68.44861507415771, 76.50305317294213, 44.09522664162421, 2.272360440223448, 0.70422203430245, 0.0571428774856031, 0.05932140171587948, 0.041651698655538985, 0.062022168084137866, 0.04749803353221186, 0.07084838580340147, 0.010160802255174326, 0.01881255494100192, 0.03011932513946968, 0.054556894071039655, 0.046917055433075276, 0.07669705341780379, 0.05116918049151859, 0.04486861293234172, 0.01706191379907391, 0.061897820522708286, 0.010835053474311868, 0.021003231240977204, 0.056257954002508236, 0.03534241684622342, 0.006525958287379435, 0.041342019103467464, 0.07997394854863805, 0.05841524993640281, 0.04452787234538025, 0.04109246213169348, 0.03938342722493314, 0.047227868795274734, 0.08109903293511561, 0.04142011793690824, 0.027374035656271924, 0.05840396163083854, 0.03288323630488688, 0.051572533444531506, 0.02105568911159231, 0.09031562224751519, 0.0578435912968651, 0.06423889711919813, 0.03750530905240486, 0.027350516756996516, 0.07027535969691892, 0.01637148088775575, 0.018281972020744316, 0.00884112100222058, 0.06541466971318569, 0.011817466433820947, 0.03770413951227262, 0.08990962629116352, 0.03919831356934963, 0.026190429813258594, 0.0759127249400462, 0.01578149934028906, 0.01895660245340438, 0.027576922551698746, 0.06643873008508837, 0.04236375056808034, 0.05269027104781521, 0.055200135966222134, 0.0496214798711721, 0.033055383922351946, 0.04264234227218455, 0.0383784692554224, 0.02415064602128921, 0.010925121473959618, 0.05311130147968089, 0.08493032291411393, 0.06191658584641353, 0.03349830914709357, 0.07773095801953347, 0.06357760619251959, 0.04504787750662335, 0.09770522975633222, 0.031265467367765885, 0.08969002718766851, 0.03607942024245858, 0.055667694748168996, 0.01490674471677912, 0.004571085286912539, 0.06739794877507994, 0.009121018886235694, 0.06431153374573877, 0.08570647723371945, 0.050776640869556904, 0.20528819802547657, 2.4920234660948477, 32.327616022479155, 85.26471030327582, 97.46487402146863, 99.44401571827551, 89.98520435825472, 86.93734230533724, 53.120012052597545, 39.26916199345743, 37.88999780531853, 40.79458744295182, 71.72663396404636, 56.679578673455026, 30.13123581486364, 15.470843853489047, 0.8504219473369661, 0.06955355931554111, 0.08755921491331632, 0.2371607498536187, 0.14751424412092856, 0.15356834587310592, 0.5190001764605122, 0.9781105407784063, 3.5329376497576317, 6.930823681815979, 8.467752952729503, 9.747793943651262, 12.187765106078118, 10.889406646451643, 7.986703178574962, 10.444179388784594, 10.96636551041757, 11.585839160027044, 6.318133281123254, 5.266386491637077, 4.440399562158893, 5.496345739210806, 5.298811254962798, 9.001780709912701, 8.278937897374554, 12.12885110608993, 14.844795330878227, 13.057734062594752, 8.076047906952521, 9.41247542058268, 12.258793346343502, 8.23593597258291, 7.851054380016943, 3.861399134320598, 1.8209108325742909, 3.261249286513175, 3.612691692767605, 5.935215815421074, 7.9317841126072794, 10.905473655269994, 13.081056475639345, 12.911255109694697, 8.951255679130554, 7.378747078680224, 5.4708091482039425, 3.7714121178273237, 2.0568781706594654, 7.311858409835446, 9.141780887880634, 6.258783407749669, 6.685829008779218, 3.871481586848536, 1.9448556462603233, 1.8246780239766645, 0.5615369939515668, 0.2101877593104878, 0.4078124427507001, 0.20362707425750073, 0.08468766456409808, 0.08028939291233979, 0.21976151413494543, 2.9279284756029806, 32.94430086689611, 61.374742061861106, 52.358072034774295, 37.48599759994015, 34.85452651977539, 31.21195274014627, 25.942868148126912, 40.08942373337285, 87.78600985004057, 92.13157238498812, 79.03307607097011, 90.4527195038334, 69.95473461766397, 9.568351391823063, 0.5039003383248083, 0.05011262650030756, 0.10964098686893141, 0.055090244483923724, 0.01744898355325624, 0.03018306940042925, 0.06010558846737108, 0.0198944051554727, 0.012844833432726804, 0.010536689040881973, 0.06181185779672477, 0.0332558078451022, 0.06941804602261513, 0.024837300203920856, 0.07821927778422832, 0.03186181893632297, 0.045724877066189246, 0.04283304453917569, 0.06513986631386703, 0.06550597207200143, 0.044146919803273295, 0.039578312331990856, 0.03152121432996806, 0.08045523562618802, 0.021377660544408907, 0.02814898147217689, 0.002159240600209864, 0.06260260226084821, 0.03481500744519215, 0.07160023215316957, 0.11709008876594806, 0.032833804481572686, 0.054839806511036815, 0.04082035153142868, 0.02518239408551205, 0.06162751022906554, 0.011810637717585892, 0.07114585008352034, 0.06396964019645127, 0.07083230561787082, 0.013270120440621772, 0.06561096442202408, 0.010409492589983969, 0.03346095086946603, 0.02532839512212142, 0.09607605951567812, 0.0779382843944815, 0.12700784771192458, 0.20545034819552976, 0.19615960157205983, 0.08780328286511284, 0.19720236981107345, 0.1329412599725108, 0.06691187364800323, 0.09669294415582573, 0.11611158764290234, 0.19703442801631268, 0.1489088918653227, 0.16401853592645738, 0.11052355846209873, 0.1883211278266484, 0.10037108549788114, 0.09274120217249279, 0.07077501756289313, 0.16607227975562697, 0.21096464907450063, 0.1668014882072326, 0.21684536980765484, 0.12559375665601225, 0.16889119220356788, 0.10480822845091743, 0.24072140395160646, 0.15517185982917586, 0.12644252078908105, 0.1771339765118976, 0.060742954468174334, 0.16855592148438578, 0.15863388776779175, 0.16483791292675082, 0.17730879777621839, 0.15828905627131462, 0.21432696300889217, 0.3278119339337272, 0.2307260709424173, 0.37296019194106905, 2.9697272133442665, 39.73066414556196, 103.30578527142926, 106.8507371410247, 108.37529966908117, 86.13022050549908, 74.49632936908354, 49.675029631583925, 35.42595309595908, 37.80182292384487, 62.32825456127044, 93.67810018600957, 67.60208914356848, 40.96818370203818, 17.45572593904311, 1.1747349125723685, 0.2576963801778132, 0.23848496347425446, 0.5296222000352798, 0.3224386545198579, 0.1870557037933219, 0.326095866339822, 0.4939619103266347, 2.3122855107630453, 7.357257883394919, 10.576361302406559, 17.79713688358184, 29.435462259477188, 23.31959286043721, 23.29610178547521, 23.27220278401529, 27.880826919309555, 29.854800893414406, 18.129161596298218, 9.167562627023267, 13.904250187258567, 14.221286542953985, 27.92550075438715, 15.463136396100445, 28.980100577877415, 22.597623755854947, 27.645975005242136, 21.618307944267027, 26.10723310901273, 33.34909731341947, 31.87989315678997, 26.560421797537035, 40.887794725356564, 40.38397412146292, 21.82409901772776, 24.659919700314923, 16.90923975360009, 14.697606428976982, 18.839191006075954, 16.427090244908488, 19.91691908528728, 28.074872455289288, 16.591339495874223, 13.718303365092124, 14.790746050496256, 11.888809896284535, 13.297296743239126, 13.657179109511839, 17.68310573793227, 8.107624457728479, 6.478424860585121, 4.271015438341325, 2.7857437825972036, 1.6026857230932483, 0.3209147524208792, 0.3993505113307507, 0.456474194483411, 0.23481788444182566, 0.21339207527137574, 0.22201968086583002, 0.3358529766480769, 5.0383987253712075, 49.25431228453114, 99.69736945244574, 113.50648157058225, 87.6543672623173, 49.777736894546024, 22.375066511092648, 24.930704447530932, 39.30853474524714, 86.12091664345034, 103.06016645123883, 88.17821548831078, 103.30886825438469, 73.95889405281314, 7.651493010982391, 0.7947494798610288, 0.22070608522382476, 0.17730236263765445, 0.18533720003981746, 0.16384066563219796, 0.19709144027963763, 0.13861784891736123, 0.12309604955296363, 0.14700769146363582, 0.13980787457718005, 0.14117218523977265, 0.07856826147725506, 0.16343499143277446, 0.17518072809663512, 0.13767306332386312, 0.10310442592467993, 0.11657208309418733, 0.15899235562932107, 0.1282431185245514, 0.1417166286058003, 0.10775871649985352, 0.11383864307595838, 0.11080651303693173, 0.14206527522014034, 0.15321004655091994, 0.16518141143023968, 0.09652924648816548, 0.2357080479663226, 0.08734509333847992, 0.1755001714393016, 0.2759570664455814, 0.22557707142926034, 0.10390934684584219, 0.17074083488795067, 0.10971222538501026, 0.22499561069473145, 0.11622664638825002, 0.18513780267488572, 0.129092664067303, 0.20699868849929304, 0.10970266460771523, 0.17989769998577335, 0.13953664880846778, 0.16270038972218193, 0.12388522736728193, 0.20221788616430378], [0.07635159372922874, 0.07481114413108557, 0.04234242651070799, 0.037989813699236805, 0.053111447036386504, 0.0330874830063793, 0.11642051259836844, 0.06971922582916676, 0.02256503170957008, 0.06576761408078094, 0.006293530562787407, 0.025589113994952173, 0.09128145993717256, 0.0569862776225613, 0.026297843001121958, 0.01907550312969233, 0.09339968538692883, 0.026206645979395798, 0.022369098977275917, 0.0634118439179034, 0.014329632488830436, 0.014339605995994664, 0.028504542030033567, 0.013087571264364788, 0.007939861651750342, 0.0707062152064135, 0.11505462379465181, 0.02607377185936897, 0.13864081623333116, 0.06609313250068696, 0.04972745281373782, 0.04694155875533339, 0.05101713119074703, 0.05146713889834862, 0.0947519991126272, 0.03772939360069652, 0.061959712766110904, 0.135941444145095, 2.41785561365466, 39.566226620827955, 20.518726379640643, 67.23438262939453, 91.5142305435673, 57.54828560736872, 47.30275661714616, 21.889659473972937, 24.349923018486272, 49.85697661676715, 44.786873863589385, 48.478334103861165, 25.604863782082838, 16.274103099300017, 5.0724110680241745, 0.06270238521298574, 0.003624108921353435, 0.12325669819068526, 0.05787043501773189, 0.04613949917256833, 0.1376411174574206, 0.16698691212842542, 0.5434815273169549, 3.1041007513000123, 2.6500403160049073, 10.170926490137655, 5.296120018728319, 5.184579087841896, 6.621202076635053, 7.819353784284285, 5.030492207696361, 3.301289086380313, 11.556564550245962, 7.334511078173115, 6.786570673988712, 7.349281253353243, 9.377683016561694, 7.441642284393311, 5.790263645110592, 4.340187907218933, 8.929570855632905, 7.971871226064621, 9.803990721702576, 8.584552311128187, 9.910096718418984, 6.999002810447448, 5.223008509605162, 5.0007552485312186, 7.231695950031281, 11.010905984909305, 6.765064808630175, 8.652445597033347, 11.103576883192986, 21.773700483383674, 29.87179260100088, 36.543393211980025, 41.62450605823148, 37.24302637961603, 36.116753085967034, 26.54338694387867, 22.116656841770297, 11.766560404531418, 5.280749720911826, 5.783875574988704, 8.578848204305096, 4.861078175806231, 4.253070594802979, 2.7936069090520186, 2.0936572551727295, 1.7285833868288225, 0.24083438659867934, 0.8860471195751621, 0.3337151929736138, 0.015893475539351425, 0.03278519620277709, 0.09698699934468155, 0.08123256972119694, 0.23596117873826336, 0.5681694767648174, 13.96605105169358, 62.96572992878576, 80.23106205847957, 62.00565530407814, 45.30253218066308, 93.37651698820054, 107.15100242245583, 29.436807632446293, 73.2326279917071, 71.73382759094238, 72.51708569065218, 81.68516312876056, 62.73534951671478, 13.678076517197395, 0.15610927565684243, 0.2549216097160693, 0.07878318744441194, 0.04224676128116347, 0.07829865981494227, 0.015048773587501098, 0.03913621448220746, 0.04487743826522943, 0.03702474975838296, 0.02712765028850446, 0.04522950929259101, 0.03913747852728252, 0.0192841088714739, 0.04189583938568831, 0.08040083572268486, 0.0463114514376127, 0.0749453244310233, 0.02223321796214629, 0.053178613795147794, 0.03695853294864778, 0.015301300107591577, 0.07268607751616547, 0.03082550881851104, 0.018928236132788084, 0.03279748425308255, 0.020700630341326038, 0.035298960508718606, 0.03456339735778109, 0.052188651996754834, 0.038320752191207105, 0.01632509617916038, 0.04351202060558623, 0.03917923414959543, 0.04474157640229791, 0.05512326670389983, 0.005464671309211202, 0.03718674288041169, 0.03692047370056953, 0.07234644009581498, 0.07908665019297793, 0.036559596492518345, 0.045308956440778515, 0.08833814247120773, 0.026821686262865702, 0.01927787291577026, 0.05146690907197134, 0.05684704497276295, 0.020785405631026915, 0.061039599034214215, 0.06336456480165643, 0.03739637901045142, 0.04247468392995577, 0.08046923971344387, 0.007198927266853712, 0.036702839612600305, 0.024461539822720715, 0.04186434934156076, 0.04281971843973283, 0.06636087256934374, 0.018464693566784263, 0.031081725009566838, 0.043716198359165466, 0.10055916774417124, 0.026362782359243404, 0.019861509340004097, 0.04379416312721949, 0.04162988813233472, 0.0669557704860645, 0.07505123608655508, 0.053294457780617865, 0.03741854193410085, 0.05542589824706797, 0.009793200710367773, 0.039094822751658584, 0.122340242528627, 0.06600120961065255, 0.06076040212064982, 0.08140510038262413, 0.04118072695188946, 0.011287219634640121, 0.023841837894231565, 0.025284818125768535, 0.08073572339790483, 7.281923861272874, 59.30425228611116, 27.573564129491007, 74.83506525716474, 105.34003626915717, 79.58249815048711, 69.2044871853244, 35.41256996893114, 34.75988757225775, 31.052661365078343, 37.75473879229638, 44.168810306056855, 34.486168892152854, 21.284341658315352, 6.976387894922688, 0.06666252735040842, 0.1835608872915468, 0.0727304493287398, 0.03299754045362915, 0.259277738871113, 0.8719042784744694, 1.963441429599639, 2.2380960852869096, 6.478373869772881, 7.161716943786991, 12.477381152491416, 9.987933212710965, 8.094339389954845, 6.622174824437788, 8.75903110350332, 5.477398239797162, 2.217408279257436, 5.052140258973645, 4.8996674341540185, 5.300062000751495, 6.171348383349757, 7.287315649370994, 7.04795987375321, 5.772994920130699, 9.28888742000826, 9.696838432742704, 7.585088754853896, 11.990094319466623, 11.023992972989237, 8.682759634910092, 7.8827108490851625, 1.411683946367233, 1.4371457671926868, 0.9409273295633255, 4.438692350541392, 5.014844402190178, 6.717242781193026, 12.4891217870097, 24.382951336522257, 33.24287560678298, 38.90409915677963, 43.21145388387865, 41.04194387312859, 39.3408158517653, 32.562120806786325, 24.864481110726636, 14.188774016595657, 7.048636482607934, 4.849106611744051, 6.432042343001212, 4.325910970087975, 6.600786139888148, 6.865634870144629, 5.408572410383533, 4.211296862171543, 2.045087648495551, 2.1424201611549627, 1.1795441061258316, 0.438840382642323, 0.06763899067957556, 0.12032971371926608, 0.14066367139739377, 0.0700798617195218, 0.7741206932452418, 15.26902614101287, 57.281046682788485, 59.464724294600956, 47.30580037639987, 27.21504576744572, 65.17077661329701, 97.73017529518374, 44.96300397380706, 89.35445585558492, 87.3401540325534, 84.06385314080023, 92.50216576360887, 88.07160546702724, 30.721717265344438, 0.6782832164918223, 0.3204898187710393, 0.14022992773642465, 0.18327142863023668, 0.03152426719034632, 0.10966684233637587, 0.09828606229876319, 0.02119149543314932, 0.0037509546476236035, 0.022192814485019734, 0.06627573721831845, 0.02575154187187793, 0.027818291958781983, 0.05588802163519206, 0.018240704779483138, 0.025950563853726755, 0.04045579327090133, 0.02030409365561941, 0.04677989888155172, 0.08513537400792684, 0.01993163319815311, 0.08226019240194753, 0.043737346216315226, 0.007162669761812375, 0.050303497306642034, 0.1106173352849099, 0.00877454508877089, 0.016395174072033936, 0.07067357219995991, 0.07189193545209785, 0.01839415985159576, 0.020786550932473714, 0.009882799481161901, 0.058783730567102475, 0.0036479402408604662, 0.11350436827107785, 0.04972251537706583, 0.055250904612964204, 0.0338982645001623, 0.06748616379956085, 0.028055103142715754, 0.046475267848901214, 0.06242173273236521, 0.0026565963719716117, 0.07705709175957788, 0.1565579733540935, 0.16545819899728223, 0.10083729596508127, 0.17404645831594545, 0.17354336837607046, 0.14279872779884648, 0.17369989546075945, 0.19902941290168993, 0.17318618754225393, 0.12325616959001749, 0.11660126338322317, 0.14440924379854433, 0.1864206169040934, 0.22403927249533517, 0.13470376781638593, 0.11722033903483423, 0.12565815400692726, 0.17250082996343413, 0.07435137646332865, 0.20126059801588136, 0.09020473102047559, 0.1253156973830154, 0.17445435417034935, 0.12453568964115075, 0.20755341276526454, 0.18291027946097238, 0.1758809018159105, 0.10493798076265282, 0.1565991582409028, 0.25414868828750425, 0.1666121572376259, 0.16687458831696741, 0.22379617747520247, 0.25162980651422856, 0.18743372221867885, 0.10551272290608577, 0.24524922873223984, 0.25614111443921445, 9.79795321341484, 71.36347739927231, 42.962912897909845, 82.67349843055972, 111.1809475191178, 76.47631829784763, 61.342441343492084, 27.231556984686083, 37.57396067342451, 68.78764906237203, 63.15669444299514, 68.69383381259057, 45.83806906977008, 28.41090779150686, 9.025748352850638, 0.24818961208145468, 0.36806924148432674, 0.377574707231214, 0.17012735167818685, 0.3914634829326984, 0.8928202561313107, 1.2810367826492557, 1.4079466630374233, 8.671891727755147, 10.650747091539445, 24.57006996677768, 16.333236752017854, 21.643511133809245, 21.561137437820438, 28.556918021171327, 20.00291312894514, 14.039327790660243, 31.448569720791234, 19.600477949265514, 15.682024263566541, 15.247226588187681, 17.416916047373128, 15.975698982515643, 15.147422859745642, 17.561261230899444, 22.00565572707884, 25.143636195890366, 27.094825121664233, 25.93534896450658, 23.734958133389874, 21.748456108954645, 19.188652615393362, 17.060978604901223, 14.92075889341293, 24.023269991720877, 13.072099743350861, 13.7984432712678, 17.406053043180897, 29.56560257942446, 37.98934751941312, 45.38095604988837, 50.92289640057472, 45.16409212543119, 45.1656767629808, 37.816927971378455, 32.00464021775031, 20.077677426799653, 13.624611669971099, 15.611975635251692, 20.59729145419213, 17.88962637224505, 15.548112584698586, 12.426463884692039, 8.096090237940512, 5.304974769392322, 3.227806913275873, 3.5649079084396367, 1.73375221269746, 0.4095285103446053, 0.22466489053781957, 0.19439550026530222, 0.3278070309710118, 0.2795159738631018, 1.5045545178074993, 20.917882457856212, 87.69819582662275, 114.74022388458253, 83.34918945066391, 60.455652283084014, 106.30329193607454, 116.51118186212356, 38.31588483625843, 91.36314868927003, 93.36127465771091, 94.91545108056839, 104.14565101746591, 98.11464601947416, 25.981646660835516, 0.5214012185892751, 0.47343476825664127, 0.25284445423993374, 0.37017800574821813, 0.2166056302526305, 0.14253493308299972, 0.2438021958955834, 0.1528230495750904, 0.1324232926051463, 0.11321160777081406, 0.19227501485616932, 0.13697281299579528, 0.1269986853003502, 0.1597170901274489, 0.11762440444961672, 0.21980769391502106, 0.19471030111514753, 0.15946334648516872, 0.1338635225810351, 0.162242483648081, 0.12841061598831607, 0.2639944809338739, 0.08654973319461269, 0.18895900327592127, 0.18536508564026127, 0.13305362974924426, 0.142446817649949, 0.1128317813779558, 0.1262550897175266, 0.1562191939522182, 0.11112831593040498, 0.10059112893237222, 0.10623879039720183, 0.0898733290453111, 0.19317401903531245, 0.20659779468851708, 0.17638872617915755, 0.2507620280788791, 0.1406638552584956, 0.29524192033756164, 0.10063835059202487, 0.08984223353646456, 0.1621372844543188, 0.10624357844672858, 0.11049129083872804], [0.045496138533757585, 0.07072693022388606, 0.08006241638213396, 0.04065679559003442, 0.04318077950888584, 0.09673088849071534, 0.07607818460993229, 0.10513234492992202, 0.18971272654110388, 0.06217914333026256, 0.03463348674197351, 0.052577269248544216, 0.016145845011417425, 0.003866603998880413, 0.038573538223581935, 0.06000279862013075, 0.06049499862016209, 0.0463247851979348, 0.05561430991116551, 0.03008598307778518, 0.12875196944561698, 0.10507858854027526, 0.021433295764689966, 0.06680008609809222, 0.13790679674956108, 0.09541133268465919, 0.04212655825540424, 0.13643269036566058, 0.05746491403589326, 0.07017830401779183, 0.0569408524390911, 0.06779598507789836, 0.02193159190937877, 0.04003578173597494, 0.036647049259514584, 0.030417658929382602, 0.2064605270542445, 12.357751804013407, 60.083525257725874, 93.29122112643336, 30.221809225697672, 24.529979421246438, 47.32993864244031, 34.20148326504615, 20.077063575867687, 78.13825007407897, 67.24833842246764, 64.3963634583258, 51.59047988153274, 33.71687443025651, 12.54907423450101, 2.3466829811373064, 0.024098211133311835, 0.19531324295507324, 0.03243235142661199, 0.12250775531415017, 0.050052220467478044, 0.5608135005158763, 1.9915962026965235, 0.8462423554831936, 2.3237045109272003, 4.62626499514426, 7.522431342832505, 8.66771734529926, 9.01125519506393, 5.891379896671542, 8.606306756696394, 9.002515173727467, 5.485241999549251, 7.587496599843425, 9.113221130063458, 16.106980712183063, 16.263491126798815, 23.998033462032197, 19.250941814914828, 25.013882229405066, 18.05637417301055, 23.245854262382757, 13.63220832040233, 14.626533081454618, 9.468445681756544, 7.974879193690516, 2.101969002716003, 5.776267647743226, 9.92681287950085, 18.122828929655014, 37.463432204338815, 46.72538765015141, 67.42766918674593, 47.61570292134439, 45.82599993674986, 61.74372334634105, 58.21340976222869, 67.47304316489928, 74.15461247967136, 77.70474187789425, 78.27955738190683, 77.36661003481957, 70.04720057210615, 56.624010455223825, 30.54396721624559, 20.858399714193038, 13.212551974481153, 8.30921761451229, 10.531882605245038, 4.588688688893472, 2.3460404478734542, 3.2734132918619343, 1.597279593829186, 0.6422649492179194, 1.6176058063583991, 0.7071910233747575, 0.06921399850398302, 0.131266254691347, 0.0960488174290907, 0.1382899479640107, 0.11263975377885566, 0.5674254521727562, 6.557117412167211, 26.561698529028124, 63.16011867215557, 93.03648671796246, 107.49355085434453, 104.5357777995448, 33.197764427431174, 22.611181428355557, 41.96367340703165, 71.5986862490254, 74.41910574513098, 73.07259528867661, 81.9417881196545, 32.88324917516401, 1.7375885358741208, 0.22095396063260495, 0.17572411426132725, 0.09301649586808297, 0.05663295021100391, 0.08175285067409277, 0.023597852296886906, 0.0141956647782917, 0.03331788011916703, 0.03995913080871105, 0.05404875561174366, 0.011776245157835225, 0.08003243936165687, 0.07890733965342084, 0.032606188267950094, 0.040418124727664456, 0.059934440594647205, 0.03665858654365425, 0.12498611103623145, 0.03347304739779042, 0.08115762333956458, 0.06976276260590361, 0.04598291463128502, 0.008708416379147, 0.02237981080167717, 0.03149971790281275, 0.03379824789120786, 0.01955756970170525, 0.01752158762106011, 0.02159197555644618, 0.06599660542222761, 0.023442296228641947, 0.03353135434970741, 0.03804266610513291, 0.08793442945687041, 0.04934941906662238, 0.07780830991724808, 0.07569558497878813, 0.11087955185963262, 0.02078547266372029, 0.03125413884258559, 0.03618400656588135, 0.03055030896869158, 0.06636286439794688, 0.045554794055680116, 0.04857692664729492, 0.054065697646189126, 0.035751082618991216, 0.024290453237030777, 0.02949749157133122, 0.09396452967438007, 0.12641620566888204, 0.16712837792452306, 0.04663667491366787, 0.009970962794707909, 0.06922201944455024, 0.016910912123538794, 0.04633038147022167, 0.010026732080375717, 0.0311991605426996, 0.09342556383701102, 0.04856038297857008, 0.10264714038179767, 0.07128700178356902, 0.10660937776969326, 0.11943338318697869, 0.0589668600549621, 0.04837667892476724, 0.15915338731100484, 0.08560525403628427, 0.058769201709618496, 0.07316600861808947, 0.06038789569790806, 0.04417351071512507, 0.01953225815668702, 0.025126797169627204, 0.040302571855605616, 0.050028172967534874, 0.11040027193244427, 0.04317831653620928, 0.12239411383146241, 20.829446738766087, 82.64423754907425, 107.32843475957071, 37.38187436134585, 35.05457132093368, 76.22934233757758, 55.56176985463789, 34.715392205023, 55.71033354728453, 52.40952176432456, 55.996101748558786, 47.240061452311856, 34.207821815244614, 16.685380281940585, 3.104837666596136, 0.06007571869920339, 0.11252071137630171, 0.03129202380566107, 0.18592512655642726, 0.932765735253211, 2.6775721676888007, 6.112909970744965, 4.638608694076538, 4.0215144522728465, 6.583429161579379, 8.096035815054371, 12.77046065176687, 5.7542352041890545, 3.9122215297914322, 1.9965077455966704, 1.4435644808315462, 2.835251693764041, 7.19944033891924, 9.13901169453898, 13.464107301927383, 16.177700065797378, 23.048321739319835, 21.33922934532166, 25.94808490045609, 19.64451243800502, 18.66819920078401, 11.24769554984185, 10.582337033364082, 9.473996816142913, 3.9395121557097283, 2.659722931923405, 2.316798442794431, 8.165104341122413, 19.051497136392904, 36.67490636148761, 47.656456347434755, 65.6586096363683, 49.62654521388393, 53.616760623070505, 67.69088375952937, 62.439563582020426, 75.60927837125718, 82.33804948868291, 87.1941791042205, 83.94722538609659, 83.29404877078149, 75.94064020341443, 57.592879033857784, 35.73215292346093, 19.061552132329634, 11.652601822730034, 6.407668244454169, 1.9794247203296231, 4.593017514674894, 4.114328026771545, 4.168782291873809, 2.751987619746116, 3.584157675504685, 3.9380853935595486, 2.1800374071444235, 0.25541068024693, 0.09934894800666841, 0.13466734799646563, 0.11946452466110069, 0.09639751766958544, 0.32409472210753354, 7.554067709753591, 26.913974438944173, 61.03622974887971, 61.04905197697302, 108.98914275630828, 112.75117428072038, 34.349909674736764, 45.78254791998094, 57.66489767259168, 88.59513205866661, 85.27603810833347, 82.7127613559846, 95.85520390541323, 59.476973856649096, 5.560305868425678, 0.49251783458936604, 0.11246439625298786, 0.06097664192859685, 0.06507304812511129, 0.05121292411199501, 0.034247523984841766, 0.0036812858935821083, 0.019248851589978706, 0.05464700899357277, 0.05361707655773048, 0.03472866550568612, 0.0649357958125972, 0.032681448745631406, 0.07934289894277051, 0.053301961611836195, 0.08442708741753333, 0.007714478584427027, 0.051438900897459644, 0.10915412267129268, 0.07155256616252084, 0.02257131171532937, 0.05047195621075169, 0.046662606989904765, 0.054196882542342915, 0.04163186080873974, 0.0716327219420383, 0.06146963482962982, 0.00878900595595159, 0.08433825186183376, 0.08828161284327508, 0.048697574004050226, 0.03798675700841892, 0.006001828700273989, 0.0775786214357903, 0.0593176287328524, 0.05331693096987663, 0.03203767250412174, 0.04418995862285938, 0.027204525296486197, 0.031361419880282015, 0.059003796984231284, 0.020327466998189207, 0.05145989936746417, 0.13675755761083097, 0.17064400137432162, 0.16260888818050587, 0.1413748614610203, 0.1172083804023362, 0.2524240251870886, 0.13333931925796694, 0.1980882432431944, 0.34497775798363073, 0.10783210006212035, 0.11497439140634191, 0.18686019815504554, 0.10189418320453937, 0.14177747130874666, 0.14237603112574548, 0.07875941573612152, 0.14177440695704954, 0.12449781425417432, 0.15896758034584985, 0.24787565392832606, 0.2331244317634452, 0.22339211206042, 0.1440267360979511, 0.2061395975010049, 0.19083685331767608, 0.144735949654733, 0.13742247596383095, 0.22243784229841926, 0.2355689876863072, 0.30664268760911884, 0.18397747058301203, 0.1937237943732931, 0.1476386567998317, 0.18730865070416083, 0.14867129735648632, 0.15959722801081597, 0.23950209841132167, 26.386974588517223, 99.28792107489802, 121.72785574390043, 46.86307853268039, 43.95786916055987, 65.44524054373464, 43.280699406900716, 28.891015706523774, 97.29767122576314, 86.33159499014579, 83.78998541062879, 67.68990316698628, 48.60046886628675, 22.00854847508092, 4.542687621808821, 0.171212668440515, 0.42245633599738924, 0.1774510603037573, 0.24255027033148274, 0.8804111639338156, 3.220315186246749, 7.927247891502996, 6.567465114978052, 11.027703535172249, 16.77913865735454, 24.79159955055483, 26.326503407570627, 24.507892554806126, 21.381996908495505, 25.51853829814542, 19.55488431838251, 16.763688441245787, 19.21220840946321, 20.041246452639182, 24.234740657191125, 23.83435687711162, 34.355793229995236, 26.59679197495984, 35.701244646503085, 26.87701394481044, 37.34228587919666, 23.359340198578376, 26.51184912650816, 27.32158518606617, 23.449588052688107, 14.558884943685225, 15.950265353725804, 16.79714233644547, 21.757932555290964, 39.43014783243979, 50.56287773193852, 69.956601665866, 61.31626344496205, 58.267267827064764, 73.40358841803767, 71.05212749973421, 79.38453612789031, 85.49936217646446, 89.62265968322755, 85.63422110772903, 88.25263069521996, 82.69282002602854, 64.31345631999355, 36.27031387821321, 28.865226122640795, 21.936117987478934, 21.14932583224389, 25.50481784728266, 16.162956856912185, 10.52220513743739, 11.57913092643984, 7.7912794197759325, 7.0954024118761865, 7.952250059573882, 3.2832265717367974, 0.3704313357030192, 0.30017816191238744, 0.21396942977463046, 0.25500865262602607, 0.24021601574795864, 1.4605684458248078, 10.824747354753557, 39.61955908806094, 83.30941661711663, 123.20931142376317, 121.71711629436864, 106.43907654669978, 45.54620158287787, 37.3895465174029, 54.716044087563795, 90.51124126680436, 91.09115585204094, 91.13434114763814, 112.37780386401762, 62.38757256538638, 4.526947640603589, 0.6229293803053518, 0.36378726964035346, 0.25633937799401824, 0.13165717403734886, 0.2053164666698825, 0.10111193082505658, 0.14886963752008256, 0.20693062924809996, 0.22013424655362485, 0.15870295825504488, 0.1405528031529919, 0.1676675046403562, 0.2354540132106312, 0.19029835479394083, 0.16788223908553201, 0.16931490011272893, 0.19310058184689094, 0.2676116110336396, 0.16275839789980845, 0.27221613653725196, 0.20575862197626024, 0.13005692361583635, 0.11573092621420661, 0.08333260824363078, 0.1208944277717702, 0.17219407303679377, 0.14234583193977035, 0.10564479646423172, 0.09640481848750385, 0.10951545570165881, 0.1494024516714196, 0.11333091064326226, 0.16088575725593876, 0.21613850047992123, 0.12685351163869904, 0.11309005259986847, 0.2622677493960627, 0.1237088815879918, 0.1654562071686791, 0.12363660885321519, 0.18292555525418253, 0.13607017755989106, 0.12965946187896113], [0.05667398571066799, 0.025245370343327526, 0.01657272452458499, 0.06440951639125425, 0.07234442528457412, 0.12492334545259515, 0.00848793818975889, 0.06628358195866309, 0.11800020888087251, 0.030188140902487986, 0.0560965852421378, 0.22127413941967874, 0.0649956809056382, 0.015603156944346285, 0.07871079979644668, 0.04250977075688782, 0.17261615683955533, 0.11956452977873626, 0.14538513256176827, 0.18941994305820237, 0.21447284147143367, 0.2522622887045145, 0.559724613783821, 0.4355934875146036, 0.48629977469963415, 0.2642755739150509, 0.08158611929825238, 0.015468136820521568, 0.0853930706638963, 0.13403242964658046, 0.2637213859106264, 0.14681492842012836, 0.14942561817024985, 0.2008619411818443, 0.15770702863172179, 0.5274074704897019, 30.72353332273422, 99.52355354062973, 89.41812376822196, 102.27824195738762, 80.94612583037346, 32.86589072596642, 28.523646516184655, 26.327574214627667, 49.28079220556444, 56.321803600557395, 64.98371485740908, 32.705183375266294, 18.1437292791182, 3.522205309521768, 1.0553040115102645, 0.21915055901533176, 0.09863018899434998, 0.03438719330475696, 0.431187194922278, 0.12581695637275137, 2.5417914794337366, 0.992630297137845, 2.8157754098215415, 6.381968875085154, 7.107888296727212, 6.494226128824296, 6.001376884598886, 8.144139272551383, 9.910373245516132, 10.476747808917876, 10.859399534040882, 22.384317421144058, 32.55048509567015, 43.032244713075706, 51.070330450611735, 57.522295982606956, 53.09060604341569, 65.62774842785251, 61.56274910896056, 57.603061506825114, 43.57396325757427, 50.843911632414795, 41.75046513157506, 25.893920890746582, 18.7573193734692, 10.5308392547792, 14.961785904822813, 38.028481006622314, 76.7522805736911, 113.15324860234415, 134.2397145302065, 140.955596739246, 150.60858111227714, 112.98165275204568, 54.73753475373792, 73.99985144215246, 88.13219039670884, 87.03775498174852, 92.10489242307602, 93.90511912684288, 106.98670218067785, 104.43796957692793, 107.57141774700536, 103.47858921174081, 84.97205441997897, 52.18232239446333, 36.84344668542185, 19.97847087921635, 7.484966333835357, 8.896324846052355, 5.517617733247819, 3.5373819403110014, 1.9180745607422245, 1.0163174906084615, 0.48748374826485114, 0.10958447256275725, 0.9938470899097382, 0.6123335875811116, 0.4768020617625406, 0.08199924753317911, 0.016125767762141845, 0.006835684762336315, 0.4509550825722756, 5.038791452684711, 18.430827163880874, 49.38910845787295, 22.968542691200014, 15.004663294361485, 36.37135805622224, 25.93687084413344, 16.468581076591246, 32.906096981417754, 72.80187329938336, 68.27675250268751, 67.02961921691895, 78.20787998937791, 46.24619168619956, 5.645867961068308, 0.38941447352690084, 0.06720643445488907, 0.0839863800173325, 0.10078129493781637, 0.05862749459582472, 0.02253083929028963, 0.10271859340249531, 0.08284603515940328, 0.04458559707047478, 0.08767982779611504, 0.04250855267708821, 0.07489152973698032, 0.058566004548582344, 0.07173751510920064, 0.1748546351107859, 0.17313643779245116, 0.2845594064602929, 0.3980980495051031, 0.44542653245791314, 0.26960141716464875, 0.10394669363215085, 0.034463828910262354, 0.02296690802810894, 0.06934300771043186, 0.022834526119573463, 0.060670179945807305, 0.021266734843412717, 0.09979703283358006, 0.07882580491563967, 0.01799523488678519, 0.029078041195809364, 0.1301341759221208, 0.07870192083740428, 0.08693857644233974, 0.049573231653700915, 0.09505672590626825, 0.08929281059892909, 0.03526760069953819, 0.05252535146991572, 0.07299538551559372, 0.13185159183077275, 0.1110742148011923, 0.03332211275494868, 0.05308156194646032, 0.019279807287779067, 0.06904617928329014, 0.10787456431576323, 0.13857862521563807, 0.020348907883970008, 0.06839788503824704, 0.08538505738420833, 0.059080271711272586, 0.0044766352643379045, 0.18886665903752853, 0.04191178933627183, 0.032522673192884655, 0.01650435500778258, 0.09040679437138381, 0.023889450258725596, 0.1674063299452105, 0.0526299033193819, 0.10301609598701039, 0.03547061016903289, 0.10892598168744196, 0.3407440496788871, 0.21200856644540064, 0.2979966192956894, 0.2699039606077056, 0.11819060471269394, 0.06081803874563306, 0.04468588181020272, 0.02010229843548469, 0.22473900188361445, 0.095514279579924, 0.0635888447023688, 0.24545287022427206, 0.2623924072231016, 1.0847812362255589, 48.87641545264952, 123.4984685528663, 99.84787079595752, 111.63647590144988, 94.73007202148439, 37.73016122079665, 23.164757297885036, 20.55192335959404, 21.44054416687258, 46.08846533683039, 59.93656973684988, 38.6844228929089, 22.141901216199322, 4.947169298125852, 0.7458497812190364, 0.0634435025013743, 0.25295397416958887, 0.027081753960960818, 0.7486346640413808, 0.619112178683281, 3.4227082613975774, 4.173045417954845, 3.9408384071242426, 3.6246372711273933, 4.780714204234462, 4.438729122761758, 4.583275327759405, 2.0949705137360484, 2.3022582165656553, 6.287222062387775, 15.246311695344987, 25.506371105870894, 39.7829258057379, 51.07445678403301, 57.862228193590724, 61.92416021900793, 62.0666834615892, 69.09832431424049, 66.51201540423979, 59.1098713874817, 50.88099764239404, 51.17457920505155, 40.99041569617487, 27.623980314500873, 14.365163003244708, 8.532740742929521, 12.757749230630937, 36.08486029409593, 80.35224760732343, 116.98059543486565, 146.14324508174775, 150.1032543182373, 158.63859853436873, 121.86961804666828, 60.53392710224275, 80.28486128776305, 96.83750660188737, 95.67393549026983, 98.41964167933311, 101.61863265498992, 112.55322010286393, 109.76864322539299, 112.60060233454551, 108.20784584168466, 90.81396195196336, 60.29587061174455, 39.22767900651501, 20.491395304279944, 11.218890643888905, 5.400758068407736, 3.08464432435651, 1.41984308919599, 5.896372093308357, 3.1324707644601024, 4.043550327900918, 2.0593387224981865, 0.98745264593632, 0.9638478222393221, 0.1688052677819806, 0.2652532553240176, 0.04150000941609183, 0.058992206073936924, 0.22717457925600393, 3.820194635660418, 17.29530688255064, 48.948320342648415, 37.14077411159393, 27.41904039536753, 25.45297980308533, 17.405290142182384, 27.628796985072476, 55.823439013573434, 94.89621577724334, 83.9754036934145, 78.20081972306775, 93.46990862200337, 76.56246139157203, 18.61326248415055, 0.36491758640735383, 0.021326949354261163, 0.025277381327243584, 0.1508329063653946, 0.0675030866818082, 0.05677259654828137, 0.06535437093266556, 0.05164584422844553, 0.007001633770884045, 0.05892163788479182, 0.04457587158427604, 0.12892414004571978, 0.07087138376288837, 0.01272992694735407, 0.17782959966890274, 0.13873749652937536, 0.2791077102864942, 0.3657455435923992, 0.28063035600127717, 0.23369725102618819, 0.08475157161874157, 0.07933367524416217, 0.019730462339676676, 0.06008047227477355, 0.04115855636736078, 0.038082897212476506, 0.04011696407331094, 0.11792278803524472, 0.11067699821245287, 0.07246888392875273, 0.07005582954133711, 0.061885632063832983, 0.10769169912823748, 0.0037805045740829124, 0.017776327177641854, 0.02022389574126611, 0.10058958909564442, 0.007566911376817453, 0.07618015091265402, 0.12633418063482932, 0.07928037084639072, 0.10065664477165669, 0.09551841645471512, 0.19632919811673705, 0.11488184798508884, 0.28747507581307047, 0.20714488871876272, 0.39793845806871697, 0.12084649365034797, 0.32611667328784544, 0.26332896503229297, 0.12045483885993881, 0.09323018077280253, 0.34573229330201305, 0.16482033886976782, 0.12539753855596628, 0.14954042410658253, 0.21843150888960208, 0.2868941053748131, 0.18926894712832668, 0.24249045418635493, 0.3568109972102027, 0.23912187365274276, 0.27423655554171533, 0.7379845710050675, 0.5611905383486901, 0.5275155808175764, 0.5205158660969427, 0.223539553342327, 0.2481362310748908, 0.20835408189844704, 0.3534487598846036, 0.5484943776842087, 0.3536343370233813, 0.36682799518589054, 0.3576299758447755, 0.3900475073004923, 1.5552270051933106, 54.53147303673529, 145.70597925493794, 112.42453498225059, 124.36793250422325, 104.09440917353477, 51.69255956526726, 41.83967944114439, 41.645416213620095, 72.16973627767256, 77.33708243216239, 86.02237101524108, 50.691068633910156, 30.244105938942205, 6.512613709895842, 1.5674091515041169, 0.3073755273174855, 0.5841416132546241, 0.12517462229175916, 1.1936549553948066, 0.8462506292327758, 7.365167342847394, 6.897968438363845, 6.89934273881297, 15.10148504088002, 16.74435115629627, 18.777829447100242, 17.14676280175486, 25.772076383713756, 26.395711668076057, 22.7859563596787, 22.218867924905595, 31.590510491401922, 43.267029946850194, 51.902979035531324, 63.39748482550345, 65.17329085257747, 60.17408101789413, 71.96641629742038, 68.58974979769799, 62.95092690375544, 51.249339580535896, 59.191335093590524, 51.86184906190442, 34.408937423459946, 28.698792111489084, 19.94742924167264, 25.34261803473196, 45.9370893047702, 79.42231639739006, 111.37122169617685, 137.2515143117597, 143.35418885754, 151.79299569899038, 119.71757042792537, 73.75898653461088, 82.60622978210449, 99.35054563706922, 100.08992810403147, 98.72303701216175, 102.55317657224595, 113.34600171735211, 112.58758006557342, 116.27157211303712, 112.35328905044064, 95.1128718160814, 58.643011277721776, 43.6275153775369, 29.999442215888735, 17.61703537356469, 19.327732016963346, 16.228492798343783, 13.043734142857215, 10.0111928678328, 7.891990196320319, 7.644619547551678, 5.345320268984764, 3.2076662778854375, 1.8132139165555279, 0.7658618364122607, 0.23892589303995335, 0.08726708260515044, 0.11290561693209795, 0.7748767300959557, 9.100142967316414, 27.441670510076708, 68.19373946036062, 36.74685831992857, 27.999331528140655, 53.72105644595239, 36.43731271066974, 25.48699655840474, 45.409577585035755, 93.04144459386026, 86.38437440318447, 87.78209532460859, 106.06045015396612, 86.02677191457441, 14.4388045226374, 0.5157460188192706, 0.16656387837663775, 0.2533042448903284, 0.3065484587944323, 0.25524770270191854, 0.1578123197560349, 0.21483241249957394, 0.2471554087054345, 0.10469227338269835, 0.2076112677253062, 0.15777232996638746, 0.25322351454486774, 0.22295009464986865, 0.21849552319655496, 0.22116936923515415, 0.3357002493594924, 0.33850149581989936, 0.35965413335830937, 0.4892825227110617, 0.6220579399697242, 0.3046362726919113, 0.23048103005895693, 0.08949468242785624, 0.20014500545878566, 0.07009197356960467, 0.22516722971152878, 0.20392578726093616, 0.24481298762463757, 0.29597727281432, 0.1603201545414425, 0.1625194244327084, 0.1947681867187062, 0.18069446207054202, 0.16830668243910038, 0.12439166511138602, 0.15709110926235878, 0.3055765996536901, 0.16927368458240263, 0.15447239091079082, 0.1625286634530752, 0.21919955799896873, 0.1623921772284854], [0.07617710188271538, 0.06239657057449222, 0.043325363282835296, 0.033805709587590355, 0.04212999415974464, 0.03478681540957863, 0.07466086832385871, 0.3073738725675691, 0.06986057671207575, 0.05679487821555907, 0.08976223097453195, 0.04427004162402404, 0.10891445972506078, 0.04407349410617063, 0.11473093632488482, 0.016881498177686048, 0.10282105000148858, 0.07859522777218973, 0.0622783555468965, 0.4557890667309685, 0.36016827028605247, 0.25106221197112916, 0.4183520046212981, 0.3998433816577158, 0.3740768110559833, 0.2547796076584247, 0.12503856507640693, 0.07189481594269315, 0.07863647394603299, 0.14697721648600795, 0.14857078662082074, 0.20491373424808826, 0.009713783248087332, 0.12387432593611941, 4.380392201485173, 61.353459281306115, 111.58681869506837, 87.57394298430413, 84.96207591026061, 76.4298382113057, 71.00816557484289, 31.621867879744503, 81.11497602155133, 119.33100515796293, 90.31518551611131, 50.74164759728217, 34.609472520889774, 12.534570290196328, 1.335247247930496, 0.1986431973355432, 0.21857703495169842, 0.02057203865279594, 0.3049951695626782, 0.03240274595877817, 0.6353233346054632, 0.829926276158902, 4.134337998205616, 5.739386581605481, 3.0987501480887016, 5.601484871679737, 4.871318994029876, 5.316470746071109, 4.998763174779954, 15.723576872579514, 29.652751761098063, 55.843690210773104, 61.760224757655976, 87.32990095692297, 77.42147614878994, 91.43784630683162, 92.74397988473216, 95.23206480087774, 93.17005126707016, 102.6662035911314, 96.29742760812083, 96.3059469961351, 86.18278811054846, 84.0198363027265, 63.131030374957675, 59.27408925948605, 50.77774909234817, 37.63138417274722, 49.244298473481216, 103.26795793348744, 111.63220836270241, 94.44166798745432, 79.17774092766547, 90.75557354957827, 90.95420237510436, 92.69970417022706, 42.45938254940895, 86.33056732916063, 101.08966965829173, 99.22497487837269, 97.7611541748047, 102.15626408976894, 105.45578541294222, 99.01486919772242, 92.83881495075842, 97.51096187099334, 103.48173495261901, 92.7763080596924, 68.3108300547446, 50.816545255722545, 31.484041675444576, 26.608380617633944, 11.50281729236726, 2.3904576128528965, 1.1403727435296582, 2.342926331104771, 2.115943672195558, 1.7495261469194967, 0.9146885730085835, 0.5157836490581112, 0.5275688392500724, 0.08965033617231155, 0.020752975213972312, 0.06217509838602236, 0.06384786286000764, 0.08276385690776572, 2.8182935714721684, 16.7181634518408, 52.393608708535474, 58.624199590375355, 97.37039981349822, 141.47830747788953, 51.053374044356815, 18.45319055741833, 13.106965691812578, 44.664307640444854, 79.56829917046332, 64.29402097578972, 76.89438020029377, 73.629697368991, 13.676781154447987, 0.6395708324928439, 0.11632437622475049, 0.18696279264986518, 0.09816571754673797, 0.05541853231167602, 0.04735826079042689, 0.0917505891993642, 0.03517198143526912, 0.04558604661255114, 0.06351037431628474, 0.041421941226168026, 0.005526119221617738, 0.14271838049734795, 0.10667910709256127, 0.3037769671890044, 0.3937533197383727, 0.4974686931217871, 0.4541172790190866, 0.1778600133594967, 0.1036914867619353, 0.04443295022112228, 0.07643092979466723, 0.09693978534590814, 0.046101321180861805, 0.009703552143858566, 0.10811959753834433, 0.16928249459353187, 0.02500228681451371, 0.07536023765081361, 0.131288088197189, 0.045010197472067616, 0.07459447914434057, 0.014673039061768402, 0.040107556513600776, 0.16362947051323232, 0.06966006085877458, 0.03749883177900507, 0.07595453035807417, 0.13804141371961565, 0.10097238024876964, 0.14085136293884248, 0.05351578058194249, 0.02465596910746348, 0.03693695608226042, 0.054956167605855775, 0.13909342097899607, 0.11541664630414979, 0.041574346757824385, 0.17586338904596147, 0.06302179791213525, 0.05880602755613866, 0.0955535262642849, 0.11224891104164625, 0.0507256692095149, 0.03151280076933965, 0.05382953955221081, 0.03396355051306948, 0.10572795530841236, 0.12507480869610466, 0.0660052468940135, 0.3137876832437131, 0.0727963099075902, 0.2055039743502294, 0.39795779412792576, 0.3163323515365201, 0.19821987247034428, 0.30743886746706506, 0.16623939417542952, 0.06432004498257753, 0.06191644028970792, 0.04800712577097359, 0.17872993684103414, 0.03709546350423367, 0.049718968389976415, 0.16800901131524196, 9.409372825776378, 81.49225311894571, 125.98611416355257, 90.02556554732784, 98.53128017917757, 90.21191735421458, 93.43303834238361, 61.31674589649324, 71.06884464140862, 80.14833927154541, 68.13720241669687, 48.702842727784194, 38.21170668448172, 14.118450822368747, 1.8392616414254712, 0.11842829115208119, 0.17245327122509482, 0.08988870442995141, 0.16299904143858343, 0.24662515328776455, 0.5935789584632843, 1.3073014636193554, 4.961785029980445, 9.308896410849787, 3.206010792524584, 2.9506112971613487, 4.203253061540665, 2.2715963134842534, 2.393585212769047, 14.187722821389476, 33.38109993165539, 62.40044186192175, 71.40555658648091, 97.22304421086466, 87.91673460314351, 98.21143442584624, 97.09763034697502, 97.69483473993118, 95.32528385039299, 104.99222401649722, 99.69691445750576, 99.0176619252851, 85.71342160624843, 85.2556182492164, 71.59536792385963, 65.81360601609754, 55.48631521963305, 43.59888599764916, 56.46109088774651, 114.66606755410473, 125.1217100697179, 111.92808058954056, 91.13500010582709, 105.46726226806642, 104.96497138853996, 103.34863324319164, 53.52109009219755, 83.26565865547427, 103.54718362131428, 102.88086706592192, 98.30753249506797, 101.7463214935795, 110.58833229926326, 102.24126185140302, 100.90840124314832, 104.66031305251583, 109.48479698550318, 97.64134930026148, 75.49623566289102, 60.19945090816867, 36.84168554121448, 31.416696540770996, 14.049239620085686, 4.244384506056386, 0.36837533957535223, 2.618867769356697, 1.3245543765444912, 2.6659894085699514, 2.265776251592944, 0.6382741827157237, 0.7483892707574753, 0.5118606047284219, 0.18180372674138318, 0.07887394588080146, 0.06577129896369673, 0.07879272523906924, 2.0021807186065184, 12.041275366660088, 36.39940692532447, 43.83375752356745, 73.9151047122094, 117.13933375573929, 52.17079847089706, 26.742478609085087, 27.565413444272934, 62.88288554837627, 97.55305674768265, 81.33154576824558, 88.00753747263263, 94.50783052752095, 35.05116670362411, 0.47457685213415857, 0.48750047962511744, 0.055169653327715014, 0.0528360077840907, 0.08037420650643688, 0.06533190157384643, 0.0265559648358894, 0.08078528928660578, 0.12752195399615074, 0.10713471490288935, 0.05065781297162176, 0.08841183246864427, 0.05529381702804277, 0.11431207775228447, 0.31431671292070423, 0.38544138833399744, 0.3716383225494816, 0.37290797538815007, 0.14638127668971015, 0.10606248292230791, 0.07505971667987686, 0.046415294655748916, 0.11255167665020113, 0.029645107138241013, 0.02042845270836786, 0.04052224756789304, 0.09563704516978995, 0.05622464449956052, 0.09437947353768734, 0.0828924294440977, 0.005277629506083266, 0.06472111499357609, 0.030300102737401764, 0.01580626504766124, 0.14756143513706424, 0.05720426028053607, 0.08178086650948371, 0.16722577834321609, 0.08228736554062174, 0.05103004743315039, 0.16629121236262784, 0.22606896116368233, 0.14004124028067436, 0.15694294785780294, 0.12056848034262659, 0.20735916351118397, 0.24126247653076727, 0.1984037182504131, 0.39343334013415926, 0.23539785896578144, 0.180647102515063, 0.23824790522696512, 0.3219327300546631, 0.2117193529322263, 0.2355761582692785, 0.25704762628001554, 0.1639221467438244, 0.2782701616806369, 0.3247004525075036, 0.196554443288234, 0.5064528513579599, 0.46962121321309, 0.38690090840381963, 0.5498007108126918, 0.7711122353230754, 0.47260386929396664, 0.5452478809222099, 0.32433380282694296, 0.22238749500003555, 0.23478213877927875, 0.2603664723855834, 0.38109074436849166, 0.2726820099257654, 0.13934727187358564, 0.33448265985615794, 12.552828923348459, 95.00661480811335, 143.95740232160017, 99.09761551887759, 106.64169834506129, 97.51465674369567, 90.52159632405927, 52.784010056526434, 109.52676634634696, 145.48867994739163, 120.71386029643398, 71.36310869647612, 52.509985431548095, 21.630777159044822, 2.797066929840273, 0.5439197296096433, 0.3109773663022826, 0.13920779790609114, 0.36890259192835906, 0.47102827158185745, 1.6250310982427292, 4.65139267906066, 10.92189956095911, 12.804688234483043, 11.540084711966976, 15.556630992120313, 14.079291839753429, 14.667890552551517, 14.852672430776781, 23.705883564487582, 34.24976371949719, 64.58246423352149, 70.41895497229793, 98.52428267079016, 91.21092934762278, 104.27518337003647, 100.91242559494512, 98.99738327149423, 95.67021708334647, 106.13058997738747, 99.93786565719113, 98.49859899090183, 85.99132153295702, 86.84888501321116, 74.35953278695384, 73.01997277044481, 60.25762750256447, 51.23469737268264, 63.78627407935358, 122.01479281148603, 125.69711392925633, 110.7181078387845, 97.54561208909558, 114.97843726988762, 114.77270895434965, 106.60992714666553, 58.77590902390019, 88.62302795533212, 104.33921214072936, 104.71996445809643, 100.4373324301935, 104.35733349092546, 113.7123981598885, 106.46070449582993, 106.51927332724296, 109.62990899239819, 115.4954605717813, 101.33498253360872, 78.94967863636633, 55.95962762832642, 34.13747410620413, 31.18998942836639, 16.508573562868182, 6.688126046811381, 7.511076081183649, 8.50445947339458, 6.734189871818789, 6.6696972808530255, 4.472668901566537, 2.1699091119150964, 2.314380546731334, 0.9604910701032608, 0.36443121250598665, 0.2631771876927345, 0.15959296856195698, 0.3830703155648324, 4.828983872167526, 25.20081062470713, 73.37472761830976, 73.99149679368543, 117.66621789624615, 167.33130824181342, 62.725990741483635, 26.458708855413622, 19.214040156333677, 57.74029739441411, 101.32148958021595, 85.63751589867377, 103.03249805204331, 107.80543419622607, 29.624140031876106, 0.8785340033711926, 0.47462977348796787, 0.41624572248228137, 0.15736680898454883, 0.19777580194415587, 0.13710753721815927, 0.21198233559487328, 0.15530912746344844, 0.24509979562172968, 0.2594635305145095, 0.10228754637101967, 0.25264062888679967, 0.3127097668907335, 0.4542356855686634, 0.7742338291098996, 0.942039444081245, 0.9556248796082313, 0.5644351352126368, 0.38979423863272517, 0.1958330948987315, 0.3379798512304983, 0.2648558089089009, 0.2570483464026644, 0.09737506118272582, 0.12839047553678676, 0.16199044072099272, 0.30822064487203477, 0.1568721613335994, 0.19947021989332092, 0.170116028898666, 0.15037783481661351, 0.19886948438661717, 0.10337059551309194, 0.1749012898653746, 0.2328620772928961, 0.23929409021812104, 0.2524626053749554, 0.33861843148066156, 0.2143316974322642, 0.2361575730385319, 0.3537925801450207], [0.11300605105897112, 0.07397582484108788, 0.03500799265419764, 0.045005968666725585, 0.023643210447663744, 0.020285632851864063, 0.011431679876911785, 0.08090199512099067, 0.03730572399593169, 0.02094348787420219, 0.019611799150645252, 0.02859847781608903, 0.12346547247181017, 0.05433042698930349, 0.05581787862484494, 0.05734446203155864, 0.053871444561668945, 0.07826949484766492, 0.08246538905246605, 0.2979010115227392, 0.1077805117012993, 0.13549705186197836, 0.27543646373575736, 0.44889102719964524, 0.13245297085133292, 0.07073308957079727, 0.05222525567777696, 0.0745922115240847, 0.04504111678069157, 0.2310554887498579, 0.13411208746894715, 0.18707628091496808, 0.3036672940417644, 15.327227250222238, 98.14033754410283, 112.13954341027045, 77.39663970085883, 86.46362981488629, 61.1197683888097, 43.98169363698652, 27.36785934817407, 26.91230743162094, 32.40230775648548, 43.319801515148534, 30.43580197518872, 21.117362437709687, 7.569616475412923, 0.4078862629830838, 0.09938933616203648, 0.055603542545389746, 0.08833600508589899, 0.10358681616884086, 1.0032260898620853, 0.14789806949275155, 0.6189487874507904, 0.3173107071028602, 0.29799772246230033, 9.019193091700155, 5.645717440112945, 1.5165307396842589, 1.2622920207438932, 7.288629153082448, 29.859417523107222, 61.92648618452011, 95.04146898946455, 99.47795990974673, 102.35868192488148, 94.75253935783141, 90.03167660005631, 90.54665242472004, 99.07268493406235, 101.25015735626222, 106.12399255075763, 102.11456929483722, 102.60098241990613, 101.7881182701357, 106.74624519963419, 101.01392869026431, 85.67630029493763, 76.44344099106328, 74.36388661784511, 59.47979011843282, 54.95089600163122, 82.28838443756104, 64.86927970763176, 70.25185415821691, 65.87168062886884, 72.19016398152998, 78.84969742067399, 64.69112565440517, 32.553391571967836, 88.837950306554, 101.04511153313422, 92.66548541284378, 99.70231163886287, 98.08265516834875, 101.81730854895808, 94.08095113692745, 86.40591606017082, 90.83696273065384, 101.22936879434894, 99.70325300770422, 95.34299727409118, 91.93563430540024, 84.09538115224531, 70.4135734804215, 55.78784742662984, 28.75427992113175, 5.323250562913957, 0.9869280902128067, 2.4536428288105996, 4.547491544677365, 2.0232244797291297, 1.1912105833330464, 0.9994726267553146, 0.9515935410895656, 0.2866501523362052, 0.023112526020756172, 0.26791289809250063, 0.11940033415392523, 0.07202190226845204, 0.33086050421960894, 13.31529159699717, 40.350841860617365, 68.67560263602965, 52.31023088578255, 49.36151066134053, 66.46107166044175, 31.766313083710212, 19.879713443017778, 38.454034636097575, 60.96516424609769, 61.317502913936494, 76.08498342575567, 81.22756373497748, 28.75429168824227, 0.4878289781270489, 0.09469277285520109, 0.05638376862231282, 0.11550872241176906, 0.05332485997989293, 0.05698921556975092, 0.11778742029902436, 0.029649492991607518, 0.058641376109012676, 0.045091896918752504, 0.040587518259041735, 0.03656253827014758, 0.07189574290908153, 0.37050871058337154, 0.03753802866765088, 0.13590962085272038, 0.046790558995018085, 0.033120275399978125, 0.0023631665023839885, 0.03861551218095326, 0.09766230584993478, 0.06569840569770144, 0.03767690508656445, 0.02124535332944605, 0.08757123483284827, 0.11452101291187348, 0.03222240886140255, 0.02577044892184917, 0.050362826985937935, 0.1336979709805981, 0.14680812555936076, 0.01587287830789724, 0.04566392328049387, 0.03293704249024872, 0.06514928153445644, 0.03552710149256933, 0.10766664039223425, 0.03523999472118674, 0.19465313563423772, 0.004470870452707693, 0.0691977267964713, 0.06285497460574394, 0.060731133731502684, 0.05580298587559693, 0.05869018357066859, 0.027698991001553597, 0.026767638759807717, 0.06820144477270304, 0.023215570592231328, 0.018794490587747386, 0.05673074516497793, 0.0828781112607929, 0.051151349795080965, 0.052853972545915076, 0.0563601041663318, 0.04997710171606272, 0.024136611290516394, 0.05667210879525351, 0.024599943182341034, 0.25146221711991296, 0.0841884586899992, 0.20589156887463986, 0.14652681807356496, 0.5088126473128796, 0.2618683724393768, 0.08291551933413552, 0.035926233301119465, 0.04926210802589213, 0.026612956031796434, 0.17261696889275507, 0.21426259630149413, 0.0989894076220451, 0.2956475179281927, 27.055038559821348, 122.28686409611856, 119.52166372729887, 88.85445564023911, 113.89894608528384, 86.267636822116, 71.35546791938044, 50.45539302210654, 39.04873655688378, 47.55944436596286, 56.665281634176935, 41.11676700653569, 28.730930051495953, 8.36515453553969, 0.639881496467898, 0.040846061442167535, 0.01826051772842484, 0.11622823219025329, 0.4111744655716804, 1.4083576538870413, 0.0961054772919705, 0.5083095114077292, 0.3252705138537192, 0.45977257071964206, 6.648057074316087, 4.6517653042270295, 1.0011270702365906, 1.8612835436098039, 8.933441254400439, 35.088903827051965, 69.9943034879623, 101.00802944552515, 103.987179417764, 106.49999095547585, 96.48816462486022, 93.06490036749071, 95.85187773550712, 104.28114537269839, 101.68562673753308, 108.56898630819013, 103.87889846678704, 104.4191578895815, 103.26456116091822, 109.59626290106006, 102.49385464575984, 92.66952545412126, 78.92829387418686, 75.22445463365125, 65.6546990333065, 64.23082374757337, 92.37156652635144, 77.64807147364463, 74.23818249856272, 74.78332134985155, 77.2291309602799, 87.51515450016146, 72.54706828824936, 37.57763593427597, 93.0101833035869, 103.21981476199244, 95.93947210619527, 101.09880093605288, 100.33917903900148, 104.85439192864203, 97.75008524617841, 87.39713822641681, 93.10739532593759, 104.362103093055, 105.44573630056074, 101.04976346415859, 93.91789820886429, 88.15330843771659, 78.28502516592704, 61.412863577565844, 35.63478008393319, 9.251569009596302, 1.2622722863189637, 4.04997002213232, 3.872253558328075, 1.7174331915955392, 1.203460267955257, 0.5346819962705336, 0.6868011336172781, 0.06557590057772976, 0.02061844825924885, 0.21202174315769828, 0.14129832927738467, 0.041055080871428215, 0.3027885911926147, 9.60658077270754, 24.9753253306112, 64.1693288280118, 58.277265948633996, 37.41710509023359, 45.80645084381104, 32.83328406272396, 33.40212775814918, 61.97841052086123, 82.04144770099272, 73.97362647518035, 86.97264363688808, 96.05165973786386, 58.870924518954375, 3.8634323929586722, 0.4093185103228016, 0.13340892600676707, 0.04731555904952749, 0.01833783898262247, 0.06591464167520886, 0.10048632044345142, 0.054974362194057436, 0.08536013654403149, 0.017213876914953994, 0.011752031991378436, 0.10390921661089506, 0.07925537339742146, 0.315593566985861, 0.14362424882429262, 0.13506306305287347, 0.04289043218558354, 0.04187167314211688, 0.07131331690376805, 0.023420939612532818, 0.024707275930972352, 0.1337648198128708, 0.02644984825183788, 0.059216734953224666, 0.0947957733766206, 0.06703411063720142, 0.03546698274271142, 0.023250576979931326, 0.013583696507398161, 0.1035676180054584, 0.0403346594483141, 0.13243346625278074, 0.06867435850924061, 0.038242277974683436, 0.049145823539865595, 0.11118805546674038, 0.07990087908242019, 0.04236939280564266, 0.0906619705980824, 0.042836005469003034, 0.1432093509262608, 0.12726356020017018, 0.11337437081120669, 0.19399531125541658, 0.12409748734846232, 0.11831760676878116, 0.14290409553195202, 0.21758046181451893, 0.08830576759552763, 0.2035166043788195, 0.1401591718557381, 0.17375258698819146, 0.31725668258243994, 0.21790024223587207, 0.2989768134730478, 0.18877043839423888, 0.20261953074124553, 0.4127473053672622, 0.17383068199119261, 0.5421856129842421, 0.37541093785435925, 0.3160552728560663, 0.3585412221089486, 0.6881441163920587, 0.5076222692526157, 0.2910348106055491, 0.17609706118462548, 0.19930050077457584, 0.15385725295111058, 0.33218200588899277, 0.35829046620957317, 0.187455938768483, 0.49214220635833283, 31.94057026217061, 137.76123416039252, 136.51184943414503, 96.11128760922341, 116.5274832325597, 80.93421751453032, 61.21489371022871, 39.02983465502339, 36.70472814190772, 50.370308968328665, 63.769082330888324, 49.69878350534747, 36.5862411837424, 12.029835774052529, 1.0391488719371058, 0.2691972904628323, 0.2031959046519572, 0.20481794261403624, 0.6935390301289097, 3.014239250652252, 0.3460647754611508, 3.580060514711565, 3.164043147717753, 2.900226981409135, 17.35597025963568, 18.856822060000514, 5.832873332885004, 7.690125905698346, 11.592465023840628, 35.16690015792847, 67.75023706497686, 103.68365072434949, 111.5685796737671, 113.14049305454378, 100.33622157189154, 96.32449980705016, 96.45675428452031, 106.64263186916229, 102.52836365853588, 112.08834079004104, 111.20084962537213, 109.75335382646131, 106.66434611043623, 111.78916592751781, 104.75343796514697, 96.31336812050112, 79.60283956220074, 76.66026176944857, 71.41747274706441, 73.88984464829969, 99.84830225667646, 90.2819787302325, 81.3889378886069, 84.15791942227273, 87.73763133633523, 97.55027186486029, 77.67712839188115, 43.67474463678176, 94.66448999220326, 107.91173042789583, 99.5398235321045, 105.64222351197274, 102.90083977483935, 108.32142199239424, 102.61325943854548, 91.96806446198495, 98.5265576454901, 110.90786426298081, 109.91686174946447, 100.96070997176632, 93.56750503663095, 90.15691787965837, 75.38846462003647, 59.830167601185465, 35.12651151226413, 11.035904230610019, 5.110318814554523, 7.985528919004626, 11.172187962839681, 5.726806559870321, 3.3285069033022854, 1.7513813054369343, 3.0188137148657157, 0.5680602019832981, 0.0918616259831094, 0.5979593879272861, 0.4617606301701838, 0.2032998014962481, 1.2255615981355792, 19.968553166235647, 58.79291642096735, 80.5126097894484, 60.11262532203429, 70.29919716619676, 88.3258064331547, 43.270344349645804, 28.10751245867822, 51.37977407824609, 79.73751806443738, 81.23138412352532, 98.82486174183508, 113.26235325105729, 56.04056181446199, 1.880081012364357, 0.9185811576824036, 0.15437402522131322, 0.2422561691773515, 0.22625335852705666, 0.23689922275802783, 0.2484493618530612, 0.12198440234867797, 0.16307106902522428, 0.060692434800007654, 0.2634294144809246, 0.4569119371233448, 0.3021946891901955, 0.6784695290750073, 0.3993327380909074, 0.43345938106217696, 0.18582029508486872, 0.23488006013776028, 0.1630813805686851, 0.10342534015616102, 0.18224264915672042, 0.23263042762635217, 0.20464292216685512, 0.11636378378757548, 0.21410197830728947, 0.1822171077853249, 0.1756479344781368, 0.12766872878156363, 0.1711082353346771, 0.2643985769921734, 0.23259808339418905, 0.211639802362169, 0.2609948789881122, 0.0797727891814805, 0.12505348846917191, 0.259519363002431, 0.24522779359211846, 0.169618807192291, 0.34205887106157123, 0.15396219167497852], [0.1483667007977924, 0.06807484108233644, 0.03496029985047156, 0.08967660532723512, 0.03344419652656202, 0.027854190838913766, 0.048074484051715945, 0.06294312451275126, 0.0726170529941878, 0.02946608005121591, 0.046191010924596945, 0.0631995647845249, 0.07768314647217912, 0.09796069709644203, 0.023670780036838788, 0.025605198010922443, 0.02380057831384963, 0.020087129894583937, 0.06786897027444455, 0.06513674833601521, 0.06866223133739925, 0.11634653148752068, 0.26661618702834655, 0.18063643857115702, 0.21876693282636905, 0.03494798498708875, 0.03250340991202862, 0.005031873288023616, 0.1383315925035746, 0.08397342547053292, 0.16794387851991963, 1.086470797177284, 17.982823848724365, 95.50269265328684, 98.91386032104494, 82.00215339660645, 73.01726633502592, 19.470773012407367, 16.44881821447803, 17.57027679874051, 44.94709091801798, 76.6212655651954, 50.65632820129395, 37.76926332904447, 21.346438661698375, 3.7795007805670466, 0.1899795089998553, 0.047355793987310706, 0.07990140002220869, 0.03177635608271005, 0.2960418999916123, 1.023436715045283, 0.9359564608143223, 0.2744415300267358, 0.04663611949992277, 0.16140950092625234, 0.2865472514062159, 0.4040541992552819, 0.6504997815335951, 0.9889003682521083, 14.986915549924298, 54.96278862799368, 88.93069867164859, 96.96423053741456, 93.81404953618204, 92.75233453319919, 84.64556417157574, 82.3608619936051, 84.53987982965286, 97.3106699605142, 96.00605826224051, 97.42145338366109, 95.01114906803255, 91.65417286657518, 90.42009322874009, 95.62379975472727, 96.45423612286969, 100.80534488924089, 91.9990276521252, 91.1683245628111, 85.96540251085835, 69.85241566934894, 48.32614614117531, 48.28486711748185, 70.2920662972235, 71.05486531411448, 63.80706264126686, 72.3462978486092, 80.84600340935492, 50.107482710192286, 48.36689564489549, 97.62353389493882, 84.34989590798655, 82.43801501489456, 87.10690636788645, 92.28410551624914, 89.07009186283236, 84.61450684455134, 85.29548521964782, 96.70162000963765, 103.5903924511325, 99.59361491664764, 88.48989486694337, 90.48702455336048, 96.97896295978178, 96.99004757788875, 94.6020301695793, 81.09661932914489, 50.90714808433287, 14.363557773251689, 0.34667050586112086, 1.0971178258619, 1.7070217502693978, 0.7942433102476982, 0.7113602577197937, 0.5146688991977323, 0.1554051029586023, 1.5589131751368124, 0.1257833327737547, 0.20680500615027644, 0.34309606218049604, 0.012423427617778222, 0.06327734186103748, 4.520757650175403, 15.584271934724624, 42.03047529343636, 68.95146293024864, 51.34237820102323, 53.29072536960725, 42.015935067207586, 14.353946005144428, 22.154170390098326, 49.36382878211237, 61.95036557412917, 75.89281866627356, 92.05507047714727, 59.63592398551203, 7.132792405543789, 0.3222789405094039, 0.02356013204271515, 0.12380164717474293, 0.05290180707590715, 0.06544417175914972, 0.09707456319442681, 0.03869935667382614, 0.028454437964565815, 0.05568036201199698, 0.02930416353797961, 0.08948385760548616, 0.07688120563304232, 0.06253604837242635, 0.03568654737224983, 0.049877770755800514, 0.08105390269549624, 0.039685782976448536, 0.027673568373786348, 0.04388850302465501, 0.00961488608511225, 0.04733955292331596, 0.020604474815509973, 0.099648833124628, 0.032488425232229695, 0.014468897697365573, 0.08365043514077702, 0.08031413755229405, 0.186294840588685, 0.09983843988588742, 0.10178439514411074, 0.09541222134665137, 0.03307137217733168, 0.048096083900741035, 0.038387941932606126, 0.03850889955497077, 0.13542292519442498, 0.028496009725776893, 0.04375312379711578, 0.13138616277325538, 0.06759160814145881, 0.08489898225713162, 0.025449785584163283, 0.030819941274521333, 0.050469665607858094, 0.07673913462748451, 0.062484686007542964, 0.030639721005554163, 0.01740413102050943, 0.020254014488009196, 0.039057843687553565, 0.06395882686540004, 0.039797026603933305, 0.04167738558364011, 0.029304307179465413, 0.03700826737669207, 0.031885900910222725, 0.02261602635224981, 0.024013401369654366, 0.08466204658391015, 0.07863170121826472, 0.16348515487005635, 0.18644502446536096, 0.11681797433524363, 0.045394972792916724, 0.03931369024118589, 0.02210648786727219, 0.16107668168842793, 0.10857018747276838, 0.22125717823303517, 0.8374579623341561, 30.117736977915612, 120.99044230676468, 106.43105137732722, 95.59133037444084, 85.08156699519004, 37.382886332850305, 33.954448469223514, 27.60502349945807, 33.676666213620095, 52.522129089601584, 49.27312004950739, 40.124995708465576, 25.50010511952062, 4.4192771084847, 0.1843251212830505, 0.1325505398093693, 0.06323998358340994, 0.03078231869655992, 0.14532988230066915, 0.9938950776573151, 1.8728420330632118, 0.7326291874051095, 0.2348909079427681, 0.11167282058346657, 0.3528832031353828, 0.1935031916946173, 1.0329803319707995, 1.756837322346626, 17.29737004926128, 61.21474466016216, 92.73101252894249, 100.3588536477858, 99.13102626800539, 97.80328827519571, 90.40438021382978, 86.95181585127308, 88.48454475402833, 100.309690660046, 99.26411228795206, 101.98558607409078, 99.5351480668591, 95.11987716920915, 94.6987009048462, 97.13150393578314, 98.83303596127419, 104.94900734193864, 96.45526378385483, 90.69370992722051, 86.15549625888949, 71.31785238942793, 56.28745148258825, 58.598229577464444, 79.02541175965341, 80.41058894126647, 72.15633746116393, 77.97591101738715, 94.30948411264728, 56.83830130484797, 54.99529330961166, 102.50693182791434, 87.48351666235155, 87.15217836441533, 88.41549534951487, 94.57327919621622, 93.37980393440493, 87.11953639984132, 86.98571297430223, 98.20395838829779, 105.51349132291733, 101.68435588959726, 85.9422605268417, 91.87704978450653, 99.26269238994968, 99.65234848760791, 94.46160147267004, 85.58379511679374, 57.787154028492594, 18.429379809287287, 1.185222962690938, 0.026559820173368342, 0.398595363142029, 0.5750021230309241, 0.5801665362331175, 0.6044664161820567, 0.12404749245052377, 2.222925828349206, 0.13172868068420118, 0.5622984240612676, 0.24297094453246365, 0.040604728424260696, 0.02303679822944105, 3.4810383185263607, 18.856019935300274, 38.404047950621575, 49.01675393504482, 44.93822636142854, 40.45273719295379, 36.895590674492624, 22.91983469840019, 40.04161788571266, 77.03089437177105, 74.88997843957718, 87.40752466263311, 99.81110249796222, 87.6151200263731, 22.36425057534249, 0.3039524626106985, 0.03161905141877792, 0.06450472579848382, 0.1009561391847749, 0.052105416543781764, 0.024563375890495318, 0.0032462427559714286, 0.0006668496127766107, 0.15323492908670058, 0.04281314157490288, 0.12766903521673334, 0.019003984991521127, 0.028402483796760924, 0.08413307819395296, 0.023695928788173105, 0.04130741491192772, 0.008702504095591364, 0.027070636109959696, 0.0026202682431997553, 0.022399133454347332, 0.0577954120273071, 0.049982200031198805, 0.06877900611969733, 0.026204043195673057, 0.034087001751627655, 0.036861799026448885, 0.08377016702246282, 0.07721520464627013, 0.07628903498933201, 0.1265079600195731, 0.04310705120705309, 0.029089137979392565, 0.04144320399650643, 0.04513554477823838, 0.03730074059398424, 0.1233270786882889, 0.03898608040124659, 0.0988214428446466, 0.28054314455197704, 0.2026012672051307, 0.24873132817447188, 0.17616292942435513, 0.1264660779927527, 0.18832003998179592, 0.21599600812600506, 0.21327915391133678, 0.12625485989114932, 0.2120743274328209, 0.12292740295731253, 0.1287613157182932, 0.19528960148172994, 0.2156762430264104, 0.1287829347195164, 0.13531185776716279, 0.1619490566513231, 0.08732577260102957, 0.14547962184634902, 0.1676158549925012, 0.14427487197662556, 0.22675494693460005, 0.45518293796527776, 0.3656777294893419, 0.21336854105034184, 0.13403474323211179, 0.20367610388465468, 0.15913262632825684, 0.4718793033351822, 0.24123558684462504, 0.28234173513708577, 1.6378039289866726, 42.663204593043176, 140.90404110570108, 122.12211670414095, 99.95433961191486, 101.38182347820651, 31.775309039700417, 23.57152669660507, 25.12582079056771, 58.557899767352694, 104.57140861019012, 70.83997434185397, 58.25771685569518, 36.61577270876977, 7.471996036268051, 0.3722843798177858, 0.37532755684468055, 0.320944783067511, 0.20754434228424104, 0.4903038711317124, 3.8223926338457295, 2.4334357582753707, 1.5770726458680246, 0.7026783977785419, 0.33765938133001333, 0.6403002707708267, 1.414871852724783, 2.7886934049667853, 3.5650037613607224, 19.345323847186183, 61.941465716208185, 95.25422619235133, 103.51011722318589, 102.20639198057114, 104.03359674638318, 93.69470750131916, 91.65238426577662, 93.02948920957505, 104.32493471330213, 101.88838189648044, 105.02108481622513, 106.34504948892902, 101.47602312026486, 98.0178419236214, 101.00502490997316, 100.9393487438079, 107.34112754944833, 97.37126273493614, 93.18559169769289, 90.29404394088253, 76.11167907714844, 61.299934617934696, 63.669975803744414, 89.4954336843183, 90.13943195343019, 79.74873604313021, 85.38951227741858, 106.40062162953039, 64.7124162797005, 61.97635912126111, 106.83541636313163, 93.85753293191233, 92.78020689564367, 93.17700955175584, 98.37169462634672, 96.75643905516594, 93.14581101940524, 92.47616829410677, 103.7427451533656, 113.41530999829693, 102.92780214740385, 87.58430588629939, 93.05766751689296, 104.65044436916229, 107.81032146946077, 98.22629236405896, 87.39713038167646, 57.725859149809814, 19.07195229684153, 1.437274592538034, 2.2974170311804745, 3.9745546108292, 2.551288273065321, 2.896555397779711, 2.9668861915988307, 0.2997736981318843, 3.109636196205693, 0.26657892451170956, 1.1660385276040723, 0.7221543752858717, 0.10219184666751854, 0.16655379665955422, 7.153590283086223, 28.803844951814224, 64.6631669998169, 90.82374434317313, 74.29620219815162, 71.8088468428581, 53.55341042241743, 21.992768779877697, 30.567095471966653, 68.61806931034212, 83.24459552764893, 93.63693883342128, 118.74494029629616, 96.53022027784779, 17.64184828727476, 0.4581524786208907, 0.148349586393564, 0.15610316227520668, 0.3310208617439193, 0.24118605159944106, 0.24149052558406708, 0.07997697459593897, 0.17873597361387747, 0.18823963139326344, 0.2177887457993723, 0.19157992796071116, 0.1807300238719871, 0.21733417986862122, 0.21929591653808472, 0.24771742612844516, 0.24388782920375948, 0.1833250547849363, 0.06820565059540734, 0.12184070723672068, 0.2426767208042645, 0.17429451758582748, 0.21990967553950128, 0.2393014599839526, 0.13451098945112, 0.15148832522813352, 0.1911866797074195, 0.28233784341043044, 0.24935133845335056, 0.22789802672641896, 0.31406071697992666, 0.1448448720358072, 0.12970366515219212, 0.15221381049242713, 0.17164979821010945, 0.08669866068709282, 0.35501945463399737, 0.20351597618672157, 0.1599177745200934], [0.08269374454093557, 0.04959523369888625, 0.09371398827962338, 0.0731104059565452, 0.04934775665582669, 0.020194152377605922, 0.05448741372674704, 0.014592138261744573, 0.03625108905497097, 0.027155518651969975, 0.05271660915065197, 0.10915942399972871, 0.11524346446798694, 0.1358559027674698, 0.04342057269006487, 0.036860864399181265, 0.04723879703951459, 0.02748324723553754, 0.0233039062755603, 0.0666785232662674, 0.039277527060720234, 0.11568959577069168, 0.1614686429140068, 0.11715519857863266, 0.07384870021093277, 0.01962673020428948, 0.023367786517126427, 0.04245178939233865, 0.107546862545273, 0.08271087426692247, 0.6102463963531679, 26.7482856781252, 100.32039088587608, 97.86803876200031, 89.6568392169091, 65.47009268114644, 45.02649537978634, 42.94334811549033, 45.65823624210973, 59.425555506060206, 70.1993336216096, 55.660131131449056, 40.71977215428507, 23.43129607938951, 3.3703585930408972, 0.11026467436984663, 0.14627281396139055, 0.05549133747756001, 0.09379332434506187, 0.00956964188991415, 0.14973366212460304, 0.03283372787278026, 0.09875514559567937, 0.0570878072551662, 0.17119541614046022, 0.10197914235534207, 0.060722561207629984, 0.5064511353210096, 2.333016217716279, 24.689984667685724, 66.54932498931885, 92.94572307217507, 91.72144935977076, 90.24336691825621, 87.4365266676872, 80.19594900069698, 75.08968199453047, 79.82271978932043, 94.14956123598161, 91.75246746309342, 96.87602427697952, 92.01953380338608, 86.71048810405117, 81.22864630914505, 83.56849701173844, 87.92403021166402, 91.66725789347004, 91.72883126043504, 94.30577355046427, 88.21650566593294, 89.23297220660795, 89.11344974271714, 75.16991799877536, 33.74957130801293, 57.98073868597708, 68.78322462881766, 77.74406756124189, 82.80260716715168, 73.09537641463741, 33.57624569246846, 71.89073024257537, 96.13554354636901, 78.35714186391523, 77.38330364227295, 75.56096261547458, 79.53837148604855, 81.40170128114762, 90.63451351657991, 97.5884129924159, 100.00416155784362, 96.12296842759656, 91.24852918809461, 83.46551910523446, 87.83967571873819, 87.8108149190103, 82.72807428913733, 85.65694732050743, 96.13030325981879, 94.64918490379088, 79.2797774653281, 43.182181235282656, 19.19232983742991, 1.9078831398679366, 0.3756523168375416, 0.6230104630512576, 0.40809610978730265, 0.3261395946385399, 0.1245241906614073, 0.4568492711311387, 0.07213502281135128, 0.19803815641470496, 0.05578970957186915, 0.23806257323632318, 0.12884362420487788, 2.978467970125137, 15.496391231013884, 35.96096438746299, 54.51656410771032, 57.291013425396336, 51.90688179385278, 68.18216062361195, 40.35532512972432, 13.27535794627282, 44.217765408177534, 66.81505772375291, 67.44582976064375, 85.75370434791812, 76.71934050898399, 21.951672146397254, 0.4469412721453175, 0.058801285471887364, 0.015642539609313732, 0.04398684190105527, 0.09093179442589322, 0.07259705043848484, 0.042785738609851375, 0.08151025361111087, 0.0092054235809032, 0.028955266029844363, 0.07213153711129582, 0.05510859995058948, 0.05017182594465633, 0.04416863839592665, 0.032021048396164854, 0.02662411601763339, 0.010217296451540485, 0.06769374298352389, 0.028186946874484423, 0.12583963257531006, 0.06799073995000894, 0.0416284708696748, 0.0381735828705132, 0.03822742736027126, 0.043742440701011694, 0.06404439505610256, 0.10889739894698705, 0.1663099815167727, 0.05154001684258542, 0.0117763840112715, 0.058057785650054296, 0.029000696958974007, 0.04476558942828448, 0.08621986339529676, 0.04827560894491692, 0.11119743238293356, 0.09352199898491945, 0.09132898803199492, 0.024395328758644964, 0.06354970143987768, 0.027182050192007617, 0.044259576862978364, 0.024325388761597778, 0.024637326357826114, 0.09231928690907457, 0.04619240520461913, 0.030824535886847207, 0.059683152264164346, 0.10372694897195024, 0.04951091423150032, 0.07406591678098326, 0.008410963590347, 0.06739735122649901, 0.03292399601289823, 0.02551349728638607, 0.014506092223699295, 0.06509727182527704, 0.09838952247293727, 0.07187033943351238, 0.07818930076375123, 0.1052443776279688, 0.10318547036618957, 0.016971381358622063, 0.04481376103696324, 0.10668429350780864, 0.08561902063628359, 0.1124638676523201, 0.14926219629424234, 44.661075607422866, 125.1120767285747, 107.23265047996276, 108.72151159471082, 78.7238520960654, 71.38792945492652, 53.51222161323794, 28.967513691994455, 39.13531503369732, 49.108239296943914, 49.06314772944297, 42.607973698646795, 29.154642128175308, 4.240351819222973, 0.26557191725700136, 0.02835820008429789, 0.037036731373518705, 0.053395137055626804, 0.0404119040937193, 0.1458164094196212, 0.023176517345071323, 0.17874323612739965, 0.4123430254478609, 0.19625972926376328, 0.28800692469362293, 0.06803474404037961, 0.4574460536241532, 2.853701542462072, 26.836582153074204, 71.7109993965395, 95.42368827327606, 92.91363808416551, 93.94354266505088, 90.44442761328914, 86.30136920559792, 76.71920714839813, 81.52003134450605, 97.20577009262578, 97.98435272709017, 98.02168584639027, 96.37753025177987, 90.91985025713521, 84.42930036975493, 85.82697422273698, 90.81968076767461, 94.68228186330488, 94.87458782811319, 96.2864528163787, 91.06052214099516, 90.19345868018367, 90.4598189938453, 76.54652872393208, 40.190801312846524, 66.89075162333828, 75.4796205028411, 81.18325664151101, 89.99322168288693, 79.77733012168639, 40.580057328747166, 75.69424475392988, 99.38060668206985, 83.28374078196865, 80.40270497722011, 78.57415091606879, 84.56792477638491, 84.15302430429767, 93.53305878177767, 98.07620679178547, 102.56061338609265, 95.23921920407204, 92.19518538444274, 84.81787389324558, 88.70301292788598, 94.12931396115212, 86.74313791336553, 88.447980419282, 98.74047586994787, 98.43357393818518, 85.01644780558925, 49.159673337013494, 24.515392126575595, 3.0659860997430743, 0.12112156518044011, 0.5760628790143998, 0.18393775658501735, 0.608244700537574, 0.2797586398739969, 0.4183515143250266, 0.036067189648747444, 0.28521575995029946, 0.18848067329775905, 0.2465095506199906, 0.04280715076733501, 3.117317177595631, 17.76977050688959, 32.91382405065721, 45.795895745677335, 35.08525994516189, 35.82099460786389, 44.990527245306204, 33.970561565891394, 21.845534770719468, 61.39799779461276, 84.60656796732258, 73.97761160327543, 93.26747509741014, 94.45439215629332, 48.33296714290496, 1.2915445671927546, 0.08494651801283322, 0.061108757621578635, 0.06421655416488647, 0.09652726998132083, 0.06356372084889202, 0.008258662438170325, 0.00963982416226739, 0.040709207495374065, 0.09198079095973123, 0.050397871678034147, 0.02868209248258462, 0.04264570539817215, 0.0762806386656819, 0.012882106483072765, 0.07768268681942456, 0.052499021027958205, 0.05754759024468161, 0.02466938330701763, 0.018258240532069918, 0.024497342941861962, 0.05331964675156821, 0.05776648454728627, 0.01680881941630956, 0.023896846837634524, 0.08378175793275719, 0.08203259534052304, 0.05906159831811825, 0.03291269238557547, 0.028786387692596165, 0.05118446777604761, 0.02988391015077791, 0.021706812136295824, 0.035559277185389114, 0.055766160029076764, 0.1629495368369164, 0.05221840685173389, 0.3336753257580342, 0.22338406813721504, 0.19179722113955408, 0.15769644129660823, 0.18455701609773023, 0.14973962228865395, 0.19878486231450113, 0.20535359129069314, 0.16031538947455345, 0.1241008121700537, 0.23141761851166529, 0.25817644151468433, 0.23205955422693686, 0.22340740317538862, 0.25332918871314297, 0.13284252656082954, 0.14782420329509244, 0.14402011709828533, 0.07659360090450895, 0.20159980642699427, 0.1368085024577956, 0.17872033009846366, 0.12223955559273883, 0.21896222396002663, 0.2843616944887946, 0.14637554635203656, 0.18393078518490638, 0.25036441312441904, 0.17993830264576022, 0.1675383728598395, 0.7901331566033826, 60.78330355305826, 143.53317445324313, 120.75322520348334, 116.65441113133585, 88.35157640518682, 60.34819110747307, 61.45968883268295, 58.7106760855644, 80.0005522081929, 98.94487057962726, 78.28438189721878, 62.480779847791126, 37.88857398494598, 6.40444552706134, 0.3013948933972467, 0.31549939945820843, 0.30548414816298797, 0.22417641755553985, 0.22985377258831458, 0.31820690740020047, 0.19042943243778523, 0.45895380658968804, 0.7812894376054887, 0.39959857060063275, 0.5361142742537683, 0.4953621351911176, 0.6875920427903053, 3.8284262197632946, 31.377231613282238, 75.7326369131765, 100.54901799848004, 97.15483419356808, 97.64495003607966, 95.32043580086001, 88.87241225088798, 78.70416964254072, 86.11042822560957, 101.33772034798899, 101.92508743655299, 103.47307435927853, 101.99566656543364, 94.10147297766902, 89.77731089438163, 93.54135067232194, 94.15304430069463, 96.01896286010744, 97.48169314476752, 100.6983426309401, 91.72401458986344, 92.56780270607241, 93.034313724887, 83.70005330731793, 49.102124321845274, 75.27960315827401, 85.12171637627387, 90.04965674492621, 99.79859013711253, 89.262860667321, 48.769930947211485, 82.44220410623859, 106.89222797270745, 86.32367964713805, 84.01682392243417, 80.64027509381695, 88.15897234024541, 87.21217493857108, 98.53075458157448, 103.42222475236463, 106.22683709667575, 99.4563711843183, 96.08961259165119, 85.98212749727311, 92.1547535927065, 100.0298217035109, 91.50021199257144, 94.82446778205134, 105.99746473373906, 102.6630735397339, 87.17985460835119, 48.76776579887637, 26.283298500122566, 2.7120826513536516, 0.8434578403830529, 1.410342495768301, 2.2314091795875184, 1.6851295314488874, 0.6645519178240531, 0.93453650152491, 0.22064113628960427, 0.6497040919719205, 0.711745324154054, 0.6396130592592302, 0.23243977898551574, 4.943329297727154, 26.79782129103138, 55.34646703350929, 73.6397700155935, 81.18364887852823, 72.53047666242047, 87.05431522861605, 54.2762993228051, 18.27263797483137, 60.63769732752154, 88.73857313586821, 84.81645399524321, 104.16354487019201, 109.83089124002765, 44.70269587732131, 0.9744781808507059, 0.11238318327213488, 0.15612928587342464, 0.2536769160219739, 0.36889444075284467, 0.18484953911073748, 0.08791587480734434, 0.17668722467797418, 0.15949428111555117, 0.2061168140461368, 0.16698548720488626, 0.17284065124488648, 0.16400209567960233, 0.22096111589381773, 0.19139307911597914, 0.1386431298188625, 0.10738927059836927, 0.14132518832000995, 0.08224918371847562, 0.1837929966108453, 0.2016351230803036, 0.0881399785078341, 0.2681505385666125, 0.15396884131816127, 0.1380253718384812, 0.24216653689021067, 0.25353598648742326, 0.2001426152644619, 0.1768759887425169, 0.15397057267687014, 0.1331122507972102, 0.06435280290221976, 0.14859389183261704, 0.1495204598552758, 0.1547784277147824, 0.2728568618336032, 0.1871062655963244], [0.12096136853459383, 0.01890135027708546, 0.06425108940851304, 0.06059233009094193, 0.09534439958271482, 0.04632558575981567, 0.025407181519474235, 0.08072993177319727, 0.05136312714086906, 0.029918366870392236, 0.0625850779995803, 0.07608676479468424, 0.03415787254550284, 0.09172399062663318, 0.05510435582348897, 0.1584603228876668, 0.03848229332136051, 0.039383565120759516, 0.08148273573287072, 0.04515164028552752, 0.09542578876379038, 0.20066648150884336, 0.040126046045653285, 0.08814033090827927, 0.0883589494192312, 0.12822993415137454, 0.04446567366680792, 0.09153962390677584, 0.11428780042596402, 1.739568597366733, 45.00545578618204, 115.59457102129537, 89.87165958650651, 95.92583010273596, 67.03755809414771, 35.85609589853595, 20.383485017284272, 24.189468660662254, 70.32175079468759, 63.15564324778896, 46.9187879562378, 38.397662331981046, 21.5216411313703, 3.0045571250300256, 0.14126805348261712, 0.13308088715759017, 0.022555323460349636, 0.05116523130826893, 0.2149514932065241, 0.1549282438692547, 0.07636439505844347, 0.020012698707080657, 0.03670624104298411, 0.08858263177136261, 0.09257308417750944, 0.3950640042462657, 2.0430792723932574, 16.432211879760988, 47.79347650466427, 75.17555836708316, 87.05019673993512, 93.0402365038472, 90.65028928941297, 86.00865056437831, 75.23111481820384, 71.38459544028007, 63.97537939010128, 78.71887853068691, 90.83256183132049, 91.94570695200275, 89.41627240950062, 79.21863555908203, 72.42211726404005, 73.06613122263263, 76.6361705718502, 82.69791910725256, 84.14193968619071, 89.09844275443785, 87.17226874443793, 89.99459451244724, 89.41592724092546, 86.38747307562059, 92.58613586425783, 73.96986099981493, 37.84045827004218, 60.30736315634943, 71.56295345675561, 80.05564581963324, 46.06195795920588, 54.14369183201944, 93.79356691914221, 87.43833880270682, 77.4370793373354, 70.4994341634935, 73.91770132126348, 78.03899057449834, 87.15201362486809, 93.68430537562217, 89.85498951327416, 90.84115182199787, 95.75993737866803, 91.36640425651305, 86.18343922399706, 85.57401272558397, 90.30632095952188, 79.35369060885522, 75.91545858690816, 82.2407982426305, 87.13982289837253, 93.20986332431917, 95.41556112227902, 90.5076797546879, 63.66620248363864, 26.204484355065134, 7.2797719509370875, 0.7575359315641466, 1.0694277310563673, 0.43480058651297326, 0.12074087310822741, 0.10455925753640552, 0.08863323953964057, 0.06373783731232248, 0.06595942717526229, 0.0950842437845084, 0.07098524741107418, 0.3756639920175076, 4.7496843338012695, 19.741781334723196, 52.34141372865247, 70.20753922001009, 67.53340844185122, 73.38638490246188, 54.53096312861289, 20.891265253866873, 29.659741424745132, 55.09778876458445, 66.41784714114281, 69.81631417428294, 86.85744362492716, 30.90369562948904, 1.262588159691903, 0.18429967184220591, 0.08663443953640039, 0.05044105988476546, 0.047503204625700755, 0.032385179562674414, 0.05523059945253115, 0.0541599762565907, 0.03817506142020707, 0.07056096493596993, 0.03877456352535275, 0.03068399705713795, 0.05100903364138738, 0.04470159044309009, 0.0890154944312188, 0.08045976320582052, 0.05192060549292834, 0.06622250942933945, 0.020047408235709996, 0.025170851055712953, 0.041942815897205186, 0.05309680326571388, 0.039344372062553326, 0.0518512285705055, 0.10322016648828022, 0.05451365989903289, 0.08628413817214389, 0.14285575538392992, 0.021901388892964013, 0.01564109649118637, 0.05782056269386123, 0.04722455546500222, 0.031143670879124157, 0.04725623320067122, 0.05934974696907786, 0.07772948713071885, 0.03225824262406076, 0.03361532141664817, 0.05251078430803553, 0.04737214996449409, 0.030635741178787528, 0.05880845222441901, 0.05759490000444555, 0.10119917291787364, 0.02452207800571717, 0.1022900591394113, 0.04775862983097473, 0.09132528782732065, 0.12453938984582502, 0.024874147117858934, 0.039232465769014055, 0.07209911627034027, 0.035534980706870556, 0.07124685877633673, 0.01227462940263532, 0.14249953982089797, 0.11879582183375476, 0.09337253523089233, 0.08687758818268777, 0.04867889295001665, 0.05498522915126336, 0.0940211282502259, 0.015423825337371279, 0.06535760382370603, 0.08873597959116583, 1.402787397946081, 69.70819011811288, 136.6098145515688, 101.24872176877915, 114.60905982602029, 82.43773260424214, 66.46938708520705, 28.650191983869, 25.915823405788792, 61.669410121056345, 58.801251457583525, 49.881444361902055, 41.81930272809921, 26.494390656871182, 3.6871240600462887, 0.11672241252756889, 0.0716614272565611, 0.016980762105254878, 0.07784304434373494, 0.3239053451726514, 0.6722005396600693, 0.15276680339968976, 0.1582251032513957, 0.14990037817868496, 0.1066315406933427, 0.2654279233707536, 0.2344688547835235, 2.032953428645288, 17.475078913473315, 49.20027771303731, 74.80683203666442, 89.31152159167875, 95.28493835080056, 92.17012143904164, 89.20036162099531, 77.9886822546682, 75.02292325419765, 66.70578049075219, 80.8078936607607, 94.12557986474808, 94.37191255630987, 93.23702181539228, 83.90042366520052, 75.60028829882222, 74.37820326897406, 81.08726055391374, 84.72262305598106, 88.77426670443627, 93.62161021078788, 90.29088251052364, 91.55002609375985, 92.57259584242298, 87.72140056856217, 92.70179087115874, 79.80152330090924, 48.58145713806153, 69.60358835035755, 79.1505196786696, 86.55908461539977, 54.32554468031853, 60.73734121937906, 97.99847325971051, 90.6974361788842, 81.2354398542835, 74.79059342415103, 76.99212566498788, 81.8263449207429, 90.62697472110872, 97.41888030882805, 93.06576328892862, 94.60295584893997, 95.5139498556814, 91.31993201471145, 88.33398849733415, 87.64143913022934, 94.188016153151, 84.22026941853186, 79.44238324319163, 86.78631536422238, 91.43523400829685, 94.80076097672986, 100.25680142064249, 94.38629196536158, 72.481549016891, 32.96379504665252, 10.819810071299154, 2.1850739755938133, 1.839832591433679, 1.0382571455932434, 0.34667473466646287, 0.09026912071051137, 0.09832634320182186, 0.08588091545407811, 0.07457809252364021, 0.07243899117794729, 0.11552386030915285, 0.5008419314699789, 5.93586104531442, 21.20982054741152, 48.756740016321984, 50.65184493218699, 60.61004854017689, 59.705852000944084, 35.029319101764315, 33.87200024820144, 46.31033420562745, 77.65203306751867, 78.42626971583213, 77.36115009553971, 96.28067908748504, 59.1032112029291, 5.162584887396905, 0.10011243889288557, 0.03528800928184102, 0.08412655878571734, 0.027201173661817468, 0.01994042788752385, 0.03342664545221675, 0.01437995105891699, 0.020937634962460688, 0.021192537312726342, 0.03967149543666071, 0.08324794020623931, 0.045299066245676055, 0.061366438955789616, 0.06246243498378223, 0.010374373204315142, 0.04500940840150561, 0.05613731430663217, 0.03013139485471672, 0.05878279210939523, 0.0313261951575236, 0.05212500541200561, 0.05389795120384905, 0.033937890398045706, 0.07095204516043586, 0.10453466611403613, 0.020848314856149016, 0.04791585022523519, 0.007365121423537213, 0.022439655675102147, 0.029768242365530426, 0.09603007891846281, 0.05123374255133733, 0.03661953904215367, 0.08675414077456921, 0.15215059291691552, 0.10819259039576977, 0.1460263634761495, 0.22685162723064425, 0.2012887747297364, 0.24737077134270824, 0.18398030510833188, 0.15153554688778617, 0.19648036258595605, 0.12178144267489835, 0.199058095233575, 0.1398499787694985, 0.1923850097603375, 0.17092792888081845, 0.17979630058811558, 0.09524211152306489, 0.2692816520650541, 0.12965477342086454, 0.16488689658862932, 0.12247021700586043, 0.20937979702026616, 0.20433697729341446, 0.25617687542351986, 0.23033979408923658, 0.2062706751448493, 0.16648288756128282, 0.22742124424586374, 0.15921511867594335, 0.19579970878699135, 0.3402699944713424, 3.8025753488463745, 86.07240476915914, 156.6923184548655, 112.91759260239141, 123.84002070273124, 86.81707459111368, 54.38938517724314, 32.19732861365042, 36.766140691695675, 96.64010155585505, 86.7929441698136, 64.66825039156022, 60.122850941073516, 36.278644992459206, 5.746560106354376, 0.38866867161085533, 0.2643582194803223, 0.14194265518698002, 0.31799801054500765, 0.7935549955694907, 1.2536832762341346, 0.40538982758598946, 0.3316028434182367, 0.35322625730787555, 0.3484843262741643, 0.6063830455945385, 0.6157076226607446, 3.5917474617881164, 22.471756858210412, 58.127274513244636, 79.60305921493038, 91.73859796216412, 99.92993462470271, 97.27462337863062, 93.38504422095515, 81.36598417835852, 78.39646754726287, 70.71879663775044, 85.23620251686343, 99.05206111169632, 100.41786962939848, 99.66277414752592, 89.9384653952814, 78.63876019754719, 78.93101599908645, 85.80265552766862, 90.14499387433453, 91.25646022058304, 95.99469123348113, 93.10213934990668, 98.03607310018232, 97.50940076766476, 93.10039781755017, 97.7620876989057, 83.69960615711828, 55.73261653223346, 76.54215920356013, 89.73546704938336, 94.84393058284637, 62.07472039807228, 67.55802523705268, 102.87489721851965, 97.09567700662922, 85.65320537936303, 78.49467585163733, 81.01520661384829, 87.076962993991, 96.5081294890373, 102.11816218591507, 98.22623745087655, 97.71857292421403, 100.32756882329141, 97.49710805954473, 91.75846084471672, 92.05720424652101, 99.37639405650478, 87.88596753151187, 85.33265359940069, 91.5081508698002, 93.8797963050104, 99.96056049100815, 101.89417915959513, 101.07553343619071, 76.45979727468183, 34.49008341758482, 10.79446469583819, 3.8049630916887716, 3.1158659006318743, 1.386941390172128, 0.47931630104299516, 0.3199946501803014, 0.5006961296162298, 0.2520065532336312, 0.24693719622108246, 0.3407052243428846, 0.1835815410219854, 1.2566016422164057, 9.6798369192308, 34.394695297364265, 76.07569525318762, 92.03119893227854, 91.29795105226579, 99.2430805390881, 73.02992774594215, 32.11503728743523, 41.626055394449544, 76.26224317858296, 85.66817314394059, 87.6260869733749, 113.83488593562957, 61.17963944711993, 3.5462817982319867, 0.26118462364519796, 0.3595055735880329, 0.20545226341534048, 0.14124929965023073, 0.11310373493019613, 0.1640167126371976, 0.1703888940955362, 0.09317078597603307, 0.10776330536651997, 0.17317734688760775, 0.18335626520697149, 0.282392603375258, 0.13773625025585776, 0.13450792509942286, 0.16981538535366136, 0.16375912323353753, 0.1806834916914663, 0.10807191622593712, 0.09077272392929563, 0.09555271421108516, 0.10240661941709057, 0.1568433257841295, 0.08298514906557337, 0.3111937401756164, 0.2789920922969618, 0.21056439877758104, 0.20128131303335392, 0.1236424464431982, 0.09537989243624673, 0.11199910509129686, 0.23837351300303014, 0.15686635438713337, 0.17521946150208675, 0.19503994874896544, 0.24267347259146554], [0.04806847026151034, 0.02746882563036296, 0.050963600797037927, 0.03455446477258398, 0.02553662739603991, 0.06248179785606842, 0.03620069196087219, 0.05768233361924368, 0.016298608689178384, 0.043418178665301496, 0.08667727151224691, 0.030169151498064883, 0.06157420966173373, 0.029489049282405647, 0.09377349032870225, 0.037107307223543044, 0.042106973217620004, 0.04632714474874158, 0.05797177695879533, 0.0693326348799371, 0.06089567792631927, 0.10970553743743128, 0.01912207169938953, 0.025412911857147853, 0.05432077045101793, 0.05882693792603189, 0.027478346188041954, 0.17038898602608712, 4.115542000339878, 40.355332974464666, 107.74279394457417, 86.52983942339498, 78.82914420097106, 47.453822781962735, 37.443714449482584, 19.116545723330592, 80.9695266908215, 118.27414604925342, 50.460641153397106, 62.131159382481734, 40.71661464629635, 15.114538688813488, 1.034840761173156, 0.3579471056019107, 0.060883389876013806, 0.36001266250687264, 0.3916721039962384, 0.04899392745667889, 0.04712128681280921, 0.06077933215325879, 0.2209493334615423, 0.10338512820101554, 0.3068376110205728, 0.5020611144361958, 0.5343868379150668, 16.464295887177993, 58.98461049602878, 88.54592984722507, 89.80858002939533, 77.70069399187642, 85.81245360835906, 89.43166379005679, 88.30416279454386, 81.62868884301956, 75.56211579230525, 68.70687177104335, 68.46319060171804, 66.76019160978257, 76.31233184568345, 75.73772814966019, 74.46866881462836, 66.56408094590711, 65.87179829997402, 67.46202130471507, 74.89514812346428, 80.33018035273399, 79.08338439080023, 85.3408827320222, 87.23758405254733, 87.26609968370008, 87.47993161601406, 84.99230169480848, 84.75858334572085, 85.48970530110022, 74.59456905241936, 30.440475479249034, 61.8515375352675, 60.10387843655002, 46.80037944547592, 88.21290493011476, 84.09498891522809, 80.92741612465151, 73.24856065934705, 67.8726307038338, 71.13669380064934, 77.30956308303341, 85.58819601612707, 89.76377871728714, 87.34661809859738, 92.10155840842955, 88.50720820888397, 88.25536066485991, 88.7519641076365, 87.21339871806484, 83.44070619152438, 76.83658015343451, 67.14519577641641, 73.51712534504553, 84.10433984571888, 86.91307852345129, 86.99200445605864, 87.55315442239085, 92.92629949508175, 92.19997852079331, 58.08761935080252, 8.97736297499749, 0.6122525661222397, 1.0468753283062289, 0.14853550061102838, 0.05546580376704374, 0.33301547890709293, 0.2258493697210666, 0.043523312741590124, 0.3285124447316893, 0.11517529030360522, 0.0630011173686193, 0.04952705187362529, 1.9886191237357356, 8.20193196496656, 28.73280690562341, 47.82014862183602, 47.530575721494614, 60.54760832940379, 56.0897248022018, 18.563903377902125, 21.88346212910068, 43.59168844838297, 56.10055054387739, 67.43881656277564, 77.07578982076338, 60.56915390876032, 5.682679895431765, 0.20119089933653034, 0.04645416595702691, 0.04444975819018099, 0.025025600785269372, 0.04892086948177988, 0.012810678360232664, 0.0768516346391651, 0.03337136837804029, 0.03243115249901049, 0.04686574286390697, 0.10553841749506612, 0.046530165709555156, 0.07421207103517748, 0.04744933332286535, 0.07091816109154495, 0.010308815230194841, 0.024962867760369857, 0.032498656336458466, 0.041761233906952605, 0.08533797362038205, 0.05181347958803658, 0.06602513453652782, 0.050144005461686084, 0.027340297144086614, 0.05939363231582027, 0.033905661079071225, 0.07662907077540314, 0.08391000871216098, 0.08978909001715722, 0.06145893258132762, 0.07713743906107641, 0.039591872088250615, 0.05671790553136699, 0.04859210667951454, 0.06945822733424364, 0.042036247980450435, 0.024616686033926184, 0.08569404362670838, 0.0763514941377986, 0.03825114544240698, 0.030129801391834216, 0.061921071291210196, 0.0491482405472667, 0.0401523764876108, 0.021989873963438218, 0.037351076401049094, 0.12461281937336731, 0.044693910411649176, 0.09374647040761287, 0.02343820340390648, 0.04780631114338194, 0.03993035271583546, 0.05159074335449165, 0.0390362476689681, 0.09748436660776216, 0.055500235588800524, 0.06783605147633823, 0.022037672104253885, 0.1233176634676995, 0.0708987867279399, 0.07307358011002503, 0.08889542547084632, 4.312584717427531, 62.01612411006805, 124.17991761238345, 95.65113083008798, 89.97971304001348, 65.0603501258358, 68.90566533611667, 29.57333160984901, 72.29555806806012, 77.66915029095065, 43.12214935979536, 58.809794379818825, 44.33427549177601, 21.148382502217448, 1.6201608628034594, 0.46643064086956365, 0.03677632276629729, 0.5017407977532956, 0.7740621641278268, 0.053910687415590214, 0.3143649764599339, 0.03752035118879811, 0.5092563347951059, 0.17460456869054228, 0.5799800397888307, 0.8717771078790388, 0.6617786795381577, 16.424161214982313, 61.08011322636759, 92.79146409803822, 95.10916125389838, 82.4166145632344, 86.93702851572345, 92.05438013999694, 91.9826086105839, 86.4133293397965, 78.53415842979186, 71.16520158706173, 71.64352678483533, 70.41649172382971, 78.91629926619991, 81.14741402287638, 76.81972965117424, 69.4409433487923, 69.69155142384191, 69.99475848290228, 76.94955225913756, 83.01740400252804, 83.58674387778007, 86.52420689982753, 90.23556924635365, 90.65502751258113, 90.17332123171899, 88.37775430371686, 88.78232325277021, 87.42792883226949, 78.93697015700802, 38.73451548237955, 70.2602009619436, 68.38625723315825, 55.160534920230994, 89.66579006564233, 85.7774111532396, 83.74545081969231, 76.9902664615262, 69.37113300446542, 74.6490272398918, 79.37743663787842, 88.34315115405668, 93.81084888212143, 88.54227419822448, 94.58185349741291, 90.08327930204331, 90.91903440413937, 92.52141675641461, 91.46780537020777, 88.4155502626973, 79.15722693166425, 71.33652287144815, 77.42706944865566, 88.49447619530463, 87.96763127849948, 88.87088252652077, 92.29392713116061, 98.0443806802073, 98.19729035900485, 66.3048436564784, 11.061053487562365, 0.5295713317971076, 0.8623058709406084, 0.34287215000198734, 0.18152854795898163, 0.8523538985079335, 0.10326430847447726, 0.09963465283714956, 0.1492571554357006, 0.08941321663798825, 0.07925855266230722, 0.012349778797567613, 2.1801531170645068, 10.182186634309831, 30.18695700553156, 41.517833279025176, 42.90850570124965, 56.17927251323577, 47.40962159249091, 29.36338870756088, 37.64603814771099, 61.077979456993845, 74.01675685759514, 75.43535263307633, 88.74239352441604, 88.7488889694214, 18.78084574976275, 0.1986781156231319, 0.050181758274594625, 0.03907396217748042, 0.039594296756530964, 0.05130479337587472, 0.08370946987622208, 0.07219714488113119, 0.03998990839106902, 0.05230417422529671, 0.040230030990055496, 0.08766550961281024, 0.031577094698384885, 0.03856708776325949, 0.06808879920431683, 0.026371573218174522, 0.047748107613334735, 0.02223174898855148, 0.029473712202161554, 0.0482962588449159, 0.1067700647118111, 0.03057651109092178, 0.06993906241991828, 0.05308736506248674, 0.082781124529579, 0.05440957536320052, 0.04173765372064325, 0.0076645210332747914, 0.0908249098386976, 0.07490099858372443, 0.03600793657824397, 0.016762953732282888, 0.037256215563825065, 0.08616830567799269, 0.07056106452740009, 0.11134842065193, 0.24414688949623417, 0.07729330731015052, 0.1476212053169166, 0.13810593364459856, 0.1262172909393426, 0.18347802722165663, 0.1782906773470102, 0.1301516120832774, 0.10111440528905201, 0.21888961414656333, 0.19702641473662472, 0.15088645591130181, 0.127055597972245, 0.2583966764711565, 0.22810468660487285, 0.12222639420219969, 0.1616257981907937, 0.1526945766301886, 0.09819516596654732, 0.14462672083848907, 0.23765077033350546, 0.15027283480571163, 0.08513557319078716, 0.2367618938367213, 0.2159315494880561, 0.20430089455218087, 0.2371035843727089, 7.0664896407435025, 85.78833887653967, 144.99253149955504, 108.54702887996551, 103.21477059395083, 67.94405706467168, 55.85935223487116, 26.698987368614446, 101.3310601634364, 143.46538020718484, 63.32886688170895, 86.2902924322313, 63.05660340093798, 27.4008955109504, 2.9320204882852496, 1.0162145283914383, 0.1219880565880768, 1.4363175342159888, 1.4655603973134872, 0.3858456988969157, 0.7489488213773697, 0.3263572248960695, 0.5642222240567207, 0.35602805535158805, 1.2418105068706697, 1.7382913755793727, 1.3902097051182103, 21.27829336350964, 73.03435217949652, 98.81075689869543, 99.62660989453717, 85.3993417370704, 89.16022792939218, 94.16702362798875, 95.5149696719262, 89.49787339856549, 83.45420698965751, 74.42731134353146, 73.84557677853492, 75.18428956308674, 82.52662135708718, 85.57382445181571, 81.1588438095585, 74.04054211032006, 71.13867851995653, 71.8922128985005, 80.1776550662133, 88.30479037377143, 86.88118965395036, 90.78356358312791, 92.13173712453535, 93.65287934580158, 93.7174415588379, 92.81452763465144, 92.01605858341341, 91.29253033668765, 82.9258245037448, 44.853640448662546, 79.4514988314721, 75.4770552727484, 61.48385063294442, 95.27714852363833, 91.68151178667623, 88.97237777709962, 81.46582418872465, 73.59989520042174, 78.12654572148477, 83.23431891779747, 94.45117581275203, 99.58676645832678, 91.54532709429341, 99.79553068837812, 97.30096601670789, 97.29031285931988, 97.84192362139302, 95.51118066233974, 92.80651815475957, 82.63888743615921, 76.42604920171922, 81.68103679533928, 93.70525083234234, 93.62046487869756, 93.45407009124757, 96.41414165496828, 103.18117941579511, 104.40874791914418, 72.49810926375851, 13.617770075798036, 0.8790466081230872, 3.064173474427193, 1.0167021893205181, 1.0597854420062036, 0.8948783973051656, 0.5875720324054842, 0.21777221362196633, 0.5071888779920917, 0.30645674274813745, 0.2324795389487859, 0.46831788314927014, 4.359625702904117, 17.989542868829545, 48.45696895353256, 66.46540195711198, 67.72204306817824, 82.02293411377939, 64.32787887511715, 29.313607946518932, 30.405099622664917, 60.7680808344195, 77.04191623195526, 85.90374285174956, 101.24925521112259, 93.82451441980179, 15.856667795488912, 0.56309019125277, 0.20500244722971994, 0.11198150805167614, 0.1495227581190486, 0.20484751360791348, 0.21949894515977753, 0.21633988967345608, 0.10573062129438886, 0.1287125465610335, 0.06577889089502635, 0.18947562232853907, 0.13550932459052534, 0.1995371146908691, 0.1424217818965835, 0.10473779432715909, 0.19979240583075633, 0.0990983683075155, 0.11600662593639667, 0.13131710760776075, 0.22136314351472164, 0.1563238568844334, 0.16576193753750096, 0.20096715569736498, 0.1654416208546008, 0.1791658868352252, 0.22857956918737582, 0.17113947640022925, 0.13029293998354866, 0.23737431984514962, 0.14621171078854991, 0.11792506331637984, 0.16352329072692703, 0.10627458968590345, 0.1612883824254236], [0.01576806694614671, 0.0029649165967824843, 0.07081784187786042, 0.030441105050305207, 0.07428456593545214, 0.05063414085476149, 0.0338220770560926, 0.021781028819180304, 0.03024463797168386, 0.030475295554365844, 0.01229429871009122, 0.010170405167305182, 0.04522652921056555, 0.017305920463836482, 0.04433131716664761, 0.029902135382496545, 0.0643559055583131, 0.04516708844852063, 0.020729140303428137, 0.11230543300869966, 0.10927463596266125, 0.046972213763623476, 0.036192150080516454, 0.07261510713086014, 0.0729735826532687, 0.07608486489663202, 0.48927660851228627, 4.774459004402161, 43.706202045563735, 92.81182904397288, 83.98158534880608, 90.89536682251962, 74.88544417965797, 35.80568559708134, 19.959723910977765, 53.354487419128425, 52.51872839466218, 90.05367325198266, 66.91537626328008, 43.80960356804633, 18.884825821845762, 0.34802550089455425, 0.1300024700861785, 0.03806930298226015, 0.0765170457382356, 0.29169793631280627, 2.0704794795282426, 0.13677245036007898, 0.1338320057238302, 0.11640240227983845, 0.2624019680003966, 0.10930578509766249, 0.1262091474247075, 2.2017533644553158, 30.40510746740526, 80.32345741025864, 89.74222921556043, 82.67867595918717, 82.59170916772659, 85.10834893872662, 83.54848507911929, 85.52148434423631, 88.80083683998355, 84.47524701395344, 80.18477024570589, 69.14568301170104, 67.49533007221838, 64.85215071708926, 63.39660621458485, 65.78687114100303, 64.67987629675096, 67.16934188719719, 64.57629826761061, 61.85028629918253, 66.37310858695739, 72.47453581902289, 75.24503923231556, 77.66384724647769, 82.09184231296663, 86.66981312536424, 88.5023287803896, 87.7710577749437, 87.39979759339364, 78.51670388252505, 87.78883395656463, 64.84594944984683, 27.85968338289569, 34.79873864881454, 75.91651762685468, 84.53391782699093, 75.3153516400245, 72.28842719908684, 65.67737817764282, 64.01876864894744, 70.8472385714131, 76.46526505870204, 81.54496977406164, 87.26312652710946, 92.18128450455205, 87.44798783333071, 78.97453861851847, 71.84615642793717, 81.28774073816116, 84.78735000856462, 82.85887748964372, 68.75416771058114, 64.04503676199144, 66.9624682395689, 70.2952669512841, 77.78896301023423, 77.80947700623544, 77.68476132423648, 79.26076181473272, 79.70438188122165, 81.67426678442186, 56.59036044151553, 17.17120309029856, 2.7721870906891364, 0.8169875414140764, 0.6702318162687364, 0.09443170541236479, 0.1803074650947125, 0.15853244240485853, 0.061924702547971285, 0.057599316501329025, 0.017378363653176257, 0.05498330244013379, 0.06759649578241572, 2.13123919983064, 11.25987352863435, 28.510002551540254, 53.00691050867881, 41.2842208339322, 60.86194315264302, 53.815687548729684, 32.168918886492335, 16.874271823513894, 49.296022768943544, 71.11500309359643, 70.65722327078544, 82.93122168510192, 74.03474484720539, 15.436874166611704, 0.2667273617079181, 0.040627856618694724, 0.03519640431829518, 0.03279546944184169, 0.03302538774967675, 0.062148097617131096, 0.05422836492559122, 0.03982983814973024, 0.068870653218079, 0.02479978104782922, 0.05380267284870629, 0.061298253300089034, 0.0798750389367342, 0.08035908393081158, 0.025621896812451944, 0.05969405752576648, 0.07414294692176966, 0.023759167431102648, 0.02647625913302745, 0.06208270052147489, 0.019358375350073464, 0.02614721862388955, 0.03472825564864663, 0.016143255634233356, 0.018597508314996958, 0.06580090826197017, 0.059301360855780305, 0.007072135406140719, 0.028482928774469805, 0.017418543049584956, 0.025098235496590217, 0.11333388306440846, 0.04157067336622746, 0.022106993485302217, 0.07067443787931435, 0.043442130404254126, 0.03669373082718061, 0.027178547254973845, 0.10039432860550382, 0.03429185749301988, 0.019733429015163454, 0.03971750284695337, 0.021610677677897677, 0.01976362437069897, 0.03518922224400505, 0.0556757846366494, 0.035885515727943955, 0.1048261012821909, 0.04039258335626895, 0.09239838548725651, 0.04489015532477249, 0.03058659280800531, 0.03543691762212304, 0.06985506087902092, 0.026396440432196664, 0.04022231265421837, 0.0343625022909574, 0.01897335105064896, 0.05769006727683929, 0.42994656149418126, 5.443501116768007, 62.26042109151041, 112.90710418455063, 99.8571825027466, 108.68766154012373, 95.53097294222925, 53.61268528046147, 26.48994072791069, 43.74981880187989, 68.04938839327905, 100.97331646950015, 60.17490471563032, 47.629427294577326, 22.533991144549464, 0.4957100003957749, 0.17009997169577307, 0.01647278069398336, 0.06970406494914524, 0.27041166239688474, 2.749274810475688, 0.4133762329095795, 0.3587957471609116, 0.6260016380298523, 1.021998369645688, 0.32202778624430783, 0.14188044884752843, 2.741369273393385, 29.208280540281727, 84.92933980880245, 95.20879730101555, 86.92215488803002, 87.11333905496906, 88.06995022681453, 82.57317989103257, 88.31080728961577, 91.99342650751915, 88.67058277130128, 82.20070377472909, 72.68216256172427, 70.0237447984757, 67.23358246587938, 67.94298233524447, 67.19654744671237, 67.94665367372575, 69.07475086950487, 68.3066644976216, 64.69493427584248, 70.45873565058555, 77.03815860133018, 76.78780940271194, 81.27582457757767, 87.06657655777471, 89.9970812951365, 92.09218394371771, 89.60919810879616, 89.67988706404164, 83.05827509972357, 92.31072272023847, 68.44219807655581, 35.255808522624356, 42.48812175566151, 79.34211961684689, 87.09401745950022, 79.35103124187839, 75.75651630278557, 66.77391206064533, 68.35155994661393, 74.08225259473248, 78.45770359039307, 86.64046595173498, 89.65493294500536, 94.73400223639705, 90.88330161186957, 82.63153691445628, 77.77958070078205, 83.64952533475815, 87.87033296400502, 84.5401857745263, 73.14522973952755, 67.28108236866613, 70.92004560655164, 74.35689695419805, 82.33870844687186, 83.25252656013735, 82.71760156077724, 83.34077204427412, 83.57756553157684, 86.77294792667513, 61.265405993307795, 20.695988093653035, 3.215882907952032, 0.3909711335455218, 0.8239509129235822, 0.5802245750542611, 0.43036438584808384, 0.45391837195042645, 0.030913268020676992, 0.1210192617990317, 0.07990053434285425, 0.037828475582383336, 0.0482509600659532, 2.1803526676470235, 13.070439600175428, 31.600947918430453, 45.1581536569903, 34.92190499459544, 45.165990552594586, 32.463583023317405, 26.78234754070159, 34.58423991357127, 73.2982570894303, 85.9507328464139, 81.75406348320746, 88.75646698859431, 97.14571860528763, 33.89326341690556, 0.9750260869341513, 0.03420666851583989, 0.04311912092230013, 0.0617747255150349, 0.04594773970424168, 0.04501029323305815, 0.013724461333045076, 0.020690408813196327, 0.027833828221886393, 0.0582617067641789, 0.044931481937847795, 0.04262685963523485, 0.024155190837900006, 0.0018232570601544615, 0.08142779956782058, 0.03291324396888095, 0.0706444685197165, 0.028786253627209418, 0.04868430536120169, 0.0692439908462186, 0.06334116081556966, 0.036939043671854084, 0.02366458813119079, 0.0034722379754267394, 0.02621418811501034, 0.07173296454693041, 0.02760362263107973, 0.008168960245506418, 0.043951460130272374, 0.022242355475863142, 0.044047948904335506, 0.03854152723966587, 0.10340501584352986, 0.09890983406935008, 0.16559050238180548, 0.196173804842176, 0.09420593930107933, 0.27859066222463885, 0.18320104047175378, 0.12373817679021629, 0.13887813495051476, 0.108616903514391, 0.08108096092098183, 0.09227114594391278, 0.14623700701180967, 0.1392111533711995, 0.14284866140975108, 0.1678346650254342, 0.11596372501263696, 0.1616332598871762, 0.18754626053475565, 0.11242307347035217, 0.15888888779426777, 0.15340002103438302, 0.20207573088907427, 0.17494681080983532, 0.12791088151354946, 0.16452179440567571, 0.11321192952774226, 0.8140980416247923, 11.625516876097649, 88.34523785498835, 129.67446004190754, 108.29525193860455, 124.19282221025037, 97.74693950530022, 50.819663540009536, 28.376045765415316, 77.22118423831078, 70.55486509876867, 101.40906041668308, 94.35046503620764, 65.7483652330214, 31.152736717654815, 1.0205141815447039, 0.44621376440890376, 0.18226538664631306, 0.3489048472575603, 0.7650220201861474, 4.780685767050713, 0.6786269754652055, 0.7335299229429615, 0.37994688316699, 0.8198251310856113, 0.6314014547294187, 0.6645838483687371, 4.5752065220186795, 38.91450520484678, 92.70004149406188, 97.94985940379482, 91.32426231138169, 90.92200756073, 89.16961023884436, 84.51282332020422, 92.27033015220397, 95.0891257870582, 91.19988395321755, 88.67132802163401, 75.43646658620527, 74.75304065212127, 70.60769942498976, 71.17983987254482, 71.99572424734794, 68.97133365754159, 73.48440493306806, 70.10576940351918, 68.5386570038334, 74.41047653075188, 81.26177464762043, 80.66429568875222, 85.56194751493393, 89.68235815725019, 94.08150811349192, 97.62289062623056, 94.91617279668009, 96.295223236084, 86.38852427082678, 96.59878330845987, 74.03767093535393, 44.82470904627154, 49.95212547240719, 83.40964101975965, 92.93452078296293, 81.15873398319368, 81.59256381373253, 71.34363805094074, 70.70084787184193, 78.89809946860038, 84.9992835137152, 89.81450280835553, 93.15249473817887, 98.62034151631018, 97.49528023504443, 88.76156606981831, 80.41271486589986, 89.63201845845869, 93.83586575908046, 89.98532202935989, 77.43186258500623, 69.61672044569447, 73.8201049066359, 78.45394595976799, 86.52414414190477, 87.80466464258011, 84.2593126912271, 88.25678840760263, 86.30837455872567, 90.54307522312288, 66.0024053819718, 24.24548795146327, 3.8404936367465607, 1.5721962817253605, 1.9367827955753574, 0.7714700290272314, 0.46899620804094505, 0.6711506314816014, 0.27949440082715404, 0.2067734280060376, 0.1879920164543775, 0.15153237528377964, 0.17256482894862854, 4.615673615086464, 20.289006886943696, 47.22428175710863, 80.25676927258893, 61.39957458742204, 84.72024609965663, 71.70313896671419, 44.45138177564068, 26.467318457941857, 62.41355826777797, 92.6525023675734, 89.74048768320392, 102.03955788766186, 108.68239771935248, 31.728352385182536, 0.6404582074572963, 0.13082606057005544, 0.13783930440343198, 0.12167416738286135, 0.09589723927239258, 0.15425353491258237, 0.14987344252726725, 0.11372798167529607, 0.20505503150484256, 0.15621263623958634, 0.17977883378344198, 0.17963908402429474, 0.1391620624570116, 0.12624427255603576, 0.2015239943660075, 0.17005017598069486, 0.23235607621890886, 0.18324694446017667, 0.131621336444251, 0.19099425374259874, 0.10202851672206195, 0.187900974565456, 0.10564229135671932, 0.08898788462242774, 0.14262795147876586, 0.19396054618541272, 0.1422927420466177, 0.11587721836422721, 0.17426457886974658, 0.1989988153499942, 0.12630750545330588, 0.13583428376624662, 0.24364039812597538], [0.03612700196343564, 0.032832563419135354, 0.07187204014870428, 0.07059026779907365, 0.039930647659686305, 0.09079511667932234, 0.053372537461860534, 0.14254286975389527, 0.054375599363758687, 0.015909899506838094, 0.029523839250267036, 0.06615671779840224, 0.043530150076314326, 0.049454135624992276, 0.033065174526024255, 0.08307242946278665, 0.02855881744424903, 0.049076883287559596, 0.03585478028042182, 0.010925027628188894, 0.05651154825764318, 0.17687926759883282, 0.04637612458018046, 0.014710692283246788, 0.06049908952967775, 0.14213934060065977, 6.4238485117112445, 73.02567589667537, 100.030574798584, 98.55700308276762, 75.77593987987888, 60.03823364934614, 37.84103878082768, 29.126616793294108, 65.27588044443439, 56.26516849763932, 56.58141351515248, 41.19706184633317, 33.30723385657034, 18.226444221312, 1.110022301154752, 0.08604754723848836, 0.09418826565266618, 0.1294677407150307, 0.18492066271362767, 0.06883827834239892, 0.45361745261376907, 0.11824889634285243, 0.08221958974196066, 0.27022161130462924, 1.4125044571776546, 0.18132587173773398, 0.44185665466131707, 31.835974377970544, 84.0261277844829, 83.60282559548655, 78.86088402040544, 82.09585097528274, 85.4572045418524, 87.96858833682153, 87.66564015419253, 80.22529617432626, 85.58092394182759, 86.80631945210119, 83.48878660509664, 75.57641675395351, 70.56450628465223, 70.88839207926105, 70.32801874222295, 73.37984238901447, 73.9981020650556, 72.52791927706811, 66.30642044928767, 65.98027536945959, 62.850910386731556, 66.46936355098602, 68.21084883905226, 72.14670412002071, 74.31512371186288, 83.57120344715734, 81.59718436579551, 85.72237245498165, 80.63770201898392, 81.49129606062367, 71.52583999018516, 91.34919289619693, 36.82674131085796, 40.04422626187725, 92.16049594263878, 72.0148967927502, 77.12358782368322, 62.59226145282869, 67.21288019610991, 67.33209671512728, 76.68917748235887, 77.5824188417004, 85.80424016521823, 83.18158657320085, 83.2417243526828, 84.86076108870968, 81.04399681091309, 63.26198262553062, 64.15974647768083, 67.18447439132198, 68.220380198571, 62.50987206735919, 65.05050889907345, 67.46439041629915, 62.60960617373067, 67.0666071676439, 67.99803672298309, 68.89365503864904, 78.86324528724917, 83.09854999665292, 87.6206741025371, 76.3040791788409, 75.12182189572242, 70.71642752616637, 37.90680123913673, 2.531356749034697, 1.5429094145374915, 0.15026836085223383, 0.35398140549659735, 0.14358566863642586, 0.052542925526898716, 0.024767457883084015, 0.05238437213965001, 0.0023943910491652787, 0.21528146259727018, 1.7570361374847352, 10.098104746110979, 27.456408815999186, 48.60462265629923, 41.70238471800282, 69.1787721264747, 76.55843703977524, 35.542608307253936, 12.321630697096548, 27.953488826751713, 54.265987411622085, 66.27184867858887, 80.65813756758168, 82.62623386998331, 30.74130754317007, 1.0536321012243148, 0.05328196671701247, 0.03779352665127766, 0.08549099968325707, 0.0608557915585416, 0.041070812486953316, 0.03716250768892708, 0.05673714966002492, 0.02559481751954844, 0.026332933658493624, 0.03120461700394029, 0.043150174296310836, 0.09168551003019657, 0.0454487674869597, 0.08312963324809268, 0.046319035708063075, 0.042856498320977536, 0.11664059433725574, 0.06044010458994777, 0.06698756313492214, 0.07852107812199863, 0.0549609862988995, 0.037763484513327, 0.02787103136670926, 0.024508568045172482, 0.015564661983761097, 0.006995532359372104, 0.00603174778535181, 0.020905126021393848, 0.061275148088292736, 0.09357435343366477, 0.05391506177763786, 0.04904822393831226, 0.03623164191301312, 0.02905929693952203, 0.015347994124186377, 0.0738156511778793, 0.06751583438486823, 0.006887301372649569, 0.029420620393789107, 0.028380466429817102, 0.029429282932992906, 0.048520760911126296, 0.009813069200683987, 0.021252338136095675, 0.04353889880040961, 0.09549577089567339, 0.06753076543851246, 0.029224616798361944, 0.03293110913927517, 0.0684961894406907, 0.02125071019925658, 0.04439196451717327, 0.042179920109769994, 0.02844629444993071, 0.05257188748087614, 0.0674553364214878, 0.10664167603658092, 11.160742486676863, 96.58124246904927, 120.45819236386208, 110.58452760019611, 86.72704835091868, 70.62651111233619, 57.96595527279762, 46.520518333681174, 48.3187799299917, 37.41115877705236, 38.055153123794064, 36.916108592864006, 43.57912901909121, 22.278576204853675, 1.6798951284539316, 0.01847940628537007, 0.14537420814796803, 0.25611814712324454, 0.17104042123161978, 0.09545552063613169, 0.5568106604679939, 0.18236730698375933, 0.06609856406407011, 0.6093410642877702, 1.0365351025135288, 0.2693878012078424, 0.7088963963812398, 31.561308445469027, 88.60314938329881, 91.25680538915819, 85.28537334934359, 87.63557910919191, 91.39205655744, 92.44194953672348, 89.70969707735124, 80.80401835903045, 87.31621188502159, 90.29595021278628, 86.10536052334695, 77.87341948478453, 74.25228734170237, 72.80805495477492, 74.25351112119614, 76.99882507324219, 78.09225636143839, 76.54373599636939, 70.59310820794875, 69.2314495578889, 65.04461357670446, 67.73083702210458, 70.35516938855572, 75.2152370637463, 77.53548376021847, 86.21408862452354, 85.43643951416017, 89.10417725962978, 84.53108587572652, 85.15769235549435, 75.86954332167103, 94.6697538129745, 42.74616664455783, 43.88873346390263, 96.51878264642532, 75.0526705095845, 80.26248808830016, 64.72211237876647, 69.75510166537377, 68.11465663294639, 80.90512921733242, 80.72047971910047, 87.4393193952499, 83.84005838824858, 84.46548031222436, 85.71677915511593, 84.4397024954519, 67.19843802913543, 67.38970064347791, 70.60489100794639, 69.94962769169962, 64.95384993091707, 71.3192173742479, 69.4047006484001, 67.53817804398076, 68.03625629794213, 70.4621010441934, 72.7315922706358, 82.7576332707559, 88.42836072368007, 94.14848650655439, 79.72942229240172, 81.63348197937012, 77.52582688485423, 43.43608017890684, 3.179687030853764, 0.45884679942842455, 1.1161760096588442, 0.5914256385257167, 0.2984163435476442, 0.05395212511141455, 0.0536690900973495, 0.09476404967567614, 0.01800320603163733, 0.38927054092768704, 1.6476369432864653, 12.070714715988407, 33.242675565904186, 52.04868724269252, 43.09237072544713, 54.141546295535186, 54.70505752871114, 22.105127034648774, 19.180025362199355, 47.83089199373799, 67.17172668826196, 78.99906912157613, 86.68776189127277, 98.90282277138003, 54.98314965155817, 2.545533665726262, 0.13517437562827142, 0.036536387858852264, 0.16873985919500553, 0.03096360765818146, 0.031140727186275106, 0.04018207388599554, 0.03204791509966937, 0.027329401458583535, 0.07184412390474351, 0.04117005917754385, 0.038213090024768345, 0.05366632068950323, 0.005564656795843715, 0.07584679541328261, 0.023772156451858824, 0.08870541268298704, 0.13762620938641412, 0.04144451017641733, 0.020105537072184588, 0.0046837595835959, 0.03338947869657028, 0.021553426012096387, 0.05616814551514484, 0.05958797350045174, 0.027281603317767866, 0.0035597209071349958, 0.05634820682086772, 0.027050631639036923, 0.038063967179867535, 0.07925967115067667, 0.04475682155199109, 0.16184041006190164, 0.11950732599343024, 0.14435112836860842, 0.11518050736236958, 0.27158144801374406, 0.17187113633319256, 0.1607399707239482, 0.191573171065219, 0.21776151903454335, 0.14132053050543034, 0.13397900267474114, 0.09727678742379912, 0.16092064490001048, 0.12159591150139609, 0.19412514783682364, 0.17884874175633156, 0.1497835344484737, 0.08695811934528813, 0.1381761226202211, 0.19907335570502668, 0.24015690440372114, 0.24491815617488277, 0.20092362658150736, 0.13617479452683082, 0.20710469974625498, 0.3487044999436025, 18.060557380799327, 118.51496388835292, 133.9005079577046, 123.89751480471705, 103.33931369166221, 80.83460500163417, 54.82851412988479, 41.892478466033936, 90.00013289913055, 78.4948641254056, 72.64271136253112, 64.1210836748923, 53.000367995231386, 30.729830688045872, 2.6107945509495276, 0.22275000780580506, 0.4245056518383565, 0.7060521264230052, 0.49441105235488186, 0.3390767359204831, 1.3518822649794242, 0.5733772811870421, 0.19531007135106673, 1.0487133264541626, 2.1297746848675514, 0.5151569891360499, 1.29355747853556, 39.804036002005304, 95.04902347441643, 94.19580598031321, 87.30373090313327, 90.6154586422828, 95.18604755401613, 96.4281209822624, 92.10326856182468, 82.38055229187012, 87.44514803732596, 94.4682224335209, 91.08306792474563, 83.9737484532018, 79.11673238200527, 77.20507114164292, 77.48646982254522, 80.28165278896209, 83.19307127306539, 79.85221601301625, 72.78492081549861, 72.31006299295734, 69.22868036454724, 72.94045063757127, 76.39634901477446, 78.86050747286889, 81.69985632742606, 89.9554963265696, 88.32410412449991, 92.78051284051712, 89.72614749785393, 89.19161473551105, 80.35231820998654, 98.15290481813493, 50.42597524581417, 51.19331244499453, 99.9995174715596, 78.6361086753107, 83.44757818406629, 69.44369685265326, 73.71690734740227, 72.53193578412457, 85.42766909445487, 84.66756082350209, 91.53479945275092, 87.79401148519209, 86.3782476609753, 91.35426059845956, 88.34643025552073, 71.83672705004292, 71.10138462435815, 75.16992584351571, 75.25130717985093, 68.90492793052428, 72.71217653828283, 73.12995603007656, 69.49519757301577, 72.67314111032795, 74.88969602892476, 74.66709367690548, 86.93138814741566, 91.92094895147508, 98.69984011496268, 79.79449441356044, 82.80266208033409, 81.91076217159149, 45.53541114253383, 2.867763729826097, 3.4409776810676824, 2.846189222989544, 0.8240592071125585, 0.5017152717036586, 0.21848971625008892, 0.17230489531592016, 0.24707841686904433, 0.15115441814545663, 0.5436362770776595, 3.628782971251396, 19.389474045845773, 45.11050470413701, 71.89052627932641, 62.408992628897394, 101.01865906869212, 100.61379201950567, 44.83904530925136, 20.13664633997025, 43.42661942205122, 73.16484943512948, 84.14481870589718, 97.70042019505655, 113.47816205793812, 55.512512730013945, 2.434422479521844, 0.23830451912456946, 0.13269156127447082, 0.17559348094847896, 0.2298579094631057, 0.1210970963321386, 0.1942235901350937, 0.1466211234970439, 0.13334889535702046, 0.1637769271168978, 0.11434950880826482, 0.07991049348586991, 0.15093073579332522, 0.1210630743674213, 0.1954626607438249, 0.07726108565205529, 0.221791310055602, 0.3402636512633293, 0.16036334657861342, 0.1915804182569827, 0.13780270072240985, 0.08579132147133352, 0.1338554326925547, 0.11998314320320085, 0.1957961234955057, 0.14436255840043868, 0.10309766136830854, 0.12283963992470696, 0.15589981189658567, 0.14938467843157632, 0.2227692366127045, 0.1474898212379025], [0.026779978521048065, 0.03624569196554442, 0.061487599591454195, 0.03875451117393471, 0.0606319674801442, 0.01422638011600582, 0.03995947171783736, 0.04981191017695012, 0.020808319320842143, 0.15127541407221748, 0.05297520979037208, 0.026990844222206264, 0.042360421916049336, 0.058330145228894494, 0.043862996127216086, 0.023780056733577967, 0.06035576597036374, 0.03498152431641375, 0.0663282219020109, 0.034578416511536605, 0.059845915304556976, 0.04300399322903926, 0.04954177225309034, 0.019937830849460537, 0.16961767338216308, 9.109147748639508, 100.87950121971869, 114.00832529990905, 98.75295685183619, 97.22507599861392, 81.86217969463718, 49.609008296843506, 25.910206571702037, 35.382512846300685, 47.32609864204161, 65.65091002372004, 69.81821260144635, 58.7123195586666, 25.188231583564516, 2.6453822562771463, 0.14954529642578096, 0.046649368990573196, 0.03817953154324524, 0.06078317791463868, 0.05004438721845227, 0.22222110070288184, 0.08383470993008345, 0.1677754617506458, 0.06267857903073873, 3.6939139279627033, 1.432710179398137, 0.3129713399515998, 27.494575438960908, 89.88127723816903, 81.2756912169918, 86.56106933470696, 80.75867575983848, 73.95884698437106, 79.76917943646832, 81.15278767001244, 84.13482450669812, 81.58631155567785, 81.75201600597751, 85.88666485201928, 81.52721712666174, 77.87452559317313, 73.40702441430861, 77.49666014025289, 79.79194487294843, 82.95763492584229, 82.9758268787015, 77.10569397095712, 73.71922154580393, 68.128965439335, 63.52152585983277, 61.52504728686426, 59.68500068110805, 62.79337706104402, 65.17890768666422, 77.10872204073014, 82.45113926549112, 85.0799431339387, 75.23997937479328, 79.58245108204504, 71.01801072397541, 86.82506838152486, 56.673040082377774, 22.253065109252933, 88.83555766074889, 72.64343307864281, 76.97755013742756, 62.595116938314135, 63.62533923118346, 65.60190000841695, 79.38399484080654, 78.3723763496645, 80.68091084880214, 80.26939145980343, 82.84052864197763, 82.67577340525966, 85.933686225645, 67.99694630407518, 58.445300286816014, 59.35019108556933, 60.966995992968165, 61.546267309496486, 66.21145202267554, 61.3782565055355, 62.3582410812378, 62.58412253472113, 64.4926223447246, 75.04584558548467, 79.57130370601531, 80.31404372184508, 75.62878824049427, 72.87571584024738, 82.21555386820148, 86.95820931465396, 94.24986408602808, 75.4262762684976, 9.156967324595298, 1.8186217618565408, 0.1879911584359023, 0.10361408123806601, 0.03519319824033207, 0.027186658210872162, 0.06100090393315881, 0.04658094201717646, 0.16970534448421773, 0.0829071919583986, 0.699187181890011, 3.421261397100264, 16.879008085496967, 29.391978863746893, 40.00963880169777, 38.840497924435525, 78.5787243996897, 54.832852271295366, 11.938668124137386, 19.91544427410249, 44.385313372458185, 60.27714913891208, 70.573833680922, 81.67134069627332, 35.30128448240219, 1.5172910666273487, 0.20486542474358313, 0.050941066320745215, 0.06717025978310455, 0.018460171732811198, 0.026659285199017297, 0.05701671812623259, 0.021870157403510906, 0.03856429537277549, 0.029134840869735328, 0.05705368186857912, 0.002736261855217538, 0.018014402406650688, 0.0751368081076972, 0.0633320022344349, 0.024924563364155834, 0.011430005974797233, 0.07983118806394839, 0.034780307492661866, 0.05395069635743576, 0.08553920193545281, 0.06305452901870012, 0.038160524901843844, 0.035074477594706326, 0.08025792968128959, 0.08099783272031816, 0.012328103297360003, 0.03479049263161517, 0.04632786870183003, 0.038679063004711946, 0.07062787505527658, 0.05411481154301474, 0.05715343800763931, 0.046427169018575264, 0.07799310564634301, 0.05908328626725463, 0.049461409629833315, 0.004867853384630214, 0.07832888964443438, 0.06308253719321182, 0.013874379951777238, 0.012270530832240419, 0.039377417265167164, 0.023679873500499996, 0.005025876255991359, 0.014876852923583601, 0.016662751347006812, 0.05386112918776851, 0.08500459513837293, 0.023335861718101848, 0.06952428709595435, 0.09860313842974364, 0.03184692044141552, 0.016458008603583422, 0.13999656203293032, 0.09287715979641484, 14.1184361134806, 119.37236262905984, 127.08538978330552, 106.08005416008734, 112.95573372994701, 106.94729020518642, 83.21298906880041, 38.60257087215301, 31.1459098323699, 44.352134043170565, 54.63394495748705, 60.87456926222771, 60.20909993879257, 30.113157610739435, 2.869442749407984, 0.036161893437947, 0.03814077515515589, 0.04657348798167321, 0.0582839539575, 0.03565430273151687, 0.17326579939934517, 0.2054012419595834, 0.4587897105563072, 0.08637897219629058, 3.287230331090189, 0.6817306734381184, 0.513664128919763, 27.460674393561582, 97.04493722608014, 86.74539719858478, 91.13401166854366, 86.11054589671474, 78.03336589567124, 84.42979458839663, 85.37234014080417, 87.66545972516461, 83.73853960344869, 80.95047181652438, 88.89270659415953, 83.87218259995984, 81.8500046576223, 78.13202919498568, 81.25898976479807, 82.35781823435138, 85.69143279906243, 85.24638498983076, 81.92065438916607, 77.49893511495283, 70.13119420697613, 67.72394149534165, 64.54804543525943, 63.22330021089124, 66.94291914663008, 67.6609560751146, 79.96168936452558, 84.8751954109438, 86.37808292142807, 80.23206618524368, 80.27129773170718, 76.21322924090971, 91.69968805005475, 60.712500849077784, 24.922134068704423, 90.19001483917238, 77.37076774720224, 82.42456912994385, 66.99372952984226, 66.85618769737982, 69.64531452425065, 80.54638139663204, 82.88549469363305, 83.09774198839742, 80.43842208000922, 80.63011615507065, 85.46964630003899, 89.70225241876419, 71.27212539795907, 61.03059722531227, 61.95957529929377, 62.49893649931877, 65.7992736754879, 68.09340523135278, 64.37161722490865, 65.23563692646643, 65.68009638017224, 67.42526085146012, 79.19809802885979, 84.50706528079125, 86.887645875254, 78.20620905968451, 74.64181007877474, 85.60638796898627, 91.4859345651442, 100.29233024966334, 82.9230631551435, 12.055139964626683, 0.6950912468375698, 0.6128124231773039, 0.4761359942776542, 0.6151219637643907, 0.4627429693937302, 0.2606933774246324, 0.08735158210319859, 0.11284638301379259, 0.26659127384904896, 0.5557519882436722, 2.9885237015062764, 18.867575237827918, 34.816216730302386, 44.06544408490581, 41.29023382740636, 70.25296811134585, 41.72743297392323, 10.99032825039279, 35.616188049316406, 66.56971346947455, 74.2658587424986, 75.34680120406613, 95.08703908612652, 60.421257019042976, 2.7108809351921086, 0.17561286297296325, 0.07211751770228148, 0.03815448046812127, 0.06226360452391448, 0.0935937584407868, 0.0447536920828204, 0.04922915858426883, 0.036251269085633184, 0.021779142327666767, 0.01997599351940857, 0.0005279101711611504, 0.09669702740446215, 0.0109567427106442, 0.0660235027692491, 0.038228626287872755, 0.07228349831195609, 0.009222441266531186, 0.048131584415152195, 0.017081696104498643, 0.04954191014891671, 0.029619468090635155, 0.012309326482335887, 0.05568930991895257, 0.047971797626345396, 0.05242776719012088, 0.03549442018171953, 0.03986690914438617, 0.030114483463788227, 0.00785888855217866, 0.05467402508422252, 0.10743342790632479, 0.20200802403832638, 0.19032892170211962, 0.18291553482413295, 0.14852957109049444, 0.1553115023360137, 0.12417195875558162, 0.1300659174880674, 0.14265753779440157, 0.23685365584829163, 0.2422704184127431, 0.1352526544923744, 0.1740587616880094, 0.1702769992933158, 0.12081434094016591, 0.13305148470305628, 0.15353644597193888, 0.12453440261343796, 0.14401584232766784, 0.14357331929908645, 0.2689680769558876, 0.22392085062399988, 0.19809127695137457, 0.17271619260070786, 0.35404109906765724, 19.808695008677823, 138.19358917974657, 140.21527290344238, 121.8608005585209, 125.33602053119291, 106.62207864945935, 75.20147738918182, 38.41809003583847, 47.38729546147008, 66.19533108126733, 88.79220762560445, 103.00477473966538, 82.87107606087962, 41.69333188764511, 4.815998865712074, 0.4612977598463336, 0.37693603505049983, 0.2438251019245194, 0.4605263093065831, 0.2852795597526335, 0.7690745640185572, 0.32583208694573373, 0.4595015594555486, 0.09991776062956742, 6.792091900302518, 3.3545965485034452, 1.650933450268161, 34.26859109632431, 101.43352031707765, 87.83670256214758, 95.44968574277817, 89.53220982705393, 82.1814606266637, 89.73654177881058, 86.68232548621394, 92.01164199459939, 85.14600369238084, 81.40331729765862, 91.1492383095526, 88.39418903473886, 86.35471343994142, 81.86908306614046, 85.10760368839388, 87.02280290665166, 88.71020655478202, 90.11439154225012, 86.19575546633813, 83.28485473509758, 73.80289354631978, 70.82461434025919, 68.89545148418796, 66.27759887326148, 71.31786023416828, 72.33116534448439, 83.9828012835595, 89.75000335324196, 89.3568955698321, 83.45799599924396, 85.12566228066721, 80.43147164006388, 91.94487540952622, 63.69396109734813, 31.102463699156242, 93.54564174529045, 80.54518899609967, 85.7751283337993, 70.63171217518469, 69.75672552662512, 74.59438077865109, 84.24870660228115, 86.78633889844342, 86.96871342197542, 84.35301811464372, 85.99108619074669, 89.9269179374941, 93.75360581182665, 75.89403460102697, 64.85966597833942, 65.33044845827165, 66.03445899101996, 69.62630671839561, 73.45807798447149, 67.88144819198116, 68.5324518142208, 69.97024366932531, 70.86070799058484, 84.31151159348028, 87.54018706660118, 89.573684969256, 79.76156219359368, 74.00123211645311, 87.42100977128553, 95.00390052795412, 104.45100753538071, 84.52725764243834, 11.855499167596141, 4.000694511398192, 2.813855899918464, 0.2613386686050123, 0.3956799389373872, 0.1919424254447222, 0.2850617149904851, 0.18501216425530373, 0.26235266258158996, 0.34975201792774663, 1.5346142144933825, 7.060424675864558, 30.35672110895957, 50.20336504905455, 56.4491904166437, 59.164933619960664, 109.30338736503356, 71.85912378372686, 21.47981885940798, 30.849782651470555, 62.93603758658133, 85.48010333891838, 85.48468466727965, 113.38317794184532, 66.88043578978508, 2.8960874099885268, 0.2797814386506235, 0.14878746692932424, 0.1685549408918427, 0.18745691936102607, 0.19026305346239, 0.1371059743987937, 0.1905141004751767, 0.16052056314243426, 0.09813135084245475, 0.13087980929882298, 0.11579905441331288, 0.19018751719305593, 0.11797234626306642, 0.11891532388906326, 0.17282051845423638, 0.14571488744789554, 0.13262252143073466, 0.17723185190510365, 0.17156652445274015, 0.16233369407634582, 0.10975341027181958, 0.13751546371608012, 0.2032774470506176, 0.17770606033023328, 0.21969120258525496, 0.19969897374751108, 0.14819426972779537, 0.090316625822696, 0.1321862956448909, 0.14591475978734034], [0.008915933318466188, 0.07880544995949154, 0.00468315820457534, 0.07065068915366166, 0.029199897056265228, 0.022721170004637494, 0.04272042195342722, 0.05006542782329264, 0.05911415578016351, 0.05358031582868388, 0.027719909032326073, 0.08371580542335588, 0.07365955310242792, 0.06862761182410103, 0.013480960286312528, 0.04368700657881076, 0.028289462845291824, 0.040896378097034274, 0.0682707527472127, 0.04330926394510654, 0.07139842927215562, 0.054690967118667985, 0.051157417211441264, 0.0941532094692511, 2.526993602514267, 94.00542982162969, 108.12891990907731, 88.31838530878868, 93.36551081749701, 86.13662965836065, 33.134582888695505, 14.671815864501463, 37.21385179027435, 58.57884130170269, 64.50313037441623, 41.92944680490802, 31.618941791595955, 20.024050781803748, 2.394712894193588, 0.03774364283608814, 0.14714882018104677, 0.04854677725703486, 0.017968450537732533, 0.05013023120080752, 0.03908428904269973, 0.16792040558591967, 0.08075091492144332, 0.05115236486158064, 0.30071926513506525, 0.9290861230223411, 1.9893410849955775, 15.655955210808786, 81.56125545501709, 83.86373381460868, 87.87994277092719, 80.26419039695494, 74.34639284687658, 67.5188172248102, 72.97120986446258, 80.27811481106667, 82.13425882401006, 85.49368258445494, 78.1182695204212, 81.43608477807815, 84.22050476074219, 76.30585993489912, 78.5163430244692, 80.11424603000765, 82.44889566975256, 80.88561150335497, 79.60756994062855, 82.28956114861273, 83.46715865596649, 76.99545967963435, 70.7829430795485, 63.26814074670116, 58.05737003203362, 60.73874542790075, 63.9258163206039, 69.96657233084403, 77.57447996447164, 82.827357322939, 79.17078264297979, 76.8859157254619, 76.4896700459142, 81.5900299626012, 59.936459910485056, 17.57378535885965, 74.82338443879159, 77.14673765244024, 75.56614798884239, 62.91397425436205, 61.005529357541, 71.72040524021273, 76.06694836770335, 80.51539467227074, 80.33156887177499, 81.04929201064571, 81.42053650271508, 78.42583041037284, 83.22544651646768, 69.41100781963718, 58.93230176741078, 59.500508077682994, 60.91419696807862, 68.87026202294135, 71.21512551461497, 70.35082340240479, 66.12779571164039, 60.27635682013727, 63.753118284287, 76.44258591436571, 83.99516459434264, 83.09378823926373, 76.79143367275115, 81.13978109052105, 84.50217800755655, 81.01224914673837, 80.93308002718034, 87.74679399305775, 86.48336718159338, 9.978560709184217, 0.981882022273156, 0.20975562443415965, 0.23437160758241532, 0.09781937685705001, 0.014353504746160923, 0.09453043116316681, 0.05978613746382537, 0.10336114964898556, 0.03502846635397404, 0.047220587129554445, 0.4178724029371816, 8.388945671819872, 25.47062654649058, 38.380086191238895, 25.87028664927329, 40.69839131447577, 93.13113351022044, 35.931068082009595, 16.510685759205973, 53.466200444006155, 64.63989557758455, 76.04497524999803, 73.39947777409708, 31.36362687233956, 2.3067716388933124, 0.12000748947743448, 0.055185323656206174, 0.011622534403877874, 0.06636511669644425, 0.04065987143305041, 0.03376678466015766, 0.02707015538978721, 0.04577010306679914, 0.019537938698645563, 0.045150709488699516, 0.0660010946974639, 0.026294110237710902, 0.017906989218787323, 0.09979923150592274, 0.010596978245303037, 0.016380955480159293, 0.04134250556929939, 0.04756083358980475, 0.016836909945273114, 0.05437173445018069, 0.028470403236907818, 0.11566519587030334, 0.10956798635062673, 0.019719166373233163, 0.012370905587299457, 0.04058900446961484, 0.030802644924410892, 0.08030296799035803, 0.15694642589697916, 0.05154653242038143, 0.0388417226232348, 0.03598782677023161, 0.04009732923981163, 0.007737823677504616, 0.08249243195619314, 0.0401316499788194, 0.09838530132847448, 0.021205744668540936, 0.0774196045653474, 0.09252791563349386, 0.02186573899140762, 0.06754644725832247, 0.02439657748196154, 0.12369329935961193, 0.07742800088899751, 0.022249736733013586, 0.03358871518303791, 0.04879735695618776, 0.037523484488408414, 0.07271209386207404, 0.011559037206273888, 0.08338078751318878, 0.0531883507726654, 4.897758710768915, 113.53217309521092, 119.08803786000898, 100.06935135010751, 108.3697142139558, 94.66248173867503, 47.452434262921734, 25.99551812294991, 37.445212794888405, 40.263643649316606, 50.345331315071356, 48.7602662271069, 39.217688729686124, 26.084136232253044, 3.0858597688136564, 0.09692512242303741, 0.05155408221687521, 0.15013120047027065, 0.101703726085684, 0.15338051643583084, 0.0998442544932327, 0.21552362299013525, 0.1751690529166691, 0.30767145176087657, 0.32391751064888896, 0.9867319104171569, 0.9241954790007685, 15.648907692201677, 87.47875490496236, 88.8806256940288, 93.02413125191966, 83.59735781146635, 77.87426671674176, 71.7846771978563, 77.81288946828535, 82.95390867417859, 87.23477563550396, 85.98946232949534, 77.5640307703326, 84.07797367342057, 86.71725027022823, 79.25817305041899, 82.35411551690872, 82.8268317253359, 84.30960532157653, 83.65469501864526, 82.29801777870425, 84.47039896442045, 87.65828963248961, 80.70596694946289, 75.28446689728769, 68.91172932040307, 62.451369916239095, 63.28229265828287, 66.78740501403809, 73.02221636618339, 81.21302743111887, 86.70316896130963, 82.77837476422711, 79.78788129744991, 78.56642384682932, 84.45544688932358, 63.329953378246685, 20.948712287410615, 76.4624095732166, 80.17796101108675, 77.86084436601209, 63.97914094309654, 64.32463899735482, 72.84789054624497, 79.92382280288204, 82.90014082385649, 84.11669531176167, 84.33347686644524, 84.17032980149793, 83.13837774338262, 85.16206972060665, 72.08354611550608, 60.84001710337978, 62.48626332129202, 63.80689790171962, 71.6548232109316, 74.94703323610368, 74.27964979602446, 69.14444354272658, 62.49643402714884, 67.44296643041795, 79.04905580705213, 84.2847296499437, 85.54092361081032, 77.59663351120489, 82.67283162763043, 89.61546605633151, 85.06383788201117, 84.1834540520945, 91.03726248587333, 92.8594623073455, 12.948599996105319, 0.35171534806009264, 0.42970548894616867, 0.5845120933748061, 0.9600263918119093, 0.4840247999996909, 0.3086847102930469, 0.30768827505169377, 0.08271845087649361, 0.16760902148821663, 0.036525264262191715, 0.35981758587783386, 7.473539979227128, 30.95339794312754, 41.544615222561745, 36.017874056293124, 39.57043924639302, 69.4646344646331, 35.356146674002375, 26.98048999232631, 67.95245878158077, 76.72576535132625, 84.57199619662377, 85.00999942902597, 52.63363815123036, 3.6073660946661428, 0.09792986971836898, 0.009216981932460781, 0.07117406510177159, 0.05567641665918693, 0.014251968410286694, 0.06157884832411524, 0.07280092175689436, 0.024123281360633915, 0.07743399169656538, 0.047813784331083305, 0.015622961274798841, 0.07209335528914967, 0.07023848788512331, 0.02089786733831129, 0.016581124678674727, 0.05405661567384678, 0.039309855971124866, 0.06100329029704295, 0.06611076784470389, 0.014204746750634045, 0.03926926480245687, 0.08829895707388079, 0.04445412489134939, 0.034353577366639534, 0.01165277093663932, 0.021330371852062886, 0.04913275024943775, 0.004910593908730774, 0.026896012113279393, 0.11373701385192334, 0.1898044579091572, 0.11229493760413702, 0.15306835092844503, 0.13424146439759962, 0.1490892289626983, 0.12222496927866053, 0.16125534871412864, 0.16126328538502419, 0.2773692116381661, 0.18249941118542226, 0.1624513958250323, 0.15189597593440166, 0.14700050555890606, 0.14594771688984287, 0.1347410609765399, 0.14969836079305218, 0.1661969222609074, 0.12255264040563377, 0.11329848980230671, 0.18567625523334552, 0.1859582828417901, 0.147120367675539, 0.25431304479077943, 7.93254211064308, 136.17620437375962, 132.14082287203883, 115.6437183195545, 117.08766829582953, 105.18054485321046, 49.10987492530577, 22.234241654795987, 54.07295188596172, 79.55394329563265, 88.26561374049034, 64.000525705276, 49.28987641488352, 35.59841971243582, 4.515526679254347, 0.23547524916789225, 0.2776985988020897, 0.2419998668014042, 0.41647947122973783, 0.27211415491277174, 0.25603623700238043, 0.28067785345258256, 0.2980741473936266, 0.31155974634232064, 1.3672923993679786, 3.6059618861444536, 7.550106115879552, 19.266572460051506, 90.41621792700984, 89.71183869146532, 95.40150334758144, 86.77588185956402, 81.60068311998921, 75.09772285338371, 79.19833337107013, 86.89346667258971, 90.59330509554957, 89.05328842901415, 76.99861326525289, 85.19963033737676, 92.0068645477295, 83.72845911210584, 87.83734583085584, 87.13462183552404, 87.27728628343152, 87.55575103144493, 85.69154262542726, 87.1210818136892, 90.97468499214419, 84.40174964166458, 80.32269647044521, 71.3082504272461, 64.71018052870228, 65.70082610653293, 71.77356904552829, 76.8300219505064, 83.91064536186957, 88.1593567325223, 85.97795409540977, 84.36757010798301, 82.35282897949219, 88.45804522114416, 77.36832803295505, 27.322220610034083, 78.95239291652557, 84.23264057405534, 83.20995315428704, 68.590683321799, 67.47512986583095, 79.20492295295962, 82.39836769719278, 86.67373549553656, 86.25553238776423, 89.00083849506994, 85.71151533434468, 86.43537306016492, 89.4833920078893, 75.63324405301002, 64.82226617874639, 66.44356219999253, 67.75206488947715, 75.33428884321644, 78.37855800505608, 78.55632766600579, 72.21063875382947, 65.90695842619866, 71.18904175296908, 84.76864814758301, 90.41909694671632, 90.35622135285409, 77.28069443856516, 84.36164732902282, 93.10802290516516, 89.50490228591427, 87.62764023196313, 95.97060788062312, 93.93627843549176, 12.054026992090288, 3.1600810635474423, 1.3603259022197416, 0.9945387753748125, 0.7465420795544502, 0.3706868719910422, 0.4582787605543291, 0.37834146931286783, 0.2434866289578138, 0.15754786620457328, 0.15693950046214367, 1.907657971305232, 13.770607190747416, 45.705861660741995, 59.34554307691513, 37.21215732635991, 60.45547577642626, 117.15201085613622, 46.72007676093809, 26.112063507879935, 70.54427469930341, 90.15086958485266, 95.1001476472424, 101.99558811803018, 58.202317299381384, 3.4081045418016376, 0.21781240259447407, 0.11039541493500434, 0.2857707446861652, 0.13512176070963183, 0.11841436367361777, 0.15517944409962625, 0.22520375678375845, 0.12253366440774933, 0.09503118453487273, 0.08025403795463425, 0.10315953828995267, 0.1628143223182809, 0.13152719956011544, 0.20076716078385232, 0.09463507111274427, 0.1519287185322854, 0.14966961717413318, 0.20574015925728506, 0.1317377205217077, 0.12802404036084492, 0.1250633326989989, 0.34499448934389704, 0.13394578510234434, 0.1296088081454077, 0.09233894472521159, 0.07667273012620789, 0.193012680918459, 0.17155203006921277, 0.22342439500554917], [0.029965266773116686, 0.12362523244753962, 0.05533092632709492, 0.024596597293331742, 0.03759758051244482, 0.054233164466436834, 0.09615170303732158, 0.07338837329899112, 0.009987348457798362, 0.01445244404397184, 0.016562838159922152, 0.017408378978049564, 0.01753152186621822, 0.061630088114930745, 0.015738110993087532, 0.0494138891958902, 0.0129827493689053, 0.03421657786314045, 0.03477400258904503, 0.015211053034891526, 0.07504914466652178, 0.03718961187968812, 0.02129315913114096, 1.1885325850978976, 69.2057894122216, 116.60123948127993, 110.23523269161102, 90.44137600929507, 68.51192997347924, 57.23449991595361, 49.98396727346605, 71.87554282526817, 56.99199153530983, 64.4373090805546, 45.94225114391696, 35.165848962722286, 25.247573121901482, 4.01841210261468, 0.1893433649092913, 0.03677104825093862, 0.05909591522668639, 0.17189511488522255, 0.028127728277937542, 0.03278880830734007, 0.08185538388187848, 0.1192954337344535, 0.26849494105385197, 0.4820190285963397, 1.3225661025893305, 0.20238104757041703, 8.301350320539168, 71.91409972406203, 88.38513620438115, 86.72895462282243, 81.55370881480556, 72.18311155996015, 63.960980369198715, 62.37132218576247, 69.32964217278266, 78.56091683910739, 82.18447300695604, 84.06124084226548, 81.58438174955307, 79.09531624086442, 83.29073044561571, 80.14877073226437, 80.66515076544978, 81.40121490724626, 81.85489193085702, 73.22803881860548, 70.07062496677523, 79.53535126101586, 85.26713432804232, 79.85954300049814, 77.51463244038244, 66.75579071044922, 62.818699882876494, 58.31556004862632, 60.88890552520753, 64.43221784407093, 75.037977310919, 78.16709518432617, 79.57965050974201, 76.46279396549349, 74.10952875691076, 72.12373472029164, 59.970972845631266, 23.584341079958026, 69.49095356848933, 86.94109209122198, 69.00748222104966, 65.81076622009277, 54.67069364363148, 67.65215427644792, 71.50511418619465, 80.1435382904545, 78.94280664382443, 77.87421964829969, 76.34079256365376, 78.39391800665086, 70.01887321472168, 62.15436412442116, 58.88531177274643, 59.724247917052246, 66.6772021016767, 74.87320638472035, 80.39882967548986, 76.49614195669852, 72.53697210742583, 66.95233283504363, 65.4265308380127, 72.2832888941611, 79.36523022190218, 79.67387368602138, 73.93045686906385, 80.91920268151068, 79.96236401219522, 77.41661240977626, 75.33867405306908, 83.5247233606154, 86.78347556821763, 85.10989435257451, 5.838301893203489, 1.5974090320448724, 1.0971440567124275, 1.8001336700493291, 0.426905989166229, 0.04814236710268644, 0.15375890258339145, 0.05079897999342892, 0.05861818279710509, 0.05403410801063142, 0.01600116260364772, 0.06266056064275966, 1.8783508793961619, 23.159775887766195, 51.96069279024678, 57.12013536883939, 93.59953511145808, 147.30200736753403, 61.26243675908735, 27.440260417999763, 67.81705856323242, 71.09830164140271, 77.70358085632324, 78.78180903773155, 36.7600453284479, 1.4611457696845456, 0.06441576000783714, 0.051322145267359676, 0.11498318609571266, 0.02597854713038091, 0.07595052371823019, 0.04008180446802609, 0.02503905903487917, 0.11017188580045778, 0.06631669227875049, 0.043746500967010375, 0.059986231968768185, 0.13097288898162304, 0.06674476688907993, 0.018094483492595535, 0.03847680813182266, 0.0549028019210504, 0.014799165862402128, 0.07548520957390148, 0.01920005753486147, 0.06782239978952755, 0.05559184055234637, 0.09599188177455818, 0.096069271976669, 0.021937352890569358, 0.03947894689777205, 0.01880260537408533, 0.03261012212944127, 0.025544240394787445, 0.10384802150750354, 0.09079959063280015, 0.09168112800726969, 0.023579594506431493, 0.06375979722267197, 0.053937071483702435, 0.07587969888963046, 0.03557342682935057, 0.013327293582410823, 0.06644609985091994, 0.005520231357114691, 0.0656906835314247, 0.04764927077978369, 0.017060967680487423, 0.044423113652174516, 0.015311535999869869, 0.035257894365537557, 0.07123519125724993, 0.06037661888366265, 0.05743705907896642, 0.06943855419634812, 0.04140832018287432, 0.09039881939609205, 1.9964885014680125, 90.11036719045332, 131.41618851692448, 122.24257269213278, 105.7760783164732, 82.9953210584579, 90.11596833505939, 52.98419606301093, 43.299173770412324, 45.42790682085099, 58.63708065402124, 51.4101214562693, 43.33725998478551, 31.04235141508041, 4.2342162516809285, 0.04086506425312931, 0.09742094984939022, 0.039377612617587855, 0.15204165521408283, 0.2180664067066485, 0.3299202385448641, 0.5116755485294328, 0.4688756870886972, 0.1696199716459359, 0.7000529225314818, 1.2704770267009735, 0.11393481775397256, 9.939953800170652, 78.1598387995074, 95.05837440490724, 93.39857639804964, 85.53311024942707, 76.38851211917016, 67.41106187143635, 66.72246625346523, 72.18271932294293, 83.56480213903612, 85.2100089288527, 87.0266232951995, 81.0509237166374, 81.66120529174805, 85.97441611751434, 84.48306822007703, 81.58313443583828, 81.90427457132648, 81.81334618599185, 75.24012842485982, 73.58904592452511, 78.08103053800522, 88.34204504566809, 85.33947067876016, 81.90300372339065, 71.47415884079473, 66.26726735022761, 61.76157405299526, 63.97393595787787, 66.33351618243803, 78.95062000520768, 82.3537625035932, 84.36676994446786, 80.61585441712411, 77.64170154448479, 77.23522632352768, 72.64284472311698, 27.36856145243491, 68.59710031940092, 89.28377474507978, 74.87288475036621, 70.01564118169969, 58.36265986965549, 71.02280386032598, 73.90725212712442, 82.7763194422568, 80.70396654067501, 81.93975633190524, 80.60528755187988, 79.95520960900092, 72.82621552867275, 66.52914047241211, 60.22877454757691, 63.126896196796054, 70.26637477259483, 79.12460065657093, 82.04049848741101, 79.8961857826479, 76.4747493497787, 69.56581592559814, 68.99392650973412, 75.99491796185895, 83.37161756330921, 80.05078992535992, 74.6491527557373, 82.895873285109, 83.47928662453928, 82.87644186327535, 80.44943609545308, 87.22294576706426, 89.73837744805121, 91.63420015765776, 7.560740642009243, 1.0777350659331968, 1.3242005052105075, 1.3849018802565913, 0.980994095725398, 0.3770392730591759, 0.08186889767286279, 0.29415956067462123, 0.13391416099283004, 0.061993121860488776, 0.057830793798089995, 0.010778493202862241, 1.0633767396211624, 26.104230534645822, 40.4090262997535, 41.12069329907818, 100.15299197166198, 119.81670441166048, 66.0593189731721, 44.73667929249425, 75.81947818879159, 80.59368518091019, 85.81433634604178, 93.28152502736738, 55.23192597973732, 1.9402544609000607, 0.02547353239459617, 0.04698298495983885, 0.07829971701627778, 0.07418109810039883, 0.05439341090799821, 0.04925520174325474, 0.058043528753783435, 0.10666209994064224, 0.029747240065086274, 0.04699258404153009, 0.05775136963254022, 0.032173452012601404, 0.056165184585317496, 0.06756902386945102, 0.010819145658564185, 0.03050434369323475, 0.02982659911316249, 0.023069856838593562, 0.030096313773444103, 0.05822180890508237, 0.03391540188702845, 0.023113588967751113, 0.054173869261097525, 0.04775292247593884, 0.08922805318668967, 0.051362678979433356, 0.09698633284818742, 0.051227092908154574, 0.2113815081576186, 0.18173568281194857, 0.3110053131897604, 0.09503768862134988, 0.1371062195469295, 0.16969849565817466, 0.16322486883690282, 0.18151779208452473, 0.08994653640735535, 0.10857858379641849, 0.07893670380355851, 0.11419399295963588, 0.12344294182595708, 0.10567817491509261, 0.0968737179233182, 0.18903775711453732, 0.09864531923085453, 0.18645676093236094, 0.23861702171064195, 0.1518357461017947, 0.25059321294388465, 0.12364177228582483, 0.15323238567479197, 2.920204593289283, 115.19029232763477, 143.4047717432822, 136.3991205153927, 118.34116366601761, 94.11152209005049, 81.32087692137688, 65.59844047792497, 88.67626236331078, 76.65797110526793, 85.30664044041788, 72.7611904759561, 56.04062849475492, 42.60744417867353, 6.194465362256573, 0.4624561154313626, 0.23850333426267872, 0.15652069551569803, 0.3877739115588127, 0.2107791025792399, 0.23191393623428963, 0.39975200269010763, 0.319656468327007, 0.33929657251123463, 2.1671830646453367, 3.8399624007363475, 1.8656492641856595, 13.098892473405408, 83.19512659503569, 97.02753759199574, 95.69498292861446, 89.17226176108085, 78.93032566193612, 70.50900474671396, 70.92424254263602, 76.28946442757884, 86.3449545829527, 89.79613827120873, 91.32019089114283, 82.30246574647965, 82.82478424810594, 89.1141636140885, 85.95157223363077, 85.46324499191778, 84.81624218725389, 85.98076251245315, 77.52520715036701, 74.77748486303514, 83.59549076326432, 92.34822057908582, 87.5448311528852, 85.14494465243432, 74.46986905990109, 68.60438023844074, 64.35419013423305, 65.52466461735388, 70.93445639456473, 83.33521796811013, 85.78847223712553, 87.11087580650084, 84.59110598410331, 80.84452075342979, 80.02877758395287, 74.94366784249583, 31.74475181487299, 73.63418456046813, 93.52249191653345, 78.75538010751048, 73.907424711412, 62.62389929063859, 76.31922737244638, 76.97444362025108, 85.44538251815304, 83.53125018458213, 84.35057840039654, 86.04447749353226, 86.69017807129892, 77.02288489187919, 69.98143026905676, 63.23529874124835, 67.24781282486455, 73.31036152378206, 83.31864987650226, 88.05542176769626, 84.18512498178791, 79.58570664928806, 74.13129006662678, 73.13083464099516, 77.81835725230556, 87.26106336039882, 84.76248218167214, 73.89673233032227, 86.72787204865487, 87.61845404101958, 85.50114293252268, 82.7110747368105, 90.46318438745315, 93.54725776180145, 97.29775751790693, 6.38489741471506, 4.633175721091609, 3.727046188808257, 3.712897464152306, 1.7900393278368059, 0.20667316241850778, 0.31021124773448516, 0.16263370942925254, 0.29087469822937445, 0.18073085124694532, 0.14004724641000071, 0.20542321336125174, 2.7784302782627845, 39.986096735923525, 79.9758412761073, 62.36940022437804, 100.28702720519036, 161.53048361501388, 80.32773279374646, 43.11934878749233, 83.60903078509916, 93.21368371286701, 100.33078516683271, 105.85990721179594, 62.17983207395, 2.6926249986694706, 0.19072393195763712, 0.21275452157903105, 0.2856722870661367, 0.12759947443320868, 0.2258580724798864, 0.07930269464850426, 0.11457851547146998, 0.17533687213736196, 0.3037331776032525, 0.08076916313579968, 0.15951749357965686, 0.21302948585681378, 0.17002768363923798, 0.15137721183559588, 0.15546635934902778, 0.07151350333926178, 0.08060807016708198, 0.17115312808703992, 0.09765992331649027, 0.11141841810557152, 0.13385069826918264, 0.1905901270407823, 0.19131345193712943, 0.14439471877149998, 0.15606027667320546, 0.2657519785627242, 0.21540702440805976, 0.0997346502939059], [0.03036756060957428, 0.04137504898432282, 0.024277088833191705, 0.04523964463582924, 0.04227113053803483, 0.04786204403987335, 0.08040641284277363, 0.07574661409542446, 0.0908395497789306, 0.07924595817683205, 0.03689161133802226, 0.045257992441615755, 0.04616240137106469, 0.07142280618990622, 0.04071240208201832, 0.029316748447355725, 0.036932053119545026, 0.11878659813514642, 0.036461851334259394, 0.09764372821777098, 0.05223322299218947, 0.06931088564376678, 0.39682272761579485, 26.181185476241577, 109.36376048672585, 96.1548416076168, 83.8374617791945, 52.09549288595877, 35.36122222100535, 19.171300049751036, 37.63578114971038, 44.19831045212285, 58.424974564583074, 52.10174514401344, 39.05318060228902, 17.962033325626006, 0.3189738839864731, 0.18517782310805014, 0.0035052453524493164, 0.06931056388683858, 0.055483293554355065, 0.13134988084916147, 0.07415475999756206, 0.5370672263445393, 0.3071012678405931, 1.11236248525881, 0.3707180977348359, 0.6090411868306899, 0.5054555887416486, 16.763429564814416, 70.21940831215151, 88.9080273720526, 81.43373920071511, 80.23314875941124, 71.65281495740338, 63.01936049615184, 63.61026164024108, 72.07241442895705, 74.7895343842045, 77.0436106958697, 80.56813486160772, 80.89357391480478, 81.39799856370496, 75.59801332412228, 74.90757419217017, 77.37753775811966, 79.4663175459831, 75.53867570815548, 73.15200759518531, 74.60335516160535, 72.32073183982604, 70.34654801891696, 75.77652823540473, 79.23942412099531, 81.61782387764224, 71.21092073379025, 67.093059632086, 58.20451382667788, 59.01602083636869, 61.12694240385487, 73.78174412635066, 78.92725836846137, 81.60910837111935, 74.75552743481052, 73.85009534897344, 73.370954298204, 93.04546894565706, 29.009079048710486, 51.87939774605536, 79.74110311077487, 72.73410258754608, 76.54268480116322, 58.49930347934846, 62.435143070836226, 71.47497469379057, 82.36182689666748, 81.35358948861399, 76.73119391164472, 73.91025666267642, 65.17590707348239, 60.225044373543035, 55.799834189876435, 57.513529485271825, 60.33101112611833, 70.97762600068124, 79.35541645173105, 80.22353110774871, 81.61747870906707, 75.54532804796773, 68.89233712227114, 71.05605771464687, 71.31920168476721, 77.0859016910676, 79.94740409235801, 76.75494778540828, 78.06015568394815, 80.77549488313737, 74.81355497913977, 65.7618817206352, 76.94288422984462, 81.3456819903466, 87.04769426776518, 61.7379064713755, 0.9798159137848885, 0.3669823159373576, 2.669472473282968, 1.457957495604792, 0.16957638124304433, 0.1892810666392888, 0.012198159463643547, 0.10086176481338278, 0.06181939227146007, 0.17135411891485416, 0.028762782608429273, 0.045575325212050835, 0.41239830635247693, 25.954886290334887, 63.89956781941076, 78.30213454461868, 91.8560572593443, 59.02387734382384, 22.57477398841612, 37.686728815878595, 56.26763566847771, 74.93881194822251, 71.33387134921166, 83.38081159899312, 22.66397653087493, 0.35081504153147824, 0.011290989744837486, 0.11364920485404231, 0.039836637180058226, 0.028773122880187248, 0.023727888061154275, 0.11365790761286214, 0.009217150471804124, 0.03521184482040905, 0.034303988495300856, 0.02902190035749828, 0.02794714794764596, 0.04150218127535717, 0.07244301313954978, 0.05378237534915248, 0.01575755717743549, 0.018065119342457865, 0.046476160341333, 0.0022568162615155623, 0.06576727700209425, 0.01672969977070968, 0.039698032722357786, 0.0265239825802705, 0.007679437243965485, 0.034392758933526855, 0.05773062780199032, 0.06227924420888867, 0.09017536687033792, 0.07402073291520919, 0.061470883552946394, 0.03677600100936909, 0.03694927860652247, 0.054274372335883884, 0.027018216543740807, 0.11135112494230272, 0.00882404011433884, 0.10316093256997486, 0.04635278571156725, 0.017607448840393655, 0.036218040021917516, 0.0672888042285077, 0.02219930708017801, 0.06297157701825903, 0.036533469063860756, 0.050129315725738005, 0.06583677649858498, 0.05062894294819525, 0.03705984807663387, 0.07744853204536824, 0.02053809712731069, 0.22920261317443466, 36.53760771597586, 130.9050723045103, 109.06242832060784, 97.3910471700853, 69.2889436598747, 70.65417951153171, 31.319353119019542, 32.86902273854902, 51.801409259919204, 59.48381447022962, 45.29132989145095, 46.340332492705315, 23.28194202915315, 0.46035041551916833, 0.3284695438079296, 0.022178821889082753, 0.13011143843252815, 0.08449388262365135, 0.4570038370307415, 0.3653043382350476, 1.947632561768255, 0.40927539489442305, 1.315128553298212, 1.5469010390581623, 0.6923273241808338, 0.1744315247502058, 17.572073244279434, 77.62651412717759, 94.76478499750938, 86.257917188829, 85.72936996336907, 76.66324277077952, 66.74234482549852, 67.33631718543269, 75.59005091267248, 78.27165772837978, 80.92875757525044, 83.37353952469365, 82.72641904892461, 79.66145546205583, 74.84571056981241, 76.12377566675987, 78.62161159515381, 80.59916080967074, 76.78886844265845, 77.63868916419246, 75.92608821007514, 75.26987568024667, 74.17440475956087, 77.77828631862518, 81.28341828623127, 83.30627872097878, 75.68244626445156, 68.66583593430059, 60.871651018819506, 61.36428502298171, 63.906714377864716, 76.28551067844515, 80.77134501549506, 84.70140303334883, 76.28705609229304, 77.00408889401344, 77.0626106569844, 94.64329350379207, 31.280898201850157, 53.84084955338509, 84.9397340897591, 75.85893723272508, 80.96925212490945, 62.810619800321525, 64.6894782589328, 75.20049679663875, 84.09616562627977, 83.48755498086253, 81.2634926457559, 75.1179858176939, 68.9735694085398, 61.50670236156833, 59.14539629413236, 59.87845982274702, 63.4558653831482, 76.78613847301853, 83.64817603941887, 83.57247429509317, 84.32749132956229, 78.33592184128301, 73.9890492346979, 73.71777026884018, 76.03847980499268, 79.97601386039489, 82.19127439683484, 78.58709473763743, 82.79923392880349, 83.29367222324495, 79.87223579037575, 68.14504715704149, 82.38765962662237, 85.69260166537377, 90.22670468976422, 68.40094258708339, 1.8010097069125024, 0.298789183218633, 1.2576476893117352, 1.141001058201636, 1.1155973374843597, 0.7142014020392973, 0.35278940332993386, 0.11897635811399068, 0.03569402055995118, 0.050298575191728534, 0.09185576541048866, 0.012770517158412166, 0.3994089791611318, 25.647211651648245, 59.88481798479634, 81.48252564091837, 100.90240786152502, 56.246176381264966, 29.372606277465824, 61.66274993650375, 67.77929398321336, 84.91767467991, 78.51147928545552, 97.24174607184626, 37.921188492928785, 0.6134920350966916, 0.0187045595263161, 0.0216604714777561, 0.04575317635411217, 0.03145432336285951, 0.054438525825859084, 0.0769588946094436, 0.05502890382382659, 0.018908662586322716, 0.030412556783806895, 0.057325378781364816, 0.02663389321476702, 0.020253627613607435, 0.006054229114294774, 0.08548095627056976, 0.046061300747697397, 0.023194395922004216, 0.0416031631550962, 0.01787906339872749, 0.09416207310653503, 0.05899393360220617, 0.07851010774292293, 0.031922092818985545, 0.038031259055940375, 0.050239230190674146, 0.013670190706879142, 0.07833152498689391, 0.08537488373657388, 0.15252013840982992, 0.19483592421297105, 0.11147670973573001, 0.12215576089558103, 0.14675638398095486, 0.13490040726479025, 0.15312403019878174, 0.21245550214042588, 0.2691609166081875, 0.09640959121527211, 0.21174589021792337, 0.1246356181499939, 0.164434720852202, 0.17734215324444158, 0.13305586672598316, 0.10036798284178781, 0.14979522495019823, 0.15516505696840827, 0.11012362226122811, 0.1903816438730686, 0.14637309487067884, 0.21901868464004612, 0.5810559336696902, 50.69421829715852, 146.74929834181265, 117.29727191309776, 111.88939817490117, 75.83521473792293, 58.621508844437145, 34.274172629079516, 55.921796368014434, 59.82090296283845, 77.96179048476681, 74.06102472735991, 61.52261541735742, 30.40455637439605, 0.6309722616307197, 0.355062416844791, 0.21363619684932694, 0.29099629170471625, 0.20939151816550763, 0.492592420909674, 0.2191554160127717, 2.205515407746838, 0.30243995990003314, 2.629135799023413, 2.913789802020596, 3.341337221284067, 1.8051660709804105, 22.149022279247163, 85.86239322539299, 94.98685390718522, 89.53803062438966, 87.48571318964805, 79.05323705365582, 68.34954384834536, 72.14499396662559, 79.01909674367597, 80.80772107647311, 82.9718731295678, 87.42174717687791, 84.64405013668923, 81.09043767375331, 74.21977873771422, 77.61892041852398, 81.15650607693581, 85.10550129798152, 79.793027447116, 79.7991071208831, 78.74964560231855, 77.20865618798041, 77.57356997459166, 82.00790359127907, 85.23077395654495, 88.02366625878119, 78.14780496781873, 72.49346517747449, 64.24000209377658, 65.37562239554622, 66.68049689262145, 80.56960182805216, 82.86325485475602, 89.21301518717121, 80.62490724748181, 81.01144898322322, 80.91434678723736, 94.89274840201102, 35.49342963003343, 58.85787871576125, 90.9541239277009, 78.62189400580623, 83.83695971581244, 65.98622952738117, 68.43218034313571, 80.15308533945392, 88.96616474274667, 88.74184439259191, 84.09340427767846, 79.3223116474767, 71.10216125365227, 66.29383748577487, 63.365541042820105, 64.04355802843648, 67.0242691040039, 80.93788100827126, 88.01517040498796, 86.16352142826204, 86.85787508564611, 84.72309374040174, 76.14841599618235, 78.68229066171955, 78.34928143408992, 85.08794476909023, 85.32502066704535, 81.27408304522115, 84.72752601869645, 87.6075263177195, 81.90026590901037, 72.19307438019784, 84.79463777234479, 88.5020463697372, 91.71234161623063, 71.69825169347948, 0.8632331437641575, 3.8834656534656404, 7.202196784557835, 4.737382310052072, 1.1594064125130255, 0.6454586778436938, 0.4258481136733486, 0.42641088186252507, 0.4103285819292069, 0.4800755554629911, 0.16190010363296156, 0.17078724449440358, 1.191421655877944, 44.182734720168575, 89.4338446278726, 84.03030118634625, 97.50594123717278, 70.45791979758971, 33.98307392674108, 58.57245568306216, 72.64326049435523, 97.48851806886735, 91.39633194092782, 110.71365202626875, 44.47677912250642, 0.9100261619014125, 0.13429882906136975, 0.31193534392983685, 0.12994882860972037, 0.15340700775625246, 0.1786422350954625, 0.24296020397976523, 0.18000607078354205, 0.11552966725561889, 0.150852732720875, 0.11657310199112662, 0.13386886987474658, 0.10325974259044855, 0.1805817245716049, 0.2123725501399848, 0.13111737316414235, 0.09337648824458161, 0.17357871567289676, 0.12399323044284699, 0.24585109804907154, 0.2338272255034216, 0.16781664663745513, 0.15209643050066887, 0.08283501881505213, 0.12741056481196036, 0.1413395294859525, 0.17584563112787663, 0.1894991105842975], [0.08030974786848792, 0.005736074235755951, 0.02386556746768615, 0.039212497687267686, 0.006044386799687581, 0.02925439272075892, 0.02142784504910871, 0.06937546685578362, 0.04005803659017529, 0.03662417387409556, 0.048062399014710426, 0.035267271281730746, 0.03609964496365959, 0.044971988836844126, 0.08368276405118166, 0.023642497985894163, 0.06760841611051752, 0.039196091914369215, 0.040116979395069426, 0.02478148303775778, 0.2325435072904633, 0.04127455740085533, 4.7133465159323915, 71.18111072048065, 101.47716845235517, 107.13287322751938, 86.28990803995441, 70.47458987082206, 26.331384797250074, 100.28483067789386, 94.7555595828641, 48.22806335264637, 57.40622520446778, 51.66176895941458, 21.045783104435092, 0.29430845752358437, 0.061100587293866186, 0.27511596319175535, 0.24173332949078855, 0.045548090786342664, 0.17636293965962627, 0.12269356227930515, 0.5699379141292265, 2.3364502528021416, 1.6534069949580779, 1.805155039314301, 1.24356061941193, 4.839706651626095, 38.613078901844645, 76.59426396892917, 93.49234457938903, 85.29528125639885, 84.28013263210174, 75.76273718187886, 62.88489772427467, 63.04680532024753, 73.01863916458623, 76.67411558089718, 76.52279053964924, 76.79561491935485, 80.45804962035149, 78.54563528491606, 75.28936986000308, 78.9669684440859, 77.98237508343112, 74.49241484365156, 73.06227161038306, 70.74754761111352, 71.62687240108367, 73.51289702999976, 74.29966172864361, 69.20637776774745, 72.51493623179775, 73.47845861988684, 79.89595828517791, 73.74694485818186, 67.40195412789622, 55.94673087519985, 55.96165549370551, 60.07199348941926, 70.56243527320125, 75.29681451859014, 76.82660948845648, 71.5911082298525, 73.24493638930782, 69.71833336737849, 84.2416306464903, 35.209885412646884, 30.751895981450236, 74.75604518767327, 73.85780672873221, 82.8957320797828, 62.83824897581532, 60.25478770655971, 68.30985730694186, 77.95633839022729, 75.50739872840144, 74.01409749061831, 61.96874580075664, 54.122271768508426, 53.29391425655734, 57.08624609055058, 57.07693830613167, 65.80252924273091, 74.65804869128813, 77.24775437385806, 75.63606815953409, 73.87885416707685, 81.52363208032425, 76.51811507440384, 75.33781897637152, 71.59502275528448, 75.1582528698829, 77.04089641571045, 72.00004669927782, 77.24831135042253, 80.30921136179279, 75.20357193485384, 67.52025281229328, 66.43033596777147, 81.99229255799325, 83.331891798204, 84.13300452693817, 35.30361829265472, 1.8070930579016287, 0.5191472040549402, 0.9160757437348367, 1.2895793371623563, 0.403681451514844, 0.3931865066049561, 0.1556651285218616, 0.09862750002573575, 0.08417362722778514, 0.049443437207129695, 0.04444578219385398, 0.04512333333672536, 0.1901176193308446, 14.981732137741583, 32.79986350767074, 50.764452257464015, 84.41315589412567, 43.29416490370228, 11.830327357015303, 41.003959640379875, 63.14013419612762, 74.49800029877694, 70.3320352492794, 77.286130843624, 7.31849653105582, 0.14400697102950466, 0.100336910315579, 0.04069304687061137, 0.17126801063216504, 0.032337318219605, 0.13120260810659778, 0.047976474593123125, 0.02559547060950389, 0.05463126205628919, 0.07987923709855926, 0.06361850762679692, 0.04536948887811554, 0.03764444211077306, 0.029974660926288175, 0.01768932065686151, 0.034375242333138184, 0.0686894964066244, 0.03713109042315233, 0.02578060341728551, 0.02240155429218806, 0.02096369344320509, 0.028537171629948482, 0.03657243229568966, 0.014147078524523926, 0.07809637429853601, 0.028143490536979614, 0.06359347570387107, 0.09407684582495883, 0.028631658999309428, 0.04834123586695041, 0.01296474630268471, 0.055122316754873724, 0.04416662741512541, 0.02553434062358593, 0.02140301613948278, 0.02508723447399755, 0.025040066440499602, 0.0605005297749754, 0.029149607214475834, 0.06874163635075092, 0.06194583891380218, 0.015015378857271807, 0.03515090252603254, 0.019732415863883593, 0.0286833239689229, 0.09099695020385327, 0.05203028247060795, 0.18436219993858569, 0.09888471404631292, 6.816636131655786, 91.09764345230596, 117.10455802179153, 112.99634595071117, 98.86803919269194, 85.85654889383625, 32.152364523180076, 69.76526844886043, 72.22309620149674, 40.89105029259959, 52.40586611532396, 56.340701580047615, 25.400212157157164, 0.24608714506030085, 0.09942816149803901, 0.15191469912327107, 0.08590199819375431, 0.14795960167482977, 0.7810232067300428, 1.027414366122215, 1.547207964524146, 3.770443782691033, 0.4013008792554179, 2.014858186725647, 1.5191762557914181, 4.790242131679289, 44.14076143695463, 88.36611270904542, 96.22215732451409, 90.13241091082173, 90.68174669819494, 82.22404187725436, 67.47240774093136, 65.00679016113281, 77.09023983247819, 80.92295246739542, 79.75842429745583, 80.26309997804704, 83.0903914666945, 80.35271044700377, 77.31847470806491, 79.74264852462277, 80.67326222696613, 76.14294821216215, 76.23615157219672, 73.61232126912763, 73.3794423072569, 76.0707530667705, 75.77368059465962, 75.22315240675404, 76.24667136899888, 74.54669260209607, 82.69624817755916, 77.23619907133042, 68.85495693452897, 59.00860363437284, 58.94784219803349, 61.806292995329834, 73.27877075441423, 76.75851714226508, 82.29244801305956, 74.95245395168182, 79.26546081419914, 72.46542023074242, 85.86760213298183, 37.923259504379764, 38.07225073537519, 79.11968984911519, 76.17954392586985, 86.55629188783708, 67.4511484945974, 63.572010686320645, 70.75541588567918, 83.08581013833323, 78.00196340007167, 76.90363699390043, 64.01308513456776, 57.88146741928593, 56.1461010286885, 60.63836020808066, 58.162148306446696, 68.8259941531766, 77.02202981518161, 79.47726880350422, 76.39425446910244, 74.95002208217498, 81.49679522360526, 79.27925186772501, 79.63446171052995, 76.08914113813832, 78.78595890537386, 79.09485340118408, 71.66120882957213, 77.92427693643879, 82.96883721505442, 78.48647025323685, 70.20909247859832, 68.36844182783558, 82.48462061728202, 84.93877703143706, 87.83599653551656, 40.476977440618704, 2.3360487001557506, 0.4265633027159399, 1.363525085391537, 2.0061505249431058, 1.0397189639268383, 1.187077630912104, 0.7541180149682107, 0.17754913487982366, 0.21769911351223148, 0.0844458029455235, 0.04645831815357651, 0.08191889257080133, 0.16379106909998004, 20.03622385763353, 34.64433062461115, 56.63662872006817, 76.04754832483108, 36.9036982136388, 22.82307178743424, 48.618052851769235, 75.43223827115952, 80.96401968309956, 78.5867181901009, 92.09971489444857, 12.932133886121935, 0.2400504947910386, 0.04236527508304965, 0.04249907999990448, 0.030919722311439055, 0.05041770569439377, 0.03948106896132231, 0.02342774055808062, 0.03588676445126053, 0.025494454255808267, 0.037871951072086255, 0.03706418796472492, 0.020106262940492843, 0.05642957301930555, 0.01844108273695794, 0.042289309804478, 0.08221901517601744, 0.02823591904504405, 0.07477356751839961, 0.09225472867969545, 0.015011119408412807, 0.015879807573172356, 0.06914337285824361, 0.033076765436318614, 0.048363892917311004, 0.02855399109032606, 0.03359821467329899, 0.020592960514008038, 0.2400079922329995, 0.12865657617728557, 0.13419931424000572, 0.12908279685483826, 0.11402293318702329, 0.11797668998159709, 0.07491114924872115, 0.12142376388393103, 0.11205569600626347, 0.060807133484030926, 0.17275486471912554, 0.14550717036810615, 0.2480188051178571, 0.14628940742583046, 0.14011133732574602, 0.08651479192438626, 0.2520270997117604, 0.1921552599918458, 0.3250637926882313, 0.16287062978071554, 0.2829291100703901, 0.2849852900591589, 12.812784987111247, 119.35417852094098, 126.66239353918262, 130.58731325211065, 110.64053904625678, 93.03247021090601, 35.40604314496441, 116.14643281505955, 107.86437957517563, 63.9839340794471, 80.4752766701483, 79.74176991370418, 32.662937487325365, 0.5455367880002145, 0.28316019283187005, 0.5598061255389645, 0.3636787303032414, 0.5127036385238171, 1.1486263909647543, 1.2228496468836263, 3.376505437397188, 7.021333354134714, 5.97648258170774, 9.012870230982381, 4.158796427711364, 5.740237735932873, 51.22107105870401, 93.00341329266949, 93.01436455019059, 94.04067623999812, 91.9197016377603, 84.03280365851619, 69.55014997912993, 68.02495202710553, 79.61119421066778, 83.1395544544343, 83.44928049272107, 82.67098026890909, 86.97491076684769, 82.87394723584576, 78.21633661946943, 81.35177735359439, 83.07543939159763, 78.76241683959961, 78.20699353371897, 76.9640964077365, 76.34171039827409, 77.31868651605423, 80.65937703655612, 77.07062013687627, 79.18168683205882, 77.98442256066107, 85.49325896847634, 80.61771362058579, 71.75007404819613, 61.90094763232816, 62.011887950281945, 64.70243384761196, 77.44385719299316, 81.67989146324896, 85.42582558047387, 77.35599610113329, 81.69776178175404, 77.37940480632167, 90.1189571811307, 41.254210779743815, 42.552456471227835, 81.58065549788937, 80.6781259659798, 89.258467612728, 73.06646070172711, 67.63364853397493, 76.07087073787567, 85.07576973207536, 81.80035529598113, 81.14902219464703, 67.77222587216285, 60.89500088845531, 59.282361538179465, 63.667622381641024, 61.87194562727406, 72.60059295162078, 81.45576723160283, 82.07426224985431, 79.18458938598633, 75.80432999518611, 86.035275613108, 84.82637759177916, 84.64417565253474, 77.6935552781628, 83.11532989625009, 80.57083345228627, 73.16280195789953, 79.73234838055026, 88.2885988297001, 81.05442247083111, 75.43041044665922, 72.47859939452141, 88.61660311298986, 88.96907514141452, 92.33595140518682, 41.82755147257159, 3.5966246839492553, 4.941758878769414, 4.94211777564018, 5.515723718750862, 1.534715950969727, 1.2942247717611253, 0.7870090500481668, 0.3644535209863417, 0.4063799502628465, 0.23168165837564778, 0.18465182713923917, 0.1411798154754985, 0.5777623071785897, 26.10406775628367, 50.79548997263755, 64.28971421334052, 99.4453493241341, 58.85483103413736, 17.962223560579364, 57.400816256000155, 82.42263147907873, 95.10997710689422, 91.18160570821455, 106.02153239711639, 14.082319909526458, 0.2488209451398542, 0.18868691948873384, 0.11595001969967159, 0.2412649892991589, 0.14854417272633122, 0.22147324567119922, 0.12058665960906975, 0.1638105890202907, 0.22827288886952787, 0.21822659569161557, 0.1539786012783166, 0.11425180195440209, 0.24452985684958198, 0.1531355674829214, 0.1532114714744591, 0.1181349943902704, 0.20388109369143365, 0.26476314291357994, 0.1731039096991862, 0.11501081122626221, 0.14173188907725198, 0.127517702208171, 0.1332513263989841, 0.1403180278477169, 0.18315729685127738, 0.08978381167135893, 0.10448516917324836], [0.006886141228249237, 0.04744956697968226, 0.018495909734478882, 0.04265538874953505, 0.05983751898090686, 0.06866468281875696, 0.028002520782812953, 0.04675520786775216, 0.08015492915987008, 0.05528566202208881, 0.028277900663294622, 0.04835355839121246, 0.0659004230833342, 0.06461882693392616, 0.10545293740447491, 0.03209406615144784, 0.06601922033775239, 0.03986983560025692, 0.032071445490263646, 0.007049412759501608, 0.030740459652377233, 0.14848941276150365, 39.260066017027825, 115.46865509402369, 98.00363509885727, 91.96953142842939, 59.60747111228205, 24.455536757746053, 62.96111329909294, 131.36385625408542, 112.30953108879828, 65.03964785606631, 52.47533913581602, 27.36568243272843, 0.32371615209887106, 0.06614176376212029, 0.044048125104558085, 0.07934081518361646, 0.07213044926644334, 0.18691514198097492, 0.5572073101516694, 0.7222680627338348, 1.1404438364890315, 1.8564391712988577, 1.3797032688894582, 0.7467345208410294, 13.662283093698564, 70.63631703776699, 84.80347094997283, 79.59602248284125, 90.79846858978273, 86.34255409240724, 82.4559324018417, 70.69705101751512, 58.11182821950605, 66.90164796767696, 77.153515508098, 80.5462480360462, 79.0626899657711, 78.34567285353138, 77.22690305402203, 75.83213175496748, 76.56183381234446, 77.02705829374253, 75.87292440475957, 76.67348800166961, 75.65447976512294, 72.92478469110304, 72.09472487049719, 73.43643434586065, 73.94424792258971, 74.59169787745323, 77.1982148385817, 75.20041050449495, 79.09778733407298, 69.89685612340128, 62.81799777861565, 57.00073842079409, 57.53495739352319, 63.03460282664146, 72.90183098085465, 76.20861653358706, 79.87367137785881, 71.24149168691328, 76.8157680573002, 68.19795993066603, 86.52106900368968, 41.62725956209245, 49.15307198801349, 81.4966618630194, 65.75424094353953, 78.0717815891389, 60.29758468750985, 60.381327290688795, 65.68764694275396, 77.71148050985029, 74.80161528433524, 75.12013527654833, 57.40434246678507, 56.15930372668851, 54.383085850746404, 56.312107501491425, 58.49415340731221, 70.86564233226161, 72.9722689044091, 79.13849369172128, 69.06661587376749, 67.97344346200266, 71.31062738357052, 76.9464143629997, 75.17318141075873, 78.51227944897067, 75.26459616999473, 77.93831117691533, 69.93669171487132, 71.87061632833174, 78.1845183526316, 78.86683817832701, 69.33517271472563, 63.52675045690229, 73.05298343781503, 83.37341400884813, 80.1050990627658, 65.44239290298955, 24.782344718133253, 1.494215272607342, 0.755464613677994, 1.6453731228266995, 1.5858035967234643, 0.08876862259761942, 0.11138056570123281, 0.18178426810810644, 0.03826181321675259, 0.09098945786395381, 0.1609278767700157, 0.07565746444367594, 0.08547611459488831, 3.9605399822035148, 31.793508837299964, 35.79194553436772, 35.51026052044284, 46.517866811444684, 31.92388842182775, 26.64615696476352, 47.02176586274178, 66.56068417333788, 74.48657051209481, 79.40192007249402, 46.885604704580004, 1.3013332096799728, 0.028909159028121544, 0.05659743820527389, 0.023044349941154642, 0.0533056847991482, 0.04240547554687627, 0.016688932401819095, 0.05936971122038461, 0.060278751151335824, 0.07228441761746522, 0.05941492572967565, 0.13917191434771786, 0.04061038215314189, 0.07771745955030765, 0.001492839148868957, 0.03433571985712455, 0.03957558888942003, 0.04369032373952289, 0.057279520758217385, 0.08362984269737236, 0.03309533540760318, 0.04252025083969197, 0.07987467121453055, 0.09805582223399993, 0.03655256380537345, 0.009391576243234018, 0.03223242163057289, 0.08823166391061199, 0.04585278310602711, 0.04799982878349481, 0.010229314455852635, 0.0575630882033898, 0.02625449774636617, 0.05293607801919984, 0.03299655220020683, 0.09840768641762196, 0.0345965268300666, 0.01804813900361619, 0.013269473096325755, 0.0695173540002396, 0.07152930007226045, 0.059566879269456675, 0.053636102351329984, 0.07118159574606726, 0.07461785248691037, 0.09105767799361099, 0.08948444749318785, 0.020001575110420104, 0.0882029585960892, 50.61584934111565, 133.04012821566675, 108.33594260677215, 106.81338048750355, 75.91100277439241, 40.63218562833725, 65.14317489439442, 135.43566088522635, 129.8756854764877, 66.38857841491699, 54.224645630005874, 32.375751349233816, 0.20264994443183948, 0.03906522877514362, 0.28750902882987456, 0.10708875728831177, 0.24969341203330025, 0.8482447254561609, 2.6823018106722065, 2.0202520585829213, 2.8456756376451064, 0.47883957984947395, 0.24691478048841803, 0.44549523522296264, 14.928578138351442, 76.26383566087293, 90.8820229191934, 80.04773832136586, 94.31407328574889, 88.3793467860068, 86.54233609476398, 73.93521862645304, 63.35169507611183, 71.13270082781392, 82.5323715517598, 83.05836139186736, 82.73086701670002, 82.43577926389634, 80.69846737769343, 75.1775509311307, 78.66095296798214, 81.16480581222042, 81.10332658213954, 79.0959987332744, 79.43977094465687, 75.17297744750977, 77.68183523608793, 75.32896226452243, 78.59344897731658, 77.49357715729745, 78.40668139919158, 76.0274814790295, 81.15390946788173, 71.93651999196699, 64.24252810016756, 58.957765794569454, 60.21970995010869, 64.79752386769941, 76.93287434116488, 78.26208714515933, 80.26101327711537, 74.9928778986777, 79.66900210226737, 70.1256871992542, 87.81629839251119, 42.784582338025494, 51.12975435872232, 84.24224253623717, 68.44101352076378, 78.7647859511837, 63.02765630906629, 62.612744069868526, 69.14445923220727, 80.14817453199818, 78.55145608225178, 78.15592427407542, 58.83228917275706, 57.95849492472988, 57.26984047120618, 58.73606166531963, 63.13196782142886, 72.8593909355902, 78.5267686843872, 80.72108376410701, 70.44302263567525, 70.99355866832119, 71.5965760138727, 78.62056824468797, 76.80353026236259, 79.72324848175049, 78.07866927116149, 77.67338645073676, 70.77509049446353, 71.80623454432335, 79.73601187429121, 81.63166984435051, 71.14037298387098, 65.57923263119113, 76.68936575612715, 84.437451054973, 84.21862202305948, 73.22131587613013, 30.128015548952167, 1.947875380996735, 0.15871844855287384, 0.8120661925884985, 1.1280769710579226, 1.2674552082054078, 0.7106729236341293, 0.5968336064007975, 0.21124050201427555, 0.01512393351614235, 0.11933577592454611, 0.10005051600596598, 0.028437564878033537, 3.4824381143816057, 34.937045343460575, 36.41443744782479, 39.186752996137066, 37.21431070758451, 33.58788728713989, 44.95491212414157, 60.091118966379476, 72.26936448004939, 83.26436427331741, 87.80366051581599, 62.852000805639456, 2.684324037644171, 0.014043007395230235, 0.07995929328664657, 0.017496906183359605, 0.04834681298703917, 0.0610443028140693, 0.014019768118047187, 0.008288077341632978, 0.16325327537713513, 0.05059662552910948, 0.053468957288010474, 0.00570388226356778, 0.009205608399614934, 0.034868587634616324, 0.04007565661243374, 0.02549839194773907, 0.08168633892050675, 0.038332415879854274, 0.1586963545771376, 0.017514420868528467, 0.037743006983110984, 0.018492046736120697, 0.01378054854520146, 0.09505383009391447, 0.030510503040145964, 0.009255024901170646, 0.01627557051007546, 0.20371347365360107, 0.08347325432564943, 0.09969256142334593, 0.09067676375590025, 0.2364185638725758, 0.10381074366910804, 0.1489613382446189, 0.1508906234296099, 0.29154674120007024, 0.11100124492640458, 0.11297283348657432, 0.14112340076075447, 0.18621838501384183, 0.14465293636725796, 0.18048924243738576, 0.08693657695285736, 0.2296785069929977, 0.1228950204207532, 0.12818019972333025, 0.2470314863228029, 0.11098196249335043, 0.19100706273269272, 62.38560745793005, 147.01186180114746, 119.56651995258947, 116.60914697954732, 84.1588294121527, 42.321848561686856, 84.09967222521382, 133.8690034804806, 120.75851255847563, 80.52944460222798, 77.23670897945281, 41.23542654898859, 0.8978524732012904, 0.11661103866513699, 0.5571177697950794, 0.3112818709304256, 0.5419629571899292, 1.2335270739370778, 3.186877225675891, 5.074452171402593, 6.484766842857485, 7.007387857283316, 12.840674019628956, 3.6305931450859195, 15.248616087821224, 84.3976782214257, 91.09210506562265, 79.12981740890011, 92.16453598391627, 91.51936884849303, 89.24642593629899, 77.36148741937454, 66.05488669487738, 74.85634019297939, 84.65872764587402, 86.041057186742, 83.52501361600815, 83.83344527213805, 80.33185912716775, 78.61499063430294, 81.61907903609738, 86.03537759473248, 83.49327379657377, 82.67429074933453, 82.5574904103433, 79.53832441760649, 79.43442867648217, 79.38511663867583, 82.99284996524935, 81.57488961373606, 82.12940292973673, 81.12660192674207, 83.63596177870228, 74.86680507659912, 68.99402064661827, 63.31540138490739, 63.46089386170911, 69.40032328328779, 80.04863262176514, 82.29014950413858, 84.56995656413417, 77.22625978531377, 84.26956576685753, 74.23757060881584, 88.97134227137413, 47.92489159491755, 56.49313665205433, 86.66906003029116, 73.18755211368685, 85.1494396886518, 66.4543487179664, 67.40274644667103, 72.95737174249464, 84.63383628476052, 81.23367478770595, 82.39304111849877, 62.92146990376135, 61.72029895167198, 60.28832789390319, 61.79709503727575, 66.7513584321545, 78.8854145234631, 81.39288379300027, 82.66996045266428, 71.84818821568643, 73.3824311533282, 73.60169164596066, 79.70235009347239, 81.02742087456488, 84.25935191492881, 80.49103675350067, 81.19294489583662, 71.4806385963194, 73.81187577401438, 83.628830909729, 85.76772289891397, 75.9740666420229, 70.90457577859202, 80.5667777215281, 87.34486087676018, 87.95289885613226, 74.72263443854548, 30.207243504062777, 2.193503394242256, 4.6598037115989195, 6.165087299962198, 4.463420442996487, 2.084582361482805, 0.5782951366516852, 1.1494573205709457, 0.6098252318559155, 0.4056598889010568, 0.3688610086758291, 0.3220693388533208, 0.13098375210838933, 7.782483504664514, 51.914349986660866, 52.21802380777175, 46.55465472129084, 62.728736400604255, 44.95617512733706, 41.9445243958504, 66.19455445197322, 85.19614727266374, 92.34665947575724, 100.01907440923877, 69.90496758491763, 2.8484659137264376, 0.12049460648408822, 0.18436062179746168, 0.09924223961969537, 0.16135405148229293, 0.11274348208380323, 0.10893794798081922, 0.16720593666597722, 0.235926965251565, 0.2301332261413336, 0.1842418781691982, 0.23856814530107284, 0.0924760208375031, 0.21168539991542218, 0.10853931412941988, 0.13993404925830905, 0.17379274531718225, 0.12584962236184266, 0.25371509784412, 0.19666037792640348, 0.2014577584040742, 0.16115362755954266, 0.18078308312162278, 0.2543927026131461, 0.1604239288116655, 0.1981481053535977, 0.0720947725518096], [0.06209044567038936, 0.05689459221978342, 0.02150568724309485, 0.021174128219905882, 0.13723112252210418, 0.04035241736639892, 0.0214259279140782, 0.074571933176729, 0.09199602078766593, 0.06467883460103505, 0.04942888919744761, 0.04303698097505877, 0.04962756643973051, 0.07571136639002832, 0.06903720839369683, 0.021527587781630216, 0.019660146959546595, 0.023729452795739618, 0.0228023351049952, 0.05979488235748103, 0.03844152595246992, 2.449625586309741, 88.31403932263775, 98.50806759249781, 104.47152153138192, 75.75275082742014, 83.2086117036881, 99.00382380331718, 45.54830397329023, 70.98392532717797, 55.8670675370001, 43.56332186729678, 35.91858317775112, 2.467912901793757, 0.01605441912092389, 0.03851781681840939, 0.04683585011310155, 0.13659815003554668, 0.09753699684816022, 0.26379873014746175, 1.317550862027753, 1.2351341425411164, 1.3534344204010502, 2.6150767985851537, 0.4263191658162302, 35.77358491959111, 87.28625282164543, 85.8340266443068, 83.88675028277983, 86.79985538605722, 79.49866925516437, 84.36993921956709, 78.67231215200117, 69.19290050383538, 57.80957037402738, 75.27885006320092, 80.3630341252973, 78.01496213482272, 78.65503018902194, 78.75109687928231, 76.21569248937791, 77.71217084700062, 78.59407655654415, 71.82005697681059, 71.02405901878112, 70.1585566612982, 71.65282280214372, 73.52911995303246, 74.91817243637578, 72.1974439005698, 68.11837503986975, 67.61890042212703, 74.60532419143185, 76.68242316092216, 76.09387936130648, 65.5920470145441, 56.00679020727835, 55.378587322850386, 57.23974804724417, 66.992858763664, 79.17941185735887, 75.52162124264625, 74.74296800551876, 67.68485115420434, 75.084959460843, 68.46290819106564, 77.80429163286763, 41.982508628599106, 47.50662180685228, 77.14307415869929, 61.37726806825208, 64.04532309501403, 53.847560728749926, 57.674425109740234, 61.999312831509506, 74.48224806016492, 75.23375065095964, 72.57323049729871, 55.01054348484163, 55.39168411685575, 55.140264111180464, 56.813331496331, 64.24444613918182, 74.7257488004623, 75.86582491474768, 69.57227999164213, 65.86081566349154, 69.94677220621418, 69.16643234991258, 71.4011086187055, 73.74693701344152, 75.17424045070526, 72.10148703667426, 70.79849919965191, 70.44365805964317, 73.63956605234455, 78.86168418392059, 77.65209582544144, 70.73803978581583, 59.26536590822282, 68.79666266902801, 81.74708950904109, 78.49176545296946, 83.74105776509931, 79.76090323540473, 35.99278265430082, 0.6406713637613481, 2.027812917386332, 0.600229459664514, 1.4673326957610346, 0.3481324467687838, 0.25899039461247386, 0.21022211069301253, 0.10317467618733646, 0.10122331234836772, 0.039550426731547045, 0.0398514686422723, 0.25473856066744177, 7.527649566050499, 40.82839435146701, 38.73653550301829, 46.72110834429341, 48.872089078349454, 12.594504106429316, 43.72161303797076, 76.72479260352351, 64.84764391376127, 71.43572745784637, 77.35403491604713, 31.627696521820564, 0.4771601925453832, 0.026702486812287284, 0.04032371588231575, 0.033651090061832825, 0.030858402718759836, 0.03985140735523836, 0.034694356257997216, 0.052175046275219614, 0.024967883721054084, 0.0006452512001663808, 0.06689550234906136, 0.023904517292976383, 0.10788955665644138, 0.040761895192366455, 0.02077414030810037, 0.02060538837535968, 0.0726552424772132, 0.033188671729857885, 0.027718918863683942, 0.022304856759165565, 0.09401064050654251, 0.03349937783974794, 0.04810609283947176, 0.03904150303212866, 0.01087759912479669, 0.04237367523713939, 0.07227426695246851, 0.00941049574213403, 0.11840343925981753, 0.030065963285103924, 0.019124825785477317, 0.06338682731673603, 0.01622165898762403, 0.015055713386485174, 0.10785649230162944, 0.04523520132586841, 0.04002150185706635, 0.058114751948103796, 0.119531266241064, 0.06466455472212645, 0.12532562588251409, 0.0378737667004668, 0.0139747949264523, 0.01674110490468241, 0.05179685164964007, 0.0747745481109427, 0.12889671409803052, 3.711991396642501, 107.18288344721641, 110.99083023686563, 117.81076508183634, 84.56292767678538, 88.08119958446872, 82.29966517417662, 54.46403572636267, 89.65742757243495, 71.09816043607651, 44.03628126267464, 41.38760666693411, 3.2826269393967045, 0.052760199553543524, 0.015029364749939452, 0.13285587181247052, 0.19429342671027108, 0.6285530172528759, 2.0835338629061178, 1.9987263362253866, 3.6961410987761716, 1.2850149240224593, 0.9065867948435968, 0.38593943741533066, 39.730032643964215, 89.737075221154, 88.94448188043411, 87.05320912022745, 89.83685247359738, 84.36648753381546, 88.11766978233092, 83.84423963485226, 72.42775763234785, 59.346327550949596, 80.76837185890444, 83.57903249802129, 81.83484077453613, 80.66335431991085, 81.40340358980241, 77.08022209905809, 78.20753482080276, 80.07630886570101, 75.88972783857777, 73.5352074715399, 74.4912616668209, 75.15660547441053, 75.35008815027054, 78.15000933985557, 74.4873079176872, 71.35283993136498, 69.66403207471295, 78.33390574301444, 79.38670127622544, 78.7421303410684, 68.54833741341868, 60.31438419895788, 59.68442801506289, 60.28957128524781, 70.8883842345207, 81.67101121717884, 77.81134405443746, 77.19444151847594, 71.94677306759742, 76.1349230427896, 70.7813427525182, 79.53490411081623, 44.91376646103398, 52.55642237201814, 81.65783989814021, 64.16612032921084, 65.2641329457683, 56.522852528479795, 60.38404157084804, 65.46286767528903, 77.2563914329775, 79.21241467998874, 75.47455280057846, 59.27752133338683, 56.91955320296749, 57.110109790678955, 59.24822907293997, 67.9488423562819, 76.66945580513247, 76.24235676180932, 71.7288383360832, 68.0314866958126, 69.42602265265681, 71.62029066393453, 71.98628702471333, 76.68006973881876, 75.19058888958347, 72.22399050189604, 70.89280866807508, 71.02318040786251, 74.94812365501159, 79.07029936390539, 79.04081098494991, 74.44753508413993, 61.81706774619318, 72.12088707954653, 86.02242592842349, 82.47604631608533, 85.79222202301027, 84.51367839690178, 42.24233819592384, 1.249838250298654, 0.9837873748713925, 0.6452106492173287, 2.8895066534319236, 1.709542731123586, 0.679782665064258, 0.44956947466538805, 0.21635360264730072, 0.19417315090615905, 0.4882787023821185, 0.06296829050106388, 0.31977659091353416, 9.055676037265409, 40.06216326067525, 34.841064945344, 45.91285297947545, 33.25079879453106, 20.655709274353523, 48.64417583711686, 84.28285475700133, 69.91754270369007, 81.23188618690737, 88.03604525904503, 44.512182435681744, 0.6043977134170071, 0.003252961107664892, 0.061556746687499754, 0.002940199248710527, 0.020951506899549596, 0.0124448646731194, 0.02043014384746071, 0.015039738538044115, 0.015970876275171197, 0.020919128193429882, 0.0616606665144284, 0.02032134787089402, 0.16600471080070542, 0.03745527201963048, 0.045441865034761934, 0.03488004447952394, 0.050447510345087904, 0.045391429636266925, 0.06344365571895916, 0.018199971884549148, 0.02582176149101748, 0.018266117831151334, 0.08536619629951255, 0.03502631747734643, 0.03815893526940096, 0.032975285599428805, 0.13570162798127822, 0.2227374133203299, 0.23132539684734038, 0.11739827827700686, 0.1893997949457938, 0.14051451407853635, 0.07979351185983227, 0.16945385314043493, 0.12444300832407129, 0.16319482286851253, 0.20160621092204126, 0.1555067781479128, 0.2329944419644533, 0.26049011897656227, 0.1636644041225795, 0.14312517318514087, 0.0992379495273194, 0.10303340191321989, 0.16050398499975282, 0.13474024892334016, 0.2619717943091547, 5.262506286944113, 119.74830612059563, 121.54606957589428, 128.77300523942517, 96.03652723373906, 102.97110511410622, 106.30923040451543, 59.39509830167217, 80.87291871347736, 71.76126849266791, 62.50784027960993, 57.73246834355017, 4.512599610513257, 0.17823533515536016, 0.22479089667960522, 0.4346982371662894, 0.7536402212515955, 1.1177878586515304, 3.342523983409328, 6.531064048890145, 5.903045515860281, 7.83890679959328, 8.407424938294197, 1.0952928205651622, 43.902740247787975, 96.495421009679, 90.19352143810642, 89.25193294402092, 92.55856160194644, 85.18245820076235, 89.01084053900935, 86.31327752144107, 75.07256477109848, 62.25927183704992, 83.93554456772344, 85.7498525804089, 86.37771421863188, 83.08680642035701, 81.46499264624812, 78.8653398329212, 81.18423723405408, 85.22925207691809, 79.11474766269808, 77.73504610984557, 78.30836326845231, 76.97016823676326, 78.28031832172026, 82.25905295341246, 81.16943420902376, 75.1967627002347, 72.56092994443833, 81.77369102354973, 82.37586898188438, 83.7724994844006, 71.52543206368723, 62.67731020527502, 61.675842808138945, 62.86061040816769, 73.16244109984368, 85.67858311437791, 81.11623118000647, 80.36829794606855, 74.6439124691871, 78.85517304943454, 74.62246494908487, 81.7454734925301, 48.80773475093227, 57.984743425923014, 84.07587128300821, 69.06976945938604, 70.70790813815209, 60.12313335172592, 64.01017081352973, 69.14737747561547, 81.21369423404818, 81.8321108048962, 78.11501395317816, 62.40190490599602, 60.95873155901509, 60.30248372785507, 63.040498149010446, 71.7756243674986, 81.17028928572132, 79.08641246057327, 71.8768842758671, 69.64468694502308, 71.68780249934044, 72.64124439608666, 76.14068108220255, 79.68837076617827, 77.33942016478508, 75.25735547465663, 73.97273217478107, 72.06876662469679, 76.77529704186225, 83.82222729344522, 82.59331733949723, 77.23005663964057, 64.0509085501394, 76.10497966889413, 91.01065312662433, 85.35364612456291, 88.04462740498205, 87.42985863839426, 41.69078234703311, 0.7215250800213506, 5.559535612983089, 5.4670770129849835, 6.571374737447308, 2.388386111105642, 0.7975401236645637, 0.47967933478855324, 0.543736910387393, 0.295322451500162, 0.3601284643575069, 0.2877207755321457, 0.5524554199749424, 13.406339614622055, 64.2164796398532, 51.7364469651253, 66.73117391524777, 66.20357590336954, 20.250414686818278, 56.55503557574365, 95.33800017449164, 83.38960555291946, 92.02378565265288, 101.16566165801018, 46.08319759368897, 0.5063708799500619, 0.11837241269888417, 0.1739102325612499, 0.15645634413005846, 0.15953229439835395, 0.0707798975429708, 0.09576714222109127, 0.16540864843033976, 0.09224506831097026, 0.09423318138766675, 0.2297604630791372, 0.13041073366278602, 0.21266147253974793, 0.13209289420516263, 0.1568171255771191, 0.1713307532331636, 0.15698224816831852, 0.2033997759703667, 0.11968705022046644, 0.06267944854053278, 0.145258697410745, 0.25126470433127496, 0.1469616342576281, 0.15777675795458979, 0.1090138289897192, 0.11989330407232048], [0.01281095702471512, 0.024111841752704595, 0.08149072602992097, 0.036390547700706995, 0.02058610977274516, 0.05517900726127048, 0.05806394116652589, 0.025250717637039004, 0.019197554342568885, 0.05420228346220909, 0.02043637214228511, 0.015679898844551177, 0.11546965958851, 0.017969329623625647, 0.04149915522805626, 0.017143793276421005, 0.04426707686375707, 0.2113578666842753, 0.10849112719898263, 0.3154080817776342, 0.7328754387074902, 17.05539511096093, 108.3287097561744, 87.65126858988117, 83.97584299887382, 59.554954498044914, 47.769808923044515, 58.2387129722103, 64.18665001469275, 61.842500394390484, 47.48880247915945, 48.292221561554946, 11.166656440304173, 0.15537547067769114, 0.0906980686610745, 0.08480409460683024, 0.058822950438386014, 0.36497203993701166, 0.0661146365887215, 0.7588444097388176, 2.47088041997725, 1.8004858253463623, 1.605228767279656, 0.5460955418886677, 63.48201582508703, 91.22783476306547, 84.97496481864684, 75.98590435520296, 83.625347845016, 77.6589991969447, 81.96028601738715, 83.6862700985324, 79.93136944309359, 64.37544545819684, 58.672621250152595, 73.02465608043056, 79.99871653895225, 76.95955430307697, 80.89362882798719, 73.02078862344065, 75.75416288068219, 77.25901942099296, 72.06091403961182, 68.46111959026706, 65.69680175473614, 61.04832633849114, 69.34210746519028, 71.38018669620638, 72.43819898174655, 66.1194645973944, 62.61979649143835, 62.43988913874473, 70.2567571209323, 76.09520512242472, 70.53179371741511, 56.32655359083607, 56.206744793922674, 53.14869242329752, 58.678367522455034, 70.3980722735005, 76.74289826423892, 73.69342803955078, 71.51852869218396, 71.46157587728193, 75.84342818106376, 70.72065584121212, 76.71941111164709, 44.32628170136483, 51.5121619163021, 78.32428809135192, 57.34101580035303, 55.52655873760101, 52.913581632798724, 56.49492525285291, 60.96693715741558, 71.64639795980146, 72.11395232908188, 71.33820949062225, 55.22077860370759, 52.662918644566695, 53.7340041898912, 57.908672978801114, 66.99791862118629, 72.63496860381096, 74.83250002707206, 71.39194596198298, 65.29213082405829, 72.11259518900226, 71.3520868362919, 72.67256059954244, 70.37470279201385, 73.66933684195243, 67.66393707644555, 72.64491573456796, 76.52484586161953, 77.22096458558114, 73.33097750140776, 73.77542126563289, 69.55892824357556, 61.31258426174041, 57.220893213825846, 78.40611657788678, 77.81499185869771, 77.54830991068195, 79.15571289677774, 88.7372003063079, 60.79255642429475, 5.649108329126912, 1.2079176739338906, 1.0126177762304585, 1.9977109326470284, 0.18406051451400404, 0.152257600078179, 0.03344313932522651, 0.5050453639799549, 0.09979193068800435, 0.02606947793655338, 0.09648313565600304, 0.039528516616912625, 25.087057967339796, 48.504578682684134, 43.048275439969956, 61.08549079587383, 34.87695855479087, 31.876810173834528, 48.542892394527314, 62.130888738939845, 68.14440388833323, 69.2407298857166, 79.28457060167867, 16.623128344935758, 0.37148853703852625, 0.07330490035876151, 0.04595918505783043, 0.06915985140949488, 0.028460172132679054, 0.022450714154289137, 0.05620898949282785, 0.08953072686469363, 0.007824541478898496, 0.05081564240578202, 0.036685901408594464, 0.015391804777356166, 0.029466258166658304, 0.004414442331425005, 0.01880075910218781, 0.028322816398295186, 0.07749361631971213, 0.03688973059216815, 0.055130483252146555, 0.05021408718499926, 0.016985732100663647, 0.04279577053121982, 0.04356081657592328, 0.06403924694525139, 0.06709756569996958, 0.054403109581119595, 0.0458603865286756, 0.024122203091880488, 0.03681425177942842, 0.06342357655446376, 0.02867949735974112, 0.02525475683561977, 0.0432188387569641, 0.06407528372120953, 0.02454896769185941, 0.09869266346457506, 0.03383233497339872, 0.036395592389688376, 0.04678824157904714, 0.06179482383172839, 0.03606486840233688, 0.07114537510900729, 0.1182515929723459, 0.12471637913897154, 0.2993347297512716, 0.7176524136335619, 22.63436459725903, 127.16896764693723, 96.87645573769846, 97.26779060979044, 71.77770322368991, 71.42826710977863, 82.83497456581362, 64.12182108048471, 66.64678019862022, 50.63128779011388, 54.33696662226031, 12.691390572055695, 0.10953535100505238, 0.04183363304623673, 0.09400778299858494, 0.07349743357589168, 0.6048212681085833, 0.7396331922181192, 1.6327825597217007, 2.680116805338091, 0.9165965609492794, 1.0981777238269006, 0.8833519609705095, 65.04462534381499, 96.39272551382743, 89.58684059881395, 81.94086244029384, 86.59366423083891, 81.49656772613525, 83.86498112832346, 85.16621174350863, 84.46642952580606, 68.14682006835938, 62.017524396219564, 77.74169844965782, 82.64957981724893, 79.27984022325086, 82.4079304356729, 72.37455460333055, 76.90726910868, 78.103788129745, 76.29923897404825, 72.26309653251403, 68.35348975273871, 64.87639096475417, 70.29134458111179, 71.72178591451338, 75.29871294575354, 70.0893582067182, 65.34232931752359, 66.53445136162543, 73.27927281779628, 79.24312683843797, 73.46187483879828, 57.99224299769248, 58.1799009538466, 55.52453479459209, 60.301456066869925, 71.38068091484809, 77.21268838451755, 77.41462769046908, 76.90295450149044, 74.79359795970302, 77.13925377015146, 71.6441543640629, 78.59324501406762, 46.19229047529159, 54.19552987621677, 81.15052838479319, 59.38353123203401, 58.03217664841683, 54.41985022637152, 59.713073084431315, 64.41380623848208, 72.88931862000497, 76.56232803098618, 76.04028409527194, 56.69640171912409, 56.35610865008447, 55.407577560793975, 61.89787249411307, 69.59972089336765, 76.32413033516177, 75.61425978137602, 70.77834606170654, 66.99972291146555, 77.27731335547664, 73.369338281693, 75.76639283087947, 74.85232368592294, 75.79064092328473, 69.20143558133033, 71.58449511374198, 77.97702497051608, 79.22671564163701, 76.57418927838727, 77.31961219541489, 72.25168243531259, 65.00924948723086, 61.5162572553081, 79.97085986598846, 80.74708123360911, 79.22865329250213, 81.82686267360565, 92.1753695703322, 68.25788590215868, 8.499913446364864, 0.8455770234427146, 0.3576453282467781, 0.8728553919542221, 1.8387622746729084, 0.8847037690781778, 0.1871097896007761, 0.710746713222996, 0.40376225846909714, 0.2539030651772215, 0.2828733388695025, 0.10532087916808744, 26.813087155742032, 39.88954759413197, 40.2952971766072, 48.04477883923439, 32.371617171072195, 47.25203644844794, 57.740622951138405, 70.11497912868377, 76.09136119965585, 78.81582383186587, 93.69226778707197, 24.859201600474698, 0.5130405027058818, 0.08703832875096029, 0.06821322720497847, 0.07212150902036699, 0.08092103240590903, 0.03324552311471874, 0.017510781950888135, 0.01700021499287217, 0.04232291808171619, 0.04885091799341383, 0.04944576611441951, 0.041321794382266464, 0.037849144634580424, 0.030679762506136493, 0.055719447817893765, 0.010429977781079229, 0.05929861060013214, 0.0217463250362104, 0.047274259249529535, 0.086768206148859, 0.038658865096588294, 0.04898265830331272, 0.012758377537642036, 0.01896961062635866, 0.08941657976397584, 0.09394406746592253, 0.14363665944866597, 0.13229046828083454, 0.13734113274803086, 0.16410217740603034, 0.23289665850179814, 0.17613349632630426, 0.10853189839831284, 0.1180376859021283, 0.15606144112685036, 0.214693428828351, 0.15960947009584597, 0.2054940764942477, 0.15484060341071698, 0.13965594402003673, 0.2392382270866825, 0.20162835086305297, 0.2938335136540475, 0.27983990648100454, 0.4609847056769556, 0.9473282699623417, 29.30045427814607, 140.0515845514113, 111.21992018914993, 109.09427796640705, 82.03662318568077, 63.750502063382065, 67.65534708576818, 77.99412650446739, 77.15431567161315, 67.29863105281707, 76.13712741482642, 16.728810725673554, 0.36595097773017427, 0.2197491801193645, 0.140890188274845, 0.17382944092875527, 0.8290845600347366, 0.7127843845275141, 5.219196946390214, 7.54922015051688, 6.144236470422437, 6.829375499679196, 0.9928125034897559, 74.56024831341159, 98.5608862292382, 91.55882789242654, 85.12947482447471, 90.79582491228658, 82.83339777300435, 87.48721153505387, 88.1191759724771, 87.99848464227493, 72.067974305922, 64.88423178272863, 80.75974264452535, 85.32813502896218, 80.31960564274942, 83.63680116591915, 72.91343335182437, 77.61341341080205, 80.68502149274273, 80.60721735800468, 76.0202564731721, 73.202237467612, 68.34703353143507, 75.13850765843546, 78.28170684076126, 80.13165350883239, 72.78790966156991, 68.48910962381672, 68.96142575048631, 76.7205721332181, 83.65879781784551, 78.10269771083709, 60.83144672455327, 61.24434678785263, 58.73770121605166, 64.78303463228288, 76.12077113120787, 81.5161560427758, 80.70254664267264, 79.00383087896532, 76.98577142530873, 80.95295859921364, 75.77364921569824, 77.49601687154463, 49.50182168714462, 59.418177527766076, 84.57007423523935, 63.310074806213386, 60.865539966091035, 58.10497976118519, 63.56394237087619, 66.35054711372622, 76.74507125731438, 79.38262201124623, 78.55719843218404, 61.50583944013042, 58.264588848237075, 59.300906504354174, 64.66156667278659, 72.3043441772461, 79.0493146834835, 79.74149534779211, 74.34621241784866, 67.99962920527305, 79.36411626877324, 77.78720578839703, 79.55716748391428, 77.33980455706197, 80.21251709230485, 69.57832828644784, 74.75419382895194, 83.0556078880064, 82.66418672377064, 80.87346000056114, 79.8153849570982, 76.56517567173128, 70.84872122733825, 63.53562678060224, 84.72955780644571, 85.35446982229911, 83.47286962693738, 85.54669733970397, 94.99621268241637, 69.75402693594657, 6.839040710080055, 3.312088106909106, 4.904899385667616, 5.289975135557113, 3.446165505916842, 1.0181178585175545, 0.1903011586757437, 1.1380831825156366, 0.705544424633826, 0.33074179123486247, 0.5207301868546395, 0.1824372048459707, 42.374172979785556, 68.87088175742858, 60.49515447308941, 87.83495318505072, 49.26583228572723, 50.07407980580484, 66.18286578885971, 80.5628239723944, 87.9853682364187, 87.10726722594231, 103.05116853406354, 25.405793689912368, 0.7379252451562113, 0.18838966205235452, 0.23155436520614933, 0.24667361600985452, 0.18323249604192474, 0.09245834718908995, 0.15823933716502883, 0.1704564170851823, 0.12015145272016527, 0.14695487736213594, 0.07896615222336785, 0.130574201504069, 0.10537575404610365, 0.10029485974941524, 0.12925403282767342, 0.1243615578559618, 0.218484322991102, 0.20524019495614115, 0.12936367533139645, 0.1798434303172173, 0.07840321549484808, 0.1707476990357522, 0.1206675814765115, 0.10123927762070972, 0.15276910166346258], [0.036080201652141354, 0.038940103634470896, 0.10701021795431453, 0.07882859347568405, 0.07018064058596088, 0.07726451772595606, 0.025867077506958477, 0.02100977937750999, 0.059008470120569395, 0.04033469009183107, 0.05006669569880732, 0.0852596641127621, 0.06739627870340502, 0.07019283670571543, 0.08416226614386806, 0.0014719140557234267, 0.05278150062827815, 0.0945247927560441, 0.01181466255201808, 0.06308868504880417, 0.44926101702355575, 58.02852099941623, 101.04700996029763, 88.23772568856516, 75.03226633994811, 46.562040544325306, 33.3561771915805, 27.04381665875835, 41.89229411463584, 57.243144819813395, 56.75819081644858, 23.35562767521028, 0.1984992494145709, 0.03130455317366267, 0.07456227280800382, 0.1418678237185363, 0.32816687779080483, 0.12421470646175647, 0.8884518389259616, 0.9425804247298549, 0.8603649718626853, 3.136764043761838, 1.4921685308218005, 76.58156333431121, 96.0716324467813, 79.949475103809, 85.83441888132404, 76.50148422487321, 75.29734796093356, 84.0042801826231, 88.40936860730572, 82.21914675927933, 77.92698337185767, 65.7524876440725, 55.51976519246256, 69.44826249153384, 77.71927818175286, 78.55096186361006, 84.41645852981075, 72.65382735959946, 76.49810314178467, 72.80104175690683, 70.18577791029408, 62.75796198075818, 59.16451000398206, 56.2013280007147, 55.875492788130245, 60.50467014312745, 59.96549329450054, 58.05501268756006, 53.49273920059205, 54.37590399096089, 60.46862356124386, 61.10460450572353, 57.02151521559685, 53.944294221939586, 55.51260686689808, 51.38471626466321, 55.89370043047013, 60.79021084693171, 71.84892562127882, 66.41999659999725, 75.97201916479295, 69.27802378131499, 76.0863248763546, 68.23539503159063, 77.43420816236927, 44.66390755868728, 47.83849354713194, 75.6072779624693, 61.097677599999216, 60.71466991978308, 50.74400494175573, 57.711311078840694, 56.979734128521336, 69.96505045121717, 67.99896240234375, 70.25287397446172, 54.407082911460634, 54.58964963113108, 51.273124833260816, 59.286068177992306, 68.18298432134813, 71.49752047754103, 64.61622407359462, 70.8853247857863, 70.61648553417575, 67.56617592227074, 63.67750283210509, 68.0205197488108, 68.0381311908845, 72.90235657845774, 71.63338353556972, 73.22650909423828, 73.58890471919891, 72.37492330612676, 71.44068533374418, 68.225934274735, 63.89175053565734, 62.2151687068324, 54.37542938417005, 66.89730198152604, 71.90567447293189, 77.39139941430862, 75.46897519019343, 76.94185656885948, 83.02522520865165, 80.97428060347035, 15.44623980599065, 1.124691843025146, 1.946740222554053, 0.4643983934675494, 0.8017983467828843, 0.08539010590362935, 0.1810030116429252, 1.3376021409227004, 0.186243757845894, 0.04493117167223846, 0.057689757011229956, 1.5437842256599859, 33.60467110910724, 42.047259115403705, 51.1617922782898, 37.9909086227417, 13.825702763372853, 23.98055930291453, 46.11445888396233, 60.88630499378328, 73.83522172128, 74.20646621334937, 71.57833699257144, 4.58131855533969, 0.06835149075355261, 0.06014880348717975, 0.06619154415544003, 0.05495939666645662, 0.06626109727808545, 0.034285020158295675, 0.024584669304350694, 0.0067665319206313265, 0.06442359708730253, 0.04496590992916496, 0.019516911500343875, 0.09319771396657152, 0.0037009482583661955, 0.05342644706909215, 0.025018031836577484, 0.046100248657767816, 0.02817614503475207, 0.07915331516414881, 0.10002040875054176, 0.04758003558362684, 0.04909221270692445, 0.03078690564800655, 0.049596306221980246, 0.06478861500058444, 0.020007010504242875, 0.09786351884324705, 0.058087494539757895, 0.03338603130091102, 0.08967618397887676, 0.04236006185472493, 0.05828887990285313, 0.04142182631297939, 0.02537062188850776, 0.057613155879681154, 0.014160882471309555, 0.058458572208520874, 0.04955438972120324, 0.07201334506633782, 0.08419082590168522, 0.06547673049593164, 0.041156001464133306, 0.03418314578612486, 0.040056010287615566, 0.024758682345911383, 0.687781848734425, 72.63707099422332, 114.31046547428255, 99.54643664821502, 86.70097243401312, 53.42613343269595, 36.71247482299805, 27.42053089603301, 43.21688244419713, 42.979563359291326, 55.73835888216573, 28.437907426587998, 0.2394059237333075, 0.026475108085921215, 0.03376417230033586, 0.35019751337747423, 0.8405114662262702, 0.7870020633262973, 2.320431783314674, 1.4357930397795093, 1.346877075491413, 1.0391395563079466, 2.0308150014569684, 82.42217648413875, 99.19187007411834, 84.50656321740921, 90.04869184186383, 83.11315690317463, 81.0242437547253, 88.81831492147138, 89.3395665384108, 86.24880160054853, 81.47043689604729, 69.05881035712459, 55.69437734542355, 72.38531758708339, 82.66802280179917, 82.42551049878521, 83.31760652603643, 73.87457878358903, 78.07542939339915, 76.26274524196502, 73.85935998732045, 66.67821407318115, 61.74661805552822, 58.41911062117546, 59.51222811975787, 65.00118509415658, 63.74188069374331, 60.96435231547202, 56.14879177462671, 57.48399011550411, 63.1156546838822, 63.80273234459662, 58.974541771796446, 56.08288418862128, 56.575659398109686, 54.40527862118137, 57.5248259113681, 64.31063221346948, 73.1229506769488, 70.8430887037708, 77.85610614284393, 71.87586445962229, 77.66303139348184, 70.24035376887169, 82.23802904928885, 49.37003789409515, 50.06410521845664, 79.08662426856257, 64.35798698855986, 64.05524669154998, 52.554378817158366, 60.79216418727752, 60.19457932441466, 72.3807833271642, 71.13191635377946, 72.99547364634853, 56.91489734957295, 56.727823826574514, 54.16327622628982, 63.23454956854544, 70.56103890941989, 76.97890727750718, 70.21066142666724, 73.31773557970601, 71.68658656458702, 72.0589763887467, 65.11385517735636, 69.13296668760239, 70.87372241481658, 76.65629233083418, 72.18666522733628, 75.09181576390421, 77.9105878645374, 76.47336867547806, 74.11237639765586, 72.6326387159286, 67.4836100301435, 63.99015888091057, 57.483448828420336, 70.98738485766997, 74.98343283130278, 79.8163341706799, 80.74912871083906, 79.98048536239132, 85.64688251864526, 89.99490830206102, 20.54686938562701, 0.09186544876185157, 0.8941130448252925, 1.0712428078536065, 2.0352618660657638, 0.5069790005443559, 0.8099512996212129, 1.1314465321840779, 0.6959044644909521, 0.046850382801025145, 0.07620571526668726, 1.6075023936648525, 36.20817961231355, 43.49963434280888, 53.179079025022446, 30.493592216122536, 22.380583324740012, 35.672987891781716, 56.17252603653939, 68.24831531893823, 82.61667113150321, 81.09749009532314, 85.69508844806303, 7.486305332952931, 0.054363069995757074, 0.014164097167761817, 0.04467537108388159, 0.05316857804333972, 0.0386628219407172, 0.03331207317270098, 0.04279742528113627, 0.038304549431608576, 0.0820702102576052, 0.056318762231498, 0.07015804099219461, 0.043913048481748956, 0.06070607499549947, 0.04727025644012517, 0.050527271589324366, 0.07953751591905471, 0.07600464783008061, 0.021771715105240865, 0.08880386264213631, 0.043611179196065476, 0.04768438825023271, 0.02678502895568888, 0.0733779161988247, 0.060280915349721916, 0.1839427055130082, 0.1608857266124218, 0.17845333313509343, 0.15050074596318508, 0.16639680992211067, 0.15786154856604917, 0.20815270802667066, 0.10686621640718753, 0.14781770686949455, 0.15642706424959246, 0.11252170729060328, 0.14266787998137936, 0.15268397397331654, 0.19817260484541618, 0.17074183080225222, 0.16127079304668213, 0.13453210283431316, 0.11797767057414017, 0.17117534463684406, 0.14050190427130269, 1.0566731638485387, 89.30775611631333, 126.35897467213293, 112.37010817373954, 99.591324252467, 63.11991437788933, 44.270878222680864, 37.286364647649954, 59.23856435283538, 76.85078697819864, 79.72576664340112, 36.0865939817121, 0.47190412458392883, 0.10221129763991603, 0.2809930220246315, 0.7658996505122032, 1.2741694479219376, 0.9938187140130228, 5.371005910058176, 5.134751748654151, 4.808008507374795, 7.565615657837161, 2.534529946504101, 88.29059923848799, 100.19255299721995, 86.68584777462868, 93.68701965578141, 85.34780179300617, 82.19284334490376, 91.31365622243574, 91.84996974083685, 87.13150747360723, 83.30570605493362, 72.96306702398485, 61.38544621006135, 77.53254982732958, 85.95596528822377, 84.277998862728, 85.46183293865573, 75.31211176226216, 80.42462318174302, 78.73510145371961, 78.18403197873023, 68.78569572202622, 64.78781992389311, 61.99990118703535, 62.38979262690391, 66.04181735746323, 66.14270856303554, 63.609838024262466, 58.868233773016165, 60.67887044722035, 66.85166128220098, 67.49831107354933, 62.38537996046005, 58.686781006474654, 60.885810775141564, 57.99851094522784, 60.01973182924333, 67.27806214363345, 79.4099138629052, 72.22778735622283, 81.47207644677933, 75.6231164932251, 81.26498314642137, 74.03863583841633, 84.26753397910826, 54.67722046759821, 55.190807773220925, 81.43078957834553, 70.40706234593546, 66.31694809083017, 57.15062002981863, 65.8597723130257, 63.27647578331732, 75.74286645458591, 72.30159851812547, 77.37359969846665, 60.84029559166201, 59.92678734564013, 57.697547481906035, 67.50256292281613, 75.5588916040236, 76.45530223846436, 72.29671124489077, 76.0684859368109, 75.29123690820511, 75.98726149528258, 68.97178080774123, 71.70127976325251, 73.8628665862545, 80.27971513809698, 74.75617070351878, 75.52917572759813, 81.09354419092979, 80.430859750317, 78.7547525282829, 74.17410665942778, 69.39739719513925, 69.06607458668371, 61.24187569464407, 74.0246251321608, 79.31423156492173, 83.9768785045993, 82.51078282633136, 82.18339043278849, 88.69025738008561, 92.1545260952365, 19.400748898906095, 2.492494885959933, 7.453748189633893, 3.660989307588147, 3.1333214284912234, 0.3142727701173675, 1.43811336688457, 3.1410298664723677, 0.7134722089094501, 0.1541081620680709, 0.225326698573847, 3.2606726980978444, 55.42169417104414, 59.440605640411384, 69.93751541260751, 54.41785373995381, 22.853250503540043, 37.8470007834896, 65.3101384255194, 80.3262815167827, 93.23792396053192, 93.63081993595247, 94.31792505325811, 7.424636848511235, 0.31855357750769586, 0.18305614260175537, 0.17050990534405555, 0.16641485895360672, 0.2726629190146923, 0.0968636591888724, 0.17676173438948972, 0.1114265769419651, 0.17869806758338408, 0.1355225625898569, 0.1167051449057556, 0.17567004377563156, 0.13570070867576908, 0.16186984315995248, 0.14309557154774666, 0.19904465805138313, 0.1358390794766526, 0.16368531832291236, 0.1890970676416351, 0.1916795193908676, 0.15017212488718573, 0.08884071913217345, 0.16715106944884026, 0.21130713634192946], [0.027870284430983088, 0.04198419230599557, 0.03695332738120229, 0.02315245835380929, 0.026455088293239958, 0.022234112369797887, 0.10693131089811364, 0.049627210208845716, 0.05826413909333849, 0.07660707639109704, 0.11528297928312134, 0.007291288742224776, 0.05702110781003872, 0.04511009916783341, 0.13350445717092485, 0.09685442782938482, 0.06976765790773977, 0.07886184169159782, 0.041178834714716485, 0.6225301565662508, 8.781645528731808, 90.99559122516264, 92.15714623851161, 88.57493185227918, 61.46625488035141, 31.404847060480428, 110.7706440648725, 101.25499756105485, 61.63058650109076, 68.1382457671627, 43.92599205816946, 5.708262083991881, 0.1566991633585384, 0.3140117179962897, 0.21876526275469413, 0.20624393867629193, 0.48198050969550693, 1.4262329979288964, 1.2555906513044912, 0.08552859161770152, 1.4335012724322658, 3.5697588997502483, 80.37387555645358, 91.0376782571116, 81.26490469901793, 86.3082568876205, 77.99187506398847, 72.96804058936335, 76.49734220197125, 80.94130915980186, 80.95406470760223, 82.52363251101586, 77.72709938787645, 62.974143412805375, 53.639153434384255, 63.93350024377147, 72.93109186234014, 77.16552580556562, 75.90056926973405, 74.39386137070196, 75.1690629220778, 70.40114741171561, 66.49026193926412, 59.34525282152238, 55.13871869733257, 55.530410505110225, 53.027342134906405, 53.25815008532617, 53.840112147792695, 53.025616292030584, 53.47159370299309, 51.44243394174884, 52.4427128607227, 51.990353753489835, 52.559426907570135, 52.34834847911712, 53.54869965584048, 51.44811353375835, 54.54791561249764, 54.12579405692316, 61.433844335617565, 61.915295662418494, 64.55425846961238, 60.50242262501871, 68.06935325745614, 62.13845891337242, 77.81499970343806, 53.085961957131666, 42.53219350691765, 80.41679413087907, 66.12847820405038, 66.07704024161062, 54.94596165995444, 56.07745562830279, 58.69965814775037, 66.9707836643342, 65.06225247536936, 64.54959084910732, 55.65512226473901, 55.08579415659751, 52.68580567452216, 57.00923427458733, 63.41370382616597, 71.309568343624, 73.74030036310997, 64.89545368379163, 69.30242876852714, 69.67104527258104, 65.90845677160448, 62.0604782719766, 62.29169414889429, 66.64889043377292, 70.14624826369747, 73.11821245378064, 73.77702159266319, 72.20515528032857, 64.2806339263916, 60.57808122327251, 60.75129701245216, 57.702972119854344, 56.103837490081794, 58.42653174554148, 67.9073436798588, 68.92233540934902, 72.8319735680857, 77.43175275864141, 78.08490583973547, 74.01165777637114, 91.87290776160457, 21.737149876932946, 0.6709907336100456, 1.1928234129182755, 0.9554553596723465, 0.17346770953266852, 0.05089040875675217, 0.7394524567550229, 1.093905649838909, 0.04290656216682927, 0.10880564459629598, 0.09183824497966037, 12.620210339946132, 30.470740487498624, 35.95128005550754, 52.13828594453874, 36.25089422349007, 20.5983446105834, 39.709102876724735, 62.395083904266365, 65.45399135158908, 66.64932189449188, 81.36625874427058, 37.209984333284446, 0.2359102492130572, 0.13011176018945633, 0.104468782552548, 0.03662461820509165, 0.05910700051895073, 0.04126969274253615, 0.052228013594304366, 0.04117054947381539, 0.06256894418789495, 0.02092701315339054, 0.09409138617376167, 0.039001145520277565, 0.0460387509496462, 0.03935527732415546, 0.07138987973092065, 0.12952648433706454, 0.009159307003081327, 0.049081322767080805, 0.038974795926121936, 0.025460051162348642, 0.05281202923206072, 0.03884860209279484, 0.0633669396742217, 0.06135655259112678, 0.011090908646433344, 0.060473758832461415, 0.042521288888829376, 0.025655949420686212, 0.01500829541680193, 0.012491967589143785, 0.09322284931136716, 0.06257531803942497, 0.07609576632779452, 0.02863595100690521, 0.03155350302075667, 0.04862438196376447, 0.06191827123984695, 0.06662013970555798, 0.0559505267489341, 0.02937081510261182, 0.07864722215961065, 0.13541923265062994, 0.07187380981180938, 0.6495255015550122, 12.84464640002097, 108.57548959793584, 99.38518016569077, 99.07237114444857, 69.418742733617, 45.7533537187884, 87.38283726476854, 87.2346422749181, 50.15657901763917, 54.156808237875666, 53.81599349360312, 6.107999163289224, 0.06810910053431027, 0.1604161760018718, 0.501414628158654, 0.8974488980827794, 1.0713020111283948, 2.5580043513928694, 1.98970488482906, 0.4384822212159634, 1.6240201073308147, 4.399136227946128, 90.87381732079291, 96.39329817987259, 84.20979669017177, 89.82858411727413, 83.06523338440927, 78.2619930082752, 77.92402590474775, 84.10654421775573, 84.546916561742, 84.98952465672647, 80.29405532344695, 65.21259692407423, 55.96759003977622, 68.17520233892625, 77.36897914640366, 80.97292346339073, 79.80791676429011, 76.25787365821101, 76.60734899582403, 71.25744004403391, 69.25937683351579, 64.07050863389047, 59.39205454241846, 57.343553573854514, 55.06254234621602, 55.57050105064146, 57.20677268120551, 56.25827689324656, 56.9332814985706, 55.00281249323199, 56.18738397475212, 54.46641660505726, 54.915716263555716, 52.72665715986683, 55.37305285853725, 55.1580128362102, 55.41072330167217, 56.75671992763397, 63.248909365746286, 63.06963351465041, 66.77719900684973, 62.294333904020256, 69.34480605586883, 63.61936938378119, 79.92552511153683, 55.99878464975665, 46.67433015761837, 81.1691596431117, 68.8712739944458, 69.5480005202755, 56.95646662865916, 59.00514410388086, 61.67554863037602, 68.57291498491841, 68.14563551256734, 69.09750846124464, 57.90801402061217, 57.900663498909246, 54.45805803422005, 58.79089640032861, 66.54589683778825, 73.34879290673041, 74.2186334056239, 68.41754990239298, 72.66087193642893, 71.33908810154085, 69.52214425609958, 64.0447739631899, 65.10268818947577, 71.17551742061492, 72.85869275369953, 76.25019365741362, 75.85605036827826, 74.16872516755136, 67.83176745137861, 63.613579965406856, 63.6813271430231, 62.655074288768155, 60.834086479679236, 60.71473267770583, 70.27439209722704, 71.36019829780825, 77.17612404977122, 78.08016761656731, 81.98212577450661, 76.88546857526227, 96.82421761174356, 27.919193583150065, 0.4124535566135761, 0.8011795928882015, 1.6221790448311837, 1.8969350692725953, 0.5863250864128913, 1.5103663672362606, 1.0464917940478171, 1.0359471147098849, 0.07369943563976596, 0.13122413517727008, 13.880347263428474, 36.21440833614719, 40.05791533377863, 39.606964357437626, 37.02215771521292, 33.39573821713848, 53.30352798584969, 76.32529135673278, 74.88279265742149, 74.69342847024241, 91.20478691593294, 49.320110044171734, 0.18540260862679253, 0.08666037927351652, 0.15499565960659137, 0.027145860198464607, 0.007131575210575736, 0.04099454077321195, 0.034317448660130465, 0.007291431426100674, 0.028724884238815116, 0.0304163335972736, 0.033792264744519226, 0.05093324839347794, 0.04400852218931241, 0.08475311911634861, 0.009291469618948478, 0.05938139789166951, 0.05138722826696692, 0.04107055201705906, 0.03681380744843233, 0.027169932596265312, 0.0391915068781424, 0.0382476597423515, 0.0380009449567766, 0.024236526392820864, 0.2522142856351791, 0.15685063426292714, 0.10754229666124429, 0.1485117212418587, 0.09019366871084898, 0.07195660859466561, 0.26920406268008296, 0.1648945727896306, 0.21616250967546818, 0.11764349536068978, 0.3343284310352418, 0.21184883711318817, 0.14250352347810424, 0.2517710731274659, 0.403671860094032, 0.20334115492240076, 0.36785544166641854, 0.23089785849855793, 0.1974580439949228, 0.7878774873191311, 19.017717684468916, 126.12062792624198, 113.80570350154754, 111.26960092975249, 83.64495185113724, 48.753315787161554, 121.91110887835104, 121.71840283178516, 86.04730160005631, 93.22311309076126, 66.19650779231903, 9.203207165964189, 0.4024145259491859, 0.5009474370989108, 0.7366022419544959, 1.4871982749431365, 1.6121125269320704, 3.86282344498942, 5.527745293032739, 3.5074924990054104, 5.9246303189185365, 4.402690385618518, 97.22866104495142, 98.25868329694195, 86.14512551215388, 92.65702878275226, 84.94972044421782, 80.89175393504482, 81.92740086586245, 87.32287991431453, 86.06995721017161, 88.50874577799152, 84.31123702756821, 69.94162605654809, 58.12791385958272, 71.81524030623898, 79.56996225541639, 85.70235267762216, 80.80996467221169, 76.36381687656527, 79.48915358512633, 76.46353921582623, 71.49852460430515, 67.31064135028471, 62.17275219578897, 61.09006820186492, 57.53086636143347, 59.472835756117306, 59.5144207246842, 59.379487268386356, 59.37955787104946, 58.713339374911406, 57.856525067360174, 58.84524476143622, 56.82248630831319, 56.57818148213049, 59.2893276676055, 57.84554635324786, 58.871603088994185, 59.65296668391074, 68.05175750486313, 67.15931630903675, 71.75927592862037, 67.2799684155372, 72.80425810044812, 68.24541276501071, 82.49178286521666, 60.82711642788303, 51.30491564350744, 85.10912556802073, 73.30559976639287, 71.86695283459079, 59.902962869213475, 61.6886571914919, 65.64020195314961, 72.849302599507, 71.579192069269, 73.35484904627647, 60.7715246754308, 61.22632349691084, 58.58463072007703, 63.14273080518169, 67.72924453981462, 75.68166963515743, 79.51446856221845, 72.01314741565336, 74.35745393076252, 76.52907417666528, 75.365691338816, 70.13341426849365, 68.99743310866818, 74.32908734967633, 75.58727387459048, 77.31302261352539, 79.48103427886963, 77.70148631065123, 69.1336727142334, 68.25368112133395, 66.90389156341553, 64.90125486927649, 62.762186373433764, 66.66341889289119, 75.9944551221786, 77.18014840156802, 80.81633460137152, 81.36063406544348, 86.62935779940698, 80.98925621278825, 101.70741942621048, 26.652038558836907, 2.4671941274596803, 6.378691244509913, 5.227665343592244, 2.836512245478169, 0.35809063983540385, 2.3231016916613427, 3.9115699260465564, 1.5743811644854084, 0.2615371160209179, 0.19455273215088154, 19.54216799428386, 49.292312206760535, 52.747226069050456, 69.51770413306453, 52.01928123351067, 33.19910980040027, 56.58326487387381, 79.08321180651265, 84.75260565357824, 83.95450530513641, 103.18226198996268, 53.95056609184512, 0.39355717058623996, 0.24430913159683829, 0.22534945138519813, 0.16026421480121153, 0.16175054794838353, 0.10989032550564698, 0.1648977597153956, 0.1663886587465963, 0.14337473398735448, 0.11721191206766714, 0.1924099382613936, 0.12319973189263575, 0.14494552066729915, 0.16643548204052835, 0.1937050405409067, 0.3088313395217542, 0.10148435680856628, 0.2140835615535898, 0.15485437767159554, 0.2289918470647066, 0.14427723152743233, 0.17235489021385872, 0.11008550938699516, 0.21890888891873822], [0.02895241235232642, 0.04041217605493242, 0.02679810224611673, 0.05435148674634196, 0.026489418608346776, 0.07826894326435943, 0.02960768374313991, 0.046634227262749794, 0.06658322192848691, 0.03459571477686686, 0.07241061528123195, 0.07121533425825258, 0.0529670164800219, 0.059362735989834034, 0.12821490350630016, 0.012543528179277577, 0.031512115120647416, 0.0973524539280803, 0.2954026762275927, 0.19314368195351095, 36.25756225278301, 95.91028967211324, 97.20365201273273, 81.48338856235628, 75.19151456894414, 54.285061897770056, 87.81523150782432, 56.04432336745724, 59.78708036484257, 54.858806594725586, 15.968065069567775, 0.12858770487289276, 0.07732983438238021, 0.10238650960907822, 0.07622067696384846, 0.3666430922044862, 0.8225899117608225, 0.22864254161475167, 0.6200667242369344, 0.6380724257999851, 2.1562653924188306, 89.54442408777054, 85.33357927876135, 84.12876836715206, 83.86207072965561, 77.25074321992936, 75.45020272654872, 72.91276654889508, 70.95520573277628, 82.14704575077181, 79.65366563489361, 80.37378141956945, 78.39339240904778, 62.996693118926025, 53.86618414232808, 60.572813480131096, 69.2723677235265, 74.06653173508184, 71.54225118698614, 73.64410815700408, 71.69141892463931, 67.37620769008514, 63.9063064513668, 57.240450151505016, 53.53918398580244, 53.06169425287555, 52.28046401854485, 52.760150278768236, 49.81932970785326, 51.79817330452704, 50.75897662870346, 52.63919222739435, 51.48548979913035, 52.82930166490617, 52.839237028552645, 52.21146952721381, 52.504921651655636, 53.79303193861439, 52.90073979285456, 53.193113265498994, 52.4696046306241, 53.365952507142104, 54.10128708808653, 55.60413929723925, 58.537024913295625, 59.890411284662065, 71.17122634764641, 60.30334272692281, 36.62304086069907, 72.02856233043056, 65.98098924083095, 67.85581942527526, 55.972924463210575, 57.97616520235616, 57.92813185722598, 64.94808796913394, 60.27528209071006, 64.27954350748371, 53.69027368484005, 56.11527904387444, 51.8491288154356, 53.869137687067834, 54.521396467762614, 62.10903721470987, 64.30634898524131, 71.44441158540788, 65.03997733516078, 66.05981319181382, 57.99952683910247, 57.45905168594853, 56.581954802236254, 66.39220268495622, 71.1074564533849, 72.99312806898548, 70.39438524553853, 70.18623290523406, 66.24843212866014, 59.679560353679044, 52.702479670124674, 58.47448664326822, 56.22897678805936, 61.422379247603885, 59.58384667673419, 68.36050295060681, 63.43006795452487, 70.72916738448605, 69.21399501062209, 80.895127173393, 66.62363821460356, 90.06398124079551, 14.19732282238622, 0.48608459592346226, 2.9211435106492813, 2.3814736691213425, 0.44505093487039693, 0.5582757270143879, 0.7878191420628179, 1.47357894768638, 0.09852977785011453, 0.09934655781234465, 0.3703342263977374, 24.70372865276952, 31.310037489860292, 36.99843129804058, 33.636763941857126, 43.630080607629594, 32.62633981243257, 24.812037060337683, 44.5506412752213, 63.251458906358295, 72.55295968824818, 73.68863490320021, 5.20093095879401, 0.15687472006726652, 0.07751818475944382, 0.07609119278288658, 0.013316673688560486, 0.04812541357692211, 0.036313479255524375, 0.07226397839164542, 0.08614188330548425, 0.0722212000419536, 0.09252515771696646, 0.038724886553902785, 0.03654887892245766, 0.061390107242210265, 0.021109432094700394, 0.11001789446679816, 0.05256784253663594, 0.021571293097710418, 0.026406591097193382, 0.038657597221073606, 0.014668089176167645, 0.044049255084246404, 0.028618543574045745, 0.06446942446693298, 0.03938011389466063, 0.07966022788276596, 0.046289759658036694, 0.030642861966043714, 0.03539826848634309, 0.0404335958732953, 0.096522573862345, 0.03132611280307174, 0.05228167805340021, 0.03565153332367059, 0.08060854514159503, 0.015672925529220415, 0.0603621666349711, 0.03934818334997662, 0.1405706836451446, 0.018720766116354256, 0.10368443875303192, 0.10681600700463019, 0.16608303563008386, 0.16531535424292088, 50.19362188154652, 109.84640813642933, 105.50038276180145, 92.58042489328693, 80.36912948854508, 51.90769372447845, 87.55499793637185, 48.11940585413287, 44.80030798142956, 63.87904990103937, 19.624510311311294, 0.03037216479799921, 0.0607857060047888, 0.21950522708075665, 0.38045415594693155, 1.0037445168822043, 1.3123915969364106, 2.0013588594813503, 0.9451386068136463, 0.7771542788513246, 3.2688795222390086, 98.07333561681934, 89.45426448698967, 88.51902238784298, 86.22095277232509, 79.80124873499717, 77.29904328623127, 76.94012288124331, 73.19833078692037, 85.66428215272965, 83.35815598887783, 83.67294188468688, 80.63188906638854, 65.73162063475579, 55.425247838420255, 65.45354812375962, 69.64219231759348, 76.15025951016334, 76.69267623655259, 75.82290634032219, 74.09572985864456, 71.29037226400068, 67.43858122056531, 60.32410775461505, 56.63964110036051, 55.46335758701448, 54.117780654661125, 55.165010344597604, 53.593995186590384, 55.77224816045454, 52.850396171692886, 55.143398084948146, 54.36271698244157, 56.13860145691903, 54.760790486489576, 54.65807537878714, 54.81877096237675, 56.23453086422336, 56.02867703283987, 56.68500331140334, 54.4210151703127, 56.07865195120535, 56.61261596987325, 57.25875585309921, 59.277533100497344, 63.45827764080417, 75.17069462806948, 64.4830596062445, 40.13439370739845, 75.51710267220774, 68.20967997274091, 70.08265879846388, 59.89722444165138, 60.38240202011601, 61.74791636005525, 67.41529803122243, 64.34690629282306, 67.03730706245669, 53.636741176728286, 58.46438261770434, 54.889208885931204, 56.05836545267413, 57.820278444597804, 64.60548070169264, 67.48467691483037, 74.25249914969169, 68.87591023598948, 68.37305453515822, 60.389740774708415, 60.43283977816182, 60.296588405486084, 68.91529083251953, 74.0517993127146, 74.81887371309342, 72.90583964317076, 75.16538373885616, 68.23886240682295, 64.24750166554605, 56.53334879106092, 60.99628040867468, 58.91778507540303, 64.13635346197313, 61.25653359197802, 72.90463155315769, 65.96649216067406, 72.71153326957457, 74.03403097583403, 86.42937183380128, 70.17081799045687, 95.16852240408622, 19.28895546543983, 0.48448678166154896, 0.4817859540062566, 0.7944614920885333, 2.230813959913869, 1.5584939718246462, 1.8992354168045906, 2.887846019960219, 0.5081445267123561, 0.14021302783681502, 0.19182856945741564, 27.30799025104892, 35.19692590159755, 34.10318866852791, 20.453993543501824, 36.916022300720215, 38.74740439076578, 37.836076982559696, 52.30444538977839, 70.31643206073393, 80.01683788914835, 87.60845199708017, 8.968829858687617, 0.3568684844480407, 0.09838186159369447, 0.05471665021632949, 0.036063673305175, 0.045780613793120276, 0.03173230985750354, 0.0389131335090966, 0.10687954633707002, 0.008718565128923906, 0.11980857474789505, 0.07178466016006085, 0.014743697266244601, 0.018741406440254182, 0.035323774096586054, 0.04835552340673824, 0.03869736484522301, 0.04326063651411284, 0.0540022655660587, 0.05324514853137155, 0.026299461361862002, 0.012540967530390669, 0.07438224980667715, 0.031064522505227118, 0.12269249741709042, 0.12980964575563708, 0.1460196678676913, 0.10524872900737871, 0.12022658296289945, 0.16408657985589198, 0.13649555554072704, 0.21587844427314498, 0.19988979092769085, 0.21785986940226248, 0.14369809970019326, 0.19921212487163084, 0.20986580319942968, 0.20783062934154467, 0.24050251730988104, 0.17545596816607062, 0.19483583228242016, 0.18189394125534644, 0.4035633820439539, 0.34184905490086925, 62.17324249206051, 121.07037236613613, 117.30181401775731, 105.60109353834584, 95.42884226768248, 71.08774262089884, 97.07206433819186, 66.20752180776289, 83.33053465812438, 76.59323630794403, 27.3702206150178, 0.3255389204188701, 0.2938046168175436, 0.39641657844185835, 0.6305490746613472, 2.370331931498743, 2.360459816071295, 3.798930241215614, 4.168845049796566, 2.6226349607590707, 3.1685335261206475, 106.98141482568558, 92.58974444481635, 92.59627911352342, 90.06110222108903, 84.1556993607552, 80.6934545886132, 80.48396864245015, 77.61156205208071, 90.34982788947322, 86.9203035293087, 86.9720317471412, 83.05309757109612, 71.78562641143799, 58.452176201728086, 69.6730064576672, 75.87070434324204, 80.8730677635439, 77.35880451817667, 77.78504848480225, 76.41680809759325, 74.93663895514705, 71.5496644666118, 63.25256893711706, 60.435161821303836, 58.753116130828865, 57.699975429042695, 58.683466603679044, 54.41602591545352, 57.317148177854484, 56.07571409594629, 58.41967936485045, 57.34413016226984, 58.29733279443557, 57.02107591013755, 57.847072155244895, 58.19917155850319, 58.188569391927416, 57.42562916971023, 60.75641570552703, 58.13952015292261, 60.15773257901592, 61.29172509716403, 62.18598235038019, 62.80290842056275, 67.40951645758845, 77.29840001752301, 69.64088224595594, 44.87016147182834, 77.96732102670978, 72.38227382782968, 74.56983458611273, 62.09395962376749, 65.1520747523154, 66.22771416940998, 70.27331736779982, 67.94795590062296, 71.17064583686091, 57.74150548442718, 61.55489260150541, 59.01241617818033, 58.65476662112821, 60.92455987007388, 68.24323192719491, 70.34202944847846, 78.06106567382812, 71.5804393829838, 72.37785723901564, 64.26802742865779, 64.39444541931152, 63.2291994556304, 73.54783750349476, 76.70722038515153, 76.60911406240156, 76.25392775381766, 77.23755621141004, 72.09540736290717, 67.12897285338371, 58.520852981075166, 64.91857605595743, 62.454735309846946, 68.1904132904545, 64.6310192538846, 76.4632724946545, 69.49292259831583, 77.50652097886609, 76.6568414626583, 88.18726047392815, 73.12348411929223, 100.57912611192273, 17.896945514986594, 1.9180842440935875, 9.55104491403026, 5.654523161149794, 4.355858266353607, 1.6182977369716092, 2.3014649171983046, 4.0444610532253025, 0.536297828920426, 0.3024664665422132, 0.9661343801886806, 40.710346698760986, 47.42850780487061, 56.544817801444765, 46.428209274045884, 58.259348561686856, 43.771536965524, 37.88468691610521, 62.40694515166744, 82.0670529334776, 89.83660144190635, 97.60953887816399, 9.227619017324141, 0.5405618130199371, 0.2599142660056391, 0.24397177711850215, 0.17829571820555196, 0.1980957049395769, 0.13453718965813038, 0.18715403883928255, 0.1924970118148673, 0.20890155897265483, 0.2547300877349992, 0.1922619300744226, 0.12034149615154152, 0.15570288133477012, 0.10908004196901476, 0.20700604294336614, 0.1337683438173225, 0.1190622672138195, 0.24547671088047568, 0.11059958502770433, 0.11348330851403937, 0.11537622750526476, 0.1297911983584204, 0.10655339972506608], [0.023243199553220503, 0.038343462867722396, 0.04264037342621915, 0.0440775505417297, 0.025236855276049148, 0.01698967553825388, 0.047440959981852965, 0.004303750766050672, 0.08111865244685643, 0.035028370592983506, 0.017406469503898295, 0.029903916536920497, 0.02661904260035484, 0.08475556293682707, 0.011906583526832683, 0.039307040598003135, 0.010852481974589248, 0.041764305919528975, 0.09321324256879669, 0.3414686156376716, 73.11833796962615, 87.95834310593145, 79.15041769704511, 83.38442802429199, 56.48000847908759, 42.1928535738299, 21.385746694380238, 63.05177104088568, 72.96014093583631, 35.636439246516076, 6.786445158143198, 0.039038860028789896, 0.3418754389689815, 0.09204741762650591, 0.15925837200014822, 1.1438153588002729, 0.3251315148607377, 3.042448691783413, 0.29133306395622993, 0.17896999815298667, 70.56460042153635, 89.52127425901352, 78.90804659935736, 83.99094412403723, 73.86423157107446, 75.92050275494977, 71.71660054114558, 69.81764778014153, 67.34907273323306, 76.55954314816383, 79.32729305759554, 79.08347852768438, 74.960220244623, 56.37938007231682, 55.630376031321866, 56.04159732018748, 64.16425328100881, 74.09123482242708, 75.21431138438564, 72.59807478997016, 70.80026426622945, 67.89948325003347, 61.73447439747473, 57.31135875948014, 55.28399936614498, 52.21453289831839, 53.66463315102362, 51.52469388900265, 52.320264308683335, 49.7651303968122, 51.26160090969455, 49.041633529047814, 51.59823048499323, 51.83126634167087, 52.07360213802707, 51.79587871797624, 56.5577341664222, 56.01495265960694, 56.53423132434968, 52.889388453575876, 53.40553706692111, 51.141325350730654, 51.68919417165941, 49.672766423994496, 53.04156464915122, 55.26207723925191, 73.40673415891587, 59.13341345325593, 42.92414811349685, 71.97129572591474, 61.529008880738296, 62.58375383192494, 53.503176627620576, 55.18373573980024, 56.75446064241471, 60.480096493997884, 60.76941836264826, 56.708674815393266, 51.078551738492905, 55.48936682362711, 54.230548797115205, 51.818899108517556, 48.65081640981859, 51.500383038674634, 53.41717866159255, 59.158814722491854, 59.15588471197314, 58.98070381533716, 57.25677505616219, 54.076297667718705, 55.392798069984686, 62.376868417186124, 68.22299249710576, 70.98631797298309, 66.92610002333119, 72.99603846765334, 68.3434877087993, 59.934247693707874, 52.445364382959184, 58.63871236001292, 54.92535744943927, 56.75511175586332, 60.321244424389256, 59.725659970314275, 60.35876973982781, 64.57038725576093, 62.98040743797057, 72.48323563606509, 80.43975568586781, 70.87214562200731, 75.7098557872157, 4.290040404565873, 1.4696531454401633, 2.4220942249221187, 1.8171045400442618, 0.3851097335498179, 0.6765674246895699, 0.16403615594871584, 0.26931333746160235, 0.12989124944133143, 0.05201651587060863, 2.7299765040797572, 30.852451824372817, 43.21249723434449, 74.91743503078338, 153.13386578713695, 103.69463336083197, 24.18777027437764, 45.737754452613096, 56.871802268489716, 61.64620537911693, 77.75875291516705, 34.49995210093837, 0.4836783443968143, 0.043929806655092586, 0.08607855081678399, 0.04003093622985386, 0.10092197166335198, 0.010930568359101252, 0.025754387888516632, 0.0271569014406733, 0.07834700762384361, 0.07883718132131523, 0.02348988369527844, 0.049068406524677435, 0.07569427496843761, 0.039685955346231504, 0.023029612324711297, 0.031095842094791513, 0.04414825279626154, 0.00942626853488506, 0.07299896314620011, 0.049667399181353475, 0.040887066298314644, 0.04369154564976212, 0.05308365336649361, 0.045442849457744634, 0.07261253307543455, 0.030100948605386, 0.04658759549079884, 0.10665281495499997, 0.04439993949246503, 0.017707664632208405, 0.06581516515824103, 0.037799628541594556, 0.022705685452467973, 0.02378194897075094, 0.034427926199690956, 0.03858342458824477, 0.05506456138626222, 0.02189690919382678, 0.051682080187263994, 0.04666143104494099, 0.04316700141756766, 0.05062487885175694, 0.8040329333274596, 87.41503207914292, 98.46364282792615, 91.11906743818714, 91.84105811580535, 73.7892044744184, 49.576672277142926, 34.591872845926595, 66.05554565306633, 61.0449884014745, 44.356789896565104, 7.864778262953605, 0.028057922346277103, 0.07862268436339595, 0.27427541152123486, 0.8486732443974865, 1.3844707872598403, 2.063044381718482, 2.0724673857611995, 0.21049106884146893, 0.4212184604858199, 76.23927377885389, 94.01474152841877, 85.2942535954137, 88.95603718296175, 76.72960142935477, 79.13286901289418, 75.17208314711048, 74.09932274972239, 70.66865305746757, 79.22771976840112, 81.84641961128482, 83.42755840670678, 78.17726196781283, 59.10578427776214, 59.62128570002895, 58.58973372367121, 67.31036678437265, 75.57145887805571, 77.81852199185279, 74.5551178532262, 74.732252090208, 69.74618219560193, 65.16217093313894, 60.91845666208575, 59.7060755760439, 56.27012637353713, 56.10943078994752, 53.46506687902635, 54.45359829933413, 53.59370100882746, 55.0718109069332, 52.621329753629624, 54.04554628556775, 54.64434316081386, 54.93703042307208, 54.73418504961076, 60.373478627973995, 59.288511814609656, 59.68722074262558, 55.64687352026663, 55.97115939663303, 53.82756448561146, 53.83914332236014, 53.24943457880328, 56.27913605782294, 58.56322242367653, 75.6931229560606, 62.38964357683736, 46.29127540896016, 74.10687723467427, 63.611909035713445, 65.40438121364963, 58.13281682229812, 58.69952870953468, 59.45824846144646, 62.784292851724935, 63.155400060838275, 59.30220873125138, 52.901261468087476, 57.47097569127237, 56.320395469665534, 54.861144327348285, 53.04817776526175, 54.18775573853524, 55.772322685487815, 62.7555654125829, 61.84445373473629, 60.79319969300301, 60.92361850123252, 57.94235437147079, 58.38492716512373, 66.04692428342759, 70.38693274221113, 72.33929249548143, 69.92458728051955, 73.19262766068982, 70.79482001643028, 62.711783916719504, 56.593525794244584, 59.02569732358379, 57.551752982601045, 60.23939240363337, 62.23554934224775, 60.98565470787787, 62.31560099509455, 66.81516755011775, 65.59569481880435, 75.02230351971042, 82.0871982266826, 76.62510164322393, 78.75502709419497, 6.297956118660589, 0.8500072792653115, 0.3505951742972097, 1.2937217277865256, 1.6874879790890602, 1.4358929376448355, 1.9477575873174977, 1.6304178608040658, 0.34531590919340815, 0.07881282738620236, 2.1224258792015815, 32.64146643300211, 41.35252498811291, 60.19677977408133, 120.83138235153692, 101.61569087736069, 32.79677267997496, 50.08453292231406, 66.74059544840168, 67.98414368783274, 88.10707153812533, 47.57238818753151, 0.4028844136384226, 0.03614272208764188, 0.04114240340347733, 0.04793958745956902, 0.0576009406077285, 0.05289169471530665, 0.017959822472485325, 0.06881117415163787, 0.020723314204763983, 0.02419836372287283, 0.030782201868151466, 0.06487050979969002, 0.047641276652293826, 0.05920810880319727, 0.024041675759719747, 0.1684753903217854, 0.026662133130875808, 0.014116133360432522, 0.09212891405989086, 0.04407375457606489, 0.06218454808056836, 0.041251157245208184, 0.012267290280320713, 0.14978548031180136, 0.23292731734052782, 0.1309009839690501, 0.17905914014385593, 0.1561214564548385, 0.19909086847497573, 0.13903193476219333, 0.18540213365227948, 0.20467630827859526, 0.16645371493312622, 0.15078790636072237, 0.12416636631373437, 0.20855337201106935, 0.17227901686583796, 0.1388202953122316, 0.1273463972874226, 0.10583542212243043, 0.11048214374891213, 0.2217128320086387, 1.4083499317207646, 98.16502494196739, 110.1144236903037, 102.10011928312241, 103.9907487746208, 75.62085720800584, 57.20204622514787, 30.35789389764109, 88.68403650099232, 93.49192880815076, 57.54225692441387, 12.006064249623208, 0.15387376980675807, 0.5659693948203518, 0.6334194528960413, 1.9391050838655042, 2.8596282437924416, 3.924680938643794, 6.665337076110225, 3.985951057364864, 0.6304610664806058, 82.43046837468302, 95.03193762994583, 88.04109727182697, 91.05887474552279, 80.05585762762254, 83.31215443149691, 78.7714147567749, 77.59132262199157, 72.87664151960804, 82.43998404472106, 86.64313316345216, 84.93461931905439, 82.99178308056247, 62.93068355129611, 63.07843923568726, 61.89209484284925, 70.67005726598924, 80.35795073355399, 80.10792316928988, 76.28734634768578, 75.77337464978619, 74.11410224053168, 66.71375859168269, 63.95417897931991, 62.71721639940816, 58.99424383717199, 59.798718037143836, 56.756347302467596, 56.47310510758431, 55.70522662132017, 57.377552678508145, 54.4486011997346, 56.36144699588899, 59.059476775507775, 57.129525523031916, 56.759555801268554, 62.68034219741822, 61.43368744081067, 62.53766598240022, 57.73339010054066, 58.7513392971408, 57.41486618595739, 56.855402838799264, 56.228243304837136, 57.747220377768244, 59.65841877845026, 78.91288680415, 68.0658309690414, 51.22310284645327, 77.4107131650371, 67.83047306922175, 68.0659015717045, 63.28933331274218, 61.069401233426994, 62.45719071357482, 67.8157877152966, 68.21409656155494, 59.81796902994956, 55.55078329578523, 62.10101596770748, 61.62904108724287, 58.15936342362435, 56.35555167352, 56.649415646829915, 59.41548678182787, 65.71218136818179, 64.10122471470987, 64.86895415090746, 64.53806692554106, 61.28377053045458, 63.16011867215557, 70.24568034756568, 75.23866930315572, 75.85779190063477, 71.30298660647485, 79.0238114326231, 76.13897092880742, 67.1008651487289, 58.49241187495571, 65.90461284883561, 60.19437143879553, 62.799841127088, 65.3455299715842, 65.18279083313482, 65.90303605602634, 71.24006394417056, 70.62455777199038, 79.34273150659378, 88.15585797832858, 80.85615450336088, 83.30128162137925, 7.365654697341304, 4.722570459688864, 9.536532144392691, 5.441113864221881, 3.8563402573908534, 1.6609796208720056, 3.4895574613924953, 1.950718241353189, 0.8010923201518675, 0.2478376866107987, 5.33103842889109, 49.85769048813851, 62.21561585703204, 94.34905298294561, 159.49387919518256, 110.2163347121208, 34.36755249577184, 63.92854236787366, 74.45338726043701, 78.63781098396548, 98.1925678253174, 51.186499288005216, 0.7868525229634777, 0.2340758516783676, 0.16241448570884046, 0.11787118435266519, 0.10158287571562875, 0.10661249574754508, 0.13271517210429715, 0.19128161332299634, 0.1617757982063678, 0.18553330322667477, 0.0834441659671645, 0.14797291628295375, 0.19509199676254105, 0.1859277465771283, 0.1292582003459815, 0.2755589152295744, 0.16138656425379938, 0.1160927342190858, 0.2874941360806265, 0.09017650068046586, 0.1291486650945679, 0.10802217413701358, 0.09046464933142548], [0.07219817143894973, 0.02409240418684579, 0.00985192996825302, 0.0903308367536914, 0.04112918838678349, 0.0063479816984205, 0.011549477386588772, 0.037489037344893145, 0.051662127427276106, 0.06421527096761331, 0.038990711402748866, 0.015343295132380821, 0.06255786655650986, 0.040599488382858616, 0.044263866955354336, 0.10516933165490629, 0.008941033231695334, 0.09754386099596178, 0.3164487356139768, 8.899233283535127, 87.75437985697101, 78.6401879402899, 86.16176420642485, 62.871918601374475, 35.59553284798899, 16.023091020122653, 33.605636012169626, 29.795486811668646, 49.83108505125969, 25.786298897958574, 0.03948062079988661, 0.08485283312057296, 0.04290728611991771, 0.31642468045315436, 0.36440179472969425, 0.3729654319824711, 1.1943173456576563, 0.6128524436104683, 1.3992463556989547, 38.57306680371685, 99.22866190633466, 76.82537001948204, 87.00488551970452, 67.63432318164458, 77.33083017410772, 68.51212609198787, 74.16761121442242, 63.72463010972547, 68.5484629292642, 70.69368562390729, 78.0546094525245, 72.85852016941195, 64.08089507010676, 53.15713728627851, 56.07924422910137, 54.67823243910267, 66.7094204502721, 72.15345059671711, 72.58467597346153, 69.9853761734501, 72.1714464310677, 64.70333991512176, 63.06592687483757, 59.83497250464655, 56.819528841203265, 51.59182525450184, 51.30641791128343, 50.77518386225547, 51.73866310427266, 47.14743468069261, 52.149347028424664, 50.01093356840072, 50.51438939186835, 50.432992366052446, 52.529656117962254, 58.45820880705311, 64.32122261293473, 62.77138825385802, 60.10318025465935, 54.42984050320041, 55.008723505081676, 51.359589561339355, 53.88019092621342, 50.51891188467703, 52.890671068622225, 55.36456877185453, 70.57602236347815, 58.1626150684972, 45.063087171123875, 67.73026435605942, 61.090884054860766, 57.61526792280136, 51.961842044707275, 53.32936463817474, 54.244987041719504, 56.84081162175825, 58.53383994871571, 52.715388190361764, 53.31542061221216, 53.33945297425794, 52.47006354793426, 53.59348527846798, 50.74176919075751, 49.33583874856272, 49.85421526816584, 50.067603972650346, 50.670303606217914, 53.15535653022028, 54.83765717475645, 49.91595337467809, 53.81205151157995, 58.592753948703894, 66.64720381459883, 67.04854857537055, 66.46520583860337, 69.38188814347791, 68.34611569681476, 62.13556812655542, 52.89275384718373, 53.23990321928456, 54.05417942231702, 55.96701345136089, 57.69051467218707, 58.397819995880134, 63.59003789963261, 63.617384664474, 68.13844188567131, 70.2430445148099, 74.75837507555562, 74.68023361698275, 69.81956189678561, 45.947079581599084, 0.09597273723733041, 0.9071922494519142, 1.3310083915149014, 1.4565143085295156, 1.2084405749074876, 0.8567925506541807, 0.9925481725123622, 0.13720360464386402, 0.11020953902193617, 0.02376308788605515, 9.395524897883016, 29.864838238685365, 48.51378840784873, 76.41280728001749, 69.44128851736747, 39.35463436188237, 33.80015419375512, 47.15070201504616, 61.154116584408676, 66.74289395732265, 71.98354136559271, 3.9296932374277427, 0.1575599703937769, 0.12533417542374906, 0.030393946592906312, 0.024016044372993133, 0.08200039666506552, 0.031882874862921816, 0.03324112577003337, 0.0696757963047393, 0.02683020133014408, 0.016338950879270994, 0.04503197735175491, 0.017689983322916013, 0.036155649821364114, 0.06526810177151235, 0.06502617120502457, 0.012310784922221736, 0.01807919812328633, 0.014261390334145438, 0.04344617534849433, 0.047760200311219504, 0.045528272091741526, 0.04513298604457129, 0.03896067692567745, 0.03963861494295059, 0.051618973694501386, 0.07247446870972073, 0.0439875275497475, 0.07605141749785793, 0.03216354266530083, 0.03983459938617964, 0.08199427562255053, 0.074175329458329, 0.0038781271582739732, 0.048342327542242505, 0.03275248041797069, 0.06418538204724751, 0.02791729350123675, 0.10078386899324195, 0.07746192326228465, 0.18871681223953926, 0.48800484127094673, 12.195242124219096, 103.99048989818942, 88.28394689867574, 96.9548325384817, 71.28314725814327, 44.807784018978, 22.37942034198392, 36.559831865372196, 37.455552162662634, 54.53948251662716, 28.87966044487492, 0.03713454931013046, 0.08017312374807174, 0.24588620019776208, 0.460894858885196, 0.5196991550826258, 1.6457914681203905, 3.048125587163433, 1.087287630765669, 0.7848128291868395, 44.00536906334662, 102.98593167335757, 82.20229625701904, 91.24881944348736, 70.39793891291465, 81.80192424405007, 70.67595651072841, 77.20052903698337, 68.02102965693321, 69.76379363767563, 74.18396749804097, 83.20764680062571, 76.38562525472334, 68.78997110551404, 54.59597641421903, 59.09162452144008, 57.32940950701314, 69.97334234176144, 76.35413646697998, 74.41003722529258, 73.04142029054704, 75.12525789199337, 69.16369453553231, 66.05797752257317, 61.09563404513944, 58.883511404837336, 55.07791019255116, 54.636957337779386, 51.7617658645876, 54.25631092440698, 49.81983569360549, 54.777907709921564, 52.32822672013314, 52.20056533813477, 52.4484512882848, 53.436692453199825, 60.67819579955071, 67.06485779054704, 64.4246986604506, 62.09741915425947, 56.29875967579504, 58.90455492081181, 53.72313137977354, 56.316080862475985, 53.25830305776289, 55.57631400323684, 59.3426287558771, 73.77496627069289, 61.657140947157345, 49.522955417633064, 70.11169218247937, 64.26754889949676, 60.92067280123311, 55.04128309988207, 55.42809547916536, 57.533851285134595, 59.78622921051518, 59.3931959521386, 53.912707374941924, 55.164453368033136, 56.3103973480963, 54.9446790449081, 55.466216994870095, 53.561882741989635, 53.13582312676215, 53.34825477292461, 52.994809996697214, 53.18304846363684, 56.880859021217596, 54.83948107688658, 52.200451589399776, 56.09602805106871, 59.766111373901374, 69.3016835181944, 69.60749503104918, 68.30435814396029, 72.89182893691525, 72.69870711911109, 65.77445291703748, 56.43259094607446, 56.284490093108154, 57.34832709835422, 58.10944734081146, 59.96759176254273, 61.97861056174002, 67.07596594287504, 66.84930786009758, 72.71866413854784, 74.73907701430782, 78.18378879177955, 78.24172219922467, 75.51985617606871, 55.500369071960456, 0.8301442128516013, 0.7540184235380543, 0.5179127606172715, 0.37893077478774134, 2.767074771465794, 2.4751656093905052, 1.5104551108614093, 0.9036178670583234, 0.22342486998006222, 0.03322786861850369, 9.74096509718126, 36.75316941353583, 46.089289034566576, 84.06226850325062, 80.72691240618306, 35.76710124169627, 45.23121564619003, 52.80104098781463, 69.7661078360773, 71.62602516912645, 87.03857867948471, 8.017411414654024, 0.37335953825423795, 0.0646071670757186, 0.08182279450157959, 0.1312758307904005, 0.05849164805465168, 0.046181476960379275, 0.019133672185782945, 0.044094071227816806, 0.04062068603572346, 0.025657600340163036, 0.08121150230327923, 0.038184338744970105, 0.04369971980791419, 0.025728798636625853, 0.0443271458178999, 0.03645871037376985, 0.0643908774720565, 0.026297565294249405, 0.018485805034757625, 0.07801612658846764, 0.021691852354354436, 0.11333042034699072, 0.3065979480743408, 0.183415345907692, 0.25163184430810714, 0.20677964863998277, 0.11855591373938708, 0.2242436647535332, 0.20278125190206114, 0.12347564611944462, 0.11952571976449221, 0.17573601926767057, 0.18796046895365562, 0.07659165504118128, 0.1157841693249441, 0.1149545956943785, 0.20589667102021558, 0.2911549025485593, 0.19192339582068307, 0.30262550639529384, 0.9159472861116933, 15.711288086829649, 121.07973114136728, 98.20612353663292, 110.673322216157, 81.40261911576795, 53.66430367192915, 24.496570633303737, 49.74328671732257, 44.279079898711174, 69.7539798675045, 40.740325373988, 0.11666740741460555, 0.2908501834157975, 0.35305753410343205, 1.18311922396383, 0.5394766035099183, 3.2178529183710776, 5.750773222215715, 7.826021813577222, 3.027948424700768, 45.589547695652136, 104.46817182725476, 83.81826569957119, 94.30920170199488, 72.49553618892547, 85.53405946300876, 73.97040228689872, 80.57652088903612, 71.50049363413166, 72.59055952872001, 75.97417646838774, 86.59480956292923, 79.967298353872, 71.51189988659274, 58.9700428132088, 62.92202688032582, 60.934620749565866, 72.39459007017075, 80.27722051066738, 77.36329955439415, 74.31016583596507, 78.322036650873, 71.48214478646555, 70.32075451266381, 63.75195726271599, 62.4157783292955, 57.94206411607804, 56.68690173856674, 55.525032935603974, 57.58674836927845, 51.17608931756789, 58.62174418664748, 53.93251926668229, 55.51653315944057, 57.02035419402584, 59.73586597750264, 64.42479279733473, 70.52049729131883, 67.17932039691557, 65.31933638357347, 60.6382699935667, 62.844815023483775, 59.29236358211887, 60.40853285020398, 56.8416117852734, 57.74257629148422, 62.96173303358017, 76.39004968827771, 66.51407857095042, 54.799386608985166, 72.09088094772832, 69.88440652047434, 63.43821471737277, 59.985061999290224, 58.35425423037622, 60.59604175629155, 62.57235934657436, 63.36268555733466, 57.94509610822124, 58.22305879285259, 59.65141734769268, 59.640066008413996, 57.84949225764121, 54.901685945449344, 55.404847591154045, 56.40229455886349, 56.17553449446156, 56.641586595965975, 60.27451330615629, 58.714319967454486, 54.429487489884906, 59.81916143048195, 63.85739449531802, 74.53244655363022, 72.38499595272926, 69.53217767900037, 76.52555973299089, 75.17715084937312, 69.5144485658215, 58.68027379435878, 58.64637274895945, 58.63298569956134, 61.25105011847712, 64.8865891272022, 65.52104034731465, 69.84087605630198, 70.22004373611944, 75.00446458016673, 77.73918028800719, 81.27800541539347, 82.48451079091718, 78.92679552878104, 57.723329221048665, 0.6527679533727708, 3.1776476435122953, 9.84521875458379, 7.015035008230518, 5.428081789324361, 3.241848998492764, 3.4396639322080924, 1.7875559772214584, 0.4181027808977712, 0.259779158739313, 15.699338586099687, 50.51357353887251, 63.7967703419347, 83.26128129036196, 75.59008229163386, 52.62692305349535, 50.15992479939615, 62.523110066690755, 80.94752219415481, 82.50169861701228, 96.4287877851917, 7.1995697771349265, 0.6429217623606805, 0.2990752710930763, 0.16643493045722285, 0.2130844143609847, 0.19081348763598552, 0.22555958930282827, 0.13466622950809617, 0.18241527940957777, 0.12548098851355816, 0.15474018460560232, 0.19806265590652344, 0.1301146713235686, 0.12814685191598632, 0.2023238054807148, 0.12911668858460842, 0.20386108347485143, 0.1704171320964252, 0.1363333440836399, 0.1404926499291774, 0.2741984043630862, 0.13514114273411615, 0.20131567973763714], [0.01953620733993669, 0.09691510199298782, 0.016548558281013565, 0.015807647836364565, 0.02151544528803037, 0.055566513685569655, 0.024796438989259546, 0.04105496212779995, 0.03990953044605352, 0.03592412272888807, 0.12377613644686439, 0.05457050745345412, 0.10800872163306321, 0.027279887280817476, 0.0720375381229866, 0.05397794610490242, 0.03360175399950916, 0.062299101207886017, 0.07451189486610313, 40.60341896549348, 93.87981983923143, 79.35478102776312, 78.30404081652242, 49.3915520944903, 36.46071357111777, 28.98292664558657, 57.241877894247736, 58.57373829810851, 46.21206706570041, 4.633304178714752, 0.01542172625645875, 0.09460121002649108, 0.033303247839813276, 0.14229680231261638, 0.4955330340852661, 1.7242236723822935, 0.5748394672428409, 2.645888242029375, 9.7913420584894, 95.840926477986, 81.99979997450306, 84.22671779509514, 71.50095647381198, 70.64977861219838, 66.26599650229177, 71.9873695988809, 65.73086361731252, 65.24566642699703, 58.30968826047836, 62.780798019901404, 63.56273428086312, 61.086871470174486, 55.256695747375495, 55.392711777840894, 53.767285500803304, 56.113447297003965, 64.72672116371893, 70.18009047354423, 71.0241610004056, 71.1248403979886, 71.93090315788024, 69.83896978439824, 62.68126395440871, 60.065784377436486, 55.21371049265708, 50.94629726102276, 52.27935791015626, 51.54274855890582, 52.86481088207614, 51.26008687480804, 52.093806266784675, 49.03894670547978, 50.4595075884173, 48.327742545835434, 54.36218354009814, 67.78387531157463, 71.4113538495956, 67.45344700351839, 60.367434255538456, 54.97056276567521, 52.07356683669552, 50.35778876273863, 51.45970413761755, 49.40730825547249, 53.48005817782495, 53.28333954657278, 75.05811475938367, 57.22095989411878, 45.73236903836651, 72.15450179192328, 56.3270595765883, 55.8761792029104, 49.89962454765074, 55.64748148764334, 51.18178067668792, 54.286187618009514, 52.12269844547395, 52.556747928742446, 51.006705684046594, 51.983772016340694, 52.430459376304384, 51.077492698546386, 48.234405825215006, 49.92499443792528, 52.725315709267896, 49.94557511421942, 48.392951949950195, 50.757427292485396, 49.90650438493299, 51.93531113286173, 50.230641211232836, 56.83223732056157, 63.271494373198486, 70.62857427904683, 70.31669093716529, 71.52589490336757, 67.4326741310858, 61.10717758055657, 55.158605114106216, 53.39409943549864, 52.87563662375174, 52.25167382148005, 54.7663131836922, 61.11304936870452, 70.78863051629835, 69.99355039288922, 74.00629981871575, 73.42343561110958, 80.23012853437855, 68.81527039312547, 71.2099636754682, 81.83356208185997, 39.03930717898954, 1.3919484182711572, 0.8563847467303277, 0.9203326185384105, 2.3490329711667957, 1.2005130970670332, 1.1461121516842996, 0.31397473127130543, 0.16788020129165343, 0.13041899209060978, 0.5374070629477501, 23.851970280370406, 31.55163391943901, 25.264447158382787, 27.770245498226537, 43.09408872358261, 20.995602261635568, 38.91664681896087, 54.03241419023084, 56.68443456772835, 71.40541538115471, 35.09672503317557, 0.5384919660225992, 0.1392410767655219, 0.06359777345712628, 0.036761724960900126, 0.0062700514043230685, 0.06649164377801842, 0.058738324535830375, 0.04774180654015753, 0.012954962402281743, 0.013209315084461725, 0.05255980627431024, 0.020829867458932345, 0.06119615676242018, 0.02965455108712758, 0.02558238582775718, 0.02298168777938812, 0.057369336906460025, 0.020977753071835446, 0.01627328373762148, 0.03799898760213006, 0.031849415972828865, 0.07093828622131579, 0.005789551482115302, 0.11520817079731535, 0.020748374855987007, 0.06639720811959236, 0.019109195676602183, 0.025282933549474806, 0.032719385419641776, 0.07461505626598675, 0.01750489456519004, 0.0158716899140047, 0.04680479673909084, 0.030336754298919154, 0.0581554695212793, 0.08782821902704817, 0.024093612690546343, 0.017554761143401265, 0.04292997381379528, 0.14192495855592913, 0.133161464285466, 51.06651790680424, 107.41933961068432, 85.88475858011554, 87.55702187938076, 61.22157350663216, 48.361847554483724, 37.21940978880852, 59.87444331569057, 47.41270849781652, 50.246883746116396, 5.685326024409264, 0.043266539221569415, 0.1353101417302124, 0.20306122639486868, 0.8219775317176696, 0.989836588982613, 2.5376342573473534, 1.8447105490392255, 1.5879613906145098, 11.56785999574969, 99.86464285081433, 84.86951581893429, 89.15871389450567, 73.75811576843262, 75.82959790383616, 68.43791484832764, 75.61295755447881, 69.67436359774682, 69.24515431927097, 61.08038779227965, 65.2671923945027, 64.45558340318742, 64.14421389179846, 58.33742333996681, 57.52487297981017, 56.98142859243578, 59.11477042782692, 67.01058787684288, 74.65338891552341, 73.232784886514, 72.53778796042167, 74.43520315231817, 73.39144475998418, 65.42511094001033, 62.595187540977236, 57.454517426029334, 53.26773243565714, 55.214855824747396, 53.75608321159117, 53.30697967160133, 55.1378361640438, 56.07802044960761, 51.542972134005645, 54.22392783626434, 51.909517626608576, 57.707961374713534, 68.65842265467491, 72.70009563815209, 70.87243587740006, 63.77089054353776, 58.05272986811977, 53.553700677810184, 54.19452574945266, 53.225751307702836, 53.001066177122055, 55.00300861174061, 56.8200897401379, 76.49908373432775, 59.75655255779144, 47.95458785949215, 74.95173223557012, 59.36819476466025, 58.539378335399014, 52.411988935162945, 56.84575380817537, 54.686237996624364, 56.78602395519134, 54.32815305648312, 53.66768475501768, 54.249125142251295, 55.272973583590606, 55.36212513523718, 54.41102881585398, 50.301298787516934, 51.84379439200125, 55.28111250169816, 51.07404885753509, 51.633594574466834, 53.569460761162546, 52.12318089700515, 53.50193715864613, 53.41943010207146, 59.516091654377604, 67.64046561333441, 71.3635087782337, 71.867321537387, 71.24737524217176, 72.13448985930413, 63.458783626556404, 58.512098250850556, 55.89033503686228, 55.90898198466147, 56.72024972977177, 57.45550194094258, 64.11543938421434, 73.1759262084961, 74.59929943084717, 76.91990698537519, 76.26421220840948, 79.86355950755458, 72.3312359471475, 74.93592508377569, 85.15781002659952, 45.38969901300246, 3.198084417850741, 0.19341285460658614, 0.81878729645283, 0.16019704421201061, 1.9386906609419856, 3.7836906073554872, 1.1382078403426756, 0.5309469805609796, 0.040812602552074584, 0.2752074340899145, 28.65240420064619, 38.20270484493625, 29.59490268461166, 34.15422654921009, 52.125114625500096, 30.979087506571126, 46.42807591346003, 60.58041895589521, 64.5531915849255, 79.76851263353902, 48.434027010394686, 0.5769976288560899, 0.03675615933213023, 0.18547455960464093, 0.0852054174268438, 0.05392857939906178, 0.05115736741572619, 0.11527226937393989, 0.01563450717742765, 0.09738693554555217, 0.05142253725939701, 0.041487323000065746, 0.046675316388568575, 0.0527535192668438, 0.004417293136113234, 0.03895618765044116, 0.03161334406374203, 0.039281748205183015, 0.041952116204605955, 0.042782651275516524, 0.033817790794156255, 0.02363456706065805, 0.05889258016982387, 0.1507844589650631, 0.1676668611264998, 0.1263142393661603, 0.1548148168911857, 0.16460125304518208, 0.18860934542552119, 0.18210303729339955, 0.13675956476119258, 0.11822853372582506, 0.13139612191627104, 0.20258672685632784, 0.12083690222953597, 0.15836851491082102, 0.1495683403505433, 0.2131041334641557, 0.2850267813811379, 0.14706865674065006, 0.1352943909624892, 0.2202971934551193, 60.388434625441036, 119.37528871720838, 97.03586870624174, 99.62347199839931, 68.48913315803775, 52.62792718025946, 40.612985626343765, 77.36698658235612, 79.36900354200795, 72.19416479910575, 8.423008514988808, 0.19614242588079747, 0.25342016931503053, 1.3643084562593892, 1.16386259275098, 2.261390796592159, 5.030729511091787, 6.080934318803973, 6.475794421088311, 12.283097332523717, 104.705090830403, 88.91875113210371, 92.35169579905849, 76.17842212800058, 78.72771170831497, 71.2109991811937, 80.13095532694172, 72.45359036230272, 72.20287246088829, 64.8186654429282, 69.57296248405211, 66.84993543932515, 66.1334909931306, 60.36454739109163, 61.44081830978394, 61.50078350497831, 63.40532956584808, 68.90535154650289, 76.48461018839191, 76.30187480680405, 76.72047799633395, 76.84189888738817, 75.69517043329056, 66.88539366568288, 66.25033055582355, 59.99575438037996, 56.35123314396028, 57.23038927201302, 58.108043132289765, 59.87622799411897, 57.61457366328086, 58.953898337579545, 54.93059381361931, 57.43787088701802, 54.22734029831425, 60.8071005728937, 75.42127132415771, 75.61245549109675, 72.63365068743306, 67.30138455667804, 62.85588395211005, 57.155130755516794, 56.651820059745546, 56.58534765243531, 56.29162880682177, 59.355847143357806, 57.969301054554606, 79.97766125586726, 63.119937912110366, 52.56156067694388, 76.52140202060824, 63.385917755865286, 61.41034541591522, 56.0066411572118, 61.435272078360285, 58.273182761284616, 58.6984775143285, 58.32920989682598, 56.86215323786582, 57.04674390054519, 57.40848056731686, 57.57726407820179, 54.84811813600602, 51.42557951711839, 53.39373857744279, 58.610439915810865, 55.38777743616412, 54.53181428294028, 55.743497187091464, 54.549919943655695, 56.69785691845802, 56.91053567394134, 62.855013185931796, 70.47011836882561, 77.67526918841948, 75.8718575200727, 73.20883489424183, 74.5156744987734, 67.25345319317233, 62.504408205709154, 60.39691086738341, 58.74972328062981, 59.499951101118526, 59.828763392663774, 66.0127761287074, 77.90437483018445, 76.44765361662834, 81.80350888159968, 79.11970553859588, 85.22700063643917, 77.86413131221649, 74.11389043254238, 80.83768798458962, 47.74607466113183, 2.1896165705496267, 3.8457378456669473, 5.704924146975241, 9.277878307527113, 5.035962933494199, 3.495055888929675, 1.1736364037759843, 1.0581564326440136, 0.22495480885188426, 1.3516273109182235, 41.184447503859, 51.85258442355741, 36.29458158246933, 38.58614790824152, 59.50208879286244, 32.95440489246, 52.606832673472745, 71.6147679667319, 75.86522086974114, 91.51292047192975, 50.835262806184836, 0.9020933520890052, 0.24688485709409563, 0.29734219634725206, 0.2227482917688547, 0.20137793204236418, 0.20265549090841126, 0.2609399658056998, 0.06852701681876375, 0.22204943572080907, 0.10692817759850334, 0.1210863940838364, 0.17048450186848643, 0.1672709009219562, 0.12422016100777734, 0.1101651442267241, 0.23987570417023477, 0.10285641262007338, 0.17169804642758063, 0.14736425942711293, 0.16146199327082406, 0.20026541915872406, 0.08188071074865519], [0.03879882552991471, 0.031988524133339524, 0.09874965274526228, 0.04680780746463326, 0.02153177062169679, 0.017831996871879505, 0.05422226686571395, 0.07092768356444375, 0.027187650294734106, 0.062076296026427905, 0.033036193419848724, 0.02712324528293985, 0.03979206618462359, 0.029098746637182853, 0.03450786747458962, 0.050151053470589464, 0.059582859863557165, 0.009618665771408668, 1.5276745610660123, 73.3518131317631, 82.25082382079094, 83.11598100969869, 63.113007084015884, 43.56084292934787, 24.08254484976492, 28.95719393607109, 36.179785574636156, 47.75074620400706, 26.94138788407849, 0.5938960575769024, 0.07349896575174025, 0.08683897735130403, 0.15786039943416275, 0.1779870154155839, 0.702036232236893, 1.4660949428235333, 1.8296346741337932, 0.9027340467418394, 73.12274671369984, 88.38566964672458, 83.21487180648312, 80.18346801880868, 70.52777721035865, 63.24626961062032, 70.28073849216585, 65.1883331421883, 64.76243826650804, 61.110189960848906, 59.59607662693147, 57.843742062968595, 59.673476757541785, 55.36682413470361, 55.57247400283814, 51.26904949065178, 53.74944656125961, 54.254934172476496, 60.92980015662409, 68.36222879348263, 71.64651563090663, 71.5513510857859, 70.21978485968806, 71.35154554920813, 67.60758046180972, 61.72500187350858, 56.68230079835462, 49.5995867636896, 50.33241887246409, 49.66786738364927, 54.49608541304066, 54.56910817853866, 54.63088550875264, 50.85839302309098, 50.53479748387491, 49.96796008079283, 61.189653258169855, 64.36099544648202, 74.07121504506758, 66.18532903732793, 59.899213083328746, 53.69618077431956, 50.71157870754119, 48.13846072842998, 51.7393808980142, 47.126834392547615, 53.15739616270989, 54.55203802354875, 71.04030547603485, 53.07201008642874, 42.58264695444415, 71.61228902878301, 56.58417486375379, 57.599421547305205, 52.76329994201661, 53.918536017017985, 47.95234818612376, 49.345883938574026, 47.77098171172604, 52.60525980303365, 50.43341205966089, 52.20262066010506, 52.444313187753, 52.36334370028589, 49.131432271772816, 50.1737315424027, 47.634797019343225, 49.99974304629911, 47.61535383039906, 51.399507522583015, 47.54935995224984, 48.28182335822813, 48.78370238888649, 52.272870309891246, 60.90202585343392, 67.16398392954181, 67.4904114200223, 70.05009528129332, 67.18157968213482, 63.95819940874654, 55.533728830276004, 54.21096048047466, 53.42505478089856, 54.68370414549305, 55.7606222552638, 66.3320178370322, 69.56809874503844, 71.36844311991047, 69.6800902581984, 71.42308958115117, 60.182647474350475, 65.77479808561264, 62.66365643470519, 66.93410950322306, 73.85783026295324, 54.61027345349712, 10.397545349213386, 0.22680523294594981, 1.9516684355274325, 1.6851403179668611, 0.8828950048454347, 0.30893019550750334, 0.2758694259870437, 0.09774391719650838, 0.08892454447284823, 6.994687712961628, 22.593834746268488, 40.38891630788004, 41.25849793034215, 52.5130448802825, 51.37360811233521, 31.73588529709847, 56.122453058919604, 61.24329167027628, 67.6226580527521, 59.11106771038425, 3.3734658456617788, 0.30295737568409215, 0.0893087605495126, 0.054872269486828204, 0.04526867553771985, 0.08157557026753504, 0.030548437798936522, 0.04127676373407726, 0.04163915396577889, 0.04734149495620401, 0.06336777087961955, 0.020949419309955933, 0.06017629455234255, 0.05510575010351116, 0.014401002197466312, 0.051065888856687856, 0.027730649585024487, 0.1128628692259231, 0.051516969087383443, 0.020127899178694335, 0.037485789132094195, 0.05394212000312344, 0.02294395986433712, 0.04466914278905719, 0.0610732073114524, 0.0169897866210029, 0.04609207833005537, 0.0904659976461722, 0.030770233659554395, 0.07691234710716432, 0.059082194591962525, 0.04524737063254561, 0.017341581856711738, 0.0054878828157069945, 0.04910236720236079, 0.06976015790696106, 0.01684182248408756, 0.04522485913889063, 0.07174528324075284, 0.017435590421120008, 2.122730598334343, 85.57823319588938, 94.44556682340561, 91.8440704960977, 70.45277364792364, 53.518026721092966, 31.67908153226299, 30.39268728225462, 35.45914419235722, 52.006215818466686, 31.11977900228193, 0.6446491986993821, 0.1367741204317539, 0.4882088351634241, 0.9780168329035083, 1.0640609480680958, 2.506404346035373, 2.521979097397097, 0.3660614476088555, 1.789217223563502, 77.03068256378174, 91.55693731000348, 87.17262960249379, 82.92728362544891, 73.53930242599981, 64.8897191785997, 73.62706938097554, 69.04104202024399, 68.16678493253647, 64.54990071635093, 61.72065980972783, 61.97445677172754, 62.640789016600586, 56.718445439492505, 60.32788499709099, 57.09148637710079, 57.351531674785, 58.69878345920194, 62.960199386842795, 71.3257912666567, 72.53974914550781, 73.89284918385168, 72.35023590826219, 72.49732478972405, 72.52942546721428, 65.97119900488084, 58.449108908253336, 52.05175845853744, 53.161322455252375, 52.235901971017164, 57.747275290950654, 59.20865628027148, 58.37334832837505, 55.39169980633644, 54.27313004770587, 51.79050899321034, 64.99746668723323, 68.7594158418717, 76.41781222435736, 69.65709732424828, 62.157576545592285, 56.00439756147323, 53.94316065695978, 51.7422991414224, 55.02959051439839, 50.395659246752345, 55.97537594456827, 56.70225389542119, 74.927123285109, 55.636883243437744, 45.92407095816828, 74.40090594753143, 58.21586124358639, 60.590075831259455, 55.24236732913602, 55.2896789581545, 49.075005054473884, 52.91917493266445, 49.96071546308456, 55.80351337309807, 53.05539492637881, 55.248635276671386, 54.457163733820764, 53.4129072004749, 51.514868351721, 52.50593362316009, 50.1654004281567, 51.517049189536806, 49.93206647134597, 53.3645365315099, 51.395392956272254, 52.86845476396623, 52.181024089936294, 53.98386701460808, 62.80907438647363, 69.15029571902367, 70.65495614082583, 73.11564722368794, 70.7994641027143, 66.3805454008041, 56.975776457017474, 55.96209872153498, 56.05034812804192, 57.035196442757886, 59.17257831942651, 70.7477201954011, 74.66118658742597, 75.32825623789142, 73.71384789866786, 73.93443415241858, 64.64410820314961, 69.08929501810383, 65.49372103906447, 69.37916601857832, 75.2376651763916, 63.752020020638746, 14.46654058271839, 0.731061403789828, 0.7043998279879171, 0.7977828816060097, 1.4671966385456825, 1.1354703936846027, 0.8473447866497502, 0.20062989314957974, 0.2766603658035878, 8.980777398232492, 37.35306847480036, 38.053901887709095, 40.70101538012105, 47.47898478661814, 47.364714376388065, 39.86854722422939, 61.217709972012436, 69.3775264678463, 71.4867574937882, 73.49905890803184, 8.228662917690894, 0.4193832202544136, 0.15204577676711545, 0.024474270288802447, 0.07545572284969591, 0.06160632406751956, 0.043033548901158, 0.008239686440285898, 0.08383549900064546, 0.05438258608562812, 0.036414698622519934, 0.01429956545302224, 0.062459516188790726, 0.08357586414222756, 0.01644122744760206, 0.048651566593757564, 0.05223985731361374, 0.0460532836375698, 0.04976823550438689, 0.0265721082236738, 0.07307224711703678, 0.05650501352764907, 0.11796229518949987, 0.08876978705126433, 0.24125930492676076, 0.07716475775645626, 0.1176072747236298, 0.23483673020476298, 0.11927871769594571, 0.19080696056687063, 0.15786073651284943, 0.14789924926815495, 0.085716528307286, 0.21099622721873948, 0.17713943105791846, 0.20525508770538917, 0.11720047437495763, 0.12970723512191928, 0.14831653736051054, 0.1707268461224533, 2.7140808538083108, 98.2704347179782, 104.4748398565477, 105.61856377509334, 84.56096649169922, 63.036983705336056, 32.5609205615136, 40.30540120217108, 49.94795207054385, 68.20845619324716, 40.843628837216286, 1.1783734012034632, 0.23031673484271575, 0.6098686843629807, 1.7413535209432727, 0.8101696040361159, 4.216912715665756, 6.203716762604253, 7.792362484239764, 1.866679376652164, 83.00715092689761, 94.65949289260372, 91.02136119719475, 85.03922893155007, 76.23645751707016, 69.81921672821045, 79.27221513563588, 71.64300903197258, 71.09346928135042, 67.13980643979966, 66.27625742266255, 64.09776126184772, 65.82527114499, 59.86357442794308, 61.981022819395996, 57.91220703432637, 61.939092682253936, 61.46736883348035, 64.85106029818135, 76.19449600096672, 75.78813060637444, 76.54742302433138, 75.42795504293134, 74.23630760562035, 75.13609147840931, 68.25760349150627, 61.18168300197971, 54.51596006270378, 57.73148382863691, 55.759076841415904, 60.57651619757376, 62.3466936234505, 60.82069550791095, 58.61822189823274, 57.59747212932956, 54.66190361207532, 68.07557413654943, 70.75567476211056, 77.55173806221255, 73.9059106765255, 65.80019543247839, 60.66889978224232, 57.86211444485573, 56.672753749355195, 58.39126571532219, 53.46056399806854, 59.27978454097625, 62.186033341192434, 78.88987033597886, 60.630295815006384, 49.19626120598086, 76.35407370905723, 61.976747435908166, 64.88580857553791, 59.003798730911754, 60.37530253010412, 50.956569948504054, 55.898956406501036, 51.68363225075507, 59.11573533088931, 57.4995776145689, 56.87751716183078, 56.81860708421277, 57.29506131141417, 53.958877594240256, 56.82772267249323, 53.20400960983769, 55.6043589499689, 52.306728209218676, 56.42380483688847, 52.75543951219129, 53.82580726377426, 55.225336397847826, 56.033254438830966, 68.10488208647698, 73.94064718677153, 74.05493720885246, 75.00323295593262, 72.51498330023982, 70.133649610704, 59.38096207957114, 58.662211279715265, 60.08851451258506, 60.92170046221826, 61.82132744020032, 74.74556461457284, 77.39540023188438, 76.4168865449967, 76.40463306057838, 80.41629206749701, 67.01226665127662, 70.94805132958197, 65.53860472094628, 72.04942149500694, 76.81157896595617, 66.09075284773304, 12.431647296874756, 1.2264205972033164, 6.6833760565327065, 6.378072000318959, 3.927322409806713, 0.8946889590832495, 0.8726593960196742, 0.4238156211231986, 0.505848040263499, 13.834225093164752, 41.80975960146996, 58.820828007113555, 53.091076727836366, 61.43941410126225, 62.684558745353456, 47.44928852204354, 72.4568380848054, 79.7209107491278, 84.35300242516303, 83.81572400369953, 7.152157637380785, 0.5410923135857428, 0.353772018345133, 0.14409652670785306, 0.17692648925848548, 0.1716623007650337, 0.11678566840747673, 0.1456993818283081, 0.2019656134108382, 0.18519263924850574, 0.17669027370791282, 0.11468455736194888, 0.10180306470682544, 0.3442485648537836, 0.16785242294351901, 0.19087091358678956, 0.14019859474032156, 0.21012477156135345, 0.32317177001987735, 0.23276173509657386, 0.19973435168785436, 0.1212292848034732], [0.09622421325935472, 0.04930261109444884, 0.011753261562496906, 0.09028097209069999, 0.0575382822764016, 0.06977655984941991, 0.03652000889903115, 0.012030373759297355, 0.05155172649650805, 0.15313058791141357, 0.05216167038006168, 0.08983324732511275, 0.04770159841545167, 0.06716495845466852, 0.0661900732666254, 0.06597451910737061, 0.23642360473111754, 0.3613766667342955, 13.86421553550228, 96.91323188043411, 75.62223788230651, 81.4220662270823, 66.18871796515681, 54.274883347172896, 34.69554893432125, 73.23979023964175, 66.38834307270666, 50.67900734563028, 7.952987465166277, 0.11192222816809533, 0.10086165756107339, 0.0713055411113366, 0.19769998988316906, 1.0862098369867572, 2.0876329848843236, 0.9305502089761919, 1.6317757363280945, 30.17992223462751, 96.44160609091483, 80.88077129856234, 84.62468931751867, 70.57448479437059, 65.02453104142221, 67.11956700971051, 66.65887678823164, 64.77450739952826, 60.291289283383286, 57.06635575140677, 59.68644019096129, 53.53493605890582, 57.12624249919769, 55.74444640067316, 54.379645932105284, 53.25813439584548, 53.61992989816974, 53.82865490451936, 56.351648915198545, 63.977297429115545, 68.48812903127363, 70.32914838483258, 68.63000116040631, 69.072295465777, 67.62736489695888, 61.207515731934585, 53.856597869626945, 51.469502218307994, 50.893051085933564, 50.101210840286754, 58.962915866605705, 60.33774975807437, 58.70070934295655, 53.810408038477746, 52.05073864229264, 54.64246042313115, 63.65456088896721, 68.1523270760813, 73.9761838605327, 65.25998307812598, 62.47510810052196, 51.58686737860403, 52.04562779395811, 47.56761074066163, 52.50344684047084, 47.46635083229312, 56.034560588098344, 54.27349875050207, 70.78012681776478, 50.58397616109541, 40.510172459387014, 74.10632810285016, 58.34652323876658, 60.629546642303474, 54.163852814705145, 57.104477267111506, 49.008414976058475, 49.603626804967085, 51.57022868433307, 52.547785312898704, 51.6584506342488, 53.00654572825278, 49.361392990235366, 50.98476394530266, 47.75880667471117, 49.58989066462363, 48.59508345204015, 47.34684013551282, 48.28145073306177, 50.518782446461344, 47.7730134994753, 49.857800314503336, 51.09764583649174, 51.91738590117424, 56.38172957205004, 66.03405890926238, 69.18941743912237, 70.00909866825228, 66.51448649744835, 67.86951634191698, 59.06466999361592, 50.902837399513494, 49.425935591420824, 53.36011994269587, 60.287551264609064, 68.77426593534409, 68.53820200889342, 69.9083722022272, 64.60129945508896, 60.426014854062, 65.7898639094445, 71.07104116870512, 63.404117553464836, 65.30422741366972, 73.8542373718754, 73.6855911439465, 75.07389837695708, 25.595807029354958, 0.5158591546839284, 0.8766380276891493, 4.2122813770847936, 2.4350883018585945, 0.6090371418864496, 0.48720673087143135, 0.04525079121512752, 0.5775577923463238, 12.752501099340378, 26.022207890787435, 42.190064768637384, 104.13256599057107, 89.25151717278266, 28.80778105028214, 31.670593523210098, 48.61058858133132, 54.29294193944624, 66.29263724050215, 34.83001562856859, 0.5151811362274232, 0.02552666825302426, 0.048379613041517236, 0.007730337083264585, 0.06442827788451988, 0.0280310939471688, 0.07207541350996302, 0.019644909470732656, 0.042449866511648705, 0.02142467727554181, 0.06738527768081234, 0.07373734167025936, 0.05094825222547497, 0.0881769882154561, 0.03487767343739829, 0.032077317554203254, 0.08992740719188606, 0.08582495273120942, 0.024880647373896454, 0.031017597704645128, 0.0729063967423093, 0.03942097702454175, 0.031740102886913285, 0.038877839838425, 0.02689567503459271, 0.061769416525719635, 0.06075515824880812, 0.03658182070320172, 0.03360614751375491, 0.04665354416976052, 0.054463963775384816, 0.03536654861583825, 0.021179383583066445, 0.029325347784305775, 0.07366102399124254, 0.09057570909780842, 0.09690960148169149, 0.1147771084440812, 0.3313681447217542, 17.888177056466382, 110.87680693595641, 84.33066060466152, 91.56257767831126, 72.6300185726535, 60.94660751281246, 39.577707398322325, 43.97224464724141, 58.807099711510446, 55.80368203501548, 9.988715725560343, 0.17122582983105414, 0.04172756434268048, 0.6400951430682214, 1.0319436005046292, 2.286405222069833, 2.66927243240418, 0.2889095601295271, 0.49938642570087993, 33.70244795276273, 98.59168467983123, 82.98716252849948, 88.69230485731556, 72.64266429408904, 68.5976416064847, 70.46035951183688, 67.87145399278211, 67.10915703927317, 63.81448376563288, 59.153072372559585, 61.55080156941568, 57.500652343996116, 59.46965471390755, 58.73371216558642, 57.38637016665552, 56.533333101580226, 57.84492269639046, 56.602704140447806, 58.099433529761534, 64.91115885396158, 72.26753665554908, 72.57818837319651, 71.14026315750615, 71.17943979078724, 71.40289721950408, 63.59570964690178, 55.22990595909857, 52.50205832142984, 53.641793189510224, 52.204966237468106, 60.65601479622626, 64.00797428623324, 62.7718863948699, 57.7783679193066, 55.533446419623594, 57.16251265618109, 66.75271557223412, 71.29600478756812, 75.35230036704772, 68.74281637130245, 65.50122845557429, 53.42881633389381, 54.80836883667977, 49.86970863034649, 54.988652736909934, 51.169115343401515, 58.41232884314753, 56.685321023387296, 75.26046199183311, 52.87573860537622, 42.92732131096625, 76.332853686425, 59.88813238759195, 65.3299307054089, 57.701685582437825, 60.31698865275229, 51.691912374188824, 52.67596052538965, 54.46478489906558, 53.946310320208156, 52.71384277651387, 53.72204488323581, 52.138168273433564, 53.457606530958614, 51.96774913418678, 51.12302357150663, 50.843644911243075, 49.17116195924821, 50.83981667795489, 51.30363302846109, 50.443798495877175, 52.127346454128144, 53.362689095158736, 53.33253783564414, 58.577652823540475, 68.37646699720814, 70.32267647404825, 71.27185083204701, 69.3403894670548, 69.67742304648124, 62.52725993433307, 54.006895249889745, 53.89804947760798, 55.65855433863979, 63.387165069580085, 72.883788078062, 72.92598493637578, 72.1735409767397, 66.92824948218562, 64.2049204149554, 69.557618171938, 73.37134653522124, 65.2974848593435, 70.91523678072038, 76.2453220736596, 75.9222678215273, 80.6298258996779, 33.213704939811464, 1.020599247947816, 0.6756932264374149, 0.43506102576371164, 2.0721256492599367, 1.7570009587272521, 1.557105575357714, 0.058362412852265184, 0.0571929719749718, 19.532048279239287, 34.493476267783876, 29.040820829329956, 86.23948204901912, 77.13761421941942, 43.23559999465943, 43.30422186082409, 58.03748753763015, 61.886489775873, 75.95709846865746, 52.48620410119334, 0.6073826984051736, 0.058118026973980094, 0.03381600580929268, 0.05416267671652379, 0.08907706491769322, 0.05764415179709754, 0.09565931534574879, 0.03220461646936113, 0.03362154971147257, 0.055077979416255994, 0.03661981483380641, 0.07890322576126746, 0.006056219027678092, 0.029385772969333396, 0.012787299272003434, 0.006347624509925804, 0.025732914443999052, 0.029089256723020828, 0.04071854993761067, 0.05283162576116381, 0.05019416506852835, 0.11116602277803807, 0.13725513171765114, 0.14659454024607135, 0.18481803757529106, 0.16792884787484524, 0.1911226807222251, 0.14630927974658628, 0.12701308775332668, 0.10637613464026682, 0.21168256539010236, 0.14191388092454404, 0.16866079892121977, 0.1741503245167194, 0.1809643701680245, 0.188364656942506, 0.19711860575743262, 0.34281735939364283, 0.7000106344780614, 21.336530754643103, 123.87728321936824, 94.86032609016665, 105.47185928590837, 85.6112438632596, 71.38755290738999, 48.15029844161003, 101.67834681849327, 83.58035825913953, 73.26517581939697, 14.578124169380436, 0.3829204074798092, 0.2350745392182181, 1.7907307681537445, 0.8998965796443724, 3.547054260007797, 6.583013880637385, 6.905933791591275, 3.8390798674475763, 38.60576760384345, 99.63217966018185, 88.02963610618346, 94.37722344552317, 74.63802106918828, 72.02381626252206, 73.70178268801781, 71.57155129217333, 70.62472251153761, 66.88325989630916, 61.45469173308342, 66.25570420295962, 60.06205420340262, 62.845050365694114, 61.77875403435, 60.08408223429034, 58.99092943437638, 60.45141220092774, 58.48301779839301, 62.023600147616484, 69.5961436917705, 74.44256151876142, 76.33015509574645, 72.43115440491708, 72.85927326448503, 74.24449751454016, 68.10929083055066, 59.68795814821797, 55.92208662340718, 56.71175387597854, 55.37336272578086, 64.02016501272878, 67.74320033288771, 67.19872828452819, 60.286001928391, 56.77767322909448, 59.00048825048632, 70.19740381548482, 75.81582253979099, 77.11575092807894, 71.15536428266957, 68.337721824646, 56.7652157814272, 57.02363721786007, 53.47653588941021, 58.44955605845298, 52.794988770638746, 61.79425131890082, 60.86105277461391, 75.3739361609182, 57.1963313318068, 47.80623597483481, 77.88296653378394, 63.49630501962478, 67.50177844878166, 58.72939755839687, 63.32199881153723, 55.66225705608245, 55.66429668857206, 56.04484896506033, 57.92472723991641, 56.31749683810819, 57.61653877073719, 54.69557716000465, 56.351452796689934, 54.13216790845318, 56.05743192857312, 55.26279111062327, 51.33243107026624, 52.97434306913807, 53.78062940412953, 53.24981504871, 55.21552262767669, 56.98170315834784, 58.42409203129431, 62.879045547977576, 71.97663014934909, 73.87709694523966, 73.43310033121418, 71.50158405303955, 73.02543270972468, 64.27871196500718, 59.427469622704294, 55.06373082437823, 59.55116941082863, 67.10423054233675, 75.30633803336852, 74.13586355024769, 73.84694960809523, 70.94050468937044, 68.053985411121, 71.47795569512152, 75.45705902960994, 66.18514076355966, 71.89411132566391, 79.6653699874878, 78.30291901865314, 84.11668746702134, 31.25183540005838, 0.7290408928548137, 3.476746019817168, 11.037353546388688, 7.69002833674031, 1.9082773380702542, 2.065578232849798, 0.19065009640349498, 1.304144078204709, 21.425017464545466, 42.39429866113971, 55.71758600973315, 112.97966803273847, 97.3388090441304, 42.16730325452743, 47.04779863357545, 67.38493104134837, 69.83609076469176, 86.455565421812, 54.9128137096282, 0.7260537015334253, 0.2331703051083511, 0.18004984504753546, 0.12429941280354416, 0.16189216696206601, 0.08658590786639722, 0.3141130561069135, 0.1246105440922322, 0.16866864366156442, 0.08149789661289224, 0.07841619302428539, 0.1544124675133536, 0.13584056568722572, 0.11568679188888882, 0.14589078123531035, 0.1474183758780841, 0.1602733925345444, 0.1748180927167977, 0.08655170970145734, 0.11966081170905983, 0.16476196296993764], [0.0687621598462424, 0.020356509391398683, 0.07414156030262671, 0.055632780291019916, 0.03397350965608512, 0.05279190410228987, 0.06563055329024792, 0.00787439129893638, 0.06786100296003204, 0.08497592812824635, 0.039826980641772675, 0.03726558481913902, 0.05496712649361261, 0.08377240399920172, 0.08307946981081078, 0.0537540300959541, 0.08858358938126795, 0.030543933201941754, 42.94170856475831, 86.2536104263798, 77.67781088429113, 64.00094539888444, 49.83070850372315, 28.956313363967407, 43.15277914847098, 107.9194574971353, 64.81623357342136, 38.472681583896765, 1.1981053746515706, 0.03313157136642164, 0.02457720186230877, 0.5160903293759592, 0.5988106035417127, 3.334929294163181, 2.204409299358245, 1.845942050699265, 4.677082242504244, 84.93858875766878, 83.39874467542096, 84.31268045979162, 75.5956599020189, 69.11984243700581, 62.96515334037043, 62.31332994276478, 61.648688239436, 65.48790416409894, 59.40149568742322, 57.28254110582414, 52.9088669438516, 54.9023723602295, 54.40691424954323, 53.02381200175132, 53.01173110162058, 53.635733127594, 53.95832454004596, 52.341853034111764, 54.654713907549464, 63.32708220328055, 67.7785958013227, 69.43877035571684, 67.023633680036, 68.49910382301577, 69.19665813446045, 62.23334497021091, 51.29324266987463, 49.55340085491058, 49.5500393836729, 53.65495666380852, 62.92501964876729, 62.2291244999055, 62.05082531898253, 56.155095023493615, 59.071208584693174, 61.318263853749926, 66.28625946660196, 69.4651992859379, 66.1407866016511, 64.99467395967054, 61.57413574957079, 49.98558721234722, 52.23337988699637, 47.279520496245354, 52.9498125660804, 53.92788694750879, 58.95565555941675, 53.89616673992526, 70.79232538900068, 47.66492866700696, 36.59618831449939, 69.96168505760932, 61.283370448697006, 68.77123786557105, 60.812411462107015, 62.10169846011747, 52.30652424596971, 48.97715760815529, 47.992834891042406, 48.30808362653179, 48.03781270980836, 50.97934322972452, 47.63613846994216, 48.338685958616196, 46.105323683831, 50.01447154629616, 47.53272518034905, 48.00459415681901, 45.990664958953865, 47.59706774065572, 47.57896992468065, 47.529881461974114, 48.29371990696077, 49.54883521603, 52.92760410616475, 61.319993618995916, 66.61840577279368, 66.37837240772863, 67.63724926979312, 66.05225870686193, 62.91257004584036, 50.498193925426854, 50.268762726937574, 53.01320983517555, 61.57929758871756, 69.01884140506868, 70.6375486620011, 65.90985313538583, 64.73885305466192, 71.2237782632151, 70.36393196352067, 69.76933202435895, 67.27144118278258, 68.98801942025462, 70.89640155915292, 70.64930008303735, 73.91579504935973, 76.05569901004915, 34.510432674038796, 0.5708794668316841, 0.8437395768780863, 2.450949876539169, 0.7557773001251683, 0.7551149098623184, 0.16505948087621122, 0.0977352757247225, 10.7741174005693, 16.814826342367358, 57.0480735840336, 83.24985150367984, 82.0215848184401, 29.919637672362793, 28.01263032420989, 55.496525149191584, 60.88022532001619, 60.874290773945475, 68.72467933162567, 9.778904222672987, 0.7065498997126857, 0.17066393498211138, 0.1427792998090867, 0.08673971533895501, 0.06651821936811171, 0.01593216680996721, 0.011340345916969162, 0.03198160252894365, 0.053253812985795165, 0.05017709279913576, 0.017428536666557193, 0.03750165481300604, 0.011253737761909443, 0.054096835289871505, 0.06604555844058914, 0.02008907575791161, 0.062366785075996196, 0.026829015809081258, 0.0238888603710239, 0.03014282297132717, 0.08301929360435856, 0.03896329694637849, 0.06830365622356054, 0.04761530244122109, 0.09200637063552296, 0.020134943357158094, 0.029549897731011434, 0.0933904080621658, 0.07008643475391212, 0.01342679116679656, 0.04219289380876769, 0.10807485800356635, 0.12075083991212231, 0.03331875728984033, 0.06591896241110179, 0.05477871099907545, 0.11577113050847285, 0.07718383334577084, 55.84749883221042, 95.72746015364125, 85.11729978745984, 72.56217725815313, 62.406741188418486, 41.369026399427845, 40.616731489858324, 96.59497860939273, 56.43230069068171, 42.57837941569667, 1.5186988297970065, 0.029335136472758268, 0.18797681726995977, 1.7422697621007122, 1.582955955978363, 2.4823028522153057, 1.5034873879724935, 0.9063146191258585, 5.863711007179753, 88.84872113504719, 84.94811227244716, 86.99536984966647, 78.60753813097554, 71.97727341805735, 65.67134164994764, 64.63587122578775, 66.45097547961821, 66.23310350602674, 61.996127866929584, 59.6833925093374, 56.64698377732308, 59.62508647672592, 57.748612819179414, 56.10812856305031, 56.31040127046647, 56.06947360500213, 55.08897912117743, 56.30236825635357, 57.63413060096003, 65.417250510185, 70.12153733161189, 73.6375185751146, 69.17261400530415, 71.4164686203003, 73.2713496300482, 63.90051703299246, 53.86058299772201, 52.007576880916474, 51.333850968268614, 55.21380855191139, 64.2159265856589, 65.43640344373642, 65.9542465209961, 60.77466257156865, 62.94851856846964, 64.42313363475185, 69.3853319844892, 73.23687984097388, 68.36167181691816, 70.77806365105414, 63.65876566979193, 53.472244816441695, 54.776640784355905, 48.571058934734715, 55.12497471224878, 55.79130303475165, 63.47574003281132, 59.54690187208114, 72.849302599507, 51.330552254953695, 39.2034387588501, 73.61840094289472, 63.987491669193396, 70.43304412595688, 64.6596957022144, 65.50456247022076, 54.667261569730705, 51.514272151454804, 50.751437833232266, 50.32408383584792, 50.89016814385691, 52.11658347037531, 50.72479317265172, 51.7606479890885, 48.247836020685014, 52.307045921202636, 50.96434016381541, 50.71051182285432, 49.32995911567442, 49.98190018438524, 50.30520154583839, 50.73639946599161, 50.759729723776545, 52.356099082577614, 55.80500387376355, 64.05267753908711, 68.70709142377301, 68.95078043783866, 71.33070991885278, 68.37286626138996, 64.9549207379741, 52.48639629733179, 52.719757710733724, 56.167093553850734, 64.8683540282711, 71.5558853457051, 74.69553870539512, 70.23421133718183, 68.75801947809035, 74.23820603278376, 73.34329374374883, 72.33250679508333, 71.674317390688, 72.16165619511759, 74.3229135390251, 74.34312159015288, 75.59691506047403, 80.1951253029608, 42.148562169844105, 1.1044749665644862, 0.8202087879180909, 2.8082049902408355, 1.67515249261933, 1.91380150616169, 0.4313559181267216, 0.07306520676901264, 5.661400546950679, 27.813952469056655, 44.47050333023072, 72.29807622971074, 73.095548998925, 31.608488675086733, 39.38642517212899, 59.69707765886861, 68.26001182679208, 65.71253830386748, 80.12841363107005, 18.785397660347726, 0.8938840764664835, 0.15809128301278239, 0.07159593439991437, 0.006173160912904648, 0.12393640204062387, 0.06282735330563399, 0.016879353131498062, 0.041600129446916045, 0.04487340864274771, 0.13758516239543117, 0.04347023817019598, 0.026808858120573625, 0.016826705654121695, 0.059080765837983745, 0.07168859273435609, 0.026557433809484207, 0.015228953636852244, 0.051494691250545364, 0.01844179519872752, 0.02484608914763216, 0.26348052786723264, 0.12063156768319108, 0.16356190155831077, 0.1420769197565894, 0.20748170693555187, 0.11454723610152161, 0.19183420786453834, 0.13030475305934108, 0.17450192823044716, 0.10236098355944119, 0.12413032187689697, 0.18995177661699636, 0.15474249819113364, 0.18143045806115676, 0.20727281008035908, 0.24109566854613446, 0.17143930789203415, 0.14551941245313615, 62.42034004580591, 105.96461880591609, 99.4277378820604, 84.32978199374291, 69.60372171094342, 40.175986520705685, 56.78185447569817, 134.02112868524367, 85.06145308094641, 58.40498224381478, 1.926995501402886, 0.18999789511003803, 0.5303000346306832, 2.033692305126498, 2.9604034942965356, 9.811782510049882, 9.14773798757984, 5.350745887525621, 6.399714168040983, 92.87750521013814, 88.8428532692694, 92.77414291135727, 80.34219065020162, 75.79970944312312, 69.61993678923577, 68.20210979830834, 68.33175197724374, 71.48591026183098, 64.69127862684189, 63.062636006263, 58.93631435209706, 62.27539277845814, 60.3296971321106, 58.56378724498134, 59.840612872954345, 59.64715765368555, 58.870963742656095, 58.619120121002204, 59.90139392114455, 71.71346264500772, 73.33145603056877, 77.51042765955772, 71.08007830958213, 73.49835288140082, 75.99835395812988, 67.51740517154818, 55.28999667013846, 54.63221911461123, 55.332930934044626, 57.91657263232816, 68.67291973483178, 68.22618530642602, 68.49223967521422, 63.132669925689704, 64.79060480671545, 67.44602587915236, 71.91505678238408, 76.0511725948703, 70.9993794656569, 70.88348127180531, 66.89401503532164, 56.50702968720467, 56.99328591746669, 51.640470489378906, 58.53336926429503, 59.15490411943006, 66.30435728257703, 62.231317104831824, 76.04954873361896, 57.25683389171478, 44.99401423238939, 75.79586552035424, 68.06606631125173, 73.13962859492149, 66.84368318127048, 68.93418881200975, 58.42058150999008, 53.73559274981099, 53.38931806625859, 52.055653372118556, 54.237711045049856, 55.69434988883234, 55.072728741553526, 54.294848211349986, 50.550318302646765, 55.575662889788234, 52.66938271061067, 54.233580789258404, 52.626475903295706, 54.2664816302638, 53.85822957561862, 53.08315354008829, 53.27716573592156, 55.09532943848641, 59.79362680066017, 67.44428434679585, 71.66542145513719, 70.44857671183925, 73.68337892716931, 71.70687306311824, 67.68160343170166, 55.62983866660826, 56.65091791460591, 60.31845561919674, 67.9053746500323, 75.26816552685153, 76.04832495412519, 71.76294726710167, 71.7348317177065, 77.32413861059374, 76.58286556120842, 75.09414565178656, 73.18962312513783, 74.15744443093577, 78.59719091846098, 77.76729583740234, 79.16769966002434, 85.21282519063642, 41.71223771187567, 0.5081527391749044, 3.2667072646079527, 9.072751095218043, 3.6166491191233363, 2.6708965388036545, 0.7375151736121024, 0.17145865927300147, 17.031845200446345, 31.076181857816636, 79.3731455649099, 86.017452363045, 86.4579031544347, 35.25175671423636, 42.88660318620744, 69.74554677163401, 80.7579932674285, 73.95159059955229, 94.61815895572786, 17.426857294574862, 1.2606176589765858, 0.5228801360053401, 0.27855339970800186, 0.25429597635182644, 0.18091203104103767, 0.1467607047168478, 0.13415037654340267, 0.12809039123596686, 0.17492480876465, 0.19482308457936012, 0.11871241784143834, 0.10791437024430883, 0.0954707887684626, 0.2647745116583763, 0.2513613693055607, 0.10820366802715486, 0.18460950844230192, 0.1905980943551948, 0.16173775428004805, 0.12484118252271607], [0.10751927571911966, 0.08540874482282708, 0.006578839900377657, 0.1344050241694335, 0.04768768625874673, 0.11213631909941474, 0.055624935550675284, 0.03845189878296468, 0.04730883279755231, 0.01849666241586449, 0.06625214937112986, 0.04024293957157962, 0.04068590310071746, 0.05612529821753983, 0.06624933782844775, 0.05326350016759769, 0.11116460551537814, 4.1630119950540605, 83.06767309865644, 76.16091266755136, 84.47495675856068, 70.32189200001379, 47.819532809718964, 22.622834790137507, 68.3906267535302, 71.53306499604257, 64.35068745766917, 13.32068975894682, 0.18579512143567686, 0.04382206021898216, 0.3468319052650083, 0.09449475444853307, 1.9644041263288068, 1.5551518672896971, 0.44102744109207587, 0.5586824890586638, 39.07446338284401, 94.26945240266862, 74.0917133515881, 80.3425750424785, 65.71075754780924, 67.01896605953094, 61.005901982707364, 63.39728086225448, 60.229676692716545, 61.76159758721629, 58.1009828659796, 57.0376322346349, 55.94348707506734, 55.127516408120435, 53.85513482555267, 54.300876894304835, 52.506635727420935, 53.19025385764338, 51.00445032119752, 50.31703925901844, 53.785038148203206, 61.20586441409204, 67.72660086231848, 71.43120888740786, 73.50219680416969, 67.98238646599555, 68.67089579182287, 59.28423250875166, 50.629138331259455, 51.63909765981859, 50.236352182203724, 57.72676129494944, 65.04089124741094, 62.65953402365408, 65.38503608395978, 61.64763312185965, 67.44804982216128, 63.16515891782699, 71.4812034176242, 61.83467918826688, 62.87072620084209, 65.42106697636267, 59.4862110384049, 51.849560276154556, 49.15853192729335, 47.78236835233627, 53.799801949531805, 56.08311560846145, 65.23657437293761, 61.13653652129635, 70.07036609034385, 47.58673621762184, 37.94740953753072, 67.76889185751638, 60.73007306744976, 63.71931922051215, 62.0643457289665, 67.82635458054082, 51.78040496764645, 49.00355515941497, 45.82749435978551, 49.566011275014574, 49.4455199856912, 48.04332756227063, 48.193938732147224, 46.22521877288819, 47.71540564875449, 49.92907370290449, 51.387779635767785, 51.44926278821884, 49.47219210286295, 46.581613171485166, 45.28022173912295, 48.970352295906316, 48.156303590343846, 49.11491909334737, 49.72962510201239, 59.417746067047126, 67.57666434011152, 65.68342255007836, 66.10590888607886, 66.99878938736455, 64.06902990033551, 53.25720871648481, 49.83474462263046, 52.338856343300115, 60.24005136182232, 68.13586881083828, 69.67107665154242, 66.52775979811146, 66.62031988943777, 69.60117217033141, 67.33092000407558, 70.03027946718278, 68.22337688938265, 70.37012146365258, 69.098677327556, 67.84038097627702, 72.92053284183626, 71.40794138754569, 68.20644793971893, 24.318687223619033, 0.9731082930680245, 0.5142346192752162, 1.5330053072783256, 1.0924749653185568, 0.3200362640763483, 0.006089437078879846, 3.657373127437407, 22.548266610791607, 24.647066093260243, 49.042735715066236, 39.907849373355994, 31.306691708103305, 31.014029941251202, 40.494126043012066, 45.39498244562457, 61.476864891667525, 55.1525568193005, 50.54942400224748, 0.5238936396856462, 0.030664335410561294, 0.00396598786708989, 0.02061371766631642, 0.05609989474197069, 0.028890453076230425, 0.018675921244486686, 0.035270998299482374, 0.07364461438790446, 0.05151476275416152, 0.008057028096499703, 0.02285889920688445, 0.07904989329437095, 0.09001808901948315, 0.06543533876538277, 0.04881979950192956, 0.047958835418666565, 0.0784382257129877, 0.043930718299722483, 0.06512954710952698, 0.04698265554203142, 0.025614304881122325, 0.029163165055515788, 0.14194912096906093, 0.03528286117098985, 0.10498727852058028, 0.0263569830736566, 0.059243421626066974, 0.04303933286498632, 0.06049266205199304, 0.03766599982496231, 0.04981521967678301, 0.06714346202751321, 0.025777766976745862, 0.04076285280227181, 0.04105850911488937, 0.16542113566350553, 6.369853654215413, 97.12933878744803, 82.90055659509476, 93.38943727554815, 75.19160086108793, 53.056097030639656, 27.430393695831302, 53.86987117029006, 74.80622014691754, 66.06373556198614, 14.35209268523801, 0.15385431117348133, 0.05119138555000386, 0.3874888962074634, 1.4074480317292677, 3.5029545618641764, 4.149773995722494, 1.2212469909460315, 0.22038549274927188, 43.019642137712054, 96.25149665340301, 79.05206034260412, 83.40047836303711, 67.80722125884026, 69.02695286658503, 65.40345945665914, 66.80285130777668, 63.01687763583276, 64.10110312123453, 61.92440732832878, 60.488580580680605, 60.311261992300714, 58.123520804989724, 57.62652904756608, 57.300587930986964, 56.186901523220925, 56.94717061135077, 52.56838167867353, 53.93316253539055, 54.2891921535615, 62.02042695014708, 70.77862062761861, 75.14650929358699, 72.2839713865711, 71.34137092098113, 71.90483508571502, 59.840063741130216, 52.78362174187937, 52.1790668272203, 53.052056989362164, 61.67030442145563, 67.96250789396225, 66.12166896943124, 67.98192362631521, 64.89505360203405, 69.53493902760168, 66.3764347568635, 72.35781392743512, 65.77872437815513, 65.98736701473113, 68.87153287087718, 61.16435789292859, 55.01745862345542, 50.869320746391054, 49.30852336268271, 56.235888004302986, 57.94709651700912, 69.32853606439406, 63.85739841768819, 72.9628630607359, 49.40130702910885, 41.304060182263775, 68.96001369722428, 62.17708249245921, 66.80817788647067, 64.57766325243058, 71.35028254601264, 53.82371271810224, 52.67446610235399, 48.322498336915054, 51.65527743677939, 52.191936123755674, 50.045411202215384, 49.38058906985868, 49.031235325721006, 50.838349711510446, 53.14407187123453, 53.20876744485671, 55.83399803407731, 50.76253814081992, 49.810935835684504, 48.04950137292185, 50.909019054905066, 49.908171392256214, 51.45216141977618, 52.435146608660304, 61.732058217448575, 70.91685279723137, 67.05746020040205, 67.63577445860832, 71.87194208944999, 67.49386310577393, 55.7665724908152, 52.4000374732479, 54.029248837501775, 62.532221732601045, 70.08174096384357, 71.82463046043151, 69.67651305660125, 70.8864152046942, 71.6185805105394, 69.66837806086387, 72.78001000804286, 69.78646493727162, 73.64049173170521, 71.64704907325007, 71.3621908618558, 75.35795642483619, 73.48849988752796, 72.07371665585426, 31.849175114785474, 1.466123870303554, 0.5830730125308037, 2.878373495994076, 1.6114247638371684, 0.8622831334510158, 0.031507983991515734, 0.22034217813803306, 22.220046597142375, 33.69093187393681, 45.763124342887636, 46.46267121837985, 25.652459782938806, 39.93487058147308, 51.35893844789075, 52.500909066969356, 69.92785853724327, 61.70641376126198, 65.90143572899603, 2.0343079946694838, 0.12307758683398848, 0.02833642403505022, 0.03327805886886293, 0.04108215058823267, 0.0272562496379138, 0.023305534212399396, 0.025000224122777585, 0.11987949150704569, 0.04407167847779009, 0.01834799730849843, 0.012887125316586708, 0.052156690808553854, 0.04078645597121889, 0.008939883142199007, 0.0541790365241468, 0.03471153961013883, 0.10480550883878624, 0.06419712617512673, 0.02047688478694087, 0.2018972630462339, 0.13808541780998632, 0.11878281366080047, 0.23945352843692227, 0.2278674138529647, 0.15677833088463353, 0.0996694868550666, 0.16669920014758266, 0.10726767712302747, 0.24521362096551927, 0.23742526469211425, 0.200924024947228, 0.18687668436717603, 0.1794925314043799, 0.1943641059821652, 0.11139965661230589, 0.33815761427244834, 8.15521506532546, 111.0162393508419, 92.60742648955315, 104.55526413456087, 86.83863193758073, 67.55498147779896, 30.862685288152388, 91.75697034405124, 80.89792774569604, 87.2949447939473, 22.43838925515452, 0.4238103504382795, 0.15935396445133995, 0.8495217633824196, 3.165799143814272, 5.661525572499921, 5.6867915199648955, 4.266124242736447, 1.4004214732877671, 44.69873820581744, 100.08189508991858, 78.81174456688666, 87.14190175456386, 72.01839554694392, 72.68997592310753, 69.07602171744071, 69.93975116360572, 64.57718864563974, 68.05440118235927, 64.22290055982529, 63.53131609578287, 65.11552218467959, 60.872349200710175, 59.58849860775856, 59.97790367372575, 58.94417478192238, 59.14218779533141, 53.90018324698172, 55.21765247468026, 57.3970978490768, 66.33088034968223, 76.79375571589317, 80.18250311574629, 74.11960140351327, 73.3868242079212, 75.33037431778448, 63.60800627739199, 54.65057972938784, 55.74503867856918, 55.44509503149218, 65.89737215349751, 72.88015596328243, 68.67435532231485, 72.65006188423403, 67.30576976653069, 73.73911580731793, 68.87261544504474, 75.37661906211608, 67.18911063286566, 68.13175816689768, 71.43156974546372, 64.36711434395083, 58.555456130735344, 55.179236781212595, 52.97607675675423, 60.29650211334229, 62.90654528525568, 72.39542945738762, 66.3111900514172, 74.1304349899292, 52.111798178765085, 44.846117342672045, 71.90478801727295, 65.4321555168398, 68.86863031694966, 67.92932464230445, 74.15663642268028, 57.4320226330911, 55.50007489419753, 51.32314289769819, 54.67156440980973, 56.363416025715495, 53.344395160675056, 52.992025113874874, 53.20712397175451, 51.613461048372336, 56.70694112777711, 57.42366798462407, 59.51366762961111, 55.5034520549159, 51.70424038364042, 50.70122365028628, 53.66768083264751, 52.06411784695041, 53.62161651734383, 56.37314742611301, 64.90263554357713, 75.57799354676278, 68.62027368237896, 70.52725161275556, 74.87281414770311, 70.39105907563241, 59.201443041524584, 56.35886999868578, 59.116955188012895, 65.94331879769602, 74.11753823680263, 74.57282343218404, 73.55042626780849, 74.10635948181152, 74.72482312110164, 73.84935794338104, 76.07629929819416, 71.62247934649068, 75.55043497393208, 78.1348297672887, 74.43228490890996, 81.41016575597948, 75.56758357632545, 77.40768509526407, 30.109998141565633, 2.172866333876887, 4.152627520022854, 6.73820637887524, 2.47941892954611, 1.7281466554249487, 0.09057793841366807, 6.032385672292402, 33.47584478316769, 42.716705722193566, 62.9405326227988, 50.32437801361085, 40.575440699054354, 43.269108803041526, 56.47125374886298, 61.446093897665705, 79.06549838281448, 72.2358674387778, 77.70359654580393, 1.7839686019766716, 0.129535018556541, 0.11449652108093424, 0.15343138467400305, 0.2492233098394448, 0.15432245218225066, 0.11730437121924855, 0.14764392748475075, 0.21429207536482045, 0.12415679021468087, 0.17814004913933817, 0.110564804635942, 0.10905008793117539, 0.24115208326087845, 0.20974024138864011, 0.11127802483256787, 0.10982778974838796, 0.219516565182036, 0.23616495812612198, 0.17622072309736284], [0.04758206954706581, 0.0738963662015815, 0.027326023010837457, 0.05684990631116014, 0.046183962915693565, 0.036133961872227734, 0.02018783789789004, 0.023936873016458367, 0.04027497353813341, 0.027409089924467188, 0.04915240806557479, 0.02251341845089149, 0.05179660267106468, 0.015206115598219539, 0.024754974480357864, 0.19241799750635702, 0.31148574224883513, 24.238070749467422, 90.20469234835717, 73.03304995259931, 73.09383884552987, 49.29547363711942, 39.57477346543343, 26.016791097579468, 36.58533119386242, 33.48820809395083, 29.026947406030473, 1.2383236423615487, 0.0969592669618226, 0.24037491770521288, 0.39190432056784635, 2.0187580032694727, 0.4712973216608648, 0.7189893289919823, 1.4992207072434889, 3.794257227451571, 85.05617357069447, 79.5767322663338, 80.77838174758419, 70.36869372090986, 66.43026536510837, 66.12074329007056, 68.9182561443698, 65.72892988881758, 68.7502061167071, 66.51778913313343, 66.09853483015492, 62.97401397458969, 59.549106244117986, 58.148263116036695, 56.37822689548616, 52.75386271938201, 55.4268991562628, 52.200526114433046, 51.84806193074873, 49.06879594249111, 56.30375677539457, 64.91257875196396, 70.82004870137861, 73.5664060038905, 75.20285021874213, 68.54493279610911, 68.66999364668324, 53.5923203345268, 49.64546280522501, 49.3737563010185, 51.11256261025706, 60.547769146580855, 65.56331173066171, 69.04893382903069, 66.82405564092821, 67.1389356736214, 63.54682906981438, 68.93951539070376, 65.5188242081673, 59.43920535425986, 69.16609502607777, 58.77887433575046, 55.795676477493785, 49.32516205695368, 51.529157546258745, 45.856402227955485, 52.09063306931527, 54.248823119748025, 66.24567078005883, 62.90890262972925, 68.96368503570557, 41.78505259175455, 43.326767644574566, 66.47218765751009, 58.85417992068876, 62.61017099503548, 61.4720796000573, 61.235666582661295, 49.265306688124134, 46.194067308979655, 44.91528834066084, 46.41876420667095, 46.785266553201986, 48.063421864663404, 47.530305077952725, 46.58943437760877, 47.22149295191611, 49.51396142282794, 53.621106609221435, 55.7943703282264, 53.813318437145604, 47.05570220947266, 45.123860374573745, 47.02147560734903, 45.61309760616672, 49.36187544176656, 51.156744187878026, 52.70198152911279, 61.79439252422702, 67.90760255629017, 66.21077737500592, 65.54257415956067, 61.72808485646402, 51.47546814334009, 49.67754387086438, 51.05587651652675, 58.12101441044962, 67.40317006264964, 67.8689750548332, 64.45052354566513, 67.17207185683712, 69.47626036982383, 66.0845947265625, 68.79838066716349, 70.03568449328023, 68.9330199456984, 67.15226388746693, 71.41990461657124, 67.02867000333725, 71.74401006390973, 73.20310823379025, 54.0249381526824, 8.539885340198394, 0.7958963441271937, 1.7614926854448936, 1.3280865934587296, 0.6727114283750135, 0.11540181484193572, 0.20739336167612385, 15.853153351814518, 45.524102949327045, 27.48612665360974, 13.008762290400844, 21.921834676496445, 20.15075314429499, 23.19267868995667, 54.23403186182822, 57.480224640138694, 59.964038095166615, 60.061183437224365, 22.04606398459404, 0.22950799114281134, 0.013086947860316405, 0.10272928798991827, 0.04784284587649088, 0.12442568707610331, 0.0642783391559797, 0.0418546200249224, 0.04269843906043999, 0.024556844990940827, 0.07689172402024269, 0.043392974372592666, 0.00566679738356822, 0.031139892150437644, 0.008647049863582418, 0.07655594768303056, 0.07940658383191594, 0.01898631900398722, 0.054112126404840144, 0.054555181864528894, 0.020376925634580757, 0.03763447147643855, 0.051002866633596926, 0.0559229284314619, 0.03161893459036946, 0.10403899956614741, 0.005520436764439388, 0.016547669619021398, 0.019068412985953114, 0.05890483374617273, 0.03405573387299815, 0.07904822322269602, 0.038730164899701075, 0.15968825457797897, 0.06715827050708956, 0.13047004418988384, 0.3038347302184951, 32.74161042705659, 103.91037940979005, 80.94387438989456, 82.64631640526557, 60.956425205353774, 57.31560276400659, 32.48500308682842, 39.9180357686935, 34.988440159828436, 36.42863642784857, 1.1852596123372356, 0.020431877121389396, 0.05099107654044225, 0.6548186788155187, 2.1052976241034846, 5.504558692055364, 3.663564833902544, 1.8338644600683645, 5.266048187209714, 89.81526374816896, 84.19351885395666, 84.24621197485155, 72.86409777979698, 70.35222761092648, 69.2977297690607, 72.49328474844657, 68.50243783766224, 73.61556114688997, 68.65932479981454, 70.8593116268035, 65.71037707790252, 63.10918277309787, 59.96026477506084, 59.641634956482925, 55.632690229723536, 58.271743251431374, 54.595505729798354, 52.27221919644264, 52.416770304403, 59.29138691194596, 67.02812871625348, 71.11679953913536, 74.43258300904306, 75.68251686711466, 70.88317532693186, 69.10267814513176, 56.99876154622724, 50.816298146401685, 51.36895618131084, 52.39814296845467, 64.71087086585261, 67.69744980719783, 70.80989760737266, 67.28429086746709, 69.36022881538638, 67.6681261677896, 70.97251122997653, 67.56165735183224, 64.03279112231347, 70.83584016369235, 62.35775078496626, 57.94309962180353, 52.12303576930877, 54.90039156329248, 49.184396036209606, 55.674286965400945, 56.284239061417125, 67.80591118720271, 65.52149141988447, 71.7088342482044, 45.497148421502885, 45.122577759527395, 66.66945934295654, 60.523446529142326, 66.17582905677058, 63.36678443416473, 63.960913688905784, 51.28709631581461, 49.18019517775505, 47.5644689221536, 48.97101125409527, 49.32628777719314, 49.56587791442872, 49.036334406945016, 48.58324181648993, 49.938275583328746, 53.378268749483176, 57.10489303834977, 58.95975835861699, 55.13629859493625, 50.89389831789079, 47.20546222502186, 51.44842732337214, 48.42082431239467, 51.342119324591856, 51.96957695868708, 55.40849931778447, 63.507295500847604, 69.89921739024501, 68.04877650353217, 69.09834000372118, 64.43013114313926, 54.88037570830315, 52.256827815886474, 53.45672399766984, 62.07695222670033, 69.4537930334768, 70.03811636278706, 69.48853738846319, 68.45422406350413, 72.94123511160575, 68.59179727492794, 72.16973627767256, 70.13750922295355, 72.919889573128, 71.56051374250843, 73.83232701209285, 67.7581916316863, 76.60589771886026, 73.63594962704566, 57.964951146033506, 11.558567900811473, 0.11790623287520102, 2.3594802041207594, 2.441575411827334, 1.7219532329228617, 0.10303530947215135, 0.41081627350180383, 9.352103279482934, 56.934199333190925, 32.806964958867724, 17.959587727823568, 14.840145361038948, 23.31113426916061, 38.86842127769224, 67.17968909971177, 65.36118415094191, 65.24714908292218, 70.04340371777936, 41.57887320364676, 0.364872693654991, 0.03602011354580041, 0.06138794687426379, 0.06394365066362005, 0.024425734788359656, 0.032039463234644745, 0.06743755552076525, 0.0016229102250015846, 0.04926254469600897, 0.0194369510732471, 0.06360497851405414, 0.08673281288675724, 0.05437574875090392, 0.04894389425434413, 0.04349754154381733, 0.0869934972856314, 0.02843091331963097, 0.05037772739606519, 0.04422957685986354, 0.11921236682082377, 0.28276250126861757, 0.13493094352945206, 0.13590150032072298, 0.15773040963517082, 0.25782955690257015, 0.09871582996340529, 0.07957082542200243, 0.1538148270018639, 0.11621326283221284, 0.1110158542231206, 0.2936301326319095, 0.13328003937438612, 0.3130565902158138, 0.23685350263070679, 0.21916471632017245, 0.5198868772675914, 39.852136027428415, 116.39806855109431, 89.99850903787922, 96.56569419368621, 68.11686100498324, 57.96368422046785, 39.20333677722562, 52.23858487221503, 50.920488065288914, 44.0826044544097, 2.5285125403634967, 0.16751103884270116, 0.6034830044354162, 2.0285533873304247, 6.214246365331835, 3.6746830373041095, 3.217187096034327, 5.11932114439626, 4.769556041686766, 94.56307318902786, 86.3597732974637, 89.0520489600397, 76.27651276126986, 72.84259534651234, 72.87661014064666, 75.54007207193683, 71.36843527517011, 77.68841697323707, 71.25726745974633, 74.1743576911188, 67.34472674708213, 64.65065856133738, 65.01160290933424, 62.99013883836808, 59.56093219018752, 61.26373506361439, 57.236049252171675, 57.10721900386196, 53.66699441786736, 63.25645600595782, 70.55982297466647, 78.26020440747662, 79.55413156940092, 78.73025340418663, 75.34812696518438, 73.5189296353248, 59.36583742018669, 53.215890469089636, 54.85430371376776, 55.10864588522143, 67.73657937203684, 69.16336505643784, 73.80754547734415, 71.5521590940414, 71.75315703115156, 68.34802981345885, 74.27899083783551, 70.40192404100972, 63.482298235739435, 74.54673967053814, 64.67982138356855, 60.0952531445411, 55.90841324098649, 58.02486142804546, 51.10710659334737, 58.665917919528106, 59.9838186079456, 71.54589899124639, 68.44396314313336, 72.3446112294351, 49.266550079468765, 49.096256456067486, 70.0582459665114, 64.59907939357143, 67.94866977199432, 66.18861598353233, 66.97966391040434, 55.38886785507203, 52.76086807250977, 50.11712389607584, 51.76699046165713, 51.94279109278033, 53.467679177561116, 52.713050457739065, 51.405963743886645, 52.61845857866349, 56.4764508893413, 60.988714156612275, 61.937009903692434, 58.68506300833918, 53.379943601546756, 49.90744575377434, 54.3989126143917, 50.8602326147018, 55.0410948261138, 56.486609828087595, 58.95599288325156, 65.11551433993925, 73.9421219979563, 71.06351021797427, 72.36626271278628, 67.62887893184539, 58.4246450854886, 55.109202861785896, 57.85173977574995, 64.40995447097286, 72.99702690493676, 73.32693746013027, 74.74236396051224, 72.16511572560957, 74.92504442891767, 72.51487347387499, 75.05774605658748, 75.30195282351586, 75.85636415789205, 75.9169412428333, 79.57743829296481, 70.80190381696148, 79.55081324423514, 76.8159092626264, 59.99544451313635, 11.26928525586282, 2.5273265136826426, 7.081398079472204, 6.164073367272654, 1.816049054745705, 0.2531747913528835, 0.4088626573643377, 20.48471550787649, 61.652202683110396, 43.47340937583677, 23.261335857452888, 32.62612996562835, 29.926992116435883, 38.08143692631876, 70.23632157233455, 74.3192735795052, 75.50175836009365, 83.01809433967837, 49.72570273184007, 0.8216329760128452, 0.12194723176259188, 0.3228204727413193, 0.16895647821647508, 0.16871562017308128, 0.24307067385844647, 0.2193996601647908, 0.09647078631866364, 0.16271948063325498, 0.13030400229317526, 0.14304425897857836, 0.2177434853248058, 0.15717930130420193, 0.18045505959420435, 0.18446980464843013, 0.15158526599407196, 0.11098005493441898, 0.14166418222650407, 0.10707867557122823], [0.029392012755476662, 0.05641072725636825, 0.04023481137870301, 0.02686228509241295, 0.08233605042820977, 0.031715423364432595, 0.029033060343335235, 0.04425452451311773, 0.03169497264729392, 0.04137843126250852, 0.06576080355913409, 0.028032407787958943, 0.0401451446176056, 0.06580944248144666, 0.08560119377028558, 0.027900479786518603, 1.3099372963751517, 56.34697344995315, 78.28200494089435, 74.6103605147331, 60.422704373636556, 39.04429643384872, 12.527740463133782, 36.24850550005513, 49.17268776124524, 49.22776960557508, 19.089340163815407, 0.06782100550950536, 0.05236567959429757, 0.09838481103220294, 0.21206087492887052, 0.5536729481912429, 2.0350270141516966, 4.979254776431668, 0.5469650823262431, 29.4623520681935, 92.89633258696526, 71.7883877600393, 79.73496852382537, 66.48873221489691, 71.03102514820715, 68.20325513039866, 74.31831652118315, 70.5558535360521, 72.88235249057894, 68.33054388723066, 70.52102288892193, 65.62187663970455, 64.63904834562733, 57.92776707679995, 57.503315633343114, 54.702154974783625, 51.745409580969046, 50.70580105627737, 50.80051845119846, 51.6814749471603, 61.43487199660271, 67.85413280610116, 68.06178308302357, 70.37217678562288, 67.98848967398366, 68.91154889137515, 62.378931583896765, 48.33531272026801, 50.59579034005442, 49.03744443770378, 51.85106646630072, 61.46822391017791, 67.24311382539811, 62.40818069827173, 66.51222721222909, 65.87616782034597, 67.49535360643941, 60.49476223607218, 63.05333214421427, 63.97061763271209, 62.654968384773504, 57.12362235592258, 52.2761494113553, 47.917301808634114, 50.24444795423939, 47.851304008114724, 54.05352046412807, 54.78227723029352, 62.583420430460286, 60.847281332938906, 66.2831921731272, 43.706617816801995, 43.015684466208185, 67.70122312730359, 59.37114438702984, 64.4407803781571, 56.585159378667036, 47.26396045377178, 41.93595401702389, 45.83195017230126, 49.35257942445817, 52.681616583178126, 49.58379922374603, 47.351150820332194, 48.42452310746717, 47.54665351683094, 45.80155180346581, 49.20480412821616, 54.210917334402765, 56.68781957318706, 57.87981610144339, 53.270838952833614, 47.95372886042441, 45.59397605157668, 48.093690795283166, 46.656334323267785, 49.10007684461532, 49.17902238907353, 58.431175831825506, 67.22554160702613, 63.927624533253336, 66.79108419725972, 60.20980988779376, 50.289115905761726, 50.89936610191099, 49.84984967016405, 56.629391947100245, 64.93385368777861, 68.55557026401644, 63.308419566000666, 68.44416710638231, 66.37719569667694, 65.63265139056791, 66.47088543061288, 69.43625219406621, 66.89139489204653, 65.92415409703409, 66.24247012599822, 70.06295281071817, 68.18315690563571, 69.59762634769564, 68.49842917534613, 27.582081556320194, 0.347204806223031, 0.998441533696267, 1.885476967980785, 0.8081525251750024, 0.233490361321357, 0.14769717059548826, 0.26262299968831004, 43.31856204617409, 45.61282696262483, 28.878142487618234, 23.77032614523365, 22.806786106478786, 17.776071794571415, 26.021676409629087, 46.40161952664776, 62.9935081543461, 55.19218060278124, 56.49157554872575, 6.735120454142171, 0.3022389384287019, 0.1259528603705187, 0.036818166488721486, 0.08222368065147631, 0.03049249231304613, 0.029769640475992235, 0.05991954401495957, 0.08032560588852053, 0.05205957767283244, 0.07133603141072296, 0.04413488073154323, 0.03772790355968379, 0.02619268785741541, 0.01772936407266365, 0.09070025967253793, 0.08496207725857535, 0.058603650109181483, 0.02017675452084551, 0.0644172768619272, 0.015597444801260869, 0.017063794544928016, 0.06145101123219056, 0.03065743487358334, 0.09168561728250596, 0.039361068948863015, 0.04933520047474773, 0.04882019403721056, 0.06882948365302817, 0.041477459618040634, 0.04193880542692158, 0.036031915130273956, 0.04389155588503327, 0.06227906417822646, 0.05012492604193188, 1.891980012578349, 72.09736854799333, 86.41500811423026, 81.27694637544694, 70.97692781879057, 50.51805680797946, 20.597750371502293, 34.68877107866349, 46.0010160938386, 56.29681418018957, 25.221273629896103, 0.025135302660806526, 0.0938112278198523, 0.43214339522584794, 1.6252191268628644, 1.5593105602648951, 7.596697989971408, 5.584047975078707, 0.7389026507735253, 33.315321783865656, 93.87778805148218, 78.86766972080355, 80.2562044512841, 69.72282840359595, 74.17351045916158, 72.11665091976043, 77.76964925950574, 75.33584210180467, 75.02896370426302, 72.13180695810627, 73.37544148968112, 68.75711733295073, 67.68047378909203, 62.38378747817009, 59.553726796180975, 55.6742791206606, 54.84455662388956, 54.4919002440668, 52.92968296235608, 55.861999834737475, 64.2902986464962, 71.1503593383297, 71.07349657243299, 71.43573530258672, 69.11762237548828, 71.0926926520563, 64.31739830201673, 51.1503860258287, 53.531201962501775, 51.62176470602713, 55.717287909600046, 64.49570140530987, 71.13679578227382, 64.6390522679975, 68.42571627709174, 67.44644165039062, 68.40478650985226, 60.99424077618507, 65.52892431136101, 63.83227563673451, 64.3959241528665, 58.353532514264515, 55.422502179299634, 49.68724781467069, 52.459802627563484, 50.85696528034826, 56.31709283398044, 59.26349101528045, 64.45691700904601, 62.56611493326003, 66.8315944363994, 46.880697819494436, 48.622845988119806, 70.24233064343854, 61.89834317853374, 67.61035749989172, 60.41915070626044, 49.14057139427432, 45.354452594634026, 49.01347091121059, 51.77027740786153, 56.736825666119984, 52.80740307223413, 48.94101688938756, 49.58280294172226, 48.49343915139475, 47.27041667507541, 52.7630175313642, 57.45621973468412, 58.90832824091758, 62.511790106373454, 56.57700084870862, 49.69926987924884, 47.9306221777393, 49.916212251109464, 50.812768013246604, 52.19059075078657, 51.565933688994384, 58.978836767135135, 68.54937291914418, 69.14474164285969, 69.91977060994795, 62.03499071059689, 52.161553444400916, 52.070134762794744, 52.009549833113155, 59.62718886713828, 68.15550419592088, 70.53577884551018, 67.28832306400423, 71.95426479462655, 69.2454210404427, 67.25138218172135, 69.23209282659715, 71.94932260820943, 69.76609999133696, 71.20962635163339, 67.48549276782622, 73.10734748840332, 71.6439268665929, 74.97403483236991, 71.45904987089096, 31.58529373907274, 1.6154057244139335, 1.2708937785317822, 4.2519610543404855, 2.285354026863652, 0.9518214062817636, 0.13086957436415458, 0.21635714197351089, 43.07096242904664, 56.18981976662913, 25.137546716197846, 18.87276061119572, 14.709358830605785, 24.982385596921368, 37.44846443976126, 53.717204678443174, 71.1788357457807, 62.010209175848196, 70.43803338081607, 13.173441040900446, 0.6108772850805714, 0.1909748104310805, 0.06659649057133545, 0.08890374518570401, 0.13041280210018158, 0.07527104969466887, 0.03616597285614379, 0.04043164617952801, 0.027903544138215726, 0.06723906213958418, 0.018018629296772906, 0.06383453676056478, 0.042052450740048965, 0.0042399614974255526, 0.09556138632638801, 0.02725385944359005, 0.11175065511657346, 0.005179814921106182, 0.12835593263228096, 0.1396125528000055, 0.15475518460715973, 0.12791068233068914, 0.14851135351965505, 0.2668607222937769, 0.16653822975293284, 0.17892793992594366, 0.15116056217060936, 0.20284837652598658, 0.2854532472068264, 0.2691356969937202, 0.09341799488831913, 0.1883238857431758, 0.24042051525846606, 0.1629653029263981, 2.087757520137295, 87.5248819781888, 95.71693251209875, 96.30360141877206, 78.00510129620953, 56.37606174715104, 17.736993220544633, 48.91515278047132, 71.02427082677042, 71.1300963740195, 31.71871316048407, 0.08454937803288622, 0.4585640823408481, 1.0307781662671798, 2.61652635951196, 3.9410965481112084, 9.623546984887893, 17.527817141625192, 1.6151394935384875, 35.558497828821984, 97.26742975173458, 81.7027275023922, 84.6145539129934, 72.79079652601673, 78.84858346754505, 76.03829937596475, 80.73771461363762, 77.56435240468672, 78.78039698446952, 72.82883567194786, 76.46823821529266, 70.81438479884979, 71.49798331722137, 65.22021808931905, 63.045028486559474, 60.5872634918459, 56.8413999772841, 56.414814764453524, 54.72293176958638, 59.768515786817005, 67.7807923286192, 74.52428017893146, 73.992124372913, 72.58327176493984, 72.58542906853461, 75.06748922409551, 67.0584721719065, 54.56130658426593, 54.88034825171194, 53.62718236061835, 56.567779356433505, 65.82609484272619, 72.37662561478155, 66.49412155151367, 70.84931742760443, 70.27565510042253, 72.17253684997559, 64.21150215210454, 68.6058158259238, 67.60243431214364, 69.39181958475422, 61.35434573696506, 58.65993630501532, 52.00399967931932, 57.26105436202019, 53.155631096132346, 60.13414736716979, 61.164620691730136, 68.57248352419946, 64.69292994468444, 68.72256909647297, 47.5806212425232, 51.33745562645697, 73.85127206002512, 64.52820216455768, 71.95556702152376, 63.49564606143583, 51.70606036340037, 48.51341578268236, 51.1264987914793, 55.14339416257797, 59.744934497341035, 54.802599030156294, 52.60405563539075, 53.27967605283184, 51.72487597311697, 51.43210634108513, 56.4528892117162, 61.23685113845333, 62.04519671778526, 66.34593440640357, 58.62609409516858, 53.95892074031215, 51.170401880818034, 53.74306486498926, 52.82688940725019, 53.960913304359686, 54.22221376049904, 63.500235234537435, 73.29714313630136, 70.57143319037654, 73.59656118577527, 67.1354918326101, 56.5170278087739, 56.16358303254651, 54.331706723859234, 63.10315409014302, 70.81925638260381, 74.4500454010502, 70.5263259333949, 75.39280276144706, 71.97322553203952, 71.40906318541496, 72.87773978325629, 72.9972779366278, 71.94758892059326, 74.3072868162586, 71.27936609329717, 80.60458152524888, 73.81185223979335, 76.98118225220712, 73.78004966243621, 35.11280675088206, 1.9022528226337128, 4.410195840943245, 8.101103027020732, 2.795306766225446, 0.7442301487730396, 0.315070788586332, 0.35080397922185164, 53.428616293015025, 64.44914287136447, 45.53440309339955, 35.03355918392059, 35.680675737319454, 26.13202052731668, 41.40508082605178, 61.62407928897489, 83.8077929712111, 71.3075993137975, 87.25205759848319, 15.232457883896368, 0.9661164843747694, 0.3209593693815893, 0.2169486691033648, 0.24089680744274972, 0.43935200680167447, 0.11830980799371198, 0.09510738730070092, 0.12889271511906578, 0.13434313958691013, 0.13723435541314466, 0.10926056292749221, 0.09262365364139119, 0.25389057794405573, 0.06904110012035217, 0.280384594995168, 0.14814859556574977, 0.15860823914408684, 0.19238281874887406], [0.061295273218063585, 0.05357130280425472, 0.0445427191293528, 0.037715289922010516, 0.06945861037820578, 0.09015871977974331, 0.0488626544604138, 0.05892913788557053, 0.06613308398593819, 0.053585812509540594, 0.08958173299869222, 0.044606066939811555, 0.14744845248999136, 0.06966796688615315, 0.08880353322432888, 0.1672120347258545, 18.980196291400542, 83.5888776471538, 73.3409167874244, 73.8518996392527, 56.601566653097834, 39.43234435973629, 32.50246351765048, 50.025960168530865, 51.03275806673112, 28.946221105514038, 6.884035689215507, 0.07412253833946682, 0.18206203626769205, 0.2628281886779493, 0.06330463374333997, 1.8421797622596066, 15.08267237294105, 5.6116496939812945, 0.8339201682998288, 73.71806836897328, 80.78220213613203, 81.02134904553814, 73.46792313360399, 73.81622960490566, 70.40685053794616, 72.6925568426809, 71.79456157069053, 71.66314648043725, 71.53200595609604, 74.29214646739345, 69.77670608028289, 67.36416601365613, 66.80043512775053, 62.3453325610007, 58.76424389500772, 56.79501010525612, 50.36487648564, 51.833749201989946, 49.27710125523229, 56.20562691842356, 65.826432166561, 71.00317631998371, 70.39424404021233, 65.75084024860014, 67.7466598633797, 66.24723972812777, 55.20437525164697, 48.78306696491857, 49.95201564604237, 48.11400082803542, 52.468031760185, 65.5468338535678, 62.57945883658625, 63.60122057699389, 66.13741336330291, 67.18235631142893, 62.080184259722316, 59.51762922348515, 63.45735980618385, 60.42873697896158, 60.31299960228705, 54.1486144065857, 50.38657503743326, 50.11845357956425, 51.74900247204689, 48.45072454021823, 52.99487275461997, 57.99443560261881, 64.60366856667304, 62.0489308141893, 64.20954881175872, 50.44468495153612, 48.43256004395024, 65.02397798722791, 58.797831150793264, 60.038527827109064, 50.62723598172588, 46.385294621990575, 44.541647280416186, 47.576353703775716, 53.14126737656132, 58.2937869717998, 58.83586637435421, 52.489043897198094, 44.8584218179026, 46.22796443200881, 44.68408815322384, 48.626360431794204, 55.50367955238589, 56.766031634423044, 58.278172016143806, 58.90853612653671, 51.953412871206964, 46.04963387212446, 45.86172880664949, 48.96119748392413, 47.98580600369362, 48.64077514217746, 50.597276918349735, 64.0300101618613, 64.2065207419857, 64.84560035890149, 58.58925911688036, 48.60178678266464, 50.11436254747453, 47.44753914494669, 54.5078250669664, 64.60902260195824, 65.86299650130734, 64.98655073104366, 66.29815209296443, 67.7313155512656, 63.791581046196725, 65.54668088113108, 67.12545056496897, 69.24900608678018, 66.41521915312737, 69.59423741986676, 66.57655408305507, 71.20000869997087, 70.86540699005127, 69.42119813734486, 48.476992653262236, 3.620035105174588, 0.27510618790984154, 2.038614266822415, 1.300403362800998, 0.754112376561088, 0.12605644311876069, 0.1951293971750044, 8.407599483766864, 62.43707679933118, 37.688764525998025, 35.954013947517645, 33.959810349249075, 21.933278191474177, 24.713973883659612, 45.13962045792611, 60.175500915896514, 65.51935765051073, 53.72014645607241, 30.801043279709358, 0.7478527027753092, 0.05941948395282511, 0.008461737982748498, 0.03589902568848864, 0.10044013300249655, 0.05222102304199531, 0.11442865335172224, 0.02359589302702056, 0.11414435812302175, 0.016095103177752708, 0.06030850217587525, 0.054218053382130406, 0.02714242620934402, 0.042112665250897414, 0.045609328024570024, 0.07190330419689417, 0.07474393523748844, 0.01532771003117124, 0.13629824193494935, 0.029300327352698774, 0.046632963217674725, 0.07029140157805336, 0.05478208178594228, 0.01981956602614974, 0.02015661981497561, 0.015635419779667453, 0.03786810531070636, 0.0474680794943725, 0.07427801588369955, 0.021398662844853058, 0.056214555121597745, 0.018173336922641725, 0.21820984900959078, 0.21499696818570938, 24.0572710575596, 98.67184223667269, 79.89376960262176, 83.24007695721042, 65.05079130972585, 51.237611693720666, 36.85140125213131, 51.309940199698175, 48.06940740154636, 43.363547709680375, 8.94573200133539, 0.197411511814402, 0.1741902683410914, 0.8989402567667346, 2.002009605207751, 2.552367905455251, 10.273139534458037, 2.0017725469604617, 2.110780607308111, 75.60583453024589, 84.77482980297458, 83.27941048529841, 77.64258800014373, 75.38678584560272, 74.3409485970774, 74.44607596243583, 74.85586950855871, 73.80203062488188, 73.16160955736714, 76.40312687043222, 74.39069994034307, 71.10549526829874, 69.54709837513586, 64.73785285026797, 62.57934508785125, 59.202776647383175, 53.863607145124874, 54.41503747817009, 51.65018620029573, 58.45631037988971, 70.2979184735206, 73.61050128936768, 72.92797750042331, 67.49088210444297, 70.36058225939351, 67.833665878542, 57.568383832131666, 51.219925726613695, 51.81259193728047, 49.48423770166213, 53.84672134153305, 69.42481456264373, 65.34021123763054, 63.26795247293288, 68.39261147283739, 66.86302046622, 66.3072519917642, 63.1841157328698, 65.7162017976084, 64.03783921272525, 62.782241452124815, 55.7890006034605, 53.26195086202314, 53.68939507392145, 54.08588001804968, 51.212508524617846, 57.52020535930511, 59.49230247928251, 67.93734196693667, 63.52919017114947, 66.14672507009199, 52.43370709880706, 51.014919127187426, 69.79047359958773, 62.03981914827901, 63.12621370438607, 53.299331049765314, 49.521798318432225, 47.05352137165685, 51.08785952291181, 57.54933288020473, 62.78356721324306, 61.716404038090865, 54.6438136408406, 46.518627751258116, 48.29127234797324, 48.22345064532373, 50.79937311910814, 56.158950713373, 60.26911220242901, 60.52037923566757, 60.53739447747508, 55.45592077316777, 48.821667009784335, 49.384876220457016, 50.71687390727382, 50.57667663020473, 50.86931290165071, 54.279770620407604, 66.79412795651344, 66.89832964251119, 68.0330321096605, 61.384748028170684, 51.09932068855532, 51.94414038811961, 49.5135848752914, 57.36333800900368, 66.6759547879619, 68.22385541854366, 66.89738827366983, 68.90002496780889, 69.15381800743842, 66.42487602849161, 70.37606777683382, 71.98254508356895, 69.94931390208583, 69.74014959027691, 71.42260320724981, 73.61589062598445, 72.31250270720452, 74.26359161253899, 70.18045133160007, 53.95770088318856, 5.592234451924601, 0.5217326588688359, 3.1205053291013165, 3.9993586992063834, 1.98677891925458, 0.13218897695262588, 0.19354463705132086, 7.272530275006448, 72.29704856872559, 41.717030848226244, 34.68620977094097, 26.88648254640641, 20.01766320197813, 31.965463584469212, 54.899030500842684, 67.93996211021178, 73.7501847359442, 63.420007075032885, 51.78581391611407, 1.8398466874514858, 0.11243509338988412, 0.039420927228826674, 0.016694618689437068, 0.024512971135517283, 0.10359410932588001, 0.06463700620036933, 0.017211450331453836, 0.059099243878717386, 0.029852157721536297, 0.014029232176741766, 0.04168719533951052, 0.012218810321252433, 0.014825268393202175, 0.03146570934463413, 0.057458804484697125, 0.04583910460613909, 0.05350544222540433, 0.24310424383128845, 0.20484089460824767, 0.10735112708061935, 0.11245347950006686, 0.23296484032705908, 0.169853046236019, 0.13645239414707308, 0.2310861475885876, 0.2594680044679873, 0.19584072513445733, 0.15732093563964292, 0.11489074226588973, 0.39789957144568044, 0.22913979396464365, 0.452402682313996, 0.5024682442026754, 30.516375303268436, 111.55940132756388, 91.39859122614708, 95.1502598485639, 75.92808077412268, 53.33132190089072, 44.39553506912724, 69.01076916725405, 73.2875019504178, 50.12491372323806, 11.292388016177762, 0.2681262076141373, 0.6747991711862626, 0.9585270045265075, 3.209372508910395, 5.400079988664197, 30.163538494417747, 16.283066695736302, 1.5479024691927818, 82.89893273384341, 85.35895701377623, 89.83287519024265, 80.21032056500836, 81.43133871016964, 76.15514678339805, 78.85702440815588, 78.28627247964182, 79.50975387327134, 75.27273116573211, 81.95491237025108, 74.79262521190029, 73.88773441314697, 72.64692398809618, 66.9195967335855, 65.53702008339667, 63.78237132103213, 55.91945079065139, 58.074146009260616, 54.51556782568655, 60.8545651743489, 72.26968611440351, 77.11754737361785, 75.87826667293426, 69.22378524657219, 73.89366503684752, 73.5848960568828, 60.29241108125257, 54.921046764619895, 53.405282112859915, 53.457712434953265, 56.31652409030546, 71.89615880289386, 66.91209716181602, 65.90966486161756, 71.4384574274863, 71.3653209132533, 69.13500632009199, 67.12956120890956, 70.80415525744039, 67.11555050265405, 65.27353486707135, 60.433687010119044, 56.80835793095251, 56.73528025227209, 57.696480597219164, 54.29484428897981, 58.68002668503792, 63.17785955244496, 68.78751570178618, 68.80505654119676, 67.1852667100968, 56.4017415046692, 54.89135442241546, 72.83370725570187, 64.8395481417256, 66.21421337127686, 56.975831370199884, 51.00537600055818, 50.27583476035826, 53.833926570030954, 60.7377177669156, 66.0144470584008, 65.99732983496882, 58.681195551349276, 49.0559031117347, 50.34887321533696, 50.39223501759191, 54.10396214454405, 58.95050156501032, 63.44590256291052, 64.45530491490518, 65.1180285792197, 59.59542943585304, 51.74355037750737, 51.71933758643366, 55.33742204789193, 52.86576401802802, 53.89765331822058, 56.59205098305979, 71.29966043656873, 71.56912726740684, 69.33726726039764, 64.63920131806405, 54.353754366597826, 55.51098692801691, 51.41849179421702, 60.371113438760084, 70.13579122481808, 72.56380896414481, 69.59019737858927, 71.23804784590199, 74.85582244011664, 68.43231370372158, 72.78743897714924, 74.40933904340191, 73.7321339884112, 73.36736140712615, 76.40886137562414, 74.91277525501867, 78.89916635328724, 77.41767929446313, 71.55210418085899, 56.815500567036295, 6.42458297552601, 4.3785310368384085, 9.676026336608395, 7.079583983267508, 1.7683592847278042, 0.2934659446679777, 0.26172722840020735, 11.324238642569512, 79.6158932101342, 55.05182250853508, 51.75030862131427, 48.03329806174002, 33.651951359164336, 35.10948842571628, 62.105091310316524, 76.26665192265665, 84.80836606794789, 70.99868128376623, 61.9849883356402, 1.9591050042260079, 0.1713325612006649, 0.12346222425901121, 0.11760899076058019, 0.15804277432541694, 0.13515856357351427, 0.198162155406129, 0.1515411546513919, 0.20294327949804647, 0.19411053087922836, 0.1845649221251088, 0.15202428033996015, 0.1710624385985636, 0.12137866428782865, 0.07960132338226804, 0.12809090451487612, 0.2791630831216612, 0.21232113031850708], [0.10444835864848669, 0.028984147544589736, 0.06797932523993716, 0.03467290962655698, 0.0853572024272815, 0.01333597144337311, 0.04660362971105403, 0.0850378433542867, 0.010754898652404307, 0.05939621403212509, 0.049476539866337856, 0.054806393586219325, 0.016404189011682908, 0.01096565901647292, 0.119760709574386, 0.16407904155071706, 49.48119002003824, 78.54174429370512, 66.507763554973, 68.59103633511451, 44.01506516241258, 19.306600247659993, 24.43658386507342, 46.33607279869818, 38.40325563184677, 36.74221815601472, 3.4351345752516105, 0.04444587795484451, 0.3108026676120297, 0.3598475552374317, 1.3874120745928058, 1.4218057451709625, 7.105406417000679, 1.100081176527085, 24.797124208942538, 88.65273598701724, 74.0074529955464, 78.70612298288654, 70.52161908918812, 72.36884363235967, 71.20484106002316, 72.11024176689887, 67.95966025321715, 71.07093134234029, 68.19999171841529, 68.77669780485093, 68.59080883764452, 67.16128533886325, 64.91616379830145, 63.30299100568218, 56.82039568501135, 57.5304505901952, 52.56181955337525, 49.71015837884719, 48.698312390235166, 55.07718063169911, 68.54752156042284, 68.96385761999315, 65.3997802734375, 65.66323018843129, 65.77281336630544, 58.706188894087276, 50.17010334999331, 49.62892217020835, 49.24171363153766, 46.562664201182706, 56.98686499749461, 65.08167605246267, 65.58782262186851, 64.5231266175547, 65.05758093249413, 60.902939765684074, 63.16873219705398, 63.17429019558815, 62.41397403901624, 62.01485718450239, 57.36380477105418, 53.45948534627115, 55.09822022530341, 60.099501071437714, 61.62293787925475, 56.89497170909759, 51.955213239116055, 59.82156584339758, 62.722731251870435, 62.10913135159401, 67.0330395237092, 47.4065621437565, 48.69509212432369, 68.56882787519886, 55.446208984621116, 55.88246283992645, 44.912511302578835, 45.289380473475305, 44.92603563493298, 50.99002384370374, 53.9409052941107, 64.56637859344482, 61.884183422211684, 59.31329334935835, 47.62150410682925, 45.87985407921576, 43.25421948586741, 46.75919063629643, 52.73436461725543, 58.35787457804526, 56.42933930120161, 61.048899004536295, 57.11811142583048, 48.55285913713517, 45.18941494726366, 47.83389260691982, 46.35363324995964, 50.202066744527514, 45.64302921295167, 58.940703484319876, 61.097889407988525, 62.40721579520934, 54.539827685202326, 49.65738681054885, 48.05965246692781, 48.82928817502914, 50.15599458448349, 59.73042957244381, 64.8348726764802, 66.73867348701724, 65.89793697480233, 66.14346950284897, 68.09670786703786, 67.34657810580346, 66.81115888780164, 67.10437959240329, 65.52038923386606, 68.36756321691698, 69.58652604010798, 69.58472959456905, 68.1695305916571, 66.66779625800349, 63.226175308227546, 13.320341648594027, 1.0624593952971122, 1.7744968134549357, 2.4633734937637084, 0.5000673246479804, 0.619271953980769, 0.12908898684526646, 0.141160647955633, 37.95776067241546, 56.14880354173722, 30.894687906388317, 39.42764143789969, 33.61119008833362, 21.800882508677823, 26.019685806766635, 40.517664186416134, 56.85615593387235, 57.220540200510335, 55.214514578542406, 20.454040611943892, 0.11502326015503177, 0.04025522379144546, 0.01743352389894426, 0.061272983889906645, 0.03662497443597644, 0.039863664762026844, 0.0458600647717474, 0.01581152328365152, 0.021743013621157697, 0.0365715091597409, 0.08597280770059555, 0.05526386682064303, 0.0653241640858112, 0.025985771339506875, 0.172774629787572, 0.04469010678510513, 0.07557275810188825, 0.05352121214532564, 0.03210430874699547, 0.06293270571698105, 0.03993850389134981, 0.04476321455571921, 0.013115465483297745, 0.0499659666280833, 0.056280787253091415, 0.07213529094212479, 0.029607961450012463, 0.0582446153425882, 0.07439895818430571, 0.0057196205823622165, 0.06598451655478248, 0.08195321330980909, 0.20748022072497876, 64.48719770677629, 89.34841540551956, 75.32445153882428, 75.61273790174916, 51.953432483057824, 27.245840295668575, 25.691246140387754, 34.31620082547588, 39.60470507221837, 43.31642043206, 2.4382070764418575, 0.11191635227371609, 0.6041939953161825, 1.9149994225271287, 3.141436812377745, 3.0851510455531463, 4.127408150703677, 0.8679766376172343, 28.083231026126494, 92.55375277611518, 77.30615846572384, 81.9253533886325, 72.90780082825692, 75.8363365357922, 71.67418403010215, 73.7396727838824, 70.1503824418591, 73.46567953786543, 70.3316665464832, 72.50929586348995, 70.94690599749165, 70.60814657518941, 68.71441841125488, 67.53789563332835, 59.814176097992934, 59.70263173503261, 55.12941875765401, 53.07924685939666, 51.218235185069425, 58.61606459463797, 71.76257071956512, 70.84007632347846, 69.958923709008, 69.48351675464262, 69.66503620147705, 62.6873161715846, 52.61561486028856, 51.46634078794911, 51.19918031077231, 49.00671266740369, 58.58936109850484, 68.12013226170694, 68.54789026321905, 66.6938643301687, 68.73650920006537, 63.953994627921816, 65.74753761291504, 66.27053860695132, 64.96045127991708, 67.57927663864629, 61.57073897700156, 55.40842087038102, 59.63407654916087, 65.9644054597424, 66.21415061335411, 59.71464987724059, 54.10310314547632, 63.31069454070061, 67.78456564872496, 65.0767848568578, 67.47028966103831, 48.6379784922446, 50.807774836017245, 68.80082038141066, 57.482687888606904, 57.54051146968719, 46.66421436494397, 48.33531272026801, 46.911457046385735, 54.681064390367084, 56.550948466024096, 66.46017736004245, 64.96615048377745, 61.63764676740093, 48.789291766382036, 47.63494606940977, 46.5092650536568, 47.88516190744216, 54.719754649746804, 62.89092640722952, 59.91161954018378, 63.62478617698916, 58.05848790753273, 49.945712397175456, 47.114055310526204, 49.29919988878312, 47.80246265472905, 52.379786276048236, 50.04140253989927, 61.745547248471176, 63.79736261983072, 65.57174482653218, 57.11161205845495, 52.06361186119818, 50.35752988630726, 50.312085305490804, 53.758530770578695, 62.17564298260597, 67.6494792199904, 68.35648644355037, 69.99524485680365, 68.59485672366235, 70.04465103149414, 70.38938030119866, 68.79715688766973, 69.42342604360273, 69.4123649597168, 69.48747050377631, 72.33860215833111, 71.71591804873559, 71.14163598706646, 67.22807545815745, 66.15051407967844, 16.08629511248681, 0.8575086283587641, 0.38365214402156494, 3.168923066508386, 1.8448326328108389, 0.9129862643537984, 0.044310935397422126, 0.2201361158081601, 39.30425543938914, 66.24460389537197, 34.46032831745763, 44.01775590835079, 28.368557960756366, 32.74024151986645, 40.3311280281313, 48.7453612204521, 62.639094552686146, 63.61685514450074, 70.63989423936414, 35.079207727986, 0.3075279175273834, 0.04811149375933794, 0.0317108076846888, 0.06311298535776234, 0.03428972393815075, 0.04534551032608555, 0.10033559264434923, 0.05386072316116864, 0.027725430611040325, 0.021059523381653334, 0.038841308935755686, 0.10240925475955011, 0.04014794083852922, 0.05023996180464184, 0.09074307632662597, 0.017199535749011466, 0.04561821464449168, 0.13413474834974737, 0.12324070227482628, 0.1338537166556043, 0.1268291117383107, 0.19421416725362503, 0.13039441598999885, 0.12843022017829842, 0.14575447887182236, 0.33816316074902014, 0.1522989075390562, 0.1606351852176651, 0.11952903692520435, 0.1141256119515146, 0.2329444777100317, 0.22335337865496838, 0.37747422713906537, 75.81238654352005, 98.01266439499395, 86.05724088607296, 87.23250850554436, 58.90828509484568, 31.089102145164247, 34.95746520257766, 62.82505412255565, 57.56173541468959, 54.58268350170505, 5.435589696130445, 0.16174765213602976, 1.5870483363828354, 1.5568941350906127, 5.160786480672899, 3.1472688865277076, 21.192248329039543, 4.288136093847213, 30.26483762648798, 95.54936101359706, 81.43766941562777, 84.75319400910409, 76.57332635694935, 77.67606935193463, 75.99675363109958, 77.11139709718766, 75.43303058993432, 78.06487821763562, 74.12812863626789, 75.05167422756072, 74.85837982546899, 72.94943286526588, 70.96277590720885, 69.93742127572337, 63.49177468207575, 63.32565053816765, 58.02548900727303, 54.2592409349257, 53.80121792516401, 61.75019525712537, 74.82123497993716, 75.7015246729697, 69.99404461153092, 70.67558780793222, 73.47848215410787, 63.78658002422702, 55.79368783581642, 53.94650643871677, 53.93185638612317, 51.28874371128698, 61.39958243216238, 70.27108161680161, 70.49734746256183, 69.95881388264318, 71.83503258612849, 65.7686125078509, 68.39274483342325, 68.83076375530612, 66.54726182260822, 68.95738570920884, 64.22225729111703, 57.7616782342234, 61.04487857510967, 67.74577340772076, 68.00910565160936, 64.41137044660508, 58.27270815449377, 67.36407187677199, 69.22344007799703, 69.23637605482533, 69.50847087367889, 50.38021295301376, 53.54086276023619, 72.52820953246086, 62.242087933325, 61.950094930587284, 49.12165380293324, 49.87208950904108, 49.64334472533196, 56.04419785161173, 58.10340296837592, 68.33725114022532, 67.88400557733351, 64.46993143327775, 53.336962269198516, 51.731857792023696, 48.601971134062744, 51.91480890397103, 58.71772066239388, 64.61303126427435, 63.79920221144154, 65.95516435561642, 61.90212434337985, 52.622235821139434, 50.32563709443616, 51.11728514394453, 51.57759881788685, 55.07340338922317, 51.48297163747972, 62.80392431443738, 66.81796027768043, 69.08922441544073, 61.34572828969648, 54.60367994923746, 53.333859674392215, 52.16846073827436, 55.5273392892653, 64.52135762860699, 71.51408072440856, 70.35538904128536, 73.80730229039347, 70.04651023495582, 75.20490554071243, 73.19432996934461, 71.18935554258286, 72.17937746355611, 73.28879633257466, 73.62008756206882, 78.03122428155716, 74.75155799619614, 73.65014860706945, 70.22182449217766, 67.80502473154377, 20.20545844108828, 3.6364394378277565, 7.9931162538067, 7.677752298693504, 4.254757704273347, 1.1660951568234352, 0.4041314515615664, 0.3790981803209551, 48.760838893152055, 71.83929228013562, 44.98902105516003, 55.3237957339133, 44.652524840447214, 32.351783706295876, 39.57318882788382, 57.21510771782168, 74.80309794026037, 73.51975333306098, 82.87471602039953, 40.09660559315836, 0.34612250784712456, 0.13998117898741078, 0.14443371264684585, 0.18581879355253714, 0.20948064483461842, 0.243168625860445, 0.22501784256629406, 0.1107304634886884, 0.162216926954927, 0.06212617601117781, 0.13752335442170022, 0.31883608009065356, 0.24289436638355258, 0.14424413652910342, 0.3426344788843586, 0.14378050011732887, 0.13400333362721628], [0.04920764300491541, 0.047727806283341306, 0.047428779183856906, 0.03158167398895227, 0.02189797788648115, 0.05239944491956023, 0.02980813447896752, 0.022800601831066514, 0.008889203553178139, 0.10326823850552883, 0.028398998096705447, 0.03700415348453868, 0.08378103781010836, 0.139262787697296, 0.13315095355914486, 5.5957895901895345, 83.44283211615779, 76.70052097689721, 75.73626118321573, 61.3572169119312, 51.15527722143358, 29.255103834213752, 50.22305926968975, 63.80305005658058, 48.24987957554479, 31.204692432957312, 0.48967160344604527, 0.10528784545679247, 0.2567253484120292, 0.8669020307640877, 2.2752909410384397, 2.650474718501491, 3.0531942700186088, 2.4301265035906146, 66.85423435703402, 80.31158831811722, 77.56534084197014, 72.99653268629505, 72.67719684108611, 73.01416766258978, 82.43701873287078, 73.80496455777076, 67.25462990422403, 63.14473513633975, 64.02759790420532, 62.58904118691722, 64.85904624385219, 61.929231843640736, 65.58719112027076, 60.94889425462293, 57.469120410180864, 55.88631068506549, 50.78819436411704, 51.30158162886097, 51.727386290027255, 52.53455123593731, 66.80946442388719, 64.29529182372555, 68.38837531305128, 67.34358141499182, 66.36659745247134, 56.8651460063073, 50.49037664167343, 49.56164959938296, 48.609870787589784, 47.58994863879296, 55.20384965404388, 64.8347903067066, 66.31481432145642, 66.14667800164992, 63.41810080312914, 59.83955775537799, 61.19201844738376, 63.3606106235135, 63.241048935920965, 61.94915356174592, 58.793767575294744, 55.35303700354792, 61.60874674397131, 64.89992910815825, 66.50997577175018, 58.25821499670706, 54.25726013798868, 52.63153183844782, 62.021372241358605, 60.3390480626014, 66.44670794087072, 48.843436164240686, 50.68738945068852, 65.06128364993681, 53.471817278092914, 48.7734846145876, 44.85249511657223, 48.62781170875796, 48.76576146771831, 53.30985476893764, 55.887746272548554, 62.503721790929, 62.413750463916415, 57.24490204165059, 48.375430722390455, 44.50890725658786, 45.097835448480424, 43.98636910223192, 49.174554809447265, 56.30214860362392, 54.20781081722629, 58.943986508154104, 60.391074380567005, 53.384242519255615, 46.07578431406329, 44.88700412934826, 45.8961005364695, 46.85642227049797, 46.55669827615061, 51.83531030531853, 57.88043583593061, 55.86321184712072, 52.83324364692935, 48.254535428939334, 48.63911990196475, 47.92739798945766, 49.686777130250015, 58.31272025262156, 65.00552715793734, 62.800229441735056, 65.52817906102827, 65.37998407117783, 65.39706599327826, 66.08695599340624, 66.22764356674688, 68.42740289626583, 67.79303796829717, 65.4150971289604, 67.483963043459, 68.38118168615526, 67.1859021340647, 63.70096645047588, 76.7757441920619, 28.83063081772097, 0.47312848630451393, 0.3378828644992844, 4.014853041979575, 2.091903220261297, 0.8173244362396579, 0.2191436795457717, 0.226751821295869, 7.440372907346295, 66.36713873955512, 39.04351588218443, 23.059453425868867, 25.83080799348893, 16.121028680955213, 18.974905014038086, 29.40177890562242, 40.36770020761798, 57.25522179757395, 52.4380805415492, 65.89836059078094, 6.261767350858258, 0.37094458396877017, 0.0792483636929143, 0.10018498741931493, 0.01712719789676128, 0.07499843730681366, 0.05264582262644845, 0.08976164108683025, 0.032899963834713546, 0.10935692912748746, 0.06103526297656279, 0.09887446378988606, 0.07541593990378803, 0.04944597678859869, 0.035828767764952876, 0.04210896887666276, 0.0591922584440439, 0.04996698552502259, 0.05827354665304865, 0.0683256965731421, 0.011209657062746344, 0.04251463924564662, 0.07581536282574938, 0.01497044109724342, 0.02614259719848633, 0.07731330220497425, 0.06763307648080011, 0.0430831607551344, 0.08165617037804858, 0.13884620440583076, 0.2129420599028949, 0.24261892713125677, 8.627664062284655, 103.88684518875615, 81.37205600738525, 87.59055029961371, 68.33693735061154, 64.496136788399, 34.69849071195049, 31.609330023488692, 46.37895214942194, 55.43311611298592, 35.05782296580654, 0.1682931226828406, 0.16473473620510873, 0.6693920613296571, 3.1447428801367363, 3.9940191276611823, 3.7405442903118753, 3.4457007050514226, 3.3252390786524746, 69.38868168861636, 81.97195114627962, 82.69161193601548, 74.45368536057012, 77.92610476093908, 75.1917891348562, 82.25429119602327, 76.30123153809579, 70.67909440686627, 65.47527805451425, 66.92681389470255, 66.0419350285684, 69.4212059820852, 65.58490045609014, 67.6579672290433, 62.35198490081295, 59.53802162601102, 58.46504157589328, 55.533924948784616, 52.96978527499784, 52.73981671179495, 54.14675912549419, 69.244016831921, 68.23222575649139, 70.13104515690958, 67.48116247115597, 69.90539120089623, 59.16489047388877, 51.78837130146643, 50.971490644639545, 49.311908368141424, 48.683070059745546, 58.01807180527718, 65.65853118896484, 66.20916135849492, 67.38172254254742, 66.32493403650099, 62.665892185703406, 63.941745065873675, 65.14923103394048, 64.30573709549444, 64.3182376892336, 61.41780576398296, 57.08121761198967, 64.29414649163523, 66.89677638392295, 69.19976465163693, 60.25714505103327, 56.815233845864576, 55.065919506934385, 63.190379758034986, 62.27516528098815, 68.8978676642141, 49.18599244086973, 55.65724034463206, 66.61330669156968, 56.3472911619371, 50.98556410881781, 46.854833710578184, 52.5218152999878, 52.41098088602866, 55.30781599783129, 57.78129792982533, 63.795020964837846, 65.53284668153333, 60.63383771527199, 51.91230643180109, 47.037980941034135, 47.849711525824766, 46.88123126183787, 52.06507490527246, 58.111820374765706, 60.240196489518695, 61.83163150664299, 63.38970284308157, 55.0899048005381, 48.370829782178326, 47.577369597650346, 47.818265884153305, 48.92719837927049, 48.97993856860746, 54.70706185986919, 61.343759259869984, 59.45399661217967, 56.309040208016675, 52.4546996239693, 51.372199981443345, 50.77909838768744, 53.38607426612608, 61.81204711237262, 67.36751571778329, 66.70887916318833, 68.03598957677042, 66.18567420590308, 68.58597647759223, 68.0778020428073, 69.64225507551625, 69.25697634297033, 70.58429071980139, 68.32867683902865, 70.18541705223822, 71.23156024563697, 70.185024815221, 66.10456743547994, 78.11840288100704, 34.686021497172696, 0.4457888001155469, 0.1218023032490765, 2.672425772874586, 3.8619107584799495, 1.5717077014907714, 0.5402587486370918, 0.3052777640761868, 6.70177540471477, 74.41712102582379, 45.14070695446384, 28.432170960210986, 25.537946185758038, 15.104174806225686, 25.61542280258671, 39.16232447470389, 48.76412976172663, 66.24673766474571, 60.758710292077836, 80.09535589525777, 11.92685394517837, 0.5487427127457435, 0.11593898803356195, 0.07515972179751243, 0.08287329256774918, 0.08713461068128386, 0.04020920488983393, 0.07531859311124972, 0.041702421337005594, 0.05756307671207094, 0.030537323778375026, 0.018966029165312648, 0.011847784363424346, 0.04840114777306876, 0.0502994638537207, 0.034166345477945385, 0.03424561259547069, 0.14812339127304094, 0.12796543463463747, 0.1789128939591108, 0.21346189652479466, 0.11382256289042773, 0.2022618289676405, 0.08549814728359062, 0.11418732799469464, 0.1676880664402439, 0.23853707277486402, 0.14767630236043086, 0.19673632788321666, 0.2485984272413677, 0.333569115328212, 0.519262423678752, 11.63610923674799, 115.29984412654754, 92.72080652175411, 96.86543387751426, 79.42765866556476, 68.42918365232407, 40.527179856454175, 71.26533185282062, 92.4895514211347, 70.6933718342935, 45.152905525699744, 0.6347838248456679, 0.2034621661709201, 1.7921831482841124, 4.628477211921446, 7.9236903017567055, 6.71353368989883, 11.55998093466605, 2.8006480538075973, 75.55476527060233, 83.71633898827338, 87.745570213564, 75.59924494835639, 81.67960120785622, 78.97281277564265, 84.40519348267587, 78.89624810987904, 74.58186057306106, 68.90051134171026, 70.05603374973421, 67.9120034556235, 73.10257788627379, 65.94759418118385, 71.91409187932169, 64.78045763507967, 62.22007559191797, 61.2223619030368, 58.42373117323845, 57.59429893186016, 57.88847277241369, 58.38666869748024, 71.24683395508798, 71.23373323871245, 70.07265675452449, 70.79132126223656, 75.82056076295915, 63.57488970602713, 54.996889714271795, 54.5853546357924, 51.242279314225726, 51.19313593833677, 62.13244591989825, 69.14877383939682, 69.96110454682382, 71.42236002029912, 69.21544628758585, 65.8859972799978, 68.47696596576323, 67.18412137800648, 67.92653975948211, 66.26561995475524, 66.08138622776156, 59.332748305413034, 67.99431831605973, 71.32022150101201, 72.57252447066769, 63.51956859711678, 59.884366912226525, 57.523613898984856, 68.18835012374386, 65.0017773720526, 72.01237078635924, 51.96673716268232, 57.883962046715524, 69.97679402751308, 58.8289826147018, 53.15962014659759, 50.914655500842684, 55.37790090807023, 53.896947291589555, 59.65271565221972, 62.68287212617936, 66.56727375522738, 67.46059356197235, 63.858775169618674, 53.60883351295225, 49.57557401349468, 49.54459513387373, 48.48499428841376, 55.85337846509872, 60.793815505120065, 63.46010938767464, 64.39968962823191, 66.87118684091877, 58.42220537124142, 51.31599241687406, 50.693072965068204, 50.03412654322963, 49.76787605593282, 52.2794795036316, 56.7536408670487, 63.94441619996102, 62.08600113468786, 59.521135822419204, 55.38888354455271, 55.014344261538604, 54.31985724356867, 55.65967613650907, 63.94464369743102, 72.89826946873819, 68.66022694495418, 70.66795487557688, 68.74924121364471, 69.57026389337355, 70.58622052592617, 74.7144131506643, 73.07808660691785, 74.84413377700314, 71.61118292039441, 73.64187240600586, 74.32998949481596, 72.68106429807602, 68.18765194185319, 81.70986621610581, 39.71137392905451, 1.276476414453599, 6.542444315648849, 11.509788324756007, 8.610554683593012, 2.638385238186006, 0.7313347439612112, 0.4903323083154617, 9.66966131041127, 83.12206852820613, 53.785500987883545, 36.49679545433291, 34.913275780216345, 24.109116946497274, 27.58993218022008, 43.7778990499435, 55.91725426335489, 76.89819274410125, 69.60014450934626, 92.3688679356729, 14.913409352302553, 0.7388614045996821, 0.2358940847578549, 0.1592754557608597, 0.23498942684983057, 0.2103894242956754, 0.10070780412324014, 0.17634305201711195, 0.15322015891152044, 0.2074684536144618, 0.1581778509482261, 0.18743576001255743, 0.2257599366167861, 0.16171190647348282, 0.2142078056931496, 0.13798188868789904, 0.09571016826216253], [0.022926092778723088, 0.0445607413477715, 0.04824876139361051, 0.06097045193816866, 0.019893265599685333, 0.018485623088875608, 0.05510139489366163, 0.03956756028797358, 0.02136794463430922, 0.02677177946503845, 0.039159790838077184, 0.03602646058425307, 0.0747781104197906, 0.1164471724581334, 0.0804991171424908, 29.32651254438585, 90.05354773613715, 65.95128905388617, 63.19982090303975, 50.7078093098056, 17.92735957330273, 20.2224717217107, 54.546550627677675, 31.864964615914133, 54.03317513004426, 13.313296091172004, 0.1078012343796511, 0.2394532066799941, 0.1941830027968653, 2.5191476364289564, 2.4063839066413144, 3.346483861246417, 2.048840743880118, 20.42896882180245, 79.5707545741912, 77.15014226974981, 74.05613745412519, 77.74908035032212, 76.90822616700204, 79.82519872726934, 87.74320894672026, 71.0210309490081, 71.56001952386671, 69.54101870136877, 63.40598067929668, 58.35718816326511, 58.53604824312272, 57.23529223472842, 58.33671731333579, 55.81781041237616, 54.71392600767074, 57.111412017576164, 52.49627282542568, 51.410737268386356, 51.60478476555117, 49.26681680064048, 62.74826195932204, 66.60207302339616, 66.5599310782648, 67.37810611724854, 64.42048995725571, 53.801818047800374, 48.484660886949115, 48.19012618833973, 48.46181308069537, 47.09935426712037, 50.836600334413596, 58.420856075902144, 62.911440403230735, 56.956843176195704, 56.10008378182688, 57.13969622888873, 61.910051453498106, 63.70209609308551, 62.9922333840401, 61.0138879283782, 58.54410479145666, 58.62072044803251, 63.35926132817423, 62.488165670825595, 64.83517469898348, 62.38412480200491, 62.1982515242792, 57.899949627537886, 61.142176889604144, 59.43283542510002, 63.305336583045225, 43.01893218871086, 51.16732674260294, 64.98326770720944, 55.86016024312666, 50.48543837762649, 49.63369569470806, 54.789851327096265, 53.65153243464809, 61.56354927247571, 61.694866303474676, 64.18888968806114, 61.237310055763494, 59.019201878578436, 54.84827895318308, 46.97232830908991, 42.47696261252127, 44.17678840698735, 45.16801057323333, 54.56497007800687, 57.95109341221472, 59.11255428867956, 60.906148264485026, 59.35422328210647, 48.66006143631474, 45.04601701613396, 45.35145198145221, 45.69397687911988, 47.9474687576294, 48.43730218948857, 51.57514341415898, 51.79724762516638, 51.9518635349889, 46.70353612592144, 47.051262086437596, 47.633353587119814, 50.05903751619401, 57.89716474471554, 64.26698407819195, 65.15125497694939, 62.63457990461781, 66.20642354411464, 62.81095320178617, 65.69103587058284, 64.18172351775631, 66.4937214697561, 67.90981477306735, 67.547379924405, 68.81664322268578, 65.61453788511216, 70.0175552983438, 69.4395548297513, 69.85065844751173, 62.23517279471121, 4.748100676844198, 0.736041036584685, 0.7827192028203319, 1.127041710480567, 0.6952900006886452, 0.48435081637674765, 0.06842768585850155, 0.04308801392213472, 33.47250684615105, 62.09832914413945, 32.411278217069565, 25.168798200545776, 42.54963628707394, 29.054658951297885, 20.408144958557624, 36.69418481088454, 46.849895446531235, 56.78898142230127, 55.943251732857, 33.22067891397784, 0.2477702861952205, 0.04719979167284985, 0.07221840382102998, 0.03330512858566738, 0.021567085359786308, 0.12782840448762142, 0.02667937010917212, 0.013542130491846513, 0.007754364473399737, 0.015951931878413646, 0.06124129083247916, 0.09293208063970651, 0.03644997314099343, 0.042391900468858025, 0.08220973019037517, 0.019407157913871834, 0.03941239683978981, 0.031966972164809704, 0.008293952278402305, 0.015499204558680858, 0.07534133060084236, 0.03290609253810779, 0.05048370799951015, 0.0709703776444639, 0.039451425189092275, 0.026328453959356395, 0.058488246624267874, 0.028343927866268544, 0.015640515221973822, 0.11275896472075295, 0.0967288047315613, 38.33008773865239, 103.12828233165126, 73.31875539595082, 71.8054892939906, 57.935439232857, 29.486396197349798, 21.918637944806008, 62.439014450196304, 36.82787095346759, 63.966510911141675, 14.402699105201231, 0.25253991896827377, 1.0872750056366767, 2.015053447215788, 3.690338197254366, 6.404618111348922, 5.2560324149747055, 1.6387880761777203, 22.470660555747248, 84.73909701070478, 79.4982691734068, 78.31895366791757, 79.92794129156297, 81.25935846759428, 80.4413873918595, 87.2981454480079, 75.00571189388153, 74.23706070069345, 72.38028126378214, 67.33879612338158, 61.30386483284735, 60.76922224413965, 59.74402450746106, 60.786700325627486, 56.887456447847434, 58.55662499704669, 57.440698915912265, 55.51501520218388, 53.021674310007405, 52.60856636108891, 53.77607945472964, 65.30328996719854, 68.56405042832898, 69.4386762188327, 69.51771982254522, 66.51305875470563, 56.38603633449924, 49.886496374684, 50.40711649002568, 50.76877078702373, 49.00891311707036, 54.064032416189875, 60.07859876078945, 64.24424217593285, 60.52392898067352, 59.47405953561107, 60.66904883230887, 66.56762676854288, 67.35490137530913, 63.71008596112652, 63.801975327153365, 59.425112278230735, 61.40495607929846, 66.12268878567603, 65.36371800207323, 65.32800874402447, 66.44953989213514, 62.72814412270824, 61.53318620497181, 63.08888842982631, 63.774357918770086, 64.2929462463625, 43.55695978287728, 52.79128997556625, 68.04894124307941, 57.446758977828495, 54.03619927744712, 50.59555892021426, 58.19857928060717, 58.38362101585635, 62.84534846582721, 63.760382513846125, 64.56628053419053, 63.411146440813624, 61.90521517107564, 56.37889369841545, 49.834109198662546, 45.54174184799195, 47.50756317569364, 48.69688072512227, 58.06022159514889, 60.948972702026374, 63.35385630207678, 63.838269018357806, 60.86513596196329, 50.875094475284705, 47.779308903601866, 48.03489054402998, 47.80274506538145, 49.559700181407315, 50.98971397646012, 54.47163335738644, 53.825156150325654, 53.288666125266786, 50.30267553944742, 50.225526440528135, 50.08029284015779, 51.576877101775146, 60.464834551657404, 67.63813572545206, 67.26897008957403, 63.39118942137688, 68.8993424753989, 65.14665403673726, 68.2361481266637, 66.88576236847909, 67.13160084139916, 69.59368044330229, 70.328748303075, 71.66138141385971, 67.98210405534314, 72.5418358464395, 73.50039251389043, 72.15216405930059, 68.4692467412641, 8.903627318720664, 0.27025210160401564, 0.9569804262249701, 2.756567967514838, 2.0108558982610703, 1.3671042481737754, 0.09512810231817347, 0.2611961149640622, 31.98335547601023, 71.59563464503135, 33.665738490320024, 21.382446019880234, 24.976205902714884, 23.92472436351161, 29.589964420564716, 46.72382654682283, 55.499710113771506, 65.77642194686398, 66.1805437457177, 48.37850586060555, 0.7578771164821041, 0.04895245911733759, 0.006895166701607167, 0.01575539585187911, 0.10437659153174009, 0.06328495677500483, 0.037398841983127984, 0.1170567179759664, 0.13281024361570037, 0.06744985123194995, 0.016893428081886906, 0.0485865333898654, 0.050195992188227755, 0.023624016114720897, 0.0507998533336626, 0.0528567496146406, 0.13169780734085268, 0.12875699498240026, 0.20838475605893522, 0.09679453507546457, 0.17864664776190636, 0.13125698502746322, 0.14373566865199996, 0.17518221430720823, 0.16585849525947727, 0.1622737706789086, 0.13698652596963992, 0.15934308600281516, 0.12712348868409473, 0.4612394145900204, 0.1478349132042739, 46.04036531140728, 115.58212141836844, 82.71689553414622, 84.0142822265625, 68.31813350800546, 31.077941040838923, 31.140232201545473, 76.14604688459828, 48.8395098716982, 74.70226164787047, 18.327178532077422, 0.2894882629475286, 1.4598008870117127, 2.822748648543512, 7.156895370252672, 8.260594933263718, 15.221297760163585, 4.477170311635541, 25.776863636509066, 88.36914862355879, 81.89120523391232, 81.079345210906, 85.05531849399691, 85.63738253808792, 81.96750317850422, 87.48981598884829, 78.31049703782605, 78.32355068575951, 76.78569132281889, 68.01684841032952, 64.6690623221859, 64.55836911355296, 63.010229218390684, 63.33484849622173, 58.891677779536096, 60.67252797465171, 61.438888503659165, 56.773566507524066, 56.51213269079886, 55.293103187314934, 54.87118167261924, 67.93054057705787, 72.23782077912362, 72.36485850426459, 72.27505191679924, 70.39568747243574, 60.38960349175238, 52.09894849408058, 52.831462890871116, 53.392338291291274, 50.5338914163651, 56.22093985157629, 64.51569372607817, 68.57504090955182, 63.0455776183836, 62.2978836490262, 63.562722513752604, 66.80915063427341, 69.36210370832875, 67.5704905294603, 65.93012394443636, 62.37249105207382, 64.39264112903227, 67.97229812991235, 66.80503214559248, 68.39472955273044, 68.32845718629899, 67.286314810476, 64.72841562763338, 64.4877350714899, 67.0544635095904, 65.14601861276935, 46.693110466003425, 57.91276401089084, 70.83745618020335, 63.69600857457807, 55.04212248709894, 56.19529147301951, 60.54496072953748, 61.314498378384506, 65.41073545332878, 65.81636736469885, 68.93409467512562, 66.2514288194718, 65.42723294227355, 60.94041801268055, 52.980811057552216, 47.42901771299301, 50.86145247182539, 51.82909727096558, 59.63781064556491, 63.27802511953539, 64.91373192879462, 67.55834687140681, 65.41041381897466, 53.63855723411807, 50.13981480752268, 51.0173313848434, 50.76146341139271, 52.05362942910964, 53.38150470487533, 57.52446505331225, 57.42009470539709, 58.477408809046594, 52.3979978407583, 52.723962491558446, 53.334628458945986, 55.0752116018726, 64.22516376741471, 69.90457534790039, 71.21702394177838, 67.90138167719688, 70.82798757860738, 66.55148229291363, 71.93783790834489, 70.08425128075385, 72.02601278981855, 73.24687404017295, 71.51235488153273, 75.45261890657487, 69.74712356444329, 76.61706862911102, 76.67439014680924, 76.2177791903096, 70.59852107878655, 10.761929615851372, 1.6842446692528266, 7.27562012210969, 5.415241420269013, 3.9065081073391825, 1.7754462721847721, 0.22650278143344388, 0.6452031109121539, 39.843255781358295, 80.93429596193376, 46.38375705288303, 36.07630560475011, 57.79557143488238, 41.53804525252312, 31.405827653023508, 51.86184906190442, 63.29174557039815, 75.75524545484974, 75.76213313687232, 58.69657516479493, 0.7938217780282422, 0.18188010570743393, 0.0896087529197816, 0.10181331496325233, 0.1470129315050379, 0.31246725409742326, 0.12257792896801427, 0.19532153202641397, 0.17018686138814496, 0.1089383540074191, 0.12689352441098423, 0.18792286935833194, 0.10616402021579205, 0.15892901547974156, 0.11993625862223488, 0.0997642366095416], [0.1013525820247108, 0.02011580839602938, 0.01797321560462156, 0.015650701318537037, 0.062320877257133686, 0.08294756479200818, 0.07820444632201426, 0.08829216953487166, 0.04186377094517793, 0.06382939631059285, 0.05355126194415554, 0.05803680633224788, 0.09276247643415006, 0.09386182792725102, 0.8299172056778785, 57.35947839675411, 73.66264527843845, 68.1421132241526, 49.111232065385394, 58.954541606287805, 53.51937601643225, 68.9448655036188, 48.92595498792587, 36.94769543986167, 54.552842109434074, 1.8877214217378249, 0.39226769139209106, 0.9717834512552909, 0.5418415475756891, 2.378939082545619, 3.270248429429147, 3.540436240934557, 1.1082361518375337, 43.224044692131784, 80.08504006170458, 77.34928884813863, 78.0940528069773, 77.49582859777635, 77.19485728971421, 82.05621934706166, 74.67184758955433, 73.34366244654503, 73.09995774299868, 69.43827613707512, 71.8165111541748, 64.95828220921179, 61.84370848440356, 56.757755433359456, 54.14893604093983, 51.88346132155388, 53.705684677247085, 53.461799544672814, 54.53810576469668, 52.009298801422126, 52.460214476431574, 49.85287381756691, 55.781453963248964, 64.39921894381123, 68.89370210709112, 66.38296942557058, 62.83248309166201, 52.958010319740545, 49.20500024672478, 48.43488208709225, 49.356211539237734, 49.095562196546986, 46.74322266732493, 48.674656575725926, 52.36950966619676, 51.4210452571992, 52.24526074624831, 58.40824957816832, 61.481963972891535, 63.57247744837115, 60.619952524861986, 62.1435187708947, 60.95030630788496, 61.43884927995744, 64.39209199720814, 55.732047788558475, 55.06628428736041, 62.15545846569923, 61.88453251315702, 57.974921811011534, 62.09520693748229, 60.66146689076578, 58.36318938962875, 44.62004761542044, 48.124908939484634, 66.38664860879221, 54.33946909443025, 52.335361511476584, 51.901304183467744, 56.91108088339529, 56.545280641125096, 58.84842972601614, 61.65286948603969, 56.30805569310343, 58.64880069609612, 61.16286346989294, 56.86682085837088, 54.986695474193944, 47.34068201434228, 44.09173573217085, 43.87291062262751, 48.538538563636045, 56.74690615746283, 55.39355116505777, 57.713327177109264, 60.362319484833755, 52.526141674287864, 47.07027381466281, 43.86937264473208, 44.9959675727352, 45.79034166951334, 49.00674796873524, 48.41313646685693, 48.62165750995759, 48.83920784919493, 46.86182729659542, 47.778187105732584, 47.39404586053664, 49.73475163982761, 58.21639468592983, 61.988906783442346, 65.53572177886963, 60.346649615995354, 66.33294351639287, 66.17422088499993, 64.81468031483313, 65.80159964100008, 61.30099758025139, 64.17718141309678, 65.57844815715667, 65.28518430648312, 66.59611102073424, 64.28337958551222, 62.9313228976342, 65.61007815022623, 73.32969880873158, 44.22778314159763, 0.5388165421543584, 1.108528368415371, 2.1315316615566133, 0.4310821489461007, 0.8629075257528214, 0.1381266180185541, 0.1192573821472545, 4.449393556964013, 57.75799905100177, 47.801148660721324, 37.491779173574145, 60.12172129846389, 99.53585409349012, 45.144256699469786, 25.899884854593587, 45.325803602895434, 52.6039065853242, 51.050365586434644, 58.76632275119905, 9.648588376660502, 0.21031004226496144, 0.013405301442910588, 0.052776743222268364, 0.036158488177123575, 0.05430554062308324, 0.06883187384735193, 0.05353087634449044, 0.04808226367458702, 0.058530059703175104, 0.014540589162929645, 0.025400112443152937, 0.07387563586235046, 0.029817218366529674, 0.05826493582477974, 0.02688187779107642, 0.05096714012324811, 0.03524083741790345, 0.0300854851206344, 0.04101547795618254, 0.04200273546420279, 0.04604952597630121, 0.0368222842113145, 0.022343479081868164, 0.021648288764540228, 0.057673960278231295, 0.0183036427329024, 0.09309706533507955, 0.05378126452166227, 0.09445582186022113, 1.0197002284469143, 70.07718316970333, 83.02035362489762, 76.02505745426302, 56.51858106736214, 71.14543284139326, 52.84715629393055, 45.0479664341096, 39.524206269171934, 43.14391066951137, 63.193733384532315, 1.91705952488607, 1.3698708674600049, 2.9513335035693262, 1.647823501017786, 4.39564629908531, 10.72234211429473, 3.18140551928551, 2.0851033012713156, 48.0680267272457, 84.15307921748008, 79.67109664793938, 82.98878638975083, 81.3021436814339, 81.70827373381584, 81.43326067155408, 76.12263817940989, 77.62382338123938, 76.09359695065406, 72.00900539275139, 72.95143327405377, 68.01062753123622, 64.67567936066659, 59.054624803604625, 57.08899959441155, 53.089401875772786, 53.98301193791052, 54.03956074868479, 55.19896630317935, 52.818005238809896, 54.179401090068204, 51.253210959895966, 57.9300695080911, 65.76403902422997, 70.81403178553428, 69.99098516279652, 64.33195421772619, 54.31550733504757, 51.01111835049045, 49.94883852620279, 50.89487106569352, 50.155127740675404, 48.94226420310236, 49.444351119379846, 55.14638693101945, 54.1660414972613, 55.299630011281664, 60.74447208835233, 64.71330273535945, 64.63435719090124, 61.94215213098834, 64.07523116757794, 63.71082728908908, 63.93130371647497, 65.32535329941781, 56.87242984771729, 55.646120425193544, 63.066848631828066, 65.45789803228071, 61.1328455709642, 65.88828794417843, 62.27380421853835, 58.91350969191521, 46.67813093431535, 51.55681417834375, 68.97669945993732, 57.006869085373424, 56.12026045399328, 55.68519899922033, 60.29146579004104, 60.16460457155782, 59.480307871295565, 62.5280208741465, 58.69857557358281, 60.09021682123984, 64.18421030044556, 59.038025333035385, 57.76025441385085, 50.6395600688073, 46.694161661209606, 46.303689710555545, 51.55231914212627, 58.75541463974984, 59.55731576488864, 60.77333288808023, 63.44896593401509, 55.758594389884706, 47.39927830234651, 46.42296114275533, 47.865557901320926, 48.638253058156664, 50.592915242718114, 48.822416182487245, 49.6084983887211, 51.33718890528525, 48.78545176598334, 49.91108963566442, 50.536735134740034, 51.292681770939986, 60.30040879403392, 66.06936808555358, 66.9436251732611, 61.337075541096354, 69.36799510832756, 70.35806409774288, 68.96097860028668, 68.06690569846862, 64.24812532240345, 68.39744383288969, 66.64698416186918, 66.76168995518839, 70.05535910206457, 66.58716017200102, 65.37367689994075, 69.75277962223177, 74.6577113674533, 49.959013154429776, 1.3239171139655577, 0.4520444902441194, 1.9747214307708127, 2.227947933058585, 1.9930230874207713, 0.6265304225587076, 0.05386203700195878, 3.223753633999056, 64.39320202796691, 54.259323304699315, 32.24527566663681, 51.77117563063099, 84.35058624513688, 48.547061874020486, 35.493708118315666, 53.63741582439792, 60.449552997466064, 57.89772564365018, 72.45843056709536, 15.915856361389162, 0.17789309303606712, 0.07301252290245987, 0.007963571594201871, 0.041120623523790034, 0.009650473742024794, 0.03083777005573915, 0.027594889228742932, 0.04822007140084621, 0.03695138534831424, 0.020999264820749243, 0.05041422765521754, 0.046878613141034885, 0.022154330058143507, 0.027762515012234933, 0.04075531832753651, 0.21780149350243233, 0.12661773275824326, 0.10047719633627324, 0.11364892140151032, 0.15712221243208455, 0.14032726686808372, 0.14184580635159247, 0.21289137552582452, 0.1064124778513947, 0.15992381129293673, 0.18204447753246755, 0.18304161757471102, 0.13331443672218632, 0.212850941405181, 1.7541639819260568, 80.42852986243464, 93.28432559967042, 85.97993881471696, 67.08023348162251, 71.75458477389428, 64.20387314211938, 88.69381889220207, 66.84560514265492, 55.02444828710249, 77.55311089177286, 2.706849474099375, 1.331715766460665, 3.0659284899311685, 2.6769534137941178, 8.022104530565201, 7.722313365628643, 10.009531744064825, 2.8953551525069825, 53.123899121438306, 86.81676864624025, 82.52600946734029, 85.18401930409094, 84.08153518553704, 83.26784733803042, 86.33152438748269, 78.85404340682491, 79.41382054359683, 77.15896760263752, 74.69729592723232, 75.70470179280927, 69.42970968061879, 67.38202848742085, 61.305998602221095, 58.60629397053873, 55.766172409057624, 59.14312916417276, 59.13222105272355, 57.456207967573604, 56.7552843401509, 58.0400017769106, 54.57416019132061, 60.821680022824204, 70.15982750923403, 75.64049259308847, 71.72190358561855, 69.20128653126379, 57.828480120628114, 54.547868544055575, 53.17061847256076, 53.52380829472696, 53.20955191889117, 51.268880828734375, 53.1741839070474, 57.54918383013818, 56.30492564170592, 58.18715341629521, 64.39328439774053, 67.54088447939965, 67.6874791422198, 63.72141768855434, 67.09610339133971, 65.42145921337989, 67.75202566577543, 68.5636660360521, 60.33008936912783, 54.959701722668065, 65.91714874390634, 65.8806707013038, 64.1866853160243, 68.46675995857485, 63.77527575339041, 60.72289120766425, 49.12158712264031, 54.386149221850985, 71.89520174457182, 60.56350961808236, 59.26529138318954, 59.104007444074085, 62.07666589367775, 62.22964617513842, 61.27726724070888, 65.3700134061998, 59.92910546641196, 63.95362984749579, 66.07720498115786, 62.88839647846838, 60.29883984596499, 53.986016473462506, 48.57122367428195, 47.25433495736892, 52.874126511235396, 62.73418065040343, 61.58766792666528, 63.748293768975046, 65.87259846348917, 59.04418737657609, 51.51105973028368, 48.81431648808141, 50.27543467860068, 49.994526293969926, 53.736828296415275, 52.28488845209922, 52.15004521031534, 53.985106483582534, 51.301118789180634, 54.1555138557188, 51.066443381770966, 53.889169231537856, 63.013665214661636, 69.57254671281385, 70.29851467378678, 63.5138850827371, 71.97572800420946, 72.53865872659992, 71.99027999754875, 72.69707541311942, 68.59535094230407, 69.97053392471807, 70.36528910360029, 70.09158611297607, 74.05613745412519, 69.11071900398501, 68.6266436115388, 72.87933226554625, 80.00473345479658, 52.01540593178042, 2.3111762154486875, 3.8275316742158707, 6.799055578247194, 3.3769552842263257, 2.9043582177931264, 0.6992262830176662, 0.14503368206562536, 6.2293087570898, 72.9423176857733, 62.14857078367665, 50.95434596461635, 67.45838134519516, 112.52863468662386, 56.42733497004355, 40.118504185830396, 60.07365265200215, 69.33343902710946, 68.99212221945487, 85.10950211555728, 20.27325660951676, 0.6304772462575667, 0.20209920382307422, 0.14109620463944253, 0.1794160758295367, 0.15875891331703434, 0.13821418186829937, 0.14564296711356411, 0.2546500621904289, 0.260412652165659, 0.14610700189105927, 0.12332343977064857, 0.10737882115908208, 0.11001882909406578, 0.12102902942006627, 0.15849717171682468], [0.050154274870311065, 0.03711618235214584, 0.03387812021819334, 0.06208365813138024, 0.011120923971306654, 0.14047948853863826, 0.07272913165751003, 0.01236385087512674, 0.02540195105417121, 0.0856104327906524, 0.07079469836166791, 0.0933906072450261, 0.024780808880384413, 0.10380546532330975, 3.873451842415718, 72.63586290421026, 68.51226729731407, 60.63412404829457, 38.36528316620858, 29.438190267932033, 46.78976158941946, 83.03154022462907, 51.65143351401053, 54.11897305519351, 35.25164296550136, 0.21988693804990864, 1.9653701325578077, 1.8911253036029878, 0.7250192376875109, 2.8398067912747784, 11.44523984001529, 3.1672450275190416, 7.129814345990458, 72.33708812344459, 73.91743460009175, 75.59039608124765, 77.07034557096421, 74.75147954879269, 76.50892888346027, 66.73290760286393, 66.14207313906762, 75.62423829109439, 72.14390354771768, 73.77588410531321, 71.82993350490447, 70.27608656114148, 69.4752876220211, 70.21341493052822, 62.615564254022416, 56.531320925681825, 50.46173941704535, 53.795789364845525, 50.04294010900682, 50.733092907936346, 51.54050496316726, 50.96277906048683, 48.64636844204318, 60.728813986624445, 67.08145726111628, 67.73677549054547, 59.68546744315856, 51.841519417301306, 50.497672250193936, 47.21594672049246, 46.73873939821797, 48.22689056396485, 46.34955006261026, 47.574125797517844, 50.52994943434193, 50.2171717920611, 51.857314801985225, 57.868841309701246, 61.08862476964151, 62.57630917333788, 60.739722098073656, 60.44293203661519, 58.54288493433307, 62.49287643740254, 61.27143859863282, 61.578395443577925, 61.92059870689147, 58.31181026274159, 57.63747246034684, 57.0410172400936, 64.43630495379048, 58.779576440011304, 65.22101433046403, 48.06195489821896, 48.90924961336198, 66.07653817822857, 56.21514651083178, 55.49282635411909, 50.53640565564556, 58.103014653728856, 58.37725500906668, 56.710620310998735, 56.3372185153346, 57.80721302955382, 51.574511912561235, 59.60249754690356, 61.04258006618869, 58.33157900841006, 54.31691154356926, 48.42597046206075, 44.68200537466234, 45.685002496165616, 55.11436470093266, 57.24565513672368, 52.839205649591264, 63.80967886217179, 55.726791812527566, 47.851994345265055, 44.94913839524792, 46.96027486555038, 45.75079633343605, 49.156123592007546, 46.435673544483805, 47.424405005670366, 46.089206664792954, 49.198661696526315, 46.1932396888733, 47.48638629913331, 47.82511434247417, 56.69326774535641, 60.0054818584073, 65.6766878404925, 66.38933150999009, 65.44083179966097, 64.5687202484377, 68.67458281978485, 60.12932677422801, 62.841041703378, 64.33608839588781, 64.68708561312768, 63.403321312319854, 61.30795194256691, 56.35590468683551, 64.62350007026427, 64.27102019709926, 70.31862858803042, 60.376596912260986, 21.209775440154537, 0.37952691376689945, 0.2219119382601592, 0.6226349573942923, 0.41026919479331664, 0.3877753824476273, 0.16577994060372153, 0.18169492693437686, 27.89021315113191, 57.73599455433508, 46.69460488903908, 78.17505759577598, 101.91321834441155, 84.1895337258616, 25.22958709347633, 26.962647130412442, 47.175361956319506, 51.03391124356178, 49.1378531917449, 25.10188452659115, 0.12333390453169424, 0.029411957854585304, 0.06002139923493228, 0.05308660280500209, 0.016800043879136924, 0.066348890954208, 0.06951232846345633, 0.07485040613720495, 0.052712774880590944, 0.05309332905697727, 0.06961687648248288, 0.012065108185784231, 0.02777739627016408, 0.0021066055717622683, 0.0536087223689162, 0.0057768138339592805, 0.05187447167812817, 0.0328195782288188, 0.053010733287420966, 0.03471187285838589, 0.13734209801881544, 0.04830836686455915, 0.040676173784079096, 0.06354982784438519, 0.0649858903019659, 0.06473436831466614, 0.03375685616065899, 0.05209109453003734, 0.16176724866513284, 6.375664155329428, 88.20491898444392, 73.53592134291127, 70.13404969246157, 42.92729777674521, 40.36815912492814, 54.82608618274812, 79.27544716865786, 51.7114536223873, 61.199086558434274, 39.520142693673414, 0.1437830128857205, 2.0997749269008636, 4.095492805204084, 2.5694049654468416, 3.6930821403380367, 10.916222910727225, 2.508509433077228, 9.269690359792403, 74.6030492167319, 77.92598708983391, 78.86791290775423, 79.1374268070344, 76.90612377658968, 77.17743412140878, 69.2321869634813, 68.93401622772217, 76.04510076584356, 75.23025189676594, 77.94512041153448, 73.73371078122047, 72.80580351429602, 73.06868860798498, 70.62588353310862, 66.21798669138263, 59.71115112304688, 54.0809456763729, 55.74715675846223, 51.67208479296777, 53.492801958514804, 53.90040682208154, 54.18900305225004, 51.463461768242624, 65.03301120573475, 69.15206863034156, 70.0153430815666, 62.175195832406324, 53.965553468273534, 51.52940857794977, 49.93513376482072, 49.77523442237608, 50.92068418379753, 48.96539049763834, 51.769712586556714, 51.69112005541402, 52.409941457933, 54.69325119449247, 59.400793583162375, 62.85885710870067, 65.9342267436366, 62.761951031223425, 63.30859215028825, 59.77079076151694, 64.15318043001237, 63.643499805081284, 65.32738508716707, 63.31684089476063, 58.651016835243475, 57.86588384259132, 58.958032515741166, 64.96428735794561, 60.842197941195586, 67.64714933210804, 50.65781477958926, 49.68739294236707, 67.84839045616889, 58.72302762923702, 58.14268942802184, 52.41198109042261, 60.89937825356761, 61.65541902665169, 59.299623889307824, 58.330300315733886, 59.137845731550655, 54.37279747378442, 60.56029327454106, 64.78747083294776, 60.354635561666186, 57.127368219437145, 53.144009113311775, 46.75627239288823, 50.45382799640779, 56.918227441849254, 60.53537053446616, 58.02483397145426, 64.21464397061256, 58.714912245350504, 50.32282867739278, 47.29841847573557, 48.99793048058787, 49.472356842410186, 50.6144255207431, 49.42139740913145, 49.98837993990991, 49.082614452608176, 52.254568530667214, 49.65708871041575, 49.503810328821984, 49.52604624532884, 60.01997501619401, 63.99912149675431, 67.2904097649359, 67.24661257959181, 66.01486282963907, 66.99165851839128, 70.26960680561682, 62.218585091252486, 64.91042929310953, 68.31978874821817, 67.01000736605737, 65.21756264471239, 63.24095479903683, 60.4416141202373, 66.59071383937713, 68.30610752105713, 72.74022932975524, 66.83610516209757, 28.601884072826756, 0.5527108030453806, 0.9380096990254618, 0.6052475807166869, 1.2662590078769194, 1.0194257238218862, 0.2676969838719214, 0.3514361549769679, 25.50249776532573, 67.44029921870079, 49.056232590829175, 77.86840669570431, 106.84584202304964, 83.96228728755828, 35.915166793331025, 37.0197650694078, 53.03836791746078, 58.75681100353118, 59.47712290671564, 40.681450597701534, 0.18885191950586536, 0.05975396177100559, 0.03186062000872147, 0.022769517813538833, 0.029589916248956037, 0.017275202253292647, 0.030516932433050488, 0.14111659789998687, 0.09974523762901945, 0.10959499861083685, 0.0005315008492025006, 0.10992444706179443, 0.013515279110100482, 0.02395843839152686, 0.05656608988741233, 0.1494361442183295, 0.1698589910783114, 0.08044468659547069, 0.13925733315127511, 0.16527384759918337, 0.23477521334444326, 0.2888974865838405, 0.14272336006885575, 0.1730540986623495, 0.22054067151921414, 0.15380348890058457, 0.1718151965929616, 0.3271192985196268, 0.426198031993643, 9.010317748592747, 98.47097766014838, 85.64365048562327, 81.83801789437571, 55.238370433930434, 42.69613289063977, 56.13116072070215, 97.25005365187123, 73.8087692568379, 75.28573774522351, 48.70441559822329, 0.2674869532066007, 4.808365443060476, 6.263529475658171, 4.744415119771035, 10.36663216929282, 23.2882962688323, 8.835514380085854, 9.404053111230175, 79.80679496642082, 80.61700759395477, 84.23711992079213, 81.58538587631719, 81.4200658182944, 77.73026081823534, 74.53622771847633, 72.67737727011405, 79.61503028869629, 78.25516808417537, 81.16171498452464, 76.97409845167591, 75.56766986846924, 74.53918518558626, 75.56845434250371, 67.32714668396981, 62.225861087922134, 54.94132934078094, 57.809511538474794, 53.06112158683039, 55.65586359270158, 57.07120380093975, 55.553929036663426, 53.87228342794604, 66.66629006785732, 71.57475194623395, 74.6058419442946, 64.2270504274676, 57.1156991681745, 55.58613169577814, 52.16557779619771, 52.26127578366188, 53.18728854579311, 50.47015682343514, 52.919159243183756, 53.99259036587131, 54.95594409204299, 55.718625437828806, 63.48271008460753, 63.554199203368164, 69.40813664467105, 63.66226050161547, 63.81765304073211, 60.43537362929314, 66.84179259884742, 66.79715602628647, 67.21789298519012, 65.75447628574987, 60.54083047374603, 60.48288137682023, 59.06599575473417, 68.80637445757466, 63.79007093368038, 69.37394142150879, 53.525000695259344, 54.63680044297249, 70.68545649128576, 61.56653027380667, 61.202095016356445, 54.1849002530498, 63.643374289235766, 64.30998110002088, 60.46907071144351, 60.417907314915816, 61.959689048028764, 55.543017002844046, 61.96960872219455, 67.51369460936516, 65.01452507511263, 60.04485068782684, 54.96430658525037, 50.873419623221125, 51.81097592076948, 61.29956983750867, 63.07881970559398, 59.42630075639295, 70.19002191482052, 61.62247896194459, 51.844853431947776, 49.8964709620322, 51.579842413625414, 51.61091150776033, 53.58697806635211, 51.58548670430338, 52.310101447566865, 52.83160017382715, 55.6776092129369, 52.091456767051454, 52.478771209716804, 52.81554983508203, 62.8208101180292, 65.76687489786457, 72.41090713008758, 72.27812705501434, 69.8155689239502, 73.29719804948377, 73.86974642353674, 66.13760948181152, 69.44283393121535, 69.74753149094121, 72.81087906129899, 69.61686165102067, 67.4117051401446, 64.67126669422274, 71.30654027385097, 70.35052530227169, 75.74552582156274, 72.69858944800593, 32.82059127284635, 1.0935876927068158, 7.480110439562029, 5.5405959583097895, 2.644912552449011, 1.31878481516915, 0.5126648744748485, 0.31496595711477343, 33.483497327373875, 75.58545389483052, 62.42177563328897, 82.24517560774281, 103.60555633421868, 90.03855643733856, 35.33472661049136, 39.55484782495807, 63.03482247937111, 68.68859352604036, 69.0985361222298, 50.571608927942094, 0.4989943112577162, 0.10763568277921408, 0.15896471517701305, 0.13134105551627376, 0.11293809906008745, 0.13599056570279983, 0.1599041534767997, 0.2381603873424953, 0.14164702185700018, 0.18034362444473853, 0.13194294015486396, 0.1975603933416067, 0.12816586621826695, 0.10046516875586203, 0.12481385616645699], [0.018548744903396697, 0.0019718680625608674, 0.09524291591538538, 0.04392444787006225, 0.08498895928383836, 0.01462030635711046, 0.011497418839304198, 0.10586085624151653, 0.10886628811638202, 0.028508089017122987, 0.07006070952141477, 0.10065219380081662, 0.1583647151147166, 0.20752849958596692, 17.738905376003636, 80.896970687374, 69.61315108883765, 61.204115036995184, 29.70130285909099, 19.407199236654467, 26.018465949643044, 44.66879483192198, 27.61392139619397, 67.30929205494543, 14.344351887702944, 0.20725209506288653, 1.5661251881430227, 4.01855526912597, 1.0795020936958253, 5.784398721110437, 20.05148187760384, 1.4261649693212202, 23.609348150991625, 79.16228678918655, 78.48511311315721, 72.33502495673396, 74.06861059127316, 69.49165175038, 72.19393730163574, 63.43711253135436, 63.2753735972989, 71.11511291996126, 71.6713285446167, 74.7034618931432, 73.16940722926971, 73.66189218336537, 73.27546027398878, 69.20156109717585, 70.09230782908779, 64.82117575983848, 52.6525322083504, 51.74615090893161, 49.694280624389656, 49.12183423196116, 48.878910080079116, 50.46257488189205, 48.90339351469471, 56.92096133385935, 62.35277329721759, 64.49632898453744, 58.45269003222066, 50.53385611503355, 49.96708146987423, 46.39721470494425, 48.67941441074495, 47.19272628907235, 48.1217828104573, 48.38176535021875, 50.132146573835804, 50.49879404806322, 50.40731653090447, 57.948998866542695, 59.659014978716456, 60.52698450703775, 61.99131511872815, 50.50960410025812, 62.66770432072302, 62.909412537851644, 63.88445100476665, 61.17201435950495, 62.86175966262818, 60.63791698025119, 63.55754890749532, 63.76842729506954, 63.477983628549886, 58.722682460661865, 64.06042422017744, 47.47941232496693, 44.065247966397195, 63.1434799778846, 55.72947471372543, 58.654095895828746, 53.02165077578638, 57.230295135128884, 59.14064238148352, 57.501209320560584, 52.73068935640397, 54.65652604256907, 60.49056922235797, 56.547116310365745, 59.94135502846011, 59.641650645963615, 56.72721978156798, 56.48095377029912, 51.677356458479366, 51.13850908894693, 53.175831302519775, 57.37566994082544, 50.41858157803936, 59.416679182360255, 58.947387203093506, 50.142219220438314, 46.38030928950156, 45.53538368594262, 46.08675126106509, 46.32833788471837, 46.98577419404061, 46.73849228889712, 45.77664475287161, 47.87512848454137, 46.706003296759825, 46.33330360535653, 49.170918772297526, 55.32247781753541, 56.66838815135341, 60.31139927525675, 62.46943243088261, 59.91082722140897, 58.32657014170001, 59.47936650245421, 61.22582143352878, 59.59317407300396, 58.83963969445998, 57.67826511013893, 56.72952221285913, 56.22060252774147, 55.67525971320368, 60.332207449020885, 64.48721731862715, 67.19698675217168, 55.501318285542155, 60.66329079289591, 17.770855042242236, 1.2258409444362888, 1.8210813331027187, 0.804643658620696, 0.7310692485301726, 0.17677619812950013, 0.03666767617687583, 2.3084504133270634, 59.79991043767622, 33.28807700064875, 31.346007585525516, 46.283418901505016, 56.1570954322815, 38.366432420669064, 18.50863914335928, 41.685279261681345, 55.09601977563674, 53.93082872513802, 49.38203250208209, 2.568144658880849, 0.13338922222535457, 0.08991010126567657, 0.03634375505029194, 0.0703046702209019, 0.06646454724813662, 0.07428655010317603, 0.02080963890729172, 0.07889770226733339, 0.02877337760442207, 0.028397448683878588, 0.038014405121606205, 0.016696987816342906, 0.02680725699681188, 0.07077635055588138, 0.05053122460301365, 0.03702814735832714, 0.03626920703438021, 0.0359786605282176, 0.055277928364493197, 0.06282384462294079, 0.049771273043006665, 0.046544181288129864, 0.08036636942697149, 0.067385645403016, 0.015750367442266117, 0.11478125297975157, 0.08023287860616561, 0.31868516076957026, 25.157558648817, 92.53775735055247, 75.76297252408921, 68.94627755688083, 38.362843451961396, 30.456365000817087, 19.016248756839385, 46.163974885017645, 33.69355986195226, 75.78955050437682, 15.647026915704052, 0.42998459009874257, 1.812839085055936, 4.058412678780095, 2.270629204088642, 7.54126460321488, 11.09854252107682, 1.050445298033376, 24.579024737881078, 83.14776789757514, 81.37306013414937, 76.28965270134711, 76.67316636731549, 75.69636283382293, 74.06201316464332, 67.48882678247267, 64.7081958093951, 72.51157868293025, 73.11002254486084, 74.16104516675396, 76.9341608785814, 75.72125419493645, 73.51761956368723, 70.688170771445, 70.15153561868976, 67.09125534180673, 54.59173633206276, 55.81877923780873, 53.21508638320431, 53.49950136676912, 50.68991937944966, 52.676823446827555, 51.35895805974161, 59.346292249618045, 65.19166715683477, 64.75282845958587, 61.40964331165437, 53.736596876575106, 53.49747350139003, 49.123834640749045, 48.4917329203698, 48.568419179608746, 50.543618894392445, 49.22053283260715, 50.8462336755568, 52.60227880170269, 53.985318291571836, 59.810555750323886, 61.34601070034889, 62.68762996119838, 61.501238499918294, 52.24082846795359, 65.27049895255797, 65.14486151356851, 63.75282410652407, 64.57803587759695, 65.27627660382178, 64.55865152420537, 66.06720293721845, 65.59256868977701, 66.05594573482391, 61.21442302580803, 67.76865651530605, 50.340906881516986, 46.43076273702806, 66.85370091469058, 58.38252667457827, 60.04218739847983, 56.40910379348263, 60.21271636409145, 59.09491146764448, 57.46124036850468, 56.05698870074365, 57.343930121391054, 61.74391946484966, 58.516126525017526, 61.02066970640614, 61.65310482825003, 60.982885514536214, 58.075507071710405, 53.92680045097105, 53.25829521302254, 57.03904428789693, 60.53654332314769, 53.54155309738652, 62.442199414776226, 62.20494308779317, 52.05353921459567, 48.65469955628919, 49.07597780227662, 47.27946950543312, 50.3563767094766, 49.411513036297215, 48.638641372803725, 49.17597470744964, 49.528768370228434, 49.26249434871059, 49.34500140528525, 51.46378732496693, 57.04989748616373, 60.06448215053928, 62.20688466102847, 62.99777177072341, 63.01745030187792, 60.34295474329303, 62.19923211682228, 64.30753354103335, 61.791195792536584, 60.25844727793048, 60.06077158835627, 58.61000061035157, 58.0222059834388, 58.66137189249839, 63.261672758287006, 68.33496047604469, 69.98927500940138, 61.42174382363597, 66.34439683729603, 23.24266733661775, 0.2610708749102008, 0.6543393529230549, 1.8258477483064899, 1.2305112615708382, 0.48215468744597134, 0.04910350867336796, 1.4877594190259136, 62.26350799683602, 42.1046551581352, 41.506552542409594, 67.2668912333827, 49.78384402490432, 38.634138107299805, 29.06175255775452, 49.16218757629395, 64.18180588752993, 61.043035061128684, 65.16701898267193, 5.377898985339749, 0.19396299766677041, 0.0773973037458716, 0.0836421460694363, 0.08352948517929162, 0.0843149551280564, 0.012840940748461553, 0.05473091477347959, 0.020473341630291075, 0.05637102474969241, 0.033781466735226494, 0.1465535085768469, 0.05213715173604508, 0.009662536754002495, 0.0697819837519238, 0.14894834539342314, 0.10910883155320922, 0.15171701779528973, 0.1796162239606342, 0.17146221392097014, 0.14591284456752962, 0.1257438562630165, 0.16332757058403186, 0.17582986503839496, 0.16585196819036238, 0.15221857555931614, 0.25943533847889594, 0.22405080977947484, 0.7730246359302152, 29.62434595631015, 107.71073249078567, 85.18566669956331, 80.8569154431743, 47.536063117365686, 34.28384519392444, 38.37073133837792, 60.523415150180945, 41.7208198578127, 87.81718484817013, 20.253091704460886, 0.5360502293032985, 4.314063941278766, 12.025354466130658, 4.182064908166086, 18.208919071382095, 44.32096296741117, 3.6691453860652063, 27.34215213406471, 87.93575809847924, 83.74258748946652, 80.47777914231824, 79.5065845981721, 75.843365423141, 77.62893030720373, 69.37449839807326, 68.05167121271934, 72.04952347663142, 77.15706133073377, 77.58638043557444, 79.85919783192297, 80.67831423974808, 78.82453149364841, 74.65396942630892, 74.0353802711733, 71.09754854632963, 58.485304540203465, 57.77904648934641, 54.879461796053, 53.8687179934594, 55.183869100386104, 54.584024952303984, 54.08539756651848, 62.27366301321215, 67.68641225753292, 69.21482655309862, 64.63366293138074, 55.41024477251115, 57.39725474388369, 50.687028592632664, 52.29848338711647, 52.64804501687327, 54.49360647509175, 51.47923754107568, 55.47217899753202, 56.44968071291524, 55.306866784249586, 63.46802473068238, 64.73058469833867, 67.58294797712757, 64.1481597961918, 54.02902526240195, 65.28416056786814, 68.11601377302601, 68.53655461342105, 68.15783408380324, 68.6194029162007, 65.98608832205495, 70.30183299895256, 68.68050559874504, 69.61093887206047, 63.83517819066202, 69.93696628078338, 53.65922812492617, 49.192578100389056, 67.58346572999032, 62.444752877758404, 62.93868910881781, 58.95074867433118, 63.26694050142842, 63.16502163487097, 58.960633047165416, 56.36901717032156, 59.72868411771713, 66.42365224899785, 59.11337406404557, 63.288003629253765, 62.607327276660556, 63.45826979606383, 61.43503281377978, 57.685996101748565, 56.8258281677, 58.54605028706213, 63.76051979680216, 54.72487726519185, 65.4229457916752, 65.91314008159023, 54.906906620148696, 50.9772212274613, 51.287708205561486, 49.724643691893554, 51.975393833652625, 52.20259712588403, 50.34717875142252, 51.160701859381895, 50.924084878736934, 53.799676433686294, 52.65262634523454, 55.20163351489652, 60.899409632528986, 63.36927513922415, 64.51507399159094, 67.79474027695196, 65.60262564689883, 64.133823533212, 65.4642758061809, 68.51505218013641, 63.78123775605233, 63.87946567227764, 62.60596229184059, 62.80838797169348, 63.76349295339277, 63.433574553458925, 66.72048153415804, 72.83868866582071, 72.93933668444234, 61.32420624456098, 65.8414077758789, 23.96153384639371, 1.9781457825053124, 8.841537179485444, 7.757783849393168, 3.0337608869998687, 0.7199470001843669, 0.14211784417350448, 3.377317858319129, 71.64740208656558, 48.9370592178837, 43.37997459596203, 54.02134133923439, 68.32644108803042, 45.64654365662606, 28.776325602685255, 55.72178294581752, 74.54132679970034, 70.5169750029041, 76.8593220556936, 7.039174254863494, 0.26418493039185004, 0.4556350217711541, 0.1322130934004822, 0.2694249717939285, 0.15478403547838812, 0.11713416946511115, 0.23921662340721778, 0.17698739324846577, 0.15228413736387608, 0.17030326078736013, 0.29944915264364214, 0.19607165467835244, 0.0869586862503521, 0.14754527068186193], [0.0851967376506617, 0.028174013395102757, 0.03849486865463757, 0.022544506298858794, 0.02067067438826686, 0.057677518756639574, 0.08867693719484153, 0.02395064727733693, 0.036431587030810696, 0.052923835934169834, 0.04411341111746527, 0.044304316397756345, 0.025454244215882597, 0.04868141337928753, 51.34328426853303, 78.80180528087001, 64.42635390066332, 54.68465335907475, 29.002269814091346, 34.48540795233942, 56.190286528679636, 45.15198769107942, 50.44466141731509, 72.99489313556303, 2.3002104941875707, 0.030896469627717332, 0.24662909097969535, 0.9301769709394825, 2.966968071076178, 2.20467209815979, 4.24269788688229, 0.4498067167737792, 41.19989379759758, 79.67247732224004, 80.56534997878536, 76.41835351144114, 72.99131593396588, 72.74823096490675, 74.40045095259144, 69.10857738987093, 66.09530279713293, 69.993864182503, 69.42952925159086, 72.82191661096388, 71.00516888403124, 73.19134896801364, 71.92909886760097, 70.37602855313209, 67.93463553151777, 64.04629976518693, 51.780550095342825, 50.54297170331402, 50.22319655264578, 49.423311525775546, 48.529928961107814, 50.05778628010904, 49.80164766311646, 53.81291835538803, 57.78135284300774, 56.215852537462794, 54.42319993049868, 49.85640787309217, 48.72257224975094, 46.60621035483576, 45.244755668024865, 46.88290219153128, 46.232416322154386, 45.724830242895315, 49.2523471770748, 47.46577816624796, 50.994809135313965, 55.85646929279451, 59.57083617487262, 63.28947451806838, 52.39736241679038, 53.395923337628766, 64.71638964068505, 56.52929306030274, 60.928631290312744, 56.06557476905085, 59.227613095314275, 62.364509028773156, 63.25198450396138, 57.17037700837659, 58.92757923372331, 55.38649482111777, 68.64624761766004, 48.10321431006155, 40.61370734245547, 63.42461193761518, 54.713584761465754, 59.94814072885821, 55.911523680533136, 57.52214693254041, 55.50490333187965, 54.58960256268902, 55.24233202780447, 58.282667052361276, 57.84269479013259, 60.49448767016011, 59.543297213892785, 56.87522257527998, 57.21298571555846, 58.25110373958465, 56.471771501725726, 54.301626067007746, 54.19957383986443, 57.17863359758931, 50.34751607525734, 56.14347696304322, 60.7547055521319, 54.09699209274785, 45.25681695630474, 44.90109328300723, 45.792400913853804, 47.429092238026286, 47.77966191691738, 47.67725667645855, 47.10520252104729, 46.43386140946419, 47.99600416614164, 46.204853826953524, 47.13397310626122, 50.03047873896938, 55.6951775089387, 57.86319701902328, 57.691326602812744, 56.20372456888999, 55.03217535634195, 52.752360451606016, 55.789204566709465, 54.97998037645894, 55.33222882978378, 51.34829705761325, 56.192337928279755, 53.94416086135372, 61.43950823814639, 63.617078719600556, 67.07363605499268, 64.42653432969125, 71.13603484246039, 63.87347229065434, 74.90724471307571, 17.58488174407713, 0.3286058768149345, 2.2502348403776846, 0.5334712709150007, 0.32747506975166263, 0.02601391357940532, 0.035309429100203904, 24.66961972175106, 69.3589501227102, 30.107291706146736, 13.444638617577093, 59.26044333365656, 83.73846115604525, 27.108453396827947, 28.462630125784106, 48.50814803954094, 47.297414348971465, 59.80442900811473, 9.091838329069077, 0.5801686812793055, 0.14108947838746733, 0.06289591051397786, 0.05837837046372795, 0.021050052619689417, 0.031551899981775114, 0.07209643496260529, 0.06707957029462823, 0.02243644576669941, 0.04169814656638811, 0.05563723126185998, 0.05511599269905879, 0.059265354723339124, 0.023711363544627547, 0.04883236717432738, 0.01438279324511607, 0.035289526135931094, 0.011644431111973622, 0.024227044139538082, 0.04757308716615362, 0.05015360454337732, 0.023846484217492324, 0.09216672049895411, 0.011782119136994645, 0.019247386446823517, 0.06268685661076058, 0.02180792425098198, 0.15226178291824558, 61.089122910653394, 85.69516689546647, 74.16845844637963, 64.32782396193474, 42.52580788827712, 39.468061462525405, 45.67120359789941, 49.40533138090565, 57.07885634514594, 81.34282650486116, 1.9662339120141923, 0.08869510880040546, 0.7469513543671178, 2.3768286022447773, 3.4217372296317934, 6.463857668061411, 3.950928704392526, 0.8956781930981145, 42.7775965967486, 81.00180779733967, 79.43513470311319, 78.65302978023406, 75.22549013937675, 76.5307451063587, 76.46806563100508, 69.72795886378135, 68.77866683467742, 72.48158039585238, 72.60195793644075, 76.14357579138972, 71.69849488043016, 75.46322499552082, 74.07570223654471, 72.64670433536654, 71.6323950982863, 67.90416656001922, 53.36913354935185, 53.01642617871685, 52.43071040799541, 51.339338364139685, 51.222283071087254, 52.43959065406553, 50.482680951395345, 55.310910747897246, 61.782476363643525, 58.7839694946043, 56.85817203214092, 54.244469288856756, 50.83119530831614, 48.71697894988522, 48.10470481072703, 47.8403135268919, 49.180371684412805, 49.43875781951412, 51.03012223397532, 50.315415397767104, 53.825046323960834, 58.95276085022957, 64.02729195933189, 67.9734669962237, 56.306988808416556, 54.605900010754986, 67.42318984000914, 60.110766118572606, 64.28028875781645, 58.68263898357269, 62.0989449562565, 63.97983520261703, 66.4976046162267, 60.15671668514129, 62.20590799085556, 57.8822793499116, 70.00644714601579, 50.677913004352206, 42.03291893005371, 65.96016145521595, 57.568344608429946, 63.491598175418, 57.76101927603445, 60.97193033464494, 56.187148632541785, 56.67753511859525, 55.36167798503753, 61.403375364119015, 59.10933010039791, 61.352674807271654, 59.978103714604536, 60.066023642017, 60.206699448247115, 60.939272680590236, 59.41647521911129, 58.49002315152077, 57.627588087512606, 58.79357145678613, 50.736623041091434, 58.108933510318884, 63.44643992762413, 56.29609246407786, 47.91269302368165, 46.935720828271684, 47.55662810417914, 49.78389893808673, 50.4986410756265, 49.24618121116392, 47.42856664042319, 49.72666371253229, 48.78809544347948, 48.809758693941184, 48.907311962496856, 52.99300570641795, 56.94771974317489, 59.03824498576503, 59.91901713032877, 58.12152824094219, 58.39750620626635, 55.556317760098366, 58.26256882759833, 58.37069680613857, 59.513079274085264, 52.647425282386045, 57.985347470929554, 57.26494143086096, 64.71227899674447, 65.59208231587564, 71.04663618149297, 66.34646000400667, 72.97917227591239, 66.9544901386384, 79.1107468451223, 23.990506433671523, 0.08025523305179612, 0.6440716909785426, 0.8935894084072883, 1.3790012872026813, 0.20090065926553743, 0.06000707339074823, 23.778561161410426, 77.40398237782141, 32.71664650209489, 12.37537109082745, 55.64603805541993, 68.00803092218214, 34.86534833908081, 39.22397236670218, 55.071657934496486, 54.03906260767291, 70.68018482577416, 14.966638857318511, 0.7110262433848074, 0.13802284374833107, 0.07488495670258999, 0.05945687287396962, 0.08303446214525931, 0.04797553230497626, 0.02930408884440699, 0.04340314035934787, 0.04220024825284078, 0.05844984263662369, 0.02716208977114049, 0.03821522741007709, 0.08893777481130055, 0.026956081067422227, 0.16308853582989785, 0.20640303981640648, 0.12245006889345185, 0.17283003326625596, 0.14690485182068042, 0.13562249109870003, 0.20241078710363758, 0.24649920843301282, 0.2136193275932343, 0.2270111880235134, 0.14265939172717834, 0.11293852806932504, 0.17920242922921337, 0.4234714944276118, 70.21686661627986, 95.66326664340113, 82.12903422694053, 73.41733240312146, 43.51996790978217, 49.55877450204665, 74.80221932934177, 61.89330685523249, 68.65071911965647, 88.45083590476744, 3.124349497018322, 0.12660513827276806, 1.3622018983287196, 5.987375493972532, 10.544972535102598, 13.749012581763731, 12.007435117998432, 2.058398089101238, 48.24665146489298, 82.1260924493113, 84.49117968159338, 81.29856647983675, 77.33988300446542, 76.96331193370204, 80.41479372209119, 73.51559562067833, 71.8925266881143, 72.03541078875142, 75.23823784243676, 77.9230845359064, 76.26170973623954, 77.15135035976287, 78.79599232827464, 75.03170151864329, 75.30384340593892, 68.3178589420934, 56.159852858512636, 55.597020195376494, 55.36991104002922, 53.40282670913204, 53.6366823411757, 54.356445112536036, 55.182602174820445, 60.326806345293605, 65.14018212595295, 62.02011708290347, 60.11724587409728, 56.414936357928866, 54.53860782807874, 51.73636067298151, 49.81290094314083, 52.99912460388676, 52.30819125329295, 51.63118231681086, 54.75662885173675, 52.34972130867743, 56.26622361521567, 61.99463344389393, 65.36640874801144, 68.75454425811768, 58.36116936899001, 57.82291819972377, 70.83856228859194, 62.89838283292709, 67.55632292839789, 59.55756679657967, 63.788749094932314, 67.91138372113629, 69.2690964668028, 63.672584179909, 65.75311522330007, 60.67947056985671, 73.21326717253655, 54.86530596210111, 45.733279028246486, 67.7514216207689, 62.86411700710174, 64.78006147569226, 62.629735777455, 63.48544005424746, 58.12296775079543, 57.005351128116736, 60.492981480013945, 64.54183632327666, 60.97526827166158, 64.01016296878939, 63.69467889108966, 61.10016830505864, 62.68024021579374, 63.733451520243, 64.06038499647572, 60.497637333408484, 60.235117020145545, 62.382406803869436, 53.496312479819025, 59.69742282744377, 64.84318417887535, 61.06705173369377, 50.5769355066361, 49.86154225564773, 49.21466104445919, 52.237004157035585, 52.22704525916807, 53.522443309907, 50.65894049982871, 52.55845808213758, 53.60736654650781, 53.91840265643213, 51.52226594186599, 54.33486423184795, 60.574296136056226, 63.16462155311339, 61.800338837408255, 61.2069038421877, 62.066138252135254, 58.21300968047112, 60.859048443455855, 62.714368758663056, 64.4688763157014, 56.384369327176, 62.16855133733442, 59.1880795263475, 68.15118958873134, 69.28155391447007, 74.25588023278021, 68.79191660111951, 74.51732189424577, 67.89431356614637, 84.75949333560082, 23.68569708639576, 0.885242420819498, 7.5903310025891955, 3.769687745840319, 1.8509842575557771, 0.21962101360963238, 0.18039129043538726, 31.516679717648415, 85.33087284334245, 44.384156273257354, 19.197876068853564, 73.5982556496897, 99.051849303707, 35.61626649671985, 43.28380984644736, 66.2306010338568, 63.59296398778116, 81.49751693971696, 21.172771799948908, 0.9842956895309111, 0.3125369680985328, 0.18494531542303103, 0.23170267982829004, 0.2948393258115938, 0.16155049174783692, 0.18789109203123278, 0.15016997984099775, 0.12894693882234637, 0.19817956092376865, 0.1684719122826092, 0.1592988520860672, 0.1777815199907749, 0.11039913812231635], [0.02324531395589152, 0.019575465515616442, 0.06219768265803015, 0.05207751179113985, 0.04905831714671466, 0.02014031171828749, 0.0241131134586589, 0.04879951349369461, 0.07273142226040363, 0.13642812448163188, 0.03324220212356698, 0.011899183117484134, 0.12197465004940188, 1.7602915821536895, 62.71062681751867, 68.1224464601086, 66.93920073970672, 54.536156346721036, 21.194111454871393, 30.533235611454135, 36.991363186990064, 26.914570639210364, 73.1529175850653, 42.46100248829011, 0.2643902113120402, 0.051976288593704664, 0.5191590324524911, 0.7339790343276916, 1.6103171845597606, 6.622005181927835, 2.837686505048506, 2.6435907137009407, 50.667126486378336, 79.40384203387846, 74.39870942023494, 75.32107045573574, 75.53385119284354, 76.6529740056684, 73.85023655429964, 69.77739641743322, 63.999137186235004, 74.2208299329204, 72.08680952748945, 71.39343646264845, 70.91472687259798, 69.8558359761392, 68.22554203771776, 68.2916182856406, 66.68516451312651, 59.71147667977118, 51.34706543337915, 48.81991371031731, 50.92608920989498, 49.929081547644834, 49.900342341392275, 49.165572581752656, 48.615715119146536, 50.76140065346995, 52.64755079823156, 55.34136795228528, 53.274675030862134, 52.511358261108406, 49.08104550453925, 45.81642543115924, 46.514834819301484, 45.031461100424494, 48.05966423403833, 50.30874344610399, 52.851737622291814, 49.59764911282448, 54.624621483587454, 59.85961283406904, 53.74622237297797, 58.822969621227635, 59.013455606276, 59.79348951770414, 60.754113274235884, 57.195060483870975, 58.53660129731702, 54.48460463554629, 54.017124791299146, 54.983930203222464, 58.626894258683734, 53.93825769424439, 54.05033157717798, 56.65163178597727, 66.23889292440107, 45.639934462885705, 37.158926840751406, 57.145438578821, 54.18010319432905, 61.100925322501894, 55.37124464588781, 57.269460001299464, 53.38612133456815, 57.33234343990203, 54.28871362440048, 57.431571560521284, 55.1257787981341, 59.88741851622059, 58.29559518444923, 60.102403625365234, 56.451771336217085, 57.427272642812426, 55.473791091672844, 58.698312774781265, 55.4853856179022, 60.14034863441222, 43.147366277633175, 55.6920749141324, 64.19445160896548, 58.12352864973007, 45.86855765311949, 44.36551324782833, 44.44355272477673, 46.10874006825109, 45.88222711317001, 47.56801866715955, 49.261882458963704, 45.59039492760935, 47.08244100693734, 46.03828253284578, 45.31885708532026, 50.54032018107753, 50.9636890503668, 53.89442520756876, 52.889337462763635, 54.25566373332855, 51.571695650777514, 52.532664575884425, 50.3907915853685, 51.249433717420025, 52.04812634375788, 53.10884898708713, 54.530680717960486, 60.98267370654691, 61.63298699163622, 64.40107422490274, 66.18205778060421, 68.24875462439753, 67.1609244808074, 66.2586695148099, 62.54570684125347, 76.51216091648226, 14.132804736014336, 1.3892264159456378, 0.8003693782994825, 1.1051488787897172, 0.1162037326984348, 0.16569861270967992, 4.051839766963836, 58.551784792254054, 61.54978959791122, 77.42602609818982, 74.9224635093443, 97.4784532670052, 24.048355510157926, 21.31747195797582, 46.008809843371, 52.234866465291674, 59.052879348877944, 17.6288220959325, 0.30786806056576393, 0.13245439577487209, 0.08132658403126464, 0.08535246800390944, 0.025709445340438716, 0.051943760500439716, 0.02300227639235316, 0.013573288245336905, 0.05958450312215475, 0.009271254473846526, 0.04908169431972408, 0.04848494247022656, 0.027440488038043824, 0.07456474727199924, 0.06680584707928282, 0.05750239871802831, 0.04510761321251912, 0.042028966314730146, 0.11724835487022517, 0.016350970798802954, 0.0538312211152046, 0.04987026309414257, 0.0836281496430597, 0.05364557502851371, 0.03874864294043472, 0.024143170918368047, 0.03506689715469557, 3.4567411964939487, 76.71111922110282, 73.26941982392343, 76.5186014483052, 60.473424542334776, 34.0917706489563, 31.77234765022032, 33.78309580587572, 35.53712875612321, 79.93422492857903, 45.24449286922332, 0.13825319106540374, 0.014569308841601016, 0.8684525927228313, 2.5993373076761923, 2.3040669195113646, 6.951386217148074, 4.487400343341212, 4.4354431571499, 53.79968035605646, 82.0495826967301, 74.95492504489037, 77.60277594289472, 75.99348237437587, 77.61681802811162, 74.21196537633097, 74.3634786913472, 65.61819353411275, 77.85642777719806, 74.10704197422152, 73.86994254204535, 73.2255441911759, 72.14866530510687, 69.72104764753773, 71.47240161895752, 69.42901934346845, 60.57116608465872, 55.31498216813611, 52.54537305524273, 53.11798810958863, 52.34466145115515, 52.767410585957194, 51.408262252807624, 51.4817557027263, 51.63895253212222, 54.942353079395915, 57.248851868414114, 56.108293302597545, 54.01139420847739, 51.20673871809437, 48.8052793472044, 48.17700586011333, 47.25292290410688, 50.96681125702397, 53.15071244393626, 54.93138221002395, 52.13872132762786, 55.818124201989946, 62.366168191356046, 56.993768368997884, 59.69161771958875, 61.4156327709075, 62.642448179183475, 63.7222021625888, 60.96093985342211, 61.487988733476215, 57.0998174913468, 56.76918914241176, 58.114691549731845, 62.13859619632844, 57.22072847427861, 56.53108950584166, 58.70108589049309, 69.42896443028604, 48.612722350705056, 39.411512651751124, 58.750354782227554, 56.678405884773504, 62.631610670397365, 56.98009106420702, 57.328009220861624, 55.99068495535082, 59.88295093659432, 56.37998803969353, 60.66007444935461, 57.52042893440493, 62.03692051672167, 58.96088015648627, 61.20404443433208, 59.62285464809787, 60.081418944943344, 59.877094837927054, 60.90086483186292, 58.26004282120736, 59.9600019762593, 47.4282253942182, 56.68516805095058, 65.0476259569968, 60.83583193440592, 48.94903813638995, 46.270298573278616, 47.07381963729859, 49.488211062646684, 48.508069592137495, 49.294751921007716, 49.38164026506486, 47.46308742030975, 50.79605479394236, 48.77692453322872, 46.953618603367964, 52.25880469045332, 52.72849675147764, 55.685983473254794, 54.16813604293331, 56.57980142101165, 54.6959380180605, 54.499482185609885, 53.82491296337497, 54.04653472285117, 54.66427664602957, 57.230024491586995, 58.06139438383041, 64.95216331174298, 64.70884692284369, 66.65880618556854, 67.16103430717223, 70.85085499671199, 69.65605397378245, 68.36069122437509, 65.56526507100752, 80.83768798458962, 18.413658949636645, 0.929628084263494, 0.8258174708293331, 1.7394255534295113, 0.26217450117391927, 0.33068565231177116, 3.3216287820569934, 59.49967261283629, 64.7489139341539, 54.24112742946994, 76.82860989724436, 80.83869211135372, 24.552650720842426, 34.29343931136593, 53.772631691348174, 57.94082464710359, 67.89774956241732, 28.743624802558656, 0.3699152682337069, 0.08071679336529586, 0.09899194337307446, 0.11850205775831016, 0.032908245245175015, 0.00028611726109727077, 0.018232139916489684, 0.03762606749190919, 0.06229619390421337, 0.07431727788981891, 0.05469599265545126, 0.07870243411631354, 0.017971428704538175, 0.03364762734441507, 0.19047185838703187, 0.12008085005706358, 0.17726179062118455, 0.090248221831937, 0.2933397546650902, 0.15362823862702618, 0.12942902263133757, 0.09623508404700026, 0.18546881394520884, 0.34344061788532043, 0.153044969924996, 0.1370051878714754, 0.4531968703433391, 4.884474623587824, 91.68811705804642, 84.58281409355902, 84.64173593828755, 70.0000693721156, 32.3478279959771, 45.115058575907064, 51.1429335225013, 42.30412337087816, 89.76482991249331, 51.16409470958095, 0.6857838914279015, 0.1497624517087975, 3.3160080256000644, 5.8418786045043705, 6.6510150317222845, 15.384251648379912, 9.540797721955085, 5.739410115826515, 57.81527350025793, 82.66937994187879, 78.4038023794851, 79.95160887318274, 80.49367258625647, 80.01961492723035, 78.68172584041473, 75.28820099369173, 68.15572384865054, 78.69274770059894, 77.57207162918584, 76.26123120707851, 77.63218587444675, 75.75209971397155, 72.73982140325731, 74.87077451521351, 72.14335441589355, 64.00705252924274, 57.75062891744799, 51.90828600237447, 57.176754782276774, 54.85974011882659, 57.19763355870401, 54.12301309647099, 55.337280842565725, 56.51907920837403, 58.990105736640196, 60.71090444441765, 59.535005323348514, 58.100802436951675, 56.36291396233344, 50.27749784531132, 52.1334457397461, 49.134444652065156, 53.975284868671054, 54.27600122267201, 59.00639141759565, 52.44461521025627, 58.68958942351803, 64.37684966671851, 60.08213673868487, 61.91660573405605, 63.93323352259975, 64.99240290734076, 65.71213822210989, 64.95419902186241, 63.562542084724676, 59.52699584345664, 58.49162740092124, 61.04798509228615, 64.06354250446444, 58.608098260818, 59.230554872943515, 62.530739076675914, 72.68922282803443, 51.36826192179034, 42.17661496131651, 59.02841552611321, 59.6954498752471, 64.83799880550754, 61.41595440526163, 59.21380635230773, 57.17536626323577, 60.43589922689623, 59.80289536137735, 62.33187883130966, 58.26267473159298, 63.709552518783084, 63.43133095772036, 64.4877193820092, 62.678569286100334, 62.06374952870031, 61.338393457474254, 62.852604850645996, 61.98185436187252, 62.980595711738836, 51.476385977960405, 62.22946966848066, 68.86043256328952, 64.54562141049293, 51.48153997236683, 48.111149264920144, 49.64304662519886, 50.331708923462905, 51.91778206056165, 51.20973540890602, 54.74701120007423, 49.02524978883805, 54.901336854504, 50.46726603661814, 50.66620080701767, 57.44489585199664, 57.10523428455476, 59.68530662598149, 57.76562413861675, 60.55060502021544, 57.692573916527536, 59.02486578110726, 59.49520111083985, 56.71758644042477, 57.988881526454804, 59.64363928764098, 61.21963193339687, 65.30419995707851, 68.04635247876568, 68.36436256285637, 70.4666353041126, 73.48445984625047, 75.29449247544812, 70.1013449699648, 69.86811299477854, 83.42391844718688, 17.679622673219253, 2.787308563147822, 5.434842974908891, 3.3487254957998958, 0.5048229226902609, 0.24847830465484053, 5.635299134639002, 71.37928455106675, 80.35804487043812, 102.45460740981564, 81.03426933288574, 108.7363773776639, 33.73805522918701, 32.25801552495649, 60.894490980332904, 66.57236499171104, 76.78020000457764, 37.77268363583473, 0.4455408021326988, 0.30859608924196613, 0.16764649850947244, 0.17814942605553136, 0.1756820253907673, 0.1857247945642279, 0.09217915410596518, 0.10629935730849543, 0.12440954560353873, 0.11921363852677808, 0.13268953880235074, 0.4035825035985439, 0.20028483182672532, 0.1895323281566943], [0.10949224323755312, 0.0565743712978738, 0.024731352159212676, 0.06368415753146814, 0.04319556117538483, 0.04882710415028757, 0.04633898080717172, 0.09751225986908521, 0.09012915644674532, 0.06445896736676655, 0.07497893270826148, 0.17800644340534366, 0.4228865709756652, 11.885317025646088, 73.41713628461285, 62.09620714187623, 66.98728115327897, 27.77029452785369, 27.771394752687026, 37.33734761514972, 42.169452713381865, 44.30140210736183, 89.40837275597357, 15.611310793507485, 0.10721616537099886, 0.08288098409050897, 0.47696002909252727, 0.7231019954046896, 1.2722826652949857, 8.672693852455385, 2.810056348962169, 7.354563705382809, 65.101919404922, 76.92834792598602, 74.61055663324173, 72.27338098710584, 68.21476336448424, 71.89993996773997, 73.24190047479445, 73.03194384421073, 63.363489643219985, 69.58302728591427, 68.08360715066233, 69.86106057320872, 65.48664116090345, 65.40165516637987, 64.89621462360506, 62.00470609049644, 61.60962143251973, 55.35667304069766, 52.36735236260199, 49.45623982337214, 48.6355701569588, 50.312512843839585, 48.7938456381521, 47.78379217270882, 49.0419473186616, 47.80350992756505, 48.02459432232765, 48.94411948419387, 51.914153868152255, 46.11752225506691, 44.74534773057507, 45.02261223331575, 45.02964896540488, 47.088026462062714, 49.053502621189246, 49.63488417287027, 50.634268791444846, 54.6637902721282, 56.103625682092485, 62.24906582986156, 54.21716174771709, 48.66075961820541, 62.24362550243255, 58.2308368529043, 61.810446785342315, 52.7449667838312, 55.263367699038604, 49.76488720986151, 51.85722066510109, 48.68013220448648, 51.42934499248382, 49.427100535362, 61.43246758368708, 56.99705531520229, 66.3290289909609, 43.05263711560158, 33.346045709425404, 60.736227266250125, 54.072877360928445, 61.46131269393429, 54.28176318445514, 58.43652986711072, 51.99454284483387, 54.12768463934622, 53.03007602691651, 59.82131873407672, 57.693589810402166, 60.35354122038811, 55.603527407492365, 58.159885098857266, 53.97711269317135, 57.22110502181515, 54.872252479676284, 57.45885948981009, 54.22511631442655, 54.18156231603315, 47.98848106015114, 50.300937929461085, 62.31907621506722, 59.395070845080966, 49.624929197372936, 42.764644930439616, 44.62040847347629, 45.25256902940812, 47.35577529476535, 44.817789985287575, 48.34309862506006, 46.02586430888022, 45.042086801221295, 47.09851880227366, 48.10072360500213, 47.52844195212088, 48.32556955275997, 49.66664360415552, 48.2855966783339, 48.51768724380001, 49.48397098049041, 48.64436018851496, 50.392309542625185, 51.15147252236643, 54.487679773761386, 55.131850627160844, 61.53823821775375, 62.92804771854032, 65.68886287750738, 68.01350655094271, 67.26089000701904, 68.0679412041941, 65.95764329356533, 65.09463556351201, 67.83816091475948, 67.62000653051561, 66.37304582903462, 3.3542440254842085, 0.6657793745398523, 0.9811895400766404, 0.9268750706987997, 0.1423254233574675, 0.008124611415569822, 29.82312971545804, 65.88533832180885, 41.34753573325373, 60.499829938334805, 51.01831589975665, 31.090604412940245, 16.110726575697623, 29.958592691729148, 45.28527375190489, 52.06038767291654, 41.61020901895339, 0.35634791238173363, 0.09932402716649157, 0.040527732757430886, 0.014975377576305501, 0.060590081622884165, 0.04222180213659041, 0.05360397645422528, 0.09955838878428745, 0.04820134438153717, 0.01521213321886476, 0.04179756562676161, 0.04133819632472531, 0.13083035066243143, 0.0432045933520121, 0.10525673462618744, 0.02246918836458316, 0.0344454198174419, 0.0494469458898229, 0.058477065571013, 0.03760149139129827, 0.041795933859482895, 0.017146348179648482, 0.020077858315480333, 0.043231513681671316, 0.08506629585979447, 0.1734759219952168, 0.36049741230184035, 17.203386137562415, 87.2263111606721, 69.98160285334434, 74.13079584798506, 34.282950893525154, 26.55350469773816, 20.103612138379006, 45.59670602121661, 50.76349519914197, 96.66292190551759, 17.079855011355495, 0.14923450987665884, 0.12081106208385, 3.0922779921562444, 2.9573830241157166, 5.728616243408573, 13.21435332298279, 1.2144859279355695, 8.979131963945205, 67.41732197423136, 76.36047501717844, 76.5477446586855, 72.40410574020879, 69.95384816200503, 72.04171011524816, 77.58899273410921, 73.39568091977027, 67.24357666507845, 71.71085034647297, 71.24948547732446, 69.94427757878458, 66.8100449346727, 65.8760658387215, 68.08062614933138, 65.17314964725126, 63.4010620271006, 58.83505052135837, 56.194350104178156, 52.623734166545255, 50.85469030564832, 52.57414756282684, 52.202440231077134, 49.39503515920332, 51.51444865811256, 49.79498355619369, 51.399989974114206, 51.541960162501184, 53.62236569004675, 48.35734467352591, 48.032686171993134, 47.09223908762778, 46.79223268262802, 48.5198288579141, 52.32533201094597, 53.94954627560031, 54.34918872771725, 56.349295493095156, 60.04445452843944, 62.97720286153979, 56.75758677144205, 50.13700639047931, 64.99339134462419, 62.27716176740585, 64.30207360175349, 55.530343824817294, 58.26623624370944, 53.03977212598247, 53.272925653765284, 50.38167599708804, 54.07321860713344, 52.101972641483435, 65.7950218262211, 57.88318149505123, 68.64016794389295, 45.28988645922753, 35.43668862312071, 61.37762108156758, 55.21866052381454, 62.0619373936807, 55.769647629030295, 59.704263441024295, 53.49428853681011, 55.84012869865664, 56.09413354627548, 60.71033962311284, 59.43709904147733, 62.123153824960035, 57.27424529290969, 59.60635715915311, 58.10753322416737, 60.898072104300226, 58.1089452774294, 59.57502526621665, 55.87325703713202, 55.58437447394095, 51.17654431250788, 53.77252186498335, 64.07753752123925, 62.10392244400517, 52.26728093239569, 46.539271185475016, 47.3776307413655, 46.76012416039744, 48.67423295974732, 48.085096882235625, 49.478918967708466, 48.305310510819965, 46.96692720536263, 48.74269793110509, 51.17522639612998, 49.44379414281538, 50.253210529204345, 51.32451964962868, 50.80821806384672, 51.74534682304629, 51.55949707954161, 52.72149139834989, 51.52793376676498, 53.08757405127249, 57.87642717361451, 59.04439918456539, 64.68114322231662, 66.32448688630136, 69.12780484845563, 69.0897813920052, 69.88834458012735, 69.86772075776132, 68.880656303898, 67.89496467959496, 70.72025575945455, 70.2877438452936, 73.30703535387593, 5.539716857094919, 1.5269879011377212, 1.0535030307308322, 1.4849103073919974, 0.21406140629081957, 0.06854299741286425, 30.70175240116735, 74.31742222078385, 46.30749833199286, 62.891083302036414, 52.649135435781176, 34.17762348728795, 19.850940896618752, 32.34908707680241, 50.09444475173951, 60.334988409473056, 54.092732398740715, 0.9614011825573061, 0.03009671022394492, 0.031414109492494215, 0.02080139197078684, 0.07554497975375384, 0.03329506602078196, 0.0716469481947922, 0.10479219423066224, 0.0298888475874499, 0.05130358295695436, 0.04378687763105958, 0.036858983653327154, 0.09597521936220509, 0.046168327061159, 0.1824336042327266, 0.15730543002005548, 0.07788693352091698, 0.17428537049601156, 0.09737152951739489, 0.15530017955649286, 0.13772739427945307, 0.22235744903164528, 0.18287954401345025, 0.1857993349192604, 0.19048148045136085, 0.30146457675483923, 0.6983012778143729, 22.489968422920477, 99.62940262209986, 77.64788319987636, 87.19213162699054, 41.76741761545981, 37.610944701779275, 51.61687743279242, 62.31310636766496, 59.51396965211438, 105.64212153034826, 20.80030352838578, 0.2514454704378882, 0.35369914806177544, 3.632014023680841, 5.864284163521183, 8.016723528985056, 18.995395475818267, 10.084078350374776, 10.900481458633177, 70.97286424329205, 78.82369995117188, 78.13406882747528, 75.63191829189178, 72.4947674043717, 76.43933819186303, 80.83200054783975, 76.75890937928231, 69.80113460171607, 73.88532607786118, 74.66076297144737, 74.39171191184752, 69.5595322885821, 69.16798560850083, 71.77221975018902, 67.34726059821345, 68.38196616018972, 61.049632487758515, 58.745718540683875, 54.44743233342325, 52.40184568589734, 55.29425244177542, 55.17702064206524, 51.38464958437028, 53.53008408700266, 52.525286597590295, 54.51720737641858, 54.50807217628726, 58.42136598402455, 51.427285748143355, 49.71898763410507, 49.9292855108938, 49.85074004819317, 51.491643997930716, 55.91167273059968, 56.363380724383944, 57.74432566858108, 60.90874879590927, 63.33436604469054, 65.92183989863243, 58.0019037954269, 50.886202627612704, 65.33558676319738, 65.48671176356655, 67.00249994954756, 58.82011021337202, 62.925855113614, 54.81981039047242, 55.27562510582709, 53.857849105711914, 56.69955530474263, 54.6221503903789, 67.4348706583823, 61.67763533130769, 70.71569012057397, 49.06975692318332, 39.46347621179397, 63.07240270799207, 57.60494424450783, 63.90707523592057, 57.300340821666104, 61.17143777108962, 53.97537900555519, 56.77506485292989, 57.09443992184055, 63.78372846111175, 63.763179163778986, 65.30967950820923, 60.28048315355855, 61.92659993325511, 60.994366292030584, 62.229783458094445, 59.98323025241975, 62.959199182448856, 60.59101327773064, 58.634754688509055, 54.19661245038433, 56.289444046635786, 67.07113358282274, 66.10756412629159, 55.57909496368901, 48.81676012469877, 49.56183787315123, 50.46953316657774, 51.13404150932066, 49.64370166101764, 52.066922341623616, 51.17108045085784, 49.535240281012754, 53.08528730946203, 54.32650173864057, 52.200435899919086, 54.12817493561776, 55.590261951569595, 53.425517620578894, 53.83222426137617, 56.44522097802932, 54.431150574837964, 56.551642725544596, 57.09639718455654, 61.536496685397246, 60.355008186832556, 68.34208350027761, 68.49200433300388, 71.54684036008774, 72.08648004839498, 73.34634534774288, 74.08462955105689, 72.65374106745567, 70.93173426966514, 74.88771130961757, 74.0494929590533, 74.377701205592, 4.9534269494395105, 3.283100565595012, 6.020399399342076, 2.02741259048062, 0.40151740634633654, 0.17641010003224497, 37.58373521989392, 78.96985530853271, 57.6130949297259, 68.72340848368984, 61.35063125241188, 40.84899071724185, 23.70373606681824, 43.18569175658688, 59.779321916641734, 68.50521487574424, 63.319900343495036, 1.497163424088109, 0.301396670721231, 0.1269860142060826, 0.23224341532876416, 0.20764869878128653, 0.11354320892883886, 0.25640674776607947, 0.1904201014868675, 0.1306747275614931, 0.12743809035107975, 0.08766688857107394, 0.1342960098578084, 0.21990385327127673, 0.09333722623846225], [0.07854455105599858, 0.05410301761942045, 0.0950720170212369, 0.030475686259207227, 0.03980511266197409, 0.05194680569993873, 0.0754885803607683, 0.03717309885448025, 0.02694841252730018, 0.03328636326196213, 0.053819136078199076, 0.020581344705856135, 0.050324147206641016, 35.70590834463797, 70.04066590339907, 66.76962098767682, 63.558706006696156, 41.47612279461276, 36.35599020988711, 47.21204788454118, 34.38614845275879, 57.63377366527435, 68.9106781251969, 3.166299491159378, 0.09734277823759664, 0.35358153824363986, 0.1786499879052562, 0.35370922977885894, 2.3977681754096865, 13.887414393886445, 2.287593209935773, 19.501897019724694, 77.06980428388043, 72.41781050159086, 74.20025317899643, 71.90969097998835, 72.98134526898785, 69.65656388190486, 69.15282172541465, 69.02150077204551, 66.42324432249993, 68.19300989950857, 70.92841594449936, 66.02670838755947, 64.74635654880156, 63.37533520114038, 62.292968919200284, 58.425009865914625, 59.83763187162338, 58.47024656111195, 55.33720631753245, 51.76950862330776, 49.525755989936094, 47.183140016371205, 50.7284527440225, 46.17520070845082, 47.58387288739605, 46.978431517078036, 47.166501322100245, 47.2695262970463, 47.11975451438658, 45.495100944272934, 47.72051649708902, 46.700229567866174, 47.72998509868499, 47.66815677765877, 50.2791452407837, 51.06950675287555, 55.45922733122303, 55.93152776841195, 61.16678584006525, 57.79832101637318, 63.64025992731895, 58.65000878610919, 59.28464043524958, 58.53409490277691, 57.97127400675128, 50.59918319025348, 53.26225680689658, 50.61190735909247, 51.439107771842714, 47.12317089880667, 49.68038758923931, 49.45443553309287, 61.91407580529491, 57.17467200371527, 66.5341297272713, 39.500672048138036, 29.677313643117106, 64.73998661964171, 54.89693203280049, 61.553131457298036, 55.40045061419087, 60.563725348441835, 57.89520355962939, 53.279648596240634, 52.84749754013554, 57.10863890186433, 56.53327426602764, 59.04064155394032, 56.277414137317294, 55.55602750470562, 58.166286406978486, 57.651157609878055, 56.95599594423848, 56.509390954048406, 53.479407064376346, 54.81250301484139, 52.957025804827296, 45.88928345711001, 60.10934622057023, 61.91244802167339, 54.13129321990475, 44.794687224972634, 42.160293979029504, 45.00387114863242, 45.35821414762928, 46.601068127539854, 45.529864911110174, 44.86861605798045, 45.06478947977866, 46.05615677372102, 46.88163526596562, 46.32691014197565, 46.53787482169367, 44.801457235890055, 46.495470077760764, 48.064147503145286, 46.223877322289255, 50.30735100469282, 54.34714909522764, 55.292565822601325, 56.83688140684559, 62.69281925693635, 62.906090290315696, 66.63731944176459, 64.99661553290584, 67.22930708239156, 65.90013350209883, 65.77364490878198, 63.079917969242224, 59.34329163643622, 65.06903033102712, 64.0549329019362, 75.18719996175459, 38.46400922344577, 0.15495278932634862, 0.19284389642698152, 0.4514704758842146, 0.01860390706438451, 0.06396420097218887, 4.59326756577338, 64.92760927446427, 52.74166807051628, 47.475768443076845, 34.93027925491333, 19.92297914720351, 34.53388844766925, 31.50413597783735, 49.76597762876942, 52.83878595598283, 50.60194846122496, 2.1583614089796623, 0.07886685956750186, 0.03194294956272408, 0.047298149701448224, 0.04248539766957683, 0.04472366143618861, 0.06688967241995758, 0.0410061470052648, 0.018351406399761478, 0.051213510169257084, 0.03834467328664276, 0.05135118383012953, 0.08323876247290643, 0.05746366148213706, 0.053869096502181024, 0.021066305175003026, 0.05355690418171787, 0.005921306634967726, 0.09319574512060612, 0.0047891292319212474, 0.0867326443474139, 0.02058106125332415, 0.046208627116415775, 0.00901140989885936, 0.04215241755328832, 0.04780349193982059, 0.09921962470417062, 48.74578091406053, 78.66776220260128, 74.97561162517917, 69.8314231441867, 48.343604610812285, 47.51523533175069, 45.790424039286954, 42.09205650514172, 65.7375983268984, 73.7939348528462, 3.0384662603178336, 0.012480117166565071, 0.4593018250119302, 2.9533949542430142, 3.374376080689892, 4.443140318316798, 15.307301609746872, 1.8755704092402614, 22.04769372940064, 76.90690040588379, 75.36090604720577, 76.13992014238912, 75.16557985736479, 74.90737807366156, 70.39724073102398, 70.19461893266248, 72.19069742387342, 69.60743227312642, 71.21193270529471, 73.28263821140413, 69.04089297017744, 66.8665349098944, 67.1290591455275, 64.79589216170773, 61.2141445375258, 64.03131238875851, 60.3345844053453, 59.17023666443364, 54.577890365354484, 52.217372694323146, 49.171601264707505, 51.9889848462997, 47.764297992952415, 48.89235204265964, 48.552427676416215, 49.14268555179719, 48.90790816276304, 50.29039852080807, 47.10746965100689, 50.077543258667, 48.51417280012562, 49.308966590512185, 49.70484748963387, 53.91648069504769, 52.21991046782463, 56.71754329435287, 56.73808082457512, 61.73222687936599, 63.52511090617027, 64.97015914609356, 59.46905066890102, 62.128911864372995, 60.85313743160617, 61.50395278007754, 53.29977035522462, 54.89579062308035, 51.043674022920676, 52.21724717847763, 49.682693942900634, 51.86636370997275, 52.17256353747461, 62.94924420695152, 61.194846476278, 67.33801164934712, 43.00275241175006, 30.641167471485755, 66.47342712648454, 56.72851024135467, 62.7322429995383, 59.93833480342742, 62.47284097056236, 58.26087044131372, 53.69547474768854, 54.76518746345274, 58.67571600021855, 60.69752131738971, 60.405124310524236, 59.62508647672592, 57.634648353822776, 59.774936706789084, 58.43054825259794, 58.80739388927337, 59.73484616125784, 57.121057125829886, 58.45698502755935, 57.3733518200536, 50.16159965145973, 60.84229600044989, 63.97145701992897, 55.97489741540725, 46.785427370379054, 44.97377872467042, 47.198005799324285, 46.717790019127634, 48.58980001941804, 47.76769084315146, 47.946382261091664, 47.42791944934476, 48.80574218688473, 48.464103744876006, 48.75057797278128, 47.52087962242865, 48.57249844458796, 49.4854889377471, 52.35294941932925, 50.70942140394642, 55.03461507058913, 56.538345890660445, 58.887912304170676, 59.180168105709946, 65.3248159347042, 64.44292983701153, 68.76817057209631, 67.42547265944943, 68.31545845154794, 68.3191611689906, 67.76001945618661, 66.09645597396359, 62.690622729639855, 66.37816844447967, 68.98606607990881, 77.70484385951873, 43.00948712133592, 0.10000832754397586, 0.40524528211643623, 1.5605486809246003, 0.2886737582664336, 0.045188312914462826, 4.568303640811674, 68.08725495492259, 61.96174829236923, 53.32697983710997, 39.05425140934606, 14.171743085307462, 34.09690110914169, 39.09419682718093, 57.345302950951364, 59.336890328315, 62.1281744587806, 4.636185159606319, 0.12836831261313733, 0.07405028092644869, 0.04982816656270335, 0.025747341794833064, 0.05233594389151662, 0.0566883230461709, 0.009900272989104833, 0.052968196255425294, 0.022760782495982224, 0.054677016657566836, 0.07007538010516474, 0.07711775060142241, 0.029371278585806012, 0.2721107841259049, 0.12177485431874953, 0.1537254398628589, 0.1343739669649832, 0.191613620507621, 0.09736363115089555, 0.13581016731839027, 0.10794233245354508, 0.12992235261105722, 0.16903935360812372, 0.14229373796091926, 0.15992494510306468, 0.17916017181931004, 57.468120205786924, 88.70952406237203, 84.77253913879395, 81.28509706066501, 55.2277211989126, 51.01218131280715, 73.88367083764845, 49.923021485728604, 71.72821860159598, 79.267210191296, 4.44190526200879, 0.21316175859782005, 0.7003734537190007, 4.816297946437713, 7.639487616477474, 8.209398686885834, 22.262618041807606, 5.072850863779745, 21.747905015945438, 79.45964951669016, 76.5631046602803, 76.89288185488793, 76.9879287289035, 78.75570958660495, 73.85693596255395, 71.37760577663299, 72.9257417494251, 72.36234818735431, 73.49701143080189, 75.75527683381112, 72.95019380507931, 68.71860750259893, 70.25783969509986, 66.91259922519808, 64.15303922468617, 65.983334818194, 64.17253340444258, 61.38403415679932, 57.307146133915076, 55.77682556644563, 51.118077462719334, 56.32532196660196, 49.24402390756915, 52.36859967631679, 51.87379267907912, 50.24006666675691, 51.30346044417351, 51.69291257858277, 50.556758834469704, 53.34306939955681, 51.03509187698365, 52.82369659792993, 52.18200860484954, 56.1862111860706, 55.90338084005541, 60.68578166346396, 60.44845865618799, 64.03270483016968, 66.15264000431185, 64.44270626191171, 61.28092288970948, 65.55234870603009, 63.97495577412268, 62.884662382064334, 55.60546505835749, 57.53250198979532, 55.9274406586924, 57.268193075733805, 52.44631359654089, 53.57360670643469, 55.3744060762467, 67.43772614386775, 64.44869964353501, 69.4479565466604, 47.35921521340647, 34.46923602011896, 68.1358374318769, 60.523434762031805, 65.15426735724172, 63.321896829912745, 64.35434702903994, 61.54096818739369, 56.08767340260168, 55.90676192314395, 61.7623899059911, 62.39756676458544, 64.71767617810157, 62.27108601600894, 61.1313433031882, 62.16044379818825, 63.50920569512152, 62.840053266094586, 60.93053363984632, 58.94219398498536, 61.97581391180716, 58.666274855213786, 52.72371145986742, 63.24218642327094, 66.57443600316202, 60.43378506937335, 47.78677317403978, 48.26505130337131, 51.531507045991965, 50.561477445787006, 51.29578044337612, 51.78069914540937, 49.843793530617994, 50.429501456599084, 53.61872573052683, 51.46830197303526, 52.4010298329015, 51.4674037502658, 52.25461167673911, 53.67428218164752, 56.73604511445569, 51.85387096097393, 57.997757850154755, 59.88616335776545, 62.04044280513641, 62.45338993687784, 69.5298085674163, 66.09536555505568, 71.1995223260695, 68.29663891946116, 73.28543878370716, 69.91704848504835, 73.10417036856376, 70.45588800984045, 66.48469217361944, 70.48718852381553, 71.06493796071699, 80.39718228001749, 46.06819060540969, 0.7791817152211744, 4.806793062917648, 3.5550870289725647, 0.2613529484839209, 0.20839016463968063, 6.383885933506874, 78.41822885697889, 67.26154112046765, 61.199710215291674, 45.77339310799876, 28.300648004777972, 48.5015506129111, 45.4506604902206, 68.06808240952031, 67.07329873115786, 73.00204753875732, 6.316845763114191, 0.42473630559059883, 0.3223660906716701, 0.1534647707857432, 0.22385052375255093, 0.11964384286153702, 0.13172333339048972, 0.15032810038856922, 0.16378466460493304, 0.20319751343659817, 0.20241238056652008, 0.1277229678066027, 0.10366601433845297, 0.17875428311526778], [0.11970398842447227, 0.036127626325093934, 0.05780452464316642, 0.060677584185595476, 0.06044524887035932, 0.05110910387649652, 0.06414697039872408, 0.07568479079993502, 0.07527912426139079, 0.12239605969479009, 0.08092099410151282, 0.10744478899024187, 3.0251767798777554, 68.86271538272982, 68.20986824650919, 66.9664925913657, 58.47430621424029, 22.665751403377904, 14.849114841030492, 23.16567905487553, 39.407609893429665, 82.01358318328857, 41.38943056906424, 0.21764076825591827, 0.08783836969204488, 0.0705207989460999, 3.692421956408409, 2.532689129152606, 10.75739045296946, 6.401692023200374, 0.4981318188290443, 36.20989368807885, 76.59567602219121, 73.69112168588947, 75.87670556960568, 74.4777608686878, 74.13500847355013, 74.04397026185067, 70.6001998532203, 70.71979291977422, 65.60926621960056, 64.96192609110187, 68.67733632364582, 68.99509537604548, 67.86043997733825, 65.47863560338175, 66.1181309915358, 63.404796123504646, 60.71821966478902, 56.48551156443935, 57.939765607157064, 52.82117059153896, 50.08195200274068, 48.979067802429206, 47.34325901154549, 48.76802859767791, 48.21691989898682, 46.94335768299718, 47.398576198085664, 47.45433269008514, 49.69985823477469, 48.19487225624823, 46.148144199002175, 44.012366571734034, 46.08426055600567, 49.489274024963386, 51.593747215886275, 53.48529846437516, 54.32668609003867, 57.27343728465419, 61.10683633435158, 58.900805134927076, 60.78600998847716, 60.1041216235007, 59.44601066650883, 56.86997444398942, 52.248041706700484, 51.21171228347286, 50.02747812578755, 47.03878894928963, 48.92706109631447, 44.97684209577499, 51.80726928095664, 49.087238927041334, 61.61375953305153, 56.5906193179469, 68.80020064692344, 34.542380379092315, 31.836180302404593, 66.71224455679616, 55.66022134596302, 58.941648775531405, 57.001715090967, 62.97115456673407, 59.33154021539996, 55.92544024990451, 51.73149301159767, 57.98655556094263, 55.086884575505415, 60.37429448096984, 55.850448454580004, 58.081249421642674, 56.49654911410425, 61.728367267116425, 57.06763836645312, 59.07817471411921, 56.135573387146, 58.33183004010109, 55.656067555950536, 50.453816229297274, 54.121330399667066, 61.049310853404386, 55.85588093726866, 47.42143577144992, 43.85776635139219, 44.35191046807074, 42.74404856466478, 46.68736811607115, 46.164453414178666, 47.72646281027025, 44.6498772405809, 47.88170629932035, 45.657137978461485, 45.49598739993188, 44.60950820676742, 43.66441703611805, 46.419446699080936, 50.04699976213517, 50.55776688360399, 54.818366958249, 55.64078207938902, 58.76522840992097, 61.03650823716195, 65.74452131025254, 64.65759331180205, 67.1302515460599, 65.04683756059217, 65.99205032471689, 62.230120781929266, 64.73628390219905, 55.716342618388516, 56.506292281612275, 61.27137976308023, 67.45754195797828, 67.55979814837056, 65.85542632687476, 4.7839864415507165, 0.6341056838150948, 1.651704441155157, 0.738317482173443, 0.15173160410936803, 0.08742958517564882, 35.577019260775664, 68.59888107545915, 47.880772775219334, 35.05483019736506, 45.189591453921416, 21.653793627215972, 19.475256281514323, 45.49881150645595, 47.83798363900954, 57.52952491083453, 15.21292938340095, 0.5681388945348802, 0.10141457385954358, 0.019953443721357374, 0.09727419804661505, 0.07350851886815603, 0.009147530316465325, 0.01577717285873669, 0.031214399946733352, 0.05153561183702081, 0.08604124999575077, 0.05369688759768202, 0.0320408326168094, 0.022786840976726626, 0.08032047309942784, 0.033426867617714795, 0.02431241889303971, 0.10974374990309439, 0.05225442447549394, 0.031721278191393906, 0.09956588878506616, 0.05719409429378087, 0.06890011695964683, 0.021980956699999592, 0.14176164393223104, 0.3491037543262205, 5.591741704171704, 85.97294130632955, 73.37797534081244, 76.5047711710776, 66.8462170324018, 36.41304892878379, 21.37963564165177, 29.102353011408162, 46.44898606884865, 88.16496572186871, 44.432024878840295, 0.11768332427187313, 0.08513312170942945, 0.905683852972523, 1.8969411979759894, 5.479739404493763, 9.347650408744812, 8.529354756878268, 0.4373834366279264, 41.17410029134443, 76.19732795223113, 78.84998767606675, 77.65157022783833, 76.29897225287654, 77.10265805644374, 74.9909088688512, 70.71999688302317, 73.86600448239234, 66.76036419407015, 69.19676011608493, 70.740934495003, 71.2907958799793, 68.8429231028403, 66.93803187339537, 67.94586135495094, 65.29415868943738, 63.63384685208721, 60.863594470485566, 59.93065480263003, 55.46008633029077, 52.85206317901612, 52.28131125050207, 49.24641263100409, 50.8008675421438, 49.40741808183732, 48.80579317769697, 50.0405356960912, 51.57694770443825, 51.91286340836556, 50.75130839501658, 47.131964852733, 45.717613081778254, 48.6638504459012, 51.766574690418864, 54.141797327226215, 56.609387859221435, 56.7325149813006, 59.19735200943486, 63.31035329449562, 61.28491586254489, 62.895543036922334, 62.328211415198545, 59.57881427580311, 60.00112802751603, 54.39111886485931, 54.25501261987994, 54.31489544530069, 48.8682294660999, 50.6700211955655, 47.79699879307901, 53.61463077606694, 51.2140735503166, 64.35136602770898, 58.412120957528394, 69.96339521100445, 38.32810694171537, 35.08764474622665, 67.36433859794371, 57.77462990053239, 61.27571398212064, 58.72321198063513, 64.0387531249754, 60.412827845542665, 55.92640123059673, 53.71997387178483, 58.8545564682253, 57.686513854611306, 61.49728082841443, 55.838677421692886, 62.17634116449664, 57.72783210200649, 63.450205402989546, 60.36380606312906, 60.174947861702215, 59.974322549758426, 60.261220393642304, 57.47657683587844, 51.07449208536456, 55.95704670875303, 64.00768403084048, 60.16312976037303, 49.87546274738927, 45.86525109506423, 48.06995261100031, 45.32503874071183, 49.1963121967931, 46.629305270410356, 49.93860506242322, 47.34778542672434, 49.46238617743216, 48.222450440929784, 46.34097576141358, 48.017082983447665, 47.432853791021536, 49.13531149587324, 52.4116986797702, 53.74192345526911, 57.14716049932665, 56.18706626276816, 61.92362677666449, 63.96654229010306, 66.92169912399785, 69.33703976292765, 68.73457154920025, 65.9206396533597, 68.37409788562407, 64.94784870455342, 65.00763739309004, 58.93855402546545, 58.07669162750245, 63.84453696589317, 69.8937496062248, 69.31323097598168, 70.3541103486092, 7.268274993665758, 0.7143343949029524, 1.0298147340936046, 1.1776117259456267, 0.14231184827944926, 0.014739690626400613, 37.40167056360553, 75.14887840517106, 54.15626695079189, 38.90072591843144, 28.658587817222845, 28.104037238705544, 24.31893433293989, 53.04886810241207, 54.14836729726484, 69.14877383939682, 25.11589719403175, 0.534144876705062, 0.12331113639858463, 0.1623470393279868, 0.05884035212558605, 0.08532970753167907, 0.049681901225760106, 0.011632496419723236, 0.06218953914339505, 0.016468458042870608, 0.04432957048618025, 0.05299554942476173, 0.08226959996165768, 0.024499951471244136, 0.19034703202064962, 0.1985066651456779, 0.14949956097670142, 0.280176923880654, 0.17797889488358654, 0.1801825621195378, 0.2015182487065754, 0.14408152670629565, 0.2499138768161497, 0.300224402979497, 0.2830838291875778, 0.5832490901793204, 7.39915075802034, 100.00061573520784, 83.79666128466206, 83.69448354167324, 78.56751426573723, 37.59488651829381, 21.872536366985692, 36.819214282497285, 55.34866356080579, 95.23352392258184, 51.72866106033326, 0.4603247668954634, 0.1920666542625235, 2.2339126323499987, 9.032756647756024, 8.686226029549877, 23.081977636583392, 13.091541951702489, 1.3570781797170641, 46.401501855542584, 77.48796032321069, 81.27427916372977, 81.44614173519997, 80.68042447490078, 79.4521656344014, 76.6545037300356, 73.39975234000914, 75.68478399707426, 69.53883786355296, 70.43596236936509, 73.66353957883774, 74.49039874538299, 72.64857138356855, 69.76738652875348, 72.47092723846436, 68.85820465703165, 66.99682035753804, 63.68946213876048, 62.093057478627856, 58.56810185217089, 54.33509957405829, 53.67971858670635, 51.035515492962254, 53.45786540738998, 51.31303494976413, 52.44134395353256, 52.31447881267917, 53.97867379649993, 54.314444372730875, 53.6998874141324, 50.19352382229221, 48.13392254614061, 50.90730105676959, 54.52569930784164, 57.881679227275235, 61.230873446310724, 57.576671800305775, 61.54289014877812, 67.02645778656006, 62.642805114869155, 66.01079140940021, 66.8276720662271, 62.657780724187056, 63.772326131020826, 57.78931525445754, 58.11517792363321, 56.73948895546698, 53.4035405805034, 53.20483722994405, 49.63720621601228, 55.614259012283824, 55.24572487800352, 66.97880098896643, 61.21863172900293, 70.59650498051798, 42.463759914521255, 37.8841220948004, 71.51004068313107, 59.973024245231386, 63.674160972718276, 63.56549170709426, 67.3741288338938, 64.4442791323508, 59.18371785071589, 54.83288365025675, 62.13423452069683, 61.89565243259553, 64.70344189674624, 56.486911850590865, 64.21181594171833, 60.33214469109813, 67.1499026206232, 63.47187257582142, 63.72946246977776, 61.71390156592093, 66.20433684318297, 61.01605307671332, 56.70823943230414, 58.926732001766084, 66.1392568772839, 63.02400066006569, 52.57718739971038, 48.09261606585596, 49.20154463860297, 47.357367777055316, 53.403281704072036, 49.146262753394346, 52.780676041879964, 50.34651194849322, 52.95510776581303, 50.55590768014231, 50.56796504605202, 52.00084217133061, 49.615825376202984, 52.46385051358131, 56.45401100958548, 56.89333215836556, 60.336686795757664, 59.76569560266311, 65.40231020219865, 68.56720401394752, 70.13404184772124, 71.20378202007663, 70.65925505853468, 68.47269842701574, 72.65949126212828, 69.98236379315777, 70.52657696508592, 62.61284212912283, 62.66302101073727, 66.83947055570542, 73.88629098092356, 71.36615245572983, 73.33172275174049, 7.2638505601113845, 2.2227113237304073, 6.717367806742269, 1.6501312029938546, 0.4291192171794753, 0.46270806642789997, 42.82508081005466, 83.07856944299515, 60.12402372975504, 50.027956654948575, 60.356208432105284, 32.72101013891159, 29.51648077657146, 65.98047933270855, 63.02002729908113, 78.30433891665551, 30.054278912082797, 0.7367796679177593, 0.23369239402874825, 0.32686848133321733, 0.29267276787469465, 0.23707274167287737, 0.10045605230956309, 0.12060106206204622, 0.12671134104171108, 0.12345855469785391, 0.19381946343327724, 0.1426667921365269, 0.26617213182391664, 0.07200291860968837], [0.08846056332150776, 0.03592428360735217, 0.08491634180949581, 0.09291015520331361, 0.09976651189067673, 0.0543501882273103, 0.03364492305404237, 0.09098800995777692, 0.09568514783055553, 0.11562265500786806, 0.31389337273374684, 0.8267831706231641, 19.788102565273164, 76.44367633327361, 65.54422155503305, 46.477034937950876, 28.900086187547256, 26.462929325719035, 55.201127529144294, 48.887974677547334, 44.89639036117062, 81.44775775171097, 16.540562452808505, 0.2963212462923219, 0.02909505217816801, 0.14577948398167087, 1.9023508818880206, 2.0158577782492486, 2.8023464400922102, 1.4860960889247157, 0.501554117447907, 56.61596175163024, 73.56940269470215, 72.60100872285905, 67.38381708821943, 72.11870624173072, 68.33540762624433, 72.40489021424325, 70.5031604151572, 73.80559213699834, 67.40553917423372, 68.83339958806192, 69.63503791439918, 69.45891564892185, 69.0461254119873, 70.23671380935177, 68.81820432601437, 64.68496753323463, 62.84520333813083, 64.6305799484253, 61.89145941888133, 58.5544559263414, 47.38564022125737, 48.956361201501664, 47.98981074363955, 48.34322806327574, 47.77732418429467, 49.082834105337824, 46.65336901141752, 49.00175479150588, 47.10610466618692, 49.30942943019252, 47.239222065094985, 43.86368520798222, 45.92893469718195, 47.698100151554236, 54.1985579459898, 55.85850892528411, 59.10195212210379, 57.686655059937515, 59.89985242966683, 60.57732028345908, 58.712343092887636, 57.159155107313595, 58.722047036693944, 52.08185480486963, 48.77958390020555, 49.653742928658765, 48.220453954512074, 48.34980195568454, 47.85739152662216, 47.37189623617357, 48.97208598352248, 48.31515958232265, 58.90420582986648, 56.7358882196488, 66.39403050945651, 34.58632269213277, 39.724913950889345, 64.15607513919954, 55.21004699891614, 56.17048248167961, 56.57563586388865, 60.86215496063233, 56.40370268975535, 58.80105926144508, 49.74331809628395, 59.31638417705413, 56.46478183807866, 55.299610399430804, 50.50524242462651, 53.30506163258707, 54.11279924454228, 56.11638515226303, 58.56357151462186, 57.94567661900675, 56.07072091871693, 56.41572867670367, 57.00912837059268, 52.59917228452621, 50.208770075152, 59.6539080527521, 58.76584029966786, 49.5958605120259, 43.32878766521331, 44.87614308634112, 43.795271227436686, 45.36188940848074, 45.78212038163216, 46.95047286248977, 45.74268879428987, 47.47438384640602, 43.74577091586205, 45.053159652217744, 45.22468489985312, 44.106825090223744, 46.74849041046635, 51.969831912748276, 52.077869676774554, 55.94010991434897, 58.428143839682306, 62.067919008193485, 63.96658935854512, 66.73132296531432, 62.390110338887865, 64.44491847868889, 65.00786096818986, 62.058183685425796, 57.19300908427085, 53.5890059317312, 49.74615789228871, 58.39835736059374, 64.69063535813363, 67.98200207371866, 66.82989212774461, 71.171171434464, 29.794731755410474, 0.1648779640034322, 0.9912484583835449, 1.4168120776453328, 0.1479790603081065, 0.1259260626149274, 8.621575563184678, 66.33168835793772, 53.486184920034106, 41.366994611678585, 28.2973002618359, 24.923571617372577, 20.153357598089404, 34.04369808012439, 56.75350358409267, 50.918915194849816, 41.275568085332075, 2.947324105808812, 0.2004543670843686, 0.08981057112255404, 0.03620012505580822, 0.02684429351751122, 0.10472584335554032, 0.006384639484402274, 0.10350702811152705, 0.01866486851095913, 0.09012004766132563, 0.026031298029627052, 0.00852955304341571, 0.023348410238301563, 0.012974598193390956, 0.04114813374115094, 0.15055132308794608, 0.05576521391049028, 0.07760423941597824, 0.037940251640975475, 0.04954062312120392, 0.11571775716278823, 0.05933742444481581, 0.13238002395918294, 0.28195611711951996, 0.8239349782947571, 26.59509554986031, 90.05971370204803, 71.27574182325795, 59.63468843890775, 40.73548909156553, 30.22508832716173, 25.94400171310671, 46.81814778235651, 51.642133574331964, 88.87510299682619, 18.12874778624504, 0.09431506852589308, 0.2212762078570743, 1.8165024562228111, 4.148169746322017, 5.239920789195645, 3.9066963811074538, 1.8939686542557133, 1.5051708202208243, 59.40433548342798, 78.41782093048096, 74.36292171478271, 70.54000716055594, 73.93784661446848, 72.34639983023368, 73.40402772349697, 74.6200958375008, 73.78194808959961, 70.97756324275848, 70.27925583624071, 73.4123117693009, 70.17658387461017, 71.49613195850004, 72.00340424814533, 71.41268745545419, 66.32527920507616, 65.69650365460303, 66.4899246154293, 63.53958052973594, 59.01602083636869, 50.5841330559023, 51.86257077801613, 49.86422515684559, 50.65335504470333, 50.62265857573479, 49.85273653461088, 49.732327615061116, 50.9339927857922, 50.75435607664047, 50.022092711540964, 48.505323933016875, 46.34716133917532, 49.750496033699285, 51.09294683702531, 55.78736497509865, 57.16670959226547, 62.18304057275096, 61.446129198997255, 61.85587959904825, 62.44889882303054, 60.92230842959497, 59.241443372541866, 60.69269680207776, 55.51446607035976, 53.07226504048994, 50.314026878726104, 50.648338333252944, 50.81715714546942, 49.6255999226724, 50.044214879312825, 50.62768313192552, 50.75014737344558, 63.342293154808786, 60.24824911548246, 67.72491424314438, 37.7289217518222, 43.8686470062502, 66.86935901641846, 55.966511387978834, 59.92446922486829, 56.81253133281585, 62.189116324147875, 59.38033450034357, 59.61627291094873, 50.84795167369228, 62.22557867726972, 60.447733017706106, 57.30185877892279, 53.11533658735214, 53.60142415569675, 57.36498932684622, 57.710722723314845, 59.96811343777565, 61.45762174360214, 60.718972759862105, 59.30693518730902, 59.603752705358694, 56.19820579405754, 53.37945722764539, 61.75644751518004, 60.83964055584323, 50.901088022416644, 44.814707002332135, 46.50356192742625, 44.33774286700834, 48.84114942243023, 47.47885927077263, 49.63755138458745, 49.87499990770894, 49.887594638332246, 46.15231367849535, 48.43903195473456, 47.09155267284763, 46.83359015372492, 50.05219298024332, 53.61919641494752, 55.259802264551965, 58.165109695926795, 60.96612522678991, 65.79688495205295, 65.79991694419616, 68.10264633547875, 66.05737347756663, 66.82468322015578, 65.88504022167575, 64.5323363427193, 59.42140956078807, 54.590143849772794, 54.697322614731334, 61.13428115844727, 66.45591766603532, 69.63757961027085, 70.2919250918973, 73.19172551555019, 36.67294125403128, 0.03433595734438108, 1.2236232118260477, 2.639491591722735, 0.18187180131433472, 0.06405206742666422, 8.050688803195953, 71.90478017253261, 63.562451870210715, 47.673820680187596, 32.07517620055906, 25.588972299329697, 22.255202800996845, 39.76641654968262, 64.25844900069698, 58.69818725893575, 52.84193954160137, 4.588319986097274, 0.33012882896488716, 0.06393455336951921, 0.031634308059789965, 0.013056318707493766, 0.10586411211519473, 0.052014960712122346, 0.04714314330128893, 0.06857068383044775, 0.09448696333434313, 0.07681067957873307, 0.02972849580879894, 0.03156793037159068, 0.18939121476104184, 0.15503796298177014, 0.2380798102146195, 0.3300308003540962, 0.21049111480674437, 0.1560205167099353, 0.23198522837652316, 0.20413045531078694, 0.1932896983118788, 0.24526421341203877, 0.39007153181779775, 1.10905984957372, 30.886127333487238, 99.17505879555979, 80.18128718099287, 67.59755488364928, 43.117501351141165, 37.92905284512428, 74.23783732998756, 70.44725095072101, 57.279658163747484, 96.67735622775172, 22.139057497824393, 0.5528924578139859, 0.17881486534831986, 4.628783647091159, 6.575435371168199, 8.763363361358643, 8.42834097723807, 4.276684243832865, 1.5956850277800716, 67.18219941662204, 78.01570738515547, 78.96435614555114, 70.84452429125386, 79.53457463172175, 73.70535204487463, 78.35394120985463, 76.2529157823132, 76.2334765157392, 72.54042379317745, 74.32585531665434, 75.32670297930318, 74.26013992678735, 72.83512715370425, 75.00739851305562, 74.79949720444219, 68.95835061227122, 67.33584650101201, 71.38275977103942, 66.96581794369605, 62.3161187479573, 52.50387045644945, 55.60869316900931, 52.08785995360344, 53.63854938937772, 54.16564926024407, 53.891954114360196, 51.432008281830825, 54.57425040583457, 52.10663633961832, 54.452594172570016, 50.1859026570474, 48.34622475408739, 53.348144946559785, 54.80430133881108, 60.07765346957792, 62.84514450257825, 65.21169085656443, 61.95171879183862, 63.48186285265031, 66.61875094136884, 63.18401767361549, 63.667908714663604, 65.09199580838605, 58.04211593443348, 52.7843552251016, 53.69749084595711, 52.7941729176429, 54.20870511762558, 51.85247459719258, 53.78907034474035, 54.500176445130386, 55.32052055481942, 64.70872532936835, 63.60528807486258, 69.48870212801042, 41.51199286983859, 47.23335812168737, 67.1265802075786, 59.52781561882266, 61.69363467924057, 60.010549560669936, 66.5442886660176, 61.44335216091525, 62.26135853798159, 53.517638406445904, 64.26456397579562, 63.99463038290701, 61.20524075723464, 55.845808290666156, 56.0008046703954, 58.30142774889546, 62.073178906594556, 64.66903094322451, 63.409451976899184, 65.0736391159796, 63.09479159693565, 62.646868690367675, 59.52468948979532, 55.19128238001178, 62.223523355299434, 64.79886139592817, 52.92903969364782, 45.177792964443086, 48.97756553465321, 47.56566524505616, 51.96982799037811, 50.746982020716516, 51.58686345623386, 51.20833120038433, 53.3923618255123, 47.3679542541504, 50.832434777290594, 49.98299844803349, 49.484567180756606, 52.06536516066521, 59.0506749768411, 58.239901450372514, 60.24351873705464, 64.52123995750182, 67.48971323813161, 68.14815367421797, 71.14624084964876, 67.71942292490314, 70.48272486655944, 70.07845401763916, 67.42228769486951, 63.84212470823719, 58.8839703221475, 57.708475205206106, 63.743786965647054, 69.37962885825866, 72.87864192839592, 73.44405943347563, 75.30277652125206, 38.87154348434941, 0.4582465235744754, 5.867296543813521, 3.361557774966763, 0.580865637429299, 0.21396969024452472, 11.464903662281653, 80.99710879787322, 68.84975587168049, 57.13768797536051, 44.11882362058086, 36.607484740595666, 30.08297693344855, 50.436663704533736, 73.51896101428618, 69.83301562647667, 63.59245015728859, 5.312685168558552, 0.41029848999554114, 0.16839599296931299, 0.14130949883932067, 0.25468576188770037, 0.30646605837729674, 0.11640806366959888, 0.19039526491636233, 0.10810020785298079, 0.3180174691782844, 0.11608429959103947, 0.1039568672797853, 0.07923687237405008], [0.06573586739719876, 0.014893440642364085, 0.03073281792533254, 0.03996522120770909, 0.027472696289600387, 0.04435574771055291, 0.05406612665542672, 0.008449517922746319, 0.1196276784063347, 0.06084327751229848, 0.16172454692423344, 0.10977476880314851, 44.38348947032806, 84.33725803129136, 54.23333760230772, 53.2738866344575, 45.20774810544906, 27.141526822120916, 57.141680948195926, 37.39697156413909, 66.49143865031581, 69.22025511341711, 5.068471047186083, 0.06011904863220069, 0.13395516201853752, 0.3434697598699601, 0.46676851628768834, 5.801927303114246, 1.0866797859630277, 0.6828443201318865, 6.609705119363724, 72.87166795422955, 70.80081339805358, 72.46987604325818, 68.63667703443959, 68.00321425161054, 66.61106309583111, 71.40923576970255, 69.53882217407227, 68.03830377517208, 69.10947953501056, 68.86400192014634, 67.76399673954134, 70.11243743281211, 68.02561098529448, 68.11780237382459, 66.65120463217458, 68.34479778043686, 63.867314169483805, 63.76287321890555, 62.42234045459379, 59.83985585551108, 50.58926743845786, 48.000252093038256, 46.867542189936486, 46.71468350195116, 47.33306477146764, 48.54908973939958, 49.95783252100791, 46.33964607792516, 47.545421892596835, 47.370119402485514, 45.41362939342376, 45.107084397346746, 46.08270729741743, 51.29721210848901, 54.449436664581306, 56.43479139574113, 59.04632506832, 59.44236286224858, 60.56464710543233, 58.27941148511825, 58.287107175396336, 54.294887435051706, 52.66381294496598, 47.577353908169655, 49.29936462833036, 45.66946598791307, 45.82606661704279, 45.85167184952767, 48.64735687932661, 49.09381674182031, 50.412666643819506, 48.74016407997378, 57.85623088959725, 55.72304202664284, 64.50504449106032, 33.7193690576861, 44.28393579298451, 60.822429195527114, 54.0065618484251, 55.62224888032483, 55.99789819409771, 57.14355191876812, 56.7990501465336, 57.38420894069057, 50.8736078969894, 59.95858992299726, 58.228412828137806, 56.95842781374532, 54.946149933722715, 48.81078635492633, 45.50268288581602, 53.4367238321612, 54.58023202034735, 58.65197389356552, 56.57654585376863, 55.5479827234822, 55.56988916089458, 54.90242727341191, 49.70523580428093, 55.97356380954866, 59.29696844470117, 51.17981949160176, 46.71629559609198, 45.60619423466344, 45.29526795110395, 43.46933403322774, 45.89673988280758, 44.56952356523083, 48.5147846898725, 46.309486973670225, 46.40579685088127, 43.133069238355084, 45.64182896767893, 45.95074307534003, 48.080378270918324, 49.565775932804236, 54.95057436727709, 58.03934281872165, 61.11746203514838, 62.98847967578519, 66.33961939042615, 63.88368222021288, 65.19700942500945, 61.580623349835804, 60.329587305745775, 51.95812756015409, 50.0849251593313, 51.17923505844609, 56.3063729962995, 60.26375032240345, 66.34945669481831, 65.63794266793036, 71.84460316934894, 66.03046601818454, 65.81486901929303, 5.102466719765817, 0.9153995638893497, 1.4163265617624408, 0.1989547040073141, 0.024162886191099405, 0.4778127462392854, 38.28708679445329, 70.67219103536299, 45.402685980643, 42.257470700048636, 35.12815106299616, 17.752192404962358, 30.18002421625199, 40.5680666431304, 53.40949866079515, 51.52889082508703, 13.2379493213469, 0.2785303864267565, 0.09695864643060392, 0.08364008529292, 0.04606653695865985, 0.07415665223473504, 0.07066557424203043, 0.11789674870669843, 0.0886941665122586, 0.03499776921084812, 0.014186894029168593, 0.07218205294902287, 0.04051401212270703, 0.06511604097942192, 0.04742244746716273, 0.048309320644024885, 0.06727080116228712, 0.006459221016660694, 0.03297759152408088, 0.014881807597233884, 0.06466803276130269, 0.047495015145790194, 0.0639199823771994, 0.09360154955497674, 0.026441670263246186, 55.741233979502034, 90.92640846006333, 62.513766980940304, 55.08033813968782, 47.728212187367106, 34.517869487885505, 47.347142158016084, 43.037096684978856, 73.77899062248969, 73.57106577965521, 5.376595777849998, 0.17917845067718338, 0.37035396082266686, 1.5874826163053515, 2.620604153602354, 4.560974692144702, 1.172191990960029, 0.5716122758965339, 9.273219512354943, 76.14820418819305, 74.90983347738944, 76.4461317370015, 72.02216886704969, 70.03122868076449, 68.67579875453826, 72.02595787663614, 69.84078191941785, 70.24105195076235, 71.02474935593145, 72.58076144802955, 70.04921667037472, 72.25562049496558, 69.84909734418316, 71.43597064479705, 68.66209399315619, 69.27817283138153, 65.97597645175073, 66.47177188627182, 64.39346482676845, 63.27085894923057, 52.290081670207364, 50.40585348683019, 50.07964957144953, 48.067909056140536, 49.148600486017045, 51.1948892378038, 50.91174510217483, 49.06748587085355, 48.970191478729255, 50.05553091725996, 48.37096314276419, 47.647685927729455, 48.67096562539378, 53.021584095493445, 56.62020183378651, 60.86996832201558, 61.70398973649549, 61.004132993759654, 63.003059125715694, 61.93714326427829, 59.75785478468865, 57.31140190555204, 55.091234484026515, 51.037523746490486, 51.40719929049092, 49.96915248132522, 48.05171358969904, 48.63566037147276, 49.64080695183047, 52.00032441846786, 51.595386766618304, 51.39217661273096, 61.82248846177132, 58.4429507870828, 66.1660623550415, 37.27699410530829, 49.376297996890166, 63.07738804048108, 55.49193597608998, 58.83117129725795, 60.0452390024739, 59.525932881139944, 59.19141354099397, 58.895666830001346, 53.11354798655356, 59.47518525585052, 58.83750592508624, 59.10242672889464, 58.13846895771643, 51.301738523667865, 47.895724850316206, 52.04828716093495, 57.715147156869214, 61.03918721598964, 57.86664478240475, 57.4261430002028, 56.45944741464431, 57.34436158211001, 54.07979249954224, 58.836697916830744, 62.672952452013575, 54.12399368901407, 46.78317592990014, 48.63147128012873, 47.18330867828862, 45.09974172038417, 48.872336187670314, 47.46932398888373, 50.756787946147305, 49.90631611116471, 49.65305259150844, 46.24204574092742, 48.10427727237825, 48.32485568138861, 49.93816575696392, 51.91595815843152, 57.987610678518976, 58.98910160987609, 62.138345164637414, 64.54360138985419, 68.862150561425, 65.2476119226025, 66.61910395468435, 62.8246501184279, 62.013064661333644, 56.32775775847897, 52.56088210690407, 53.51821107249106, 59.17486898360714, 64.8992976065605, 71.12651132768201, 67.98084105214765, 75.08646565098917, 66.89425822227233, 70.09652045465285, 8.01353366144242, 1.0966639340885225, 0.9260238550843732, 0.5379652039658639, 0.026693471872638312, 0.32707523314222214, 41.02432458631454, 76.5552834541567, 53.660973579652854, 36.89213506637081, 23.97073180444779, 27.617700599854995, 39.61411876063193, 47.773197850873395, 59.8956633383228, 62.683405568522794, 18.35503912741138, 0.4236491961825279, 0.03325434078672721, 0.07729419597214268, 0.05586873920213792, 0.0390967954280636, 0.010522765392858175, 0.02936721065892808, 0.05764477615875583, 0.09806699179593595, 0.004878682995049824, 0.07263157802123217, 0.0648349786417619, 0.11088906667165219, 0.08480846130799863, 0.1459120018708129, 0.14125159791400357, 0.19126377879611908, 0.11918773709405815, 0.20220386675528942, 0.11067477655747246, 0.22682945664611556, 0.14518904469666943, 0.24169914664760714, 0.2541358180103764, 65.35697152537685, 101.7940410490959, 73.19598520955732, 66.98413541240078, 58.526167792658654, 39.45306231898647, 78.70770762043615, 54.96072546128304, 80.29185095141011, 82.50041207959576, 7.124417164633352, 0.2976634936226953, 0.7174462440513796, 3.6832389523906097, 4.100355563625213, 15.179554916197254, 3.711660691807347, 2.7797079903464166, 10.467985233952923, 82.88984067978399, 75.35280243042978, 79.79244693633049, 74.91275172079764, 73.84770270316832, 70.72711206251576, 76.98265706339191, 73.65246280547112, 72.01631669075259, 74.30745940054618, 74.77593160444691, 72.02274937783518, 75.77883458906605, 71.27185083204701, 73.14862651209678, 70.99300169175672, 72.86432527726697, 67.36957103975358, 69.29005761300364, 68.5885730866463, 64.91708555529195, 54.736224682100364, 52.7048566264491, 51.210351221023075, 49.797529174435525, 50.67888967452511, 53.464792313114295, 55.14621826910204, 50.57143242128434, 50.700486244693884, 53.45115030965498, 49.806511402130134, 51.56958933799498, 50.57868096136278, 56.885581554905066, 59.940060646303245, 61.67027696486443, 64.19961737048241, 62.40086940027053, 65.28287403045162, 63.38185810273694, 62.616387951758604, 59.27440304909984, 58.15453106357206, 53.24066808146816, 54.800265219903764, 53.46545911604359, 50.7206589944901, 52.65251259649954, 52.07036618263491, 56.0212912098054, 55.251918300505615, 55.76684705672726, 63.500643161035356, 62.4911545168969, 67.0979469053207, 40.143430848275464, 52.29552199763637, 65.09342355112877, 59.50007269459387, 62.04849150873, 63.284065569600756, 62.17553707861132, 61.82699918746949, 60.89439684344877, 55.62194685782156, 64.19104699165591, 64.55598039011802, 60.642953303552446, 62.199228194452104, 52.07845410993023, 49.990321513145204, 54.2939813675419, 60.078940006994436, 63.241135228064756, 60.282197229323856, 61.97769664948987, 59.9765073099444, 58.54093551635743, 56.236837217884684, 62.194211483001716, 64.52133409438595, 56.48674318867346, 51.66464013438071, 50.47078048029254, 48.1480077774294, 48.8512691374748, 51.392360964129054, 50.165910336279104, 51.7683123004052, 51.19537561170517, 50.91303948433169, 46.800242162519886, 51.4370838288338, 50.96237113398891, 52.70677466546336, 53.931122902900945, 60.09936771085186, 62.63998493071526, 65.72238737537016, 67.88178551581599, 73.38186633202338, 69.02958085460048, 71.19336420489897, 67.31295554868638, 67.21779100356564, 59.73529331145748, 55.75285988469278, 58.002817707677046, 62.23416082320675, 66.01614152231525, 74.18832132893225, 71.24085626294537, 77.07073780798143, 70.93779825395154, 74.64622666758876, 7.610250759509302, 2.4828662026313046, 6.312565476663652, 0.9807348515718215, 0.2617402518949201, 0.7686513770491846, 48.857964623358946, 83.74531745910645, 61.138607532747336, 57.297289217672045, 46.1448964764995, 28.007217453372096, 44.951393758097005, 59.55693137261176, 68.93772678990518, 73.93565793191233, 22.816919549818962, 0.7474244902691534, 0.2230284041574886, 0.13467765953992644, 0.13256630589885096, 0.17899428314018637, 0.1951754390592537, 0.16521458303736103, 0.21569015518311532, 0.113339169071086, 0.15839777946952852, 0.1682626630269712, 0.12479048282388719], [0.03511330676114848, 0.078556616940806, 0.0403394015325654, 0.01865525410750941, 0.018621996315496585, 0.09256613576003621, 0.042797892594770084, 0.06113947008646304, 0.040377200310749393, 0.1219164350280358, 0.131652225109358, 1.8874961306010525, 62.648814185973144, 70.73287010192871, 53.31003127559539, 59.47491068993846, 23.904041705592988, 18.06042205902838, 38.89102981936547, 40.40785351107198, 78.14545939045568, 43.371608180384484, 0.36999668805829944, 0.02877389279855115, 0.2154624432085022, 0.7279710663903145, 3.596355756444316, 3.4675360495044343, 1.463829651474953, 0.4939817366821151, 36.418167621858665, 81.12754329558342, 70.56973872646209, 69.51328754425049, 66.04402172950007, 62.58415391368251, 59.96453231380832, 64.4274325524607, 65.79249581983014, 67.57846863039079, 65.54823021734914, 65.64262205554594, 66.6865530321675, 65.87147666561988, 67.81026501809397, 68.6826942813012, 69.73627428854667, 66.4785889656313, 65.82897386243268, 66.58597561620897, 67.06408116125291, 64.61006203005391, 56.47194016364313, 48.19673145970991, 47.7011086094764, 47.73804949175927, 47.81242155259656, 46.03831783417733, 47.61534598565871, 46.967413579264, 49.70475727511991, 48.35641899416524, 47.29872049823884, 44.71400799289827, 48.311319581923954, 49.10044162504135, 53.39525653469948, 58.7215292838312, 59.848818471354825, 60.92404211721113, 59.663725745293405, 57.41125368302869, 57.49835775744531, 52.453597437950876, 48.228867438531694, 46.38512596007317, 48.35547370295371, 45.24367309385731, 45.33997904869818, 46.59244283553093, 51.496868595000244, 50.029078452817856, 50.91949178326515, 46.9726695552949, 58.15172264652868, 57.069160246079974, 64.65914264802011, 34.24723379073605, 44.574916824217766, 62.83995520684027, 50.60655332380726, 55.78816906098397, 55.699994179510306, 60.943646123332364, 56.915340577402425, 56.28027746754309, 52.061074087696696, 56.57738131861533, 53.87329932182066, 55.402388265056, 53.74194306711997, 56.26099901814615, 59.47437332522485, 59.993550008343114, 50.15835192895705, 51.95861393405546, 51.80635144633632, 55.180786117430664, 53.89242479878088, 55.48522087835497, 50.09237374028852, 53.72925027724236, 59.94125304683563, 53.78387320426203, 46.211698362904215, 45.51544627835674, 44.985945916944935, 42.785288364656516, 47.153341770172126, 46.327741684452185, 48.00069532086773, 47.0940355331667, 45.53086903787429, 45.025114705485684, 47.6505139566237, 46.13847163415725, 45.744120459402765, 49.02682658164732, 53.23810285137546, 55.94584049717073, 60.533883956170854, 62.15988682162378, 63.76203383168867, 58.37165778683078, 57.324349649490856, 51.87278070757466, 50.07206762990644, 47.06234278217439, 52.57784635789933, 55.89803072714037, 62.073143605263006, 65.62905457711989, 67.50515168712985, 66.3453774298391, 70.38445380426222, 66.22440368898454, 71.51250393159928, 41.086698116794715, 0.12196518120265777, 1.834712427469992, 0.5815345241177468, 0.19477592420674142, 0.0362270760289844, 13.202508745654939, 63.828663133805804, 59.67658719708843, 50.659874023929724, 36.741406225389056, 17.709095362694033, 26.037412958760417, 41.14393334234915, 50.40836772611065, 53.73978968589537, 29.229124015377415, 0.6581352879443477, 0.047961945735639146, 0.02964835726625977, 0.06842452191537426, 0.06473516504610739, 0.09723279865518694, 0.03344428845711293, 0.03918518282232746, 0.029552908456553856, 0.07344523234473121, 0.04010000671710699, 0.04963482895325269, 0.028762259753420952, 0.03815936810907818, 0.05342470421906441, 0.08256847384355723, 0.034499229833243356, 0.021528455376204465, 0.06466937341517018, 0.04433533529781046, 0.06958159047269052, 0.14140175114716255, 0.13818245050647568, 3.4614571111817516, 75.67140871478666, 77.16934619411346, 60.784244921899614, 67.56613669856903, 37.79224449588407, 24.224479736820346, 42.40085294169765, 46.21087074279786, 87.7233382194273, 45.404047043092795, 0.30264073622322857, 0.02822111822634695, 1.1833473343041636, 4.2634585019080875, 6.608389164170911, 2.339287107029269, 1.1159000954320355, 0.36754876134857056, 38.85663455532443, 85.5019901644799, 73.79513509811895, 74.67110233922159, 69.66976657990487, 65.3162024098058, 62.541239261627204, 66.0582285542642, 68.7162305462745, 70.38867427456763, 69.04196769960465, 68.92530072119929, 70.25636488391508, 68.43189793248331, 70.87879796181956, 69.1408271174277, 70.84483808086765, 67.73465741065242, 69.21308502074211, 68.16270566755726, 68.49354974685177, 65.94884149489864, 59.259972649235884, 51.0340916725897, 51.48999660245834, 49.125905652200025, 49.572875422816125, 47.61509887633785, 50.691676601286865, 48.93255633692588, 50.63916783179007, 49.5456620185606, 48.77682647397442, 47.50524897729197, 48.62021800010435, 50.27743900975874, 55.86964845657349, 61.82147649026687, 60.92632493665142, 62.782347356119466, 61.66017686167071, 58.66945197505336, 60.079763704730624, 54.15894200724941, 50.689362402885195, 49.763726188290505, 51.11642614487679, 46.0421617569462, 49.00767757046608, 48.10228863070088, 54.26097070017169, 52.48547846271146, 53.774271242080204, 50.498888184947354, 60.998696588700824, 59.27632501048427, 65.3920453594577, 37.59520423027777, 44.80543059687461, 65.10859527895528, 52.70637850607596, 58.15606078793926, 58.74788761138917, 62.72113484721031, 59.87471788160263, 58.11996321524344, 52.9036384244119, 57.33725424735778, 57.709655838627974, 57.83778006030668, 56.615808779193515, 58.23704988725724, 55.72074351772186, 61.49630023587135, 53.11301454421013, 52.12753472789642, 52.93130682360742, 56.18041784532609, 56.515415714633086, 57.350433411136756, 53.74784623422931, 55.554748812029445, 61.63698780921198, 55.988080501556404, 49.199375567897675, 47.30589451328401, 46.69440092579011, 46.889864398587136, 48.05045450887373, 49.43074049488191, 50.43915048722298, 48.46768486884333, 48.58970980490408, 48.52956418068179, 49.60140674344955, 47.92813147267988, 48.698496741633264, 50.62452562393681, 56.64569331753639, 59.15538264859108, 62.365736730637096, 64.61471788344845, 64.67870350806945, 60.456770158583126, 58.64344666081091, 54.843568186606134, 50.88377860284621, 50.625820006093676, 54.78358730193108, 60.32369198337678, 66.5037392031762, 68.45861711809712, 70.58255703218522, 69.3510583139235, 71.4916604565036, 70.10321986290717, 73.69632274873796, 49.75026853622929, 0.8660847681664652, 0.5010768140275632, 0.6409886467360681, 0.33218715399984394, 0.0496908146587591, 12.48181539197122, 71.78732087535244, 64.13914226716565, 53.22215449425482, 23.86711455160572, 16.791076390973984, 36.054936532051336, 47.483240558255105, 57.739356025572754, 61.91681754204535, 40.486406818512954, 1.0033582247072652, 0.09709149373755341, 0.08379365527822126, 0.026744974048567877, 0.09442587548326101, 0.02112026266272991, 0.03967057230071195, 0.10723146414684673, 0.03525309482469194, 0.05155972062399791, 0.03540521690381631, 0.03747042140833313, 0.1153951728596322, 0.14428830915881743, 0.1091954684365661, 0.1808313773043694, 0.0925592792731139, 0.187549615999864, 0.10116240069750818, 0.26891570718538377, 0.2808386399861305, 0.3503635399524243, 0.5445161750239711, 4.5964544915383865, 87.35196036677208, 86.37981660904424, 71.01561807817029, 76.18741220043552, 36.396116056749904, 27.874162812386793, 56.212624426810976, 55.82892248707434, 93.10504974857454, 51.760977468182965, 0.5999464974288018, 0.20655713074149626, 3.4867058982772217, 4.865381506181532, 13.346742141631342, 11.167046716136317, 8.814687575063399, 1.3990472954127098, 47.204336504782404, 85.10823911236179, 76.50057423499324, 74.16895266502135, 73.31273063536614, 68.54493279610911, 65.67689180374146, 69.74633909040882, 72.87074227486887, 72.3302161309027, 70.64596606839088, 72.54338126028739, 73.91519100435319, 69.38432001298474, 74.94354232665032, 73.25059244709631, 73.2983982947565, 68.59913210715018, 71.45352717368834, 70.59256692086497, 72.51753284085181, 69.17393976642241, 62.72078967863514, 52.434609243946696, 53.93392739757415, 51.40055087304885, 52.11777979327787, 51.09209176032774, 53.406011673711966, 52.65881192299628, 53.520662553848766, 52.03530803803475, 51.96410132992653, 49.047054244625954, 53.42201494401502, 53.66411932053105, 59.14730648840628, 63.38936551924675, 63.316119178648925, 66.50574745670443, 65.01324638243645, 61.94657264217254, 64.0317399271073, 58.80357742309571, 54.36779645181472, 52.24051075596964, 55.200625465762236, 50.123744856926706, 51.25571735443608, 51.42612864894252, 57.74784795699581, 54.686696913934526, 55.36164660607615, 53.715329785500806, 63.55825885649651, 62.577481962019405, 70.14776229858398, 42.69473260448825, 49.5831088865957, 68.43733433754214, 55.20172372941048, 60.25477201707902, 59.50621120391354, 65.6311216662007, 62.40398768455752, 61.02765152531286, 56.03550587930987, 59.7693669411444, 59.197752091192434, 62.06242376758207, 58.31259081440588, 60.16709135424707, 53.826878070831306, 62.62306382579189, 54.69212155188284, 56.02658248716786, 56.837375625487304, 57.65706862172773, 59.41214884481123, 59.48735637049521, 56.553874554172644, 57.37642303589852, 64.99288535887196, 57.048975729173236, 52.22191872135286, 52.017739742032944, 49.93880510330201, 48.60563462780368, 50.6138293204769, 52.48545492849043, 51.897860342456454, 51.932553706630586, 51.950110235521876, 51.736015504406346, 54.17566307129399, 51.369093464266875, 49.786683820909076, 54.58393081541985, 58.87287785930019, 60.02110465880364, 66.2901504578129, 68.29947871546592, 69.64871129681988, 62.935276646767896, 63.43684973255281, 57.28574568225492, 53.78897228548604, 53.72963074714907, 57.848499897987615, 61.964180161876065, 66.96061688084757, 72.02669528222853, 74.23701363225138, 72.15845554105698, 75.69496647004159, 73.00425191079417, 76.34145936658307, 50.84501381843321, 1.0489198637585486, 4.6041644004083455, 1.9122772976275415, 0.5164795020414937, 0.1885668581892406, 17.207332041955766, 79.99419796851375, 72.96766404182681, 68.37045008136381, 49.13071055566111, 28.214030304262717, 37.599797325749556, 59.18943666642713, 66.88274214344641, 74.04448801471342, 47.07765571532711, 1.6264169206542354, 0.18841436072703333, 0.17002972143311657, 0.21234559916680862, 0.17684355257980286, 0.16015700845708772, 0.21385119176439701, 0.12933048840251662, 0.14822149649262428, 0.14416018861436075, 0.1877827059117056, 0.10927863494162599], [0.04848330687250822, 0.02152549253115731, 0.0806056569901205, 0.06812815314098712, 0.020602454258609685, 0.024218427565609737, 0.07954113185405731, 0.0625498571072615, 0.06352576885312315, 0.15045851919679873, 0.18115629051481524, 10.534993044791683, 74.56937959117275, 64.25531110455914, 64.2160834804658, 43.17912570891842, 14.987402904418209, 41.711253196962424, 48.72773801126788, 49.62119510096889, 86.850155861147, 22.219240550071966, 0.02157959557558981, 0.09960949450971619, 0.8043950171239915, 1.1200260611311084, 3.0654619730287984, 0.4386898310434434, 0.6917718797922136, 10.3544855694617, 73.86853048878332, 73.34795351951354, 75.11358491836056, 69.85298049065375, 67.32254182138752, 61.30588093111592, 59.557719769016394, 56.1334631519933, 58.70704397078484, 61.55852471628497, 65.12989767136114, 64.26590542639455, 62.54944878239786, 64.77051834906301, 66.57063914883521, 64.8878638975082, 66.755398473432, 64.85564947128296, 65.77994031290855, 65.5910546548905, 65.24831010449317, 64.01508162098547, 62.58524433259041, 50.07274619994625, 47.39363793403872, 47.85253170997866, 47.84087834819671, 46.255362187662435, 46.95913737820041, 48.379082449020885, 48.14672124001288, 47.36321210861207, 48.25402552081693, 44.7688348831669, 44.771039255203746, 47.872924112504535, 56.91046899364841, 57.93974991767638, 61.06856969095046, 58.35441504755328, 60.77769064134168, 56.14571271404144, 51.23430905803558, 48.50135449440249, 47.147140502929695, 47.20452477855068, 46.8242980587867, 45.286344558961936, 46.309161416945926, 48.18854547316029, 51.40419083256876, 51.844174861907966, 53.26295498878726, 50.65550058118759, 57.59847233372351, 56.98659435395272, 63.700189821181766, 38.06526107172812, 42.14491828795403, 62.34813313330374, 49.404915609667384, 51.920339445913996, 58.27722672493228, 59.57086363146382, 56.737217903137214, 57.72905980387042, 55.481867251857636, 55.48791554666335, 55.48597789579823, 57.47852625385408, 51.87915848147485, 51.87182364925262, 49.17176208188457, 45.66339415888633, 54.28712506448069, 51.04212468670261, 52.195944786071784, 52.460708695073286, 54.77378137650029, 58.108917820838194, 47.556388839598625, 55.283030540712424, 58.97681674649639, 56.34567122305594, 45.2079128449963, 45.97831733765141, 44.496830278827304, 44.749972205008234, 45.49848987210182, 48.642799085186375, 46.74354430167906, 45.533018496728715, 47.64521875689107, 47.656460269804924, 45.68688523384833, 44.4814153640501, 47.6673173904419, 47.025554872328236, 46.45428126858127, 50.049600293559415, 50.11255825719526, 53.79243181597803, 51.83635757815454, 48.852689035477184, 47.03716901040847, 48.44851232344105, 48.71829686626312, 55.96282436001686, 60.015476057606364, 66.76449052749142, 65.55141518192907, 67.76152564633277, 65.44597402695688, 68.10134410858154, 62.770709683818204, 67.95732252059445, 62.91134234397643, 72.64046776679255, 20.553723727503133, 1.061011550407256, 0.41371076818435426, 0.09963099859775075, 0.07267014288734044, 1.559095565349825, 48.46857132450227, 66.46365258001512, 47.50952043840962, 42.720698695028986, 29.60202963121476, 13.371556035933958, 26.53334175386737, 47.51879292149698, 57.55940552680724, 45.06871577232115, 6.1075990815316485, 0.2148054155611223, 0.1010500998686879, 0.07321031914362985, 0.09565848797079056, 0.04474370229628779, 0.05756744724367896, 0.09179706775373028, 0.026049848848713503, 0.015582693778278848, 0.08421862723245736, 0.06496029530441569, 0.02172425978877131, 0.04296323352102791, 0.0597526747432928, 0.0649055123569504, 0.030810058740298116, 0.022454916146553816, 0.054896945178869276, 0.058397568627110416, 0.04485668877380029, 0.15876355580985546, 0.25226086378097534, 15.19980513280438, 86.56103011100524, 69.63397887445265, 70.3785780937441, 47.17177690998201, 25.988899123284128, 42.829540544940585, 51.35710670102028, 58.62311309383762, 92.95060250066942, 23.418295383453373, 0.14565801308039697, 0.11106493747642926, 2.1122164399393144, 3.9850655822984637, 2.953847742849781, 0.8601280974764979, 0.8396925488787313, 12.670107791500708, 77.4085166377406, 74.67165931578606, 78.31008126658779, 69.0786418607158, 69.31612568516886, 63.76521879626859, 62.218483109628, 56.615738176530414, 62.450907076558764, 64.15220375983947, 67.0559383207752, 66.26714967912244, 65.83489664139287, 67.95039561487013, 68.98791743863013, 67.33590925893476, 68.1977951911188, 66.07897789247575, 67.70958562051096, 66.72192496638145, 67.60281870442053, 65.587924603493, 66.30843654755624, 54.057168268388324, 49.9657125626841, 49.696347713470466, 49.82539369213966, 49.11329130972586, 49.502759133615804, 50.07069872271631, 50.32888089456866, 49.24108997468026, 51.674559808546505, 48.331394272465865, 48.99152917246665, 50.14249378635038, 58.65122472086261, 61.101725486017045, 62.26974456541, 61.414197183424434, 63.42323910805487, 57.14251249067245, 53.80198278734761, 50.82932433774395, 48.56603830091415, 50.19348067622031, 50.21787389632195, 46.99758837299962, 47.247019736997544, 50.453157271108324, 53.94268997253911, 54.343877838503936, 57.15039253234864, 53.48093678874355, 60.60012494364093, 58.90519818952007, 66.80494585344869, 41.28438949584961, 46.17829938088694, 65.98619030367944, 54.385815820386334, 55.43966254880352, 60.139646530151374, 63.31461691087293, 60.130907489407456, 58.68374116959111, 56.538290977478034, 57.52302162108883, 58.20449813719719, 58.794226492604906, 55.811883711045795, 49.91634561169533, 50.671374413274954, 48.47521974194435, 54.88261538167154, 55.65593419536468, 53.47486103734663, 55.24745072087934, 56.41437153662405, 60.88044497274584, 51.05726503556775, 57.124395062846524, 61.69632542517878, 59.104364379759765, 46.714793328315984, 48.062833509137555, 48.59953534218573, 47.190176748460345, 48.41020645633821, 51.34403344123594, 49.533953743596236, 47.33013476094892, 48.762141120049264, 48.344036071531235, 46.701327831514426, 46.93432446449034, 49.95771877227291, 49.81086915539157, 48.38429527897989, 51.24222047867314, 52.6763488400367, 56.52570409159507, 53.36048080075172, 51.81949138641358, 48.57067454245783, 51.398134693022705, 53.02835018404069, 59.266428870539514, 63.270815803158676, 68.7704377020559, 67.36145173349689, 69.55853600655833, 67.67467652597736, 70.02219153988746, 66.34515777710946, 70.04285458595523, 66.75105248728107, 78.93014523290819, 28.15367875560638, 1.8877995014190676, 0.2525332846468495, 0.3269758255731675, 0.021489074626456828, 1.5056335373270897, 52.23878099072365, 74.09683596703314, 52.862379012569306, 41.002802541179044, 27.160664066191647, 21.16410336186809, 34.89524464453421, 57.057020510396654, 64.38423941212316, 56.621653110750266, 9.391561342823891, 0.32430322059700567, 0.060530479982375145, 0.11471657217630457, 0.022513770851336663, 0.021603296420747237, 0.056187588826663075, 0.05789506857493713, 0.03814426468565099, 0.0160122909883578, 0.04482614484825923, 0.024559212202626853, 0.12070508148040503, 0.12223584006630606, 0.21481411831994213, 0.12777577424722333, 0.12001298232785157, 0.23799489702909227, 0.1260995815297769, 0.14599257899868875, 0.19529660352535788, 0.34043602104629245, 0.4802388547649307, 18.54395616439081, 99.65528242049679, 80.67357601657991, 80.1929287756643, 54.69740106213478, 24.959928066499774, 54.9819415615451, 68.69150392470821, 64.78739630791449, 101.01296378720193, 28.253636437077677, 0.380385545112433, 0.2142461407328806, 2.973055834731748, 6.637489228479325, 11.058992282036813, 9.466317795938062, 2.747970622393393, 17.352457777146373, 79.08559660757743, 76.40664131410661, 81.81937094657653, 73.78222265551167, 73.20994884737077, 67.23818732846168, 65.303733195028, 60.1712804455911, 64.28574477472614, 66.31094686446652, 72.97062935367708, 70.28742221093947, 68.5703654443064, 69.75571355512066, 72.20961109284433, 68.49726030903479, 72.39763382942446, 68.97836254489037, 68.89279996195148, 69.72311865898871, 70.4610106252855, 68.76738609806185, 70.0596893987348, 57.16596041956256, 51.87926830783967, 52.75629066651868, 52.22612350217758, 50.72066291686028, 50.642023317275516, 52.14849587409727, 52.34300621094243, 51.40311610314154, 51.89302013766382, 49.40442531339584, 49.32546407945695, 52.00390946480536, 62.41145979973578, 66.3284327906947, 67.33524245600547, 63.129441815037886, 68.32920243663173, 59.000911866464925, 56.477568764840406, 55.459694093273534, 52.93437411708217, 53.648653414941606, 53.7478187776381, 49.873956557243105, 50.16560046903549, 53.114006903863725, 55.73464831998272, 58.71661455400529, 58.92274295130084, 57.57829566155711, 62.68636303563272, 64.11259958820959, 68.78598597741896, 45.8696049259555, 48.15209096477878, 67.95745588118031, 55.72710167977118, 58.64459199290122, 64.06360918475737, 65.78140335698282, 61.97693178730627, 62.22778304930657, 59.08474468415784, 59.89936605576546, 62.12467962695707, 60.71815298449609, 58.54250054205618, 53.10501683142878, 57.501958493263494, 53.285830251632206, 56.67167117518764, 56.615506756690245, 55.280069151232325, 57.034537484568936, 59.9123961694779, 61.632379024259514, 52.21770217341762, 60.02707058383573, 63.88256434471377, 61.386438569714954, 48.14376769527313, 50.55258935497653, 50.30867284344089, 48.95432156901206, 51.65950575182515, 55.12588862449893, 50.673123790371804, 49.603238490320024, 52.85145521163941, 51.214328504377804, 49.80444039067915, 49.889002769224106, 53.06715811452558, 51.87424375164894, 51.79143075020083, 53.83425212675526, 55.41187255613266, 58.997201304281916, 56.89479520243984, 54.63382336401171, 51.76191491465415, 54.426051493613954, 55.893217978938935, 62.097748633353945, 66.81159819326093, 72.86737688126104, 68.97116107325401, 72.38240718841553, 70.25313285089308, 72.28182192771666, 68.75592493241834, 72.96210212092247, 69.4974176345333, 79.92062214882144, 30.283763062569406, 3.3721045380638492, 3.0967217924133426, 0.8529611304402352, 0.17666554438971704, 2.623899925139643, 61.498131982741825, 80.79945272014987, 61.84239056802566, 58.01711866932531, 41.444065263194425, 22.099633755222445, 42.747602232040904, 65.8040903460595, 73.79430355564241, 69.17303762128277, 11.821337284580355, 0.5696525004121565, 0.1607335815506597, 0.1657530509175793, 0.29467161384321033, 0.22077279616027112, 0.16012618107901466, 0.14860558233434154, 0.09335893717023636, 0.09694884050517313, 0.2404106786895183, 0.13703033087715027], [0.010504825528891338, 0.06242671230387303, 0.018396017614812143, 0.06821428440631398, 0.07397532688393708, 0.03436977246535882, 0.05182699720946051, 0.043720139881535884, 0.043024279237274206, 0.0311957955014922, 0.1322551516275252, 30.717681146437126, 81.82406210130262, 57.60606212000693, 62.19504302547824, 28.0048365746775, 28.228078273034868, 55.90144711156046, 43.005878540777395, 63.24867010116578, 73.21037246334937, 8.135816493342, 0.17308193829751786, 0.10476827696566621, 1.0411604349651644, 5.241793230656655, 3.690006021530398, 1.2408395976789537, 8.787592822505582, 76.28700902385097, 72.61983609968617, 76.63706487224948, 73.71416953302199, 70.30548864795317, 66.78163128514444, 64.55900845989105, 58.43057178681897, 56.188929388600016, 55.49808233014999, 56.50829661277033, 59.59414682080669, 61.245346992246574, 61.436931240943174, 58.234853359960745, 60.97891607592183, 62.83952374612132, 60.98804343131281, 63.84095976429602, 64.12531591230824, 64.29226375395253, 67.30959799981886, 62.10821743934386, 64.25977083944505, 57.256873115416504, 44.9497659744755, 49.69798334183232, 46.98867282559795, 46.25265967461371, 48.199767374223285, 49.584764126808416, 47.95817290582965, 48.32728755089545, 52.31568298032207, 49.76931948815623, 46.09504315160936, 45.70949377552156, 52.31153703504994, 56.61308665429392, 59.13614342289587, 57.91547436867991, 57.459079142539736, 51.34928549489668, 50.46042542303763, 44.743574819257184, 46.28306196581933, 46.07985573430216, 46.59486686029742, 47.09497297963789, 47.47062229341077, 50.347735727986986, 53.38790209062638, 51.4334987824963, 52.60332215216852, 53.150873261113325, 57.64235973358155, 55.77824938681818, 65.58895226447814, 39.61101616582563, 43.003885976729855, 62.36721154182189, 53.14047113541634, 46.94006289205244, 52.36341430294899, 59.67872096646217, 59.557378522811405, 59.706671776310095, 56.66969822299097, 56.650074605018865, 55.680974606544744, 55.24205746189241, 52.96228570322837, 41.91443197188839, 39.55021942815473, 53.23081900996547, 57.26574159437611, 58.11325988461895, 56.153624134679, 53.76140979028518, 51.577539982334265, 44.54643257202641, 42.44428142424553, 55.624512087914255, 56.56930908080071, 56.64808988571168, 44.340045298299486, 43.02079139217254, 45.810851743144376, 45.81777472649851, 44.129853325505415, 44.08335754948278, 47.123002236889256, 44.20294277129635, 46.74310499621976, 46.68923908664335, 43.608789982334265, 44.0652754229884, 46.99244614570372, 46.3313384979002, 47.22373654765468, 46.458721391616336, 46.10872830114057, 47.203712847925004, 48.32079995063044, 48.713484118061686, 50.00838402778872, 56.45277938535137, 58.98852894383093, 60.62192547705866, 63.784803190538966, 62.55939199078468, 64.85244489485218, 62.5135826295422, 67.02171956339191, 60.663686952283314, 63.55183793652443, 62.26284119390673, 71.91194242046726, 68.83704739232218, 59.902978558694166, 2.211855919130387, 1.0956761096754382, 0.7454618342941808, 0.06208386497511979, 0.07944504144571482, 22.555491616649014, 67.1214654368739, 56.685556365597634, 42.801464219247144, 16.59348307117339, 16.4989362993548, 18.713114261627197, 44.90132470284739, 48.69545690474972, 55.740535797611365, 15.155752993399098, 0.47188169352950593, 0.06204949060995733, 0.1106685559235273, 0.0805914307373666, 0.06351009086375276, 0.042645425776079784, 0.030402540184196927, 0.028088734402591665, 0.0742716190495318, 0.008214882428517506, 0.12712205609967633, 0.07584458908006068, 0.11237452647859052, 0.04529603636793552, 0.018362422744112632, 0.08191174497046778, 0.015573784175719467, 0.06594571420141766, 0.05413042058447196, 0.04154834956411393, 0.05444568108707186, 0.05543209972881502, 41.60912644478583, 91.11285440383419, 65.11507111210977, 72.50823682354343, 38.11493004522016, 31.11576053404039, 44.377150920129594, 49.132648206526234, 69.18397318932318, 79.68082412596672, 7.753447178871402, 0.1967556639424255, 0.19966931082308295, 2.3949509330334204, 4.3871945719565115, 1.1466491486757033, 0.678971469882996, 11.512700684608953, 84.54042111673664, 74.14111168153825, 79.32209199474704, 75.00942245606454, 74.109693496458, 70.13319461576401, 67.50711287221601, 61.38364976452243, 59.263663599568034, 58.582034111022956, 60.57817536015665, 62.38039070560087, 65.51300341083159, 62.49020922568537, 62.463831286276545, 64.4174030519301, 65.86053325283912, 64.78146960658412, 65.83397880677255, 65.17590707348239, 66.20409365623229, 66.4429267760246, 65.82513778440415, 67.01349827551073, 60.596422226198264, 47.319344320604884, 50.776113463986306, 47.87757996589907, 49.12672934993621, 50.175088682482325, 51.262981583995206, 50.58573730530278, 49.890159868424945, 54.279664716412945, 50.690805835108605, 50.10576863442698, 48.192032460243475, 55.06111068110312, 58.64398010315434, 62.10061980832008, 60.00697235907278, 59.06304613236458, 51.33130142765661, 51.07520203436575, 49.56708992681196, 48.48053455352784, 47.591811764624815, 49.52291619393134, 48.55090187441919, 49.32973946294477, 52.1633263557188, 56.75722983575637, 54.187081090865604, 57.11744070053101, 55.102825087885705, 59.30763729156987, 58.951172290309785, 65.95318748104957, 43.32182153578728, 46.96580932986352, 64.61591420635101, 56.2345112523725, 49.82716660345755, 55.535886133870775, 61.244421312885905, 61.20829628359888, 60.70455804947884, 58.430305065647254, 59.629389316804954, 58.899075369681086, 59.56548213958741, 56.366961848351266, 46.04430729343046, 44.04001928144886, 54.344525029582364, 59.47289851404006, 58.403758464321015, 59.08492119081559, 56.15256509473247, 53.43401347437213, 46.42866426898588, 46.82728298248784, 57.45103436131632, 59.07907685925884, 57.00753981067289, 46.82779289061024, 44.73030151859407, 47.09399238709481, 48.410018182569935, 45.279539246712964, 47.10976031518752, 49.04891344808763, 46.91318681163173, 49.97897017386652, 49.23772458107241, 47.71622934649068, 47.01898097991944, 50.608616490517896, 47.73240912345148, 50.34873201001076, 48.358725347826564, 48.99320010216006, 49.00553203398182, 50.23484599205756, 49.82615070958292, 52.83300438234883, 58.8189648812817, 63.03658362357848, 63.22465735097086, 67.08424998867896, 65.83144495564123, 67.41260728528424, 66.83064522281771, 71.83081211582308, 64.15480821363388, 65.0283710418209, 64.07349747996177, 76.10222616503316, 70.03708870180192, 68.86470794677734, 4.406650508603742, 0.853871733190552, 0.9618607740248404, 0.06286112246133628, 0.05286799195492941, 21.237987087618922, 77.18691841248544, 60.90443026634955, 46.66566171953755, 18.3118655989247, 20.319477819627334, 26.238279496469808, 50.615837574005134, 55.38261167464718, 67.84437394911244, 22.107741294368623, 0.7094629337230037, 0.017266177737544623, 0.09073947571338185, 0.11127876793785442, 0.06256656931532968, 0.07875312615426318, 0.09200597993068158, 0.04967179269559922, 0.04809481985566597, 0.05169476660329008, 0.1283459888110238, 0.12553715041928715, 0.12871931877828416, 0.161470573455576, 0.26550275483919733, 0.17877109108432648, 0.12166362601302325, 0.11807690194297223, 0.16472891393688419, 0.13953554564185683, 0.18698235853545128, 0.1690089399175298, 47.519746057448856, 103.16455641100484, 73.79548811143445, 84.78148998752718, 40.26383584545505, 39.90063221223893, 70.29281939229658, 62.52012514298963, 74.87137856022005, 87.36464531190934, 11.003779038306206, 0.3184052322420382, 0.4679732355138948, 4.6099155756735035, 14.24908143858756, 14.507753906711457, 2.950702492267855, 15.39782795213884, 86.24838582931027, 74.00433078888925, 81.04659341996717, 79.48494095956126, 76.95706752038772, 74.38374950039771, 70.01321715693321, 63.13018706537063, 60.28652360362392, 60.263620884187766, 63.592261883520315, 64.77514282349618, 67.16206981289771, 67.2427058989002, 64.01617596226355, 67.55537371481618, 67.70879330173616, 66.82288677461686, 67.60215190149123, 68.27996884622883, 67.9294030897079, 70.76940305771367, 67.49059184905022, 67.09823716071345, 61.6462093014871, 49.45441592124201, 53.28899560436126, 50.714445960137155, 50.465406833156464, 54.15017550991428, 54.04934706226472, 52.68946132352276, 52.335412502288825, 56.00584883843699, 52.90950236781951, 52.93218543452602, 48.512313596663944, 59.30653118318128, 62.478042033410844, 66.36323205886349, 62.4827527999878, 62.80006470218782, 56.51315250704366, 55.85406880224905, 53.3070541966346, 50.27565433133034, 50.1742414505251, 51.2474960665549, 53.516587211239724, 52.15377146197904, 56.54373914964738, 59.341585405411266, 56.70269712325066, 58.61466038611628, 58.07736235280191, 62.14800596237183, 62.117642894867934, 69.12206249852335, 46.69363214123634, 50.90994081189556, 66.69403691445628, 61.01568045154695, 51.044391816662205, 57.68249342518469, 63.57650964490829, 64.46570704060217, 64.54172649691182, 63.05628176658385, 61.53398244611679, 61.54367854518276, 61.35961348010648, 57.40287157797045, 50.05551522777927, 48.50939927562591, 55.05613711572463, 61.13014698028565, 62.14304024173368, 62.023639371318204, 60.73395621392035, 55.43088820672805, 47.01841223624445, 48.09343584122197, 58.72148221538913, 60.459731548063225, 59.30862965122346, 49.44596713589084, 45.949178049641276, 51.340762184512236, 51.28615494697325, 47.0360315230585, 48.87495240857525, 51.87115684632332, 48.83447747076712, 53.69969914036413, 52.361821820659024, 48.352006327721384, 49.3943722786442, 53.97661455215947, 51.57259779591715, 54.002384524191584, 51.840503523426676, 51.587757756633145, 51.73003388989357, 53.30706988611529, 55.150175940605905, 56.147642520166215, 61.124298726358724, 65.18166511289536, 65.81268033673688, 70.87209855356525, 66.56906235602595, 71.48218401016729, 67.66171701492803, 76.42858305285054, 67.02579882837111, 68.47671493407219, 65.61729923371347, 80.99775991132184, 72.85699828978508, 72.65538846292804, 5.315903963581209, 3.1312898858900997, 3.674954661438542, 0.10424298579774557, 0.19433128677548903, 26.525793152470744, 82.52743721008301, 70.01238561445668, 58.6349468846475, 26.31076881962438, 26.60845906503739, 30.61488563014615, 64.3302087629995, 65.26867897279801, 79.36499487969184, 29.524205884625836, 0.9714573429476832, 0.2128330149477528, 0.31221514988330107, 0.17260143262965066, 0.16247891370327244, 0.13369067782355895, 0.16542678939238672, 0.1557499650985964, 0.15222421396643887, 0.1599057316179237, 0.2184220247210995], [0.07060070191660235, 0.027991720858300408, 0.08286512607047636, 0.11158128839827354, 0.060547483303854545, 0.04646807811373184, 0.09307209852962725, 0.10388677023471364, 0.029886564645435543, 0.1319419135970454, 0.8951899192986951, 54.97184538072156, 72.51247298332953, 56.57170172660582, 44.89164429326212, 23.051206642581572, 35.205304084285615, 64.64548103270992, 45.817927698935236, 74.93862367445423, 55.876618508369695, 1.8957164378896838, 0.04840390185915655, 0.18425804262440051, 1.7680706227979355, 2.1805774684875243, 1.2733786000359444, 4.904993522551752, 79.24788859582718, 75.19703726614676, 74.58550053258097, 74.96958686459449, 73.01115528229745, 70.7364865272276, 68.21283355835946, 62.54023121249292, 59.46553622522662, 53.68230342864991, 55.3366336514873, 54.0878882715779, 53.48576914879584, 53.76434764554424, 55.62933268085603, 57.807424837543124, 55.779112308256096, 56.78216434294178, 60.75798857596613, 62.1558036342744, 62.66428009156258, 62.9913547731215, 63.553057793648016, 60.876302949843875, 64.0251934912897, 56.48680594659621, 47.54428440524686, 47.47794535852248, 47.446283986491544, 48.43009287311185, 45.224378954979684, 46.87184503001552, 47.96064399903821, 48.548646511570105, 52.5147589560478, 45.76667801026375, 47.27907726841588, 45.71608727978122, 46.37389229189965, 47.12676378988451, 48.21320933680381, 50.07784528117026, 46.48025520386235, 44.57251633367231, 46.674161495700965, 45.81900635073262, 46.423121959932395, 46.66293567226779, 46.69071782019831, 46.4950817631137, 46.0360977726598, 49.583548192055, 54.66883051779963, 54.15767508168375, 56.653318405151374, 53.27174502034342, 59.31097130621634, 53.98816200994677, 65.01796891612392, 40.322800836255475, 40.95110962467809, 63.34275991685929, 52.89123981229721, 49.44252329487955, 43.289669867484804, 52.852055334275775, 55.18047232781687, 58.91710650536322, 55.106119878830455, 58.24019170576527, 57.69003614302605, 59.28135348904518, 54.3533189835087, 53.58401667687201, 56.740983378502634, 53.01871292052731, 56.08185260526596, 56.569238478137606, 55.98215380022603, 58.76198460978847, 55.579369529601074, 48.36647202891689, 54.70919170687276, 56.36707951945644, 59.20082330703736, 52.294109944374334, 43.39602101233698, 44.290964680333296, 45.76500315820017, 45.02349868897469, 43.8081052226405, 45.532908670363895, 45.91176648293772, 46.773679871712964, 45.63400383918516, 45.29813912607009, 46.183924059714045, 46.66558327213411, 46.7573392775751, 46.020816218468454, 47.520679581549864, 45.998529311149355, 46.76508988103559, 47.55744787954515, 48.39380702664776, 52.80022513481879, 57.086081351003344, 57.88707248626217, 61.10857394433791, 62.174372134670136, 64.56636290396413, 62.55925078545848, 65.3265025538783, 63.50619331482918, 64.71918236824774, 56.174651961172785, 58.85692165743921, 61.84210815737325, 68.37173661878033, 64.5012515591037, 78.21247700721987, 36.66570448106335, 0.05025853560636601, 0.44513682864846726, 0.07895477581769228, 0.055475444983570814, 5.052292741114094, 62.591033750964755, 59.7704573600523, 52.07890910487021, 39.01145835076609, 26.47992103330551, 16.108873255791202, 31.83030459188646, 52.157560471565496, 53.557823088861284, 33.28924978933027, 3.615598169065291, 0.13106517193298187, 0.06879824258747601, 0.0676912761804077, 0.04922220633635598, 0.10464994702488185, 0.009732477708659586, 0.004190518661597443, 0.052686498064788125, 0.03266261064357335, 0.08503096388472665, 0.06840250454843044, 0.05626779823233524, 0.05585035309195519, 0.06281323047474989, 0.05214169846787568, 0.0699538479168569, 0.043851209864501035, 0.024734546745856924, 0.11727875323906062, 0.1474809959050148, 1.3214870830697398, 68.16968748646399, 80.03390019939792, 64.04184395267119, 52.86071200524607, 29.18551314261652, 31.93896209039996, 55.700511932373054, 55.56229545224098, 82.06109093081567, 61.417405682225386, 2.1309256553649902, 0.05758925776688322, 1.0852318184991037, 4.502505390874801, 1.5292617726710536, 0.857377841828331, 6.674137894184359, 84.70257189966019, 78.43611486496465, 79.38814470844885, 75.28864029915103, 76.07378113654353, 72.87650031428184, 69.83079556495913, 65.62528517938429, 59.59048332706575, 56.782733086616766, 57.64359135781565, 56.99011664236746, 57.45378002043694, 57.85867452621461, 58.56318712234498, 58.517318925549915, 59.05233021705382, 58.405860854733376, 62.74912880313013, 63.684967102543006, 64.83237020431027, 65.31795570927282, 65.82171747761389, 64.83186421855804, 66.54974076055711, 59.07602917763495, 49.62561953452326, 49.347401895830714, 50.05063972165508, 50.425077023044715, 48.80613050153179, 48.75341384641586, 49.63165998458863, 51.015311364204656, 53.346411258943625, 49.59425234025525, 49.724447573384936, 47.62633646688154, 48.18023789313532, 47.961907002233694, 50.64250969117688, 51.0472826034792, 48.09223951831941, 46.51229312342983, 49.28342803832024, 48.249208850245324, 50.86981496503277, 47.52991676330567, 49.722294192160334, 48.16243817729335, 49.3174232206037, 53.12400110306279, 57.6046932128168, 56.15663651497134, 60.44774478481662, 56.821933254118896, 61.70298953210155, 56.513117205712106, 66.94196993304838, 44.39402103424073, 44.65181489144602, 64.90953107034007, 55.07644714847688, 51.90531676815402, 46.6899686474954, 55.11008147270449, 58.916318108958585, 61.724209554733775, 57.94362129703645, 60.15011533614128, 59.368437951610936, 61.17689378799931, 58.487332405582556, 57.00644939176498, 60.252787297771825, 57.80808771810224, 58.041774688228486, 58.31740356260731, 59.49121598274478, 62.53632453180129, 58.03098424788445, 50.94768970243393, 58.0362049225838, 57.5111250723562, 61.65300284662555, 55.057164776709776, 45.02216116074593, 46.134968957593365, 48.45640020985758, 47.83651275019492, 46.55372904193017, 47.04615908284342, 47.68169679949361, 49.55746050803892, 47.524492125357355, 47.255288093320786, 48.159621915509625, 48.79623043921686, 49.257101089723655, 47.044292034641394, 47.26216400823286, 48.80511460765716, 49.81309706164945, 49.54484224319459, 53.15896118840864, 54.99636411666871, 61.23358772646997, 60.60347464776809, 63.10582914660054, 63.70797572597381, 66.22419188099524, 64.3111813452936, 67.69344898962206, 65.2892674938325, 66.35442241545647, 58.327256556480165, 63.548813789121574, 64.78663929047124, 69.91282801474296, 67.2237059377855, 79.71368574327039, 45.242919998784224, 0.11117602022544992, 0.3984461292143791, 0.2586415488152735, 0.06249470260715293, 4.806419457158735, 65.19465208053589, 67.2706017955657, 56.79568475292575, 35.50811890632876, 27.541279100602676, 21.361292677540934, 39.551050970631266, 59.91336107254029, 61.188245127277995, 45.438567822979344, 5.132900880229089, 0.15614321335188805, 0.04107207653202838, 0.027120864664715146, 0.0495053447722908, 0.08564564219165234, 0.042939718452192126, 0.07261598047109381, 0.04751841913187697, 0.09031749916292968, 0.05173960955993784, 0.1569411858555771, 0.09677365151864868, 0.22793634644439145, 0.18926617389004077, 0.15138470417549535, 0.14910003080243064, 0.1565485964379003, 0.20574167611137514, 0.2924821345556167, 0.31396498663290856, 1.9261004655591905, 82.28058676565848, 90.38882409372638, 76.65353098223287, 62.48392951103949, 33.49391906492172, 48.775657607663064, 82.67707563215687, 64.1932435189524, 88.56929148397138, 67.87220708785519, 3.150023861277488, 0.25394588949218877, 2.110191026041585, 7.254359895183194, 12.839790505747642, 6.411683770918078, 8.203080238834504, 88.55703799955307, 78.42413594645839, 81.53923526886972, 76.80878623839348, 78.47380884232061, 75.10008412022745, 73.68783473968506, 68.54510538039669, 63.58845718445317, 59.24902531408495, 61.92840422353437, 59.34670802085631, 59.712520030237016, 59.001088373122684, 62.81527173134589, 61.57320222546978, 60.053730933896965, 59.64772247499036, 65.42704466850527, 67.63517041360178, 67.8171056316745, 68.62215642006167, 67.7926221970589, 67.67529626046458, 68.22100777779856, 61.669480723719445, 52.57626564271989, 52.135504984086566, 52.06848736732237, 53.014437537039484, 49.38962228836552, 52.31465139696675, 50.42295894315166, 51.92555619824318, 56.8949560196169, 51.33539245974634, 52.46876132103705, 51.58450218939012, 50.145765043074086, 52.689343652417584, 53.27865231421686, 55.48459722149757, 51.365849664134366, 49.49724428115353, 52.679251393964215, 52.01415861806562, 51.639187874332556, 51.607044050770426, 51.714979833172215, 50.624396185721125, 52.301648739845525, 56.87414000111242, 60.00867466772757, 60.58932273618637, 62.07210417716735, 60.060206767051454, 64.92351432000437, 58.560002157765055, 70.18067882907006, 46.807765268510394, 47.64725054464033, 68.22248258898335, 58.639928294766335, 56.170921787138916, 48.82793495731969, 57.48026386384041, 59.88304115110829, 64.1677559575727, 59.985061999290224, 62.22263689964049, 61.6179290125447, 63.25193351314914, 60.79079135771721, 59.73249666152462, 61.163589108374815, 59.49709953800325, 60.03108316852201, 62.581639674402055, 62.43782989440426, 64.64725394402781, 61.540881895249896, 53.57976090523505, 59.68606756579492, 59.27905105775403, 64.3722055804345, 58.25114296328638, 48.21364864226311, 48.325757826528246, 51.6589605423712, 49.92432763499599, 49.55710749472342, 50.9295016719449, 50.7312297821045, 52.301578137182425, 49.86896730238392, 49.41678470180881, 51.56013250350953, 50.72795068064044, 51.7763178579269, 49.764083123976185, 50.521936032079886, 51.82198601384317, 52.334063206949544, 52.58174127148044, 54.24074695956323, 57.71372725886684, 64.09947141524285, 65.48933190684166, 68.9594018074774, 67.95307067132765, 71.15907484485258, 67.04974097590294, 70.3540397459461, 67.9943104713194, 70.25153252386278, 60.711324138026086, 65.18606208985852, 68.31412484568935, 72.9088520234631, 70.17834109644737, 81.8717267436366, 45.976987654163, 0.19616052087756897, 3.1818254580420837, 0.5777714389466471, 0.14438843685052088, 7.0328460008867335, 74.02012225120299, 70.91043579962947, 69.78244843021517, 54.16884991430468, 35.59767446210308, 28.155237897749874, 47.6258893166819, 68.60736908451204, 71.56562066847279, 55.922223906363214, 6.517735835044615, 0.30828539462339494, 0.14390776264331034, 0.15537467394624987, 0.07413803629817502, 0.21299357165492352, 0.23691296637538942, 0.13196926293594222, 0.25885712595716603, 0.10823939836794332, 0.16521953196535188], [0.012863022275269033, 0.09841341675529558, 0.021512777386834065, 0.0320024784248803, 0.07012157520699887, 0.02917900775378991, 0.01636330672960368, 0.051344239243095925, 0.1203477397681244, 0.11612888590823259, 5.885023695807304, 67.12887871649959, 70.71645890512775, 57.818583980683364, 38.725537177055116, 36.375472622533, 46.60469239757907, 51.62049778046147, 49.978393585451194, 83.07307812475389, 31.371667731192808, 0.12012088581198647, 0.07361704288350959, 0.22740645874892512, 1.5154056323151437, 1.3419259411673392, 0.377476770550974, 56.83627343946888, 79.7903367011778, 70.43631538268059, 71.97445715627363, 73.18493197041174, 74.27764938723656, 69.46150441323557, 70.76344105505174, 64.54256196175852, 59.23743078785559, 52.00652960808047, 51.031177351551676, 50.06147723044119, 51.84012305351996, 48.85108086370653, 49.89056387255269, 51.23612511542536, 50.127047492611794, 52.7234172821045, 54.990366812675234, 56.62478708451795, 61.53289594957906, 64.00899410247803, 62.20743379285259, 62.659671306610115, 63.928303103293146, 55.198507385869185, 46.19116867742231, 47.102923623977176, 47.79217427776706, 49.33352062779088, 51.38836014655329, 46.369762036108206, 48.41238337178385, 46.38245482598582, 49.89776534418906, 48.122575129232104, 47.751016847548954, 46.303925052765884, 46.36808326167446, 45.59805923892606, 45.37515094203334, 45.14504117350425, 44.83549948661558, 46.489853243674006, 45.145362807858376, 44.96225480110415, 46.93224953066918, 47.521479745065015, 47.18186916843538, 46.85942680604997, 44.54621684166693, 49.8055386543274, 56.93206556381718, 53.13914929666827, 57.80875844340171, 59.07920237510436, 58.604430844706876, 58.139469162110366, 63.31053372352355, 38.44240873090683, 43.69322684503371, 60.75570967889602, 53.58010215144004, 52.42239106085993, 46.03270100009057, 44.23576516489829, 45.25654631276285, 51.844747527953125, 54.40467065380466, 56.71954370314076, 56.492383556981245, 56.0526466369629, 57.4014477575979, 54.73991171006234, 52.62475398279006, 57.130541416906546, 53.310239161214525, 53.11890202183878, 54.5666096287389, 55.95428536015173, 57.61556994530463, 59.1347078354128, 57.461785577958636, 59.39315672843688, 53.93795959411129, 48.97483556501327, 44.84375999819848, 42.847171598865145, 46.06220114615656, 45.19008175019295, 43.818950576166955, 45.37416250474992, 45.21208624685965, 47.04078935807752, 45.85252300385506, 46.463024231695364, 46.14062893775202, 45.931193982401204, 46.43525385087537, 46.325713819073094, 44.57888626283215, 45.73966072451684, 47.998538017272956, 51.82069555405648, 51.12719697336997, 56.001844098491055, 57.1714517378038, 59.5813089032327, 58.79807433774395, 60.56354099704374, 61.69156759015976, 62.87393862201322, 59.40831276678271, 60.31699649749264, 55.06453883263373, 56.33077798351165, 55.154008096264256, 61.33276485627698, 62.62378161953342, 70.43446402395926, 63.96476937878517, 80.23010500015752, 12.014705231112819, 1.4894906551607194, 0.23836038225600797, 0.012030937791531606, 0.10281861384188938, 31.40852624370206, 72.02635795839372, 51.90142969931326, 46.425459692555094, 22.978950700452252, 13.818475796330361, 20.48153446566674, 38.39972157632151, 49.90320174924789, 49.39262290154734, 14.597853691347185, 0.3328115463016495, 0.04823491435437914, 0.03496375873744969, 0.017519335322562727, 0.04442966753436674, 0.08123557278586012, 0.049776662471553976, 0.047606480938773, 0.03402808192937124, 0.0059286577274061504, 0.05979519262309036, 0.0817241300378115, 0.05563787477571638, 0.029558958635935863, 0.0742166905453609, 0.04447808429118126, 0.008950149677994271, 0.07546483163511561, 0.01207297016310716, 0.09056640879040764, 8.608859239086028, 79.92903171047088, 78.13787352654242, 66.79197065291866, 47.93205776522237, 44.872840450656035, 36.97070406329247, 46.724544340564364, 59.24231413872012, 89.74017389359014, 35.491087975040564, 0.15232817209776373, 0.07706991607143034, 0.8524879945381996, 4.311336913416463, 1.465762889673633, 0.13182922206338377, 60.86572823985931, 83.26920447811004, 73.56210708618164, 73.67265516711821, 74.84167837327527, 76.30576579801499, 72.95950551186839, 71.49595937421246, 66.89521528059437, 62.72113092484013, 55.778080724900775, 52.45906914434126, 52.748241962925086, 53.2514859784034, 51.43420088675715, 53.68223674835698, 52.33880927485805, 52.95500186181838, 55.15773042555779, 56.69588004389117, 59.00682287831461, 64.395116144611, 64.56340543685421, 65.09837358228623, 64.59012462246802, 64.9562543438327, 56.95656861028364, 48.06854448010845, 49.34567605295489, 49.730099708803245, 50.44585774021764, 51.529153623888575, 48.3962663527458, 51.52967137675132, 47.895014901315015, 53.060772495885054, 49.41563544734832, 50.40740674541843, 47.14398299494098, 49.30104340276411, 48.170098566239886, 46.90941349152596, 46.61117999784408, 47.26143052501064, 49.00516333118562, 46.40099194742019, 46.83005609819966, 47.8990549425925, 49.410171585698286, 51.386724518191436, 47.86136096523654, 47.542021197657434, 51.395836184101725, 57.94495490289504, 56.38826424075712, 60.81432557875111, 60.03408378170383, 60.876267648512325, 60.25029267034223, 62.07757196118755, 40.67808128172352, 47.017408109480336, 61.76020906817529, 57.04030729109242, 54.32563489483249, 47.65693095422561, 47.179178422497166, 47.47809048621885, 52.57621465190765, 57.377211432303156, 59.41530243042977, 59.997946985306285, 56.839301509241906, 58.963578747164824, 58.740121318447976, 56.19427557914488, 59.75323031025549, 55.669850764736054, 54.295491480058246, 56.95298748631632, 58.9092460755379, 59.032235914661044, 61.874985464157604, 59.90536335975894, 61.17388140770697, 56.98714348577685, 50.45920556591403, 46.11067379674604, 46.8908332240197, 47.38620504256218, 48.23355859325778, 46.90271016090147, 46.67745236427554, 47.85494396763463, 48.508089203988355, 46.66982335429038, 47.95114794085103, 46.73324023523639, 48.61324402593797, 49.46607712776431, 48.7629020598627, 47.39895666799238, 47.845526356850904, 49.90843026868759, 54.387894676577666, 53.14307558921076, 59.32191864136727, 59.5991752993676, 62.10022757130285, 60.17788571696128, 64.5690183485708, 64.02048272471275, 64.64640278970042, 62.108244895935066, 62.73967196864467, 55.85134275497929, 60.43764075925274, 56.909523702436886, 63.393978226569395, 64.85691639684862, 73.00607189055413, 65.98901441020351, 83.93697231046616, 16.092192396040886, 1.2930735561155504, 0.2642255330518369, 0.08612008044315923, 0.05622316978030628, 32.49851957444222, 78.5728173102102, 57.28145068691623, 44.939787464757124, 25.21400155559663, 24.904261789014264, 29.96074607295375, 46.676691424462106, 59.315525177986395, 63.52306342894032, 20.40757425369755, 0.3932221756587106, 0.15720652806903088, 0.050288313443982796, 0.0061973415206246565, 0.09485457828568836, 0.07901185702893042, 0.039027606197182214, 0.050727741477350076, 0.046032652889768925, 0.08969407213190872, 0.13812367624092486, 0.25140764101618723, 0.21187517521602495, 0.16788438413172, 0.18129956427841418, 0.17938396142375085, 0.07220367961112531, 0.21212332641645787, 0.37133026327336993, 0.3209705236217668, 13.617625928694203, 95.0711456421883, 85.36028277489447, 76.19015785955614, 53.70705358443722, 51.322727126459924, 60.75310130273143, 70.31620456326392, 63.998890076914144, 97.93941020965578, 40.10159092564737, 0.35374204898553513, 0.19792557213335268, 1.4617483438022676, 8.116807216598142, 7.881667988915598, 0.6400801890319394, 66.1997712043024, 82.2021628964332, 76.7757441920619, 74.42122382502403, 77.60897328776699, 77.09794336749663, 76.37278341477918, 74.80608678633168, 67.37485055000552, 64.22776429883896, 57.53662047847625, 55.146716410113925, 56.95483884503765, 55.88018002048616, 53.97482202899072, 56.847558098454634, 56.24747468579201, 55.15151739120484, 59.31001817026446, 59.87555334644934, 62.405250687753, 67.23972489756923, 67.89956954217726, 66.09851914067423, 69.22470308119252, 68.97863711080244, 60.65950570567962, 50.40228020760321, 52.173340166768725, 52.12551862962785, 52.92777669045233, 55.933508565348966, 49.422989891421416, 54.61059116548108, 49.76775838482765, 55.97277149077385, 53.2515291244753, 52.98511782000142, 49.925637706633545, 51.12354132436937, 53.44436460925687, 51.32931278597925, 50.2232789224194, 49.84406417415988, 52.4883064916057, 50.49288303621354, 48.94586886129072, 52.466113721170736, 52.99772039536507, 53.88821609558598, 52.15937260658511, 48.85237916823357, 54.74806631765058, 62.73706751485025, 59.17135846230292, 64.24488152227094, 63.52678575823384, 64.12494720951204, 63.36677658942438, 64.38168202677082, 44.3357503029608, 49.71954853303971, 64.95073556900024, 58.18624734878541, 56.09461992017685, 49.59707252440914, 50.15699086650726, 51.20393030105099, 56.49068124832646, 60.25573692014141, 62.80372819592876, 61.22421718412831, 60.518814209968816, 62.772843453191946, 61.646138698824, 57.70499606286326, 61.30472775428527, 58.48728925951066, 58.03731103097239, 59.47269062842093, 61.78984649719731, 61.813957306646536, 65.44521308714344, 61.99193877558555, 65.79273508441064, 60.27709422572967, 53.01289212319159, 49.194252952452636, 48.64918470382691, 50.295270104562086, 49.86891631157168, 49.123246285223196, 50.03035714549404, 49.402562187563994, 51.16984098188339, 49.35126150808027, 50.983524476328206, 48.53492998307752, 49.14662753382037, 52.36234349589194, 50.11303678635628, 50.57788864258797, 49.90737122874106, 53.38121837185275, 56.988328041568884, 55.22945880889893, 63.247858170540106, 63.35214222631147, 65.31886177678263, 64.0398710004745, 66.2620976663405, 67.44255850392004, 69.21694463299167, 66.62887065641343, 66.6212220345774, 59.49572278607277, 64.30591752452236, 61.369270355470725, 67.60802761200937, 68.85179550417008, 76.60653314282818, 71.62010239016625, 88.62229054973972, 16.69926154998041, 2.937231847355443, 2.6855005035477304, 0.15049184402150495, 0.2162908906898191, 39.7421488454265, 84.9206635259813, 65.60549289949479, 62.28796005249024, 33.17444201438658, 26.509911475643037, 34.03312729251, 59.20271388946041, 68.38255451571557, 75.17625654897383, 26.871869756329446, 0.8534739803402656, 0.2862193964181408, 0.17048968062285455, 0.13876806343755416, 0.1370145341441516, 0.18890738427158327, 0.12825375182494042, 0.2209051608318283, 0.15624737066607322, 0.14998660903544198], [0.03624625887060839, 0.15132721693765733, 0.11421342094939564, 0.03208627886769753, 0.050254076974646705, 0.01338900292232152, 0.09166411319447142, 0.05487353353190327, 0.11256549687635516, 0.16497374031572573, 13.9785869467643, 72.24907798151817, 59.591020691779356, 60.153676848257746, 26.62684125284995, 47.90673886576007, 47.35319437519197, 46.34381555741834, 64.1799545288086, 76.53542841634443, 18.669254318360363, 0.2877191514257462, 0.520245099980985, 1.5484973211442272, 2.7454127467447713, 2.1980523630496, 12.50905821400304, 84.00562947796237, 72.03459493575558, 71.32502248210292, 64.4007525905486, 74.40817017709055, 70.94986346460158, 73.08921044872653, 69.91158070102816, 69.64673442225303, 64.97370104635915, 59.9511609538909, 55.32445861447243, 52.9303889889871, 48.627784252166755, 48.832755550261474, 48.764580834296446, 49.77837624088411, 47.95119893166327, 47.758308533699285, 47.820584004925145, 49.96353172486829, 53.16041638774257, 57.561574597512525, 60.72835899168446, 61.85886060037921, 57.760156354596546, 49.09125935646796, 49.13442896258447, 48.42830427231328, 47.69809622918406, 46.52000842555877, 51.299691046437914, 48.92320932880525, 48.48693978401923, 48.570541181871974, 48.698316312605336, 48.09864082644063, 46.04708040914228, 42.95021226329189, 45.86709853141539, 47.041299266199914, 47.172514315574404, 46.1313368428138, 45.18071120785129, 46.27516623466246, 46.739488570920884, 46.528614105716834, 46.70296345987628, 46.151921441478116, 44.52648731970018, 45.26945091062977, 45.147535800933845, 47.82446715139574, 56.651141489705736, 57.380404241623424, 58.31514035501788, 57.435976382224794, 60.17155108913299, 58.14902013347995, 59.026595546353256, 27.796437125052176, 40.82579774241294, 60.23066905237014, 56.12963099633494, 56.41022166898174, 53.26026032047888, 52.69630585947345, 44.90884388646772, 41.808735862854995, 45.18641825645201, 52.84985880697928, 55.902753260827836, 57.082088378167924, 55.323285825790904, 58.250472237986905, 57.552745342254646, 55.90514982900312, 49.43357244614632, 48.773637587024325, 50.46084903901624, 51.74066351306055, 52.37318100467805, 52.07914444708055, 51.26480548612533, 54.175474797525716, 46.284564233595326, 44.47734786618141, 45.90470621662755, 46.30951050789126, 45.38031278118011, 45.65898541481265, 44.986212638116655, 43.541148708712676, 45.30188891195482, 45.286615202503825, 44.70569649050313, 45.7144751856404, 44.679267560282064, 45.441721408597886, 45.08859434435445, 44.6666532178079, 45.17835386337773, 47.59558508473058, 53.15360715312343, 53.53228453666934, 53.538670155309866, 56.9316380254684, 55.57595314518098, 57.22072847427861, 57.6986300560736, 55.04375027072046, 58.660053976120494, 55.129940432886926, 55.474963880354366, 54.195706382874526, 53.85277355870893, 54.520737509573664, 57.5197385972546, 59.35990287411598, 57.356905321921076, 67.44932067009711, 65.47810216103831, 74.58775981780022, 53.29634220369401, 0.40433480194018734, 0.7329162558720959, 0.16127820877778917, 0.14997465806382318, 8.088173424043964, 67.18769857960363, 60.07232296851374, 51.45394217583441, 38.48602940959316, 18.494971644493845, 10.797769292708367, 37.279626015693914, 46.6997157373736, 60.47391876097649, 31.066266106021022, 0.7844025124945949, 0.05655108222497567, 0.08321071599399851, 0.027296653115040353, 0.1159386049895998, 0.011656999741981347, 0.05399711362476792, 0.056108586009471655, 0.05016904504549119, 0.07652856003973754, 0.07385977784231787, 0.0636594703481082, 0.04828441895604615, 0.022311006529977726, 0.03493234913255419, 0.05029440001254121, 0.1172420959318838, 0.040982635766868634, 0.14847497966501022, 0.12906128510592446, 19.352980313762544, 85.90008720274895, 66.570952938449, 67.55451863811862, 38.98579036035846, 47.79886191891086, 30.96519054905061, 53.55196306782385, 70.29766744182956, 84.24407036073747, 18.580747996607137, 0.40999518046456, 0.1298489460661527, 2.7103271455534044, 2.554332277467174, 2.8080211291390085, 16.02165641323213, 89.82093549543812, 74.62924280474263, 75.1411513359316, 67.01971130986368, 75.40085146504065, 70.94734530295096, 75.52995235689225, 71.88155189637216, 72.41764576204362, 67.37290505440005, 62.28176270761798, 55.47073948767878, 53.45496285346247, 51.052715086167865, 51.843876761774865, 51.29589026974094, 52.108675972107925, 50.30557024863459, 49.92683795190627, 51.34179376786756, 53.109296137286776, 55.45980784200854, 60.33865582558417, 64.0800674500004, 63.899352089051284, 59.01433029482442, 50.312132373932876, 50.292897070607836, 51.13916804713588, 48.53382387468892, 47.294507872673776, 51.856765670161096, 50.12037161857852, 49.000629071266424, 49.9457202419158, 49.6205557546308, 49.120324119444824, 49.18797716017693, 46.91395167381533, 46.72032779262912, 48.609604066418065, 48.11800164561118, 47.216531153648134, 49.73843082304924, 47.81019756870885, 46.97307748179282, 47.45491712324081, 46.72617604655605, 49.13255799201227, 46.403937647419596, 46.30350143678727, 47.16854879933019, 49.59373850976267, 58.444884515577755, 59.426112482624674, 59.72399296299104, 59.19659891436177, 62.33636994515697, 61.28097388052172, 61.37252200034357, 29.507112195414884, 44.48530635526104, 62.176890296320764, 60.068424132562455, 59.838635998387495, 56.77572773348901, 53.67958130375032, 46.012649843769694, 45.82783560599051, 47.896317128212225, 54.67791864948889, 57.56035081801876, 57.975361116470836, 59.44404163668233, 60.547482813558275, 58.72851894747827, 55.1813901624372, 51.159046619169175, 52.80350031391267, 51.35650265601374, 55.88764821329425, 55.55351326542517, 53.11819991757793, 55.30960067625969, 55.155545665371804, 48.59104733313284, 45.963741810091086, 47.4785376364185, 47.99757311421056, 48.34109037153183, 47.260230279737904, 46.945005078469556, 46.482471343009706, 47.308271469608435, 46.69380080315375, 46.78452914760959, 48.066857860934356, 46.58640238546556, 46.41319444102626, 47.23171464858517, 46.05592143151068, 47.65550713385306, 49.744788985098566, 56.52888513380482, 54.942941434921764, 56.56730474964265, 58.99391043570734, 58.834124841997706, 58.63994006187686, 58.111675247069336, 59.51971200204665, 61.70054197311402, 58.80964140738211, 56.00362093217912, 56.80822064799648, 56.78846366943852, 58.22068575889834, 61.00203844808764, 61.67536427897792, 59.51581316609537, 68.19624193253057, 68.05298128435689, 76.23316272612541, 57.76573396498158, 0.5702054320323853, 1.7664821854522152, 0.13660714390777773, 0.059919195444954026, 7.986746324646858, 72.01701487264326, 69.45772324838947, 53.44902438502158, 36.57544682102819, 26.04060772926577, 15.984082068166426, 44.132544071443625, 54.79369524986514, 70.26864974729477, 40.90244085558, 1.1508155638171782, 0.05153620172472251, 0.06316954562921198, 0.04303528792074612, 0.015300198856200424, 0.10802179109305145, 0.0352035672403872, 0.040740797130931775, 0.027217146595038717, 0.08358746271340117, 0.20066983697395172, 0.2542466709330197, 0.340640903600762, 0.15212508218903698, 0.08337926299821946, 0.17277049291278088, 0.3996587238244472, 0.1921967819573418, 0.17379035512285848, 0.5107960795923587, 27.25314178774434, 101.1606567136703, 74.36886802796396, 81.02387505192911, 41.379899209545506, 59.9537104945029, 61.545184735328924, 65.89010007919805, 76.00546129288213, 90.71341591496622, 22.104640660747407, 0.4422181868745435, 0.6326320370839489, 4.106553398793744, 12.260062233094247, 7.019489840153725, 19.326108155712006, 96.07512335623466, 78.22480893904164, 78.1596113020374, 69.86552423046481, 79.02741216844129, 73.08989294113653, 77.61533537218648, 76.31553249974405, 75.03800084514003, 71.7115249941426, 66.24312123944684, 58.48207250718148, 58.48384934086954, 53.220495331671934, 54.727065947748, 53.46385878901328, 54.77586023269161, 53.043317948618245, 51.34881873284617, 53.271352783326186, 54.90980917407621, 57.36575811139999, 64.10810847436228, 65.53871454731112, 66.3705982700471, 64.455983484945, 53.01169580028903, 54.79611142989128, 53.15163027855658, 51.650923605888124, 49.63931252879482, 53.87010259013022, 52.31059174383841, 52.04767134881789, 53.02364333983391, 52.838542769032145, 53.104200978432935, 50.57719438306747, 48.50845398441438, 49.278427016350534, 51.846206649657226, 51.924603062291304, 50.39852257697813, 50.93584806688371, 49.686133861541755, 50.29472881747831, 50.94386146914575, 51.0449880169284, 51.344649253353, 47.39988626972322, 50.26634262454126, 49.98381037865916, 54.938611138251524, 61.68617433117282, 62.88896522214336, 63.74154336990849, 62.79913117808681, 66.12898026743244, 65.40503624946841, 61.482014963703776, 33.08950701067525, 48.39137907951109, 63.97987442631876, 62.36725861026395, 60.51417796842514, 57.817673990803385, 56.572168488656324, 49.2188540581734, 48.363020343165246, 50.56416034698487, 59.265338451631614, 59.651837041301114, 61.76339011038504, 62.8920913511707, 63.85767298360025, 63.26878009303924, 59.97520508304719, 54.038858644423954, 56.36507911066855, 54.197079212434836, 59.03443636432771, 59.193257054974964, 56.16886254279844, 56.34514954782302, 58.701737003941695, 51.22068274405695, 48.71040897984659, 51.14664408468431, 50.0117023529545, 51.46330879580591, 49.24991530756797, 50.16654183787685, 49.438553856265166, 49.43403920819683, 49.21565340411279, 48.37051991493472, 49.66799289949479, 48.85795285624843, 49.27992536175636, 49.34035339663106, 48.70618066480083, 51.0410068112035, 51.60852278432539, 58.82106727169406, 58.51818184698782, 58.97759337579051, 63.0493313266385, 60.88859173559374, 62.36720761945171, 62.01350396679294, 62.07052738435807, 65.03894967417564, 61.327430432842625, 59.73389694767614, 59.13710440358808, 60.83131728633758, 61.77234095911827, 66.17222047621205, 65.0841236114502, 62.269520990310184, 72.90457663997528, 72.04381250566053, 80.25376473703693, 59.77729405126264, 0.4514624779262851, 4.624610245227814, 0.8465381267089999, 0.24619729318205388, 11.408169519516731, 79.33183516225508, 72.91131527193131, 65.39830153988254, 51.73674898762857, 26.403297531989317, 19.54330155926366, 55.03326185287968, 67.20872248372724, 79.61047249455606, 49.116311534758545, 2.090457581704663, 0.23608575995650985, 0.22575570781144405, 0.18066030987087758, 0.2176072136048348, 0.19388087304128757, 0.1354310150829054, 0.13093138233788554, 0.19910445887475245, 0.17995195433257088], [0.07967990102066148, 0.04778427845467964, 0.052179336367595586, 0.06150486721326748, 0.08744017251076237, 0.04126235362022154, 0.0538382193283929, 0.010686148006859566, 0.03399143611351329, 0.11295535902102148, 20.428623653227284, 66.98758709815242, 54.55210862621185, 44.214823630548295, 16.256399481527268, 66.32392990973689, 66.42370716218026, 42.90781144172915, 72.26840742172735, 67.46635160138531, 4.90243515660686, 0.2602569524559283, 0.3040291020466436, 1.8964198904652751, 2.5633373039384044, 1.8098182471529132, 41.53380517036685, 77.07749997415851, 71.43681787675428, 61.15871360225063, 65.76789079173919, 70.92674501480596, 73.60399015488164, 69.26534668091806, 69.96224203417378, 68.83987934358659, 67.82501312994188, 64.44255328947499, 62.67763576199932, 62.64580965042115, 56.88504419019146, 49.29893708998158, 48.74785192551152, 47.2275020230201, 48.107572063323, 48.98647715968471, 50.04292441952614, 46.4508060486086, 46.13093283868606, 47.868593815834295, 51.39306699076007, 47.67905704436764, 46.091018799812566, 46.97076720576133, 49.27911343113069, 47.62680322893205, 48.39021805794009, 48.73473159728512, 47.93385813313146, 50.33494880122524, 48.39725871239939, 48.988183390709665, 48.46707297909645, 47.58015840284286, 46.03611738451066, 44.123114693549375, 42.7295946305798, 43.39418534309634, 44.025220178788715, 45.253902635266705, 45.43879139807917, 47.995404043505275, 48.03041511966337, 44.157662930027136, 48.17688034426782, 45.61321919964206, 45.31926893418836, 46.28239516289004, 46.04081246160692, 46.86949945265248, 55.73265967830535, 56.42539731917843, 58.010078014866004, 59.15693198480914, 60.18119227501654, 57.53470243946199, 59.94885852259975, 32.03688013938166, 33.67703099404612, 52.71363096852457, 58.165823567298155, 56.67744490408129, 57.209934111564394, 55.76330515646166, 53.911471828337646, 44.6023851825345, 42.841539075297696, 42.48370516684748, 47.53956579392957, 48.743549085432484, 50.97577779523788, 49.79823520106655, 48.934003691519464, 47.19509540065643, 45.16131116497902, 43.834173294805716, 47.88647982382005, 44.84903950845042, 45.86538053327992, 44.99220601973995, 43.1783922256962, 42.073362488900464, 42.20416961177703, 42.83219598954724, 43.37308299156928, 44.31778976994176, 45.25731117494645, 44.518956368969334, 44.47660261584867, 45.12786511451968, 45.47725808235907, 45.26218275870047, 45.40245848317301, 45.50569526610836, 46.64346894910259, 44.924168586730964, 44.59767049358737, 45.66466500682216, 47.727231594824026, 50.94121386927944, 56.32076417246173, 57.483860677288426, 59.22399274764523, 58.914604033193285, 58.099092283556544, 58.64810643657562, 59.124031143803755, 54.52311838826826, 58.97030561201034, 54.2357067138918, 54.05443045400805, 53.024902420659224, 55.47863521883565, 55.586492553834, 58.507583602782226, 59.69538319495417, 62.71019143442955, 60.86537914891397, 68.3917877751012, 66.04712824667654, 76.48818738998906, 8.883305518857895, 0.8845869559914836, 0.6137915448315683, 0.10701891305225511, 0.2883690697771888, 40.23789328913535, 67.92999928997409, 53.672117033312404, 49.54956477688205, 25.531464469048288, 18.655751559042162, 29.126816834172896, 43.388223340434415, 52.21953784265826, 52.651186835381296, 7.8239302096828345, 0.08691083639860155, 0.05982986959298292, 0.03948516370127759, 0.0891061456152989, 0.04901051709067918, 0.018113595471086524, 0.023501405657659617, 0.03884604335912774, 0.05971928097067341, 0.030607127794815652, 0.009012196096591651, 0.06993265026399205, 0.1105005375199741, 0.0799495792917667, 0.003034997841290709, 0.04958472680300475, 0.005282246622241913, 0.019455559348927873, 0.1059298271373395, 31.195427794610303, 78.06733362136349, 63.39548441671557, 54.10296194015011, 22.092897084451494, 66.35384974941131, 59.99945317545245, 51.02034768750591, 78.86677542040425, 74.16474003945628, 4.812145627314045, 0.2246545177073248, 0.024033400094917706, 2.4873668772559014, 1.8173988403812533, 2.700892864696441, 51.934785535258634, 80.37464434100737, 76.26590667232391, 62.65135980421498, 69.10522768574377, 72.81902190177672, 76.70846769886633, 71.32077847757648, 72.847914080466, 70.2053113137522, 69.43171793414702, 66.90038496448149, 67.21197020622992, 64.21467142720377, 59.31330511646887, 53.349784497291814, 51.41127071072979, 49.2308682780112, 50.350430396295366, 51.4904555197685, 51.97613516161519, 49.389743881840865, 48.60650931635211, 49.10257539441509, 52.60922531927786, 52.24473122627505, 47.365895009809925, 49.42994425373693, 51.20941769692206, 48.04345700048631, 48.70919696746334, 50.65206066254647, 50.53763727987967, 51.43439308289559, 49.94501421528478, 49.17790451357442, 49.2864796423143, 50.408210831303755, 49.26303563579437, 46.42821711878623, 44.954100193515906, 43.741377861269065, 44.955049407097604, 46.20177476636825, 46.76288158662858, 50.21820337541642, 48.61471099238242, 46.67985285482099, 49.97419664936681, 46.71653093830232, 46.35861466007848, 47.918709939525975, 47.02791613917197, 48.55002718587076, 56.850233154912154, 58.552588878139375, 58.850563495389885, 60.66779367385372, 61.46114795438705, 58.901734736657914, 61.29877359636369, 34.629009846718084, 35.77852710600823, 56.29350762213431, 62.354561898016165, 60.7516029573256, 59.41531811991046, 57.79318271144744, 55.10278194181381, 45.59133629645071, 46.323160356090916, 44.51909757429554, 49.71458281240156, 49.85258748454433, 54.246752108297045, 50.90625378393358, 52.35599710095314, 49.59288343306511, 47.389786166529504, 46.35650834729595, 49.33746260981406, 46.46465986005722, 48.50249198175246, 46.43573630240656, 46.465856182959776, 44.74038200993692, 44.763841705937544, 43.081646965396025, 44.395115375518806, 47.3096364544284, 49.080261030504786, 47.34864442579208, 47.36101950368574, 47.27866149717762, 47.48178535892118, 48.08968213296706, 47.73920659096011, 48.32702082972373, 47.25549597893992, 46.93600716129426, 46.02517004935972, 46.83459035811886, 50.609471567215465, 53.1407613908091, 58.972102057549264, 58.285934386714814, 60.8851400498421, 63.51040594039425, 60.494213104248054, 62.644413286639804, 62.23367444930538, 57.85599554738691, 61.22030265869633, 56.260175320409964, 57.303082558416556, 55.03499161812567, 59.33601563976657, 57.59515008618755, 63.2367657076928, 63.85480573100429, 65.41196707756289, 63.76759575259302, 70.611096197559, 66.93614129097232, 81.09897275124827, 11.640613098298351, 1.678231798352734, 1.5230043665055306, 0.09416022683463751, 0.23703973860509936, 43.492444638283025, 74.50360928812336, 58.2527119113553, 41.77433667644378, 26.139633847821145, 26.13450534882084, 36.925824303780836, 53.44103451698057, 59.708385852075395, 64.18984282401301, 10.655584354554454, 0.16402849506947303, 0.07099071727885355, 0.07996320799593964, 0.10859861699563843, 0.045186458981686065, 0.0531349276312657, 0.00443227063383787, 0.058075206489452434, 0.06634143691870474, 0.15483373926291544, 0.20579141053941943, 0.2517757002985285, 0.23552867613973158, 0.21883447113777363, 0.14113734356097637, 0.15051485730275033, 0.25858737107726837, 0.15037458660381456, 0.20718426563807074, 43.53579859579764, 90.0780939286755, 72.66825383709323, 65.69294998722692, 27.89724792203596, 77.16059146388885, 81.6954711175734, 60.53941057574365, 82.70795253015335, 82.26361074755269, 6.092172399643929, 0.35760543038768156, 0.5385128649011736, 4.331598897134104, 10.728093289559888, 5.39089624920199, 61.028341862463186, 81.05940388094994, 78.89420847738944, 63.68506908416749, 71.51777559711088, 76.12989456422868, 79.47831999871039, 72.6457315875638, 77.0436263853504, 72.81571142135128, 73.22651693897863, 68.3241190448884, 68.58665112526187, 67.61902593797254, 61.92029276201802, 55.53439563320529, 55.025997623320556, 51.33332144829535, 54.51450486336985, 54.49441448334725, 56.337100844229425, 50.31262659257459, 50.955640346773215, 53.02820113397414, 55.49341078727476, 54.919709236391135, 49.76034510520197, 51.7878496262335, 54.3407517094766, 51.40196292631088, 51.01000439736151, 53.956453569473766, 52.750611074509166, 54.12488798941336, 53.26817958585678, 52.97901853438347, 52.36634431346771, 52.580678309163744, 50.323919096300685, 49.11993580479776, 47.71011437139204, 46.52749230784755, 47.69693912998323, 49.10443459787677, 49.38600586306665, 53.288273888249556, 51.453655842811834, 49.99885266826999, 52.13232394187681, 51.46034348395563, 48.419122003739886, 51.25084577068206, 49.006132156618186, 54.12270715159755, 60.92393621321648, 60.267904112415934, 62.679071349482385, 63.439493410048954, 63.473437601520175, 61.28142887546171, 64.05277167597126, 39.155056322774584, 39.51713423575125, 58.92865004078035, 63.84344262461509, 63.52771928233486, 62.045600721913004, 59.34487235161566, 59.44701871564312, 49.74691490973196, 49.28270239983836, 47.33051523085564, 52.876479933338786, 53.89414279691635, 56.5293832748167, 55.08734741518575, 56.31539444769583, 53.43086381112376, 51.02866311227122, 47.532034843198716, 53.16787673581032, 49.615091892980764, 51.181863046461544, 48.488100805590236, 46.802634808325, 46.45340658003285, 48.35195533690914, 47.338489409415956, 48.63947291528025, 49.12977310918993, 50.88632029871787, 49.5112471426687, 49.338274540439734, 51.15117049986317, 51.07621008350004, 50.963500776598536, 51.35754600647957, 51.232124297849595, 50.795976346538914, 50.03500515414823, 48.443836858195645, 50.19998004359584, 54.558302048713934, 55.370923011533684, 62.25531808791622, 62.98021131946195, 66.01842434175553, 63.645319784841234, 64.39944251891106, 65.1875800471152, 65.0144152487478, 59.72340852983537, 63.76314778481761, 60.17978022175451, 60.81898535451582, 58.685510158538825, 61.81510263873685, 60.009435607541, 66.21247183892035, 67.12148897109493, 69.50625865690171, 65.80540434006723, 75.09063120811217, 69.98291292498189, 86.37034800744827, 12.068465236694584, 3.198025582298156, 2.7679097460162256, 0.22378822548254845, 0.8685425620886588, 50.90546146515877, 79.90237528277983, 68.16698889578542, 63.071826119576734, 35.08010595075546, 30.573084931219782, 45.20777556204027, 66.81115104306129, 72.56464835136168, 76.30268281505954, 14.158807108479163, 0.34878962763374854, 0.13557752173754478, 0.23406244513969268, 0.2859269040486505, 0.15840790715188752, 0.10776914295650299, 0.12636229606165042, 0.1621979739396803, 0.22277518145499692], [0.0331576758124415, 0.023251695468300776, 0.04180777757879227, 0.12271639936032797, 0.04596603005343387, 0.06914659808840483, 0.03943390092782436, 0.02146450044106572, 0.05561069780660253, 1.0221849273770087, 46.184943875958844, 62.66439384029758, 53.14589577336466, 31.884090092874345, 26.46608095015249, 18.055054295447565, 37.984464168548584, 59.66672635847523, 76.8753880839194, 53.1804596993231, 0.7410470228041373, 0.016686641798925497, 0.1823523376257189, 1.2665701008612111, 1.6237351226229824, 2.6378035016598242, 83.49393275476272, 82.3659610748291, 73.99153601738715, 62.793828133613836, 56.713773896617276, 71.84595246468821, 73.22223371075046, 67.93506699223673, 64.18685005557153, 66.36053346818494, 68.14792617674797, 68.45589499319753, 64.28275200628465, 65.12692059240034, 65.4079701823573, 58.658504639902425, 51.15950161410917, 49.39679238104051, 46.8508642719638, 46.36033658058413, 47.09153306099677, 47.845969584680375, 49.51822896157542, 45.98190238398891, 48.04734014695691, 46.7833524365579, 46.96338530509703, 47.25937128067017, 45.70853279482934, 47.0658689929593, 47.73071465953704, 48.74882075094408, 45.162817355125185, 48.01589450528545, 48.05362770634313, 47.10205678016909, 48.139457010453754, 46.24426580244496, 43.01414689710064, 44.98320810256466, 43.20972411863266, 42.872008046796246, 45.16241335099743, 44.10680940074306, 43.088656240893954, 44.32490887180452, 46.646402881991484, 46.635404556028305, 46.247125210300574, 44.6563099276635, 44.440046125842684, 43.92835724738337, 47.14174724394276, 45.71497724902245, 50.62086605256604, 56.551289712229085, 56.39819175966325, 58.060315732033025, 55.364627607407115, 54.64169163857737, 60.08607872070805, 44.891153996990575, 31.25871131497045, 49.28178848758821, 59.719027242352894, 56.834488761040475, 58.126615555055686, 55.67320439123339, 56.471277283084014, 49.018954384711485, 43.28919133832378, 43.960253961624645, 42.29000283825783, 44.01413948305192, 43.46569407370783, 43.79806395499937, 43.11668942051549, 43.02728291480772, 42.742059922987416, 43.40689774482481, 44.567283891862445, 44.39172252531975, 42.703514791304066, 41.788202255002915, 40.718583676122854, 42.77269755640338, 42.82159382297147, 43.609825488059755, 45.724135983374815, 43.469659589952045, 45.68866598990656, 44.991880463015654, 43.38374007132746, 42.86520273454728, 44.42199537830968, 42.572193837934925, 45.01995286633892, 44.135007319911836, 44.65417223591959, 44.746598966660045, 45.4627884587934, 44.91126791123421, 48.61746057387322, 50.577386579205914, 58.3456995410304, 57.61909223371937, 59.93188250449396, 62.108856785681944, 61.92614493831512, 60.492930489201704, 61.84779951649328, 60.891937517350726, 62.31238857392342, 59.29453265282416, 57.84648772208922, 58.515557781342544, 58.98924673757246, 58.371308695885446, 62.09586589567123, 63.10215780811926, 65.87078632846956, 64.63941704842352, 69.77043028800719, 64.46684845032232, 76.06107265718522, 28.635881216295306, 0.8092121779918672, 0.7029436480614447, 0.04792545696780567, 0.11280568842325481, 14.787009012314583, 71.71690648601901, 57.09892319094751, 64.57345454923569, 54.008173942565925, 18.60604924540366, 12.119193250133145, 31.889004822700258, 49.083634268852975, 58.80202416450747, 20.98268589665813, 0.5665381384953376, 0.06788135791618018, 0.03339779458098835, 0.04804389416089943, 0.02544180294799228, 0.014486023592912864, 0.06046647716674113, 0.04038701772749905, 0.0368982226768088, 0.034572586582432834, 0.05006882542323682, 0.032138660129520207, 0.054494388957297614, 0.028927728999406103, 0.0980541674840835, 0.04327738702657723, 0.0766562515749566, 0.025804790728274855, 1.4256364299405007, 60.46083373408164, 71.87529963831749, 61.37127860899895, 39.90466440877607, 28.45463633537293, 32.81655319275395, 48.36231039416406, 64.45148452635735, 83.04666488401352, 57.14542288934031, 0.7711206316467255, 0.08049005432234657, 0.6398786772643367, 0.6932565581894691, 2.2309983113119682, 7.1706619089649575, 84.46095389704551, 81.71418082329535, 76.93216046979352, 65.75949691957044, 62.77715021564115, 72.69978184853831, 76.99016447990172, 67.87438008093065, 66.28188994623, 67.98510859089514, 69.58734973784416, 71.6496378375638, 67.69143289135349, 67.22665556015508, 66.18983191828575, 62.60160061620898, 55.009798234508885, 51.50019084253619, 48.63352267972885, 48.48245651491227, 48.93391739937567, 51.4169503027393, 49.18285454473188, 49.18629838574318, 49.02119405807988, 49.342836256950136, 47.18990218254828, 48.2687932445157, 48.42131460866621, 48.44461740985994, 48.9273395845967, 50.373305659140314, 48.75778336678782, 49.846645093733265, 48.88344041762814, 48.643763988248764, 50.37935395394602, 48.301945117212114, 46.25650751975275, 45.21677740158574, 45.321775328728464, 44.980274169675766, 47.89746246030254, 47.327310654424856, 45.877382986007206, 45.69935837099629, 49.99009793804538, 48.96335086514873, 47.787777300803896, 46.783823120978575, 47.247157019953576, 45.61882034424813, 49.01708733650946, 46.71109453324349, 52.49295057788972, 59.90307661794848, 59.33875737651702, 60.596473217010505, 58.61807677053637, 56.85728165411181, 61.75219958828342, 48.973309763016246, 32.507990137223274, 50.48495200372512, 61.886658437790416, 59.02621899881671, 59.47257687968593, 56.0786597959457, 58.820165126554436, 51.44166515719507, 44.74447696439682, 44.79101588649135, 43.4916405523977, 45.003184733852265, 45.71581663623933, 46.70663479835757, 44.75654217504686, 44.20241717369326, 46.781167676371915, 46.300108586588216, 46.844062882085005, 46.10331935267295, 45.23740122395177, 43.68854745741814, 43.95201698426278, 44.870538019364886, 45.026252192835656, 46.503350119436945, 45.97559129038165, 44.92405091562579, 49.80320092170469, 46.25314212614491, 46.93586987833823, 46.05215987851543, 46.7347542701229, 46.07823579542099, 47.24103027774442, 46.47221042263893, 47.771217053936375, 47.475748831225985, 47.177664387610655, 46.84729491510699, 50.37304286033877, 53.265402547774784, 60.82022482349027, 60.589361959888095, 63.6907212195858, 63.68650859402072, 63.56873550722676, 62.44845167283089, 64.2129102829964, 64.82667884519024, 66.06337470393028, 62.40892202623429, 59.87043465337446, 61.25198364257813, 64.3411207968189, 62.03564574641567, 64.6985742353624, 66.46331525618031, 68.93170987406086, 68.10867109606343, 73.6842026249055, 67.85061836242676, 78.37783628894438, 32.982508674744636, 0.8587005998819106, 2.6040941621026685, 0.9278203619103279, 0.30437917358452277, 17.715745741321197, 77.83738859238164, 65.42931572083505, 58.326311265268636, 44.864728989139685, 22.334685710168657, 16.305819384513363, 40.68072888158983, 56.64063738238428, 66.29471609669348, 27.827961214127082, 0.6536954100574217, 0.08704133181562347, 0.041517399611973, 0.05422710471095578, 0.047138473995390444, 0.024166260808405858, 0.05206191041056187, 0.05989397583048671, 0.05152357659573036, 0.10598240375158288, 0.175798378824707, 0.2241861621939367, 0.2502753477423422, 0.18781109713017943, 0.14730055155532976, 0.08539017485154253, 0.14519724183745925, 0.23638413588125862, 2.3168320280890313, 74.44337737175726, 82.58812412138909, 73.84568660489975, 49.8992754567054, 40.7078089252595, 27.055519050167455, 53.370055306342344, 75.11256510211577, 88.41238883233841, 64.29934755448373, 1.0008404307788419, 0.24290651653803166, 1.284608468413353, 7.897428562564235, 5.798901194526303, 13.656723133979307, 83.46958268073298, 84.61630329009026, 80.06699715891193, 67.78113749719435, 63.74985094993346, 76.51776206108832, 80.07315528008246, 69.8091362368676, 67.46446101896225, 71.39033779021233, 72.45644584778817, 75.26312920355028, 72.82030059445289, 69.84377861022949, 71.54903688738423, 63.05387735366822, 56.08598678342758, 55.51097908327657, 51.57023260670324, 51.347700857347064, 51.92890198000016, 52.83190611870059, 53.54544016622729, 51.37658911366617, 51.212739944458015, 53.61375608751851, 49.87425073500603, 51.55408813107399, 50.41277254781416, 50.85287424825853, 51.03877890494562, 52.99884611560453, 50.04092401073825, 53.07685813596172, 52.17696051443777, 51.49793155731694, 51.95695477147257, 50.96287319737097, 48.11744466904671, 48.01797728384695, 48.36277715621456, 46.63762461754584, 49.94379828053136, 50.17568488274851, 47.73902616193218, 50.61004031089045, 52.64011006201468, 51.02155969988916, 49.106223198675345, 48.43645887990152, 50.632574327530406, 49.91274095350697, 53.29624022206953, 49.75179041585615, 55.11395677443474, 61.98997366812922, 59.069243477236846, 63.301606409011356, 61.58655005116617, 58.28323187366609, 63.53789783293202, 53.51634402428904, 35.47617512364542, 53.15045356750489, 66.14468543760239, 61.52880491748933, 62.96489838630923, 60.174822345856704, 61.16556206057149, 54.080322019515506, 47.44051025759789, 47.39495977278679, 46.63391013299265, 49.57960228766165, 49.12331296551613, 50.36322124542729, 46.294617268346975, 47.93848260756462, 48.87890223533877, 48.29339827260664, 49.006457713342485, 48.904570225746404, 47.31206440156507, 44.4886129133163, 45.95858781568466, 48.23621796023462, 48.86965328647245, 50.45935069361041, 49.593463943850615, 47.36389067865188, 51.01638609363187, 50.44126072237569, 48.51116434220345, 49.13048305819112, 48.47332523715112, 47.846844273228804, 49.10037886711859, 48.6639210485643, 49.42511189368464, 49.9033429545741, 48.5142316356782, 49.194864842199514, 54.501145270562944, 55.3556885257844, 63.79671150638212, 64.16634390431066, 66.78300411470475, 67.16520770903557, 65.58142523611745, 64.86779312933645, 66.88697830323251, 65.92244394363897, 68.85083844584804, 62.85580942707678, 62.499952393193404, 64.58466860555833, 67.79171220717892, 63.165759040463364, 67.67511583143666, 69.91431851540843, 72.20871679244503, 69.95455418863605, 74.88959404730028, 70.26215430228942, 84.40006302249047, 35.24350012502363, 1.4926739037036898, 2.3030743147096326, 1.0191111987636936, 0.34768670617092046, 19.957131224293864, 85.17651973232147, 73.0878846876083, 80.23292126194124, 65.36805614348381, 28.641043055442076, 24.996525741392567, 51.0620464048078, 65.99485874176025, 77.38611205931633, 36.11839655906924, 0.8609670556841359, 0.23814321165123295, 0.18049466633988967, 0.16550427152504846, 0.09744880480631705, 0.12771855514015884, 0.12158166226600448, 0.09645214739946589, 0.10047938734773668], [0.12337526561872614, 0.035546962322006305, 0.005708285832717534, 0.08695565254217194, 0.01822418409339603, 0.016373882573398373, 0.07239844980499438, 0.2073986476828014, 0.16881980813078343, 5.344064620233351, 56.79437860365837, 61.33995063843266, 50.29863157579976, 48.61313812194332, 30.812651534234327, 23.217534749738633, 42.76558629928097, 59.48487743254631, 78.07677084399809, 31.16591980380397, 0.2236917137258476, 0.13410897715197456, 0.5508610377869299, 0.4824427058619838, 4.245486201778535, 28.797837841895323, 91.3752374341411, 70.52411371661772, 75.35796426957654, 65.3505309935539, 54.64671619476811, 65.19534241768622, 69.03151066072526, 70.1692255081669, 69.300491117662, 59.75283415086808, 64.38306662344164, 60.025721288496456, 60.69104548423522, 64.06192256558326, 66.10172763947519, 65.85119016708867, 61.62967651121078, 53.50615762895154, 50.571051951377626, 47.67480519510085, 47.49085387875957, 46.96967286448325, 47.49000664680235, 46.023934502755445, 47.38729938384026, 46.72446589316092, 47.232165721154985, 46.34176023544804, 44.94380397181357, 45.74596789575393, 47.524405833213564, 46.094176307801284, 47.433175425375666, 46.017588107816636, 48.04188805241739, 46.65183144230997, 45.70288850415138, 46.32631394170946, 45.85088345312303, 43.837079771103404, 42.13694410939371, 42.92950607115223, 44.225217911504934, 42.789551981033824, 43.60530691762125, 45.9650714935795, 46.47720752223846, 44.65358388039374, 46.90256895557527, 44.687108378256525, 44.04034876054333, 45.39635919755506, 46.125516045478086, 44.34830580988238, 46.43031558682842, 48.60188876428912, 54.15692198661066, 55.24840385683122, 54.49098633181665, 55.090218590151885, 59.40665752656999, 54.31108682386337, 40.040005791571836, 55.51555648926766, 57.06043689481674, 57.85808617068876, 54.53789787907755, 55.01385396526706, 58.63086369729812, 50.387959634104085, 43.24550397934453, 43.27403137760778, 44.07600310540969, 44.00765580515708, 44.068974218060895, 42.48070847603583, 43.26180534978067, 43.65929049830283, 41.599116556106075, 45.074316916927216, 43.03924614383329, 43.49633562949396, 41.02430889683385, 42.540563844865375, 42.29460377846995, 41.12824386165988, 42.05290340608166, 44.92046979165847, 42.947007686861106, 43.92188141422887, 46.10767710593439, 44.60153795057728, 44.22510024039976, 42.44332044355331, 43.68140874370452, 45.007605245036466, 45.12911242823447, 44.883913301652484, 44.049770293697236, 47.00085178498299, 44.43113842318135, 45.693113957681966, 45.21808747322329, 48.2671497714135, 55.7670392528657, 60.089283297138834, 55.995870328718624, 58.66446272019417, 59.67404550121677, 59.9062458930477, 58.4173337874874, 62.65621962085847, 59.7227103479447, 58.92709285982194, 60.21114349365235, 62.437194470436346, 59.395408168915786, 64.61688303178357, 63.40837724747197, 66.61331453631001, 65.83954857241723, 68.21565766488352, 68.83900857740834, 71.35700548848799, 73.29296188969766, 51.66936659043836, 0.11511033370850549, 3.22139187685905, 3.362083862866125, 0.5656579341138563, 13.461928425296662, 66.03361960380309, 60.553185939788825, 55.694130236102694, 64.49279100664201, 42.116739980636105, 20.31216456044105, 38.94552330816946, 50.36534324769051, 55.67900557671824, 33.46128102271788, 1.835651467404058, 0.11046530513633644, 0.12232941770625692, 0.005881346052422399, 0.06650123519883042, 0.13758284880989982, 0.018723937720360777, 0.029638499629894094, 0.06228313210510439, 0.07938078965150541, 0.04230450515845611, 0.022453943214889978, 0.08138712795992052, 0.04821454407647253, 0.028590303657936956, 0.0531567802893058, 0.31423002241119263, 0.2469944229890262, 8.336180967669334, 73.81948517214867, 66.45711791130805, 61.23035177107781, 54.205214208172215, 44.511394039277114, 23.18364743263491, 43.15792529813705, 70.11620290817754, 84.73065607009396, 34.50802041638282, 0.18380707730689358, 0.013328061585554914, 0.8771096314153365, 0.4062727285969642, 3.070561299400945, 34.38398722679385, 89.327893564778, 75.2473142070155, 77.6354100627284, 68.28069840708088, 56.62731701327909, 69.14059961995771, 71.28796392871489, 72.56283621634208, 69.03909652463852, 63.232290283326186, 68.67372774308728, 64.1291049218947, 63.37005961325861, 67.49632635424214, 67.60769813291489, 67.87783961142263, 64.8489422182883, 56.88617775517126, 52.718365269322554, 49.9146354583002, 50.24619340896607, 49.363997444029785, 50.24269073240219, 47.433814771713756, 50.641705605291556, 49.91468252674226, 48.989250275396536, 47.12698736498433, 48.53401999319754, 49.26397700463572, 48.45507837110951, 47.728553433572095, 48.79450459634104, 48.43995371172505, 49.69106820321853, 48.398804126247285, 48.53924066789689, 49.95654598359139, 47.80504357430243, 46.51956127535912, 44.72579863763625, 44.20744957462434, 46.16350812296714, 47.599354482466175, 46.222881040265484, 47.39517550314627, 47.03104226819931, 47.35822285375288, 47.43951005320395, 48.27167226422218, 46.892912080211026, 45.58114205637286, 47.86909587921635, 46.84475321923533, 47.65338120921966, 52.422736229435095, 56.55498850730158, 58.750692106062374, 57.03831472704488, 57.42672743335847, 59.97005501101094, 57.28078780635711, 42.699306088109175, 57.817677913173554, 59.470254836543916, 60.741969616182395, 58.50131565524686, 58.19859889245803, 59.7497707797635, 52.98844791227772, 44.87960653920328, 45.921564563628166, 45.74474019388999, 45.89890895351287, 45.06388341226886, 45.591226470085886, 45.57510552867767, 45.98207496827649, 44.464910030365, 46.9643815871208, 45.29860981049077, 45.89699091449861, 44.22272328407534, 45.02861738204957, 44.296797244779526, 44.45619452384211, 45.914574899981105, 45.92558891542497, 44.989934967410186, 48.424460349544404, 48.23965787887574, 46.97900026075302, 46.47817242530085, 44.588378398649155, 45.811118464316095, 47.71038109256376, 47.35315907386042, 46.9850524779289, 46.05962807132352, 48.863420640268636, 45.91170764738514, 48.117170103134654, 46.81098553442186, 50.170668171298125, 57.718461559664824, 62.53220996549053, 58.4631549158404, 60.482038067233184, 63.74692878415508, 64.24819984743672, 61.374636157866455, 65.42917451550885, 62.078156394343225, 62.358621551144516, 60.957762733582534, 65.79597103980281, 60.9384842841856, 66.06566536811091, 66.93539604063957, 68.33337583849507, 69.7064015173143, 71.17678042381041, 70.89860593118976, 72.96985272438296, 73.82308590796687, 54.872075973018525, 0.540681200162057, 1.963689642087106, 5.045537439084822, 0.3292470004770064, 12.700063913099228, 70.64502469954952, 67.70473757097798, 58.403989884161184, 52.37288290454496, 35.42831828517299, 28.538327947739635, 48.706306180646344, 58.81142608581051, 64.61394125415434, 43.79435731518654, 2.19482155576829, 0.07840832530130303, 0.03357119475220961, 0.05225252840788134, 0.06958125339400384, 0.05020618115762069, 0.010308631369093013, 0.03764573296892547, 0.02926827231872707, 0.19602840135414756, 0.15043967343386144, 0.22050484924787478, 0.23443431953989693, 0.09994647360496944, 0.09263262453098452, 0.16725052298317034, 0.31985831717329644, 0.5902328089840951, 13.062651734198294, 89.80017831248622, 77.77046511250158, 68.59566473191785, 62.96403546487132, 43.33556552087107, 31.3549074434465, 63.19822842074979, 72.81534271855509, 93.3650872015184, 38.55830300238825, 0.2054077230634228, 0.16266001688857235, 2.0601607041974224, 5.737887745903385, 7.053425206292061, 37.52819445825393, 91.99060240099507, 80.60554642831126, 78.53488014590356, 71.80998433020808, 58.25637932746642, 73.82460778759372, 72.45646153726886, 77.70587936524423, 71.12746054126372, 64.56165605975737, 68.86666128712316, 68.54294023206158, 65.6766603839013, 69.53216198951968, 70.94772969522785, 69.3949967045938, 68.51877843180011, 58.30444797392815, 56.03162273283928, 52.16878629499867, 53.211469957905436, 52.53315487215596, 53.92004220716415, 50.26377739444856, 53.00013265302105, 52.88476397914272, 51.67300654995827, 49.650644256222634, 50.58672182021603, 51.64653055129513, 51.23252437960718, 49.25754039518295, 52.10250608382687, 50.741098465458045, 52.20540162055723, 51.54740441230036, 50.84008732149678, 51.80302135406002, 49.03394960588025, 48.35025302825436, 49.11690381265456, 47.00672357313095, 50.40158202571254, 50.129040056659335, 48.19232271563623, 49.43017175120693, 51.61083698272706, 48.97034445116597, 50.66762462739022, 49.69986607951503, 48.97036798538701, 50.35471754689371, 49.76991961079259, 49.96575570875599, 49.755555891221576, 52.719863614728375, 60.71400311685378, 61.70025956246161, 59.34278172831382, 59.31399937598937, 63.9022546429788, 59.0383626568702, 45.919944624747004, 60.78075793481643, 62.19979301575692, 64.03905906984883, 60.809218652786754, 60.00246555574479, 64.09105008648288, 56.44107895512735, 47.59000355197538, 48.76802467530774, 48.94947351947908, 48.54959964752198, 48.36774287685272, 48.79878782456922, 48.58575997814056, 48.63077309823806, 45.96292987946541, 50.55569194978284, 46.613937424075225, 47.22104972408664, 44.308936980462846, 47.25528417095062, 48.73185257757864, 46.157487284752634, 47.777688964720696, 49.514953782481534, 47.58150769818214, 49.98353189037692, 52.72741809968026, 49.41093252551172, 49.155586227293945, 47.57927194718392, 47.922361666156405, 50.58734547707343, 51.42973330713088, 49.97750712979225, 48.505665179221864, 52.67371300728091, 49.83661951557283, 50.80427608182354, 48.480365891610425, 51.74959082757273, 63.180664047118164, 65.46178902349165, 64.35499814248854, 64.74144966371598, 65.69086720866542, 67.28024298144926, 66.5509331610895, 69.12951500185075, 65.54238980816257, 64.42209028428601, 66.56302190596058, 69.28821409902265, 62.260393634919204, 71.54316902160645, 69.40295127130324, 72.4057060672391, 70.0580184690414, 74.64935671898627, 73.95465789302703, 77.57669218124883, 75.79175487641366, 60.608401144704516, 0.6331659084366215, 6.921018736977731, 6.684127680716976, 0.6805230737213166, 17.715351543118878, 76.60159880115141, 75.95408608836513, 69.56423128804853, 77.72699740625198, 55.24544246735112, 35.55595613295032, 56.85066461563111, 70.86151599884033, 73.10953617095947, 56.208866796185895, 3.8146908148642513, 0.31182784647230183, 0.26787002781225794, 0.14538686392047714, 0.0881857216177929, 0.26692709615153654, 0.09572794150200584, 0.08271363984432914, 0.14690250759163212], [0.08290222770864926, 0.04891019404655503, 0.061560856749213515, 0.07918939790538243, 0.05677903168684533, 0.05670905338540193, 0.017296329043024493, 0.05860037125286557, 0.18062726083782413, 13.993798878885086, 63.41239767689859, 52.06237239222373, 49.88059320757466, 44.25313342002131, 17.332422310306182, 43.2303479409987, 54.51193963327716, 68.24691895515689, 73.52340113732123, 12.962281223266357, 0.11996900122011862, 0.20038871334925776, 0.5334915569232357, 0.7028914315085257, 3.2550502256039655, 54.58049874151907, 56.846954053448094, 75.6771275304979, 68.65868153110628, 73.09870258454355, 55.593701870210715, 59.9236180705409, 69.44328892615535, 66.4914700292772, 68.30026318950038, 68.08545066464332, 65.57008174157912, 61.206872463226325, 64.50733515524095, 62.846258455707186, 62.01293130074779, 63.16505301383234, 60.889854738789225, 60.45897845299014, 55.863800202646566, 51.827579313708895, 47.64850962546564, 47.869574408377375, 47.23883767281809, 48.03414921606741, 45.051908416132775, 47.82646363781345, 47.56522593959686, 45.40272128197455, 47.02530776300738, 49.26801704591321, 48.23423716329759, 47.839909522764145, 45.01740332572691, 46.20744651363742, 43.3443751642781, 48.27560247913484, 45.677675508683734, 47.8248123199709, 44.491837101597945, 43.968757660158225, 43.07525742438532, 43.39650346386818, 43.37489512658889, 45.06651532265448, 41.33348188092632, 43.38739179795788, 42.98501153146067, 44.787713250806256, 44.346783930255526, 47.17265944327078, 46.79170708502493, 43.5229253768921, 44.816628963716575, 45.2331179957236, 46.58366064871512, 44.85698623041953, 45.92160378732989, 49.45135255013743, 50.42763440839706, 53.95593189424085, 57.43143819993543, 54.87308402215281, 47.229918203046246, 56.5051979403342, 55.82048546883368, 55.265881938319055, 56.444871887083984, 60.01697832538236, 52.026580764401345, 49.24317275324176, 42.26417010830295, 46.15359237117153, 42.84500252815985, 43.76293913010628, 43.26407640211044, 43.28646136868385, 43.108377918120354, 42.63520279238301, 41.8978678026507, 42.52066173861104, 41.08647061932472, 44.86803162482477, 41.49634653522123, 40.474341607862904, 41.230676558709916, 41.523242227492794, 42.14234521312099, 41.789826116254254, 43.34673643112183, 44.57787036895753, 45.43900712843865, 42.78340954934397, 43.6898849856469, 44.013723711813654, 42.819793455062374, 44.56522856989215, 44.762790510731364, 44.820641548402854, 45.056097507476814, 47.713930837569706, 45.707571814137125, 45.06274200254872, 45.28890586668446, 48.152114498999815, 54.03494411899198, 62.2316465839263, 54.97183361361104, 56.94433866008636, 59.51285177661527, 61.86167686216293, 58.15826908234627, 59.62185444370393, 59.67441420401297, 61.7968322384742, 58.90864595290154, 62.74592814906951, 62.078132860122196, 65.67422459202429, 63.66988166686028, 68.49122770370977, 68.47849569013043, 70.16888033959174, 66.7835924702306, 73.30159110407676, 65.88557366401919, 68.56878865149714, 3.948825823683893, 2.456100929167963, 3.1011810370029944, 0.22428751562631902, 0.7498417121748772, 38.03607079290575, 74.84485549311485, 52.81428290951637, 70.28799487698463, 46.94617394478091, 10.30710922133538, 23.47255353004702, 46.2667449059025, 55.94799387839533, 50.19665779605989, 5.90820441322942, 0.20776577233787508, 0.07408081719111051, 0.04043534255376266, 0.027709465338698322, 0.02527553505534607, 0.0420601346019295, 0.0690840240267496, 0.036224095946958954, 0.03933136772003867, 0.0643714418214175, 0.03583578896077891, 0.13699789471443624, 0.04161676504619179, 0.07285645547052545, 0.015419269029441622, 0.04723641450607008, 0.2006400514754557, 19.433632089245705, 76.80149062987297, 59.97067474549817, 57.31097044483308, 51.949737610355506, 24.84398280420611, 32.339212509893606, 59.751618216114665, 71.70324879307901, 81.8950334672005, 14.464201869503146, 0.11526402626787463, 0.15110307493277136, 1.0429465842823828, 1.7256180749785517, 5.958388197806574, 57.121629791875044, 61.125385222896455, 78.75584294719081, 70.62749170487928, 76.7092364834201, 58.12090850645497, 61.8538321218183, 72.22795209577008, 68.02780751259097, 69.4404883538523, 70.87253785902455, 68.51126317054995, 63.761061083885934, 64.9494961000258, 65.09288226404499, 64.88358851402037, 66.39927079600673, 64.52146745497181, 63.889299054299634, 57.96669267839002, 52.73170917264877, 50.65129972273304, 49.693554985907774, 50.388583290961485, 49.71870130108249, 47.4786513851535, 47.92462095137566, 48.025876937373994, 48.146066204194106, 47.67194186487506, 51.84493972409157, 49.495765547598566, 48.313104260352354, 47.73611968563449, 47.517412247196326, 46.15401990952031, 49.38584896825975, 47.56455521429739, 48.030595548691295, 45.94560084804412, 44.79107864441411, 46.027747046562936, 46.10706129381734, 45.84039503528226, 48.020044372927764, 44.473209765649614, 45.50267111870551, 45.2671367122281, 47.19173000704858, 46.27097322094826, 48.52052703980477, 48.5816022657579, 46.156506692209554, 47.77575131385557, 47.25847305790071, 47.70600372745145, 47.50084415558846, 47.58482602334792, 50.94089615729548, 51.74233836512412, 57.17782951170399, 59.928026814614576, 58.492968851520175, 49.018330727854085, 60.58434132606753, 58.35220283077609, 59.084505419577326, 60.94819999510243, 59.75135541731312, 54.12572737663023, 52.820750897930516, 44.777570001540646, 47.973811395706676, 45.89001694033223, 46.65364749969975, 45.46576161538401, 44.98005059457595, 44.58486003260459, 44.65625501448109, 42.24783343653525, 44.91269173160676, 43.80142150386688, 44.98291000243157, 44.16151077516618, 41.61741441295993, 43.84778391930365, 44.41902222171907, 44.56268295165032, 45.11823177337647, 46.02534655601748, 46.88652253920033, 46.89511645224787, 45.33758640289307, 46.64184116548108, 46.15351392376808, 43.661561550632605, 46.90884867022115, 45.57534871562835, 47.3919120911629, 47.024519366602746, 50.381150399484945, 47.42869215626871, 45.50733481684039, 48.3578977277202, 49.93386683925506, 55.94157295842325, 65.37186476492113, 60.196269865958925, 60.99521352398781, 62.382269520913404, 63.0626634628542, 60.68455788397021, 64.09406246677523, 62.66253855920608, 64.71744083589124, 61.0609838270372, 66.12523832628804, 65.74589806218302, 68.49062365870323, 67.52840349751135, 73.33344074987596, 70.21244218272548, 72.16933619591498, 68.35693359375, 76.46260569172522, 67.20559243232974, 75.73808900771603, 4.468482752000132, 2.5988421084419375, 7.312743394605576, 0.0762010880956246, 0.4294765512308767, 42.72736280195175, 80.8071013419859, 61.36004886319561, 66.61085913258215, 50.505607205052534, 20.60500087276582, 29.89365000878611, 56.878842922949026, 60.59247632180492, 62.2670106733999, 8.244436729338862, 0.23460117348980522, 0.06511314516706813, 0.04134164372038457, 0.01243656411045982, 0.0670354666128274, 0.008574895872434062, 0.007300909370138882, 0.07093984137980208, 0.16074989922344685, 0.09956537550615688, 0.18209260317587084, 0.2987057715654373, 0.18593962093995464, 0.23179888514982117, 0.11586081642176836, 0.1525572170653651, 0.37333517665824584, 27.6842632216792, 91.27742136678388, 71.1543680006458, 67.97739721113636, 58.31619939496441, 26.288754517032256, 58.61758255189466, 73.31847298529841, 75.74148578028526, 90.63740822576708, 16.317218772826656, 0.19352528567035354, 0.334753027606395, 2.674940012155041, 5.718008193277544, 7.327637124446131, 62.43096182423254, 67.88883009264546, 81.32025718688965, 73.14834410144438, 78.11301354439028, 61.112186447266616, 65.3375950167256, 76.34719387177499, 68.6769127076672, 71.40553305225988, 73.11955390437957, 72.48964478892665, 64.58449602127075, 68.92213144610005, 67.19433522993519, 65.6232455468947, 69.44077076450472, 67.57569943704914, 65.9616990243235, 61.94159907679405, 56.652353502088985, 53.592783174207135, 52.56351401728969, 52.90014751495854, 52.15922355651856, 47.885424706243704, 49.938569761091664, 50.57014980623799, 49.47432979460686, 52.16229084999331, 54.727544476909024, 51.44410487144224, 50.54903176523025, 50.67482217665642, 50.200282066099106, 47.91528963273572, 52.74789679434992, 51.876946264697665, 51.37982114668816, 49.19578267681984, 49.12783938069498, 48.254272630137784, 48.19634314506285, 49.70326285208426, 50.558198344322946, 44.56622877428609, 49.46825012083977, 48.455725562187936, 50.53426796390165, 49.2613019481782, 50.798576877963164, 51.09393135193856, 49.096311369249904, 50.87640846929243, 47.89084934419202, 49.71684601999099, 47.78388630959296, 49.991392320202245, 55.15940135525119, 54.204818048784816, 59.19774424645209, 62.77909178887645, 59.37369000527167, 52.07475923722791, 62.679012513929806, 60.44243389560331, 61.63674854463147, 61.664542459672504, 64.2452423803268, 57.12961965991605, 56.4461309679093, 47.19594655498382, 52.26209948139807, 46.81601401298277, 49.84957902662216, 49.01441620242212, 47.285007892116425, 47.79439041691442, 46.806478731093875, 45.15010887576688, 45.393080096091, 46.55714934872043, 48.60031197147985, 46.21507552362258, 44.683295834449034, 47.19884126417099, 47.75451952411283, 46.171101831620746, 47.67246746247815, 48.55209427495157, 49.96577924297702, 50.900640872217, 46.65000754017984, 50.32125580695368, 49.731045000014774, 46.779845837623846, 48.918243608167096, 49.38284443270776, 50.14884018128919, 49.960276157625266, 52.64895108438308, 49.694892514136534, 49.157280691208385, 49.876313901716664, 52.60192578838718, 57.45040678208875, 67.52676394677931, 64.65632638623639, 64.04975537330874, 65.04694346458682, 65.66805078137305, 63.59767475435811, 67.22027778625488, 67.34966108875891, 68.18674979671356, 63.43248021218085, 69.04314441065635, 68.02493633762484, 71.32393206319502, 69.28418190248551, 75.21872797319966, 71.5895628160046, 74.36278835419687, 70.63932157331898, 78.40363763993787, 68.21644998365834, 79.52708290469262, 5.176594122763603, 7.081728539159221, 7.36196227612034, 0.3177368971368959, 1.8086341816571452, 49.83745498041953, 87.76830427108273, 68.59198554869621, 85.02917981916859, 59.33914176879391, 19.424571414147657, 35.11480323729977, 67.87765918239471, 70.87855477486887, 75.01205828882034, 12.42453702034489, 0.3505707514141837, 0.23687564257171848, 0.08722533847415641, 0.13625187829377192, 0.07998009257379078, 0.11370435552371126, 0.17974462029674362, 0.12580818466601834], [0.02375007588266125, 0.054874923981485836, 0.06464681978667937, 0.03811251417162918, 0.01738585407785591, 0.036318535435824625, 0.010509921928807613, 0.0360956919499703, 0.18352921721675705, 29.393402684119444, 64.80746707608624, 47.56318238473708, 36.648634326073434, 15.457305792839298, 26.450522868864, 39.094883241961085, 54.14096970711985, 70.55313925589286, 65.35927787903817, 5.098933644833104, 0.15687289677800673, 0.07735407340430445, 0.6854391518619753, 0.6051820648774024, 20.444740672265333, 66.98034640281432, 65.2267135343244, 74.1055985419981, 69.30118929955268, 74.16812896728516, 60.74642150632797, 51.27955752034342, 58.710491734166304, 69.4623516451928, 67.58421098032306, 68.28814306566792, 66.78293351204165, 68.01309862444478, 65.06012655073597, 65.94222837878813, 59.30506421673683, 60.56854986375379, 60.94343823771323, 61.997532075451275, 57.861706518357806, 55.792236558852665, 47.38110596133817, 46.33055010149556, 46.43490083755986, 46.418081714260964, 46.417116811198575, 46.75861797025127, 47.00309930309173, 48.84174562269642, 46.19975082335934, 47.201092704649895, 48.316006814279866, 46.14421398408952, 45.3333031746649, 44.98823658112557, 45.23005462461903, 44.611073232466175, 45.769847285362985, 45.16774385206161, 42.93438549964659, 44.230383673021876, 42.976319559158824, 42.83235288435414, 44.17267384067659, 43.58731892801101, 41.79277966099401, 43.59790540510609, 41.22957829506167, 42.559854061372825, 44.59799997268185, 44.231097544393236, 43.925862619953776, 47.02622951999788, 46.567586775748964, 45.33406411447833, 44.861022349326845, 44.16693933548466, 44.480709337419086, 48.24618470284247, 50.539908332209436, 57.09179624434441, 57.29377085162748, 55.040051475647964, 42.12370218769197, 57.554067181002715, 57.31674417372673, 49.22789119905042, 45.9928693309907, 47.32365108305409, 47.70067714875745, 45.75134546526017, 43.600788347182736, 44.46495709880706, 43.705558776855476, 43.82766216031967, 43.745072733971384, 41.574586053048414, 41.569145725619414, 42.74313073004446, 42.084254910868985, 42.14086255719585, 42.149860474371145, 40.33010036714616, 40.265549921220355, 41.93289849065965, 40.168479104195875, 39.323675094112275, 41.51253415692238, 43.12398110666583, 44.08763293297061, 45.0423417552825, 45.849659673629276, 45.065067968060895, 42.71035932725476, 43.7497325097361, 41.63415901122555, 43.85215736204579, 44.86428183894004, 45.651521144374726, 44.46776159348027, 45.14113449281262, 45.8609051089133, 46.699872632180494, 48.48415490119688, 46.422286495085686, 50.072295127376435, 59.83098345418131, 56.92024354011782, 52.73110512764224, 60.070652038820334, 63.12690796390657, 59.361895438163515, 59.96998048597767, 57.49023452881844, 61.41697422150643, 59.92346902047435, 62.81726037302325, 60.86151561429424, 64.4658011774863, 65.96031835002285, 70.44135955072218, 64.33414682265251, 70.94235604809177, 66.56649712593325, 75.3027843659924, 66.38511888442501, 82.09502727754655, 15.480344814638938, 1.7349557674700216, 3.7835891160272785, 0.10279484213359895, 0.042956917126092224, 17.13115372965413, 77.21533990675404, 56.11931908515192, 58.3623460800417, 43.616348389656316, 17.731174384394002, 18.451898136446555, 40.22380413547639, 50.87764793826688, 61.116112739809104, 14.709303917423373, 0.40911687598113095, 0.036288554584907914, 0.03935512027613098, 0.04405481305213706, 0.05594487302005292, 0.034248707590684775, 0.010480390196936506, 0.03677055795466708, 0.13206315467194205, 0.10054774537322023, 0.08559406915258977, 0.011851700030327325, 0.03625017741034108, 0.04305855018056689, 0.02300525647437861, 0.04295719291774496, 0.0710913276059493, 39.597087829343735, 73.71351841957339, 54.93669309923726, 44.71587111873012, 27.338176811895064, 28.706162245042865, 32.723055654956454, 62.15067317408901, 74.71953576610935, 71.49570834252143, 4.402027014763125, 0.23664950873822937, 0.10297555461405747, 0.9377010575225277, 1.678891859708294, 24.603210072363577, 71.1046088126398, 67.3055971822431, 76.38767273195329, 72.20673991787818, 76.89324271294379, 63.95250804962651, 55.16428470611573, 61.938131701561716, 71.70786150040166, 66.57164327559933, 70.92308152106501, 67.45677317342451, 69.46910596662953, 65.98942233670142, 66.72628664201306, 64.93097466807212, 63.27487937865719, 66.438110105453, 61.297475291836655, 60.16895840244909, 57.76430229986868, 47.73824561026789, 48.47272511451475, 48.769574011525805, 48.11632287117743, 47.34054865375642, 48.502629264708496, 48.37900400161744, 49.042645500552275, 47.42751152284684, 48.41954954208867, 48.620065027667636, 48.47902051864132, 46.83460212522938, 46.41214716819025, 45.505722722699566, 47.783301876437285, 47.95909074044997, 47.98576285762172, 45.79874338642244, 46.27855908486151, 45.63876559657436, 45.03663470668178, 46.85450030911354, 45.88407454952117, 43.874126557380926, 45.03099826074416, 45.41088373430314, 44.03523398983864, 46.56741419146138, 46.82827926451161, 46.55957337348692, 49.26030174378426, 46.90942918100665, 47.228149214098536, 46.84566320911531, 46.11554145812989, 47.479883009387606, 49.29958035868984, 52.91231078486289, 59.45213740871799, 59.316254738838445, 58.58106920796057, 46.50295396004954, 59.557484426806056, 56.84553415544572, 52.58751107800392, 49.01069779549876, 50.68066650821317, 49.50443790804956, 48.1813596910046, 45.64302921295167, 46.24677611935524, 46.67932333484773, 46.40976236712548, 45.50916264134069, 44.174533044138265, 42.49632735406199, 44.23380397981213, 44.37702148191391, 44.45821062211068, 43.21713739825834, 42.79394895799699, 43.674740714411584, 43.75534542145268, 42.653288841247566, 43.69153630348944, 43.54847177382439, 46.00304788158786, 46.2822735694147, 46.78288567450739, 48.27674781122516, 45.62469605476626, 45.64016980509604, 45.358696599160474, 44.61480732887022, 46.319237985918605, 46.246521165294034, 48.26668693173317, 47.87015491916288, 46.82988351391208, 48.71809682538433, 49.17880665871405, 50.70302794056554, 47.08511214102469, 51.49224019819691, 61.906305589983546, 59.64399622332666, 55.868522736334036, 61.50618068633541, 64.48701335537818, 62.0365910376272, 60.76958702456567, 59.21426919198806, 61.85714652461391, 61.79260392342845, 65.97636868876796, 63.44340793548092, 65.95332868637578, 68.29657616153841, 70.7092809677124, 64.01259876066639, 71.89708448225453, 68.30340893037858, 77.60367024329402, 68.38864203422301, 86.4539650947817, 17.2672737029291, 0.4440871656181351, 3.5804971235413707, 0.26454830121609474, 0.11164600750611675, 19.02666461083197, 83.39965466530093, 60.46753706470613, 63.743069171905525, 42.15733651191958, 23.907911123767978, 24.47870815953901, 48.0673324677252, 58.71650080527029, 70.96596087178877, 20.077406783257764, 0.442736184885425, 0.06264113648343952, 0.05075174684245741, 0.06766302285776024, 0.03887812329095699, 0.025862774008043835, 0.038917500210265, 0.041739484670782284, 0.16701689680978177, 0.16623796925189036, 0.2435635135418946, 0.07792066437222304, 0.10015250529132544, 0.13619753201642346, 0.1145213193470432, 0.11287673541735257, 0.39333016341251714, 49.54095517435382, 85.09279281862321, 66.18954950763334, 53.207696637799664, 28.318830151711744, 39.520499629359094, 54.515814935007405, 69.8435511127595, 80.87514661973523, 79.79598491422593, 6.0106557415377715, 0.3423539068429701, 0.4034529121652727, 3.1593066405865455, 3.565936059721055, 26.567507559253325, 73.50003950057491, 64.50493858706567, 80.42582342701574, 74.70998087236958, 80.31645990187123, 66.7588972276257, 57.527485278344926, 64.32843585168162, 75.0609859343498, 69.49420129099201, 74.66981580180507, 70.92901214476555, 72.65902842244795, 68.77580350445163, 71.41349546370968, 65.52549223746023, 67.52671687833725, 68.35514499295142, 65.1817867063707, 64.32347405341365, 61.21117530330535, 51.266496027669604, 51.16745225844845, 50.180583923093735, 50.694763506612475, 50.56958498493318, 51.560348233869, 51.43765649487896, 53.5674838865957, 49.55655051815895, 49.948728699837964, 51.450388508458296, 51.19279861450196, 51.44395974374587, 48.93241120922951, 48.42052621226157, 51.02073992452314, 49.72729521413004, 48.80422422962804, 47.05592186220231, 47.984405717542096, 47.854708625424294, 47.27568049584666, 49.33798428504698, 49.41135614149032, 45.027770150092344, 49.73114305926908, 46.695091262940444, 46.728003871056345, 51.72395421612648, 51.035601785106046, 50.37569830494542, 50.79027322030837, 49.687989142633256, 50.0479450533467, 49.17373111171108, 47.348871923262074, 50.70309462085847, 53.52458492402108, 55.02229882824806, 61.844390976813536, 62.66272683297435, 59.598045656757975, 48.97296459444108, 60.80646514892579, 61.092382400266594, 55.325458818866366, 50.820326420568655, 52.13933713974492, 52.73165425946636, 53.13945524154171, 48.41637242224909, 50.663690490107385, 47.502169916706706, 49.30497361767677, 49.620779329730624, 48.07184319342337, 45.44406306359076, 47.500530365974676, 46.7247522261835, 47.246121514228086, 45.62888122374012, 45.869985395862216, 46.80592567689958, 47.94521339478032, 44.618737543782885, 45.35573913205055, 45.54552693520823, 48.074361355074, 49.02536353757305, 50.12407433602118, 50.933926105499275, 49.873666301850356, 46.874943702451645, 48.81608155465896, 48.39545442212013, 48.02992482339182, 48.6550800261959, 51.50523893294796, 49.39818874482186, 50.05741365494267, 51.562658509900494, 51.93200849717664, 53.28793264204457, 50.10958117823447, 55.05285801426057, 65.7047563214456, 63.81246374499414, 60.45023548987604, 67.15726098706646, 68.63207217185729, 63.979360595826186, 65.90982960116479, 62.276279234117084, 66.78414944679507, 63.95612055255521, 69.21539921914378, 65.58113498072471, 67.14905538866597, 69.36208017410772, 74.71556632749497, 67.14750213007774, 74.66139839541528, 70.94704720281786, 82.01902743308776, 70.05057381045434, 89.94611401711741, 18.558668974907167, 3.560286866080377, 10.474884683086026, 0.28434269550827246, 0.21031152847553455, 23.39335891508287, 92.73746875024612, 66.38183978296095, 75.5086774210776, 53.40159900726811, 28.397369730857115, 30.78903102105664, 59.010180427182114, 68.6095577670682, 82.04459344187092, 28.447954577784387, 0.77941000942261, 0.14931948434922004, 0.1695353342520614, 0.1362186760431336, 0.18675060161659796, 0.24987848355404793, 0.1148583980337266, 0.15193087890023185], [0.021630854518603415, 0.05812891691382374, 0.037390970429706, 0.07216335274279118, 0.03966933123827462, 0.03767795845746033, 0.050452846147480516, 0.01067392124358805, 0.6151359984951635, 44.26836790577058, 65.30481576919556, 54.69227452431956, 34.863897062117054, 29.629117519624774, 38.77441383177234, 43.95545298053373, 62.601835958419315, 75.96089532298427, 49.879067405577636, 0.3883909800600621, 0.07448793929671088, 0.2583836223329267, 0.7380794433336104, 6.426867756151385, 51.67010007366058, 76.92093464636034, 73.23136498851161, 72.8449252343947, 75.26235257425617, 69.1019642737604, 64.86267051389142, 53.56919011762066, 52.34503407632151, 52.90749411429129, 56.950869406423266, 58.73734820273615, 60.89843296235608, 57.37822340380762, 61.62219262892201, 61.67902777271887, 63.64231132691907, 62.099709818440104, 59.775650578160445, 58.80962179553125, 56.698315835768184, 52.105024245477495, 47.73342893969628, 46.83515910179385, 45.831408885217485, 48.145838706724106, 48.17830808701054, 48.105332389954604, 45.98005494763775, 45.778939339422415, 46.63737358585481, 44.43699452184862, 45.44432978476248, 46.518149222097094, 47.004111274596184, 44.54289459413098, 44.23569456223519, 44.908090791394635, 45.55713715091829, 46.133207813386, 44.95563384025328, 44.98604005382907, 43.42554077025383, 44.36796080681586, 43.03728103637696, 41.95004709305302, 43.352741579855646, 42.33512186234997, 42.85367488861085, 42.429086162197976, 41.35202292473086, 43.117556264323575, 42.78841841605402, 43.56130969139838, 44.15780805772351, 43.340837186382664, 43.49674747836205, 44.255133828809186, 44.356860499228205, 46.158001115245206, 53.77290625726023, 55.83926185484856, 56.74817700539866, 52.7231191819714, 40.31241047766901, 57.36809192165252, 56.85934482082244, 51.33838522818781, 44.77999794867731, 43.73942844329342, 44.2215387282833, 43.093665107604, 42.661847452963556, 43.47721015253375, 42.2833897221473, 43.43344826852122, 40.125984145749, 41.34450374111053, 41.45980181232576, 41.25393229146158, 41.59101293933007, 42.199176434547674, 39.38753912525792, 41.68037629896595, 40.58580360104961, 42.10908351405975, 41.43650685587237, 41.39750280687886, 41.389171692632864, 43.54938960844471, 42.47493082477201, 43.98007369810536, 43.83193362143732, 46.74645077797675, 43.7987542921497, 44.34321065102854, 42.49687256351594, 45.654392319340865, 45.7944562358241, 45.05700357498662, 45.2018488607099, 45.72981165301415, 45.43261758742794, 47.60308857887022, 44.46004236898115, 45.91643410344278, 49.487654086082216, 53.4511189306936, 57.43585871111963, 55.20615993007537, 57.783196356988725, 62.060129181031265, 58.27568915582473, 61.36074704508628, 58.591898872006325, 60.68910783337009, 60.680176596487726, 62.687535824314246, 63.62211504290181, 63.42186235612439, 60.2161092142905, 61.3181540273851, 49.923786347912205, 65.84687555989912, 64.43179030572215, 71.57904301920246, 66.09513805758569, 80.43661778972995, 39.957090808499245, 1.0648046049379534, 10.2263044734155, 0.16407009364376146, 0.253920562625412, 6.517705926972051, 66.43856510039299, 66.34875066818731, 56.072693870913604, 64.50210271343109, 29.42746258551075, 12.179362408576473, 45.08974752118511, 41.21569702702184, 64.43060574993011, 26.316919096054573, 0.48112592329421355, 0.10614206413588217, 0.06490676108026697, 0.04681965501438226, 0.03315544649658184, 0.08080316977875848, 0.018052911731384454, 0.015251155822507799, 0.06733349779801023, 0.02296808780351233, 0.0007187854064414429, 0.08178363208689036, 0.03848431962392023, 0.0570493649631258, 0.0018349934074532001, 0.07300575834608848, 0.9853025742115514, 57.94775939756825, 73.51066127900155, 64.15728322921261, 40.64119923499323, 34.55959958414878, 36.19809519860053, 45.58176963560043, 70.26431160588419, 79.70509575259301, 56.13786797369681, 0.44465474483947603, 0.06654381436566192, 0.3144491848445708, 0.9482698226647993, 7.937663745495581, 55.40446319887715, 76.56694858304917, 74.71970050565659, 74.07148961097964, 76.40559796364077, 73.40673415891587, 67.07721325658983, 55.88509867268225, 54.632250493572606, 55.4318021189782, 58.76465966624599, 60.75765125213131, 63.95580676294143, 60.17889376609557, 64.15932286170222, 63.77404020678613, 65.58107222280195, 66.18993389991023, 61.43107121990573, 63.09966318068966, 58.602591253096065, 54.601781522074056, 50.26848423865534, 47.52906953134845, 47.74605504928097, 49.66088164237238, 49.323938277459916, 49.2566264829328, 46.53354452502343, 47.624971482061575, 48.66798070169265, 46.22492067275509, 46.865490790336366, 47.83007614074215, 48.5770405492475, 46.721571183973744, 47.690027913739605, 45.810710537818174, 46.739625853876916, 47.11611455486667, 46.214087086339156, 47.024429152088786, 45.187508675359915, 45.48714245519331, 45.08265587591356, 44.79727598928636, 44.13943567583638, 43.12983328296293, 44.93815183639527, 43.17115937509845, 43.79296879614554, 45.345093819402884, 47.04580214715774, 46.98092614450763, 46.32549024397328, 46.20165317289291, 45.01880361187843, 47.24803955324235, 45.918391366158765, 49.606195957429954, 56.50138147415654, 57.44282876291583, 60.1361713101787, 55.41013102377615, 42.04483901300738, 59.24119234085084, 58.98018606247441, 53.728418734765825, 46.61968761874784, 45.89263708360734, 45.92867189838041, 45.245410703843646, 44.602926469618275, 45.86427050252115, 45.78756070906117, 44.77132166585615, 43.462528720978774, 43.398135169859856, 44.206049288472826, 42.6088797661566, 42.48868657696632, 44.23269787142354, 42.521681554855846, 43.241303120889974, 43.300930992249526, 44.4006419950916, 43.77936209401777, 43.720342190034934, 45.773589226507376, 46.53411326869842, 45.885302251385106, 46.70269281633439, 46.364557050889545, 48.585532480670565, 45.06423250321419, 47.234248499716486, 45.62065601348878, 46.62940332966466, 47.4915442159099, 46.310487178064164, 46.87915632801671, 47.49119120259439, 46.74235582351685, 48.00091889596755, 46.67259647000221, 47.43258314747965, 51.935067945911044, 57.04875607644358, 59.73790953236242, 57.84870778360675, 59.47158059766216, 62.54219631994925, 59.34550385321341, 64.78861616503808, 61.13676794113652, 64.90627550309705, 63.82037908800187, 64.1605152622346, 66.63777443670458, 64.58904597067064, 61.342084407806404, 62.14234205984301, 51.490914437078665, 66.90907693678334, 68.95362807858375, 72.1073470577117, 68.77267345305413, 82.7701848553073, 43.16493457363498, 0.3700430516994769, 5.781857025238776, 0.08869583658393353, 0.26888607490447264, 6.5126857834477585, 73.09940076643421, 69.23529348065777, 64.6636337618674, 56.063084063991425, 29.37139230389749, 20.815681180646344, 51.34835197079567, 50.32392694104103, 72.52139245310138, 35.5250439336223, 0.4441779930024378, 0.05633677295859783, 0.06802758111828758, 0.0036843907042977313, 0.026824668260110963, 0.07130036235696847, 0.06479781571655505, 0.05739221995275828, 0.12825293211086145, 0.11770364092362505, 0.12253275276311945, 0.17434302627319292, 0.12256246165282304, 0.13125012087966167, 0.11095130365462073, 0.12813943618487927, 1.9348893939487397, 74.57073673125237, 85.41875746942337, 73.49326164491715, 48.712703566397394, 39.730707291633856, 51.845355495329834, 60.918523342378684, 74.16185317500945, 88.1923673998925, 61.793439388275154, 0.7340205869367047, 0.23487549425373155, 1.2238998614972638, 3.1411992638341846, 8.797538972670033, 57.16189684406404, 79.57313937525596, 77.83006160489975, 76.56774874656432, 81.59278346646218, 74.42196123061642, 68.45201184672695, 57.421090987420854, 57.178143301317775, 58.977554152088786, 60.9975669460912, 64.33785738483553, 66.51578872434555, 62.68086779502131, 66.30782465780935, 66.98940707791236, 68.01281621379238, 70.11213933267902, 64.31503703517299, 64.28913762492519, 61.15495597162555, 58.24658909151631, 52.835298968899636, 50.95301628112794, 48.659484847899414, 53.212846709835915, 51.62666766874252, 52.24302499525009, 48.618354874272505, 49.542653560638435, 51.77142666232202, 48.19430743494342, 49.90562577401438, 50.768217732829434, 51.39022327238514, 49.131271454595755, 49.49522033814461, 49.60934169830815, 51.00784709376674, 48.51886787722188, 49.698046099755075, 50.85320764972318, 49.42722997357769, 49.0016528098814, 46.81892048928046, 48.15777840152864, 48.386931111735684, 46.06282480301396, 46.73681743683354, 46.93495988845826, 45.4536218797007, 49.09034936658798, 49.38887703803278, 48.19912018314485, 48.65838266188099, 49.20102688574022, 48.00783795695151, 49.06483042624689, 49.21462966549782, 49.79466584420974, 58.254053361954234, 61.18875111303022, 61.2056722179536, 57.58659147447156, 46.072320861201135, 60.99493503570557, 63.249246689581106, 55.783230796937026, 49.207773362436605, 47.28115220223704, 48.08276699435327, 48.28660472746819, 46.83953254453598, 47.652412383787095, 47.344267060679776, 48.747895071583415, 45.37936748996858, 45.68396306806996, 46.354735435978064, 46.40269425607497, 46.00439717692714, 47.73875944076046, 44.952072328136815, 46.9552856106912, 44.25177627994169, 48.31071945928758, 47.61711497460642, 46.88978202881352, 47.12088807936638, 48.128866610988496, 47.32036805921986, 50.63366082406814, 48.561233397453066, 54.20806184891732, 48.92665316981655, 50.063128548283736, 49.682768467933904, 48.034145293697236, 50.688985855348655, 49.13690790053337, 49.727852190694506, 50.132750618842344, 49.48596746690812, 52.24906544531546, 49.13637445818994, 51.52374859779112, 53.96090938198952, 57.778438521969704, 63.74730140932145, 61.903869798106534, 64.18865042348062, 66.63804900261664, 63.393515386889064, 68.16456487101894, 63.5825304831228, 66.45568232382497, 66.38530715819329, 67.7704058924029, 67.36543686159196, 67.4968990202873, 62.70774779781219, 63.65667896886026, 56.244811396445, 71.30967816998883, 68.92929369403471, 77.22061157226562, 71.9373280002225, 86.55350700501474, 46.04966525108584, 1.97111064387906, 17.25874254780431, 0.5539267990858324, 0.4094977442535662, 9.585466654069963, 78.98359929361652, 77.24830350568219, 73.15960914857926, 79.86159832246842, 41.622289919084125, 24.020106600176906, 60.93259288418678, 61.178419589996345, 82.03652904879662, 46.40250990467687, 1.2117308306117212, 0.19363492817407657, 0.15719410212289903, 0.12068347780094033, 0.15835838722846202, 0.16330428151113374, 0.07675054167667705, 0.16375464928005973], [0.03970715299909634, 0.09477068399710041, 0.019021283256851377, 0.02488118555066326, 0.04780443039752784, 0.03504900900166362, 0.07353959905524408, 0.19624744121345783, 2.7752801247181433, 61.23586662354008, 61.415016958790446, 45.00042730762113, 25.54696567596928, 27.314507269090225, 42.42455190227878, 48.28949159191501, 62.44816926217849, 76.09542477515437, 30.594477538139593, 0.056810556204929474, 0.02961559934661754, 0.1563330959048002, 1.6212053164359064, 29.241130390474876, 75.30258824748378, 67.20342728399461, 74.79381761243268, 71.96847161939068, 72.33925327177971, 68.6053059178014, 62.17908682361726, 49.735630250746205, 54.83964189406365, 48.41250104288901, 47.83472807176652, 50.62408239610734, 49.28382027533747, 49.643156451563684, 50.11398992230816, 50.78022803029707, 53.428208366517104, 54.625707980125185, 56.883820410697695, 55.142044867238695, 51.67824683650848, 49.59074966369137, 48.25529636875276, 47.48604897529849, 46.87409647049443, 45.48715422230382, 46.952383056763686, 45.432433236029844, 47.60524196009482, 45.73675424821916, 46.76166565187516, 44.6562393250004, 46.6425746487033, 45.54716256357009, 46.18703449926069, 43.73092474475984, 43.446764715256236, 43.78866987843668, 43.662973603894635, 44.91736719685216, 47.541719175154164, 45.28612882860246, 43.66959064237533, 43.93577444937922, 43.21939668347759, 41.53668419007332, 42.35940525608678, 40.04431647639121, 41.996644850700136, 42.84304526544387, 42.1994274662387, 40.431066097751746, 42.92132792934295, 43.18068288987683, 45.719805686704575, 45.64145242014239, 47.23952408759825, 45.60721012853807, 46.601444675076394, 45.72828192864695, 53.815365914375555, 56.34465140681113, 57.703999780839496, 51.90179055736911, 34.689696758024155, 51.56718492507935, 55.82827921836607, 51.43551488076487, 50.04736846493137, 46.53858869306503, 45.60329168073593, 44.85247550472137, 44.06307497332173, 42.49796690479402, 41.375357104885964, 40.83914164573916, 42.6234592160871, 39.75690480201475, 40.21842656597015, 39.90607646203811, 42.04069699010542, 41.14229379161712, 41.91753456669469, 42.04370152565741, 40.44946985860025, 43.174999375497144, 41.58636100830571, 41.23583839785668, 44.10482860380604, 44.08258092018866, 42.718647295428866, 42.568714695592085, 43.978814617280044, 44.23051703360773, 42.97618227620279, 42.39670307405534, 43.41916691872382, 43.364139987576394, 45.25180808959469, 44.16560572962607, 45.59524297714234, 43.71675322132726, 45.2969898716096, 44.57156319772044, 45.49919197636266, 44.06380845654396, 48.58843895696825, 55.972571449895064, 58.768397685020204, 54.808039357585294, 57.294225846567464, 60.14706765451739, 61.68779427005399, 60.43737403808102, 60.290242010547274, 61.83669136416528, 62.724763039619695, 63.158879203181115, 63.66140934728808, 64.31917121333461, 61.73267010719546, 58.167282689002256, 65.94019659103887, 65.84769141289496, 69.52984779111802, 66.85257911682129, 67.0593507828251, 70.84796813226515, 67.80467171822825, 1.5701903571044247, 2.1164687795023767, 0.07593889450353962, 0.1071563262432333, 2.373131032912962, 50.10054795972763, 72.77231431776478, 53.91802610889558, 60.39434955966089, 39.781305866856734, 13.46088605542337, 30.60776456709831, 50.32742177286456, 59.591267801100216, 44.032354970132154, 2.187549481468816, 0.12889571818372897, 0.022166913052299814, 0.05480566197225163, 0.023318446624363144, 0.026746971622830438, 0.006649368827516634, 0.03648439347143135, 0.026571351711848573, 0.02112023584965256, 0.04716528324230064, 0.02274623257108033, 0.018177240140615933, 0.021088500657389243, 0.0822441888252093, 0.23469895695246037, 4.1342159144340025, 75.6028849078763, 67.55182789218041, 53.409702624044115, 33.71017502200219, 38.91621928061209, 37.43497148636849, 51.157081511712846, 69.30939489795317, 81.07831754992085, 34.399543346897254, 0.01123049561189668, 0.05307785791134643, 0.5326412606143183, 3.21957974183944, 30.50964451605274, 78.69483440153061, 69.88373971754505, 76.94562988896524, 73.0270879499374, 75.51722818805327, 69.76609999133696, 65.68788620733446, 54.28783893585206, 56.72423093549667, 51.81119165112896, 51.612327483392534, 51.61794823984946, 50.99779013664492, 51.784915693344615, 53.03847774382561, 53.66215421307472, 54.77587984454248, 56.52220533740137, 59.14347041037775, 58.189145980342744, 55.28617235922045, 52.59245718679121, 50.50921578561106, 48.62356770423151, 48.75134283496488, 46.760453639491914, 47.674460026525686, 47.835414486546675, 49.302494679727864, 48.414736793887236, 49.72562428443663, 46.56803784831878, 48.98020921214935, 48.84561700205649, 47.32812258505052, 45.41339012884325, 45.713314164069395, 45.60569609365156, 47.67939436820246, 45.96694246415169, 48.9914938711351, 46.52658624033774, 46.258978612961315, 44.11681144468246, 44.93935600403817, 44.247057668624386, 45.197404815304665, 44.38642340321695, 43.660247556624874, 44.94267040683378, 44.62111450010731, 43.50085419993247, 46.76677650020969, 46.98524859643752, 48.549054438068026, 47.99451758784633, 49.90788898160381, 47.595949865156605, 47.72254044009794, 49.46853253149217, 53.275675235256074, 58.64403893870693, 58.427339753796986, 54.39744172557708, 37.904604711840236, 52.9124088441172, 59.901907751637125, 54.72594414987872, 52.3043865542258, 49.16970675991428, 47.497608200196304, 47.49264640192832, 46.94783702973397, 44.058595626584946, 44.51246092396398, 43.22378581570041, 44.60169876775434, 40.87054414133872, 43.89442090065249, 43.493456609787486, 42.782613308199, 42.61756781608828, 43.88152022515574, 43.74413136513003, 43.814867388817575, 44.21256826769921, 43.71063824622862, 43.64693110988986, 46.47437164860387, 46.24843135956795, 45.00744050548923, 45.53449330791351, 47.110293757530954, 44.8881612285491, 45.42967973216888, 45.16601408681562, 45.88639659266318, 44.782504343217425, 46.94836262733706, 47.52295847861998, 48.430163475774954, 45.12882609521189, 47.33692046134703, 46.986174275798184, 48.24912648047171, 46.539808550188624, 52.05720270833662, 57.96690840874949, 59.4424452320222, 58.91845972307267, 60.51358569052912, 62.00996206652734, 63.88404700063891, 63.78018263847598, 63.66948942984305, 63.63920873211276, 65.73012621172013, 64.93571289124029, 64.66215110594227, 64.8435724935224, 63.57106147273895, 59.845982597720244, 67.72769912596672, 68.4381894142397, 72.86180711561634, 69.61530839243244, 71.13588579239385, 73.49425008220058, 72.29542470747425, 2.2981088392196165, 0.7539066972751772, 0.4181425255392829, 0.2427784879241259, 2.491334109537063, 55.70863516099992, 78.4477956833378, 60.53071468107162, 60.20167489205638, 40.97826027101086, 25.13636019922072, 40.96103322121405, 59.508796045857096, 68.18194881562265, 53.66662571507116, 3.780034958354889, 0.13894619420170784, 0.048720774976837064, 0.027364995818765416, 0.024655580317841905, 0.05646450279821312, 0.07977812115343348, 0.04617528696995109, 0.09317258628265512, 0.11860974673782626, 0.1503141882318643, 0.09059588785373396, 0.1338174194097519, 0.13257116289629092, 0.21644631460789712, 0.33959871758857085, 6.6047918604266265, 87.93006281698905, 77.4588720260128, 63.52268688140377, 37.874171041673236, 37.05767477712324, 57.74658103143015, 63.66203300414547, 73.49475214558264, 89.04645566017398, 38.50396248602098, 0.22705885401416212, 0.2439807556689747, 1.5511450435846084, 4.1756248666394145, 35.201503307588645, 80.71050905412244, 73.34467441804948, 79.31202719288488, 78.91083148217972, 77.32056140899658, 75.79785808440178, 69.15632047960835, 56.04756716758975, 59.49908425731044, 54.41899907204413, 54.27065503212714, 54.569955410495886, 53.89744151023127, 54.58742172487321, 54.38960090760262, 55.54413095597298, 58.7881350517273, 59.9450969696045, 61.86591694431921, 62.53764244817919, 57.63910024396835, 55.50388743800502, 53.47492771763956, 51.74107536192864, 52.021768016199914, 51.29485084164528, 50.50099842010006, 49.78596602716754, 50.88403747927759, 50.60142286362187, 51.73056340986683, 48.622187029930856, 50.69623831779727, 50.9744716459705, 49.5866507868613, 48.332806325727894, 47.826200839011904, 48.43312094288488, 48.50147216550766, 48.011466149360906, 54.214235659568544, 50.28256946994413, 48.06194313110844, 47.03225035821238, 48.919275191522416, 48.861298638005415, 47.725933290296986, 45.2128864103748, 46.93805856089438, 48.929245856500444, 47.52937547622189, 46.466495529297866, 49.5354324771512, 49.93431791182488, 50.96174747713151, 50.637857760152514, 50.658673778657, 50.347653358213364, 50.20616954372775, 52.37536184249386, 57.115656022102606, 61.268649793440304, 60.03495454788209, 58.38062040267452, 44.240068004977324, 56.15273375664988, 60.990330173123276, 56.931508587252715, 55.775801827830655, 51.83487099985923, 50.55525264432354, 51.33494138717652, 48.579099793587964, 46.51568597362888, 45.27637389398391, 46.999647617340095, 48.08558325613699, 44.67288978638188, 45.92301584059193, 44.48483567084036, 46.21057264266476, 44.84778434999528, 47.83208831664055, 45.86607479280042, 46.11139943522792, 48.49274881424443, 47.10270004887735, 46.08633156745665, 49.262949343650575, 47.91410115457351, 47.90306752727878, 47.24807877694407, 49.51424383348035, 48.59671908040201, 48.47085414394256, 47.75271523383356, 49.09254589388448, 47.78047776991322, 49.30917447613132, 49.99778578358312, 51.17613638600996, 47.700477107878655, 48.839588319101644, 49.977946435251546, 50.6760851798519, 48.09899383975614, 55.45885470605666, 61.226288195579286, 62.26541426873977, 61.991797570259344, 63.20645363100114, 63.00656180227957, 67.41696896091585, 67.25113115003033, 66.52371191209363, 67.05612659454346, 67.7633220918717, 66.980589589765, 68.36675520866149, 67.42109529433712, 65.45443457941856, 60.302789672728515, 70.71408979354366, 71.47983843280424, 76.72620465678554, 73.0207415549986, 74.14894857714253, 75.51330581788095, 75.8813653453704, 2.2350962075494953, 6.430879360245121, 1.2969673665300494, 0.3357565415001685, 4.159044027328491, 61.93017321248209, 85.87791796653502, 64.63250975455007, 77.14142676322692, 51.38160582511656, 22.21155074334914, 46.05710598730272, 70.2719602277202, 75.02055414261358, 66.78607925291985, 6.116620042631704, 0.3229419436425932, 0.4440974005528035, 0.15674469962475762, 0.1797790329663023, 0.16947248439875343, 0.22839501860641667, 0.16258543056826438], [0.03606020675731763, 0.028644247739125165, 0.104387600215212, 0.09589969841462952, 0.059236162942984415, 0.0622564492627017, 0.10265394324256528, 0.10808889273433916, 7.2019736997542845, 70.22253051880868, 62.12599754333497, 40.97529495916059, 18.16757925095097, 16.69897717814292, 35.30325351222869, 51.76574707031251, 67.25355517479682, 74.30160722424908, 14.652312859412163, 0.16502140630637446, 0.2605642150005987, 0.28254226631214546, 19.71430120929595, 65.10726559546687, 72.11519964279668, 70.87076494770666, 69.71798035406297, 69.25645859010758, 67.90882633578393, 63.48655008500623, 54.603330858292125, 50.53128304020051, 49.070172694421586, 48.65207941301408, 49.590416262226725, 46.89296699339344, 46.27683324198569, 46.68854090475267, 45.2247594248864, 47.37298273271131, 46.93483437261274, 45.5570077127026, 48.5786134196866, 46.95521108565792, 47.16125319080968, 43.90299912421934, 45.82039879214379, 43.04304299816009, 43.850396217838416, 45.05145734356296, 46.35854405741538, 46.93223776355867, 47.29823804670765, 43.14713485779301, 43.896307560705374, 43.623322363822695, 47.1952130717616, 45.91451214205834, 44.85926120511947, 41.110138200944476, 44.98224319950227, 44.8471293141765, 44.388451268596036, 45.23988408427085, 47.02061268591112, 46.00158875988376, 46.31251112107308, 43.12524803223149, 40.98639134437808, 42.15154317117507, 41.78631167257986, 40.9642142634238, 40.325471970342825, 41.99999063245712, 40.40672779083252, 41.10901248070502, 42.498080653529016, 41.73432850068615, 42.26020851442891, 48.45805937244047, 52.77366284401187, 48.87658411456693, 50.364817650087424, 47.45848255772745, 49.36101644269882, 56.322070321729115, 56.49901236257246, 57.24674163326141, 33.321385768152055, 45.02360067059917, 57.61112197752922, 52.69226581819596, 54.969841049563506, 48.73613580580681, 49.5212217300169, 47.753178073513894, 48.8616124276192, 42.20075714972712, 40.80510723975397, 38.902094825621575, 40.62269741489042, 39.33291619823825, 41.33426635496078, 38.571133075221894, 39.49259981032341, 39.17157342357021, 41.32884171701247, 40.96234329285161, 42.389807547292406, 41.9460266636264, 43.76287244981335, 42.22724491550077, 44.850180918170565, 44.35512288924187, 46.67831920808362, 42.955942846113636, 43.777675474843676, 44.71160750235281, 43.42962003523304, 43.00492540482552, 41.98902368545532, 42.99830052160448, 45.410903346154, 43.30586925629647, 44.52878582862116, 43.693062105486476, 45.28867836921446, 43.466772725505216, 45.37069512951759, 44.39058896033995, 52.60289461381974, 59.41779313548919, 63.285936540172955, 56.408860606531945, 55.48001981550648, 59.578559321741906, 59.688915206540024, 60.543368247247514, 63.61525481747043, 61.75604743342247, 63.4576932076485, 61.85631890450755, 65.64406941013952, 63.19304696975216, 69.13703026310091, 64.03394037677397, 66.53434938000095, 67.60430136034566, 66.782713859312, 57.99391392738589, 71.16741380383893, 65.7869456660363, 87.53429566660236, 11.115250837418342, 1.309803813215225, 0.7834699076990929, 0.22443800593816468, 0.45556463361267124, 38.513952762849875, 75.22876924084079, 59.260933629928104, 56.260477342913234, 33.35567905056861, 12.170993051221295, 18.324634875020674, 41.49779388981481, 48.21796717182283, 58.36577030920214, 10.022805044727942, 0.16654150860924877, 0.0906960844933506, 0.0683147261940664, 0.02623044067032395, 0.01691848681789012, 0.014137408579699697, 0.07159959630019243, 0.11605957793372294, 0.05013406930130817, 0.02722101342383652, 0.08211119596155421, 0.015287626395753075, 0.06217151309453672, 0.0659731401491069, 0.19818441792120858, 11.01271027518857, 80.73041900511711, 66.89915334024738, 49.701109470859656, 21.049758426604733, 24.757714194636193, 36.7820341356339, 57.618354828126975, 74.43593271317022, 81.17813402606596, 17.614428958585187, 0.3027356698388054, 0.11967799506120144, 0.5535925396027104, 24.04562750170308, 68.59087944030762, 74.7035324958063, 71.7306661605835, 74.83592817860266, 71.49778719871276, 70.34801498536142, 65.3368733006139, 57.79974483674573, 53.9671028044916, 50.56188144991475, 50.82586872962214, 53.08336927044777, 49.22957389585434, 47.94058892034715, 48.65606454110915, 50.276466261956, 48.88897488194127, 48.34288289470058, 48.97813035595802, 51.4891101467994, 48.73182119861726, 49.88717886709398, 46.64847781581264, 47.54564154532648, 45.80548201837848, 47.3249101638794, 48.55501644072994, 47.54255464000087, 48.65455442859281, 49.104548346611764, 45.308596164949485, 47.317720459353545, 47.17742512303014, 47.94971627573813, 48.34857425382061, 46.79289164081697, 43.91136161742672, 46.985778116410785, 46.10389986345845, 45.394652966530096, 46.9473506558326, 48.36807235594719, 47.55040722508585, 46.63987998039492, 44.51507714486892, 43.60663267873949, 44.44043444048974, 44.32124930043375, 43.45642159062047, 43.2578476782768, 45.11054392783873, 41.630617110959946, 43.59717976662421, 44.483796242744695, 43.769030570983894, 43.151755409856, 49.32835094390377, 53.44874981910952, 52.59483022074546, 51.532256218694876, 48.4410951214452, 52.75438439461493, 58.84774723360616, 57.82934304206603, 61.7094849771069, 36.58403681170556, 45.702794367267245, 59.66924844249603, 55.52010251629738, 59.429462186751834, 51.847995250455796, 50.910321281802275, 50.95321239963655, 52.59859961848105, 44.934064726675714, 44.105216918453095, 42.04375643883982, 42.39416530055385, 42.475738833027506, 42.92172408873036, 41.62563962321128, 42.2279627092423, 42.47072604394729, 43.00467829550467, 42.74836317185433, 44.261448844786614, 45.06288713024509, 46.73314217598208, 44.049750681846376, 47.23408768253942, 48.25650053639566, 47.52191905052432, 44.20692005465108, 46.133415699005134, 46.77887701219129, 45.847008151392785, 45.49702682802754, 45.15938528122441, 46.2246931752851, 47.209521878150206, 45.40304291632868, 46.987166635451786, 46.35887745888003, 48.25007177168324, 45.49662674626997, 47.39877231659428, 47.13150593542284, 56.78984042136901, 60.25097908512239, 65.31336653617122, 57.778897439279866, 58.639320327389626, 62.597686090777, 63.10452299733316, 64.1703329547759, 65.7416775918776, 64.48270659292898, 66.57967628971224, 63.64605326806346, 67.56990217393445, 64.74719201364826, 71.16155378280148, 65.31713593390681, 66.61806060421851, 69.42188847449519, 67.91521195442446, 60.689268650547156, 75.04324897643059, 67.93726351953322, 88.79650654331331, 13.76931575036818, 1.542212458387498, 0.2967058530738277, 0.1443496574797938, 0.7048369271139945, 41.94020978866085, 82.0161013449392, 63.771094506786724, 63.484883077682994, 29.606255985075432, 15.779984478027592, 24.727374661353327, 49.55060028260755, 55.469245064643125, 70.7876185447939, 12.857564726183492, 0.2971759246241662, 0.09832635852358035, 0.028047057304290995, 0.05030569980942434, 0.05704126741376616, 0.05355369810375476, 0.048258046379252795, 0.20780574680576402, 0.13281962053189356, 0.14647732879365646, 0.2244719283114518, 0.12963241897523403, 0.13093584096960484, 0.23739097459662348, 0.3610174634283589, 16.4465275502974, 92.81781458085584, 77.96137471352854, 60.37580459348617, 31.766705320727443, 27.34420941722009, 51.85559680384975, 69.10701628654235, 79.4299493297454, 89.18820227346113, 18.912521677632487, 0.3114740670688691, 0.45713401069083526, 1.700449083601275, 25.403181391377604, 72.65777326399281, 78.43613839918568, 74.44796654485887, 78.16817775849374, 74.91963940282022, 73.548935767143, 68.2065656108241, 61.00505475075015, 55.83407648148076, 54.83084401776714, 52.64348722273304, 56.327887196694654, 50.966356262083984, 50.28806078818537, 51.388328767591915, 51.94210075563001, 52.07247641778762, 50.76000428968861, 50.71115116919241, 54.391228691224136, 51.09491194448164, 51.67951376207414, 47.92871590583555, 49.36338163191273, 47.9777180763983, 49.1758099679024, 51.56227019525344, 50.14006583921371, 50.87522391350039, 51.96506231061874, 46.536478457912324, 49.982512074132124, 48.43077536552183, 50.35969503464238, 50.9233670849954, 48.840761107783166, 45.05394412625221, 50.02119056640133, 48.19451532056255, 47.415489458268695, 49.45088186571675, 50.89542804225799, 50.79039481378371, 49.32502869636782, 47.690847689105624, 46.827110398200254, 48.21029893813595, 47.491528526429214, 46.50284021131454, 45.42693799541843, 47.23745699851744, 45.3184256246013, 45.10944566419048, 48.2688638471788, 47.282175940852014, 46.68683075135755, 52.95322110576015, 57.58340258752146, 54.82167743867444, 55.5906149648851, 51.95191060343097, 55.627948084185206, 62.906023610022764, 63.4688719626396, 62.524412293587964, 42.02537621221235, 50.303008940912065, 61.384904922977576, 57.51968760644236, 62.07306123548939, 54.85730824931976, 52.73489413722869, 52.15123761084772, 54.37398202957646, 46.32958912080335, 45.170960195602916, 45.54413449379706, 45.780563200673754, 45.80099874927152, 44.18622562962194, 44.60940230277277, 43.84505394966372, 43.353690793437345, 45.500733467840384, 46.635369254696755, 47.76828704341766, 47.1476347215714, 49.90704174964659, 47.401388537499216, 49.26427510476882, 50.351607107347064, 51.10601225206929, 46.11923240846204, 48.95217995489798, 50.38080523090978, 49.902393740992395, 48.08292388916016, 46.862372506049375, 47.88562082475232, 50.370218753814704, 47.740387224381976, 48.32393392439812, 48.79070381964407, 49.72049382425124, 48.18963196969802, 50.6468282207366, 51.47799807210123, 58.69753222311697, 63.8681927804024, 69.47487969552317, 61.16753109039799, 62.941270028391195, 64.62989353364514, 66.66330906652635, 66.83551680657172, 68.50491677561115, 66.6550563996838, 68.33305420414095, 66.00426458543348, 69.91832717772454, 69.45077280844413, 75.89453666440903, 68.51356952421128, 70.49421741116431, 74.02494676651494, 71.31411829302388, 62.335165777514064, 78.42368879625874, 72.72945850126206, 94.53205508570518, 13.770596404229442, 4.25275533430038, 3.078001790469693, 0.22156690758082176, 1.1409854912950148, 48.89535657821163, 89.43439375969672, 70.12019588101295, 73.85277040543096, 41.06022211813158, 18.15716535814347, 30.216888612316502, 59.35017147371846, 64.54952809118456, 80.13283021988408, 18.532428318454375, 0.5035329531998404, 0.24634712465828468, 0.14923997974443823, 0.1403768021132677, 0.12824149441815194, 0.200457661262443, 0.16282385245205896], [0.04560720596101977, 0.04462036214047863, 0.024362662769553643, 0.06085430917840812, 0.04185378498908493, 0.06326786918385376, 0.04045006293322771, 0.08847951633675445, 20.527657616523005, 77.32199699647965, 54.88841264478622, 40.60245798480126, 18.965238332748413, 26.082237805089644, 35.679032264217255, 51.94556028612199, 69.41734636983564, 65.75109128029116, 14.694916663631318, 0.22427864432815584, 0.28939081656356014, 1.3619580985076967, 17.838986612135365, 75.35455180752662, 73.63812262012114, 67.97924856985769, 63.361151910597286, 62.210454017885276, 58.66869495761011, 53.60858248126123, 52.45790027802991, 52.87986101642732, 54.0739324785048, 51.35461207359068, 48.89937308526809, 45.26755640583654, 48.594397037259995, 46.89703449126213, 47.89883136749268, 47.08259790174423, 47.229435751515055, 46.56136981902584, 46.97814126168528, 45.232219772954146, 45.36972630408503, 46.12790476891303, 46.98289517433413, 46.47468936058783, 44.96705185982489, 44.95186836488786, 44.457998814121375, 45.95188448506017, 47.21244012155841, 45.61509017021426, 45.15454899880194, 46.73795884655368, 46.78847897437311, 45.949056456165934, 45.82296794460666, 44.4704915631202, 43.997249757089925, 44.13145365253572, 45.24264543287216, 45.26652090011105, 43.48942049088017, 45.32432879171064, 47.58533593147032, 46.8775716904671, 42.09719481006746, 43.51344108581544, 41.51893154267342, 41.03446391320998, 42.028094414741766, 41.03268315715175, 40.24438088940036, 39.94212304392169, 40.222764707380726, 42.27862796475811, 40.63158942807106, 45.60278177261353, 51.20892740065052, 54.502318059244466, 53.41255810952956, 54.78968266517886, 51.29782007586572, 56.44531119254328, 56.698817899150235, 57.70528239588584, 35.120655413596864, 38.79835990167434, 55.25177317280924, 51.84640276816584, 57.12708973115491, 53.19236409279608, 52.58695410143945, 48.69607271686677, 46.73723320807181, 40.691593846967145, 42.99014983638641, 39.425417454011985, 40.31484626954602, 38.3848322591474, 41.622097722945675, 41.62077980656778, 42.62449079944242, 40.67867748198971, 43.164197168042584, 41.63726160603185, 42.85092530712005, 40.79901187650619, 43.24462536842593, 42.138258103401434, 46.894837963965635, 44.7305094042132, 43.720785417864406, 43.34779939343853, 44.48357266764487, 42.754913530042096, 43.89323634486045, 42.69645060262373, 43.4393592803709, 41.96030409105363, 44.75679320673789, 43.79551049201719, 44.594026611697295, 43.51020513042327, 44.473613769777366, 40.75305346519717, 45.80863560399702, 43.90517211729481, 57.08623040106989, 57.24782812979914, 64.44453016404184, 37.08637868204425, 47.919600317555094, 59.386869169050655, 60.752579627498505, 61.73550598083004, 60.147561873159106, 63.00474574488979, 64.4939951742849, 62.21544327274446, 63.36944772351173, 61.59985473079067, 63.670277826247684, 63.8744842621588, 63.537478139323575, 61.261675819273925, 61.70235018576346, 57.56403784598074, 67.81572495737385, 65.44609562043222, 85.68597285978257, 35.72351586434149, 0.6664526126077098, 0.2363873381287821, 0.03736909095858855, 0.03877179028706686, 23.746662485984064, 71.38250873934838, 62.076442318577925, 53.08223962783814, 67.82700569398942, 47.040652075121486, 20.016186429608254, 38.78225857211698, 51.415538249477265, 61.74022459214734, 23.286470405517086, 0.22363977296458137, 0.036155795378069726, 0.04840089879449337, 0.04917794560653068, 0.01931613900758807, 0.030519791856227867, 0.04334650730954544, 0.06403701762939173, 0.03863748741306124, 0.014992620300261245, 0.017185357376752843, 0.08412441373952935, 0.021546492916381648, 0.017696226939498898, 0.11066443437049467, 26.88173059494265, 87.42697177394744, 61.73084228269516, 48.56515968999555, 25.534925960725356, 30.082135585046586, 36.551645878822576, 59.51556213440434, 75.0840965394051, 72.27257297885033, 14.494497276121571, 0.3134145677810715, 0.4367625989740895, 1.1014807272341944, 18.785442767604707, 78.61925817305043, 73.54093413199149, 70.90447379696754, 67.13388366083946, 66.84299284412016, 62.034798514458444, 56.308895080320305, 53.669261547826956, 56.758504606062374, 55.90099996136081, 54.4339236905498, 51.14200784314064, 46.85966999300065, 51.053158313997336, 49.59809234065395, 49.1981400212934, 49.67124062199747, 50.470823626364435, 48.24893036196309, 46.746160522584, 47.690847689105624, 46.99649010935138, 49.28477341128934, 47.45189297583796, 47.76052467284664, 47.04652778563961, 46.96741750163417, 47.56330005584225, 48.68851430954472, 48.479922663780954, 47.809656281625074, 49.6120834350586, 48.236708256506155, 48.47780850625808, 47.7537860408906, 46.5240994576485, 45.84214833474929, 45.83671192969046, 47.09404337790705, 46.37657127072735, 46.977701956225985, 46.26018278060421, 47.60635199085359, 49.71383756206882, 48.87840017195671, 44.38658814276419, 45.167877212647475, 44.09240253510014, 44.56287122541859, 44.496010503461285, 44.463541123174856, 44.15922403335572, 43.45194224388369, 43.70348776540449, 42.58306272568242, 43.68394259483584, 47.727141380310066, 54.15992259979249, 57.75111529134936, 56.72969087477654, 54.36962819868519, 54.01524989835678, 58.17583345597791, 59.679913366994555, 61.424003108855224, 39.63672730230516, 42.16181193628619, 58.95192930775305, 54.34434460055444, 57.117938841542895, 55.32773379356631, 55.77618622010755, 51.103258748208326, 49.287907385057025, 43.4510910895563, 44.81622495958882, 40.521512031555176, 42.23861978900048, 41.59357816942277, 43.62292228206512, 42.26393868846279, 43.3779388858426, 44.302378777534734, 44.702582128586315, 42.99634718125866, 45.34073606614144, 44.58149071662657, 44.87331505744688, 45.604739035329516, 48.1995673333445, 46.62580259384648, 46.318900662083784, 46.17971927888932, 47.566155541327696, 44.93044830137684, 46.154274863581506, 45.01643842266452, 46.490798534885535, 43.790427100273874, 47.192443878419944, 44.44439995673395, 47.03951066540134, 45.97047259730678, 44.854315096332186, 45.6505327070913, 47.27027546974921, 45.75302031732375, 58.6882479729191, 58.79253202869047, 64.42176472756171, 41.2699394841348, 52.91492700576783, 61.56464361375379, 62.704562833232266, 63.22421412314139, 62.72202914760959, 64.5107868409926, 64.97752535727717, 63.716326452070675, 65.4736698827436, 64.55288956242224, 66.36037657337805, 67.2263966837237, 67.65967738243842, 63.9385954026253, 65.1345770589767, 58.98606961773288, 69.43405566676971, 66.4001807858867, 87.57124439362558, 40.23845026569982, 0.6216593291009627, 1.532498218359486, 0.15247892287950363, 0.06757941202170427, 24.532946694281794, 79.29145043896091, 63.73154132596908, 65.05340360826062, 47.131670674970074, 31.24386710505332, 27.11834365321744, 46.77360142430952, 58.87330539764897, 68.94043322532409, 29.288547923488004, 0.21375290268371183, 0.07135056409864657, 0.0670919502754846, 0.10208103971015062, 0.01734257394057368, 0.031872456067151604, 0.05913476737576628, 0.2207473467194265, 0.18947263458563438, 0.0942535057002979, 0.13069786341680636, 0.27940740388247276, 0.21442310704338938, 0.10930953126761223, 0.1453521754592657, 37.05227367339596, 97.89168280939903, 71.42701979606383, 59.33275615015338, 31.818823814392093, 36.80687842830535, 49.77975691518476, 67.18384681209442, 80.60241637691375, 77.56756874822801, 18.052124284928848, 0.37365849640580917, 0.6290984105679297, 3.0192897925453805, 22.151108980178837, 81.96160393376505, 79.85325936348208, 74.73512326517414, 68.12198362042828, 68.93218840322187, 65.57646343784948, 60.107577231622514, 57.05836588336576, 57.58295543732182, 59.478899740403705, 57.768577683356504, 54.82072430272257, 48.742207634833555, 54.7093839030112, 51.49757069926108, 53.41051063229961, 51.96886308731572, 54.6105597865197, 52.439582809325195, 51.75394858083418, 50.5648075380633, 50.43134889295025, 51.80045220159715, 50.67038205362136, 50.513773579751295, 48.787852256528794, 48.365299240235366, 48.7474439990136, 51.87312587614983, 50.517499831414995, 49.43870290633171, 50.79692948249079, 50.735018791690955, 52.61320260263259, 51.84893269692698, 49.64929496088336, 48.15093778794812, 48.94742211987896, 49.684498233179895, 49.91085037108391, 50.38302529242731, 48.36398916859781, 50.29698810269756, 53.18254640025478, 51.32138175349082, 45.24758369691911, 47.43332055307204, 46.28490547980032, 47.54557878740373, 48.09043522804014, 47.59769139751312, 45.669885681521514, 45.0141320690032, 46.18925063840805, 47.46511920805901, 47.25793177081693, 50.43260797377556, 56.97171680388912, 59.74219668296076, 59.454632036147586, 57.62747826114778, 57.765490778030895, 61.832514039931766, 63.58852778711627, 62.73509456265358, 42.930125805639456, 44.70230756267425, 58.77945092416579, 56.97203843824325, 59.736426876437285, 60.08201122283936, 58.8260918278848, 52.98224664503529, 52.98196423438288, 44.57069635391236, 48.547701220358576, 43.526267236278905, 44.23663985344672, 43.609378337860115, 46.70181812778596, 46.08024797131939, 47.496058863978234, 48.23698282241822, 48.4572042957429, 45.9330649529734, 48.08963506452499, 45.935237946048865, 47.62865851002355, 47.065076674184496, 51.86589694792225, 48.96998359311012, 48.12156315772764, 48.211573708441954, 49.44574356079102, 48.87612911962694, 48.55812295790642, 49.322498767606675, 50.74671922191497, 47.174526491472804, 50.354066433445105, 48.31541453638385, 51.17400653900639, 48.41435632398052, 46.860391709112356, 46.08938317145071, 51.336678997162856, 48.738857930706395, 61.51426469126056, 61.664271816130615, 68.9749736170615, 44.962129285258634, 55.17031731144075, 61.78396686430901, 64.68077451952043, 65.48592336716192, 66.29384533051523, 68.78148309646114, 69.43102759699669, 68.01941364042221, 68.90125659204298, 67.6808189576672, 69.85354531195857, 69.95833535348216, 69.83751850743448, 68.58008507759341, 68.65259401259884, 63.5062482280116, 72.16768095570227, 71.25944829756214, 90.64877525452646, 43.1761682418085, 1.0667499779693543, 3.6214167600677865, 0.4187740577805427, 0.1374918528862538, 29.97279755530819, 85.55172581826487, 72.12881026729461, 71.15136346509381, 88.49045184350784, 61.950914705953295, 33.218447085349794, 59.2475308910493, 68.49750349598547, 80.87696659949519, 38.82167839234875, 0.3572925600794054, 0.12598459939322165, 0.2094298991705141, 0.21586402649841002, 0.06922135294805612, 0.13240755715918157, 0.1840190385137835], [0.035901630387431195, 0.0920570090473179, 0.09113530568297833, 0.01596373059005747, 0.04640489501217681, 0.03747845384021921, 0.052946037162215485, 0.1347575778321874, 32.21007631671044, 69.93625240941202, 52.660906468668294, 41.3719367980957, 14.837583072723882, 31.80998867557895, 39.59971581735919, 59.99780577998008, 71.70077769987046, 65.58336288698258, 8.204872271706982, 0.5126300327960522, 0.5084772846631466, 0.3194750587065374, 29.18213402071307, 75.91763157998362, 69.61544959775864, 69.0771984284924, 60.25655669550742, 58.81011993654313, 58.040637200878514, 57.08497132024458, 60.24208707194175, 63.925396626995465, 64.55083816282212, 62.38398751904888, 61.77619272662748, 54.913774690320416, 53.1926308139678, 49.313653822868105, 47.07127794142693, 46.981392906558135, 45.31644875003446, 46.31371921108615, 43.826956133688654, 45.709552611074145, 44.904290014697665, 43.735800250884026, 44.206249329351614, 45.81049088508853, 43.58346323813162, 44.99468495768886, 45.194945489206624, 45.09852186326058, 45.95073915296986, 45.699515265803186, 44.934727607234834, 44.70810482578893, 45.0075581765944, 45.07402666153447, 43.14035700213525, 43.90705877734769, 45.13328190772764, 45.205375071494814, 43.70236204516503, 45.11902801452145, 44.81959819793702, 44.85178516757104, 45.93034675044399, 46.122080049207135, 46.482757676032286, 49.10210863236458, 44.19958522242885, 43.67066144943238, 42.151911873971265, 41.368277226724935, 42.358522722798014, 40.83918086944088, 38.76715744695356, 39.18118715286255, 38.0263864609503, 42.03663733697707, 46.599675686128684, 51.83002687269642, 51.74768063329881, 55.95590137666272, 55.41907010539886, 54.5036595098434, 56.48835920518445, 56.59310610063615, 39.60445796289752, 42.05853985201928, 54.97774462546072, 52.558108991192235, 55.18564593407416, 53.67201505168792, 50.44385340905959, 46.99749815848566, 42.278149435597086, 40.884276359312, 39.62447774025702, 38.71128328384892, 39.3148732954456, 39.860443607453384, 42.10145058170442, 40.18237213934622, 41.74742921706169, 42.267351150512695, 41.93463217827582, 42.13990942124398, 44.14977896598078, 44.15201079460883, 45.83560974367204, 45.35928103231615, 48.09457332857194, 43.9672593147524, 45.00032140362648, 43.09338661932176, 43.38086889636132, 43.01204450668828, 44.26338257328157, 41.42092720154793, 42.30342518898749, 41.449105508865856, 43.710732383112756, 44.25295299099338, 44.25733035610568, 42.85131362176711, 43.78626938789122, 43.9621720006389, 43.86647401317474, 44.337911528925744, 53.98952307239656, 57.84175342129123, 58.395109638091064, 49.38024782365369, 60.018076589030606, 61.09112331944128, 60.44447745046308, 62.02679295693675, 60.43417338402041, 59.39748702510711, 61.27405481953775, 57.18619592728154, 57.748236271642874, 56.33852466460198, 55.49081025585052, 54.95374756474649, 54.443000055128536, 52.68700984216506, 53.65224238364927, 51.30138943272253, 62.95839117419336, 68.09257368887624, 77.61030689362558, 58.71390811858639, 0.48801568907595455, 0.8290297081393581, 0.2430291518929505, 0.31492434321872653, 13.124694804991446, 65.56621428458922, 67.18543144964403, 60.03306004308886, 56.49463499746015, 35.929142198254986, 14.627745093837863, 30.92999904386459, 44.986902975266986, 62.29559298484557, 34.615940509303925, 0.5404932941159895, 0.03158123348839581, 0.06343400684155284, 0.06709057131722089, 0.08027344296175627, 0.025094945148955432, 0.05871851350210848, 0.011450449031056657, 0.03167109177147429, 0.08657748089923013, 0.004647966998163611, 0.030689212200682492, 0.0549349814443098, 0.04792638776463367, 0.0710594353656615, 40.72565570954354, 78.76235408167686, 59.343389695690526, 49.63120498964864, 18.790967425992413, 27.671476294917447, 37.84895020146524, 67.80809986975886, 76.20177592000654, 72.48471044724988, 10.515530243996652, 0.4459389227051889, 0.20648046066203427, 0.544913437577986, 31.997785875874182, 79.17066497187461, 71.15839235244259, 70.99329979188981, 62.26103690362746, 62.46452946816722, 60.31012842732092, 58.87176782854142, 61.72944591891382, 64.2418848314593, 67.1515735503166, 65.39266509394493, 63.44929541310957, 56.92905710589502, 55.813966489607296, 52.273768532660704, 49.89708285177908, 49.2223253557759, 48.73299790966896, 48.00815566893547, 46.87178227209276, 48.610886681464414, 46.85271563068513, 45.250290132338, 46.93371257474346, 47.06991295660696, 45.022420037177305, 46.28559189458048, 46.63366694604197, 49.17476269506639, 46.18079008594636, 47.592913950643236, 46.08302500940139, 47.28326635975992, 47.106704788823286, 47.73502142198625, 46.49932969001032, 44.35183986540764, 46.89518705491097, 45.72459490068498, 44.902062108439786, 45.461007702735166, 46.478195959521884, 45.509056737346036, 47.046465027716856, 48.14294007516677, 47.78532974181637, 51.04003798577094, 48.40647628230434, 46.46182006405246, 45.95279447494015, 43.803359154732, 44.231372110305294, 42.980085034524244, 41.32597838678668, 41.35793785895071, 41.66166267087383, 44.002882280657374, 47.788063633826475, 53.49076624839537, 55.80228174886396, 58.51504395084997, 56.560342542586795, 58.01193721832768, 58.24107816142421, 59.37556097584387, 43.09173530147922, 45.741963155807994, 56.14069600259104, 55.43223750206732, 57.58137864451255, 55.04140861572758, 51.05636681279829, 49.90664559025919, 45.692364784979056, 42.11415906106272, 42.45269490826515, 42.384782991101666, 42.12715779581378, 43.35598145761798, 43.63778414264802, 42.7819896513416, 43.536014326157115, 45.14502156165339, 43.55386503281132, 44.435429496149865, 47.07811463263727, 46.96423253705425, 47.35854448810701, 47.7970576286316, 50.36081291014149, 45.318029465213904, 47.35623813444569, 45.70683048617455, 45.40388230354556, 45.03470097818683, 46.80196016065536, 43.881955608244866, 44.42664338696388, 44.69957759303432, 46.14360993908298, 47.94451521288964, 44.17124609793387, 45.26575996029762, 46.522228487076305, 46.59109746256183, 45.325834981856815, 45.61156003705917, 55.96034149969778, 61.01460964448991, 60.73663519274805, 55.19528711995771, 60.62593806174494, 62.5415648183515, 62.74034661631431, 64.64253141034034, 63.43703408395091, 62.73939740273261, 62.346626943157574, 60.18752690284484, 60.41767589507565, 57.04581429881435, 57.42280898555633, 56.001412637772106, 56.810527001657796, 55.53255604159448, 56.152902418567294, 54.158055551590465, 65.38949581884569, 71.09396349999213, 78.14784419152045, 64.87572808419505, 0.5397595044585967, 2.5711403690999557, 0.7760194268438124, 0.3882078544026421, 13.434620884156997, 71.47643381549467, 72.96573423570203, 66.97662015115061, 60.449709892272956, 34.33864854997204, 17.70980138932505, 39.40458182365664, 52.76095828702373, 70.86252012560445, 42.87606377755442, 0.7615315397420238, 0.0398484081210148, 0.04846125503160781, 0.01945705322038022, 0.06726797429784652, 0.05618271267702503, 0.051124448617619854, 0.11376280803233386, 0.2573705783053752, 0.18332485560207598, 0.13692620420648208, 0.1111448940730864, 0.132067981025865, 0.17695443614596323, 0.2358695699442779, 50.85458047928349, 88.12213343958702, 67.55421269324519, 58.698650098616085, 25.912273660782848, 44.60703711355887, 52.66143206627139, 76.66245045200472, 79.3175655795682, 84.35036659240723, 13.083514821144844, 0.7378631001037936, 0.9162086140244239, 0.93026694030531, 35.372051885051114, 82.82106584118259, 74.18739564957158, 74.78081887768161, 66.03474924641272, 65.83513982834356, 63.42211338781542, 62.24855984410932, 65.07567482609903, 66.56916433765043, 69.98924363044001, 67.37737655639648, 67.92782629689863, 59.01451856859269, 58.850924353445734, 55.19140005111695, 52.1492293573195, 51.52272485917615, 50.69919578490719, 51.67779184156849, 49.25240209025722, 51.24420127561016, 49.947979527135054, 47.975137156824914, 49.05855463397119, 50.17360994892736, 47.18430888268256, 48.48442554473878, 48.62396778598909, 50.537837320758456, 49.128208083491174, 50.7455111319019, 49.258811243118785, 49.7443026111972, 48.3499784623423, 49.8830525336727, 48.023358775723366, 48.26586715636715, 51.248578640722464, 49.9613901107542, 47.911328038861676, 48.08979980407223, 48.27556717780329, 49.91374508027108, 49.84264035378733, 50.05575449235978, 50.425080945414884, 53.62302072586552, 50.383248867527136, 48.36606018004879, 48.67377012006698, 47.19740175431775, 45.478732893543864, 45.94276889677971, 44.50407881890574, 43.26722606535881, 43.91883765497516, 46.072340473051995, 51.582337041055005, 58.575213109293294, 57.53341590204547, 62.82337927049207, 59.07202836005919, 60.03229518090526, 60.73165770499938, 61.90349717294017, 47.64212008445494, 50.28224783559, 57.65062024516445, 58.180654048919685, 60.65264155787807, 58.97904465275427, 54.9796744315855, 53.99287669889389, 47.377571905812914, 44.598435355770974, 46.067006049617646, 44.78806626412177, 45.2122627535174, 44.818892171306, 46.34390969430247, 44.549154696925996, 46.77251492777179, 48.38919824169528, 46.64557526188512, 47.46466421311902, 51.09508452876922, 49.85799251064178, 50.3215931307885, 49.168498669901204, 53.52500461762952, 46.45101785659791, 49.90264477268342, 48.07025463350358, 49.32297337439753, 47.89173579985096, 50.040057166930175, 48.418321840224735, 46.82722022456508, 47.560809350782826, 47.822313770171135, 51.404214366789795, 46.0849783497472, 46.89894860790622, 49.087376209997366, 49.516985570230794, 46.50282059946368, 48.9345371338629, 57.831331683743386, 62.79039998208324, 62.177208008304724, 55.19653835604268, 63.797872527953125, 65.57510629776986, 66.07209021045317, 66.15095338513775, 66.68903981485676, 64.76329334320562, 64.97775285474717, 62.809533303783795, 63.91484152886176, 62.33001962784798, 60.30674342186221, 59.499241152117335, 60.21758010310512, 58.532274923016956, 59.05251456845192, 57.65123997965167, 67.51567148393201, 74.67508746731666, 80.8678823901761, 67.44852050658196, 0.49345800833356, 4.532991032446585, 1.1267208115708445, 0.5649359115669804, 17.18522556366459, 79.14498913672664, 80.37748413701212, 74.74696882309453, 74.46895907002111, 48.88291874239522, 23.529725997678696, 48.42516245380525, 64.45723864340013, 81.31885297836797, 56.176362114567915, 1.2286287690362623, 0.14587855447203885, 0.2907859546042258, 0.16548793853050278, 0.1852800805241831, 0.21060775935409531, 0.17991449263307357], [0.0762005518340776, 0.13663501418646307, 0.06115131763621204, 0.016227701506126794, 0.013973838274156856, 0.055613026713892344, 0.022412285268787416, 0.4088864060899904, 44.509734876694225, 66.51631432194864, 48.53424749066753, 28.62968191023796, 19.334592242394727, 44.46857744647611, 43.86744676097747, 60.3721881681873, 72.93674792012861, 56.686886049086056, 3.163688418365294, 0.1541857974183175, 0.27927977363428763, 0.5217027507962719, 36.341473517879365, 76.67720640859297, 68.6064826288531, 65.22265388119605, 58.6184690075536, 60.4098625336924, 57.320576329385084, 61.99934813284106, 63.390534385558105, 66.60697598611155, 68.27185738471248, 62.19042639578543, 63.55299111335509, 59.46335930978099, 57.834626474688136, 57.313119903687515, 53.98102721860332, 50.686079379050966, 48.41098308563233, 46.5611776228874, 48.109933330166726, 46.07436049369074, 44.15223829207882, 47.016607945965184, 45.733584973119925, 45.811706819841945, 45.99056689969955, 43.97538254337926, 46.241476997252434, 45.000219422002, 43.21108125871228, 47.16964706297844, 44.79686806278844, 45.19220375245617, 46.76764334401777, 44.29023119711107, 44.581529940328295, 44.856637139474195, 43.66946904889999, 45.12201686059275, 42.96532907793599, 44.79498140273556, 44.227873356111594, 43.838260404525265, 43.994202075466035, 43.007592616542695, 45.457834505265765, 44.699997286642756, 44.849059120301284, 46.27592325210572, 43.29523571075932, 42.35063875875166, 42.234313026551284, 41.14043066578527, 40.25575968527025, 40.86708853321691, 39.94173080690446, 38.49798871624855, 42.17925471644248, 47.49309355212797, 47.87321829026746, 51.447215310988895, 54.443058890681115, 52.908215830402995, 53.30453995735415, 50.009023374126805, 41.86466886151222, 42.203436128554806, 48.37822344995315, 53.50400424772694, 51.532275830545736, 49.643631058354536, 46.78202667543965, 42.784292082632746, 40.446665363927046, 38.25461741416685, 40.29087274305282, 39.144446311458466, 39.6321459739439, 39.927214114896714, 42.080120732707364, 42.66585611527966, 42.61456328053629, 40.28858207887219, 42.99905753904774, 41.489631437486224, 45.94221192021524, 46.8775716904671, 45.198687430351015, 46.708799946692686, 46.05700008330807, 44.183609408717004, 44.24103683040988, 44.669442023000414, 43.10182363756242, 42.92086116729244, 43.02262706141318, 40.532475056186804, 42.39978997938095, 42.56601218254336, 42.53737888028545, 46.04016527052849, 43.20028297362789, 43.53686155811433, 44.408063119457616, 44.27025848819364, 45.56966127887849, 44.277969867952415, 46.19917815731418, 53.21436858946278, 57.931701214082786, 59.61051487153577, 57.36285555747248, 58.26570672373618, 55.44700130339592, 55.57459208273119, 56.161170774890536, 53.84712926803097, 52.39586799375473, 50.55728050970262, 48.59695834498252, 48.23910482468144, 47.10104088629446, 51.14261581051735, 50.51317345711493, 52.387097574049434, 53.929110727002545, 56.96568027619393, 59.32391512778498, 69.82998755670363, 70.43458953980478, 74.44478158027896, 4.472759606376771, 3.2305395795452982, 0.289078988134861, 0.34139592921541584, 5.573409526578842, 64.44997833621117, 66.25945398884436, 64.43331610771918, 45.32878068185622, 41.47974314228181, 17.06341439677823, 27.250117640341482, 46.97968667553317, 56.155044032681374, 42.563333203715665, 1.6109890130258377, 0.1154716284344754, 0.03702870660251187, 0.058453554332616835, 0.04444429981372049, 0.023887176892810294, 0.03839219372058588, 0.09827492338034416, 0.10629763361066581, 0.036328732066096804, 0.04494688796600507, 0.06122024256675955, 0.0428225759476904, 0.07344434368273906, 0.6193778579754214, 54.93173522333945, 74.4444913248862, 58.83820410697692, 37.01037099284511, 26.607639289671376, 38.38515389350153, 42.46902765766267, 66.22882027779856, 74.9390394456925, 64.8076553498545, 3.4249013566201736, 0.20645118078156827, 0.27665920134994293, 0.5872076809886964, 39.35759182899229, 78.93417742944534, 71.6442955693891, 68.86159358486053, 61.654489424920854, 63.1072372774924, 60.83864427381947, 64.97993761493315, 66.46155018960276, 69.92956084589805, 67.85181076295915, 64.61580437998619, 65.52824966369137, 61.58868382053991, 59.505234533740634, 58.5389272628292, 56.926091794044744, 53.79997845618956, 50.57376623153687, 49.76416549374981, 48.34622475408739, 48.56258269279234, 45.90494548120807, 49.29331633352464, 48.080872489560036, 47.325447528593, 46.2436931363998, 46.833915710449226, 46.65536549783523, 48.22835360803912, 47.31485320675758, 50.28444044051632, 47.10946221505442, 47.34338060502083, 48.566971825015166, 47.14882712210379, 46.58249570477394, 46.06204425134967, 46.18910551071168, 47.06661816566221, 44.96940135955811, 47.35078603990617, 46.92998632307976, 47.76692990333804, 44.83913552376532, 43.529722844400716, 47.26105397747409, 46.52612340065741, 48.39385801746, 47.00323658604776, 44.63741194817328, 44.31500488711942, 44.947279191786244, 41.80282092863514, 42.8934791011195, 42.14320421218872, 42.75129710474322, 41.77323449042536, 47.75157382411342, 48.59423229771276, 49.91367839997815, 55.09874974527667, 57.42901809753911, 55.173510120761016, 56.323090137973914, 53.76434372317407, 43.94152072168166, 46.48018852356942, 53.18280527668615, 55.33264460102205, 53.63931425156132, 52.016237474256954, 48.89219122548258, 45.812848229562086, 43.864516750458755, 40.07225551912862, 42.74214621513121, 40.82555847783243, 41.85339204726681, 43.937649342321585, 43.73716131333382, 44.38954168750394, 45.90039553180818, 44.114022639489946, 46.31320145822341, 44.564259744459584, 47.05793796047088, 49.0212332817816, 46.32993036700834, 47.87353992462159, 47.776853499873994, 46.946538725206935, 45.82893779200893, 45.16453535326066, 45.306317267879365, 44.603212802640854, 44.6003298605642, 43.39377349422824, 44.83615060006419, 45.47449673375776, 44.3488706311872, 46.577498605174405, 44.45561793542678, 45.476842311120805, 45.522749731617594, 46.715538578648726, 47.53839300524804, 46.162958991143014, 47.34407878691151, 55.58626113399383, 58.82021611736667, 62.91580207886235, 58.50663046683035, 60.28542533997567, 57.63148692346389, 58.86134216862341, 57.238563491452126, 56.824416114437966, 54.240119380335656, 54.30509344224007, 50.92011936249272, 50.333066063542525, 49.00899940921415, 53.30720324670115, 54.10313844680787, 53.93763795975716, 55.445855971305605, 58.68916188516925, 62.25447870069935, 73.13009723540276, 72.9872602032077, 80.15805106009208, 5.618489326969271, 1.9321514569943952, 0.6021403280958053, 0.5043413291775412, 5.9270288482789075, 69.74247947815927, 72.65171712444675, 71.085310751392, 51.0603048724513, 43.9973948847863, 24.70430131881468, 34.11030384802049, 54.65241932099866, 64.54510758000036, 53.152120574828125, 2.2582482426397266, 0.07375955055918425, 0.10683674500474047, 0.07106767081084751, 0.03183861796353613, 0.02585705516168908, 0.07558021979827075, 0.3540060122407252, 0.27874050902262815, 0.3517050824819073, 0.17857055990926682, 0.1328363059268844, 0.1683620246307504, 0.158646420966233, 1.3420947256588167, 68.3116380630001, 85.33422254746961, 68.96850170627718, 44.47182909134896, 30.98948374871285, 63.7514748111848, 59.65577902332429, 72.67656926185855, 82.42592627002348, 70.9326599490258, 4.418224442389704, 0.36474282643006695, 0.7277667354191504, 1.144382754160512, 43.0303462859123, 82.26979240294426, 75.73204855765067, 70.87373025955694, 63.8001984934653, 66.0313210948821, 64.01084546119937, 67.10586224832844, 69.23323031394713, 71.84288517121347, 70.90441888378513, 65.72365037856564, 67.29066864136728, 63.440866239609264, 62.61350893205213, 60.79191315558649, 60.40079793622417, 56.47239123621295, 51.80683782023769, 52.193218738802024, 51.831093757383286, 51.86661866403396, 49.096044648078184, 52.45388769334363, 51.42912926212434, 49.55922557461647, 49.571051520686, 48.357870271128995, 51.16671877522623, 49.837427523828325, 48.15714689993089, 51.82127998721216, 48.707686854947, 48.38104755647721, 53.08555795300392, 48.53401999319754, 49.966355831392356, 48.15189484627017, 48.563818239396625, 49.937851967350134, 46.32654143917946, 49.568827536798295, 48.786742225770034, 48.2621056033719, 47.873175144195564, 45.948115087324574, 50.88552013520272, 47.27858304977418, 50.3008790939085, 50.282377273805686, 48.05792662405199, 46.06804940008348, 47.132788550469186, 44.19190129926128, 46.074921392625384, 46.56839086163429, 45.64373523958268, 44.46041499414752, 47.43578772391043, 52.6322574769297, 51.743064003606, 56.795892638544885, 61.292219315805745, 56.86881734478859, 58.31616409363286, 57.619284429857814, 46.78787885173675, 50.552032378412065, 54.31069066447597, 59.49564433866932, 55.377806771186094, 54.87633174465549, 53.317550459215724, 49.50643831683744, 45.58595480457429, 43.76158199002666, 44.46104257337509, 44.73983680048297, 42.80239774334816, 45.821195033288774, 46.52713929453204, 48.8539755728937, 48.456906195609804, 47.19272628907235, 49.09034544421781, 45.77495813369752, 50.59277011502174, 50.9281131529039, 48.09977439142043, 49.738909352210264, 50.96061391215171, 48.811912075165786, 47.170921833284446, 47.84076852183188, 48.41350516965313, 48.099040908198205, 48.12463829594274, 45.87560615231914, 47.964613437652595, 47.60039783293202, 47.85824660331973, 49.70893067698325, 47.51484309473346, 48.866056473024436, 47.70387388044789, 50.28113388246106, 50.32084003571541, 49.63790832027313, 50.92079401016236, 58.85840039099417, 61.60849571228028, 66.83707006515996, 61.89001990902809, 63.85106771223007, 60.31009704835954, 60.27213634983186, 62.34445787245228, 59.40609270526517, 59.3671827931558, 57.14660352276218, 53.51928187954811, 53.856958727682795, 51.972436366542695, 57.46837123747795, 58.3480647302443, 57.54291588260282, 58.78169844227453, 63.22093502167733, 65.74895751091742, 76.82449140856343, 78.33506676458543, 83.92058464788622, 5.992443686531437, 6.872075401967572, 1.8649849127377234, 0.6748379658787482, 7.099048745247626, 77.07345208814068, 78.07349958727437, 77.20354926201605, 61.813655284143266, 54.143833037345644, 31.486367640956757, 44.80839198635471, 68.30133007418725, 73.90022323977563, 66.67141268330236, 3.9396224723708246, 0.4600040518468427, 0.13949636790540912, 0.21465169235823617, 0.22012018117933507, 0.2508592599582288, 0.24028182270065432], [0.037764706423566226, 0.054358787564260345, 0.1188054592198422, 0.04595850323957782, 0.07417412670028788, 0.07108534445926067, 0.03354349684330725, 0.887654984910642, 48.924841034796934, 60.54048530517086, 45.576933353177964, 24.236280187483757, 6.897146701812745, 38.931543980875325, 47.16160228175502, 64.41352775019985, 71.66883391718711, 55.909927275873, 2.123083366501716, 0.1978354035846649, 0.1625151343403324, 0.1759663206194678, 40.62783964218632, 77.04203390306043, 68.65414727118709, 65.89406951781243, 62.27041529070947, 63.16890870371173, 65.74416045219668, 66.83838013679751, 68.87511791721468, 66.77087614613195, 62.59593279130998, 62.68624928689773, 63.47128422029557, 64.26328920548963, 59.821467784143266, 56.158746750124045, 55.76277955885857, 52.57042915590348, 51.92627006961454, 48.22956954279254, 46.68230041380852, 45.18816371117869, 44.90246219019736, 44.69462363950668, 44.08416948010845, 46.1202012338946, 43.79968389388054, 45.81881023222401, 46.240225761167466, 43.95706115230438, 44.49890129027828, 45.2192053487224, 44.358609876325055, 44.70551998384538, 45.583785733869, 45.897744009571696, 42.59197827308409, 44.464451113054835, 42.42231615128056, 46.093246706070445, 44.862642288208015, 46.97112806381718, 44.13055542976626, 44.198600707515595, 45.23309838387274, 44.81205155772548, 44.52873091543875, 42.04322299649639, 43.75547485966837, 42.150484131228545, 43.09698735513995, 41.26662115896902, 40.92507293147426, 41.350948195303644, 40.54192012356174, 39.90671580837619, 39.355089356822354, 38.063970611941436, 41.616653473146506, 41.306464595179406, 47.4255621048712, 49.2901352913149, 50.05271465547624, 51.43242405306909, 49.47181947769658, 45.58352685743763, 45.04848026460217, 41.16458069893622, 47.01403879350232, 49.12978879867062, 49.9288736620257, 45.206100709976695, 43.8788059449965, 41.92131573154081, 41.14349011451968, 39.27459839851626, 39.36142790702082, 40.48719913728776, 39.811076656464614, 39.826052265782515, 39.75967399535641, 41.795988159794966, 39.9899406586924, 40.901377893263295, 45.092089176177986, 44.059501694094756, 44.355417067004794, 43.78476712011522, 47.06150731732769, 47.62009989830756, 44.235098361969, 43.575273329211825, 44.95603784438103, 43.00574910256171, 42.19716818101945, 42.90774868380639, 42.26523307061965, 41.26946487734395, 40.979586032129106, 41.63592015543292, 42.53308780731694, 44.891436407642985, 42.85072526624126, 42.87751505451818, 42.975036944112475, 42.052428799290816, 43.98008546521587, 43.37070603524485, 44.174552655989125, 44.479320818378085, 46.49262243701566, 48.296951939982755, 49.216131933273815, 48.29407292027628, 45.71658934316328, 47.5158707557186, 45.77305970653411, 47.18788608427971, 44.711874223524525, 46.19744839206819, 47.107030345547585, 50.2603570876583, 53.640471350762155, 56.20081809259231, 57.990572067999075, 62.46066201117731, 59.47125504093786, 60.53974005483813, 58.965787041571836, 70.97792410081433, 69.48965918633246, 79.74775545058712, 13.016835508808015, 1.6251126099978725, 0.7558575861396328, 0.2936479978023037, 2.2307254614368563, 54.75532270246937, 70.95096172824984, 63.669669858870975, 59.12209349293863, 33.53732401324857, 11.743441954735788, 25.940016585011637, 39.04840707778931, 54.29693491228166, 49.440483662389944, 3.016223969959444, 0.06495951389473292, 0.033162015700532545, 0.07290659592516961, 0.058033217210322625, 0.0148495236944948, 0.05352749789674437, 0.0675045728923813, 0.035472885450168, 0.10261215314629579, 0.05414046399715928, 0.035533843066303, 0.03396338963460538, 0.036593683574709206, 1.363493093559819, 59.590342121739546, 67.10898445498559, 53.1580747327497, 31.39494307579533, 14.609882620073135, 33.91694668800601, 49.94231562460623, 69.65933307524651, 75.93599611713041, 62.730787800204375, 2.071850593051603, 0.09177522658700905, 0.29351914181343974, 0.5166292875524491, 42.54273291557066, 78.9988337793658, 69.18238070703322, 67.24092514284196, 65.06712013675322, 63.96712280088856, 65.65481670441167, 69.44237109153502, 69.91893122273108, 68.27249280868038, 64.12777523840627, 63.64777126619893, 66.91486635515767, 66.38475018162882, 63.14675907934866, 58.299588157284646, 56.95007708764846, 55.93501475549514, 53.600106239318855, 51.48919251657302, 48.218704577415224, 49.093993248478064, 47.2976222345906, 47.14361821451495, 46.61110547281081, 47.0860731217169, 46.80389388915032, 48.02144858144945, 47.57969556316253, 46.05991832671627, 44.27880141042894, 47.00123225488971, 45.04105914023615, 49.09207913183397, 48.23147581469629, 48.03745577412267, 45.76673292344617, 47.521530735877256, 44.59530922674364, 46.70825473723873, 46.4883235193068, 49.28209051009148, 44.96582415796096, 47.29102088559059, 46.14777941857615, 46.908425054242535, 45.88331753207792, 44.48230966444939, 44.213078175821614, 44.19584328128446, 45.8546293166376, 43.01151890908518, 42.15441042377103, 42.85757372456212, 42.35333734943021, 41.35067362939158, 42.18581291937059, 40.509635094673406, 43.84210432729414, 45.545138620561175, 48.2909664030998, 51.51524097688737, 50.539159159506525, 52.6744229562821, 52.60798192793324, 47.55649082122311, 47.514274351058475, 44.77196101219424, 50.34074606433992, 51.83033673994003, 53.317726965873476, 48.03369029875725, 45.52222021164433, 44.801531760923325, 42.14844449873894, 40.962311913890225, 43.77599670040993, 43.12003912464265, 42.82630066717825, 42.62860536575318, 41.924159449915734, 44.014488573997255, 43.127362189754365, 43.950165625541445, 47.85576766537082, 46.84013266717234, 44.14271477730044, 45.30135154724122, 46.6930006396386, 50.329390802691066, 47.46743732883085, 45.410734684236594, 45.100828216921904, 43.28870104205224, 44.11149663309897, 45.74033537218648, 45.84479985698577, 44.60343245537051, 43.80654019694175, 43.159219680293916, 46.166398909784135, 46.786835501270915, 45.5406710409349, 46.689886277721776, 45.18013461943596, 46.09878901512393, 46.86383947249382, 46.779704632297644, 46.95503457900017, 45.89308423380698, 49.980907824731645, 50.67836015455185, 52.07164095294092, 50.96157489284393, 50.01526386507096, 50.75813724148659, 47.62020580230221, 49.12043786817982, 46.9211256888605, 48.901091083403564, 49.513718235877256, 53.128178427296305, 56.38235715127761, 60.18442430803853, 57.81192771850094, 64.33175025447723, 62.719573743881725, 64.2804927210654, 61.180914217425936, 74.4228006178333, 72.41535509786299, 84.54326875748174, 14.34563450274929, 1.4687681606700345, 1.211516938863262, 0.33148694963705155, 2.541968966684034, 59.95349476414343, 78.17469673772013, 70.71514098874985, 64.00847242724511, 43.032515356617594, 23.19681286811829, 34.24016960205571, 48.984547353559925, 60.91532661068825, 63.02291808589813, 5.5517977572256525, 0.30723272852839967, 0.06914948623987936, 0.11325719000230874, 0.10668000341543268, 0.018135530483578483, 0.05446893185557378, 0.18752595920476223, 0.17026202993527537, 0.2237934042369166, 0.21774256601929667, 0.20308476061590258, 0.4138604004777247, 0.2472848928863964, 3.8883441013674584, 71.32466946878742, 75.57658149350074, 64.11614541084536, 41.956283661627005, 12.975328987644566, 52.87427948367212, 64.41647737256943, 76.01398852563675, 83.15948009490967, 67.02469271998253, 2.935532480478287, 0.30038279931872125, 0.5478166043758392, 0.7622108452262417, 46.61606334870862, 82.81376238792174, 74.22308137339931, 70.11322975158691, 68.3576003966793, 66.83318691868936, 68.60493721500521, 72.19667511601602, 71.34919212710473, 72.1141327581098, 68.06188506464805, 65.01882007045131, 68.85957748659196, 67.40447228954685, 64.09095987196892, 61.36443407304826, 60.89457335010652, 57.990803487839244, 56.63160024150726, 54.24826222081339, 52.67332469263385, 51.68707216939619, 48.8153245372157, 48.652193161749075, 49.51467137182913, 50.47041962223668, 48.47552960918796, 48.5103210326164, 51.21296744192801, 48.07296891366282, 48.38948065234769, 49.4046724227167, 48.64505052566529, 53.34932557998165, 50.46485377896217, 50.87418056303456, 48.14077100446148, 49.518142669431626, 47.48215798408755, 50.97034139017905, 49.21364907295474, 51.68696626540154, 47.43680361778506, 49.71513586659586, 49.15855153914421, 48.70177192072715, 49.260509629403394, 47.00391907845774, 46.370401382446296, 45.04175339975665, 49.54475202868062, 45.60972436781853, 46.06380539555704, 45.883376367630504, 45.393209534306685, 43.79978195313485, 44.86208531164354, 44.32293591960784, 46.376398686439764, 46.961443731861735, 52.1468916246968, 56.314421699893096, 54.3318400844451, 56.522158268959295, 54.25132559191797, 52.8515846498551, 51.280844057759936, 47.044448929448286, 51.06569028669789, 52.60775050809307, 56.68552498663626, 50.925139996313284, 50.40756364022532, 46.91937631176364, 45.49751712429909, 43.58332595517559, 46.38137225181826, 45.91854826096566, 46.73118883563627, 45.89631626682897, 43.62315370190529, 49.101265322777536, 44.86723146130962, 46.09104625640377, 50.45639714887066, 47.08819120160995, 45.251847313296416, 47.18234377522623, 49.08306160280782, 51.313223223532404, 48.042613690899266, 48.766863653736735, 48.85218304972495, 46.839289357585294, 46.15998975692257, 48.16135952549596, 48.992905924397135, 45.772753761660674, 46.45386941971318, 44.674525414743734, 46.5413696535172, 49.04255528603831, 46.40839345993535, 48.673122928988555, 47.420200224845644, 46.634992707160215, 50.476330634086366, 48.02377454696163, 49.54970990457843, 48.99846392293131, 52.39295759508687, 52.642322278791866, 54.65548661447341, 53.103812663785874, 51.56656126822195, 52.95369179018083, 50.514079524624734, 52.15725060432188, 48.76717744335052, 51.73640381905341, 52.502984000790505, 56.19706830670757, 58.95337273997646, 62.369663023179584, 62.08003913202594, 67.71172723462506, 63.9199366877156, 65.85328471276068, 63.758370337947724, 77.28043556213379, 74.87103339164489, 87.2241303228563, 16.53217250300992, 3.575014875781152, 4.424142318387186, 0.3679404161389797, 3.1482328089975544, 65.44453451710363, 84.4570158373925, 74.5288065941103, 75.86218495522776, 45.55668607834847, 23.392729374670214, 39.83647400333036, 61.01461356686008, 72.28819970161685, 77.80269915057768, 9.592438667051255, 0.3934330030554726, 0.3989803070022214, 0.2694323875250355, 0.32373098356108515, 0.2053847251039359, 0.2522432284369584], [0.03285306776242872, 0.0209514532733949, 0.016746856309773944, 0.10726265158624419, 0.01719960661214446, 0.1026082001326065, 0.2753683738410473, 4.058184691013829, 58.98905846380419, 56.79797149473622, 41.88781476789906, 18.448993621333955, 18.935524417508034, 54.904553198045306, 54.74914496944797, 65.1118939922702, 69.06084214487385, 48.852775327620975, 0.6943310424685479, 0.051228506340374874, 0.17470181589165043, 0.9039828926324845, 34.89304811723771, 74.27595492332213, 67.04764643023091, 67.12577219932311, 62.79333391497212, 67.28550680222051, 65.20579945656561, 67.33222223097279, 67.1932291215466, 59.117539621168575, 63.85160507694368, 65.03905557817029, 63.1838607788086, 61.339319136834916, 61.59490077726303, 57.415077993946696, 55.41519480366861, 53.34930989050096, 51.353262778251406, 48.8760075261516, 48.00690051048033, 44.04919762765208, 42.32073853092809, 44.42716898456697, 42.38044092732091, 44.55271228667229, 43.37151012113018, 42.99264054144583, 44.65099511608001, 44.42944003689674, 45.691564621463904, 43.75171722904329, 45.599710556768606, 45.756887774313654, 44.654964554694395, 44.08195334096109, 44.40049686739522, 41.87727535924604, 41.576013795791134, 42.990687201100016, 42.35361583771245, 44.25811483014015, 43.424018890626975, 42.66783298984651, 45.67891105528801, 46.89408486889255, 43.267775197182935, 43.7159256012209, 43.389560868663175, 39.64015545383577, 40.77854887131722, 40.21628102948589, 42.30891258485856, 41.77890623769453, 39.63490732254521, 38.39539127965128, 41.72480890827794, 39.89645096563524, 40.57569173074538, 41.69555979390299, 41.342158163747484, 44.38901216753068, 44.98249815356347, 48.195523369696836, 49.10842364834201, 43.2143368259553, 47.74002244395595, 42.52721601916898, 41.77949851559055, 47.44876684681062, 45.16086793714955, 44.476288826234885, 40.82624097024241, 39.83233982516874, 38.80380022910334, 38.08819909249583, 40.06885874655939, 40.49989977190572, 38.585963556843424, 40.07284387465447, 42.821409471573375, 40.80777837384132, 42.59197827308409, 41.121230663791785, 42.12919350593321, 40.65509227014358, 40.61230313393378, 43.51535912482969, 42.99232282946187, 44.28753260643252, 44.23146624718943, 43.67285797672887, 43.05616724875666, 41.9254106860007, 41.49452655546127, 44.855993870765936, 41.08090869842037, 42.39023508564119, 41.93055291329661, 43.3599312843815, 43.45427213176605, 42.882029702586514, 43.404999317661414, 41.39568282711891, 42.331195569807484, 43.85270649386991, 43.92024186349685, 42.58138395124867, 42.807206569179414, 43.489679367311545, 42.408262298953154, 43.56289040657782, 43.631449514819735, 42.73572137278896, 42.46308918922178, 43.49609244254328, 43.76865010107718, 45.60059309005738, 47.45964750166863, 51.871525549119525, 56.44293815858903, 60.9747975872409, 58.69484147717876, 63.887514375871234, 60.462940046864176, 67.19315067414315, 65.7397360186423, 68.51019628586309, 65.63734646766417, 72.66512378569573, 67.18117960037725, 82.78637639937863, 17.63202863354837, 0.3413316697603272, 0.4819350347163216, 0.02328363941952346, 0.12471548281610013, 41.47155715573219, 74.09208989912464, 67.80074150331559, 52.97127969803349, 50.39179963450278, 31.45642818943147, 12.715839685932284, 41.94373992181594, 44.82984735119728, 63.643695923589895, 6.721683884820631, 0.24767740569528074, 0.06345965163481813, 0.0798763106426885, 0.06075480967880257, 0.1023794922436918, 0.0472331433106334, 0.03601662401530532, 0.04433603626826117, 0.041215852083217715, 0.06236002818050404, 0.03377368328191581, 0.1316553047828136, 0.27269438990662176, 5.6330869178618155, 68.3455430307696, 65.89625035562824, 48.162901016973684, 26.130757524121194, 20.757420255291848, 51.04094013091057, 60.77307008927869, 72.44973075005316, 76.17711990110337, 53.11567391118696, 0.8534391693049862, 0.23674663336526966, 0.04284072074017698, 0.9558485159950872, 38.67965721314953, 77.09406806576636, 68.35698066219207, 69.12831475657802, 66.05218025945848, 68.81723942295199, 67.93090143511373, 69.39879355892059, 67.93316072033298, 60.231375079001154, 63.31480910701137, 64.67838187371531, 65.44198105412146, 62.60257336401171, 62.94957368604599, 59.625106088576786, 56.44966502343455, 57.11656993435275, 53.116913380161414, 51.02628223357662, 51.115296502267164, 46.60824214258502, 45.246363839795514, 47.000326187379905, 46.03457197066277, 45.11660006738479, 45.28849794018654, 45.008546613877826, 45.50879786091466, 46.37063280228646, 45.62391942547214, 46.54357794792422, 46.51941222529258, 46.22753689366002, 46.61215666801699, 47.414473564394065, 45.67660077925652, 46.0607930152647, 44.14264417463734, 46.09589430593675, 44.215910127086026, 45.03648565661523, 46.18512822735695, 45.27864886868385, 46.512818721032914, 48.711687672522764, 44.8970022509175, 45.222080446058705, 45.98176902340305, 41.32490757972964, 42.29918510683122, 43.21347782688756, 43.162859639813824, 44.06465176613101, 42.303538937722486, 42.22624471110683, 43.34278660435831, 41.894141550987, 43.35657765788417, 43.915315366560414, 45.0365327250573, 46.50881005871681, 46.28863173146402, 50.09225606918336, 51.35676937718546, 45.61705135530042, 48.928029921747026, 44.72269996520012, 44.55153165325042, 49.80890797030542, 46.62302163339431, 48.78068608622397, 42.90547370910645, 42.89380073547364, 40.57604866643106, 42.00496812020579, 41.65808546927668, 42.51542929680117, 41.55170294546312, 43.22003995218585, 43.94503908772623, 42.510098795736994, 46.87430827848373, 42.23447776609852, 43.03639065834784, 40.69557113032187, 41.337184598368985, 45.4278205287072, 45.85671993993944, 45.95626969491282, 47.275503989188906, 46.01361474683208, 45.8419482938705, 43.46385448209701, 43.93924574698172, 44.89098141270299, 44.107213404870805, 44.59835690836753, 44.54147861849877, 45.876155284143266, 46.9437381529039, 44.99352001374768, 46.51641553448093, 44.21374497875091, 44.51230010678692, 46.37328824689312, 47.231130215429495, 46.026319303820216, 45.28967465123823, 44.181593310448434, 44.32219459164528, 46.97908263052664, 45.401979954011985, 46.964762057027514, 45.62280939471337, 46.03061037678873, 46.59074837161649, 47.777277115852606, 49.722808022652906, 54.934629932526626, 56.68443456772835, 63.00064686805972, 62.42039888135849, 65.53629444491479, 65.01785124501875, 71.11526981476815, 66.83638757274997, 71.02682821212277, 68.11335440604918, 75.42381302002939, 69.2085664503036, 86.08508971429642, 19.580446404795495, 0.9181306366958927, 2.0326906298437426, 0.05853815725253475, 0.034314824808989806, 43.41106330194781, 82.40528675817674, 72.85142067940005, 64.72687805852583, 40.32820586235293, 30.322470972614905, 21.473119451153664, 50.93634228552542, 53.382355859202725, 75.4371569233556, 10.896969956736411, 0.49445796757936483, 0.11434494292423611, 0.05951968442288138, 0.027601994694240635, 0.08700025418112356, 0.0782478911682002, 0.20184676253026534, 0.20695086929105944, 0.12382033972009537, 0.1591260532938665, 0.20279426007501541, 0.26828181539331714, 0.6689462594447598, 8.148667648915323, 82.44454183886128, 73.03750576511507, 60.892671000572946, 32.17202344248372, 29.921100716437067, 67.04739539853989, 71.37403641977619, 76.6216185785109, 82.11274854598507, 60.14396505971109, 1.7595388548028086, 0.4359186458731852, 1.1613283738974602, 1.7711805720483105, 42.213132227620775, 81.09767836909141, 73.56795926247874, 73.15299603246874, 65.74428989041236, 72.4303150177002, 69.56465490402715, 71.8470742625575, 72.62503716253465, 63.26932138012302, 66.9783224598054, 68.54909835323211, 65.68528175354004, 64.1904390242792, 66.92809258737873, 63.2292700582935, 59.626749561678984, 59.984791355748335, 57.71398221292804, 54.513834138070386, 54.23256881775395, 49.48231574027769, 48.99719307499547, 49.270382235127116, 48.29565755782589, 48.73727721552695, 48.136566223636756, 47.420627763194425, 49.43666327384211, 50.51902563341203, 48.25809301868562, 48.53646362981489, 49.92411582700668, 49.95237650409822, 49.03582842119279, 49.219893486269065, 48.479620641277684, 46.708745033510276, 45.965848122873616, 48.05587914682204, 47.6556287273284, 47.644724538249356, 47.69282456367247, 49.07962952890704, 50.56059883486841, 52.86202992162397, 46.77900645040697, 45.67424343478295, 46.70221036480319, 42.54692592928487, 45.380002913936494, 45.13219541118991, 46.29488006714852, 47.058212526382945, 44.892597429213986, 44.35592697512719, 46.1128193332303, 44.913080046253825, 47.1879723764235, 47.05053644795572, 47.48750809700259, 50.387849807739265, 50.77317560872724, 53.97252744243991, 54.89391965250815, 49.37439172498642, 52.12387515652565, 48.67032235668552, 47.14748567150485, 53.809929509316724, 50.773261900871034, 50.980582698698974, 45.64784980589344, 45.27824094218593, 42.69163393205212, 43.79965251491916, 44.399630023587136, 44.07652870301278, 43.84095899520382, 45.27439701941706, 46.53830628241263, 45.81348365353, 48.14445018768311, 44.091865170386534, 44.91415869805121, 42.50742766164964, 43.508561657321074, 46.831656425229966, 48.48786154100972, 48.26706740163988, 47.67359710508778, 48.95222702334004, 47.68096331627139, 46.31339365436185, 45.77887658149966, 50.06565847704488, 47.13793077776509, 48.10834869261711, 46.96806077034243, 49.63958317233671, 49.07913531026533, 47.95052036162346, 48.42145189162224, 45.63876167420418, 46.959109921609205, 51.07789670267413, 49.82586045419016, 47.931759665089274, 47.986225697302054, 48.33530487552766, 46.68417530675089, 49.538272273155954, 49.590718284729995, 49.103905077903505, 47.329985710882376, 48.39776077578145, 49.56390888460221, 50.99567990149222, 53.14533879680019, 57.86002382155388, 62.17336016316568, 66.22920467007545, 65.04178162544005, 70.1917242234753, 67.01131743769493, 75.0403856462048, 71.56602075023036, 74.9136774001583, 70.35882503755631, 77.32633513789024, 72.04090210699266, 91.11792995083718, 21.349288263628562, 1.4770697345656734, 3.230096842012098, 0.2775647785634764, 0.24631902455322205, 48.82830366011589, 89.41245202095278, 78.77729046729304, 70.79357270271548, 61.23357203698928, 43.56795026410011, 27.654761114428123, 64.0425499793022, 61.21736872580744, 88.92385021332773, 16.85364015640751, 0.8252289314423839, 0.28720323717401874, 0.15229106279871157, 0.19212912107186933, 0.2646337659849275, 0.22426654013895223], [0.05489504528081706, 0.02926346894744183, 0.06494993013480017, 0.0377120110656946, 0.05451075259536024, 0.1138928208139635, 0.41007362786800633, 7.552006013931767, 70.69454070060485, 56.33343342811831, 42.096731970387125, 13.782703780358839, 28.651721708236206, 34.75252920581449, 51.35012095974338, 72.30147300227996, 63.935257465608665, 50.72960592085316, 0.6286269907028444, 0.0845053816033948, 0.27129496177358015, 0.6596335720631384, 38.53717319426998, 68.56183036681145, 67.99373780527424, 70.38418708309051, 67.18827124564879, 70.59943106866652, 70.32240190813619, 67.3215376946234, 60.40356320719565, 65.70545450333627, 65.49630195863786, 64.01564644229028, 61.49903020551128, 60.64129021859939, 57.84973544459189, 55.04396600107993, 51.81373334700062, 50.87037978633758, 49.27710125523229, 48.905833228941894, 43.90434057481828, 44.239161937467514, 44.04275709582914, 41.95328304844518, 41.95385179212017, 43.45149901605422, 47.45010829740956, 44.06302006013932, 45.349369202890706, 43.68215007166709, 43.68927701827019, 45.23300816935878, 43.86698784366731, 41.77242255979969, 42.02460742765858, 46.50392670785227, 44.78781131006057, 43.5036273156443, 42.70334220701649, 44.62670779997303, 40.91174079525856, 39.962068296247914, 44.94545921202629, 43.4357467774422, 46.05825916413338, 46.40330614582185, 43.55890135611258, 43.88053571024249, 44.35731941653837, 42.36626548151816, 42.571730998254594, 39.25912464818647, 41.423417906607355, 41.49265558488908, 41.04621925661641, 40.483268922375096, 43.07220582039126, 39.512403857323434, 39.96374707068167, 39.27187627361667, 39.301654907964895, 42.381323460609686, 42.63219825683102, 44.52022721690517, 42.77287406306113, 40.98711698285995, 46.49882370425809, 42.84996824879801, 41.07575862638412, 45.76140634475216, 42.3103520947118, 42.04822009609592, 40.617017822880904, 39.94845767174998, 39.50428455106674, 41.96767422460741, 39.68333290469262, 41.1488990629873, 40.35633710122878, 41.555970484210604, 41.39081516573506, 42.269861467422984, 39.88874350824664, 40.8817542752912, 42.44495999428534, 43.29085834564702, 44.08976277997417, 43.70931248511038, 43.42570550980107, 44.96132912174348, 43.46199920100551, 42.03018896041378, 42.6066832388601, 43.11674041132773, 43.07210383876678, 43.16127892463438, 41.61741049058976, 42.7535956136642, 42.1549674003355, 43.94426245843211, 43.034566756217714, 43.4540093329645, 42.89285936663228, 46.150795721238666, 44.225680751185266, 43.5768069759492, 42.774576371715916, 44.86180290099114, 43.32304531528104, 42.63969782860049, 42.62714624404908, 43.13673273209603, 43.59414777448101, 44.90268184292702, 44.41983415234474, 47.00770024330386, 45.46260802976547, 48.263733386993415, 50.99344415049399, 55.23153374272009, 55.834649147525916, 62.43051859640307, 62.96171734409948, 67.76214538082, 63.603762272865545, 71.11214760811099, 65.76312903435, 72.7237553750315, 64.2633637305229, 76.41898109066871, 68.50363023819463, 81.26116275787354, 18.111181451428322, 0.3423409446352913, 0.9850395915489044, 0.10265847848307702, 0.0544969285387666, 27.391428870539514, 75.9584556087371, 69.85468279930853, 59.11573533088931, 86.62352915733092, 83.96932401964742, 13.026445315730188, 41.15960713355772, 45.76289292304747, 68.3939136997346, 22.279980413375363, 0.12023705538482436, 0.03311067631828689, 0.04929476252366458, 0.01845216802922228, 0.028372667654747927, 0.037762297077044364, 0.03033699753183511, 0.056538702244119304, 0.10952088726504196, 0.035906602298059774, 0.14300220075153536, 0.12945079485014563, 0.4425152451280625, 11.000354809145774, 82.26396376086821, 62.66374272684898, 49.888414413698264, 23.579871539146673, 26.51022526525682, 38.46600963223366, 60.80812823387885, 77.40716734240132, 73.76244606510286, 57.2747395115514, 0.7458303532292767, 0.08451128048041175, 0.3071533311759272, 0.8851679570732579, 41.05951609150056, 70.90574464490338, 71.08753865764987, 73.03991410040086, 70.17241047274682, 71.9954732156569, 70.58454959623276, 70.09994076144311, 62.53062925031109, 66.39217915073519, 67.61897102479013, 67.6379160727224, 63.830267383206284, 62.89155790882727, 60.308481031848544, 57.05423170520414, 56.62138638957855, 54.96014887286771, 50.601097306897564, 50.76107509674565, 46.65672263791485, 47.02670412678873, 47.01948304330149, 44.67010882592971, 44.2488266575721, 46.36567492638865, 47.27744164005403, 47.4804360635819, 47.09211749415244, 46.32042646408082, 45.22969768893334, 46.48858631810835, 46.36370589656215, 44.709822823924405, 45.705575327719416, 47.472665848270545, 47.71204809988699, 44.29769938991916, 44.45728102037984, 45.543287261839836, 43.940002764424975, 41.666342058489406, 47.06250359935146, 45.11090870826475, 48.060888013532086, 46.86430623454433, 45.73078440081689, 45.93322969252064, 45.4965522212367, 43.056532029182684, 45.57778058513519, 42.39252967219199, 43.778534473911414, 42.653755603298066, 42.0609599544156, 42.61857194285239, 42.76198164109261, 43.8782960368741, 41.96487365230438, 42.182294553326024, 42.67638375682216, 43.23002238427439, 44.302363088054044, 46.52119298135081, 44.674572483185806, 44.51154308934366, 48.01079934643161, 46.1171260956795, 43.11594809255293, 47.78725170320081, 45.20912485737955, 44.666519857222035, 42.45000416232694, 42.69506992832307, 41.75002190374559, 41.367277022330995, 41.8701837139745, 43.62602487687142, 41.160952506526826, 43.49806539473995, 44.73897780141523, 46.41259039601972, 42.43576203623126, 42.62281202500866, 43.21881225032192, 44.873570011508086, 44.83915905798636, 45.28038255630001, 43.661667454627256, 45.69287861547163, 45.57385821496287, 43.6389490865892, 44.16119306318222, 43.91702944232572, 45.47918396611368, 43.95625314404888, 43.81978996338383, 44.538670201455396, 44.73527508397257, 46.23953542401714, 43.67385818112282, 45.070414158605764, 44.125879964520855, 46.76920052497618, 45.840249907585886, 45.6998957357099, 45.898461803313225, 47.895587567360174, 45.48173350672568, 45.777335090021936, 45.014022242638376, 45.60124028113581, 45.22606165178361, 45.94783267667217, 47.98414291874055, 47.68650562532487, 48.62963561088809, 51.62905639217746, 53.5231650260187, 59.37953433682842, 58.998785941831535, 63.991861189565356, 66.0861401404104, 71.07308864593506, 64.71903724055137, 71.79026265298167, 69.60340007658928, 76.74187060325377, 68.36462928402808, 78.84877174131333, 69.90805841261341, 83.61969963196786, 20.26510984666886, 0.6498782697223848, 1.4683762913750065, 0.08566719224496235, 0.03298222252558316, 28.809567689895633, 82.79508406116118, 73.61582786806169, 68.13944601243543, 77.15320956322455, 69.64332980494346, 17.30615027489201, 49.27533226628458, 53.64364062586139, 79.98837717117803, 29.04568260715854, 0.08882470023367675, 0.030638303742894245, 0.023274861967131015, 0.054393353451403885, 0.041228829612655025, 0.04953645177245621, 0.12503804413661843, 0.1296257540102928, 0.266585911233579, 0.19812015846611994, 0.301963116132444, 0.33834567353610073, 0.6477182694981176, 18.053479463823383, 94.42707677041331, 68.43927198840727, 60.48375606536866, 28.124925821058213, 43.838593805989916, 46.53125778321297, 66.18627040616929, 83.2043206307196, 76.47182326163016, 64.95626611094322, 1.111913128725944, 0.22097449178897569, 1.162303940903756, 1.4730117974742767, 39.391081025523526, 73.73827642010104, 74.09817741763207, 75.18703522220736, 71.06152549866708, 75.31517905573692, 73.78700794712191, 72.46769520544237, 65.38829949594313, 67.21839504857218, 69.39480843082552, 69.16891913260184, 67.83548585830196, 66.26700847379624, 63.963055303019864, 59.87274885177613, 59.78626843421691, 56.59609494670745, 54.519827519693685, 54.42880107510475, 48.07725998663133, 48.88539768034413, 49.15559799440446, 45.913229527012, 46.93164548566265, 48.828491933884166, 50.047890140164284, 49.63192670576034, 48.554192742993756, 49.07975112238238, 49.433493998742875, 49.26099208093459, 48.8781177613043, 46.19427127222861, 46.39688914821994, 50.61447651155534, 50.534668045659224, 46.83294296264649, 46.526013574292584, 49.39696888769827, 45.96039995070427, 43.0871618178583, 49.218218634205485, 47.678402008548865, 49.75859572810512, 47.88596991569766, 48.72412158596901, 48.69467635308543, 46.2255992427949, 45.07850208590108, 46.78405061844857, 43.418531494755904, 46.48563277336859, 46.123452878767445, 46.10357822910432, 45.27051387294647, 46.457729031962735, 46.803164328298266, 44.7920710040677, 42.94274014811362, 45.806501834623276, 47.86121975991034, 46.53551747722011, 47.87819185564595, 48.19468006010979, 48.35958826926447, 52.47671981011668, 51.66742893957323, 47.56263717528313, 50.380471829445135, 49.2248042937248, 46.41956829255628, 45.18689678561303, 44.58983359798309, 45.30210071994413, 45.87992860424904, 45.01208066940308, 46.37493564236549, 45.95772881661692, 46.34249371867026, 45.89374711436611, 48.06632834096109, 43.31014856215447, 42.773450651476466, 44.36022197046588, 47.82132533288772, 48.44568821691698, 47.06925399841801, 45.56121249352732, 48.912038418554495, 47.84929183221633, 46.465432566981164, 45.54649183827062, 47.53672599792481, 47.76978538882348, 48.15549165971818, 48.27366875063989, 48.124304894478094, 46.428044534498646, 47.978628066278276, 46.86046623414563, 48.77630872111167, 47.09096039495161, 50.23590895437425, 50.97766445529077, 49.180995341270204, 47.29066787227508, 49.78751928575578, 48.08776801632297, 48.07339645201161, 49.26663244924238, 47.72654518004387, 47.90109849745228, 48.98546126581008, 50.758121552005896, 52.99315867885467, 51.39842887078562, 55.14464147629277, 57.213052395851385, 62.238193019743896, 61.094112165512584, 68.21146857353949, 69.70953156871181, 73.94704849489274, 67.63721789083174, 74.77159346303633, 70.58804835042646, 81.78960015696865, 70.14296131749308, 81.91550823949999, 70.41036498162055, 87.5278865137408, 21.574448001000192, 0.7901821862305365, 4.042575618913097, 0.26380829092475677, 0.1694428061525668, 33.16702481239073, 89.60169853702669, 78.65346908569336, 77.96732102670978, 100.45704626267957, 93.43219895516673, 25.119666591767345, 61.84348098693356, 64.13324694479665, 91.95241420499741, 40.74421244282877, 0.24746588881938691, 0.16151397999736572, 0.15827155882312408, 0.23463659739542395, 0.12096549008762646, 0.19353319169773212], [0.06857297443334134, 0.041205199630630594, 0.02708269241866806, 0.04234297043313423, 0.01889608342260603, 0.054645281465303515, 0.2510084785641201, 17.387084461027577, 73.57302696474137, 55.682645536238155, 41.94795254738101, 20.845685351279474, 55.215408878941695, 59.43272167636503, 51.368473729779645, 68.93043902612501, 66.90658230935374, 47.84526748041953, 0.1167959186639036, 0.09445513238108928, 0.33908877882265276, 1.261963154519758, 26.188081003004505, 71.74462979839694, 62.96414921360632, 69.1344807224889, 67.40350738648446, 67.82032197521579, 63.98037256733064, 62.839755165961485, 65.452897010311, 66.98418248084285, 62.38133207444222, 61.75625531904159, 59.05316175953035, 55.78866720199586, 55.27018870076826, 52.24518229884487, 51.36154682405534, 50.88726166755923, 45.72945863969865, 47.54975218926707, 46.98082808525332, 45.21329825924289, 43.50844790858608, 50.42159003596152, 49.82962985192576, 49.143175848068736, 50.045783827381754, 51.821860497997655, 52.465368470837994, 53.4291575800988, 47.18622692169682, 42.08871464575491, 44.52593818787606, 43.7497325097361, 42.9562880146888, 43.43986526612313, 43.324680943642896, 42.55064041383805, 43.25041478680026, 39.74583587338848, 40.73490858078003, 43.26605327667729, 43.81627944207961, 44.67492157413114, 49.61065569231587, 49.65753193824522, 45.539792430016306, 42.346539881921586, 41.00943526914043, 42.629672250440045, 45.38446657119259, 42.66833113085839, 41.73228102345621, 42.46059063942202, 39.95052083846062, 41.81644332024359, 41.63606920549947, 38.290656151310095, 40.42645731279927, 40.371379390839614, 38.98950876728181, 40.74643642671647, 41.137547723708614, 42.9665607021701, 41.055264242233775, 40.219465994065814, 44.37213028630903, 40.86791615332327, 39.65581747793382, 42.8610920906067, 43.11670118762601, 41.751241760869185, 39.5078892092551, 40.088984427913545, 40.061206202353205, 40.04107267625871, 40.183348809519124, 40.888057524158114, 40.03589514763125, 40.608620028341974, 40.99476952706614, 43.30718717267437, 40.97252184344877, 41.96099442820395, 42.323366518943544, 41.74768809349307, 39.768699369122906, 40.42404897751347, 41.521971379556966, 45.12455071172407, 42.554880495994325, 43.99978753059141, 45.00501255835257, 41.91852692634829, 42.76112264202487, 41.05990440614762, 40.51909585152903, 42.020641911414366, 43.37654644443143, 44.55907437109178, 43.63625834065099, 44.31939009697207, 42.61351208533011, 43.70047146274198, 43.654038444642104, 44.422058136232444, 43.82246109747118, 43.90812958440473, 42.59509263500091, 43.9994070606847, 41.86578281464116, 43.93356223260203, 42.351823314543694, 44.04920547239242, 43.38702309516169, 43.57375144958497, 45.32794913937969, 52.380680576447524, 54.46147049626997, 58.49383961769843, 58.98919574676022, 62.073802563451956, 61.95518616707095, 66.44638630651659, 64.81039708660495, 67.53021563253095, 63.60257771707351, 71.55579120882096, 66.16078284478957, 70.94638039988857, 68.33264627764302, 82.970625815853, 18.532769564659365, 0.6050140158303323, 1.9323197511896013, 0.24824757429380573, 0.2723642060112569, 16.834546058408677, 76.22488652506183, 66.42519766284575, 64.78852202815395, 51.570087479006865, 41.6171359246777, 15.226616494117247, 32.97340877594487, 42.297031725606615, 65.6502353760504, 33.26249138001473, 0.1629728871968485, 0.12032078879494822, 0.03662878955383936, 0.04155111131108096, 0.05285617121825776, 0.08723027208038876, 0.035129678060090354, 0.045002463814472, 0.10875628555133458, 0.01460459772422309, 0.06143819841165697, 0.07230592170549978, 0.2577829481132569, 21.30668544000195, 84.02158567982336, 61.05559056805026, 51.2205768400623, 28.54350155399692, 57.58685819564327, 60.45882940292359, 57.69855553104032, 74.98974000253986, 73.4662208249492, 52.44747069574172, 0.10036377701908351, 0.13760883451229142, 0.3779817144236257, 0.9159567856019544, 30.091866985444103, 71.53519092067596, 62.980489807744185, 72.1196162316107, 68.85880085729784, 70.51909308279716, 64.3504991839009, 65.26636869676652, 67.4001027691749, 68.8946670101535, 64.56894382353752, 63.65258793677054, 61.45279330592002, 59.02750553623323, 57.43829842536681, 53.66906542931834, 52.06910317943942, 53.16705303807413, 49.59959068605977, 50.17356680285547, 47.459565131895005, 46.62341779278171, 46.63728729371102, 52.594814531264774, 50.65143700568907, 53.24344904192033, 51.91252216216057, 54.58280117281022, 53.286512744042184, 55.604190288051484, 46.92957447421166, 45.54985330950829, 45.039960876587905, 47.543676437870154, 45.51121011857064, 45.889173630745184, 45.97367717373756, 43.78741864235171, 44.082200450281945, 43.3045474175484, 45.02102367339596, 45.08019262744535, 46.06702958383868, 47.77501783063335, 52.22466045810331, 50.52714493966872, 46.665140044304636, 43.832482753261445, 42.46027292743806, 45.958697642049486, 48.110521685692575, 44.66165611820836, 43.00985190176195, 43.42871396772323, 41.76665275327621, 42.98301896741314, 43.24986565497614, 42.253054111234604, 42.140019247608805, 42.85334933188654, 42.03976738837458, 42.68192998824581, 42.58436103020945, 45.0604905620698, 43.66991227672946, 42.31845963385798, 46.61753031515306, 43.741236655942856, 44.10973156652143, 44.78949792923466, 45.85829673274871, 44.29145889897501, 41.842935008387414, 40.83392881578015, 41.51671932589623, 42.39263949855682, 42.985945055561686, 43.669924043839984, 41.50670551484631, 41.198783766838815, 44.13931408236104, 44.67242302433137, 41.86379417296379, 43.7372358383671, 42.93527587767571, 42.53493916603827, 42.343115652761156, 41.10759258270264, 43.403697090764204, 46.942616355034616, 44.9026975324077, 45.81628030346286, 45.42204679981355, 45.062765536769746, 44.18175020525533, 44.73265494069746, 42.849438728824744, 45.29595044351394, 46.120742520978375, 45.648045924402055, 45.41910109981414, 46.41723840467392, 44.59223016615837, 47.48915549247496, 45.19348636750252, 45.848271154588275, 44.68406854137298, 46.6077910700152, 44.89053426250335, 46.43354761985041, 43.326893160420084, 46.66628537639495, 45.51357530778455, 46.542569898789935, 45.919568077210464, 47.66987477579425, 47.585343776210664, 55.72909816618889, 56.373931900147475, 60.348214641694106, 60.79945979579803, 63.55145354424754, 65.24804338332146, 69.24752343085505, 65.50027139725225, 69.19466557041292, 64.56421736747988, 73.52553490669497, 69.10012860451975, 73.15998569611581, 71.07508905472295, 84.0932866065733, 20.111980515141642, 0.507470798348227, 3.955743904075315, 0.30582677332624314, 0.2816020925679515, 18.04249486615581, 81.8430228387156, 71.95734777758199, 71.01847356365573, 57.864703209169456, 48.14097889008061, 22.966565816633164, 43.277687026608376, 48.94308790083855, 76.60628211113715, 42.70019646613829, 0.3383235182733305, 0.03852542024105787, 0.027856088821746172, 0.044491253342599645, 0.04804833747086026, 0.010743562466344767, 0.17046283690198777, 0.26478903668542064, 0.22932710246213023, 0.3547572380592746, 0.2795222251405639, 0.1788832923217166, 0.5066049657762051, 28.301238321488906, 95.41156030470326, 68.47727975537701, 60.40654813089679, 32.379118704026745, 67.5538989036314, 72.74566573481407, 65.20607402247768, 80.4189435897335, 80.71654165944746, 55.751745931563846, 0.2943393155451744, 0.591739489426536, 1.0639706109800646, 2.492536315994878, 33.09362157698601, 68.25313198950984, 67.38805324800553, 74.02578615373181, 72.27494209043442, 71.67099122078189, 68.28730367845105, 67.96685388011318, 68.99427952304964, 71.23385875455796, 67.27771697505828, 66.12553642642114, 64.27313435462214, 60.42680325046663, 61.263797821537146, 55.32329367053125, 57.31744627798758, 56.32059943291449, 51.823621642205026, 52.872004508972175, 51.950828029263405, 51.19075113727201, 49.04990580774123, 57.14170840478713, 55.186242134340354, 54.675125921926195, 54.37330345953665, 56.192247713765795, 57.43842001884215, 59.57068712480607, 51.22471101822392, 46.092893692754934, 48.97384712772985, 49.430462006599676, 48.06243342737998, 49.26277283699282, 47.47696084360923, 46.485452344340665, 48.022452708213564, 44.42028914728473, 45.070469071788175, 48.327295395635794, 48.173024654388435, 48.99842862159976, 55.01323030840967, 51.48430132096814, 49.01543209629674, 44.71154082205988, 44.24398253040929, 47.27478619544737, 51.81881673874394, 48.55595388720113, 46.23431867168796, 47.47782376504714, 45.227477627415816, 45.995481629525464, 46.28560758406117, 44.12420511245728, 44.68795168784357, 45.26857622208134, 42.79081106185914, 45.2989314448449, 45.211129188537605, 46.88891518500544, 46.486840863381666, 45.187100748861994, 50.30558593811528, 48.63334225070093, 46.851229052389826, 47.066167093092396, 47.65421275169619, 46.740841788630334, 42.85575766717234, 43.093543514128655, 45.78032393609324, 44.98680883838285, 45.76318710081039, 46.87335906490203, 43.434864244153424, 44.1486571681115, 45.87897546829716, 45.74420282917638, 43.42354036146595, 46.33973237006895, 43.08354539255942, 44.664468457621915, 43.64693503226004, 41.35562758291922, 46.56850461036929, 49.974396690245605, 47.470700740814216, 47.502507240541526, 49.11679006391957, 48.23563352707894, 48.144003037483465, 47.05754572345365, 43.88996508813674, 46.79633155945809, 47.70141063197967, 47.9394632001077, 47.494756637081025, 47.61476939724338, 46.23531103134156, 50.047121355610514, 48.397395995355424, 48.51900123780774, 47.75837129162204, 47.772174112258426, 47.37377897385628, 49.55220060963785, 45.844886149129565, 48.878788486603774, 47.56628497954338, 50.10850644880726, 49.49408285079464, 49.95825221461635, 51.06427823343585, 57.23107176442301, 58.51411042674896, 63.5876452538275, 64.0200355745131, 65.15466743899931, 67.29852122645225, 72.76795264213317, 69.68655432424238, 71.50093293959095, 66.98167216393256, 76.5708552637408, 71.02264696551909, 78.06456442802184, 73.61875395621024, 86.60686692883893, 23.341356131338305, 1.3126289003318357, 8.24603509518408, 0.6576876474484321, 0.4630345731012283, 20.93151857776027, 88.91921397178405, 76.9875600261073, 77.6298402970837, 64.9482213297198, 54.795181828160445, 26.1499261471533, 53.21402734325778, 58.16963218873548, 87.73027296989196, 52.94052439351236, 0.5797303564125492, 0.1675093074839923, 0.18928889605787494, 0.13852714410712644, 0.20427694664366786, 0.20584909696011774], [0.03955413459710056, 0.07453751284629107, 0.013561527838089294, 0.04634787508797261, 0.06990537753388767, 0.0564908447314895, 0.21753167733550074, 22.679632671417732, 71.4444508091096, 54.996532778586115, 44.193697744800204, 18.53103195467303, 25.985823985069032, 41.539174895132746, 59.04452862278108, 68.13573545025241, 66.59617377865699, 45.521019966371604, 0.22519102440245692, 0.1188720016169452, 0.15375939287966298, 1.0038656813483084, 15.96591364952826, 51.88581474365727, 69.33390186678979, 62.11592881910263, 64.0619460998043, 66.16423453054121, 63.935932113278305, 66.54781095443234, 65.40138452283799, 62.49658699958556, 61.33280015760853, 56.93194397034184, 55.99103404629616, 54.287685963415335, 51.829917046331595, 53.85986128161031, 51.896577727410104, 51.501787247196326, 48.1436578689083, 49.29640323885026, 47.24727861342892, 51.26275800889539, 53.85533878880163, 54.612446446572584, 56.14499884267008, 54.067131088626006, 55.575058844781694, 56.07097587277813, 56.97963999163721, 56.53069334645426, 50.73048453177176, 43.870941592801, 43.93282482700963, 41.738784313201904, 44.409632067526545, 43.18139283887802, 41.37196033231674, 42.010145648833245, 43.79412197297619, 42.12988776545371, 40.269656642790764, 41.24993931862616, 41.18344337709489, 42.14862100539669, 47.377783713802216, 52.669747491036695, 45.10563704275316, 40.82708427982946, 42.144333854798354, 39.522994256788685, 40.07957466187016, 40.99678562533471, 41.587631856241536, 43.09811699774958, 40.20327052762432, 40.32487184770646, 38.747843696225075, 38.645238414887466, 39.375697489707704, 40.66890685789047, 38.95914962214809, 39.65140481148997, 38.97132858153313, 42.152555142679525, 43.18775100092734, 40.33039454490908, 40.94866206569057, 41.58186204971806, 42.97047522760207, 42.425858051546165, 41.58055982282085, 40.956749992985884, 38.47299929588072, 38.764686353745, 38.32537304970526, 41.49742126464844, 40.804958189687426, 40.08266548956595, 40.53264371810421, 41.99922184790335, 43.15421865832421, 44.03260992419335, 44.323720393642304, 44.328388014147365, 42.9071956296121, 40.45944444594845, 39.66944379191245, 39.82018440000473, 40.82684893761912, 43.05346081333776, 41.87476896470593, 43.55668913933539, 42.15247669527608, 42.33432169883482, 41.813517232095045, 40.88038144573089, 41.049957275390625, 42.07154643151068, 42.41409878576956, 44.38975741786342, 44.35146724024127, 42.481485105329945, 40.81905518808673, 43.875040469631074, 43.81504389547533, 43.041983958213564, 41.85908732875701, 41.66280408059397, 42.52150504819809, 41.899911357510476, 41.003265380859375, 44.19826730605095, 43.62148277221188, 43.17223018215549, 42.58268617814587, 45.509911814043605, 44.95204487154561, 48.4727604158463, 52.002458187841604, 55.43017433535669, 56.54085620757073, 61.37534610686764, 60.509914352047836, 67.41103049247496, 64.97597209868893, 68.60798881899926, 66.35926262024911, 70.63935295228036, 67.6073843433011, 73.66489671891736, 60.95477388751123, 75.41286176250827, 21.364432534863873, 0.4965352303078098, 0.8157798804102406, 0.22913104524054836, 0.337187992108445, 11.029468601749791, 75.34613440113684, 66.79409657755207, 70.40823905698716, 56.03206988303892, 42.020551696900405, 9.492259371665217, 26.73024081414746, 46.75680191286149, 66.7083300313642, 38.10973290474185, 0.9685248809476054, 0.048177940395450404, 0.09683840127000887, 0.03642104183053298, 0.017575725139449203, 0.04027603840034816, 0.1481342084345318, 0.06280226392611381, 0.04965455954774253, 0.05545746873042757, 0.02244204012376647, 0.12040783170490496, 0.23552032578135693, 29.161090504738596, 84.00667282842821, 60.833909973021484, 53.205143174817486, 27.427130283847934, 39.374748276126006, 49.66826354303668, 62.678569286100334, 73.55228547127017, 72.41500208454748, 50.69655602978122, 0.27235997720591487, 0.15746823902572357, 0.3766440636207981, 1.380918223050333, 19.548063316652854, 60.85512215091337, 70.54089361621489, 63.530237443985484, 67.32287130048199, 69.14624783300584, 65.21804117387342, 67.95841293950235, 68.13762603267547, 64.86947582614037, 64.96972376300444, 60.055448932032434, 58.20512179405459, 57.021452457674094, 54.28949809843495, 55.28908275788831, 53.195819700917895, 53.812620255254934, 51.67584634596302, 50.41177626579039, 50.16716549473424, 53.23497279997795, 56.63585601314422, 56.32680070015692, 58.33439919256396, 58.57673498892016, 58.79878036437496, 59.593307433589814, 58.36671952278384, 58.970795908281886, 53.556838573948035, 44.94469434984269, 45.3629288365764, 45.33883763897804, 46.30771798472251, 44.13508184494511, 43.447396216853974, 44.30153546794769, 44.64733162233907, 43.19034368761125, 43.73331346819478, 43.47376631152245, 42.7204555080783, 42.010835985983576, 48.21122069512644, 52.298954071537146, 45.179809062711655, 42.08719276612805, 44.147860926966516, 41.240839419826386, 42.637728798773985, 44.93208000736852, 45.706524541301114, 44.91489218127343, 41.7955723885567, 42.01267949996456, 41.06223821640015, 42.290940284729004, 41.7878649311681, 43.26012265297675, 41.502257547070904, 40.695657422465665, 40.65086787746799, 43.55877584026706, 44.946290754502826, 42.73496043297553, 43.37484413577665, 42.66320851541335, 46.20379086463682, 43.51142498754686, 42.53419391570553, 42.01350712007092, 41.6289383365262, 41.134158795879735, 40.84835137090376, 43.02100320016184, 41.74383632598385, 42.902994771157545, 43.88361869319793, 41.24399300544493, 44.9995526190727, 45.905965297452866, 45.036269926255756, 46.032759835643155, 44.40945556086879, 40.662172148304606, 40.797815553603634, 41.33792592633156, 43.0154138226663, 45.84785930572018, 45.24728951915618, 45.746830817191835, 43.74018938310685, 44.735510426182906, 43.20613122755482, 42.49404845699188, 44.09476380194388, 45.471939348405414, 45.08679397644536, 46.729306097953554, 45.98420481528006, 45.39958730820687, 43.16418540093207, 46.413319956871774, 45.528562684212964, 45.10558212957075, 43.789360215587, 44.55493627055999, 43.95247982394311, 44.621859750440045, 43.707488582980254, 46.83004433108915, 44.835009190344046, 44.748152225248276, 46.53026542355938, 47.81855613954606, 48.49797341131395, 51.364351318728545, 55.03615656206685, 56.5578047690853, 57.557762053705034, 64.86263129018968, 63.21419246735112, 69.11439818720665, 65.63020383158039, 70.52724376801523, 68.95973913131222, 73.15765580823346, 69.0799754665744, 76.06267298421552, 61.83473410144929, 75.36049812070786, 22.586427350198072, 0.27356484964970623, 2.304119871508691, 0.42062967595073486, 0.3486456031039838, 11.585920549208119, 83.36311386477563, 70.67076329262026, 76.30380461292883, 58.99945274476082, 44.56103555617794, 14.945323717209602, 34.181914560256466, 55.6731180990896, 73.87996812020579, 48.094616474643836, 1.0480467686730048, 0.02701145964824865, 0.05571670139268522, 0.0913979436060594, 0.027649683667527094, 0.025079225024749196, 0.22657093261518788, 0.1588650931033396, 0.2874171902095118, 0.1304493138506528, 0.1382750552147627, 0.17059783691600447, 0.46942622851460214, 36.66523771901285, 94.42736702580606, 66.94903804409888, 61.47940658753919, 30.595154146994318, 34.85895095332977, 55.34148562339045, 72.90448250309115, 77.75051593780518, 81.73960562675231, 55.12893630612282, 0.45607864796634645, 0.27655865997076035, 0.7536592202321176, 2.6364073830266155, 23.180274194286717, 59.15571605005572, 69.55728084810319, 64.99748629908409, 68.92027224263838, 70.09795604213592, 68.27886273784023, 69.58814205661898, 70.74799476131317, 68.1995367234753, 68.20185876661732, 60.31394881586875, 62.27755792679326, 59.269582456158055, 56.92968860749276, 60.802228989139685, 57.60287323305684, 56.65580126547045, 53.873522896920484, 54.272726043578125, 51.96540747919391, 55.92407134271438, 57.57733075849472, 59.94208066694198, 61.74723779001544, 59.915408549770234, 60.282185462213334, 62.66344462671588, 60.9495492904417, 61.043431220516084, 55.96338133658133, 47.74236409894882, 48.07576556359568, 47.10278241865097, 48.30141167486868, 45.935665484397646, 47.29355081435173, 45.915947729541415, 48.24527863533267, 46.02284016147737, 45.71157263171288, 47.527575108312796, 43.797467754733184, 45.041392541700795, 51.70184381546513, 55.2684550131521, 45.17614949134089, 42.48836494261219, 45.25119619984781, 42.7717875665234, 43.8147928637843, 47.543978460373424, 46.981251701231926, 49.1027009102606, 45.46743646744759, 44.09791346519224, 44.283159163690385, 44.69292525322207, 44.966404668746456, 45.78796471318891, 44.323539964614376, 44.70430012672178, 42.96709806688371, 47.09907577883813, 48.35166900388656, 45.34602734350389, 46.194565449991536, 46.88709520524549, 49.1733310299535, 45.943635740587794, 47.54680256689749, 45.029213582315755, 43.88827846896264, 43.97358217547017, 44.64591564670686, 46.990449659286014, 45.06415405581075, 44.46958157324022, 46.19592651244133, 44.519238779621745, 47.17074532662669, 48.002911460015085, 48.895901787665586, 48.48627690346011, 45.91644194818313, 40.38584901440529, 40.26744834838375, 42.345096449698175, 43.53292349846133, 45.41553958769768, 49.01115279043875, 48.874634696591286, 46.46093360839352, 47.70708237924884, 47.02102061240904, 44.07947832538236, 46.09773389754757, 46.904518373550914, 47.11685588282924, 48.373430313602576, 50.568223922483384, 48.66825526760471, 45.96618544670844, 48.43307779681299, 49.25193925057688, 47.89676427841187, 47.2153034517842, 45.78916495846164, 46.63408663965041, 45.55334814133183, 45.31252245749197, 50.038652958408484, 48.7222663048775, 46.92953917288011, 49.143874029959406, 49.609455447043146, 50.95046674051593, 53.17680405032251, 56.91456002573813, 59.68867201958934, 60.99684915234966, 66.90422104251, 65.39645802590155, 73.6605115090647, 70.01144424561532, 74.01284233216317, 74.36937793608635, 76.27022127951346, 71.13830981716033, 77.76029048427459, 64.47992955484699, 77.40269584040489, 24.64217293647028, 0.6638579034516889, 5.126044577167881, 1.7850600014771185, 0.4057579481553647, 13.399556856001578, 89.19916137572258, 78.43136879705614, 82.77261672481414, 75.29516712311776, 53.95120151581303, 17.997934779813214, 43.18162425871819, 68.13687293760239, 86.04167692122921, 61.435146562514774, 2.0898145581445386, 0.21939607487330515, 0.17995943135071188, 0.20073903003527274, 0.13303947244440356, 0.11595412593094573], [0.06251356369184871, 0.03402048999804162, 0.05635972112236966, 0.06021327744688719, 0.1013125998959426, 0.027646927666219494, 0.3018128403252171, 22.643131094594157, 71.39752357236802, 53.72417865260955, 35.99296308332874, 24.669203950512795, 31.91969148574337, 40.91546704692226, 62.19266606915382, 64.62834419742708, 71.25399620302262, 39.71556694276872, 0.3182544661385398, 0.09660892729316989, 0.07221150136883221, 0.31121249400800277, 20.56249414720843, 45.06700561892602, 53.26851298732143, 66.66168520527502, 61.898817785324596, 65.93819618225098, 63.905890680128536, 64.51034361316313, 59.31506233830606, 60.02661951126591, 56.090485742015225, 55.49302639499788, 55.03247737884522, 55.45460285678987, 55.09610606778053, 56.25708057034401, 52.878586246121316, 52.60853105975736, 50.93732680043867, 51.14249029467183, 53.52194124652494, 58.95103500735376, 56.808440300726126, 62.474676639803, 61.52578861482682, 57.887064641521825, 58.01097623763546, 59.97847241740073, 57.269118755094475, 57.49590235371744, 51.78166404847176, 42.2908422254747, 43.52801661337576, 43.07258629029797, 40.77020598996071, 42.475064185357866, 43.888855057377974, 44.04031738158196, 41.92675213659964, 41.94340652035129, 41.83052855153238, 40.67857157799506, 40.07353028943462, 42.060810904349054, 44.56667200211556, 47.17599738028742, 43.90340705071726, 42.932412547449914, 46.166398909784135, 41.99400509557417, 39.303114029669, 43.40196340314804, 41.051259502287834, 41.92873293353666, 40.26631086103378, 38.51923227310181, 38.45894544355331, 38.030814816874845, 38.30436875743251, 42.33037579444147, 38.85729743588356, 40.75359475228095, 40.71693628065048, 40.29859588992211, 41.18258830039732, 41.469023304600874, 40.89241919978973, 40.65948924710674, 41.65327272107525, 40.59328356096822, 39.60590531749111, 39.64951422906692, 40.110000487296816, 39.996828340714984, 38.75527266533145, 39.95768700876544, 39.99888758505545, 40.15241307597007, 40.55848429279943, 40.615695984132834, 42.566969240865404, 41.10262686206449, 39.76600077844436, 43.616352312026486, 42.564098065899266, 40.12241478889219, 40.37048116807015, 41.03778616074593, 42.74297775760774, 43.512127091807706, 45.2039316392714, 41.831093372837195, 40.20794207049955, 41.01050999856765, 41.32486835602791, 39.83303408468924, 39.359470644304835, 41.431497989162324, 42.79794585320258, 43.276172991721864, 42.52913013581307, 42.11403746758738, 41.87427866843439, 41.918401410502774, 41.05269116740073, 43.78726959228516, 43.521827113243845, 43.84849779067501, 41.916404924085064, 42.80439815213604, 42.01067516880651, 41.372693815538966, 42.30288782427388, 41.71310063331358, 42.72641358837005, 43.2171570101092, 42.870956851590066, 45.064354096689534, 45.216232192131784, 49.58110063306747, 47.954505489718535, 53.13119865232899, 52.66893556041103, 59.57432316195581, 62.089648938948116, 65.15559704073014, 66.40242438162527, 69.81471384725263, 67.16961645310926, 75.26868327971428, 66.23616295476114, 75.19702942140641, 26.062508283122895, 0.12790221705912583, 1.0670151056781894, 0.26723978259871084, 0.13573919693308492, 5.407896782121351, 69.70534247736778, 67.00307261559271, 69.10573759386617, 54.480497913975874, 54.774036330561486, 26.72721274437443, 22.544491329500755, 34.853698899669034, 62.53942320423742, 50.93798968099779, 0.8307659698109474, 0.03854548408379478, 0.03148325084288034, 0.015669029972125447, 0.03791873606162206, 0.06493360480113376, 0.08823252958996643, 0.03496769642938049, 0.13653681703632878, 0.025046262176587217, 0.08252434717911868, 0.07676993902291983, 0.2331771386126357, 27.62239959932143, 82.14478646555256, 60.396765739687034, 44.99231584610478, 23.26327350831801, 25.815736286101806, 44.29625203532558, 69.91587961873701, 70.41315770918324, 77.83523913352721, 43.66571141827492, 0.17920256712503974, 0.10655838695745315, 0.4690073929246395, 0.5540889645776441, 22.19022677790734, 46.23267519858576, 59.62826751893567, 69.50897293706095, 63.42907559487128, 68.04241441911267, 67.5338085236088, 68.46430455484699, 62.57458725283223, 61.28752423870949, 57.80398884127217, 58.17811627541819, 57.14046893581268, 58.474353282682365, 55.62391196527789, 58.0297016328381, 55.5559882810039, 54.262637707494925, 54.10117726172171, 52.33169801773564, 56.628736911281464, 60.141180176888746, 60.17368485850673, 65.29899104948967, 62.267324463013686, 60.280918536647675, 59.01902929429085, 61.30081322885329, 60.37096831106371, 59.46932523481308, 54.71448298423521, 44.26985448406589, 45.65360392293623, 46.156753801530414, 43.41633104508923, 44.013147123398326, 44.31984509191206, 44.95827359537925, 44.61456021954937, 44.381159582445704, 44.16351118395406, 44.05834459489392, 42.85171762589486, 44.02517703271682, 46.66488509024344, 49.573495157303356, 45.36492924536429, 42.53999902356056, 46.688282028321304, 43.462673848675145, 41.25241433420489, 45.81161268295781, 43.807112862986905, 46.28809044438024, 42.27509390923285, 41.856125939276914, 42.014083708486254, 41.58993820990286, 41.37263890235655, 42.936919350777906, 41.51110641417965, 41.18497702383226, 41.108020121051425, 43.75735759735108, 43.3833517566804, 43.55592819952196, 43.44686277451054, 42.9816069141511, 44.91307220151348, 43.31664792952999, 42.704173749493016, 43.0926021452873, 42.91122390377907, 41.694477219735425, 41.27685854511876, 42.859707493935865, 41.043842300291985, 43.794757396944114, 41.82887331131966, 43.63885887207524, 44.33499328551754, 42.49752367696455, 42.47470332730202, 43.22522140318348, 43.161180865380075, 40.61656282794091, 41.25980800197971, 40.17033046291721, 44.18719837742467, 44.62033002607284, 46.85210766330842, 43.396707427117136, 42.6454205666819, 44.69076010488695, 43.982897804629424, 42.97764532027706, 42.88232388034944, 42.793599867051654, 46.501424235682336, 46.015874032051336, 45.0916616378292, 45.20252743074971, 44.584008878277196, 44.33710352067025, 44.217051536806174, 44.90836927967687, 44.821194602597146, 46.2677215760754, 44.14591935373122, 44.96769120616298, 43.55098601310484, 43.56745212308822, 43.657552888316495, 44.29240026781636, 43.830380362849084, 46.65950359836702, 46.26246167767433, 47.69611935461722, 48.28621249045096, 50.12767899420954, 49.422687868918146, 55.46865278674711, 54.99510111347322, 61.55328442973476, 63.723476932894805, 66.86006299911007, 69.75456037829, 71.98419247904133, 69.32571980261034, 77.51402055063556, 69.14635765937068, 77.3765806997976, 28.89063915898723, 0.14142451928027217, 2.3270115592787346, 1.2691263830469501, 0.19316773711433335, 5.47948690191392, 75.49538058619346, 71.72086023515271, 75.90765307026525, 60.96429347991944, 54.46134498042446, 24.67417359352112, 33.228217709449034, 44.833193132954264, 68.96742697684996, 60.64308274176813, 1.9603395702377444, 0.17157427726253388, 0.08926023654038868, 0.07973139745093162, 0.07796100656231565, 0.019324096745901534, 0.14009059166475651, 0.09189491250341938, 0.25418524600325093, 0.14289039787986588, 0.18104631093240556, 0.1936813990675634, 0.2921434624060508, 36.91146842895016, 93.22799251925562, 68.55034566694691, 54.00654223657424, 34.01455879211426, 41.484426452267556, 54.429059951536125, 75.71850853581583, 74.84201569711009, 85.46405300017327, 47.8727868295485, 0.5085606963163423, 0.24617218081989597, 0.913518971252826, 0.6299685638758444, 25.064922071272328, 49.897310349249075, 60.02472108410251, 69.28563317944928, 64.7751820471979, 69.29002623404227, 69.72407571731075, 68.64996602458339, 65.71646851878013, 63.703174744882894, 61.40396764201503, 60.7940508473304, 59.78860616683961, 61.17557587162141, 58.311425870464696, 61.28158184789843, 59.22604806961552, 55.62615948338663, 56.56543770144063, 55.44523623681838, 59.0988338378168, 62.73806771924419, 61.57247266461773, 69.83182322594428, 67.39415645599365, 62.374762104403594, 61.355789169188476, 65.09611037469679, 63.34483877305062, 61.5365319867288, 57.87012000237742, 45.331004665743926, 47.168446817705714, 48.52651257668772, 45.68581834916146, 47.28055600197085, 46.4782783292955, 48.62590935922439, 46.44277695686587, 46.949555027869444, 46.057521758540986, 45.45023687424199, 45.10438972903837, 46.31285236727807, 48.25270760443903, 50.58394478213403, 45.96248272926577, 43.49243287117251, 46.16601451750725, 44.14388756598196, 43.9918408086223, 48.783749457328554, 46.136235883159024, 48.405491767391084, 45.26857622208134, 43.24851243726669, 44.260303512696304, 43.57487716982442, 44.254298363962484, 46.291463682728434, 44.77734250407065, 44.56570709905317, 45.42348630966679, 45.71858975195116, 45.46032128795501, 47.306973165081395, 46.353327305086204, 46.60942277600689, 49.34803731979863, 46.67329072952271, 46.369726734776656, 45.49804664427235, 45.585060504175004, 45.019427268735825, 44.4665103573953, 44.536461907048384, 44.090915956804835, 45.565734986336004, 44.02661654257005, 45.9630593176811, 46.28563504065237, 43.48320353415705, 42.95404441895024, 43.59860358699676, 44.452864431565814, 41.4948481898154, 41.79603522823703, 42.45084747191399, 44.93231142720869, 46.25961011455905, 48.04568098437402, 47.058942087234996, 46.38081135288362, 45.25977834578484, 47.40460488104051, 45.33398958944505, 46.00786455215947, 46.28295606182468, 48.99075254317253, 47.01032430894914, 47.31293909011349, 47.344533781851496, 46.58845378506569, 47.08555929122433, 48.217688683540594, 46.79732784148186, 48.93074420190627, 49.14065376404793, 47.820991931423066, 47.57172138460221, 46.75669600886684, 46.93139445397162, 48.6820855448323, 47.9789928467043, 46.61476504418158, 49.61573908405919, 47.49328574826641, 50.359130213337565, 50.93244344957414, 52.96600411015173, 54.12463695772233, 59.16424720518051, 58.52062940597535, 63.61995773930704, 69.01236949428436, 73.02950412996354, 74.21260080029889, 75.06879929573306, 72.7115568037956, 81.03688947616085, 69.72406787257042, 80.05940345025833, 29.877113296139626, 0.654437105742193, 7.677979796163498, 2.0290252974917813, 0.2666972391307354, 6.703389950336949, 82.76710187235187, 78.49418947773596, 82.83960296261696, 69.81013251889136, 72.31618189042615, 39.02814411347912, 36.65019542940202, 55.07068518669375, 80.00677308728619, 75.88236162739416, 3.856470431050947, 0.45573455191427664, 0.19467754319550531, 0.14539061775130613, 0.17534214282228103, 0.16105443449510684], [0.014037586365556045, 0.060143222536651365, 0.040739467968383146, 0.07165296964587704, 0.06751134510963194, 0.056582005364039255, 0.16818055372324683, 31.13042235374451, 69.39200785852248, 48.02103673258136, 37.373170621933475, 37.57291732295867, 73.23667587772493, 41.89332569799116, 61.73313686924597, 67.26533797479445, 68.9782605632659, 42.495711541944935, 0.29854167553205646, 0.22958993190719237, 1.1627640839545959, 0.4652689451411848, 12.070437208298715, 57.16044164473011, 55.287466741377315, 64.12529630045738, 67.15645297881096, 64.62617512672179, 65.39397908795264, 65.12377485152214, 63.24415545309744, 59.40225270486648, 59.891376187724454, 60.680764952013575, 62.32674052638393, 57.77755206631076, 58.20077580790366, 56.292601554624504, 57.2235643479132, 55.38808338103756, 56.19031790764102, 55.625849616143014, 57.75115451505108, 54.32370508870771, 62.540866636460834, 36.02289076774351, 42.910051115097545, 57.63018469656668, 54.227191248247706, 60.344382486035755, 55.520337858507716, 58.483908176422126, 45.32293635029947, 43.8553148700345, 42.221333903651086, 43.32086055509506, 43.431079156937145, 42.3898506933643, 42.98499976435016, 42.19902346211095, 41.772889321850194, 43.242154275217366, 41.65329625529628, 42.76433114082583, 39.66741200416319, 39.31302193672427, 44.30935667407128, 46.74216754974858, 42.793242931365974, 43.74717904675392, 44.64671581022201, 42.69643491314304, 42.48928277723251, 45.17818912383049, 45.145649140880955, 46.428597588692945, 40.00311590010121, 40.14584310593144, 38.52739080306023, 39.57221215771091, 39.39132421247421, 40.59318550171391, 38.27319375930294, 38.78097595707063, 38.22001426450668, 40.402256288836085, 41.25039431356615, 40.77764280380742, 39.78458889069096, 40.6298831970461, 41.082332518792924, 41.96760754431448, 38.41971389708981, 40.968030729601466, 38.9755686636894, 38.253126913501376, 40.400248035307854, 40.87451750232328, 40.45254499681535, 40.456388919584214, 39.204423273763354, 41.51364026531097, 41.68086267286732, 41.16431005539433, 40.94850909325385, 40.417267199485536, 41.5501614539854, 40.00152341781124, 42.59783829412153, 41.39270574815812, 42.23482293467368, 43.88347748787173, 43.558054124155355, 40.306232744647616, 39.59955107781195, 40.91173687288838, 41.299278813023726, 40.30296541029408, 42.12973479301699, 41.3632958166061, 41.37383914762928, 42.04126181141023, 42.81901682576826, 42.81624371005643, 40.714610315138295, 42.29768676142539, 42.66426755535988, 46.16959956384475, 51.42697588089974, 52.071185958000925, 52.374659738233014, 50.52206547029557, 47.867883866833104, 46.830107089011904, 45.37842612112723, 43.494782370905725, 46.65953105495822, 43.92771790104528, 42.882170907912716, 43.00110893864786, 44.03013098624445, 45.02004308085288, 44.89884968726866, 45.72024891453405, 45.8490320944017, 46.59351756495815, 50.38262521066974, 58.725643850141964, 60.09998352296891, 66.14605042242235, 65.23183222739928, 72.98308680134436, 65.88250637054443, 80.19579995063044, 38.35746196008498, 0.19971463258468336, 1.0083277451415216, 0.4541386069068986, 0.036866560262898286, 1.8097440898418429, 65.46029067808583, 68.6063414235269, 75.16724294231784, 55.98638996001213, 47.2920956150178, 25.04927965902513, 14.414204397509176, 34.574312394665135, 55.98714697745539, 63.3862707691808, 3.5526831063532063, 0.15049755903742007, 0.054554208932865056, 0.07411747449828733, 0.05367690802461678, 0.03974279140933387, 0.054656477840316874, 0.0228489936900235, 0.03325323762011624, 0.054537580994468544, 0.07569491082141477, 0.07269386863035542, 0.19160140906610798, 39.40544866746472, 79.0968930336737, 57.180194700917895, 46.31986556514617, 38.580974301984234, 48.580362796783454, 44.096250380239184, 70.56269414963262, 71.67047346791914, 75.61812723836591, 46.2402492953885, 0.2942880489412816, 0.15052568978599964, 0.5852023079510659, 1.10346814317088, 14.946261163680786, 58.431066005460686, 57.85122986762755, 66.04923848182925, 67.87914968306019, 63.93610077519571, 69.10405097469207, 65.38803277477142, 65.49956144825106, 61.42438357876193, 62.999548604411466, 62.79077652961978, 65.06172687776628, 59.336776579580004, 61.290822952024406, 59.87744000650222, 60.574543245377086, 57.04208412478047, 58.51193351130332, 56.59832285296533, 62.1517361364057, 56.19384411842593, 64.81817514665666, 37.7585474137337, 43.31603211741294, 58.20418042521323, 56.49000660065682, 61.11152356670749, 58.02214322551605, 58.70675371539209, 49.28742493352583, 45.48371038129253, 44.681668050827525, 45.47809354720577, 45.0331320301179, 45.274047928471724, 45.4533237795676, 44.12278913682507, 44.60080838972523, 45.184602199062226, 43.52618878887546, 45.69951918817336, 43.43308348809519, 43.05239392865089, 46.929762747979936, 48.66161861727315, 42.474330702135646, 44.550386321160104, 46.0168860035558, 44.41991259974819, 45.485828461185584, 45.12722576818159, 46.5425463645689, 47.426491706602036, 43.190010286146595, 42.82777155599287, 41.5608303008541, 41.591926851580226, 42.51633144194081, 40.81910617889897, 40.60286591129918, 41.61011095969908, 41.17533191557854, 43.73286239562496, 45.34842391167918, 43.28372747667375, 43.488028049469, 43.24289560317994, 44.02134487705846, 43.03617492798836, 40.087894009005645, 41.36191514230544, 41.226169755381925, 41.79417602477535, 40.89368612535539, 41.86335486750449, 42.47545250000493, 42.128879716319425, 41.60692599511916, 43.25334087494881, 42.96584290842856, 42.56325083394205, 41.062073476852916, 41.341087356690444, 41.76773532744377, 40.323973624937, 42.31789481255316, 40.11384833243586, 42.90248486303514, 44.60665664365215, 44.56309087814824, 41.45223556026336, 41.61390389165571, 44.08201609888385, 43.58131377927719, 41.63203700896233, 43.77623988736061, 44.52486345844884, 44.62553893366168, 44.16268748621787, 46.09377230367353, 44.126417329234464, 42.77867917091616, 43.4711540129877, 44.4871537916122, 47.63218079843829, 53.75039185247114, 55.89848179971018, 55.40885233109998, 52.40176331612372, 51.432773144014426, 48.44730815579815, 47.916497722748794, 45.5829777256135, 48.941114948641875, 46.630254483992054, 45.51053939327117, 44.80492853349255, 45.905557370954945, 48.27582605423466, 48.048285438168435, 48.398694299882465, 47.38107850474697, 48.907264894054784, 52.76557883908672, 60.28675894583426, 62.87969273905601, 67.58965523012223, 67.42435086158015, 75.09491443634033, 69.47737432295277, 83.03561948960828, 41.097590538763235, 0.2750401204872516, 2.1918028016244215, 2.0774992963960095, 0.060059734274663275, 1.9898214527676183, 70.48123436589395, 73.09494495391846, 79.89585630355343, 61.94397995548864, 51.019253346227835, 29.90615844726563, 18.820108675187637, 39.5571816352106, 65.41054717956051, 72.3780768917453, 5.329573913928002, 0.2081734230441432, 0.15144494932986077, 0.07269244370681625, 0.046976557482154145, 0.051874536795601736, 0.23604658222006214, 0.14934844247275783, 0.07250006370727094, 0.1748445380719439, 0.2246423981963627, 0.1696556406996904, 0.23844486643229765, 50.849136229484316, 89.69130116124308, 62.360304247948434, 52.43656258429251, 50.41849528589557, 88.63131200113605, 56.921310424804695, 76.09619355970814, 78.90600696686776, 81.73179226536905, 51.67654845022386, 0.622910013602626, 0.5974933613211878, 2.542312909518519, 1.352104982060771, 15.91957280712743, 62.243256799636356, 60.270434041177076, 66.8454953162901, 69.32333500154557, 67.71457487537016, 69.21641903538858, 67.60667831667008, 69.12403152834985, 64.75183217756211, 65.28819276440528, 66.03695361844956, 68.31818842118787, 61.17525031489711, 63.86709059438398, 61.72197380373555, 63.900764142313314, 59.54947102454401, 61.29673004150391, 60.168158238933934, 65.04222093089935, 58.44951291238108, 66.99896197165212, 38.572556895594445, 46.09013234415362, 60.77627466570947, 57.95996973591467, 62.765253666908514, 60.74537031112179, 62.00731446666103, 52.00660413311374, 48.56068818799911, 47.110293757530954, 47.809295423569225, 47.323517722468225, 47.408680223649554, 47.8027097640499, 45.714024113070586, 44.31782507127331, 48.324659562879994, 47.01883585222306, 48.67731986507293, 44.14370321458386, 45.44060353309878, 49.062900620122115, 49.6453647459707, 45.24571272634691, 46.535121317832704, 46.8800937744879, 45.153744912916615, 46.84910312775643, 46.306349077532374, 48.96118571681362, 50.094562422844675, 45.13276807723507, 45.81633521664528, 44.6447193238043, 44.943600008564616, 45.311392814882346, 44.53078231503887, 42.18738186743952, 44.41620595993535, 44.794075335225756, 45.86478041064355, 47.4632639269675, 46.68336729849539, 46.3461729018919, 45.336676413013095, 46.29657060869279, 46.37766168963525, 41.30316980423466, 47.317434126330966, 44.264457302708784, 42.42037457804526, 43.77701259428456, 45.219346554048606, 44.52901724846133, 45.1607894897461, 44.280072258364775, 45.044526515468476, 45.40367049555625, 43.61913719484883, 42.351536981521114, 43.527997001524895, 43.86867838521158, 38.9187531317434, 44.28179417887042, 42.212406589138894, 45.07098682465092, 45.05543070454752, 48.600025638457275, 43.70384077872, 44.22048753307712, 46.13242333935153, 47.36766399875764, 43.847972193071925, 47.83485750998221, 46.673165213677194, 45.66834026767362, 45.58100477341683, 49.54044134386125, 45.57723929805141, 45.2475287837367, 45.98060407946187, 47.63799375103366, 49.72872295687276, 57.72528256139448, 56.44919826138405, 56.10781085106635, 55.115537489614184, 54.015077314069195, 51.19039420158633, 50.61882249770626, 47.56743423400387, 52.37142378284086, 48.985065106422674, 47.41534040820214, 47.57409441855646, 49.533596807910556, 49.75733664727981, 49.239913263628566, 50.73453241778959, 51.40799160926573, 51.05816718070738, 54.88742812987297, 63.19269003406648, 66.22638840829173, 72.31666826432752, 72.56668013911094, 80.20334659084197, 72.07876082389586, 86.7843855580976, 43.84847817882415, 0.37275723992816867, 5.147066520106408, 3.0469157811134093, 0.14542994870533868, 2.3706425341867634, 78.66938606385263, 79.58449855927499, 87.39496523334135, 72.99730931558918, 63.69963676698747, 33.435020754414225, 25.264660927557177, 52.40357545114333, 73.55560379643595, 86.2189837424986, 8.481307683452483, 0.8586730207166365, 0.3363185742449376, 0.288516832816024, 0.18341482496790348, 0.27651621869975523], [0.032345220416543946, 0.016601381958612514, 0.06685201153759995, 0.13199103515475027, 0.03613816003405279, 0.026559372011932637, 0.08885801739750371, 34.30456315317462, 69.76635886776832, 49.0370875020181, 44.64734338944958, 13.482991553121998, 54.79315396278135, 57.85572098147485, 58.76136487530124, 69.3951222204393, 66.90894357619747, 43.897052811038115, 0.16892071723216967, 0.04306543731100617, 0.5633091698250463, 0.1988416294296903, 7.34942049749436, 45.80497995499642, 65.82378848906487, 63.923776688114295, 64.47516779745779, 63.68212338416808, 60.06988325426656, 62.71954236492034, 65.24549776507963, 65.3781758585284, 62.55299852740381, 61.79250194180397, 60.93691533611667, 60.04410151512393, 62.308513272193174, 59.55567621415662, 56.967751287644916, 55.22007649944675, 55.851127024619814, 55.63778538857737, 61.60388692732781, 58.91039140762822, 57.43943983508695, 47.43874519102035, 47.0393459258541, 61.009949868725194, 56.691985130310066, 55.758170773906095, 54.636780831121634, 51.76539013462683, 45.28350868532735, 44.41936346792406, 47.06464129109537, 46.61881685256959, 44.48362758082729, 41.64461605010494, 42.83549862523233, 41.78247167218117, 41.594692122551706, 43.02367825661936, 40.65333897067655, 40.64711809158325, 39.97521608106552, 40.09174969888503, 39.81304568629111, 45.856453218767726, 42.25452107767905, 43.014633271002005, 42.116202615922504, 42.48095950772686, 44.900046010171216, 44.14578599314536, 42.875644083945986, 42.625483159096014, 41.150342495210715, 40.47812669507919, 39.51644389860092, 39.947265271217596, 40.04832906107749, 40.76478135201239, 38.556992930750695, 39.7545749141324, 38.53516886311193, 40.40768484915457, 40.69386489929692, 40.04547749796222, 38.99365471255395, 41.5561548356087, 43.715368624656435, 39.301623529003514, 39.3471622467041, 41.42427298330492, 39.30307480596727, 40.62083821142874, 39.393967889970355, 40.01168627892771, 39.28501229132376, 39.53927601537397, 42.97997913052959, 42.3729335108111, 41.340247969473566, 45.77160450720018, 41.50763119420698, 42.520383250328806, 39.353077180923954, 39.04474358404837, 39.11914310147686, 39.65931623212753, 41.519672870635986, 42.70280484230288, 43.80705010506415, 38.68388552819529, 39.31710512407365, 40.76289469195951, 40.36763352732505, 40.098806042825025, 39.98449640889322, 41.14247422064505, 43.091598018523186, 42.00713326854091, 41.49910396145236, 41.76176940241168, 41.24959807242117, 41.88201750478437, 42.76690029328869, 51.65708172705866, 56.3981133122598, 56.97198744743102, 55.90008212674049, 59.6182184065542, 57.213958463361195, 55.95115923112439, 55.8618115609692, 54.51234363740491, 57.46435080805133, 51.4863331087174, 52.13359871218282, 50.81616478581583, 50.46107653648623, 49.68964438284598, 50.40571228150399, 50.5026222813514, 48.63667234297722, 48.918424037195024, 46.04408764070081, 46.952955722808845, 51.2196276264806, 58.18719263999694, 63.80421500052176, 68.86259771162464, 66.79331994825795, 75.61891171240038, 51.566074894320586, 0.1367785024546808, 1.28598093025146, 1.5472926632050545, 0.09246141920166631, 0.5536873506442194, 56.11855422296832, 71.59887452279368, 69.59579852319533, 61.15873321410149, 56.409754906931234, 31.7176462757972, 22.931374311447147, 44.999991924532004, 50.26326356395599, 69.34590431951708, 8.631666841045503, 0.3171555896199519, 0.07080090367385457, 0.05737771790835166, 0.042968186279458385, 0.03036157171722622, 0.030651859668714386, 0.030514944434886983, 0.05273517912193652, 0.07561018915786859, 0.03203351456191271, 0.08699352792914837, 0.07816775071044123, 43.0303188293211, 79.97239743509601, 54.266379648639315, 50.6479617857164, 17.467004714473603, 51.010075000024614, 57.162418519296956, 66.29660667911654, 73.48478932534495, 72.51746223818871, 48.29262948805287, 0.15886651802687876, 0.022845147928643613, 1.1759031660133794, 0.5881496627003916, 8.039144287186286, 50.27987872400592, 69.66677773383357, 65.76854974992814, 65.28853401061028, 64.74079855026739, 63.40700049554149, 63.98181207718388, 67.3725441963442, 68.26700149043914, 66.15893148606824, 66.36593064954205, 63.61446249869562, 61.30704195268693, 62.99513201559744, 61.20538980730119, 59.868285194520034, 56.14746993587863, 57.19454273100823, 57.349456740963845, 62.6772552920926, 60.129962198195926, 58.90546883306196, 47.55070140284877, 48.665686115141845, 62.61295587785783, 57.74067394195065, 57.637256729987364, 56.09671838821904, 52.389902068722634, 46.71065915015436, 46.17640879846389, 47.378030823123076, 50.31297960589009, 47.17357335552093, 44.21652593920308, 44.55921949878816, 44.04300028277982, 43.12704840014058, 45.65754198258924, 43.35290239703271, 42.3764479544855, 42.91780171855804, 43.545286809244466, 43.13058637803601, 47.12610875406573, 43.97910879504296, 44.3833561097422, 41.147639982161984, 44.18411147209906, 44.3110550603559, 42.596845934467936, 44.772274801808024, 44.32960787127095, 44.75571847731068, 42.82415120832382, 41.69814463584654, 42.167389546671224, 43.260236401711744, 42.01316195149576, 41.82619825486214, 41.143839205465014, 40.640159806897564, 42.74315426426549, 42.98724336008872, 40.0438222577495, 41.60101890563965, 45.6760085013605, 44.86517221696916, 42.107483187029445, 41.48592872004355, 40.95358071788665, 41.60472162308232, 43.3859875894362, 42.7501674621336, 42.54638856457126, 41.044764057282485, 41.51398151151596, 45.09386208749587, 44.41773960667272, 43.10695802011798, 46.432288539025095, 41.248417438999304, 41.78248736166185, 41.33175211568033, 40.079570739499985, 39.744529724121094, 40.43874217617897, 41.56101072988203, 45.56893171802644, 46.38247051546651, 40.175288338815015, 40.292363243718306, 42.923991218689956, 41.78285606445805, 42.17161393934681, 41.79665496272426, 43.43688034242199, 45.048523410674065, 43.69947518071821, 44.70339013684181, 44.41917519415579, 45.32643902686335, 44.243135298452074, 44.852499038942405, 55.49180653787429, 59.003618301883826, 59.45762480458906, 57.77126450692454, 61.291666261611454, 60.48355602448987, 57.70836537884128, 59.098927974700935, 57.18643126949188, 59.86896768693001, 54.75111792164465, 55.619789554226784, 53.41327590327109, 54.42359608988608, 52.87953545970302, 52.5696329147585, 53.819394188542525, 51.448697966914025, 51.61695588019587, 48.42042030826692, 49.723129657007036, 53.43012248316119, 60.557982998509566, 67.6660551563386, 69.95427177798364, 70.41607595259144, 78.76302088460615, 55.65324344942647, 0.15306511803740455, 1.6767605418159117, 1.4861132492942195, 0.07577191797956344, 0.583847925787972, 60.35747535767094, 78.39964466710245, 74.02673536731352, 68.7904731688961, 56.57882082846857, 32.34529022247561, 26.35902770103947, 49.54417544026529, 58.691699658670736, 81.77069433273809, 11.615541308156907, 0.4250158357524103, 0.1914067461245483, 0.055090305770957665, 0.1481573136463281, 0.0676589702526408, 0.0786249673054103, 0.16436321420534966, 0.11450593630152364, 0.28787037718199915, 0.17009896045971304, 0.2654584443136569, 0.19095006579112625, 52.478771209716804, 89.98579271378057, 63.404192078498106, 63.42453741258191, 23.60242909000766, 65.31775959076421, 71.74601831743794, 70.51488830197242, 78.42337500664496, 78.72597017595845, 52.73267407571116, 0.3821192327285967, 0.2845469958359196, 2.0698685703739046, 1.6987674899639624, 9.692753284208237, 52.954013424534956, 71.58395382665819, 68.52809013858919, 67.74454178348665, 67.37496822111069, 63.578321779927904, 65.13825231982817, 70.43166345165622, 70.0738883787586, 67.51078421069731, 68.10739240338727, 66.34011360906786, 63.128359240870324, 65.82420426030313, 64.62046807812106, 61.08662043848346, 59.32428775295135, 59.55198918619464, 61.49770836676321, 67.78906852968278, 62.99117826646375, 62.2867048940351, 47.06027569309358, 47.60226880350421, 66.99122705767232, 60.36370408150458, 60.695960214061124, 59.739423567248934, 55.939482335121404, 52.08423960593439, 49.10265384181854, 50.76845699740995, 50.72231031233265, 50.252877127739694, 45.68044470202538, 46.21301235691194, 45.58301694931523, 46.05658823443998, 47.84032137163224, 45.80406604274627, 45.06227131812803, 44.161353880359286, 45.94499680303758, 46.0371881915677, 48.25297824798092, 45.42815785254202, 45.50293783987723, 42.26645292774324, 44.849541571832475, 44.4463768313008, 44.99868577526462, 45.879810933143865, 46.62834821208831, 46.77460162870346, 45.57788648912984, 43.88061023527577, 45.278699859496086, 46.4344693768409, 45.77730371106056, 43.23173253766952, 45.25674635364164, 43.50711038035732, 46.98018873891523, 44.86330124639696, 43.291721267084924, 44.511770586813654, 46.91054705650576, 48.07617741246378, 43.10313370919997, 43.49256623175837, 44.09989033975909, 44.02549474470077, 47.077216409867816, 45.12264051745015, 44.55408119386242, 43.163518598002774, 43.51975217942269, 47.77477464368267, 46.1470498577241, 44.689089175193544, 48.14547000392791, 42.81285085985738, 42.48213621877855, 40.44164473010648, 39.98562605150285, 40.680234662948116, 41.9277209620322, 43.66715485049833, 46.840713177957845, 48.28802070310039, 43.63208101641747, 43.40454040035125, 45.33973978411767, 45.67221556940387, 45.89553179279451, 43.78523388216573, 44.66324860049833, 48.54333954472696, 45.02387523651124, 47.054419594426314, 46.08072650048041, 47.50402519779821, 46.78847897437311, 47.69466807765346, 58.83089280897572, 61.99396271859447, 62.95165254223732, 61.33189409009872, 64.39543777896513, 64.32472921186879, 61.06864421598373, 62.203342760762865, 58.480695755251, 64.6672344976856, 56.20092399658696, 57.606054275266594, 55.825843426489065, 57.22027347933862, 55.57550991735151, 55.901078408764256, 56.05164251019878, 55.27369922207248, 53.98025843404955, 51.80079737017232, 52.09786591991302, 57.8690609624309, 62.78403789766374, 71.60558962052869, 74.97799642624395, 74.5758750361781, 80.74843052894839, 59.98450110035559, 0.12548241343709732, 7.772218661923563, 5.5463245799464564, 0.22336503851317593, 0.9514485359672578, 66.87285777061217, 86.02930576570573, 80.66322880406534, 76.02991334853634, 69.26478970435359, 45.942066792518865, 35.92100328014743, 64.4888960930609, 65.13816602768438, 95.87742021006923, 17.32552678354325, 0.8658811113526745, 0.37781562656164175, 0.19344133775561087, 0.24885138947396512, 0.172683572576892], [0.09320569660274253, 0.02977263013411674, 0.06268407188115582, 0.059352106519884644, 0.07182988999111038, 0.024186052689929644, 0.051909807483635606, 34.35885267872965, 69.83262338945943, 48.34116097419493, 43.18119672036941, 25.861612327637214, 26.5890472550546, 44.464188314253285, 65.93037497612738, 69.85902094071912, 66.22971457819786, 49.846621559512236, 0.3186958860005102, 0.07122933068462918, 0.4507805064560906, 0.13747156687801884, 5.4302425249930355, 37.07056368550947, 65.67642896406113, 66.42002797895863, 64.0850253258982, 64.984464030112, 66.97827539136334, 62.61082603085426, 62.390702616783884, 63.172015220888206, 61.69479962318175, 63.09798440625591, 65.91658392260152, 63.965067478918264, 61.797769684945386, 59.410936832427986, 57.977612556949744, 60.203471337595296, 58.64818880634924, 59.78771186644032, 57.41872187583678, 56.143006278622536, 54.98962548471267, 65.67699378536594, 60.37576536978445, 54.61646295362904, 59.05702529415008, 54.626672883187574, 49.81326572356686, 46.087759310199374, 44.12353438715781, 48.298873901367195, 51.62094100829094, 50.42080163955689, 54.831051903386275, 52.362833792163485, 43.6327438969766, 42.197925198462706, 42.73782376320132, 43.46650208196333, 42.335243455825314, 41.26214965697258, 42.20136119473366, 40.02346907892535, 40.80001208090013, 46.33243676154844, 45.34811796680574, 39.88218530531853, 40.40403704489432, 45.74067661839147, 47.078910873782256, 43.60017253506569, 41.52859626277801, 42.97777083612258, 44.30725036128875, 39.31373580809563, 37.91356732768398, 39.813908607729026, 39.733378425721206, 40.842114802329775, 39.98273526468585, 37.68346148152506, 39.87153999267086, 40.010435042842744, 40.55504437415831, 40.566078001453036, 39.420514491296586, 42.77348203043784, 42.95343645157353, 40.34729603798159, 41.037060522264056, 40.274700810832364, 41.188244358185806, 38.921204613101104, 38.87217890831732, 40.3200630218752, 38.66230072513704, 38.99247407913208, 42.52463902196577, 42.72150670328448, 43.144189157793605, 42.372502050092145, 41.01823314543694, 39.47193676425565, 39.764741697619044, 39.02708115116243, 38.593823986668745, 40.66048552913051, 41.249543159238755, 43.88809803993472, 42.31723585436421, 41.463998748410134, 41.38589651353898, 40.30895094717703, 38.4009139768539, 39.740085678715865, 42.33143091201782, 42.51738263714699, 42.23707045278242, 40.73612451553345, 43.00645512919272, 41.44120585533881, 42.290955974209695, 41.63037000163909, 44.63447409291422, 51.66203960295647, 56.764368549469985, 53.86006916722944, 51.72100851612707, 57.50162901416902, 57.13153377656014, 58.27472817513251, 60.4596491782896, 59.66793052611813, 59.55861406941568, 60.338091004279356, 60.549106674809615, 60.96488183544528, 60.150664467965406, 57.226529659763465, 59.936036294506444, 59.270488523667865, 58.218877546248905, 59.90368850769536, 62.21323890070762, 58.2843497491652, 53.619718090180434, 47.51958131790162, 56.60788559144544, 63.459940725757235, 68.46324551490046, 71.55554017712994, 57.92037340902514, 0.3983608789501652, 1.5566264333263522, 2.5258083112778205, 0.042709198765336506, 0.0569582847698081, 46.90815833307082, 71.63707840827205, 71.25318819476713, 61.494464566630704, 60.69839208356796, 44.87834745837797, 19.26980253188841, 43.730222640498994, 49.43651422377556, 71.88650977226996, 18.259564715047038, 0.4060989798557374, 0.1461427322318477, 0.062329147176276294, 0.010662007618755584, 0.03405164679392211, 0.026163501822720134, 0.015178675286381718, 0.06917948624299419, 0.04590384669662003, 0.057755249867876696, 0.040091307788726785, 0.051315943785612626, 42.679305922600534, 79.93372286519697, 54.70802284056141, 49.48386507649576, 25.526537972111857, 37.81579832876883, 52.71373687251922, 70.71015173389067, 74.97987916392665, 70.60293766760057, 52.675238809277936, 0.3972978859899506, 0.16658607960468338, 1.5296878401310214, 0.9071932300444573, 5.328433484800401, 39.3703003083506, 66.9465434166693, 67.64553331559705, 65.24050458785027, 67.36247939448204, 66.576279517143, 63.695914437693936, 61.80333945059008, 64.42419659706854, 64.52161650503835, 64.01948644268897, 67.62165392598799, 65.30102283723893, 63.625456902288626, 62.52211770703716, 59.36217392644575, 60.567110353900546, 61.26725735202913, 62.77288659926384, 58.50196284632529, 57.2661534432442, 55.678421143562566, 67.878325985324, 62.87577036888369, 56.69897479395713, 61.643200843564934, 56.98395067645658, 52.24536272787279, 47.105249589489354, 45.396045407941266, 47.73240912345148, 54.255844162356475, 53.45935983042563, 57.58194738818754, 53.26331192447294, 45.25120404458816, 44.403305284438595, 45.569422014297984, 45.06063176739601, 43.99107202406853, 42.882955381947184, 42.68236144896477, 43.27135239878009, 43.0807997334388, 47.88000791303573, 46.17809149526781, 41.56134805371685, 41.239325384939875, 45.43806575959729, 47.44713121844877, 43.19652926537299, 43.974943237919966, 44.069899897421564, 46.40077229469053, 41.59680235770441, 41.29994953832319, 41.71028437152986, 43.09193141998784, 42.55826157908286, 42.17898015053042, 40.90704964053246, 41.58343492015716, 40.94003677368164, 43.23878103686918, 43.4158956620001, 43.29514941861553, 43.18973179786436, 43.09235895833662, 42.96128511428834, 43.71191301653462, 43.18377763994279, 42.71115164602957, 40.43225849828413, 43.0690404676622, 41.97671921022477, 41.6442826486403, 42.728437531378965, 44.19806334280199, 43.12966854341569, 42.276392213759884, 42.35350601134762, 41.013761643440496, 40.3236755248039, 39.71147591067899, 39.049850510012725, 39.80493814714494, 39.91092058920091, 40.33009644477598, 43.42687829848259, 42.22824119752453, 43.80426914461198, 42.95016911721999, 42.32154261681342, 42.247900116828184, 40.80948068249611, 44.50154104540425, 43.26512367494645, 43.86379895671722, 43.33064294630482, 45.438724717786236, 42.68453051967006, 43.91704513180641, 43.89993575311477, 47.4869393533276, 53.370463232840265, 58.30005491933515, 57.39192424281951, 56.0453353389617, 59.64282735701531, 59.14324291290776, 59.928685772803526, 61.75529826071955, 61.417264476899184, 61.77199971291327, 63.29129842019851, 62.97344130854454, 64.62896785428448, 62.56379289011802, 60.630617449360514, 62.39064770360147, 61.23312096441946, 61.45057716677266, 64.10326434719947, 66.17863747381395, 60.07923026238719, 57.11357716591128, 49.647557350897024, 60.559963795446585, 66.17790006822156, 73.27745283803633, 73.33000475360502, 68.05263611578172, 0.42020869531458427, 0.8995408084123366, 2.379021452319238, 0.03115340402620214, 0.1487866548761245, 48.86454243813792, 80.91675512252316, 77.0157697123866, 71.23471383125552, 63.34356792511479, 41.35331338451755, 24.661873040660737, 55.319363455618586, 54.942584499236084, 82.81278964011901, 21.95132697782209, 0.3490135704557742, 0.14440994859943468, 0.04138038861715505, 0.005720815200719142, 0.04304327055691712, 0.14332994848730105, 0.16836257621405587, 0.18567176595810922, 0.1611182342974409, 0.13857238925993443, 0.1518483405872699, 0.12567690783931365, 56.387730798413685, 88.7860102807322, 63.44484744533416, 59.44215105425928, 39.791951179504395, 39.864738602792066, 57.0309445934911, 80.50573779690652, 80.41452700091948, 77.49966467580488, 58.40752001731627, 0.8063116465364734, 0.3888006838819673, 2.4227173914832454, 1.2205955097752235, 6.653658709218425, 41.98765870063536, 70.34078213476366, 68.56030064244425, 68.02380669501521, 68.48380657934374, 68.77334025598341, 61.53272728766165, 65.03682374954224, 65.77514325418781, 67.80468740770894, 68.29361869442847, 70.42859615818148, 68.41252142383208, 65.13086649679369, 64.76636063668036, 60.95691942399549, 64.27627617313017, 63.221111528335086, 65.1565815556434, 60.563242896910644, 58.20181523599933, 57.001593497491655, 71.00985219401699, 64.95534043158254, 58.72017998849192, 67.18407430956441, 60.43944897190217, 54.87126796476303, 50.39953454848259, 47.64915681654408, 50.62008550090175, 58.65710435375091, 58.02199025307932, 60.293305381651855, 56.20659574385613, 47.73173055341167, 46.88052915757703, 46.3869773187945, 47.11605964168426, 45.401697543359575, 43.68430737526187, 47.170819851659964, 44.45031881332398, 45.25010970331008, 50.072561848548155, 47.76794971958284, 41.78920245939686, 42.04118728637695, 46.8982857273471, 47.91929045031148, 43.621345489255845, 44.38352477165961, 46.75555852151687, 50.02315175148749, 42.79178773203204, 43.23612166989235, 44.00074458891346, 44.868259122294766, 45.00737774756647, 45.00681684863183, 42.60341982687674, 43.74918337791197, 43.95060100863057, 44.8640464967297, 47.18475211051203, 46.53183437162831, 47.24977324085851, 46.64766588518697, 45.046899549422726, 45.68030741906936, 45.01356724769839, 45.628010457561864, 43.231120647922644, 45.246626638597064, 46.29751197753414, 46.04063595494917, 42.983826975668634, 45.91822270424136, 43.86305370638448, 43.52061117849043, 43.02425092266452, 42.56689079346196, 40.42132685261388, 40.10916894482028, 38.78976991099697, 40.146784474772794, 40.78621318263393, 42.59748528080602, 45.11530176285775, 45.618863490320024, 46.66689334377166, 45.6287988539665, 45.477414977165964, 45.22031930185134, 43.803692556196644, 46.96428352786649, 45.57574095264558, 47.43963949141964, 43.90377183114329, 48.31257474037909, 45.63831452400454, 46.20067258034983, 45.068127416795306, 48.10191992790469, 57.397737195414884, 62.27172536234703, 60.12922479260353, 58.16346230045442, 62.263260887515166, 63.292745774792095, 62.719648268914995, 65.49874951762538, 63.12471535898025, 65.31743795641007, 64.94684065541914, 65.39827016092116, 66.60618366733675, 65.71364833462623, 63.3042069404356, 64.72875687383836, 64.55224629371398, 64.28830216007849, 66.9854062603366, 69.09640235285606, 63.03006464435209, 59.617010316541126, 52.33991146087647, 63.779347173629276, 66.81477531310051, 77.6304521868306, 75.24948720009097, 74.99749060600035, 0.4658369227282463, 7.1732840134251505, 7.076297037063107, 0.08191672454197561, 0.3642956762304229, 53.25557701049313, 87.74539762927641, 82.3960142750894, 79.75185040504702, 75.71898706497686, 60.13892089166949, 31.89321940945041, 63.85155800850161, 65.25703345575641, 93.2006928228563, 29.055680728727772, 0.5979597556494898, 0.3031919824500238, 0.15452180358190692, 0.1565580959281614, 0.09891931823785267], [0.03399751119075283, 0.03701751788837775, 0.011583424657733451, 0.11452393170686499, 0.07824420628528442, 0.11236450604854092, 0.10685936758114446, 32.663902390387754, 66.38551896618259, 44.559458763368674, 29.228012023433564, 11.700643993193104, 20.735631488984634, 47.2824897304658, 65.65848412052279, 66.50471979571928, 66.05729503016319, 51.572742923613525, 0.4285133335619204, 0.10899231724080541, 0.6040781015349973, 0.12486315392438443, 2.1473540125354647, 28.500343714990926, 63.73132951797978, 64.57738868651852, 63.84984785510648, 62.11419120911629, 59.49128266303771, 63.407098554795795, 62.07014299208119, 61.942411007419715, 58.92460215476252, 59.16786363047939, 55.02242826646375, 55.91825054537866, 58.7881075951361, 57.55593030683456, 59.79882786350866, 58.69821079315678, 56.48212263661047, 56.379678172449914, 56.50304063673943, 58.32580527951641, 57.97460802139775, 55.810546182817035, 54.51116692635321, 56.071089621513124, 52.821676577291186, 48.544547634740034, 44.007800932853456, 43.4351231205848, 48.919365406036384, 54.88110919152537, 60.38106056951708, 61.14216512249362, 52.29126622599941, 53.15033589639972, 50.72520109914964, 44.97881897034184, 42.053397624723374, 41.65243333385837, 40.82675480073498, 42.516700144737, 42.12356882710611, 43.484996057325795, 40.556899655249815, 43.29700862207721, 46.224838302981475, 40.50941936431393, 40.24312965331539, 40.80564460446758, 47.896568159903254, 42.78975986665295, 44.689712832050944, 45.49294364067816, 41.72067080774615, 40.337745066612, 41.20566360412106, 39.95948737667453, 37.63944072108115, 39.73016600455008, 37.08871641466695, 40.16498819474251, 40.22058386956492, 38.347907066345215, 40.93531423999418, 41.43719327065253, 40.47326295606552, 44.167770877961196, 41.668840608289166, 38.84137261298395, 38.92288730990502, 40.71528888517811, 39.75649295314666, 39.23046388933736, 36.83395847197502, 39.219465563374186, 40.69188802473007, 42.91988841948971, 40.36668039137318, 42.10850692564442, 43.77408650613601, 39.24641224645799, 38.93920044745169, 41.53613898061937, 38.721261793567294, 36.55456804460095, 39.50278228329074, 38.764960919657064, 41.13462948030041, 43.95824963046659, 41.59304472707933, 37.811330749142556, 39.7335353205281, 38.05617294003887, 40.19007959673482, 40.4405229322372, 39.05897394303353, 40.25582636556318, 41.6359515343943, 40.438855924913966, 42.664110660552986, 40.61665696482505, 44.410020382173606, 46.14257443335749, 47.487978781423266, 48.37124947578677, 53.31609918225197, 54.75894697250859, 55.464142061048946, 59.22915850916217, 59.62297231920304, 58.62815726187922, 58.96719909483387, 57.32454576799947, 57.53236078446912, 55.78816121624362, 57.83667395191809, 60.02648222830988, 60.53327991116432, 60.011498774251635, 63.926361530057854, 62.820178616431456, 63.49261014692245, 61.19515242115144, 63.69376497883951, 62.86570164465136, 65.6146163325156, 59.262392751632206, 57.107917185752626, 62.176529438264915, 71.20301323552286, 70.98795752371512, 65.3627452542705, 1.155079670490757, 0.17933511565769875, 0.8446506086376406, 0.0847235864268676, 0.030252634014393535, 38.806549810594134, 72.62611189196187, 67.44109938221594, 66.77417878181704, 66.75521019966372, 47.45071234241609, 21.967787204250214, 42.02612538491526, 47.83701089120681, 76.1666157937819, 23.55071067810059, 0.2559136169692201, 0.0872759155989174, 0.05549174350415988, 0.08253259028518393, 0.037311638194707133, 0.08275351472078793, 0.04242290404715365, 0.0339132453495216, 0.04846751396994918, 0.03320837551127038, 0.11408202154862304, 0.19376868712565593, 41.20152158121909, 75.230298965208, 51.8353142276887, 34.276886909238755, 18.8467219568068, 30.089511602155625, 52.19882380577826, 73.23028241434406, 71.25391775561918, 72.58695094816147, 55.04957499042634, 0.48208117364875736, 0.04268457669945013, 0.9802049638763551, 1.1835500718124452, 2.9006697189423347, 28.644859521619736, 66.97333320494621, 66.15587988207417, 66.53233328173238, 64.54630782527309, 63.419901171038234, 64.47624644925519, 61.20351099198865, 60.39054878296391, 60.21023742614254, 58.97051741999965, 56.614812497169744, 56.15869968168197, 60.85722061895556, 58.637088498761585, 62.070327343479285, 59.19110367375036, 57.81149233541181, 55.916128543115434, 56.68561520115022, 60.04979679661413, 60.01877084855111, 57.27976014537197, 56.87331238100606, 58.888147646381015, 55.67070976380379, 52.526961449653875, 46.71032182631954, 46.30089698299285, 49.26950754657869, 55.72263017777474, 62.53446140596944, 59.17144867681689, 54.089096361590975, 55.71781350720314, 52.77959739008258, 44.79746034068447, 42.67893329743416, 43.28095436096192, 44.043992642433416, 44.99954085196219, 44.78876836838261, 45.00561268098893, 43.38085320688064, 44.850326045866936, 48.23627287341703, 40.8912621005889, 40.26103135078184, 40.52258283861222, 46.82529434081047, 43.599768530937936, 44.5170775536568, 45.9502370895878, 43.59692873493318, 41.84302914527155, 42.55834787122665, 40.579543498254594, 39.80965283609206, 41.64545543732182, 39.44231502471432, 40.88024416277486, 42.21785083893807, 40.62285823206748, 42.89718574093234, 44.30433604025072, 42.404610572322724, 45.93656762953728, 43.71032837898501, 42.63089602993381, 42.69684283964096, 41.47757014920635, 40.84867692762806, 41.43688340340891, 40.247616844792525, 40.48270410107028, 43.52409424320344, 43.58300039845128, 43.53579075105729, 41.658465939183394, 43.09363765101279, 39.2002224153088, 38.6376956970461, 41.069172966864805, 40.30054530789776, 38.20043379260648, 40.045214699160674, 39.32357703485797, 40.53742508734427, 43.48765542430263, 44.443254624643636, 40.604909466158965, 43.42422677624611, 39.618872673280784, 42.423237908271055, 42.268653377409905, 41.53356590578633, 41.59685727088682, 43.917484437265706, 42.334988501764116, 45.17693004300518, 43.85453039600004, 45.44070943709343, 48.604144127138206, 49.967646291179044, 50.50783118894024, 56.65050998810799, 58.74962129900533, 58.42341738362467, 59.681607830908995, 59.6784620900308, 58.60095954710438, 58.757842586886504, 57.13538946643953, 60.41895066538165, 57.75432379015031, 60.54834573499618, 60.70826861166186, 64.27887278218424, 63.001721597486934, 65.10926208188458, 63.95084496467345, 67.25931321420978, 62.92521184490573, 68.82544502135246, 65.49256393986364, 66.95521185475012, 61.21852974737845, 61.36270823017244, 64.572050340714, 75.00513922783637, 72.09849819060295, 72.59848271646808, 1.1670986707172086, 0.6068724225605688, 3.077577929342947, 0.04864725351874386, 0.010757403759916705, 42.534982312110166, 80.94985208203717, 70.45954365884104, 75.08419067628923, 70.38034316032164, 52.62632685322916, 29.722475813281154, 49.50632849047261, 55.02441298577094, 85.51266685608896, 29.044713781725978, 0.3439216904582516, 0.1011230314390794, 0.06206491962075234, 0.12235047746329539, 0.0557511676883986, 0.16750691728966852, 0.16920597773165474, 0.07391468336385104, 0.19709153221018855, 0.21486921536345638, 0.32019781669782055, 0.26800626888871193, 50.84101692322762, 84.93934185274186, 60.149950596594046, 45.676785130654615, 24.388532869277466, 33.320475778272076, 61.76401376724244, 78.19233171401486, 75.00790057643768, 77.91704408584103, 60.105380704326016, 0.6495821920614089, 0.2682637970053381, 3.4385722875595097, 1.3578698856215323, 3.1962041316493868, 32.50041604042053, 69.6899667862923, 68.80266389539166, 68.35090883316533, 67.0991079268917, 64.32440365514448, 67.15799839265885, 63.5450130124246, 62.4463688942694, 60.908078070609804, 61.74925388828401, 57.31018989316879, 57.96847735681842, 62.03697935227425, 59.938809410218276, 63.0264639085339, 62.335734521189046, 57.6197394247978, 56.380388121451105, 56.92597804530975, 64.20862313239806, 63.592905152228575, 60.67205729023103, 59.81167754819317, 61.726672803201986, 58.42319380852484, 54.65707909676337, 49.27811714910692, 47.917313575744636, 52.95382907313686, 60.41012533249394, 62.75709121457992, 59.41079170473161, 56.81336679766255, 57.978377419133345, 54.778554901, 48.09662080580189, 45.704433917999275, 45.33132237772788, 46.792577851203184, 45.87814000345046, 47.05334878736927, 48.45741218136203, 45.2986333447118, 46.269212076740885, 48.3608591172003, 41.218450530882805, 40.87299562269642, 41.71394002053046, 48.673554389707505, 43.46827891565139, 45.685269217337336, 46.80310549274568, 42.79929907091203, 42.56281545085292, 45.329686749366026, 44.35030229630009, 43.55567716783093, 43.03275854356828, 40.725141879050966, 44.21305464160058, 44.798056540950654, 42.501681389347205, 45.24950173593337, 49.18003828294816, 46.42251007018551, 49.39456447478264, 47.2489534654925, 44.929750119486165, 45.152313247803725, 45.48511066744405, 43.643769679530976, 43.574865402713904, 42.17686207063737, 44.59633296535861, 46.62321775190292, 47.856846317168205, 42.65313586881084, 42.402967099220525, 44.97623412839828, 39.1357700286373, 39.71228784130466, 42.2367605855388, 40.76000390514251, 37.38134876374276, 40.490972457393525, 39.91868295977193, 41.46645022976784, 45.09435238376741, 46.633815996108524, 42.81801662137432, 45.00014489696872, 40.783530281436065, 45.430813297148674, 44.029927022995494, 43.748830364596465, 43.81182755193403, 45.46052525120397, 45.21932694219774, 48.095295044683645, 45.14213077483639, 48.67880252099807, 51.094809962857155, 52.915899753570564, 54.0019569858428, 58.66702795028687, 59.47504797289449, 59.74129061545096, 65.09393345925116, 62.26815992786039, 60.96980833238172, 61.17022968107655, 59.2622084002341, 62.195125395251864, 61.38883513789023, 62.954786516005, 63.95730510834725, 65.6672506178579, 65.8175362310102, 70.40990998668056, 67.69482966392272, 68.85482357394311, 67.67277025407361, 69.764280011577, 66.75811275359123, 70.92525451414048, 62.62907681926605, 64.28909840122347, 67.60540746873426, 80.20999893065422, 75.40356574519988, 79.28442939635246, 1.3571500081208445, 3.6546774785364833, 6.129561903015261, 0.16027601255524546, 0.15079123118231375, 46.110132509662265, 88.12935060070407, 77.73064521051224, 81.73477326670002, 81.94672246133128, 62.315393109475416, 34.18393458089521, 60.082277944011075, 63.771169031819994, 98.73907950616653, 37.02939448818084, 0.48221769051686414, 0.22316869017818283, 0.16863570188082036, 0.23609835444198501, 0.16075077256368053], [0.019302246003081242, 0.022154515834465142, 0.07339039577111121, 0.03813263930140003, 0.05181725257106366, 0.05225517907209935, 0.05450982179853225, 28.002796942187896, 71.1291628499185, 54.203782543059326, 43.481940530961566, 25.6468782501836, 36.330647776203776, 45.99235550049813, 64.28117913584556, 68.53496997587143, 67.10221444406818, 54.614156599967714, 0.541685265639136, 0.03433690729340719, 1.3624749933519673, 0.9835167926165366, 0.5516951543188865, 17.114769989444365, 58.6859533863683, 63.3962728131202, 61.72445274168446, 63.08744891997307, 58.386802058066095, 53.01403353291174, 52.81841708767799, 52.14414596557618, 54.685539814733694, 49.90876367015224, 48.055345704478604, 52.02129340940907, 51.831234962709495, 51.342335054951334, 55.03415615327897, 55.141758534216116, 55.6833044944271, 58.83728627235659, 59.88938362367692, 56.72206970953173, 54.20439835517637, 57.83776044845582, 53.325199081051736, 48.441785458595525, 45.17696534433673, 44.40350924768756, 44.257879487929806, 45.831299058852665, 50.33521160002678, 53.073053436894575, 51.9460545047637, 55.661413746495406, 66.59684058158629, 58.483896409311605, 51.39694621486049, 50.32712367273147, 43.38619547505533, 40.724035770662375, 41.46794857517366, 41.893364921692886, 42.963560088988274, 41.14266641678349, 41.966889750572946, 42.53358594832882, 50.33949090588478, 43.47722976438461, 42.11288036838655, 42.551793590668716, 45.07364619162775, 46.568084916760846, 43.19437196177822, 42.59631641449467, 40.31243793426022, 36.90596926596857, 38.94262859898229, 39.47928728595857, 39.09353786899198, 40.13466827331051, 38.09967594762003, 37.89848581437142, 39.50324512297107, 40.39261510295253, 40.483268922375096, 41.206291183348625, 38.13142753416492, 39.7432118077432, 42.13099387384231, 41.76621344781692, 41.72325564968971, 40.853901524697584, 39.06204123650828, 39.93521575004824, 41.8603071858806, 40.287856440390314, 43.7884541480772, 45.11127348869078, 37.85985439054428, 41.17445330465994, 41.55915152642035, 37.7948332601978, 37.671200152366396, 37.37399431966966, 40.44459435247606, 39.6180764321358, 40.224172838272594, 36.11902413829681, 39.155393646609404, 46.397391211602, 39.33869384950207, 39.20371724713234, 38.45069669908093, 37.5326188918083, 39.61288713639782, 41.339200696637555, 40.74601281073786, 38.315296480732584, 39.80607563449491, 40.66384307799801, 44.30505775636242, 41.36259763471542, 46.43916445393717, 51.80409216111707, 52.84373598714029, 51.572550727475075, 49.19341748760593, 51.82479050851638, 53.69174849602484, 53.57674460257254, 55.46869985518917, 58.22661246022871, 59.857624192391675, 57.94044417719687, 58.75566959381104, 59.4182598975397, 59.63582200388755, 56.76421949940344, 59.15708887961603, 58.548948918619466, 62.52349445896765, 59.76469932063934, 61.93342093498477, 62.509824998917125, 76.8753174812563, 73.52938667420419, 68.49056090078047, 61.94557636014877, 62.695541381835945, 62.49667721409952, 69.2902066630702, 71.41766102083268, 69.2112885752032, 1.1172164183470512, 0.832052507227467, 0.7310789931685694, 0.019081524580777175, 0.046583125367760665, 34.196066471838186, 75.1035201164984, 67.47373350204961, 64.68607364162322, 63.96660504802581, 51.908627248579464, 9.166888959946172, 31.568125524828513, 41.41223130687591, 65.4397217689022, 23.437010972730576, 0.12109885067348519, 0.0467274563326951, 0.02309519519668914, 0.02978627990570761, 0.03158268330979251, 0.07397135088761007, 0.007400884801867388, 0.052359742412884394, 0.06631265499538953, 0.057463994730384126, 0.0827796766234021, 0.07318867715976893, 37.91012348667268, 77.79391304139169, 61.00301904063071, 51.2925523327243, 28.401105788446245, 37.002083024671, 51.71332851532967, 72.19872259324598, 72.75951954626268, 73.14069547960835, 56.754907792614354, 0.5950555469720595, 0.11841775744312233, 1.212233629438185, 2.0481133893612893, 0.9861813077042181, 18.14612780847857, 58.84109097142374, 64.45330842848747, 64.23038051974389, 65.92704096148091, 61.83836229385869, 56.925715246508204, 58.62326998864451, 53.37304415241365, 54.84444287515456, 50.040806339633086, 50.062434288763235, 51.421170773044715, 54.54930413153864, 52.159180410446666, 53.401822582367934, 55.75573105965891, 55.642872702690866, 60.42181007323727, 61.40217119647611, 61.88794105283676, 57.288177551761756, 60.38183327644103, 55.48822149153679, 50.09105582391062, 49.12166557004375, 44.83331080405943, 44.24526514545564, 46.91355551442793, 52.00367804496519, 54.424035395345385, 56.11957403921313, 56.05597672923919, 63.855903994652536, 57.76671847989483, 53.87732759598763, 53.917112196645434, 45.03456761760097, 42.581317270955736, 42.31217207447175, 44.121581046812, 43.47924194028301, 43.10488308629682, 43.23376432541878, 44.47245274820636, 51.611896022673584, 43.05644573703889, 42.11053871339367, 43.28584163419662, 44.85410721071305, 46.414320161265714, 42.68182016188099, 43.68447603717927, 39.94835176775533, 38.35339838458646, 40.72093317585607, 42.45514638962285, 40.902334951585345, 44.01697927905668, 40.65837137160763, 41.23255537402245, 41.232159214635054, 42.553135041267645, 41.71150422865345, 42.8579738063197, 40.50330046684512, 41.3116656580279, 44.083534056140536, 43.61466961522257, 43.40619956293414, 41.87820888334706, 41.43950354668402, 43.11539111598846, 43.33273356960666, 42.0211322076859, 45.75697014408727, 45.67126243345199, 38.87453625279088, 41.10694146925404, 41.019821705356726, 38.17364008195939, 38.53544735139416, 37.83401773821923, 40.25027621176935, 39.63989657740439, 39.556134362374586, 36.604597876148844, 39.38671934989191, 47.68425418484596, 40.6300950050354, 42.58482386988979, 38.93037903693415, 40.68192912686256, 42.32728104437552, 43.60995492627544, 43.12684051452145, 41.11851246126237, 42.2183568246903, 43.19538393328267, 47.15143157589821, 45.197687225957075, 48.09651490180723, 53.730466211995775, 55.71931577497914, 52.573955366688395, 51.80817142609627, 52.574347603705625, 57.42418181511664, 57.50870889233005, 58.74631081857989, 60.1137000514615, 61.15216716643303, 60.66732691180322, 61.495135291930175, 59.825339163503344, 62.183609316425944, 59.403217607928866, 61.200828090790786, 60.00458755800801, 62.81203577595373, 61.34395930074877, 63.00122737884522, 65.92978662060153, 74.07294873268374, 72.83032617261334, 71.4071176898095, 64.26693700974988, 66.11575403521138, 64.26529353664768, 72.2588368385069, 74.04426051724342, 72.15453317088466, 1.0878823601430463, 0.8612081588756654, 2.345732051518656, 0.1116910994413399, 0.0930318559309648, 36.819963455200195, 81.78801551941903, 74.5949612894366, 71.98668710647091, 67.41147764267461, 53.623263912816206, 18.27923147909103, 42.56718104885471, 49.61877499857257, 75.17548776442005, 30.35267714531191, 0.10801785340112065, 0.15148627211249646, 0.03288249703003995, 0.08335520783739706, 0.0059146608222245935, 0.180836096405983, 0.06474857924566155, 0.1596539491607297, 0.1374187068112435, 0.14068423319728146, 0.2846618170940107, 0.14924719629268493, 49.17579035605154, 88.08993862521264, 67.8684808361915, 61.621466990440126, 37.38157626121275, 50.42246080213978, 61.46863183667583, 76.9053549920359, 79.4851919912523, 80.34240245819092, 64.3680400233115, 0.8445190253757662, 0.2407886511495998, 4.594107933582799, 2.445284993417802, 1.3142414847689292, 20.800691843032837, 61.53461787008471, 66.7483695860832, 65.93141048185288, 67.19945000063989, 61.306571268266254, 59.627781145034305, 60.90790548632222, 56.52201314126292, 57.37388134002686, 52.47721010638822, 51.20984915764102, 52.390882661265714, 54.218565956238784, 52.02501573870259, 53.537583658772135, 57.44355440139771, 56.22974949498331, 61.53708111855292, 63.74051570892335, 63.36476833589616, 58.5503335152903, 64.33090302252, 58.397549352338245, 52.57721485630159, 51.87732673460438, 48.56284549159389, 48.94875964810772, 48.932470044782086, 53.48733025212442, 56.884475446516475, 58.60372089570569, 54.840481281280525, 62.70548459022277, 58.389547717186716, 56.75588054041709, 58.306216962875865, 46.932704525609175, 46.2425870280112, 43.837456318639944, 45.74362624076105, 47.445711320446385, 45.19669878867365, 45.934257353505785, 47.50830842602638, 54.4188617890881, 44.31297309937016, 43.05275870907692, 42.68728402353103, 44.92611408233643, 46.89074300950574, 43.65223023199266, 44.49890129027828, 42.49422104127946, 39.43719240926927, 41.87281954673029, 43.239338013433645, 44.095426682502996, 47.62286124690887, 43.90669007455149, 43.52505914626583, 44.04549491020941, 44.89087550870834, 44.81776252869637, 46.05403869382797, 43.66446018218995, 45.23881719958398, 45.97445380303168, 47.27606096575337, 46.68474405042587, 44.297919042648815, 43.762056596817516, 45.29196139304869, 46.3570967028218, 44.97577128871795, 46.23488741536295, 47.624579245044345, 38.21200870698498, 41.14645542636995, 43.47865358475716, 38.630447156967655, 39.471113066519464, 37.68816048099149, 40.03265134749874, 40.61141275590466, 39.79244539814611, 37.010347458624075, 41.68494978258687, 50.33754933264948, 43.7364984327747, 44.372177354751095, 41.15953260852445, 42.78532366598807, 42.29818882480745, 45.98901756348149, 45.66245279004497, 44.32246523518717, 43.619007756633145, 45.20078589839321, 50.9286230610263, 46.56408017681491, 49.61469573359336, 57.534314124814934, 57.718496860996375, 55.744705277104536, 54.23309441535704, 55.67838191986085, 58.55971190237231, 58.84677448580342, 62.8308553080405, 63.45537508687666, 63.14548038667249, 61.817989503183675, 64.41444950719034, 62.59126909317509, 63.370212585695334, 61.04228588842577, 64.82911463706725, 62.46463537216187, 65.1782722626963, 62.94075227552845, 65.05440773502474, 67.58666638405093, 77.424755250254, 74.37697164473995, 77.00798772996473, 67.92832051554035, 69.41250616504301, 68.4814453125, 77.00275528815486, 76.8895870639432, 78.20012154117708, 1.4334664613969865, 2.575912913007121, 6.140070913299438, 0.2532077024901106, 0.16873497155404862, 40.10428559395575, 86.45448284764444, 81.67170155432918, 79.53058950362667, 80.35799780199605, 64.87267255783081, 16.077215806130443, 50.38428045088246, 59.57782191614951, 87.70506781916465, 42.15762284494216, 0.21525040539281987, 0.23712868141310833, 0.15882055275142193, 0.14140525982985575, 0.1593137754788322], [0.11670115358767011, 0.055426350238943295, 0.04452679982228626, 0.01367022805366545, 0.02829625612996038, 0.07027771158684647, 0.04195297039264152, 30.756742069798133, 63.77830382316344, 48.05078006559803, 33.373855313947125, 22.526230735163537, 51.608346277667636, 51.884418379875925, 65.56562985143354, 65.54980701015842, 65.09286265219411, 53.67881251919655, 0.5312891460714803, 0.1568702614355472, 0.2455669713597144, 1.6718377221015193, 0.18580097434741838, 7.907628686197343, 47.41476774215699, 54.86508630937146, 61.297565506350615, 58.496479372824396, 60.05260913602768, 61.66751953863329, 58.760674538150916, 56.20907468180503, 54.504314545662176, 56.14415553308303, 57.66254425048829, 53.52965654865388, 54.156969055052734, 55.51644686729678, 57.520228893526145, 61.891475108362016, 62.37711944887715, 58.98893294795867, 57.205901915027255, 58.15563324959048, 55.68993330001832, 46.9077935526448, 44.97040156395205, 43.52141134200558, 42.80282528169694, 42.14933879913823, 45.38008136133994, 47.063048808805405, 50.37071297245641, 53.546479594322946, 50.44350039574408, 44.98134105436264, 45.99636024044406, 63.54246347181259, 59.95290640861758, 49.27559114271595, 47.77306056791737, 41.29201850583477, 40.19725753415016, 41.24808403753465, 42.131519471445394, 40.76633461060063, 41.77238333609797, 40.205133653456166, 48.510352411577784, 49.75534800560244, 41.08614114023025, 39.24142299159881, 41.31132833419308, 43.81656577510219, 42.03508015601866, 41.83208181012062, 41.255332577613096, 41.587510262766195, 41.42785018490207, 40.66778113765102, 38.78787540620373, 39.25406479066418, 38.260814759039114, 38.48879468056464, 39.7968109961479, 38.24935751576578, 41.22779753900344, 41.06799233344294, 37.037054877127375, 40.66851069850307, 42.394075086039884, 42.7889165570659, 39.477479073309134, 39.19084795059697, 40.590467299184496, 40.850241953326815, 40.90527280684441, 41.211955085877456, 44.44210144781297, 40.589757350183305, 39.665262545308764, 37.253577555379565, 37.27817866110033, 38.086739970791726, 40.00069187533471, 38.91135946396859, 38.56878357548868, 37.292122687062914, 36.72525390501946, 36.92008979858891, 40.04996468943935, 44.322057308689246, 39.90854755524666, 40.459875906667406, 40.17222889008061, 39.87831392595845, 38.916674275552076, 40.57764114872102, 39.76115272891137, 40.86841821670532, 40.17515890059933, 42.21872160511632, 42.48967501424974, 42.50821605805428, 49.30636998145811, 52.35863685607911, 52.99094646207748, 57.84237707814863, 51.53549217408704, 47.36565966759959, 49.721560708938114, 53.87347190610824, 54.85017738034649, 57.705855061931, 55.653306207349225, 56.85289644425916, 58.50390049719042, 61.85247498173868, 61.84268474578858, 61.73930283515685, 58.09794302909606, 62.39370715233588, 59.17493958627025, 60.37568692238101, 59.135135373761585, 60.81491393427695, 51.650488222799, 51.45073367703346, 73.74341472502678, 65.23052215576172, 69.92620329703055, 63.61327402053341, 69.69893332450621, 70.96600009549049, 67.86713938559255, 1.3674029611772107, 0.39779026602064416, 2.1662887642460484, 0.14312042344001033, 0.08356467925853307, 30.214968612117154, 76.63198932524651, 63.05454023422734, 64.93553246221235, 59.836196284140314, 53.90258765989735, 25.881316354197843, 21.07401828612051, 45.12067540999382, 67.611934292701, 45.71827988470755, 0.11519829592397136, 0.053640369461068226, 0.04419673084011001, 0.054103442798218424, 0.029539630237606265, 0.02911380792577421, 0.13541198545886626, 0.05598992665087985, 0.0367516968699713, 0.041920587856082187, 0.04381199765409674, 0.06133474206792251, 38.88097678461383, 77.2194113269929, 53.305053787846724, 47.85910168001729, 27.23101765878739, 47.49292881258073, 56.429700159257465, 70.08794615345617, 71.67310930067494, 69.61255488857147, 58.30749565555204, 0.7087440368148589, 0.1575949806119165, 1.2315140400202045, 3.5511698069110995, 0.4760864743542287, 7.13419710436175, 51.72725292944139, 58.65067166666831, 61.08640078575381, 61.12343188255065, 63.40166607210713, 63.5842445588881, 60.72318538542717, 58.062272994749016, 56.764031225635165, 56.17954707914784, 56.230753621747425, 52.75928343496015, 52.968153569006155, 55.869507251247285, 59.066713548475704, 64.88412980110415, 63.1174668189018, 61.90827461981005, 59.097272734488214, 57.673232709207845, 57.05176845673592, 48.84444813574515, 47.65265164836761, 45.39172687838155, 44.723280475985625, 45.663233341709265, 46.21558543174498, 49.310300196370775, 53.37965726852418, 57.12026872942525, 52.230885259566776, 48.192742409244666, 52.63957661967124, 62.610625989975475, 59.283750057220466, 51.33201922139814, 50.602054365219615, 41.680219404159054, 42.11659093056956, 43.24244453061012, 44.8371272702371, 41.38544936333933, 44.51095473381781, 40.95893475317186, 49.9258848159544, 49.310017785718365, 42.2528854493172, 39.691664018938624, 41.12916169628021, 45.532979273026996, 42.347183150629846, 40.79124558356501, 42.65099817706693, 42.54349385538409, 43.05173104809177, 41.65410426355178, 39.23345665777884, 40.732810112737845, 40.572589135939076, 41.79514092783774, 42.367195083249, 40.399369424389256, 43.4947156906128, 42.819381606194284, 40.93500045038039, 42.370395737309615, 44.66890073591664, 45.32272061993999, 41.15260570280014, 40.25492422042355, 41.620975925076394, 41.96310466335666, 42.12299223869078, 43.72361736912882, 45.372742606747536, 40.34583691627749, 41.307092174406975, 39.03556916021532, 37.24601522568734, 39.52386110059677, 41.516660490343654, 38.99013242413921, 37.988594424340036, 37.41717569289669, 38.45951810959847, 37.143900240621264, 40.439432513329294, 45.73355751652872, 42.10216445307578, 43.46590195932696, 41.40668899782243, 42.40405751812843, 40.94604192241546, 41.536288030685924, 42.15049197596889, 40.91361176583075, 41.90843466789492, 44.22664957661783, 44.65964001993979, 46.69763688118228, 51.60049369258266, 55.9843973959646, 55.476219038809504, 58.447971420903365, 53.86309723700247, 50.577668989858324, 51.93335387014574, 56.042970149747795, 58.05218073629565, 59.402684165585434, 58.66883224056613, 59.17088385551207, 59.28824901580811, 62.85766078579811, 64.41239026284987, 61.63172398844073, 60.21346161442419, 63.43962284826464, 60.66082362205752, 60.6843735325721, 59.29305784163937, 62.77412214586812, 50.60138756229032, 52.596740415019376, 77.06119075898202, 68.92434366287725, 73.72814886031613, 65.38979391897878, 73.17171358293103, 73.59707893863802, 70.55790885802239, 1.8432657685010665, 0.5539210381046419, 3.8325780485906913, 0.047861120903924595, 0.12339853936986578, 33.405128371331, 84.51714577213411, 69.47143585451188, 73.30221868330433, 66.54008388519287, 59.4758402916693, 21.749405322536347, 28.75797283264899, 52.07456704108946, 77.31295985560264, 53.257487204767045, 0.08329579771886911, 0.07258312296002142, 0.02913724447059776, 0.037821059851276304, 0.031164728720942815, 0.22729784280302065, 0.22375597318093624, 0.16289198831204446, 0.13526635214446053, 0.14475016824660764, 0.21889249463715862, 0.188135213609184, 50.84111106011176, 86.74888810803814, 63.317460629247854, 49.82668415192635, 33.89781728867562, 64.47625037162535, 66.46057744180003, 76.24205866167623, 76.20225444916757, 75.95348988809894, 63.48218056463427, 1.189837386050532, 0.4420650612202383, 2.361461001057779, 4.096210353797482, 1.2329750003353244, 8.328720619601588, 57.82481662688717, 63.29123958464592, 64.26968659124067, 62.14255779020248, 66.69822600580031, 66.66167736053467, 65.44715466037874, 62.26067212320144, 59.352677868258574, 56.248047351837165, 56.83699123321041, 53.98849148904124, 55.49988662042926, 56.22348546981812, 61.07572801651494, 65.79184470638153, 66.01164648609777, 64.83163279871788, 61.96154432912027, 60.67750546240038, 59.58518420496295, 51.612288259690814, 49.011411666870124, 46.47314394673994, 48.279105155698716, 48.048960085838075, 48.50069553621354, 51.578928501375266, 55.87504956030077, 60.51915153380364, 52.68538598091372, 53.9422232104886, 56.18197110391433, 64.64920336200346, 58.70509847517937, 54.05986685906687, 54.225163382868615, 45.429813092754735, 43.351623704356534, 44.889565437070786, 46.334837252093905, 43.86459912023237, 45.877029972691695, 44.51851706351004, 52.06159576292961, 51.692194784841234, 41.19485747429633, 39.788189626509144, 41.61310372814056, 44.75695402391496, 42.514272197600334, 40.210872081018266, 43.342935654424856, 44.29416141202373, 44.08422047092069, 42.979151510423236, 42.81216444507722, 44.53393197828724, 42.27124606409381, 43.95544121342321, 44.9261180047066, 42.76018519555369, 46.089897001943285, 46.368891269929954, 42.09015807797832, 44.535536227687714, 47.83747765325731, 48.67830045761601, 44.368788426922215, 42.70568386200936, 45.93259426855272, 45.97668563165973, 45.40494918823243, 45.931535228606194, 46.082817123782256, 40.22024262335993, 41.48889010952365, 38.32600847367318, 37.093909632775095, 39.0216447461036, 41.15703798109486, 40.16418410885719, 38.23227559366534, 37.563303593666326, 38.585732137003255, 38.36575777299943, 40.89991092681885, 48.31883484317411, 44.20834387502363, 44.76327688463273, 43.998320564146965, 44.28425350496846, 42.847140219903764, 43.99158193219093, 43.5515861357412, 43.713638859410445, 42.51018116551061, 47.084331589360396, 47.1087718779041, 48.28711855796076, 55.31802200501966, 59.9550990135439, 58.46415512023434, 62.135740710843, 57.777097071370775, 51.84837572036251, 54.54428742008825, 58.89373310150639, 59.06301083103303, 63.20593587813839, 60.76589215186335, 62.393154098141586, 61.07514750572943, 66.15228699099633, 67.83679592993953, 64.82288199086344, 61.853773286265714, 67.57752726154943, 62.229140189386186, 62.52757372394685, 59.85602778773154, 61.64623283570813, 54.51430482249106, 56.13897015971523, 76.85073206501623, 74.26548219496205, 77.72989211543914, 68.42945821823614, 77.87309000569006, 75.00647283369496, 75.13438916975453, 2.454125035193659, 1.8486607435249516, 8.79281153601985, 0.25157895359781485, 0.16073730473797168, 34.60291039559149, 91.89347667078819, 74.41097859413394, 82.77460928886168, 72.62608835774084, 71.03981910213348, 39.304883018616714, 37.39727358664236, 61.72003223050026, 88.47880240409606, 67.11006702915316, 0.3866423077640995, 0.2443275636722965, 0.15376769727276218, 0.13488571369840255, 0.1546369006316508], [0.06877581919393233, 0.055715353077938484, 0.05143056586084347, 0.08486440870910884, 0.006287754738643285, 0.06124203010732609, 0.06993922329838238, 33.884202741807506, 64.28052410002678, 45.92198425723661, 38.51410573528659, 20.980032413236557, 36.876053348664314, 49.93325887187835, 65.948849339639, 67.66677687245031, 66.9317090126776, 55.50115354599492, 0.4435934679162118, 0.1772440633466167, 0.3472806795710518, 2.3979307086237016, 0.08497503946625418, 2.091601197758029, 31.7754110213249, 54.49556766017791, 61.05140147670623, 61.719455642084924, 62.29567927698936, 61.700000686030236, 62.20044020683535, 63.44678901856946, 57.634291418137096, 54.33456613171486, 51.80361363195604, 55.59768699830579, 58.107223356923754, 60.306551225723766, 58.821235933611476, 56.92722535902455, 58.761353108190725, 57.20482718560004, 52.664381688640965, 48.62221448652206, 45.31118885163338, 44.23294890311457, 44.78898409874209, 43.14767614487679, 44.063251479979485, 42.03186773484753, 43.62423235370267, 48.41457205434, 50.519598299457186, 51.016225276454804, 51.147240284950506, 53.79292603461973, 47.698033471261304, 41.772567687496064, 54.00457712911791, 54.48196488042032, 48.52404932821951, 44.204343057447865, 40.92001307395197, 41.727672238503736, 38.6667683047633, 41.28103194698211, 40.99474599284511, 41.357988849762954, 43.183110837013494, 52.05233504695278, 43.553076636406686, 39.67709241374847, 42.001316393575365, 39.394705295562744, 43.645750476467995, 42.72140864403018, 38.769738366526944, 40.09500134375788, 38.2729309605014, 41.5575158980585, 41.88337464486399, 39.61531900590466, 40.04163749756352, 37.76058704622331, 39.00849696128599, 40.46394732690627, 40.91188592295493, 40.777219187828806, 39.270899603443766, 41.85550620478969, 39.97534944165138, 40.39266609376477, 40.450681870983495, 39.16242645632836, 38.786228010731364, 41.29898855763097, 40.78945698276643, 40.20461982296359, 41.860228738477154, 38.59696972754694, 37.49478370912614, 38.392767214006, 40.17241716384888, 39.8110217432822, 39.53626755745181, 40.71603805788102, 38.22530946423931, 37.63978196728615, 39.51986812776135, 37.511355723104174, 46.43002925380584, 41.91780128786641, 38.482134496012044, 41.28672330610214, 40.182097573434156, 41.7260052311805, 38.492901402135054, 41.26984142488049, 40.80830004907424, 41.19990948707827, 39.679539972735995, 46.48625643022599, 49.80855495698991, 47.6118197748738, 49.85279929253363, 55.00416178857127, 55.28198719024659, 54.94590282440186, 54.50246710931101, 53.56447542867353, 51.475119052394746, 47.95953004590927, 49.620547909890455, 53.00016010961225, 54.60015766082272, 55.8321858990577, 56.257602245576926, 55.88818165563769, 56.80680859473444, 62.731556584758145, 61.46280319459977, 60.5003555359379, 61.86472454378682, 63.502514131607555, 63.999933427379986, 63.57606641707882, 51.98685107692596, 51.685401239702784, 63.36225409661571, 64.6807627524099, 72.07411673761183, 64.84111708979454, 68.25263777086812, 70.91296965076079, 65.47612136410129, 1.1156186653721718, 0.2211367185678213, 1.622275633196677, 0.11027353800713055, 0.17500233686258718, 26.449357924922822, 76.93215262505316, 64.48367149599137, 66.87051219324913, 53.63944368977701, 40.1214930319017, 20.55210574980705, 29.12275325867438, 49.210770053248254, 65.40898215386176, 49.32809991221274, 0.42182143296926256, 0.09528151908588987, 0.01644085014929935, 0.049280157057388176, 0.052307238576993834, 0.022702339563458677, 0.007596542700118716, 0.027030309241625573, 0.041652905244019725, 0.10845571095424314, 0.031610419523091085, 0.006357087611010479, 43.79796981811524, 71.98205086492723, 52.93474674224854, 38.81819925000591, 25.58110010239386, 47.42937072630852, 54.92887973785401, 72.89368029563659, 71.63987113583472, 71.68897136565178, 59.779376829824145, 0.5284373378080707, 0.20747619110249704, 2.2887071630647107, 5.908983494004896, 1.3847763644110773, 1.8932602987174068, 37.315194068416474, 57.85685062408448, 63.79618590877902, 62.79017640698341, 64.42731095898536, 63.176365129409305, 65.75636294580275, 65.42440883574947, 59.096272530094275, 55.03706262957666, 52.83173745678317, 56.3027604933708, 58.46464541650588, 61.273462541641734, 61.470447894065614, 59.57254632826775, 60.79835760977961, 57.34341236852831, 53.1692103416689, 50.90641460111065, 46.037180346827355, 46.41712465593892, 47.55081515158377, 46.95002178991995, 46.30876917992869, 45.824325084686286, 46.333499723865145, 50.397318409335234, 53.9850398032896, 52.77099955466486, 54.4433726802949, 55.72346172025127, 48.67668051873484, 46.396594970457016, 56.87207291203161, 55.77238544341057, 51.87449870571014, 45.62789670882687, 41.99374229677262, 42.71331287199452, 40.986987544644265, 43.35148249903033, 42.89838990857525, 42.823107857857984, 45.822920876164595, 52.96144239364132, 43.14178866724814, 40.74804067611694, 40.664070575468, 39.76675387351744, 43.78782656884963, 42.30147969338202, 39.95605922514393, 40.026748180389404, 41.45200414042319, 42.52874966590635, 43.41114567172143, 41.816211900403424, 42.31875773399107, 41.08376418390582, 41.82244454660724, 41.60532566808885, 43.57996840630808, 42.53304073887487, 41.81301909108316, 43.635391496842914, 43.34308862686158, 43.25200726909023, 41.326413769875806, 41.14847544700869, 41.52809027702578, 42.012173514212336, 43.96928718013149, 43.615634518284956, 42.523446621433386, 39.37722721407491, 39.08669333304129, 37.800669747014204, 39.83270460559476, 38.67331081821073, 38.45628999894665, 39.02639865875244, 38.363059182320875, 37.48425214521347, 38.64066885363671, 35.83518182077716, 46.970661301766675, 42.820095477565644, 39.74342753810268, 43.496492524300855, 40.789806073711766, 42.07284081366755, 41.98848632074172, 42.73203434482698, 43.1244949371584, 44.10236927770799, 42.058845796892726, 46.84574557888893, 51.07625322957193, 51.03279729043284, 52.51067184632825, 55.96166726081602, 58.23058582121327, 56.290569766875244, 57.78488297616282, 54.8760611011136, 53.85360117881529, 51.5616661502469, 51.89574618493357, 55.56608446182744, 56.42564442849929, 56.98962242372575, 57.634079610147786, 59.53879433293497, 59.98037868930448, 63.80514067988243, 62.531719669218994, 61.73190916738203, 64.1402836768858, 64.66907801166658, 67.17172668826196, 64.87741078099897, 56.058589027773955, 52.2621504722103, 64.31573129469349, 66.33059793902983, 73.07223443062075, 67.73694807483305, 72.34174005446896, 72.47003293806507, 68.73839193774809, 1.0093794919310077, 0.5256139054413765, 2.2297970854466964, 0.09868889431198759, 0.10928666354307245, 27.953522166898175, 85.54172377432548, 70.7606718617101, 75.26370971433579, 62.24550039537492, 52.30604179443852, 30.225090288346816, 40.793959863724254, 56.313817654886556, 74.87237484224381, 59.463084743868926, 0.5772807749529039, 0.089312338180119, 0.07169318926190177, 0.019851896851774187, 0.06163794434659424, 0.13273196475159738, 0.18448195480290921, 0.12936670903957662, 0.2184281993897692, 0.2304965969655783, 0.17190086054465464, 0.18909126069516907, 53.060470473381784, 84.0279712984639, 61.14806828960296, 53.34932557998165, 30.657580629471813, 50.094954659861905, 65.16139038147466, 75.84141208279517, 76.94762245301278, 79.00491345313289, 65.31596314522528, 0.7291739470055028, 0.6201950592860099, 2.550204963453355, 7.411655274129684, 1.3899345263358087, 2.767842330278889, 39.394932793032744, 61.55631642187796, 64.1865441106981, 65.97501154868834, 67.1216066422001, 67.5296272770051, 67.83857668599775, 67.9374361038208, 60.743075724570986, 57.63740970242409, 54.73940572431011, 58.38556258909164, 59.07615861585064, 62.4579712652391, 60.57462169278053, 62.531170537394864, 64.8785835696805, 61.798071707448656, 55.75500149880686, 54.78247727117231, 49.24280012807539, 49.244694632868615, 48.56623834179294, 48.85779988381171, 48.79455950952346, 46.863459002587106, 48.294112143978, 53.91103644524851, 58.53863308506628, 56.1401076470652, 54.76370872989778, 56.846346086071385, 52.015790324057306, 55.53070860524332, 57.7450160057314, 56.62526169130879, 54.25560489777596, 47.69156548284715, 45.071928193492276, 45.85457048108501, 42.66263977173836, 45.7963115169156, 46.815594319374334, 45.48753076984037, 48.75495926026375, 54.15601591910086, 45.15672983661775, 40.01882107027116, 42.55626117029498, 40.03500476960213, 44.518897533416755, 42.957370588856364, 40.26753464052754, 41.04659972652313, 40.526681715442294, 43.961932736058394, 45.91173902634652, 44.18512736597369, 45.844901838610255, 43.00325447513212, 44.65211299157912, 45.4172654305735, 47.651929932255904, 45.38758877784976, 44.75736195041288, 45.177753740741366, 45.24749740477532, 45.42882073310114, 44.02960146627119, 42.763346625912575, 44.05155497212564, 45.38442734749087, 44.44203084514987, 43.97803798798592, 45.62156208099858, 40.87025388594597, 39.48609259820754, 39.26190953100882, 38.606269667225504, 40.11849241871988, 38.550250376424486, 40.69986220329039, 38.930135849983465, 38.9215301698254, 39.0867482462237, 36.81565277038082, 48.8075739337552, 46.14373153255832, 42.801840766783684, 45.59844755357312, 43.76418644382108, 46.03987893750591, 44.567609448586744, 46.88523207941363, 44.14660969088155, 46.43039403423187, 42.999728264347205, 48.83043350711946, 55.39187631299419, 53.94541209743869, 55.03347758323916, 59.809508477487874, 58.64201891806818, 57.810292090139086, 59.884629711028076, 59.538747264492905, 57.41961225386589, 54.811479276226414, 52.993166523595015, 59.317266710342906, 59.467383661577784, 60.56084632873536, 61.00641973557011, 62.70805374268563, 62.798715406848544, 67.0025234837686, 65.63222385221913, 65.50564896675849, 68.24050195755498, 68.93937418537756, 69.80340173167568, 67.33094353829661, 58.011592049752515, 53.00870695421773, 65.75849279280632, 67.46719098860218, 76.0170401296308, 71.42527826370733, 75.18451706055673, 76.19624537806358, 73.23279273125434, 1.8289808640556953, 1.565092011324821, 6.730808298433981, 0.4574038575012838, 0.3882818584961276, 32.41145276254223, 91.78452107214159, 76.85605864371024, 83.75180505937146, 70.19280679764287, 54.52161219812209, 34.23742002056491, 47.782611539286954, 67.81858044285929, 84.85566985222601, 71.36177509061753, 1.4855019724176777, 0.27965432934222684, 0.15753714097363336, 0.15623736555778212, 0.21651964454400927], [0.027220067305250034, 0.08311047338910642, 0.04807333491982953, 0.05449525463665205, 0.011907670414075257, 0.14660198662069537, 0.10748146928005642, 31.99005880663472, 65.43454031790456, 54.83109897182834, 38.196935038412775, 11.087771692583638, 39.91502731077133, 48.99347074570195, 67.37135179581182, 65.24845523218956, 63.37410749927644, 55.649952580851895, 0.9785078646194552, 0.11796144483190392, 0.2930838506548636, 8.1750843217296, 0.9205118831126922, 0.337438227068032, 34.84557567104217, 60.08656901697959, 63.391232567448775, 64.42913486111549, 62.919218463282434, 61.38005295107442, 61.839844949783824, 60.831340820558616, 58.02965064202586, 58.28837802333217, 62.87085956142795, 62.429439944605676, 61.37075693376603, 59.29255185588714, 58.167945569561375, 57.50574750284995, 55.69160815208189, 50.573923126343765, 44.2321801185608, 42.163106318443056, 42.40960767192226, 42.93243608167095, 43.13597963702294, 43.79598117643788, 44.5187484833502, 43.79360422011345, 43.66235779177758, 45.98220832886235, 45.79089080133746, 49.768413420646425, 50.68615390408424, 49.330802425261474, 53.94378431381718, 53.563239882069254, 42.72795507984777, 50.68417702951739, 49.4349648875575, 41.40287645401494, 41.07374252811555, 39.56122167648808, 40.14105389195104, 40.782573223114014, 40.103187330307506, 39.9590245369942, 39.04070354277088, 52.168903966103834, 51.98121855335852, 40.95786394611482, 38.90551121004167, 39.34273781314973, 40.79081412284605, 41.56329354932232, 39.00422157779817, 40.5952408236842, 39.81647776019189, 39.39990243604107, 37.05450550202401, 40.28558146569037, 40.11676657584406, 38.271279642658854, 38.588709215964045, 39.78057238363451, 40.35195973611648, 41.698042654222064, 38.90973560271725, 40.22654979459701, 40.723769049490656, 41.02843523025513, 39.09746416153447, 38.473822993616906, 38.83150785200058, 41.152786131828066, 40.75814077931066, 40.772033814461004, 41.582375880210634, 39.30339251795123, 37.259743521290446, 37.982106824075025, 37.0862296319777, 39.64199112307641, 39.04331584130564, 36.613493811699655, 38.403224252885394, 39.118025225977746, 37.805427582033225, 43.548479618564734, 49.40654339328889, 37.74856890401533, 40.36316594769878, 38.641174839388945, 39.77266488536712, 39.851261338879986, 39.915015543660815, 39.7559634331734, 40.15690418981737, 40.399212529582364, 48.35088060748193, 51.4650385610519, 51.174641962974306, 54.18361371563327, 53.21162685271233, 53.48762050751717, 52.41360102930377, 56.86817015371015, 56.7202889534735, 55.07662757750481, 50.01094141314107, 52.478414274031124, 49.24991922993814, 49.09271847817206, 46.777692456399244, 50.86592005145166, 55.1685953909351, 53.6720895767212, 52.037418273187455, 56.90093763412968, 59.03022766113282, 59.170993681876894, 58.91479230696156, 59.21371221542359, 62.61942778864215, 62.706735826307735, 63.784646295732074, 58.89933424611246, 55.005977845961056, 79.93308744122906, 74.68352840792748, 63.738075994676166, 68.99872749082505, 73.31582930780226, 60.97430336859919, 0.7170064482958086, 0.20693513384509474, 1.5969257224952023, 0.1400392944173467, 0.27232856760101937, 24.38319452347294, 77.34703740765973, 67.33134362005418, 71.81653468839585, 57.26123086867794, 50.02943146613337, 15.746971849472294, 12.428638838952589, 37.743940507211995, 63.56553093079598, 55.371401540694706, 1.303547632790381, 0.03875055816024542, 0.0795241247021383, 0.018592544065247622, 0.028175394268586274, 0.03413761335034524, 0.09594398595753217, 0.019257768853417328, 0.090979399129508, 0.03392919913054474, 0.11341825232750948, 0.10136953555047513, 41.530906538809504, 75.09922904352989, 57.38062389435307, 42.48825119387719, 18.52746455900131, 42.2046559856784, 55.442718075167754, 72.39167967150289, 70.8688900547643, 67.9329018439016, 59.677508954078924, 0.8396294845208045, 0.13470850223975797, 1.9762689283778592, 11.24194045220652, 3.2446309395374793, 0.39012325807444515, 38.398858654883604, 58.27833675569104, 64.9563249464958, 65.73719432277065, 67.18935381981635, 63.44162325705252, 64.71439315426734, 63.94890339143815, 61.509667673418605, 60.22123967447589, 65.76534909586753, 63.06411081744779, 64.75183217756211, 59.82616286123953, 58.52091573899793, 59.792179446066584, 57.98524941167524, 52.21536836316509, 47.67106717632663, 44.691050360279704, 45.66605744823333, 45.756173902942294, 46.94302820390271, 45.69185487685665, 46.23085914119598, 46.03456020355225, 45.36968708038331, 46.47484625539472, 48.80703656904159, 51.73128120360836, 52.03341353324152, 51.503163999126805, 58.51349069226173, 53.76436333502493, 45.63259178592313, 54.5355523017145, 51.74276590347291, 45.262261206103915, 43.54989559419694, 42.27379168233564, 43.10757383223503, 42.85372587942308, 42.548141864038286, 41.49253006904356, 41.76142815620669, 55.0887280894864, 53.627904076730054, 42.41903312744633, 39.64235982587261, 38.964648785129675, 40.442535108135594, 41.838651780159246, 39.68854573465163, 40.74607949103079, 40.08836861579649, 38.607928829808394, 40.11491129475255, 41.649821035323605, 42.67649358318698, 40.15862611032302, 42.06193662458851, 41.67065274330878, 42.92170447687949, 43.33112932020619, 40.650946324871434, 42.163694673968905, 43.39878236093829, 43.68833564942883, 40.75567360847227, 40.280615745052216, 41.46582657291044, 42.14357683735509, 42.22655065598027, 40.635056803303385, 42.28848095863096, 39.191083292807306, 37.36634962020382, 38.12916824894567, 38.413351812670314, 39.06168037845243, 39.648435577269524, 38.21164000418879, 37.878116946066584, 39.61982188686248, 37.81648082117881, 45.28958051435409, 52.279703078731416, 39.789130995350504, 41.59161698433661, 41.869285491205034, 40.79660746359056, 41.69113536034861, 42.62222759185299, 40.84878675399288, 39.79342991305936, 41.61345674145607, 50.25617976342478, 52.75591411898213, 52.69432114016626, 57.01357241599791, 54.74951367224417, 55.66628140787925, 54.309757140374955, 58.790982692472404, 58.32054930348551, 56.60176277160645, 53.025094616797666, 56.35646950814032, 51.70020034236293, 51.495942915639574, 49.057997657406716, 53.402163828572924, 58.547521175876746, 56.616448125531605, 56.687992157474646, 59.46605397808937, 59.829136017830145, 59.78648416457638, 61.218121820880526, 61.43636641963836, 64.25928838791387, 64.3412188560732, 66.00703377877512, 59.78873952742546, 57.9441390498992, 74.75071076423892, 75.58946255714663, 67.9951577032766, 71.10416166244015, 73.33725329368346, 62.83655451190088, 0.8589745529236332, 0.563500140222811, 4.424937088643351, 0.04062471182776555, 0.25319981178449047, 26.382303045641994, 83.53429394383585, 71.46108165864023, 77.27546984149565, 65.03347404541509, 50.42937986312374, 21.17326797977571, 24.06842431714458, 46.75888861379316, 73.44485959699078, 65.32161135827342, 2.095306121533917, 0.07652626943684394, 0.18381335922787267, 0.03404765547583661, 0.17196538046963755, 0.17555917553122968, 0.22169501280351994, 0.14597941760814961, 0.2649999866562505, 0.15604694674332298, 0.20162471960629189, 0.14593601106635987, 51.156975607718195, 83.83770496614518, 68.59335053351619, 53.09653666711623, 20.19143008416699, 49.963061040447606, 65.58557510375977, 77.69457509440761, 77.99773508502592, 73.9444754200597, 65.69921793476229, 1.1412900878537087, 0.2920827575989308, 4.847663669816909, 21.436500203224924, 3.034772368208055, 0.4477721404644751, 42.787324074775945, 59.224561491320216, 66.48009515577748, 68.18547894877773, 68.83347803546538, 63.39592764454504, 67.75997238774454, 66.56309250862368, 63.04894693436162, 60.75686285572668, 67.29678753883609, 64.58140519357497, 67.5073560591667, 62.6859551091348, 62.41126368122717, 62.104718685150154, 60.856765624015566, 53.39065167211717, 48.8228476432062, 45.616937606565415, 48.10729357504076, 47.8754501188955, 47.784105962322606, 47.51261518847558, 49.4085830257785, 49.225278900515654, 48.512588162576, 48.96091507327173, 49.91782434525029, 54.67103881220664, 55.45144534880116, 53.578568504702666, 60.39564786418792, 56.52429988307338, 50.34506851626981, 57.268298979728456, 54.477928761513006, 47.17624448960828, 47.08049551133187, 43.8441635716346, 45.05977669069844, 45.17276056351201, 45.102240270183934, 45.27876261741885, 44.03334340741558, 55.991163484511844, 55.878599305306714, 42.024885915940814, 39.019526666210545, 39.77548114715084, 40.290876665423, 43.24164436709496, 39.415278127116544, 41.47613063935311, 41.10077942571333, 38.79304509009085, 40.0664347217929, 44.05535967119279, 43.85901758747716, 41.843503752062404, 43.267096627143125, 43.8744991825473, 45.828074870571015, 46.5404910425986, 44.44417638163413, 43.89888063553841, 44.713478472925004, 46.32792995822045, 45.46791891897879, 42.79829102177774, 42.438358645285334, 46.98163217113864, 45.097976653806626, 41.369289198229396, 44.73115659529164, 38.51306630719093, 38.26789855957031, 39.31550087467317, 37.25431496097196, 39.77916817511282, 39.71029919962729, 36.83662960606237, 38.693589472001605, 39.7404347696612, 38.22727457169564, 45.79321284447947, 54.323179491104625, 42.871937444133145, 43.22074990118704, 42.766610037895944, 42.65445770755891, 43.97992857040898, 44.91133066915697, 44.67982453684653, 44.33293796354725, 44.78513233123287, 53.935900349770826, 56.41314775713029, 54.98127868098598, 59.003351580712106, 57.86603681502804, 59.02186516792544, 57.96710060488794, 62.090033331225, 61.13561868667603, 59.09104008828441, 54.23696971708729, 57.4384553201737, 53.70897162345148, 53.234435435264345, 52.39664854541902, 57.23436263299758, 58.94921110522363, 59.094436860853634, 57.574341912423414, 62.94163480881722, 63.0943875928079, 64.14578676223755, 64.01228104868244, 63.028946768852975, 69.50847871841924, 67.89512157440186, 67.25183717666134, 61.17065329705516, 58.52931353353686, 72.45905814632293, 78.5590733251264, 70.09085655212402, 75.20557234364172, 76.28382405927105, 68.68251385227327, 1.1229369500952384, 1.7101851418133707, 9.55554485321045, 0.36714644261425544, 0.40555092055470715, 29.33245493519691, 90.62803376105525, 77.80986139851233, 85.47301953838718, 75.5744634136077, 64.29209509203511, 22.941731329887148, 27.48737788969471, 59.82391534313079, 82.40113689053445, 79.48968702746977, 3.932855893527308, 0.2786079145246937, 0.24461800292614969, 0.2300581648465126, 0.24859999006073324], [0.017168886486380812, 0.0647996160231771, 0.038860143207374125, 0.12185887884228461, 0.07417471658798956, 0.12135542884108522, 0.18966303807833504, 27.775156305682277, 69.88075087147375, 53.968526624864154, 35.81047088869157, 29.70180492247305, 44.770650940556685, 45.406867227246686, 68.87183881575062, 66.83740738899478, 63.50635805437642, 56.849589886203894, 1.005917816392837, 0.0026489579965615828, 2.2175264406588773, 3.4369763731956486, 4.00910627938086, 0.5603484545023211, 29.547638124035252, 59.70837016259471, 65.07981292663082, 62.7639239834201, 61.917488267344815, 58.59060448984946, 62.96825201280656, 63.59990266061599, 66.09555382882395, 60.493675739534446, 58.406747310392326, 58.481362558180294, 60.523505364694905, 57.79321016803865, 56.86409481110112, 51.47496607995803, 47.719708488833525, 45.72462235727618, 39.43456049888365, 45.382462240034535, 47.61549503572526, 49.47844436091762, 48.07653434814946, 48.22189738673549, 48.1353699007342, 46.971551679795795, 46.49086129280829, 49.15340931184831, 52.341264678585915, 51.07162091039842, 52.78755980153238, 52.61808203112695, 48.95847535902455, 51.22065136509558, 47.916999786130845, 47.676385910280295, 51.20625626656317, 41.97434617627052, 38.73843785255186, 40.10653703443466, 41.91874657907794, 39.187357041143606, 41.84111502862746, 39.7300208768537, 39.57543242362238, 46.018784430719194, 54.1194123606528, 48.34696608204996, 40.95798553959016, 41.07966922944592, 40.540037385879025, 40.213233347862, 41.553903395129794, 40.09290287571569, 39.845860235152706, 40.38350735941241, 37.726686000823975, 40.85485073827928, 39.96375099305184, 40.072059400620006, 37.574345065701394, 38.95073221575829, 40.68801664536999, 39.16282261571577, 38.887899767967966, 41.71091979549777, 39.39377961620208, 39.5701019225582, 39.728353869530466, 40.18956184387207, 39.51156839247673, 40.97965663479221, 39.772178511465754, 41.358753711946555, 40.25060569086383, 38.99055211774765, 39.426060722720244, 39.45061475999894, 41.3312029838562, 38.38385166660432, 37.9693865776062, 39.01247032227055, 37.39455146174277, 37.84904433834938, 42.05138544882498, 53.235396415956565, 46.86488674532983, 38.015180249367994, 37.92333795178322, 39.946210153641246, 39.86524851091447, 38.80588300766484, 40.43834601679156, 40.499354562451764, 40.70909546267602, 42.58384327734671, 48.38753907911239, 53.37306376426451, 47.550862220025834, 49.58785887687437, 52.926827476870635, 49.84660194766138, 48.70378409662555, 52.51784193900324, 56.55841273646201, 54.38407036565966, 55.751338005065925, 51.79997759480631, 49.91312926815402, 49.88695921436433, 48.35119831946589, 52.95741411947435, 50.52724299892303, 48.7657065545359, 50.72602087451566, 48.83911763468097, 53.34208488464356, 53.31004696507608, 55.95963155069659, 58.99982929229737, 62.187704270885845, 62.85305592321581, 66.63774305774321, 60.63796012632309, 61.582529621739546, 43.490040225367395, 59.11645704700101, 71.10689947682043, 68.72405959713844, 76.50191568559217, 51.974126908086966, 0.4197569179438776, 0.1375152798549783, 2.386125109849438, 0.14516232354987055, 0.25883300950930965, 22.849977285631244, 80.73441982269287, 65.30860085641184, 76.15597048113423, 57.47813009446668, 54.07569754508234, 29.952630689067227, 29.00557637214661, 39.374450175992905, 62.436249179224816, 59.43567522110478, 1.0959561914205551, 0.17475660649999497, 0.08814030792564155, 0.12495458651814731, 0.044241933858082186, 0.056202791841520425, 0.05602228620480146, 0.01436602549567338, 0.1772631389359313, 0.022985929991268826, 0.17197763787642603, 0.12526237766348547, 38.15877429900631, 79.74304076164, 62.082576905527425, 41.64170172906692, 21.57692890013418, 49.68161136873307, 52.066047653075195, 74.33960714647847, 72.76004514386578, 70.24724929563462, 61.46847101949877, 1.3458590978576292, 0.21237670233653438, 1.73780647256682, 7.620822527716237, 6.33876298704455, 0.4463373497128487, 32.65202349232089, 59.81742382049561, 65.36216866585517, 65.59203916980375, 62.64698243910267, 59.89995048892114, 64.99485438869846, 64.27388352732505, 66.22706305596137, 61.942693418072125, 62.35641717910767, 59.92082926534838, 59.58747094677341, 58.80612304133754, 58.572247797443026, 53.92143072620515, 49.96980751714399, 48.261505480735536, 41.934643945386334, 47.45327365013861, 48.59374592381139, 51.062524933968824, 52.56462797041863, 51.35308234922348, 51.41868399035547, 48.33397519203925, 47.92603300463769, 50.108141668381236, 52.78585357050742, 53.31615017306421, 55.99054767239479, 54.768827422972656, 51.17599125831358, 54.534195161634884, 51.42236709594727, 50.75476008076822, 50.856749549988784, 46.01171631966868, 41.21660309453165, 42.53080498787665, 42.70500529196955, 41.55674711350472, 42.92277528393654, 41.93022735657231, 41.96046490823069, 48.53775801197175, 56.24426618699105, 49.477777557988325, 42.78736329847767, 39.80606386738439, 40.20045818821077, 40.55409123820644, 42.718313893964215, 40.228436454649895, 40.750802024718254, 40.10079076213222, 38.07697326906266, 42.617654108232074, 42.607812881469734, 42.144765315517304, 40.18601209886613, 40.996432612019206, 42.71019458770753, 42.53685328268236, 41.21159030545143, 43.2963300520374, 42.74868088383829, 43.81266301678073, 42.99328381015409, 41.67262569550545, 43.74563363290603, 43.21062626377229, 42.464261977903305, 40.96556355876308, 40.01724819983206, 38.670259214216664, 40.45938561039586, 39.21755144673009, 40.649212637255275, 38.541197546066776, 37.772358079110425, 38.30779298659294, 39.0179184944399, 38.34422396075341, 41.34667281181582, 55.53878084305794, 50.49686424193844, 39.84285962197089, 40.242247120026626, 42.39824848790323, 40.38961056740054, 42.003705117010306, 41.29400322514196, 42.386602970861624, 43.359021294501524, 43.86263401277604, 51.25486620010869, 55.906981575873594, 50.339592887509255, 50.75854909035468, 54.08643307224397, 51.68284777672061, 50.657198967472205, 53.06329850227603, 57.505006174887384, 57.049669988693736, 57.141680948195926, 54.2557696373232, 52.57077432447865, 53.7889212946738, 50.49049823514877, 55.75997506418536, 55.14062496923632, 51.74823760986329, 53.76036251744917, 52.180792670096125, 55.976686016205825, 55.73301661399103, 60.566310190385394, 61.10273353515133, 63.33675869049565, 64.34207785514094, 69.40495952483147, 62.89055378206315, 63.04971964128556, 42.08254867984403, 61.80952895072199, 73.85886576867873, 72.03618741804554, 76.37863559107628, 54.018646670926, 0.1526731721335842, 0.3912927372561347, 3.335923860149999, 0.12602404526044286, 0.2583786887266944, 26.590143557517763, 85.58079842598208, 71.64406022717877, 83.13646362673852, 68.02546977996826, 52.36844670388007, 23.866651711925385, 29.16277712391269, 44.1358349400182, 72.51242591488746, 69.4221708851476, 2.067304075725617, 0.3296809739643528, 0.05621430997346198, 0.04607013757190397, 0.14192518838230642, 0.22709896637787744, 0.2342618578263829, 0.16317842858693293, 0.2323225981766178, 0.1693475048147863, 0.3152787048489817, 0.1873051726649846, 50.4950991753609, 88.00641567476335, 68.41688309946369, 50.58838098279892, 41.79277573862384, 59.258313486652995, 59.35765143363707, 80.46142285869968, 78.84309999404415, 75.77916406816053, 68.81013208819975, 1.5119849578026803, 0.22348551350014828, 7.8927967336870015, 9.812137484550476, 12.206347334769465, 0.9051010132797304, 36.5505515375445, 59.82524894898938, 69.38271968595444, 66.69195805826496, 67.21166426135649, 61.47031061110958, 67.81935707215341, 66.68865542257986, 70.77605539752592, 65.4264876919408, 64.14701838647166, 62.71994244667792, 63.97063724456295, 61.345167390761844, 61.27920881394417, 56.07879707890173, 51.064929346884455, 49.73685403023997, 43.207606038739605, 51.765448970179406, 50.709974458140714, 54.10918281924341, 54.19615353307417, 53.41677073509463, 54.609822380927305, 50.89022305703933, 51.07286822411322, 53.02451410601216, 56.692773526714696, 55.61037586581323, 58.2093854104319, 57.168141257378366, 55.343219311006614, 57.50634762548632, 53.13842758055657, 55.13753021917036, 55.09846733462427, 49.28174534151631, 43.27650639318651, 42.96303056901501, 45.89636725764121, 42.423182995088645, 46.16335907290059, 43.865728762842, 44.70633583684122, 49.89965200424195, 59.097680660986136, 51.05129518816548, 42.68767233817808, 41.55117734786003, 41.901127292263894, 41.03914330082555, 42.405646078048214, 41.54656464053739, 41.50415597423431, 41.67795619656963, 39.15023180746263, 43.144887339684274, 44.77538916372484, 45.427545962795136, 43.69562733557917, 44.44259174408452, 45.62648073319466, 44.57906669186008, 42.20868425984537, 45.78230081066009, 45.48310241391582, 47.461828339484434, 45.70978795328448, 45.832048231555575, 44.14187539008356, 44.86767861150926, 42.75668251898981, 42.26065958699873, 40.74483217731599, 39.24259578028033, 40.4964873098558, 39.79614027084843, 41.29438761741885, 38.88436571244271, 38.14158255054105, 37.895175333945986, 38.72191682938607, 38.90063570391747, 43.26070316376225, 58.69851281566005, 51.64073328818045, 41.40274309342907, 41.15723802197365, 45.8497969565853, 42.62163923632714, 44.622856032463815, 43.84657975166075, 44.857562818834865, 45.739346934903054, 48.07047036386306, 53.40845923269949, 59.35944003443564, 52.73835366772067, 53.670257829850726, 54.24394369125367, 55.16264907775387, 52.066494803274836, 55.61128977806338, 61.52580822667768, 60.338718583506925, 60.21500310590191, 56.65418524895945, 55.77199712876351, 55.34828701326924, 52.973268339710856, 57.02810871985651, 54.925255467814786, 56.01266984016665, 55.595843484324796, 56.03685517464915, 58.262823781659534, 59.16975421290244, 61.27102282739455, 63.82619988533759, 66.00051479954874, 66.61583269796064, 72.75215333507907, 66.15451489725422, 63.99701518397178, 49.01974278111612, 65.36352580593478, 75.55781687459638, 76.02084482869795, 78.75697258980044, 58.59706855589344, 0.5732593649337369, 1.0701834001848776, 6.65115378556713, 0.3539121817917593, 0.3528975443013253, 28.6747460211477, 94.6381316646453, 76.71883060086158, 90.75573044438516, 76.08547764439737, 72.81429936808925, 41.51188304347377, 45.453841532430346, 57.452160081555775, 82.94071382091892, 83.64325738722279, 4.597448322080798, 0.7194261216828901, 0.311618949617109, 0.23182733765532895, 0.37328813885969503], [0.05294122229961138, 0.07678975005664172, 0.056018735387272416, 0.02648907578400066, 0.01030953631045357, 0.12732939779638283, 0.15254482176275025, 24.2721914475964, 65.8906021425801, 46.277339227737926, 40.408979231311434, 28.043622932126446, 25.799199573455322, 42.83717739966608, 69.9001116906443, 63.862301380403586, 63.540129661560066, 56.77630824427451, 1.884127917789644, 0.16862724427013628, 0.60583415891855, 6.542730648671427, 7.454894012020481, 0.8013785306003787, 13.774466802996974, 66.02771251432358, 60.326202300287065, 63.52651903706213, 59.621450439576186, 55.52887685837285, 57.45140306411251, 56.31457074995964, 56.830029026154556, 56.92327160989085, 57.77460636631135, 55.56856339977634, 54.88475307341545, 52.62690736401466, 47.5311876112415, 46.40652248936315, 42.01473089956468, 41.31707852886569, 44.99788561174947, 48.7023877328442, 49.375858691430864, 49.907916438195016, 50.66239610795052, 51.273752412488385, 50.52959249865625, 52.89185954678444, 51.310654071069536, 55.123346928627264, 51.382017673984656, 54.54296165897001, 55.60386080895701, 51.15413581171344, 49.11006319907404, 47.168109493870894, 48.02600637558968, 48.560272416760846, 46.60767339891004, 41.97421281568466, 39.893030658844985, 40.133303288490545, 39.24167794566001, 39.543461184347834, 39.883640504652455, 37.924844141929384, 40.51578144873343, 48.55974681915776, 52.706256912600615, 54.830267429351814, 43.61674062667355, 40.73229628224527, 38.08824223856772, 40.10701556359568, 40.44234683436733, 42.11823832604193, 40.39511365275229, 40.681764387315326, 40.662156458823915, 36.448424785367905, 40.433156721053585, 39.68295243478591, 39.23823018227854, 38.94317380843624, 42.7945843819649, 42.26708442934098, 41.00974905875422, 42.785049100076, 40.40586486939461, 39.664725180595156, 40.93249405584028, 41.203902459913685, 41.83602771451397, 38.22147338621078, 38.7249017530872, 42.85414557303152, 42.22146726423695, 38.73161292845203, 39.32245131461851, 38.86401645598873, 37.68417143052624, 37.98263634404829, 38.34234906781105, 39.91935760744157, 38.26453316596247, 40.3023809771384, 48.8311787574522, 52.92050853852303, 48.531411617032944, 38.84369073375579, 39.77220204568679, 39.949834423680464, 39.83200642370409, 38.168125229497115, 39.976914467350134, 38.9095865526507, 40.87125016796974, 40.715218282515, 44.647865064682506, 54.68199791446809, 55.522781495125066, 52.51857149985529, 52.85279666223834, 54.10993199194632, 53.47994442908995, 52.7200165871651, 56.02045966732887, 55.23793112847113, 53.72459834621799, 57.69693166978898, 52.43893169587659, 49.19736731436945, 51.47671153468471, 52.53690073567053, 48.29790115356446, 51.40406531672324, 52.05431192151962, 50.15047973202121, 48.401726292025664, 49.82367569400419, 53.273643447506814, 57.51888744292721, 56.70563497850972, 60.56350961808236, 62.878869041319824, 64.6723767249815, 62.580106027664684, 39.72306259216801, 62.29210207539221, 68.95827216486778, 75.35248079607564, 78.5109458431121, 41.08406620640909, 0.10903955422221653, 0.039143967292001175, 1.9388952370612853, 0.058347278785321026, 0.2068113187147725, 22.012655196651338, 82.10045583786504, 63.59133228178948, 80.44531760677215, 59.057299860062145, 65.09813431770571, 37.40460841886459, 23.113072226124427, 42.457076195747625, 61.37192187770721, 58.58288526535035, 1.581054341889197, 0.15716270783976202, 0.15088305448091802, 0.017314357007102623, 0.07797211483721772, 0.07637041650952832, 0.12977497261618415, 0.026356347220679446, 0.0563443917030048, 0.0450002804638878, 0.0716312510532237, 0.15831488875612137, 32.294848542059626, 77.24866436373803, 50.72124342764578, 52.59985085456602, 28.9901202724826, 32.538767014780355, 52.10396520553097, 72.08910019167008, 70.56556532459875, 67.11748815351918, 64.08971255825412, 1.6401129792774878, 0.15391457164960523, 1.397256120558708, 5.980981049999114, 4.061763853796067, 2.1095842844055546, 18.154119637704667, 66.53660082047986, 61.92834146561162, 64.91046067207091, 62.00681632564914, 58.234763145446784, 59.16675752209079, 59.13275841743716, 57.88280886988486, 59.314877986907966, 59.673547360204886, 58.76066669341057, 58.02047621819281, 53.931785783460064, 51.082148551940925, 49.44375099674348, 44.324983396837794, 43.357715145234145, 45.40845970953665, 49.4015698279104, 52.592104173475704, 51.27692953232796, 53.312525903024984, 53.90640412607501, 54.35582145567864, 53.33598952139578, 53.79651108095723, 56.599530942978404, 53.498434482082246, 57.01185834023261, 56.03819270287791, 54.66650062991727, 52.764127562122965, 50.2776429730077, 49.90990115750221, 51.691912374188824, 49.48598707875898, 43.1740423171751, 41.35748286401072, 41.75239101532967, 41.65323349737352, 42.09166426812449, 42.12975048249768, 39.685301934519124, 42.38432799616168, 50.09260516012869, 52.84276323933756, 56.244376013355875, 43.68851607845676, 39.72103472678892, 39.622402806435865, 40.40187189655919, 40.74669138077767, 43.11556370027604, 40.45944444594845, 41.81210125646284, 39.6049561039094, 38.02967732952487, 41.49228295972271, 41.503038098735196, 42.08471382817915, 40.96882697074644, 44.41871235447545, 44.68200145229217, 43.772007649944676, 43.85167098814442, 45.37164434309929, 41.52196353481662, 43.20533498640984, 42.7378119960908, 42.43528742944041, 41.48344193735431, 40.27871731788882, 41.338216181724306, 40.61576266442576, 38.97371730496807, 38.24867894572597, 38.28756140124413, 36.467377678040535, 38.675083729528616, 39.00420588831748, 39.773174793489524, 39.3610199805229, 42.02579198345062, 49.426880882632354, 54.715043883169855, 49.034177103350245, 41.29177139651391, 41.53522506836922, 42.4031553729888, 41.29335211169335, 40.82871598582114, 41.73796846020607, 41.50001002896217, 42.313313484191895, 44.03908183497768, 47.72909864302605, 56.166771919496604, 56.77275849926857, 55.63739315156014, 55.03251268017677, 57.204529085466945, 55.70485791852398, 55.95134358252249, 56.58890131981143, 57.80155304939517, 56.61274933045911, 58.3537757012152, 54.564824950310495, 52.17791757275982, 52.95578241348267, 54.445749636619325, 51.66621300481981, 53.51810124612624, 53.36321469276182, 53.45377829767043, 50.02087285441738, 52.190527992863814, 55.33276619449739, 59.565191884194654, 58.84201272841423, 62.16092624971944, 65.91861571035078, 67.9857361701227, 63.3297807939591, 43.31471027866487, 63.796821332746944, 71.44499994093373, 76.90682980322069, 79.51643759204497, 42.632790534727036, 0.0422122260375369, 0.8104810034555774, 3.7026586071137464, 0.08028227595552322, 0.2753319386993685, 25.16172028356983, 89.31543611711072, 70.93035359536448, 83.16936446774392, 71.02065440147155, 47.99040694390574, 20.593820156589633, 28.292571844593173, 49.64242689071163, 70.30209187538394, 69.36045631285637, 2.1824249048386855, 0.08261918120326535, 0.11068546348401617, 0.008827833207173934, 0.04283261552993809, 0.2441254543561128, 0.3253001767781473, 0.1443018382715602, 0.16453956764551902, 0.1361089109653427, 0.4042304301213834, 0.17888168353707562, 42.23494060577885, 88.35514576204362, 61.66823733237482, 58.15448007275982, 39.44933214495259, 35.693776453694994, 54.74677193549372, 80.34798006857596, 75.9772829855642, 74.21799013691565, 68.3383180249122, 2.032492672724109, 0.49370474993221225, 3.7986353280082827, 21.095714876728675, 14.075543034461237, 1.2959316156564222, 19.80177398650877, 69.45052962149344, 64.66027229062973, 68.33125775860202, 65.2752685546875, 59.29916889436784, 61.718490739022535, 61.72525290519961, 60.94277535715411, 60.702659622315444, 61.93932017972393, 60.28780229630009, 60.71425807091498, 55.883376752176595, 53.56220045397359, 51.87816612182125, 46.10504911791894, 45.02818984370078, 47.80617321691206, 51.98883187386298, 55.18913684352752, 54.08933562617148, 55.044346470986646, 54.72874864455193, 56.167646608045025, 56.066363165455485, 56.696033016327895, 60.20572670044438, 56.11676954453992, 59.25705048345751, 59.079496552867276, 58.51317690264795, 52.967369094971694, 50.71500293670162, 52.55286085990168, 54.44249799174648, 53.59394811814832, 46.54986550731044, 43.753658802278586, 44.78843888928814, 43.439245531635905, 42.58480425803892, 42.896899407909764, 41.736019042230424, 45.88803614339521, 54.15749073028565, 57.030775931573686, 59.773705082554976, 45.210842855515025, 40.237202951985026, 37.83684576711347, 40.97292192520634, 42.29126976382348, 43.65870998751733, 40.628800622878536, 42.02743153418265, 42.8354750910113, 40.09159280407814, 43.23007729745681, 43.002136599633005, 43.84986277549498, 45.19886785937894, 48.13728793974846, 48.61100435256959, 47.56787353946317, 47.16226908468431, 46.69680926107591, 44.79629147437311, 45.98790753272272, 43.592618050113806, 45.71109802492204, 43.45076945520217, 42.00847864151001, 43.74736339815202, 42.71181452658869, 39.47271339354977, 39.130776851407944, 38.55543967216246, 38.07428252312445, 37.45572082458004, 39.166003657925515, 41.25508154592207, 40.7594390838377, 42.4152127388985, 50.04033957758258, 58.3131124896388, 52.43409933582429, 44.33914707553002, 43.507228051462484, 44.7727454862287, 42.94741561335903, 43.197800113308816, 43.88156729359781, 41.91578518959784, 44.94644372693954, 48.02817936866514, 49.33641533697806, 60.13671651963265, 58.52531271596109, 56.8872485622283, 56.20165355743901, 58.96792473331575, 58.522492531807195, 58.50216288720408, 58.59604873964864, 59.18680083367133, 59.03283603729741, 61.491734596990774, 57.36171022538216, 55.01205359735797, 55.60891674410913, 57.44780232829433, 53.924953014619895, 55.822223078820016, 56.47825125725039, 55.58313500496649, 53.26332369158345, 56.18126899965348, 58.4320269861529, 64.64983094123103, 60.7858766278913, 65.83818358759727, 70.88173189470845, 71.15585850131127, 65.78136805565127, 46.66787785868491, 63.92007397067163, 74.86000368672033, 77.12911052088585, 81.87434688691171, 45.620675625339636, 0.5320652850693273, 2.043350038509215, 9.32344252063382, 0.4970049034924277, 0.3733702634851779, 27.07277355655547, 97.19611321726154, 75.95794570061469, 91.53114380375033, 77.3646096260317, 77.45094883826472, 53.999011285843395, 39.634260131466775, 63.43380205092892, 79.57081733211395, 82.9020078720585, 4.653872597602106, 0.4416055616832549, 0.34283681802691957, 0.15751860164586576, 0.12293828906671656], [0.01667168584742373, 0.001460441410252374, 0.022157053500714324, 0.08185323117481125, 0.06100775275920188, 0.10428158896825007, 0.080727020639085, 35.14602138150123, 62.50016812355288, 51.814776697466456, 27.8893639579896, 18.549019944283273, 37.01299505849039, 40.991404133458296, 69.37234893921884, 66.59381251181325, 61.86351645377375, 61.93648822845952, 1.8638167818707807, 0.10855722526508955, 0.798941083973454, 6.795338151916382, 4.492275849465401, 0.7710742373620311, 3.5588880508176746, 59.005987413467906, 66.21541361654958, 63.213753161891816, 57.62419915968373, 53.67398015914425, 51.78712006538145, 49.8451389035871, 49.33100246614026, 53.00606327672159, 51.60031326355473, 47.10612035566761, 47.61025474917504, 44.56302812022548, 43.40869026799356, 41.72437352518882, 42.67822334843297, 43.32936033125847, 49.087646853539255, 52.0694326585339, 54.38774170414094, 56.17553841683173, 55.12784196484474, 54.867631927613296, 54.026499256010986, 54.348980842098115, 54.974155656753055, 54.2577818132216, 55.18647747655069, 57.068305169382405, 53.42638838675715, 50.89397284292406, 45.97903120902277, 47.02255425914642, 49.35862771926388, 50.431976472177816, 48.23963042228453, 40.26714632588048, 39.92429587148851, 39.38083579463344, 39.709381365006976, 40.30203580856323, 40.038601583050145, 42.331564272603686, 43.45370731046123, 48.52203715232111, 52.24656297314552, 53.99790125508463, 50.466705137683505, 40.86738271097983, 39.481185713121974, 39.35276339131017, 38.5200128247661, 39.54687364639775, 42.777200437361195, 45.656227988581506, 40.905441468761815, 40.228467833611276, 36.63990313006986, 38.810401578103345, 39.90071065964238, 38.20187722482989, 43.04475707392539, 44.122436123509566, 42.218196007513235, 40.681058360684304, 40.36506437486218, 39.0220840515629, 41.93784067707677, 40.50539109014696, 40.37909469296856, 37.220206029953495, 40.26795433413598, 40.490525307193884, 37.687477988581506, 38.75173860980619, 38.757626087434836, 39.75683812172183, 38.31681836035944, 40.08011202658377, 39.440447976512296, 37.91092365018783, 38.04537073258431, 43.08205096952377, 50.498813659914084, 49.80555434380808, 48.07401618649883, 38.515882568974654, 40.085626879046046, 40.340698611351755, 40.4231232981528, 39.95045415816769, 40.30139253985497, 39.96129951169414, 41.65077417127548, 38.88345180019256, 40.7943207217801, 46.38063484622587, 52.11537145799207, 54.03819184149466, 54.79479351351338, 50.90843854411956, 53.519274034807765, 57.74544746645036, 53.51229613827121, 50.126008064516135, 59.41241556598295, 53.9502562246015, 54.694361225251235, 55.55527440963253, 56.88960590670186, 49.51543623401273, 51.97555072845952, 55.69307511852634, 54.00862501513574, 53.466930004858206, 53.96464347839356, 50.775705537488385, 51.85893081849622, 53.61076331907704, 57.64839233890657, 58.99362018031459, 60.78013035558886, 65.29237401100897, 65.02615882504371, 63.97705816453504, 58.0708472959457, 65.78672601330665, 77.55775497805688, 76.36307162623253, 33.025995992845104, 0.21931195841921916, 0.12632601413755648, 1.7787755064425932, 0.16139097692024323, 0.12821844283251033, 23.828965579309774, 83.86337295655282, 63.7405784668461, 81.98218853242936, 63.661115169525154, 79.32077407836914, 56.45758821118263, 23.173812089427827, 45.56473085957189, 62.06171774095105, 58.51376918054397, 1.2428412322075137, 0.03544077870526141, 0.046789107258401574, 0.04431277783888002, 0.0569930958050874, 0.05409284014134638, 0.06354159239919917, 0.06227558996948985, 0.05984863108624855, 0.07969631828487882, 0.14055546913896838, 0.04892805921694925, 42.10724392244893, 70.7832254902009, 59.13530795804916, 39.77317087111935, 24.004887803908318, 33.506388279699514, 48.18814539140271, 74.2947038527458, 71.57929405089348, 67.56404999763735, 65.09889525751915, 2.30674859496855, 0.403264056170179, 0.5940185090707195, 3.0707900226116185, 7.930410302454426, 1.8508692830801012, 5.003616617571923, 61.82260221050632, 68.30828835887294, 66.22534505782589, 58.14944767182874, 55.819375438074914, 53.61285394237888, 52.064125691690755, 51.57228400630336, 55.18175102049305, 52.89403646223007, 50.56604700703775, 50.17561035771524, 47.589015114691954, 45.66682231041693, 43.334075020205596, 43.90169689732213, 45.885161046058904, 50.23719941416095, 55.03027300680838, 57.44136571884156, 58.75890162683303, 55.95535616720877, 57.480707091669885, 56.7149466852988, 56.56291953979, 56.5635863427193, 57.503629422956905, 57.30182347759124, 58.43614155246366, 56.5053822917323, 53.608358906161406, 48.92232287314631, 50.3777850058771, 51.885500954043486, 49.71561831812705, 47.95526250716179, 42.55056981117495, 40.76578940114668, 40.84569984866727, 40.487497237420854, 41.915812646189046, 40.65832038079539, 43.55353947608702, 46.931115965689386, 49.72417300747287, 55.80000285179385, 56.46232251198062, 51.22032580837127, 41.43578121739049, 39.11938628842754, 39.64073988699144, 39.72788710747996, 40.131040080901116, 42.79218389141945, 45.89916390757407, 42.318424332526426, 41.981014205563454, 37.46460891539051, 40.95390627461095, 42.12209401592132, 40.83223435186571, 44.2586600395941, 46.948088061425, 45.10006727710847, 42.35236460162748, 43.75533365434216, 41.52543091004895, 43.731073794826386, 42.43390283276958, 41.329375159355905, 40.08267725667646, 39.59447945317915, 38.56928563887073, 37.384953421931115, 38.62612470503777, 39.53560467689268, 39.35647003112301, 37.99197550742857, 39.679610575399096, 38.50974013728481, 37.986103719280614, 38.05764775122366, 43.12498131105977, 54.15609044413413, 52.439990735823116, 50.63216247866231, 40.96126856342439, 40.64966763219526, 42.074001835238555, 41.82411939867082, 40.11256571738951, 41.781036084698094, 40.81757645453177, 43.438370843087476, 41.07056933064615, 43.229163385206654, 49.051772855943256, 53.54040384292603, 56.21754307900706, 57.57898599870744, 52.1212746251014, 56.0679478030051, 60.05244439648044, 54.91970531402096, 50.25390086635467, 61.73463521465179, 57.071246947011645, 56.72458002644201, 56.28583938844743, 60.09785367596535, 52.425874125572946, 53.89597454378682, 58.4816724254239, 55.18217463647166, 56.565696577872004, 56.95634111281365, 54.631305202361084, 54.955332202296105, 55.76421906871181, 61.82590876856158, 62.18172657874323, 64.18335130137783, 67.6454391787129, 66.13780560032015, 63.838857373883656, 58.01065460328133, 67.8548074537708, 77.88932861820345, 77.72910764140468, 35.172230658992646, 0.09820995146348592, 1.0718155964728326, 2.633337147774235, 0.07499800063669682, 0.10598354522259006, 25.90554875712241, 89.19068905615038, 69.18656979837726, 89.91576271672403, 68.77898846903156, 81.01858769693683, 43.74272323423817, 22.335385853244414, 55.88961332075058, 66.47565503274241, 69.07146392330047, 2.805971935872109, 0.10578682150451407, 0.03268818265848583, 0.03371258393951482, 0.04469658788894454, 0.1355813521771662, 0.2625308546327776, 0.15019080211077968, 0.20795884181655225, 0.18797900828142322, 0.22279061046579193, 0.13552685268223286, 55.59523159457792, 79.66619368522399, 68.534436533528, 42.28520185716691, 27.989574632337018, 48.56708557375016, 55.32227385428644, 81.30605036212553, 78.25498765514743, 71.77300422422348, 73.9033297569521, 2.4464058106945408, 0.5854445143092064, 3.3166211410876247, 16.13346749736417, 13.952725779625679, 1.5316302713847931, 6.797781788533734, 66.14977667408606, 70.4151894969325, 68.03761343802175, 61.524376561564786, 57.85101805963824, 57.18262657042473, 53.04712657005557, 52.837154249991144, 58.38254628642913, 55.184708487602975, 52.064463015525575, 52.69148918890184, 49.69486505754533, 45.64148772147394, 45.19334908454649, 47.08348827977335, 49.2975446485704, 52.12277297050723, 58.251464597640506, 58.92880693558724, 61.196340899313654, 59.07901017896591, 61.68893567977413, 60.03867687717561, 60.270324214812256, 59.51134166409893, 59.8538665617666, 58.34849619096326, 62.199294874745036, 58.672409442163286, 56.834453459708925, 51.60745197726835, 51.712540118925034, 54.56002396921958, 53.31478518824424, 51.83646348214919, 44.895217572489095, 43.54774613534251, 44.08067464828492, 43.430137788095784, 46.35397449616463, 43.74506488923104, 45.859128275225245, 47.892696780543176, 51.42961171365554, 57.35161404455862, 59.757395867378484, 53.813008569901996, 40.58974558307279, 39.45001463736258, 39.812931937556115, 39.34848408545218, 40.46563394608037, 42.995719602031095, 48.176911723229196, 43.464921366783884, 43.41080050314627, 37.60193501749347, 41.643702137854795, 43.506741677561116, 42.356938085248395, 47.2793165329964, 49.319086305556766, 47.805553482424834, 44.986334231592, 46.55898501796108, 42.81967186158703, 46.13405112297305, 43.746170997619636, 44.13851784121606, 40.538429214108376, 40.3592239656756, 40.1894167161757, 36.76347740234868, 37.88603621144449, 39.10819184395575, 39.91734543154317, 37.705234558351584, 40.40695136593234, 39.159872993346184, 38.04016574736565, 38.236299945462136, 44.837346922966745, 55.747384255932225, 56.33903457272438, 52.664381688640965, 42.44309294608332, 42.62065079904372, 45.006303018139256, 43.958975268948464, 42.71750196333855, 46.19336520471881, 43.91003977867865, 45.782383180433705, 43.34938795335832, 45.48235324121291, 52.52330972302345, 56.816712579419544, 58.557025078804266, 61.77278026457756, 54.55204979065926, 59.88237827054916, 64.49881576722669, 56.37179028603339, 55.0640759929534, 63.27695823484852, 58.572106592116825, 60.63550472259522, 59.97378126267464, 62.01756754229146, 55.87812077614569, 57.495843518164854, 61.967514176522535, 59.517515474750155, 58.94605751960509, 58.38238546925207, 57.08762676485124, 57.114141987216094, 57.97319989050589, 64.37701048389559, 66.32243940907141, 68.40895206697526, 71.29231775960615, 69.58831464090656, 65.50457423733127, 60.37401207031743, 72.9119977643413, 79.17363812846523, 76.9618449672576, 38.8180305880885, 0.5265281241266958, 2.138503429389769, 7.571937537962391, 1.0346713638113392, 0.25976947538795014, 28.97227348819856, 98.31182356803649, 77.09114982235816, 94.49057209876277, 78.00298321631648, 93.21476628703456, 70.23522330868629, 39.43101467624788, 67.73486921864172, 79.62274166845506, 85.13539760343491, 4.895074338682236, 0.24758475502171826, 0.17730040145256828, 0.1328648197194261, 0.16990595226806982], [0.03607567790294847, 0.06121038684561368, 0.058484749432893536, 0.07983361656266837, 0.08098787357730251, 0.01819907747689755, 0.027124539971531882, 47.17712702289705, 63.615274429321296, 40.50958802623134, 34.69900846481323, 25.594908806585497, 36.66882668772052, 41.31891419810634, 62.56822909078291, 69.4609631261518, 61.0976658328887, 65.19624848519602, 2.504049453043169, 0.10634725312552146, 1.0601872398007302, 0.15330704860389233, 2.889210269335778, 1.650085850588737, 0.37939024368120783, 44.47585736551593, 67.90584533445298, 60.99496641466695, 61.3751107646573, 50.838887076224054, 54.25893891242243, 48.71490793843424, 49.096503565388346, 42.92622696968817, 45.63885581108832, 45.09126940081197, 47.25287583566482, 45.59041453946022, 46.984546492176676, 46.470653241680516, 51.35780488291095, 51.69518363091254, 55.38479643483316, 57.07272175819644, 54.11262273788453, 47.9753803437756, 53.27378857520319, 53.15860425272296, 53.31735826307728, 55.721174978440814, 55.14435514327019, 54.930891913752404, 55.80115995099468, 54.36705904622232, 52.52468255258376, 48.11701713069793, 49.30783694790256, 50.89789129072621, 52.27143864477835, 50.61434315096948, 44.43965781119562, 39.86510338321809, 37.22128860412106, 39.2837453657581, 37.92272213966616, 39.110517809467936, 39.2193361251585, 37.08580209362892, 37.99890633552305, 40.50940759720341, 47.94196959464781, 55.86519656642791, 51.656485526792466, 42.876962000323886, 40.2176538590462, 39.77515951279671, 38.5166552758986, 39.628286361694336, 41.47840561405305, 45.55064170591293, 46.529433881082845, 40.931062390727384, 40.04883112445955, 37.98161652780349, 39.88038493740944, 40.527532869769686, 39.87867478401431, 41.66007018858387, 42.31743981761318, 40.544936426224254, 40.49922904660625, 43.165836718774614, 41.107078752210064, 38.01957330396099, 38.638499782931426, 38.45912587258124, 39.05653815115652, 36.77274204069568, 37.82802043422576, 40.314418731197236, 40.840208530426025, 39.27259014498803, 39.78587935047765, 39.242521255247055, 38.22438378487864, 37.768274891761045, 39.55014098075129, 49.90015798999418, 53.70366073423817, 50.656504707951704, 41.61682997980426, 40.18240744067777, 41.514538488080426, 39.165948744743105, 38.07225858011554, 37.99318751981182, 40.79455998636062, 39.017690996969904, 40.397463152485514, 39.26082303447109, 41.97239283592471, 41.616602482334265, 44.38413273903632, 45.092755979107274, 49.4116424745129, 51.595492670612956, 52.21788652481572, 52.40863923103579, 57.25003642420615, 36.700692023000414, 35.91949316763109, 58.188196766761045, 57.79453200678672, 52.80330419540406, 52.54545542501634, 51.32830081447479, 57.88861790011006, 57.36626017478205, 59.19593995617282, 56.117193160518525, 53.42573727330854, 57.00713188417497, 54.88422747581236, 52.708378914863836, 53.094767678168516, 55.64047613451558, 60.88830148020099, 62.95685360508581, 67.36082415426931, 63.702441261660674, 58.03436925334316, 59.475279392734656, 68.08018684387207, 76.23615157219672, 25.499485385033395, 0.16644136559578682, 0.4859535948884103, 1.870872145218234, 0.30799376027237985, 0.27758907887243456, 30.920130360511045, 78.17955263199346, 68.06172816984116, 77.13021662927444, 68.69943495719664, 51.59941896315544, 62.157023491397986, 28.677264182798325, 39.074934067264685, 66.41175177789503, 55.4586781993989, 1.5973575509363607, 0.16190777983396284, 0.07136214734806169, 0.04973173141479493, 0.17056656520693533, 0.06537571414223602, 0.05506157364335753, 0.122812980064942, 0.014324809965347091, 0.034185290832312844, 0.0664055354953293, 0.08447790969043009, 57.87127317920808, 70.82791697594428, 48.43064984967632, 43.583494617092995, 26.703953089252597, 23.963169474755567, 46.80283877157396, 67.30236514922112, 73.98052984668364, 65.19469130423762, 70.49104029132475, 2.681564650227947, 0.060973190702497966, 0.5947432282470888, 1.4517235010862353, 4.543137713786095, 1.4308525693993417, 0.2310569596386725, 50.831116860912694, 70.22875924264231, 63.663605874584576, 61.0664673005381, 52.93897897966447, 55.20177472022272, 50.989851259416156, 48.41928282091695, 45.936736291454686, 47.334606262945364, 46.4196781189211, 49.24180384605162, 47.587767800977154, 47.92625265736734, 49.09516211478941, 53.552739697117964, 54.63848706214659, 56.52735148706744, 55.93639150742562, 56.309663864874075, 52.274301975004136, 55.6419901694021, 54.44315694993543, 54.27851153958229, 57.439435912716775, 58.51074503314111, 55.39768926558956, 57.958659664277114, 54.693808171056936, 52.93142449471259, 50.30791190362746, 51.48454058554865, 52.70549597278718, 53.43962638608871, 53.02853845780896, 45.24376330837127, 40.628871225541644, 39.009701128928896, 40.81421106092392, 40.99366341867755, 40.605305625546364, 39.80846828030002, 40.43857743663173, 38.84860154121153, 43.05197423504245, 48.79042140899166, 58.447045741542695, 53.885694011565185, 44.476983085755386, 40.73710118570636, 41.132734975507184, 38.772213382105676, 38.96813969458304, 40.77561101605816, 46.712561499687936, 46.55850256642988, 42.79637298276348, 40.78952366305936, 37.654906626670595, 42.22718607994818, 42.75836521579374, 41.74624073889948, 44.51960356004777, 44.581977090527936, 42.68510318571522, 43.58960566982147, 45.12175406179121, 41.85374506058232, 41.22660121610088, 38.72241497039795, 38.65182407440678, 39.17943385339553, 38.44485628989435, 38.97221503719207, 40.44908546632336, 40.81159876238915, 38.80216852311165, 40.175358941478116, 39.100413783904045, 39.23184848600818, 39.73674774169922, 40.37110090255737, 50.254281336261386, 54.19145061123756, 53.69770265394642, 42.60108209425404, 39.813092754733184, 41.42608511832453, 41.36469610275761, 39.36512277972314, 42.13311195373535, 42.78177784335229, 39.959067683066095, 41.73863526313536, 42.77526278649607, 42.85614205944923, 43.627758564487586, 45.7948523952115, 47.68830207086379, 52.03820274722192, 53.67071674716089, 56.5113482167644, 53.887729721684615, 58.914976658359656, 40.42481776206724, 36.92531439565843, 61.60475377113589, 60.28520568724602, 55.61438845049951, 52.724284125912575, 54.98665232812205, 60.72799028888826, 60.40474384061752, 60.02337571113341, 59.16817742009317, 57.887068563892, 58.998181896824995, 57.83064526896323, 55.63703621587446, 54.867526023618645, 57.49378819619456, 64.15501609925302, 63.842889570420795, 68.39774193302279, 67.23359031061973, 60.92468146354922, 62.17264629179432, 70.3304192327684, 78.66194925000592, 27.406235817940008, 0.21588869452957185, 0.7573234494174681, 4.188459352139504, 0.023824411309173992, 0.16827925649141112, 32.59945196490134, 86.37980091956355, 70.84448506755214, 85.85880033431515, 73.1832218170166, 64.80202282628706, 66.37792525752899, 38.36526355435772, 52.06641635587139, 72.50112164405085, 66.95117181347263, 2.664107651479783, 0.15318596074658056, 0.12341791373347083, 0.009205195669745727, 0.12463594756780133, 0.19285148069743188, 0.1553560120444144, 0.26073652349652787, 0.2097608031885278, 0.09374927428941573, 0.19348589342928704, 0.3541633667003724, 67.0389779921501, 79.82698732806791, 53.7050727875002, 46.24237129765172, 35.91185631290559, 52.87726440737325, 55.52801785930511, 72.08748417515909, 79.87950786467522, 70.70280121218774, 78.18924088631907, 3.2331320210810635, 0.35846458267300363, 3.6110332656291226, 5.577008301211942, 10.982242284282561, 3.940740347869935, 1.2805779879131627, 53.51907399392898, 70.1415414194907, 66.93876927898776, 65.35915628556283, 54.53212022781373, 60.118626548397934, 53.887478689993586, 53.216549427278586, 46.098938065190474, 49.39416047065489, 48.73963063763034, 50.11761811471755, 48.91385447594428, 51.888497644855136, 51.67657982918524, 56.13515761590774, 55.709658899614894, 59.43212547609883, 57.794763426626886, 59.44893675465738, 54.7327063160558, 56.23630769791142, 54.99564632292717, 57.49169365052254, 60.223977488856164, 59.7151009498104, 57.958459623398326, 62.132292947461536, 57.66596063490837, 56.741422683961936, 52.85283196356989, 54.9973996223942, 53.51111942721952, 56.6880274588062, 55.28091246081937, 47.90998658826275, 44.27070956076346, 41.089373173252234, 43.2778399990451, 41.7490570006832, 42.83632232296852, 41.94976468240061, 41.4686232228433, 42.40306515847483, 44.89222872641779, 51.22718603380265, 61.18678600557389, 54.85626489885392, 43.26495501302904, 41.518441246401885, 41.47938228422596, 38.711883406485285, 38.88930397648966, 42.233975702716464, 47.72356810108308, 48.26484734012235, 45.58519386476087, 42.523485845135106, 39.9634450481784, 43.6871079475649, 44.652289498236875, 42.80714773362683, 47.248051320352864, 47.34987212765602, 45.0904574701863, 47.11915831412039, 48.317967999366026, 44.811298462652395, 41.94223765403994, 40.591538106241536, 38.41437555128528, 40.59003583846554, 38.81058592950144, 38.30977378352996, 40.906331846790934, 41.03793521081248, 39.32720130489719, 40.39785146713257, 39.5302035731654, 38.360403737714215, 39.18979675539079, 40.99294954730619, 52.02432147918209, 58.010415338700824, 56.48527622222901, 44.97081341282014, 42.74294637864636, 44.721374204081876, 43.30468470050443, 41.651793987520286, 43.56396513600504, 46.75250299515263, 43.21951827695293, 45.095854651543405, 44.648849579595755, 45.53026499286775, 45.74865471932196, 49.36570367505474, 50.70260040221676, 55.15600850505214, 56.887009297647786, 59.10436045738959, 59.09407208042761, 62.505490779876716, 39.923821264697665, 40.39291320308563, 63.2294544096916, 61.83163542901317, 58.6356686007592, 54.89182510683614, 58.204725634667184, 62.52932310104371, 63.12744925099035, 65.91453644537157, 63.10586052556192, 58.69466497052101, 62.40561546817903, 60.7825896816869, 58.011897994625954, 57.02537090547624, 59.85488245564123, 66.85188877967097, 66.49357241968956, 72.926377173393, 68.99035715287732, 62.333541916262725, 64.1719921173588, 74.80058762335008, 82.63614962177893, 29.98057365417481, 0.6579154513535962, 3.8384770481817188, 6.366873633476996, 1.582222350182072, 0.39350682328785624, 36.1463983597294, 93.32653814746489, 78.23833327139579, 89.54518502758395, 82.8886482792516, 69.80973243713379, 74.95856500441029, 47.10479851691954, 62.04630674854402, 83.31912056092294, 82.0079271255001, 4.232390388365715, 0.30604973555572573, 0.2188389757347684, 0.14466922339652816, 0.3436798824658317], [0.07522472435788763, 0.03625001270143736, 0.027504234214223204, 0.1559190407034851, 0.04475576052021596, 0.17495399671456507, 0.010869810883436474, 36.832405213386785, 57.52626149885116, 47.24684323033979, 20.913265828163397, 48.617644925271314, 68.38655533329134, 42.28630404318533, 64.64419057292324, 68.82594708473452, 60.651009851886386, 69.5151859714139, 7.872835301583814, 0.21065893402743727, 0.5114837201131929, 0.5672027350914094, 6.057811456341898, 0.7434302916930569, 0.05529039644546086, 36.40438049070297, 75.89339133231871, 58.49258445924329, 64.55884764271399, 53.73896206578901, 63.584401453694994, 59.33776501686343, 57.65214996953165, 47.64249270962131, 45.23343178533739, 41.32741005189958, 46.58464908599854, 45.55021024519398, 50.989172689376346, 51.441547486089895, 55.73959442877001, 54.48309452302995, 53.545553914962284, 50.83785941523891, 53.789086034221036, 54.922086192715554, 56.35631261333343, 55.44944494001327, 56.1984097573065, 55.57582762933547, 56.925687789917, 54.85016953560614, 55.01796460920765, 52.60194147786787, 48.695209795428866, 49.03948014782321, 54.727505253207305, 54.524957979879076, 53.04858176938949, 50.43176074181834, 43.311380186388575, 35.567499668367454, 38.52646120132939, 36.42338829655802, 36.154490209394886, 37.37644187865719, 39.45222685413976, 38.90921784985451, 36.60457434192781, 36.55772163021949, 40.56179477322487, 50.74613086638912, 54.17381563494283, 46.044558325121486, 41.233496742863814, 40.37365044316938, 42.08059533949822, 39.766812709070024, 42.801585812722486, 42.673865595171534, 47.158605590943374, 50.35197188777309, 42.19274374746507, 37.22042960505332, 38.50099717417071, 43.330744927929295, 40.49839358175955, 41.677309005491196, 42.86975268394717, 41.73284584476102, 40.48956824887184, 42.5806700798773, 37.7862746484818, 38.45123798616471, 38.56418655764672, 38.79809318050262, 39.04476319589923, 39.01926778977917, 37.478301909662065, 39.17702551810972, 39.385448501956084, 38.52766929134246, 41.63290777514058, 37.75227946619834, 40.66702019783759, 37.76735705714072, 42.050291107546904, 53.05060571239841, 52.242048325077185, 48.08135101872106, 40.430250244755904, 38.48560187124437, 38.09984853190761, 37.524260320971095, 38.77133477118708, 39.27936015590545, 40.329523778730824, 41.06153611213931, 40.15457822430519, 42.0468904126075, 41.41102321686284, 43.441649944551536, 40.38048713437973, 41.69400261294457, 38.179021573835804, 44.9914490022967, 50.00086092179822, 54.52712312821419, 53.40006928290091, 58.97276493810839, 37.93622686016945, 31.228526715309393, 49.98626186001686, 58.42171507496988, 57.339827322190814, 53.51712065358316, 55.1096264777645, 57.029634521853545, 59.283734367739775, 60.93606418178928, 59.79747856816938, 61.016488459802446, 58.66937352764992, 56.80443556078019, 51.53186005930747, 52.33625973424604, 54.41598669175179, 60.77363883295367, 62.593226355891076, 69.31829083350398, 69.74756286990258, 61.571852930130504, 48.06833659448932, 65.88504022167575, 18.88563971365652, 0.44610914744196406, 0.6559410895551405, 2.379677959026829, 0.4418793002203588, 0.12312951227349621, 29.847613150073638, 78.82450011468704, 65.53396063466226, 78.01977880539434, 67.95795794456237, 62.13739202868555, 40.3026359311996, 20.572349102266376, 40.58520740078342, 65.16317113753288, 51.55605716090049, 1.439118474241226, 0.14558687415574828, 0.06874659293962103, 0.05371294097013531, 0.1092787804983316, 0.0414462223829281, 0.07181828375905752, 0.03805202769956762, 0.03012020231014298, 0.05606943891654092, 0.10563368818932965, 0.018749218621862032, 47.10443765886369, 67.56503843492078, 51.76975181025844, 27.53012387983261, 28.036370469677834, 51.69872945354831, 47.70796491253761, 71.40876508528187, 74.43957267269012, 64.77766490751698, 75.82884480876308, 8.53779765867418, 0.27762107070415254, 0.24483931040571583, 1.5838218191939017, 3.8852223850065664, 0.6655185982104271, 0.05876549384406498, 41.58160317328669, 76.45409414845129, 60.618454179456165, 66.71906163615566, 56.02198154695573, 65.99201110101515, 62.18449577208489, 60.53789654085713, 50.052612673851755, 47.35449267971901, 43.50858911391228, 48.68426246027793, 46.53362297242688, 52.00739252951838, 52.66251071806877, 57.00111496833063, 56.904001005234264, 56.08970911272111, 53.56406357980544, 58.382432537694136, 55.843811804248446, 56.29597871534286, 56.22242250750142, 56.703858144821666, 58.511851141529704, 57.586316908559496, 56.65154549383349, 54.68649687305574, 53.63090468991188, 50.68815039050195, 50.41694202730733, 57.42264816837927, 55.76188133608911, 54.532324191062685, 50.913031639591345, 46.1003226618613, 38.54659080505371, 40.029242807819, 38.60345732781195, 38.66415208385837, 39.06916818311138, 40.02563422726047, 37.99671373059673, 39.0621667523538, 38.90274201670001, 42.95272650257234, 52.57244525417205, 57.374430471850985, 44.519701619302076, 42.472624471110684, 40.98660707473755, 42.179937208852465, 39.68392126021847, 43.36306918051935, 43.138180086689616, 49.2042040055798, 49.38228745614329, 43.19238724247102, 38.139974378770404, 41.391701621394006, 46.559471391862445, 42.46829417444045, 43.829023222769464, 44.6655471094193, 43.67028490189583, 44.474951298006125, 44.82911779034523, 39.78092931932019, 38.28503539485317, 39.157547027834006, 39.06597537379111, 38.8696176005948, 40.75929003377115, 39.90363674779093, 38.72364267226189, 39.43259931379749, 39.06738350468297, 40.59716670743881, 36.978615483930035, 40.95092135090982, 37.623778696983095, 41.74786852252099, 53.83739394526328, 54.948534734787486, 53.38093596120035, 42.77044611592447, 39.059370102420935, 41.26749976988762, 40.67476687892791, 41.905920428614465, 41.63755970616495, 43.583353411766794, 41.17792852463261, 42.7270019438959, 45.5202982502599, 42.731218491831136, 45.308294142446215, 42.710469153619584, 44.65531364563973, 41.018452798166585, 46.792252294478885, 51.707578320657056, 57.11136887150427, 54.0814555844953, 64.03457580074188, 43.520077736146995, 34.280985786068825, 50.338196523727916, 57.63828439097251, 58.681124948686175, 57.380863158933586, 57.595734519343225, 59.86924617521225, 61.23749048479142, 62.6274961040866, 63.84408981569352, 62.34654065101378, 60.80384892802085, 58.06945485453452, 55.26668602420438, 55.27070253126083, 57.38449527371315, 63.93291188824562, 66.15111027994465, 71.25414525308918, 71.82576794778147, 60.4641834382088, 52.90955728100192, 67.23022491701188, 22.681438922882084, 0.5419666344119657, 2.152961530993062, 4.055296355678189, 0.11200593093470221, 0.09835226761717951, 33.29592174099338, 85.3522889844833, 70.58473787000104, 86.32946122077205, 74.83307269311722, 66.14458345597791, 52.72641397291615, 24.607809051390618, 45.17480804074196, 73.69300442357218, 64.14896388207713, 1.994893077400423, 0.13545986595413378, 0.06251537932022926, 0.046742149899082805, 0.1028830111928044, 0.1762726178933536, 0.229079288340384, 0.11159778993216254, 0.37307528899081294, 0.22194797503611735, 0.24065573489473713, 0.12680823584237408, 58.60454851581205, 74.9602908472861, 61.70963402717345, 32.78494085035017, 62.62075747213056, 80.53151561367898, 58.364068000547356, 78.7011415727677, 80.99224505885955, 69.62025057884955, 79.81600469158542, 9.950652064815646, 0.889794024969301, 3.0510904087174326, 3.0330950646631183, 14.979835671763267, 2.9988630692805014, 0.328060238351745, 44.331172896969704, 80.49505326055711, 64.41666172396752, 70.40805078321888, 58.173578093128825, 67.80162795897454, 64.81260930338215, 62.88771790842857, 52.588734857497684, 50.95062363532282, 46.465946397473736, 51.82914826177782, 48.81951362855973, 55.84280375511416, 55.028637378446525, 59.80160097922049, 56.887295630670366, 58.24314917287519, 58.8259937686305, 60.12531418954173, 58.07315757197719, 58.69095833070817, 57.37308509888188, 57.18680389465825, 61.39359297290925, 59.036299490159564, 58.194578463031405, 58.5452462011768, 56.02191878903297, 54.0330849155303, 51.04395251120291, 61.132727899859034, 59.95587956520819, 58.3526695928266, 56.69276568197436, 49.72251776726016, 38.44320497205181, 44.966224239718535, 40.42542572944395, 39.28886405883297, 42.80158973509266, 41.420974269990005, 42.967192203767844, 41.73896866460001, 40.12145773057015, 44.43021274382069, 56.38317692664362, 59.20169799558578, 46.227850683273815, 43.5061768562563, 41.25952951369747, 43.14875087430401, 40.725357609410445, 44.14351494081559, 45.127927872442434, 50.06408560660578, 51.00764313051778, 44.53262190664969, 39.2602542907961, 42.84670875918481, 48.31088419883482, 44.67213669130879, 45.993445919406035, 46.719978701683786, 47.680327892303474, 45.31266758518834, 46.13246256305326, 40.64542755003899, 41.596119865294426, 39.53203924240605, 39.612651794187485, 38.986225743447584, 40.27741901336178, 39.01756155875422, 37.66197473772111, 40.50019394966864, 39.623222581801876, 42.09608477930869, 36.98389891655215, 41.48894110033589, 38.74886351246988, 44.132971609792406, 57.30213334483486, 57.365820869322754, 53.4122835436175, 47.205136668297556, 41.88877967096145, 43.080882103212424, 40.925123922286495, 43.821249085087935, 45.093214896417436, 46.54203253407633, 43.853090886146795, 44.41384469309161, 47.413226250679266, 45.227026554846, 47.95707856455157, 45.09774915633663, 45.73502448297317, 42.45255762530912, 49.80006694793702, 53.31624038757817, 60.72023184068742, 57.12630525712044, 63.71828371478666, 40.25420642668202, 37.95413640237624, 54.98595022386121, 59.37125813576483, 60.12509061444191, 58.30589140615156, 59.85882836003458, 61.95407613631218, 64.67764446812292, 65.1705804947884, 64.85302540563768, 66.98070726087018, 64.20350836169335, 61.508275232007435, 56.55239974298785, 57.43495264360982, 60.75365435692572, 68.35451741372385, 69.26135370808264, 74.50830044284945, 72.27081575701314, 63.67914630520729, 57.57092160563315, 74.15669133586269, 25.20825920566436, 0.62719440628444, 3.5512649243877785, 5.773942172527314, 1.1550524590476867, 0.35933985344825253, 36.890260173428445, 92.33389608321652, 75.84566393206197, 90.85043214982556, 83.77245241595854, 81.02443987323393, 58.05833885746618, 33.70085547047277, 60.65406537825062, 83.49227751455, 78.79951461668938, 2.704667655691024, 0.40207717147084976, 0.4218210652470589, 0.1802913772483026, 0.1429939729672286], [0.07384324566491189, 0.009050500492805676, 0.06354333141878729, 0.14598438185789894, 0.02925134560604009, 0.1441272621553752, 0.07178146557341661, 29.210339784622196, 64.93583448471563, 42.405748059672696, 25.438459188707416, 81.29775847158125, 92.6069087366904, 52.1735558971282, 56.99661993211316, 70.37541666338521, 59.34136575268161, 75.33672071272328, 13.646757371963995, 0.2339295748501055, 0.6038241893533738, 0.38244264440671094, 2.477817621923262, 0.2605908135733297, 0.184772348091487, 31.221717480690252, 79.41997866476737, 58.11195765772174, 61.8306666035806, 57.959746160814845, 65.26350536654073, 58.784440179024976, 55.92237295642976, 49.13011043302475, 47.10406503369732, 45.38421553950156, 48.62280284204791, 51.339605085311405, 53.86308546989195, 54.676020222325484, 56.984641013606904, 51.91226720809937, 53.3553542629365, 57.25107585230182, 58.24852282001127, 54.35927314143027, 56.644422469600556, 54.1470415361466, 56.383777049279985, 54.64785368211808, 56.78170542563162, 52.62203185789047, 50.71426160873906, 46.51205778121949, 50.40609667378087, 51.86327288227697, 53.11349699574133, 51.39911136319561, 52.65002581381029, 44.59963560104371, 40.05633069622902, 38.28296438340218, 37.98226371888192, 39.46379392377792, 37.05481536926762, 38.38711507858769, 36.29040033586564, 36.32164593665831, 37.71611913557976, 39.55785236051006, 41.962951690919944, 46.908762378077355, 53.87206377521638, 48.69093048957087, 43.77385116392567, 41.74815485554357, 39.63931214424872, 41.693488782452, 42.123902228570756, 45.784375744481245, 43.81838575486214, 48.47294084487423, 45.823403327695786, 38.81632435706354, 38.72740030288696, 44.13070840220298, 44.11358725640082, 39.20102257882395, 46.88750705411358, 40.36721383371661, 44.39299337325558, 44.06478904908703, 36.92664407914685, 36.59936935670915, 41.552016735076904, 42.18249067183464, 42.627832658829234, 40.71103311354115, 36.80177542471117, 41.20897800691667, 38.58960351636333, 38.67120842779837, 37.16046440985895, 39.843059662849676, 39.24228199066655, 40.227432327885786, 46.531748079484515, 52.55192733580067, 51.31330167093585, 48.35980007725377, 42.287547434529955, 42.92780376249745, 39.835430652864524, 40.51369474780175, 37.98746085936023, 36.84179144520914, 39.06500262598838, 39.27829719358875, 39.79965471452282, 42.37801298018425, 43.50545906251477, 43.649727759822724, 42.02678434310421, 42.387654166067804, 42.070989454946215, 40.0767780119373, 42.73669019822152, 49.961543083190925, 54.64308407998855, 53.848451106779045, 62.86311288033763, 49.93932285616475, 35.71537302386376, 42.4070934326418, 44.96567903026458, 52.981293509083415, 53.493476606184444, 55.28111250169816, 55.78126568948069, 58.88106384584981, 57.68615299655546, 59.38162103776009, 59.88558676935012, 59.460040984615205, 55.47247709766511, 54.93026825689501, 52.738134014991026, 58.30801340841479, 61.57647348219349, 65.08914816764094, 66.59051772086852, 65.61268260402065, 47.14015868402297, 56.30270165781821, 13.912001771311607, 0.47055023271710644, 0.8974528204529517, 2.8868926388602105, 0.2041918342752803, 0.13289831308347563, 31.139239841891875, 77.59568429762318, 65.16081379305932, 76.95034457791236, 67.82899825803696, 48.50834415804956, 28.35130737673852, 41.14988357790055, 48.55023899386006, 68.50551297587734, 47.476396022304414, 0.520320666893836, 0.06000123580076522, 0.05455687491884155, 0.0412021927355278, 0.01630219972632345, 0.03810048659121798, 0.06801877876803761, 0.06536325755258722, 0.07914517164951371, 0.02010243058565163, 0.16770191730991488, 0.08114951046844644, 39.46870080886349, 71.20332702513664, 47.54778708181074, 24.126467550954512, 73.13183092301892, 91.09310134764641, 56.805196500593624, 64.01226535920175, 75.5063710674163, 63.6386086094764, 82.13607095902967, 14.914964572075876, 0.2517205419679803, 0.3250931185339728, 1.2710385385059542, 5.4243795621779665, 1.0496048076498894, 0.11736454742570078, 32.72113761594219, 80.86488569936445, 62.77504390285861, 65.67316947444793, 60.265903703628055, 66.37619156991282, 59.418412869976414, 57.67233056406821, 50.404539492822465, 49.15768077296596, 46.63400034750662, 51.408729014858125, 53.362598880644775, 57.34521665880757, 56.680704393694484, 59.35849474322412, 55.766650938218646, 58.052933831368726, 57.534506320953376, 58.23343738432854, 53.691764185505534, 58.321529896028586, 56.75808883482411, 57.74602797723586, 56.956627445836226, 57.936000131791644, 54.691439059472856, 54.46794240705429, 48.34781723637735, 51.66487547659105, 54.0067461998232, 54.14400169926306, 53.53113920457902, 54.20027594412527, 48.236080677278586, 42.74210306905931, 39.57485975757722, 39.15834719134916, 40.2779681451859, 39.356336670537154, 40.55280862316009, 38.01998515282908, 37.26659590198148, 39.81854092690253, 39.990054407427394, 44.80084534614317, 48.018204781316946, 57.05689891692131, 48.84110627635833, 43.31878954364408, 42.31987168712001, 39.60745465370917, 40.781753447748, 42.63539891089163, 47.887915411303126, 44.72969355121736, 48.574926391724624, 46.011292703690074, 40.21160164187032, 39.24359990704445, 45.99659166028423, 45.350867548296534, 42.70441301407353, 46.11867935426774, 44.27679707927089, 46.078384845487534, 43.24492346855902, 38.04357036467522, 36.95913307128414, 40.491917748605054, 41.531738081286036, 42.4457170117286, 39.6097884639617, 38.69861402819234, 39.748557998288064, 38.89759194466376, 39.313884858162176, 38.25046754652454, 38.61489103686425, 41.96548946442143, 38.508641873636556, 49.55021981270083, 55.07308175486904, 54.49060193953976, 49.43674564361573, 43.65078287739908, 42.42883905287712, 43.23172469292918, 43.05997979256415, 40.88133065931259, 39.06956042012861, 41.91722469945108, 41.10838490147745, 41.80327200120495, 42.6950660059529, 45.14812807882986, 44.83617413428522, 45.3288826634807, 44.9680991326609, 46.344305853689875, 42.03803370075841, 44.45584935526694, 52.810799844803356, 58.19032269139444, 55.5422442959201, 65.67679374448716, 54.233612168219786, 38.76887152271886, 43.313788521674375, 45.296209319945305, 53.638314047167384, 54.20616734412409, 55.985460358281294, 58.4185811012022, 58.69581814735167, 60.90546577207504, 61.1513630805477, 61.72365650053948, 60.473334327820815, 57.1475645034544, 56.63300052765877, 55.25977088559059, 62.44199152915709, 64.8854830188136, 66.85306549072266, 69.31295641006963, 68.42331578654628, 48.80258075652584, 60.91829584490869, 15.50741897475335, 0.38479370695929377, 1.4276072983780217, 6.374029997856387, 0.3849694475291237, 0.1402071749250735, 34.35039604863813, 86.49436550755655, 70.99970894475138, 81.85924576174828, 76.20095222227036, 55.748627647276855, 34.03823421847436, 43.53001702216364, 56.747863215784875, 77.58671775940927, 58.040080224314046, 1.0126294207669075, 0.1262622449787394, 0.07049004817681928, 0.042530121882596326, 0.005098178197870092, 0.19498854424924622, 0.22189269413150128, 0.11499489191919567, 0.31437171803366754, 0.12888445669124204, 0.2889088553286368, 0.16188642130263392, 49.79481097190611, 83.40545977315595, 58.184788227081306, 42.03934769476614, 91.35383698248094, 93.48395070722027, 64.67613435560658, 70.82885834478563, 82.01023347916143, 69.18421637627387, 86.97161597590294, 16.351781718192562, 0.4913220326265981, 1.8616554333317665, 2.274232391388186, 11.028573320757959, 3.2932060620477124, 0.20372988325693916, 37.12848532584406, 80.78757578326811, 66.16972584878245, 67.10374416843538, 63.27226708012243, 69.43367911923316, 63.31463260035362, 60.81913832695254, 52.79249806557932, 51.92703885416831, 47.59252955836635, 50.753685351341005, 56.13131761550904, 59.98415985415059, 58.86868484558598, 61.698447427442005, 59.69370442052042, 59.77116730905349, 58.07911565226894, 58.37411319055865, 55.62405317060409, 58.94958765276017, 57.64733722133022, 61.13781521397253, 59.341106876250244, 60.51301302448396, 57.08580286272111, 56.935897719475534, 52.07793243469731, 54.97460672932287, 56.063711643219, 58.2905274821866, 56.11967209846743, 57.69905759442238, 48.591627843918346, 45.17366663102181, 43.45786502284389, 40.82643708875103, 43.63223006648403, 41.26262426376343, 43.61671317008234, 39.53255307289862, 40.3323753418461, 42.51670406710717, 42.596406629008634, 47.527473126688314, 50.33571366340884, 59.73554826551869, 50.04809410341325, 45.17241147256667, 42.02931427186535, 40.48939174221408, 42.96653716794906, 43.536751731749504, 46.90978219432216, 46.139605199137044, 48.07594599262361, 47.932555906234256, 40.69402963884416, 41.62534544544835, 47.22616057242117, 49.935926083595525, 44.0877192251144, 50.87524744772142, 45.46713052257415, 48.978965820804724, 46.22847826250138, 39.71629650362077, 37.22714470278832, 41.02268895795269, 43.96427046868109, 42.37444754569761, 38.33754024197979, 37.98486032793599, 42.5572652970591, 38.81999177317466, 40.59788057881017, 37.964099222613925, 39.82552274580925, 40.598955308237386, 39.219112550058675, 52.08155670473653, 59.34895946133522, 56.66481487212643, 54.441737051933046, 47.163826265642726, 47.28596495043847, 44.123330423908854, 46.5146622350139, 41.87552598214919, 40.96454766488845, 42.862684572896654, 42.9816069141511, 44.339990385117076, 45.96507541594967, 48.43111268935665, 49.46706164267756, 49.07945302224929, 46.79631194760723, 47.88697796483194, 43.743499863532286, 45.97133159637452, 55.47631709806381, 59.91704025576192, 59.84182096296742, 64.79329947502383, 50.232014040793146, 40.99627571721231, 46.79390361232143, 48.17568009899509, 56.18538748833441, 54.68743431952692, 55.28737260449318, 58.74599702896611, 61.253266257624475, 61.28976783444805, 61.46630194879348, 64.22319081521803, 62.72885407170942, 59.05446790879773, 59.78219701397804, 57.36809976639287, 64.65802869489117, 68.20219609045213, 69.69534043342837, 74.49283061488983, 72.62295046160298, 53.53358284119637, 68.76864910125732, 18.71102167714027, 0.5860782835272051, 3.0093399651588935, 7.010775804519654, 0.6382323849585749, 0.22905612184155374, 38.90904134319675, 94.38771186336395, 77.25457929795789, 87.64518107137373, 82.09933403999575, 65.91408145043158, 42.75974589009439, 56.36422403397099, 68.96461071506624, 89.22674348277431, 70.06610639633672, 2.096429390292014, 0.19076576035830284, 0.14524673111736774, 0.16791649853750584, 0.20268752870540466], [0.04670273084493895, 0.02358283888879082, 0.09477387092286542, 0.08991344906990567, 0.0417935015303233, 0.13344836421310902, 0.06034354686797146, 34.42659201160554, 64.70170036438974, 39.36723693724602, 38.48817102370724, 72.96985272438296, 87.40368073986423, 48.61288709025229, 60.341817255943056, 70.1546029121645, 60.701427998081336, 75.17406786641767, 23.071271527198054, 0.0872151188612465, 0.24401864637770962, 0.85830511465188, 1.4048877045992882, 0.3837847385194994, 0.38161192930513815, 27.68831110769703, 76.71021707596319, 59.654312056879846, 65.04547649814238, 57.142026116771085, 65.20477964032081, 56.054792173447154, 61.35003897451586, 49.13353073981501, 47.890880723153394, 45.91714405244397, 51.4295175767714, 54.53502278174124, 57.81153155911354, 54.68062508490778, 52.393216471518244, 58.315434532780806, 59.500366872356786, 60.60812657879245, 58.06934110579952, 56.06717901845133, 56.87653264691753, 54.56124382634317, 53.432844608060776, 52.95238564091345, 51.92090034484864, 48.23979908420194, 47.75146792011876, 48.49963257389684, 53.19041075245027, 54.41705357643866, 51.20180829878777, 52.65818826613888, 49.20379215671171, 42.3573342446358, 39.06824250375071, 36.526209308255105, 39.04708131667107, 36.651019127138206, 37.56336635158908, 38.46468387111541, 39.27206062501477, 42.76808092671056, 47.20375207162673, 45.61236020057432, 45.830404758453376, 48.093569201807824, 53.18795142635223, 50.03263604256415, 42.37236084476594, 40.208738311644524, 39.85073966364707, 41.88968573847125, 41.00699947726342, 44.680044189576186, 43.92163430490802, 46.52241676084457, 50.48828994074176, 41.54035160618444, 37.57086200098838, 41.23667386270339, 42.814094251202, 43.447800220981726, 45.40817337651407, 44.1698811131139, 45.44158412564186, 39.58153170924033, 42.562580108642585, 41.0772922731215, 38.433493183505156, 41.51424038794733, 41.10064606512747, 39.53188234759916, 38.41813318191036, 40.46499067737211, 39.94231916243031, 39.01823228405368, 39.27746957348239, 41.574990057176166, 37.91109231210525, 39.775014385100334, 49.66742023344963, 51.35696549569407, 45.63100714837351, 40.72839352392381, 37.97316382008214, 38.971336426273474, 36.91171946064119, 38.09176060461229, 36.910264261307255, 37.12115833836217, 38.47765122690509, 39.37727820488715, 39.25007181782877, 41.0877767685921, 40.545112932882006, 44.09192792830929, 45.80374440839214, 46.378450086039884, 44.03772469489805, 41.99244791461576, 40.96543412054739, 43.916750954043486, 51.083580217053814, 55.1027976312945, 52.25844383239747, 65.26570189383723, 61.42570933988018, 51.374157244159335, 43.49900284121114, 42.91609548753308, 44.89786124998524, 45.02364773904124, 47.80662821185204, 55.24326555190548, 56.975403831851104, 61.182075238996944, 57.011630842762614, 60.20955493373256, 61.5426234276064, 60.59459047932779, 55.00477760068832, 53.041945119057935, 57.04384919135802, 65.40228274560744, 64.32228165288126, 65.00748442065331, 53.550472567158366, 54.38256809788366, 9.355620664934959, 0.47806797609213864, 2.2471516122741084, 3.977706725558927, 0.11099129344426817, 0.1416033548453162, 39.92454690317954, 75.47835749964561, 63.966079450422725, 74.2042383070915, 64.57689446787681, 52.58340043406333, 30.710524782057735, 21.092106296170144, 35.383744470534786, 63.892291822741115, 36.810337958797334, 0.1967187997915091, 0.025782060899561452, 0.1052313311506183, 0.04674670429179265, 0.008102238775351116, 0.048199111235237894, 0.022964925775604866, 0.03164389373494252, 0.06779196311629589, 0.08627402581154339, 0.16921952216615602, 0.0066477121623803774, 40.644615619413315, 74.42629152728666, 45.012967125062026, 41.26826463207122, 85.60670175860005, 101.57330574527865, 56.957255025063795, 64.31411135581233, 77.06519157655778, 63.535105105369325, 81.12978689132198, 25.689126099309615, 0.25971750398316695, 0.4460470943200973, 1.7363493120478046, 4.494656237863726, 0.5973341376070054, 0.1348179302388622, 30.766012591700402, 73.96483252125402, 60.72629190260365, 68.09120085931593, 60.018664944556456, 67.6088591544859, 59.07394639907345, 65.71034962131132, 51.36293142072616, 47.39744263310587, 47.28831837254186, 54.133077898333156, 56.8512882724885, 59.640262126922615, 57.7872520877469, 55.30897701940229, 57.80908400012601, 61.96430175535141, 60.672884910337395, 59.75325384447652, 57.260297344576934, 58.75217868435768, 57.35711712991038, 57.72055218296667, 55.12190741877402, 52.80466525785385, 51.61261773878529, 48.60724279957433, 48.9258804628926, 53.83884129985687, 56.48296202382734, 54.64344101567423, 54.81032217702558, 51.707119403346894, 44.63567041581677, 41.3141445959768, 38.15868408449235, 41.681286288845925, 40.61799841542398, 38.8501077313577, 39.490791597673976, 41.306731316351126, 45.02677779043875, 48.43788662264424, 46.58490796242991, 48.571325655906435, 51.223208750447924, 53.93058161581717, 50.58682380184051, 42.54148560185587, 42.0980106630633, 41.99201253152663, 42.24642922801357, 40.577154774819654, 45.12875157017862, 43.458912295679895, 47.526217968233176, 50.99458556021414, 42.25079090364518, 38.432214490828976, 42.932443926411295, 45.17059933754706, 44.82095926038681, 47.250973486131244, 46.260410278074204, 48.550411578147646, 40.52119824194139, 41.37594546041181, 41.35858897239932, 38.08284113484044, 40.77320268077236, 41.14275663129745, 38.93388955823837, 38.433532407206876, 41.45262387491042, 41.349092914212136, 37.308506427272675, 39.53287078488258, 41.83774963501961, 38.01183446761101, 40.1673141602547, 51.97083603951239, 53.903917343385764, 49.7508059009429, 42.47591533968526, 39.12295172291417, 40.58318738014468, 39.88140867602441, 40.06251627399076, 39.7077339695346, 39.149423799207135, 40.12787865054223, 41.40465328770299, 40.91045818021221, 43.93857502168225, 44.11950611299084, 46.011363306353175, 47.509304708050145, 49.42051095347251, 47.963028800102975, 44.17290526051676, 44.06884477984521, 47.09157620706866, 51.58368633639429, 57.66119103277884, 54.22955643746161, 64.2724165608806, 65.12559875365227, 52.94088132919804, 45.83182465645575, 44.27283156302668, 45.31478958745157, 46.33762605728642, 49.423970483964496, 57.629141346100845, 60.02436022604666, 61.3109996241908, 59.1784304957236, 63.41766542004001, 64.32122261293473, 62.04315316292548, 56.799258032152736, 54.9986037900371, 57.95604736574235, 67.56783116248347, 68.03487562364148, 68.22252965742543, 58.09300868741928, 58.79079441870413, 10.589394357896621, 0.6576823154764792, 3.9920471560570503, 12.07910172400936, 0.19351911100168384, 0.0538519284717979, 43.6316103319968, 81.76969805071431, 69.645322368991, 79.63755253822573, 72.58206367492676, 57.82483231636786, 33.273391646723596, 26.70394720569734, 43.830043039014264, 74.11367862455307, 47.01918886553857, 0.43228242486234636, 0.01104531109318017, 0.1642523459609478, 0.03526592679742364, 0.06400949209027233, 0.20046493909772367, 0.14905023508735243, 0.09413739741449395, 0.185382935488897, 0.13070226076149172, 0.27041953778074634, 0.10575995480100955, 52.22487618846279, 84.58225711699455, 55.59046591481855, 54.65982475588399, 83.96560561272406, 91.25570712550994, 60.55884591994747, 71.35724867543867, 81.8109300059657, 69.01759409135389, 89.0003050527265, 29.380047013682706, 0.29438834517232837, 2.002020391725725, 3.770810034005873, 9.525304359774436, 3.9865524057419073, 0.5559707216678128, 36.732886837374785, 75.01685926991125, 62.457429978155325, 70.17693688792568, 62.337334848219356, 70.50330946522375, 60.91447937873102, 66.6882396513416, 54.12245219753635, 50.91190199698172, 50.463888875899784, 56.15000770938013, 58.98207272252729, 62.36850984634892, 60.7899009796881, 56.92276562413862, 57.19156957441761, 61.64204766673427, 62.9661770789854, 61.63157101600402, 59.45615391577444, 61.662400845558416, 58.35953766299833, 60.259239596705285, 56.45130457416658, 55.98849627279467, 51.24942195030951, 51.57262525250835, 53.916182594914595, 56.54191524751725, 57.379423649080344, 56.91122993346184, 57.3617337596032, 54.32576041067801, 46.571026694390085, 43.42766669488723, 39.68429388538484, 44.3159148769994, 40.89994230578023, 40.65086003272764, 42.073825328580796, 44.265171174080145, 47.08413939322195, 53.64782187246508, 48.783090499139604, 51.33498453324842, 55.964958129390595, 57.58438318006454, 54.880128598982296, 43.92900836083197, 42.865434154387444, 41.267174213163315, 42.966905870745265, 40.42409604595554, 46.327474963280466, 44.17858485252627, 48.09366333869196, 52.352227703217544, 42.23806673480619, 38.68055151354882, 44.038113009545114, 47.185524817435976, 49.477314718307994, 49.07472656619165, 48.505414147530836, 50.50256344579881, 41.965003090520064, 43.790583995080766, 42.765700048015965, 38.9922308921814, 42.40270822278915, 42.29734159285023, 39.13339699468305, 39.20654919839675, 40.763902741093794, 42.13716768449353, 37.38938570022583, 39.714554971264256, 40.32323229697443, 38.2179432530557, 40.00011136454921, 53.615152451299856, 58.584411067347375, 50.879977826149236, 46.17459666344428, 41.56134413134667, 42.9193510547761, 41.75957287511518, 41.981849670410156, 41.406767445225874, 41.70034900788338, 42.25761190537484, 43.91422102528234, 44.28389656928278, 44.887141412304295, 46.36107006380635, 48.764439628970244, 49.53237302841679, 50.4409900788338, 50.07055359501993, 46.7389629733178, 44.676588581454375, 48.99035638378513, 54.72218259688347, 61.576293053165564, 58.91557678099602, 68.12869871816328, 62.56438909038421, 53.74287266885081, 46.45976474208217, 45.94114503552837, 46.823827374366026, 47.1393467533973, 50.59934008506037, 60.4419671335528, 61.40152792776785, 67.1771474038401, 62.001995732707364, 66.40934344260924, 67.95048190701392, 65.54849693852087, 61.04012074009065, 58.25613221814556, 62.386474301738126, 71.24568862299766, 71.51077024398312, 71.52639696674963, 63.35792772231564, 64.36319589614868, 13.202841166527042, 0.8117097471990894, 6.398718866609759, 24.1274324540169, 0.6599669735277853, 0.26547673849328873, 49.37816112272201, 88.88359100587907, 76.62055953856438, 87.41940944425522, 80.28304915274344, 72.414672605453, 43.23367803327499, 34.90874544266732, 55.81248775605233, 82.21442422559186, 60.0687300774359, 0.7368146015271064, 0.15533053196005284, 0.23191862469238622, 0.15662594067473568, 0.1319983589553064], [0.05100296239458746, 0.07336653979314912, 0.08412223038894516, 0.08690302230177388, 0.2079861298684151, 0.07650883327568732, 0.12023478010368925, 33.61022518527123, 65.70408167377596, 45.31029847360427, 20.443609068470618, 22.082720495039418, 36.44983683862994, 44.97221369897166, 61.16110232568557, 67.5217511576991, 64.41404158069243, 70.71628632084017, 31.91406680691627, 0.046770173395352985, 0.14651223175948666, 0.5100796035220546, 4.486188330957967, 0.4683485879532753, 0.31586807161088915, 25.889141482691613, 71.08245526590656, 60.64167461087627, 56.9548741463692, 55.09808686471755, 59.704675289892386, 57.51093679858793, 53.49420224466632, 47.219276812768754, 46.9544069997726, 52.654540461878625, 55.61530628511983, 57.05997405513641, 57.813704552189, 50.642976453227384, 62.18892412800943, 61.34004869768697, 54.92127426208989, 52.8421474272205, 55.16865814885786, 52.272980136256066, 52.493676216371604, 52.55591638626591, 50.34445662652293, 45.42064259129186, 48.85668985305294, 46.741210491426536, 49.6583281793902, 49.710201524919086, 56.48397791770197, 54.93049183199483, 54.97799957952192, 53.00478066167524, 46.45030790759672, 41.3456412284605, 38.256429549186464, 37.56326044759443, 37.227909564971924, 38.15100408369495, 39.73342549416327, 41.043908980584916, 41.85746738987584, 38.491348143546816, 37.023271668341856, 37.748451232910156, 41.82969308668568, 43.887627355514034, 49.98952527200022, 48.41136355553904, 43.05275086433657, 39.65579002134262, 39.88290309906006, 42.11914047118157, 39.88180875778198, 41.5295611658404, 42.69341861048053, 44.633783755763886, 49.99256903125394, 45.89245273220924, 41.839957929426625, 40.393595695495605, 44.36755288031794, 42.63226885949412, 46.66111961487801, 44.45796743515999, 44.4774341583252, 38.32342363172962, 39.40581344789074, 40.56017875671387, 38.28852630430652, 40.32090240909208, 40.12637246039606, 39.02187224357359, 41.15102890999087, 41.15188006431826, 42.15799547010853, 41.198642561512614, 39.581700371157744, 39.99303540875835, 38.646599477337254, 46.21147478780439, 49.18742018361246, 47.868578126353604, 41.56332100591352, 38.16725446331886, 38.93923967115341, 41.48513640126875, 39.9356040646953, 37.226285703720585, 36.24809365118704, 39.77512813383534, 39.70327815701885, 38.52158177283503, 39.73182908950314, 39.85985132955736, 42.577238005976525, 45.42360398077196, 46.30454086488294, 47.70742362545383, 50.160775953723544, 45.11611761585359, 43.780601562992224, 41.24324383274202, 43.28407656761908, 47.717943422255985, 55.44108636917607, 53.87648820877076, 56.689584639764604, 61.03917152650895, 58.782679034817605, 55.32768672512424, 53.68701811759703, 55.508323638669914, 57.66072819309851, 60.86058209019323, 59.48523436823199, 57.77755598868094, 58.75075094161495, 61.56560851681618, 59.40437078475953, 60.55979513352918, 56.647203430052734, 55.760822296142585, 51.47613886863955, 61.26905379756805, 58.608639547901774, 66.1570801273469, 63.91810101847496, 58.36345611080047, 5.2384155796420195, 0.45811346942378633, 1.4005357123190358, 7.449016340317265, 0.4427484422922135, 0.08389074160086532, 47.952881628467196, 72.1647705570344, 63.65081502545265, 66.49587877335088, 65.30150136639996, 50.03442072099256, 17.598923829294023, 36.65383538892193, 52.826454024161066, 68.23180998525312, 33.14341214395339, 0.3258566324028277, 0.033597835459776466, 0.10894876514231006, 0.08877948572438571, 0.021040382674865184, 0.03351952978259614, 0.15971220248649198, 0.049812162985965136, 0.14694755356157982, 0.13107284813398315, 0.0484260494610475, 0.14611876900157622, 42.53200131077921, 74.29764563037504, 52.09439069994035, 30.925074508113248, 43.91915536695912, 52.341617691901426, 49.37138326706425, 67.52884280297064, 71.21387820090018, 68.78682536463585, 74.6246850106024, 37.70294781654112, 0.16948215242835785, 0.11503079079932745, 2.8472046265679025, 2.939389641246488, 0.6697333075346485, 0.23503634207431348, 31.465298629576164, 70.87747220070132, 60.358577543689364, 59.02210443250595, 56.44810392010597, 61.23304251701602, 58.91408628033054, 54.981357128389426, 47.40312222511538, 48.81030390339513, 54.698852339098536, 58.36870031972086, 58.47090159693072, 58.40378592091223, 52.680196685175744, 61.480143993131584, 59.85894995350992, 57.815304879219305, 55.902968991187315, 57.86955125870244, 52.96616100495862, 54.38303485993416, 53.197545543793716, 53.79841735286098, 47.976470762683505, 52.215199701247684, 47.862482763105824, 52.394553999747004, 52.047902768658055, 58.524151694390085, 57.06697156352382, 55.9591922452373, 54.75486378515921, 48.482291775365034, 43.49115025612616, 40.09036117984403, 38.90989249752414, 39.171032136486424, 41.22963713061425, 41.161576163384225, 41.932769052443966, 42.381605871262096, 42.994025138116655, 39.96231932793894, 39.097581832639634, 43.254243020088445, 47.42865293256698, 52.08169791006273, 52.11128042590234, 44.07632866213399, 41.064736766199914, 41.76371097564697, 40.62813381994925, 40.867465080753455, 41.61038552561114, 44.597038991989635, 43.73586300880679, 51.34915213431082, 45.99328510222897, 41.900248681345296, 40.67136618398851, 44.31315352839809, 44.05773662751721, 48.78811897770051, 45.98441270089919, 46.35471190175703, 41.668483672603486, 39.92335450264716, 40.56353630558137, 38.846236351997625, 41.05381296527001, 40.63684932647213, 38.63833504338419, 41.016009161549235, 39.3408158517653, 43.079313155143495, 42.332795896837794, 39.054255331716234, 39.62172031402588, 39.1016101068066, 45.567531431874926, 50.448807362587225, 49.69201349443006, 44.853609069701164, 39.81948621811406, 40.686063305024184, 41.99828047906199, 41.70240825222385, 38.92183611469884, 40.629624320614724, 41.40876000927341, 41.222368978684955, 40.00938777000674, 42.412345486302534, 41.54989865518386, 44.198973332681966, 47.778900977103945, 48.569348781339585, 50.342318934779016, 51.71565840321203, 46.5867946224828, 44.53581471596995, 43.68312674184, 46.07047734722015, 48.76306287703976, 57.63938265462076, 55.35959128410586, 58.23439836502076, 59.28353040449081, 60.910835496840946, 59.136567038874475, 56.96419369789862, 58.84945738700129, 60.57134651368665, 63.26828587439753, 61.067243929832216, 61.547675440388346, 61.77421585206063, 64.11477258128505, 61.830164540198545, 64.06043990965813, 59.86929324365432, 58.164129103383715, 53.59562297021189, 63.277503444302475, 63.57270886821132, 70.83118823266798, 65.22050049997145, 62.436033448865345, 6.134506540913736, 0.21411242774657666, 2.972942576293023, 6.647782998700296, 0.1999828246452155, 0.004923349272670044, 53.046098909070416, 78.17618723838561, 69.83324312394666, 72.64646899315619, 71.7449906564528, 64.58106786974015, 27.944718407046413, 35.95867764565253, 60.82553963507376, 75.74023062183012, 42.65037059783936, 0.4026360172898539, 0.06919123037087341, 0.18507164332174486, 0.10753892587437745, 0.07120344457366774, 0.20779871411861914, 0.28833101052911053, 0.1881103923604373, 0.15948024638477834, 0.27722252112242485, 0.23042660717281604, 0.2367181502162449, 48.81617961391326, 84.10005661749071, 63.26324955109627, 37.494132595677534, 34.80183732125067, 45.78729398788945, 60.16869168127737, 72.62961849089592, 79.45247942401518, 73.01789391425349, 82.01048451085245, 40.63724548585954, 0.27193519677365985, 0.8679068929726078, 4.392927606259623, 10.333327324159685, 3.311712539965107, 0.4757190279422268, 37.22589738907353, 73.00604051159274, 64.70155915906354, 60.499649509306884, 57.665101635840635, 66.89064179697345, 61.8022882553839, 57.00792812531995, 49.49153331018264, 50.988211708684126, 55.76123806738085, 60.49238920211793, 60.60787554710143, 61.53670849338655, 54.78611330832205, 61.66487586113715, 61.99454715175014, 59.931360829261045, 57.90510754431448, 60.30506856979863, 55.8959714827999, 57.09494982996295, 56.499890973491055, 57.03578087591357, 50.95830755849039, 55.934418555228945, 50.745126739625015, 54.82030460911413, 55.37727725121283, 61.168543061902454, 60.19702688340218, 59.36068734815044, 57.461291359316924, 51.28271110596196, 45.98266724617251, 43.48586290113388, 41.25543455923758, 39.92549219439107, 43.88270478094778, 44.094822637496456, 44.51268057669363, 44.34440305156093, 43.18673118468254, 41.95722110809819, 41.522242023098855, 45.7775390532709, 50.21762286463092, 55.68248471906109, 53.60245573905207, 45.86469019612959, 42.27247768832792, 41.68897805675384, 41.40764605614447, 42.763931059068256, 42.96916123359434, 45.87275458920387, 45.44856202217841, 52.23669428979197, 46.12533561645016, 43.97493539317962, 41.86181729839694, 47.685211243168006, 45.44964067397579, 51.339306985178304, 50.01805659263365, 48.7984073546625, 41.20364750585249, 39.66257179937055, 41.387955757879446, 38.4002197173334, 41.483571375569994, 40.378580862475985, 39.17333456777757, 41.61994826409125, 39.63776280803066, 43.07227642305436, 42.35498474490258, 38.25591571869389, 40.75660321020311, 40.44926197298112, 46.990198627594985, 51.94683505642799, 52.187103763703384, 47.11710691452027, 41.62649469990885, 43.419637603144494, 44.687018163742565, 44.59929435483871, 40.37075181161204, 42.47805303142917, 44.10499726572345, 43.556787198589696, 41.78168327577653, 44.87082043001729, 44.14043588023032, 46.85007587555916, 50.540512377215975, 51.77058727510514, 55.02489151493196, 54.33537021760018, 48.91863584518433, 48.654350465343846, 45.54994744639243, 47.514690122296734, 53.34251634536251, 60.414840021441066, 57.289852403825336, 60.99091852864912, 62.47159757921773, 63.320880936038115, 61.84402619638751, 58.49512223274478, 63.08033766285066, 62.682974107803844, 66.52877176961591, 63.85099710956697, 64.41234319440781, 64.15001507728331, 65.09103482769382, 64.3749669290358, 65.3128566280488, 63.58362482440088, 61.63750163970455, 56.35253144848732, 67.79240254432925, 65.19291447054955, 75.51665552200811, 70.37092947190808, 63.50240430524273, 7.321723170818822, 0.8126611058269778, 4.137465598121766, 17.626858949661255, 1.1356948268029, 0.0958745860524716, 58.437490847802934, 83.50599012067242, 75.69680213928223, 78.98988293063256, 78.85114869763775, 70.15559134944793, 29.175822927105813, 53.557834855971805, 70.74360170672017, 88.35887201370733, 52.75879313868862, 0.5585469221395831, 0.08235827463889316, 0.3032907158617051, 0.23152195968695227, 0.1487237284140241], [0.024564134317540356, 0.05975391963616975, 0.03932941419583175, 0.027891673605829, 0.08740868629707445, 0.093974971452788, 0.2841983032563041, 19.133806113273867, 68.66101141898864, 51.88801519332394, 32.26870202249096, 23.122297640769716, 39.8603847719008, 44.98503592706496, 57.82421258188064, 66.01867537344656, 64.19083518366661, 65.62590491387152, 41.24448330171647, 0.03239379422138295, 0.24801849868268738, 1.7419167487852036, 1.8644522058386959, 0.19567164952956861, 0.13561478425418177, 30.142887215460505, 50.98850980881722, 45.59671386595696, 63.31449139502741, 62.17996151216569, 61.74142875979024, 55.027629329312234, 51.649633146101436, 47.815410398667865, 53.06049400760282, 55.980114167736424, 57.30567916747063, 58.93906001121768, 53.00847161200739, 56.48326404633061, 58.89212492973574, 53.926314077069684, 56.913344090984715, 54.60092252300632, 55.00545617072813, 53.27124295696136, 48.250491465291674, 47.23693532328452, 46.43073920280703, 47.64582280189761, 47.82918576271304, 49.41506670367334, 52.43230681265555, 55.2824814088883, 54.898355853173044, 51.29549411035354, 52.78016613375757, 50.486030655522505, 45.53557588208107, 39.86938268907609, 37.71423247552688, 37.093533085238555, 37.88327878521335, 35.23558870438607, 38.76617293204031, 38.69824140302597, 36.147273048277825, 37.503742402599705, 37.697856580057454, 38.70982808451499, 40.91332935517834, 41.32109895829232, 48.567901426746005, 47.966256910754794, 45.389624487969186, 40.498440650201616, 42.500312482157064, 40.822236230296475, 39.009634448635964, 39.75218619069746, 42.952451936660275, 43.82450072996078, 50.06478378849645, 49.47329428888137, 43.67800412639495, 40.56496797069427, 44.3391509979002, 42.405375434506325, 47.18294389786259, 46.02761368597708, 44.44190925167453, 40.53848412729079, 40.21225275531892, 40.007759986385224, 40.89244665638093, 39.75863848963092, 38.99512952373874, 39.693323181521514, 42.153245479829856, 40.81037106052522, 40.904817811904415, 40.34742547619728, 37.896442259511645, 37.37738324749855, 44.04874263271209, 49.285291164152085, 48.63244795030164, 44.90953814598822, 41.60676910031227, 37.29938299425187, 37.036144887247396, 37.51254027889621, 38.99848315023607, 40.054483259877856, 38.81255495932795, 37.22725060678298, 39.89147347788657, 40.19854407156668, 38.55369029506561, 38.50242883928361, 39.45197974481891, 45.11789444954165, 48.60623867281022, 49.40206796892228, 52.23221494305519, 52.6056206610895, 50.070867384633715, 45.41613971033404, 41.87998571703511, 42.07790459356001, 45.13667083555653, 51.80136219147713, 54.85480577714982, 50.85174852801908, 55.11813409866826, 55.258727535124756, 56.453089252594985, 55.896979531934186, 56.510269564967004, 56.25169123372724, 57.09515771558208, 56.39068042078326, 56.73097348982289, 58.72220393150084, 62.721891864653564, 60.261008585653, 56.39543041106194, 53.42114025546659, 53.96190174164311, 57.0508937681875, 62.75840913095782, 66.59892728251796, 67.86929668918734, 59.86081700171194, 3.8555587251340193, 0.6518618245759319, 3.9590261924651364, 4.86891261992916, 0.1725304928878623, 0.5433570533510178, 53.06940563263432, 70.9333267519551, 65.775398208249, 69.4287290880757, 66.73421767450148, 49.216171156975534, 21.43081865003032, 36.70539494483702, 46.07862803243822, 70.56473378212222, 19.3848083865258, 0.4504978200120311, 0.1353474195686079, 0.13467471776229722, 0.1227424463497535, 0.007312231192049841, 0.06646710598180372, 0.09247373789548875, 0.008948252652771771, 0.10662558819017104, 0.05924557050269458, 0.17241991575687163, 0.2543747301904425, 25.567416914047737, 76.74872690631499, 60.463544091870716, 34.18501715506277, 22.196508453738307, 41.03314207446191, 50.98579552865798, 64.39830110919091, 73.05587814700219, 68.50625038146973, 72.43366472182736, 45.06422465847385, 0.02501600744923757, 0.1659122286664863, 1.8352972283478708, 4.596434389391254, 0.31785089102002884, 0.09560061002811117, 33.26278948014782, 54.124130971970104, 50.202172648522165, 62.496563465364524, 63.83004380810646, 63.090116131690245, 57.60991780988632, 53.68717109003375, 49.59153021535566, 54.527935058839866, 57.854575649384536, 59.333850491431456, 60.79014416663878, 53.60892764983639, 56.173883176619015, 58.28063134224185, 56.09970723429034, 56.542805625546364, 54.697197098885816, 57.441338262250355, 54.518384087470274, 50.77723133948542, 48.70010883577409, 48.397054749150435, 47.69358942585607, 48.223034874085464, 50.159116791140654, 53.27392193578905, 56.390821626109464, 58.75135106425132, 51.91209070144161, 53.48093678874355, 53.378559004875925, 47.80449444247831, 43.49031086890928, 39.48102881831508, 39.095648104144686, 39.63939843639251, 37.34105425496256, 41.0273055876455, 39.290511454305346, 38.75758686373311, 38.96173446409164, 39.27547700943486, 40.79373628862443, 41.738086131311235, 43.705221453020656, 51.63103718911448, 51.08358806179416, 45.72747784276163, 40.18267808421966, 43.10653440413937, 40.170385376099624, 39.52560263295328, 40.92597507661389, 42.370717371663744, 44.01307652073522, 50.5980888489754, 50.506976112242675, 45.89347647082421, 40.78240848356678, 47.44924145360147, 44.14856695359753, 50.68990368996897, 47.055270748753706, 44.6689478043587, 40.081496623254594, 40.98035089431271, 40.14194426998016, 41.512722430690644, 40.6362727380568, 39.32068624804097, 41.479362672375096, 40.982245399105935, 40.38524889176892, 40.61320527907341, 40.65719858292611, 38.545080692537375, 38.00461730649395, 44.746371469190045, 49.60446619218396, 51.14655387017035, 46.641072380927305, 42.3858263415675, 38.49339562077677, 38.02382907559795, 38.529108801195704, 39.280085794387325, 41.398871714069, 40.344573913082, 39.71019721800281, 42.486490049669825, 41.864257012644124, 40.83463876478134, 41.24214556909377, 42.27898490044379, 45.21769915857623, 50.48186902076968, 52.380825704143895, 54.298256751029726, 53.81389110319076, 52.02772609649166, 47.86089420318604, 43.961913124207534, 45.383383997025035, 46.65343961408062, 56.18814099219538, 57.17834726456673, 54.750204009394494, 56.947158844240256, 57.748251961123565, 58.61549585096298, 58.75234734627509, 58.38031838017126, 59.37848706399242, 59.430909541345414, 58.80909227555799, 59.6303738317182, 60.387097097212276, 64.21472241801601, 62.69814975800053, 57.842718324353626, 56.964774208684126, 53.81925298321632, 60.93835484596991, 65.56744198645315, 70.84159035836497, 68.51676233353155, 63.20877175177298, 3.819266259670258, 0.36908240808594617, 4.653913782488916, 8.162967629971044, 0.6595463606138384, 0.6112739347642469, 58.51587157095633, 78.73470921670237, 72.56416197746032, 73.80506653939524, 71.901807015942, 58.957836397232555, 21.388786531263783, 40.841561748135476, 53.27740892287224, 81.23080361273982, 26.90280352869342, 0.4237833841433449, 0.14334459608841327, 0.0646793095755481, 0.09301115623525075, 0.013618307402207246, 0.20633006228073952, 0.2083399399153648, 0.16151640083520644, 0.18814583158781453, 0.1641601089748644, 0.25894271330006663, 0.42343288359622805, 32.28995734645475, 90.49484575948408, 67.10140643581268, 45.60888498060165, 32.01963543891907, 55.99008483271445, 60.519029940328295, 70.3119291797761, 79.48379562747094, 75.05166638282039, 76.72553785385625, 50.06028875227898, 0.09596385061740877, 0.7207635886246159, 6.271672316135899, 10.478993365841529, 2.6646178047503195, 0.25947208005574446, 40.35539573238742, 55.76843169427688, 53.40402695440477, 64.67774252737722, 67.15599798387098, 67.72434942183956, 60.082827075835205, 56.09756562017626, 51.89606389691753, 56.92968860749276, 60.45733105751776, 62.11316354813115, 60.32435094156573, 59.77162622636365, 56.82998980245283, 62.7509174039287, 58.91825575982371, 58.59212244710615, 58.65326435335221, 61.26046772926085, 58.306628811743956, 50.47633455645654, 51.63486150003249, 51.74132247124949, 51.21881569585493, 50.70655807372063, 53.70161717937839, 56.87887822428058, 59.21991348266602, 57.412316645345385, 55.710121739295225, 56.7126795553392, 55.63038387606221, 50.070867384633715, 45.38419985002088, 40.82389931524954, 40.11874345041091, 42.01885331061579, 39.47365476239113, 43.04853039403116, 41.41247841619676, 40.167427908989694, 42.305288314819336, 41.936958143788004, 44.23621231509794, 46.461973036489184, 46.282457920812796, 54.000741051089385, 55.27726465655912, 48.34999415182298, 42.08352927238711, 45.5818873067056, 41.55699422282558, 40.54083362702401, 41.53236173814343, 43.3475483617475, 45.315942764282234, 54.3690594550102, 51.33968745508502, 45.98939018864786, 41.57580591017201, 48.54666179226291, 47.41779973430019, 50.97303213611726, 50.836227709247225, 46.63400426987679, 41.31727464737431, 40.271307960633315, 40.972133528801706, 42.01077322806082, 40.023068997167776, 39.26871484325778, 41.64080742866763, 43.45380144734537, 41.302601060559674, 40.27412030004686, 41.923300450848, 38.552627332748905, 38.99196024863951, 46.66874862486317, 51.45520125665973, 54.84728267115932, 47.64169254610616, 44.66317015309488, 40.53027852889031, 39.39710186373803, 40.90215452255742, 42.75827500127977, 43.31139587586926, 42.67995703604914, 41.462637685960345, 44.30421836914555, 43.96930679198235, 42.25286191509616, 42.28105591189477, 43.47305244015109, 49.455243541348366, 52.42169680133943, 55.56124817940497, 56.44402465512676, 57.59820169018161, 55.64342183451499, 50.052679354144686, 46.09447440793438, 46.89541455238096, 47.55729098473826, 57.83858022382183, 59.955071556952696, 56.65052959995886, 60.74230301764704, 61.1251381135756, 62.15845515651088, 60.10912656784058, 61.297781236710094, 61.77904036737258, 63.12782187615672, 61.01765340374362, 61.617960391506074, 63.6462180076107, 68.10172065611809, 64.61534154030585, 62.761221470371375, 59.294112959215724, 58.79256733002202, 62.07182176651494, 68.8159764197565, 74.68854904174805, 73.97534447331583, 66.91949475196101, 5.841692782217457, 0.8737204584383196, 8.548821480043474, 20.76356464816678, 0.9062814628404956, 0.7027046899161031, 65.29231125308623, 86.63378223296135, 77.64916973729288, 82.72018248035063, 79.61182963463568, 68.51997083233249, 31.665751357232374, 53.99046836360809, 62.3508591805735, 94.94608479161417, 37.925911026616255, 0.5381678189000776, 0.21873555386499052, 0.22630145352694298, 0.19689739020841737, 0.12421989287700384], [0.0952347417572333, 0.052159456385960506, 0.16544880675933055, 0.04959994513962058, 0.19133995857930955, 0.15042205341160297, 0.38499524937041346, 12.722065467988292, 67.5993513291882, 48.79409274747295, 31.52648368189412, 21.754420072801654, 34.10038025148454, 46.13569067370507, 62.83775083480343, 64.28860418258175, 63.33385613656814, 67.49471033773115, 44.16622938648347, 0.034512747454667286, 0.08691794569453887, 1.105394884943962, 1.8281693011522295, 0.6701599878649558, 0.032924949792363954, 32.26230463673992, 51.26389549624536, 45.04419311400383, 66.07311002669796, 56.4048009534036, 61.24484492886452, 51.73865918190249, 52.68916322338966, 51.85047026603453, 59.34974785773986, 56.68769405734155, 61.29161527079921, 48.55361615457843, 53.47036207875898, 57.9822801774548, 53.230356170285134, 55.52826104625579, 49.75262195833268, 47.74889092291556, 45.372550410609094, 43.990781768675774, 44.11973753283101, 43.82059797163933, 47.14165310705862, 50.48685827562886, 52.31693029403687, 51.9392688043656, 53.53594803041028, 55.16666166244015, 47.26517246615502, 49.39202277891098, 54.87903033533404, 50.61311152673537, 41.16105056578114, 39.43778076479512, 37.118585263529134, 37.53006935119629, 36.54809613381663, 38.42357743170954, 38.750856076517415, 39.33166496215328, 38.85257490219609, 38.20290096344487, 37.701884854224424, 35.932119277215776, 38.25222476836174, 42.50163824327531, 46.59052479651667, 47.57691852508053, 46.56809276150119, 40.23045255291847, 42.52730231131277, 40.44007970440773, 41.43280806079988, 39.78751497883951, 42.08898921166697, 44.25888361469392, 48.602402594781694, 49.092318396414484, 49.04765044489215, 39.89360724726031, 43.91656268027521, 44.22786943374142, 49.16294459373721, 44.38557224888956, 43.92580770677136, 38.92484849499118, 40.7849697912893, 41.16587900346325, 41.582787729078724, 40.34821387260191, 40.836478356392156, 40.27163743972778, 41.74397360893988, 40.32494245036956, 39.44644528050577, 40.88462545025734, 37.76956535154773, 40.04306131793607, 43.97547275789323, 46.31352701494771, 47.78999343995125, 42.593782563363355, 40.09453458170737, 38.12723452045072, 37.49702338249453, 39.04940335981308, 36.85857918954665, 37.478533329502234, 38.787279205937544, 37.0134892771321, 38.67033373924994, 39.099182159669944, 37.18644618988037, 39.43460756732572, 41.05415028910483, 41.897436341931744, 50.66601645561957, 51.618493449303415, 54.09219111165693, 53.84469739852413, 55.04060845221243, 50.73754087571175, 49.22189781742711, 43.3624533684023, 43.76684581079791, 43.222008982012355, 45.895625929678644, 50.072204912862475, 49.104010981898156, 50.898271760632916, 51.40843091472503, 51.36373550661149, 48.9141486537072, 50.27723504650978, 47.794786576301824, 47.688509956482925, 50.33412510348905, 50.62492178332422, 49.03743659296344, 50.716116889830566, 49.62641577566824, 52.10548708515783, 51.861688244727354, 58.352626446754705, 59.88552793379753, 68.98477954249229, 67.2447455313898, 59.45444768474948, 1.2153679709280691, 0.025676775520907778, 2.977617551242152, 4.186280475508783, 0.24874922398838306, 0.6195904014091338, 58.42673178642028, 68.6229173598751, 69.26730002126386, 74.76813393254434, 71.84804701036023, 51.53935963107694, 37.4467856653275, 36.61636890903596, 51.17711697855304, 73.64740294794883, 16.685131211434644, 0.37415697449638, 0.11910860787235922, 0.08642731234431268, 0.1604939032826693, 0.04697839992361204, 0.10327998263340804, 0.07692271227677984, 0.0801626819696638, 0.088808459169682, 0.061091375086576714, 0.1326470822095871, 0.44603854477886234, 16.252408469876936, 77.18143493898454, 56.123555244938025, 40.02229629024383, 31.31283021742298, 46.497003724498136, 52.11883098848405, 67.96261772032707, 70.01230716705322, 67.87412120449927, 70.37798973821825, 48.498691205055486, 0.08843361234833157, 0.2106549656919895, 2.006900678238561, 2.894145101308823, 0.8040242918556737, 0.0576480818281491, 36.55372081264373, 53.62234215582571, 46.4033414471534, 66.11471068474555, 59.31812963178081, 64.73459336065477, 52.16616222935339, 55.157004787075905, 53.376487993424945, 59.91554975509644, 58.12425428821195, 61.50648663120886, 52.113010191148334, 55.13671044380435, 59.06743134221723, 56.5930001966415, 56.54691626948696, 52.79175281524659, 51.14021924234206, 47.13848775432956, 45.73201210268083, 46.92617377927227, 44.7711451591984, 47.757382854338616, 48.35390867725496, 54.32983575328704, 53.68781043637184, 55.74882376578547, 57.997985347624756, 51.0148799034857, 51.462159541345414, 55.82771047469109, 51.04458009043048, 43.91111450810587, 40.08773711419875, 38.98760641774824, 38.88933143308086, 38.14773282697124, 39.33228861901068, 39.531925493671054, 41.13886956245669, 40.30988054890787, 39.10990591972105, 39.83643085725846, 37.672074840914824, 41.07230301826231, 44.08782120673887, 47.92284019531743, 49.13770021930818, 48.87455232681767, 41.84444512090376, 42.51466443461757, 41.46035094414988, 42.29550592360958, 40.22881300218644, 42.61188037933842, 45.33116940529116, 48.84974333547777, 48.13921774587324, 49.00133117552727, 38.85881931551042, 44.80068845133628, 47.252130585332075, 51.709484592560806, 47.32641635402557, 44.31855463212536, 38.55017192902104, 40.341796875, 40.52986275765204, 41.832505426099225, 39.98214690916, 41.29329719851094, 39.095063670989006, 41.39866382844987, 39.11171413237049, 39.306722610227524, 39.16489362716675, 38.94820228699715, 39.450324504606186, 43.75986791426136, 48.26520427580803, 50.517872456581365, 43.49333109394197, 40.89075611483666, 39.76547910321144, 40.93557703879572, 40.579884744459584, 38.42098866739581, 37.884388815972116, 39.95858130916473, 38.48533907244283, 39.29199803260065, 40.438055761398815, 39.34864098025907, 40.5655445591096, 43.23508224179668, 45.33958681168095, 53.24172319904451, 54.9120919935165, 55.4280052646514, 57.36686421978859, 57.291872424464074, 54.874998138796904, 51.801071936084384, 44.94719682201263, 45.357700317136704, 45.34629406467561, 47.92318536389259, 51.39614605134534, 52.64392260582217, 53.900650009032226, 54.987401500824966, 53.36034744016586, 51.62737761774371, 52.11129219301286, 49.50408097236387, 51.03580574835501, 52.125648067843535, 52.380480535568736, 51.87406724499118, 52.65400309716502, 52.502889863906375, 54.61507443458804, 54.58050266388924, 59.5041911832748, 61.06695759680964, 71.61852559735699, 68.92851706474059, 63.44647522895568, 1.5881556705121072, 0.20865365292035765, 5.035578050921041, 6.512210686360636, 0.575367393753221, 0.8555555944481205, 64.11159938381564, 76.06170023641279, 75.11406344752159, 80.23336056740054, 76.71012293907904, 58.586709576268355, 35.55563449859619, 40.7786233963505, 60.12398058368314, 84.20732559696322, 22.83930647757746, 0.5314636302571143, 0.17972117800626064, 0.11153435019115288, 0.16621946056763973, 0.0200166976860454, 0.2828987423450716, 0.15567354016727017, 0.2817209587702828, 0.16705158527099317, 0.29102111295346295, 0.2683904466609801, 0.6601858295259938, 21.179967388030022, 88.8101093230709, 63.067774311188735, 49.613040493380645, 33.88365753235356, 45.82892602489841, 60.518798520488126, 74.20762723492038, 74.71101637809508, 72.59722755801293, 76.52104900729272, 52.437598090018, 0.19174117414701372, 0.8348138558287775, 3.8733233847925743, 6.326959594603508, 1.5445508038805378, 0.17797252103205652, 38.822455021642874, 55.286219427662516, 49.519460585809526, 66.27102498085269, 62.61751367199806, 68.40762630585702, 57.34083929369527, 57.22528626841884, 56.56547300277218, 62.75159989633868, 59.55930832893618, 64.1792602692881, 55.65713836300758, 58.413493787088704, 62.56878998971755, 57.51438848433956, 59.114515473765714, 55.194812513166866, 52.91141256209343, 49.01549093184933, 48.07616956772343, 49.293328100635165, 47.120899846476895, 50.86992871376776, 53.56742112867294, 56.71196568396784, 57.03722823050715, 57.77769719400714, 61.147636828884, 53.76832492889897, 52.64417755988337, 59.16847944259644, 54.690336873454434, 46.57989909571987, 42.22235764226606, 40.64598060423329, 42.511844250463675, 39.63174589218632, 43.01407629443754, 41.88779515604819, 44.69676525362077, 42.82235868515507, 41.404414023122484, 41.549322066768525, 39.284753414892386, 44.12527591951432, 49.50405351577267, 48.83133172988892, 52.971060045303844, 51.95156935722598, 44.32151602160546, 46.39113503117716, 42.70926106360651, 41.84858322143555, 41.4793901289663, 43.889157079881244, 46.88723641057169, 50.59704157613939, 49.801894772437315, 51.178242698792495, 37.83138975020378, 44.84170467622819, 49.69788920494818, 52.84923515012188, 49.81475622423234, 45.17651427176691, 38.639182275341405, 41.87953856683547, 42.59631641449467, 42.67323409357379, 40.300117769548976, 41.501700570506436, 40.51615015152962, 40.507583695073286, 40.4269201524796, 39.813449690418864, 41.27434430583831, 38.34511433878253, 41.68405548218758, 44.687857550959436, 50.733108597417036, 52.04229770168182, 46.709678557611284, 43.61947844105382, 43.40537978756813, 43.24421744192801, 42.65904295829035, 41.735752321058705, 40.98741900536322, 43.42656450886881, 39.33626982473558, 42.55797524606028, 42.07247211087135, 41.34849671394595, 44.29094114611226, 47.46440533668765, 45.59052044345487, 56.61982920862014, 55.485111051990145, 59.27961195668867, 60.478719742067405, 60.61878758092081, 57.65031430029101, 53.799154758453376, 48.488779375630045, 47.85746212928526, 48.24767912587812, 51.44572481032341, 54.10893570992255, 53.30916050941714, 55.816465039407056, 56.68734104402604, 56.82707940378497, 52.95122461934244, 55.40830319927585, 51.71682726952338, 53.659318339440134, 55.05539578776206, 55.57772605649887, 55.2324947234123, 56.76488630233273, 55.447797544540904, 59.42635566957536, 57.52187628899851, 63.96184329063662, 65.88365170263475, 75.57788372039795, 70.87274182227351, 68.43435333621117, 2.263104627209325, 0.25013379001569364, 8.010410474192712, 10.783212396406359, 1.5688203467476753, 0.9946853739600029, 71.11681522861605, 79.92940825800743, 83.53713373984061, 86.82590776874174, 83.71175765991211, 70.35288656911543, 52.339103452620975, 53.71800091958816, 68.9998806676557, 95.53874707991078, 32.939044890865205, 0.7410652250532181, 0.3313484102968247, 0.24349157788580467, 0.2642251959731502, 0.19257711396823007], [0.073231715979355, 0.007219128047807083, 0.061840927003011595, 0.10809705157073275, 0.0821799906571546, 0.04640665318396303, 0.23521087222522308, 6.776830448258308, 62.54755427760463, 59.91327085802632, 32.06582527006827, 15.274987163082248, 31.715906704625777, 44.57533651782621, 67.97045461593136, 64.25568765209567, 64.45739553820702, 65.3866050320287, 51.70369909655664, 0.4065439850091935, 0.1870275883665008, 1.1561693539542537, 2.6108815785377257, 0.6018793679052784, 0.11122490429589826, 32.05234996734127, 64.7036027139233, 55.79285237096972, 65.61817784463206, 59.39011689155333, 60.63488106573782, 54.51929407735025, 58.165376417098514, 56.33795984329716, 59.40349217384093, 55.08912424887381, 55.1651946959957, 50.8294302417386, 62.026290893554695, 57.28383941035117, 54.423372514786266, 49.18132482036468, 46.378767798023844, 43.09510461745724, 44.05423395095333, 43.12408701066048, 44.065918691696666, 44.96910325942501, 50.25315561602193, 50.699893966797866, 50.639320804226784, 50.72780555294406, 54.67117609516267, 47.657797798033684, 52.926898079533736, 54.05876467304846, 53.938132178398874, 47.33488867359777, 42.217446834810325, 39.275057315826416, 37.834880659657145, 36.13893801166166, 38.06782630182082, 39.500209208457704, 37.18040573981501, 37.915799156312026, 37.63041926968483, 37.37100155122819, 38.555478895864184, 37.85807363448605, 38.89576019779329, 40.97633830962643, 43.65013960869082, 47.472614857458304, 47.214177731544744, 41.39377655521516, 40.108023612729966, 41.658842486719934, 39.05315706806798, 40.65733978825231, 41.73314786726429, 45.60693556262601, 45.63030896648284, 46.39476714595672, 48.80807991950743, 42.03675500808224, 44.76378287038496, 43.15461089534145, 49.35493676893173, 44.595650472948634, 43.525141516039454, 39.94491969385455, 38.63359289784586, 41.41950730354556, 40.50389274474114, 40.120806617121545, 41.721259163272, 42.26532328513361, 43.99713600835493, 40.354921125596576, 39.84791947949318, 40.82341686371834, 39.42895935427758, 39.57937832801573, 45.39054232258951, 47.308593103962565, 45.679252301493, 39.41883571686284, 38.25195804719002, 38.70032418158747, 36.744512742565526, 37.543589761180264, 37.43969402005596, 37.13939343729327, 38.225121190471036, 36.683755228596354, 38.55476110212265, 38.63370272421068, 38.769663841493674, 37.76032032505159, 40.778395898880504, 42.19368511630643, 47.20927476882935, 54.28938434969995, 54.17247026197372, 52.97848116966986, 55.54021250817084, 54.5528381870639, 53.93495113618913, 50.78897099341116, 46.774158400873986, 44.22451580724409, 40.55190255565029, 42.047208124591464, 45.506628790209376, 47.676409444501324, 45.67749115728563, 44.70256251673545, 43.49155818262408, 44.615831067485196, 44.322669198436124, 47.34661263804282, 48.934376316685835, 47.13271402543592, 48.16191257969026, 52.79307073162448, 55.9535518769295, 57.977824364939046, 62.54226692261235, 62.89600587660267, 63.30873335561445, 67.4726430831417, 69.56918916394635, 55.63875029163977, 0.4823247589651616, 0.303510154086736, 2.894967083008059, 2.60240656233603, 0.30412516947234836, 2.1013215664894354, 63.46423572109592, 67.23818732846168, 69.7010592491396, 73.71762121877363, 69.33400384841427, 50.08630975600212, 26.570433647401874, 30.664072152106996, 47.89519140797277, 69.94423835508286, 12.846110424687787, 0.3405326094117857, 0.1611905376757345, 0.10965735050699404, 0.08150060856414419, 0.040248152799904346, 0.09718172357327516, 0.03005901869807032, 0.047230726303232294, 0.08937088261929252, 0.013749585186521855, 0.14463876374065876, 0.2374621901300646, 8.685277796560719, 73.2320317914409, 63.37715125853016, 38.86496959194061, 13.465620356221354, 39.18445840958626, 51.52409768873646, 69.50476815623622, 71.09867818893926, 68.50936474338656, 69.07067160452567, 56.52019316150297, 0.5148922904364525, 0.2581404966692771, 0.7084238733495436, 4.583788177659435, 0.6226529144952375, 0.19719516858458522, 33.57259396583804, 66.40196938668528, 55.19933500597554, 65.13668337175923, 60.05347597983576, 62.23700846395185, 55.01245760148572, 58.63464093977406, 59.7747366659103, 61.51671617261825, 57.43449372629966, 56.68471305601059, 54.4533472676431, 62.42223062822896, 58.34549950015161, 55.68843103224232, 51.50983595078992, 47.37344165002146, 43.3722436043524, 46.03369335974417, 43.98580820329728, 45.97578348652009, 47.61912715050482, 50.6555986404419, 51.723358015860285, 53.06079995247626, 54.31131824370354, 57.652675567134736, 50.08792185014295, 55.99292462871921, 55.38006605640535, 57.06994864248461, 49.73672851439446, 45.07730184062835, 40.60366607481434, 39.068768101353804, 38.72168148717573, 40.02156672939178, 40.61523706682267, 40.737516956944624, 39.41934954735541, 37.84469442982828, 38.87559137036724, 40.55447170811315, 40.13790815107284, 41.80544891665059, 42.14046247543828, 47.33623404656687, 50.2509355545044, 49.38969681339879, 42.461465327970444, 39.99992309078094, 42.84926614453716, 39.98414339557771, 39.86780981863699, 42.05865360075428, 46.00773511394378, 46.32599230735533, 47.64237896088631, 50.54999274592246, 41.75390897258636, 46.73978274868381, 45.43046028383317, 50.057978476247484, 46.016074072930124, 43.479751848405414, 40.07014528397591, 38.022648442176084, 41.4821397104571, 41.98825882327172, 40.88098549073742, 41.78389549255371, 42.903583126683394, 43.62373813506096, 39.925284308771936, 38.91998475597751, 40.8179255454771, 40.00595177373579, 40.03810344203826, 46.41275121319679, 49.40271516000071, 48.63335401781144, 41.21483410558393, 39.38497389516523, 39.54908194080476, 38.41281052558653, 38.78602012511223, 38.92085159978559, 39.74713417791551, 38.980463781664454, 40.22327461550313, 40.70420818944132, 39.53320026397705, 40.71855621953165, 39.57593448700444, 43.65095153931649, 43.630449310425796, 48.430520411460634, 57.60139449950188, 56.52301726802703, 54.14604525412283, 56.23501331575456, 57.21928111968502, 56.76774963255852, 53.53623828580303, 47.34016033910936, 45.829985064844934, 42.701710501024806, 44.0865425140627, 47.26752196588824, 50.171346741337935, 47.201696749656435, 45.60578630816552, 45.64997573052683, 47.85823091383904, 47.109717169115626, 48.29523394184728, 51.81448251970353, 49.86605298134589, 49.41511769448557, 55.49531705917851, 57.614271640777595, 61.411149501800544, 64.06964571245256, 66.40148301278391, 65.69305981359174, 69.96077506772934, 71.58505209030645, 59.348559379577644, 0.8175338540346393, 0.4305892786191356, 4.28014769669502, 4.069739012948928, 0.8964152922553401, 2.530925778612014, 67.28892710901076, 74.6024843954271, 75.03336460359635, 81.83712359397643, 74.93490526753088, 58.274124130125976, 31.494341819517075, 38.749502858807965, 56.00228732632053, 82.8206971383864, 18.366863112295828, 0.39614961212200506, 0.2316582160851648, 0.07387299285901171, 0.022311743889604847, 0.08675062443099676, 0.24027656733749375, 0.12684590438561094, 0.20406550637656645, 0.17952715857855736, 0.14318639893204937, 0.3679417338102095, 0.4295429250886364, 10.148223811580289, 84.07446707448652, 75.0220367985387, 48.823949829224624, 24.86155894494826, 48.18660389992499, 60.26117332520024, 77.71301023421749, 77.9610844581358, 75.41901988367881, 75.87506601887365, 62.4048270717744, 0.6416006590570174, 0.8314930178946065, 4.884225553081882, 11.008747700721988, 1.9990659889674958, 0.25813730974351207, 38.397521126654844, 67.83781574618432, 55.831534785609094, 67.30382427092522, 64.02291851658975, 67.38515853881836, 57.86014541502922, 60.778165248132524, 62.50260391542989, 64.27974747073266, 59.98344206040906, 59.54539175956481, 57.0087282888351, 64.01587786213045, 60.828685375951956, 59.52966697754399, 54.21219210470877, 50.59741420130576, 46.280661475273874, 48.77514769954067, 47.28145030237014, 48.78749924321329, 49.48996436211371, 54.53413240371212, 56.009794742830344, 55.26659973206059, 56.832084348124845, 60.393341510526604, 53.15139885871641, 57.78857392649497, 58.91134454358009, 62.35688394115817, 53.41996746678507, 45.43189979368641, 43.55076243800502, 43.569283869958696, 40.65486869504375, 42.636854110225556, 42.95176159950995, 41.700199957816835, 41.76461704315678, 41.183078596668864, 41.606192511896936, 43.593214250379994, 42.56284290744413, 43.36209643271662, 45.14754756804436, 50.44697561571675, 53.33800561966435, 52.201651834672504, 44.06877417718211, 42.40215516859486, 43.525608278089955, 41.07136164942096, 41.083740649684785, 42.883971275821814, 47.41386167464718, 48.81093932736305, 48.58861154125583, 51.74105575007778, 43.433593396217596, 47.80109766990908, 48.10474011205858, 52.7283045553392, 49.44189963802215, 43.92496439718431, 39.33317115229946, 39.250511123288064, 42.38715602505592, 41.60005400257726, 39.64663913173061, 41.91542825391216, 43.11404966538952, 43.65910614690473, 39.95537281036377, 41.13126408669257, 40.627945546180975, 42.656767983590406, 41.471553233362016, 47.50102458461639, 51.59440225170505, 50.2568583334646, 42.95631154890984, 42.292948538257235, 42.497315791345414, 39.93970294152537, 40.52730537229969, 41.8177180905496, 42.6604667786629, 41.54403863414642, 41.49356165239888, 42.545109871895086, 41.561049953583755, 42.32073853092809, 41.423362993424945, 44.443948884164136, 45.711906033177534, 52.246115822945875, 62.03182143549766, 59.150044302786554, 58.71795600460422, 61.27516092792634, 58.56106512008175, 59.23769358665713, 55.279288599568034, 50.724302876380186, 49.33177909543438, 44.76561069488526, 47.62048821295462, 49.76050200000886, 53.84348538614089, 51.008105970198116, 48.3146418294599, 48.22434494572301, 49.063324236100726, 49.191424923558394, 51.84982699732627, 54.75576593029884, 51.93730369690926, 51.422669118450536, 58.82760978514149, 61.00765135980422, 63.840430244322754, 67.87890649610951, 69.11049150651502, 68.60549419156968, 72.0157204904864, 73.25912752459126, 62.94742030482139, 1.1608661470874664, 0.62599134180815, 9.212955236434937, 6.985488774315004, 1.434595613710342, 2.512949310964154, 75.15731150104155, 79.93590370301278, 81.1477513467112, 86.46297085669734, 82.62856375786566, 67.59980632412818, 40.92748911150041, 48.51563976657007, 62.818805786871145, 93.06766956083237, 25.65261079419044, 0.7684501717167517, 0.4053660175733028, 0.19410814068490462, 0.22161795968009582, 0.15441714064969173], [0.05081813602197555, 0.01984994332756727, 0.018966680340048288, 0.03291251618535288, 0.06528097204864025, 0.017927566340433496, 0.28827667957352054, 2.8155763495352963, 57.153655944332, 57.13914317469443, 42.689464861346835, 41.758533447019516, 30.08451842492627, 41.59677490111321, 68.3450880358296, 64.01977669808173, 66.31963099202802, 59.9605118843817, 59.14985602901828, 1.8437973722334833, 0.10043881533126678, 0.44054547985715253, 2.8319292010799533, 0.37159171376016836, 0.26474726957178885, 22.164186162333337, 64.24416765089958, 62.716882997943515, 61.08419641371697, 59.768896256723714, 59.76828044460666, 56.436011252864716, 59.324507405681, 56.26315239937075, 55.563805564757324, 53.27102330423171, 55.04667243649883, 57.8043810782894, 59.46645013747677, 53.45899504999961, 52.30205274397328, 45.32681165202972, 41.16717730799029, 42.480720243146344, 43.048597074324086, 44.990613537449995, 49.20669078826905, 52.717651397951194, 53.07816036285893, 54.05063359968124, 56.15537351177585, 52.27769874757337, 52.274458869811035, 56.77288401511408, 55.837681139669115, 53.07122561239427, 50.72488338716569, 42.994629183123195, 41.274199178141934, 37.8633649118485, 36.46340431705598, 37.263669813832934, 37.59729485357962, 36.275114859304125, 37.703932331454375, 35.9500954997155, 38.50929690945534, 39.40917099675825, 39.82060409361317, 37.2154874186362, 40.1526915642523, 37.416348072790335, 42.99110297233828, 46.735703483704604, 46.92064715969948, 44.50829928921115, 39.44187179688485, 39.6854470622155, 41.035369980719786, 39.077789552750126, 41.12787515886369, 42.26150681895595, 45.44770302311067, 44.55631302249047, 46.12961099993798, 43.21271296470396, 45.53314009020406, 42.38891716926329, 46.718625483974336, 44.43336632943923, 42.59111927401635, 40.184435306056855, 41.41605954016409, 39.70039129257202, 40.219611121762185, 41.48238289740778, 42.88687382974933, 41.19788946643953, 42.38935255235241, 40.77893718596428, 41.69295141773839, 38.45304619881415, 40.917812624285304, 40.18827138408538, 45.79663315126973, 49.069690242890395, 45.82499580998575, 40.852567918839, 39.16051626205444, 37.66934094890472, 36.68948188904793, 35.99413194964009, 36.56422884233537, 36.021043331392356, 37.698225282853656, 38.21505638860887, 39.02460221321353, 38.77187998064103, 38.66745471954346, 37.327333804099794, 38.88672697928644, 41.54278739806145, 44.83364812789425, 52.98923630868235, 56.548167505571925, 51.860793944328066, 53.02045445288382, 55.793201461915054, 57.10627371265043, 53.49011121257659, 52.48339176177979, 48.12000989913941, 48.921240298978745, 41.50948255292831, 42.14015653056484, 45.480976489282426, 43.13940778855355, 41.40104078477429, 41.71636404529695, 44.084196936699655, 46.14627322842998, 50.80826513228878, 51.82848145884853, 56.77774383175758, 60.15703439712525, 62.0418470136581, 63.33773536066856, 62.787642555852095, 66.04809314973893, 69.72244401131907, 67.22903251647949, 66.87794900709584, 71.73580446550923, 51.98263452899072, 0.41596325054284067, 0.2459640194091105, 4.4282245251440235, 6.106238019081855, 0.7157142111851323, 5.099853440638512, 67.9132507693383, 65.35769716385873, 69.77507437429121, 73.01343810173773, 71.17150091355848, 50.6365986793272, 34.83922927610336, 30.18893780246858, 54.3610538974885, 67.08187303235455, 10.622052992543868, 0.48218913075904696, 0.170351846083518, 0.07965103482767459, 0.10438643576156709, 0.0033110968868112975, 0.036754971895847595, 0.10570457430496331, 0.03699047881509027, 0.10719339723788923, 0.060020123698538354, 0.07650353194725129, 0.26140911805052913, 3.889835337477346, 69.11917563407653, 64.56212282180786, 46.360222831849136, 36.60553140024985, 38.6543579255381, 48.532082342332416, 73.96657405361053, 69.36263715067219, 71.49482973160283, 64.6625158863683, 63.69860126126198, 1.903530044421073, 0.24346741547267287, 1.445926237971552, 4.288559709825824, 1.1196616484272865, 0.47681395144712546, 24.663114470820275, 67.24169392739573, 62.07853686424994, 64.85419819431921, 61.86290456402687, 61.76782631104993, 59.66159982066001, 61.58736590416201, 59.080351629564845, 60.55894005683161, 55.72218694994527, 56.13736983268492, 59.65872080095353, 61.34468101686048, 54.634796111814445, 55.28387385029947, 46.09269365187615, 43.096567661531516, 43.35348290781821, 45.532932204584924, 45.53265371630269, 50.54685092741444, 55.42673049434539, 54.56501714644894, 56.05359192817442, 60.43053734687067, 53.57063354984407, 53.941226928464836, 58.779184202994074, 58.05092950021067, 54.79554660858647, 52.46358771477976, 45.534744339604536, 42.169401722569624, 39.91987143793414, 37.07425855821179, 38.38733473131734, 39.66097539471042, 38.136055930968254, 40.085277788100704, 39.14379127563969, 41.034001073529645, 40.33093190962269, 42.0790107019486, 40.3548034544914, 40.97807984198294, 39.519264082754816, 46.6472501139487, 48.45105009694254, 49.90222900144516, 46.61620455403482, 40.273022036398615, 40.26618534518827, 40.52756817110124, 39.2509739629684, 42.95623310150639, 41.3493674801242, 45.31701749370944, 46.02429928318147, 46.642413831526234, 44.62031825896233, 45.28856462047946, 45.6404169144169, 48.95661223319269, 47.68346186607115, 43.74923044635404, 39.27580256615916, 40.73501448477469, 39.02614370469124, 39.84649565912063, 41.6393090832618, 42.57985422688146, 40.49871521611368, 42.773203542155606, 40.64539617107761, 39.98692435602988, 39.34903713964647, 40.95637736781951, 42.41391835674163, 49.37809052005891, 50.72867631912232, 48.653817023000414, 43.151339638617735, 40.05373016480477, 38.33672046661377, 38.055878762275945, 38.56172723154868, 38.46463288030317, 38.39434792918544, 39.24352930438134, 39.79821912703976, 41.090177259137555, 39.85014738575105, 40.555118899191584, 39.44186002977433, 40.32439331854544, 44.866156731882405, 46.228815586336204, 54.290164901364236, 59.08440736032302, 54.39801046925207, 55.779151531957815, 57.35423418783373, 56.593812127267164, 55.03868256845782, 56.37648536312965, 50.24738973186862, 49.00145276900261, 44.957579335858746, 45.308027421274495, 46.63727944897067, 45.89634372342018, 43.78968577231131, 45.205586879484116, 46.101503295283166, 47.99640817026938, 52.12158056997484, 54.65057972938784, 60.36993672770839, 62.873518928404785, 65.74842014620381, 65.16945477454894, 66.3252321366341, 68.75145343042189, 71.87132235496276, 69.35220364601382, 69.47388341349941, 75.34898204188194, 53.24763421089419, 0.5151367644148489, 0.39643340173267555, 4.318865412665952, 3.670245856046677, 0.9025848741012236, 5.754415633216982, 72.34823549947431, 71.98630271419403, 75.23031465468868, 79.57964266500166, 76.61126352125599, 62.3360679226537, 30.50301374927644, 34.064996550160075, 61.16725652448593, 78.97791185686665, 14.10729265982105, 0.5638453700850087, 0.16694969557706388, 0.07157376381538569, 0.1010208736143766, 0.015690170168395967, 0.15150989826408126, 0.22683589178467953, 0.1374216792323897, 0.18896873259255964, 0.12676960968923184, 0.12516984956399088, 0.39674195130505874, 4.416463298182334, 80.88534478218325, 72.48970754684942, 59.15081308734033, 57.79826610319076, 43.668068762748476, 57.25509235935827, 82.13789878352996, 75.4487200706236, 75.48279762268066, 69.45116504546135, 71.05067622277045, 2.9510672726938805, 0.4804659845127214, 4.399525032889459, 9.225310702477733, 2.8936297999274347, 0.9598141548133666, 29.910965311911802, 71.13110834552397, 63.917340078661525, 65.64623848084481, 63.39903416172151, 63.92184295961934, 61.76125241864113, 64.5584632504371, 61.42592114786948, 63.137823920096125, 58.520033205709154, 58.156213760375984, 60.35107404954972, 62.437908341807706, 59.00444592199018, 57.28400414989841, 47.121327384825676, 46.02194193870791, 46.99236769830027, 45.187241954188195, 48.70235635388283, 52.39041197684504, 57.043327516125096, 57.24723585190312, 58.56308121835032, 61.91342861421647, 56.590438888918975, 55.38807945866739, 59.798612133149184, 60.2874335935039, 57.06164498482981, 54.949358432523674, 47.058177225051395, 43.78688912237845, 44.017446041107185, 39.37468944057342, 42.5242232507275, 42.16626774880194, 38.81526139474685, 42.429286203076764, 41.66320416235155, 42.85378471497567, 44.469565883759536, 42.920037469556256, 42.213081236808534, 44.66180124590474, 40.535416833816036, 48.781180304865686, 50.81760429566907, 51.62575767886255, 49.94204498106434, 40.90189564612604, 40.110714358668176, 43.51138968621531, 41.013228201097064, 44.1878181119119, 42.676626943772845, 45.73817414622153, 46.741928285168065, 48.00511583205193, 45.31792748358942, 46.388875745957904, 47.56549266076858, 51.34030718957224, 49.54902348979827, 43.213595497992735, 40.217434206316554, 40.762726030042096, 39.380439635246034, 39.845628815312544, 41.39734983444214, 44.049025043364495, 40.74486355627737, 43.48917338155931, 41.09175405194683, 41.221447221694454, 40.34659001135057, 42.66153366334977, 41.585086237999704, 48.72987570301179, 54.7002173239185, 49.27194726082587, 47.28004217147828, 43.47166392111009, 41.80806513755552, 41.44341022737565, 41.454581137626406, 40.93843252428117, 41.342087561084384, 41.06690191453503, 42.26976733053885, 44.40821216952416, 41.9491998610958, 42.72491524296422, 40.52704257349814, 43.54705187582201, 47.0012047982985, 50.182133259311804, 57.356156149218165, 62.910746143710234, 55.91397516189083, 57.75571623156148, 60.43949211797407, 60.25869046488116, 57.82409883314564, 59.891019252038774, 52.70078128384006, 53.48170165092715, 47.364129943232385, 47.31559845709032, 49.29312805975638, 48.080107627376435, 46.15199596651139, 46.91714840550577, 47.92553878599598, 50.88892083014212, 57.04069560573947, 57.50294693054692, 62.53914863832536, 64.88214115942678, 68.2569759122787, 68.0899457008608, 71.42636868261522, 71.9003478942379, 74.80884813493299, 71.42869072575724, 73.22664245482414, 74.96943781452795, 58.72841696585379, 0.8030918709212734, 0.5440723956111939, 9.77461903325973, 14.761763657293013, 1.1269452446891417, 6.673643185246376, 79.33528684800672, 75.05979353381743, 81.89999918783866, 84.56930545068558, 82.58509605161606, 67.79808213633876, 47.06232317032353, 44.40882798164122, 71.77152941303869, 92.32042666404479, 20.63069239739449, 0.6180438843946303, 0.30338007235719316, 0.1817124397043259, 0.31973485444341937, 0.11940720596260603], [0.10495182397144456, 0.03404041977539178, 0.015540206541998253, 0.03655159470414923, 0.017651154156473857, 0.009145391973546677, 0.03658708372724153, 0.10432023810403002, 41.49085521697998, 60.65822701300345, 46.71189469675864, 27.32263638127235, 21.33815069352427, 41.81893010293284, 68.09398574213829, 65.49973011016846, 64.4660012183651, 60.873290569551536, 63.02148249841506, 5.2153986211745975, 0.5558569116457817, 0.4577586174972596, 4.116201448825098, 0.7071163144803817, 0.6852047289571455, 20.264937262381277, 60.51630781542871, 54.97516762825751, 67.65550398057508, 59.2264050053012, 64.01252423563312, 60.88658348206551, 60.87405543173514, 56.983601585511245, 58.03346318583335, 56.5182045198256, 54.73982934028872, 60.071130567981356, 57.41686659474527, 50.03380883124567, 46.4775409237031, 41.02652111361104, 41.45847212883734, 41.53603307662472, 45.89415504086403, 50.49330665219215, 56.87362617061984, 54.27074132427093, 53.42655704867456, 52.135826618440696, 50.97292623212261, 47.673820680187596, 55.55933798513105, 53.40871810913087, 49.03912713450771, 47.10876403316375, 43.410933863732126, 43.00015188032582, 43.46345047796927, 38.167662389816776, 38.626650302640854, 38.07229780381726, 39.90702175324963, 37.0165212692753, 37.30616084990963, 37.39282561886696, 39.11580908683039, 39.64591349324873, 39.67125592693206, 37.62335508100448, 38.41554833996681, 38.74320353231123, 42.9021789181617, 45.387490718595444, 45.7022334683326, 45.412158504609145, 43.31135272979737, 41.27375595031246, 37.74812567618586, 40.50261797443513, 41.022018232653224, 41.55551156690044, 46.4440478048017, 44.458744064454116, 44.246292806440785, 43.3119293182127, 46.12251150992609, 44.73736570727441, 46.805200038417695, 46.65470653964628, 42.180988404058645, 39.956345558166504, 40.04888211527179, 40.437079091225904, 40.49907607416953, 41.88888949732627, 43.83809174260786, 44.033390475857644, 41.693355421866144, 39.042060682850504, 40.262361034270256, 40.45820889934417, 43.12407524354997, 41.456989472912205, 47.32374521993822, 45.230705738067634, 46.87905042402206, 41.99975921261696, 39.999613223537324, 40.14627848902057, 40.0232925722676, 38.70961235415551, 39.25979145111577, 39.982048849905695, 36.5314378276948, 39.02679089576968, 37.826200454465805, 36.98812330922773, 38.72771017013058, 38.484927223574736, 38.00866519251178, 41.679266268207186, 41.45162759288665, 46.986868535318685, 54.26082165010514, 54.58284039651194, 55.5786713477104, 52.74324094095538, 55.43697180286531, 56.230380996581054, 52.80171955785444, 56.1726946984568, 49.65351543118877, 48.12822726465041, 49.50568914413453, 45.974783282126154, 46.22543450324766, 44.31781722653297, 39.84359310519311, 41.24177686629757, 43.88046510757939, 53.26632430476528, 56.708765029907234, 60.56790659504553, 62.173819080475845, 65.31999534176242, 63.41990901577858, 63.0522221134555, 60.43050204553912, 61.562937382728826, 69.83374518732872, 66.66235985294466, 64.39280194620933, 44.61436410104075, 0.39633892776985324, 0.3892942283663058, 1.5218695757850524, 2.91602359183373, 0.8755129203200341, 7.4445041437302875, 70.94105382119456, 65.00615081479474, 71.06333763368669, 71.1164386810795, 71.61519158271052, 49.55910398114113, 23.6029762606467, 32.36353708851722, 54.92563986009168, 68.60095208691013, 6.174917740206565, 0.16321141633295244, 0.20634587433549667, 0.06490176618700066, 0.08050689293492226, 0.048692318640889666, 0.15152589417994022, 0.045565779756514296, 0.07311537020629452, 0.05751184075169506, 0.033227887770701806, 0.081105797491487, 0.038728690180446834, 0.2729409476441722, 51.75611372916929, 67.85843956855037, 54.18651626956079, 35.786591499082505, 28.76296404869326, 49.051686563799464, 73.856731999305, 72.17116402041528, 71.52745600669616, 66.16071224212646, 67.84926122234714, 5.463503733758004, 0.9002252620074057, 0.5614766875101674, 5.249598257003292, 0.44586507182928825, 0.5359896777137634, 20.31818343747047, 62.613187297698, 56.82926808634112, 67.60278732545915, 62.50287848134195, 64.9129552995005, 62.63039081327377, 63.744885229295306, 59.0573626179849, 60.78911650565363, 56.60925842100575, 55.138710852592226, 62.360265024246715, 57.814681222361905, 51.92377544218495, 48.94046775756344, 44.24778330710627, 43.04231343730804, 43.15996885299683, 48.3017489987035, 52.93501738579043, 59.899428813688225, 55.729431567653535, 56.8873191648914, 54.66910900608186, 51.88219439598822, 49.58860020483694, 56.448398097868896, 54.32418754023891, 51.889819483603205, 48.65099291647635, 45.408502855608546, 44.76836027637605, 45.12844954767535, 39.04870910029258, 39.405307462138516, 39.64964758965277, 41.62933841828377, 40.107682366524976, 41.80703747657038, 38.59160784752139, 39.33987056055377, 41.96459908639231, 41.03824900042626, 40.807546954001154, 41.194347566173924, 39.355889520337506, 43.64850790269914, 47.03548239123437, 49.726145959669545, 47.488567136949115, 44.07509703789988, 40.99024311188729, 38.732515073591664, 39.53835425838348, 39.82745255193403, 42.033750472530244, 45.85216606816938, 45.63670242986372, 45.76097488403321, 44.86347775305472, 47.12933686471755, 47.10509269468246, 48.647862865078835, 49.00291189070671, 42.728151198356386, 39.994474918611594, 40.80677816944738, 42.0247878566865, 41.79308952823762, 41.160611260321836, 44.44740056991578, 44.677376977859005, 42.06546675774359, 38.117722772782855, 39.91760430797454, 39.86740973687942, 45.02863699390043, 43.27223493206886, 49.351806717534224, 48.108576190087106, 46.977113600700136, 43.490628580893244, 42.215469960243475, 42.32238984877064, 43.52558082149875, 41.14041105393441, 41.75606235381096, 41.408603114466516, 39.49432173082906, 41.097861182305124, 39.473250758263376, 39.2651572535115, 40.233461010840635, 40.292347554237615, 39.33867031528104, 45.39170334416051, 42.60556144099082, 46.460490380564046, 55.75677048775458, 56.41510501984627, 57.48119346557125, 54.46338853528423, 56.193691145989206, 58.80406771936725, 54.446781219974646, 56.4441187920109, 53.01534752691946, 50.941413910158225, 50.69437911433559, 47.35177839955976, 46.72776068410566, 47.1534437517966, 42.07902639142929, 42.894953912304295, 46.53208540331933, 55.40453772391043, 58.87986360057708, 64.98183211972638, 62.810070668497396, 67.1933703268728, 64.06791202483639, 64.54791599704375, 61.4417165325534, 63.34226177584741, 72.16986963825842, 70.60507928171467, 67.11056909253521, 49.80095340359596, 0.29383807953807617, 0.32888825682382433, 3.7287470265742275, 2.2093076042590605, 0.7427843876423375, 7.838277259180623, 77.30782939541724, 68.43898957775485, 77.74993542701968, 79.18480903871598, 77.76219675617834, 57.29421015708678, 25.995510278209565, 36.36530583904636, 61.41008653948384, 78.86732455222838, 8.55757228789791, 0.4147243331516943, 0.1835062652225456, 0.029975729618942546, 0.06530043834279622, 0.020625973157885096, 0.18706955466299288, 0.24318050022327134, 0.14904841179809264, 0.1380821542754289, 0.19417604671851282, 0.15992241701291454, 0.1340719904269903, 0.39346704800282756, 60.733144283294685, 74.4919990724133, 63.92168214244228, 37.150532968582645, 32.302034324215306, 58.58893356015606, 80.13272039351925, 77.6393638118621, 75.97492956346082, 72.38221891464727, 76.33868232850106, 6.368856881895374, 1.2570056463441541, 2.2686354143004266, 9.79589298848183, 2.489526632332033, 0.8888567010721854, 23.13935406746403, 67.23784215988653, 59.17868544978481, 70.20683319337907, 64.26772148378434, 68.77225768181586, 67.17602560597082, 65.12884255378478, 61.25307013911586, 61.59634028711627, 57.51132903560516, 57.35006863071073, 63.02140012864144, 62.19682770390665, 54.27244755529589, 51.219800210768184, 46.52001234792894, 44.97657929697345, 45.84953415778376, 50.545223143792924, 55.227587838326734, 63.265348019138465, 60.35065435594129, 57.98736749156829, 56.29043248391921, 52.07754019768008, 48.72983647931007, 58.72085855853174, 59.14922844979071, 53.45275063668528, 52.108283735090694, 47.335065180255526, 47.22287754858694, 47.779916870978575, 42.25286583746634, 41.807233595079, 42.357632344768895, 43.5050864373484, 41.239093965099705, 42.52170901144705, 40.90082876143917, 41.54311295478575, 43.833784980158654, 43.65867860855595, 42.89690725265011, 42.48601936524914, 42.39561657751761, 46.7992066567944, 50.2569995387908, 51.227539047118164, 50.93935466581776, 45.39846551033759, 41.69139815915016, 38.28126599711757, 41.12887144088745, 41.68322393971105, 42.99463702786354, 47.43801955253848, 46.732443994091405, 45.64056988685362, 45.08994363969372, 48.27898748459355, 50.03595044535976, 51.58329017700688, 52.579462374410326, 43.55474756610009, 39.76748343436949, 40.35029665116341, 40.58830999558972, 42.12394929701283, 42.106859530172045, 44.50040748042446, 46.23291838553644, 43.14612680865873, 39.04745786420761, 41.955008891321, 41.01870775222778, 47.0333956903027, 43.404105017262125, 52.10410641085718, 50.144305921369984, 50.86107984665902, 46.663320064544685, 44.064106556677054, 43.578666179410874, 46.01882757679109, 43.351298147632235, 44.12203604175199, 45.30803526601484, 42.34635553052349, 43.77433361545686, 40.064069532579, 40.67109161807645, 42.41775835714033, 41.69643448245141, 43.151053305595156, 48.03812649942214, 45.69150186354115, 50.44337880226874, 58.84776292308685, 59.992561571059696, 60.902602441849254, 55.94715449117846, 58.26322778578728, 59.26153767493464, 55.53051640910488, 60.30711996939875, 54.78004932403565, 53.858704182409475, 53.92813405682964, 51.268006140185946, 49.24988392860659, 49.158084777093705, 44.8043127213755, 45.18140546737179, 48.03416882791827, 59.57827298871933, 61.661012326517415, 67.7519158394106, 66.34317305780226, 68.59464491567304, 66.518416712361, 67.39902019500732, 62.515029984135786, 67.4507954812819, 75.82772301089379, 70.80160571682838, 68.07355803828086, 53.063961382835146, 0.7840621243080785, 1.1329847141619653, 8.744491857867088, 9.271461309925202, 1.3181580939600546, 10.170614661708957, 85.01736564020958, 74.41930970837994, 83.09493357135405, 85.1382609336607, 84.0824608648977, 66.76659291790378, 34.633551951377626, 46.37385306819793, 71.073041577493, 92.89577561040079, 12.167796319530858, 0.9061693688554149, 0.48904595476004387, 0.1828823478952531, 0.14735436157113121, 0.10897247556356654], [0.05071264188436251, 0.12760392540404875, 0.033716912336287, 0.09221479251620271, 0.16881266819132915, 0.044357781673991875, 0.060399835178207975, 0.046855557724953666, 35.384564245900805, 60.956476196166015, 50.44040172330795, 39.15942976551671, 34.50409412384033, 35.4427251508159, 56.39148450666859, 62.311239319462935, 65.6458854675293, 57.89634104697936, 69.71255963848483, 13.268615391946609, 0.6514259511905333, 0.8892474672006023, 3.6464863438760085, 0.477362807479597, 0.42382450774312025, 21.243878487617742, 66.33306903223838, 54.62146789796891, 68.20538105503206, 61.48998129752375, 61.789909255120065, 59.72772313702492, 60.65710129276399, 60.2979180889745, 57.179300400518606, 57.150349386276744, 60.7388944779673, 54.57236766815186, 52.300985859286406, 49.25408478706114, 45.522906626424486, 43.48487838622063, 40.672927287317094, 43.14916664554227, 53.0332374572754, 54.48417317482733, 49.83286580731792, 52.64274981714065, 56.758755637753396, 54.138035774230964, 56.04764561499319, 54.45044471371559, 50.775097570111676, 54.067397809797725, 49.93539656362226, 42.38331210228705, 41.771190935565585, 42.98505467753257, 42.21540720232072, 38.676299664282034, 39.28325114711639, 36.82152455852878, 37.919066490665564, 36.122577805672925, 37.55122269353559, 41.74417364981867, 40.28675817674206, 38.80167430446994, 41.23570111490066, 38.003644558691214, 38.301764303638095, 39.00577091401623, 44.23134465371409, 47.767561404935776, 47.089254163926654, 42.84661854467085, 42.78014613736061, 40.12128514628257, 41.49687605519449, 40.87653752296202, 40.953039430802875, 41.24942941050376, 44.58715854152557, 45.41944626838931, 44.32729367286929, 42.89884490351523, 46.83120143028998, 45.132948506263, 45.90700080317836, 47.343572801159276, 42.627326673077, 40.744345803414625, 40.7958229895561, 41.011270938381074, 41.15905407936343, 42.0559589324459, 44.400198767262125, 42.99333480096633, 40.782247666389715, 39.76197642664756, 39.789205520383774, 39.77833271026611, 42.845822303525864, 44.09963146332772, 46.0876416390942, 45.68955636793568, 42.83375709287582, 38.977537693515906, 37.871056679756414, 37.21769963541339, 37.62027602041922, 36.871005258252545, 35.718946303090746, 38.49083431305424, 39.079982157676454, 36.383384043170565, 37.52274236371441, 36.700390000497144, 39.3928696263221, 39.71943832212879, 40.24054481137184, 41.744824763267275, 45.81477019094652, 42.9777394571612, 45.37097361779983, 50.50645835937993, 54.09831785386609, 53.50512996796639, 52.18751953494165, 52.485227431020434, 56.691043761468705, 54.97032742346487, 55.23993153725901, 57.526343868624785, 50.63891680009904, 56.82859736104166, 53.18129908653998, 53.52531448487313, 47.76953435713246, 44.39251092172439, 40.6552020965084, 48.38608387977847, 54.797676455590036, 60.395483124640684, 60.16329842229044, 63.168077161235196, 62.69983637717463, 58.82693513747185, 54.96957825076196, 50.52948267229142, 43.85147094726563, 64.91069993665143, 58.67796351832729, 45.7251440325091, 0.4302182775591651, 0.5055937603596719, 2.83979453386799, 1.1527421830161926, 0.6387676659130281, 9.621268087817777, 71.18384069012058, 66.58222583032423, 72.08766460418701, 74.82755784065493, 69.35222718023485, 55.569438088324766, 24.493936761733025, 38.59813074911795, 65.04403698828914, 61.027612301611136, 2.876613577527385, 0.32764655087263356, 0.06681349263676713, 0.09333827577891851, 0.05985844467255858, 0.016050747644546774, 0.08523453642884571, 0.047182711742578015, 0.05342602955117341, 0.08072390266123318, 0.12973738834261894, 0.07349681304467302, 0.14600076081772007, 0.06056858519572885, 43.68200494397072, 69.63342974262854, 56.30780073904223, 33.18053345526419, 35.79486770014609, 49.739744817056966, 63.50243960657428, 70.5126682404549, 69.35312932537448, 65.06778301731234, 73.48616215490526, 13.590800839085734, 0.7919967727315042, 0.330868961830293, 6.610311615851618, 0.19313753792835822, 0.4320574095172267, 23.876626299273585, 67.15663340783888, 57.52416695317915, 69.68143955353769, 60.27499183531731, 63.77848032982119, 61.00941642638176, 63.670097397219756, 60.716972351074226, 58.57435803259573, 57.44727280832107, 61.63217506101055, 56.58435529278171, 55.611321157024754, 51.716682141827, 47.087006645817915, 44.83817846544328, 42.21373627262731, 47.13043120599563, 53.56385569418631, 55.20869770357686, 52.41639375686646, 55.159393510510846, 58.02980361446258, 54.86438420511062, 56.33468466420328, 53.33374200328704, 54.09867478955177, 56.076133789554724, 49.919648247380415, 43.23970279385967, 42.57700658613636, 45.506491507253344, 42.54151305844707, 39.94720251329484, 40.65241721368606, 37.72794508164929, 39.286039952308904, 38.309628655833585, 39.70953825981387, 42.708127498626716, 41.59939112201814, 40.74932329116329, 41.007172061551, 39.879949554320305, 39.98468468266149, 41.569251629614065, 44.33656223358647, 50.0130202693324, 49.8791850766828, 46.728572614731334, 47.36545570435063, 42.20614256397371, 41.81159919308078, 42.11563779461769, 42.14190590766169, 43.38013933550927, 45.16815962329988, 44.99252765409408, 45.41710069102626, 44.718612855480565, 44.56185925391413, 46.75965739834694, 47.13782879614061, 46.56172675471152, 41.84608074926561, 38.2417324281508, 42.15131567370507, 41.12864394341746, 41.57135009765625, 42.045533272527884, 44.00972289423789, 41.795027179102746, 41.12542759987616, 39.4723407683834, 40.47478875806255, 40.35521922572967, 43.05568087485529, 45.727152286037324, 47.93060648825861, 46.90570685171312, 45.29040028972011, 41.89180774073447, 39.72176428764097, 39.4745647522711, 39.74219591386857, 40.32851572959654, 38.73407225455008, 41.74781360933858, 39.22534911863266, 37.58399801869547, 39.30020363100114, 39.17570367936165, 41.04880409855997, 39.95779683513027, 42.14314537663614, 43.028934232650265, 46.19842113987092, 43.85163568681286, 48.37938054915398, 52.66422871620425, 54.51834878613872, 57.82773879266555, 54.08553092710434, 55.0880769760378, 58.772873109386815, 57.87365405790268, 56.695448583172215, 58.712201887561434, 53.84113588640767, 58.515091019292036, 55.62111139297486, 55.699048888298776, 49.63453115955476, 46.69900578837241, 42.845430066508634, 52.39471481692407, 55.60835192280432, 63.4871776642338, 61.686064504808, 65.85680700117543, 66.27875205009215, 59.94162174963183, 57.093996694011075, 53.9992230938327, 46.32090107087166, 64.93489703824444, 61.75878917017291, 52.74110324921147, 0.7735031038042038, 0.46168585998877404, 3.0579898578505365, 0.35170158912097255, 0.677040989600843, 10.201744552581541, 78.48286951741865, 70.97830849309122, 77.51651517806515, 80.69673369007727, 76.61641751566242, 62.43251900519095, 22.20861484927516, 42.726437122591086, 71.48574552228375, 72.56655462326543, 4.351824108631381, 0.3942733708648913, 0.06491541787381135, 0.1512465632009891, 0.10850480952931028, 0.08220262855531708, 0.18446073416740666, 0.26630334736358735, 0.12274834522677046, 0.1911339881799875, 0.39057025505650433, 0.15236115984378323, 0.270674369267879, 0.14405990770507243, 51.957099899168945, 78.9963391519362, 63.91064067040721, 51.66829578338131, 49.61308363945254, 49.19824592528805, 71.83860978772564, 74.6528946968817, 76.71495529913133, 67.45605930205315, 81.29382041192825, 16.863487266725112, 1.4354471357599383, 2.854761317853005, 10.696738842994938, 2.2656649543393046, 0.6036622690096979, 27.291228002117528, 67.5118746296052, 62.23948740190076, 69.83449043766146, 62.5398938886581, 65.78527081397273, 63.4633178864756, 66.40782156298238, 65.13927605844313, 59.909713268280036, 60.23638786808137, 63.69047018789477, 57.151545709179295, 58.46901493687784, 54.72262190234277, 50.579751768419825, 47.115388916384795, 46.17901717462848, 49.251680374145515, 57.04240968150478, 57.6871100548775, 55.18038603567309, 57.37768211672383, 60.26988883172313, 55.730396470715924, 57.657096078318936, 55.76999279760546, 55.871837139129646, 56.97632166647143, 52.485333335015085, 45.66817552812638, 45.588445509633715, 47.39267303097633, 45.52921379766157, 41.439389797949026, 44.94856572920277, 40.79548174335111, 40.57944151663011, 40.12363072364561, 42.5472750202302, 46.8994192923269, 44.41445658283849, 44.72394727891491, 43.91177346629482, 42.16413005705803, 43.41169088117538, 43.646962488851244, 46.23426375850555, 52.91149100949688, 53.41459774201917, 48.025959307147616, 49.32882947306479, 43.338193508886526, 42.304429315751605, 42.17796817902596, 42.507564944605676, 42.957405890187914, 45.129033980831025, 46.138910939616544, 44.4723625336924, 44.84197139739991, 45.668657979657574, 49.25025263140279, 50.75538373762562, 49.78242412690194, 42.01097719130978, 39.106085531173214, 42.880476443998276, 40.52168461584276, 40.30324389857631, 41.53194596690517, 43.84137084407192, 44.18921447569325, 42.893173156246064, 39.77991734781573, 40.976769770345385, 42.15272772696711, 44.5571877110389, 46.07760037145307, 52.6641502688008, 50.91775025090864, 47.23500551715974, 44.55396744512743, 41.741828072455625, 41.296235053770005, 40.90046790338332, 41.0631246720591, 39.205705888809696, 43.49188766171856, 41.5424539965968, 39.89261096523654, 42.185040212446644, 41.008878292575965, 43.63373625663019, 42.53759461064493, 44.618149188257036, 45.93822679212017, 49.5109490425356, 47.828534649264434, 49.85594503341183, 56.7541076290992, 58.20385094611876, 59.216293134996974, 55.5621228679534, 56.354092551815896, 61.68022017325125, 60.83083483480639, 59.462680739741174, 61.83845250837265, 55.66054690268732, 62.271874412413574, 59.260702210087935, 58.974349575658, 51.383178695555664, 50.113617297141786, 44.58250268813103, 53.55354378300329, 58.195253110701046, 65.7695460319519, 64.98090251799553, 67.97862099063012, 67.35900417450937, 62.29932315887944, 57.760160276966715, 53.74120566152758, 48.84991199739518, 67.99956644735029, 61.6820401530112, 57.38717033017067, 1.2097405954714746, 1.4933117791529626, 12.565912969650762, 7.578522707185439, 1.4621459740784861, 12.061569709931652, 84.75578277341782, 77.01243569774013, 82.14930503599106, 86.10332873559769, 81.60698244648596, 75.51385494970506, 36.80329730433803, 54.262386675803896, 80.85740966181602, 87.74742157228532, 7.699994589051894, 0.6504686477203524, 0.3165412790352299, 0.2367832064027748, 0.23494542275945987, 0.18755384480520604], [0.041634216529106906, 0.02935778011658019, 0.104366050161902, 0.05500551132905868, 0.0402746671029637, 0.0888610051404084, 0.06028868348127412, 0.20677816242940966, 26.654388058570127, 66.91521936847319, 43.84144144673502, 33.579289451722175, 30.146019228043098, 33.447611562667355, 47.21430716976043, 61.05566901545371, 65.39525778062882, 56.61237670529274, 67.80865684632333, 22.437451808683335, 0.756745390113323, 0.6354408831365648, 3.9919125697305127, 0.23317025914307565, 0.09503709873364818, 34.953319257305516, 71.37654673668646, 63.329953378246685, 61.830803886536636, 62.07291610779301, 64.52767656695458, 58.4938866861405, 56.10901894107942, 54.874962837465354, 56.79943061644032, 56.44881779147733, 56.26789454490908, 53.50312955917851, 48.924605692586596, 42.09299787398308, 42.432400564993586, 40.860353823631044, 44.32994519510577, 48.7842672101913, 52.27404702094294, 52.461406876963956, 52.23714928473196, 56.020847981975926, 53.72590449548537, 53.488126493269405, 53.49693221430625, 59.262251546306, 57.10149234341037, 51.331854481850904, 53.07013911585654, 49.71803842052337, 44.80445784907187, 44.25421599418887, 43.86317529985982, 40.52674447336505, 39.35959223778018, 36.18135060033491, 36.37038530841951, 37.77379758896367, 37.876901011313166, 37.73983378564158, 35.764998851283906, 36.680903665481075, 40.25638334212765, 40.38001252758888, 40.8971417334772, 40.35103013438564, 41.07583707378757, 43.77070934541764, 46.22164157129104, 41.6916335013605, 42.155602824303415, 43.75484728044079, 39.95695744791339, 39.53025848634782, 39.734488456479966, 40.489611394943736, 39.9268767910619, 43.29416490370228, 44.57427355550951, 43.47389574973814, 43.37514615827992, 46.26323438459828, 42.57764985484462, 45.08507597830988, 40.393489791500954, 41.502606638016246, 40.95928776648737, 40.294057707632746, 43.11560684634794, 45.7586802974824, 41.50240267476728, 41.00676021268291, 41.68712277566233, 41.44720708170245, 40.34642919417351, 43.06787552372102, 44.51312772689327, 44.16917900885306, 47.51367815079228, 46.098989056002715, 41.16999749214419, 39.976008399840325, 39.014039270339474, 38.43762736166678, 36.78408553523403, 35.429867621391054, 36.44060750161448, 36.229846785145426, 37.90542056483608, 36.8217206770374, 35.963749270285334, 39.023515716675796, 36.399042144898445, 39.16203814168131, 40.090749494491085, 43.4718482725082, 42.93107894159133, 41.43396516000071, 44.071998365463756, 49.72729913650021, 53.83571124845936, 53.78198262183897, 51.7322814080023, 50.46759159334245, 53.7143256587367, 56.18297130830827, 50.93527147846838, 53.68765354156495, 56.14964685132427, 54.558780577874955, 57.131561233151345, 60.64174913590955, 56.40590313942202, 54.89287237967215, 47.677084092170965, 45.28297132061374, 46.54224041969546, 53.9496325677441, 55.88901712048439, 60.640831301289225, 59.306111489572835, 65.7114557296999, 60.487564686805975, 68.91095269110896, 67.22329016654723, 65.61893486207532, 67.65180126313241, 65.9136107660109, 1.4109375928678822, 0.26099671759913046, 1.6182199024385022, 0.9058550889453582, 0.5140789502090024, 17.700056260631932, 73.10335451556791, 62.16024767967963, 72.3367900233115, 70.4416419613746, 71.58320073158511, 45.963157376935406, 38.022165990644886, 35.474170792487364, 65.16774069878363, 57.2855927098182, 2.177470215866643, 0.3322650498199848, 0.22004994623843702, 0.011259335949416123, 0.016275963130136652, 0.08908658739059203, 0.06971801541024639, 0.08093035569594753, 0.011373631479669244, 0.024670672249950232, 0.05271794597407984, 0.08995323201581355, 0.1750280620950845, 0.3111085511984364, 34.49967361265613, 77.00376725965931, 52.650778908883375, 36.18703019234442, 34.83944892883301, 44.67608259570214, 55.652662938640965, 68.26566788458055, 70.2836645803144, 62.72504152790193, 74.79340968593475, 24.035013568016794, 0.7565479232899605, 0.3027816351142622, 3.7678824749685105, 0.573368884863392, 0.09916579170573143, 36.29009831336237, 73.466079619623, 66.04852461045789, 63.15393309439383, 64.35638666152954, 64.56442525309902, 60.14447104546332, 56.42649950519685, 58.119574900596376, 57.597640791246974, 58.02803854788504, 56.15064313334804, 54.55450519438713, 50.977715446103005, 44.382622626519975, 43.98252125709288, 43.500862044672814, 46.373366694296564, 50.718038851215, 53.688571376185266, 55.972524381453, 55.960266974664506, 57.33295925201909, 56.20934924771709, 55.94543649304298, 56.464554340608665, 61.640647380582756, 56.85189623986521, 54.1742588627723, 55.32172864483249, 49.75348095740042, 45.44579675120693, 45.44813056145945, 45.131971836090095, 42.73529775681035, 40.345440756890085, 39.252970449386105, 38.18746251444663, 39.75226856047107, 39.11813505234257, 39.48018158635786, 37.894088837408255, 37.424851771323915, 42.07446075254872, 42.5950377218185, 42.581246668292636, 42.173751631090724, 43.10825632464501, 46.31954000842187, 47.99739268518264, 46.88577728886759, 43.7892896129239, 44.213772435342115, 40.872972088475386, 40.26504393546812, 41.516248641475556, 39.93361542301793, 40.38857506167504, 42.9458741218813, 44.52787583874118, 45.37576283178022, 46.70018249942411, 46.76103415027742, 46.834009847333355, 47.6527379405114, 40.760498123784224, 41.268868677077755, 40.30056099737845, 40.440821032370295, 40.75148451712824, 45.155113820106756, 42.88845846729894, 40.8045934092614, 41.159203129429976, 40.1593792053961, 39.67957135169737, 44.14637042630104, 45.433268700876546, 46.16699511005033, 50.49188675418977, 49.15149519520421, 44.37087905022406, 41.64584767433905, 40.99252200895741, 39.092161117061494, 39.09753084182739, 37.93392050650812, 39.01935800429314, 37.20739164660054, 39.46174644654797, 38.31723413159771, 39.717088822395574, 39.24113665857623, 39.186219553793634, 40.582179331010394, 43.14293007696829, 45.40523552125501, 45.470017387020974, 45.034293051688906, 45.002655213879, 50.56468594458796, 55.16085263221495, 56.67400498544016, 55.01226932771745, 53.74393955353768, 53.91937148186469, 57.981142690104825, 55.90539693832398, 55.27443270529471, 58.72103898755966, 56.404726428370324, 57.795606736213934, 63.1724976724194, 59.5927857583569, 58.76758967676471, 50.86695555717715, 47.23474664072837, 48.23256231123402, 57.52070742268717, 58.95260003305251, 62.5462128270057, 61.76040910905408, 69.93747618890578, 63.49058620391354, 68.70982923815328, 67.84154984258836, 70.52510999864148, 70.35753065539946, 70.46314439465924, 1.8540830525659748, 0.29686339139457674, 1.8753779679536822, 1.3662909692333591, 0.4733987008371661, 19.238909944411247, 80.70459411990258, 66.01232113376741, 81.19409022792694, 76.9356043108048, 81.52513042573007, 50.376353340764204, 39.23016971157443, 44.149786810721125, 69.82369607494724, 70.88724674717074, 3.7426275591696467, 0.42606166834312104, 0.162955834079654, 0.06687685576898438, 0.09505006094132701, 0.028166141841680776, 0.18689041266277914, 0.21948115659817574, 0.22526446159087846, 0.09184292577687772, 0.13772860469837345, 0.23691915636581762, 0.3121088475229279, 0.428592547053291, 40.16383109554168, 86.7021962135069, 59.88750480836438, 48.546042057775686, 43.44763155906431, 48.82725246490971, 68.04494827024399, 70.8408215738112, 78.5189631677443, 65.23671557826381, 82.77522902334891, 27.45131365714535, 0.9593160750885165, 1.163350600869425, 8.814631681288443, 1.115795172029926, 0.20308232445630336, 41.235665813569106, 73.26550529849145, 66.69932426944857, 66.19454660723287, 64.52506819079, 65.6859956249114, 60.23286557966664, 58.349900399484945, 58.49723639026765, 59.696779558735514, 58.43293305366271, 59.724914719981534, 58.55903333233249, 54.60595100156723, 46.11881663722377, 46.59289390810075, 44.737557903412856, 48.52048389373287, 54.32880416993172, 54.99321053105017, 60.38384545233942, 57.61556210056428, 58.839867191929976, 60.16446728860179, 58.982602242500555, 59.72356150227209, 59.02223779309181, 55.756727341682684, 58.80076900605233, 57.43689421684512, 53.976763602226015, 50.81164621537732, 48.650945848034276, 48.99510245169363, 45.227779649919086, 41.7835856253101, 40.16876935958862, 40.53438132809055, 40.80842948728993, 41.099335993489916, 41.08315621652911, 39.46550407717305, 40.28563245650261, 43.548926768764375, 45.04195344063544, 43.449726104736335, 46.25010228926136, 45.62092273466049, 47.898545034470104, 51.34526114309988, 50.10153639701105, 49.21295089106406, 45.93979966255927, 41.355047072133715, 39.88268736870059, 40.45820889934417, 40.71406902805452, 39.74791865194998, 44.31875859537433, 45.88785963673746, 45.66174284104378, 48.80871926584552, 50.22912325397615, 49.13905343701763, 50.10116769421486, 39.636754758896366, 41.15786167883104, 40.43218005088068, 42.131284129235056, 43.020285406420314, 45.71312589030112, 42.083215482773326, 41.673402324799575, 42.78020105054302, 43.231854131144864, 40.1781673585215, 46.42090582078504, 48.10453614880962, 47.8754501188955, 55.1984485503166, 52.22692758806291, 46.4368502555355, 42.738439575318374, 42.712516630849535, 42.00224991767637, 42.00440722127115, 40.232476495927386, 41.63200955237112, 41.176998922901774, 41.276819321417044, 40.04618352459323, 41.126345434496486, 42.833945366644095, 41.787574675775346, 42.366116431451616, 45.009652722266416, 47.96975958731867, 46.75151063549904, 45.73787212371827, 48.16106142536287, 54.117172687284416, 59.79229319480158, 57.61458935276155, 56.843274870226466, 57.0030604639361, 56.1076618009998, 61.155136400653475, 59.318592471461145, 57.502990076618815, 60.01952786599437, 59.73255549707721, 62.02279606173116, 66.18658419578307, 61.08834628135928, 61.434824928160644, 52.90797656582248, 52.662600932582734, 50.19154302535519, 59.25372431355139, 62.15009658567367, 65.01949471812095, 64.23439310443017, 72.64944999448716, 63.305744509543146, 69.2059306175478, 65.04477047151136, 71.20475476787936, 70.3250220514113, 72.33865707151352, 3.234311183614116, 1.5137586045649745, 5.883742551649771, 4.608692286476012, 1.1249752342700958, 21.828596015130323, 85.82862161820935, 72.62262098250851, 85.60918069654896, 82.9867075335595, 87.69331639812839, 61.62758588790894, 52.8673957240197, 54.0791609979445, 79.90508956293907, 84.12129232960363, 6.366329894911859, 0.717774865127379, 0.2923697034918493, 0.16329412318525777, 0.2018868136069467, 0.19068481550822336], [0.0553660897628194, 0.028698808521092422, 0.05081959158903168, 0.03670743614014599, 0.12001632247120143, 0.10171975264505995, 0.16355756550065934, 0.33187707225161217, 17.960491834148286, 68.46609315564557, 43.477559243479085, 34.38859993411649, 17.489326923124253, 31.755765830316854, 48.03691056466872, 59.70522442171651, 66.93653352798955, 56.003715069063254, 67.93396088384813, 29.518549826837358, 0.3267049981701759, 0.5678840017607135, 3.593097982868072, 0.10695914287240275, 0.35351642077007606, 53.878367024083296, 66.44709233314761, 59.69388092717817, 61.712642485095614, 58.97567141440607, 60.36111923956103, 60.40216292104414, 60.62670684629872, 60.66143158943423, 58.671401393029, 58.46291565125989, 52.97488043385168, 44.89156976822884, 41.31678435110277, 42.65180226295225, 38.15973527969853, 44.06516951899375, 45.48658547862884, 49.313598909685695, 51.475099440543886, 51.47216158528482, 56.193867652646965, 54.642644774529245, 52.908019711894376, 52.1781607597105, 50.53308733047978, 48.12556005293324, 56.61653441767539, 62.11057870618759, 54.52314976722964, 53.04561253516905, 50.720913948551306, 44.992755151564076, 43.1227808613931, 42.22589562016149, 38.335618280595355, 39.034753307219475, 39.00473540829074, 36.456195000679266, 35.37548003658172, 37.80293295460363, 38.443605053809385, 43.95153061036141, 41.63510038006691, 37.43483420341246, 38.91523868806901, 38.42343622638334, 38.644579456698516, 42.32761836821034, 47.18525417389409, 45.18557886923514, 44.035720363740005, 44.59077888919462, 41.13769677377517, 40.04465380022603, 41.159403170308764, 40.90171913946829, 40.89334095678022, 42.136006662922526, 42.394537925720215, 40.52484996857182, 41.643113782328946, 48.07178828024095, 43.50586698901269, 45.75127878496724, 40.7560658454895, 39.33407721980926, 41.987788138851045, 41.985803419543856, 43.49299377010715, 42.89232984665902, 43.25779668746456, 40.10601928157192, 40.44922667164957, 42.28053031429168, 40.796493714855565, 40.169243966379476, 41.765221088163315, 47.119844728900546, 48.0615665835719, 48.39825891679334, 42.71956905241936, 38.28985206542477, 40.16506664214596, 37.66500672986431, 38.284027345718876, 38.73046759636172, 36.07641150874477, 36.21748739673246, 37.12162117804251, 36.28241831256498, 36.983338017617505, 39.73222524889054, 38.08869331113754, 37.64335916888329, 40.56102206630092, 44.67164247266708, 42.7964122064652, 43.45128720806491, 46.558278991330056, 51.80049142529888, 51.41224345853252, 54.32857667246173, 54.31931987885506, 49.405684394221154, 48.206313810040875, 51.26966138039866, 50.108824160791215, 47.09591827084942, 48.866401641599595, 55.99577226946431, 56.601327388517326, 55.47301446237872, 58.318089977387466, 58.77118649021272, 57.63749599456788, 51.55743783520114, 43.84078248854607, 44.6866298490955, 47.29644160116873, 55.90616964524793, 59.48689353081488, 62.56831146055653, 61.510432535602206, 63.339151336300766, 64.26375596754013, 74.72616457170056, 58.88812018978981, 76.45557680437642, 5.4326101656883, 0.7102444046928037, 0.7458070028693445, 0.3516312316060067, 0.18962268056648393, 25.938914398993216, 74.93113194742511, 58.63224829396894, 63.094571944205995, 74.60968586706346, 66.5836065046249, 63.793593222095126, 46.957042832528394, 30.62487198460487, 62.68160912298388, 46.44959011385518, 1.8314155527660925, 0.1438769352652373, 0.15909717177912114, 0.0990129801474752, 0.09336446066417041, 0.018628663195657636, 0.06312648382698817, 0.05087109568018106, 0.06968742551942987, 0.026830051942998846, 0.1684217641670858, 0.09373395253093013, 0.29378607748977603, 0.3637148590097505, 22.183172395152432, 78.44011568254041, 50.684796764004616, 41.152625314651, 25.263119436079457, 42.15347689967002, 58.05315348409838, 69.14539275630828, 73.26472866919734, 61.078101050469186, 73.59284277885192, 32.35424107120883, 0.4399007402600781, 0.423350942831847, 4.057148204695794, 0.09090089043902774, 0.20151074104491742, 58.55136117627544, 67.46926200005316, 62.81826842215754, 62.98199207552018, 62.44401547216601, 60.84087218007734, 63.023486829573116, 59.924284873470185, 60.718223587159194, 59.85048547867806, 58.60650970089821, 55.389730776509936, 47.36540471353839, 42.627244303303385, 44.81663680845692, 41.21934483128209, 45.033971417334776, 47.349668164407056, 52.224778129208474, 53.854213068562174, 53.08942540999382, 56.393845773512325, 55.79012632369996, 53.989511305286044, 51.47997494666807, 52.36639922665012, 49.954251397040586, 59.49436956836332, 61.14168267096243, 54.639189166407434, 54.661115215670684, 52.87632696090206, 47.185434602922015, 44.1343326722422, 44.322986910420084, 41.36320560209213, 41.270790638462195, 39.570235283144065, 40.741988458941066, 36.574964369496996, 39.57770347595215, 40.30387147780388, 44.56140818134431, 43.29497291195778, 39.525379057853456, 41.392415492765366, 40.54461871424029, 41.449733088093424, 45.21469070065407, 50.66040354390299, 46.754209226177586, 47.496678598465465, 45.52193780099192, 41.59776333839663, 39.96918739811067, 42.626389226605816, 40.977111016550374, 39.69577074050903, 41.91864067508329, 43.34128825895248, 40.052027856149984, 44.16211482017271, 50.1207285542642, 46.32205032533216, 45.78344222038023, 41.02664662945656, 41.757250831973174, 41.12366253329862, 43.14686029188095, 44.24768917022213, 42.126239961193455, 42.7451938967551, 39.551960960511245, 42.206648549725934, 41.02739580215947, 40.059954966268236, 41.624290327872004, 43.53086033175069, 48.18523499273485, 50.48989419014224, 51.19563841050672, 45.23439668839978, 40.56672911490164, 42.85554585918304, 39.04989365608462, 41.58888701469668, 40.98752883172805, 39.009936471139234, 38.72956152885191, 39.21830454180318, 38.69248336361301, 38.41865877951346, 40.35745889909806, 40.968732833862305, 40.71101742406046, 42.46756853595857, 46.101385624178, 45.45396704827586, 45.27326737680743, 47.569489555974165, 54.53188096323321, 53.559533242256414, 55.530485030143495, 55.389966118720274, 52.3004484945728, 50.584584128472116, 54.669403183844786, 52.89072205943447, 52.56326298559866, 48.728016499550115, 58.189840239863244, 57.24422347161078, 56.98432722399312, 58.930560235054266, 60.9910911129367, 58.4110579952117, 54.00818178730627, 46.04103603670674, 46.948519522143954, 48.57641297001993, 58.345475965930575, 62.84019447142079, 66.25110718511766, 64.72420692443848, 68.21197063692155, 64.04536231871575, 77.83016358652424, 63.274581278524096, 84.64083379314792, 8.216798238215908, 1.1044939655450083, 1.627863417229345, 0.9405040200198851, 0.2435586105791792, 27.374584251834502, 80.61801956545922, 63.659099071256584, 71.18370732953473, 78.97123598283338, 77.006787484692, 59.18485141569569, 44.30793677606891, 37.28776493380147, 70.13993324772005, 58.121767505522705, 2.773760941720778, 0.33966573496018687, 0.22124721909001951, 0.04816631884163907, 0.1520954499081258, 0.06776232317450546, 0.366286646815077, 0.19780754862773806, 0.22609131560931284, 0.11227280532400455, 0.3342263881237276, 0.4495804450444637, 0.4663325509717388, 0.5401770530208465, 26.156074462398408, 90.46591435709308, 59.627781145034305, 48.08523416519166, 26.050609773205174, 45.414551150414255, 65.52570404544954, 71.97117021006923, 77.94477524295931, 66.28178011986518, 79.56220380721554, 37.304776253238806, 0.7435944796569887, 1.4008379799704398, 7.762490693599948, 0.49481949979259127, 0.2956116650133364, 62.60225565202775, 68.36045588216474, 66.24424303731611, 65.41144540232997, 64.30040267206007, 62.19537250457272, 65.20491300090667, 61.41620543695266, 65.3030820815794, 62.23364699271418, 61.8902160275367, 57.95524327985702, 48.35481474476476, 44.633336605564246, 46.89124507288779, 41.94233179092407, 48.78056841511881, 50.94020582014515, 55.31425652965423, 55.91780731754919, 55.74571724860899, 60.33344691799533, 58.74419666105702, 56.289644087514574, 55.23743690982942, 53.50682050951066, 55.43548914694018, 59.40190361392114, 62.49428849066458, 55.96465610688733, 57.05968772211383, 55.23206326269335, 47.91067692541307, 48.34860563278199, 48.34976273198282, 42.315309970609604, 42.09920698596586, 41.238697805712306, 41.1846318552571, 38.5715998372724, 43.16169469587265, 43.26641413473314, 48.36249474556216, 44.65037930396296, 39.842722339014855, 44.683272300228, 43.527887175160075, 42.35257248724661, 48.504916006518954, 51.246919478139574, 52.23247381948656, 53.42085392244401, 48.08344948676325, 40.636147222211285, 40.30781345982706, 42.02986732605965, 41.76882574635167, 39.157174402667636, 42.85192551151399, 43.869333421030355, 40.5159265764298, 45.60994794291835, 54.325940839705936, 48.61665648798789, 45.72973712798088, 41.794650631566206, 41.89522020278439, 41.18535749373898, 44.39863374156337, 46.491175082422075, 43.46121472697104, 43.60866446648875, 39.24918143979965, 43.0536961555481, 43.21263843967069, 40.43053657777848, 42.17716409314064, 43.29032490330358, 51.82408055951519, 53.32400668051935, 54.10868075586135, 48.94746134358068, 45.59951051588982, 47.941651882663855, 41.74743706180204, 45.21005445911039, 44.835213153593, 39.66812195316438, 40.611451979606386, 41.53453080884872, 39.98947389664189, 41.41707543403872, 42.54520008640905, 41.34218954270886, 41.1309189181174, 45.68663812452748, 48.737379197151434, 46.81648469740345, 48.45053234407979, 50.26450695530061, 59.06659587737053, 55.39719504694785, 59.000958934907, 57.661143964336766, 55.15290983261601, 53.490523061444684, 55.87139783367034, 55.485879836543916, 57.62694481880435, 53.38038290700605, 59.23810543552522, 59.861652466558645, 60.863147320285925, 61.432224396736395, 63.370961758398245, 60.93327929896694, 56.029481118725194, 48.03855796014109, 49.4017110332366, 49.688220562473425, 60.586937935121604, 63.832459988132605, 69.64433393170758, 67.4050606450727, 68.74684856783959, 65.49512524758616, 76.92338220534786, 64.79721007808563, 85.708950104252, 11.601150131994679, 1.422337471477447, 4.837598867954747, 2.3791751602003655, 0.8571269327113706, 30.78643637318765, 86.95356522836994, 70.87293009604178, 77.19634779037969, 86.55386001833024, 81.29624443669474, 78.00001005972587, 60.91573061481599, 47.35719127039756, 79.70595867403092, 72.7853052077755, 4.1368267420799505, 0.4866435949600512, 0.43006686794181026, 0.21023700344226054, 0.30059166553039707, 0.14053078578604808], [0.08442085912270893, 0.07345296983276645, 0.04667142466191323, 0.0621111415356638, 0.08510504458700457, 0.06864224410345478, 0.21711809710869867, 0.33824822715213226, 11.565081977075147, 63.15436063274261, 52.54832267761231, 31.93480241683222, 24.175128475312267, 35.0552067449016, 43.52228603055401, 51.542399467960486, 63.062694841815585, 60.212814423345755, 66.41550940852012, 36.45472411186465, 0.07380376915417372, 0.3786364131637158, 1.5698340342890833, 0.08826474358718242, 2.390157061238443, 62.21803203705819, 61.673493308405725, 61.37805646465671, 57.14179469693092, 63.18295863366897, 60.28710803677959, 62.463509651922415, 61.40599550739412, 59.100069384421076, 54.31078087898993, 51.064733228375836, 46.713083174920854, 42.65927830050069, 40.87105404946112, 44.1865433416059, 42.48983975379698, 44.84394042722641, 45.057344821191606, 49.535561915366884, 50.348610416535415, 51.80909710545694, 52.79714215186335, 49.421550381568174, 45.09641555047805, 48.80677377024005, 50.22059994359171, 53.69241529895414, 43.4321617311047, 47.2174999790807, 53.72102114462084, 54.196690897787775, 48.01154067439418, 49.278423093980365, 42.645251904764486, 39.80353786099342, 41.690107699363466, 38.69349925748764, 37.063083725590865, 38.755245208740234, 38.90450708327755, 40.59122823899792, 42.18412237782633, 39.24413727175805, 39.543818120033514, 37.922651537003055, 38.28797325011223, 38.41004917698522, 40.386782538506296, 41.882099874557994, 46.84321565012778, 50.60088549890826, 46.19026260991251, 41.943818369219386, 40.10179488889633, 39.731903614536414, 39.89069292622228, 40.3586434548901, 41.76770394848239, 41.65133114783995, 41.7054049430355, 43.45200107943627, 41.51975524040961, 44.87415444466376, 44.662805372668856, 45.70904662532192, 40.10232440886959, 43.66546823132423, 43.15042572636759, 41.79338370600055, 42.65210036308535, 42.959312162091656, 39.63846098992133, 40.92689291123421, 41.161450647538715, 42.94847857567572, 40.83310511804397, 43.86206526910105, 42.25407784984958, 41.865292518369614, 43.76028368549962, 42.58789116336454, 42.84841891257994, 40.22286668900521, 38.72234044536468, 39.58650527461883, 36.89238609806184, 39.449147793554495, 40.30013345902966, 35.304818537927446, 34.9899188933834, 37.072889651021654, 39.33537944670647, 38.002428623937796, 38.2784418905935, 40.79865886319069, 41.19493984406994, 41.390991672392815, 45.86326245338687, 47.17552277349657, 51.71974159056141, 52.1447657000634, 55.67438502465525, 54.24286111708611, 47.938678726073235, 45.45209215533349, 45.09165379308885, 48.75030732923939, 50.90371601043209, 54.37888891466203, 49.10951014487974, 45.13356039600988, 50.135135419907115, 54.74130807384368, 57.22085006775395, 57.960420808484486, 58.449756099331765, 57.22564320410452, 46.785905899540076, 46.92346734385337, 40.88534324399887, 49.35002596147599, 56.75723375812654, 65.39311616651474, 58.74341218702255, 66.84655435623662, 58.06888218848937, 65.62412023544312, 60.100175719107355, 79.62330648975988, 16.65097128960394, 0.7596617336234739, 0.5306640183252673, 0.2820343806618645, 0.2673911002855147, 25.78487115521585, 75.10457131170458, 61.303660869598396, 70.08746762429514, 71.3021864429597, 67.66369388949487, 55.68083340121854, 39.482005488487985, 30.484256975112427, 65.71849638415922, 48.36794684010167, 0.7452404655275807, 0.07514289084581599, 0.04735142345570269, 0.03110812056899792, 0.09773276295633086, 0.05878709752352969, 0.11686007852756208, 0.02696709741177338, 0.05630606815459267, 0.03040409342746341, 0.14228382478317908, 0.038748493553289486, 0.14132080629708307, 0.48644254284520305, 15.962648276359806, 74.64632864921325, 59.597084676065755, 39.490348369844504, 24.96927115225023, 45.06454629282798, 51.79295655219786, 58.43414114367578, 71.73855012462985, 62.7414252681117, 73.2787472201932, 38.594196611835116, 0.014816413374407398, 0.02775229539932503, 2.77333315822386, 0.11302176352229812, 2.3517744627691086, 65.16096676549604, 63.72842696405227, 64.23784479018181, 60.35924042424848, 64.47479909466159, 62.454417597862985, 63.30073172046293, 62.91578638938166, 60.73038685706354, 56.0436918658595, 54.36549402052357, 48.73945805334276, 45.0034200760626, 42.85864453161917, 45.53031598367999, 43.95787700530022, 48.135126713783514, 47.997063206088164, 51.35444733404344, 51.94925123645414, 55.157593142601755, 55.13870693022206, 50.69190017638668, 46.35391958298222, 50.34222087552471, 51.94030038772091, 54.145900126426454, 46.69793498131537, 53.356221106744584, 55.05634107897359, 54.56527602288031, 49.23157822701239, 50.70507541779549, 45.54735475970853, 42.016276313412575, 41.97511888319447, 40.93090941829067, 39.23450000824467, 40.594428893058534, 40.27748569365471, 44.05683840474775, 44.70855197598858, 41.17593596058507, 40.045673616470836, 40.275375458502005, 40.5366406133098, 40.052788795963416, 42.22582109512822, 43.98133277893067, 47.804376771373136, 52.018363398890344, 49.412062168121345, 43.55237060977567, 39.47640042151175, 39.37154762206539, 41.04015527233001, 40.18626313055716, 41.208358272429436, 41.28553482793993, 41.29957299078665, 43.743056635702814, 41.44845831778742, 48.46099330532936, 46.55281512968002, 46.295633162221606, 38.87849784666492, 41.308802327802105, 43.61542663266582, 40.3124261671497, 41.68410647299982, 41.93603638679751, 40.698975747631444, 39.3771997574837, 41.309386760957786, 42.392537516932336, 43.6931287857794, 43.41817455907022, 44.94047780190745, 45.31764507293702, 48.630961372006325, 46.03657237945065, 47.25554696975216, 41.89452202089372, 41.65926218032837, 41.18607528748051, 38.79736754202074, 40.840424260785504, 41.04636830668296, 37.54582551217849, 38.28518052254954, 39.87399539639873, 39.71401368418048, 39.70040698205271, 38.95847497447845, 41.59471957914291, 42.009643585451194, 43.22015370092085, 45.23308269439205, 50.617049586388376, 53.57010795224098, 55.52584094385947, 57.66352092066119, 56.08600247290827, 49.45935418528896, 47.24887501808905, 48.75385315187516, 49.954200406228345, 50.63335487919469, 54.42082297417426, 52.64775476148052, 49.70108593663862, 52.72070692431543, 57.19214616283294, 57.200963650980306, 61.60322404676869, 59.182203815829375, 59.1252863022589, 50.18411797861899, 48.854136390070764, 44.127268483561856, 52.016413980914706, 58.56889024857552, 67.84036528679633, 61.38396747650639, 69.07241313688218, 63.384368419647224, 69.80775556256695, 61.63168084236884, 82.8984385152017, 22.837739490693618, 0.5486336218253259, 1.3623449422659413, 0.5793031857859704, 0.19763062828250472, 28.756315631251184, 81.63816528935587, 66.11784073614305, 75.08088804060414, 77.48726214132002, 73.54599398951378, 65.65479317019063, 43.835903060051706, 36.20338255359281, 72.79289107168876, 57.303972936445675, 1.4960123310166022, 0.14664989775947987, 0.16171657960982094, 0.01973380248302654, 0.11413999908273259, 0.05956265429455427, 0.21690463436947716, 0.26309386797008977, 0.2832911325798881, 0.28674603590080816, 0.2646775249271624, 0.36495748426645036, 0.3458557253883731, 0.7063581325834798, 18.761543766144786, 86.81216378365794, 68.2399449809905, 48.5649831833378, 34.54976620212678, 49.75008026246102, 59.975322754152366, 62.80705828820506, 76.8585846501012, 70.38366148548742, 78.24904918670654, 42.837044039080226, 0.13487367079623286, 0.8208509534597398, 7.402929471385095, 0.22549154537339366, 2.650451429428593, 69.19554418133151, 65.71644106218892, 65.7886754312823, 60.28222468591506, 68.39463541584631, 64.84001490377611, 65.66124939149427, 66.1658505470522, 63.45233132762294, 59.19022114046159, 57.428233623504646, 51.20485205804148, 49.14940457190237, 45.26215137973909, 48.37606614635837, 45.667547948898815, 51.247915760163345, 49.37893382964596, 53.82803124766196, 54.9845773943009, 55.90381230077436, 57.82354185658117, 53.44660036025509, 48.886582236136164, 52.77895412137432, 52.89626044611777, 57.8424947492538, 51.24577806841943, 56.860541143725, 55.400944832832586, 56.47510159400202, 49.36790020235124, 53.41117351285873, 46.49143788122362, 42.82033866451633, 43.834475317308986, 40.681179954159646, 40.97834656315465, 43.156776043676565, 42.81316857184134, 45.011511925728094, 47.3862874123358, 43.542419556648504, 42.449572701607984, 42.287708251707016, 43.25396453180621, 44.92809880164362, 43.21545470145441, 45.98376158745059, 50.256991694050456, 55.92495779837332, 53.285124225001184, 44.992523731723914, 40.481162609592566, 40.88223280445222, 41.028564668470814, 39.882910943800404, 42.16910362243652, 42.01174205349338, 43.59719153373472, 45.041961285375784, 42.5723389656313, 49.67066795595231, 51.56307428113876, 48.13368720393027, 38.74384287864932, 43.86495213354788, 44.62682154870803, 41.8372554163779, 42.9508908333317, 43.17197522809429, 41.322275669344016, 40.33226943785145, 41.76273822784424, 44.318366358357096, 43.160521907191125, 43.18673118468254, 46.510143664575395, 48.36005503131498, 51.37024271872736, 50.08315617038358, 49.148831905857215, 44.32257898392216, 42.88024894652828, 45.51892149832941, 40.442919500412486, 41.8534077367475, 43.219333925554835, 39.969748297045314, 39.55179229859383, 42.51331906164847, 43.03343711360809, 42.249017992327296, 40.28677778859293, 44.13129283535866, 45.80373264128163, 45.289647194647024, 48.90610387248378, 53.09046483808949, 55.979878825526086, 58.60722357226957, 61.9387435913086, 59.40033466585221, 50.75151628063571, 50.1309149496017, 52.51285268414406, 51.37523981832689, 50.97959426141555, 54.4220075299663, 55.86764412541544, 55.05117139508648, 56.44619372583205, 58.8981810692818, 58.77314375292871, 62.26607322692872, 62.84831377767748, 61.21279131981635, 53.662346409213164, 53.33763299449798, 46.812291683689246, 53.517795301252804, 62.74553591205228, 70.0265924392208, 63.883537092516505, 70.1238436852732, 64.33539021399714, 71.28116253883609, 65.9867472802439, 81.45076228726296, 28.173614202007172, 1.1763101119187571, 2.929977914018016, 2.886797521383532, 0.6858145962319067, 33.43655047878143, 88.44162617960285, 70.94941631440194, 84.41803532262003, 83.03117152183287, 80.75523976356753, 71.59830185674852, 55.501349664503536, 48.38536608603693, 80.17836109284433, 76.01166648249473, 2.7866375927002203, 0.389402553198799, 0.29903932624766905, 0.22667410933682997, 0.27552183657403917, 0.25236212528280677], [0.028837194643734448, 0.0348590613312779, 0.05946151153635114, 0.024153047706931833, 0.04746619874851839, 0.16359047663788642, 0.08969069368416265, 0.22475640740125413, 4.898670661833979, 62.272690265409416, 52.202526523220925, 30.80529905134632, 22.185500321849702, 41.72186713064871, 47.105532000141764, 52.930930276070875, 60.07960680992373, 64.10400175279187, 61.42620748089206, 53.793275125565074, 0.6629461975347611, 0.24631691015055104, 2.146026535380271, 0.17303105473758715, 4.597324277124097, 65.89627388984927, 63.315283713802216, 59.49166313294442, 52.05222129821778, 54.607131634989095, 56.79907760312481, 59.18203907628214, 57.14310476856848, 54.18144072255781, 48.15400508142287, 44.54380850638113, 40.69140949556905, 42.554217615435206, 43.62333413093321, 42.794047017251295, 42.23736070817517, 44.7724199295044, 44.69638086134388, 45.14113057044245, 50.23747790244318, 49.42985403922297, 48.053384519392445, 42.38924272598759, 42.90034717129123, 47.800222981360655, 46.70576010980914, 49.66387441081386, 52.11224532896473, 48.332163057019635, 47.815626129027336, 47.777292805333296, 48.54145288467408, 47.284666645911436, 42.94985532760621, 42.052444488771506, 39.799968504136615, 37.927872211702415, 37.81628078030002, 37.93193186483076, 36.96430275517125, 39.48948544840659, 37.08260928430865, 36.48771124501383, 38.52464514393961, 37.97449350357056, 38.906511414435606, 37.78179922411519, 39.26371382128808, 40.593503213697865, 45.00624418258668, 49.51370646876674, 49.210158163501376, 43.63379509218278, 39.39280686839935, 40.85609805199408, 37.900650962706536, 41.03928058378158, 40.72309832419119, 39.03155265315887, 41.127074995348536, 41.95623659318493, 41.588165298584975, 44.18381337196597, 46.6027469019736, 47.156056050331365, 39.78540082131663, 40.47685976951353, 40.40196211107316, 42.02885143218502, 42.85209809580157, 42.57231543141027, 41.31844351368566, 40.481488166316865, 42.426556233436834, 42.863767147064216, 42.309296977135446, 41.195163419169766, 42.04780824722783, 44.243119608971384, 44.057367924721014, 44.858045270366055, 43.157791937551195, 42.91185932774698, 38.002087377732806, 35.61183421842514, 37.50166746877855, 36.60214247242097, 38.44116926193237, 40.18157589820124, 37.053348402823175, 37.12821468230217, 39.19337395698794, 39.087858276982466, 37.93829394925026, 39.48889709288074, 41.49538163215884, 41.79461140786448, 46.43839566938339, 48.64556435615786, 52.16602494639736, 54.43759110666091, 53.6475786855144, 48.4668101802949, 49.50335925625217, 51.85579292235836, 51.445783645876, 50.88149970577609, 48.79930557743196, 53.32421848850866, 57.70544321306291, 59.066839064321215, 51.38529677544871, 53.758279738887666, 55.016536866464925, 56.267321878863925, 56.06444120407105, 56.91031602121169, 46.71873531033916, 46.741767467991004, 44.47150353462466, 49.45387463415823, 54.044526469322946, 59.909540683992454, 56.58373948066466, 59.58830248924994, 54.24843872747114, 64.43199426897111, 56.581362524340236, 80.09592071656259, 20.64941975378221, 0.7175242624455883, 0.7951149957314615, 0.758571376002604, 0.12156553611519838, 29.748057511545, 71.52175288046561, 60.14281188288043, 72.22753632453181, 70.97444888084166, 65.06283690852504, 37.0044207572937, 31.492806211594615, 36.148892987158995, 65.80621234832272, 44.699177511276744, 0.18805275190501444, 0.06416156437368163, 0.05745373298263839, 0.03998812723664507, 0.11714716231630695, 0.03195406932894501, 0.059920624198932806, 0.03243147808637831, 0.043555281590670354, 0.04151983194113259, 0.046026183277248375, 0.09885706593312564, 0.0900923535828629, 0.3128613603691901, 7.094740021613337, 72.09457582043063, 60.29975375821514, 37.941169046586566, 26.492213741425548, 47.86701310065485, 52.764821821643466, 51.469874843474365, 64.83263692548199, 68.74760166291269, 66.41091239067816, 57.78938977949081, 0.36855708627450856, 0.37952669926228066, 1.227636899678938, 0.17895823104246972, 4.895148373419239, 68.89277642773044, 65.31570426879391, 61.44348159913094, 55.69522849975094, 58.972011843035304, 58.7060437663909, 64.12128763814127, 58.904139149573545, 57.11917438814717, 51.88099022834532, 47.30267816974271, 43.18769216537476, 45.36419183977189, 46.0632013505505, 45.386525815533055, 46.14272740579421, 46.39606937285393, 48.159657216841175, 47.876026707310835, 53.52157254372874, 51.45808027636621, 50.329747738376746, 44.61831785017445, 43.560407546258745, 49.839420087875865, 48.12880385306574, 52.72667677171769, 53.26998779850622, 49.6230778386516, 50.26398528006769, 50.300584916145574, 48.75859921978366, 49.977161961217085, 45.5998674515755, 44.40414467165547, 40.836799990746286, 39.6842703511638, 41.83720050319549, 39.28958969731485, 39.38706844083725, 40.77662298756261, 38.271511062499016, 38.77939131952102, 40.37543904396796, 40.47666757337509, 41.14138772410732, 39.97751851235667, 42.367112713475386, 43.20815124819356, 47.79464537097562, 50.56653338093912, 53.64304442559519, 46.499306155789284, 41.40207236812961, 40.08831762498425, 39.51512598222302, 40.42204464635542, 41.1268396531382, 40.264267306174006, 42.34432374277423, 41.65846986155356, 39.10457541865688, 48.09462431938418, 48.86895510458177, 47.01750224636447, 39.35831746747417, 41.6427529242731, 39.63847275703184, 40.77945101645685, 41.8450766225015, 41.15892464114774, 42.370787974326845, 40.78777820833268, 41.22564808014901, 43.22539398747106, 40.95260012534357, 41.98563083525627, 43.709343864071755, 46.33308787499705, 45.433005902075, 48.20442322761782, 45.63194851721487, 44.08143951046852, 39.49273317090927, 36.7463719460272, 40.74512243270874, 37.191372686816806, 40.610169364560036, 40.57029454938827, 37.14561431638656, 38.563406005982436, 40.67805382513231, 39.98444934045115, 40.3379568746013, 42.76908113110451, 41.40707731246948, 44.268595403240575, 47.459918145210516, 51.71065345887215, 54.860893295657256, 56.800026816706506, 55.28121448332264, 51.507831619631865, 50.765150439354684, 54.25232187394173, 53.67097954596243, 53.57276731921781, 49.7739714191806, 53.59795678046442, 55.35256239675707, 60.01086335028372, 54.595521419279045, 56.718284622315444, 57.44824947849397, 57.9211578830596, 57.983527491169596, 56.19202806103615, 51.22059645191316, 48.57055294898249, 45.82510563635057, 51.124761181492964, 57.70281914741763, 62.27049373811292, 60.00241456493255, 63.60066752279959, 55.01998462984639, 67.8139442013156, 60.13049171816919, 82.98091027044481, 27.662672535065685, 0.6563553899045914, 1.1706572410560425, 0.4245443546002911, 0.08127019229915836, 32.545505646736395, 80.60517772551506, 66.06371987250544, 78.80298983666205, 76.18827512187343, 72.63365068743306, 44.63155192713584, 31.40521772446171, 43.855762020234145, 74.06161308288574, 56.02531948397237, 0.7456396279796478, 0.10366463538018927, 0.15767214098765006, 0.02286090252680644, 0.07347351631089565, 0.004474876134941776, 0.11984019119653011, 0.10997862479979954, 0.2555051235662353, 0.08161883891349839, 0.17499721939525298, 0.23228296078741553, 0.3592421925596653, 0.5332956835627556, 8.452795974669918, 83.91447359515776, 66.88497789444463, 46.638220817812034, 29.958100434272524, 53.96478860608993, 62.32957640001851, 62.785214608715435, 71.56236510122977, 75.27967376093711, 73.91370834842806, 63.52036483826176, 1.055648567215089, 1.0365576561420196, 6.237191740543612, 0.31144060434833654, 5.053331678913486, 72.18375482866841, 66.03365882750481, 65.36330615320514, 56.66844306453582, 61.26453522712954, 59.19871699425482, 65.02964188975673, 60.9337382162771, 59.79974569812898, 53.30421832300002, 49.24432985244259, 44.995124263148156, 47.67957087486021, 49.951917586788056, 48.6222654773343, 47.496074553458925, 49.80908839933334, 49.54062961762952, 49.490611553192146, 56.17309870258455, 53.27675388705347, 52.33874259456512, 49.14213641997307, 47.052725130511874, 53.75256092317643, 49.78045509707544, 52.22066356289772, 54.411966262325166, 52.69655689116448, 53.732874547281575, 52.84826632468931, 51.84468869240054, 53.08429494980843, 48.07925647304904, 46.534815372959265, 42.96102231548679, 42.19534035651915, 43.29327844804333, 40.09170263044296, 42.28374665783298, 43.56060366476736, 39.936392461099935, 39.55385938767464, 42.382821806015514, 41.69935272585961, 43.5993488373295, 41.6788387298584, 44.51208437642744, 45.048523410674065, 50.862240868230025, 55.82456473381289, 56.52416260011735, 48.54924271183629, 39.625132776075795, 40.90316649406187, 38.63111788226713, 40.6588145994371, 41.66893866754348, 40.287676011362386, 41.93005084991455, 42.782954554403986, 39.90879074219735, 49.892893760435044, 52.06939735720235, 47.70005741427022, 39.674476192843535, 41.37485896387408, 39.76462794888405, 41.89361595338391, 44.11756453975555, 42.19037071351082, 42.98678444277856, 40.10005727890999, 42.68301648478354, 44.1929328826166, 43.607687796315844, 42.39940166473389, 45.254043840592914, 51.00426596979941, 49.86241302182598, 50.22919385663925, 48.08082542111797, 47.060997409205285, 41.74635448763448, 39.26525923513597, 43.016967081254535, 38.894979646128995, 41.92972137082008, 45.01679928072038, 39.40773933164535, 41.33171681434878, 43.085412440761445, 42.28267977314611, 41.68645205036287, 45.3368450749305, 45.58460158686484, 47.77689664594589, 51.63822297127017, 53.111704472572576, 56.11119585652506, 59.353176009270456, 60.22242423026793, 53.847384222092174, 53.156666601857836, 55.25124757520614, 54.94944472466746, 55.799390962046964, 51.855910593463534, 56.00667253617318, 56.98114618178337, 60.1166888975328, 59.206396995052216, 59.60286232732958, 61.39445197197699, 60.14564383414484, 60.46919230491885, 60.42004108428956, 54.28388126434819, 49.67453149057204, 49.03750719562654, 54.273012376600704, 61.30126430142311, 65.20316362380981, 63.426620191143414, 64.71745652537193, 58.77357913601784, 69.00845496885239, 62.77329844813194, 85.97742065306633, 36.620001023815526, 0.9111391957248411, 4.586443131969822, 2.0214060934320575, 0.296140173750539, 37.19236112410022, 88.27465088136735, 69.93502862991826, 84.7799131947179, 82.61289781139743, 79.18015710769161, 53.3909458498801, 45.17857351610738, 54.64662598025415, 82.46806821515484, 69.11001297735399, 1.8219322422819755, 0.4780268218488463, 0.319769359043529, 0.1284643264126874, 0.23918357437416432, 0.09893469362249298], [0.0722750177186343, 0.0888441818495912, 0.030908545088623802, 0.03052509701510351, 0.10732883392202278, 0.04931383428253955, 0.058749264271389094, 0.2796146766312661, 2.976678388734018, 57.416184102335286, 55.13424327296596, 41.62547488366404, 33.281110871222715, 38.694640667207786, 46.77422508116692, 62.06310233762188, 55.66463793477705, 65.04336626298966, 57.722897760329715, 61.485580398190415, 2.8102708535809673, 0.21934220357046974, 0.8876339021709658, 0.08281021288806394, 3.398098820640195, 63.62043626846806, 62.82966682987829, 61.87023547387893, 50.36143656699888, 49.02917608138054, 50.548537546588534, 53.589358945046705, 48.766989169582246, 45.7020216603433, 43.1743247278275, 44.573151757640225, 41.81388201252107, 40.710507515938055, 39.32479296961139, 41.90478686363467, 43.34756797359836, 42.96488192773635, 44.80062569341352, 45.724830242895315, 46.17545174014184, 47.805855504928104, 43.86771740451936, 38.97395656954858, 43.0710801001518, 44.41588432558122, 49.699842545294, 49.78190245166902, 52.1521907467996, 53.47769298861104, 52.92494473918792, 51.54436849778699, 49.044092855145855, 47.02619029629616, 41.80222472836895, 42.46981605406731, 41.39199579915693, 39.16108500572943, 40.31465799577775, 37.01079853119389, 37.81522566272367, 37.11714575367589, 37.07472139789213, 37.0260996972361, 38.391868991236535, 38.593380758839274, 37.87767371823711, 37.632996266888036, 39.09660516246673, 40.593122743791156, 45.4233294148599, 50.09813962444183, 51.53914782308763, 44.82911779034523, 40.07632693936748, 39.542209948262865, 40.63384871329031, 40.599951590261156, 39.996330199703095, 38.513654662716775, 40.21376679020543, 41.828453617711226, 40.90590038607198, 45.61599623772406, 46.94993549777616, 42.98461929444344, 42.44237907471196, 40.997503419076246, 38.75838702724826, 40.9915021927126, 38.61218460144536, 39.70768690109253, 40.339969050499704, 41.79046154022217, 39.879286673761186, 42.429407796552105, 42.55299383594144, 42.60833847907282, 44.332894817475356, 42.703640307149584, 44.363795249692856, 44.48047007283857, 39.952309439259196, 41.16571818628619, 41.419036619124874, 37.61458858366936, 38.11700105667114, 37.58137395305019, 35.24377076856552, 36.61707493566698, 37.14959552211147, 37.178593604795395, 35.77299656406526, 38.72450167132963, 39.75188416819419, 38.72869076267366, 40.50019787203881, 44.15429361404912, 45.955544056430945, 48.81046079820203, 50.71901944375808, 53.82360289173742, 51.86950552848078, 53.738028541688, 55.38452971366144, 53.42807108356107, 52.21262662641464, 51.950651522605654, 53.109955095475726, 52.74667301485616, 50.362891766332815, 56.874034097117764, 61.15585811676518, 53.31505583178613, 50.87498072654971, 51.080583526242165, 49.379545719392844, 48.555083121022875, 44.160357598335516, 45.320382887317294, 43.49564921471381, 47.61749544451314, 47.84249828707787, 54.84179527528825, 50.46275531091998, 53.82666234047183, 49.33335588824365, 62.811604315234774, 57.67786110601118, 74.8121193916567, 17.42088156361734, 1.2864719619674068, 0.6451576359329686, 0.39314391211636607, 0.07278109540141399, 35.2204522778911, 72.84720805383498, 62.89102446648383, 71.24828523205173, 72.02023121618456, 64.60102881154707, 40.868496664108775, 35.235310216103834, 38.948535688461796, 67.23753621501308, 37.288165015559045, 0.3334967659846429, 0.0493081882145376, 0.042039990319960543, 0.038074795832677234, 0.022757279558948452, 0.04780534970303697, 0.052267673966144367, 0.10227555709500467, 0.06372081483864496, 0.008208548796603517, 0.11755527267532966, 0.04453773955784498, 0.08064468150898334, 0.2133167535066605, 3.808409629329559, 70.00012428529801, 61.1001173142464, 41.42898767225204, 17.183564439896617, 44.43934794395201, 54.074214889157204, 64.97432470321655, 61.33223925867389, 68.05491109048167, 63.561953729198834, 64.66961929875036, 2.6837979497448092, 0.3389677982176504, 1.6470251761136518, 0.34293837064216215, 3.7555958955518665, 64.26801958391744, 65.27311125109273, 63.83585283833166, 51.27525860263456, 50.886579175149244, 53.19301128387452, 54.999545158878455, 51.31100708438505, 47.66240266061599, 46.0630169991524, 47.48178928129135, 43.45726490020753, 42.192865340940415, 43.0985955269106, 43.94973024245232, 45.17522381198022, 46.173243445734826, 47.85356721570415, 48.37765078390799, 49.28079220556444, 50.70229053497315, 46.29928488885203, 42.49051440146662, 45.37959498743857, 46.38032890135243, 51.05252681239959, 50.664023891572036, 52.259275374873994, 54.94587929018083, 55.02173008457307, 52.260679583395685, 52.50185043581071, 48.34160027965423, 44.58766844964797, 43.62980211934736, 42.35984848391625, 41.899923124621, 41.01266730216242, 39.53185881337812, 39.78865246618948, 38.737896565468084, 38.20885512136644, 38.880392351458156, 39.72571803677467, 40.35514077832622, 38.502240565515336, 40.595032938065074, 39.742670520659416, 41.838851821038034, 47.94902593858781, 53.50216465611612, 55.60072291281916, 48.96737521694553, 40.48088412131033, 40.33029648565477, 40.560963230748335, 38.81506135386806, 39.613204848381784, 39.69323688937772, 40.912144799386304, 41.56592938207811, 40.76727990181216, 47.71245210401474, 52.00229344829437, 44.54192969106859, 41.804048630499075, 40.45976215793241, 39.703733151958836, 41.5897342466539, 39.58965886023737, 38.769381430841264, 41.45506751152777, 41.62672219737884, 40.36522519203925, 42.8693800587808, 42.63492038173061, 42.88836040804463, 46.85000919526624, 45.82415642276887, 47.07541211958855, 46.1587110642464, 44.27769530204035, 43.37696613803987, 41.893439446726155, 40.62951057187973, 39.42031837278797, 38.193871667308194, 36.91960734705771, 37.63045457101638, 39.152416567648615, 38.28988344438615, 38.069073615535615, 40.172919227230935, 42.93431097461332, 41.52686257516184, 43.99588869464013, 43.38319878424368, 46.6786761437693, 49.85977326670001, 52.225774411232244, 54.30128089843258, 55.21679347561252, 56.311711342104026, 55.95108078372095, 55.17392589199928, 55.23768401915028, 53.6145366391828, 55.025326898021085, 54.321775282582934, 54.42419621252245, 57.260297344576934, 60.886516801772586, 53.87636269292524, 54.32502692745578, 54.25726406035885, 50.92640299950877, 51.347755770529474, 46.246591767957135, 46.84442766251103, 46.050728213402536, 49.37503891606485, 51.46960419993247, 59.33825923550514, 53.78408501225134, 55.963801030189764, 50.14277227463261, 65.23956321900891, 60.67341443031066, 78.2998909488801, 25.22731604114656, 1.280420970532202, 0.9895647809870782, 1.0939155783384078, 0.0141997097225319, 37.48726844787598, 79.51697887912874, 66.65796679835167, 78.52422698851555, 77.34036153362644, 70.76947366037678, 49.91041891036495, 38.502581811720326, 46.96730375289918, 75.38451871564313, 45.41233108889672, 0.20929192673535119, 0.07718664488845295, 0.05365219785861912, 0.05112071393898899, 0.061570436678706646, 0.03878743763292029, 0.13390896691670343, 0.12127604681037127, 0.13412670442654243, 0.1176944325467752, 0.29586098066741423, 0.12217066130570828, 0.14541741550689744, 0.32321234203634724, 3.793176369320962, 80.01894812430106, 71.31892711885514, 55.32590204669584, 42.7400359799785, 52.52682416669784, 59.73634450666366, 74.17944108286213, 68.65803826239802, 74.11843253720191, 68.04023358129686, 71.24076212606123, 3.5106818762517746, 0.95365866898529, 4.290330659958625, 0.21787431782051442, 4.260438276875404, 68.70957820646225, 66.06930532763081, 66.04296268955355, 51.39231389568698, 53.600231755164366, 54.719107458668375, 58.243231542648815, 53.089648985093646, 50.26501294105284, 48.36981781067387, 50.929274174474905, 45.749490184168664, 44.70248799170218, 44.57900001156715, 45.803579668844904, 48.426507826774355, 49.38371127651584, 50.67937212605631, 51.32682992566017, 51.56958149325464, 52.342421777786754, 48.575408843255815, 43.35619718797746, 47.877168117030976, 47.781234787356475, 54.041404262665786, 53.96256462220223, 55.37603778223838, 58.410834420111875, 56.823521814038685, 55.27312263365715, 56.22548980097617, 50.956373829995435, 46.07350933936335, 47.32471404537078, 44.122424356399044, 43.04152896327358, 42.95727645197223, 40.873168206984, 41.94845068839289, 41.12250935646796, 40.82363651644799, 39.92607270517657, 42.66034518518756, 42.9767902435795, 40.71937599489766, 41.2306373350082, 41.80055772104571, 43.472887700603856, 50.93557350097164, 55.332699514204464, 56.51954597042453, 51.43248681099185, 41.024301052093506, 40.85813768448369, 41.19559880225889, 40.125242817786436, 40.48823072064308, 38.92302851523123, 41.7154501330468, 42.487862879230136, 41.343993832988126, 49.21353532421974, 54.71339256532731, 45.134027158060384, 41.61213882507817, 41.906226373487904, 38.22770211004442, 42.848779770635794, 39.16207344301286, 39.111698442889804, 42.29749456528695, 42.58679682208646, 40.715979222328436, 44.38657637565367, 43.56374940564556, 42.504144637815415, 50.287696007759344, 49.71187245461249, 49.47618899806854, 49.72563212917697, 46.3188692831224, 45.52469130485289, 45.96147075776131, 42.80613968449254, 42.013762074132124, 42.80812440379974, 38.87703872496082, 41.25840379345802, 41.61271933586367, 39.52338257143575, 39.76703628416985, 41.967446727137414, 44.26364537208311, 44.69355675481981, 44.48311375033471, 47.52437053188201, 51.622470732658144, 51.56961287221601, 53.43712783628895, 55.65917799549719, 56.55274098919284, 58.09439720646028, 59.512824320024066, 57.979997358014515, 58.03208251153269, 54.60414671128797, 56.54389604445427, 55.31962233204996, 57.30129003524781, 60.17390058886621, 62.98194108470794, 57.377819399679865, 55.06501343942458, 55.071622633164935, 54.002506117666925, 53.91963428066623, 49.188871460576216, 50.01634251686835, 49.56238308260518, 50.04845103909893, 54.09532900779478, 62.54416142740558, 57.53674991669194, 57.587211208958784, 53.151088991472804, 67.47767940644296, 63.648041909740826, 80.72921091510405, 35.185103877898186, 1.5454381175579563, 2.101269349936516, 2.6796466112136845, 0.2199414528666004, 41.771132100013, 87.72373830118488, 72.11701177781629, 85.78794663952243, 83.02735113328504, 78.13487683573078, 57.984508083712676, 47.372884673456994, 55.4679036140442, 82.68874860578968, 58.55201228972405, 0.9430006699215983, 0.38940000978689043, 0.22348310798406604, 0.2127637299558809, 0.19142343151953914, 0.12975283267517246], [0.04347755430987285, 0.06517918194614111, 0.060237049155177615, 0.09399547196564176, 0.0442084864593081, 0.02118008455351716, 0.08447048629844382, 0.0025109261895845374, 0.5194079190973313, 47.583449271417436, 60.580269905828665, 49.66043449217274, 48.51713811197589, 42.55613565444947, 47.39923907864479, 67.11183209573069, 53.28938391900832, 67.35570938356462, 52.17299499819356, 68.16957766009916, 7.9162652550205115, 0.2858469551128726, 0.7351830793965248, 0.38395625028398733, 0.6531934692494331, 51.27883580423171, 68.88767734650644, 59.38017760553668, 58.18278389592325, 47.207505779881636, 47.43435213642736, 43.28367256349133, 45.4265026123293, 42.98777680243216, 43.56662450298187, 41.031910450227805, 42.279847821881695, 41.745821045291045, 40.10480726918867, 43.410914251881266, 41.111746372715125, 41.87998571703511, 42.63323376255651, 42.28051462481099, 43.22405253687213, 40.38055773704283, 38.9268998945913, 41.691358935448434, 41.440284098348315, 40.94190382188366, 44.58380099265806, 46.18624610285605, 45.879097061772505, 45.699409361808534, 44.58146326003536, 46.480365030227176, 42.86850537023237, 41.50713697556527, 42.972028486190304, 40.79441878103441, 44.01293139303885, 41.433172841225904, 39.61943357221542, 40.13277769088745, 36.88196828288417, 37.931014030210434, 41.19386511464273, 39.10392822757844, 37.946699588529526, 37.50209500712734, 38.581950972157145, 40.4743847539348, 38.72827891380557, 39.43753757784444, 45.7986492495383, 51.108593171642674, 54.28989033545218, 44.06926447345365, 40.908759793927594, 40.46872869614632, 40.03005473844467, 40.922252747320364, 38.82917404174805, 39.05620867206205, 40.175896306191724, 40.2429727585085, 39.70666708484773, 45.96694638652187, 49.76459303209859, 44.768277906602435, 39.89147347788657, 41.21489686350669, 41.2684097597676, 40.68108189490534, 41.37083853444746, 41.402648956544944, 39.869963199861594, 40.92620257408389, 40.449630675777314, 42.210139459179295, 43.39527183963407, 43.92779634844872, 41.06928279322963, 45.76238301492507, 45.3068938562947, 40.49864461345058, 38.786228010731364, 38.37029203291863, 38.91704690071845, 41.457311107266335, 41.38846566600185, 43.702891565138295, 41.33164621168568, 38.270706976613695, 38.30725169950916, 38.48385249414752, 37.78497634395477, 38.85404971338088, 41.32053805935768, 39.66390932759931, 40.93614970484088, 43.128264334894, 44.034010210344874, 44.155599763316495, 50.01354586693549, 50.48944703994259, 52.02517655587966, 52.80381802589663, 53.045887101081114, 49.73614015886861, 49.685533738905384, 50.112213088620095, 49.529980382611676, 52.79646358182354, 54.013649571326475, 51.84541825325259, 48.0245590209961, 52.19045739020071, 49.245314367355846, 45.73248670947167, 46.20090400019, 46.04675485241798, 44.22818714572538, 44.38140276939639, 45.213929760840635, 45.9702294103561, 45.277538837925086, 47.66530913691367, 46.079702761865434, 47.918384382801676, 51.16384367788992, 63.99646605214765, 56.28995787712836, 69.90137469383978, 10.810486597399558, 0.5622156865654454, 0.4575267073608214, 0.6975494697690011, 0.07540017381430635, 36.67520053925053, 71.4807091989825, 61.29294495428763, 70.03696318595641, 69.17378287161551, 60.52898491582563, 38.50432334407684, 36.80133611925187, 39.187717899199455, 66.89621940735849, 31.138761312730853, 0.25155485247171694, 0.03892148386747126, 0.06570951397260351, 0.006313754326378506, 0.06825370729089746, 0.14435687402804054, 0.04862851883855559, 0.028242582094765482, 0.019309073761706392, 0.07120924385925455, 0.014191615046001973, 0.01910366452178888, 0.02409937941739636, 0.028879088161873723, 0.8448477077387995, 56.507343476818455, 65.48519380630987, 55.283509069873446, 35.081541538238525, 41.20754634180377, 56.86902915277789, 70.35081555766445, 58.74492229953889, 72.38026557430145, 57.80239243661204, 75.67060070653116, 8.015128595213737, 0.43974353901801577, 0.5455589739065017, 1.0527799663043793, 1.012667173579816, 54.02928021646316, 72.69210969248127, 60.49895917215655, 60.688911714861476, 49.52290442682082, 49.52091578514346, 44.99250804224322, 45.34436033618066, 43.433828738427934, 46.02873548384636, 43.79278444474743, 45.1017499739124, 43.136273814785866, 42.97128715822774, 45.062710623587336, 43.64268710536342, 44.90550202708091, 43.54671847435736, 45.70745806540213, 47.15506761304794, 41.70468322692379, 41.8430644466031, 42.61845034937705, 42.39026254223239, 44.66030682286909, 45.17860097269858, 48.036855651486306, 49.57040040723739, 47.825875282287605, 48.46594725885699, 48.95157198752127, 44.795326571310724, 43.44638816771969, 43.79146652836954, 42.942520495383974, 45.79684888162921, 41.737372259939875, 40.90418631030668, 38.969073218684045, 37.821171975904896, 40.04233960182437, 43.92978499012609, 40.35515254543674, 39.99654985243275, 38.8950071027202, 40.21788920125654, 41.44704626452538, 39.73822647525419, 42.708507968533425, 48.295488895908484, 53.8878591599003, 54.0307903289795, 46.104056758265344, 40.41969122425203, 40.07498941113872, 39.48204863455988, 39.86385999187347, 37.33870083285917, 39.92339372634888, 40.5663800239563, 40.25246097195534, 40.423221357407115, 48.9831627568891, 52.949506621206964, 46.05473295334847, 39.750640776849565, 40.07579741939422, 39.27785396575928, 39.379333526857444, 40.27761120950022, 41.10458412478047, 39.85062983728225, 39.82110615699522, 40.146101982362815, 41.34341332220262, 43.54352958740727, 43.76326076446041, 45.44014853815879, 48.60694862181141, 48.020864148293775, 44.28121759045509, 41.46678363123248, 42.78865375826436, 41.875114133281095, 42.65889783059397, 42.965552653035815, 45.71140789216565, 42.640831393580285, 42.72362086080736, 38.96234635383853, 40.62216397254698, 38.783674547749186, 39.57046670298423, 41.953969463225334, 41.32849262606713, 43.22307194432905, 44.68549236174553, 45.98968044404061, 47.95014381408692, 52.350321431313795, 52.17736059619535, 55.16911706616802, 56.2323578711479, 54.91041321908274, 52.21485061030234, 51.45758213535432, 50.928721120280606, 52.74363317797261, 54.97006462466333, 56.33965822958178, 55.99501917439123, 51.01958674769248, 53.830659235677416, 52.5929553278031, 48.96449619723905, 49.188090908911924, 48.57587560530632, 46.37840693996799, 46.49421491930562, 47.202108598524525, 47.156071739812056, 47.33186452619491, 49.43265068915583, 49.207463495193, 51.886520770288286, 53.90172866082961, 68.87526696728122, 60.22781748925487, 74.92291850428428, 15.268506426965038, 0.5307065515268234, 1.0740970675983736, 0.7729194060929361, 0.027526716979581024, 40.36875140282416, 77.40820284812682, 67.27581854789489, 80.47170731329149, 73.29932397411716, 66.75334315146169, 41.63410802041331, 37.2976218500445, 45.686857777257124, 75.65287159335229, 39.19753166937059, 0.29151383006284315, 0.04671393488083155, 0.06276363394253197, 0.034060587039998466, 0.034419403471533334, 0.08809059648023498, 0.11899925648204743, 0.1512073548210244, 0.08807201118719193, 0.36022493014893225, 0.1800689359586085, 0.1061036065220833, 0.1636064725537454, 0.10731889776164487, 1.038640924999791, 66.60752511793568, 75.99436883003482, 65.86098824777912, 62.33980986379809, 59.94427719423848, 63.32352461353425, 78.59016203111219, 64.07807488595286, 79.69838065485801, 62.31807601067328, 81.95381410660283, 10.857597204946703, 1.1440375855853482, 2.819724010844385, 1.3876752411165547, 1.49210074736226, 57.37563463949389, 73.36544729048207, 65.75584127056983, 62.45856354313513, 52.791176226831254, 51.403182783434474, 48.55494191569667, 48.614985558294485, 46.823701858520515, 49.22284703100882, 46.84617703960788, 48.55021545963903, 45.509805910048954, 44.85814332962037, 48.866111386206846, 46.15884834720243, 46.52674705751481, 47.01133628045359, 47.92447190130911, 48.25488451988467, 43.712230728518584, 43.51987769526821, 45.554964157842825, 45.62364485956008, 46.16994473241991, 48.18701182642291, 51.55834390271095, 51.58614566249233, 50.50383429373465, 50.067890305672925, 52.23184624025899, 46.87950149659188, 46.88517324386105, 47.16028044300695, 44.53714439945836, 48.49392552529612, 44.91975199791693, 42.855891027758204, 41.58896546210013, 39.45432532218195, 42.314611788718935, 45.702511956614835, 43.865975872162856, 41.945908992521225, 42.00888264563776, 44.10987669421781, 45.70134309030349, 42.277349272081935, 44.999050555690644, 52.881582936932965, 56.312374222663145, 58.589184591847086, 47.11640088788925, 42.72525256679904, 39.5349221844827, 39.98249992247551, 39.67083623332363, 37.38888363684378, 38.76708684429046, 41.14861272996472, 40.38381722665603, 41.251590636468705, 48.64350118944722, 54.65463546014602, 46.81138169380927, 40.0628928215273, 40.327433155428984, 39.91668647335422, 40.13307971339072, 40.181744560118645, 41.50450506517964, 39.527716790476155, 40.194774673831084, 40.46004849095499, 41.736999634773504, 44.70665354882517, 46.67441644976216, 47.75099331332792, 51.910823775875954, 50.739776626709975, 45.09044570307578, 42.96962407327468, 44.64449182633431, 44.033739566802986, 44.748705279442575, 45.33679408411826, 46.29839451082292, 44.65807499424104, 45.813028658590014, 42.333262658888295, 41.970918024739916, 41.72780167671942, 42.45953944421584, 45.739719560069425, 45.33276188758112, 44.834762081023186, 47.55539255757486, 49.35598796413791, 47.44773134108513, 54.52270653940017, 53.71167021413004, 58.42250347137452, 57.883981658566384, 58.63381724203787, 54.982016086578376, 54.46595376537692, 54.61566279011389, 54.9094561607607, 59.56271294624575, 59.946618849231356, 59.22842894831012, 53.169751628752685, 55.7851331464706, 56.762732921108125, 50.10271310806275, 51.870560646057136, 50.75303816026258, 48.11231420886133, 47.8805648896002, 50.758054871712964, 50.612966399038996, 49.84524088521158, 51.755486149941724, 52.276404365416504, 54.388808588827814, 57.12554039493684, 70.12780527914725, 62.56915477014358, 79.03135807283464, 24.63358686816308, 0.866770631363315, 2.2054455405281437, 2.0015747124148957, 0.16717943002379712, 44.163726914313536, 84.86648774916127, 72.71416910233037, 84.0762556752851, 77.91959362645304, 73.11836150384718, 54.025216640964636, 51.182592607313595, 55.58772417806811, 85.8666999878422, 52.318107005088564, 0.5403679621315772, 0.14497029595077038, 0.17938930871746234, 0.09417459864409701, 0.115056018074674, 0.2062707823971587], [0.086274707629796, 0.09969060789913901, 0.07341632018646888, 0.11555402119073177, 0.0845477462656075, 0.04161892158369865, 0.028487057988381678, 0.044638185176037015, 0.15357652769213723, 44.91026770684027, 56.8995608821992, 46.290141843980365, 26.434692182848533, 30.704415690514352, 49.47316485066568, 72.17969125316989, 57.12693283634802, 63.66575925580917, 54.07587797411027, 68.8348900887274, 20.667974525882354, 0.23415845127836352, 1.7045434251908334, 0.4828898254181109, 0.03913573184681516, 29.095449639904885, 75.1095134981217, 57.132573204655806, 63.92995834350587, 49.00564970508699, 49.717316704411665, 47.98449200968589, 47.504829283683534, 41.69156682106757, 44.39783750041839, 40.525877629556966, 42.11636735546974, 38.83014678955078, 40.619049610630164, 38.61244347787673, 40.323134237720126, 38.80851099568029, 39.23002850624823, 39.64234805876209, 39.556793320563536, 39.248957864699825, 40.549039225424494, 39.37495223937496, 41.56084991270497, 40.47024273103283, 42.14747959567655, 40.94000147235009, 41.0449876323823, 40.497605185354914, 42.31720839777301, 42.23835699019894, 41.95690339611423, 42.2227773358745, 43.27446676069691, 41.76591142531365, 40.1954807004621, 39.743184351151996, 38.99330562160861, 38.8286994349572, 38.34470641228461, 38.67520140063378, 38.227372630949944, 37.73827660468317, 38.39874490614861, 36.494810735025716, 37.09539228870023, 38.767577140562, 38.23607637036232, 41.62911484318395, 50.64467091714182, 50.44418288815407, 53.680722713470466, 49.03261992239183, 38.19118876611033, 36.942031537332845, 42.052381730848744, 40.06167688677388, 38.917317544260335, 39.49409815572923, 40.32254588219428, 40.66721239397603, 41.14245853116436, 46.55089709066576, 51.541975851981874, 45.00429476461103, 41.238721339933335, 40.48945450013684, 41.41740099076302, 41.56567835038708, 39.81176699361494, 42.13122529368247, 41.842381954193115, 39.56834077835083, 40.462229328770796, 42.802142789286954, 43.0720724598054, 47.65015309856784, 47.31223698585264, 52.663016703821, 47.47028889194612, 41.13525705952799, 39.42467220367924, 39.03330203025572, 37.79136980733564, 37.266948915296986, 37.37930913125315, 38.448649221850985, 39.733754973257746, 40.04700329995925, 40.48761098615585, 37.89753660078972, 38.70277958531534, 39.673797622803725, 40.451572249012614, 40.08853335534373, 40.18969128208776, 40.39666691134053, 41.164266909322436, 42.00522699663716, 42.24713525464458, 44.072876976382354, 43.237984795724195, 46.263775671682055, 44.464827660591375, 43.209171064438365, 44.21954224186559, 43.48454106238581, 44.109311872913, 47.85012729706303, 48.93262693958898, 49.34531519489904, 50.779321962787265, 49.57468363546556, 46.74658806093278, 44.49886991131691, 42.28482923200054, 43.541815511641964, 43.482407293012066, 42.646860076535134, 43.68517814144012, 42.811874189684474, 45.033634093499955, 44.68872831713769, 47.14089608961537, 50.254195044117594, 52.71050091712706, 64.13258406423753, 59.09781402157199, 65.18270061862084, 7.429343202421743, 0.1205906049618798, 0.833720924152482, 0.8938701643097786, 0.07117020401863322, 37.050904766205825, 75.09471047309138, 56.15789559579665, 67.69501793769099, 64.08403688861479, 60.73095560073853, 39.01564351973995, 44.65373685283046, 46.906781581140336, 61.4348170834203, 16.88387966925098, 0.3054559867708914, 0.14265205260486374, 0.011335587553349475, 0.03635186792141007, 0.005162383547999086, 0.03247001230896961, 0.0495969420749574, 0.022933232718177383, 0.024055350429168152, 0.07790382575964735, 0.08258557292602717, 0.06983238467646223, 0.09242241000456196, 0.002082574829992448, 0.24583611336927264, 55.447299403529016, 65.83461423074046, 53.45215051404892, 39.09779756299911, 50.19821889938847, 53.80021772077007, 77.00004885273596, 61.2276178790677, 72.27495777991511, 58.18499611270044, 77.79736472714332, 20.838487802013276, 0.19085894729341232, 0.4877079362350126, 1.1109338844976118, 0.1616927695971343, 29.686654767682477, 76.56325371034684, 60.278565114544286, 66.08508110046387, 50.67164897918702, 50.602803537922526, 48.05551436639602, 51.49187149540071, 43.18429539280553, 45.56664889858615, 43.56387492149107, 44.380520236107614, 41.50172802709764, 42.263499383003484, 42.45882949521465, 43.04267037299372, 41.48868222390452, 42.74143626613002, 40.085575888233805, 42.1927829711668, 41.32002030649493, 43.62552673585954, 41.79826705686508, 43.95765735257057, 42.581999763365715, 45.17383137056905, 42.573884379479196, 43.02040307752548, 45.22468489985312, 44.65607458545316, 42.83001907410161, 43.740667912267874, 41.93888794991278, 44.82995325519193, 44.11753708316434, 40.89869106969526, 40.705443736045595, 40.94010345397457, 39.63957886542044, 40.129361306467366, 40.631134433131066, 41.746538839032574, 40.52818790558846, 39.29477899305282, 38.46181661851945, 37.973995362558675, 41.144282433294485, 40.65859102433728, 43.37618166400541, 51.174606661642756, 53.970644704757206, 55.34591790168516, 52.831553105385076, 40.446900706137384, 37.54849664626583, 40.571396735406694, 38.319877809093846, 38.51094822729788, 40.308284144247736, 39.57866445664437, 40.50297491012081, 41.79389361412295, 47.39672876173451, 52.866874048786784, 46.6513882144805, 40.732131542698035, 40.53005887616066, 40.19773214094101, 41.027992002425655, 39.84439326870827, 40.210805400725334, 41.55885342628726, 38.976847356365575, 39.13919818016791, 42.11542990899856, 43.503552790611025, 48.764204286759906, 52.21720795477591, 53.47343329460391, 49.693857008411044, 43.91505649012905, 40.42230744515696, 40.24199216596542, 42.13065655000749, 39.544563370366255, 39.49612994347849, 41.5341228823508, 42.134943700605824, 43.07281771013814, 42.40000570974043, 38.09892285254694, 40.64440773379418, 40.47927202716951, 41.94632084138932, 41.49030608515586, 42.125808500474506, 43.74094640055011, 44.72425714615853, 44.23794208034393, 46.38965237525202, 47.35615576467207, 46.245571951712336, 47.224638692794315, 46.67950376387566, 44.24308823001, 45.80729023102791, 44.70367646986439, 46.36385102425852, 50.533028494927194, 53.03922691652852, 52.33576551560433, 52.264688245711795, 51.23429336855489, 48.558099423685384, 46.31753175489364, 44.68993640715077, 45.026503224526685, 45.19680077029813, 47.36992720634707, 46.222308374220326, 47.047751565133375, 46.06399759169548, 48.37621127405475, 48.72041494615617, 52.04193292125579, 54.74341438662622, 67.38030264454504, 60.87738160164126, 69.92565416520642, 12.144555295667342, 0.14110565816442813, 0.6448413948378255, 0.722581974921688, 0.06974865892721761, 41.692516034649266, 79.82026438559257, 61.672030264331454, 73.56136183584891, 69.67831734688052, 64.4532339034542, 46.426934503739886, 51.92844306269, 51.994021169600956, 70.61543433896958, 23.696244339789114, 0.46277673854943246, 0.12898771002167655, 0.024234402414050796, 0.06161509960469219, 0.02010417726611899, 0.0789402814341649, 0.12983759264311484, 0.13037848136117383, 0.21079494527751402, 0.2704525102050074, 0.18406178621995836, 0.20332102213175068, 0.15362497509246872, 0.25253565951941476, 0.4290002284030761, 65.35884249594905, 72.37721397030738, 64.33180909002981, 38.537381079889116, 45.55476411696404, 61.77917372795844, 84.3249967021327, 68.02346152644004, 75.55078014250725, 62.890185079266956, 85.80125916388728, 25.13660534735649, 0.5242725774165123, 3.28225455937847, 1.73414395941842, 0.25715239646454013, 32.69798582600009, 78.79193659751647, 60.54387815536992, 69.37078783589025, 53.697200590564364, 54.01929386200444, 51.60402382573774, 53.04113711080244, 47.221951869226274, 47.798151969909675, 46.5989500476468, 46.04094974456295, 43.66868457486553, 44.928338066224136, 43.0254158666057, 44.94286260297222, 41.97429910782845, 43.97830863152781, 42.6298213005066, 45.09010053450062, 43.252564245654696, 45.589481015359205, 43.028039932250984, 45.88141126017417, 46.06618235188146, 46.87933283467447, 44.10163579448577, 45.5828796663592, 46.10552764707997, 45.258848744054, 45.894378615963845, 46.89915649352535, 45.098867031835745, 46.99181464410598, 45.81098118136006, 42.966694062755955, 43.75276842424947, 43.55975643281014, 42.74589600101594, 40.447026221982895, 43.12311034048758, 42.6888176702684, 41.94899982021701, 41.372446706218106, 40.38858682878556, 39.650192799106726, 43.65193605422974, 44.400928328114176, 45.5727207276129, 56.766651368910274, 55.91222970716415, 58.80985713774159, 52.329336750891905, 41.42080560807259, 38.16330071418516, 41.482343673706055, 39.08625794995216, 38.20327751098141, 41.22498912196006, 41.40458268503989, 41.369755960279896, 41.61109155224216, 50.07879057238179, 56.56861874365038, 46.7346405213879, 42.02247758065501, 40.0760837524168, 40.83699218688473, 41.39338431819793, 39.09614624515657, 42.085431621920684, 42.71200672272713, 39.273719787597656, 38.87072763135357, 42.18423612656132, 44.62526829011979, 51.37769522205476, 55.2494550520374, 58.04093137864144, 53.79897432942545, 44.95830105197045, 44.16122051977342, 42.97935939604237, 43.85634645338982, 41.53686461910125, 41.75379522385136, 43.1998711247598, 43.235560770957704, 43.86011977349558, 44.7962797072626, 41.80854758908672, 43.90505052381947, 42.98091657700078, 44.87466827515633, 43.24958324432374, 43.01163265782018, 46.30592938392393, 46.129210918180405, 45.947099193449944, 49.23252744059409, 49.726212639962476, 48.85807444972377, 50.90917987208213, 48.92297006422474, 47.08990919974543, 50.09831613109958, 46.808922367711226, 48.033702065867764, 53.72302155340872, 57.21494297827444, 54.61027345349712, 54.88497664851528, 53.5915986184151, 51.40302981099775, 48.60486976562008, 46.523605239006784, 47.52258977582378, 48.392257690429695, 48.89732560803814, 48.79922320765834, 47.47759234520697, 49.86058519732568, 48.80265528155912, 51.00076721560571, 53.6938940325091, 58.52901935577393, 69.81050906642791, 66.67023597225067, 73.35024418369417, 18.78497208318403, 0.24199427435955695, 2.804506685464613, 2.7398503355441557, 0.13966372747334743, 45.186633986811486, 87.0113338962678, 66.1422457233552, 81.34323443135908, 74.49349741781913, 75.14232020224296, 54.392244585098766, 61.20503679398568, 61.336738217261534, 82.26777630467569, 31.99510885823158, 0.6674818670557392, 0.4230568876429912, 0.17292911907838238, 0.18018046303862528, 0.10136996455971273, 0.1765599621519927], [0.05905369612117929, 0.04780964745629219, 0.0736818845654207, 0.07209725467668426, 0.056664290867986224, 0.03099847998049471, 0.03416289808228612, 0.056802807225575375, 0.017969210879997383, 32.08495663058373, 61.705044854071836, 48.50625745711788, 16.628976598862682, 20.18671735640495, 47.52087570005848, 67.96151161193848, 55.23077280290666, 54.320951584846746, 58.64887914349956, 64.9143438185415, 33.09091514156711, 0.07511292148621813, 0.24823159369970524, 1.188478897656164, 0.09241205249582568, 7.022140381797668, 71.28695195721042, 59.01323987591652, 63.09680377283404, 54.020478417796475, 48.98088385981899, 45.151744504128736, 47.26389377347885, 39.65016926488569, 43.034547144366854, 41.47638559341431, 42.038794640571844, 40.34400516940702, 41.96197502074703, 40.89170532841837, 40.820467241348766, 39.96011103353193, 40.500813684155865, 38.98318198419387, 40.496048004396506, 38.608819207837506, 41.15402952317269, 40.89263100777903, 40.64478035896055, 39.22823206070931, 41.468399647743475, 41.198336616639175, 41.06223429402998, 38.832096207526426, 39.53319634160688, 39.592271158772135, 43.254956891459805, 41.76595457138554, 42.83436113788236, 40.6081768005125, 40.65266432300691, 40.07367149476082, 38.91497196689729, 39.71375873011928, 37.449939250946045, 38.555957425025206, 38.59475751076975, 37.114502076179754, 37.73189883078299, 37.57427446303829, 38.69843359916441, 39.23964223554058, 40.49659713622063, 44.88518414958831, 48.65810809596893, 50.56365828360281, 51.08720056472286, 49.20993458840155, 48.90853181962044, 36.44847969855032, 38.56455133807275, 38.78960124907955, 38.719284919000444, 38.589156366163685, 38.671310409422844, 39.03165463478335, 40.644615619413315, 47.05983246526411, 50.89599678593298, 45.346854963610255, 40.92327648593534, 39.89837292701968, 42.21426971497075, 41.513004841343054, 41.06317958524151, 38.66146133792016, 41.78332282650856, 40.93582414811657, 42.752167870921475, 40.447187039159964, 45.84002241011589, 36.46008206952003, 43.33025855402793, 54.85428017954673, 49.07745653583158, 43.30083685536539, 38.13677764707996, 40.183309585817405, 38.4025574499561, 38.85689735412598, 38.279587222683816, 37.06571563597649, 36.96157670790149, 34.90335218368038, 39.430873470921675, 40.502861161385816, 37.39290014390023, 37.87571253315095, 40.25721880697435, 39.5775975719575, 39.130380692020545, 40.37848672559185, 41.44598722457886, 40.953827827207505, 41.10632173476681, 40.083257767461966, 40.36553898165303, 41.36304086254489, 42.111978223246915, 43.099905598548155, 41.138222371378255, 38.527535930756606, 39.04600658724385, 41.33490962366904, 45.69111354889409, 46.47100233262586, 44.6993814745257, 45.28863914551274, 43.56096452282321, 42.69725076613888, 42.64665611328618, 43.11945861385715, 39.79981553169989, 43.118556468717514, 41.859569780288204, 43.87312243061681, 43.896142821158136, 43.06664389948691, 44.84726267476236, 47.07347054635325, 49.36006722911712, 66.10179039739793, 59.07276968802176, 63.758688049931685, 12.108533228597334, 0.2483742086276893, 0.08510485306502351, 0.3814882520706423, 0.12261400404836863, 40.25357884745444, 67.46814804692423, 61.835530342594275, 68.30891593810051, 67.2935555058141, 67.58337943784653, 21.85735091086357, 18.16847747372043, 42.54034026976555, 61.98651021526706, 15.108739464513718, 0.24263121518156222, 0.11884912623152619, 0.188661178934478, 0.14214747645441564, 0.008672726257974583, 0.10071436183587198, 0.04136128621476312, 0.09349790551970083, 0.0334323987725281, 0.04873297109659161, 0.06585341592830035, 0.08637260600563981, 0.1424804642315834, 0.1108024987362085, 0.02475834909766432, 39.81981177483836, 68.35754548349689, 56.87812120683732, 22.5647170312943, 25.669898640724924, 58.125242725495376, 71.87100072060862, 63.55212426954701, 61.370250948013805, 61.71874569308374, 72.02372997037827, 35.375813438046364, 0.04379111026684123, 0.16908939447133772, 1.8022029654633616, 0.1324210709501659, 7.9937953141427815, 72.29980207258656, 59.739262750071866, 68.75666233801073, 55.14855992409491, 50.529011987870746, 45.81704908801664, 49.6725114699333, 41.307731520745065, 45.84178747669343, 42.874898833613244, 43.88163789626091, 43.534735633480935, 45.32778832220262, 41.60281927354875, 43.06216455275013, 41.555025192999075, 43.59184534318986, 40.157280737353915, 43.56864844599078, 40.495353744876006, 41.68365932280018, 42.25966330497496, 43.49060504667221, 42.61082918413224, 42.73705105627737, 41.32697466881045, 45.06722527165567, 42.1011132578696, 42.13533593762306, 40.8698812607796, 45.19376485578476, 43.352102233517556, 44.046828516068004, 42.937903865691155, 42.49502120479461, 41.30105956908196, 40.42747712904408, 40.956091034796934, 39.07132940907633, 39.49360001471735, 38.978518286058986, 40.54320666097826, 38.84121571817706, 37.883372922097486, 41.57949293813398, 39.515165205924745, 42.53513920691706, 47.84029783741121, 51.832395984280495, 54.40203089867869, 53.664448799625525, 52.067922546017556, 47.88236917987947, 36.999580552501065, 39.69254655222739, 39.04333545315651, 38.958537732401204, 38.417450689500384, 40.08079059662358, 38.65392254244897, 39.87193222968809, 48.25556701229465, 53.104914849804295, 44.9444237063008, 41.72183575168733, 39.56461452668713, 42.61304924564977, 40.54519530265562, 41.14477272956602, 38.76419997984363, 43.07865811932472, 39.17884942023985, 42.53684936031219, 40.31790179591025, 44.551931735008, 42.47558978296096, 47.901325994922274, 55.84090140558059, 52.80259032403269, 45.5625343322754, 39.97145452807027, 41.12081489255352, 39.70033637938961, 40.692197891973684, 39.37577201474098, 38.413477328515825, 39.130451294683645, 37.05642354103827, 40.336976282058224, 41.12485885620117, 40.4050450940286, 40.366766683516964, 41.69254349124047, 42.44947856472385, 42.27955364411877, 41.7342225966915, 44.08937054295694, 42.250108411235196, 44.172160010184015, 41.523218693271765, 42.4507886363614, 44.871134219631074, 45.36425067532448, 45.20083296683527, 43.109621309464984, 41.22191790611514, 41.13396267737112, 43.67923575062906, 48.66239916893744, 49.37593321646414, 48.33944689842963, 49.49891913321711, 47.046747438369266, 45.81478588042721, 45.21669895418229, 44.70194670461839, 43.051931088970555, 46.231365126948205, 45.663272565410985, 46.54304058321061, 46.165559522567264, 46.576820035134595, 47.74562358856202, 49.774598998408166, 52.75817732657156, 68.48062161476382, 61.47338182695451, 68.56856899876749, 15.039447853642127, 0.2690887204822033, 1.5366327642433106, 0.31511476203318567, 0.12932543222221637, 45.277327029935776, 75.44229522828134, 66.28476112119614, 73.54194610349595, 70.5511780708067, 74.28434879549089, 30.414656477589762, 24.90406959287582, 47.394241979045255, 73.32048123882663, 21.185801913661344, 0.3716897423709593, 0.07182606721236821, 0.06439679933171119, 0.03862870804544899, 0.06221921355914205, 0.06499397252956707, 0.14842395820925314, 0.1733412590598868, 0.14910442814711602, 0.1662315341133264, 0.2061772124180871, 0.2757429601925035, 0.2831893348165097, 0.24224852361986715, 0.14778845763254553, 47.71943000055129, 76.4382791519165, 65.54317035982686, 25.2856554139045, 29.68376986442074, 63.870612882798724, 78.34331943142799, 66.43174802103351, 65.00957896632534, 66.1649876256143, 79.64587580773139, 40.029454615808305, 0.1816669953686576, 0.8134538536110233, 4.868968023407844, 0.34331482624815357, 9.084948685861404, 77.11297388999694, 61.278204687180065, 68.9095014141452, 58.36008679482245, 53.93135040037094, 47.26964789052164, 51.21931383686682, 41.92544990970243, 48.461824847805886, 46.7606536803707, 45.95279055256998, 45.00018412067045, 47.41540708849507, 45.67727934929633, 45.21779721783054, 43.37587571913197, 45.20643018907116, 42.83409049434047, 45.47966641764487, 42.808650001402825, 45.89754789106308, 46.956454477002545, 44.366399703487275, 44.273674872613725, 46.56108348600326, 45.34437994803152, 46.627591194645056, 44.57224569013042, 42.56449422528667, 42.992005117477916, 48.69021269582933, 46.493155879359094, 46.28660386608493, 45.06436194142988, 44.61043780849826, 43.03245259869484, 42.255564428144886, 43.06536520681074, 40.46015831731981, 42.46603096685102, 41.27217131276285, 41.38841859755978, 40.957318736660866, 38.639127362158995, 44.46840093981835, 43.64736257060882, 46.25176537421442, 49.13260113808417, 54.465000629425056, 57.59045893146146, 57.87952584605063, 55.08031852783696, 48.61681730516496, 36.1920625932755, 40.12199117291359, 38.7272394857099, 38.16708187903128, 38.55335297123079, 39.40841790168516, 39.63376199045489, 42.594049284535075, 49.47835414640365, 55.880003513828406, 47.47086155799128, 42.925650381272845, 39.38083971700361, 44.068276036170225, 41.354156694104596, 41.79182652504214, 39.68832608192198, 42.03673931860155, 41.05110652985112, 42.44674467271374, 40.99113741228658, 44.738562030176965, 48.69313878397788, 53.68558253011396, 60.29326223557996, 55.371425074915734, 47.540377724555235, 41.596547403643214, 43.263817525679066, 41.651817521741314, 43.149911895875015, 42.078139935770345, 40.966214672211684, 41.49203585040185, 38.30505517221267, 43.6986554053522, 44.673591890642726, 42.513911339544485, 43.114704701208304, 44.08667195227839, 44.68022461860411, 45.05624655754336, 44.055391050154164, 47.69502893570931, 45.82516447190316, 46.43678749761274, 43.532221394200484, 45.600287145183934, 47.17922549093924, 47.535243341999674, 48.173310987411014, 46.06604114655526, 41.49732712776431, 44.63976537027667, 45.82026935392811, 51.12808342902891, 52.364845968061886, 50.50490510079169, 51.14072130572412, 50.005010789440526, 47.260245969218595, 47.88701718853366, 46.18919180285546, 44.57492074658794, 48.72068166732789, 48.25060913639684, 49.96736388052664, 49.55935109046198, 50.68920158570813, 50.659673983050936, 52.45718640665854, 55.04820608323621, 71.96367848304011, 63.699515173512125, 72.25296897272911, 19.09548455669034, 0.3226154063257479, 3.749917284134896, 1.3384975444885994, 0.27371607540595916, 50.05274211206744, 81.48897401748165, 71.77820528707197, 80.0104679599885, 76.77425369139641, 82.57160309822329, 34.49225248829011, 32.00231621342321, 58.44874412782731, 84.19941025395548, 30.20676301371667, 0.5489025493302654, 0.2123729791492224, 0.2595972281790549, 0.296243473046249, 0.16858371515427867, 0.19326556654226398], [0.04599008138381666, 0.029635592326221448, 0.010698366151641934, 0.10769487839312324, 0.04067475652141918, 0.05023260353012912, 0.08468345108051455, 0.04037730373261918, 0.1924107809581103, 21.529142664324855, 68.07186357436642, 46.73366777358517, 44.356613389907345, 51.34798326799947, 41.06110072905018, 71.17877298785795, 54.700848825516246, 51.55788890777096, 62.275016230921594, 57.48226035025812, 47.06146809362596, 0.22848668868743607, 0.2021083968781656, 1.5035445074881277, 0.07509317173953019, 0.4171584702787861, 43.92993796256281, 66.04507292470625, 60.29430166367562, 59.04069646712273, 49.59402092041508, 44.229014765831735, 44.04376906733359, 44.10797434468424, 41.30126745470109, 39.73843436087332, 42.351854693505075, 40.656292515416304, 42.516656998665106, 39.821023787221606, 40.67756352886077, 40.5942641535113, 39.88597823727516, 39.993423723405414, 41.26823325310984, 40.786295552407545, 40.10803145747031, 40.79585436851748, 41.66932698219053, 45.057917487236764, 41.49939029447494, 40.40081677898284, 39.52718334813272, 38.94364449285692, 39.883938604785556, 40.22703616849838, 40.41380374662338, 40.20079158967541, 43.059007044761415, 39.79494787031605, 39.0828101865707, 38.58146852062595, 38.26916940750615, 37.76200302185551, 38.8517512044599, 35.639365334664625, 36.798013871715916, 38.33178220256683, 38.42548370361328, 37.654498700172674, 38.98268776555216, 40.40128746340352, 46.02246361394083, 50.50524634699668, 49.14809450026482, 52.745107989157404, 51.02170482758553, 55.66527335874496, 50.69453600914248, 38.73011850541638, 39.51070547103882, 38.70609398811094, 38.45434450334118, 40.142893483561856, 38.216386072097286, 42.592123400780466, 37.76317188816686, 45.523192959447066, 52.79365908715033, 47.22226173646989, 40.37241881893527, 41.10258763836276, 37.83346860639511, 41.49973154067993, 41.4078970878355, 41.633186263422814, 42.65865072127312, 41.93863691822175, 41.28908849531605, 40.75613644815261, 42.234689574087824, 45.304328626202, 47.316865382655976, 57.05221952930574, 49.325934763877626, 43.91813555071431, 39.86430321970294, 39.486480912854596, 38.233824929883404, 39.79282586805282, 37.634294571415076, 40.71161754669682, 37.3913311958313, 35.52115686478154, 36.68403371687859, 37.1862304595209, 37.801720942220385, 40.46104085060858, 40.56458750078755, 38.907460628017304, 39.619763051309896, 40.40777114129836, 41.09299744329145, 40.2475070184277, 38.85291614840108, 40.50970569733651, 40.5464739953318, 42.07149151832827, 40.36273840935, 41.135868949274865, 40.95864449777911, 41.14058363822199, 40.381718758613836, 41.44193541619086, 40.85579602949081, 42.530546111445275, 44.112524294084125, 43.989173596905125, 40.47696175113801, 41.64023476262247, 40.13481732337706, 41.93645215803578, 40.68167417280136, 43.10223548643051, 41.10637664794922, 45.29511105629706, 44.804469616182395, 48.29904648565477, 42.42403414941604, 46.74561139075987, 45.09836889082386, 60.45251438694616, 56.19086703946514, 71.40436418594854, 19.75043212213824, 0.2453474258823741, 0.1398413526194711, 0.4545643985752137, 0.8905426460889079, 53.66324070961245, 63.93456712845833, 62.260468159952474, 71.0009248795048, 66.51560045057728, 58.74129018475933, 29.25062840984714, 38.00168729597522, 52.586118636592744, 67.73901124154368, 12.349592293462447, 0.3931076301922722, 0.08991267532110216, 0.048320405936289224, 0.0938605179169005, 0.07724844520130465, 0.05247108946223894, 0.07542377698325342, 0.12142653712221693, 0.03993032590275811, 0.11059702629403723, 0.043784560215088635, 0.04816263395872328, 0.05925209757180945, 0.04229153912033766, 0.15537128783762455, 27.697969944246356, 73.65084678896012, 55.63686755395705, 31.32269693959144, 39.646776414686634, 56.45347364487187, 72.59841995854532, 63.18243695843605, 56.02481742059031, 69.5780223415744, 63.92874240875245, 51.36835998104465, 0.22021966535718213, 0.3012835348565733, 1.4548832154081714, 0.0394158135919321, 0.7443860017003552, 48.30999382080571, 67.63649617472004, 63.883568471477886, 60.00086130634431, 51.11766953622141, 46.81281335892216, 44.870455649591264, 45.42090539009341, 42.96602333745649, 42.813996191947695, 44.295283209893014, 43.43080851339525, 44.718808973989184, 42.56017177335678, 43.40472475174935, 41.155072873638524, 41.624929674210094, 41.1042821022772, 41.92869370983493, 42.78008337943785, 43.202648162841804, 44.28695209564702, 45.23650692355248, 46.35162107406124, 43.259895155506754, 41.28903750450381, 41.0253797038909, 41.03769594623197, 41.29234798492924, 43.25070504219302, 42.2960275988425, 42.01443672180176, 44.201311065304665, 42.0578573596093, 40.72176864070278, 40.22243130591608, 39.83042570852464, 38.80939745133923, 41.042983301224254, 38.10411214828491, 38.99992266008931, 41.09213059948337, 39.729369763405096, 40.33103781361734, 41.00821541201684, 42.09622206226472, 48.196841286074736, 54.04246330261231, 49.365158465600786, 54.29553854850031, 54.050410024581424, 55.872962859369096, 53.13994161544308, 41.78635089628158, 38.637511345648, 39.00546889151297, 37.261453674685576, 40.09744105800506, 39.324012417947095, 39.884130800924, 36.97982357394311, 46.373386306147424, 56.0674810409546, 47.16575999413767, 40.95061540603638, 41.3167098260695, 38.32860116035708, 40.502861161385816, 40.537985986278905, 40.633750654036, 40.85654127982355, 42.6313941709457, 41.621689796447754, 40.83672154334284, 45.61013621668662, 47.539255926685954, 52.31297654490317, 56.392888715190274, 50.679215231249415, 45.51500697289744, 43.122263108530355, 40.65159743832004, 39.596405336933756, 41.15626527417091, 38.4678727580655, 40.05818597732052, 39.056377333979455, 39.43132454349149, 37.737111660741995, 38.949355463827814, 39.627341070482814, 41.070600709607525, 42.19343800698557, 41.15726940093502, 41.30380130583241, 43.42622718503399, 42.299420449041556, 43.13430086258919, 41.284056094384965, 43.03575131200975, 42.76632762724354, 43.38206129689371, 41.414031674785, 42.56410198826944, 42.94854917833882, 42.89282406530073, 43.60611100350657, 41.895330029149214, 42.37195291826802, 45.61542749404908, 47.15421253635038, 46.57014808347149, 44.085550154409106, 43.838899750863355, 43.84202587989069, 44.44256428749331, 43.54209007755403, 45.77743707164642, 43.267704594519834, 49.5507767892653, 48.517553883214156, 50.03756253950058, 45.330326095704116, 50.24422437913957, 47.6019157901887, 62.073480929097826, 60.57166814804078, 74.02957516331827, 21.54320828376278, 0.14407084744063117, 0.20892696244822395, 0.7292648969638733, 0.9994185715913774, 55.58817132826775, 71.43367213587608, 65.91694478065737, 76.68623570472964, 71.43454290205433, 66.64901594961843, 35.4489460299092, 39.30121952487577, 59.22800140996134, 74.42720936190698, 16.403257923741496, 0.36540307164672886, 0.050352503951158256, 0.06076031019009891, 0.06258259587470563, 0.022479356266558174, 0.06522536938709599, 0.25215152771242205, 0.13146667861409728, 0.17699916035898272, 0.2501379422122433, 0.10703880835564868, 0.11555314018961885, 0.18224353781871258, 0.2689752168953419, 0.34291581701367135, 31.100863372125936, 86.86858315621653, 60.749441731360655, 57.13684858814363, 67.9306660929034, 57.08799154527726, 80.4668749532392, 69.34781059142082, 66.70118347291024, 73.47805853812926, 71.76201374300065, 55.3204813311177, 0.44666569499719533, 1.5551747886403915, 3.8640013817817938, 0.20902215653369505, 1.3809113589025315, 51.78151892077539, 68.57533116494456, 65.47396013813635, 63.0489077106599, 53.14325994060886, 47.826749970836026, 48.11058444361533, 49.00934850015948, 45.71316903637302, 45.65914230961954, 47.21994361569805, 46.6106112541691, 46.63210192034322, 45.05691336047265, 45.835809784550825, 44.48802455779045, 44.07825846825877, 42.68768802765877, 45.425321978907434, 46.00520518518264, 45.051712297624164, 46.25678993040516, 46.42993903929188, 48.43276008482903, 45.73971171532908, 43.206535231682565, 44.06227873217675, 43.366791509812884, 43.486953320041785, 45.877794834875296, 45.029841161543324, 44.88161871510167, 48.083967239626, 45.23825630064934, 42.54182684806086, 42.19761925358927, 42.679070580390196, 43.040787635311005, 42.43730745007915, 39.04384928364908, 42.450533682300204, 42.82810495745751, 40.79601910806472, 42.08611019196049, 42.77896550393874, 44.955316128269324, 50.16339217462848, 56.03475278423679, 52.76360588689005, 58.169918521758056, 56.527806482007435, 59.2901631324522, 57.77313155512656, 43.935040966157, 38.339721079795595, 40.09489543976323, 38.303243037193056, 39.54417897808937, 37.84626730026738, 41.00925876248268, 37.19726800918579, 47.91206936682425, 59.18480042488345, 47.744278215592914, 41.554421147992535, 41.708295729852495, 37.644673162891024, 40.360094731853856, 40.94092715171076, 42.0136522477673, 43.03869308963899, 43.08305117391771, 43.170504339279674, 39.58195532521894, 48.59089436069612, 54.87502167301794, 53.106217076701505, 60.26543694157755, 53.367062537900864, 46.52521733314761, 44.76444182857391, 43.34439477612896, 42.072723142562374, 44.304339962620894, 40.545203147395966, 42.51536261650824, 40.9661832932503, 39.297285387592936, 41.76183608270461, 41.56715708394205, 41.74163979868735, 44.906729728944846, 45.364701747894294, 42.82386487530124, 44.525706768035896, 45.42172516545942, 45.77004732624177, 46.12284883376091, 43.90528194365963, 46.06269536479827, 45.01434779936268, 47.37702277398879, 44.216816194595836, 46.6010053696171, 45.13058723941926, 45.75240842757687, 44.772384628172844, 45.342473676127774, 45.29757430476528, 47.70031629070159, 49.50654029846192, 49.73069198669926, 45.587182506438225, 46.16179012483167, 45.18793229133853, 46.430166536761874, 46.5068135722991, 48.34637772652411, 46.326392389112904, 51.757121778303585, 52.2989462267968, 53.283908290247766, 48.27877567660425, 52.659655232583326, 50.46965476005308, 64.52677834418513, 64.27227927792457, 78.01152613855179, 24.243214937948412, 0.3950151891237305, 3.2733713715307178, 2.0147832939701695, 1.3446137453279188, 63.39548833908574, 77.99237712737053, 72.5022905103622, 83.30782413482666, 76.19587667526739, 74.58750094136884, 42.53328784819573, 51.41091377504411, 67.68300764022335, 84.97997760772705, 21.613526575026974, 0.6461063592183975, 0.2159945832024659, 0.1544107514764032, 0.2022424316213977, 0.13729798667613538, 0.13786781819597368], [0.07199079909872624, 0.10076528370019891, 0.032736377249802315, 0.05919083352050474, 0.04780989260442796, 0.06606811206907996, 0.18797749142733314, 0.06564745318985755, 0.15966965396317745, 13.660080682846809, 65.81686158334055, 50.82304462309807, 38.07186242072813, 18.256267962917207, 44.41457817631383, 63.70842287617346, 61.274247015676195, 57.66955352598622, 62.10735451790595, 54.44092904367755, 60.600968253227975, 3.6223480778355754, 0.4256895641165395, 1.4819215838947606, 0.16898120753467086, 0.15516545533412887, 19.860966474779193, 70.54723216641334, 55.8254276552508, 59.51566019365865, 43.04255662425872, 45.026177667802386, 44.679067519403276, 46.320363706158055, 41.444014272382184, 42.734250483974336, 42.93632315051171, 45.032924144498764, 42.608346323813166, 45.80800802476945, 40.88464898447837, 40.63482930583339, 37.62340999418689, 40.07859799169725, 39.929312582938906, 41.04513276007868, 39.25406479066418, 42.22066710072179, 43.12649142357611, 44.12165949421544, 39.90491936283727, 38.58629695830807, 39.008649933722715, 39.3437066385823, 38.729549761741396, 40.942735364360196, 41.03782930681783, 39.74405903970042, 40.4417977025432, 40.465139727438654, 38.72164618584418, 39.705408004022416, 39.845377783621515, 38.849691960119436, 37.576157200721006, 37.87663821251162, 37.08494701693135, 39.20613734952865, 41.151111279764486, 41.5983909176242, 39.22233281597015, 41.539406314972915, 45.045099181513635, 47.10281771998252, 50.084117151075795, 48.9744629398469, 52.420684829834975, 46.708050773989775, 40.57070639825637, 46.8269064349513, 40.23555555651265, 41.226538458178126, 39.185937143141224, 39.11640920946675, 39.25140150131718, 40.774104825911984, 37.86003089720203, 43.19795700811571, 54.074638505135816, 45.27862141209264, 40.1660668465399, 40.13659807943529, 40.41949118337324, 41.19928583022087, 39.88970841130903, 41.38887751486994, 39.59115720564319, 40.84385633468628, 41.24430679505871, 41.42641851978917, 48.97498461507982, 60.01434249262656, 53.92003828479398, 54.21578107341644, 49.92240567361155, 48.48550419653616, 42.398934902683386, 40.49422410226638, 39.69862622599448, 39.48590040206909, 37.6135766121649, 38.62006464312154, 36.464251549013206, 36.955489189394065, 37.1568872082618, 39.96743409864364, 38.545421938742365, 39.63270295050837, 40.35527413891208, 39.86790003315095, 40.20719289779663, 41.85579253781227, 39.5735026174976, 41.105686310798895, 39.79420261998331, 39.2386616429975, 40.37010462053361, 39.882193150058875, 39.46969316851708, 41.409352287169426, 40.80420509461434, 40.15100886744838, 39.95216038919265, 41.56478404998779, 40.199603111513206, 43.86247319559897, 40.32231446235411, 41.43213341313024, 39.651408733860144, 41.12751430080783, 39.56978813294442, 41.841628859120036, 41.03985324982674, 44.31468325276529, 42.199635351857836, 52.18466797182637, 55.83114254859186, 55.71163577418174, 53.43493523136262, 53.494935727888546, 45.07521906206685, 54.36953013943088, 56.25328763838738, 74.30101886872323, 27.068964935118153, 0.4865175275312316, 0.580232052072402, 0.6718504681221901, 3.4097624786438483, 61.85855465550577, 61.09890137949298, 64.7162131340273, 69.24163987559658, 69.26077319729713, 58.02105280660815, 27.72310253112547, 41.01835866128245, 47.55445511110368, 60.167044285805, 3.3710329955623997, 0.3086099401116371, 0.056222572231725346, 0.05371615470897767, 0.05471649316830501, 0.047880790211380496, 0.07207220360156029, 0.02210023084415063, 0.09371426407127612, 0.026737617689274976, 0.020370318126233838, 0.05731294134391412, 0.03539762497248669, 0.14779964251624, 0.06700407232969038, 0.11146816785537428, 16.64287159519811, 76.83756859071794, 56.10783046291721, 45.97124530423073, 31.18461185886014, 52.537210602914136, 68.51567191462364, 65.62299451520367, 61.6516496289161, 71.63087321865943, 57.07634995060583, 66.22208949058287, 2.986306581766375, 0.1995046478846381, 1.1566591599295217, 0.3936620939883494, 0.08153450029391436, 22.73832505749118, 71.65644707218294, 59.32720991872973, 63.60492721680672, 46.92791923399895, 47.5772205475838, 46.644814322071696, 49.08824305380545, 43.20511533368019, 45.639879549703295, 44.51903089400261, 49.12022213782034, 45.08580553916193, 49.67108372719058, 44.31746421321746, 43.352565073197894, 39.47531000260384, 42.55096989293253, 42.2109317779541, 43.5370929779545, 43.010961932520715, 44.34186135568927, 45.927789365091634, 47.33753235109391, 41.451584446814756, 41.549588787940245, 41.8593579722989, 42.39222372731855, 39.90124017961564, 42.741930484771736, 41.98664280676073, 41.49544046771142, 42.31642392373855, 41.794583951273275, 40.33819613918182, 41.47653856585103, 41.78525263263334, 41.26564448879611, 39.46874787730556, 40.09125548024332, 40.069925631246264, 39.9605268047702, 42.217109510975504, 41.153766724371145, 40.97080384531329, 45.0750425554091, 48.83961577569285, 50.65328836441041, 52.9445565900495, 50.97302036900675, 54.784234493009514, 49.953502224337676, 44.36679586287468, 46.72552885547761, 38.46531537271316, 41.46217484628001, 39.33059415509624, 40.74120006253643, 38.7860946501455, 40.37886327312839, 36.99092388153076, 45.66133099217569, 53.748293384428955, 47.82556933741416, 38.4477823780429, 42.153606337885705, 41.05256957392539, 41.2298293267527, 40.15379375027072, 40.139688907131074, 39.74635362625122, 41.269543324747396, 38.9295357273471, 41.4185659347042, 49.255104603305945, 61.43251465212915, 55.900666559896166, 58.57613094391362, 53.04069388297297, 49.315630697434955, 44.426211926244925, 42.93100833892823, 39.82485986525013, 40.590934061235004, 39.19931242542882, 39.727926331181685, 38.54978361437398, 38.0905407474887, 39.271899807837706, 40.67877946361419, 39.66792583465576, 42.64904483672112, 43.18786474966234, 41.543152178487475, 42.0194887345837, 43.3994609309781, 42.027992433117284, 43.56503986543225, 42.88995289033459, 42.28884181668682, 43.09737959215718, 41.568286726551676, 42.59569275763727, 43.03461382465978, 43.11681885873118, 41.87127021051223, 41.290477014357045, 44.00057200462588, 41.30997511648363, 45.74746624115975, 42.46221842304353, 44.34162601347893, 44.29605199444679, 41.99473465642622, 42.22460908274497, 45.04886857924923, 44.67166600688812, 46.186022527756236, 44.977014680062574, 53.97336682965679, 57.87446206615817, 58.04354759954638, 55.56955575942994, 55.18264532089234, 46.881501905379764, 58.082053507528, 60.63344155588458, 75.30199989195793, 28.421988487243656, 0.5189590528607368, 2.058490755096559, 0.9724530121011119, 3.5970836012594165, 67.40019690605902, 69.78949300704464, 69.9824030168595, 75.54820706767421, 73.74459928081882, 67.66795358350201, 28.884977217643495, 43.416068246287686, 55.048943488828606, 68.3949492054601, 6.120595855097617, 0.5932125845743764, 0.13128715356992138, 0.1383628029256098, 0.07689692575724856, 0.04064568348469273, 0.019588255353512305, 0.18433861975227633, 0.19013502484848424, 0.17649032475967563, 0.169651273998522, 0.1470429468299112, 0.2100588113910729, 0.2698861873678623, 0.16765978247407945, 0.24104757354624812, 19.657297403581683, 87.84399817066809, 64.28780794143677, 54.42131719281597, 29.092774583447365, 60.446269973631836, 76.12411299059468, 74.45226546256774, 68.45549491143996, 75.5666265180034, 63.73869572916339, 74.21791168951219, 4.422875392821528, 1.0864682231218585, 4.374444907711399, 0.5178434449818827, 0.2658943176990555, 26.13407781047206, 72.77611901683193, 61.92938481607745, 65.707702021445, 51.33437264350153, 50.26937853905463, 49.71459850188225, 51.43092963003343, 45.50628362163421, 47.0935256250443, 47.27519019957512, 49.4964833413401, 47.76904798323109, 53.07532841159452, 46.654157407822154, 44.35533861960135, 41.75481896246634, 43.287171317685036, 44.28697955223822, 45.123879986424605, 45.818943592809866, 46.78730226332142, 47.17315758428266, 49.9360437547007, 44.49368453794911, 44.02596542912145, 44.63880831195463, 44.694862904087195, 43.42112810380998, 46.36734585608206, 45.57868273027482, 45.00092152626284, 45.136984625170314, 44.57461087934433, 40.78384799342002, 43.27577290996429, 43.93307193633049, 43.514480513911096, 42.92118672401675, 43.42691359981414, 42.8603546850143, 42.180882500063994, 46.705363950421734, 43.48851834574054, 43.50256043095743, 47.57749119112569, 50.54572128480481, 53.232972391190074, 55.4088915548017, 55.2558445930481, 58.18690238460418, 53.020548589767955, 48.064543662532685, 48.00799877412858, 40.46145269947667, 42.46772935313564, 40.90478643294304, 39.35051979557161, 39.74581233916744, 41.17897187509845, 36.964796973812966, 44.8585355666376, 56.31261348724366, 47.228419857640425, 38.86743676277899, 40.58845904565627, 41.71928621107533, 41.42213921393118, 40.55457368973763, 42.478092255130896, 40.4427900621968, 41.82199347403742, 40.160791258658136, 42.67234371554467, 50.86277431057346, 60.18016069166122, 57.833183042464725, 59.79670978361561, 55.04231860560756, 52.08896998436221, 46.62301771102413, 44.788607551205544, 44.32599144597208, 43.310509420210316, 42.11251558796052, 43.1000977946866, 39.70481180375622, 41.783209077773556, 41.53584872522662, 42.91346357714745, 43.55453183574062, 45.13512149933846, 44.617188207564816, 43.21827880797848, 44.12392270180487, 46.77324841099401, 43.83202383595128, 46.43780339148737, 45.65060723212458, 44.01291178118798, 47.130901890416304, 45.14409980466289, 44.18957925611927, 45.35420940768334, 44.87813172801849, 43.939253591722064, 44.4034896358367, 47.76722015873079, 43.51921873707926, 49.329594335248395, 45.41608087478146, 45.16758303488455, 46.58478636895457, 45.55070054146552, 45.582754150513686, 48.42069879654915, 47.170910066173924, 49.679665873127604, 48.342019973262666, 58.20319591029998, 61.64543659456315, 60.0948569851537, 59.40730471764842, 58.221536913225734, 49.84301690132388, 60.023744413929606, 64.12046394040509, 79.38265339020761, 31.27874678181064, 0.588025801604794, 3.860076314979984, 1.522585530915568, 4.595983316821437, 73.9555835723877, 75.51905601255356, 74.32499239521643, 80.87798641573998, 78.01238121524935, 75.6231164932251, 40.71711670967841, 54.75662492936658, 62.106515130689075, 82.6471479477421, 10.07762703203386, 0.8083673975160046, 0.2657826833667294, 0.23882889098698096, 0.16169497593035623, 0.11157525928630946, 0.17079525777409155], [0.028166003945854404, 0.05958561011920533, 0.068512920800957, 0.11274146727256237, 0.053425186854456706, 0.029458643252690955, 0.05919847907798906, 0.047293572326100645, 0.2977175487866325, 8.022918912672228, 62.05129992577338, 51.85825617082658, 44.58158877588088, 37.24066119040213, 51.915220752839126, 57.037138015993186, 71.65428192384782, 58.68990713550199, 65.0028403343693, 51.113884449005134, 66.9851238496842, 11.284976697737171, 0.1539541171082566, 0.46605819956429545, 1.3720975479772015, 0.029066929090467673, 10.360397561903923, 72.1228482646327, 54.56808443992369, 55.17974276696482, 41.57068721709713, 53.16895930997787, 49.28303580130301, 49.40253473097279, 41.16177620426301, 42.68185546321254, 40.869963630553215, 45.78077893103323, 43.55289228500859, 48.78088612710276, 44.08237303456953, 42.51005957203527, 38.45503091812134, 41.420746772520005, 40.772441740958925, 41.29103399092152, 39.05783645568356, 39.08712087139007, 38.304972802439046, 39.42774341952416, 39.636468425873794, 41.105631397616484, 37.869150407852665, 40.239132758109804, 40.32917468778549, 40.83872195213072, 40.70602032446092, 41.03708797885526, 40.82610368728638, 38.34349047753119, 40.4829433656508, 40.860444038145005, 39.68858888072353, 38.54432367509411, 38.66437565895819, 42.637603282928474, 42.52712972702519, 42.491467537418494, 39.50894824920162, 39.78902901372602, 41.840134436084384, 44.081812135634884, 47.14357114607289, 49.51081960431991, 49.70838154515913, 51.26550759038618, 47.937658909828436, 47.46912787037511, 51.232798945519235, 44.18518620152628, 38.429766931841456, 39.57194543653919, 39.94551197175057, 40.474663242217034, 38.876344465440326, 40.485461527301425, 39.62804317474365, 44.01783435575424, 53.45631999354209, 45.81708046697801, 39.80272593036775, 41.02364993864491, 41.40433165334886, 41.548149278087, 38.50644534634006, 39.23270356270575, 41.003265380859375, 42.42816832757766, 40.786366155070645, 42.05135014749343, 47.734205568990404, 54.817253005120065, 52.10943298955118, 54.32586631467266, 52.46959678588375, 51.43105514587895, 44.36895708883963, 40.50258659547375, 38.09764415987077, 39.35257903991207, 36.94935068007439, 38.15882921218872, 36.62493144312213, 36.97434402281238, 37.288788672416445, 38.768436139629735, 38.78731058489892, 40.24163915264992, 40.55151031863305, 42.721714588903616, 39.6625090414478, 40.7051456359125, 40.76138065707299, 39.771856877111624, 38.771448519922075, 39.16116737550305, 40.93466704891574, 41.55358960551601, 39.88826105671544, 40.53030990785168, 40.695743714609456, 41.10898894648398, 38.854830265045166, 41.72729176859702, 39.067975782579, 39.84451486218361, 40.40232296912901, 40.52095113262054, 40.57553875830866, 42.41654634475708, 41.445332188760084, 40.155856916981364, 41.40700278743621, 42.7235581028846, 46.04631162458851, 56.08803033828736, 55.47282226624028, 61.73046573515862, 59.4331649041945, 60.5692558903848, 54.494543921562936, 56.09830694813883, 56.407111229435095, 72.27981367418843, 23.03194976622059, 0.5318550092558707, 0.5016037905889174, 0.6196219642316142, 8.24450929318705, 64.6874386264432, 58.11384039540445, 66.8150734132336, 63.7976489528533, 67.82778232328354, 51.63975661800754, 40.7114214281882, 42.273344532136, 52.98144255914996, 56.061707312060946, 2.624902335866805, 0.3322784716804182, 0.03438870249796779, 0.048292727179584966, 0.1287401104045491, 0.03943693846644413, 0.06416178653917967, 0.044942869834842226, 0.0650280021551636, 0.006510949667332875, 0.08806005255469392, 0.04582398586095341, 0.01946273184711895, 0.08852050204070346, 0.09164696814672602, 0.3007637595217074, 10.192258300319796, 73.69001557750087, 58.28911542892457, 47.38380455201673, 28.711475095441266, 55.514560207243896, 64.04795892776983, 74.97143822331583, 62.43488811677503, 70.37335349667457, 56.070442430434696, 74.84853467633648, 12.243852057764608, 0.31154001191739117, 0.7046709005390445, 1.971496997341033, 0.0816521637382046, 12.71578477274987, 74.59462396560177, 55.41870924734301, 58.797595808582926, 44.49786578455279, 55.06267178443171, 51.80434711517827, 50.76617025559949, 44.372765710276944, 45.37724156533518, 44.03818753457839, 47.40772708769768, 47.02025575022544, 50.43093704408216, 46.251867355838904, 45.55816088953326, 42.078194848952755, 43.805720421575735, 41.46319074015464, 42.085325717926025, 41.15675557044245, 41.54817281230804, 42.4768449414161, 42.09391178623323, 41.296870477737926, 42.832341117243615, 40.21266852655719, 43.21262667256017, 43.833851660451586, 42.794635372777144, 40.574177695858864, 42.858067943203835, 40.43631815141247, 41.042359644366854, 40.93982104332217, 42.50520367776194, 40.11242058969314, 41.63643006355532, 40.218591305517386, 45.24539109199278, 43.774310081235825, 45.058580367795884, 41.99538576987482, 42.49097331877678, 42.7369333851722, 45.968770288651996, 48.41309332078504, 49.44011888196392, 52.0053489746586, 52.86742710298108, 52.62954711914063, 49.591467457432906, 52.08950342670564, 44.84942782309748, 39.08303768404069, 40.80859422683716, 39.839051000533566, 41.10965182704311, 39.06992127818447, 39.896862814503336, 39.15314220613049, 43.970401133260424, 55.87466909039406, 46.81488829274332, 39.20879279413531, 41.941770891989435, 41.7119082327812, 40.7144534203314, 40.68682424483761, 39.783474937562026, 39.441483482237786, 42.7459587589387, 40.39150114982359, 41.572675858774495, 49.51716207688855, 56.36176470787295, 53.946580963750044, 56.08175062364148, 54.83950853347779, 52.276333762753396, 45.66422570136286, 41.21383782356016, 41.52781178874355, 40.78143965813422, 38.572250950721006, 39.87138309786397, 38.393739961808734, 38.45137134675057, 38.17380482150663, 40.44035034794962, 39.90420156909574, 42.514605599064986, 41.769586686165106, 43.1741560659101, 41.72875089030112, 42.896232604980476, 42.64334955523091, 41.79952221532022, 41.692727842638575, 42.78875573988884, 44.32081783971479, 43.88666637482182, 42.7796793753101, 44.260460407503196, 41.85700062782534, 42.7349212092738, 41.63117800989459, 43.18900223701231, 41.47141987277616, 41.060649656480365, 42.7870612759744, 42.51229532303349, 41.90777570970597, 45.214678933543546, 43.20030650784893, 42.78686515746578, 44.44632976285873, 44.16275024414063, 49.288229019411155, 57.17907290304861, 59.22371818173317, 64.81340162215695, 60.64702864616149, 63.85860650770126, 56.630643183185214, 58.87510184318789, 58.66132090168615, 74.55339985509073, 25.32666575524115, 0.35840439880567215, 0.8244422510746987, 1.2711298561865285, 9.488000658250625, 69.79667094445998, 63.743802655127745, 71.32150019368818, 71.37700173162645, 70.43534263487786, 61.26858703551754, 37.342274112086145, 44.74415533004269, 60.3611937645943, 66.63499739862257, 3.74129910142191, 0.36927619768727216, 0.08775886508726305, 0.04121055458522132, 0.03352680378743718, 0.013539682840928437, 0.009559091901586903, 0.2117813141235421, 0.18619134211011473, 0.14144241509418334, 0.1715424233266423, 0.19564764033402168, 0.1529220894219414, 0.27590739330457104, 0.3013758944167245, 0.3937792135102134, 10.607710846008795, 87.08881639665174, 66.06077025013586, 60.63980364030408, 49.92953262021465, 69.56310949017926, 67.34677422431209, 84.04974829766059, 67.739929076164, 77.60944397218766, 58.94896399590277, 82.16341772387105, 13.641518066006324, 0.5853066797698698, 3.0470310007372214, 4.4350577842804695, 0.15197060821998506, 16.09297981185298, 76.08877243534212, 58.54568158426593, 59.62551401507471, 46.918568303508145, 58.86121273040772, 53.88050079345704, 53.09452056884766, 45.62591591188985, 48.16607813681326, 47.71802186965943, 50.094844833497085, 47.78591809734222, 53.99014280688379, 49.38345240008447, 48.48140531970609, 44.87944179965604, 45.995265899165986, 45.52435790338824, 44.358841296165224, 43.59487733533306, 41.95351054591518, 43.88428157375705, 43.75146619735226, 44.68285260661956, 46.69073743204917, 42.526321718769694, 46.07681981978878, 45.44452590327109, 45.98705245602516, 44.48701650865617, 45.803646349137836, 46.09197585813461, 41.95862923899005, 43.66351096860824, 44.97687347473637, 44.26551634265531, 42.055068554416785, 42.12628310726535, 46.51196756670552, 45.90550638014271, 46.68775250834804, 44.27146657820671, 44.53310043581071, 46.615980978935, 48.83130819566789, 50.85094444213375, 52.74633176865117, 53.697235891895915, 55.821775928620376, 55.370511162665586, 53.67980095647997, 54.801818478492, 44.23228602255545, 38.59743648959745, 39.73053862971645, 41.409477803014944, 40.18894210938485, 38.359030908153905, 41.8949770158337, 40.92210369725382, 44.922956574347715, 58.90815565663, 47.45275981964604, 40.42394307351882, 42.290991275541245, 40.56148490598125, 40.94326488433346, 40.6907779939713, 39.58093550897414, 40.86998716477425, 42.77148946639031, 40.55529932821951, 42.54877336563603, 48.33864673491448, 59.77796477656211, 57.11149046497961, 57.95764769277265, 59.24364382220853, 54.93918772666685, 49.582073380870206, 44.05146083524151, 43.249885266827, 43.18565645525533, 40.37641571414086, 41.16754208841632, 41.604552961164906, 40.30133762667256, 39.994247421141594, 43.03821848284814, 41.87198015951341, 44.62220099664504, 44.90729847261983, 45.3098120997029, 44.403838726782034, 45.750145219987445, 45.44940925413563, 44.34166523718065, 43.733321312935125, 44.86058304386754, 47.17563652223157, 47.905154228210456, 44.3794455066804, 46.085762823781664, 45.35450750781644, 45.16968934766708, 42.22011012415732, 46.95271645822833, 43.856048353256725, 43.72946562305574, 45.55375606782975, 44.53146480744885, 44.52387894353559, 48.80261998022757, 46.25544455743606, 44.31183561202019, 48.09737782324515, 48.10537945839667, 51.10708698149651, 60.551460096913004, 63.09374432409964, 67.3319241308397, 65.10047205032842, 66.44524881916662, 60.8600329583691, 62.07074703708772, 61.997159450284904, 76.92315470787787, 27.218317024169433, 0.6011914822363085, 0.8776467509808079, 1.5533841040826615, 10.423578120047047, 76.59884529729044, 70.86966668405842, 76.48846195590112, 77.96899980114353, 76.48976418279833, 69.20250246601721, 56.740265584761104, 55.76401118309268, 68.37369780386648, 78.69523448328819, 6.496871277209252, 0.6050615745686716, 0.2691023874907725, 0.24083461642505663, 0.21053622206372602, 0.1316099370559377, 0.11862715991634516], [0.05624860006895277, 0.05305641511034581, 0.009936723452542099, 0.07039066359040237, 0.08006148941574559, 0.01606800664787091, 0.08165135168500486, 0.06774527005731099, 0.04107891003631296, 2.8277393742915127, 54.071112294350904, 50.525717196925996, 48.49423931490991, 22.52082178669591, 30.909016324627785, 57.02697123250654, 66.88948862014279, 57.93128544284452, 63.25587157280215, 54.543589238197576, 65.6008723474318, 22.292494735410138, 0.21993204530689026, 0.8255942021646808, 0.2873278643575407, 0.06496669213858343, 7.265047373310213, 65.67201629761728, 56.81215478527931, 51.11340984221428, 41.70355750668434, 59.03677017458024, 53.92411754977319, 51.41174923989081, 42.067012171591486, 44.42714545034593, 40.7905944701164, 47.14410458841632, 44.95325688392886, 48.13251049287858, 46.26912186222692, 47.24764731622512, 39.29924265030892, 40.037405260147594, 40.073718563202895, 38.69144393551735, 39.14524255260345, 41.776662641955966, 40.469662220247336, 40.838816089014855, 38.78338429235643, 40.2451967423962, 41.008203644906324, 42.39668346220448, 38.66309696628202, 38.9371019794095, 38.44493865966797, 39.54291205252371, 38.48544105406731, 41.4748284124559, 40.891838689004224, 41.44872503895914, 39.602916471419796, 39.16488970479658, 37.42396923803514, 37.694091104692035, 36.37132275489069, 37.583864658109604, 40.59005152794623, 40.898632234142674, 41.08654906672817, 43.63732130296769, 49.29796041980867, 51.98381908478276, 49.41504709182247, 49.315991555490804, 51.29047347653297, 53.78099810692572, 53.469891394338305, 46.32823198072372, 36.206473381288596, 40.05285939862652, 39.325636279198434, 40.23375911097373, 40.49297678855158, 39.2503228495198, 39.2458591922637, 44.0806628811744, 54.57807863912275, 46.475289483224195, 39.93324672022174, 40.818062828433135, 40.98301810602988, 42.34156631654309, 40.13715897836993, 40.18061099513885, 42.07188767771567, 40.68881680888515, 41.247793782141905, 42.47717442051057, 48.677186504487075, 55.919744968414314, 51.83081526910105, 51.27026934777537, 47.82699315778671, 50.79090472190611, 49.176394401058076, 42.68573076494279, 38.99371747047671, 37.95958065217541, 39.040723154621745, 39.177088276032485, 38.65953545416556, 39.17737068668489, 38.84671095878848, 39.150420081230905, 37.01976899177798, 40.171868032024754, 39.874760258582334, 39.37349311767086, 39.70834585928148, 40.012141273867705, 39.4892148048647, 40.699560180787124, 38.90876677728469, 43.14413032224102, 42.793811675040956, 40.658289001834014, 40.77223385533979, 41.260290453510905, 41.573142620825, 40.04810940834784, 41.296945002771196, 41.78131457298033, 40.336701716146166, 38.395308909877656, 39.18490948215608, 41.513628498200454, 40.69657525708599, 41.56942421390165, 39.60782727887554, 40.28942931082941, 40.20241152855658, 41.467113110326956, 46.873319841200306, 55.63953476567423, 56.94809629071144, 55.892751216888435, 61.32967010621102, 63.595270341442486, 54.830640054518184, 61.54107801375851, 54.96569902666154, 73.79580974578857, 12.136198686015222, 0.4497620078825182, 4.527133462890502, 1.809611832422595, 15.244629979133608, 63.2294818662828, 57.97704773564493, 65.78779289799353, 65.39235130433114, 67.98925845853745, 47.007833603889715, 28.03797079670814, 41.164533630494155, 58.663941044961255, 45.728289773387296, 0.6585994759394277, 0.028628054555625688, 0.06297893146233213, 0.031621096873535745, 0.024652854960051276, 0.07909879268657777, 0.02960319446790363, 0.025052480895312566, 0.007251474195190015, 0.1781753657926475, 0.059978663020076296, 0.1388118683450645, 0.02635301473820883, 0.12401966047623467, 0.08405980954487478, 0.07500481115834368, 3.795395205097814, 66.07449070099862, 56.83203727968278, 58.21846569738081, 31.604111309974428, 44.42285045500725, 61.47125982469129, 74.92280867791946, 61.462312898328236, 70.18736254784369, 57.80664428587883, 72.1315323921942, 24.20168488256393, 0.13827821149701072, 0.5603392001601958, 2.897616153763187, 0.04194255159687131, 8.856055832678273, 71.92545890808105, 57.61719380655597, 54.515756099454826, 43.51958743987545, 60.43799377256825, 56.57440031728437, 53.775342049137244, 44.57371265657487, 46.69837428677467, 44.357860703622144, 48.98040140828779, 47.6637754901763, 49.76191797564107, 47.320379826330374, 47.76471376419068, 43.164177556191724, 41.33786709077897, 42.35014846248012, 40.74494200368082, 41.15254686724755, 42.33743606075164, 42.01849637493011, 42.451553498545, 41.36014223098755, 42.97299731162287, 42.83080354813607, 44.166315678627264, 39.99232545975716, 42.04470565242153, 41.13858322943411, 42.36927001707016, 40.25261786676223, 43.88837652821695, 42.38180983451105, 43.49966964414043, 41.854164754190755, 39.723933358346265, 40.22349819060295, 39.68692579577046, 38.41546989256336, 39.93017158200664, 43.233493681876894, 41.98036309211485, 43.736796532907796, 44.47037389201503, 51.24758628106887, 52.616587608091294, 50.247436800310695, 51.079904956202355, 52.8048849105835, 55.07671779201877, 57.411708677968676, 46.95356761255572, 35.85942599081224, 38.82921326544977, 39.033000007752456, 40.88907734040291, 39.60776844332295, 39.25083668001237, 39.412265746824204, 44.77584415866483, 54.683900264001664, 46.56804177068895, 39.75100947964577, 42.32424512986214, 42.35660860615392, 42.116971400476274, 39.966167173077984, 41.310175157362416, 41.00170035516062, 41.13263691625288, 41.56696096543343, 41.84081300612419, 48.86239297928349, 57.727377107066495, 54.3971279359633, 54.76992176425073, 51.08143075819939, 52.93185987780171, 50.959688232791045, 45.49964697130265, 41.24016477215675, 40.30535021135884, 41.11135805806806, 41.490415911520685, 39.915729415032175, 40.90636322575231, 38.65742914138302, 41.685922530389604, 38.74172087638609, 40.730758713137725, 40.221619375290416, 41.08800426606209, 41.963022293583045, 42.09693593363608, 41.11617865100984, 42.66982555389405, 41.73228494582638, 43.10926045140913, 43.50028545625749, 42.65495977094097, 44.168669100730654, 43.328638615146765, 43.85981775099232, 42.6795804885126, 42.17402619700278, 43.123063272045506, 42.72421706107355, 41.686416749031316, 41.81477239055019, 44.16351118395406, 42.875291070630475, 44.153936678363436, 42.745323334970784, 42.88559905944332, 41.1721077272969, 44.77089412750737, 51.36919152352118, 59.0476429846979, 59.46426929966096, 59.15716340464931, 63.22966229531073, 64.01988652444655, 59.65065640787925, 62.77750322895666, 60.19941560683712, 74.83274321402274, 13.430958371008597, 0.7094017079760953, 1.3246465522435404, 1.8041657440124022, 17.707512686329505, 70.02616882324219, 64.95066888870733, 71.790725492662, 71.83460112540953, 70.98045795194565, 58.129008200860795, 32.70634243565221, 46.889385869426114, 66.32329448576897, 56.175342298323116, 1.4712968636904995, 0.10548672954281492, 0.03748080189970713, 0.0166155181960353, 0.013942554116158957, 0.05128072289329383, 0.057025198719554374, 0.1543863898804111, 0.11302057608601548, 0.3490173089648447, 0.17241777071068365, 0.18848456502441438, 0.07100416212192467, 0.2456653523709505, 0.2544242960791434, 0.22432611113594425, 4.186607993418171, 75.98705753203362, 66.0268731271067, 64.72871372776648, 32.558700499996064, 44.69243495695053, 68.50607779718214, 80.01748900259696, 66.17178901549309, 74.1448300884616, 61.80258635551699, 79.30583769275297, 28.170968563325946, 0.4210854676221648, 2.864534883729873, 3.4747801769164304, 0.1279308610866147, 12.739945592418795, 75.54301384956607, 60.79631013254966, 56.80953856437438, 45.49152766504596, 65.82320797827937, 57.37758405746953, 56.31151130122524, 45.667567560749674, 51.00759213970554, 45.914610201312655, 52.86793701110348, 49.59647240177278, 54.65534148677703, 49.75672475753292, 52.430169120911636, 45.40905590980284, 42.7493594538781, 45.59111664372106, 43.992739031391764, 43.5884250363996, 45.26121785563808, 45.34851020382297, 45.32136740223054, 44.07352416746078, 45.66926594703428, 45.12105980227071, 47.894606974817094, 41.5903579035113, 43.38242215494956, 42.24493088260774, 44.47684972516952, 42.22217721323813, 47.11293351265692, 45.45313550579933, 45.87910490651285, 43.25136792275214, 43.14721330519646, 41.490823838018606, 42.13572032989995, 40.403452611738636, 42.80568468955256, 45.331757760817005, 44.6496928891828, 45.3177313650808, 47.36934277319139, 55.887495240857525, 54.696683268393244, 52.433648263254476, 52.088836623776345, 57.190337950183505, 58.31132388884022, 59.464245765439934, 48.027853811940844, 36.16835186558385, 39.482703670378655, 39.9598325452497, 41.7354699104063, 39.61524840324156, 39.448865382902085, 37.80564723476287, 45.32866301075105, 58.47368647975307, 48.448849647275864, 40.30469517554007, 43.58651876449586, 42.40305339136432, 43.80246093196254, 40.83151655812418, 40.81730581098988, 42.38964280774517, 41.540226090338926, 40.990498065948486, 42.609401441389515, 51.964536713015654, 60.247668604696955, 56.803698155187796, 59.53852761176325, 52.546949848052, 55.2542011199459, 53.218906771752145, 47.591458751309304, 43.3788880994243, 43.18595063301825, 42.87235321537141, 43.79929557923348, 41.569894898322325, 42.160239065847094, 41.31694124590966, 43.144138166981364, 40.044610654154134, 43.69715705994637, 42.75998123230473, 42.69677223697786, 45.393189922455825, 44.63415638093026, 44.525675389074514, 46.49685467443159, 42.61962706042875, 48.63589179131293, 46.67976264030703, 46.23209076543009, 46.8689150194968, 45.307223335389175, 46.471261209057225, 46.13898938701999, 45.307725398771225, 45.7130592100082, 44.24115057914488, 43.88194776350453, 43.593567263695505, 47.27593937227803, 45.03519127445836, 47.27804176269039, 44.53375939399966, 46.1397817057948, 43.52969931017968, 47.23835914365707, 51.461461359454745, 62.58885683551912, 60.931094538780954, 61.83609908626926, 64.5990833159416, 67.18002642354658, 62.42875352982552, 67.35497197797223, 61.20181652807421, 80.00043453708773, 13.567327414789508, 0.6087000631997662, 10.17145699070346, 2.893209125726454, 20.136183500289917, 76.4560317993164, 70.92227351280951, 76.70177613535236, 77.24989598797214, 78.10989133773312, 63.00601659282562, 41.25484620371173, 56.026139259338386, 73.52027108592372, 68.51640932021603, 2.378644414486424, 0.30345600699224784, 0.14781459655252197, 0.11037190369660817, 0.09688092681068568, 0.222012234491206, 0.10842553475090574], [0.02572756140462814, 0.05663605286709725, 0.07428433610907487, 0.08446428098625715, 0.010357190809783437, 0.07551448179348823, 0.020823537657457977, 0.05911174643364164, 0.0639413868738038, 0.7672559938603832, 42.766951284100934, 56.69669981925719, 46.72109265481272, 24.67235165257608, 27.479976377179547, 54.7021588971538, 64.50037687055527, 61.70926532437725, 61.64054932132844, 56.70044568277175, 62.851949814827215, 36.942619892858694, 0.07270993349412758, 0.5915741370089593, 2.001558287489799, 0.18749407462535367, 3.1950163889315824, 58.49108611383746, 55.150156328755045, 49.56453254145961, 48.509477723029356, 62.352565411598455, 55.98564863204957, 54.3159427181367, 41.084772233040106, 42.161415776898785, 42.5663181274168, 45.35147551567324, 45.264740144052816, 48.09374963083575, 47.06801060707339, 46.409217157671534, 37.7704910309084, 39.29270798160184, 41.28684097720731, 42.3828649520874, 38.97789070683141, 39.29959566362443, 37.72497976979902, 38.641284665753766, 37.80084233130179, 37.826341659792014, 38.901612374090384, 41.70677777259581, 39.29771292594172, 37.8411917532644, 37.615361290593306, 39.144360019314675, 39.45394877464541, 38.3145433856595, 40.1179511316361, 41.13250355566702, 38.951834401776715, 40.073757786904615, 38.34982510535948, 40.51380457416658, 38.64662301155829, 40.503684859122004, 34.95115803134057, 38.38998233118365, 39.93158755763885, 46.44590308589321, 48.21416247275568, 47.78488259161673, 50.380099204278764, 48.93030489644697, 52.13299858954645, 53.168182680683756, 50.66181167479485, 46.373080361273985, 40.27369276169808, 39.77421814395536, 40.633864402770996, 40.96485753213206, 40.59252654352496, 43.90168513021162, 39.12924712704074, 44.116054427239206, 54.42691833742204, 44.91328793187296, 40.538927355120265, 40.27289259818293, 41.60633763959331, 41.828383015048125, 40.90241339898879, 41.78842583010274, 40.2778269398597, 41.518464780622914, 41.3731841118105, 40.864437010980424, 49.961295973870065, 54.37079314262637, 50.650083787979625, 52.29027778871598, 48.9046839744814, 49.857325707712484, 48.607446762823294, 44.52150590958134, 40.45221551772087, 37.97865513832339, 35.841661576301824, 38.048179149627686, 35.33229866335469, 38.55550243008522, 37.89317492515811, 39.56700717249225, 36.941694213498025, 39.134169701607, 38.302764508032034, 39.18407793967955, 36.67909153046147, 39.27210377108666, 38.971532544782086, 40.60570570730394, 37.42288274149741, 40.47797764501264, 41.62935410776446, 41.534738694467855, 39.49709876891106, 40.835376170373735, 38.82280411258821, 40.23030350285192, 39.97084263832339, 40.698952213410415, 39.110486430506555, 41.502783144674, 38.64293598359631, 40.08885106732769, 39.940173625946045, 41.35920478451637, 40.75702682618172, 41.36300163884317, 39.175401656858384, 43.646942877000384, 49.805244476564475, 57.678665191896506, 55.55735718819403, 55.16287657522387, 51.77834180093581, 65.61421625075802, 63.00659318124095, 59.63026400535338, 63.96452226946431, 63.882128961624645, 2.6834993593154417, 0.3563332647806214, 0.7445140916012949, 0.5667744000111857, 16.855785692891768, 67.26610675934823, 55.889793749778505, 69.04242269454464, 60.18966067221857, 66.74984439726799, 42.17131976158389, 31.49938402637359, 40.05775843897174, 56.81342171084497, 33.23631348148469, 0.3729923982774058, 0.017853382216285796, 0.0980269483801338, 0.06905576304322289, 0.021564760282936118, 0.04470469309918342, 0.06912372270298582, 0.05221824597326979, 0.03742316910516351, 0.008804958779364824, 0.03091077631970327, 0.023578092974099903, 0.05051457368197942, 0.07040350322401331, 0.04349363066496388, 0.10143233943850764, 1.435102334906978, 51.91978246934953, 63.21596930103918, 46.90695024305775, 19.697193791789395, 39.39008866586993, 63.04625226605324, 71.48595733027305, 64.6393346786499, 67.77388895711591, 61.33420828850039, 68.62937358117873, 39.674264384854226, 0.04883875634761588, 0.37268020212650305, 2.514366267188903, 0.22277292915649954, 4.496231559784182, 64.14236253307712, 56.40226710227228, 52.234937067954775, 50.22617363160657, 64.30515266233876, 57.28656937999111, 55.35934809715518, 44.06868004029797, 45.53146523814048, 44.261856771284535, 47.719402543960086, 46.78500767677061, 50.688417111673665, 48.945555071676935, 46.71638581060594, 41.05276569243401, 41.72425585408365, 41.13620235073952, 45.016018729056086, 40.8321088360202, 41.37102680821573, 39.7148177700658, 41.41533390168221, 40.155837305130504, 40.52360265485702, 40.97808376435311, 43.454256442285356, 41.636539889920144, 41.28985727986982, 41.18504370412519, 42.211492676888746, 41.49176520685996, 40.82324427943076, 40.38170699150332, 43.58309453533542, 41.36230737932267, 42.273658321749785, 39.80669929135231, 41.518766803126184, 40.24866019525836, 42.508259204126176, 38.018565254826704, 40.972062926138605, 41.620022789124526, 47.54902655078519, 49.44574356079102, 50.58939295430338, 51.34088770035775, 51.98362296627414, 54.28730157113845, 54.35135387605237, 52.37388703130907, 48.09150603509719, 39.055965485111365, 41.77155963836178, 39.37073176906955, 38.94115771016767, 38.58841111583095, 42.79217212430893, 38.72532929143598, 43.93402114991219, 55.61211739816974, 43.81649517243908, 40.19587293747933, 40.26174129978303, 41.8268415235704, 41.20869951863443, 39.37725074829594, 41.947654447247906, 40.26110587581512, 43.24250728853288, 42.63663053512574, 41.410101459872344, 49.56623877248457, 56.91281457101145, 55.44802111964072, 54.529453016096554, 51.35978960221814, 52.040732675983065, 53.13469348415252, 47.86857028161326, 41.21949388134865, 42.30205628179735, 37.641319536393695, 40.34306380056566, 39.11620132384762, 38.970465660095215, 40.89644355158652, 41.90200590318249, 38.68125754017984, 40.594138637665786, 39.71958737219534, 40.562606703850534, 40.70416504336942, 42.03025956307688, 41.455953967186716, 42.39946442265665, 42.20521296224287, 42.63716789983934, 43.47785734361218, 44.166758906456735, 42.521967887878425, 43.68786888737833, 41.362213242438536, 42.58338043766637, 41.256866224350475, 42.3723530000256, 40.79840783149966, 43.15090817789878, 39.88351106643677, 42.431263077643614, 41.93441252554617, 43.43399740034535, 42.75740423510152, 42.63159028945431, 41.64825993199503, 46.4667740175801, 52.884948330540816, 59.65193117818525, 58.60583505322857, 56.900380657565215, 57.86731550770422, 66.35024116885278, 64.7854115886073, 62.37642518935665, 66.33346126925561, 65.10050735165997, 3.0060991068040175, 1.1196525779462632, 0.5309863268367706, 0.6472064614776643, 19.27888281883732, 72.69729506584906, 61.62010592799033, 74.98651581425821, 65.25478986001784, 72.42590627362652, 52.716615892225704, 30.654338790524392, 45.52367933334843, 64.31682563597157, 40.96817193492767, 0.2640730815549051, 0.05811532268360738, 0.056676372074552124, 0.0723832429596974, 0.052509156371196436, 0.04212762311761899, 0.03566539568466044, 0.21465598245061215, 0.18577318067752546, 0.10469866255598684, 0.16560585478380804, 0.11481856146166403, 0.15107463774902208, 0.1802630473168627, 0.23072803212750345, 0.13656975881707284, 1.5044956822549145, 60.33854599921935, 70.56499265855359, 60.5661258389873, 35.81824894874327, 43.59796424065867, 68.02814483642578, 76.75813274998819, 70.37094516138878, 73.41877583534487, 66.7239018409483, 75.15185156176167, 43.56439659672399, 0.10818097650283769, 1.2172216585566922, 6.143608400898596, 0.5608002625165448, 5.523032565270701, 69.81989922062044, 58.05656594614829, 55.71178482424829, 51.67687792931834, 67.25175088451755, 59.36255831872264, 59.96244169050648, 44.94477671961631, 48.21925763160952, 46.919937210698286, 50.97311058352071, 49.95776976308515, 53.385705563329886, 51.71805889375749, 51.13824236777521, 42.824119829362445, 43.07636745514409, 44.8300983828883, 47.95476828852008, 41.097986698150635, 43.37192196999827, 42.6526024264674, 43.277184963226325, 43.497061267975845, 41.74846472278718, 45.676157551427046, 46.70246924123457, 45.1776203801555, 42.812356641215665, 42.54201512182913, 44.61558003579417, 43.696721676857244, 42.178278046269575, 42.38372395115514, 46.273612976074226, 42.263801405506754, 45.25143546442832, 42.138077674373505, 44.59559163739605, 41.14153285180369, 45.3864630576103, 40.595746809436434, 44.270646802840695, 44.690830707550056, 52.1055341535999, 53.32916459729595, 52.40630934315344, 55.02809216899257, 53.743037408398045, 57.94746521980532, 57.803784878023215, 54.14069121883762, 48.07181181446199, 39.929904860834924, 40.97667563346125, 39.50416687996157, 42.43339292464718, 41.10491360387495, 42.26821014958043, 38.242736554914906, 44.659812604227376, 58.48595565365207, 44.903348645856305, 40.31920794517764, 40.189820720303445, 42.7749333074016, 41.638587367150095, 41.87752639093707, 41.67792481760825, 39.95928733579574, 42.20809198194935, 42.42470879708567, 42.18621692349834, 52.325951745433194, 59.9643087387085, 56.33671645195254, 59.992867515933135, 53.90783186881773, 54.04172197464974, 54.806321359449825, 51.39329056585989, 43.860206065639375, 44.10791943150182, 40.464531760061945, 41.66956624677105, 39.420734144026234, 42.11561818276682, 42.76238564522036, 43.8467994043904, 39.240108997591086, 43.18604084753221, 41.07204414183094, 43.49522952110537, 43.39007469915575, 44.07272792631581, 45.1842805647081, 45.66954051294635, 44.258040305106874, 44.29727185157038, 45.773145998677904, 47.228721880143695, 44.94557296076129, 46.3699895335782, 43.91651953420332, 45.52985706636983, 43.78299813116751, 45.21901707495413, 43.017343628791075, 45.176098500528646, 42.852023570768296, 45.05174367658554, 43.97337428985104, 45.39318207771548, 44.25395319538732, 45.34892989743141, 43.479555729896795, 50.975966069006155, 55.13695363075503, 62.89191092214277, 59.32083214482954, 58.23529266542005, 61.62706029030585, 68.37783982676845, 68.93097246846845, 65.24770998185681, 69.29065381326984, 70.2548037805865, 3.7428928094525493, 0.9626703144561861, 2.7692801240951788, 0.91476469150474, 22.023775116089855, 79.92971420288086, 67.95801285774478, 81.93822660753804, 71.64903379255726, 78.33800069747433, 56.327585174191384, 43.23538426429995, 54.67058381726665, 74.21049056514617, 52.847991758777255, 0.5376111487707784, 0.2552342808414852, 0.27391032466003973, 0.19535030628884995, 0.20032215563039626, 0.14193133240745914, 0.1696084650053132], [0.07152038280882182, 0.06733579606178307, 0.02849916600802493, 0.06909500206670455, 0.016720997011889855, 0.05121251808539514, 0.05201155928173854, 0.03389952854523736, 0.013768517134350636, 0.15857218704637022, 32.270176833675755, 60.142729513106815, 49.11076138096471, 26.153401367125976, 27.182229257399037, 48.220450032141905, 65.09991115139377, 61.27725155122819, 61.04247416219404, 56.089662044279045, 60.168119015232215, 45.50902928075483, 0.33447741981475587, 0.3020606238034464, 1.914687348950294, 0.24133637337194336, 0.9591884754838483, 49.956820549503455, 57.425507576234885, 51.383943557739265, 55.17966824193155, 58.39651384661275, 58.06719949168544, 49.470862419374534, 41.85367445791922, 42.05698659343105, 43.83343196684315, 46.822685964645885, 46.729678723119925, 49.580167108966464, 48.568419179608746, 47.49655308261995, 39.939471521685206, 42.182682867973085, 41.61514728300033, 39.557063964105424, 39.413364010472456, 40.51924490159558, 39.14651732290945, 39.0460850346473, 38.68374432286909, 37.623829687795336, 36.939054458372055, 36.36719249909924, 36.73615417172832, 39.54745023481308, 38.33987797460249, 38.77541795853646, 39.128721529437655, 40.87553731856808, 38.57267456669962, 40.674190290512584, 41.80896728269516, 39.02851673864549, 36.61302312727898, 38.299963935729, 36.77090637145504, 37.06826125421832, 37.74043390827794, 36.24005279233379, 37.868291408784934, 45.475108623504646, 49.111032024506606, 52.44973782570132, 49.33558771687169, 49.78134939747472, 49.60133221841628, 53.61388944810437, 51.76128733542658, 49.521296255050174, 40.074381443762014, 39.750585863667155, 39.442318947084495, 40.227734350389056, 39.927688721687566, 41.08163041453208, 40.25936042108844, 42.51579015485702, 52.60472243832004, 44.67450972526304, 40.64699257573774, 41.87007780997984, 40.65087964457851, 42.53075007469424, 40.76987651086623, 41.931180492524184, 41.44393582497874, 40.44994054302093, 41.369293120599565, 43.702797428254165, 53.302147311549035, 55.000898376587905, 51.31521186520977, 52.1323396313575, 50.7487980781063, 50.27042188952046, 45.51938433800974, 46.79474692190848, 43.299601308761105, 41.60900485131049, 41.24153760171706, 39.37873732659125, 37.7604458408971, 36.25974309059882, 39.06452801919753, 39.520570232022195, 38.50057748056228, 39.99186262007683, 39.927653420356016, 39.132910620781686, 38.35855630136306, 39.63039659684704, 37.21964905338903, 39.51128205945415, 38.932520651048236, 42.06074422405612, 40.354226866076075, 42.2545995250825, 39.7846398815032, 39.3471622467041, 39.91978906816052, 39.95921281076247, 38.268247650515654, 38.74760443164457, 40.223639395929155, 41.29087317374445, 39.55612259526407, 39.032611693105395, 40.862205182352376, 39.13020810773296, 38.60283759332473, 40.6841334988994, 42.24472299698861, 41.25689368094168, 51.776502209324995, 57.159872901055124, 57.90373863712434, 57.53690681149883, 54.098670867181596, 49.460499517379276, 64.95894116740074, 55.38893453536495, 68.65177031486266, 35.554324426958644, 0.02909166606954269, 0.5361161128647867, 0.437579738997644, 0.10465760790412465, 26.547009252732803, 67.53916648126417, 55.894461370283565, 69.9440893050163, 63.74199052010814, 71.05485746937414, 39.46361349474999, 40.570380841532064, 42.50281887669718, 62.11196330285842, 25.63314210984015, 0.42837041219876665, 0.05941199544336527, 0.001096817178486456, 0.06759216738564354, 0.04366211255171126, 0.015937334073016483, 0.04480254934019139, 0.06963363848626614, 0.04706983251737491, 0.048956144000253374, 0.07832682886791807, 0.038749688650451364, 0.0327193547761248, 0.08814249127622574, 0.057676001902549505, 0.08509706961171282, 0.2333047841825793, 40.98833291761337, 66.93607068830921, 57.377105528308505, 32.842533011590284, 33.17411645766228, 56.522836838999105, 69.74533496364471, 68.17604172614314, 67.89487838745117, 62.78341031843617, 63.54044345117385, 49.34959842312721, 0.42954093326003323, 0.1340335787784669, 2.9376346257425126, 0.776319059152757, 1.192005108441076, 53.806607261780776, 60.88881531069356, 52.19078686929519, 56.58071141089163, 62.76432798754785, 60.41347895899127, 51.21218296789354, 44.63402694271457, 45.260233340724824, 46.97115552040839, 49.165396075094904, 49.5731342992475, 51.601874366883315, 50.3489242061492, 50.599045907297445, 41.546235161442915, 43.07550453370617, 43.43310309994606, 42.16907616584532, 41.46602269141905, 41.36264862552766, 40.8945333573126, 40.639410634194654, 40.59171461289929, 40.06370475215297, 39.76323942984305, 39.57666012548631, 40.57537794113159, 40.97110586781656, 40.9716667667512, 39.68571378338722, 41.17299418295584, 43.41811572351764, 41.86213893275107, 41.57971259086363, 40.89469809685984, 40.93030145091396, 39.19407606124878, 39.42485263270717, 39.40000049529537, 39.67399766368251, 39.64139884518039, 39.33131587120795, 40.90183288820329, 47.98886153005785, 52.84370460817891, 53.87367194698703, 53.07101380440497, 52.35382803024785, 52.40927073263353, 55.27216949770528, 54.188979518029, 50.2082601670296, 39.64361106195758, 39.38505626493885, 39.85980818348546, 39.50002485705961, 39.33987056055377, 41.16750678708477, 39.40336196653305, 42.640470535524436, 54.29316943691623, 44.339978618006555, 40.95184310790032, 41.085501793892156, 39.67851231175084, 42.03160885841616, 39.829707914783114, 41.592374001779866, 41.24633858280797, 41.29151644245271, 41.69297495195943, 42.71743920541579, 52.360296018662, 56.519161578147646, 53.01465718976913, 54.282316238649436, 54.06901382630872, 53.08823693183161, 47.393834052547334, 49.12832575459635, 46.05116751886184, 43.99096612007388, 40.730899918463926, 40.851595171036266, 39.661873617479884, 39.080715640898674, 39.90678248866912, 40.76653072910924, 39.815234368847264, 42.52278374087426, 41.59073837341801, 40.806621274640484, 40.277140525079545, 41.1135781195856, 40.311688761557306, 41.70513429949361, 41.13025603755828, 44.43341732025147, 42.860437054787916, 46.498859005589644, 42.26955160017937, 42.852521711780184, 41.97652309171615, 42.498382676032286, 40.96297871681952, 40.59000053713399, 42.67950204110915, 43.52056411004836, 43.54620464386479, 41.99374229677262, 44.03964665628249, 41.61944227833902, 43.0125936385124, 44.94148585104173, 43.639258953832815, 43.969149897175456, 53.558568339194025, 58.715229957334465, 60.80711234000422, 61.81836997309039, 56.8309154818135, 54.83200503933815, 66.54629691954582, 57.970979828988355, 71.35254967597224, 38.375253831186605, 0.05170762538909913, 1.3856516658298432, 0.5442924160630472, 0.25776830051214467, 29.052652658954745, 74.08757132868614, 61.28850090888239, 74.97785522091773, 69.75383081743794, 77.42812848860218, 46.57681219039425, 40.063610615268836, 46.997635441441695, 69.2473743807885, 33.051683595103604, 0.38782539266732435, 0.06513460328982723, 0.043066218720688935, 0.04464451306229157, 0.056051937637910734, 0.04949681821369356, 0.020281093780912703, 0.14255215473953756, 0.21007460812407158, 0.17186784215511816, 0.16784188157368093, 0.08213004172449151, 0.20860425557100004, 0.16039857130137183, 0.15881540464057078, 0.1288868315638073, 0.3181216877795035, 45.630681591649214, 78.50931413712041, 64.38302347736975, 38.13852702417682, 40.31794494198215, 63.1834920760124, 75.8310099570982, 73.09630993873843, 71.73377267775997, 68.00555982897359, 70.6289037581413, 55.91374766442084, 0.7418079626175665, 1.5254001992364086, 8.153728977326425, 0.8282691360481325, 1.978930746836047, 62.87777862241192, 63.36375244202153, 57.03898152997417, 59.907646179199226, 63.790561229951926, 61.1469857154354, 54.08884140752978, 46.73189878463746, 46.08650022937406, 49.890481502779075, 51.92722320556641, 50.74183979342061, 54.5564506899926, 54.23948003399757, 53.58350676874961, 43.18335794633435, 45.395649248553866, 45.600691149311686, 44.35953947805589, 44.34494433864471, 44.0648086609379, 43.66925331854051, 43.31662831767913, 43.057724429715066, 43.577430632806596, 41.5161152808897, 41.56019095451602, 42.69980422912106, 44.78590111578665, 43.62236922787082, 43.40405794882005, 44.009193374264626, 45.254490990792554, 43.371286546030355, 44.11426582644063, 45.378324139502745, 42.45419325367097, 39.90956737149147, 41.23999218786917, 42.09955607691119, 42.251430249983265, 41.356525805688676, 41.47400863708989, 42.8111054051307, 50.149095135350386, 56.753884053999386, 58.30048638005411, 56.09497685586253, 57.67743749003257, 56.61948404004497, 56.84110972189135, 55.82308600025793, 51.16187857043359, 40.65309578372587, 40.124493645083525, 39.584269523620605, 40.185557103926136, 39.99811880050167, 39.76598508896367, 38.533246901727495, 44.37209890734765, 56.157554349591656, 46.680970730320105, 40.261823669556655, 41.57181293733659, 40.25796013493692, 42.72096149383053, 40.6201635637591, 41.892368639669115, 40.90740657621815, 40.8213262404165, 42.212457579951135, 43.31618901221983, 54.10544872283936, 61.26424104936662, 55.57867919245074, 58.59060448984946, 56.36616952957646, 55.392656864658484, 48.17891605438725, 50.93077251988073, 47.18388918907412, 45.30281459131549, 46.193475031083636, 43.30727738718833, 41.55559393667406, 41.82086383142779, 41.835105957523474, 43.750167892825225, 42.078104634438795, 44.989613333056056, 45.08919054462064, 43.11349661119523, 43.09932116539248, 45.69269426407353, 41.113550662994385, 45.234502592394435, 44.685700247364665, 48.44087939108572, 46.30559206008912, 49.95146651421824, 43.0242823016259, 45.34356409503568, 43.48993824374291, 45.612407269016394, 43.50598466011786, 43.955853062291304, 45.93896027534239, 46.816786719906716, 44.8418301920737, 44.21183870684716, 46.73441302391791, 42.376173388573434, 43.38876070514802, 46.73886883643366, 47.05713779695573, 46.63215683352563, 56.63769952712521, 62.32628945381411, 63.284642158016084, 63.7785077864124, 58.67715943244196, 58.85579985956992, 67.16064991489534, 63.85727290184268, 72.48239624884822, 40.79522286691974, 0.13862292041941998, 2.530607821479921, 2.187602923762414, 0.4547347152425397, 34.26698684692383, 79.84746994510775, 66.77836787316107, 80.46237207228138, 72.0803689956665, 82.20963893398162, 55.338292814070186, 50.667310837776434, 57.894372017152854, 79.14325544911047, 44.60894338546261, 0.7063514522967801, 0.1715458400787846, 0.12108601103987425, 0.1186250914789496, 0.1295678377632172, 0.11375566043200032, 0.30298388232627227], [0.023916904934711998, 0.05801591511455275, 0.025804432582170255, 0.04906376020141667, 0.014634881179869897, 0.08425204398771448, 0.009605043770505056, 0.060703489448755026, 0.01698546971554958, 0.011712519091463858, 23.681413858167588, 64.4748265512528, 36.319084628935784, 26.078648836381976, 27.71221010915695, 38.32953076208792, 65.70208518735825, 62.30319453823952, 59.58872218285838, 57.379796274246715, 54.53301060584284, 57.10370456018756, 2.8763765192800954, 0.4965089688137655, 1.7034466324313995, 0.6411052146746267, 0.12480318456167176, 31.404170451625703, 65.03274448456304, 53.93990116734659, 61.41821369048088, 60.49315014193135, 59.710688283366544, 47.416968191823656, 44.0391916613425, 40.66828320103307, 45.413174398483775, 47.26616090343845, 50.80350729726976, 50.49025504819809, 50.963791031991285, 46.40122336726035, 43.300221043248335, 40.877447512842, 39.54748553614463, 39.077311023589104, 39.453666363993, 39.5025900871523, 39.30120775776525, 39.65289923452562, 39.3704140570856, 38.5218837953383, 39.41598415374756, 36.581706923823205, 39.08179037032589, 37.265838884538226, 39.45814571072979, 39.2612741070409, 38.23601753480973, 39.20102650119413, 40.10733327557964, 39.121343551143525, 39.32774651435114, 39.54016639340309, 37.368263736847915, 37.28734131782286, 38.19549945092971, 38.0475829493615, 37.33706128212714, 38.513223201997825, 38.57571832595333, 48.78563219501127, 49.11858258708831, 50.34268763757522, 50.58911054365097, 50.824605726426654, 50.109800830964126, 50.70982540807417, 52.99310376567226, 48.540605652716856, 37.35290373525312, 39.26315684472361, 40.651781789718136, 39.78209426326137, 42.49451129667221, 40.01640096787484, 39.94151507654498, 44.43701021132931, 51.4045948366965, 44.429028188028646, 40.75973718397079, 40.830528120840754, 41.99527986588017, 40.70360022206461, 41.47606003669001, 41.83646701997326, 40.220521111642164, 41.510278794073294, 40.87412134293587, 43.37786436080933, 54.31470324916225, 52.61202589158089, 51.1614941781567, 51.430262827104144, 50.5024379299533, 52.93719430123606, 48.60129256402293, 42.70246751846806, 43.71352118830527, 39.20778082263085, 41.15454335366526, 39.5469089477293, 40.75732100394465, 38.830440967313706, 40.57616241516606, 38.62819179411858, 40.09114173150832, 38.63593063046856, 40.89748690205236, 37.16749329720774, 36.98906860043926, 37.71389515169206, 38.10871701086722, 37.91835654166437, 41.64713813412575, 40.37313661267681, 41.77542317298151, 38.86844481191328, 41.837263261118245, 41.97841759650938, 40.15695518062961, 38.884620666503906, 40.68496896374611, 40.04918413777506, 39.226204195330226, 41.33253266734462, 40.746769828181115, 38.92604481789374, 41.750190565663004, 40.843150308055264, 40.22256466650194, 38.9583259244119, 42.48225388988372, 40.17878709300872, 48.0558281560098, 54.223398316291075, 58.83285399406188, 57.362506466527144, 60.40512823289441, 51.217074163498424, 59.508192000850556, 56.405385386559274, 66.84526781882009, 10.440913035023598, 0.25741182447921845, 0.6099744657835653, 0.5247411780780362, 0.05391084063317507, 30.795434290362945, 67.05696598176034, 51.69614853397493, 67.23995239503923, 43.15220648242582, 57.54517516782207, 40.289550904304754, 41.55699422282558, 45.25620898892803, 60.701875148280976, 11.539298276747427, 0.47558845591641247, 0.030388298609684554, 0.09642806925600576, 0.005404367261836606, 0.087086561646673, 0.06184378451096916, 0.045692264703252626, 0.04097916155813202, 0.01219368359494594, 0.04765457210821971, 0.06055402186428828, 0.0363556677175145, 0.03948805568319175, 0.02203295491786013, 0.04027888824742648, 0.05055886122488207, 0.06230673527405147, 31.687802922341135, 71.1541405031758, 44.86361111364057, 23.641997960305986, 30.02783037001087, 54.2189464261455, 69.23807836348011, 69.38224115679341, 64.08413102549892, 65.49690208127423, 60.110675904058645, 61.732250413587025, 2.582773138438502, 0.14865072023484016, 1.0890739026569551, 1.4413881782562503, 0.03310560481622815, 35.73240395515196, 65.14399074739026, 54.92093693825507, 65.0153644623295, 61.872741868419034, 61.66523279682283, 50.57608827467888, 45.55714107328846, 42.93459338526572, 48.6945822162013, 49.31650930835355, 53.127786190279075, 52.498775297595614, 53.08360461265811, 48.1286116569273, 44.223594050253595, 42.77918515666839, 41.22334172648769, 41.58509800511022, 42.41454985833938, 40.770441332171046, 41.86450804433515, 40.91610247089017, 40.8957806710274, 41.6100089780746, 41.38673590075585, 38.5907841497852, 40.35067319869995, 40.93930721282959, 40.86801813494775, 40.3436678455722, 42.01567226840604, 40.714555401955884, 40.228612961307654, 41.77683914861372, 41.403523645093365, 42.082842857606956, 40.06020207558909, 39.320446983460464, 40.44743022611065, 39.88338555059126, 40.640834454567205, 41.330104720207956, 39.098095663132206, 51.23493663726315, 51.85117629266555, 52.4559037916122, 51.75771797856977, 53.6813973611401, 54.11543507729807, 54.92598502866684, 53.572810465289706, 50.178226578620176, 38.05968346134309, 39.3834755497594, 41.73213197338966, 39.34583256321569, 40.41947157152238, 40.428732287499216, 39.82695048855197, 43.26469613659767, 54.11001828409011, 45.50086290605607, 41.07601358044533, 41.154747316914225, 40.717622695430634, 41.208213144733065, 40.57469937109178, 41.92306118626749, 39.87910232236309, 41.93226306669174, 39.68620015728859, 45.89523761503158, 56.73409961885022, 54.79804908075641, 54.45323351890811, 53.31386343125374, 51.99391134323613, 55.73144766592211, 50.3579495799157, 44.576838785602206, 46.90247481869113, 42.08299975241385, 42.738259146290446, 41.96195933126634, 42.08925985520886, 41.04194387312859, 42.374941764339326, 40.8558823216346, 41.639728776870236, 39.54015462629257, 42.91853127941009, 39.8165052167831, 39.71477854636408, 40.61661381875315, 40.2231373325471, 41.37910296840053, 42.38095475781349, 42.627922873343195, 44.75910348276938, 42.23521124932074, 44.07278283949822, 45.351848140839614, 42.214775700722974, 41.07237362092541, 42.637889615951046, 42.33769101481284, 41.499221632557536, 41.978535267614554, 41.992259640847486, 40.85587447689426, 43.97477849837273, 43.11668942051549, 41.680768535983184, 41.50756059154388, 44.02025445815056, 43.25357229478898, 51.33799691354075, 57.11242398908062, 61.790175976291785, 59.83787505857406, 61.70497817377891, 52.69489772858159, 62.92824383704894, 57.505790648921845, 67.05767200839135, 11.245652975574618, 0.3515997300705602, 2.356405801350071, 0.6837479974473677, 0.020389029823784387, 36.1620407719766, 72.67051312231249, 59.93055282100555, 73.08304448281565, 52.76395890020555, 64.79922225398403, 48.370453234641786, 46.16426514041039, 52.24120501549014, 70.46026537495275, 19.25994953801555, 0.39655392268492334, 0.009617001445393169, 0.09932751286654704, 0.036227711881961555, 0.07853552654025056, 0.02086471296816824, 0.04458324901098686, 0.12267096268553888, 0.12887615229814284, 0.09385025233871515, 0.15963375508304567, 0.09582058451468907, 0.15251093003298008, 0.10161630779264436, 0.16756820432361097, 0.10343981921792993, 0.12238864396368304, 36.388165412410615, 82.75320883720153, 50.503559727822584, 39.37489340382238, 40.83299529167914, 55.144684622364665, 75.67956724474507, 73.89829343365085, 69.74641753781226, 68.69630490579914, 63.092167531290364, 68.27357538284795, 3.779165663065449, 1.028998635949627, 4.48377852478335, 1.4460513860948625, 0.1757882664641065, 36.616772913163715, 69.61774026193928, 58.586282037919574, 66.73788901298278, 63.917963735518924, 65.96095377399077, 53.22351947907479, 46.340971839043405, 44.866529357048776, 51.320777708484286, 52.78972102749733, 55.972638130187995, 54.097921694478686, 54.432911719045336, 50.94885856874528, 46.854688582881806, 44.40056747005832, 43.507600676628854, 42.71618012459048, 44.31497350815804, 42.730771341631495, 44.2388952162958, 42.96578015050581, 44.25573002907538, 43.69840045129099, 45.122813101737734, 41.58701996649466, 43.62286344651253, 42.40588142025856, 43.41549558024253, 42.68897456507529, 43.24464105790661, 42.28013807727445, 42.007803993840376, 43.377291694764175, 42.130534956532145, 44.45292326711839, 41.08394069056357, 41.834839236351755, 44.03764624749461, 42.838726735884144, 42.29727099018712, 42.94186938193537, 43.47692774188134, 53.52560866263605, 53.863481629279356, 55.52439358926589, 54.46444757523076, 55.786623647136075, 56.85251597435244, 56.7826154155116, 56.100075937086544, 52.59826229464624, 37.7031635469006, 40.025100784917036, 43.03955208870673, 40.438608815593106, 41.5947078120324, 40.62237578053629, 39.82879400253296, 45.92014466562579, 56.96107149124146, 46.50485630958311, 41.4294897356341, 39.56000181936449, 42.14456919700869, 41.180081905857215, 42.03872796027891, 42.09428833376977, 40.12229711778703, 41.853913722499726, 40.169067459721724, 46.41950945700369, 60.74193039248067, 56.41588949388074, 57.68112451799455, 56.891198388991825, 55.03194785887196, 57.78533797110281, 55.29772373937792, 47.05932647951188, 48.051313507941465, 43.47093436025804, 43.4298946011451, 44.06464392139066, 45.20340211929814, 41.95802127161334, 45.032194583646714, 41.027313432385846, 43.24029507175569, 41.71152776287448, 47.87555602289016, 41.94357910463887, 41.435326222450506, 42.35303924929711, 43.67390132719471, 43.883846190667924, 46.49227334607033, 46.110563970381214, 47.99191705642208, 46.192855296596406, 47.46780603162704, 48.44199334421466, 44.55672879372874, 44.88376425158593, 43.89491119692403, 45.082769624648556, 43.26612387934039, 45.49961951471145, 44.36222237925376, 42.8785034918016, 45.951284362423806, 45.41301358130671, 44.1722619918085, 43.242942671622004, 48.08008017078523, 44.55692098986718, 53.001509404951534, 59.7655975434088, 63.24973698585265, 64.40852280585997, 62.07716011231946, 54.9947637896384, 65.51156390097835, 58.64646688584359, 71.77152156829834, 13.070635718684043, 0.3858186100279132, 3.482654335037355, 2.3462828993797302, 0.18981584197571202, 38.37649330016106, 79.19624667013846, 62.281503831186605, 78.07532741177467, 54.81719024719731, 72.19261938525786, 54.315017038776034, 56.34980932358773, 60.69013157198506, 81.13459571715325, 26.638849589132494, 0.6226207388024176, 0.1451991877007869, 0.1889633546553312, 0.14860780398932197, 0.19829649658453083, 0.19238191476512342, 0.14323712927439522], [0.028858712138307673, 0.055709595927187515, 0.00842784816819814, 0.04671219203080382, 0.05444809043359372, 0.06072979690807481, 0.01656805138824688, 0.061584019417604136, 0.0887346159546606, 0.17087799526991385, 22.7398665489689, 61.82420253753663, 48.41206173742972, 58.91671426834599, 54.470672376694225, 34.29133692095357, 56.51183851303593, 65.45357165798065, 55.38369424881474, 60.765696033354736, 50.27912955130301, 61.2206478272715, 14.477694822895913, 0.338807471336857, 0.8444370846113852, 1.3393821615365245, 0.02207390423263273, 6.397731409918878, 70.27855765435004, 53.05009580427601, 62.62277357039913, 56.2131304125632, 58.55344787720711, 40.31979630070348, 44.381034066600186, 44.59528961489278, 48.98818731307984, 49.06758000773769, 55.81647680651758, 51.16824457722326, 56.20648199512113, 47.20403840464931, 41.90947801836076, 38.86993531257876, 41.63789702999977, 37.144967125308135, 41.044497336110766, 39.73037781253938, 39.79854860613423, 38.72169717665642, 39.7836475218496, 38.142900466918945, 40.7867701591984, 36.43448860414567, 38.283203647982695, 35.59194780165149, 37.463949957201564, 37.783019081238784, 38.829621191947695, 38.58242950131817, 41.60852239977929, 39.4363530220524, 40.97205900376843, 39.504861139482074, 40.25466534399217, 37.85629680079799, 36.547190066306825, 36.12533130953389, 37.4978627697114, 37.056121518535, 44.1820796843498, 48.16268920898438, 48.75046422404628, 48.559417340063284, 49.434470668915786, 50.19580271936233, 50.69696395627914, 49.557397750116166, 53.37233028104229, 46.87633614386282, 40.592769730475645, 38.861015842806914, 40.16377618235927, 39.43020666799238, 42.32346065582768, 40.757289624983265, 40.56139861383746, 42.29969501495361, 54.420662156997196, 43.57197069352673, 39.70922447020008, 41.54669407875308, 41.67056645116499, 40.46739901265791, 41.18537318321967, 41.59985788406865, 42.21357545545025, 41.420013289297785, 40.61451142834079, 44.90363890124906, 52.70624906786027, 54.389553839160556, 52.6808124972928, 51.19225340504801, 51.138614992941584, 50.516052476821415, 52.58983312114593, 45.28586210743074, 41.393380395827755, 39.94428034751646, 38.597569850183305, 37.638754306300996, 37.1531609565981, 37.73478177285964, 39.48709672497165, 38.25833189872004, 40.36963001374276, 39.63680182733844, 39.279030676810976, 38.27474309552101, 38.05168574856174, 36.85996770858765, 37.40728347532211, 38.286753392988636, 38.55932281863305, 40.984061456495716, 40.230342726553644, 38.61961357055172, 38.625650098246915, 38.62950186575613, 37.98843360716297, 36.576337199057306, 38.47410540426932, 40.106313459334835, 41.22944493447581, 39.88585664379982, 41.59035398114113, 41.01069042759557, 40.26627555970223, 41.22604816190658, 40.528623288677586, 39.43439575933641, 40.10777258103894, 40.388692732780214, 43.748277310402166, 52.035562992095954, 57.06220980613463, 57.61984925116263, 58.56999243459394, 57.42284036451771, 49.998197632451216, 58.73129990793044, 47.5340352519866, 1.689445241805046, 0.07166557179223146, 1.574008049022767, 0.45865058898925787, 0.0968946244627718, 38.863369264910304, 66.3856444820281, 51.16156085844963, 63.710693928503225, 51.08634941039547, 48.80080000046761, 31.37906336015271, 41.81808679334579, 49.43563953522713, 55.704112668191236, 6.455610394477845, 0.33137479436493694, 0.08704245796487217, 0.04474719948766213, 0.023751399299550443, 0.059667765388205174, 0.08178168622356269, 0.013660565769720464, 0.0769143465966467, 0.06202521328363688, 0.03526834380482474, 0.04515093548463718, 0.14200470830884673, 0.057519279465439825, 0.014085197772440172, 0.11911604658610399, 0.030485785213269057, 0.15627389263001182, 26.845601643285445, 71.96642414216073, 52.92431323759018, 55.041545898683616, 46.08457826798963, 43.82595200692454, 62.93528841387842, 71.25358827652471, 60.35474538803101, 65.4893122949908, 54.67216061007593, 66.50100138879591, 14.813259474692808, 0.219128480361354, 1.8824395825785978, 2.110083160861846, 0.07026157777516112, 7.485436527959763, 74.0607972298899, 55.95254775016539, 64.9274641467679, 57.91508213166268, 61.85249459358954, 41.91585971463112, 47.00906130575365, 46.40259619682066, 49.86326809852354, 51.987855203690074, 58.535879581205315, 53.81037665951637, 58.10989841338127, 49.063237943956935, 44.87825332149383, 41.544756427887954, 42.407889673786784, 38.961569724544404, 41.31764727254068, 40.44284889774938, 41.50263801697762, 40.39181886180755, 42.65793684990176, 40.26982922707835, 41.4248142703887, 37.38891893817533, 38.74795744496007, 38.18048854028025, 38.78750670340754, 41.10213656579295, 40.994526340115456, 40.80956305226972, 42.316643576468195, 40.754575344824026, 42.130538878902314, 41.11599429961174, 43.87524051050986, 40.924049192859286, 38.78930707131663, 37.11782824608588, 38.932861897253225, 37.00959044118082, 45.541753615102465, 49.28336135802731, 51.21947465404388, 52.07625366026356, 52.26273490536598, 52.72717491272957, 52.87847249738632, 53.09248093635806, 54.89164467780821, 48.34179639816285, 41.85466681757281, 38.657111429399066, 42.289045779935776, 38.89372448767386, 41.7531519551431, 40.27583437581217, 40.69493570635396, 44.424980302010816, 57.22599621742003, 43.285602369616115, 39.33455182660011, 42.082952683971776, 41.57657469472578, 40.14539987810197, 41.52065738554924, 41.55906523427656, 41.717564290569676, 41.45843682750579, 41.04024940921415, 46.3164609478366, 55.7430814158532, 56.08287634388093, 55.50107902096164, 53.22501782448062, 54.400771817853375, 53.18105197721913, 54.14059708195349, 46.91605798659786, 44.94757336954917, 43.675093727727095, 41.06557615341679, 40.138241552537494, 39.60708595091297, 38.49689829734064, 40.92794802881057, 39.593392956641416, 42.363817922530636, 41.3581378998295, 41.61744971429148, 41.017170183120236, 39.80232977098034, 39.44289945786999, 39.78738161825365, 39.82658570812595, 42.5730332251518, 42.7306144468246, 43.35482435841715, 41.054589594564135, 41.61677506662185, 40.67633582699684, 39.90209917868338, 38.34459266354961, 40.43513751799061, 42.201384728954686, 43.569299559439386, 42.032856172130955, 44.3920127807125, 41.957566276673354, 42.512452217840384, 43.050201323724565, 42.55750848400978, 42.36148803464828, 43.00734550722184, 42.75869077251804, 46.44705626272386, 55.68497150175033, 59.29443851594002, 60.720698602737926, 62.862053840391106, 57.00256624529439, 54.71691093137188, 59.80153429892756, 51.877656213698856, 2.2947432004636337, 0.2759001001475319, 3.3513225951502403, 1.1857811649960857, 0.20900121168984523, 42.66479707533314, 71.42786702802105, 56.574282646179206, 67.33476392684445, 52.315482939443285, 53.08965682983399, 42.08268596280006, 48.0494660715903, 53.58344008845668, 67.65650026259884, 10.072845662793807, 0.465837198519899, 0.03444599438338511, 0.04808894013084712, 0.01808138147387053, 0.08243064696509993, 0.03941483299938902, 0.055799641901807445, 0.18229108123529345, 0.07764771490568116, 0.14254607200141878, 0.16205911284252522, 0.2340447638304003, 0.1859123175663333, 0.11052643895269403, 0.20880729951445134, 0.20805664060096588, 0.22278322537820186, 30.116591645825295, 83.29856734122001, 61.85889590171076, 72.40205041823849, 64.29185974982478, 51.69277921799691, 65.71208723129766, 78.35987967829551, 64.72599160286688, 72.96002326473113, 58.410457872575336, 75.25184062219436, 18.010551083472468, 0.45551257027733716, 4.759959472763923, 3.505365593779472, 0.09442929989628254, 8.809795398865978, 76.30954696286109, 57.51122313161051, 66.70931062390729, 60.31816144143382, 64.05937694734143, 45.95152754937449, 48.393936464863444, 49.36562130528112, 52.91813550456878, 53.55575599978047, 61.85191800517421, 56.94788056035196, 59.805884207448656, 51.73664700600409, 47.035874628251605, 44.639349599038404, 45.623691928002145, 41.877522468566895, 45.43843446239349, 44.28519879617999, 43.34812102779266, 42.06280346839659, 44.264633809366536, 43.07115462518508, 44.168806383686686, 39.69181699137534, 44.29278858246342, 41.93143936895555, 40.88757899499709, 42.901265005911554, 44.89974398766795, 44.485027866978804, 45.19583194486557, 43.06812263304188, 42.00835704803467, 42.95932392920218, 44.511907869769686, 42.3068807971093, 39.36642500662035, 39.65567235023745, 40.41394495194958, 39.339113543110514, 48.182136320298724, 52.053947141093595, 54.18591614692442, 54.1238760179089, 55.15312164060531, 55.038502139429895, 56.117208849999216, 55.95148871021887, 57.99582412165981, 49.949991703033454, 42.521026519037065, 38.76925591499575, 43.297726415818744, 38.70118318065521, 43.429851455073205, 41.26565233353646, 41.36202889104044, 44.260425106171645, 59.9066577419158, 44.59467380277572, 39.64435631229032, 42.9248070716858, 41.21915655751383, 41.5745742859379, 41.41209402391988, 41.57867708513814, 41.11253869148993, 41.887308782146825, 39.46696712124733, 47.35967805308681, 57.48783011590281, 58.41570208149572, 57.523935533338985, 54.177384991799634, 58.24951517966486, 55.33910082232568, 55.52327179139661, 50.211978573952955, 45.94178830423663, 45.38398804203157, 43.93996354072325, 41.00149246954149, 42.20587192043182, 41.79976540227091, 43.878107763105824, 41.20404758761006, 45.406078830842056, 43.49704950086532, 43.99952473178987, 43.79644009374803, 42.45725270240538, 42.399009427716656, 42.3723530000256, 43.115198919850016, 45.735346117327296, 46.361932985244266, 45.074764067126864, 43.78022109308551, 43.94956550290508, 44.16471535159696, 42.088334175848196, 39.965163046313876, 42.87567154053719, 44.7194718545483, 44.688500819667695, 44.719558146692094, 46.9003410493174, 45.172674271368216, 45.39626506067092, 45.664284536915446, 44.6051622206165, 44.43506079335367, 45.38897337452058, 44.207406428552446, 48.893391470755304, 58.60274422553278, 61.8975273255379, 62.27186656767323, 64.24486975516042, 62.29545570188954, 56.65256138770812, 59.838569318094564, 54.499376281615234, 3.446210368025688, 0.23195083102872296, 5.034263566617043, 2.0546802950482217, 0.256970971522312, 48.15855895319293, 79.63802322264641, 60.85001914731918, 77.29187319355627, 61.754894256591804, 63.191556469086684, 42.9342560614309, 53.18933602302305, 62.686057090759284, 78.65764248755671, 14.56375946921687, 0.5837675784864734, 0.12975347618902885, 0.2382600707032027, 0.09572395784479958, 0.13083683176627084, 0.17522862391366115, 0.1244954470424883], [0.11324327018472458, 0.04427800127755731, 0.014877941726045984, 0.01844165921812096, 0.0915996468956432, 0.01335427136866436, 0.05720919771720806, 0.045159691869611704, 0.0646175628888511, 0.3218170814216137, 12.441141393876846, 58.835070133209236, 48.93604332400907, 49.12565854287917, 90.86935366353681, 61.68573110334335, 46.03661160315237, 69.56380767206993, 55.31815928797568, 60.891976741052446, 52.65046511926959, 59.988497995561175, 34.25879693800403, 0.06406492238203365, 0.27520832275190665, 2.401830280019391, 0.3257388080800733, 0.19207809961611227, 43.451706901673354, 65.43399118608045, 58.316972101888354, 62.05812877224338, 48.74074066838911, 43.770901541556086, 46.60037386801935, 45.960627448174264, 51.1337669434086, 51.210457125017726, 56.09730674374489, 55.98133794723019, 55.69533832611577, 46.35005604836249, 39.39928270155384, 38.98088347527289, 40.394219352353005, 40.8633073683708, 44.05424179569368, 45.757707549679665, 43.82821913688414, 41.642011596310525, 39.63095357341152, 40.06307325055523, 37.08906550561228, 38.7243486988929, 37.0324460921749, 36.744371537239324, 36.73231024895945, 37.69480105369322, 36.82882801178963, 40.076252414334206, 41.3248134428455, 43.22753167921498, 41.50055131604595, 41.86485713528049, 39.45534906079693, 37.890970553121264, 40.35445436354607, 37.10871265780541, 39.99803250835788, 40.25125680431243, 45.18808134140507, 46.598043980137, 49.56282631043465, 49.75431642224712, 49.44426874960623, 50.10918894121724, 51.2301827246143, 51.30057750209686, 52.28182115862447, 44.585899460700254, 40.08394418224212, 40.55719775538291, 40.95614987034952, 41.129502942485196, 40.290723692986276, 42.388866178451046, 42.151605929097826, 42.53613156657065, 50.56070081649288, 43.729202824254195, 40.43469821253131, 39.60232419352378, 41.69661098910917, 42.00906307466569, 41.771547871251265, 42.55124838121476, 41.306056668681485, 40.400334327451645, 42.96442301042619, 46.627540203832815, 54.5618910174216, 53.75459663329586, 55.066900099477465, 50.37824392318726, 50.2008076637022, 51.64370644477106, 51.52658054905554, 50.202137347190614, 41.96051197667276, 37.395720328054125, 37.24058274299868, 36.12253465960103, 36.991767191117816, 36.784768027644006, 38.160441306329545, 39.19578229227374, 40.14652559834142, 39.87607033021989, 39.735896587371826, 38.119189739227295, 36.60102067455169, 36.70335138997724, 36.70386914283999, 37.13882861598846, 36.82885154601067, 39.04207244996102, 37.64337878073416, 39.41856115095077, 38.628054511162546, 39.23812820065407, 38.69852773604855, 39.083100441963445, 38.769095097818685, 38.88468342442667, 37.46831947757352, 39.59729571496287, 45.54699390165268, 48.23540210723878, 48.784071091682684, 47.081589852609945, 42.276474583533506, 39.54313170525336, 38.95663538286763, 42.13425728582567, 40.50048420506139, 46.91808192960678, 52.20464068074381, 57.337191489435014, 55.87413564805062, 59.7710810169097, 51.74859846791914, 59.5814932546308, 25.073990591110725, 0.10265087122998892, 0.4396173796586452, 3.4239955342585042, 0.30767978679749275, 0.33269822657588993, 53.09248093635806, 61.29136816147835, 59.301365421664336, 64.12319783241519, 68.99301651985415, 42.609668162561235, 28.89779160099645, 48.48729671970491, 64.91793278724917, 51.845108386008974, 3.6450745357621104, 0.25310930615711597, 0.14045903399105997, 0.03394042997951469, 0.0847675981781175, 0.011568623839036353, 0.09735597793253199, 0.029975758347239707, 0.1188334673943539, 0.062149760027926784, 0.04653201581189229, 0.023472750138851906, 0.05705318774186796, 0.06715404936262677, 0.09938091685574862, 0.13381116813228977, 0.15380708951382868, 0.21320617637566983, 17.220817150608188, 68.12320739992204, 53.609971000302224, 58.31423428750808, 75.49963243546026, 55.228388001841886, 54.15440774733021, 75.76287838720506, 59.51811951975669, 66.55604008705386, 57.62880794463619, 66.57188646255001, 35.83453462969872, 0.078638052087157, 1.0266838246776213, 2.4643151077532, 0.8014211250889687, 0.09784510208954735, 45.63978541281916, 61.73589037310693, 59.02605425926947, 63.54834310470089, 53.779440925967315, 44.785552024841316, 46.36490614183488, 47.96794745229906, 54.06820581805322, 54.441023180561686, 56.52953232488325, 57.26763609916934, 56.8708138312063, 47.69487204090242, 41.19854057988813, 41.493804839349565, 41.82154632383778, 43.246080567759854, 46.377112557811124, 46.077113997551706, 45.204057155116914, 44.03261384656353, 41.76602517404864, 41.36024421261203, 39.92607662754674, 41.99790393152545, 38.978804619081565, 38.163669416981364, 39.09403993237404, 41.934369379474276, 38.692306856955256, 42.405908876849765, 40.94675579378682, 44.457571275772594, 44.468906925570586, 42.74173436626312, 41.73254382225775, 40.939671993255615, 41.37540025095786, 39.09541276193435, 42.51132257523076, 39.887366756316155, 47.041028622658025, 47.75892434581634, 52.60065886282152, 51.92400293965494, 51.84697935658117, 51.78929305845692, 53.38945927158479, 53.964529729658565, 55.700174608538234, 47.650682618541104, 41.61719083786011, 40.47967210892708, 40.96038210776545, 41.261271046053984, 40.026426546035275, 41.636924282197036, 42.11883060393795, 41.44230804135723, 53.15391309799687, 45.71112548151324, 41.50203397197109, 40.86611970778435, 42.74532725734096, 41.266511332604196, 42.171876738148356, 40.959617245581846, 40.51267493155695, 41.0943506610009, 41.422048999417214, 46.22606600484541, 53.90756122527584, 54.31189483211887, 56.69509949222688, 53.84584273061445, 53.485686779022224, 53.53519101296702, 52.770242537221606, 52.763095978767645, 43.49337816238404, 40.397839700022054, 39.08129222931401, 38.46215786472444, 38.726411865603545, 38.85019010113132, 40.74247483284243, 40.11825315413937, 41.7067503160046, 42.254403406573886, 41.97142401049214, 39.89029676683488, 40.088960893692516, 39.37112400608678, 38.909845429082075, 39.70634152812343, 39.61804505317442, 42.369862294966175, 42.357330322265625, 41.05499359869188, 42.045925509545114, 41.371662232183645, 41.29694892514137, 40.767009258270264, 42.26424071096605, 40.483410127701305, 40.328927578464636, 42.513201390543294, 47.418239039759484, 50.413666848213445, 52.581784417552335, 48.895846874483176, 44.646904083990286, 42.604282748314645, 42.463920731698316, 44.37549567991688, 44.017147940974084, 50.35964404383014, 55.059478975111446, 59.895043603835575, 60.2976199888414, 62.453029078821984, 52.85374587582004, 59.421115383025146, 29.955660720025342, 0.07311437429199297, 1.8422643383664472, 3.817678680343013, 1.0126786955421971, 0.45476483781972243, 55.647222611211966, 67.0307331700479, 62.91652771734423, 67.52710911535448, 70.7291046265633, 48.95262318272745, 33.18834289427727, 46.878881762104655, 71.70666125512892, 60.76565288728284, 5.691128680782934, 0.40007375961830544, 0.11782734114075862, 0.009880247450764141, 0.06303771721920179, 0.030115331906164368, 0.0230276798679223, 0.04476214203262522, 0.29661787553660335, 0.15613313163480452, 0.17854917073442092, 0.10823862461913979, 0.17282819465523766, 0.21423029803460647, 0.21473830625895532, 0.2041141836032752, 0.23119920684445291, 0.5232558255234073, 17.96142928061947, 80.83094935263358, 59.389328495148696, 64.41672055952012, 94.06748171775573, 73.87628109224381, 59.60601591294812, 81.53950199004143, 63.47125284133419, 75.1338400379304, 62.074838069177446, 71.56520489723452, 42.04329359915949, 0.13946627597174338, 3.2396816438244236, 6.27406741342237, 0.718760728355377, 0.3229056310749823, 46.463734180696555, 61.34759926026868, 60.5328013820033, 67.5797002546249, 55.68646984715616, 46.58809292700983, 49.262239394649384, 51.90177486788843, 57.13859012050014, 57.48484911457185, 59.05930026885002, 59.882511631135024, 60.436150258587254, 50.84044033481229, 43.580423401248076, 44.21003833893807, 44.605315193053215, 44.87371513920446, 47.738429961665986, 49.82135757323235, 47.523778253985995, 45.086727296152425, 44.1330853585274, 43.7811859961479, 42.037829737509455, 44.15445443122618, 41.14249383249591, 40.2836359700849, 41.910286026616255, 43.4087844048777, 40.21678309286795, 45.19818144459879, 44.62760994511266, 48.28528681109029, 45.77563670373733, 44.78974111618535, 43.467019834826075, 43.016096315076275, 44.651253992511386, 42.10791857011857, 45.3656352719953, 43.7679519191865, 49.55743305144772, 50.94643846634896, 55.27140463552168, 54.51398711050711, 55.137749871900006, 55.38589077611124, 57.66317182971586, 56.372629673250266, 57.890018186261585, 47.841831484148585, 41.62911484318395, 41.66997417326897, 43.23304653167725, 41.369634366804554, 39.96572394524851, 43.05195462319159, 44.341637780589444, 43.66939452386672, 55.32397224057106, 46.52256188854095, 42.17529312256844, 39.51663217236919, 41.7970315102608, 42.33681632626442, 41.6831886383795, 41.709723472595215, 40.799058944948264, 40.38859859589608, 42.48831395179995, 47.911630061364946, 57.646364473527484, 57.50679085331579, 58.8852882385254, 56.17804481137184, 54.86004214132986, 57.05140759868007, 56.07603573030042, 55.688584004679036, 47.186383816503714, 42.37312962931972, 41.098214195620635, 40.02828182712678, 40.83231672163933, 40.14161871325585, 42.47083587031211, 43.25567468520134, 44.42538430613857, 43.936935470950225, 43.95231900676605, 41.9610022729443, 41.899805453515825, 41.27197911662441, 41.83720050319549, 42.00692538292178, 41.63260967500749, 45.861540532881214, 44.03417887226228, 44.453629293749415, 44.735031897021884, 45.16191520998555, 43.72868899376162, 43.76993271612352, 43.50504329127651, 42.897005311904415, 42.311850440117624, 44.714208033777055, 50.39955416033345, 53.49581433880714, 54.30719975502261, 52.12282788368964, 47.30605925283125, 44.59594465071156, 43.886329050987, 48.12778795919111, 44.921854388329294, 52.15534433241814, 58.2879347955027, 61.31660076879687, 64.64749320860832, 63.81396209039996, 56.195299317759854, 61.26541383804814, 36.13488228090348, 0.44009756356958424, 1.371606271113119, 10.73325316752157, 2.3936401259514595, 0.6793619295762432, 63.597274672600534, 71.64697062584662, 70.2037972788657, 74.46049459518926, 76.21219373518421, 55.057419730770974, 39.28090164738317, 56.79361766384494, 77.85317220995503, 74.82439641029605, 8.414364591721567, 0.6097788375712211, 0.2839048302942707, 0.15326998527011565, 0.23819250174828116, 0.12316738766047264, 0.2093103281672924, 0.09843125894305207], [0.014827870219315012, 0.009004985294004363, 0.032530506441910426, 0.0719608833652831, 0.019077018068562594, 0.010680983616640011, 0.020397565958480683, 0.06863429977168, 0.03014732182266251, 0.154013320383045, 4.144942616262744, 53.23029341236238, 50.570267477343165, 51.56610235091179, 85.9113287156628, 67.58457968311926, 40.35678032905825, 62.478198928217736, 61.02533340454102, 55.52316196503178, 52.95340545715825, 51.66595805075861, 49.47862871231572, 1.0200314235783394, 1.1151683282467628, 1.821446113528744, 1.529800117977204, 0.3422523848712445, 14.695771740328881, 64.72696435066962, 56.52787316230036, 57.817422959112356, 42.54203081130982, 45.83215021318006, 48.17340904666532, 52.32379051946825, 55.846624143662, 54.44123498855099, 55.14384915751796, 56.928923745309156, 53.400132040823664, 43.08931912145307, 38.96339754904471, 37.192376813580914, 45.534603134278335, 52.18046319100165, 51.3911214951546, 52.564239655771566, 47.26054014698152, 45.517403541072724, 42.394804646891934, 40.19517867795883, 38.77140537385018, 38.7440860656, 36.82517236278903, 37.52382493788196, 36.781434012997536, 37.31828489611226, 37.390319224326845, 38.79049947184902, 40.60526247947447, 40.50519104926817, 38.39275544689548, 39.06231972479051, 37.97577219624674, 40.03735819170552, 37.46025508449924, 36.955955951444565, 37.83081316178845, 40.36367193345101, 43.63844702320714, 47.89681134685394, 50.02212016813217, 49.93118786042737, 50.08629014415126, 47.502887710448235, 50.96606208432106, 51.84876795737974, 52.250532411759906, 46.67554609237179, 39.52755989566926, 40.39130895368515, 41.249096009039114, 40.008771957889685, 40.72626367692025, 40.808829569047504, 40.7151202232607, 43.21996542715257, 50.9098074513097, 44.509503456854056, 40.95331007434476, 42.215077723226244, 42.959045440919944, 43.88647810105355, 42.3164592250701, 42.46467774914157, 39.70625915834981, 41.85387449879801, 42.48286970200078, 43.35569120222523, 52.3003072892466, 54.42520818402691, 53.8398140476596, 50.919201527872396, 49.53818205864199, 50.28122801934519, 49.06445387871035, 49.0378955102736, 47.565516194989605, 38.6063128132974, 37.423729973454634, 38.673801114482266, 34.83678956185618, 36.65828335669733, 36.65299600170505, 38.84807986597861, 39.39734897305889, 40.422476107074374, 39.69757110841813, 39.89966730917654, 37.9738502348623, 37.86100756737494, 37.09471764103059, 37.25864525764219, 36.5630482089135, 37.3975520749246, 37.53798077183385, 36.227336468235144, 38.20187722482989, 36.8134601654545, 39.21251512342884, 38.63975494138656, 38.98696707141015, 40.758262372786, 40.22001512588994, 44.610269146580855, 50.54716079465805, 51.53153450258317, 51.39670302790981, 53.92093650756344, 49.10265384181854, 44.32558351947416, 40.83551345332977, 40.58203420331402, 39.735045433044434, 43.10281599721601, 49.858714226753484, 54.589892818081765, 55.06013793330039, 60.79634151151104, 53.03860325967112, 54.409216680834376, 9.173623669532038, 0.2923165982769382, 1.9004813822046405, 1.8885662022136875, 1.2004181021644225, 1.308248348293766, 58.972313865538574, 55.705038347551906, 62.11779586730465, 61.29201927492696, 63.59578417193506, 49.218022515696866, 37.42980180248138, 45.627351499372914, 61.238714264285186, 42.097818466924856, 1.1308775433609564, 0.19189157252830846, 0.09586189963644552, 0.041249912352331226, 0.026676267453078783, 0.0512786238123813, 0.076793450261316, 0.0803884021156738, 0.10557845324998903, 0.025715116306298205, 0.026608583584968603, 0.06536572435570341, 0.12570986494181619, 0.09875295458421593, 0.022332912814172528, 0.04505194543350128, 0.04898589502479281, 0.16284516501811244, 6.066899588031154, 65.21884525975874, 56.96842201294438, 58.10530139553932, 84.4766669119558, 66.31524578217538, 48.49500417709351, 68.97525602771391, 66.24024221974035, 62.56682095989105, 60.35779699202507, 57.46346827476256, 55.34532954615932, 0.7175075310853221, 0.9670120718017702, 3.4587271415418197, 2.5414882311897897, 0.31793850083504954, 15.708028597216453, 66.36200043462938, 57.59608361028857, 59.02787031665925, 44.70557489702779, 48.691377639770515, 48.57404778080602, 54.93549677633471, 56.32507877965128, 56.877379878874756, 55.20676789745208, 58.16690614146572, 55.56953614757907, 46.1351062405494, 41.27747043486565, 40.499366329562285, 47.327224362281065, 53.15547027895528, 53.60420119377875, 54.42860887896631, 49.81245379294119, 49.47395324707032, 43.9898717787958, 41.33037928612002, 39.35006480063162, 41.45545190380466, 39.64997706874725, 40.40663757631856, 38.701202792506066, 40.17550014680432, 40.02192758744763, 41.65669302786551, 40.5536283985261, 42.500775321837395, 40.23250395251859, 41.341303087049916, 39.54447315585229, 42.06059125161941, 39.97790290463356, 40.69291568571522, 39.57539712229083, 41.83941271997268, 46.86012498794064, 50.55799830344416, 52.45792381225094, 52.982952671666304, 54.415563075773186, 50.08337190074306, 52.25954994078606, 53.885607719421394, 53.842034109177135, 48.36566402066139, 39.328880079330936, 39.35368514830066, 40.773175224181145, 39.07598134010069, 40.85239533455142, 40.02957620928365, 40.160744190216064, 43.8484428774926, 51.43852726105721, 46.087900515525575, 40.9974955743359, 41.14366662117743, 43.16132207070628, 41.716140470197125, 42.09244481978878, 41.59226417541504, 41.05588789909117, 41.92435164605418, 42.37291782133041, 44.059042776784594, 54.39818305353965, 58.8804558784731, 56.53849494072699, 54.34711771626627, 50.955232420275294, 53.19935767881332, 51.916330783597886, 53.88426626882246, 49.597994281399636, 40.32786853851811, 40.55614656017673, 39.90790820890858, 38.0997504726533, 40.380526358081454, 39.156233033826275, 40.316309313620295, 42.53112269986061, 42.567130058042466, 40.96128425290508, 42.93593091349448, 40.06539137132707, 39.54051156197825, 39.002181945308564, 39.819278332494925, 40.059923587306855, 38.06541012179467, 40.79591320407006, 38.457458865258005, 40.358721902293546, 38.90367554080102, 41.439691820452296, 40.72809934616089, 40.816105565717145, 41.74466786846038, 44.017802976792865, 48.25564938206827, 53.69073260215021, 54.74225728742538, 54.47690894526821, 57.136746606519154, 51.169436977755645, 46.10989324508175, 42.78207202111521, 42.057759300354995, 43.11161387351252, 45.35198150142547, 52.43504070466565, 58.30919011946648, 57.40722540886172, 61.919625959088734, 56.32247824822703, 56.778187059587054, 11.464510444671879, 0.32359701010488695, 3.2848107189901414, 4.160650728210326, 1.0829543923178027, 1.7093045697096856, 62.59285373072471, 62.09574430219589, 66.33128827618015, 67.67978345194172, 67.33436384508687, 54.798017701795025, 43.476060898073264, 46.18550085252332, 66.36742899494787, 50.408920780304946, 1.639711304057029, 0.26212320392650945, 0.0895860230910682, 0.04726294413088791, 0.08046356300192495, 0.062429045041602474, 0.037644591497918295, 0.042258474765525716, 0.17200279620385941, 0.10409330753909965, 0.14147318118522245, 0.1148769373614942, 0.2122320189711548, 0.17503440530309755, 0.10628432666342105, 0.1981372269050729, 0.2153505484062818, 0.3305030475941397, 6.566263889112781, 73.52637429391184, 64.71487168342837, 61.98643569023379, 88.21816090614566, 76.56712901207709, 55.25003948519307, 71.99607726066344, 70.89185945449337, 67.32017270980343, 67.274045636577, 62.326764060604965, 62.53302581848637, 1.3912944856189913, 2.6111245203402738, 6.328248583501385, 4.351366662210034, 0.2625937351296025, 17.180956063732026, 70.36770528362644, 59.648499104284475, 63.05031976392193, 46.16577917529691, 50.19973685664516, 52.641043586115686, 57.890720290522424, 59.4000247986086, 57.201501015693914, 57.78386315991802, 59.87900503220097, 57.62521505355836, 48.06253148663429, 42.216642748925, 42.107844045085294, 50.02166909556235, 56.88723287274761, 55.10157777417091, 58.62366222566175, 49.50995276051183, 51.55733193120649, 47.40340855813796, 43.818232782425426, 41.25910589771886, 44.34628186687347, 41.8162158227736, 43.79782076804869, 40.35097129883305, 43.01420965502339, 42.31752610975697, 43.01860270961639, 43.42696459062638, 44.18155016437654, 43.089099468723425, 42.53836731756888, 40.94187636529246, 44.879990931480165, 40.668232210220836, 41.62015614971038, 42.16809165093207, 44.338178250097464, 49.203976508109804, 52.47783768561579, 54.96245522652903, 54.96791908817907, 56.60918389597247, 54.127716018307595, 56.60777576508061, 57.52219400098247, 56.28474504716935, 49.944606288786865, 40.586882252847, 39.842047691345215, 43.34240221208142, 41.15983463102772, 42.29688659791024, 40.07875488650414, 40.682999933919604, 44.612673559496486, 52.979332323997255, 46.85767350658294, 40.50792101890811, 41.220835331947576, 44.313184907359464, 44.50323943168887, 41.6954303556873, 42.723699308210804, 41.17517109840147, 42.17272397010557, 43.065353439700225, 44.46752625126993, 58.55132979731406, 61.58364357486848, 59.052989175242764, 56.711173365193034, 51.61374345902474, 54.053261587696696, 54.35233446859545, 55.655961651955884, 51.700345470059304, 43.098532768987845, 42.84563795212777, 42.74620979062973, 39.158892400803104, 41.32758655855733, 41.136814240486395, 41.82593937843077, 42.82000134068151, 44.89337798087828, 41.563117042664565, 44.332294694838986, 44.2321801185608, 41.01899408525036, 43.37464409489786, 42.94992200789913, 43.85972753647835, 41.83598849081224, 43.47801423841908, 40.5257599584518, 41.949278308499245, 41.03383633398241, 43.8688313576483, 43.782919683764064, 44.19500389406758, 43.99127206494732, 45.80251670652821, 50.21064889046454, 56.7353783115264, 55.66722277672061, 57.164305179349846, 59.2994866063518, 54.34258345634707, 48.859251160775464, 45.58627251655825, 44.26751282907302, 45.88800084206366, 47.25081659132435, 54.924576897774976, 59.967191680785156, 60.10098764973303, 66.13222798993512, 60.004634626450084, 59.545736928139966, 15.557009500841941, 0.43810325284158036, 4.662912680256752, 9.845209929250903, 3.3940315679196393, 2.0495481188258817, 70.28135038191273, 65.75421348694833, 72.64934016812232, 72.020537161058, 74.93370502225815, 62.07754058222618, 51.93065920183736, 56.617487553627264, 71.9649257967549, 64.63543192032846, 2.801353099846071, 0.4350439266812417, 0.3031207669165827, 0.1861381296428942, 0.1612225907944864, 0.24662653224602823, 0.19678106741799464, 0.1575917936861515], [0.04711775514747828, 0.058253517284268336, 0.012525858361304048, 0.004361370632860569, 0.050506625519765, 0.040138311113321015, 0.05246191555934568, 0.036270570670885426, 0.040476335918590914, 0.07937013336847867, 0.3294808105114968, 44.88681585558, 53.277059831926906, 36.98409503506076, 65.28916551220802, 60.18318876143425, 46.00673883192001, 57.49367836982974, 61.168794093593476, 57.344287057076734, 59.734426467649406, 50.726499403676684, 57.243784166151485, 6.58094532066776, 1.2964752316474915, 0.820999819665186, 1.4704254846419058, 0.2916538402918847, 0.4995091529863496, 49.438608769447576, 57.26458841754545, 57.49759681763188, 48.91152458806192, 49.73340234448833, 51.798930321970296, 54.7124158951544, 54.56582907707461, 53.71895405554003, 54.07662322444301, 58.447598795736994, 49.89286238147367, 39.22384292848649, 37.830138514118815, 40.77997269168977, 52.39609156885455, 56.87617571123185, 56.09798139141452, 54.073587309929636, 51.53670026410011, 47.743050513728974, 44.926753428674516, 43.217925794662975, 40.926018222685784, 39.25456685404624, 38.19436588594991, 39.014780598302046, 38.9274529487856, 38.61626386642456, 39.329931274537124, 38.84229044760428, 37.238798064570275, 41.87249791237616, 40.47034863502749, 39.39226558131557, 39.33279068239274, 40.01067038505308, 38.28806346462619, 38.44584472717778, 37.02482884930026, 38.42814307059012, 41.0344756803205, 45.84890265618601, 49.09599757963612, 47.638574261819166, 49.6593911417069, 49.416161044951416, 51.22606815830354, 51.20050999426073, 50.57853975603658, 46.77836318169871, 44.07004502511794, 41.55855140378399, 41.193241457785334, 40.02286503391881, 40.68876581807291, 39.866131044203236, 39.462358336294855, 45.20224109772713, 50.6380303444401, 45.69357287499213, 39.681359952495946, 41.741416223587535, 41.50687417676372, 41.3765142040868, 41.490878751201016, 42.26514677847586, 42.83835411071778, 40.50564996657833, 41.8089751274355, 45.36034007226267, 51.60096045463316, 53.70718694502308, 54.09777656678231, 50.034781579048406, 50.705961873454434, 50.034087319527906, 52.50674947615593, 46.30722768845097, 51.10474924887381, 44.916912201912176, 38.21225581630584, 38.78577301579137, 37.03312466221471, 38.68124185069915, 36.29902955024473, 37.69533449603666, 40.467846162857555, 41.13640631398847, 38.46501335020989, 37.9493668002467, 38.36289444277364, 38.34072520655971, 37.55894191803471, 36.117157090094786, 35.89563731224307, 37.59192512881371, 36.18637123415547, 38.77004431140038, 36.63123469198904, 38.90965323294363, 36.93510463160854, 39.16180279947097, 38.7638783454895, 39.568580042931345, 40.214735615638, 50.220156715762236, 52.17247332296064, 55.46819779180712, 53.708912787898896, 55.29069485202913, 55.070681264323575, 53.24542591648718, 45.161879908654, 40.930081798184304, 39.52371989527057, 41.95536582700668, 44.48995828628541, 51.79032856418241, 51.776737551535334, 61.04270950440438, 54.26534022054365, 48.603202758296845, 2.2494876288598586, 0.14291192495053814, 3.882464223331021, 2.037977984836025, 0.9046215035261647, 3.0356465664602097, 57.13368323541457, 54.937681536520685, 60.51819447548159, 63.12615094646331, 64.7411358741022, 47.871535593463534, 28.892388536084084, 35.16216585713048, 59.89789124458068, 37.03322664383919, 0.3575499656219637, 0.018598260996382565, 0.16838286222229082, 0.014248466430862826, 0.04614699534290741, 0.05377496727892468, 0.07527838115610423, 0.036947236982204264, 0.04019546127247234, 0.04641551299080734, 0.04438997651900976, 0.061003206027371276, 0.04436899337076372, 0.025201975292856657, 0.04335293861766977, 0.056902808512771325, 0.04210541805913372, 0.0668636713958075, 0.9683817144363158, 55.13101908468432, 56.49162653953799, 44.04699717798541, 76.30308289681712, 66.29805011133995, 51.27995760210099, 62.46348219533121, 67.91118760262766, 59.38471186545588, 65.59925633092081, 53.499752398460146, 64.2747817500945, 6.444789065468696, 0.9511705992683288, 1.8470333276256439, 3.6055907318668985, 0.6701894056412482, 0.5436804037420981, 52.513339058045425, 59.43786390366093, 60.318785098291215, 50.83155224400183, 51.80212705366073, 54.82786301643618, 57.15536609772713, 55.51142231110604, 56.64949017186319, 56.64088449170513, 60.285158618803955, 52.10075278435984, 41.05380904289984, 37.18693256378174, 43.725515796292214, 52.3803157960215, 58.743918172774784, 58.195915991260165, 55.47550516743814, 53.14667632502895, 49.8842723907963, 47.066751526248076, 45.14839087763141, 43.468004349739324, 40.4650063668528, 38.88135333215037, 39.61755867927305, 39.96163291315879, 40.931203596053585, 40.129702552672356, 40.96280221016177, 40.22383551443777, 44.360978987909135, 41.56537632788382, 40.08211635774182, 40.70133309210501, 41.49848030459496, 40.74351033856792, 39.97114858319683, 38.8774388067184, 39.66820040056783, 43.90969068773332, 51.20397736949306, 52.578885785995, 49.79876472103981, 52.75376073775753, 52.551240921020515, 52.47937133235317, 53.83908840917773, 52.24049506648895, 48.229914711367705, 43.433236460531916, 40.77306147544615, 42.826653680493756, 41.01960989736742, 41.55271883933775, 39.57210625371626, 42.352584254357126, 44.812353580228745, 52.117948455195275, 45.59297584718274, 40.563744191200506, 41.425877232705396, 41.77809822943903, 41.286656625809215, 41.95298102594192, 42.08666716852496, 41.80286407470703, 40.63428801874961, 41.13036586392311, 43.49237011324975, 53.90055979451826, 54.60418593498969, 55.17980160251741, 53.06422418163669, 53.541258919623594, 53.29880545216223, 54.67722046759821, 47.84445162742369, 51.62823269444128, 47.02830053144886, 40.63625312620594, 40.25495167701475, 39.22099528774139, 40.04818785575129, 37.685838437849476, 40.29615225330476, 42.04088526387369, 43.63568567460583, 41.34743767399942, 40.275038134667184, 40.859785079956055, 40.469003262058386, 39.45513333043745, 39.04523780269008, 38.69647633644843, 39.76002308630174, 39.574016447990175, 40.08142602059149, 38.9384473523786, 41.18327863754765, 39.51679691191643, 41.42866603789791, 41.45735033096806, 41.604015596451305, 42.41861343383789, 51.32485305109332, 54.82312479326802, 59.271218084519916, 56.84504778154435, 57.17358550717754, 56.37246493370303, 55.51343840937461, 47.40768001925561, 44.18646489420245, 42.26463294798329, 44.13567412284113, 46.87745401936193, 54.69376110261487, 54.640824794769294, 63.287685917269805, 56.06366065240676, 50.48828209600141, 3.238457864330661, 0.25341387207229293, 6.365259087854817, 3.7707124650478367, 1.1407590969916315, 3.5188443285803643, 62.32669345794186, 62.00170155494445, 66.38351855739471, 66.69980279860958, 69.0524325832244, 55.4131002579966, 30.141545764861572, 38.6737540460402, 66.61611510861304, 46.361579971928755, 0.6984530857974484, 0.02029255828669956, 0.05903690347387906, 0.017040110936748887, 0.0526308877423646, 0.061835625674575574, 0.10715509284167521, 0.02131252008820734, 0.13659522357967593, 0.14891273762670257, 0.17523663719334912, 0.16006284092943515, 0.18481164840200257, 0.1629045215104857, 0.1623816511804058, 0.3202796348881337, 0.1508291678563241, 0.22002748454049711, 1.0241783494430206, 61.50227400564379, 66.27516700375465, 50.91525562347905, 74.52688463272588, 68.61281333431121, 61.1986158740136, 68.0773784268287, 72.8406733851279, 66.14374406876104, 73.42764823667466, 62.00657706106863, 71.4614111377347, 9.10523126202245, 3.3278996713699835, 5.681233031134452, 5.041936212970365, 0.714187796317762, 1.1113016067012664, 55.09512547523745, 61.207923658432506, 64.83292718087473, 54.97812509536744, 54.86742796436433, 56.74297986492034, 59.62203095036169, 58.798847044667895, 58.03855834468719, 58.71932098942419, 63.66226050161547, 55.006750552885, 42.33711834876768, 40.25714428194108, 46.09256421366046, 55.18316699612526, 62.167151051182906, 60.23713704078429, 57.60332822799683, 53.28053505189958, 54.06185942311441, 49.10769016511979, 47.5811311506456, 46.927393636395855, 43.16657412436701, 41.717262268066406, 43.19180280931535, 43.49735544573876, 43.5285343662385, 42.976605892181404, 44.20033831750193, 40.80264791365593, 46.47475211851059, 44.92066591016708, 42.38843079536192, 41.3504578990321, 44.08427146173293, 42.14563215932539, 42.88861536210583, 41.88916406323833, 42.00461902926045, 47.9756784439087, 51.46945122749575, 54.62085600822203, 52.00135992419336, 56.71744915746874, 55.5208359995196, 56.28273679364113, 56.05427049821424, 56.02739441779352, 47.0984991904228, 44.0975369176557, 41.68181188644902, 42.43222013596566, 41.81890656871181, 41.79718056032735, 40.73239041912941, 43.55592819952196, 47.731459909869784, 53.95026799171202, 48.4627583719069, 41.41413757877965, 43.162247750066946, 41.9236691536442, 41.24768003340691, 42.106016220585, 43.16672317443356, 41.31989871301959, 40.415235411736276, 42.22795878687213, 46.39493188550396, 56.49345828640846, 56.423369453799346, 60.8237628013857, 56.621872763479914, 57.126834777093705, 55.87566537241782, 57.17569574233025, 50.00815653031873, 56.09913849061536, 50.8717369264172, 42.41754262678085, 43.08054085700743, 40.96866615356938, 43.23332109758931, 40.96208441642023, 41.7747877490136, 44.10902946226059, 44.67110510795347, 44.91944997541366, 41.66045458086076, 43.74652401093514, 43.59539901056598, 42.11385703855946, 41.15557101465041, 41.46252785959552, 41.446434374778505, 42.84392387636247, 43.49871650818856, 41.77014366272957, 44.41220121998941, 42.406461931044056, 43.53244104693013, 42.16849957742999, 44.18759061444191, 44.934845278340006, 54.481564798662745, 56.704842659734915, 60.565149168814386, 58.520119497852946, 59.47504797289449, 58.997522938636045, 58.20310961815619, 49.21245667242235, 45.89631626682897, 45.44727156239171, 46.16361010459162, 49.2664167188829, 58.701521273582216, 56.70692151592624, 64.90754242866271, 58.91236828219507, 55.4935049241589, 4.4522230567470675, 0.3722627761383211, 9.396799668189018, 8.993128941905114, 2.749884739037483, 4.190664214472617, 67.3164935265818, 66.33708553929483, 72.05583849260884, 72.79861773214033, 74.05183069167599, 61.54758130350421, 39.914446799985825, 47.022970030384684, 74.67037277836954, 57.72716529907719, 1.3744939935784186, 0.16112502183645003, 0.2063041072218649, 0.051417094204695, 0.12047566112972076, 0.23348433987027217, 0.16745773444492973, 0.2997596940446285], [0.04645377142174591, 0.020419439683938702, 0.029009512715762662, 0.022919889381756226, 0.05156391495538335, 0.10005993888743463, 0.04206341728868504, 0.009483759603162688, 0.017264496174550826, 0.06665033889153311, 0.03579885586194935, 30.8533755425484, 60.54975778825822, 40.44752828536495, 39.566210931347264, 37.46631906878564, 45.898402967760646, 54.097513767980764, 63.16870474046277, 54.85456259019914, 58.722451040821696, 50.023979371593846, 61.101262646336714, 15.519426330443352, 0.7897639022238794, 3.3032816504278495, 2.14599417582635, 0.5067981118636747, 0.045996819127110705, 35.26097820651147, 67.19657882567375, 54.19916591336651, 54.69456518850019, 51.990083109947946, 54.37579416459607, 56.49800823580835, 54.34597630654612, 57.416541038020966, 56.95795712932464, 52.97891655275899, 43.58509102175313, 39.9445156897268, 38.95241099019205, 47.54739876716368, 55.65126265248945, 55.435689187818966, 52.750885640421224, 52.134167455857806, 52.51928537122665, 50.34065192745578, 48.280066136390936, 42.24288340537779, 42.507227620770855, 38.494399747540875, 36.78951801792268, 37.32951856428577, 38.368691705888324, 36.1120109404287, 37.59328619126351, 38.19787248488396, 39.243003706778254, 39.50472777889621, 40.01835823059082, 40.96683832906908, 39.153095137688425, 38.40141604023595, 38.36813472932385, 36.21338851990239, 37.44396940354378, 37.90438113674041, 40.484073008260424, 48.66920448118641, 49.26373774005521, 50.1038388283022, 49.01672647845361, 50.44908585086946, 50.585141105036584, 52.024545054281916, 52.47193451850645, 46.2691532411883, 41.78385234648182, 37.5850139125701, 40.32678204198038, 40.65688087094215, 40.642313188122166, 39.4758120659859, 39.637700050107895, 43.4846979571927, 48.3211451192056, 45.074779756607555, 40.36492316953598, 39.59527177195395, 40.549278490005, 42.85775807596023, 42.44230454967868, 41.530565292604514, 40.66208193379064, 40.759015467859086, 42.89642480111892, 45.30662321275281, 52.26211909324893, 54.42613386338758, 51.897613233135594, 51.22296556349724, 51.48002985985049, 50.78608412896433, 50.93880553399363, 46.41396714795021, 46.19052148634388, 47.398995891694106, 39.213731058182255, 38.58250010398127, 37.36092890462568, 38.91084171110584, 36.69419657799506, 37.267450978679044, 37.93187695164835, 41.01038840509231, 38.92064371416646, 37.34085813645394, 37.84702039534046, 38.28184650790307, 37.47850587291103, 38.01607062739711, 36.86481183575046, 36.302485158366544, 35.83001998163039, 36.931837297254994, 35.80296347218175, 37.64832881189162, 36.66982689211446, 39.34170622979441, 39.35119836561142, 40.41805951826034, 45.11195205873059, 50.85019134706067, 52.25480779524773, 55.424604569711995, 55.02162418057842, 53.181679556446696, 54.69672249209497, 54.58444464591242, 53.28956827040642, 44.70635937106225, 37.86061925272788, 41.64866393612277, 40.30777423612533, 48.31427312666371, 51.31243482712777, 58.91427455409881, 58.149510429751494, 44.0655029204584, 1.6618375167731316, 0.2745922961302342, 2.1135458782795937, 1.848011836409569, 0.6063001242376144, 8.102714140569011, 65.60929759856194, 55.370334656007834, 63.06793120599563, 60.226699613755756, 62.730042549871634, 41.37534533777545, 42.05402912632112, 33.09919918737104, 58.01048201899375, 25.34057055750201, 0.16518856669145246, 0.07014869471951839, 0.053378689147892504, 0.024782310412716002, 0.025546981074336558, 0.03376818277061947, 0.12199832982714139, 0.026522594045907743, 0.0660568275939553, 0.059593807259995135, 0.033510076257610516, 0.03257459097151314, 0.1461395453060827, 0.04193420123849665, 0.030769387132398067, 0.03241224544903925, 0.017306202001148657, 0.03085183159958932, 0.060564444490498116, 38.65626027507167, 69.10117195498559, 43.60320060483871, 47.56602218074184, 46.77738258915563, 54.51122968427597, 63.39850464174825, 68.88295481281897, 60.11708505692021, 65.85266497827345, 54.28854496248307, 67.03511837990054, 16.443860338580226, 1.1177751109484704, 2.7506189577041136, 4.630543810705985, 2.287336784985758, 0.06246270694499535, 37.21406359826365, 67.32647203630017, 54.50444790624804, 55.35282127318844, 53.99500654589746, 56.09501607956425, 57.833791009841434, 56.3514292624689, 58.17155415011991, 56.81475923907373, 54.87857534039406, 45.41741448064005, 41.88308438947124, 41.29198712687339, 48.954807942913426, 56.49054004300026, 55.85961895604288, 54.835492026421335, 54.663700057614236, 55.32144231180991, 52.11261403176093, 48.934180198177216, 44.975018193644864, 44.94594558592766, 39.230934573758034, 39.16747454674014, 39.32180412354008, 40.88209552149619, 38.857042481822354, 39.572321984075735, 39.33553634151336, 40.64649443472586, 40.977515020678126, 42.253905265562, 41.77871011918591, 40.961099901506984, 39.50479445918914, 39.48317043242916, 39.94645334059193, 38.65094154111801, 39.325655891049294, 43.392216313269834, 51.746107762859715, 52.452761973104174, 53.949091280660326, 51.9814617403092, 53.59111616688391, 54.1412325059214, 54.75256527623823, 53.46879705306023, 48.17519372509372, 42.26400929112589, 38.624991140057965, 40.17128359886908, 40.89009323427754, 40.48918385659495, 39.679826305758574, 39.205192058317124, 44.55787804818923, 51.14609495286019, 44.52140785032704, 41.690911785248794, 41.743812791762814, 40.44957184022473, 43.00233664051179, 43.03300173051896, 42.987894473537324, 40.04663067479288, 39.846040664180634, 41.425237886367306, 44.85069867103331, 54.513889051252804, 56.15616975292083, 54.99115913145004, 53.93858717333887, 52.89898649338753, 53.255686836857954, 52.96889489696872, 48.43277577430972, 49.18011280798143, 49.296646425800944, 41.70589916167721, 40.5661956725582, 38.95154022401379, 39.777057939960116, 38.809581802737334, 38.18571705971995, 40.07665249609178, 41.35430966654132, 40.51813879320699, 40.17067563149237, 40.27062546822333, 40.8001022954141, 39.83701921278431, 41.068176684841035, 39.73921491253761, 39.111533703342566, 38.13944485879714, 39.244498129813906, 38.59804053460398, 40.132091276107296, 40.662121157492365, 41.057390166867165, 41.06376009602701, 42.71510539516326, 46.37842262944868, 54.19869522894583, 54.57073203979, 58.63632363657798, 56.76525108275875, 56.612867001564275, 57.995953559875495, 58.40865750466624, 54.64798312033377, 47.5505131290805, 40.434772737564586, 43.71090496740034, 42.49377781344999, 51.3641591225901, 54.74089622497559, 60.777125820036865, 58.43583560759022, 48.5296190938642, 2.5678267017487557, 0.03615831197690099, 8.311824029491794, 5.083651110049217, 1.0933316354790041, 8.886710136167466, 72.03738766331827, 59.81625103181409, 69.30693164948495, 65.98236207039126, 69.39196863482076, 46.87181757342431, 39.91954980358001, 36.84126976997622, 65.71272265526557, 30.878900366444743, 0.14575100083264614, 0.016830821461494894, 0.03187142759411326, 0.04806347919868366, 0.020406822215825803, 0.026708671057056037, 0.044449378976658474, 0.07583929541250391, 0.11801878651303631, 0.15552481185765038, 0.24408538795767293, 0.08005946694362549, 0.24482000499002396, 0.28271016214163075, 0.1292260706184372, 0.08247331806248234, 0.12289984677467616, 0.1697681790157672, 0.19442389148377603, 44.16581753761538, 77.65652810373615, 54.16455491896599, 49.48684215545655, 51.34489244030368, 63.26406932646229, 70.32299810840239, 73.50811173838954, 64.8445373965848, 70.37052939015051, 61.04138374328614, 72.32495231013145, 20.145934512538297, 1.9234270025645535, 9.412246942520142, 6.117631033543618, 1.6809259763648434, 0.1595972126890575, 41.62619267740558, 70.19146534704393, 58.41829084580945, 59.47805643081666, 56.73498215213899, 57.58933713359218, 60.72509557970109, 57.964790328856445, 59.663580617597034, 60.06880852483935, 59.57209133332776, 46.87719514293056, 44.99424957459973, 43.69911824503253, 51.418409424443404, 59.19233922035464, 56.27662574091266, 53.729469929972005, 55.83323709426388, 57.109152732356904, 55.81016179054014, 52.02364290914228, 46.63836986787858, 48.76860518609324, 41.74595832824707, 41.681894256222634, 42.16152952563378, 42.67930984497071, 40.85802393574869, 43.36346926227693, 41.668342467277284, 43.566412694992565, 43.82996459161082, 45.12533518575853, 45.349549631918634, 41.592232796453665, 41.35228964590257, 41.664294581259455, 41.3856533265883, 39.65029085836103, 42.03350728557956, 46.23617395277947, 53.67023037325952, 54.25508322254304, 56.662198651221495, 54.43438260785995, 55.858328496256185, 56.529822580276004, 58.54894107387912, 56.72196380553707, 49.48848170618857, 41.69672081547399, 37.9970863557631, 39.741921347956506, 41.597794717358006, 41.87353734047183, 39.46722992004887, 40.71792864030407, 45.55430912202405, 53.200149997588134, 48.325455804024976, 43.09078608789752, 42.668268372935636, 41.791548036759906, 44.7339532452245, 43.097536486964074, 44.50939363048923, 40.770711975712935, 40.51191399174352, 42.44082189375355, 47.37501059809039, 56.52023630757486, 58.89154834132041, 57.398407920714355, 57.333512306213386, 56.49190110545005, 55.9186270929152, 56.874351809101725, 52.14542465825235, 52.74327231991676, 54.6862615308454, 43.51385293468353, 43.84601885272611, 41.047568551955685, 43.59151194172521, 41.42376699755269, 40.58747060837285, 41.24304379186323, 44.84840800685268, 41.68658541094872, 42.283519160362985, 42.38686576966317, 43.172575350730654, 42.5946964756135, 43.313145252966116, 42.357895143570445, 41.90786984659011, 40.682799893040816, 41.47704847397343, 41.07202845235025, 43.21933000318466, 43.114116345682454, 43.925529218489125, 43.683366006420506, 45.275742392386164, 50.35780445221932, 56.146144174760394, 57.15864912156136, 60.85426315184563, 59.91263151168824, 58.074848113521455, 59.97665636001095, 59.583501508159024, 58.71622623935823, 48.208981021758056, 43.44891809648083, 46.90302395051526, 45.287434977869836, 52.3773544065414, 58.71611641299341, 65.17938621582525, 61.35831125320927, 52.22726491189773, 3.5506312164568135, 0.48709056129859346, 11.2602206583946, 8.920336615654731, 2.6073600255673934, 11.030077549719042, 77.31378355333882, 65.49083025224748, 74.613066950152, 70.94927510907574, 73.55551750429215, 54.10880234933669, 55.72405007577712, 46.00126320315946, 72.91384127832228, 40.3391061290618, 0.3597090771842388, 0.12867068751685082, 0.27776996755311567, 0.11023561665487867, 0.09589888636142978, 0.16159912300927026, 0.174281723917492, 0.13863644953216278], [0.01630972079452007, 0.04337430480987795, 0.04156467106734072, 0.04851459773377546, 0.04471874315171473, 0.11420024423709801, 0.023510096925160578, 0.05703655597303183, 0.06779191715102043, 0.13724069862115768, 0.25194413238956087, 9.421795952704645, 60.859813305639456, 43.357056187045195, 46.14484940805743, 44.07192384043048, 37.63381996462422, 44.3868274073447, 64.6719217300415, 56.13314151763917, 59.624411829056285, 51.82611234726445, 59.85009324166083, 31.348243336523737, 0.1963954800439458, 0.9242815872834576, 3.3577577337141964, 3.6716601156419326, 0.09596654724690223, 15.106851823868292, 65.94284026853501, 58.255124169011275, 56.19148677395236, 57.13531101903608, 58.25253540469755, 57.81501070145638, 59.273948054159845, 55.95354403218916, 54.52404406762893, 45.642680122006325, 40.65256234138243, 37.5630094159034, 43.29299211502076, 51.388854365195, 54.79918264573621, 52.554971095054384, 47.60473205197243, 55.33133060701432, 54.08695474747689, 51.96042214670489, 44.67772606880435, 44.20549623427853, 41.20032918068671, 40.62302689398489, 39.666670676200624, 37.788596691623816, 38.55716159266811, 38.36595389150804, 38.40959418204523, 38.164202859324796, 40.13368768076743, 40.313708782196045, 39.79276703250024, 39.61670752494566, 39.61036113000686, 38.85991365678849, 38.98557462999898, 39.13158485966344, 36.267611365164484, 38.858466302194905, 42.149880086222005, 50.52514845325101, 51.06871835647091, 49.33508957585981, 50.311869575131325, 50.25943140829764, 51.14251382889287, 51.41193751365908, 48.2523153674218, 46.75196955280919, 43.312792239650605, 41.38274292792044, 41.34994406853953, 42.02117143138763, 39.827836944210915, 38.38916647818781, 39.3606512777267, 42.66967258145733, 46.89989389911775, 44.219228452251805, 40.709523001024806, 41.07574293690343, 40.14677663003245, 42.36622233544627, 41.51599368741436, 42.64662081195463, 41.11384484075731, 40.80100051818356, 43.30384923565773, 45.91891304139168, 51.20923726789413, 51.86848963460615, 54.158875326956476, 51.20557769652336, 52.441245894278254, 51.31806342832504, 49.82109869680097, 49.067321131306315, 45.53483847648867, 45.872625150988185, 43.041517196163056, 40.39575692146055, 38.39950976833221, 36.97865470763176, 38.848272062117054, 37.63693040417087, 38.66002575043709, 38.15540890539847, 39.329950886387984, 38.73613934363089, 38.318756011224565, 36.02095311687839, 35.79187885407479, 36.00600104178152, 37.44780548157231, 36.360995154226984, 36.41837550747779, 37.82217610266901, 36.68149986574727, 35.928647979613274, 37.73662136447045, 38.69727649996358, 39.22437637082992, 41.3428210443066, 48.70649053204445, 51.24649586216096, 54.92025836821526, 54.38658852731028, 55.4819300097804, 51.885449963231245, 54.29407942679621, 57.30779724736368, 56.67955121686382, 51.80760660479146, 41.50008063162527, 40.093903080109634, 41.04827457858671, 44.09659947118452, 52.12627956944128, 56.607662016345614, 59.126153146066976, 44.67432929623512, 1.5087226489859245, 0.11898911347792995, 6.341133569517444, 2.278051063899071, 0.6617604772890768, 17.152336489769723, 63.07601913329094, 52.64826466960292, 60.73814530526439, 59.32134205295194, 59.69568129508727, 34.586361915834495, 30.38613496288177, 34.31281974238735, 62.29661280109037, 17.262751210120417, 0.04002675338978729, 0.016853794523124254, 0.16300878607698027, 0.02754997349374237, 0.08435420947329653, 0.03236104779305958, 0.0454167143682078, 0.008976440857945672, 0.018565482009322416, 0.031169478466073354, 0.07717985734944383, 0.0166530488434458, 0.02656621317709646, 0.047500833583575104, 0.05255465816345908, 0.08778364803161352, 0.08638568312650727, 0.1324552384715888, 0.2453292236332932, 13.821815694532088, 70.38570896271737, 44.90002247595018, 44.627260854167325, 49.70447094209733, 47.68691747419296, 51.032765911471465, 70.15657194199102, 62.692882014859116, 65.48857096702822, 56.06838318609423, 67.26817777079921, 33.1148180653972, 0.17289351131166183, 1.6919480816971872, 3.97495273140169, 6.185923910910084, 0.15638042481676226, 17.75330439690621, 69.45453828380954, 59.02142586246614, 58.26033307660011, 59.436934301930094, 60.72558587597263, 59.64724394582934, 60.51456236070203, 58.39408197710591, 56.59166659078291, 48.27229984344975, 43.09321403503419, 40.59392290730631, 46.03025344110305, 53.88316800517421, 57.313567053887155, 54.49860749706146, 47.972799424202215, 56.71787669581752, 55.80467831703925, 52.92610183838875, 47.90910797734415, 46.56739850198069, 43.468271070911044, 41.9439713416561, 40.756967990629136, 39.91024986390145, 41.129146006799516, 40.20439624786377, 39.650553657162575, 40.47382777737033, 41.312477588653564, 41.676026390444854, 40.788950997014204, 40.45899337337863, 40.35942008418422, 40.824640643212106, 40.66481974817092, 40.6521269582933, 38.748149641098514, 40.31319887407365, 44.89273078979985, 53.88133625830374, 52.65274793870988, 51.85650287135955, 52.419974880833784, 51.26370722247709, 52.54539658946376, 53.043639582972375, 51.46612505758963, 45.65776948005923, 43.58452227807815, 40.628643728071644, 42.20576601643717, 41.63263713159869, 40.50825442037275, 38.54131521717195, 40.337419509887695, 44.50577328282018, 49.67013451360887, 45.991876971337106, 41.95541681781892, 41.24768395577708, 40.87117956530663, 42.524917510248, 40.95989573386408, 42.70387172698975, 41.51425607742802, 41.55146368088261, 42.715532933512044, 46.79521368395898, 53.25654975829586, 56.090701472374704, 55.55074799445368, 54.21441608859647, 56.72527820833268, 52.91076144864483, 52.34065278883904, 52.30620653398576, 47.53985604932232, 46.64366506761121, 45.3866748655996, 42.236380115632095, 39.63018086648757, 39.60381469418926, 40.30071789218534, 39.2036662563201, 39.66108522107525, 39.80737786139212, 41.39128585015574, 40.22718521856493, 41.35425475335891, 39.41200687039284, 38.23596654399749, 38.198276489011704, 39.27685376136534, 39.32947235722696, 38.29910493666126, 40.45744403716057, 38.35174706674392, 38.96899084891043, 39.71754381733556, 40.88898320351878, 41.35161892060311, 43.12971953422793, 51.732897220119355, 53.90726312514275, 56.39475968576247, 56.19626422082224, 58.06518339341687, 56.27238173638621, 55.18717958081154, 60.27523109989782, 58.812143879552046, 56.77765753961379, 42.96716866954681, 41.65529666408416, 43.60864093226772, 48.80298083828342, 54.716738347084295, 60.83370208740235, 60.30188752758888, 50.21009975864042, 1.832066666214697, 0.10016974226962175, 6.77360478908785, 2.39094129012477, 0.6550682396177323, 18.67529476842573, 70.71377600392988, 56.99585899229973, 67.28191391114267, 66.0633276354882, 66.31511242158952, 48.01190545482021, 36.674678864017615, 37.056702029320505, 68.1994818102929, 22.341414536199263, 0.1438172110506604, 0.04525238467801002, 0.08427105828999512, 0.008613939543495016, 0.014982524219029134, 0.030325904578691533, 0.04334637324415869, 0.04548045288350794, 0.1450488812500431, 0.09687821485943372, 0.24997452033623574, 0.15822409201533566, 0.2063259254059484, 0.280378129213087, 0.1405555457477608, 0.17626265875033795, 0.3773090585825905, 0.28699691437425157, 0.5430207101087416, 14.769226947138387, 80.93879099815123, 53.98943678025277, 57.6929622311746, 55.31561366973385, 54.21363161456201, 55.067951294683645, 78.07305243707474, 67.09617399400281, 70.49826529718214, 61.56387090682984, 72.862732794977, 38.70124986094814, 0.32676793995403475, 5.397285299916422, 9.61134547187436, 9.574099625310591, 0.1749639711793392, 19.03073799225592, 72.78284980404761, 61.664652286037324, 61.43598987210182, 61.27217208185504, 64.43195896763956, 61.28894805908204, 62.72744594081756, 61.830717594392844, 61.04994627737231, 48.85843138540945, 44.177953350928526, 42.39445947831677, 48.22336435317994, 54.56291083366641, 59.8801621314018, 53.962125316742934, 48.483448874565866, 59.864700148182536, 58.76211012563398, 55.50416200391708, 50.287515578731416, 49.56825879312331, 45.38316826666556, 43.47796324760684, 43.359821458016675, 42.48475636205366, 43.99595537493306, 42.914279430143296, 41.78127534927861, 42.959167034395286, 44.48414141131986, 43.8553148700345, 44.02802859583209, 43.33521250755557, 43.02036777619393, 43.32490844111289, 43.09356704834969, 41.78827678003619, 40.309374563155636, 44.21392933014901, 48.769934869581654, 57.00852040321597, 54.536799615429295, 53.94749095363002, 55.73245179268622, 52.956370769008515, 55.709443169255415, 55.15596535898025, 53.254008062424205, 46.67046270062847, 45.04041194915772, 41.85609456031553, 43.08482016286543, 42.88148841550274, 40.375215468868134, 40.094150189430486, 41.40157030474755, 45.88014041223834, 52.444968223571784, 49.072384911198775, 44.66023622020599, 43.67089679164272, 41.35624339503627, 42.48271672956405, 41.718117344763975, 42.921912362498624, 43.04543172159503, 42.27582739245507, 44.09711330167709, 46.82380384014499, 54.7840658310921, 56.816194826556796, 60.522846406505955, 57.8747837005123, 59.74718986019012, 56.71544482631069, 56.457800019171934, 54.48091760758431, 51.14343558588336, 48.9156509214832, 49.02468888990341, 45.0398196712617, 42.32512374078074, 42.39403193996799, 42.33344308791622, 40.622469917420425, 42.77123451232911, 42.32257027779856, 42.71837665188698, 43.15265363262546, 43.555128036006806, 41.01144744503883, 40.82003970299998, 40.52028825206142, 42.82941895146524, 42.17520290805448, 41.52993771337694, 43.08841305394327, 41.737819410139515, 41.36370766547419, 42.51860641664074, 43.02549823637932, 43.98656522074054, 46.45627775499898, 54.71375342338316, 55.8439883109062, 60.547106266021736, 57.845538508507516, 60.59403742513349, 57.87309708133821, 58.58896101674726, 61.520877807371086, 62.58925299490652, 57.63025922159995, 45.677338184848914, 44.88654128966793, 46.54769643660515, 50.38666525194722, 58.74141177823467, 61.56759715849354, 63.009295694289676, 53.33270257519138, 2.820385175366556, 0.3903594583032593, 13.993101677586957, 8.60559190473249, 1.5380352567280493, 22.297366319164155, 75.89123402872394, 61.67490928403793, 71.5384307984383, 69.90205718624976, 73.87108002939533, 47.62120600669615, 43.958080968549176, 48.04932878863428, 76.41832213247977, 29.699594666880948, 0.24414901922066368, 0.14485035722534503, 0.25150203837021706, 0.18327057061176147, 0.121146708186115, 0.11479249148960076, 0.17615534515390474, 0.1344089618613643], [0.02136879116146555, 0.06403194995777262, 0.04974883815814411, 0.031727862717103095, 0.09948355731584373, 0.03937571271953564, 0.05248712751293375, 0.036602865138481704, 0.012265307070206732, 0.06012895797950126, 0.014946640660655836, 0.6082544451759708, 44.8819834955277, 55.37004047824491, 47.588050211629565, 35.85855130226382, 33.69144178205921, 53.310454891574004, 66.92945757219869, 56.35353165288126, 57.44265225625808, 52.50280749413275, 59.510616025617054, 39.33161397134104, 0.11907843166902182, 1.8871116157500976, 3.7587117283575, 3.7648620047876915, 5.640518828745812, 1.540808004717673, 41.166922353929095, 64.69530690100886, 54.71860539528632, 59.01525989655526, 57.3787921474826, 59.88906198932279, 57.806867860978656, 55.002934086707334, 50.01136110674951, 42.5671535922635, 40.49543611464962, 41.074679974586736, 51.12036028215962, 51.840758477487874, 56.291993587247795, 48.9670810391826, 50.51971989293253, 55.00617396446967, 50.82351922988892, 49.70831094249603, 43.26663770983296, 43.43336982111777, 41.869391395199685, 41.392309588770715, 37.569065555449455, 37.6269087483806, 37.30489392434397, 37.607610687132805, 38.61282002541327, 38.81975643096432, 38.75088353310862, 39.29221376296013, 38.23253054772654, 39.08190804143106, 38.482189409194454, 39.04196262359619, 37.86279224580334, 37.74021817791847, 36.530292495604485, 38.195864231355735, 42.52621581477504, 47.23081642581571, 48.899557436666186, 50.36102471813079, 51.516013683811316, 51.961434118209354, 50.98625444596814, 52.141623881555375, 51.119179648737756, 45.6532391425102, 43.17649772090297, 40.89755358234529, 41.048490308946185, 38.661731981462054, 38.82522421498453, 40.52533634247319, 41.46058236399005, 44.18830840818344, 44.29111373039984, 42.54842035232052, 40.50654426697762, 40.34643311654368, 38.20120257716025, 42.02532522140011, 40.01653432846069, 41.665294785653394, 41.01298501414638, 41.914263309970984, 43.53057399872811, 44.66962245202834, 51.60826783026419, 51.00937289576377, 51.50807088421237, 51.174269337807935, 51.464579643741736, 49.17127178561304, 50.99870797126524, 48.753280485830004, 47.36280025974397, 41.457326796747026, 41.14666723435925, 38.901428022692286, 39.17940247443415, 37.94211041542792, 37.48919825400076, 37.584449091265284, 38.89536011603571, 37.36937768997685, 37.22331646950015, 39.47610624374882, 37.11862448723086, 36.43468864502446, 36.248780065967196, 36.6355767557698, 36.16948150819348, 37.2443207617729, 33.988247532998365, 35.53155114573818, 37.130493579372285, 36.59680412661645, 36.54906495924919, 39.20846331504084, 38.102586346287886, 42.69005321687268, 47.6840776781882, 53.31927237972137, 51.249982849244155, 57.446441265844534, 54.0682371970146, 51.519010374622965, 52.99464917952015, 57.04137809814946, 59.109396780690844, 55.55331322454638, 50.612005418346776, 39.42944180580878, 39.056640132781, 43.430973252942486, 52.33894655781408, 55.63813840189288, 57.79443002516224, 54.12344063481977, 6.626082976018229, 0.01171763081313862, 7.0668911933898935, 3.210198658127939, 0.13781793055034455, 31.297246640728368, 65.05282309747511, 53.25970726628458, 62.53908980277277, 57.11330652236939, 49.50537143215057, 26.57286551690871, 30.187461030098703, 37.08838693557247, 54.96287492013747, 6.784795311189468, 0.38791343149158264, 0.004814964589557701, 0.010040441223780715, 0.020427784296653925, 0.06938641425222158, 0.0498657584971478, 0.03237861035872371, 0.015807870959472514, 0.03380859773906489, 0.05287711989254721, 0.0961924589148933, 0.05533293347745653, 0.06328714778646827, 0.016364896362046563, 0.08917442703199002, 0.07112218562753932, 0.06674973113882927, 0.1040774035537916, 0.028172779993544665, 1.189113341031536, 59.42704208435551, 60.59299407466766, 48.88002403320805, 43.988993167877204, 40.26584409898327, 55.04301286512806, 69.5908877157396, 61.771313298133116, 64.93726222745835, 57.09795828788512, 64.35970106432515, 42.544039064838046, 0.20188666038936187, 2.7815049261816087, 2.6788040370710435, 6.981519825996892, 7.010890043550923, 2.080557519389737, 44.723209873322524, 66.76675765745102, 57.42355423588907, 59.9217470999687, 58.20599648260302, 61.18394228719897, 58.060154914855964, 55.96187906880533, 52.49454306017969, 46.35036199323593, 41.605192307502996, 44.88094406743204, 52.417746974575905, 54.65465507199688, 57.77805020732265, 48.81607370991861, 51.03322482878163, 58.141500949859626, 53.417174739222375, 51.7343367299726, 46.40689119215935, 45.9423452808011, 43.87930800837856, 43.593100501645, 39.01746349949991, 41.18163124207528, 38.619676328474476, 39.76653029841762, 40.88828109925793, 40.173593874900575, 40.875290209247225, 41.986450610622285, 40.105850619654504, 41.04869427219514, 40.53481671117967, 42.50541548575125, 40.09114565387849, 39.74989552651682, 38.377552340107584, 40.93782455690446, 45.370518622859834, 51.78844190412953, 51.999677227389434, 53.514602491932536, 53.12399325832244, 52.46778072849397, 51.28004781661495, 53.357715529780236, 51.33647111154372, 46.82332531098397, 43.718420228650494, 40.589659290929, 40.09797450034849, 39.28694994218888, 39.38095738810878, 40.57275779785649, 40.68277243644961, 45.242398323551306, 46.219633317762806, 44.419065367790964, 42.03636669343518, 40.774955980239376, 40.38779058764058, 43.5864834631643, 40.29242992401123, 42.63985864577755, 40.918491194325114, 41.66685981135215, 41.762722538363555, 45.04964520854335, 52.4478707774993, 54.26151198725547, 53.879241712631725, 53.2658536203446, 55.76705886471657, 52.83044307462631, 52.71833781273135, 50.78051044094948, 51.01350707392539, 43.08438870214647, 41.862558626359515, 40.49607546098771, 40.100104347352065, 39.325546064684474, 40.0691411572118, 39.65491533279419, 39.331519834456905, 40.55988065658077, 40.5459640872094, 41.5213438003294, 40.48122144514515, 40.401577718796275, 37.51294820539413, 39.998307074269945, 38.280889449581025, 40.11994369568364, 37.52138914600496, 36.93643431509695, 40.13433094947569, 39.36747620182653, 38.80653019874327, 40.242678580745576, 41.36437839077365, 46.24100239046159, 51.41540881126158, 55.555603888727006, 53.53962329126174, 58.38376222118255, 55.776637292677364, 54.76764678955079, 55.14198603168611, 57.63744500375564, 59.72742895926199, 57.39986312004828, 52.59238658412811, 43.2400244282138, 42.381613716002434, 44.82640351018598, 53.72269991905459, 59.08845132397067, 62.42072836045296, 55.521271382608724, 8.847068702020954, 0.08674273372537668, 5.674786125459979, 1.2170115666043375, 0.06942346992511904, 34.60550308227539, 70.4630502577751, 59.07762950466525, 68.36230724088608, 63.94564782419513, 57.18713729612289, 35.85350321185204, 31.16011469594894, 40.216096678087794, 61.61844284303727, 10.606614543545632, 0.3873556581956725, 0.08499563190965884, 0.023498188088377638, 0.05632135926956131, 0.04350155584454056, 0.038698586755462235, 0.016674068380868243, 0.05082847820895334, 0.08484993730821917, 0.13920759872323082, 0.20803538932194635, 0.20414991394406368, 0.24529861075983894, 0.14540292112337005, 0.17466070761363353, 0.18555496819317344, 0.14500018870157583, 0.18349964622287981, 0.1983109909680582, 1.132026675247377, 66.59480094909668, 71.05862294473957, 60.47892370531636, 45.37855163697274, 48.20808279898859, 64.83892448486822, 80.02335686837473, 67.14787083287393, 70.26320549749559, 62.98618116686421, 68.11165994213474, 49.69724985861009, 0.21095640596843537, 6.840922957466495, 8.941774329831524, 9.133170304759856, 8.551011143192168, 2.5753836381819943, 48.519675885477376, 70.3440769257084, 60.846618452379786, 63.713941651005904, 61.22966927866782, 63.14953219506049, 59.84533148427164, 58.65861446626725, 55.583809652636134, 46.72523467771469, 43.69961246367424, 46.80233670819191, 56.75298583122992, 56.21350303772957, 60.19064126476165, 51.04743165354575, 52.60961363392492, 58.06611691751788, 53.61493279857021, 54.759417656929266, 49.519138951455396, 49.551482815896314, 45.53450507502402, 47.47752566491404, 42.40347308497275, 43.54469845371862, 41.64226262800155, 41.550588992334184, 43.85757415525375, 43.15947855672529, 43.02302714317076, 42.85992714666551, 42.27407801535822, 43.53738323334725, 41.8206363339578, 44.205672740936286, 42.37982511520386, 41.22311030664752, 40.723804350822206, 42.81180358702137, 48.90645296342912, 54.09846298156246, 55.50748032908286, 56.21908064811461, 57.307593284114716, 56.11826788994574, 53.69490600401356, 56.77075809048068, 54.93669309923726, 49.254500558299405, 44.54294166257305, 40.48117045433291, 42.406571757408884, 38.214621005519746, 40.27322992201775, 43.226041178549494, 43.63463055702948, 46.44225528163295, 49.03057244516189, 45.52435790338824, 44.837115503126576, 41.51587993867936, 41.27313621582524, 44.276455833065896, 40.91639272628292, 43.36524609596499, 43.13091193476031, 41.778074695217995, 43.58865645623977, 45.7502785805733, 54.825756703653646, 56.10304517130698, 56.11848362030522, 56.65644845654888, 59.130055904388435, 56.017423752815496, 54.642982098364065, 53.82061796803629, 53.40971439115463, 46.422090376577074, 44.89736703134353, 42.065015685173776, 42.8683170964641, 41.832627019574566, 43.07646943676857, 41.83252503795009, 42.23132418047997, 41.40391195974043, 41.08093615501158, 44.0959365906254, 43.390717967864006, 42.35817363185268, 40.111032070652136, 41.975256166150494, 40.295112825209095, 41.97385195762881, 39.29392783872543, 39.53392590245893, 43.4362566855646, 40.78288309035763, 41.17440623621787, 45.2039041826802, 43.54703618634132, 48.53710297615298, 54.62449989011211, 59.75946687882947, 56.326459453951934, 61.95035772938883, 58.40514306099185, 56.512422946191606, 56.85427319618964, 59.14517664140271, 61.44015150685465, 59.60607867087088, 56.161441418432425, 45.8740254371397, 44.38285796873031, 47.97268175309705, 56.398658521713756, 61.32595954402801, 62.38897285153789, 59.60059911974015, 12.350768023921598, 0.177866080775857, 20.25396639300931, 8.838983716503266, 0.3027281315336305, 39.13273019175376, 76.68150532630183, 64.04289514787736, 73.3756297634494, 67.60001028737715, 63.90887952619984, 38.51250540825629, 42.96960838379399, 50.94973717966388, 72.48116462461411, 13.651679946530251, 0.7164182766310631, 0.2402136102318764, 0.1771140582258663, 0.38901031618156745, 0.19803743629205614, 0.10487979638480371, 0.0682891541791539, 0.16571709075041358], [0.004841605775929507, 0.08963968755016405, 0.027762239220582192, 0.02145718430138884, 0.0284659790791451, 0.08188709226106444, 0.11854191731301048, 0.06107506507466878, 0.03744289969965335, 0.04047870313027694, 0.11638480524021773, 0.28418037679887587, 18.07067317347373, 58.720650672912605, 39.70966377565938, 49.64161103771579, 30.05121357979313, 44.531931569499356, 63.567143024936804, 57.216154990657685, 58.32370288910405, 56.080593524440644, 52.64828428145378, 52.08085067810551, 2.2781434847462565, 1.2125443547002732, 1.942279261927451, 6.090630417869938, 12.19593148077688, 1.0402923654164038, 22.285742375158495, 63.23682454324538, 54.70706185986919, 59.941500156156486, 55.84273315245106, 59.499186238934925, 55.32658061673565, 53.49022496131159, 44.5703786419284, 44.53696397043044, 43.148950915182795, 50.287339072073664, 53.253317725273874, 54.78658007037256, 54.381854226512296, 51.84424546457107, 54.29240457473263, 54.501925822227236, 50.67299042978595, 47.1753776458002, 42.560285522091775, 42.28369566702074, 39.51611834187662, 38.88469519153718, 37.25000819852276, 38.28177590523997, 35.32350863179853, 39.248761746191214, 39.12552479774722, 38.081487917131, 37.987935466151086, 39.25176628174321, 36.54955133315056, 39.1007040392968, 38.82538110979142, 39.42104401126985, 38.47596853010116, 36.00481648598948, 36.33349541694888, 36.28440695424234, 41.661372415481075, 48.43143432371078, 49.561304430807795, 48.39184191919143, 49.05449498084284, 49.81489350718837, 52.860096193129024, 51.06809077724334, 49.34911989396619, 44.66046371767598, 42.77763189808015, 42.41060395394602, 38.94797086715698, 39.06057427006383, 39.38087894070534, 40.19572780978295, 40.99836634051415, 42.90801148260794, 42.81785580419725, 42.21762334146808, 41.74333426260179, 39.818850794146144, 39.549129009246826, 39.54506543374831, 39.126156299344956, 40.43521596539406, 40.455745650875954, 40.94437099272206, 42.81747533429054, 43.554272959309245, 49.001711645433986, 53.01434340015535, 52.19467001576578, 50.91801304971018, 52.19624288620488, 50.178548212974306, 49.194990358045025, 48.06215886146792, 49.71761088217459, 40.13684911112632, 36.205194688612416, 35.33053359677715, 38.04105612539476, 38.35366902812835, 37.03381892173521, 39.90781014965427, 37.56158559553085, 39.31180600197085, 36.58948890624508, 38.44878258243684, 37.09326244169666, 35.75533413117932, 35.77718173303912, 36.86958536025017, 36.13252885880009, 38.90031799193352, 36.404298120929354, 38.357010887515166, 36.208826803391986, 36.884392307650664, 37.43005283417241, 37.498890430696555, 37.5353253272272, 41.30284424751036, 49.445135593414314, 50.73277519595239, 54.92026229058543, 53.22817141009916, 52.09195098569317, 53.912883881599676, 54.754177370379054, 51.0757903898916, 57.07977417976626, 54.83469578527636, 56.27670811068628, 44.333059557022594, 40.422276066195586, 41.19927014074018, 51.927882163755356, 55.791938458719564, 60.393215994681086, 55.97020626068116, 29.946298022424024, 0.16977801558471498, 3.3092267378684017, 1.1058777041973606, 0.5631400788983991, 50.25072374651509, 55.30998114616641, 56.146607014440725, 59.12026174606816, 61.744801998138435, 46.06577050301337, 33.52454100885699, 33.22954739293745, 44.94498852760562, 46.344023443037464, 0.8757524913357151, 0.0872241740205115, 0.05569320547604754, 0.01587215914285832, 0.10406709201033078, 0.010752025822688256, 0.012881335607098957, 0.1115249426314427, 0.05151816418454532, 0.019972563360727603, 0.009344357456411085, 0.01804052217442903, 0.04532823887383265, 0.030551253172058253, 0.07753422664057824, 0.11253106888503799, 0.027408009740493955, 0.01272141858334503, 0.10992423255717564, 0.06687112543131075, 0.2230809884326112, 26.223629443876206, 67.67918725167551, 45.243986883471095, 46.786302058927475, 41.7486608412958, 54.489268333681174, 68.22480463212537, 61.91733137253792, 65.19828811768564, 60.43925285339356, 59.61470004050963, 55.99002599716187, 2.187208970708232, 1.8506579653870676, 3.0414261789091173, 7.618232292513694, 14.285860523100823, 1.0884344337447998, 24.114672983846358, 64.19095285477178, 55.103480123704486, 61.97206020355225, 55.467621203391786, 61.67989853889712, 55.14759109866235, 55.50834717289094, 46.095443233366936, 46.19166681843419, 43.75353328643307, 51.448646976101784, 54.80619192123414, 58.229750356366566, 57.64764708857383, 54.69555362578362, 57.39116722537626, 57.003872394561775, 53.56879788060343, 48.5282580314144, 44.80232800206831, 45.18976796057917, 41.61570033719463, 41.57854764692245, 39.142771459394886, 39.84149071478075, 37.847804869374926, 40.9097796101724, 40.768146745620236, 39.95719279012373, 40.51814271557716, 41.01366750655636, 39.21349179360175, 40.92076616902506, 40.01697755629017, 40.4224015820411, 41.39216838344451, 39.01090921894197, 37.531304897800574, 38.45170867058539, 45.196173191070564, 50.49432646843695, 50.9673446993674, 50.63167610476094, 51.14629891610915, 51.48239897143457, 53.257436213954804, 53.88969875151112, 51.74033795633624, 44.564287201050796, 42.31912643678727, 41.93702090171076, 38.58084094139838, 40.36719814423592, 41.3095122768033, 42.1365479500063, 42.88806230791154, 44.96566334078389, 43.50192500698952, 42.63880745057137, 42.117359715123335, 40.40453910827637, 40.005830180260446, 40.25345333160893, 40.427947813464755, 40.41802813929897, 41.104368394420995, 42.0306400329836, 41.058688471394206, 43.42399535640594, 48.94163662387479, 53.46865584773403, 53.24537100330476, 53.41085580087478, 53.37867275361092, 52.21349347022272, 52.09083703256423, 51.453675454662694, 53.08107076152679, 42.94179877927227, 39.40815902525379, 39.28257649944675, 40.40841833237679, 41.79179514608076, 38.99933430456346, 40.06621899143342, 38.71303266094577, 39.7166455945661, 39.62524260244062, 39.67773176008655, 40.525803104523696, 39.944143064560436, 37.21502850132604, 39.08696789895335, 37.748043306412235, 40.31246146848125, 39.14146138775734, 40.19184466331236, 38.284937335598855, 39.04502599470077, 38.307934191919145, 40.59134983247326, 39.83579151092037, 42.82879921697801, 51.074429327441806, 53.82654859173683, 57.55633823333248, 56.859266373419, 54.80656846877068, 55.408185528170684, 54.886851541457645, 53.150888950594016, 58.570929881065126, 58.91179561614991, 57.92932033538819, 45.564005221090014, 43.36460282725673, 45.416245614328695, 53.52465160431401, 58.65893217825121, 63.480886182477406, 58.26634607007427, 33.310614939658876, 0.13988612279776605, 4.416652552543148, 1.4683602341721136, 0.7200242218471343, 54.703276772652906, 62.35897456446002, 60.14935439632785, 64.46288685644826, 66.55397692034322, 54.7929774561236, 37.55954988541142, 31.263441693398264, 51.30560598065777, 53.88279930237801, 2.1542760152970595, 0.17842898686085978, 0.06971741786166545, 0.018302206318044377, 0.07164153195316754, 0.0375927081932464, 0.03939559653161034, 0.03085082227874908, 0.06732854120914014, 0.16852325549529446, 0.1162047362736156, 0.12438541383392389, 0.07447920589437408, 0.2244441499633174, 0.22312851652743357, 0.2190901299998645, 0.12680350907988128, 0.1585626262690752, 0.19441195583391577, 0.1375823585136283, 0.3908626248519267, 29.767467360342707, 78.52083021594633, 51.87301997215518, 59.943253455623505, 45.09603508057133, 58.68448641992385, 74.5548354425738, 66.64970628676876, 69.52595679990708, 65.83849737721106, 62.851698783136186, 65.00525259202527, 2.8398769036416085, 4.132964188052762, 9.850225660108752, 13.595423352333809, 17.868639730638076, 1.4498003139611215, 27.34428001988319, 65.55970315010318, 57.07113319827665, 62.195980471949426, 57.390523956668, 62.188402452776515, 59.452141331088164, 58.351504648885424, 49.393379918990604, 48.42270312770721, 48.5290660396699, 55.87665773207142, 58.24666361654959, 60.3805467390245, 59.32029085774576, 56.97860448591171, 60.56882835203602, 58.31137880202263, 56.098197121774, 53.58847641175794, 47.59371411415839, 46.71300472751741, 44.26674404451924, 44.01886201673939, 42.793509652537686, 43.017465222266416, 40.0352361894423, 42.695705352290986, 43.66141250056606, 43.42535249648556, 42.817667530428984, 43.301095731796764, 40.95010549791398, 44.36840011227516, 43.18671549520185, 44.365579928121264, 43.313415896508005, 39.940973789461204, 41.252912475216775, 41.15451197470389, 47.780964143814586, 53.6728544389048, 54.314856221598966, 53.23116810091081, 52.419049201473115, 51.86328464938749, 57.216884551509736, 54.99937257459087, 53.91496666016118, 45.510912018437544, 44.11993365133963, 43.825065551265595, 38.076918355880245, 41.78692356232674, 43.524965009381695, 44.091951462530325, 44.40084988071073, 48.63080447719943, 47.19307538001768, 45.46624798928538, 44.429530251410704, 42.948258922946074, 42.39208252199235, 42.298369253835375, 42.43852338483257, 42.04584706214167, 42.10918549568423, 42.54936956590222, 41.3729723038212, 45.69860919829338, 50.564905597317605, 56.69267154509022, 56.675354280779445, 54.74743089368267, 56.70221467171946, 56.43177509307862, 55.150121027423495, 55.64345321347637, 56.394559644883685, 44.71389424416327, 42.45371080213978, 40.56964343593967, 41.53397383228425, 44.38396407711891, 40.14845148209603, 43.37204748584379, 40.96682656195856, 43.2310422005192, 40.21583780165642, 42.7028872120765, 43.17465420692198, 42.3500229466346, 39.925962878811745, 41.880872172694055, 41.183113898000414, 44.358841296165224, 41.698187781918435, 43.02610228138585, 39.81496764767555, 42.28534698486328, 41.14942466059039, 41.30834341049194, 41.59580215331047, 46.46156510999126, 53.845462260707734, 56.354272980843824, 60.9362877568891, 59.34239733603693, 57.5264968410615, 56.111521413249356, 58.094424663051484, 54.684198364134765, 61.16731928240869, 60.691520091026064, 60.79645918261621, 47.75532360999815, 45.843623145934075, 46.77808861578665, 56.918403948507006, 59.94946648997646, 65.54259377141153, 59.07878660386609, 38.375822574861594, 0.3963490094869368, 11.009875382146529, 4.508534073829651, 1.1292044073343277, 62.42682764607092, 67.78995498534172, 68.12817312056019, 69.20389882979855, 72.91635943997291, 59.145478663905976, 44.83720179527037, 42.566341661637836, 58.07217697943411, 64.19463988273375, 2.8281504877151984, 0.2703117645315586, 0.1800208409587222, 0.16575470566749573, 0.2780265150771987, 0.15711007759936396, 0.08676817550534204, 0.1622671823227598, 0.15174807499974005], [0.037602154057352774, 0.029226713964054664, 0.025814276811997258, 0.02149716643015704, 0.10158366478619077, 0.10317329722907274, 0.009148774251732375, 0.053738535967685526, 0.04287397278653037, 0.06385598722244464, 0.051359101348826965, 0.21450002227098713, 2.57141248353066, 52.983042886180264, 47.356928471596014, 57.03623587085355, 32.4957876436172, 37.154969169247536, 57.718536084698094, 61.909341504496915, 57.47464702975366, 56.701810667591715, 51.75542339201897, 56.8494055348058, 8.22832755504116, 2.7086243466023476, 0.9271953567381829, 2.4046406582478554, 7.8339101902900214, 1.4394455018543428, 13.471757884948486, 56.93574866940899, 36.66978374604256, 51.73033591239683, 56.39398697883853, 58.336725158076135, 54.17432554306523, 54.25955864690966, 48.29431610722696, 50.73992959914669, 48.37217907751761, 54.093822817648615, 52.48400757389685, 58.0301409382974, 55.42984877863238, 56.13957420472176, 52.740844372780096, 53.70323319588938, 48.27714397061256, 41.98285379717427, 40.38382899376654, 41.343193669472974, 40.38499001533755, 39.83639163355674, 38.595914609970585, 38.43944734142673, 36.98139252201204, 38.498765345542665, 39.77359448709796, 41.011588650365034, 39.99140370276667, 39.47437647850283, 39.31704628852106, 39.9199341958569, 39.533157117905155, 38.09603598810012, 36.78296373736474, 37.34540024111348, 35.86773357083721, 35.84399146418418, 42.70922968464513, 47.64680731681086, 48.14160254693801, 49.853685748192575, 50.987799859816036, 50.8752513700916, 50.95526379923667, 52.01775935388381, 48.8022748116524, 43.82205709334343, 40.17608065758982, 39.06975653863723, 37.91752892155802, 41.1091850649926, 38.66308127680133, 42.69354020395587, 41.01263200083087, 41.02666624130742, 42.215203239071755, 40.60802382807578, 41.53837080924742, 41.119944126375266, 39.294794682533514, 39.88879449905888, 40.89052861736667, 39.92131094778738, 39.663101319343816, 42.11015039874662, 42.161702109921364, 42.62502031941568, 47.37709729902206, 51.711857626515055, 51.52134026250532, 49.66410583065402, 51.42087267291162, 49.5985238013729, 51.165353790406265, 47.86657379519555, 52.01827318437638, 43.59117069552022, 35.07229651174238, 35.27407107814666, 36.066954674259314, 39.27209592634632, 37.651129384194654, 37.64102928100094, 37.58073068434192, 38.24426235691194, 37.84181148775163, 38.367773871268, 38.73743372578775, 37.95676831276187, 35.43852429236136, 36.82138335320258, 37.289965383468136, 36.19482786424699, 37.385224065473004, 38.14597560513405, 38.638899864689, 39.79274349827921, 38.00432705110119, 37.396116487441525, 38.58959959399316, 40.992776963018606, 43.2711523579013, 47.950171270678126, 49.72361995327858, 53.15923967669087, 54.85181693107852, 54.47636765818442, 57.16080250278596, 50.928070006832, 49.03260423291115, 58.680097287701024, 52.328697404553814, 52.859331330945416, 39.734413931446696, 44.95969349338163, 50.68985662152691, 58.19863811615975, 57.54069974345546, 64.9751248667317, 18.87926390094142, 0.4939419920406034, 7.919648299294134, 2.0057342634085686, 3.1568794288942894, 52.05140936759211, 56.510159738602184, 55.990269184112556, 59.436396937216486, 59.27164170049853, 40.12582725094211, 29.554176715112504, 33.63610106129801, 46.61219981408889, 29.58708932322841, 0.1080981700591022, 0.059461109340190894, 0.008869517966353846, 0.005682214903044365, 0.04782897202418216, 0.015755024299235837, 0.064262967601779, 0.050400591290165345, 0.07306260207007009, 0.009014260703547588, 0.014470368586180192, 0.05566934949808544, 0.0727670836532789, 0.07149354674883428, 0.032165837098634055, 0.029554101638495926, 0.035511718447049784, 0.06663294869565195, 0.017387566284366676, 0.07547243888820372, 0.2550256597779451, 5.336361085214923, 63.54789595450125, 53.9342176529669, 63.03193169255411, 40.23617921337005, 47.48501346957299, 64.34797317750993, 66.4877986907959, 61.16772720890661, 61.92220295629194, 54.228391493520434, 60.82022874586044, 6.865091621875764, 0.9961658235519164, 2.0827346799835085, 5.487218874116098, 11.061852670484974, 1.275601113034833, 15.962447254888474, 59.11988519853162, 40.12464661752024, 52.85863707142492, 57.11323984207646, 60.606318366143014, 56.84516153027935, 55.234287246581054, 51.13487305179719, 51.980920453225416, 50.7789767942121, 56.814841608847345, 54.003863257746545, 59.21111168399934, 56.427507554331136, 57.52319420537641, 55.416351902869444, 55.69858212624827, 51.23838440064461, 44.20340953334686, 42.687201653757405, 42.24562514212824, 43.43419351885396, 40.29826248845747, 41.37076400941418, 41.67990561454527, 40.0426180901066, 40.346205619073686, 41.30527611701719, 41.75986313050793, 42.427281871918716, 41.807543462322606, 40.617766995583814, 41.46457533682547, 40.30888818925427, 39.285757541656494, 38.399482311741004, 38.89861176090856, 37.155612437955796, 38.79998768529585, 43.58913498540079, 49.86772783340947, 50.32697462266492, 52.0374967205909, 52.74093458729406, 55.62113100482572, 52.09916030206988, 52.42713320639826, 49.885190225416615, 43.69109307565997, 40.69356287679365, 39.647380459693174, 36.52006295419509, 41.536770482217115, 41.08424271306684, 44.30194339444561, 44.18074607849122, 43.30302553792154, 41.31722757893224, 42.58441202102169, 42.92605046303042, 41.320816547639915, 41.568325950253396, 43.12711900280368, 40.95472997234714, 39.00774386621291, 39.921416851782034, 42.07779476719518, 42.09816755787019, 42.45343231385754, 48.09201202084942, 52.11298273455713, 53.34511687678676, 53.022192062870154, 53.7421509527391, 52.19085747195829, 51.620917474069905, 51.90151206908688, 52.96353301694317, 46.43832506672029, 37.26866299106229, 37.53548222203409, 38.90460514253186, 40.297481936793176, 39.19899079107469, 39.1965667663082, 38.89767823680755, 40.40133453184559, 39.07166281054097, 41.30906120423348, 39.3297076994373, 40.86947333428168, 38.80842862590667, 40.42278597431798, 40.258156253445534, 40.99207093638759, 39.471399399542044, 39.94709660930019, 39.70181903531475, 42.43586794022591, 40.57259698067942, 40.264624241859686, 39.73474733291134, 41.98728215309882, 46.746611595153816, 49.7124804219892, 51.41928411299183, 55.49822745784637, 55.195549918759255, 56.169180254782404, 60.15035852309197, 53.05887406872165, 51.23352458400112, 62.173124820955344, 55.09480384088332, 55.49304208447857, 43.456825594748224, 46.39017405048494, 53.31685227732505, 60.32734371000721, 60.058222047744266, 65.48377783067765, 20.426750721470004, 1.0434154300920426, 8.413246716222456, 1.9636282324790957, 4.163935713229641, 60.29964393185031, 61.183055831540024, 62.16255403334095, 66.28742048817297, 64.18119792015322, 48.37697613623835, 35.566609290338334, 32.77513884728955, 54.40522763036913, 37.923969453380955, 0.21242478201466225, 0.01835083374903808, 0.04799725089762961, 0.07405578909862427, 0.0348888429993343, 0.06575565544828292, 0.0014231832028599458, 0.057233658904630336, 0.022202788949793866, 0.15955671728138002, 0.09501717278673764, 0.13099610144572874, 0.1398864139111773, 0.21969815866360742, 0.13885473862530726, 0.16558320922476633, 0.08867474618337809, 0.11836432281040377, 0.20513577717206172, 0.28468357399106026, 0.459240262186335, 6.053407124934658, 75.71938714673443, 61.26670037546466, 68.0824225948703, 45.73354182704803, 51.197144600652884, 71.55007239310973, 71.46841649086245, 70.0086279838316, 66.54736380423269, 62.489805221557624, 67.41471752043694, 11.933724957127726, 6.2061540253700755, 7.837209884197482, 9.163523566338325, 15.38344854308713, 1.5726864554228321, 18.73706817626953, 61.354439873849195, 38.87798401617235, 54.89174273706252, 58.63280134816324, 65.2772689634754, 57.912375696243785, 59.42554766131986, 52.10995858715427, 54.509915690268244, 53.52641667089155, 59.581461875669426, 57.857984189064275, 62.067597373839355, 57.65070653730824, 59.771300669639345, 57.46406447502875, 58.51474977308705, 53.60285974317982, 46.59249382634317, 43.870918058579974, 45.619934297377064, 46.03177139835973, 44.262460816291075, 45.4311074749116, 43.43177341645764, 43.12046666299143, 43.665393706290956, 44.85722157262987, 45.17986789826424, 45.097066663926654, 43.24857127281928, 43.2939923194147, 43.67705099044308, 43.28456294152045, 41.40259012099236, 39.552714055584325, 40.57227534632529, 40.61074595297537, 40.695673111946356, 46.85094271936725, 54.16096202788815, 52.40559547178207, 55.37658691406251, 55.89921920530258, 58.92346074504238, 54.916073199241396, 56.75373500393283, 50.097574803137014, 44.944207975941325, 42.224546324822214, 41.518782492606874, 38.55193307322841, 44.95894824304889, 42.09353916106686, 47.44564464015346, 44.74958781273135, 43.85331838361679, 44.054426147091775, 45.71317688111336, 46.5252330226283, 43.267045636330884, 41.99568779237809, 43.70346423118345, 43.515068869436945, 41.94206506975236, 41.36464511194537, 44.22844209978658, 43.4930565280299, 42.99269153225807, 47.937392188656716, 54.57947108053393, 54.402662400276434, 56.44901390998595, 58.569129513156035, 54.18999541190363, 55.8127191758925, 52.81398873175345, 57.421997054930664, 48.61743703965218, 40.056373842300914, 41.70276518790953, 41.21966646563622, 43.19878462822207, 41.83566293408794, 41.13022858096708, 40.07699374229678, 42.07173078290878, 41.18180382636286, 44.35651140828287, 43.329709422203806, 43.404642381975734, 41.245083424352835, 40.9757617212111, 42.22682129952216, 43.33558905509211, 42.10416093949349, 42.8630179743613, 41.39106619742609, 45.3057877479061, 42.66738583964687, 41.45361231219384, 43.60524023732832, 45.98654647027293, 49.28809565882529, 52.94130102280648, 53.902418997979936, 60.162984632676654, 57.21344855523879, 60.045713609264745, 61.57216279737411, 53.49233127409413, 52.74798700886389, 63.95056255402104, 56.46841003048805, 58.06478723402947, 45.21906806576637, 50.11262493748819, 56.57349817214474, 63.50886444891653, 62.655290019127634, 68.61770060754591, 23.98432477827995, 1.5610856779160038, 18.00494601649623, 5.546732016148106, 4.559135100533886, 63.27505980768512, 66.80656971470003, 65.09953068148705, 71.42408586317494, 67.77356732276179, 53.7206720536755, 40.62852997933665, 44.39860628497216, 61.906093781994244, 45.591544182069846, 0.5918827172248595, 0.185850877314806, 0.18661391620914783, 0.22299768403172496, 0.1696365038233419, 0.23588964144789407, 0.17867549863313475, 0.16920714218529964, 0.11790975687965272], [0.027227393021025968, 0.05595122005850558, 0.07218848042670759, 0.048763944031370264, 0.014799772987082122, 0.020592841770379774, 0.044429250016448, 0.05944611699951272, 0.028630199601813674, 0.02501786329723414, 0.02937179952559452, 0.08399864508500023, 0.33788491761492145, 32.0540032463689, 44.34871765875047, 44.607915724477465, 43.453562182764855, 32.916703070363695, 60.42907822516657, 62.571492502766276, 56.140084112844164, 58.30294570615215, 50.47536180865381, 58.98160988284696, 28.260494701323974, 1.1621252279127798, 0.3834991102978107, 4.897096320506066, 6.405274127760242, 0.26864285731027204, 27.45674810101909, 65.47234412162535, 49.91780473339943, 55.46158467569659, 51.023050200554636, 58.78496577662807, 52.97783005622126, 55.84239582861624, 50.14924418541693, 54.701048866395034, 50.29087312759892, 54.35139702212427, 54.921011463288345, 54.3410066635378, 53.63154795862014, 54.25597752294233, 51.2433461989126, 49.14716489853398, 42.09286843576739, 42.976441152634166, 39.77511244435465, 40.50497139653852, 39.12479131452499, 40.158704557726466, 37.0974083869688, 37.09679257485175, 37.015054302830855, 38.26709447368499, 39.61668399072463, 39.936019835933564, 38.03684742219987, 41.371215081984, 40.49846418442265, 38.203814875695016, 38.50435080066804, 38.45329723050518, 37.707462464609456, 38.955490050777314, 36.696769652828095, 37.89475564033755, 40.69068777945734, 46.607877362158995, 48.91934579418552, 47.5653043870003, 47.09297649322018, 49.74161186525899, 52.62835864097842, 50.78665287263932, 45.14500194980253, 41.03979833664433, 38.84592256238384, 36.776232950149044, 38.419643294426706, 40.22347857875209, 41.0848859817751, 39.87327368028703, 39.79713263050203, 40.655327612353915, 40.85399958395189, 42.71355998131537, 40.07900984056535, 39.69468816634148, 39.792229667786636, 39.42097733097692, 41.87023470478673, 42.055374499290224, 39.817623092282204, 39.346668028062396, 40.17064033016082, 41.87839715711532, 49.28169827307425, 49.61506051401938, 52.334863370464696, 51.54423513720113, 50.666844075725926, 50.38309981746059, 50.32648432639338, 48.08828576918572, 48.396748804276996, 43.19752946976693, 34.255831626153764, 37.66201003905266, 36.65602799384825, 35.11326174582205, 37.38253724190497, 38.51370173115885, 37.10370379109537, 38.008527909555745, 39.112765327576675, 38.49174822530439, 36.58969679186421, 37.95757239864719, 35.08167097645421, 35.070539289905184, 36.15441176199144, 36.540412210649066, 34.81325926319246, 36.46338470520512, 35.89633549413374, 35.842320534490774, 38.279512697650546, 37.22235548880793, 36.94054103666736, 39.83765463675223, 41.28997102860482, 42.59394338054042, 47.24866713246992, 49.34120062858828, 50.91411421375891, 52.17099851177585, 54.08948467623804, 54.408542033164736, 48.596479815821496, 60.37477693250103, 54.1504696876772, 55.860356361635276, 46.87193524452948, 41.52040635385821, 50.10608634641094, 60.0262390413592, 57.25547675163516, 54.448479606259255, 4.828085159101795, 0.481658814054343, 1.2671853001079252, 1.3495862075398046, 7.170402051941042, 55.11148568122618, 55.493544147860625, 57.29266866560906, 52.13923908049061, 53.121067170173895, 37.606826213098344, 32.70306725655833, 33.97557435497161, 48.280548587922134, 16.588754653930664, 0.2102695315355255, 0.05209924570555168, 0.0038675522720891865, 0.0451594045866401, 0.041248054589114846, 0.02966965259533496, 0.013702782002397844, 0.050750264462323925, 0.049993507488961184, 0.02403190047780593, 0.0054188932464908695, 0.03873152087532705, 0.05111957629842143, 0.02208129889632185, 0.05513994443801142, 0.041746360309902704, 0.11393179936755089, 0.030843458258576935, 0.05945063308782636, 0.06096073794328879, 0.03142570231800839, 0.18062221997928235, 42.78818699621385, 52.50806739253383, 51.45484039860388, 38.2260194132405, 39.77064878709855, 66.12187293268019, 67.06961954793623, 61.17325775084957, 62.28651662026683, 56.30379207672612, 64.30612933251166, 28.9035084555226, 0.932169473699985, 1.6035520766050586, 5.764088198061913, 7.638222161800631, 0.2389146468692249, 30.22409792869322, 63.938713073730476, 51.150950847133515, 56.47676075658491, 51.86529682528589, 62.10766438514956, 57.34720922285511, 58.919059845709036, 50.3621151370387, 58.504881089733495, 54.29985707806003, 56.206172127877515, 55.51797659166398, 56.49485072781963, 56.09985628435689, 56.26253266488352, 53.078101527306345, 52.50680831170852, 44.71720864695888, 43.89920226989254, 43.003489817342455, 42.922245763963275, 41.56325040325042, 42.89593842721755, 40.81488178622338, 39.20983614460115, 39.90167164033459, 39.95992668213383, 40.70912291926723, 41.308359099972634, 42.34485718511766, 43.37687592352591, 42.198619457983206, 41.49797039647257, 39.87548197469404, 40.65430387373894, 39.44940274761569, 39.795587216654134, 38.116067532570135, 38.255021418294604, 43.23744743101059, 49.79703887816399, 50.76269111325664, 50.352517097227036, 49.5093055694334, 51.28533124923707, 55.291000796902566, 53.28666571647891, 47.13596959267893, 43.15736047683224, 39.74201548484064, 38.26747886596188, 40.38220905488537, 40.71135867026545, 41.98872558532223, 42.131480247743674, 40.393505480981645, 42.0603362975582, 42.55629647162653, 43.41743323110765, 43.57432411563012, 42.56203489918863, 41.34152273977957, 41.10745529974661, 43.57644219552317, 42.14868376331945, 39.74072502505395, 40.39950670734529, 40.17322909447455, 42.022979644037065, 48.4337132207809, 53.45645335412795, 54.70225303403793, 51.80428435725551, 53.82667410758234, 52.27634160749374, 53.43254258555751, 49.65899105994932, 51.51735905678042, 44.21651024972239, 36.92704416090442, 39.313763264686834, 38.4856410949461, 36.440364314663796, 38.68505047213647, 39.857517519304835, 38.238174838404504, 40.24185488300939, 39.87523486537319, 41.16140750146682, 37.817269217583444, 40.31829795529766, 37.5981185513158, 36.61838500730453, 38.663536271741314, 38.769471645355225, 37.489374760658514, 38.49631778655514, 38.513638973236084, 39.3673389188705, 39.42890836346535, 40.64527849997244, 37.793593791223344, 41.98406973192769, 42.46082598163236, 45.51357923015472, 50.015354079584924, 51.59847759431409, 53.56171408007222, 56.446334931158255, 57.447845474366225, 57.25388819171537, 52.26071880709741, 60.66010975068616, 57.69935569455547, 58.19492363160657, 48.46862623768468, 43.76413937537901, 53.37861784042851, 62.94384702559441, 59.29638793391567, 56.777331982889486, 5.693345310226564, 1.4341805779164838, 5.681393358015246, 1.4418852161015234, 7.2009921266186625, 59.65505730721259, 60.149221035741995, 63.4238588425421, 62.023776654274236, 56.7256155321675, 46.984409209220644, 33.1692252620574, 37.366839916475364, 55.54368380577334, 21.08227095296306, 0.19161898312309097, 0.059174347308374224, 0.024628987490770318, 0.04945832612593809, 0.011466744678816008, 0.0591280602759892, 0.07199456059043446, 0.027325327786046173, 0.0571719428614503, 0.08018639239092028, 0.08266700041149894, 0.1320838543676561, 0.11736928950995208, 0.20648475075441025, 0.15082185937752648, 0.18113372156456595, 0.19476853911915135, 0.11748027266754259, 0.26784931279478535, 0.11683404685989504, 0.21136117618410818, 0.5102795831138088, 50.18570261616861, 60.34193492704823, 55.39624975573633, 58.38167944262105, 46.00878238677979, 72.70954855026739, 72.54899809437414, 65.13573808054771, 68.46809356443345, 62.738828659057624, 67.85580373579457, 36.938681833205685, 2.13172018047302, 7.397648980540614, 16.52605164435602, 11.051259329242091, 0.9817085799670989, 32.54403279673669, 63.289698093168205, 51.864535885472456, 54.288839140246, 52.81246685212659, 62.80848995331795, 59.51201631176857, 60.70313422910629, 53.80159839507073, 59.526768345986646, 56.25609605543075, 59.9112900610893, 58.90087965996035, 57.74849514807425, 58.510937229279556, 59.17894824858635, 55.83232710438391, 53.66206792093093, 46.6672698913082, 46.06024780581075, 45.459242636157626, 45.114113284695534, 42.58996217481552, 45.21659697255781, 43.217996397326075, 40.87116387582595, 42.03733551886774, 43.7020835568828, 44.86158324826149, 43.95008325576783, 43.97996387174053, 46.2974609867219, 44.19561578381447, 43.703158286310014, 42.343778533320275, 41.140917039686634, 43.19665085884833, 42.30561387154364, 40.65235837813347, 42.82509257716518, 46.74266176839029, 52.12340839447514, 51.31337619596913, 51.993397512743556, 49.86388783301077, 53.08464796312394, 57.17250293300998, 54.17416080351799, 47.81367278868153, 42.195108936678984, 41.18559675831949, 39.12013153876028, 42.21426579260057, 42.96307763745708, 45.98476963658487, 43.90262649905297, 43.93642948519799, 46.02943758810721, 44.64224430822557, 47.08721060906687, 45.465698857461255, 43.861237648994695, 42.767429813261955, 44.479058019576534, 46.196083407248224, 44.813043917379076, 40.85788273042248, 40.95472212760679, 40.79344995560185, 43.26597875164401, 49.71866599975094, 53.498681591403106, 57.08412408828736, 56.53791442994149, 58.15317784586261, 56.16171990671466, 55.3205087877089, 51.602925562089496, 55.50305981789866, 47.45521914574408, 38.51104628655219, 43.242723018892356, 41.42335907105477, 38.471936333564024, 39.86908066657282, 43.07171552411972, 40.75471655015023, 42.14360821631647, 42.14194905373358, 42.19262215398973, 40.31380291908018, 41.764303253543, 40.10676845427483, 39.348637057888894, 41.54011234160393, 41.32073025549612, 39.058711144231985, 40.69850506321077, 41.04932185142271, 40.64432536402057, 42.7081431881074, 41.64412183146323, 40.25810918500347, 44.17812593521611, 45.19174875751619, 47.01609803784279, 51.05056562731343, 53.26036622447353, 55.5769141258732, 58.46881097362888, 59.027956608803045, 59.22130592407719, 51.19057855298443, 62.07523815093502, 60.576935891182195, 61.58284733372351, 52.04909124682027, 46.803505574503255, 54.58123222474129, 66.715131421243, 61.374173318186116, 60.585831826733006, 8.293854671139872, 2.4803823617196854, 5.93588948249817, 4.144136569192333, 10.649908684915113, 67.3672176176502, 65.68785090600291, 68.17481010190903, 64.38074458029963, 63.494155560770345, 50.13569631884175, 44.05224530927597, 44.960505424007295, 62.6899363148597, 26.940946617434104, 0.3364914956112062, 0.17443946142110134, 0.19778016864532427, 0.10708837424434962, 0.1121422716025864, 0.21571540544109963, 0.18740658738440086, 0.15102602180934724, 0.1262644666337198], [0.037696133893463886, 0.11087866319764046, 0.008722692427615966, 0.00424805952559015, 0.08792998614690958, 0.05065085306282967, 0.023555861102537285, 0.1331189770491854, 0.061958188251141584, 0.06742973376305834, 0.03965038588390716, 0.18141202598569856, 0.11888793624577024, 18.192515719321467, 53.49191550285586, 43.580015474750155, 57.75633596604871, 29.142702433370776, 50.32715897406302, 60.13596342455957, 56.549293225811375, 55.03003766459804, 52.144687252659956, 44.005361218606275, 42.0901894569397, 0.11277521344562692, 1.3239178494099648, 2.705873049074604, 6.3623344705950835, 0.302361328635485, 28.177569912325954, 60.08018339833906, 52.90315989525088, 57.44633536184988, 55.0706498853622, 61.6774784365008, 57.90705303991995, 54.763430241615545, 54.172034878884595, 56.75997549487699, 55.10443718202653, 58.04594024535149, 52.49826146710304, 53.86014369226272, 55.55977336822018, 53.186264807178134, 50.48105316777384, 44.38066536380399, 40.61478207188268, 39.19430748108895, 40.513616300398304, 37.953226412496264, 40.16499996185303, 38.28344683493338, 36.756260241231615, 38.28281141096546, 38.13957429701282, 38.16419893695463, 38.98348008432696, 40.44747729455271, 39.004637349036436, 39.06703441373764, 39.4869202183139, 38.76363515853882, 39.08979985021776, 39.93023041755923, 38.898309738405295, 38.1285406697181, 37.111572065661036, 37.41454378251107, 40.284251782201956, 45.62011080403482, 47.284133203568004, 48.2908251977736, 49.28019992766842, 51.457503687950876, 50.980618000030525, 50.52264598108108, 43.22410745005454, 39.03119571747319, 37.188807456724106, 39.13995911998134, 42.1614000874181, 39.28919746029762, 37.20270441424462, 39.583536040398386, 38.534706023431596, 39.69251125089584, 39.094796949817294, 40.825660459456905, 37.73969650268555, 38.63717402181318, 36.86188574760191, 38.847503277563284, 39.042543134381695, 42.069298913401944, 40.107556850679465, 38.94873572934059, 38.9379374442562, 38.578687560173776, 44.50254909453854, 48.5964366697496, 49.659500968071725, 50.64387075362667, 49.081296536230276, 49.27918011142362, 49.991388397832075, 48.71688089063091, 46.39264906606367, 42.185036290076475, 36.153364489155436, 36.24091179140153, 36.379108659682736, 36.15406659341628, 36.100471327381754, 36.127951452809, 38.92124383680282, 37.83670456178727, 39.103441853677076, 37.287207957237, 36.99500314650997, 35.9306993792134, 37.335229535256666, 35.032370705758375, 35.29921347095121, 36.84809861644622, 36.63621217973771, 36.91317465997512, 38.36797783451696, 38.46239320693478, 38.49812992157475, 38.651675024340236, 37.75968882345384, 36.774569865195986, 38.26383890644197, 37.223214487875666, 39.713021324526885, 42.771171754406346, 46.14679882603307, 52.21104198886503, 50.26917849817584, 56.929370895508804, 51.74034187870642, 48.13128671338482, 57.4736782043211, 55.169572061108006, 53.409008364523615, 41.76534660400883, 50.889360135601414, 55.07715709747807, 61.79976224899293, 43.81908001438264, 1.6923680204537608, 0.8208329963587946, 2.2902334553580133, 0.7754291101328789, 16.4484965801239, 57.997310699955115, 51.651421746900006, 58.9353298371838, 44.033869005018666, 50.21109211829401, 34.22115002909015, 33.69095540815784, 37.03453671547675, 49.850653756049375, 4.334712768754652, 0.3297016276947914, 0.05426994817812116, 0.013510425943100165, 0.011931004494638934, 0.05255982542650835, 0.011523847915081969, 0.012995589002516243, 0.0693298769634097, 0.025759097414031148, 0.023023123559992642, 0.029645392505992806, 0.017139957091140173, 0.04382888989282712, 0.07510355989178343, 0.01535033931084458, 0.0329658703788394, 0.04985374240805546, 0.12282673134318284, 0.09537547976980287, 0.022791284286687453, 0.05855798743845475, 0.15657185486728148, 23.799285004215857, 58.702482254274436, 48.07643628889515, 56.801470248929924, 35.38210099743259, 58.51341224485829, 65.07927556191721, 61.461065584613436, 61.06379224408058, 60.24889630656089, 51.847818743798044, 45.9338729612289, 0.1093977616138516, 0.5410511899859675, 5.463205143328636, 5.725815671105539, 0.3467306590849354, 31.144570342956055, 60.817381105115345, 52.658537357084214, 56.7237171050041, 55.87297854884979, 60.145228062906575, 59.39784788316297, 55.75188321451987, 55.62435519310736, 57.4342191603876, 56.61932714523808, 59.63737918484596, 54.463329699731645, 53.58988846501997, 56.408715478835575, 56.13321996504261, 52.24586871362502, 46.994607371668664, 42.304860776470555, 42.34119761374689, 40.39771026180637, 41.29481123339745, 41.75324609202724, 41.21091565778179, 40.152589582627826, 39.364557958418324, 40.120124124711566, 40.04128056187784, 40.10316771845664, 40.984292876335886, 40.95649111655451, 41.055052434244466, 40.96082925796509, 40.96463787940241, 39.038761969535585, 41.6956147070854, 40.42621020347842, 39.47779678529309, 38.66738803925053, 39.263772656840665, 44.434303775910415, 47.48959479793426, 49.955643838451756, 49.770762920379646, 51.70763715620964, 52.255796232531154, 52.5027015901381, 49.92033466216057, 43.81710706218597, 39.33892134697207, 38.43488170254616, 40.25447314785373, 40.717956096895286, 42.31456472027687, 41.16676938149237, 41.00533639231036, 40.68462379517094, 42.0996541361655, 42.96762758685697, 42.30809280949254, 41.00312417553317, 40.839957498735004, 39.34742896787582, 39.77298651972125, 41.73076698856969, 43.59472828526651, 40.999715635853434, 41.31413675123646, 40.12092036585654, 40.47844832943332, 45.89783814645583, 49.208769644460375, 51.33953840501847, 53.025220132643184, 50.666028222730084, 51.84661849852532, 50.87226252402029, 49.46652035559378, 48.68657273630942, 44.394511330512266, 36.54757838095389, 38.58452012462001, 38.862404361847915, 38.532956646334746, 38.958282778340006, 37.512387306459495, 40.55447170811315, 38.74490584096601, 41.14304296432003, 38.90145547928349, 38.53985217309768, 38.92216951616349, 39.49390595959079, 37.24734883154593, 37.827094754865094, 38.667313514217255, 37.26350115191552, 38.45187341013263, 39.44934783443328, 40.3447582644801, 39.67035378179243, 40.96272376275832, 39.061974556215354, 39.64947108299502, 40.15382905160227, 41.59448815930275, 41.64086626422021, 45.192003711577385, 48.499993431952696, 54.62080893977996, 53.17060278308008, 57.804157503189586, 53.039807427314024, 49.2257535073065, 61.100780194805516, 58.53237298227126, 54.98984121507215, 44.39225204529301, 52.232905280205514, 59.420334831360854, 63.435143501527854, 46.58837926003241, 2.975264129138762, 1.4578144516675704, 0.60020188049924, 1.1148481647814474, 17.659722528150006, 63.053814595745465, 56.29569238232028, 64.0161524280425, 49.81370895139633, 56.12374744107647, 46.43824269694667, 35.2995547171562, 41.820628489217455, 56.849232950518214, 6.48238645445916, 0.32536434430268507, 0.04514526260355788, 0.01184954445043038, 0.01918784800856825, 0.043515069635524865, 0.03231957562327866, 0.05592931377431078, 0.03865953925396166, 0.0157422210548013, 0.06567975911762446, 0.2055685095969708, 0.13014016672968864, 0.11566988432839995, 0.29658704815853026, 0.16161128848550782, 0.1469600407947456, 0.15836833104971917, 0.21936180009957285, 0.2182766059113126, 0.1679568866928739, 0.25769546087230405, 0.32742122909234417, 28.099806962474702, 70.73088538262152, 51.92346557494133, 71.92983627319336, 45.258181941124704, 63.01823869828255, 71.3797160117857, 68.94473214303294, 64.93011959137456, 65.19944129451629, 58.39438007723901, 51.072664260864265, 0.23877885012376696, 4.207555901619696, 13.990775712074774, 10.9019092013759, 0.5560834285232329, 36.168967677700905, 60.883347526673354, 53.69782032505159, 56.081358386624245, 57.959550042306226, 61.05346464341687, 62.01435904349051, 56.62699930129513, 59.5295375393283, 61.29193690515334, 59.42508482163953, 62.50728722541564, 54.1637312212298, 54.711298019655295, 58.88456652241369, 56.17480885597968, 56.91983953599007, 48.27678311255671, 45.27607579385081, 44.21221525438371, 43.6285783398536, 43.755247362198375, 45.49838789047734, 44.979399481127345, 44.12080441751788, 42.44685449907857, 42.39087835434945, 43.12654633675852, 43.45784541099302, 43.686645107884566, 43.430133865725615, 43.25061875004923, 42.87709536090974, 41.79266983462919, 42.63599511115782, 44.51566157802459, 42.736529381044456, 41.73499530361545, 40.80660950752997, 41.06799233344294, 46.17450252656014, 51.13468477802893, 54.24330042254541, 52.617328936053866, 55.62379037180255, 55.963495085316325, 56.265733318944136, 52.42896103089856, 45.093124681903475, 39.39926308970298, 39.60440697208528, 42.4588647965462, 46.0569961609379, 43.24401740104922, 43.42091629582067, 42.76214245826968, 43.75287432824412, 44.6605460874496, 44.727077330312426, 44.08964118649883, 43.348536799030924, 42.763236799547755, 41.272591006371286, 41.05688810348511, 45.04624843597413, 47.13930752969558, 43.74992862824471, 42.97662942640243, 40.92220567887829, 40.09751558303833, 48.353108513739805, 51.20756633820073, 54.12217370925411, 55.808569308250185, 53.66326032146331, 54.36613728923183, 54.91708517074586, 52.13732888621669, 51.261965690120576, 50.81699632829236, 39.48225259780884, 41.257705611567346, 38.941404819488525, 40.76975491739089, 39.819937290683875, 39.39877279343144, 42.723307071193574, 40.96558317061394, 43.95675128506076, 40.27652863533267, 40.7219490697307, 40.672566429261245, 41.94051573353429, 40.4988956451416, 40.66307821581441, 41.29232445070821, 41.456240300209295, 40.41059524782243, 43.00548238138999, 42.87959391070951, 42.68384410488991, 43.43477795200963, 42.83878164906656, 40.43954626206429, 42.80961882683539, 43.431561608468336, 45.05579940734371, 46.55801227015834, 49.94145662553849, 56.865063636533684, 55.644849577257716, 61.89288323925388, 57.842718324353626, 50.31312865595664, 62.378233402006096, 62.50323933939781, 58.377996337029245, 46.935469796580655, 54.85686109912012, 62.00563569222728, 64.69000777890606, 49.969725147370376, 5.106539610893496, 1.5770906642560036, 6.009628570848896, 2.5972810051133557, 20.196266366589455, 69.88725416121945, 61.05300572610671, 68.57977913271996, 57.115569729958814, 62.51687349811677, 46.069983128578436, 46.36623974769346, 48.557028616628344, 66.55877790143414, 8.825007330986763, 0.6057339546180541, 0.16592805604300193, 0.15623744216657456, 0.10987193939546425, 0.12941394602098774, 0.1358631806027505, 0.159072840826646, 0.1402171800333646, 0.15850795823479855], [0.02537621816079463, 0.019471191373022816, 0.05146605871437539, 0.03408669531645794, 0.00672785836579879, 0.023858239836690408, 0.01946549359408598, 0.04591939828148292, 0.003781543820232694, 0.01666198525908253, 0.05361606915211005, 0.053147116090141, 0.10773676808082289, 3.9746987579330324, 55.645508535446666, 46.01087301008163, 57.1809164170296, 29.862498544877578, 42.64219637840025, 56.63168261128088, 63.62189931254234, 57.63419335888278, 55.39400223762759, 50.49390677482852, 59.658214815201305, 3.013650404830133, 1.145779608238128, 3.1131602006573833, 3.6148364938074544, 0.24347147573867153, 32.798271025380785, 63.720111539286954, 52.81034484986336, 62.106605345203036, 55.5813346370574, 59.74723692863219, 57.80556171171127, 59.885598536460634, 56.02613141459804, 56.26787493305822, 54.30846668058827, 55.132474284018244, 50.18505542509018, 56.82440434732745, 53.87797086469589, 52.741452340156805, 45.07015528217439, 40.92661050058181, 39.836948610121205, 39.89232463221396, 38.525884612914055, 38.451434104673325, 37.166751969245176, 37.98585660995976, 37.24495226337064, 38.40644451879686, 37.63787177301223, 38.439380661133804, 38.79476308822632, 40.00155087440245, 38.7297615697307, 40.0233631749307, 38.48477817350818, 39.5500821451987, 38.590384068027625, 40.232033268097915, 37.81001675513483, 40.25833276010329, 38.1311765024739, 37.10161316779352, 38.85653257369995, 42.94352069977791, 44.6642723391133, 47.47076349873697, 47.259779207168094, 49.30343212619905, 48.968822571539114, 46.205532396993334, 41.52027299327236, 39.184595692542295, 40.05888023684102, 40.37619998378139, 41.188922928225615, 38.78889522244854, 37.68923128804853, 39.066163647559385, 38.167038732959384, 39.547218814972915, 38.770110991693315, 39.216457105452015, 40.716818609545314, 39.08666979882025, 38.97880069671139, 37.177291377898186, 36.432178328114176, 38.15991963109663, 39.98569665416595, 39.540641000193936, 38.749130233641594, 39.05825614929199, 39.62581526848578, 46.03405029542985, 51.8656341491207, 48.87011220378261, 50.87920119685512, 48.69418997918406, 48.25368819698211, 48.07382006799021, 45.16512763115668, 40.823554146674375, 34.690069383190526, 37.43989798330492, 38.477066793749415, 37.6912473863171, 38.036568933917636, 37.479313881166526, 37.29172260530534, 37.50706465013566, 38.00427213791878, 36.729878379452614, 37.11817733703121, 37.015662270207564, 36.964353745983495, 34.90660382855323, 35.72926213664394, 35.99894469784152, 36.489354718116026, 36.486322725972826, 36.42346674396146, 37.63238437714116, 38.02286025016539, 39.36036886707429, 38.211804743736025, 38.69486031993743, 37.69452648778116, 38.35880341068391, 38.015674468009706, 37.44404392857706, 39.91883985457882, 45.12611573742282, 51.170472483481134, 51.21163383606942, 58.85003397541662, 48.38221642278856, 57.15002382955244, 56.104531749602295, 53.592975370345584, 47.6841208242601, 51.59712829897481, 57.83302614765783, 62.99270799083095, 27.9886705260123, 0.782096220120307, 0.2761176384745106, 2.0397140013594783, 0.2452318232146002, 18.20535363689546, 52.30169973065777, 52.44863956205307, 57.80210218121929, 57.453940837614006, 41.63119762174545, 32.70887824796861, 28.953489257443337, 43.930145848181944, 35.257181352184666, 0.2774973015391058, 0.04104097719274221, 0.07698669594021575, 0.04272111143255907, 0.03608679000829016, 0.028308454164934736, 0.08002523047428939, 0.04353031861565767, 0.004534194322918812, 0.013506024767975173, 0.06285643783367931, 0.02006683431024994, 0.037320023027038386, 0.09756705047742975, 0.043402791789342324, 0.03492276154218182, 0.026248148792693694, 0.020765491175435243, 0.06057491308198341, 0.07816726807504892, 0.06185157179471947, 0.08903550464780101, 0.17848564672373957, 7.925179331533371, 65.02948107257967, 50.13428426557972, 61.667233205610714, 39.652926691116825, 51.15078610758628, 63.58244811334918, 72.34297952344342, 61.999587397421564, 60.83903258846652, 53.396798026177194, 63.752055321970296, 3.4977181976841343, 1.3064120661827827, 3.097726409473727, 7.166318864591661, 0.31667896035698156, 35.56826060818088, 62.91319370269776, 55.0610440008102, 62.24371571694652, 58.8877671764743, 60.1314252422702, 58.170463731212, 59.18309027148832, 56.962989530255726, 59.198818975879306, 54.9899039729949, 54.82039874599826, 52.194822988202496, 56.567508712891616, 56.52697886190107, 54.172960558245265, 47.6335967740705, 42.53807313980595, 41.232516150320734, 42.236042791797274, 41.51884525052963, 42.03738650967998, 39.91565096762873, 40.447932289492705, 40.89550218274517, 40.586423335536836, 40.681662405690844, 39.94734371862104, 40.389740005616225, 42.051008901288434, 40.627427793318226, 41.888575707712484, 40.93633405623898, 42.16628343828263, 40.369422128123624, 42.241891045724195, 39.267510675614886, 40.63083633299797, 38.96246010257352, 38.523335072302054, 42.043948634978264, 45.51545020072691, 48.50567302396221, 49.035251832777455, 48.84647207875406, 50.996664416405466, 49.36736283763763, 47.69017304143598, 42.30942249298096, 40.515644165777395, 40.54972171783447, 41.22503226803195, 43.03816356966573, 39.85353239120976, 40.12979276718632, 42.20829594519831, 39.980303395179014, 41.36147975921631, 42.3408995136138, 39.89544683887113, 42.44868624594904, 40.529603881220666, 40.4891760118546, 39.84982967376709, 39.67807692866172, 41.22052546470396, 41.00872139776907, 41.901209662037516, 40.57081622462119, 41.387300722060665, 41.46626195599956, 46.68787802419355, 52.40119849481891, 51.286511882658935, 52.39983350999894, 51.27192458798809, 50.046140763067434, 49.58863158379832, 46.93419110390448, 43.08853856978878, 37.51762367063953, 39.20640407070037, 40.06217895015594, 39.61853927181613, 39.281329185731956, 39.141845780034224, 39.648808202435895, 39.62981216369137, 39.45898117557649, 38.421282845158736, 39.239010733942834, 39.253519581210234, 39.485359114985314, 38.669310000634965, 38.75389199103079, 38.72161088451263, 39.843953963248964, 39.581057102449485, 39.99922883126044, 40.93215280963529, 40.483606246209916, 41.10959691386069, 40.62121475896528, 40.53164351371027, 40.778897962262555, 39.99216856495027, 40.40796725980697, 39.740136669528106, 41.86883441863522, 48.72345478303971, 54.57672934378348, 53.87495848440356, 60.40064104141728, 51.08850671399025, 59.321157701553844, 59.90991723152899, 57.05738136845251, 49.52810156729914, 54.402195638225926, 59.17976802395236, 63.536391642785844, 30.06720704417075, 1.0971656297483752, 0.37911625999596815, 1.3843339946000808, 0.08810612508246014, 22.207514624441824, 56.87313195197814, 58.65456265787925, 62.77067830485683, 57.07549487390826, 48.5582249395309, 47.233624842859086, 30.869518056992565, 49.558005717492875, 43.691944229987364, 0.40551341288993437, 0.031010093873426802, 0.03052594737269946, 0.04656255590699373, 0.04175161950350289, 0.033989348523919626, 0.04555408925478978, 0.012640646103048518, 0.033674746856934605, 0.07040158800420261, 0.1674958549800419, 0.12583736495505418, 0.11417474117009871, 0.24890519948976658, 0.17686045247941248, 0.09863919818833952, 0.15702236053203383, 0.14886098072653817, 0.1130448840558529, 0.10746927316030187, 0.18553299679150506, 0.20193057254918162, 0.3223160498084561, 7.97467326925647, 75.52816375609368, 57.512850915232015, 67.75506942502915, 45.545923094595636, 57.61889219284058, 67.96622630088561, 73.63008176126789, 66.63136528384301, 64.6807078392275, 60.58614169397662, 70.5100324076991, 4.3940449914624615, 3.3882791669138017, 9.908595431235529, 9.482570136747054, 0.8513751445758728, 41.08904761652793, 61.56164300057196, 56.35914848696802, 63.488876050518414, 60.52961641742338, 62.361406433966856, 60.11095046997071, 62.71968749261672, 58.809009905784364, 60.08233677956366, 57.21725717667611, 55.793111247401086, 52.136877813646876, 60.46637604313513, 57.93722391128541, 56.36094493250693, 48.264341354370124, 45.753573371518044, 44.332914429326216, 45.68552809376871, 43.76615155127741, 44.31047847194057, 41.09715515567411, 44.61432487733903, 42.98362301241967, 43.52030915598716, 43.50305857196931, 42.87409082535775, 43.145565909724084, 44.69594155588458, 43.474150703799346, 44.629237728734175, 42.721059553084835, 43.325022189847886, 41.51327156251477, 43.84401059919789, 41.57447230431342, 43.11045285194151, 41.88568884326566, 42.27419568646339, 45.03653664742747, 47.212157710906, 50.01262803231516, 50.921503959163545, 51.30273480569163, 53.947561556293124, 51.77768676511703, 48.12231625280073, 43.44399944428475, 42.38584595341837, 42.227644997258345, 43.639153049838164, 45.058698038901056, 42.264032825346916, 41.60362335943407, 43.97191124577677, 42.665361896637954, 45.201382098659394, 43.980866016880164, 45.05043752731816, 45.655674934387214, 45.05705064342868, 43.67515256327968, 42.961257657697125, 41.674881058354536, 43.72193859469506, 44.64062829171458, 45.02863699390043, 43.26601797534574, 42.578077393193404, 41.67167255955358, 47.77372344847649, 54.50378502568891, 52.42155167364305, 55.10000098136164, 53.2678501067623, 52.474868451395345, 51.37516137092344, 47.93312072753907, 46.83218594520323, 38.98690823585757, 41.40652818064536, 42.61184507800687, 42.23920814452633, 42.83790696051813, 42.18178072283345, 41.57169918860159, 41.45193353776009, 42.334227561950684, 39.41297961819557, 40.76888415121263, 41.38438640102264, 42.415483382440385, 40.421264094691125, 39.854218805989916, 40.55088273940548, 40.701560589575, 41.05900226100799, 40.320835728799146, 43.19358356537358, 42.36941122239636, 43.92129305870303, 42.64841333512337, 42.54045009613038, 43.19009657829039, 43.37242011101016, 43.543913979684156, 42.0454744369753, 43.49915973601803, 50.545270212234996, 56.32464339656215, 56.518839943793516, 63.264689060949514, 51.70152610348117, 60.936601546502885, 62.56737009171517, 60.53656293499855, 53.731678224379024, 56.94631161228303, 62.44130511437694, 65.37224915719801, 35.340296376136045, 1.8273402101570562, 0.8370526711786948, 11.328233576590016, 0.7649058199697926, 23.809428253481467, 62.44134433807866, 63.74348886551396, 67.70207820400115, 67.37933774148264, 52.40996499215403, 44.27605182893815, 40.53292612875662, 55.76051635126914, 50.991886969535585, 0.813161330598016, 0.1382922002625081, 0.15125267658262484, 0.1854395647082598, 0.16871004305299253, 0.06504481778510156, 0.11419803024299684, 0.12707975272449756, 0.11377993009744153, 0.21026436810291585], [0.04234686982066881, 0.01834651492836495, 0.028032764018843734, 0.015324739525244843, 0.03541995643547947, 0.03229750079974052, 0.09558639143623653, 0.021393715832082015, 0.09206263979356136, 0.034844390747527924, 0.03304086272574721, 0.09077946550302929, 0.17700420121752447, 0.20922979700469205, 35.87090284593644, 51.27949476242066, 41.86489243661204, 35.524424199135076, 30.97014646376333, 54.312145863809896, 46.54113823367704, 49.153307330223825, 59.37318794188961, 51.70596622651624, 58.65026374017039, 12.300355761281907, 1.686778030087871, 2.50043670496633, 8.834387679253856, 5.858536910626197, 35.78364187671293, 52.37320846126926, 59.07677050559752, 57.96234669223909, 57.6196688221347, 57.07378864288331, 56.41412834967337, 58.27927027979205, 55.57579232800392, 57.42576253029608, 57.102798492677756, 56.254197628267356, 54.473367045002604, 56.60715603059339, 53.762680638221006, 52.12987638288929, 43.9814975184779, 40.95166267887239, 38.973136794182565, 39.88114587722286, 39.230934573758034, 35.535179338147564, 37.57027364546253, 36.56603313261463, 37.213388950594016, 38.09122716226886, 36.73445186307354, 34.966886735731556, 38.15089033495995, 38.05811451327416, 39.0037783499687, 39.96959532460859, 39.32656980329944, 39.19107152569679, 37.92811932102327, 38.158389906729425, 38.094741605943256, 39.253292083740234, 37.472896883564616, 35.61737260510845, 39.41849054828767, 43.55281383760514, 43.75702027351626, 46.6115604677508, 45.27976282181279, 50.23534413306944, 48.23327618260538, 40.133252297678304, 40.46692832823723, 39.72716931373843, 41.2754229576357, 41.795666525440836, 39.464084179170676, 38.674409081858975, 36.21897005265759, 38.10362969675372, 39.72409025315316, 40.64628262673655, 37.73395023038311, 37.568155565569484, 39.27007590570758, 37.65218842414118, 39.174770155260646, 37.04899064956173, 37.3415014051622, 37.568261469564135, 37.87824638428227, 40.279133089127086, 39.56522249406384, 38.28972262720908, 40.99112956754623, 45.18881482462729, 48.51525929666335, 49.6123383891198, 51.25649790610037, 45.66646929710142, 45.795166184825284, 44.83267145772135, 44.52089401983446, 40.201175981952304, 34.60263190730926, 36.73643266001056, 38.25093823094522, 37.444393019522394, 38.56079762981784, 35.54932732735911, 37.877905138077274, 36.86498049766787, 38.67240475070092, 38.02632762539772, 36.23445949246807, 37.55481166224326, 36.950092008036954, 35.31076877347885, 36.71176487399686, 36.87525318514916, 38.039600926060835, 38.26715330923758, 38.92604089552356, 39.42866909888483, 38.08056223777033, 38.389476345431426, 39.94478241089852, 44.74924264415618, 42.99320144038047, 43.33269826827511, 42.574527648187455, 43.10383581346081, 43.2387065118359, 45.25612269678424, 48.1788807530557, 51.03770025314824, 55.249243244048095, 55.183316046191806, 52.46610587643039, 56.55611814991121, 54.702406006474654, 54.97375557499548, 52.33717364649619, 56.5907330666819, 55.24861174245035, 23.467077901286466, 1.6288378810690296, 1.5149704943741522, 0.32581802157144396, 0.3155902268425111, 28.5058448391576, 57.93287400276431, 51.97928874723373, 56.72669026159472, 55.28599193019252, 41.02433635342506, 29.607842583810132, 22.13594117472249, 48.909453576610936, 13.487786650657656, 0.20664581307961097, 0.01389925386906872, 0.054065686154870264, 0.07978791175710578, 0.07478508948078079, 0.03453474183897338, 0.01629057434207249, 0.031469442108045184, 0.04115684416085001, 0.008570904554348559, 0.022141379341783545, 0.02395417702744805, 0.06678974391111443, 0.015081893483687554, 0.07026063548701425, 0.017923412228664084, 0.048409724127381086, 0.016994919410095583, 0.035816223075192784, 0.09533778824392827, 0.00536550936709729, 0.02304169161605739, 0.08617859423881577, 0.4529491787956607, 47.213875709041474, 57.58781917633549, 48.30973886674451, 39.220465767768125, 41.65747750189997, 57.766220338882945, 56.59824048319171, 59.203596422749186, 62.0256946932885, 57.25881861102197, 62.84168497208626, 12.818576366670671, 2.1753918499715867, 4.304511989316633, 10.5635400549058, 4.750443802725885, 39.32004297933271, 52.142655464910696, 61.20265983766126, 60.45449910625335, 59.02985895833662, 59.610169702960604, 59.440676243074485, 60.07065988356068, 57.43945944693781, 59.67782274369271, 55.59385484264743, 56.9747095723306, 54.71513017531365, 58.28900560255974, 55.543409239861276, 54.034885283439394, 46.700688485176336, 41.730508112138324, 41.045050390305065, 40.22393357369208, 39.765632075648156, 38.75226812977945, 38.68306967519945, 38.02294261993901, 40.34787262639692, 39.60355189538772, 39.15401297230875, 38.12957617544359, 39.43981255254438, 41.34598639703567, 40.5002567075914, 41.862523325027965, 41.9477407393917, 40.91342349206248, 40.653280135123964, 39.80722881132557, 40.566278042331824, 40.10041421459567, 38.59076846030451, 36.510876763251524, 40.69513966960292, 45.82050077376827, 47.1457088378168, 48.1382175414793, 47.19519345991073, 50.90850130204232, 47.523138907647905, 40.88575117049679, 40.10040244748516, 40.601861784535075, 42.87400845558413, 43.54228227369247, 42.77106977278187, 39.690416705223825, 39.91046559426093, 40.59750010890346, 40.64508238146382, 42.29662772147886, 40.18891857516381, 40.02841518771264, 41.479845123906294, 40.81453269527805, 42.02097139050884, 40.02788174536921, 39.265055271887014, 39.979354181597316, 40.49142745233352, 42.87800927315989, 42.36017404064056, 40.622242419950425, 39.97344709211781, 47.70597234849007, 50.883045119623986, 50.79954570339572, 50.64902082566292, 49.331516296632834, 48.8396079309525, 47.852441495464696, 47.241489195054584, 42.00009653645177, 37.970265188524806, 39.47725157583914, 39.912591518894324, 41.13490796858265, 39.59718981096822, 39.2243802932001, 39.64644301322199, 39.058699377121464, 39.49889521444998, 40.38324456061087, 38.99594537673458, 39.96348034950995, 38.552819528887355, 37.846028035686864, 39.024253122268185, 39.440393063329886, 42.01986528212025, 40.185345295936834, 42.036507898761386, 40.68400406068371, 40.42923435088127, 41.366257206086196, 42.73172839995354, 45.41617893403577, 45.56446021603, 45.4429098867601, 44.141122295010476, 45.985334457889685, 47.1890353387402, 48.0401582871714, 51.8211034805544, 55.027339073919485, 57.652855996162664, 54.991539601356756, 53.301107883453376, 60.02291679382325, 55.824843222095126, 56.49123038015058, 55.43555974960328, 59.072400985225556, 55.99313643670852, 26.99072933966114, 2.1512893755589766, 1.8280383920477283, 0.4703020508731566, 0.21839423105120662, 31.688332442314397, 61.31685180048789, 57.937055249367994, 64.61312147878832, 60.20921368752757, 49.107721544081166, 33.71899251014956, 22.98390857635006, 56.257904268080196, 18.502322166196763, 0.15290457665199234, 0.07068851091448339, 0.09320233347675494, 0.034873754897665594, 0.0075085910183617915, 0.03944670608747871, 0.0876856730469773, 0.0311748200141254, 0.06942766042606485, 0.010973587068879317, 0.13616664335131645, 0.09803591926972713, 0.1092897508774073, 0.1470588201717023, 0.21681124825150738, 0.2461357609999757, 0.21995654479870874, 0.13454426831055072, 0.15923345882085063, 0.1672582298276886, 0.130033879691074, 0.1655733420123016, 0.23370636747248713, 0.4448143056323452, 54.71975857211698, 65.71623709893996, 53.02644391213694, 51.89409094472086, 46.090250015258796, 65.0148114081352, 61.726547287356475, 60.054138860394886, 67.27838377798757, 63.28088060502083, 68.7537048709008, 16.21867020283976, 4.058556580735791, 10.664393017368933, 14.831141560308396, 7.981417294471496, 43.851078710248395, 51.59798337567238, 63.40002652137511, 62.92974218245476, 62.84791369591991, 60.74817088342483, 61.87329492261333, 60.34829701146772, 60.13959553933913, 59.91721676241968, 59.220144902506185, 58.55711529331823, 57.42639403189383, 60.36247637964065, 59.37782026106312, 55.98290689529912, 49.06827426725819, 45.37674734669347, 42.81252530313308, 43.279879631534705, 44.66032643471995, 41.94841146469116, 42.42372428217242, 40.94819530364006, 43.44468978143508, 43.52183495798419, 41.047176314938454, 38.92728820923836, 42.680404186248786, 42.86399856690438, 43.30178999131726, 44.324395041311945, 44.127731323242195, 43.58767194132651, 41.978515655763694, 41.165016082025346, 42.59114673060756, 43.49026772283739, 40.95745209724673, 39.47572185147194, 44.360355331051736, 49.65022064024403, 48.51604769306798, 50.391736876580026, 48.99279609803231, 53.321327701691665, 50.29676060522757, 42.3746475865764, 42.35540443851102, 43.55137040538173, 45.46448292270784, 45.09327765434019, 43.801390124905495, 42.33751843052526, 41.286872356168686, 42.74707663443781, 43.320491852298865, 45.67463567180019, 42.557841885474424, 41.96830572620515, 43.74345279509022, 41.73474034955425, 44.18535878581386, 43.29769503685736, 41.95422441728654, 42.942908810031035, 41.713128089904785, 43.73003044436055, 43.61233580497004, 41.24870769439205, 43.557371631745376, 50.30256571308259, 53.02793833517259, 55.55402317354756, 54.39056188829484, 50.46734056165142, 50.362907455813506, 48.98638694517074, 49.388033728445734, 44.86228535252233, 39.45036372830791, 41.85067384473739, 42.78301731232674, 42.27169321429345, 42.134547541218424, 40.77763495906707, 40.7881586782394, 40.87379578621157, 41.914424127148045, 43.23416048480619, 41.49730359354327, 42.10856183882683, 41.010062848368, 38.617432732735914, 41.192472673231556, 41.25331255697435, 43.88577991916288, 43.885913279748735, 45.06965714116251, 44.129264969979566, 42.33706735795544, 43.64265180403187, 44.97304524144819, 48.402440163397024, 46.67671888105331, 47.92336971529069, 46.16337084001111, 47.666674121733635, 48.97663593292237, 49.920432721414876, 53.757138329167525, 56.43872945539413, 62.144617034542954, 55.924934264152284, 52.68357384589411, 63.97404970661287, 58.828617834275775, 61.779977813843765, 58.05344373949113, 61.71593335367019, 57.209345756038545, 32.25898631157414, 3.5015476567129937, 4.955255264236081, 3.3444699693110684, 1.0865872425417746, 37.68232007180491, 67.38626464720696, 62.353240059268096, 69.18920563113305, 64.69227883123583, 51.541673829478604, 39.74295293131183, 32.79023801126788, 65.42731138967699, 24.618572035143455, 0.37878861951251186, 0.20995293803993734, 0.22932627508717202, 0.2151521775991686, 0.16021965912753539, 0.1927321395205875, 0.22599134113519426, 0.14876440768280338, 0.11280065522559228, 0.14603721128115732], [0.022218968726754672, 0.03235708328805143, 0.020946224723311684, 0.03460277810752873, 0.020359813145572142, 0.029401780376511238, 0.03836470265542308, 0.0370691407231554, 0.05923512106340739, 0.019704478552504893, 0.054505052901203596, 0.03653472161761696, 0.12436377185006296, 0.23688204706676547, 16.686721732539517, 53.1772158991906, 39.62445812840616, 55.59256830523091, 28.868634662320538, 47.73309161586147, 51.995044908215924, 47.5475517396004, 57.23050302074802, 49.67718301280853, 57.97996205668296, 17.815430818065522, 1.5269691473053348, 0.6404036007100536, 7.953827832975696, 25.573586802328787, 31.63060692048842, 52.76738705173616, 59.75554450865715, 58.13612338035338, 56.05036381752261, 53.169484907580966, 53.47967378554806, 56.696378184903054, 57.225458852706424, 55.828322364437966, 56.72549393869216, 56.647681959213756, 57.55265512774068, 56.60113519237888, 53.78521073249079, 47.58333160031227, 39.417792366397, 41.056550779650294, 39.837603645939986, 38.29002072734218, 38.49223459920576, 39.17286780572707, 40.085132660404334, 40.44284497537921, 36.35442910655853, 35.75362790015436, 35.37676657399824, 38.85894090898576, 38.530089393738784, 38.299461872346946, 41.05941018750591, 41.032035966073316, 38.88575423148371, 38.850339151197865, 39.06573218684043, 37.88659711037913, 39.807707340486594, 42.1243925248423, 37.50383261711367, 37.427330709272816, 40.096433008870775, 43.83179241611112, 43.850043204522905, 45.620856054367565, 46.12597888515842, 48.551784407707956, 43.99444134004655, 39.65440150230162, 40.38074208844093, 41.540567336543916, 40.42711627098822, 39.90855539998701, 36.508166405462454, 38.15446753655711, 37.49381880606375, 39.440326383036954, 39.18576063648347, 38.233789628551854, 38.44311475753784, 40.371575509348226, 40.13151468769197, 36.59741601636333, 38.16560314547631, 37.62051136262956, 38.73619033444313, 37.27842577042119, 38.720583223527484, 37.23081211889944, 37.989488724739324, 40.4906076769675, 40.93293336129958, 42.72818257731777, 46.72613682285432, 48.89594885610765, 49.92767733912314, 46.48977871864073, 45.7123649504877, 45.0336850843122, 42.33140737779679, 39.43284642311835, 37.06644911919871, 36.394456894167014, 39.98803046441848, 38.73687282685311, 36.63900098493023, 38.304796295781294, 36.66432772913287, 37.264042438999304, 38.12961147677514, 37.890311594932314, 37.594898285404334, 36.466648117188484, 35.52380446464785, 35.43844976732808, 38.162296587421054, 37.18750915219707, 40.578382476683586, 37.928013417028616, 38.486500094013834, 38.495521545410156, 43.33758554150982, 49.78884504687402, 52.01482149862474, 49.880032308640025, 51.51579010871149, 53.136293811182824, 50.45578918149395, 48.975541591644294, 48.60500312620594, 49.38886527092227, 50.02779976014168, 50.6715666094134, 58.381561771515884, 50.189279817765765, 45.96651492580291, 56.259441837187744, 53.84453658134707, 56.10573591724519, 52.64456587453043, 62.629292549625525, 41.455349922180176, 3.6893375025641535, 0.9840002860273085, 1.0187491762541956, 0.9076665498075948, 0.23705797149769722, 38.01132848185878, 57.97690653031873, 49.9780523392462, 59.60850269563737, 45.57446225996941, 32.177455925172374, 32.26296947848412, 32.3947532715336, 48.7835454940796, 4.2992221828429935, 0.22761963037473543, 0.047004224747539534, 0.03542951338233487, 0.03959117877867915, 0.02220844842433449, 0.037848466646767435, 0.06470718751511266, 0.06580316056046756, 0.006010033501943033, 0.06547180455057852, 0.01941299741907466, 0.017951190576798493, 0.016578822584462263, 0.03239146531409314, 0.01577651402312181, 0.04227178554321009, 0.028901565181572112, 0.07042241027398456, 0.09598771425625009, 0.024640172374464815, 0.025474624069888267, 0.045526759068091074, 0.15414614470735674, 0.2815571385285547, 23.502065443223525, 61.66313432878064, 43.70769646859939, 54.32990635595014, 33.364300420207364, 55.27791184763755, 52.58125881994925, 53.08663268243113, 62.04253735080842, 55.37041702578145, 63.57018286182035, 20.47917712119318, 2.4186918139457703, 3.772627317136334, 11.30294115312638, 28.284291721159413, 33.19206522357079, 51.17786222888578, 62.2029269895246, 59.461394202324655, 58.54867435270741, 55.799975395202644, 58.161026508577415, 60.19781135743665, 59.79071247962214, 58.736948120978575, 59.37504322298112, 58.331355433310236, 59.2901631324522, 56.3369478717927, 56.73961054894232, 50.22885261043426, 42.36814037446053, 42.35892280455559, 41.65631648032896, 41.191633286014685, 41.624357008164935, 40.51758181664252, 41.864684550992905, 40.86554704173919, 38.682093005026545, 39.29169208772721, 38.55425903874059, 40.605729241524976, 40.09184775813934, 41.40293136719735, 41.74909230201475, 43.509044108852265, 41.72561691653344, 41.686314767406834, 40.51994700585642, 40.49693838242562, 41.47595413269536, 42.790552185427764, 39.77271587617936, 38.13211787131525, 41.858196950727894, 45.80388953608852, 45.32978873099051, 47.2193552601722, 46.818037955991684, 51.34934825281943, 45.606951252106704, 40.05565997092955, 40.748440757874526, 43.20137731490597, 42.44264579588368, 41.93969203579811, 40.176214018175685, 40.66739674537413, 39.67875157633136, 41.433027713529526, 40.98497929111604, 40.22968769073486, 41.40196254176479, 41.89927593354256, 40.81360309354721, 40.29674453120078, 40.00824243791642, 39.633275616553526, 40.09040040354575, 40.81657625013783, 40.584532753113784, 39.49841276291878, 38.82631463389243, 41.151381923306374, 42.91664069698703, 45.298433303833015, 49.63478611361597, 51.2930622408467, 51.895275500512895, 47.76849885140696, 48.49954235938288, 48.20089701683291, 44.298938858893614, 43.38593267625378, 37.70657600895051, 39.537538405387636, 43.033280218801195, 39.87190085072672, 38.359215259552, 39.44309949874878, 39.499373743611, 38.878807713908536, 39.46477059395083, 40.13620192004789, 39.41274035361506, 38.03709060915055, 38.93989470697219, 39.39048090288716, 40.43660056206488, 40.0478034634744, 43.353569199962, 40.40419393970121, 40.36922600961501, 40.71325709742885, 45.179110880820986, 51.689535417864406, 54.03399490541028, 52.45565668229134, 53.55791722574542, 54.15440774733021, 51.69530130201771, 51.35841677265783, 52.05288025640672, 52.47100099440544, 53.70670841586206, 56.03437623670025, 59.470180311510646, 50.34442916993172, 47.637079838783514, 57.836003226618615, 57.41756085426577, 59.978692070130386, 55.87811685377552, 64.61246644296955, 44.008765835915845, 4.520902777871778, 2.2911728630142827, 0.8549440111364088, 0.5342439165519131, 0.16360633465791904, 41.582105236668745, 62.44663561544111, 55.42806802257415, 65.85766992261334, 51.67142583477882, 41.69849372679188, 27.50039819748171, 29.449072883975123, 58.62091264417095, 6.639326858905054, 0.2399299585170323, 0.058826478273277326, 0.031585717017972664, 0.05983529349548682, 0.0678027419733905, 0.03838636762192173, 0.02518367919800503, 0.09068674588155362, 0.03622794170833884, 0.048289796893274596, 0.19846453030984249, 0.1517783814380246, 0.06705920001672161, 0.1837347739286, 0.0849726262892927, 0.10026659110500928, 0.15469273311957238, 0.19911113916145218, 0.14361315587114903, 0.13653537679103114, 0.08531448536462362, 0.17497374646125302, 0.42006911409478037, 0.42108454831665565, 26.018540474676318, 71.00107392957135, 50.10278371072585, 67.96131549342986, 43.21602736749957, 58.31466182585686, 61.287100622730875, 60.497315699054354, 66.17709205996606, 61.539799321082334, 68.33470944435366, 24.58130951850645, 3.5475114612810077, 5.9690737147485065, 13.144217421931605, 32.589134170163064, 37.65498507407404, 53.17257573527675, 62.4619956170359, 62.410365458457704, 60.56258001635152, 57.99121925907751, 60.10023847703011, 63.72612061039094, 63.50032937142157, 59.993918711139315, 61.90248912380588, 62.54528322527486, 61.31369429249918, 59.96164152699133, 58.330696475121286, 51.92449715829665, 43.80452802104335, 46.50240875059559, 43.3389622934403, 41.679505532787694, 44.60573880903183, 43.01214648831276, 46.137640091680716, 45.14890470812398, 40.764757817791356, 40.67878338598436, 40.23489267595353, 42.83705972856091, 41.53810016570553, 43.41756266932334, 45.750094229175204, 47.294707913552564, 43.02901268005372, 43.9394889339324, 43.038916664738814, 42.446450494950824, 43.37891163364534, 45.82418387936008, 43.825940239814024, 41.52442286091466, 44.18616287169918, 48.61943744844007, 48.24607095410747, 49.86247970211891, 49.49840138035436, 51.535641224153586, 47.386699261203894, 41.155119942080596, 42.30782608832083, 44.57229275857249, 44.79886454920615, 43.780370143152055, 41.04782742838706, 42.58732241968955, 42.121301697146514, 42.81200362790016, 44.24788528873075, 41.904531909573464, 43.347646421001805, 45.82319544207665, 44.13111240633073, 42.614496600243356, 42.25292075064875, 41.24175725444671, 43.78666554727862, 43.39056499542729, 42.75594903576759, 40.965912649708415, 40.35792958351874, 42.77897334867909, 45.051390663270034, 45.988742997569425, 50.64873841501052, 53.16410733807472, 54.579247505434104, 49.63808090456071, 50.50619163820821, 50.548361039930775, 46.76894164854481, 44.81225159860427, 41.692963184848914, 41.14450993076448, 45.6902898511579, 43.07948966180125, 38.77676725387573, 41.78253443010392, 41.22080787535637, 40.236116455447295, 40.618476944585005, 41.074205367795884, 41.904241654180716, 40.212868567435976, 41.05214203557661, 39.401514530181885, 44.2643553210843, 41.290096544450336, 47.03073632332587, 43.25591394978185, 42.787751613124726, 42.25114783933086, 47.51449792615829, 54.13146188182216, 58.255908643045736, 53.86269323287472, 55.898277836461226, 57.757842156194876, 54.94732272240424, 52.71459194921678, 54.41072679335072, 54.708803392225704, 56.628732988911295, 57.992372435908166, 62.148217770361136, 51.183145661507886, 49.38600586306665, 58.2797174299917, 60.50431320744177, 61.32845809382778, 59.19750498187158, 65.08399025086435, 49.03834266047324, 5.869294501120045, 3.2184309776752227, 3.4900533960711573, 2.19750470211429, 0.4634840522081622, 48.04131538637223, 69.62863660627796, 58.71165667810748, 70.591429433515, 56.692396979178156, 45.85397428081882, 46.04257360581429, 40.918365678479596, 67.07656214314123, 9.885466194921925, 0.43021221014280475, 0.18261486063561133, 0.15019913714739586, 0.16210094124319094, 0.13517276684363044, 0.10423527129234807, 0.21146174820680774, 0.18215232739044776, 0.14809061803164023, 0.1268114610725353], [0.04315988829119071, 0.02627618761072236, 0.029019941087631933, 0.020354542460653092, 0.15180845804993184, 0.04425888355340689, 0.0400102173819417, 0.007178059989406217, 0.07735982672461579, 0.012305257597848052, 0.05013712216168643, 0.03761915354839256, 0.1307659686332749, 0.08603567287566201, 1.829000353332489, 41.951239493585405, 43.13391647031231, 46.12291159168367, 32.68207080902592, 35.105322868593284, 67.65030291772658, 58.84766878620271, 57.234727413423606, 51.85278838680637, 57.13877054952807, 27.44004664882537, 0.4542252667728932, 1.7945332608876692, 0.6332928951709502, 4.301111784673506, 29.28044822908217, 67.49601256462836, 59.81645107269288, 58.66099534496185, 53.61734113385601, 49.462731346007324, 48.10924691538657, 51.53292694399434, 49.604717223874985, 51.30366832979264, 54.191270182209635, 53.51940347302345, 56.71242852364817, 54.53002960451188, 47.56180171043643, 41.88373550291985, 39.51242739154447, 37.85763432902675, 40.13336212404313, 38.644814798908854, 37.418058226185465, 38.12444963762837, 37.786757100013, 37.732997094431234, 38.701881362545876, 37.79946165700113, 36.247018921759825, 38.44196942544753, 39.52644202017015, 37.234252037540564, 39.426860886235396, 40.059190104084635, 38.8960700650369, 38.58561838826826, 38.37721893864293, 39.49980520432995, 38.70632540795111, 40.98711698285995, 36.18487288874965, 38.726486390636815, 41.23759169732371, 42.680282592773445, 43.18222045898438, 45.97465776628064, 44.893221086071385, 50.42335118016889, 46.532799274690696, 42.30723773279498, 40.955232035729196, 42.949349341853974, 39.022131120004964, 37.33520600103563, 36.26296335651029, 35.88107355179326, 34.959242036265714, 37.79452339295418, 37.67689935622677, 39.28797760317403, 37.75289920068557, 37.53662755412441, 37.63068599085654, 39.57227491563366, 36.455445827976355, 38.39179054383309, 38.939369109369096, 36.98238095929546, 36.541290821567664, 37.92515008680282, 36.976332664489746, 38.244034859441946, 39.317901365218624, 41.67664612493208, 41.48798404201385, 47.58477895490585, 46.37294307831795, 48.894497579143895, 44.52639710518622, 42.35237636873799, 41.52884337209886, 40.41214850641067, 37.4369679727862, 38.42480905594365, 39.87128111623949, 39.429983092892556, 37.78060290121263, 38.54308028374949, 36.98789581175774, 38.955756771949034, 36.03074335282849, 37.15877779068486, 37.48820197197699, 38.03625906667402, 37.41302190288421, 36.25111387621972, 38.48870446605068, 37.471437761860514, 37.76810622984363, 40.51604424753497, 38.977239593382805, 44.806128778765284, 50.22160799272599, 51.041610856210035, 53.14683321983584, 52.85908814399473, 52.08463184295162, 52.03004813963368, 51.708131374851355, 52.504333296129786, 49.997875998097086, 52.626746546837595, 51.22783322488108, 53.13105744700278, 50.15053464520363, 51.561368050113806, 41.696885555021225, 53.42003022470782, 53.54860551895634, 59.071530219047304, 53.90763967267929, 60.55084036242578, 13.618496694872457, 2.828661866726414, 4.253024506953455, 0.17876044246217898, 0.30568498577321734, 1.563832685351372, 46.37620649030132, 55.81418614233694, 47.89888235830492, 62.34723491053428, 38.55307840531872, 34.35347903159357, 27.092420708748605, 41.69364959962907, 32.34889488066397, 0.47632460512461205, 0.02259338653886751, 0.14470532145952025, 0.02066351912705408, 0.060695028007631345, 0.046485330413786635, 0.04043995057262721, 0.04308059053014844, 0.04369562123751929, 0.02669079056490333, 0.06440287440895073, 0.011080517621350386, 0.02756640033405875, 0.03311379429613871, 0.027850798984629013, 0.04239591093914163, 0.017455886005454006, 0.022816030841861522, 0.09196559943619276, 0.07252270926631267, 0.049201621553830566, 0.0856895390297136, 0.1042323065320811, 0.0657482780215721, 0.13382301185159914, 4.345499777024792, 52.74427644668087, 48.496749631820194, 52.29060334544028, 38.478192513988866, 43.1782078742981, 68.84961466635428, 62.662577782907796, 60.69696434082524, 57.980460197694846, 64.15649483280798, 29.515325638555712, 0.937140710171192, 3.2488732280269748, 0.8869500001592021, 6.089519406518629, 33.871757061250754, 68.29769011466735, 61.307030185576416, 59.47136486730268, 55.42472224081717, 52.26287611069218, 52.20526433760121, 52.82386918221751, 52.61664644364388, 53.46556502003824, 54.801045771568056, 55.987758867202274, 57.021523060337195, 56.45612908947853, 51.09772428389519, 44.285940124142556, 41.46791327384211, 42.337200718541304, 40.99462439936977, 39.58795262921242, 39.251931021290446, 38.84658544294296, 40.70593403231713, 39.551694239339525, 40.32896287979619, 38.873708632684526, 40.75847418077531, 40.59689998626709, 41.660729146772816, 41.6497229760693, 40.93092903014153, 42.306072788853804, 41.06391306846373, 40.95715007474346, 40.76045105534215, 39.822486831295876, 41.27170455071234, 41.993612858556936, 39.67436244410854, 40.956157715089866, 44.12408744135211, 44.67927540502241, 45.34902403431554, 47.563413804577245, 46.46510308788669, 51.927705657097604, 48.27009547141291, 40.843436641077844, 42.768963459999334, 44.03524967931932, 40.92457871283255, 40.1898128755631, 38.64035114165276, 37.66380648459158, 38.252769977815696, 40.16324274001583, 39.783102312395656, 40.97410255862821, 41.39001892459008, 40.62952233899025, 40.48120967803463, 42.3814489764552, 38.79465718423167, 40.26885647927561, 39.877556908515196, 39.00042080110119, 38.97525095170544, 40.65065214710851, 38.3661303981658, 39.90195012861683, 41.796647117983916, 43.403802994758856, 43.84333202915807, 48.35572473464474, 48.586603287727606, 51.479378746401885, 46.2437637390629, 46.13679285972349, 43.41033374109576, 40.82796289074806, 38.27417435184602, 40.353356099897816, 41.84757517230126, 41.747413527581, 39.61813919005856, 40.323793195909076, 36.86528644254131, 40.264196703510905, 38.58275898041264, 39.493466654131495, 39.65945351508356, 40.658057581993845, 39.46759077810472, 39.28933082088348, 41.28436596162858, 39.29644207800589, 41.15241742903187, 41.530067151592625, 39.59643671589513, 46.038035423524924, 51.38664999315816, 55.49852163560929, 55.33794764549502, 55.29513497506419, 53.77980570639334, 54.858418280078524, 53.432770083027506, 55.80519214753182, 53.268183508226954, 54.29761348232147, 53.994700601024014, 57.060833054204146, 52.30616338791386, 52.30208020056448, 43.13484214967297, 54.59097146987916, 56.142504215240486, 62.413483742744695, 58.43751438202397, 62.624836737109774, 15.861586447684997, 4.271568492535622, 7.38460268705122, 0.15982538431642518, 0.24908438745525577, 1.3823804091061316, 49.9519254315284, 58.80659764812839, 53.73885223942419, 67.91269379277384, 46.69462450088994, 43.03373913611136, 27.04582687347166, 42.92466586635959, 41.954306787060155, 0.8087429031729699, 0.035145248797151356, 0.02347008798331503, 0.015808978914133003, 0.027960678975608562, 0.029761376302509062, 0.03911230104765104, 0.027557257074682463, 0.01917288439618724, 0.02928524308146969, 0.06680374799837029, 0.10418127741544478, 0.20409201301874655, 0.17096822510563559, 0.12189657036815921, 0.23500540744393106, 0.10085848595706687, 0.06826611025439155, 0.16444533883083254, 0.16708399079019026, 0.16421201909261365, 0.20564021542668345, 0.25238746747134194, 0.17263932333838555, 0.33883275223835824, 5.0945597117947, 63.4076084629182, 54.89461783439883, 53.47108379487069, 47.84601273075227, 48.346711127988755, 75.9530270484186, 69.48013567155408, 67.37783155133648, 63.50686796249882, 68.22979388698455, 35.094626565133375, 1.4219648463110772, 8.201297521591187, 1.4922076319494557, 6.181495554985539, 35.565934642668694, 68.75239479926326, 65.98076174336096, 62.808980249589496, 59.45647555012857, 54.90745182960264, 53.64309933877761, 54.21503974545387, 54.43114273009762, 54.654266757349816, 58.53953523020591, 56.96988897938883, 61.78225671091388, 59.11611187842585, 51.74347193010392, 45.87254670358474, 42.95158117048202, 42.65276716601464, 43.78874440346995, 42.30094625103859, 41.25965502954299, 41.45031359887893, 44.61351294671336, 41.4784409153846, 42.47036518589143, 41.96789387733706, 42.28761411482289, 43.12321232211205, 44.68049918451617, 42.23900810364754, 43.74884213170698, 45.43660663789319, 44.03140183418028, 42.17308482816143, 42.79118760939568, 42.163286747470984, 43.73650235514487, 46.02636244989211, 40.80412664721089, 43.636140669545824, 48.49206632183444, 46.326392389112904, 48.185580161310014, 49.65847722945675, 48.89770215557468, 53.46586704254151, 51.83754213394658, 43.996194639513575, 45.771133822779504, 47.43091614015641, 41.66333752293741, 39.79342599068919, 41.851811332087365, 39.16521526152088, 38.55537299186953, 42.11818733522969, 42.92295571296446, 43.76823825220908, 43.208425814105624, 42.526678654455374, 42.42572861333048, 44.12378149647867, 41.47429104774229, 44.81078463215982, 44.10942169927782, 41.349771484251946, 42.67731728092317, 42.77283483935941, 39.90477031277072, 42.20200446344192, 43.41912377265192, 45.3447800297891, 46.9887512730014, 49.70149778550672, 49.46335892523489, 53.587287933595725, 48.6851449935667, 47.30632597400297, 47.73813970627324, 44.527420843801195, 41.80360932503977, 43.06349423623855, 44.870526252254365, 44.42134034249091, 42.66656214191068, 42.96019469538043, 39.09412230214765, 42.59606146043347, 38.7915506670552, 41.263126327145486, 41.952918268019154, 41.776541048480624, 42.325523822538315, 42.58920123500209, 43.37660527998402, 41.938723210365545, 43.192936374295144, 43.218121913171586, 41.11801432025048, 47.88300460384738, 54.90192913240003, 56.70467792018768, 56.65219660728209, 56.52461367268717, 57.26354898944978, 55.78039492330244, 56.39309267843924, 58.803373459846746, 55.72584652131604, 54.81715494586576, 57.88222443672919, 58.074044027636134, 54.91972100350165, 52.30038573665004, 43.97822233938402, 55.81588060625138, 55.95177896561162, 64.1019425084514, 62.54391824045489, 63.75063934633809, 20.337663888931274, 6.795377375618105, 9.136405279559474, 0.7431515582626866, 0.9796818790416565, 1.6821149448233268, 57.64535250202302, 61.26238184590494, 58.45080729453795, 73.43172750165387, 50.97722907220164, 47.7290633416945, 39.03293724982969, 51.37618118716825, 48.72473739808606, 1.550151948486605, 0.16152223842518945, 0.18992186854443244, 0.12831834835871575, 0.14393137347313667, 0.21853352115759928, 0.17549179043740998, 0.16880456298109026, 0.09189449115506104, 0.2134837913176706, 0.13693259337977057], [0.024547835796951287, 0.018008886573595867, 0.02708973468191201, 0.06403270455437803, 0.04355815058994678, 0.014742440882048782, 0.033652346446028644, 0.06006238110844166, 0.030864981498809594, 0.06660389098068399, 0.09688571486021243, 0.048096689110201214, 0.05147858808237699, 0.05392906203445408, 0.05145378215538879, 30.23955991191249, 46.690121619932114, 32.90725015824841, 42.70614277931952, 31.19899715146711, 52.69521936293572, 56.774958948935236, 58.851563699783824, 51.09452755220475, 56.118903313913655, 40.60161859758439, 0.05175304291169009, 1.2032075202272785, 0.8378271554266253, 0.07708713006708892, 17.028975986665298, 65.84682849145705, 57.79748947389665, 60.022304904076364, 50.494146039409024, 48.394669948085664, 45.31636638026084, 44.68766535482099, 44.16229524920064, 44.534853735277736, 46.19934681923159, 48.83019816490912, 48.27274307127922, 43.95987349171793, 40.844056375565074, 39.82559727084252, 39.197464989077666, 40.06478340395036, 39.83576405432917, 37.529002466509425, 38.50260534594136, 39.20307397842407, 37.60866580470916, 37.73668020002304, 37.680719744774606, 37.410217408211004, 38.19268711151616, 37.72443456034507, 40.21777545252154, 39.12736046698786, 39.834269631293516, 40.00270012886294, 40.36509575382356, 41.75557990227976, 38.075259193297356, 40.48848959707445, 40.13361707810433, 42.20411469859462, 38.1515218365577, 39.76974664195892, 44.073288825250444, 42.856691191273356, 41.044093331983014, 43.20691570158928, 45.812079445008315, 47.37643441846294, 44.85615076557283, 44.39364840907436, 39.9836060308641, 39.48182898183023, 37.498557029231904, 39.63751177633963, 39.06521051160751, 36.92581645904049, 38.092784343227265, 38.41571700188422, 37.39573209516464, 38.50078928855158, 37.72291268071821, 40.4038683829769, 36.85639835173084, 38.4694181719134, 36.09599590301514, 36.8072392863612, 38.318014683262, 36.003290683992454, 38.594165232873735, 38.70361505016204, 38.708902405154326, 38.529481426362075, 39.95189366802093, 41.488031110455914, 42.611397927807225, 46.136588896474535, 46.721563339233406, 46.54676683487431, 44.611034008764456, 42.557826195993734, 40.529176342871885, 44.50920535672096, 37.258696248454434, 37.834527646341634, 37.47074742471018, 38.521656297868304, 37.2329576553837, 38.64514035563315, 37.644814368217226, 37.22570519293509, 37.44057263097456, 38.63685238745905, 38.14155117157967, 38.854292900331565, 36.94731496995495, 39.78637356911936, 38.0977814428268, 40.8347721253672, 39.19678249666768, 39.29157049425187, 38.74494506466774, 42.751473611400975, 48.97537685209706, 53.54194141203358, 53.51716772202523, 53.02642037791591, 49.31317921607725, 49.02019777605611, 51.34535920235419, 54.84418007635302, 51.46411288169123, 54.87118559498941, 52.15668578301707, 56.61503607226957, 52.62928432033908, 56.23168714584843, 52.60275733086371, 52.34781895914386, 50.124192007126354, 53.38208129329067, 52.08659695040796, 45.00806416234663, 0.7864409192435203, 6.932071485827047, 14.099380258590946, 0.2528715431089363, 0.3579019064143781, 5.60543175666563, 56.90380880909582, 45.7051948578127, 55.96449921208044, 52.266453312289336, 40.58321091436571, 25.89411897044028, 25.57653642469837, 45.186853639541134, 14.852876394025742, 0.2557720439208131, 0.008778717395128503, 0.045747622216661135, 0.10098726533713842, 0.017024519132269968, 0.046628144524631, 0.024649306057742047, 0.01612274746050037, 0.01702252921888665, 0.04260362418849142, 0.029295621657623883, 0.04859083880399985, 0.04143187738654595, 0.008671881646038064, 0.030843178636484572, 0.019568890566006303, 0.024159578606486324, 0.05170110981130312, 0.06375219763046311, 0.04130892027469893, 0.01515700744705335, 0.019406435876003197, 0.02311316761939276, 0.011749963553982877, 0.028448977672885505, 0.15883161506104856, 39.78368674555133, 53.10134157057732, 35.640522433865456, 45.55409339166457, 42.76895561525899, 60.61055452592912, 62.845207260501006, 63.96331417945124, 55.2376800967801, 60.984595667931345, 41.4210174160619, 0.07684725261623822, 2.670441543863666, 2.9510670275457445, 0.05670713433515161, 19.59054062443395, 69.8612331574963, 60.65733663497433, 62.05637547277636, 54.339798573524725, 50.751924207133634, 46.36207419057047, 46.88816601230253, 47.759257747280984, 48.5433199328761, 50.10119907317623, 51.389379962798095, 52.13463029553814, 46.986472375931285, 41.93281612088604, 41.12967552677278, 41.21279055072416, 42.7803030321675, 41.336023576797984, 39.72684375701412, 41.429121032837905, 41.737376182310044, 39.084759604546335, 39.19637064779959, 38.92269119139641, 39.46360565000965, 37.697589858885735, 40.03055287945656, 41.494071560521284, 42.65760344843711, 42.79439218582646, 42.75684725853705, 41.68550675915134, 42.35021906514322, 39.91037537974697, 41.86602992396201, 40.72818563830468, 43.18522499453637, 39.832473185754594, 41.192327545535186, 46.034450377187426, 45.5610320644994, 42.71967103404384, 45.68571244516681, 47.39748970154793, 50.07741774282148, 47.3230823393791, 45.02350261134487, 42.63105684711088, 41.596319906173214, 40.562320370827955, 42.14129794028498, 41.11120508563134, 40.03661686374296, 40.032859233117875, 39.471944608996, 39.37291260688536, 39.54331213428129, 40.08772926945841, 40.80390307211107, 39.654440726003344, 39.86979453794418, 38.53282720811906, 38.40258882891747, 41.328002329795595, 38.68103004270984, 40.59650382687969, 40.89346647262573, 39.66412505795879, 41.589863684869584, 40.547776222229004, 43.72933618484005, 43.68277372852449, 47.570434847185695, 47.94968489677676, 47.098381519317634, 44.40407406899237, 43.034386327189786, 43.44589002670781, 45.36953018557641, 39.481577950139204, 40.256532392194195, 40.48818365220101, 39.93414102062103, 38.77129946985553, 40.7527514426939, 39.41214023097869, 38.555690703853486, 39.79539502051569, 39.84602889707012, 39.8521242603179, 40.0962172785113, 38.333017749171105, 41.966783846578295, 40.4911175850899, 41.90534384019914, 39.848409775764715, 40.61294640264204, 41.11468030560402, 46.0349916642712, 50.35732200068813, 54.35255019895492, 55.35226821899415, 52.72739064308905, 50.14310567609726, 49.95255301075597, 52.09464173163138, 56.01540373217676, 53.981431222731075, 57.065830153803674, 53.31372614829771, 59.817298304650095, 55.6311369711353, 58.61328755655597, 54.12138531284948, 54.015983381579005, 50.06060254189276, 55.77475455499465, 53.71147017325125, 48.85319502122941, 1.3727267206676546, 10.834813137208263, 16.639761155651463, 0.23305893124591923, 0.5501306189164039, 5.268284918800478, 64.77497808394894, 49.74480075220908, 61.62902539776218, 56.797265468105195, 47.03447826447026, 36.29321659764936, 26.18623160546826, 52.32433965129238, 20.521693652676, 0.22656610626126492, 0.0469010058910616, 0.096941800157149, 0.02188477436110618, 0.04369351832616714, 0.03503843315786893, 0.08221447993550571, 0.07301209389322227, 0.018046650877823273, 0.042345180596795776, 0.05672159041428278, 0.17953685725167876, 0.15741226864197563, 0.09060778519919804, 0.10769908421582754, 0.11993670295323096, 0.08879298419361153, 0.14077164382944185, 0.14971832504435895, 0.1151527519968729, 0.1762267292266892, 0.1869450960188143, 0.11876658025768497, 0.14780471401829876, 0.08936007311868091, 0.22548535538296546, 46.16274718315371, 62.997336387634284, 39.54148823215116, 55.520071137336, 45.87025211703393, 64.1367692332114, 69.8695093585599, 67.62549000401651, 63.74087264460903, 65.6314629124057, 49.816886071235906, 0.21845239244641798, 5.834250084815487, 6.254920363426209, 0.1302965405967928, 23.02520132833912, 69.89657371274888, 64.27238125954905, 64.91171583052605, 55.88240008200369, 53.12251844713765, 49.85504681064237, 49.85681187721991, 51.09475897204492, 50.68935063577468, 52.03764577065745, 53.994998701157115, 55.62336675582394, 48.92398988046954, 45.50192979074294, 42.84693625665481, 44.992755151564076, 43.845905103991115, 44.690105069068174, 41.635680890852406, 43.03537868684338, 44.96679298339352, 41.89998588254375, 42.32467266821092, 42.90667395437918, 42.51540184020997, 41.32042431062268, 42.102403717656294, 45.94693053153254, 44.68826155508719, 45.26742696762086, 45.36587061420564, 45.86376059439875, 44.534516411442915, 42.17099420485958, 43.97446863112911, 43.229159462836485, 45.396935785970385, 43.66372277659755, 45.07457187098842, 49.39410163510231, 45.25436547494704, 45.325905584519916, 47.825608561115885, 49.00195091001449, 50.4232648880251, 48.6669098946356, 48.38934336939166, 42.717207785575624, 43.99000121701149, 41.635202361691384, 43.78577909161968, 44.612230331667014, 42.59090746602705, 43.2517562373992, 42.00145759890157, 41.67265315209666, 43.29671836668446, 41.47728773855394, 44.28235115543489, 41.321616711155066, 41.92000958227342, 40.74278862245622, 40.682340975730654, 44.5696137797448, 40.40068341839699, 43.15382249893681, 43.10777779548399, 42.206448508847146, 44.31868014797088, 43.708273057014715, 45.52100035452074, 47.83450841903687, 50.5058817709646, 50.361322818263886, 49.72143911546277, 48.1153501233747, 45.31616241701188, 44.873271911374985, 50.76603689501363, 40.525308885881984, 41.67126071068549, 41.21793670039023, 41.27956890290783, 40.92764992867747, 43.38428528078141, 40.98166488832043, 38.871747447598366, 41.235940379481164, 43.22604902328984, 43.02908328271682, 42.60969169678227, 40.138598488223174, 43.63869805489817, 42.664063592110914, 45.46116067517189, 42.92278705104705, 42.38605776140767, 43.33402010702318, 48.258238146382, 52.69317580807594, 56.82005443880635, 58.44699867310063, 55.493297038539765, 50.3004397884492, 50.406481066057765, 53.70530812971054, 59.09743355166528, 55.45395958808161, 58.914658946375695, 54.95100582799604, 60.79518048994003, 57.562449286060954, 62.94340379776494, 53.1163485588566, 55.02174185168359, 50.928277892451135, 56.16039414559641, 52.151390583284446, 54.27129045609505, 2.775832933764304, 13.1519542970965, 20.693632710364557, 0.4608744196593762, 1.1083874082373035, 6.854898852686729, 74.50998706202354, 54.07128880100866, 68.48590112501576, 60.71877271898332, 54.31498958218483, 37.10461378097534, 39.40793545015397, 62.08379676265102, 28.649552637530913, 0.2931268128656572, 0.12927470187987053, 0.1788125057975131, 0.1962022420259253, 0.08066179591321176, 0.13516392618898423, 0.1928140036761761, 0.17181833755345116, 0.15463578214328136, 0.09623241806102377, 0.17043286754238993], [0.05733339972193203, 0.06328740059548328, 0.03724805672743148, 0.05581487172974214, 0.04128565801487815, 0.07881150205409335, 0.03192888035799467, 0.04874539704272344, 0.058573960371676, 0.02468760662351645, 0.020567321466402184, 0.022608078190035397, 0.05908651915829509, 0.09955664976469933, 0.13577866578294387, 7.606477929699806, 49.460432837086344, 43.059650313469675, 36.84896153788413, 25.595958040606593, 48.753347166122936, 62.99414357831402, 56.387766099745235, 55.66693252132785, 53.244774803038574, 50.55179311383156, 0.9870298879761851, 4.7252950360698085, 0.8776593761098, 0.13545566779230872, 10.790892397203754, 65.13948394406226, 59.761051516379084, 54.37430366393059, 52.47499788961103, 49.26997038625902, 47.17402050572057, 45.623707617482836, 43.10922122770741, 42.877656259844386, 39.76389054329165, 39.90278167109336, 40.07780959529262, 40.40413118177845, 39.44566472884148, 38.90933944332985, 40.37463888045281, 39.43794550434236, 38.732138526055124, 38.51066581664547, 39.12825868975732, 37.98730396455334, 39.175597775367, 38.04241326547439, 38.04824582992062, 38.0182671546936, 39.41738443989908, 37.945773909168864, 37.32726320143669, 40.56173593767228, 40.44262532264956, 40.9015190985895, 39.67324456860943, 39.978322598241995, 38.32669488845333, 39.267228264962476, 39.39077115827991, 40.02785821114817, 39.13966494221842, 41.19763059000815, 43.77050145979851, 42.174857739479314, 42.828971801265595, 43.726923927184075, 47.49294842443159, 47.373563243496804, 44.67978923551498, 42.26276197741109, 40.590863458571896, 38.25011061083886, 38.96084016369235, 36.17259194774013, 38.27925774358934, 38.56974455618089, 37.483754004201586, 38.906801669828354, 38.14906643282983, 37.65482817926715, 38.640570794382405, 38.42307929069766, 38.97487048179873, 37.545605859448834, 37.17768361491542, 36.390212889640566, 36.84972640006773, 37.2169190837491, 38.48193053276309, 38.69250297546387, 37.88334546550628, 36.00488708865258, 37.08019310428251, 39.67749641787621, 40.462786305335264, 44.36357559696321, 45.128375022642075, 43.609519543186316, 43.18671157283168, 42.98168536155455, 43.280573891055205, 42.09588866080008, 39.25350781409971, 37.42846427425262, 39.002127032126154, 40.188138023499526, 37.35780669796852, 35.774181119857296, 36.88039541244507, 36.17076020086966, 37.114658970986646, 38.743011336172785, 37.9667232882592, 36.0565564709325, 36.31689202400946, 36.107009918459006, 37.100130511868386, 35.16323274181735, 36.539827777493386, 38.70474077040149, 38.5161728243674, 40.45689882770662, 45.59909866702172, 51.14569487110261, 51.881013762566354, 51.90373605297458, 50.66315704776395, 51.41324758529664, 52.757071218182965, 53.284939873603086, 52.295157217210345, 52.31627918058827, 53.28703049690493, 52.94220316794611, 52.40655253010412, 51.53268767941383, 57.26093669091502, 57.73992084687757, 48.96292724917012, 50.746142633499645, 57.44909278808102, 15.442611613581258, 0.06736358973167597, 1.0107055594844203, 0.5907139734875771, 0.06971816862783126, 0.8289950196781467, 14.108996929660922, 57.87529753100488, 47.72769443450436, 56.450986862182624, 50.38069932691513, 34.272944927215576, 24.52239747970335, 34.253819450255364, 40.242035312037316, 2.420364949972399, 0.09498839086342244, 0.01576796160905712, 0.030863049042020595, 0.049188287793508464, 0.037212632821812745, 0.03995186446474926, 0.02504673140544084, 0.04873364525396497, 0.04645958602909119, 0.029787672270509987, 0.06708861779301398, 0.06944819924331481, 0.030623001136606744, 0.092277305290824, 0.05604542206011473, 0.04231287083858925, 0.04398491135948608, 0.028858091607089006, 0.015520462540969735, 0.04001858306207484, 0.0834219723999981, 0.03915378853919045, 0.12036064068876928, 0.04087154535696872, 0.0661337658041908, 0.1274335704323265, 13.684867120558216, 59.95114526441021, 44.97923866395028, 42.12075648769256, 34.564859482549856, 56.819830863706535, 66.34009791958717, 61.00316024595692, 58.705227913395056, 58.69677128330354, 55.17609496270457, 0.930293538878041, 4.499532724580457, 2.2332921624183655, 0.3363306784341413, 13.585530154166685, 66.16002974971649, 59.806048946995894, 57.34410270567864, 56.4544895387465, 52.18953171084004, 49.771802348475305, 48.56606183513519, 45.476469685954434, 44.44645135633407, 42.590483850048436, 42.73454466173726, 41.824762667379076, 42.099712971718084, 40.78389898423226, 41.46700328396213, 42.984274125868275, 40.68887564443773, 41.364868687045195, 40.50977629999961, 41.40295490141838, 40.707459834314164, 40.51357315432641, 39.8935523340779, 39.35595620063044, 39.49682812536917, 41.9379505034416, 39.835465954196074, 40.56155550864435, 42.20189855944726, 42.35673412199944, 41.81053230839391, 41.41851886626213, 41.66159206821073, 41.55135777688796, 40.27358685770343, 41.23279463860297, 42.842413763846125, 41.271222099181145, 41.76926112944081, 45.750290347683816, 43.74909316339801, 44.145350610056234, 45.651595669408, 49.013212034779215, 48.95790269297939, 45.908444235401774, 43.96925187879994, 42.04159913524505, 41.04219098244944, 40.70121934337001, 38.38766813278198, 39.547862083681174, 39.677935723335516, 40.040009713942005, 39.97087793965494, 40.932768621752345, 40.582536266696074, 41.419122911268666, 40.83149302390314, 41.0464467540864, 40.95718929844518, 40.037569999694824, 38.19086320938603, 39.11134542957429, 40.71757170461839, 39.540127169701364, 40.20068568568076, 40.15761021644839, 39.25156624086442, 39.39205377332626, 42.35685571547478, 43.09192357524749, 46.837057528957246, 47.437897959063136, 45.01551274330386, 44.51006827815887, 42.44803121013027, 45.68490051454114, 45.87068750012306, 40.92862659885038, 39.07427118670556, 40.253143464365316, 41.44797194388605, 38.95997331988427, 37.836967360588815, 38.89031987036429, 38.063190060277144, 39.32097650343372, 39.89282277322585, 40.36374253611411, 38.09545155494444, 38.034572447499926, 38.80926409075337, 38.52005989320817, 38.02995189543694, 37.68155520962131, 40.85934577449676, 41.41280005055089, 42.466525185492735, 49.877008161237164, 55.318257347229995, 53.953853038049516, 54.62985392539732, 52.23890650656916, 51.38988987092049, 53.3521810654671, 54.19991116369925, 53.58580135530042, 54.127308091809674, 55.85676347055743, 56.39733668296569, 53.67168165022328, 53.97861496094735, 59.27336362100417, 59.56867887127785, 50.6172731614882, 52.428921807196836, 57.31062135388775, 18.504548111269553, 0.01622209182730125, 1.9492713770558758, 0.5109505229178937, 0.005002920431340294, 0.6642884448651345, 14.544378057602914, 65.44158097236388, 50.11665321165516, 64.39404925992413, 51.769798878700506, 47.08018956645843, 30.088115238374282, 31.872060183555853, 49.35179102805353, 4.243304873666456, 0.11922021156116841, 0.025283012073487047, 0.021629239988302993, 0.006438368103361779, 0.0777489151204786, 0.030156459336379365, 0.03511047606626826, 0.032543533767062816, 0.023838645222807126, 0.018369053235097278, 0.06643539760261774, 0.12259335031793003, 0.14558917241952113, 0.1399172719327673, 0.20961380623761686, 0.19044625572860244, 0.18627141361996052, 0.1396599123554845, 0.1333095337594709, 0.18052195439175253, 0.21802796441460812, 0.1591491738274213, 0.250159990222704, 0.24032132219403024, 0.15113532723438355, 0.41882924675460786, 15.018376881076446, 68.88132310682728, 53.802441704657774, 44.25059564651982, 40.36016533451696, 60.178709414697465, 73.47984713892784, 66.05812657263972, 66.36251818749213, 65.20565825123941, 62.19731015543785, 0.9971143629762435, 11.072490138392295, 5.954316287271439, 0.43360950365181894, 17.88715527903649, 67.44067576623732, 64.11924800565167, 60.07096975080429, 59.57660598139609, 53.59142995649769, 51.72092222398328, 51.96124584444108, 49.41442735733525, 46.167685447200654, 45.835825474031516, 45.01601480668591, 44.33652300988474, 44.00057592699605, 44.34019434836603, 41.6749987294597, 45.24597160277828, 44.24892471682641, 43.343547544171734, 41.70008228671166, 45.577709982472086, 44.97024859151533, 43.20791982835339, 41.39025034443025, 42.23152029898859, 41.97142793286232, 43.59004889765094, 42.92925111709103, 41.518958999264626, 43.80244524248185, 47.01156770029376, 44.998775989778586, 42.77491369555074, 43.68011436154766, 42.834623936683904, 44.29769546754899, 43.6488962173462, 45.16474716124996, 45.67480041134743, 44.44130128429782, 47.660539534784135, 46.55393300517913, 45.335374186115885, 46.57792222115302, 50.810646010983376, 50.18982110484954, 47.547794926551084, 45.94880150210473, 44.9654358433139, 42.52245818414996, 42.852258912978634, 40.538519428622344, 42.627350207298036, 42.36464946500717, 41.77197148722988, 44.213792047192975, 43.548907156913515, 42.22845692788401, 43.626460259960545, 43.02364687765799, 44.100867009931996, 43.740467871389086, 42.26744136502666, 41.902500121824204, 41.847712455257295, 43.21044975711454, 42.01021625149635, 42.13271971671812, 43.50856950206142, 40.993741866080995, 41.165353405860166, 44.86048890698341, 44.06565981526529, 48.990823145835634, 48.88367968220865, 46.69163565481863, 46.94579347487419, 46.19471450005808, 49.78521293209445, 46.43322990786645, 43.315031913019, 42.180309834018836, 42.87849564706126, 43.50826747955815, 41.853701914510424, 40.67181333418816, 40.978393631596724, 38.86566385146111, 41.72023542465703, 42.97212654544462, 42.55052274273288, 39.36876666161322, 40.42562577032274, 42.16767980206398, 40.627196373478064, 38.518106552862356, 39.97572598918792, 43.12733081079299, 43.010565773133315, 45.71457716726488, 50.78793941005584, 56.88475785716888, 55.68146490281629, 56.67570729409495, 53.15724711264334, 53.812667323697, 54.260660832928075, 56.808299095399924, 54.33331881800006, 56.41064920733052, 56.3381245828444, 57.37839991046537, 56.46459748668056, 56.96695896887011, 60.59371579077936, 61.49810452615062, 50.64477682113648, 53.079403754203554, 56.5819626469766, 24.643206481010687, 0.08824522366687175, 2.817203642860536, 1.4824015839445976, 0.21314632958702504, 1.1828520124958408, 17.367774632669267, 71.49522981336041, 55.93971767733174, 67.75951739280455, 58.894513653170684, 48.549772231809555, 35.11333627085532, 42.95713132427585, 59.889626810627604, 8.432941917450197, 0.4852305611054744, 0.18845055072057634, 0.16520689151460127, 0.1646249864490763, 0.2749680775788523, 0.17783491631909726, 0.10009648894230205, 0.14496471883068163, 0.1553891223645018, 0.15199938248242104, 0.27080846529814506], [0.04499824650044884, 0.03975961853059069, 0.04365180483869007, 0.07581157835140344, 0.0150135163060059, 0.0735969100928595, 0.06272496182411429, 0.11221863524687868, 0.040743076242506504, 0.04943007280329063, 0.025032399815597364, 0.02835267467514402, 0.036021707008682916, 0.018497233151368076, 0.019732071124317668, 0.641990689741027, 41.12925975553451, 40.81900419727449, 30.63568792035503, 37.17591070359753, 31.168896882764756, 54.941086153830256, 56.97074013371622, 57.624116789910104, 50.446504931296076, 58.73133913163216, 4.444378316402435, 3.6428022576916606, 0.6029846795624303, 0.323804650575884, 3.9887717318150306, 58.5154361878672, 60.8217937715592, 54.88192504452121, 51.936511378134455, 52.178635366501354, 53.80032362476472, 48.272935267417665, 45.928142378407145, 41.405853532975726, 42.04933797159503, 40.0967271866337, 40.91571807861328, 41.747852833040305, 41.50365391085225, 40.183168380491196, 38.71973206920009, 38.49731014620873, 38.982911340651974, 38.311605530400435, 37.465856229105306, 37.59237620138353, 38.250043930545935, 38.46647639428416, 40.5074542568576, 37.74844338816982, 39.31636379611108, 36.94522434665311, 38.79223708183535, 38.44315790360974, 39.33184931355138, 38.880035415772475, 39.244478517963046, 37.95679576935307, 38.75138167412051, 39.56097064479705, 42.0592184220591, 39.225207913306456, 38.94715501416115, 43.8565190376774, 45.03137088591053, 41.93046662115282, 41.5356957527899, 45.00425946327948, 45.88369015724429, 43.98674172739829, 44.0068595640121, 40.10460722830988, 39.473592004468365, 39.73799505541402, 37.20796823501587, 36.95165311136554, 37.473877476107695, 35.77530684009675, 37.55031662602579, 39.859337499064786, 40.2821062457177, 40.12457209248697, 39.70587868844309, 42.107377283034786, 38.80288631685319, 38.72495666626961, 38.56140167482438, 38.44629187737742, 37.339171517279844, 38.19178104400635, 40.12115178569671, 39.28343157614432, 37.895532269631666, 35.84512895153415, 37.38772261527277, 36.969484206168886, 37.40794243351106, 40.037228753489835, 40.63526076655234, 44.07919983710013, 42.49622145006734, 43.30344130915981, 41.213900581482925, 41.72725646726547, 40.78709179355253, 35.6136816547763, 36.6949418283278, 39.827017168844904, 37.9800985705468, 38.02993620595625, 37.84390995579381, 39.1399081291691, 38.277410307238185, 38.30990714411582, 36.93754434585571, 37.281732328476444, 37.21882535565285, 35.055155754089355, 37.13597705287319, 37.32232885975992, 36.86341154959894, 38.48171088003343, 36.68578309397544, 35.02407097047375, 38.04888125388853, 43.91471524392405, 46.987774602828495, 51.2682532495068, 51.795741435020204, 52.89493076262936, 54.56318932194864, 51.48655276144705, 53.34909416014149, 52.038665586902255, 52.161588745732466, 46.915214677010816, 48.053615939232614, 49.277548405431936, 52.572653139791186, 54.64684955535397, 52.21488198926372, 52.19632917834867, 49.19795959226547, 1.685034046250005, 0.7765885382410019, 3.768538736527966, 0.2108351036065048, 0.2376172003606635, 0.44899919881455364, 19.169191775783418, 53.28145680889007, 48.63586041235155, 53.12255767083938, 45.75946084914669, 24.232734364847985, 23.87146249894173, 41.60705151096467, 28.98134789159221, 0.18668553010830957, 0.14821112366212955, 0.035843013169904875, 0.028654055579775767, 0.020687074415505897, 0.04903069584660473, 0.06418637413110945, 0.046237451174566825, 0.08748362501782757, 0.039782926755686926, 0.020032415895031828, 0.06200662416015422, 0.05202553655591704, 0.024729898507376353, 0.025723070214172045, 0.09946775292196583, 0.026610828222586747, 0.046665943302815004, 0.02255640364432287, 0.07692199981501026, 0.16125446005213648, 0.06200197400645383, 0.06139930795818087, 0.050521403355824376, 0.038069088477641344, 0.043271940141435594, 0.08186574139061474, 1.6207224971825078, 50.79753352749733, 47.130615557393725, 33.02077531814575, 38.45414838483257, 42.1822984756962, 60.89671496422061, 62.63825124309909, 61.249590996773016, 55.04858655314292, 62.88698442520634, 4.360445478270131, 3.4679478983725276, 0.4022048323625519, 0.34534774780754124, 5.459057727167684, 60.839118880610314, 61.76837936524422, 57.05042700613699, 54.964530160350186, 53.67560009802542, 54.93198625503048, 49.51290630525159, 48.315547896969704, 44.28926629404868, 43.02845962585942, 43.232618993328465, 43.472566066249726, 42.40965866273449, 42.61221378080307, 42.02885143218502, 41.44323372071789, 41.49130236717963, 41.9890982104886, 40.072043711139315, 40.60195592141921, 39.04705778245003, 40.3567450277267, 40.57534263980004, 43.253121222219164, 39.152487170311716, 41.240733515831735, 38.83091165173439, 40.11073789288921, 41.23984706017279, 40.509352684020996, 42.56861663633778, 42.232065508442545, 38.992356408026914, 40.82748436158703, 41.35492940102854, 43.6671862294597, 41.23521866336946, 39.08730522278817, 45.34705108211887, 47.1704315370129, 43.70457033957205, 43.5503545115071, 44.40376812411893, 46.038537486906975, 46.3721429148028, 45.0497942586099, 41.79350529947589, 41.20680109147103, 40.573805070692494, 40.070941525120894, 40.15915563029628, 39.34547562753001, 39.37980421127812, 40.572836245259936, 42.621647081067486, 42.02985163657896, 42.59972103180424, 42.191849447065785, 42.11283722231465, 42.4829363822937, 39.73619076513475, 41.80866133782172, 40.038585893569454, 39.25212321742889, 39.47364691765078, 40.054412657214755, 40.973153345046505, 40.407429895093365, 38.461895065922896, 39.59690347794564, 39.56483025704661, 41.631456498176824, 42.79535316651867, 42.47229499201621, 45.86746331184141, 43.30966611062327, 44.64642947719943, 42.89454990817655, 46.20162179393154, 42.20106701697073, 36.403129254618, 40.03745625095983, 41.65683423319171, 39.416984358141505, 39.06748940867763, 39.38074950248965, 38.97177573173277, 39.009289280060806, 40.17167975825649, 39.01598476594494, 38.23651959819179, 39.456921931236025, 38.257249324552475, 39.8884375633732, 40.04243766107867, 39.793712323711766, 40.205098352124615, 40.09510332538236, 39.36397744763283, 42.44871762491042, 46.07676490660637, 50.57287585350775, 53.012405749290224, 54.299825699098655, 54.958360272069136, 55.30047724323889, 52.982364316140455, 54.978262378323464, 53.237130103572724, 54.4936417764233, 49.51283570258848, 50.809932139612016, 52.89458167168402, 53.694172520791334, 58.086093548805486, 55.8378105778848, 51.52699239792363, 51.25706664977535, 2.8204376370676103, 0.889140337465271, 5.261603161211937, 0.48702219561223065, 0.1710049360389671, 0.24333626122003604, 22.121697087441724, 59.58838093665339, 55.400199582499845, 61.407223209258056, 51.272964016083755, 36.45337481652537, 21.867037204004106, 44.446427822113044, 38.55711060185587, 0.904278357423121, 0.09590303855797938, 0.07141710649574957, 0.08707919188084141, 0.038606617900152365, 0.0422767268103217, 0.010511366962154788, 0.09015125808336082, 0.0852800650341857, 0.05748083717339943, 0.07542720905715421, 0.036868751274361726, 0.13977713912965792, 0.11341737898727579, 0.1907184314463408, 0.17386736228100716, 0.1917281966175764, 0.15404932651548617, 0.09563090880551646, 0.15174488807397504, 0.39059896803190636, 0.19075086760905482, 0.20364245730302027, 0.1293168826809814, 0.1530230291668446, 0.16132595137723033, 0.2465952758587176, 2.2473259125986407, 61.32379831806306, 54.59733747666883, 37.895034128619784, 48.79786606757872, 44.08288294269193, 63.88805174058484, 67.03427899268367, 68.26078061134585, 59.80321307336131, 71.4956691188197, 4.774982150523893, 7.334762109864143, 6.148364274732529, 0.6093602471293942, 7.589613699143933, 64.68712091445923, 63.48414174972042, 59.599387107356904, 56.86971164518788, 57.06701863196589, 57.462766170501716, 52.34551652785271, 50.86688887688422, 46.56746518227362, 45.7422455664604, 44.80166119913901, 46.24642310603973, 44.924023459034586, 46.98030248765023, 45.75128270733742, 43.999230554026944, 45.3097846431117, 45.63726332879836, 42.185040212446644, 43.98078364710654, 42.4220690419597, 43.078065841428696, 42.881813972227036, 46.12423735280191, 42.61092724338655, 43.306943985723684, 40.36937505968156, 41.888375666833696, 42.74686874881868, 43.094076956472094, 43.7284654186618, 44.23847160031719, 39.56231994013633, 42.865838158515196, 43.23023811463387, 46.68766229383407, 42.9664194968439, 42.61585766269315, 47.54876375198365, 47.765812027838926, 45.34025753698042, 46.986189965278875, 46.34581204383604, 47.68976511493806, 49.238795388129454, 47.723132717993956, 43.49685730472688, 42.67344590156309, 44.06713854882025, 42.403661358741026, 42.438358645285334, 41.67118618565221, 39.862404792539536, 42.0048386819901, 44.93760662694132, 45.257875996251265, 45.25942533246933, 44.25797362481394, 45.79943764594294, 43.35225520595428, 43.67715689443773, 43.745155103745006, 43.24346434685492, 42.173524133620724, 42.34059356874035, 44.44698872104768, 43.81883682743196, 41.83982456884077, 39.209255633815644, 40.46487692863711, 41.44528904268819, 43.07238232704901, 43.89133791769705, 44.20376646903254, 46.37768914622646, 44.30504598925191, 47.010492970866544, 45.746477803876324, 47.03032839682795, 45.246163798916726, 38.65864507613644, 40.98132364211544, 45.164511819039625, 40.88965000644807, 41.05804128031577, 41.847265305057654, 42.269684960765225, 41.72589932718585, 41.85628283408381, 41.280008208367136, 40.70851495189052, 41.82002836658109, 39.01576903558547, 41.38739878131498, 43.451087167186124, 42.1002071903598, 44.291933505765854, 41.50585828288909, 39.198751526494185, 42.9918796016324, 48.28582809817407, 52.65630552845617, 55.1056178154484, 56.86553432095436, 57.05376886552381, 58.47833841077743, 55.65143915914721, 56.98862221933181, 56.57732640543292, 56.71510358010569, 51.67308891973188, 54.19974642415201, 55.22572863486506, 56.69515832777947, 61.00297589455882, 55.490884780883796, 51.34198988637617, 53.58166325476862, 4.874847656296146, 1.742410599704712, 9.001111945798321, 1.1621999980941897, 0.3547466354024026, 1.0078615959613555, 27.189830810792987, 66.70011658822337, 60.52589016575968, 63.630465768998675, 57.68486645913894, 35.45914811472739, 32.52500537903079, 54.64760657279722, 49.48103704760152, 2.2068374916430447, 0.36350691210358377, 0.23339790983065484, 0.18122415058314803, 0.11613658509187161, 0.2660602216999377, 0.12134795182294424, 0.18211791472088906, 0.10192505654788787, 0.14148954482328507, 0.19699111340507386, 0.18649213887270422], [0.034883936206179286, 0.004486595364963456, 0.044617232671307946, 0.053378761926245306, 0.0113185181567866, 0.05475277892283855, 0.03781259074927338, 0.025631867446786454, 0.010069006727257324, 0.04894329287532357, 0.006051789603060893, 0.023969539005549687, 0.015952783193619504, 0.03108400412114157, 0.09954374884405445, 0.10003452009010701, 22.00305715683968, 51.722753970853745, 31.224639646468628, 24.882302399604555, 24.486056720056844, 47.24167746882285, 58.77884687915925, 57.88369532554381, 48.417666804405954, 57.46399779473582, 10.333512656150326, 2.1685637389459917, 0.5614764423620316, 0.17433614680363288, 1.3219453875095615, 46.129763972374704, 66.84230250696983, 56.586979358426994, 57.52462194811914, 52.62760162353516, 55.02171831746256, 48.57831139718333, 48.4262607174535, 44.49899150479225, 43.32169994231194, 39.69019705249418, 39.14850596458682, 38.718959362276145, 40.35960835795249, 37.90752295524844, 39.24079541237124, 39.36309491434405, 39.55281211483864, 38.87530895971483, 37.410695937372026, 37.82684764554424, 40.01118813791583, 36.945396930940696, 39.185882229958814, 36.807109848145515, 37.67340452440324, 38.04672787266393, 39.084410513601, 41.14730658069734, 41.41164295135006, 38.7822977958187, 39.666721667012865, 39.633973798444195, 38.45476027457945, 39.26103876483056, 41.18890331637475, 39.04478280775009, 40.07153380301691, 43.26357826109856, 44.41209531599476, 41.24221617175687, 42.8250611982038, 44.30812504983718, 45.48807597929432, 44.15946329793623, 40.600273224615286, 40.41709853756813, 39.379478654553814, 39.86735090132683, 38.018031812483265, 37.399713300889545, 37.80993046299104, 37.97823936708512, 38.90979051589966, 39.861157478824744, 41.50780770086473, 42.37693432838687, 41.85860879959599, 42.28906931415681, 39.99860125203287, 39.62573289871216, 40.39869085434945, 40.34759413811469, 38.79603785853232, 39.988112834192094, 38.62319861688922, 37.788263290159165, 36.66987396055652, 37.26741959971767, 37.14682632876981, 38.20653307822443, 38.026853223000806, 40.38189526527159, 41.23023725325062, 41.94215528426632, 42.5679890571102, 41.567259065566525, 40.828743442412346, 41.335811768808675, 39.879447490938254, 36.4411291768474, 37.82162697084489, 39.20125399866412, 37.21110220878355, 36.025114751631214, 37.48565635373516, 40.48680297790035, 36.766764348553075, 37.37421005002914, 38.29797529405163, 38.27051478047525, 36.65542002647154, 37.002808663152884, 38.1001897781126, 37.38257646560669, 37.6914317377152, 36.51869012463477, 36.989115668881325, 38.181069051065755, 37.330793334591775, 35.731729307482325, 37.2763547589702, 39.7638552419601, 42.34852460122878, 45.50010196624264, 49.14221486737652, 50.38006782531739, 49.52301817555582, 51.61093111961119, 46.17460843055479, 46.423302388960316, 46.94265950110651, 49.82272255805231, 52.022850590367476, 57.78193335379324, 55.17240401237242, 53.770811711588216, 41.84447649986514, 0.6582172899957627, 0.9421653889359968, 1.6089507288509801, 0.2443587281290562, 0.031167348741643855, 0.0673112276220514, 27.165557222981608, 52.9658236811238, 48.10919592457433, 50.103364221511356, 34.654128705301595, 31.42611219036964, 31.706436141844723, 45.862285783213956, 12.188280897755778, 0.20425785573259478, 0.09740013524048752, 0.015406179459645383, 0.07077508651080631, 0.11254267511709083, 0.07991567224023804, 0.007396820226624128, 0.030086586372025555, 0.0955913633468651, 0.044759590959837364, 0.04280714310645577, 0.01801935133464154, 0.022774009003994927, 0.1061977663888566, 0.06667840835307876, 0.06123739910582381, 0.03312548479786323, 0.05992807440399643, 0.0701911666340405, 0.04849710028558489, 0.02942781587461791, 0.040039727088784983, 0.0414328541486494, 0.02213379698655298, 0.01324205576712566, 0.09574866418035761, 0.048572245850077564, 0.030776456208719365, 31.64994420543794, 57.11403608322144, 36.05608186414165, 32.07684516906738, 31.54282427603199, 55.619820933188166, 61.95058522685882, 65.77676711543914, 52.621341520740145, 65.46721758381014, 10.609841673604905, 2.451834616161162, 0.4503865840454256, 0.27478902750918943, 2.237532489722775, 50.72976281566005, 70.45605274938768, 59.25819189317765, 59.41820498435729, 54.12102053242346, 58.23860706821565, 51.73321100973314, 51.64640503544962, 46.544962544595045, 45.076176120388894, 41.850901342207386, 42.211728019099084, 39.67666487539969, 43.07066432891354, 40.528180060848115, 41.719207763671875, 39.52098992563064, 42.024348551227206, 39.969532566685835, 39.40003579662692, 40.53196907043457, 41.33730226947416, 40.48379451997819, 40.87718863641062, 39.73121719975626, 39.180924354061005, 40.082473293427505, 41.21694826310681, 42.838738502994666, 43.26265258173789, 41.40711653617121, 39.92982249106131, 41.333477958556145, 39.41767077292166, 41.479178320977, 43.00786718245476, 42.04783178144886, 41.67865830083048, 45.57996534532117, 46.390429004546135, 45.56779423067647, 44.1588867095209, 45.07369718243999, 46.27821391628635, 45.61186205956244, 41.953592915688795, 41.853933334350586, 42.087851724317, 41.58300738180838, 39.750013197621996, 41.493534195807676, 38.67183992939611, 41.15599463062902, 40.71644598437894, 41.62396084877753, 43.97401363618913, 44.610022037259995, 43.58734246223204, 45.043761653284875, 43.17263418628324, 42.62022718306511, 41.781157678173436, 40.87205033148489, 40.25607347488403, 42.21032381057739, 42.16321222243771, 40.14802002137707, 39.65986536395165, 39.52121742310063, 38.79415512084961, 41.069278870859456, 39.99088594990392, 42.22972385344967, 42.50104988774946, 44.40642749109576, 44.2631080073695, 43.0762380169284, 42.78917543349728, 44.76511255387337, 43.476692399671, 37.9927089906508, 39.16743924540859, 41.173790424100815, 38.616185419021114, 37.714095192570845, 39.5434376501268, 40.139473176771595, 39.13549154035507, 39.66408975662724, 41.62457666089458, 39.40194599090084, 39.65421715090352, 38.623492794652144, 38.768577344955936, 40.44473163543209, 39.97616137227705, 38.50480579560803, 38.89838818580874, 40.71336692379367, 40.5277995909414, 38.57468674259801, 39.41831796400009, 42.69726645561957, 45.62138165197065, 49.407092525113015, 50.86039735424904, 52.8345537185669, 51.70706841253465, 53.165793957248816, 48.608337140852406, 48.59960986721901, 49.686278989238126, 53.49535542149698, 55.082817077636726, 60.40507724208217, 56.61305527533255, 53.66403695075743, 44.55818399306267, 1.1901796128480666, 1.7422263708806809, 4.147622085386708, 0.3013768750092676, 0.05198657715452775, 0.1533638463625985, 29.91652331044597, 60.10432558674967, 55.470457077026374, 52.91378559604768, 45.9251025415236, 39.29093507028396, 26.67465494525048, 54.360422395890765, 16.516851725116855, 0.22585779668823366, 0.04956031158085793, 0.07601764834215564, 0.04516614999081339, 0.008426437608807558, 0.027699533008760022, 0.04273905321174572, 0.03877325351500223, 0.08065428059067457, 0.045742002961736535, 0.05254269570052143, 0.09758321493263207, 0.13234648462985793, 0.13599153097358443, 0.10243301880696129, 0.12456529893942418, 0.12009520654476459, 0.2599681373084745, 0.12614531697885645, 0.11367884479583272, 0.12309733658067643, 0.12097844463442603, 0.15362125190515674, 0.08667987621118946, 0.06314477417618036, 0.16159687071077286, 0.14202577572676445, 0.17918752115820685, 36.2202291334829, 69.90226899423908, 40.12060657624276, 36.05167312006797, 38.72465464376634, 58.336952655546135, 70.23223446261498, 70.31703610574046, 57.83602283846948, 70.18361276195895, 12.032564763099918, 6.608573025272739, 4.07036536643582, 1.3448514164455476, 3.500719056014092, 51.42293976199243, 72.73126279154133, 60.48614086643342, 63.368341615123136, 56.27282496421569, 60.817796876353604, 51.9859960002284, 54.49366138827417, 50.17477489286854, 47.175256052324855, 44.341025890842566, 44.61210089345133, 41.299529844714755, 45.13027737217565, 42.227625385407485, 43.59537547634494, 42.53066770492062, 45.283920534195445, 43.18889241064749, 41.57479001629738, 43.43640573563115, 44.22038162908247, 42.480598649671, 44.19169733601232, 41.659893681926114, 40.21638301111037, 44.34683492106777, 44.186457049462106, 46.62284512673655, 45.98861355935374, 44.13632131391957, 42.40272391226984, 43.02831449816304, 41.61673192054995, 43.47342898768764, 45.202719626888154, 44.33180832093762, 43.755106156872166, 47.09553387857253, 49.21687326123638, 46.483808871238466, 45.73366734289354, 46.344180337844364, 48.967269312950876, 46.76568608130179, 42.74227957571707, 43.97322916215466, 43.57756399339245, 44.49546921637751, 40.76245930887038, 43.633089065551765, 40.32661730243314, 42.868171968767726, 44.026200771331794, 45.76985513010333, 46.475752322904526, 47.985704022069136, 46.06318173869964, 47.49940464573522, 44.64771209224578, 43.85065509426979, 44.48427084953555, 43.951483541919345, 42.00001024430798, 46.04119685388381, 44.922387830672726, 40.255336069291644, 42.90487750884026, 41.92459483300486, 40.86741016757104, 42.03451925708402, 41.30900629105107, 44.62225983219762, 45.683543374461514, 45.833409294005364, 47.439792463856364, 46.541593228617025, 44.93459424664898, 46.93232013333229, 47.19550724952452, 41.83784769427392, 41.9321414732164, 42.185389303391986, 40.385001782448064, 39.86137713155439, 41.126259142352694, 44.32217105742424, 40.882832927088586, 41.76228323290425, 44.46192510666386, 44.167865014845326, 43.38688973457583, 40.53954316723732, 41.913623963632894, 43.56232558527301, 42.23393647901474, 40.009132815945534, 39.886613661243075, 42.91737418020926, 42.76821820966659, 41.04923163690875, 41.65109580562961, 43.654838608157256, 45.48749939087899, 51.07825363835981, 54.050821873449514, 55.837732130481356, 54.20334323760002, 56.025088064132206, 52.338515097095126, 49.71407682664933, 53.16081646950015, 53.91329573046777, 58.23161740456858, 62.3492157074713, 60.31015980628229, 54.13353289327314, 48.70841641579905, 2.580056161649766, 2.3855825970249795, 5.990206954940673, 0.6120245783559738, 0.23552103058224727, 0.1793857387477352, 37.117636049947436, 66.21251106262207, 59.263106623003566, 62.84729788380285, 47.020973543966974, 43.10185501652379, 44.41688452997516, 62.15175574825656, 24.914216764511604, 0.3032099701944859, 0.16388791793536756, 0.18414677601427804, 0.20653715116843102, 0.1609944191671187, 0.11328325997437201, 0.10693309588297721, 0.08705529759848311, 0.18092629559818776, 0.12789890755929295, 0.2122584949698179, 0.18909328316728916], [0.018354229433762453, 0.07603993383987297, 0.051171559194523486, 0.03949182866621883, 0.049724648931934956, 0.021967230319616296, 0.04286607825047067, 0.05860442385798501, 0.0258330229835044, 0.05758872916621547, 0.03251895000557265, 0.038030113754493576, 0.019475249723801692, 0.06386141878582778, 0.03044624933071675, 0.05310971567767763, 2.9195615697291593, 39.08251993117794, 30.728271545902377, 34.45899078922887, 30.942619269894017, 40.21638693348054, 56.79914036104756, 54.32194394450034, 51.518402407246256, 54.91955234158424, 12.281027301665276, 1.2253798207929059, 0.9582619993917404, 0.07792370574128243, 0.240375867654239, 38.02995581780711, 65.81793631276777, 53.928573362288944, 59.34930070754021, 52.55080946030156, 56.613188635918405, 50.4745263438071, 51.20044723633797, 46.95505026848086, 45.05664271693076, 41.6234980090972, 44.58959433340257, 40.808719742682676, 41.539108214839814, 40.91784008087651, 46.093317308733546, 43.03246436580535, 43.71349765408424, 39.31234336668445, 39.512078300599136, 38.59699326176798, 38.3866169375758, 39.305702793982725, 39.80164335620019, 38.48349948083201, 38.30721247580744, 39.76230590574203, 40.07997082125756, 39.71147983304916, 41.48419895479756, 40.37982425382061, 40.7259734215275, 38.95961246182842, 39.171432218244, 40.389065357946585, 41.295591785061745, 37.848808996139034, 42.105843636297415, 44.40345041213497, 42.6344536196801, 41.010266811616965, 43.48412136877737, 42.15230018861833, 40.7587722809084, 39.58437934998543, 40.44134662997338, 39.70942843344904, 39.870108327557965, 40.31389705596432, 39.473486100473714, 38.5537059845463, 38.2901736997789, 39.447829877176595, 42.6835185481656, 43.33028601061913, 43.716992485907774, 44.00323137160271, 44.49076237217073, 45.394598053347686, 43.848635073631044, 42.08985605547505, 43.52520819633238, 41.562089381679414, 40.89990308207851, 37.95034739278978, 38.13549110966344, 40.1111222851661, 39.5760247015184, 38.159480325637325, 38.237084419496604, 37.344003877332135, 39.10735637910905, 39.210946175359915, 40.67074644950129, 41.23173559865644, 41.26595435603973, 39.280297602376635, 41.12288198163433, 41.86599070026029, 40.78546008756084, 37.345106063350556, 36.76196336746216, 38.96166386142854, 37.79571971585674, 35.909102809044626, 36.46106658443328, 37.08275441200503, 38.35124892573203, 38.608799595986646, 35.92458440411475, 37.79721021652222, 37.104711840229655, 37.01935322053971, 37.336763181994044, 37.04739816727177, 37.847593061385616, 38.1354401188512, 38.759571583040305, 36.55613307029971, 37.041526379123816, 37.308094578404585, 37.720582792835856, 37.35907754590435, 35.95323731822353, 36.988743043714955, 38.78689481366066, 41.01485990708874, 41.87319609426683, 41.52343834600141, 43.116893383764456, 44.52604409187071, 49.29551286082114, 49.538695889134566, 50.590220574409734, 52.95024794916953, 56.59034475203484, 57.351076679845015, 50.04252433776856, 1.9985905241581703, 0.04913752680764564, 0.7307083904743196, 0.07965718651370657, 0.022006339108150814, 0.09883098063930389, 34.72871257412818, 47.87926266270299, 51.302346491044574, 53.059756602010424, 37.23422850331953, 27.34340533133476, 33.70186351960705, 49.052827973519605, 2.7752896854954385, 0.08023700015919824, 0.09611805645568718, 0.031043231006591555, 0.03647508167271172, 0.12294823288797371, 0.13446485563631982, 0.041196611784999414, 0.0372519446236472, 0.04926392365427268, 0.03457953883034568, 0.02762817957949254, 0.03255215225621097, 0.07236243601167396, 0.0038412687530170286, 0.04610104538920907, 0.06775909794434425, 0.039279691259106325, 0.030190213170323162, 0.06031157801889124, 0.03767452638355955, 0.06050566256406808, 0.07683461216548759, 0.05020395184176103, 0.025321762715916962, 0.05291814390089243, 0.043955371009125825, 0.034128458599650094, 0.17619631553609527, 6.859180610026083, 52.97898323305192, 31.846558893880538, 31.31003356749012, 34.44378768244098, 48.71444117638373, 60.87745612667453, 64.03399528995638, 53.69012855714368, 62.30479094289965, 13.870070653577006, 1.3515705591247928, 0.8994878564150104, 0.042218350910491524, 0.11953189443316191, 41.010874778993674, 68.28978261639996, 57.14858039732903, 61.179043246853745, 56.12393571484474, 58.607298097302845, 53.44984808275777, 52.8259245041878, 49.539711783009196, 48.36108269230012, 43.00414485316123, 46.2277957700914, 41.88901109080161, 44.315291220142, 44.599094313959924, 47.37783078224429, 45.53550920178814, 45.19238025911393, 40.42745751719321, 41.50641918182373, 41.98162217294016, 40.13697070460166, 40.904531478881836, 41.56837694106564, 40.530247149928925, 39.72702810841222, 41.252214293326105, 43.42206555028116, 40.74212181952692, 44.162997353461485, 42.87975865025675, 42.87775824146886, 38.57678913301037, 43.01559032932405, 41.58570205011676, 44.11991796185894, 41.06902391679826, 43.40081807105772, 47.010253706286036, 44.639671233392534, 42.95411502161334, 42.79585130753056, 45.26175522035169, 43.72570014769032, 42.22451886823101, 42.99002039817072, 41.3663278087493, 41.258293967093195, 42.29976561761672, 40.44454336166382, 40.44799896978563, 39.395376020862216, 40.424684401481386, 44.01644583671324, 45.82995368588356, 45.51280652323077, 46.06737867478402, 48.2692756960469, 46.30729044637373, 46.02754308331398, 43.67314038738128, 44.84529364493586, 43.990546426465436, 43.05566126300443, 41.85147793062272, 40.007807054827296, 40.949619124012614, 40.025783277327015, 40.09200073057606, 40.132663942152455, 39.31674818838797, 41.23305743740451, 40.994416513750636, 42.07891656506447, 43.01922244410361, 41.99238123432283, 41.8742629789537, 42.11391587411204, 45.10160092384585, 42.16349463309012, 39.00171518325806, 37.84241161038799, 40.27332013653171, 39.11002359082622, 36.91006814279864, 38.871355210581136, 39.107972191226104, 39.50281366225212, 40.394878310541955, 37.992218694379254, 38.53216824993011, 38.6302000476468, 37.844349261253114, 37.95412463526572, 39.13516990600094, 40.20394909766413, 39.046571408548665, 40.508050457123794, 39.27550054365589, 39.49850689980292, 39.470505099142756, 40.568772669761415, 40.00603806587958, 39.15598200213525, 40.72077235867901, 42.913204700716086, 44.38092031786519, 44.007589124864154, 43.916311648584184, 47.18309294792914, 47.155699114645685, 51.18281226004324, 52.462724793341856, 52.758314609527595, 55.45231611497941, 58.423990049669825, 58.224741489656516, 50.34888498244747, 2.8765191954951135, 0.07873475536583893, 2.2318482398986816, 0.1706791494882876, 0.20663164045301177, 0.3685036133373938, 40.59205193673411, 53.92958141142323, 57.209432048182336, 54.249136909361816, 48.159908248532204, 29.813712104674313, 32.23621891390893, 58.58851386654762, 3.8777983188629155, 0.10586538382114903, 0.03584577874731153, 0.08661972298737496, 0.026641398961205157, 0.03367119603940556, 0.019628867589598222, 0.034212812540992614, 0.028530211721156395, 0.06907866907215889, 0.031182459825950287, 0.025616091781205712, 0.016232435929498846, 0.2173699714964436, 0.1285633739204176, 0.17573840946199434, 0.09091753752962237, 0.1258858659815404, 0.1374380735139693, 0.193546092618377, 0.11110409989111847, 0.21627783655158936, 0.20689889788627627, 0.1776654883137634, 0.08603843079218942, 0.16250411799598127, 0.1344362345914687, 0.13297922729003814, 0.21920167240163974, 9.057925516559232, 67.78331049026983, 41.61710454571632, 42.586310448185095, 44.794342056397475, 52.21638033466955, 65.68755280586981, 67.0891058829523, 61.95962236773584, 69.25681160342309, 16.676819709039506, 3.783345929076595, 2.913321569081276, 0.18142457450589827, 0.810531442684512, 43.871384820630475, 67.52740721548757, 58.551463157899924, 63.784787501058275, 57.93012442127351, 62.153677709641, 55.87923472927463, 55.30499189130722, 52.4536798077245, 51.21614063939741, 45.7021628656695, 50.095864649741884, 44.10647599927841, 47.786047535557906, 47.76422346791914, 51.93628388066446, 50.15834408421671, 49.334297257085005, 43.26930099917997, 44.658408395705685, 43.69428588498024, 42.98006150030321, 41.99406393112675, 45.14479798655356, 43.45735119235131, 41.57608832082441, 43.879245250455796, 46.64067229916973, 44.132477391150694, 45.56218131895989, 45.59501155730217, 44.20188765372, 42.630362587590376, 45.652399755293324, 44.81942169127926, 45.57205392468361, 42.97111849631033, 46.102734919517275, 49.84140872955323, 46.84043076730544, 45.3329070152775, 46.335876680189564, 47.6091133394549, 44.057010989035334, 44.93522574824672, 45.267717223013605, 43.41238906306606, 43.63234381521902, 44.8513654739626, 44.57264184951783, 42.36652828031971, 41.25151218906526, 44.720272018063454, 46.971963528663885, 48.52710093221357, 47.495756841474964, 50.58232876562303, 50.57718261595696, 48.96089153905069, 48.11291433149769, 46.46087869521111, 47.492920967840384, 46.87855228301018, 47.980624552695986, 43.284782594250096, 43.37685631167504, 44.24548479818529, 43.563113981677645, 43.30749703991798, 43.110723495483406, 41.70692682266235, 44.43128355087773, 41.88883850651403, 45.11172848363077, 44.52185892289685, 45.25026659811697, 42.844178830423665, 45.02059613504718, 47.05427054435977, 45.299182476535925, 41.819965608658336, 40.135660632964104, 41.72354982745263, 41.52226555731989, 38.68087314790295, 41.12851842757195, 40.861832557186005, 43.62461674597956, 42.4808967498041, 40.38730421373921, 42.256082181007635, 42.20091012216384, 39.90041255950928, 40.87825944346767, 41.79862007018059, 43.06755781173707, 41.18551438854587, 43.50237215718916, 41.76191845247823, 42.5950377218185, 41.77144588962678, 42.80577490406652, 42.52101867429672, 41.741459369659424, 42.59318244072699, 44.58904912394863, 45.64184465715962, 46.50808442023493, 46.01025327559441, 49.39429383124075, 49.61911232240739, 54.0266953745196, 54.79385214467203, 55.59665933732064, 57.32990764802503, 63.10704115898379, 60.08608264307822, 53.68200532851681, 4.047661952434048, 0.22223268395229695, 3.7365076811082907, 0.49823300372208323, 0.42348427277418876, 1.0029733421341067, 45.14169931411744, 60.24714300709387, 61.92887098558488, 62.80344186290618, 48.01283505655105, 37.23396178214781, 42.52420756124681, 67.17417424724948, 7.024495274789873, 0.3924939937649235, 0.1430060005476398, 0.2104820443257209, 0.12029412127430401, 0.10782945705878158, 0.25793668663790154, 0.1468587486493972, 0.08828842336492193, 0.09856052861939515, 0.1624547819336576, 0.2135306146116026, 0.17383063602591717], [0.02226857100463202, 0.04782080169646971, 0.06858913888854366, 0.05130197800275299, 0.05494122506089269, 0.022385703933034694, 0.004032936769597714, 0.10332300613123564, 0.04656106586598101, 0.016276639202729832, 0.021326250299030257, 0.1339838443504226, 0.039010319423170826, 0.05995222149536975, 0.0838709612106604, 0.09511747667866369, 0.01376424044851334, 19.501608725517027, 43.2872340756078, 43.05031507245956, 34.21123427729453, 33.53611200086532, 44.98487903225807, 50.87643984825381, 51.65638354516799, 56.49425452755344, 16.574616470644553, 0.3248559989996495, 0.4259719441254293, 0.25672234534736604, 0.044360846025688995, 33.01007901468585, 67.857953194649, 53.648065059415764, 57.01654557258853, 48.806193259454545, 53.80506969267323, 49.79136713089482, 50.63289203951436, 45.00914281414401, 44.331725951164, 43.25883219319005, 43.763147015725416, 41.426826446287095, 46.65185105416083, 45.2396644315412, 46.88937802468577, 46.27420917634041, 45.763736232634514, 42.59463371769075, 40.92632024518905, 38.14294753536102, 40.81816481005761, 39.32410655483123, 39.27383353633266, 38.698833680921986, 39.19484484580256, 38.239582969296364, 38.88742908354729, 39.748255975784794, 42.00527014270906, 40.867857317770685, 41.46892524534657, 39.512686267975845, 40.11182046705677, 40.32287536128875, 40.9902980250697, 36.475540130369126, 40.67444524457378, 44.74824636213241, 42.60240785537228, 39.454015454938336, 42.81421192230717, 39.22821637122862, 40.18559240525769, 39.16810997070805, 40.63168356495519, 40.860977480488444, 39.86542109520205, 39.17841403715072, 39.500958381160615, 39.354889315943566, 39.62107704531762, 40.84486438382057, 43.756714328642815, 45.16448044007824, 46.755370247748594, 47.47250110872331, 48.326224588578754, 46.55103437362179, 44.02269809476791, 45.24324555550852, 43.515727827625895, 44.76781114455193, 41.88720680052235, 41.08184222252139, 37.8086753045359, 39.02774795409172, 38.8430513874177, 36.65292539904195, 37.628273733200565, 38.38453415901431, 39.36893140116046, 39.06326501600204, 38.94488788420154, 40.453925671116004, 38.79183700007778, 38.47022618016889, 38.410998390566924, 40.16723571285125, 40.95627538619503, 36.42899728590442, 38.021295224466634, 40.014192673467825, 39.21753575724941, 36.586719712903424, 38.239508444263095, 37.74169298910326, 38.20392862443001, 38.46622144022296, 38.86287504626859, 35.20996386005033, 37.86360809879918, 38.39223769403274, 38.573235465634255, 38.08240967412149, 40.1263528485452, 39.68784363039079, 40.32803327806535, 38.44505240840297, 39.4326973730518, 41.561783436805975, 42.207680133081254, 39.110843366192235, 40.32435801721389, 38.53771055898359, 38.5956008203568, 37.92584434632332, 39.99034858519032, 40.147655240951046, 42.043054334578976, 45.22384943500642, 47.43042584388487, 46.725242522455034, 50.88444932814568, 51.17341818348054, 55.89202557840655, 55.039623937299176, 57.35594826359903, 4.243071492641203, 0.17498223471545404, 1.271838334298903, 0.13547511110382696, 0.20179232432236596, 0.2721123469452704, 35.527436579427416, 50.98205358751359, 57.67197362838253, 44.997834620937226, 28.906007005322365, 35.16681778815485, 46.39905037418489, 22.656849584271832, 0.224836386980549, 0.05484666299795913, 0.033994048473335085, 0.035090262836386124, 0.03263497785214455, 0.004133044830298111, 0.11195578281917881, 0.037149828933780236, 0.06485259866402035, 0.03764343470515263, 0.030038242393563834, 0.02488069525439172, 0.04208351560537854, 0.030092954477896134, 0.03107346275130347, 0.05529674348391353, 0.028800395610291633, 0.01946984114305627, 0.06019905885501255, 0.050814887809176604, 0.09145609734039153, 0.11767348004204613, 0.04971641348674894, 0.029331846125123483, 0.08040227596798251, 0.09836923646470232, 0.01940400737728323, 0.10028810285392309, 0.13308549900689434, 0.04981078402770143, 33.88529316071541, 47.87555994526033, 43.41830791965608, 40.2680367039096, 44.33191422493228, 51.87786017694781, 57.64838449416622, 55.22174742914016, 62.834314838532485, 18.096392154693604, 0.916339461841891, 0.5100907884057492, 0.13923304816407545, 0.05745902281975555, 36.75773897478658, 70.43094173554452, 55.898689685329316, 60.05778666465514, 51.31309378531672, 57.06797961265811, 51.606906767814394, 53.316871889175914, 47.3384972541563, 46.11423923123268, 45.02840557406026, 45.510660986746515, 44.8187078199079, 49.04049996406802, 45.987778094507036, 48.1302119839576, 48.35334385595014, 49.02042135115593, 45.53798421736687, 41.62942863279774, 39.916443286403535, 43.29021899930893, 40.98759943439115, 41.193363051260675, 39.508085327763716, 39.44397026492704, 39.01658488858131, 42.462406696811804, 42.29656496355611, 44.385689919994725, 42.50712563914638, 43.32539089264409, 41.1999055647081, 42.598383503575484, 42.140270279299834, 43.971805341782115, 38.927833418692316, 42.416534577646566, 45.653109704294515, 44.08527558849704, 42.12140367877099, 44.17066166477819, 41.987733225668634, 43.18386785445675, 41.57647663547147, 42.84994471457697, 41.82477835685977, 41.69779946727138, 40.2600036897967, 39.559146742666925, 41.60288595384167, 40.86983026996736, 41.26966491822274, 46.97357562280471, 46.70450887372417, 47.84427119839577, 47.1575112496653, 49.77077860986033, 48.98224884463895, 46.04370324842392, 46.03971812032884, 46.32898115342664, 46.26127319951212, 43.88210465831142, 41.997339110220636, 40.86664138301727, 40.86902226171186, 40.15747293349236, 39.828068364051084, 39.17535458841632, 41.225487262971946, 41.451635437627, 40.87808685918009, 41.04096720295568, 41.55314637768654, 42.00070058145831, 41.29775693339687, 41.83197982849614, 41.50382649513983, 43.04123478551065, 37.9846602870572, 38.772589929642216, 41.46729746172505, 41.25782720504269, 39.57863700005316, 39.127705635563025, 40.19047183375205, 40.29867433732556, 40.39269355035598, 40.59289916869133, 38.326918463553156, 40.01493792380057, 40.04151982645835, 40.22744801736648, 40.861687429489635, 40.07491096373528, 41.83033635539394, 40.99646399098058, 41.13064827457551, 41.493946044675766, 42.97638231708158, 44.185601972764545, 41.72456572132726, 42.77036374615085, 39.7479578756517, 40.024712470269975, 40.892301528684555, 40.17743387529927, 41.850085489211544, 44.40522332345286, 45.8416933398093, 49.18433327828684, 48.970838669807684, 54.029962708873136, 51.913439996780895, 58.17289167834867, 56.03868692151962, 57.32693449143441, 5.436775232515028, 0.11903252768059892, 1.3208838960816784, 0.16406638577820795, 0.10750968429830768, 0.2958935240824377, 40.96714427394252, 56.66164167465703, 61.34317874908448, 53.22185247175155, 42.406073616397, 25.351639486128285, 49.022715937706735, 29.803249182239657, 0.21383680463317903, 0.04721581057134656, 0.03898100123830861, 0.042352772528125394, 0.014995689440007894, 0.030238352220265136, 0.08815266492386019, 0.04788049143709002, 0.03798352028693884, 0.020693279727692568, 0.05017312829412761, 0.014506693602719856, 0.0421129678556275, 0.1255851381668641, 0.17424862891916307, 0.20421440322552958, 0.1117751622692712, 0.1210136616963052, 0.1758750642259275, 0.11086079802724624, 0.22639793464012686, 0.2776191095190664, 0.13022950790341825, 0.11893057669963568, 0.18840101547539237, 0.18131182168520268, 0.15425316719037874, 0.17252470126315472, 0.25619795816319607, 0.3158917896930249, 46.40339243796564, 59.773383448200846, 52.3974173299728, 46.13651044907109, 45.580636070620635, 57.42556641178747, 65.96431132285826, 59.27529342712895, 71.14518965444258, 22.503169159735403, 1.4182976753480974, 1.126232599058459, 0.4683337871345782, 0.2688839911453186, 38.00202854218022, 70.69689412270823, 56.841882428815296, 63.11907499067245, 53.27192152700117, 59.27535226268154, 53.18104805484895, 56.422251578300234, 50.3988677455533, 48.1726324173712, 47.75340164861372, 47.64847040176392, 46.21016079379667, 52.595281293315274, 50.13470003681798, 51.078457601608775, 50.35925180681291, 51.38758743962934, 47.260477389058764, 43.925419392124304, 41.550318348792295, 44.74753641313122, 42.89212980578023, 44.377186221461145, 42.22654281123992, 42.094774707671135, 40.47078009574644, 44.22120140444848, 43.742217248485936, 47.15985682702834, 45.35181676187823, 45.58701384452082, 44.17489390219412, 46.10998345959572, 44.44971084594727, 46.38397670561268, 41.38670844416465, 44.96433365729548, 49.41834580513739, 46.94672307660503, 43.749489322785415, 46.64398277959516, 43.694846783914876, 44.233082263700425, 42.96173618685815, 46.15360021591187, 44.199797030418154, 43.03202506034605, 42.64905660383163, 43.252834889196585, 44.50181168894614, 46.002573274797015, 44.988597439181426, 49.42230739901143, 48.458133897473736, 49.88733968427105, 52.03343314509238, 53.61173606687977, 50.87333333107733, 47.06684174076204, 49.48117433055755, 49.04721506180302, 50.39381181040118, 45.78093190346995, 44.71225861580142, 42.4832344824268, 43.94323871981713, 43.98191328971617, 41.68073323465163, 41.84050313888058, 42.46608195766326, 45.00050575502458, 42.95750002707205, 42.50527035805487, 44.58720953233781, 43.579764443059126, 42.54395669506442, 43.299256140185946, 44.73629882258754, 45.22723444046513, 39.72456485994401, 41.419495536435036, 43.62592681761711, 44.13971808648879, 41.23065302448888, 40.90469621842907, 42.15403779860466, 42.44880783942438, 43.02179159656648, 41.72762909243184, 40.031804115541526, 42.05958712485529, 42.405732370192005, 43.37997067359186, 43.841680711315526, 43.070166187901656, 43.148256655662294, 42.206377906184045, 42.51299350492416, 43.42329717451527, 45.82152451238325, 47.56800690004903, 43.45075768809165, 45.27253781595538, 40.92047199126213, 42.540242210511245, 42.725319247091974, 41.878816850723766, 43.567161867695475, 46.300751855296475, 48.188270907248224, 50.72507166093396, 49.7893863339578, 56.18017465837541, 53.82327341264295, 61.08900131717805, 58.53924889718333, 60.82163295438213, 6.955481171607972, 0.34127304871236125, 4.958730484208753, 0.3906825022591699, 0.38632444256255705, 1.4010705029772175, 48.38297344023182, 62.70852834947648, 67.66607869055964, 57.1413593138418, 40.62774158293202, 46.57556487667946, 57.3425769036816, 36.86882442043674, 0.4960087133992103, 0.14786966295251924, 0.18580269038436875, 0.08667256007151258, 0.13594878326740958, 0.10342887182149196, 0.17998039151632017, 0.16226837741992167, 0.13102774087700153, 0.11253837736383562, 0.11327152350737203, 0.10081408350097557, 0.09032710590550015], [0.019096110894855474, 0.05511802283205813, 0.06437663589754412, 0.16992823010490787, 0.048334279788597945, 0.05321431732285888, 0.04828846390028635, 0.011841672897008399, 0.033295081342540445, 0.06398407712338433, 0.022181838360284607, 0.010192204199190582, 0.1254543669581894, 0.030493815729935324, 0.1023976025622218, 0.06663430467127793, 0.2746073114535501, 5.234866324932345, 32.623441180875226, 46.342077947431996, 50.34303672852055, 25.18837671126089, 37.38086238984139, 58.06030396492251, 52.20737065038374, 54.91959548765614, 27.007097390390214, 0.14238511692852746, 0.7197278377509887, 0.12973565698391007, 0.12046024744068423, 22.31251843513981, 71.60241250068911, 54.283371356225786, 57.84166320677727, 46.796908147873424, 48.83392441657282, 46.3929000977547, 47.6795159616778, 41.53458964440131, 46.036733196627715, 43.318409073737364, 47.421353401676306, 46.03514071433775, 48.7735552172507, 47.6765545721977, 51.076414046748994, 48.1032221548019, 48.78840531072309, 42.83822467250209, 41.228217232611875, 38.774527580507346, 41.672351129593395, 38.664528631394916, 40.83709416850921, 40.25216679419241, 40.78253792178246, 40.06803897119338, 42.307547600038596, 41.3539997992977, 41.75773720587454, 40.66210939038185, 41.26933543912826, 39.337489681859175, 38.941369518156975, 39.951670092921105, 41.09569603397001, 40.15998325040264, 41.18014466377997, 43.89409142155802, 42.68480116321195, 41.72424408697313, 42.76208362271709, 37.70285367965698, 42.11484939821305, 41.003241846638346, 41.6918178527586, 40.34200476061913, 40.741827641764, 39.40034566387054, 39.75865417911161, 38.07407855987549, 38.6036063778785, 39.78802880933208, 46.770310555734945, 49.308197805958415, 50.23641101775631, 50.35900077512188, 51.73308157151746, 49.47479655665737, 44.886427540932935, 43.65299117180609, 46.21060402162614, 45.99594839157597, 45.183982464575, 42.68986494310441, 38.95639219591695, 37.39865426094302, 37.70268109536941, 37.301838397979736, 36.79799425986506, 35.804293155670166, 37.76450941639562, 39.57666012548631, 39.50697529700495, 38.06583373777328, 38.770860164396225, 38.679688592110914, 39.820706075237645, 37.755417362336196, 39.81619927190965, 37.82001879907424, 37.73444837139499, 37.77650794675274, 38.754598017661806, 36.56597821943222, 39.28691464085733, 38.041420905820786, 38.15983726132301, 38.08931696799494, 37.900831391734464, 36.343611209623276, 39.30453785004155, 37.04130280402399, 37.719998359680176, 38.2572885482542, 38.48985764288133, 39.54428488208402, 44.848506066106985, 43.45504483868999, 43.72573937139204, 46.72776068410566, 45.630752194312315, 44.46028555593183, 45.42072496106548, 43.18979847815729, 41.46053137317781, 39.82349095805999, 38.853708467175885, 38.41876860587828, 40.5238889878796, 41.08835335700743, 45.089135631438225, 42.8872464549157, 46.93687008273217, 47.72296405607655, 55.822399585477775, 51.303334928328, 57.82663660664713, 6.534767746925355, 0.4225702379499713, 0.9003013805035622, 0.035157812639109554, 0.1782878887869658, 0.24836510750314883, 34.983631333997174, 50.94347315449869, 49.606356774607015, 33.11818345900505, 24.406613034586755, 33.16802501678467, 47.1824183002595, 5.746878308634605, 0.25370771275653, 0.031402468786484776, 0.03323017071271616, 0.02394848690939046, 0.008685165610645086, 0.029042282126723763, 0.031232879902686805, 0.07807441821862614, 0.02993200323544443, 0.04019610861676835, 0.16082135990502375, 0.054358760751183, 0.05829069936167329, 0.020641631995057388, 0.021048219754330574, 0.07754212500707758, 0.08870531309155688, 0.06373394941610676, 0.0853408617718566, 0.020795456704593474, 0.022821606046730475, 0.0549633305279478, 0.02875960525876332, 0.031578594315496665, 0.07658663716527724, 0.06116681176448061, 0.10862697757059529, 0.06447709300705502, 0.059705901245075854, 0.43340373243535724, 11.946970801199637, 44.46980514834004, 46.162778562115086, 50.04526215214884, 36.372224900030325, 42.86886230591805, 61.75338806644563, 56.26202275676113, 61.03518639841388, 29.515380551738126, 0.6370876657385981, 0.4141080613818861, 0.18145417614329248, 0.08397271300876334, 24.507210062396144, 76.05951155385664, 55.680582369527514, 60.43414200505903, 48.605501267217825, 50.06887482058618, 47.64438329204437, 49.52606193480953, 44.695325743767526, 49.045340168860655, 45.31457777946226, 49.458883500868275, 48.44966157790154, 51.37735789821994, 50.238952713627974, 52.55821881755706, 50.212209993793124, 51.9351307038338, 45.02526767792241, 42.586310448185095, 41.699894012943396, 42.0759081071423, 40.97114901388846, 43.99242916414815, 41.07218142478697, 42.485438854463645, 41.13197403569376, 43.890906456978094, 43.8119883691111, 44.507808992939616, 42.79943635386806, 43.68886124703192, 42.65452831022201, 41.12070506618869, 43.67838459630167, 43.85106694313788, 42.429423486032796, 43.14018441784767, 44.39406418031262, 44.602765652441214, 42.97233835343392, 42.651684591847086, 40.44683402584445, 43.49867728448684, 42.33995422240227, 43.658851192843535, 43.47968516811248, 41.00911755715647, 42.63563817547214, 42.430564895752944, 38.804231689822295, 40.32870008099464, 42.41616587485037, 49.934819975206935, 50.26317334944203, 52.79581246837493, 51.99008703231812, 52.27323509031727, 51.222651773883456, 48.42328363849271, 45.90971900570778, 48.37684277565249, 48.315834229992284, 49.570412174347915, 44.5391801095778, 41.02404609803231, 38.78817350633683, 38.31478657261018, 38.48528023689024, 39.56376337235974, 38.34765211228402, 39.86436989999587, 41.343248582655384, 40.32050624970467, 40.857443424963186, 41.31605086788055, 40.78051005640338, 41.090977422652706, 41.591146299915934, 41.493122346939586, 40.70237252020067, 39.85991408748012, 40.517338629691835, 41.252696744857296, 38.81553988302908, 40.97616964770902, 39.71650831161007, 39.88335809400005, 40.841365629626864, 41.05038089136924, 38.81322960699759, 40.195488545202444, 39.70717699297013, 39.01140343758368, 39.3132729684153, 40.84848473148961, 41.30381307294292, 45.45226866199125, 44.70317440648233, 45.66239003212222, 47.29972462500296, 48.24033644891555, 45.79500536764822, 45.770219910529356, 45.07501902118806, 44.10998259821246, 41.89977799692462, 41.3666102194017, 40.248703341330256, 42.905277590597834, 45.01404969922958, 47.65496584676927, 45.55495631310248, 50.0839602562689, 50.359361633177734, 59.10834950785483, 53.800464830090924, 58.81884328780636, 6.910853914676174, 0.45398872946539237, 0.4723792523145676, 0.04929416497508365, 0.2386326192607803, 0.363450252240704, 41.087768923851755, 57.17351882688461, 52.93919471002395, 43.314769114217455, 29.793184380377497, 29.317516588395645, 57.63163205116027, 7.936262478751521, 0.18788674065182287, 0.05248701643018473, 0.07032056654533071, 0.03721439865447822, 0.07702014333898984, 0.05020957492712525, 0.03618676448240876, 0.050293289185051, 0.060920836253752636, 0.04504517704669026, 0.23772806860506537, 0.03230972373257241, 0.12494285771202658, 0.11456982037352939, 0.16914184085063397, 0.2293764232026954, 0.23160040709039859, 0.10998615544409522, 0.1588871411138004, 0.08595121934288934, 0.12274394022120584, 0.19247035195510234, 0.17031646814317475, 0.1254927556240751, 0.1580024781005998, 0.16437803034580525, 0.1624014315706107, 0.17986503399668202, 0.25626871404388263, 0.6086832705524661, 16.851980993824622, 56.08137799847511, 53.80277118375225, 58.605270231923754, 37.19169039880076, 47.791417260323804, 69.54535684277936, 62.79353395585091, 68.07908858022383, 36.50523639494373, 1.1535385467352406, 1.183322574342451, 1.0517181071542925, 0.1733024030803673, 25.678263095117387, 77.53723313731533, 57.31223344802857, 63.1269746441995, 52.58573424431586, 52.59366527680428, 52.103973050271314, 51.70062395834154, 46.01158688145299, 51.38762666333107, 47.50721016237813, 53.87904951649328, 51.17578729506462, 54.13947136171403, 52.886925205107666, 56.44643691278274, 52.77638889128163, 55.22134734738258, 46.44180028669296, 45.582624712298, 43.011907223732244, 44.55515200091947, 43.76114660693754, 46.64555565003426, 44.779193862791985, 45.945165464955, 43.293553013955396, 48.24394895184425, 46.861054589671475, 46.62316283872051, 45.91176648293772, 45.29536208798809, 43.379448998358946, 42.88647767036192, 45.87203287309217, 45.50847230419036, 45.485306785952666, 45.36442718198223, 48.880879109905614, 47.596946147180375, 46.11505116185835, 46.4506216972105, 41.82154632383778, 44.70723798198085, 43.980775802366196, 46.19530285558393, 45.58949278246972, 44.03157049609769, 44.24150359246039, 44.748454247751546, 41.81460765100295, 42.257470700048636, 45.2398762395305, 52.18848051563386, 53.286834378396314, 56.38909578323365, 56.182759500318966, 55.624135540377715, 53.115430724236276, 50.00126884829614, 47.72879662052278, 51.23767445164343, 50.40270774595199, 51.915652213558076, 46.11645537038004, 43.55799528860277, 41.65289225116853, 42.054103651354396, 41.40750877318844, 41.79945553502729, 41.02205745635494, 42.25593705331126, 42.775898210463986, 42.74282870754119, 42.97888086688134, 43.17963169467065, 42.67643867000457, 45.03310457352669, 43.62861364118515, 42.63204920676447, 42.68302432952389, 42.32698686661259, 42.52643938987486, 44.09925491579118, 40.7129942986273, 42.65131981142106, 42.18354578941099, 41.20248256191131, 42.53718668414701, 42.809305037221606, 40.69893260155955, 44.161608834420484, 41.756305540761645, 41.197763950594016, 40.823907159989886, 43.03613962665681, 43.23522736949306, 50.82803387795725, 47.666866317872085, 47.994850989310976, 49.8243111179721, 50.75119856865176, 49.201654464967795, 49.79534833661972, 46.57980495883573, 46.33901849869759, 44.43593548190209, 42.149197593812026, 42.882418017233576, 45.294052016350534, 46.269588624277425, 49.58019848792784, 48.01844796826763, 53.0126214796497, 53.56167877874067, 60.967349006283676, 54.75178472457394, 60.71523474108789, 8.797860607024163, 1.1351031617772196, 4.5437883369384275, 0.3154769377602685, 1.0433934893338912, 0.8457257670740929, 47.221304678147845, 61.57686964158089, 62.64574297012822, 43.39073757971487, 36.89067986703689, 41.64542798073062, 64.70904696372249, 11.890138599180407, 0.43236393661748984, 0.23076825174352816, 0.14667239010093674, 0.13961383982771827, 0.15420114982032007, 0.11606025975197555, 0.13432273100460732, 0.146351644408799, 0.25479307548413355, 0.14957437712338664, 0.33140991183538593, 0.1709936592247217, 0.265836309521429], [0.05175270583300341, 0.017409062711521983, 0.1081650342131334, 0.08255728895986274, 0.02617510613955317, 0.05085902979537364, 0.022962956929639466, 0.05332423944867427, 0.029127264260164196, 0.026288759113559802, 0.060111816762195486, 0.034124471112004215, 0.021360473361827677, 0.019517198783315478, 0.0668220421780021, 0.015632111237444464, 0.09906779373845748, 0.3229277250507186, 32.11578646013814, 51.98035955429078, 60.684349998351074, 27.904329761382076, 25.03903246694996, 52.52046600464852, 52.51308018161405, 55.72738409042359, 34.307657903240575, 0.008448987406858755, 0.7958143420757786, 0.3078761198107274, 0.09872310779868596, 10.520809754248589, 75.060193615575, 55.37441392098704, 60.6145945672066, 47.62686990922498, 46.819410785551995, 42.30938719164941, 43.10138825447329, 38.95070475916709, 42.484528864583666, 44.68222502739199, 47.296790692114065, 46.01139076294438, 50.690288082245864, 47.2853373712109, 52.12179237796415, 47.67899428644488, 45.95471251395441, 40.472035254201586, 41.63572011455413, 40.74480079835461, 41.05977104556176, 40.1353782223117, 40.23546534199869, 37.616738042523785, 40.81243422723586, 37.71870789989349, 39.20245032156668, 40.768409544421786, 41.535291748662154, 40.244333820958296, 42.20039629167126, 40.50084506311725, 39.53640876277801, 41.07213043397473, 39.27989359824888, 40.139029948942124, 39.92080103966498, 42.66283981261715, 42.17566574773481, 40.08633682804723, 40.21270382788874, 40.23735592442174, 40.750766723386704, 41.092742489230254, 41.182866788679554, 38.966009847579464, 40.43544346286405, 41.11449987657609, 39.771692137564386, 37.70581114676691, 39.48323319035192, 38.951402941057765, 49.0320433339765, 48.95173672706851, 51.55194259458973, 54.1000593862226, 52.534770888666955, 52.54236851969073, 48.235994385134795, 47.089360067921305, 50.41484748163531, 47.5988406519736, 46.505417208517756, 43.739793223719445, 39.09067061639602, 37.469849201940725, 37.65434572773595, 38.24927514599216, 39.1089645508797, 38.41605824808921, 38.60267285377749, 39.27374724418887, 41.07789631812803, 37.02737838991227, 40.11720588130336, 37.6316705057698, 39.31617552234281, 39.383452015538374, 38.62979212114888, 37.6906943321228, 37.162064736889256, 39.202156143803755, 38.56138990771386, 35.83001213689005, 37.1663518874876, 38.25540581057149, 37.95125346029959, 38.295668940390314, 38.33468867886452, 35.335824874139604, 38.338830701766476, 39.65592338192848, 38.105688941094186, 38.13223162005025, 41.435953801678075, 41.510671031090524, 44.35048664769819, 43.43587229328771, 44.55392037668536, 46.883302273288855, 46.43910954075475, 44.96637721215525, 44.679353852425855, 43.616972046513716, 42.47637817936559, 41.310461490384995, 40.46981911505423, 39.586069891529704, 40.35374049217471, 39.58868219006447, 40.39572946486935, 41.25188481423163, 44.16170297130462, 48.758344265722464, 54.61907917453397, 54.30272040828582, 53.63393668205508, 4.9501860910846345, 0.364818393342918, 0.15503174234782496, 0.08195207183880192, 0.5063524938398792, 0.7556777699820457, 42.42272407777848, 51.74023597471176, 44.20245247502481, 30.91984598867355, 26.144375993359475, 39.003601843310946, 30.56272791277978, 0.37027692302100124, 0.04700577990602582, 0.12478086842043747, 0.05118078289313182, 0.04863810259848834, 0.015957229376410045, 0.04497236805036665, 0.02936807633828252, 0.05803402926352236, 0.03363988602594022, 0.0386073763271974, 0.028136293140930996, 0.02079617491202249, 0.0434793163120987, 0.039441531163550196, 0.07006958848045719, 0.021679223394922672, 0.05704828094871295, 0.0551725491400688, 0.057848509581338976, 0.04526914285135366, 0.04404159803544322, 0.05416076915759233, 0.02601845073513687, 0.05448282102964098, 0.009640700375330786, 0.057642271051243435, 0.018339468834681377, 0.11057840269659797, 0.03221763613363428, 0.059154628205203244, 1.2216171646310439, 40.325848517879365, 55.9404040921119, 55.3237251312502, 36.34263453945037, 34.06826388451361, 57.67653534489294, 59.30119675974692, 60.92758793984691, 38.51298785978748, 0.06133315626591925, 0.6193529141526068, 0.162574123110502, 0.0573901821588797, 12.04778257877596, 77.21451620901786, 57.3616631569401, 62.91934790149812, 50.55599789465628, 49.275818640185946, 45.557035169293805, 45.02920573757541, 42.28671196968325, 45.675071054889315, 46.09976960766701, 48.76605564548124, 48.682305197561945, 53.21866358480146, 50.900534968222345, 54.46008589959914, 52.00972633977091, 47.63700139138007, 43.38919216586698, 43.11797203556184, 42.54525107722129, 43.41306763310587, 42.120336794084125, 42.97012221428656, 42.126577285028276, 41.84040507962627, 40.3597495632787, 42.814725752799745, 42.959849526805264, 42.863382754787324, 43.891918428482555, 43.67210488165579, 43.29614962300947, 41.50481885479343, 42.64828781927786, 43.66783734290831, 41.77159101732316, 43.49539426065261, 43.45943004854264, 43.96472546362108, 42.66267899544009, 40.82761379980272, 42.74272280354654, 44.441720977906265, 43.27090132621027, 41.49384406305129, 41.50607401324857, 41.73238692745086, 43.60726025796706, 41.68869172373126, 39.691593416275516, 41.20105481916859, 42.439460831303755, 50.03114946426884, 53.241833025409335, 54.38862423742972, 54.41574350480111, 55.19666779425837, 54.08961803682389, 51.368665925918094, 49.794869807458696, 51.4610848119182, 48.646329218341464, 48.631192791846495, 45.79934743142898, 41.50655646477976, 39.820278536888864, 40.61090284778226, 39.21513918907412, 40.93258819272442, 40.71209999822801, 41.42980744761806, 40.95547914505005, 41.35892237386396, 39.34177683245751, 41.13404504714474, 40.34529562919371, 41.81367020453177, 39.835179621173495, 41.62595733519524, 38.256747261170425, 40.73614020501414, 39.977090974007886, 40.488246410123764, 38.57431019506147, 39.40120466293828, 41.755254345555464, 40.055055925923014, 40.8335679577243, 41.43323559914866, 38.61469884072581, 40.1701618009998, 40.03669138877623, 39.97176439531388, 40.875113702589466, 43.51448835865144, 44.88590978807019, 46.363270513473026, 46.50681749466927, 46.75419745906707, 46.30354066048899, 48.26016403013661, 46.11998550353512, 45.84875752848964, 44.72073878011396, 43.669049355291556, 43.14774674753989, 44.06117262378816, 42.10407072497953, 43.09287671119937, 41.49331454307803, 44.52273753381545, 44.05834067252375, 48.166003611779985, 51.67882734729398, 59.7509474908152, 55.52302075970558, 55.28662735416044, 5.021566854369256, 0.7276987068114743, 0.42377765380567123, 0.07214436142314827, 0.558544960954497, 0.47477569791578483, 46.83821070578791, 56.94298152000674, 50.676685302488266, 42.43109441572621, 26.074867671535863, 38.57156453594085, 39.06197847858552, 0.48155045857833284, 0.05199918696176141, 0.07416203783284273, 0.061445882273537505, 0.0223201651111125, 0.025548199154136163, 0.03037520425183879, 0.06770353358719619, 0.06612216723301718, 0.029726860211080605, 0.014086976054034406, 0.033089493987180536, 0.023823070655306502, 0.04525902282987391, 0.12070802325803427, 0.1969832839864877, 0.2079695364039752, 0.1954068895429373, 0.15100270209293212, 0.19651313582735677, 0.12421708133432174, 0.13791110216369554, 0.11846360014451128, 0.1316347429829259, 0.16513578323346956, 0.1405463833361864, 0.16651000707380234, 0.12965717893694678, 0.31269386290542545, 0.21050894933362163, 0.15400195163824867, 1.7469837156034287, 54.45882681877383, 62.545357750308135, 65.41678374813449, 40.78752325427148, 35.66001661362187, 64.56382513046265, 63.60629612399686, 66.80867994985273, 43.138058493214274, 0.2469927069520758, 1.491097846338826, 1.1070995225060372, 0.21585441975583955, 12.781245208555653, 79.60332593610211, 60.65886243697136, 65.91593280915292, 51.6477817873801, 51.3137056750636, 46.718107731111594, 46.56175421130273, 44.11094750127485, 46.01444236693844, 48.19000851723456, 52.27807529510991, 52.82758758914087, 56.73103624774564, 51.143317914778194, 56.341505665932935, 54.33130664210166, 49.719042547287486, 45.38350559050038, 44.37268334050333, 45.65438839697069, 46.6239159337936, 45.05300667978103, 45.51051193667997, 42.5935786001144, 45.09825514208886, 42.9575353284036, 45.24760330876997, 46.093693856270086, 45.71662072212466, 45.78909435579854, 45.82829844567084, 44.9017914648979, 43.93824946495795, 45.760006058600645, 44.867831583945986, 44.82789008848129, 43.928843621284734, 47.09338049734793, 46.61706747547273, 45.31659780010101, 43.585185158637266, 44.075979571188654, 46.275240759695734, 45.75612291213005, 44.689908950559555, 43.74375873996366, 42.424293025847405, 46.28700002547234, 44.98949566195088, 42.83314520312894, 44.8885573879365, 42.99796712013983, 53.128500061650435, 54.63411754177463, 55.80891839919552, 56.53593363300447, 57.34646789489254, 54.66078181420603, 55.743387360726636, 52.20837085477768, 54.22743835756856, 51.545757016827984, 50.030486583709724, 49.28319661848007, 44.518615122764345, 43.23708265058456, 43.54609873987014, 42.109624801143525, 43.748618556607155, 43.46772193908692, 43.1047301138601, 43.700820553687315, 45.59271697075137, 41.34575105482533, 43.89927287255564, 42.86314349020682, 43.804029880031464, 41.47578939314812, 43.76789308363392, 42.34009542772847, 42.69548569956134, 42.752112957739065, 42.921622107105875, 40.1667611060604, 41.62438838712631, 43.91938286442911, 40.53970398441438, 42.32353125849078, 43.51240558008994, 40.205063050793065, 41.18768345925116, 43.205837049791896, 42.34307250668926, 43.40757631486462, 46.604598260694935, 47.14677572250367, 49.73914077205043, 49.3698888440286, 49.69436691653345, 50.958119284722116, 50.786182188218646, 48.95663576741373, 48.22645518087572, 47.49512141750705, 45.96425171821348, 46.721284850951164, 46.49597998588316, 43.73691420401297, 46.18842694067186, 44.43109919947963, 47.13578916365101, 46.590246308234434, 50.24285154957926, 54.04553844082741, 61.58216484131352, 58.121147771035474, 55.94662104883502, 6.6270390537477315, 0.8862698366565089, 2.0192031922840306, 0.2590419676515364, 2.1692950158349933, 1.5110542529052304, 54.55996905603717, 61.76195844527214, 57.12952160066175, 42.89518140977429, 36.00744055163476, 48.54275511157129, 50.81779649180751, 0.850873387628986, 0.08606714376759145, 0.26762625863475187, 0.11989223921010572, 0.23936116887677103, 0.16977059985360793, 0.08064010796407539, 0.2254590172801287, 0.1609647102774151, 0.08871402351125594, 0.17431550839495275, 0.12533334038791158, 0.08258563421306112, 0.1628633979107103], [0.05939768109050009, 0.028618909381029588, 0.0355787817839413, 0.08873715936656922, 0.03973657077538871, 0.02575738520752038, 0.01966062767971908, 0.08812525429792943, 0.06714553046490877, 0.033333807087112824, 0.039404896839011105, 0.02247053476411008, 0.13393118346650756, 0.013212053848791027, 0.03827880887735275, 0.020347789395600557, 0.0751076891056953, 0.08265384668183905, 13.318413803654334, 51.34676341087588, 54.739750892885276, 32.396308491306925, 26.324875623949115, 46.1835906582494, 58.01996238770024, 52.92068504518079, 41.34486067679621, 0.22564264855557875, 0.1506341371925608, 0.1916085336838038, 0.01014221313169166, 1.4262912206111418, 59.31683524962395, 60.68811547371649, 59.83814962448613, 55.47064535079464, 51.724785758603005, 43.973590020210516, 43.279185372014204, 42.55990112981489, 43.83304365219609, 43.99821858252249, 46.347741849960826, 48.14770575492613, 47.25417414019185, 49.82895128188595, 48.67132648344963, 48.22165027741463, 45.47087638608871, 40.99352221335135, 40.02238258238762, 40.44585735567155, 41.124301879636704, 40.11756673935921, 38.99386652054326, 40.59065165058259, 41.23108056283767, 39.18539585605745, 40.00903475669123, 41.36928135348905, 40.72820525015555, 41.20141175485427, 42.12027011379119, 40.72646764016921, 39.92728863992999, 40.962508032398844, 41.68715807699388, 40.778894039892386, 40.48806598109584, 41.23201800930885, 41.48186906691521, 38.98022059471377, 39.793320086694536, 40.92084069405833, 40.66824397733135, 39.583414446923044, 39.34370271621212, 40.67163290516023, 42.561352406778646, 40.82942201245216, 40.464441545547984, 37.96305194977791, 39.672001177264804, 39.23146801610147, 48.69154237931775, 52.50070902609056, 54.437622485622285, 54.89553566901915, 55.171658762039684, 57.05572612823979, 50.835478536544315, 50.584427233665224, 55.06275023183515, 53.28038600183303, 53.6866964832429, 45.82301501304873, 40.60822386895457, 37.29431921435941, 38.49267782703523, 37.60702625397713, 37.762924778846006, 39.005284540114864, 39.39758039289905, 38.5538471898725, 39.3380662702745, 40.34913955196258, 39.342639753895426, 38.23415440897788, 39.2083691781567, 38.444993572850386, 38.33714408259238, 39.657629612953436, 37.102503545822636, 39.205243049129365, 38.221328258514404, 37.334605878399266, 38.64106109065395, 36.28400687248477, 39.17127532343711, 39.52818355252666, 38.59938982994326, 38.04991283724385, 38.4739798884238, 38.73879086586737, 39.29282565270701, 40.635096027005105, 43.81558910492928, 44.06853883497177, 45.341096924197295, 43.75885986512707, 42.937201761430316, 43.56397690311555, 43.394961972390455, 44.18852021617275, 42.9360132832681, 43.42308536652596, 44.594101136730565, 41.114029192155414, 41.23273188068021, 38.83759144813784, 41.02523457619452, 39.427221744291245, 42.180188240543494, 41.27952575683594, 48.23679062627977, 52.36068041093888, 55.05236379561886, 53.82527382143083, 38.6121924461857, 1.023964886703799, 0.08583563965775313, 0.11591572194330155, 0.15051877967292263, 0.5457865326635299, 4.1005443276897555, 53.81554242103331, 51.48218716344526, 46.24213987781156, 25.829064499947336, 23.684657658300093, 48.37110827046056, 10.898728159166152, 0.3729022756939934, 0.09138399314495826, 0.08567342053978674, 0.017249662797116948, 0.04817803998688056, 0.045328407413175995, 0.10703647944835887, 0.022594683142679355, 0.04449987949262704, 0.006891333389156048, 0.026798048619962028, 0.005160904998305224, 0.03604095496778046, 0.0241396009486409, 0.030612729812761953, 0.033799239975069804, 0.04580376880063165, 0.0430594465034383, 0.005891410053722681, 0.056474488754306114, 0.032153116208651376, 0.010508529564005234, 0.03712578909471631, 0.04677222268055043, 0.051652543667343356, 0.02570223645307124, 0.0568614435952998, 0.031636387988504384, 0.03341865898560613, 0.06926884273848227, 0.06765820416471652, 0.03830948303784094, 20.835153787366806, 59.10040278588573, 56.00047911367109, 35.632964026543405, 34.94415267821282, 48.92342505916473, 62.17550177727977, 59.115241112247595, 45.640840530395515, 0.0629355057683443, 0.456470915627095, 0.18833182241407134, 0.05224416655818782, 2.3204984636076036, 63.692615724379024, 60.89478515809583, 63.18580627441407, 57.36208677291871, 52.5253140541815, 46.7674119241776, 46.28202253772367, 44.07343395294682, 45.25501266602547, 44.889369318562174, 48.94214260962702, 49.08252031572404, 50.754324697679095, 52.104094643746656, 51.02200292771863, 51.90035889225622, 47.49491353188792, 41.74478553956555, 42.02773355668591, 41.46058628636022, 42.96381896541965, 42.96080658512731, 40.40581387858237, 41.20856615804857, 43.159094164448405, 42.73974964695592, 43.26441764831544, 42.761224623649355, 42.453244040089274, 42.636799197043146, 42.78403712857155, 41.69703852745795, 41.41372572991156, 43.09663041945427, 43.77595355433803, 43.726472854614265, 42.26058506196545, 44.103844088892785, 43.20356599746212, 39.85185361677601, 42.705138652555405, 42.711751768665934, 41.78364838323286, 41.37242709436725, 43.49214653814993, 43.29800882647115, 43.29960915350145, 42.54477647043044, 41.617673289391306, 41.10396046792307, 42.57564552368657, 43.00450178884691, 50.863543095127234, 53.02783243117794, 56.094886641348566, 54.639848124596384, 55.540573366226695, 57.16987494499453, 53.1659665415364, 51.22923743340277, 57.238457587457475, 52.97807716554212, 53.444882362119614, 48.21787695730887, 42.95780989431566, 39.8510612980012, 39.749675873787176, 40.19171522509667, 39.604807053842855, 40.98487730949156, 42.210386568500155, 41.107110131171446, 41.47157676758305, 41.342691606090916, 41.58758871016964, 41.192005911181056, 40.79124166119484, 41.2498922501841, 41.190260456454375, 42.04788669463127, 40.43281939721877, 40.87852616463938, 40.63970873432775, 38.99761630642799, 40.702090109548266, 38.958878978606194, 40.77628174135762, 42.898287926950765, 40.700576074661754, 39.522174481422674, 40.33342653705228, 38.98279759191698, 41.187110793206, 43.24872032288582, 45.5522616447941, 45.52258499207036, 46.49207722756171, 45.76834109521682, 45.08452684648576, 45.33151065149615, 46.566692475349676, 46.391460587901456, 46.785909821910245, 46.31962237819549, 46.41151174422234, 42.60889153326712, 43.95176203020158, 41.138218449008086, 43.28643391209264, 41.60938924358737, 44.589590411032404, 42.60227841715659, 49.94619877107682, 53.70282134702129, 57.622791028791866, 56.87820749898111, 41.04457970588438, 1.297175497297318, 0.7009033414144671, 0.9367291677382685, 0.15252038355796568, 0.8018609821315735, 4.011726667804103, 59.76464440745693, 55.077792521445986, 54.42893051332044, 34.24281327955185, 18.885214136492824, 55.13164666391189, 14.727541958132099, 0.3052274474213201, 0.08261723533993767, 0.06232772608317676, 0.06438107154662571, 0.04020175851520993, 0.07703222454555574, 0.022445581365196456, 0.045879680453048605, 0.013380253240616332, 0.015161307115528374, 0.045828371714319915, 0.0202670264914031, 0.02484941779966316, 0.04654452602769579, 0.10635898193164219, 0.15963697265232765, 0.15134544983025522, 0.22107973694801333, 0.13514612230562395, 0.13746215931830869, 0.16124353563833624, 0.16587720312658819, 0.15524099160346294, 0.09862253577598641, 0.17087050293001438, 0.08044653286736819, 0.21180477173578358, 0.1251502760175255, 0.15872682955476547, 0.11567044357258467, 0.18952482049503636, 0.1584158131792661, 24.642616164299753, 65.38268266185638, 61.34385339675411, 43.4011750067434, 37.6097797578381, 58.46295487496161, 68.27779585315336, 67.2592818352484, 50.52373639998898, 0.7236383795257538, 1.168002286745656, 0.637309279653334, 0.108327575088028, 2.6780629542566117, 63.84066558653309, 64.55198349491243, 65.48428381642988, 58.392473805335264, 56.52959900517618, 50.56715311542634, 46.69076881101055, 46.74556824468797, 46.71602103017992, 47.631404169144176, 49.79987475179857, 52.278542057160415, 53.65413688844251, 55.21822906309559, 52.00274844323435, 55.6845518081419, 48.54690890158377, 44.91320163972917, 44.94691441136022, 44.32296337619905, 46.25385991988644, 46.39657928097633, 42.452796889889626, 45.110241905335464, 45.7539342295739, 44.24592018127442, 43.9406931015753, 45.80416410200058, 45.40412941286641, 45.39262902352118, 44.67410179876512, 44.56091004033243, 44.24615944585493, 45.52081208075247, 46.34933825462095, 46.148038295007524, 44.435500098812966, 46.94991980829547, 46.269286601774155, 42.29940868193104, 44.92826354119086, 45.0114256335843, 43.88327744699294, 42.349414979257894, 46.57237206735919, 45.33091445122996, 47.18549736084477, 45.809000384423044, 45.091112506005075, 44.975477110955026, 43.5529040521191, 44.771149081568566, 53.575144275542236, 55.55402317354756, 59.3891441437506, 59.161595682944025, 57.9988718032837, 59.55320904331823, 55.294832952560924, 53.9836238276574, 60.48604280717912, 56.80320393654608, 58.360702606939505, 48.89738052122055, 46.26639973732733, 41.74986108656853, 41.92372798919678, 41.95092178160145, 41.594692122551706, 43.20807280079011, 43.703315181116906, 43.00663555822065, 43.91992415151289, 44.65379176601287, 43.2029737195661, 43.993292085586056, 42.52898500811669, 43.672438283120435, 42.5082278251648, 42.93398934025919, 42.480112275769635, 42.64080393698908, 41.98830196934362, 40.794438392885276, 42.780224584764056, 39.53942506544052, 42.154904642412745, 43.061627188036525, 43.303892381729625, 41.86089161903628, 42.04314454909294, 41.75174382425124, 42.43356943130493, 45.00793864650112, 47.34872287319553, 48.82345953295308, 49.1409989326231, 47.71151857991373, 46.509892632884366, 46.74950238197081, 48.19490755757978, 49.494271124562914, 49.95673817972983, 50.43134889295025, 50.15559058035574, 46.09534517411263, 45.698675878586315, 43.054872866599794, 46.028017690104825, 43.942622907700084, 46.94961386342203, 45.90604766722649, 53.262566674140196, 56.62679926041634, 60.581929068411554, 56.40240046285815, 43.46050477796986, 2.0204842138674954, 1.3593370972141143, 1.407976816258123, 0.3868283445556318, 1.2838789075613022, 5.774713408562445, 65.04507249401462, 60.60319223711568, 57.70345849375571, 37.14247642024871, 31.491182350343276, 62.70701039221979, 21.627166617301203, 0.37135894560525495, 0.1488344434408411, 0.14051547934932096, 0.20972038438964277, 0.13516499871207824, 0.1542212366456947, 0.24278608751633476, 0.12120293137887794, 0.10463588165059205, 0.20080089929603762, 0.10672616021287058, 0.08045015646325004, 0.11258556071909205, 0.14554795688919483], [0.03933635112198611, 0.024991728207697312, 0.029962932120167443, 0.06905482075507603, 0.060699911818148634, 0.015502377120297284, 0.061090490255024166, 0.04655858757154596, 0.020449638869913838, 0.03277886065564329, 0.06202900924930169, 0.012703941244962475, 0.025929232135475166, 0.02971662719163203, 0.03761074190298396, 0.07917533253109263, 0.09357376354596308, 0.1100091150991859, 0.8620023775485255, 34.466325621451105, 56.37443004115936, 37.932316257107644, 27.011219801441317, 38.5169102299598, 55.264936647107525, 53.60974350283223, 45.5237264017905, 0.4937887744557473, 0.4743493240206473, 0.21770357214395078, 0.3055322278411158, 0.1344776339828968, 27.54013376851236, 73.75315789253482, 57.66099099190005, 61.554359159161976, 56.430574847805886, 54.41980315792946, 44.23693403120964, 46.738147120321955, 42.48154786325271, 46.45791730573101, 46.06796310793969, 47.53179165624803, 48.9006321660934, 48.73387652058756, 48.92044405783377, 48.21899483280797, 45.77586420120732, 42.85580473561441, 40.30549926142539, 40.92704196130076, 39.110486430506555, 41.55014968687489, 39.997738330594956, 40.598939618756695, 40.05506769303353, 40.914282491130216, 40.50763468588553, 41.436628449347715, 41.71283391214187, 42.088228271853545, 40.876431618967366, 42.89201605704523, 41.215881378419944, 42.799503034160985, 41.90277468773627, 41.91385146110289, 40.86264841018185, 41.55138523347917, 39.30102340636715, 39.652408938254084, 38.790346499412294, 40.93527501629245, 41.93680517135128, 40.6542528829267, 39.169624005594564, 39.70214066966888, 40.52891746644051, 39.61546805597121, 40.52430475911787, 38.14930569741034, 38.805961455068285, 38.67004740622736, 44.133242253334295, 49.94613209078389, 52.42691355366861, 56.57866001129151, 54.45906608335434, 55.68959205381332, 53.91644539371614, 54.1243859260313, 56.61335337546564, 52.83397713015157, 52.67922001500284, 47.205776014635646, 38.849248732289965, 39.321906105164565, 36.9279541507844, 37.9716537075658, 39.07505173836985, 38.77502572151923, 38.873979276226414, 40.12699611725346, 38.925534909771336, 39.088858481376406, 38.747043532709924, 39.78396131146339, 38.49726700013684, 38.61806815670383, 37.628877778207105, 39.590219759172015, 38.70229321141397, 39.61417759618452, 38.314421792184156, 38.5773382648345, 36.51961580399544, 38.58211571170438, 38.745721693961855, 38.73710816906345, 38.11221968743109, 38.635687443517874, 39.40829238583965, 37.64220599205264, 40.98667767740066, 46.252902861564394, 45.2516080487159, 45.708626931713475, 44.752094207271455, 45.65905601747575, 44.57510117561587, 43.010659910017445, 42.819126652133086, 43.01052654943159, 42.39930360547958, 42.789410775707616, 41.33130888785086, 40.88482549113613, 41.16620848255773, 39.53558114267165, 38.21652335505332, 40.76484803230532, 40.711221387309415, 45.50809183428365, 50.528462856046616, 54.54131818586781, 55.494509050923014, 56.41837235419982, 19.433071190311065, 0.22255126927648822, 0.30122218653559685, 0.6801920624509935, 0.08428198270379536, 0.31686796956966, 7.747436146582327, 55.10679452650009, 51.24730387041646, 37.78354467884187, 29.23140879600279, 39.26679288187335, 40.62103825230753, 2.693645795506816, 0.28322463614806054, 0.0519458327682749, 0.0215839067353837, 0.043726927420545014, 0.022258606115956942, 0.04209701407460436, 0.048057545847710104, 0.03656240803520045, 0.0698944301374497, 0.038120075459441835, 0.04613280356411011, 0.05899053600226199, 0.030868459537985827, 0.022899833199898564, 0.02777799956440445, 0.060004510826641516, 0.024849927248132807, 0.08336126759287812, 0.0626979035986287, 0.07881303422994192, 0.04558511581572314, 0.05207583022814605, 0.041850161393203085, 0.011099439035470208, 0.032713298851083365, 0.03322763496168679, 0.02697004876550167, 0.031321464564591166, 0.016143766997922814, 0.10469257215698881, 0.1484504954949502, 0.13600617857469668, 2.887427061796189, 45.49335548954625, 60.3275868969579, 34.1382428907579, 37.87573606737199, 45.67627914490239, 61.175101264830566, 58.389245694683446, 53.19014010890838, 0.5830086611451641, 0.6335222925389967, 0.10811694687412632, 0.2165400378045536, 0.05110203288495541, 31.94069185564595, 72.74990189460017, 59.878550037260986, 62.80085702096263, 56.526492487999704, 56.9205730192123, 46.165704650263635, 46.80370561538204, 44.47746161491641, 48.453532957261615, 48.03648694869011, 49.72976630733859, 50.20434564159763, 50.648138292374156, 51.82527688241775, 49.91541993233466, 45.98256526454803, 45.48136872629966, 41.19689710678593, 41.142552668048495, 42.49124788468884, 42.987549304962165, 41.52234008235317, 42.619776110495295, 42.666589598501886, 43.18923757922265, 42.427070063929406, 44.20281725545084, 42.989871348104174, 44.587919481339, 42.69220267572711, 43.93246789132395, 41.61539831469136, 44.49714014607091, 43.564451509906405, 42.96913769937331, 42.64436544910554, 42.70177718131773, 40.75094323004446, 41.04256752998599, 43.5024231480014, 42.289916546114036, 43.2196359480581, 44.18263666091427, 40.60012417454874, 42.221957560508486, 42.21838820365168, 41.38287236613613, 41.56316018873646, 40.64117962314237, 40.52447734340545, 41.19792084540091, 47.1792725593813, 53.501431172893895, 55.52669994292721, 57.73941486112533, 55.71141219908192, 57.72917355260542, 54.65193686946746, 57.26112496468329, 56.520142170690725, 56.03498028170679, 53.90913017334477, 48.793982921108125, 40.91159958993235, 41.93438114658479, 38.63491081422375, 42.119034567186915, 41.52066523028959, 39.96750862367692, 39.95374502674226, 41.03640940881545, 40.506869823701926, 41.95429501994964, 41.652829493245775, 41.156790871774, 40.656382729930264, 40.39023030188776, 40.4200913060096, 40.74452231007238, 40.20349018035397, 41.00747800642445, 40.801945809395086, 40.87211308940765, 38.38687189163701, 40.66582387493503, 40.99799371534779, 41.66982512320242, 39.42466043656872, 39.54771303361462, 40.9042961366715, 39.48806162803404, 42.077049516862445, 47.722136435970185, 48.15371090365995, 46.3299068327873, 45.661864434519124, 49.380004636703006, 45.45597137943391, 44.255718261964866, 43.77212924342002, 44.38762757085985, 44.10532674481792, 44.99581460029849, 43.385085444296564, 42.90772907195553, 43.700589133847146, 42.41098442385274, 41.57331128274241, 43.543219720163655, 44.01882671540783, 47.07526699189217, 51.715175951680834, 56.459463104125, 56.75364478941887, 58.63414279876217, 21.19032636765511, 0.1530481415290025, 1.0605722449479564, 1.2199037017360812, 0.08196232975610802, 0.6145952629946894, 8.516821803585175, 61.590645005626065, 53.1021378117223, 49.681391716003425, 30.202785730361942, 34.98258798353134, 48.79932126691265, 3.577750238680071, 0.32071538569946445, 0.07154270661093536, 0.11816344689577819, 0.13671859437900205, 0.06653305849120503, 0.04344173586897312, 0.029878273658875017, 0.032175344249774376, 0.03387655739882781, 0.04624766695703711, 0.055142081823320165, 0.04337847998906528, 0.04051539874184997, 0.06363662943664579, 0.13453585666514215, 0.20992378073353923, 0.1532582181595987, 0.28994745604934236, 0.18828977950878684, 0.15087513313178094, 0.19827149147468232, 0.16182571649551392, 0.1737265859640414, 0.14778160880650246, 0.16260698828245365, 0.15210360108364016, 0.15666277418213506, 0.1363351520511412, 0.18501630113009485, 0.30413748816617076, 0.31260046146569714, 0.29680164470787973, 3.547866680929738, 55.07727084621307, 64.64311192112585, 48.5683407322053, 37.48975130819505, 50.661709693170366, 65.87842710556524, 62.99766586672876, 57.48213875678278, 0.5420499234910935, 0.9505926012512177, 0.39444822277272906, 0.7731859434035517, 0.20024445899311574, 32.53098503235848, 75.30905231352776, 61.58858183891543, 65.58734409270748, 60.72033774468207, 59.82021262568813, 47.96581760529549, 50.35623942652057, 46.45324576285578, 51.88945470317718, 50.870156211237756, 52.716474686899495, 52.202722641729544, 54.59458397280786, 54.03938031965687, 51.62511048778411, 49.22066619319301, 47.85767785964474, 43.55369637089391, 44.88583134066674, 42.59259800757132, 45.87600231170655, 45.24798770104685, 45.57446225996941, 42.63918007573774, 44.766175516190074, 45.58677457994031, 46.73749600687335, 47.604092705634336, 47.106959742884484, 45.010139096167784, 47.40227107078799, 45.994175480258086, 46.58697112914055, 45.744814718923266, 45.2269834087741, 46.28382682800294, 45.19639284380021, 42.84261772709508, 41.86164471410936, 42.20130235918107, 45.79950040386569, 46.05428580314883, 45.423964838827814, 42.08167006892543, 44.05067243883687, 44.47860302463655, 41.59951271549348, 44.573026241794715, 44.974335701234885, 42.808767672508, 43.773188283366544, 50.04741161100326, 53.99213144856115, 59.09753553328976, 60.63432801154352, 57.25981881541591, 60.13072313800935, 57.7749829138479, 61.018732055541015, 58.100194469574966, 57.61946485888574, 57.24199556535291, 52.103310169712195, 43.76954047910629, 44.791082566784276, 40.77848219102429, 43.038465592169, 43.19953772329515, 42.37225494077129, 42.106863452542214, 43.880798509044034, 42.38484574902443, 43.73079530654415, 43.22592350744432, 44.653858446305804, 41.999712144174886, 41.65301776701405, 41.71624637419178, 43.20912399599629, 43.229445795859064, 42.16941348968014, 43.47558629128241, 42.8752596916691, 39.802537656599476, 42.86424959859541, 42.61129594618275, 42.246280177947014, 40.928030398584184, 41.809488957928075, 43.67555264503726, 40.18351747143654, 44.43176600240892, 49.78307916272072, 51.12243521598078, 49.26772286815029, 49.261866769483014, 50.76465622071297, 49.104297314920736, 46.899529118691724, 48.342290616804554, 47.165826674430605, 46.525958661110174, 45.27048641635526, 46.96882171015586, 43.47124422750166, 46.150015169574374, 44.57080618027718, 43.368964502888346, 45.45327671112553, 46.464432362587225, 47.78112888336182, 54.92608701029132, 58.87476451935307, 59.78373066071541, 59.03496980667115, 22.714975187855384, 0.43544514224894587, 2.031451160869291, 2.149626780902186, 0.20209100668228444, 0.8315739167794105, 10.452354588816243, 67.01662832690825, 58.30564037446053, 50.60286629584528, 39.568862453583755, 48.734182465461, 58.83515642535303, 6.32821818513255, 0.5811930327646194, 0.1302443700091493, 0.23267167380019543, 0.18413494761672713, 0.2401041669110137, 0.1575510378085798, 0.14303316602543478, 0.18243895152643805, 0.13324380341556766, 0.16347324986371303, 0.2935431969742621, 0.21908381743536842, 0.07595230104221452, 0.10420648936903286], [0.017506848089396954, 0.04483562901676182, 0.029968266007340247, 0.03829481245409097, 0.055949921539473924, 0.045710375021782615, 0.06704261421316093, 0.026957986711133874, 0.03931380132393491, 0.04305969931245331, 0.05126143662980007, 0.012842058279221098, 0.028331256772000945, 0.056705755376887906, 0.043770682532340295, 0.0216791927514057, 0.046249654955200614, 0.02064996894689337, 0.046805133817777525, 12.253016675672225, 56.57324321808354, 38.76254866200109, 27.362526885924805, 33.900300148994695, 47.94957899278211, 54.12516255532542, 52.82952524000599, 2.998038390951772, 0.8552074228082934, 0.16682116134512812, 0.21196770331551953, 0.16127732011579698, 2.9177361967102176, 62.44185424620106, 60.1016152289606, 61.37550692404471, 56.03985971020114, 62.359621755538456, 52.283284202698745, 45.99249278345416, 45.48474196464785, 45.81675883262388, 45.96036857174289, 48.260434673678496, 47.64037070735809, 49.071318026511904, 46.64648132939493, 46.80638851657991, 42.652347472406205, 42.36947398031912, 40.937903004307906, 40.213139210977864, 41.443382770784446, 40.00485351008754, 39.698151619203635, 41.57684533826767, 39.058656231049575, 39.52033096744169, 40.07086307771745, 40.55723305671446, 40.04495974509947, 42.867465942136704, 41.457915152272875, 42.296462981931626, 42.236450718295195, 41.003139865013864, 41.46190420273812, 42.859762407118275, 39.911128474820046, 41.480468780763694, 40.217861744665335, 41.2457110035804, 39.828440989217455, 40.66525513126005, 41.766185991225704, 43.95313485976189, 38.476482360593735, 41.445744037628174, 39.43485467664657, 41.68682859789941, 38.88841359846054, 37.24938061929519, 38.40674654130013, 39.860980972166985, 42.57184866935977, 48.38276163224251, 48.18069681044548, 50.68493404696065, 56.13877404120661, 56.83482216250513, 55.698586048618445, 55.75156550253592, 56.98486066633656, 52.516496566034135, 50.48208475112916, 46.12134264361474, 40.83996926584552, 39.852528264445645, 38.673926630327784, 39.688616337314734, 38.49354859321348, 38.5908978985202, 39.31160596109206, 41.085384122786984, 39.91816128453901, 39.913073970425515, 40.303440017084924, 38.11354544854934, 38.32815793252761, 38.2427797009868, 38.32434538872012, 38.28349782574562, 37.931884796388694, 40.204223663576194, 39.33670128545454, 38.24630983414189, 37.31335447680566, 39.745522083774695, 37.0722738389046, 39.3247341340588, 37.690796313747285, 35.7617275945602, 37.49477194201562, 38.433512795356016, 45.43188410420572, 49.06789771972164, 49.27861529011881, 47.81818743674986, 47.721191144758656, 48.06933287651309, 46.43121380959788, 47.54930111669725, 46.63694212513585, 46.57939703233781, 43.30695183046403, 44.24503764798565, 41.821287447406405, 40.07775860448038, 38.715056603954686, 40.965257613889634, 41.36281728744507, 43.193430592936856, 44.320582497504454, 47.90775083726453, 49.960029048304406, 55.40823259661275, 55.64710886247697, 46.98272259004655, 6.367121233094124, 0.02109439378874677, 0.48269410527521567, 0.5051502567385474, 0.17799487547768703, 0.4598700783906445, 15.492878748524575, 61.306461441901426, 45.410538565727975, 35.443058552280554, 23.562275786553663, 46.858579574092744, 26.587801902524888, 0.23175166349016854, 0.07532571772894553, 0.02473920072999693, 0.06980261449972469, 0.0815816147012576, 0.03743276435641512, 0.04689248316290398, 0.19584743606467403, 0.04779566252123445, 0.042128680318954496, 0.01975344306218528, 0.05037039593462983, 0.04382989346800793, 0.10956137501184018, 0.028502929414952957, 0.04202314404650562, 0.0035998148368596434, 0.018529270948361487, 0.012985891287004756, 0.04868254718941547, 0.11057923773243544, 0.030075909021580895, 0.03458306283479737, 0.052035001572221525, 0.0581297327974631, 0.05768231063660595, 0.015229241877433755, 0.07586529643665399, 0.07580325863654576, 0.05098566795969683, 0.01177901839612112, 0.07243490792931088, 0.030390723277964903, 0.09751502544649186, 20.117844458549254, 65.6152125327818, 35.0603489721975, 28.417991592038064, 44.45374304248441, 52.226398068089644, 58.09734682882986, 54.509805863903416, 2.7499175888876763, 0.7189220971157475, 0.14874220645475775, 0.37188426741669256, 0.19302947356575922, 3.736113237757837, 67.72249806311824, 60.91076097180767, 66.87834124411306, 58.68935800367787, 62.74771674986809, 54.22133907195061, 48.58256324645012, 46.483075388016246, 47.85546564286756, 48.452536675237845, 50.9426220001713, 47.85017044313493, 51.65073533211985, 49.01637738750827, 50.19614004319715, 44.88836126942789, 44.48453757070726, 42.57846178547029, 42.42822716313024, 42.97972025409822, 43.02309774583386, 42.196768099261874, 44.78586973682527, 40.43438050054735, 43.04197219110305, 41.50053170419509, 42.19461471803727, 41.61822242121543, 44.267328477674916, 43.107428704538655, 43.05209582851779, 42.052444488771506, 43.13598748176329, 44.39737073836788, 44.40331312917894, 43.48032843682074, 43.93933596149568, 42.01221666028423, 43.53886196690221, 42.00524268611785, 42.49325613821707, 43.47444488156227, 45.69932306966474, 41.571730567562966, 43.15625044607347, 42.97826897713446, 44.62467601222377, 43.05030330534905, 40.33238710895662, 40.19582194666709, 42.082309415263516, 43.721514978716456, 49.89593359731859, 51.6238514069588, 52.48571772729197, 58.16130107448947, 57.740211102270315, 57.25551597533688, 56.58385322939966, 60.19059027394941, 54.64024820635396, 51.99442909609888, 48.55844066989038, 41.930858858170055, 41.18982507336525, 40.758960554676676, 40.635684382530954, 41.50055523841612, 40.10448171246437, 41.94875663326633, 41.52223417835851, 41.29536428759175, 42.307822165950654, 41.977409547375096, 41.23967447588521, 40.14285033748996, 41.72875873504147, 40.2147630722292, 41.0713694941613, 39.55345146117672, 40.75848594788582, 41.16368639853693, 39.76599293370401, 39.45992646678802, 41.57377020005257, 41.2039299165049, 42.035492004886756, 38.70880826827019, 38.901055397525916, 39.8642090828188, 41.05455821560275, 46.68320255894815, 52.14424010246031, 51.43123557490688, 49.353889496095725, 48.77222161139212, 50.39964829721759, 48.88090264412665, 48.71023247318883, 47.57023480630691, 47.57496910710489, 45.470974445343025, 45.64828126661239, 43.83601288641653, 42.49302079600673, 41.293720814489554, 42.45522483702629, 43.41240867491692, 46.19228655292142, 44.566966179878484, 51.0566492234507, 53.19594913913358, 57.15711547482399, 56.47693334087249, 48.05419645001812, 7.121619534107947, 0.39688015356659895, 2.5586088866956773, 2.0234983101967843, 0.14849918804341747, 0.7798137684022227, 16.52016808909755, 67.83765885137743, 48.11814285093739, 49.081014125577866, 26.524386982763968, 46.967503793777965, 33.84763840706118, 0.3623041847059804, 0.11130299163802017, 0.026762065470158577, 0.10069085059747582, 0.06773534155781231, 0.05282543960117525, 0.03786862625049488, 0.06792154688868793, 0.05781149604327737, 0.017887791055404854, 0.08453016454774527, 0.002929792662466606, 0.06187566909037771, 0.12381576617518741, 0.023795460846515435, 0.17061325060504098, 0.09165095946481151, 0.12044138635598844, 0.15190781965371103, 0.1561037751455461, 0.16574154427695661, 0.11996522440665192, 0.09830179008384866, 0.1789706876321185, 0.2216418156580579, 0.18379647465002152, 0.10079639453080394, 0.2832383644436636, 0.18255669924039997, 0.1488632023815186, 0.13524597420567466, 0.12109766323720256, 0.13853875800005852, 0.2026534224710157, 23.37909717713633, 74.12551633773312, 47.01512921241022, 38.062621316602154, 46.73529947957685, 58.81011601417296, 64.16299027781334, 66.38944918109526, 3.018148873121508, 1.8192864810266804, 1.4944310029668193, 0.9276596060202968, 0.26817949669015023, 3.8604187869256545, 66.80217666010704, 62.14490336756553, 69.58722422199865, 59.29600746400895, 67.83179098559965, 58.188855724949995, 51.23274010996665, 49.68268217579011, 49.79970608988116, 51.950667212086344, 54.09984365586312, 50.8277161659733, 53.48662814786358, 51.89364771689139, 53.30352798584969, 47.83947021730485, 46.68010388651202, 46.18108426370929, 44.91912049631919, 44.29821322041173, 46.24300279924947, 44.43584526738813, 46.59232124205559, 44.40771402851228, 43.79948385300175, 44.190775579021825, 44.59972581555767, 44.500611443673414, 46.99783940469065, 45.83145203128938, 45.429471846549745, 46.66453992166827, 45.043016402952134, 46.23081991749425, 45.83560582130186, 45.91031912834414, 46.421411806537265, 44.46693397337391, 46.130795555730025, 45.18188791890299, 45.02112565502044, 45.33998689343853, 48.710475660139515, 42.66957452220302, 47.1994766881389, 44.233399975684385, 46.77768068928873, 44.62985354085123, 41.824515558058216, 42.9611203747411, 43.050232702685946, 46.26704300603559, 51.924085309428555, 52.77314116877895, 53.55108837927542, 60.64498901367188, 59.71828591439032, 59.327056946293006, 58.99949196846255, 61.384728416319824, 55.025523016529704, 54.90654576209284, 50.19135475158692, 45.749505873649355, 41.98414033459079, 43.11845840946321, 45.03032753544469, 43.56429461509951, 42.172112080358694, 44.99485361960627, 44.057509130047215, 43.91081640797277, 44.61893758466167, 43.238004407575055, 43.63904714584351, 42.57042092661704, 42.43704465127761, 42.71947491553522, 42.50174806964013, 41.95855471395677, 44.029020955485684, 43.55677543147918, 43.16301261225055, 41.440319399679865, 43.50671029859974, 42.32690841920915, 44.53224928148332, 40.82085555599582, 38.804627849209695, 41.86930510305589, 42.37946033477783, 49.922931271214644, 54.793875678893066, 52.81772675052766, 50.89998583639822, 52.12965673015964, 52.42899633223011, 51.634681071004565, 50.954950009622884, 50.940186208294286, 50.41756176179456, 49.026959942233184, 49.8554821937315, 45.81195785153297, 43.27604355350618, 44.309207624004735, 45.25052547454835, 45.68675971800282, 47.985327474532596, 47.2379159158276, 52.44130865220101, 56.27273474970172, 60.128934537210775, 58.4346628189087, 48.59792324804491, 8.863898611837818, 0.6062077646774631, 2.936220120999121, 1.8707767825934196, 0.280354748209638, 0.8992867123696112, 20.546737986226237, 72.60929276866298, 53.25273721448837, 46.55356430238294, 32.73283412379603, 58.0801550803646, 40.17167191351614, 0.4280478891826445, 0.21860971626254821, 0.14288840605126274, 0.2690513660350154, 0.25667518497474734, 0.17746416040726248, 0.117746802317279, 0.3867339931668774, 0.21513926135676525, 0.10528599152401572, 0.15106369801346334, 0.08841698824037468, 0.177262909109554, 0.31514684579545454, 0.09186735632078302], [0.006814588137316488, 0.09041402624138901, 0.0840060301725903, 0.03624348946276211, 0.10404381825919114, 0.05424989582670312, 0.02843344715544053, 0.056804174692520214, 0.01742934488931731, 0.03953707381902684, 0.003262614533718255, 0.041168071179380344, 0.04233700260820408, 0.04346517049857686, 0.03436657787871457, 0.07199650645376214, 0.006841625774189109, 0.046403079383796265, 0.09663751769450404, 0.5702907435836331, 31.79568183037543, 51.06301523024037, 32.55790033648091, 35.43654741779451, 42.607648141922496, 50.40435514142437, 61.18256553526848, 14.35355474871974, 1.0182309330951784, 0.4125257833830772, 0.11624137059815469, 0.07662147118319428, 0.10255812862587553, 20.515504152544086, 67.38984184880411, 59.11817112276631, 62.407866908657944, 56.06083262351252, 58.80002767808976, 49.29756033805109, 45.02774269350114, 45.244022184802645, 45.760131574446156, 46.47726243542087, 47.237049072019516, 45.331698925264426, 47.04175033876973, 44.39318556939402, 43.186923380820986, 41.6134802756771, 41.81948315712714, 41.1286949342297, 39.6411007450473, 40.53610717096637, 38.86130217582949, 39.74977393304148, 40.879357707115915, 41.16868349813646, 41.472427921910445, 41.534056202057876, 43.36403016121157, 41.91012913180936, 42.13574386412098, 41.2978079242091, 41.51096913122362, 43.058595195893325, 42.25381112867787, 42.74301698130947, 42.126577285028276, 42.18616985505627, 41.7715714054723, 42.25940835091376, 40.70012500209194, 41.181454735417525, 42.03390344496697, 42.49512318641909, 39.47444315879576, 41.8519760716346, 41.098072990294426, 40.1415128092612, 40.013447423135084, 37.69702503758092, 39.30774242647233, 39.624434594185125, 39.951685782401796, 45.722119885106245, 48.26363925010928, 52.08771874827724, 53.02995443344117, 55.337979024456395, 59.203847454440215, 57.08177066618397, 54.69596155228154, 53.614689611619525, 47.74494109615203, 43.995963219673406, 40.28198857461253, 40.263376928144886, 40.479468145678126, 40.13854749741093, 37.67102756807881, 38.80962494880923, 40.40374678950156, 38.843561295540106, 39.06391220708048, 38.565457405582556, 40.27588144425423, 40.19611612443001, 38.73002829090242, 37.59554939885294, 39.639053267817346, 37.59525914346018, 40.20658100804975, 38.734970477319536, 39.59399700164795, 37.967539141255045, 39.38955522352649, 38.8421453199079, 38.209612138809696, 38.66755670116794, 36.77033370540988, 35.907675066301906, 37.264842602514456, 38.5337842664411, 45.587076602443574, 52.850023546526515, 51.168723106384284, 50.55582138799852, 54.06795086399202, 55.59629455689461, 50.465155801465436, 49.7640674344955, 50.17892868288102, 48.48322529946604, 47.40730347171907, 48.54303359985352, 46.72232820141701, 45.80344238588887, 44.46790279880647, 41.25528550917103, 40.84060076744326, 43.034311802156516, 44.098670482635505, 47.8420276026572, 52.337699244099284, 55.54662950577275, 55.24502277374268, 31.060398240243238, 1.181288825408105, 0.08647952123635239, 0.4281605653945477, 0.8611664836925845, 0.05557335102029386, 0.08204893599594794, 36.49994903995145, 58.97695795182259, 42.42332420041485, 26.816556492159446, 26.477871594890473, 46.94609941974763, 6.594664790937978, 0.28638490205330236, 0.047161184671905734, 0.03190361286303209, 0.05287113291541896, 0.03344368324765275, 0.061340311527132034, 0.08890297909777972, 0.03416630717354917, 0.02781888184648368, 0.012184105580672623, 0.01892768646470241, 0.04200498776270017, 0.07212383026677756, 0.035060726316465486, 0.017446597189372106, 0.012325354956931645, 0.019157604772537466, 0.06318140850071946, 0.022238318192502184, 0.021000028993453712, 0.05671847626687058, 0.024429452230012225, 0.010432563327823677, 0.023155302455228184, 0.04538343167833744, 0.010307582786246654, 0.03215336901766639, 0.035085934439613935, 0.02273069630797592, 0.042023442820796085, 0.01336684765955133, 0.022648862795904282, 0.11979152929157981, 0.05511057262699451, 2.176882350637067, 44.59202620290941, 52.44357578216061, 31.73738168131921, 47.006743184981815, 46.93981186036141, 56.33455914835776, 65.62200607792025, 14.071952104568483, 1.261762010474359, 1.1872546278661298, 0.27514538096804775, 0.05043090921976874, 0.07350473439381008, 23.34674939032524, 67.88966947986235, 60.98724326779766, 64.6402289790492, 58.586725265749045, 61.67128893636889, 51.278423955363614, 47.61118435090589, 48.971870253163004, 48.46489998602098, 49.254802580802675, 48.80197671151931, 48.8164855587867, 49.20027379066714, 48.51006215618503, 44.81544833029471, 43.079226862999704, 45.202307778020064, 42.87558132602323, 40.345334852895434, 41.527054771300286, 41.27510916802191, 42.04539991194203, 42.950698637193256, 41.930294036865234, 42.84734418315273, 42.93660556116412, 44.09139056359568, 43.47981852869834, 43.98488644630679, 43.405105221656065, 42.235489737602975, 46.00288314204062, 43.745837596154985, 44.363650121996486, 45.058058692562966, 43.85495401197865, 41.8080690599257, 43.51215454839891, 42.86740318421395, 42.72208329169981, 44.83925711724066, 43.1369210058643, 40.92002876343266, 42.483748312919374, 44.19154828594577, 40.863275989409416, 41.5696007205594, 40.96460257807086, 42.25703139458933, 40.312602673807454, 42.99153051068706, 48.99174098045596, 48.61553469011861, 52.589217309028875, 55.65261194782873, 57.142434043269006, 57.805463652456964, 58.158979031347464, 57.743254861524036, 56.46524075538882, 48.68669825215494, 46.10289965906451, 42.83611051497921, 42.706295751756244, 41.33075975602673, 41.484030292880156, 41.064215090967, 40.562606703850534, 42.44075521346062, 41.49127491058842, 42.01840223804597, 39.8434950459388, 41.27073572527978, 41.90128810944096, 40.27566963626493, 40.331590867811634, 43.36831338943974, 38.92968085504348, 41.31697262487104, 40.883691926156324, 40.48924661451771, 39.380208215405865, 41.57041657355524, 40.83414062376946, 40.900734624555035, 40.533098713044204, 39.34495002992692, 38.05734572872039, 40.21581818980556, 38.70931033165225, 48.55755813660161, 53.00839708697412, 53.21324286922332, 53.266849902368364, 55.26562306188769, 55.87712449412192, 53.73249015500469, 52.78318243642008, 50.23239451069986, 49.80209873568628, 49.826209545135505, 50.61001285429924, 47.78270959854127, 47.70155183730587, 47.92360113513085, 44.1494926329582, 42.30167188952046, 45.250870643123505, 45.290788604367165, 50.6654320224639, 56.06280949807937, 55.515293690466116, 56.031740403944454, 33.510793101403024, 1.2847675695534677, 0.6535888931924297, 2.6486738602961264, 1.805741801377266, 0.05774004302257973, 0.41284251477449174, 39.910697014101096, 62.481321134874904, 48.53829929905553, 34.368521321204405, 23.11595516820108, 55.47435591297766, 10.522004115966059, 0.33475670482843156, 0.08619467442434642, 0.030674359671050505, 0.019454454267097097, 0.05475732565466916, 0.024363892340672114, 0.06859227984903321, 0.022053449685054443, 0.018605776318919756, 0.023336062816181974, 0.015633206743176187, 0.01582239885934659, 0.032794688032158924, 0.02324357110586378, 0.045035639252032966, 0.1321735939071063, 0.1003420124611547, 0.22529009489282487, 0.14883151698497035, 0.15498426021827807, 0.19868763043515145, 0.13605114793585193, 0.13381718958337463, 0.09384422322675105, 0.21848789296082913, 0.11114173012995913, 0.09599155235675075, 0.1346070109115493, 0.083635289582514, 0.12130608511788231, 0.1297140226609284, 0.11949928973110453, 0.262254633970799, 0.2743272909954671, 2.6671661196216463, 52.14760941843833, 62.67580009275868, 45.1906701057188, 48.35327325328704, 52.70300134535759, 59.939739011949115, 70.61571674962198, 18.88438847757155, 1.3944499098485517, 2.493255335477091, 0.6894283861883226, 0.2572726416251352, 0.16106218730490054, 23.81594527152277, 67.6074000327818, 63.86158358666205, 66.88390316501741, 60.7844175061872, 65.17278094445506, 53.521094014567716, 50.55002412488384, 51.03436623850177, 50.63782638119113, 50.59149534471574, 52.11910947676628, 50.875647529479004, 51.62842096820955, 50.52709787122665, 48.54928193553802, 45.30670166015626, 46.60510816881734, 45.14492742476925, 42.98139902853197, 43.489342043476725, 43.24267987282046, 42.7267038437628, 44.810568901800345, 44.08092567997594, 45.6803584098816, 44.48469838788433, 48.202230622691495, 45.39382142405356, 46.12866570872646, 44.59190460943407, 45.09874151599023, 48.779827087156235, 45.96700522207445, 46.2884081563642, 46.39759125248079, 45.39200928903396, 44.82161821857576, 45.20545351889826, 45.303300965216856, 45.544126649056714, 46.09341144561768, 45.81694318402199, 42.60370223752914, 44.58014926602764, 46.751267448548354, 43.15525416404971, 45.30193990276706, 42.39181187845046, 44.09144155440792, 42.7052524012904, 45.06989248337285, 50.24744464505104, 51.517139404050766, 54.474841856187396, 56.25604114224834, 57.69206793077531, 60.11730470964986, 61.44970247822424, 58.99940567631876, 57.818332948992335, 51.28210313858525, 48.714056784106845, 43.62039235330398, 44.58101610983572, 44.544181131547504, 44.43755934315343, 42.19802325771701, 42.213242053985596, 46.065276284371656, 43.21984775604741, 44.427423938628166, 41.01746043851299, 44.561384647123276, 45.03805852705433, 42.36044076181228, 40.0807592176622, 44.384944669661984, 40.55815089133478, 44.84526618834465, 42.035837173461914, 42.727370646692094, 41.015742440377515, 43.6530892310604, 43.547946176221295, 43.57503406463131, 41.63962679524576, 40.98049209963891, 39.28751084112352, 42.43731137244932, 41.407802950951364, 50.67238246240924, 57.34358103044572, 55.824490208779615, 55.41945842004592, 57.50840294745661, 59.14832238228091, 55.09871052157495, 55.19867212541642, 53.70962273690009, 52.92119887567336, 51.43109436958067, 53.89017728067214, 50.37367043956634, 51.17445368920603, 50.36678667991392, 47.1638576446041, 44.64668050889046, 48.6239089504365, 47.93119876615463, 53.100149170044936, 57.715790425577474, 58.17692387488581, 56.51961265071746, 35.72785400575207, 1.5690844938639672, 0.5598092511776955, 2.4182743266705544, 1.982041921827101, 0.13292943157495993, 1.0162538746672294, 45.44924451458839, 67.04868978069675, 52.3308115620767, 38.51968334567162, 35.60951217528313, 61.845336268025065, 14.72463450124187, 0.38395002965004216, 0.3077298889477407, 0.15516946963485212, 0.10758155100648442, 0.22719549345633677, 0.14630240027702626, 0.19729154244545968, 0.15307811088860035, 0.1270736929690165, 0.166119072406042, 0.15671431657768067, 0.09842547497922376, 0.12456907575289089, 0.13468521316685986, 0.06708012953881295], [0.02790926106935067, 0.06251532569407456, 0.03291233615469068, 0.04039355245749316, 0.07270023482100618, 0.0343994238984681, 0.03478533685988477, 0.03928597318008542, 0.03536118983080791, 0.010117172590276648, 0.005183479215409006, 0.013350063630740249, 0.08893933763066608, 0.05014463748422362, 0.14115582160171003, 0.02268781836685394, 0.11253726653634541, 0.033108454663306475, 0.08544399252822323, 0.008446877792237267, 9.872937163999005, 49.7428709460843, 31.983741829472205, 34.6204786915933, 45.61136784092073, 42.668158546570815, 57.211695255771765, 28.766437307480846, 0.22676207155229586, 0.5690300080084032, 0.49811695672331324, 0.08986606653178893, 0.060870017811295495, 1.1805188151136523, 45.636439631062174, 58.24827178832024, 57.823792888272195, 60.92864305742326, 58.53423218573294, 52.967388706822554, 47.01918102079823, 46.85436694852768, 44.29666780656384, 44.824799260785504, 45.561079132941465, 45.06052978577153, 42.79246630207185, 43.74498251945742, 42.87755820059007, 42.28947724065473, 41.3180983451105, 41.19079782116798, 41.23841931743007, 41.75993765554121, 40.04841535322128, 39.09804859469014, 41.00507359350882, 39.801078534895375, 40.564724783743586, 40.48422205832697, 41.60079533053983, 40.795065972112845, 43.554696575287856, 40.85235218847952, 40.54516392369425, 41.076535255678245, 41.41310207305416, 43.41662914522233, 41.18099974047753, 41.10163450241089, 42.36086830016106, 40.58395616469845, 41.483963612587225, 40.96200204664662, 43.5166613517269, 41.48859593176073, 41.93053330144575, 41.39280380741243, 40.15047542510494, 40.104972008735906, 39.27216260663925, 42.41771521106843, 39.569737142132176, 41.0550759684655, 43.2331955817438, 43.38904311580043, 47.7735234075977, 54.11647058302357, 58.440448314912864, 60.0206143625321, 55.28637240009924, 56.192890982474054, 54.933331627999586, 52.45063212610061, 47.46045158755395, 43.804347592015425, 44.151124338949884, 41.73239084982103, 43.194732819834066, 42.242589227614864, 41.254657929943455, 38.31345688912177, 39.051207650092344, 39.51472982283562, 38.869237130688084, 39.89155584766019, 39.591294488599225, 39.37685851127871, 39.42544491060319, 37.9560544413905, 39.1562016548649, 40.870532374228205, 38.736970886107414, 39.09846436592841, 38.74686702605217, 39.58904304812032, 37.638789607632546, 38.76828708956319, 38.390245129985196, 37.40085078823952, 37.638769995781686, 37.58353517901513, 36.41433154383014, 37.74665478737124, 43.859723614108184, 51.47258127889326, 49.317148654691636, 52.348536752885394, 51.207782068560206, 50.77774124760782, 49.7635575263731, 52.05251155361053, 51.601305623208326, 52.173681412973714, 52.47977925885109, 49.32209476347893, 50.56443491289693, 50.36668077591927, 50.34267194809453, 48.15511511218164, 47.88968047788067, 45.34281884470294, 46.169964344270774, 50.09966934880903, 51.91778206056165, 55.03973768603418, 49.60988298539193, 12.544321302444706, 0.22645470175531604, 0.5128647927795688, 3.56660163690967, 2.671592759509241, 0.10433932135422384, 4.277060791369408, 52.70432318410566, 48.27302155956146, 38.695087817407426, 25.375791480464322, 44.23401186543126, 25.939018341802782, 0.443368636432194, 0.05177073188186173, 0.029216628416531512, 0.045232075687137344, 0.022572148666386644, 0.02572963558768313, 0.013126942438013373, 0.027376789742359714, 0.026726001881123073, 0.0207320514375404, 0.06515026978787876, 0.06364788709869308, 0.04440021145367815, 0.09003498891909277, 0.045582622199529604, 0.0717999512750295, 0.02425164705322635, 0.08331601477919087, 0.02090426417247903, 0.03789198427130619, 0.02735789992936677, 0.03518673628869076, 0.045405426062643535, 0.014161999044459195, 0.02992612925628501, 0.046122246872513525, 0.038209274906905434, 0.03588560765849487, 0.03566835278404817, 0.05504511424430436, 0.09404402661828265, 0.02013339968999067, 0.015113314579901917, 0.07100351860806828, 0.07623002323652468, 0.1330807339400053, 16.049752350776426, 58.57116914564564, 29.69609591268724, 42.61250795856599, 56.94710000868767, 48.41213234009282, 65.38292584880706, 28.64250021596109, 0.3971057204950241, 1.4245581458653174, 0.9931364667511756, 0.06857619966350256, 0.08727716432223398, 1.854241418261682, 50.299212086585264, 58.347903913067235, 62.759829028960205, 60.931537766610425, 60.24955134237967, 56.12270409061063, 48.448932017049486, 47.89479132621519, 46.46959812410417, 47.29942652486986, 47.3527511473625, 47.80150167403683, 46.46521291425152, 46.32694936567738, 46.10369197783932, 45.037878098026404, 44.32222989297683, 44.3713693464956, 44.11714092377694, 42.78248779235348, 41.7273662936303, 42.098093032836914, 43.40753316879273, 42.628938767217825, 43.90163021702921, 42.81901290339809, 43.2661081898597, 44.54067453261345, 44.77500869381813, 42.98814550522835, 42.62844062620594, 43.96655328812138, 43.09473983703121, 43.98522377014161, 42.212120256116314, 41.376800537109375, 42.96255203985399, 41.87893844419911, 43.70473507911929, 43.18645661877048, 44.57520707961052, 44.32936468432027, 44.18304850978237, 42.961041927337654, 43.638650986456106, 42.40352799815517, 41.42393958184027, 43.092135383236794, 42.657340649635564, 40.8632642222989, 44.5050201877471, 45.04624451360395, 50.572966068021714, 53.44015982843215, 59.04613287218156, 60.45660149666571, 58.06657583482804, 57.36472652804468, 56.90500905436855, 55.01147700894264, 50.01536192432527, 45.58381319046021, 46.21049027289114, 43.74870877112112, 44.6772357725328, 44.87261687555621, 42.5611602106402, 41.368940107284054, 41.583835001914736, 41.144015712122766, 40.73810531247047, 40.7868682184527, 42.89904102202385, 40.04435177772276, 41.081316624918294, 40.27683065783593, 41.77437982251568, 42.76846924135762, 40.76879393669867, 41.73679174915437, 40.27171196476106, 41.149401126369355, 40.90562189778974, 41.07358171093849, 40.122893318053215, 39.016706482056655, 39.7006776255946, 38.65790767054404, 38.27098546489593, 39.33708567773142, 45.36781218744094, 53.4462591140501, 51.73634498350082, 52.994217718801195, 54.15652582722326, 50.308194314279866, 51.45460505639353, 50.633488239780554, 54.56449547121602, 53.85144387522052, 53.565448176476266, 52.30158598192277, 54.4207602162515, 52.1960977585085, 51.97606063658192, 49.06494025261172, 51.36035050115278, 46.44332216631982, 50.137237810319476, 50.557041245122115, 57.04010725021363, 56.020028206609915, 53.829576661509854, 11.329848612508467, 0.5674032049794351, 2.2919041399032842, 3.4287045847985054, 1.6095497483207335, 0.2136989700938425, 4.994879538013089, 57.74924432077716, 54.232207959698094, 51.477025324298495, 27.241366832487046, 38.476764771246145, 37.16754036564981, 0.8512689954330845, 0.1321943855333713, 0.0970405948558642, 0.07761985228787507, 0.08328219965821312, 0.025933215792681423, 0.035728460042587215, 0.02097081614568109, 0.028723643176377784, 0.018705392646933758, 0.016078601643863707, 0.00767219148861665, 0.02736413588507041, 0.07313556428397856, 0.010754603708553459, 0.010995177341805351, 0.08657572655788354, 0.21663665681356387, 0.11397259354951883, 0.12544630771322599, 0.15473756458490126, 0.24049047440771135, 0.09200171282094333, 0.1412754998572411, 0.16800303582943257, 0.15398963294442625, 0.17922263862865587, 0.11146886499538539, 0.0981838508479057, 0.16438578315559896, 0.26921313316110645, 0.15706057299769696, 0.19924296757146237, 0.1449243919623475, 0.18756945767710287, 0.2197602883942666, 19.105533669071814, 66.11792702828684, 42.69216737439556, 44.81510316171954, 56.19605241283294, 55.90378484418316, 68.70616574441233, 35.47519845347251, 0.6036960381654002, 2.920908413587078, 1.3488132554677226, 0.20824139036478537, 0.21085232526304262, 2.2254601697767935, 49.54484224319459, 58.32120826167446, 62.8825129232099, 65.8128450762841, 63.79053769573089, 60.07029118076448, 52.46965562143634, 51.536323716563565, 49.14198736990652, 50.1683618176368, 50.503073353921216, 50.07000054082563, 49.323706857619754, 49.434066664788034, 47.712542318528705, 49.47596934533889, 47.04937934875489, 46.933112452107096, 45.98017261874291, 47.0830842756456, 44.18220912256549, 44.102808583167295, 45.46823270859257, 44.39577433370775, 46.07181879781908, 45.808141385355306, 45.37364475188717, 45.799261139285186, 46.37662618390976, 45.358641685978064, 45.29109847161078, 44.793992965452134, 45.589822261564194, 46.51651751610541, 44.30502637740105, 44.65910657759636, 46.23797432068856, 44.90015975890621, 46.45657977750225, 45.92713825164303, 48.438329850473714, 47.32539653778077, 46.78991063948601, 45.905502457772535, 45.26877626296013, 44.41823774768461, 44.512107910648474, 46.6457203895815, 45.66188796874016, 43.49901460832165, 46.372013476587114, 46.095513836030044, 52.61306924204673, 56.847577710305494, 62.5898648846534, 62.87272660962997, 58.894388137325166, 60.18672281695951, 57.94638264563776, 56.420984652734575, 52.394640291890795, 48.276590916418264, 48.31839161534464, 45.45392782457414, 47.163787041941, 47.6498196971032, 44.65256798651911, 42.667503510752034, 43.68963787632604, 42.91703685637444, 42.246629268892356, 43.70710419070336, 44.80135525426557, 43.887231196126635, 43.70814361879903, 42.7222127299155, 44.64896725070092, 45.3947235691932, 42.29315250150619, 43.38114738464356, 42.808524485557314, 43.557677576618815, 43.213242484677224, 42.99401337100614, 41.74494243437245, 40.7743440904925, 41.92437518027521, 41.57822601256832, 39.89434465285271, 43.196321379753854, 48.037393016199914, 56.39511269907798, 53.66228757366058, 55.88621654818135, 54.97068043678038, 52.42543482011365, 50.79858472270351, 53.88080673833048, 55.772110877498505, 56.44673893528601, 55.21652283207063, 56.18854499632313, 57.72500799548242, 54.838214151320926, 54.08482490047332, 53.758295428368356, 53.19002243780321, 51.05291120467648, 50.83978922136369, 55.62663801254765, 57.591616030662294, 59.20995066242834, 51.436734737888465, 16.383750996282025, 0.47201762817079024, 2.7162509051061448, 5.633205569559529, 6.2149896544794885, 0.3821749119989334, 7.647524062664279, 64.30185002665367, 58.11141637063796, 51.86792089093117, 35.93942273047663, 53.450605100201024, 44.72496317278954, 1.153631825600901, 0.19477963207229493, 0.17761584581627002, 0.1724765756197514, 0.0914237684299869, 0.15584796306587037, 0.09182011167849265, 0.15683370371980054, 0.13763777731407073, 0.11083642110949564, 0.1602854507584726, 0.17005124850378883, 0.11538531330804672, 0.13936849250908823, 0.07980127233050524, 0.21905790834176928], [0.022547792816053958, 0.023453406418763825, 0.01795272658308668, 0.03619046468708304, 0.146610367622587, 0.055219349451363094, 0.0046260923150956874, 0.020220501971761548, 0.016067001157470288, 0.0463238735533049, 0.0288353426261775, 0.01540803818047167, 0.020855071751641172, 0.051375216008314205, 0.022987151901508053, 0.09169346968372984, 0.05209177251785033, 0.06381838762712094, 0.03920518537803043, 0.07772333544468688, 0.21987034458546872, 38.18735268808181, 48.684552715670684, 31.64178567547952, 27.86784975759445, 39.1147735811049, 56.03437623670025, 46.912665136398815, 0.8518148177573759, 1.4285717111441398, 0.5185828117593643, 0.0595890038887099, 0.09326575023512687, 0.23494048915322752, 13.274579355793616, 62.10551100392496, 55.38235279821581, 61.640992549157914, 56.44514645299604, 56.15557747502481, 45.25209442261727, 48.427578633831395, 42.98103424810594, 44.90501565317954, 43.1201450286373, 44.75402793576641, 44.336534776995265, 46.10497067051549, 44.140604542147734, 43.17895312463084, 40.142842492749615, 42.25255597022272, 40.846574537215695, 41.77244609402072, 43.67969859030939, 41.43578121739049, 41.31399946828043, 41.111440427841686, 39.5141806910115, 40.61313467641031, 40.01048995602516, 40.83254814147949, 41.465528472777336, 42.24700189405873, 42.18861349167363, 40.766079656539425, 42.81849515053534, 43.70571174929219, 42.560352202384706, 43.37293394150273, 42.650511803165564, 42.289579222279215, 42.04574115814702, 41.30956326761554, 38.86828399473621, 41.17069959640503, 40.26168638660062, 41.07344835035263, 39.687620055290964, 41.48849787250642, 40.257618888731926, 40.3398709912454, 40.05392628331339, 40.88175035292103, 40.58001418267527, 48.42967317950342, 52.4977005681684, 55.34572570554672, 54.27398120203326, 59.51367155198128, 56.06220153070266, 54.66405699329992, 54.603009223937995, 51.94586623099543, 47.086222171783454, 46.77361711379021, 47.626665945976015, 47.19428739240093, 46.8496875609121, 44.577964505841656, 43.75552585048061, 39.19414274154171, 39.51935037489861, 38.58532813287551, 39.249189284539995, 40.39870654383014, 39.28595366016511, 38.77914421020016, 38.21664494852866, 38.14040976185953, 40.37779246607135, 39.76733830667312, 39.53230596357776, 38.97266610976189, 40.842236395805116, 37.94006293819797, 38.506166858057824, 37.609905273683616, 37.360477832055864, 37.26643900717459, 37.03021818591703, 37.570952215502345, 38.01187369131273, 37.08262497378934, 38.30975809404927, 45.789137501870435, 50.5748252714834, 51.729178813196, 51.23004544165827, 48.06023297771331, 51.00382274196994, 47.791166228632775, 50.802730667975645, 50.61151904444541, 53.77980962876351, 51.90317907641011, 53.75700104621149, 50.416373283632346, 51.870956805444536, 50.6182498316611, 49.33118681753836, 48.23112280138078, 48.80928800952051, 52.24730822347826, 53.46181915652368, 51.761455997343994, 37.97608598586052, 2.86899094139376, 0.2267933279396065, 1.741670497482823, 3.764050319310158, 1.646716289462582, 0.31882697896611306, 25.97106802848078, 63.36886721272623, 43.93339749305479, 29.901457486614106, 24.722632515814997, 49.46689298076015, 17.754312446040494, 0.18877195524832896, 0.08106865754891789, 0.026239880788770896, 0.05228049827799682, 0.008010180383515095, 0.08723570364377192, 0.036558416717114954, 0.013525055349624206, 0.09672109022616379, 0.002793599466507834, 0.0221398854703312, 0.03812549936194574, 0.05140392515327662, 0.06643573468130443, 0.02576721603080871, 0.006427080755407412, 0.04447648699785914, 0.023404434248204195, 0.022405348342633056, 0.08905265735642565, 0.03751827126008369, 0.04544328612786147, 0.03756912417649742, 0.017067232364488226, 0.056814581996971564, 0.013736590420106247, 0.05136068332039061, 0.010216849247714686, 0.021209374010082216, 0.028490373233874, 0.06058923892616745, 0.051957772248574806, 0.00638396245419919, 0.08721185532668907, 0.07946303685105617, 0.07862518947090834, 1.1916372636633537, 47.09196844408589, 46.70978838397611, 30.633930698517833, 46.117600702470355, 43.4785633702432, 59.95783290555401, 47.25638243459886, 1.2105060705254156, 2.2068350401616867, 1.0264662557071256, 0.019594901166255438, 0.026397930473209392, 0.3838702339318491, 16.36186122894287, 62.134614990603545, 57.001503282977694, 63.83302088706725, 59.130055904388435, 57.431959875168346, 48.54808561263546, 51.110570046209524, 45.95498707986648, 47.95267374284806, 46.688391854686124, 47.23720596682641, 45.73802901852516, 48.15093386557795, 47.60750909005442, 44.39089490521339, 42.07839881220172, 45.77981402797084, 42.73928680727559, 44.79153756172427, 44.063588803814305, 42.77561579981158, 43.829038912250155, 44.04243153910483, 41.85848720612065, 42.96249712667158, 42.62730313885597, 44.06197278730331, 43.19079476018106, 44.39505261759604, 43.15954523701822, 43.896448766031575, 44.17501157329929, 45.579102423883256, 45.079294404675885, 45.603738830935576, 43.76328037631127, 44.388631697623964, 43.020285406420314, 43.92334838067332, 42.65451262074132, 42.03935946187666, 42.76984599328811, 42.715874179717034, 40.87616882016582, 42.18615024320541, 44.100761105937345, 42.504532952462476, 41.51566420831988, 44.11249291512274, 43.62696624571278, 49.85046155991093, 53.32770155322168, 54.921478225338845, 54.83642947289252, 56.85553619938513, 56.4269466553965, 55.91886243512554, 59.2162892126268, 53.83566418001729, 47.94586843059909, 48.973372520939, 49.68734979629517, 48.226208071554865, 49.15759840319234, 45.21674210025419, 44.8797163655681, 42.945066113625806, 40.692268494636785, 40.519943083486254, 40.57775097508585, 42.52627465032762, 40.43944428043981, 40.64511768279537, 40.3032164419851, 39.17766486444781, 41.745056183107444, 41.18256476617629, 39.726949661008774, 41.9894669132848, 41.66412591934204, 39.6781357642143, 40.84037719234344, 40.456867448745236, 39.855222932754025, 39.740509294694476, 38.97831040043985, 39.272562688396825, 39.72408633078299, 38.10106054429085, 40.46169980879753, 48.04130361926172, 52.44946718215943, 53.08283190573416, 53.921693525006695, 49.7923477234379, 51.315251088911495, 49.004692646764944, 52.81604797609391, 51.64073328818045, 54.7744874031313, 52.29117993385562, 55.233090923678496, 53.00934630055582, 54.862626983273415, 53.53026843840077, 51.896613028741655, 50.77779223842006, 53.18557839239798, 55.3446235195283, 55.937485848703695, 55.270922183990486, 40.70833452286259, 4.060141953729814, 1.1326833045290363, 3.9964090768368017, 5.473849965680031, 0.4414459089598348, 0.19282512727283663, 26.531923817050075, 67.27729335907968, 49.38515863110943, 40.03233755788496, 24.021885395050052, 52.96978919736801, 24.56412365359645, 0.16721525229513648, 0.040722663829764055, 0.06775224911830119, 0.03759285374995201, 0.09225708056962298, 0.080994799012138, 0.04469867164809858, 0.009833665474528267, 0.09906965533211347, 0.036448352865033576, 0.03317973531422115, 0.10536175761972705, 0.08218474040228514, 0.06328920473254497, 0.015605682161666695, 0.025892358408459736, 0.1537907718410415, 0.13776720020799868, 0.17067121281739206, 0.13235921701115946, 0.1808304273553433, 0.11991224176580868, 0.10317705105990173, 0.10606843542547957, 0.16586434817121876, 0.1096771385580782, 0.1492275384765479, 0.061685989550765485, 0.14210053058641572, 0.12213581196603276, 0.1421278186382786, 0.21177274926054865, 0.31191135005604836, 0.15667045038313637, 0.2291646611786658, 0.25064752857771616, 1.5394349300092267, 53.94919718465498, 61.47402509566277, 43.09756002118511, 40.70619683111868, 49.59267554744598, 65.14979585524529, 57.402506797544426, 1.894751412253226, 3.5081722947858998, 2.2502914695970477, 0.2751822451189641, 0.19842665492286607, 0.3195650280723649, 17.535450073980517, 65.43047674240606, 57.19826506030176, 66.18872580989715, 61.30841870461742, 62.730395563187145, 51.2842212184783, 54.81950836796915, 47.092446973246915, 50.388669583105276, 48.27928950709682, 50.58125795856599, 47.61223554611207, 50.129750005660526, 49.75351625873197, 49.001962677125015, 44.59527392541209, 48.37706635075231, 45.56576244292721, 45.42424332711005, 47.75089917644378, 44.36121433011947, 46.162347101396136, 47.09473371505738, 44.13915326518398, 45.16693976617629, 43.96946368678924, 45.21409842275804, 47.04347618164555, 46.655655753227975, 45.49354376331453, 47.69513876207414, 48.21445272814844, 47.534600073291415, 47.03222682399135, 48.94301729817545, 45.03653664742747, 45.8642783472615, 45.81455446058705, 46.559279195724, 42.36310012878911, 45.74650133809736, 44.5227022324839, 46.205634378617816, 42.353760965408824, 45.759378479373076, 46.315954962084376, 44.178310286614206, 45.8624073766893, 46.3133583530303, 45.812812928230535, 52.57811307907105, 55.07377601438954, 58.37012021772323, 56.353559109472464, 56.654102879185835, 57.09751113768547, 58.539927467223144, 60.092974247470984, 57.40513870793005, 50.57147164498606, 49.836427319434385, 52.88211245690623, 51.10196044368129, 52.78715187503446, 48.512901952189786, 48.325902954224624, 46.047249071059696, 44.0228549895748, 43.50062278009231, 42.31212108365951, 45.09014368057252, 42.609809367887436, 42.5568103021191, 41.73347342398859, 42.71530543604205, 44.72770883191017, 43.65876882306991, 42.31304676302018, 43.0838042689908, 45.13105400146977, 39.89689811583489, 42.365100537576986, 41.82915964434224, 41.00409300096574, 41.97104354058543, 40.77159058663153, 42.06497253910188, 42.77232493123701, 40.403664419727946, 40.90803023307554, 49.36631556480162, 54.78062983482115, 55.86619677082185, 57.34207876266972, 53.0854324371584, 53.20631204112884, 49.27873688359415, 53.21469022381691, 52.49977942435972, 55.74093587936894, 53.81223978534822, 58.19808113959528, 54.671811519130586, 57.94042848771619, 56.26180702640165, 55.624833722268384, 54.30485025528939, 55.39027598596389, 57.43085376677975, 59.13120908121909, 56.69914345587454, 43.41384818477016, 4.590087994452446, 1.9020455498849194, 6.879213625384915, 12.557653438660408, 7.328874141939226, 0.7766517251729966, 34.097858167463734, 71.19938896548364, 53.41418589315107, 40.37188537659184, 34.69746305096534, 61.23858090369933, 30.846597686890636, 0.2644533676005179, 0.23699011142936446, 0.21853546702092697, 0.18323992709479026, 0.1897159134668689, 0.29926054179668427, 0.2088179021713234, 0.14106404426838123, 0.22809863451027104, 0.14834391734292432, 0.16333025189176684, 0.18308767478071875, 0.17592420110539084, 0.13802011647532064, 0.13224726092190514, 0.10134107538408811], [0.019056460099114526, 0.054566929822847735, 0.02784855626223068, 0.05921025001894563, 0.04737899112965792, 0.009168368865615659, 0.040937808131979364, 0.04100510129524816, 0.0514483965572811, 0.09247896261513235, 0.07128888635986275, 0.04605240263645688, 0.049583255914190126, 0.011176264247736864, 0.08625715655545074, 0.06814898307164831, 0.0598897508555843, 0.07685859071751756, 0.13165800141230707, 0.08948852308094503, 0.013283503996658952, 13.989967703819277, 49.66887151041339, 32.077062860611946, 23.553115091016217, 38.11616559182444, 48.54302967748335, 60.47783720877863, 6.89937460807062, 0.8119606563160497, 0.40881185041319945, 0.08913829832548097, 0.16533522656367672, 0.021995054633026163, 0.481098834425211, 35.890491162576986, 63.51337909698487, 59.9253596028974, 57.9003026408534, 54.64628865641933, 51.74119695540398, 43.85588361370949, 45.98201221035373, 45.71435359216506, 46.47783510146603, 43.51165248501686, 47.705497741699226, 46.41359060041366, 42.42024906219975, 42.943501087927054, 43.26135035484068, 39.761121349949995, 43.64656240709367, 41.41252156226866, 40.96923097487419, 42.31430192147532, 42.7458450102037, 38.86442438248665, 40.26686783759825, 40.966657900041156, 43.1958193163718, 42.95023187514275, 43.00512544570431, 41.48696422576904, 42.5604384945285, 40.0759700036818, 41.841719073633996, 42.51884175885109, 45.08960631585891, 41.42494370860439, 43.82931740053239, 41.764114979774725, 41.825943300800944, 39.91729051836076, 40.963241515621064, 42.18826832309846, 42.19332818062075, 39.15655859055058, 39.459416558665616, 42.07621012964557, 42.626585345114435, 42.80746152324062, 43.23665118986561, 39.79480666498984, 44.837664634950706, 51.130319180027136, 56.73102448063513, 54.06533856545725, 68.22056062759893, 109.92318461018225, 54.229780012561434, 57.34329469742314, 54.54742139385593, 50.72369098663331, 51.291885529795, 53.370443620989406, 53.64522526341101, 50.86621422921458, 51.47524064587009, 50.20871123959942, 44.152552081692605, 39.876219380286436, 38.70203825735277, 38.45733727178266, 40.07284387465447, 38.84197273562032, 41.4316156602675, 40.702823592770486, 38.15389487051195, 39.0061160825914, 38.7977127105959, 38.11994283430038, 39.517502938547445, 38.60028413034255, 37.62039761389456, 38.66163392220774, 37.34525903578728, 37.484703217783284, 36.28472858859647, 35.637153117887436, 38.23245602269327, 37.15518882197719, 36.429989645558024, 37.31876342527328, 37.32356832873437, 40.194311834150746, 45.50555798315233, 48.702615230314194, 51.09300175020772, 49.66457651507471, 51.63611273611746, 52.41136135593538, 49.880055842861054, 50.16440414613294, 50.290869205228745, 49.13444857443533, 52.82067245052707, 52.318816954089755, 52.84619531323833, 52.21098707568262, 52.73042263523225, 50.40315489615164, 53.10629944647513, 51.3303953601468, 56.74198358289657, 45.891272098787375, 16.5901098328252, 0.001024187853721331, 0.9147602175512622, 3.3677526683576646, 2.3758617379973015, 0.7690819797496643, 1.6761551484946282, 50.577653300377634, 48.46712396990869, 35.00686745489798, 22.7092485274038, 36.078149118731105, 39.024539455290764, 2.1143043666116657, 0.05049815258732246, 0.11811434065983181, 0.1432210567497438, 0.07021247920009398, 0.03247678069578063, 0.01863097295074934, 0.039659628734713605, 0.026313823595222448, 0.07448027075658883, 0.025857591423236077, 0.04046679812393362, 0.0184297465508984, 0.07075031888821433, 0.11107013155255588, 0.06440767778023597, 0.023952549090608958, 0.03235612184770646, 0.020315487298273274, 0.026847306158273455, 0.06240641863475885, 0.05712233866835314, 0.05323628106364801, 0.027591378630829916, 0.03686834141732224, 0.026061533604778593, 0.07989832800963233, 0.028261040983301018, 0.04344804460302957, 0.011372360731324842, 0.017673711615404295, 0.11103047884159511, 0.07077942256845775, 0.04776264030125834, 0.03269544134156839, 0.05503352333401, 0.07288656272594968, 0.08329998055893569, 21.036859712293072, 58.85255213706725, 30.859212029364805, 25.924556562977454, 51.41265530740061, 51.62878967100575, 67.34693896385932, 7.248745512577796, 1.0808555565534101, 0.824021393012616, 0.08258272307894884, 0.12936289392171368, 0.0980876378654953, 1.0421493625448597, 40.12671370660105, 65.16008815457745, 63.939626985980624, 61.28804199157223, 57.11049810532601, 52.81738550432267, 46.723959907408684, 47.188450905584524, 48.25550817674207, 48.181908822828724, 47.10315112144717, 48.51940131956532, 49.12450928841868, 45.117694408662864, 43.91845326269827, 45.23786014126193, 41.91323172661566, 44.95450027527348, 42.52290925671978, 43.38804683377666, 42.93768813533168, 44.39937506952594, 42.907062269026234, 43.253921385734316, 42.71480337265999, 46.51231665765086, 44.53466938387963, 44.79837033056444, 43.35146680954964, 44.632677647375296, 42.6767603043587, 43.92621171089911, 44.56855473979827, 45.065711236769154, 44.46396473915347, 44.025737931651456, 43.76902272624355, 44.04858966027537, 40.95570272014987, 42.12796580406928, 44.838005881155695, 44.569923646988414, 42.145847889684866, 42.42788199455508, 43.60805649911204, 44.16706877370035, 44.66773971434563, 42.51585291277978, 42.762989690226895, 44.91893614492109, 54.0790903952814, 58.86373481442852, 57.73180154062087, 61.66526417578421, 77.93635783656951, 57.64445035688339, 58.071172852669996, 58.66810660208426, 53.84004546749977, 53.267897175204375, 53.62722942906042, 53.67321529696065, 51.5063960321488, 52.2885754800612, 50.961774933722715, 47.15795447749477, 41.79237957923643, 41.195183031020626, 40.77191614335583, 41.664647594574966, 40.68609076161539, 41.70069809882872, 41.34500580449259, 39.813606585225756, 40.42733592371787, 39.68960869696833, 39.06712070588143, 40.66953051474787, 41.57206004665744, 39.22191704473188, 40.44495128816174, 39.07049002185945, 39.11405186499319, 38.99155232214159, 38.68971024790118, 42.17441843402001, 39.189373139412176, 37.804003761660674, 39.71768894503194, 38.53975803621354, 41.27473654285554, 48.909841891258, 53.057881709068056, 51.901637584932395, 52.256349286725445, 53.08264363196589, 54.69902100101594, 51.85695394392937, 51.84509661889846, 52.3466932389044, 49.257889486128285, 53.21454117375036, 53.6345995626142, 53.5502686039094, 55.08844960120417, 53.66227580655006, 53.169484907580966, 55.036360525315814, 55.3389282380381, 57.79332783914382, 48.1869569132405, 18.090235994708156, 0.13013609114193148, 2.0653245045292765, 6.395194126713661, 2.445514452072882, 1.6055792065397387, 1.9609059850054404, 55.47688976410897, 53.61931016368251, 42.49852780372866, 26.947432256514027, 35.049378102825536, 50.28304799910515, 4.2464275706198915, 0.2355712706283216, 0.03098747895790204, 0.01675373386411417, 0.0342908232743221, 0.03223994844442895, 0.024993256553106254, 0.020056792812782432, 0.03314429608684394, 0.027995436384733167, 0.03240244335404808, 0.009796341670857323, 0.0421786330820572, 0.05927973036323825, 0.07285381246718668, 0.019840769424674012, 0.013774976213162225, 0.1426109902921223, 0.1798986959000749, 0.12346669055160978, 0.16131029254005802, 0.22264281678343975, 0.1554350416746832, 0.1375006782191415, 0.13864447813360922, 0.13378827742511226, 0.30759879598213785, 0.1816804938378834, 0.1815506266129594, 0.1873230531571373, 0.16676252497540367, 0.24901278887785253, 0.12315074823075726, 0.1761786955138368, 0.13140493192740027, 0.25477309591106834, 0.3150652114662432, 0.19928700230535001, 24.596928396532615, 65.98637073270737, 44.31858993345692, 32.42127829982389, 52.39891567537862, 55.52184404865388, 75.30106636785692, 11.551812598782202, 1.6576236654673855, 2.0692402557019265, 0.3000562926453929, 0.16590364848173436, 0.43827559198102645, 1.5520636136493378, 39.798685889090265, 65.6384055076107, 64.82504321682838, 63.05581108216317, 59.563120872743674, 57.70286621585969, 46.90261602401734, 49.73195891226492, 50.960974770207564, 52.4600968053264, 47.183351824360514, 51.9200844918528, 52.18666445824408, 46.786317748408166, 45.50303197676136, 48.21765730457921, 43.96386254218317, 47.91545044991278, 44.14225978236045, 45.97232003365794, 45.35665696667087, 46.585610066690755, 45.369337989437966, 45.32983579943257, 45.61936163133191, 50.02887841193907, 46.80604334800474, 47.7850277193131, 45.93666961116176, 46.89697565570955, 45.64200547433669, 45.362599357481926, 46.30417608445691, 48.40571534249091, 45.082624496952185, 47.047535834773896, 47.15913511091664, 45.89459434632332, 43.53521024027179, 43.78684597630655, 46.90824070284444, 46.99819634037633, 43.68817875462194, 43.76805390081098, 47.03809468976913, 46.46588756192116, 48.05505152671568, 48.04302946213753, 44.67440774363857, 47.55667909499138, 56.25928494238085, 59.529961155306914, 59.224832134862105, 63.31511112951464, 87.20424390608265, 59.11115008015787, 59.78683325552172, 60.75255609327748, 54.290753256890085, 56.85550089805358, 56.01745905414705, 56.63651889370334, 53.85103202635243, 55.3265727719953, 54.411287692285356, 49.04281416246968, 44.50551440638881, 43.18473469826483, 42.47096923089797, 43.88170849892401, 42.88028817023001, 44.255506453975556, 43.87301652662216, 41.261380872418805, 44.29930756168981, 43.397315394493845, 42.40003316633163, 44.01869335482198, 44.0328452664037, 41.635861319880334, 42.318926395908484, 41.568039617230816, 40.91274492202267, 39.89565080212009, 40.15941450672765, 44.63958886361892, 40.42827337018905, 39.61645257088446, 42.261106737198375, 41.15707720479658, 44.22433930058634, 51.44639945799305, 54.368875103612105, 54.118529827364036, 52.43169884527884, 56.476125332616995, 56.11638515226303, 53.86515255897276, 53.59325385862782, 54.63579239383821, 50.13435094587265, 54.99080219576436, 52.2940432640814, 55.66608136700046, 56.54843030437347, 57.38143582497874, 54.64280166933614, 58.347597968193796, 56.825322181947776, 62.58308702899564, 48.78682067317348, 20.8552029825026, 0.16976896042544998, 3.6286275473333176, 7.402111657204167, 7.191172472892269, 3.3900461946764304, 2.08810955286026, 59.523967773683616, 55.357532039765395, 46.18416724666473, 34.92396816130608, 44.17395253335276, 59.23537546588529, 7.102019940653156, 0.3565706294630805, 0.3023933204672029, 0.2572871360086626, 0.20486948500958183, 0.1800248705812039, 0.09785786511436587, 0.17357307726577406, 0.17964738841739394, 0.13703462096952623, 0.09248191205364081, 0.11954833468001698, 0.13766960060644534, 0.23287278720207755, 0.20951289713623064, 0.15817933715879917, 0.09544790572216434], [0.02236339928311927, 0.08791032833077254, 0.049996273066367836, 0.0223482996901317, 0.008590850611067107, 0.019229906235611247, 0.03181051402803391, 0.02454650854962247, 0.027491235617367972, 0.036957272734012336, 0.09507138116825974, 0.12385609304352153, 0.05546857317489001, 0.029203620243577227, 0.008555549279516263, 0.0825773987678751, 0.0468413353026394, 0.09179281596575053, 0.023192999726762215, 0.05782400242864125, 0.08452769008374984, 1.7414814882701444, 35.295279333668375, 46.43686986738636, 32.26495812016149, 32.652125473945375, 40.317093787654755, 60.484301274822606, 34.465258736764234, 0.14645574043595022, 0.1517718850124267, 0.056743477546279474, 0.2726560242233738, 0.01653377278407495, 0.17547971689172331, 7.755829038158541, 65.81134673087828, 58.172189574087824, 61.1872527676244, 52.385567849682225, 54.96081567579701, 49.29588940835769, 49.610079103900546, 48.55727964831937, 49.465622132824315, 46.95450113665673, 49.49174904054212, 46.32296031521213, 44.00384718371976, 41.94321040184268, 44.82214773854902, 41.75431689908428, 43.14125914727488, 45.573791534669944, 44.23094457195651, 45.08725681612569, 44.53384568614345, 40.2620433222863, 41.9873135320602, 41.06572912585351, 44.33543259097684, 40.806582050938765, 43.481230581960375, 41.730900349155554, 42.744629075450284, 42.377255962740996, 41.901923533408876, 40.709475932582734, 42.70597019503194, 42.83053290459418, 42.549408789603945, 42.666589598501886, 44.004968981589045, 40.491329393079205, 41.655006408691406, 42.30436655782884, 43.10849558922553, 42.22076908234627, 39.21270339719711, 38.741391397291615, 42.030451759215325, 40.391544295895486, 43.419547388630534, 40.65475102393858, 47.041244353017504, 56.20015521203318, 58.521190304909986, 55.46915092775899, 65.65058446699574, 68.09164800951558, 58.06292410819762, 56.88334188153667, 57.62013166181503, 55.77730409560665, 53.453005590746486, 56.35432789402624, 54.13048521164925, 55.5805697748738, 53.705064942759854, 52.87422064811953, 48.549270168427505, 42.10851477038476, 37.940388494922274, 38.63484021156065, 39.14959246112455, 40.592428484270656, 38.82349444973854, 37.86529079560311, 38.762603575183505, 40.437702748083304, 37.64325718725882, 39.41584687079153, 39.86144773421749, 39.60515614478819, 38.268679111234604, 40.34462882626442, 37.694197008686686, 37.877740398530044, 37.93005304951822, 38.20397177050191, 36.45207258962816, 37.19247095046505, 37.537867023098855, 37.47918836532101, 36.695035965211936, 37.14725386711859, 40.92477875371134, 46.36134462971842, 44.189167407251176, 48.06071542924451, 50.697775886904815, 50.50571703141736, 50.90306881935366, 52.65929437452748, 49.002943269668094, 49.41370171885337, 47.43668594667989, 47.33146444443734, 55.48627599593132, 53.721931134500814, 49.952690293712, 51.75100680320494, 51.70484835101713, 57.13915886417512, 53.92544723326161, 35.60784909033006, 3.1301070461350107, 0.7483064106875851, 1.2307984526118925, 2.903223672220784, 0.6991989490005278, 1.2007387559260092, 10.981309740774094, 60.39238837457473, 39.90630788187827, 43.89709987948018, 37.27052611689414, 44.68531585508778, 23.21245920273566, 0.3531372991781081, 0.06267338878505173, 0.1591859000825113, 0.021351349254649495, 0.0656907218358209, 0.04905524130369868, 0.0858336631509085, 0.051075032116064144, 0.041685712959377036, 0.03665877040475607, 0.018822132955275236, 0.040149419388223084, 0.04576077594632103, 0.043447803285333424, 0.049974362951733416, 0.02585871948770458, 0.037475014105439186, 0.02605631463079443, 0.04678100587860231, 0.03238487695794433, 0.005395732014515107, 0.0375608504269152, 0.037299434414073344, 0.043370018547941605, 0.07345930537990025, 0.07806704079191532, 0.020705433712611278, 0.031201274945370616, 0.12971921673705503, 0.07705720667276653, 0.10072215295006191, 0.0046329081035970205, 0.08229001620483976, 0.05410406332943709, 0.041850479319691665, 0.028511773900038777, 0.10861265938729049, 0.13282668386255542, 3.566426846288866, 45.41749685041366, 47.601672603238015, 26.55069039713952, 44.91469998513499, 48.449912609592566, 66.82843300604051, 32.08189914303441, 0.31296196303540663, 0.13792214915156364, 0.10825136466132057, 0.7190536803776219, 1.2940148023828384, 0.2406681148755935, 8.473645333320864, 68.14252115065052, 60.152198114702784, 64.24025312546762, 53.92348604817545, 57.35627774269351, 52.15842731537358, 51.60314913718931, 50.56250118440198, 52.064553230039536, 49.33882759463403, 51.95999853072628, 47.47987908701743, 46.7323027887652, 44.99508503944644, 45.69528695075743, 44.363634432515795, 46.13428254281321, 45.80953382676648, 45.19986021903254, 44.89686496796147, 46.828267497401086, 41.86103282436248, 43.50138764227591, 43.046149515336566, 46.08540981046615, 43.15687410293087, 44.726418372123476, 44.79899006505167, 45.4197875145943, 43.04429423424506, 43.85597775059362, 43.96049322620515, 44.989542730392955, 44.047593378251605, 44.845815320168775, 42.89888412721696, 45.49292010645713, 42.60567911209599, 43.718969360474624, 45.61359182480843, 44.07347317664854, 44.38682348497453, 43.36014701474098, 41.23753286177113, 45.31641737107308, 43.069507229712706, 44.6744587344508, 43.44570959767988, 50.24264758633029, 59.37864788116948, 59.33418389289611, 55.1156198593878, 65.55415691867952, 76.62955745573967, 52.2090768814087, 57.76351782583422, 59.60839679164272, 56.39192773449806, 54.506601287472634, 57.613365573267785, 55.75099283649076, 57.54757565836753, 54.74459502004809, 54.57970250037409, 49.44698302976547, 43.383124259210405, 41.40003273564, 40.358957244503884, 42.93379322175057, 41.49362833269181, 41.87295290731615, 39.61162413320234, 38.31978367220971, 42.11131142031762, 40.661466121673584, 40.95048204545052, 40.908704880745184, 41.74504049362675, 40.510654910918205, 41.30524473805582, 40.33487781401604, 39.57309861336985, 40.60363861822313, 39.95381170703519, 41.029541338643725, 40.47380032077913, 40.3136303347926, 39.887417747128396, 39.319435011956, 39.208808483616004, 42.46330099721109, 51.05129911053566, 47.36290224136845, 49.58009650630336, 52.80987024307252, 52.44589390293245, 51.490824222564704, 53.91736322833646, 51.6941402804467, 50.53285198826944, 49.177571112109774, 48.07752278543288, 56.71328752271591, 53.812404524895456, 53.604581663685465, 52.895075890325735, 54.79613888648249, 58.7809375024611, 57.29182143365183, 36.533081300797, 4.058203322272147, 1.4204294835367512, 2.1272543168837026, 5.854351741652335, 4.210423154215659, 1.0307868690259996, 12.277638373836396, 64.50391484845069, 44.33637003744803, 44.025279014341294, 31.988544771748206, 47.97733760649159, 33.24609195032428, 0.6732307134136077, 0.12696971951593317, 0.012357411906123163, 0.06599272901733076, 0.02980103475912925, 0.09829630489431082, 0.04765878942224288, 0.023039021799641273, 0.07275389161922279, 0.011194685789486094, 0.06485290509919006, 0.04687034322189228, 0.029271453498832645, 0.012911782814039579, 0.04362312250680501, 0.011021611205632649, 0.04306606550310408, 0.15508892315049327, 0.13058210753144758, 0.11155826745614891, 0.14908254867599857, 0.08774074710785382, 0.14291010166127838, 0.1054934174903939, 0.16685030332976775, 0.11282446523827892, 0.14391697102016018, 0.23311061153729118, 0.374175054171393, 0.12654294725507498, 0.185596413549877, 0.19079405964622576, 0.17894339958025565, 0.17537162188560734, 0.15586979657171235, 0.12052197880562275, 0.1738910497196259, 0.22102208117083197, 4.262004283166701, 54.393335004006666, 57.45803971444407, 42.00555255336147, 45.48077252603347, 51.60908368326003, 69.03593509427964, 42.0769279233871, 0.736222017195917, 0.49161621038952186, 0.23997725678547738, 0.6364622928442494, 0.4417549181849726, 0.17752959963775453, 9.753492166919093, 67.96875230727657, 63.395029421775575, 67.76844470731675, 56.4967962234251, 60.269367156490205, 53.64488009483584, 55.11131701930877, 54.259641016683275, 56.07187801791776, 52.015755022725756, 55.78869858095723, 51.092417317052046, 49.218932505576845, 48.969638424534956, 48.86831183587351, 45.809302406926314, 48.30345130735829, 49.30199261634581, 48.889053329344726, 49.57875505570443, 49.60919657061177, 44.34747426740585, 46.290804724539484, 46.438685924776145, 48.85038268181586, 46.09270934135684, 48.73137404841762, 45.5746191547763, 47.76987560333745, 44.82936097729591, 47.1639713933391, 46.88479669632451, 46.48763318215647, 45.87565322076121, 49.242929566291075, 44.86773352469168, 48.341592434913885, 44.45589250133884, 44.66111090875442, 47.010218404954486, 46.83633189047537, 46.89082145690919, 44.66069513751615, 44.44541977297875, 48.56393983287197, 45.4404584054024, 46.679276266405665, 44.876911870894894, 52.73557662963868, 59.5231048522457, 63.04822129587974, 55.824419606116514, 72.11104977515437, 84.0820215594384, 51.52587060005435, 61.40739187117546, 60.16026250777706, 58.92955218591998, 57.090164538352724, 60.69996103163689, 57.60039821747811, 58.03317685281077, 57.02232322385235, 57.430375237618726, 51.562211359700854, 46.7594220561366, 43.29762443419426, 41.228181931280325, 45.196549738607104, 43.38548160368397, 41.98577988532282, 40.44911684528474, 40.7038708656065, 44.268022737195416, 42.33638486554546, 43.72133454968853, 44.534838045797045, 42.585082746321156, 41.30749617853473, 43.80086844967258, 43.550993857845185, 41.99092995735907, 43.277812542453894, 43.434876011263945, 42.709876875723566, 43.2806170371271, 41.81079902956563, 42.21500712056314, 40.03657371767106, 41.73469328111218, 44.859955464639974, 52.41136135593538, 49.70205083970101, 52.26494712214316, 54.53509338440434, 53.7006091302441, 55.000953289770315, 56.13365534813174, 52.661867449360514, 53.23867551742062, 52.52652998893492, 47.637134751965924, 55.326851260277536, 56.41973733901978, 55.77225600519488, 55.515513343195764, 55.34511381579984, 59.32757862152592, 57.323369056947776, 40.12923186825168, 5.349300003820851, 2.4053253569910606, 5.167686910398546, 8.131317044458083, 8.476416487847606, 2.4800918611787983, 14.223778228605948, 72.60888484216505, 49.3239696564213, 53.27783253885085, 46.36922074902443, 55.08707677164386, 43.37311044816048, 0.6860239527398541, 0.25514147695033784, 0.24987050091787694, 0.20298406601913516, 0.21393578319299608, 0.12171388138085605, 0.2386735130341784, 0.11055460800566982, 0.15267703321672257, 0.08204543497413397, 0.07099659317323277, 0.16028773370048693, 0.1434674306261924, 0.11367498371269434, 0.11581784655009547, 0.14533803347618351, 0.13046653550719062], [0.031573746894155784, 0.08160767701244162, 0.00982541374997386, 0.024126428066782897, 0.042208939520341736, 0.017855406603625706, 0.05091943199776354, 0.0366050829630225, 0.026470749045632062, 0.023816777243008538, 0.056383366426152576, 0.05822067509495443, 0.026371672809604677, 0.07546208137946744, 0.056821158861801516, 0.104816417930828, 0.03838145316788747, 0.062163967128482565, 0.10176237011628766, 0.0670990212670257, 0.037512583057245905, 0.07854109599946008, 14.20536760360964, 51.30454301834107, 34.71818885495586, 34.77873456093573, 42.33769101481284, 44.34590531933693, 63.45894836610364, 8.324093203390799, 0.2165292666083382, 0.18221045814214215, 0.7010964568584197, 1.4300367164035, 0.1520084529634445, 0.0721339885926535, 37.58326453547324, 67.29159432072794, 58.92719876381659, 60.17541070138255, 54.69384347238849, 54.761665175038004, 50.22473019938315, 53.72666151292863, 51.2972277979697, 52.603498658826275, 48.88386403360675, 46.73531124668737, 40.18056392669678, 42.359981844502116, 43.575987200583185, 43.817507143943544, 48.27317845436835, 53.563687032268895, 55.88267072554558, 56.138236676493, 52.125954012716974, 46.20673264226606, 40.98378689058366, 40.221854717500754, 42.312187763952444, 41.83130125845633, 42.574174634871945, 44.03216277399371, 43.8451559312882, 44.872236405649495, 41.567949402716856, 40.34979458778135, 41.61001682281494, 44.80006087210871, 40.8308615223054, 41.6448631594258, 41.084752621189246, 43.50751830685524, 40.1608814731721, 41.05795106580181, 41.73182602851622, 43.43532708383376, 40.71781881393925, 42.510204699731645, 40.431819192824825, 44.92494521602508, 44.172944484218476, 46.551414843528505, 50.98909816434307, 59.48044907662177, 56.00262465015535, 62.42342302876135, 34.2938119365323, 20.55052895699778, 96.01147897781865, 55.81951664340112, 56.04146395960162, 55.537455081939704, 55.67283176606702, 57.397125305668006, 57.50020519379647, 56.91226151681716, 55.8072357023916, 53.96283134337395, 47.95781597014397, 41.2967606513731, 39.480240421910445, 39.03010137619511, 38.97678852081299, 39.571878756246264, 40.62435265510313, 39.04932883477981, 39.52076242816064, 38.78143879675096, 39.20810637935516, 37.35550818904754, 39.94898719172324, 40.83285800872311, 40.09229490833898, 39.62859622893795, 37.87331988734584, 38.597911096388295, 38.823274797008885, 37.32909102593699, 38.28236426076582, 36.74266922858454, 37.70832538604736, 38.08300587438768, 37.21108259693269, 37.84196446018834, 37.689372493374734, 42.44368130160917, 46.37907766526746, 47.234534832739065, 48.28481612666961, 49.21219779599098, 52.44841990932342, 48.64357179211032, 50.35213662732033, 52.450726262984745, 52.38675632784444, 52.4521775399485, 47.98108739237632, 50.54742751582977, 55.01563079895512, 54.35746885115101, 57.02288412278699, 55.99820021660098, 53.39158911858836, 17.36282067914163, 0.3908286718351226, 0.933009596361268, 1.714911965593215, 6.960079170042469, 0.08726647739569027, 0.06308156043110837, 28.45944712238927, 61.07811281757971, 37.130799524245724, 39.88507609213553, 35.643377919350904, 47.12882695659515, 12.111776048137296, 0.1989027785678064, 0.08329333091575293, 0.09709929251262257, 0.04686434858388478, 0.024362030747016112, 0.018791479862204963, 0.09129958557746104, 0.007683945192594923, 0.12308254342285857, 0.06971260682950098, 0.01654493660035153, 0.040051092003141685, 0.008714781612187864, 0.03732594871713269, 0.030350063161383715, 0.04582375986501575, 0.08370586926297796, 0.03437734907492995, 0.13019497265979169, 0.021880514912247177, 0.039062811767742525, 0.02418447646402544, 0.0546421826396498, 0.06152322651037286, 0.03538543268317177, 0.03233827582951034, 0.026163829325307763, 0.02649484059563087, 0.05295956627495828, 0.056326557176127556, 0.07358841417777924, 0.10556772035816986, 0.07148425410231275, 0.014007885136731691, 0.02108202338398945, 0.10054941544489515, 0.05980455421752507, 0.05117190010364979, 0.06303273764769397, 22.066611320741718, 58.839121941597234, 31.733620128323956, 39.30435742101362, 49.7311116803077, 50.88765782694663, 69.21626998532203, 6.816924425863451, 0.1899685539425381, 0.09433487189873573, 1.6117444370062122, 4.756118491772683, 1.0381452354692644, 0.4337315567799153, 41.644341484192886, 67.22514937000891, 60.70975911232733, 62.918304551032286, 57.93865949876847, 57.15904135857859, 52.91591936542142, 54.13597260752032, 53.945545458024554, 54.15033240472117, 52.28581413145989, 49.12648224061536, 43.341566747234715, 44.33781739204161, 45.71143142638668, 46.59141517454579, 47.49743561590872, 53.665001853819824, 56.83363760671308, 56.45067699493901, 52.72169143922868, 48.471830814115464, 43.49760647742979, 42.5354451517905, 43.48822416797761, 43.08122727178758, 45.526903521630075, 45.091540044353856, 44.687430012610655, 47.13793862250544, 44.30328092267437, 43.04017182319395, 42.700412196497766, 45.61059121162661, 43.420673108869984, 43.43101247664421, 41.84411564180928, 44.88663542655207, 41.62966789737825, 42.38843079536192, 45.180111085214925, 45.062428212934925, 44.95219392161216, 44.96338444371378, 42.7356154687943, 45.07681938909715, 46.79720232563634, 47.148658460186375, 52.09952508249591, 60.172896462102095, 57.728298864056995, 63.250709733655384, 39.5745930364055, 24.774870641769905, 77.55087514077464, 58.10076321324995, 58.28970378445041, 56.13216092509609, 56.93319128405664, 60.184161509236986, 59.426128172105365, 59.13689259559878, 56.08801464880667, 54.298217527328006, 48.23202886889058, 43.53025236437398, 40.70935041673722, 40.77426564308905, 41.258756806773526, 42.152017777965916, 41.040504363275346, 40.36759038125315, 41.177461762582105, 40.98936842333886, 41.58807116170084, 40.12121846598964, 41.12315262517622, 41.37165830981347, 41.51507977516421, 40.04514409649757, 38.852319948134884, 39.13641721971574, 40.1567865187122, 39.95998159531624, 40.20667514493389, 38.03344672726047, 39.53905244027415, 39.720815074059274, 39.623991366355654, 40.17674746051912, 40.415078516929384, 44.01708126068116, 49.66142292945616, 48.3694451855075, 48.97485909923431, 50.5728405521762, 52.8684155402645, 50.66638908078594, 51.51595092588856, 54.19928750684185, 53.05801506965391, 54.182841008709325, 50.30771970748902, 53.342975262672674, 55.9325554293971, 55.29189901967203, 57.61824107939198, 57.12426954700101, 55.297005945636386, 19.520243906205703, 0.42198381296569304, 3.026970283639047, 3.2424611333877813, 7.340984950142523, 2.699367307847546, 0.35608162021925377, 29.490557832102624, 68.54206162114298, 42.06467051659861, 59.6007481698067, 41.80558227723645, 52.26928918592392, 18.518131279176284, 0.28105237851700476, 0.04976004219403671, 0.09802039066750197, 0.18089589722935231, 0.09450010940312378, 0.008637706463735913, 0.05920448903775504, 0.0075610900662028266, 0.10930255986750127, 0.08145969946898761, 0.027941266307607297, 0.015972936094077607, 0.04194907866598618, 0.0726389937523392, 0.059208300325178334, 0.03145712341422276, 0.03503541477144726, 0.19069765514183432, 0.22778250066743744, 0.10001880762678, 0.14944979590514015, 0.10679535327419158, 0.1251015911299375, 0.17483811825513842, 0.1515821403553409, 0.08895732537512818, 0.15247360622930914, 0.1342823734927562, 0.1064956826608508, 0.17431026835355068, 0.23959539259874055, 0.23080917616044325, 0.21739390408319814, 0.11267395960467477, 0.1742272091008002, 0.23231121411006297, 0.15325455625932063, 0.22832597876268051, 0.237793936844795, 25.263574431019446, 66.12604633454355, 44.51723052609352, 45.66889332186791, 55.17106256177349, 55.79696693728047, 75.29264111672678, 10.465493548300959, 0.34049764515892156, 0.3472965222693259, 2.2113004134547327, 7.501882535796012, 0.9629098241848331, 0.7426631618891993, 41.85049733807964, 71.38854918941375, 62.60359318025651, 66.81935664146178, 59.23190416828279, 61.259647953894834, 53.09288886285598, 58.09362842190651, 56.47968684473346, 58.836588090465916, 55.31060480302381, 52.02213279662594, 45.32538783165717, 48.33533625448904, 48.8650131225586, 50.43466329574586, 51.467595946404245, 58.827990255048206, 61.47680605611494, 60.36646150773572, 57.101680617178644, 50.14065811710973, 46.753962116856734, 45.16395092010499, 45.61387815783101, 43.92155977987474, 48.03265871540193, 48.51493766230922, 48.1465761123165, 50.32273454050864, 46.4731204125189, 45.292196735259026, 45.49725824786771, 47.70044965128745, 43.4457919674535, 45.70989777964931, 45.18160550825058, 47.5006127357483, 43.12046666299143, 45.105233038625414, 47.576977360633116, 47.03214445421773, 46.69358899516445, 49.210087560838275, 46.197879852787146, 48.06171955600862, 49.25190394924533, 50.1004812794347, 54.2696548277332, 62.4391281989313, 60.10722814067718, 65.05211314847394, 44.70801853364514, 31.875872727363344, 84.33469280119866, 61.04356458110195, 59.565544897510165, 57.786263650463475, 57.979801239505896, 61.933283652028734, 60.50069678214289, 60.955052375793464, 57.98832062752017, 58.31083359256868, 50.495867959914676, 47.86631491876418, 42.33689085129769, 44.607558788791785, 42.946941006568174, 43.78938767217821, 44.59423057494625, 43.40966693816647, 42.528690830353774, 44.39211868470715, 42.75324260034869, 42.45523660413681, 43.15133179387739, 45.842140490008944, 44.2384559108365, 44.668069193440104, 41.238148673888176, 43.51690061630742, 42.804190266516905, 40.66675347666587, 42.35991908657936, 40.0484271203318, 42.23031220897552, 43.20597041037775, 40.82048293082945, 42.47865315406553, 41.72849593623992, 46.50052601291288, 51.18218468081567, 52.138431072235115, 51.41082748290032, 52.17751749100224, 56.0393851034103, 52.05735568077334, 55.05935345926593, 56.823843448392815, 54.167755573026604, 57.246871071477095, 52.801672489412375, 51.58012482427782, 55.612548858888694, 56.978271084447066, 58.70978570753529, 57.45691007183444, 56.18963541523103, 20.756414167342648, 0.934295827342618, 2.907507390745225, 5.865332416949734, 15.999972570327023, 5.743433487030768, 1.0423190050548123, 37.06029884276852, 72.44895412075904, 47.46952402976252, 49.645984480457926, 43.22141278174616, 63.49750918726768, 24.318549940663, 0.26388094670349554, 0.257629546667299, 0.18751540251316565, 0.22305443582515563, 0.11850928962831536, 0.10115079446545533, 0.10471809820662584, 0.2196599615197028, 0.2409810464709036, 0.25613771300883065, 0.1642312478995131, 0.11337141371181897, 0.12279269405670705, 0.28363507541437305, 0.19397871779097667, 0.07259052336936997, 0.22162937439016758], [0.02705294713978806, 0.05294466586483102, 0.023110511209515315, 0.08826799946086061, 0.021457632462824547, 0.026389154936036757, 0.08834052500465224, 0.024225870109794122, 0.04967967190990045, 0.027645615740649165, 0.028157504200334513, 0.065050479174862, 0.08231213316321373, 0.030502388253808025, 0.020923448929322824, 0.05283082902972257, 0.05755882109365156, 0.06343876807800224, 0.07420418032955739, 0.039181942270407756, 0.08612512896258025, 0.09916015329860872, 1.5926824534131636, 39.71315076274257, 45.0351442060163, 25.795557652750325, 40.10077115028135, 38.23540564506285, 58.998236810007405, 37.5126697171119, 0.23892546403071574, 0.1390995650041488, 2.171198836257381, 3.427799252733108, 1.2581704677112642, 0.3734242880055982, 10.741502892586494, 61.4164682357542, 60.69833324801538, 57.88981814538279, 54.39077369628414, 57.189035723286295, 57.41745887264129, 55.41867002364128, 53.653375948629076, 53.97487694217313, 50.15289198967719, 44.2590287423903, 40.26819359871649, 42.657646594509, 45.640864064616544, 54.39670039761452, 53.77605984287878, 57.98775188384518, 56.30626316993468, 55.4417335602545, 54.31869622199766, 51.20616997441938, 43.77693806925128, 45.26055497507895, 41.48371650326637, 42.452318360728604, 42.476417403067316, 41.874816033148, 41.88075057921871, 44.85686463694419, 43.5136019029925, 40.5726715057127, 41.08157550134967, 41.72540903091431, 40.87888702269524, 42.17315543082453, 39.73529646473546, 40.367421719335745, 41.68566365395823, 42.22699388380974, 43.07109971200266, 45.37277006333875, 44.84031223481701, 43.10742085979831, 41.02022963185465, 41.00463036567935, 43.281287762426565, 44.49839138215588, 52.89109076223066, 53.01223708737282, 57.245800264420055, 55.858304962035156, 45.96252587533767, 37.948590170952585, 41.69054700482277, 52.04875000061528, 55.72679573489774, 55.6776798156, 58.65257401620188, 57.453858467840384, 57.37116313749745, 56.628179934717, 54.17616121230587, 52.90266175423899, 42.5785166986527, 40.57531910557901, 39.036734104156494, 39.926013869623986, 39.710310966737815, 39.97194874671198, 39.85944732542961, 38.38581285169048, 37.88006244167205, 38.338367862086145, 40.33643499497445, 37.65862111122378, 37.9948623718754, 40.21193504333496, 40.08123382445305, 40.958601351707216, 40.40002446020804, 38.67622906161893, 40.76036084082819, 37.22383029999272, 39.03233712719333, 39.0273125710026, 36.616051197052, 38.16236326771398, 36.09814928423974, 37.967201817420225, 36.99696433159613, 36.495469693214666, 42.007325464679354, 44.29616966555196, 45.507985930288996, 49.85186184606245, 52.813243481420706, 51.06823982730989, 51.85425927562099, 50.698509370127034, 47.60013503413047, 51.30032254803566, 51.094774661525605, 47.4052167707874, 52.488435929821385, 53.2238724923903, 53.249713067085516, 53.45785364027947, 36.488605545413115, 4.0291400301841005, 0.2662864014987023, 1.994685559503494, 1.2088676229599984, 5.508010377807002, 4.039013126204091, 1.0938688776185437, 46.10265254974366, 45.35657851926742, 32.05732745508994, 14.23533941468885, 22.94131163627871, 47.198609844330825, 5.494620386631259, 0.220241621437092, 0.08973898786690929, 0.046351253535718694, 0.03033859865559686, 0.051585587582761244, 0.018141571086861433, 0.013514434498163962, 0.15308744183951808, 0.09979366204671322, 0.05869414424523712, 0.01211110027431841, 0.06915441984611173, 0.05037493117514157, 0.07963001337503234, 0.031835304633263624, 0.04406422827272646, 0.04643255844712258, 0.010578459027343461, 0.006375233361106967, 0.050209065478655605, 0.00477318502699716, 0.026495156606899637, 0.014099678749428883, 0.05123045986458179, 0.02878798115547867, 0.014244116009062818, 0.03443127017348044, 0.05096872209481174, 0.057070566446430264, 0.0457171012737578, 0.03660716289173692, 0.05138288454843625, 0.046348606701940305, 0.044363538824742844, 0.023394978807998762, 0.05820960129400896, 0.026954378437010512, 0.06009818422758292, 0.16304045615177, 3.648114862941927, 50.901923487263346, 44.48183113528837, 27.019156717485, 52.629119580791844, 44.07355946879233, 64.38943655260148, 36.500835495610396, 0.11397036423365917, 0.0916893634524557, 2.725805308549635, 6.450857462421541, 4.419245239227049, 0.40866917419818144, 13.00371910295179, 64.75389142190257, 64.1317407546505, 59.69619512557984, 56.489245660843395, 59.411282001003144, 58.13081249114006, 59.12146591371106, 55.4749011224316, 55.007036885907574, 51.480324037613414, 46.05256388264318, 42.41090989881947, 44.73384734122984, 45.83938698614798, 54.330345661409446, 56.84344745451405, 60.13317854173722, 58.837121532809356, 58.919636434124364, 55.50448756064139, 54.16774380591608, 48.48208781211607, 45.37682971646709, 43.7625821944206, 44.59523862408054, 45.427408679839104, 44.03469270275485, 44.13861982284054, 46.80680821018834, 43.54784811696699, 42.345276878726104, 43.64919431747929, 43.25644346975511, 43.99735173871441, 44.26660283919304, 41.18644399027671, 44.226998667563166, 42.924312853044086, 43.01021668218797, 46.07344658144059, 46.71502867052632, 45.01437133358371, 44.897641597255586, 44.23853828061012, 43.727904519727154, 44.27285117487754, 47.69447588151502, 53.904733196381606, 56.09137219767417, 59.18675376522926, 58.986312804683564, 44.93449618739467, 37.38694206360848, 55.055368331170854, 54.62985000302715, 57.20842007667788, 56.626983611814445, 59.35186986000308, 58.04497141991892, 60.360664244621034, 58.0977233763664, 56.85318277728174, 54.63192493684831, 46.16122530352685, 44.40732179149505, 42.932734181804044, 41.04609766314107, 42.58013663753387, 41.58216407222133, 42.54279959586359, 40.39678066007553, 38.60704629651962, 39.716818178853686, 42.39099210308444, 39.809201763522246, 39.76800903197258, 42.80340971485261, 41.63043275956185, 41.48248095666209, 41.875325941270404, 40.61709627028435, 41.98872166295206, 40.43476489282424, 42.049094784644346, 40.89314876064178, 38.47539978642618, 39.28519664272186, 37.75913576925955, 40.26404373107418, 39.886664652055316, 38.71275417266354, 46.03264608690816, 46.871892098457586, 48.28157232653711, 49.95605176494968, 54.69122332911338, 52.6979414878353, 53.767085459924516, 51.734481857668975, 50.73584248942714, 52.64229874457083, 53.949714937517726, 49.625643068744296, 55.57132082600748, 54.404423544483805, 54.25161192494055, 53.616333084721724, 38.80313342617404, 4.734700879743023, 1.1708998151363865, 4.597481662227262, 5.80953081769328, 6.7548808647740275, 3.204990976279782, 1.6994784195576946, 50.33399566527336, 53.80569334953062, 39.93381154152655, 23.35021676555757, 25.25511976211302, 55.132544886681345, 8.132498658472493, 0.21581639115127826, 0.05037054149133544, 0.02083160839374027, 0.089893929149595, 0.045798999903303, 0.011620454475163453, 0.035906675076412584, 0.07963337650101993, 0.11443532597754272, 0.03251079883005831, 0.036000340816474734, 0.03679788814136579, 0.05665625843610014, 0.023045874456123962, 0.06561577545418855, 0.03795746946707368, 0.03627930024278261, 0.09026257065875877, 0.1485787999005087, 0.15359070031873642, 0.22315024278096615, 0.1360173174931157, 0.10427360633207906, 0.19035411067306998, 0.1174803109719388, 0.07236282671651534, 0.07296928490001349, 0.10543655078377455, 0.2427737075354784, 0.19974886139314021, 0.142011878891818, 0.14977093996299853, 0.11981785207265809, 0.12914241381710576, 0.1926792028450197, 0.26132659505932565, 0.1835391763597727, 0.2810600700397646, 0.3366816079904956, 4.107839691062128, 57.091211811188735, 55.32763181194183, 34.7591305548145, 49.31181815362746, 52.04705945907101, 66.93215616287725, 47.00186375648745, 0.40548485313211724, 0.15944425557409564, 5.701001776802925, 10.990992111544456, 4.033455617966191, 0.44785886161750366, 13.482051164873186, 65.2393945570915, 66.77901114186933, 64.56601773538898, 58.53784861103181, 63.37542149328417, 61.509455865429295, 62.3776803478118, 58.783337993006555, 57.87735677534535, 53.35734682698404, 48.30020358485561, 44.41065580614152, 47.062366316395426, 49.883848774817686, 59.776329148200254, 57.708992958068855, 62.573528212885705, 59.91573410649454, 59.89760098918792, 58.35894930747248, 56.43494829054802, 49.91897752208095, 49.173911540739, 46.491229995604485, 47.28074819810929, 48.49630640399072, 46.632619673205966, 46.14652818249118, 49.64836928152269, 46.05787084948632, 44.60667625550301, 46.58949321316135, 45.460599776237245, 46.5236170061173, 47.27793585869574, 42.93769598007203, 46.406271457672126, 45.184410002923784, 45.05885101133778, 47.6357501552951, 49.771500325972035, 48.48857933475126, 49.123214906261815, 47.20594467655305, 46.59392941382624, 47.19015713660948, 49.55183190684165, 57.23406061049431, 55.208097580940496, 60.15238246610088, 59.56003004504789, 48.612949848175056, 42.83252939101189, 60.50765898919875, 54.577894287724654, 57.927084584389966, 57.81014696244271, 60.7901127876774, 58.853968112699455, 62.98712253570557, 60.99724138936689, 58.055769705003314, 57.34001167358891, 49.782745761256066, 44.60236949305381, 43.28121323739329, 45.27634251502253, 44.65625893685126, 43.74174656406526, 44.65112847666587, 42.42804281173214, 40.280490229206706, 41.41787951992404, 43.99521012460032, 41.10081080467471, 41.89590661756454, 44.557266158442346, 43.89702535444691, 46.22961182748118, 45.181479992405066, 43.712924988039084, 44.94689479950936, 41.2399019733552, 44.041388188639, 43.47204046864664, 40.40587271413496, 42.10948359581732, 38.71859065947994, 42.02930250475484, 40.88211121097688, 40.6111107334014, 47.363412149490856, 50.436628403202185, 51.24162820077712, 51.438746913786865, 56.89330862414453, 56.68406194256198, 56.09197624268071, 55.586233677402625, 52.48116385552191, 56.38661292291457, 56.28913417939217, 54.542875366826216, 56.85920753786641, 55.15722443980556, 54.77067485932381, 53.65518808364869, 38.789648317521625, 5.592874778855232, 1.0328675638283453, 6.078650518771141, 6.815610922151997, 15.9134990169156, 7.872477875601861, 1.6854604814321765, 55.248211660692775, 57.486355304718025, 43.68036539323869, 25.29644193187837, 33.99499400969475, 65.13369452568793, 11.295717127861517, 0.35063914774406346, 0.29703300326101245, 0.23487647484627464, 0.17421734188833546, 0.1902913833938299, 0.26959271440582894, 0.0991857942614344, 0.3165168561522038, 0.26624846482469194, 0.13244359393513974, 0.1950043103387279, 0.1317308104086307, 0.14904159361556654, 0.19201089838339438, 0.14912854459497238, 0.12808743413657914, 0.0842134791216062], [0.051759554659046476, 0.11263106634179432, 0.043974285719976317, 0.020727374470762668, 0.03199412423606602, 0.07951156086018009, 0.07108154466315623, 0.043366574982721964, 0.04770076721005383, 0.038132290731394486, 0.03206495481032518, 0.08598000126620454, 0.040631484045016195, 0.05576282754660614, 0.03885335949880462, 0.03810993245532436, 0.06576279538773722, 0.039661739306945, 0.04529193013666138, 0.022800766539970235, 0.020169800357712854, 0.01255112968670625, 0.11843660320605963, 17.510015464598133, 47.66740760495586, 33.13107236739128, 43.89530343394126, 37.66015475796115, 39.49818526544879, 63.94148226707213, 6.151215347551531, 0.44151755350251354, 0.6734527563375812, 5.6701170340661085, 4.503866453324595, 0.052323881837148825, 0.41313335239406557, 43.16363234673777, 64.8240194782134, 59.590561774469194, 61.88380295230497, 56.62797597146804, 58.628067047365256, 58.07014911405502, 56.30737712306362, 55.363615635902654, 49.39731405627344, 43.07576341013755, 41.658375724669426, 44.13459154867357, 54.53181428294028, 56.20874520271055, 57.10612858495405, 56.1497566776891, 57.2645531162139, 56.59166659078291, 57.35328105188186, 53.83878246430428, 52.52565137801632, 51.375938000217566, 47.293119353632775, 42.00207341101862, 43.86877252209572, 39.795285194150864, 43.18472293115432, 42.71164978704145, 43.17615255232781, 41.583874225616455, 40.46015831731981, 41.50774886531215, 42.80428440340104, 41.9941423785302, 42.109624801143525, 41.560414529615834, 43.060666207344305, 41.59657878260459, 43.44527029222058, 45.39480201659664, 51.599579780332505, 50.64531418585008, 47.30282721980926, 45.21365519492857, 43.92380337561331, 44.359963094034505, 50.17606143028506, 54.737989748677904, 57.11422435698971, 56.28678075728878, 57.50926979126469, 46.99008487885999, 25.638090179812526, 51.00036713384813, 52.447443239150516, 57.30870723724366, 57.28489452792753, 57.24160332833567, 56.63982937412878, 55.04349531665925, 52.9317775080281, 45.04566400281845, 39.963743148311494, 42.14189414055117, 40.31512868019843, 41.755987828777684, 39.29236673539685, 40.52348498375186, 39.43270521779215, 38.001593159091094, 38.24324646303731, 39.19961444793209, 40.72212557638846, 38.44065150906963, 38.18810578315489, 39.87006518148607, 39.65155778392669, 39.3965252753227, 38.743956627384314, 40.04085302352905, 40.978158289386386, 38.4276919980203, 39.39820404975645, 37.81711232277655, 37.28426225723759, 38.78922470154301, 37.60647712215301, 36.27541295943722, 37.09372135900682, 38.00801407906317, 37.98258535323605, 37.613011790860085, 40.65357039051671, 43.87438935618247, 42.7419775532138, 47.58151162055231, 48.67806903777584, 52.39649949535247, 52.61073150942403, 49.90881858333465, 51.71812949642059, 53.21832626096664, 49.1721268623106, 50.642811713680146, 50.772618632162775, 51.72608014075987, 19.04455061881773, 0.15560620103872594, 0.4037670082142277, 5.0870434699519995, 3.199389831673715, 3.8526272437264844, 1.9083044269392568, 4.998872020552236, 53.10697801651494, 30.813887080838605, 31.24000357043359, 28.94799597801701, 42.95983775969475, 28.43032548504491, 0.24568491825653663, 0.03778978431176755, 0.03211697984126306, 0.047749609145666325, 0.05284571411809134, 0.03869016744917439, 0.06012741048189421, 0.03442681920264037, 0.07677478835948053, 0.028382469749739094, 0.08937552511211365, 0.059016552348170555, 0.01152173638524067, 0.04906030514487817, 0.0914648767080038, 0.022121861336692687, 0.04577983621387713, 0.09792483652070647, 0.04089921262235411, 0.08411653069478851, 0.04215390759430105, 0.02715604916785754, 0.03241838181331273, 0.024556822008303097, 0.020841586688954025, 0.0643439852302113, 0.048177090037854454, 0.02363238371007385, 0.04609624967880307, 0.0380124899017955, 0.035164477604050795, 0.021209259096893574, 0.05228674189457971, 0.02707138113046606, 0.07785104996254368, 0.08012603998424546, 0.031183202931236838, 0.034668795734403596, 0.058854505599987124, 0.03652576604978212, 0.03412354031517621, 24.084327567008234, 58.86213056502804, 29.288436135938092, 45.63096007993145, 44.98733835835611, 49.158296585083015, 69.06044990785661, 4.9011682310412015, 0.17282264817866588, 1.9560016739752986, 5.743358961997494, 6.893454770888052, 1.1094198496110979, 0.8973603383187325, 46.49037491890692, 66.50990516908708, 62.54524792394331, 62.636297902753284, 59.30215774043914, 60.05969685892905, 60.438550749132716, 58.54011181862124, 55.352130936038115, 53.55388502920828, 44.67125023564985, 43.669943655690844, 46.96885308911724, 58.41403899654266, 58.082673242015225, 59.783157994670255, 58.24341981641708, 58.36516234182543, 59.565509596178615, 56.84082731123894, 55.647226533582135, 54.26437139511109, 53.60367559617566, 48.931716949709006, 43.468059262921734, 45.49469694014519, 42.94406590923187, 45.56246372961229, 44.77037637464462, 45.1880068163718, 42.76922233643071, 43.263566493988044, 42.6873860051555, 43.40726644762101, 43.47732782363892, 44.65644721061953, 42.179631263979026, 44.2279714153659, 44.226680955579205, 43.992538990512976, 47.02765334037043, 52.72435080620551, 51.9485765887845, 47.809424861784905, 48.002856546832675, 45.37612368983608, 45.79912777869932, 51.40984689035724, 54.9300995949776, 58.714967158532914, 57.75998769267913, 60.97707648431102, 46.763426796082534, 26.981048930075865, 52.45508793861636, 53.14946120785129, 58.309515676190784, 58.309248955019065, 57.56231200310492, 58.528211347518436, 55.737554796280406, 54.059611905005674, 48.21014596569923, 43.2780949531063, 42.985913676600305, 42.83984068901309, 42.93115738899478, 41.6771246540931, 42.59053484086068, 42.185946279956454, 40.63654338159869, 40.926053524017334, 42.64697382527013, 42.0938019598684, 40.76278486559468, 40.326166229863325, 40.94113503732989, 42.464207064720895, 42.63290820583221, 40.44277437271611, 41.93147859265728, 43.02596499842983, 40.63549610876268, 41.966858371611565, 39.97650261848204, 38.86057261497744, 40.86483317036783, 39.94059331955449, 39.35556004124303, 40.16893802150604, 38.9467078639615, 39.72943252132785, 39.9178082712235, 42.9341148561047, 46.504369935681744, 46.760465406602435, 50.77674104321388, 52.42860017284271, 53.40692950833229, 54.224076886330884, 53.41519001991519, 54.51694065524686, 53.71287438177294, 50.23484599205756, 53.964619944172526, 52.42048478895619, 50.9785234543585, 20.704680065954886, 0.5067791128831526, 2.4582839733169926, 5.1400552834233935, 6.063340037099778, 4.3514362842805925, 1.1666572814987552, 5.601890836992572, 58.98922320335143, 33.35435328945037, 38.19978267915788, 24.90172205432769, 42.51254635472452, 39.48453149487896, 0.47568403304584567, 0.03298809075908315, 0.05326993530616165, 0.022439466068340887, 0.0368534256854365, 0.004442002344500995, 0.058531534422429345, 0.07849474768004111, 0.0735977681113347, 0.041787154491870634, 0.05424925614328635, 0.03599046594313076, 0.07549589650044519, 0.06420518542009016, 0.018622817944795377, 0.02606532190956416, 0.029397044037919373, 0.0793100031273019, 0.12301502809409173, 0.38169411521765495, 0.14668988754912732, 0.13423790974963096, 0.11902217017186266, 0.127957942294738, 0.13842088771202873, 0.15325717628002167, 0.15357836630315552, 0.1506101892840478, 0.13318193415480276, 0.17523286804076166, 0.12728085080462118, 0.14650098558875824, 0.24333665958575665, 0.20559664034555036, 0.17109455300434945, 0.23617292544053448, 0.13707805815483295, 0.18938937615002358, 0.08181173985283222, 0.12918666305561222, 0.359641722733936, 28.87328463215982, 63.06870783528974, 43.09538702810965, 53.89952821116294, 48.62881583552207, 51.74429955021028, 75.77706167774816, 8.171981236627026, 1.3085827303509558, 2.748329274116024, 18.07863166255336, 14.289606386615386, 0.7764142379164697, 1.1469911303251021, 47.738429961665986, 68.09757863321613, 62.573084985056234, 67.41868695905133, 60.59734006081859, 63.406545500601496, 63.014359474182136, 61.86189259252241, 60.78206800645398, 56.25323272520497, 47.35837974855977, 47.386714950684585, 48.732119298750355, 61.45834345971385, 60.58913838478827, 62.440136248065585, 60.677807484903646, 62.54136869984289, 61.092237272570216, 62.28067621108025, 58.01839736200149, 57.60858028165756, 55.563982071415076, 53.18528029226488, 47.010830294701364, 48.47570219347554, 44.07070398330689, 47.95592146535074, 46.274291546114036, 47.01929084716305, 45.118282764188706, 44.63237170250186, 45.87420194379745, 47.405989477711344, 46.80161106971003, 46.862976551055915, 45.068076425983065, 49.289303748838364, 46.434571358465384, 47.920580910098174, 50.35634533051522, 56.515917778015144, 55.7662743906821, 51.210300230210834, 50.10820834867416, 47.42953546585576, 48.92883008526218, 54.05242220047982, 58.17929298646989, 60.66066280488045, 60.02794135001398, 62.393095262589, 48.70451757984777, 31.554091284351966, 53.257789227270315, 54.35018500974102, 59.6557633338436, 60.81489432242609, 62.115042363443685, 61.48822799805672, 58.028764186366914, 55.89205303499776, 48.698528120594645, 45.60177764584942, 46.04923771273705, 44.64637064164685, 44.455484574840916, 43.49521383162468, 45.101200842088275, 43.73769475567726, 42.43926079042497, 43.38060217518961, 45.03419107006442, 46.38014454995432, 42.694277609548266, 43.025404099495184, 44.09313994069254, 44.29869174957276, 44.372016537574034, 42.47847664740778, 44.0823063542766, 45.4347905805034, 43.14799777923092, 44.56499322768181, 41.15274690812634, 41.49540516637987, 44.778209347878736, 42.065635419661, 42.03392305681783, 42.709484638706336, 43.052123285109, 42.05056959582914, 41.40520241952712, 44.84053580991684, 47.90121224618728, 47.283278126870435, 52.55633607987435, 53.9526371032961, 56.41625035193659, 57.546936312029445, 55.75688031411941, 57.20955364165768, 57.346205096091, 54.75942550166961, 55.90178835776545, 54.511967089868364, 53.25972687813544, 22.5397668346282, 0.653622662348132, 2.6012462762094315, 9.690746991865097, 10.458514671171866, 13.335333927985161, 4.939881534345688, 6.617457684009306, 65.60633228671166, 38.35361803731611, 42.78439406425723, 37.85491220412716, 51.98035170955043, 44.10256147384644, 0.5522241839958776, 0.13564121428756945, 0.10061018153904908, 0.178271203391975, 0.16391868402640666, 0.0874287424789321, 0.1416522159331268, 0.16867114110819756, 0.14543050028864415, 0.19395991799331483, 0.1627703795149442, 0.1829629709884044, 0.19025499421742656, 0.18619782321395414, 0.18019538643139024, 0.11384294849009284, 0.20946953655971637, 0.18776792041476698], [0.024873718108621337, 0.04325166945495913, 0.045422226370823, 0.048117143657779506, 0.04871139423020425, 0.06077356734162858, 0.08380198265395819, 0.019774782441316113, 0.02483048776705419, 0.05936814074013984, 0.026507802803309697, 0.06033734155578479, 0.08196760044102708, 0.026023796113628535, 0.03153959852493098, 0.06438326255808915, 0.05865368714195587, 0.05107145831589738, 0.025733259183564977, 0.032780170665993806, 0.04044536298381225, 0.0514549466090337, 0.031897083878697406, 1.3015767643528602, 30.696506231061875, 47.80258424820439, 33.8439945251711, 49.495035986746515, 30.965243501047937, 53.15312862396241, 20.181702606139645, 1.4913535358444339, 0.919769880992751, 2.5411315406522443, 3.499630107995003, 0.7645013868328064, 0.17537742883207338, 11.794091520770905, 61.26824971168273, 57.85102982674876, 62.73229006798037, 58.21218206036476, 61.92895727772867, 57.62911388950964, 60.445913037946156, 52.95543724490751, 44.530507749126805, 42.54547465232111, 48.6991439327117, 53.31034898757935, 57.64026126553936, 58.231146720147905, 57.37003741725799, 55.38574564841486, 58.81723903840589, 56.536078760700846, 54.594187813420454, 52.91148316475653, 54.38440768949447, 51.62541643265755, 50.90345321163055, 44.73200382724885, 42.22988467062674, 42.63316708226358, 44.2468144816737, 42.27190502228276, 41.95584827853788, 43.15883528801703, 42.525462719701956, 42.485423164982954, 41.337682739380874, 41.948921372813565, 41.76574276339623, 42.76183651339623, 43.62795860536637, 42.4569232233109, 44.293051381264966, 54.44438857416953, 55.80368203501548, 55.1473989025239, 54.884568722017356, 54.579035697444795, 50.29479942014141, 47.05435683650356, 45.42925611619027, 50.06137917118688, 57.050226965258204, 54.879759896186094, 57.60195932080669, 57.2528919096916, 49.46855214334304, 50.2379564316042, 57.269585517144975, 55.69573840787334, 56.899023517485595, 56.433536237285985, 53.55971759365451, 50.90242162827523, 47.40849194988128, 41.91095282954555, 42.11904633429743, 43.05377068058137, 42.169668443741344, 42.84774034254013, 40.020946994904556, 40.62165406442458, 39.004617737185576, 39.737379243296964, 40.7677270520118, 38.71937905588458, 39.983743313820135, 39.68172473292197, 39.41405826999296, 39.61802151895339, 38.7673221865008, 39.29954075044201, 39.36356559876473, 41.58423900604248, 40.184400004725305, 39.246565218894716, 38.04360958837694, 39.27046814272481, 37.455356044154016, 39.060782155682965, 37.14678318269792, 38.753939059472856, 37.191003984020604, 37.44169050647367, 35.51501051072152, 37.47432070393717, 37.46037275560441, 38.50234254713982, 36.666928260557114, 39.840247323436124, 41.45064700034357, 43.16584848588513, 43.2351646115703, 46.79526075240105, 45.24859959079374, 49.3492885558836, 52.10258845360049, 55.75630372570407, 53.03421804981848, 50.98139855169481, 5.903484821319581, 0.19310300268473166, 2.6670445261463045, 3.086817562580109, 5.05855921776064, 3.296441281995466, 1.3650673123136645, 16.751748746441258, 59.43520061431393, 31.737201252291282, 35.70420211361301, 22.337396067957727, 44.162122664913056, 9.729558844720165, 0.06868503777490509, 0.08920514715775367, 0.05802140796496984, 0.028153828893517776, 0.008455843893781064, 0.027069894919892954, 0.04029528635944571, 0.05653543487912225, 0.03258951436427813, 0.06161731359879337, 0.03929905030095289, 0.01525829001630266, 0.0075725718089679804, 0.03419309726826126, 0.05408499540100175, 0.10573697216328114, 0.045749185036026666, 0.04505942628208188, 0.02864584311722748, 0.04380919377229387, 0.06518636785087085, 0.028599490967368888, 0.03395782400583548, 0.012310419115237893, 0.04083310689536795, 0.008946630461592107, 0.05103486995663374, 0.03033527574922529, 0.04083655046058759, 0.03506831441735549, 0.08674247325548241, 0.06874063277557012, 0.012285538494677074, 0.0341141787207415, 0.02358458556925818, 0.04031955985532653, 0.07183078631398178, 0.08760185536718176, 0.053219384994478, 0.08465226364111708, 0.0235434792064611, 3.02645547255393, 41.67089200788929, 48.58455973286783, 37.66488121401879, 54.03638362884522, 35.37498974031018, 63.433056800596184, 20.46418974476476, 1.1468279842407474, 1.9455045533757058, 4.116430907480178, 5.3780107728896605, 3.425520355662992, 0.14573650644911876, 15.3155650631074, 64.94546782585883, 59.20591062115085, 64.55541164644303, 59.837514200518214, 63.490088062901656, 60.08677690259872, 59.95480875815115, 55.53963591975551, 47.6140869048334, 43.30106435283538, 49.574193339194025, 55.794464465110536, 59.035817038628366, 60.951043713477354, 58.321694635575824, 56.30230549843081, 61.54845206968246, 59.42039366691344, 58.48673620531636, 57.06273932610789, 56.48836312755462, 52.464454558587846, 52.91759813985517, 45.17366270865164, 45.67062308711391, 44.33199659470589, 47.08282539921422, 44.41761016845704, 43.24408800371232, 45.3915072256519, 44.570476701182706, 44.27054482121622, 43.56729130591116, 45.00271012706142, 43.938771140190866, 43.661173235985544, 44.35946495302262, 42.838652210850874, 45.759594209732555, 54.9310056624874, 57.04672428869433, 56.07016786452263, 56.124002395137666, 55.12313904300813, 50.75137115293934, 48.85938452136133, 48.29149984544324, 52.854106733875895, 58.87384668473275, 58.003833601551676, 59.955357889975275, 57.79087243541595, 47.576479219621234, 47.551109329346694, 58.14359549553164, 57.687831770989206, 58.17187970684421, 58.50510074246315, 55.99786289276616, 54.79925324839931, 51.152304064842966, 43.10513804035802, 43.4209829761136, 44.53840740265385, 43.708022025323686, 44.46629854940599, 42.40865061360021, 42.432059318788596, 41.259882527012984, 41.445830329771965, 42.876393256648896, 39.85454828508439, 40.8588162545235, 40.92951697687949, 40.552463454584924, 41.140187478834584, 41.424845649350075, 40.91638488154258, 40.00974078332224, 43.39099645614625, 43.46721987570486, 40.71914065268732, 40.33940422919489, 41.12097570973058, 39.76261577298565, 40.6704758059594, 40.13340134774485, 41.51221252256825, 38.8511000910113, 40.106897892490515, 38.172545740681315, 39.20768668574672, 38.849695882489605, 40.34612717167024, 39.21324076191072, 43.60799766355946, 43.86392055019256, 46.43480670067572, 44.813420464915616, 47.90647214458835, 48.23775552934217, 51.62641271468132, 53.298758383720156, 58.71319424721503, 54.410824852605025, 53.66345643997193, 6.82104830780337, 0.30533454651313446, 6.261280976956891, 6.194500663588125, 8.705206378813713, 1.3864358947161706, 0.7972033514130501, 17.538201616656398, 64.03476407451015, 33.52316033455634, 38.224819167967766, 21.33283195957061, 52.041179826182706, 13.872383871386129, 0.12095460397822243, 0.09269054077806012, 0.08710751415140207, 0.006892831569852969, 0.04849835283934109, 0.03844797258235274, 0.029876300982469996, 0.02021434262485033, 0.06483376056196229, 0.020420533274450613, 0.04288248785380875, 0.07179565352177428, 0.04671547471755936, 0.0393541396835879, 0.09123545635731951, 0.04927906538209608, 0.018819118399293195, 0.06409211084246635, 0.06802991768645664, 0.10446004148933197, 0.2001996734930623, 0.15209027115375767, 0.19039063774529966, 0.20688092546357265, 0.1274452379514133, 0.14471382503547978, 0.17323376160235177, 0.12417053383204246, 0.13244771548817236, 0.10836995507199919, 0.19168362562214175, 0.17491316422820094, 0.1534940659879677, 0.25484984259932275, 0.14345567883743396, 0.11152664334663462, 0.13348354297059198, 0.20566885179329306, 0.13773435035780554, 0.16955180514243343, 0.13997950891573585, 3.0560031773582583, 48.798399509922156, 61.31793829702563, 43.67688232852567, 60.8500740605016, 41.81782007217407, 65.70681164341589, 26.011229176675123, 2.945896363066089, 5.616829674090109, 5.799572900418313, 11.216386210533882, 2.1150552553515283, 0.38945188926112273, 16.052373474644078, 65.65773102544969, 60.598293196770456, 65.71424061252226, 60.252426439715975, 65.72248935699463, 61.57498298152801, 65.02348769095637, 57.643422695898245, 48.56259838227303, 45.76074346419304, 53.22493937707717, 59.417322451068515, 60.91060407700078, 63.842571858436834, 62.67623155347763, 57.909579046310924, 64.1535295209577, 61.71974589747768, 60.198874319753344, 59.112067914778194, 58.793779342405266, 54.42148193236321, 56.107277408722915, 48.210518590865604, 47.72685112491731, 47.238206171220355, 49.59386794797836, 45.94298462713919, 45.000745019605084, 46.56301721449822, 46.90415359312489, 46.62999168519051, 45.506919045602125, 46.47629753235848, 46.067217857606956, 47.05400382318805, 47.781787841550766, 45.51261040472215, 48.93238767500847, 59.09640589068013, 60.008360878113784, 57.99468271193966, 58.720187833232266, 60.2017141157581, 56.412280913322206, 52.661279093834665, 50.73090422538019, 54.71253748862974, 61.11741104433614, 59.30782556533814, 61.07429635140204, 60.67586591166835, 51.15401029586793, 48.78014087677003, 60.72700577397501, 60.88600689365018, 60.27573708565005, 61.013350563664595, 58.01069774935323, 55.547704235199966, 53.322327906085604, 45.654659040512584, 46.550716661637836, 47.16410867629513, 47.74121484448833, 47.54908930870795, 44.18504499620007, 45.288486173076016, 43.278436199311294, 43.77395706792032, 45.784626776172274, 41.65349629617507, 42.700718141371205, 43.13933718589045, 41.839526468707675, 42.82393940033452, 43.30978378172844, 44.20885378314603, 43.41158497718073, 46.403545410402366, 47.109003297744266, 43.34550088451755, 41.55193044293312, 43.42344230221164, 42.531259982816636, 42.36611250908145, 41.65730883998256, 43.73291730880738, 42.02584689663303, 42.37187054849441, 39.4271001508159, 40.900628720560384, 40.9813864000382, 44.29280034957394, 40.13131856918335, 45.08705285287673, 45.117498290154245, 47.82800512929117, 47.064700126647956, 50.9199938466472, 50.1100165613236, 54.60218944857198, 55.52621356902584, 62.53602250929802, 56.44790780159735, 52.927204024407175, 7.322797900246036, 0.5915461901214816, 7.0469537858040106, 8.519708668032, 17.78162390955033, 11.099336801036712, 2.5439755041753096, 22.12710015235409, 72.55569750262846, 39.98725775749453, 50.8938394823382, 33.009839750105336, 59.42415521990869, 18.547982477372695, 0.31867425167752855, 0.2571634894176837, 0.156172018257841, 0.11826925129900057, 0.16140727927127194, 0.1210031892743803, 0.07301652954230387, 0.16896424634802729, 0.12593509479155465, 0.1544467576088444, 0.1662039702698108, 0.128149050588329, 0.117563960112391, 0.09267452187956342, 0.1735037309868682, 0.2058464003306243, 0.10749054742195915, 0.15727637996596677], [0.03566454532706449, 0.05029963622350366, 0.07225838594979818, 0.02495531030299683, 0.08246253154450849, 0.03758128199185576, 0.03010638016876915, 0.041111621990679734, 0.06476898782796438, 0.016799685733032324, 0.03319501493787093, 0.04594771672160395, 0.057279926784817255, 0.033163969224739465, 0.019304693653999318, 0.09765623077269524, 0.11844338308418952, 0.02990567662392653, 0.03196171871686895, 0.04075166408813769, 0.03405498693727198, 0.018374295191719167, 0.07109959369465228, 0.06842641415254724, 5.507909867071337, 46.344913821066584, 28.252128285746423, 37.02738623465262, 40.25562240231422, 40.263733863830566, 45.75716234022572, 0.29497863123974494, 3.3738110142369426, 0.5697623880640154, 3.159408867359162, 3.415642356680286, 0.03239144233145541, 0.32061965535244635, 29.41015708831049, 64.02421289874663, 61.64994732026131, 60.011408559737674, 61.440677104457734, 59.90462203179637, 55.42088616278864, 50.52885117069368, 41.88741860851165, 45.56566046130273, 51.83654192955264, 56.575553494115034, 57.95322718158845, 56.67828036892799, 55.52577034119637, 57.22550199877832, 57.63111037592734, 57.12790558415075, 53.92105417866861, 55.56751612694033, 55.20463412807834, 58.22210957927089, 51.33143086587229, 42.59628895790347, 42.02056346401092, 40.790751364923295, 42.81678499714021, 43.85534624899588, 42.92814108633226, 42.5617838674976, 43.10013309601815, 42.76417032364876, 42.02895733617967, 41.76820601186445, 43.12218466112691, 42.053001465335974, 40.894211722958474, 41.79106558522871, 47.63593842906337, 57.97281942059917, 55.28019074470767, 56.13422409180672, 56.16460284879131, 56.75906158262684, 54.94186670549455, 52.20092227382045, 46.926679765024495, 46.40702063037504, 48.88994762974401, 55.02365989069785, 54.802332308984575, 58.754524261720725, 51.78858310945573, 55.556227545584406, 58.970011434247425, 56.409696071378654, 53.79676211264826, 52.092170638422814, 49.42795953442974, 42.92530913506785, 43.32206864510813, 40.952898225476666, 42.46680759614514, 42.063340833110196, 42.4457876143917, 43.119211504536295, 40.517609273233724, 39.458883116322184, 38.827499189684474, 37.366055442440896, 39.79923502091439, 39.59481285464379, 40.25116658979847, 39.1040184420924, 39.809884255932225, 40.14791019501225, 40.03442033644646, 38.11295709302349, 37.939141181207475, 39.50343339673935, 40.67929721647694, 39.770570339695105, 38.729749802620184, 39.58421853280837, 36.548084366706114, 37.73976318297848, 37.70794883851082, 37.01803922653198, 37.59589064505793, 37.79775542597617, 36.75233394868913, 37.72810197645618, 35.95287646016767, 36.62511187215006, 37.66785829297958, 36.741480750422326, 37.33051876867972, 40.65760650942403, 41.98865106028896, 39.644709325605824, 43.17752145951794, 46.24187707901002, 52.58463598066761, 51.92515219411543, 58.161418745594645, 37.664355616415705, 0.4200138638336813, 0.3875030535123041, 4.696156238355945, 4.534202064237287, 5.288698894362296, 1.3253319864311528, 0.2594620289821779, 34.80052332724295, 45.36901243271367, 30.36130047613575, 39.43450166333107, 31.817245060397735, 41.055691780582556, 2.3745156295837897, 0.13153066227753318, 0.049063227770309296, 0.03078783452961474, 0.017071083871527545, 0.16439143688448016, 0.059831057029265555, 0.062014518696213924, 0.06278323047163506, 0.1656815902360024, 0.012533806523518458, 0.06563234593599074, 0.0267514034414724, 0.022274349222800905, 0.05199755902492231, 0.02643603185612348, 0.01301617953070109, 0.07700951003860082, 0.04255520743167689, 0.032002338613834114, 0.01711578701712912, 0.018267077356276494, 0.027201640975451278, 0.04674219203391864, 0.06710071432133836, 0.011674114146209773, 0.03726119130489327, 0.047034833790554155, 0.03385077470973615, 0.13043633632121548, 0.0265358665191959, 0.05882256356398425, 0.03063643257313919, 0.03697803371676034, 0.09005261660223046, 0.05334828311817781, 0.03217741651760955, 0.046528939968876304, 0.05078575348541622, 0.05167061951191676, 0.025094320787297144, 0.050377463095731316, 0.018200759039891344, 11.530149348320501, 57.08685405792729, 26.802985091363233, 46.37915219030073, 46.03568984616188, 46.18099012682515, 47.196315257780014, 0.18525426336113485, 0.7890876610913585, 2.127472253576402, 3.966041841814595, 6.373896146974256, 1.0259054180595184, 0.9699130322664016, 35.96148998506608, 66.32466731532928, 64.02133780141031, 60.14056828714187, 63.82008098786878, 62.062160968780525, 59.25390082020914, 51.69174763464159, 44.21428234346452, 46.56404095311319, 55.46018438954508, 59.9124393155498, 61.23026940130419, 61.50101884718865, 57.11550697203606, 58.90902250043808, 60.087949691280244, 58.991478566200506, 57.053933605071045, 58.46382956351004, 58.49158425484934, 57.80553817749024, 52.769442373706454, 45.999454990510024, 43.6709124811234, 43.14107871824696, 45.37067159529656, 43.803135579632176, 43.172787158719956, 45.49742298741495, 45.8657649255568, 44.75331798676522, 44.827415481690444, 44.57813709012924, 45.09563892118393, 44.53269250931279, 44.33167103798159, 45.559973024552875, 50.558182654842255, 58.70460817890783, 58.948795333985366, 58.96758348711076, 57.88582909491755, 58.60980056947278, 56.79295086091565, 54.8139895931367, 48.09086276638893, 47.5499600748862, 51.27483498665595, 57.05025049947924, 57.14851763940627, 59.160473885074744, 53.74896410972842, 55.20429288187335, 60.904363586056625, 57.09402415060229, 56.792895947733236, 55.46914308301864, 51.06855361692367, 46.505989874562914, 45.82829452330067, 43.21335623341222, 43.10306310653687, 43.37091784323416, 44.07858402498307, 42.78587672018236, 43.15798805605981, 40.00868958811606, 40.11739415507163, 40.81281861951275, 42.4202137608682, 43.137536817981356, 41.804013329167525, 40.06010793870495, 42.498688620905725, 41.05791968684043, 41.910199734472464, 38.81594388715683, 38.73179335747996, 43.18511909054172, 43.37521283857284, 42.23580352721676, 41.07280508164437, 41.49227119261219, 39.084653700551684, 41.620222830003314, 41.09729243863014, 39.41038693151167, 39.64735300310197, 38.569183657246256, 38.902004611107614, 39.288460054705226, 38.530230599064986, 38.43726650361092, 38.96224044984387, 37.10149941905853, 39.227596636741396, 42.48209699507683, 43.170182704925544, 42.21921974612821, 43.68131068445022, 49.07456182664441, 54.60115394284649, 54.215235863962484, 58.57691541794808, 40.03532640395626, 0.3361331196802278, 0.8878532484654458, 9.050804453511393, 15.596508749069708, 5.036946958111179, 1.7249201382360153, 0.018524408205262115, 38.89427754186815, 53.486522243868926, 35.16516647031231, 44.21490600032192, 31.226651822367025, 50.94328488073042, 4.288796522924978, 0.25235348381102085, 0.12331923394794427, 0.02881526537690192, 0.04689158300959295, 0.03988681210865898, 0.03570049017247173, 0.07668380775759298, 0.10103666268649603, 0.08782032832142808, 0.014735342119820418, 0.014392962104700988, 0.057541128293040304, 0.019818319218052972, 0.02516098767368784, 0.06136807072306834, 0.03341261455188355, 0.07645889200390348, 0.04190317467756329, 0.10966512629942549, 0.14078708816199534, 0.13632392120217124, 0.17070919545667787, 0.157487467832623, 0.1161387301380596, 0.09825993870054522, 0.11837284170812178, 0.17954749055206778, 0.15100129249115146, 0.23809658754016125, 0.13624766481018838, 0.22049343453780298, 0.20292276366343423, 0.11450890872266986, 0.19564085279501256, 0.16940290829347027, 0.14752167517379408, 0.13529325715236126, 0.14672169551974343, 0.13668047384388987, 0.22119221397705618, 0.17257045203399274, 0.20453415300336578, 12.127391984385829, 64.00280067997595, 39.29253931968443, 49.890497192259765, 53.08015684927664, 51.18888408906999, 57.556495128139375, 0.42095416015194315, 7.383049918759254, 5.566282579975744, 14.500583814036462, 11.986079773595257, 0.6444234172663381, 1.538972580625165, 33.406630639107, 68.21197063692155, 64.21576969085201, 61.85051379665252, 67.02725010533487, 66.47250144712388, 61.34513993417064, 56.10323736744543, 46.202539628551854, 52.12560492177164, 56.38478509841427, 62.29857006380635, 63.75967648721511, 63.90210167054207, 57.18371306696246, 61.51338608034196, 60.30312699656333, 61.635587523060465, 58.393234745148696, 62.325842303614465, 59.159575662305286, 59.83985193314091, 55.94760556374827, 48.401263452345326, 45.06778224822014, 44.40825531559606, 47.400356954143895, 46.196687452254764, 46.35481388338151, 47.289604909958385, 46.18177460085961, 48.07529880154518, 46.27690776701897, 47.81288831464706, 47.63279268818517, 48.13602493655298, 44.94028168339884, 47.312033022603686, 52.36785834835422, 61.87072969252064, 58.580684815683675, 58.89947152906849, 59.92439469983501, 61.13066473314839, 58.76644826704457, 56.20890209751745, 50.519260975622366, 50.03536601220408, 52.350250828650694, 58.71104086599043, 57.55263943825999, 62.36148095900013, 54.88556500404112, 58.716642010596495, 63.651489673122285, 60.187122898717085, 58.61000061035157, 56.35040552385392, 52.67779619463029, 47.27877132354244, 47.82449853035712, 44.216478870761016, 45.6189380153533, 44.732909894758656, 45.49897624600319, 46.77360142430952, 45.072018408006244, 42.50953789680235, 41.96534433672505, 42.37220394995905, 43.82055090319726, 44.80337135253414, 44.43482545114333, 42.07790459356001, 43.79498489441411, 43.262711417290475, 44.910691322818884, 41.44838771512432, 40.29183372374504, 45.51775263201806, 45.142530856593964, 45.41376275400962, 43.58527537315123, 43.65024551268547, 40.755453955742624, 42.602964831936745, 42.019998642706106, 42.07965789302703, 43.18173016271284, 41.305699732995805, 40.90486488034649, 40.50319456285046, 40.58357569479173, 40.425166853012584, 42.46077499082012, 39.98519851315407, 41.14436088069793, 44.2091558056493, 46.72079063230946, 44.56396164432649, 47.34450632526029, 51.71466996592861, 58.99187472558791, 57.369009756272845, 61.77513368668095, 41.2557718830724, 0.810596468227525, 1.7524419388463421, 11.575432131367346, 14.568378060094773, 15.89625333586047, 6.707008827117182, 0.41870290353413553, 45.077796059270064, 58.75089214694116, 40.24534187009258, 51.95466802966211, 38.92085552215576, 62.588001758821555, 6.03645807312381, 0.4261725365875229, 0.19170219559342633, 0.1334575266246834, 0.08570162023627952, 0.26680878153251064, 0.19773470898789747, 0.1917844121494601, 0.19617352905052324, 0.27326475768800707, 0.10526047313525792, 0.13602664844403345, 0.18366605584179202, 0.09196847992678804, 0.17753019718633545, 0.1601362627960982, 0.13667023890922148, 0.14582189460915906, 0.08468017988507787], [0.049696468387640295, 0.07187360296806983, 0.019736349725374774, 0.045039144104286555, 0.07057060232205738, 0.03272902280572922, 0.024993584055693883, 0.03761621560120294, 0.07830780690475818, 0.04389423336232862, 0.04244996993351848, 0.047338070543182474, 0.060244319329579035, 0.006278861415452294, 0.022674118799547997, 0.06688773421750915, 0.05270170874052471, 0.16518663614988327, 0.16669339320111662, 0.052163765630534584, 0.03600938831486049, 0.04685400256646737, 0.02401791362752838, 0.14690629206597805, 0.13733978443328412, 19.226191659127515, 46.96135351734777, 24.14475364069785, 50.09107151339131, 29.751868094167403, 56.660559100489465, 13.492026732813928, 1.2235540800517606, 2.8296887922671536, 2.1298889238988203, 5.994387220951819, 0.8723680374603119, 0.4097049250718086, 5.6018476909206765, 49.76773092823644, 60.6893470979506, 63.81027898480816, 59.48766623773883, 59.909328876003144, 52.08343944241924, 46.17911915625296, 45.44823646545411, 51.616410670741914, 57.29576341567501, 60.80603368820683, 55.907977857897365, 59.3478572753168, 58.2794899325217, 58.42462547363774, 57.85321066456457, 58.64131289143717, 58.63856723231655, 56.629999914476954, 57.49765565318447, 55.623139258353945, 51.53466063161051, 43.10237276938654, 42.57609267388621, 43.84661113062213, 41.92391234059488, 41.13800664101878, 42.359326808683335, 43.16660942569856, 42.644094805563654, 42.864379036811094, 43.28475513765889, 41.69760727113293, 42.96273246888192, 42.110209234299205, 42.35274114916402, 44.22748111909436, 49.8251465828188, 57.043825657136985, 56.81975241630309, 58.01254910807456, 56.34858946646414, 57.33527737279093, 56.835061427085634, 53.23463939851331, 52.51903433953562, 49.44705363242857, 46.77830434614613, 50.47933124726819, 54.80587028688001, 56.38285529228949, 57.37202998130553, 56.65089830275505, 58.177339646124075, 53.15711375205748, 54.14603348701231, 48.119021461855986, 43.70457426194222, 42.851168494070734, 41.53834727502639, 43.51186429300616, 47.856485459112356, 50.40391975833524, 49.4613310598558, 47.54909323107812, 42.03282871553975, 40.25188438354, 39.018079311616965, 41.54434065664969, 41.72624057339084, 41.22272199200046, 39.81429692237608, 40.652989879731216, 43.713121106547696, 39.25997972488403, 39.87266963528049, 37.8880758439341, 39.439773328842655, 39.892050066301906, 40.2725003611657, 40.66037178039551, 39.25211929505871, 38.055490447628884, 38.31016994291736, 36.58947321676439, 38.992732955563454, 39.77322578430176, 37.968217711294855, 39.63118107088151, 38.575216262571274, 37.66720325716081, 40.01008202952724, 40.95022709138932, 42.65566971994216, 45.4672364265688, 47.92822560956402, 50.53964945577806, 51.223918699449115, 49.84531933261503, 51.07337028749528, 48.727016295156176, 56.73204429687993, 50.69943897185787, 58.179834273553666, 16.754204150169127, 0.024461846257890427, 0.1902576295598861, 7.682096813955615, 10.978271865075635, 4.0583403600800425, 0.9403337033525591, 0.5844305816196627, 44.0961915446866, 33.97274632607737, 35.838774711855, 51.23856090730237, 39.159621961655155, 24.979753686535744, 0.1380282523290765, 0.08922239179692923, 0.025847285625434695, 0.06842933294753875, 0.053109983808451125, 0.02428838671485503, 0.026407709585562832, 0.08357175791095342, 0.03542472533280811, 0.03611263781485539, 0.02914227575304047, 0.03847334924484453, 0.018285710529814807, 0.009950151058634924, 0.030158253897341992, 0.026589435217301213, 0.03546785225250548, 0.06584927139263, 0.029942395218137293, 0.08653621174274914, 0.05889615013955101, 0.022556394068223816, 0.03305813417800012, 0.05956347017819363, 0.023184036498048136, 0.04905148364243008, 0.09534133523101769, 0.05512866762376601, 0.07998302669054078, 0.06499165894403573, 0.04032165893623906, 0.09762834517225143, 0.03726997450294514, 0.023385965783569603, 0.006905220648003443, 0.0047232284334548305, 0.0669618379024248, 0.12138614130596961, 0.051470517346094695, 0.04226464943419542, 0.02334847535577513, 0.03152043675072491, 0.06499093882138691, 0.23250311913509525, 27.708530925935317, 49.29553247267201, 27.37588647873171, 56.47108508694557, 34.35456945050147, 64.11756138647756, 11.376628760368595, 0.9016047718544161, 0.19408943281779367, 3.469254783084316, 4.928369377889942, 3.717419956960986, 1.7041972760231265, 6.936881782547121, 51.61390035383163, 61.64666429642708, 65.41027261364844, 61.10915053275324, 62.62340507199688, 55.04787268177156, 50.20845236316804, 46.85063677449381, 54.393280090824256, 59.91622832513625, 63.24301796574747, 58.63774745695053, 61.00533716140255, 58.76535784813666, 59.511526015497026, 60.963646288841005, 58.7055613148597, 60.0282786738488, 60.286245115341686, 59.421688049070305, 58.31012364356749, 51.019339638371626, 45.30366182327271, 46.01161041567403, 46.44106680347074, 43.709269339038485, 44.73238821952574, 44.86090467822167, 44.58822150384226, 46.27602915610037, 44.88303469073388, 45.2117096993231, 44.92824000696982, 43.463976075572354, 43.85197693301786, 43.22075382355721, 44.2051039972613, 52.15543062456193, 58.676170995158536, 58.352948081108835, 59.427893238682906, 60.93601319097704, 58.56080232128021, 57.95528250355875, 55.69285154342652, 54.421454475772, 50.29594082986155, 47.8322648232983, 52.400111998281176, 56.82487503174813, 58.84941031855922, 59.54777656062957, 59.090545869642696, 61.22094592740459, 56.96050666993665, 54.158145766104425, 49.898345854974565, 46.06364457837997, 46.71282037611931, 44.27457309538319, 45.434927863459436, 47.69140466567009, 50.668165914474, 50.82397422482891, 49.27076270503383, 44.48077209534184, 43.25227791263212, 39.984366970677534, 42.25148516316568, 42.9990065482355, 42.26696283586564, 41.93547941023304, 43.50653379194198, 43.83195323328818, 41.06405035141976, 40.914498221489694, 40.659414722073464, 40.944947581137384, 42.07105613523915, 42.79931868276289, 41.84818706204815, 40.82275790552939, 40.926979203378, 40.19510807529573, 39.15834326897898, 41.152040881495324, 41.61175835517145, 39.77240993130592, 40.66603176055416, 40.52391252210064, 38.55811472861998, 41.153731423039595, 42.09788906958796, 44.32819581800892, 46.79775145746047, 47.72870248363864, 52.00434092552432, 51.62252956821073, 51.347218405815866, 52.90402281668879, 49.76722886485439, 57.84021192981351, 52.14446759993031, 56.584610246842914, 19.626536215505293, 0.2462260214792144, 1.6954164375220577, 6.998062422198634, 16.53073887671194, 3.7337703570242855, 0.3762952484671147, 0.6265980221571461, 49.02556750082201, 38.56018574007096, 44.08575804002824, 51.16566365764987, 43.8480741746964, 37.26226952768142, 0.6498413136409176, 0.04276964693300186, 0.020627424894501607, 0.06624254262855937, 0.04853833496810929, 0.04373842256984884, 0.04399432658007549, 0.08298574661415431, 0.028935158137051813, 0.02014014700938377, 0.048950409832140135, 0.07525345265504814, 0.029603324702850757, 0.048757849801932616, 0.02615111801142414, 0.026394339436064326, 0.06930364611288233, 0.0570432975467655, 0.02219233759528687, 0.1439180128997372, 0.212880757547194, 0.12420644803393273, 0.17090174399556654, 0.13037374693780177, 0.09030564012186182, 0.1323035070973058, 0.28460809900876016, 0.17446966060707647, 0.21380038481325875, 0.24353515296693773, 0.138530254424099, 0.2543728149706318, 0.11198455708161478, 0.11931920544274392, 0.1657546290587033, 0.1389692534482287, 0.23406822144264178, 0.18476309374936167, 0.1636716359925847, 0.09588223927083517, 0.08010098124824225, 0.1436076706816112, 0.18181025381049803, 0.35565092558822325, 30.249565878222068, 62.049750589555316, 35.91203674193352, 64.43578720092773, 40.65693578412456, 71.90221494243991, 16.45185609017649, 2.5294669020560483, 8.482622658052753, 6.436415295447073, 13.870792369688711, 3.6138093231185793, 1.3281032635319618, 7.318444069354766, 51.971075304092906, 62.75486330832205, 67.93418838131812, 63.9033882079586, 64.87370806355631, 57.73297040693222, 52.46452908362112, 49.39095197185394, 57.069995710926676, 62.1895948533089, 67.89197583352366, 59.43616159500615, 63.36640396425801, 61.46237565625099, 61.54421198752619, 61.90992201528242, 63.71747962890133, 61.83368290624311, 62.576489602365804, 62.676647324715894, 60.16796604279549, 55.6716158313136, 49.01349052306145, 48.60326943858978, 49.26336903725901, 45.122868014920144, 46.685379474393784, 46.496556574298495, 47.53362732548868, 46.14492001072053, 46.6213507037009, 47.65034921707646, 47.843133711045795, 47.337634332718395, 46.95835290416595, 45.62793201015842, 45.95952918452602, 55.46626406331217, 61.680600643157966, 60.31089328950452, 61.966886597294966, 61.65848632012645, 61.43677042376611, 60.52558422088624, 57.15472675138905, 58.43165043861636, 53.436837580896196, 51.26941427107781, 53.389059189827215, 60.56612191661712, 59.581002958359264, 60.254034611486624, 60.43899005459201, 63.50680912694624, 56.17915484213061, 57.01101503064556, 52.62820959091187, 46.27541334398332, 48.652177472268384, 46.77837494880923, 48.045324048688336, 53.28953689144504, 55.3933197452176, 55.08311125539965, 51.539320407375214, 47.125269366848855, 43.87285178707492, 41.87696156963226, 45.883341066298954, 45.23306308254119, 44.18033030725295, 42.61763057401104, 46.165488919904156, 48.044488583841634, 43.13974903475854, 43.319177858291134, 42.599152288129254, 44.620271190520256, 45.37438607984974, 44.234541385404526, 44.31169440669399, 43.25806733100645, 43.34209626720798, 42.4863096206419, 40.522527925429806, 42.273356299246515, 44.58066309652021, 40.46736371132636, 44.743249262532885, 41.66345519404258, 42.516625619703724, 44.140800660656346, 45.44307854867751, 46.89534787208804, 50.8844885518474, 51.97056147360033, 55.3841963121968, 55.93537169118082, 55.943957759488015, 55.47248102003529, 52.461924629826704, 62.05079394002115, 54.890864126143924, 60.03853959421958, 20.51180535747159, 0.26043097698880785, 3.0775985217863515, 21.71434913912127, 24.226103598071685, 10.654673384081933, 2.523749802381762, 1.3326212211001305, 55.46043149886593, 44.28049587434338, 48.863440252119496, 56.02852406040315, 52.35182762145997, 49.15269544047695, 0.9335598926390372, 0.16379755020381945, 0.11717225169582714, 0.15116600139487177, 0.1448042846975788, 0.1881236303597689, 0.11841047194696243, 0.21547782625402176, 0.09668469338888123, 0.14614458616462447, 0.16724834729346538, 0.18789392655655263, 0.1766034299808164, 0.11375641885904536, 0.16784555879571747, 0.1320189973639865, 0.12812493414047266, 0.24604435138885053, 0.12473372336957725], [0.035736714639971336, 0.03066288175872497, 0.04719096250952252, 0.0564616721033329, 0.061214270911389784, 0.06046068937247319, 0.07504421872116866, 0.04295073479654328, 0.045483337204542854, 0.04301372254567762, 0.038552528262258544, 0.07531083264057675, 0.09506147565139879, 0.009534099240667157, 0.02417754911397013, 0.030258507993552956, 0.014527520660551326, 0.04438362565011748, 0.06428537950400384, 0.04374885285693792, 0.020508746383711696, 0.012863096011231744, 0.019870472568718177, 0.044723400966294354, 0.033471277734685334, 2.0341325911783406, 32.77254027705039, 30.303298427212624, 31.008385650573242, 38.43464636033581, 34.60582471662952, 39.643371797377064, 0.38038582090408574, 0.11064152834155869, 2.1251411399533673, 3.310606186428378, 4.839897376875724, 0.9551807937602844, 0.15086820769694545, 21.19476649069017, 62.847384175946644, 62.71635740034042, 61.408635262520086, 57.379835497948434, 52.62665240995346, 48.90803367860856, 47.3186618281949, 57.051352685497655, 56.24226970057334, 58.67892057664933, 59.49035698367704, 57.03382753556775, 56.518718350318174, 59.34604906266736, 54.76674072204098, 59.13694750878119, 56.53820076296407, 56.63119623737951, 59.71604231865176, 56.30916572386219, 46.10667690154045, 42.202420234680176, 43.776945913991625, 45.33356989583662, 42.929145213096376, 44.099031340691354, 44.67008529170867, 44.651646229528616, 43.638654908826275, 43.96358405390094, 44.03530067013156, 40.086807512467914, 40.25457905184838, 42.23599180098503, 41.898754258309644, 45.397739871855705, 48.89216376889137, 55.245697421412316, 56.25640592267437, 57.38873927823959, 58.23958373838856, 57.588689942513746, 57.43594500326342, 55.766619559257265, 54.24225707207957, 53.16153818561185, 51.36368843816942, 50.41447093409877, 54.845956910041075, 57.07699321931409, 55.96638979450349, 56.939635738249756, 57.363165424716094, 50.4733221761642, 48.51163502662413, 46.0169840628101, 44.105871954271876, 43.70968903264692, 47.75022845114432, 50.174967089006984, 54.298170458885934, 58.50144901583272, 55.70925489548714, 54.04082375188028, 47.69586832292619, 38.35497517739573, 39.8599729230327, 39.83424217470231, 39.90775523647186, 40.71857190901234, 39.02644964956468, 38.27060891735939, 41.262608574282744, 38.97462729484805, 39.47910685693064, 38.779344251078946, 38.345730150899584, 40.20182709540091, 40.241250838002856, 41.758447154875725, 38.913038238402336, 37.977011665221184, 39.434352613264515, 37.74208130375032, 38.457368650744044, 39.07722473144531, 39.48807731751473, 37.5554863099129, 41.38789692232686, 47.522405424425685, 52.47502534620224, 51.450302216314505, 53.47831664546844, 51.11845793262605, 52.410153265922304, 51.24637034631545, 52.12955082616499, 50.387092790296, 53.054673210267104, 52.77821671578192, 55.81697886989963, 53.08536967923565, 49.44951295852662, 3.1971646220453325, 0.436650259840873, 0.7918710117378543, 4.766304887110188, 15.408336962423018, 3.9078782402699996, 1.3230231812884732, 4.842525855187447, 46.98639000615766, 27.999039311562818, 36.77737435986919, 44.922654551844445, 44.18881831630584, 8.38356221875837, 0.23891552020945858, 0.10340542187012973, 0.06690615097120886, 0.16212421499433058, 0.040474493477133014, 0.028503094123856678, 0.02770301104793626, 0.086645501846027, 0.07812242894884079, 0.04812134181960456, 0.02127281375109188, 0.07545045216477687, 0.012114398282832436, 0.040767039472778, 0.03883017384777627, 0.052192390505825324, 0.0852236196759247, 0.03078057201609256, 0.05111601398957353, 0.03806172637268901, 0.051263033923122196, 0.08963829327014186, 0.028488582503350995, 0.05493775851303532, 0.1281184300539955, 0.06071542126817569, 0.054852083070023414, 0.05563350424410836, 0.01278837754075686, 0.044126350342506365, 0.04648195196604056, 0.0556550428060995, 0.07181012492266393, 0.04568107598911851, 0.01730179508036423, 0.05043511121203342, 0.04744051182041726, 0.0526581451507105, 0.03163675762592785, 0.042076735727248654, 0.008428746406289359, 0.062120763599992766, 0.09688139412431948, 0.019454414047481074, 4.54381138086319, 43.41523670381115, 30.065791068538545, 44.26352377860777, 43.613300708032426, 43.84942739240585, 41.04534064569781, 0.30895210562213776, 0.4107698792171094, 1.4961844250079126, 4.647742423319048, 6.143922190512381, 3.711097586539484, 0.3790252793940806, 25.345559812361195, 62.236557391382036, 65.95064578517791, 62.26340993758171, 59.87998954711422, 53.68738682039323, 50.24387528819423, 49.56073568713281, 58.43712214500674, 57.851120041262725, 61.73624730879261, 60.74829639927034, 60.48729796563426, 59.30757845601728, 61.56811098898611, 57.17453864312942, 60.630240901823974, 57.96102485349102, 59.27359896321451, 60.615767355888124, 58.91836950855871, 49.363499303017896, 45.771612351940526, 44.50708727682791, 45.49878404986474, 45.151999458189934, 46.40240007831205, 46.978396215746486, 48.233001616693315, 45.92867582075058, 45.43418653549687, 45.990770862948516, 43.904615140730336, 42.9555231525052, 43.82719147589899, 44.54653455365089, 46.83548073614798, 52.01029116107572, 57.37759582458004, 58.48249612316009, 57.51709491975846, 59.27744288598338, 59.308123665471236, 59.290508301027366, 59.08559191611506, 55.53118713440434, 55.950586565079234, 52.13035098968014, 51.5637920748803, 55.84412559386223, 58.579292374272505, 56.20133192308488, 58.84146751896028, 58.33452863077964, 54.020333290100105, 51.51539787169426, 48.05857773750059, 43.73651804462556, 45.456842145612164, 47.79591229654128, 49.6432113647461, 55.31640598850866, 60.386834298410726, 55.84330189612604, 55.92749164950464, 48.60659953086607, 39.38984155654907, 41.39591816932925, 41.70722100042528, 41.173484479227376, 42.9457054599639, 42.06852228410783, 40.71580663804085, 43.21748648920367, 41.43630289262341, 41.2537165611021, 39.20969101690477, 40.92440220617479, 41.25947460051506, 43.90876108600248, 43.709237960077104, 42.264197564894154, 38.412139800287065, 40.93982104332217, 40.274304651444965, 39.508744285952666, 40.328201939982755, 41.68893883305211, 40.40880664702385, 42.83475337489959, 47.31592009144445, 53.30159425735474, 51.376279246422556, 54.887192787662634, 52.50819290837934, 53.59259882280904, 53.87613911782542, 56.51298776749642, 51.63382991667717, 55.64601452119889, 52.91688426848381, 57.89531730836438, 53.23047384139031, 52.84480287182716, 3.6743305142848723, 0.3970903680930215, 3.7782568989261507, 8.490880227858021, 9.105434244678868, 1.0622663411401934, 0.8383635395476896, 4.555460820274969, 53.70425301213419, 31.947214757242513, 49.19127195112167, 47.89575230690741, 49.6862829116083, 13.961792338278986, 0.25026707399276, 0.2112475500231789, 0.041839053118301016, 0.0176279493532474, 0.01645340633037831, 0.06653381691825005, 0.04838337453322546, 0.035026957160763206, 0.030437684467723294, 0.08407474059851901, 0.016724821705851826, 0.06253024908683955, 0.039339426965002096, 0.03737662926376347, 0.031698425788612615, 0.0743192084313881, 0.08733079813781285, 0.0432023027491185, 0.0051527696233543184, 0.11543500177081555, 0.11368711854541495, 0.2382194833649743, 0.27830586137790836, 0.11105686290970734, 0.18932389095425609, 0.21132395963274667, 0.12570605748483252, 0.1424448871083798, 0.11357641117947717, 0.1360124145304003, 0.20444747781561268, 0.1674588069680237, 0.18457330312700043, 0.09673000748960242, 0.24345059218185566, 0.11558267287909986, 0.10844268745953038, 0.1437048719174439, 0.15828956188934465, 0.13323707716359248, 0.09341717517424016, 0.20827747310601896, 0.20300130299743147, 0.12341010729752241, 4.346562249045219, 48.96635147833055, 44.47494345326578, 43.49928132949337, 51.093009594948064, 46.4424749343626, 49.20638876576578, 0.9075656713497255, 1.3032149667701414, 4.318330009137431, 18.115129317006758, 12.606039797106098, 3.4099507524121195, 0.4770711731285819, 24.22911793954911, 65.94235389463364, 65.73208347443612, 67.9497366566812, 61.52314101496051, 57.82709552395729, 52.75380388382943, 53.44718871578094, 61.63872934156849, 61.12701692888814, 61.87382836495677, 63.787427256184245, 61.04128176166166, 62.987883475519, 63.8135031730898, 60.396224452603256, 61.47501745531636, 59.69661089681811, 60.61743044084119, 63.260637252561516, 60.83564758300782, 52.50721231583626, 47.94196959464781, 47.155342178960005, 49.63550782972767, 47.63835460908952, 49.17258577962076, 48.97978167380057, 49.44367647171021, 47.599872235328924, 47.815233892010106, 50.0491060749177, 43.14977461291898, 44.424517462330485, 47.99813793551538, 47.14904285246327, 49.74572643156975, 52.83121970392043, 59.05040825566938, 60.5759435315286, 59.71565008163453, 63.27402037958946, 61.11228450652092, 60.77263862855973, 61.66512689282818, 57.47805164706323, 59.92543412793068, 56.15164333774198, 53.929965803700114, 58.294700884049945, 61.80540653967089, 57.9766554986277, 61.62666020854827, 60.26484466368153, 54.52973934911913, 52.36914488577074, 51.115292579896995, 47.16230830838604, 47.254130994119954, 52.13236316557854, 53.83651925671486, 57.20276794125957, 63.032935819318226, 57.659002350222686, 56.98566082985171, 53.8166210728307, 41.955965949643044, 42.756549158403956, 43.33997426494476, 42.81618095213368, 45.538082276621175, 44.84317164267264, 42.45760571572089, 45.76679175899875, 43.923921046718476, 43.707861208146625, 43.346916860149754, 42.496370500133885, 43.48757305452901, 46.334550919071326, 46.10907739208591, 43.19905527176396, 41.44947813403222, 42.344013875530614, 42.45922565460205, 42.37152537991924, 42.593766873882664, 44.096301371051425, 42.00656060249575, 45.70974088484242, 50.91759727847192, 56.86689538340415, 54.518666498122684, 56.53054429638771, 53.85458177135837, 55.128904927161436, 55.89286496562343, 57.16610162488876, 54.13281902190178, 57.257889009291134, 55.82640040305353, 61.40018255479875, 56.2287728248104, 52.28532383518835, 5.0440332101237395, 0.5724586498352789, 3.6404012768499316, 20.146077679049586, 32.69110991108802, 10.90857428889121, 2.2513007444720117, 7.049844572621008, 60.70111813083772, 37.17388283821845, 51.63096266408121, 48.264360966220984, 60.413114178565245, 16.260946489149525, 0.3074317275276107, 0.2783632873287124, 0.10065937204466713, 0.22287670342672258, 0.2627854409717745, 0.24836746705395563, 0.156278504479316, 0.276009681364221, 0.19375197108714812, 0.09865700207169979, 0.12924157623802462, 0.2292805089945755, 0.13412678103533485, 0.17371213754578946, 0.17970516676864318, 0.20281097611352322, 0.2744878323808793, 0.11482026217685593, 0.12622599369816243], [0.004117977317242373, 0.011894293561307414, 0.017496639967805917, 0.00462256878944895, 0.034355856478214264, 0.07528047257613751, 0.042350531720946875, 0.04708760958765784, 0.04392735134329527, 0.012669806282276349, 0.029297056157262098, 0.055972027006529035, 0.030691087200877168, 0.020690925922545216, 0.0179672094752952, 0.013541876725221594, 0.013383230449812067, 0.02731084106339803, 0.012242096521320843, 0.03119244386682347, 0.030904624633671298, 0.09823933093538208, 0.03032855907334916, 0.018649864678962097, 0.0287465185617968, 0.03421210007922303, 11.529001074452555, 44.93981492134833, 18.33436627541819, 46.10160135453748, 30.617839174885905, 40.258387673285704, 2.6207946337038472, 0.3689748186978602, 1.0998427699650488, 4.834180032053302, 2.265606854231127, 6.741521762263391, 0.23140153066525537, 2.756769479282441, 53.529436895924235, 64.31542927219023, 60.7398711481402, 58.71595559581634, 57.532780478077555, 50.526642876286665, 53.32575605761621, 54.26155905569754, 60.244656224404615, 59.39923640220397, 60.85964464372205, 58.07165138183102, 58.76425173974807, 57.78554193435177, 57.158264729284475, 57.273272545106956, 61.43540543894614, 60.1943753611657, 57.47215240232406, 49.154664470303445, 42.1994000096475, 42.61929758133427, 40.88088350911295, 44.02494953524682, 42.63807396734915, 44.39380530388125, 43.347842539510424, 44.22536696157148, 42.71486220821258, 43.13119826778289, 42.57806562608288, 42.98942027553436, 41.10701599428731, 42.15128037237352, 41.62161919378465, 45.483365212717366, 50.47179637416717, 55.07496449255175, 57.29360611208024, 56.11240394653813, 56.6863133830409, 58.10181048608596, 57.835897322623964, 53.97829332659322, 55.57858113319644, 56.23441319311819, 53.01698707765149, 53.51293156223913, 56.80684781843617, 58.91065812879994, 56.78703984906597, 57.69699050534157, 54.92185477287539, 50.812160045869895, 46.42570680187595, 46.77010267011581, 49.16126189693328, 51.7485749336981, 53.708755893092004, 55.59292131854642, 55.9401491380507, 57.91080282580469, 57.54726186875374, 53.42511753882132, 50.37111697658416, 40.95793454877792, 41.8607190347487, 40.910897485671505, 40.11090655480662, 40.18391363082394, 40.57881785977272, 38.98444890975952, 41.05860610162058, 40.42125624995078, 39.28547513100409, 39.03784021254509, 39.451038375977554, 41.126973013724054, 42.60588307534495, 41.209534983481134, 39.528199242007354, 38.02504501035137, 40.80952775093817, 39.093479033439394, 38.63080801502351, 39.56364570125457, 39.88296585698282, 39.64395230816257, 45.0862487669914, 52.28131125050207, 52.16278114626485, 51.140772296536355, 53.75149796085974, 51.86955651929302, 51.88850941196565, 51.980794937379905, 53.291254889580514, 53.646154865141845, 53.41144023403045, 54.28141801587997, 53.53952130963726, 55.56106382800687, 19.73629197766704, 0.09887149902961909, 0.03059155705775465, 2.8395297738813587, 3.365690237091434, 6.024533087207425, 0.6081944451697412, 0.5380294327774356, 10.477733304423671, 38.530803265110144, 36.84369771711288, 26.282737601187925, 34.17275974827428, 35.618843493923066, 1.5041001357378498, 0.07544774787440416, 0.1419907961521418, 0.043898952463942195, 0.06281488522466633, 0.04801726877509106, 0.05379399690296381, 0.023334672366599404, 0.04989639052280015, 0.02164632757945407, 0.13790973852719032, 0.026203945519462712, 0.038292422259767214, 0.022034722665745406, 0.009125714047601628, 0.023805601935413097, 0.009562098796689704, 0.06284049554397503, 0.0998195021923992, 0.07924122375346, 0.06123170707254641, 0.06546236634735139, 0.022674957665825085, 0.047998863512710224, 0.03337157905221947, 0.05936549390636145, 0.03059362549515021, 0.006997532806464381, 0.10060465804511502, 0.007353593715496602, 0.02744893798784864, 0.046201579107512394, 0.03491765939660611, 0.017214618105020736, 0.04274305985158971, 0.028641125930833723, 0.029797064508461667, 0.06437662057578564, 0.07609979595027624, 0.016503987285578926, 0.055907035937472704, 0.05349570907832635, 0.02459713738531836, 0.048332326264391025, 0.025631348422217756, 0.047375647155868436, 18.608712534750662, 49.5649875363996, 21.84994939834841, 54.528633240730535, 32.96485016422887, 45.0241772590145, 1.4579039307371264, 0.27695923202460815, 0.4370052649849846, 3.863970247968551, 7.075757220868142, 6.297665372971566, 1.1863508892636145, 3.8133991293368803, 56.68636437385314, 66.82488718340474, 63.356362696616884, 61.84766223353725, 57.7651495318259, 53.11520322676628, 54.45046040319628, 57.334798843629905, 60.334560871124275, 61.44695289673344, 61.37575403336556, 58.55901372048163, 60.64472229250016, 58.87020672521284, 59.2206391211479, 59.96593259995984, 63.191968317954775, 62.300060564471835, 59.39573764801026, 53.10535023289343, 44.776408979969645, 44.32907835129769, 43.96354483019921, 46.42684428922592, 43.55601056929558, 45.82774539147654, 45.379642055880645, 45.38318003377607, 44.30377514131608, 44.28819940936181, 44.408274927446925, 45.730501990164484, 42.80428832577121, 44.34603083518244, 42.49548404447494, 46.85592805185626, 51.84674009200066, 57.19735899279195, 59.510459130810155, 58.10907079327492, 59.96370861607214, 60.59703411594514, 59.10188544181086, 56.94890429896694, 57.615020813480506, 58.97761298764137, 55.03884730800506, 55.51533683653801, 56.23964563492806, 59.62502764117334, 57.904087728069676, 58.93279598605249, 56.66840776320427, 52.31565552373087, 48.58330849678286, 48.363181160342315, 48.398784514396425, 49.79525027736541, 56.772142687151515, 56.573945322344386, 58.63688845788279, 58.416576770044145, 58.660787459342714, 55.61911882892732, 53.1312535655114, 40.9843046434464, 44.24737145823818, 41.088427882040705, 41.05722542731993, 40.963665131599676, 43.306783168546616, 41.351109012480705, 41.77098697231662, 41.6783994243991, 41.51130645505844, 41.21618732329338, 40.425967016527736, 41.78946133582823, 44.254114012564386, 41.63271557900214, 41.74360098377351, 41.27374026083177, 42.39611471852949, 39.259724770822835, 39.54499875345538, 41.99595843591998, 40.97444772720337, 41.02728989816482, 47.12691283995106, 55.63904839177286, 55.789832145937034, 53.686700405613074, 55.85448065111714, 53.66199339589765, 54.4945203873419, 54.52008639612506, 56.26763174610754, 55.75950045739451, 55.83275072036251, 54.811471431486076, 56.32055236447243, 55.63890326407648, 23.223926251934422, 0.1279788105297954, 1.2468940211880593, 5.334128275994332, 7.794252086070276, 5.983413900098493, 0.20024007697018886, 0.7969656190083874, 12.870018251480596, 44.46336069414693, 43.43535454042497, 31.450115134639127, 35.20353117296773, 45.590889146251065, 2.8103569005766227, 0.023882147525587392, 0.11142132923968377, 0.10355107050629393, 0.06983158028414173, 0.025291691849669142, 0.020660251762057026, 0.07038134030036389, 0.023386402453686443, 0.03387654973794857, 0.019369987327785745, 0.028861531341869025, 0.03680134319790429, 0.060549570893448215, 0.010177237713979858, 0.08345106075848303, 0.01903599022977775, 0.05851904335882395, 0.05297271617417855, 0.029462456455334064, 0.1155563730806593, 0.13350497811071335, 0.122977742594817, 0.15063456620179838, 0.18999838540630956, 0.16945746907543752, 0.13818778247842867, 0.13505124997708107, 0.2136902366915057, 0.10460582036044329, 0.08359860163182022, 0.17100694318932874, 0.10927481216288383, 0.11076913560710608, 0.16397702928271987, 0.129230008310368, 0.144970694316491, 0.11245285896884818, 0.11659470567059134, 0.2377357907713421, 0.11600857946060358, 0.33603735868969276, 0.2945582021868998, 0.11733975682047107, 0.10745097131979083, 0.13375253176256535, 19.452382979854463, 60.37561239734773, 27.601897370430734, 57.39020232231387, 40.39041073091569, 53.335307028985795, 3.4861744171188724, 1.251914532434556, 4.719719877166133, 8.64823297146828, 9.125777617577585, 10.37168908503748, 0.7156165809400621, 3.8121748595468463, 58.0041277793146, 68.1913625040362, 66.96461769842333, 63.14958318587273, 62.26981124570293, 55.4667543595837, 59.00717981400029, 59.924159357624674, 65.53885967500749, 64.26072397539693, 64.56417814377816, 61.45453091590636, 63.81589189652474, 59.50810963107694, 61.12378881823633, 59.89729896668465, 67.64431738084363, 62.47495120571506, 63.89868136375182, 55.46009417503111, 47.07764002584642, 48.17594289779664, 46.74318344362321, 48.63431892087383, 46.29235013838738, 48.78541646465179, 47.63503236155356, 49.847586462574625, 46.70506977265882, 46.757523628973196, 47.027194423060266, 47.232910971487726, 44.63412107959871, 45.80241472490373, 44.91546092494842, 48.703285955613666, 54.57851402221188, 60.330799318129024, 61.98946768237699, 59.50613275651009, 59.32477020448255, 62.703672455203154, 60.74108316052345, 60.24649189364526, 61.01392715207992, 61.79550255498579, 57.455886333219475, 57.675527295758656, 59.54101831682267, 61.915734967877796, 59.737968367915, 60.89956260496571, 58.73643821285617, 55.47055905865085, 50.5733936063705, 50.00035493604599, 51.64541659816619, 54.25239247660483, 59.42373552630025, 59.9617160520246, 60.88340636222594, 61.27851847679385, 61.633073283780014, 56.72370926026375, 55.36889906852476, 45.203017727021255, 47.17501286537417, 43.62041980989518, 43.43112622537921, 44.146503786886896, 44.702354631116314, 42.82773233229115, 43.5920100827371, 44.563973411437004, 43.70038517059819, 43.59989012441328, 43.11352014541627, 45.2854149572311, 46.16148417995822, 45.65132110349594, 44.3569036453001, 43.86055515658471, 45.84125795672017, 42.9081016971219, 42.07495497119042, 43.594543933868415, 43.15559148788453, 42.923332260501006, 50.407124334766024, 57.27900312792871, 56.499247704782796, 55.20511265723936, 57.58925084144839, 56.208199993256606, 56.92302842294016, 56.05003041605796, 57.997008677451845, 57.74379222623764, 59.044175609465576, 58.13106352283109, 57.68866331346574, 56.30645144370295, 24.920380769237397, 0.2394906683794914, 0.9588855949621048, 7.424704509396707, 10.523140622723488, 16.252329041880948, 3.787376899873057, 1.3870632287956055, 15.262101196473646, 51.0123303628737, 48.61271842833489, 36.66373937360702, 41.930968684534875, 53.84947876776419, 3.0524156795394037, 0.18746759862669055, 0.2129591896288818, 0.13661930938401531, 0.2513993519448465, 0.11709348253545263, 0.19286094954417599, 0.18513227152007242, 0.13774608682480552, 0.07977849653651638, 0.23189112213590454, 0.11493784901235374, 0.2851875679146859, 0.10754167613002563, 0.061500331972755735, 0.2590598021784137, 0.12258213479071857, 0.1289393392301375, 0.19298139388763136, 0.12182281142280948], [0.09188966480113807, 0.0364863355043194, 0.0440966108092858, 0.01663906965404749, 0.020361473641148018, 0.07686504117784, 0.049362565135403026, 0.05981722148135305, 0.037914783047932776, 0.061649405021941474, 0.043202176344610994, 0.015926644273643053, 0.06196977150055671, 0.047059976796229044, 0.10314065422261916, 0.07565517384078234, 0.06159211696696378, 0.02403764230679841, 0.025351919767056263, 0.02427180474173398, 0.0670105534335298, 0.02365950513781319, 0.008432994363829494, 0.11517850021200797, 0.04880726247304871, 0.029788047653592886, 0.028333053248183384, 34.38536005635416, 35.53773280112974, 33.00311288525982, 40.705996790239894, 36.051798635913485, 18.935693079425445, 1.106378909560942, 0.7209649778181507, 3.393615796681374, 4.880792008292291, 2.984243660203872, 0.5979140968092027, 0.16647940952210658, 15.91871282746715, 68.34946540094191, 62.86608211455807, 64.60792041593983, 57.76578887816399, 58.1600223818133, 55.7646309175799, 57.61000802440029, 55.88001135856875, 60.33714571306783, 60.93223987087127, 59.858479269089244, 58.276571689113496, 58.62715705748528, 59.007756402415616, 59.41008175573042, 62.25503175489364, 58.53621690504013, 53.260660402236454, 42.69680753830941, 43.81737770572786, 45.645319877132295, 43.595297028941495, 42.41471067551644, 44.31855070975519, 44.14367968036283, 46.8133036551937, 47.723011124518614, 48.3404431804534, 46.21538146849602, 44.76025273722988, 43.527902864640765, 42.05094222099551, 42.008180541376916, 40.99974701481481, 45.66539849004438, 48.84050223135179, 51.71599964941702, 55.09581189001761, 56.157766157580966, 57.86357356655983, 57.474160655852295, 58.03522433004072, 55.524797593393636, 54.92088202507266, 55.57873802800333, 55.517274487403135, 53.680314786972545, 57.89556834005541, 57.41480735040481, 55.20898011422927, 58.479417062574825, 56.638950763210175, 50.90848561256163, 48.400067129442775, 49.68028168524466, 52.681926450421734, 52.43115755819505, 55.923290791050086, 57.509767932276574, 55.1195736085215, 56.19154560950495, 57.64593301280853, 53.88517625870244, 49.754202673512125, 38.47267766152659, 40.9702782477102, 40.119861325910016, 38.97025385210591, 39.881875438074914, 41.6333863043016, 38.3125312097611, 39.64068105143886, 38.95875346276068, 40.43501200214509, 40.30947262240995, 39.29319827787338, 38.93325021190029, 40.15420167676864, 41.06961227232411, 41.244098909439586, 37.77795137897615, 39.552780735877256, 39.50072696132045, 38.30191335370464, 38.516627819307395, 39.65594299377934, 41.459946940022135, 49.20886770371468, 50.534381712636645, 54.016038294761415, 53.79191798548545, 55.721406398280976, 53.237232085197206, 51.98335232273225, 51.44332039740778, 52.98989134450113, 50.25918822134695, 55.44725625745712, 54.83589210817891, 57.247733992915, 33.284448808239354, 2.115098891719695, 0.10646944414944419, 0.6422090554429639, 5.912717100112669, 6.64852922962558, 1.158613603441946, 0.2888208165043785, 0.10931799653917552, 10.885700987231347, 36.06663696227535, 31.49176286112878, 21.06401231981093, 47.81544177762924, 13.50468029898982, 0.1847835942622154, 0.04940435523167253, 0.06902433045568966, 0.06831463426351547, 0.08207023324024293, 0.056839502837148406, 0.06182704548982363, 0.06080265186967389, 0.04062126443210629, 0.03162995859559986, 0.06512578561781876, 0.06139148237003435, 0.035506723553783474, 0.022560611382246982, 0.02149997605761934, 0.07119232863788644, 0.029903531577738545, 0.03472309221603698, 0.05548051648562955, 0.03322799119257158, 0.0575135299755681, 0.057875943189907464, 0.05528516789537765, 0.04429704622335492, 0.012730591528628384, 0.07019565590927679, 0.05039847688749433, 0.055707849246720155, 0.07138713713615172, 0.04527469315836507, 0.045900916410309654, 0.016851749068366426, 0.0653877570444057, 0.02019759019716613, 0.10105485727469768, 0.04267285555420865, 0.047149065160943616, 0.036054679432943944, 0.09640337058132696, 0.015237141201542992, 0.03802776186456604, 0.039744794729255864, 0.06451277738256801, 0.02075878790609779, 0.06920996888150131, 0.021415263970172214, 0.7927483969157743, 48.44286411039291, 30.877553032290553, 42.31614543545631, 50.69978806280321, 44.2270928044473, 20.66426004132917, 0.9745055761548781, 0.7389757662050186, 3.2872626906441105, 4.70244477833471, 7.043460424869292, 2.5266050427190723, 0.46244266292741226, 19.73603114005058, 67.44993255984399, 65.3172496826418, 64.60629263231831, 61.73420375393283, 58.224816014689786, 58.322859579517, 57.25586506628222, 58.61458193871283, 61.16522473673667, 64.52624882421186, 62.13623100711454, 60.01436994921777, 59.18027008733442, 61.408223413651996, 62.031017349612334, 64.60444519596716, 60.29980867139755, 55.93015886122181, 44.924007769553896, 45.685590851691465, 45.511308177824944, 46.74109282032136, 43.55148023174655, 46.69533444989113, 47.48877110019807, 48.78730312470467, 49.833662048462905, 48.90790816276304, 46.82469421817411, 45.26654835670225, 46.13423155200097, 42.23145361869566, 43.42510146479453, 42.0454744369753, 46.451896467516505, 52.50559629932527, 55.45616788248862, 56.80590644959481, 57.21085194618472, 58.32704474849086, 59.54434056435863, 59.451549053192146, 58.9270418690097, 57.68024198470577, 58.67447260887393, 58.35918072731265, 55.62841876860588, 60.01712737544891, 58.997201304281916, 56.4054677563329, 60.62129397546092, 57.91493308159613, 53.83114560957878, 49.83318744167205, 51.72617820001418, 54.04806444721838, 55.87981916243031, 55.913437797177224, 59.04164568070443, 56.25874365529707, 57.929347791979396, 58.75455171831193, 56.208878563296416, 51.53000085584579, 41.68145102839316, 42.73157150514665, 41.763542313729566, 42.23945525384719, 42.49549188921529, 43.135112793214866, 41.51499740539059, 42.02225792792536, 41.10917329788208, 42.180776596069336, 41.75483465194702, 39.87052017642606, 40.70660083524643, 43.95262887400966, 41.44792095307381, 44.7992685533339, 39.68956162852626, 41.93459295457409, 41.545897837608095, 39.51722837263538, 40.598602294921875, 41.26898242581276, 43.55745400151899, 51.88250034086166, 51.41052153802688, 55.6060730257342, 55.31504492605887, 57.28615753112301, 54.65942467412641, 54.752879065852014, 52.9023636541059, 54.06120830966581, 51.148915137014086, 56.76034812004336, 55.617059584586855, 58.76391833828342, 35.826882085492535, 3.2619234438865417, 0.5883894175771744, 3.176925191956182, 7.98141876536031, 6.011287243135515, 3.1918721189421997, 0.07488709408789873, 0.35883953674666347, 13.462544237413715, 39.927688721687566, 43.58965273826353, 21.759066120270763, 50.87282342295493, 21.341408221952378, 0.2541964768522209, 0.03197798659394105, 0.038750757343105735, 0.04042288213367424, 0.09071912841811296, 0.09416035706958464, 0.012653263571161418, 0.04254703710396444, 0.010187042681800743, 0.018421501529613332, 0.04607906249622184, 0.029228309342156977, 0.016848027796274232, 0.021473722224454247, 0.030777496173076575, 0.022709900851271326, 0.02661138555155166, 0.047550384150517565, 0.010066296691225182, 0.05772320057956442, 0.19039583182142628, 0.13785732279141105, 0.1366208109163469, 0.13624823171525233, 0.13626609688564656, 0.16138909234394952, 0.11968683571584764, 0.12603104730407078, 0.17747805724220891, 0.1690666263382281, 0.15090487266500152, 0.10569398696984976, 0.1418430331133066, 0.10543037611510485, 0.25209168092377726, 0.09435152665020959, 0.19048564796966894, 0.10507980662007486, 0.12744282477445182, 0.09845350613637317, 0.10745217407783193, 0.07721808513686543, 0.12512956866093222, 0.1825514438772394, 0.12626155549960752, 0.09250011430272172, 0.9015552519309906, 53.50518488114881, 46.83419419873146, 44.26089971296249, 51.77610212756742, 49.23615955537366, 24.29926953008098, 1.3602757694259768, 1.7905230051086796, 8.342718578154042, 14.380719123348115, 12.542363059136177, 2.1799717074440372, 0.2976421963784003, 19.470804391368745, 68.00952142284763, 67.24761670635593, 69.02408953635924, 62.88549000217069, 63.71514189627863, 60.625051606086, 61.33121944242909, 61.26767312326739, 65.08842645152923, 66.16362264079433, 64.21590697380805, 61.99193877558555, 60.94218700162826, 64.59205050622263, 65.03926346378942, 66.80818573121103, 63.376751176772586, 58.961939196432795, 46.950712127070275, 48.56265329545545, 49.81906690905171, 48.88355416636313, 48.50916393341557, 49.77406163369456, 50.00054320981426, 51.71229693197435, 52.05853631419521, 51.5950886664852, 50.100763690087106, 47.93547022727228, 48.64622723671698, 45.267164168819306, 45.89956398933165, 45.93243345137566, 51.208425337268466, 55.646775461012325, 58.2003600366654, 59.49153369472873, 58.411105063653764, 59.96867041434012, 61.298636313407656, 60.73921611232143, 59.65401003437658, 57.92163641222062, 60.18696992628036, 59.76052199640582, 56.16414000911098, 62.56328690436579, 62.38804717217723, 57.7080790458187, 63.01961937258321, 61.10660491451141, 54.806144852792066, 51.90819186549033, 52.81574595359064, 55.83603766656692, 57.61507964903309, 59.31491328823952, 62.91530393785047, 57.583606550770426, 59.79828265405471, 59.40439039661039, 57.92281312327231, 52.90422677993775, 42.940574999778505, 44.891204987802816, 43.55541829139956, 43.400166957609116, 44.04818957851779, 45.83230710798695, 41.79507816991499, 44.62336986295639, 43.07029954848751, 44.50653422263361, 44.299382086723085, 42.41393012385215, 41.49764483974826, 46.715538578648726, 44.670634423532796, 46.863623742134344, 41.8025149837617, 44.01910912606024, 43.81500467177361, 41.193006115574995, 41.321977569210915, 42.7321873172637, 45.798868902267955, 55.002486936507694, 53.249301218217425, 57.663085537572066, 56.45873746564312, 58.37987907471196, 55.138871669769294, 54.75178080220377, 54.57163810729981, 57.731440682565015, 52.382171077113, 56.81332365159066, 56.15449882322743, 59.88583387867097, 35.89039310332268, 3.2884967663595757, 0.3096478666749693, 3.7437880904443808, 14.913788841616723, 16.729775628735943, 8.833325697529702, 0.7902081106458941, 0.4409249078842902, 16.237563279367265, 49.375552746557425, 43.88105738547541, 31.980690225478146, 62.19366235117759, 25.493772452877415, 0.40146096098807554, 0.1658692051686587, 0.21177766754502253, 0.09822816137344607, 0.12594565914403047, 0.24793306455737163, 0.13713600504542553, 0.21754428714273438, 0.18123403311737124, 0.15027252837054192, 0.1990349747000202, 0.1103271641618302, 0.09427866402773127, 0.1838745543312642, 0.1471667926037504, 0.2278070308027729, 0.13408833874329446, 0.09463928459632782, 0.13949452929439085, 0.15783588462058576], [0.011746804398905126, 0.04229246991716566, 0.08168391042178677, 0.02768108752676316, 0.028873415280794425, 0.09691552334134618, 0.025985231247520255, 0.04308323353348721, 0.056236587810300054, 0.062424027165698434, 0.07285882268221149, 0.03552150138984284, 0.04268256954908852, 0.07644894818264632, 0.011168665613137908, 0.06902446835151604, 0.0302508739273875, 0.05948115786116931, 0.07447046483115805, 0.055748133980218446, 0.04122184672122521, 0.018247409964040406, 0.05233098730264653, 0.09427645769450935, 0.056480119500549576, 0.0497222587376112, 0.048475860497884216, 6.166819026393275, 44.56945688493791, 22.221590049805183, 40.66136414004911, 33.09274296606741, 24.569481611251835, 0.24013122513649926, 0.2536328659663277, 0.3928647803202752, 4.722659693610284, 3.2832947229185416, 4.120873481996598, 0.28971364601485194, 0.10122323573957528, 38.398858654883604, 69.8115602616341, 61.80577916483726, 60.903849755564046, 59.89354133605958, 60.60862471980434, 60.38522220426991, 63.296138624991144, 60.76218551205051, 60.65291612379013, 57.557824811627796, 58.247369643180605, 56.956113615343654, 60.151127307645744, 59.11400948801349, 58.282882782720755, 56.058255626309304, 45.96751905256703, 44.06067840514645, 43.98351361674648, 44.33097677846109, 44.55194350211851, 42.68253403325235, 45.27263587520969, 47.82638519041, 50.08013986772107, 50.78042022643551, 53.956049565346014, 52.660494619800204, 48.111251246544626, 43.61573257753926, 42.92257916542792, 41.13970894967356, 41.86548471450806, 42.704409091703354, 47.810370152996434, 51.782919206926906, 53.3993475667892, 56.642939813675426, 57.22809860783239, 56.797241933884166, 53.665731414671875, 43.04031302852016, 54.520184455379365, 58.088039044410955, 57.54437892667709, 58.55202405683456, 58.90108362320931, 59.81735714020268, 57.40709204827586, 56.865797119755904, 56.69818247518232, 51.95067505682669, 54.81251478195191, 55.13313716457736, 57.86313033873036, 65.37345724721109, 57.95449410715411, 58.07974715386668, 54.68202144868913, 56.73278562484249, 55.88791101209579, 53.222025056039136, 47.46750400912377, 40.58539959692186, 40.890446247593054, 39.543622001524895, 38.60066460024926, 39.825428608925115, 39.17387585486136, 39.001554366080995, 42.30633166528518, 38.42454233477193, 39.52762265359202, 40.176268931358095, 40.653440952301025, 40.2001130196356, 41.82081676298573, 39.644077824008086, 39.72513360361899, 40.45247439415225, 39.2488205817438, 39.473948940154045, 38.678723689048525, 39.4076765737226, 40.32337742467081, 41.335341084388, 43.62954716528616, 48.965417954229544, 52.1826950196297, 52.14621697702716, 54.8748569334707, 55.513901249054946, 51.48419933934366, 52.03124054016606, 52.0814900244436, 52.82539498421454, 50.739709946417044, 51.83984064286756, 39.89770220172021, 4.7186623081084225, 0.06742244826689844, 0.32000546734179225, 3.4736728427871584, 5.110111909527933, 3.996474041092781, 1.794205620404213, 0.21521557903578206, 0.02523166886080177, 16.47759468324723, 43.59843100270918, 23.777078505485292, 32.019588370477, 39.64728240043887, 0.9646327865700569, 0.015085553468745804, 0.07163394768271716, 0.027408996078696464, 0.06076024124218572, 0.05252979477987655, 0.05674932662758136, 0.09073840319028786, 0.03987753095345632, 0.010210946540258104, 0.04139078443028754, 0.019704666244046345, 0.030452412508067586, 0.045837783104469704, 0.004004258986359703, 0.028425190642836596, 0.06303291384791655, 0.031954839247308915, 0.06781264749025145, 0.014264906677717884, 0.04647542872736531, 0.054950705398955656, 0.06988083973767296, 0.04913542006585387, 0.023115504187561815, 0.04786063443809267, 0.023219025648769834, 0.040322516954714255, 0.06454800976620567, 0.07717490842145297, 0.025102983326500943, 0.09828426965302038, 0.039637730111398047, 0.029170373942883267, 0.07752484972438506, 0.021857315854680155, 0.027427223225634907, 0.017681410799043316, 0.019516149242859215, 0.05553431501011214, 0.07589099102563436, 0.019426813814789057, 0.03763070998473033, 0.0547481517517759, 0.05549924350493858, 0.041778823285694086, 0.04746168266020475, 0.05687481566001812, 12.796302207054632, 50.81890652256628, 25.573133768573886, 53.38803545121224, 38.639860845381214, 30.4945041671876, 0.13515275662704823, 0.15684116541618304, 1.580727436850148, 4.8790774422307175, 1.8479065452852559, 3.9597246195039446, 1.6844896948145283, 0.20007337623786545, 43.32101352753178, 71.4362059870074, 63.82135968054495, 62.90806324251237, 62.29915449696203, 62.045334000741285, 62.562345535524436, 65.23649592553416, 61.32411995241719, 64.17895824678483, 58.11970433881206, 59.97210641061107, 56.846632419093964, 61.496814066363925, 60.57794001794631, 60.02110858117381, 59.82561765178558, 49.598421819748424, 44.65476059144543, 45.90075246749386, 46.113823459994414, 46.95283020696333, 45.31887669717112, 48.39234006020331, 48.98790490242743, 52.30990140668808, 53.407941479836744, 55.64327670681862, 53.07887815660047, 50.331069577124815, 45.85388406630486, 44.826846738015455, 42.94722341722058, 44.600447531669374, 45.71295330601354, 50.93959785276844, 53.35843332352177, 57.65421705861246, 59.0217435744501, 57.69862221133325, 58.31458337845341, 55.67515380920903, 45.97055104471023, 58.949654333053104, 60.29706301227693, 59.7730931928081, 58.27779154623709, 62.02628697118452, 59.725585445281006, 58.88433510257352, 58.52839177654636, 57.648058937441924, 53.757169708128906, 54.27942937420261, 57.63677427845617, 58.72156458516275, 60.84410029072916, 60.618101166140654, 59.59764165263022, 58.23548486155849, 58.21004436862085, 58.54352035830098, 54.927930524272305, 49.98206884630265, 41.026203401627086, 43.06876982412031, 40.570271015167236, 40.134287803403794, 40.37236782812303, 41.12345072530931, 41.08426624728788, 44.01820305855044, 41.71195530122326, 41.55079687795332, 40.64325455696353, 41.20070572822325, 41.02557190002934, 43.51493550885109, 42.94545835064304, 42.515425374431, 42.33506302679739, 41.48598755559614, 41.2807926824016, 41.49799000832343, 39.82798991664764, 42.61161758053688, 42.97381708698888, 46.218150661837676, 50.48488924580236, 53.61967886647871, 55.80603545711887, 55.467146596600934, 56.65430292006462, 53.9908213769236, 52.21471332734632, 54.07666244814473, 52.428125566051854, 52.64622503711332, 52.33009769070534, 43.92940452021938, 6.024756172010976, 0.40502547616920165, 2.024111057962141, 4.3364077229653635, 5.618010797808248, 5.319234546153776, 0.6571376576058326, 0.16667618686633726, 0.1594764465886739, 17.50522428943265, 53.744288644483014, 32.495077694616015, 30.35299877966604, 49.69860307631954, 2.3524591615123134, 0.1299848960291955, 0.0689219274828511, 0.052810340008187684, 0.05358921777036402, 0.026154500289609837, 0.0704135772802176, 0.02295461423214405, 0.05619427294380242, 0.021876433578830574, 0.022970654198058674, 0.03674210161871968, 0.0642240388439067, 0.029886237142847914, 0.042109344259745655, 0.03273084992542863, 0.03467878935137584, 0.02072456101286075, 0.048892236945609895, 0.03279727357890337, 0.04793761861360362, 0.12204664699252575, 0.25949840283682274, 0.17650913987909594, 0.10900569313596334, 0.16492506308901697, 0.1470949182346944, 0.08193794517747818, 0.12132599574303436, 0.20936510345387846, 0.11819747652137473, 0.20947923523283776, 0.2855502339380403, 0.08585129849492543, 0.18912518306845622, 0.12440372333531419, 0.18590185280528762, 0.13730186308103223, 0.15962356611365275, 0.1603388777303119, 0.21535483849865777, 0.14933321264482316, 0.176421775212211, 0.16012218210004991, 0.1848117403325535, 0.23743667940218605, 0.09580143231658206, 0.31318520105654196, 14.021494734671808, 64.66407698969688, 33.01724910736084, 50.95540500456288, 45.663806007754424, 34.15996105440202, 0.6083387148476417, 1.0177173477507409, 4.021614963008512, 14.971395711744986, 9.59722101688385, 7.709181760588001, 1.3219455100836293, 0.29132114362812817, 43.25114827002249, 73.33240524415048, 66.93676887019988, 64.8167238696929, 63.040749180701475, 64.86112902241369, 65.64297114649128, 68.48974504778462, 66.05785200672766, 64.13334892642114, 59.61472357473066, 62.52946822874008, 58.92774005090037, 62.63602725921139, 64.02785285826653, 61.97843405508227, 63.24809743512062, 52.32342573904222, 47.731369695355816, 48.583661510098366, 49.28649533179499, 49.948995421009684, 47.79074653502434, 50.60506674551195, 52.61131986494988, 54.977026831719186, 54.712333525380785, 57.25543752793343, 57.38671925760085, 53.49204101870137, 48.96779883292414, 47.31080139836958, 45.27272216735348, 46.49367755459201, 46.7135734711924, 52.775376919777166, 55.563323113226126, 58.21710855730119, 60.25806680802376, 60.24505630616219, 61.02273287311677, 56.742336596212084, 49.31495997213548, 62.48065040957544, 62.2277085242733, 61.445842865974676, 60.469321743134536, 66.01828313642933, 62.839751243591316, 60.06197967836934, 60.17379860724173, 60.21148473985734, 56.798222526427246, 57.537899171152425, 59.624360838244044, 60.4336791653787, 63.513979219621234, 64.1780404121645, 61.228504334726644, 60.08631798528857, 60.36426498043922, 61.69019868296962, 57.280740737915046, 52.22526842548002, 44.56062762968002, 45.14891647523449, 42.6677780766641, 43.199400440339126, 41.496887822305005, 43.71807113770516, 42.02012023618145, 45.63876559657436, 42.68769587239912, 43.819217297338675, 43.347218882653024, 44.59426195390763, 43.39630342298939, 46.183033681684925, 43.96755349251532, 44.66513133818104, 45.35668834563225, 42.71938862339143, 43.36324960954728, 43.6357327430479, 41.27474438759589, 43.61903913559453, 46.37424922758534, 48.61635054311445, 53.97711269317135, 56.20395206635999, 54.46823658481721, 58.4812056633734, 59.715014657666615, 54.66734001713415, 53.614658232658144, 53.79883312409925, 55.16420233634211, 53.96083093458607, 53.201444379745, 43.407227223919286, 6.240516929857193, 0.5147255284170951, 1.7311390561442224, 9.333391612575902, 12.0408909743832, 14.288004098399995, 5.1726452765926245, 0.5155376429038664, 0.2684303138765597, 25.522670515121956, 54.3554449081421, 33.058885066739975, 43.05463360201928, 54.37172274435721, 2.8445403566283565, 0.2513552865674419, 0.24709818193749075, 0.10255233700116796, 0.11819159296611625, 0.13751895707701484, 0.15976889299288874, 0.16699935339631575, 0.11713497385743166, 0.31517059452110724, 0.15550565965954335, 0.16418041030485786, 0.13174616281063328, 0.09865114915995829, 0.1145328796138206, 0.13107654067777819, 0.11771248157827124, 0.1358162040912336, 0.1285595434807962, 0.178706142150106, 0.24492751776931748], [0.05463106287342887, 0.03787756649657123, 0.01650790774053143, 0.06365757811093523, 0.031623295545878435, 0.047919581073426434, 0.06648855644368357, 0.04080620954834646, 0.03443800025589524, 0.052353567744214694, 0.07947082030436686, 0.030579023859313423, 0.01675457847605069, 0.025659096126835194, 0.0224498484749347, 0.06044577747102707, 0.034928568488647865, 0.024643416756824143, 0.028667952414722215, 0.15479283016775885, 0.02956529035263004, 0.029758093615753517, 0.02821076263283049, 0.0726095529934091, 0.030776513665313684, 0.060076477126248425, 0.08550297363751358, 0.4543248582030497, 34.592441589601584, 35.08595812705256, 36.35917125209686, 45.05715654742333, 35.21676132755895, 7.096028520214943, 0.7492473505197034, 0.16119470519404258, 2.187251136187584, 1.646101825660275, 3.466446856337209, 1.1426659817657163, 0.13556480467800172, 1.9639503571294972, 58.65695530368436, 66.92318962466332, 65.479847615765, 62.93748101880474, 63.233270875869266, 65.2893106399044, 63.04048638189993, 60.9426929873805, 58.16747096277053, 59.940256764811856, 59.451286254390595, 59.12252103128741, 60.250661373138435, 60.1431139053837, 55.394759255070845, 47.98205621780888, 46.25103973573255, 46.849036447463504, 44.53650897549045, 43.603836028806626, 41.613880357434674, 45.08512696912212, 48.351645469665534, 48.705996313402736, 51.73748639322097, 54.4018308577999, 56.467853053923584, 61.92091641887542, 57.163042176154356, 46.06524882778045, 42.526019696266424, 41.672566859952866, 42.791069938290505, 42.00512893738286, 45.73188266446514, 49.53728383587253, 55.17875040731123, 56.21695080111104, 57.33874867039343, 54.201538947320756, 56.822505920164055, 37.9615379148914, 42.87030573814146, 56.28942443478493, 58.84748443480461, 58.73264528089955, 56.78224279034523, 54.02378105348157, 52.39986096659015, 58.96898377326227, 57.45773376957063, 56.9519127568891, 56.60859554044662, 55.74818834181755, 64.31348377658476, 74.34798532916655, 54.193145075152, 59.70746017271473, 57.34778973364062, 56.28261127779561, 55.89392400556996, 53.84414826670001, 46.60236250969672, 43.7635314080023, 40.482131435025124, 41.77487404115739, 41.87227433727634, 41.30265989611226, 40.467901076039965, 40.20984442003312, 39.86357365885089, 40.82518585266606, 40.140092911258826, 40.04981956174297, 38.996259166348366, 41.54044966543875, 40.81835700619606, 42.12938177970148, 39.77585377231721, 41.07508397871449, 39.43902807850992, 39.36736637546171, 38.758057548153786, 38.53421572716006, 38.977541615886075, 40.062453516068004, 41.33359170729115, 42.79995018436063, 46.887189342129616, 50.63087594124579, 52.719702797551314, 53.017516597624756, 53.02458863104544, 54.285438445306596, 55.68130408563922, 54.812440256918634, 55.93481863698652, 45.85427238095192, 10.58114855520187, 0.02748330660735167, 0.13629402845136582, 3.16866320948447, 1.812776204559111, 5.044159706561796, 3.440732042635641, 0.6380536106805648, 0.08022104254773549, 0.39488274784338095, 24.332007592724217, 44.01216653085525, 19.569655964451453, 39.55797003161523, 12.173022877785469, 0.03177545018373959, 0.005459417382465495, 0.027699239980128985, 0.02050326310939366, 0.03464364123740985, 0.019620025019732215, 0.019745320614968098, 0.036984962982035456, 0.029390185635777253, 0.058752937662986025, 0.05104512021306062, 0.04171664375931986, 0.03254519234741888, 0.012000978965642712, 0.01550242308557274, 0.024134535192241593, 0.029320892983026085, 0.07154768618244318, 0.12835932640178552, 0.041110610754619685, 0.054969440079143936, 0.035526231982775276, 0.03542380602729898, 0.04143027243234458, 0.03332521158060239, 0.05447153655451633, 0.05888318410143257, 0.05777776902241092, 0.015286780826206652, 0.02102072485872815, 0.008928240520969756, 0.0342155474748823, 0.10040064116999989, 0.012390112369171074, 0.014397022370699675, 0.010995919489481998, 0.1771970102263074, 0.03457158300725203, 0.041578847524379535, 0.03914174946746038, 0.019524129963810408, 0.05849422977095651, 0.06510097969083056, 0.05574455251917244, 0.04917098186729897, 0.12398036782659831, 0.09193346204776918, 0.057306199770180456, 0.6266091151102897, 47.542072188469675, 30.510205414987382, 39.16243822343888, 53.68732406247047, 35.317283830335064, 7.228382527828217, 0.8913268749752353, 0.3294551618877919, 2.0677245047784623, 4.327547088746102, 7.529277349672011, 4.4210725734310765, 0.4497823245342701, 3.534888783770223, 61.78426888681228, 64.61428250035932, 68.68760508875694, 64.3533193680548, 63.263245628726104, 65.66637200693931, 64.4776192788155, 61.44100658355221, 60.94343039297289, 61.527318339194025, 58.85949080990207, 63.432735166242054, 63.445698599661554, 63.380728460127315, 57.66898478231123, 51.12576923062725, 49.215618102781235, 48.0432608819777, 46.089363559599846, 44.956473227470156, 44.509577981887325, 46.33205236927156, 49.2550261559025, 50.858138069029785, 53.35562098410822, 55.68116288031302, 57.203603406106275, 61.664679742628536, 58.69382166093396, 47.176989739941014, 44.33545612519787, 43.53597510245539, 45.26487742700885, 44.15892201085245, 49.39415654828472, 54.16452354000461, 57.044951377376435, 58.07119638689103, 58.774810760251945, 56.95226969257478, 59.04872555886546, 41.87301958760908, 47.97427423538701, 59.74130630493165, 58.992816094429266, 60.77920075385802, 59.19822277561311, 57.08705017643591, 54.6822528685293, 60.832325335471864, 58.67983056652931, 57.4177412832937, 60.033209093155406, 57.75317453568982, 62.458963624892704, 72.97907029428791, 56.03274060833839, 60.10412946824105, 56.81518677742251, 57.677260983374815, 56.223728656768806, 56.65364788424585, 49.150667575097856, 44.65840055096535, 44.3532911423714, 43.3258145086227, 42.838436480491396, 44.142118577034246, 41.26156522381691, 41.21727774220128, 42.34110739923293, 43.584796843990205, 40.95463975783318, 41.587757372087054, 41.20491050904797, 42.61999184085477, 42.33478846088533, 44.435358893486764, 43.314129767879365, 42.03796309809531, 40.43079545420986, 41.582391569691325, 41.078214030111994, 40.279388043188284, 42.46974152903403, 43.3156830264676, 43.08315707791237, 45.39174649023241, 50.00313197412799, 54.40915784528179, 53.44870667303763, 55.603507795641505, 54.91153109458185, 56.4850369576485, 54.513994955247455, 56.61631084257557, 56.23388367314493, 50.29683120789067, 12.167177565636175, 0.42850634684005096, 2.6054807199585825, 4.695332540619758, 6.335020065307618, 6.514631279053227, 2.068792860354147, 0.4166200943291188, 0.08544560131286422, 0.44204587837861437, 26.58749007409619, 52.87577390670777, 19.196414985964378, 43.22428003434212, 19.8423057986844, 0.040881600260974905, 0.03829618375147543, 0.018226059093590707, 0.060059830035653815, 0.040270909441695105, 0.029339654476291714, 0.05385128878838113, 0.04883157810376537, 0.06766201162170019, 0.05654385418541009, 0.038253340284310045, 0.03441780234777159, 0.025320466112105117, 0.015815214869836648, 0.020059566051068328, 0.058045386516999815, 0.03349398075032138, 0.007157248253333233, 0.049222030136133396, 0.02558926721253703, 0.03691834397614002, 0.14645204789215518, 0.14598217552467702, 0.10501927801317747, 0.21999618218791103, 0.13724672007224253, 0.14002389605006865, 0.20128203315600274, 0.1213938864548841, 0.10272577164634582, 0.21656917978919324, 0.15318036830473333, 0.28138777181025476, 0.08042903541917763, 0.12818560830407566, 0.10399505676281068, 0.27715011049182187, 0.12429727541823542, 0.06832362047486729, 0.10791891314569982, 0.32355328180616905, 0.222032459212407, 0.1690079746467452, 0.1498067622343379, 0.29411865157946465, 0.2247321530575714, 0.14297338052382394, 0.2921099996855182, 1.4678527775310701, 51.92382643299719, 47.66994145608718, 48.62278715256722, 53.77833481757872, 45.94594209424911, 9.894785746451348, 1.1356155213809784, 2.991992057331147, 5.0984565865608955, 11.05585438589896, 9.944842053997903, 4.214727955479776, 0.31770812287445993, 2.6422600496199826, 62.49987002341979, 69.31776523590088, 73.0740700998614, 68.15551988540157, 66.4904345235517, 70.06607501737534, 65.83692842914213, 63.59223834929928, 63.096301709451986, 62.673862441893554, 63.87904990103937, 64.75758629460489, 64.08052636731055, 66.76888358208441, 61.5743044114882, 52.10565966944541, 50.331073499494984, 52.094186736691384, 50.22935075144614, 47.1844304761579, 47.43901583456224, 48.949673560357866, 54.19220762868082, 54.654855112875666, 55.547441436398415, 59.143693985477576, 61.13841141423872, 66.89170083691998, 61.81439268973566, 50.81547052629533, 47.508645749861195, 46.53971441330449, 46.50906109040784, 45.02023527699132, 52.42154382890271, 53.583294960760306, 58.43572578122539, 61.176783961634484, 60.66474599222983, 57.534796576346125, 61.6589883835085, 40.99365949630737, 49.73340234448833, 61.095147671238074, 59.95926849303707, 63.0071383906949, 60.134763179286836, 57.27798723405408, 54.05504234375493, 63.44386293042091, 60.93213788924679, 61.02196016619283, 60.828151933608524, 60.83784411030432, 62.73642424614199, 70.87588756315171, 57.961636743237904, 62.051378373176824, 59.330371349088615, 59.054660104936175, 58.62678835468908, 58.542692738194624, 51.39365142391574, 47.90438152128651, 46.799069373838364, 44.9097538763477, 45.04659360454929, 46.94924516062583, 44.26756381988526, 44.02072906494141, 44.74354344029581, 46.77497425386983, 43.70788474236765, 43.79341594634518, 43.26473928266957, 44.928930344120154, 44.61017500969672, 47.732797438098544, 46.50938272476197, 44.90574521403159, 43.53643794213572, 41.4504155805034, 42.239820034273215, 40.41796145900604, 45.16562969453874, 46.292177554099794, 44.922925195386334, 47.167250494803156, 51.64959392239971, 55.79587651837257, 56.564606158964104, 57.72285853662799, 57.52287257102228, 58.11786082483108, 56.42979821851177, 56.74676495213663, 58.116440926828695, 50.21629710351267, 12.869671121720346, 0.2725208863135307, 2.2109650508049996, 9.233283900445509, 10.135428059485651, 15.174586253781474, 9.305500618873104, 1.9302368500540334, 0.36796318427208935, 1.2305928959000496, 36.36207772839454, 55.48599358527891, 27.588722129021924, 53.431028550670995, 24.54421958615703, 0.12867575901890957, 0.09739648866196794, 0.08600545836792839, 0.1903534365156966, 0.11800364095477328, 0.05934909962478185, 0.17660479361732162, 0.16649263219967966, 0.19044472355275385, 0.1444222826150156, 0.07557646596744176, 0.11185966176731933, 0.08112146398953854, 0.10414294237571378, 0.17717896119481136, 0.15234268180304958, 0.09860695354760655, 0.10314084574460022, 0.1871628335286533, 0.22239005373370266, 0.11849031363043094], [0.12024063301543075, 0.032621686226658286, 0.041935511248847174, 0.052361144353785825, 0.019918891240752513, 0.02562019035160061, 0.0765743720976095, 0.033260906160238295, 0.04984548398023171, 0.05036643909050092, 0.08858822421320985, 0.05956591399867208, 0.020273436732109518, 0.00788480578546202, 0.06830093661142934, 0.04516734891841489, 0.03537015688996162, 0.04512933180517247, 0.06594807375222445, 0.0628390782813151, 0.06560043837394446, 0.04533079760749975, 0.05795621005217395, 0.032382383341750795, 0.06580657731260985, 0.05471817473129881, 0.018275921841362314, 0.07519154508988704, 8.250655647247068, 40.92839517901021, 26.62923978221032, 38.324459137455115, 37.668740826268355, 10.954126734887401, 0.08651364279249985, 0.883242808763058, 1.2301394944229436, 2.1815663960672196, 3.5431112973920764, 5.2132658323934, 0.10454196693195451, 0.1569755832033773, 6.985180868256477, 66.7716213964647, 64.6577698184598, 64.61917761833438, 63.01239044435563, 61.40766643708753, 60.26199702293643, 61.931659790777395, 58.66831841007356, 60.98317184755879, 62.317315070859856, 59.19364536962202, 58.86114605011479, 57.19676671489593, 49.001288029455374, 50.135543346405036, 47.95301891142323, 50.06228916106686, 49.45330589048324, 45.02545987406085, 44.47541413768646, 46.13107796638243, 47.028763371129195, 49.625980392579116, 52.41171044688071, 56.774103872237674, 58.068678225240404, 57.96000895961639, 61.008161267926624, 52.875644468492084, 43.671653809085974, 42.77843598396548, 45.28429315936181, 44.527052141004994, 44.69450204603134, 48.35326933091687, 53.271356705696356, 55.73287540866483, 58.875290116956165, 55.29523695668867, 57.4531053727673, 48.34500097459363, 42.114951379837535, 52.36207285235005, 49.99884874589982, 56.22891795250678, 48.26669869884368, 51.203793018094956, 52.36002929749028, 58.461915446865945, 56.82555360178794, 54.99003341121059, 58.84609591576361, 57.34538139835481, 66.564465338184, 59.561245979801306, 54.6592717016897, 57.946108079725704, 56.60547333378946, 58.15502920458394, 52.49931658467939, 52.02219947691887, 47.31541410569222, 42.86807390951341, 40.26827596849011, 39.9470103171564, 39.411567564933534, 40.055856089438166, 41.31966729317942, 38.56377078640846, 40.63258571009482, 39.83642693488829, 40.71759523883943, 41.44758755160917, 41.703267251291585, 44.44713384874406, 42.900304025219334, 42.40250818191036, 40.51896641331334, 41.91525174725441, 42.79672599607899, 41.56084206796462, 40.72700500488281, 42.12947983895579, 39.84588769174392, 40.217132183813284, 40.02769739397111, 39.419020068260934, 40.08463844176262, 42.92131223986226, 46.16479858275383, 52.09508103709067, 51.4083210883602, 53.72659091026553, 55.3608032964891, 54.713282738962484, 55.776013635819965, 23.600554197065293, 0.19967321787149678, 0.43099343596446904, 2.194458491379215, 2.144253133766113, 4.416373573964642, 2.700699442817319, 1.2615611115770957, 0.10194752590670701, 0.12685411684815923, 3.729678099193881, 41.56709824838946, 35.008710968878965, 29.191977208660497, 35.25273338440926, 1.8115956937113118, 0.040067402015049616, 0.15926964881439365, 0.05548412475975291, 0.04296841610583567, 0.014317738973805982, 0.020170625817451267, 0.026170988416960164, 0.17342938981469602, 0.06218388924495347, 0.04123377087976664, 0.004164674685471842, 0.08774440134725264, 0.013733701311021805, 0.058872412905217185, 0.01886964189789949, 0.07913296786887992, 0.02782431724030645, 0.10026409365837613, 0.0081042583746415, 0.07583763300170822, 0.04953545968859427, 0.12318972678434466, 0.009056359150206611, 0.03230106310858842, 0.008309861051759893, 0.02366581578708945, 0.03916909114547795, 0.05649190193282501, 0.015296085921656943, 0.009407289664170915, 0.009676791735053545, 0.04992691146570349, 0.06486661807303468, 0.06293911787290728, 0.021397435188954397, 0.007052145299366526, 0.11291867873120694, 0.022046577876373645, 0.021113013555746407, 0.048709716497650074, 0.05361367895778629, 0.07783416538469254, 0.021292703308826013, 0.02887028198118412, 0.009714480388098428, 0.06840183039105709, 0.05426712897455981, 0.07060051039462129, 0.03421203113130985, 16.074417195012494, 47.94866508053195, 26.788664517864106, 46.47197508042859, 44.92818117141724, 14.709123488395447, 0.1066052868601776, 0.5614673105939743, 0.7626327451679015, 2.338089313237898, 5.64153423232417, 6.2153411969061825, 1.972564004601971, 0.29785700743236854, 9.656313484714879, 72.49854072447746, 62.06823672017744, 67.90386061514577, 63.01558717604607, 63.80970239639283, 61.36141777038575, 63.69498091359293, 60.297659212543124, 65.4701828956604, 63.28545016627159, 61.571907843312914, 61.644001007080085, 58.96652444716423, 52.34449671160791, 52.36319857258951, 49.29442244191324, 50.70846434562437, 50.6098206581608, 47.59151366449172, 46.01183399077385, 47.26274451901836, 49.760572602671964, 51.35945227838332, 54.23914271016275, 58.332653737837276, 60.75656083322341, 61.578446434390166, 63.090237725165586, 55.3909545560037, 44.36055537193052, 43.93986155909877, 45.792538196809836, 46.60659866948282, 45.941015597312685, 50.7134771347046, 57.934823420739946, 58.78541292682771, 59.953326102226015, 57.692056163664795, 60.0918524496017, 51.70353043463923, 47.49820047809232, 55.30032034843199, 55.33643753297868, 59.661690035173976, 51.979206377460116, 52.83032148115097, 54.38945185753607, 60.51040464831937, 59.69091169295773, 58.1569903896701, 60.04465064694805, 57.71516676872008, 64.0759724955405, 66.68956541245984, 54.9993686522207, 60.14070949246807, 58.776544447868105, 59.70471843596428, 55.39908562937091, 53.648814232118674, 48.48488838441911, 44.56715837601693, 41.29867084564702, 43.52097595891645, 41.20794250119118, 41.61245653706212, 41.175073039147165, 39.971709482131466, 43.43896704335367, 41.443794619652536, 41.985807341914025, 42.780942378505586, 42.46474050706433, 45.565217233473255, 43.97194262473814, 45.139247832759736, 41.86884226337556, 44.3529930422383, 44.31892725729173, 43.50156414893366, 43.338107216742735, 44.01432775682019, 41.57308770764259, 42.10865597571097, 41.520920184350786, 41.63204485370267, 41.48374395985758, 44.45702606631864, 49.326632945768296, 52.206268464365316, 53.8752918858682, 55.35565322445285, 57.18175972661665, 54.55598785031227, 57.46024408648091, 26.966602840731223, 0.815082066241772, 1.5826946280656324, 4.794461621392158, 6.833334151775607, 9.719049834435987, 5.412526649813499, 1.6449428878484236, 0.06471297147894098, 0.09135865095642307, 4.219344585172592, 47.831366600528845, 41.571499147722804, 26.293645712637133, 43.68892400495468, 4.008217372240559, 0.056101771657385176, 0.1009160498036973, 0.05798367813469903, 0.12996044250265246, 0.01163060705537998, 0.02270518174965776, 0.021405873647440347, 0.021540693630794847, 0.027899642835461327, 0.027942227747952266, 0.051658151430949095, 0.08897496838002436, 0.024827496193709876, 0.02369444640803962, 0.060720247622098655, 0.018617432346687685, 0.058672674631159154, 0.020712451077997684, 0.009542563554620551, 0.0759284220816147, 0.0063361537796745625, 0.2359737119367046, 0.09295273437014512, 0.11715203463550537, 0.18568114287430243, 0.11286807096292896, 0.06939424367080774, 0.20385402014418957, 0.11185731753827104, 0.09016462631763951, 0.11542526479329794, 0.21061666129577547, 0.2050842654200331, 0.14904202262480415, 0.1024381056307785, 0.17638310309379332, 0.11684890130474684, 0.1225868998576076, 0.15863961810546537, 0.20657602246970902, 0.4403020477583332, 0.18020543750495682, 0.16591760660371474, 0.07620488789172904, 0.13336588718718098, 0.08968518551198706, 0.1435703009126648, 0.19925013815443363, 0.17596475780010226, 19.33852637967756, 58.33778812039284, 36.63033254684941, 49.36873566719794, 51.26276585363573, 17.767391589380082, 0.38512168452143675, 2.8373057899936556, 4.109193399067848, 7.141856022419469, 11.939288839217156, 10.871298043958603, 1.626063049320252, 0.19602924405086428, 8.19607831778065, 70.12280817954772, 65.40816237849575, 68.39952268908101, 64.7635365301563, 62.885517458761896, 61.97838306427003, 65.00291485940257, 61.87279678160145, 67.4550473305487, 66.79400244066792, 63.37346815293836, 65.3691347952812, 61.68311488243842, 55.320449952156316, 54.82302281164355, 51.39240803257112, 54.35647256912724, 53.899281101842085, 51.16638145139141, 49.67007567805629, 49.558378342659246, 51.56012858113935, 55.03597613303892, 57.97049345508699, 62.20682974784606, 61.807359880016705, 62.43799071158133, 66.68485072351271, 58.04062151139783, 47.65922554077641, 46.44432237071376, 51.72531527857627, 48.55250612381966, 47.69951612718644, 51.11262929054999, 57.68092447711576, 60.8494504036442, 61.76002471677719, 59.052663618518466, 61.975323615535615, 50.25278299085556, 46.31774748525312, 59.360828553476644, 55.96405206188079, 58.95787954330445, 52.956315855826105, 52.086871516320016, 53.89647268479871, 60.8663244401255, 62.39847675446541, 59.429823044807684, 62.90993421308456, 59.67842286632907, 63.729999834491366, 67.62472121946274, 57.45654136903825, 62.427674878028135, 61.00907518017677, 62.43311520545714, 57.23341734178605, 56.08646923495878, 49.67226043824227, 46.227956587268466, 43.439441650144516, 44.40855733809933, 43.34061361128285, 43.94257191688784, 44.00372559024442, 42.20746832509195, 44.4775479070602, 43.354043806752856, 44.35906487126505, 46.46574243422478, 45.21949560411515, 48.05488286479827, 46.65455748957973, 47.8396192673714, 44.54243959919099, 47.372527737771314, 47.050869849420366, 45.602777850243356, 44.18117361684, 46.56160516123618, 42.395126281246064, 45.13174826099027, 45.18568477322979, 44.6104181966474, 44.65048520795761, 48.07765614601874, 49.48765800845239, 56.87480288167154, 57.22320348985734, 58.902762397643066, 58.67760658264161, 57.29296676574215, 58.02135482911141, 27.150234483903457, 0.5606802012170515, 1.523839708778166, 5.840003221265732, 6.77426423757307, 10.18919590980776, 13.806314487611095, 7.084456057317796, 0.814198368499356, 0.4136989397868034, 8.414250842986569, 54.550131751645, 45.22766197881391, 39.14253219481438, 53.81549927496142, 5.9565726307130635, 0.4151965497482208, 0.3107918810940558, 0.09186724140759438, 0.21343243278322682, 0.06342143150827577, 0.10254549583600414, 0.14975811565114608, 0.22351214271639624, 0.1634937350548083, 0.2284622504826515, 0.19746864665179484, 0.2633725094699091, 0.12347786011354578, 0.2597872792713104, 0.1436411027586268, 0.12807249542205565, 0.2649481378255352, 0.14576046967939024, 0.10682636451336647, 0.15015154776553954, 0.06258134332094943], [0.00963989598301029, 0.04866894529831987, 0.04146037585732918, 0.017651973870552836, 0.03345207191042362, 0.03301325291695614, 0.036767658311873674, 0.07105987203577835, 0.04895955692195604, 0.04438489735607178, 0.04536584229959596, 0.028301239531907826, 0.010408854821787007, 0.025479266562709407, 0.08855374259573799, 0.043575422042199684, 0.023586052627633178, 0.1072999141028812, 0.046677603161022554, 0.010994284849373565, 0.032074316404759884, 0.03414527806002767, 0.016936694812630455, 0.05772346104945868, 0.056431863622199145, 0.055042436767009, 0.09046315545997313, 0.038176432717591524, 0.6773939416293175, 25.4855570485515, 36.757044715266076, 61.43221262962588, 52.94569799976965, 22.803524655680505, 1.3357973603471633, 0.07782055200227807, 0.318659910511586, 1.4452647057271775, 8.002536316071788, 8.201419115066528, 2.100736397889353, 0.17088885839668014, 0.019375857476505543, 10.968770903925742, 68.89005430283086, 62.38557607896867, 64.08187566264984, 57.74990720133628, 63.80378746217298, 59.80926921290737, 63.319135481311434, 57.8851701367286, 60.63245704097133, 60.05098135240617, 56.155075411642756, 54.08602514574605, 52.03373908996583, 50.24685628952519, 54.79779020432503, 54.22963880723523, 51.87878585630848, 43.88505035831083, 46.22742314492503, 46.07375644868421, 47.6896474438329, 49.1929115018537, 54.461905879359094, 58.236245801371915, 61.02398410920174, 60.470180742202274, 60.27201083398635, 55.15890713660948, 44.809270597273304, 42.21902362761959, 44.15919657676451, 42.21697222801947, 44.3962489404986, 46.32764362519788, 54.05840773736277, 55.54474284571987, 58.445637610650834, 57.17607228986679, 60.308622237174745, 52.204770118959495, 46.665406765476355, 58.56995321089222, 51.342742981449256, 51.65232389203964, 48.41406999095794, 51.0191866659349, 53.38690973097279, 57.521727238931966, 56.497180615701986, 61.749508842345215, 55.46642095811906, 59.96696810568533, 63.82198333740235, 45.2523023082364, 59.846390524218165, 56.993121177919456, 56.31083273118543, 55.81847721530546, 53.25143890996134, 52.213681743990996, 45.52349105958016, 41.2009685270248, 41.38440209050333, 39.82107477803385, 40.16131685626122, 41.28700571675455, 39.203242640341486, 40.23106444266535, 40.72017223604264, 42.61860332181377, 40.38964979110226, 41.763773733569735, 43.98349400489561, 46.1402210112541, 44.66062061248287, 42.53471166856828, 41.70546377858808, 42.471714481230705, 43.49075801910893, 42.008737517941384, 43.957351407697125, 44.91980691109934, 46.89979976223361, 49.68814211506998, 50.4987116782896, 47.714754535305886, 45.69895436686855, 42.593123605174405, 39.068175823457786, 45.17318417949062, 51.411772774111846, 55.7206807597991, 55.01374806127241, 56.00406808237876, 46.36849118817238, 6.952586462420802, 0.2405201373321395, 1.7388408751257005, 5.590115881735279, 6.43405451889961, 6.026391800372831, 4.7495225360316615, 0.5428723954866009, 0.10229807241909927, 0.11274509086844423, 15.222213633598821, 47.37051948424309, 17.758150485254106, 37.43629332511656, 26.45000315481617, 0.16717618181099816, 0.029250935749000603, 0.03164157440375177, 0.011068417262586375, 0.02816153956847566, 0.03540158947749484, 0.04581731706557255, 0.028668113293186314, 0.0083430795817666, 0.019643189603342645, 0.05345848486608556, 0.041723477263604446, 0.02886194502934814, 0.03901529899467865, 0.03058680731262411, 0.07941793725495377, 0.037985374219715595, 0.005857317225872389, 0.023865912207252076, 0.04295436988374399, 0.07172775514904531, 0.065608911306387, 0.0958498337516381, 0.026348908506934682, 0.026951545826910485, 0.020944995152193214, 0.0362139031471264, 0.034510989282881065, 0.03794937191771404, 0.08041971212913913, 0.1427562252408074, 0.06074038807362799, 0.037702117040152514, 0.04908939733380272, 0.024842362129880537, 0.03688713355410484, 0.03734723447010883, 0.009982411021126375, 0.07245088086253212, 0.08992031321770723, 0.04278607568853805, 0.07209177714802566, 0.06576626576603421, 0.02475250576202187, 0.09812496166916625, 0.030387507623902736, 0.050790392147797736, 0.016796146406822147, 0.03936525178892959, 0.1736468208893653, 1.0281089320778847, 39.59682110817202, 31.25242375558423, 49.72167838004328, 50.79838468182472, 22.95032132056452, 1.9722090301013764, 0.08269039673670646, 0.3218389302492142, 1.765334769602745, 3.2982561136445696, 4.340493361796103, 4.31062892560036, 1.414725867009932, 0.16449982300400734, 14.340942367430657, 75.40132214946132, 59.264051914215095, 64.54801013392787, 58.36140863357052, 63.416210220706084, 64.01369702431464, 64.98762546047088, 59.34724930794009, 65.05311727523804, 59.87371767720869, 60.42373203462171, 55.78850638481879, 55.34654548091274, 53.14214206510975, 57.72885584062146, 56.27549217593286, 53.80517951903805, 47.2705735698823, 47.791056402267955, 48.20849857022686, 49.22048968653525, 51.35753423936906, 56.815947717235936, 60.870156595783854, 62.28763841813611, 60.60907187000398, 61.45008294813095, 57.94855563871322, 48.44491550999303, 45.446369417252086, 47.01201092812323, 45.68541434503371, 48.48345279693604, 48.23782613200527, 56.74045385852937, 58.00857182471984, 60.098449876231534, 60.846155612699455, 60.628318940439534, 56.575416211159, 50.28811570136778, 57.983696153087, 53.40678045826574, 54.33586051387172, 52.01137373524328, 50.410866275910415, 55.41450446651828, 56.955525259817804, 59.20186273513302, 60.24271465116932, 60.77537252056984, 55.009280481646144, 66.15864907541584, 52.630162931257686, 56.904463844914595, 58.66277217864991, 57.461130542139855, 56.73194623762562, 54.692811889033166, 54.46852684020997, 48.51787159519811, 41.85649071970294, 42.52991460984753, 41.82901451664586, 40.846766733354144, 43.60225531362718, 40.241203769560784, 42.374745645830714, 41.90507319665725, 43.96319181688371, 42.58196838440434, 42.30524516874745, 44.91054619512251, 48.52462199426467, 46.888134633341146, 45.122330650206536, 44.24726555424352, 44.17288172629572, 43.5062200023282, 45.37620998197987, 44.06332992738293, 44.95025627074703, 47.563017645189845, 51.7885164291628, 51.45411083775183, 48.085849977308705, 47.61260817127843, 44.72890515481272, 42.13291583522674, 48.46262108895087, 52.919057261559274, 57.659288683245265, 57.78295317003804, 56.74774162230953, 46.399195501881266, 8.461365372903886, 0.8589942260615288, 3.6107491389397657, 5.626929286987552, 4.668943324396688, 15.853666201714548, 2.55639789565917, 0.42632508001500563, 0.1262532664282668, 0.029100186882480502, 16.97333324340082, 58.320459088971546, 22.116929446497274, 36.856025726564475, 37.170372316914225, 0.1457251530260809, 0.020307056500666568, 0.10037467845024602, 0.02157832003919588, 0.04143081635477082, 0.06605139603057215, 0.05662852605324119, 0.04255636805488218, 0.050341211815154364, 0.03459230951604343, 0.0406682103001062, 0.051460849316490274, 0.11953895776382378, 0.045715480997797944, 0.054290387403940966, 0.1090619010069678, 0.03686014427653244, 0.03151485580019653, 0.10515146648451205, 0.009201515574879464, 0.07490930297682363, 0.07735158361855053, 0.1811159942899981, 0.13915640872813043, 0.11662063774682822, 0.05636171295097279, 0.09876248471799398, 0.18173945196453603, 0.1770838130746157, 0.1267302097872861, 0.24198574014008048, 0.2691388532759682, 0.09896626410585257, 0.11783747648399685, 0.10092813867114245, 0.17200123338449388, 0.10404525084360954, 0.17020265812114363, 0.177829860138797, 0.24419411115588682, 0.10497355788585641, 0.13355576974009314, 0.12351824060803461, 0.08568355588302498, 0.24365524490994794, 0.1356247740407144, 0.12023651912327736, 0.10391601947166267, 0.11949087808569593, 0.23032022820365047, 1.3383133156645683, 49.02643434463009, 45.457999244813, 74.65944505506947, 64.44493024579941, 35.78953719908191, 3.0366423581877067, 0.3365973076753078, 2.047574063462596, 5.418033167239159, 16.57009397783587, 14.486097520397557, 6.0600310275631575, 0.6560708342059967, 0.13148374705305024, 13.903517684628888, 71.91879087878813, 61.140301996661776, 64.23217696528282, 60.326555313602576, 65.07621611318281, 64.94601695768296, 68.21415147473736, 63.01757974009361, 66.00652387065273, 65.50656680137881, 62.00547487505021, 58.76560103508734, 58.246067416283395, 54.95610883159023, 58.535506956038944, 60.037935549213046, 56.1667444629054, 49.60012020603303, 51.11936400013586, 50.60582376295521, 52.24306029658164, 55.36171720873926, 59.13541386204382, 64.10949699340328, 64.80403107981529, 62.57800755962249, 63.96257285148867, 60.24396588725429, 50.62392942367062, 48.63815499890236, 49.95253732127529, 47.86977052688599, 50.4253202099954, 51.144051398000414, 58.42608067297167, 59.41225474880588, 61.90568977786649, 63.898712742713194, 64.49103770717498, 55.19622064405873, 47.212871582277366, 60.414718427965724, 56.29316637592932, 56.02138926905971, 53.37204394801971, 51.52020669752552, 55.302359980921594, 59.040508193354455, 59.48060204905849, 62.19196788726315, 61.30798724389846, 57.80399668601252, 62.63588605388519, 55.3869733502788, 60.45455009706559, 61.711657970182365, 57.23905378772367, 60.57700257147513, 57.05706757883872, 57.25570817147532, 48.85292437768752, 44.10122394561768, 44.2956676021699, 45.402446716062485, 42.571083807176166, 45.64976392253753, 43.1524928154484, 44.729026748288064, 44.8743897868741, 47.91813335111065, 45.018042672065, 45.79402869747531, 45.70205696167485, 51.1598938511264, 49.59707252440914, 46.75646851139684, 45.50374192576255, 47.03869873477567, 46.062354118593284, 48.41806296379336, 48.21188357568557, 47.80559270612655, 50.233869321884654, 54.30039052040347, 54.24584996315741, 51.49444064786358, 51.15668535232545, 46.955434660757746, 43.92858082248319, 49.92823039331744, 54.52698192288799, 59.66735786007297, 60.58121911941036, 58.50273555324924, 47.83155095192694, 8.562785117856919, 0.9687463722882733, 6.782826771659236, 11.442571647705572, 15.212126278108167, 14.606548605426667, 8.012698196595716, 2.8200279945327393, 0.3103429842139444, 0.346840699954379, 24.344853355038552, 59.999927782243304, 28.96024750125024, 49.36600569755801, 42.53371146417434, 0.3171307683712052, 0.1843596412049186, 0.165943423766763, 0.11526932759631066, 0.20372510286829165, 0.31204716212326483, 0.1865978896497719, 0.1471323799341917, 0.18115606068843798, 0.08901267522765745, 0.16280338258272217, 0.16605525728194945, 0.15010853958947046, 0.163142682924386, 0.2594322741271988, 0.1758309682050059, 0.08947832645067284, 0.07471453278295456, 0.12431317174266424, 0.13053281743439937, 0.1752541193197812, 0.09614057944066103], [0.007032431941854978, 0.016785074521096486, 0.039847733963641434, 0.07536241334051856, 0.05303157470940102, 0.05202269820015758, 0.053919999214309844, 0.0464717208618118, 0.04124181097253196, 0.06412923929371661, 0.03872569860710252, 0.02405952369313567, 0.058085943211711226, 0.11553386541744394, 0.004659536841040057, 0.0847890563008766, 0.09731329151339109, 0.06414664481135626, 0.03961979982353026, 0.03938181077941291, 0.01580931982325931, 0.13788459552151544, 0.04205309808434498, 0.04116662710364308, 0.08709825980927675, 0.06403222574942535, 0.06203169438747629, 0.13243956431265802, 0.24447989259516043, 7.322643947216773, 44.05313176493491, 40.1715934661127, 49.95818945669359, 48.52630469106859, 7.356360641218002, 0.1167165979202236, 0.369906688048955, 0.5290603817951295, 1.67376630248562, 3.3290572608670885, 4.287395256180917, 4.483277932290108, 0.14372181778232898, 0.10711730172437046, 18.129634241903982, 63.69511819654896, 60.32107184010168, 62.4480123673716, 62.13869033321258, 63.100667307453776, 58.363730676712535, 63.23171369491085, 62.08291815173242, 58.896635655433904, 57.63472680122622, 57.840027578415416, 59.117327813179266, 59.89480433925506, 58.57739002473893, 55.8470477596406, 50.90974077101677, 45.63155628019764, 46.0857863580027, 46.006907493837424, 47.60916433026714, 50.525536767898075, 57.59648369204614, 62.05092730060701, 59.66607132265645, 59.18367078227382, 60.69520319661787, 56.81164095478674, 49.516962036009765, 42.54802811530329, 44.508201229956846, 41.698474114941014, 44.60528381409184, 42.727974691698634, 50.393431340494466, 56.39856830719979, 60.67498337837958, 59.7243812776381, 59.15064442542292, 55.767976699336884, 49.21136625351445, 57.90761001648442, 51.61242162027667, 55.01972967578519, 56.758328099404615, 53.64773950269146, 53.37607222218668, 56.10885420153218, 54.63061878758093, 52.73794181885258, 56.093804067181004, 77.60872225607596, 46.4811965727037, 47.79865011092156, 60.01504067451724, 56.436368188550404, 58.14198732376099, 54.01557937745125, 54.11359548568726, 48.08708160154281, 42.69652120528683, 40.7311587948953, 41.84288793994535, 42.194736311512614, 41.71355955062374, 40.360310462213334, 39.893336603718424, 39.72217613650907, 41.35509021820561, 41.95046678666146, 41.47265934175061, 46.33987357539516, 47.69446803677467, 47.09003079322077, 48.68969886533676, 44.37869241160732, 44.77567549674742, 44.19878505891369, 44.94281161215998, 44.92470987381474, 44.6759610022268, 46.26538776582288, 51.813976533951305, 52.996696656750096, 54.5176584489884, 55.44712681924143, 50.78425630446404, 50.96230445369598, 48.09508715906451, 44.11792147544123, 50.55052226589572, 57.67900251573133, 52.95373885862289, 58.40540585979339, 29.603063175755164, 0.5449607511681895, 1.0845988460125462, 2.162501960992813, 4.2410720644458655, 5.356226419248889, 20.516971118988533, 1.7148103516909385, 0.3902992437924109, 0.1060148552360554, 0.44870180348234795, 35.11348532092187, 37.702222178059245, 20.553723727503133, 45.905890772419596, 7.509950360944194, 0.2181800175458193, 0.03452422728221263, 0.06787668477984206, 0.04835230200701664, 0.059034168539989385, 0.011567436402753718, 0.040149036344260945, 0.060334192934416, 0.0775348624935554, 0.027485152879249186, 0.03564545441599142, 0.07263838854287902, 0.028162154354034897, 0.04960181439415582, 0.056053879670798785, 0.03211611224668882, 0.03513108766187103, 0.023308460668270147, 0.05770516686982686, 0.05303236761040265, 0.038286262912856, 0.04596445574274948, 0.04818055658571182, 0.05863718560806686, 0.04813302083001022, 0.025711960024050167, 0.08222375726026875, 0.05014669059986069, 0.03307485404694754, 0.057221209975860776, 0.043576969539806734, 0.03967024671334413, 0.05403282481335825, 0.017072108514126272, 0.01541201321918878, 0.025633838207971667, 0.04711338461587026, 0.18879049457609656, 0.02746401459819848, 0.06984761450439692, 0.041130601819003784, 0.034897235492544795, 0.04160542311447282, 0.024962009741894664, 0.025542005333268357, 0.07359599078735037, 0.059339619286718874, 0.06605526477458977, 0.037658201049893134, 0.04725829014674791, 0.17610697436236566, 16.808219109812093, 50.64474151980493, 47.87381056816348, 66.48142876163607, 50.924834051439845, 9.085175202738855, 0.07157617699234717, 0.2476594332725771, 1.1987115034172613, 1.5073923526271698, 5.760108463225826, 5.837021239342229, 6.266558035727471, 2.1278890054072104, 0.5729708868649699, 22.57841983149129, 65.18581890290784, 58.81166927276119, 62.573398774670025, 62.41395834953555, 66.00490785414173, 63.8505813383287, 66.72525898102792, 62.592316366011104, 62.43221698268768, 59.17199780864101, 60.47654674899194, 58.690487646287494, 59.94938019783267, 56.52339773793375, 60.02809040008053, 54.14100893082158, 47.673032283782966, 48.19227172482399, 49.68776948990361, 49.392791563464755, 51.807383029691636, 59.91664801874469, 63.096835151795425, 62.876982381266934, 61.03578652105024, 62.70859895213958, 57.34753477957941, 49.62369365076865, 46.1489482848875, 46.10217794295281, 43.56243148926766, 46.8070984655811, 44.91870472508092, 51.06311328949467, 59.620399244370006, 60.89141191974763, 61.90689002313922, 58.448771584418516, 60.327449614001864, 54.18892460484659, 60.47919827122843, 54.06643290673533, 55.88117630250993, 56.08225660939371, 53.616792002031886, 53.20031473713537, 57.78643231238089, 56.336437963670306, 57.930971653230735, 52.629790306091316, 72.05673279300814, 60.295305790439734, 45.94433784484864, 62.87534675290508, 57.058091317453695, 61.35858581912134, 56.63849184590002, 56.333535409742794, 50.04861185627599, 45.177275211580344, 41.85930698148666, 44.762841501543605, 42.436217031171246, 42.79353710912889, 40.93013671136672, 42.648676133924916, 42.23851388500583, 43.168974614912464, 43.267382960165705, 42.074076360271825, 46.871821495794485, 50.194916263703384, 48.30321596514795, 50.64142711700932, 46.287239290052845, 44.533092591070364, 46.53909860118743, 48.462789750868275, 45.62885768951909, 45.71140396979548, 48.33530487552766, 53.64589598871047, 54.76383032337312, 56.021401036170225, 57.02474724861884, 54.193090161969586, 52.395012917057166, 50.3813700522146, 45.284351994914395, 51.76458212637132, 59.14137978707591, 56.43183000626103, 57.81443411304105, 32.109800923255186, 1.0406866861927895, 2.893371168644198, 2.845946526335132, 7.6974994713260285, 12.99085961234185, 6.252061445866862, 2.157857874708791, 0.2782654425790233, 0.1102538418865973, 0.7165575820592143, 39.174064128629624, 48.63092999304495, 19.16939377784729, 51.60523976049116, 10.801365125563837, 0.34042532645886947, 0.12336742087838151, 0.03872491719741975, 0.012963028350514511, 0.07122988226793467, 0.018498543161718596, 0.040124349160901004, 0.13020917592990783, 0.011949668311694217, 0.04971997196515722, 0.06294641486038605, 0.004817081865058431, 0.017797817859137734, 0.013817396416749447, 0.05977786371424314, 0.05510852717223668, 0.046083750954318436, 0.03046181815255794, 0.02232439966211396, 0.059740539910572196, 0.045427803490911765, 0.03504713974712837, 0.06868915166705847, 0.14590725212568237, 0.10848975590159816, 0.10509807781706895, 0.1761945688556279, 0.16729143207832692, 0.16279354601377444, 0.11635350288763163, 0.18223434476362121, 0.13247601477609527, 0.14631674144296877, 0.1426306940735348, 0.13580239918683806, 0.17979185727815475, 0.08373909449625401, 0.23357824692803048, 0.19380740520934905, 0.19449224184838035, 0.10538820297487321, 0.1491242545025964, 0.13087590225040913, 0.18197258784165307, 0.09503662375913513, 0.24582289069169955, 0.22769127491741414, 0.17871945675822998, 0.22784032498396214, 0.2746911214724664, 0.47844112219829715, 20.40818222107426, 64.15949936835997, 51.990997022198094, 56.61428689956666, 61.21557228026852, 15.137093297896849, 0.3046848120227937, 1.5538185065792454, 3.106675542170002, 6.34828846300802, 12.414219225606612, 12.830635693765457, 9.318051222831974, 1.4391572076466776, 0.3190262844004939, 21.491948789165868, 65.55008157607048, 60.39027029468168, 64.14533176729756, 67.17997151036417, 69.93004721979942, 66.33110000241187, 70.93370329949164, 66.30800508683728, 62.935131519071525, 62.60873148518225, 64.84274095104587, 62.34913333769768, 61.89464438346125, 61.77849123554846, 61.88883535323605, 54.92642041175596, 51.21519534818588, 52.369270401616255, 52.87406767568281, 51.95327558825093, 55.973332389708496, 64.68099809462025, 67.5350558373236, 65.24048497599941, 61.55216655423565, 65.26763954470235, 61.272548629391586, 51.9767431289919, 48.15964544973066, 48.140272863449596, 43.69805136034566, 50.01686811447144, 46.39704996539701, 55.17307473767189, 60.18914291935583, 65.40099620819092, 66.12015493454473, 61.37717393136794, 60.80241726290796, 51.901366941390506, 63.56984161561536, 56.33253520534885, 58.331339743829545, 57.76874634527392, 55.224838256835945, 55.551736431737105, 56.42951188548919, 55.67824071453464, 58.580343569478686, 55.58918329977221, 68.49227889891594, 61.40439910273398, 50.77357569048482, 64.31379364382836, 60.024623024848204, 62.21638464158582, 59.17908160917221, 59.735893434093846, 52.16129456796954, 47.2888086688134, 43.01073443505072, 46.81000101950861, 45.2243907220902, 45.95211198253017, 43.818589718111106, 43.90237938973212, 44.6825074380444, 45.30448552100889, 44.75320031566005, 45.68705781813591, 50.8847866519805, 51.85027022515574, 51.62533406288394, 53.29849558491861, 48.55209819732174, 49.90118172860915, 50.569302574280776, 50.765864310726045, 47.96218156814576, 48.39364228710052, 50.00034316893547, 58.68345483656853, 55.92704449930499, 57.85227321809339, 61.00489393357308, 55.77422895739156, 55.71401273050616, 54.40345471905124, 48.723556764664195, 53.16835918734151, 63.299935479317945, 58.203117462896536, 61.599129092308786, 33.210135582954656, 1.6205204951186336, 3.422892612795676, 6.67302345075915, 10.478795286147825, 16.82594822299096, 36.449048442225305, 8.68872457934964, 1.3225097185181034, 0.2911033295094967, 1.5398380761185002, 47.69396205102244, 51.33343127466018, 30.651432314226707, 62.93698680016303, 13.487627794665675, 0.6137240065201637, 0.20393994456577688, 0.24296009672745583, 0.18027395640890445, 0.11548747879362876, 0.08518198279724007, 0.1338182774282271, 0.23281275655233094, 0.19621483651140045, 0.10452341228242844, 0.14333943265580362, 0.17400562582958132, 0.15836551184615782, 0.1999167878661425, 0.11349875284659286, 0.17003611060640506, 0.14023164377337502, 0.2117212528302785, 0.10530775608194452, 0.13540706717439238, 0.1439328137184343, 0.13074148446321487], [0.03068452757302552, 0.07773697947061832, 0.04780549909018221, 0.08920716196899453, 0.027600123524485577, 0.032384819501350005, 0.022220698170243733, 0.03460072882233128, 0.15117033745252317, 0.0573510235746301, 0.031401423076468135, 0.02170230179364162, 0.1321252690808427, 0.03409817514400329, 0.04970411011468499, 0.04109458802568336, 0.009740896057337523, 0.015332229949924496, 0.011968147310037768, 0.06380301224248064, 0.10315074360058193, 0.03724382792208945, 0.027318335318517302, 0.03333868323675087, 0.0177832257994, 0.02033749508911804, 0.05569810077788369, 0.10729436762630941, 0.10499346085012921, 0.6293202083437675, 32.77475445501266, 40.97458893252958, 15.829566178783296, 47.14661098295643, 30.24665547955421, 0.8832133909867657, 0.26054432735808436, 0.689173432127122, 0.5755135633291737, 2.311228922297878, 4.158603250980377, 6.315305742525286, 1.4726478750667265, 0.9120599108357584, 0.11414540000259878, 18.322812934075635, 61.460304644800004, 61.888196006897964, 62.239962008691606, 58.0478661291061, 65.1124039003926, 63.92500046760806, 62.66260916186918, 61.3896196119247, 60.00824320700861, 61.836867870823035, 60.841986133206284, 62.32646988284204, 63.81651555338214, 59.97907646240727, 54.684876934174575, 43.20670389359997, 44.29571467061197, 46.526437190271196, 49.533204570893325, 53.69381950747583, 59.228236752171675, 61.556877320812596, 61.23833379437847, 59.83962443567092, 59.132876088542325, 57.8611260075723, 50.12814183388987, 44.60951605150777, 43.817954294143185, 41.54303842975248, 45.11469379548104, 44.91908127261747, 47.46028684800672, 56.673306803549494, 61.19580745697022, 59.35001457891157, 60.58341172433669, 54.46704418428483, 50.071612634966456, 57.94700238012499, 58.842134321889574, 59.560857665154245, 58.198947983403365, 54.94749922906199, 55.06738255100866, 58.03707568876205, 56.564449264157204, 62.9063727009681, 71.14165167654716, 48.64048880915488, 39.70676122173187, 60.11369612909133, 57.780768409852065, 60.41413791718022, 56.42001582730202, 55.35083655388125, 48.92755923732635, 43.68130283970987, 40.19093467343239, 41.307288292915594, 40.05121200315414, 41.178140332621915, 42.80726932710217, 41.05089079949164, 41.066878380314, 42.00594086800852, 40.05018041979882, 42.51975174873106, 41.51385599567045, 47.33983870475523, 46.91175122414866, 49.752920058465776, 47.27968915816277, 48.71260550714309, 44.21015993241341, 42.90219460764239, 44.49122521185106, 47.12843079720774, 46.866761638272195, 50.64320395069738, 51.39735806372858, 56.667850786639804, 53.34021783644154, 53.599231550770426, 54.73217287371236, 54.19635749632313, 51.3804251916947, 50.997539104953894, 52.69661572671706, 57.25702608785322, 54.0123434220591, 54.48480859879525, 10.538417273952115, 0.5723035936394046, 2.659762155625128, 2.3601827986778754, 4.278871945796475, 3.0723589706805448, 6.3351004738961505, 0.17067035479891687, 0.034370810514496225, 0.05353692077821302, 5.680183306817086, 50.56246588307042, 21.55684244248175, 30.136242720388598, 31.682831318147723, 0.3553519367931351, 0.05362790138010056, 0.022376012920792547, 0.04247636166250995, 0.05412067211563549, 0.0628246681674594, 0.04759536117255207, 0.037662613716336994, 0.02606718350322016, 0.04526981700872702, 0.05084046748496833, 0.03706985318492498, 0.009352466497089594, 0.013258901082970684, 0.03846646211440525, 0.013751681394604667, 0.053069476909454794, 0.09355902401429993, 0.022564911050722006, 0.02588740181958964, 0.13712376296039552, 0.0373889479575859, 0.07352744123988575, 0.018474171989627423, 0.03719044691552559, 0.010354914571038418, 0.032415731149094726, 0.0064305429940202065, 0.06148731996936183, 0.016942212560905084, 0.05754815714974558, 0.05766679735613927, 0.09689790331908772, 0.04891684752017741, 0.02322567529195259, 0.03634527190438202, 0.03922345657502452, 0.0691937891045405, 0.024132928322820414, 0.03294651516743245, 0.011869466566901294, 0.037981091788218874, 0.08523470496818905, 0.05482843010536125, 0.003735573996128815, 0.06217027586253901, 0.012794107878430477, 0.004752320143574428, 0.06649654674073381, 0.06265407187804099, 0.028658458670120568, 0.08695087215352444, 0.9785827573749327, 45.25942141009916, 36.85120121125252, 22.626941511707923, 64.25819012426561, 31.139047645753433, 1.0618693237343142, 0.0946762559995536, 1.0584984142934124, 0.8416436828913227, 2.157330806216886, 2.5862633124474557, 6.672713583515537, 5.288252724755195, 6.7047245367880794, 1.0703307342144752, 23.638375651451852, 64.20616772867018, 62.33175331546415, 62.12258900365522, 63.102663793871486, 65.75160118841356, 67.856337178138, 65.07094444767122, 63.197294896648785, 62.093720359186975, 63.34547027464836, 63.339351377179554, 63.62022838284893, 64.8420427691552, 63.28202593711115, 57.57458117700393, 46.27116149471652, 46.38592220121815, 49.133322854195875, 50.43121553236439, 55.622515601496545, 61.1768114182257, 64.02542491112986, 61.19818833566482, 61.02919301679058, 61.30390797891925, 60.577955707427, 50.73503055880147, 47.33848548704579, 46.50006709560272, 44.38070066513554, 48.54857198653683, 46.57673766536098, 49.53729560298305, 58.581394764684866, 61.72515092357513, 61.524678584068056, 60.767319894606075, 57.443817200199256, 56.60249625482867, 56.28093250336186, 61.01448805101457, 60.42412427163894, 61.57547720016972, 55.6117683072244, 56.75795939660842, 58.905170732928866, 56.94799430908696, 57.64179098990656, 66.92533908351776, 62.034523948546386, 40.18428625599031, 60.06826723775556, 60.3790170146573, 61.32228036080638, 58.46670466084635, 57.32022331606958, 51.23257929278959, 45.344948691706506, 42.46166536884923, 42.947996124144524, 41.17305301850842, 43.204142585877456, 45.316672325134284, 44.07037450421242, 42.854694704855646, 45.31418162007486, 42.034868348029356, 43.704119267002234, 43.70408788804085, 48.44909283422655, 50.081638213126894, 51.0018458674031, 49.62310921761298, 50.13598265186433, 47.26541957547588, 44.82736841324837, 47.585022141856534, 47.04870077871507, 48.20179523960237, 52.374655815862845, 53.83272632475823, 58.01115274429322, 54.610712758956424, 55.51804327195691, 56.60622250649237, 56.38762489441903, 52.93479381069061, 51.19505005498087, 53.7254338110647, 60.15786986197195, 55.78762385153002, 57.60470497992731, 11.260919820877815, 1.3772548518834578, 3.1509613077486716, 3.2970517008535327, 8.417392661494594, 8.851806925189111, 1.4353169620998445, 0.3014725440692517, 0.12439319728723458, 0.03299313544806454, 6.439295786042368, 58.201674030673125, 27.93190206250837, 29.882096667443555, 42.00701559743574, 0.634352486700781, 0.021447686726347576, 0.03692942926840436, 0.10552160952600742, 0.08642297628666125, 0.028906950779679804, 0.04829718198086466, 0.051609845756883585, 0.0511713293681462, 0.04129964294993589, 0.04930449184030295, 0.007350218140580241, 0.036352212660976, 0.03382846239894148, 0.02736875539525382, 0.03615066258897705, 0.023801068610121167, 0.06832138349812839, 0.031634357855505044, 0.07828644837342924, 0.06800819909380329, 0.03355951191136434, 0.01576812057230141, 0.1694254619219611, 0.17356668809248557, 0.08748227670308083, 0.25105015374720097, 0.0680528007327549, 0.16330045107151234, 0.12181750243349422, 0.14247937638673092, 0.16339357671958787, 0.1292923985109214, 0.13410022842787928, 0.10923165076922987, 0.25206851442494704, 0.11984962939975724, 0.10748795038389583, 0.13573171991494395, 0.1249129189959457, 0.15637104790056908, 0.1298048500452311, 0.1581955016140015, 0.11350666653485068, 0.08783640084607948, 0.16256220278240022, 0.12894877743336464, 0.10514415800571443, 0.17274459914094017, 0.17778181110418614, 0.16094189617903004, 0.1724157175950466, 1.727749270296866, 49.8207966742977, 54.257895561956595, 24.894987344741825, 58.399671354601466, 45.66085246301467, 2.375521227236717, 0.41808954289843964, 3.8539657525477873, 4.877592334824224, 9.231734564227443, 11.839093854350429, 11.143404629922683, 7.479835383353695, 4.226188630827012, 0.5554097614461376, 22.588925899997836, 66.20931040856146, 63.782202659114716, 64.62209193937241, 64.42789931451121, 69.41001153761341, 69.86413571142381, 68.32033003530195, 65.7065841459459, 65.47084185384935, 65.46757451949581, 66.22420757047593, 67.02483392530873, 70.3934124977358, 64.79833187595491, 60.5981598361846, 48.947590781796364, 47.40022359355804, 51.62170587047454, 53.264512169745664, 58.11797849593624, 63.169304863099136, 65.80778521876182, 61.55649292853571, 60.620113342039055, 63.40760454054802, 64.25920209577008, 56.741340314188314, 51.38051540620866, 49.562390927345525, 47.042224945560584, 50.35385854782597, 48.297626587652395, 52.242103238259595, 60.97255791387251, 65.74306218854844, 63.17804782621322, 63.745548109854425, 55.43431635825865, 53.508864064370435, 62.741931253863925, 62.94960506500737, 62.25002681055377, 62.96212919296757, 58.12055157076929, 60.14398074919178, 60.706366262128284, 58.98938009815832, 60.42957636617846, 64.60980315362254, 61.17079450238136, 47.74662771532613, 61.681600847551906, 60.87487520710115, 62.704115683032626, 61.13250040238904, 58.32339694423061, 52.51379797535559, 46.25897469059114, 43.627385939321215, 45.37046763204759, 43.29543575163811, 46.36208595768098, 48.954415705896196, 48.07957810740317, 45.69428674636349, 47.798975667645855, 43.54168215105611, 47.32452184923234, 46.14253913202594, 51.152837507186405, 52.95101673372331, 54.312538100827126, 51.26928483286212, 53.63646268844605, 49.19546104246571, 46.03617229769307, 50.23623843346873, 49.86222867042788, 52.208535594324914, 55.64479074170513, 54.5683668505761, 60.484905319829146, 54.17584350032192, 55.44258471458189, 59.50641908953267, 59.115292103059836, 57.669039695493645, 54.11782772310319, 57.156605566701586, 62.91856342746366, 57.96589251487487, 58.225761305901315, 12.893931961828663, 1.8163215368986132, 7.424595663624426, 7.172788323894625, 13.033280045755449, 10.959098339080812, 19.700872975011027, 3.29993145600442, 0.4599910896391638, 0.22919167343887592, 11.07297258992349, 64.82684750710764, 31.64553350017917, 41.83295649866904, 48.59491479012274, 1.0421552461001182, 0.106385258747445, 0.2466465884278859, 0.19526064335819215, 0.17106571745487953, 0.19616234416682876, 0.173917587005323, 0.15096027614368548, 0.14546733379604357, 0.10396419108034143, 0.16920332706743674, 0.10556620350407978, 0.09128158251124044, 0.1889101115445937, 0.13665500908128678, 0.1030738513556219, 0.16345578305903943, 0.12713389215810647, 0.10612663512508716, 0.1895838705522399, 0.20185161952770528, 0.09099127349233435, 0.13768876812631084], [0.023019245239875974, 0.047523747273390336, 0.04251781468009276, 0.07985747254063046, 0.056754903747670116, 0.043382884994629896, 0.05332751830499019, 0.06890223902319709, 0.021686985780815446, 0.05197471045258065, 0.022516486633028236, 0.04184448468168417, 0.02703508388461365, 0.03132058547869806, 0.04548418756213881, 0.029352848425567634, 0.05670632994283111, 0.03191867989728288, 0.04004089537286951, 0.0743039402990572, 0.06524562475181396, 0.04461822858560951, 0.014666321428282367, 0.04498176794919757, 0.0640113307012906, 0.04308644727232956, 0.05256033870541761, 0.02884974699437378, 0.08010330249465282, 0.061154443274943106, 5.718039572238923, 48.75995635986329, 42.30674743652344, 32.704444008488814, 55.42848771618259, 10.373836582706822, 0.1866244882225029, 0.6183923011825931, 0.513065691676832, 2.481203362826378, 1.9767913390551846, 6.080262612911963, 4.813973942110616, 10.183447676320231, 0.745964142824373, 0.3150600020683581, 27.734267557820967, 65.48933582921183, 64.0053423758476, 63.05676421811504, 60.43835070825393, 67.20828317826795, 63.0533556784353, 62.978120696160104, 63.10604095458985, 62.917465163815415, 64.0857901880818, 65.51907523985832, 59.19483777015441, 61.47596274652789, 55.26878841461674, 47.83936823568037, 44.666480633520315, 47.77404508283062, 49.15315828015728, 58.45021501664193, 58.15422119632844, 62.62166353964037, 61.28546499436902, 61.95099707572692, 60.876518680203354, 58.64405855055779, 47.034274301221295, 45.092877572582616, 44.012417562546275, 44.92481970017956, 43.030875805885564, 44.15635678075975, 42.1919475063201, 48.23297416010211, 59.95638162859025, 59.54871008473059, 60.36629284581831, 58.62178733271938, 51.28217374124835, 61.395028560392326, 58.07840962563792, 56.787420318972686, 57.583304528267156, 57.792574744070734, 54.00259240981072, 58.33271649576003, 56.26385058126142, 61.74308400000296, 45.76933737724058, 45.59094405943348, 60.004010969592684, 56.73976352137905, 58.88431549072266, 60.19034316462856, 58.33148487152592, 53.95372359983383, 43.54784811696699, 40.98515579777379, 41.07166367192423, 38.73039307132844, 42.235830983807965, 43.71308972758632, 42.180992326428814, 40.29356348899103, 41.032267385913485, 41.69555979390299, 43.055139587771514, 45.64809299284413, 43.851467024895456, 46.85300196370771, 52.267386836390344, 53.4122835436175, 51.46108088954803, 50.89560454891574, 48.887790326149236, 45.362116905950735, 45.87014229066911, 47.407483900746996, 49.73896818776285, 53.37231851393177, 54.87725350164599, 55.59012859098373, 56.26301511641472, 54.65067778864215, 55.21015290291079, 55.882290255638864, 51.97311885895268, 51.32716724949499, 54.06890007757372, 52.30419043571719, 58.35588201399773, 36.79851985746814, 1.5008416267171985, 0.8409841118320343, 2.1657781206792404, 1.983773280535975, 8.82375511430925, 15.279147817242531, 0.4993582336652664, 0.38905171557299556, 0.06114380997455409, 0.010598354330737024, 19.98599986876211, 48.89370133799892, 16.333629969627626, 38.88666029899351, 11.735912965190026, 0.11775601069412886, 0.050019462547835805, 0.014024456576143783, 0.0315652126746793, 0.04354602341810542, 0.04453567112044943, 0.026273958294862704, 0.010296080933673488, 0.04361005304681678, 0.011059225165104915, 0.06424268542398369, 0.03638747951857025, 0.03548477896519246, 0.0959224588868599, 0.047260496479969834, 0.05591365110669887, 0.014695411701987108, 0.024325047852471474, 0.04747092168057158, 0.023699860734444474, 0.024601550051762212, 0.06948360782717505, 0.04844236713383467, 0.017012160218831514, 0.04323262833960114, 0.04293060583633281, 0.10695034052215277, 0.03147982834507862, 0.04387854005119974, 0.05478413490157935, 0.04018975008699683, 0.03196254417660736, 0.02931544992832407, 0.008534788296768262, 0.06533698839766365, 0.06731976184152788, 0.03065601761092342, 0.011429967670401019, 0.01806751336722124, 0.03961243005769868, 0.03227610396401536, 0.05133801860915077, 0.05501435964458412, 0.08379678857783157, 0.008258288012697332, 0.01517642777593386, 0.0460763888493661, 0.04872180536509522, 0.02296760899855966, 0.04351403158638747, 0.041805850867662704, 0.0340914833659847, 0.035137377243729374, 11.495952163973163, 60.95302451041437, 28.443457580381825, 40.13677066372287, 64.30752177392283, 8.927848935127258, 0.12155022967847125, 0.18127445191625627, 0.6944106543256391, 0.7809901730187478, 1.9435774438804196, 2.646471694592507, 9.062413688628904, 8.105607378867365, 2.6535373541616627, 1.0125916679539988, 31.400089225461407, 67.852399118485, 63.52236132467947, 64.12030312322801, 63.11497611384239, 68.39429809201148, 66.39708211345058, 65.52353105237408, 64.56189532433787, 65.263807389044, 66.12244559872535, 67.53748770683043, 64.09720036291307, 63.08933558002595, 58.62363869144071, 50.16300778235159, 47.136408898138235, 49.864393818763, 52.05436291233186, 59.33761596679688, 60.161415684607725, 63.61397220242409, 62.77189031724007, 63.1913564282079, 60.47844517615534, 60.79464312522643, 48.168376645734234, 46.487378228095274, 45.43890906918434, 47.22167338094404, 45.596164734132834, 43.965462869213475, 45.55922385184996, 51.639831143040816, 63.05272417683756, 61.05373920932893, 63.84952622075235, 61.06545532903364, 56.77887739673738, 62.753110008855025, 61.1960937899928, 57.586371821741906, 59.66808349855485, 58.98706982212683, 55.11376065592612, 58.241486087922134, 57.6206180357164, 62.75103507503387, 57.73358621904927, 43.70480960415256, 60.1145355163082, 58.95760105502222, 60.47437767828665, 64.15788335184898, 59.95580896254509, 57.51560049672281, 47.53134842841856, 43.98194074630738, 43.79951130959296, 40.572820555779245, 44.87845728474279, 45.28514823605938, 44.08706418929562, 43.27944424844558, 43.414318869190836, 43.00130897952665, 43.51131908355221, 44.53645406230804, 44.571637722753714, 49.026477490701986, 53.964886665344245, 54.4377911475397, 52.97944999510243, 53.40964378849153, 49.435149238955596, 46.38911501053841, 47.95168530556464, 49.60468584491361, 50.835462847063624, 54.634549002493586, 57.20828671609202, 57.281317326330374, 56.98069903158373, 57.20123821689237, 56.724328994750984, 57.89668621555452, 54.18439818966774, 54.00697369729319, 55.81630029985982, 55.08242484061949, 60.597885270272535, 38.654028446443625, 1.8593500602629878, 2.126587513954409, 4.088209699238501, 3.1996028654036985, 4.833152371068155, 1.3456673920154574, 1.1986439651058567, 0.38927476973302905, 0.1062650595521254, 0.03137159161269665, 20.343737679143107, 61.63507761493806, 19.16895055001782, 42.57481790358021, 17.924917897870465, 0.014252184830125303, 0.06502451645510812, 0.012160215128753937, 0.1112322127746959, 0.021215496967817028, 0.10083882048005059, 0.07026604406775967, 0.02765887863783827, 0.007929163712692719, 0.058621706801556775, 0.04629371267172598, 0.03293400495162895, 0.011285654900054778, 0.04530766941306572, 0.036538379687455394, 0.04333133876864468, 0.008762801918501576, 0.052936947528993895, 0.0389519167102633, 0.027567277504732052, 0.033583138062949144, 0.04182381562948708, 0.022551535155564066, 0.0743039786034534, 0.10945575446971964, 0.17451613150056333, 0.24323449410017461, 0.19268061244680038, 0.12323191524633478, 0.18255528963861928, 0.10298287075373436, 0.18273941121034085, 0.15761944946021805, 0.08410814203201764, 0.2059855372194321, 0.0965831560953971, 0.14076667957969252, 0.11773253009924967, 0.14354832951099644, 0.17325726517986867, 0.1466264707907554, 0.10773744989907551, 0.11286756534489895, 0.174916289866932, 0.08498468451322087, 0.14614054122038428, 0.16842608490297872, 0.15704503673459255, 0.0860538904465014, 0.210804536698326, 0.1683703137020911, 0.17789157618197704, 0.13418011607662325, 13.783451972469209, 67.95405910861108, 57.57526759178408, 43.14855475579539, 70.61165317412346, 17.72378856135953, 0.43916547971387065, 3.249965362971829, 2.526650149976054, 5.709575097407065, 11.560118217622081, 17.200063890026463, 14.19170500770692, 21.13741751640074, 2.5073363992475697, 1.189375404388674, 30.820855171449725, 66.93641585688438, 67.38970064347791, 69.68800560120614, 64.27253815435594, 73.10220133873725, 69.41264737036921, 69.15959173633208, 66.92212273997646, 68.07904151178175, 65.76204253781226, 71.89328762792772, 66.10772886583882, 66.25064434543734, 60.666538515398585, 52.1422867621145, 49.91797731768701, 53.41563717011483, 53.77228652277301, 61.29509833551223, 62.72011110859533, 66.14424613214308, 64.32018710720924, 66.46140113953622, 65.23720587453535, 63.9178813657453, 50.82787306078019, 48.955557115616344, 47.7364452423588, 49.0050535048208, 46.59620046615601, 46.578404672684215, 46.60471200942994, 53.15938872675742, 64.04337759940856, 62.77916239153955, 65.06268785845849, 62.57972555775797, 56.27322896834343, 63.929126801029334, 62.01806960567352, 60.12175267742526, 62.04374936319167, 61.585883248236875, 55.49471301417197, 60.566039546843506, 58.93599271774293, 64.10451166091427, 58.38403286472444, 53.64948103504797, 63.175972892392075, 60.78314273588119, 62.234466768080196, 65.86190608239943, 62.77969191151281, 59.12089717003607, 49.0262774498232, 45.949821318349535, 45.445086802205736, 41.75488172038909, 47.32564364710162, 48.67936734230288, 47.5565771133669, 46.08709642964025, 45.547852900720414, 44.529080006384085, 45.83786510652112, 49.61766104544363, 47.56115844172817, 52.320852664209184, 57.55464376941804, 56.6509061474954, 56.50246797069427, 55.70690147338375, 52.316267413477746, 48.91117157474641, 50.44353177470546, 51.87649911449802, 53.36254004509219, 58.1806658160302, 57.42250696305306, 58.70327457304924, 58.164893965567316, 57.827817240068995, 56.8564461892651, 59.90443768039827, 55.40125862244637, 56.33690864809098, 59.73135132943431, 57.40091823762464, 62.599855161482296, 38.66354411648166, 2.1361225506951733, 2.2516189467522407, 6.417511922697868, 8.853658283910445, 21.7298170058958, 31.424906061541652, 5.786865401652552, 1.4182552647206093, 0.6323171443035526, 0.0824422761797905, 30.379735615945634, 62.14610753520843, 24.9698281288147, 55.44354569527411, 22.88157589973942, 0.22819995729913636, 0.1279086521976898, 0.17071371537543115, 0.22707071305522997, 0.16178045602094743, 0.1487496068641063, 0.2838238701224327, 0.09295863324716207, 0.10578418616205455, 0.12266227524847755, 0.1936876809885425, 0.11509029284840631, 0.09425290049083772, 0.1826254173272079, 0.128603424997099, 0.10688756727763724, 0.13011965089507643, 0.20799749861321143, 0.18831058645681029, 0.11059936286220629, 0.09069527244015087, 0.1116024707293799, 0.11259622466299804], [0.03988585449875363, 0.033995684071053425, 0.014118146256453568, 0.09418390661237702, 0.047232679827439214, 0.026044497724562406, 0.049598841973009615, 0.04686838203680612, 0.04254041044341941, 0.01849052796681081, 0.09650610297197297, 0.03681484932800935, 0.099807474611988, 0.13048617800156917, 0.02793114437090774, 0.006559034612315197, 0.06267720773335426, 0.08764072666845976, 0.017802351184429663, 0.06098149126515754, 0.05366109213942001, 0.02416683154390945, 0.01942370158259667, 0.06376040626257178, 0.014432054613867115, 0.01844496871795385, 0.03206687769101512, 0.054408399418236754, 0.07943425492774095, 0.019806552107536027, 0.05498288492221506, 17.600779110385528, 48.59889991821782, 29.262734805383992, 46.93043739564958, 33.65358306515601, 0.253276972160224, 0.12071231335041024, 0.35791094625188463, 0.4937726559658205, 0.6938195408832643, 2.6900021587648704, 5.628322218694995, 3.3036018138931644, 3.1131141128078585, 0.38260180683385947, 4.1637768572376626, 52.12989599474015, 62.09406945013232, 62.70105623429822, 68.27000602599114, 67.84322077228178, 62.43101673741495, 67.07403613675025, 65.15619716336651, 65.31834010154971, 61.24958315203267, 59.70489886499221, 62.06034491139074, 65.63509110481509, 56.39408111572266, 46.896120579011985, 46.92212197088426, 47.6474388184086, 56.07270563802412, 61.736655235290534, 61.32936416133758, 61.935311517407825, 58.11347169260825, 60.44892541823849, 61.66211059016567, 59.24578935869279, 48.24996194531841, 43.59981559938, 44.88436829659247, 43.72377818630588, 43.90438372089017, 45.41391572644634, 44.16321700619113, 46.27687246568742, 52.994111814806544, 59.711825770716516, 58.38436626618909, 65.16714842088761, 55.45983529859974, 53.387968770919315, 57.39929829874347, 55.05902398017145, 60.34162898217479, 57.68516063690186, 55.64941913850846, 59.085435021308164, 55.41949372137747, 49.1565981987984, 50.76873548569218, 62.02261171033306, 58.523167179476836, 57.72546691279258, 59.852505499316806, 58.10728219247634, 54.99305363624327, 47.11931520892728, 41.78136556379257, 42.45374610347133, 40.61875151049706, 41.627800849176225, 44.36533674117058, 48.39270876299951, 43.28526896815146, 41.678893643040816, 41.35680429397091, 45.085385845553496, 53.45831255758963, 51.9039321714832, 47.94435439571258, 47.838732811712454, 50.64183504350724, 53.656713885645715, 51.994880168668686, 51.87897413007675, 50.7248245516131, 46.899972346521196, 47.18715652342766, 46.915214677010816, 54.30637997965659, 51.70625648190899, 55.55774942521126, 56.611262752163796, 56.2431679233428, 55.32269354789488, 58.06705828635924, 54.07891388862364, 55.67172173530825, 54.0995063320283, 55.44156489833709, 56.251008741317264, 57.46960286171206, 13.426119146808503, 0.35343172208916757, 1.622926133774942, 1.8373130814683054, 1.8092202082757027, 4.468191025718566, 2.0504590892984025, 0.08592410749124904, 0.162452744139779, 0.07444177483839375, 0.8303321801847028, 41.63411978752383, 27.529523757196245, 24.787051562340032, 41.49133766851118, 3.867362117575061, 0.13600288439662228, 0.09461085507345778, 0.027524261667783705, 0.055408596151298097, 0.042961517484077526, 0.009088075190271822, 0.02132825361895225, 0.07781748765058095, 0.03450986696407199, 0.028113256877047882, 0.06820167459908032, 0.05098458011484435, 0.10928467937534857, 0.05977469594067624, 0.011809650421773475, 0.05163017773039399, 0.08701216684834612, 0.0736900817062105, 0.01119934360406572, 0.05549046413732633, 0.035505888517946005, 0.02737863409903742, 0.02911883346255749, 0.04705143491587332, 0.07524384591247767, 0.04646244353704876, 0.04318008619931437, 0.06279057342438929, 0.02304726682092634, 0.025990431069306312, 0.08786098460756964, 0.008580508424089322, 0.02510550950143126, 0.015450056187898643, 0.01850508172215233, 0.018045534304673636, 0.024403219464265054, 0.014879878970884509, 0.01216717599515593, 0.056380233126542265, 0.037250998505060716, 0.0370463227943307, 0.06907824772380053, 0.05524278791140645, 0.04820670699700714, 0.058942605711279385, 0.04153700763239496, 0.025165633996948603, 0.02246145662220736, 0.07454298271407044, 0.0556492971466674, 0.05824414802895439, 0.009503680762023696, 0.17982276126502023, 29.449792638901744, 52.709363429777085, 27.282945917498683, 63.88014031994728, 34.28930513320431, 0.3176839757830866, 0.140741674469844, 0.19901452015244192, 0.2612866665567121, 1.6090713417337787, 4.464961934474207, 7.413758645134588, 7.125767930861443, 8.045160222438074, 2.004533895561772, 5.818665527528332, 56.66029630168792, 61.1349989521888, 64.47989033114526, 70.36308473156345, 68.52892952580606, 66.43090078907629, 67.7784389065158, 67.43672201710363, 68.45782479932232, 63.548743186458466, 62.08516959221133, 64.06014180952504, 68.50392049358737, 57.787903201195505, 50.400617122650154, 48.234982413630334, 51.206017001982666, 58.98933302971625, 63.61072447992141, 62.40978887004238, 63.41947363268945, 60.558963591052645, 63.06792336125528, 63.746885638083185, 59.68425150840514, 50.696010820327274, 46.620087700505415, 47.2608264800041, 48.00677107226465, 46.48220069946782, 48.2472005967171, 46.59531793286724, 49.10081032783755, 55.25798620716218, 60.95404824902935, 60.796467027356556, 64.56107554897186, 57.51879330604308, 54.81664896011353, 59.86277426442793, 58.65594725455008, 61.38442247144638, 60.01409930567588, 55.937470159223004, 60.275176186715406, 58.993278934109604, 53.608955106427594, 49.71300994196246, 63.14922232781688, 60.876769711894376, 57.40778630779636, 60.14336101470455, 59.50921573946553, 56.51728276283511, 48.49903637363065, 44.52280029173821, 44.10884511086249, 43.41198113656814, 42.428658623849195, 45.459956507528986, 50.14242318368728, 46.274974038524014, 45.41273509302447, 43.15305763675321, 46.345749285913286, 53.68585317365585, 52.73015591406053, 48.600668907165534, 49.68053271693569, 52.75873430313603, 56.02690412152199, 54.74597961671891, 52.74476282058224, 53.49302553361463, 48.22065007302069, 49.139151496271936, 49.456486932693, 55.387644075578265, 53.33467552738806, 58.77152773641772, 58.17752399752217, 58.19231133307181, 56.24116359218475, 59.13265251344251, 56.62599909690119, 56.348440416397594, 55.60530031881025, 58.37537619375414, 55.80236804100775, 59.29442674882951, 15.653095802953167, 0.621890013496722, 4.012468486062942, 4.341589173962993, 5.261048636128826, 5.248621586830386, 0.9905667627050031, 0.2618582907222933, 0.160491559053621, 0.1131277824301393, 0.9799950557851023, 49.30670338292276, 39.05827968351303, 21.641143983410252, 52.535033687468506, 5.569496472035685, 0.0860102387565759, 0.026107734452272137, 0.04957284477929916, 0.08401265683313532, 0.03278315457845888, 0.0314140884250763, 0.018288391837549788, 0.06691081644666773, 0.06749640639510847, 0.04349950272890349, 0.06509504250941739, 0.028967644095480926, 0.07381683861416194, 0.044443595012830156, 0.03396680638674767, 0.04447847499602264, 0.05783986427911347, 0.0019983645301357273, 0.04412772930077007, 0.005360087379813195, 0.019821178641230352, 0.02779778953070843, 0.055058528443858515, 0.12847298320623177, 0.20634434215964811, 0.17457766368264155, 0.14119254785680002, 0.15271857050397705, 0.11755076041745564, 0.1630553948662935, 0.15968667643685497, 0.10954057572469597, 0.16176403109585086, 0.16084829555644145, 0.10481906093416676, 0.1566205627375072, 0.2432694277095218, 0.051110950148394035, 0.14402495877396676, 0.2731118158948037, 0.21514393449310334, 0.1125333441661731, 0.15468753904344576, 0.18109996773062215, 0.11425861247604895, 0.12804491625678155, 0.0897849148379699, 0.1473313789334028, 0.08135676023460205, 0.2062580040505817, 0.20856104821207064, 0.200597150551696, 0.10948288930399765, 0.3715621121227742, 37.5599774237602, 67.23468857426798, 39.91233656483312, 61.075018067513746, 48.09582064228673, 0.7893271095329716, 0.9980251495876621, 0.5981784277865964, 3.4458453424515265, 6.673544145399525, 11.388131110898911, 15.938557078761441, 11.20193031526381, 11.299241377461342, 1.6520135729543626, 5.6960679254224225, 55.528739575416814, 63.13802003860474, 67.62950651107296, 75.23335056920206, 71.66563326312651, 68.09619795891547, 71.97755582870977, 69.29698451872795, 70.35339647723784, 65.38874664614278, 65.45974546863188, 65.93977297506025, 71.88146560422837, 63.2787036895752, 52.12524798608596, 51.33339597332863, 53.49290001776911, 63.32878451193533, 64.58843408092376, 64.95057475182318, 63.236483297040394, 60.502446159239746, 65.63877028803672, 67.23100939104634, 64.22227690296789, 55.05571742211619, 48.445425418115434, 51.674665712541156, 49.95949952833114, 48.83548944227157, 49.26082341901718, 49.725840014796105, 51.93487967214277, 57.95916957239951, 62.49166834738947, 63.88180340490034, 65.84807580517185, 57.555761644917155, 56.9984281447626, 62.77771895931613, 60.57451971115605, 64.04551921352264, 61.97769664948987, 57.677512015065844, 62.14043186556909, 62.71333717530774, 58.130075085547666, 55.61583972746327, 66.14171228101178, 63.82823167308685, 60.85717747288366, 63.00828764515539, 61.313702137239524, 58.02258253097535, 50.42792466378982, 45.43452778170186, 46.83743407649379, 44.73001126320132, 45.7391429716541, 47.90993167508034, 54.2638732540992, 46.949394210692375, 47.29320956814674, 45.11530176285775, 50.67362585375386, 57.91174419464604, 56.75650419727449, 52.97407242559618, 52.12772300166469, 54.0970548506706, 57.321054858546105, 57.071337161525605, 56.73437026239211, 56.43097492956347, 51.3330743389745, 52.7287164042073, 50.57295037854103, 58.88932827980288, 54.43886195459674, 60.878585769284165, 62.92951468498477, 59.574334929066325, 56.84034878207792, 60.7388944779673, 57.928994778663885, 58.52727390104725, 58.77834089340703, 59.335078193295395, 60.24167130070349, 60.7070016860962, 15.494970352418962, 1.1575678014947524, 7.024598237006896, 6.581320397315487, 9.087375652405525, 12.678900764834497, 10.998501489239356, 1.6263720585453896, 0.7818681710670072, 0.23712154147365402, 2.431649854106288, 55.218401647383175, 38.25149520750969, 34.73810272832071, 60.61664596680672, 6.991795945552088, 0.32784576437646346, 0.19072270621695828, 0.15431338170122716, 0.13481019275082698, 0.08695878584178225, 0.15922630355963785, 0.09799153213539431, 0.21206139586865905, 0.08966180450853803, 0.18112783800930748, 0.3110328617115175, 0.14625841150841407, 0.19573794677853587, 0.19665691520898573, 0.10860288410537666, 0.23862713407124245, 0.16782801538225145, 0.11764935593331054, 0.1709082710646814, 0.157716911165945, 0.20693930136340283, 0.1692513761020476, 0.2090497969860031], [0.012801052465464079, 0.06452651333905036, 0.06361845783108185, 0.07618247981994383, 0.014323370677659349, 0.026099209808894706, 0.08999294601380826, 0.01959783719822524, 0.025394284429268974, 0.04860454028652561, 0.006520704839438681, 0.017264327635207487, 0.03249795536600775, 0.022556011024261677, 0.012322413179302409, 0.041118669999583114, 0.017198279364815643, 0.06457132182174152, 0.07503460431771894, 0.07701018419597419, 0.044504069993572856, 0.07026027542568984, 0.018947441957049796, 0.04789846002935402, 0.03649159086747997, 0.03694574311075192, 0.02935434038180017, 0.024273154971700524, 0.03017029871473149, 0.013018850304727114, 0.06568022643125827, 3.7150461875623275, 45.7933226708443, 36.85996770858765, 37.1641553601911, 59.32407202259187, 8.194132331878908, 0.19784128713992336, 0.08198361933952378, 0.21568606427359968, 0.6841635235374974, 1.1114880418585193, 5.229388734986705, 5.781902132495757, 4.739645027345227, 2.225051998130737, 0.02790290445479895, 13.023071096789453, 61.62296925821612, 57.83854884486045, 63.08764896085186, 65.17174151635939, 68.28294200281944, 64.5867435393795, 67.46760675984045, 61.98756141047325, 62.093053556257686, 63.64717898830291, 64.81940677089077, 64.18871318140339, 60.45817044473464, 48.27198605383597, 50.648448159617764, 51.94985528146067, 60.780193113511615, 62.80290842056275, 65.4095861988683, 61.05914423542639, 63.270533392506266, 61.895166058694166, 59.96346150675128, 58.315081519465295, 45.79158898322813, 45.4248316826359, 43.94392905696746, 45.37433901140767, 44.69308999276931, 45.63292518738778, 46.01567791354272, 46.33481371787287, 46.212678955447295, 54.48312590199133, 57.564583055434696, 61.26051479770292, 62.891828552369155, 55.260088597574544, 55.05284232477988, 57.14711343088458, 60.14009760272119, 61.66047888417398, 58.08323806332004, 59.77308534806775, 59.82156584339758, 61.43283628648328, 60.96233229483328, 58.35011612984442, 58.50060962861585, 59.363907614061915, 59.28655847426384, 59.46214729739774, 51.80709669666906, 42.7472335292447, 42.383088527187226, 40.19706926038189, 41.44446926732218, 47.38888794376005, 50.38402549682125, 50.163250969302275, 47.13869956231887, 42.04339950315414, 40.40484505314981, 51.48680379313808, 59.04228110467235, 55.88055264565253, 55.86299219439107, 50.932678791784475, 52.09786591991302, 53.83446785711474, 54.699762328978515, 54.00432217505671, 52.78931310099941, 51.33553758744271, 49.31239081967262, 50.05392274548931, 52.4922602407394, 53.43717882710119, 55.55511751482564, 56.34442390934114, 57.55184319711501, 54.16406070032428, 53.6732074522203, 54.808517886746316, 52.21953784265826, 54.548633406239176, 54.23003104425246, 56.033862406207675, 39.520201529226, 1.3317000769799756, 0.30085578200317203, 3.6460678760082494, 6.567986790210971, 2.573205742143816, 1.91586050535402, 0.325521943910468, 0.05471642805083145, 0.13315550412141508, 0.13340910986786889, 13.848624114067325, 46.928727242254446, 20.55652233862108, 38.239328015235166, 23.90240607723113, 0.0407607575517989, 0.012346001026491004, 0.05128678264877489, 0.04008915891209918, 0.04609453364185268, 0.0965986540541053, 0.03780998605033083, 0.05334103975685374, 0.018107974300942114, 0.04385845322582511, 0.029342174905562596, 0.023523480481197758, 0.0615416317727537, 0.017690067592587684, 0.011231881273429722, 0.019482902942165252, 0.002895752981966061, 0.013792846171605973, 0.02692273900573773, 0.014363295349833227, 0.057676396437830506, 0.048318831625604824, 0.008298921316201168, 0.028327179269023964, 0.010078967785492781, 0.03679253318677506, 0.08427910221320006, 0.052443981441038276, 0.00582458324647779, 0.06048608135672347, 0.09211281855260173, 0.022473867246580702, 0.03217411084821628, 0.09160867141139123, 0.04398054082787806, 0.01174416331078617, 0.03968525820622041, 0.025681215000428984, 0.035269190331981067, 0.02825184792820965, 0.0644936788106157, 0.03327066612039362, 0.041564318666895556, 0.02696026582270861, 0.08917939128173936, 0.01880859426643339, 0.010966182829091146, 0.046150450399445916, 0.02088265091691527, 0.0431046916562463, 0.02878601230951327, 0.011081925307911251, 0.03210653997807494, 0.08287747540781576, 0.11513616619331223, 6.967299763233432, 55.775731225167554, 32.75954938703968, 42.8389032425419, 66.58129230622323, 6.143194590845416, 0.03144043801923192, 0.25450424501492136, 0.05216942702029502, 0.9366038357538562, 1.7614787120011546, 6.434601689538648, 3.181615120941593, 4.201996922492981, 5.063979933338781, 0.09962609563503536, 16.649994619431034, 69.30718268117597, 59.60245832320183, 67.62217167885073, 66.40593882529967, 69.6353046355709, 66.41820015445833, 69.72881394047891, 64.47152783793788, 64.497184061235, 65.21859815043788, 66.6255444865073, 65.20053955816454, 61.7832176916061, 49.127329472572576, 52.27573364011703, 53.48729887316304, 62.14191452149422, 64.78973796290737, 66.44843378374654, 62.66265623031124, 64.00804096652617, 64.3292320928266, 63.87725737787063, 60.12988375079248, 48.642779473335516, 47.24493695843605, 44.69019920595231, 45.689250423062234, 46.5213498761577, 47.25727281262798, 47.09176055846676, 48.761497851341005, 50.427857983496885, 57.342647506344704, 61.21412100330476, 64.0402397032707, 68.19213913333031, 58.10410507263676, 56.69894733736592, 58.18226222069033, 61.80049965458532, 61.4558566770246, 56.17540505624587, 61.253976206625666, 59.88729692274525, 63.17048157415083, 64.64053492392263, 59.64041117698916, 58.04617558756183, 59.22131376881754, 61.51042076849169, 60.75410542949554, 54.612014985853634, 45.105087910929036, 45.4611018396193, 44.49980735778809, 43.369274370131954, 49.11709208642283, 51.035154634906405, 51.13942300119708, 47.0071981799218, 44.26082518792922, 43.40381476186937, 53.84482291436965, 60.53089511009955, 58.9020485262717, 58.311249363806944, 51.77383891997799, 55.02907276153565, 57.11434595046505, 55.76618809853831, 56.348526708541385, 53.298060201829486, 52.75580429261731, 52.54049754911854, 51.10927566405266, 54.789902317908506, 55.86281568773332, 57.17630370970696, 58.37959666405955, 57.512152733341345, 56.58820706029093, 55.64960741227674, 56.798905018837225, 54.82382689752887, 56.003699379582564, 55.603166549436516, 58.57946888093026, 41.60200734292307, 2.3373224898692104, 0.7070313093643035, 3.5781816993990256, 8.856149969562408, 5.683428577838406, 1.1835032485185133, 0.6353254183646172, 0.03402041721968882, 0.03826680427957927, 0.0249778735075867, 13.325128901389338, 58.402240507064334, 20.710153733530355, 38.17586798821726, 33.735764565006384, 0.07543946646394269, 0.01964347688631425, 0.03981971429781087, 0.01427120392045547, 0.040300580027002486, 0.025753520293942383, 0.012346773817684623, 0.1765836189470945, 0.0276884323947372, 0.04877986716887644, 0.01838318372686063, 0.03406937406848996, 0.09996412427074487, 0.038016902568239364, 0.04250019848827393, 0.05466820281599799, 0.03595914443834655, 0.01595794279578953, 0.005818918983887641, 0.05918938178388823, 0.0637270124899524, 0.10241058775253835, 0.03987000797003989, 0.02799538467379828, 0.09966640718161099, 0.1644969118698951, 0.270283664426496, 0.1934294021057506, 0.09772402189311483, 0.09176920513592421, 0.1705271270005934, 0.13187178590845677, 0.1498249491616603, 0.18278468700666584, 0.13439599965368548, 0.11589954216634074, 0.12136060759545335, 0.09056001961711915, 0.13261679109306107, 0.23782730763477666, 0.15034936698934726, 0.15253481665445914, 0.14206060208380222, 0.14426100578519607, 0.16642074250886518, 0.20149344277958717, 0.15648179357090305, 0.1557427179068327, 0.1734588841997808, 0.12912580503090737, 0.14193962147879985, 0.17018759683255227, 0.18534266990759682, 0.18038556009771364, 0.2675147468764936, 8.74525377827306, 65.24828657027214, 49.22976609199278, 48.57520095763668, 76.70203501178374, 12.60098974550924, 0.34924692083751, 1.1839738103651232, 0.3690243079777687, 4.237625281656943, 5.574693612514004, 14.798715326093859, 16.598825339348085, 12.15221078165116, 5.676193275759298, 0.1475122829358424, 15.18101207671627, 69.78328781743204, 60.68949614801715, 69.61745000654652, 67.150922436868, 73.9471112528155, 68.66236855906826, 74.397822964576, 68.45383967122724, 65.67740563423403, 66.30292953983431, 69.64059199056318, 67.75546950678672, 65.02941439228674, 53.08843305034023, 55.652255012143044, 57.363251716859885, 66.06495149673955, 68.00937237278109, 69.91228672765916, 62.29780912399293, 69.10912652169505, 65.24906712193643, 64.45365359706264, 62.78405358714443, 50.380718938765995, 50.14489427689583, 47.30922460556031, 47.29113071195541, 49.173593828755045, 48.77310022231072, 50.82104421431019, 52.193328565166844, 49.67763016300817, 61.13842710371941, 64.2849289217303, 66.53751865510019, 65.46408361004245, 59.01206316486482, 60.169079995924434, 61.34681086386404, 63.45215482096519, 64.66955261845743, 57.642995157549464, 62.81800954572616, 63.4108522630507, 64.80933804665843, 67.97079193976619, 64.1630648028466, 60.26596646155081, 62.70975605134041, 64.5850137741335, 64.44129813101985, 56.86336525024907, 48.38777049895256, 48.12001382150958, 46.471759350069114, 46.132937169844105, 53.770066461255475, 55.11611015565934, 54.20983868260538, 51.613700312952844, 47.209113951652284, 45.56777069645543, 55.77546842636601, 63.02007828989337, 59.9066577419158, 60.53818287387971, 56.07159168489518, 56.9416400694078, 58.83998486303515, 58.764259584488414, 60.985199712937884, 55.74376390826318, 54.834083895529474, 54.33604094289965, 55.27629975349673, 56.11433375266291, 58.4305678644488, 60.857675613895545, 59.94383004403884, 59.191009536866225, 58.08274384467833, 57.29509269037555, 59.227628784794966, 57.20135981036771, 58.93978957206973, 56.1142356934086, 60.3353924136008, 43.319177858291134, 2.5516966898595137, 0.6244965510502939, 7.996034006918631, 12.013157856079841, 8.653211439809493, 7.644703388214112, 3.3716772448632026, 0.2555637752577182, 0.5608125199233333, 0.2327963929142683, 20.49717099435868, 59.48536380644768, 30.098664452952725, 51.39489873763054, 37.77741009189237, 0.20582107346384756, 0.09064629643915162, 0.16740279061900032, 0.12951485512237396, 0.12289161132949016, 0.16122145698435847, 0.1364443808673851, 0.414675701890261, 0.11651559943153013, 0.24697232901328997, 0.08402325949000736, 0.2591554405948808, 0.2956370072018716, 0.06936204499535023, 0.12688513574821333, 0.13165587168787757, 0.1156489011801539, 0.059595304961887106, 0.12088230826080808, 0.13190239878191104, 0.16775546685582207, 0.18258023346143384, 0.15993015450094977, 0.10089469893324761], [0.042267568229186925, 0.0892900373606432, 0.0457647787557254, 0.05685395891627958, 0.015040136903764741, 0.06122222290404382, 0.02107483556403989, 0.01886726127967479, 0.0036103894836419536, 0.04581865388900042, 0.07257725472652143, 0.013234903378742597, 0.03695850996601005, 0.03573276162628205, 0.06206459786382414, 0.025557656509561405, 0.05924940477275561, 0.022343572927638892, 0.039146882256553064, 0.023092554108570182, 0.05315766129041872, 0.03444327094081429, 0.045556134709547606, 0.0702133065750522, 0.04193455746938144, 0.04265758742187773, 0.008104575343520172, 0.027277608169242743, 0.07777690797323182, 0.06451680700504972, 0.017313359177581245, 0.09182408001394042, 22.739946957557436, 51.35284700701314, 29.24975960485397, 51.91616212168048, 41.880138689471835, 1.3295650818655569, 0.029109973655713182, 0.041951047511951584, 0.13055432918331317, 1.985147826133236, 2.9134642452962938, 4.109207372511587, 6.510938857832263, 3.0840871026439056, 0.3995345256501629, 0.2015522936539304, 21.37744107554036, 59.21493207254718, 65.32263117451822, 66.69726894747826, 62.56800551568309, 65.91859217612975, 61.36646193842734, 66.04354320033904, 66.12490884719357, 62.86221857993834, 61.73488232397265, 67.0503842446112, 62.509915213431086, 49.975738140844534, 49.44989342843333, 57.418125675570586, 64.3653767339645, 64.98148695115121, 60.70225169581752, 59.55350322108115, 62.94556894610005, 60.62439264789705, 59.59073435875678, 55.51478378234371, 45.899081537800456, 47.352488348560954, 45.62646504371397, 44.12452674681141, 43.73008143517279, 46.22842334931897, 47.48155393908101, 44.96528679324735, 46.5759688808072, 51.73745501425959, 55.08463313502651, 56.213283384999926, 61.198392298913774, 60.530224384800086, 59.085968463651604, 60.66770345933976, 61.47059302176199, 61.83160012768161, 58.56981592793619, 61.619756837044996, 59.882903868152255, 58.26331800030124, 58.142454085811494, 58.9682581347804, 58.37368957458004, 57.4416010610519, 57.361470960801654, 51.127577443276685, 43.26670046775572, 42.62880932900214, 41.03580536380891, 42.10861282963907, 43.45795523735785, 52.170312096995694, 54.262959341849054, 54.614082074934444, 48.03996216866278, 43.686578427591634, 42.05110696054275, 53.95161336468112, 59.621881900295136, 56.79130738781345, 56.35413177551762, 54.533748011435236, 52.84382620165425, 55.05991435820057, 54.21072121589415, 54.48692275631813, 53.665409780317745, 52.337342308413604, 51.03437800561228, 49.86840248107911, 53.76861518429172, 54.021796334174375, 56.80050534586753, 59.670715408940474, 59.002512193495235, 55.139550239809104, 55.35132292778262, 57.7482754953446, 56.56584562793855, 57.06400232930338, 56.87934890870125, 46.9590118623549, 9.606530762487843, 0.16118019548875673, 1.3379573605714308, 2.0672947600964577, 5.515903167186245, 5.663660322466205, 1.0508663399565605, 0.32020679524829315, 0.16364287705190722, 0.08804935796727097, 2.7586277021515757, 40.84805719314083, 37.23318515285369, 25.644934715763217, 43.7850103070659, 5.232268735285729, 0.09771933343501822, 0.051146699641380584, 0.033263798142152454, 0.03065197649712284, 0.009660594721114444, 0.04117206632790547, 0.00827864392645537, 0.05946783559216608, 0.08093343536940314, 0.07252041866341907, 0.0631275448587633, 0.06638947063155713, 0.010632068902674702, 0.03246480674152413, 0.06602879643680588, 0.08495943425523658, 0.02245785792418305, 0.044679680328455665, 0.05698695944081392, 0.09263235640021102, 0.039004183058897336, 0.05758293371106829, 0.019816403998242273, 0.04333707293675792, 0.11453015234081015, 0.04516629937795862, 0.07345624102820313, 0.06316352417812714, 0.07214092168836825, 0.06860695809366242, 0.026602544896905462, 0.027956655098786278, 0.06332930943538105, 0.0420252890926936, 0.013705931581376542, 0.03701637641737058, 0.05761658412314231, 0.02567090537218798, 0.019680614913663557, 0.05691652148661595, 0.05632487178269414, 0.024230857342181188, 0.044165049274001396, 0.008499865221130031, 0.05511918345526342, 0.08879410268198099, 0.029783462617366068, 0.050255567015659426, 0.12427001034901028, 0.06076019527691026, 0.037199149674345414, 0.03691039581392561, 0.03527553353999411, 0.05159636260941625, 0.0392207331324537, 0.035987102817143166, 33.20429909613825, 53.06282781785535, 29.03781629377796, 70.82796404438635, 43.67440731294694, 0.9511972591280938, 0.13826698064804077, 0.10208576647264343, 0.07411287797074165, 0.38063467690540903, 2.6036997187522153, 6.0917164241113975, 5.995140316024904, 5.86479603282867, 0.9367764200414381, 0.5191965401172638, 27.414260987312566, 65.01102239854875, 63.92199593205606, 69.06077154221074, 65.58134678871401, 68.50632098413283, 64.94485201374178, 69.09641804233675, 66.25957165994953, 63.67907962491436, 63.04052560560165, 69.23815681088355, 63.79043571410641, 51.669374435178696, 51.25814137920257, 58.65082463910503, 63.48343572308941, 67.07799773062429, 61.975609948558194, 60.49253040744413, 64.43797196111372, 63.56062796808059, 62.11700747090002, 60.566620057629, 48.982017424798784, 48.89029279831917, 48.435686172977576, 46.133219580496515, 45.77700561092746, 46.867652016301314, 46.50165173315233, 48.25729285517047, 49.19565716097432, 52.73921266678841, 57.85204179825322, 58.39244634874406, 62.90840448871736, 63.05860380972586, 58.44627303461875, 63.00031738896524, 61.814777082012554, 62.03510838170206, 59.65951311972834, 64.74633301458051, 62.419865439015055, 60.0934959227039, 59.82013417828468, 62.698624364791385, 60.31929500641362, 60.31128944889192, 59.4072223478748, 54.19992293080976, 44.528777983880815, 44.28097832587458, 43.825493089614376, 43.96662389078448, 45.22603027282223, 52.7648885019364, 55.662143307347456, 56.14331222349598, 50.489450962312766, 46.093231016589755, 44.823171477163996, 55.43699141471617, 61.32593600980697, 60.20289474917997, 58.46346870545418, 55.695522677513864, 53.16072233261601, 56.58393952154345, 56.76663175705941, 56.27569221681165, 55.10276232996295, 55.19980176802605, 52.53410016336749, 52.15327332096716, 56.507253262304495, 55.16714019160117, 57.762870634755785, 60.490753573756066, 60.828277449454035, 55.04585658350299, 57.39525041272564, 60.2758429896447, 57.50654766636511, 59.082081394810835, 57.88222443672919, 50.25696423745925, 12.23364212820607, 0.27439550346424507, 1.6224827833714026, 6.250996032068807, 10.464353119173358, 5.132833219343617, 0.4633924280924182, 0.07805801627616729, 0.19256413643879278, 0.017743010013814897, 3.403337391153459, 44.9660163540994, 47.438545150141564, 21.98159786962694, 52.18434241510207, 7.471819529610296, 0.10847218950549442, 0.07582824076375655, 0.19523108768607342, 0.019978274546203115, 0.014069400081831603, 0.03052813263850347, 0.031899297872798583, 0.020763529990349087, 0.036416357202876004, 0.041903182338442535, 0.04145762177124139, 0.040329553472298774, 0.09494186634378088, 0.04395643204090096, 0.02323321359712751, 0.10732115772102149, 0.037973526669966604, 0.05213191935552224, 0.006089409786997544, 0.07054083214531984, 0.013869099690759135, 0.0594900329897721, 0.04150996089822823, 0.05252799447325449, 0.1152519374004295, 0.25608246274773155, 0.12068369230555913, 0.1449483398708605, 0.15144105760320542, 0.18248775132721473, 0.17275815889719995, 0.16236505771596588, 0.19287389643009634, 0.15515471478143048, 0.09769474201264883, 0.1005366447591974, 0.1603585508682074, 0.1949883297446274, 0.12265003316344754, 0.10725437783666196, 0.1826113825964351, 0.10238571287763697, 0.19850206861813224, 0.07786126957545358, 0.1296594925224781, 0.2513869413204732, 0.12564855492523602, 0.20535265666342553, 0.2377501779025601, 0.12977316464868285, 0.20798790719239943, 0.11587394716879053, 0.1327747431012892, 0.1628033672609637, 0.20740722786755333, 0.1824636042358414, 36.852087666911466, 69.33594934401974, 40.81951802776706, 65.44287535452074, 56.23741380630001, 2.268122809548532, 0.3388065213878309, 0.17292302101850512, 0.8166138743681293, 7.878253075384325, 10.158078766638234, 10.80547380831934, 17.767271957089825, 10.492300987243652, 0.8331900558644726, 0.5696599774302975, 25.877837211855, 65.41454799713628, 70.03380960033786, 69.87151761208811, 67.74540470492455, 72.63055201499694, 66.70676892803561, 69.4757975301435, 69.96757645760813, 67.57036501361479, 63.90094064897107, 73.000196180036, 68.39815770426105, 55.17638521809732, 56.426989801468395, 62.74453570765834, 69.01843347857076, 69.80037366190265, 62.52521637947329, 60.66742497105753, 63.9841615769171, 65.60599496287685, 64.95967857299313, 64.28576830894717, 52.580768523677705, 52.75818124894173, 51.05861433090703, 49.841138086011334, 48.55281599106328, 51.41662866838517, 50.29228910323113, 49.58922778406451, 51.16370247256372, 54.348298349688136, 59.53335400550597, 60.648334795428866, 61.86346938533168, 64.41487312316895, 62.923384020405436, 65.94046331221058, 66.56697565509428, 64.37192709215226, 61.575987108292125, 67.01658125846618, 63.940195729655606, 62.23326652280746, 62.61531322233139, 65.21901784404632, 61.84852123260499, 62.11013155598795, 58.97142740987963, 54.94436133292414, 46.583166430073405, 46.47445794074766, 44.059168292630105, 46.72713310487809, 47.43698012444281, 57.19693145444317, 58.15513903094877, 59.5859843684781, 52.10823274427845, 48.19036545292024, 46.2214062290807, 59.171044672689135, 64.14899918340868, 61.777608702259684, 60.60886790675502, 57.24900091848066, 55.76112039627568, 58.694013857072406, 59.067851035825676, 60.117469449197095, 57.450269499132716, 56.165520683411636, 55.82757711410523, 53.76675598083004, 59.14601995098976, 58.303220272064216, 60.782118997266224, 62.86363063320037, 62.40058306724795, 58.95396109550231, 59.50605823147682, 61.10455743728146, 60.8015464967297, 60.47008268294796, 60.57879509464387, 51.290936316213305, 12.070399945782079, 0.39576647622931393, 3.0968713327761623, 6.993959132702121, 16.619866894137477, 14.37959634488629, 5.562820107706132, 0.43737274204050347, 0.3794203049713566, 0.23812338529575258, 5.129305047373618, 53.979544562678186, 50.87232920431322, 35.45111510061449, 58.66563943124587, 8.663114443902048, 0.2637964318836889, 0.2251729600492024, 0.35281434715274845, 0.12705837887141014, 0.17829616253654804, 0.13016760799913638, 0.14673189981089485, 0.09995015082700599, 0.11615871737200407, 0.2688199461948487, 0.1307660605638258, 0.18694174055370594, 0.21329962378067358, 0.12684590438561094, 0.16826627896197383, 0.3014128504981918, 0.0753830747318364, 0.0993503805910868, 0.22783041180622196, 0.18291170438451154, 0.12659103459408208, 0.12256327370602278, 0.170146886920256, 0.14192198613478293], [0.14583055140270343, 0.057084911442812414, 0.010206122101554948, 0.04137334060825167, 0.017700122496593865, 0.008690315636716062, 0.02872191373288872, 0.0825687726178477, 0.036082270089536905, 0.037540418861974637, 0.06260183617292393, 0.008749921107664704, 0.04762246153287349, 0.026194426877003525, 0.026745809084405343, 0.008599031472488517, 0.05017236986708257, 0.01373009782494797, 0.013799281310169928, 0.044633730374757326, 0.05425656079164436, 0.10979591282985865, 0.06963292602449656, 0.044437703796692436, 0.016294621201532505, 0.028688521875489145, 0.05267775700157208, 0.08255862195285098, 0.04565594830520211, 0.030320051666950027, 0.021777818910777572, 0.06168551457625243, 2.349646576950627, 47.881894573088616, 37.80151305660125, 27.672064650443296, 62.78754057422761, 25.975867048386608, 0.591853360735601, 0.07927377482936268, 0.09904772989572057, 0.10794660722416256, 4.759648624927768, 0.9961169777858643, 1.4689813169740862, 2.9020651021311363, 1.063277086903972, 0.40947577285189785, 1.5491152170204348, 32.750602460676625, 55.731851670049856, 60.43259659121114, 63.78670554007254, 62.434523336349, 67.9270496676045, 65.78130137535834, 63.83926530038158, 66.11791133880615, 66.24333304743614, 63.112042180953495, 60.657285644162094, 49.725467389629735, 54.288843062616166, 59.994507066665165, 66.48662982448455, 63.56671156421785, 63.41024821804416, 60.64026647998441, 63.426655492474964, 63.70140967830535, 62.92982847459855, 54.098564963186945, 45.66106427100397, 46.85156245385447, 45.07332847964379, 44.421524693889005, 46.21153362335698, 45.589430024546964, 45.334075881588845, 46.15004262616558, 49.16241115139377, 54.15510985159106, 53.97921508358371, 55.94993152926045, 57.38884125986407, 56.25360927274151, 57.817889721162864, 57.733774492817545, 59.27426184377363, 60.76386820885443, 57.365730654808786, 61.634908953020656, 60.619152361346835, 60.836690933473655, 58.18423517288701, 52.45875535472747, 55.61958166860766, 52.893452029074396, 48.41576837724256, 42.78050699541646, 44.23349803493869, 44.45038157124674, 42.79399994880923, 42.5776380877341, 46.94583662094609, 56.53316443966281, 59.44977614187426, 57.88569573433169, 51.577198736129276, 43.490432462384625, 42.50716094047793, 54.82917308807374, 60.6140140564211, 59.86855191569175, 58.36894350667154, 57.22539609478366, 56.63256122219948, 54.18584162189115, 56.09657718289284, 55.44005478582075, 53.97719898531514, 54.106370479829856, 54.46044283528482, 53.02616542385471, 53.33437742725496, 57.25511981594948, 57.32385150847897, 57.03827158097298, 57.35606201233403, 55.62126044304141, 54.89628091935189, 60.40495172623665, 57.37682704002627, 57.97511792952015, 47.07608284488801, 14.462449550628664, 0.10092305950820447, 0.2495919207050916, 0.9355962769158426, 6.583971919551973, 10.773278013352426, 5.207328834841329, 0.12696145342723017, 0.08777836968581523, 0.15652431145070062, 1.1908113595939454, 29.175085521513417, 47.39888606532928, 17.633266141337735, 40.34336582306893, 25.971073912036037, 0.035202946709168535, 0.034971760525818796, 0.04870202114445068, 0.038826963939373536, 0.006723364781317932, 0.12024237969589811, 0.04723062288136252, 0.035334721493024024, 0.014807613896987131, 0.012512443204139991, 0.05786108874505567, 0.059090571763414534, 0.06764201672687646, 0.025975442559067762, 0.03129503453120349, 0.02793439641414631, 0.0673977266095819, 0.03646873080381944, 0.06643683018703615, 0.07077735413106219, 0.06567067331484248, 0.0767705059279838, 0.03779880882751557, 0.019737435655007442, 0.031486137079135064, 0.04151453827357581, 0.033086812679445556, 0.032706273824817715, 0.05291005784285165, 0.07175569437564382, 0.022826332809223283, 0.03738785245185418, 0.034652114169852394, 0.04267734865988455, 0.0360389746304962, 0.06271378460129903, 0.06506770849227905, 0.018038315841207103, 0.08790444477551407, 0.03767416249179552, 0.023699533231856845, 0.03431547215328582, 0.028454001294448975, 0.023652284759126847, 0.02920312994730569, 0.055799147775096286, 0.036391076301374746, 0.014105633167820352, 0.04407373159342716, 0.0382950690935456, 0.016883411482276938, 0.014037796082125317, 0.048138720524166866, 0.035645695733687574, 0.08638454931637934, 0.015343380359662397, 0.14479404976291044, 3.780034958354889, 61.1443655721603, 35.04311407766035, 35.35797842087285, 74.4901006452499, 23.044595487656135, 0.4840319705826621, 0.004854427214952247, 0.0675510131423512, 0.3034359354886317, 0.26982683087548903, 3.672537010523581, 5.968810425650689, 6.571301193006578, 3.124499527677413, 0.6707235834290904, 2.4537901628401975, 40.277356255439024, 59.4730201075154, 61.464685932282485, 63.81029467428885, 65.13978988893571, 68.8372278213501, 66.59454991740566, 64.99916899588801, 67.20561596655077, 66.42582524207332, 66.17810403147053, 63.44662820139239, 52.44720005219983, 54.68409246014011, 63.015359678576075, 66.86807247900194, 64.69761325467017, 65.13246682382399, 62.1425421007218, 63.94461231846964, 65.15625207654892, 64.98342067964616, 57.42853564600791, 45.95404963339529, 49.2773405198128, 45.528990222561745, 47.72871032837899, 47.17372632795765, 46.750714394354056, 47.60889760909542, 48.62303426188808, 51.66739756061185, 57.149851245264855, 55.400234883831395, 57.81033131384081, 58.52710523912984, 57.730734655934, 61.01187967484998, 60.05779450939548, 62.34013149815222, 62.16582529006466, 58.9323409911125, 63.63027357286023, 62.22328016834875, 63.66853629389117, 60.06797305999264, 55.74878454208375, 58.207541896450905, 55.405851717918154, 52.63334005109726, 46.16860328182098, 45.129979272042554, 47.14768571238364, 46.29150682880033, 45.6134113957805, 48.30436129723826, 59.71716803889121, 59.34894377185453, 59.45220016664075, 52.63811749796714, 47.16266132170155, 45.07359127844534, 57.11737794260825, 61.618011382318315, 61.210347683199, 59.15735167841758, 59.79744718920801, 56.88357722374701, 55.04193421333067, 57.786295029424856, 55.792295394405244, 56.42270657324023, 55.93390864710654, 54.68476318543958, 54.68861495294879, 54.63534132126839, 56.229027778871604, 60.16851909698979, 59.188671804243526, 59.51031792548395, 57.047857853674124, 57.57436152427428, 61.86101790397399, 57.78979770598873, 60.295749018269206, 49.5162756212296, 18.43917004523739, 0.42867709251661457, 0.7445724368576081, 3.531800407555796, 8.2855196345237, 7.242176032835438, 1.069378088558874, 0.0339007887598728, 0.05612268968815765, 0.0721108987026157, 1.4934383981650876, 26.339086371083415, 57.98136234283448, 22.127521807147613, 40.56187714299848, 36.25873111909436, 0.05714582309367196, 0.03456885190380197, 0.08654931184625433, 0.06341754744249968, 0.013787123494811598, 0.08911073448196535, 0.05020937191382532, 0.029066892701291272, 0.02236736570334723, 0.03091424861322007, 0.049913175509221135, 0.05875261590605783, 0.02718494983480102, 0.05472770869551648, 0.04990358791884877, 0.03388454386543843, 0.040011274583277204, 0.006769097836372713, 0.05914893234148622, 0.032283366477537545, 0.03982280546258535, 0.04480336522383075, 0.011616205560013412, 0.054364456614900025, 0.04382528544914338, 0.2951441675184235, 0.10634763616948359, 0.14764734423689305, 0.09799612866294, 0.1872173483453451, 0.09842405771656383, 0.12303889173293307, 0.19324714978856428, 0.21562212657543922, 0.07996989594351861, 0.1436772927521698, 0.2800815612558396, 0.10118556719633842, 0.1396829256367299, 0.09895155521770639, 0.07209815866043491, 0.19616033701646715, 0.1267008379762692, 0.13954417179188422, 0.19125127624119484, 0.11114625770959163, 0.13556609170571451, 0.12397734944017665, 0.1897828848732095, 0.11624234352981853, 0.12297794177767732, 0.11675004531899769, 0.1738960599346507, 0.09789861333105834, 0.14151704737976675, 0.1135585000438075, 0.315861820333427, 4.492966186615729, 66.12450092069565, 50.697191453749134, 40.161363924703295, 76.14195977487873, 37.425800984905614, 0.9386390555770168, 0.15576070565129482, 0.23371922242785656, 1.3608023476216102, 10.17099218983804, 8.702610750352184, 3.1434480076836, 5.587850712960766, 3.3910022724059323, 1.2240505050266943, 2.4447591506665756, 39.19180500891901, 63.77578958388298, 66.12898026743244, 67.95679692299136, 66.94898313091647, 71.25581618278258, 69.83143883366739, 67.66482353210449, 69.75386219639933, 68.87227027646958, 67.89580406681185, 66.04234295506632, 54.89779103186823, 61.19754114458638, 65.96180885068833, 69.95459341233777, 66.8460052244125, 64.84099941868936, 62.00303516080303, 66.94164045395391, 69.87473395562941, 68.30100059509277, 60.40358674141669, 48.22135217728154, 49.85377596270654, 48.43309740866385, 49.46871688289028, 50.10683944148403, 49.46335108049455, 49.69038963317872, 50.74264387930594, 53.4499147630507, 61.67021812931184, 59.562854151571955, 62.54085879172049, 61.20193812154955, 61.1683234091728, 64.88764816714873, 63.2878428120767, 63.58944169936642, 63.0985531499309, 60.256172303230535, 66.67090277517995, 64.9331162821862, 65.93851781660511, 63.5790591855203, 58.34194975514566, 60.76902220326086, 57.761768448737364, 54.598302379731216, 47.3767521304469, 49.26996646388885, 48.187309926556004, 50.52785488866991, 47.08418646166402, 52.39712707458004, 62.185641104175204, 63.5991495655429, 61.77301952915808, 56.36520854888424, 49.329715928723736, 47.482593367176676, 58.16090491510207, 65.68592109987813, 62.49903063620291, 61.72703758362801, 60.80394698727516, 60.258188401499105, 57.86674676402923, 60.33980900241483, 58.886151159963305, 58.195237421220355, 59.46626578607867, 57.120915920503684, 58.31961185701432, 57.715515859665416, 60.697988079440215, 62.387415670579486, 60.5881421027645, 60.911282647040586, 59.98975707638649, 58.23479452440816, 62.96158006114345, 61.35168636998823, 60.54386246588923, 50.351269783512244, 16.639835680684737, 0.2269699724931871, 0.8765180276766901, 3.491614499399739, 14.098292781460671, 24.571036831025157, 10.878649546254067, 0.24714236988896326, 0.21159907712811427, 0.4547994649938999, 2.491820973734702, 41.29021029318533, 58.227671500175234, 27.903578627494078, 53.194572387203095, 39.003535163018014, 0.0742616139412407, 0.12198748202213358, 0.33924509140272296, 0.12190973175869835, 0.11275377830550556, 0.18800140869232917, 0.17070856726457997, 0.13235391568272345, 0.11095193950759788, 0.12144283181236637, 0.1889825068534382, 0.16436581890429222, 0.12233026806385287, 0.09349952962610031, 0.059643963036397775, 0.1316696765922731, 0.160619311875874, 0.11615798958847601, 0.11683359486801971, 0.23497194472339847, 0.1827970669875222, 0.17606485484828874, 0.10252158623188735, 0.10227225525605102, 0.1393789266266169], [0.1156634874942322, 0.05016729070414459, 0.026134629884073814, 0.10021071265181226, 0.03735825081445998, 0.07139589352112624, 0.07536175450490368, 0.036643237972091285, 0.0326990764287691, 0.05757694673394004, 0.031780550414095485, 0.016864671056429227, 0.10701576443088633, 0.017748979753964854, 0.018982402379474333, 0.06450628095697011, 0.0271271025356386, 0.04103374149229738, 0.03963443210288402, 0.10504927035541305, 0.01538101347133277, 0.06796010409391696, 0.017347358159660813, 0.07392070481493589, 0.027764547060454087, 0.036951749240078276, 0.041772242590424516, 0.03762598705267714, 0.016658453593751597, 0.04513713824112089, 0.08105863711886829, 0.024687918804345593, 0.11612119438547282, 10.822539060346543, 52.31663219390377, 35.8981829304849, 41.50568177623134, 65.15668353726788, 22.562993149603567, 0.5926578143431295, 0.13600086192450217, 0.11762628902591045, 0.21244681470336454, 4.630709530845766, 11.797671664145685, 5.367369872908439, 1.9965350796138088, 0.2828362908574843, 0.02045267066287418, 5.526131237706831, 40.821436066781324, 59.43093699793662, 59.98043752485707, 64.90720902719806, 68.62392148663922, 66.83827031043269, 68.79584681603217, 66.87895313385995, 66.44779051503828, 66.17855902641051, 61.312470513005415, 50.05026317411854, 53.77711496045513, 65.08626914793446, 67.79328899998819, 64.8769400965783, 59.21919961129466, 64.60757524736466, 63.39514317051057, 63.76875677416402, 59.06718815526655, 52.364881269393436, 46.14495531205208, 46.091179616989635, 46.64787769317628, 45.191646775891705, 46.14921500605922, 46.1113876681174, 45.31355796321746, 44.84934937569403, 50.009376387442316, 54.991739642235544, 54.98769567858789, 58.086717205662886, 55.6839281512845, 58.18093645957209, 58.87263074997933, 61.625283456617794, 61.34322973989672, 59.72161992903679, 59.848853772686375, 62.61072797159996, 59.331375475852724, 54.87219756649387, 50.28032195183539, 49.129243589216664, 45.9237140224826, 44.041388188639, 42.80598671205583, 42.753454408337994, 43.166585891477524, 43.167346831290956, 42.87239243907314, 44.55173561649938, 55.14796372382872, 61.16341260171706, 61.35073323403636, 59.933106283987726, 53.6959768110706, 45.47720709154683, 43.6135595844638, 54.6934590801116, 60.70923351472425, 59.15099743873843, 61.4023712373549, 60.523360236998535, 57.394450249210486, 57.0124545404988, 55.04311092438237, 56.59752268945017, 57.21297002607777, 55.31149518105292, 52.42572115313623, 54.84102649073447, 52.618325218077636, 55.12458639760172, 55.725273855270885, 59.408265698340635, 57.740532736624445, 54.76680347996374, 57.537181377410896, 57.32478895495015, 56.26552935569518, 47.11987610786192, 15.841747099353423, 0.5488654706747301, 0.17453782711057894, 0.3497190761470026, 2.2314481581411054, 5.6580454495645345, 4.619623932146258, 1.4799637083084354, 0.15289732946022866, 0.03899040113713953, 2.935431969742621, 26.161100979774233, 50.703639830312426, 23.211688456996797, 35.15986734820951, 35.95351580650576, 1.5678208777981422, 0.10958348430933491, 0.11301764196926549, 0.05236004118717486, 0.09405199393269517, 0.1149700936530867, 0.06138207097988456, 0.053795885309697165, 0.041199365871087204, 0.06276484436145233, 0.040162213056558566, 0.029805342088483518, 0.027201390081656077, 0.04868318304239262, 0.04314448609347305, 0.026301443614366076, 0.05755796307517637, 0.046193263223094326, 0.01373196995231293, 0.016853212296301802, 0.009976486288641971, 0.0573647863441898, 0.08877181718426366, 0.06418622474396421, 0.024487726623192433, 0.05094396596353862, 0.04929529495477196, 0.037966758283155586, 0.009850382470645973, 0.01618372039839385, 0.04081307752658764, 0.01721356090368523, 0.04022425851754604, 0.03423939579196515, 0.04935344485866447, 0.013516160111213404, 0.030599738876785965, 0.020995453533325947, 0.005729183753682, 0.059735560339064374, 0.03584152312889215, 0.01448501906012215, 0.054987818528447426, 0.08603556562335261, 0.03235426408449008, 0.03311732596146964, 0.03991858177487889, 0.03701613126923481, 0.020901860571616603, 0.02375754140948336, 0.04042131931430871, 0.07545511764023574, 0.004105072087352915, 0.08712694980204107, 0.02872387108753526, 0.026874188183536454, 0.08984736632555725, 0.09614856973771127, 0.0369155286030183, 18.95908413394805, 60.85460439805062, 29.144039961599535, 56.046821917257006, 73.11905184099751, 17.493578772391043, 0.692715761401961, 0.059547110370570616, 0.03528637368412268, 0.2626621927465162, 0.9454941328975462, 4.912453870619498, 8.562372288396283, 5.49035971203158, 2.1687493160847695, 0.04584648969372915, 6.662335482335861, 48.24554143413421, 61.57070759804019, 65.01782378842755, 66.44629216963246, 71.1857077383226, 69.44171213334607, 68.85664355370307, 68.5393238067627, 68.13873214106407, 67.17673947734218, 63.783787296664336, 51.328893092370805, 55.84976596217002, 67.37101447197699, 70.63813701752694, 65.39508911871141, 61.22735508026616, 62.549637056166134, 66.57423203991306, 67.29728960221814, 62.73158796371953, 56.86680516889019, 48.56566959811796, 48.20560778340986, 49.18902835538311, 47.57402773826353, 48.76432195786507, 50.04950223430511, 47.772786002005304, 48.03389818437638, 52.449247529429776, 57.098417205195275, 57.98122505987845, 58.525014615828, 57.24676908985261, 59.558806265554125, 59.3310812980898, 63.85028323819561, 62.410698859922356, 60.310881522394, 60.752163856260246, 65.09329803528325, 62.0840124930105, 58.95693817446309, 53.16489181210918, 52.91694702640657, 50.02394799263247, 47.0065745230644, 43.67659991787326, 44.869435833346465, 45.47024880686114, 44.5498058103746, 43.81870738921627, 46.61633791462068, 57.01675345820766, 60.95842953651183, 62.58844106428085, 62.80022159699471, 56.117746214712824, 47.09187038483159, 47.142182627031886, 56.83995654506069, 64.76735299633395, 61.14678567455661, 61.82170791010704, 60.15892890191848, 58.97459276260869, 56.77793210552585, 54.91932484411425, 57.41248922963297, 59.082724663519095, 57.611369086850075, 54.1799972903344, 55.32017538624426, 55.616683037050315, 56.1295094028596, 59.69730515633861, 59.505265912702015, 60.44484223088911, 55.52871604119578, 61.14375760478359, 59.179156134205485, 59.134833351258315, 47.711240091631495, 20.147415207278346, 1.122074886675804, 0.5677828781547085, 2.2409295074401365, 4.743619368922326, 5.696865637456217, 1.582961104089214, 0.07730487523780716, 0.01681235491208011, 0.0470789221505965, 3.1306147479241897, 25.967859529679824, 58.6528838834455, 32.14654176465927, 27.64988756948902, 49.4048567741148, 3.8504682240947603, 0.09664556161770899, 0.09556448898248135, 0.02374609031023518, 0.0610737435729994, 0.08159982461121776, 0.04102496212468513, 0.08169393851271561, 0.038678300747227286, 0.03621620524133887, 0.03965220534272733, 0.035594260590451385, 0.015075502395179245, 0.02978764928787226, 0.043522152118384845, 0.044048125104558085, 0.028264660748743245, 0.031079725520084464, 0.06968873552978039, 0.00536422090296964, 0.016226198058575392, 0.03004398613777613, 0.07307943302176653, 0.05930794921192912, 0.045872632444145224, 0.03382217281708314, 0.23514722564047386, 0.21147262665533254, 0.14702382527532118, 0.23135173495017716, 0.1516696582398107, 0.17896786842855716, 0.12899173964415828, 0.13131137727008713, 0.17250341934061822, 0.22408494665738077, 0.20161488303734412, 0.09855253066146567, 0.2722850844504372, 0.2270959173479388, 0.08522781017687052, 0.14086411064190252, 0.11350403119239116, 0.23944830371727868, 0.18705306845086236, 0.1929942181994838, 0.17633441054532606, 0.15475346857020933, 0.14034928423502754, 0.10827155873900461, 0.114244700319344, 0.2620287299636872, 0.11516949867889767, 0.18968130161444988, 0.1060059073290998, 0.11961739750639086, 0.1409538808248697, 0.20365439295288057, 0.15609937780086072, 21.085399043175485, 74.06565312416323, 47.42290273789437, 54.94813857540008, 79.08535342062675, 32.23702496097934, 0.8573503239500908, 0.3483411904063917, 0.25734784081578255, 1.2853712468378007, 10.673240903885135, 30.53585183235907, 15.853857417260448, 8.158308834798875, 1.5642836353471203, 0.0970749385775097, 6.858005860159475, 49.00992901094499, 65.53197199298491, 64.17308645863687, 69.66848004248835, 73.99754508849114, 71.97567309102705, 72.22108010322818, 71.66097348736179, 69.2340147879816, 69.45026290032172, 66.66198330540811, 56.13252962789228, 58.671946602482954, 70.69731773868685, 74.51136773632419, 69.55499802866291, 61.18182028493574, 65.57054850362962, 66.86546802520752, 69.1773836074337, 63.98549910514586, 58.28648744090911, 52.280252210555545, 53.206978844058135, 53.180628361240515, 50.181082064105624, 51.032212857277166, 53.4837491281571, 50.73835672870759, 49.308841074666674, 53.95700662366806, 60.300812798161665, 59.43203526158487, 61.51112287275253, 58.84550756023776, 63.09830604061004, 63.155168640998106, 66.61078852991905, 64.682790617789, 60.02286972538118, 63.7956367769549, 66.13709957368913, 63.17505898014192, 61.87160045869889, 54.6313444260628, 53.14735489506876, 51.53335448234312, 48.412528499480224, 46.494203152195105, 46.710121785440755, 47.52286434173585, 46.93890579285161, 46.21721321536649, 48.56983907761113, 60.789657792737415, 64.53837287041449, 63.56389138006396, 64.26816863398399, 58.86733555024671, 51.208213529279156, 49.17617474832843, 59.684227974184104, 68.9466070359753, 61.30768129902502, 63.30632109795848, 63.27616199370354, 59.00226900654455, 59.47640119060394, 57.12026872942525, 60.72340111578665, 60.306194290038086, 59.3485083887654, 55.76949465659357, 58.67897156746157, 57.76129384194651, 58.655402045096125, 60.80931671204106, 62.956151500824966, 60.18861339938257, 58.194809882871574, 60.48494454353087, 59.92010754923667, 59.71086086765413, 49.64362713598436, 17.914362799736764, 1.2191952236237065, 1.088785731023358, 1.233339535613214, 4.190498494332837, 17.336903618228053, 12.644408422131693, 3.0039079727665072, 0.25268749814600716, 0.12649259229581203, 4.38143898402491, 38.09698520168182, 58.02992520793792, 35.218498937545284, 44.13182235533192, 53.48218802482852, 4.243856456971938, 0.432856715013904, 0.26959216282252346, 0.16634787222550762, 0.22495246462283597, 0.24303457579545437, 0.12423270186709783, 0.15516409169762366, 0.1416678747702991, 0.09858527325934942, 0.15676745243610876, 0.247745281085372, 0.1096732008661474, 0.2252340479002845, 0.18027501361023995, 0.15860695211637407, 0.14869587345709726, 0.13670934003687676, 0.12796505925155457, 0.10177042170037186, 0.1194427447814134, 0.18248761343138833, 0.2158300888033644, 0.14092185834963478, 0.0865229584216591, 0.26467317354775244], [0.0232492478173827, 0.05898659447989157, 0.03458833735015604, 0.03594099198498073, 0.08001462015653811, 0.053430331134868246, 0.07363601122051477, 0.021214209940104235, 0.037073143532559756, 0.0709535543536467, 0.015878083875342723, 0.013415009692131032, 0.03667803368561211, 0.06814301524671816, 0.023591622086842696, 0.09662602637563983, 0.016337259740178144, 0.04488935476289161, 0.023934161065206416, 0.027354590429533875, 0.1355360917025997, 0.04067124783872597, 0.04676456563174725, 0.027684942864242102, 0.05120794454048719, 0.03395614244284169, 0.030142118170436834, 0.09297053825350539, 0.07099643995564792, 0.045170390287474285, 0.041000225145610115, 0.01619767277471481, 0.028727778135949088, 0.20534545543693727, 24.264256492737804, 52.885309188596665, 28.85563200519931, 34.52673796684512, 63.56369526155534, 21.313455450919367, 1.0459931627396615, 0.08014680096699346, 0.06559204971117359, 0.5400113328810662, 5.775641049108198, 9.740404198246619, 3.680305264649853, 2.9752060290305846, 0.37874957967189055, 0.10110908097797826, 7.762275453536742, 43.88559949013495, 63.92841685202814, 66.79126462628766, 72.40667097030148, 69.82415106988722, 68.0371976667835, 70.43245577043103, 68.33947120174285, 62.20282108552995, 56.4477744410115, 50.73786251006588, 60.11478262562906, 67.69508854035409, 67.12656451809791, 63.8645371314018, 65.06591989148048, 69.29072441593294, 67.98285715041622, 63.239389773338075, 59.532616599913574, 53.158259084147794, 48.4492418842931, 48.63536619370984, 45.408420485834924, 47.26756903433031, 45.845247007185414, 47.15035684647099, 47.7263843628668, 47.31052291008734, 49.622830729330744, 56.243713132796756, 57.380223812595496, 57.53626354279057, 58.23954843705701, 58.208451886330884, 60.816098490068995, 59.388649925108886, 63.19894621449133, 59.62296055209253, 54.24457911522158, 62.746744002065356, 59.23070784538024, 57.349186097421956, 51.009992630251, 45.59803178233486, 46.57063053500268, 46.439701818650775, 46.157573576896425, 47.13181972503663, 44.02450238504718, 45.70255510268673, 46.03689009143461, 49.239579862163914, 58.859302536133804, 61.31452975734588, 64.39239009734123, 60.80464909153601, 56.006531330846975, 45.01426150721889, 44.12719003615841, 53.463293967708466, 60.916970083790446, 60.385426167518865, 62.41817881984096, 60.70598971459174, 60.89582458619149, 57.63574269510085, 57.73752820107245, 54.901721246780895, 56.696943006207874, 56.33197822878438, 56.01743159755584, 54.28659162213726, 53.96056421341435, 57.416595951203384, 58.81174379779447, 57.780113374033284, 57.42819047743275, 58.00866596160397, 56.01300716400147, 58.030846964928415, 48.48486485019807, 16.942240615044874, 0.7048860180281824, 0.15886858646427432, 0.9223829149719208, 3.521860876391011, 9.457589541712116, 3.4074980453137433, 0.34603373357845896, 0.08858457763469027, 0.06351361103776483, 4.203750221960006, 30.995514392852787, 49.5127768670359, 25.43919267192964, 27.027177964487386, 43.13109236378824, 6.1954650763542425, 0.23525889061631697, 0.008136578666556987, 0.07839774562706871, 0.050529906931783886, 0.051635544176303574, 0.048312936579027486, 0.1031820382922888, 0.027986708728055802, 0.009901906671603362, 0.023753952287558108, 0.014302273573834571, 0.02590597753653363, 0.03788017119551378, 0.026221255276111827, 0.04828753693389797, 0.014312826434991533, 0.02678539859311235, 0.025176183027665944, 0.048281285656435836, 0.06879859498792118, 0.016102300573801322, 0.02303273796344236, 0.04296986401201256, 0.03606351625715052, 0.09473122280812073, 0.02943680591640934, 0.016479399693649144, 0.02042623296860726, 0.052997529762046, 0.04210899185930048, 0.026590097883355715, 0.06164564353023326, 0.052853137510077614, 0.03575794293635315, 0.03909726274169741, 0.04064748762175441, 0.018443524642216585, 0.028261416366383917, 0.02954357750563612, 0.060448022108645215, 0.019827146466160496, 0.07930016655835413, 0.04867245015057345, 0.0073344961011541955, 0.015934186409257593, 0.02261204077982374, 0.06002621409753638, 0.04173512180005351, 0.06804202953653951, 0.0627109500759792, 0.08860767518560733, 0.008477184230521803, 0.03793565894386942, 0.03621808598719297, 0.01669869236197443, 0.09156097477722554, 0.029975947954000968, 0.054256622078678304, 0.026826028066176563, 0.5739813874806128, 35.61980055224511, 55.71444419122512, 27.970319717161118, 57.32554597239341, 70.77854218021517, 19.775790245302264, 0.9220748863393261, 0.05279114184480521, 0.02845713267883947, 0.17068599831433068, 1.670628651495903, 4.02385953933962, 7.05198226436492, 4.163131627344316, 1.418557900094217, 0.5052611862699832, 11.524395231277714, 51.04744734302644, 66.68711000873198, 67.75930558481525, 74.23622915821691, 70.56904054457142, 70.60346326520367, 71.53825036941036, 71.73786763221987, 63.42487081404656, 61.412286989150516, 54.089720018448375, 62.388933627836174, 68.02661511205858, 69.50892586861887, 67.59345208444904, 63.73652273608793, 69.49096141322967, 69.09653571344191, 64.93236318711313, 63.36512527158184, 54.78917667942663, 48.7442708015442, 49.91041891036495, 48.200732277285674, 49.376929498487904, 49.66896172492735, 48.64090065802298, 48.9890855358493, 48.921930636129076, 51.01540550108879, 58.05802899022257, 57.66488590548116, 60.95224788112026, 61.15223776909613, 61.80268049240113, 62.9970932006836, 60.371505675777314, 64.96140441586896, 59.68956631998862, 59.25418715323172, 63.40247408036263, 62.92943623758132, 57.21457427547824, 52.7279789986149, 47.75068736845448, 46.89445357168875, 48.37053168204523, 48.01079542406144, 46.808765472904334, 46.55490575298187, 46.495273959252145, 47.34664793937437, 49.58311280896587, 61.930090842708466, 63.87146403712612, 66.12431264692738, 62.064243747342026, 59.80676674073743, 44.597501831669966, 46.13977778342463, 55.23898232367731, 63.0414826639237, 61.014401758870775, 63.00880932038831, 62.069723298472745, 60.97890038644115, 60.61545356627434, 59.43537712097169, 57.04654778203657, 57.95248977599606, 58.18380371216805, 57.81008812689013, 55.11651808215726, 56.02259735907278, 58.989709577252796, 61.87195739438457, 60.838420698719645, 58.529105647917724, 59.62496096088041, 58.35212046100248, 58.25670488419072, 52.15798800991428, 21.390618278134255, 1.5321677586724682, 0.7422898625654559, 2.052598129357061, 3.896078034754723, 8.555695433770458, 1.021741699547537, 0.23397368619278555, 0.056640427229144884, 0.07398729317731435, 4.339132789642581, 30.020793637921734, 53.17505075085548, 35.24902282222625, 23.862164520448257, 50.80168731750981, 13.51666117868116, 0.16751997142789826, 0.0662275656096397, 0.08177546558961754, 0.02131692700899176, 0.038328405409570665, 0.035523600470755375, 0.04523602870082663, 0.026471777518670407, 0.0434547440419274, 0.0317672377211913, 0.014442866987308428, 0.02823512039838299, 0.062212954620800676, 0.07667113666332538, 0.04277480653517189, 0.04238901614782311, 0.02402117716208581, 0.0655826727949804, 0.08556619121302521, 0.017821131829893398, 0.060661186073576255, 0.05913442646663997, 0.059440183648539174, 0.0168432435771871, 0.018003062390151526, 0.03422452985579449, 0.1344658209071044, 0.18108250092594855, 0.10074356510754555, 0.1713133017502485, 0.17663114704191687, 0.1454753777192485, 0.19759947914750348, 0.09425977229951851, 0.17605822052686446, 0.17581552387245242, 0.16652470064019004, 0.14293011187786056, 0.12878455882591586, 0.10649397428477965, 0.09509797208011152, 0.20777874986731237, 0.10690508004758628, 0.09667036754469718, 0.11286138301535, 0.2396685693172678, 0.20372350940540915, 0.22121629978139556, 0.17226856742655078, 0.16084031292027043, 0.21047553257836452, 0.07317314089666452, 0.17507873115039643, 0.16129356117979174, 0.19301481064288847, 0.23444325212509404, 0.17085003306067761, 0.1489224975868579, 0.1098323403106582, 0.5669449618266476, 42.010141726463075, 67.94588488917198, 40.00735598225748, 47.092427361396055, 77.56858071973248, 31.61001055471359, 1.8109667661689945, 0.13249283806691248, 0.21738664156967596, 1.056757985103515, 16.109679302861615, 22.042751542983517, 8.349144401088838, 8.572087018720566, 1.1472428974605378, 0.38228409484990183, 9.414141447313371, 50.32409952532861, 70.634473523786, 69.98457600993495, 75.55197254303964, 73.84713003712316, 72.00149797624158, 75.05444342090239, 76.14769428007065, 66.97112098816903, 61.85304372541366, 56.097063556794204, 65.47491327408822, 73.13886765510806, 71.68788094674387, 66.35033530573692, 65.7142484572626, 72.47433970051428, 71.82086498506608, 69.36481798848799, 66.24402338458647, 58.708542316190666, 50.943194666216456, 52.52267429905554, 48.269491426406375, 51.53048330737699, 51.080497234098374, 51.37090559928648, 53.52183142016011, 51.25288932554184, 54.25767590922695, 61.274207791974476, 61.13625018827377, 64.60039338757916, 65.22037890649611, 64.63552605721259, 66.16880016942179, 63.12362494007234, 66.92274247446369, 60.75896916850921, 59.59065198898316, 65.26262283325195, 64.89365331588253, 61.516390615893954, 57.13457753581386, 50.476546364445845, 51.06317212504726, 51.90578745257471, 51.12956608495405, 50.67713637505808, 47.91878446455925, 49.76489897697203, 51.40591667544458, 53.76458298775458, 65.0603618929463, 65.11987601557087, 67.74924862769343, 64.47774871703118, 63.07702326005506, 47.91641535297517, 49.348970843899636, 56.42249476525092, 65.56478261947632, 63.575999736785896, 64.96805283331102, 64.60144458278533, 65.9959726948892, 61.88077096016177, 60.796737670898445, 59.14327821423931, 60.711857580369525, 60.05864566372287, 59.3492026482859, 56.96266005116125, 57.483131116436375, 62.7007620565353, 63.85509598639704, 62.34661909841723, 60.25876106754426, 61.64499728910385, 60.19517160231068, 59.111459947401485, 52.58176872807165, 19.698025334265925, 1.5663577111498004, 0.7752458006143571, 2.3590605105123212, 8.618317054164025, 19.01095355710676, 9.48698966733871, 2.006095121464422, 0.2164435720131282, 0.1722626991930508, 7.442474807462386, 45.47850539607387, 57.811131477355964, 35.00144281694966, 37.27071831303258, 59.62735752905569, 15.60554490935418, 0.3773632669641126, 0.2086175088920901, 0.13486273106067412, 0.14578515303231057, 0.13711478440992295, 0.17192807198772508, 0.24813777857249786, 0.12113022963486372, 0.10650133638973198, 0.12306241829308773, 0.0879503564248162, 0.09775924661587324, 0.25035374918051306, 0.14306247654941776, 0.12312393515340744, 0.07907987797572728, 0.18447279239133482, 0.10997347668894839, 0.14220206787989986, 0.1078011118055832, 0.19937127197702087, 0.14627894266478478, 0.23356552986848741, 0.11244812454547613, 0.18489460040244365, 0.18783789488577074], [0.04366740238882842, 0.03745603810755476, 0.09414904195094302, 0.031244440169464198, 0.022730989336606958, 0.07611772240770441, 0.08294368072623208, 0.056065631459557244, 0.06110735951111682, 0.03727565504490368, 0.036645685623009364, 0.0047715532597184425, 0.022363163711082552, 0.019196443515078678, 0.03673159089239855, 0.008289598983772581, 0.047573175266264915, 0.014219401055015625, 0.03220935855361243, 0.04449956156613846, 0.01882784605597056, 0.06648151609565943, 0.05981655881529855, 0.014176632281422857, 0.02709066930917963, 0.0586221932673887, 0.02451965142221701, 0.05054113395031422, 0.02465537347410235, 0.03500212442069765, 0.030576323399380333, 0.01191358078241108, 0.04206798317271375, 0.20438743184410757, 2.411851690661523, 45.656847723068736, 46.77994781924833, 27.815719496819284, 38.0270375743989, 64.86162716342558, 27.744865802026567, 2.461337293348005, 0.056456734666660915, 0.19203457050025466, 0.6544782293419684, 2.6520382733114305, 6.367800783726477, 3.327177464962006, 0.839141333295453, 0.43003790981827245, 0.0226798644589801, 8.139808975881147, 44.42305441825621, 66.78858172508978, 68.64846767917757, 68.92696380615234, 70.75888326091152, 67.16535675910212, 65.71678623076409, 62.93068355129611, 59.57104798286193, 54.3368842524867, 64.36301938949093, 68.12366239486202, 68.44404943527715, 68.59501361846924, 66.72398028835174, 62.412409013317486, 66.24956177126977, 64.83444121576125, 60.26173814650505, 47.959216256295484, 47.63325552786551, 47.879309731145064, 50.09207171778525, 47.355324222195534, 49.83858070065899, 45.443000101274066, 46.500267136481504, 47.20530533021497, 48.719508878646366, 50.80618235372728, 59.01212984515775, 58.57734295629687, 61.14739364193332, 56.97104215621949, 66.81075880604406, 58.243015812289336, 68.18769901029526, 49.359310211673865, 36.35248753332323, 68.54224989491125, 60.85653028180523, 63.079717928363436, 52.71944392111994, 55.75409543129706, 53.17668245684717, 54.20950528114073, 45.05929423916725, 45.20356685884538, 42.92743113733108, 45.696518574991536, 44.4648668842931, 53.37802948490266, 60.50633715045068, 60.96393654423376, 62.646641192897675, 63.139126146993334, 58.52014303207398, 45.96365159557712, 44.43682193756104, 50.575362636197, 59.538111840524984, 59.18420814698743, 61.722091474840724, 59.83583150371429, 60.89260824265019, 59.70607165367373, 59.33202266693116, 58.42523736338462, 58.685298350549516, 55.249957115419456, 56.897278062758915, 56.4907753852106, 57.324404562673266, 58.162163995927386, 57.92602554444344, 59.399244246944306, 59.74304391491798, 55.149199270433, 58.879659637328125, 49.22830697028868, 18.444802568804835, 0.8763363729080847, 0.3497279014798903, 0.6610554312506031, 0.9595321731701975, 8.048070130809661, 3.9867752453973218, 0.4460831004525385, 0.05153801352266343, 0.03362569807758255, 2.985384089331473, 32.80663547977325, 48.78064294015208, 36.46597739188902, 30.372581212751328, 45.4338845129936, 19.050553806366462, 0.030166648305772297, 0.01883577315076705, 0.040303560109027935, 0.0485171641283218, 0.03175087408312867, 0.03513030625218826, 0.03707761748603756, 0.023888871862342762, 0.024308180511598627, 0.07040720342868759, 0.02906197250159758, 0.015153869359393515, 0.017361214774991238, 0.054945526644587524, 0.03402846114289376, 0.028833751078514807, 0.05430772780410705, 0.028215303619001663, 0.05345396877777192, 0.0062588799271672485, 0.061897035282585895, 0.048960790323514136, 0.029301210269031507, 0.06896460624111277, 0.07369560520014456, 0.03548173376569345, 0.04014381545505697, 0.06355830077682773, 0.013746565842490285, 0.03945406436199143, 0.006968149025323651, 0.009940967579642612, 0.03405920425129514, 0.06577466208968433, 0.021645908146315528, 0.08436739384647339, 0.07064253031726807, 0.0729047496532721, 0.04458804855183248, 0.02131424570125678, 0.039084982352271196, 0.02022487441858938, 0.07341461947127696, 0.03918175074842669, 0.023724969266162767, 0.03132583892663881, 0.029468615802245277, 0.02277281007639343, 0.048367148790989196, 0.0048247542356201, 0.07863448211742986, 0.021152752451598648, 0.013635989669109545, 0.06536606143439008, 0.013108174241478405, 0.027002008038482843, 0.08569733780478278, 0.034757795999006885, 0.013401386733617515, 0.040436047354653, 0.16455233067033753, 5.1434584298441495, 58.33166530055385, 46.134537496874415, 23.411217466477428, 57.13529925192557, 72.74990189460017, 24.476837188966815, 1.8844724734944684, 0.08128429597784435, 0.03658932836485967, 0.22328322032286277, 1.1668190792683633, 5.010226791904819, 5.813597334969429, 3.367925007497111, 0.8152413512429884, 0.4416032327759651, 11.032314281309805, 51.807324194139056, 69.56481964357438, 70.62539715920725, 72.7800178527832, 71.6160309699274, 68.63688099768855, 67.82289505004883, 66.41702344340663, 59.522269387399, 55.71478543743011, 66.9814525112029, 69.40211188408637, 70.08817365092617, 68.2651658211985, 66.27598285675049, 64.16965830710627, 66.09940559633317, 64.90987623891523, 62.125130699526885, 50.21412411043721, 50.17410416756907, 49.7410588110647, 49.80479340399466, 49.55340477728075, 50.084183831368726, 47.231879388132405, 48.173667923096694, 49.75624230600173, 51.001390872463105, 53.03751676313339, 61.35897413376839, 60.4954957192944, 62.61799220115908, 56.82465537901848, 66.31650878537086, 61.54441987314532, 68.7750425646382, 51.254403360428356, 41.16774997403545, 71.22060898811587, 61.53825782960462, 65.80244295058712, 53.43431941924557, 57.42832776038878, 54.251525632796756, 53.81353024513491, 47.75016569322156, 47.35615968704224, 45.72871731173608, 48.05916609302644, 45.49565399846723, 53.1147482318263, 63.51299470470798, 62.2785855877784, 63.93628512659381, 65.05220728535807, 60.27903579896497, 49.00400230961461, 45.44534960100728, 52.93266396368704, 62.18335043999457, 61.659957208941066, 62.44508627922305, 62.77488308568155, 63.225912509425996, 60.888485831599084, 60.7550467983369, 60.108306792474565, 60.402241368447584, 56.74084217317643, 58.18613360005041, 58.96848955462056, 59.72839778469455, 59.26442061701129, 60.0374883990134, 58.73754824361494, 61.226488236458074, 56.86809562867688, 61.96379576959918, 52.810034982619754, 22.654515774019305, 1.6210484216290137, 0.8427116094577698, 2.4078256228277763, 1.1334541728419643, 9.231451172982494, 4.020533859729767, 0.22964392578409565, 0.09581244100005397, 0.062467866547165386, 2.16969681362952, 34.027718344042384, 56.00035752019575, 45.0282016108113, 24.347373477874267, 48.845738595531834, 28.837828366987168, 0.1303018419252288, 0.026531750711822705, 0.04500465865637507, 0.05180688357100852, 0.0077954885519800655, 0.09889575337330181, 0.025821615934311867, 0.02353609411887104, 0.026120290633351095, 0.015474527909029877, 0.01609126316203225, 0.0454355601311451, 0.019417869738273082, 0.010643285387496074, 0.0345535914323503, 0.006909301023810141, 0.067998125037599, 0.009705437677762201, 0.07905082792163858, 0.033140193686009414, 0.025537085133574666, 0.038878180747551304, 0.046614519650897676, 0.04008864563318991, 0.060998693769497264, 0.09749408826352128, 0.04757527051673782, 0.2777282617265179, 0.13082681133622123, 0.2049046331235478, 0.0721509191357801, 0.10092656819089767, 0.17352869013144126, 0.19846236994189603, 0.09375752505636024, 0.1915218584960507, 0.1866293911852183, 0.13526589249170598, 0.10656746509935587, 0.10267715570667099, 0.14087374802798996, 0.13636127564935915, 0.16482858197583308, 0.08891517521753427, 0.21084259594640425, 0.2352771541524318, 0.11372993519950299, 0.14197605662047863, 0.3575051035131178, 0.12282938200740084, 0.19400727754879385, 0.22298087606266623, 0.13882483055274333, 0.13947579078376293, 0.16492825001478195, 0.10304426503998619, 0.1340819955352814, 0.17412858294142833, 0.19317734385690383, 0.15783505724562755, 0.28222213349034714, 5.06463889152773, 64.52375419678228, 60.41405162503643, 39.78337687830771, 50.40036216858895, 80.1238166132281, 39.22625518614246, 3.977873916587522, 0.22926848141416428, 0.46942791390803557, 1.8220279726289936, 12.08712689338192, 19.574188263185565, 10.933041053433573, 4.4226125940199825, 0.5280476135592307, 0.712965548999848, 9.526785054514486, 49.71427686752812, 72.09026905798143, 74.69083970592868, 74.08612005172238, 75.95224257438414, 72.81376592574581, 69.59864616394043, 67.27961540222168, 65.05828695912516, 58.49835818813693, 69.68238092237904, 72.21639679324242, 72.82189307674285, 69.78164042195966, 67.8890105216734, 67.57036501361479, 67.95500047745244, 68.69924668342837, 64.86853837966919, 50.95061971295265, 53.287171702231134, 53.090256952470355, 54.854370394060695, 53.49964257209532, 54.8270667752912, 51.47709200459143, 51.48545057542863, 52.27205053452523, 53.8810734595022, 55.402674598078576, 62.59170055389405, 64.29151065887945, 65.75936355898457, 61.037382925710375, 70.21670187673261, 63.598749483785326, 72.41471967389508, 51.886465857105875, 44.37785694676061, 73.90954279130506, 66.15609953480383, 67.28283174576299, 56.125947890743134, 60.3781109471475, 56.75818689407841, 56.95401906967164, 51.26935543552522, 49.14538414247575, 47.380317564933534, 49.48909359593546, 48.50183302356351, 59.05080833742696, 65.69645658616098, 64.1243706210967, 66.16225765597436, 67.30708768290859, 63.195212118087284, 52.24886540443667, 49.37019871127222, 56.597338338052076, 64.9772782479563, 64.1346707651692, 64.32355250081709, 61.100423259119836, 63.72122157004572, 62.668939867327296, 63.93365713857836, 64.07708644866943, 64.58944213005805, 58.26501246421569, 59.88776368479575, 61.333149248553866, 61.37455378809283, 60.86469665650399, 61.92765897320163, 62.09175132936048, 60.85251769711895, 57.778595416776604, 64.23044720003682, 51.84352767082953, 22.24068218661893, 1.5927655586311895, 0.9367853679483937, 2.7851681747744164, 4.703251315701393, 16.766100698901763, 11.155509064274451, 3.1604992862670653, 0.1881656732650534, 0.15441144095553508, 5.2150970889676005, 45.251172665626775, 59.03150635380899, 46.92311040816769, 40.660764017412745, 58.63600200222385, 32.66908972494064, 0.16507008353308325, 0.12050662640362017, 0.1201819200369139, 0.10404799343837846, 0.08359717670828105, 0.1971763228216479, 0.13808503476602418, 0.13166118833807208, 0.1409254436411204, 0.11708096465876988, 0.09085171525516818, 0.10563279952733748, 0.10363475029026309, 0.08184404578059912, 0.12036928216055517, 0.15352867784038668, 0.15211990343466883, 0.09846862871199848, 0.13570711317081607, 0.12230767613096584, 0.10788593306055955, 0.15667193659370945, 0.09850560011522425, 0.17790533512109713, 0.20183098111902514, 0.1909184876468874, 0.1096630885055469], [0.10205853204693525, 0.07847764093669192, 0.0941251093641885, 0.013817071786991531, 0.05045458516706863, 0.08154485780265062, 0.05027486477047206, 0.02597063344212309, 0.016494731028233806, 0.06268766866396032, 0.03531524370754919, 0.008822286730602143, 0.029144229277247385, 0.06956335758009265, 0.045740880642927466, 0.07553797771012591, 0.05277854735933004, 0.022150748597097494, 0.033740304831054904, 0.02701647369371307, 0.022919751485929857, 0.031831317145617745, 0.01736946745715555, 0.021125435671438614, 0.04325290285651723, 0.00951786679516156, 0.06789230531261814, 0.0327206609560357, 0.024886220663545594, 0.0711162407852469, 0.03494623064574215, 0.015093950750005823, 0.07082394759861693, 0.05147437459879345, 0.06360528494922385, 5.820495803509989, 29.458496378314113, 42.71563099276635, 28.75418382306253, 36.990076649573545, 61.264707811417125, 30.906415793203543, 2.690859441795657, 0.06863066085403965, 0.03014844031103196, 0.40121639507912826, 4.048318949437911, 2.2716514718148018, 3.070103607831463, 1.4190256427372656, 0.09772295703090007, 1.120767389093676, 15.90146714641202, 48.17939458354827, 70.98947940334197, 67.68172894754719, 65.38565189607682, 66.60244172619235, 64.64486522059288, 60.419848888151115, 55.829848166435, 60.78861836464175, 68.63566506293513, 68.30923757245465, 65.82850317801199, 66.79604991789788, 68.0316985038019, 66.81551271869291, 68.45804445205196, 63.96876235162059, 55.92171007587064, 46.78227378476051, 51.24409929398568, 51.34794404429775, 50.47844871397942, 48.096671796614125, 46.92431457581059, 46.14250383069439, 46.480635673769065, 46.13972287024222, 47.0844727946866, 49.5632734606343, 57.55527527101579, 56.95002217446604, 60.614320001294544, 60.60022692526541, 63.36508997025029, 58.67182500900761, 66.79297477968278, 51.748794586427756, 40.42923827325144, 66.13050999179964, 59.02910978563371, 64.68622269168978, 62.283853330919825, 59.37623170114333, 58.40122069081953, 60.83045436489967, 56.54085620757073, 49.37825525960615, 44.97052707979756, 48.25783806462442, 47.20475227602067, 56.10070743868428, 62.4171668483365, 66.05742839074904, 62.80078641829952, 63.67980526339624, 59.76287149613904, 49.453439251069106, 45.140106831827474, 49.97733454550467, 57.35010000967211, 62.49918360863963, 63.47248054319813, 63.897814519943736, 61.358715257337025, 64.23924507633333, 61.07951310373122, 60.30334272692281, 59.18674592048892, 61.221067520879934, 58.369096479108265, 60.25320306901009, 58.898130078469556, 61.02235240321006, 62.090543239347404, 58.14849061350669, 57.802466961645315, 58.072118143881525, 43.33533802340108, 16.729208846246046, 1.1181584000587463, 0.1291083229044753, 0.562639854127361, 2.0885221371727605, 3.2024156951135208, 4.186703110894849, 2.5198423862457275, 0.004801638490114842, 0.0273653865236068, 3.9878362465289334, 40.455078847946666, 45.21755403087985, 33.655932564889234, 27.92951333907343, 43.244417482806796, 32.05819626008311, 0.5475375645102993, 0.034692686186322284, 0.07661797016138032, 0.013920673687431603, 0.019513385580672372, 0.009864399964440494, 0.03208779189134798, 0.015395769282364318, 0.053517289775153326, 0.028531573442441803, 0.0547437314244528, 0.03239828732705886, 0.08400226868088208, 0.03378789421291121, 0.039382484936786276, 0.0548973243923918, 0.026407552537538355, 0.060101769519068544, 0.04747308587895767, 0.07138182814683645, 0.06351924561444791, 0.019120455253869295, 0.12376394032710984, 0.06751646257696614, 0.0812098169098458, 0.026717626624890876, 0.03128239791089248, 0.06498395976039671, 0.015615779200508712, 0.025690475088213722, 0.05511297431263713, 0.03138581978067035, 0.01306202702013956, 0.04351731427314301, 0.045792093620665615, 0.058215649558171156, 0.01950037357727847, 0.03393009928385577, 0.03112029945177417, 0.05050721923790632, 0.08374542238250857, 0.06967405728515118, 0.045211061895374334, 0.06781280070783631, 0.09714312040277066, 0.024737061429468375, 0.026937986070650722, 0.04347771135789733, 0.0012427129977074782, 0.030947496829133843, 0.030835377946195584, 0.06772447077016677, 0.03852124123143093, 0.03413056534144186, 0.015875617072226542, 0.016828467656347542, 0.015608581804460096, 0.039233794931562684, 0.03208737628864906, 0.06455881160593803, 0.04398661207467799, 0.0794774163213949, 0.02309156010948843, 11.371900343125867, 44.947294881266934, 39.71105229470038, 26.3658526251393, 53.71531017364995, 73.82180721529069, 29.72277391341425, 2.1412584041395495, 0.04691288025388795, 0.02439203841101018, 0.1534370843681597, 0.3908854849155872, 5.341311116372386, 6.783291572524655, 2.289253843407477, 0.2927268230386319, 1.5043178272824136, 19.965289754252282, 55.36458838370539, 75.63366766898864, 69.78404875724547, 68.95740139868953, 69.67911751039567, 66.72870282203921, 63.30166916693411, 57.540962542257006, 62.592457571337306, 70.1915987076298, 69.4128042651761, 67.48316287994385, 66.10372020352271, 67.8056993792134, 67.04453991305444, 70.50946758639428, 66.27757533904045, 58.98706982212683, 49.9388913954458, 51.570295364626, 52.94054400536322, 52.15748202416205, 49.364122959875296, 49.70909149416032, 48.66016734030939, 49.478028589679354, 48.63338931914299, 47.660151220137074, 51.25148903939032, 60.94658005622126, 61.457700191005586, 64.60457855655302, 63.33914741393059, 66.45778471423735, 60.669656799685576, 69.9412573537519, 50.741863327641646, 41.26213788986206, 68.46387309412803, 62.81293399872319, 64.99507011905794, 62.174317221487726, 59.53093390310965, 59.849748073085664, 60.739847613919174, 55.19651482182165, 49.696347713470466, 48.04666549928727, 49.093134249410326, 47.76207793143488, 57.227263142985684, 62.536905042586795, 66.29775201120685, 65.53228186022851, 64.74102604773738, 61.36438308223602, 50.79006925705941, 46.329118436382664, 49.903837173215805, 57.744364892282796, 65.01684319588446, 66.08556747436523, 62.350427719854544, 63.098655131555375, 65.49314052827897, 62.51739125097952, 60.6281110548204, 60.05292292564147, 61.991523004347286, 60.77126187662925, 60.39192161252422, 63.06973157390472, 62.49637519159625, 61.95092647306381, 60.099426546404445, 59.54323053359986, 61.32538687798285, 47.77916377590549, 19.980851757910944, 2.0524797228074845, 1.1083789506266195, 0.9702617554895341, 2.7097672272113065, 0.9463927846762442, 6.806581626015325, 0.7625324182933377, 0.04049037064936373, 0.010427706330383738, 2.6196806805749095, 40.48490455073696, 55.14224490811748, 37.4585174745129, 29.859388105330932, 45.12646090599799, 42.91093364838631, 2.29607337424832, 0.09233017301847858, 0.012933743681998984, 0.0711151682621529, 0.03126456146879542, 0.031840395287520466, 0.04427653421918231, 0.04102541411656045, 0.03727934758869871, 0.01838760022374411, 0.05649900739832271, 0.08805202395324746, 0.08724049169329867, 0.015022242047463455, 0.04313923456075211, 0.02015159619341214, 0.03947516242342611, 0.04587732856312106, 0.05243170105161206, 0.04160521627073327, 0.04916160112066616, 0.032141211202308055, 0.09162494311890296, 0.038163845892995596, 0.03697697268498521, 0.08674245027284469, 0.010711506474763157, 0.057511737329825285, 0.25957988394844916, 0.2507192497291873, 0.15245788610510289, 0.11136287673106117, 0.08441819313673243, 0.17240425691969935, 0.1622847410579843, 0.11912949909005435, 0.056296679747080615, 0.1615591178978643, 0.13484963095716893, 0.29797676229669207, 0.2018024826482419, 0.17966997268940174, 0.15305638463506777, 0.18676003981982509, 0.15850742197325154, 0.18198711286869743, 0.13930075501482334, 0.10372791424273484, 0.07797327162998338, 0.1422645500110042, 0.11304990959263618, 0.1603757265594698, 0.13944477954458806, 0.1300351360752698, 0.2348410662624144, 0.15924297363287018, 0.08077410440291129, 0.13202137223655178, 0.20549271285774248, 0.21327166157143734, 0.12840785807178867, 0.17303149906858323, 0.17236296478058064, 10.580646491819813, 52.39693095607143, 56.4046597480774, 41.25468538653466, 50.0479175967555, 74.77044813094601, 44.640432173205966, 4.960798063585836, 0.1477513176899764, 0.19825345776494474, 2.4201364719098617, 13.139755725860597, 13.316079993401805, 10.159646734114617, 4.143689909288961, 0.4560549605277277, 1.554556892764184, 18.97654260358503, 54.86345460337978, 78.22065122665899, 74.51222281302176, 72.37009094607446, 73.26302636054255, 71.17569784964286, 66.38245167270784, 60.850419229076756, 64.70007650313839, 74.35830900746008, 73.31971245427286, 66.6898556678526, 66.0603387894169, 69.13604182581749, 69.87394163685461, 73.54182843239077, 69.49698617381435, 60.59231158225768, 50.22653448966242, 55.47882741497409, 54.0474800140627, 54.87456667807795, 51.83190961037913, 49.73179809508785, 52.08663225173951, 52.93936729431153, 50.232370976478826, 51.665895292835856, 54.254235990585826, 63.39796727703464, 63.49556761403238, 68.45325916044175, 66.009489182503, 69.44012749579646, 63.612105154222064, 71.77564790171962, 55.982463667469645, 45.22748939452633, 69.79593353886759, 64.36090915433823, 68.59983028904085, 67.24945237559658, 62.63224217199511, 62.680475558004076, 66.41390123674947, 61.96766714895926, 54.53538363979709, 52.594649791717536, 52.60520096748106, 51.0948178075975, 61.14387527588875, 66.29517109163346, 69.04043797523745, 66.80325138953425, 68.3613815615254, 64.38765579654326, 52.97282118951121, 49.82238523421749, 52.557728521285526, 59.73328113555909, 67.73413181304932, 68.29333628377607, 65.46491515251898, 64.23780948885026, 66.47276032355525, 64.71702506465297, 63.22271185536539, 64.05500742696947, 66.29508479948967, 61.950863715141054, 64.36814984967633, 65.74716891011884, 65.09623589054232, 64.14362161390244, 60.27094787166965, 59.379385286761874, 63.08552695858864, 46.54146379040134, 19.835920180043868, 1.9434958095512085, 0.7959403482175643, 1.9226634886956986, 6.333914447215296, 11.64642801207881, 15.338631541498247, 5.768268464073058, 0.12516243383288383, 0.15826549140676377, 6.586688160896302, 52.04805181872461, 56.84826412508565, 44.78916452777001, 38.573804209309245, 55.0183686133354, 48.56700320397654, 1.9582146261968922, 0.18679178650340728, 0.25728097666175137, 0.18886068355171912, 0.09937234433187593, 0.17677241365515417, 0.088234850836377, 0.15627298864626116, 0.12062485675297438, 0.17513738284187932, 0.12123349828705673, 0.15943400531766877, 0.2187797571382215, 0.09167780318567831, 0.08223115000873804, 0.11516204464339441, 0.1506091167609538, 0.12838154295158963, 0.16060244261978135, 0.20906194714048218, 0.24757626676751723, 0.11451648533224099, 0.25229103232343353, 0.10983931937164838, 0.15588862701289116, 0.16387595164199031, 0.09083890626507421, 0.27841106057167053], [0.044822007973468116, 0.04112322439229296, 0.04725393110645875, 0.04335494193759176, 0.05960854296121867, 0.03497971251847283, 0.033669173567285465, 0.026573699771336494, 0.07658322041313495, 0.04439133632507536, 0.03454727120697498, 0.04015227689618065, 0.056781303137540824, 0.029805721302006035, 0.05772934077427753, 0.05761902028274152, 0.018548882799223065, 0.05188089149493364, 0.0355466750390347, 0.05784262219564088, 0.03282350059899111, 0.02579141291789711, 0.04347559695522632, 0.0459009240711889, 0.07291272462856385, 0.022137784474198858, 0.06805968020231494, 0.07395819715795017, 0.04619573002621051, 0.07402746682806362, 0.017072328764404503, 0.07672809530049562, 0.02287685056217015, 0.05081596033227059, 0.02709705656724832, 0.05595137710653006, 4.734624393524663, 34.278867706175774, 44.455468885360226, 29.750918880585704, 34.898178577423096, 57.28378057479859, 43.12817412038004, 5.793672184790335, 0.022125678369775418, 0.09575948134184846, 0.33972965733658883, 4.771538799808872, 4.822056476146945, 1.6236635393673375, 0.3260246508063809, 0.048818841892024206, 3.577866929192697, 27.723924267676573, 50.77767456731489, 70.4325185283538, 70.02505487011325, 66.58045291900635, 66.43548211743756, 67.21247226961198, 64.30858473623952, 64.60675547199865, 67.13165575458159, 69.2282175248669, 70.95178542598602, 68.27572484170237, 70.24512337100121, 71.29627150873985, 64.22467739351335, 58.137013758382494, 51.81763610532207, 51.090687551806056, 51.90664645164244, 52.35687571187174, 53.23964434285318, 49.90429609052597, 51.422382785427956, 48.82154541630899, 49.645043111616566, 45.61910275490054, 48.91210117647725, 46.00516596148091, 54.0852524388221, 58.036499100346724, 58.64517250368672, 58.72849149088706, 69.1586660569714, 62.89401331255513, 69.69007661265712, 50.31387390628938, 39.62182229565036, 67.33523461126512, 63.53167303146855, 68.78218912309217, 61.78552796763759, 65.44233798980713, 60.333988205079116, 63.703131598811, 58.41165811784806, 52.33964866207492, 44.348698046899614, 45.21948383700463, 46.47745463155931, 58.37734130121047, 61.70425253529703, 65.96459373351067, 65.13157252342471, 62.880991043583045, 62.085479459454945, 55.65247858724287, 50.71038630700881, 48.09348683203421, 53.91926165549986, 62.16021237834808, 63.1394713155685, 64.5297161994442, 64.32794947778025, 61.462050099526685, 61.91263237307149, 62.240699414284, 61.802998204385084, 57.1877452634996, 59.161042628749726, 60.87865244957709, 61.50049324958556, 61.25402327506774, 58.019738812600416, 60.41837407696632, 60.156049882211995, 36.26363015943958, 13.626756225862811, 0.6206157947740247, 0.24686202767395207, 0.43297846170683063, 1.5196796674882214, 3.4091008238254057, 1.7984135881547005, 0.6644128575440377, 0.051142662358019626, 0.15231304952213842, 3.329296035151328, 43.62179263945549, 40.57311473354217, 36.24483808394402, 57.32001150808027, 34.51274295007029, 38.05881661753501, 2.673718929290772, 0.14792266091512096, 0.077780700108457, 0.025632650771689032, 0.08820568586909965, 0.056493874609230034, 0.008592588673045319, 0.046006475665396264, 0.04729324673873283, 0.08515844091532693, 0.11801238967886857, 0.05104780918167484, 0.0431159301660955, 0.06916902148194852, 0.01473263112617837, 0.08157552430225957, 0.05798855428433707, 0.07008500216949372, 0.07834402754181817, 0.039081699665515654, 0.04763501005307321, 0.03284587802725934, 0.004033864693595998, 0.05688202071694597, 0.029399060764380043, 0.02711668948552782, 0.06181364661202796, 0.07736838392673001, 0.05267444750173919, 0.017659152114403345, 0.01327328438374905, 0.06519316305075923, 0.08179884659306658, 0.031897122183093624, 0.01635897067195225, 0.030037895738778096, 0.018609193071062048, 0.06660422805937068, 0.03195444662724772, 0.01057155944797541, 0.07788406835208017, 0.01817127806134522, 0.031652234517218124, 0.019663259191738985, 0.04247625057976093, 0.05237645079051295, 0.08262656629085541, 0.07721207900753907, 0.06628155182566374, 0.03810085431342164, 0.03812057724703224, 0.08092092515359964, 0.04484189178554281, 0.0336019033866544, 0.07553666769977539, 0.055958777515878605, 0.06950544133301705, 0.011473785026840145, 0.04225443748216476, 0.06476259865467587, 0.02270597465065939, 0.06428849748185565, 0.04168382455264369, 0.06847163632271752, 0.05107022491433928, 8.640298016609686, 46.43254741545647, 44.504298471635394, 27.253959601925267, 49.50943893001926, 70.90285778045654, 37.33830467347176, 4.181239249244813, 0.04288055348179994, 0.05094920217450108, 0.19843531171641043, 0.21789815847671803, 3.170908521259985, 2.018400945009724, 0.8002227184272582, 0.3309362243500448, 4.7600879303870665, 31.000048652771984, 59.5386335157579, 71.84801563139885, 74.39571272942328, 67.78023535205473, 67.89537260609289, 69.87940942087482, 65.03307004128733, 67.00587318789574, 68.6377674533475, 73.73603282436248, 71.96293323270737, 66.8811418164161, 72.1955297839257, 71.31589904908212, 67.26284334736486, 61.33467897292107, 54.46770314247378, 51.84323741543678, 54.99949809043638, 53.411381398477864, 54.82857688780754, 52.4600262026633, 54.16398617529101, 50.58512541555589, 51.3358082309846, 49.72298452931066, 49.89112084911716, 50.88561819445703, 56.511261924620605, 61.85802513553251, 61.59423397433374, 60.03731581472582, 69.30522149608981, 64.58734366201585, 67.5845875278596, 52.25878115623228, 43.84073149773383, 70.32674789428711, 63.76308502689485, 70.27938919682657, 64.09280730832008, 67.03895445792907, 63.201021148312485, 65.66977270187871, 60.810983719364295, 53.88087734099358, 46.38235284436134, 47.77129550133982, 48.67879859862789, 59.46314357942151, 64.30973399070002, 66.49985605670561, 66.44144412009948, 66.01245449435326, 63.42758901657597, 59.48532850511613, 50.99810784862888, 49.79291646711288, 58.22158005929763, 65.27117360022761, 65.52227197154876, 65.58111144650367, 64.32194825141661, 63.73693066258585, 63.33877086639405, 63.5743837202749, 61.25942830116519, 61.18908843686504, 61.286033738044004, 62.554269375339636, 62.263205974332756, 63.2727534540238, 60.3008363323827, 60.36788532810827, 63.222076431397475, 42.901853361437404, 16.713676260363673, 0.9512146646457335, 0.7316488400101663, 1.1924375497525739, 3.3507886625105336, 1.6188626808504907, 2.80324932067625, 0.476175555058064, 0.11265790240178186, 0.1477463074749516, 1.8411648489775199, 42.51305234047675, 51.091260217851215, 40.20649863827614, 55.825078564305464, 35.417049315667924, 45.1464649938768, 6.0651575653783745, 0.17227579929655598, 0.04956688844568787, 0.03344267967247194, 0.10603655084607103, 0.07953347863569375, 0.05294866867423539, 0.06119501146097338, 0.042175959435201464, 0.034745902483982426, 0.022531614954312964, 0.039194735938743244, 0.07094457580317413, 0.01322839258899612, 0.025545309087441816, 0.04472024851448594, 0.006431768734699056, 0.04910176582334023, 0.028507407198870377, 0.05938316372433498, 0.025274384008239836, 0.027603277891513803, 0.04505479145013998, 0.009694543907478934, 0.029020228370603536, 0.03495172349615924, 0.04202544614071808, 0.03184231050733117, 0.0074318438513024205, 0.14380253280603117, 0.13677735332279436, 0.12777112409352295, 0.18765855370269668, 0.1526032129843389, 0.13876075495875653, 0.11115115301142778, 0.1860262501624323, 0.11492529283127478, 0.1991255109709117, 0.08622236084192993, 0.1382557804425878, 0.10145153760189012, 0.12872432899330893, 0.13168185739026916, 0.14379053586913695, 0.11594624288620488, 0.16109690640962895, 0.20290220186354654, 0.17826797050093451, 0.11572067595777974, 0.07750955860941641, 0.16784214204357517, 0.11917813801236692, 0.0748952299416546, 0.2500616551767434, 0.12673364952206612, 0.21434423063070546, 0.1439501732707985, 0.13315722015836548, 0.14949173155811527, 0.12040936388075353, 0.22717692348505222, 0.15248704341150102, 0.09311496114899075, 0.1864279713481665, 8.712118575649878, 54.75102378476051, 60.51477416869133, 42.9756566785997, 47.05298792931342, 68.88919138139295, 56.60259431408298, 8.909752099744736, 0.110361170804789, 0.11827036212649077, 1.8801711043042524, 11.5796467181175, 13.630581517373363, 5.104323962042409, 2.0611324714076136, 0.6709534098063746, 4.445728102037984, 30.906704087411207, 57.00143268031459, 76.40182464353501, 76.11822943533622, 72.761825899924, 70.64925301459529, 73.54859059856784, 70.52248201062604, 70.27227401733398, 70.91184000815116, 76.52246106055476, 73.13988747135286, 69.02470142610612, 73.59342328963741, 76.94873640614172, 67.01597721345964, 62.15072416490125, 56.188164526416415, 55.2859095604189, 59.519531573018725, 57.16648993953582, 59.24802510969101, 56.15714642309374, 58.92438250203287, 53.72653991945329, 54.82418383321455, 51.80174266138385, 54.86803985411122, 50.75936886572069, 58.40757885286885, 63.82957312368578, 63.81594288733698, 62.61141830875028, 74.46403257308468, 66.12005295292025, 70.43546030598303, 53.62111837633195, 46.95913345583024, 69.52296795383577, 67.58843929536881, 74.14770910816809, 67.04121374314832, 68.99665647937407, 65.52934792733961, 67.19202103153353, 62.64224813830469, 56.538738127677675, 48.401490949815326, 48.809472360918605, 50.77810210566367, 61.4134793896829, 67.30643656945998, 67.23853249703684, 67.10954143155006, 67.40801811218262, 67.94047986307453, 62.02483569422076, 54.26112759497858, 51.843092287740404, 59.71750536272603, 67.02040164701401, 67.38172254254742, 67.57636623997843, 64.64883858157744, 62.91683758458784, 66.04275872630458, 65.87788581848145, 63.4898840996527, 60.75423094534106, 63.16122478054416, 65.32683203297277, 64.81503332814863, 62.62088691034625, 61.451212590740575, 62.328493825850956, 65.00760601412865, 41.77118309082524, 16.664599564767656, 0.9096292670696013, 0.7413430391780792, 1.1210392583762447, 5.965765195508157, 12.17230998700665, 10.79776340915311, 3.573904354726115, 0.23564484571256947, 0.2721720711598473, 4.99777767927416, 56.55052877241566, 51.94715669078212, 48.39450128616826, 61.415750442012666, 44.84457585119432, 52.48954988295033, 5.641718093425998, 0.2513758177238126, 0.2214488840752071, 0.1413780483867853, 0.19546574041728051, 0.26689286734307965, 0.11010383421014394, 0.19075321183810312, 0.1687086947382458, 0.14444811509982233, 0.1912382221029651, 0.18160198514740314, 0.29692798792835207, 0.1540625032277838, 0.1947919967313928, 0.10717695699103418, 0.061315547734979665, 0.20871751400972569, 0.11664428688105076, 0.16166620166792026, 0.12128152433902988, 0.13247731712556657, 0.11318169203737091, 0.1251169128884231, 0.12378799548793225, 0.14983360595520467, 0.13100676538963474, 0.2055908640426013, 0.1316901311398514], [0.03374982730395371, 0.04572273202000126, 0.003904992904168584, 0.03268987571279849, 0.03696872191804071, 0.04255464435705254, 0.03705389940390184, 0.028662197179191058, 0.05968957208096982, 0.03550416098967676, 0.02919231853147428, 0.023667407334752144, 0.037400083045565316, 0.00852242459528028, 0.03750571124856511, 0.03969457000494003, 0.08559741695681888, 0.019104003515695373, 0.04834361073951568, 0.01641825821641232, 0.05902610546458633, 0.060070325440216454, 0.03128537416247831, 0.08666699061230307, 0.018908133985654964, 0.03888547773503008, 0.05181581998664526, 0.025906772352755073, 0.052315822592185396, 0.040771907961536805, 0.04942478296617347, 0.06281237245627469, 0.031182923309144475, 0.037683600695022655, 0.020429607585913712, 0.08798611740912161, 0.10576925510841031, 5.987784401062997, 35.51712859061457, 47.44655070766326, 31.378416169074278, 32.868310828362745, 48.83370868621334, 54.753216389686834, 9.060047518822456, 0.15458947978913784, 0.0981353498214195, 0.6061378361717348, 4.173996592721632, 2.4684649753955106, 0.7588917846160551, 0.1509478195540367, 0.18242788921681144, 6.782476700121357, 32.06407000941615, 58.64603542512464, 69.57227214690178, 71.9324956401702, 71.68562166152462, 65.30767125468101, 65.64709747991255, 71.54472228019469, 74.6558286297706, 70.26067949110463, 67.28354561713435, 70.43940621037638, 72.44673405924152, 67.59913167645855, 64.61589459450015, 56.96771206394319, 53.33715446533696, 53.6998168114693, 53.54737781709241, 52.61681118319112, 50.4100465005444, 49.92044841089557, 49.846233244865175, 50.70782107691611, 49.792802718377885, 48.87915718939997, 50.98650940002934, 50.69646973763743, 52.336075382847945, 60.685632613397416, 63.22469657467258, 63.34605863017421, 65.27451153724425, 62.192611155971406, 67.47829914093018, 53.49378647342805, 38.52014618535196, 59.05073381239369, 62.08949988888156, 66.78663622948432, 66.39601522876372, 67.12216361876457, 66.36530307031447, 65.98227577824747, 63.97124128956949, 59.87498068040418, 46.84599661057996, 49.94148800449987, 51.755839163257235, 63.571936161287375, 63.4892604427953, 67.57939430975145, 61.66816280734155, 66.18958088659471, 63.44522007050053, 60.35327057684622, 57.402224386892016, 55.085084207596324, 50.45049005939115, 58.898934164354884, 63.651168038768155, 65.33055043989613, 64.78828276357343, 65.28878504230131, 64.08286802230343, 60.89129424864247, 62.968361839171386, 62.8696906951166, 61.55184099751135, 61.53540626648934, 61.872612430203354, 59.58537640110139, 55.73024742064938, 53.44425870526222, 23.729670778397594, 4.16027614185887, 0.08252851469742675, 0.16417573716851974, 0.9043378058460452, 2.0950896557300323, 1.6930783371771536, 1.5409846339494953, 1.2669030120295863, 0.04254503761448207, 0.17795707669950303, 4.003208750678647, 43.72324082159227, 46.542181584142874, 51.27487813272784, 53.748736612258426, 35.87354260106241, 34.851627888218054, 5.0788207111820105, 0.08923528505669487, 0.06561128617895227, 0.07246061784004973, 0.020694059222155524, 0.04289991252364651, 0.02659377127495264, 0.02335370007541872, 0.04498217014535781, 0.02808454198642604, 0.05108538196392117, 0.029218961154260946, 0.037333126960983204, 0.07828111640147625, 0.054181947658259066, 0.0503014326996861, 0.030791327890549457, 0.018000928835282405, 0.02345959066353258, 0.01948141673159215, 0.025839475359046654, 0.014330038515430306, 0.023496518016702706, 0.036537617429970734, 0.03507528581746644, 0.015244193040885994, 0.05933661239161607, 0.050914724387468836, 0.03178329683930403, 0.06262724730937232, 0.02883119426006752, 0.047192847085816246, 0.015471980666681645, 0.0924080458559817, 0.021014783846875353, 0.02593785062462332, 0.06199255112498518, 0.05450778783509328, 0.06002314591539964, 0.0603005463527816, 0.025063627474610845, 0.03435545811249364, 0.03537363492913785, 0.04056068602949381, 0.020001249523052288, 0.03276663006193215, 0.04737393494935767, 0.08326951324218705, 0.036893381001127344, 0.03262851207006363, 0.06981491787178863, 0.01642885704284474, 0.04790253944755082, 0.04475069284859685, 0.04098788346914996, 0.01283446155984195, 0.008156995867348967, 0.04200149440176545, 0.019826073943066503, 0.04680431410369854, 0.044180627671941634, 0.025004744041530837, 0.02312639795784508, 0.034756076131616874, 0.018429767618316318, 0.0411723229673601, 0.1343441201794532, 11.814138754721611, 44.98877786820935, 48.13999437516736, 28.20860762749949, 43.412647939497425, 68.34719042624197, 52.52433346163843, 6.321392280440177, 0.0733639580768443, 0.18142702598725596, 0.3514014052287225, 0.8642421734909859, 2.7219059823020815, 0.9874204089564662, 0.32900185234123663, 0.4676431741925978, 8.795029636352293, 35.8185705830974, 64.03891786452263, 73.19577340156802, 74.92966498098066, 72.01470851898193, 66.96423330614644, 69.24345985535653, 72.98661693449944, 75.35984700725925, 70.46380335284819, 68.01300448756065, 70.52313312407463, 73.45816427661528, 69.71467771837789, 67.65955971133324, 58.3535050576733, 56.20494834838375, 56.972462054221864, 56.69033381246752, 53.552292546918316, 54.03069619209536, 52.72838692511282, 53.04271390361171, 52.64466785615491, 52.1589489906065, 50.93646387900076, 52.26892832786807, 52.87506788007675, 52.38981185420867, 61.153728269761615, 65.62235909123575, 65.54062474158503, 68.0647405501335, 65.05214844980549, 68.55726472793087, 54.96117261148269, 40.91233699552475, 62.12568767609135, 64.78192460152411, 67.60057510868197, 67.20866757054483, 68.74928043734643, 66.90106745689147, 67.76292985485446, 64.77661371231079, 60.879425156501036, 48.333194640374955, 49.411438511263945, 52.5909000058328, 64.50122802488266, 66.492262348052, 69.3499522055349, 63.7122001186494, 67.81302636669528, 66.55462018905148, 64.58950096561064, 60.126208489941014, 54.94817387673163, 51.628193470739554, 61.04780466325822, 64.78165395798223, 66.3942030937441, 66.51618880610313, 65.3998940221725, 62.738507024703495, 63.1998993504432, 63.33056526799356, 63.2313959829269, 64.0324341866278, 62.06903688369259, 63.16018927481867, 60.8351259077749, 57.118958657787694, 57.396109411793375, 31.378604442842548, 7.727084928943266, 0.4004784991904613, 0.7898442495253779, 1.5971002679678703, 3.5652677859029467, 0.6626865243719471, 2.614002069157939, 0.4955572118201564, 0.048086856371693076, 0.04042237268520459, 3.2726665706403795, 44.25888361469392, 57.15188695538429, 50.82481361204579, 52.773223538552564, 44.26371597474621, 42.49388371744464, 11.916591063622507, 0.14908363652085105, 0.07042257115244865, 0.04521867297890206, 0.07353024512168861, 0.052859997827439546, 0.10101069230586292, 0.03333830402322835, 0.026165560684016636, 0.0955497877552144, 0.015898592049075712, 0.020420270889336546, 0.007610153688508417, 0.005121295379790208, 0.02524142690573729, 0.04441350307916442, 0.06502239439155787, 0.04852939472203294, 0.02426164641585802, 0.006740878030071937, 0.01278522413133854, 0.022496432366390384, 0.032372420368295525, 0.025430280985611103, 0.04336574760776374, 0.03394869606821768, 0.09593672344400998, 0.00848945600145887, 0.05805082574126221, 0.10427243421755492, 0.0965650457768671, 0.10998065493279889, 0.08375789429391585, 0.1399273842933678, 0.07329822773294103, 0.14141166432490274, 0.1692315650683257, 0.21032985329868334, 0.2223402886621414, 0.19233620995956083, 0.14602236449718475, 0.08695012138735864, 0.1538785042301301, 0.12274960161096628, 0.09312548719707037, 0.16940264782357603, 0.15746908172244029, 0.14989504620673197, 0.18636388043242116, 0.11594912337680018, 0.19722326868964782, 0.1427199126731965, 0.12264964245860616, 0.15238297802786674, 0.18121442126650966, 0.14010281842802802, 0.09838960674260894, 0.1043531109368609, 0.1608682598077482, 0.09110660802933479, 0.2008572680455062, 0.10439800368922372, 0.06669398292057938, 0.1780526997942117, 0.10712062654596184, 0.24975604738198945, 0.23643721045265276, 10.100189485857564, 54.808517886746316, 66.70083045959473, 44.27942114491617, 48.10571285986131, 62.48097596629974, 70.17714085117464, 13.770931766879174, 0.38884284936131974, 0.24744898891977726, 2.8428125525674517, 11.993694074692266, 11.812973810780434, 2.460070367782347, 0.9858999389313883, 0.7627361976811964, 7.758274635960979, 35.09077087525399, 64.57280343578708, 76.71916007995605, 79.55552793318226, 78.58194858797135, 71.07541068907707, 70.5531314111525, 75.32729917956938, 81.80887468399541, 73.20129609877064, 66.90811203372094, 69.58443933917631, 77.04047279973184, 71.84685460982784, 71.55053523279005, 61.19877276882049, 59.97831160022367, 61.146169862439564, 58.40849276511901, 56.224301322813965, 55.40724415932932, 54.62149535456012, 54.108512093943936, 57.42770410353138, 54.89715168553015, 54.25927623625725, 55.037533313997336, 57.18760013580323, 57.69611581679314, 67.81648589718726, 67.82087895178026, 68.8948082154797, 72.31981400520571, 67.97449465720885, 69.66605601772186, 59.45989193454866, 46.287811956098004, 64.42157253142327, 66.58919195975027, 69.15322965191257, 71.41730800751718, 73.19001536215507, 70.34708930600074, 71.13421486270043, 70.34224910120811, 65.32678104216053, 52.14054522975799, 55.09559223728796, 56.947660907622314, 68.71279455000355, 68.1567201306743, 69.16061155257687, 64.23651118432322, 70.62807221566477, 68.53973173326062, 65.64970585607713, 62.27306289057579, 59.374074397548554, 54.27935092679916, 63.2979311481599, 67.51181971642279, 71.0678405146445, 69.5165038877918, 68.60250534549837, 65.30536097864952, 64.89084097646898, 65.35353160673573, 66.32244725381175, 65.2253681613553, 65.64799178031184, 63.92199593205606, 63.0411139611275, 63.52560904718215, 57.2673301542959, 28.569655918305923, 5.82119006303049, 0.24309832963251302, 0.4790520313526354, 1.8409471574329563, 8.23295202947432, 5.481210783604653, 7.60347927770307, 2.4752158647583378, 0.2863514393327698, 0.24812368255469108, 7.264907148576553, 55.75707643262802, 57.401455602338245, 61.50483923573648, 62.053657270246944, 47.73084409775273, 52.40810971106253, 10.00970923131512, 0.25267830509091577, 0.12858877739598676, 0.20565256476402285, 0.16799434839237123, 0.14132411579691595, 0.3478380851447583, 0.1169686791517081, 0.14522598545637824, 0.20453303451499633, 0.17547691300992044, 0.18528651566274706, 0.08534276933078805, 0.19304427438445632, 0.1940391468064439, 0.14100395233160065, 0.21750503279749425, 0.2003051025132018, 0.13959853339099115, 0.12326072015228773, 0.13126864488567078, 0.12690002849746135, 0.0883667711769381, 0.13467234288973196, 0.1557282694885808, 0.14060950898114713, 0.15988435776483628, 0.16703013480911333, 0.22448383331779512, 0.22087015061368867], [0.08807788708157117, 0.041417153176641276, 0.06948739996240025, 0.028168962960461938, 0.03605172999443547, 0.021645624693783543, 0.007623569324477426, 0.025935567682608966, 0.041124350541541656, 0.02280695653039842, 0.038083540726332896, 0.04235679065928825, 0.031105073454279094, 0.035563927339089495, 0.011292761323162386, 0.02144415314579683, 0.04302432137211004, 0.018601785000834255, 0.04905008553196827, 0.03649055281834256, 0.032529192601120284, 0.028959701678925948, 0.021584088681265715, 0.019548324935678995, 0.029383390435888886, 0.06652434041062671, 0.05213409121478758, 0.022407355492994673, 0.060562697810030756, 0.020058958926388336, 0.017022536879765893, 0.007158169952867132, 0.05203122475875482, 0.09238225167557117, 0.06627284140596468, 0.08026528412536268, 0.01333430328691799, 0.02113195507967424, 6.340810954570771, 42.54766725724743, 49.90754773539882, 33.60580075171686, 27.051618253031087, 49.00883859203708, 61.39834296318793, 15.864312494954756, 0.1074290612051564, 0.06378350381348884, 0.18957890630249055, 1.3596337264583958, 1.7278122733677588, 1.2552696298207007, 0.1825179964784653, 0.21074602290266947, 7.302970319024979, 36.707148244304044, 69.4078306997976, 70.39964906630978, 67.95342368464317, 76.98139406019642, 71.6491122399607, 74.23905326474097, 72.86452139577558, 70.36662270945888, 69.91237301980296, 75.05357265472412, 70.08847959579961, 65.79325675964355, 59.21378281808669, 57.106171731025945, 54.91811675410117, 56.573270674674745, 56.475427150726325, 53.8932288846662, 52.35994300534649, 51.3970011280429, 54.93719516261932, 54.89815188992409, 54.404815781501036, 51.6444242385126, 51.999355593035304, 51.83833837509156, 53.67966759589411, 56.15343193854056, 61.9643880474952, 62.11124943148706, 68.09010259566769, 63.45274317649103, 69.67594823529645, 45.24175113247287, 40.26611082015499, 68.28193787605532, 63.860218601842085, 67.965575187437, 60.70260470913303, 67.8807500100905, 66.26752622665899, 66.95007354982438, 63.98429101513278, 61.886356415287146, 48.39528183783255, 45.92796194937922, 53.606044707759736, 64.04152624068722, 67.41297598808043, 65.5263473141578, 64.98707632864675, 67.7595801507273, 64.86709102507561, 69.30103240474578, 64.56256212726717, 62.92283488858131, 55.8996977344636, 51.87684820544336, 58.6187945642779, 62.22380184358167, 62.78753272948727, 64.16742255610805, 65.59086638112223, 62.0284011287074, 63.02590300959926, 60.4546481563199, 63.06031788549116, 58.59094181368428, 66.65785697198683, 63.00423191439722, 47.28407436801542, 11.106865790582473, 1.1990252930310465, 0.058097924826846975, 0.9423924573967535, 1.7650785898008656, 13.918036337821716, 25.965586516164965, 2.7078808123065583, 0.16307629374486787, 0.18992173064860607, 0.056429477258315014, 7.646408638646526, 47.35993300714801, 44.2704624514426, 27.44705004076804, 25.430416368669082, 39.602100618423954, 39.71750459363384, 8.514777268132857, 0.3939112257813254, 0.014811038310008665, 0.0907623204552839, 0.09936465280911616, 0.03327008772401079, 0.0482513890751908, 0.028378154759505586, 0.08981854609784581, 0.02881447822155972, 0.034880507962718126, 0.08511560127860116, 0.060348760096296195, 0.035591349456339114, 0.0850431600044812, 0.05483010783791543, 0.053253740207442356, 0.027007581328131983, 0.031106241738363623, 0.014640182508305918, 0.005856819268721607, 0.06220600620332745, 0.12170032928547553, 0.0926609161580282, 0.09826858783321035, 0.10881534326941737, 0.03214440578895231, 0.04252011677430522, 0.009573576709015236, 0.020978846662347356, 0.028976009775614067, 0.01754935447787566, 0.07876697702393418, 0.019771442297966253, 0.04958454677234254, 0.01796415278447732, 0.03272814946549554, 0.01584637453854685, 0.032010589380778616, 0.044391646590684695, 0.0030896649179574585, 0.0354107097542334, 0.041520758907520966, 0.02309801248503068, 0.028650887806208867, 0.021930618977714932, 0.027958397948814016, 0.05585518327631778, 0.027545813636313525, 0.11730064037105731, 0.022332736613949942, 0.0540131823189797, 0.036540777542658394, 0.06249304402679686, 0.031308854757357514, 0.024459000241251725, 0.03024937239505591, 0.014408209169613979, 0.08053471724833212, 0.0503614786711912, 0.026990507143519582, 0.022871430490105864, 0.02475534603300114, 0.05399786439093371, 0.04440620609168564, 0.04241571048154466, 0.10265170626582638, 0.09438687394703589, 0.08867073188265485, 12.069271283764994, 52.25492938872307, 52.99821853637696, 28.797906483373335, 32.66216085803124, 68.45558120358375, 62.74391989554129, 10.220039467657767, 0.1272311546809731, 0.06804563014978363, 0.12240099330102244, 0.6034441484558968, 0.9730133594524477, 0.9335956842668596, 0.10487477850889969, 0.8356446015738672, 10.065683414859157, 44.0500880056812, 73.8323897700156, 73.07384260239141, 71.62316968364101, 78.38288045698597, 72.53061002300632, 76.33808612823486, 74.279798846091, 72.5599571966356, 70.20171057793402, 76.1374568939209, 71.50946017234557, 67.58166143971106, 61.61990980948172, 59.30591144869405, 57.36485204389019, 59.4991038691613, 57.948069264811856, 58.00027993417556, 53.98480053870909, 53.41083226665374, 53.134987661915446, 56.06016189821305, 56.64621499276931, 53.39469955813501, 54.059980607801876, 53.898998691189675, 55.6746909695287, 60.091797536419286, 63.88508642873457, 64.57918905442762, 68.64478065121558, 66.97697316446613, 68.38994426112022, 49.501186263176706, 45.52815868008522, 67.77560695525139, 63.79590742049679, 69.77570979825913, 61.86101790397399, 68.28703695727934, 69.81880095697218, 69.08828304659936, 65.92212230928483, 63.578408072071696, 51.31993047652706, 47.80947977496732, 54.68477495255009, 66.36107475526872, 68.70750719501127, 66.85972567527526, 65.53523932733845, 67.94811279542985, 66.03775378196471, 68.83565102854084, 66.33953309828236, 63.54098473825763, 55.911315794914, 54.910883903503425, 62.0054631079397, 66.08457903708181, 64.82119144931917, 67.80870391476539, 64.38822061784806, 63.28414793937438, 64.64892487372121, 63.87868119824318, 64.06496632483699, 63.397453446542066, 64.37847352796986, 65.26357204683366, 54.480529292937256, 17.95816782982119, 2.1190747041856093, 0.0787490122621098, 1.3384682492863749, 1.564504513817449, 12.418060206597852, 30.62052207608377, 2.742704840437059, 0.21928692266585367, 0.18279522837650392, 0.1256065656461062, 4.651262750548701, 48.031317264803, 56.86277689472322, 35.00066226528537, 34.879508095402876, 45.59713748193557, 43.932962109965665, 15.857725854842895, 0.2840990489048343, 0.017461488023400307, 0.06332216566548714, 0.11638064538278889, 0.013954123959035404, 0.0627958556006272, 0.02408595947218278, 0.03990125286603167, 0.09866884579100917, 0.051289927439704064, 0.051265297712938446, 0.04263770744024266, 0.025723089366370154, 0.021609687509255546, 0.1201728648776489, 0.058839471124473124, 0.004555692186488981, 0.04460011826707952, 0.0560230637840446, 0.03158024331975368, 0.0344369545458786, 0.06588606659563319, 0.06972884789349572, 0.10585581538297477, 0.06567336994433595, 0.029078232717790434, 0.04540263750259915, 0.07654235728325383, 0.058721865136777206, 0.016376481526681495, 0.2600883518255526, 0.21158743259166518, 0.1765009887035816, 0.1566390101347239, 0.07865325127157473, 0.14498279850569465, 0.11091741192485056, 0.14190589828837302, 0.15994975103005288, 0.20562126241143674, 0.07718396358071797, 0.11822003781074479, 0.12315185905824746, 0.1359830427193834, 0.13053903806834452, 0.14280565323368197, 0.14653136863583519, 0.09834144279480943, 0.19516385580983855, 0.1612354763933728, 0.12495493891859248, 0.09092343640663932, 0.1764263717397567, 0.061609985967797626, 0.14426443785909684, 0.22697977841861788, 0.09024191692832018, 0.10114995942961785, 0.16554131953706666, 0.09694414438619729, 0.13090175005697435, 0.11809505822677767, 0.1324037113978017, 0.18331811402834233, 0.17533566171844162, 0.15750041471854334, 0.13102789409458637, 0.1495352453522144, 10.278174877166748, 59.059190442485196, 67.39661185972153, 47.821705802794426, 40.4746122514048, 63.48337296516665, 75.89411304843041, 21.881716674373997, 0.38405332894575217, 0.19757510222975286, 0.6756773530956238, 4.7763044795682355, 4.462483486821575, 1.8057951210967957, 0.27732388987656564, 1.143077340337538, 9.01686026204017, 40.75155119742117, 75.81267679891279, 76.56281440488755, 72.88017165276312, 84.46193448958859, 77.44876800044891, 79.59266493397375, 75.65906109348421, 73.64176257964104, 70.80766970111479, 78.52505853099208, 73.88718528132286, 72.20514743558823, 61.28622201181228, 63.17815765257805, 59.5289138824709, 63.64253490201889, 63.53693292986963, 61.56854244970507, 57.442444370638945, 57.000252046892726, 58.41255241824735, 62.23485508272725, 62.13197131310741, 57.3178542044855, 57.1203746334199, 56.07670253322971, 59.26051785868984, 62.127464509779415, 67.86660594324913, 67.9289794737293, 71.3403981731784, 70.65901971632435, 71.98117225400864, 50.3498028170678, 47.78543564581102, 70.50763976189398, 64.7910637240256, 71.02525141931349, 63.24104109118062, 71.00666722943707, 70.72493122469994, 70.87962165955575, 67.72027015686035, 67.7263576753678, 53.35460116786342, 50.12655719634026, 58.519429160702614, 68.86344494358187, 73.50819018579298, 66.47317609479352, 67.51483209671514, 69.25032400315808, 67.96295504416189, 74.84505945636381, 70.22626461521273, 66.67443290833505, 60.65941941353583, 56.07979336092549, 63.18120533420194, 66.96944221373528, 65.08212712503249, 67.36482497184508, 67.94989355148809, 63.41744576731036, 65.08453938268846, 61.90197137094314, 65.6510865303778, 62.23630635969101, 67.23015431434878, 64.49465413247385, 50.81141087316698, 12.75904949634306, 2.1367376273678196, 0.16372106398545927, 1.9094029357356412, 3.4977598728672152, 25.186846986893688, 47.92325988892586, 7.108496754400193, 0.5824201217582149, 0.468320150769526, 0.291533196765569, 11.665704500290657, 60.37300009881297, 55.780061521837794, 40.24373369832193, 36.089704421258745, 51.49536632722425, 55.757774614518695, 14.683790860637544, 0.36196024187149545, 0.13521131638798023, 0.11859542089364222, 0.14289762974987108, 0.1650776984470506, 0.12104289561149575, 0.12237233395177512, 0.30504579265271464, 0.20639188557622895, 0.11694920519667289, 0.15519910191576328, 0.2216345837880527, 0.08193742423768967, 0.12086826586915601, 0.31200052269043466, 0.09354116650478494, 0.10289189781272605, 0.09121877862320793, 0.2032665839238513, 0.11398571663566175, 0.22091836818764288, 0.1658117026090622, 0.19035070924268616, 0.13693509082640373, 0.4301745492604471, 0.11781485390759285, 0.10404303684950837, 0.17411375147921426, 0.15930671214817033, 0.18241806796962218], [0.10899191887508478, 0.03147719300261909, 0.05116729591522486, 0.07793786304612314, 0.03054872891234775, 0.1120783951914599, 0.09453170286912112, 0.02598898124790961, 0.0308360961536246, 0.03331145647192194, 0.06458655164967622, 0.039368634067115285, 0.04655013762174114, 0.0341499014006507, 0.029946327164408662, 0.0563823513596529, 0.10896083868799672, 0.042764583091822364, 0.0031877308755346966, 0.02319495516618894, 0.042154715817061164, 0.029005749308834636, 0.07206838082281813, 0.025685803867095423, 0.05976057694023175, 0.07343174153638464, 0.0549300593293963, 0.05098550708123273, 0.049382073564394835, 0.08140493950416004, 0.025474377006532687, 0.0674568762582156, 0.04412318639937909, 0.06396440781592842, 0.04493287621786998, 0.008891521926758992, 0.0539588820069067, 0.032163412430353706, 0.02023965225464875, 5.293217464800804, 42.06850659462714, 47.185493438474595, 49.86827696523359, 28.9422163655681, 49.55487566609537, 66.83432440603933, 30.796108938032585, 0.13586235322779225, 0.38367601532128554, 0.270561570481908, 2.899784734172206, 6.549626175434359, 0.030955063862605926, 0.18322111197536994, 0.05297122613316583, 5.611410429400783, 30.23940105592051, 67.71888163781935, 72.12573512907952, 72.78496788394067, 72.49919968266641, 80.6383688219132, 73.14181727747764, 69.28204028837143, 69.51259720710017, 72.24204909416937, 71.74829329213789, 68.04971002763318, 62.892291392049486, 58.61307182619649, 60.991726536904615, 57.19098906363211, 53.81478932596023, 54.62120117679719, 53.62098501574609, 57.715806115058164, 65.12122531091013, 66.93179530482139, 66.2143781108241, 63.80408948467624, 59.37261527584445, 57.158249039803785, 60.539441954705026, 59.89932683206374, 70.82961928459906, 63.41712021058606, 70.99262514422017, 60.33270951240294, 71.84607013579338, 48.28627524837371, 29.628238908706177, 69.74009467709449, 61.20772361755372, 74.05856932363203, 66.10302202163204, 66.92541753092121, 68.14043444971885, 69.19632081062564, 64.95592486473822, 67.7190306878859, 54.06763707437823, 50.47232197177026, 55.181550979614265, 64.1378753416, 63.87976377241073, 68.06455227636522, 67.58631337073543, 68.51628380437052, 65.49993799578759, 67.73426517363518, 66.39807839547434, 66.50763019438713, 64.19583228326613, 56.30299191321097, 52.783476614183, 63.33091043656873, 63.56219299377934, 70.0152724789035, 66.48906169399139, 64.62695175601591, 65.40085500286472, 68.34289935327345, 65.19385976176109, 69.27146557838687, 59.57833966901226, 28.772454223325177, 2.956914055731989, 0.09818267873338155, 0.13151014644292094, 0.3261398091431587, 0.5125471114391281, 9.945102891614361, 33.58794612269248, 2.714908228766534, 0.38782220574155934, 0.08103916316383308, 0.03856492739531302, 14.817479944998219, 52.55925432328255, 35.10743310374599, 26.076526834118752, 29.28781640145087, 36.906145772626324, 39.22636893487746, 8.20891917713227, 0.031056256416524132, 0.04748063567545145, 0.07205353403884558, 0.02635384977404629, 0.06471208281694882, 0.05100368251723628, 0.03830406679621628, 0.01290234748364216, 0.029065846991274628, 0.058554218285867286, 0.012935356297079596, 0.07676343493644269, 0.01689753814360067, 0.026230072948120298, 0.03198301979160357, 0.028309371555224064, 0.02183821153706841, 0.025919784356148976, 0.10204535533463764, 0.024265800527627432, 0.08406449034209214, 0.04195949363131677, 0.05736719952115128, 0.03686787410368843, 0.03424833220760188, 0.09594973927784352, 0.006798649678051833, 0.1049230343872501, 0.019800674297936985, 0.015223678163883668, 0.03953328934468089, 0.11243154640279471, 0.04677545557159089, 0.016048929143336513, 0.028532699591690497, 0.04642797724133538, 0.048383857168617754, 0.03810577259789552, 0.05830277673779957, 0.04580997411281832, 0.03206787935097612, 0.028700218122873097, 0.06154329418354939, 0.04608151014713992, 0.036074885001946846, 0.034794300088598844, 0.01585364088250865, 0.03998133969763595, 0.012788208043803612, 0.07110024486938793, 0.04391751860478713, 0.03774551975150262, 0.07386403729117687, 0.01037751224958488, 0.08445074421263511, 0.05133495808789327, 0.061837100393829815, 0.016466376198936376, 0.011819975371772965, 0.019746760860265746, 0.11423365333147588, 0.004752951208502054, 0.11867887085123409, 0.02731860727973042, 0.04549359512184897, 0.028306351253582586, 0.04652693281851469, 0.0378091586753726, 0.03742734811479046, 0.05151979978226366, 10.469349238180346, 54.468103224231356, 49.21585736736175, 40.47320804288311, 32.868744250266786, 69.61515934236589, 75.2817290829074, 22.255700942008726, 0.17326993627413628, 0.34210505084164683, 0.41208460866924257, 3.4641694301559083, 7.291401288201732, 0.33752029040648096, 0.4795500497904516, 0.05726384276884699, 8.511114754984456, 37.557529864772675, 73.47743880364203, 75.32565962883734, 76.17516656075755, 73.93247296733242, 83.1370912059661, 72.74504600032684, 69.5794657737978, 70.0192262280372, 74.83843849551293, 71.70335861944383, 70.27760844076835, 63.32600355148316, 60.52690605963431, 64.56045189211446, 60.398903431430945, 57.68127749043127, 56.279536139580514, 55.46283983415174, 59.027172134768584, 65.83666955271076, 67.64294455128332, 66.25538256860548, 64.78860047555739, 61.50736131975728, 59.22103920290547, 60.75853770779025, 60.86376705477315, 71.51631647540678, 66.09949188847696, 72.38850255166331, 60.58961691394929, 70.5382420939784, 50.29717245409566, 35.20260549360706, 72.46871502168717, 63.57480733625351, 73.23768000448905, 67.84980250943092, 66.89469752773162, 68.80698634732154, 70.00199133350004, 67.25545360196021, 66.66336397970876, 55.272369538584066, 51.27248156455256, 57.30343557173207, 68.82479390790387, 66.53324327161236, 67.58053964184177, 69.65096273729878, 68.13520200790899, 67.19618658865652, 68.1964772747409, 66.86005515436973, 69.94292043870496, 65.28619627798757, 56.382329694686405, 54.988507609213556, 66.46726900531401, 66.43635288361581, 71.3560562749063, 66.42751970598775, 65.59465539070868, 65.2234540447112, 66.2233603385187, 64.28579576553838, 67.10426192129812, 62.197223863294056, 38.08706552751603, 5.6073144943483415, 1.0796504083179659, 0.36200455239703583, 3.5571195521662315, 1.7503453094151713, 11.543278501879785, 48.9488616297322, 3.9715542427955137, 0.8717698760090337, 0.12429499247622107, 0.13259937025366292, 10.48011810548844, 60.194214543988636, 49.266836412491344, 31.575525076158588, 31.38479590415955, 38.379944985912694, 47.11751876338836, 15.838809244094358, 0.19236227227074487, 0.0841976747277283, 0.06847855409667378, 0.021459551513074868, 0.09525429232106095, 0.08023453335608206, 0.03650168024544274, 0.007539714776700544, 0.016872519627213478, 0.024456598555609107, 0.030280029318565806, 0.055808953700527075, 0.016976701839256193, 0.0201695398878186, 0.0091059326997868, 0.09961854200810195, 0.06866983092960811, 0.032110935407540495, 0.039057349560842405, 0.04827888780123284, 0.0090571625849172, 0.032763205648910616, 0.07611648134526706, 0.12158072763873685, 0.018683693206478513, 0.017051198144233035, 0.06675065810521764, 0.06693896251700579, 0.03916599615026386, 0.037505125191303036, 0.08711180424377804, 0.16743579368677833, 0.19079577568317616, 0.11056051454356602, 0.17903163758737428, 0.12705449480563402, 0.20021297277942782, 0.21509317350724053, 0.17032959889019691, 0.15139372869124337, 0.06265697918171365, 0.1606190054407043, 0.17393471673130992, 0.1702637153287088, 0.21887246909881794, 0.14819505113747813, 0.1916605970191379, 0.2376244322306687, 0.0808975441501506, 0.12098445076375239, 0.08370531767967247, 0.20522499577172343, 0.2248968619612917, 0.12037128931091678, 0.21595702957241766, 0.15362197202780556, 0.19831860588202554, 0.11763745858784645, 0.19092616384788869, 0.08150109119953648, 0.17536520206880185, 0.1103328944995038, 0.3057125649384914, 0.12110793647626716, 0.16415183522528218, 0.09819852143165567, 0.1964043053768335, 0.1741103960141059, 0.14598009176552296, 0.1788885170413602, 8.086495630202755, 57.07266292264385, 63.794864070030954, 62.14311084439678, 42.740490974918494, 65.10788925232427, 80.29948388376545, 40.469199380567, 0.6224584507365382, 0.504524638696063, 0.4648642055690289, 4.70499235776163, 9.388476398683364, 0.5395287587758034, 0.7023498379895765, 0.1355136146829013, 8.046782122504327, 34.584063406913515, 73.49558368805917, 79.647687942751, 79.33797759394493, 75.40122016783684, 83.97146563376151, 75.21549594017768, 69.36797941884687, 69.6552538102673, 74.74579211204284, 75.82067843406432, 72.69370217477122, 70.24145203251993, 64.22175915010514, 66.9151173868487, 61.88337933632636, 58.56145343472881, 58.08125334401285, 59.2298488463125, 61.43908069979761, 69.54388203159456, 72.83342484504946, 71.80756815018194, 71.63104580294701, 64.89007611428538, 62.92371349949991, 65.15027046203613, 66.12699554812524, 76.10034342735045, 70.53756744630876, 76.4233192320793, 64.48869997455229, 73.95454806666221, 55.76436811877836, 36.519090206392356, 74.14738747381395, 65.73111857137373, 75.21184029117708, 70.09026035185784, 68.37299962197581, 72.73672273082119, 71.8591159389865, 70.79723619645642, 71.83213787694132, 59.59821039630521, 55.748631569647024, 60.73572128049789, 70.31724006898942, 67.70154476165771, 69.84268034658125, 71.19172465416693, 69.5579319615518, 67.77548143940588, 70.4643524846723, 69.10554147535755, 71.79940177548316, 69.10644362049719, 61.72580988176408, 57.4831703401381, 69.57906569204023, 69.1448514692245, 74.40933119866156, 67.79252806017476, 67.59234597606044, 66.75074654240763, 69.69473638842183, 65.24072424057992, 68.81665891216647, 60.890262665287146, 34.89791970099173, 3.7898823138206237, 0.6426959809276366, 0.20964797375903976, 1.9480827763195963, 1.9027482670161033, 18.532832322582124, 47.085724030771566, 4.92316194118992, 1.0982874276176577, 0.23959271129100557, 0.3123454767609796, 21.29295518321376, 64.97865107751662, 47.199449231547696, 40.51729156124977, 39.927853461234804, 51.45664468888314, 54.419297172177224, 13.853060314732215, 0.243431577879575, 0.22775139749771167, 0.23773805839159798, 0.11242919451286716, 0.15116865205908978, 0.14109625060471798, 0.13499907938943756, 0.07723729096112714, 0.10263585590667303, 0.18457613765232025, 0.14367946844187476, 0.17834666305251662, 0.14511686389244374, 0.15877169166361133, 0.1321125979865751, 0.17826977846843584, 0.12785478855573362, 0.13577060653798043, 0.1989974057482135, 0.18274963082325074, 0.2163738426902602, 0.12209868734522213, 0.1879470930584977, 0.2095615896846979, 0.11480962887646691, 0.19035426389065482, 0.13507875253356275, 0.2816567912457451, 0.13558599466998733, 0.16059115048377745, 0.2501970382347222], [0.053090348974951816, 0.02488426522411887, 0.023934624548400604, 0.01736597984188026, 0.1203729210781955, 0.018652509597520676, 0.06560704205185175, 0.010143942575180724, 0.01021332237043328, 0.021059193963845892, 0.03027110630946775, 0.002364183723505947, 0.07868810827212949, 0.05263748758983228, 0.033696974898057605, 0.049407576631394126, 0.016629551011588306, 0.04909467184916139, 0.04200792570988979, 0.01776615353000741, 0.0050988834775653824, 0.08079970706134074, 0.019260164793400515, 0.05882329134751232, 0.045026810088705634, 0.0673489727740807, 0.03465954905315753, 0.10961372946058551, 0.02590506780712355, 0.03446949413046241, 0.07083719325882774, 0.046617216280391144, 0.04495171048948842, 0.05538795391217836, 0.058740159316409024, 0.012706741296325721, 0.01582614311407651, 0.047096316176917286, 0.03483426306516894, 0.03429438558317, 2.5356321325225215, 27.62382341969398, 58.722968793684444, 42.23792945185016, 32.756537006747344, 34.37507560176235, 62.96956600681428, 40.506195176032286, 2.384504680672, 0.03588095750479448, 0.10842000359609243, 0.2854640643683172, 0.1499392954452384, 0.10042400685169044, 0.06058431681125395, 0.04746142602075012, 1.7056984406325126, 15.57246756169104, 55.2408258376583, 79.00698446458387, 76.35522688588789, 65.22605849850562, 70.06931489513767, 71.55455958458685, 74.73544489952826, 74.36301585166686, 71.6181412050801, 68.86473148099839, 62.51641850317679, 60.545400034996774, 60.68031780181393, 57.22189734058996, 58.793336114575794, 57.11267502077165, 66.64143793044552, 68.68522813243251, 72.54762526481383, 67.40597847969302, 68.35484689281833, 67.5061087454519, 67.96322176533361, 63.66308027698148, 60.26599784051219, 59.39805969115227, 64.38203111771615, 63.164315608239946, 71.04294915353098, 64.18826210883357, 76.89055196700558, 39.51165076225035, 18.983973533876483, 72.8577749190792, 62.47840681383687, 69.99646863629742, 63.852836701177786, 70.14776229858398, 65.52739850936398, 70.11307285678002, 65.45192818487844, 66.12377920458394, 52.23548227740873, 48.649714223800174, 50.5142403418018, 60.809716793798636, 64.36900492637389, 69.24579758797923, 65.93230478225216, 70.55466113551971, 69.47134956236809, 68.83004988393476, 68.24410269337316, 70.74004019460371, 64.19358868752757, 65.26654520342427, 56.666348518863806, 61.97952055162, 63.833817128212225, 64.01639169262302, 64.71160042670466, 67.50044484292307, 63.76325761118243, 65.42145529100972, 63.334754359337595, 45.70294733970396, 9.838398733446676, 0.32141617228907926, 0.042251748513550534, 2.493042546895243, 0.9643273319928878, 2.9631815129710786, 2.468947672074841, 6.897442840760754, 2.1922793696003575, 0.3979862313116751, 0.0407601140379425, 0.27199182599302263, 28.550910911252423, 56.143865277690274, 29.421451553221676, 21.444288069202056, 31.672499795113843, 41.46118640899658, 27.224027995140325, 2.9781492775486362, 0.14672155762391706, 0.052219835605712674, 0.022501927132027286, 0.0696958065213215, 0.0798334097189288, 0.06049909336011737, 0.018217999848627278, 0.06831278033073872, 0.05342347464794594, 0.040145225056837645, 0.045741937844262975, 0.050705341066444115, 0.025727743350510156, 0.07959648170658658, 0.06453681722163193, 0.02988161380222488, 0.09248481552687385, 0.031366598634650154, 0.056267476475407044, 0.03293058819948666, 0.0455292335320865, 0.03215395890536808, 0.06118833883515289, 0.03075571246294966, 0.05104083395112426, 0.01746430148130223, 0.061003983606614416, 0.03437927961649914, 0.07538066921575416, 0.04703623956189521, 0.020730751003288937, 0.015922782232894773, 0.071482936431083, 0.05366100403930872, 0.03857883189113871, 0.030848160123212204, 0.018198705924254273, 0.05106454054194112, 0.0373685815101189, 0.07765464800139589, 0.01252219167297646, 0.04688693668633219, 0.044589998245599775, 0.07219405754679634, 0.050417012384822296, 0.057520669915022395, 0.02761987135595372, 0.04865737737066323, 0.027058995403950254, 0.17692264349710557, 0.029876622739398194, 0.025479040566771746, 0.1029457614546822, 0.07343382529553867, 0.0386468758205733, 0.03501667243037974, 0.030580561780821414, 0.012205121287655447, 0.040879401588632215, 0.058618447097438964, 0.013229942001822977, 0.030430940978769815, 0.0709112279958302, 0.07614101914148177, 0.07605478828472477, 0.056419694315521955, 0.035779393398233, 0.025480429101134502, 0.030600254070915045, 0.025591218821524132, 0.09009190159098757, 0.02493916499999262, 6.435821546662239, 39.739693441698634, 67.70541221864762, 39.19888488708004, 33.57138587582496, 53.100808128233886, 85.3556465333508, 33.12877778084048, 1.0035145679308524, 0.1144089419094305, 0.19243998422978387, 0.5315923330283935, 0.2512215889028965, 0.22629443616155656, 0.05456423319335427, 0.0836624397385505, 3.014010037145307, 22.394399873671993, 63.500592170223115, 82.90833073277628, 76.45946779558736, 66.91628625316005, 70.58330228251796, 71.28419060860911, 72.887726137715, 76.09400487715199, 73.33083629608154, 69.00170064741566, 63.29431080049085, 63.683966898149066, 61.991546538568315, 59.45118427276612, 60.13439055412047, 59.10052437936107, 67.16345833193871, 69.14747161249961, 74.27012628124606, 71.24390002219909, 69.18609126921623, 71.1077388640373, 67.88122069451117, 64.56488417040917, 62.30525378257998, 61.84435959785216, 69.00087694967948, 62.63690587012999, 73.87653996867519, 67.19016182807185, 75.81699140610235, 43.21535271982993, 22.6753298313387, 73.72885488694715, 63.59332484583702, 71.55723464104437, 66.74208594906715, 73.57877715941399, 69.22863329610517, 73.83824194631269, 68.22904863665181, 69.45660929526053, 55.333927216068396, 50.99973955462056, 55.22583453885971, 61.87387543339884, 65.99499994708647, 71.0766109343498, 68.56376801767658, 73.8025091540429, 72.03734843961655, 70.18016892094766, 69.27701180981052, 69.96736464961883, 67.91747908438406, 67.73385724713727, 58.6724643553457, 65.14189227934807, 66.11009013268256, 69.69547379401423, 67.24878557266729, 66.91857691734069, 65.67870001639089, 65.46432679699313, 68.02917249741094, 55.016215232110795, 15.56211054325104, 0.8614517135485527, 0.09481271158062643, 3.655545302937108, 2.933745840864797, 5.003236147665209, 9.249419550741873, 9.767906877302355, 1.6362325294363884, 0.33420267004159193, 0.052530671950549855, 0.16084014438092709, 20.51579244675175, 70.99998351066344, 46.44171399454917, 23.36851462241142, 31.773673411338564, 46.61146633086666, 39.83798803821687, 7.502298307034278, 0.05766875471078581, 0.03922053778003301, 0.038454802256197705, 0.08285410206524596, 0.055960608466017636, 0.12146287267246555, 0.019319163139669165, 0.09616043643965837, 0.04360749814358931, 0.08154229140810429, 0.04703619359661976, 0.01432360337686635, 0.0843291124328971, 0.0379286224262849, 0.026141549573249878, 0.0201336563294453, 0.06784343656392829, 0.0678347414659877, 0.010089525434699272, 0.0775278298064105, 0.04961648880834541, 0.040709969752858725, 0.030041791295873064, 0.04878006252129713, 0.09836710674027282, 0.030919331606597673, 0.08554376781948152, 0.014082267486129799, 0.059741328981134205, 0.009306654439217622, 0.018587307854285164, 0.02798519378918554, 0.11616137569710133, 0.14971863147952866, 0.195916659769512, 0.11523463913509924, 0.2294925927755333, 0.1311245590688721, 0.2531541376224449, 0.1573919673119822, 0.0671791464030262, 0.14042862030046602, 0.1288986906048752, 0.13855556596911725, 0.23331996804523855, 0.2157864524351974, 0.1544348372807426, 0.16295823959573624, 0.10073720657777402, 0.2508156848770957, 0.07941831263803667, 0.1519858840131952, 0.18226627530830522, 0.2814800087963381, 0.18699509091675284, 0.1763281899113809, 0.20834259057958282, 0.21530537986226622, 0.125928322574304, 0.2092555988459818, 0.11876694031900938, 0.13382739387452602, 0.21760776518814026, 0.16494522652318402, 0.21005436808111208, 0.12170354685475751, 0.1429058881776948, 0.1485381359534879, 0.13144106063390934, 0.1413418430714838, 0.17861281731917014, 0.1275026562413381, 4.350603270915247, 42.109585577441806, 76.48428855403778, 55.89388085949806, 46.628787517547615, 48.34552657219672, 76.70850692256805, 51.14232947749477, 4.238368080508325, 0.2166309877629242, 0.19491716017646177, 0.4924570991387291, 0.7443397299897286, 0.407325946275265, 0.42624957438918853, 0.14082170001441432, 2.2619735137108834, 18.101918774266398, 60.87997428832516, 81.31598180340183, 77.30509158103698, 64.7109846145876, 69.53299353199621, 70.93415044969129, 75.85801939810477, 78.09028733161189, 75.67964569214853, 73.8179240688201, 65.97749833137759, 65.9950234813075, 64.21332213186449, 61.473424973026404, 64.35585321918612, 62.40429362943096, 72.39528040732108, 74.11414930897375, 79.28128365547427, 73.56703358311808, 70.6471114004812, 75.12306920943722, 71.12276154179727, 69.54585890616141, 64.24548164490731, 64.71065513549313, 69.56905580336048, 67.27128428797569, 75.01446662410613, 69.92338703524682, 79.5179908506332, 43.72896355967368, 26.2451240324205, 74.03372503096058, 65.03092058243291, 71.86313244604295, 67.6656864535424, 74.22172423331969, 72.36371317217427, 74.6788372532014, 69.20727206814674, 70.73846340179443, 55.72606617404569, 51.87804060597574, 54.846917890733295, 64.49931390823858, 70.1050163084461, 73.7726285380702, 69.97356199449109, 77.12987146069928, 76.91629056007632, 72.01392404494747, 71.10595810797908, 75.45731790604131, 69.1386462796119, 70.51111498186665, 61.62147875755065, 66.45088134273406, 68.57569986774077, 69.21611309051514, 68.08952992962253, 68.23173938259002, 64.42620485059678, 66.48135815897297, 66.64215964655723, 51.335361080784956, 12.627309829958024, 0.5844502547575582, 0.1378634361730468, 4.419641398614453, 2.5957927107810974, 7.276389396959736, 11.055302312297206, 14.614853243674002, 4.078924468448085, 0.893185159131404, 0.1762594258592975, 0.9081019941837558, 37.516203772637155, 68.59987735748291, 42.23699592774914, 34.28998370324412, 41.032306609615205, 58.47354919679704, 40.36830033025434, 5.552884253763384, 0.23466733284294608, 0.12775124411188787, 0.1483363790377494, 0.14457793635947092, 0.18936063253110458, 0.22122949181545168, 0.0754456258108539, 0.16418154411498578, 0.10750822107037229, 0.25950649272530313, 0.1266541066128881, 0.1873312502979271, 0.11855426665034988, 0.13671792022162868, 0.12671287321755964, 0.1283538488731269, 0.14235943766130557, 0.12190257649748557, 0.10562018205922459, 0.21455651359452357, 0.22561585079998742, 0.23861403396773725, 0.1927653264494673, 0.11807792850079075, 0.24574546984607176, 0.09522264522890891, 0.2100792659386512, 0.10294511794082581, 0.21887819943649156, 0.10123250540345909, 0.142196077072332, 0.11717359234969463], [0.007855526383800973, 0.07051923612673437, 0.024509366691833543, 0.030535546454390695, 0.033961547193147486, 0.05981191249203779, 0.0571282375453701, 0.057500862711740125, 0.0459411743307306, 0.04413234498051386, 0.05202856260321794, 0.04574235536218171, 0.14575313055707564, 0.022173143262344024, 0.027145850622365554, 0.026834345865814437, 0.050762529529991655, 0.028294145557728988, 0.09042419988902346, 0.05197107536537994, 0.0771198266996972, 0.06322953031368314, 0.040414531775299585, 0.019655062050949183, 0.04439781359847515, 0.05489599906028279, 0.056306064324153055, 0.017575116099549398, 0.01388118281254485, 0.024063390521933476, 0.09385341628184242, 0.04415762971245474, 0.049687202554196126, 0.029868986758012927, 0.13531617850305575, 0.0211899345290036, 0.07458345513911017, 0.040083363456952, 0.03902210185544626, 0.06508992504208319, 0.04331800117788296, 0.7248578689271404, 17.91524729421062, 51.261196905566806, 48.21109517928093, 35.19744757683047, 29.280267800054244, 54.28683480908794, 57.825734461507494, 9.884175735135234, 0.14650408058397232, 0.044376221410329306, 0.15870383159527857, 0.0725717542152251, 0.20863266211123238, 0.02742999263348118, 0.09192885019846501, 0.06568585717750174, 5.175752774361642, 24.508853535498343, 47.59159211189517, 73.89725792792537, 75.62368915927026, 70.9166488339824, 73.521847878733, 76.06861929739676, 73.39510040898477, 73.18456326761554, 73.95523840381254, 73.86856971248504, 71.14854720331007, 70.1139279334776, 63.597360964744325, 63.39242496798116, 66.59272209290536, 68.4804411857359, 69.37329030806019, 70.10325908660889, 69.9015708123484, 71.89110679011192, 71.72348037842782, 73.7080898592549, 68.15932458446872, 68.67590073616275, 69.30864964762043, 73.25376956693589, 62.88227758099956, 70.569213128859, 63.795519105849735, 46.697248566535215, 52.95181689723846, 57.70950678856143, 78.1494680527718, 66.12080604799333, 72.8934371086859, 66.52853642740558, 72.64440582644555, 69.18053719305223, 74.34851092676963, 68.44291194792717, 61.663310835438395, 52.649104056819795, 57.11777017962549, 51.63665010083107, 57.7828315765627, 58.2374107453131, 62.54180016056184, 65.45258322069722, 67.42647678621354, 68.60299171939974, 69.66008617031959, 67.56418335822322, 66.27724585994598, 64.16233131962439, 62.88137151348976, 63.443305953856445, 65.20024145803144, 65.66198287471649, 72.47994084512034, 64.80148546157345, 67.21630050290015, 55.05740796366046, 20.38390078852254, 1.3492688632780507, 0.01712364707923224, 0.07382094484543608, 1.023142905004563, 2.4055202497589976, 2.7513313581866603, 6.843037605285645, 4.055736641730032, 1.1425777284368392, 1.2208700756872854, 0.046615504073880376, 2.09054583503354, 38.402373098558, 50.88322947102209, 21.848819755738784, 25.931844326757616, 37.823329279499674, 47.889915820091005, 14.966795752125403, 0.21595804080847772, 0.018480130238458514, 0.04064992761179324, 0.020471344056028514, 0.014455913464658925, 0.013866228776262894, 0.04405830258263215, 0.055716004252674124, 0.06611044608777569, 0.09243845188569638, 0.059043258173210975, 0.043540741241867506, 0.05707423600758757, 0.03312223658506428, 0.02533169696107507, 0.07523437706573356, 0.08576762637183552, 0.024614550563837254, 0.07386990552467686, 0.03126826741912913, 0.04353238705305323, 0.08272452595373316, 0.061916570524655046, 0.11556844662634597, 0.016211447035593372, 0.04522651771924669, 0.014566376640070832, 0.07271108262601399, 0.04348143071476971, 0.08472740154473052, 0.02344519587143535, 0.023939812878867792, 0.050117812915554935, 0.046676251015836195, 0.0363817798244136, 0.0830187650036908, 0.05891386209236038, 0.017793366888297663, 0.07426366705687777, 0.043319812975823886, 0.03542877410748794, 0.022548551243098996, 0.024547992844975764, 0.035794163573413126, 0.06157283453390964, 0.016279276460409164, 0.06989530347768338, 0.08119693897183865, 0.03300927309018951, 0.034399829925067966, 0.023061228773346352, 0.04399016289220702, 0.012193927785471804, 0.04631329387907059, 0.051605639934179284, 0.022721397915794965, 0.035434427836369124, 0.046386842150241143, 0.017357897614279104, 0.05969602637173188, 0.08357112205797627, 0.03869097950237413, 0.026938575958352418, 0.03162373604643489, 0.0739934601851048, 0.02707649093692101, 0.04130662584136571, 0.03801823556122761, 0.031128919856142134, 0.04038108054608588, 0.08154617547388039, 0.0814188746435027, 0.10436308540163503, 0.03350084872856256, 0.031543089970645886, 2.4169478301079046, 30.12137301506535, 61.54465129298549, 45.02662481800203, 28.81548654648566, 39.936266945254424, 81.76182977614864, 55.44996269287602, 3.7797741207384297, 0.08358674259075234, 0.033027371917400634, 0.07389304904086937, 0.054430110350010864, 0.3787472814081177, 0.07179964483985979, 0.0654552647122933, 0.19513148093415847, 9.487445642871242, 35.270878268826394, 56.90291450869653, 76.77590893160912, 73.94136105814289, 70.76264089153659, 75.66565852011405, 76.97275700107699, 75.16504641502135, 76.1309692936559, 74.92298910694738, 73.809294854441, 69.39587531551238, 69.05370343116023, 64.44422421916839, 63.21529857573971, 68.16829896742298, 71.6209182431621, 73.04159287483462, 72.8946138197376, 71.98444351073235, 74.23022793185326, 72.93901505008822, 73.59224657858573, 66.72130523189422, 66.78295704626268, 70.87241234317904, 73.2010607565603, 67.88311912167457, 68.5515380674793, 66.98636331865865, 42.93929630710233, 43.24034214019776, 61.27163863951161, 76.02529279647335, 66.80096857009396, 72.65636905547112, 68.77792942908503, 72.83144012574228, 71.16581347680861, 73.69682481212001, 70.07342553907826, 62.551151091052645, 53.95390795123193, 58.45161530279345, 56.66830578157979, 60.805296282614435, 62.083949735087735, 66.26279584823116, 67.87747090862644, 70.15187294252458, 72.57353644217216, 71.34560708076724, 68.87729875503048, 68.6692483963505, 66.33976844049269, 65.29174250941124, 64.8347903067066, 66.50887750810193, 66.28059556407314, 73.49429715064265, 65.50762584132534, 65.1604333231526, 61.855106892124304, 28.232312471635883, 3.019972530103499, 0.431671668925593, 1.1357847961687273, 3.731343390480165, 5.591069507983423, 5.770467933147184, 5.298762715631916, 1.0704536760045638, 1.2811966192337776, 0.36496134534958874, 0.011061415218958452, 1.423274550226427, 33.2101159711038, 70.49784168120354, 34.644236487727014, 20.539285482898837, 36.10071059196226, 54.2523414857926, 24.833780719387917, 0.8829243000476592, 0.14667648101045241, 0.06264765972211477, 0.03643596139285834, 0.048045522097738526, 0.019729391731802496, 0.011494706888052245, 0.07746940794130487, 0.027211249633241567, 0.024453890434796774, 0.02904875556968393, 0.04698575053724551, 0.0476522968270846, 0.02397031275435321, 0.028118205805038734, 0.02089682737395408, 0.018564177744631326, 0.008043424290184292, 0.024560480078141537, 0.07182909325966913, 0.04534850189942987, 0.0032038065124182936, 0.07067845984091682, 0.06976335249360531, 0.01825343333034506, 0.050963673575390736, 0.01648684606827315, 0.03927834294435959, 0.019931068208308953, 0.057932836709604155, 0.034036328865876125, 0.044135861324086305, 0.05531752361885964, 0.018338775525109905, 0.07879316190918607, 0.16037385730493456, 0.11583701406996097, 0.1892162249573777, 0.20045229864697303, 0.13027688278065575, 0.19660682838049628, 0.19958418313293688, 0.12388094493578519, 0.1588739184362273, 0.1617900780852764, 0.11353391628231733, 0.27622320539047646, 0.2238365043435366, 0.09112992008487064, 0.10808042746277587, 0.13519890576360688, 0.15966308092878712, 0.16133506782352924, 0.11805623289077513, 0.19929835572838786, 0.20073875424362, 0.12665337882936, 0.1012909425903232, 0.13627141353584107, 0.1898412148077642, 0.13822429422889987, 0.1109154507397644, 0.16761974671915655, 0.23802541797199558, 0.15711612969396577, 0.19199539276380695, 0.13491442667380457, 0.08868561697102363, 0.20391526121285655, 0.13114410963269973, 0.21127938863731202, 0.23680955982737004, 0.2862604280873653, 0.10647492933898203, 0.14218493815391295, 1.8710837080594034, 30.085061673195135, 72.05678770619055, 62.912169964082786, 48.12616802030995, 41.62611423000213, 69.94457567891767, 71.08043916763799, 13.982998632615613, 0.2171218969048031, 0.2573817938325867, 1.3968928110214973, 0.5774941151180576, 0.3600446236950736, 0.10732858877388701, 0.201045909535981, 0.4329350704867994, 7.676119612109277, 30.48225460513946, 50.888575661566954, 75.92438590142035, 75.55227848791307, 73.21595007373442, 72.50855061315721, 78.1634787590273, 76.18501955463041, 78.50226956029093, 81.65763593489125, 81.53972164277108, 76.9815117313016, 75.83399095842915, 67.55702111028856, 67.88543332007625, 69.05043217443651, 75.55557327885782, 72.83024772520989, 74.90288303744408, 75.8184426830661, 78.1738495057629, 77.2191289163405, 78.11215846769272, 72.43616719399729, 72.82644302614274, 73.17621646388885, 80.25348232638451, 71.24895987972137, 75.14073556469333, 63.54768022414177, 58.70562799515263, 61.17265370584304, 58.355905548218765, 76.61619001819243, 68.1057293184342, 76.37480735778809, 71.46192889059745, 77.83143443446006, 75.2935746408278, 79.39563643547797, 74.35848159174766, 67.3720342882218, 58.097793979029504, 62.145574092865, 56.2398809771384, 62.23018353985202, 62.557623001836966, 68.15370775038197, 70.75447451683783, 71.86769808492353, 73.84228983233052, 73.3006654247161, 69.94564256360455, 71.33669545573574, 69.91498531833773, 67.82413451902329, 68.58935756068077, 69.86288055296868, 69.96153600754278, 75.83763876268941, 65.24954565109746, 66.15484437634869, 60.881115698045306, 24.814635630576845, 1.7371332957859964, 0.2579210890877632, 0.48215582125609924, 2.368897569756354, 5.619372350554313, 6.518867438839329, 22.174258808935843, 14.61626039397332, 7.046746880777421, 4.146900369275001, 0.14774511237778973, 4.365038573741913, 49.43241534694549, 62.239589383525235, 31.49705609967632, 37.71331071853638, 47.83559883794477, 64.64219016413536, 25.397091911685084, 0.6689204576034701, 0.23075505970947205, 0.18901854362939635, 0.1443866901700535, 0.08057614728327721, 0.09647873065043842, 0.12721175733473034, 0.1998782689653097, 0.14279638356979818, 0.15490166061828214, 0.17382446135724747, 0.11319231001600144, 0.1376737068377195, 0.14608426440146663, 0.11527163352096274, 0.28044027426550466, 0.2509557257496542, 0.14361249703553416, 0.12972601959782262, 0.1020287235658015, 0.18020444159065524, 0.14434191999175858, 0.1683618101261316, 0.1647242101570291, 0.12181561019632126, 0.16101001671725707, 0.057554412257647326, 0.30019814148545265, 0.12718132066149868, 0.12124439971821925, 0.20659089989719853, 0.11096154625016837, 0.18026353761313424, 0.07753799579316571], [0.060081878046114603, 0.03664474716530212, 0.0029824688681401317, 0.035304939824967616, 0.027693467507619533, 0.11660281088083022, 0.06390466061871379, 0.04390058040078129, 0.07099307682966033, 0.04930484807118774, 0.07256345748300515, 0.04590578106862884, 0.053493575523457224, 0.051301330658456976, 0.0360139541988892, 0.023673160655063488, 0.03671503573235485, 0.08419987340007098, 0.09161816324077307, 0.059380926747596076, 0.12517314374206528, 0.0874405861982415, 0.046328952716242884, 0.04133741874548216, 0.031347053816481944, 0.06535395724518646, 0.04312384768479294, 0.06121007658000435, 0.02526349406839619, 0.09944053381801614, 0.04652049001907149, 0.054617269460352204, 0.045542218722403056, 0.09564497417980626, 0.045324910221801656, 0.09194277767692843, 0.04245211114926685, 0.05916137743981616, 0.04322595188334104, 0.050253674778486454, 0.0619425677183655, 0.09918112878597553, 0.20462701818154705, 11.060834815425258, 50.003798777057284, 56.356038047421364, 42.11433556772048, 27.06048869317578, 43.41174187198762, 67.14589395830708, 25.776047783513224, 0.9182713517258245, 0.09514623561934119, 0.8701002333433399, 0.02725115898365696, 0.24776993379477533, 0.0823988926206385, 0.048286330345417225, 0.11775761181789061, 0.21367146753736083, 3.88345756357716, 16.73100136941479, 42.71662335241995, 69.8634453742735, 78.71792147236486, 76.1120948483867, 75.64465030547112, 76.5574799814532, 76.09141611283826, 71.807615218624, 70.92416409523257, 71.92585114509829, 75.35719548502277, 73.30945937864243, 77.04652109453755, 77.60749063184186, 77.67366886138916, 73.83411561289142, 68.18482783532912, 70.76348027875348, 71.5786115584835, 69.54566278765279, 67.91964423271918, 68.058605963184, 64.22525398192867, 70.081340882086, 73.43295912588798, 79.53642599044308, 51.82432374646587, 40.108129516724624, 61.68143610800467, 43.59052350444179, 74.90995899323495, 69.05165595393028, 75.12160224299278, 72.806258509236, 69.89167859477382, 69.22820183538622, 70.25004986793765, 66.43858078987368, 60.662816186105054, 53.822100623961425, 53.42170899914157, 56.0833627177823, 63.254290857622706, 63.379053608063735, 64.82945196090206, 64.84826364824849, 69.66432233010569, 73.17966814964049, 72.30271247125441, 67.22529842007545, 71.9648551940918, 68.0184095136581, 65.71578602637014, 70.08889536703788, 67.12675279186618, 69.4809279903289, 69.80691617535007, 73.23965687905589, 41.04263813264909, 4.328204576046237, 0.18624029512847626, 0.10716029457868108, 0.23930548960643433, 1.1061614631645142, 4.973500659388881, 7.308427316527213, 7.006929920565698, 4.717951868810962, 3.2089268295995654, 0.1430564704200914, 0.36334342894054233, 9.008833131482525, 47.814131705991684, 50.63277829077936, 26.750507700827818, 29.369148708158924, 40.58678811596286, 42.78025204135526, 12.834224662473126, 0.19329296184643624, 0.0060307576167096776, 0.06881718794184347, 0.05723109251008399, 0.0570476106217792, 0.020503008385158835, 0.03712086697980281, 0.10839126763805267, 0.03819550447646649, 0.015651696275228697, 0.04465147297108366, 0.03752828785969365, 0.07688757948457234, 0.023669868392208894, 0.10107962489728967, 0.03679879978599568, 0.051881661413297545, 0.05635642311385563, 0.14579837570988363, 0.02333895288287632, 0.03310840869803102, 0.07362800560170606, 0.06811254792996953, 0.03500009045725869, 0.03934628728236403, 0.05374904669400665, 0.050019891557073405, 0.11305220785640901, 0.02590916446229864, 0.03323795416602685, 0.03644758294666967, 0.06192035116856137, 0.05757477870511432, 0.014446198512169143, 0.02451344802525015, 0.0609804455551409, 0.08096581024508323, 0.10419891275946172, 0.021961657029967156, 0.05013051082289988, 0.04683495379023014, 0.024415825441059087, 0.027090073675818505, 0.056314380208571116, 0.013584676142331335, 0.08332497034702571, 0.091423393046904, 0.10025371316700213, 0.04628242053572209, 0.01776123141509391, 0.021455841732301542, 0.0632860254676592, 0.01671210273108896, 0.06500001696328964, 0.038109545580922596, 0.04178175740244408, 0.08142556259108168, 0.08470766711980106, 0.0192453965334402, 0.02380318492801199, 0.09988488013585729, 0.04383205000551478, 0.025338557278437, 0.04460900105656155, 0.050640660262997114, 0.043089147732262655, 0.03026392806561724, 0.043822313027997176, 0.03582364263673944, 0.02747631222460299, 0.026051237383076263, 0.014875340857543053, 0.03028570028442529, 0.05918381232467871, 0.06334452777199688, 0.06979816352888461, 0.05748941352771175, 0.7465881674039749, 20.254089947669737, 60.2286764883226, 52.4607910648469, 31.348021722609, 29.61315347302345, 72.43609659133419, 81.530864930922, 21.956631983480147, 0.29009724156029765, 0.04808915463546592, 0.5890860060049642, 0.2764054117423873, 0.5134031074422022, 0.662545993203117, 0.09414925645556181, 0.16394500680748494, 0.3357537529401241, 7.095551952239006, 25.145877830443848, 53.0618707595333, 74.90138469203826, 77.87848718704717, 76.67269568289481, 75.90860228384696, 77.0287919813587, 75.10694042328866, 76.19618262014082, 75.05698511677404, 76.12074759698685, 75.70226992330244, 73.67747183768981, 79.01283664088096, 78.67239844414496, 78.10767127621558, 75.44680595397949, 70.18219286395659, 70.38085306844404, 73.46891157088741, 72.50606383046797, 72.29700150028353, 73.27637810860911, 67.28693454496323, 70.92586640388735, 72.54440892127253, 81.93973279768421, 57.34684444242909, 50.10680414015248, 61.77108580066312, 46.27532312946935, 75.61779775927144, 70.62173366546631, 77.53296559856784, 75.07556146191013, 75.83943520822834, 72.7335613004623, 72.46763244751962, 69.27202255495133, 64.50590349012806, 55.473167434815444, 58.114671937880985, 55.46208673907865, 62.43479790226106, 62.120514069834066, 65.76475289560133, 66.7522527325538, 71.58021973025414, 73.44121179273053, 72.18752030403384, 67.89384288172569, 71.72788912250151, 71.11614058094641, 68.65868937584662, 69.47965714239305, 68.7413101811563, 71.30458693350516, 69.379636702999, 72.41956772342806, 51.991703048829116, 9.072834445584206, 0.8198899114804884, 1.0035523820307948, 1.4122224142474513, 3.2589135150755606, 5.637342689498778, 5.9289532611447004, 5.626991064317766, 1.2880471613137954, 1.4254377373764593, 0.3798752079807943, 0.23393460038688876, 5.620784403816347, 48.604414770680094, 65.11297264406758, 31.152768096616192, 21.03878167367751, 39.89712169093471, 52.211222417892955, 19.53683945440477, 0.32248783736459674, 0.09830946628484996, 0.05266106394570201, 0.07286921083446472, 0.05345604870648635, 0.04385160056934242, 0.04950233021630876, 0.05450787593520457, 0.04685888254654504, 0.06821946316068211, 0.0397472883454494, 0.05794314059218573, 0.03040009253327885, 0.05031680042344717, 0.0361195479279324, 0.024019112555129875, 0.03693864530613346, 0.0526285243611182, 0.10760513885367302, 0.021672663767071023, 0.05113791261288909, 0.03170574575872912, 0.09100237410635718, 0.08304844324987742, 0.01916569657623768, 0.02456987614653284, 0.04221863819346313, 0.020818540848971858, 0.04530887983198609, 0.03941628473600553, 0.006634615889314803, 0.04272842757223595, 0.0362316036086169, 0.010240168964129784, 0.06029644395194708, 0.13371719978749752, 0.14741471397780603, 0.18967701152207392, 0.1441315062824757, 0.19967992880171348, 0.20845359671981106, 0.1414674814910658, 0.2621205685840499, 0.25230836123228073, 0.1148411074292756, 0.19190171553242594, 0.15497731946168408, 0.3047931981423209, 0.2368381655504627, 0.10209439262267082, 0.17211021705260202, 0.2340259027457045, 0.14208312506877607, 0.25941980221579153, 0.09658475721915884, 0.1934218484788172, 0.16825014515028847, 0.14729287535432847, 0.1326467910961759, 0.09563563556800928, 0.15200128238047325, 0.19669109805216714, 0.13096502891951992, 0.23506119396657715, 0.13021093793213367, 0.14880945365275108, 0.08815170731395484, 0.12335016091744747, 0.18129050911914918, 0.11487663858720373, 0.24692239540238536, 0.18243234784853074, 0.2316293498921779, 0.17363401189927133, 0.1588856702249858, 0.22250418551266196, 0.19651331968845862, 0.6078744655655277, 17.71469846848519, 67.75859955818423, 70.69156754401423, 57.5871523734062, 41.57393493959981, 57.612326145172126, 79.13086075936594, 34.62359697588029, 1.8729396020212483, 0.18920833425175762, 2.37338843845552, 1.5269811595639877, 0.6329903823714103, 0.3576862986289686, 0.20649647189965173, 0.25394581288339635, 0.5229030573560346, 5.891604452363907, 22.01346124372175, 47.161884692407426, 72.45177038254278, 79.42212812362179, 78.81057570057531, 81.41455096583213, 81.57228515994164, 79.11565765257805, 76.2575912475586, 76.34730369813981, 78.82434321988013, 80.09693268806704, 79.97015383935745, 83.94672332271453, 84.52242528238605, 82.25013348364061, 77.23557933684319, 72.796993870889, 72.89997177739298, 75.70711797283542, 72.21861685475996, 74.42014909559681, 74.70689788941415, 70.58389063804381, 72.23571054397091, 74.97460749841507, 81.16648458665418, 61.74691615566131, 52.13084128595168, 62.13802745265346, 49.861099027818256, 73.63589471386325, 73.76309717855146, 76.49043098572763, 78.14372570283952, 72.76944314279865, 73.10679051183885, 71.68544907723704, 71.45899495770855, 66.07768351031889, 60.24416592813308, 59.19023682994228, 60.16018013800345, 68.03795860659692, 69.22635047666489, 68.236587432123, 72.3064701018795, 75.54301384956607, 77.48182573626119, 76.29462626672561, 70.11499481816446, 74.80491007527998, 75.07800117615731, 71.21997356414795, 72.58998686267485, 71.46042270045128, 72.36614504168111, 69.77564704033637, 75.69869272170529, 46.944989388988866, 6.286221857993834, 0.3428120274216898, 0.35388460262648525, 0.7511003639909529, 2.4128511596110562, 14.697818236966288, 17.07459315176933, 18.787490244834654, 11.266633733626335, 12.673939947159061, 0.5812284566702381, 0.4964688258065332, 12.587532093448024, 59.170275888135365, 62.26098591281522, 37.75089879189768, 40.90778312375469, 53.6569139265245, 60.97533887432468, 19.151231242764382, 0.309645997420434, 0.2592062475460191, 0.15332834584818733, 0.1493874516698622, 0.16429207528070097, 0.21680977736269275, 0.17830518705229606, 0.22425471174140132, 0.16471595172920536, 0.1563309661803707, 0.14545853910667284, 0.17848796030927092, 0.16954305641833814, 0.11113728681999831, 0.1644127800940506, 0.13738524409071093, 0.14668648611874352, 0.14492921831627048, 0.22185420587418542, 0.11174784357389135, 0.15992799413300332, 0.10028360591780755, 0.23107716903811504, 0.1965108988506179, 0.11400810938568846, 0.11348477174197474, 0.08688267500650498, 0.13438634694583956, 0.14185892177685616, 0.14077109224613638, 0.16146473586559296, 0.14866208897963648, 0.23592000917321254, 0.06491514208215861, 0.11742877623727245], [0.05267142145443828, 0.031557888874123176, 0.031114751059982567, 0.08796722568090885, 0.03269328863450116, 0.06752181753155685, 0.03134889817315965, 0.014611594022191582, 0.03412240267460866, 0.14806712977588177, 0.054434025059303934, 0.15055823320102307, 0.036974827638797225, 0.043506297928791855, 0.029405903844763676, 0.06153353039295443, 0.0526496607269491, 0.03356359132956113, 0.08479900778301301, 0.042173362397138155, 0.049981372656240586, 0.02503159350805706, 0.023300535488693465, 0.04581923611582287, 0.030452709367138245, 0.04059928536955868, 0.014406824465690842, 0.05805373304493486, 0.024577851121824597, 0.08133059067110862, 0.09063665139218492, 0.043872430500003605, 0.016073748476863388, 0.10084790628283255, 0.06671678935808521, 0.12223661381510958, 0.04981338489620436, 0.07482290358072327, 0.03486111444691497, 0.08587287153087317, 0.04788542504332239, 0.09226765258297806, 0.01813909662286601, 0.045543295075936664, 7.368884769178207, 44.809180382759344, 52.84382620165425, 48.292119579930464, 29.20145365499681, 33.75039500574912, 59.64395699962493, 53.70460210307952, 11.430189705664112, 0.07009214976982725, 0.25359397934329125, 0.25879396966868834, 0.4909202654755885, 0.06330084543855441, 0.06806696569847484, 0.06880978753249492, 0.0715455794406514, 0.022489654403480313, 1.8232322628459625, 16.82974115494759, 48.842490873029156, 74.15255715770107, 75.77937587614983, 78.33421953262823, 82.5458723498929, 79.01998319933492, 75.65796282983597, 76.46194673353627, 72.26812501107493, 72.89927359550231, 73.65393761665591, 75.83374777147847, 72.30940403476839, 76.8570000125516, 73.11128554805633, 73.19202361568328, 71.989762244686, 78.56877726893272, 75.19594684723886, 74.43084932142689, 77.57061250748174, 80.53406515429097, 57.48187988035141, 49.907324160299, 40.896239588337565, 31.442501814134662, 46.10111890300628, 45.83767291038267, 68.89953074916717, 73.02178490546443, 72.00596947823801, 77.14658860237368, 72.4800036030431, 73.17946418639153, 69.59064452878891, 71.09194740172356, 68.22027037220617, 65.57696942360171, 67.22798132127332, 69.9419790698636, 69.80576299851941, 71.68197385726437, 72.3868473114506, 68.00011557917442, 71.3183230738486, 67.79219073633995, 71.00751446139428, 70.47354652035621, 70.73757694613549, 70.3779975829586, 71.37928455106675, 71.26752838011711, 77.99617398169734, 71.70202501358526, 70.2528190612793, 27.1819939151887, 0.8181181646162464, 0.14554124595897813, 1.0461809462116611, 2.048409773457435, 4.5648078283955975, 5.526153791335322, 5.001936372249357, 4.342238326226512, 6.961163215098843, 0.6938914918611128, 0.651955287302694, 1.0093169791563865, 24.68657808919107, 51.373035446290054, 39.60747426556003, 23.84421967690991, 37.90310244406424, 51.167903331018266, 36.12936350607103, 6.020046876322839, 0.09101958810201577, 0.11627306365558218, 0.044154446617129355, 0.017547657593123375, 0.013104737379528103, 0.027926678078309185, 0.05394519584613943, 0.14627843704675475, 0.1613120392205254, 0.0627200435396404, 0.044127457339556954, 0.06877978752938009, 0.07489190512006322, 0.035151810340222814, 0.05393442464992405, 0.03745301589069348, 0.06580699100008895, 0.07403164200725094, 0.0283262369808771, 0.027981916848089428, 0.056978720165188276, 0.049598573842236114, 0.018246117190668182, 0.029316135577016303, 0.1058749369375648, 0.008915808829178494, 0.03754677739174616, 0.07416898625031595, 0.04641553214300544, 0.07119079646203788, 0.02903277497558344, 0.04481975950541035, 0.024406584505472454, 0.04715257384363682, 0.07797645089486915, 0.009472304673474884, 0.021819473026440512, 0.039224617198229804, 0.023660725132832607, 0.048626902393035354, 0.06336418941857354, 0.10212823838716555, 0.03342878283752549, 0.008633540860647637, 0.011578290911030867, 0.033455136262120745, 0.008733304660587062, 0.059962598156304135, 0.025357661596048745, 0.07441328402848975, 0.05390704849794988, 0.10296459189586102, 0.06494589285143922, 0.08638227403524422, 0.03604780762426315, 0.1088101415324115, 0.07578946905390871, 0.09856307203130377, 0.012164178676152182, 0.062937026452874, 0.009835131575293359, 0.09751741564081562, 0.06820956530470042, 0.01539472452995758, 0.03984127967287937, 0.01445292189131461, 0.06817184313530884, 0.05746116403550391, 0.04994211831100045, 0.05908784449040409, 0.10495498025369261, 0.016669019861447237, 0.024941447942006974, 0.0778925412845227, 0.026034101911429918, 0.044168519652298385, 0.015490935597148155, 0.054934701822217435, 0.029028802809696046, 0.024605704163531625, 12.974840652558113, 59.71152767058342, 58.215833786995184, 39.85090048082414, 25.084949693372174, 50.842609405517585, 80.10567957355131, 50.02878819742511, 3.771210360911585, 0.059217255893013174, 0.7217735376569533, 0.3369129359001114, 0.47267817982262184, 0.44472697160897723, 0.5616104158182298, 0.1024803247362856, 0.15594596103314431, 0.17729384373993645, 4.99912501342835, 25.142812498154182, 57.47688670312205, 77.511321959957, 77.34795524228004, 80.85285186767578, 83.72000248201432, 77.79719214285575, 75.59467930947581, 77.74316541610226, 74.32470998456402, 72.71091353508734, 74.90293010588616, 76.94894036939068, 74.76140314532866, 75.65369529108848, 74.03635301897603, 74.0277002703759, 71.88973396055161, 76.57817440648233, 74.3031918617987, 73.57932629123812, 74.58576725375268, 80.85191834357478, 66.8786628784672, 56.619354601829286, 49.19319783487628, 34.02858518785046, 52.153861676493, 46.956827102168916, 66.09189033508301, 74.81005622494605, 72.62740627411874, 77.05110242289882, 71.51349236888271, 73.68255522943312, 69.79525104645761, 72.39984604620165, 67.13873955511278, 65.03056364674723, 65.53442739671277, 72.06031783934563, 70.5742572969006, 72.7754992823447, 74.57942085881388, 70.32310793476721, 72.93912487645304, 72.42828322995094, 72.1452057746149, 71.79940177548316, 70.51494321515484, 73.60378619163268, 71.18089891249134, 72.96459674835205, 74.91197509150352, 72.16658269205402, 74.3314564612604, 37.591297549586145, 2.1414765859803846, 0.35472074163056194, 3.333352746502046, 4.587140333267951, 5.482388475248891, 7.20595931814563, 4.125098855264725, 2.243286116469291, 2.731949946572704, 0.9987064162569662, 0.2898731455206871, 0.7152093285995146, 20.60069214913153, 64.68137856452697, 57.924931203165364, 30.41332091054609, 31.72779933098824, 52.72109916133266, 47.41775266585812, 11.160587553055057, 0.17868447718360733, 0.053759040310978896, 0.06573344655935803, 0.04553402541205288, 0.10035672901018013, 0.06664103092325312, 0.031036956746491696, 0.021302022768424887, 0.0009638903300642157, 0.05384481917586058, 0.028441632804911465, 0.07887050614602144, 0.10474618298992996, 0.05315852313933354, 0.06462549189886739, 0.046937647876479936, 0.03889705332356595, 0.04166188762493191, 0.06879486413972993, 0.05039538572271986, 0.078193552551731, 0.03544088212713119, 0.059885468424087575, 0.0878280811312218, 0.09117269843456247, 0.06554911814389691, 0.09801730333316712, 0.01340560404764068, 0.07594809521951022, 0.06538115336649841, 0.04345089445010789, 0.06257679658911883, 0.02638498167206924, 0.04038158233367628, 0.07368822777343374, 0.06270988521376444, 0.10705458210600961, 0.10243657345492994, 0.12513348337022528, 0.13896153128195193, 0.16156619655028467, 0.19836811048369254, 0.1078302997554983, 0.1750949262491157, 0.10636137978684519, 0.18714495303650058, 0.11781712918872796, 0.2609257778573421, 0.10488596339259418, 0.15066664996406726, 0.12936893069455702, 0.20214018952702323, 0.13726769555960933, 0.17933732199092067, 0.24639403988276762, 0.27847826180438845, 0.16290476665862147, 0.25682921461280317, 0.1887439011085418, 0.1782848244352687, 0.0543675133057179, 0.14665613371518352, 0.12102644770376145, 0.13574926332840997, 0.11702887834079805, 0.12471895319439712, 0.2706170658911428, 0.2219839198815246, 0.15071209429973556, 0.14575853913782105, 0.27486664753767753, 0.19856839651061645, 0.10263972465069064, 0.18319330298371855, 0.18978884503726037, 0.16806010937979146, 0.12204393504127381, 0.2017709045040031, 0.10264187735775787, 0.13177004943211235, 11.511405321859545, 64.68027637850854, 72.0532654177758, 62.20743379285259, 44.52476932156471, 45.390895335905014, 72.04587567237117, 68.27858032718783, 16.308838628953506, 0.18286609150949987, 1.1039976631441424, 3.152985250757587, 1.845228424476039, 0.3357050603916568, 0.27094072271739283, 0.17379124378485067, 0.1947696576075208, 0.1739521835359835, 3.8422971915814186, 19.71637025956185, 51.92037082487538, 75.16162610823109, 78.99562528056484, 82.13005404318534, 88.73893399392405, 82.93519896845665, 80.82260254890689, 81.63580402251213, 77.85215239371024, 75.62136711612825, 79.19543866188296, 78.37490235605549, 76.04715608781385, 77.46986250723563, 75.28366673377253, 72.97865452304964, 73.39866976584159, 78.57259765748056, 78.14548292467671, 77.99038456332299, 82.93450078656598, 82.69153348861202, 73.74556418388121, 59.27185350848783, 53.53716788753387, 42.17507346983879, 56.02005174083095, 53.77784452130718, 67.72433373235887, 76.07953917595648, 76.39638823847618, 81.37637061457481, 77.30713121352657, 78.01631927490234, 75.59522844129994, 76.62553310394287, 73.73005513221987, 70.37809956458308, 72.24249624436902, 76.86444467113864, 73.85349212154266, 73.54193041401525, 78.39026235765027, 71.21321924271123, 74.17335356435468, 73.69085496471774, 73.86770679104713, 74.80211734771729, 73.01580721332182, 75.61375771799396, 76.50663821927964, 76.2154257682062, 81.18175045136483, 73.3520798529348, 75.18548196361911, 32.01897451954503, 1.7785209201035963, 0.25163366759736694, 2.1301316205532324, 4.334593136464396, 8.187302995112635, 15.331800733843158, 13.33494169096793, 15.514767535271185, 17.867415951144313, 3.8482844445013233, 1.1549183630174207, 2.1285889033348333, 32.70885667493267, 66.51759301462482, 51.50360330458611, 36.23361618288102, 48.98968958085584, 64.23242799697384, 54.21256472987514, 10.301537494505606, 0.17131517100478375, 0.21931888385405465, 0.1815068676707245, 0.09085353088354872, 0.1719544407340788, 0.09900403990139885, 0.24128487694167325, 0.19481430521174786, 0.2815389056359568, 0.1949336157450753, 0.24218807928264144, 0.1694519532423827, 0.15857790206228534, 0.12225234160019506, 0.17113009948403607, 0.1305733588073523, 0.14870138929015206, 0.161177744007399, 0.12360082488627204, 0.13188962043533403, 0.13712618379823624, 0.11133561166183603, 0.1291634505915065, 0.2155654054255255, 0.1934641978192714, 0.1073435657928067, 0.2532181212858808, 0.16498566064382755, 0.14172220572588906, 0.12319069971600849, 0.11026197774035316, 0.13594968725116024, 0.1486972064500855, 0.08975745824676368, 0.2619471875650268, 0.12450611864727353], [0.08188617295555531, 0.03681149769334063, 0.03131805547332812, 0.08455556036243517, 0.08442050672226376, 0.0878618885913203, 0.010081952655567758, 0.020245024446217764, 0.0190461102512575, 0.08618397983692347, 0.06681745331133566, 0.0035313076636333384, 0.02737126433320584, 0.008563608524479694, 0.058281341597678206, 0.04147193612410657, 0.034792599373406945, 0.03945067059248686, 0.0945500813184246, 0.06173413051592727, 0.03698002937580309, 0.033789866889316234, 0.055255382396881624, 0.07925648422491166, 0.07433823805542723, 0.039795858319848776, 0.06390860597152384, 0.034070086530259544, 0.004697168037490619, 0.06982993319510453, 0.03587274887268582, 0.014139586184624464, 0.09409743826836349, 0.04953049926928455, 0.06741222865398853, 0.05736661346388921, 0.04498896151480656, 0.043621329861062194, 0.018560623096662666, 0.03779020182968628, 0.03557018244699125, 0.009801252294451961, 0.12086792879046933, 0.023180236701943704, 0.07682481390093604, 2.7708157320176405, 29.217111756724698, 52.61438715842463, 53.86870230397871, 47.40713480980166, 28.846553679435488, 39.96334306655392, 62.60211052433137, 34.987032028936575, 2.66999390336775, 0.35852154897105315, 1.3686337273928428, 1.4537930416484035, 0.5687785473081374, 0.092331322150365, 0.1935740854711302, 0.05905436644811304, 0.026316510648616863, 0.12111756620147537, 2.9488516238427933, 24.832725601811564, 58.493270874023445, 74.56485317599389, 74.82849920949629, 74.4520850335398, 72.94684410095215, 76.07960193387925, 77.4883290260069, 79.41713102402227, 80.35318113142445, 81.31496983189737, 78.48692524817683, 78.31143056192707, 70.67965922817108, 73.25547187559067, 74.64286911872126, 74.06867334919592, 67.37921222563713, 69.20760154724121, 63.45292360551896, 63.4457064444019, 66.17302848446754, 65.20498752593994, 42.6974468846475, 39.85843143155498, 36.843874223770634, 52.92399160323605, 58.96923872732348, 81.09335591716152, 69.57972465022918, 76.32251431865078, 76.59344811593333, 73.29140078636908, 65.3603369189847, 65.06871261904317, 64.07640787862962, 67.04775625659575, 64.33563340094783, 70.72565294081166, 75.2318286895752, 79.29469816146359, 73.50319308619346, 76.17483708166307, 78.48764696428853, 76.95681648869669, 74.9909245583319, 76.5311687223373, 73.16582218293222, 76.45683980757191, 74.82623992427703, 78.68426753628638, 70.29336067938036, 50.691802117132376, 11.777944103364023, 0.40146975567744625, 0.0501306219056489, 0.6353979209257711, 3.6151024795347646, 6.140302823435876, 6.238516030773041, 5.441271739621317, 1.5244056332495906, 1.216545662572307, 0.13283768488514808, 0.43540705235735067, 6.881711194592138, 39.832328058058216, 48.80516952083957, 27.506528862061042, 24.293642890068796, 39.04198615781723, 50.1255020787639, 24.569297259853734, 1.3908385100864595, 0.300938825934164, 0.07564598844657022, 0.12099234913025173, 0.05172003984391209, 0.058404225931172414, 0.03387967154624001, 0.039106187666015285, 0.01888919629216675, 0.03155373667757357, 0.03774258563475263, 0.03658424154104244, 0.05283221947930513, 0.05694919896702613, 0.05701633508227045, 0.04962197782832289, 0.0555258765516262, 0.04325061225362363, 0.0119153561911756, 0.04261155702894734, 0.021625938149349346, 0.09646353912689994, 0.03290106317088489, 0.021487488824453567, 0.026690252388136524, 0.07494211452262056, 0.01571755015080975, 0.04934117596055712, 0.03951484960834346, 0.035903193206796725, 0.035672880363680666, 0.08792404896549641, 0.11355545101386887, 0.028007502269540584, 0.025920816659626943, 0.03076694714235923, 0.059414818477366245, 0.05095827265552456, 0.1293830879993977, 0.1066505320129856, 0.08484109665357298, 0.013516907046939577, 0.013909831628083222, 0.0393492367208725, 0.03072599974280644, 0.038876173597189694, 0.025616511214344252, 0.06147664453413698, 0.07049137350892828, 0.029332177458150737, 0.01958343283002896, 0.02363036315317356, 0.10073636388105732, 0.020894370146936948, 0.0461873873287151, 0.03702630108642963, 0.08433462826595192, 0.024954749143592296, 0.036320354894644795, 0.026922386605292562, 0.05164530413645891, 0.08204908155265354, 0.1210765498540094, 0.011579328960168266, 0.09509523714622183, 0.05256901465116009, 0.061274657792021195, 0.011242231121286752, 0.03771391479418643, 0.005700626389889588, 0.04250731927553012, 0.08956579070898796, 0.0835799320691055, 0.06698646762919042, 0.04730453887473672, 0.03497980061858412, 0.0783467548148286, 0.05879567770828163, 0.04666092925735059, 0.050517603559719945, 0.02863303604235332, 0.03605818045475791, 0.10356166550228674, 6.679651275757821, 41.62809502693915, 62.6831780710528, 46.37843439655919, 32.27866876509882, 34.06507891993369, 66.75669285558885, 86.1664318269299, 22.73186295263229, 0.5538636121538378, 0.18278733767088384, 1.2472411509483092, 1.5729385902804713, 0.9654902534619455, 1.18680723251835, 1.3320518645548052, 0.6275625574973323, 0.08819599485685749, 0.3748584965304021, 6.888296854111457, 34.87190261963875, 64.91834071374709, 76.07601688754174, 75.85894507746544, 75.9183297618743, 74.5498461877146, 78.68509123402258, 78.04131261764034, 81.15911053073022, 80.86148892679523, 83.18423025069698, 79.66235760719546, 78.17101755449849, 71.24925013511412, 73.39525730379167, 72.32550144195557, 73.05919647216797, 70.5052157371275, 73.6632179444836, 68.91420825835198, 62.4300322225017, 63.3495024711855, 63.41714766717727, 46.459796121043546, 42.18172973202121, 46.10932842377694, 57.98218604057067, 62.48674969519339, 81.52669937379899, 72.29985698576897, 79.38377518807688, 79.92337565268241, 77.95459685787078, 68.28682514929002, 69.3365063205842, 67.69830488389539, 68.66620463709678, 68.12549806410267, 71.54496546714537, 75.30556924881475, 79.02047741797664, 74.32778512277912, 78.78377022281771, 80.01696340499386, 76.40417806563839, 75.7770146093061, 77.33695691631686, 72.98925276725524, 78.86457104836741, 77.00208848522556, 79.96992634188744, 74.65542070327267, 57.112569116776996, 20.206072292020245, 1.058493388756629, 0.45497275408237214, 3.3837738344746255, 6.1198878672815145, 9.750919092086054, 9.691536368862275, 3.364203658796126, 2.1077062045374224, 1.1579888434179368, 0.6806263423735096, 0.417736713444033, 2.7063089224600025, 45.83323278734761, 73.60413920494818, 39.534847659449426, 22.228993523505427, 38.406738696559785, 56.41149251691757, 34.469965580971014, 4.545758347357474, 0.2369108519727184, 0.05667192493415168, 0.05302578308469346, 0.009983991077470203, 0.08165144361555576, 0.038516238677285375, 0.03173786591017439, 0.08434032796010857, 0.026827730696588278, 0.0450644594797444, 0.03537100724755757, 0.05958847145760252, 0.10906240662499782, 0.0471392898790298, 0.03262785706488836, 0.09119051763968122, 0.06956157259522908, 0.03888838503870272, 0.01373934737902375, 0.014915479076725822, 0.08980025957909324, 0.05184773520957078, 0.04265060836088754, 0.005260557715495628, 0.037557755431701104, 0.11020292768314963, 0.06447845664356025, 0.0304122714160551, 0.03839818452815375, 0.050609166388429945, 0.015086611627691216, 0.011015775530869442, 0.0367459167365826, 0.0257243687332037, 0.052450022044321226, 0.040997888577441056, 0.031839129327225595, 0.226273751787601, 0.1844043347744211, 0.1692054874353832, 0.23501202644359684, 0.15569367295792028, 0.20083163474355975, 0.10870881874354617, 0.10839829266431833, 0.12291405770567157, 0.15066881033201374, 0.25440371895749725, 0.14290530595087236, 0.2270054270423228, 0.07301231605872031, 0.2182339961009641, 0.10198461222312144, 0.08865869664136442, 0.1857959334888766, 0.16392798433380742, 0.21408688637518117, 0.2258543646143329, 0.10756688042273445, 0.14858888161759223, 0.2135466105274616, 0.33244811419037085, 0.14107358972391776, 0.2135840722269589, 0.21060005250957706, 0.1395134210226036, 0.11065034601356714, 0.1085636220992573, 0.08910175593149278, 0.2974332382361735, 0.24675734941997837, 0.18761114818194222, 0.23366098442385275, 0.18633654641528286, 0.17713351685914303, 0.1413211893410452, 0.1885502187595252, 0.13647497841908088, 0.12845951538052292, 0.21248184024326264, 0.0829571638736994, 0.23286598434130992, 4.8026074036475155, 47.406448395021506, 75.7886326697565, 65.65296534569033, 65.18995700343963, 43.537477370231386, 52.450585057658536, 73.86709490130025, 46.88922505224905, 3.932228804596009, 0.6609762484027494, 6.022740073742406, 7.293957202665268, 1.1785048006042358, 1.129035990565054, 1.466506178821287, 0.4292495747006709, 0.10558078981815808, 0.2502652200599832, 5.299836464466588, 29.75345861527228, 64.05264223775556, 76.11786857728036, 73.59849883664039, 74.45243020211497, 75.4630131875315, 79.61804266898864, 79.68664492330244, 83.6848972689721, 86.22574590867566, 86.21099779682775, 83.628830909729, 77.0733501065162, 67.63762581732966, 75.66474068549373, 73.96934324695219, 71.97877960820352, 68.83591774971255, 71.85453461062524, 69.23381866947298, 64.2894043460969, 72.17717309151926, 74.40441254646548, 59.602536770605276, 45.42389031379454, 50.31965547992338, 60.57894414471042, 62.963180388173754, 82.12245248979139, 72.16138162920552, 81.44315288912865, 80.70679064719909, 77.49262009897541, 68.36843398309523, 70.38191210839057, 69.81037570584205, 71.83185546628891, 69.0732603688394, 76.61436219369212, 81.24727756746354, 83.61088998856084, 75.4266292818131, 82.5983222838371, 82.5728347224574, 82.06309133960356, 80.88427005275604, 79.83521646068942, 73.3592499456098, 82.55943590594877, 78.3799151451357, 81.24276684176537, 72.23092525236069, 54.26095108832083, 14.773285619674192, 0.7459228353634958, 0.25999176346005937, 2.2116904441387426, 8.268994688987732, 20.22796303995194, 20.394526489319343, 14.551295157401794, 11.043190033205095, 8.472960879725795, 1.7066209330674142, 0.8146553246244308, 9.694712508109308, 51.605922252901145, 63.910597524335316, 39.19552733821254, 35.1737956846914, 51.533503532409675, 66.34828782850697, 36.16013057770268, 4.048482218096334, 0.23435702126833702, 0.16152675834394273, 0.20887329032824886, 0.1377451215540209, 0.22937029449930116, 0.11160211066805548, 0.0826281750754964, 0.224839573906314, 0.13670368630799556, 0.17833477336793177, 0.14151674094459704, 0.17581658107378792, 0.19471341143212012, 0.25538950557670287, 0.17803927793377833, 0.20152048568331427, 0.2140174175222074, 0.11158941659115015, 0.10871969719207096, 0.10826026660300071, 0.14060563257625028, 0.13546096912074473, 0.15555707948102107, 0.21023799935656212, 0.12151475214669782, 0.1401658981077133, 0.14959812584903934, 0.10168475008779958, 0.13026146909161923, 0.15099654274602092, 0.13735771089071228, 0.25535267206930345, 0.1640107524731467, 0.12593157078710296, 0.07713568471972981, 0.1534379423866349, 0.11709084719299309], [0.019171068767806696, 0.020508164156889244, 0.0032387875234557977, 0.028953952189054222, 0.06680110499503152, 0.006282648283823003, 0.03437652936085098, 0.010042550838402203, 0.01063092455883781, 0.021588005305778597, 0.07038830403959559, 0.03785996562651089, 0.031355049859191624, 0.05921675027498315, 0.04317549733264793, 0.09018409261179548, 0.13974078059677156, 0.08237502898179716, 0.06958705267959064, 0.03327331678461164, 0.09151163871490187, 0.0643919499951505, 0.0778248880599295, 0.05429768056098012, 0.060191248588624506, 0.0977493257772538, 0.11404010887828567, 0.03875471035679502, 0.09982313344916029, 0.02161032719267232, 0.05544901878062276, 0.04455921300236256, 0.058213573459896355, 0.04627781634729716, 0.041311310469022686, 0.12876270999831538, 0.03147710107206818, 0.06720721586457185, 0.0213407370216784, 0.025381538641428756, 0.05383893945104173, 0.05709622273101442, 0.09355979776310344, 0.023597249002646536, 0.029830270589539604, 0.10265117766515863, 0.43698013730106816, 21.129747321528775, 52.1092604052636, 56.946091959553385, 44.18630407702538, 26.044090793978786, 25.489499030574677, 49.726804917858495, 62.7511017553268, 13.59572929720725, 0.8647215606704836, 1.493296457394477, 4.836460400012232, 1.7169077165665168, 1.6259779829171397, 1.0530153085147183, 0.32623560077721075, 0.26383439920121626, 0.1417510259536005, 0.12480741336701379, 6.893021839280283, 33.35246662939749, 66.77919157089727, 81.7557736366026, 82.85553563025691, 82.4601685616278, 72.76290062935122, 71.21886745575937, 72.82138316862046, 73.09326617948471, 73.32161872617661, 76.08560316024288, 76.27423778656991, 77.98978051831646, 78.71126128781226, 81.74796811995968, 82.87070735808342, 81.26102155254733, 84.44675491702172, 79.27643560594129, 55.630925163145996, 26.168375015258793, 41.85609456031553, 64.5398751381905, 35.797354482835345, 47.91545829465313, 45.66264106381325, 78.50568202234085, 81.26131965268044, 81.10699007588049, 83.43947456729028, 78.94990613383632, 81.06793111370456, 78.09561391030589, 79.4301611377347, 79.68417383009388, 81.59601549948417, 74.63518127318352, 74.92653492958316, 76.24684395328646, 76.13544864039268, 75.79340227188604, 76.78173757368519, 75.6493414601972, 74.16117068259948, 71.6815580860261, 70.43168698587726, 75.85809000076787, 66.27212324450093, 43.66813152067123, 21.90066368349137, 2.5606722985544517, 0.11824868183823363, 0.34236270153234083, 1.2819421147146535, 5.773349404335023, 8.44425207184207, 5.270517237724797, 3.9228920926970825, 2.988618083538548, 0.6491028661689451, 0.7775365873690575, 0.9652617141123742, 23.919705690876132, 53.37551524562221, 33.590731005514826, 19.695111013227894, 31.053008494838593, 47.73469586526194, 45.30739984204693, 14.565556895348335, 0.5597886587342908, 0.2247122500932986, 0.054799357068634806, 0.07579547518323507, 0.021769627515647202, 0.04416127246053469, 0.007178217516235647, 0.05039962218894113, 0.06682695280159674, 0.05060158211797957, 0.022452836217839393, 0.0643653207789025, 0.02621232843657415, 0.08275351472078793, 0.06185706081469694, 0.058955866693248676, 0.029939562608037266, 0.028914328206390626, 0.014735223376192154, 0.05016729836502383, 0.0329323846756691, 0.010487193057704116, 0.06417375283255693, 0.0545794706821682, 0.08270101471533699, 0.018085240641789093, 0.020493583588470376, 0.05567624811984359, 0.040996892663139495, 0.004106808234111316, 0.056969186200970606, 0.03313718296046699, 0.044928394603512944, 0.061865273277245225, 0.028304162157338955, 0.04773254453715298, 0.02852410216996026, 0.02736104855073556, 0.08587120912007748, 0.02733801420207226, 0.0418254129228092, 0.04120504641304574, 0.03508075951568542, 0.04984114026170104, 0.07007244598841475, 0.02412149254533072, 0.07562862889420602, 0.06752156472254185, 0.0299449558670242, 0.021193205724440275, 0.027341997859278516, 0.048919337305931315, 0.03301507237577631, 0.020002316300486846, 0.03509459123315831, 0.019450380594559738, 0.016496912463598194, 0.01698718192206035, 0.06160150537447584, 0.0732430617415136, 0.04692487336034256, 0.09213013213969047, 0.05775632622141031, 0.06950917218120829, 0.11173835174450952, 0.1026191168855275, 0.04387067998909662, 0.039458201236782536, 0.05486104629873749, 0.10000501804414297, 0.030467487203197616, 0.042823246274624145, 0.00978278766025699, 0.051849577651028676, 0.059862512599436514, 0.04059956882209067, 0.05295512679543707, 0.05344891259747167, 0.07206627408102637, 0.040961192965868025, 0.027978385182758494, 0.07695316427176999, 0.0672350554997402, 0.031331563518652995, 0.054999260051596555, 2.105464324835808, 32.353774309158325, 63.51883903626473, 59.63966592665642, 35.1308221970835, 21.081415876265496, 42.83249408968034, 87.52286587992023, 64.65130183004564, 5.700985106729693, 0.7904609196609067, 1.1768974868520614, 0.7610683323394868, 0.794073238728508, 1.4165084616791819, 2.3360246756384453, 2.221365705613167, 0.9515416922588503, 0.23374997319713717, 0.7166116985101855, 12.470660171201153, 42.770261764526374, 72.92283135075724, 81.678753975899, 77.24867220847838, 77.24851531367149, 72.55087298731651, 70.60914285721319, 72.212858815347, 75.49617290496826, 74.92191437752017, 75.79632836003458, 73.57549805794993, 75.81710123246717, 76.83862763066446, 77.41261943694084, 76.12534461482879, 75.21155788052467, 83.00044367390295, 80.7850262426561, 71.84650944125268, 42.34669285435831, 53.3851368196549, 61.24186000516338, 41.67089985262963, 54.66572792299333, 52.38072372251942, 76.40793569626348, 79.7021775091848, 80.05560659593152, 81.18116209583899, 77.70266302170293, 77.16411375230359, 75.12899198839742, 74.40671105538645, 78.07541370391846, 81.01982716591128, 77.1783519560291, 77.2665503717238, 77.39665539033952, 77.21273545295962, 75.19186758225965, 78.11687315663984, 79.2004357614825, 75.27662215694305, 75.83286916055988, 73.65159203929286, 76.34490320759436, 72.55803523525115, 53.304198711149155, 31.333783518883493, 5.8792710496533305, 0.47030318468328447, 1.3454104767691706, 1.8474906514729224, 6.444122262539403, 8.231216380673072, 4.257707816939201, 1.6209286667646903, 1.281544361864367, 1.409010605946664, 0.4106060896188982, 0.42330010523719175, 19.678286006373746, 69.38505741857713, 50.896149758369695, 21.124540375125026, 24.73023799157912, 42.65936067027431, 54.686037955745576, 23.66335918826442, 1.514439380938007, 0.25018832015414394, 0.04356254793463215, 0.018127065212015184, 0.039672445385686816, 0.04681672855851151, 0.006586773698443488, 0.04103844527215247, 0.10513023818813025, 0.011668777386207255, 0.02043800965522326, 0.04730265046800337, 0.022050312555004514, 0.04589784056729367, 0.08297238604075487, 0.0808149828545509, 0.04202436212630522, 0.07644396095025925, 0.060218643892796776, 0.13956361510340246, 0.0781533022921893, 0.008738549490038668, 0.0927265469105013, 0.03314844828339354, 0.09800222672281728, 0.01786369759018623, 0.05453945407944341, 0.05907976609324256, 0.02876700949855149, 0.06827639881521463, 0.08108315959332452, 0.12957254154307227, 0.05373183652878769, 0.022088521190228003, 0.027998374331922784, 0.07857283502216302, 0.016952152551722624, 0.04901133297431854, 0.10114917035905585, 0.1293784301848181, 0.08930558128462684, 0.2015567522856497, 0.10838412769859838, 0.15885036889343493, 0.13596134710936778, 0.1450285339547742, 0.19445792110937257, 0.10014278363556632, 0.17716662717923043, 0.22093436410350187, 0.21825371520413508, 0.21343632450988217, 0.1558635606160087, 0.16721132992496415, 0.16486829597382777, 0.2238124645044727, 0.1407892791734588, 0.14346902408907491, 0.1713052118617681, 0.29952560821848534, 0.07306614139628026, 0.28396574960600945, 0.14332101590210392, 0.12341129473380505, 0.21713298985794668, 0.2387721851588257, 0.22201142243800626, 0.1958956689603867, 0.13119005958639807, 0.17226009449410826, 0.1507676509960044, 0.2181007887326902, 0.13863767527284163, 0.17105491561514719, 0.17313357262361437, 0.13506808858965674, 0.22112564093643622, 0.1788382463517689, 0.21643618692553815, 0.21069504741218784, 0.1581553432850107, 0.13561654625640762, 0.11448463905722865, 0.1285875669770664, 0.2123871211323046, 1.1447789135479158, 33.74675896859939, 78.30360935580346, 73.37722224573936, 60.70428740593695, 40.680344489312944, 36.35548422413488, 65.58086433718282, 77.80542912021761, 17.885199977505593, 1.325904529902243, 3.311537013899896, 13.959686025496453, 10.232727354572667, 4.529226537673704, 4.3219822260641285, 1.0616946556875784, 0.6572861560890753, 0.3933372727084545, 0.6467246841038428, 7.9970695126441225, 35.611928355309274, 70.84592849977555, 86.46140975336876, 83.0337759756273, 81.80314017880349, 72.41091497482793, 70.7344861184397, 70.9209006832492, 71.62999460774084, 71.50429048845845, 75.47117171748992, 77.05745666257798, 78.4619789738809, 79.69230882583126, 79.64712312144619, 81.10454251689296, 83.55836160721319, 88.87420869642689, 85.51100377113589, 65.69453070240637, 35.00973862986411, 54.294463819073094, 78.31195615953015, 51.026650936372825, 63.07766652876332, 57.60503445902179, 72.5853035526891, 82.84682796847436, 82.56507627425655, 88.39906061849287, 84.32191371917725, 86.91641253809776, 83.25085563044395, 82.73358129685926, 84.97968735233431, 87.60609857497677, 79.23465451886578, 77.77805097641485, 78.14779712307838, 80.12254576529227, 76.54208860089703, 81.56046313624229, 80.6966709321545, 74.1971545065603, 79.12961344565116, 75.8338575978433, 75.2890560703893, 72.26981947498938, 48.55309055697534, 29.63974125923649, 4.033518130740812, 0.4001202764770677, 0.8629549619170928, 3.404462375948506, 11.475385215974624, 16.95411951311173, 15.95063699829963, 14.639420028655762, 12.535935275016293, 3.9257036966662255, 1.5383974630986492, 1.3552718056786446, 31.897635998264438, 66.05494160805979, 45.839430132219874, 29.407689917472105, 41.533864005919426, 59.81691783474338, 63.431397638013294, 23.456699309810517, 1.0777448718586276, 0.3286689105293443, 0.11838970330333519, 0.15975398492188225, 0.12661266891706374, 0.197381190054359, 0.11507685566621442, 0.18564685277881163, 0.17507281695162097, 0.22992474297361992, 0.23372155133514638, 0.227550330061105, 0.09658068929228092, 0.13657841561061723, 0.16049632412051001, 0.1824968064864797, 0.15976898492343966, 0.0957681687789098, 0.12858373653744498, 0.21419629905252688, 0.14016504008923808, 0.14440337556504435, 0.23633185804130571, 0.16579938391523977, 0.3538272379627151, 0.09316682530146453, 0.09359187386449307, 0.09645784709362254, 0.13301114251296367, 0.13651184256999724, 0.3067511963027139, 0.25859935269240414, 0.1913199636844858, 0.09865191524788257, 0.1338827820314515, 0.2301496051011547, 0.14886666509893634, 0.21990054377144386, 0.17674655052683047], [0.11252287940512742, 0.04628548488741921, 0.09110463918336938, 0.02968151163640282, 0.08265220725368108, 0.009892573805465814, 0.10955664824934737, 0.09079236642367418, 0.06546417431485269, 0.05024805552356186, 0.054287598843896584, 0.02714865450416842, 0.056761066925020955, 0.03313801799630446, 0.027972474814422672, 0.0890953514364458, 0.004913669272941808, 0.1168780662720242, 0.02228952159414128, 0.059601483460996425, 0.1601062474712249, 0.36175952683533397, 0.09442946077474663, 0.03626190238602219, 0.08588841545485681, 0.093875425987907, 0.09129820661919733, 0.2322344214565331, 0.07104542361752642, 0.020624904465230725, 0.06208273116499186, 0.003281986742701021, 0.0599769814570825, 0.028487000531787356, 0.06647899566638855, 0.008806014065480521, 0.04241093392333677, 0.041739948153976476, 0.0644800960717182, 0.043902606703341014, 0.017649591337108327, 0.02896367767525296, 0.059283622089893594, 0.007861677591027993, 0.03233127378588242, 0.07898440809860345, 0.07160633021304685, 0.07883928040222776, 11.070431874644372, 42.09429617851011, 60.01366392258675, 51.178548643665934, 47.52061290125693, 19.809332393830825, 28.971494897719356, 61.61475189270512, 39.603720557305124, 3.9741787987370647, 0.0948557120958163, 1.270063706944066, 1.537581119806536, 2.879477643197583, 2.369520736317481, 0.5754242681207196, 0.41030379132397715, 0.06469070896386139, 0.138677190087976, 0.19528990791689968, 5.237067755191557, 25.902620707788778, 50.39982088150517, 63.18047577334989, 69.39320025905486, 71.13845102248654, 73.93647378490817, 71.30250023257348, 74.56029538185366, 72.63125804162794, 61.25637277480095, 60.83529456969231, 56.78070522123768, 54.45925435712261, 52.92163425876249, 40.04347708917434, 22.214374849873206, 7.756665973894059, 0.33030984021963616, 0.13327699034444748, 2.6934852234778868, 37.22759185298797, 23.071153856092884, 42.52416833754509, 59.05096130986368, 68.51731146535566, 59.93180013472035, 71.89986152033653, 83.55965598937004, 77.60333291945919, 74.91944328431161, 70.72386434001308, 70.09181361044608, 70.26081285169049, 66.9753179242534, 80.78830534412016, 87.91294559355705, 85.58768610800468, 80.770615454643, 82.76853745983493, 81.3192452153852, 78.30943799787953, 69.100999370698, 61.922014682523674, 50.43201569587954, 26.32818022081929, 9.743765669484294, 2.692174416395926, 0.05814305123602671, 0.044250820478003834, 0.4152535773333042, 1.5992046195653178, 3.334274748640676, 3.692886757273828, 4.204411631630314, 3.7062323766369976, 3.5158245938439525, 0.7219350289913916, 0.20832683981185962, 10.027459917529937, 45.494845990211736, 40.98484985290035, 24.137350166997603, 27.58053025891704, 43.207711942734264, 53.40474474814631, 34.6429774069017, 6.26703852607358, 0.2691192414251066, 0.09050303033643192, 0.11631853097388822, 0.08662473320239976, 0.036024671768949884, 0.08654352788242602, 0.006463971240596185, 0.007854621442440417, 0.04071112271518477, 0.12899674985918308, 0.03463782663006456, 0.0366565564106549, 0.07071419784258451, 0.03135618941497899, 0.029268758784558986, 0.0572538759649521, 0.042233887173595934, 0.10979906911210668, 0.03998857156764116, 0.06760859231074011, 0.05127401579351676, 0.05618161334085369, 0.04482355164063554, 0.098060809466387, 0.008935883205624358, 0.02143625286407769, 0.028787418080854322, 0.04068889084362215, 0.05469511165433834, 0.019555236963975816, 0.01791739460801886, 0.04405791187779077, 0.012779762882048325, 0.016175885234148275, 0.05453660806280471, 0.02987948024735576, 0.023393699441165216, 0.13237820066992315, 0.03955340681357249, 0.02034879488600118, 0.03907502320925555, 0.028355555165739312, 0.03256765404535878, 0.05595484365438742, 0.0942437150966256, 0.024974159896373752, 0.03905031304325789, 0.04430043233198024, 0.055779505280717734, 0.017356181577328714, 0.07186955802382962, 0.07071674891537236, 0.0369888547086908, 0.05504389616450476, 0.06849962917547073, 0.0014805277568220553, 0.025711431423382416, 0.04884543280387598, 0.09316299486184314, 0.0806959481128762, 0.17231748980139533, 0.12965170906916743, 0.023323181047735196, 0.018536445361772375, 0.08822709802658328, 0.06004058973743551, 0.11629846713115131, 0.1891961840972785, 0.044611329963851365, 0.03079681691052693, 0.013442054511077944, 0.09212558157742025, 0.07596341697799583, 0.04624244989827276, 0.08315993202549797, 0.05891182429848179, 0.11763612559485821, 0.044630681344818686, 0.023936834712062153, 0.037098447416698745, 0.04530090485669432, 0.04986220001873951, 0.027766224793008262, 0.041927984434991114, 0.050212175795628186, 0.048407843381526976, 0.07325937941430077, 0.5182802376727904, 18.575213532293997, 56.57636934711088, 67.13160868613951, 45.629328373939764, 23.061865683524843, 25.47104035654376, 63.453111879287235, 88.96146574328023, 32.03911392919479, 0.7952551591780879, 0.09615458352791686, 1.3696103975657494, 0.7438841834664346, 3.375363292232637, 3.4361333087567365, 2.7807604112932762, 1.7454814478274316, 0.7210401157217642, 0.24152420280921846, 1.2901497968742925, 10.366057542062576, 39.61424427647745, 62.79385166783487, 71.21443517746465, 74.98787295433783, 76.60366196786204, 78.05138526424285, 75.27778317851406, 77.25604626440233, 76.46319404725106, 69.19340256721743, 66.42967700958252, 65.43179858115413, 67.0782252280943, 69.78879482515397, 56.79728507995606, 40.53034128681306, 17.844995683239354, 2.6360381899341463, 0.46311577842120205, 8.547153492127697, 61.47380544293312, 37.40915836826448, 50.98772141241258, 64.7082664120582, 73.48379304332119, 69.0941587571175, 75.55074091880553, 83.39956837315714, 83.03171280891665, 81.01723840159755, 76.35880408748504, 78.16563606262207, 74.83227252960205, 73.7178094925419, 77.35237967583441, 82.21554602346113, 84.2355509727232, 83.82363934670725, 84.34307882862707, 82.63479248169931, 77.77001796230194, 76.44368417801397, 65.91605048025808, 60.13505735704976, 41.419907385303134, 17.42826346428164, 6.035774600121283, 0.17183152958750728, 0.09617955033336917, 1.5180379104229713, 2.559210725368992, 5.080263653109151, 9.326494124627883, 5.9440705660850774, 0.4893793255811738, 0.8770768428521772, 0.42668921692717465, 0.24973962245689285, 4.9474134656690785, 54.2044375788781, 69.5913819343813, 32.827939833364184, 21.573226182691513, 32.7313651961665, 55.234765775742076, 46.54725713114585, 11.631018000264323, 0.292022880166769, 0.13701660258154716, 0.09345829877401553, 0.11697239467814086, 0.036509666712053364, 0.010972244499792016, 0.006177235543051916, 0.005480985151558754, 0.03442729417715342, 0.01293236280851547, 0.011899230040369496, 0.03902209036412739, 0.06560123510538571, 0.0244588527693263, 0.04649785978178825, 0.03731436163727795, 0.01839421922340989, 0.05985145795068914, 0.009627336929101617, 0.049734186726592244, 0.022490516252395128, 0.02203099181755416, 0.05015555040670499, 0.08046678823208617, 0.048955933326074196, 0.031310145615509925, 0.024115471094245874, 0.02459411516845707, 0.030419878669143207, 0.008479191380883417, 0.027133474471948804, 0.044401651698975794, 0.07130260699458661, 0.025755425937654033, 0.02907690930090124, 0.02851536876762346, 0.035048315692092144, 0.0512355620101575, 0.06925518339079234, 0.023374275281845082, 0.3015328505106511, 0.18854808903509573, 0.10830096885441773, 0.1544452560765128, 0.1910951168787095, 0.1898310871254052, 0.202853815750249, 0.2160671010853783, 0.14339399343777087, 0.12255123080385309, 0.22595112151916952, 0.16488332661890215, 0.14271067365282966, 0.1985009348080043, 0.22061996161937716, 0.12126637111988761, 0.15863146692995103, 0.14661265056460135, 0.13926876318310538, 0.2625108137726784, 0.2615143172442913, 0.5069516665272175, 0.16509914890893046, 0.3280264691960427, 0.19262451948898454, 0.2830189875056667, 0.1919663886749937, 0.5331092484055028, 0.25554479159895455, 0.14135207800615218, 0.20771115026887388, 0.18038195948446953, 0.20638039425736476, 0.0978023543833725, 0.13741948822092626, 0.14834664461593475, 0.24690546485925877, 0.23341412025113262, 0.09060386282902572, 0.12116756876029315, 0.2009309503820635, 0.205298907934658, 0.09561099818036442, 0.19738688974851565, 0.08974489440480549, 0.35780847433113283, 0.17637660666819543, 0.3279258971733432, 16.674952660837484, 66.38831953848562, 82.04654678221672, 64.61370983431416, 67.63914769695651, 30.31955469039179, 43.54752648261286, 81.57408945022091, 52.162859593668294, 5.129461451884239, 0.24203676159583756, 2.945560264971949, 9.404802283933087, 9.950120583657297, 8.153961868055406, 2.8789294919660016, 1.1385123143273017, 0.5005004094733346, 0.21097526705313116, 0.8387243363165087, 5.300697915015682, 29.058079258088146, 53.676447329982636, 66.48091885351366, 73.49971786622079, 73.93413605228548, 79.54011301840507, 75.96968143217026, 81.73834262355682, 73.72009231198219, 62.403995529297866, 63.465612473026404, 59.09147154900336, 61.92285799211072, 64.24582681348248, 45.358798580784956, 29.761356307614236, 9.345838273725203, 0.8388723445034797, 0.32955683707710237, 4.90846432985798, 53.32181407559303, 35.600816280611106, 53.115681755927305, 71.08159234446865, 75.18264216761436, 69.31100306972381, 76.94922278004309, 80.34782317376907, 79.54128972945675, 78.43169827615061, 77.28142399941721, 77.49146692214474, 74.42555412169426, 70.84004494451708, 87.86049565961285, 92.68436770285331, 84.95826336645311, 82.49168088359218, 86.143125103366, 84.53265482379545, 82.26679571213262, 80.4470120706866, 59.0332478861655, 57.18921222994405, 38.348209088848485, 13.109107305926662, 4.23370732415107, 0.10564196193891187, 0.24327053087613276, 1.3181612808858196, 3.161812544830384, 8.577755824212106, 16.37338907487931, 16.681175501115863, 16.39178204920984, 12.249745418948512, 1.5227158271497296, 0.20133523030146477, 15.143301429287082, 57.37760759169056, 56.083033238687825, 35.58340095704602, 40.75779168836532, 55.661413746495406, 67.73798358055853, 49.52879190444947, 10.424697956731244, 0.4944094588919994, 0.21702978249278762, 0.14638820212454567, 0.26245133470623727, 0.13432654612247022, 0.13675916639547195, 0.11890364104821799, 0.12004715751015371, 0.17263062057956574, 0.3182843742111037, 0.18155176042308732, 0.20211043467204418, 0.24167006595000146, 0.08520499607848545, 0.13515528471719834, 0.28140738366111634, 0.1518292803197138, 0.2545522940495322, 0.10803297597674594, 0.2533586524547108, 0.14226254286064258, 0.14309163385581586, 0.15397789647742627, 0.13730216951620194, 0.11583001202633304, 0.19412225202446987, 0.26881853659306804, 0.17983561622038965, 0.10870697247164865, 0.15168174710725585, 0.19451087310669885, 0.15553664025520125, 0.13496477397218828, 0.08308095602138389, 0.31791276028079374, 0.1137398177337262, 0.21180477173578358, 0.2164945781471268, 0.12102957334249251, 0.13906843119090603], [0.041330845711091836, 0.2629202111594139, 0.05502436475287523, 0.14354425392323925, 0.08203881597446819, 0.05371496344225542, 0.09771184109511877, 0.29954678288871245, 0.11580096963312357, 0.10067995682719255, 0.10455511300073517, 0.16391338269797065, 0.08942928150176041, 0.06055694448971941, 0.021692204754799608, 0.10337110113112197, 0.1422982578796725, 0.0994707023604743, 0.0505464467700691, 0.21347842870220063, 0.20161355004435588, 0.03369125988214247, 0.15816234532863865, 0.07108598031223783, 0.016472621730739073, 0.06778045647567318, 0.08180871380553131, 0.10841845609848538, 0.05554949504233176, 0.057000235744541695, 0.020579046442083294, 0.04412129799264573, 0.08961619163352637, 0.09820385340360865, 0.05462474264805356, 0.04034809280006636, 0.04266316071152688, 0.09173346713425652, 0.004967443857176771, 0.06019776416642051, 0.07479633565150923, 0.016015358212884637, 0.03116637772519983, 0.03432445070375839, 0.07556180304457104, 0.03558595619735218, 0.032048531800448414, 0.03281253405035504, 0.22079930280245122, 2.0757967425930888, 22.880379576836866, 52.66592318011869, 57.777257888547844, 50.7134771347046, 40.56590933953562, 24.758396687046176, 45.013237768603915, 66.25936769670056, 20.525998453940115, 1.118742220344082, 1.2527421525409146, 1.5169743352359342, 4.950776407795568, 3.7093609571456914, 1.4835520641457651, 0.24665758945047858, 0.06514639338298191, 0.3016550568563323, 0.12553897370854694, 0.2582961350919739, 1.380209009493551, 4.755331566256862, 5.859058585859114, 7.4074573574527625, 9.846511175555568, 14.706760260366625, 11.295605340311605, 7.74667275528754, 3.3159874331566597, 2.972951891922182, 2.0996697583506188, 2.7136469416079985, 3.1849064798124376, 2.2811884697406524, 1.1454504968658572, 0.09935372073443667, 0.1657598537783469, 0.13138187268087942, 0.039092041852493445, 0.39710884613375513, 0.1685670604028048, 4.5964437050204126, 20.64896672002731, 47.54561801110545, 62.498559951782234, 89.84173190209174, 90.6324032814272, 82.35783392383208, 89.35947648940548, 90.74746993280228, 88.2134775961599, 94.67391152535716, 94.00239390711631, 73.13009723540276, 43.48749852949574, 21.138454983311316, 17.180748178112893, 17.149343721328243, 16.083628881362177, 16.47770647079714, 12.15656461254243, 3.401333795439813, 1.3363369313939926, 0.17576208157885462, 0.40678334152025564, 3.6269159230493733, 0.6503303841717782, 0.2374306732728597, 1.262262480393533, 3.100673580361951, 2.383679512046999, 7.7186920373670524, 4.640899848553443, 0.920079809523398, 0.4394487483847526, 5.546194161138227, 30.876270417244207, 42.267759077010616, 27.627945830745084, 22.505122500081217, 40.027975882253344, 55.865690785069624, 51.052056127978915, 17.65916947395571, 0.41747100350837557, 0.2388818583060657, 0.08560981225943373, 0.07869043717941931, 0.04204122372151863, 0.050647769558934436, 0.02480082675784586, 0.0678025274687717, 0.0852655170245036, 0.030252030720153165, 0.06641594663022027, 0.035335445446112466, 0.07939273296224494, 0.03275104400311266, 0.08252705146949138, 0.07722039872239675, 0.14201468277362087, 0.04962512261925205, 0.03584891204692183, 0.039691601414233446, 0.02072732275982778, 0.016373177772508036, 0.009032620000652969, 0.04144200123846531, 0.07292069194297637, 0.07543419577902363, 0.09141769335274735, 0.04091575629107895, 0.30649250373244286, 0.0895133596514502, 0.08835590038929256, 0.04633262227740019, 0.20252710989406034, 0.37420557511429636, 0.20105968379685957, 0.010646875467031233, 0.024717114415139924, 0.07757768680852267, 0.011092731935693132, 0.048943802323793216, 0.5570378515028185, 0.03026731417424256, 0.09096718002711573, 0.07762430325871514, 0.04245522912711867, 0.11321622728099746, 0.0682793099493269, 0.008638455314681897, 0.04604512097073659, 0.10916212062922218, 0.08427655880129145, 0.062052390252750736, 0.049277069723053325, 0.06897155465858598, 0.06991799500200056, 0.041151722863076196, 0.04753680907249932, 0.06850979516222593, 0.0880320750236992, 0.045803868392061804, 0.08245650243254439, 0.08852497599418126, 0.2610694346649032, 0.09511406758740064, 0.1158540748480347, 0.09915418547367859, 0.11348163844236445, 0.13366829273441147, 0.07317586816967496, 0.0702429082124464, 0.04178404417489806, 0.038581436590081265, 0.07045146032807327, 0.06883859243844787, 0.022991143219593554, 0.07937799343058179, 0.03188488201328343, 0.04871087712085536, 0.06206223831301736, 0.05097457883699287, 0.010835185624478806, 0.024887011649327415, 0.13027282251465705, 0.10011007934207879, 0.01783102010977605, 0.04095952289419309, 0.08132731947567194, 0.08899565275397994, 0.08482296335240526, 0.0719976096203731, 0.12451747207031136, 6.00877300385506, 37.70406569204023, 67.25867779024186, 56.922471446375695, 26.843785585895663, 20.35671287967313, 38.81966621645036, 77.30233023243566, 69.55064419777163, 12.108237089649325, 0.9700812651745736, 0.44583237519668, 2.173639040800833, 1.663004054177192, 2.4298254616798896, 1.5651620011175833, 0.8021537502927165, 0.24091033655549252, 0.19520835019648078, 0.5218893698146266, 0.9400256134329305, 4.6458243843047855, 10.602667658559739, 12.277755064349021, 14.071828549908055, 18.467099282049364, 25.13769184389422, 24.53977946312197, 17.340837755510886, 9.316551896833605, 8.4682491325563, 7.444208004782277, 7.392074311933211, 5.137208132974563, 2.7273656764338097, 1.0224051929769977, 0.13776488662246736, 0.4628632145543253, 0.1835814490914345, 0.22016842939680625, 1.1231024250868828, 1.1367536216012895, 9.214609496055111, 31.952725687334617, 54.892970438926454, 61.95261701460808, 87.57115810148179, 84.79843462667158, 78.34544535606139, 81.16131490276706, 83.24509759103098, 80.53522617586198, 87.62656550253593, 90.37553510358258, 86.14518042533629, 60.76287584920084, 35.36756469357398, 31.461862633305213, 28.787839720326087, 27.361995404766454, 27.803773918459495, 22.264887132952293, 7.154595880739151, 5.228316457040849, 1.315868655520101, 0.6301580633847945, 3.515702510072339, 1.543184470745825, 1.3844916248513808, 2.2964129044163615, 1.6942804210609006, 1.600630155974819, 0.7038538218025239, 1.7444243690659924, 0.6493562880542971, 0.36858411385647716, 2.405183171072314, 33.42791734203216, 63.04733091785062, 44.47106815153553, 19.523346501012004, 30.000518906501036, 56.569866057365175, 60.75998506238384, 26.06735044910062, 2.0593664242375285, 0.25722063957683505, 0.03564178868527374, 0.18184932429463635, 0.07072141439083122, 0.06306056196110384, 0.033390283088890776, 0.07569842716498722, 0.07849470171476565, 0.036273328587412834, 0.07141099311411381, 0.055363500385635325, 0.04318770111328171, 0.008329358947042736, 0.03809400548737857, 0.04777636859686144, 0.05497189922138088, 0.07082291337991915, 0.029581200083597537, 0.04422925510293534, 0.07309260973406416, 0.04867390188718996, 0.034086534437993844, 0.024730337092713005, 0.019049301007462126, 0.03120136496070172, 0.04717474059772588, 0.08181966120196928, 0.14550330928496777, 0.10322729110597603, 0.22402703041030517, 0.07037677441633518, 0.11393132439303784, 0.23909345179075198, 0.07304973179294218, 0.04868109162235933, 0.056379298499274644, 0.03282305626799503, 0.0726232276628575, 0.07920416041968331, 0.12123867704142487, 0.020435979522223917, 0.302105761703945, 0.43810355927675004, 0.0880697129234191, 0.17345349094079388, 0.12131307950063099, 0.15916552214372545, 0.23880429956461155, 0.37900664813576207, 0.28307111212803476, 0.12333084017999711, 0.2169445015850567, 0.1969412410812032, 0.4976931568836013, 0.3606986789213073, 0.11747436612964639, 0.13521602016783532, 0.2667028162508242, 0.13453784849374525, 0.1645309568172501, 0.2632582091516064, 0.26856140684216256, 0.19805156295337986, 0.22506941560535665, 0.24436603660785386, 0.12610100645331607, 0.2764517447400478, 0.13534492212197474, 0.27070933352074317, 0.31614655989312357, 0.218566830660547, 0.19965857027038453, 0.13669496822741725, 0.11984992817404772, 0.15282933149606953, 0.1030212517587408, 0.3426512715316588, 0.18478160243361227, 0.13909990208283549, 0.055478164595702005, 0.08703896460393745, 0.22217772480460907, 0.18200005975461778, 0.1172523002230352, 0.11284745553688658, 0.11549663354432392, 0.17357916000389284, 0.14819832999379406, 0.19634300302113258, 0.4776182211935521, 4.621293881247121, 40.21876388980497, 79.22969664296797, 73.17315701515444, 66.38430303142917, 56.822219587141475, 37.98527217680408, 64.31296210135183, 82.72930591337143, 27.50341057777405, 1.5894550782057548, 1.8147502599223968, 5.102392194732543, 16.7014874950532, 16.28478567446432, 7.36143030466572, 0.36484600315170906, 0.30004069509525455, 0.3513528658978401, 0.5345238757229621, 0.9061237713021617, 2.802577614784241, 6.942524112039997, 6.442193437007166, 8.120644765515483, 11.003049477454155, 16.837809470392045, 16.063368858829623, 10.407207127540342, 4.9034167297424816, 3.7365606331056167, 3.5928109144010856, 3.784420168207538, 2.885833844061821, 2.2468282618830284, 1.5096458768652332, 0.2439680079659147, 0.23916632207410954, 0.22824892563925636, 0.2669281073875966, 0.6177409425858529, 0.6595768815567417, 5.77544100822941, 25.06054274497494, 56.64240637133199, 74.6056850494877, 94.5689175205846, 88.64267902989542, 85.64991843315863, 95.58703930147233, 96.21097072478264, 91.34050092389508, 101.8798154400241, 98.80188449736565, 79.82144109664425, 48.397305780841464, 25.704852842515518, 22.378386797443515, 18.769894492241647, 16.736610358761205, 17.66073646083955, 14.262760704563512, 3.4910893920929205, 2.104462649553053, 1.2039711566702014, 0.5374269199467475, 6.820587919604394, 2.749079917707751, 0.8537350631048604, 2.8084015990457227, 6.796237355278385, 8.969134822968515, 18.96714852702233, 14.353764595523959, 1.3609094773569417, 0.568788475807636, 8.99353490721795, 39.81204548189717, 55.17295314419655, 38.63129831129505, 32.0416340520305, 50.000625579587876, 71.15610168826196, 67.25520257026919, 25.830492242690056, 1.7098635074592408, 0.38365097956792005, 0.2361930275876676, 0.41144890890967467, 0.34369186408096747, 0.17096664696451158, 0.16201042029405796, 0.1598882035262162, 0.16704381713944097, 0.06719986142049875, 0.21178681463483842, 0.21313877596009165, 0.16761110524737066, 0.12770712510832857, 0.15472356049764543, 0.146621000922976, 0.1869352900933835, 0.09765671340808754, 0.26504466490399453, 0.29149786479050116, 0.23343814476843805, 0.1777588591099747, 0.1200198617974116, 0.0726060289889574, 0.4379763886813195, 0.22318226525620108, 0.2842857904972569, 0.14529467289966924, 0.2917219608301117, 0.13892370186025096, 0.4087561404993458, 0.24339285979588188, 0.589642063263924, 0.7568313145349104, 0.3053029836906541, 0.12941468146539506, 0.21560557907627476, 0.14419521415425887, 0.15629600192750656, 0.15370409665328844, 0.6141831689784604, 0.30405340235560174], [0.06924892445245097, 0.1081275725136361, 0.05660370097405488, 0.028106900262496168, 0.055405987621915925, 0.0941166977187799, 0.030221613199119608, 0.05578436610859729, 0.049560254124263604, 0.064297721180464, 0.08541919426211426, 0.1338605348381304, 0.027588153400668697, 0.11907022686735277, 0.1112798557827069, 0.012525989553861082, 0.11840409809543241, 0.07712069237905164, 0.10663911730291382, 0.11302826760877525, 0.049759881315572616, 0.1051324675039899, 0.042036627193972956, 0.044514186184612975, 0.08405647706240417, 0.049348358034847245, 0.04608700682799663, 0.04398679210534019, 0.10040846292770679, 0.0623043604014862, 0.043227123997865186, 0.03594523611208124, 0.03659769787543243, 0.10478737553761852, 0.09239685331140796, 0.02714140922762454, 0.05609374305593872, 0.029585294823552814, 0.033799569392877246, 0.038378017263547066, 0.0956013837769147, 0.04515194289025761, 0.02139127201160356, 0.041042570655624715, 0.06986831420011098, 0.01788464243403606, 0.002947764366962797, 0.06350195884043652, 0.08253753921317478, 0.1629821262172153, 0.03576110687948043, 7.758880642152603, 41.92233554778561, 67.18708668985676, 56.90299687847015, 48.62658008452385, 33.024634930395315, 31.973212226744625, 57.188980810103885, 44.48627125832343, 16.70797509531821, 0.32724775614277013, 0.7105126580403698, 1.213644579533608, 1.6787218494761376, 6.013733331234225, 0.47842420697692906, 1.8846282651347501, 0.40393689587231607, 0.025133228477751537, 0.075087770819664, 0.10830240909971538, 0.024489433084043766, 0.1949346576246523, 0.26115008840157145, 0.1471406843272909, 0.04206306105780025, 0.10214379763290768, 0.1029604550210699, 0.0426621992711819, 0.15650509796555967, 0.6128849870254917, 0.4406772469801288, 0.12565053143208066, 0.6149723621145372, 0.1365733134650415, 0.1852907291463306, 0.08591917388501667, 0.09850723954338221, 0.11614070664490424, 0.07409513537441531, 0.05120943458149991, 0.2541494390536701, 4.812428528262723, 18.157800782111384, 30.981509570152532, 47.458474712987105, 60.80198187981883, 68.92625777952134, 64.79604513414445, 52.42956115353493, 33.96256385311004, 15.311589740937757, 1.9851501550405257, 0.35698201867841906, 0.2098606550885785, 0.17432039603590968, 0.09960105222079063, 0.09855498214282336, 0.04624999969476654, 0.058275933016932784, 0.059462561076807405, 0.26914240792393684, 0.3466929369155438, 0.9998073152476742, 2.3399061060720876, 1.6763654855951187, 0.6681180877550956, 3.9330270069260753, 1.0749028695206488, 3.364374036750486, 1.4505996194577988, 0.7936903173404356, 3.6186458506891808, 23.59854594353707, 42.38043700495074, 36.9706295382592, 25.32443000424293, 33.729006321199485, 54.038289900748964, 54.509590133543945, 28.540047907060195, 3.118929026588317, 0.05694629932423273, 0.042839249851362365, 0.1378455403591356, 0.132829257917981, 0.08364838202513995, 0.018152575939893723, 0.02395829475004106, 0.0562335885760765, 0.023471962983509707, 0.057616300670610326, 0.018609193071062048, 0.0604936579662946, 0.02220022638568715, 0.02574214388826682, 0.06980698120089308, 0.07831990343308257, 0.008675844235826404, 0.044269601123467575, 0.14060428426150354, 0.01676514282852652, 0.015230722342347427, 0.012735231148619807, 0.02084962678171935, 0.010826891765088565, 0.061920358829440615, 0.1023938640531513, 0.023245654865017822, 0.011310370811711878, 0.06456392141239298, 0.018907639858943802, 0.07079536485816203, 0.06820296162679311, 0.07888042698464087, 0.17623872616358344, 0.06620406969300201, 0.05668178831617679, 0.07180997936595833, 0.07503209921020655, 0.07542232141619729, 0.3720643900094494, 0.11769283142301346, 0.027946278437851902, 0.017363641358491395, 0.18894014219122549, 0.26766165189685365, 0.05130714526580227, 0.04934082356011195, 0.06000426184806613, 0.1533866298174666, 0.14593924395740032, 0.07879893821213516, 0.0485034205109602, 0.02689693141878853, 0.048395026730553764, 0.024121862182754184, 0.0495308478392901, 0.028759381178045468, 0.038365813482913284, 0.056366979805452216, 0.03361891819945267, 0.07220280627089162, 0.008955110097303987, 0.05765736298335176, 0.018581182981330543, 0.01971199962070152, 0.06448358177177368, 0.041491934849369916, 0.06054649505043223, 0.06210242345508549, 0.09181535427248286, 0.04563939697559803, 0.030296829626745278, 0.0352688915576906, 0.07661610856772431, 0.02408312303164313, 0.020465747783741644, 0.10008554920674333, 0.025064429951711528, 0.0086968905863262, 0.08218286348687065, 0.06221735962636529, 0.02896582655188057, 0.06633192976756443, 0.07676605495714373, 0.07537027340262167, 0.047220338150979056, 0.024237980044657187, 0.03832226904529718, 0.08476619623721608, 0.029364983258288235, 0.036486772174436244, 0.05412370582381564, 0.1400984976921351, 0.16656349533267562, 15.326390804782992, 58.56397159637944, 73.36277223402455, 53.29812295975224, 26.747477669869703, 29.157297572781964, 55.214122341525176, 84.08030356130293, 53.309489988511615, 5.210705995559692, 0.7143056512840333, 0.15603617554710758, 1.5439163605051658, 1.7818298070661485, 1.8471719588964217, 0.1977283964234014, 0.5305032624352364, 0.5237350288418032, 0.24004690949955296, 0.09298926910325404, 0.14515738994363817, 0.10768039167047509, 0.40774613017997435, 0.7620144815694901, 0.750024960406365, 0.3771513670442566, 0.4997104502493336, 0.10851673751829133, 0.10982735307827113, 0.937994622415112, 1.558609314022526, 2.758361961572401, 0.9386328655865885, 1.7593355044241876, 2.3214346843381084, 0.7243585021745774, 0.267487688651008, 0.7047611150530078, 0.2708196808253565, 0.1793391146366635, 0.2465621808603887, 0.7143913305574848, 10.414812603304464, 30.345885561358546, 48.77721871099165, 62.93089535928542, 73.9786078852992, 83.52759453558153, 77.49072951655235, 67.62936530574676, 52.91953971309047, 31.707204926398497, 6.4531187088258815, 0.6650684449461199, 0.8179153045338969, 0.7355525789241637, 0.07995661963979084, 0.2853323891758919, 0.1361491459031259, 0.3409542029182757, 0.4205247219051085, 0.6250374091248359, 0.57373090737289, 1.300293904158377, 4.239340828311059, 1.442269118082139, 3.117170088714169, 1.4070528529344069, 0.555643571480628, 0.8190868674747406, 1.1603083125045224, 0.9377432842889141, 0.35806250908682424, 16.76907777786255, 52.02581982458792, 54.71455750926849, 26.864081890352313, 19.14483581819842, 45.51484615572038, 64.16249213680145, 40.025406729790475, 7.365118803516512, 0.05034357136596115, 0.16611694268161253, 0.13052400742327014, 0.051906386901053696, 0.08078266926590474, 0.0460234483433587, 0.03086775856753511, 0.08669899010490026, 0.017776597223635164, 0.010482921159916348, 0.036167639097379106, 0.07108616417333966, 0.07999825651847547, 0.05430332279854244, 0.06076187300946444, 0.009969542659218273, 0.014261126991421466, 0.13988077550405456, 0.12344133304131609, 0.10634578989758607, 0.07480198938039041, 0.08440764410601509, 0.03556144904465445, 0.015423033393979555, 0.025449789414602905, 0.15412081784058004, 0.08388424517526742, 0.12057300026137983, 0.16246694740989517, 0.24401896813463783, 0.07477952002157127, 0.09082080360742346, 0.025890732386840448, 0.19836522999309725, 0.14279045404926424, 0.0584530295623887, 0.03794769801559948, 0.0638756871734175, 0.09291253773675812, 0.2886306121945381, 0.06279400166785044, 0.16525760653518862, 0.05679264889969941, 0.2989248420682646, 0.2935407148493875, 0.13062502377696578, 0.13400567785626458, 0.18789798682255132, 0.20004313108661484, 0.21871434855124644, 0.16616160560759807, 0.15587184968734943, 0.10111666524842863, 0.27748804719698045, 0.14851317680891485, 0.30996827528842036, 0.15200359596600457, 0.18802166405704715, 0.25839214123064475, 0.1279824417865565, 0.21372193740981243, 0.12742174969565484, 0.2697955744881784, 0.09784668789155061, 0.1448032428180018, 0.15494937257420632, 0.17650089677303069, 0.13913944754148685, 0.13930303795683768, 0.17717427273671474, 0.17349436939243348, 0.22242389949819735, 0.14531445328987416, 0.15755967928036568, 0.26582604394324366, 0.1811351618098636, 0.1832592631539991, 0.16115929661018236, 0.14010477961311418, 0.23316155638425584, 0.17370009464361977, 0.14321865123366156, 0.14895867225864243, 0.22558048818140264, 0.19204247652763323, 0.12412079940399817, 0.2620904460068672, 0.18572379864992636, 0.27025455308537333, 0.1527907206646858, 0.15250838662107147, 0.16360409768118014, 0.4175946500993544, 0.14867822279132184, 14.600106112418638, 66.44019680638468, 90.98792691384593, 74.8235962467809, 64.83159749738633, 51.484371923631244, 44.4672477629877, 73.34578052643808, 57.9500892854506, 20.67239699825164, 0.6168014736425492, 1.3570118671463383, 4.441234536709325, 9.502521272628538, 17.893707598409346, 1.171913992974066, 2.105188533183067, 0.8435421100547238, 0.4132474994947834, 0.15775005212954937, 0.15936328008049921, 0.18195294534727452, 0.4012227995741752, 0.539230045772368, 0.5860885184618735, 0.34469804396071746, 0.3776766275686603, 0.2420504439261652, 0.190125172957778, 0.7167845279459031, 1.2768155768994363, 1.2395622533175255, 0.6449822937288593, 1.1716678642457532, 1.6830509204056956, 0.30534337184602217, 0.17179161640665225, 0.4366209339951316, 0.45173517458381196, 0.21081365314462494, 0.2348948456346989, 0.39508686430992623, 5.843144059181214, 20.45995358497866, 36.164939403533936, 50.275556272076024, 64.4902846121019, 67.20645535376765, 64.02537392031762, 53.92880085975894, 37.000616058226555, 18.751074960154874, 3.2408821342452883, 0.5334675324059303, 0.3740569847005029, 0.36750831190616856, 0.25252715594345526, 0.26907223427007276, 0.23008917608568746, 0.35187647167232733, 0.6356278085900892, 0.6323428848578084, 0.7942876207732386, 2.941421674143884, 5.864670026686884, 4.644072065430303, 6.466066943060968, 13.257917127301617, 6.204812084474872, 11.49172188774232, 4.254294864593014, 1.0119727301982142, 4.687994766619898, 31.357329507027906, 55.143131363776426, 51.05029890614172, 36.87597490126087, 45.895390587468306, 69.17479484311997, 71.81324774219145, 43.69474872466057, 6.347394652905003, 0.1713275816291571, 0.23514436047163703, 0.3982093774022595, 0.2490155774378969, 0.10960349452591713, 0.12107382258099895, 0.15325665534023317, 0.16358430196921672, 0.09537162634754374, 0.1741668260506084, 0.1486536620124694, 0.21968021688442077, 0.31410233087597356, 0.18050575929303325, 0.34027642960990634, 0.19699961698103338, 0.15151968886775358, 0.21575818379079142, 0.22790034031195028, 0.16548252994975737, 0.22168560524380979, 0.2100314620521761, 0.06756196819966839, 0.12655533489681062, 0.1884132115951469, 0.17208299028777307, 0.21692605418784006, 0.1773602175976961, 0.2820169751442248, 0.26848035473977366, 0.13257450303964077, 0.2872009695537629, 0.17703780183388343, 0.23777164368619844, 0.16210913838398072, 0.1201788250416998, 0.17562565664129873, 0.17473523264690755, 0.1973942901578642, 0.536519197687026, 0.17843721464516657, 0.11549760647598775, 0.16423012941114365], [0.05085967330923004, 0.06222642627694915, 0.018149988477929466, 0.06865186616778374, 0.04137457784024939, 0.1284114050588781, 0.047423071828821016, 0.11235483035805727, 0.02281512111245144, 0.08354540448635818, 0.04094012937838993, 0.04395420655548092, 0.05032876671682443, 0.01865596273883937, 0.021750678330840125, 0.062059886423089815, 0.04496626616004975, 0.04907800943680829, 0.06447571404879132, 0.09366004802887479, 0.03844359055942586, 0.020330479638951442, 0.01132963600778772, 0.025849581973987724, 0.013148334485688999, 0.03168231112912538, 0.01418723685351471, 0.05388383986428381, 0.037235293702612964, 0.013704163833491266, 0.0501592391200604, 0.03816659231820414, 0.0405561201454651, 0.00669743653552066, 0.05659351966554119, 0.03083848251750873, 0.07843395094237021, 0.06691787977732959, 0.0812493317249802, 0.014396129878267888, 0.040488095368228616, 0.05230091835161852, 0.057752411512117234, 0.07610779390820573, 0.03030178621561537, 0.05116624254432898, 0.07255991049591573, 0.03239492803151089, 0.013876609267636895, 0.014789489214308562, 0.05820425016985786, 0.1353780937290961, 0.5820030022052027, 20.745559007890765, 36.476112796414284, 54.734330177307136, 51.97166365961875, 40.48029968815465, 35.17252875912574, 33.18144736751434, 49.80446784727035, 46.98446804477323, 16.11022843468574, 1.0915977027147048, 0.6139245989822573, 0.7667189355819457, 0.19881126170437183, 0.635125438772863, 0.43441604101850145, 0.27082875130638, 0.022454232413081393, 0.23590436565779874, 0.07076428467107397, 0.35214282512184114, 0.01632985166995035, 0.33032347658468836, 0.481842031642314, 1.7113489825879376, 0.5900692951775367, 0.21345835719858447, 0.936527472109564, 1.5764151585678903, 1.763951521246664, 2.0669640552613044, 4.549783189450541, 6.082633195384857, 1.9457845125467548, 0.8282654588260959, 0.30955513939261436, 0.02305256431892274, 0.1286648499268678, 0.13124003916257812, 0.04319641153298078, 0.12129716019356444, 0.23794592868897224, 0.21573956785423143, 0.7024187859027617, 1.0694979659972652, 1.5341682900344173, 1.4242107709569316, 0.39509342202255804, 0.04022679426857541, 0.2919804388957639, 0.08600605591650932, 0.37355112152234204, 1.4225152038758802, 0.6929974366099604, 0.2904870883832055, 0.3249500439532342, 0.043934491282749566, 0.10983346645990688, 0.25702047612397905, 0.7899464762979939, 0.11043249359053951, 0.6366255002156381, 1.7378429996390499, 2.5904254374965547, 3.677915070326098, 0.5914518080892102, 0.1471589172198888, 0.4395251733160788, 3.689886634388278, 24.056421864417292, 45.662484169006355, 41.7971021129239, 28.427291531716627, 36.43450821599653, 56.762446588085545, 57.36671909209221, 36.59363877388739, 11.168797073825713, 0.2786995386404376, 0.059491814144196055, 0.08447898221352408, 0.07729640996624386, 0.02562092388078811, 0.05001478175061846, 0.05081693326393443, 0.015526793300054006, 0.030875271974852493, 0.04209981795640723, 0.0503710356180466, 0.033754534914248416, 0.010889841209826692, 0.04335624811750266, 0.09216503510552068, 0.09544908549756774, 0.03251785833028055, 0.04301517045185451, 0.04218666934438291, 0.04519226975859173, 0.07557128721307363, 0.013721158536481521, 0.02725299567945542, 0.05062555683956993, 0.044848346076304876, 0.07894242648035288, 0.07336205051791284, 0.039537276832326766, 0.06979760428469989, 0.0513919856729767, 0.019708760984001622, 0.051072075016676426, 0.04446690706836601, 0.08586858909937643, 0.019300777029486436, 0.07404978296929791, 0.02181198834742029, 0.08487098174349916, 0.03289482721518124, 0.046608946361248536, 0.030174157882650054, 0.06314788832359257, 0.12291879978992286, 0.030260116778193947, 0.04728247937295706, 0.02174441173161951, 0.04810461812021752, 0.07148895788216783, 0.0293495312648555, 0.05440177658813135, 0.009527222643936835, 0.04828338856778799, 0.06530286684151619, 0.034169520912391525, 0.10434540409234264, 0.05070759719538112, 0.04871183856120033, 0.023890976688914725, 0.04296955757684285, 0.04131758855956216, 0.034698443337073254, 0.04980203913404577, 0.09425607975572349, 0.05019343345456066, 0.024230796055147247, 0.11744841107077177, 0.02308848426647244, 0.015484950535239713, 0.025939206600249298, 0.037878619867467114, 0.020464380316796805, 0.029365412267525832, 0.02906987086809691, 0.028324967190142603, 0.05959575695376243, 0.01480192760936916, 0.04646689450788883, 0.05815996645739483, 0.07541663704379913, 0.04742698270767447, 0.049162784726509166, 0.0845321946807446, 0.07388009449406978, 0.08890484069143573, 0.00899176070121147, 0.07351213480315863, 0.04218520994688715, 0.04028521613368104, 0.04405177168307766, 0.011840587924985636, 0.04702171453485086, 0.15397714571126048, 0.048869920804375605, 0.03669734293174359, 0.021066760997317975, 0.09780593201397889, 0.15059604730096557, 1.923383856492658, 33.826865534628595, 53.63230105369322, 61.15281435751147, 48.230354016827, 30.73729495848379, 37.83955612490254, 52.5836318539035, 73.88013285975303, 47.37107646080756, 8.055959978411275, 0.9204554990414651, 0.303469674000817, 0.9404548065316294, 0.778690315783024, 1.6979103295072433, 0.5427692494084758, 0.3241140888102593, 0.4902732582582582, 0.7081767640286877, 0.3685499463350542, 0.21216403632875414, 0.4034503381098471, 1.0372039892019764, 1.3135046920468731, 2.434753674653269, 1.7324616303367002, 1.598264231316505, 4.499699915609052, 3.6201937160184308, 4.281246940935812, 4.459130840916788, 3.394300005128307, 4.878604796624953, 6.046439034323539, 3.1337970158746167, 0.5670281283317075, 0.5352749483239266, 0.8996997256913494, 0.7332481864479281, 0.5092970600291606, 0.11495168456026625, 0.40982578310274315, 1.205458715558052, 2.333245921519495, 5.458701281778274, 5.609449244314625, 4.453864568664182, 2.2941690635296608, 0.10776093815483394, 0.215055926312362, 0.5105855892742834, 0.9648238795418894, 3.6398146373610345, 3.0576150263509447, 1.5281503935975413, 0.6940415838072378, 0.1599056396873728, 0.42387988057828724, 0.8076890113372958, 1.4518235215256292, 1.5282227122975935, 1.6378632548355287, 1.997039471903155, 1.2238051117427888, 5.386517903497142, 0.3426593614201392, 0.17544380268983303, 0.2786396918517928, 0.49253747708374457, 19.161364686104562, 55.97961994909472, 66.8766232459776, 36.39573950921336, 28.772648380648707, 44.84018279660133, 62.89713159684212, 50.452106075902144, 17.190369752145585, 0.8951320030516194, 0.19602043403973504, 0.17727253117388297, 0.014335599356150676, 0.1631482140791993, 0.031754899875170765, 0.0968010391619417, 0.06495343115661414, 0.0323982949879381, 0.03019217244018951, 0.01857189033480902, 0.05724066477869788, 0.06325956862119418, 0.03770106366925663, 0.057407185480359106, 0.06761187116705603, 0.08766010869294406, 0.07659464278408597, 0.020973326998852918, 0.007649272053141989, 0.07609481637876842, 0.06515774680601974, 0.029787603322596803, 0.06097610183661023, 0.10221613165471824, 0.02122560932841753, 0.08325730946155326, 0.05176163075732128, 0.02260392407826599, 0.04111747873286086, 0.0334585645055819, 0.06801771390582285, 0.04169869431925397, 0.041395760171355746, 0.01721314913142593, 0.08580642106432108, 0.029613804785654913, 0.03121117471657213, 0.08411355061276306, 0.07390894536529818, 0.10523978876130236, 0.06078556044808319, 0.12162730578453311, 0.039462717325096174, 0.01936437190330077, 0.1797693496149394, 0.16273123242201346, 0.12241385591727112, 0.19631427472397206, 0.1061615227691589, 0.19004234353140478, 0.11089705696870243, 0.21040339773941427, 0.09385875591467466, 0.1418668584477517, 0.1327576286970608, 0.14220531609269882, 0.12670345033609098, 0.16179410770775812, 0.07796201779837571, 0.14529307943678674, 0.11744744579998717, 0.2933044226900224, 0.13152511580096138, 0.22109047750071173, 0.17472009474952377, 0.12204994117060017, 0.11316237129992056, 0.07130816879291689, 0.15952838734994013, 0.11715303054980694, 0.16785507360773702, 0.19589609796962432, 0.21117268791121824, 0.1191695961320112, 0.16223872981725201, 0.12456849352606844, 0.210108224062189, 0.09839952758122837, 0.15623224809044794, 0.12949754153528523, 0.2238293797258408, 0.21142640090998144, 0.22750836376461292, 0.15258142544377237, 0.1585865741775882, 0.15008878984278248, 0.14139833439502025, 0.11969833469559109, 0.15760201329906143, 0.1180002625070272, 0.26385306110305173, 0.1178548283754818, 0.2987492547160195, 0.0965498848968456, 0.2397925989522088, 0.3166432606597101, 1.111290452461089, 34.19850618608537, 64.71138469634518, 80.04669497090002, 68.62804782006049, 60.72461705054007, 54.422003607596125, 42.22786464998799, 64.47878422275667, 58.88824570563532, 22.68703418393289, 1.3060567239599845, 0.6618524691270244, 2.711509495012222, 0.659867259523561, 1.2183234768529092, 2.625562764944569, 1.4388784742163074, 0.8359692389926604, 1.3711472312288902, 0.3486874621481665, 0.38999921311774566, 0.3723346351856186, 1.0265154079083474, 1.9569929304622837, 3.715052071117586, 1.9806773047293387, 1.1262795449264589, 1.5315820997761143, 5.139002617328398, 4.432740153804902, 5.415589040325535, 11.209916260934646, 13.547845982736158, 8.47786384244119, 2.795877225937382, 0.3510810885458224, 0.2140772489890937, 0.8006019625932941, 0.5031399807382015, 0.20670138509763827, 0.41100681489033086, 0.3080526264684816, 0.6329915468250552, 1.1266328033901032, 2.5951283593331618, 3.380651627817462, 1.6716178242237338, 0.8899892854594416, 0.16568200392348154, 0.2922126861108888, 0.3426543358833559, 0.576518302963626, 2.076228448460179, 2.69138430395434, 0.7029373967839826, 0.4468063793836102, 0.20177753882542734, 0.47331626977651353, 0.4872632988037602, 1.608835876949372, 1.7942496244945836, 3.012871814350928, 6.337793181019445, 4.593022907933881, 11.554858319221005, 4.108451825957145, 1.8431735928020172, 0.7158709221309232, 5.527128990619413, 32.4408430822434, 60.60654194124284, 57.843310602249645, 44.65862412606516, 50.2963448339893, 69.840193563892, 76.97139986099737, 59.18573787135463, 17.71047995936486, 0.6782788038253785, 0.35331656375238973, 0.3279108512065103, 0.1668435311125171, 0.28325114279024066, 0.10844654854266875, 0.1609155427544348, 0.2484649287596826, 0.12284906280617561, 0.16149202391745585, 0.16366305580783277, 0.23363757277688674, 0.17392347056058147, 0.2082133362249982, 0.12508017131157462, 0.17042336805212885, 0.1433595960899707, 0.17722871094461412, 0.14388156243629996, 0.15866416356255933, 0.16932945578329026, 0.2423339730669414, 0.22697821559925235, 0.25561185493584604, 0.23040742433119207, 0.16488954725284732, 0.3103166614328661, 0.22126221909157692, 0.1937888352380645, 0.09817541621985937, 0.13271613737508176, 0.12374402970195779, 0.14902771210237858, 0.25199408132222395, 0.12733169606015568, 0.1569048579662077, 0.1536190762154518, 0.1500363741070032, 0.2021597400908509, 0.16004542009003703, 0.15085377460045202, 0.1759933482014364, 0.18225541218153893, 0.12415817683382381, 0.1868002900793668], [0.01568562822461489, 0.010465219740815943, 0.02645995295155914, 0.01982915361652211, 0.015275138204977399, 0.0450587329725104, 0.021236166020014116, 0.018287809610727335, 0.017931500201924674, 0.04575847768254819, 0.0171738775492075, 0.036872662153215184, 0.031625279713602315, 0.06363077269446465, 0.062040496737726276, 0.05997530372452833, 0.052683521813202294, 0.032863440592923475, 0.07092851093940197, 0.01007915739225404, 0.0390167392399763, 0.06266576237976551, 0.03078944331425573, 0.01945754543187157, 0.0408229677216901, 0.016645807397341537, 0.015861495198952337, 0.0064446150715793335, 0.013345529347838414, 0.11615973626894337, 0.038152354574131395, 0.03084475103194916, 0.05750023068920259, 0.010284555140852688, 0.10935438571557884, 0.02912541607304687, 0.039432602408792705, 0.07707082771606023, 0.053791763756664536, 0.03321992811716853, 0.039994604510044864, 0.06219152331111893, 0.026825497550289, 0.010050558372430745, 0.07876446425554254, 0.0790188667334376, 0.014415715873662024, 0.012319250193785035, 0.07916001843348627, 0.056744167025411324, 0.08358498058852651, 0.057436603256651474, 0.08345044788814361, 0.29219273718134053, 1.8985318416549315, 30.03053092187451, 65.67091018922868, 58.996773765933135, 51.49651165931456, 47.67397757499449, 40.83950250379501, 33.575790697528475, 54.731302107534106, 53.03291190055109, 31.790333678645474, 7.246158219152882, 1.247366911941959, 0.2760201308035082, 0.3411546115192675, 0.8667964944916388, 0.7016770902179903, 0.8203180626996103, 1.1802960980323054, 1.143269904198185, 2.7232567485301726, 0.9133709630658551, 1.6308531213191249, 3.564517387459355, 2.212854652635513, 2.5762784288775538, 13.106046876599713, 4.462216765649857, 3.163330747235206, 5.193744196045784, 2.215735878675215, 3.719377219676972, 3.9288460054705223, 2.326586227263174, 1.703749635527211, 0.6635962078167547, 1.1382514767108427, 1.2520248490956523, 1.0295877269198819, 0.7366767669877698, 0.1143840287301329, 0.1149201600421821, 0.07185302584642364, 0.12447983417059146, 0.03514809864422968, 0.046463983373776566, 0.12250885848076114, 0.1868310561704059, 0.168837841840521, 0.8093916264272506, 0.7949224318708143, 3.6549902875577254, 1.5723241264781647, 3.977195836843983, 0.34088687911148996, 1.5266893107083537, 0.29886821284890175, 1.7438501095579517, 3.6092583931261495, 2.04072977266004, 1.2792118999265856, 1.7580001825286498, 0.3375782679405905, 0.03695058861687299, 0.6980902665565092, 6.399625914712106, 29.60635796669991, 50.10869080020536, 41.50437954933413, 35.64093036036338, 23.862129219116706, 39.086877684439386, 56.54836362408054, 49.45400407237392, 19.479568927518784, 2.2145927529181204, 0.11768506329146125, 0.05501219927663765, 0.08341136208224682, 0.09035209569359019, 0.08259713319280455, 0.030215222110611298, 0.1022083558622868, 0.006064049403874144, 0.02399953517822489, 0.020611775633428368, 0.03401977370583242, 0.02332318679339463, 0.06643267799048655, 0.12506812074852566, 0.023913156849542455, 0.09885649136718243, 0.08534153592922995, 0.06200694208664279, 0.0349541864688358, 0.033213079291125464, 0.028642443602063486, 0.01232265832743818, 0.07389890195261087, 0.06153597804387251, 0.041738366182412834, 0.03617485947606545, 0.05228699853403434, 0.04259222863061775, 0.010093719766084707, 0.08262717916119484, 0.02571482710810679, 0.10491114470266527, 0.028163336044658097, 0.08464476364033838, 0.09811026044189931, 0.06349974101589573, 0.05653452323449235, 0.05582805610291901, 0.027149012650273023, 0.05300159768892392, 0.11863505828284449, 0.032667513606288744, 0.08935888568239828, 0.030674545447372144, 0.027338575361476793, 0.057238144349427, 0.0033112826631329357, 0.020760415842936888, 0.028895936350548462, 0.03165812956379547, 0.03224195559479056, 0.04668586924972554, 0.02720507687979168, 0.016007383237592876, 0.02579085175849257, 0.031041277482384638, 0.10193265614009674, 0.0536098140442083, 0.007916418882462407, 0.03711381131002019, 0.09900677483528854, 0.05075978310478311, 0.06120801197304841, 0.03720989788792307, 0.04020792169256076, 0.06394656179773231, 0.02248857996516651, 0.018134111305698752, 0.11808758886951594, 0.006163806021739279, 0.03577859666679175, 0.045464031788850987, 0.020469580138582858, 0.014108804771826874, 0.007443145084600415, 0.04698934732005001, 0.04341174352673754, 0.039801676757633686, 0.07777823330534082, 0.01767868927169231, 0.052732949806076866, 0.07754983951247509, 0.08593470248724185, 0.041428226977586746, 0.03852897871946616, 0.02585134589143338, 0.04398004287072728, 0.04581517968026381, 0.036860657555441705, 0.049709545508507764, 0.08065608855817588, 0.025294968790765253, 0.02072079569071291, 0.1362830887158071, 0.014290460498042166, 0.056887429297691396, 0.029993219406253872, 0.07425523242883145, 0.1201736156438147, 0.23298284339327968, 5.938825376572148, 41.07844937232233, 77.24561275974398, 60.37382771891933, 41.25440297588226, 25.075031980391472, 41.36418227226504, 57.917494389318655, 74.36477307350405, 52.94761211641374, 16.0170417447244, 0.6912327377546219, 1.028970198765878, 0.569600896729577, 0.06631600279961863, 0.5004443624807943, 0.7245938443849165, 1.5557907233315131, 0.7251200548583462, 0.20914926584209168, 0.4296051314280879, 1.4495147163829496, 3.079856090968655, 2.7668933618453244, 4.3644345287353765, 2.5043735388786565, 6.317726335217876, 3.1496794281467317, 3.767595406501524, 4.363272036275556, 4.272404937974868, 4.942310462074896, 5.417769878141342, 3.794938494120875, 2.851752614782703, 2.2785563142068925, 1.7027623014103983, 2.8879443243626626, 1.4838511448714042, 1.6186596981940733, 0.8972657724253593, 0.6001291940769842, 0.4255759685991272, 0.601841492518302, 0.10942144905247035, 0.4236541604322772, 0.5040466304748289, 0.4841604894928394, 0.4803392429265284, 2.350304554547033, 2.7900961425996598, 3.223364583907589, 1.4257857251551844, 3.5525497457673474, 4.208983154066147, 1.7968689097512154, 1.4514116726575361, 2.2207565124957793, 0.654156104691567, 1.3871774678268742, 2.1568289879829656, 1.3355064920840727, 0.1824003713385713, 0.07096720604045738, 0.49711666039882174, 2.125123489287592, 19.506625436967422, 59.46895260964671, 64.70068839288527, 43.96087761848204, 24.45379718657463, 34.79737366399458, 59.94479102473105, 65.50056557501516, 31.672642961625133, 3.9870620687161726, 0.08382458224772446, 0.07063146034676222, 0.09368440196398767, 0.00681445790236936, 0.040635310654197974, 0.022903416576164386, 0.05676745609830945, 0.03194210303556775, 0.012226113054390636, 0.04028736501030865, 0.053917823524604884, 0.029311713334473393, 0.03963003858863827, 0.08423577228020276, 0.022712957542089206, 0.05374134751036764, 0.02228478717076923, 0.06164442928087327, 0.045072534046466314, 0.09566445579572071, 0.11269259852387252, 0.04051758209243417, 0.10966159463409456, 0.014033043464165063, 0.07154109016541513, 0.03419773593064278, 0.04092575756893043, 0.04331753769468877, 0.05408928932381734, 0.024315270655337843, 0.010275856212472484, 0.059307608302802815, 0.049699448469665744, 0.09784555408142268, 0.05499550239032796, 0.058775181025867505, 0.028291351252025174, 0.022322302496421243, 0.08064038375572813, 0.02804293575125837, 0.05693180494070534, 0.0178485865058798, 0.09931044442759407, 0.0036093231850123455, 0.10105287310697379, 0.026014087864408092, 0.07863753880824774, 0.10515851449341544, 0.1803221280175832, 0.2464796578691852, 0.18451958504174987, 0.11985527546775919, 0.11600363819349198, 0.194148161118069, 0.18476068823327943, 0.12514053137912867, 0.16013443950683842, 0.1604705682444957, 0.09817834267573011, 0.12320972167916837, 0.17613214801155752, 0.1322674090343137, 0.20278903535537182, 0.10231552390201439, 0.1673202216625214, 0.14911781936403246, 0.12593987518020217, 0.15921157934973318, 0.2268017395850151, 0.1102935022584373, 0.16484747370404584, 0.10900927076656973, 0.11265724356616698, 0.03543044800960249, 0.13964040775693234, 0.1492471196838925, 0.09555551043200879, 0.10215050856312437, 0.15893796338669716, 0.1455883756880799, 0.1836603255041184, 0.19289718550299445, 0.14568415200037343, 0.11853065582052355, 0.17322662166289746, 0.14821066400937496, 0.10310388200225369, 0.2017543723265971, 0.2088122484424422, 0.10684015409600352, 0.22483313876775005, 0.22693960476786862, 0.12351440250753395, 0.29869032723288386, 0.23463083641423335, 0.11595427914853058, 0.14655579151886125, 0.2188336590845739, 0.1427918789728034, 0.3091473661122784, 4.259764119502037, 46.37232334383073, 91.38242321629679, 75.77427679492583, 68.62469811593333, 67.88478220662763, 54.263437871010076, 43.65745090669201, 69.99265609248992, 66.54902688918575, 39.24391369665823, 10.229510030438824, 1.9068639364934739, 0.657382192871263, 0.7323817103620499, 2.4432509993353198, 3.1151770343703613, 3.716627147889907, 4.963940862686404, 3.125093766758519, 7.578932104572174, 4.784281599906183, 11.705181194889931, 11.811639224329303, 9.92466244005388, 10.657823047330304, 32.476501349479925, 14.60241246607996, 13.591702984225366, 16.90427207177685, 9.45425650765819, 13.397923188824809, 11.208108048285208, 11.547331290860331, 6.583983196366218, 2.968759858800519, 3.32079160117334, 4.68125956673776, 3.3530065176948427, 2.1613603061245334, 0.2739485984127368, 0.5601556454935382, 0.22651248010656527, 0.44335598065968485, 0.1331143958433982, 0.3315898812105579, 0.40740990951176614, 0.640704581333745, 0.45798151843970825, 2.814847033831381, 2.6566943718541056, 13.005920533211002, 9.132195595772036, 13.277155372404284, 9.743718601042225, 4.848899216421189, 3.7083352573456305, 9.531726260339061, 11.505649243631671, 7.042685266463988, 6.648680731173485, 5.073147983320299, 0.6667735728044665, 0.19130372262049108, 1.4693082220131353, 8.866560920592278, 37.73551525608186, 59.85729863566738, 56.156126606848936, 51.046600111069225, 38.35117832306893, 51.28686489597444, 74.50692761328914, 72.83655489644697, 35.33735067613664, 3.881689310073853, 0.2562154862549036, 0.0971105540051095, 0.23714674576636285, 0.15335454605519772, 0.15895958238792035, 0.15471983731033342, 0.27247519682972665, 0.08454470489654811, 0.13658151060583132, 0.08810587993432438, 0.10929728152170297, 0.16078110964548203, 0.19378816108069113, 0.2671362381548651, 0.14458521419475157, 0.24368164429981864, 0.18621418685201677, 0.17844510535078664, 0.1143239674368693, 0.1132311583346417, 0.2513095204748454, 0.1910739268867239, 0.13790618387922166, 0.15737629315305143, 0.12053958350612272, 0.10642713311338618, 0.10283053416999118, 0.20075114954623485, 0.2186638173917609, 0.2000179421156645, 0.1352335022942674, 0.22385202528488254, 0.23400331847369674, 0.21406260138798147, 0.20292481677907132, 0.17722610624567156, 0.09978179534476611, 0.15020318209163605, 0.21684330137025928, 0.19523530116965696, 0.1655996188281044, 0.1132841333146057, 0.17172430792162496, 0.09478062781835757, 0.14008084702635967, 0.21286941944591461], [0.05310365592219657, 0.03928269815420912, 0.07928270741455978, 0.06720670258566257, 0.044710480893451365, 0.013226915954522068, 0.03046029172236881, 0.02657836141635574, 0.04299910558808235, 0.02484955378026972, 0.04879258039797987, 0.05796639519112726, 0.03778377818244119, 0.03993141374761059, 0.02395903019444837, 0.025654532158026294, 0.0511211276264681, 0.05426684935246745, 0.028947976703244834, 0.025064498899624716, 0.04975745281685264, 0.08389467929279612, 0.012745104106743971, 0.07755570774597507, 0.0762052939183289, 0.05470417447448258, 0.0377797179164425, 0.0651054613051876, 0.09298893968544661, 0.03703999873851577, 0.01520448191572101, 0.09528279845272342, 0.07201673883584238, 0.07639519179299956, 0.03711263536505642, 0.06866243818113882, 0.02592585751816871, 0.013677306706085803, 0.0016797298890343238, 0.015495448812632071, 0.0434253377569539, 0.06970643216083128, 0.050991317858138395, 0.012319973189263575, 0.01510294174940716, 0.021585532757002982, 0.022861946321603273, 0.012286681880904062, 0.061796198959552476, 0.06869292848052518, 0.04237218902656629, 0.08532098179022152, 0.057505221752029274, 0.11620610757100007, 0.3111161201471283, 0.49794219674602636, 19.517670831372662, 55.857398894525346, 65.11566339000579, 59.45371027915709, 50.39762827657884, 47.29054627879974, 33.00482303865495, 40.66675347666587, 47.46480149607505, 53.153905253256525, 47.62770929644185, 26.36822762027864, 12.256353632096323, 4.042893821193326, 0.7191562748724415, 0.05940948650541325, 0.8725627463671469, 1.8981725770619609, 1.2687932267304391, 3.3613467024218653, 1.873967385580463, 0.8249430887160764, 2.7722650477963113, 1.1721623280356008, 2.570395609063487, 2.4173268291258045, 1.7940875815768398, 1.7955123825419335, 3.4929025077050735, 3.4224287925228, 5.345913037177056, 3.0940847339168673, 1.6392962682631709, 3.4485733509063725, 1.0087144050386645, 3.4094106910690187, 1.8030088899597045, 0.6107004107006135, 3.23745594389977, 0.08891793313406168, 0.306148468967407, 0.7819746879319992, 0.33474904394918875, 0.8948951899524659, 0.408092555139334, 0.20844883165292202, 1.3163675319763923, 7.327979841539937, 8.217926900232992, 7.01872693915521, 4.012416514658159, 1.8006943238358346, 2.5386074954463593, 1.7949235367198146, 0.42735093303265115, 2.244089221762073, 0.7664022654775651, 0.3530258180633668, 0.11281727167266993, 2.4865269997427544, 10.307262193772102, 22.93961717236427, 38.885122729885964, 66.4826996095719, 59.96051972912204, 19.291350072430028, 28.851085978169596, 39.355120735783736, 60.3655436731154, 55.22939605097617, 30.561439414178174, 5.911029990642302, 0.11405084177010483, 0.1599307826930477, 0.09427058946100936, 0.01603317550278359, 0.09359112309832728, 0.06423032459532542, 0.026210937986991582, 0.010772195960124655, 0.019253396406589497, 0.03173122584309069, 0.043577164892227425, 0.03859719884912333, 0.04077220673582727, 0.01810484674699124, 0.02178773783417719, 0.035401432429470366, 0.0381244728041272, 0.03669628956084771, 0.04260724012349402, 0.05832969706745879, 0.031067937342149597, 0.08850062971994763, 0.03542094085846217, 0.06711541554860531, 0.09200371997130495, 0.021052925449405468, 0.04410109625408246, 0.08465421716532401, 0.020405223007283865, 0.05596011433930648, 0.04594273715009613, 0.027582350284642274, 0.0012402038203529835, 0.01583639528572319, 0.00923385693421287, 0.0709020272798596, 0.06902610011879476, 0.03613074430294576, 0.04919503702812138, 0.011753529693270403, 0.04045169470050643, 0.02889233382208453, 0.021394954979299538, 0.037363287842562126, 0.02915186334341284, 0.04978558739587184, 0.03509872810794942, 0.01733734730571028, 0.047694040958078644, 0.03554680527398183, 0.018454885726133664, 0.05294436326010093, 0.06050679637419601, 0.0180885712090399, 0.03707867085693344, 0.005207695733500464, 0.06420194869861007, 0.020904706588255304, 0.07036839341444355, 0.06536433007568121, 0.05834508011297834, 0.04742860298363432, 0.034158868459804405, 0.07877888969115673, 0.02874266896997729, 0.05335631171962427, 0.031040367752974554, 0.029888364952057603, 0.04305030324406201, 0.030826820744081374, 0.04339797692673822, 0.022458715942658247, 0.030480512613130194, 0.08050970447760436, 0.052340157375100164, 0.09708620773087587, 0.08508167890531403, 0.11176232263566026, 0.05489632847809023, 0.03877153747805184, 0.036320538755746624, 0.020532889644645398, 0.015748677260783172, 0.04383734367307156, 0.029074551665314266, 0.024422185886050427, 0.03453364250280204, 0.05406400459187646, 0.01241663529071957, 0.06769327566989007, 0.05609519862299485, 0.05584016029212264, 0.016317052255955436, 0.042365428300634514, 0.02528188209379873, 0.035289821079781944, 0.13256498822762122, 0.09845866956898282, 0.017716574234767787, 0.03399636971974566, 0.03387030229092606, 0.04940123725382071, 0.3225201356314844, 1.5105769494848869, 28.697309455563946, 69.43104328647738, 71.0901274219636, 57.42887296984273, 44.25960140843546, 28.244093310448434, 36.22958006397371, 56.49194817389212, 72.06664854480375, 63.83767281809161, 45.47733652976252, 20.181431962597756, 2.610635449809413, 0.7635323775391426, 0.8172404117161228, 0.47485696452279247, 0.816257551552788, 0.7176947016869822, 0.4076095520248337, 1.4259961848297429, 2.0961903708596386, 1.941717137252131, 3.5004086984742075, 2.1501680679859656, 2.8114034379682233, 1.2486891184122333, 0.8967490614421907, 1.1828575283288956, 2.340251519795387, 2.8408619088511315, 3.1779423115714907, 2.0696148420533826, 1.86622989754523, 1.839517453505147, 1.8731542292141148, 2.9201371775519465, 2.6645616658272284, 4.965131792329974, 2.099964916706085, 1.688894884240243, 0.8328769404080607, 0.8629298955202104, 0.6198810245240889, 0.9104988075071766, 0.534253538616242, 1.1586818771977578, 1.0677366992158275, 2.8591379475209022, 1.7689629620121372, 1.678925812725098, 2.0679966192091666, 1.6802228915114559, 1.8748396226475317, 1.5097341301941103, 0.12355492855872839, 1.0159266631930106, 0.48751871251771534, 0.4683019485204451, 0.3079582444362102, 1.0884648321136352, 3.5924829061954253, 13.907389063988964, 27.416696779189575, 62.664487977181714, 75.42116934253325, 32.99129478393063, 27.381171872538907, 34.956672883802845, 56.083303882229714, 67.07641309307468, 41.5792772077745, 11.300758354125485, 0.38696777255785086, 0.1718687461388688, 0.08411735806974673, 0.03212390910653818, 0.07036784183113806, 0.10863836929802934, 0.06841309954442325, 0.05668550767304917, 0.07936127739207399, 0.04095267789858965, 0.015161844334685275, 0.033515837238801104, 0.021853594582587964, 0.02132792994680424, 0.06324257296059402, 0.03417673363019863, 0.03655627933180621, 0.0722795989244215, 0.029840926872566346, 0.044230139934487885, 0.01893819719102354, 0.07313613884992178, 0.028287605082075444, 0.03236059197074464, 0.048240947296782855, 0.02091999770322394, 0.0520908187383846, 0.0562974994611596, 0.046144685587815704, 0.014874741393742303, 0.04147093254892577, 0.015999996234783005, 0.021507200266745304, 0.042794521807903246, 0.035075772283298355, 0.005712420792288838, 0.03497969336627472, 0.05218787824795131, 0.007670707672068309, 0.02096536159966021, 0.006843292494229372, 0.02299175608993298, 0.04045659000234258, 0.04436574515796477, 0.05659737691823995, 0.07345571242753537, 0.05270402615649566, 0.04475987058192973, 0.16503242265072562, 0.12491828161141566, 0.21003495541311082, 0.14490530105127444, 0.17651103977714816, 0.10452102208810468, 0.16314542551915492, 0.12520358807617618, 0.20831039956500455, 0.10801726351341895, 0.1364267302016097, 0.24669413184446676, 0.16832119214438623, 0.08894610218703748, 0.1411643558211865, 0.26013238655944027, 0.13382719469166574, 0.12514086845781536, 0.17707958426927367, 0.14238444277115408, 0.14726901937636638, 0.21797948637075965, 0.1030823166271852, 0.13641151569543347, 0.1385308060074045, 0.14054589303991488, 0.09856071248049698, 0.15876996030490245, 0.3030947812141911, 0.17799130550795988, 0.18215663280458222, 0.2844495188084341, 0.1756737976064605, 0.14791997960738598, 0.14991072036566275, 0.1522857308267586, 0.22508698966233964, 0.1051452075461707, 0.15514068005065765, 0.11374431466984172, 0.11341243005928495, 0.23775616871012797, 0.15001143028418865, 0.09360235394729723, 0.21918821989768938, 0.1820712446445419, 0.21523486912971546, 0.1521403733040056, 0.3033850366069425, 0.13654852285981178, 0.1566201490500281, 0.18581583645314942, 0.19646304899886732, 0.13393107621419814, 0.4866760770880407, 0.7264629763460929, 26.292504302916992, 80.61515623523344, 88.49382508185603, 73.35305260073754, 67.37285798595798, 69.62934263290899, 50.26896669018654, 53.66914387672178, 62.58738202433433, 66.2041485694147, 57.88926116881832, 34.37412246581047, 15.538957772716401, 6.065302202778478, 0.9874912567677038, 0.39500844754999687, 1.3825203886916562, 2.4073855819240695, 2.4728146387684733, 7.132916450500489, 4.96538576579863, 3.7492725445378214, 9.336003911110664, 7.909807072531793, 11.985094278089463, 10.690658188635304, 12.69763106299985, 10.50511831237424, 17.864935052010324, 16.823577150221794, 17.96758936297509, 12.478607873762808, 10.191564040799296, 9.442381531961503, 8.34775686264038, 13.729289923944782, 7.720101639147728, 10.936675129398223, 6.980481378493771, 4.023129488191297, 2.7559190603994557, 2.4771640569933, 1.5868327285974257, 3.8403159043481274, 2.4504416844537182, 5.898842696220645, 6.927657348494376, 21.75596352546446, 23.905932288016043, 21.116852529587288, 14.247392858228377, 9.89774811652399, 10.053011217424947, 7.719030341794414, 4.997138823232343, 2.8466456888183473, 1.5011968463659289, 0.6909013587620951, 0.29637643526638713, 3.754643249896265, 14.09080203502409, 29.530817039551277, 52.49172679839596, 78.29283852731028, 76.24430225741479, 29.99958146002985, 46.899207484337595, 51.73346204142417, 78.14355311855194, 75.3132257153911, 46.851425170898445, 10.781225715914081, 0.3039131163349075, 0.38858188917079284, 0.31578769366587367, 0.10254871340528612, 0.20977716682659042, 0.15469374435563243, 0.22059668786823752, 0.15349826414979276, 0.142770474476199, 0.12257184622989548, 0.19024013211169552, 0.14623454020869348, 0.07719587624794053, 0.05857607094390739, 0.14758815628386315, 0.0714690319352573, 0.1510562976041148, 0.14436741539787862, 0.10765559340436613, 0.21115042539613865, 0.12120277816129309, 0.1930836972690398, 0.11498653389994176, 0.12207205812897413, 0.20987392373142705, 0.08427311140563219, 0.1491177580769985, 0.10595834092988123, 0.19568283441326312, 0.174574492078635, 0.11841172067027901, 0.18376037658702943, 0.1412108113929149, 0.18834668451980238, 0.23494430427109045, 0.13867276209977367, 0.08062306250776015, 0.13696870676452114, 0.14990915754629722, 0.13925141895249968, 0.08497782036541932, 0.10916893881174827, 0.17136282167367398, 0.1390331145375967, 0.1097737652279677, 0.18359758290311984, 0.2291499522905196, 0.18186338966892612], [0.011064172177875956, 0.05821252008900047, 0.03240902404931765, 0.08261360408317658, 0.0280145924132798, 0.03528075059875846, 0.03449267595105114, 0.03502046073516531, 0.008029788882742006, 0.03389738732948899, 0.02855420367972505, 0.04914155643012735, 0.023017280224350192, 0.01984529891952632, 0.00622766375947263, 0.03352628667808829, 0.031170905304832325, 0.03330755325394773, 0.09230367403717772, 0.01285277010362235, 0.03919838634770244, 0.044144460661036354, 0.05783560099981486, 0.07050091130358559, 0.05788850320142604, 0.012328180863762335, 0.020935436290118004, 0.01669236447571987, 0.014853427870078914, 0.06476947046335667, 0.035886009854655114, 0.011700967443175616, 0.013512053879939262, 0.04430202196442312, 0.04456039660820558, 0.02950230068827589, 0.030510014659094236, 0.08909280036365794, 0.017420862380775715, 0.046972106511314074, 0.043799173342244285, 0.14527812540050478, 0.07545615185893352, 0.04776341788050148, 0.015115044023390981, 0.04755272454912624, 0.006104490706591957, 0.015619042735066146, 0.07003171309348076, 0.06292338625738217, 0.028511961591580225, 0.11575081385672094, 0.03626890826008974, 0.08827214399653097, 0.018704348852136926, 0.10280696164456107, 0.48543366633595963, 2.1515852693588506, 30.532745315182595, 57.318579842967374, 57.803643672697014, 56.030438177047245, 49.7171127411627, 46.094568544818515, 34.941658050783225, 28.184863559661377, 35.17733366258683, 36.18007975239908, 50.99515430388912, 50.52495625711257, 42.34263320122996, 32.216373682022095, 31.638885082737094, 23.148922689499397, 12.602824434157341, 7.938032938588051, 4.407056964212849, 2.267631777832585, 0.16096371436311355, 0.14033906462211765, 0.19744140456520742, 0.8854885495478108, 0.6076709313258049, 0.7665689049228546, 2.6317493232988545, 2.5601197346564266, 0.9526869017750987, 1.5926911561719834, 1.239037758881046, 0.8849651582779423, 0.9079977449390196, 1.5476119686518948, 1.398790502740491, 2.745810131872854, 3.67509096380203, 1.2953841998692484, 1.3212474507670249, 2.1066417713319106, 0.8657403350357087, 1.3688830430469205, 1.2316904241038908, 0.8489690769103266, 1.572717589236075, 1.3147118014674033, 1.237432161165822, 0.9993857217411842, 0.9440381368321757, 0.2243102071506362, 0.08234078485158183, 1.6249164914892567, 4.385133856727231, 12.121803587482823, 18.4772248806492, 28.68114144571366, 37.370475953625096, 51.48113596823908, 34.87404423375284, 56.116318471970104, 104.16862826193534, 47.743423138895345, 25.25562967023542, 37.6104308712867, 50.46453214460804, 53.6495751719321, 28.763277838307044, 9.059515057071563, 0.5117735464967067, 0.1785434403967473, 0.05078512529331831, 0.029201283675408172, 0.026673327590669357, 0.03698009832371627, 0.055556451120684226, 0.022861128522744103, 0.020694911494971286, 0.022124552220526724, 0.025145698473939014, 0.004960139208818756, 0.029196610539070064, 0.09524769630403289, 0.029009560596257932, 0.04964933099765932, 0.049198867467742775, 0.0656663449180703, 0.06542354101134885, 0.046462818920131654, 0.03891675710497845, 0.018576768399666876, 0.027513517284645673, 0.030716011871493636, 0.035841461841858206, 0.017751119054493406, 0.03620853670121681, 0.0028222533094982107, 0.0429429360214741, 0.030353682926825942, 0.03530440356342062, 0.03599895419733178, 0.01019320394393177, 0.099678649266641, 0.010709100958680915, 0.024839724872201204, 0.040069704109262076, 0.058464405968064265, 0.057877797122684226, 0.02396083241629024, 0.029110569289074312, 0.023059348027492245, 0.12795810317320208, 0.03269380957428967, 0.05052018144558515, 0.026564531614102667, 0.0359921551670038, 0.06147892364571172, 0.03500409709710268, 0.028075431285786535, 0.014022310572345893, 0.016055393967807533, 0.05732318393946175, 0.05864370501630249, 0.026082744664182107, 0.005109026481682856, 0.003472343312516328, 0.04240330751805056, 0.017594559411067637, 0.045950562738242655, 0.008282465747587623, 0.05061694218086139, 0.07520903487719836, 0.012795197638502766, 0.016705991264673013, 0.011161545783491626, 0.012310335803176127, 0.043137763671937494, 0.028808391653001312, 0.03823329176333162, 0.061605324322778376, 0.039450153483137976, 0.17082035481449098, 0.08418852763791239, 0.07118668256988449, 0.03769002817270737, 0.031870634693111626, 0.049616396877794504, 0.0433473423453829, 0.11108790479239919, 0.01779287084636669, 0.03931906434797472, 0.010249612913016352, 0.036349742027420195, 0.015460162802839713, 0.066289005861167, 0.052888676328884984, 0.08516382651343461, 0.007598940076516762, 0.05631318511140924, 0.011819908339079591, 0.01162270198561131, 0.04039156062889003, 0.01612996400874709, 0.04186698468402029, 0.05701788641031712, 0.031198708550824277, 0.0655554536910307, 0.03627795958891511, 0.08222686757724132, 0.08990333670930517, 0.061044750975505005, 0.05250207771877608, 0.04640885185630572, 0.016264749518144998, 0.2542456750187182, 0.3719154625169693, 5.3621629265046895, 44.92521585956697, 71.48125048606627, 60.43453424207626, 60.8673874024422, 43.778299131701075, 39.19846127110143, 34.2687479911312, 43.73303890228272, 58.516754104245095, 57.32165498118247, 73.71846845073085, 57.299270014609064, 41.77673324461907, 28.175757777306345, 16.473401669533022, 6.288359059441475, 2.276871411069747, 1.4039283173699535, 2.2926109019787084, 2.130044102668762, 0.6121856406811745, 0.23979233848231457, 0.4792992938910762, 0.7953467832938318, 1.1829195508072454, 0.6819403363812355, 0.6287224759017268, 1.4644828486827113, 1.4720497136154485, 0.8086805742594504, 1.2277452551549481, 0.5891845555555436, 0.9037245677844171, 1.5458770552950523, 1.5089187674945401, 2.663531553360724, 1.2829394999050325, 1.2803444843138418, 1.4240403930025718, 0.7479318856231628, 0.8098934446611713, 0.8610407839859686, 0.6024841483562224, 0.7523390362339636, 0.7821673743667141, 0.47958994764954815, 0.04840821110373063, 0.4756490381494646, 0.7132896348353356, 0.5935248420123131, 0.3028433818009592, 1.1547559523774733, 0.4313461734883247, 0.6029526877307123, 5.510921266771132, 20.14875665787728, 34.58831917855048, 57.23652385896253, 56.318175408148, 72.87277406261813, 109.7179191343246, 71.9996387727799, 34.125844278643214, 22.346819562296716, 46.35226042039933, 65.19937461422336, 46.12120536065871, 16.001723908608962, 1.167754441980393, 0.21880440984762486, 0.056729527085178325, 0.08190987571593254, 0.019062575395970095, 0.06499433259089148, 0.02685043179700452, 0.04908038047893394, 0.021834691363056342, 0.00663332503116239, 0.041769522978293325, 0.043920050525376876, 0.040650686038838285, 0.043048188841391, 0.058067231514160676, 0.06451578810811043, 0.08296335386412759, 0.06880824769576711, 0.03223073623713947, 0.027269140982459632, 0.03896129745689612, 0.031980872830195774, 0.03180032505864098, 0.023578273004762108, 0.1428655459876022, 0.04784767989129309, 0.030314011063667077, 0.04808360815889413, 0.061474878701471516, 0.030823800442439896, 0.03345723151259365, 0.05358760898572303, 0.039674797275614355, 0.05260848350101902, 0.026532583832440358, 0.14379055119089543, 0.012450336456118573, 0.07804035028863339, 0.034030793880623196, 0.019530869622324264, 0.005009139150065641, 0.03601379715086472, 0.036238486908616564, 0.06056322258025889, 0.05411178549571384, 0.034815110867061926, 0.026390374931056174, 0.04264491249717051, 0.06421447806661168, 0.03880562072980308, 0.09082969788822437, 0.17507879243743035, 0.14465059213820966, 0.17368682600077123, 0.09806320732159, 0.10469145366861936, 0.08512098687670885, 0.17282632540070242, 0.06172533199611691, 0.1702058603686671, 0.1305547275490338, 0.2017029525051194, 0.15206077676867286, 0.07319793150189423, 0.07988676774285494, 0.12270695349622159, 0.160059837864772, 0.21223276973732058, 0.15791169668157257, 0.12918174477113833, 0.17553415509962267, 0.17805449243995453, 0.27486857807924675, 0.17776100415616267, 0.21283649298692905, 0.13452114777699595, 0.1266631158068776, 0.1331152385401149, 0.12241698155600218, 0.20794157419473897, 0.06366494021588756, 0.13019414528483345, 0.14364687906157586, 0.1759797271581427, 0.14160775219000157, 0.10356721963973776, 0.1509793210894831, 0.2047872071665141, 0.047340931881579666, 0.22953553966456847, 0.11131167907508151, 0.19139332426411493, 0.11718671543583756, 0.1145095982018017, 0.1744671784822018, 0.1676304413065795, 0.13850762418681575, 0.16503632969913945, 0.19643862611584126, 0.18816887551257688, 0.21773927184122227, 0.14375357978766964, 0.08470710021473708, 0.3792658922893386, 0.15127211989414308, 0.2353480632507032, 0.5814175884569845, 3.735466046679405, 46.397453969524754, 85.85028094630088, 78.31464690546836, 75.17049066482052, 66.41937686551002, 63.33645666799238, 48.48746930399249, 42.898982186471265, 47.10494756698609, 50.703906551484145, 68.07005928408715, 64.69089031219482, 56.11856991244901, 43.92729428506667, 42.27167360244259, 28.98353461296328, 16.35202294395816, 10.38796692125259, 5.815267284070292, 2.692840729028948, 0.4080620035529137, 0.19322140923430844, 0.27420459435351435, 1.5606271283280466, 2.2693443827090727, 2.6180472585462757, 3.9119295583617304, 5.125541533193281, 6.257897932683268, 6.941796022076761, 5.478717136767603, 6.515213260727545, 7.448761386256065, 8.406619871816329, 8.865984332176948, 9.512495859976738, 11.271306257094107, 8.358856189635492, 8.70696948420617, 8.432734031831066, 4.8252728196882435, 5.986873430590476, 5.833322444269735, 4.195115124025653, 3.9425836167027875, 1.7834075804679625, 2.1912573470223338, 1.4512029290199282, 1.1702550755393122, 0.40697342325602814, 0.24599755873843548, 2.263287998014881, 6.257249761012293, 14.007372240866385, 24.16851143683157, 37.47005316518968, 47.38649529795493, 61.1054438929404, 46.389358197489095, 67.50781105410668, 111.26597665971326, 61.63325763517811, 38.538789210780976, 50.97888823478453, 65.88984904750701, 78.56571782019832, 53.72908161532495, 15.690224959004311, 0.8333671753925662, 0.4894586310030953, 0.1748050232568095, 0.2071536527646165, 0.10835067263894504, 0.11532323720354228, 0.18933925867801715, 0.18959188383192788, 0.14435921825708883, 0.06307943453711849, 0.13177032522376508, 0.08122759781056836, 0.18034802178942388, 0.16170387787203636, 0.22509966075660723, 0.10393374674623052, 0.17623987529546986, 0.13882895210577598, 0.1611598635152463, 0.12211920317983437, 0.10726251369041782, 0.1492674516574029, 0.10518938017588471, 0.15816053736113733, 0.19212791065294899, 0.11930520135548808, 0.18152508524156388, 0.23992925371614196, 0.16937581942446772, 0.10445334588087375, 0.15311037851197107, 0.13583374750469962, 0.11812481308175672, 0.22525136148737324, 0.09187060453358198, 0.19506521432870821, 0.059586464307240905, 0.2036835196157617, 0.13237939576708502, 0.12197004586097696, 0.14321368698391224, 0.16915301041256997, 0.31771437415192205, 0.12589289866868528, 0.12525782710121525, 0.16595860762942224, 0.07925703580821715, 0.22365420606107483, 0.18983983584950048, 0.16623885791388252], [0.017135684235742497, 0.05471444771354718, 0.02562442298738226, 0.012661126506094252, 0.03692196374158225, 0.026554725688671874, 0.07467533206386913, 0.027149384202916297, 0.005890776115965339, 0.0340703125261972, 0.08985878103562901, 0.04993371049603147, 0.051139984880724264, 0.08314700812221536, 0.0211790350130609, 0.02168027676581856, 0.05398072700406756, 0.035420622931973594, 0.025372630954089186, 0.014980523771936856, 0.0657365185719344, 0.049824872384628946, 0.015121386273794118, 0.07153417239145887, 0.025028218890750603, 0.044151727004998156, 0.030629206448793415, 0.04164866494735883, 0.04617526398731336, 0.03450658810775607, 0.0276688531026124, 0.038051545064175324, 0.09225782367490953, 0.022849602729923302, 0.0320976571885929, 0.04686586543797486, 0.029906323968222546, 0.06717136294971551, 0.042999343075338876, 0.013013493434916581, 0.031547789920061346, 0.06098748207272542, 0.05954564331219562, 0.06416650181035362, 0.042673326698282076, 0.011029363057816462, 0.020090678796893167, 0.020871096395797307, 0.02945965831919063, 0.03693255490713543, 0.009251667520842485, 0.02637184326416783, 0.04500126488687051, 0.05647346219648758, 0.04479349801136602, 0.006234112304575261, 0.06783933033265414, 0.3729164636423511, 0.14898225244495178, 7.364475534808252, 42.484728905462454, 64.29782567485687, 64.89228833106257, 58.498797493596236, 54.819320094200876, 44.70648096453759, 36.500215761123165, 36.76966298011042, 30.813386978641635, 34.44194416845999, 44.89102455877489, 37.60915217861053, 32.98463459937803, 37.21357722436228, 51.00801575568415, 53.132265537015854, 45.35164417759065, 39.13340091705322, 50.336172580719, 41.078963202814904, 35.81717814168623, 31.932399965101677, 20.224270128434707, 14.516830271290196, 13.80012498747918, 6.409270042373288, 1.9036640178772712, 1.013858716093725, 0.8710463825733432, 0.2637227648688901, 0.027051326863828207, 0.07932188515100749, 0.10592258760645505, 0.10383849137372549, 0.09654180266924443, 0.13382281266873883, 0.06618870196924095, 0.452334561775769, 0.6033661913487219, 1.332651742043034, 2.319817932382707, 3.3222629802842296, 7.305051626697664, 13.186245618327973, 13.966075566507156, 20.577899256060203, 28.63132538334016, 36.31342072640696, 39.053663053820216, 42.54818108774001, 49.00776778498004, 46.082836735633116, 41.36122872752529, 33.100066031179125, 26.81453254915053, 27.28355976843065, 21.59396375379255, 26.97216868400574, 38.35682261374689, 27.439013104284964, 40.325169947839555, 51.75861227896906, 42.47014161079161, 15.114162141276946, 0.6110654975618086, 0.3062630144338454, 0.05505187880067576, 0.18538904887053276, 0.006316439943358062, 0.026601719437167052, 0.07296251268276284, 0.054247628206447254, 0.010473143005172813, 0.04311893323075868, 0.07572066669742908, 0.014955227548677116, 0.09318988454798538, 0.048259191680699594, 0.035221351971549374, 0.025623614764622143, 0.012356742536799322, 0.08117575664073229, 0.08698632670266014, 0.03524425033960612, 0.039115576073527336, 0.03802925956645801, 0.024543513145838535, 0.045509522089794766, 0.07026521669280145, 0.046044906466117794, 0.028720103850167607, 0.04761998323843845, 0.015906932831351316, 0.016308468240763874, 0.03639834264533655, 0.04971715276159587, 0.08548628058164351, 0.1207186948628195, 0.0771211673535647, 0.057362656619760304, 0.046007521375412905, 0.09582126633294168, 0.012959729384390578, 0.07166400131198668, 0.013372604810302297, 0.04054295875492596, 0.020571940976585594, 0.04274964054685928, 0.03570096131654517, 0.08217751619315918, 0.0448782733010669, 0.019330734897765423, 0.024300494734498284, 0.039989904560629404, 0.023263847537999673, 0.0647399454347549, 0.011746904947945188, 0.028893517427927548, 0.05390717490245739, 0.07048662376379775, 0.027190858287917032, 0.04667183834939234, 0.055242818554923426, 0.05363894836796869, 0.05355176373174595, 0.04645000609959807, 0.06809241513931943, 0.021090990443143155, 0.05040949323184548, 0.09482191995747628, 0.04093130404550222, 0.04417418870293806, 0.07408521453579588, 0.039544987507284655, 0.0891498662531376, 0.055082629569956375, 0.056688683107495315, 0.0172857895884062, 0.007240923728057815, 0.012098542178019643, 0.035994250417476704, 0.03549895159179165, 0.043562712643535874, 0.021520859614435225, 0.04229430086730469, 0.013084696519428925, 0.05716215608821762, 0.023554447670316985, 0.0816303302323626, 0.018559416508181922, 0.02105495175196519, 0.06083065621374596, 0.020846834391235344, 0.031780745766516176, 0.04314955376509217, 0.013146476722472619, 0.0624840310023677, 0.07266081193642271, 0.03652437560019955, 0.019558887372935013, 0.00600997221490909, 0.03031099267724541, 0.024516767101182092, 0.030426078235670447, 0.04158238685058971, 0.07799648409408909, 0.0358473492275563, 0.0444011154374288, 0.042777399742795576, 0.030898833008963737, 0.11484767280278668, 0.081378371574946, 0.037030717583313104, 0.3868846673398249, 0.17081391967592702, 15.004794693762257, 58.99859766806326, 75.39332835905014, 73.53284620469617, 66.34264746019917, 51.901029617555686, 35.106087730776885, 26.26143324759699, 28.84950330180507, 38.079487508343114, 47.69184397112939, 60.44150821624264, 59.31098307332685, 65.93694886853619, 72.96865247911023, 72.10619388088104, 69.56122675249654, 64.82110907954555, 54.176812325754476, 48.742207634833555, 37.694804976063395, 30.826122914591146, 18.174457127048125, 11.025218713668085, 4.62280938702245, 1.7022880623417518, 2.4385667087570315, 1.8614265875470255, 0.8026803897753839, 0.8527987810873217, 0.3896167207389109, 0.11375722325136585, 0.1935206431775324, 0.2503245152653225, 0.08427125747285544, 0.14748344738637248, 0.1684333627382594, 0.11537710850637768, 0.6522210891689024, 0.780339488579381, 0.2544397097681799, 0.26951147844233825, 0.8992977440357209, 1.3412900269031527, 2.311885674153605, 4.264818093469066, 10.295770629759758, 20.663669724618238, 31.542029996072095, 42.00856885602398, 55.40816983868999, 53.64746885914957, 79.63348896272721, 71.72009929533928, 62.4930254874691, 52.95124030882313, 51.80951679906538, 26.662215148248983, 35.86253643035889, 59.40219779168407, 25.834506788561423, 40.875627533082046, 59.54841982933783, 57.89119489731328, 25.627509586272705, 1.7208363380162948, 0.33822138343126545, 0.04039900317307442, 0.10861557052140275, 0.025197606676468448, 0.10024961459660724, 0.010282234852052024, 0.02236369614218993, 0.01779811088776877, 0.038914370741094315, 0.0915926295302568, 0.03252230930112062, 0.05371222850836573, 0.059295297269859625, 0.042721946468396534, 0.05792252516614334, 0.050928088791307904, 0.04179061720928839, 0.06468608179279874, 0.09701493091040081, 0.026802085903322986, 0.015015520583537799, 0.049977584351455016, 0.04184091854239664, 0.032231123111541235, 0.04923478166963305, 0.04374801399066083, 0.02019447796497374, 0.03979279779859128, 0.030943505511048342, 0.06489888569640537, 0.04790384179702209, 0.10511934441784698, 0.028503061565119895, 0.0797250235994016, 0.01869442226785806, 0.046735458121064215, 0.017531876181883198, 0.015024079700871823, 0.05325120828685261, 0.03655043025050433, 0.026678489108059197, 0.041121155954897404, 0.07003952719030843, 0.05548829227806099, 0.04509715228191307, 0.050857317588862874, 0.030301874315726663, 0.03679940116501624, 0.03691893769428134, 0.05997893115084979, 0.03714705952593396, 0.14739094993039487, 0.11794039273574469, 0.1755619181259986, 0.13104761319775737, 0.11202911275529093, 0.13718125019823352, 0.2638989650914746, 0.22004712703487567, 0.09570075304157312, 0.1424002854694282, 0.20925061927447397, 0.09516659823636855, 0.13046238331064103, 0.26050409242030115, 0.2275674904306089, 0.10590633122070182, 0.1326430525871054, 0.2551405882883457, 0.19963024033894464, 0.18869065799780432, 0.17709381818290681, 0.1566657159597643, 0.1020025923067043, 0.13788669460242794, 0.10355082535815817, 0.12404569980478096, 0.21318921518902625, 0.08953672533314075, 0.14990040882220193, 0.1570705474624711, 0.10054801350399371, 0.16792129424791183, 0.18331621413029012, 0.08024047819837447, 0.12567962745144484, 0.09719129201144942, 0.1258434859975692, 0.20721397452777435, 0.17137115671029016, 0.07601238531811584, 0.12098643493147627, 0.15747547089572878, 0.1720793743527705, 0.1532034888382881, 0.18592037681129672, 0.10072376939558214, 0.08053157628784258, 0.09928111092097337, 0.07433994643149838, 0.31755542622939237, 0.18312600982044974, 0.14517818156990314, 0.07914009248657573, 0.15822462827688263, 0.17059756112435173, 0.14156734871287502, 0.2205320913344622, 0.41269162609692545, 0.1600565130431806, 12.875995943623206, 64.66898779715261, 90.48302373578473, 87.96625060419883, 77.97275743176861, 72.96603233583512, 60.420578449003166, 53.92069724298293, 55.12955604061004, 46.437050296414284, 50.59723769464801, 59.10323865952031, 52.109515359324796, 45.323909098102206, 53.64910448751142, 65.20059447134695, 68.14526680977114, 59.70140403316867, 53.18726501157207, 66.07964469540504, 53.108978425302816, 45.64925401441513, 42.256525408837106, 30.33204547820553, 20.0067864694903, 19.38933676288974, 9.60205533812123, 4.040915475737664, 2.1727601847340985, 1.5652182626147426, 0.38427236880506244, 0.14480978520887514, 0.1865769141624051, 0.18812200625336942, 0.16093828024402743, 0.2859907957815355, 0.12963370600294682, 0.24751183877308525, 0.7053149659787455, 0.9736691307156318, 1.8766468547044264, 3.2283236855460755, 5.519099408580411, 9.806288250031011, 16.731856446112356, 17.238660012522054, 26.585287663244433, 37.66243365503127, 47.078502947284335, 52.13528140898674, 56.78618869473858, 61.44928670698597, 61.42204976850941, 54.9188070912515, 48.11063543442757, 38.06206826240786, 41.15751651025588, 32.093246559942926, 38.919616053181315, 49.585336792853575, 40.61133430850121, 57.02342540987077, 76.30425176312848, 67.46431981363605, 27.893794275099232, 1.7470545634146661, 0.49271998987082516, 0.16368133466570609, 0.2929297750515323, 0.17697835341095927, 0.2365233034135834, 0.1623159208365025, 0.1578549908534173, 0.10970585153348024, 0.2623659925114724, 0.15533400999922908, 0.08446476362164944, 0.24718200727816553, 0.1941574461037113, 0.11655948094783292, 0.11774038250047354, 0.21451742778862679, 0.1415038093804352, 0.2793641352365094, 0.3276030677220514, 0.15200189525081267, 0.17077821997865555, 0.12755534010789088, 0.1987576355496722, 0.2469165118471269, 0.12022171830458027, 0.12435529125674118, 0.14322667983510803, 0.22503710201671048, 0.10688045032082066, 0.3346260102285493, 0.21202730495602856, 0.1642881069452532, 0.19932841701853662, 0.14544922347751357, 0.16806245360883976, 0.1433726961934759, 0.22442677508919473, 0.09962128460287087, 0.11707384770195331, 0.16249167672809095, 0.18473153092688133, 0.11627760655697315, 0.15418952060562952, 0.18151246011257174, 0.20496602740979966, 0.11528033627978257, 0.08193335631081174, 0.19356712939277773, 0.07999701545603814, 0.20308828462035428, 0.1410621596920875], [0.058534782635228294, 0.028839785936138326, 0.04166078062788133, 0.03835840924312511, 0.0466970311507823, 0.07472483666553613, 0.016250599874183536, 0.028357060528510523, 0.09434771919322592, 0.025163973501372724, 0.02667680562984559, 0.00897139712657419, 0.03170956087659203, 0.0329336027554687, 0.01966098199538406, 0.03480374978314485, 0.03711021069677607, 0.025694581319487868, 0.046047526486818834, 0.08625350231605192, 0.06049771440185367, 0.05786956167749821, 0.022397486365310127, 0.07335782171257081, 0.053109489681739966, 0.09808261998959127, 0.1534109914134587, 0.09228282878475805, 0.012167876007996742, 0.08381095354355152, 0.020879914067805778, 0.05395545376344554, 0.044014394253252015, 0.019002803300897923, 0.07433824571630648, 0.05817499327202959, 0.04243900721532203, 0.03294126746515113, 0.04409420912364318, 0.0075037919563211266, 0.005237791497605823, 0.0671240416986327, 0.03737502047912248, 0.01926612878789104, 0.06674621479525682, 0.018300461552796826, 0.07889474516794567, 0.03756923525924644, 0.023651091577184778, 0.035183116523248535, 0.017412121317559676, 0.030458744224761764, 0.05640461770517211, 0.11457417941381855, 0.05140868638972602, 0.03718116959076255, 0.16282697809079003, 0.14259211388566803, 0.0824800749579745, 0.23111095351557578, 0.05245417424087083, 7.786842728814772, 30.23625139267214, 41.83610223954724, 61.67612521879135, 67.31651706080284, 62.55581086681735, 51.629723195106756, 50.73712902684366, 46.03024951873287, 56.58322565017208, 57.074616262989665, 40.313438138654156, 35.760170413601784, 40.23013091856434, 40.25073120670934, 20.851757180306222, 26.477061625449892, 25.11674246480388, 34.82489693549372, 30.49506506612224, 28.40422799510341, 54.66049940355363, 61.28386858970889, 28.879683979095955, 38.087685262003255, 50.656186995967744, 39.19059691890594, 36.972571111494496, 37.797014098013605, 35.06611093398064, 27.995242457236014, 27.160618958934663, 32.815619668652936, 36.60597462807932, 37.37066814976354, 36.88382748634585, 41.27241057734336, 38.33575948592156, 41.34699444616995, 48.4321834964137, 60.57132297946561, 54.02510289222964, 49.278819253367764, 61.58897407593266, 52.45651175898891, 33.021908883125555, 29.619286098787864, 24.90061398475401, 27.033381192914902, 39.66863970602713, 21.640320285674065, 24.687515535662254, 33.60689509299494, 36.63252907414591, 40.06396362858434, 44.2201502092423, 43.9662394985076, 54.23432211722098, 51.309959811549035, 40.285538319618475, 23.5995618374117, 2.0608581506436874, 0.17453922139060113, 0.06697987161216236, 0.14073238948420172, 0.02952241241150806, 0.06348400173949138, 0.024472634691084107, 0.09803657044446278, 0.016829080526686965, 0.07301776294386195, 0.03245342267496932, 0.06719857439278595, 0.025138378503822514, 0.038430777738892266, 0.052108664756580714, 0.04179520607595483, 0.06226347045852773, 0.009654014025844876, 0.035252930115788214, 0.04901599844977741, 0.03777322915172385, 0.08127983734612504, 0.01848798838534182, 0.05234196151216185, 0.0799802917566511, 0.021209126946726636, 0.0001573716068495771, 0.08284759797876881, 0.029060348395198107, 0.016341603458708814, 0.013418575831418558, 0.02792642143885455, 0.04705876637730868, 0.050790284895488334, 0.03932567185632164, 0.08232118832247873, 0.03969496070978142, 0.03438456179273706, 0.04656782659191278, 0.007405582836063038, 0.05344071545668187, 0.02562613902433265, 0.050237506492844516, 0.08295244477208584, 0.03450137870987097, 0.017456115831831293, 0.02621580073009095, 0.06407869281247258, 0.01667334059734018, 0.03526829400910966, 0.01912360387523809, 0.046157391156039895, 0.027105215403641907, 0.0687824535153566, 0.09945096793554484, 0.024418355446429025, 0.050589336202509945, 0.03975297654828718, 0.05106487379018819, 0.06074462070940964, 0.04674311900030702, 0.06210121303616513, 0.04641308832252699, 0.062295734251458804, 0.03204041318367085, 0.0842475547124782, 0.033801453969170975, 0.046958539094175064, 0.040576103548969955, 0.01142544870925767, 0.0574494582120209, 0.031588631982524554, 0.01602494580325701, 0.07921637186119634, 0.13966155178364248, 0.04961830060628634, 0.03513969849013994, 0.03213306002679371, 0.05973697760172429, 0.05904501251455757, 0.07633954316617982, 0.03966343619169728, 0.060491643155053745, 0.022824798718154914, 0.02511310909364012, 0.04756518496921466, 0.0850318678684773, 0.05609735133006208, 0.06253712472595996, 0.02897093444311571, 0.10687309587674756, 0.008975079136660263, 0.048708977222803145, 0.05304421516015165, 0.08603573416269596, 0.015223697316081775, 0.06221039205669396, 0.038035047360725945, 0.0386024542122839, 0.005786222351279351, 0.018493517624935316, 0.04000356773875895, 0.056932318219614614, 0.004419933266622285, 0.07465902971284044, 0.016758970075076627, 0.04284089310995994, 0.06174767111998893, 0.022346384470321, 0.10071606255106388, 0.16977780108009616, 0.026968148867449453, 0.12402224219253949, 0.32511809300030436, 0.04677796833998254, 16.905680202668716, 47.25230316961966, 57.84580130730906, 72.74710132229713, 68.00311226998606, 52.658584425526286, 45.65045818205803, 38.13036064947806, 35.958128513828406, 46.78799652284192, 37.94034927122055, 25.105455844633042, 27.167620389692246, 40.95251383319978, 49.27005275603264, 38.24888290897493, 41.54784725558373, 54.38487052917481, 59.196073316758685, 62.454044972696614, 68.08755305505568, 66.40230671052011, 61.25304660489483, 59.9573229974316, 59.218803451907256, 56.58380223858742, 38.35114302173738, 37.83342153795304, 33.10460813583867, 29.60521067342451, 29.801911654010897, 29.194091366183375, 32.73879416527287, 27.72861542240266, 34.093182702218336, 37.448138883036954, 42.15327293642106, 49.159669414643325, 36.02145125789028, 45.93037028466502, 68.04274389820715, 69.99238937131821, 77.0312552298269, 75.6181429278466, 70.41938643301688, 60.5997327066237, 60.24753916648127, 47.635079429995635, 43.102968969652736, 53.07656003582863, 27.153435137964067, 23.919423280223725, 20.06208404417961, 19.18380456586038, 18.004534167628137, 27.12597462438768, 33.74508019416563, 45.76491294368621, 56.4657388964007, 58.339698314666755, 35.91808111436906, 5.662233560316025, 0.12327533710988299, 0.08197385937936845, 0.18904071421392504, 0.09069590063224878, 0.046043477712139014, 0.014240936744177054, 0.027213049939863627, 0.02175946727455143, 0.08932115585212747, 0.02753324021825627, 0.07397502044876737, 0.03810028740835767, 0.006843815349237693, 0.015255683402140296, 0.01015341142192483, 0.07801821800850092, 0.03189356945034477, 0.02587756716586169, 0.0386793234746062, 0.06501847202138555, 0.037603912229139, 0.051897642007398034, 0.061156550016734874, 0.02715048162386783, 0.07279389673062871, 0.04725783815487258, 0.04534647942730977, 0.006873528548185864, 0.030708908321215745, 0.01583469457053129, 0.01559595763307786, 0.04344617534849433, 0.0446766083158793, 0.0262898143996755, 0.03534061270916174, 0.02920180078475706, 0.044797922169128736, 0.04710630979388953, 0.11302710315513034, 0.056633953786184715, 0.04857355586042808, 0.034597764062064315, 0.061451616441650744, 0.0454499127884065, 0.05902007635262224, 0.006204613131440936, 0.07810924457566393, 0.010892723615641796, 0.048377016003453926, 0.01871654497189147, 0.02888410029211833, 0.022002933847327388, 0.04813498967597562, 0.17535478327303164, 0.11219994270152624, 0.15218082274640762, 0.2119046236358343, 0.10511673205802519, 0.2063415689213622, 0.20317909668289846, 0.23328063709120597, 0.15251790143309102, 0.14425656247523524, 0.12907122892718162, 0.22019398608996024, 0.10897354042578129, 0.12350053631610448, 0.1532230853673912, 0.08891830851714458, 0.18438772598822273, 0.0805787213387028, 0.1092876747791325, 0.29609552614631196, 0.26995397082740263, 0.18573090794586367, 0.13086958968591306, 0.16206015472210225, 0.17145038552341924, 0.15236451530889158, 0.18204345097464902, 0.14913367738406505, 0.13609309891058555, 0.2338012857663055, 0.14598896306368614, 0.11433853842918912, 0.25745239649568835, 0.08883291269622504, 0.13913511148383542, 0.14169393708148312, 0.17528320001738687, 0.11559404928477542, 0.10264802904378983, 0.14627632264408374, 0.297766026830481, 0.17597232674879415, 0.17970827708561576, 0.12093252532424466, 0.11919551288648961, 0.11510965955113212, 0.1531238616594384, 0.12206526292908577, 0.20474553198343326, 0.11456419728816518, 0.24146895254811934, 0.11039772852053566, 0.20298118552853986, 0.20218905061483386, 0.09204472865789168, 0.11869258382507872, 0.2304575418031985, 0.17079934868360722, 0.16520182001254252, 0.3147100224610298, 0.06426732281162854, 12.231697613193143, 47.25122844019244, 65.83936029864897, 88.48907901394753, 88.44787059291717, 78.0936291909987, 65.79253896590203, 64.26202227992397, 59.30403263338151, 71.67748666578724, 71.67268568469633, 53.70586118390484, 47.19083178427912, 53.35121224003454, 52.51870093807098, 30.69102079637589, 35.967263713959724, 35.77160804502426, 45.95405355576546, 44.48531420000138, 39.285004446583415, 68.86358614890807, 82.36789872569423, 41.96279871848322, 55.48460114386774, 70.95993611120409, 56.86915074625323, 53.3774293622663, 53.80960003022225, 49.99655415934902, 42.051785530582556, 40.299494112691576, 45.8083688828253, 50.12661995426301, 50.90884647061748, 51.62815424703783, 56.373206261665594, 54.07095147717384, 59.326009673456994, 63.08751952263617, 74.8481502840596, 68.65851679155904, 67.72225487616755, 81.50295334477579, 67.90011867400139, 46.184979177290394, 44.356076025193744, 38.03368206947081, 36.713902565740774, 56.475752707450624, 27.6668498592992, 34.55148027789208, 46.73323239049604, 52.48098734886416, 52.71155211233324, 58.7263459544028, 61.48361529073408, 74.91752132292717, 82.19048207806003, 73.3086121466852, 41.686632479390795, 4.665068022666439, 0.38781773178808154, 0.30077898934964215, 0.3000355469844034, 0.16062758562545623, 0.20750749345508315, 0.17429202013919431, 0.14851401950563156, 0.13630378841152116, 0.2815571691720717, 0.1281134351607292, 0.14042347218961487, 0.19029832415042386, 0.052009548300937306, 0.18245992701380484, 0.1723764326062895, 0.18570870671781803, 0.14726411641365098, 0.08478263648407114, 0.09718780631139394, 0.1279354422924019, 0.21743936374062495, 0.2301430320667644, 0.15510920915872822, 0.11891593675940268, 0.19669574054498828, 0.09598012232492048, 0.16809761704456422, 0.10656625468043551, 0.10203972458839418, 0.07486308489235179, 0.14332938158223707, 0.1801577561925496, 0.11016625505421432, 0.1540957054784221, 0.2031542601123933, 0.19942675206449725, 0.23817868152212715, 0.14868001543706463, 0.09729509692518942, 0.19019381443579353, 0.13209064190666522, 0.21200378605675316, 0.1851596668242447, 0.125906772520994, 0.18445742466757375, 0.18781823706963371, 0.10963288165869252, 0.1587284996264404, 0.1371747690943941, 0.10849855825184815, 0.13817768543958664, 0.12882821051584137, 0.15006488789954495], [0.042864117065384504, 0.021619985646177686, 0.022115575585273967, 0.06790259387344122, 0.03968036673482388, 0.08082411462260831, 0.03622857756131599, 0.06593137303547514, 0.11622385016732639, 0.013449479818284033, 0.07359156279914802, 0.07712785530114367, 0.09437305372088187, 0.01887739470769321, 0.018368792765203024, 0.004905769948832571, 0.0024606483179189626, 0.02841690157149588, 0.03893606252067032, 0.026500750963966695, 0.04346123663708568, 0.01662828122085381, 0.020777116559686202, 0.014494171895597492, 0.14445599048368393, 0.09645258406958274, 0.09635335270075068, 0.047071368523663094, 0.02607326815655876, 0.026839612720293865, 0.060358700087113734, 0.05559403922468905, 0.049650901477904096, 0.023881829599098816, 0.1106373071970959, 0.04384980409315998, 0.04709287644213727, 0.07879768948881857, 0.10771771547414603, 0.07746713266016976, 0.02329931549367405, 0.04798233899618349, 0.03037615611608471, 0.08795948053199439, 0.031548578990623355, 0.01886150412892382, 0.015217490088675293, 0.05978110809660247, 0.06432943722052921, 0.1177090724870082, 0.05626581023417174, 0.0754929087575405, 0.04278649320645679, 0.06750799730540284, 0.07826586359090383, 0.05072954944485138, 0.22184498217557708, 0.0488572841840646, 0.08490913292212833, 0.02961025205290606, 0.12927693885660943, 0.3995330241178313, 0.3905715727277341, 1.1188587882826406, 13.305808286513052, 39.67358189244425, 57.05528682278049, 71.05393963475382, 75.32655392923664, 71.32287302324849, 66.04993666371992, 64.66700700021559, 68.43789915884695, 72.06563657329929, 65.98804950714111, 64.2944642036192, 64.83078948913082, 68.84880665809878, 54.05429317105202, 57.992960791434015, 44.302006152368364, 26.401995305092107, 47.00377395076137, 60.029412238828606, 24.36512416408908, 20.232528678832516, 9.344401705649592, 21.932580009583507, 19.96376395225525, 20.300611219098492, 21.97788534625884, 18.433853272468813, 24.69931402514058, 27.068911983120827, 40.259776192326704, 33.59092320165327, 25.896874435486335, 33.17823494634321, 17.357984396719164, 100.1847396358367, 65.40343200006794, 31.51198071818198, 29.027414168080977, 55.429880157593765, 43.577238436668154, 25.62220850298482, 45.34157545335832, 44.66197775256249, 49.050686359405525, 64.10523337702598, 52.57150780770087, 71.71499236937493, 74.3555711930798, 66.37091205966088, 65.60414360415551, 61.81519677562099, 61.18341668959587, 51.34849317612187, 32.73632895561957, 14.995014263737588, 2.5624162823923173, 0.07009555120021105, 0.2456418487934336, 0.030744987232009732, 0.11425747100504176, 0.062195817233934525, 0.012850832858783825, 0.03561324041877543, 0.024610570737070615, 0.02813375355946201, 0.039474036274177414, 0.05337397004627893, 0.06411714276539222, 0.06970185095504408, 0.05938525131392864, 0.007143072753904328, 0.034328124095355315, 0.03985677763158756, 0.03833142379599233, 0.01218741412289561, 0.043030358144953366, 0.09161715200471302, 0.0602738788321374, 0.06546238932998912, 0.028755709701668353, 0.05752932670856676, 0.0674834518483089, 0.05528680349309599, 0.021968869747774258, 0.02900127344013703, 0.05046940896840346, 0.05007581214510626, 0.05079703413010125, 0.01488184973206972, 0.03603503310812577, 0.011283645834473353, 0.060177830558630734, 0.0329651732388283, 0.022325525811362653, 0.015682288081265025, 0.048839177695974234, 0.039316804388598095, 0.04278837778275052, 0.07691119031439866, 0.07090178979260307, 0.1050872759773366, 0.012512879874256831, 0.05689989354821944, 0.02898585209022126, 0.01525568244453039, 0.0425872452286703, 0.021945381492015817, 0.058061436059013496, 0.045664156937310775, 0.022982658795832146, 0.010481823738964816, 0.030118959332485835, 0.02319683399682324, 0.02780933256050752, 0.05134461462617882, 0.025563250866628466, 0.017793500953684413, 0.018259052585269657, 0.0885294039823836, 0.07475210173476128, 0.004386327862213817, 0.04176809039387492, 0.05371129771153774, 0.0331892462958011, 0.019969665633154013, 0.03659024383992918, 0.03255111803751319, 0.016512862414181713, 0.015666198319635324, 0.052215752357076255, 0.02686739681408771, 0.03979429167004363, 0.048936164427188136, 0.0351186617157392, 0.04245133740046332, 0.10988458750709412, 0.075752689172664, 0.0608065206136915, 0.05084855354300911, 0.035972550977021456, 0.026360930341686455, 0.047656437532315334, 0.001618016838385243, 0.0028318727403999337, 0.0589047379851822, 0.11092208506118868, 0.0744021068056745, 0.010809734268414398, 0.06608016263212889, 0.08911256543210438, 0.06437392394629217, 0.06008742835312601, 0.012221263717829943, 0.03827322409638474, 0.04883874102585739, 0.01945429530385281, 0.051667022729112264, 0.029451553108951742, 0.03277665432242136, 0.021229591070403977, 0.0076564364116488695, 0.04975176078357524, 0.07667343492709822, 0.011512028136020227, 0.043187808365591114, 0.12806732432856677, 0.025197811604988192, 0.047731724823074, 0.10440335864381445, 0.054896834096120256, 0.05810367814715832, 0.12303642492981688, 0.380363175345044, 0.18659720017064005, 3.324126841560487, 24.318520522886708, 58.38866910626812, 73.01893726471933, 79.04227010665402, 78.9152951394358, 74.20707810309626, 70.60606771899809, 65.70778046884845, 56.023201404079316, 50.57924578266759, 48.175931130686116, 43.38421467811831, 28.232341889412176, 33.67900786861297, 22.65579838906565, 35.92895784685689, 23.639271913036225, 16.989265911040768, 55.52740596955823, 71.93825367958316, 25.99379816362935, 33.4088271664035, 34.42304618896977, 49.20395297388877, 48.798666231093875, 55.470139365042414, 54.75928429634341, 49.1675651458002, 50.442245237288944, 59.7875157479317, 71.85931205749512, 66.32335724369173, 56.38134517977315, 61.93248348851358, 37.59343916370023, 93.656872318637, 73.14923055710332, 52.115418526434134, 39.39512498917119, 48.879270938134965, 47.308702930327385, 28.853211902802993, 26.416268810149163, 22.095752569936938, 21.960917172893403, 32.03010620609407, 40.4686894724446, 29.92953577349263, 43.461010763722086, 54.71904862311579, 58.60321098758329, 66.64779217012467, 68.02258291552144, 67.14077918760239, 57.555243892054406, 31.59012217675486, 7.612331576885716, 0.17512511011333237, 0.23763855889199242, 0.031918978671573346, 0.0861583388740978, 0.17779437494614433, 0.08474250879859732, 0.03142090086194296, 0.0422256134240137, 0.07528754356767862, 0.04759233512525116, 0.03592728667201535, 0.021907237974265893, 0.028165785610795985, 0.045205316235942226, 0.0600614924464495, 0.02815867439963885, 0.04605106964346863, 0.051533168016542355, 0.05619464066600608, 0.008519523037267069, 0.023979348761420098, 0.05535832929214644, 0.0684060745181576, 0.047400698230992404, 0.030561905624645374, 0.03163344238043553, 0.06763817096549658, 0.052986264439119454, 0.03984202277816592, 0.035774704940136404, 0.029333295946520184, 0.044661780684104854, 0.07756878486684254, 0.06025724706330127, 0.05448664763882276, 0.03365247285053615, 0.05296596693956564, 0.03590143886545012, 0.07579742104656274, 0.06771564543727907, 0.014225554656267408, 0.025171213032257174, 0.059733760032442317, 0.08172373933297011, 0.014800209657198962, 0.038242722305679516, 0.03869495166826152, 0.026755021291694818, 0.0062014640312671905, 0.04863655510088129, 0.01219582768352402, 0.0022357548286597575, 0.04996852919219002, 0.028378442042477192, 0.009200760978274047, 0.1827271231600354, 0.13446428873125585, 0.09369906488685839, 0.1606346642778766, 0.13855703685793186, 0.20858870398613716, 0.12561648648472565, 0.2790071689073117, 0.19538566890743472, 0.11067326736426163, 0.172752229376666, 0.1699954773029012, 0.18385817537144308, 0.057845387773047534, 0.16576941455564193, 0.08640626790903269, 0.15275261545133206, 0.12196269907778311, 0.11432141636408145, 0.12104769132190174, 0.14025035164048597, 0.13013609114193148, 0.10161772505530428, 0.1022049927362992, 0.2115662272779211, 0.2641856964797743, 0.19376117946399798, 0.16810475698401853, 0.16486074234689438, 0.1411647848304241, 0.23481468219430218, 0.2243671581269272, 0.10990060640559082, 0.16325719774730746, 0.12647006164995894, 0.13607025416868349, 0.12418464517160771, 0.21612258117285468, 0.16070964896390516, 0.16388900578022003, 0.1715307175031593, 0.1223717593858319, 0.11997568150681835, 0.13562547884160472, 0.26070563483142084, 0.13804162822423444, 0.1256191601315814, 0.11516837252964897, 0.12877594799764697, 0.14046628118282364, 0.13532788432653875, 0.16671197849415964, 0.19605726754713446, 0.24680446382732163, 0.18502586190738987, 0.12608750798409024, 0.3410090854571712, 0.14602210402729052, 0.3573487909330476, 0.12668140998650945, 0.18299048886664454, 0.4382756532680604, 0.3968319819579202, 1.9958532000741653, 22.608980978688887, 59.43667150312855, 82.32394464554326, 95.8589066228559, 97.2285198396252, 90.96208633915072, 83.63096467910275, 84.65031808422458, 84.70760037822109, 87.31337208901682, 78.3233545672509, 79.03546871677523, 81.92545537025698, 88.85192963384813, 69.97175770421183, 75.336759936425, 60.490914390933135, 39.938459550180745, 55.30941240249142, 73.74174379533338, 33.90362631890082, 30.66964976249203, 19.588108754927113, 37.8578539817564, 32.71121598059131, 34.92234822242491, 36.899116885277536, 32.27086324845591, 42.90066488327519, 43.55252358221239, 57.703274142357614, 49.26684033486151, 39.18535270998555, 48.13841365998792, 26.645794145522583, 114.15771269029187, 82.9020235615392, 47.957129555363814, 42.74320917744791, 67.47414927328786, 52.52477276709772, 35.175121445809644, 57.620049292041415, 59.78637041584138, 59.98928639196581, 79.68113007084017, 67.68150929481753, 86.9557382214454, 91.38961684319281, 84.97196812783518, 83.87277880022603, 86.41679671502884, 87.05816699612527, 82.68396331417946, 63.6637431575406, 35.99974878372685, 6.797466528031134, 0.1933420067953487, 0.37409982433722866, 0.15279533251398994, 0.21309818862186325, 0.3398781558198314, 0.14500303854865415, 0.12258349076634455, 0.16213654900991148, 0.2428839169442654, 0.11888554605144648, 0.14080982565158798, 0.17671250557947546, 0.16910074789437557, 0.16255426611150467, 0.20992555805752355, 0.09430964462338917, 0.08918042550043714, 0.12618866989449148, 0.11823346733205742, 0.20004356009585245, 0.20074538856504426, 0.18015420154458095, 0.14049559170680662, 0.1871319295417878, 0.10388883101122995, 0.1252681233229176, 0.11227400808204567, 0.1453009701424068, 0.11174921487127581, 0.11726536202214419, 0.08359776659598274, 0.11550521372907585, 0.3072672024849923, 0.14326625593727635, 0.09101645480240546, 0.1970333248497017, 0.10992610947259011, 0.12091380213537525, 0.1719756613695814, 0.21322885257822854, 0.14273926405416382, 0.15370818756280408, 0.1520613743172538, 0.2240826790371249, 0.13470234289284677, 0.10524631583041723, 0.15135401469324866, 0.1837388954816326, 0.10643251871149387, 0.1572275801651901, 0.08216544264747251, 0.07634656053156623, 0.2190386948566283, 0.19325805888060602, 0.14814651180659572], [0.02008546556856844, 0.04819777824224965, 0.07814315928807182, 0.017685233577785474, 0.07055453745828522, 0.06492776721115075, 0.019099066079023386, 0.017675467871970708, 0.010127000540735261, 0.023051043634393045, 0.13015525866179697, 0.0002828280206989392, 0.04504173731191024, 0.016043048460907754, 0.03955138051101277, 0.018427272086902972, 0.03993511395228486, 0.06817154436101837, 0.019415887485769008, 0.07086494096344517, 0.010344870200741195, 0.027837585883154988, 0.01524712236958646, 0.057630783562818845, 0.01700267413510911, 0.047661405612504294, 0.027597647145270344, 0.03142936613350626, 0.021016674168828516, 0.06810546161666994, 0.07138852375529467, 0.05389992388025407, 0.01758765695886987, 0.09425202715060405, 0.06077008547201272, 0.006697995300900432, 0.035749473834350225, 0.04633887355486232, 0.016389535664911234, 0.021965412776015943, 0.0628880427909955, 0.014129085992012295, 0.017642690800130367, 0.0034552978562010874, 0.07300699174764656, 0.010235940158787754, 0.06978505576450018, 0.024841553907120423, 0.04922768769545421, 0.038357240959040584, 0.037114405028161504, 0.05122587482835497, 0.0835884892712197, 0.08645614023290335, 0.04076692455958936, 0.043903518347970905, 0.05514916047574051, 0.05914279980765236, 0.06601915905071844, 0.18387035616943914, 0.10441412984002983, 0.14699918788767632, 0.16016333634334226, 0.06210135859287074, 0.4256873271398006, 0.0804859251084347, 2.432548322023884, 8.952602032692202, 20.6500022257528, 31.431791782379154, 48.06929757518154, 49.05566776952436, 60.34298219988423, 62.269666118006555, 63.31965715654435, 71.23778896947061, 75.11707582781392, 70.32401007990684, 79.96719637224751, 62.187829786731356, 61.39147881538638, 71.46774968793316, 44.926023867822465, 37.0924779676622, 64.89413576741373, 60.56485499105146, 49.404272340959125, 41.11976761971751, 44.49858357829433, 45.28548948226437, 44.73975835307952, 54.27031770829232, 44.15435637197187, 49.43766347823605, 40.13529193016791, 46.83507673202023, 52.36307697911417, 51.94525041887837, 64.87186847194549, 61.21647442540815, 61.46585479859383, 60.52784742847566, 75.1595707862608, 75.39599557076731, 60.73259907384073, 68.34784153969058, 81.93017790394445, 78.09322126450078, 79.43545633746733, 74.87214734477382, 73.3764377717049, 64.78269730844806, 54.20413163400466, 46.308133755960775, 34.894734736411806, 19.546102131566695, 16.28764900469011, 6.237239299281952, 1.1582770150515342, 0.06337140596682025, 0.10742595088818382, 0.1178372543184988, 0.06141424284226472, 0.08525956452133195, 0.0669666872389855, 0.11215267507659812, 0.06561446544383803, 0.10583949004930836, 0.04772894009346924, 0.020313257982413617, 0.017423459418839025, 0.07063195064303375, 0.04718085014892202, 0.021019336324365392, 0.0622336121816789, 0.016975127528571797, 0.04422955387722581, 0.037046560281587225, 0.030978035009015473, 0.026372653402147755, 0.06777074248079332, 0.035988554553759676, 0.01684059099774928, 0.041941685917516874, 0.08661282053517719, 0.029900417430326346, 0.03117235704144884, 0.04935277836217035, 0.04458113843875547, 0.04117080611327002, 0.03811011631642619, 0.04639709623710764, 0.013384009944275023, 0.003934837774478741, 0.04385655715821251, 0.04463273063001614, 0.03864766106069569, 0.027481412454958887, 0.03882328671733699, 0.10241808775331705, 0.07643506666945835, 0.1084001849014913, 0.03433272828378024, 0.02909479745393319, 0.04937772218498492, 0.08484802974928772, 0.059364149422054334, 0.02521402202546597, 0.03255724291046781, 0.006641642830800266, 0.02713857278708489, 0.04145057376233801, 0.029659944346114516, 0.05908268871867369, 0.050810115081408334, 0.01060357426233109, 0.09039577036615341, 0.061680171112980575, 0.041955808748400984, 0.0556531620602454, 0.045418024378558325, 0.04903800432540236, 0.02418317219933435, 0.043511760135691975, 0.021052890975448876, 0.039318627677857876, 0.036534058951562455, 0.0141998169748413, 0.02750843429126807, 0.015362148556197363, 0.03571965386189761, 0.030561905624645374, 0.042077949976608645, 0.05197929165836784, 0.05877239246582312, 0.06249733794961245, 0.06044079406907963, 0.031029330341205485, 0.04589589853440562, 0.09786705050857798, 0.00976409032685502, 0.02958670825577311, 0.010322331894008864, 0.025844441524015802, 0.03939972574552221, 0.013271995440816448, 0.011866438604380575, 0.10305736514349138, 0.04370515137129734, 0.07091991543289154, 0.0419992650859058, 0.028477608293835676, 0.04241157743719317, 0.02036308817144844, 0.03974368007132604, 0.012903082928049469, 0.058999219608883706, 0.045689560412879915, 0.014152216101666133, 0.03517265176220286, 0.09256158519776599, 0.017224803243974046, 0.033525428659613096, 0.08899396736054652, 0.07035397563970859, 0.0290699762051865, 0.014431642841607814, 0.0683372798225572, 0.05027951492417244, 0.01698464042537155, 0.018834652747177792, 0.04653113864121899, 0.06726481035471925, 0.06683409274105104, 0.05198186954423305, 0.2383652545752064, 0.11373826257523992, 0.20025086348816273, 0.056625672375723246, 0.10793764399544847, 0.10598467137183874, 0.25973346925550894, 7.116140963569765, 19.549491059395578, 38.78864811312768, 51.22119657454952, 65.56685755329748, 65.36603612284507, 73.23917050515452, 77.61782999961608, 79.35691479713687, 79.04211321184712, 71.92593743724208, 68.41096032050349, 70.77861278287827, 56.47771781490695, 48.81946263774749, 38.18990222869381, 41.04679584503174, 45.317335205693404, 38.79242143323345, 32.822091579437256, 10.220766086732189, 24.217450849471557, 20.051987863356068, 15.20731156872165, 20.317895143262803, 16.68314060857219, 20.712950383463216, 20.132127769531746, 26.41789463258559, 23.349087122947942, 18.756407422404138, 23.060363415748846, 17.94856390645427, 75.39808227169898, 59.13781827495944, 36.7643089448252, 48.524665140336566, 61.72408011651809, 52.874801158905036, 52.782048871440274, 69.24639378824543, 69.88103328212615, 77.26336540714388, 83.28295630793419, 80.62746463283416, 80.26444142864597, 76.12506220417639, 64.19104306928574, 54.50655421903057, 36.47738756672029, 29.781397658009684, 13.041055164029522, 2.725016421848728, 0.30006352451539814, 0.20099079717070828, 0.0679179462754438, 0.12170042887690569, 0.1184959980028291, 0.016592259766654145, 0.05340842868111307, 0.03289602231234312, 0.051525629711367434, 0.023670364434139866, 0.09607425920905606, 0.07346125124322792, 0.0261715495763647, 0.05611016415059567, 0.07394348826980399, 0.03671192541538227, 0.020582534057358583, 0.021901750869508234, 0.03168067744662685, 0.0703146217030383, 0.06065522590952535, 0.04942063843050311, 0.01737845558372717, 0.05817164546780049, 0.053250342607498176, 0.021950952866445148, 0.038025264417932886, 0.009250295265848118, 0.06803981554243835, 0.03311206293742984, 0.021769455145864237, 0.051635877424550634, 0.01860387067520811, 0.03382312659654887, 0.055054494990937175, 0.021686436112729773, 0.06391321015994876, 0.06517469267090482, 0.05794949146107801, 0.02654807029982969, 0.047729886212055726, 0.04525177946854984, 0.12030632505493781, 0.0291332071872368, 0.011687481422878562, 0.03207220008686906, 0.017884288118371082, 0.040715673277455, 0.04701445968220792, 0.006864092738983492, 0.017257716296420946, 0.07362530897221259, 0.03746068826125514, 0.034777223988766634, 0.03487904090434313, 0.07504269420619934, 0.03662538429301593, 0.12778407864032254, 0.1178465239823826, 0.1546876003304797, 0.11753533140666063, 0.13272228140023448, 0.1629048432674139, 0.16215349487479658, 0.17196328138872502, 0.12452531681065598, 0.14135308924221224, 0.16700768843293193, 0.0635033339682606, 0.1049743086520222, 0.07777493912726641, 0.16142618632124317, 0.11944175652799108, 0.30089607822798914, 0.10165583792953722, 0.1444882887505716, 0.1314045642051966, 0.10543549358243905, 0.18680905412522056, 0.0985329571150003, 0.22209734685959356, 0.10227305964837152, 0.08393758021655583, 0.0647534592257392, 0.16203502703818584, 0.1182746981841422, 0.09343926148909716, 0.2106472741692297, 0.3523336423020209, 0.10598496248524998, 0.18213398724554047, 0.1301471381297996, 0.06467618393681704, 0.1441553622604378, 0.16346882187551068, 0.08393420176880975, 0.1503179114191763, 0.15805146176247828, 0.11621790532503398, 0.154318361272735, 0.15784271812487036, 0.17606765873009161, 0.12130227766089863, 0.14208667971674474, 0.24414682820920022, 0.18037546305887162, 0.2102367276506078, 0.11183838750566207, 0.16382296900114707, 0.18620078031334186, 0.1512009962912529, 0.17015730571602622, 0.1503246070276345, 0.17511395587315484, 0.1596678919609516, 0.09331940703334347, 0.3041999396537581, 0.2331223020390157, 0.22334541134055585, 0.33108208749082785, 0.16786524725537147, 0.5124329030513763, 0.13309722015213582, 4.203233449689804, 13.855034247521433, 33.39324751207906, 48.059358289164884, 67.87956545429846, 71.63557221812587, 83.27235806372859, 87.83108572806083, 89.08907613446637, 94.68427442735242, 96.57632381685319, 86.2522925100019, 98.87910027657786, 76.64113629248835, 74.84145087580528, 89.7753026408534, 55.4182856313644, 49.23155861516153, 82.82740439138105, 75.70775339680334, 64.62974840594877, 56.176887712171, 59.12074027522918, 59.770571108787294, 59.3147446263221, 66.15192613294049, 60.51065960238057, 63.985997246157744, 54.55102212967412, 61.418335283956225, 68.55834730209844, 65.91704676228186, 79.9186138952932, 74.36108604554208, 75.21795918864589, 77.79644689252301, 92.58226840726792, 90.7384406366656, 76.54288876441218, 89.09353979172246, 102.60634822230186, 100.79124789084159, 102.2767436119818, 99.8179195773217, 95.55793531479375, 91.41048385250954, 80.29494962384625, 64.97628588830271, 54.27720931268508, 35.550456969968735, 24.505564628108857, 9.922381581798676, 1.961303492707591, 0.2888555049655899, 0.32812609126971615, 0.22897157637823015, 0.20998109943203389, 0.3290167450904846, 0.15275647653447044, 0.20676083352056243, 0.23488583644070934, 0.21134985340458734, 0.15593419392262736, 0.10624822860042896, 0.151918483597617, 0.19362964216739903, 0.1365752440066107, 0.13745711845976694, 0.2272225210383054, 0.11672059689918834, 0.12979124432369588, 0.08144988588267758, 0.12104844974894678, 0.06418469256811565, 0.1800933281981176, 0.09912608536861597, 0.14319622017923864, 0.24874369283356976, 0.16337163596143647, 0.10170864437015788, 0.13207420165981018, 0.0891791461336036, 0.1621408084587705, 0.16362433772413962, 0.16799249445959447, 0.1408054436286611, 0.09985006143969875, 0.08904701894930295, 0.12706299838159354, 0.19361864114480634, 0.16014730978396632, 0.15382409666574773, 0.10547883883719483, 0.20115066439874713, 0.165894455426643, 0.25283444913164266, 0.17774321559456088, 0.0993483734407252, 0.18407009061305754, 0.16495187616636678, 0.14753008681920268, 0.1662558191005261, 0.1991540400852119, 0.1667125760427406, 0.13541626022948375, 0.13238002395918294, 0.17225689224658475, 0.16844143730498132, 0.17710796016598904, 0.14315659811179485], [0.03539165714755654, 0.029892068987171498, 0.03921453931158589, 0.07748158873930093, 0.02099294842581355, 0.005539814000874157, 0.06062173254547581, 0.05532777004484689, 0.017352063854735707, 0.0713309369260265, 0.032509151741021106, 0.007119932110541531, 0.04990983536587127, 0.04180904162386733, 0.053819814066012064, 0.021886346756570765, 0.046881761762403676, 0.027318500027421023, 0.030327281621735425, 0.06196876026449665, 0.03288984764367342, 0.046319529834774234, 0.04861919171807747, 0.11649591863275537, 0.08339758016048901, 0.01868747385038484, 0.04860359799837874, 0.054882309069075895, 0.10511495473404085, 0.043189677620126356, 0.0771673624553988, 0.04245322963763629, 0.02359728156138332, 0.061769148394946134, 0.010078616342657517, 0.05106015468857462, 0.16165644170776491, 0.036903723188105135, 0.08755405148070666, 0.06303090286711532, 0.024148635040487976, 0.08592787664383651, 0.027983491158773823, 0.06848980026740221, 0.05100319222096474, 0.02257517279846774, 0.0576677319834069, 0.027035618230940837, 0.022448798934478435, 0.01915856429766263, 0.04665955029908688, 0.03262689945498302, 0.07632958402316417, 0.04713642471019299, 0.027926429099733793, 0.04216608456185749, 0.035007226566273364, 0.05525350931190676, 0.04835674914741709, 0.0711099052381131, 0.08530307831543107, 0.07797167816710088, 0.07403220891231492, 0.041012049712721384, 0.13988944761935743, 0.05807714469190087, 0.178706647768136, 0.43520541801568, 0.4548219266918398, 0.19348842151943715, 0.0781170586724916, 0.7827122773854964, 4.6636196874803115, 8.880684394990245, 11.844917593463776, 22.231513646341142, 48.964076503630615, 55.402553004603234, 55.38647520926691, 67.67535117364699, 75.46246405570739, 71.14462483313777, 80.47210739504906, 77.8344468147524, 65.8423020762782, 65.85477521342617, 88.90398733077511, 87.05227559612644, 85.49563592480075, 93.95101085785898, 91.158306829391, 89.62480914208197, 84.00401346145138, 91.58233073449905, 94.16784732572495, 90.52685230009018, 95.45576541654526, 94.5968447962115, 88.86587758218089, 76.81695261309224, 82.32181872090986, 86.33366600159677, 66.74299593894713, 57.44108330818915, 67.64470177312052, 53.277722712486025, 42.88175513667446, 31.886694546668764, 23.883411999671694, 22.515720744286817, 11.501386607846907, 8.48796590681999, 2.4779549048792933, 1.212301780619929, 0.25057638965306744, 0.12261198923712778, 0.22360514579040391, 0.10736035844010693, 0.07849410416618471, 0.014821323040392131, 0.1046775185292767, 0.06288542277029445, 0.02208569815622703, 0.08595009319364064, 0.03980952149797832, 0.015126505656348122, 0.06132462587688239, 0.06263158336702375, 0.06273179915883849, 0.06280797894202894, 0.0669369783492819, 0.01967950408617335, 0.10064346805935907, 0.014603710977450736, 0.007567183338030572, 0.0174234728253777, 0.06887253779437273, 0.004796959129312346, 0.08728064236141021, 0.03459986314297684, 0.018635218993069667, 0.09717292888390441, 0.028323638027593977, 0.05278428918832252, 0.03117208699545553, 0.044701624917046684, 0.05994192527366742, 0.04138380919973697, 0.10503533521607038, 0.03877214268751202, 0.06290238778737765, 0.029871327156621604, 0.0112894709755276, 0.04965423012993509, 0.015974926007460925, 0.00846324717595933, 0.05972213464819136, 0.02273514536359618, 0.04685734654025686, 0.02071191481645069, 0.0883904662764361, 0.025261299226493127, 0.03360631222265863, 0.04859359672052726, 0.05218990838095065, 0.041911264566043695, 0.024227597638063376, 0.030290346607686053, 0.018752171890810132, 0.04088550730938873, 0.044945489855543266, 0.031711439707226334, 0.04061846055030342, 0.050183639020448735, 0.020532316993921995, 0.0376594114688135, 0.022534022385615016, 0.08481837448573883, 0.050678903372177196, 0.048930774998640826, 0.09137683788374548, 0.04482080904586662, 0.031323347225665085, 0.01750341410027637, 0.020346433419974583, 0.1039421354090014, 0.04757943037416666, 0.029790753859185407, 0.0350759599748398, 0.014799815121917956, 0.030230771780254382, 0.029403745392037016, 0.018925219661586227, 0.04136570654208622, 0.06443401588307274, 0.0673721852381864, 0.051466200440641374, 0.024168022810631705, 0.024477878562925805, 0.03964418057172049, 0.06930917726769563, 0.08868383198616006, 0.06470776974193512, 0.015671406759910526, 0.05113522747471448, 0.061658774277255426, 0.030016006691561594, 0.02896577101050606, 0.0391928858364061, 0.03939617492799317, 0.0050184547792248915, 0.0790380189315446, 0.07056497157581391, 0.08538639803807582, 0.014588872811967328, 0.06414659118520157, 0.03483146684424531, 0.04072589672080452, 0.03783211066958405, 0.05560544627388159, 0.06584731786842309, 0.038491842607336665, 0.061421122311824755, 0.06975667986778483, 0.015731845351476825, 0.0918198895129946, 0.06332901832196983, 0.04168860877173082, 0.0482549513840387, 0.02087659499187383, 0.029862017273121787, 0.014323586139888054, 0.004148097979205271, 0.030433151142431364, 0.07222899881702277, 0.056674364924190514, 0.0459347506834855, 0.11407809151757149, 0.051342381479879545, 0.021669721989441785, 0.09676428226333472, 0.1189891747649639, 0.2463363381403108, 0.37032913957392016, 0.20511055755759441, 0.4956873241932162, 1.857269365460642, 4.95710221029097, 11.967786819704118, 20.371198192719493, 27.60260339706175, 42.034601626857636, 67.01702840866582, 74.31561793050459, 75.88891983032227, 77.77942380597516, 84.0765380859375, 79.3337885026009, 73.54604890269619, 67.02806595833071, 65.27280922858947, 65.84885243446597, 77.97362819794687, 78.09567666822865, 70.65452468010687, 70.40185343834662, 74.96165583210608, 77.18414137440344, 76.20005007713073, 77.31686653629427, 77.76942176203575, 80.34686611544701, 88.90645842398368, 89.15399920555853, 91.45610101761358, 81.43934034532117, 88.9187668215844, 95.16591010555145, 87.14078780143493, 78.59742626067131, 81.84671771141791, 74.11481611190304, 65.00245594209241, 51.91118855630198, 41.86474338654549, 38.99964417180708, 27.13481172438591, 19.64429670764554, 8.882860329843338, 4.751495978524608, 1.6381874632450844, 0.27878316479825205, 0.17521575363653322, 0.17089947637531067, 0.026877074419791182, 0.02828396233399549, 0.134049421476741, 0.04485896788537503, 0.09720155758963478, 0.03642736205590829, 0.061238820198923356, 0.02369187618305366, 0.040901786677779696, 0.03776602026435637, 0.042031119021797375, 0.02755033930072621, 0.025881604449222648, 0.0382543170464135, 0.046862904508147514, 0.012156073465913296, 0.03457872677714594, 0.04339906094115108, 0.06635895734953304, 0.026898354427107883, 0.04809568936546003, 0.04763443165669038, 0.08802133447100079, 0.05152299819934753, 0.03465040962422087, 0.03444207201321279, 0.0618916305322801, 0.04403093409153723, 0.026449861658376553, 0.03333790565750772, 0.0523756540590717, 0.015261992136196745, 0.05615993305259655, 0.04138695782110576, 0.06138642235929447, 0.011562159972175235, 0.06270611223073737, 0.05567947335000481, 0.023508610714587475, 0.03312370364343928, 0.03511565099019678, 0.041913007416071436, 0.061544408841479215, 0.028824190301219785, 0.05155830719177762, 0.04746868470383268, 0.07758567710557292, 0.057665449041392536, 0.0904873102122257, 0.024688652333533092, 0.02597119651674744, 0.01711799143513124, 0.03320750983191594, 0.03387633140289015, 0.015688183127842363, 0.01514555347497545, 0.018457969230028893, 0.035032909663934866, 0.15827931163291778, 0.19667951480275203, 0.2431033551692963, 0.172363638937954, 0.1825671946449626, 0.11935611555893576, 0.1874611328446096, 0.20926799414859665, 0.0873302695371451, 0.16770482844402715, 0.1175451143494537, 0.08865843617147015, 0.11111023625539196, 0.09437483870574544, 0.17640789369902304, 0.125719387414715, 0.16034140582046202, 0.19658740039073652, 0.19075000959057964, 0.3278511269919334, 0.21398703447513043, 0.1304227765649557, 0.18178969201061035, 0.19945339660250372, 0.1480691369262434, 0.19553576085355975, 0.15839750367787578, 0.12846906083605944, 0.16612841867871825, 0.14141109741983876, 0.14849112879845405, 0.1753060600810474, 0.16549630421063594, 0.19862415238974557, 0.12685154279273364, 0.175896346148464, 0.18680272623896602, 0.15866306039594835, 0.18654830843931247, 0.130817495707062, 0.20703797348805014, 0.13270187281793164, 0.10322827935939836, 0.24036826806203013, 0.1695603546836684, 0.1587346742951101, 0.14090026999192853, 0.10328638712845503, 0.10622865505396359, 0.22412554931736764, 0.14257832430303097, 0.12323347806570031, 0.2190208143644756, 0.10408245973409185, 0.18215830287625714, 0.12942798075176057, 0.12734687992281493, 0.2105007981581073, 0.15559230420377948, 0.10684242171625938, 0.1797485886321914, 0.17328329684753574, 0.2661549101673788, 0.09591642211401656, 0.2613896594172524, 0.20591205406573512, 0.24915613925024388, 0.485402379305132, 0.5865433908277943, 0.29872804940227543, 0.6433182894702881, 1.8898719837588651, 6.252469862661054, 13.089010061756259, 21.427123777328, 37.67469106181976, 65.27277784962808, 80.19713355648904, 83.42598945863786, 93.77607314817368, 102.60985482123591, 93.1730636473625, 105.0337697613624, 98.5884604915496, 87.06532139931956, 85.62843953409504, 109.09762767053421, 108.6887441142913, 107.00698867920907, 113.30100428673529, 111.40974721600934, 110.61742059646114, 106.95383271863385, 113.53428333036362, 114.90117442223334, 114.31099107188564, 119.25338929699315, 116.26275462488975, 110.7498868819206, 102.88546408376386, 106.08522384397446, 110.71747241481658, 93.14250053897982, 86.26863310413977, 89.96845583761893, 73.73036892183366, 64.70652487970167, 52.03990113350653, 37.74854929216447, 34.015096156827866, 20.572327529230428, 14.163415893431633, 5.153330545271597, 2.1943185117936905, 0.5349052649351859, 0.15641632369689404, 0.47081612651386573, 0.46532238743478255, 0.2340080222535518, 0.09707061018073752, 0.29818596558705457, 0.18032614231830646, 0.1890969757110842, 0.4042530450369082, 0.14084480522621062, 0.19063397791356812, 0.09886139432989782, 0.17615355250816192, 0.14189967765442787, 0.18271820589659676, 0.15216649690222356, 0.17926336386271063, 0.24169341630993352, 0.08764580583139774, 0.10821231715981999, 0.12685436965717425, 0.1809144518788784, 0.13911035152212267, 0.21548888856364837, 0.34461806438142256, 0.14304499442298568, 0.14210604641947056, 0.10113964788615705, 0.1399316284204683, 0.16820367425680163, 0.1718852476727578, 0.1724657431365021, 0.20239051641716113, 0.21105339269964926, 0.10625834862190871, 0.16289594132573376, 0.10373110116849985, 0.15043118517966042, 0.10834308836849467, 0.1597364568301747, 0.12975738323744268, 0.11127802483256787, 0.1604435253407686, 0.10253266386327245, 0.11916013494614633, 0.26359412338464494, 0.0917020345467233, 0.10760403568706206, 0.17677337892593878, 0.15527102225009473, 0.09820708629464912, 0.179198568146075, 0.07637001048292845, 0.0850980502042559, 0.12756035032291568, 0.13572290990381472, 0.12821530953290003, 0.14072134249633358, 0.12963945166237895, 0.10281181864200101, 0.17375293938863665], [0.02568109625680072, 0.05429738178668965, 0.06019354685239735, 0.05114805944744618, 0.03201025421731174, 0.029443154870081815, 0.03251682411158278, 0.023360125637883623, 0.05714183177558645, 0.04493869465565489, 0.055376305545289675, 0.03867178516943128, 0.10501665799247642, 0.05495450902549971, 0.08967017018867117, 0.05468762697531812, 0.020602157399539026, 0.13061537106911983, 0.06721335222884532, 0.01627822308951328, 0.028207707857232422, 0.048716787489191185, 0.05183256283823041, 0.02120790503648741, 0.036416801533872084, 0.06309263040161421, 0.021599713044481415, 0.04309446821289678, 0.022336021215925296, 0.08342309088836755, 0.021541534412291743, 0.020412248033549518, 0.031242201277505488, 0.026824017085375327, 0.039408539587091056, 0.009576425598483653, 0.0400962490558384, 0.07167265810553106, 0.0431081620345433, 0.03231233226195459, 0.0022593328603468235, 0.008718651313815386, 0.036063152365386486, 0.030658572514150894, 0.04570522308049183, 0.05725882106250333, 0.05659865628507349, 0.0546324456621322, 0.016291284888622262, 0.04614964983756504, 0.05803349300197536, 0.06539270597239656, 0.04102445267621548, 0.03853706477750694, 0.04376589065237392, 0.05406568998530988, 0.054120354189146916, 0.080721972119664, 0.0693455204788235, 0.04394377626839184, 0.11686499681203597, 0.02694106957454595, 0.11052099206755239, 0.04737554756443828, 0.08957705220147487, 0.02081778625236644, 0.021194517650010607, 0.1367542327892396, 0.09577598287573746, 0.04157051631820299, 0.054480599374660564, 0.10069452781951237, 0.2842864952981472, 0.4168091954723482, 0.19122783395071186, 0.21302410791958534, 0.08395574416124052, 0.1419185234173652, 2.5919269698281444, 6.641945531291347, 9.280808318045832, 22.051084618414603, 31.717242271669452, 43.81904079068092, 49.20935407761605, 48.11777414814119, 47.12439075593026, 36.07368546147501, 46.00780179423671, 49.506124527223655, 42.141874528700306, 46.56663363979709, 44.50496527456468, 41.42289230900426, 37.86820511664114, 35.43184841832807, 30.496090765922304, 30.71447853119143, 29.53515518096186, 26.693331310825965, 24.73471929950099, 20.51839101699091, 8.59675088236409, 4.1542043128321255, 2.541676995254332, 0.6806074659670553, 0.7012205631021531, 0.05624429082437869, 0.018887660285878568, 0.2557478815076813, 0.22285568197408032, 0.30699349459140535, 0.16407818353224188, 0.2241821172496965, 0.08132737310182664, 0.09867059247147653, 0.0403861673699031, 0.07990747509944825, 0.0982208988599239, 0.023414268901932146, 0.024542745142694444, 0.023279473816435185, 0.02490090656905405, 0.03125635283668676, 0.07530373100551867, 0.07489359817437588, 0.06260113137203359, 0.07266670315256042, 0.03181698364055446, 0.0647955864006954, 0.017976105671315905, 0.026394109609687043, 0.02563884459255684, 0.013183337042949373, 0.006474454675035011, 0.02702890347028452, 0.04715027174942436, 0.03276375340177648, 0.0973941520937989, 0.037856487587334654, 0.0758682152316455, 0.02856537707210068, 0.006312979619965078, 0.037059878720150846, 0.1071056035617667, 0.0452788147113977, 0.01659651346985371, 0.05720096610246166, 0.04015748629406576, 0.056582434373276855, 0.07637394817485925, 0.055125388767450094, 0.04353785692083259, 0.04567219319963648, 0.023009117557516983, 0.015852022521768608, 0.06517015743039309, 0.07898724262392329, 0.028170454916694475, 0.04728474316277331, 0.05527204480923473, 0.053590363071810816, 0.022090411512181166, 0.02320959319120213, 0.058733000224756624, 0.0392991958576585, 0.07090359009922513, 0.10182269187944551, 0.023853583937330593, 0.04414621883282258, 0.01955986796547809, 0.06753825011753267, 0.03419666340754878, 0.02653395704504463, 0.0074067458532930865, 0.04353492663452222, 0.023836526989696488, 0.060537922526559526, 0.004264648201980538, 0.10937122432815452, 0.018955554828167926, 0.013749227040417254, 0.011344878284651186, 0.029284157151837024, 0.08031133367049118, 0.031516100693073486, 0.044152738241058205, 0.05687921683514311, 0.09374190452358416, 0.09383766551411922, 0.11802201174319753, 0.01677052459619459, 0.014437801230909124, 0.1012397755778605, 0.06467940150609901, 0.02301754835512369, 0.006980112445871196, 0.035456583099139315, 0.09952567682992067, 0.03549892860915392, 0.018690193462516033, 0.021585402522055853, 0.013462980202729664, 0.04236548575722883, 0.04587318019701108, 0.05203573318618921, 0.035528855833915934, 0.008857304609621005, 0.05072299173221954, 0.01919344619607493, 0.06674153399803946, 0.04283390638809051, 0.0746031819031604, 0.05505803048670773, 0.011801982839261333, 0.055470599477449735, 0.01357476200698124, 0.06816662607654449, 0.06065176702254723, 0.053106796882686116, 0.0054613464876198245, 0.07646479088092044, 0.054095222674790895, 0.03277375467962796, 0.07374536261082658, 0.017115767864931016, 0.04573176036618891, 0.08355223032976351, 0.032393552903686805, 0.1100511886479874, 0.10691168372549358, 0.0397255965658734, 0.050428909730286374, 0.061113947867265636, 0.041416417732233965, 0.010357840069299264, 0.02761703491541407, 0.06875419253182989, 0.07621405796418268, 0.03865066795579849, 0.06483919212534543, 0.005325318958174678, 0.11743629922068889, 0.2410019300277195, 0.016813668752870253, 0.11150704681753151, 0.11480602060234356, 0.08274302697710453, 0.12107496405200613, 0.30683813196036125, 0.32067410888210424, 0.45939620704420153, 1.4478306712642794, 3.690891496596798, 9.557812963762592, 17.738736714086226, 24.133427796825288, 39.16791385219943, 51.64802497433078, 66.52613593686011, 66.21962624211466, 66.69478216478902, 65.3694760414862, 57.810260711177705, 66.51230565963253, 69.55995590456071, 64.79428791230725, 66.2925587930987, 64.24614060309626, 59.87228993446597, 60.967321549692464, 55.19598922421856, 49.97362790569183, 50.01729173045005, 47.500777475295536, 44.261495913228686, 41.127416241553526, 35.31167484098865, 18.133411484379923, 10.894091917622475, 7.670819999710207, 3.733601940255012, 2.6764393381534086, 0.6455405573210409, 0.4151129235904063, 0.505667120939301, 0.20092554180131805, 0.1695143740864531, 0.1301378991094328, 0.3251509122069805, 0.08068452574192517, 0.20107004130559586, 0.05272582135794144, 0.08255435484311274, 0.07317355458414362, 0.022544569501112548, 0.0778254243214765, 0.07038722385562236, 0.10765761587648623, 0.12448453795044653, 0.05727166835699351, 0.08579070094011484, 0.01017151599479539, 0.07608185417108959, 0.048961889659685474, 0.09549201706484442, 0.024129697346999764, 0.08231009536933515, 0.026782202091248288, 0.03385157910205665, 0.02725468490332846, 0.042788596117808934, 0.01513238250833726, 0.009338558170824282, 0.07255418781912135, 0.04415904314467504, 0.04550389517399092, 0.08828543562201724, 0.06532191944819304, 0.03231621632773069, 0.1076549422296305, 0.024155024213776476, 0.022536115720868114, 0.03973794973365242, 0.06880484626538332, 0.026352535933256153, 0.025407403684972275, 0.031582135556926655, 0.04898982888628398, 0.02429433155714745, 0.02586252119902882, 0.02998051958368911, 0.05965784838002536, 0.0883992533049276, 0.01573301459317126, 0.055460682469269926, 0.10639424495879682, 0.02700315142470983, 0.008829712995418139, 0.03437181792011665, 0.028750327934000282, 0.03014420959047012, 0.021817653567620346, 0.04314750447989472, 0.03492079269621642, 0.01941811105596923, 0.01516278279239252, 0.027283872853243546, 0.038803694018673514, 0.07579874637867175, 0.13526483529037045, 0.04506968036894837, 0.14376401390519836, 0.13990024945908977, 0.1653417536327916, 0.20517778943382925, 0.12841551895103148, 0.06678581388006288, 0.20912951609540373, 0.10272654539514935, 0.23610036159234665, 0.12881324115780093, 0.1488130542659952, 0.10424523043536371, 0.1889941054246118, 0.2724149210318443, 0.18757434531805978, 0.13151504940563633, 0.07342561283299039, 0.23318187303600774, 0.12350858023930943, 0.1308375978541951, 0.13536177605630892, 0.19366161867735848, 0.26724753540850454, 0.12345896838533303, 0.09770694579328261, 0.10288393815919276, 0.08525913551209435, 0.12982725045613705, 0.14602961168894846, 0.12630517654601606, 0.10837286620611146, 0.09735829917894256, 0.11196844625256716, 0.14176185843684982, 0.18721630646576806, 0.10624008508579386, 0.15851903586618363, 0.13552219486765324, 0.18245140811608684, 0.10270068226682563, 0.07967756445249242, 0.16030500132230022, 0.1007424466191761, 0.11594664125192551, 0.1123641076828203, 0.16818007874873378, 0.12278605973528278, 0.1793665712278697, 0.1596757826665717, 0.11177556063499182, 0.19113299226568592, 0.22719796025945296, 0.23674278760388975, 0.2205231281057481, 0.19319818144844425, 0.14164939672956545, 0.16911643737506482, 0.13276021807424485, 0.2723919996811498, 0.09995326880485782, 0.1547030446630332, 0.10346455619700494, 0.28690728208711075, 0.12449710179240474, 0.15709279465579218, 0.12675699222111894, 0.12583332767169322, 0.315084578168969, 0.2152593073345, 0.1663109467875573, 0.18712829828502672, 0.23029536098962833, 0.3972606234733136, 0.5465409147643274, 0.3887091823402913, 0.2698628982949642, 0.394962543561574, 1.3922834131986865, 5.079446329224495, 10.07549032088249, 16.1531077854095, 31.84732767843431, 44.13673316278766, 58.695798535500806, 66.70557652750324, 68.15391955837127, 63.99635622578283, 54.88565129618491, 61.60868790841872, 65.67853527684366, 60.93265171973937, 63.84908299292288, 61.221047909029075, 54.467326594937234, 53.290988168408795, 48.31750123731552, 44.99546158698298, 45.083354057804236, 42.98157161281955, 38.41665837072557, 34.38266931041595, 28.944869848989672, 13.911879197243723, 6.511493873211646, 3.9038127035863943, 1.7103959692101327, 1.2047673978151814, 0.24730055172356868, 0.16582841864757, 0.2995627175175375, 0.38320245041001233, 0.4373958166087828, 0.3116164062052004, 0.25591367825625405, 0.19165518843839247, 0.24548447901202788, 0.3230988997365198, 0.26849837312775277, 0.18735023395669076, 0.14869461707290144, 0.14884783465775753, 0.1837382519677762, 0.2093486785287819, 0.26505891413938615, 0.11802727476723733, 0.21646224923672217, 0.14148128639546134, 0.21629947087457105, 0.07902595304673718, 0.184160657527466, 0.10232847844881397, 0.12843916808525402, 0.13330309862090697, 0.13951518302482946, 0.09634048242362277, 0.2162877037640541, 0.12486254105404501, 0.10820403574935852, 0.28055549388931644, 0.12437989033998982, 0.1624720189119539, 0.15777478144774515, 0.14869608796171604, 0.15930645167827606, 0.21634802552721194, 0.16115652337189645, 0.12029985927285687, 0.2142078056931496, 0.2024334633061963, 0.11829334476421918, 0.15357260532196493, 0.15158914239896884, 0.20724182948470118, 0.1631218146893286, 0.09420819926045595, 0.11322492237893805, 0.08847492747008802, 0.192851894384911, 0.13633256267395713, 0.2239449057848223, 0.24688140969843636, 0.12838886675214575, 0.15756190093534608, 0.1856648711667907, 0.15994604316449937, 0.18791595924525492, 0.15905157422586796, 0.18714412566154234, 0.13254928342517347, 0.16821767834405746, 0.10534060593213766, 0.1511138001637113, 0.13573732767854968, 0.18646151067749148, 0.26319535929829846, 0.23722940665339273], [0.017016306669721683, 0.01962353561764523, 0.05236923424226623, 0.04312683542769763, 0.016157428260832545, 0.030347879810799516, 0.05828693020908583, 0.04109371468544968, 0.03986176869441425, 0.04575815209518037, 0.008365890807321957, 0.027672419241899927, 0.03427646295618146, 0.012688532343975479, 0.033529711091109825, 0.053119368385523565, 0.040679720771168514, 0.03414809726358902, 0.06977171817373845, 0.0268357171631989, 0.021213332769430934, 0.028916457930820125, 0.0675098512381796, 0.026480265772871436, 0.08016950781306914, 0.007524544320579979, 0.10537599153336018, 0.01964669445559623, 0.03501678351312876, 0.04170633604629867, 0.03650575583319991, 0.04999507413876634, 0.02644151704566133, 0.03763458255918757, 0.07540169066839641, 0.09564558705014568, 0.014413505710000473, 0.05129683755278107, 0.06423048547378953, 0.06930760678745086, 0.02442227973182115, 0.044023323008009506, 0.040748373740502906, 0.01907545141875744, 0.011198763292463077, 0.042437011556279276, 0.04533069035519035, 0.027750583192814263, 0.019906109063735893, 0.08517157932322833, 0.07707681086274885, 0.009712829468621603, 0.031816186909113205, 0.03705471911798081, 0.07152119486202156, 0.026326536824325883, 0.05743497531981238, 0.0676038655482473, 0.020947293415966056, 0.060428574966687354, 0.1079551337827598, 0.015403686801061757, 0.030224118306632006, 0.08559086690506629, 0.06717212137676055, 0.03150851259218349, 0.051657121042690934, 0.07380690245378403, 0.19647355972518846, 0.07374580694182266, 0.023589297009992505, 0.03686706205048869, 0.08320119352109971, 0.27351404269856794, 0.144105643154152, 0.08108026378097073, 0.0924560642470756, 0.05588610258494174, 0.22248713239546747, 0.2331556115419634, 0.1685830563186638, 0.46390886328393416, 0.13167123941163864, 0.03553917886869561, 0.18483176587089417, 0.07846917566512862, 0.160870052453491, 0.1035660245425759, 0.14303209350234078, 0.42124692831308613, 0.10128461470406863, 0.34195682815005707, 0.2702420505304491, 0.156020286883558, 0.06816853363547595, 0.053391433020512906, 0.02894725658059601, 0.08019156348440917, 0.15638287629811995, 0.40642999112606054, 0.43115725620619716, 0.6157556104083216, 0.4673669228871023, 0.20732704910539812, 0.15434946444246078, 0.10843603781634763, 0.0440237864912037, 0.03401015547194308, 0.03553399245344824, 0.11851317369409146, 0.09880519411977261, 0.13867418702331283, 0.07492660890303313, 0.0502048941299079, 0.06168632279901255, 0.04100184542156997, 0.06437472833861267, 0.11345103322978943, 0.0471846767581038, 0.018299697380092357, 0.09216166431865386, 0.06406005006283522, 0.052812864267898184, 0.04771107875351464, 0.006575752087237855, 0.026051608935719537, 0.04549099425334604, 0.03355357856039078, 0.007736979065568097, 0.022118919559063453, 0.005413134659325043, 0.025524990520470088, 0.028647384869175094, 0.04299499552636858, 0.08725939108239067, 0.055165026156652364, 0.06912871759625212, 0.027015110057207848, 0.03440938687192337, 0.015704428022276732, 0.05537922817072081, 0.1087394086343627, 0.042749364755206534, 0.06478865330498065, 0.009990405148616242, 0.04271867527295986, 0.056175902155378175, 0.04543347637199106, 0.05639193895002527, 0.09413067882339801, 0.10309639732323347, 0.05396538992382346, 0.07358538046959909, 0.06607849256045396, 0.060807635271621335, 0.025672753559305303, 0.05308665260071716, 0.026745876117098718, 0.06530695775103185, 0.03480479549316149, 0.05567000067282108, 0.0787475643559329, 0.015517747716888066, 0.049004798244324424, 0.004233964465393295, 0.06036154610375243, 0.02586961900364728, 0.04895748848456049, 0.030859061554374716, 0.0575447787019995, 0.030870420723071987, 0.004130372619857231, 0.042965972285357215, 0.050793061964213855, 0.04199305211283988, 0.029574872197342977, 0.010511573805894342, 0.028420632419687127, 0.10899236320608086, 0.037574126730642976, 0.0643957804347719, 0.032025614280193564, 0.02485154560887285, 0.0449265253489777, 0.05759784944295403, 0.0715935595273491, 0.02583727860192378, 0.011036065369544011, 0.00995510764750502, 0.007654805601980057, 0.029727047902622053, 0.04388805103277968, 0.05555737808707261, 0.04777657927104062, 0.04018262929974064, 0.09679329401302723, 0.07858802654570149, 0.010011479269803293, 0.04917450204131104, 0.038342489936058564, 0.01308569243373049, 0.03715881514513204, 0.11764209341978836, 0.07005245109359104, 0.004061985387271571, 0.0030222817393575586, 0.03563684358772251, 0.06921919258010965, 0.032671041441180056, 0.0449977562041773, 0.01855654176324606, 0.01804278596424528, 0.02389984224141846, 0.041399491019546986, 0.019186074515023542, 0.07065933828632678, 0.037260988291593335, 0.0147083317748301, 0.016574063263232672, 0.06186782051959346, 0.08905627329142825, 0.06854830640217952, 0.035631228163237536, 0.05000420973726338, 0.08418742447130143, 0.03153870028683976, 0.03654485696085519, 0.07777162962743352, 0.006750219514698632, 0.036536054610605204, 0.016043055164177093, 0.05759165562208622, 0.037829659188226346, 0.06578190928144802, 0.04549069930949519, 0.04733337825464626, 0.0329621663437255, 0.05012877180331177, 0.012796858134078644, 0.09318095196278826, 0.018788066940502297, 0.0711080972706118, 0.08181879552261484, 0.013467919554621463, 0.06897655721273153, 0.05978482745347485, 0.15050509734259498, 0.08954864566124256, 0.14439824277595167, 0.0829485530454305, 0.035942298164891626, 0.03730169054301035, 0.1363078946427953, 0.09115921528709513, 0.30169804971064296, 0.18790472839628497, 0.07223728022748424, 0.3490037951738604, 0.1208023286815132, 0.20944566525999578, 0.7008426059638301, 0.36967842449103633, 1.4291158174314809, 0.936397543597606, 1.3004799715934263, 1.7330404250852525, 1.140557217501825, 1.6895392561151137, 1.2052952017514937, 0.5715951768140639, 0.6045320545954089, 0.30958446523835587, 0.1664142460832673, 0.1979641216777025, 0.44103982107293227, 0.2647147874437994, 0.35036360123945826, 0.34881187482706966, 0.17781674471353331, 0.15665183444657635, 0.2482160880801178, 0.10994055022996281, 0.1261598420059008, 0.031345220951123104, 0.08431467167552441, 0.26264886281663374, 0.020200658379302874, 0.13090335884161536, 0.06174804267263221, 0.14918431579586, 0.08902903886572008, 0.04290330246271145, 0.023983102592249072, 0.020682872423241218, 0.07785734720528126, 0.06582290264627626, 0.11014568559344738, 0.0726326045790507, 0.007779230251007023, 0.026689499706750917, 0.040001675501585975, 0.0521586673153985, 0.06677528017110403, 0.07119459625814231, 0.06455938617188124, 0.052917523369673765, 0.015398078079846118, 0.024243086020672516, 0.09202678687870504, 0.013247478712019662, 0.029897412450443354, 0.005509962906099616, 0.0612408694841208, 0.028324881005251122, 0.046723610571315216, 0.07810886919258103, 0.06690732308573301, 0.08268525628673454, 0.00569213095361427, 0.11156320872326052, 0.0208510325530604, 0.08237244726549234, 0.040181418880820274, 0.028452114802935434, 0.043373193982387745, 0.02230445839344494, 0.04830685767134832, 0.03890517385556333, 0.05944810882811585, 0.017690994558976065, 0.035600228415381525, 0.027755170144260894, 0.0049987380700786755, 0.0805399036635795, 0.029407775014518734, 0.027403756037294388, 0.0528894309254904, 0.0294526198863863, 0.023233805400049014, 0.03604955047429089, 0.006071487160009002, 0.07290466538360042, 0.014353249064316193, 0.05372151732444764, 0.08003789390767775, 0.013187475832960299, 0.023026959745273478, 0.07950387699829956, 0.01727384436244686, 0.04108185564438182, 0.04245283893279491, 0.049866463298038136, 0.12306421859970978, 0.14858163442582856, 0.21406548187857677, 0.2397499125330679, 0.1188585797565118, 0.1023333507680124, 0.2657165853006225, 0.19290349806749052, 0.16184658473057134, 0.18573806320707645, 0.13807250156758294, 0.14866725241224613, 0.1474394432960018, 0.1542700058029544, 0.10174074345418524, 0.11021863248559738, 0.18767749139618492, 0.16079448554064, 0.19914449462967537, 0.1629530608413681, 0.17896396138014334, 0.1164477470240766, 0.14080466221897833, 0.11892294646390986, 0.13658633695975428, 0.1351744062717884, 0.2036387954027422, 0.2069227998295138, 0.1152110436270314, 0.07649564890251045, 0.16983070711214698, 0.10040221165024465, 0.12490461460284649, 0.11239102035160027, 0.09236464697507121, 0.3997415838943374, 0.13170038139627827, 0.18497381389381426, 0.1785000951419915, 0.1362025728749652, 0.12538465295707987, 0.14645169549171003, 0.1893330227223135, 0.19712304906739345, 0.15805307054711928, 0.14310887083411217, 0.10305437740058669, 0.1664029539472634, 0.0969940243709472, 0.21028566534721085, 0.1412024763562987, 0.17834172944628424, 0.0895312937697576, 0.162439996436719, 0.18986787466752916, 0.1336643090772052, 0.20144219149745282, 0.1505756693621797, 0.08874777734519974, 0.21506884255476538, 0.20524207953243487, 0.08873465425905683, 0.166121753713777, 0.17185221396146283, 0.2503049953450119, 0.18401821113882527, 0.28378688339744845, 0.16718217261856602, 0.3487036419251273, 0.24428677715120778, 0.14131155195495776, 0.13328344080476992, 0.21339621214616686, 0.3460863484970985, 0.48358197053593976, 0.2689206101480992, 0.22332520194111333, 0.1249706207384025, 0.4398671549654776, 0.46913502317282463, 0.3353714444223912, 0.6557001702247128, 0.1282204040175965, 0.11348838001609811, 0.3389030791098072, 0.22957539155838952, 0.4107095421321931, 0.46046413361064853, 0.5801325832163134, 0.6487711807412486, 0.43856232336932616, 0.5265803406796148, 0.46554896559926773, 0.20819648229066404, 0.3096923304180945, 0.18031324139766156, 0.17115456833233758, 0.19711690504224072, 0.35926189634107775, 0.4795658005581748, 0.624110994319762, 0.7482542554217001, 0.5609825301554896, 0.2973106028812547, 0.46708426708655976, 0.2283845691671295, 0.2024252355218895, 0.12814324364186297, 0.2254928783663819, 0.3783585071083038, 0.2650920091377151, 0.27946302186577554, 0.2498008022385259, 0.22802346596314063, 0.17093928230385627, 0.14808330955284257, 0.2621105481540003, 0.2863579970454016, 0.19799537806501313, 0.11306533094255194, 0.1763545126924592, 0.24563311539109678, 0.15542307538130593, 0.21242061449635416, 0.15454161461562882, 0.15116200241590702, 0.1479277477389382, 0.11523789500877743, 0.1881621492606017, 0.1025732818450178, 0.17825315436047895, 0.1071775698613736, 0.1494656079598973, 0.0943760108202696, 0.2279685527807282, 0.18993942727965696, 0.1268378987668022, 0.0835167374762316, 0.0941647161098738, 0.10787609649161178, 0.11590190171714752, 0.18756282335567862, 0.18052057543348882, 0.2655846343165444, 0.10391650210705497, 0.12935400730179203, 0.17418496701265537, 0.14241122520498692, 0.1372095801296734, 0.15423399967051324, 0.2704864325782945, 0.1346527003953534, 0.13116454885851953, 0.10304211233291896, 0.17757104499445808, 0.10472292456054881, 0.11116528733363075, 0.15641451572939274, 0.1989128909284069, 0.07470341684717326, 0.11385100773505627, 0.2820277003751647, 0.0918865544841655, 0.12966713807996244, 0.06361693331611253, 0.15805562928078637, 0.17815247508547, 0.185060856803771, 0.13107986549936956, 0.25632112977966187, 0.10783820578287687, 0.17427079950369176, 0.20403821832470356, 0.1254061876886314, 0.17343119778219732, 0.1517123753024686], [0.01281149903192155, 0.027753408142035047, 0.07360345248373286, 0.007948256060180646, 0.092695459062534, 0.08523891079089335, 0.034933797038731076, 0.034443615680380214, 0.06884380183633297, 0.04746671585786728, 0.015686182680750088, 0.02871828056090782, 0.06639094152037175, 0.010377880929398441, 0.0042753255524251976, 0.03275245360489334, 0.024646228299506252, 0.03577199298888445, 0.05316841716487562, 0.02956171655246327, 0.0415087734619456, 0.013593179718290847, 0.047478084602663596, 0.032397735743753375, 0.04525608871312392, 0.02938670759660102, 0.11469820904875956, 0.029893863548134125, 0.030119340461228165, 0.04659814069107656, 0.017520582130659493, 0.05444743542841846, 0.04101299966174749, 0.015797533560544252, 0.03697683478915884, 0.007161944372309072, 0.04512164794329194, 0.02353643119755772, 0.010899901859492305, 0.08458084126393642, 0.025263128261412346, 0.02117385242825314, 0.08026673203153957, 0.04294910302926456, 0.041091910548388, 0.07203969083005382, 0.04028629631765428, 0.029308543645686684, 0.026545572853196534, 0.07053022182756855, 0.01610010956233788, 0.01818025661181779, 0.03879001551878549, 0.03500087569738108, 0.030479135570086302, 0.012129015240427709, 0.030950542028632858, 0.026254610744335, 0.03870763808428761, 0.08051311356886741, 0.07936459455278613, 0.015130141701158738, 0.05374750302683923, 0.17985115248349406, 0.05839940723812869, 0.030193905714118195, 0.053728128663234176, 0.1154969706230106, 0.04219633737398733, 0.0347152934409678, 0.09613137106381117, 0.08598183221634358, 0.1478160521195781, 0.22055469092822846, 0.13620018268064146, 0.07802915774405965, 0.09798374102120438, 0.04218380034510647, 0.05608994709027391, 0.08607478166419653, 0.013984857491337726, 0.11773376350080776, 0.1325701056949554, 0.06147756383964612, 0.21182516499632792, 0.19050052539715845, 0.028901674349101323, 0.014552395535452713, 0.06382954569773809, 0.04308362040788897, 0.05847181786873168, 0.06967817117730457, 0.04212146760114739, 0.030119618168100718, 0.05218654142452344, 0.04545655094027039, 0.030258195812723813, 0.07175812287436378, 0.10177050597004353, 0.10414456648211326, 0.14295870227919472, 0.11519088785374358, 0.11724977213288508, 0.12884241378595754, 0.021869766698669524, 0.02887582079687667, 0.04680362462456669, 0.046473705029535683, 0.031192667947541323, 0.0513844320460433, 0.15235677782085635, 0.09987079943980902, 0.08514886481627341, 0.057915710814056866, 0.07443050568502757, 0.036614168765804464, 0.10890972530168873, 0.10273951526370742, 0.03539744111138486, 0.07331250761184963, 0.01797073731018651, 0.023741518680547035, 0.09678708103996131, 0.07106655232247806, 0.027619049726654927, 0.020362417844514695, 0.03146861856352658, 0.05796462935846179, 0.05522537856332718, 0.057260590725608414, 0.06091203773394228, 0.0605190001548298, 0.10074929544521917, 0.0514322167803203, 0.04039494290707573, 0.07505553383981028, 0.012444480671547355, 0.04933690885081888, 0.09817084267495141, 0.02760463961279921, 0.017962182023292108, 0.020895293282885707, 0.04044260123684522, 0.006291494205323679, 0.04926385853679911, 0.06291047384541842, 0.05168155924747548, 0.05733279451247185, 0.04699562158014986, 0.020367772799105417, 0.028325788819441394, 0.06057969730107054, 0.05209094131245248, 0.03367571978859844, 0.015627148902914938, 0.048507867651360656, 0.07828426502284505, 0.016095852028698693, 0.08105336643394925, 0.06392110469600847, 0.020332456145796086, 0.015336573668455165, 0.025665360810835997, 0.03338742558093321, 0.049346622845698754, 0.029708615827163862, 0.011001917957929114, 0.023011358364695506, 0.10891963847942891, 0.06036003308010198, 0.019716331847913323, 0.04617979539738548, 0.025275739983865814, 0.039183872811976946, 0.024524535232734297, 0.08323300915259509, 0.03887507426101835, 0.039968806499194716, 0.04814965259884635, 0.018269668648680373, 0.02626625528078406, 0.037026507930169185, 0.0609572330910352, 0.02041812392792875, 0.03173675125224456, 0.08538807577063, 0.036209862033325824, 0.029913663090537154, 0.07278261991638331, 0.020941072782020898, 0.012044953370106318, 0.02531763350200509, 0.034834672922208425, 0.04597495114731212, 0.06120080308568093, 0.012540278051258817, 0.02366576407615456, 0.010738857728879779, 0.04780526160292568, 0.05785385687505046, 0.04332410306819985, 0.018904263326417536, 0.10046184393427066, 0.05832957066295128, 0.012835159657462951, 0.032905747798541864, 0.015694417168326195, 0.018722321274840546, 0.03295075163365372, 0.02891848806381947, 0.03775260989524184, 0.0238063182276223, 0.09131398036955826, 0.036177950640839916, 0.055983391920885736, 0.05736523067518588, 0.00996689295261017, 0.01927195488655519, 0.046476937920576146, 0.037076219375575745, 0.022177682333295385, 0.1308417653725032, 0.008355402106028652, 0.024570902704351374, 0.02396629462319036, 0.0237817995836057, 0.013871460199175824, 0.06149806052206024, 0.018902489832872828, 0.020792652822790608, 0.034287322252508134, 0.030556937544456417, 0.03446217416034591, 0.03627450070193699, 0.03908304414982277, 0.051777664977576465, 0.03996019184048619, 0.03229739737787074, 0.04477390148226292, 0.1560640611475514, 0.01057534487993126, 0.044691252086551926, 0.00882167769070234, 0.008382953500615494, 0.04166130922854908, 0.06996504046143064, 0.13511276683740078, 0.052254363188459996, 0.05991467552620077, 0.08553767742048349, 0.053396006565420866, 0.052476214590452375, 0.11127743494486618, 0.06614513454898711, 0.06329925580611152, 0.03998150823697929, 0.12005221369045398, 0.17978197474393154, 0.08137025870382786, 0.08516461558399663, 0.16203542540390647, 0.20438973010788042, 0.05787916075918944, 0.025991907703780362, 0.07092537763979166, 0.0832974065035101, 0.1306739614735688, 0.07963424984125361, 0.1348573071581702, 0.18402420194639316, 0.07437415991819675, 0.04171667057239721, 0.11757882221812203, 0.06576936842212755, 0.21797671313247374, 0.08423788668287378, 0.09572556662944057, 0.08513358136218402, 0.12683150193263448, 0.05749545030055508, 0.06516912321169531, 0.04483360654464172, 0.02949223046251122, 0.06150192543563824, 0.06468156187404549, 0.028497654899594285, 0.03880639447860661, 0.029222692002452193, 0.06719018573001509, 0.04075397001278978, 0.04997849216564529, 0.05893497930599317, 0.04988102662947871, 0.07817750300971732, 0.06062628310774604, 0.0487879493964776, 0.040016204359069954, 0.06686768569653073, 0.17064161117999785, 0.02768253543294005, 0.013203546442391892, 0.01905719937396146, 0.08774148255226114, 0.044305005876888195, 0.012880886488053347, 0.06834711639150497, 0.06819697081922524, 0.10360991371975792, 0.043961779334612434, 0.019496778709693782, 0.03851273382503179, 0.050207207715439225, 0.0233761215537426, 0.07209870258286115, 0.06043376138193473, 0.02550894097845641, 0.05816555506880245, 0.046368547970609325, 0.004615085068038635, 0.03698407432004329, 0.0434831467517201, 0.04024763952099508, 0.0379600856573351, 0.039674329961980545, 0.03496276282314812, 0.02392909913924673, 0.03272736422537315, 0.0031369406825697593, 0.015815911052237838, 0.06909199900204135, 0.05576756963085744, 0.01792137826522512, 0.08788598971741815, 0.032189076375817104, 0.043275456485008044, 0.07197668009828176, 0.03229083200435966, 0.042272279669921246, 0.04046519316973225, 0.08759794831876794, 0.03092729509057057, 0.007661570637156406, 0.019861811944734187, 0.027336976152934858, 0.010478206846352306, 0.03229612950235605, 0.036351465725249825, 0.014798596084508446, 0.02886025772069491, 0.05739678966722662, 0.05043080962833859, 0.03148001412140026, 0.06560306605552474, 0.21940892982867458, 0.15881491434429923, 0.0856261452539794, 0.19938691549243467, 0.1896568174443899, 0.10582675000712757, 0.13187103514229098, 0.09631813563887151, 0.14841252817742287, 0.11409776465546702, 0.1426550709912854, 0.13514074436839552, 0.15217628750589587, 0.09780089881631637, 0.10683312140885862, 0.0944880665009541, 0.2001278144457648, 0.10856423496959672, 0.11570766012394622, 0.15875876009944948, 0.20459012338711371, 0.18121883393295352, 0.1661916975412638, 0.12122727765311157, 0.10552750074214513, 0.23199961550774115, 0.11849762210922858, 0.12178173378830957, 0.22440330215519477, 0.18335436530891927, 0.15253679316130378, 0.10382570536626924, 0.08102013353979395, 0.13606718981698637, 0.21968098297234506, 0.17776933919277885, 0.09617660089486069, 0.12504477804947284, 0.14706887124526888, 0.11916904454870571, 0.14277416701999404, 0.1774127099422678, 0.09666725722772461, 0.08993468502716673, 0.19144716492343336, 0.14940789089568202, 0.11949361301958562, 0.1353761478657684, 0.13380726108387594, 0.21944740276423194, 0.13726703672399446, 0.1545205318759526, 0.13664820622051918, 0.125899578955385, 0.21171939889750174, 0.12057067901496926, 0.13067368568191606, 0.1743241039014632, 0.1680098080466832, 0.1957684830431977, 0.11410891889564453, 0.28283494254273756, 0.2764698244150608, 0.15878325959126796, 0.1656698844125194, 0.18030017193767334, 0.13823443723301734, 0.19329064826090492, 0.20063159386477164, 0.2259301766753197, 0.1382634566435891, 0.25697927591541125, 0.3489841833229988, 0.2876975477462815, 0.24918718113293573, 0.16377706501272418, 0.2540065636557918, 0.21566597744822505, 0.14621166482327447, 0.22769934948413606, 0.3806133183740801, 0.20651124207483185, 0.14871859562493142, 0.29815804934309376, 0.24813338122781248, 0.232720029269976, 0.08572916875803664, 0.1991421044353516, 0.24649044438715906, 0.215968398317214, 0.20866633933638373, 0.12034435365949908, 0.23683274164795878, 0.17024860807484196, 0.1643240824341774, 0.23994471337045395, 0.17511721940771227, 0.3286552435207752, 0.20334924481088118, 0.3237167956127275, 0.22032203002562448, 0.257197289216903, 0.13860726158224768, 0.1161808266694988, 0.13122205141811602, 0.1802817858274906, 0.15859714619094328, 0.13719857910708075, 0.2067389387276865, 0.30126465845011896, 0.2892841771245003, 0.17814397150951047, 0.1499806948366665, 0.24262914674416666, 0.17024532921852606, 0.15254425485768627, 0.1446109394272489, 0.16011053756360086, 0.12010119735233246, 0.13097170920621964, 0.2536250825130171, 0.4051577029449325, 0.13452683214939412, 0.06888768335263576, 0.12545710955295833, 0.145147982383928, 0.20006507184476624, 0.0752144281361853, 0.17542461984820906, 0.14768238509854964, 0.17617209183592952, 0.13838863541041652, 0.21613298464686642, 0.15097850903628335, 0.11268437073956575, 0.13950700120579812, 0.15524989354514307, 0.21161300460657767, 0.0741446016716861, 0.1362148149599952, 0.11526977192730674, 0.10038268406905475, 0.10094359832545442, 0.130519364930449, 0.10648393853297157, 0.11956813805285962, 0.16189933754503727, 0.14802585295852155, 0.09217727719055069, 0.15948421472022611, 0.14143640896485699, 0.1545453378029408, 0.18356323152059512, 0.09185379656452326, 0.08075571063184932, 0.22113985952831086, 0.1338733131847074, 0.12556960956463892, 0.18000512083451595, 0.14833408077397656, 0.12287589886616315, 0.09864274517542894, 0.23274694959963524, 0.12887319519875512, 0.11070820863448805, 0.089263369839999, 0.11405318599915314, 0.12542031434995513, 0.15555502636538399, 0.06853244072126766, 0.1059486345958806, 0.12796674464498797, 0.24225155732804732, 0.16250934271562487, 0.15558304986165417], [0.05586745600486475, 0.006187020401064788, 0.019382631608975992, 0.027472064267062855, 0.023610276327798926, 0.045262309347069075, 0.029236855052952326, 0.049989497018677574, 0.040727647231711496, 0.03194556000732607, 0.03801311809389341, 0.05909678856692007, 0.07407717061259093, 0.025768740545778025, 0.09674327613245096, 0.03196472369675194, 0.08971938367692694, 0.01693313824944198, 0.04160761412593626, 0.04630176042537055, 0.09982275806607739, 0.049753771764376474, 0.05608405970457581, 0.04271733844953199, 0.09052077293275826, 0.07999857827540367, 0.033689003753205465, 0.010721172589147765, 0.07780879255264037, 0.01103692434562911, 0.06437077532492338, 0.03347389009450713, 0.02267983764590275, 0.0764071197819806, 0.028938019475449, 0.0778828579331598, 0.04288279428897847, 0.06398666650056839, 0.018165769889169646, 0.03661291621204826, 0.03378957960634463, 0.07615429544520956, 0.007117305865376107, 0.07340594735597411, 0.025366157511129014, 0.058047853320116, 0.018673326121643186, 0.06146481996702571, 0.021198696659637556, 0.02894714549784699, 0.033953870992146196, 0.028832609607507626, 0.0672724252686866, 0.01814565816593747, 0.04215425233386698, 0.035851696776526595, 0.026275800736320597, 0.0674206326385179, 0.03257462927590936, 0.02799151018412123, 0.15134240080031658, 0.0855340997898771, 0.056550132275949565, 0.04936061544163574, 0.09856288817020194, 0.04172299462821215, 0.01859000065333901, 0.05075769934562906, 0.12015547468176774, 0.09502933060209598, 0.03934673161336011, 0.0233689624620902, 0.11644730269308053, 0.13363818547898723, 0.10326882073235127, 0.06837543866206562, 0.0679564958197936, 0.10358539890618094, 0.004155440931959499, 0.02900180012558497, 0.036926445355939294, 0.07760717353272824, 0.02449747892246852, 0.08304155611943814, 0.22654411953783807, 0.08272163014137938, 0.02596186365060989, 0.058950009951067556, 0.012491836396586752, 0.03877066413781816, 0.034122678466261394, 0.035609256761569175, 0.045486669687013474, 0.04905925943486152, 0.0036027312378263884, 0.027335964916874806, 0.03362582831252967, 0.07233062038017858, 0.08824565267610936, 0.11881948628973578, 0.14054572450057154, 0.18007857334469596, 0.1446925124694263, 0.010486659668986837, 0.04670657277587922, 0.06867360774307482, 0.04900376019518703, 0.061927877982417424, 0.045521074695692915, 0.03943637156138017, 0.04904437434649275, 0.08173870103013131, 0.06804408265217658, 0.05261911680140803, 0.05279975650351375, 0.046621506372767116, 0.11877457821561445, 0.05258332900402527, 0.036533480555179625, 0.04252458306690378, 0.0030822496656553763, 0.06648533887440158, 0.08954961859290639, 0.06897225179859708, 0.01916113260742878, 0.053791813552379615, 0.06324573690372129, 0.02721606258062586, 0.0695428187628427, 0.0268889794261345, 0.02989078962033795, 0.03343286991660153, 0.03276736550633946, 0.06317127698792085, 0.03285491020388661, 0.017592307112570253, 0.014833893585619668, 0.04371416056528688, 0.08075155077442046, 0.05753538646404782, 0.056883625671147346, 0.07660881541068516, 0.06511461605588276, 0.07439383305609226, 0.012848555662428901, 0.04805594089350874, 0.01605842480315797, 0.036332964701878454, 0.039473124629547524, 0.08370095863938333, 0.01798431430342457, 0.015746435495994745, 0.04434360138651344, 0.06692315812312788, 0.10206948710425247, 0.034468218594068484, 0.018613301217556, 0.010442826990789224, 0.06040408696618773, 0.024995958928259152, 0.009745964686566544, 0.041631067907738115, 0.05084164726037172, 0.043084041756247325, 0.09687501261191023, 0.09035493021891003, 0.05041507418237386, 0.03886579693625531, 0.0677537736332705, 0.015560311561961089, 0.03423083475941131, 0.024295473028154626, 0.04021488543179247, 0.09348348008408662, 0.08209207440696417, 0.06783435076114631, 0.045820496330458316, 0.09273010155846996, 0.028462562327002807, 0.03121563143307163, 0.03387358114724198, 0.0694115266143795, 0.056613928247844024, 0.0636226713146654, 0.06668503501362379, 0.03917272240223904, 0.05194752965302718, 0.07652576381881392, 0.07174507639701329, 0.015815732936795442, 0.13879181216320685, 0.0627964454883289, 0.015400599466726906, 0.00992183166090399, 0.038720041047781706, 0.03586678487819529, 0.0494545339907129, 0.03782223196580045, 0.021239446791549845, 0.04613779845737642, 0.05232397759813936, 0.026285840318568295, 0.014090813196925147, 0.023675725134390018, 0.04532132876075564, 0.04865411766654542, 0.04609454896361117, 0.030842305296250892, 0.01328284516104407, 0.03340577721715935, 0.029084169899203607, 0.06375438481148693, 0.02453813903904971, 0.03281917986309817, 0.0195275467159527, 0.016875189443629597, 0.04566856960375463, 0.0540612007100736, 0.034161817898312886, 0.016907056786059853, 0.0084317427676832, 0.06516408235315355, 0.04252415405766618, 0.045315602253521645, 0.05716851461798914, 0.013759382493463496, 0.04077646235424665, 0.016047410374026627, 0.03483455034814054, 0.07568587098390826, 0.05511519979805716, 0.026330702427414157, 0.030754580568041534, 0.07590936947493784, 0.013957750427746966, 0.022623740857647314, 0.08817493509981902, 0.024674512265670686, 0.10507471979625764, 0.08852030285784314, 0.08329179107902512, 0.040079065703696785, 0.04459092904242777, 0.06395758197252309, 0.032998118850011984, 0.12076177198680178, 0.04838168913979204, 0.06153178371248707, 0.12046252272181934, 0.05915029214755182, 0.021136446270130334, 0.061496011236862796, 0.044990677551756945, 0.1033482717109784, 0.061756032969682455, 0.0169054901362547, 0.03201783082688288, 0.0424013999591191, 0.04384756711642108, 0.027757960619525086, 0.14059225668109235, 0.09425253276863406, 0.023902525464373253, 0.043514157990894975, 0.04216091729880821, 0.02487943503975628, 0.07977390766984994, 0.025763600095806104, 0.05700476715461381, 0.038363771858595075, 0.02690014324241108, 0.06101702625352529, 0.0549365749071923, 0.03181140460524588, 0.10467174988720687, 0.10630747784049281, 0.08910767779114748, 0.036490656240212346, 0.16014804522837364, 0.05220793442980898, 0.0245645537506789, 0.03441817773085448, 0.13950520856005533, 0.050249514921057614, 0.05829860921949149, 0.07898757204173074, 0.038563046649458914, 0.0953207198049753, 0.03136582680106644, 0.09562694813094794, 0.009571822367668634, 0.04404686105948302, 0.02373186022704167, 0.048406701910519795, 0.025578854162426248, 0.030880983160328, 0.033497726920271115, 0.0132228767559413, 0.10673249576000438, 0.05382277499583941, 0.031005384347912286, 0.013156008771470478, 0.05970499343088558, 0.03588403334781047, 0.014914193006622938, 0.08728487882763149, 0.011766200787538003, 0.060857568882525935, 0.027087038052418543, 0.028964089447512265, 0.08569686283026973, 0.05783833210326492, 0.019289191864851504, 0.021764841381340258, 0.024123965094106335, 0.016986272192650267, 0.06029185125484102, 0.08161284044505128, 0.03189196066570378, 0.016863274861187223, 0.01142528591557376, 0.024304595220112996, 0.011749636051395248, 0.02516431058005941, 0.051463021175755616, 0.0337517042193682, 0.059466387685989185, 0.03536919928005627, 0.02042818074715474, 0.06958137596807173, 0.07204964231219023, 0.054010466537288124, 0.02458671475910852, 0.024866819486863194, 0.07055087555800715, 0.046781021200360796, 0.015006660776693496, 0.07778555710589694, 0.03822161658336559, 0.07787873638012717, 0.018512658331723466, 0.07351165982864558, 0.04860682705897958, 0.009926340088338382, 0.03327381474176242, 0.020469840608477112, 0.06556086227177613, 0.021743082569070885, 0.035068831526704376, 0.027258419581959327, 0.032448481407857714, 0.06883110775942765, 0.15720407658767316, 0.10695476851035511, 0.12478884339572922, 0.1493337948716456, 0.08095356049917399, 0.1617440974880611, 0.18603302237968292, 0.1682795935700978, 0.1689383219326696, 0.15803894388579554, 0.14898516357906405, 0.19117973895082552, 0.24283379947225897, 0.12702417304559102, 0.22564719911784897, 0.24296539805589185, 0.19516882005958788, 0.11055028726977688, 0.1396912147080706, 0.10889962826284671, 0.2837153001418037, 0.11899492808527525, 0.20386010288230835, 0.15943144658400168, 0.18796590817791803, 0.12737842742353678, 0.11129968213818728, 0.13270859906990684, 0.17739337388305895, 0.13158433439750827, 0.11889352868761748, 0.1836808873040061, 0.1501238153826806, 0.14607010709662593, 0.10585740118497804, 0.16370704457644494, 0.09993390976301125, 0.10060686437833695, 0.07659144053656249, 0.09401489229452226, 0.07418679013367623, 0.2937162715581156, 0.13628901823634101, 0.1664493482319578, 0.1113752107466421, 0.18519493751227858, 0.23031183188000035, 0.1778713054955006, 0.12666434154755649, 0.09449404964764273, 0.08502124222896754, 0.09004531578431207, 0.11794920274687391, 0.15496918360792822, 0.06711161575250088, 0.1271887746970019, 0.10855215376303082, 0.13853992245370342, 0.21282054303634554, 0.28873449371707055, 0.2330960099014544, 0.14048356412639543, 0.2639866361935293, 0.22369114682078364, 0.32580766406270767, 0.138816143115682, 0.17149872567144134, 0.14973600635365134, 0.20657013891445053, 0.278805565209158, 0.1694278827598018, 0.13827798167063346, 0.21675477224972942, 0.3548119060935513, 0.29602109304358887, 0.1212673900168269, 0.1520609453080162, 0.23769583162521166, 0.13478195474993798, 0.2631850937201131, 0.14309017828875972, 0.18529011627599118, 0.1482208376570094, 0.3206203295098197, 0.42624381340799794, 0.27227564624721007, 0.18412699562407311, 0.1500470686944262, 0.1689744353174202, 0.07712970923392043, 0.1445142744529632, 0.09930302869648704, 0.18375325196933362, 0.09629458609607913, 0.12238004845717262, 0.257666809183936, 0.17870980405038406, 0.19319884028405915, 0.21096472568329305, 0.2820843908815615, 0.35411804493877197, 0.37037973202043967, 0.399154331535101, 0.11574659271225815, 0.16767067624436272, 0.1151566896888037, 0.22383739300552877, 0.1754045636663514, 0.12343367982295253, 0.2013957818909999, 0.24021004026214923, 0.17064098298789995, 0.18086733747153513, 0.2535972275560902, 0.1388840644710487, 0.24887222706550555, 0.21991038034039162, 0.24793600633500085, 0.12432096285685418, 0.16220987894602362, 0.08033727340760731, 0.2110486735980357, 0.17070047737609956, 0.17554748502950515, 0.17189411897092097, 0.1284538922951587, 0.23781285921652473, 0.11884858230909995, 0.11782203215144335, 0.15062171124642895, 0.16479208554712035, 0.15036078169941902, 0.14912218606520086, 0.20279147151497104, 0.19493038285403483, 0.1242413969650384, 0.15095105244507714, 0.09547608243601938, 0.15752093055315558, 0.17881105023045696, 0.12688540387898684, 0.30650754969927574, 0.16464790779977076, 0.11630485630443982, 0.20135885645304957, 0.11510166159320263, 0.08853165628088099, 0.14217367666142602, 0.10367821045820752, 0.13102194925229396, 0.17434987509923597, 0.11318762155790484, 0.20458237057731998, 0.1251748291354987, 0.15555274342336964, 0.16460154415859332, 0.12575543185155239, 0.14852957109049444, 0.20691797347559085, 0.07776416027017179, 0.1271309657022357, 0.15309389229984055, 0.1600021054787982, 0.18791556087953432, 0.11771477218116484, 0.34435085291343354, 0.13827606645082274, 0.14043816575600257, 0.08357909703326803, 0.11897220591744108, 0.18206192901538265, 0.07612367491087607, 0.12863625952553365, 0.17846488574099156, 0.20553734514021105, 0.1723583222877595], [0.02439498976473847, 0.023951246741137678, 0.08417428606340001, 0.08950769060081051, 0.06831202956457293, 0.059866829504889835, 0.0177046385849075, 0.06832970321298608, 0.01958632481194312, 0.047954380617386876, 0.0434516107423171, 0.01907616388052702, 0.010186819558692797, 0.0759568056392093, 0.017254550438073855, 0.060898730786697525, 0.016945960646074627, 0.013316544411223263, 0.03477291091375294, 0.03673203905383426, 0.005642446800090012, 0.05915947754176394, 0.02871997170000067, 0.04458562771399175, 0.02693262345518076, 0.0854986988668961, 0.017572455859232335, 0.08069378008405048, 0.06964585758865842, 0.013395852705974494, 0.015951636934562797, 0.0083248600957074, 0.07453334532798299, 0.035798361735238184, 0.040834363279563766, 0.05979695462531621, 0.0910018761492064, 0.09419075543842009, 0.03748593468879981, 0.05144135237881734, 0.043059795073443846, 0.09900260731698045, 0.03567918526729749, 0.019456932561532147, 0.03128349341662421, 0.020193133480666627, 0.044057559477345604, 0.01880370471025667, 0.0531782039381083, 0.05251151592200322, 0.027828072986355232, 0.02247287707793857, 0.023794727317327936, 0.005719012978877272, 0.04242154424108806, 0.08048005687493472, 0.023317469862259688, 0.018459754214892467, 0.10225163983000864, 0.034855989318701534, 0.010061176351061272, 0.032371481910588286, 0.02838117123070744, 0.07310988501675668, 0.0727537307407587, 0.055525769299316796, 0.025101585216039134, 0.04938096273690463, 0.07265251520420275, 0.05560150475151116, 0.05727409302527386, 0.037694096099585295, 0.09876692036707556, 0.0630837131381756, 0.09544936895009973, 0.10020542664513474, 0.08372222524016135, 0.07895018695102585, 0.03664139936107301, 0.04330962017599133, 0.12933632599249964, 0.20633320324122909, 0.021833276015616233, 0.13050539148671012, 0.08718357902140388, 0.08926837239414455, 0.12252915981075457, 0.09686892987379143, 0.09533347516891458, 0.036129212127097195, 0.0255029616622074, 0.012098050924138197, 0.09229078843829133, 0.08539353031665088, 0.03955461340205323, 0.04962492726683136, 0.01957557276792584, 0.03853592713693938, 0.08961632186847349, 0.040164021024059866, 0.056421149882578084, 0.09360007100528286, 0.05061862374385519, 0.055334247318246675, 0.02505659095702633, 0.017649292562817855, 0.037531095571936145, 0.056315502527380185, 0.041983158087297794, 0.04121261153129801, 0.015519620801862932, 0.02462134001806619, 0.022556834568780278, 0.08291976346123604, 0.02800650444001921, 0.08802231506354387, 0.05801302696307821, 0.07501148378416415, 0.08092904568559701, 0.0456781380419289, 0.07571347313182009, 0.11670229505867728, 0.07560471929008923, 0.054408548805381984, 0.02543822148694627, 0.024503314597231728, 0.024978896234965613, 0.01941009777628126, 0.023308805407836072, 0.026389892295663877, 0.062092115742064295, 0.043679567865065994, 0.0165450572591996, 0.04541655732018333, 0.01400196998034634, 0.03009165595886448, 0.018495342829414917, 0.029893482419391795, 0.024880432869277658, 0.03692937947268929, 0.010621780341851616, 0.049013332463800914, 0.010712940016791466, 0.02772199853713955, 0.021832619095221165, 0.04713187797836239, 0.050198229164966655, 0.01435022014418557, 0.03416762867521855, 0.04479440965599591, 0.03314076059107338, 0.04210013971333543, 0.10622200541078083, 0.02997999289824117, 0.05705080903886307, 0.05443843772574779, 0.012704111699525629, 0.05815382626268172, 0.0369778115512623, 0.07542700987429389, 0.03062105718849888, 0.07038176930960148, 0.025127787338269335, 0.030707240164760622, 0.018338940234013626, 0.016499325640559677, 0.04243745971771498, 0.10618413768468365, 0.06425537184000978, 0.05187455594779984, 0.054091089630439404, 0.08649699570190522, 0.04224245203658939, 0.06046333237581196, 0.07864798824753493, 0.04465637593379906, 0.022504211989261454, 0.011238666897219037, 0.0630372001098529, 0.03306142069519528, 0.019001014485594728, 0.022808856428450635, 0.008291088067175401, 0.01692919481185175, 0.02312775393347106, 0.01685791224571726, 0.03602497054324035, 0.025517304743369742, 0.026402691709658793, 0.07019777797282704, 0.02718276839943663, 0.056246290313861066, 0.03974379115407506, 0.01748121287223072, 0.03040224332512627, 0.05463005163736882, 0.03403927447394498, 0.09456696589627574, 0.05743415943617302, 0.07044235920353283, 0.0882919090649774, 0.0851911528696937, 0.05359995449262281, 0.025353834986866965, 0.017184045451182513, 0.02898171904586977, 0.04741480190967841, 0.07970756445560725, 0.16358473097845433, 0.06132610442657625, 0.04451405211922623, 0.035262670923745444, 0.026650325800742836, 0.07173331694737559, 0.055979775985883135, 0.05732793751503191, 0.017736176509530317, 0.06237674421901184, 0.09530932041666201, 0.013648932724590264, 0.07408729063407068, 0.03681937307720223, 0.03279530856337759, 0.04706801688899437, 0.006636527278685883, 0.03097838357902102, 0.11012934493802248, 0.0534797016711485, 0.009800190305066927, 0.019165076045019012, 0.009539046253438198, 0.09910841172020282, 0.044586037571031245, 0.04101768811984409, 0.010487942866260007, 0.04321816076915111, 0.04121893175667332, 0.12672239569045846, 0.016184497977636995, 0.04782833234076539, 0.05940244615738911, 0.05685082561666927, 0.0559575058099243, 0.05435983327427699, 0.041454710637129126, 0.0551739280983325, 0.03495550414006557, 0.031149451012512853, 0.0796047171517726, 0.05360425990675727, 0.1047411957575429, 0.05104834161278221, 0.17917990624423952, 0.010646918559476975, 0.004315996202715343, 0.0859507290466178, 0.11153184508364047, 0.025799600482587854, 0.03357631604998343, 0.04894998465334216, 0.10042045986460102, 0.1264923548085555, 0.07481262268077943, 0.006489787446034532, 0.07114791086003666, 0.025608612847844922, 0.04074197307589554, 0.06818937122701638, 0.058690670036500504, 0.05535619956771693, 0.04372245346706721, 0.006876113616125359, 0.02708189568722681, 0.09206954990663836, 0.07682638438118082, 0.1159649660750743, 0.01263147794581469, 0.14299506081208108, 0.09436658793880094, 0.050396569328562874, 0.03848107141112128, 0.021995418524790197, 0.04535201824300232, 0.0343167745027571, 0.04605447873473168, 0.040735530276452346, 0.007482894992966566, 0.04686829776713445, 0.03411397570744157, 0.03236612695599756, 0.049244196890222455, 0.03352977620858339, 0.05783752771094442, 0.03716051969076357, 0.043343067574765415, 0.06048012502311219, 0.0092302113133032, 0.10311361131889206, 0.03645312176236222, 0.022780202824862737, 0.039627077658810926, 0.027776687638834122, 0.08911048933382958, 0.06400476532777952, 0.056352627148190816, 0.016577240612898624, 0.01902552738395189, 0.022323202649732272, 0.04644545553732784, 0.026624269235218247, 0.05472077943024136, 0.03940338764580027, 0.05116152727315503, 0.029626046870684916, 0.06460076258067163, 0.05827679103540798, 0.05861842794524086, 0.01905556760668274, 0.05168223340484885, 0.044015635315689354, 0.04564272562762903, 0.0043774421999020685, 0.038825110006596775, 0.03982164483938006, 0.03256557411664436, 0.02297084380481993, 0.07098151656288294, 0.057004273027902654, 0.04490406748147742, 0.07735580476301332, 0.03310372023993442, 0.0400487860784896, 0.014208142435358418, 0.037042166767341476, 0.035072106552580674, 0.04872633294472772, 0.059509763584261945, 0.02515986535487877, 0.038429908229098204, 0.09208219801826824, 0.03845649531051036, 0.027593651996745218, 0.03166946000419557, 0.09437004299533945, 0.011849897808485456, 0.062490358888622255, 0.014152135662434083, 0.019799515589951508, 0.031424537864363486, 0.05238363286480308, 0.02409258996316743, 0.060432424558506864, 0.13835791528465288, 0.13416278716777602, 0.20656667619703278, 0.26073554290398476, 0.12001493585205848, 0.15319172172777115, 0.12658886656525636, 0.1445222570891342, 0.14723060772784297, 0.1243190169935265, 0.14762629214073383, 0.09399479780826839, 0.07795572821651736, 0.1361675473350671, 0.10036114167662398, 0.10898218189756717, 0.10783241415816931, 0.13888709817922887, 0.1885064751390488, 0.10608935728669168, 0.08747521337241897, 0.1732378678336259, 0.15977151301358977, 0.1879729715085799, 0.1591683260255283, 0.16904402674446184, 0.14742015320206844, 0.13659939109798402, 0.14551409580294164, 0.0907067867416528, 0.0731917874767415, 0.20116649177526275, 0.18835186327417053, 0.10156645079053218, 0.20104160412184655, 0.15237709447260828, 0.19068098506860195, 0.2554854044630643, 0.1315228481807055, 0.1632345521882657, 0.18459838484564137, 0.2626920088885292, 0.16790603377646016, 0.12868695922436255, 0.16672316337785414, 0.10381946174968636, 0.12039339094753228, 0.09525324278060468, 0.125686637155952, 0.0848381472150645, 0.16014190120322092, 0.1005386136051628, 0.12171001263683844, 0.13022904825066367, 0.1541079475634521, 0.17363825602637184, 0.16357654915942302, 0.21741907773239, 0.1931957146453281, 0.15374871361399853, 0.16677438401647154, 0.19955003093327248, 0.15867115028442877, 0.13635959025592576, 0.17979020252823832, 0.15602362702690786, 0.13075190325898509, 0.18061235276681764, 0.13757983042347816, 0.10971598687671846, 0.16587957799915345, 0.11026871165320759, 0.293451787363137, 0.2473328040251809, 0.2024864765905565, 0.18397831327972874, 0.28577429933413384, 0.13323686265897366, 0.11023528723707123, 0.17580121335002685, 0.1992037745132562, 0.26844600335724894, 0.18065041201489587, 0.21333930713515128, 0.2728044307760654, 0.22066448664953633, 0.18808072943600918, 0.17303483921193308, 0.15010066420560883, 0.08256580785758073, 0.17089679506757569, 0.1030232206047062, 0.1281543442558858, 0.23099528956076792, 0.14054581643112246, 0.08061550888082675, 0.2078780655058161, 0.18986762951939337, 0.2154376526032725, 0.2005775693443514, 0.13435558085480045, 0.3393809954004903, 0.2620472999349717, 0.2044129425719861, 0.11577624031492781, 0.08517981476841435, 0.07984875446005214, 0.13907926367415538, 0.2637997720270388, 0.19159794634869023, 0.14617538289918056, 0.14863930552476837, 0.08499501903931941, 0.20477001615349325, 0.1786974853565616, 0.23162145918655783, 0.154745853656242, 0.11223795598432904, 0.18059678586019626, 0.1654656760154232, 0.21019845389791075, 0.21589614090419587, 0.14974080206405732, 0.1248395967207128, 0.16612360764655376, 0.09850609807237502, 0.1403719910811032, 0.12214911125239827, 0.19041239464234924, 0.14936399405762074, 0.08094410697418837, 0.12482743124447523, 0.16376146746258582, 0.1289383739593529, 0.13000110644967328, 0.12391099856505472, 0.12810634118655037, 0.17825134639297763, 0.12991361920872044, 0.22962230678287246, 0.1082329708902586, 0.12062491804000833, 0.0847521691673225, 0.09925359304273322, 0.14705175684104044, 0.11420194495228991, 0.16170165621705596, 0.11373374265648666, 0.074142579199566, 0.1088831420507162, 0.17965759270854537, 0.09582426173672562, 0.2668192309717978, 0.17781020232265998, 0.163283750354763, 0.21304664622631767, 0.1324391353034204, 0.11619118417823508, 0.13808777736079308, 0.19977426486870936, 0.13850649037668783, 0.10041092206994373, 0.11510805076649112, 0.1720302681168241, 0.12532773262430585, 0.11289680692096872, 0.15817483256180442, 0.15047675208939662, 0.1494292034617355, 0.18524582107220927, 0.07620125663496795, 0.16336057365180987, 0.2259652022152178, 0.13031305745244026, 0.1622715337021697, 0.14125371231667458], [0.019568428998031927, 0.02901384302775466, 0.039782815672937906, 0.011688786645179555, 0.04033256036740157, 0.03218876227976815, 0.012412624820435961, 0.04950525284173989, 0.02275392983949954, 0.02593296681410603, 0.020137538480001594, 0.03284575928363108, 0.021382676505093134, 0.06649238688330497, 0.028421203155190717, 0.00381233983658134, 0.04026132185132273, 0.058731893227706035, 0.03428985034265826, 0.05555394218273221, 0.04043195261469772, 0.01583255814283245, 0.028677857931583162, 0.00779801281169057, 0.03752587851317179, 0.09795407809677625, 0.017409909238678314, 0.0375238943454479, 0.04703344334097159, 0.0807893189090875, 0.002642783327891882, 0.017032547733716426, 0.023298539829650716, 0.03611982371958514, 0.023675707897411722, 0.05247384354832673, 0.0488077987345957, 0.09152168212758918, 0.03923409753629277, 0.032376220164399956, 0.1071370131666622, 0.03377178721430321, 0.025013925605303338, 0.045856111758058114, 0.038480833923864755, 0.047414081787029584, 0.030766675181146112, 0.055042854284927736, 0.05509468013300531, 0.021276582903679342, 0.038361665116803306, 0.068136005542211, 0.04750673246059207, 0.016818121638930133, 0.0256302471708266, 0.03506711932019361, 0.03268272045158571, 0.01106611995642344, 0.046228139375847195, 0.026400981418367837, 0.008615499490030832, 0.12151643754013124, 0.1084358003290911, 0.03375139395375887, 0.010661361232069472, 0.05866220987011349, 0.043762516035067464, 0.05761434714640341, 0.04768816506369941, 0.08311025888448761, 0.08061144861482805, 0.03413965497466345, 0.0883201853702626, 0.08513845368138245, 0.07795071034061332, 0.04347766156218225, 0.060617220287601796, 0.07872543207580045, 0.007529898796365747, 0.05514333437707636, 0.04407596857016606, 0.038616067594698364, 0.04511334355019274, 0.08143983480911102, 0.1602662372733316, 0.08499533313536838, 0.04654723797894774, 0.010601747142631682, 0.020850852522398197, 0.060383839262349, 0.047436060849577195, 0.03298598401729138, 0.06067119118186736, 0.041174395235195275, 0.037125758451199344, 0.07607787051388333, 0.0020258041237661197, 0.08840549692151048, 0.0737615270660289, 0.06429323956610696, 0.08435187290512747, 0.010381024762717708, 0.13247016186435379, 0.02607759272289132, 0.01610561964973327, 0.013087458266395957, 0.01569003993344884, 0.025149555726637764, 0.05894465499647683, 0.0303283867035662, 0.029877118781329166, 0.024799030281663425, 0.017143109542948586, 0.019450426559835192, 0.04879996931600956, 0.054642167317891316, 0.0797560041950595, 0.047294005165777864, 0.06738954479055059, 0.10764075428127282, 0.04372472108732309, 0.03770472556953469, 0.05389718128548515, 0.05034751671877119, 0.04115178415011014, 0.04306585865936453, 0.053415836751340866, 0.03396601731618566, 0.008508201215356108, 0.03754703786164042, 0.07266854942445794, 0.006661043049872763, 0.02330243155630606, 0.030865040870623726, 0.035772280271856055, 0.037947977637691845, 0.044052871019249006, 0.03175835110126965, 0.028912748150046796, 0.05574863576780885, 0.00760775966374504, 0.014871945172818679, 0.05961020154157474, 0.052354291697303136, 0.051138150100145614, 0.024257938550304503, 0.007203693291352641, 0.03787449065355524, 0.03846104970322021, 0.07089511716678258, 0.07360089375006576, 0.039283272720152335, 0.052452917856675, 0.04358053567909426, 0.0800582871682221, 0.043857966759993185, 0.04732110935653891, 0.045083898960823016, 0.036596341899806456, 0.010449654749414374, 0.05133558244955155, 0.02584815322000894, 0.018598814494907856, 0.04474507742411187, 0.0702394531559079, 0.024995030046650962, 0.06673770355841806, 0.06968822991175037, 0.008704563914497775, 0.06945124827325344, 0.05947461930073558, 0.006366532038701999, 0.009049936460571424, 0.020536787116960175, 0.11065846654556452, 0.04786002922863249, 0.03039134380918357, 0.04313362296670676, 0.035587139803195195, 0.041767937176290064, 0.03805648250084731, 0.15944299918989982, 0.06782933288524229, 0.05206576383282101, 0.017705446807667613, 0.027665738955200202, 0.012045413980470791, 0.01440001202882418, 0.023367589249485926, 0.08434576718437095, 0.08185172198160041, 0.06311765849410046, 0.024519314343530326, 0.028798976432411905, 0.05482864077954043, 0.051613116952320265, 0.04988316784522707, 0.03852960308112445, 0.014706114907899212, 0.029237870119452, 0.03530174906876299, 0.02068927308784858, 0.03379676168063476, 0.0666404563573099, 0.018963556616537033, 0.025105731666929303, 0.052365706407374916, 0.02955532163351534, 0.0145257260995887, 0.056001885283377864, 0.050885214680625554, 0.038890710115552916, 0.02470033325915856, 0.05025868499351125, 0.02656058626129262, 0.042858367575512785, 0.022906940580616077, 0.01969042849997359, 0.030064381313540285, 0.03335802312639933, 0.014565716846846046, 0.08293751371844162, 0.04591093684035925, 0.026892852000591737, 0.06010460021394876, 0.06178507536289193, 0.01865763472573411, 0.0564571981498551, 0.04063387806977957, 0.041614857487260334, 0.04260714053206387, 0.06202050184290256, 0.05933548624236738, 0.017071168141199217, 0.029362688824955015, 0.05284572943984982, 0.0373447063799587, 0.03878744529379952, 0.0026761182075020888, 0.02451929519133222, 0.0316392186833846, 0.05718983867536149, 0.07059768353018069, 0.06215500006932886, 0.01682512559777787, 0.06769513726354608, 0.0339567897871377, 0.03821017122977684, 0.06870983604101405, 0.04263940815543456, 0.028033551174185933, 0.050403138532513575, 0.07249884562747133, 0.06359636768578522, 0.0973183936589668, 0.06508902105833254, 0.033076022331032066, 0.051485831443701065, 0.05688758251527625, 0.030970659497524464, 0.029647053001568686, 0.06458905675718862, 0.04428154443420711, 0.010793984458301096, 0.020522181650683768, 0.04986246048863377, 0.0777659682376731, 0.03706975359349482, 0.013139793562943177, 0.048095482521720474, 0.054924811627114975, 0.045408134183455864, 0.03334000856885987, 0.0722493154687747, 0.11796132991871527, 0.029677391998590003, 0.10098420864632053, 0.07506769931604786, 0.011264107719574486, 0.05338821545123093, 0.021666653807305043, 0.01734224835320586, 0.006249308137358317, 0.04499946841068807, 0.05560499811244588, 0.05477556237770666, 0.09067084189624557, 0.01267212944390673, 0.028445539853325295, 0.0641888524255445, 0.05731509788142097, 0.08566497058998193, 0.03411017591133714, 0.04395025737223126, 0.02257191500956974, 0.011690975741423186, 0.08507811659646612, 0.1007336595906846, 0.023512027466729767, 0.0467993843279058, 0.015627197741020112, 0.022621965448882793, 0.055376217445178386, 0.06153006767553668, 0.049741391783520106, 0.027083623215496063, 0.05062255377490675, 0.030798502303960345, 0.08321289934458272, 0.05907613483648147, 0.03217271273775447, 0.004156609216044027, 0.029250726990041234, 0.019001749930002036, 0.04045449475186967, 0.008604026365754826, 0.01709184868471517, 0.01774894336478845, 0.07089758396989877, 0.07995476570701407, 0.034542161400520036, 0.05001018905351239, 0.028125878175600406, 0.03678940371760438, 0.021580654692145127, 0.045053171174180125, 0.06827802292161411, 0.06734617655315707, 0.039485167531717213, 0.12648333795368671, 0.033958743311344616, 0.08989717736239396, 0.051771601391655785, 0.024394943799463012, 0.05756840868402393, 0.04271043599733422, 0.01958736860673995, 0.022635599898715174, 0.049073374604866396, 0.03111418032447898, 0.057214430097730896, 0.05999628687277437, 0.048362092610688946, 0.033325874246656895, 0.09287204998995989, 0.03803683617602914, 0.04161180462688208, 0.006099192729790605, 0.03803857519561726, 0.03794779760702964, 0.05667575154333346, 0.03265015022348493, 0.11895972634515456, 0.11228952136251236, 0.10763208216596996, 0.07251724705941255, 0.11786346218638843, 0.2690325202720781, 0.15731854544531915, 0.15907933725224388, 0.17024704525547643, 0.1308554170593139, 0.1160956530140773, 0.12113671839958239, 0.09925028354290033, 0.14561872809163987, 0.24917552127472817, 0.09251281604050629, 0.052969893140177575, 0.1217875560565341, 0.11862184326615065, 0.18213185752111097, 0.11583632459082913, 0.2757035832731955, 0.09824221142597737, 0.09054374790960744, 0.11429146232624209, 0.1630924275565532, 0.11766208831461207, 0.19916344764492205, 0.08894575744747155, 0.1807106571692613, 0.14870750267178784, 0.14238361539619585, 0.1767461828046268, 0.11007809365588812, 0.055928773682324164, 0.218996973708272, 0.1667484442793554, 0.3028711141838182, 0.09188673834526732, 0.12707202289734157, 0.18343327236512016, 0.19364323256717575, 0.11433231779524397, 0.09918964002281429, 0.11985006606987408, 0.1131038191998678, 0.15476506714138294, 0.14508758401197774, 0.16587836758023308, 0.12597040378398475, 0.19819391741146966, 0.16722666700520825, 0.12003856966452253, 0.151816823730065, 0.12713480380273637, 0.1299509123688744, 0.3541170337027119, 0.09324988455421503, 0.10722878283911175, 0.0844373913001149, 0.15196080229455425, 0.13766025433376913, 0.316301616088998, 0.10769185234582233, 0.20209214049241236, 0.201651195604955, 0.15559873934234345, 0.14377017325210956, 0.09795746420540156, 0.1859843911182496, 0.15461492922998246, 0.23079564704770045, 0.317150104430414, 0.1956294227631823, 0.17112021694981283, 0.14048406974442545, 0.17083615154748963, 0.1919108932657588, 0.23466365562090952, 0.16456552270439365, 0.10017967076912042, 0.1422348104777836, 0.25361569027506536, 0.15003265091969123, 0.2803693038801993, 0.24462793142564837, 0.15953443944454193, 0.0867219957252664, 0.13422762884968711, 0.07692350900822109, 0.1573796026528843, 0.14000855896982456, 0.10912377026773269, 0.10074918053203052, 0.11481960334124104, 0.10346919868982608, 0.08057977087915906, 0.11224556323741713, 0.3932980183632143, 0.20767857621033348, 0.15773290708180399, 0.19283991276977525, 0.31376258620331365, 0.1205138429518669, 0.10587596349538335, 0.08517898739345613, 0.13515733783283543, 0.13681421747371075, 0.13700734823942184, 0.2647660540476922, 0.15538032767513107, 0.12685960203769708, 0.1379203871493378, 0.13288210266299788, 0.20970495537884776, 0.11436147510164207, 0.09041426372864554, 0.22414968108698247, 0.1256438434845017, 0.12661157341133203, 0.13439892610955623, 0.19319902414516096, 0.0986691905305751, 0.2071390511287797, 0.14333334991768484, 0.08884422781486666, 0.10190519188801128, 0.15637394371292285, 0.11334923546641104, 0.16436733575838228, 0.1939881559942038, 0.10687160200529522, 0.18741694489313712, 0.1652352520895581, 0.1399960717366588, 0.10169762802580673, 0.13101122402135404, 0.1533581926337173, 0.14540123572993666, 0.1304777357126436, 0.12560985216330137, 0.14057371735332475, 0.23832348746157464, 0.1293420103648978, 0.11353072169567309, 0.2729636544902479, 0.1383313626771973, 0.13496086692377446, 0.1392640747250088, 0.16909446597339647, 0.15155307497949372, 0.1458880692840584, 0.09538371521498888, 0.21898528320654748, 0.13563465657493762, 0.17374310281968888, 0.13739088249783363, 0.11456910025088057, 0.08546822388926822, 0.12509190011769533, 0.06934018084599126, 0.13595282821164978, 0.15542859121436076, 0.12880715841968216, 0.212028423444398, 0.1042416298221196, 0.1739849567773842, 0.17503085065512888, 0.1642134899814283, 0.16107507290378695, 0.13155652540585688, 0.130068997161523, 0.11800843666517928, 0.12180934359710063, 0.24038670013748833, 0.13197986559281427], [0.029886361632135608, 0.03804420977230034, 0.05321535537199629, 0.02380203579612557, 0.06605701145505713, 0.04426759014266633, 0.019267120871752984, 0.029311914432553515, 0.057504605051250234, 0.08585240932241564, 0.006450908962682251, 0.07385353422573498, 0.060845997124429674, 0.0463005155324936, 0.04201036953036824, 0.004799385234007552, 0.026915237089739214, 0.06415030671163433, 0.0472762395868138, 0.035397471754901835, 0.0331593765276334, 0.07702543700654661, 0.028912340208227118, 0.058203522386329795, 0.05312622870288549, 0.01662997044472685, 0.060506455465069706, 0.03784236858689016, 0.02068987063642952, 0.028557396351149487, 0.019108479384392984, 0.09415572989852199, 0.0557468546133849, 0.06369060033091134, 0.0229150879256908, 0.05811947104971736, 0.008210820247299008, 0.05021465792050285, 0.011510292946871732, 0.09489097512297093, 0.06314206222492842, 0.051653711951427886, 0.04263315687797243, 0.03150712214260092, 0.02123888754736512, 0.04265674855560065, 0.037368493410007614, 0.03198939938879302, 0.10423485760486896, 0.027579019717391462, 0.042935562425202904, 0.04325794371505899, 0.043393518295018904, 0.05184558633294317, 0.03587889672827817, 0.036249043600213145, 0.025481197104278593, 0.02430900597133704, 0.01356005599166477, 0.012520340613029417, 0.02189026721152327, 0.05934405110536083, 0.00538449302586096, 0.03143675888197557, 0.040242851471468326, 0.07124623824511805, 0.018757097836163257, 0.057373297581028555, 0.020082180966593085, 0.04088020215051309, 0.0799028862327818, 0.08263606578111649, 0.04145068101464741, 0.03601627927573939, 0.006051573662027236, 0.020176691318591757, 0.018958879649759303, 0.05158359958459774, 0.007597842176760277, 0.055141920944856065, 0.01657946801353847, 0.08603440883058695, 0.05246400314893934, 0.05157770836846002, 0.10965749606369965, 0.03301332186486933, 0.07550220906494126, 0.029080776129699046, 0.024627181438488827, 0.05962424010278718, 0.0751565118891097, 0.03324013751661105, 0.06438662568407674, 0.03944325103094021, 0.07629717850396711, 0.03768121816157814, 0.01525900247807224, 0.058258673055998744, 0.0637653475296834, 0.09236545902827094, 0.06715527510330563, 0.03283055243833411, 0.054610432125628, 0.02079923160284037, 0.01953307595554619, 0.05912895659886061, 0.03217365885634096, 0.04549669011706307, 0.07399366702884436, 0.0770589916576301, 0.04771797737527279, 0.033944337027928526, 0.020688030110191435, 0.021795279969791734, 0.03275997658830977, 0.012957594871911551, 0.09837079162318861, 0.04379679463923939, 0.02335170250115616, 0.029637245160918084, 0.0212209151246615, 0.03796116967174796, 0.019875329566158114, 0.05930257127470067, 0.05967931799410332, 0.022442788974712455, 0.08544052214992624, 0.05552072844077503, 0.016231867109215068, 0.06316669195169403, 0.054306689754969655, 0.060815855395048864, 0.012410572662408794, 0.020548240131428166, 0.09525246137092191, 0.03086947843492512, 0.042230650452115846, 0.01238373851764106, 0.07860043717007484, 0.044308832486069975, 0.04735994618386031, 0.025137809683538737, 0.01741300997955184, 0.03444007635417004, 0.04866415341835349, 0.025567184728119644, 0.06833490494999193, 0.09200385020625207, 0.018091865387114308, 0.028002786998366638, 0.06990114872854564, 0.028743781712687308, 0.06889000459904633, 0.03233976587052307, 0.019982867243309176, 0.04984447657461128, 0.03502647835581053, 0.03176493371175903, 0.027064266088869304, 0.06280181576467811, 0.07000105425475106, 0.009178675621026948, 0.019685228678187536, 0.01874819972492274, 0.03581281015349012, 0.03572446489406209, 0.022722547047681386, 0.03279302179092362, 0.0699720501659378, 0.07002559205096576, 0.02753028503408836, 0.03017220435844314, 0.018349002798899047, 0.02750037313108483, 0.009378656170391029, 0.07314868737012148, 0.045270157917853326, 0.025144861522881735, 0.0181491170529156, 0.02232038727661054, 0.03983229729196718, 0.01925110963413552, 0.06327547643694185, 0.03245341501409008, 0.032749270509567954, 0.05378316441971449, 0.04983624879030451, 0.04056293449755158, 0.050905933528537714, 0.07612897623931209, 0.023999251725692904, 0.08391419155222755, 0.05215652609965013, 0.034405035492513454, 0.06986833718274871, 0.03216718541338079, 0.020866517105229923, 0.04015465176874592, 0.03279871765464064, 0.11832049492025569, 0.03305602743620834, 0.07442284480578477, 0.05322916410683144, 0.04279278278831513, 0.02042132426023243, 0.041840320993815704, 0.045303877277840535, 0.037386676506890405, 0.04133208677352917, 0.05284530426105184, 0.0380457955743036, 0.008304828811707276, 0.028173733773010395, 0.08112345581814166, 0.06415913970540128, 0.06082569196399662, 0.028450316411533186, 0.021396209448275548, 0.028518900432954394, 0.04025987777558546, 0.00831747213528762, 0.020450866525812496, 0.03084494255393023, 0.04052567198091457, 0.030941781813218713, 0.020169051506766872, 0.051026255297925205, 0.059678433162550774, 0.05741337164034767, 0.06450239689119401, 0.020269929964636123, 0.04424847624895554, 0.02945944764501145, 0.045389682955799565, 0.044436918556570046, 0.07205302842081555, 0.03261304858531202, 0.07141534449352373, 0.06701207028761988, 0.09737337578929241, 0.07940060068522731, 0.05351249406474733, 0.027305656563370462, 0.04036817196456175, 0.008725834345715422, 0.03990260501121802, 0.051946514586527506, 0.010165395909890292, 0.06373247086641289, 0.044995683936342123, 0.022662960728930853, 0.024816215549024846, 0.04676824668422342, 0.035414042236704024, 0.07224582976871921, 0.0442785183869062, 0.06860155717379625, 0.06136764937470998, 0.03520722147978602, 0.003914888844930477, 0.061422784722620444, 0.057907142120623784, 0.033210516727018746, 0.062084757467551585, 0.04128596061960824, 0.05581039777626434, 0.03795905526907694, 0.03188227539912107, 0.023733997612350413, 0.05501655065604756, 0.04847776039593643, 0.02193932556697438, 0.06340155535708032, 0.0660584210568378, 0.061593480603469, 0.057908149526244214, 0.02858509809049147, 0.07958199498393843, 0.10495494961017564, 0.017538232796434915, 0.008842396538614506, 0.015697062086884775, 0.00971669821263922, 0.05286613036127341, 0.08401681669056417, 0.07901861392442258, 0.042324683914381656, 0.03319766177164932, 0.07216674651229574, 0.015087620948531456, 0.0626065744267356, 0.05488686346178574, 0.07335645041518635, 0.020053366484541087, 0.03882708651344142, 0.06645537717568298, 0.015201849446091202, 0.028889221589892145, 0.020516468549988443, 0.04581663141688032, 0.06521224630095306, 0.036932991577252265, 0.1029142062930811, 0.028619757823405728, 0.03821461837017729, 0.027707055992176457, 0.09574377653940071, 0.12505044710011254, 0.022564947439898408, 0.05489557388148481, 0.07254470365061876, 0.023748177899828842, 0.0565839818708839, 0.03793701874993501, 0.012111863489412974, 0.04865766465363484, 0.0858279021697179, 0.00639922867131029, 0.011057678625107774, 0.03465623955332464, 0.05975260196493999, 0.03555077743986922, 0.050309756244983406, 0.012576090746499118, 0.057057757456336296, 0.05195326765158004, 0.05818047463112782, 0.04061549962047608, 0.07157376381538569, 0.009013261916416307, 0.014283010292978538, 0.03904968485115998, 0.06426481770411616, 0.006932466086225525, 0.01477207316295995, 0.01262654338197242, 0.08938929171211298, 0.04177910290778645, 0.046422913400155884, 0.046772992598914334, 0.02244692967994319, 0.0019019054419796675, 0.046979732916600285, 0.03735591424629092, 0.030714914450542103, 0.004913207226162476, 0.03507461166009307, 0.08881415886383864, 0.028804934681242997, 0.05765512217617324, 0.05277037703161759, 0.03845617355358216, 0.10188599372462881, 0.14628923888648712, 0.09708653714868332, 0.1276871608570218, 0.21612209087658316, 0.084182552152103, 0.19861169580009677, 0.15950462330252896, 0.0949842846321483, 0.1401080891129471, 0.08593327756370268, 0.18506248091017047, 0.2473394077030882, 0.1337158361509923, 0.10977302212268115, 0.20845986331903166, 0.11442901341304665, 0.12689043707664938, 0.17641434415934548, 0.22944416069696028, 0.12814092239545238, 0.12437348584494284, 0.1502456386843997, 0.2304661679532259, 0.1219839426959234, 0.150043529368216, 0.13325026919764857, 0.1632091487126966, 0.06482370182751648, 0.11435471820614992, 0.09985126419773988, 0.2888547695211826, 0.18572125523801775, 0.15225914757578604, 0.13848945258125184, 0.10847820329570002, 0.0752260956552721, 0.1377927569011527, 0.15146479100709961, 0.11843255826181943, 0.15590525112084805, 0.1600510738189182, 0.1256589124339723, 0.231816106806359, 0.05696622527114326, 0.20416299872581037, 0.08501431679413204, 0.10240022258292283, 0.2086126365728917, 0.2272863974494319, 0.12622596305464545, 0.16803893470956435, 0.21145237129061453, 0.17939704620549757, 0.13631324193650676, 0.11756712405551827, 0.11188809129018938, 0.09660531135816729, 0.13454788424555333, 0.21356421522796157, 0.16034745791506383, 0.17630079460720863, 0.15128282980332453, 0.3160873259748182, 0.16185337226958046, 0.19620475479431693, 0.11005956964987902, 0.1091487753775812, 0.19322746132891025, 0.13834289996133697, 0.2311784458617049, 0.1638738219175608, 0.13348505982468206, 0.19129088298688013, 0.1169312404348485, 0.18551320107954164, 0.17913620858903856, 0.25193198223508173, 0.18037151004518234, 0.12550560291856527, 0.15977258553668378, 0.24420869746996512, 0.21150610469762357, 0.11568823213418646, 0.21925405749390203, 0.10215931091337435, 0.13403128051469404, 0.09669364129583682, 0.11987438170059074, 0.15097075622648964, 0.18495472298274118, 0.07196256875871651, 0.13596667908132076, 0.15333062879020168, 0.12861131570271908, 0.17245376152136635, 0.1717794356086562, 0.1876556732121014, 0.22567483957015702, 0.1965000050803346, 0.17728480390242993, 0.14326219567127768, 0.3522886269755902, 0.16145093096119745, 0.15976864784475298, 0.17401544707677058, 0.10669331036267743, 0.18767358434777107, 0.21592267818989294, 0.27112927227731676, 0.23988341101475302, 0.2281554169472187, 0.14877548531418847, 0.10018372337423986, 0.18319721003213238, 0.1731157380967371, 0.19794944343307327, 0.19270923349165148, 0.07270125371794547, 0.17804655576905898, 0.14214306378797179, 0.1456447750810654, 0.08052432143519964, 0.14143527515472906, 0.11260390086399932, 0.13560520815512828, 0.1120561326763803, 0.15368097611973364, 0.12145927972010068, 0.1860566944965432, 0.21361876068817032, 0.2625663704689472, 0.09398017318979388, 0.16497326534121268, 0.18209136211343352, 0.09807218587206257, 0.13918886021260293, 0.13459078516931305, 0.15068612391910247, 0.1305391759641709, 0.23563739933794547, 0.14474655231160505, 0.0776811010174213, 0.08664095894463601, 0.15492910188772988, 0.11279396727801332, 0.2487566243977316, 0.19808139441715134, 0.09537541848276893, 0.08668405139037678, 0.31279820408071246, 0.09570341902754961, 0.1439607299623951, 0.11016256251041928, 0.12171827106466218, 0.1528474418145995, 0.19134602599566986, 0.0908965160769801, 0.11118054780508242, 0.190687864538162, 0.17407275045350676, 0.07528055684580919, 0.11356895714397393, 0.10252666539482533, 0.18592693452392856, 0.1152068378043271, 0.1795739512289724, 0.16018241193265687, 0.19826505633611835, 0.15653126752905308, 0.12344725490097078, 0.12489828671659194, 0.13957850785265047, 0.10511844043409634, 0.17111820979945122, 0.08211232211080291], [0.023091483500695998, 0.04766261986186428, 0.05146876300474809, 0.009626840887170647, 0.02110901074634204, 0.025607492444255663, 0.0352678535085532, 0.009859683735656643, 0.0675818175377865, 0.09261467509091863, 0.034509254093732566, 0.04048237269143424, 0.02495994896537835, 0.05149608936100718, 0.08873814761999155, 0.01716183081659819, 0.08133455134567716, 0.04369803441448077, 0.02632745612983502, 0.05418634883338406, 0.11324916906174153, 0.09320755819639853, 0.06688968774171607, 0.007284300583940481, 0.038502644447069016, 0.06483202154237418, 0.05850068789215819, 0.03506972401913616, 0.0151317456977502, 0.025271873155068007, 0.08599072649714448, 0.017173607503214193, 0.07199557182649452, 0.006363114807754756, 0.04660628037527204, 0.01977679342211735, 0.03535909841077463, 0.007919915116226842, 0.06152396195478017, 0.05253491224721075, 0.0686023539052375, 0.022047723177820448, 0.02132865964555212, 0.009209937753997022, 0.04769240919079992, 0.0442146075018231, 0.012225484862292727, 0.03931309652304457, 0.07953369314031256, 0.01798651872142669, 0.031911610820961576, 0.01806141722256378, 0.029963703953751156, 0.020637983501318003, 0.013125394940406326, 0.05017447660887434, 0.03282741913872381, 0.06099948284005927, 0.04729642217317897, 0.052781033314644336, 0.041103072449444764, 0.03272775876065416, 0.03406329133037118, 0.08840920478706399, 0.013948454908395727, 0.049638073335612015, 0.07976564158114695, 0.04458956540592256, 0.01265380079031832, 0.030570874599018888, 0.032276870051939646, 0.01325069628130164, 0.03617615416465748, 0.1222728574348073, 0.05842204513629118, 0.0369668411721866, 0.010571327706378315, 0.08670852789955755, 0.03701643004352528, 0.036354480281231866, 0.06049749606679525, 0.05983170054312195, 0.0030168116321757196, 0.05948206567535958, 0.03607297744301539, 0.05098320115658064, 0.05005507031455637, 0.05482235885856133, 0.11675186094737823, 0.0350107046054496, 0.003840162713576349, 0.011069276238671474, 0.03911781305026624, 0.012732952994654977, 0.024946919725006147, 0.010252157282534867, 0.04490069286417096, 0.031376869958494945, 0.027167325982102947, 0.041122186343155565, 0.028726184673066583, 0.09833885341762535, 0.013537062820227397, 0.06644310444713601, 0.051947414739838535, 0.06366029772306643, 0.022306411917651855, 0.01952465473403854, 0.024473113496036782, 0.01874265707879057, 0.05949074162110206, 0.0088693666639888, 0.02655044708761477, 0.08062169121037568, 0.05451480520047969, 0.07396753576974716, 0.02531310017671316, 0.04043206752788636, 0.0113047908187934, 0.012686303028115823, 0.023553051475074985, 0.03796660889601035, 0.058913230069822846, 0.06781472358852625, 0.027019082223095243, 0.08488041228584706, 0.02281875428443234, 0.027819605799572125, 0.054713616508149335, 0.02372309426596809, 0.012165679250873867, 0.025716207981590303, 0.02169776846834969, 0.033635729998951, 0.07534125399204993, 0.052731950061335686, 0.020187246094968532, 0.01724465258209215, 0.029449706837054224, 0.06082364650923879, 0.04957168415609387, 0.02367928552801811, 0.04616368456833786, 0.061293346506934014, 0.007619131760176032, 0.02231642660204201, 0.006628899915789765, 0.03663729312979887, 0.09215816329683989, 0.025090668463118138, 0.08886793823612314, 0.043962871009904536, 0.08164555239941805, 0.047852069575099215, 0.04867298641212044, 0.05245631928705881, 0.013776011389469909, 0.012648124078799401, 0.026282946421434323, 0.05245172275951313, 0.029910441690815553, 0.08571343331207192, 0.04971561675530769, 0.005697479683740606, 0.04204362540716126, 0.07668733176204466, 0.028750695656203938, 0.02756065467462665, 0.05928151534810182, 0.04619509034279374, 0.03895488913140951, 0.05270391507374664, 0.014669274697230469, 0.040729493503609014, 0.047053162444142566, 0.019039922176049124, 0.05520615741730698, 0.09090906459717982, 0.025667132389160897, 0.03035679898945795, 0.03908689374164228, 0.04544063929408308, 0.03183691341790461, 0.03828366970523231, 0.03675781791248629, 0.010174094838270498, 0.03944623494340528, 0.07228161373566236, 0.03230459477391935, 0.05616203213350908, 0.012717129448578965, 0.047990486341258215, 0.04074115719225618, 0.012223247885553828, 0.0685567180475881, 0.10224282215800017, 0.027103790480102745, 0.03788413953096156, 0.04980526053376737, 0.030199197466455163, 0.05748968548892487, 0.068862417772893, 0.08099937255704596, 0.048060200342367736, 0.013416894268424762, 0.01565570961834202, 0.1408962556912053, 0.04760141709759351, 0.011164823682197641, 0.018033612061352018, 0.03342822742378039, 0.07437750772242585, 0.06413696145999336, 0.05185324338174636, 0.06357891237243049, 0.014526801495512408, 0.059410758211367556, 0.02172591645390757, 0.06976891429193559, 0.0220255047127965, 0.040436480194330215, 0.025719550040159977, 0.044081388642230344, 0.03278599293421834, 0.05073656681023779, 0.02674891365571849, 0.0444760158537857, 0.04636937917600717, 0.03880142256797802, 0.05184972320773429, 0.04580972896468255, 0.04158445145754565, 0.03141141477822056, 0.03270512469293129, 0.038148872704515537, 0.03483443160451228, 0.07062523971281706, 0.05066935408620104, 0.023567032579693104, 0.04528142324077987, 0.050389620911089644, 0.0344828968386977, 0.008524111903933509, 0.042551258248427225, 0.06480504758656025, 0.02558547124687222, 0.057288859370014364, 0.05609513350552129, 0.022711846714599, 0.03518003301935331, 0.03353048100947373, 0.05371226298232233, 0.0489514057464417, 0.041314803829957406, 0.032199410901915644, 0.04513563287834968, 0.02147980113213341, 0.025590651916460167, 0.06262774143608348, 0.040232210510200074, 0.07590519429575052, 0.03064921091971619, 0.07865753370307146, 0.0354415294714272, 0.08890261137557608, 0.08418886471659907, 0.05036804404470229, 0.08248222766504174, 0.04318243808924191, 0.023938826540665283, 0.04020881801543217, 0.06146762384882858, 0.02384397910997993, 0.027022525788314884, 0.08510222538344323, 0.0071856251076584865, 0.07006020390338476, 0.11034322902560235, 0.024392814075033513, 0.03912848465505146, 0.024962387040197372, 0.0037079998583067213, 0.028780327937115106, 0.03588950704602945, 0.09251010408925434, 0.053892059987711335, 0.020825215390012152, 0.008596401875688425, 0.023698822685307073, 0.06812164905450999, 0.10890108382990284, 0.06749637575159151, 0.03250711777758214, 0.02491939035544713, 0.027791061363513433, 0.03406062151395506, 0.04736468060723236, 0.02344276545749557, 0.08704738391022529, 0.07021457828100651, 0.008431600083807304, 0.011789565511618652, 0.043970095219030496, 0.02742711597332551, 0.033869337020141464, 0.047090765869905876, 0.018940801889966094, 0.0760612923712019, 0.05081987887200329, 0.026444815054175355, 0.011751712149670048, 0.08777513679477476, 0.021882575688763492, 0.05223116221567316, 0.024616333633481015, 0.0506575525017275, 0.04568426674532314, 0.028242020935360945, 0.019545950063113725, 0.059077199698696216, 0.02770310106326736, 0.006156581333808361, 0.028029017848894004, 0.03715113128325151, 0.026684826570412806, 0.027126401565187884, 0.06702116375128109, 0.07774139213706217, 0.06937810985912239, 0.08192901259228107, 0.0700413504795682, 0.005686742961481815, 0.05663316088518309, 0.061219706305212555, 0.02433588608138023, 0.09696025521524491, 0.09418012979891031, 0.04781741941828401, 0.062883515211363, 0.020178895736593875, 0.058394113570571914, 0.08940658997744323, 0.041413119723719936, 0.04533481190822298, 0.04263363951336473, 0.032927604287021586, 0.04955990938469768, 0.0426153798076895, 0.0628002567757522, 0.01726936849374925, 0.07058629180274664, 0.05617283014280181, 0.12659043704550113, 0.16185570117687026, 0.1999864252584596, 0.1410560616322102, 0.12008648846418628, 0.07543467841441594, 0.12897335353397554, 0.18025014639621784, 0.16893331171764484, 0.1491823699325323, 0.16631454740080143, 0.25968808620687456, 0.08569202881546752, 0.13255191876763298, 0.1367014952965321, 0.27015505358576775, 0.10953132904344991, 0.14325096482230773, 0.14467594964850336, 0.23841155692934993, 0.23634557101515033, 0.18269215890717122, 0.18917955998932162, 0.07099740522643251, 0.12616323577540536, 0.11540810442379407, 0.25041787073977534, 0.09479261709437256, 0.10322962001326585, 0.13378199550413317, 0.25382708457689135, 0.10000920088420953, 0.1265592189625867, 0.11385650058547336, 0.09355651890678753, 0.13456429384889143, 0.15841262625350108, 0.15085231903339588, 0.14695644018150147, 0.14962418816022335, 0.26339656463073147, 0.13783889071595284, 0.22597047290013683, 0.1583641328878941, 0.22200428249855197, 0.12457299046218397, 0.20212509759491493, 0.11044518766744484, 0.18025659685654027, 0.11680375574336899, 0.11347292036178613, 0.1559035963709316, 0.18923882455114396, 0.1501510727910265, 0.09235302542125987, 0.1620711404229364, 0.2311407543358303, 0.19201906488066722, 0.08729354328205509, 0.13850146483990455, 0.20207433660905208, 0.11827801534485434, 0.13002995732090167, 0.15262618030030883, 0.13778782329492031, 0.15641909693517994, 0.10734736558891113, 0.1786684353024729, 0.23810936588673826, 0.09921436934101005, 0.0893802595354857, 0.0751359654109805, 0.1453811642263205, 0.32642271009183704, 0.19922562334085667, 0.16487531333921418, 0.14924066922357007, 0.195352895666034, 0.1671592206243546, 0.15985829545365227, 0.1113047153358498, 0.16111322408241613, 0.17566045235481956, 0.191364488714645, 0.14424269628380576, 0.15530233992443931, 0.10483077441852902, 0.17461216828275114, 0.28122851745255534, 0.19441187922512332, 0.15146782471527978, 0.1672024433050425, 0.15842773350736788, 0.19584978029372233, 0.1292249827735847, 0.12502315904824965, 0.1081615255304402, 0.08220189311090978, 0.14398985662527625, 0.13862846689599176, 0.1833310149489872, 0.23125113228396063, 0.11151783333550538, 0.17000908302443643, 0.0856115053137464, 0.15081349369739333, 0.13952701142238033, 0.10093334806902755, 0.18507144413888457, 0.09948053892942206, 0.2141976780107906, 0.1626913652064339, 0.14769358530400262, 0.18700993770072538, 0.19947967341830655, 0.24192952460819678, 0.11416892656275343, 0.11143174803545398, 0.1542767320549296, 0.09913615942482026, 0.09280319400732556, 0.3094947410206641, 0.19970580725179565, 0.1552609252112527, 0.09477284436504688, 0.11873898577065238, 0.23855709831320474, 0.1394763576888269, 0.15634559845972448, 0.06723917705277282, 0.09125548955653945, 0.10974823151745143, 0.13492596395794423, 0.11094355850570625, 0.183587302003176, 0.16105846411758856, 0.16238424055758985, 0.1438542437409201, 0.17683523286494518, 0.1500222474456795, 0.15446684443421904, 0.17823495211139803, 0.11181320619559097, 0.25651665073969676, 0.11937362832888482, 0.10118936699244285, 0.10607934451752132, 0.12667292939318767, 0.19800504609461755, 0.1885810154940813, 0.18471573419388265, 0.11848932537700861, 0.16836924117899713, 0.19762983155106345, 0.14817179270809697, 0.14363287497432004, 0.1783410399671524, 0.13924939648037957, 0.08276202595762669, 0.20764407161022388, 0.19788933617453422, 0.2167874842040962, 0.14137237933614563, 0.09567776274296547, 0.11447868655405699, 0.15245630796397888, 0.1579338979096182, 0.1198289680084394, 0.12789356026558146, 0.1492145303035936, 0.14646163931296718, 0.14275677682411286, 0.10704920416878116, 0.11054630361257062, 0.14692971903470256, 0.10186426747109621], [0.04270886168664983, 0.06567615084350109, 0.040333081307190086, 0.039130916984211055, 0.03213639250926433, 0.015943081647668396, 0.06651204469944201, 0.05121821394911216, 0.04110481146903288, 0.02738893223595956, 0.03882855740225604, 0.025959425575790868, 0.10207800600197046, 0.026996471138010104, 0.03939792926933977, 0.013537590463285246, 0.02576978434057486, 0.07708811832051124, 0.008952274614374244, 0.0031919975064679863, 0.05105562710894212, 0.061325794160966916, 0.013007234496575211, 0.004013670376509488, 0.10497785563911162, 0.052813182194386764, 0.04235094157798637, 0.021643048723138148, 0.05163062972226932, 0.10930447508731198, 0.037672653298584685, 0.053368626583007076, 0.0778707767265939, 0.0877516945042918, 0.10573150995638102, 0.039001256603026585, 0.011389513439949484, 0.0978415321198202, 0.04948539201230292, 0.021218599623910362, 0.034912725790373744, 0.032426988811142025, 0.06673945023888542, 0.05813539418722353, 0.015984418794452664, 0.007491841942312257, 0.005501912279625334, 0.026657664923057444, 0.07644478066433823, 0.04783030884761003, 0.10276442078212578, 0.05610689295515899, 0.06958988720491048, 0.04087467482613941, 0.06218741324940517, 0.06232265841155764, 0.02689389388016876, 0.018307390818071943, 0.017779033383234374, 0.05977858000645234, 0.08669525925670901, 0.03753756518445669, 0.09366292851947008, 0.012866263784798644, 0.05446550744255224, 0.02542612112818226, 0.05156142133918982, 0.015759909067363027, 0.1137525960803032, 0.0365109614006454, 0.02286660988184233, 0.00898748688820389, 0.04864736460149289, 0.00221664811702325, 0.08598092823259293, 0.011262389767404285, 0.04035780296450661, 0.05051830836061028, 0.023128972013270663, 0.015378297689641196, 0.12294002042542543, 0.09209916686579105, 0.03442365142907347, 0.04720487083578783, 0.038555408752853834, 0.02248506362159406, 0.08549823921414153, 0.022782028029342333, 0.018647325097493107, 0.04697169282383496, 0.033331382418832475, 0.05173764071397243, 0.056724788831366654, 0.06328904385408086, 0.08387119869791693, 0.06241592961633879, 0.05403891138191666, 0.046124866893214565, 0.07729981905750691, 0.045624102030189774, 0.09538639652272386, 0.03216831922350872, 0.031066016376679464, 0.04339649837704436, 0.03703835164947856, 0.024536620269739823, 0.0693133754295207, 0.012857381952926518, 0.00828196395999722, 0.023369745786992774, 0.03127205380869489, 0.0468596984301844, 0.049135845244651845, 0.01632514980531508, 0.024176742806429827, 0.08151750080287457, 0.01761494309551293, 0.07075709110546498, 0.07629413713490771, 0.00715461147445885, 0.020958296353778532, 0.02337380222255184, 0.07354717566481522, 0.035779600241972555, 0.023865059934436314, 0.0377260074920712, 0.0084951346281976, 0.03211067302242643, 0.023166196225511453, 0.05168812845142619, 0.02019253976252531, 0.05805792737632029, 0.031562860784751755, 0.07231543651751934, 0.07602939247003487, 0.03172474090881165, 0.029627008311029886, 0.00398404982631966, 0.049335070239800605, 0.07756005912538498, 0.031857764415983716, 0.03561136733380056, 0.005042557820542566, 0.05605369197925734, 0.024218400752532388, 0.06430927378636214, 0.07536622845838148, 0.029159039672043537, 0.01073842105876294, 0.012505585759607776, 0.027407237906910242, 0.047616972512896025, 0.07769519703522806, 0.028575177251872037, 0.023946426132874146, 0.05524480272264731, 0.003796001575181201, 0.032963441880119425, 0.09531809978427426, 0.009904555420601561, 0.016470304314768123, 0.06356989934800134, 0.027756181380320943, 0.021876571474656947, 0.022254982520075097, 0.050159304237533966, 0.030190033139660958, 0.09187787470798339, 0.07878464301146808, 0.04444501610592969, 0.03671867464999518, 0.05241796892556933, 0.005690848713951005, 0.036964286268959125, 0.03676621423613641, 0.033517695002017484, 0.036733701464629946, 0.004461454753313334, 0.09951209409102317, 0.0386161097295342, 0.08027957932602975, 0.0497052745683299, 0.028869701669581478, 0.03635597415268421, 0.0359190090919935, 0.03777435147053292, 0.03910711463240366, 0.06593341849023296, 0.03305790818206245, 0.030183548205381924, 0.08602433477438266, 0.011525745897914373, 0.0180746647979944, 0.05739004426305333, 0.10129448957741262, 0.06363875916107528, 0.09521916718973268, 0.05304011658975675, 0.04764198911406341, 0.05012070872790871, 0.05344492510982579, 0.03543480321945202, 0.023791785539698698, 0.050562343094497926, 0.04448449261666787, 0.04074487271868894, 0.06798628131828963, 0.011583551062240956, 0.053861370505464655, 0.03482078757858084, 0.03351265797391534, 0.04853697133160407, 0.010624605291072401, 0.04057918705286519, 0.033950465731322765, 0.038659481797367334, 0.024854676993263346, 0.02802461284332939, 0.05974342806204673, 0.019001778658299197, 0.00795460309863331, 0.019732988514606992, 0.054757310332910675, 0.02669818714381226, 0.04925279239673288, 0.003094642334842995, 0.008215965485320458, 0.02624534491089083, 0.09515498434343646, 0.05260315535950565, 0.02102487705527775, 0.05349293967048007, 0.048390380407293, 0.031345935328112494, 0.06729788237041043, 0.010412616313495224, 0.019479476613923907, 0.025381598013242888, 0.04080120316376129, 0.03048472418149393, 0.03428697368250259, 0.03483898599722213, 0.03423681790609995, 0.07304104435588084, 0.02371765695692551, 0.012534027731406593, 0.008944882823514843, 0.04626583473216142, 0.0312189371024649, 0.03790457109590212, 0.04897178368522756, 0.019287950802414168, 0.0492442045511017, 0.005183125857353932, 0.0835343115332146, 0.11895006597642938, 0.034286521690627264, 0.0780661444690439, 0.04812049146200861, 0.053858796450039076, 0.0038608047132936097, 0.03154134712061815, 0.028219984416219018, 0.03334670417731808, 0.027466286048893968, 0.0365699693230131, 0.03045684624192936, 0.02978934042696511, 0.040529690112077424, 0.07804236509987424, 0.04466202966268024, 0.029697277725884513, 0.05696566985739816, 0.02249197564989088, 0.12772714298579002, 0.011417321473990959, 0.07700358051806688, 0.03430068665634721, 0.018438365040046555, 0.02433137190828641, 0.026715975705414053, 0.009657775517553091, 0.11870852611478298, 0.05810914035405844, 0.024361053984912655, 0.05557701675101154, 0.0337740395128006, 0.05052653997535667, 0.00749529843526562, 0.062495020533641504, 0.013287095033804016, 0.036129480257870696, 0.03313198122346113, 0.05490017806990974, 0.024188155601281795, 0.051496679248708876, 0.03155079873038396, 0.04474833712822968, 0.041802464759037386, 0.05134662177654044, 0.0215695176889459, 0.0607523811800826, 0.07665595280066614, 0.10479006450623275, 0.021828798231698816, 0.03002031210569605, 0.01639499021093211, 0.024941813748990817, 0.06255554147965967, 0.057427571080024206, 0.05669010420059485, 0.016200532197892185, 0.033649477446752216, 0.02803305130181534, 0.03064389043908206, 0.05732706034435861, 0.055984721083434365, 0.034226215249227906, 0.026127729347095858, 0.0491758733386955, 0.06111585159575748, 0.04411464068858374, 0.013780176034948279, 0.0711168153511901, 0.014936476589120446, 0.019360457194007693, 0.032042822530192715, 0.023269868989084518, 0.03989051231333325, 0.11068479698752204, 0.03355419526116983, 0.03205583261836681, 0.060057838207050684, 0.016213032837596633, 0.0030975972796084303, 0.06059447896756953, 0.035836344374524015, 0.031035397757565787, 0.05835147694714608, 0.04591177953707595, 0.08352124973410562, 0.03571300038827523, 0.06680656720193164, 0.06599979234799262, 0.0774816730089726, 0.012340619258822934, 0.10828068284618278, 0.025660842807302554, 0.030907351906681736, 0.01611070072789106, 0.03875825351344482, 0.03095499682991255, 0.12176630477751456, 0.19705266090891055, 0.1677185107743548, 0.11510834187990236, 0.09983585050870335, 0.1229241930489098, 0.13331494234021635, 0.11153787419560457, 0.11036222034524526, 0.16543962902599768, 0.08186547325984125, 0.17398426729825237, 0.16966786746296192, 0.11750105663292831, 0.1094266278068385, 0.07122353905992163, 0.07020332444939884, 0.1831296717207278, 0.2486853016119811, 0.11897114105522634, 0.1927280639328303, 0.19967928528785708, 0.20972948551418322, 0.1275934989473993, 0.18300846128934817, 0.2056580193100437, 0.1408511331124652, 0.19719757410066743, 0.11369996583990513, 0.14519597013150493, 0.13756507557005654, 0.10597866524251238, 0.11075865552430192, 0.1375626700539743, 0.21014010864159754, 0.08117213304485045, 0.09723101367032337, 0.21512320415387232, 0.1420753416154654, 0.13242303213525203, 0.16048711574366017, 0.09205389106946607, 0.19247068903378903, 0.18961456003448657, 0.16488836747744393, 0.08076254413613389, 0.09961730860654386, 0.13149484000619382, 0.1367093860021522, 0.13455885462462902, 0.2573898837210671, 0.11595045636978843, 0.20089053158317843, 0.21605340343329216, 0.14981741085648537, 0.12378919058509412, 0.1360294829693533, 0.15515471478143048, 0.19754203787494093, 0.13865907976944603, 0.17964820047059368, 0.08611642620376042, 0.14472608244226826, 0.1480848723722081, 0.15616752898260472, 0.15349527640688806, 0.13200776651501656, 0.15954320349039572, 0.20860370398769457, 0.15288496480113076, 0.1238699745567095, 0.10116250028893833, 0.23440012137495705, 0.2321110353354485, 0.18320595875622767, 0.20189985242341796, 0.1758818670866951, 0.12515593740728595, 0.17231247958637055, 0.16974660597981947, 0.2089814159778818, 0.28224202113286145, 0.23637385498131477, 0.23071673999149955, 0.19361075043918627, 0.21957005344090924, 0.1336612294037496, 0.11025530511453269, 0.17808489080878998, 0.13783840041968132, 0.15263998520470437, 0.14910478054756118, 0.19233204244125277, 0.1554249906011166, 0.16215223849060076, 0.12659534766909578, 0.1403815671801567, 0.23867407993924236, 0.18737474877026775, 0.14279361033151228, 0.22259852157965784, 0.12014549255611436, 0.13890168449330714, 0.14839241070853126, 0.19863463247254973, 0.10606121887723285, 0.2496155621784349, 0.10799821856762133, 0.1285183049678322, 0.17602111122781233, 0.1281520613138714, 0.2103653231695775, 0.09611094715974985, 0.13075642317773836, 0.13024619329840909, 0.20113581761477456, 0.16820834739313972, 0.15926047108106076, 0.12265374102900106, 0.12104546966692134, 0.15062992370897724, 0.1539712468342435, 0.14740449436489614, 0.2492259758254213, 0.11787829364860251, 0.23542166897846808, 0.19116660820380335, 0.21015650292317714, 0.1211981816337474, 0.1511477378587569, 0.09355510930500685, 0.08637036902890091, 0.21858992055058482, 0.16062734047732047, 0.10838244230516496, 0.13162250089789593, 0.1091351543342875, 0.11412626312625025, 0.16056616069568744, 0.14436805891173501, 0.14643451980044767, 0.15486514886781094, 0.20470961778154298, 0.22284465030797068, 0.1024295484286643, 0.15477717133058658, 0.14868664975848891, 0.1008320406019207, 0.14749783451759046, 0.10384508739075354, 0.15330596075903985, 0.14861814617629976, 0.18035128532398134, 0.14055836495132218, 0.1185870398917506, 0.12922774069011211, 0.11457782599233812, 0.14049782868354552, 0.17682162714340996, 0.20714467421414393, 0.13548788945040396, 0.18475121938653533, 0.09616858761517272, 0.10103352172600646, 0.15189828951993298, 0.09283615110982811, 0.1288457692510659, 0.1333079402965884, 0.13477846138900326, 0.2958338611548947, 0.17013268365013987, 0.15300628248481982, 0.162837642034696, 0.14115571434940063, 0.12173930783906292, 0.13082189305174735], [0.03553234153397141, 0.0314363528553757, 0.06118897085769042, 0.01890470765741362, 0.024220880962187247, 0.0010728337187057122, 0.024909739562821005, 0.07382940245612014, 0.03372643097874618, 0.035916002196890694, 0.07511105989256213, 0.010319462894732434, 0.035980437852201924, 0.05030339388477226, 0.01099598077651594, 0.02595742991674812, 0.05795708722284725, 0.07253908822613378, 0.12521930820038243, 0.07744961989022071, 0.036443568645946445, 0.06374190140876078, 0.04484724674013354, 0.0344373835551162, 0.03754396967950367, 0.05148717592800817, 0.07170559222539587, 0.016103057085626548, 0.03893155026279631, 0.05209555316175665, 0.050147977627573476, 0.012182539888477374, 0.06559385767867489, 0.058209007575867645, 0.09050228723114537, 0.06233711832112843, 0.02184938684466385, 0.059363138185994285, 0.0715984088639098, 0.006432836948548474, 0.015442150160520068, 0.05079973459003433, 0.006932286055563319, 0.0057868658651357464, 0.0372418514152448, 0.10737884414171982, 0.051116274459467786, 0.03137020690877351, 0.02888675287155615, 0.03068174667386038, 0.06088099585125043, 0.02672853954737225, 0.015250888649344206, 0.010481567099510182, 0.07898013332798597, 0.03612669169782631, 0.0604189720545565, 0.04436797830426405, 0.0209553909653257, 0.020175094025269635, 0.14871252820857112, 0.051752272993326194, 0.032693384395491694, 0.03619363629108956, 0.024988208033685243, 0.03900790624620934, 0.012137551375124003, 0.054605038866641066, 0.11924399093033806, 0.04193539250521891, 0.032687883884195364, 0.03456917366073017, 0.057826534349231, 0.039973789901142164, 0.0771540095428786, 0.020104686714588635, 0.029483066135717016, 0.03049090459582306, 0.016555468394090573, 0.03747601385018037, 0.050935148291530154, 0.06894110266359584, 0.027530386540738326, 0.010135026269352004, 0.047496892061204686, 0.04783753688717562, 0.03558440103886589, 0.05800339723787001, 0.08533215901303677, 0.030254687130030607, 0.05757130066593809, 0.045870809154885436, 0.06986381726399546, 0.02925218447231718, 0.034131580407941536, 0.014990480042122787, 0.08106976837640809, 0.08027348892703172, 0.05303512552693006, 0.07002844955892333, 0.05199639457127741, 0.0953949767074758, 0.07858680080502264, 0.03256007743578765, 0.04608047975888176, 0.03884371445183793, 0.041655130729439764, 0.009286195103589807, 0.06091393380155487, 0.02836333287339057, 0.02834126379551186, 0.05252306852790137, 0.0498032801964831, 0.013357325186652523, 0.02713926035099693, 0.011436836606252098, 0.0629389952988394, 0.02995628822264412, 0.022008742709013245, 0.06975538517919279, 0.01676717104630605, 0.061815117500842585, 0.005551910050393593, 0.026144338133294257, 0.07640196401025019, 0.01991041064743073, 0.040259199787772475, 0.015364856677009694, 0.05868945961758014, 0.043307636008267446, 0.034155087815898086, 0.038481278254860835, 0.02949618539142032, 0.04865851884167041, 0.044336499751455365, 0.02906508856422959, 0.06824873538026888, 0.029296916346215916, 0.039350577374739994, 0.022940539281755205, 0.07400632280135348, 0.042643200290659745, 0.03516011856376164, 0.035192589200432264, 0.05100252572447062, 0.06632239963378637, 0.009821856229175484, 0.05152610851632011, 0.09945491328835489, 0.10218481398037366, 0.047752206183729634, 0.07310328133884939, 0.014281476201910167, 0.0687338835409572, 0.04464358226546357, 0.01834029429441979, 0.07321342946060243, 0.05338644195768622, 0.033505353325557326, 0.048928917235424446, 0.04449900998283298, 0.04433977477733166, 0.06943647809807332, 0.04799528588210383, 0.0675097976120249, 0.06867645759015314, 0.09073000686663775, 0.014155708504990946, 0.03318613980926814, 0.031827726108472676, 0.04274823860595784, 0.02813942261010168, 0.04455825539245721, 0.07255735176224863, 0.04773672737721955, 0.03208667914863796, 0.038738469292800275, 0.07821677267671594, 0.08884911545582357, 0.020042097331174923, 0.07551422898447321, 0.034400373847494205, 0.055259772080687754, 0.07257961427732822, 0.02278281135424491, 0.07281174657926445, 0.03527725340738412, 0.015431331083809417, 0.057354413513695045, 0.016118834666427106, 0.010600879548057433, 0.017958623544883826, 0.03808387014414034, 0.0948073183216395, 0.09335306893673637, 0.019456354165149313, 0.04694927709117051, 0.07630880005777844, 0.02957203192636371, 0.049547900956484585, 0.06966648067558004, 0.06035946617503801, 0.017286833383203033, 0.04155687229227155, 0.07383917773803396, 0.043167277209220395, 0.037922348166185046, 0.018115397692928394, 0.04969037415820265, 0.017216385852906014, 0.027890551287019928, 0.08662592829956163, 0.027305145199681004, 0.03169785122266941, 0.009074246345628655, 0.03624580304829344, 0.02615283979403396, 0.008748451176459992, 0.015538778745629376, 0.02977538996586396, 0.026369966348753344, 0.11762639627821984, 0.020085726038462693, 0.07109030870901001, 0.02975260842621567, 0.08239749834061631, 0.0379324528659063, 0.0435052675405337, 0.0330476617560752, 0.01246906347542761, 0.03325218807965998, 0.04743325313733471, 0.03353901522895021, 0.043172406167873455, 0.061318156264361844, 0.039191365151876406, 0.05698693262773657, 0.02143879053032687, 0.006468944108834671, 0.055213569317974394, 0.019250393341926318, 0.022956029579584158, 0.04559934972935627, 0.03737455699592829, 0.016603335482819427, 0.021353256813580954, 0.045076134659710436, 0.06100588350466663, 0.053333823208607016, 0.03631386612992614, 0.11631614077956447, 0.05164593998943606, 0.0022233990274534952, 0.02819811260598081, 0.035288319547450354, 0.07226808462291956, 0.022802141667794318, 0.04232837262773707, 0.05616784674085437, 0.04388494837668635, 0.058010793816778934, 0.03923106765855224, 0.10017217842922096, 0.028542940272018317, 0.02717517263766739, 0.04683172856006892, 0.0372897434018312, 0.08387875232485034, 0.030627143757057287, 0.04829502161291819, 0.005845229794842101, 0.04533852743465574, 0.0648365721046444, 0.05118608039112822, 0.049901128776611826, 0.05612470449939851, 0.045786853579263535, 0.0516863051621664, 0.05115044581133032, 0.05273335200223712, 0.03988344132179215, 0.022998537883282672, 0.010727241920727876, 0.03683936797202595, 0.09050925863125632, 0.09367906999203468, 0.054991373176416086, 0.03037835095798777, 0.05227549572385127, 0.014593042245495224, 0.01849887832518547, 0.017529602815967896, 0.03658121549374154, 0.04620357476655514, 0.06182856234391371, 0.06830886562144564, 0.04383633626745113, 0.014574867767101575, 0.09480921821969171, 0.0448961346410215, 0.048025335680933735, 0.037286636915298245, 0.02449703267625263, 0.020485501360869216, 0.009926279758914344, 0.0276814341815489, 0.04262685963523485, 0.07254666483570492, 0.009964465411500105, 0.0799597989046766, 0.021468849905255823, 0.03355650884670115, 0.02860063626881569, 0.03333415565711837, 0.004013985430168349, 0.01071211742988277, 0.053225582645785426, 0.030242219049062942, 0.04654873951127933, 0.04851555917412043, 0.016148495675635435, 0.039107126123722524, 0.04429393207594272, 0.08475213852380553, 0.015396069014264692, 0.05033982902645104, 0.039550403748909314, 0.044767144586770766, 0.06747376849694599, 0.011324501303475232, 0.025036756940666708, 0.022516542174402746, 0.06537256552086723, 0.05674934577977946, 0.08667169439215815, 0.043708058674969984, 0.045796276460732185, 0.01762774825516728, 0.058910610049121806, 0.03996365455790393, 0.016433350148520643, 0.061058896789026845, 0.10229750551403531, 0.04468862823541126, 0.03921242107847526, 0.04950039201386033, 0.03369678337607653, 0.017736094155078454, 0.0295499092223303, 0.051044629916789076, 0.022839168612394604, 0.029470774254971938, 0.1247651253135935, 0.13415966152904496, 0.1148846518668917, 0.12093934350677076, 0.18225594844308593, 0.10261972975586692, 0.09500876114132906, 0.1434253723991494, 0.15863083873785314, 0.2053612981352114, 0.19076891664055087, 0.16337211093594953, 0.16628713677487067, 0.13403396182242902, 0.11799838559161271, 0.11282333908903022, 0.11355394182065803, 0.2231372192862534, 0.3097894703668933, 0.3057084280637003, 0.17645729104838065, 0.2713235215313973, 0.11330533862834978, 0.14613451976929942, 0.21993474193638374, 0.1502960779133343, 0.12481956352149287, 0.1543755420754033, 0.23074718432561045, 0.11229080839022515, 0.14281921298994174, 0.07050762989468153, 0.14208353875625518, 0.14416705276216232, 0.2028604041063978, 0.15320581774557793, 0.07254982877883219, 0.1368604891843373, 0.21376281586145202, 0.16587259127728401, 0.11545298951527766, 0.17886415544536807, 0.10029087609220898, 0.08050474022785503, 0.145240617735732, 0.2793772506617731, 0.14855109816116674, 0.20425696707060262, 0.1500544078167408, 0.12165145287590644, 0.17404593737615695, 0.18604293555742313, 0.08953792809118187, 0.07855451785989347, 0.2934526147380952, 0.11406014973838484, 0.17178279107376454, 0.11394274676398886, 0.13296404342737891, 0.1876497130480505, 0.32354963522764946, 0.16022790223360062, 0.1157386024152079, 0.19501011728519396, 0.11050254467033571, 0.15538403554068458, 0.1784418571379877, 0.15664780482409463, 0.20665499081294383, 0.1392330941293509, 0.13953788987090512, 0.14164308416506938, 0.1527020383265711, 0.19795091432188788, 0.27919127515727477, 0.1480102707301417, 0.2979023904810029, 0.09958153230047996, 0.08983150064464539, 0.17036267856676734, 0.11746978492385919, 0.21093426602742366, 0.3023820436529575, 0.12655677514210825, 0.19566607240947986, 0.2124469832427079, 0.2359415362438848, 0.10588126482381936, 0.12029500993629617, 0.15139671643414807, 0.14709819709101032, 0.1699375610558256, 0.2153652113291525, 0.21145525178120983, 0.1250415145149154, 0.07744486248421092, 0.2247532357972476, 0.1894527929083955, 0.1540636676814287, 0.23558887532882153, 0.14093996866816474, 0.14278916702155145, 0.22674275081484552, 0.11764187125429032, 0.11092256003570174, 0.1721580515825941, 0.11197920212702406, 0.11535346703303438, 0.2778025416116561, 0.17246678501607912, 0.19233372783468616, 0.1835300292699568, 0.11842557153995, 0.13741846166310773, 0.12066139148608332, 0.16443565547946962, 0.15973137000635748, 0.1078607977157639, 0.23396449313769418, 0.20193475538924818, 0.1702147316668303, 0.13269995759812095, 0.25450102744563935, 0.11381489435030569, 0.2138957014727977, 0.15807472019185945, 0.09952678765741088, 0.10341366497619499, 0.13013812893581006, 0.15557298346632914, 0.09463658796683436, 0.13994970809548132, 0.14696918788456148, 0.14069698090034147, 0.1003020839585412, 0.14199857960545248, 0.12314870277599943, 0.09822138149531619, 0.12841093774524429, 0.13715383957230276, 0.2680063301757459, 0.14210564805374992, 0.1568488569389428, 0.18931575510050022, 0.11960581425697574, 0.24507235435228197, 0.15487590474226784, 0.16204089527168583, 0.25218040922716745, 0.2001534630694697, 0.15005561823566116, 0.21328696800816446, 0.14987024027974377, 0.11477271876027507, 0.07249648607666455, 0.10173213262591632, 0.15233856025001696, 0.13756567311863746, 0.19234707308632715, 0.17072295439579796, 0.20186700257322482, 0.09609734909909387, 0.16129981245725386, 0.156882181763649, 0.10384759249826593, 0.13860537700595396, 0.17351879227545955, 0.0778206286110705, 0.15690447492224557, 0.11177006012369549, 0.11909215230374567, 0.09189896510853883, 0.17534085579456823, 0.16593242274417033, 0.14651598559031564, 0.18998255802979394], [0.03860235462085374, 0.08621603295567536, 0.05104740315507497, 0.04608925912649401, 0.019088553437482447, 0.08591095376158915, 0.009187498081084943, 0.027771587408478224, 0.031462181509742816, 0.005319750935380017, 0.036706490021559506, 0.038606483834765615, 0.01598735099598285, 0.022254176212534792, 0.04691583352283605, 0.057157724269575653, 0.06160823545689064, 0.025147504526220506, 0.0755452402236481, 0.06523186581269388, 0.06317009338207784, 0.016570167706137704, 0.02032405982214597, 0.06810418991071564, 0.027144900673339446, 0.07902419104451135, 0.0046050617651593306, 0.04256476820897191, 0.09418144747014008, 0.017508878222396298, 0.04355522413407603, 0.048946422344494256, 0.04024779273857994, 0.018063091124678333, 0.028722630025097923, 0.0295709383358518, 0.030147641664370898, 0.07655646862281908, 0.031840941125166514, 0.05954259045181736, 0.020154719916923393, 0.05073169449103936, 0.03741543161712828, 0.029567289842112415, 0.012883539067491168, 0.05728164282176764, 0.05527295645386462, 0.08252414799625836, 0.03069559179787194, 0.01446984381595206, 0.05208084810405009, 0.047084729097062544, 0.008945570387426884, 0.0301776914632008, 0.046913117741144476, 0.037958921203690196, 0.04235047426435255, 0.04417567491351117, 0.019473974187407764, 0.042890501133496725, 0.01664671904197143, 0.024392925157782533, 0.017028027814963174, 0.01454736042257038, 0.02384947196039702, 0.06663752990143915, 0.05541852082035715, 0.0643156552987714, 0.062868480735849, 0.036605726476878896, 0.06655742008719714, 0.048942844713887865, 0.08387879829012579, 0.043171693706103874, 0.02526595895629256, 0.07556753338224466, 0.03456241676523801, 0.03675834651315405, 0.08556120398063814, 0.025178213160665288, 0.032550635402120894, 0.0719290983773047, 0.034781923938182094, 0.0472208475994487, 0.09535942256690995, 0.06638847471725556, 0.07677946149581864, 0.03313348275579272, 0.07373068436619735, 0.04773563953236707, 0.0353845248689815, 0.02805017719736263, 0.015005787436459816, 0.03983802379920118, 0.0035000728225455654, 0.05199394308991971, 0.009656996023090137, 0.06567955993476414, 0.03041811475169755, 0.0954636105246121, 0.03738629729336789, 0.10102250538165532, 0.03282356571646468, 0.026219204075694568, 0.03319979532651844, 0.04284970312108917, 0.02698032391978608, 0.019669052731666355, 0.05143538838432682, 0.04303313138323926, 0.08063849151855515, 0.04129725658605176, 0.009533994861187474, 0.02896571355391174, 0.08038452571077694, 0.03054629849840797, 0.08314555255515922, 0.02587606754874991, 0.02042544772848487, 0.057640390305389325, 0.022266632802183592, 0.03799411911337126, 0.07519700729678716, 0.03863553771929395, 0.04376412481970845, 0.02793622927950515, 0.05429912846715701, 0.039848423442773284, 0.027099636368333336, 0.07712954069457709, 0.052871014171790694, 0.020865377549442555, 0.039378424670787594, 0.06632331893929551, 0.04278081649493787, 0.05622072595982783, 0.022410456233868198, 0.03033475289421697, 0.02998046212709479, 0.05149125917664459, 0.006600002600480953, 0.0595166813582182, 0.03754656288712736, 0.052861970503844564, 0.08843023390058549, 0.024548318432343584, 0.04736632769626956, 0.04300303178869429, 0.05724305497302164, 0.07495203536124, 0.018255967166154616, 0.05871115522759576, 0.02217247868106971, 0.07914894846298041, 0.04149519072304811, 0.015339836245402695, 0.05613612687034954, 0.05654652017138659, 0.05301737143928486, 0.04405056509459692, 0.09006210077073305, 0.06551262171518418, 0.017157498589386384, 0.012583539993952841, 0.026084182994259943, 0.05921580798683628, 0.0034727115135249355, 0.06639422037668767, 0.038659194514395735, 0.023845865601493467, 0.026665885046484972, 0.0030958513173484996, 0.09820618997177771, 0.032197526325621915, 0.05119416261872938, 0.05415429188419254, 0.030094074881485397, 0.05775556013348603, 0.06471691683175103, 0.03227366780441615, 0.025129317598898086, 0.038735404941103155, 0.025160993419347272, 0.020826623076573018, 0.011651328776121862, 0.02994904677653986, 0.03014971967786551, 0.034963433150081866, 0.02035199713352467, 0.022304479460862857, 0.01914603492966102, 0.05179984705342401, 0.05723690328698966, 0.035642830564850764, 0.015797829462005007, 0.04066172536582716, 0.02158287634712554, 0.018538887267031016, 0.03359390925916453, 0.026427796410937465, 0.03413645272713996, 0.028845872504696734, 0.032905881863928614, 0.012001716325269833, 0.06506792299689786, 0.1002624235867012, 0.06756126339877806, 0.04804819574459426, 0.0530728247136839, 0.03314659435061678, 0.01399942848365754, 0.010877381747348175, 0.04461571581721787, 0.03007097541534853, 0.005947690224274994, 0.09099613815065354, 0.02041449458638747, 0.037550523561695894, 0.07030924376580985, 0.039627395585299506, 0.01938714961250944, 0.03836843733405394, 0.03249829627513405, 0.06065759312121138, 0.061971104493544954, 0.038117122190493735, 0.09863941269295831, 0.04976001538095936, 0.026178752718072747, 0.027186280912569454, 0.05532329226092947, 0.0527578514940556, 0.02416249357103821, 0.027903982723552375, 0.03303736553437287, 0.0418236585814626, 0.05591159416062217, 0.03400907911840947, 0.03249112569216279, 0.004549840711162336, 0.02668825098343434, 0.06574524431339195, 0.02699132111193913, 0.05586657117331221, 0.038706998400870836, 0.06739807901002708, 0.04371575402816938, 0.011060559115703068, 0.0281877129624087, 0.08179719184315012, 0.02455147662981143, 0.043669689161282395, 0.08459234024367987, 0.029053687260696487, 0.03653550685773935, 0.06163022984119673, 0.04331456527354256, 0.05014851388912048, 0.030099016148597005, 0.04035186961353306, 0.11739820166821442, 0.036678137107481884, 0.024858197167275414, 0.025465241408035643, 0.08749897741983015, 0.09624752531489057, 0.025377193007678277, 0.042262266900750904, 0.027073305926375815, 0.03333165821048521, 0.1050491018160697, 0.04967601767050163, 0.012320676074934103, 0.07456490815046334, 0.06620731790580096, 0.05794211020392757, 0.03929932226216601, 0.1023145050050751, 0.04780418524939207, 0.01884268326384406, 0.02927477065954478, 0.03364593429010242, 0.05874547596660353, 0.033078780247559475, 0.044019255081131574, 0.04406664911056719, 0.03095683544093082, 0.03345008774269973, 0.046099869444245295, 0.0069984152439921616, 0.03690770301487177, 0.02296220424825386, 0.032506420637571046, 0.10294952294639043, 0.017618350271556168, 0.018970824875718644, 0.029094657642887007, 0.10280844019425493, 0.04115088016635949, 0.0629336824790845, 0.029619684510473764, 0.027002429386841196, 0.054912129041528514, 0.07190700440156846, 0.017557676107953155, 0.0177048894787027, 0.01968200727846594, 0.049818686224640384, 0.05713557283724508, 0.03531866045969148, 0.06450081875007, 0.03720761494590871, 0.039024308188668186, 0.02366975156380044, 0.023841288226145892, 0.07148753295862867, 0.04085594780683037, 0.005281918162044379, 0.08242336146894001, 0.006353117360342895, 0.05339972975273287, 0.03766935912051028, 0.01626456948748279, 0.011360523715284804, 0.04420467900232442, 0.05609199637547136, 0.03021041873932606, 0.031057713898800077, 0.04413684191662939, 0.03144175569046169, 0.02318033054771443, 0.08996482292610793, 0.06517224118954713, 0.023692318598829934, 0.023321915087440324, 0.0706212024294561, 0.09108506563690402, 0.027038692158737013, 0.046574526030810616, 0.037107131023320465, 0.023967520363869208, 0.0595386412685677, 0.056684354710723125, 0.019487980189883423, 0.05310898789414956, 0.025999434517636418, 0.0145496548559036, 0.023645142904452743, 0.09984633825238674, 0.012014785785258058, 0.02987306426098991, 0.06282324324392023, 0.11402344646593256, 0.16872323508704865, 0.10192877973519987, 0.12167924654579933, 0.1405856070379096, 0.17700193359726862, 0.09172186856308291, 0.12201502288301146, 0.15737774872010754, 0.10555024589261702, 0.13364426821710604, 0.13831533611782137, 0.09847729316642208, 0.09852582483642525, 0.12101265046024516, 0.15469319277232693, 0.100972801597128, 0.09007202927023174, 0.10461379533573505, 0.12600099367480125, 0.10239438499293982, 0.11452019319779451, 0.08923297913204278, 0.2196911566199795, 0.16754128399395174, 0.18712878858129825, 0.13795251687688215, 0.09409379168984391, 0.16495256564549862, 0.13058629037151415, 0.1654857015537639, 0.16381907727449171, 0.12755150200739024, 0.1413547593138872, 0.07300563577202059, 0.12356096533157172, 0.13443773612380028, 0.10784186768315493, 0.06659359475898166, 0.18668340038388007, 0.16885224429349746, 0.17042801054494996, 0.10359494436171748, 0.1410233956431189, 0.11605603094663351, 0.15830149753920494, 0.1950933450772878, 0.20363677293062213, 0.25795783066461164, 0.10360013077696485, 0.3234055187673338, 0.1093272278986631, 0.11200062194538694, 0.1610109360227662, 0.16553229502131864, 0.16393915389574346, 0.06424203807968767, 0.1985128704578646, 0.10912576209633582, 0.09144679703299077, 0.15526835626411825, 0.06157317544303595, 0.10341007968470936, 0.09095293079172412, 0.1218419636209165, 0.16093242733228594, 0.19343808954281194, 0.20049968884596903, 0.1603665488261369, 0.14984007173728559, 0.13499950839867517, 0.1363740999612116, 0.1390825118869543, 0.14806503069496926, 0.09520963705595463, 0.3308644572332982, 0.21232157464950316, 0.09644140684676748, 0.24568972928870111, 0.1011846861952255, 0.1626065133079406, 0.1741425563851672, 0.09892753070040096, 0.1392025118994136, 0.17000384298303436, 0.1578518039276523, 0.16621325525545305, 0.11273532324740965, 0.16346034894306816, 0.18189633144967018, 0.16448565037740817, 0.16061375007754372, 0.09661851105310264, 0.11651137828706734, 0.18264924266165306, 0.17445668307763917, 0.09957023250359683, 0.24150685857861276, 0.2047250314705795, 0.1686391492764796, 0.15756272831030432, 0.32510031976046105, 0.1515467930585146, 0.10126156311842704, 0.11411982032680705, 0.17937078471145323, 0.16855861811387926, 0.13574760857849352, 0.17233365425659766, 0.1880599531315027, 0.18891156711164983, 0.10831881104217422, 0.1503985191905691, 0.10925926057802093, 0.2725582714042356, 0.1495045865134847, 0.19115461126690914, 0.17281023755429253, 0.08754135740380134, 0.09097829596289704, 0.1328690025594927, 0.19712284988453313, 0.1323935990372012, 0.16631635536830272, 0.2542918394770353, 0.08840713634966843, 0.11790345963691512, 0.08133725563604986, 0.13106532515056674, 0.11083594613498259, 0.151610792043709, 0.1807485478779962, 0.13191283289943972, 0.2398967409446355, 0.1453755258191978, 0.1431376144530312, 0.12101467293236526, 0.1520247553144732, 0.08607381639341194, 0.16137501164790125, 0.13970799203361237, 0.09089097726128756, 0.2134810180793847, 0.14750878957490768, 0.18653876298377592, 0.22030174401738953, 0.10453156345794279, 0.14800054141350333, 0.13539507023749814, 0.11063788176303911, 0.08397105059796765, 0.138696909191147, 0.09334925381887345, 0.12838402507646432, 0.12312794179325143, 0.12942209719650208, 0.1340886911437396, 0.1489167519274258, 0.22641648928965294, 0.14686987224605777, 0.15416924991915304, 0.1392932473531654, 0.13338271047799818, 0.1070736576953242, 0.1518990096425818, 0.2466820582987801, 0.2139245829875431, 0.14257916699974768, 0.1412170473486185, 0.12906430349234613, 0.09546383269011013, 0.11525700124160898, 0.17281704041506016, 0.16316758078192511, 0.11630092627338826, 0.21973856214073398], [0.029121227487320864, 0.06461237647360371, 0.027042055284724604, 0.007419030073158924, 0.013063077518205731, 0.00801373934072833, 0.029691081989796895, 0.012684426112701336, 0.013329271046865373, 0.02560018971111746, 0.020374625455588102, 0.07076554871614903, 0.02757576575893308, 0.08236310865369537, 0.024919570386109334, 0.09191846204621178, 0.061575347302301284, 0.03796095133668954, 0.03621486075703175, 0.04547762984950696, 0.002752867768586223, 0.047821598427910963, 0.03722962848241291, 0.11648705499547145, 0.030187761688965465, 0.07060220344893395, 0.03585758416222469, 0.02572851901453349, 0.036662907279547186, 0.10623853758818681, 0.026770724178922754, 0.030037993414988442, 0.014079544043558982, 0.022491113800976067, 0.05287750293650935, 0.052192685449676174, 0.03605770931068448, 0.03804312575788748, 0.031122274043399, 0.044113506878455805, 0.022248292657276316, 0.011170406547945835, 0.03153921931140846, 0.0295016227004629, 0.010009524787986472, 0.012041940729344084, 0.07631112896506825, 0.03030300429541498, 0.06760026493500318, 0.022654715707645785, 0.027592221327546625, 0.03254840991670086, 0.07256261478628843, 0.04177935954724108, 0.08619652069624394, 0.04279306624084712, 0.09006427646043802, 0.04569290055622978, 0.09914100110050171, 0.13213502904099803, 0.06946557411743749, 0.03193530209001995, 0.09330266801219794, 0.04947610319622102, 0.03257029704869755, 0.05354395346535791, 0.04886883295952313, 0.05822255967124816, 0.04623582323772773, 0.06318258444568323, 0.04077553155741865, 0.03508404603288059, 0.10165525570271478, 0.03418455538790553, 0.05003220259001659, 0.04976960297133173, 0.03944270710851397, 0.035454281004926855, 0.034172876377499876, 0.12507434138247084, 0.025723321107967247, 0.023711882569196246, 0.04001515098817406, 0.08709478943097977, 0.03584451087179684, 0.04014927383151747, 0.015388691587553871, 0.04608907143495256, 0.02315701274651914, 0.03268177816343885, 0.08021398687795286, 0.019478568799733635, 0.07124915704010956, 0.05140897367269762, 0.02832637296148366, 0.10682552947752899, 0.042579343031731345, 0.05549188523042587, 0.01907410884967014, 0.0631639646786836, 0.015089417424713893, 0.02507647668432084, 0.10075786030821263, 0.06560179434957043, 0.021602729515683268, 0.08325647442571579, 0.04484117166289399, 0.05301229227634688, 0.05472325389423678, 0.01282656510856243, 0.022547511278741786, 0.10444760022144164, 0.04237866246952646, 0.018219742698655016, 0.019942270328981743, 0.03956500155430648, 0.04522550265274702, 0.05184598086822418, 0.007771733601862986, 0.08461775138012825, 0.10006213755977732, 0.02521376155557171, 0.028520434524022767, 0.041156744569419854, 0.02744504434597348, 0.07375328395996364, 0.06789078079764882, 0.01701313506571516, 0.01677632005134177, 0.06751790282226379, 0.03764563337749532, 0.03000233776777262, 0.068953444340056, 0.010680030794784186, 0.04888888531094117, 0.01911499879262861, 0.10826440347779183, 0.013689354396305017, 0.024977511531042478, 0.07198256365354024, 0.029436486074700955, 0.02644460437999618, 0.05736017832532526, 0.05063626291831175, 0.036506429990573276, 0.019048883489543394, 0.07673428529092381, 0.05113264575840966, 0.027129634456228346, 0.01886920522778265, 0.023810050991033355, 0.02219275128276598, 0.016646650094058246, 0.0027824689271754677, 0.010100314825502856, 0.04297290538107196, 0.04752581954122551, 0.025662915075137734, 0.043650065819101955, 0.01586169055137303, 0.05617516671097087, 0.03770375646831047, 0.04065467735692378, 0.028945360512983416, 0.029451673767799814, 0.06837807400452514, 0.04851780381173857, 0.021613048720023325, 0.010677044009489399, 0.059206760488450534, 0.02351920188014065, 0.011304258387686025, 0.01837792836370007, 0.02097213764735047, 0.00850075962878163, 0.05517696180651265, 0.04167331382632256, 0.04300410048134866, 0.021253979479473446, 0.05090432857433635, 0.017895243175688292, 0.0688586256376678, 0.019329566613680894, 0.04929194715054286, 0.014817823933797979, 0.0527467355582743, 0.011237934325641442, 0.10288568483966012, 0.06453130904945635, 0.08665317038614904, 0.03149098641569576, 0.022649201789810773, 0.023449888159971566, 0.01544285208858069, 0.018696350894207438, 0.03682972675549888, 0.030467307172535412, 0.05480127228844551, 0.043117171228532834, 0.09152545128017665, 0.05911723545361912, 0.02922907543008126, 0.015666076703177347, 0.011965807869038995, 0.04918055796635248, 0.006098227937810965, 0.033235678884891734, 0.03325318782440117, 0.045241816495094574, 0.026647259533825903, 0.10062204824099619, 0.024952864567298564, 0.015528402084694996, 0.04089889086542591, 0.017283682846614433, 0.09146894463488171, 0.04144637943095258, 0.02625439049405677, 0.052970149779632214, 0.04646089220900209, 0.09171982310832509, 0.09343543871035499, 0.018309034076669527, 0.05925390170887113, 0.04344361278438761, 0.023375855338188912, 0.039923867781556426, 0.07254915462145883, 0.09088623517703626, 0.012449840414187601, 0.03489252022137085, 0.09522748690459037, 0.11813174617747146, 0.03470755595293257, 0.06250813212846557, 0.01072110364123458, 0.02745951574686314, 0.01356747268038171, 0.08734207495205826, 0.006687764675476619, 0.03325691101171317, 0.004112751161183922, 0.08942707516853848, 0.03278386704022846, 0.03618932321607586, 0.07076379437480243, 0.07609008961627561, 0.041120278784224105, 0.06652358198358167, 0.021337371980470997, 0.03688593845694296, 0.05624018459310455, 0.018661949715967623, 0.04498776258720506, 0.05799703104721923, 0.07071484901732014, 0.0793297069087144, 0.06668005544211596, 0.01976300192426049, 0.028087041348279006, 0.011482570140111831, 0.021685200795951872, 0.023877246478091807, 0.06845787738359745, 0.02114632305869412, 0.05470389485239022, 0.041768182324425834, 0.017208004851014386, 0.03445774234170395, 0.04270565943912633, 0.027828421556360783, 0.04462880825984382, 0.02958251967004711, 0.05353519708038338, 0.02010838883448272, 0.10493460231490674, 0.10547759011387826, 0.025480078615909143, 0.05479846840664264, 0.03551019776252008, 0.028755169609681736, 0.03601894143127626, 0.014648570213466884, 0.10195705604048506, 0.05448629140793797, 0.004455693772122745, 0.03125095383204039, 0.028326478298573245, 0.01298397319436434, 0.023075583345827558, 0.009068786053948346, 0.07302003822499707, 0.06366918051254845, 0.0357875369128681, 0.03176386501910466, 0.04271195668186392, 0.06526214926834069, 0.029135384792161566, 0.027946312911808494, 0.05968548500189378, 0.024539307323134234, 0.03819793680562608, 0.08601987614266335, 0.03737669055079741, 0.007729522636040084, 0.006049601464427167, 0.0576171203846893, 0.0270097321199794, 0.061193751246337934, 0.03521010963126056, 0.09283130943414666, 0.04315890003776839, 0.07457105217561608, 0.030556470230822603, 0.014362085888522768, 0.036538291587344104, 0.0697775251202045, 0.04134128748949978, 0.07080916976255756, 0.02198966903491847, 0.07283696619373176, 0.03566980069022506, 0.07183227252455489, 0.019825367226956353, 0.06476816811388539, 0.0377561109170558, 0.041357846479983106, 0.030578165840838226, 0.005456750917684047, 0.05718656364948519, 0.039261312809802835, 0.10666901005371925, 0.01266300725194836, 0.0217963658994244, 0.017911486154902848, 0.01662633535752614, 0.03870712480537834, 0.039681761014846065, 0.05314085715179963, 0.0243007839326897, 0.035408740908268004, 0.03668520809902299, 0.026925948914140466, 0.017224125256161057, 0.010881474572083643, 0.05394517669394132, 0.04144888453846497, 0.020737873705764933, 0.022930670154070663, 0.02031321776279759, 0.038913137339536226, 0.08549427087869375, 0.1559968599148335, 0.16662219298943398, 0.1566875801091233, 0.13801585702646163, 0.09466203740767895, 0.1999160370999767, 0.22780899198785906, 0.27144775034919866, 0.12645844775702686, 0.12537034243465434, 0.10507295013315256, 0.1924863785144783, 0.20371488325538176, 0.1920118483324205, 0.12610153505398383, 0.09423821458532926, 0.12456460946029234, 0.10831497294167358, 0.10205116228110368, 0.13683516231756057, 0.12260151681520286, 0.11463155173846792, 0.13791769051984434, 0.1671562328814499, 0.09171298194316127, 0.21683936367832848, 0.11444500166802637, 0.10176217093342736, 0.19411796193209388, 0.21626389375136745, 0.13121534048789932, 0.18381700580639226, 0.15292094029005499, 0.09431905218309934, 0.1421952190538568, 0.10615727864205839, 0.14187933035915898, 0.15664421953260899, 0.16233203932642937, 0.1561977894556138, 0.12895141277582417, 0.05802536863953837, 0.17892956403234314, 0.08108257736650207, 0.2534841836219834, 0.13539303244361955, 0.11670909025856566, 0.17348653997384733, 0.17563725521247234, 0.06852527779917564, 0.1075567220968585, 0.16094192682254702, 0.27307685164193957, 0.08461128559804733, 0.2152484288859752, 0.21428246862224995, 0.34544877948299535, 0.1257759093817684, 0.26629240762802864, 0.22764560075536852, 0.1837113163163585, 0.08456486066983593, 0.23353761362452663, 0.08693059380616873, 0.21428668210583351, 0.1702902372926474, 0.21566852086013366, 0.17378329179219662, 0.1713388584434025, 0.1524061292049385, 0.1735965655215325, 0.15476822342363097, 0.19477757895665784, 0.13443897718623762, 0.1472441061970688, 0.13199797591134427, 0.09472283414534985, 0.10555636693513203, 0.17398969120075627, 0.20591969962321943, 0.1435116338994234, 0.15563918878474545, 0.09832999744122067, 0.15517595073869153, 0.13139578483758435, 0.3265670410567715, 0.07476972941789897, 0.12678647128444526, 0.08160852737003758, 0.2014283559495403, 0.14987076121953227, 0.13178411480640212, 0.16550617142310067, 0.14601291097219915, 0.15571926029459124, 0.14677032678117677, 0.1274606516404498, 0.16023743236737867, 0.09631325565879384, 0.24498240030821294, 0.1503013945635288, 0.09250821951296061, 0.21911544154488274, 0.23145503424588712, 0.1405501371670154, 0.17995183175850302, 0.18858447821149904, 0.22948244977141583, 0.08915384991034385, 0.12352673652311488, 0.21021098709635197, 0.31403482320808596, 0.15664392841919778, 0.14049554574153117, 0.10793313939845371, 0.17343436938620385, 0.16271226408500827, 0.1490696324335952, 0.11599321939772177, 0.15395983212417172, 0.13663950346169934, 0.09466548480333821, 0.17057261730153717, 0.13604837469756603, 0.1668557578757886, 0.22040315873680577, 0.1718852476727578, 0.14905849351517617, 0.13635566788575343, 0.1482186006802705, 0.2653475760692551, 0.17627398152985882, 0.1354698710624249, 0.09432824523819071, 0.2140388220188118, 0.11357451128142496, 0.2492814252693807, 0.15240412205457687, 0.09736538549224216, 0.15720088966190815, 0.18526413057359958, 0.0955929185053514, 0.1276491092698228, 0.16363006806181324, 0.11587863562688713, 0.14286410574230457, 0.2420236155270569, 0.12914815947653788, 0.08044558291834208, 0.14547629702475764, 0.09992226522656218, 0.12403453024284494, 0.06023747050353597, 0.12296541624011532, 0.1455150917172432, 0.2238212898373604, 0.115691120285661, 0.13664889569965102, 0.10791308321659604, 0.08995425091275285, 0.11002819834937973, 0.12847289893656008, 0.16990641192082437, 0.07602203036508254, 0.12104783687860736, 0.18413853290821278, 0.11873985911088607, 0.11402199855975567, 0.11318391369235133, 0.15413633878192595, 0.19374426424262986, 0.11674069904632146, 0.13821177635221712, 0.1594902974583449, 0.10324491112823449, 0.18260955930717532], [0.048498349008901466, 0.08290588194804807, 0.040092265398632136, 0.005167455050057822, 0.04015114691649233, 0.07004710379987955, 0.03517495768685495, 0.12572645074537686, 0.02614653105997751, 0.027398632824300762, 0.017631791284187667, 0.027387616479949608, 0.010585173787999778, 0.021468277254532424, 0.06356267896931499, 0.0274231055030419, 0.10512327444889855, 0.03686068819895868, 0.037781139009542046, 0.03770677868517176, 0.0510769396749956, 0.053564971087560545, 0.045203558064156005, 0.07611383068104906, 0.04663824539391264, 0.056367830163048166, 0.07151889659824871, 0.041104742521119696, 0.011829502632721298, 0.06367876044204158, 0.03434879697799202, 0.04974296992464412, 0.030480788404782935, 0.030460159572201873, 0.059900108364320574, 0.009964408912515689, 0.061294461164863846, 0.050252219211430325, 0.04575914417904231, 0.07851368537352932, 0.03673895682779051, 0.032786850952693534, 0.05032785890263416, 0.022335416006465113, 0.12554596809129562, 0.0043313112579316145, 0.01967703919827698, 0.05957882258019621, 0.015909182257018983, 0.005150503439513306, 0.008957077985659482, 0.06383612256256804, 0.0034274201560389973, 0.024052630817036957, 0.00243038353566531, 0.042096320765032884, 0.09005365082092824, 0.05375701017797955, 0.010988625374832943, 0.0321326999654693, 0.015026190273103215, 0.03136309761283619, 0.0769164226949215, 0.020759611450616392, 0.05779401008640567, 0.025532201323057377, 0.033853134260542934, 0.010558136629932111, 0.026974649123486974, 0.01748280058945379, 0.09980588880998474, 0.04005342474087112, 0.03269726463082818, 0.02589332750968395, 0.041168243549163305, 0.06004835020810847, 0.009323860773996962, 0.04889276554627765, 0.043626002997400305, 0.020302458057901072, 0.005617321989003329, 0.03098925245144675, 0.03613070216810992, 0.10846992188523855, 0.06190215658035971, 0.07442077636838922, 0.05149300585711195, 0.024035807526219758, 0.006542850047304866, 0.06276452260452413, 0.04166441571508204, 0.03386781633561177, 0.032517456134120305, 0.010815287448255526, 0.03603299914468681, 0.0487572560837913, 0.02139515033172023, 0.01588205412601031, 0.010702736683249956, 0.05656565321729549, 0.05592640647063813, 0.10774776144253631, 0.04890384317766275, 0.0700377881707203, 0.06713302024910528, 0.029687266871933977, 0.04436061619931171, 0.027429266765172926, 0.036359325787352945, 0.06383870044843325, 0.034480617727122964, 0.03869914983008658, 0.05328269450054054, 0.01080996888284121, 0.05387894073200803, 0.007208642219343493, 0.07575615189008175, 0.03225673726128955, 0.021617850176088756, 0.07677065914556866, 0.02066887216642499, 0.061106137600877596, 0.07228101618708142, 0.01851196502215199, 0.01690095106530334, 0.046061216478025725, 0.05724686243000531, 0.01529670645287561, 0.03244672323607149, 0.09743543657203836, 0.015046884223157841, 0.08008082547495443, 0.00938380906929172, 0.019298021028178836, 0.035244709992360686, 0.0557268635490008, 0.0326235669725124, 0.029727193459327665, 0.018027376105648377, 0.033582670749315334, 0.05401544227835633, 0.0403340504084143, 0.06107251400188093, 0.04506640151263245, 0.00824218388691905, 0.03479007511369644, 0.03493155623155256, 0.031583981828824166, 0.02288611448039451, 0.0626731704499933, 0.08522933469183984, 0.018259048754830035, 0.022998007367395108, 0.0222124952837945, 0.038108170453098514, 0.10241179051057947, 0.05973782795932024, 0.01135903558949189, 0.0592896014061426, 0.016301339792628444, 0.004615435074459041, 0.016450326656922698, 0.055121906897834236, 0.0746643003977595, 0.04735603147456723, 0.017794389615676576, 0.05396300739037895, 0.00414273057568578, 0.11214587987670976, 0.0796610399359657, 0.042992590010286345, 0.04802459257564718, 0.07240111579097087, 0.03534620132056936, 0.09524585769301462, 0.027291935928646597, 0.025046365598456997, 0.05729832438631885, 0.05744406112259435, 0.005961032124281291, 0.10301846319869642, 0.10304785799235107, 0.032841595595762614, 0.014459786039116162, 0.023825382325618018, 0.03267189562921563, 0.04908244891632949, 0.07219475468680744, 0.04033028891670608, 0.08034075910766279, 0.007711566971509808, 0.012149326146520194, 0.07626879494637251, 0.026331050997419704, 0.007925814950853706, 0.060428980993287223, 0.007648707542102785, 0.03541199678194619, 0.02761738923107905, 0.022953049497558706, 0.01490996803172053, 0.022693609991561503, 0.08555080050662642, 0.006223377976341234, 0.035265524601263386, 0.0937480332269784, 0.01911079871558374, 0.03912919711682104, 0.027076205569169214, 0.01796922811697568, 0.04869730587327673, 0.02418541300651287, 0.029351971254894332, 0.04273153022832928, 0.08043007729875465, 0.021508535174953363, 0.04912787026936009, 0.03147347939140614, 0.013837216068960488, 0.027707649710317774, 0.051344695065410874, 0.01647474953994876, 0.03592931297457507, 0.0238410392475705, 0.03294569545335347, 0.03828710560957271, 0.05579683418956496, 0.004263632656675914, 0.05427821426682415, 0.0563498309272672, 0.028091821736926516, 0.02483802224178949, 0.10299420119413447, 0.02028638936368929, 0.03800117095271426, 0.05938740402099587, 0.032322157339583484, 0.07878614454379967, 0.039799941568485195, 0.026199289620102897, 0.08638245789634605, 0.05539224400455433, 0.05746342782532016, 0.02622032830972345, 0.012646883973971972, 0.037546252621518034, 0.10728955659414492, 0.0075487110429563594, 0.04345708444053608, 0.06857760160440399, 0.03996556211683539, 0.019607357755904237, 0.027197368120053605, 0.016180860975216475, 0.07128019126192217, 0.03054697648622096, 0.020571130838605668, 0.02588892824977877, 0.007865147969324984, 0.018227447627953464, 0.034733392268178925, 0.03861531299809295, 0.060744456000505924, 0.05666311109258283, 0.03435742312801942, 0.015492587474234884, 0.024430593701019406, 0.01764293977870576, 0.07323128697011741, 0.02928189910768021, 0.0479932749013026, 0.05293105248241656, 0.032989825948231646, 0.018792155934798143, 0.0475769674014901, 0.1657786076107333, 0.06478091581694542, 0.0979683886192018, 0.016595021513621175, 0.048861850068093314, 0.12315729062163061, 0.03619579282859641, 0.05877443409014133, 0.028856339180962216, 0.0726706714880082, 0.04542384664678285, 0.023318839244424336, 0.01857667646911596, 0.023848665652856715, 0.0222639495792288, 0.07102142974373794, 0.011363056593484456, 0.05609259009361268, 0.0454840075314766, 0.025114807893612215, 0.052472816990508195, 0.0321506685577333, 0.02651996061866803, 0.05686228629201651, 0.03845453029498458, 0.06003416609019042, 0.027368109966177615, 0.0442993329958089, 0.027513831380694628, 0.038445122735274416, 0.012205212260596456, 0.05848780612371141, 0.061671694350098415, 0.027186478180209958, 0.03286643599670741, 0.005118053870260595, 0.09655234403908254, 0.021403328320311926, 0.048766449138882666, 0.03284354528952991, 0.02610064430853292, 0.0312541943839601, 0.047104176239020405, 0.03168522800889707, 0.04252300109534014, 0.05167283350601793, 0.011683013215060196, 0.02907319568968829, 0.044771756436074936, 0.04300637576248377, 0.10207801366284971, 0.05113551858812571, 0.033865460615244605, 0.023843260902550914, 0.06143596143491807, 0.05121693458227862, 0.05676089072479837, 0.04140195399222355, 0.035414865781222625, 0.02858338013832127, 0.08076761563819262, 0.029817028759768414, 0.017009293134774894, 0.04926709908871882, 0.03339795162901282, 0.03982395842491139, 0.04281452819404583, 0.021666127121857098, 0.07103633781474444, 0.07498653996134959, 0.06095648232486941, 0.022744483975393158, 0.047896096648107615, 0.027048116955425472, 0.04858867843605338, 0.009664987277750288, 0.025115600794613845, 0.15842531266952717, 0.15561914792464626, 0.27397283743466105, 0.08578018255291447, 0.09611526023476355, 0.20940590529672562, 0.1694988071798317, 0.1793678582555825, 0.12486589651915336, 0.15931605842084656, 0.20385277908175223, 0.12794727068995276, 0.1721873314630601, 0.13738437075047724, 0.11445672281326787, 0.1709645938488745, 0.21575187122629536, 0.10912033053295267, 0.11096231233809264, 0.14565448907594528, 0.18909829338231396, 0.14676573025363107, 0.1601834384904754, 0.12163878178163884, 0.14835537801827156, 0.08408884427720502, 0.2005353885432405, 0.13977278775024798, 0.13686784362841037, 0.22024784207103715, 0.16333616609054227, 0.2018179576243124, 0.13137981956524233, 0.14671113882814685, 0.11895509151321267, 0.12084707587717042, 0.1103082647727382, 0.16005787667968582, 0.2199772444944228, 0.2776300798981421, 0.11019442410719012, 0.12096987977143257, 0.06719716479100528, 0.15055089407870847, 0.23223313442882032, 0.09130343133884092, 0.09419794134314984, 0.18500503963760792, 0.11850349800360781, 0.1142203234015934, 0.10214792684681955, 0.12083294155496745, 0.12602871839678095, 0.11637185069341814, 0.09569540574786164, 0.08249813931122904, 0.21460877611271797, 0.21177262668648075, 0.16025981745652615, 0.18745713386564486, 0.1630283366408079, 0.1940797188229138, 0.1732219791700763, 0.11266208524184843, 0.2373538959410883, 0.08531162785666604, 0.18973224646141454, 0.11481958801948255, 0.12620346305230934, 0.08952666659869495, 0.2958291726967981, 0.10051841952747877, 0.2736022347404111, 0.16658634007457765, 0.1291701768434817, 0.21745166711268887, 0.15004264070622383, 0.22416005391747723, 0.1526697707032004, 0.11189353817533101, 0.08569129337106021, 0.1558841224158964, 0.10922898478325337, 0.21011058361299578, 0.18247696480924086, 0.21834596751197693, 0.12248506378983298, 0.1293818316152019, 0.12276407301185593, 0.14671751267967686, 0.21820286228772134, 0.1963676710522944, 0.1805684099634809, 0.13061236800445666, 0.1160909798777392, 0.12246706838449165, 0.04914168283463486, 0.18259984531229545, 0.15339689539565196, 0.2234292673247476, 0.1623983672189136, 0.22016980835506994, 0.17301856750442138, 0.1497328500714033, 0.17308086577442386, 0.15443160438970213, 0.16227214657250913, 0.09463029838497601, 0.20272664515481842, 0.20980909737127446, 0.11790126862545168, 0.10196428791049028, 0.10516701040849571, 0.09246304330806579, 0.17576238801402433, 0.13527891598641872, 0.3689525715045391, 0.13310304242036036, 0.10594101202103401, 0.19681457610380268, 0.12450735204883161, 0.1417929922500926, 0.17247242342320182, 0.19556899374771505, 0.07933148423269873, 0.16543563004703293, 0.16194427626267557, 0.16083144162210727, 0.14333411600560914, 0.10759384671766913, 0.126885786922949, 0.12476518660062745, 0.12031215498404157, 0.21607739730708062, 0.1374083646242657, 0.1600964415457941, 0.11981261203125601, 0.14302797194930816, 0.12670045493230706, 0.183081025137536, 0.10266620064935378, 0.2047932592611159, 0.13077349161669133, 0.1332796410086655, 0.10279508728173473, 0.14768390195263972, 0.16362583925647123, 0.12244523487864964, 0.10299995451444581, 0.17703210213972678, 0.1452396524649474, 0.22864430361697752, 0.13800669461488724, 0.24194541327174635, 0.10254882065759552, 0.15175169093474267, 0.10361621862337475, 0.21529899068897773, 0.08775814496461423, 0.12062113356566238, 0.11976975707277177, 0.0819029426202178, 0.10836087693009647, 0.15546769234201602, 0.17659728595566365, 0.10113382561793251, 0.15842427078995014, 0.14079972861274598, 0.2577138469824868, 0.18632661791578417, 0.15623598659951843, 0.11589573470935707, 0.15043723727426223, 0.1277535040712645, 0.1319211526142974, 0.09903716554324474], [0.03392141184679443, 0.018558857263997197, 0.029469023744064956, 0.009143509312472757, 0.016959997292067257, 0.041299562510703845, 0.014472885185011454, 0.06152834780814667, 0.027111794183691664, 0.041117497885058966, 0.02999524570881359, 0.048374802009352756, 0.047291718393323884, 0.0722361617391148, 0.04952346275170003, 0.022274151955160405, 0.018785439258922013, 0.04935775027279893, 0.030612601493034634, 0.030869407571792126, 0.031151946543926196, 0.0261457056002391, 0.04800952362617658, 0.05136877703931063, 0.052391259270089294, 0.02787700876773846, 0.06371796499156664, 0.045677969502585555, 0.047407118047797875, 0.09346209857011996, 0.04082178411584708, 0.07744733694820635, 0.016439586104224288, 0.03140096150849375, 0.024984818094620304, 0.05611343151559273, 0.01731869306475405, 0.00970835647275371, 0.021137936311143062, 0.009717071680502306, 0.06765356933277461, 0.055819364835418044, 0.0696249510492048, 0.0930513452077585, 0.02992400527751494, 0.07670293697306226, 0.02854911877112764, 0.017578898658675533, 0.012404121244476448, 0.04092845802886352, 0.035319874709051464, 0.043665724656274246, 0.07541984695220187, 0.009332412230451743, 0.04716101996300202, 0.039902696941768935, 0.02237596695551709, 0.009415587354000778, 0.05202211597333512, 0.10165506418073371, 0.021926221633029562, 0.020654929366203088, 0.03657419812835513, 0.0231909389502459, 0.010609842776771515, 0.11780263480520058, 0.01577151721463569, 0.03832563217128477, 0.025352226202225974, 0.040166847888500466, 0.030588446740782073, 0.08838596934032056, 0.0033681113047585374, 0.029907354356480703, 0.0478285315236257, 0.045417706452069745, 0.04327388600476327, 0.04854895294673982, 0.03340185101654741, 0.1386762554607084, 0.03113174289014311, 0.028866068497600577, 0.005714499284588402, 0.03391211536983329, 0.030840648631114635, 0.06496456241415394, 0.04203763459959338, 0.04328323610787911, 0.02827371016234881, 0.053431227457739656, 0.04052796258380817, 0.04485510680223665, 0.026255472593249816, 0.05069823943138604, 0.0494113304622231, 0.03942642007924376, 0.11819769868687277, 0.0072375055395006655, 0.026660185352328326, 0.025260887454233827, 0.05862393994785606, 0.04181672165530824, 0.010765110604434965, 0.025766926832617294, 0.05515591354079305, 0.01740672231291331, 0.029156735662611264, 0.03888211843948211, 0.05481220436312499, 0.08949505781093914, 0.06771512449749055, 0.015067579130822373, 0.036546572997805574, 0.02458326736344926, 0.025996933240563642, 0.016235984831808076, 0.042100993901370995, 0.01779923320657784, 0.023735173557314183, 0.025772073028248646, 0.013656678831114644, 0.06150937947114149, 0.02715615833538675, 0.05702828988432885, 0.019622376909659758, 0.03230899594904434, 0.07933169873731752, 0.06476770080025158, 0.09062300736625349, 0.03639872568929869, 0.02285155433891041, 0.05404558017729752, 0.02099298098455033, 0.04078701138496399, 0.035574246543429555, 0.05846645525326172, 0.051894638942734855, 0.044261522726306034, 0.03979739049569734, 0.05762312651401567, 0.05962672988854109, 0.06298809770434614, 0.043548084194621736, 0.033547082134792884, 0.010865231592869087, 0.01604414683946919, 0.05751797328552893, 0.02808547086803423, 0.02266555202133473, 0.07854730131164675, 0.015309909978250583, 0.05574707294844332, 0.03135477023709926, 0.009825907876685021, 0.03284187138741536, 0.11518476681122858, 0.03845284490155117, 0.04923442543874826, 0.04936257279628227, 0.08440012112259866, 0.031158056095122334, 0.04170830872270369, 0.015661821084757967, 0.030026910037943916, 0.014097237801780144, 0.06464818342318458, 0.04294246487740067, 0.01988803704960212, 0.054197794186972806, 0.08188961269033533, 0.028188705046270645, 0.04261698859233049, 0.08007195417679126, 0.024018677800232847, 0.061557769414878664, 0.020656158937321558, 0.023841205871694034, 0.03615765697172573, 0.02904558396567741, 0.010275183012709022, 0.02703393092228761, 0.028204754588284323, 0.0014719359610500117, 0.012663032149805898, 0.036072130915859056, 0.08487368603387187, 0.03747408330861119, 0.007841775584365092, 0.03418166723643099, 0.07754702030891374, 0.02947881051729764, 0.009879215147286173, 0.03710331590545755, 0.03643175940059366, 0.01759532741421173, 0.04682878678243968, 0.024264603515245745, 0.048691372522303177, 0.02860735485991163, 0.04921213228015169, 0.037942710783212416, 0.047963692416106506, 0.021648681384601423, 0.04264640636862286, 0.024629749748254978, 0.02983588792924439, 0.03851987759492571, 0.03876763042963801, 0.03680614656918953, 0.018621230227572304, 0.04875882656403607, 0.012724855445295334, 0.025927351389621055, 0.008172236228992623, 0.05873537509732189, 0.013761071717336535, 0.020646000611445597, 0.0795538182700834, 0.02899728786771096, 0.07459293930761277, 0.09342203983255933, 0.045199643354862935, 0.01499590011418707, 0.06976420285120126, 0.01665168520694058, 0.04641876886448553, 0.014314580776338136, 0.09768428491248239, 0.04939101381047119, 0.03891895194688151, 0.07828254898589465, 0.016767370229166363, 0.023925105905941418, 0.023663873754201398, 0.03560123199056234, 0.09212055604063696, 0.01992961647169244, 0.03978327149525285, 0.04475650745594213, 0.03976814891962756, 0.014465563299675143, 0.06127350482969515, 0.03457676176162016, 0.03981457384783895, 0.045415871671491095, 0.07323832731814155, 0.02607124951487828, 0.09481630453299131, 0.052238754147002776, 0.08206418880652036, 0.022334356889909795, 0.0682743150560606, 0.017740949237298582, 0.047521805240502285, 0.025584339351964094, 0.013057294511987318, 0.07434761497162043, 0.042111535271209095, 0.036570654971705335, 0.04634081558775037, 0.046133404943130674, 0.06473980753892852, 0.028013343689963225, 0.04393560211023977, 0.059108777842935056, 0.018891366236212275, 0.016357005656426473, 0.01511765351038306, 0.05702419131393394, 0.07156780365133478, 0.044401674681613525, 0.015292903783941462, 0.025355252249526884, 0.02688398261764838, 0.060657137298896435, 0.04341799480419967, 0.014596562419507294, 0.07101963709799514, 0.04315499298935456, 0.026101151841782758, 0.09409324010653843, 0.05399444763879142, 0.0499631742375993, 0.1298583995911383, 0.03795807084609424, 0.06492100265477935, 0.037952761856778976, 0.037325979360649665, 0.09606626891200581, 0.0660475196256753, 0.008325403060523734, 0.03139275862204452, 0.10750832066180245, 0.012393355793920497, 0.025763297491076014, 0.020353921929434426, 0.009145894718746985, 0.013947996213251065, 0.030818491453124635, 0.013392065358798833, 0.11029300430128652, 0.02064996320123394, 0.05609151374007906, 0.06934861547403759, 0.055029715877026326, 0.018094121516051314, 0.021262735864447973, 0.04452880314220825, 0.10461617786917957, 0.03544058335284072, 0.05796937527315271, 0.024313003035081972, 0.03632489013515654, 0.021946220358292905, 0.019799262780936498, 0.05104489038668333, 0.0264169390298306, 0.061415192791290825, 0.027683094677124775, 0.04385757988559143, 0.06012978535445948, 0.04453443388845171, 0.13266963583807792, 0.026792684089272257, 0.0023611188930038724, 0.03879091950253614, 0.009849657559947623, 0.023234592555391214, 0.023196108128514983, 0.09229474911285986, 0.02688677117769276, 0.05909684602351439, 0.031651602494680596, 0.018928588533233252, 0.05685118567799369, 0.048835439186903744, 0.03254591630050733, 0.022173962976423003, 0.027556379904009165, 0.12519676223277085, 0.030480564324065085, 0.03398380587778745, 0.050321799147153096, 0.10047561053426997, 0.06679560448373519, 0.04132650965344041, 0.05495347863724155, 0.04632622927367207, 0.04523258130516737, 0.039624040120191155, 0.047833097407654415, 0.050654622215417125, 0.1541205267271688, 0.12112276793848123, 0.16156228950187085, 0.097801833443584, 0.13937520343930493, 0.08372377273776839, 0.09898435144174485, 0.19332021925478213, 0.11791403931114944, 0.20408668104679356, 0.13468253185912488, 0.12590828171420482, 0.1088050930129905, 0.16177517001426991, 0.14186239981603238, 0.11329224618572382, 0.18683684779511345, 0.17887789906272966, 0.10444904046673929, 0.1268414227712539, 0.15057318723730503, 0.14714978545183136, 0.14126117401305707, 0.1097777565460532, 0.11116845127675803, 0.12212789827777494, 0.10086315143252574, 0.10495694909965801, 0.08610864275044973, 0.22418364942554506, 0.18224376764508987, 0.17309798017865227, 0.0579478788459974, 0.12831614968637306, 0.1315042322441455, 0.16673572721981234, 0.06304734311397038, 0.05732971483901624, 0.1682133882516815, 0.07317255866984207, 0.17784116759655938, 0.1562246025329636, 0.1851401928692095, 0.1403021698276843, 0.2609220087047546, 0.16269470534978375, 0.09137936597389561, 0.14629887627257457, 0.09306756328911552, 0.15675327980950957, 0.11029585414836485, 0.1295528377616598, 0.113342639449383, 0.13655014696621126, 0.12729455611758655, 0.11004230202806574, 0.23591550457621777, 0.09185837777031046, 0.19798333516284344, 0.15758623188782125, 0.11810470327374437, 0.20603179360830015, 0.15554247784518427, 0.09268750706987997, 0.10592801916983821, 0.2795015714101253, 0.07662957639343317, 0.08416607360085172, 0.13616601515921856, 0.1826873019097313, 0.15648936251959494, 0.14009714937738835, 0.12451233928121867, 0.17544648399756801, 0.19153149588213814, 0.15120914746676722, 0.11227940900191186, 0.09394641935585007, 0.09534482093107316, 0.2728732254716658, 0.3032580192290968, 0.07989227591503052, 0.1581194750483959, 0.11123249622722788, 0.09968559002323497, 0.22807261816436247, 0.12955450783333472, 0.140456888944872, 0.17817489081813445, 0.1442787483815224, 0.14012613814444314, 0.06560652877294249, 0.09968906040153197, 0.1312583793074854, 0.13295773086288284, 0.08043396136453075, 0.2782580574914333, 0.08959274168216413, 0.13772920224695437, 0.13841682744603004, 0.12409972432520121, 0.2133179945690978, 0.1910273027756522, 0.124966629420317, 0.15745087947335937, 0.15609510303024324, 0.11612708560161053, 0.18233877786945912, 0.18814089798158218, 0.17008166219438278, 0.19840377953744706, 0.1779433637256584, 0.2714225613782483, 0.1564200928494815, 0.09750072258494555, 0.11429652616742159, 0.20003982158678196, 0.08219076185336999, 0.11561596706028908, 0.08677258051090664, 0.13102032514589448, 0.1630723254094201, 0.16759218287564095, 0.15513910190953364, 0.2121634541019317, 0.12368932336328492, 0.12448502824671807, 0.24096667466144409, 0.15098661424652224, 0.07888058786310496, 0.14930862122245375, 0.1689764731112988, 0.2113749198014698, 0.267182142143288, 0.11438778256096187, 0.12032782914297235, 0.1331733999353263, 0.10455852209199822, 0.12036348287496837, 0.12464956861109504, 0.20117088911994813, 0.1538234837954083, 0.21305945521641165, 0.11994494605929622, 0.13293971247490377, 0.1346345900768234, 0.4109296851581143, 0.09382624314316819, 0.1017803808433875, 0.18251955929783084, 0.0813340763711641, 0.12285708374674283, 0.34926919867434814, 0.2322986349463463, 0.1298133689429491, 0.19238664918849546, 0.09695497686944662, 0.12801935956362756, 0.25275116005251486, 0.24976752337909516, 0.1350339517117508, 0.1368135126728204, 0.19221821709746317, 0.20217348370821248, 0.13181036097868798, 0.19744096023421134, 0.18261142856171056, 0.221028991283909, 0.2702319994568825, 0.10731871390054304, 0.145689912981564, 0.14489658297069613, 0.14580315609853114, 0.17662619811392602, 0.14929463245695637, 0.1270030520015186], [0.039990345061185865, 0.002038640645144868, 0.021583293865044272, 0.0717896244098102, 0.026702929228063554, 0.02267679819206317, 0.03758768265646312, 0.06340249764522718, 0.02097254367395034, 0.05269366481731977, 0.05096351269692664, 0.10282983702998008, 0.03948807866582948, 0.04462010933146362, 0.05793881985629278, 0.07018879942235447, 0.03004740097469861, 0.03968641116854645, 0.04235126716535419, 0.0362711567281475, 0.05719124827714217, 0.01987463242614702, 0.0033898892692260205, 0.025445928331464533, 0.02070640281383549, 0.07448250007244848, 0.0469067515504937, 0.023686180319336635, 0.03663300686786252, 0.09173457796174674, 0.05614253519583614, 0.0164204377365569, 0.08664573167240427, 0.018022425262437716, 0.07238285991573527, 0.004667865653191844, 0.03446204392539878, 0.03924381536161227, 0.042837909197494875, 0.051589349074469465, 0.02611929854948915, 0.006842768202806193, 0.017862584847476215, 0.07445503582036303, 0.04200968388167601, 0.024207384408181234, 0.005508993804875401, 0.0349520375922082, 0.05808837554087082, 0.02173881354411283, 0.04834130098442397, 0.06860583960529297, 0.02572161081667629, 0.01106318296684373, 0.04162811080835039, 0.04292250445653354, 0.05282047918186553, 0.023105575688063137, 0.06217343597522667, 0.051925592725315405, 0.025793513914029446, 0.04035768805131797, 0.04507198246316083, 0.12354729066212332, 0.0514912974810408, 0.0022368450675369993, 0.011023112737964238, 0.07495381268522433, 0.021525283772197944, 0.020372304209177534, 0.008229250407537386, 0.055860450130797205, 0.03047976567740402, 0.05538632214489964, 0.04378150352427075, 0.012431814365329282, 0.010918009305192579, 0.015398969614667999, 0.05536499425708767, 0.05931575947831716, 0.013448097029580705, 0.08631374747041734, 0.02089759154665855, 0.035575073918387774, 0.0592241506843317, 0.03339974810519526, 0.03639530510671678, 0.015319762826566736, 0.05499332287018338, 0.017117131501436234, 0.004956830187790817, 0.01746416550069567, 0.026625933561233744, 0.01990007995177181, 0.0016912684898876076, 0.030527383787557486, 0.011923407775259787, 0.045234914042896805, 0.0113368985213099, 0.043614343139192754, 0.061547335297349966, 0.03612796723422024, 0.052490410199689294, 0.05143875151031441, 0.04612178721975896, 0.01655802521253786, 0.04924086057731221, 0.035586584389450095, 0.014040337578814118, 0.05428592877222165, 0.04458896019646237, 0.05599534289250451, 0.049523581495328296, 0.03234373803641046, 0.018889133089912996, 0.0077639922833881315, 0.00901027896156114, 0.05129272366062768, 0.038298436049972816, 0.035619135465352766, 0.022618477833607507, 0.07396434884398215, 0.08129707432442135, 0.026707433825058323, 0.012698724186198126, 0.05251763696451822, 0.022805874431205374, 0.06985019622070175, 0.02674457376762744, 0.0687277088722875, 0.059090142754176934, 0.038258997843630856, 0.06824295141644056, 0.04917056817981986, 0.01955746244939585, 0.04455507229713183, 0.030560214485552524, 0.07984775854575057, 0.005633072756726536, 0.05400173696539095, 0.02272405432567241, 0.023433252560695814, 0.037368064400770014, 0.009457168691310911, 0.02431321370926115, 0.07340203264668103, 0.019902642515878526, 0.03494165327039457, 0.019374993712370916, 0.06397500281192123, 0.007816393655018822, 0.06278967710151788, 0.006702709614464473, 0.06035115412105957, 0.0903964292017683, 0.05159394177157552, 0.03685894151849132, 0.038791268072541685, 0.07438748984807923, 0.021601250965989405, 0.0640909540497007, 0.027904710507080443, 0.014613717043351744, 0.030138699503074733, 0.04066414620366789, 0.027901571461810704, 0.06855943765971931, 0.029393278715771534, 0.052033342991865454, 0.0230107129356193, 0.09583661107406502, 0.05503843395760464, 0.07448702765208098, 0.04180235367628836, 0.02260906835867753, 0.03230517700074181, 0.09696901926109869, 0.02260772578959023, 0.054724586887225035, 0.041939460432096835, 0.04058202540862464, 0.010622458329664604, 0.05544956653348862, 0.04624625352481681, 0.070514302520502, 0.07353118740983548, 0.008312091325229455, 0.024072070298115575, 0.13310400769114494, 0.056705108032591885, 0.026255576015119592, 0.06490861501304374, 0.0668671800785007, 0.03403004694489702, 0.04306256831172974, 0.046288058942844795, 0.052262583311887524, 0.02284251833184352, 0.037333249535051086, 0.019604534721903263, 0.12079668261351124, 0.08025930863955329, 0.015760203053603972, 0.02301497621491792, 0.09777941771091954, 0.06285185662789211, 0.03001796213098832, 0.030548140939865864, 0.02589819599844275, 0.07307841412482724, 0.11740012454890436, 0.08406639790102359, 0.04625789040038663, 0.05473086880820413, 0.06332684263226486, 0.019403610926782413, 0.030426888373650374, 0.09459961656360857, 0.05307771235464081, 0.03325403818199712, 0.04825357242577499, 0.01808143318480542, 0.010103112961646291, 0.0254957489444003, 0.021744258514034654, 0.02360736519368666, 0.05516838545220033, 0.05765082442291802, 0.08817700353721458, 0.04143401477185469, 0.04148394838275929, 0.06943240251031614, 0.049288495924443974, 0.015764747870214764, 0.048236580595614455, 0.06119898745730039, 0.031114299068107244, 0.04456344180770459, 0.0089586025006288, 0.04536625215663545, 0.015058259671223501, 0.019784241711961168, 0.030991608171813914, 0.057822983531701955, 0.03609623970283616, 0.022549836355591976, 0.07787446927038894, 0.05387530947524694, 0.018195704774810903, 0.01584815856580052, 0.05416242007706916, 0.0194792065679306, 0.024916563491006533, 0.026546304467164224, 0.021480105652083314, 0.06963640406367279, 0.05215173038924414, 0.040423464360496694, 0.053708624064682, 0.08335284828659027, 0.015123721884353267, 0.05846938170913247, 0.0390524274459289, 0.04432154954561303, 0.029423996926315373, 0.04615702343383624, 0.03456090757202718, 0.016184490316757755, 0.03530583231739941, 0.11435127081049067, 0.023928968904299602, 0.014709312367373177, 0.022637135905003356, 0.09141470560984266, 0.03590566767079215, 0.07020119472496933, 0.011275429541485445, 0.05528208439148242, 0.04466565708900171, 0.08838719508099942, 0.11410934790488213, 0.020137850660830736, 0.04789756370648261, 0.019169504033221353, 0.03863361866904363, 0.0898232345559424, 0.053296993531647234, 0.0520139150021057, 0.04786647585851531, 0.04130606276674136, 0.06736818625922165, 0.0295963169135634, 0.0274292801717116, 0.06246275674071043, 0.011060788942080353, 0.03791442298660836, 0.05063934642220697, 0.04499996253739923, 0.00444443371605068, 0.08090020247524785, 0.014546519641073482, 0.02324386604971463, 0.05035865180675061, 0.00526933660430293, 0.04883875634761588, 0.05136727167653942, 0.022563848103727066, 0.04944144920896619, 0.018742777737638643, 0.03974776715040207, 0.03177984561320515, 0.02549614922534074, 0.057077231411371505, 0.010442464056635096, 0.029327927585390788, 0.11105841040731439, 0.05420168974406777, 0.03975772629341772, 0.02869561010400855, 0.06216937187878836, 0.03914046243974759, 0.006292633282306094, 0.03407272187271907, 0.03397116542703683, 0.07031990004883659, 0.01818937880377616, 0.0907487377163864, 0.028139836297580795, 0.010691185034961711, 0.04975046992542283, 0.02668736806710161, 0.05239227433658896, 0.010147913783458213, 0.026037285006755305, 0.16945428214967254, 0.019225336521142916, 0.05456348242718847, 0.012362408714609282, 0.022684296277622064, 0.019256089205643343, 0.008812598591189711, 0.029938172158454696, 0.031715289299045844, 0.06008460148868542, 0.05703459095750606, 0.048000870663071835, 0.05327670369297267, 0.0462609279390064, 0.03960755007762102, 0.04214192214872568, 0.002933931931282484, 0.04446966881533304, 0.09813199435631115, 0.0720495810251563, 0.08188700033051353, 0.12645778892141196, 0.1287114740379395, 0.1480214249703192, 0.12161471895993718, 0.13004169378790165, 0.10684969955154004, 0.2015385653583273, 0.15334181367389618, 0.16894429741847902, 0.1937123949849798, 0.1364934564598145, 0.14880971412264532, 0.10968712834461082, 0.16265021096314156, 0.1031571097912327, 0.11464195521247965, 0.12822385141325573, 0.14502591393407316, 0.10736172973749139, 0.09911728301836599, 0.1604664466914631, 0.3269388082046663, 0.2598814774424799, 0.11597649569833472, 0.13297826201925356, 0.20170609346560894, 0.21250280040887096, 0.29548657817705987, 0.16876134030040235, 0.1635186482341059, 0.19548031140960034, 0.14795096020304388, 0.1210108501536231, 0.13814383967509195, 0.14719006635489004, 0.1330192017579271, 0.1798922147962355, 0.17224792901787067, 0.16931001247177202, 0.10658610401855362, 0.11387444236466002, 0.17768471712066283, 0.13512888532732764, 0.1936584011080765, 0.12812005416039499, 0.1536698218795561, 0.1152288321886332, 0.19218322220108203, 0.19713596530979682, 0.18930276224930442, 0.21120411283787222, 0.10968644652635821, 0.1402770268220094, 0.16659781607168336, 0.12052646808085904, 0.15072353965332433, 0.10217952797369612, 0.13951941183017147, 0.2070972074063555, 0.13039999311008763, 0.20145801887396844, 0.12270051835765763, 0.1076156036147187, 0.09444056138876947, 0.14378148070987196, 0.12328567929686078, 0.12454300578082762, 0.1536507769337585, 0.11636455753637899, 0.07593730870153635, 0.17192205053664025, 0.17914121880406336, 0.14061180724491998, 0.17055976234616774, 0.14652580683750493, 0.1282420613232159, 0.18376676576031795, 0.22725780704809775, 0.18498533585619542, 0.10944695211946966, 0.16810817373616083, 0.3297470107434258, 0.18423119890353373, 0.16752775488120897, 0.10099875665600262, 0.12398769928803369, 0.23254801188745808, 0.08742696515494779, 0.1236918591143143, 0.09628098803542315, 0.1569255423401633, 0.12193505862547506, 0.17924962024534905, 0.07385430031365926, 0.15962698286579502, 0.1059134864819146, 0.12845195409271026, 0.1794234149518513, 0.14998020454039498, 0.2162029437961117, 0.18858682244054734, 0.15338410172731648, 0.14654800806555057, 0.11209150295584433, 0.12667964032340434, 0.21461562493876105, 0.12680302644448896, 0.13879861502397445, 0.2006590044907024, 0.10266973231468471, 0.08846689120776231, 0.07749430579884399, 0.15555314178909027, 0.0922459339903247, 0.16516472603524887, 0.17263500260249262, 0.19356135308982866, 0.10120082766779008, 0.12131840381170474, 0.17619976293175452, 0.1432609086435649, 0.1453480539062331, 0.16941167233932405, 0.18831496847973717, 0.15764042494758485, 0.1328749474017851, 0.19926925970902368, 0.1481844331588476, 0.24840313610771012, 0.17556363416294898, 0.16130759591056457, 0.1510092138402885, 0.1831454378102095, 0.1482208683005264, 0.2171085976184376, 0.11091546606152289, 0.11427031829953195, 0.09502523203170109, 0.10578094561013485, 0.1325173222369725, 0.17540110094893366, 0.18763198577348264, 0.21636164657050566, 0.056318478778966015, 0.10048232912536591, 0.1839239516806218, 0.11305193972563553, 0.158876400561102, 0.17532208664042337, 0.08283815977554168, 0.13578974341432895, 0.14604949933146277, 0.14096831392136314, 0.12262156533618128, 0.08548084135738113, 0.285038456561104, 0.08259136455073472, 0.10159572301011893, 0.16779649852504655, 0.11147510861196827, 0.18659482529807478, 0.12287594483143861, 0.19065437117411246, 0.1688330614518735, 0.14094261933238278, 0.1819248758857289, 0.11948700934167832, 0.30804989919547116, 0.09552460644514331, 0.1656004615248211, 0.1915306991506969, 0.11883677689418679, 0.19147010159588632], [0.0159204245973078, 0.027101109172367764, 0.052543783545373916, 0.03902328163084965, 0.0476120465675429, 0.032214453038308895, 0.026947845622236212, 0.048413332401504444, 0.04852710411913934, 0.008772541768848896, 0.003932417415442967, 0.035560924274426316, 0.017788479247340755, 0.05994963977906493, 0.033629785156658584, 0.04531478636988229, 0.03602200961341301, 0.02929490536541468, 0.048382443736397454, 0.0686055944571572, 0.014982972380464837, 0.029899260637560682, 0.03861702903504333, 0.0018346945134614927, 0.05390920120501711, 0.022974245235203736, 0.039653764331653234, 0.039587957378957546, 0.11511771113521631, 0.043905142454370376, 0.0035368553372175106, 0.014495885059718164, 0.043236052752622676, 0.09164504526603608, 0.042874788670169736, 0.028436438728784843, 0.07042056400208704, 0.015404206783240362, 0.04194964174061053, 0.03119921608407411, 0.02249718121733637, 0.006486167680592307, 0.014585239639986428, 0.036219124036330375, 0.081455547272438, 0.05873902933672071, 0.02279436204492325, 0.009666693738601621, 0.06206670843605554, 0.024698538698195934, 0.015229851874943464, 0.048371297157099175, 0.10136596558074798, 0.06055677595037607, 0.0600469597585259, 0.0108742541933973, 0.06812375579630175, 0.021148109958777507, 0.08134755951863143, 0.0577625889901913, 0.06494698069629169, 0.03271637852453897, 0.10766156122929628, 0.027697263473284342, 0.046060944516812606, 0.06633660290390253, 0.029000798465623975, 0.05612683805426764, 0.04644970732530759, 0.021658745864706657, 0.021880915193187616, 0.01719717045254525, 0.058512098771790345, 0.0347459867536541, 0.012670976481580687, 0.058695209107451865, 0.030508003678293, 0.056195755323935906, 0.02665541645499968, 0.03861673792163211, 0.0317375269162679, 0.012650523849222209, 0.042218350910491524, 0.007196639057984877, 0.0341393600308126, 0.045477760084454096, 0.01188462840453271, 0.05465534019974932, 0.04739353147846076, 0.02898145283031608, 0.0600947100188463, 0.030813975364811, 0.041536705027664864, 0.016612342761589155, 0.029503999488247983, 0.039571118766381856, 0.053065018277735486, 0.03189638865390613, 0.005127523195809655, 0.10066155539525133, 0.020907742211655266, 0.04491571201792648, 0.0772479166006369, 0.013176043885910224, 0.0400518465997471, 0.033572435814646945, 0.02339849515157121, 0.02908526923537495, 0.020548918119241154, 0.056684289593249566, 0.02490504727428479, 0.021913914430525996, 0.040400765175300266, 0.07112308195041073, 0.03137516732808323, 0.039799313376387285, 0.05374875941103505, 0.03420295298940713, 0.09242180479510177, 0.027423693475523786, 0.0765832817001689, 0.047609775116847414, 0.06809420778506226, 0.01868404177648406, 0.050848863808618444, 0.021279271872293566, 0.017950920530805187, 0.026302161821795088, 0.021166057483623588, 0.01086663544899033, 0.03391543636098504, 0.02178801362582993, 0.03476035090223436, 0.05774987959152749, 0.04088714290710707, 0.08404938308822532, 0.06376853445544839, 0.04242008867403192, 0.10134623881669776, 0.07033552824249191, 0.05216208789798041, 0.03217655849913436, 0.049960929599981156, 0.03506587442731665, 0.08635090273474494, 0.04748755344940771, 0.037372036566657406, 0.02211603906846816, 0.0508214914870839, 0.028838862800189567, 0.04391034036093662, 0.012979855471771332, 0.13290353780311923, 0.024137894487789562, 0.023461335428780126, 0.062418021036372076, 0.028192183085446878, 0.0619921067939891, 0.03133033969319396, 0.022249761630871126, 0.026750076194143584, 0.1081500878377307, 0.09597712692113654, 0.027189130759647778, 0.03824462603417136, 0.026385485374879454, 0.036260013979288845, 0.029904295750443014, 0.07445990047868221, 0.02662493190127275, 0.03331431781031913, 0.08643441397937075, 0.05717511829589644, 0.03901997213101676, 0.018601302365441958, 0.08099981688804204, 0.08711955705357176, 0.017000611443372986, 0.051440486699462905, 0.046094725163833755, 0.03450522830169048, 0.020830005354758714, 0.01119582151483384, 0.04401486539732545, 0.025881761497247125, 0.06171692035070831, 0.032997912006272424, 0.02875539943605902, 0.019905710698015267, 0.05860038274418443, 0.023584438097332756, 0.027851239485185475, 0.0350078241148543, 0.03720257791780657, 0.04968735577178098, 0.046480641955690044, 0.023420409096645254, 0.03939519816588971, 0.017167384954049222, 0.030652528080428322, 0.024206585761520173, 0.020315719039870367, 0.01698123324932831, 0.04210353348283999, 0.08706505755863844, 0.026894288415449764, 0.03931990321425181, 0.05313054560833881, 0.034419280897465446, 0.02208094266543706, 0.0321552152895639, 0.013737766365070018, 0.05157492746929488, 0.05794544268639819, 0.04290181625213835, 0.06615598235399493, 0.022955592909467318, 0.07934419363136254, 0.03578961684158252, 0.05900646297020778, 0.020599719324720003, 0.04886212969018568, 0.09812083245525438, 0.10503237045580342, 0.009887624877474962, 0.030172279052015756, 0.045376667121966044, 0.028181003947411815, 0.028291217186638427, 0.07157745635918072, 0.014970478444029729, 0.06176274773033877, 0.08939485351044325, 0.036200684299992944, 0.05301611888552866, 0.012307170902438944, 0.04423632226403683, 0.02182368267958443, 0.032477868540633115, 0.026066484447989254, 0.02017148000548684, 0.07150242570787668, 0.030644579918213913, 0.10320600152256028, 0.016536074878287413, 0.009778900721651173, 0.058242780562009544, 0.013764487511868921, 0.05991724958162635, 0.02540350429743769, 0.04175369943221731, 0.009776827496206088, 0.028788992391538717, 0.06930291832935426, 0.01063703123720423, 0.02648539090108487, 0.024298989371727073, 0.05840600325515675, 0.05956284198609572, 0.048793882747451146, 0.027031245784113006, 0.09294302037526524, 0.04159111642248688, 0.012699747871186946, 0.07277851368510917, 0.03216478755817779, 0.04500203863567403, 0.05088892637661869, 0.07650851151875912, 0.03719648751880854, 0.08063303697253428, 0.04211343516926131, 0.0009793937351787463, 0.05314609336276209, 0.0113374175458786, 0.05470579858088205, 0.05394750943167075, 0.03033215585615366, 0.058863668011561524, 0.03280005447806851, 0.07620491087436676, 0.04187172293783196, 0.02738333596367269, 0.017912897671903336, 0.07979904301464558, 0.029809511522011414, 0.05625370221452848, 0.039855827682561455, 0.07172986955171631, 0.10656741147320117, 0.022105440242035736, 0.036386146525582, 0.08141001866709802, 0.06379678011721661, 0.09203928177275005, 0.03374687403500561, 0.009569867885851813, 0.02722904394050279, 0.06312343862748916, 0.03901394684949229, 0.037571671418845654, 0.023584286794967713, 0.0117827013638171, 0.04224720178171993, 0.07680495690193868, 0.020459578860731378, 0.012221318301594546, 0.05894236439358323, 0.033804579607902036, 0.05919085267270285, 0.011455622997375266, 0.07585304669074475, 0.019327812272334294, 0.009879556056412478, 0.10668096868621726, 0.011572477261295483, 0.17590085074545878, 0.05202841321607271, 0.07714152997059208, 0.021470498909512838, 0.0467392311040913, 0.05333745829580773, 0.06771946821602122, 0.04442487948483998, 0.01239324183834176, 0.036024032085533106, 0.025917895949415626, 0.019603391335676276, 0.11544956510225612, 0.04026735862416606, 0.05350328568789748, 0.051756379224600337, 0.027251831225810513, 0.007156612879161033, 0.037010293679251786, 0.04126270602066671, 0.003194136567594063, 0.023212172992287144, 0.021809852877331358, 0.07450520691852416, 0.01971238074944385, 0.04536456293276241, 0.06546153897239317, 0.03810001927758417, 0.10021065136477833, 0.030134334717126145, 0.03269220845052793, 0.036717253556895646, 0.056717162426080436, 0.021863931023906318, 0.00891024032757888, 0.04226793212095096, 0.19233437134854256, 0.12332543159925169, 0.12058646042620945, 0.154002687082656, 0.18669718996651713, 0.1265035243704915, 0.08264859897955772, 0.1286251359288731, 0.12042152169611185, 0.17922813913995223, 0.1084697533458952, 0.16643258622817456, 0.10344214812521974, 0.25528370883435975, 0.16861939952979166, 0.1890901728503166, 0.18308378305406342, 0.20397912230222456, 0.1796707540990845, 0.20802896950514088, 0.11789984370191252, 0.10017214012482475, 0.0891748866847446, 0.09509649353041764, 0.19262407515798846, 0.06368849358911957, 0.13885703688908008, 0.08949639080392738, 0.39717129762134246, 0.11182665869954134, 0.13435089239670386, 0.1505632280942894, 0.14379208336674398, 0.2852347282873046, 0.09271997387611097, 0.1189322237886729, 0.17779454348548768, 0.1473650561585542, 0.07731956880419485, 0.23472311936559218, 0.08628773878538802, 0.1186117385664294, 0.15092770208514508, 0.1608730401963957, 0.18429760340481036, 0.1609495877017898, 0.2237091958522797, 0.13945778771754236, 0.13615593344213503, 0.07714769697838253, 0.18724699594801475, 0.17812016149682386, 0.17489735217344377, 0.256834730445858, 0.13626199065437242, 0.13120553456246853, 0.14825298270631224, 0.06863954747396131, 0.2076677896923596, 0.17725553934372243, 0.1404859236772022, 0.05269356522588961, 0.1615215489460576, 0.14281665425627463, 0.11528350788378909, 0.23165270025211, 0.1377748610872415, 0.17725552402196393, 0.11683985380636108, 0.12392321000656775, 0.13570585678662025, 0.1156368735997427, 0.1865007803444901, 0.16285103325161243, 0.13704664854993745, 0.1354238598216926, 0.10285412201717978, 0.22062835794302726, 0.19082254279525052, 0.13737480997318222, 0.09812658577556573, 0.15852473556034027, 0.14129215460871497, 0.1386430072447946, 0.18773992756201377, 0.24121182279721384, 0.10397249547344062, 0.21661349031473362, 0.1190216568929534, 0.12207920572930768, 0.1694113046171204, 0.13920972844766033, 0.12877587138885452, 0.18139521801663985, 0.3059447815100993, 0.10778841772867788, 0.11561253498638831, 0.12244713477670185, 0.11358511393829701, 0.20500454631063247, 0.1633964112449077, 0.10595844052131138, 0.13699242484665689, 0.10695017964368868, 0.1562936270549413, 0.14590218062362365, 0.14842374370463435, 0.09432331929283758, 0.22130957864705594, 0.32888687786556065, 0.10054943842753288, 0.1062292832460615, 0.23819316058389603, 0.22562325120933596, 0.1843819190417567, 0.1158677112130869, 0.1692938786600867, 0.11626812238847056, 0.13417315999827079, 0.18699170480812752, 0.12851906339487723, 0.13106486549781216, 0.16375371465279212, 0.13935277238488197, 0.14770329929888248, 0.15006928524423033, 0.10999151805956518, 0.1378880582389332, 0.1560727945498882, 0.1432912457253664, 0.07014747663971878, 0.11424116865401307, 0.11667133744565711, 0.18947779801824402, 0.12472528874153092, 0.2198359778811855, 0.11360035142711095, 0.238297563046217, 0.20858916363889174, 0.22145775537337029, 0.1655216004338957, 0.11249946775816141, 0.13391508029833918, 0.1568472787978188, 0.15405637452438956, 0.08565432196783443, 0.14936569477281264, 0.13154929353585168, 0.1192438530345117, 0.09771289829645427, 0.17380964521679187, 0.14468885056914824, 0.21643920531195981, 0.08646226893629759, 0.1670716108093339, 0.17695518691212903, 0.10813594585464847, 0.1302496713375853, 0.200242605060339, 0.16986161109901246, 0.10381046021657606, 0.17952974795574145, 0.16649223383395903, 0.227465171727442, 0.0864178128540516, 0.10081154008906695, 0.17913631584134795, 0.07900807255458447, 0.21635320428158009, 0.11870778300949644, 0.12145197890218228, 0.14670629715246541, 0.24461840129187032, 0.09897128964263587, 0.20004991862562396, 0.10871243467854877], [0.09673390687713701, 0.026590118950773633, 0.030570811396765134, 0.014319376486744133, 0.016298198832138892, 0.0240451040031809, 0.018491117854512507, 0.029969964807312337, 0.013775701123860576, 0.05609529821442501, 0.025841283326547955, 0.04071625167383783, 0.01714235494634317, 0.0317458140723888, 0.010203661044098197, 0.019452343694865704, 0.02992796403686366, 0.007523786851144847, 0.01770761483649333, 0.015440431250739965, 0.019516283308245966, 0.05937204012767442, 0.08432552714141146, 0.03506100210811823, 0.01604755401551243, 0.1064781622300225, 0.013092131402734066, 0.07134140934795141, 0.013553826739230465, 0.056578427733432864, 0.03763508051633835, 0.022791010410254522, 0.02230765106486938, 0.043146707748453465, 0.04642791978474106, 0.025271572465557727, 0.009326894482177113, 0.0966025381198814, 0.03663881381432857, 0.04626709111635724, 0.04370269988993964, 0.07212231341268747, 0.07287427467564422, 0.020709654857074062, 0.050768914872840534, 0.06615807377402821, 0.024372328883938255, 0.03556735175211103, 0.009803704733419563, 0.05863907018436059, 0.02117245240257152, 0.027709095701274854, 0.04741642218563826, 0.0389685063442636, 0.02241739890568199, 0.06502266252233137, 0.07057918250680932, 0.09644801818555403, 0.05445308532686003, 0.04408535697767812, 0.01624680965417816, 0.04458145636524405, 0.06125663174316288, 0.040229923737746094, 0.023482251544332793, 0.02467435904808583, 0.049232215275086706, 0.04709147450123583, 0.014569760833476341, 0.02833435368243485, 0.09909068444563497, 0.057541767976457076, 0.019729278733833663, 0.09286271137816292, 0.02488888090386266, 0.03512435757945623, 0.032291287826674606, 0.04486955139004896, 0.03859433368028652, 0.053211015483905236, 0.005822602909193525, 0.07026026010393135, 0.034266446356571494, 0.030455417487950578, 0.04527185480260561, 0.03416595860354362, 0.028405592198513692, 0.028562676612167593, 0.03164004797356264, 0.05292798430027981, 0.009108207023312009, 0.02695658668545225, 0.03594398355832504, 0.037415423956249035, 0.04815664315115541, 0.03687735827219102, 0.019237873550023765, 0.08028179332013093, 0.02786753226011511, 0.06674324237411061, 0.06300497845175766, 0.0063471710816356205, 0.06618770605493939, 0.04766195336537016, 0.06539603079398794, 0.028911166178483157, 0.054478530937265006, 0.04410240626443298, 0.019773399652612787, 0.03684093079139148, 0.022761134896427396, 0.000880970349704336, 0.05684668108099892, 0.013043634206687492, 0.05213237517783719, 0.04560463573603381, 0.05302910407584521, 0.0037080925070650636, 0.030198419887212016, 0.04806222664492746, 0.0317177331195243, 0.04082021746604193, 0.02880210973202221, 0.05871376758741756, 0.06652705236187866, 0.030134966739663677, 0.04683231461733099, 0.058099131415327715, 0.03727977659793631, 0.004807849069155994, 0.04481264254859379, 0.017050746152357712, 0.06521302004975658, 0.024523650401181752, 0.010131739752156841, 0.007276630128598622, 0.017716560828229113, 0.05120149791060437, 0.0083659520943559, 0.0355237843318572, 0.024561592820851554, 0.06628181995643724, 0.053576094684221094, 0.05766651390360729, 0.022761795647262086, 0.033724546402452454, 0.017320711706434528, 0.03761308996247188, 0.08100286591798067, 0.08185913771270745, 0.07063116157247175, 0.02069656241444811, 0.02080290307921748, 0.04317217634149617, 0.08942715177733092, 0.017081640563124133, 0.042668370109411984, 0.0646450884279705, 0.05253462879467876, 0.04709409452193687, 0.016633188014008825, 0.013568015645198045, 0.0536274072533894, 0.0407402110736697, 0.0641363600809728, 0.035122185720190886, 0.0520193733785662, 0.024054894606853207, 0.03642921598868505, 0.053828302320213094, 0.04964254728908982, 0.07783084056310116, 0.051886621832607255, 0.02901991427455458, 0.0409352379069934, 0.04115016770458991, 0.013620015778278392, 0.018924357812671412, 0.05445912593014298, 0.026276610874300523, 0.03617880865931511, 0.08383850206530864, 0.03589472410479381, 0.01962356051550277, 0.02284000747867169, 0.07707908614388398, 0.01996866780363264, 0.054200548273060596, 0.01653794796326228, 0.013859973668361144, 0.029228418509686188, 0.017687141136716933, 0.051660296477137074, 0.03255269234819758, 0.06775706781134491, 0.05995244749130742, 0.04447696580281181, 0.017820233591802178, 0.009607511531231145, 0.04765270285368447, 0.021140508451348832, 0.07373470632779984, 0.10160437980366331, 0.04038062472377093, 0.039855521247391744, 0.009843887002657979, 0.032893861944396655, 0.011091725487682608, 0.0804825619824471, 0.04607029461992845, 0.06191071761291354, 0.040168682669079116, 0.011881752701986943, 0.03348256220980998, 0.038195830063834306, 0.0202734692908463, 0.0413870727342944, 0.009988340541660305, 0.0687282987599892, 0.0323500620922254, 0.02714931142456349, 0.03878272236174634, 0.09728168272563527, 0.041286707555334416, 0.019692464378632365, 0.08651585678660101, 0.050931444256416256, 0.01391628496123538, 0.06368285135155724, 0.05830065084380969, 0.014079534467459928, 0.029633774782621095, 0.03753523627716688, 0.06415907458792772, 0.011837556132025296, 0.0845460991765703, 0.06412045609566473, 0.046588296461249554, 0.019193509398328683, 0.07162080927481575, 0.018380728415063313, 0.06784543605341066, 0.018994562110052477, 0.05306771107678933, 0.046407901907279614, 0.014180720318108799, 0.034164843945613796, 0.004888410396468376, 0.05583288628728159, 0.007503589421826145, 0.021954745001670335, 0.009274818697914241, 0.031902842944668185, 0.030607137370914705, 0.011032723310974338, 0.006606712094282792, 0.02464704418314561, 0.06649218770044465, 0.062288326181231014, 0.01714068678988805, 0.037023382291438124, 0.01621797027426862, 0.034303904225629185, 0.028784796144933473, 0.038523826778175375, 0.027901883642639846, 0.06966851080857939, 0.04691933837508963, 0.05850121266238632, 0.052578881863624825, 0.02757237773508795, 0.04925631257074495, 0.046115578077132666, 0.06774170774846308, 0.026352183532810984, 0.07004786222692459, 0.05841470984441619, 0.019439940731371605, 0.030019130415072846, 0.03941682865843177, 0.08162336649313089, 0.0441171036612603, 0.039675341198040594, 0.04663642210465285, 0.022377198441855373, 0.08756466945933719, 0.034854993404399966, 0.07415777072310448, 0.0706324256175468, 0.05128340037058919, 0.03246729652727804, 0.01806103992426107, 0.08511574683530677, 0.007120923715598521, 0.045202573641173305, 0.07475789335946884, 0.018948884117567254, 0.02715204061279374, 0.03636895168212153, 0.055704551238206126, 0.032590491126381585, 0.10338429316517808, 0.012695078565288457, 0.07840411947859872, 0.05240756162111798, 0.06094705561296113, 0.04051668193912314, 0.04368146776311821, 0.014349576630329174, 0.04442211773787295, 0.010545308487640034, 0.0400256808666933, 0.011921322100885935, 0.04839820599543953, 0.03542012880526243, 0.04101263193954383, 0.05675674235868839, 0.042926580044290716, 0.02325675930948027, 0.03412083219436388, 0.00800180369086804, 0.02611531297706308, 0.01021432115756456, 0.08145893338106333, 0.005215838290525661, 0.0802067090426722, 0.026376587263638937, 0.024821706484222127, 0.0019114660995734496, 0.03229638614181069, 0.08168249315912686, 0.01838301327229748, 0.03565158694982529, 0.026750099176781315, 0.04086853846186592, 0.07570227292636711, 0.04533118448190151, 0.013843859008873903, 0.023912607181456783, 0.027566582279940768, 0.059796291959261706, 0.04381639116834249, 0.032161738528239156, 0.035894042286541195, 0.06616168970903082, 0.03390938426638323, 0.03929546500946726, 0.015038052187000793, 0.018024309838731444, 0.03420259292808271, 0.03744913948579662, 0.03709234935682147, 0.2966723597097782, 0.06768021387078109, 0.14463897824527758, 0.06717600544253666, 0.10587929597785396, 0.1441413888166989, 0.09486855172942724, 0.13054389506578445, 0.12486837864402803, 0.14772700205925973, 0.10425590204014894, 0.16006040476983593, 0.062292436242944775, 0.0895075986702596, 0.11898869979045085, 0.10372488819543393, 0.06935076818110482, 0.07135905235284759, 0.08875329317825456, 0.14728199690580368, 0.07278045188755759, 0.16603736146803827, 0.18911310952276955, 0.11349229472539119, 0.12793751839067669, 0.24078839067970556, 0.32965897191916743, 0.18318507519941177, 0.09080210340119178, 0.1345711426749345, 0.22992049884651938, 0.19572781909617687, 0.17676188760707456, 0.18672953419868024, 0.2050266709298857, 0.17299445105656502, 0.047646298358637484, 0.1955793665782098, 0.2038064154405748, 0.17486329190433028, 0.1633711916304404, 0.16820177435874942, 0.17510756669986635, 0.1589290767667755, 0.08976715691988507, 0.10274398155630597, 0.1669727854671017, 0.09240980019732829, 0.12388124371007567, 0.28446919194632964, 0.09547102625571913, 0.11191519548095043, 0.23771064776566722, 0.19214125590458994, 0.11025310644219, 0.11133717448120156, 0.16351817325959284, 0.21741654964223986, 0.11473301242315963, 0.30363404582585063, 0.12324449441005146, 0.14118620464878698, 0.14802130239625133, 0.20652150765301722, 0.1858075167382917, 0.12749750813048694, 0.16646286202294214, 0.12724323588753902, 0.16822281113315016, 0.08216016430167422, 0.16728755567343007, 0.16790922070222516, 0.15225232939325994, 0.15128491356247856, 0.23500678640219475, 0.2397193762684061, 0.18694696527334953, 0.09120926381118837, 0.11746227726220124, 0.18306918141822662, 0.12611961472899685, 0.287781081973545, 0.10037945117801429, 0.12153070209728134, 0.20727368342059277, 0.11153243497134217, 0.0832244749331186, 0.10865013640854629, 0.14123649066013677, 0.19782967324699127, 0.1803732720474082, 0.12016158806340349, 0.1855070876979059, 0.09249202441424133, 0.12976513604723638, 0.09458801799243498, 0.20254214053913472, 0.22168304651014267, 0.112793768095153, 0.19877960695134056, 0.09157972860961192, 0.1636504306788406, 0.23713303279251824, 0.13730451374525024, 0.23214788416460638, 0.16415728977130306, 0.22101544684940772, 0.13512799666533548, 0.08948002716586476, 0.16032061419419705, 0.14680671595758008, 0.21285103333573188, 0.14447538782992672, 0.11865781109419563, 0.17611432880643876, 0.1561104707540043, 0.18143067256577555, 0.12465783469979802, 0.15550023575703945, 0.2626354103126834, 0.08091945426478502, 0.1650115850591852, 0.08299538400024176, 0.1535365225807313, 0.13768211848312809, 0.1272294539657812, 0.17130174914435034, 0.20858263656977685, 0.15486013865278614, 0.18235043772766668, 0.11746417716025345, 0.07972535301720904, 0.20161629263912478, 0.14677446365596789, 0.10263485233149222, 0.09957053893876654, 0.10075667287192999, 0.23741826264848634, 0.14808102661082823, 0.0973691316621919, 0.10518275351533968, 0.14429528055892837, 0.15732737077820688, 0.21891943028857633, 0.10375006184462579, 0.11147010605782272, 0.05548547690493926, 0.1550728965911173, 0.1563346127588903, 0.16120058874930107, 0.09868795202384073, 0.09132196300572927, 0.1374352083451325, 0.14832131774915805, 0.19792517376763208, 0.11922313035615992, 0.14651961684707673, 0.13136935480419668, 0.12251625122923045, 0.20296934180923049, 0.14679609797894955, 0.08290839471643971, 0.11532090829625247, 0.10434332799406783, 0.17133507396905653, 0.16406234083396776, 0.2122055736160086, 0.14237742540576767, 0.15336652767033349, 0.1096301926900783, 0.17319893524531396, 0.1625732804137853, 0.1360505657090295, 0.07768107803478357, 0.09098470045794403, 0.1104843577430133], [0.020079072564840317, 0.0463031470445135, 0.039849358070040905, 0.015732402680441737, 0.07719987522690527, 0.030377192250002297, 0.0189869242134474, 0.06880651633705824, 0.031101202795041666, 0.05367869300948036, 0.039432380243294665, 0.07923166297616498, 0.017378229587789507, 0.018334466280535828, 0.025053407861700943, 0.02129848727265433, 0.03407718816531762, 0.035679461058950236, 0.04048753995448351, 0.006791714667117284, 0.060947024969444166, 0.012471903746406878, 0.03175732071301149, 0.015073566107950626, 0.0225205430685873, 0.042155366991796804, 0.09020716718007481, 0.04322176904327447, 0.03276512086872132, 0.04111485871215982, 0.04120288221465965, 0.01778814025343426, 0.05546598762814557, 0.03855878337016029, 0.039925813644884095, 0.03499203121229526, 0.029261976991209294, 0.03596619627768955, 0.024454281139638157, 0.0246210201763578, 0.022572478084194086, 0.03904222698521711, 0.044889419880365176, 0.05321910920282526, 0.05496613824019029, 0.06293610331692523, 0.01954265780025913, 0.020236061217503685, 0.05915232228055116, 0.032688791698385636, 0.040754762913791404, 0.02862690925417889, 0.03874033854733552, 0.030578003047154318, 0.06155514173329838, 0.04294658259999368, 0.056228428973906466, 0.03401391313321168, 0.017447606510212346, 0.02403832220983121, 0.05919158428667053, 0.025762152189629215, 0.009983277658090718, 0.04980489281156371, 0.04620937405214195, 0.05882138761902048, 0.06852109495910906, 0.0339413799285408, 0.07969386680352111, 0.04880435899981568, 0.025092196808527076, 0.0434149227916233, 0.03586725985270835, 0.029767801864973964, 0.014972309394168758, 0.008672109557195537, 0.06324955968246346, 0.0774210524715243, 0.025162707541077852, 0.01563365969266142, 0.016039522541236254, 0.02466715590637778, 0.0872546719807771, 0.0727216623002483, 0.022339162176414844, 0.035026872891091534, 0.1069558946596038, 0.04506999446499733, 0.04104038347460089, 0.07818305714716835, 0.06899921809353175, 0.06302476267240222, 0.04367907756879445, 0.00849943716950234, 0.07361700457911338, 0.0500868438112159, 0.06982107721869985, 0.021221809532313098, 0.024863827913518877, 0.0638191307324075, 0.015514308939717952, 0.03027744185660155, 0.04844896698130235, 0.038241948556875995, 0.041615914688595844, 0.02682531177396736, 0.05089750656137063, 0.03303624704600342, 0.03200277145351133, 0.06655919741118146, 0.06828506326963825, 0.08476618857633683, 0.030045453196151123, 0.032629638219312314, 0.06591465699696733, 0.03485778196444435, 0.01535923071881576, 0.03267232463845322, 0.050076382880609845, 0.059003440753346494, 0.005616057943928266, 0.035496733767250856, 0.06306095266594522, 0.09477171055491894, 0.009171749228581546, 0.016677096343388962, 0.011996318278233371, 0.0665957857704451, 0.07044558443369404, 0.06191201230150558, 0.016727769229140495, 0.12896247508545078, 0.039723708159140045, 0.040142628018774336, 0.044782018183820674, 0.016863146541459907, 0.0372792556581478, 0.05014913825077876, 0.04021459814882086, 0.09872301586813505, 0.061192678723243944, 0.05136226529195424, 0.01948906228907647, 0.034012821457919576, 0.01034148121928616, 0.03564016840931389, 0.04554828230832373, 0.008967358885603327, 0.05759584995347166, 0.017398046367170832, 0.058996228035539396, 0.07506244395288729, 0.084690154349852, 0.035338827724298166, 0.01916984685756747, 0.019892380768132788, 0.036652572753448645, 0.02923981789799948, 0.05519278152214904, 0.08218221231213502, 0.03778564743697643, 0.02631161917722033, 0.016790483101841905, 0.01760248650586413, 0.048626814292924064, 0.022473564641850612, 0.01618079011208348, 0.05351360872267716, 0.032035969873710025, 0.07483513800487404, 0.08981931218577009, 0.027963852494834896, 0.0356758029891118, 0.05011053508027427, 0.048337026213806485, 0.03284262981446039, 0.046134891153703776, 0.028483532068710175, 0.03922541009923143, 0.015967768831028333, 0.01336197246752319, 0.031617456040675604, 0.06700407999056963, 0.12049881996767176, 0.033981404192144835, 0.0327817258244801, 0.019019011806155887, 0.10906270539928829, 0.003150203579758865, 0.027220615058115898, 0.058686042865437854, 0.007608322259564434, 0.03084401367232204, 0.021388742006233624, 0.06347371700910792, 0.017775432769990256, 0.035496844849999876, 0.03861789471439777, 0.08639785626362409, 0.07451585554067167, 0.060527036417155504, 0.03380578619638278, 0.03746135475774927, 0.05094988016231407, 0.015922718073031115, 0.047588236554856264, 0.027845744719548572, 0.07755609078993721, 0.011252032258668014, 0.11658576542451499, 0.023074256098498742, 0.02340961300257233, 0.01070135964020606, 0.07182633534314171, 0.028701114445744504, 0.032400811586769364, 0.027016362610964045, 0.04915721909773927, 0.05866995118858834, 0.051170390910438956, 0.0358122700615035, 0.1077045387618484, 0.05180984833127549, 0.020480253658587896, 0.04600717663584698, 0.02916659329897694, 0.03410158423526633, 0.024082584854876323, 0.034943430594378905, 0.037308903260817455, 0.11234726140936536, 0.12447172129947333, 0.09260309950238274, 0.014780435970263376, 0.045640461837812785, 0.031678373437194575, 0.025442739490479715, 0.007018345978952224, 0.02590903422735151, 0.08512386736730415, 0.027678779686891267, 0.0677848614812378, 0.024455374730150067, 0.05141623235578018, 0.06272021207898375, 0.02474720251836604, 0.07248284971161235, 0.03536133538751352, 0.01747203705411765, 0.014564977571999115, 0.0736221450290853, 0.02545600621810844, 0.0665947821952643, 0.027216324965739926, 0.022585809929296378, 0.027819284042643926, 0.04022709304286588, 0.01237100996677914, 0.033394025428400885, 0.021412010011713833, 0.08141980927077033, 0.03172415102110996, 0.008415019068296158, 0.11601094667228962, 0.004004290587486579, 0.07335090393861456, 0.08551694708125246, 0.12102184351533653, 0.03720171606889175, 0.04537028943999641, 0.08835431458728929, 0.03549846512595973, 0.04074918196326302, 0.02101922141117675, 0.030978724488147327, 0.07870873135905113, 0.0056502656849672, 0.023011281755903078, 0.014437113666997082, 0.04199876712875501, 0.05467000695305967, 0.053594308424620866, 0.030657672360839865, 0.05367162584837887, 0.041083732559796304, 0.037458999037382104, 0.052563027674031836, 0.02418281788366937, 0.025051186206720533, 0.014470454771071674, 0.06313258954774469, 0.020844836816972783, 0.04534653688390409, 0.04755115789932109, 0.05360852701649551, 0.007258039568701098, 0.09666071483685125, 0.03619549405430594, 0.025316610774626176, 0.053278458034319263, 0.02022485143595165, 0.037291497743177804, 0.04220411316641877, 0.04418464580310449, 0.041827105977121866, 0.09310748413084977, 0.01841062499630836, 0.04208535038595719, 0.046627213727803006, 0.026703745111702915, 0.03379327215013966, 0.027039356740011324, 0.04523799754679204, 0.04438915297449116, 0.026109176612789595, 0.048408632452088984, 0.00908217918608458, 0.023996955377139875, 0.050088180634643764, 0.06522357674135316, 0.04244833816623977, 0.04530027666459641, 0.07073741796756945, 0.01929265458226925, 0.07627970403841428, 0.03641560260627059, 0.07963905321253885, 0.13110824139608493, 0.0798873882740736, 0.10811742950951862, 0.05001406162796963, 0.021290539110439922, 0.017380715543103796, 0.053257873251793854, 0.01623107612343325, 0.03298145643765888, 0.0757936901983715, 0.04358850299350677, 0.02390030955505227, 0.05278907340740966, 0.03558702489000655, 0.010330376774823714, 0.018280991428201238, 0.027005101118477124, 0.02486203909821568, 0.03159088811146156, 0.08781043046544637, 0.042779636719534476, 0.046002894204350255, 0.07782016129743669, 0.013605931251790496, 0.06055512503089924, 0.19848279384595735, 0.06391605617658747, 0.20672908683698024, 0.070117162540555, 0.1679864117214757, 0.106910435002177, 0.12991925761584314, 0.2202142720981952, 0.0832149371384613, 0.17054750493937926, 0.13891596437221573, 0.25883570613880313, 0.08924204195218702, 0.11069655643715975, 0.13707660258777682, 0.07859964809951284, 0.1045303300563847, 0.10522283523553803, 0.18188488609608144, 0.14258063788856232, 0.12983868048796732, 0.1615536020648095, 0.3910792745169132, 0.07695046764227652, 0.16988494613718602, 0.1595745058429818, 0.2428579159201153, 0.13419033568953315, 0.13074632613889633, 0.15023324338178481, 0.14977020451859122, 0.16777586011636644, 0.10691381344992308, 0.16411815800013083, 0.09564855181041265, 0.11352468492282976, 0.10935767223277401, 0.1592388367580791, 0.14308475438625584, 0.13316904855591635, 0.11046492209237431, 0.09171961626458554, 0.148581680391104, 0.15908515952046842, 0.16796267831758147, 0.19009903403780154, 0.1033854959232192, 0.23011582062369396, 0.19862940775290613, 0.22831962023290897, 0.12648892273465473, 0.09064454209780501, 0.12378938976795444, 0.10450871871604074, 0.19742229833237587, 0.13063888996839523, 0.1453150201949381, 0.14714241568599978, 0.1102267453567155, 0.19632970373476707, 0.19124991260468963, 0.1442327677843071, 0.1556787495651553, 0.1299686089999253, 0.11369743008887577, 0.13901443731400276, 0.145737839442107, 0.12290732379281714, 0.16780929219338203, 0.18022947734402073, 0.09966749502646347, 0.10822480439298576, 0.09245166690239022, 0.10746833087215502, 0.17128403719154098, 0.08274449786591916, 0.20817975093039776, 0.11936436632588027, 0.10500339701050714, 0.08706216174628466, 0.19349802826200763, 0.19211594435957172, 0.1317936296184217, 0.18708746579866256, 0.1173494631544717, 0.07915065683905156, 0.23386157688594636, 0.21547431757132854, 0.099468358131426, 0.16711294891372805, 0.12923762322433535, 0.20202475539859266, 0.1795406264042662, 0.13901538726302887, 0.15282216091309825, 0.14810370281338692, 0.16306544593986005, 0.09783590903445598, 0.15733163022706587, 0.14425518351697153, 0.07617972190341643, 0.09672827613089355, 0.11234304026490259, 0.18609231758502223, 0.2706794867352132, 0.12859792448580265, 0.10001850119161029, 0.12852051896193337, 0.20096493404238455, 0.1784668928913532, 0.22305365441547287, 0.28402412550583966, 0.08313536358576629, 0.11789174615255288, 0.17138511483227054, 0.13708648512200003, 0.09595346246515551, 0.08696295336009034, 0.22345580461044467, 0.21612127882338342, 0.19451350844915838, 0.12867335350282733, 0.23089531508664932, 0.24196096485660923, 0.13605750646562348, 0.12480093226317437, 0.1371726393699646, 0.15731140550586487, 0.18424884956930915, 0.26623562519108096, 0.17783474777975392, 0.22405612642966935, 0.1324247788157194, 0.16930180000922374, 0.11677748658844542, 0.12092910091122314, 0.11854239228752353, 0.18137114753405895, 0.09507877391672905, 0.16670528288570144, 0.24436657286940083, 0.13662363011990825, 0.11060452629481593, 0.3088182547400075, 0.08090664527469105, 0.11218979969740876, 0.25211979635059834, 0.14238822724550002, 0.24378486698673618, 0.13733411538264445, 0.23294712837424972, 0.2415189321242994, 0.20631181406638316, 0.220136207738711, 0.13795705211739387, 0.18150361945792554, 0.13857715432682347, 0.14934036790603591, 0.1613405683348256, 0.20950944974057137, 0.11842017828096306, 0.08724697279713808, 0.09242692226243597, 0.09343393717802341, 0.35711813718080526, 0.23245926826230942, 0.08426570333540441, 0.0964504313625155, 0.11875803837732923, 0.20029632314558954, 0.2513897145587591, 0.073746764551728, 0.15760146171575592, 0.20409867798368778, 0.10371781720389282, 0.20060591459754976], [0.07538944858336642, 0.08124687258274325, 0.027965913271351207, 0.048987339100530075, 0.06444529269731815, 0.03789877564075493, 0.03924798287992035, 0.03380499329538115, 0.09544042104314412, 0.06098328774133998, 0.03357687146372853, 0.049547828178131775, 0.034758401208467064, 0.05818752264003119, 0.041249851065297286, 0.03841892635870365, 0.05990969978513257, 0.01618371656795423, 0.037101500277077, 0.05048813981815212, 0.02315392349696448, 0.09480469064005921, 0.02148156696479888, 0.05987069058802821, 0.029632434128753604, 0.03514920564128026, 0.027055442671201406, 0.10607297066599132, 0.016300391758822145, 0.020503000724279595, 0.04656285851172382, 0.07782054434139883, 0.03568526417497666, 0.026130065915264913, 0.04286629658552908, 0.045377333618460164, 0.03212843285573106, 0.08405961036201447, 0.09516298230136595, 0.04439605542668893, 0.03704432713528795, 0.03774777205000001, 0.09272225681812533, 0.0184961453065156, 0.049232042905303745, 0.04364018328487874, 0.036883080948985396, 0.043489922799410365, 0.018271039946064837, 0.051592214243306275, 0.08347722266109721, 0.06093845627601109, 0.048971569180608764, 0.03345919652811943, 0.04265276872883401, 0.02924467872587904, 0.055479662297593976, 0.038812500199363116, 0.006898729489260023, 0.009704634243051612, 0.008489139990190105, 0.08768319092210262, 0.06790404944049735, 0.01686881176165996, 0.02662859571677062, 0.1010359808682434, 0.07935473500120063, 0.017098392990808335, 0.02881365850748074, 0.048517340328544385, 0.019349607473780072, 0.02121389009839585, 0.02605773189345435, 0.015055285334857482, 0.015589806904655792, 0.044542481642096274, 0.007945992270364396, 0.010539898949284709, 0.023524891998198245, 0.024004062757857388, 0.032838037117354335, 0.04894996167070443, 0.04375257987468954, 0.08609536644672194, 0.013167220468242324, 0.021481149446880145, 0.10085591956252053, 0.05503460734842285, 0.04280012957150898, 0.07086076578425785, 0.01604804814222359, 0.05473379909451451, 0.04534259536153367, 0.02591163126541482, 0.05728195308737698, 0.06544784898118627, 0.030608096896039865, 0.02598936812231137, 0.02230024874030102, 0.051272533413383274, 0.06615379134253149, 0.023768050220584678, 0.045587061679050814, 0.02715750090447405, 0.04975620026309645, 0.049737270230487476, 0.03353728387024134, 0.03234130570725088, 0.02569054978178634, 0.038911394489508484, 0.07205662137318043, 0.05376007069923705, 0.023343654747511593, 0.024904005394707766, 0.0100880631643738, 0.029003851326002233, 0.048794035965036, 0.02990997054674212, 0.028281957098853686, 0.03126854895644131, 0.020279404557039662, 0.05943930647786587, 0.02004976012563754, 0.01796505102256854, 0.047730158173268845, 0.031383737936736114, 0.05193447934523706, 0.034699512029727625, 0.02662851336231876, 0.043838381722208955, 0.017585262934106494, 0.07074648078771369, 0.04851092434217853, 0.05580842893029894, 0.03441120250030391, 0.05836238220874822, 0.11892604145912394, 0.029335475466664762, 0.03510598679103198, 0.010258011151886275, 0.03061717503794259, 0.019180912997633703, 0.04518876490633815, 0.052962339513244173, 0.06060914189044026, 0.01990710689325727, 0.06521190156138713, 0.10805140805220413, 0.019550969854237574, 0.06694726691010498, 0.029667160894361236, 0.030070412340724183, 0.01796876846422111, 0.03894823182734751, 0.05287128996344344, 0.01984830581462912, 0.0680589754014246, 0.09213120466278446, 0.06384394815071456, 0.08543754972878002, 0.021482750570641893, 0.03475820968648599, 0.04802300677364392, 0.06495360735683672, 0.06015635328367353, 0.03174906420040756, 0.04520810479598661, 0.05369651987547836, 0.05407554570645575, 0.05791922715762931, 0.007489966463312628, 0.05337445268167123, 0.0323683524414176, 0.05989281520728142, 0.018539266480553537, 0.014583354106082793, 0.016255926100477096, 0.02073887345050612, 0.048359238933171, 0.04452708710525786, 0.05271737906901587, 0.05096559645608068, 0.03607742458341583, 0.015193559417140581, 0.0529802774619912, 0.019110921289651625, 0.021697961905550574, 0.06584827547832843, 0.01998268338220735, 0.012031111118924475, 0.048857740006379546, 0.00859096743947556, 0.010346984603412209, 0.029326450950916738, 0.05181545992532084, 0.025918794187506842, 0.046993388433850584, 0.03076554137101818, 0.056425332722644654, 0.05009339003252888, 0.011370365072282092, 0.02467946693932097, 0.024837633452167916, 0.044212029615957896, 0.06620145733318021, 0.030602301440892682, 0.01596184792898355, 0.03271362443845118, 0.03458431538855357, 0.01964598582426627, 0.06664591090333077, 0.03265488464685698, 0.06258186043029831, 0.035197201049736435, 0.004948029752760645, 0.024298060490118883, 0.028909896387748664, 0.007335622250402888, 0.012475003529670499, 0.03415626376086185, 0.02375174212389656, 0.038036472284265106, 0.019999058511588844, 0.04450708071911528, 0.03412503418662856, 0.022943456161526904, 0.15884307573639578, 0.031992360318620364, 0.003218490263304463, 0.019317696081294168, 0.04583502135750267, 0.0035569529357035797, 0.05351075121471959, 0.03224628782200237, 0.022177531030930342, 0.04435648315496022, 0.03893803519707534, 0.04574197997909881, 0.053703023961955504, 0.04125679565233089, 0.04582902671949518, 0.042442657624281226, 0.00673281591227879, 0.03423625100103598, 0.09301779055667501, 0.005689672768987235, 0.06190340530367629, 0.046566125876720876, 0.06543084182926724, 0.044834472223996155, 0.04118543073174454, 0.026577997524591706, 0.03214750461460602, 0.09428925136284483, 0.10150976028413543, 0.07435753581023986, 0.029229458474043398, 0.04329634387226355, 0.028795735880492196, 0.02575315257173873, 0.044771166548373244, 0.018461177223211816, 0.09239949631474673, 0.04889983270737914, 0.04850186918291354, 0.005448064917037565, 0.09940281930950381, 0.06416483939955793, 0.06102383294473253, 0.02767349176499392, 0.07107234394718563, 0.1313948961755922, 0.04383811742187508, 0.035492233000695705, 0.08626785114287369, 0.06025626264031857, 0.05870811385853637, 0.019521178610082117, 0.05353160795845813, 0.021699059326502106, 0.06331875274378447, 0.04372461000457407, 0.049489333534673344, 0.001464525496797456, 0.05332533878484561, 0.05801494218288891, 0.10410495973642796, 0.0702499408995913, 0.015884345686513812, 0.03331711403124275, 0.048117944219660376, 0.06237960555740903, 0.02048654707088586, 0.027328595151043227, 0.011747990877577856, 0.016721291955740705, 0.08165360398350224, 0.039374192035005945, 0.018425475610720537, 0.04438302810153654, 0.06628228727007104, 0.008972624782472849, 0.04306067990499639, 0.04149901733222989, 0.05970154986566594, 0.012675436070909905, 0.0355843665649093, 0.029072058049120733, 0.04845326473455756, 0.007218817303392797, 0.026269654795948057, 0.059111769416279374, 0.03612676830661874, 0.07930244183948926, 0.04026294595772221, 0.039496053641121236, 0.05527586758797688, 0.012600100899655974, 0.007215622237943594, 0.051118442488293496, 0.09346613585348092, 0.05584311356107074, 0.03700249107374299, 0.06937344438366352, 0.06818413884649355, 0.009663186971128229, 0.03231025233324016, 0.03653959010637576, 0.07202484404608127, 0.021228463005935474, 0.09604084245379894, 0.020783928996552865, 0.08374364505852423, 0.05158989682733532, 0.021370738940013033, 0.034605773511312665, 0.033897222620585275, 0.020793847919952486, 0.0041727353668501305, 0.03189768717293778, 0.018706675844206926, 0.044856615995447484, 0.05633337152821403, 0.03597940746394377, 0.010407762188885, 0.04163479875592936, 0.04265943369377525, 0.08020788115719635, 0.010117989431525911, 0.038075224841914834, 0.028546132943442756, 0.01894199507190816, 0.18475552480066978, 0.15568326948390854, 0.11894530090954035, 0.13383245005482627, 0.15701142079647512, 0.15828905627131462, 0.1765615862583922, 0.10108854982160753, 0.16664649329839215, 0.10420990612117514, 0.07791288091891235, 0.18186450815729557, 0.09134198854406995, 0.10549003138176857, 0.16157784108673373, 0.13105277663036702, 0.09933552614623502, 0.12249764295354967, 0.20906111976552397, 0.20682979675550617, 0.14854861603629205, 0.14224608729202903, 0.1716975408095506, 0.2375033596951154, 0.09581520657746062, 0.12410173913644207, 0.11977347259920453, 0.1767580112021777, 0.14332346738346163, 0.15177672668810815, 0.11620377866371025, 0.19469289559750788, 0.16329821409477344, 0.09309921804214678, 0.13502932454068817, 0.10377666807823605, 0.19821253334802968, 0.1688236692139218, 0.18358382396399978, 0.10155835324117254, 0.16214918946066212, 0.1055935528429766, 0.1798202484966286, 0.21367538990753315, 0.1037685322244802, 0.1054472070668013, 0.10225473482522274, 0.15161293708989698, 0.1725929750189666, 0.11738887837817592, 0.2099212679651476, 0.1865857394952928, 0.17354635611897515, 0.10041449203967087, 0.10834675026877273, 0.06745412600256744, 0.20791560381410584, 0.16023732511506927, 0.08745029253224212, 0.16269493517616104, 0.15150364698661914, 0.13641044317233947, 0.15113705859309243, 0.14415637349649785, 0.1710440371666224, 0.12527494916632292, 0.34435544944097923, 0.1469606383433265, 0.13474913554326182, 0.1416432833479297, 0.2200676275477294, 0.17494399160627397, 0.1617826317106524, 0.1634513397490786, 0.1349137525164312, 0.1618354151686353, 0.12094332716397702, 0.1661314523868984, 0.18103120367853873, 0.15509885164999193, 0.16051895435779326, 0.15176328950591628, 0.1425436205200611, 0.23989395238459113, 0.13255620886000896, 0.16839752514516154, 0.27217056962751573, 0.17351981883327808, 0.19614382016081966, 0.10973501650075759, 0.21393984345899475, 0.17186568178717168, 0.14662774249670968, 0.097424381923291, 0.13033446194904466, 0.19376729284563374, 0.1191661257537142, 0.19216926407910165, 0.12896460480988026, 0.11354798165660714, 0.13161482469689462, 0.12594010500657943, 0.24079468792244313, 0.1157767765764748, 0.39926253379352633, 0.13969669989760847, 0.12020664935510968, 0.11036393638219565, 0.11050423006376914, 0.19054989210299908, 0.13694154128672617, 0.220952857465994, 0.17072750495806818, 0.2111808237649741, 0.11056785366588062, 0.14156765514804473, 0.111296771004075, 0.09413179731176746, 0.06221329169948736, 0.1428651323001231, 0.19562710917765097, 0.13011707683965085, 0.14819437698010476, 0.14311807921096203, 0.16244299950138216, 0.24150457563659838, 0.16418016515672207, 0.11391230242987795, 0.18341229687775337, 0.165568653554205, 0.10414258997526862, 0.139016842830085, 0.14901062834166712, 0.19206521401722587, 0.13944428924831653, 0.16401165645689736, 0.19373070448637011, 0.15671535845725768, 0.2302233946900214, 0.08499480453470061, 0.13033669892578356, 0.061144212170714335, 0.10787500098588006, 0.13582553504215134, 0.21977125877334228, 0.11738990493599447, 0.10886010578683308, 0.21731737189956252, 0.172585635896652, 0.11385864563166134, 0.12041949156311252, 0.10276456633883138, 0.0981647752585911, 0.09513234644527398, 0.1591927182650374, 0.10986479179513071, 0.17306393523129726, 0.2137773408884964, 0.22244084536308245, 0.18016134148403523, 0.1532705828186966, 0.10536746497476294, 0.13687905915562185, 0.1052895844763806, 0.1412864855580753, 0.12127033945533539, 0.134556770865475, 0.19666039324816198, 0.14887218093199117, 0.11165533845703449, 0.1348349680342982, 0.23912273167121798, 0.09139992011290404, 0.11092331846274676, 0.24049269606269177, 0.2523378096520901], [0.03533603150337454, 0.03890199842111718, 0.009552375225710773, 0.021330777878662752, 0.0105897233926601, 0.13970334954079122, 0.03949678908552855, 0.036776035483325684, 0.022974595720429095, 0.0434927573247302, 0.04400929593811593, 0.0271453220216978, 0.05530723888847617, 0.09941450981122833, 0.006397451826130912, 0.07806777623632262, 0.04844521315047338, 0.041821708887695305, 0.034255717295191945, 0.033154630612942486, 0.012557447996861752, 0.0452822161417815, 0.02619616589659164, 0.0156380589525666, 0.05585714446140393, 0.07304045446817914, 0.04300483975619559, 0.05520458310662259, 0.04491573500056421, 0.06753435072999808, 0.042906910736834815, 0.061043900617909055, 0.0830489565287867, 0.04634332835614201, 0.00859472222791444, 0.06665524185424851, 0.02444920772235961, 0.06659878883510828, 0.04776491558239345, 0.007068197235404965, 0.03819933108564827, 0.03951465808636239, 0.05366982171131719, 0.08114877502403914, 0.021764477489576228, 0.01483221872589521, 0.02726190145157518, 0.021784947358913, 0.040107533530963045, 0.036663987463520425, 0.013234389142223425, 0.01216451096678934, 0.021943684607263536, 0.040656186550134615, 0.03613640186226657, 0.04123998385283255, 0.037701929348611066, 0.0924346061243165, 0.10949636479058575, 0.04801680146145725, 0.03406607989041555, 0.10359580238019267, 0.03857675962330353, 0.11497463655447769, 0.047642042740218105, 0.03887165367843644, 0.05055577772098684, 0.050893852321971814, 0.022075149125509688, 0.0204469479860798, 0.05988267986404319, 0.04229189535122245, 0.03358632498871415, 0.055263571876792185, 0.04454585625940273, 0.025360863843572237, 0.06693152380326102, 0.07788966845480666, 0.018703071400523186, 0.012881881444745008, 0.09386693007282673, 0.0057367407322500745, 0.052216315431700605, 0.017172341542919318, 0.05984649370093981, 0.06523789492465797, 0.03503625363772435, 0.04064210585408634, 0.0380006768260031, 0.06983195566722462, 0.09106169229433422, 0.027605459326878194, 0.05357854616557879, 0.028465348971827377, 0.09167657744499946, 0.03975225259519873, 0.029295401407345652, 0.021671914916125037, 0.03038239207178835, 0.027916471871937958, 0.03345040949962793, 0.03351218682984191, 0.028292780006003958, 0.028828892165855057, 0.0456764028527804, 0.022330729463588328, 0.03571447893796909, 0.02105014646546014, 0.10758311382584995, 0.06424325615948727, 0.027076766728573752, 0.05503920004552892, 0.04424368819942878, 0.03296282900978, 0.03194982903228412, 0.05077010230912317, 0.06191575847145531, 0.0179868787827511, 0.028502021600762685, 0.015243945977530413, 0.02196765549841427, 0.06744153917797151, 0.05245129375027553, 0.030897005889264327, 0.0324094990238307, 0.08511201598711553, 0.03707975870178592, 0.05553939800348975, 0.038410579830768614, 0.051683554906518235, 0.1162473843883603, 0.029819120179801702, 0.027011823540012685, 0.031144429306169192, 0.037131749258767215, 0.012128846701084366, 0.13087967140299658, 0.057082387183101914, 0.029720430818176078, 0.11945975959421166, 0.009796570539624702, 0.041916454811730695, 0.011676516789462299, 0.0657917305286373, 0.044070621276454586, 0.02832288343098856, 0.019904500279094905, 0.10880046584192785, 0.023094793000528892, 0.021899872038873936, 0.054859992927841605, 0.013572975106897854, 0.04885811538946244, 0.056333202988870686, 0.05997248069052735, 0.047911855076710065, 0.05556818375724459, 0.04911308477242147, 0.008455564271688702, 0.06436792547784506, 0.041538375099339796, 0.04983052611351014, 0.04692725972422669, 0.036469757361637975, 0.045877477950266296, 0.038104098695780964, 0.022663845560483398, 0.04365430228532322, 0.028375779886940317, 0.02197950304816327, 0.04471418875900488, 0.08624699056869553, 0.019487011088659207, 0.035566459259679245, 0.018482920713722706, 0.03098244384501971, 0.021687895510225527, 0.04785089746057507, 0.05011203661260586, 0.01687667182376308, 0.004007943869275492, 0.04344105022028089, 0.04135785797130197, 0.031815190994811636, 0.009793955306973188, 0.022980362447279117, 0.04607754947257139, 0.035842584160667275, 0.02511839510031766, 0.08136803704884746, 0.051786938471899885, 0.10852896428156285, 0.02899294414918029, 0.03296231190043111, 0.028191510843293324, 0.043323788972150896, 0.032239695635413936, 0.07738722968966731, 0.04004377969390443, 0.0594039476897207, 0.01581213711160085, 0.03053968332918181, 0.04426448365613338, 0.062203470452298085, 0.058911717046172395, 0.0294088073179967, 0.021810601728277344, 0.062052968649133566, 0.09829307200327035, 0.005209598983187349, 0.013167651392699731, 0.06501959817063424, 0.02947217236543375, 0.04077120316064647, 0.07096450175008467, 0.07803242127861708, 0.022366848593998342, 0.04099020854600015, 0.024522911126334822, 0.032241369537528486, 0.010865339802788391, 0.021761692759971467, 0.01542493137681196, 0.06346042921406127, 0.021492343906673695, 0.07084877650824285, 0.014035003691641314, 0.01798825199535537, 0.050907013712510954, 0.026668338443062482, 0.03597907421569671, 0.06902698878078692, 0.05408513712726774, 0.027950972641607928, 0.06996357723349525, 0.05241695385906966, 0.025916015203561515, 0.05396044865671185, 0.04339718402573659, 0.013925617827372927, 0.06986877385286555, 0.044922526370012955, 0.04462572858638821, 0.007658379402146825, 0.03273888235731471, 0.02116622793818674, 0.03259386574368804, 0.0323136767462617, 0.08220953866839409, 0.04452010421382804, 0.03699929265665912, 0.01873009323683237, 0.05394077934925595, 0.05172094765810236, 0.049318304405577724, 0.1304170615490406, 0.029483692412595117, 0.04067577924879809, 0.043010577754748446, 0.04807421975138207, 0.03213172894902527, 0.038034507268739325, 0.03348754944219705, 0.02303532542540662, 0.06776614595324763, 0.009646144387642703, 0.09443350571898684, 0.04525011322731453, 0.04779655884410586, 0.06022629328072072, 0.023181690353780024, 0.0074175663664185956, 0.026679303076478745, 0.05320489827182986, 0.03384487200227957, 0.007371844802682679, 0.019132385158070156, 0.04788495772968858, 0.0075009057200664, 0.04613921572003634, 0.05405985239532687, 0.039556406047796054, 0.08540984798943804, 0.09325422061186645, 0.06795587528857493, 0.005857500129364312, 0.018645273897075848, 0.004904555220667634, 0.06594428161699926, 0.012680020149526818, 0.06681464942953279, 0.03956834169765634, 0.026497726831885598, 0.06461722581016441, 0.03338363727614765, 0.054399983942388534, 0.02078457059518945, 0.035751048145034624, 0.03475187796979182, 0.010734788844391946, 0.01673160158398171, 0.10761964089807965, 0.016460207275926106, 0.10380287594612568, 0.038553167945675315, 0.051540032164343906, 0.033136083624295654, 0.08465086170021566, 0.032102473966416814, 0.1068136091494272, 0.07249096258273048, 0.024545091286962552, 0.09712278842926027, 0.04254851948409792, 0.065759033896029, 0.0632886761318772, 0.03964987643543751, 0.03901850507264176, 0.07940070027665747, 0.012171213278516889, 0.03610691513806101, 0.029399418910484643, 0.045403706195253524, 0.0681548513051483, 0.03318107596808865, 0.043877103636341716, 0.040351501891329404, 0.04613289549466103, 0.1102830145147539, 0.024558679771519477, 0.012888279236522655, 0.038489778000380725, 0.07491500267098028, 0.02156053722325352, 0.05653948748424169, 0.02685906943835078, 0.074442571569835, 0.030979291393211296, 0.039429993879410534, 0.034001812774447665, 0.013798933697774286, 0.020366876476234006, 0.029319686394545342, 0.04655072367900322, 0.02357491562443395, 0.04546749833670836, 0.02097970276560274, 0.0647484643324729, 0.032281524036079645, 0.03478817521564422, 0.053600977220001726, 0.004026580633850948, 0.14465839091327884, 0.10817668641046171, 0.10361026612020309, 0.16660371494870033, 0.07714895336257835, 0.26383050747456094, 0.11436864568461334, 0.1113301111505397, 0.1049781544134021, 0.11264143917228907, 0.16719443002535453, 0.07180423370652622, 0.16127085433371607, 0.22723367527848293, 0.11026426068236751, 0.21597146266891112, 0.1837676544223101, 0.09336967006205552, 0.09026059415191413, 0.14592614385389513, 0.14503047981810185, 0.17352168808781332, 0.1021515504427014, 0.20572615517002923, 0.07124418512948098, 0.11585160804491852, 0.22305837351708646, 0.20865720756832631, 0.24509415721460698, 0.12245499483880498, 0.1389901216832861, 0.1355598251064939, 0.2621956758441464, 0.16289805572840477, 0.08060952573413811, 0.1464265984513106, 0.07888780441135168, 0.1952989324326477, 0.16349588010099628, 0.18931796143372215, 0.07884843515292292, 0.16427442461492556, 0.13066936494602313, 0.1282865710316166, 0.12404265077484232, 0.16623370980303134, 0.09566125354819721, 0.08326487074936591, 0.1420899126077852, 0.19429618462679848, 0.09761892995166202, 0.12774318486692446, 0.19020717500919299, 0.12946124428943281, 0.18642578033670304, 0.07452894032241837, 0.21171184527056836, 0.16142257038624058, 0.1525977737600765, 0.12254786001698625, 0.15644984770446055, 0.2227393438618991, 0.1750502326796132, 0.16823920541472975, 0.17555549830919312, 0.22072315366277773, 0.1445937024489526, 0.10663371638304765, 0.17953707175629754, 0.18722033608824978, 0.1265859707529026, 0.10901210529188957, 0.17108807190051004, 0.20766074168345622, 0.19004206773975205, 0.11440957776240765, 0.11077358657794614, 0.20185620073349247, 0.12202916486609368, 0.2542934942269518, 0.18490816015870343, 0.07871057763094864, 0.14797037287104517, 0.15731165065400063, 0.15802444950226816, 0.19686092442322164, 0.1966836823210601, 0.11407192450978103, 0.10615259018396178, 0.1179685311452035, 0.37603805742917523, 0.138122481143763, 0.16920678978485448, 0.15035157332256918, 0.20688296325745123, 0.17875990620063198, 0.14355180755017266, 0.16915281122970968, 0.13825369668343376, 0.11488184032420959, 0.13239436512512545, 0.1467345045098374, 0.09431542092633825, 0.11712494576650283, 0.2228992417334549, 0.19832891742548636, 0.20698089993769125, 0.1994162719816931, 0.2712159014997944, 0.1120744574995291, 0.05947351613412461, 0.08660178886906755, 0.1827112651400028, 0.10482191078124509, 0.20161701276177363, 0.16536441451359182, 0.24997229868125534, 0.22887029955464028, 0.09139639610845236, 0.18596163830689846, 0.15304380547135107, 0.203098182476336, 0.17960791956753502, 0.11881241529819467, 0.11499994809949592, 0.1520179218101886, 0.10399778403582112, 0.19613248205954031, 0.17562098350496064, 0.1063836116584078, 0.2186023005314412, 0.1986355211345419, 0.24713308490332098, 0.23004238343527242, 0.1680479132600369, 0.05003766479691671, 0.2461541777536754, 0.08761080327413737, 0.1554392704800252, 0.22069378185176083, 0.1297109276657143, 0.12980806761451308, 0.17435506917536261, 0.19759900417299042, 0.13857744544023468, 0.09631405239023509, 0.19179231817683867, 0.25852406157120583, 0.20853032808630698, 0.12839789892877304, 0.16940496140910735, 0.12996191339146707, 0.1338439413736905, 0.264182846632696, 0.1891604384347316, 0.1309964691679324, 0.1661673206235132, 0.11491251448469778, 0.10428594034765998, 0.14403648073634795, 0.1213319099418098, 0.15329977076861168, 0.10419005678305704, 0.11422924832591128, 0.13806589788967563, 0.11114658712739907, 0.12178194829292836, 0.14524067902276594, 0.08749952900313562, 0.10510933164867664, 0.11198510866492026, 0.26102729982906775, 0.10807786106822953, 0.17332299552377195, 0.12633357542536913, 0.07911548574244784], [0.05234136779402053, 0.07656987516149398, 0.043943691998720176, 0.023293491310229706, 0.04520159304863022, 0.026219495189105792, 0.034931303422537544, 0.02983752735740235, 0.09665705293657319, 0.010919288672026127, 0.07575475761005956, 0.06086244503216398, 0.05607703467831016, 0.039698749014566985, 0.03456017595805949, 0.03037457605974088, 0.018833932624528968, 0.07250427719085448, 0.03832134973978804, 0.025185280321766774, 0.025276642052396655, 0.015327856545486759, 0.0740589607026308, 0.002150472245111521, 0.0637335280677484, 0.061399212197190335, 0.0850502463177808, 0.07362174666336468, 0.051760722943131006, 0.10928528458480874, 0.1329816021626034, 0.05373036180953345, 0.017762076027030428, 0.027743221087861928, 0.07802925733548981, 0.03388195065781474, 0.08407544539940935, 0.008485627477057278, 0.019673476889429074, 0.018818325498291565, 0.00884837872769323, 0.07253791611160963, 0.008291706683174258, 0.024080179338794083, 0.11585677147752817, 0.014884447727742937, 0.05524245083271977, 0.06185794564624948, 0.07041785971171434, 0.0528808584016177, 0.02144979921379878, 0.02868394641536138, 0.04255598884135966, 0.04210492010198293, 0.0052311385027884, 0.03944847958102342, 0.048337432240406354, 0.04244227074987946, 0.0533030379653698, 0.061578940254666155, 0.03836376802815545, 0.05414999413093733, 0.07439940251530179, 0.07640230874981611, 0.07987506191937194, 0.02608938856170543, 0.056981796008204265, 0.07214554119855165, 0.007507995385000663, 0.013157852170538279, 0.049206888408309994, 0.0742126302793622, 0.032234505389726935, 0.050670970531721274, 0.06153699311037218, 0.0449522429205958, 0.03800297892021556, 0.12653094265730153, 0.05142909880246847, 0.005487783703081791, 0.11449576265388921, 0.0518524811242617, 0.09391543109931293, 0.006421200072978654, 0.022387295480697386, 0.04212750820443035, 0.0595950176789155, 0.0125447673264951, 0.011977362390156957, 0.0750450307743684, 0.09073625814409987, 0.04647384292536205, 0.07557207628363564, 0.028665849503370065, 0.021166469255882888, 0.029424521696543502, 0.028487295475638205, 0.040835937590248166, 0.015407580442936912, 0.010253873319485256, 0.03974592087850456, 0.07892648419064861, 0.033958463689252254, 0.03074396450463082, 0.01027559957301785, 0.019810899656506318, 0.019821172895570918, 0.09698014285775924, 0.026079155542256854, 0.04549755196597788, 0.04121505918221609, 0.04118338910742633, 0.04977216553543845, 0.01339159612994521, 0.04434594944600136, 0.03224173342929252, 0.01434262821285595, 0.027124338873451757, 0.0603907302232279, 0.05107235463876879, 0.0486780425924207, 0.02554644289756975, 0.048940577093632, 0.05091952775875407, 0.03391888375664431, 0.06485650571243418, 0.03626276423493701, 0.07337943305291476, 0.03315909690554104, 0.05701348140475251, 0.05045452771047431, 0.02653510234649143, 0.03785062318427428, 0.06801053566197235, 0.018198116036552577, 0.04528174882814769, 0.09633518109518675, 0.06673475411990959, 0.02285699547839261, 0.04489353377251856, 0.019220582945572755, 0.03293069928223568, 0.07367799283876535, 0.04005719006301896, 0.02701349744212724, 0.061752566421825084, 0.03512654476048004, 0.016122599988574945, 0.04433970582941848, 0.0817091147144956, 0.037702323883892074, 0.04431769995379352, 0.020144490727914438, 0.001825973081248512, 0.027884947353853818, 0.03704525793211595, 0.0935518610922079, 0.02509631070068046, 0.0397909936615296, 0.025529029719050855, 0.0542719055327677, 0.026742560871606393, 0.03864155917037879, 0.022707319134966503, 0.009335746628142173, 0.04896748976241197, 0.005275166533406704, 0.08486549655396132, 0.037423789636382175, 0.04523601720950777, 0.04240894209473364, 0.01205755168602111, 0.057247398691552306, 0.00730798562853447, 0.03040263402996765, 0.04548169011550565, 0.0531808699240848, 0.0503168234060849, 0.020655415832035003, 0.06087122823021585, 0.016184007681365457, 0.04238672937536913, 0.021552640771974, 0.041693622817195235, 0.14025012181410867, 0.03907830972645072, 0.03512271815129826, 0.019844935027762287, 0.012671197689468823, 0.024262661482357693, 0.045539112235870094, 0.07819794223553712, 0.014861866328564864, 0.018104559464019634, 0.08368703882179915, 0.02827934473903189, 0.007704445705448668, 0.02669654963087411, 0.019129550632750316, 0.049123358011486075, 0.0077266952927945365, 0.02270943928329695, 0.042650213825606534, 0.0194367365686283, 0.04804726494776626, 0.07598285262863483, 0.1292095537627897, 0.05880435365402411, 0.016771340479833946, 0.08045501346068998, 0.027631569518557483, 0.022493977054593065, 0.035077323611345024, 0.03800768270007065, 0.04352107959529085, 0.04807042378571726, 0.01372159999464789, 0.03469585395988918, 0.005796525276251017, 0.0314182942477806, 0.057106951792393966, 0.0431178990120609, 0.010721784501877284, 0.04794608771560654, 0.03852234439804189, 0.011494049967657174, 0.030938140980358568, 0.057776386233707594, 0.04128586868905733, 0.0523160562490023, 0.04560243706369112, 0.04156046524463643, 0.05973071866338292, 0.0448739793782513, 0.05590253900135717, 0.0622832048834572, 0.042040480616232084, 0.0094553051824351, 0.05606731302255104, 0.05236995436491505, 0.07339650149186773, 0.03250357462093234, 0.0539889318057366, 0.06843543100741602, 0.03916032326918456, 0.027851377381011847, 0.02046810924976824, 0.04791144521967058, 0.08314785081893207, 0.012962651052211803, 0.09658068163140167, 0.028383800827507532, 0.026258040903015967, 0.04914329161927585, 0.02722613663683015, 0.059778526380297646, 0.04380873028909968, 0.01524751594725756, 0.05554324376486963, 0.04301968654016814, 0.008782819795963025, 0.01092523830236807, 0.01712370070538694, 0.03041003252409639, 0.006955316573787, 0.006430659343623707, 0.07998912475041806, 0.02716721872979355, 0.036034688368559845, 0.02237468184302411, 0.03222974032283791, 0.05293160789616166, 0.06650998392292569, 0.04754229043159754, 0.030048567343563325, 0.0584210109175934, 0.04393083321291112, 0.07574875914161244, 0.025435701057675387, 0.03008168340931016, 0.038368778243180246, 0.058504851580026655, 0.02672746510905845, 0.019015420769010822, 0.09247487170561668, 0.054936103763118874, 0.010909209827772312, 0.06363562203102535, 0.05682874696269151, 0.01878873535221623, 0.05889377143654612, 0.06180850233161642, 0.02506603873635252, 0.10609893338574518, 0.02912201081222344, 0.07530872589878498, 0.08581371422136023, 0.03851996186459738, 0.038927126105033585, 0.021070878719910983, 0.03447140551983349, 0.07636672396573328, 0.05081263934111884, 0.02545248795931618, 0.12569317954682535, 0.02762014523238665, 0.032400811586769364, 0.011910514515494148, 0.03377561382348499, 0.029891201392597253, 0.03889300454888613, 0.03524930651990637, 0.038565704974556164, 0.03719086826388394, 0.04681585904871745, 0.046491382508388454, 0.05275361119739471, 0.03641656021617594, 0.02318197572153182, 0.01311805581809172, 0.04069052644134049, 0.15304106287658215, 0.02253283303411257, 0.046741954546662114, 0.024214928459015586, 0.04746490405992635, 0.01918473003071643, 0.03995862902112065, 0.037106096804622686, 0.07630832508326539, 0.04862655382302981, 0.05454486649062845, 0.07722091200130601, 0.015304756121739987, 0.0089890276825416, 0.016096761758108775, 0.014360856317404299, 0.031543953734780514, 0.03648775276697932, 0.0649883954094783, 0.06891496374361938, 0.017917362049282078, 0.0406611048346085, 0.037676368825017445, 0.09797822518814957, 0.08059188272924193, 0.015412469041503727, 0.004410314075123038, 0.05752274218285757, 0.03196024399761471, 0.02507469361467708, 0.03687907430914141, 0.2887720933123943, 0.1912546163845447, 0.15024565400615816, 0.09428592654125345, 0.13567890581344405, 0.13469998334203998, 0.18163930895107408, 0.12918378256501692, 0.23387564226023613, 0.08450783308475249, 0.1705151913507331, 0.1343591508245276, 0.19274697098280155, 0.13453853797287713, 0.18082170927476499, 0.13988033117305848, 0.08288764139457096, 0.1154941973847247, 0.10469313140117353, 0.12585719897141381, 0.12233931556223862, 0.07421515836951233, 0.12697674454219882, 0.11259607144541318, 0.14226104132831097, 0.12507718356866993, 0.21892634040165335, 0.1578699142461823, 0.15646083340529474, 0.24308400378832895, 0.2831875574925254, 0.18091728640419824, 0.0966775304667892, 0.22614773032405686, 0.1197441007881876, 0.07642722192911372, 0.1205321524532572, 0.1420655203682761, 0.13106670410883042, 0.13151907902811805, 0.11041394660189269, 0.1369304023683071, 0.11508601807778883, 0.10325816444932454, 0.21262854608076237, 0.07976949500340609, 0.10440850675466562, 0.24136563793065088, 0.16928715240811149, 0.10680195695209889, 0.12933791945538214, 0.11047141851797221, 0.18434012128460794, 0.13315855315135372, 0.1714232813326582, 0.169325472126084, 0.14939344247743008, 0.20792914824860714, 0.08259684207939333, 0.11451445519924165, 0.12447976522267827, 0.12461040619640582, 0.22048240287169335, 0.24388569947933, 0.14846145055226742, 0.17375218862247083, 0.15266797805745758, 0.2761844106979909, 0.1926257758731804, 0.16642209082361192, 0.1668938630891423, 0.2135681069546169, 0.21435775974344826, 0.15294611393924684, 0.25898399011742684, 0.15837231470692545, 0.13184420674318267, 0.2440184625166078, 0.14326107718290823, 0.10308818486068519, 0.24630007153797537, 0.2052410070093409, 0.26159362266621283, 0.19889398387843565, 0.22904268465936187, 0.17563970669383006, 0.12577834554136763, 0.08218506215921334, 0.12886079989614027, 0.1624189903058352, 0.10219928538126331, 0.1738739353153975, 0.1490939174207949, 0.1915803110046733, 0.12960992663377716, 0.1679548948642708, 0.12195967303048219, 0.15410505175109834, 0.09681108257462902, 0.16668386306733857, 0.15610068015033202, 0.16055770308500336, 0.16995392469388826, 0.17147410360555496, 0.2028466911325532, 0.07737207647052503, 0.12411195108847273, 0.19863500019475339, 0.1822546001283392, 0.13874946282275263, 0.1010476483873302, 0.18945650077394902, 0.24277381478778778, 0.13873142911301506, 0.22657700003154818, 0.1872622564194664, 0.15373665539007034, 0.2140660794271577, 0.148219121620059, 0.1813725877793566, 0.1867292584070275, 0.19107430993068605, 0.10460115488498442, 0.14816174163453041, 0.12268770170668442, 0.17688453828375186, 0.13211080534083228, 0.13637492733616985, 0.20721588974758504, 0.16558860248375326, 0.10284658371200485, 0.13141780220452817, 0.1506940759117565, 0.19900831484025527, 0.08812569862892551, 0.11763929719886473, 0.15786570076259876, 0.12594768161615058, 0.18935386031385393, 0.16303101794854288, 0.08951000418634185, 0.1690622749588182, 0.16713640652596953, 0.09259465721345718, 0.15564772300422192, 0.24867240069133623, 0.09378054599848487, 0.11602741756266165, 0.1254349083249127, 0.1533664970268165, 0.17891027393840975, 0.16589278535496804, 0.12637094519431555, 0.13245077983986947, 0.10734674505769246, 0.17429336845394106, 0.176774206300897, 0.05298628742175718, 0.14882163445074714, 0.20562964341332837, 0.11016394912956223, 0.17282212723887738, 0.11172516737133266, 0.14074628631914818, 0.20534824399698168, 0.13387516711748418, 0.08667557845793425, 0.2594084947580292, 0.25014039369360097, 0.19305446335384924, 0.24390701204538348, 0.06332619911840846, 0.18690219509505457, 0.10581787104808515, 0.1420669146482983, 0.11164704938569378], [0.03776778609702184, 0.044562036036363536, 0.04817591792333031, 0.033960612565879865, 0.03214875716836222, 0.04168093640116915, 0.08780030278308738, 0.052015994930820125, 0.061216258909553296, 0.007508264952189019, 0.0618156920667858, 0.042431024579151023, 0.02179445259483351, 0.011650480333745722, 0.019094258877298525, 0.04283841864596452, 0.0409896990975305, 0.010255977188447311, 0.02779908613452027, 0.02944582277127812, 0.019544370006769896, 0.08673707999649548, 0.02200881165692643, 0.08926409762352706, 0.029663972053376418, 0.036750076594011444, 0.02204767338210537, 0.037023014569234465, 0.01888387006587319, 0.05551087655006878, 0.022326644299732103, 0.053005703920198065, 0.05995793268084527, 0.011656899192941286, 0.02233961225307036, 0.026586127632688132, 0.01922422952409233, 0.07293441257770024, 0.03134301270268137, 0.02113291268957959, 0.05898816496013634, 0.020123371599061836, 0.029451240928122596, 0.024846579443903703, 0.023709145720086755, 0.021257221946612965, 0.015928558535843847, 0.03290866659353337, 0.03313471998779043, 0.03113436865650358, 0.06954073500368865, 0.010539378009496198, 0.03721557842988161, 0.1006949108634745, 0.022129911005557067, 0.07841705870363982, 0.04167035289649521, 0.07856145095560821, 0.015907517931003486, 0.014252519993592176, 0.0822427026146362, 0.021630988583990166, 0.02597401188986917, 0.04822502415927668, 0.04697976356011726, 0.03994024674137754, 0.03160401311282429, 0.05573516411166038, 0.011053064860583795, 0.07514895060129705, 0.02129084171517001, 0.03625519911668474, 0.06318263041095869, 0.04897621550386952, 0.008962920363692027, 0.02486831718875516, 0.013773075357500105, 0.018101667482105475, 0.053818841134348226, 0.018734858303721395, 0.03139062698239521, 0.06704183280347817, 0.04125611000363866, 0.016936478392791846, 0.05468545128561316, 0.04216965836202426, 0.014063924468392807, 0.050258504962849046, 0.0042620454182577955, 0.035718742217267715, 0.038553857424807166, 0.031446204746081945, 0.014561833738679848, 0.032757007997603185, 0.07077426679672734, 0.017906638733561964, 0.026654696332350857, 0.05851569555459484, 0.022352538071572784, 0.02564255820376979, 0.036217476947293166, 0.02953368539531385, 0.02963199554341695, 0.0461693651102964, 0.0556038566414387, 0.0779659171859103, 0.04041052896589522, 0.04883199945212372, 0.05959402559505356, 0.03340800653301901, 0.07414754344931535, 0.022998961146860834, 0.053763790056109435, 0.043938563040067116, 0.03316182417855148, 0.04093065287076658, 0.04726976231341401, 0.028371028226589965, 0.009206695286857506, 0.03466128424230603, 0.050238896942427086, 0.03983556082652461, 0.029138929864031174, 0.03527351489831363, 0.025698214491468765, 0.027071235573760448, 0.048184111233680486, 0.0059580946558966275, 0.06840919249600942, 0.023646134988314683, 0.050100246519451185, 0.01981292595906604, 0.017470568080522844, 0.05017168421839034, 0.05621138351759123, 0.02154207258905855, 0.04686326839991155, 0.03567275012873354, 0.03267223270790231, 0.032755138743067944, 0.0864691254232199, 0.035671834653664025, 0.07629645838131828, 0.038950476464965654, 0.04511430499053771, 0.06505064771420534, 0.028143253049723087, 0.05685927556647409, 0.08830875533843234, 0.04332390388533954, 0.058537306894938794, 0.04922768769545421, 0.1224611005595615, 0.02553103686941247, 0.07041781374643888, 0.06746636042671819, 0.02945144394142253, 0.004285573414827307, 0.02112930824589585, 0.021414679828129952, 0.06871241009643964, 0.0227924200120352, 0.044163773737607465, 0.01795292193550737, 0.029503237230763323, 0.009402118570682023, 0.135741786310269, 0.02991570279963555, 0.019014940048838337, 0.051754364413359476, 0.06653895736822198, 0.10144084301446715, 0.07749815156022388, 0.05657915551696093, 0.027518969915446737, 0.03799873479311505, 0.03296795413799344, 0.023209049268775893, 0.04381578978932193, 0.031062923296685183, 0.005112895704505425, 0.007393351284741996, 0.05427088663582841, 0.019716688078798113, 0.0396908583089469, 0.06262884460269444, 0.07103343434151142, 0.022565893558484894, 0.032687723005731265, 0.010710837105439316, 0.04909843717130923, 0.01014021747264891, 0.009632433329017894, 0.017473640093099208, 0.011780580257876747, 0.020940622705365383, 0.005705690231069082, 0.0520932893719404, 0.02917800226338929, 0.014175243747060098, 0.09953317683069937, 0.0240591349035141, 0.04062963394267906, 0.04133296777464209, 0.022721531981181715, 0.043218880891799934, 0.04662494610754713, 0.044818564408248475, 0.007490145536364928, 0.04473944667786841, 0.011159925507531773, 0.05223936318690258, 0.016504833812735254, 0.08328971498075032, 0.061876393043466156, 0.049531981649418036, 0.033136550937929464, 0.020474040685521982, 0.019563236837125113, 0.042707574658937035, 0.037035597563390775, 0.07690643290838889, 0.07042919781299369, 0.023701890867443818, 0.04831844475120307, 0.013215529015137544, 0.030981216189121048, 0.03562673505756163, 0.12246990290981148, 0.017387202392602642, 0.014827342576257166, 0.04609313553139087, 0.017298979707242503, 0.17771940558187424, 0.020231156339568478, 0.05664531103966217, 0.05636865370756677, 0.047011494921940955, 0.04321782752090404, 0.05419252350205376, 0.03040213415759706, 0.027539321041155248, 0.04101996723141882, 0.05336351677655213, 0.023812309035190174, 0.015770087503047002, 0.11427939644143467, 0.017442178777268818, 0.06625126070913769, 0.04206789124216284, 0.024444291353105538, 0.005582272987662545, 0.04451811238522491, 0.06388915499912635, 0.05022516481638436, 0.08766649020535332, 0.02518925631809379, 0.03176263353276638, 0.07537094755999504, 0.06990825802448296, 0.031415496111637166, 0.03252668749360788, 0.027675724911293196, 0.04866963477745172, 0.037084052624601516, 0.05522414899220871, 0.07550446136343865, 0.060127318551343296, 0.03412967284901008, 0.04959367087952072, 0.03081255618693127, 0.06283887143757555, 0.014300677238122351, 0.05305137042136443, 0.041010720550172755, 0.020126663861916434, 0.04939235063389905, 0.025613490912702777, 0.04835667253862466, 0.014718090777375526, 0.04625602114585139, 0.05105201117393952, 0.061629080709310315, 0.030284947603039687, 0.022359842719930797, 0.019371735923472914, 0.10479194908252648, 0.03938574081046447, 0.059689265645800106, 0.018500128963721857, 0.025235022410690307, 0.0941323948603484, 0.03436738610147469, 0.047910943432080175, 0.06205077763767012, 0.061487488508705175, 0.03641150786631531, 0.061347731088678685, 0.04972952891201262, 0.03825764952888412, 0.0711134139208063, 0.06394519050034785, 0.05003312189552573, 0.052600167616600954, 0.08013604509253656, 0.0840132084164408, 0.024955750803553292, 0.0639290566886625, 0.04060441432821174, 0.05195812081858035, 0.03732026434473453, 0.04115841847153441, 0.038062492460613294, 0.03429675279485603, 0.06496515230185564, 0.05999192783248521, 0.0388085586769927, 0.03782572532673517, 0.011988824023114098, 0.07460010989058403, 0.05663835496130971, 0.06605383219017137, 0.04193875946164612, 0.027025044302365957, 0.06601718254387379, 0.03903798285811659, 0.022903744078752016, 0.07943918853397332, 0.041902787803161534, 0.03349761966796171, 0.014634994177838728, 0.054639336623011105, 0.03645212967850028, 0.031379846210080775, 0.02005520318033955, 0.05673354138590156, 0.06088127164290317, 0.016194579694720528, 0.038769331144829916, 0.034034179989248514, 0.05767148581423587, 0.021859091263444676, 0.014734880551846038, 0.03897795220836997, 0.019281360531045545, 0.051525530119937275, 0.01064392698613266, 0.04506906749860895, 0.027579713026962938, 0.061453596778935006, 0.04592231324603481, 0.04199315170427004, 0.1492357356173377, 0.15803394899252923, 0.10875552712428956, 0.15670687020305665, 0.17969163765590038, 0.08762905148849373, 0.180203108597667, 0.15257155823130764, 0.13486481481982818, 0.12511407070222402, 0.12991718917844758, 0.1318969902011656, 0.08252183441072702, 0.11914299755928018, 0.17228278601842542, 0.12859933408758334, 0.13105366529235918, 0.05125264577086895, 0.1369463829624076, 0.1431103264011683, 0.10275863681829746, 0.1768337160108551, 0.1563772991780312, 0.18327076979462179, 0.3502393417781399, 0.18995709326719085, 0.15343467885207746, 0.14729920324058304, 0.12408645568235267, 0.14716351374743447, 0.17408018150637228, 0.20515522048357995, 0.16639175374181042, 0.10084086593480841, 0.14946323308733203, 0.21893289811428518, 0.1381271542801011, 0.17574156574424238, 0.13804460064538066, 0.10042515598357686, 0.17211957864703673, 0.07431305674535614, 0.10454644088543232, 0.16630857191499204, 0.20499765151931396, 0.24768400937318805, 0.16538278530201606, 0.07486375904972516, 0.1046814562212075, 0.09068280818962282, 0.13865419212848912, 0.13738289986166263, 0.23077710771993284, 0.1526130189097697, 0.2103473354251154, 0.13965902369349234, 0.11425044597877611, 0.18234792495927504, 0.1151703260538559, 0.15296313641292436, 0.2725511621082983, 0.18402247058768428, 0.1888866692541107, 0.26664535965650316, 0.1308566734435097, 0.15900542508930932, 0.15902221773660954, 0.13382068294430935, 0.09890306185209945, 0.1483491420625679, 0.1559886780958022, 0.09892514816695645, 0.183137976113827, 0.1840145492385472, 0.13705806326000922, 0.08486933465446196, 0.159476354658123, 0.11730119195436278, 0.1606179175958518, 0.2593902312219143, 0.1841602438399869, 0.17421499765928716, 0.32171699969518575, 0.09219714951130653, 0.1597805375293378, 0.10893989384414689, 0.12743188503889308, 0.18530428890259037, 0.13282499846912202, 0.16858458849451236, 0.1692917029703817, 0.10262284773371874, 0.06363308627999599, 0.18815401340684584, 0.1305910247948862, 0.19621400913644224, 0.13340788412719004, 0.25511656377104025, 0.13433675041362164, 0.09404224163341908, 0.11192535380682639, 0.10286995705457465, 0.1088776108959029, 0.14091785937067003, 0.2922265063370428, 0.1334641609461077, 0.14312039279649336, 0.1197550328628671, 0.19358047464441872, 0.1703883731557477, 0.1869997946966079, 0.09772360054475647, 0.14711468330314084, 0.15169167560675453, 0.05143552628015319, 0.14959247212015814, 0.15257091471745124, 0.11148709022710401, 0.140013431289023, 0.07345722162074621, 0.18455762896806965, 0.14934249763046542, 0.08311130842494388, 0.16602118169107746, 0.09629073267381999, 0.16583571180460915, 0.1547344542679287, 0.15390139493730762, 0.18969887567143287, 0.1576447150399608, 0.20360851960797466, 0.156715021378571, 0.11694258619700709, 0.19098357447693426, 0.19433021425239502, 0.1788534761797036, 0.10387317983493691, 0.12946607064335577, 0.14892769166298453, 0.1926091517652235, 0.14689573537438147, 0.18948935062414218, 0.16204440395437902, 0.16000929138352796, 0.18682206229817483, 0.1719085827109314, 0.12427886632541496, 0.16625673840603522, 0.143299121109228, 0.1484941778283927, 0.08360288406331694, 0.2690023670513784, 0.16629773943174272, 0.15090953047958114, 0.1709232097792049, 0.1542601232687312, 0.1193325353726264, 0.10842783301467858, 0.07293496416100571, 0.2548034942799038, 0.1533178351218662, 0.13501855334447277, 0.1103264670218191, 0.10544195170364073, 0.13237918126246623, 0.10991710027860058, 0.16249559909826325, 0.12951851702265202, 0.11747831914333567, 0.08328331814658257, 0.12968501857211515, 0.2816786094298286, 0.18484745535158342, 0.12898496742690765, 0.12558113918789934, 0.1299894619132242], [0.06382575739295253, 0.08809453417216578, 0.021748795669766206, 0.023586200099558603, 0.09113276993194896, 0.07103636845826142, 0.046044251460942535, 0.01505705499796257, 0.02218990335090747, 0.029495421218715852, 0.013204102813746902, 0.04439207559992229, 0.018829000933516412, 0.054805003136636755, 0.0502697549640171, 0.02761864370005506, 0.012596005202090789, 0.07407819717040948, 0.050152934216443575, 0.05253581240052178, 0.04952183864530056, 0.03482506617963795, 0.03281687393844609, 0.01758547360828567, 0.04713463206445018, 0.06101789959375897, 0.01439057861364657, 0.11569275971381895, 0.03738015326821516, 0.04290999424073004, 0.027810451048876972, 0.04306896514589748, 0.055391903095428026, 0.043283688099754435, 0.020992329809814695, 0.0167486202272196, 0.03224885804698833, 0.03017654233131438, 0.02597898188527794, 0.07998384640461977, 0.021014914081822482, 0.14710860056502206, 0.01662483957085398, 0.06779325780488792, 0.06982813288848247, 0.004210322034440094, 0.06116757402196527, 0.07316063834174026, 0.006353953353790266, 0.025660346765371583, 0.03881640724777695, 0.05808643350798277, 0.11273497084696447, 0.12414277080566653, 0.04763538543615611, 0.01769347476863092, 0.04298826544395378, 0.04893197775668195, 0.041172525980660034, 0.00963425278783806, 0.027782818257448175, 0.01180133453735541, 0.02444295261445786, 0.022546986508513653, 0.06886965730377743, 0.03831766102643263, 0.03066503063535258, 0.02683844443620934, 0.021735657261864796, 0.058575438921369856, 0.03247034555721668, 0.04721051690378978, 0.035422676047610666, 0.09348863585581703, 0.03953596299153663, 0.022199385604190252, 0.028389621180512255, 0.03386237711134938, 0.03894569224587852, 0.08244367812069194, 0.006413263402083108, 0.06899770123944168, 0.009587103906538217, 0.014915458966917811, 0.015463606368059353, 0.06420785523650628, 0.028450080839496468, 0.04984980471612466, 0.055061248055989706, 0.06750908515025532, 0.005641472432011318, 0.046014925615201076, 0.024557963479310278, 0.018507741962469394, 0.02970030377318542, 0.03162290867147667, 0.01251677064330227, 0.028375452384352687, 0.04271969416989915, 0.021433343645185236, 0.0424800580367446, 0.03288657644823675, 0.024995834438971458, 0.08399693670892909, 0.038957179734303106, 0.04731564714963879, 0.04098010767671851, 0.053399810191964915, 0.029486479057419687, 0.06413044205175773, 0.031870314851403236, 0.043692633494614594, 0.02798697494360949, 0.03361852366417166, 0.03283063670800578, 0.059536308530838265, 0.028160133797134605, 0.009016681541388315, 0.035223834096424045, 0.07726409637759771, 0.053874014786654906, 0.05771696462386078, 0.05734854144975544, 0.033126695216783596, 0.01706273159793308, 0.03646776936347446, 0.0717354160282881, 0.01790829348347841, 0.042233002342043385, 0.044613003865965915, 0.04516170285041294, 0.009025475273149149, 0.0698936793712839, 0.02199387102718315, 0.007452772415783858, 0.051634249487711545, 0.08278267968806528, 0.02821862461015342, 0.0976846449738068, 0.02176341837302091, 0.08380489378807046, 0.07217860555336361, 0.008540890187085157, 0.02371017993878453, 0.04257268189722973, 0.03665146192595844, 0.011044622571658223, 0.023671733816304517, 0.052012934409562624, 0.006269350433872352, 0.044992412740905444, 0.07151791600570565, 0.1061444313475682, 0.01970878205141954, 0.0381921413504789, 0.07666000540578559, 0.03475504957379834, 0.029098057158051, 0.055895483331574555, 0.04569079764487763, 0.015849070210430413, 0.02472322588155587, 0.03810831217936451, 0.028204164700582627, 0.017983439047971082, 0.03802109306918518, 0.0803801896531255, 0.011037104376291317, 0.0476007161271428, 0.04740843188858802, 0.04542509153965981, 0.042156374397417234, 0.049396307478027965, 0.009187001081544065, 0.019771752563575586, 0.04475194540235304, 0.050968262442057176, 0.05372498770274463, 0.1594540002124925, 0.02593044830005496, 0.038035242713146636, 0.05831985666807141, 0.02498221914133718, 0.04332897538739828, 0.004865437334839014, 0.043936042610796235, 0.07491920083280533, 0.06085223308013332, 0.007614840231385203, 0.02471724081964743, 0.028441630889691656, 0.03656307070125495, 0.02084064057036754, 0.04406053955937105, 0.019119986025015676, 0.014210623602623181, 0.022219058742085775, 0.025476776776955496, 0.07092471880417678, 0.05350766004994512, 0.037638589199031555, 0.024881093620112347, 0.025848526687872027, 0.043099727406496965, 0.0342701695438835, 0.023994394728252967, 0.007612258036275425, 0.04344712912796005, 0.06091052471029182, 0.005265638793653419, 0.05468310322612525, 0.0236874271274334, 0.030958664475850044, 0.02195916149855381, 0.09999069986083817, 0.04978522350410781, 0.10794803980858096, 0.037806324150052764, 0.03295786476003067, 0.03575530759389362, 0.03180870223009298, 0.05622689679805791, 0.032496147398506446, 0.029112999703014092, 0.02325714618388203, 0.04969693953171373, 0.00463616541369007, 0.05236664486508216, 0.06191891092326372, 0.052146222217068564, 0.0728949054234451, 0.06848170271804256, 0.036142216469611854, 0.06493011910107828, 0.04593622923317937, 0.030351850061467102, 0.038923483356953635, 0.03635793150733075, 0.015854778523076207, 0.020663712564254963, 0.12961096851335419, 0.020911494127264427, 0.03437516189390614, 0.020528725956776933, 0.019961983686493292, 0.053222284637271404, 0.06269370543680365, 0.04318080249152357, 0.03838638677411983, 0.022811116387827263, 0.06823254794242882, 0.07541334286572472, 0.026883143751371293, 0.06316104588369209, 0.06736103099800887, 0.058421976188377994, 0.019030943625576554, 0.03854110589130752, 0.038588595681733666, 0.022345499638768456, 0.052666510830843644, 0.08162692880197879, 0.09575728266950577, 0.0361532136617649, 0.03611151932648594, 0.042901310634108326, 0.030986050203923258, 0.03518801565552431, 0.02477716421708465, 0.031632739494765, 0.054991940081480055, 0.029180559081836577, 0.007757413982143326, 0.02059023707143722, 0.04992626795184709, 0.042967630865713285, 0.04787324424532633, 0.039051105944259513, 0.015842731790466896, 0.026280514092274734, 0.03185237307221659, 0.027407915894723228, 0.0274094499857916, 0.010752791910612536, 0.08093683679978694, 0.022677661956197793, 0.06803260665507087, 0.018083930631438573, 0.0863252311284023, 0.0558238311280166, 0.05176185675325894, 0.03328330274070463, 0.06826827062233802, 0.1130983263494507, 0.03905153878393673, 0.053633283147768634, 0.02007410831509098, 0.011774582747039537, 0.01312747008107122, 0.0663277009622224, 0.045592447277158506, 0.011505008855414008, 0.028236715776485302, 0.02513547120014987, 0.02547487304846366, 0.012688115783666652, 0.012352417970466758, 0.02322718640038323, 0.009878843594642897, 0.005226371999484517, 0.06398213509049627, 0.049322816663451736, 0.03565953894247932, 0.026200873506886345, 0.024447801951018554, 0.007879435987917767, 0.11394699089108937, 0.004173728408321979, 0.04009372479612789, 0.02645971737952242, 0.016727694535567876, 0.02192296958979099, 0.036080891131273204, 0.01641998382946176, 0.013875733054573498, 0.03681787920574989, 0.054742513344653194, 0.027696604637669462, 0.03156563019259803, 0.09438044646935118, 0.05409882328803501, 0.032898538911174384, 0.008143828731150398, 0.016580324116793853, 0.0448148642035742, 0.004046247547282086, 0.09915367985564856, 0.044802671914259275, 0.040514038935784376, 0.07442110578619665, 0.06272329558287898, 0.01686728150103121, 0.06435812721329351, 0.03302843677961538, 0.06781437884896033, 0.05474691835021781, 0.0421922885993075, 0.04833578515136915, 0.035105086637720946, 0.04876677855669011, 0.024161290812997088, 0.0252973034437145, 0.13753778751819365, 0.17134762248925625, 0.24420495896089464, 0.07342329924745906, 0.12479777598092634, 0.2886487225130681, 0.12144150648025737, 0.16797298986104228, 0.14112802793181714, 0.14501888124692827, 0.11480008342093038, 0.21838217282727843, 0.09933695106977418, 0.2598681781561144, 0.16192798923340537, 0.09967255886764297, 0.12399528355848406, 0.14462505076681414, 0.18587811940139343, 0.1183580102459077, 0.10363987541847652, 0.13667200091144732, 0.17709918079837678, 0.18456536645610488, 0.17291183613481062, 0.140098589622686, 0.1824716941243218, 0.21274312219071775, 0.08866186824537094, 0.11564368412138955, 0.1748273623806815, 0.1322975316114964, 0.12580099110040935, 0.18983456516458144, 0.12936542201186382, 0.15465657376954633, 0.15344079223371324, 0.09560051043668101, 0.12494560796767475, 0.1558620897271941, 0.19286321716443186, 0.1565367680403494, 0.17441333782288337, 0.13041346093579648, 0.11567107942556182, 0.11170897227261337, 0.1445322775191838, 0.13460066770353626, 0.09175263465412202, 0.14236198107321418, 0.08474868346726702, 0.1423990903722663, 0.28479894683245693, 0.2807146869599819, 0.16215824461992712, 0.10368161954947057, 0.10659587930046743, 0.17494633583532226, 0.14864336579076706, 0.10376674723961662, 0.05984909456944274, 0.08796760106399175, 0.1151229894810146, 0.09228273685420714, 0.3199616164690064, 0.09439214463195494, 0.1803177613164148, 0.1775461318151605, 0.13911260382062005, 0.10957932445190607, 0.16482766267032395, 0.1579448682886939, 0.12079318159169729, 0.20917773366935793, 0.20552997537437948, 0.15467911207627866, 0.08928613797310861, 0.1388272207470671, 0.18432034089440302, 0.13723518278810287, 0.07510074834910131, 0.18842540771490146, 0.09333493563556865, 0.05975690737907445, 0.1191322263630648, 0.17524840430386607, 0.2434121192462983, 0.18356755225648805, 0.18109106578894202, 0.20684982229384685, 0.11333987387197633, 0.1259007817134261, 0.17147189727233303, 0.11219604331399165, 0.12812360880836365, 0.0906664445515602, 0.17234402708709243, 0.0953334445253976, 0.19003737928165546, 0.11924158541425584, 0.1238466165358982, 0.10103388178733089, 0.09367466498647006, 0.13005044251199693, 0.1637829179244657, 0.11745005049892973, 0.10842938051228562, 0.12857619823227007, 0.08514139545901168, 0.1503324977332546, 0.15601288647420947, 0.10206626187409125, 0.15866404098849143, 0.18252496787857625, 0.129304533343642, 0.1279931287131002, 0.19044541303188572, 0.25893532821247656, 0.139952726481903, 0.20136167565661095, 0.1263653910568645, 0.13891172024511522, 0.12193795443782884, 0.17171116185284432, 0.09757897080553156, 0.22993438035970737, 0.1528270025887797, 0.12010905741443557, 0.12266825073428693, 0.14750733400785154, 0.22319061561457573, 0.09280322465084254, 0.14332055624934936, 0.09349013738814863, 0.11711079612254136, 0.15537372399722377, 0.18960734348623984, 0.17004147322187502, 0.22575370066108244, 0.1465231561732869, 0.23087130589110239, 0.16694557402403126, 0.1378964239190663, 0.17211898109845578, 0.06004044035029027, 0.2431863837785298, 0.10065563353559664, 0.10659108359006145, 0.12086880979158225, 0.11277041773522094, 0.16910419529003484, 0.0759279394462224, 0.230815825803626, 0.1955165320466603, 0.16140655914862312, 0.19192897294077182, 0.10741711789441687, 0.12604421635548915, 0.1338053918293407, 0.11332246069345744, 0.17810965077050273, 0.13411286887862992, 0.14095104629954985, 0.1011368823087504, 0.0842601185544364, 0.08797882425208246, 0.10151905293065695, 0.16467499666877333, 0.08853586976446452, 0.14636882010006136, 0.12546364428295245, 0.14628398352332656, 0.08863753729289578, 0.1236375971066375, 0.11298954186420287, 0.12413257417539436], [0.07718407083302736, 0.05263135505599841, 0.06810725426241275, 0.03037528086063122, 0.029266328370619207, 0.022971067885537783, 0.03782181444788172, 0.049559380784029924, 0.04030688493061931, 0.0412975860038592, 0.05360184289935616, 0.006641141522014815, 0.05176944102370932, 0.10581728116038347, 0.017262142369403474, 0.03218775487414772, 0.0783628962873932, 0.03836469882498345, 0.05866445833817125, 0.07957067986529681, 0.029755868130333485, 0.08540751908214823, 0.018797637293896368, 0.07096498438547696, 0.014558525196456862, 0.07149948393024745, 0.01352063693752092, 0.04897956713853825, 0.02999510589776741, 0.023196462444179965, 0.036277005809449384, 0.0225876217272373, 0.06728641403418395, 0.008675289779691207, 0.008789424431480227, 0.0041214500895641265, 0.039573432351913185, 0.06253863391917079, 0.07832207912278753, 0.02456255809163615, 0.0315472440824153, 0.04959519539449004, 0.021622797188859795, 0.030591465127203735, 0.02467069523258796, 0.03130667140677331, 0.030123437116403255, 0.019647177090988528, 0.04939606616033181, 0.06324526575964785, 0.054643335601975845, 0.03543139029774935, 0.06024740283347427, 0.04218060575846223, 0.01569789712272224, 0.030480987587643248, 0.06310118760372843, 0.025861848956875266, 0.059133208386840365, 0.08905258074763323, 0.05733857847630017, 0.018742023141033227, 0.09021629128725299, 0.031311105140635086, 0.020959784479571447, 0.08772387785176117, 0.025988282192678704, 0.05618817105348553, 0.0347480628519289, 0.06856322979494449, 0.0014226652556023891, 0.024103071961191394, 0.026111492113540732, 0.05034196258132016, 0.03310417989268899, 0.015319299343372545, 0.06044737859478882, 0.048536952179405964, 0.0732180949360613, 0.09730994370916198, 0.045853598989666476, 0.05243034507598608, 0.007248775171671784, 0.026385192346248417, 0.10719410203877958, 0.030216827064812667, 0.06163722805438503, 0.006481608978637885, 0.051693288053596215, 0.0777066423888168, 0.029095471611306555, 0.03445558963463672, 0.008929923041573456, 0.05571357192351453, 0.028939601447012638, 0.053222345924305345, 0.020345039139952392, 0.03217788383124336, 0.044706570014597914, 0.030868704686121597, 0.013795751560058807, 0.0660151447499952, 0.07702154527989126, 0.04171432251290929, 0.049004706313773516, 0.032868868325867, 0.05115577012240406, 0.04759999217405435, 0.014392540756342633, 0.03594235562148594, 0.08572790471296157, 0.09202882467258362, 0.06448411037244144, 0.033593813498173995, 0.030630740539861784, 0.02550404950705988, 0.015604477488405764, 0.023123509806370544, 0.04429764377193586, 0.0035343746487576998, 0.05382688122711355, 0.058197730761622234, 0.02035680242002972, 0.035077051650131905, 0.025032826909615148, 0.06413986493322639, 0.005703375687927849, 0.03138070422855597, 0.0323857311459799, 0.04652187280777482, 0.017452821653756886, 0.02961557253354019, 0.024076191851148204, 0.03254922580034022, 0.01278522796177816, 0.0042686682483632, 0.07131559984578241, 0.04237163361282118, 0.04774806164805928, 0.02876108189323737, 0.037540334592302965, 0.05079772743967272, 0.1139893402315436, 0.02987521888327695, 0.006438880903466095, 0.030169115108888478, 0.06623976939027348, 0.07995817479827712, 0.014187738641105114, 0.030495782660680915, 0.06560539496281455, 0.07342288555997996, 0.04581735536996876, 0.05180651967924449, 0.11490742000000131, 0.055312252933940584, 0.07105877653004662, 0.07211417755893162, 0.09682477256583591, 0.057876789717063795, 0.020114377726830786, 0.035080556502385486, 0.01893771264041143, 0.02419439730264487, 0.05833578746645682, 0.006192904913933167, 0.1206911693237001, 0.013818830916387661, 0.02729503666952012, 0.013158725510771959, 0.015418870663720996, 0.026272406966816035, 0.009367863906757727, 0.08386812668534056, 0.021296671644273787, 0.022937806263085336, 0.014051835600947662, 0.01288353044900202, 0.012413761503393612, 0.01045693641513466, 0.05589829104381704, 0.019941730236995126, 0.0017520089679765667, 0.021579992026090625, 0.016691037228391055, 0.02109444166924204, 0.03781965024949562, 0.03776269161232537, 0.04002431723018808, 0.04017048297570117, 0.0906677162575145, 0.07959853482222365, 0.05158304800129226, 0.04206457025101108, 0.02460307648195134, 0.06933397553380459, 0.034295576849892255, 0.04581640542094265, 0.08069512839879721, 0.028880103228373394, 0.04613263502476677, 0.07763035535331696, 0.013554461634597711, 0.013777041777728066, 0.04320223380120532, 0.04497891810211924, 0.03734342701312515, 0.03241588436667958, 0.047145587121767384, 0.042497965341974656, 0.05587523945817544, 0.040044017181160955, 0.03790172890970304, 0.05718901513084289, 0.058308162335907264, 0.008334497481794849, 0.03210798788425182, 0.04197314148768783, 0.037833213836195013, 0.008044342638083525, 0.023344263787411397, 0.038708837011889104, 0.032129951625040946, 0.02773063234804619, 0.006718616472602252, 0.04979322529247692, 0.03820583134168579, 0.02801374014046404, 0.04182758478207454, 0.07870612666010857, 0.03346106195221505, 0.08794454947835015, 0.11239786917764334, 0.04296647407294762, 0.06306201369772035, 0.08216155858169641, 0.025866043288260702, 0.04877662661695673, 0.08846341316858608, 0.051679498470959165, 0.029244381866808382, 0.029904450883247682, 0.05912917876435865, 0.029827549062188596, 0.05047156933634993, 0.08864545864203284, 0.06099883549576325, 0.09532172338015611, 0.05687802173798123, 0.08051600172034196, 0.03566615028126586, 0.09884431056918637, 0.00795933177634593, 0.025693681166176836, 0.048874264522906274, 0.045287283813400615, 0.03421306151956801, 0.050049466381390253, 0.04890266340225936, 0.05446990478723761, 0.04996980472858395, 0.04645890038039896, 0.08239123940227494, 0.05055883824224434, 0.031264728092918956, 0.07998986785570461, 0.01933722366248408, 0.03334082828293885, 0.035145827193534186, 0.010917870451756304, 0.009210992082502813, 0.0295366290881629, 0.06454656186002879, 0.05799868196669606, 0.013730503851547839, 0.025763263017119422, 0.0688355740520262, 0.016897338960740357, 0.006371558054290231, 0.008954399550754217, 0.05515547687067621, 0.07011790564584156, 0.051008761680174264, 0.05470389485239022, 0.07177752788148581, 0.024275263628712105, 0.06093264932954504, 0.11123546098749484, 0.08923281059269944, 0.021923710779857733, 0.052857086693327275, 0.04444257228545124, 0.07582313861818084, 0.02367195981224218, 0.08286697234237388, 0.032631714317587115, 0.04337729638322227, 0.025497809720916614, 0.051146025484007214, 0.01743043273416979, 0.06368128470175209, 0.0408641679302579, 0.011033217437685499, 0.02456037665627176, 0.00639783630650791, 0.0536866296803759, 0.029791412694800287, 0.0155083937833326, 0.007099513952139646, 0.020224906977326162, 0.024075450661081462, 0.0037379000305889118, 0.0896939802013578, 0.045819354859451135, 0.04169345427785189, 0.014679419616567753, 0.055325364528764645, 0.04368629028660156, 0.014915431196230554, 0.028676886915139137, 0.03518856723882979, 0.036304818631540385, 0.051721422632615414, 0.029410241817634915, 0.054932905346035, 0.08246606320983942, 0.08588439349325434, 0.02564351006801571, 0.030702109290887753, 0.08470927590444204, 0.03696740807725057, 0.09610216013125836, 0.06537400576616488, 0.04270503124702842, 0.10041365700383341, 0.030174104256495356, 0.05103815647382891, 0.04521229912737205, 0.014297907830276077, 0.04527774601874333, 0.019063609614667874, 0.0381174745909389, 0.03725761367428688, 0.016570604376254544, 0.07955882082422895, 0.012961833253352633, 0.015381103486663874, 0.05266253866495625, 0.06729403660903055, 0.016112742352209265, 0.04438469434277185, 0.06591509366708417, 0.19446640936357362, 0.10237844270323554, 0.1833383540713018, 0.10726622921685058, 0.09253074249793446, 0.09756895803636122, 0.1478783350678221, 0.1345241814851761, 0.12284770683054963, 0.11143905651425162, 0.164078566576204, 0.08886708021764794, 0.1692515906066664, 0.17242734680973715, 0.18211508019556924, 0.17430596293941622, 0.14761703779860852, 0.17829243934923605, 0.11411541532124243, 0.18441141342684148, 0.1188641262330836, 0.16630218274170355, 0.1201375175808226, 0.21430980263938829, 0.1373467558333951, 0.31585575291706675, 0.13366029477648197, 0.10624884147076838, 0.11063559116014551, 0.09452950419677843, 0.13860795106137955, 0.07538592457891473, 0.23380120915751304, 0.11607080112181364, 0.10756711024911174, 0.0832266046575481, 0.10601080263093596, 0.11563292824693265, 0.1757564584934904, 0.09864620023196745, 0.11561726940976036, 0.09224234869883907, 0.14486938684938416, 0.11470599250207025, 0.10267763834206328, 0.13898751698434353, 0.23145109655395632, 0.09643266578355143, 0.14016447318417413, 0.1489067314973762, 0.2110757165017628, 0.13143730680308036, 0.20497934201792364, 0.2408422926260579, 0.11313019560710078, 0.21627852603072123, 0.2676481687493863, 0.13924421772601145, 0.09145273421440395, 0.11647596204232787, 0.1077164744117087, 0.11678811222795518, 0.22424980877868592, 0.12216353668801247, 0.10019394298714977, 0.18198348161193634, 0.11340808634075428, 0.11569854367764727, 0.23130846630421378, 0.2065469570938618, 0.1228674412554791, 0.25941327514667667, 0.19315721106625375, 0.18550284357080538, 0.10799981203050384, 0.22307118250718042, 0.12351056440703331, 0.15816936269402504, 0.1962255310988234, 0.15584454631372807, 0.12160914183984842, 0.11821885803534139, 0.14861014821837026, 0.14419745113099777, 0.17828931371050497, 0.13040187768638134, 0.1873975781904113, 0.18239122424875537, 0.14934015340141713, 0.1734004316911582, 0.08403304243280042, 0.07228829402236209, 0.13358725595378107, 0.16057319338283232, 0.10747879563320069, 0.2787589257763278, 0.10276340954606572, 0.1627501394719847, 0.1820888033797664, 0.08459755730244421, 0.11796932021576552, 0.18500470255892124, 0.16667462404697173, 0.14438189445964753, 0.17916440062465208, 0.10913438824636322, 0.13069331285453614, 0.1664392358713573, 0.20772406651127726, 0.132483231324342, 0.2790542067058625, 0.24166926921856022, 0.14023021884983586, 0.13567031030693363, 0.09953362116169545, 0.1943104491839486, 0.10667319289378582, 0.09867268389150982, 0.11287377831796486, 0.12699085588176406, 0.14166101062249753, 0.16429530817174143, 0.09872879217108411, 0.14950637915922751, 0.13335035092407657, 0.14406052057541188, 0.13611718471492493, 0.11807726966517589, 0.11847159044156153, 0.17048019645435197, 0.09628804370520577, 0.10757677061783691, 0.15536286087045748, 0.13274763891052815, 0.15700965879424927, 0.1054922377149905, 0.1610866255096851, 0.11098884196291048, 0.1688970297935509, 0.11974884287243891, 0.1846943756625537, 0.12597831747224256, 0.1638488014859538, 0.09661620512845055, 0.09387009401595402, 0.20749575698808317, 0.1075066812336445, 0.1198794225591325, 0.11535003495913361, 0.17410299560475737, 0.157638662945359, 0.19536244112157053, 0.16319627843556866, 0.2300601719968742, 0.19131639371475867, 0.2249413410261754, 0.2529324470989166, 0.1289876793781596, 0.18719027479810102, 0.20355454105282986, 0.19896317693975665, 0.22563846571551216, 0.1824337880938284, 0.1053802356604607, 0.1483363637159909, 0.11013090775738801, 0.23422359939544435, 0.06286366587324489, 0.23761626573339586, 0.12874159661512222, 0.10613561367555972, 0.1971520378344482, 0.11471806604775692, 0.13398474833417323, 0.10080652221316293, 0.09097954468621362], [0.003264743779342802, 0.023460488901623798, 0.03739473575185384, 0.004504720526446979, 0.028173078767835136, 0.03808208515927677, 0.03296156879514456, 0.03224102479796256, 0.062067030192983735, 0.0301620498630068, 0.05825535589528661, 0.06890606180193924, 0.05350640749618892, 0.01224233209335756, 0.11545200126185534, 0.02616835498972045, 0.03132601895730101, 0.07923439791005465, 0.006459956939872956, 0.052031929559645154, 0.022524844652282137, 0.05173232789421755, 0.027380537827529257, 0.025153077815869646, 0.03827313216583383, 0.013114995296834218, 0.03743680930065532, 0.02644649470194934, 0.03757558612813873, 0.0756445711839103, 0.13438594858011893, 0.021922626765444878, 0.057556457712405154, 0.04795937168021356, 0.025939555170254845, 0.00590399352668394, 0.11224888039812927, 0.04325135152847056, 0.022842453214369958, 0.012584604856167591, 0.04858548767984875, 0.058584777533166835, 0.004963693377982465, 0.10128616220167569, 0.08824327780354409, 0.040893152866873055, 0.05894829774455679, 0.013250294085141393, 0.03780392629484977, 0.033889879667831045, 0.007508750460411032, 0.03851012146521, 0.0036757329531434567, 0.04331104892997011, 0.09340200663333939, 0.04522275622753848, 0.018600415618669604, 0.08373322626275402, 0.02846182113693607, 0.0345204274861082, 0.011054192925052298, 0.002363861008967844, 0.08799884979042315, 0.018373986841329647, 0.04426935214489218, 0.11005725606434769, 0.058457354128721266, 0.05162941164246971, 0.02861099186233215, 0.06486561449785387, 0.04542019240738404, 0.01618666217602309, 0.03217918235027502, 0.10158132821802171, 0.05246296893024156, 0.028282031792426304, 0.07579819479536626, 0.008378332075212271, 0.019907122215015755, 0.1449257862423697, 0.0917883343513935, 0.03272933307133856, 0.01649788731048184, 0.06725457542005085, 0.03044935773246952, 0.02860119168256079, 0.043596183024947686, 0.07711619544293612, 0.03615991310066274, 0.01380451847874229, 0.036347443763647354, 0.07415035499199744, 0.026742863476336486, 0.02579658209616619, 0.03897375787698454, 0.029852377971814528, 0.030437088834362167, 0.07957478609657095, 0.07037650628556168, 0.06768405963216098, 0.03605287146544264, 0.021894183836036155, 0.03535485428367411, 0.01533783101026089, 0.031834961808917504, 0.08446175289610702, 0.028782760266274698, 0.046184836255927245, 0.016651162351932258, 0.02396847797377456, 0.03923297904792332, 0.025110035165843946, 0.042894155372895544, 0.03900915879996554, 0.0480548070833808, 0.048545218268108946, 0.03401835261273288, 0.03539584764850236, 0.03649800685384581, 0.03596659081297056, 0.042264565164523746, 0.01469779232021181, 0.04535515537305225, 0.05260899677992829, 0.10142246456516367, 0.04444386314360365, 0.032912274867656736, 0.04659419533826652, 0.028351577254192486, 0.028925890388387828, 0.042219013576546026, 0.009179183154276783, 0.019332483493452592, 0.04366046929311368, 0.008942790445871651, 0.0570912623117047, 0.02101567442408733, 0.002808297581542584, 0.027585824493378885, 0.024722549808962692, 0.02202093499832817, 0.04292265384367878, 0.06026735559346215, 0.04615710004262867, 0.06016516712524238, 0.0785622553479287, 0.023454739411752072, 0.009662119236083762, 0.003424800853545387, 0.07122333987706131, 0.11270799689115056, 0.023783362402971235, 0.061671782450209704, 0.06469931979213031, 0.03182440894776054, 0.02323512115605897, 0.04100551115228765, 0.018863342739942095, 0.03368558700106317, 0.07139105950632403, 0.031692950175173824, 0.027776670401855826, 0.05213691424878855, 0.039837943359969125, 0.07168106209006041, 0.009923202000678548, 0.04627686256783144, 0.04027107415059882, 0.010047345591198293, 0.09341591879004434, 0.0700332222866916, 0.013455747375114551, 0.025404890916580637, 0.05464581389641089, 0.034057388622914596, 0.03435997803124689, 0.022017504839647203, 0.04771068038779402, 0.02297009878431357, 0.03294641174556267, 0.029161621388348363, 0.03619220370667116, 0.06921001484677677, 0.02961385841180961, 0.036975785248702576, 0.05110377573498315, 0.008259952338712831, 0.06358011896091123, 0.05661874694088775, 0.06108831456531921, 0.03300765664466927, 0.02622754677318998, 0.04080916664773419, 0.02772322810825802, 0.0029509685297061, 0.01946360518735263, 0.06016959128300509, 0.0420123498676525, 0.02551333640792197, 0.06194442548158188, 0.02619541704564566, 0.0456157669935736, 0.04976214893582848, 0.026067593360259652, 0.035991151591822985, 0.08386769767610297, 0.0714252729930224, 0.027287747342920592, 0.06099963605764413, 0.02906107234828655, 0.05064251036533425, 0.021218567065173582, 0.10264145600939951, 0.02467282878745708, 0.026221762809361664, 0.04421371883983093, 0.048081080068744, 0.0836531700746667, 0.016534224775950276, 0.08041821059680755, 0.010937471768908925, 0.0560522172600031, 0.046157885282751054, 0.04712406388153473, 0.013923251573296805, 0.00408743339170131, 0.018034853123789354, 0.037270916791092006, 0.02162078620805856, 0.027737391158758153, 0.017698571168547197, 0.02391319898437829, 0.06057166486918446, 0.03821550320172983, 0.060824757336729, 0.10952166101384549, 0.04765385581601051, 0.008473367197439075, 0.08425978147574971, 0.030965582249806296, 0.015600841443595147, 0.061569096024839155, 0.006377230935369529, 0.03907926733635607, 0.031044738284582575, 0.048752893213062524, 0.027008676833863703, 0.035667923774810574, 0.037035019167007945, 0.053178652099544005, 0.035229418877392046, 0.07433761752420857, 0.06342841056926597, 0.03539895413503532, 0.011113478554292552, 0.18919380922471324, 0.04347524455478115, 0.03647584393019638, 0.032397850656942014, 0.04308247510644217, 0.03966903629442377, 0.03989318212974937, 0.09634296454849745, 0.05248954068989523, 0.02227518042819875, 0.054029162913080186, 0.03617419297957132, 0.047000742877923676, 0.07492398888233208, 0.023178796456646056, 0.005356036211108609, 0.09379326305802792, 0.02021293493828947, 0.0026727244379975263, 0.018198449284799637, 0.058191946797793916, 0.0327431035017775, 0.052644623698846954, 0.02095247217033419, 0.0034009522970600598, 0.037469601694254145, 0.08527746799612239, 0.06084182194524235, 0.051252764514497215, 0.03163151375408615, 0.018423073925077915, 0.030596345107281403, 0.055071532786373174, 0.02213821922909589, 0.010549101580475128, 0.016836597764443968, 0.10666213058415921, 0.04180068743505305, 0.028395901186271544, 0.07429704550773868, 0.04855555279420749, 0.005854690501902012, 0.06267792402556346, 0.04477998038994209, 0.04703715120652511, 0.025176539258550734, 0.043619778533015525, 0.01344825886565471, 0.0293778267223388, 0.03026865674332986, 0.04643934981657132, 0.03882956863831609, 0.05701728120085694, 0.0620164645595416, 0.018395506251122684, 0.05800875602290035, 0.028344343468967467, 0.0353121142383785, 0.018566828408849337, 0.04153175993011363, 0.11678258873402111, 0.07705491606987293, 0.028109541350615122, 0.012490128978125513, 0.06593786946107304, 0.03851965542942767, 0.046945707121443365, 0.01562762004698837, 0.014260297701243433, 0.03168174613928122, 0.036421857714172334, 0.0261008549827121, 0.04322416689847747, 0.017770181237269315, 0.016747473010552988, 0.08548110948815461, 0.029730633194107684, 0.05561203846047002, 0.029695565519373746, 0.028323220509675243, 0.039065814832405704, 0.02089472446260193, 0.1123235892925051, 0.006046444703374179, 0.024752247207347425, 0.0632901240380541, 0.013088943519359155, 0.014392072485098916, 0.03360826191642592, 0.026909144775521372, 0.08538920958075794, 0.012084548624472754, 0.027323111876725193, 0.07224625877795682, 0.024754545471120267, 0.03293765153014853, 0.05362074228844816, 0.09489718809603684, 0.10257038603266401, 0.06601721318739076, 0.14666410102959604, 0.13741015727000852, 0.19242524469812072, 0.1662769937707532, 0.16598016534361149, 0.14926103184059744, 0.15807003173376286, 0.14597972404331933, 0.20968312187300575, 0.2283192678324638, 0.17271436931144807, 0.14448940723894105, 0.15258242135807393, 0.08786974099254416, 0.16460341341312856, 0.09247006833433144, 0.13344047350748894, 0.1628146440752091, 0.09917309252364982, 0.11623437621540601, 0.1272595765429639, 0.1519556541837031, 0.15266077683096932, 0.1375473329737302, 0.10031212737122852, 0.1859403104190865, 0.26900907798159507, 0.21770481320638813, 0.1447524358668635, 0.19291794648574245, 0.14582623066681047, 0.10798332581837332, 0.0884754790533935, 0.2861884464659999, 0.2664957886501666, 0.10270491107216767, 0.26071850510854877, 0.22270588114136652, 0.19991634353514642, 0.09509515287655015, 0.1862144626436695, 0.20158912716132982, 0.15795255981145367, 0.13129168881043313, 0.14730579159673185, 0.11724939674980218, 0.0805995742520017, 0.13156262346573416, 0.1441978341749599, 0.0842652207000121, 0.1722384295276096, 0.13985886538942016, 0.14998207379493023, 0.17762091731832874, 0.14980366723912378, 0.16570222864468254, 0.22882837922342364, 0.06267852540458403, 0.20627177831146026, 0.24622606744448988, 0.18025264384285097, 0.13323453375168387, 0.2755473932671932, 0.14685148613587504, 0.26478750450957206, 0.06812704231349692, 0.17861117789101216, 0.09167251717900077, 0.16711143205963797, 0.20381900992604995, 0.23737597459506607, 0.17463348084880462, 0.17528577407281246, 0.15835268753430537, 0.10717955402909748, 0.06906710114450225, 0.38539450375303147, 0.14642737986099336, 0.09994760741509738, 0.10816236056627766, 0.1463024462423017, 0.20055788088469736, 0.08705927359481012, 0.16482357176080828, 0.2389533036658841, 0.15321763082137033, 0.15385354508555707, 0.15008125153760757, 0.14611130730519373, 0.2507426766979118, 0.1975750409427189, 0.18281850212764356, 0.22907280723654458, 0.13681806323509063, 0.15467986284244448, 0.1778353146848179, 0.20362805485004382, 0.19924286031915298, 0.1247571963035772, 0.13701962096796882, 0.13532221527589908, 0.1087808616519455, 0.34202758403074357, 0.2162158447167566, 0.13898204711656417, 0.07477668549625144, 0.15985150791464314, 0.17297575851121258, 0.12133652179111397, 0.17623923178161346, 0.09486344958385153, 0.14762125128219206, 0.205023146925434, 0.1304391861682938, 0.1307016478911523, 0.19809054150696725, 0.1782635425127322, 0.10365794743261031, 0.12688323585016112, 0.15414018454330583, 0.18968300232964178, 0.16678990495781745, 0.1518192598896642, 0.14118851823431833, 0.16993553858370553, 0.12443461966130043, 0.0835660811994345, 0.10931725343388897, 0.10940782800917664, 0.16937097774878626, 0.1528807972828227, 0.2569284229989975, 0.10758360412212149, 0.08631327249590429, 0.11804438151058652, 0.13718410004531184, 0.23071081047096562, 0.16091033335654967, 0.19863270193098054, 0.20467462288516186, 0.1733286798961701, 0.1361028282272239, 0.16098608413050253, 0.060174620650227995, 0.10861848165551502, 0.07847199486868997, 0.21344933268283645, 0.3231872756394648, 0.1325514744366369, 0.16646275477063271, 0.1127900985339957, 0.227640820366721, 0.11017576986623388, 0.1418960463976668, 0.21016738137170193, 0.15383682904704926, 0.14188473893990441, 0.10371083814290263, 0.18683546883684976, 0.15049915250030257, 0.10887939588076646, 0.20370581277435829, 0.15727020529729707, 0.0958773592907575, 0.12562750282907678, 0.10512368813637765, 0.19201923342001057, 0.19479602635387452, 0.15971561923863428, 0.20990908716715154, 0.3149853238174993, 0.11115337466640819, 0.1608948583804792], [0.06322749251980456, 0.02673263428732753, 0.02189873056786676, 0.015647074849825474, 0.0254291529211426, 0.055175111704175515, 0.02317454275344649, 0.08707741455685708, 0.07357737485079036, 0.009130057766132299, 0.014557762938972204, 0.029957038988809914, 0.046504517085850246, 0.06382431331721526, 0.028072479932058244, 0.021720994338994066, 0.018747483432713537, 0.07643338893690417, 0.0360246755993895, 0.03505274751073411, 0.02993790977334063, 0.027319028628088778, 0.03995354219730343, 0.04074560050221701, 0.03861454691016867, 0.04213325386386245, 0.04772867579313536, 0.048939535214054974, 0.020483833204414097, 0.03260057667390474, 0.03434290576185431, 0.030284265784787077, 0.015350273235761111, 0.008979871016626638, 0.004451439111313273, 0.019775686425066764, 0.015810763898996577, 0.042521514884767034, 0.03922912562566419, 0.006547776471462942, 0.047699847904544686, 0.06705243546035021, 0.09467628664307057, 0.008871960829222396, 0.02030889894212446, 0.042415913494844595, 0.028042301813501026, 0.0678609952991528, 0.022842393842555826, 0.030047094539528894, 0.03744057462280316, 0.059694658904787035, 0.029063102481285893, 0.015372396897404425, 0.042796858376072305, 0.014439008776999772, 0.024341193155475685, 0.0473598734055075, 0.04956572399204297, 0.01750063894677066, 0.021094253977700587, 0.026371207411190676, 0.12621656315581453, 0.11141611984179867, 0.043859820692769946, 0.11654300239658165, 0.036547247155178944, 0.03244388871075165, 0.05988990024272954, 0.034695712233623194, 0.015798849316554207, 0.05466246098700551, 0.01921524139752071, 0.02335167760329862, 0.043315940401366645, 0.02038405791315581, 0.024929684661929647, 0.043327577276936466, 0.05449142802747027, 0.056749564114837885, 0.0639006156744736, 0.03348745751164613, 0.027814886697958556, 0.0665862096713916, 0.026470488575737805, 0.05580603490553557, 0.01947093090312856, 0.025217708823601567, 0.04457824645684131, 0.030196726832899357, 0.05284758337262658, 0.00956670490033444, 0.057161164004355676, 0.057257894096114946, 0.06607705231515631, 0.020477041834965348, 0.03777167016279794, 0.062434457452787515, 0.045161940337669466, 0.02776769759704269, 0.14190015262894093, 0.014955743700416099, 0.06569715697438487, 0.020966518392425873, 0.0026136650440974104, 0.06017592683013889, 0.035840232270739736, 0.04844000375258827, 0.03794862115154824, 0.04438707687621636, 0.029437579665212866, 0.045640216689677014, 0.014727570157828591, 0.026170900316848874, 0.07718754121132436, 0.03162643650636798, 0.107017710294214, 0.040302326707469846, 0.04054106651775299, 0.0375637500697086, 0.036534307930137844, 0.0776856822232085, 0.030427696596410488, 0.06858257351503258, 0.052167971453238884, 0.04958637389204195, 0.05962088080723921, 0.060972282888307694, 0.036556041844549685, 0.040589241956871365, 0.03625733650199348, 0.05061167149594234, 0.031064790636000615, 0.03475313052354801, 0.009741427530834993, 0.12417246437361165, 0.018287918778256546, 0.04205002990220824, 0.04503122658558911, 0.04359679589528711, 0.03664487740024924, 0.025917754223149632, 0.04264108588798873, 0.04165079084134871, 0.05458558023336434, 0.005613442711276753, 0.026744832322301886, 0.03973855877355222, 0.04410168997222378, 0.030318439051869418, 0.041636212188149654, 0.06784732829058363, 0.03180558233702135, 0.025114897908943317, 0.038734949118788206, 0.10354301892220975, 0.0062559558653212605, 0.005894986726719165, 0.03510320972230646, 0.012177633095322358, 0.030359742682307, 0.02886165391593691, 0.09271868684839818, 0.00855188163357877, 0.05758784433466293, 0.04670053983347551, 0.03851339266064667, 0.017890750070012385, 0.05332173817160149, 0.07987435711848159, 0.03359508903456792, 0.024660630752482725, 0.041147946049609495, 0.0680491694759938, 0.054536259492799166, 0.0225682033135766, 0.051644522726776144, 0.03537556930114666, 0.05758178074874225, 0.032295681340920354, 0.013144646729943494, 0.03823597690150623, 0.020697204013084693, 0.020680290706936392, 0.08380579011094186, 0.03413696983648885, 0.027770060978289095, 0.04794169420136079, 0.030132861913091717, 0.012458417726109826, 0.006569733987787679, 0.034172003037266196, 0.08011614212826376, 0.03549629709713402, 0.05848102241514191, 0.018121880711987615, 0.028635391762720484, 0.06821420013664231, 0.06994752769148158, 0.03970640223293055, 0.04481132487736402, 0.03240848012689141, 0.07569759212914975, 0.025893647351392338, 0.01477813483366082, 0.02126040695715816, 0.03001604882639743, 0.04290439413800355, 0.0814566887434452, 0.025722417124216596, 0.028058956564974882, 0.03793194341743666, 0.06363475635167092, 0.03194164338281318, 0.03272316223310848, 0.007601347507818813, 0.048918770400867354, 0.027980601092079477, 0.06572233062357673, 0.05158995811436927, 0.01184614014721686, 0.026447239722455704, 0.049434087104013855, 0.07114307684523445, 0.041542745630947814, 0.036709531390618895, 0.022308566539938894, 0.02312319571032159, 0.04773107364833836, 0.0147854873625141, 0.028638915767172174, 0.05787673226046947, 0.01743350091630653, 0.03067199820502391, 0.03908077269912728, 0.03134558292766733, 0.02439444584231223, 0.04498230038030494, 0.0700044786677726, 0.06206192038652878, 0.011933340105198085, 0.07412856745143091, 0.022671563896320523, 0.01682302268642572, 0.10768147185444833, 0.025075513328756058, 0.02651568010239111, 0.003906413279060696, 0.08385521810381644, 0.037169279906177716, 0.03904401197008068, 0.060847743804897034, 0.04739259685119314, 0.05531082034952218, 0.028319367087416114, 0.048713455006720564, 0.008876361046737481, 0.03786790229740643, 0.01490409596778092, 0.02241600654087961, 0.10572754162093324, 0.02185768357688381, 0.04217152378611988, 0.008298521035260732, 0.03613484287334066, 0.02698758260286864, 0.057176382340971506, 0.009547592921843453, 0.05542638088246027, 0.05630678444680187, 0.006344997785955427, 0.008696816850363488, 0.022689049853192225, 0.05590308292378342, 0.02670704120499713, 0.020853064601279555, 0.03569576724041854, 0.016194981890880776, 0.052290445929693605, 0.08417674520563695, 0.0379056780929527, 0.059005114655461044, 0.026819562284095634, 0.04458490759134293, 0.0327102076863089, 0.041269252241979686, 0.015417813462385488, 0.026447385279161316, 0.01689595808725684, 0.015131518744202632, 0.04355347745360867, 0.0639805990842081, 0.10298896115273239, 0.033162283831306046, 0.02212216585664259, 0.04037041277174027, 0.0615875932177709, 0.04836511482755023, 0.0207393350184805, 0.09243666690083281, 0.03277796050233226, 0.033284467194349535, 0.0374542378009327, 0.039576163455363245, 0.06734420004631243, 0.029000248797538302, 0.04204480901300427, 0.07394613127314276, 0.037896174772252, 0.016081763671771172, 0.017616134362235185, 0.058142036169527046, 0.04135471701081242, 0.031409568506323045, 0.026549690575789542, 0.02549609942962566, 0.038813990240375844, 0.030690445602240584, 0.011773592578397404, 0.06089352521925204, 0.002316175387316053, 0.034458201994458516, 0.04599584236500725, 0.08225857595642729, 0.06036939467453669, 0.054322114935325044, 0.04920386619144871, 0.05247081750102582, 0.14548515300116233, 0.02744405417733135, 0.04895278853514502, 0.07761989059227128, 0.008793046112142263, 0.029551761239887248, 0.018675342848103856, 0.02182346051408639, 0.03312881344989423, 0.04546294011355889, 0.06126534982374119, 0.01970263802626681, 0.014527057177357137, 0.061308388643327265, 0.03209176214201556, 0.03754049930120668, 0.04642810747628251, 0.03198629673269968, 0.031165347336941672, 0.022243991073581482, 0.03697360955899762, 0.04945072653372923, 0.03667210416507818, 0.014272593412428133, 0.16096873989989682, 0.08355297343505007, 0.11326338765361618, 0.16855969063697324, 0.13363915074977184, 0.169919052371575, 0.15833312164871924, 0.12851312621346406, 0.2613956961900957, 0.11109610959406822, 0.1754153195408083, 0.14355917731600423, 0.1438678954277308, 0.12428487245474132, 0.07608589145445055, 0.09008022641102154, 0.17475349618302238, 0.14386758899256108, 0.16750160063947403, 0.13395438060885476, 0.0834142578946006, 0.14373890154304045, 0.10071079186614483, 0.2508922477042483, 0.15674169656009446, 0.10631215097683092, 0.10548349665177446, 0.14482340625216886, 0.08182174496112332, 0.07873820276149819, 0.21477536959273202, 0.1160425861035624, 0.2772355139736207, 0.13934546390608435, 0.11567044357258467, 0.10686794010501717, 0.23091598413884643, 0.16271667675145213, 0.20605172721608994, 0.0809558894064638, 0.1884704843283661, 0.18082662755923887, 0.1274017318181934, 0.24625812056324176, 0.15521390273446037, 0.111951845127248, 0.23534899787797084, 0.17908765393639767, 0.24275005074037662, 0.12228928235990387, 0.12294996424668259, 0.20427480159747988, 0.06846569914130435, 0.09569042617635382, 0.2870758214304524, 0.2509368799867169, 0.06949093928861041, 0.12046345734908698, 0.11146277459638734, 0.10082493130598338, 0.08680071125948623, 0.15569191095569443, 0.42956026931924207, 0.15721559855005435, 0.11153548400128081, 0.24068404950441855, 0.1808685478904555, 0.11436176621505331, 0.16183982783507916, 0.13846293061731324, 0.1067315534718575, 0.10649611167008839, 0.1380181246467175, 0.14442415186955085, 0.17821478867723098, 0.09639000234704825, 0.14450099048835618, 0.1619555377551625, 0.10771828237921001, 0.18246268493033227, 0.18412037662440733, 0.11984243583414825, 0.13775486619241778, 0.14125280833292392, 0.19091281859624773, 0.24152320689491688, 0.24905170614440597, 0.1773190020673698, 0.16279616603447547, 0.18871645983909408, 0.12222638654132044, 0.1105531907430099, 0.1737801048664316, 0.10985195216151977, 0.12365750007091031, 0.14313807410578575, 0.21667839328367866, 0.19281161348185233, 0.13843309915354177, 0.1406092178677359, 0.2288137469440699, 0.09992902212205435, 0.1326872558603364, 0.13089045792097045, 0.13264752654058318, 0.13287079520523548, 0.0974251326894568, 0.09298261179919205, 0.18992481032206168, 0.1462618742258318, 0.12604605496650742, 0.18775385504047717, 0.13432758800204725, 0.10115844768381889, 0.13764375279988014, 0.11163649269409719, 0.34658890217542654, 0.20573283545672896, 0.10339776099088693, 0.20161581766461173, 0.19864705841868155, 0.13473039703263393, 0.10250270982543308, 0.16123455708786366, 0.11600950642699197, 0.21969579911280065, 0.15452045526716018, 0.31903857245079936, 0.15266218643275, 0.14806248728306065, 0.15277216601515972, 0.20158201786539248, 0.14968113913651437, 0.15685975070922606, 0.12445967073642439, 0.18331742454921046, 0.19027462139004664, 0.18202062155450546, 0.09673916990117681, 0.21188233047723773, 0.2418180128499385, 0.1500421350881938, 0.07295004077135556, 0.12213686916736827, 0.0983731358522369, 0.119093676818715, 0.15333524063950585, 0.11840259656310083, 0.13980986640578316, 0.12077764532859288, 0.18092569804960684, 0.142871628725721, 0.20676164557376217, 0.11563599259862978, 0.09789390189032401, 0.1615405172830628, 0.12140147838621371, 0.14392316101058839, 0.08797343099309553, 0.10710165054807741, 0.16673094683116482, 0.11308861235457082, 0.22776245980733828, 0.10353207152577178, 0.12304315118179207, 0.13686454945033596, 0.09010299454413115, 0.2139477801298903, 0.12272618996400027, 0.1996084374766196, 0.12110913923430829, 0.19658496423113733, 0.1225314197701312, 0.22699724522329148, 0.15370379021811872, 0.14519125102989136], [0.04056985610194745, 0.04259566070451852, 0.03592712962399087, 0.044109078890253464, 0.01426245040831066, 0.03647050429736415, 0.04932113510045794, 0.07167503297809633, 0.05997279478657631, 0.07982763341597973, 0.07424680546166436, 0.03294250086670922, 0.054631181617057135, 0.04493384148865458, 0.03496036496794513, 0.04442926916864611, 0.04287696052943507, 0.033928387077345, 0.04876597799480923, 0.046843158591899185, 0.04926385087591987, 0.055435635224585576, 0.014933182411046039, 0.04339909924554729, 0.03073915921812577, 0.0896642713116542, 0.04413598006771457, 0.009224220505735327, 0.0549341578997912, 0.022675723753749363, 0.07810208165357191, 0.04029788339750902, 0.0391057969611739, 0.047844232495633826, 0.019355751498932802, 0.042190400192574154, 0.06863001734018326, 0.04540760558278811, 0.016215991852204167, 0.060108733258300254, 0.01432019045516368, 0.032332560813595215, 0.03804159358203892, 0.05289495441942446, 0.03133343468840805, 0.03648419811901066, 0.05843774993873893, 0.0622142646311512, 0.06999708591930329, 0.03601440619076452, 0.0867671872519197, 0.018501354704400706, 0.01889435589433678, 0.03342735408354671, 0.026699707828341957, 0.027346609708582683, 0.028825785679322098, 0.039013165439809525, 0.04343671416262946, 0.03658594608667397, 0.006264867383100454, 0.04218600284788878, 0.038860032124625105, 0.051230988465249545, 0.04562838829212612, 0.06492160786423953, 0.0287534631488304, 0.027616563771340637, 0.03335578998010005, 0.041465144754657825, 0.01479892454470598, 0.03349085511159032, 0.06707617652512367, 0.03034641083720471, 0.016858278052701105, 0.046522665708776445, 0.007925583688061564, 0.055782270858124386, 0.03115322016510031, 0.054156375643346584, 0.052660171453270226, 0.027096301970642903, 0.002650449473989166, 0.0207076036566568, 0.030345332568451285, 0.04266838926161009, 0.05247891121994584, 0.05674021784216166, 0.03299583590799763, 0.02109384603588091, 0.05538213547439345, 0.028811699237614393, 0.03399341645079755, 0.07210636346210396, 0.029840291019589193, 0.03309479531561656, 0.00897151874303217, 0.04695185497703572, 0.007886876138077389, 0.039070775251715414, 0.019207745227181626, 0.03287572098234969, 0.02468427988670526, 0.024390718824560606, 0.0683945142513802, 0.056594737745340795, 0.05079009337350727, 0.08130412233332474, 0.042281679568752166, 0.08440393624046157, 0.01068476521815624, 0.010452419369211121, 0.07872727834769795, 0.026568971093623873, 0.02786283805635908, 0.05171298800456909, 0.029423843708730517, 0.05401774054212917, 0.05174855363645381, 0.041456284947813525, 0.04346028285761995, 0.04883499102546804, 0.005663537200645454, 0.017189040344448823, 0.09078881943658476, 0.058963826346781954, 0.03698900792627566, 0.012926624809962609, 0.07054409567987727, 0.04207972730059297, 0.03637047619709084, 0.05465322196663869, 0.05009846919546685, 0.022530820138091524, 0.051477366172137766, 0.022599003878572298, 0.04399043868385977, 0.032749132613741586, 0.06888104903121149, 0.0077758297782331235, 0.02961898737046267, 0.009555489373122974, 0.02207507826237669, 0.04053354353433655, 0.02572616903982576, 0.017507665888256124, 0.014253976518258214, 0.10114224492422036, 0.04513789666816593, 0.008812070948131865, 0.048792296945447886, 0.01896021455796736, 0.03349653182310924, 0.07942820283313913, 0.05776777157499906, 0.028279440500022426, 0.03573729686679379, 0.07293458877792282, 0.045210789934161215, 0.06444030546493108, 0.04420412358857932, 0.026117203299016244, 0.02994179000867711, 0.04898079670965672, 0.0326343419991674, 0.01891965403281633, 0.04450422704159733, 0.052392894867807634, 0.03344400883502057, 0.01942004734319785, 0.04488177432288085, 0.03179786591640404, 0.02382756950664184, 0.04695239506902234, 0.03767887010209022, 0.02232305709302666, 0.03353829510630139, 0.04776141073013987, 0.04491128786016376, 0.004473022680969969, 0.04187243156916192, 0.05060502951363883, 0.0018357126921933566, 0.08158404319997757, 0.05339834313358992, 0.11232451625889349, 0.011202417531861894, 0.030441480433388107, 0.036619408807206544, 0.08167606568144214, 0.023031878029747356, 0.01729148928256285, 0.09945615435079222, 0.11048533833555638, 0.02941094087286582, 0.0370987615127477, 0.02158451002962407, 0.029211698640738765, 0.07842708679456865, 0.054848785061509385, 0.019646594864166072, 0.03524557567171512, 0.01098793398048128, 0.029075181772631985, 0.05239700875996102, 0.0861500881071533, 0.06436607920594754, 0.05671080389630891, 0.04226225157899242, 0.023923975926253106, 0.03741716297583715, 0.028964518456749862, 0.013797369920798849, 0.0282196415918729, 0.018217718311315103, 0.015090511015225804, 0.010797926938281426, 0.053083235848574876, 0.021866466774935686, 0.07213564334256996, 0.027629135274178082, 0.008564688708452929, 0.009737085727524134, 0.006889768654570705, 0.02973876330220411, 0.013242979860684324, 0.007187808458242686, 0.0828701439463804, 0.040894198576889695, 0.03523271305546646, 0.0249470365534146, 0.023338259573304848, 0.007143248475321959, 0.04493559199956156, 0.07441673142414901, 0.0511649401948577, 0.03671028598722431, 0.018433218844415202, 0.0605080642497107, 0.00559414352004927, 0.02652422964362608, 0.042129825620401296, 0.03006210220196555, 0.05394047674452586, 0.03209574962966144, 0.05279026850457153, 0.01606212979588177, 0.04982160501963189, 0.10728264648106792, 0.09310141671448947, 0.02278392601217474, 0.017918832938096697, 0.03324478767031143, 0.05245345028778238, 0.03567264670686376, 0.007362032173982552, 0.04733908560968215, 0.030990794203394366, 0.012354033458377085, 0.03031404936806329, 0.03332530734159293, 0.048042484559118755, 0.06988567375247517, 0.015002745109790517, 0.019165495478157556, 0.011756167908559644, 0.06102146190260688, 0.033851916180743326, 0.05599214447542064, 0.020791735432501283, 0.07110946090711702, 0.012838628120540131, 0.03432103778205572, 0.06409481896327869, 0.04137904796328756, 0.030731557710697095, 0.05449829217527182, 0.03328622919657538, 0.014347695884475065, 0.010786463390104474, 0.018597117610155575, 0.012231194132548428, 0.03597645802543529, 0.04249205114319921, 0.03191278676592535, 0.02855940158629129, 0.05596890902867722, 0.046274836265271714, 0.05846829769471961, 0.01875197653838944, 0.08513905122996339, 0.03900410645010491, 0.06311812197729465, 0.05282191942716318, 0.02590542978366777, 0.03033180728614811, 0.09837656026525844, 0.04548234512068091, 0.01627541154683117, 0.05637832173717119, 0.04345935206079195, 0.13539215910338587, 0.043715106683873364, 0.043379318855342366, 0.022937857974020225, 0.03431606204098752, 0.01872861085669889, 0.042833358635224646, 0.02888162008246347, 0.04764482746982286, 0.05478497376785644, 0.041975232907721115, 0.06326695753922386, 0.05605993942627984, 0.058527830387315447, 0.010414078583820693, 0.019419840499458295, 0.04339305864226434, 0.01919852727423272, 0.009349893399273917, 0.016391774556869944, 0.04351936355834046, 0.03633405637717055, 0.06796473892585886, 0.01749959706719364, 0.04112487914220941, 0.08185528429044832, 0.0296488628842898, 0.05779565717544287, 0.08671325466205036, 0.06925506847760371, 0.028704921902728178, 0.030395545801448248, 0.04541563035379495, 0.036295556628535834, 0.017114298891336206, 0.031370080504266006, 0.03207932853500449, 0.05030800190363681, 0.04753255345407994, 0.03881175326363694, 0.054667892550388654, 0.027440495698923068, 0.016000170519785778, 0.05168419075949539, 0.04044066686483641, 0.05929442776006557, 0.02561757033089957, 0.038759490745442535, 0.022667227838669094, 0.051742126158769094, 0.026515063401612065, 0.10011141999594628, 0.16946224946408503, 0.19886376937070202, 0.11785664400386235, 0.08539896954091326, 0.08681106110734325, 0.13933873765410917, 0.17203233655421965, 0.22946604016807773, 0.224570723010167, 0.14035126074187218, 0.10564864988649085, 0.08736622204343159, 0.14234452959029906, 0.08574108908613844, 0.09117102836288753, 0.27230193838477135, 0.1505200973441524, 0.108919546548878, 0.10911438569066026, 0.17556697430629886, 0.10228951521698507, 0.2092582648319583, 0.10519339447660793, 0.14312636828230274, 0.3160912483449905, 0.14755055668853945, 0.08781329563428318, 0.1994479880217583, 0.09970284998416902, 0.16225294840912666, 0.18909208807012728, 0.11071904111773738, 0.08383169154366178, 0.08682728684957951, 0.10270036817077668, 0.23618371195850835, 0.09626761980114446, 0.20520722253188012, 0.160714628535413, 0.11062454417227738, 0.12201715260744096, 0.1657736893262594, 0.1380780940094302, 0.10751805763932006, 0.1771106567954825, 0.16463430207823554, 0.15559604271284996, 0.16855587551911033, 0.10022269426694802, 0.13693187325712175, 0.12563906309585418, 0.13939286942683882, 0.10760631096819717, 0.13973046905331074, 0.10821537385063787, 0.07664172654791225, 0.12733715060617656, 0.16517572705784153, 0.18822450881763814, 0.10101384858811095, 0.15121314644573197, 0.16599625319002137, 0.1566939386388948, 0.21467706519028834, 0.13394521819728036, 0.31748083990908443, 0.13640475879994132, 0.1242789812386036, 0.352255838412431, 0.0960471703400535, 0.14382638878399326, 0.2390713731367742, 0.15071889716050318, 0.10847285600198854, 0.08983231269784513, 0.05972030369805233, 0.18252315991107496, 0.09179630932668525, 0.1445950814072163, 0.1613315131755606, 0.16463258604128517, 0.10518446955229006, 0.206860869281715, 0.1410895243527428, 0.17191270426396402, 0.167544762033128, 0.1971978345705617, 0.14941720652484125, 0.13149531498070688, 0.14185032627034572, 0.16197473591854497, 0.20933125768938374, 0.1512707409358794, 0.0894792304344235, 0.10700656371491571, 0.09480826060978637, 0.1786202943373111, 0.13836641886061238, 0.21347067589240692, 0.1145669552046926, 0.2037170742668452, 0.1678897007819145, 0.1078350954659043, 0.15678176295853433, 0.18312199551972652, 0.09163024444733897, 0.14927924941143683, 0.2772697427820775, 0.1324128584876176, 0.1922228595902843, 0.13675674555763123, 0.28962122516766675, 0.09887899903039779, 0.1218059191840791, 0.11756902395357048, 0.17997107588716094, 0.14576411625790983, 0.10630606823871214, 0.16501120201522307, 0.23672260884796423, 0.10189598351116143, 0.10854766448779453, 0.15960321881838385, 0.29980326912576155, 0.225798869205098, 0.14515155235365515, 0.1307463567824133, 0.1086591762460528, 0.21862925150461737, 0.1150372259378914, 0.14721327881899574, 0.1846375319385721, 0.12631351158263224, 0.13209104027238586, 0.22570465571217, 0.19580314086089212, 0.12384984176605941, 0.20481057284820467, 0.16849622791332586, 0.15887644652637745, 0.1143157702960795, 0.06771318629504212, 0.12577283736919204, 0.09608873060994572, 0.1636919986096121, 0.09843420838156054, 0.17899198487641352, 0.14157242021493374, 0.16299844389000248, 0.11236029256495739, 0.11497409263205145, 0.12110678734438074, 0.2061889182415701, 0.20035420874914817, 0.16658994068782176, 0.06618258858760519, 0.12586556465154694, 0.12665653511160804, 0.14931179282646026, 0.13699319093458115, 0.13884378356799004, 0.23724374781933524, 0.07655736494569049, 0.1642321978485392, 0.10947488368518891, 0.10755063169786047, 0.13372492195377428, 0.08851399795422632, 0.13055681130818783, 0.09998210435432774, 0.08474188060649941, 0.1806122761580252, 0.17592432367945873, 0.11033710798308735, 0.08386800411127268], [0.07257220620710043, 0.020713374213946444, 0.1418785795929932, 0.06710547938822739, 0.03931600765715684, 0.03838932472130945, 0.06615039757302692, 0.07207088593033052, 0.028655248761717832, 0.1329711986885917, 0.06533709564997305, 0.02814750483770284, 0.05808573636797167, 0.035142483219744704, 0.0256800371402454, 0.057914864286900535, 0.05219252840165169, 0.01670090444085579, 0.012001656953455701, 0.0457320284969624, 0.02981737541455415, 0.03376273971591746, 0.02821253421115539, 0.05820397437820512, 0.04818658186723629, 0.04638485415207763, 0.02153455918174117, 0.04872127676442747, 0.06730997123785558, 0.01743906846029624, 0.09359106947217258, 0.05061744013801218, 0.04723872809160141, 0.033201771833363085, 0.045359334382679195, 0.06447311701072801, 0.011189286784839728, 0.05919176814777236, 0.021106430945257028, 0.03844109694323233, 0.01539640322012166, 0.07389728550709064, 0.06916301535262216, 0.0223755034723229, 0.012429389697048935, 0.10296744940381858, 0.021559520241534038, 0.02657715674309481, 0.05871297468641593, 0.03578597792394219, 0.08379531002813771, 0.06325752316643635, 0.04257575390980609, 0.08804627063293612, 0.08232836656632923, 0.0658341488170047, 0.057410766941405116, 0.04224384631661158, 0.0658880201198401, 0.03204878077902381, 0.030448227752781207, 0.04891584011455698, 0.04297479761824493, 0.05006206852774467, 0.06914479012090353, 0.1058852254983879, 0.05898097139452735, 0.003190261120307109, 0.05032679787085903, 0.03591146695637896, 0.024505086175556627, 0.07255102387599408, 0.05253626056195748, 0.06528370698252994, 0.0010708736109306977, 0.0403917521508711, 0.02937625049643459, 0.0704490318293533, 0.05710554602105291, 0.08121463560288952, 0.06123309752212898, 0.051258766813383955, 0.044430548535479654, 0.013993013454901596, 0.03915351274753771, 0.018207705542144757, 0.03186623543320644, 0.06492306343129566, 0.013130769047195153, 0.021488603482383396, 0.030168663117013154, 0.04996486346147234, 0.009425206545500026, 0.012395202065818013, 0.018020188285698815, 0.019655199946775552, 0.037495005169823285, 0.02954234218885822, 0.01080156968636138, 0.03606338985264301, 0.024766226396745732, 0.0498006678366613, 0.044741407862954566, 0.03631098563933084, 0.05121390853497771, 0.053089954439670815, 0.027929188931481014, 0.022557181223566015, 0.051630078138963836, 0.03174573937881618, 0.016344945517278487, 0.07772042431057462, 0.036034933516695615, 0.04701885702689329, 0.06910598776753872, 0.030410292993990645, 0.028883102462596955, 0.07285830174242297, 0.03475673496723175, 0.016685659291162606, 0.07371498722462885, 0.031541195818253105, 0.03440886976257448, 0.018687381919833924, 0.01914051718138639, 0.06290708773679311, 0.004841319450567807, 0.03800680552939734, 0.057201184437520085, 0.03151428889513257, 0.03174389693735829, 0.02185467668178101, 0.036805323024670926, 0.043246325991687276, 0.050831481273616516, 0.011473051497652646, 0.02635914535682288, 0.02520804270921696, 0.03737131644400858, 0.0555215098504578, 0.015291978732772894, 0.023045171570453434, 0.026472675756761627, 0.03519861065151711, 0.02590938471257687, 0.02400252100590977, 0.03855874506576407, 0.07984954353061416, 0.02022113590951889, 0.09037299457216456, 0.019823955709955866, 0.017607322435886148, 0.02062055500104062, 0.04556197229953063, 0.04942872448854389, 0.0495324949283273, 0.07392073545845286, 0.01924752817308951, 0.034354695855008985, 0.03783927742211569, 0.07225891455046593, 0.06506069878777189, 0.021636035188191363, 0.016617148048094204, 0.022066235692510684, 0.04289443499498791, 0.05684750845595714, 0.02002904127772537, 0.021752984255492207, 0.02557389182789672, 0.09017561967935293, 0.023629200614748463, 0.09814383807562052, 0.07463249242714337, 0.06337157067572398, 0.01768609925713991, 0.02342449617572129, 0.05217413463058972, 0.09183585478533661, 0.03442512997876733, 0.03945528244179103, 0.04301544241306763, 0.04365491132522303, 0.04707984145610564, 0.05797811633636875, 0.053707612828621944, 0.029330426947243755, 0.01959578408258817, 0.05316321542786975, 0.03834153615659283, 0.019899495809729544, 0.054765097616660985, 0.034887540649863026, 0.045944104617040966, 0.0787067931566027, 0.030265621119929902, 0.008013138919317675, 0.01622181986608813, 0.007627749770519234, 0.006867483635658339, 0.020324806757872144, 0.028267884063684655, 0.04196425486776618, 0.03259004296494588, 0.042651232722545826, 0.004734675223458438, 0.02882029665934463, 0.04811620520007226, 0.01610773213718447, 0.03820584666344427, 0.023543002316728238, 0.04290665026694056, 0.07035321721266355, 0.040067045784164826, 0.029053495738715417, 0.057957784362858346, 0.06753683285487276, 0.12561560548361272, 0.06299341435454066, 0.04603196724107669, 0.03460089736167462, 0.07312744375198119, 0.06265789848722278, 0.06819487939919196, 0.035868600506575844, 0.018949221196253935, 0.06112446242402639, 0.06732674856339732, 0.03996481518110922, 0.06385070887664634, 0.08387191115968651, 0.09429046944264444, 0.04030274422538858, 0.03008381504895947, 0.030415211278464527, 0.04120685055010742, 0.01967363010701393, 0.04003665890664824, 0.03658534087721379, 0.015376002298698071, 0.07510290871704779, 0.051076840083565445, 0.030227100303877267, 0.031429913886372125, 0.010501326422297187, 0.08485234282430142, 0.04038087370234632, 0.015830730065523137, 0.03767947531155041, 0.06982871511530492, 0.013662439812305234, 0.022557974124567646, 0.02506292650416013, 0.04165191699059741, 0.009013594207053464, 0.14659303871373977, 0.013003334151430717, 0.02970819447880551, 0.0910540467368499, 0.010279176246014335, 0.017622192202496435, 0.055022349941634366, 0.03729184631318335, 0.05612754668559759, 0.008600329033910267, 0.014206296163460901, 0.04390930614223884, 0.056069898569295486, 0.023807948079681205, 0.019776351006341078, 0.014484439706129414, 0.04099994169307813, 0.03088294434541416, 0.04900077628272195, 0.030907183367338394, 0.008555939984357646, 0.06418866473400305, 0.04893524895211862, 0.02456851825568705, 0.06453829577132579, 0.02099502069364873, 0.016674039652571082, 0.012270937816450193, 0.020999100111845522, 0.060506938100462, 0.037882741420499744, 0.04385966747518509, 0.03246799749772876, 0.0069191893036927915, 0.05893419406587078, 0.06016098428517581, 0.07331787788819882, 0.049707775845402674, 0.06140397726407936, 0.04187320914840506, 0.0018923917072712476, 0.031190486512176936, 0.037640519740600745, 0.035674615552829164, 0.006646414600958627, 0.07413776816740152, 0.05133809138750357, 0.01067062993834336, 0.043436350270865426, 0.019092558162106622, 0.005323349154599372, 0.027231399660869956, 0.026520387712685813, 0.04491425262043073, 0.01317293261132774, 0.0457261219590662, 0.036538084743604544, 0.06217512519909971, 0.04326788370587653, 0.050811172282743844, 0.025326085367029714, 0.06310635103633808, 0.020617354668736942, 0.024672279119371407, 0.03673126147459111, 0.006820944273063252, 0.02660881915700532, 0.03668350355339147, 0.0417798268608749, 0.05207673804233632, 0.08019409923543853, 0.058282460086047656, 0.0331381673834497, 0.02120832255440614, 0.03260808816600231, 0.03652864270993779, 0.024593925561695814, 0.013319129000357805, 0.03430254441956359, 0.01910099279015295, 0.0501219229772687, 0.06302392763656474, 0.04108022770754272, 0.045789067573364706, 0.06511050216372936, 0.058327092368516235, 0.03764020947499141, 0.05290942582031412, 0.03654368867677066, 0.018953568745224227, 0.023854302144759608, 0.0640756705956113, 0.016998972015215025, 0.0711617004426737, 0.018676957378404278, 0.035707300694118586, 0.006719122090632277, 0.10926575700361883, 0.14912728821077656, 0.20877408194205455, 0.13994042310983906, 0.12744158371201447, 0.22285385868482052, 0.11702577568470471, 0.13870734330867568, 0.225794104138209, 0.1805026183325437, 0.19147547953311475, 0.16706195810148794, 0.1423521751477834, 0.1490739991347636, 0.1051117754691551, 0.06944793111254131, 0.1689935875155272, 0.09852993872857864, 0.15425701295175862, 0.19929162947641266, 0.12997948744845006, 0.23092222009455007, 0.07283056935956402, 0.17551587624174936, 0.13973825250662145, 0.15587823886063792, 0.12192909080054491, 0.16214735084964385, 0.12073737208641346, 0.08482304762207693, 0.16581994571512745, 0.10502886943398945, 0.14460864116347608, 0.16878580914870386, 0.07827864193748083, 0.17055124344844974, 0.12820201024653452, 0.15940728417086988, 0.082256484536394, 0.1739235471693739, 0.17303090152000228, 0.1670446291926407, 0.14069158764135453, 0.1235208682896149, 0.05625077575865773, 0.20098721187922264, 0.12159898351397246, 0.14059556618092522, 0.17190020170903977, 0.15181982679472816, 0.23052635182055736, 0.13577858917415142, 0.09796589883344789, 0.15622133899840618, 0.16583980271412482, 0.23564271598813996, 0.11854527277811883, 0.11293435289013772, 0.15373250319352075, 0.11414401338345583, 0.0809539588648946, 0.1296842065189154, 0.10209754124403962, 0.11802604136567925, 0.14628409077563595, 0.18591109182565443, 0.1750595789522894, 0.09404008892635185, 0.1269501689521055, 0.15807070589113623, 0.14488354415422486, 0.11358103068966059, 0.13865589284368102, 0.15293407103707715, 0.08156280724271651, 0.13709825223251698, 0.1605079686569591, 0.14727949945917054, 0.15347745720176928, 0.2831011427746665, 0.13725582119678298, 0.11003861714514995, 0.10985127034326715, 0.12684087884882767, 0.07924349137371586, 0.15055273268972674, 0.19388346241847162, 0.13366063185516866, 0.13300775640433835, 0.21096526194484005, 0.17776040660758174, 0.17487611621618274, 0.1267566934468285, 0.14821454041427182, 0.07773595291279978, 0.15044806975751154, 0.13502897214024298, 0.08053931377587781, 0.23339217949298122, 0.13051567238665399, 0.24483175677878244, 0.2274515353623898, 0.16319152869043813, 0.2067034841785508, 0.23229155629392595, 0.1482438662600133, 0.20648684983532276, 0.11931541330751874, 0.18509146967722526, 0.13451459006436411, 0.10497669118546671, 0.12693952799083727, 0.11329719511371468, 0.17694106025080528, 0.14526995890323194, 0.14072146507040148, 0.12784250050542817, 0.2074057723004972, 0.12430131270159638, 0.11303572930515775, 0.12517952525447454, 0.1255109195687598, 0.11907650878833187, 0.12286621551480024, 0.11888838057676632, 0.18822971821552326, 0.11384487903166203, 0.12195431807589148, 0.14426520394702114, 0.14796599084811826, 0.14096459073405113, 0.08065850173513736, 0.09102629903223246, 0.10343162207714013, 0.13081398702436878, 0.15155790133341668, 0.17726145354249787, 0.16695433806988502, 0.11196361223776495, 0.1735179036134674, 0.14672417764461812, 0.14985084293350098, 0.11122383177280427, 0.15915305023231816, 0.1189932197092041, 0.12081579650722205, 0.23733736376368234, 0.15707047085367865, 0.23086399741230473, 0.16990098801832046, 0.10453953077235531, 0.17091757137208216, 0.1459628088219512, 0.13692559133614265, 0.08500359156319211, 0.16389125807871743, 0.17965466625267462, 0.13799071402078675, 0.11995807680631838, 0.1374686404221481, 0.16789723908708942, 0.17531356774270537, 0.12145197890218228, 0.13220311893570807, 0.09432439947681082, 0.14128294623186513, 0.191900551078781, 0.15637308569444766, 0.0954963990877713, 0.15742962819433984, 0.1757985167205334, 0.19373461153478394, 0.22046355710875606, 0.1853777107692534, 0.1819707339088763, 0.14031954470180696], [0.036233740993925644, 0.05812863729173138, 0.09194339054726786, 0.05703008636051128, 0.018532524906819867, 0.010444314158972233, 0.043987722902168194, 0.036373460109555916, 0.060097919927249034, 0.06334263936526353, 0.01813038620316694, 0.04306026621751728, 0.014498928343997368, 0.025157390890883344, 0.05856946343556047, 0.08446999600217228, 0.034470221913990476, 0.06901970328462702, 0.008987241740068121, 0.10907769773996646, 0.008215891749357745, 0.07738745185516535, 0.04847639292899159, 0.06794152646175317, 0.0066249133857537905, 0.019366911484769756, 0.05257383717464344, 0.037216693087811434, 0.024038213042301998, 0.04960543032915843, 0.018223485038165125, 0.01085077838656763, 0.058047228958457715, 0.07341372314840555, 0.04448399082907746, 0.10184512293386845, 0.024754970649918242, 0.08886148777580069, 0.04688684092534166, 0.06864380692282031, 0.013984695655263722, 0.04678538407108957, 0.03876312966308287, 0.041054180718117186, 0.014615545120661058, 0.025960143783219883, 0.0019725021200194476, 0.00751230989642922, 0.045234044533102744, 0.038628528014786785, 0.01929241134935329, 0.032280179551772537, 0.052156851687017954, 0.0075323296891104796, 0.04056681856332768, 0.03604551319092993, 0.01081726587031998, 0.02720604023535646, 0.0075794814432400374, 0.0241573377993078, 0.027609354883973158, 0.016590403918657574, 0.027707134516188697, 0.026777360415566834, 0.02010212606570173, 0.04181394075614311, 0.011599198408094386, 0.04013927638410561, 0.022323066669125712, 0.037463610886686274, 0.020531022305329962, 0.06317308878586178, 0.07629752324353303, 0.06940177431510341, 0.05236502841956193, 0.07720762803669899, 0.04229628503502857, 0.020931741831103162, 0.08893560678247484, 0.07384448672734922, 0.012300878447750884, 0.03168125009735025, 0.02383548511011947, 0.09051028518907486, 0.04935275537953262, 0.041330627376033414, 0.046286768084692384, 0.022997264262108554, 0.04162561336171724, 0.06357280282123436, 0.060166277952732584, 0.028310832867939627, 0.04252770487519522, 0.054300220142449104, 0.05105330203209193, 0.007033685932026035, 0.039631386903385, 0.02699263303750946, 0.04608111178141929, 0.025234463166505582, 0.056353707332164056, 0.04195667825819504, 0.03108430481065185, 0.017664800097625104, 0.04310996617160497, 0.030881885228858843, 0.06641216215587432, 0.07163904216741362, 0.05487772403284908, 0.011852456542152551, 0.012487040686180756, 0.03668001019245675, 0.037685937263191714, 0.05164617747669259, 0.0498471463910274, 0.06953794644364426, 0.021009811936246774, 0.0755863331799065, 0.0460611590214314, 0.02330919611267746, 0.024344941240645224, 0.059568782997948516, 0.0437147198094716, 0.10229763574898244, 0.08003729635909682, 0.1022970918265562, 0.03249013743874046, 0.03827189876427574, 0.05735207311508637, 0.022155645814153458, 0.05958264152849874, 0.019306869343704274, 0.045628568322788325, 0.06337845780616326, 0.042703797845470334, 0.020879776171979406, 0.030291828987819534, 0.021036063854192055, 0.018208935113263228, 0.11225009081704963, 0.008762301088521078, 0.007168667272649586, 0.039992022793740034, 0.04638970731907795, 0.010697052310851794, 0.05093260487962154, 0.04985989026364781, 0.02083930374693967, 0.010749437403114093, 0.03515322760288273, 0.01635308903191359, 0.019331060485133243, 0.07870467109305244, 0.04285527258029869, 0.0883251419591327, 0.015459507797664453, 0.03729537031763504, 0.07530792150646448, 0.016221174437011925, 0.007670516628892191, 0.029073046302543055, 0.06557384746209269, 0.01916192933887003, 0.03681393768337946, 0.032348625677367376, 0.10156914742002565, 0.058982327370153326, 0.06151160878700115, 0.061412522974874706, 0.042925794804168325, 0.013501051899736688, 0.05864439832587397, 0.03356767074775792, 0.060670670242078846, 0.03869192562096062, 0.048129286151379354, 0.03704758300896614, 0.0529109082004476, 0.06073568046333329, 0.04724251639638697, 0.01918259839106712, 0.05072951880133441, 0.02663441032411591, 0.041029627600143996, 0.07198278581903828, 0.041337119971191695, 0.041386291324611635, 0.048381359721984596, 0.08804768789559604, 0.01071911372785126, 0.04369854386295042, 0.029913205353002396, 0.02422020872003369, 0.010647018150907132, 0.04535384153226211, 0.05929895533969807, 0.06397632431359061, 0.022754636555609685, 0.01795595564368752, 0.044229228289857994, 0.01916479067726722, 0.015476312893893451, 0.05307963140489114, 0.015918166553150984, 0.059396957137411645, 0.04069840182520209, 0.05296872485609305, 0.015767367890915804, 0.05244650187030916, 0.026463413753757076, 0.02766775951210049, 0.018480455825826334, 0.012170960469501875, 0.009353596476777908, 0.030464830793320175, 0.0661386534451477, 0.016227377833978786, 0.047828523862746455, 0.02640544196530696, 0.040699439874339494, 0.04566943528310907, 0.046183422823706945, 0.029247467285923423, 0.04358338552617258, 0.035986478455484874, 0.022005818168362303, 0.03782686296730273, 0.012720348933080753, 0.026444355401420788, 0.012015591135188457, 0.03320224680787614, 0.05612933550090079, 0.03340132241587966, 0.008698168995549843, 0.030191195678086053, 0.039951117529023084, 0.04224972221099081, 0.02392516910819517, 0.017641863425172145, 0.029953078314241384, 0.054716864720948284, 0.021663193005107103, 0.011782517502715271, 0.039664079705553676, 0.049245246430678714, 0.010935308528132738, 0.02802076133629007, 0.08786096928581115, 0.01992802300880994, 0.09849692033904214, 0.028432864928618077, 0.06388463891081272, 0.021708478377531135, 0.039668706876616326, 0.06339248104561722, 0.04472655724854239, 0.09677642475693457, 0.06368517642840743, 0.012550368386831497, 0.017520421252195394, 0.07473858794377697, 0.07009395773732854, 0.05923702862233885, 0.041171541557677334, 0.054751825143372825, 0.05283379378998953, 0.004620946119464333, 0.04458881080931714, 0.051949088641953085, 0.02830991356243049, 0.02105438484690122, 0.05699417598906064, 0.03503831058380104, 0.032516927533452554, 0.003062983033164675, 0.047544255447123325, 0.03267832310690034, 0.04412337792136016, 0.009762059236245771, 0.01692938633383282, 0.0586013978106841, 0.011238025298582451, 0.038854769100585294, 0.07503906294943825, 0.003007088779404219, 0.029026056384487502, 0.07691662187778181, 0.033273366580326716, 0.028821568365298936, 0.04370589447658389, 0.026436008873485753, 0.07105002780595134, 0.011956330403805742, 0.032838998557699305, 0.03748933611918361, 0.044020404213018, 0.046976618769188086, 0.029717165368398833, 0.05536143194823977, 0.10551374180302506, 0.06610941952995716, 0.017143410232458866, 0.04981747580572002, 0.04020690662606109, 0.054356975766319426, 0.02639809135167349, 0.023131863995184822, 0.05570983724488367, 0.04150262177591363, 0.08196673476167264, 0.031327466863477905, 0.056752827649395314, 0.0184020237441385, 0.039361854188985405, 0.020313932139786984, 0.05962979424023821, 0.04418963303549155, 0.015755846886144533, 0.0015424112620342884, 0.043488042053556254, 0.015797204142736814, 0.050323978667297674, 0.0818039870430385, 0.025883408586284327, 0.04292289899181455, 0.05202135371585047, 0.022690333050465392, 0.04279098631213269, 0.038617331639773426, 0.0377036185724841, 0.062136104510676485, 0.030701670705551104, 0.016843536605818138, 0.09381435345858337, 0.04326814034533116, 0.06958243316940724, 0.016798143981084708, 0.04324437629791998, 0.10893099190246676, 0.0016988652092667538, 0.04102095165440152, 0.07250678229836688, 0.05441036443376253, 0.02838461288070727, 0.054072619250585, 0.023375805542473833, 0.017309551720597574, 0.019078335739792358, 0.05005748732195747, 0.0391658237804809, 0.05293161172660128, 0.013971674075770765, 0.13211829768073174, 0.10761634672000524, 0.1712146909126351, 0.16855052822539884, 0.14888057725564127, 0.104483422492781, 0.22576390495223386, 0.10913523860395917, 0.23180761855215798, 0.12389715535626297, 0.13325701077138224, 0.09749260971382742, 0.1636347871634268, 0.18911519328192358, 0.18008752125165156, 0.1376022461561426, 0.14306043875553917, 0.20425569536464833, 0.08493877286391874, 0.2491984885906981, 0.16426461868949477, 0.16740107458204995, 0.11651216735762936, 0.15084116479321835, 0.08085363965121009, 0.08296426550875749, 0.17478378729954844, 0.16539162595666226, 0.1304526386722442, 0.11300583655435233, 0.13774973340332508, 0.12297377425936923, 0.22531681603962378, 0.2579137040001731, 0.12251401425249155, 0.20628854031524352, 0.1129116920093375, 0.21354196803464046, 0.1587698990178685, 0.12018443280530554, 0.1334867452181155, 0.08215269494441249, 0.14326167473148915, 0.19481583738759642, 0.18398960541573264, 0.12527058246515452, 0.05884931918473975, 0.14304234375876768, 0.2153612736372217, 0.15759829011174942, 0.20124377472506416, 0.1949736361782397, 0.13719790494970738, 0.10061323822986695, 0.25640509301616304, 0.2090401136346402, 0.12374647352243624, 0.07996254149944552, 0.13268207710596824, 0.16792032897712725, 0.18511670461345106, 0.13914692455962782, 0.10295669352936168, 0.10998551959111807, 0.15794361190449807, 0.12832155826711847, 0.08011086378246546, 0.15672940850978898, 0.11981221366553538, 0.09210916431320292, 0.11536822188645603, 0.2843163727271942, 0.13421465132024982, 0.24380470866397505, 0.13579101512028327, 0.3220109935970076, 0.13609167398704639, 0.1305746458350651, 0.20999107389680802, 0.18613103566871536, 0.18451624489840002, 0.10011745676878961, 0.15538739100579294, 0.28251189858682696, 0.16035871940755075, 0.1284922656392859, 0.08896091832749306, 0.18753251691739406, 0.1005898342437802, 0.1932710823753188, 0.20506784049493654, 0.10641278428656441, 0.1504648470830533, 0.1285050056814667, 0.17247357255508824, 0.13315573394779237, 0.12652274551651171, 0.11139157438470472, 0.14446863093443457, 0.10835444179153252, 0.13521480974891495, 0.21835471623607222, 0.08618244000019566, 0.25090323340508247, 0.12919525856212263, 0.1411597899371578, 0.21571621749429934, 0.11664685327559711, 0.0981460520697217, 0.11318914607287416, 0.12218885589390995, 0.16121531295920574, 0.13980032095024664, 0.18342299146517632, 0.1809473323725885, 0.1569002767604205, 0.08115855030595295, 0.182409196671459, 0.06167694205237974, 0.1715614682724399, 0.08930859201016927, 0.14117814540382356, 0.0897734235191057, 0.24402639918750335, 0.17182422110870962, 0.18890911563029214, 0.19032613314207525, 0.14704109289713446, 0.1213714247569442, 0.11378176104758056, 0.11875888873492518, 0.16653087530885974, 0.18397477395351858, 0.1959518998140289, 0.11660138595729105, 0.22957277153768849, 0.15995339760857244, 0.11083236084349694, 0.0758138076672631, 0.20884997061183377, 0.12901718908500287, 0.09078042311293465, 0.12886133615768727, 0.092501416652193, 0.10946599706526726, 0.1737292213065009, 0.13762607149058773, 0.07883525077974604, 0.14242663889402343, 0.14765555669944133, 0.08795099227779335, 0.1354496310194654, 0.1477917671323784, 0.11369841068141884, 0.18150879821229368, 0.17772021763507398, 0.17051277051289238, 0.20804573150892414, 0.13639535124023117, 0.11881357209096033, 0.11456895469417495, 0.15217135389966352, 0.15836600214242935, 0.06223478046576343, 0.07555106249187263, 0.19447862080508665, 0.1786213515386466, 0.22743828204129973, 0.23498325218116087, 0.24268772182685716, 0.08121724796271132, 0.12850900466043141, 0.11388262418369133, 0.11776397800854138, 0.11442654660993046, 0.1487666140160253], [0.060371455451053005, 0.06978726975860135, 0.009675465445334633, 0.045866136018547325, 0.021289183134813944, 0.022214466044979713, 0.02635605802248803, 0.03247931644681, 0.027516694634311625, 0.023869673698960293, 0.011436245760940498, 0.07267532164170858, 0.022705271764988863, 0.024119163638040907, 0.06516481779756085, 0.07417101638331529, 0.021339886664082448, 0.025695106089715997, 0.018651942692456708, 0.02238071478542782, 0.0299403918982153, 0.015873000881965124, 0.015337627996960956, 0.05106372848874138, 0.014785672181225834, 0.048669470068548, 0.06055393376417699, 0.017155366949737072, 0.03731277200483507, 0.019348887351131248, 0.09110400333039223, 0.0257311160525968, 0.08359724565619424, 0.06556926625630548, 0.022354888046280514, 0.04993302484733924, 0.09487691740956038, 0.049765029426423774, 0.11001134441504556, 0.039466984434834415, 0.014032809807348156, 0.037931602508310354, 0.050363504973750924, 0.06021613112440514, 0.02969989391614593, 0.025583308963705937, 0.02214125676771566, 0.047871578004091024, 0.020785271565640168, 0.06440044591023077, 0.04429778932864147, 0.02444090332926041, 0.018052065204228127, 0.023575834929943088, 0.05198055187300329, 0.035724361472192316, 0.015229368281941262, 0.0563278365429611, 0.0760073674422118, 0.06221576999392241, 0.04200247116386891, 0.09036822184439629, 0.055439427359810764, 0.014575287200240119, 0.015853069189395157, 0.06239084406725823, 0.014352927307387995, 0.015591425265395835, 0.05064789596344194, 0.04440788382423982, 0.0777457818208683, 0.010523237494541513, 0.03548415460353417, 0.03933062844519173, 0.03472300411592569, 0.021701265659724033, 0.025264430610883622, 0.027494050990489703, 0.02933869495116655, 0.03162229771635706, 0.21681904702657656, 0.031129415898073106, 0.021457347095072753, 0.042178284512051654, 0.026854685500204086, 0.05545194140605389, 0.05341703184850274, 0.08844315014298886, 0.08231712805648005, 0.05865672085013601, 0.04572147180536582, 0.07115002526270767, 0.004904217184371045, 0.03551425036763953, 0.02012294642026386, 0.04003614179729935, 0.030516465119416677, 0.03394183958129537, 0.062354730682507645, 0.04360951295483016, 0.03715121172248356, 0.08245663266749152, 0.041939755375947685, 0.07098227498992797, 0.02256738742993724, 0.032046624241516955, 0.043406752463910854, 0.026447795136200807, 0.013977038606460539, 0.025554488735994505, 0.10018023001330514, 0.04433724285674192, 0.04770622558651432, 0.09250851828725108, 0.01772594540530155, 0.02275071418543737, 0.02782557170928246, 0.023641797015443448, 0.017374188473988927, 0.05791350831127456, 0.07186018110763642, 0.039722256422523534, 0.011982439637875125, 0.08723332877120665, 0.04913881000491881, 0.04693908046089834, 0.06534387552810293, 0.050647941928717403, 0.031422840979611205, 0.06474714666124314, 0.02754806018915148, 0.005725341343936781, 0.07299208367664008, 0.04803196617191838, 0.04356368940563933, 0.033137447260800874, 0.06818174865216979, 0.02152936893605417, 0.0754283735107991, 0.021002993753720677, 0.01186709073672612, 0.07607855999301519, 0.04045404659043397, 0.04557824783748196, 0.08244556269698566, 0.01979594370500455, 0.028547146094722614, 0.021424635140705976, 0.03795123734180966, 0.06287871184007776, 0.01820104057720352, 0.031879297232315425, 0.019386500352993608, 0.024457607876449346, 0.017836696821294965, 0.02437906471201249, 0.017187523490358746, 0.006875895281066939, 0.053501581142265955, 0.07969464821320388, 0.01610758849569867, 0.04013675595483473, 0.09993653744459154, 0.005832510341274282, 0.0598772942659355, 0.05568817227838501, 0.060094349957521886, 0.027887100060921044, 0.03566004839094897, 0.03302916073270383, 0.01535095505401372, 0.08806317053254574, 0.09484887093065247, 0.050467819335960576, 0.0270642469366712, 0.002120788253265463, 0.023435378454685695, 0.03214319920047157, 0.08782788960924072, 0.026996898232027892, 0.021646869586660497, 0.047965305031187115, 0.08090743434525306, 0.02984760907448588, 0.052358348132862206, 0.027744703467995412, 0.052308663500532995, 0.10407945666942867, 0.024958604481071237, 0.03397378161729824, 0.016517924340141397, 0.00688496767731023, 0.03979147246648227, 0.033863273434220784, 0.03802364031153341, 0.09613063561940387, 0.06376144048126955, 0.03016259187021323, 0.04430267313915876, 0.06372959803669684, 0.016061786971535656, 0.07663508456560873, 0.033325958516328566, 0.016980882764102954, 0.07241897330048584, 0.005811558794155116, 0.030562420818774454, 0.03947738790884614, 0.011668221972462152, 0.025273589192018397, 0.015828429886530486, 0.043863179988317916, 0.011514605064275525, 0.04041208029394189, 0.035977373500504804, 0.03432368844627373, 0.05130757044460024, 0.04469623165805975, 0.04116409518305333, 0.011915992044152753, 0.07365852654460939, 0.04547700548784868, 0.08003374171112815, 0.03973038844583977, 0.07815027624488839, 0.03973446403359694, 0.1028010244631479, 0.038424702661652724, 0.06358432861405515, 0.007397867851860582, 0.014012764159199453, 0.06102669811356933, 0.024362249082074534, 0.042317969153725335, 0.025594809858669198, 0.01568179491216377, 0.04525404708880571, 0.04820440490279467, 0.04900113634404637, 0.01797833690239537, 0.059299269435747023, 0.07476648120510002, 0.03886134213497562, 0.03892048795316969, 0.053809946853547334, 0.08618302222701811, 0.059562868799173066, 0.010629227674085527, 0.05465207666519189, 0.04231878503736469, 0.02972729113553801, 0.03626473308090241, 0.028969111153855923, 0.0725984370576278, 0.02538482515862392, 0.03854655660688877, 0.10111285779144495, 0.0291243837695689, 0.04987805803877212, 0.03700610317830597, 0.02987500054821853, 0.09270302801122589, 0.010137401141917274, 0.02294617385843829, 0.0349298287032833, 0.07970624678437749, 0.01571439291095181, 0.06908519614127374, 0.011692605593482093, 0.02901169032068743, 0.04022084559584337, 0.09549214729979154, 0.08075407886457059, 0.04241937238182272, 0.034002942754135984, 0.14176319142983806, 0.0297435934865667, 0.04024312726312107, 0.03087073481912094, 0.08839729978072067, 0.020376651758147825, 0.02012201370821605, 0.03787894545483493, 0.016905313936032115, 0.05227794337476935, 0.020202307383559888, 0.024826465805451718, 0.02063502640193028, 0.066929156591575, 0.034394850353560144, 0.028837654296489015, 0.028981849280816895, 0.01790420257396275, 0.032660929080579555, 0.020906593079768845, 0.05387374665588141, 0.03239955903301316, 0.07159144512467808, 0.01692410990325434, 0.08392315478094163, 0.08362590500544156, 0.00687456947015298, 0.019539716022629893, 0.014746871743080838, 0.038815476450948946, 0.027837003656332533, 0.010200946220016528, 0.07568198691813216, 0.050703678655648426, 0.10208159895433534, 0.017500303783303788, 0.025601905748067845, 0.02779181787533866, 0.03208406295837655, 0.029898393042986433, 0.026254593507356705, 0.020374215598548615, 0.07214780115792829, 0.021422576279409473, 0.014449621967580772, 0.06326425707929077, 0.048991904984558785, 0.045640588242320285, 0.03884121700520477, 0.027587375821425553, 0.039127802836798856, 0.044651407853610096, 0.02144849303388788, 0.02746266053779231, 0.021145654646980188, 0.01594837435761527, 0.01865438076727573, 0.01386597213680826, 0.04034931471030559, 0.03095442609440896, 0.04277073860829396, 0.03689019790580196, 0.09662531391387025, 0.13722773641347885, 0.04308217250171208, 0.05933775003218363, 0.06228782056320099, 0.05098305176943541, 0.03173631841256734, 0.02804848605826978, 0.056070143717431256, 0.022379153881282098, 0.02427543982893469, 0.06820296928767236, 0.01055867001864939, 0.02545895948705654, 0.0042404087012513515, 0.08822056329658917, 0.19706277326951105, 0.2010731975878439, 0.11771496370314591, 0.06781765004439701, 0.1187360899582986, 0.185976515734388, 0.1466827629314315, 0.11788109753040538, 0.11704400857730259, 0.15170430073574667, 0.2810130628847307, 0.08277589214905616, 0.12120375875383617, 0.24145436623404104, 0.07364970887260092, 0.13999423312564052, 0.17009764278848327, 0.18384622439982432, 0.2549626260635353, 0.15832261092239813, 0.1342221130166323, 0.14615964745321583, 0.13351550415879296, 0.1247672703597815, 0.1596205017619556, 0.16126454176922, 0.08539055023462543, 0.19345289036150903, 0.12438759718450809, 0.1503620993706488, 0.0844781624994451, 0.2171115547178253, 0.10941528970555914, 0.12087875361283942, 0.107996441243637, 0.22181764815843877, 0.14086663873205263, 0.20865284086715793, 0.10762597644521345, 0.14347483103554096, 0.06044741306874541, 0.16701789272408332, 0.16319408742410524, 0.09919067424151207, 0.1505458532201667, 0.09270872770538253, 0.16128652849264685, 0.16633222871009382, 0.2005290146917105, 0.2797963926869054, 0.12206944576915234, 0.23372510598311502, 0.07056581427253063, 0.22894378270833726, 0.1997592189018765, 0.16115799426071106, 0.17294012010097506, 0.1463041622792521, 0.24895602176266335, 0.18980194514076557, 0.1642735359529334, 0.17276496175796757, 0.09501191742357709, 0.12674606014643947, 0.1611598635152463, 0.10613883890572096, 0.1060560554446232, 0.1754178476309584, 0.22403173419016026, 0.17770727074915366, 0.12445246950993616, 0.15762269767301698, 0.1512960371591391, 0.1362223839086871, 0.12982461511367752, 0.10623262338941136, 0.29222592411022036, 0.10970318554750375, 0.1444407912992662, 0.3042535045214238, 0.1529297656229427, 0.1145683724673525, 0.16168207500971135, 0.13964989192543492, 0.192199248760458, 0.22630968131124976, 0.13292661237139858, 0.15948396957209035, 0.12792319254649262, 0.14777837591546197, 0.14147172561816632, 0.07297279358270668, 0.19554519905678688, 0.06778845443360268, 0.19542942784966963, 0.1517273906257845, 0.1059479374558695, 0.11482344910262093, 0.22082384825954515, 0.17024735169064614, 0.12672608057337423, 0.10302486003286417, 0.08756725883652126, 0.11104706464515579, 0.11900943779056111, 0.1190958065431445, 0.09920332235314193, 0.10117173164842591, 0.13442279740927682, 0.15933663554249272, 0.14341424880248888, 0.20821399506061308, 0.15571172198941632, 0.11432704711032492, 0.1553156851760803, 0.11266118125809778, 0.0831478584798113, 0.08104482455359352, 0.14387322739968378, 0.24797202778920052, 0.2384329920694713, 0.07267379712673926, 0.21098651322385958, 0.1353907495016052, 0.145435985478182, 0.12118099828160579, 0.1478553217865767, 0.12973931888418813, 0.19885616977849316, 0.08534921979111049, 0.1327934969336756, 0.1711826531156417, 0.24001510152893685, 0.1089710199965104, 0.1336048146890056, 0.09783769401931956, 0.2115800781475921, 0.16618835739791396, 0.094356146160393, 0.1117299171164632, 0.23528625527697228, 0.1835322509249372, 0.12480683880107057, 0.23089090242020546, 0.1461478650209404, 0.21996080424756775, 0.06840374561086779, 0.13937112785154773, 0.17790594799143655, 0.09984256909979929, 0.12628109074167668, 0.13014569788450195, 0.12218357754811165, 0.10392590966676513, 0.12022934087942685, 0.074110901463897, 0.23460069851529217, 0.1239695200215905, 0.15211496982843647, 0.1092138315641111, 0.2682478010894791, 0.22764319523928628, 0.1358544165568967, 0.13535197013087813, 0.1176078646113315, 0.1639627340820528, 0.0874302976374184, 0.12257361589300057, 0.13154112703857884, 0.13752680181735946, 0.24975312092611868, 0.2311846052086161, 0.11888963696096214, 0.13747979466232563, 0.09923900672865492]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.05176845660072662, 0.011414605692299384, 0.05748974677595881, 0.04025039743752249, 0.014999115768249237, 0.04943538179260589, 0.04105367510008716, 0.04440720583642683, 0.015388223316310155, 0.032427751068626685, 0.02853650513345436, 0.01733486709605542, 0.029502174283768383, 0.05449942981583938, 0.01954786911336405, 0.05874690472058231, 0.03390645398007285, 0.016918615137617436, 0.02563591813668609, 0.027251563095037016, 0.023960334459139455, 0.020517705781986157, 0.04752005472959531, 0.021445124162240856, 0.026456036327046253, 0.0886975143164877, 0.019967702532848044, 0.056755934135928277, 0.055375616066157825, 0.04480299367118747, 0.020105833931255247, 0.014479982989629912, 0.05767575292397411, 0.009626198330924157, 0.05278867121124941, 0.024714557596692638, 0.012311034858407033, 0.03442778830386458, 0.04894397469357618, 0.05046670850847037, 0.034229172348615625, 0.06847031865148775, 0.012957462721744613, 0.1318863569007766, 0.015297026294583996, 0.05197320892024906, 0.0599407569895829, 0.015330762891549499, 0.054287043430151484, 0.11445937347748589, 0.026695138113873623, 0.01361764569376265, 0.047673015674996766, 0.09937517119631653, 0.013433500181793446, 0.10766056531499471, 0.026956511991879633, 0.03357405992104642, 0.02217499144946135, 0.027046739912381577, 0.03326395902061655, 0.042291719150999864, 0.010314843384549022, 0.04893700712390485, 0.030700852906691934, 0.015704447174474837, 0.03158762649212393, 0.05602027522400022, 0.021075777852186756, 0.04296667708624755, 0.017091019394537135, 0.01709381178502114, 0.06524891126900911, 0.07631351915939201, 0.027773933552746332, 0.025851031795384425, 0.0740392415994598, 0.0012251343920774338, 0.06116721779108048, 0.012051830924446545, 0.03435894764298874, 0.02473947269121005, 0.03846968351412685, 0.02326265818649723, 0.018016143341458613, 0.0324261078100291, 0.03851029000455334, 0.05855105434274001, 0.10173617757015652, 0.025325187128938498, 0.015238710724177863, 0.034041741277061166, 0.09150933279024978, 0.016699674869737318, 0.1014509630359469, 0.011637305536667907, 0.032558729121040915, 0.013343138195904753, 0.02919846638706663, 0.027056097676376664, 0.06952715992567039, 0.029909625807176196, 0.04167693359176478, 0.03161300698505535, 0.03158375583288651, 0.04759146561545711, 0.02125251625153807, 0.07922404806219763, 0.041266275990393855, 0.05022596537826523, 0.09654588591788085, 0.0804433995677579, 0.09465577080845834, 0.03287963186120314, 0.10231791409633814, 0.05549011556732078, 0.022519319243128263, 0.019749306187394167, 0.0470374193372986, 0.0622479112127856, 0.045890915132458174, 0.12127085273424465, 0.01761449876451685, 0.030939085183725245, 0.08660742727619025, 0.054808335619107376, 0.04025479861264748, 0.015108673044690683, 0.05124939755807, 0.06669123266493121, 0.03778706086919673, 0.059143887652504834, 0.031148200373976465, 0.12096314585857815, 0.015855102195224215, 0.0739533861257857, 0.05251507823085112, 0.07626502579378505, 0.023337303878619306, 0.049922426020906824, 0.02137436062067507, 0.028794142417609695, 0.017330843219233137, 0.025255756580360958, 0.017781310579589298, 0.02367900782114556, 0.038250436811077024, 0.024193449268838572, 0.0489572050320285, 0.05341546519869759, 0.06514181217719471, 0.0407757192489601, 0.03470420431826384, 0.08422107105293582, 0.04847542382776738, 0.10294734725668546, 0.04010307489924374, 0.029109941096976403, 0.04707944309038501, 0.03608238883316517, 0.017708486261507197, 0.020929024134191777, 0.020668854929446694, 0.031924982885679895, 0.06459890864789486, 0.015317602458620265, 0.040630181695544915, 0.05895860545757798, 0.0485382123940414, 0.062277328989077965, 0.06468409762507485, 0.025702701851485238, 0.04200438255323999, 0.09382294896509379, 0.05135313735433644, 0.041635534200336666, 0.03749972427143686, 0.04627346496788725, 0.002858812461659733, 0.08971308643418936, 0.036728181801135504, 0.07599309522418246, 0.004332177894895956, 0.03565431805327535, 0.021041671617797787, 0.03984483815128765, 0.044113261730320034, 0.028555199594026612, 0.035571465644264416, 0.02734198253752003, 0.03145776692807915, 0.03704076865687966, 0.02264970357740118, 0.02954783503927531, 0.01309153576937294, 0.06807170778272614, 0.013836803339091281, 0.03581831832566569, 0.033375263935135256, 0.007518362948640942, 0.043597060195620985, 0.07730483693341095, 0.02357379139040507, 0.011938878920890633, 0.040147822094900955, 0.02857220866116545, 0.012260022021139102, 0.03533685121745352, 0.04229632333942479, 0.03275903813060253, 0.05018031036841774, 0.03348044780713897, 0.03066992593718873, 0.0075099268841797556, 0.056086763994948524, 0.043668865616763794, 0.03352707191821068, 0.041465194550372904, 0.0372855912052816, 0.06050109668003936, 0.061849292683144735, 0.027773397291199337, 0.07412923394792503, 0.06910349032090557, 0.020220501971761548, 0.05945342547831036, 0.08348154339699015, 0.05866067003338568, 0.02988234733141238, 0.04171711107295367, 0.06771805861424054, 0.041099023674764944, 0.021460501462100975, 0.04323134514232797, 0.03686677476751708, 0.06698049980426027, 0.012939147474694879, 0.040964908492300785, 0.048529126591259436, 0.08754751675071255, 0.023410903860724742, 0.03987572298595502, 0.06070553107307323, 0.13599592831826982, 0.03814633312304655, 0.024303371394653956, 0.03649397340092448, 0.024060818381727706, 0.04779075955851905, 0.021557854000298728, 0.0670240825462726, 0.03736965786365252, 0.05450492649669609, 0.05546432138691026, 0.1066299855348564, 0.04903592056624832, 0.034300456829969926, 0.021386587383946585, 0.05050726520318178, 0.010336600281598588, 0.017376413959408962, 0.028530115960165862, 0.02017189560818576, 0.08819026451918387, 0.06526812475415007, 0.018108801675900336, 0.058198883723948276, 0.03851580583760816, 0.018824030938107642, 0.029384972407452525, 0.06483569110353148, 0.0337458168336701, 0.012037869929636439, 0.07497908592584633, 0.06533288982726874, 0.044294847551012234, 0.05470735756980796, 0.027630073731885325, 0.005499986047300721, 0.03990207641055027, 0.06562309159386544, 0.0268207190768613, 0.057446711786812356, 0.12575953808282653, 0.019664088481917016, 0.02883630789696209, 0.03869687454895147, 0.06561400579108347, 0.03451046834309255, 0.04518447481396218, 0.05191621197868259, 0.10327742389974096, 0.02370027825236321, 0.03814804532955732, 0.02290755728139512, 0.04772063570037004, 0.04157751070095166, 0.03117880941699109, 0.020131336998254545, 0.03332775882295063, 0.029581140711783405, 0.03433047981572247, 0.05139893409044993, 0.014436213513686052, 0.028397734051630385, 0.046183284927880576, 0.023092353010490056, 0.03596687426550254, 0.004253311058311093, 0.05640327705130462, 0.04469088053390865, 0.04455585370681459, 0.06240528482463091, 0.02206293959921647, 0.07134222140115115, 0.09168603863086432, 0.06253389949579874, 0.03523236831590053, 0.032214663712488066, 0.04823417507953221, 0.008037364534703235, 0.024598640832869757, 0.036738006878764405, 0.03925616852939129, 0.035836815518597444, 0.06110008167583616, 0.12574633838789118, 0.014121920197090555, 0.04946683736277684, 0.1484723596443092, 0.06780931500778084, 0.046426295678341584, 0.03038292833333535, 0.01842884831280718, 0.03610534465781624, 0.03133879155821858, 0.004814322033311211, 0.03605829919838617, 0.07968696435132334, 0.07407745406512292, 0.09266840849792765, 0.053296338526471976, 0.04991758817566499, 0.015501795851084736, 0.03324596744571482, 0.04632771548424517, 0.051190899084171945, 0.025537169403246334, 0.02125417291667433, 0.04840302085804363, 0.03558639286746902, 0.012186423954253477, 0.11412978713070193, 0.11161214641986356, 0.1567543063673281, 0.197383840718577, 0.11620795384289757, 0.1936744736327279, 0.15992836185520695, 0.14080115353628514, 0.11082898239575087, 0.12647355501089366, 0.123598741127118, 0.1300666529324747, 0.11037988633277918, 0.1069866760724014, 0.17952171935429498, 0.20030524040902817, 0.28485962099605994, 0.1183681915544214, 0.11189128587683363, 0.11600223625259054, 0.15701705920359782, 0.11470442968270472, 0.08365452605029268, 0.0653334184279365, 0.2551705576479435, 0.2292876182905128, 0.08373623698829644, 0.07579038835941784, 0.12469888935166022, 0.15465461258446017, 0.1105427029993265, 0.12561739812935555, 0.1702633016412297, 0.2110105837064405, 0.1355757750570774, 0.16831348529986798, 0.16378084948707014, 0.10138012288558869, 0.16703128394099975, 0.08474605578568675, 0.11566065296891237, 0.1839686912153998, 0.16854711147325654, 0.19808738522471922, 0.12860391529337054, 0.11089487361811823, 0.1297281799657691, 0.0955468689602229, 0.13212733751823827, 0.14606912650408285, 0.15542566475848998, 0.23350045836019903, 0.11240405150719228, 0.28659689390370924, 0.1190464091937869, 0.2288199216127396, 0.08528609414614978, 0.09613003807082292, 0.13620393651147045, 0.12472965544269932, 0.11159319340461686, 0.09892269668559875, 0.10867470484827796, 0.10760482475762406, 0.06966918496595276, 0.17563478840935617, 0.07856876709528508, 0.18927473875303424, 0.11865109250309969, 0.14395837041158832, 0.1353321897406732, 0.13462792511188215, 0.17965875716219026, 0.13308557561568676, 0.1470624514284634, 0.12000742052952129, 0.18079697995656924, 0.09758397335967711, 0.23553094375998745, 0.11371285143879153, 0.13388180143890843, 0.1022392292056353, 0.1174888834958115, 0.15732940857208547, 0.09558538786105572, 0.11459679432934332, 0.1270349442418064, 0.1187368407244644, 0.18815903894362912, 0.11514254770572148, 0.17298749497821256, 0.1275364790231951, 0.15038580213102604, 0.15012580721128374, 0.1780017089819716, 0.09033229998162678, 0.12465827903079411, 0.17513620306647595, 0.1418763272944958, 0.15599670669724866, 0.13981541288235497, 0.1439630895132019, 0.20994939871372717, 0.24946972968116884, 0.16111368373517068, 0.14581351360726744, 0.11981640416648119, 0.20100071034844846, 0.11318743003592377, 0.15174288092361343, 0.20241264103641435, 0.14227884521167125, 0.16845957826702826, 0.12455671875467225, 0.12138349830263084, 0.15220783500661775, 0.11683527260057389, 0.25402809072646404, 0.0731033196432456, 0.15195153263067046, 0.2054785249093848, 0.2458621143934227, 0.11836763231023667, 0.1156631274329078, 0.1976234883430504, 0.11333147754832623, 0.10991094859256861, 0.06647960087584873, 0.09046808906620549, 0.16615166178634092, 0.12406069980633837, 0.1270547246320113, 0.12280679773539306, 0.20774461298940644, 0.1301086192289668, 0.14287628654030063, 0.14684894272396642, 0.07986361656578318, 0.3196098901812108, 0.22177286265838533, 0.12809589940814242, 0.11195217454505545, 0.1743262183041342, 0.1355492684148973, 0.16337600266260488, 0.1278100413600764, 0.1192443892960587, 0.23581919200237722, 0.19608696111507956, 0.2194365856027411, 0.14970507172326888, 0.09441997660624404, 0.15756908684007584, 0.24746072538677724, 0.19387782401134893, 0.30467540446308355, 0.13839585195866325, 0.09097803549300279, 0.17155316387934072, 0.1849299936645454, 0.09312306635922964, 0.2613425296881507, 0.1767700387825889, 0.17872638219306547, 0.15204611384580213, 0.10486957677189382, 0.18572468731191852, 0.15355129275591145, 0.14733306432683624, 0.09970357010681784, 0.1622177696516437, 0.11679557392433768, 0.14919884082290436, 0.12157665205097969, 0.19819428513367332, 0.16555198348097264], [0.008946561513678923, 0.04380135669282848, 0.07905314916804915, 0.06427921249621338, 0.03797098708849761, 0.01384015688897982, 0.023697985734249798, 0.07092343177646399, 0.012448465286363519, 0.008201266173273325, 0.05222176997772148, 0.019455406131343018, 0.08557974330840573, 0.036430740503654364, 0.04759507005914085, 0.047350576928546356, 0.029663351522157752, 0.001926955679194972, 0.019731475490956538, 0.04097644577644045, 0.10905201081186534, 0.0730671679540988, 0.03704525027123671, 0.0228821748732439, 0.02359149568233519, 0.06610905946863276, 0.012261407682672145, 0.08413074928666316, 0.07789058009943656, 0.0519216895073412, 0.039655078172443375, 0.05876351350678071, 0.044845258741970026, 0.057872913312166936, 0.015036563103597973, 0.09561312024391468, 0.056173600061165715, 0.07189218060023363, 0.04816329662477778, 0.02809071473987593, 0.010865333099519054, 0.07330696879615707, 0.04563814059140221, 0.014658067788508151, 0.05684955008027535, 0.09685196868714788, 0.029611874244085727, 0.04388407503645267, 0.06237452639447105, 0.02795490650309911, 0.02361864966881131, 0.025354436365887526, 0.05919617315333697, 0.04032914361525928, 0.021883835903398936, 0.042003574330479874, 0.03757754348278527, 0.04878382401300534, 0.04456778935667488, 0.029920517662239653, 0.024272856197410056, 0.021361153264860475, 0.04627433830812093, 0.031295756569072124, 0.022598155436196157, 0.04590303464342029, 0.00699910759595373, 0.07340702753994735, 0.08167673983881552, 0.05579750068605908, 0.03364329511720327, 0.05651417593922346, 0.012254307962833874, 0.07166549518343902, 0.053516837783278, 0.02203891125147141, 0.009455423926063364, 0.09447692758253506, 0.05363001578277158, 0.03276371509738026, 0.07334179515319486, 0.01759488882887508, 0.050514677103849194, 0.031095302002804897, 0.04702181412628101, 0.044132931037775935, 0.01797292257599052, 0.015364367338348062, 0.027408749015340884, 0.032562383360439734, 0.014552949033978005, 0.057424985533279765, 0.05428400972197133, 0.0270529720376456, 0.029635002438519752, 0.009107801954322045, 0.01471438482704182, 0.03301805628824138, 0.0783480801469376, 0.051016250189634106, 0.09090213150146509, 0.015135488994870216, 0.04557585764315821, 0.003754158810366907, 0.058237191950601924, 0.053356323210943135, 0.03864239803665588, 0.04099423816848186, 0.08177444669267825, 0.034257969593689326, 0.004132068546999607, 0.029788737132724737, 0.02051315521971593, 0.06254272482868645, 0.020853491695297342, 0.044440929026853655, 0.01708455552767602, 0.07281622053274224, 0.019325858748127377, 0.03959575998446634, 0.07996984997824316, 0.019649237867504842, 0.1830451262574042, 0.027479079717229453, 0.026771697110586593, 0.015109837498335589, 0.03504374597762381, 0.025151055343749545, 0.016323745949193835, 0.04957996556655534, 0.030921298537343263, 0.02920332529972638, 0.07282273228009863, 0.052261058796918204, 0.061028575028983824, 0.018662966697687106, 0.06125658960832704, 0.02812936387565588, 0.016372721950193087, 0.008557038362919083, 0.022708472097292546, 0.012666340692028885, 0.025117592623216972, 0.06963328608582098, 0.05288548174224073, 0.015783423178588912, 0.024812258704895937, 0.04669617313230711, 0.048302762931393045, 0.03764157694193625, 0.019875017385328972, 0.04334618555261724, 0.020205605392073913, 0.03693978677714064, 0.04478978631537288, 0.033648925863446734, 0.026040479593399554, 0.04602973409477742, 0.02860675348089107, 0.04592290313373651, 0.09119674593450562, 0.033350634208369645, 0.04853804002425844, 0.012274938710634748, 0.0720497265818619, 0.08687709788641623, 0.04169737281758459, 0.024219863980467764, 0.014060158188635064, 0.03179671678451761, 0.04228919106084974, 0.06921738461260835, 0.02466346527780256, 0.01674966593723624, 0.06708249675049897, 0.040177588441198876, 0.041935534231484904, 0.03800462217881315, 0.022034339621783267, 0.06481238670887486, 0.0656971799570226, 0.055417333384074514, 0.03413181789519806, 0.08671681697089827, 0.04680151022189567, 0.016440009367802454, 0.043146669444057255, 0.059934268224864244, 0.044025797472004934, 0.04345233086496592, 0.020390410697267904, 0.012822906081114086, 0.03971053910772166, 0.04896613378678599, 0.045514432713389404, 0.05362626578238222, 0.03522705166570602, 0.05670796171010983, 0.042852932181690014, 0.043430765489897424, 0.005897242376851219, 0.04336055736207674, 0.005901225555252525, 0.03576176571509531, 0.016039959211353094, 0.0313507501907166, 0.03951088127289568, 0.021577977214849765, 0.08697185530177048, 0.016068843598928184, 0.03644828774756001, 0.018031984124512925, 0.05048676852076765, 0.035471851231470224, 0.0300162939745332, 0.04815755096534568, 0.03506371022893056, 0.026928490410829266, 0.08093147418431698, 0.015868821872338172, 0.008244993514381349, 0.039119854674584446, 0.04316589059007745, 0.07031910331739534, 0.04494941988659482, 0.03210566663784126, 0.012323135217171044, 0.050683231768949386, 0.033507383458556673, 0.046845165742260796, 0.0086197531932304, 0.011361075298590286, 0.04299080502542277, 0.08075319020257843, 0.036773438445262374, 0.02933207595150077, 0.11264696266622314, 0.07591058755473745, 0.004424353593945383, 0.05347195269179441, 0.01423657100061856, 0.01848513662304369, 0.03484324161564151, 0.02009279128434437, 0.027597292829605363, 0.04828088346027559, 0.029451980202969526, 0.01883954421857432, 0.05198385754239656, 0.04460690963652827, 0.049687968642120404, 0.03833917660578605, 0.023186445844569997, 0.06655937361140406, 0.02335495645961454, 0.026015627701135895, 0.07592425456330662, 0.03473235421904153, 0.04172906970545169, 0.02180485606884524, 0.006483422212993667, 0.02417298131472161, 0.04590590364269672, 0.03299847125045715, 0.03338346490636468, 0.093326301824662, 0.010446101059055617, 0.05448118160148302, 0.034379425173204754, 0.027073960931551073, 0.03960285395864518, 0.04684823392439754, 0.023157650514716105, 0.057998406175043316, 0.03511852765035245, 0.04472142062901009, 0.017816043090856364, 0.1032701307427018, 0.00858706039106173, 0.011340964532968019, 0.02664817500889542, 0.04422622905563443, 0.08304335642606021, 0.03675365422461783, 0.03607311916928138, 0.013312313690661423, 0.051169146017562, 0.02684317502914177, 0.014236924358673636, 0.019047090843800577, 0.07775932625536958, 0.007129379889867719, 0.01806780639585228, 0.06830016286262582, 0.027162551339114868, 0.043284385239765535, 0.06252814234504778, 0.010132845791597522, 0.012338497195272677, 0.05743161985470403, 0.0921545320400788, 0.03355122284002362, 0.049661347086751656, 0.04825942150707688, 0.016847483873847994, 0.02498901625644536, 0.033552800981147636, 0.03639745015290476, 0.05631596218013475, 0.09839955822474535, 0.02609048023699753, 0.06968354911453302, 0.024380196606920614, 0.04068833542987704, 0.059367049064847736, 0.07810699993804579, 0.02453311350226643, 0.041852287287192966, 0.06301986354012644, 0.024473008158947193, 0.05601828339539709, 0.0333619914618471, 0.026688852362454902, 0.04660164554333014, 0.04358032117447546, 0.04526541200316241, 0.03311531498066841, 0.11545443742145454, 0.02093630388469225, 0.08999081628937876, 0.04757263134383867, 0.011249671750251326, 0.017849306628528624, 0.00811777982650505, 0.08649440632472116, 0.031123243144623218, 0.1032963156279537, 0.01705423759807262, 0.024791061052031098, 0.06822543098561226, 0.042720739879915794, 0.03679371679261808, 0.05558684565908006, 0.06383279008009742, 0.08400327991694213, 0.012552234768537025, 0.028183920827183514, 0.036593342665582895, 0.034535201491727945, 0.055338686797767885, 0.14048897270714084, 0.042551419126891324, 0.15813026156636978, 0.09829888661061564, 0.16163892893781587, 0.31253243285802107, 0.15134086862446802, 0.1324258513388134, 0.11797116648766304, 0.21696259658182823, 0.16188306583752557, 0.13622063722821975, 0.1503955314476644, 0.07618948186357176, 0.19225083712127902, 0.1278331082674765, 0.13863419723366538, 0.14235462662914108, 0.1861691255603106, 0.09331261949433435, 0.1650643838389266, 0.1201118000092045, 0.2461368028795527, 0.1639855175369209, 0.10023782450345256, 0.08576741952809595, 0.11813199132560723, 0.1864276342694798, 0.14335472377077227, 0.18679489682037986, 0.1452296320348978, 0.10529663248528397, 0.14636564849605485, 0.16802496126582547, 0.15689609392035395, 0.11783337025272271, 0.16632708059924264, 0.1726062896270906, 0.12906151493230175, 0.1503486621884569, 0.14433585257539827, 0.1584317631298496, 0.09181188389418588, 0.10263500554907708, 0.15762429113589949, 0.0937828978884124, 0.17414252574165023, 0.1494697601564469, 0.12929236786740442, 0.12268379465827059, 0.11804612053017463, 0.20184630287751076, 0.14814775286903306, 0.12952944143645226, 0.11278619148558187, 0.196756721143761, 0.14891549554322997, 0.10983073918689644, 0.17794255167245868, 0.13188021287562388, 0.15695594070899874, 0.08343884165609076, 0.2036883153261677, 0.13868600009910523, 0.08639845381220503, 0.1511402761623744, 0.1751559528131639, 0.16264840299564023, 0.11561270352573165, 0.16476358707633712, 0.19160880947545653, 0.14605784968983743, 0.10553253393980766, 0.15606887217971588, 0.09850407560025493, 0.2251061878257221, 0.2758024699024616, 0.14117097482085228, 0.09254080123238026, 0.1745060344617213, 0.08755448048994427, 0.15498914785923498, 0.20621516441385593, 0.11195854073570621, 0.16060201361054377, 0.12252069453919127, 0.11431698837587911, 0.13316152557249994, 0.2688790575390862, 0.10402434430415593, 0.12108700695417582, 0.16402567586591169, 0.084127715578483, 0.15429778415108883, 0.14634465768692956, 0.2549572021610314, 0.18841920240271479, 0.07877160419499682, 0.07910675234011105, 0.18275540712619984, 0.169277576309058, 0.15601002130537264, 0.18435700586245907, 0.3412939169474187, 0.1451209394802009, 0.11860883509319638, 0.1722689657922714, 0.15661362198091325, 0.16461867388458024, 0.19006558663902745, 0.1615629943027612, 0.10334123902383352, 0.15040964278722965, 0.17394389446464278, 0.09228934819299368, 0.20270599142437984, 0.2207625765473612, 0.10132332512688252, 0.15565984251518405, 0.3488574110932889, 0.10166290892107833, 0.1695053955359805, 0.11627690941696206, 0.10848244742280054, 0.19308002004700323, 0.165784782279403, 0.20281685966878168, 0.1403189931185015, 0.14314571966327008, 0.14742920836133344, 0.08462505219804664, 0.05915272830715103, 0.07731911681231952, 0.17149425171796354, 0.15819386218584355, 0.22949686754615078, 0.14854109305287563, 0.1409137224958789, 0.14658177722125285, 0.16908734135570067, 0.11107221531170992, 0.1357321182806646, 0.15015812079992988, 0.14815539842651737, 0.09218471590429546, 0.13886111247683727, 0.20237285042962722, 0.10988539189941461, 0.15725019508071486, 0.12026004568343202, 0.12229753312684837, 0.12939510025805043, 0.09074801759373757, 0.12466230099239659, 0.15291383099411765, 0.12129804119467737, 0.1711374232845922, 0.13605571381988066, 0.08888676867730196, 0.08608856358595433, 0.1720185316498241, 0.13296637233466874, 0.2288436243731168, 0.08469717937611765, 0.11933697868258723, 0.11779145758238532, 0.15833054759329365, 0.2781577306168695, 0.25039424458819054, 0.17879047310881077, 0.16288527738182776, 0.0897899786791494, 0.16390612018444847, 0.19197096988078088, 0.09714470620477393, 0.09923264053800415, 0.2274743034954994, 0.12491052114074269], [0.01833108208713032, 0.04576952083997669, 0.01932485900338619, 0.024090586643245433, 0.027386442450205647, 0.05172479724992187, 0.04068801750338847, 0.055592097191801, 0.012363666056415007, 0.053074517767996564, 0.035433232739207246, 0.13530252681624505, 0.01776585092527732, 0.02433183922192022, 0.02275365979350623, 0.09887539075627443, 0.023436121559972246, 0.047443200789031484, 0.012543450612875243, 0.04042274423784787, 0.02049648897692321, 0.021278013572877934, 0.00950821312970572, 0.044795597092278545, 0.03474283047140606, 0.05284518551742358, 0.023504874120736798, 0.06904091625925034, 0.14071933534597197, 0.020229206645801183, 0.0365971731052043, 0.03256857718130754, 0.05782350830193009, 0.01121219568660543, 0.12440999759541405, 0.024317383142789046, 0.09990787043446496, 0.029140573122628757, 0.06315808495386474, 0.04350813653981013, 0.04574315209362296, 0.03318348531461051, 0.034648770196062904, 0.024298828493262974, 0.04984995793370951, 0.010189231778044375, 0.10460356040106666, 0.037962602256166364, 0.018482348062999306, 0.029775263561356454, 0.0469543754063066, 0.07580214780905555, 0.020868133550750154, 0.018489221786899913, 0.08853013176591167, 0.03582055147196497, 0.022559199865246495, 0.06496798682717547, 0.035391408168981155, 0.01584253739565611, 0.037660028169592547, 0.02384721008580058, 0.01656815481011666, 0.08785447286021325, 0.012092151089511331, 0.04239285424832375, 0.010458981869892489, 0.06147172624966311, 0.04398396907133922, 0.020622284444529685, 0.03977600898173067, 0.025999899916050416, 0.04769968319564097, 0.045560589510827296, 0.025672533309027076, 0.031084921511430896, 0.08324602498642861, 0.024817828164105455, 0.08995372997296434, 0.03555464235344722, 0.02270184352152771, 0.054435472965480826, 0.0297410519898779, 0.07862660673356826, 0.03663391851249241, 0.03589362476862246, 0.059139980604091, 0.10902583358749267, 0.027811253525977655, 0.041811014300272356, 0.0433952343319693, 0.035658646450047536, 0.03850634082130367, 0.036822203772082444, 0.05463947451883747, 0.03890323182267528, 0.04720609274602706, 0.014400184398607142, 0.026024286409900076, 0.033459974107362574, 0.05243994415767732, 0.04976924291000732, 0.07065693277024454, 0.04449197729568809, 0.06488549447948895, 0.03298328738779791, 0.08374800409881339, 0.03290037752219266, 0.1207416391961517, 0.014504730502413887, 0.020066246337768052, 0.027435824477804766, 0.017384643658935543, 0.048779074267874804, 0.0354605361128286, 0.015660410525367385, 0.023963437115232793, 0.028881474525757858, 0.02901477765502228, 0.031696640803749045, 0.013732508129079737, 0.04022019825154736, 0.05730516172104305, 0.010847219908159348, 0.07377096526925603, 0.04041283872098692, 0.016440978469026667, 0.01571164552813336, 0.04430589836931998, 0.009964955707771644, 0.09583840371980783, 0.024044514115479206, 0.031056612647408922, 0.009270930801698518, 0.04938634067413308, 0.10925140051591782, 0.1295337774941037, 0.02968901738284096, 0.043866500979469675, 0.029466396062484676, 0.06039529993769623, 0.037077644299114906, 0.037165920610629746, 0.04878149127527591, 0.03641772466982084, 0.043071814992975806, 0.01770244948866387, 0.05749549243539091, 0.05099427878796574, 0.09373013741306721, 0.0414403886233847, 0.018287980065290487, 0.0591621013929046, 0.06477453430453617, 0.029454960284994978, 0.0613883069355882, 0.04080110740277075, 0.03611843327000257, 0.028267713609121503, 0.02168254821651405, 0.06185976510506965, 0.029512399642337716, 0.05499502358537528, 0.034241387620568275, 0.031584684714494694, 0.015243725727252183, 0.0515745367644535, 0.017411954693436142, 0.06363218995712458, 0.03197481882037415, 0.02150604730441926, 0.033913230027763114, 0.030988970914134578, 0.15033988282084465, 0.07867118538988215, 0.011375733433411488, 0.03231993568460307, 0.03163604516415827, 0.08308798870852879, 0.05352863553731192, 0.02889716209122731, 0.08037601447393818, 0.02300550353773419, 0.05397931357184726, 0.005158994087739097, 0.014479506099897047, 0.03769539078817733, 0.11951840362481533, 0.0694050838149363, 0.09010333162281783, 0.08620770557993844, 0.022117155641617797, 0.04482864612533201, 0.03685983784136273, 0.022091593202804367, 0.03042852014092909, 0.017485265477350163, 0.02064540497808447, 0.0518539673348348, 0.049699115221418684, 0.024538893635655125, 0.06946125338154455, 0.022899442495057182, 0.07142312028595517, 0.057221041436517434, 0.023978180477335572, 0.06073866054535874, 0.04218077429780557, 0.042751479157877546, 0.027687346465104533, 0.09688252027356818, 0.04023877588371116, 0.032157241592123624, 0.013661887271389847, 0.04995950850688162, 0.03528425545101205, 0.05165731256467201, 0.0344073529084844, 0.02621052429951247, 0.05099239038123239, 0.040775267257084774, 0.019859264702385953, 0.023012536224879088, 0.041738963730993776, 0.025722844218234384, 0.007501403677217182, 0.05169368258887722, 0.01831054901553979, 0.015738063112592265, 0.0742125383488113, 0.0867920621268211, 0.015875719536486414, 0.04192413484317161, 0.019574624734119545, 0.05452533507899893, 0.06145131766736027, 0.015676403568396648, 0.03529040330660439, 0.0706476018193268, 0.0642124785771293, 0.02218705733426877, 0.03931221169149203, 0.03178326428056725, 0.0536675502606217, 0.025807418409855138, 0.03403325685329976, 0.03582294549672835, 0.09720174145073661, 0.04801043527080648, 0.060462527983491464, 0.04659110417349204, 0.034798283745805104, 0.03642733907327056, 0.057190037858221805, 0.11637439410532675, 0.0671790391507168, 0.022856177679533442, 0.05609443253507057, 0.05258219902433696, 0.03116289010992454, 0.05221272630977535, 0.013114530856030123, 0.07968159407497415, 0.06618938378749356, 0.03775852792445691, 0.046302917218136216, 0.05038544956234194, 0.028721245321174784, 0.07916218646231198, 0.013646385482242031, 0.0512776930155533, 0.08128502376137242, 0.09316714705839273, 0.05635633884418396, 0.023560036281724612, 0.04441682023987655, 0.020350667970976042, 0.006868157314226753, 0.04474231567714484, 0.049432129749367316, 0.027988570321711804, 0.030257404826941992, 0.015463089258710464, 0.01874505876443319, 0.04851113118591809, 0.013133418753803259, 0.012791679379710508, 0.07512602925060258, 0.05763925649526139, 0.035517104045157476, 0.02448515448298666, 0.05186459297434457, 0.08522657677531244, 0.01492491057668362, 0.027506187738430117, 0.04589879051631978, 0.017511444616942637, 0.03357802059561495, 0.08291028695361269, 0.04421992032157798, 0.021569416182295933, 0.03809581345487987, 0.010243496658550877, 0.023563460694746147, 0.029471322007837798, 0.02972871222863755, 0.035568627288504955, 0.053859129698286136, 0.04842865032955043, 0.03858861483393177, 0.028926616256696083, 0.03419645273336961, 0.019056011937678825, 0.021937915965193705, 0.05547921030571865, 0.005627404663696765, 0.08889652097657805, 0.02399710476428511, 0.013093877125591522, 0.012672238611435939, 0.0327455205091786, 0.04083691818279125, 0.055381032307782484, 0.012003997352064378, 0.049788448734269034, 0.0342440765891825, 0.009693596831282542, 0.03154493049688397, 0.021046007675449216, 0.0833050137565982, 0.00941046701383687, 0.06353052242869331, 0.040320475330396045, 0.09670347786478459, 0.05259456368343485, 0.04506920922487494, 0.04242946175978549, 0.029821205854175553, 0.07473339386765035, 0.0226770548315178, 0.03312335507343373, 0.048727639124638615, 0.008024147602789586, 0.04060433005854007, 0.06514355885766207, 0.07560006913638885, 0.02359862604569043, 0.018277517219464627, 0.1015797347551392, 0.08396668389679925, 0.07353952244645165, 0.019481129448620543, 0.09740342941856193, 0.12610664486043877, 0.2528558229847301, 0.11867465736765055, 0.15019179802508126, 0.13665799682419147, 0.07723885378049267, 0.1151037683349944, 0.1265158354034347, 0.16520925106540804, 0.10003925451347906, 0.3693610189422485, 0.09795903468564635, 0.1412966132404343, 0.11966653438585421, 0.15487765142273519, 0.12451807727977154, 0.19304102617165736, 0.1726553805412785, 0.15961694711398694, 0.08459211041730258, 0.1258704446316246, 0.1439386972736928, 0.11174096410433132, 0.18149145398168795, 0.15266031717821477, 0.10433248784993926, 0.2304554274005275, 0.251166200745971, 0.1118719498176248, 0.13082417599376173, 0.14666122053900074, 0.1265009273324282, 0.0779606924662667, 0.3104495317224534, 0.10284345041239455, 0.1728665909820026, 0.16135127824400702, 0.12637227052642455, 0.12047740014930887, 0.1505442750790427, 0.1693372852018764, 0.17788583052254495, 0.12088473675952804, 0.17740232179001456, 0.09743828641911668, 0.20448288639947293, 0.10918493472760725, 0.13535141854757263, 0.07405262515549699, 0.11400780295051875, 0.1358460202332466, 0.08050184441550125, 0.21592774969195166, 0.22243632544432917, 0.10832832585419379, 0.2027692549651669, 0.11020919428237023, 0.1210798976582385, 0.10374993160967866, 0.14688692536325226, 0.1617148176075951, 0.15682189064400812, 0.13904932495807448, 0.13881399806949402, 0.15634204381175582, 0.08206385938871293, 0.12452576880253131, 0.19938691549243467, 0.136196949789601, 0.18337906398359807, 0.24608126150504236, 0.1751528731397083, 0.18244711802371089, 0.14071977967696805, 0.09181245079924984, 0.15821033307621557, 0.16471915397672884, 0.21155321910496683, 0.16759901637992553, 0.1934381355080874, 0.13830056594264123, 0.13178163268152746, 0.25408804476741825, 0.15610935226563485, 0.06500025445054616, 0.12969566719426265, 0.1388808928670422, 0.2828242479553146, 0.09399645255818483, 0.11503487404796386, 0.09990798534765359, 0.21559224914639227, 0.16248910267266536, 0.09882512006668315, 0.1536596175884047, 0.1684471829644134, 0.12178107495269469, 0.09439571460168208, 0.16040402584739272, 0.2598595979713625, 0.0841719571561102, 0.1404073690214465, 0.16774765275899442, 0.11963809720210491, 0.16193385746690536, 0.15772132383238885, 0.06943028810764514, 0.39246690489592095, 0.07632810547347031, 0.10405442091606318, 0.1712336745713988, 0.10884878300731221, 0.22902169385023657, 0.11208777976853233, 0.11223540491154117, 0.1490035190457298, 0.1965548569757131, 0.0936470934820752, 0.0978800280380153, 0.10038634596933281, 0.09562802065404193, 0.11956146542703915, 0.1272567420176441, 0.2106999963401787, 0.11310865321467001, 0.11698483594603117, 0.08729136759235014, 0.15906318811880005, 0.13232699535306425, 0.19757425953303615, 0.19357911100791347, 0.14520137871225036, 0.1087322686949084, 0.1328571741619418, 0.23738962628187674, 0.24985205352066026, 0.18103236813218365, 0.15540769233578638, 0.0659880635418719, 0.1359205759100376, 0.10961206704978982, 0.20220884632679725, 0.14176247130718925, 0.162714684922849, 0.24211638877468727, 0.1686259572424235, 0.09104332916678921, 0.21953842933139495, 0.13346485042523953, 0.13621358921931637, 0.16456484854702028, 0.1532962314424015, 0.18474381897718678, 0.16777797451903745, 0.1549675288580118, 0.05841402036528434, 0.21226226412240537, 0.21261837243312792, 0.14443846239197639, 0.11350970790391007, 0.08959752207081165, 0.208256712123271, 0.1644824328081262, 0.0902147361287667, 0.16888262734057444, 0.08565794556371628, 0.15840053738605592, 0.2012607665552247, 0.20240510273123943, 0.09387475183053363, 0.09905273244986612, 0.21683798472006477, 0.30183389242137637, 0.1345558975252413, 0.18697642901491734], [0.0324879962229921, 0.01802935261249302, 0.014779406539615125, 0.06831698615344302, 0.04024804937803457, 0.037694452330470085, 0.07209990534090227, 0.032985918899817813, 0.05459766527036986, 0.022026741944794214, 0.03847127314656973, 0.03872187582836036, 0.0182224603955664, 0.08314709239188703, 0.06475543573258385, 0.04093372105290333, 0.03632369886843428, 0.020377599791954124, 0.04514933436087543, 0.01862951929891302, 0.0917007475190105, 0.01866697142231128, 0.058183309156447656, 0.024772222949973038, 0.021161179418765733, 0.01070449485503618, 0.03267733868391764, 0.017902988324602766, 0.031428944785147905, 0.012045079774613823, 0.022305996314952933, 0.04173046015503426, 0.032042058357488246, 0.008406699353438473, 0.11704678947646772, 0.03950939123188296, 0.03890684009679864, 0.04994893266308693, 0.031575531879019354, 0.00957279912977209, 0.03411545808757505, 0.0757083403427274, 0.04023302639383943, 0.029011763099040237, 0.030383386070870107, 0.03625260590906105, 0.021723740764202613, 0.034917180591653434, 0.04004135502562408, 0.06066535359188434, 0.041673191252254674, 0.022384554801148274, 0.036282736147123004, 0.0038633809233414793, 0.07078828620574168, 0.034864600146970445, 0.06175479956812436, 0.11103814738171716, 0.1039354627831809, 0.04772078125707565, 0.02438990868658068, 0.03752447274183074, 0.025512292613125136, 0.036188763971891136, 0.032374213014038346, 0.06578995320465296, 0.036813922361620975, 0.07426397349204748, 0.00755888564820071, 0.01106571392982357, 0.035554343579156746, 0.07720558258194117, 0.010055450801437181, 0.05997983896504006, 0.07727251568388555, 0.03170862816454422, 0.0749014046103243, 0.0709366774366748, 0.022892714327862187, 0.029496939988025737, 0.019437914428811882, 0.05103426857761318, 0.07147470098589698, 0.0315964614011107, 0.029922434797270164, 0.058937675935486634, 0.03887870934821906, 0.04299679200255102, 0.03816924298242216, 0.09200313774448249, 0.0696717896648953, 0.09308241007308807, 0.012792033695375488, 0.046448006610115694, 0.093465791113915, 0.07728694111949976, 0.022719067093285344, 0.006288884718331599, 0.06062288550780185, 0.02824908618124262, 0.060839178941903584, 0.0643162834908693, 0.02243848547579781, 0.03174482198852686, 0.026704325423305555, 0.016710388609358383, 0.0046350785264474975, 0.02139343237955003, 0.06065215772738861, 0.011598741628169533, 0.11875013234995066, 0.03699798647674822, 0.04223256567192655, 0.019219318900497693, 0.020973597044846224, 0.07364565626748147, 0.029196097260160796, 0.015914184811164536, 0.05019631394515595, 0.037860126504974986, 0.055989137580317844, 0.06079586050022514, 0.009277582360101084, 0.029656198176164782, 0.03783862241694043, 0.013615798464255228, 0.022834359495449933, 0.03634475479503313, 0.046276188410458066, 0.04707729038331778, 0.047556570310506134, 0.03585148610234742, 0.056201650370513244, 0.023508361736012083, 0.07206398347813277, 0.05529148429031334, 0.06031273098121728, 0.008597678369692257, 0.07261511479173938, 0.03965370687505892, 0.12507886896210332, 0.09402286726981403, 0.06320621442770766, 0.04982574189442301, 0.02887805968883538, 0.03165019097768011, 0.06881685086315678, 0.009114640246656154, 0.015444362239401429, 0.04273886552020427, 0.030069280445816058, 0.07735790384392585, 0.051334843174704624, 0.022241759842502016, 0.02397378504787001, 0.021034547000101978, 0.026612006082770326, 0.03963553526949498, 0.016663944528948878, 0.05092568327522567, 0.0033157329157655763, 0.03263552177457079, 0.020970588234523614, 0.06329629487628419, 0.03740688207589331, 0.03326221234014919, 0.019355355048431985, 0.05568038116419508, 0.01505973439047774, 0.02886771750185759, 0.017861659796307647, 0.023589427244939634, 0.04205826534739426, 0.023822208806391687, 0.03601426063405891, 0.057436392582472295, 0.0266595897189672, 0.0204720392808198, 0.10020183369276986, 0.04670686005885082, 0.05757520005347268, 0.0521912758478955, 0.013136303074838174, 0.01681963849302021, 0.024747710051615874, 0.01612102567789055, 0.0193992059212178, 0.043032966674335545, 0.02419688325795916, 0.029013532762145324, 0.04382993943328339, 0.026687308695287477, 0.04775785225173158, 0.03394969964339849, 0.04714609273979741, 0.03144992410295433, 0.04442430108845715, 0.0404598688586585, 0.05421837896949822, 0.028297638918663708, 0.06730007338187388, 0.05875627780633588, 0.014265675638471881, 0.016883218045076056, 0.013432519589250368, 0.0922277317412438, 0.019125840851976987, 0.038301117357707797, 0.06781555096348447, 0.07428676460779483, 0.04678228524543586, 0.03447665322211481, 0.032392388450041894, 0.033124875757963426, 0.0311951155984594, 0.07442459914713137, 0.007445427069004866, 0.02212137678608058, 0.034528624626898, 0.1045695614189871, 0.07610314375450535, 0.023503529636429685, 0.051912538587085666, 0.035437009552673954, 0.017281223704377492, 0.05155434651720909, 0.06765563010929093, 0.03216620865127733, 0.039280706325606, 0.04459649084075805, 0.04571790949651792, 0.04129202803596854, 0.02379856158738896, 0.06345418942791801, 0.021331333292407856, 0.003437755879149923, 0.07688791656325902, 0.037739659178881876, 0.06046303743196111, 0.00920243296516879, 0.012820827110009569, 0.08152368313242352, 0.017164879846536828, 0.023967612294420123, 0.005506990484953408, 0.03858799813315272, 0.045469321625968145, 0.0370914951687859, 0.03339391051521225, 0.07094234648731447, 0.03325606448455684, 0.026925180910996376, 0.06992636068213372, 0.08900716705548187, 0.1402340186459403, 0.041977852928422155, 0.05275160787747272, 0.06034165463079849, 0.026511277012046308, 0.044216124355913176, 0.05899274616592354, 0.05086133572002573, 0.08911736114251037, 0.026933820467562448, 0.0030378311695981653, 0.04681319689318057, 0.0798499112528178, 0.04206202683910247, 0.0267656316094461, 0.02470820098214092, 0.05721932539956705, 0.033725837260604866, 0.06196854959031748, 0.0453803634962007, 0.07128234396898939, 0.05145155283952913, 0.04973377686955276, 0.07290163933629952, 0.009169496930084162, 0.043681532880591775, 0.03360476089461196, 0.017343765207295938, 0.05020461833825515, 0.07366016597276734, 0.06540535408402644, 0.07777362145603665, 0.08527313193847096, 0.0707572749665668, 0.06342480995602186, 0.048769540303657134, 0.020586856708471334, 0.06763657750261408, 0.06537034386588682, 0.0339857287584774, 0.02550549166757734, 0.03607640568647654, 0.08366760317116015, 0.024189446459434206, 0.0291601964648092, 0.012098107423122612, 0.062376974045389125, 0.05820301293786015, 0.03439689580831797, 0.05630223388453165, 0.038006667633570974, 0.009665219976957287, 0.007486565032928823, 0.018903273157775402, 0.0333712611257309, 0.09009157983405937, 0.05397851300996639, 0.04527336399581644, 0.04001915379757843, 0.04362113833908112, 0.010716645967125172, 0.054362598851683645, 0.07117798747194391, 0.08343821346399286, 0.06916068644533235, 0.015286678361946778, 0.03299775878868757, 0.034886081252367265, 0.07693123117449784, 0.06349417155668621, 0.04914548263073929, 0.07458854962380664, 0.006532019000470399, 0.03211305747109075, 0.049962454114950476, 0.033280062188784924, 0.016265469640793822, 0.022875337538519697, 0.04284690690016554, 0.020573386967542674, 0.026709699530094385, 0.02159041848274008, 0.05333823587505087, 0.056315452731665105, 0.08581094098307433, 0.06975599804953223, 0.011686588930446776, 0.03015124993849426, 0.025492460511985327, 0.03300173095457497, 0.10465941587162596, 0.06643503754129333, 0.017525837493820057, 0.028709989574347294, 0.05592745218065478, 0.040589448800610925, 0.02877298498436088, 0.110913481893799, 0.10104789353546598, 0.14357123553993242, 0.17469187207039327, 0.12416678000121348, 0.11763214193765195, 0.14249783910570607, 0.10156235222013728, 0.044615317451497244, 0.14494637868577434, 0.11060127808201699, 0.14891891229537227, 0.15819271305395713, 0.0788222119632748, 0.09344140653528514, 0.1144181962515558, 0.09390915683921307, 0.1624063498550846, 0.10231038345204246, 0.22309301601302242, 0.1352847229328848, 0.101870350209215, 0.08755115566835289, 0.18771820130848116, 0.10701890539137587, 0.11911774730129589, 0.1971924259898163, 0.07570582757433576, 0.07635668055304597, 0.10033025301151699, 0.19248427943356577, 0.11922790308392818, 0.1183016874617146, 0.10920479938748384, 0.10505046545257492, 0.19787951492734496, 0.21359754005266776, 0.20764039438818732, 0.09019653387968579, 0.15020711978356685, 0.17955625459792154, 0.1375300806736754, 0.14540365656777737, 0.14287763485504737, 0.23846541291042683, 0.198449085977289, 0.13563579038506554, 0.13192950297267209, 0.24482175167049133, 0.09169484864199355, 0.19275452460973494, 0.21906762233664914, 0.18921735876750564, 0.09600003295007253, 0.10082136899713548, 0.19600073025832254, 0.1813801567280485, 0.18039715866888725, 0.27907565716774235, 0.1440284214913845, 0.08562655128057926, 0.15498844305834464, 0.170196391521923, 0.18415800686324799, 0.10723067507628473, 0.06626362536823557, 0.21199990965185628, 0.15360962269046616, 0.15201191568086225, 0.1420775785922043, 0.07791876447417083, 0.23195683715804932, 0.12441239545061705, 0.1085411450795589, 0.15077951003707227, 0.14228474408868821, 0.19173535187878918, 0.3014915736932909, 0.17371526318452052, 0.22073231607435212, 0.09679360810907618, 0.18123879818426025, 0.22566272005919488, 0.19526465765891537, 0.24959187473981614, 0.12487636128019904, 0.12447392763269526, 0.19518910606782283, 0.0881152262070006, 0.10173774038952205, 0.18777676106941318, 0.27188638165112466, 0.15923610948506864, 0.08781295089471726, 0.13797068848244606, 0.19864301347444135, 0.1925423948635017, 0.13856069875820992, 0.11039841799966751, 0.2147164114660794, 0.09767739778204311, 0.12752594531423625, 0.14418268095581763, 0.16656331147157377, 0.160199296510508, 0.07832005665066742, 0.0675213425570438, 0.1134968989138161, 0.1276478375638685, 0.16992731079939874, 0.14864543422816262, 0.2531326105517726, 0.24079084216106325, 0.20323339699497148, 0.14088389103210744, 0.08389493210181113, 0.28649319624227865, 0.14638876902960962, 0.1228333656646071, 0.1296467294976596, 0.13488680154325502, 0.19666454544471157, 0.1600727234636584, 0.13593672504348142, 0.11879759149685984, 0.20943210550373603, 0.1856094830098652, 0.10294275839001903, 0.16675630434145852, 0.17628259235812774, 0.10726829765424614, 0.19949628220450497, 0.11067522088846854, 0.14026136798483713, 0.10527416312646483, 0.14459734902747218, 0.12299134065547299, 0.1826459944488541, 0.27089006898383944, 0.17304977792645657, 0.23747925856901755, 0.22314356249426642, 0.1826068933211988, 0.15181071034842922, 0.13968390622927299, 0.11211507548127445, 0.13559387005384893, 0.1705915243515084, 0.10887819312272534, 0.1297899266524661, 0.1077399550065879, 0.1841717198370926, 0.13538442161535064, 0.13533692416404525, 0.16730788764694046, 0.12490505127296334, 0.11091702888088842, 0.10489528668263268, 0.13434888524634225, 0.09955937703770977, 0.120634846539507, 0.15151927518027444, 0.16197974613356977, 0.1633490363676702, 0.1700110595312811, 0.15520262592021497, 0.09874085805589154, 0.08994297409850745, 0.10708721745158396, 0.1496933505780274, 0.11637892168495925, 0.19663551071238136, 0.09240796924718926, 0.15320204859299047, 0.12230573792851741, 0.14751338610245338, 0.2206019432313981], [0.030101036705497294, 0.02684754173031017, 0.06988015025854111, 0.023788476039865808, 0.022513113930941592, 0.07828107809708004, 0.01096292791302286, 0.03480050923122514, 0.033256171736866236, 0.0023931542959725184, 0.04779826338973738, 0.036736099319832946, 0.035927784629166126, 0.08242057290889564, 0.023849358962428187, 0.007482816468954327, 0.027436826137765765, 0.013383086808326264, 0.03851442304890483, 0.05885917490588562, 0.06601229490291688, 0.06342062711595528, 0.029035580772606116, 0.06297944091080178, 0.021937013896662864, 0.022575186205006415, 0.046384727747570124, 0.031897070472158735, 0.01596186708118166, 0.05412075255486754, 0.02148241732239483, 0.05815267330035568, 0.034311626391905936, 0.06661915145213566, 0.028255597928599007, 0.04217912337832874, 0.006102722479901727, 0.018493161394050526, 0.05103004743315039, 0.027214137784716104, 0.022979234382810614, 0.04263029937001486, 0.05417179316282273, 0.05599365749907109, 0.034210939456017754, 0.00985930739496384, 0.032260215300465786, 0.05811448764776992, 0.03385838196282426, 0.03592660102332312, 0.025628856721244035, 0.03892194352022583, 0.050280281012096716, 0.004359954806615509, 0.015631221617842396, 0.04105435691833977, 0.05879788787194318, 0.04836650144669318, 0.057150806495619405, 0.1395204537097485, 0.015163943415597804, 0.028133058334670724, 0.036247136041281686, 0.029838000416695595, 0.04336849020253267, 0.032957585137938304, 0.09408813796096271, 0.032712337410738396, 0.08148420662168535, 0.020664105184316155, 0.07413763027157515, 0.03875589396263804, 0.0811043112809139, 0.026291268051511822, 0.03881066541878447, 0.05127017386257649, 0.044230251017236905, 0.028253870400329752, 0.03775697276597062, 0.03880407706263565, 0.026494583956176238, 0.025965433620337038, 0.012473730866106288, 0.034122023461086136, 0.047809528712663925, 0.04107199226235671, 0.019097309822456974, 0.02448045644879101, 0.05506661833233892, 0.0851013443823303, 0.024872785396573525, 0.04568795545867855, 0.013588809186682827, 0.07009196590872542, 0.020087993658718564, 0.013482120909517812, 0.015844054249746185, 0.016600811223108924, 0.0331926285739868, 0.045669975375095685, 0.06288329304586496, 0.03177630820221478, 0.02958481984903976, 0.06941374060848067, 0.03901251809551351, 0.04718143237574447, 0.06400904392883663, 0.017912342258158232, 0.036244527511899514, 0.02070580526525455, 0.027061820353171038, 0.03089528027621489, 0.022144928244092775, 0.02839701967464099, 0.022069549022783196, 0.022322578288073984, 0.0288064208918161, 0.023219278457784848, 0.06159729955177154, 0.007248200605728574, 0.03815903869127074, 0.022756852464930668, 0.06974046944730705, 0.050618033856153495, 0.07339119250255247, 0.013271821155813674, 0.08167670919529854, 0.0341760479815064, 0.0606730412842045, 0.03831775678742317, 0.019858705458201228, 0.0462597826375596, 0.03462266958048267, 0.054815916059118126, 0.026646694543981747, 0.03523676949102552, 0.034386791108596715, 0.041508275504794814, 0.03367388500801979, 0.010076625471664293, 0.03214319920047157, 0.040248191104300564, 0.040814077271328825, 0.03376932424162665, 0.08035513091712229, 0.07021637858762857, 0.05751258002654199, 0.04578175526412745, 0.013045860649717432, 0.0704648515449897, 0.023428357258859663, 0.09812593460083009, 0.036566376370648225, 0.05892378676141943, 0.09752907549902316, 0.03208446132409717, 0.0625893566006374, 0.009076056228349767, 0.06032001647737719, 0.07325094478625445, 0.01293281384278089, 0.06584393942067701, 0.01835269342747427, 0.08451416097100704, 0.03348279586662689, 0.04617781889054083, 0.05783183184722739, 0.0721266647920974, 0.045032279956485, 0.030702657043753617, 0.02435047431067834, 0.018305081062980236, 0.03418313429480599, 0.0307506007412749, 0.057074450512206366, 0.036311717253298535, 0.018474509068314108, 0.037612339196306084, 0.03239651000307452, 0.041132187621007045, 0.05585986407353513, 0.08567806303260789, 0.02784587112405608, 0.06813245089424234, 0.03073189478938378, 0.029362187037364613, 0.08136418362658832, 0.006090353032754314, 0.04598904716511888, 0.06288196771375595, 0.022146213356585755, 0.06748121487157, 0.05553449887121397, 0.014892254163691354, 0.01500115451973773, 0.02430158066413095, 0.0895649939775467, 0.08890063486873143, 0.054221573556142474, 0.06076068940362143, 0.03796202769022315, 0.030849299678999572, 0.025348763484808228, 0.018084101086001725, 0.027902213060447288, 0.06194391220267262, 0.008278437082715815, 0.02619492674937412, 0.04309433414751003, 0.04035515996116785, 0.10219929304214255, 0.042069794970654675, 0.09438545668437597, 0.018769460580041333, 0.053223207773220156, 0.031868654355827364, 0.02934651096321402, 0.026154025315096783, 0.05040506141320352, 0.02238251700726969, 0.06851843663401182, 0.053406302787123196, 0.016690368816677122, 0.02173419403392942, 0.05079770828747461, 0.06347384341361542, 0.017368697538791646, 0.03931693845398484, 0.06681253502686178, 0.06078249609638607, 0.040955140871266206, 0.06582168456647666, 0.05220624520593593, 0.07472059253843562, 0.043332277226351926, 0.041133601053227345, 0.10881368085862168, 0.02410679706372321, 0.02247173369171158, 0.019653830564610904, 0.053385530313056324, 0.015617964466312721, 0.08037904052123909, 0.09326844686462034, 0.06839597747931558, 0.051199609503871014, 0.06055884438777163, 0.056083377886323206, 0.07098080410111336, 0.011584179254338868, 0.032687956662548166, 0.04858346137728903, 0.013234419785740395, 0.06631804825437647, 0.04870085669080577, 0.02233412131787308, 0.08764507804786967, 0.07558267127962844, 0.05025297380803574, 0.01939838620713882, 0.03079304775793947, 0.05542450013660616, 0.035173088432319706, 0.03637340648340122, 0.10841406641467925, 0.04485060603568151, 0.03841684642998922, 0.037442807769102436, 0.05388300099800672, 0.01829806944325326, 0.0681995755181678, 0.022631311721559015, 0.0347533258759687, 0.03925458655782765, 0.06254065256085127, 0.07208960911919994, 0.03147382413097207, 0.06187091551480755, 0.015413441973167564, 0.01839158771138999, 0.06166119128465653, 0.05927778066947095, 0.02069121512073663, 0.05692815836218577, 0.030586251898879008, 0.03998333918711832, 0.03794433105917227, 0.0534363717381512, 0.02705554034741175, 0.03339495622522889, 0.07284193810436033, 0.03117640964656828, 0.033484305059837724, 0.08684424803622308, 0.06513329327947671, 0.09125758863745198, 0.052364821575822375, 0.023169605316774502, 0.017156548640360276, 0.016172861102067174, 0.037372059549295136, 0.040859433506885846, 0.04950907945092167, 0.0068400490694799495, 0.058870041863091534, 0.017625781324421688, 0.0621817633509636, 0.06830681250580857, 0.03323194803670049, 0.05860198003750655, 0.03682807583602206, 0.05726578480173504, 0.01808706393104888, 0.013520048007429128, 0.01784803875301394, 0.03146538950292574, 0.01787555088559466, 0.03969335575558005, 0.01756351369793617, 0.017911696829082027, 0.017816592758942037, 0.09022049710995729, 0.03667105462462191, 0.05867236819598944, 0.04973050567411608, 0.005315788345591676, 0.031462886310633154, 0.04157095298831982, 0.047262840709018136, 0.04237414638121282, 0.06284448686206053, 0.009361666255450297, 0.039843811593469114, 0.0379341535810982, 0.034539284740364364, 0.027559965195494796, 0.08556010081402718, 0.016603546156998605, 0.03497470613388765, 0.07719118778984393, 0.0520429803779529, 0.00966343786492343, 0.01890864343412461, 0.015935231161664332, 0.046655057193410975, 0.04109942204048557, 0.054961296564508835, 0.007418969743734887, 0.03557032800369686, 0.029079351206159884, 0.02206313878207678, 0.05861534827178525, 0.10621604524672994, 0.1237081844479807, 0.13420708237155793, 0.12081053348318224, 0.16005499618909053, 0.1752512541509444, 0.056633180037381194, 0.14371195056986424, 0.17070021690620532, 0.08622092059663228, 0.15686776398891406, 0.08066135924309492, 0.14936738016624607, 0.18110746007052161, 0.173930334708383, 0.1542474674962221, 0.13591890583836264, 0.08280864240781916, 0.12262999230334837, 0.12676526597070117, 0.14191023434602446, 0.15241952042185491, 0.14957741083156678, 0.20474816732589277, 0.12237091668911519, 0.16615319396218947, 0.12749178545369258, 0.1604993118634147, 0.19362372796862357, 0.2393109288306967, 0.15116315154779345, 0.11550747368845249, 0.1174725428403866, 0.16298566554342547, 0.19495701207028282, 0.11676437116318172, 0.14521930516967851, 0.07843002857219789, 0.2775329399493433, 0.17147508419809804, 0.1916563528920374, 0.14628805911108372, 0.11721153668458424, 0.12835360372499113, 0.19635824817082576, 0.12015078622367113, 0.1240164812113489, 0.13664655147060273, 0.22705074880392323, 0.19460438179873651, 0.18661325737353296, 0.1305129757571605, 0.12239205305494609, 0.18893488682806495, 0.10143549572075568, 0.23040854281956152, 0.16817059458023118, 0.19541228280192424, 0.1915204642160285, 0.28884048964227405, 0.15907800425925564, 0.1168170550297345, 0.12674541663258307, 0.144283973101166, 0.1871617456838008, 0.11202354329608141, 0.15945373974259824, 0.14605314590998236, 0.16397842356274206, 0.15260623137076057, 0.14328907003566144, 0.27994979413286336, 0.15862624221030744, 0.1850166688522985, 0.21870645784562637, 0.14179702187257429, 0.1488778959479063, 0.11240130125154411, 0.15274797295851095, 0.12198077875279612, 0.16357216713649614, 0.17157757144060828, 0.14791631770710792, 0.14293279318559554, 0.13696274660047025, 0.09568295681909209, 0.1407797643614392, 0.11013646955571829, 0.226976974536815, 0.1480069612303088, 0.089969526705963, 0.19176732838874866, 0.13195548867506365, 0.1296529194880878, 0.1674243176896726, 0.13107837928879645, 0.11452433007258563, 0.12285368231635903, 0.17395972184115843, 0.19871948437104303, 0.16745523699829656, 0.12915243424715536, 0.11874101590365173, 0.11415102308796299, 0.18340803742889436, 0.14683936662491293, 0.1708658910807102, 0.21714164665149105, 0.14206622516916645, 0.15466550635474344, 0.07981607314920233, 0.15249232941817853, 0.09269096212641847, 0.15456989858179324, 0.15768236060055996, 0.16244905159598397, 0.11646594161227827, 0.17316064617085844, 0.1365500243921434, 0.11990137097816314, 0.10232851675321018, 0.1945264706568372, 0.20645406127216356, 0.11665131190731642, 0.2651353084271954, 0.16462173823627735, 0.18416540727259653, 0.10134004116539033, 0.12687467098716768, 0.11765958320709968, 0.14625542376550937, 0.1906060923131243, 0.12979954871679508, 0.15612179353352518, 0.13783999388256382, 0.11801607456178435, 0.1054043980735925, 0.08636838486117702, 0.11421209561728662, 0.14408560229405282, 0.12257275021364614, 0.11405441173983198, 0.1115801009619909, 0.14549981592403305, 0.19044389617779564, 0.16699901631762906, 0.17996264891999383, 0.14128930476163665, 0.1609133823864883, 0.18865849762674303, 0.07629156307948214, 0.18203658682684745, 0.14303973905982512, 0.2116045776394106, 0.16650652903462612, 0.09426325033869475, 0.24499963728650925, 0.06679481541317317, 0.13180898202042426, 0.12940240873684808, 0.19249249189611406, 0.11025263146767694, 0.21184588001380045, 0.22654114711669185, 0.09689471639332273, 0.11907112319022418, 0.09116802529822435, 0.20745320846476864, 0.18812588265826627, 0.08818484827755921, 0.11055972547300401, 0.1499255518278768, 0.12083168517077163, 0.17594528384506705, 0.17243441014039904, 0.2099756602077715], [0.020319704612296437, 0.010814420811291183, 0.04214295253698384, 0.02502094488590956, 0.05763294393076532, 0.01629029663519994, 0.0467731113425426, 0.034857452546636906, 0.048120208009476625, 0.09276497388078321, 0.07668481899365302, 0.060955367666939576, 0.04085775194389205, 0.027839108482904495, 0.09587771169120267, 0.0837743881669256, 0.03636152445969563, 0.02738590044299922, 0.027337025948649934, 0.009547207962661501, 0.0048780605486113465, 0.016587808795814073, 0.04870801195201855, 0.045816807617102905, 0.024616678373046944, 0.04952830825782111, 0.006683305086147401, 0.017937697853232105, 0.04821547870374015, 0.058770431280736966, 0.08791125529716093, 0.028902764109173612, 0.09002927390317764, 0.03237061623123384, 0.03509962060038121, 0.03882297262128803, 0.08970628357342175, 0.027032285748470216, 0.06348944096375378, 0.026332906845416275, 0.03295795669058158, 0.1338533029681252, 0.050675582381025444, 0.010121845726614759, 0.06100820092063758, 0.030496290193930752, 0.052684517727503856, 0.02569077194728438, 0.026002190518944014, 0.014952066478379553, 0.056295557428271546, 0.07373606996430505, 0.0562778493059018, 0.027005763784531626, 0.04081719524918064, 0.023501664212334062, 0.016080434509222547, 0.06769866126799776, 0.06413730236911966, 0.037539059055909034, 0.06476225391510995, 0.024302333345516555, 0.049028807439871376, 0.10343212769517016, 0.015996251980053083, 0.029623015077724576, 0.014720805601457195, 0.061165612836879116, 0.01541580918485359, 0.01978659551710852, 0.10745608112624577, 0.003171156084487936, 0.02532271266494307, 0.03774055167131367, 0.05528780323783717, 0.004936921477858579, 0.113194631262412, 0.03354776395304549, 0.016103733158219728, 0.05316525705218796, 0.010470644600929753, 0.0676508267380057, 0.009703393180614278, 0.020885732505590688, 0.035411027680721976, 0.03054746869771231, 0.0313283612711295, 0.0398208825818954, 0.0711680359898075, 0.028683063499028646, 0.049118658062070615, 0.042976835412123514, 0.039260527569680445, 0.028596790507435802, 0.025015959568742304, 0.04190062743521506, 0.03711463485453879, 0.0504489774034629, 0.05326237018790938, 0.027550239709296057, 0.02897002662892544, 0.028572520841994596, 0.047402651755199324, 0.0355082672209509, 0.060130999603819464, 0.01953558489349821, 0.015819654349357854, 0.05646583196076174, 0.051294466510655425, 0.04110798690347903, 0.0175199213798248, 0.12916703588299214, 0.02011209861525605, 0.029353344467498606, 0.037120246448584145, 0.05379272902744913, 0.028627005015169422, 0.030983123748052507, 0.05277362524441654, 0.1039611267286443, 0.06356687330070042, 0.030638713599933736, 0.032183020450775666, 0.09421569926123466, 0.009229452886258163, 0.0280692681084357, 0.04067864824807452, 0.08188153046273416, 0.015316109544777823, 0.009530001627882163, 0.04719116552282245, 0.07198943546222103, 0.05292256422821553, 0.029157361939489364, 0.07174775004386902, 0.013855830090300692, 0.08688281290233137, 0.07267532930258783, 0.026784866162004973, 0.09543590112439088, 0.029651400550538977, 0.019515762368457455, 0.031624798993429834, 0.020709880853011724, 0.028947269987134688, 0.05416816956694088, 0.07986730144869897, 0.015466521332611241, 0.057145999293894544, 0.011502220295369627, 0.08200814181398, 0.06843055102733836, 0.03845807345163438, 0.042832596377739986, 0.054344936694589355, 0.015223573784403985, 0.031230614197650747, 0.02780061639514902, 0.02561770248106651, 0.08304984519077886, 0.043989730052529805, 0.02931779607259218, 0.033540256291387543, 0.031879295317095616, 0.007255757105491696, 0.04747556800383234, 0.04754331698941608, 0.0031099212402853397, 0.03769246433230658, 0.02882895536810881, 0.005845357156959513, 0.03154469300962744, 0.012131496407692472, 0.020505080652994015, 0.06650691957122858, 0.04802738496613118, 0.03027883613662374, 0.05409015117273216, 0.03402327089720676, 0.019300233107060194, 0.031385995980892936, 0.030719844226334846, 0.05645279314429049, 0.09766603669812603, 0.1072850596580294, 0.0536644897393642, 0.018618267382525148, 0.08097858859166022, 0.01788827752123677, 0.019668476250503334, 0.029450358011789864, 0.024246962425569375, 0.022726703074670607, 0.05638794763193977, 0.04105847464093278, 0.004872462361104666, 0.011777365561424485, 0.013810445126446505, 0.03873145958829311, 0.03786298401293255, 0.009232958696121651, 0.07989198480161928, 0.018763136524226398, 0.02525784416995462, 0.0185736580826943, 0.05311695520856208, 0.050050040947333466, 0.03063853548449134, 0.05337060308985172, 0.0026000143148966377, 0.10842410216648733, 0.02995669999490342, 0.04375271394007629, 0.03900989807481247, 0.050588979971625155, 0.030292922578331445, 0.00835656177162403, 0.03224467137648213, 0.057322256973073374, 0.02179608627733204, 0.004068557464051992, 0.03522199165496615, 0.02166875671865719, 0.04875131124149888, 0.009625719525971481, 0.03978976025997151, 0.03330827337659655, 0.0054671859928226525, 0.05297228716494096, 0.035746187317155065, 0.04249628760942048, 0.01371206986086984, 0.011386939384523901, 0.01466147879499101, 0.05776321718228921, 0.02937921717192137, 0.07498420339318053, 0.04813675933908071, 0.04424690959915038, 0.05253826005143985, 0.04564142710859737, 0.030221337407466867, 0.06705800491955972, 0.1352553051565924, 0.009346216177237372, 0.023042716258656115, 0.016496971835412325, 0.015279669615049517, 0.02179708027641379, 0.01916702956922593, 0.008023927831316308, 0.013666722243801962, 0.01693278201855719, 0.04938733658843464, 0.10089449975038729, 0.040059618561738924, 0.03472364379934246, 0.04161800993906875, 0.019856569988112298, 0.015485333579201854, 0.09273877367377283, 0.041482511967901266, 0.03072583694912253, 0.015719749780762342, 0.07987906855921592, 0.0319904699966672, 0.03435598288272177, 0.07758723226405921, 0.008085789910006908, 0.051152361031141014, 0.043281114044328856, 0.015161107932668061, 0.00603064701276561, 0.04285138468408296, 0.0795106492155502, 0.06834557655477716, 0.015039223343915036, 0.025875962211660324, 0.0714155206937463, 0.041415751235739845, 0.049881731430369045, 0.05608061996979579, 0.029316957206315095, 0.04355251984370332, 0.040511177597387184, 0.009725269778902012, 0.02216660853234991, 0.10460239594742175, 0.027223428516017816, 0.0612253868471711, 0.142218416196204, 0.13635870159393357, 0.02798186705237435, 0.05945075949233386, 0.04071490718953071, 0.021108727293810057, 0.05962583356566968, 0.0699246599669418, 0.058212589036913655, 0.05065187195976896, 0.026506073359820633, 0.035850199074634624, 0.0557401436831682, 0.04729615404240547, 0.03570673378905462, 0.033943145761206266, 0.04518013109543151, 0.07227631240722633, 0.05677875589519259, 0.008967611694618339, 0.055375531796486153, 0.027128065891203382, 0.05316626445780839, 0.06978851082103868, 0.02744482792613487, 0.03057732888978095, 0.02776000224384329, 0.02280146751042095, 0.018745847834995197, 0.0206383052582462, 0.0452792092466787, 0.0301053153065544, 0.006395681684220871, 0.03156416887988246, 0.037011400676302375, 0.026281613428446076, 0.04198936339948447, 0.09152021123877457, 0.051259207313940416, 0.0017894223081736617, 0.06598222595188888, 0.04596322617163101, 0.07635068208459886, 0.05987477383666462, 0.007721542393893845, 0.09156797682085345, 0.02723091702547766, 0.03203863011402709, 0.027098764943319465, 0.008424361510532758, 0.024073468408577388, 0.09349102605014079, 0.044224834775612246, 0.024431304247569174, 0.03551048121505207, 0.01253871618950319, 0.06179134579255216, 0.011874996764104695, 0.010994777060864915, 0.06677293594205572, 0.09877579932611796, 0.025413158920503436, 0.10855085141355954, 0.14357324269029403, 0.07316423895498438, 0.17788238312688567, 0.13399294547496304, 0.10011824583935161, 0.12019099817881662, 0.20973394414590252, 0.1554191683328921, 0.15005062334239483, 0.19269003532826903, 0.19377144504218333, 0.08970916406401704, 0.09777659084647895, 0.16343010379181755, 0.1630355685108131, 0.1078598324449793, 0.18301984535590296, 0.1828009127489021, 0.13835108178036828, 0.09364399848686111, 0.08660114535521116, 0.15103746716293598, 0.18926151607546116, 0.12004357987954734, 0.25343305491391693, 0.073331261444236, 0.21610837790273854, 0.11812860521698192, 0.18133725580428878, 0.15783338717395262, 0.1099877795504947, 0.20673110930910035, 0.07134687155485153, 0.20591721749834477, 0.24020533648229417, 0.15680967920249508, 0.11937195059633064, 0.2320103254169226, 0.06224963491061523, 0.0982423033565283, 0.1884531400977604, 0.15099810556538645, 0.12151744877619129, 0.19662506127309418, 0.10945754711546245, 0.12769973235985926, 0.12044759166817512, 0.10087793692946435, 0.1331403815457898, 0.10504973000816761, 0.11424961094293865, 0.0962612382887352, 0.12395413697607095, 0.1676741083182635, 0.1048185476552575, 0.10210017658649914, 0.12819565937764224, 0.14495066877815033, 0.08942452409575063, 0.127636147062144, 0.10403519977004298, 0.13932451906223453, 0.20186162463599638, 0.13365690866785665, 0.1892433444698972, 0.16084912293139966, 0.25798614527429303, 0.12176474961902826, 0.11981820447310326, 0.20591364752861763, 0.09743606476413627, 0.14229546931962814, 0.13915412578611605, 0.1421277267077277, 0.07844077678577555, 0.2445523032257634, 0.13140465613574753, 0.1629621160006331, 0.17072304632634888, 0.11023774637930817, 0.10532691594093077, 0.09390940964822808, 0.09927117476059545, 0.16205488403718318, 0.16011197780889852, 0.0546328938235679, 0.12630116990617207, 0.18814082137278973, 0.12718318225515465, 0.14838697148426888, 0.17597061071184375, 0.1146229026058028, 0.15647935741130384, 0.12300955056543313, 0.157247896816942, 0.17132686150650825, 0.20164253881141064, 0.172099583752213, 0.1581300317399925, 0.07799626192859105, 0.136569605599488, 0.2972120226871583, 0.09198112037753867, 0.16070742730892476, 0.15265696171310641, 0.10433922176279369, 0.13244472774526767, 0.10090473468505567, 0.1222296347541194, 0.18245556031263646, 0.23903522910850666, 0.16059407693964822, 0.0968184523404606, 0.27924913011731645, 0.24330592413823454, 0.13447054000871797, 0.17022158049287336, 0.10656368828588918, 0.2037552101237159, 0.17350843476672329, 0.19671288559273367, 0.1020582332726448, 0.14368256343708885, 0.09288640647766092, 0.12461550834198153, 0.10466244191892686, 0.13285516701158018, 0.10082952783352907, 0.16833119725267734, 0.13068517700078028, 0.2825969343464221, 0.19264897301552758, 0.12036204262967072, 0.11950743324573963, 0.11796162869300574, 0.11343349747720266, 0.16125470520027224, 0.13740464143695372, 0.16221012409415939, 0.11884189436152098, 0.10432279683769712, 0.25128420892982717, 0.12420249502024344, 0.1566103584463558, 0.08472177845936629, 0.1571517681042033, 0.05808152288438813, 0.1684779796989695, 0.16700106943326612, 0.16003860190751093, 0.202762252921539, 0.13001722493960013, 0.13911264978589552, 0.25047757963259376, 0.09898157054257971, 0.09271611279297261, 0.1718173263173911, 0.159402365886396, 0.19735091425959142, 0.16973249464025422, 0.0892198637067791, 0.10906847404135812, 0.10996911764865923, 0.14257046424092787, 0.14592550034003873, 0.1334060148726548, 0.16207866340635285, 0.1998047858116127, 0.08426535093495924, 0.1325656623849946, 0.07994063904569035, 0.07753798813228646, 0.08261871388963155, 0.2747491602936099, 0.12965713297167133], [0.02512266795571533, 0.05050155401770627, 0.045606903356289676, 0.09686399626755908, 0.05224889715112025, 0.0181351934048918, 0.006695296756187154, 0.06682568109564244, 0.030502503166996667, 0.028997531100626917, 0.03785360326629974, 0.021984561143683332, 0.07283619244492824, 0.025328944790207093, 0.038382571656256914, 0.021427025335029732, 0.039109386083099155, 0.04999179911289004, 0.05763859765964651, 0.04771223937671992, 0.019381899995008306, 0.03873967971172064, 0.017237673521101955, 0.028624641633923018, 0.06744715460245648, 0.09721363113532144, 0.08891710575910346, 0.06670623266648862, 0.010543426784176019, 0.04628662635842639, 0.05808860919768772, 0.01132266843811639, 0.0532474659473425, 0.06724468522494839, 0.06184903221325048, 0.015076575875883142, 0.03417106074911933, 0.020838102904118357, 0.056313127654814915, 0.03499825184624042, 0.0516850526084102, 0.03324287628094035, 0.03421264017120965, 0.036344318124916286, 0.02293246854547291, 0.012432948175457217, 0.08662356874875485, 0.06595540521365982, 0.10380710475146772, 0.013772784244088877, 0.096376174460015, 0.10038449203655606, 0.058076041525289904, 0.05119366083113898, 0.057584232230099945, 0.013767965551045154, 0.03968261903332126, 0.0465312841979246, 0.10946104813727642, 0.023724141891204545, 0.023247409206364426, 0.019880715164265806, 0.028214824814048987, 0.020939743619472272, 0.0770506183166177, 0.047890634441207496, 0.0262831034694588, 0.009599346949178125, 0.0482924475574926, 0.032501965836291356, 0.03628554002892587, 0.0466175303764401, 0.018771697556780233, 0.024162164153230768, 0.038281697028827284, 0.015062748946459785, 0.048408092360102364, 0.07713116480097656, 0.054924083843586914, 0.07852358322951102, 0.06965623041915317, 0.015991154622526902, 0.02035716056613432, 0.04672682047971795, 0.032201107786667925, 0.05234204578183351, 0.040307792744809584, 0.030310839459660555, 0.02641671303389294, 0.029783194486592567, 0.02683846933406688, 0.01940155206548591, 0.06426058889877412, 0.05199775820778263, 0.055471668170104106, 0.03916727168665778, 0.05921815987676383, 0.0709304491418504, 0.02617804983240222, 0.09459567887167777, 0.0727261898798808, 0.016527584708866574, 0.04355474532912335, 0.029671575476024902, 0.02561669699066589, 0.023703966965718616, 0.03674867848354963, 0.013736182478286568, 0.008497312233122367, 0.02404788490234604, 0.006220665546284328, 0.04819731092861584, 0.1065137776576223, 0.02482215273043802, 0.07826881302941231, 0.051539296719936595, 0.02512036394628306, 0.046040624034621065, 0.040180874958394036, 0.00887800909338459, 0.04184619305775531, 0.09452545925253823, 0.03323761708734017, 0.03218669767281221, 0.019167136821535327, 0.0073715082028009485, 0.007198530337547944, 0.02663577587584094, 0.018121905609845154, 0.013624783717997134, 0.06420874006805882, 0.03843695240756197, 0.013428275462149853, 0.06262761120113634, 0.048629116387136524, 0.10456010789400148, 0.019901598721081694, 0.0591424857116034, 0.01248352625782812, 0.06934656235840052, 0.034684489045532486, 0.005943790836740406, 0.05120539346769933, 0.04880637764149616, 0.07924456389680987, 0.016384542686864734, 0.09380044896275767, 0.03866630381033306, 0.019916232915655262, 0.010189915511516795, 0.04853773741952835, 0.03734064611396001, 0.0019211519646623564, 0.057233858087490645, 0.037532857574161985, 0.02087413010397746, 0.013371091786651843, 0.03198357137490905, 0.02372727902125447, 0.025121645228336417, 0.051491577103133165, 0.029451267741199945, 0.03860568710332436, 0.06121059368935324, 0.026466254024736346, 0.05549950014439322, 0.017252070228418997, 0.035390067515113664, 0.03144520117090114, 0.046094629402843215, 0.08976664364097581, 0.022595154286752787, 0.06725565560402409, 0.016641463678810867, 0.07508292148310332, 0.038762432523071766, 0.051507247431624326, 0.01827067413908099, 0.06887637589487337, 0.05311773661824484, 0.019199120992374037, 0.010513363578807442, 0.031013514456008712, 0.06128747827343403, 0.058649975445962725, 0.03414167744678355, 0.04633014015252552, 0.007605134376189522, 0.03854018275535876, 0.018732481515936313, 0.02470219293759475, 0.019050911707322926, 0.035270787625303196, 0.03514414946098001, 0.009320956343154033, 0.040821458528479265, 0.04398907887779417, 0.10327828191821614, 0.0037375054953079074, 0.02309006432281627, 0.044703988298293085, 0.040240760051435044, 0.0925590800902536, 0.02119288588273189, 0.023828239833575585, 0.013195669143310478, 0.041126564535642826, 0.02072908859249325, 0.04661520913002953, 0.010328744049935092, 0.029707981889406522, 0.036715154475983114, 0.07113577602731605, 0.012913440436785741, 0.06789173840755416, 0.09695082467289702, 0.0656793377692661, 0.02619599352680868, 0.011489773281819878, 0.03779411270853974, 0.05833670294152633, 0.04642647570900379, 0.06855168484992559, 0.055538268023801435, 0.0063393751793961615, 0.025143099520655892, 0.09024590824640567, 0.05528144087762602, 0.06069138908999101, 0.04882120910371023, 0.05027244010219171, 0.05584191080302962, 0.02523808867760724, 0.04359637454692875, 0.03591489519984011, 0.035205838691082694, 0.01074897870796943, 0.01788661128000146, 0.03895210440180475, 0.018412335287599314, 0.030092186474752043, 0.05305197946126423, 0.01724043526806899, 0.043262406177217924, 0.06676375820872284, 0.02377384567573186, 0.03425517337276571, 0.05280456753567823, 0.03159494454702062, 0.0822639462327765, 0.05230073449051669, 0.01536044784100546, 0.07760991612749715, 0.05611360771581531, 0.02229669600755217, 0.032478829980978084, 0.027389305703822645, 0.029026046808388446, 0.07367166495251079, 0.014766059372754348, 0.03807524016367332, 0.061235008911500056, 0.02003967074767476, 0.030729372444893086, 0.03686122829094529, 0.03372805891558528, 0.015521539852113254, 0.046452350328646363, 0.07275313319217774, 0.06847466237001842, 0.027986030740242814, 0.016386614954699914, 0.056541111590641166, 0.08475375496932576, 0.015105922789042516, 0.0934171292089647, 0.05633731305058445, 0.018542520439011917, 0.01161727521027769, 0.037040385612917524, 0.04308150600521796, 0.029678236610526522, 0.006593367321446779, 0.06549490976237482, 0.04767118855529735, 0.02092739811257249, 0.018587351904340813, 0.03084254661394704, 0.04112127086808605, 0.08829754747210011, 0.07286230072138772, 0.05826983495705551, 0.04369261051197687, 0.06301725501074426, 0.06608431482867849, 0.035135691850295955, 0.05055352159204984, 0.09511589087666043, 0.046099314030500195, 0.012396213301878064, 0.0326615994075133, 0.025807113889905236, 0.02634248294446978, 0.04418541572146839, 0.02884995958377277, 0.0723575407098378, 0.022609897648855563, 0.02575295913453785, 0.01873694589331506, 0.03084615105763078, 0.06308018147284467, 0.055720455223514195, 0.030749095378503687, 0.0630456653814162, 0.004449801598375123, 0.10204609077904495, 0.01924255434724112, 0.01588868557460486, 0.06027281396992265, 0.06774019855525225, 0.037011561554766474, 0.04643936513832981, 0.06135768640125471, 0.02354946043792992, 0.09402512722919065, 0.02061959739113527, 0.06787341358440538, 0.05394834446750822, 0.04194422549898586, 0.05461047043002421, 0.05892135826269946, 0.05323372232998091, 0.06321143148647201, 0.0496063917695034, 0.03725660243822682, 0.014795793160315485, 0.038425204449243126, 0.05733208588114189, 0.024820718230799805, 0.0343697686349192, 0.02383431108037551, 0.01571122130694529, 0.041199021131521275, 0.027975236561389703, 0.04302157877734111, 0.04225074493836972, 0.06148920071521594, 0.08033327442864258, 0.02669797646963308, 0.018605414342375535, 0.07723208156324203, 0.07227609024172829, 0.1827550087604792, 0.1431117206811905, 0.14258252246485603, 0.1364463114089543, 0.12841376460968487, 0.06705176896385609, 0.06961577331587192, 0.1388890746860735, 0.1250808837733442, 0.11136238643478964, 0.11511090061356945, 0.1622230863018382, 0.12748809290989754, 0.0982338917111197, 0.14949459672695206, 0.12297025025491753, 0.1095605016716065, 0.15218379516755381, 0.15910809619292138, 0.10017982398670527, 0.1486398264645569, 0.18511645946531527, 0.07867891521703813, 0.12341617471388272, 0.17961179597243188, 0.11037818561758726, 0.22807271009491337, 0.08220473529710885, 0.10402253633665462, 0.07672891501457461, 0.11511079336126005, 0.10027896342498642, 0.14023354367142724, 0.2179521676753798, 0.16532082411070026, 0.13358203123413748, 0.16978146298037422, 0.13393453893161592, 0.1749723828247478, 0.3103744244623569, 0.1782059327008263, 0.08171481440865225, 0.19382537763205268, 0.15288228349339578, 0.1426903110358023, 0.14520166982566157, 0.17102791867669553, 0.15909821365869817, 0.2256956158746635, 0.13347392090626303, 0.19120790034292207, 0.1800855753883239, 0.22317517128202224, 0.18595566282108908, 0.09448573759366428, 0.12320760727649736, 0.15556334608024167, 0.08972152872311492, 0.13052497269405475, 0.13475508038555423, 0.1112509512853238, 0.11379530548208183, 0.10080008707459896, 0.16422974636718152, 0.18003634657830964, 0.10980921211622416, 0.13666636250432462, 0.08059453339345994, 0.14193694017106487, 0.08604644407187739, 0.09872173650130149, 0.10775688554971449, 0.09106734602321541, 0.17469873621819482, 0.1668764116062272, 0.1121268425917914, 0.15748035853668568, 0.12083580672380426, 0.11756611281945822, 0.2031326411111701, 0.17215423646473116, 0.18929897777495847, 0.16533432257992609, 0.14573393239369317, 0.12254653468487725, 0.11857551792936942, 0.14649784462826868, 0.21115624766436317, 0.10131060806733948, 0.11796608732472505, 0.14875080196126816, 0.11381106391068428, 0.1420324253699472, 0.14646543910907162, 0.21519814287462544, 0.1210566851941328, 0.11812030848476196, 0.18847595419614546, 0.12085413154695304, 0.2771509378667801, 0.19892122596502307, 0.21794565592802342, 0.12342051077153414, 0.12764960722697358, 0.12086127914728657, 0.09995297003056734, 0.09558040828954789, 0.10730120113059398, 0.10617174238206879, 0.1822508769410272, 0.16782207053995904, 0.16502895993330788, 0.1616688216886213, 0.19698665477335456, 0.1987511544458328, 0.11713723381680828, 0.08857232788878103, 0.14965529132994915, 0.13069550386599957, 0.07555793430055342, 0.1556935350620939, 0.22099552856337643, 0.13289906384964145, 0.1625692201477866, 0.21702543111337771, 0.15195269708431539, 0.1274462798309903, 0.09317590344336726, 0.11265187328981777, 0.12491477292872245, 0.10986397208105173, 0.21686164151516654, 0.09277541565919116, 0.16340090052014397, 0.16705659548601798, 0.25388253402085076, 0.08690040228107283, 0.21859997162415137, 0.16385872998545248, 0.16835735149441228, 0.17822641789192156, 0.07293312554998745, 0.19315302822618716, 0.1646207423219758, 0.19673094994598822, 0.2634599967108619, 0.20093249787967052, 0.1259280161391343, 0.16945659573520386, 0.12983345576832372, 0.2008984529323155, 0.2037938515986166, 0.12802882074949243, 0.27097001791961733, 0.12101369233982218, 0.1660494656572419, 0.15553921431062684, 0.10735566998201032, 0.13008595834816658, 0.13266356842171761, 0.13697350247492715, 0.2710695787062568, 0.09980760484693513, 0.18741138309480684, 0.1727438177312574, 0.14015468258050182, 0.18270365022603544, 0.15896338218402478, 0.1057248296696813, 0.1387531247230307, 0.14172321696194912, 0.24828089911851192, 0.11837890146360283, 0.09403712416608488, 0.19480566373996197, 0.16654396009060646], [0.06287341817252098, 0.06142731230225294, 0.0011156634202287082, 0.0517313702843122, 0.03944931078642126, 0.0025038338912230346, 0.03297581036965693, 0.03517416478585332, 0.04712057818147925, 0.014746216737905578, 0.07112614630210785, 0.012725359148105547, 0.015587442565799482, 0.023311724202827584, 0.006671769717227548, 0.05379297800602452, 0.02431058219724125, 0.02280067269419951, 0.013335422732897345, 0.05199121198646965, 0.014421422271088008, 0.025271725683142583, 0.010842963332130064, 0.038430831365046964, 0.01486136645619427, 0.046908337352496964, 0.05425346962686989, 0.04359331402567126, 0.06908722627427309, 0.01978489863235624, 0.03393020653616517, 0.03962584042681321, 0.08352295044929751, 0.06543150066488213, 0.02743312401787168, 0.0648999275759824, 0.0459847915466995, 0.010863768364933711, 0.06427188869565725, 0.05057383058292251, 0.09734262502001179, 0.0294204939892816, 0.03473595866272527, 0.037921072629791115, 0.030414052570479053, 0.02686587612955801, 0.07978362166472981, 0.0693819402987438, 0.04744346125892574, 0.0623497472805602, 0.03000645932080525, 0.032395165518767415, 0.03799449449645416, 0.04051704583088717, 0.007000627322873522, 0.023731392913407857, 0.03337662374120086, 0.07358940243120156, 0.024962025063653148, 0.048135882168407404, 0.0012459517541086123, 0.058961623843999646, 0.031832253688105175, 0.023055224559239806, 0.07345580435808628, 0.01223431594083987, 0.05499842118531947, 0.029069122017150926, 0.06872612307028425, 0.053335458806325356, 0.05205596173782984, 0.04411443384484418, 0.022668509120722453, 0.022718373783713868, 0.00881074561602286, 0.00511032117027489, 0.006787224913076048, 0.0367901238402532, 0.04582935996774224, 0.012813641205279818, 0.04069959309192435, 0.024068714833007227, 0.03440832584014824, 0.025951854711879167, 0.05905021808200306, 0.006979372692219312, 0.026969606349725398, 0.012427391165176467, 0.035270469698814616, 0.020436849032017975, 0.00962501951313067, 0.009329197533999481, 0.10113431591420405, 0.033888021904614665, 0.03330574528644643, 0.01827880807761704, 0.05019073299462757, 0.09750781655912438, 0.02784604157861923, 0.07787882831067809, 0.08568620654724299, 0.0484932353720069, 0.02581144420189723, 0.02112853641231214, 0.05588805227870903, 0.055548935798147035, 0.014782846274395144, 0.09791123846005048, 0.025996148000441255, 0.03399052063844377, 0.026261179948285706, 0.0537140479671859, 0.012941837400919008, 0.08677763669120689, 0.02751812721873003, 0.0392782012180936, 0.031272932894588, 0.02131989943013797, 0.03265306135759719, 0.045166605813128334, 0.03011148039912505, 0.052194148677611546, 0.0631850665705579, 0.03363242815999735, 0.0649184515819915, 0.022483073708210743, 0.07915980392886747, 0.052950465150417826, 0.06159836824442591, 0.0370322727417994, 0.03541210020381597, 0.025522575428288792, 0.010638177496260934, 0.027780638737303597, 0.04956825208219309, 0.040545176579466755, 0.04999394415907803, 0.023175103912851023, 0.06015309740999534, 0.07154600844988901, 0.013390106088932485, 0.02828169471373962, 0.02997565684058974, 0.042446089698182005, 0.07946199497147914, 0.024266003540927367, 0.04169012179538127, 0.07721999269579688, 0.0535679703217841, 0.02760823256516409, 0.019794829047074722, 0.01949737051261529, 0.06586096955523377, 0.0019940841335600486, 0.0214817144367243, 0.030172740619990136, 0.03954334424868707, 0.10932849960461741, 0.023343993741418087, 0.057223274582816716, 0.03621872184017012, 0.032388523536463903, 0.015392255811621586, 0.047801557567811785, 0.02381951217689822, 0.03972307613660251, 0.0589269660263052, 0.015639083595165325, 0.0248412991828856, 0.0756620379885839, 0.07126154468184517, 0.008036324570346023, 0.041237268071140976, 0.060280513153561664, 0.06778943502614576, 0.033151964626965985, 0.053055465161319704, 0.04308974145040397, 0.03754244516453436, 0.07167263512289332, 0.03247040684425062, 0.04773701466019115, 0.028432751930649244, 0.08290113220291753, 0.030691991184627822, 0.030909129230666067, 0.021912236697971824, 0.029158520647474838, 0.03230818772628423, 0.019634877549364202, 0.07179333993624296, 0.09055015240465442, 0.04526073120594506, 0.06056053744208428, 0.03366012606889971, 0.06459851028217424, 0.03739534096131402, 0.012960102852253665, 0.034269702230249686, 0.08097849666110932, 0.008553858140423413, 0.043477879897240675, 0.039479854711962324, 0.05771419138557488, 0.04635523336248533, 0.05284794726439061, 0.010626058942908722, 0.06100744632403217, 0.0763300896411942, 0.00987742633198298, 0.03324049374749584, 0.032017687185397076, 0.04995283971150076, 0.0568788222998621, 0.023557986996527162, 0.017778399445477034, 0.02703027476766898, 0.013658880376287047, 0.07054665441354437, 0.018972389610303987, 0.04157193741130252, 0.015521457497661394, 0.03669758807987936, 0.049701819511791395, 0.08530788934759556, 0.06683069131066723, 0.028578128605600328, 0.01973388292225859, 0.016302546381109183, 0.030734051326890627, 0.038082678877418084, 0.0032223932418761958, 0.04143169735588374, 0.04402791570511557, 0.05151328037402803, 0.03256827074613783, 0.03471948777235324, 0.04291834076866508, 0.07453912163093206, 0.03956771733599805, 0.03146002880267559, 0.029606348834931854, 0.03007709837308334, 0.07400891983941679, 0.031000483300416704, 0.038477746589529904, 0.028017718052010865, 0.031192784775949778, 0.00437377886320915, 0.0616150651307356, 0.019290835123449084, 0.06824866643235569, 0.029596805294615128, 0.03960365069008643, 0.03309710124026864, 0.0029957185981930386, 0.0212502486312822, 0.057581796070500735, 0.022358086463364384, 0.03954638944818609, 0.08566573667790621, 0.017156977649597872, 0.04494807540228771, 0.048120640849153844, 0.00576354279708598, 0.03632854054411573, 0.03844970394106161, 0.036346543610336325, 0.08039801651912351, 0.07340092181919083, 0.07424487492009517, 0.032960021297537515, 0.05268696920886155, 0.05444716729764497, 0.06491890357386682, 0.08859459806473986, 0.03796227283835892, 0.03707331973278234, 0.06347954310777207, 0.03196023633673547, 0.036015015230664325, 0.07735507697948525, 0.07467231367744746, 0.04409465728507888, 0.06871277015776404, 0.022226664079954068, 0.032937889017405055, 0.03971626178451604, 0.02033905024760433, 0.07992065181174586, 0.03454902937876121, 0.052943639307012486, 0.07029904713553768, 0.022056763015326955, 0.06594947569312588, 0.017690868154468558, 0.03896726528182626, 0.05689955646953276, 0.002618110987485477, 0.026227564010168278, 0.022634736134580547, 0.10186173172006685, 0.013526703396271314, 0.04684317008321805, 0.08149024339452868, 0.02696415371892433, 0.040129010805920254, 0.022869733605353583, 0.02908114193668289, 0.018793362523278883, 0.030111118422580824, 0.058857638899597435, 0.04504738337991219, 0.012898330310089214, 0.03764164972028906, 0.07598499001394357, 0.017046199420527104, 0.03984502967326872, 0.03810811299650419, 0.060673340058494965, 0.07647900181191583, 0.05104832629102373, 0.006890620448581514, 0.031170460973836245, 0.025966958135306358, 0.05087646595653027, 0.008137614800474577, 0.07148371784076576, 0.01258663594677684, 0.01135252671496522, 0.022660899952414538, 0.025986501038254752, 0.053607312767135526, 0.06255183361410614, 0.03274655089743676, 0.012469903299314602, 0.023361632915874644, 0.054469782213169726, 0.01382842904046899, 0.056098301279088186, 0.05739609635765514, 0.03999722836118552, 0.04934296094542069, 0.04114680840904194, 0.04754294926721243, 0.02978645610593019, 0.0425304742830415, 0.04214843772652169, 0.05275824985977623, 0.0371244982365639, 0.027738603492898327, 0.09601968310533032, 0.221345707353565, 0.19608516846933674, 0.11837717010489396, 0.1694214016559624, 0.19568706321860516, 0.12365631263462767, 0.13890511656720794, 0.18750274674065653, 0.08877948572438571, 0.10896905881142425, 0.22853176530090072, 0.15137511275468335, 0.14512640934798027, 0.10352078705064713, 0.17911265904624618, 0.22887769996398882, 0.13424109667539597, 0.13305131616371293, 0.190952992246997, 0.26204665642111535, 0.11757126093030938, 0.11248753976918037, 0.08181969184548625, 0.2083473862899888, 0.05408853472721192, 0.1313719901466562, 0.11947492047423318, 0.11524300481523238, 0.11953175653733554, 0.1438263581404763, 0.10109927505254747, 0.15684409187205378, 0.3082358746999695, 0.2569838724429569, 0.11555830362222849, 0.06112299536565139, 0.14322379934451274, 0.14119253253504155, 0.10811464861035348, 0.15372059818717743, 0.17041333230032077, 0.12425744650705207, 0.12119601360492169, 0.1596375395573916, 0.15390851955500343, 0.11275956993021312, 0.17393860845796524, 0.1017142674555221, 0.15825274370370374, 0.17971910956886508, 0.11919241023039627, 0.14737541366729046, 0.1629013192629622, 0.14357886577565826, 0.1234583555149936, 0.15752053218743495, 0.11550263967365028, 0.16086177870390878, 0.14572349827616446, 0.19843983163516368, 0.1504746530084841, 0.12316354955997198, 0.23199026923506494, 0.09522292102056165, 0.10997041233725126, 0.14266864606930366, 0.1436992335103212, 0.20923276942583824, 0.19059878383432666, 0.16019218721457068, 0.18759619414566026, 0.11991874585228583, 0.11890972378633677, 0.22233438978512443, 0.14627472918120124, 0.18790581624113745, 0.09854604189674701, 0.062374587681504993, 0.1453556075331665, 0.07902622883838993, 0.13229468176441808, 0.1392432064899514, 0.10974238626658918, 0.20848701347506818, 0.14428541334646364, 0.14397056653134285, 0.1788469644323472, 0.25228070545821424, 0.2329626952808711, 0.07864994943262109, 0.14853248222460672, 0.10798399997574669, 0.15299027124720235, 0.1613214008149601, 0.11321953678083037, 0.10548743434370526, 0.16986875103846674, 0.2073223912908185, 0.29379254327185694, 0.1734553908388461, 0.1253716830885218, 0.20223858586001783, 0.11420258080526707, 0.142308370240273, 0.12472469885382922, 0.12907510533207847, 0.12379062316951253, 0.1822564080958405, 0.1396278745584911, 0.08886221555932876, 0.13850048424736147, 0.11604606414273863, 0.1036808381397878, 0.25980753463602835, 0.10386140506354072, 0.09928726260700535, 0.1403254895440994, 0.09255947845597422, 0.13380888519027542, 0.08633670712550802, 0.26250762684691337, 0.1518851434511523, 0.11076686032597097, 0.18133708726494543, 0.18420437050442542, 0.21245450622612433, 0.1178581378753147, 0.14752313074085022, 0.13318522833287716, 0.13629286399772092, 0.13985241492909772, 0.09914618751574909, 0.14412735408592608, 0.07610184906591332, 0.1414192639171116, 0.1712537920402904, 0.12922774069011211, 0.11313393411617126, 0.19828914214045773, 0.26795966009939876, 0.08104824896661506, 0.11900357721794037, 0.09868556949039621, 0.12325485957966698, 0.1305503608478654, 0.1372012910583327, 0.21970048757089725, 0.23466630628512752, 0.17391584032485563, 0.17261655520527594, 0.10865428094421664, 0.12823106030062323, 0.10211568220608658, 0.07742646871314895, 0.13895330349764518, 0.07673413207333896, 0.13908692455339816, 0.15781493977673594, 0.2080922943329619, 0.11634888337744821, 0.11201660253948743, 0.21595303059345294, 0.06620021627074288, 0.11596593900673813, 0.15915113501250744, 0.19415487204828571, 0.18523736346152522, 0.14082572963689605, 0.17158206071584456, 0.2676717029704202, 0.16243066548580126, 0.1615276316841764, 0.15904697769832227, 0.14036102070202752, 0.06849673336311694, 0.15933680408183606], [0.03726630111134822, 0.04481445051609509, 0.0825174983530756, 0.009605116548857862, 0.05342414880531931, 0.07009001238451851, 0.009141783699423317, 0.06332274406186997, 0.0793595230507274, 0.028352251411565853, 0.09328474921564903, 0.04036866226083329, 0.03882962609491041, 0.07190560246066702, 0.020549433313370235, 0.04874772595001325, 0.09284002751472498, 0.01799946752256684, 0.038953674882049524, 0.03477862976010769, 0.012015548042742717, 0.024930113671167244, 0.04801270672150197, 0.04216682383670442, 0.044856650469404076, 0.03141204297031847, 0.032243572040310794, 0.035994238926157836, 0.018006166961464672, 0.016329265612688278, 0.04385047825053335, 0.034105330405216065, 0.04122573461744093, 0.021573631581099286, 0.04947695355381697, 0.03753455828935389, 0.027488992894969644, 0.049530100903563926, 0.05306688370183111, 0.024790287303227573, 0.03269382106560854, 0.01906171354705528, 0.08809587482603327, 0.05987970744289699, 0.03336679866357196, 0.04508508256666603, 0.012248458881531993, 0.0939380306930792, 0.017689213404552113, 0.026110796888749448, 0.01666736511153079, 0.038988685100189144, 0.07575442053137288, 0.032973761084459485, 0.006835820264137921, 0.026043162816354347, 0.011554660929006436, 0.020415109371946707, 0.08207632363924096, 0.07176334759400738, 0.050683664608626604, 0.0024493801221627024, 0.03252938412310135, 0.01751936405085989, 0.019770287420420397, 0.048770635809388854, 0.02588469944443674, 0.021869816494384603, 0.011440793450381006, 0.014831093534256422, 0.02060033985593867, 0.044665940541533694, 0.0139050311296277, 0.06356473208495206, 0.028565823318316575, 0.04715414815432122, 0.02572330387098895, 0.03724170202809957, 0.015431511114471623, 0.03223337924047824, 0.009097915589659205, 0.03175672891008998, 0.04132374407603376, 0.06452180189831604, 0.012880739016127924, 0.0219158660395131, 0.05174249005053313, 0.024191344442266612, 0.015681006799211666, 0.008831265281074712, 0.07777706119081668, 0.009993173598852611, 0.00755724813526256, 0.1215343639975594, 0.04378310081759288, 0.022215881392419822, 0.0318838382184866, 0.03098146516769644, 0.031849687934041984, 0.004919908101475167, 0.06266590410603151, 0.08865133453641208, 0.03381177317351103, 0.06680184810031807, 0.03146789461043814, 0.03691695735699708, 0.08064974535016284, 0.027463870956712676, 0.12740406072548321, 0.05555920520677202, 0.021216037059803645, 0.021992440357984557, 0.05814811507720621, 0.04398826299415481, 0.030389194932555964, 0.04996456468718187, 0.011450284322152936, 0.047229875945636345, 0.029135130067926743, 0.006558494520328579, 0.05835304359695124, 0.013730501936328028, 0.06655234092425916, 0.05861712559576958, 0.051551006373859225, 0.027257347058865334, 0.03542559867304179, 0.06936161598611264, 0.02433017872634434, 0.042899111961765636, 0.015749857036186563, 0.03018197964035696, 0.06775726699420521, 0.03980497859658734, 0.057181626212813204, 0.031955607250453, 0.08760082880936323, 0.04974772350021428, 0.07823685950209057, 0.009702764988516369, 0.04354033904570726, 0.03875862123564847, 0.10952312424178086, 0.0552834058931518, 0.05362167691571578, 0.054894524341028546, 0.024105148059466196, 0.0497084959680515, 0.039156182563953826, 0.017814918856827483, 0.005807322327933845, 0.12359396839934973, 0.033023778965035756, 0.015455332618477124, 0.03877883446553061, 0.07565827649687568, 0.04675335393497541, 0.03243404448092465, 0.014030766267810139, 0.08973883464932443, 0.04754676055463572, 0.06503786936762833, 0.025545757248877518, 0.051740586322041295, 0.02414564538236347, 0.05682540298890203, 0.026925121539182244, 0.043821462670401226, 0.030646069959226637, 0.04158724384802965, 0.06419719512303991, 0.034121935360974846, 0.007750046610336511, 0.014491058705795198, 0.055067993460163, 0.041111790530023076, 0.01313416377430962, 0.059155796489287774, 0.07693061830415841, 0.019639935644884265, 0.020379220067913976, 0.03160210938433246, 0.04419695300560805, 0.032842710253692446, 0.06386430693730231, 0.08872869409500592, 0.1158860053927187, 0.0485713035619307, 0.02009788959948046, 0.04642199409464675, 0.024365146809648124, 0.012532556842591976, 0.03572824936840804, 0.10175896102502462, 0.008192299114119622, 0.02533503710442493, 0.03247293110396112, 0.06203420715586794, 0.024380639022696885, 0.06738557645510282, 0.03938221680601278, 0.021768223659525958, 0.03247015020479599, 0.038535689649682854, 0.08110122394657905, 0.01947099027494269, 0.01916993687289857, 0.04810504712945512, 0.018530625008767652, 0.07553885871123883, 0.006364422424080512, 0.09138991500461295, 0.09539794912862201, 0.017802385658386256, 0.04875547492936735, 0.025109954726611896, 0.02751558380682142, 0.04461131081165326, 0.09925488007044601, 0.032588288623599276, 0.03723088486660873, 0.09649732360436071, 0.008918768801395933, 0.10512691336653887, 0.03954882943822492, 0.020019551363563346, 0.06757513725108678, 0.051408586798295866, 0.04879039704739567, 0.024267206298968485, 0.032289456876535574, 0.06808417969413343, 0.015849823849425924, 0.0172871493944718, 0.08088386181982295, 0.025592988484629223, 0.0512948380632987, 0.06396213253479331, 0.012589594003774468, 0.0593995082101995, 0.017563251312822104, 0.1493000410377018, 0.012617715176254993, 0.11917010941092046, 0.05641588685853828, 0.0030359444386821484, 0.02400620014316613, 0.03771928124009602, 0.05358793457309085, 0.04624452982698718, 0.035544415079658075, 0.05667021272764091, 0.05915641319006682, 0.037008485711750486, 0.03760806059524898, 0.03599296338976391, 0.05494806622605651, 0.13431851752102375, 0.02111487897984203, 0.050720287441846826, 0.02164476859052816, 0.05321654280827892, 0.06793358212997837, 0.06014608387504855, 0.03507063949420568, 0.009043348104422613, 0.031737998060341326, 0.04441050767538048, 0.03574800294553561, 0.11015971266334096, 0.06710437622161643, 0.028749879772564577, 0.009222123340042609, 0.07274628436613469, 0.03532496153286869, 0.012536279072294073, 0.02654851654604558, 0.025364684707094586, 0.16958606459440725, 0.052214262316063534, 0.02207471628583247, 0.030059880546985135, 0.019573642226356654, 0.03217449389217842, 0.022510396234030207, 0.0198949778061961, 0.026753921955523473, 0.012429717199636564, 0.011299642707942235, 0.059250170860679886, 0.036323748664149356, 0.11208173533480977, 0.026950808467283368, 0.025412620743736628, 0.01827070478259796, 0.024097364606155504, 0.009413764064740992, 0.049734837901327884, 0.08650202123868851, 0.015767991294964187, 0.07932050619274378, 0.05758685991168023, 0.052733110684540965, 0.03193803319347001, 0.047491272806280085, 0.049806777387857444, 0.02123513946219558, 0.06410016625699017, 0.008649934184617333, 0.046494737973496805, 0.033767673322149826, 0.017736065426781293, 0.053192614051964016, 0.015522450539133242, 0.07635998239199962, 0.029787130263303558, 0.0166650227977023, 0.03983084172491105, 0.059337033739974426, 0.06992297457350839, 0.04147034649166369, 0.10313733706190702, 0.04534414668958034, 0.045871636529843655, 0.07969359101186838, 0.032412375683986375, 0.07543218862866202, 0.10954521055663786, 0.045531949313778075, 0.0063512787493246224, 0.03553932059496161, 0.07911368543582578, 0.027234238016629414, 0.04702349568927481, 0.029311334120950876, 0.01856945800564943, 0.05222906696520025, 0.03615273868725185, 0.011452142085369316, 0.11748261689659088, 0.04556047459763866, 0.02457419305198616, 0.029106055115980488, 0.08498931934516277, 0.011987715110843702, 0.03615955686977795, 0.08199399217001854, 0.026735495625724717, 0.02008762785173472, 0.04525569800828253, 0.06123634956536755, 0.014477893484816437, 0.20785180401177178, 0.21704404704993774, 0.1398485998112348, 0.10081801353202713, 0.11439204967070012, 0.1611048430805245, 0.17179734674432587, 0.1311538236275796, 0.15998653857217682, 0.21813630456885985, 0.14157399835605777, 0.13886132698145606, 0.29012840601705736, 0.18003921174714643, 0.08398708481822284, 0.1313849676760935, 0.16192490955994976, 0.17109466025665884, 0.10749113730966084, 0.09813027065848151, 0.07604279900870978, 0.05277719138370407, 0.22713344033447005, 0.15712827984844485, 0.21813654971699561, 0.13141582569768354, 0.11825730032738178, 0.14239386565262271, 0.12660035788412058, 0.07773008467929979, 0.19582848304942732, 0.14702727267098042, 0.16583964949653995, 0.11103562695244629, 0.11932252260345606, 0.2039013796996686, 0.15458859112714568, 0.17889176525415915, 0.11997334493864929, 0.08267348151533835, 0.21910607995044803, 0.12684064136157114, 0.18015760297496475, 0.09090968512839849, 0.11322499132685124, 0.19459659834542584, 0.10318287332812626, 0.16428326526957174, 0.1499576355901457, 0.1394171850575555, 0.17486958914706785, 0.16732255056981118, 0.20473500593535363, 0.14719991824559628, 0.09517434338528304, 0.12562715042863162, 0.09791253314864251, 0.171739170027356, 0.1787687315335197, 0.16055067039785847, 0.1421509085283164, 0.1591687550347659, 0.16508362796758452, 0.09986275551660408, 0.17999470203874574, 0.22612422674653992, 0.11115712083635793, 0.18259855828458266, 0.20755085403159743, 0.14919268147599313, 0.1280232359685244, 0.09703773734790665, 0.10191170363536767, 0.2353755504854264, 0.10102377708760962, 0.1030007589067663, 0.16410233062361518, 0.13816527481521332, 0.07822117768228054, 0.1267807103032547, 0.15476405590532288, 0.1922044275148261, 0.13070828221257658, 0.09689917502504203, 0.1188157324589068, 0.15376397408545017, 0.10889105573897401, 0.2078232442539546, 0.13263542235137957, 0.12057025000573167, 0.21647937896270908, 0.3076975293938191, 0.15208259495275636, 0.2560451389440606, 0.1409206479307144, 0.19398499971195576, 0.10111349364442211, 0.10347718132599708, 0.06445562722341669, 0.31227803038012597, 0.2019650771492912, 0.2422905358816347, 0.22379895071348838, 0.20079288601634965, 0.08669253198369857, 0.17256668288140528, 0.0950273311126136, 0.0608289631594333, 0.17351578921079638, 0.19463024492706024, 0.15953336692144796, 0.11411278763966215, 0.15507085879723873, 0.19320296183709176, 0.16734112054109576, 0.14961511767919988, 0.07755040641753905, 0.11912754556584744, 0.1669642512476252, 0.05620366901219372, 0.1122280351457096, 0.16591935328418211, 0.279592429437945, 0.10166031188301503, 0.17798745974657998, 0.1619544652320685, 0.11395851285347056, 0.15784624212932202, 0.08394854293475229, 0.1543180241940483, 0.08165013360520525, 0.16292672273853134, 0.19900575610658816, 0.23596277220114587, 0.15613867811137633, 0.18107125475522012, 0.22697853735618054, 0.12195474708512907, 0.17142407806409946, 0.050096236049167575, 0.09440133002616706, 0.11611626077924045, 0.1929526196251954, 0.15062734965355168, 0.18364357882209364, 0.17259101383388045, 0.10376275592153111, 0.1808533333842793, 0.12382332746300007, 0.10621230673765945, 0.15151055709969613, 0.25618309605746503, 0.17078010455494927, 0.09617784961817727, 0.07523266868966241, 0.20935284604708995, 0.14250991265139273, 0.11739191208635608, 0.19860780407344142, 0.12879617271884797, 0.17917590726527477, 0.123525005164406, 0.050262243471919536, 0.113569148665955, 0.07917917063159328, 0.14120615357833524, 0.08926396738857993, 0.17760855265923087, 0.1049995972144027, 0.15092898911285788, 0.1912949738963958, 0.07626880260725176, 0.12041692516856617, 0.11678500957186184, 0.10696277412916384, 0.12403901951808123], [0.040460910738235524, 0.0238967893810402, 0.06117826860938823, 0.03763166376419606, 0.04534847508635252, 0.03571955810090707, 0.07097363351814209, 0.02396938578796483, 0.010746847068320119, 0.10999883419924206, 0.010627204244355521, 0.0070309280154986255, 0.04621153825052804, 0.12032323261542667, 0.0540102482022297, 0.06212986089409359, 0.017097952490251873, 0.011202306449112874, 0.04874701731868329, 0.049009651411324746, 0.008569026681324168, 0.04657287894177341, 0.0219894238867827, 0.007936071431744964, 0.02059996255763596, 0.01805505677757244, 0.04359830891893756, 0.10054258960148982, 0.06941672835138536, 0.040777753212399064, 0.020029926109277917, 0.032848789161371614, 0.03266540303405735, 0.029090480548479868, 0.03898056073775215, 0.014593067143352763, 0.06947306645733696, 0.04023285785449609, 0.004625622607437113, 0.0726316393082661, 0.07676113667266984, 0.016459795503666805, 0.022785366257472385, 0.0427590595978883, 0.01861810841928086, 0.04181661057255922, 0.04702964737530678, 0.015584531431687216, 0.03369182678720644, 0.10452856039327961, 0.05293168450495409, 0.01840945479700402, 0.044696446162678545, 0.03700054521041532, 0.037531490107217146, 0.14344905983776818, 0.005524441967868517, 0.010892102126813224, 0.05520835992008929, 0.029447376014544602, 0.07183568161581794, 0.05827633138265341, 0.021890590883671276, 0.04418007991907578, 0.07535566410590565, 0.09604209117711553, 0.036679562031021046, 0.02657415367843163, 0.031505965349835255, 0.06681147782552628, 0.02739947360579766, 0.07466600877383063, 0.041735474200498675, 0.0337664514119106, 0.03532352128757104, 0.05928790835182994, 0.02144516246663707, 0.005390240600512874, 0.039379221402228846, 0.005828179071672382, 0.039328617464390495, 0.020808953258599487, 0.07789739828196265, 0.07082445321664696, 0.057560341778181257, 0.009689054887501464, 0.018578139697051337, 0.10637244975735104, 0.09029597975313665, 0.04194419102502927, 0.036283732061424566, 0.04848250631062735, 0.033078535099423705, 0.03841433749203721, 0.056615196123358705, 0.022075991822226394, 0.07134340117655455, 0.03994638693609065, 0.03459376125265995, 0.055190487088815826, 0.012217475413044375, 0.07225935888146201, 0.04940368490473879, 0.02593136952078391, 0.01525442414511476, 0.03665474461271398, 0.04120103594276213, 0.026926389414696928, 0.056366983635891835, 0.02338030630902898, 0.021638618819716, 0.019940230619883346, 0.0676189881238726, 0.044937583828164686, 0.05228356262969394, 0.044824528402739, 0.026627373806531393, 0.03171594238900129, 0.02218512870791939, 0.03567937295883894, 0.040260456171968294, 0.07121960902887006, 0.05052444855532339, 0.027741610388001128, 0.004383304208937672, 0.07530027594898017, 0.035773348964510426, 0.03663575329307107, 0.0412362874785979, 0.002376559155715269, 0.05738092015587515, 0.01330073522929583, 0.029187867560634212, 0.1560255116032016, 0.028657005018284245, 0.04815402696089399, 0.03633282680605208, 0.060814913106902, 0.036148548186306036, 0.009722369178498705, 0.0604658451442036, 0.02949467428298968, 0.03882583779012484, 0.055232928359820965, 0.006719266210923032, 0.013184563741238128, 0.012925396196454043, 0.04250009123596453, 0.09346317109321395, 0.061831419851871273, 0.1076969468305188, 0.0423278785010259, 0.025005443096761743, 0.020056262296894868, 0.009355244523425017, 0.02178267973865713, 0.026854585908773928, 0.035392082326354525, 0.022305573051374768, 0.021804162759273764, 0.06013480706080314, 0.06845612304225084, 0.04463239738176908, 0.01453571109807179, 0.040356358888769345, 0.0714509369384858, 0.07743938495555232, 0.030564349445123828, 0.036601053340540785, 0.05424546400806116, 0.035113019478176875, 0.0501398915695327, 0.06637639351068966, 0.08047951295250848, 0.007705831845786664, 0.022503053281275977, 0.02363285676936709, 0.0199470947676849, 0.02571844304310939, 0.11750360770571618, 0.03750101896002889, 0.043256204695470875, 0.04544053204177369, 0.05424785803282454, 0.04719154473634497, 0.05798581552000777, 0.03809566406773464, 0.06877742797857331, 0.062289571074107965, 0.0434791018074799, 0.05876847009565081, 0.10105713255583279, 0.02673742042163447, 0.04755833997361122, 0.040178059585272305, 0.02027844120147488, 0.042527513353214155, 0.07440127943071627, 0.04686533300686748, 0.03204938407326418, 0.02531474152009093, 0.023496518016702706, 0.053675295409536174, 0.044830745206244534, 0.06949107718443678, 0.051041703460918325, 0.025315017311743675, 0.05167908861391968, 0.026422960480915445, 0.028628154147055843, 0.06549672539075536, 0.0531539534248652, 0.06983811501413584, 0.030244846730643225, 0.012473969310972721, 0.0774647041614498, 0.0585268919296082, 0.03789215281064953, 0.016497596197070617, 0.048812839593137466, 0.05693021530826246, 0.0622535496199083, 0.034771562599006205, 0.06678528527939512, 0.046146516537954735, 0.08304098921437418, 0.024234779712353504, 0.00840054958262631, 0.09069374792518155, 0.03413724179770197, 0.039277354690937266, 0.04979980598774649, 0.09225619956851007, 0.0517215260544852, 0.07357717566793004, 0.047702322368540113, 0.06689537977499348, 0.048541257593540416, 0.059166349350444736, 0.024355842671807737, 0.029285532279661106, 0.018254208994368394, 0.024383435243620508, 0.05255877205561246, 0.03494737594718895, 0.052403336646215576, 0.026659149218410737, 0.021891812793910507, 0.08790815264106759, 0.06397863789912193, 0.06767290539198345, 0.01185528053376343, 0.046615948404876456, 0.027689562374425512, 0.044531886646103476, 0.07024695315668661, 0.029491043026228587, 0.028018367311526692, 0.09907996687557429, 0.02912608065432118, 0.025120542061725454, 0.06621454211492693, 0.029557526051517458, 0.04815721771709862, 0.04704257127858939, 0.025589828371941566, 0.04299040665970214, 0.029995329978485263, 0.027403702411139687, 0.10011221672738753, 0.09200422558933498, 0.013636755757033827, 0.1420231863495804, 0.06485132695806604, 0.09566196600996679, 0.041748145294766274, 0.0622683159646488, 0.03207123481608447, 0.05043927106946226, 0.025225674222794273, 0.049809765130762136, 0.04200100027505429, 0.08780858419354885, 0.05440746862140875, 0.040956581116563855, 0.015825514921978596, 0.05741866913834407, 0.02239265809616735, 0.04288940179732539, 0.05430154164411849, 0.0810614486615504, 0.034203067902595766, 0.038194106366004676, 0.038542626575837215, 0.047871478412660866, 0.09219508873479021, 0.015737261593101487, 0.06934830137798864, 0.024348739121529846, 0.06364510236908832, 0.045019513101226864, 0.012326463869202041, 0.04145451911514805, 0.05357159391766595, 0.046808914461683844, 0.03307055629369232, 0.021956464869060346, 0.04817653079366973, 0.02611012081615627, 0.10605454625141238, 0.033166282810270786, 0.05291548557579518, 0.04738125491947417, 0.012138109661698824, 0.0129535049200058, 0.01822286450694646, 0.038666062492636905, 0.008953180513344705, 0.01980243630016283, 0.038602722343057394, 0.05152177245866868, 0.05196491601846872, 0.03838884591635677, 0.006054462292306727, 0.018490508814612706, 0.06002284331066955, 0.05854555383144368, 0.05108472695874591, 0.022785057907082865, 0.050300701085718415, 0.014358634662423885, 0.054439288083343744, 0.06633429697925045, 0.07399407305544423, 0.058802553347402045, 0.04412785570527758, 0.0038101974238205945, 0.06208615174757377, 0.012620117819507518, 0.03252363846366925, 0.05913888126791966, 0.061976022778018836, 0.014663343261476728, 0.018511530267254963, 0.046206279056927854, 0.006818631645141831, 0.09619584502351862, 0.039340143257211295, 0.046524128936711824, 0.008936498948793498, 0.020396148695820765, 0.02306633091892206, 0.1853718578575119, 0.22842552422756152, 0.12241803875733769, 0.18668387535839312, 0.2977953220327055, 0.21629487434702538, 0.12633078686532476, 0.132749400912754, 0.0959553010761738, 0.2689456152579477, 0.17332114159099518, 0.1645683572297135, 0.15808326973309442, 0.16288107922000272, 0.20255838160312947, 0.25308373414220353, 0.10315871091499444, 0.10838816498195934, 0.16900848026477522, 0.14929296238528145, 0.0905825962282477, 0.2470245608879674, 0.12835006439878097, 0.08452813441474592, 0.11245969247313277, 0.11175293039770857, 0.1670365546259188, 0.18488644922692932, 0.3182001658264668, 0.0937954234259744, 0.08370307304205434, 0.22034364902684767, 0.1429042334277784, 0.20303865744461938, 0.1216836438904847, 0.11899192502061207, 0.1639355839260163, 0.12089252787371799, 0.16341473606805648, 0.19234345715132453, 0.13481299663262983, 0.13846752714485894, 0.16674902650617784, 0.20008604733213303, 0.11488052265297984, 0.14798603170821745, 0.17980750079356855, 0.15177865722967734, 0.07716679555033484, 0.19655994379953032, 0.18385192409398096, 0.12922141280385757, 0.12292086822731842, 0.20462747783430163, 0.1430836205761279, 0.24301531634503798, 0.1772332155416089, 0.23942470820921086, 0.12691756425004813, 0.09398591884922597, 0.22047984413802627, 0.1347230732320778, 0.16278488922023004, 0.15525746249383496, 0.10895741427497518, 0.23853383988382357, 0.0979257558262156, 0.118785165550728, 0.16362164109464616, 0.23688111243949783, 0.16626715720180543, 0.12647749270282446, 0.3205712692391488, 0.09147714943655076, 0.14484335518171712, 0.15423194655487615, 0.17200106484515054, 0.11657766787515533, 0.18727020841212044, 0.16164637531243986, 0.1004379956171878, 0.15569195692096988, 0.2639533573340985, 0.26227372488187206, 0.20412831026459896, 0.2165296190087834, 0.15434405586171537, 0.19568088854993546, 0.13534404878174106, 0.18165864501028292, 0.09650192779278564, 0.09241359999343272, 0.20229379015584148, 0.15071442320702538, 0.1960037639665027, 0.16832968039858728, 0.22417195892382055, 0.13461597414026338, 0.17646014089545897, 0.11011393124898596, 0.18290787394489014, 0.19716236469966752, 0.1216210391853125, 0.07662275821090707, 0.1338713060343458, 0.15567954629659653, 0.2036118597513245, 0.15064449470129707, 0.2653682910867276, 0.1421443201721676, 0.07257137883214221, 0.08238378536677168, 0.11111963615422288, 0.10922804249510651, 0.14167424862182912, 0.14413078615982688, 0.12293720122186408, 0.12977472746804838, 0.10496836380972978, 0.23310249100529382, 0.30689258549001913, 0.2461732073777145, 0.16003210548191302, 0.1971409755248216, 0.10031318457256402, 0.20143967872906118, 0.13467088732267582, 0.2533482030154236, 0.14650204279009374, 0.1528882589792052, 0.1459234012591262, 0.10905323655254419, 0.09189709585400359, 0.22958427817831117, 0.11993045167576884, 0.2879675477743149, 0.176563915165682, 0.13436129587071557, 0.20534606830727672, 0.10164076898006663, 0.13620117859494302, 0.10840778449370016, 0.10754136203397667, 0.16123572154150856, 0.15388280964426457, 0.14087004016243643, 0.15058869285689247, 0.14822505114059295, 0.15637041970847115, 0.2044223501316963, 0.2687569737674729, 0.1554617321779651, 0.1354662244839053, 0.17996782767436198, 0.17878647412984602, 0.10540050634693716, 0.10332545761259333, 0.18169075941606877, 0.19168108221023314, 0.19156000967467987, 0.19921967849856426, 0.1774388948275197, 0.09992350628899951, 0.14018108197037252, 0.14651682828703236, 0.12105041859491218, 0.1463588916005627, 0.18676279773635251, 0.18749119413475837, 0.1526515378106025, 0.23545323180094843, 0.1833585787925028, 0.14890985713610727, 0.14841536270274272, 0.09589654979326072, 0.12426693833643392], [0.043071864788690885, 0.02490436545603218, 0.03906358551654605, 0.04335008494015183, 0.006233551145170726, 0.06495756037052601, 0.047782439843661366, 0.04965290479782609, 0.008394722526352252, 0.028306232509954322, 0.06146190500247383, 0.021126146217988386, 0.0055317557135206325, 0.023072708600891695, 0.039263220368734295, 0.031926974714283025, 0.026773978137381138, 0.011885115827974534, 0.03130733790326744, 0.039699166532485716, 0.030017688254555388, 0.01301385636907071, 0.020239305599863013, 0.03191266419185746, 0.011170416124044888, 0.008956696856917154, 0.03336531628343848, 0.05921548622990808, 0.047453385927984794, 0.045159799121921106, 0.04059979864846795, 0.056339649618753505, 0.03439377783046615, 0.04614705279950173, 0.006107695826945166, 0.033376482014934865, 0.07048712938182777, 0.0517534374469711, 0.02640904257855108, 0.041492134032230225, 0.06045172614375911, 0.07714658615089233, 0.01955126288286861, 0.02686778177326966, 0.01855197204877773, 0.02947812678382522, 0.028896794369023655, 0.043187118886459264, 0.045565925313219915, 0.03097898112760196, 0.03080807648779404, 0.033765152892878944, 0.022805742281038436, 0.10484762835286318, 0.016024231426267615, 0.08592308093343051, 0.022647723240116914, 0.02931664885592557, 0.09429574778844273, 0.02013462926110914, 0.025927678892208685, 0.0273832478635614, 0.05995068548908157, 0.03436480438516986, 0.061096959867544716, 0.04702297857992592, 0.019811991331798416, 0.10860271556603332, 0.047370184948968316, 0.04230637058255173, 0.017523297912351066, 0.030380511325934244, 0.07071668762833842, 0.028161554890234145, 0.009426570182005245, 0.016419010897797924, 0.020777723684366194, 0.014926829626933943, 0.022450522632308068, 0.023152345355840463, 0.05216988667304959, 0.09428002000335725, 0.08173000593219074, 0.04628815470383533, 0.0276194385162765, 0.07121213967160833, 0.007504954973551175, 0.003234387545343188, 0.04338544372829699, 0.04588367560157373, 0.038935269619668686, 0.04444222754588531, 0.056802880003928184, 0.08797494018630636, 0.03217658148177209, 0.028465818200681, 0.0132211406091829, 0.01516682773663272, 0.04260945411759519, 0.01838947905437841, 0.01770248970827989, 0.0029786843937941857, 0.033572949093556216, 0.07030044141555987, 0.06168135854926321, 0.05701111419306648, 0.01780306173097943, 0.012139359342625305, 0.033555516762839216, 0.0646019576778335, 0.04430636568295379, 0.04093943606881846, 0.04892679517187419, 0.020513961527256236, 0.013721847058003469, 0.02408962328768065, 0.012394505883416822, 0.11976202724561577, 0.07056116411883025, 0.07206560758453223, 0.046415321468826265, 0.026901309611275796, 0.0342300265366512, 0.05184840936694415, 0.046689768637260126, 0.06634615602031832, 0.052819556045916774, 0.04126284391649308, 0.06579232807721823, 0.05102075861706849, 0.036842535745592854, 0.04936258811804076, 0.013163318207878019, 0.03099730978119037, 0.08965296385389182, 0.0536237913183868, 0.05222471175535072, 0.014951821330243783, 0.05312354356471089, 0.04852803874640696, 0.04380301527318455, 0.11625963413426954, 0.022485161297804406, 0.09354721859938676, 0.032828208209285815, 0.09052396751940252, 0.0269982963424897, 0.0508140451124599, 0.02933502922044887, 0.09874714763774987, 0.028006249715784387, 0.009755627928121437, 0.0315731416846956, 0.007313040372419863, 0.011670544176482627, 0.03953261901774714, 0.010336600281598588, 0.03926450356600746, 0.05788166969714146, 0.0565552918781196, 0.03726472680066382, 0.02973106028812547, 0.032557078201564095, 0.060939352598882494, 0.03177567617967725, 0.028394426467017304, 0.019435890041471972, 0.038616266777558673, 0.042498275607583985, 0.069582678317543, 0.035474111190846855, 0.0960869915903576, 0.01599965915609632, 0.06066185257007038, 0.026446029303535342, 0.05858248309983362, 0.03600951088892837, 0.06576990468367454, 0.01924054145122007, 0.05523609996382749, 0.04269784917273829, 0.018723227173811006, 0.11397756546014741, 0.03539114386864728, 0.07395393004821194, 0.038703393957187096, 0.011747439294272374, 0.02635288833370132, 0.05895422726509072, 0.11807137844903816, 0.03804322917975726, 0.13611405907619384, 0.018438035622239113, 0.036443802302763346, 0.04103705099213027, 0.01742100985270114, 0.0423783483734775, 0.025013758981179808, 0.007728551140791106, 0.07379632277954971, 0.059249347316161285, 0.06560101293988767, 0.032881129563095114, 0.03602818811252233, 0.04417178318685582, 0.041150332413493626, 0.022297577008665092, 0.003445763173775988, 0.022179752685910752, 0.05095899277817338, 0.05414534780767657, 0.06516788981013721, 0.09171937877732901, 0.014346063159586442, 0.09531693533062936, 0.07111011208185265, 0.019188328728740735, 0.040884932743445526, 0.09424066606668696, 0.03691409218816027, 0.003245363191273364, 0.07474296996670385, 0.05433891141306489, 0.02587298021441506, 0.056492855712290735, 0.06440488155931234, 0.08218772814518983, 0.03771728941149289, 0.025286308166781263, 0.019078638344522447, 0.013703447541282063, 0.05716066604720489, 0.04196660675769372, 0.04255547939289001, 0.02488620151134749, 0.01455544648061116, 0.011784075534031277, 0.06884806894607122, 0.017836344420849796, 0.02861382638765199, 0.03564476493685957, 0.03741635475307703, 0.032821321078846534, 0.09521780355322747, 0.08039112938868423, 0.020028602692388722, 0.006196530903839777, 0.025928058105731205, 0.06645836491858767, 0.021794542610164613, 0.06038446745444691, 0.03942740450222646, 0.047755289687624866, 0.06947621507870574, 0.043471965698465224, 0.03407359904339237, 0.04294989593026619, 0.02968344983885125, 0.045939270602238756, 0.044227136869824706, 0.01216398140851168, 0.007078998117527414, 0.02767217600898397, 0.011750761243034036, 0.026124823958643024, 0.07286943299996276, 0.024749642508404873, 0.06488684279423568, 0.034802573838181076, 0.06821871239451632, 0.025610920687716816, 0.008936414679121828, 0.03137770499433241, 0.10163939002180293, 0.03232478502116377, 0.022477094391961733, 0.044360857517007864, 0.007895961462054402, 0.08308225070997592, 0.05804740898911992, 0.029679583010053443, 0.004145300321866789, 0.038370907967609745, 0.03987338641778596, 0.03947812335325345, 0.025966954304866736, 0.013749860978174596, 0.028595363668676828, 0.07206375365175548, 0.047440515650856885, 0.06766531346065384, 0.02435737676287611, 0.01413420728978611, 0.05156237894909517, 0.08366749591885075, 0.06754955757529506, 0.11159553763366516, 0.04771999218651364, 0.02473161071388712, 0.0539960181190362, 0.05411244433132872, 0.03013913234275195, 0.03460804113156853, 0.04012383588199173, 0.03348453488621501, 0.03853853949676118, 0.04745443546844106, 0.020788402950030663, 0.01766516781982876, 0.07076768610145777, 0.04013751438187976, 0.07974007722711371, 0.028337264816547116, 0.04027221179116638, 0.010387148678062424, 0.03864439369569864, 0.09484939953132022, 0.07945411958761754, 0.021107428774778402, 0.13703310411543618, 0.004364518296619457, 0.030234023823492953, 0.028950740365431677, 0.028163060253005356, 0.07134069688618183, 0.115473382775822, 0.021305100526660684, 0.006412690751359708, 0.028196409975569096, 0.010802376951511589, 0.030343283283253832, 0.020024622865622083, 0.006160329897782856, 0.08945333666258282, 0.035355030483896696, 0.03418574282418817, 0.04006378991048663, 0.08384276917504688, 0.028617061193912264, 0.04904679518433348, 0.03137992664931282, 0.042352462262516065, 0.040136809580989426, 0.0437002407477027, 0.03423648465785288, 0.07666225004340373, 0.024136724288485224, 0.08110227348703532, 0.09920224983004794, 0.04574246261449111, 0.03318309460976913, 0.034640144046035506, 0.08101216622538145, 0.25712690105842007, 0.10368750310472905, 0.19671712971983418, 0.17930295528663745, 0.2104477695519886, 0.19367211408192114, 0.09297862048110656, 0.12619656826099082, 0.08361906384027774, 0.19753514308362238, 0.17355778615080542, 0.09712281141189799, 0.20681660472145005, 0.1730380261376981, 0.22095749995881514, 0.16408533879345463, 0.0864653486097532, 0.15567444415102083, 0.15726222266112605, 0.12174398863628028, 0.08034836636075089, 0.15315311089638742, 0.136604723069937, 0.11663728483742285, 0.19249033152816758, 0.06423691295147424, 0.14602942782784664, 0.1661483676082665, 0.10096199975739564, 0.15869483772304752, 0.2330839516775262, 0.1851166739699341, 0.12622013312554167, 0.1495466447405277, 0.16351259613950409, 0.14921800834276985, 0.10186949985161906, 0.18658235338666748, 0.17960168361183138, 0.11974995369992911, 0.17172125889168632, 0.2341750907080789, 0.053887363868735494, 0.14796919309564177, 0.10244724505971517, 0.10990459772367632, 0.09194344417342255, 0.14090226182053167, 0.12545839658067112, 0.13320568288045545, 0.20455168109507332, 0.1225492466361292, 0.2006727327863055, 0.07548524021741844, 0.3661958500742913, 0.07992190819594168, 0.13146585123913904, 0.18094794524292793, 0.15592219698573315, 0.10094487003140873, 0.23802118916665357, 0.11526512177360636, 0.1762786853097139, 0.13985059163983793, 0.17078034970308506, 0.10786471242505698, 0.16367980248985753, 0.209069071758178, 0.1326023579965676, 0.11592417189310636, 0.14430694041713593, 0.25628380597599093, 0.1192918177994509, 0.17343139696505763, 0.1447196626254628, 0.21116531814538667, 0.1276506491065506, 0.16845190206602698, 0.08470217426938396, 0.21784797971767766, 0.18076927821722724, 0.23910074494779113, 0.17457187205793398, 0.12465560538393837, 0.270375165968172, 0.11512403136059163, 0.1436417615942417, 0.1824329453971117, 0.13211082066259078, 0.13651247076209516, 0.16308905676968638, 0.16685597238040742, 0.23065320065905973, 0.18495974851952446, 0.1044872682541609, 0.1558663491760531, 0.2075553586285922, 0.14747892746761923, 0.07882500818419842, 0.07447339894790804, 0.06676513716698655, 0.12010386333830896, 0.16982211160563654, 0.1567409151504117, 0.1392569347855545, 0.09574002270857174, 0.11866146533359444, 0.16652312249906603, 0.2030665277233047, 0.10922068039015417, 0.16898885309215517, 0.18017226589783547, 0.09264816079408893, 0.15356374934556025, 0.07665208405664853, 0.11686233848693872, 0.3131942102505315, 0.1619017430611195, 0.12700576395277055, 0.19007726181899348, 0.11740899584706753, 0.14475816620453713, 0.10245088397735551, 0.1486414046056809, 0.176954681294099, 0.12993744454316555, 0.17101812807302322, 0.2365454586763536, 0.11679410303552305, 0.17650581505750457, 0.11501560693666821, 0.1307312495285465, 0.13256987586857813, 0.12279860059460326, 0.1766798702339011, 0.15604771283124724, 0.18659856380714526, 0.1521443263176949, 0.2106095979651136, 0.16927284188568595, 0.2193540932550546, 0.11857059198401629, 0.2540420641702029, 0.12063431793883925, 0.17625458418361603, 0.15207452038603445, 0.16545078326617518, 0.1014134323885364, 0.2949948416602227, 0.08212687778136424, 0.12686412961732957, 0.14856084279956358, 0.06518641381614632, 0.1755070815523786, 0.10297156329597197, 0.1032668365646274, 0.17425699459929622, 0.20376526119728244, 0.12099067139769755, 0.16973725970714323, 0.21570340850420539, 0.21799986430954552, 0.13642017248897784, 0.24353717543905784, 0.14027869689368433, 0.10389774061378934, 0.13327395663626734, 0.08057459978567016, 0.22185016092994522, 0.07602395324577248, 0.20801202364025578, 0.16135946006303833, 0.14324105164456752, 0.09994590669990548, 0.24358655746665694], [0.05489123399339376, 0.026421106548138687, 0.046367647817298296, 0.041946313088579525, 0.020582262096145464, 0.05476015634954937, 0.05597544375867133, 0.008999973163759757, 0.024147204371289383, 0.06425924058402739, 0.02342392160977808, 0.037165924441069365, 0.021105364167822466, 0.048680229773444515, 0.04108928669724734, 0.04679842671800045, 0.03670990677370179, 0.09951457621589785, 0.035249187776278106, 0.03601951216677985, 0.01253617469281439, 0.048069182723279924, 0.032364916537077196, 0.030716450456830285, 0.020491335120412613, 0.03148612941825583, 0.028748286309682076, 0.07848542439000261, 0.03745403478763277, 0.03283342143761055, 0.0675803313272134, 0.08576571881290405, 0.02704317185787424, 0.0362636222534122, 0.046367368195205934, 0.036854613121719136, 0.016229229851535732, 0.027232510488360163, 0.09754297233396962, 0.014796959529180202, 0.09458676160823914, 0.031802753557360945, 0.020059207904963725, 0.03656356865840574, 0.03883224228517183, 0.03874781939591612, 0.060928734620251966, 0.06323067178469031, 0.061791855241021806, 0.011407000354431089, 0.06801458060621254, 0.06506469010585739, 0.045979965192776535, 0.045122674501110474, 0.016851122791488326, 0.009930166697520162, 0.09046183778874337, 0.042634600953709696, 0.025377164279381116, 0.016058499496730588, 0.026059135749575593, 0.043008765956807526, 0.01775309939177767, 0.06206002814935581, 0.05397195146689492, 0.045485719737987367, 0.01999028488963602, 0.05084658469704371, 0.007093108978287708, 0.02109403755786198, 0.05759185480494654, 0.07002892453343638, 0.04611917485993716, 0.04017614436546161, 0.03850646722581118, 0.032454483706744454, 0.040053957171978495, 0.08242195952803859, 0.016156014828612248, 0.013114409239572144, 0.03283697608557921, 0.076739149949243, 0.028274719483189048, 0.03110978489501342, 0.026698968553495024, 0.06275939364587108, 0.03645153596035896, 0.07100859777100625, 0.03372284185682093, 0.018727699212068995, 0.038114957992107644, 0.09141773931802281, 0.04233412977848803, 0.032864769755472104, 0.056906458921730525, 0.05955735296611825, 0.024030877750427015, 0.03710002555782276, 0.07779078948641978, 0.02988155443041075, 0.07753870059405604, 0.007479507926731341, 0.05457677788311436, 0.00865793022732701, 0.016310580728215077, 0.05081308367211492, 0.05641522419248378, 0.03290132364077914, 0.010850059221528712, 0.04512361295881771, 0.02646120742053515, 0.030479637357676705, 0.03844169449181326, 0.03269074905303217, 0.05162525561548049, 0.02921101682248616, 0.048400167180525686, 0.04218557383865119, 0.03185463494681303, 0.03546388008661809, 0.044005890677292506, 0.029289341651864594, 0.03013945793011977, 0.02806015740779619, 0.00814392066170131, 0.009123251074925065, 0.03148706596074326, 0.006643181231113212, 0.06623035416968408, 0.030956260874987613, 0.031653647949438424, 0.007295439023554566, 0.06942990506368299, 0.0873794677036424, 0.09791280894029526, 0.0606008796321769, 0.030488016444348523, 0.05670096349692153, 0.026563878524147218, 0.02932271244184625, 0.039833967363642114, 0.046857009461570176, 0.08892928655709952, 0.054259782191365964, 0.0599495440180744, 0.0972665831326477, 0.07764753870545857, 0.031238593003382126, 0.029298147832554196, 0.011396341198574633, 0.024579570989214608, 0.016259905927243735, 0.02540350812787731, 0.019781068192734834, 0.0534371416565151, 0.028259639042399587, 0.05370661691432038, 0.01674452548726432, 0.03746038182608543, 0.011503934417100204, 0.11040493740790314, 0.01865278921961304, 0.04412930744189409, 0.010698090359989193, 0.08643045330480223, 0.010882464740725776, 0.044522563356064984, 0.03692409729645137, 0.04454816984493406, 0.032002989788569754, 0.058744020399547396, 0.06441781312347421, 0.04570779330547779, 0.012602168379441626, 0.036253988697764375, 0.03346232982772974, 0.019416944687104514, 0.023784938628875443, 0.007421496876275108, 0.045043732970952995, 0.022138156026842135, 0.09564511973651187, 0.011868297325206861, 0.029864463008820053, 0.053223713391250184, 0.04872106225980867, 0.06948157003329647, 0.05726706416856858, 0.01402980195463545, 0.047142116743470394, 0.0026273011697471264, 0.07340363377044279, 0.038891142955230135, 0.015848686208858365, 0.03470977377747336, 0.004670496207601842, 0.045589003711938865, 0.03380303594073461, 0.03207178639938995, 0.04415972879336726, 0.03656624996614072, 0.013874900891565749, 0.019985054424332998, 0.05226888821550435, 0.029710042665922837, 0.022425642011747248, 0.033692018309187506, 0.03706421860824189, 0.04175923441747024, 0.019436859142696186, 0.036690547731855226, 0.04301142045146516, 0.03160965918082624, 0.032786667091591705, 0.10167079196581918, 0.04170391520845794, 0.02621328987691912, 0.05251042424671112, 0.07800963016286974, 0.02625704115827478, 0.039902313897806796, 0.03748885731423094, 0.02047796688613392, 0.04362080509083406, 0.027927057291831703, 0.06353715675011759, 0.04141283244074833, 0.08453537394563038, 0.0351096065564742, 0.028582943468204433, 0.017720996477310697, 0.06440036930143833, 0.04433788637059831, 0.047112331244974374, 0.01995417342010525, 0.10269265366537918, 0.019217175769529516, 0.023027292993520538, 0.024800763555592107, 0.047832285354454676, 0.037777523074539444, 0.05260369162105265, 0.01741375116961858, 0.08550293533311737, 0.05837604921731738, 0.026077033478706598, 0.018306329786296816, 0.013466185323082873, 0.055651702662749644, 0.015284368606855073, 0.07688915762569636, 0.019941584680289514, 0.1040618519689287, 0.08084821574870618, 0.054613366242377996, 0.027245367358949397, 0.007563301666279234, 0.056472826343510425, 0.05082961584952089, 0.016220199590128277, 0.015551993762323213, 0.028504898260918357, 0.05461391782568348, 0.042853433969280416, 0.022858753650178833, 0.07698548552129539, 0.008684905140750833, 0.023137525384945255, 0.010157451578115505, 0.016826037242407763, 0.06516759103584675, 0.01354360999915028, 0.03715664328586671, 0.019021032363056176, 0.038612164376724156, 0.0044346976961429805, 0.017276615685512944, 0.05114729718996152, 0.03173339961757583, 0.0401378974258419, 0.02852921963729445, 0.0400515784689736, 0.007829272071830928, 0.0465426491122813, 0.015594732850008916, 0.05093880253092897, 0.03402641951857555, 0.034472730851942496, 0.029329206952224338, 0.035928301738515016, 0.02265534198452388, 0.055260806299385526, 0.05415357559198334, 0.018360191513033166, 0.08229727871836194, 0.03351951063039803, 0.016010483020856496, 0.04129786179551194, 0.05034355221376304, 0.07123666214606456, 0.04756922608301525, 0.03544526798049769, 0.03437811516285424, 0.036325583444728006, 0.04220494437181661, 0.036425412362140995, 0.03471618976383921, 0.059803366781242435, 0.09948414720354543, 0.045200532016855095, 0.07490253075957298, 0.016404378618444168, 0.039810743408217546, 0.055074620120708025, 0.016472411056559895, 0.0662119757203806, 0.030152699759890957, 0.043360350518337185, 0.056900567705592806, 0.03466647831843265, 0.062244739608779076, 0.05231107284705486, 0.051969999011846325, 0.048616824506391446, 0.03462673367692098, 0.014653996988800506, 0.16620499682762932, 0.018291827741890185, 0.012677643361741738, 0.08222170414463167, 0.06195618493121959, 0.02256806541775023, 0.040226882368686705, 0.04025448068615891, 0.049496603709074764, 0.044295927734985474, 0.03802592708398739, 0.081398596296147, 0.010290549778860184, 0.021933269641932943, 0.06781558926788069, 0.01906381645840743, 0.04171806868285902, 0.026961725220204364, 0.0367931843615107, 0.049038548247828606, 0.0449984724963865, 0.04199794741467603, 0.030772332740466923, 0.016631468146618818, 0.014639029545979875, 0.07857835085521783, 0.1440834878913818, 0.13859267526816937, 0.13877042298836095, 0.16140046108874584, 0.16795247402643004, 0.20667181410376104, 0.13493223055716486, 0.07646128219822723, 0.08359418130449711, 0.1307096305273233, 0.11744677930349305, 0.18497603554879466, 0.08221241915898939, 0.09056903647198793, 0.12965659671012433, 0.17082651416140218, 0.14183171033378572, 0.20557885178394858, 0.10551155845244085, 0.18289537138996587, 0.12111848550698451, 0.14115085735196067, 0.14521352886672945, 0.14690938706119216, 0.12125432821771792, 0.14171534157808752, 0.18231692904185864, 0.24190024472773078, 0.1842508107543953, 0.11559555081710701, 0.13290917621024195, 0.17165005868000371, 0.09793723182332131, 0.13164238854041024, 0.1466021858035557, 0.15292287083162417, 0.1409887991124584, 0.1111155758882242, 0.2907683039384504, 0.12762850150465965, 0.13605654119483887, 0.09276706530081649, 0.1790682259466379, 0.09214334715638431, 0.19156747137106236, 0.1499933965744511, 0.10547020502628819, 0.2140400937247661, 0.140968972756978, 0.12746687227439496, 0.14807308993993268, 0.24035970319903668, 0.1182533473136925, 0.08923820385168638, 0.14839702255783543, 0.10239505148943394, 0.13904822179146353, 0.16638383239267335, 0.10533900480837592, 0.15484265652635407, 0.10436755935511283, 0.12177034206087552, 0.11233351779200378, 0.11718971083962149, 0.13109062137382646, 0.1603788215546839, 0.17307859815416798, 0.18787693472639208, 0.09707866942570095, 0.1560276413276311, 0.10150187723939458, 0.1679299510414562, 0.09252447589871385, 0.09966852924516124, 0.15149371848712045, 0.07634099873323595, 0.15909216156409633, 0.20275094546377662, 0.14445383011573745, 0.12299089632447689, 0.11560765500631064, 0.08774712862026307, 0.1469243564192326, 0.13982596957395155, 0.1725290986078401, 0.1459167209724265, 0.1438734265825441, 0.1569792910689308, 0.13874653636688186, 0.2059676567272794, 0.17751194897197908, 0.2036654399407487, 0.12843452559243287, 0.08370419919130304, 0.17616269959797784, 0.12932587655321245, 0.1911810413002968, 0.09788090137824898, 0.20570943913152143, 0.13984631686922044, 0.12710475017346684, 0.25707986325986926, 0.13441342049308364, 0.1545789997063337, 0.14948563349823799, 0.1977695966319692, 0.09697747687178274, 0.104304020022673, 0.08729895186280051, 0.1418250147253275, 0.10938793270578308, 0.09210868167781061, 0.11344654395455316, 0.09896131517786173, 0.09841525536631385, 0.10796860160846865, 0.14971794200039681, 0.11621447325113321, 0.18411004975918802, 0.16707004798996836, 0.16747146274053282, 0.16217630897318164, 0.12872440560210135, 0.13324541220020863, 0.09766272719829314, 0.14525494357991606, 0.09745173892306705, 0.08151956157939089, 0.16023013921033952, 0.1718204213126052, 0.2053854911918602, 0.11396819620483345, 0.1277970102044844, 0.1422895551208527, 0.19417272189692145, 0.2070502615383556, 0.11991298487109524, 0.19010166938026107, 0.14344334482185303, 0.18028379297785221, 0.16784692243222268, 0.11880740508316986, 0.22917316475462532, 0.10818333605364447, 0.203981343957205, 0.16132359182642353, 0.14962729847719594, 0.1452675687089082, 0.1469662001416568, 0.05569860256547409, 0.38620980516556774, 0.17396174431327852, 0.15008364173193134, 0.16400618658911797, 0.17467667288597555, 0.11267599739855337, 0.1503077990585758, 0.16712050254066146, 0.18836430454206085, 0.2513831262026103, 0.19456817648343502, 0.13505295069227297, 0.12493092206216629, 0.07173576076785404, 0.19734130751702095, 0.13198608622675942, 0.1543302662790783, 0.20029989311531668, 0.10207921642089084, 0.10948946233838798, 0.13447213347160047, 0.1926218228594911, 0.15345245209192077, 0.09716804890382676, 0.09828986209486762, 0.1798811371648504], [0.040269817766403, 0.09080871473997833, 0.047399380559762644, 0.02745809273854379, 0.0771750386564001, 0.051119932529306224, 0.006596160669540686, 0.01947387459597761, 0.07377687180715223, 0.02771452343421838, 0.0897535588592291, 0.05303564646671857, 0.10109567443930334, 0.03236160320680469, 0.03558180017036296, 0.014844472302244076, 0.0771629574498342, 0.05461818493542172, 0.00709156483231533, 0.0045342800290053414, 0.10109802632923089, 0.06325253210360966, 0.022891358352236213, 0.06820525222968671, 0.040434116813083815, 0.030995540118085283, 0.029338210400554444, 0.12987560592591763, 0.0017064803626365781, 0.03875476398294972, 0.026573542723312017, 0.020815838473818956, 0.02457550497755649, 0.04006596943063121, 0.004088439360906881, 0.021062285128620364, 0.031900577239632126, 0.06941376359111841, 0.0626740629424251, 0.025303422571009686, 0.05044926085599488, 0.11397894441841111, 0.015456638798388022, 0.06166185395071103, 0.06442184274595592, 0.01261157593915179, 0.013909654470250733, 0.013132648835439357, 0.08088176273891041, 0.026556541317052422, 0.0678774968330418, 0.01873555352851268, 0.012023454070121292, 0.009494071146623503, 0.05310862400238553, 0.03432283808867778, 0.07848834318499412, 0.015307699814589034, 0.015850639733065282, 0.09417113592667926, 0.046945174690335996, 0.06305018530016945, 0.050323863754109036, 0.017871333571571498, 0.016095742861169483, 0.0644783417303716, 0.01136282102144774, 0.03388384289498772, 0.028986930358974688, 0.030131844931372234, 0.01858494638825857, 0.08948772634950378, 0.03767016351283078, 0.07820484468773489, 0.02067117043019783, 0.010933393308322036, 0.036383890396645, 0.01873222679170149, 0.062373369601705385, 0.07134226736642661, 0.02678406368490429, 0.007992870626865977, 0.028570527098171657, 0.034000027789584095, 0.02806361820999413, 0.02396843392371891, 0.11250933497062615, 0.0025524965143807594, 0.05801097384744114, 0.01731063765023024, 0.02649860974821833, 0.02915798438592784, 0.05547117021295333, 0.042333271760012836, 0.03422929109224389, 0.019984826513175524, 0.04537925649915011, 0.03755725747455032, 0.05649217006359851, 0.032121626164523825, 0.045313855573054285, 0.042596553196950306, 0.05346191693998633, 0.028754233067194303, 0.03423474946870439, 0.01569990331547395, 0.07783232677367427, 0.014251791252454203, 0.004304219516099341, 0.03187578088874298, 0.0756441421746727, 0.06508209562349705, 0.09695650138441594, 0.01945156420040275, 0.020327894092206995, 0.02180422979196714, 0.009948968410401816, 0.031033959427487948, 0.03768507158383727, 0.006986019941377304, 0.10071501301060762, 0.044908169882311944, 0.01040950695413255, 0.05429154802714625, 0.04572681526863768, 0.03873098461378006, 0.0425824839922209, 0.02121758072697107, 0.011918348722129822, 0.07429138411797824, 0.04914268257937605, 0.02673121702466761, 0.05236995819535467, 0.01569992821333149, 0.07885569000556585, 0.04372867027057275, 0.0008534211695904002, 0.045277845610173485, 0.06819713935856858, 0.06321449200772951, 0.052155717876890016, 0.031081887803250746, 0.043093774903325305, 0.025151327304962664, 0.056001885283377864, 0.07983312626639683, 0.025267571571373174, 0.021868521805792566, 0.09536860030024283, 0.03182559446882337, 0.032080042911993886, 0.02853222270195763, 0.025250610384729602, 0.002363868669847087, 0.02907923629297124, 0.0036334690793732847, 0.03189353689160799, 0.03712470891074308, 0.04946520559549813, 0.07958109866106704, 0.029225725710632342, 0.022915319667287895, 0.0312896316961175, 0.015643890796890183, 0.02562294635290821, 0.031410219681058685, 0.0669883981707596, 0.04986071380816641, 0.04711974697608141, 0.02518374048503897, 0.011438729801034976, 0.05484850543941702, 0.09578185110923745, 0.01289230885900437, 0.0016819748857561801, 0.04657913788011478, 0.042860891835223285, 0.07356794430844246, 0.026504631199303175, 0.02584688725971407, 0.04789137754649405, 0.06500084433824786, 0.02565105603406987, 0.02258592484248502, 0.03905530027564495, 0.05899889019107627, 0.07288338346106392, 0.033628161050259106, 0.05142698823023708, 0.023491369905851545, 0.09379844181239606, 0.02371303936196191, 0.04495310093907099, 0.04398647034841199, 0.03379250606221538, 0.0261751827483456, 0.013997120643785645, 0.04323555862591152, 0.07157980058822902, 0.023855298059061173, 0.034138272185960127, 0.043537274694010135, 0.03752151947288263, 0.043246885235872, 0.09442475699489156, 0.06975520897897021, 0.013749714463859076, 0.020448742547042428, 0.013206862645494121, 0.06911418490832852, 0.012091555456150205, 0.024441148477396177, 0.0176120740962365, 0.030314587544830098, 0.13716358421069963, 0.02387948920049014, 0.06751011170807385, 0.03254135041647861, 0.03911792030257564, 0.014705378505881998, 0.034888858321092786, 0.033892591619083, 0.06599487406351874, 0.043364939385003624, 0.0853533030397469, 0.0366963240348043, 0.017792794237574263, 0.029232890547944174, 0.056099940707246145, 0.017619897769163215, 0.09775772210090392, 0.018327795569935156, 0.02721401712586803, 0.01861805479312616, 0.03303353126431185, 0.05025578535071785, 0.035036345568275264, 0.06482548681238005, 0.07339075583243564, 0.04693654470986897, 0.025189618294638012, 0.05319910281668267, 0.028093342421456214, 0.028144476875182123, 0.002222533826904011, 0.003587314915362626, 0.04691564200085498, 0.01123366530068339, 0.015827723170420336, 0.05379697315454964, 0.03976759350588245, 0.044165888140278484, 0.03374867817206729, 0.055993247642031604, 0.07181223166445572, 0.009759653720163531, 0.015559192115981734, 0.013889205668331876, 0.04000295869885914, 0.039861818490129326, 0.04673192645573328, 0.06855674869110508, 0.024596919050259937, 0.02240193542093039, 0.04343176906507823, 0.028649842096192223, 0.05839700172204645, 0.03275798859014627, 0.010720582701446069, 0.07190102125487982, 0.04697733123095767, 0.013510005552351717, 0.013808303910698143, 0.0485955540751738, 0.03997431084093067, 0.0796297912095343, 0.07691401717883926, 0.061050864357140765, 0.026011837481130517, 0.04893548260893553, 0.02197706688856406, 0.009951402654781217, 0.023037173612523946, 0.04904245912668206, 0.049813484487634514, 0.06670626331000559, 0.07602633577921698, 0.05288624399972539, 0.040261352494839704, 0.02181141186625727, 0.040339750102570945, 0.027169723837305943, 0.05165025689488938, 0.03496604934034329, 0.018868033113258503, 0.04326715975278809, 0.04116058650036012, 0.027369243776305553, 0.028249880997464064, 0.036361244837603265, 0.07287387630992359, 0.0120133436247406, 0.04391801656193791, 0.07370872062540824, 0.039714101416569565, 0.04264208946316954, 0.039513769424370224, 0.034882683652423085, 0.035554443170586904, 0.02978787719902973, 0.013423161825255282, 0.01115318680662782, 0.05040462091264706, 0.027231177495371912, 0.023547614166032405, 0.0159499544139591, 0.05676611927488158, 0.017102953129177614, 0.02211834307790043, 0.0160773835640641, 0.014256694215169598, 0.011388791402080848, 0.026218738677280567, 0.0358676812010667, 0.04834244628587077, 0.013997125431835173, 0.013330992829475193, 0.0070607585216602015, 0.019360079895704985, 0.02674755193443308, 0.018968093772268584, 0.012160002539354947, 0.04612547593311437, 0.04954092189549439, 0.019645530001951322, 0.016119493502041986, 0.006804532754505354, 0.026754199662396026, 0.016956768231466413, 0.031128153768217856, 0.007309688737751135, 0.027402880781840895, 0.059163756142821045, 0.013395778012401877, 0.03647351885334619, 0.06293774657552281, 0.026846360039686965, 0.02885225784754561, 0.03294702844634172, 0.036476610018120664, 0.05055313471764807, 0.05875053214690378, 0.17518209173314034, 0.23247658184939818, 0.24756109822661648, 0.15600219188678652, 0.23735100012873453, 0.21282308644825415, 0.1712232098103531, 0.10338802401336933, 0.14445041336359518, 0.09242088548959264, 0.2070920899390213, 0.150767543743695, 0.1351771641883158, 0.13168496770724175, 0.16800479783165842, 0.15822537904304845, 0.1469629978941333, 0.19597653720167377, 0.07941933153497596, 0.12870367526287033, 0.21437492011295212, 0.13568170969524693, 0.12688603207108476, 0.12913432392862537, 0.13462824686881036, 0.166538076535348, 0.10249030686193898, 0.20570197743513893, 0.2177491237319285, 0.16414973614436967, 0.07769266894507794, 0.1323094825831152, 0.1883871186404459, 0.20911656920948338, 0.16607270876486457, 0.18703455976661176, 0.1423649381726019, 0.1816470617608678, 0.18065355297538543, 0.20921069077186047, 0.20888107378155957, 0.14753978549232408, 0.11475378106678687, 0.17897828722432738, 0.12912375191527029, 0.1821842272916148, 0.17603770469225224, 0.1368916689628555, 0.2642317230422651, 0.08464040460004922, 0.13165228639639195, 0.15910546085046184, 0.09211723887992483, 0.26112266245388216, 0.12530103446014468, 0.08904763181964237, 0.13677738396631134, 0.12368502561002971, 0.109364329536836, 0.16564823476777923, 0.13111078480799354, 0.17016859785203012, 0.11650953967604907, 0.18916241494157623, 0.16663881709739087, 0.1985477734236948, 0.14715628187742927, 0.1170868941793038, 0.08994380913434491, 0.17837122383136905, 0.09015059924774593, 0.16005792264496127, 0.101964847154675, 0.10061578164177556, 0.08184874956045421, 0.1705029186221861, 0.16995777045526814, 0.22767216868458257, 0.08223917094930526, 0.1808671842539503, 0.11275440649760347, 0.08834688353442377, 0.2686817745768255, 0.1279235066425416, 0.13170698507418557, 0.165257208169468, 0.16618471081939437, 0.09997998229077748, 0.14790870279314058, 0.08476884690143409, 0.11139007285237314, 0.12154625368214424, 0.11656697328773238, 0.17754717369473752, 0.19785489286145858, 0.15035001050320365, 0.1370860867562794, 0.1592346539180125, 0.13379979938749345, 0.2062785658504694, 0.2348200907750476, 0.1574324014326257, 0.09347431767251223, 0.11393707005246995, 0.14410319167279428, 0.09412121763753314, 0.1606872485529992, 0.08793030790383778, 0.095708605442797, 0.13396234792326728, 0.14834039333847263, 0.16892129945899212, 0.17085073786156793, 0.14723549536879987, 0.10299072315495822, 0.1214165626574428, 0.15752178857163077, 0.1598471718569917, 0.09266038755736045, 0.08619210036892085, 0.14512418769299984, 0.1159279563674523, 0.1378250092027649, 0.11174767503454802, 0.13388699551503505, 0.2158614984082599, 0.08428880854720071, 0.22239016098601205, 0.08355109651963558, 0.15501067492990725, 0.12423805682168854, 0.180565131107165, 0.21209737135758325, 0.1641172386946217, 0.14384261452622954, 0.22612122368187676, 0.10054998234995913, 0.19336111302818024, 0.14886272740700554, 0.09449958846333528, 0.2550967067720429, 0.07614665754860447, 0.15601665562679692, 0.22363094763169367, 0.13543006513387928, 0.15091539871308113, 0.11480222846711836, 0.0891040848387826, 0.1958030489303412, 0.20579735538171184, 0.11041449818519816, 0.15428062378158494, 0.14970694097780413, 0.14012983068823814, 0.09207173325722257, 0.11144527714819678, 0.1406294579106954, 0.11875993061450221, 0.18577246055487665, 0.09947137651784767, 0.17781171917675004, 0.10171389973331844, 0.12483127700585513, 0.16243204444406495, 0.10415904554388217, 0.12554325614004366, 0.12384461704641582, 0.11734797694389859, 0.11081398239419346, 0.11721277008614234, 0.17123827109894446, 0.1536460884756619, 0.18924407991430453, 0.13530799668402443, 0.11111232767542524, 0.2215414274964602], [0.05377494429628696, 0.016135135102235985, 0.04146322187396788, 0.035375676553456054, 0.015364119317382576, 0.03776852537186877, 0.03718308481057325, 0.009355274209332083, 0.060026516702266476, 0.0458563607366335, 0.03442284320631335, 0.013821153120408136, 0.022309520319404624, 0.04769402180588053, 0.07643324338019857, 0.014349961589511125, 0.026079716701661388, 0.03849006528335233, 0.004904036674903887, 0.03818248481219334, 0.040313722265343514, 0.019816785126984603, 0.08805161026576835, 0.04340094934788443, 0.04346071569729717, 0.039963344292294596, 0.06668582408418579, 0.040875329831314665, 0.02318784587025162, 0.05432968771445656, 0.04004085323803368, 0.01544626692550317, 0.02030725568352688, 0.04438785445545951, 0.03252286471486573, 0.05239847581833602, 0.05676321197120894, 0.0612204647322576, 0.022872031869126425, 0.037113937714527694, 0.04958993237045023, 0.021016584153497414, 0.005089657384932282, 0.03402489500360624, 0.09785569708554015, 0.06912934578835003, 0.04400703980917892, 0.039731089416290485, 0.0211123681266702, 0.02644370231146534, 0.03604384694969462, 0.01794779297685431, 0.0403426957106398, 0.08463784586638214, 0.029567711190470768, 0.025801981100812558, 0.03408484138368118, 0.044320002048005985, 0.0628652976405236, 0.028992421294171965, 0.05570711763275247, 0.09834246169174872, 0.01068604841542941, 0.02836418706142614, 0.11767010925517929, 0.026560427298048334, 0.057845111981394796, 0.0655520522606469, 0.020124131941326687, 0.0659510002080952, 0.018411735823798566, 0.04113335207465195, 0.015660896991199304, 0.06216912290021297, 0.04423335750376986, 0.06219501667205365, 0.03621664574189532, 0.03498178478630801, 0.014159416370544464, 0.06807399072474049, 0.010133600388202938, 0.03770790483442046, 0.04160065038670455, 0.03245395127563708, 0.009778796342171488, 0.018354321364313364, 0.04898898235912766, 0.0506226533663369, 0.03246820817190794, 0.02944628050881288, 0.01856563331168746, 0.016408770217470104, 0.02724316294094728, 0.018001474672928452, 0.06801390644883917, 0.03688710674102749, 0.07953527894231581, 0.034512012010259975, 0.015689326514069353, 0.08549579539366307, 0.023544771979833325, 0.03235617930430078, 0.03942888305192033, 0.076068646815275, 0.01926820488616584, 0.03478453629800389, 0.04120858956969554, 0.05977146304963578, 0.04661453497265616, 0.03311040052663415, 0.03363294526934624, 0.012640285084114201, 0.06666746861752003, 0.04247517805666693, 0.06017498071155241, 0.034346640440485174, 0.012087911750460345, 0.02841203882839651, 0.0355949807131002, 0.02722397818410349, 0.07298175681142077, 0.051440513512540254, 0.06815662096825338, 0.05657886440354971, 0.03336588701894207, 0.03495326333288704, 0.026851469846141916, 0.04342849020876231, 0.06751232570217502, 0.06989590868714356, 0.029343371917944283, 0.02027578479159744, 0.05320377595302078, 0.05823824149105818, 0.05944233252516678, 0.06781226444628931, 0.05239574471488596, 0.014566299073668498, 0.0494832239834772, 0.028846701794874766, 0.05454701919769568, 0.04068599120082875, 0.07115043128930754, 0.08408625490002095, 0.08080831788960965, 0.030194779054351875, 0.027774027398517056, 0.040727019039613586, 0.04378594300379196, 0.06752491252677095, 0.03356135435282223, 0.04449941983987247, 0.06425501177868535, 0.018956862923298633, 0.03164150162539896, 0.05276378101458954, 0.042713848919036894, 0.027134185018498572, 0.05407416674819204, 0.02171349242299555, 0.0042664293564044905, 0.04290799092080805, 0.12728501066205003, 0.0016513474087508757, 0.04247151615638887, 0.027109009454086907, 0.018956612029503432, 0.026129688616962205, 0.0455514270992529, 0.051528016075251565, 0.05810155225316844, 0.06118957606715061, 0.03313655859880871, 0.023250582725590756, 0.06428730238469378, 0.054220834281295545, 0.04705759809322415, 0.06692714178033414, 0.0981006843428458, 0.04414964324584411, 0.024660002560384815, 0.04455079369607472, 0.016369251571896098, 0.06286743502583235, 0.00856817153567869, 0.029302679242626316, 0.037097685159214085, 0.0157164316624403, 0.08711404888139618, 0.0382297984023969, 0.11200508057710626, 0.02114161736361923, 0.012587244986676642, 0.04473392701437397, 0.011986243264419178, 0.04130899688349136, 0.02179884802429907, 0.006262345996219666, 0.029227859265501463, 0.052576177573252114, 0.041368414662898555, 0.036593166465360316, 0.02474438714524431, 0.05214613028651765, 0.021323574736954707, 0.10790352243930103, 0.02008644807633133, 0.011882580076945166, 0.07657400437540586, 0.03802084026017016, 0.03747158586197803, 0.02813525892223322, 0.011482042497053984, 0.06870091111669618, 0.02146315787197842, 0.07092552319649728, 0.03779464897008673, 0.014502516508312717, 0.05177062845999195, 0.012372107387730672, 0.09305290802712403, 0.05361383217537115, 0.027196873993342443, 0.07355731866893268, 0.031073058639923413, 0.03092325397676999, 0.03403320705758468, 0.004384518458297657, 0.08104929084619207, 0.03845679025436121, 0.045187083343344356, 0.09576662894218199, 0.04591238857697576, 0.04305947331651565, 0.05652052680811575, 0.04279966225787517, 0.043904108235672604, 0.04423493181445426, 0.014745224654043635, 0.03175734178042941, 0.05211638309241784, 0.024330632633439476, 0.0513084591065924, 0.10271339166548946, 0.013290285790008644, 0.046521865146895575, 0.04138125429650949, 0.026139705216572173, 0.03911781688070586, 0.07296795190702524, 0.015474958833487285, 0.007846068070765825, 0.015451475365778372, 0.004918684276016129, 0.02551177933421587, 0.04168254518581014, 0.013999561591434383, 0.012960296289454545, 0.021581914906780568, 0.016713615754739414, 0.039626169844620654, 0.025493197871612448, 0.041422014004520835, 0.035198920917126446, 0.04756691632792354, 0.05540259002197174, 0.015542652277696519, 0.04746908689999292, 0.04085107931807157, 0.09905806442181911, 0.04307814670966999, 0.06946254040925734, 0.04872631379252961, 0.02182768740420861, 0.012920876277700789, 0.09714884307956505, 0.048379551754483295, 0.024730226009963982, 0.021289788344274127, 0.04642032402297182, 0.09727785994689311, 0.02716807291782912, 0.0506864033729559, 0.0212973362255481, 0.01633773279947139, 0.04735378300650947, 0.09960915743102951, 0.0287729888148005, 0.0714096677820048, 0.04598533546912574, 0.04655063557889193, 0.05895684345535213, 0.024023486917177518, 0.04330999555907423, 0.0055737957459754284, 0.01733024950109182, 0.09517255840041945, 0.059128902972705906, 0.0488932749947473, 0.014229448298142563, 0.03313082826113509, 0.0717899844711346, 0.027729056122141982, 0.04714922986984734, 0.01785353160343103, 0.06805037989491416, 0.054296010489305185, 0.010014665237958393, 0.05965797861497249, 0.09249144218741887, 0.046598615665589614, 0.10023068456399827, 0.07987780451414087, 0.04127556863691538, 0.05268522252839419, 0.007353409375589822, 0.042659180884760235, 0.019058670262776075, 0.01714243921601484, 0.026232928540858052, 0.02207428153093544, 0.01573690057416717, 0.046726295709489815, 0.018677045478515567, 0.003176902222724992, 0.013409966918369456, 0.054892160959782145, 0.04376399841520094, 0.08738607138154969, 0.026777440854798884, 0.005025532474035337, 0.03673448670475233, 0.06491383973268733, 0.03152849216524872, 0.07563808241919165, 0.0277754312546383, 0.011919973786139201, 0.05278867121124941, 0.03386325045158306, 0.025510727878539793, 0.06186194462521423, 0.06242491965813022, 0.049500185170120774, 0.040901162316121405, 0.06637036439872558, 0.04290566584395786, 0.03396268483371504, 0.042020933882844065, 0.053248354609334664, 0.024971963139250878, 0.05480015380007606, 0.04836604562437823, 0.16811603379826393, 0.15872040973796, 0.17788098884686349, 0.09565771422198704, 0.13275257251676054, 0.12836904805754462, 0.13143991150202292, 0.1590000011868054, 0.08628111212484299, 0.14494061770458377, 0.20764143626776435, 0.08823488147989397, 0.21426895483126565, 0.09868119512834857, 0.23453288441223485, 0.14724871804637296, 0.11921846488070105, 0.13727911026968112, 0.08383197499619377, 0.13388474321653768, 0.11731167969804619, 0.15033858047137338, 0.21797907268328054, 0.12898697457726926, 0.17353101903873105, 0.20900046092367944, 0.16951726989880686, 0.12459909873864344, 0.12390560530606778, 0.23995906985815496, 0.07902222219854593, 0.11098391601755736, 0.18484232256249075, 0.1647905533712718, 0.08842887026408026, 0.1594270492393163, 0.13921418707937966, 0.10637374444594307, 0.12921122383446465, 0.21010575725907282, 0.11417553024066072, 0.11294772878529565, 0.14849135862483134, 0.12263468842232421, 0.1828929045868497, 0.16665767818208665, 0.11922372790474085, 0.11929440717663496, 0.0772396658336924, 0.09419970334537568, 0.17177554388200084, 0.10463565948509401, 0.2673086385813452, 0.13542998852508684, 0.10657544773552688, 0.17804650980378353, 0.14775487233794507, 0.13713120933501952, 0.13581074954521272, 0.19211936111171402, 0.1429852548866503, 0.16087425061531607, 0.14338686882007506, 0.18178426810810644, 0.2617279025575807, 0.13613120412393925, 0.24333477500946293, 0.19474843697201824, 0.2227309015729735, 0.16915569172030495, 0.09622990529263213, 0.11059849718285185, 0.13066089201358058, 0.2264882870499165, 0.11200043042340588, 0.15047577149685354, 0.08221068780028051, 0.10752044017276458, 0.12632529401490766, 0.16246012922736908, 0.08338384420400666, 0.1355977158152288, 0.15506799362840193, 0.1365694830254201, 0.1031060653528379, 0.09180207030787584, 0.1594887039954624, 0.12261660874731119, 0.13325799136392533, 0.14993486745703608, 0.060574518546702406, 0.15640014391993323, 0.08805314244161691, 0.16420055841726644, 0.17088274501504438, 0.173788225398429, 0.22223161142920295, 0.10414612164059955, 0.1540984021079156, 0.11660366123842618, 0.17909407375320313, 0.16937001247800168, 0.09776909850657949, 0.2338405707550626, 0.15964363761726888, 0.20571854025606187, 0.1183704668355565, 0.14491455539339973, 0.14606073018043272, 0.17966054980793308, 0.1627440414121074, 0.13327597910838743, 0.21160325996818083, 0.1494988408540526, 0.14602705295528137, 0.11516184546053411, 0.20948562440612625, 0.14955577650858512, 0.23346239911212077, 0.10234328692839031, 0.3157310338029939, 0.09144036955530606, 0.21876992056927375, 0.10507713297321912, 0.17206866444358904, 0.19365359007591204, 0.1675605281226097, 0.20808216665060292, 0.2458911644475114, 0.2581423965673293, 0.11334082382100244, 0.09889572272978484, 0.1934411998597845, 0.17443605999071754, 0.13847348730890982, 0.15299206389294517, 0.12646365715491195, 0.11904928968438219, 0.15957490420870243, 0.0836329453534657, 0.17472987003143758, 0.14822402458277442, 0.10900449037792222, 0.1531505674844788, 0.208191211605745, 0.12617762290662335, 0.10636896405729557, 0.14171814545989037, 0.116637637237868, 0.1592395568807279, 0.13205907908418488, 0.13773033605708232, 0.23602209805000215, 0.10704087679304423, 0.10687997534630761, 0.1434685950798373, 0.10814106332198267, 0.09173097734850261, 0.14076038233695493, 0.07623334805811606, 0.1038020179276505, 0.27035950713099977, 0.16002321886199136, 0.09802699434540926, 0.22810456403080495, 0.17357765847156126, 0.1175750224220176, 0.23892408507245205, 0.15282229880892462, 0.1319890126826302, 0.11982242561756604, 0.16956502782000651, 0.21141432736429477, 0.10561969176295305, 0.1479583912559094, 0.16158657448907054], [0.052096867002546794, 0.02844653959806648, 0.04481142446879418, 0.039183355702628056, 0.07822123896931449, 0.05544354891284339, 0.037908635192340424, 0.027601510143628525, 0.015602703994861054, 0.04947392367607644, 0.04772038289135502, 0.02247446479516164, 0.06965118189973217, 0.031084649550217777, 0.03097629790464717, 0.0437572070457522, 0.019937200742142818, 0.03734300949520642, 0.02346817276350433, 0.0881649989394411, 0.03315857596575253, 0.021461614204810995, 0.05505318498058666, 0.03925942440306948, 0.03263447989499377, 0.056688449450678406, 0.018864980252880244, 0.0334528916245026, 0.019729196379381805, 0.045129649731661045, 0.002287577085700187, 0.03506498576532449, 0.03549464617765719, 0.024250513243098414, 0.024994200756472927, 0.07206451973967976, 0.031009471426988323, 0.07286776292828784, 0.039172347019156145, 0.01827813008980405, 0.12977157118580035, 0.09046511664505928, 0.05231875670893539, 0.03695937564536449, 0.04666207072835776, 0.009322822724859561, 0.03053979824237045, 0.06425644053266415, 0.03930419075092481, 0.04900584012390145, 0.03559905247041776, 0.009886069718988673, 0.04170274309393379, 0.059844172454529235, 0.02166695258159551, 0.05466367140592587, 0.015283319066398808, 0.04089741614617167, 0.0457221842671354, 0.04444376738261312, 0.006316275234454342, 0.006592380983244267, 0.02883867510864812, 0.12068936901707804, 0.05745325034724609, 0.04432272932101642, 0.041142322964245276, 0.01591331338615067, 0.03639075071400693, 0.03519880217349818, 0.0444314869931869, 0.020341693250943097, 0.07286906527775912, 0.035718903095731815, 0.05736601208486865, 0.10873662773519756, 0.03394282400427807, 0.025952061555618723, 0.0431163783275312, 0.024142506337093732, 0.05750796817723782, 0.056023975428674495, 0.02386348370853211, 0.10000750016901763, 0.05678972627426829, 0.059684987044742996, 0.02537035567295407, 0.02142644885386671, 0.03617706963972699, 0.016167885360998974, 0.03070247701309141, 0.024672162290962956, 0.04940618235137194, 0.021652697600544463, 0.04400529312871156, 0.026620630317577915, 0.017149119502714565, 0.03332124324515462, 0.01247829866535481, 0.029795143542991533, 0.05275278382243649, 0.024810017897717418, 0.023640680442293806, 0.04965808355219422, 0.0162048299511474, 0.014328407705761494, 0.07222026541468597, 0.020926063204364433, 0.022844491008248542, 0.07372591163842909, 0.016718564682730263, 0.05378741620769424, 0.0305560220693869, 0.017002275769388484, 0.08183762596379365, 0.022535975909821933, 0.02450883617594598, 0.04538010685674606, 0.07677507947289175, 0.02507322272586246, 0.04268995080623896, 0.06665498138435426, 0.013952264280599213, 0.07975156854597792, 0.03270091503978737, 0.025021979104607336, 0.016211311054986813, 0.11175908974461979, 0.024513813832233992, 0.04442837667621432, 0.04427200280911019, 0.0531519845788998, 0.03479952097780282, 0.02037464077734659, 0.06536436071919818, 0.03146137903264213, 0.011765437572443438, 0.029612753329978838, 0.04952527454964096, 0.019869237251940276, 0.03163881648722435, 0.02574075152346444, 0.1124103717325676, 0.02628079754480672, 0.03211797384034482, 0.03209596030384062, 0.08406483508165806, 0.05194035140917667, 0.038762662349449056, 0.03937107405715412, 0.01925785695352862, 0.0408875412728277, 0.008367666216086476, 0.038460413850243055, 0.07333892998435805, 0.02688999257741436, 0.04064765616109775, 0.0177108132535772, 0.04364336638020412, 0.030384155989234007, 0.05343596954199095, 0.11861158534884454, 0.022702678557365172, 0.023548516234563246, 0.03495635449766152, 0.08194336907998209, 0.026114826511231162, 0.04530834740087871, 0.04041245567702478, 0.03952303908825402, 0.042523748031066316, 0.07131339351256048, 0.05768455527422409, 0.03884112507465386, 0.05088018148296303, 0.029964462380796194, 0.006178892686993125, 0.03433772700748617, 0.06714481034225996, 0.009257104829885066, 0.03940539862660151, 0.03652876528400568, 0.03256509531169169, 0.07689384608379296, 0.016470082149270083, 0.07176765300814184, 0.02949282226543273, 0.0520292520823498, 0.046662154998029434, 0.06679231030566078, 0.04623011205225222, 0.03364936636400319, 0.04548782264933952, 0.031084063492955703, 0.010249616743455972, 0.01386967138387263, 0.027059075843182304, 0.024846142773786863, 0.05047916509811917, 0.027379861754936077, 0.04225565173152474, 0.03539885454360516, 0.08344693154457115, 0.03742581210850227, 0.046672351628301606, 0.02704076442657219, 0.032418010260669455, 0.040493412018423124, 0.0709981023664436, 0.04631225966037281, 0.04845398102676676, 0.028019351734509392, 0.08135011825229853, 0.03405710900082223, 0.03874347950782507, 0.025113587898592797, 0.04357911841643434, 0.1574664923452562, 0.029676654638962883, 0.04918694330920135, 0.010820815730239115, 0.050210961546268196, 0.09156325005836065, 0.04101059797610487, 0.03647161895529397, 0.013476314920661672, 0.016252068847778346, 0.04592878668899498, 0.059369672915988395, 0.0029386977163789376, 0.0682111740893414, 0.012047059154288184, 0.09135053808530492, 0.012524095401468297, 0.025468422588141217, 0.03860228184250094, 0.011544602194560633, 0.005506746773232496, 0.0011931503409399623, 0.06409217595993992, 0.040624631388533505, 0.0242628242760416, 0.027270715293144027, 0.05624108474641558, 0.03992879372690955, 0.05689449645879288, 0.03307590741784342, 0.024521882653296478, 0.03323208210208724, 0.012603897822930688, 0.021697163258889512, 0.02259387875035886, 0.07630565143640965, 0.036650741803309614, 0.04375096725960893, 0.007037434974805482, 0.0508787986942597, 0.030998692569893696, 0.04034130526105723, 0.02740322360618701, 0.01688369685002873, 0.029842189002421596, 0.041643773475962306, 0.03925010877391023, 0.04704720994097091, 0.06218474726342867, 0.009364766996323822, 0.05061489289566394, 0.05463694642868735, 0.010002364738724165, 0.04377922824313564, 0.03514687290355083, 0.04379790163628998, 0.04687547218054534, 0.03312326697332244, 0.052648427325391, 0.025668333231982206, 0.007430825911973033, 0.012855752100867611, 0.0482649028661751, 0.04564276010158562, 0.03612904741819348, 0.026128382437051307, 0.04018606137364142, 0.029896939391150113, 0.02518851321280724, 0.02952185508254315, 0.027121787800663905, 0.019961968364734805, 0.03567471897469894, 0.05731383383634591, 0.08775482014302285, 0.041627329398667624, 0.0531249953013274, 0.032652689804953915, 0.011627731352834212, 0.03302350317338302, 0.02545772225505883, 0.04733387621179704, 0.011113982257102768, 0.017981452965027383, 0.033139021571485267, 0.04282072967579288, 0.039810931099759, 0.025545257376506928, 0.022698014997126117, 0.02117887796503642, 0.09033982296504321, 0.03187160953999527, 0.016660456913673592, 0.0786955546467535, 0.14425614878775614, 0.056718158340382005, 0.03429678726881262, 0.061169033419461026, 0.03850843607177658, 0.034054205527589206, 0.0332189207115481, 0.024351761338391134, 0.04147200507201976, 0.056419793906952106, 0.06789789009358614, 0.020186426380889553, 0.07062661101020153, 0.034809725268954234, 0.030804144541522673, 0.07149715502295764, 0.011360529460944237, 0.015618041075105149, 0.0366245913920143, 0.019641722544967648, 0.011273876298218967, 0.03875665238968307, 0.04206553552179568, 0.044811198472856514, 0.01626415005434425, 0.018861163219797517, 0.07959459713029285, 0.025083373390859174, 0.046061645487263325, 0.02708845148463884, 0.03902796625850662, 0.029039041574804053, 0.04877777574884315, 0.03493820587473531, 0.05425074618429907, 0.043284423544161746, 0.020146063123379025, 0.027636415024678555, 0.013574980342039659, 0.05171729341870354, 0.03894656941655182, 0.13910845162407046, 0.1771620766169602, 0.17646389472628796, 0.11089481999196353, 0.18174826197566527, 0.1140612529049958, 0.11764793867065061, 0.17446403752171225, 0.09269845446631794, 0.15444913248140968, 0.13821940658794296, 0.24143060218662987, 0.14784341678023338, 0.15802104807188436, 0.1370100601906738, 0.13505586182638524, 0.22827290419128635, 0.15127644063003604, 0.16468984345274587, 0.17146487990694662, 0.19342328872411482, 0.13888976416520535, 0.0972189018202405, 0.09796843458447727, 0.12143395285332396, 0.09846453014160357, 0.19876453034099073, 0.19398418765875602, 0.12505849102331748, 0.09952651186575813, 0.17948891546937729, 0.16560467500840464, 0.1145937682820424, 0.12206917763837885, 0.10020734186494544, 0.1441342795207616, 0.16450040523082982, 0.16717992032006865, 0.0871156653269164, 0.10417629018305771, 0.21562060972134914, 0.2516729679078825, 0.12387719110495622, 0.11415184280204196, 0.2753662900818933, 0.13296393617506952, 0.14421914674101338, 0.2248650233471586, 0.09894977789372207, 0.13355812929089994, 0.2143651601527968, 0.186894825329223, 0.08231158924078749, 0.10491422437612088, 0.12594428784664602, 0.20724763643116723, 0.16629113575383542, 0.10413129017838549, 0.11934430248314336, 0.0988324132237223, 0.08965375292445384, 0.08890388308153038, 0.15848528203223983, 0.15281943364008782, 0.18857287964032543, 0.09924345769949498, 0.15230319763143219, 0.19376133268158283, 0.19161726708614057, 0.13937561712678403, 0.1314998502212186, 0.08712459025123427, 0.18379460539548628, 0.09197921281860721, 0.11496028772765592, 0.1697671064926732, 0.14101889104612414, 0.18573783338069919, 0.15264038357042498, 0.1345939414515611, 0.12458222182167154, 0.1813943293546477, 0.1105796437590353, 0.11241804793356888, 0.10363727071953398, 0.23418852789027078, 0.13679054535685048, 0.12473984441209225, 0.1318206725221488, 0.15013037309531244, 0.1646563807322133, 0.13523359422481832, 0.17098279609795541, 0.08752078028215517, 0.1435224970261897, 0.09143688385525058, 0.1316070565653424, 0.12417523761189754, 0.09215455502271654, 0.14843699702572438, 0.13073877251196292, 0.12884923196848364, 0.0729939682529338, 0.11535317591962316, 0.16691836258096082, 0.11108471786663418, 0.19893890727431546, 0.1695461973788277, 0.13085025362670422, 0.19907487255911674, 0.16150342330576914, 0.15678119605347035, 0.06534605887868712, 0.14858132799065885, 0.2262018927403035, 0.21904361314110218, 0.11342600513730319, 0.1622151189874257, 0.1225034652217742, 0.09244946056916829, 0.24475337066237005, 0.25155495972402636, 0.14591696612056226, 0.17608875679152627, 0.08993195009327705, 0.17197647342278113, 0.1571571920067072, 0.25797710543678654, 0.13808224620597978, 0.1620863855726296, 0.13927547411332208, 0.11818960879839237, 0.08987026469361398, 0.1997133455569706, 0.14769726252603918, 0.21289073201196812, 0.21167423035348618, 0.1356380886488384, 0.13496183219455904, 0.09733083492685711, 0.1317471127596594, 0.09220271897051605, 0.20304340718974992, 0.19761155269319014, 0.11393583665091185, 0.12882459458083878, 0.15642395393261987, 0.1881306324033968, 0.08929539231523391, 0.12737133344935794, 0.18145621393717107, 0.0710054185061205, 0.10298620323620497, 0.15879551699805647, 0.10975226113993315, 0.11816824260618418, 0.12506949204591014, 0.0920094732916163, 0.10941126008307743, 0.06764239210995936, 0.10026593993027365, 0.2007725080775638, 0.15149906578083194, 0.11396844135296923, 0.09863563587949162, 0.24836680821834073, 0.12108293902729789, 0.13428674019392461, 0.1320827818445621, 0.14716328392105718, 0.20051232929671967, 0.17803953840367256, 0.1904610871908165, 0.14611207339311802, 0.19473640939160702, 0.11891874830208479], [0.06137464758789828, 0.0173065678081325, 0.007293131183682671, 0.03209834092206532, 0.020340111279379458, 0.016666118303434025, 0.027277947163149237, 0.04238115991615961, 0.021797333085428805, 0.034214543899701494, 0.08993894447602573, 0.028657550855930296, 0.015868098876859634, 0.0568054425680349, 0.04049362652304192, 0.0146117941626618, 0.021884732226270343, 0.05404572573400313, 0.02889052393936342, 0.025288112303842942, 0.01723345237663917, 0.04564007879385064, 0.03722442674540705, 0.03129128644603395, 0.03397633652052572, 0.0768294946981534, 0.03063176135202089, 0.04840662530172737, 0.03284683946760432, 0.012115101168502965, 0.029551062184656342, 0.011055638916009377, 0.06196392241925482, 0.10910594340173468, 0.04469772935995171, 0.054227514567995266, 0.027985136332591216, 0.08886284375142667, 0.11155344876310519, 0.02687879428718119, 0.032112546107401295, 0.06980419264084871, 0.04400543868541718, 0.09146571174384126, 0.08786531300434182, 0.04572289289846536, 0.013073192751635949, 0.010203003166093221, 0.018881753747982365, 0.05977603276410411, 0.031209219277145404, 0.034715710958886536, 0.07936822580954722, 0.06070937683445312, 0.024181211014248194, 0.046795956084444645, 0.036850962712759935, 0.023493095518900983, 0.05932479165494443, 0.0526706362143159, 0.02988748395094468, 0.03783512522556609, 0.030864238393523043, 0.0196641746668085, 0.02614691601915946, 0.05337367893286771, 0.02442309178502089, 0.03905656815115963, 0.0656848689240794, 0.022104909726148172, 0.030571636856503548, 0.060847579095993316, 0.020946385601775783, 0.016181854974298228, 0.06481876056040488, 0.0677132705647138, 0.023219008411791538, 0.018498123728580052, 0.0489118717791092, 0.04299100037784346, 0.056150720845307076, 0.0359639324878733, 0.04462442623691694, 0.018465235573990692, 0.029229799383169705, 0.025574834116043586, 0.041364136061841444, 0.02441671218783144, 0.04058093373333255, 0.013328101805170939, 0.09715806677817337, 0.04180535291051192, 0.004607802444708444, 0.0072519266658702935, 0.004638965465053315, 0.06601943484237117, 0.08379498061033026, 0.03179813021673791, 0.04997438210393152, 0.1252074031940391, 0.06922059452101108, 0.02485478999123218, 0.028542335062558134, 0.015033000794750069, 0.048388239191544634, 0.07911245969514694, 0.09258763218719153, 0.01260683672773021, 0.031851285227364114, 0.08044943634060123, 0.04157605130345591, 0.013418096068855977, 0.051398945581768794, 0.05037333771225907, 0.04742078122592742, 0.02810975777045373, 0.013578977405784592, 0.04947367086706143, 0.03077057265346089, 0.07682272248090276, 0.010881914115030198, 0.027560350154676748, 0.03573817403746709, 0.01834011043331796, 0.019121669503229282, 0.032986359400374275, 0.05800949529774728, 0.02083225956847591, 0.05538844803888952, 0.052048580480679396, 0.03126445230126622, 0.030098700137328238, 0.022487231650419777, 0.06545443733733508, 0.030288659299032825, 0.04472815071142489, 0.01216338002949112, 0.03986382181005132, 0.06292649657435476, 0.006790597615162692, 0.050327372436802235, 0.06102852906370836, 0.02512883879394541, 0.012269002486831479, 0.04966116322564983, 0.06070690237045769, 0.020866363887645064, 0.08907538718513905, 0.02804588327454704, 0.045523204420122414, 0.005720924368248352, 0.08078120603796937, 0.027867277535880287, 0.05570853872585201, 0.13284030490584914, 0.05144532837514436, 0.043448419986112465, 0.031003873239481644, 0.018261747299543312, 0.05822645139790351, 0.019195865118695844, 0.06342153109970593, 0.08687191147116885, 0.01973931831608136, 0.032607923457098585, 0.011064325395460812, 0.05441866499642211, 0.10362340452810449, 0.04320744702953004, 0.05372008857046885, 0.09494252517939576, 0.03783110709440324, 0.061431284468140335, 0.006066050329771374, 0.014156184437113905, 0.045733882429739164, 0.040653482259761904, 0.035568822640925646, 0.03177021205755732, 0.0374434283003211, 0.0316582789509407, 0.05590350427214177, 0.08324730435326215, 0.048337026213806485, 0.06763647791118392, 0.041422887344754515, 0.02138143927309542, 0.09746182064015059, 0.061468815115550836, 0.010597175512943539, 0.02095503664966072, 0.03667419558511146, 0.04991311039174757, 0.040958821923742374, 0.04666120887944295, 0.023483458132813537, 0.00351361749644932, 0.04679294535890222, 0.07239540843593498, 0.032667352727824644, 0.015060872031045298, 0.038118612231506456, 0.03701674797001385, 0.07596570758088943, 0.03317281370982528, 0.028417677235519214, 0.06159687820341318, 0.05964658688753844, 0.05534800625736675, 0.06707589307259168, 0.059015767108048164, 0.027172328536248496, 0.07889513587278706, 0.03562826723341019, 0.059028300306489395, 0.03590063064269001, 0.09177133486035371, 0.04543935992724953, 0.03178167847856399, 0.05034055297953948, 0.0384973086446764, 0.03834051342921392, 0.01740618030570688, 0.044143717555749806, 0.04301737295463682, 0.0275253169538994, 0.09782814856378302, 0.00790937326758379, 0.037338600659202185, 0.06774655708502378, 0.10916003687006813, 0.09605953499915139, 0.03753724342752849, 0.0130856225282074, 0.028982169122525284, 0.0036061226133061878, 0.03805626416578889, 0.029310765300667094, 0.04210926765095323, 0.00872350926886523, 0.032459087895169374, 0.1214913558214903, 0.048716358479953585, 0.06103048258791528, 0.04260498782499664, 0.0660684951130421, 0.03813850753490002, 0.06085346265125179, 0.0017472196017361938, 0.009144849008730343, 0.03984475388161598, 0.04274517425426072, 0.03839140848046349, 0.03426592541678298, 0.07764784514062828, 0.03606019143555914, 0.13157400753228896, 0.021872302449698892, 0.1105251825684982, 0.024193700162633777, 0.04883119889024285, 0.04090126190755156, 0.038475678152134346, 0.014176941589422285, 0.046065556366116776, 0.012220075323937402, 0.025829292135313157, 0.025705005860917514, 0.07493521973130203, 0.004057593788245633, 0.08535516463340291, 0.03109556055747934, 0.02895905241941012, 0.007088304170587611, 0.03869356121867895, 0.03819966050345571, 0.06251896078127527, 0.04073292557750979, 0.025493741794038686, 0.03011219477611444, 0.07983072841119382, 0.07553988526905737, 0.009688099192815923, 0.028869037088307164, 0.02398829475315588, 0.04120058778132643, 0.0277221689917027, 0.005686735300602572, 0.03866198307444011, 0.13023569789384642, 0.016814134151284254, 0.04426186746587196, 0.05277668576567404, 0.014877080834741074, 0.05847036230167555, 0.027138471280434923, 0.01729621029939623, 0.030970441162466045, 0.039281192791437915, 0.05967284838158277, 0.05946370254781458, 0.003703431580253246, 0.047312973502783046, 0.02044437393065422, 0.03855986738457315, 0.035934798164112915, 0.08325005460891031, 0.035142448745788105, 0.032246575104973974, 0.02448020747021562, 0.0033720437298348596, 0.02800406828042, 0.05006755754772214, 0.010179415318904626, 0.04238013335834107, 0.02041813158880799, 0.03104316971955761, 0.10816524105687296, 0.01377151924140391, 0.026108356898710616, 0.023962129020102085, 0.023786997490171945, 0.011594310767137477, 0.04469966373196052, 0.03657479950737569, 0.07019151137360642, 0.02743870305318025, 0.0848134485403857, 0.02696947611477827, 0.01316783908424118, 0.03432248185779299, 0.057461891819031975, 0.023206321995765455, 0.026422987293992794, 0.03218446452651293, 0.03158920654846776, 0.01633962695186417, 0.025562050023807154, 0.058640108233497995, 0.03104253578180027, 0.0454560338309215, 0.015774178412562657, 0.022414709937067765, 0.031114555707561876, 0.04323577696096994, 0.028238847416134614, 0.1029284172240765, 0.012627106456596766, 0.02210189325494632, 0.019174326556704698, 0.033483519819715334, 0.03884453799635653, 0.12360364408983339, 0.17992570816028505, 0.13550197014645224, 0.2336625319214598, 0.11069247318852334, 0.07621015857664809, 0.2392064804031003, 0.15148516894588548, 0.2083978714841989, 0.09033803031930039, 0.11903867170575166, 0.20024465817597606, 0.1204088046365688, 0.15283333047503425, 0.08282902800748426, 0.07673996200244274, 0.1420327318051169, 0.08942073962140469, 0.19087437630420734, 0.14732745656323049, 0.10837577734022372, 0.13342908944093412, 0.2632957168163792, 0.17749454345433943, 0.08356109396704743, 0.14950179795344032, 0.1441256380489757, 0.15767197244830672, 0.160602274080438, 0.15884408697245583, 0.15841503176958333, 0.11089781539574747, 0.14105253762775852, 0.14358707823820654, 0.11862571201016826, 0.14399757879155298, 0.17077163162250675, 0.18317134690380868, 0.1681805843667638, 0.1090829147987308, 0.22638143310623787, 0.17757251588327272, 0.08059282501738879, 0.19145404439299338, 0.1818404223529562, 0.23550673538158018, 0.11603536189443643, 0.1338100956091958, 0.15604022049134778, 0.15665627775653718, 0.1765860704284522, 0.10959781015351897, 0.1966354647471059, 0.15173054690803253, 0.18476419691597262, 0.185566597407864, 0.0656089649325417, 0.09052116363759964, 0.1529643621536032, 0.2059070898159858, 0.13001615241650613, 0.14016238942502007, 0.1743996708143142, 0.07303876141386648, 0.1480588866698165, 0.1984089276482982, 0.1259512822293947, 0.22077039064418888, 0.13725277216684434, 0.14466453493843157, 0.11543460340509493, 0.1715431434492911, 0.14340165431701368, 0.14024656716614, 0.12093515300582494, 0.25944088495546774, 0.09642262237086412, 0.08397678093564126, 0.25303196192028066, 0.06987020643728395, 0.2096228001098479, 0.09242717507145098, 0.22164632025505268, 0.08984801750029288, 0.11577599516679203, 0.11355295356723571, 0.09876180289974136, 0.24617287029902785, 0.14476697621566637, 0.17766971711910542, 0.11555356919885644, 0.15107603202904427, 0.2093052106999582, 0.0815345615809483, 0.20478657897441618, 0.12707059031292317, 0.2603161250871997, 0.1204496294620537, 0.11255162302404643, 0.15254532738078028, 0.17257800566092615, 0.12950305736834003, 0.09396631465924364, 0.2280813056014238, 0.15989834653033366, 0.3262144873940176, 0.17279044184232914, 0.19239358994508945, 0.10747879563320069, 0.2516191425703226, 0.11472555838765637, 0.18634174049140947, 0.18569359946395123, 0.33214621426117036, 0.08686119390110816, 0.12232924916691358, 0.1435356890602458, 0.11161054529610182, 0.12172843705141738, 0.23313607629989427, 0.08737123991933562, 0.14521967289188217, 0.12618608051730743, 0.15879911761130058, 0.2297365151706242, 0.13888144445034767, 0.15080025569806177, 0.14008001965140143, 0.1271765862381266, 0.11366268800150965, 0.17925712790700699, 0.13672843094794981, 0.08479051952881199, 0.13330148983626597, 0.08746435024565266, 0.10992581069829965, 0.1834215205763617, 0.12327398113425701, 0.2049522531489211, 0.10666718676445947, 0.16342817325024836, 0.17194613634097963, 0.1813264846080734, 0.10065434650788385, 0.1550874062964032, 0.18807754251024417, 0.10707480682721061, 0.1217603522743429, 0.0946599536485249, 0.305888703874042, 0.11750364601011239, 0.1805284967826259, 0.1712991138018908, 0.09426410835716995, 0.15884451598169344, 0.14000221576181152, 0.18056946716481642, 0.20184302402119483, 0.1390012912452221, 0.0903193990609819, 0.1337007288971255, 0.1100393602504365, 0.18518972811439346, 0.11556568104893931, 0.15766472525654301, 0.06769570416861004, 0.10237321798359195, 0.19878429540943718, 0.11194808363553979, 0.12744485490745114, 0.20580012861999775, 0.10182085326842724, 0.10757320064810977, 0.14740558220974861, 0.21713047708955505, 0.08048248537365468], [0.007888722409974904, 0.022994088827662414, 0.04014691428071068, 0.029442990161178094, 0.050786615334331035, 0.05774920543415412, 0.043528820913765705, 0.033657230256545934, 0.0491937346786501, 0.0745782150977081, 0.029326100465691382, 0.03874960438077969, 0.054189788568164074, 0.07901373394434491, 0.04175140882932371, 0.04614377394318581, 0.02520687250991262, 0.044905565183369384, 0.05265731777575228, 0.008736552873386011, 0.011616325261251581, 0.02079833911040858, 0.06439256286548992, 0.04943119129166008, 0.04027848222082661, 0.062228467901267355, 0.041466891435125185, 0.044546833021506194, 0.06440404652347488, 0.024930987011400924, 0.0833544111059558, 0.11309889325451468, 0.020722831569371686, 0.018144294529432253, 0.023778193224702152, 0.04107881427532242, 0.02216629826674058, 0.047831461809936075, 0.03926528880612985, 0.05577279435050103, 0.04710022322533112, 0.009696346129320804, 0.04470717522405809, 0.01808534406365887, 0.04905474717698751, 0.05574631452139828, 0.05715856696629236, 0.044861913493443886, 0.024442364641975974, 0.014375175458319006, 0.034341829408320694, 0.0035967373180263227, 0.07327936664824525, 0.026154659252854127, 0.0395950015574213, 0.014974559777446333, 0.025807717184145606, 0.031578079121367585, 0.039095711413650744, 0.06594068100375515, 0.07615609575183162, 0.06610422545383055, 0.01084049269857426, 0.019619402573293736, 0.03941827273416904, 0.06279714262833999, 0.013520609166833663, 0.05781334614561451, 0.04776517988272733, 0.013158763815168173, 0.03545307058600649, 0.05726310349400005, 0.039441335811129505, 0.06926226970409194, 0.08251148456287, 0.008822644876706745, 0.03162547123558339, 0.03856686559776145, 0.007517792213137352, 0.029777450742380276, 0.049170043409591725, 0.07952725034086935, 0.06267295977581414, 0.013277960392916876, 0.06381982021153935, 0.04950132281068833, 0.02034421176499417, 0.025269797056793206, 0.025514081428428332, 0.010753140480618083, 0.04278487293049694, 0.06012063060376433, 0.10124787312722015, 0.030633714876227805, 0.02485607510372516, 0.05284579455732338, 0.05521705118759025, 0.01713206063986065, 0.009093516329754024, 0.024010559183455283, 0.05417231410261124, 0.003129362157778815, 0.04698588843307188, 0.09625545432490688, 0.041879858791587815, 0.0156598761790402, 0.07242305654912226, 0.024551635593055718, 0.032507110116702896, 0.08822876043737897, 0.0393123495873184, 0.01493774637985494, 0.024315002524564346, 0.010730827212213509, 0.06176197781197487, 0.033428258067297364, 0.01787710029842152, 0.04097111380448745, 0.0666234721880286, 0.004371742505745422, 0.0197870934742593, 0.02528610898392095, 0.038494393680124514, 0.04238376078466254, 0.015529308941275364, 0.03556761222200529, 0.05523840971891919, 0.04311721719380829, 0.013303755530937305, 0.05612015776756791, 0.10832365271785568, 0.04083804816247956, 0.02531091491090915, 0.05639082046165582, 0.048555809433662125, 0.011013331710390989, 0.08540013399455817, 0.03633410234244601, 0.07412128961615025, 0.07216217296738779, 0.03822291510239725, 0.06065900655343168, 0.04404016928146443, 0.07587697927749927, 0.038790344936592926, 0.06142340142339949, 0.021741548478002512, 0.037397780951352856, 0.020497048221107934, 0.008754763740956063, 0.007291400782583703, 0.09781041362833592, 0.022521916281191573, 0.036856991824724024, 0.020086746850621798, 0.013140573057406133, 0.03612309108458219, 0.012198578896782091, 0.024641536010970033, 0.0399005250825036, 0.03842958647217001, 0.018803555323111436, 0.04960947910383825, 0.03434327731449758, 0.08904406951079447, 0.06741851057496763, 0.011079139620696586, 0.021018248479512912, 0.018983834963892738, 0.05149582889111293, 0.03937950485476083, 0.020046479354101806, 0.0074280057508017755, 0.02453172113746405, 0.051802942048638105, 0.04881011615056665, 0.03767582873303083, 0.012055872995857031, 0.015770984783528313, 0.006707080146072493, 0.05902981716057947, 0.012857217244022797, 0.08201869084469735, 0.03848569092130469, 0.05736606571102335, 0.02728421376236985, 0.04516277154306731, 0.00719871228342996, 0.02894342997141423, 0.0652363091226547, 0.0651312171812019, 0.0454910938447762, 0.042350087389950795, 0.05709466757252813, 0.03911336590986579, 0.04186812998546709, 0.02292145411634157, 0.04256588286690174, 0.0036833236874606943, 0.01422986102801177, 0.03144039396917628, 0.018216084628816576, 0.04866003186532086, 0.050788155171058835, 0.02885913923232546, 0.022306411917651855, 0.010036167410773136, 0.030898855991601467, 0.004707403450963959, 0.052582325428844466, 0.09433952205243612, 0.06276852158348888, 0.018486599850979064, 0.09009168708636876, 0.017138620267712304, 0.03709084399405026, 0.08232072100884492, 0.027330659757999164, 0.023912237544033318, 0.06695938642106711, 0.027484781326605912, 0.06132307837927534, 0.06668363307272235, 0.09967194599730354, 0.054533248767256744, 0.03224265656524128, 0.02474305223703625, 0.0360019993968308, 0.006321507136172225, 0.010773581621657697, 0.013629701044861109, 0.024460965256777503, 0.03323680120370081, 0.04027942067853386, 0.047723470225689874, 0.034906451530273885, 0.021752947866315805, 0.0500628805809444, 0.03857936432224609, 0.040466051188207446, 0.02561034995221323, 0.03852104204857061, 0.04238474903808486, 0.04755254068802442, 0.045790860219107526, 0.022375947803318984, 0.0632319741341616, 0.009727904163751631, 0.04680021170286402, 0.00543430837194225, 0.009549250544589615, 0.03073224527460914, 0.029034831921660134, 0.06435464917411728, 0.05841901525855065, 0.03994059531138309, 0.07724781700920674, 0.032505079983703555, 0.015933147402510287, 0.029501379467546943, 0.02733449019762057, 0.06607861513452185, 0.030459098540426745, 0.0502743361698043, 0.03490805648447525, 0.09872921351944247, 0.010109855492989863, 0.0224141257950255, 0.02866204204638639, 0.037119656560882446, 0.02370651229284704, 0.041398495105245424, 0.029988224512987563, 0.03521319696559541, 0.031891265440912496, 0.05531423327122485, 0.0459132197823736, 0.07158081182428906, 0.06739395745699445, 0.05598043099105839, 0.031534640020841075, 0.021975877537061612, 0.05406145351908861, 0.025648602637492364, 0.06455240711089104, 0.011991442128595327, 0.051187788767199364, 0.05409736006009964, 0.10070567439881065, 0.043294164352118976, 0.05379323081503953, 0.01680445654558078, 0.005412142096658148, 0.03584773993239768, 0.057726130865874796, 0.07268065361366158, 0.07292771696924202, 0.03618476116248677, 0.04655173108462365, 0.034639309010198044, 0.030124854379063173, 0.021034859180931124, 0.03626582858663413, 0.03516769517333277, 0.01752887120200021, 0.016713757481005405, 0.026548625713574792, 0.05152778624887428, 0.057520041722924485, 0.11536567081366816, 0.04791017351371627, 0.053987365155931444, 0.03497343442793335, 0.04018740202750891, 0.03325565845795697, 0.02580701621369489, 0.04474388998782924, 0.10441291942110947, 0.022153669307308815, 0.0535349672540061, 0.025394305496686892, 0.0738416368802709, 0.057129107055164156, 0.048519987162322774, 0.04388380690567917, 0.01658187352962071, 0.01361152848168727, 0.08352457455569699, 0.006577415455643449, 0.017541423552639542, 0.03925500790618601, 0.008913207960675561, 0.04629712942386827, 0.015283755736515648, 0.044593051105978034, 0.06299491588687224, 0.02242007829819716, 0.04155068230184336, 0.018352488498954524, 0.02683593358303751, 0.017045578889308438, 0.05149057352795236, 0.07448269159442956, 0.013133337356961303, 0.04283431241469037, 0.15073611881704102, 0.0522107306507326, 0.04265725417363067, 0.035274468677779364, 0.05122920731082559, 0.02808803343214095, 0.013667689429806366, 0.11754079361356075, 0.07869806741514514, 0.21826571214102933, 0.15397340720219, 0.20952146199922408, 0.13371035096145448, 0.21693607461788963, 0.07158235166101687, 0.15289610371954981, 0.12739281455475476, 0.11060297879720889, 0.08427356339750752, 0.17040746406682078, 0.09812129210800895, 0.1685617590743688, 0.1155024481516692, 0.11664628637053313, 0.1505292291122098, 0.15192576143289768, 0.14787295713059365, 0.10397846329837077, 0.15270835089106716, 0.24221810992927323, 0.11686769344152943, 0.1425236869122713, 0.15013087871334246, 0.11934497664051673, 0.1988869052260153, 0.1389142943005408, 0.14395663905287945, 0.15237222215340984, 0.21576192229986194, 0.14644394268191632, 0.10702063675008475, 0.22682726563465214, 0.2161156557380192, 0.15097190535837604, 0.19796884077931606, 0.10423532491850276, 0.13930273152166797, 0.1999873905292442, 0.08388989890414862, 0.13165015667196245, 0.20456973012656937, 0.09894684377697208, 0.08874625283023042, 0.20917983275027047, 0.16451321422092377, 0.16932268356603963, 0.07390443310742417, 0.1360227567173781, 0.07678943596059278, 0.14567413157032383, 0.13128093293597623, 0.07820309800726753, 0.07633475511665307, 0.11596934043712194, 0.11656099014104375, 0.12991050889174785, 0.12965275094874446, 0.16191441415538713, 0.21231273399485698, 0.14882223199932806, 0.12280130488497597, 0.12327156795729553, 0.09670874854970364, 0.1366999171554081, 0.1634244194194194, 0.1287979653645908, 0.10020843737067715, 0.14756122063244545, 0.15541778937462838, 0.15916233521796044, 0.13307227632932125, 0.21459474138194518, 0.16806781622430972, 0.16056370921432972, 0.24484560764845342, 0.10831994485230216, 0.11488357168291846, 0.1447433040988061, 0.17434446651849056, 0.1056914512188204, 0.07573274024311574, 0.1231302094135073, 0.16720527783036235, 0.20746407159153493, 0.129681954220418, 0.06770429967512047, 0.2227975665441444, 0.10706241152459577, 0.09748398356380002, 0.21649332176293098, 0.11151863006694664, 0.1377357752813447, 0.14136704736419264, 0.10842458480187964, 0.08950441940537385, 0.09223260406044223, 0.20316254918373403, 0.12104479550954797, 0.2866265261846204, 0.21797234643130534, 0.19352781376050365, 0.15835987343903513, 0.14085660298024455, 0.15307331517819436, 0.14649638906121254, 0.1754318363964558, 0.15319746738720327, 0.17266754601751605, 0.21161017008125785, 0.22461851157488363, 0.12469923409122614, 0.18892779285388608, 0.10326235495027035, 0.12489011255843986, 0.14585993853547882, 0.17300923655350364, 0.16895629435537324, 0.22276546746011705, 0.13115956928701172, 0.10600515656293401, 0.12750306226793798, 0.08385981463136212, 0.0894941921315847, 0.14844419825221264, 0.16408766770074446, 0.09298669504782847, 0.15893157421340867, 0.1701898031657742, 0.07626266624297827, 0.16569041556889014, 0.1848022408422924, 0.15420733981074827, 0.10152548040834167, 0.1983561441903153, 0.22187732640774022, 0.2121678054813416, 0.13122871638305728, 0.14292746121364255, 0.1914981250921565, 0.10613017445129734, 0.19267638364145834, 0.17771149955449567, 0.29377283949044447, 0.15301967370173625, 0.1594150523024221, 0.10696131090122847, 0.14562032155452237, 0.14017271629023936, 0.1572704810889498, 0.0897082447585079, 0.14438304359153395, 0.17146829665908891, 0.18205642850408632, 0.11901417987481241, 0.07983439031147188, 0.14586646560459368, 0.11481035665999498, 0.15697003672680548, 0.13495689858832668, 0.14954074586351074, 0.08536748332722534, 0.1874349632811162, 0.1534986318719964, 0.16425717231487075, 0.08359687027311133, 0.04198794613682455, 0.20599359646439555, 0.1737104981176315, 0.1550880344885011, 0.10778087942350296, 0.1417423998035731, 0.12619947173422383, 0.1280707104371921], [0.10797721243673757, 0.0037006535539178243, 0.04615192511870016, 0.04697226355933855, 0.03700385087980859, 0.010511014561709619, 0.0635141626210703, 0.009600063241387327, 0.026345995457602606, 0.041822386875508294, 0.05994821102508615, 0.026278311589492426, 0.023572810797861988, 0.034823020724880124, 0.035312148712335095, 0.05783717531049925, 0.02133513691895191, 0.09018961610572954, 0.020006135248789386, 0.06232351643003284, 0.016583681497122013, 0.021437605009264043, 0.04585203617030094, 0.04594307805922243, 0.01632711099040124, 0.08116912998018727, 0.060004043513007706, 0.011531543268281366, 0.0575225851348331, 0.03706528347045664, 0.05305894703093556, 0.07248327872084995, 0.011083392366286249, 0.056450326341174306, 0.021165220532566312, 0.060272982509265986, 0.06519449604374748, 0.06838415674264393, 0.028618133717006253, 0.047223919612025066, 0.041941046234100096, 0.05402478855103255, 0.02003449773896606, 0.041132865608820034, 0.00596178911491147, 0.06772983338563673, 0.01783031722410552, 0.10458013343234217, 0.04729590506383008, 0.07315251780974288, 0.04047671130167381, 0.03503636089003375, 0.019500300798925663, 0.06588586741277287, 0.036542585510159695, 0.06672680212725556, 0.029966124791591883, 0.021021755246986306, 0.04252257974698179, 0.05601798845154624, 0.016451650073811892, 0.02748851792045659, 0.04075838267923363, 0.06601663096056831, 0.07769829203044215, 0.06269317683613589, 0.0423451844272354, 0.03485229294446688, 0.0024700716781925654, 0.07762877721219294, 0.026360305980028167, 0.009732073597279529, 0.046361243322251305, 0.015622851149659726, 0.02094585508588822, 0.08820758576715186, 0.026439873787063747, 0.032485904802958813, 0.033998231313401656, 0.04227583814832953, 0.07129614121250569, 0.06144403217120036, 0.06355705205351114, 0.02150579832584387, 0.033075731217620835, 0.046058657744358626, 0.014890110075113275, 0.006172189896460623, 0.010614931515808548, 0.095409149334075, 0.05894102373971574, 0.013428704471387451, 0.02752143097290349, 0.027154428891897685, 0.025385022426264423, 0.03385456684496134, 0.04252504655009797, 0.010769701386321216, 0.00916326480482014, 0.05426297677801021, 0.06602247621143056, 0.0545439969808344, 0.08794547644473853, 0.05328106273326182, 0.029686864675773732, 0.053922523474020344, 0.043037838993533965, 0.027993881226246877, 0.05987337955664243, 0.026967158698807323, 0.017864469423769944, 0.04273344161770037, 0.016949883016246944, 0.011355167803084178, 0.0570913695640141, 0.030991075740706538, 0.035641390319553115, 0.035037770491814425, 0.05311747231791097, 0.09573542618102605, 0.033212355338037014, 0.02521935782785858, 0.03686560648343256, 0.0263227638412988, 0.05552707930966731, 0.020912821374593243, 0.03782944468360755, 0.053799106709418766, 0.05636765013238596, 0.035849854335068695, 0.11818596988075203, 0.015810869236086166, 0.08815523897928577, 0.06819264242245306, 0.047303596586589856, 0.05595844043719192, 0.03781210045300184, 0.050820212120250355, 0.04597817254703372, 0.03242169131314562, 0.039465042401946364, 0.052128912460419445, 0.04091084183704469, 0.04554257112284822, 0.01740454279276873, 0.09568808194730552, 0.03189884971136288, 0.049127847286722356, 0.04920145301448722, 0.03975989432224343, 0.06231500136275446, 0.06843774459294735, 0.03069892811078218, 0.024881149161486857, 0.006046684584655469, 0.021221106646642573, 0.02543770246237757, 0.02993722603986821, 0.090355213671442, 0.06327237761128815, 0.06285064237853212, 0.01364918074555575, 0.08783503720957427, 0.03803411656389794, 0.042150012037206086, 0.02343266650343374, 0.030529492444569067, 0.062109398685636065, 0.07682472197038513, 0.03022601245902479, 0.024252755965496746, 0.040979092610218835, 0.027647446690788193, 0.02037844057345102, 0.04999710427176568, 0.016778627891213666, 0.03686469483880266, 0.038874576303867564, 0.044545637924344315, 0.020955251154279517, 0.041783105717190815, 0.040926075495419004, 0.04205724262001534, 0.032127249249888044, 0.0316103678121562, 0.023132503678601597, 0.03568672357247241, 0.044908897665840004, 0.09131993287272992, 0.00910940116286398, 0.05302434283939581, 0.01649919349039274, 0.053592699639979875, 0.03737166501401413, 0.0248487800314662, 0.06514317581369992, 0.021221771227916884, 0.030963649793017297, 0.05882421065302146, 0.033507839280871615, 0.01942304849264122, 0.052119573848622466, 0.05709395894119817, 0.04018470156757582, 0.03945347830472935, 0.04266090458258987, 0.08760237630697028, 0.04438015527182049, 0.031575233104728886, 0.05398349641191383, 0.07790924200127203, 0.08293986560836916, 0.05145225764041947, 0.03189828280629891, 0.0565933243131205, 0.022745384128704187, 0.012709904281843095, 0.029820227176852288, 0.08020427288307298, 0.07143468055273257, 0.09070400584248767, 0.03566399374375901, 0.01863086569843994, 0.011028367143514897, 0.03680079544503843, 0.045939366363229296, 0.018310842044170828, 0.029171032778498147, 0.05476184557342241, 0.1006897933961403, 0.11000478670241372, 0.008244677503112583, 0.04509506469231941, 0.022796290671272625, 0.04336347232662863, 0.018250880342337395, 0.04776968064928248, 0.025909315764663682, 0.04577934974804521, 0.019525713850593856, 0.04136030179178042, 0.010591526572111874, 0.015641251623991038, 0.02504684057297005, 0.0041503967217830645, 0.08111074641947785, 0.015897388333424686, 0.025300455895522912, 0.01104858611905647, 0.018189535851800637, 0.03228486034898989, 0.06092699177022423, 0.040673802741953445, 0.006354065394149192, 0.030025462131767027, 0.09034723103527101, 0.04214890887059512, 0.03596320853478486, 0.007181634747182891, 0.04581368963925108, 0.12842170894145966, 0.03615943812614968, 0.00987076519748136, 0.03052792004910448, 0.06116409981322866, 0.02219395021036748, 0.03925856638459429, 0.027143948809093526, 0.05081558111874808, 0.029163235918648785, 0.10232732165604831, 0.06379642388633182, 0.06744126338631877, 0.0794009760683102, 0.009268413245257352, 0.017443758833612648, 0.07102699154206822, 0.06080722158414222, 0.023007213829025146, 0.025298789654287602, 0.0560743035748601, 0.052675305520214384, 0.022724197967158213, 0.04303694267066256, 0.015814192142457734, 0.05429784143944422, 0.02010991909511147, 0.047570842528535474, 0.04141800736467685, 0.040300557044364756, 0.03752322018807454, 0.05203976663911054, 0.009570302640748842, 0.07318288553506136, 0.08450651541352273, 0.04447192494427005, 0.01595073390842205, 0.019957762542030504, 0.03496111573411092, 0.01815671856034427, 0.07620818973068269, 0.054345377195145816, 0.05476792065066196, 0.031043215684833068, 0.03339351597993124, 0.02222672728220782, 0.017026062799437393, 0.04319816970476701, 0.01582890486104354, 0.026677002897486094, 0.006984112382445846, 0.019373612838887402, 0.06870599794051341, 0.014051664188774604, 0.07878373902771743, 0.04917808350235705, 0.02745787631870518, 0.01027185723350774, 0.012026957007155064, 0.016647379792806123, 0.009466279391950418, 0.02747589853712388, 0.04209855008089254, 0.05942456311576309, 0.03326519625261426, 0.03728433099064616, 0.02469385790097858, 0.008886934975312363, 0.0009266639033505213, 0.07355556432758609, 0.010788060683426599, 0.019289576824033455, 0.03752163055563166, 0.022821584979312557, 0.030610962064876675, 0.053235051492529536, 0.09015477442693326, 0.04904158195600875, 0.0805190354285221, 0.06095589243716771, 0.06775413369459492, 0.073446266563429, 0.007788190606891388, 0.08991606909060672, 0.030195432144307324, 0.033293602792846586, 0.022574602062964154, 0.06732811219990253, 0.09918379477195202, 0.05663623289775945, 0.04227993671872443, 0.048310550215143355, 0.21553857702641718, 0.09689732109226527, 0.12916225549434462, 0.1166282220172786, 0.1034172119632844, 0.10632946456391966, 0.13281847140000713, 0.0975775995081471, 0.10136922911530542, 0.07371986720470652, 0.10773917359690513, 0.09841551583620811, 0.11142969491981691, 0.08895144948074896, 0.1322530219030957, 0.11667404939690906, 0.1090941686303385, 0.21646954239376132, 0.08732598710564837, 0.11458902619779111, 0.13118085120954823, 0.13182862451480282, 0.16152069092758242, 0.06656374031257245, 0.1172507603863074, 0.18928396245164258, 0.1638945675785503, 0.10041791645269241, 0.1231382609975915, 0.11104180928199522, 0.21320531835719464, 0.26248023154274114, 0.09077017285650776, 0.16477641138818958, 0.15968241698799596, 0.2125832549626789, 0.21539007854317466, 0.26332121222249927, 0.1442048668621048, 0.11670256318945078, 0.12172051570228032, 0.1398825528280389, 0.15290980137163593, 0.18439866572378144, 0.2084548071387314, 0.12943496747362998, 0.09903818444018403, 0.1992644639986177, 0.12056176175153065, 0.1437547135977976, 0.23822988683898605, 0.18460161773668182, 0.16525831133607896, 0.18225383404041492, 0.11839632230300097, 0.17882130048688383, 0.1600462014997198, 0.14630785482304712, 0.11111815760452902, 0.1862238395598627, 0.10441900215922825, 0.07754816944080015, 0.16111028230478688, 0.15098711986455227, 0.12498262533617598, 0.17708076404467707, 0.13489605588538034, 0.1462342184517653, 0.09279298971617415, 0.20288930094290167, 0.12486915239283156, 0.15215347340751081, 0.12682944115611816, 0.12131278072634052, 0.10560757991287018, 0.14404754304597456, 0.09389006592814, 0.196850934636689, 0.14965999510980424, 0.2201395019167854, 0.14923123102034294, 0.15516248291298268, 0.1729336849624111, 0.10931110940873624, 0.16330725393227993, 0.14051091346529224, 0.11051739145430828, 0.1064333307646936, 0.188958237187997, 0.16657987429249674, 0.1265031489874086, 0.050569980991103, 0.12163504327256834, 0.1841868270909594, 0.19355796698120334, 0.170287418089086, 0.1409724967614297, 0.2667681788725238, 0.17279805675629648, 0.11560308146140269, 0.2199452066974294, 0.1726210904457877, 0.15327853481135062, 0.17869097360920522, 0.24591713482814453, 0.17949723518423497, 0.1515355315660277, 0.10786648208816206, 0.1007370227166722, 0.13121301158060952, 0.15594531751928792, 0.1573616149084222, 0.14647427976371782, 0.18036104528413666, 0.08017408135797709, 0.14965506150357186, 0.13717012660157296, 0.09925419059131416, 0.28287487104535103, 0.16772620229711457, 0.06753749169048763, 0.11153130882209349, 0.1947945861085769, 0.12087535984333485, 0.14322332436999968, 0.21424650845508422, 0.15510490374459376, 0.16851135048895113, 0.17432123873262637, 0.10842659961312048, 0.3493254601715073, 0.0919406249698612, 0.17648142281799548, 0.2011340862560657, 0.11400517526893847, 0.18695301736795134, 0.1428509596735239, 0.09660282923329262, 0.14752978038403297, 0.1307538031570373, 0.2380017611768938, 0.11900068906646584, 0.1540371457174901, 0.10630925516447715, 0.12409085302703804, 0.16431309673334324, 0.16221006280712544, 0.09736884054878066, 0.16080006266072874, 0.12973463042609154, 0.11388465431669068, 0.14025160802468178, 0.15154814137326134, 0.11498855637206186, 0.0866100472968913, 0.1386047947791315, 0.11193473072301958, 0.09903410119154761, 0.1956240754694708, 0.19354082193345795, 0.2809107441815638, 0.09980638676713552, 0.23860264990118243, 0.09535680254620892, 0.11074548647288354, 0.1248243285883819, 0.16278404652351336, 0.15316417320601403, 0.11801007609333723, 0.14711434622445416, 0.11991012736313766, 0.09715621284539662, 0.17539140227581226, 0.13763265984673656, 0.11510046649604075, 0.07893414506989141], [0.03588913549338618, 0.018898247620992122, 0.07047448893107715, 0.08986991229316882, 0.0429104347412865, 0.009988826049882318, 0.030850259204124732, 0.025122229370378682, 0.016049273882902438, 0.02113056271487186, 0.10812889018486585, 0.04430172702057227, 0.10300514092969318, 0.06851239986116849, 0.014880218922400908, 0.020506884790055697, 0.11208216434404736, 0.11221399275405754, 0.02735270968367977, 0.04978009837589437, 0.05396366239555421, 0.07029031373320088, 0.018796834816795685, 0.07689926998629686, 0.04895431688055397, 0.019595303362415686, 0.0467327346784934, 0.03350997666618036, 0.050066492685507384, 0.00984707105559327, 0.08630051713196502, 0.03786233666863653, 0.03358131094324974, 0.026558073492900982, 0.02096049502612122, 0.025679805398648305, 0.014833196445608572, 0.10640686242690972, 0.0332686398178339, 0.047894104819504485, 0.02842607738960895, 0.007702411742009704, 0.060818180471899054, 0.040346135445419824, 0.013307280492998902, 0.018501649648251555, 0.01970693003386259, 0.05740173476477785, 0.02609233033933467, 0.08918871457177786, 0.007711729286388765, 0.0004907499093068538, 0.013490746101935305, 0.015547212416065798, 0.038984280094624534, 0.06257295848861819, 0.054155073293875304, 0.019009533383312727, 0.04046908106594797, 0.006727522723526965, 0.033058693422184836, 0.05178262539688618, 0.07515621311481922, 0.06096018252954368, 0.01936501158671754, 0.11270392130339339, 0.018600417533889413, 0.057642309355639645, 0.025009323332098224, 0.032576195925714514, 0.026723119475307967, 0.0331204669219592, 0.02529072466366474, 0.03330765667581751, 0.04053276212465379, 0.03070117083318051, 0.06540792813945202, 0.07155893235317162, 0.03516394900338304, 0.014708446688018741, 0.028420090412480697, 0.11621183790867368, 0.007344400660405237, 0.08387124466319239, 0.005474762602393786, 0.07215379196549616, 0.0307203728270026, 0.03004830495844926, 0.08324078494502653, 0.031134519958868626, 0.0968431127107432, 0.011531030946982004, 0.07615293946958358, 0.0014267210926552634, 0.07940341988878866, 0.04377168993796072, 0.038197354578803626, 0.08556116567624193, 0.05810661609434794, 0.05159206485616104, 0.04873682068841112, 0.007397004566530908, 0.08543370396740015, 0.017432005129634373, 0.10015092715020142, 0.05567034924282663, 0.013124480422946715, 0.07826602446936792, 0.025613010192530292, 0.010215050856312437, 0.02095148774735149, 0.04355310973140501, 0.01583586189700591, 0.04490290685827213, 0.01843867913609551, 0.06194329167145395, 0.03475946224024219, 0.044229044428756165, 0.03469591907736275, 0.02768744988697431, 0.07338231354351006, 0.011634359928599049, 0.03763286269179756, 0.02360807382501662, 0.023040776140987877, 0.024478458874528448, 0.03748799929575574, 0.016318006035421165, 0.025337484755343007, 0.040399167881978136, 0.08795682986777636, 0.020603898334346955, 0.03461890042789521, 0.04773391966497706, 0.03987607921683981, 0.037659342520900314, 0.021629465984240658, 0.03921664222293804, 0.02328268947049735, 0.04572137987481491, 0.009978270315895639, 0.010697276391569647, 0.016175011893914595, 0.0604183821668548, 0.08511815235138902, 0.06227338746670754, 0.02818677450470146, 0.029764126558157227, 0.038288189623985565, 0.03788988902083328, 0.03466110421164382, 0.048898028570317456, 0.04223380290392426, 0.06845243049845581, 0.05716916962316441, 0.029907406067415595, 0.05515534663572908, 0.03600943811057556, 0.023206017475815553, 0.028170445340595422, 0.044037227503835194, 0.04218950770014236, 0.016866607343657844, 0.021395924080523755, 0.023556709544913425, 0.025604878169214054, 0.030300673472905354, 0.02995430022448061, 0.06928447093213759, 0.07884773801291182, 0.047412580254697995, 0.0269221069832002, 0.04242148295405411, 0.04014036805939771, 0.017456699973873554, 0.05464884377415142, 0.013889203753112065, 0.009556801298693305, 0.04782328382134438, 0.057137549344089725, 0.03405149357633726, 0.04098440542997372, 0.04571801674882731, 0.014874676276268739, 0.05228366605156372, 0.0997830287463242, 0.08601119636648125, 0.049102202493457064, 0.034430251276541146, 0.07420595765354172, 0.03168347366755048, 0.03100650666672136, 0.04107009236430449, 0.0649793019458171, 0.015199469785476405, 0.07475356496269665, 0.1309429043002667, 0.052955092321480476, 0.06716986141738392, 0.07384405005723238, 0.007865038322990821, 0.06184313333623352, 0.04022855244036164, 0.035013596587363756, 0.04414147674857129, 0.035890104594610395, 0.047691616289798296, 0.09518971876992334, 0.030869419063110987, 0.041480029843026595, 0.09550324025293512, 0.007491822311309197, 0.030856135098503965, 0.085023938858461, 0.03952732151975075, 0.056917915766638134, 0.01864711250809412, 0.04319873660983097, 0.031504649593825304, 0.04359594936813078, 0.022848179721603953, 0.020384019608759595, 0.021730664283818295, 0.013086022809147837, 0.021186774416315942, 0.01881345509431295, 0.04295720440906383, 0.026513471853949373, 0.03727163308330121, 0.04070531576871872, 0.05770836528691073, 0.06101840904222862, 0.04986758944728682, 0.0283762606071128, 0.0035353140640748486, 0.01943536910168346, 0.06242355219118538, 0.0408968837150643, 0.033361459030739726, 0.01973937002701625, 0.033774541300391, 0.04548539798105917, 0.033939529826203664, 0.04529054351751843, 0.04540657519452995, 0.006562916284066535, 0.06891976711490462, 0.044885608592941884, 0.035724882411980824, 0.05726227611904183, 0.034130684085070126, 0.05859252268208131, 0.019846231631574132, 0.04949234042977614, 0.0352613379307572, 0.03349637094464514, 0.041520192002457, 0.0402303718991818, 0.0268809259268305, 0.04200668081701283, 0.007606197323184461, 0.04569642839112109, 0.049755476310008, 0.03695004086400713, 0.08583816774790326, 0.06289405275076147, 0.022281983288966363, 0.028505537944335132, 0.029643172766232205, 0.10988434235895835, 0.020807061021426515, 0.06890910317099865, 0.052779535612752365, 0.04123988043096277, 0.01992396274281125, 0.027799744970135154, 0.005071389539572861, 0.020779315232028885, 0.055892913106588595, 0.045504910240490595, 0.04476259785494016, 0.02026722184382379, 0.05697636827526074, 0.07386826609651889, 0.06242080959641646, 0.04509683052498487, 0.007176177807137251, 0.026279895476275877, 0.0444877025250706, 0.015932556557198687, 0.013210260245438307, 0.048569847994874564, 0.009017375808569693, 0.0643562656196375, 0.023980248914731127, 0.04671291981433188, 0.019253879041981795, 0.0492452617524372, 0.07234228023838613, 0.015978182838749022, 0.028490656686405984, 0.0033029742001916373, 0.016902010181858655, 0.02204158872876677, 0.01583094840058156, 0.013902481972059656, 0.032381375936130365, 0.035599466157896865, 0.012531038073282088, 0.031234536567823063, 0.0203401725664134, 0.015338463032798422, 0.035312439825746327, 0.040368083864450455, 0.043306234067366015, 0.036287792327423254, 0.0039592822037276725, 0.049379085821490136, 0.04787142478650616, 0.04131655817130401, 0.07122307174628781, 0.08376493464193999, 0.013626636693163986, 0.014932989931455063, 0.06242485454065665, 0.03374250350339759, 0.07829868279758, 0.017761819387575793, 0.07503592964982794, 0.015344418408799798, 0.05133471677019712, 0.04051779659705297, 0.06339324330310188, 0.0384792672740596, 0.025237288115726366, 0.026250525580478773, 0.031822007262117924, 0.0596760391377874, 0.02647197861675053, 0.08921709812937245, 0.0348872150624952, 0.0045863146360422815, 0.015849475279420374, 0.053963336808186387, 0.06689537977499348, 0.07899167061212563, 0.04155273541748043, 0.03582977134013369, 0.08464150776666018, 0.050836365084133806, 0.041772782682411136, 0.007939389550067004, 0.11419936323598509, 0.10817536873923195, 0.16072135478738817, 0.14621192529316873, 0.18836902364367442, 0.10982039699991865, 0.08313962303462528, 0.1334805552276873, 0.09940959152675445, 0.15554744209493362, 0.25849976126224766, 0.10240460460584971, 0.2066486629266893, 0.13209240390889107, 0.08205285070524101, 0.13790371707610546, 0.20818304510847216, 0.17195038046808014, 0.1387407753856913, 0.12854344031262782, 0.1915587992557595, 0.13977404413444383, 0.14783168031323343, 0.173069542994903, 0.12783247241449933, 0.1704304313827907, 0.21926354166240464, 0.10162124905975596, 0.1449920988130954, 0.1287024188786745, 0.11285556074712547, 0.17558643293957557, 0.09789851373962818, 0.1338493652761944, 0.15729458221504766, 0.11483092612076191, 0.09467685354813453, 0.3502993111408526, 0.10220486250135208, 0.24679231367284254, 0.12305471144856946, 0.1319575724342177, 0.14124291047694223, 0.11862914408406905, 0.17052568675529572, 0.1703853088040506, 0.10724690081852098, 0.15563623168535773, 0.05483557004481555, 0.18385255228607886, 0.18762898270881948, 0.2092499451171006, 0.206891191041758, 0.1944844124297942, 0.1608234130206608, 0.1714790984988213, 0.21139028752523087, 0.130603481384535, 0.1460092337501626, 0.06833682016980264, 0.17195721397236471, 0.19064108720950543, 0.2217074081061348, 0.12184661377461688, 0.17028107488107297, 0.16971711159473465, 0.11983548741667502, 0.1525272936710427, 0.21190430187890608, 0.13903673047259932, 0.10694071079694456, 0.1276801588133939, 0.11643670769708774, 0.1782748040052191, 0.15551960245976526, 0.20446454625456564, 0.14059055596590042, 0.2279368214189045, 0.12351093979011621, 0.06192158073967984, 0.13227761332546512, 0.17873585103980957, 0.16144144679269484, 0.129826775481624, 0.10529812635673631, 0.19287299244634568, 0.26470942482832943, 0.1825075776826951, 0.18428186795884566, 0.15250208937833387, 0.19963909631534932, 0.08650074187185496, 0.1156618940313497, 0.33881712404470293, 0.2180025456172805, 0.18038854784061834, 0.20926057841748963, 0.2056544340185581, 0.11692015514258416, 0.14357206291489064, 0.075553851051917, 0.1497055773412989, 0.18036585631630114, 0.06336324713042667, 0.21675348522201662, 0.132374094438649, 0.12250127421031076, 0.17233887897624126, 0.08526520292845466, 0.09085421270180134, 0.12123270921649472, 0.1645811049327735, 0.09333763992594135, 0.15260451533381017, 0.12396449448480723, 0.12142348043139904, 0.20204553170309913, 0.15756004700256934, 0.06468753735985487, 0.11342454190936782, 0.09536627905383226, 0.1251791268887539, 0.11268043304763495, 0.12464617484159048, 0.10205140742923945, 0.126366195449185, 0.1499881718548075, 0.13508976887791388, 0.1566272889894824, 0.1683288070583536, 0.14302300769955884, 0.14634795186500396, 0.12383264309215931, 0.19058813521217918, 0.12778030182685585, 0.2102612271424263, 0.16037597170760556, 0.1117773456198554, 0.12349797758243738, 0.09903094490929958, 0.13699715927002892, 0.1315472404202146, 0.13600619389645516, 0.1938806125713933, 0.19013415150825055, 0.2391159900974843, 0.13034264376807597, 0.059266339146321824, 0.21159110981370174, 0.0861803179366454, 0.14403125601670436, 0.0796265889620108, 0.17131731605097172, 0.1349860712164833, 0.13739638300912996, 0.13569099468088922, 0.17821048326309652, 0.11978166207911507, 0.0986162155506111, 0.1751354216567932, 0.05846448257685669, 0.12938745470056612, 0.12237397337993308, 0.17502204064399968, 0.14794981107115746, 0.1044402534382478, 0.12973738834261894, 0.17390966565618593, 0.1818765204159483, 0.10576160189004676, 0.2160268661475951, 0.09975095264493458, 0.17599339416671186, 0.17522116221727865, 0.07282571236212408, 0.12318716038979831], [0.034495920333410465, 0.03565310380391536, 0.036810183852550485, 0.04072195519843409, 0.07858185187703179, 0.03444141700803753, 0.005354369012263394, 0.04046228203561999, 0.0207137419361501, 0.015596039029919814, 0.05696580775322453, 0.022740188137357755, 0.062096666304334525, 0.03974996582274476, 0.12008421318305117, 0.01191852587996231, 0.027693772027569435, 0.019572360944303296, 0.028876640510955648, 0.032080761119422894, 0.0018943949074920028, 0.006391619981807327, 0.011242973268963398, 0.06715241759534805, 0.06534817328135814, 0.02305969276705817, 0.019317991025145018, 0.0320936122443527, 0.016996897832160036, 0.04053251697651802, 0.01427943649281177, 0.03437154212846391, 0.042534959727838155, 0.09504669781533942, 0.03131240174444693, 0.09133320917645771, 0.01513873625005926, 0.01818097098880718, 0.0315251232936017, 0.05489599906028279, 0.061315980574656884, 0.049603346570004384, 0.05497820795543733, 0.06952067116095174, 0.04549873174138127, 0.03511714486164912, 0.080433432763863, 0.04390859368046926, 0.04077004253744118, 0.011759770437023573, 0.028621077409855304, 0.024994618274391662, 0.029702347312723438, 0.031044512288644913, 0.07000236426510158, 0.06148070096969605, 0.059042089889126445, 0.02576162358896146, 0.04281294622248219, 0.061882111889820915, 0.011855945115037745, 0.040257702085880503, 0.011210383888664506, 0.008675205510019535, 0.02489043989278857, 0.08533991948370973, 0.03869848333359246, 0.0338516786934868, 0.09686201209983519, 0.03167536462687197, 0.07086268100406855, 0.04676082329223714, 0.03055883552728882, 0.007042566806288257, 0.030951319607876004, 0.01903617409087958, 0.033458484066349846, 0.08611570608111159, 0.06305564750706957, 0.13327158176370207, 0.03491072247045175, 0.04010014461293336, 0.04445194154076519, 0.03017264294377979, 0.03629979692519673, 0.005121626234012506, 0.005410452872785109, 0.036890427732179244, 0.05967628428592317, 0.04275997507295782, 0.07331995398647363, 0.09236095443127618, 0.08999671516639572, 0.006665929254414815, 0.005559128513860126, 0.09884310781114525, 0.023288414062511538, 0.03596243095554171, 0.056064459345033096, 0.05800807803508736, 0.04383891798375596, 0.020517451057751334, 0.07597503853180716, 0.07988263852894306, 0.005837301263630751, 0.04520324396810705, 0.04690865910942516, 0.03355812912266101, 0.04083936583370932, 0.014999825357189103, 0.022606028904837948, 0.06374053777225556, 0.0286778828294407, 0.05012536271204872, 0.10540449766502266, 0.007519221445921088, 0.029784454701228008, 0.021256946154960224, 0.025615865785268047, 0.06420024032253893, 0.04814593707241359, 0.03303977488089473, 0.005998865855226835, 0.037881412257951115, 0.052512898710706545, 0.04139363810780548, 0.008457764859251198, 0.029721064755933422, 0.022681486650159764, 0.07889797039810689, 0.054529115722905246, 0.03647900404288404, 0.041295846984271085, 0.039997063652281804, 0.02863748509797358, 0.05043969624826024, 0.05852713707774397, 0.011020382592124085, 0.046634794167813756, 0.013440629587538782, 0.09791971905337227, 0.028018779083785993, 0.06293998738270133, 0.024356490016103755, 0.00965689643165998, 0.04682185751716456, 0.03672289962489759, 0.04488921686706524, 0.012875738377202184, 0.023376688458806565, 0.06939612058622223, 0.0057041039502608686, 0.019566176699534542, 0.025488375348129103, 0.03094554522014674, 0.02289291159550269, 0.01994654893003885, 0.023308707731625727, 0.029437112351579052, 0.050271842553610765, 0.008238724999940925, 0.048479736902781075, 0.10081715551355194, 0.05391278266606312, 0.13588012646763556, 0.03819631652966623, 0.05299201392899117, 0.001441717383474292, 0.058538854392545844, 0.011610254014451659, 0.05227898908478599, 0.018185770529652798, 0.022415778629722136, 0.024213181778548226, 0.04888109419675124, 0.08961526466713798, 0.07242421334188792, 0.008845975126830802, 0.05100775427455383, 0.03090555160005968, 0.057225921416595105, 0.02470241318787298, 0.061841827156322624, 0.019045189030528552, 0.0501736645556746, 0.05372686461815911, 0.04606156504803127, 0.024255446849330783, 0.04117918328472203, 0.011209673342114736, 0.08093148950607547, 0.1419656837899839, 0.032671531737451596, 0.04787464618622776, 0.047992983787891366, 0.02582927106789524, 0.09024424583560998, 0.026584032382215225, 0.021534019089754552, 0.035726311165959604, 0.05094690391072824, 0.04662134549430302, 0.029968721829655192, 0.04870887380093337, 0.048607340337888855, 0.07458658843872047, 0.004931752778394449, 0.02819115269718872, 0.05589882730536404, 0.07544083776132715, 0.03287104018513234, 0.05800305249830408, 0.054235868756809545, 0.04811942659979386, 0.03677830310358155, 0.07207205038397543, 0.026116498498125907, 0.02781891249000065, 0.0323802727695194, 0.07065502521131309, 0.017697715065291813, 0.06058094985482674, 0.027286734191640735, 0.03459590246840831, 0.05830047081314749, 0.06218155267678442, 0.05673933684104874, 0.020409212410149556, 0.02702142453692373, 0.06942876359267582, 0.002145107714421747, 0.08045900477877549, 0.02376304766643913, 0.03425780488478561, 0.012679411109627016, 0.027627216223927758, 0.0448814066006772, 0.03169461641640913, 0.04711439202149068, 0.017466638049471284, 0.06500138059979485, 0.06190478809237961, 0.03896661793753024, 0.021081322413538734, 0.040750825221860604, 0.055310923771391955, 0.04865518635919979, 0.05957408049594491, 0.027984663273297974, 0.0558084212694197, 0.01591897286069129, 0.04204311978913123, 0.009307321893321651, 0.05161545352048932, 0.04095762299614088, 0.0742344101590495, 0.0457109266050881, 0.014425550527389974, 0.04295908898535756, 0.025492514138140028, 0.036573301805483724, 0.025460493578124913, 0.05145218103162704, 0.04050072432766038, 0.006169516249604884, 0.04426102476915525, 0.047780585910884604, 0.043005238121916214, 0.013186066231179624, 0.04065266637612255, 0.02256870127072738, 0.07860188507625172, 0.020921506896434773, 0.03412039169380742, 0.030060096966823744, 0.08168945689835856, 0.04925180797375018, 0.03217314174699207, 0.0378958338631257, 0.04746523730817342, 0.03450726992600868, 0.06047167124286775, 0.05433118541634852, 0.10867318033330864, 0.047150172157994205, 0.06756331651441513, 0.013919478590269724, 0.0029429037784857136, 0.05178701508069231, 0.032745911214019985, 0.04378353748770972, 0.03336738472083404, 0.0863198072258984, 0.13089497783972373, 0.04022243522828625, 0.025472241536443754, 0.03973743262430353, 0.0784835627963466, 0.026051273772252664, 0.029797911035617995, 0.04067025575486403, 0.022370303650536848, 0.055628256541827036, 0.030761848827223146, 0.04248904041765679, 0.07049635308043611, 0.049523213773124644, 0.042965003184133, 0.04304025600093507, 0.01613048111809598, 0.00978023562985923, 0.03251040046433768, 0.07169679753602513, 0.05088370548741472, 0.04280757977657261, 0.029098800263337554, 0.04512594186610753, 0.008942941748236698, 0.07112460646538005, 0.024633679779306538, 0.03400157528719114, 0.015487941150974124, 0.06521957776238842, 0.015352841545527261, 0.02825726991549375, 0.01950510800065052, 0.07303657806328229, 0.0352166137177377, 0.065508293318412, 0.06487881419278922, 0.006117053590940252, 0.05135881406585536, 0.027088158456007802, 0.07921730648846396, 0.06586556608277945, 0.061077007107556834, 0.023225972151023247, 0.016697296166732427, 0.06027868603386226, 0.04173876071769384, 0.033529243777476014, 0.04351906861448961, 0.05731608996528292, 0.03693683733863216, 0.059861562650410406, 0.016982564327096748, 0.03847602672213989, 0.016167536790993427, 0.044628517146432595, 0.02518586254858923, 0.08030555736754211, 0.04372999560268175, 0.13801735855879324, 0.1156097770698609, 0.10578603243395206, 0.17846477848868217, 0.11981924635268028, 0.0821836602183119, 0.15789550158285326, 0.08907051486594063, 0.09598545429687347, 0.16804955268819488, 0.21967612597490513, 0.12211334260721361, 0.12429210432474652, 0.11377216962676857, 0.19142628136661746, 0.19643877933342613, 0.1280867523183265, 0.1386732523960452, 0.13073111163272014, 0.12642346052152495, 0.188779907240983, 0.05958819566594978, 0.13523779238664335, 0.1237813458447495, 0.1268715759919536, 0.15189819758938206, 0.10041050072158537, 0.11817444791837085, 0.1405682474855454, 0.17134719348001867, 0.07687923678707692, 0.12686661174220423, 0.16417893941604322, 0.25503617050426625, 0.11906065842917851, 0.23343603036576704, 0.12368873347558322, 0.19707668542621598, 0.16906645779888477, 0.08800489422414573, 0.1854998405061422, 0.20100147643637276, 0.1281106236180471, 0.14664812043549555, 0.09427163134058637, 0.15199936716066254, 0.15493360648472465, 0.08066404055082992, 0.18523469747554872, 0.1076149601008623, 0.1965594381815003, 0.06722251464041971, 0.11391553532091842, 0.15287667572979005, 0.22526968631052205, 0.1373094626732411, 0.08339372673822988, 0.10526358345223051, 0.1124818707185407, 0.12669386657615825, 0.2168482656200086, 0.19056176646582543, 0.08908447298792102, 0.09818686923432736, 0.07590028367215589, 0.12928754151348146, 0.17231961952582484, 0.09119964940773864, 0.1770416629170218, 0.22673721966003219, 0.17144845498185005, 0.11626960859904367, 0.09761887632550732, 0.12611673423840156, 0.11562764990113436, 0.1818569085650867, 0.09630439968238916, 0.19099702698088464, 0.1701624691486359, 0.25279088937226807, 0.19557118475917848, 0.14219186358874844, 0.1594148224760448, 0.09547584494876285, 0.08962008336018171, 0.08011274069787995, 0.20690082842784546, 0.1739054521726024, 0.12817519716918468, 0.23039342024393622, 0.23201366556027245, 0.28063464609365313, 0.14381276774069957, 0.13646094368830805, 0.09510534184594309, 0.21014384715066803, 0.0785875975364639, 0.08415969974932172, 0.1986086774136751, 0.20546396923882349, 0.1483751277649595, 0.15080790125554608, 0.1338164541389673, 0.1798794211279, 0.12107995894527245, 0.17134111074189987, 0.12305198417555903, 0.18029698501190833, 0.1338436196167623, 0.28132060122105385, 0.10022938221452699, 0.16985419536790541, 0.07215523221079381, 0.1421482578640984, 0.1696261463146056, 0.10350642290206687, 0.15107528126287847, 0.19104354383964695, 0.14834980089818278, 0.21577744324120784, 0.1879828540428031, 0.2825254736648452, 0.16344665129098201, 0.13619083640796525, 0.09583422087974126, 0.14377081676596595, 0.10694623429087863, 0.07726677768533269, 0.11790598772706525, 0.20093770727755564, 0.15015534756164398, 0.1926454336893174, 0.11586398036489565, 0.15756020022015418, 0.09079120197002927, 0.1016828042244719, 0.1126145265035091, 0.11062976123104173, 0.17879658649044652, 0.11426745313069514, 0.16753567623034601, 0.061741948443194555, 0.22344552371050083, 0.0765342444121357, 0.09792045449777957, 0.08118979903238435, 0.12604669848036382, 0.1270093875486524, 0.14070159274964564, 0.08952855883586792, 0.14190379920746052, 0.1095743908456737, 0.2142536790380555, 0.17045813312213268, 0.09973651954844114, 0.14257663890959757, 0.10507292715051483, 0.16474800484795726, 0.13530223570283384, 0.11473713397619226, 0.14130134766380634, 0.08196820565048726, 0.23681922785697446, 0.18801472330045318, 0.2101515693169448, 0.15612093551505, 0.15212244684657744, 0.1362265667487537, 0.1443730844485183, 0.12400246180233457, 0.07855093256840784, 0.12660216585162187, 0.1030216271418237, 0.12916246999896344, 0.1821913672310691, 0.16840371513558974], [0.0583650635164832, 0.05921472397242343, 0.02129981643520296, 0.009201539515127099, 0.030050758355026765, 0.0462447481620456, 0.08912520588285501, 0.008584937369901567, 0.032296949216435035, 0.08596667133632206, 0.015147896746413843, 0.1279560653793235, 0.05530109103288382, 0.04133360745805887, 0.07176398344698452, 0.03610712581224019, 0.036799355199740785, 0.03743838361133972, 0.04080705224506317, 0.08320228136595219, 0.019445628934209386, 0.04147619940340519, 0.045850622738080646, 0.011964598407728538, 0.014722339692525567, 0.07636611109539386, 0.06646555848419666, 0.03602552978742508, 0.04335755429741356, 0.08420157411526288, 0.06289511378253661, 0.04156952806478066, 0.04063176366710856, 0.042374173194290175, 0.011498535412453837, 0.017067640306307905, 0.010562760928165047, 0.03469083225354552, 0.022976122150618224, 0.034452077121503895, 0.03148518904532877, 0.007436784639609077, 0.0203507139362515, 0.05189203807423192, 0.02696994151319227, 0.04435356819040833, 0.0179861624905419, 0.006345587673657124, 0.011385982732228454, 0.022016694701667276, 0.01683286117059329, 0.032371252084210995, 0.018568048403868755, 0.03012207731033766, 0.04280759126789147, 0.03398699663399208, 0.015850972981312345, 0.01972219625097369, 0.0830962241537148, 0.07717119289502021, 0.05760057671596447, 0.07374947650297996, 0.05390648542332554, 0.060772107944132826, 0.04575573508777926, 0.020635148975998163, 0.06699807386124326, 0.06323124635063353, 0.055186982236562244, 0.05619192105387488, 0.02100652541905161, 0.023887479497540384, 0.05981455549537655, 0.01824928687945489, 0.006467224720249614, 0.04268287981469785, 0.022913270382090442, 0.0017917351754975597, 0.04643552320738954, 0.010191207327279113, 0.04404422188658388, 0.06826665417681779, 0.03691103549734239, 0.01521530099243166, 0.04779795695456767, 0.05433710344556359, 0.03644043534633614, 0.04097993530693554, 0.025077909268739245, 0.05864434853015889, 0.007489779729381084, 0.035919039735510465, 0.059194694603643114, 0.030770237489994016, 0.012223493991299503, 0.030753352912142876, 0.024263511839953643, 0.05015433998778463, 0.05921265553502787, 0.01275068601488226, 0.009618919538033587, 0.027792654826395938, 0.013753411795703635, 0.03989798550103461, 0.025037567078646634, 0.024429881239249825, 0.01664537838810394, 0.05249575749340077, 0.014969261321840028, 0.06213662928090461, 0.023448673910611582, 0.004682146489710337, 0.05067447155353524, 0.007604383131218775, 0.029414346133689248, 0.032853282267047514, 0.05109124636698154, 0.040530574943629966, 0.029754887537790403, 0.031904281274746024, 0.018407552983731996, 0.02160074151751976, 0.014396061887964608, 0.0445819849659118, 0.01893631452994962, 0.0317198092177991, 0.022526704330718326, 0.028365694339417165, 0.0166185250911381, 0.08689665611112311, 0.027619915406009363, 0.044018646041231776, 0.019084857063247793, 0.06451824725034737, 0.03289545540727916, 0.013902187985818715, 0.08999319116194403, 0.014870785507223299, 0.021818036611582485, 0.04851936280066448, 0.03555455808377555, 0.03226029957013746, 0.04107364701227315, 0.021347087890570684, 0.005239353838166403, 0.04953299671591771, 0.01078730034116175, 0.061467007148049535, 0.04149566186712154, 0.03957161289309302, 0.062220209473443616, 0.04865860311134208, 0.023191207081019398, 0.023323259571747437, 0.0837011884657606, 0.021153160393418326, 0.019464966908638037, 0.03453411747731509, 0.05519846972498683, 0.027740371240783605, 0.057181599399735855, 0.046927834290169904, 0.03214267059980381, 0.11040444711163161, 0.032830016176787116, 0.013467764421816797, 0.028867219544706807, 0.012638900380191064, 0.006379555054609814, 0.024882943722449487, 0.06964932030607617, 0.06076135206967593, 0.02567450981587172, 0.10414243675768377, 0.054894351971245585, 0.06582192205373319, 0.047045915252378875, 0.04110983700581616, 0.048757627636434576, 0.09144621480616832, 0.01309189391547754, 0.0802481237558588, 0.05061428768620376, 0.060379974348771, 0.028235708370864875, 0.08538700324753601, 0.023500308236708085, 0.08132549618641216, 0.020136772392077312, 0.037073760233338804, 0.051286962679437095, 0.04135928672528075, 0.054280033725644314, 0.036928314610474536, 0.021955488106956886, 0.04964867982292368, 0.017406576756207694, 0.04911757404765776, 0.039328912408241344, 0.009152687045805638, 0.07587744659113307, 0.020716377278609623, 0.00945128705127225, 0.05158122471203247, 0.010910064015807885, 0.019238997784052646, 0.016229689504290302, 0.04178136286716308, 0.014358930563884638, 0.05971869108297172, 0.03821823430517989, 0.024472772586910475, 0.06275734436067362, 0.03302595082430109, 0.0387167277175092, 0.05917919664493492, 0.05163028498270339, 0.06864229772960947, 0.04027993778788275, 0.05539559946966268, 0.04303732188418508, 0.06875914145982073, 0.02030860399827361, 0.03530456444188472, 0.07965425239695657, 0.028507960697395668, 0.09298502497615353, 0.01705776160252431, 0.07915879269280741, 0.028729185822509953, 0.03482659452504689, 0.04306227336787889, 0.0682983855386415, 0.023729447050080187, 0.05407814274451906, 0.06855566850713185, 0.01691401094919251, 0.08880604599272052, 0.031732043641949856, 0.027547889734588327, 0.025443157008398446, 0.04496415941825798, 0.024594463738462618, 0.08513489137253455, 0.12084860039213974, 0.08252500601473355, 0.010450853677015873, 0.011488742893561723, 0.033133302725130515, 0.055761889088898904, 0.03956490196287632, 0.04523882875218988, 0.06099656404506776, 0.0238127437900872, 0.02261807563744726, 0.0844500087682278, 0.03704695864730785, 0.038942823246602094, 0.10866356592985893, 0.044186380992252985, 0.022111003955585823, 0.04462778170202528, 0.07094079132882819, 0.07044580659919208, 0.04012562086685531, 0.046126379916865023, 0.023461390970154636, 0.05398216341892558, 0.06817060973375075, 0.024249333467695023, 0.023195568036528367, 0.08047966617009333, 0.030741361720908075, 0.023738561581159313, 0.048926998185174125, 0.023770277621224526, 0.06762599782837976, 0.0396949760315399, 0.019370962174669392, 0.022023181551166122, 0.05933859655933996, 0.015816957719864386, 0.03390807042559309, 0.03631146827472314, 0.018041843676098415, 0.04251223372956438, 0.05021973325300121, 0.06459201385657634, 0.09096229238615883, 0.04341280838895229, 0.05286391636717224, 0.06601981022545407, 0.050191376508483966, 0.04975071124311897, 0.03425920299524742, 0.0624356908543456, 0.06473757822306887, 0.04091642278757307, 0.03655120016886823, 0.05850849815854623, 0.004921709844512084, 0.04015500033875147, 0.04612430764902984, 0.04184928422252979, 0.0649875910171578, 0.009116190617092916, 0.03719988894919234, 0.05497936474820299, 0.051795231373680216, 0.013917464736638772, 0.04887718331789778, 0.03710758684563541, 0.029234859393909577, 0.026592955391313282, 0.051605084520434184, 0.05016362880386653, 0.017765536829228365, 0.03095784093133144, 0.04145458423262162, 0.058148620695236235, 0.038056524635683146, 0.06452822937600075, 0.026914595491102627, 0.046807052868027846, 0.022262647229757522, 0.0530482332913145, 0.027233219119690122, 0.04612181786327593, 0.05176303269822271, 0.057970011126129865, 0.02870577034510432, 0.025703015947534193, 0.007074874649274975, 0.046067797173295295, 0.022480792681416197, 0.03695127426556522, 0.04424189172324635, 0.05934485166724171, 0.0890027697107965, 0.04522125086476726, 0.09033465953243357, 0.04561675524699592, 0.01180617908586658, 0.11798360775555335, 0.021150615066289905, 0.02169499714528361, 0.03711021069677607, 0.040884059403211846, 0.04060130018079954, 0.022460592858072732, 0.04110270855768074, 0.01927938019376128, 0.16000795839053972, 0.1079304734124772, 0.14877016866399398, 0.24221916713060873, 0.08261872921139002, 0.1491009501079398, 0.16747860267998713, 0.16088925061687348, 0.13194243453683394, 0.1500435446899745, 0.09299741261788914, 0.3335592481157472, 0.10195588392596092, 0.12025069941075579, 0.17234836314474383, 0.20577336150792339, 0.09652122554759826, 0.21027702387542496, 0.1627778105678097, 0.1472648671798168, 0.12149164693490153, 0.1606082648880059, 0.08884036673172828, 0.08798765724584942, 0.11014140316195066, 0.13270539682238333, 0.16394661559212595, 0.1438055971577283, 0.1346707800703664, 0.2420941109378492, 0.18975532102969386, 0.13051395634970359, 0.16820344443042434, 0.14896132292286043, 0.13179894626861619, 0.14691404487577178, 0.15670889267517676, 0.13181849683244384, 0.13006234751834025, 0.1313039615389801, 0.16721450152897066, 0.12923901750435754, 0.13522317542904808, 0.26871707590837635, 0.1133834106487132, 0.14768410113550004, 0.11201114033258731, 0.10486013856866669, 0.1085856011618049, 0.08817865828713102, 0.19565116433847338, 0.14640484155426103, 0.19023944263256368, 0.2945817057644167, 0.1869835076673377, 0.0923971291030607, 0.18901710338409872, 0.11075721527900427, 0.16141633443053693, 0.19807521974848163, 0.08359645658563222, 0.22773606041746758, 0.07687429551996532, 0.1830999934745412, 0.07043513499440686, 0.16539698857213223, 0.13610316530591057, 0.15855383157970446, 0.18141175019404582, 0.2578241636435832, 0.19310645008039093, 0.18137235795297932, 0.21667113077015648, 0.08837960314966979, 0.14245997904048813, 0.10795576963573696, 0.14011366623303584, 0.14836283971465405, 0.10688567504046426, 0.15560656876092957, 0.11200049937131906, 0.15931731480504238, 0.1983272779973284, 0.12768051121383905, 0.12105170562262497, 0.19184802809069235, 0.16365229993337588, 0.10038512022865397, 0.13849775697435104, 0.1793606876726112, 0.14486238480575625, 0.11797768589589866, 0.1864926904560097, 0.1562177077416451, 0.1612377133701117, 0.19336373304888127, 0.18929902374023394, 0.1446620528135569, 0.20254712011064255, 0.08253554738457165, 0.13445713347004307, 0.08237984767484088, 0.0687994223628794, 0.09625841908517385, 0.09983123099851994, 0.19494233382565362, 0.16490935828656922, 0.243409238755703, 0.1002154623969428, 0.1827120005844101, 0.16613327567615818, 0.120217198385827, 0.2728807944203577, 0.13713146980491378, 0.08523940874804413, 0.08254958977622372, 0.1986413587245249, 0.13334641323214577, 0.1271720893020111, 0.0897791002306246, 0.30661562938363324, 0.09506145266876107, 0.13578241961377283, 0.15531920918053196, 0.09904214511475257, 0.10297537075295564, 0.1612450678141848, 0.15880284079861257, 0.10407443113264539, 0.12082098292246943, 0.1323066020925199, 0.18057731190516105, 0.14526974439861315, 0.12950877238425518, 0.1894121289613747, 0.09360555619482072, 0.2905149739836493, 0.0805517167393719, 0.12863846585875557, 0.10412503890092335, 0.12355180291999733, 0.08470399755864375, 0.1571111960877334, 0.19648675175924457, 0.12248705561843612, 0.10721241154016987, 0.10458391024580888, 0.15819642091951064, 0.14021575510982545, 0.2646877292183138, 0.14306273701931202, 0.22134072778205718, 0.1715887410025443, 0.1526578197315816, 0.21407694255392398, 0.13272185239099688, 0.10975632140593183, 0.17875995216590745, 0.18142609135998836, 0.09683395029916879, 0.18058998299942863, 0.15204237533673165, 0.13301573904050937, 0.12696364443869362, 0.12984107068229106, 0.1326303968145963, 0.049518735989207224, 0.23457345642870475, 0.14662449428391072, 0.1411042179191305, 0.20784694701433185, 0.12177368220422538, 0.12879577435312733, 0.1281887645863237, 0.15397045010280225, 0.10465133364402479], [0.04081562476893587, 0.029818633713969783, 0.03069090525499515, 0.03443264913174414, 0.017487347321284395, 0.022574751450109388, 0.03712743618375352, 0.07122149360516379, 0.03768220258456084, 0.055561407709554325, 0.025007275962120584, 0.1396336355396817, 0.09877517113402005, 0.039538023768052946, 0.0518200334702288, 0.03100577505275367, 0.00544647480578973, 0.02337461619097139, 0.02359780824683126, 0.025954166382190683, 0.06874568895587037, 0.0795779960049737, 0.04282411195397858, 0.06503371717107874, 0.038998437399465236, 0.07365831970086983, 0.06530118910896202, 0.035266715867985646, 0.013464310322888197, 0.055769454207151174, 0.037832957196740374, 0.053189350517406586, 0.02152742881838593, 0.09148972860026745, 0.02950430017775826, 0.04415782889531505, 0.026028867615687273, 0.022610115983913985, 0.05911793259363021, 0.050236671457007054, 0.021780649605657787, 0.03335614621098484, 0.02213185303844512, 0.012715683457621885, 0.038569995066932136, 0.06203872707462119, 0.037909780493787223, 0.09677388900590521, 0.08632759067920909, 0.05486606417464153, 0.06623231535477024, 0.016768172706267046, 0.027688011046378847, 0.05573830890258955, 0.06299650168887551, 0.07529261506973736, 0.01901577125423618, 0.025327966112883824, 0.06249030526246756, 0.041344478245704405, 0.04079279534879231, 0.025487570955808607, 0.06867346218636922, 0.009570979670951925, 0.030461415956397692, 0.022285003590607838, 0.01856997894543794, 0.04608667357974956, 0.04274371485676497, 0.0729183170704111, 0.018682195504586545, 0.05656028677138591, 0.09459718040400937, 0.061887574096721035, 0.027540177144410632, 0.04933860956601078, 0.07133828370922035, 0.07770614443166603, 0.03040235823831491, 0.06069413934563918, 0.09601975971412274, 0.031491091752785354, 0.06020664312546292, 0.05150656944381134, 0.024926813747433406, 0.05616053443161711, 0.07711949728188977, 0.029987575253471736, 0.026208053665956663, 0.04953657817696372, 0.060141797613112204, 0.03834152466527397, 0.056066481817153194, 0.020570171313480507, 0.010250075438600636, 0.07521100372316376, 0.0757443847795648, 0.06144636873936942, 0.026207063497314532, 0.04037781318108882, 0.010214241675942416, 0.07497554659963616, 0.05702532512406188, 0.032762309326039206, 0.05345594911505619, 0.04036785020763355, 0.03644341542836159, 0.02747308124878234, 0.03170337854704309, 0.01565838709563738, 0.05760530347845728, 0.00407071017111922, 0.03455592033964011, 0.04433538509352554, 0.08876222576345168, 0.06694276997398946, 0.019458240656662854, 0.009567354159850267, 0.12654870057538634, 0.06873737690189193, 0.09837453779313834, 0.0615417581772612, 0.040211801927897244, 0.01552556085610582, 0.07265904993419686, 0.03612319833689159, 0.025046472850766395, 0.032802291454807404, 0.021618449639889504, 0.023963868039690202, 0.061130322996647134, 0.04620065214112402, 0.015035849684218486, 0.10483229893349832, 0.004736249055337882, 0.04448776764254417, 0.07027446337404751, 0.016769408023044947, 0.014059732052227183, 0.011210206730832017, 0.0419747464418892, 0.028248620782828623, 0.02467121234193685, 0.041409193523108, 0.059229961461237365, 0.05311633850778303, 0.006891895506170489, 0.03797508565889251, 0.0537469246304564, 0.04472432793268273, 0.03857210946960315, 0.036269256830095284, 0.010742279269071597, 0.013417205491644001, 0.039379198419591116, 0.03608774761819551, 0.03900731252806802, 0.023526058367062962, 0.07920498013376229, 0.07288343708721862, 0.047745621658020446, 0.016771447732143344, 0.051681352403735926, 0.03965564890794697, 0.016572630678814267, 0.053574459086502754, 0.04978386369804221, 0.009800818497164836, 0.01876914839921219, 0.040745792024198084, 0.07188814331687267, 0.011667232761429924, 0.027898882493196477, 0.018123045165632522, 0.01439546816982329, 0.03933125663728964, 0.03666764170291924, 0.049881865495755795, 0.03224419257152946, 0.1250871656943233, 0.013527993296813822, 0.033221812693462256, 0.0532122795289803, 0.013345459442315324, 0.07057617944214614, 0.0052670900514649776, 0.0641556003791911, 0.03504376896026154, 0.10936771564546133, 0.03611806171735929, 0.03818367224847598, 0.03546451977003486, 0.02239323649255018, 0.034332517609601064, 0.02401152636945969, 0.04136242385533068, 0.03724725233511098, 0.0671203185113207, 0.03631840137043788, 0.131626162798174, 0.038636548955354004, 0.02500092700844811, 0.024285398971950336, 0.04570762093569483, 0.05713472631008876, 0.04567359897097753, 0.034336872819450595, 0.0503165744275095, 0.02756152418442071, 0.06737423835382347, 0.03287976209615027, 0.02192268613725901, 0.029776326508351394, 0.018587305939065355, 0.03501380343110331, 0.04227127609474044, 0.026462153539121635, 0.020859099458903078, 0.03673997189429018, 0.04063417684407004, 0.054923199012034365, 0.08925212366927056, 0.009642611764701865, 0.024426477893646208, 0.07406465273590819, 0.03400602242759159, 0.0874535637276788, 0.05523754787000437, 0.02488890197128058, 0.09022644961312895, 0.07785078949264942, 0.07927528402257351, 0.1190865368792607, 0.04597566743952133, 0.04179633988608276, 0.06120231610933139, 0.027408291277806127, 0.01641867190389143, 0.10535445680180866, 0.04952711699109885, 0.014755748786903439, 0.018689902349104805, 0.041621767600337346, 0.06426458021685963, 0.07077350070880306, 0.02083417095784699, 0.06249629607003543, 0.08914851027751163, 0.05511036578325495, 0.04907451224543395, 0.023069207579077735, 0.03205194280693128, 0.0006689932824003571, 0.04472716628844219, 0.013449863819856078, 0.03078758555103935, 0.06935834479067596, 0.043933978003840295, 0.04733045179877551, 0.04549585891166522, 0.02373656017645713, 0.06676745841339712, 0.06130359293292127, 0.024341411490534103, 0.027467582652705814, 0.07061123562556121, 0.0531487631791782, 0.02376567534801941, 0.03702132917580105, 0.009665478531631732, 0.053997190233560345, 0.020644338200649908, 0.02298894071681125, 0.054468441559302236, 0.009944795146434298, 0.04067441178185325, 0.03305844827404907, 0.040110287617050835, 0.04315474401077917, 0.04683604546552224, 0.014062626906971057, 0.03453246272739864, 0.04600000988331534, 0.02674309713315339, 0.03413423490259917, 0.04406486029526399, 0.08458564463522165, 0.11166724346337781, 0.03276232847823732, 0.04662754314561044, 0.06829152139083994, 0.06208958765191417, 0.04572088957854337, 0.02353580875111924, 0.018924388456188383, 0.012332961252409846, 0.03650416237031741, 0.03535924396748024, 0.04842097029810952, 0.023956643830564235, 0.07121933323721732, 0.031023900693042145, 0.02336721961206246, 0.06580207271561508, 0.06475463134026335, 0.06629350279728252, 0.024915473730934244, 0.04635647059448304, 0.06925209605645749, 0.0780634938048259, 0.044298229829197934, 0.007518553513012106, 0.056405119492762515, 0.0397765873781135, 0.011130440698546028, 0.05020354581516116, 0.018699985981408148, 0.009972466242259309, 0.03411148592168766, 0.021698120868794864, 0.025841279496108333, 0.01709457978816523, 0.04248891018270966, 0.04492819159021301, 0.01729782291447684, 0.13314027429348038, 0.02798175596962533, 0.0499699924201254, 0.08010418349576574, 0.01573029593864997, 0.01779521890585461, 0.0629380491802529, 0.053562990750276276, 0.04857784978324368, 0.04707628297769735, 0.05319151471579268, 0.03195511695418147, 0.061163414164536425, 0.04681848673029773, 0.030053432001882506, 0.04455780340058189, 0.0709296600712884, 0.04273834458041576, 0.02916696293640041, 0.02733351726595673, 0.04401409547896155, 0.059852227869053046, 0.036499814821347114, 0.038418734836722576, 0.04220300616936819, 0.019302219190003893, 0.050757117118806615, 0.14162834463340623, 0.11295299180933546, 0.07345201988374034, 0.15634489365883414, 0.11916886834848313, 0.13149905348977736, 0.09999710435588514, 0.15380393323158065, 0.12870140764261448, 0.16301083919261733, 0.12799557253357866, 0.19583721645176413, 0.2190680973111622, 0.13813745050180343, 0.10842496018496253, 0.17497080468362378, 0.07737120313029136, 0.16505955748500364, 0.11577633224547872, 0.17771565175104528, 0.1772221532319823, 0.21294278002554373, 0.12228706070492346, 0.2299268726980494, 0.08192476080430132, 0.180689666360136, 0.14659441767200349, 0.19181303319431123, 0.11352079319617442, 0.17634248511204798, 0.1198152397128363, 0.1543296534087389, 0.07746468117881207, 0.18836824223399165, 0.11563219280252535, 0.14002450892040808, 0.14205603619977353, 0.1224582200689662, 0.13603562699450603, 0.1642335001980105, 0.12160120516895287, 0.1278617829384823, 0.1569007057696581, 0.17087237218454962, 0.12422613649358674, 0.2110352670593608, 0.13109958460254054, 0.1836761069153586, 0.3025202459144977, 0.1939037331049481, 0.18829216970311058, 0.10905014921820934, 0.13360314461733067, 0.30218512841290046, 0.13069141295648393, 0.14419381987423668, 0.17974661212534676, 0.2457420990592049, 0.15745219714458913, 0.12489173666483934, 0.10418564411661319, 0.12371183868737952, 0.16218171755392707, 0.14013240474366373, 0.08839573696135514, 0.06953852100958748, 0.1390360103499505, 0.10753580789652564, 0.1442901324480772, 0.10295126196597854, 0.11779931764448844, 0.13027276122762313, 0.16529387313752406, 0.17070798503775753, 0.10841653321779544, 0.18558947279328303, 0.20292455630917705, 0.18481429906622057, 0.1136146083233818, 0.11246883190206944, 0.2199490371370508, 0.11976725196525936, 0.17283875134683427, 0.2549643421004857, 0.12540461720838664, 0.18018797070028322, 0.13519460034947242, 0.07833753111622027, 0.11233458265421853, 0.10107378730730665, 0.2102837807709171, 0.1361839416166467, 0.1622172487118552, 0.1058390150747953, 0.23094000865615186, 0.1795782259995899, 0.2402368073742236, 0.25555597648264905, 0.12155898606344578, 0.17246399645603475, 0.09163880164945319, 0.12121100594559986, 0.12807552146935655, 0.08734169190809613, 0.16505922040631696, 0.1754905800184896, 0.09589139402153031, 0.16144304025557735, 0.09870024007414618, 0.09807862867150577, 0.15664641054407244, 0.24870028629178004, 0.12989742411000113, 0.10106081743874859, 0.11187741968540416, 0.2251336750604453, 0.1561924421619023, 0.12099598038701281, 0.18315807826096014, 0.17668448208320528, 0.24178519364326234, 0.1585452820384695, 0.1663976066535519, 0.09065502218060917, 0.121985444228255, 0.13332770536503485, 0.06831574509100569, 0.16053418418572796, 0.15225093511323776, 0.11095348700520494, 0.07320903211591706, 0.19492396303722936, 0.14997776838079577, 0.17564077921692403, 0.07246958872964306, 0.11194429916119385, 0.11118339765216075, 0.12946887452515865, 0.04279682773255533, 0.16543550747296504, 0.11684486402138589, 0.1258137081599524, 0.13716530024765, 0.10116955595872096, 0.11707914136951009, 0.158283862195188, 0.12986578467872836, 0.15668557295876165, 0.13474268508293938, 0.128545937759261, 0.1611219881282699, 0.10434279939340008, 0.1817242681018768, 0.07626337104386861, 0.2380176191969264, 0.0780632256740524, 0.09521268608589327, 0.18954561212130133, 0.23462334407433388, 0.12104409836953688, 0.13753184267590124, 0.12556403244455017, 0.13039849157775604, 0.12166433847479283, 0.19579335025721983, 0.19018480524180398, 0.1793199317950395, 0.10742333852836203, 0.10466542200095232, 0.15846035353118376, 0.22308966054791407, 0.09506565849146537, 0.10221713522989904, 0.17052582465112212, 0.12368078914380844, 0.22395595277269043], [0.077701915626324, 0.044135133540558244, 0.05906503805289826, 0.051151104646945195, 0.04533442886426084, 0.0107377516894391, 0.04678575179329322, 0.054706258233636625, 0.011215003398847918, 0.08208632108665283, 0.01754786060642331, 0.06970420284497161, 0.030661087197762345, 0.015495012142515231, 0.03322736300047367, 0.04705447245449309, 0.0169033604118252, 0.044816239331398285, 0.023082441747969678, 0.042431426775311275, 0.03456084628499324, 0.03167364284426215, 0.13790849746475298, 0.017392203031528383, 0.029796265861800605, 0.012400065766527288, 0.03689405898894033, 0.03545532288450388, 0.02478419498900973, 0.011030582095225974, 0.046704875891126936, 0.012637141250794934, 0.03473302454597527, 0.05266069622349836, 0.01078753112514894, 0.049205900154887676, 0.009642277558844899, 0.021213775185207208, 0.03670591928605591, 0.020368226706200553, 0.02735369410666247, 0.0582669697882187, 0.05021434765489352, 0.011338056271685468, 0.011161163697139391, 0.03941993897540435, 0.08472917886871485, 0.02630219438053187, 0.08706421486192173, 0.02816304110080725, 0.0274414322414105, 0.049058677208039074, 0.03659012509630092, 0.016529381185049014, 0.00971138443527443, 0.04708581694191502, 0.01826884701938158, 0.022285465158582218, 0.06756528536038053, 0.02283896751431448, 0.03572885840830784, 0.07423852405120289, 0.019552017479474028, 0.04554540181772844, 0.01623511340679421, 0.08395055774599315, 0.03354333596484315, 0.022019395161600366, 0.020143335850368586, 0.02967888970048197, 0.013373130538140335, 0.012566757880361571, 0.053645498419721285, 0.026864794030364965, 0.04155279670451437, 0.09568953751436166, 0.041240160053055135, 0.018973284017955585, 0.0264938255291312, 0.07705329962435269, 0.0574813696045068, 0.06032920953246856, 0.06744774449015818, 0.014537258595678837, 0.04187778269331302, 0.04092997488295359, 0.032494994436180404, 0.017794088926166296, 0.01589451454609873, 0.02131140543027751, 0.02242286494302173, 0.03601585792738103, 0.029351433078127525, 0.044440151447610515, 0.07324876143567025, 0.029089302688296285, 0.03133540736481307, 0.007401297531736594, 0.054610550869256265, 0.08470640307472599, 0.0105974015088812, 0.048232263690161134, 0.04983340277366581, 0.022987594317284324, 0.0808992448653425, 0.047804556802035346, 0.01563937279335674, 0.03427126504961522, 0.14472343177805025, 0.03467717673629522, 0.05195341320828565, 0.0392974951424666, 0.03310291201717431, 0.011474866168423286, 0.04065434410867672, 0.014073063897329473, 0.04847849200990412, 0.032398337122773936, 0.04828600092760978, 0.03370653950579224, 0.015726435813121498, 0.07411850105610586, 0.015359382978790711, 0.06777987424885074, 0.022485128739067627, 0.03487971123127687, 0.05749558819638145, 0.06068862351258436, 0.040080655336139664, 0.0769938818449455, 0.03394754693633126, 0.007850007199111485, 0.0339573260486847, 0.041103781080774726, 0.07598082249563548, 0.03860757167961809, 0.007840296555866278, 0.020146635774102424, 0.05132409113068735, 0.035433531513497714, 0.039133234400182, 0.05029095261688194, 0.02966353155281996, 0.031448763479749044, 0.06803115108801473, 0.04858496290962062, 0.20222358585846043, 0.05903093564894892, 0.03939382303806563, 0.0013552933289188772, 0.05902582967293359, 0.018023254552615747, 0.05858325301819752, 0.040835669459474665, 0.019988404143781915, 0.03686724208115089, 0.029363014412322835, 0.019761703405228835, 0.013013616008984466, 0.03502093187923874, 0.03767402842640877, 0.060620564261391285, 0.05175142646616986, 0.05292209691458172, 0.04729847145837642, 0.03049055028015808, 0.017447414988231276, 0.03982173676993098, 0.03427705284388315, 0.027575095431999336, 0.1056966223123093, 0.018232461673417882, 0.016022727978716216, 0.012892586565876921, 0.03473363358587508, 0.010015112441784192, 0.04820445469850975, 0.10791369608693546, 0.04684668259635087, 0.08955341072813158, 0.03312705910854763, 0.015703979860841027, 0.11036141595292477, 0.019317879942395998, 0.037031414723324205, 0.08573078520355687, 0.04356342127486583, 0.06210757156593665, 0.03784087088499819, 0.06749230016383433, 0.011144766542730073, 0.03415981840883051, 0.018731516245151722, 0.03318370748010855, 0.04723995383228025, 0.021464236140731844, 0.07483834025239752, 0.037879665577483755, 0.030859938725048018, 0.06016973300927109, 0.040969007062695684, 0.037568346597254276, 0.01645316692790197, 0.0681696521238454, 0.09039788476882443, 0.037761220723510756, 0.05086259593466117, 0.05092908853604909, 0.0323954144973428, 0.01829617720608029, 0.022514960202839107, 0.04142807376000189, 0.04219865862039789, 0.013371037202887239, 0.02715305184885379, 0.0469495069175478, 0.05626299103061038, 0.04598895906500759, 0.044467634851894075, 0.034269997174100536, 0.017422317947831847, 0.02557864157302726, 0.023306269656806704, 0.07684051870338379, 0.03343511838465929, 0.07124281383209652, 0.09771310514019382, 0.04400000712203403, 0.03285298732319667, 0.034158619481229016, 0.04484021405298864, 0.027581762312160387, 0.02063650112118452, 0.04860385080739375, 0.059949950044674266, 0.030630547102660905, 0.0691858064683695, 0.03699415986756644, 0.047327575138619835, 0.035790202898844596, 0.02887096762987635, 0.056199792607296864, 0.037274643808843634, 0.03208595711076933, 0.043224503977164146, 0.034608676984545686, 0.053223441430037065, 0.04601552699422164, 0.07558022745914998, 0.05164604724174546, 0.035719849214318304, 0.015215932057359287, 0.05181682356182606, 0.043316852045996536, 0.006778504917277925, 0.018328502286045302, 0.043162673020795475, 0.011530223681831793, 0.03569796208232161, 0.03467592418253903, 0.11197436811222185, 0.033930018844623724, 0.019883655026675235, 0.03374829129766553, 0.008716666188481595, 0.050575029510524006, 0.12263233653239666, 0.037305570778346835, 0.03569375625961731, 0.010422374358430747, 0.07966719162199767, 0.02513795524024435, 0.030569792499825842, 0.016323171383250627, 0.10005818454608803, 0.0791976793158439, 0.07200101871163615, 0.14435652162759535, 0.056739873102595734, 0.019602523741102027, 0.02033687264267956, 0.04162879645704262, 0.043812989737958684, 0.03563171079862983, 0.06212029245591933, 0.02065267515248589, 0.05602274202711641, 0.03597960664680408, 0.03544635199491055, 0.0746565705706035, 0.053152854088693864, 0.05399218001853555, 0.010088601341140608, 0.060559365327560136, 0.04137168968877485, 0.021127201504104083, 0.03944675971363341, 0.03696689862878092, 0.023048237837370367, 0.029136357723825404, 0.07357932837499727, 0.04982857258930322, 0.007439636880712163, 0.042905976109567194, 0.05038112499600938, 0.06564454971662452, 0.014061603221982239, 0.0039824728822080244, 0.049194102400853756, 0.030578753813320113, 0.03078481039753364, 0.025245571441407648, 0.04576492814287063, 0.04749360554400952, 0.018914040523551164, 0.03989818851433454, 0.03238035320875145, 0.009206094865446851, 0.03579410611681881, 0.017391119017115524, 0.054260421874782735, 0.08818732274155464, 0.040859138563035, 0.025901315891514384, 0.04894055411099427, 0.05231696023275295, 0.05606220704653571, 0.04578014647948646, 0.018594934259571375, 0.031091358565214663, 0.020419997012903614, 0.045459615291967514, 0.03492895536304962, 0.027295291393754945, 0.01602401021837948, 0.03908583654030677, 0.007671423006667606, 0.028937441079066168, 0.03810835431420034, 0.046527277558080615, 0.01744958110183718, 0.03739501154350658, 0.04397761820244693, 0.02021297132746587, 0.024671668164251793, 0.03074861848877082, 0.11010560387324904, 0.06796483085640977, 0.036736643242259184, 0.019707558225960504, 0.035295972765813914, 0.03432914299229461, 0.14976710952337713, 0.24086564298599, 0.0924490315599307, 0.17085827616674287, 0.1503692239883446, 0.06528474886210696, 0.18383173001629693, 0.09067218255011306, 0.0828621459884509, 0.16656101320780095, 0.14897004100343875, 0.14734516851603985, 0.14579926437187582, 0.19137168994113324, 0.1406901320742984, 0.1107525498035454, 0.1552080345009604, 0.10040452523577599, 0.10586402018464382, 0.10024036025448192, 0.13617814999193917, 0.16465546142670417, 0.15915669681083772, 0.14211758370361022, 0.18657122979000693, 0.17741503884955762, 0.15535107843818205, 0.1421409034200253, 0.20255128762895064, 0.07541870548119468, 0.15882050678614648, 0.11388647760595046, 0.11468348483885489, 0.12210303872463205, 0.084549623181022, 0.14673064342669903, 0.09186596970164007, 0.11624186855530548, 0.1124994294537652, 0.18810754251335898, 0.08450535862075706, 0.20549023073286782, 0.17120067150362078, 0.1544218444295468, 0.15276321810820412, 0.13415509564501626, 0.1750739660835074, 0.15620082316379394, 0.2509285449501007, 0.18476845636483163, 0.36707767856217205, 0.12446257420965742, 0.10327788355249552, 0.16807941479548333, 0.08527775144865436, 0.14890939748335272, 0.13627012650812828, 0.19364796699054782, 0.20630461283989493, 0.08567240164284745, 0.09813492847306114, 0.19132794632065683, 0.07651434910874214, 0.2180398847427099, 0.12811452300558168, 0.18425778215450628, 0.2353265668235479, 0.1094017529319371, 0.12103913411978753, 0.09640877150119313, 0.12601343494269157, 0.107449178674048, 0.143804861713321, 0.1279354269706434, 0.1696777959624606, 0.14368247150653793, 0.16353617632581344, 0.17009523727240103, 0.13549676074856712, 0.15941633933013485, 0.14864894291085584, 0.1085858539708199, 0.13135936501766407, 0.10598725308814358, 0.21363311717587136, 0.10164613925641584, 0.09686284713567266, 0.14092691452993503, 0.054112187691874085, 0.1057303761462531, 0.24685406035953955, 0.1534180241006036, 0.11096562183792553, 0.11391502204200915, 0.1424805408403758, 0.1067565739034645, 0.10373256439643522, 0.19580458110618978, 0.22025720366547186, 0.28778641394549803, 0.1585013852004082, 0.20979291759431365, 0.18846519832168857, 0.0701856737836234, 0.15502633376707955, 0.21201483304462126, 0.08777198051252673, 0.18544152589334598, 0.20766827998863113, 0.16868739749395079, 0.17050894007327097, 0.14998536797300463, 0.13750383450138953, 0.17307309764287165, 0.23092819558035946, 0.12794168590898478, 0.11843336265413992, 0.13592895691192922, 0.13957126066088676, 0.08681447785948554, 0.09780987736678894, 0.15267971452445755, 0.13949408496339477, 0.11140270564224451, 0.25404575671399793, 0.14821195103708776, 0.10035784749854958, 0.12973654564590226, 0.11103600233552918, 0.24118628142581833, 0.07080325556378211, 0.12593786802984056, 0.15189810565883113, 0.2810732161085452, 0.22159099338516114, 0.13108628531617503, 0.17975373674304257, 0.09208438902973168, 0.10313266392556891, 0.10397969669992886, 0.09553861053239915, 0.1481768948536727, 0.10237904025181647, 0.1041478300166707, 0.13314588205708613, 0.2154916311584173, 0.3058510736352013, 0.2585001289844513, 0.11286390344462088, 0.21185108941168557, 0.1344658362288629, 0.163085195686548, 0.16022152838207063, 0.11986875095434728, 0.10380045510828496, 0.08489283823197888, 0.09527571213942382, 0.12357176717130408, 0.12680091204181795, 0.14261474412295128, 0.09051522645618647, 0.13807653119006466, 0.15007650179247703, 0.13753651581223936, 0.09019591334846713, 0.09322998925082146, 0.13005093280826846, 0.09862573036263067, 0.15698063938367754, 0.07090349816867421, 0.1996201433001026, 0.178471872462861, 0.08042767944355166, 0.14164619448204196, 0.22465624906603368, 0.1470311337541188], [0.03869874380348671, 0.033020446482565136, 0.033950488713960496, 0.029481964884325865, 0.0190635425819745, 0.052475724294180834, 0.023220124984941175, 0.007669268384380567, 0.021499617911514737, 0.011256162430189792, 0.028629219009270592, 0.07538073050278811, 0.01798432962518306, 0.03737656031585029, 0.041062178676046675, 0.011162080129818812, 0.13922426879646319, 0.035020020234608845, 0.04261973501753904, 0.019274019493511128, 0.07181630725221289, 0.025891433357291167, 0.055450252182180845, 0.03351828105927956, 0.03988881542858097, 0.06597385261087649, 0.04405783526899834, 0.050073268733197646, 0.03899546880875865, 0.004986693731494128, 0.02078833400211748, 0.031142899045540445, 0.04789579787381715, 0.07571331991423523, 0.01998735268810584, 0.022293675705910693, 0.04481112952494333, 0.026427518704064915, 0.031618524733329975, 0.03612515952197775, 0.021631270121302337, 0.03949224235369794, 0.07093664679315782, 0.0337652524843091, 0.053355537970820745, 0.06854228495109467, 0.04837372565581914, 0.027059512513299144, 0.02090450357495537, 0.07210859277796361, 0.034672878983040015, 0.044438872080776966, 0.11088391089992178, 0.043975902165496544, 0.04317231423732254, 0.012312042264027462, 0.02276693226679439, 0.01823488251125861, 0.024403194566407514, 0.013109443074602996, 0.009005447819588647, 0.03906622851988481, 0.03985924060426412, 0.03775492348077317, 0.02321109280831391, 0.03331597256023557, 0.02808161936099491, 0.04252755548804999, 0.027918532648454272, 0.05370178289951817, 0.017945295530221155, 0.03846791385102176, 0.013764959613552258, 0.02349463535562879, 0.06885265015185842, 0.051061794116732576, 0.03180403100897468, 0.040173616275311484, 0.029045162617319056, 0.008866706423671737, 0.04833956196483585, 0.09389258635741088, 0.017987290555010402, 0.018730008967160698, 0.043117910503379764, 0.04428908273938202, 0.031037253605562354, 0.02786010695290902, 0.024892247860289873, 0.016676715214646632, 0.03886570883614402, 0.09224064798364717, 0.09805090394952605, 0.043797920788488084, 0.08171133636947601, 0.02748024991653379, 0.007728250451280826, 0.07138959627838866, 0.013736613402743975, 0.012781208873005405, 0.011083693055796527, 0.04593472770084778, 0.026694036862482468, 0.08159358099463486, 0.008314851156976676, 0.03328248685706527, 0.025520777036886544, 0.04392512585787524, 0.05287203306872999, 0.06772500703171377, 0.03565071360959161, 0.03748804909147082, 0.045578083128578244, 0.07677340174033757, 0.038269638804899114, 0.007222738715955207, 0.02289394772942028, 0.06090158829465509, 0.06536349503984375, 0.0837249371914133, 0.02977700066572476, 0.023409925183401476, 0.0318484200585273, 0.014133181689577478, 0.046834402206924655, 0.03961950487967941, 0.034478955316327276, 0.040073274078989224, 0.042178725012608116, 0.0583135019687395, 0.062204320809894034, 0.05873112330934214, 0.010267882194790629, 0.08069998539623716, 0.03411325558479275, 0.034529222175478935, 0.08503212067749231, 0.07219641709760313, 0.02398675683164789, 0.016884277161631375, 0.04167676122198182, 0.04797714108961725, 0.023052663910352898, 0.08123443897573218, 0.00897280194030534, 0.021323521110800006, 0.05588183930564312, 0.030452249714383678, 0.05153496066228517, 0.05505097098648549, 0.020185208301089948, 0.050337768249934724, 0.04331777901238492, 0.04679146297876874, 0.007272029291808366, 0.011630910617719975, 0.05400313890629238, 0.06077059492048237, 0.023122464096353903, 0.05799322359023556, 0.0257246904901319, 0.027955595982230963, 0.016285066169896917, 0.04227292318377764, 0.050179912002697113, 0.037330545244678374, 0.06754801007768801, 0.04885187560331918, 0.016054304207735244, 0.04999642245351307, 0.06607432504214587, 0.021093727292252645, 0.0987797600006865, 0.041169139872034716, 0.06521361759833752, 0.009481720851674195, 0.040087530975260084, 0.09136762184601638, 0.04634998182976439, 0.021579892434660467, 0.028506409369349003, 0.013522239976502476, 0.059267679800189314, 0.039681293701212254, 0.028725726935531826, 0.07653192316572513, 0.06713451412055763, 0.06407771988080875, 0.03097488447242687, 0.010443205246701838, 0.020894827884471705, 0.08534403337586312, 0.048962085012106166, 0.0647718376750427, 0.011318449208873415, 0.026210099120714495, 0.0668736228779439, 0.019278139131323948, 0.09973005376636021, 0.027289903880427444, 0.055024380074633714, 0.05048227924553137, 0.03340724044509473, 0.06335822542408301, 0.027635020744656364, 0.026192245441639138, 0.12478784748142767, 0.05043648250941789, 0.027711254154001514, 0.009794972288692671, 0.06854938658615274, 0.02433220119846444, 0.035151404313622944, 0.03781754733814347, 0.08064554718833777, 0.008383273342323881, 0.06711592882751458, 0.05124110848672929, 0.02635599673545409, 0.1370572205632925, 0.023248071872418927, 0.03803325471498313, 0.06217946125675113, 0.02974522908428504, 0.06138436541321778, 0.006892950792286185, 0.03654812815629187, 0.023909251716348435, 0.07956388466540845, 0.039504875143569325, 0.05833766821231093, 0.05694436495222392, 0.05776378025691356, 0.055050580281644106, 0.023606579953564272, 0.034869483957487735, 0.04827973815882879, 0.0036914585836066477, 0.06938115122818178, 0.01643030686424144, 0.025397509659430193, 0.049015339614162524, 0.06519619675893938, 0.07222262496549277, 0.05323697054277986, 0.046977691292282076, 0.029714692819623217, 0.05496939028342886, 0.0681987174996926, 0.07668270459098202, 0.05680544639847452, 0.05574226957715808, 0.030386289544103127, 0.022824210745673028, 0.03837383059304088, 0.036332508879563505, 0.06593629131994902, 0.09978739544749261, 0.04159074103940399, 0.036873792132903496, 0.053763200168407736, 0.03893673667804368, 0.02876489701110029, 0.05084826242959788, 0.030388608875293887, 0.01603157533663175, 0.024038961893247984, 0.1060318930314914, 0.04093731017482858, 0.03302336910799627, 0.045664317815774874, 0.08301713323641209, 0.00793131881378471, 0.038523753999822566, 0.07056648842990398, 0.10022418813840037, 0.08155317751750832, 0.056056932531177044, 0.05559102466870701, 0.06646784142621102, 0.06576916157838798, 0.06971131214090893, 0.026956971644634203, 0.041536076835566954, 0.05633568128330573, 0.04280339693650604, 0.04453065324454539, 0.05694589329763286, 0.04964556184507186, 0.012532544393663206, 0.058664056142011, 0.0026874136951406517, 0.03312462677938804, 0.025903911014357885, 0.0273710421677078, 0.02779539742116486, 0.03564784077987556, 0.07356623593237131, 0.009850348954299286, 0.01942419570930783, 0.042794487333946654, 0.014682301064772953, 0.06522182240000655, 0.0703845655305251, 0.014901819729035901, 0.027901163519991022, 0.015620247408327077, 0.04883226758289722, 0.0037131379142538797, 0.047642866284736705, 0.05062487885175694, 0.04288981931524412, 0.04845472413205332, 0.060794546659435, 0.062282434965093295, 0.07756603461119436, 0.012815745074241873, 0.019040374167924447, 0.016579508233154495, 0.02905899241957213, 0.018515738005179073, 0.04666724182184666, 0.0617286414959498, 0.029580263541110104, 0.04972412799214644, 0.06405766752939071, 0.012433803321102695, 0.010775786997269719, 0.07163887362807028, 0.05154991469856712, 0.06443176358457535, 0.05556428053927037, 0.06720109482205684, 0.057430830784142024, 0.0117201684793878, 0.024481756883042476, 0.007602262982888328, 0.005734233709517867, 0.0180261810084865, 0.016655502240023306, 0.027579460217947924, 0.020857071241123543, 0.0559485579029687, 0.03986738794933885, 0.019227468160792224, 0.082104247544081, 0.03799465537491826, 0.007113745471748013, 0.0657842688322548, 0.040015997515330394, 0.04584571211448601, 0.007306443876586855, 0.17626008469491236, 0.20070607293277018, 0.08073163248838917, 0.10673097124503506, 0.09216395492154746, 0.19357039292733516, 0.14926124634521623, 0.10555267439133699, 0.19887818714543698, 0.20757723809970965, 0.15106570516382495, 0.16371000167583266, 0.0933692716963349, 0.12060139914073291, 0.1351490640832532, 0.1869871542458573, 0.28235429897904396, 0.17608494167366337, 0.0933325837456411, 0.11587960089767173, 0.17306617220803616, 0.11929717275404161, 0.18110986558660386, 0.09802170067785249, 0.10795644379311031, 0.16990772959205414, 0.20118452548500032, 0.166680722106849, 0.1099481728048094, 0.08211018472549417, 0.28005419659518427, 0.08767521594681087, 0.1083809101293164, 0.20417421425302185, 0.2048734686667881, 0.15868057316589743, 0.13134180628243955, 0.05883818409676033, 0.1276429882273078, 0.13504947265309675, 0.12212361584627822, 0.19479855444402466, 0.11745384263415491, 0.17443137153262095, 0.10390703326031085, 0.16022799416415154, 0.1293491503043521, 0.14144765513558544, 0.12206840388957532, 0.1760244360494037, 0.11202214135517997, 0.10097310803229771, 0.21376980258332146, 0.16397908239835696, 0.12448350373174875, 0.10315549334571247, 0.10488978617133633, 0.12321562821706458, 0.09921954043449895, 0.05011549549958399, 0.1448699690762066, 0.1770683840638207, 0.24340712435303197, 0.09634273472212015, 0.14286887080919358, 0.1863140081085505, 0.21750676415620313, 0.10800109139733738, 0.18128343046672885, 0.15020534245958253, 0.09428920539756937, 0.1390281349660889, 0.19782735966145995, 0.16018803501802106, 0.11779957811438269, 0.11934742046099518, 0.18516760349514025, 0.11742562761590367, 0.15682910719225485, 0.18635451883798648, 0.20741700314946715, 0.25769147721509783, 0.10142683126633206, 0.12481954819973438, 0.15769431157217872, 0.1425508370683078, 0.09950743627644355, 0.16576320924345525, 0.15467767183098102, 0.21146738661393044, 0.12967476831568828, 0.2868566283535573, 0.14885336581257083, 0.1662260795673055, 0.26272482809520536, 0.13198875221273593, 0.09145402124211674, 0.11693799733034066, 0.2293446918408717, 0.1341463009556455, 0.11883565074493808, 0.17129163678374984, 0.13135672967520454, 0.2479424567953233, 0.12411706089492767, 0.18522797122357354, 0.1460586310995202, 0.11451889850920248, 0.14965055690657708, 0.17864827186830584, 0.17228221911336147, 0.1249107739497577, 0.20600326449399997, 0.1678703494009472, 0.1386209898778508, 0.10906261346873738, 0.11031473055481912, 0.10243883341430657, 0.1055325952268416, 0.17410915495166857, 0.12431867991483982, 0.1875782523664736, 0.1492526814822228, 0.08738761887915673, 0.14689650146230576, 0.2624125400137517, 0.16677225429204204, 0.16315058895176457, 0.08302434978465881, 0.13892011656876535, 0.1655744758224295, 0.11974688934823198, 0.12023818153407305, 0.25175694646614216, 0.1482661134533344, 0.14889563854423263, 0.2806116940994417, 0.15726619099657382, 0.19704861596467035, 0.10580166828848662, 0.12307450716053286, 0.10329124412589497, 0.13814321148299402, 0.17422822033686025, 0.08122454111975047, 0.1265441500131161, 0.16587095184912606, 0.11540990473041612, 0.23034907907487887, 0.17802784790194806, 0.13462532041293962, 0.1081378304309422, 0.21686092139251772, 0.16792992039793925, 0.10746327469185477, 0.08250340999614808, 0.11025994760735382, 0.15854385711493033, 0.16385162068951517, 0.2634960028433031, 0.21190082383972986, 0.07629406052611529, 0.17972508505467447, 0.1408595294361153, 0.14598657286936237, 0.1496622780518186, 0.16654612045855294, 0.10805306280212057, 0.1632458443242696, 0.20702018492644836, 0.13418178614829818, 0.06991529071162786, 0.24741590924320683, 0.06219636881724001, 0.19139839576617365, 0.1472548161062502], [0.02108171886403955, 0.09023813245397422, 0.03126199315902928, 0.009664505599967895, 0.0893047309270309, 0.07510994906507193, 0.08764868632199303, 0.014843738773056578, 0.023732145594793464, 0.005048652049980217, 0.042138436448670206, 0.040148339204249844, 0.0233130878393328, 0.03501565736388007, 0.06362355614621794, 0.0336256712645052, 0.014128303624719623, 0.07525141486116955, 0.043953758394045216, 0.026529257095629172, 0.0587438595210833, 0.044190257397149844, 0.0553034505836906, 0.02145029525572975, 0.044106998961539044, 0.04658103011728776, 0.040828962359697595, 0.010333443041740647, 0.05655790806838101, 0.014642449170951883, 0.07658273777774266, 0.010729822679422798, 0.04724938820506777, 0.06734832159934506, 0.02057769812733656, 0.03842586711529763, 0.04628391823761406, 0.06126757530916122, 0.07427744897863559, 0.013746365702020065, 0.03865835181767902, 0.011060887575900603, 0.045382703894809376, 0.027025804644630804, 0.024768135870897004, 0.022421215938764717, 0.026219278769267183, 0.04702563690502317, 0.0279609183780849, 0.026608179473588546, 0.09022860232019618, 0.007862881785483972, 0.029235709751505527, 0.10569476837953252, 0.03330202592957405, 0.02960661122004592, 0.025203467249089194, 0.016911791209431908, 0.048242870177472794, 0.040014028669364994, 0.05073591180506253, 0.03242427302945045, 0.01867069269440347, 0.03820216178052849, 0.0726525075433235, 0.02532757540804244, 0.07400885855238284, 0.10307077934304554, 0.09780452241219821, 0.045790729984160394, 0.010084109193074607, 0.02588603243742499, 0.05279077412260156, 0.03202649528130649, 0.041149263720839255, 0.020574130072829225, 0.04249531467775664, 0.07023698635279171, 0.09144416169053124, 0.03713413562265135, 0.05397412332616026, 0.05708589969623474, 0.024144616909325126, 0.06684885525535192, 0.05530487933766939, 0.0678201015257547, 0.01665171968089717, 0.049220911647763946, 0.0456707299717011, 0.01761131566919146, 0.008690652715402746, 0.04146322187396788, 0.04869915214517424, 0.03391960387929313, 0.058551019868783416, 0.012593379435730318, 0.025396498423370144, 0.025214286325799844, 0.028985289015596914, 0.03838726011435351, 0.0758863638545717, 0.0493863100306161, 0.05358437992512219, 0.03896089143029625, 0.023002404712080475, 0.04826617840256903, 0.02433402448772423, 0.021424116116137277, 0.08624962591115506, 0.07024618706876232, 0.03240050132116003, 0.03271404195636992, 0.055215373455036076, 0.07494731625962643, 0.0391481960973432, 0.02020418046853475, 0.020018099626946836, 0.014260678829985761, 0.027629043343627167, 0.04242129909295229, 0.06206332615786984, 0.027376186448119344, 0.013340855253890399, 0.018056523835947438, 0.09070150839585452, 0.070174396969378, 0.04447257228856606, 0.037534037349565376, 0.04888402065262199, 0.023816191185746464, 0.014950699969044617, 0.038491329328427394, 0.05075683749671425, 0.05930594589200713, 0.04462484375483567, 0.0304754487719507, 0.008082469876465059, 0.04629265163995085, 0.0990579188651135, 0.0346573771938922, 0.03331110024103715, 0.06255641098945372, 0.015532772616303016, 0.04318027389085582, 0.036979244135680704, 0.02768834620984572, 0.05146416264676279, 0.03930391112883245, 0.004760763868914857, 0.026575915680657473, 0.0750451380266778, 0.028493613785793705, 0.04980586957366717, 0.08464563698057206, 0.04376179974285826, 0.04390066467045296, 0.02297043203256063, 0.03419978904627985, 0.03198883822938848, 0.0291708450869567, 0.06607613300964718, 0.04434928958935123, 0.0381933402780804, 0.06283167021108732, 0.06971572480735279, 0.02752550273022104, 0.08609152068534205, 0.05685135804777665, 0.046639432830195275, 0.05677435088962798, 0.08021249300650052, 0.050268962063015475, 0.02248684094557839, 0.05816389648844639, 0.02213612206340317, 0.014074245587952677, 0.03245611930446279, 0.02240139532894377, 0.04576527288243656, 0.04748654221334765, 0.050317037910703695, 0.018826233440889947, 0.03003262696907886, 0.02388788169370063, 0.022130757532713395, 0.05148647495755746, 0.0032175879553711464, 0.020520789285881386, 0.010569072535051214, 0.02010377506995874, 0.01984182471078971, 0.02283251896921185, 0.11211471541995004, 0.023697618012046142, 0.04415241265369039, 0.1327282415642854, 0.013438993989820442, 0.06668644461540446, 0.04062173557617972, 0.03674181433574807, 0.08449237343044051, 0.01768450770947722, 0.038987850064351674, 0.00606003797598063, 0.034119342153351155, 0.031065001310179793, 0.034341657038537726, 0.011606211943041173, 0.03940419203812077, 0.03785379861872043, 0.04322787093359136, 0.02888601359670922, 0.017556446536834684, 0.07280974708978208, 0.04070723098852942, 0.06826333701610565, 0.056496617203998956, 0.010579414722029, 0.06318105226983467, 0.027434096949535514, 0.08938703175273635, 0.031036838002863432, 0.06027696616647225, 0.07634980874436517, 0.023811768943203554, 0.02938318359214933, 0.05400883477000941, 0.02865531770963102, 0.010138940978645077, 0.029685050962612997, 0.03134209914283166, 0.019390058831401893, 0.05336936968829363, 0.06409196911620037, 0.08770382933078275, 0.028269875892287785, 0.04448151636508204, 0.026490625196827516, 0.043211166386402426, 0.07706721944193687, 0.04315082164060685, 0.022897517699147427, 0.035557231730631286, 0.03265778428965038, 0.058835349571440494, 0.03664008552028287, 0.009818896256958046, 0.006856890076080398, 0.025168976055518277, 0.06503404658888617, 0.01066349957498812, 0.07615123109351243, 0.026048427755613963, 0.06307632805058552, 0.04401075533561168, 0.040139418110371604, 0.05473699368115875, 0.013650130694581857, 0.04210272142964025, 0.05708503018644068, 0.05390057505498971, 0.011688886236609712, 0.015325857056004387, 0.026331600665505377, 0.021168187208053087, 0.10550545273168434, 0.03334718681271038, 0.020726782667841163, 0.027483950121208068, 0.060475616595677795, 0.045881687603410215, 0.058701628924257336, 0.015032467406032788, 0.13339139791505952, 0.05025113519701747, 0.02053519556929748, 0.021588215979957776, 0.027976722771962805, 0.052569167868744944, 0.03284605422748193, 0.029948441567079678, 0.06423472194001079, 0.05782015666726136, 0.036230358715739944, 0.026977790083976525, 0.06645714683878808, 0.043277375535258365, 0.012181279673841933, 0.04429388228022764, 0.0672539548888322, 0.053613020122171416, 0.07142716523019538, 0.06735186092555523, 0.08238603766526907, 0.010230591907466372, 0.043127750902767145, 0.046744808224180055, 0.04563879176613785, 0.03402601349197569, 0.039327679006683255, 0.07836154797264645, 0.017933626095914555, 0.04891636871522473, 0.04873879336481614, 0.05006760351299759, 0.06707610757721048, 0.01461888334879111, 0.048416638070897716, 0.014930377571633267, 0.04360446060496954, 0.005972464550136319, 0.028747278904061646, 0.040261436764511375, 0.07827340189607875, 0.073733733396136, 0.0806694797750923, 0.030189424099761154, 0.04916225995628103, 0.02369451918639243, 0.035371589474380016, 0.03144469746809093, 0.06089864651702585, 0.06638858963044421, 0.05592487046434995, 0.018416598566897938, 0.025383473013437567, 0.04375392435899666, 0.030075550875476295, 0.07021866919052216, 0.08661005495777054, 0.017347706729666363, 0.08846196526240918, 0.05702435219239804, 0.0288862070339101, 0.08782764446110496, 0.09174659788127869, 0.09355062769064981, 0.017481775946855065, 0.05583509262050352, 0.03713623470356388, 0.032137039853560354, 0.055917642424784364, 0.03751957360955496, 0.0561722555768586, 0.025024428670745225, 0.005966801723961028, 0.07276639417414704, 0.03987195000292794, 0.08508248329763451, 0.07858329212232944, 0.013048278614728442, 0.031167042306474144, 0.08619822141143584, 0.186459350309545, 0.09148684810967216, 0.14226543867299635, 0.17095180018053902, 0.16466952680099398, 0.29146057163034716, 0.12842459709293422, 0.0847448300450079, 0.10508134645680267, 0.23659819616906105, 0.09434584993869068, 0.08336429364017903, 0.07528519167775109, 0.1948256586347857, 0.13832045358515557, 0.21563211636197185, 0.113748551136063, 0.09986765081844023, 0.21244284636791677, 0.20607474049733532, 0.1047458152677263, 0.18494410500411065, 0.17980281233547196, 0.11721203464173502, 0.12929607573295795, 0.10169316939408742, 0.12260304133017218, 0.1259659068478692, 0.15781000617050356, 0.13428500883521574, 0.11041646703116356, 0.1984401380703334, 0.11397552766626882, 0.10175029657060101, 0.14535061263990018, 0.07668972195636842, 0.17046542627917183, 0.1548258792008123, 0.19220140912840444, 0.12568637668605775, 0.11922420287925391, 0.1617727338546707, 0.16628992533491505, 0.1411509646042701, 0.12543646348339896, 0.20050315156338677, 0.14260916700286252, 0.1563841020387988, 0.1926616441097952, 0.21618259650084282, 0.09280746111706381, 0.06424209170584237, 0.2400558267629916, 0.16044730981511457, 0.19494225721686118, 0.15393231424593157, 0.16531808151593133, 0.16012501662536976, 0.15129407597405298, 0.23492827771171448, 0.15581796306275553, 0.10305522775818264, 0.21152041522004913, 0.18260932948079803, 0.1380205914498337, 0.1597756652101394, 0.19713739023333599, 0.2881964548460899, 0.09165297427605237, 0.0923160540180341, 0.16163152852846732, 0.1958502246247184, 0.15008002579692872, 0.1566621919553126, 0.1691225507567006, 0.11868495358935288, 0.2412937482398364, 0.15155065414165297, 0.15827065483937341, 0.16086298912282915, 0.12539135622641734, 0.14347875340571328, 0.15102877972587464, 0.17594382827801092, 0.16840409817955188, 0.12119742320670236, 0.1176570627778288, 0.08677225875397844, 0.23328629082008717, 0.12322079931055346, 0.14843223195883537, 0.13702564241905368, 0.15787118595213662, 0.20598815724013314, 0.23590073440103765, 0.24242184335185638, 0.19112775222428385, 0.2546715279740672, 0.10417200775156099, 0.24128941218218497, 0.18148282783166056, 0.18847334949720293, 0.09967442812217821, 0.12120360553625131, 0.1459700560137149, 0.14379828867893066, 0.1840556575165641, 0.09697249730027492, 0.22430288335008008, 0.1440813581669523, 0.16794436881619115, 0.2078383515078214, 0.1710963150065753, 0.1518570586678482, 0.18008739867758367, 0.2057216965383099, 0.1177461741251811, 0.078061256828087, 0.12386149396338772, 0.11830510421385688, 0.18234406387613666, 0.15224169609287094, 0.08891975642332146, 0.14107735887650522, 0.1921196828686422, 0.18342179636801445, 0.2678014782647933, 0.15636913268075836, 0.1145546441717494, 0.14099459073716594, 0.16443499664385475, 0.109234967929942, 0.17039894516910278, 0.12517026325147, 0.28189682191418064, 0.12418355732675522, 0.13448780763053125, 0.1768241552335601, 0.21105143151456313, 0.07577570245390938, 0.11926568654035369, 0.11555769075188907, 0.10103150691476562, 0.13273772573278797, 0.17115216281625534, 0.16168325478511472, 0.2070484382490958, 0.09798199434073702, 0.07695216069658918, 0.18695821144407798, 0.11162077256989096, 0.12568505135394875, 0.1464875024412909, 0.12064119740839928, 0.2172575404326762, 0.1517560116706356, 0.16022405647222074, 0.15093455091118813, 0.19929118514541658, 0.13233718432245717, 0.1011100922140383, 0.13162859895777318, 0.20953653860957394, 0.10802147699700249, 0.14511311006161476, 0.2247776280367567, 0.2230156104891531, 0.1920486665180614, 0.16837507876898014, 0.1310115764217992, 0.177327873365533, 0.16167983803297245, 0.1475687282941034, 0.09725100090426785, 0.09802428239415731], [0.11009841030764003, 0.015186904028298394, 0.07471034228200875, 0.022073963604446863, 0.11859938922909, 0.022542537452893394, 0.06854718791381006, 0.0666146315333824, 0.055677657721624266, 0.01605411843141361, 0.02022083138956899, 0.06091293405681368, 0.04715142088131078, 0.03789071256535188, 0.028379826746400327, 0.0719995784663385, 0.04771012497404891, 0.06373401836401994, 0.08902175336956017, 0.063514216247225, 0.012404408527448053, 0.03668400151054225, 0.0856016993883156, 0.08204987062321556, 0.047499761060481115, 0.03733038053577466, 0.02479650793717273, 0.04919202247213933, 0.03095821631441434, 0.060869807137116316, 0.013354460975425619, 0.07949074625127739, 0.019420225458640247, 0.09087015499150561, 0.07568851398724703, 0.05334555201472775, 0.051124176656406735, 0.03955444103227027, 0.05900469713754231, 0.0709915676364495, 0.023547100887123137, 0.0818858128942309, 0.03329729150620199, 0.06305424939660777, 0.041549387613251325, 0.028530345786543145, 0.02439753126142727, 0.009615463523885176, 0.016135387911250996, 0.06199373090038858, 0.011752871815265428, 0.029219671700810714, 0.02098521668343775, 0.04548122280187184, 0.043215115569652095, 0.02393327814887368, 0.02654555753143805, 0.008544299278348204, 0.012525601721849414, 0.0029714312169685842, 0.056735674940770676, 0.05569397922485106, 0.023173330419306314, 0.03904229593313029, 0.06302700731002035, 0.055935316073197516, 0.03741126792925981, 0.029225252651339097, 0.15981249871753878, 0.027425436325551524, 0.013831291336476082, 0.06399598979060689, 0.05759402283377225, 0.06975310223717844, 0.02536903417128469, 0.03437077987097925, 0.03993130649530119, 0.0534896340010868, 0.02849571861236567, 0.024171226973375006, 0.02016998230359487, 0.09581090882420541, 0.042064137411333864, 0.09489868962836844, 0.041002600018175385, 0.04105292433392137, 0.05171730491002241, 0.007457040961936958, 0.028387679147624204, 0.04149191952761143, 0.054316430562926885, 0.06258836834721508, 0.04336559439017888, 0.021041278997736595, 0.020593663399678566, 0.05685982714977957, 0.04291632978786384, 0.04089582651372879, 0.0526323011745849, 0.028498855742415594, 0.023153804753336216, 0.04590649736083804, 0.04062924323783767, 0.058601455267278425, 0.025030576526337577, 0.030252572727359595, 0.024181377638371724, 0.04283138212838, 0.0682357118855561, 0.012801250690714487, 0.012147231853657193, 0.020933906029489253, 0.025651400773635796, 0.02270542881301334, 0.07915722987344188, 0.024721659231750716, 0.09520730048778558, 0.055514132423746976, 0.04435246885423699, 0.029634607903238748, 0.02766890864398691, 0.056154091632173914, 0.08415914816601623, 0.02476960101405219, 6.032937914912304e-05, 0.03665239655322606, 0.025815416367784626, 0.053338216722852765, 0.028507397622771324, 0.027486706122515664, 0.01978299681908421, 0.015457404886312304, 0.09452735915059045, 0.06972675647346244, 0.04291652514028453, 0.02382112479197883, 0.01592522796859304, 0.04192319255502474, 0.0655342790208036, 0.04673294152223295, 0.061128955529702295, 0.02095585444851989, 0.0718578675221051, 0.051980689768829656, 0.02691825739138069, 0.029899072946019234, 0.08103452833189119, 0.030038933787915497, 0.017573421130016927, 0.053000609435501604, 0.039327361080194675, 0.05448385907877838, 0.022400617749700626, 0.02637809071119034, 0.04965656669810415, 0.028163406907791094, 0.051716278352203875, 0.09199520873446619, 0.03907608424103068, 0.04866413426615539, 0.07676700490616983, 0.019975401716487064, 0.014360572864872315, 0.01637229294095549, 0.08565336435792908, 0.05112292793309016, 0.05729498041252937, 0.05271852437046267, 0.015367006511247207, 0.05482567218883384, 0.06838695296356756, 0.05509984356561496, 0.05321326012152338, 0.062378008264086904, 0.02574408209071525, 0.040717140335829995, 0.09822508169999046, 0.03589122691341946, 0.027469584057407997, 0.0027795786210786434, 0.05396758859616615, 0.06268752693769432, 0.007231692368570235, 0.003632902174309317, 0.04265014487769335, 0.03298657390499308, 0.030169300885210117, 0.05183412182715632, 0.017446568461074945, 0.05468809045851231, 0.06232245922869733, 0.12092704013470681, 0.08056862429986078, 0.03003828835883929, 0.015441773819827266, 0.0371196297478051, 0.049642562610848304, 0.01509830979029498, 0.05726017320768968, 0.0526903591479265, 0.030440990137116566, 0.04567118579401605, 0.05474258229256638, 0.028336826231210466, 0.10206318220063564, 0.03203366011861832, 0.040181713824671124, 0.08034403030309947, 0.057739874483236385, 0.10548113710096768, 0.01729954852752628, 0.039213018627056194, 0.01545398047329077, 0.027539365091210896, 0.04721923498436809, 0.04694872167742541, 0.04626442513038074, 0.12114732105645443, 0.04055904277089623, 0.03300103381456387, 0.040482893631222754, 0.09213070670563368, 0.03249809709227374, 0.022650214941090634, 0.04149673822065515, 0.029829922019534057, 0.06758808413700712, 0.022434716323210348, 0.028875466481211687, 0.023811186716381102, 0.0051176602925894965, 0.06551003233800012, 0.08212421179538773, 0.01752016652796057, 0.021207508585986592, 0.014169938588184456, 0.10289686972335463, 0.036772404226564595, 0.0623369153078285, 0.04538029837872713, 0.051551339622106285, 0.029714869019845803, 0.01668162392302146, 0.08476346896420564, 0.03210740374220956, 0.06077146826071605, 0.026012950223840536, 0.03576652312110509, 0.010489102531855386, 0.0803496380667052, 0.021084683624306516, 0.05013106623664499, 0.0585099422342835, 0.04044069367791376, 0.06160578397553294, 0.03790284739807248, 0.012750432248257343, 0.06106897084523113, 0.029006270248623147, 0.0051461319502953805, 0.018969727454767115, 0.06698236905879552, 0.0695410490997376, 0.009523912186494038, 0.0655725604343799, 0.036284126596705574, 0.05326081119898347, 0.05010485453831573, 0.05957797222260026, 0.021404814530885028, 0.04864420065836561, 0.048537936602388664, 0.03054518575569795, 0.017115516971135815, 0.012698197500750184, 0.04695858888989014, 0.026595058302665432, 0.03800955195460589, 0.045560934250393224, 0.05508235377830364, 0.026517080128072735, 0.04456138869206752, 0.06446685041150739, 0.03954813612865345, 0.08109259779655165, 0.030667332729565042, 0.025164088414561366, 0.08169647426374498, 0.05673716881222302, 0.024549166874719724, 0.053892082970349066, 0.013598211958343464, 0.07238443805685929, 0.028156588725264997, 0.060911685333497105, 0.04119083548205034, 0.04608778440723977, 0.07458102664039021, 0.06256810532161786, 0.04778294929213101, 0.051179495865419034, 0.04654349946987726, 0.030647860689749642, 0.03499944694340229, 0.057385068521985126, 0.029771109449587045, 0.04075485484434232, 0.014045493350544525, 0.04507368700879236, 0.05596500964114263, 0.043324773395133596, 0.018145554744067694, 0.04971885347678777, 0.0920420473501567, 0.026367869183060624, 0.026038650558480335, 0.09690288289059555, 0.018909078189021638, 0.07545198434062543, 0.04119522899629609, 0.032810752895931085, 0.001795601645191651, 0.058682193273618344, 0.05285504889944869, 0.026198693986741767, 0.09125370457167588, 0.02484799479134381, 0.04997738133815508, 0.04961415607061598, 0.0627860649969549, 0.04207798062012561, 0.018702619408647862, 0.023641132434169133, 0.02523232769641665, 0.06071986840857614, 0.01717327233974732, 0.008428743533459643, 0.019098616002367872, 0.08191757489957156, 0.018928046526026823, 0.009722404610065204, 0.03324693654693904, 0.05193097066254385, 0.02749201319661112, 0.03590804637379704, 0.06444891629319999, 0.02827809027005588, 0.09226000702549374, 0.024106138228108327, 0.012044668002354523, 0.036260397023250984, 0.07766872869744416, 0.20023528125978288, 0.13970034647612803, 0.10658104017737413, 0.06605060696001015, 0.14074492268264294, 0.21172514455693386, 0.1363982010873095, 0.20241850926991434, 0.15994668667835577, 0.08739828282306272, 0.0784012696315204, 0.12358124367892744, 0.11408133973037043, 0.1158878823081332, 0.21805378157765637, 0.1845793858651192, 0.1905988604431191, 0.19780701236619105, 0.15920492970655042, 0.15392002619562611, 0.10027016873561567, 0.15726481203831014, 0.16424710591954572, 0.1576602972683407, 0.19356012734914982, 0.13340382386119137, 0.1241493515009361, 0.11458394703485313, 0.14874951493355537, 0.2257316066853462, 0.12816772015104372, 0.20834445983411806, 0.11599285933639734, 0.1922064653087047, 0.17855955888667416, 0.1600994292886988, 0.1167492945528319, 0.0960658169201305, 0.16450458807089638, 0.22732605016039265, 0.11059000892865081, 0.28147841533345563, 0.10507379282986927, 0.14201802291697072, 0.17102736709339006, 0.22008186146136255, 0.10204966840965134, 0.13715554028749466, 0.10518122900037036, 0.12265078392961334, 0.16944927193464773, 0.15605443908322245, 0.10916483258047413, 0.08562674280256034, 0.08283815211466244, 0.15473915804778376, 0.10590620864663394, 0.15076261013746262, 0.059631115741907596, 0.0812731723811838, 0.2060169468243276, 0.14206801781490927, 0.14497450943435394, 0.14943202266529684, 0.19758152204655832, 0.09869489278043471, 0.16212954696628357, 0.15079025058977066, 0.25949248863804725, 0.1968971450602816, 0.09405256083775913, 0.16072935274531766, 0.1074419468040428, 0.18691436057129215, 0.08928866606325873, 0.17264604959036076, 0.2103743017200501, 0.22915994207705223, 0.12536303395585668, 0.20241944389718197, 0.0984220812097192, 0.1897134466637527, 0.0899495701155355, 0.21119799945623646, 0.1581208693284181, 0.154906073284726, 0.17298145820536923, 0.13025186234904876, 0.1589187652233147, 0.18565840538470976, 0.14297023956333438, 0.08629911519106358, 0.17894837915176348, 0.13618996306773157, 0.14595862598188464, 0.21242092093152387, 0.08491234283053106, 0.18742072936748305, 0.14132557136397209, 0.13843139843834987, 0.2217111466152053, 0.14588762495306232, 0.1514674723148346, 0.17513883840893546, 0.12902838929045585, 0.11278920987200354, 0.28625212369426606, 0.14391415181659883, 0.31572698885875367, 0.13285846118965458, 0.09297103621065618, 0.1784831799206234, 0.1433563938424472, 0.21253816302745573, 0.2090446948404274, 0.14796805928551382, 0.26815167237674037, 0.07278798253185327, 0.18373089752370314, 0.14758985699905505, 0.1299480472000376, 0.1539035553052541, 0.17533377714214787, 0.18192801684621843, 0.1570788212120533, 0.1436187176694793, 0.09733635842079118, 0.13087320562091567, 0.14867972432365342, 0.14379812013958732, 0.08579093842737137, 0.09028035922036057, 0.1730350537165519, 0.1784435425314211, 0.21461583944337986, 0.13279617824141057, 0.11584473623623771, 0.1751608251323623, 0.12884622890382044, 0.12736662966950288, 0.17110327108492776, 0.0860207265002593, 0.1424246777089373, 0.11090373725540216, 0.15264646630854378, 0.0872140999643072, 0.21694045664081651, 0.20893393384833492, 0.10495046033493935, 0.12894329224382678, 0.1335318677968556, 0.2192279032521671, 0.13042409423618548, 0.14942826883446786, 0.13160518731080717, 0.18490213870761857, 0.15929039447538315, 0.22477434918044076, 0.13400655119649826, 0.06389064120969946, 0.14183083699355203, 0.09756659082467518, 0.16309415891526208, 0.08571508040110912, 0.23533900809143823, 0.18034602996082078, 0.12887120337015198, 0.18640160260181274, 0.13051348137519053, 0.17189768894064814, 0.18947925358530016, 0.14154079610541945, 0.10497904307539425, 0.10607003654924133, 0.10890081569912935, 0.21197910270383283], [0.08992920749850812, 0.012489534302374289, 0.006489313907936336, 0.020953657691397017, 0.06281751290624661, 0.09054533371161069, 0.07521003079149993, 0.04076902747094151, 0.07780728335942953, 0.03031569071144106, 0.03957285778596997, 0.04161578828408834, 0.024678308231335495, 0.052550896671750856, 0.0684248666549402, 0.036700510705310496, 0.07849466341036944, 0.0682178850195581, 0.027240642511676398, 0.04362488833947047, 0.009623686520142422, 0.05338788220298387, 0.07224379197484063, 0.0267660970078601, 0.04269578839622198, 0.01907954615871272, 0.01452962069907376, 0.05169198570412494, 0.03537795949547041, 0.09227201162326722, 0.07465837087722556, 0.038898439942708904, 0.07886733454201492, 0.03614608521362947, 0.03432379952902275, 0.020069879509748954, 0.0629120443256632, 0.04479554346612385, 0.07695770717316097, 0.028238663555032788, 0.030421217407790885, 0.06462952152134911, 0.02043227740232983, 0.049390761001456174, 0.08231470721863932, 0.03579061658632371, 0.07737545491827112, 0.0113850777908679, 0.092628916665431, 0.049907663506605936, 0.05765024602653519, 0.0311439830599533, 0.04604066999989652, 0.03293627640232444, 0.056958223482774156, 0.06561194501456714, 0.04500060605125562, 0.038638356922855305, 0.01733871285743531, 0.02507136687786589, 0.052978955960321816, 0.0958757122017203, 0.047761736317507686, 0.03621514420956373, 0.055371567291478, 0.02295918011617276, 0.03981110729998158, 0.0343426721050374, 0.0495845046375067, 0.021188687720906832, 0.03201784423342155, 0.042719839726604765, 0.06141137001254867, 0.0013749149952819873, 0.021799489622935656, 0.03657612483948469, 0.11276796625386323, 0.043920433569339015, 0.037497242146562186, 0.09651050031665834, 0.03933193462510263, 0.03282773323477276, 0.05152308629945882, 0.02713553524846512, 0.010433439540887072, 0.08881601279661541, 0.05062780147718807, 0.03803795849483821, 0.03229696836863314, 0.08188628786874395, 0.024509558213814616, 0.011512609405232774, 0.0024150617771797004, 0.08180995486796865, 0.013327249532355177, 0.08888383456055196, 0.030397694678075855, 0.051819995165832584, 0.031035125796352665, 0.0428206798800778, 0.04027970413106584, 0.03223817878132386, 0.02410745589933809, 0.08327576451964917, 0.08450036372749076, 0.061334098554066116, 0.05891619866052943, 0.0281236220466634, 0.03561224450447387, 0.05857524739938879, 0.07354925942396925, 0.04253916938098208, 0.041981357780675736, 0.017963599285952026, 0.0760902121903435, 0.04099850910865972, 0.04121110999896642, 0.05619048846945648, 0.004540280891477221, 0.019566592302233465, 0.01907818635264712, 0.03396019121752151, 0.059885418628372496, 0.04602331810841157, 0.01175023072714647, 0.03744004602213541, 0.019849508572670243, 0.0417024749631603, 0.0802340737033275, 0.028813576153028878, 0.0701920782786704, 0.04204512693949285, 0.007265624317956428, 0.014389251366317754, 0.016118564620433797, 0.03284777409487194, 0.078601325832067, 0.02628722502249143, 0.032629856554370736, 0.0383767340662739, 0.0343480768553432, 0.027723682015353156, 0.020463662109367793, 0.06321004869776868, 0.05931390171510078, 0.05841831811853956, 0.06696664893458928, 0.01608817008203797, 0.07845026861515739, 0.03725474467501044, 0.020182559552091747, 0.057116374673862616, 0.05582439803308057, 0.08124461262336663, 0.010426391531983692, 0.025573472394758177, 0.004685022671061058, 0.057897742221792864, 0.027517893561913122, 0.027070570992486134, 0.025813083630055193, 0.011545313698720309, 0.02797536488111702, 0.04193833045240852, 0.024147378656292157, 0.05311485229720993, 0.042609174495502826, 0.024839324591260765, 0.025539427447403153, 0.006386719413116695, 0.06600616619952264, 0.05721671687018487, 0.015584059330003877, 0.05823220471821486, 0.022042806808566375, 0.01309220705391659, 0.037458198475501234, 0.06271545467297397, 0.0331495859239611, 0.06298244014502534, 0.031105739950773217, 0.09676501770774204, 0.06934270893614139, 0.07775758723578147, 0.06290161786901374, 0.045977000432509574, 0.10363971454001243, 0.042334696683552, 0.006999578740027163, 0.04967199570889916, 0.05867597263967318, 0.04814106092277554, 0.039288217817703565, 0.04813732241370505, 0.036174518566939144, 0.1172529437368916, 0.030965561182388378, 0.04292187243399601, 0.017397898895245408, 0.059897561121972344, 0.03667393894565683, 0.04481660322316232, 0.041285983602245974, 0.03180791315953097, 0.05913639531260537, 0.04854917128179823, 0.033748877354927605, 0.023338317029899167, 0.03212891357590354, 0.014789024773504467, 0.07726904530558856, 0.029794007817643787, 0.025850326994494088, 0.031885517866260586, 0.030163997641554287, 0.02884570013491377, 0.011041996805297752, 0.07064064574097434, 0.06823717511349148, 0.058518997393548496, 0.05739234252682617, 0.04364066592027103, 0.019892562714014805, 0.01591606651462855, 0.07381420327170242, 0.02390541361584779, 0.016044557654118587, 0.030322062647751266, 0.05929523981326531, 0.043661357955105846, 0.04357590467759198, 0.035196350692140485, 0.024338548236917106, 0.003787792464267583, 0.03369657653233698, 0.034222997679945924, 0.026404622251227982, 0.06807965211450093, 0.04395451682109026, 0.058930539826471964, 0.05227854092335028, 0.052115678291527495, 0.021988983386226242, 0.03991651716792295, 0.04139156583997031, 0.0391566613689065, 0.03451605312406056, 0.033481968491668665, 0.08461805015441873, 0.07594733679246518, 0.0364301735985904, 0.03578102899595134, 0.05916452606118495, 0.01061945813783114, 0.06764342632865714, 0.03510227509503884, 0.010534140840923835, 0.014247657250492804, 0.047757247042271404, 0.03977075744900973, 0.01634901344415642, 0.022701920130320137, 0.11269796113934248, 0.10917539693294995, 0.03996091962401425, 0.041090608198916724, 0.0291305048120839, 0.020314206016219912, 0.04819320852778131, 0.11208345903263939, 0.08134929853821955, 0.06223768776943607, 0.018014402406650688, 0.07873446425242771, 0.00881309559073059, 0.06450662569653604, 0.0407922744090038, 0.035299623174773115, 0.019659756254705212, 0.12932109616456494, 0.07805086101495451, 0.02562778611336985, 0.01071795214703607, 0.06945913131799429, 0.07985482953729169, 0.04265816581826057, 0.0490053306754318, 0.026726773714706786, 0.03460907535026631, 0.031026495815885645, 0.008804151514214615, 0.045061119336394534, 0.040635912033218535, 0.057873763669762886, 0.01289566623933253, 0.08674264179482576, 0.0184606907573799, 0.04009810298861515, 0.029351163032134215, 0.0120596794952308, 0.02146726027281294, 0.08093264629884113, 0.04215287337560327, 0.01492812144269626, 0.053492725165861274, 0.023338069966543588, 0.059406196157778465, 0.041275614602190834, 0.019943582254552075, 0.047298345053868915, 0.0037241801140724773, 0.05060302619371684, 0.012128502919128346, 0.030186239089215958, 0.04920067543524408, 0.043709728746644916, 0.01894319782994928, 0.02501469743888705, 0.02064458143356587, 0.006927812102085521, 0.030752642365593105, 0.028693712121176145, 0.07835157350787232, 0.03272967398046486, 0.009723000243426332, 0.04197271247845023, 0.032308145591448394, 0.06839008626317786, 0.025816391214668274, 0.01887996301745936, 0.023694913721673434, 0.012513816416744265, 0.06001796333059188, 0.0445741632082049, 0.01068455933202659, 0.018255815863789573, 0.03511196993772061, 0.012469078797186095, 0.07008464976904855, 0.050101947234643084, 0.06116691518635039, 0.10432999040330611, 0.054047418788315794, 0.021263448326217554, 0.025206974016562588, 0.048061249882824, 0.01647679499470659, 0.06709623270698133, 0.05592014370185714, 0.036578802316780054, 0.021325627852591778, 0.05511135786711689, 0.15087663466411252, 0.10162707132798049, 0.09107189658548563, 0.09812283960561599, 0.12897886936703037, 0.2682727142687767, 0.14343222122519247, 0.16927992053810628, 0.19459457587330573, 0.10984979945445254, 0.27436688241939394, 0.16842456804888864, 0.11188573940026184, 0.19406635824951435, 0.13987460083538486, 0.1524341527012087, 0.2040997198632648, 0.12466063092072165, 0.13501743485610332, 0.20633559343555283, 0.1978231614996349, 0.25807442924668716, 0.19307816611422648, 0.1623630812091212, 0.08271190848562025, 0.10846950819775944, 0.12268173388175427, 0.15481294763665046, 0.162502785002993, 0.20027096563529587, 0.1426447594478246, 0.10373262568346917, 0.20948148753133514, 0.14505456562244123, 0.14631721641748183, 0.13887562218212313, 0.1490396171087219, 0.11124112237725528, 0.2885969962564207, 0.29985916290071707, 0.2097111913345514, 0.19978575618757358, 0.14391405988604794, 0.21846169275381874, 0.15964527704542683, 0.09061916926575285, 0.1580299193700475, 0.15466227346370298, 0.20280680859521513, 0.17477624899437352, 0.1806368829021531, 0.16412730508994672, 0.1664115954190493, 0.11625897529865466, 0.17278405266904062, 0.19769395311032573, 0.13487838989784642, 0.16494274439830936, 0.177485978591346, 0.11999631991549847, 0.20195116499258628, 0.17009827098058117, 0.09375395508663309, 0.1912477982020186, 0.25097895353551836, 0.15318093520979728, 0.10270007705736546, 0.12860868036025955, 0.13858302256032345, 0.16514247884192776, 0.1598817990311692, 0.23425741451642207, 0.21804795930943183, 0.11724343658575129, 0.1244817034251267, 0.117797915703587, 0.23586246064834057, 0.11530566314655928, 0.1386266282849735, 0.2136676524194979, 0.19555417760725946, 0.1813406572346726, 0.11802568896523408, 0.15509874439768254, 0.09589890168318826, 0.28943767050100916, 0.2035646993787058, 0.1359613317876093, 0.1285665761679411, 0.21711740762956683, 0.1540224674728609, 0.09791496164736249, 0.15436567486293856, 0.21394813253033548, 0.1497208071692336, 0.11149678123934616, 0.07588748234294115, 0.19123462148972098, 0.11757956532340859, 0.15924153338757255, 0.1892325273084064, 0.31821594723770696, 0.09015635256805728, 0.1557796739883, 0.22308553899488143, 0.22429631031568975, 0.15032296759947655, 0.2587678001051949, 0.09072296651861361, 0.215265144924483, 0.13979474383015789, 0.0750154827631289, 0.09089274692439264, 0.11218200858321883, 0.12001973156246448, 0.20764376517505417, 0.12337009452523724, 0.20241072581660366, 0.10675838187096581, 0.16358845416576634, 0.06900880951434374, 0.2064913850758345, 0.1765956465275057, 0.13004337918133507, 0.10537389245244766, 0.12582785014303463, 0.10233037834686619, 0.1469471245523422, 0.12625146612164476, 0.13536176073455042, 0.15680234008018049, 0.07436446890595459, 0.22318537557317367, 0.10845552709314132, 0.14124934561550617, 0.13583339510425446, 0.19903868256557375, 0.18943839045541902, 0.2523769107797454, 0.22064679001848544, 0.12238230841654925, 0.09539849305104825, 0.12136039309083455, 0.1666242920703465, 0.0995075511896322, 0.15558775364150926, 0.19996359583831605, 0.11564196042355993, 0.12225874609524205, 0.19437339096780748, 0.09210058412845097, 0.23292434491938163, 0.1500442648126233, 0.19739239025981198, 0.12670923429991932, 0.13675904382140408, 0.27177018143476983, 0.09321364093451731, 0.12024869992127342, 0.13113958971394649, 0.10048776068874907, 0.10023116719939056, 0.20122952548967254, 0.17285911396386164, 0.16323150315832707, 0.2226285981915651, 0.1789366426847635, 0.157355424917994, 0.1096308362039347, 0.07949404809023104, 0.15523489354358566, 0.14995374386349034, 0.14900646082335903, 0.13680982012902537, 0.11755328850760577, 0.24605532176792624], [0.023150636979769317, 0.023839411310731404, 0.005764562651635178, 0.02442842567219369, 0.06886598774262014, 0.04457364609885601, 0.047126293197394385, 0.04927890450363198, 0.011257194733667758, 0.01331767151808186, 0.04210452556670193, 0.046275092904726346, 0.04125588783814062, 0.029282571349833763, 0.015677609199267483, 0.014436942254824024, 0.022118814221973863, 0.04862982118802686, 0.021185066040244796, 0.030901278744662003, 0.0676016285715084, 0.058923625882955334, 0.07783510001196016, 0.028366198042227377, 0.022636739454502543, 0.053201692193866744, 0.052622050918158025, 0.04562792097849231, 0.043735476961779984, 0.007145692295800414, 0.026845923369570125, 0.03471222525883106, 0.05973913030879152, 0.054305004361536235, 0.056873884863190116, 0.07398653475026931, 0.06819825784693803, 0.06696549980270286, 0.015619404711610368, 0.02252680200692867, 0.03163164590425309, 0.035603292767078645, 0.06212991068980867, 0.028943985385159333, 0.0933218814973389, 0.020094656708439993, 0.045082374445853696, 0.035052900728318966, 0.04669256485818375, 0.058619714972953645, 0.009843367020479374, 0.07384720633948043, 0.02229714225376806, 0.046478638635768045, 0.04667062026959273, 0.03822156678765051, 0.03512579399431425, 0.03356182549689566, 0.02112736046734837, 0.028961800759838476, 0.004470248006269216, 0.0795781032572831, 0.014849032440613356, 0.09577945325403445, 0.05442364839836956, 0.00808554859231076, 0.01184691868406991, 0.024969530810091286, 0.05065590924312992, 0.07381026557977162, 0.011256921814844735, 0.04394218280550934, 0.04850286126677548, 0.04289158514790958, 0.044086406518134384, 0.0014752114657312634, 0.07092421318614675, 0.04739199164173296, 0.011742493239111237, 0.03479220100768632, 0.033529737904187173, 0.050085077978550434, 0.06775935075335926, 0.017614416410064986, 0.022298023254880985, 0.22507597331798848, 0.019069447204650893, 0.08612083120932502, 0.05660527145429965, 0.01728712449661426, 0.07781757192025263, 0.023305449942727725, 0.006968738913025347, 0.07357483143888174, 0.03965889712074592, 0.07299124097992336, 0.049374140723938906, 0.040356630849982464, 0.02633876933325683, 0.04008023781822093, 0.0628763561197106, 0.04397073873288689, 0.03353967023412547, 0.07347009955875336, 0.08253791459625767, 0.07765798814474575, 0.025104245456356197, 0.031156238551521977, 0.034983029679184964, 0.034120326576333855, 0.05100205458039719, 0.020589909568849592, 0.02158965047959599, 0.09722887628501463, 0.0285062657278632, 0.03101893644329281, 0.054009110561662146, 0.10243494168765123, 0.059543578705239686, 0.08057771010264274, 0.026515333447605375, 0.018292095872663686, 0.04624838324924631, 0.05370757835466535, 0.04571520137570558, 0.07549440262899285, 0.06849098770368485, 0.038267620163218635, 0.017326692937903346, 0.009400937837668726, 0.04013935299289804, 0.037398880287524194, 0.013511934178701092, 0.01980167404267817, 0.03543217936831136, 0.015829841403530973, 0.013416411633032465, 0.05960505726116319, 0.037520531219460314, 0.06890538764456589, 0.02361635332025828, 0.09606067647015858, 0.023634274032027013, 0.08266707702029137, 0.05606203084631313, 0.03146834851753327, 0.028023894635900378, 0.041137255292626164, 0.04931853423195501, 0.04630444939398477, 0.02820190857164562, 0.027111541374676654, 0.03996487646814316, 0.019472035984959335, 0.07539278872671627, 0.054623306233195536, 0.03577463982266284, 0.05162971807763942, 0.07345954286715678, 0.11956526522314358, 0.023924841605607542, 0.015200280881066237, 0.05349707271483156, 0.1048807233511921, 0.033404923029123776, 0.03138273053111569, 0.08302753671042382, 0.0598211323602065, 0.0720855028879258, 0.039528466821197546, 0.020049995697674253, 0.10194452284204383, 0.029177906502398755, 0.05263389080702778, 0.037416530953299616, 0.07963361398827645, 0.051264719316555615, 0.04617177062637864, 0.04877586052903245, 0.07506015334999369, 0.06878790806137747, 0.10014836841653432, 0.044800434937520374, 0.025430828738476963, 0.05356449611304749, 0.11425812984065664, 0.03435257762189835, 0.06372140855678628, 0.029327140430048592, 0.015484519610782305, 0.020886117464772636, 0.033225551202532747, 0.052122404543502684, 0.07844148924754513, 0.03610225349304176, 0.03928048416010795, 0.036707428479266745, 0.060460421241699695, 0.03573225600825202, 0.012926823035213015, 0.021126339655189265, 0.08223906369699586, 0.0832656215155317, 0.03967942827711663, 0.030470817770448425, 0.018068177948495554, 0.056005378644312584, 0.10474010791269042, 0.040251362708307085, 0.03150124624822169, 0.021195327787990534, 0.004435570078766755, 0.07150070201004706, 0.06005878049519755, 0.027295101786993688, 0.02196921065690056, 0.05054630887424273, 0.03209895953806418, 0.026353443747446425, 0.025922013672008633, 0.052482845081437024, 0.017191018766513275, 0.021124200354660713, 0.028308046223115058, 0.03316386580286968, 0.049322226775750044, 0.04141468637352509, 0.06363047775061381, 0.016130758824968533, 0.06359114679658125, 0.023609778370648146, 0.032270477048211524, 0.049899949001208435, 0.03428912638956982, 0.02534382604813624, 0.029760725127773422, 0.04489261829744905, 0.038216851516476566, 0.004715291283754332, 0.06779079866265098, 0.020772299781862288, 0.041587324287261695, 0.01768593837867581, 0.07453427229437136, 0.07831809546558127, 0.10549421422183515, 0.015582982018860358, 0.025390227993709907, 0.09297058421878085, 0.0820386934004003, 0.02082857468556012, 0.03259368188258621, 0.03443446476012468, 0.058457553311581575, 0.010947570722970751, 0.03343200040680747, 0.0648901752767063, 0.09952700982290892, 0.08202933946684485, 0.07490771717482037, 0.015931168980445835, 0.019754490687421734, 0.03804900548270634, 0.08348456178341182, 0.039791120066037106, 0.03581136607775285, 0.03752678632736206, 0.01429891044784698, 0.053927020410135876, 0.0545158815540133, 0.06818683547598701, 0.04365670397096584, 0.01987348903992003, 0.027742464576036702, 0.03872126295802094, 0.017724698597204783, 0.049397131022546566, 0.022734074755722, 0.06709689920347545, 0.07191680266612, 0.08492086172824906, 0.007872980260740845, 0.0407456349761736, 0.013522600037826887, 0.01662347401912895, 0.007587505735441923, 0.021959557949054628, 0.025305209471093073, 0.0700149510896975, 0.02993752098371906, 0.029936741489256104, 0.02010483227129425, 0.031053695767637224, 0.047757442394692096, 0.08434212826673063, 0.040519550938399575, 0.024551673897451932, 0.055165861192489826, 0.0553798180584225, 0.02487047755670163, 0.04926028473663235, 0.050124259545437755, 0.031321328583984606, 0.05783824400315362, 0.05743311372615638, 0.04942043541720317, 0.06275532954943276, 0.011439289045219701, 0.02619140082970262, 0.04799817403357837, 0.0359372649672291, 0.05750523707378776, 0.07192428734514021, 0.09440856955705151, 0.01935981751059092, 0.09452139898653954, 0.012519115829960474, 0.030101145873026505, 0.008716200790067595, 0.08210993191647915, 0.02951204915711236, 0.014674759886768318, 0.01613042749194128, 0.04760726234845577, 0.01769737415616551, 0.06413143413561968, 0.011198442493144785, 0.029691216055183645, 0.018892002089189428, 0.033832537986698656, 0.07122770657822972, 0.08446367577679696, 0.05991148093955652, 0.12800238305522552, 0.003972672223631714, 0.049569466331553076, 0.03921771091559241, 0.047890017740428455, 0.033127518761302197, 0.04547502515056441, 0.08719048913448088, 0.09555852881843045, 0.028748835977767746, 0.04067652618452426, 0.05811637988494289, 0.01794798258361557, 0.040576019279298284, 0.034529528610648653, 0.032455935443360964, 0.03891668432662564, 0.048960951201978235, 0.06266608030625409, 0.16678910822637621, 0.17960850179435747, 0.10449049348432211, 0.16797780089320677, 0.1735130925813029, 0.14703775275378458, 0.14924512785528937, 0.123089277335713, 0.15310668596817603, 0.09519509670715179, 0.10136064893055348, 0.15360784536648184, 0.18451874234503318, 0.17232960931235747, 0.10780545552411389, 0.08091571575571453, 0.23144604037365607, 0.12101227507716227, 0.07694016375969495, 0.12578783737074944, 0.21995239260215915, 0.13892221564967788, 0.11301540499252659, 0.11679588802038662, 0.0980941879172479, 0.1808143854742089, 0.1803465355788508, 0.11191432214071674, 0.16692904184662527, 0.09869880748972779, 0.1401344885028178, 0.15653649224869667, 0.09287543609858522, 0.16365626826882362, 0.15280579727503563, 0.09628709375617966, 0.29235373821950733, 0.0979031179280531, 0.1486163075652815, 0.141874534648753, 0.12401128713522228, 0.057221263602015474, 0.11226021849940862, 0.09866221913046415, 0.22671120331412364, 0.14730430538615874, 0.10187512293698327, 0.12249696113529707, 0.10681041456278294, 0.16299176360330275, 0.11738605151373534, 0.23731810431326592, 0.2152656658642715, 0.14395965743930111, 0.09735063829969975, 0.16783235143990288, 0.18687605617507813, 0.07800589165379924, 0.10509162735674651, 0.16169860718711732, 0.08395631872718373, 0.1721023723122574, 0.10890535093964109, 0.23129784832558326, 0.13265149487603095, 0.0784387466527762, 0.17301934891410414, 0.11268476910528638, 0.23425243494491424, 0.20306675754968198, 0.15246121092669426, 0.09842350613325836, 0.17193032428622249, 0.16842162627125942, 0.15964538429773625, 0.07401143260780843, 0.14797909095162345, 0.2809473018973105, 0.15534216117474342, 0.07211956315703931, 0.1005816371029904, 0.2121107319309827, 0.2534863286681714, 0.2360590847749864, 0.11125221533039886, 0.48098962093072556, 0.1180290061259462, 0.2156738987973621, 0.1612482394181913, 0.19133209851720642, 0.1356325421722666, 0.11754363579975984, 0.08549627802905538, 0.14157284922417135, 0.1306442525838652, 0.15160699224760457, 0.13371943676423642, 0.1789678531067987, 0.14128804837744083, 0.12771800355685334, 0.12525721423087582, 0.10272582527250053, 0.25374454626392934, 0.247482267779208, 0.1890070063452567, 0.14694804385785135, 0.12391353431608408, 0.116020645345411, 0.11610738182019804, 0.15374275344994762, 0.16880329127513594, 0.15793313182169394, 0.09304950659674022, 0.18186731203909845, 0.1505981310601196, 0.055301305537502614, 0.1605226469015883, 0.1500682280428948, 0.15525277403573837, 0.29354549523803497, 0.24165574010581742, 0.16960814324838502, 0.2071130807481466, 0.06269924042205657, 0.12671851928556158, 0.1082238621048389, 0.18197710776040632, 0.1384624556428002, 0.14319824265135875, 0.18499914076059096, 0.11530685824372115, 0.11683306626735196, 0.09642875107425837, 0.11043061667512502, 0.13235301169897282, 0.16596871999002275, 0.19053087780071845, 0.3033168241381645, 0.18525417143058392, 0.17520369541260505, 0.11951339340979054, 0.2667795782608371, 0.08213033283790273, 0.145199095770236, 0.11050136489493233, 0.1528532181175486, 0.15505527656885887, 0.11885504809118087, 0.19789669061860732, 0.1138913192816319, 0.0962814093837815, 0.16395734082306587, 0.11043967949526926, 0.12062704010355858, 0.12579379753480036, 0.15534243696639616, 0.1998684477181204, 0.2746465964423072, 0.1517112874576161, 0.1949365881662215, 0.088882731393941, 0.19686763535343832, 0.131939691942065, 0.16710924104817454, 0.1093898326038353, 0.17350659615570502, 0.23954522916145865, 0.14680391207577723, 0.1284108687973311, 0.13964338017807854, 0.2589797000250509, 0.12595528886923868, 0.11165615051023423, 0.16897939956716954, 0.2097261147273164, 0.27239068200992], [0.0355689758585105, 0.034549580962066694, 0.02752967982462818, 0.03745930930299144, 0.048306528253540884, 0.043049426073388714, 0.03410696983337402, 0.0046507751892110516, 0.07728084305962248, 0.015934274509368886, 0.01925913632036217, 0.040878957257636135, 0.07501852413218829, 0.014093178493391364, 0.03517350211979882, 0.018706865450968186, 0.07699315406141743, 0.05600378518143008, 0.07369346015395657, 0.08044736790320567, 0.018466790732476982, 0.005337692235761713, 0.014732376401943546, 0.051470099828175964, 0.042914567785638, 0.027787332430542, 0.011402954452580983, 0.03419120503108829, 0.019101458188566952, 0.0549644758293946, 0.09750437682434436, 0.030747231869627873, 0.02581799425364983, 0.028115639410492395, 0.05341246979491365, 0.014822380241727637, 0.020493070309561108, 0.06689125822196085, 0.05200833788201694, 0.002786752316282101, 0.03367048740807561, 0.09340628906483613, 0.06626262945393402, 0.028571205085984645, 0.028234858013268922, 0.01585370887281193, 0.04946432842482482, 0.027971256734623064, 0.09429747148627236, 0.07377218334905564, 0.03596143887167977, 0.05076659362642996, 0.0180540110675558, 0.05710838437681237, 0.073604624598257, 0.06926682026636216, 0.01803085414482461, 0.02035412877317398, 0.03630738502608673, 0.029323158688062144, 0.11861591374561672, 0.017115656782181996, 0.08548755228759781, 0.07046050016557978, 0.011299839975582737, 0.019184174616971326, 0.023724911809568445, 0.03323110150954416, 0.044462421623569344, 0.011771271331986834, 0.038905154703365225, 0.023109306536254384, 0.03850054919659611, 0.04556722766269119, 0.07824337124944696, 0.022759882342671196, 0.0834068651461313, 0.07369106995963282, 0.03584454151531381, 0.031500022422762654, 0.01445736424366553, 0.07239733897750417, 0.05097056836670926, 0.04454568005918015, 0.0490125970193936, 0.07531091691024842, 0.006882328504411083, 0.09183439921828047, 0.06646481537891012, 0.0112781596873256, 0.002460639938832291, 0.052779891843637156, 0.05555773814839702, 0.0390081858683017, 0.08796812200378026, 0.06260002054454339, 0.026218786557775833, 0.03600871415748712, 0.019126926781609654, 0.02107259475686137, 0.01264009356213313, 0.00214591809180415, 0.0031982562054068816, 0.03923499002872456, 0.025200106038321412, 0.025802277959883217, 0.061523494641146356, 0.017502456490371018, 0.05282738546450293, 0.05870954261251515, 0.012855796150923257, 0.04365663119261304, 0.07905334835090945, 0.027837884657445456, 0.055561656688129714, 0.0066624947864892745, 0.03609235946749968, 0.07282496159595829, 0.012357741323930603, 0.05009420974660785, 0.02366693619067871, 0.02078407646847829, 0.03522152434133234, 0.026337794486373186, 0.024524067919100487, 0.03267779067579297, 0.05396188124113026, 0.04745663414078374, 0.03153388159379604, 0.022437677253037695, 0.05736127383105698, 0.027192591561845718, 0.04897769022312376, 0.056075927681259574, 0.07863716342516484, 0.007908815938618877, 0.07390575077865394, 0.045744818334858266, 0.03768070488266888, 0.0969202347820805, 0.06098725607678775, 0.050206912771588376, 0.03735214892414309, 0.025682593958692688, 0.00649634467986142, 0.04516704248324518, 0.02248191500022527, 0.0638787132207184, 0.03905431202222263, 0.03931830209049006, 0.02603542149787949, 0.08622875767609767, 0.10509993174984571, 0.021061992099989327, 0.025317319405956135, 0.03579623584124831, 0.021311407345497323, 0.028251819199912494, 0.030426133777044957, 0.03434185239095842, 0.021424139098775004, 0.02437728738802816, 0.029211449662163377, 0.03307216124789369, 0.019493582207829725, 0.04154193357774808, 0.019294136962402734, 0.03307221870448801, 0.0823468829114591, 0.05111153620565611, 0.04754668394584329, 0.009628416155464947, 0.0259839327284886, 0.07843339169818549, 0.06777569906966341, 0.008441640623664905, 0.03058538813474438, 0.014676336112672524, 0.037973109152047865, 0.034326848558961384, 0.022187099469104604, 0.024912298296488104, 0.027747965087333036, 0.05507274320529354, 0.025962723584304896, 0.05434082280243597, 0.06911056131244668, 0.0375422383207948, 0.01546569587287283, 0.041644696611911065, 0.02532306506538824, 0.049188938968244104, 0.013438472092422027, 0.062018981158372864, 0.10566738839711874, 0.03361074021086097, 0.034668573568905556, 0.02221980376259214, 0.050463173012699813, 0.035110292205166434, 0.02366854689053951, 0.01646803094885282, 0.02026350440217122, 0.018582598328770652, 0.003765235244739621, 0.02197734651065642, 0.031008103960043484, 0.055689087753454526, 0.017753543722773754, 0.04432425383598574, 0.07856063890240847, 0.011721042777231384, 0.032150974992903016, 0.04820932318726855, 0.026800469457802754, 0.030446749203087344, 0.07028864366152594, 0.08394101229045661, 0.021950477891932094, 0.034548991074364994, 0.07366512256163744, 0.04367948359539432, 0.08691756265057672, 0.030856592836038723, 0.04370528543668409, 0.02862358060214789, 0.020608651909917113, 0.05537512193944666, 0.09249776241279418, 0.024855962105756326, 0.06076496034379929, 0.06616405692071685, 0.04061522382882334, 0.016200589654486508, 0.10457201290034479, 0.013080037747239395, 0.1390076650967521, 0.02008942815835678, 0.07766773278314261, 0.0027643715363791996, 0.019872784239029693, 0.010943977770605877, 0.06069655635304028, 0.006120171568792073, 0.07451240814501241, 0.00752351345351687, 0.0939155689951393, 0.08529500374870916, 0.10586649464863924, 0.03525925417160315, 0.027321640987910574, 0.13829216961899113, 0.017578465818998315, 0.036253115357530695, 0.058360160553767804, 0.034191798749229604, 0.09540505842455933, 0.009179058664989088, 0.06923606949708155, 0.004719992190779698, 0.08036126728139578, 0.04545279327900179, 0.039992474785615365, 0.09115890885192542, 0.03927831613128224, 0.04132895730435848, 0.04639776656404138, 0.028735776093878576, 0.0501740399387575, 0.05729719440663054, 0.042705127008018956, 0.068584511717481, 0.046057822708521164, 0.03403569684333859, 0.09469809716627484, 0.06324320115269193, 0.06758921028625581, 0.045561596916447726, 0.028195090389119524, 0.046483828881455046, 0.011035914067178966, 0.011851995931788078, 0.054629274058125676, 0.007433196475293728, 0.08644120151837988, 0.0674562327443592, 0.04625360030801066, 0.03133649137922593, 0.07584777600582569, 0.026208252848816976, 0.05762518346009236, 0.022670280699047352, 0.02902297288059227, 0.024683151822236758, 0.02236700372680301, 0.03305401262496749, 0.004663224117980609, 0.03859637913504436, 0.06676483073181684, 0.05478881186835709, 0.033033178863866676, 0.046276065836390184, 0.052801062683424646, 0.030454208984250025, 0.03511674266548888, 0.01536155005000652, 0.03869868634689239, 0.045412539189020475, 0.07172362593513343, 0.07283882778738776, 0.053972169801953344, 0.04549407775724127, 0.06868647035932349, 0.06662839047250248, 0.06814499175356281, 0.043893800522651405, 0.09719234921278493, 0.03452693540302496, 0.03939283478464331, 0.06696414382707688, 0.010324209767033257, 0.01718341151342517, 0.008582559624506582, 0.10981592304644086, 0.02950503753738538, 0.04121306735361296, 0.012337293479621652, 0.012794085853402654, 0.07270784973497353, 0.053727255323000496, 0.03327451571221313, 0.07177022706356741, 0.03153167143013449, 0.047433184189421516, 0.0057083849453427385, 0.022372653625244578, 0.008249223277333283, 0.05389715830284742, 0.0671309135073135, 0.050263193420945644, 0.02857326586250096, 0.04386761180695988, 0.01690237215840288, 0.041945156295813864, 0.049903151248731924, 0.06326768915319154, 0.014448491030282553, 0.04969579806070655, 0.07440277330216861, 0.028594796763612863, 0.03380181786093501, 0.01507914705847901, 0.15064861625432968, 0.14837563338298954, 0.10841451074567535, 0.1480082176145046, 0.10283266389442068, 0.10533308294872124, 0.14423682805030577, 0.1481680235555095, 0.08901300464546488, 0.11755518074477873, 0.13861178150100095, 0.1510026254841397, 0.1403505099757064, 0.08602384447811112, 0.13438676063331867, 0.11718843147278794, 0.12276826351280175, 0.25104091472683415, 0.257432600783725, 0.213006901584806, 0.07543100119237939, 0.06993766047901685, 0.11762008371372377, 0.11327768285428325, 0.0911082934227682, 0.194915842505232, 0.09063479745940817, 0.11506528007767855, 0.11675016789306557, 0.20551980172674503, 0.21139404135605983, 0.14462834494488855, 0.1870128028695622, 0.1358598557811591, 0.1330681700980471, 0.09119083173573019, 0.07233835020733458, 0.13737330844085063, 0.1779576282828085, 0.1571692195871184, 0.13629162293528357, 0.2523369516336149, 0.17423419582266964, 0.17972893081605437, 0.23727655170425294, 0.10917626261230438, 0.1985260624919207, 0.0663530967769123, 0.18232344078921503, 0.10476488319616165, 0.09403546941616843, 0.12253430792160573, 0.20136903010068402, 0.21818844451298638, 0.2129924072012786, 0.18928800739588278, 0.12119337060158292, 0.14581029603798545, 0.16227683503060572, 0.11849150106671358, 0.1621310025333397, 0.12015318407887414, 0.1661252777182287, 0.1867483186745836, 0.12828692343206177, 0.2104710739466452, 0.12958142816299392, 0.08836526198372727, 0.27649789387660645, 0.14242302295902085, 0.15121500037850874, 0.14526818157924762, 0.16982451712171878, 0.17022573268942295, 0.22724663748616175, 0.24125086263783518, 0.19570247690764167, 0.15583709993910405, 0.20843145677879935, 0.09542898335043462, 0.1755321019839856, 0.18165135185324377, 0.11755305868122848, 0.16965348033174393, 0.209965547847171, 0.21437341858062053, 0.06785842124372721, 0.2579331013464159, 0.16125046107317173, 0.13649852796187326, 0.1365088088618171, 0.12675910662378997, 0.1310628123821751, 0.1523810015210221, 0.2565762830237227, 0.20236705880491965, 0.08580519532364222, 0.09467997152598635, 0.29403401418559016, 0.13864466199471107, 0.12504130001029662, 0.15635667609110956, 0.10286159137444151, 0.2451519355658562, 0.17935097367773134, 0.09461001237674106, 0.13180315975219975, 0.07234051823616028, 0.2423219608082887, 0.20225228351210395, 0.0851271002583446, 0.16334384229154358, 0.17483467085947915, 0.1355010355191846, 0.15207378494162715, 0.1282815454948333, 0.1364436454229778, 0.12277553368720318, 0.11331921248065849, 0.11113241450079989, 0.09574745376143726, 0.15018764582853164, 0.15531124186611947, 0.10125529651920642, 0.08922604603632804, 0.22262953281883271, 0.1246952351122614, 0.149723565085761, 0.13044189811954576, 0.16736729010458917, 0.22047327110363593, 0.18500834913744083, 0.2078047202479455, 0.14623573530585537, 0.18692173033712373, 0.10270742384055931, 0.13768962614478605, 0.17129001267735036, 0.18995372248032402, 0.2386333700269461, 0.1630460179501003, 0.14308221097434723, 0.13203303209475933, 0.1562605933436463, 0.07512667276445897, 0.21973338338636586, 0.1089236451192729, 0.2124177033622419, 0.12451031680909858, 0.12036933578670987, 0.08633764175277564, 0.13860574472815762, 0.1939314042007731, 0.21025998607998897, 0.11673280067982213, 0.14354693523097423, 0.16463257071952667, 0.18929284907156424, 0.10701829252103645, 0.09828086056175733, 0.10558255948126317, 0.1374635382765724, 0.16948814323592573, 0.10360820534368677, 0.16511408762345392, 0.13820728707698085, 0.12108192779123784, 0.16317298936267055, 0.1797161218259604, 0.18317346130647968, 0.09651846763107086, 0.11188092836809736, 0.15478627245512702, 0.16047930164683252, 0.13477147466713382, 0.1041794005000303], [0.036222433536163265, 0.04901083118672814, 0.03172907313602346, 0.05151160647191348, 0.04098569245768651, 0.03406798744934701, 0.04619367691057344, 0.03468617060852628, 0.03884425454382454, 0.03934842466767277, 0.09226627362471435, 0.03781708002450966, 0.009219015895899747, 0.03714031029132105, 0.05933051050129918, 0.12390547507112065, 0.02800232926083188, 0.0527904408743545, 0.04200077427911662, 0.018332633415176984, 0.042377126463238275, 0.013109655664001983, 0.06681886291311634, 0.011885552498091374, 0.059573337390658364, 0.05734378787418527, 0.07072919784414192, 0.03111104319442905, 0.03762949190493073, 0.03538918651400074, 0.04278615229733048, 0.04684842161593899, 0.013049311875816316, 0.07185134811386948, 0.09060754005106227, 0.03057431816423853, 0.012376702000056545, 0.10751457193926459, 0.04590985282594639, 0.06145443947565171, 0.02019111292376634, 0.023357538175919366, 0.0384037233438463, 0.08359083350026801, 0.012796838024270632, 0.07317311025314754, 0.0731074718397952, 0.050265752154612736, 0.014531251508742573, 0.08335065727512683, 0.025314308680413712, 0.05273173555671688, 0.02534341619109675, 0.026189269190053308, 0.037553610896030744, 0.016404120063769723, 0.05673376738183922, 0.03714497576677992, 0.024755365185199246, 0.01697434420366922, 0.03322517581944985, 0.04765809994311102, 0.026503244580160228, 0.0907601907308544, 0.04841001524079231, 0.053346387050565214, 0.07044109515845776, 0.028489938478976972, 0.07427801588369955, 0.03419898848439898, 0.08006727337957391, 0.06473548680303559, 0.06214813209108769, 0.04852291744863314, 0.05462673830709631, 0.043959366157650955, 0.05709195179083655, 0.004865394242393274, 0.05283853970468045, 0.07416132537107314, 0.09777765570869369, 0.1683280562921878, 0.11779000201532919, 0.07225960402959777, 0.7124158043053843, 0.998913137422454, 0.13740551477718738, 0.0732872496929861, 0.08942354350320755, 0.18837590311323443, 0.0880411684873604, 0.027378540253266696, 0.018457385087986628, 0.023532732908103256, 0.06565268557038038, 0.044616608309649655, 0.04677190092362223, 0.03039267680217182, 0.043556610753218976, 0.04173032225920789, 0.047749176305989106, 0.04411805361028641, 0.013779163841278324, 0.05830731963919056, 0.08707231241128138, 0.0870842710437794, 0.05255328686607461, 0.04734302713205257, 0.051876283476069096, 0.055455986350294084, 0.07203340124819549, 0.04227308406224174, 0.05056934130768623, 0.017511379499469074, 0.03157621369727197, 0.008921759417130342, 0.009268366322371989, 0.02450740933718701, 0.05023019801404688, 0.023903184299988132, 0.050979726947844035, 0.0759507765272452, 0.014089107693683718, 0.030139436862701853, 0.07303427979950944, 0.032361741102631056, 0.046429444299710375, 0.03845466052993171, 0.029476366696819186, 0.0322770232695245, 0.0434997555379185, 0.039736023022522854, 0.02490054267729002, 0.03522560758996875, 0.03763663950526426, 0.04364512838242997, 0.046970041904358134, 0.07854091213835825, 0.015192728211742737, 0.03837807472014139, 0.03581500116495356, 0.02692978892986092, 0.05653259652336279, 0.08132272294812626, 0.014111409470769427, 0.03833857905720511, 0.04315376341823609, 0.09606602376387005, 0.07819532221483608, 0.051974587878512765, 0.015629353320917055, 0.02729377070922525, 0.021251731011415684, 0.014417459681299667, 0.03499661624852208, 0.10130534504329967, 0.02525076743275408, 0.07728877206963879, 0.00491347631454588, 0.03133164587310486, 0.05032305936178854, 0.013862126375428371, 0.0632728870597578, 0.011730251154081236, 0.004526252385168787, 0.04061736887501132, 0.009305865368655613, 0.038092618868235624, 0.021877584625936804, 0.012452602161154633, 0.04159567081519673, 0.07790968633226811, 0.0710814833761223, 0.01298232131727761, 0.06622903649845431, 0.0365444471038157, 0.07167322501059502, 0.03834754228591919, 0.045883641127617135, 0.03792821639968503, 0.018055014642736605, 0.11203903359391036, 0.025428965229601152, 0.04459815325155374, 0.00675110147342146, 0.030849910634119185, 0.03995162697749273, 0.0291116054229919, 0.014656762566207158, 0.05199090938173956, 0.032613852977632515, 0.025006534772053845, 0.09352616650322754, 0.02234403258039346, 0.033540524422161044, 0.039473342964605945, 0.03379851985242098, 0.0702857172056552, 0.020748189079665372, 0.003997272025087788, 0.0345551312690781, 0.018534018778272213, 0.008480233260460438, 0.013565764304310566, 0.056768448182171395, 0.04412354263026388, 0.02415020552073275, 0.0018347469426038105, 0.02184213582246054, 0.024884765096489462, 0.010248428349563432, 0.05825595344386755, 0.02567809702257716, 0.0444592270369251, 0.014801144284466583, 0.017931396780054898, 0.0276836175321331, 0.022756032750851685, 0.05867248310917809, 0.016481485368022998, 0.007210376929687037, 0.025258937760466532, 0.05644382608513679, 0.025374122910321723, 0.040670826490367615, 0.0183027655622291, 0.02144966514841203, 0.0578628852212381, 0.016589432902213548, 0.057031752601746595, 0.049884723003713355, 0.04175373007573428, 0.054800858600966396, 0.015515360395394027, 0.025779994377385707, 0.02085014963672767, 0.04225655571527539, 0.021228646867037303, 0.01830440307516725, 0.0493034461302863, 0.023082884163745952, 0.029547003833877466, 0.07890746988836797, 0.047202024819149126, 0.03480448905799178, 0.0387202900263571, 0.12576706106624297, 0.07237657799475616, 0.11756996624171735, 0.04962587721585747, 0.06552677902002489, 0.10256227316154588, 0.10156390737862357, 0.014616192464957075, 0.03949739046454911, 0.023423061676083073, 0.1300864486444381, 0.10627760041144588, 0.029705365699145104, 0.035275510557356386, 0.6455572273942732, 0.8128944255651966, 0.2241563613736822, 0.08349495759654431, 0.02761646034947086, 0.24494749734238272, 0.1863712961635282, 0.1323171281405995, 0.057634054758255525, 0.010346967366433913, 0.08472715639659474, 0.029187599429860715, 0.06367561948155204, 0.003872670218228333, 0.02758935615870982, 0.028091111190376744, 0.1202669328138713, 0.01984491587556418, 0.043024417133100575, 0.09127112541107402, 0.03652695348606475, 0.03330697868800452, 0.028813375054948756, 0.053155784375004234, 0.016655082806884762, 0.034435357252556476, 0.028503117106494405, 0.05117337865334365, 0.04753013644667883, 0.016135161915313334, 0.08367326456092058, 0.10092945634237221, 0.04410538634645843, 0.05168700613261712, 0.04824529867619277, 0.04075127721373593, 0.04479127252594598, 0.06991935097762654, 0.027856868316209125, 0.02791144825037449, 0.02019737760776714, 0.024439664182042884, 0.10004276319617227, 0.07839893306335134, 0.10048604465179867, 0.0422787492824418, 0.03806266866083588, 0.035092254664989254, 0.033204479954175414, 0.015480156740053527, 0.03535057568261701, 0.03536834509202069, 0.011930673161611683, 0.068971018397039, 0.020234525211215503, 0.030575180013153343, 0.03170803827684253, 0.03383844069415524, 0.013329836036709529, 0.03515875492725642, 0.03681689478276718, 0.019523940357049147, 0.019023376592104475, 0.03344330786456985, 0.02794802703353907, 0.05749706674607531, 0.031222746474668387, 0.016382280812268297, 0.0029556129377470504, 0.05612262074024447, 0.011808449578952166, 0.08268993708395189, 0.0199333856242799, 0.0273642948483147, 0.05862475200105579, 0.030615386222639394, 0.07437847299321045, 0.0178706364315604, 0.053658475949158596, 0.05597999049050193, 0.06109663811061652, 0.09468352617395502, 0.030598472916491093, 0.02510185526203244, 0.004795437965977697, 0.05084061304167394, 0.023714424065885045, 0.046987715552771286, 0.008268010626066356, 0.027648277896186037, 0.11483426626411178, 0.02734772436651251, 0.13733740956071885, 0.16699478751228702, 0.14426653694000938, 0.1268038538194472, 0.15318491886700356, 0.194907323607514, 0.33776029043139955, 0.11849500974940678, 0.10691968934430231, 0.13573420203981862, 0.1300717550780504, 0.12275044430768299, 0.17213713738226122, 0.13888506038535026, 0.1559394952510634, 0.23244809870037342, 0.24207669009845106, 0.1357539364647481, 0.126028404300732, 0.09333145759639241, 0.11163214131468728, 0.19959116985480632, 0.20170376455831915, 0.1837983439045568, 0.15365351952852743, 0.13908618910899087, 0.24716136886948542, 0.09527938170058113, 0.0883820929354237, 0.09586746143477579, 0.12126127663519114, 0.10161347326732452, 0.14561799264723255, 0.09992091691181545, 0.18822755784757678, 0.09257588039843306, 0.13205089726515357, 0.1767744208055158, 0.12822372883918787, 0.1519612925908258, 0.133909395925941, 0.20652392849085793, 0.1692437152228048, 0.16303253480263297, 0.15252511798133775, 0.16524850541064817, 0.17854327185740396, 0.11712622513333637, 0.16305369415110157, 0.13746962101469118, 0.07424485959833668, 0.11677683541370977, 0.12812419869606534, 0.11170920209899066, 0.21933071225160555, 0.20032558770429706, 0.14578495384945026, 0.15007310036209323, 0.12895725036580719, 0.15627908670613844, 0.13835705726617767, 0.09482173609637445, 0.09734811020954963, 0.11682484614392442, 0.21986861322675982, 0.1930462049260255, 0.22112315881156155, 0.18292190867566294, 0.14242843153976625, 0.11107428374910548, 0.22169363384525623, 0.1983868949595959, 0.2705975459708322, 0.15365640001912273, 0.22479451261460784, 0.20419647676810143, 0.17833382341890566, 0.10560852220101703, 0.20979028225185412, 0.18141245499493616, 0.2559908233102291, 0.32350685687795766, 0.2031743929030434, 0.34395659342408186, 2.086070655815063, 1.9020591556064546, 0.4594173204273947, 0.2062746128367801, 0.16767386317012772, 0.4016249650909055, 0.28022846627619963, 0.15927931684399807, 0.23632922269884618, 0.16736583453753304, 0.1223380591780428, 0.19746097045079355, 0.1512378297986523, 0.1170711434115806, 0.18544770056201568, 0.07714317705962928, 0.20218822323987562, 0.08071912227258568, 0.137245693514424, 0.21117881661461246, 0.23550678134685565, 0.2285883332332296, 0.20847912276944808, 0.14898782956504053, 0.1441847340714547, 0.18100661225616935, 0.11666472610687056, 0.1850243603750583, 0.14273316599428654, 0.19863662430115286, 0.14718991313730517, 0.19955197679660014, 0.16553799471547528, 0.12833756950473593, 0.08172773831193486, 0.2229604674803634, 0.1432965470538024, 0.21266439899561868, 0.11664535940414476, 0.13830756798626917, 0.20177807508697435, 0.16579950648930766, 0.1589634741145757, 0.15501205388817096, 0.15277008225600566, 0.12743205357823642, 0.12912673965817498, 0.16011620661424053, 0.13068709222059097, 0.19693281411403613, 0.1490577121054934, 0.17669922161486842, 0.10790878546334083, 0.15551975567735013, 0.17426228060597376, 0.11946506092264769, 0.11115648498338078, 0.11356568594853725, 0.11084984296992903, 0.20437891294638957, 0.10812984779477121, 0.09160146252402375, 0.10627515659096742, 0.16147851012647152, 0.1748801764821814, 0.19558046974482077, 0.057666728408226085, 0.1387518223735594, 0.11069919944049851, 0.14151660304877067, 0.18740955980554705, 0.16635824505600239, 0.14726152703646692, 0.15678776908786068, 0.13695557601749897, 0.13497986590429661, 0.10102546248104304, 0.1389681809251347, 0.23420219489883995, 0.15978665091097355, 0.10284631558123136, 0.18037236806365753, 0.08772599225443217, 0.12803153270074438, 0.12966623409621178, 0.2565960174486522, 0.10938204915052462, 0.17751093773591906, 0.13116396663169708, 0.07995531729031956, 0.19889226784148525, 0.15529323879989887], [0.04957197909994472, 0.037627059575771137, 0.051582205304575544, 0.034205959884509925, 0.0032402995894963466, 0.08092658654336007, 0.03909428649011158, 0.09485385050216029, 0.02286431161806949, 0.050205595100358616, 0.0623105886963106, 0.03618378823082294, 0.03318514389496657, 0.05629789016600098, 0.04343964061850021, 0.06312578285653746, 0.01313810433907014, 0.05483516401821568, 0.01791970819355019, 0.029794243389680505, 0.023173682819751483, 0.041268118431851755, 0.04235081134303924, 0.04433836517555099, 0.0504472230621163, 0.05303769575191602, 0.039486864416469494, 0.05346059543831695, 0.014320509339262162, 0.029043546171798825, 0.09448376874769888, 0.07693403505630071, 0.05690193900297727, 0.013560672692443817, 0.03502421073555466, 0.029282379827852693, 0.04994821637087772, 0.04540247662413505, 0.016992330032911514, 0.10111984451331439, 0.04397615497451156, 0.03429327858611941, 0.07532780914897881, 0.04260764615009389, 0.023915073984572967, 0.006882046009489005, 0.05646015141880321, 0.05729322224074314, 0.017381267126409278, 0.03419782403075407, 0.13027227093135157, 0.026209147256468574, 0.007493431095950186, 0.034519217067187837, 0.017079876645678477, 0.07140194561572806, 0.029797518415556803, 0.015828165586196607, 0.05123290368506024, 0.0092490034500858, 0.00863651423940375, 0.0497164058258697, 0.05897901020944119, 0.2016327941730138, 0.01609213267182631, 0.013821188551974634, 0.03936583018531242, 0.037597637969039144, 0.047426565189755736, 0.5759132773645463, 0.9494406501612357, 1.9716922578311737, 3.0381848302579697, 3.577596775947079, 5.355587563207073, 5.695281490202873, 5.6357315759505, 4.150581023385448, 7.607161402702332, 8.284899900036475, 12.864691672786591, 19.482187109608805, 32.74487776141013, 55.275683941379675, 59.446363679824344, 55.7301885850968, 33.08164658084993, 16.30602432835487, 8.60812379467872, 6.842457094500142, 3.194228727971354, 1.4416294040218478, 0.4775848197600534, 0.3955903679372803, 0.19523517859558906, 0.24919481136866156, 0.4996698782328637, 0.7434969719859862, 0.2349356015122706, 0.19791633311298587, 0.039946379275211406, 0.12254196113996929, 0.09593194305536248, 0.0777158737483044, 0.02662452587467288, 0.055373034349852995, 0.04058058899376662, 0.03505206186204188, 0.05266278381309202, 0.0494568973719593, 0.03573091152394491, 0.018720626305308075, 0.008712023695660456, 0.07567795729565044, 0.047910119887561574, 0.049847299608612256, 0.02563067809528401, 0.029040353500374386, 0.03972328298034207, 0.07419805162616315, 0.03451483504426095, 0.06643647012571174, 0.09551933576022426, 0.039289546980252193, 0.031492926533364, 0.05062873993489531, 0.060788448599557725, 0.021549396389614672, 0.029647315386682752, 0.0512811289198937, 0.021513509000801755, 0.021228009098840338, 0.025267205764389327, 0.02751572744830722, 0.01504365324733719, 0.06078059236789423, 0.06607201911749379, 0.01340422796220669, 0.10861927072607702, 0.04920876149328486, 0.03809955196395036, 0.03745539842413799, 0.009393841948270077, 0.06520460840434798, 0.009355342199635363, 0.03951346681964013, 0.06289979457975396, 0.05523861656265874, 0.00659880654570917, 0.034685155542026606, 0.05458468391049293, 0.04137327932121773, 0.04062864951969635, 0.05250356775978881, 0.02467815501375064, 0.061940051119534247, 0.05150763430602608, 0.04458196198327407, 0.020461766041755196, 0.0428342626189753, 0.0732200637820267, 0.029112953737738635, 0.012164944764076462, 0.0511045724664244, 0.062490316753786426, 0.1499540043333846, 0.06304987886499974, 0.02905954400287761, 0.013232152165484526, 0.009348596795462072, 0.05597268201170429, 0.02844118464347576, 0.09085423568443907, 0.00835894909311807, 0.025900003965944055, 0.06089497695586855, 0.011187619585994513, 0.04788909077404007, 0.021645927298513633, 0.02799921511341968, 0.03760745921622842, 0.040707705963042476, 0.0449449421026774, 0.054785307016103506, 0.02234053921945874, 0.012539855745290557, 0.015057704257478398, 0.021133060161505016, 0.07256731856614351, 0.014947861613285159, 0.049287883054104545, 0.053695271152161786, 0.013164858044605824, 0.023479162294778134, 0.03634008548913464, 0.025992036023507678, 0.044959888478080114, 0.009883965850026618, 0.030799366068094972, 0.014506568155822255, 0.01588833604698941, 0.07478554147265612, 0.035143651503829226, 0.006037909526287789, 0.025540273974559484, 0.04766356215001114, 0.023623006793880658, 0.036417674874105764, 0.057415072355539575, 0.022966423477496833, 0.08188156110625114, 0.0217635600992869, 0.07327032681073874, 0.03886502701789141, 0.045424988117790034, 0.06789586762146604, 0.037029104968232494, 0.05760185225235839, 0.04081610357388854, 0.013512420644533011, 0.03252517446995743, 0.08824147749692203, 0.015360673836943124, 0.04810194447336178, 0.03375954129883359, 0.036229297683964816, 0.1134182753101472, 0.012147667566164127, 0.044865115740967375, 0.05054534743389776, 0.059610320285203, 0.06026363623658977, 0.02737456617215949, 0.015279025143583216, 0.007351056528052376, 0.016737659424242955, 0.03255098397212644, 0.006323779544477622, 0.035156422189526984, 0.06803149582758065, 0.05471428300464346, 0.06262486860636743, 0.06371025431660876, 0.046614879712222085, 0.06077491948681493, 0.31321244314312935, 0.6773672204825186, 1.5505270251343328, 2.1826048435703402, 2.8846056519016146, 4.820942523018007, 4.241557948050961, 4.238131267409171, 3.849630552914835, 6.687419039587821, 7.14028658405427, 14.335461835707388, 21.97633601004078, 35.35692330329649, 60.54126585683515, 66.14123375185075, 59.975220772527884, 35.5797335409349, 16.27333921770896, 9.914602541154432, 7.257083000675325, 3.4396308372097635, 1.2126692576754479, 0.25361942878413585, 0.5402596066555669, 0.3946868438393839, 0.3276754170656204, 0.6070086023499889, 0.5145436897873878, 0.3017013592104758, 0.13827701639984885, 0.04912452246513098, 0.04513315841435425, 0.11400054809787583, 0.02360397333940191, 0.020411503013043154, 0.05652543360127076, 0.07842777627370051, 0.09186760146891879, 0.060060312671046105, 0.03320133516324624, 0.1017445126067727, 0.0228634191256377, 0.02451864593181639, 0.03304574270582488, 0.028661457904344125, 0.07603740574972284, 0.013678376356350079, 0.04279421154229392, 0.01671522645460021, 0.012617513120564963, 0.09513700425985361, 0.012100667114399615, 0.05182791268453003, 0.03168022545475153, 0.04173586107490044, 0.09914202765832025, 0.03842582498046179, 0.025073435315261447, 0.0554412774621479, 0.0270909144573154, 0.05729962673579013, 0.06851928699160777, 0.034934337130717696, 0.044010123313074155, 0.04541538520565918, 0.0244620205428932, 0.04565640412751706, 0.01789002803214375, 0.08451387751847507, 0.022378755515561472, 0.06919318389508032, 0.06496668447770419, 0.04053765742648994, 0.08273762605723836, 0.02924699231141037, 0.04979397605864271, 0.06457657718490209, 0.06694967242618723, 0.0484399731090713, 0.03706623341948275, 0.0323433320098106, 0.022214716938774914, 0.030399801419867627, 0.035008628507174795, 0.06724417960691838, 0.01904201742652203, 0.042240012046550555, 0.013130154261635918, 0.02970540208832151, 0.08141176534756538, 0.08180063157793015, 0.0502110151724229, 0.04014957260580794, 0.062029871098216505, 0.02160981199854324, 0.028932618555582823, 0.04185789122035907, 0.0539056197439711, 0.10537984495561932, 0.02646380828903808, 0.020022876185154723, 0.05362802395416845, 0.012623648527228545, 0.07237533693231883, 0.010786231648507378, 0.01643071672128093, 0.09629299263319663, 0.11462906961359325, 0.10211598098037705, 0.08126004929504088, 0.16070063976991564, 0.22011080426314186, 0.16825549244399995, 0.21731577843668, 0.11915726211643028, 0.10521104514238336, 0.11256765724430162, 0.07999922178926007, 0.13495528980368568, 0.17891096341754162, 0.12920428307787066, 0.11151253966794861, 0.18095670928878171, 0.10757505458088652, 0.11084670967031872, 0.13845954450868792, 0.18166253673693827, 0.0973503778298055, 0.09728997179697599, 0.19189616905585413, 0.11680439925722538, 0.20904752936574722, 0.13507913557752488, 0.13537610190049296, 0.10152476028569284, 0.12782927016697584, 0.12913541177347784, 0.19029334457891603, 0.19689115425271375, 0.12179784461735718, 0.16642760665666673, 0.12891373657170804, 0.17560796001024787, 0.10648341759318307, 0.17983964584287138, 0.19788530655205253, 0.18184684216976169, 0.13476666363496936, 0.18476664839733034, 0.1094606344497973, 0.06656328065981788, 0.14389069420435738, 0.13596332361621244, 0.16323078303567826, 0.13232270526068826, 0.18522006519619497, 0.19282931011290322, 0.08673666630901637, 0.08895133456756031, 0.17154697388891252, 0.1503049185679805, 0.15632633900930806, 0.28753191953705204, 0.1136898458184254, 0.19327829892356552, 0.1392504536817151, 0.1723713151389553, 0.10669658921899335, 0.15572436244016694, 0.22409783225626717, 0.11563943999428904, 0.23739123506651771, 0.08017991128708087, 0.2380367867167919, 0.21884164172074488, 0.9911228199639629, 2.274776129953323, 3.922089477700572, 5.585052101842819, 6.886347436135815, 9.737604606536127, 8.96588513928075, 10.415732399109872, 8.252502103005687, 11.620022616078778, 14.59025017676815, 22.31869028460595, 32.31359551029821, 50.41916208882486, 80.4742411644228, 85.99334547596594, 80.59778013537007, 51.84418270664831, 26.308107491462465, 14.390445620782915, 11.242264047745737, 5.2811360743738, 2.9558773242658187, 0.9362467774941076, 1.412520024084276, 0.9149719029664994, 0.49785434178286986, 1.2223342229281704, 1.8436352067416715, 0.9736392226430678, 0.55529227420207, 0.10876065991338223, 0.24948935685378892, 0.23997230785748652, 0.17178358780520578, 0.1380057906311366, 0.1062890610867931, 0.15576793752130003, 0.14982450483066423, 0.26642837291282995, 0.15780003170572943, 0.21440257588701866, 0.10184565919541544, 0.07858473236762709, 0.21280166662989125, 0.14036406973196616, 0.15756606845365417, 0.12002718559796773, 0.16845314312846432, 0.08657748089923013, 0.15702427575184455, 0.14788990299547874, 0.10465809820039619, 0.22596682632161727, 0.11992100581166246, 0.10414782235579145, 0.18560787422522423, 0.16107904123923472, 0.13292137232999648, 0.15588108870771625, 0.18333407930068432, 0.22273244907058057, 0.11023283575571353, 0.1079867042661194, 0.13733871191019012, 0.14135354889496682, 0.12027217285527338, 0.20639746269631773, 0.10596277657896282, 0.20650925024622874, 0.12012056405505828, 0.15498954622495562, 0.18155513120995415, 0.1327028993757502, 0.21104639065602135, 0.20182839174184108, 0.06905642953971702, 0.1397460512816906, 0.1375168579961023, 0.12104509428383843, 0.17821137192508868, 0.14741811540818986, 0.12117244107949159, 0.17835590207288343, 0.14734233399072003, 0.17347043680567897, 0.0931279463393073, 0.13283252145253843, 0.13466917128572542, 0.11027076476884466, 0.20697216653535444, 0.15017270711400818, 0.1526424826513375, 0.1459437485543951, 0.13121918624927922, 0.17752316449919056, 0.18836289494028016, 0.15579317245752583, 0.19339331936451698, 0.20031581242238322, 0.17203886362333454, 0.10237425220228973, 0.06827154947865395, 0.13875666404924086, 0.18538717961599752, 0.10106163715282757, 0.25655104808749696], [0.04303371744050134, 0.03476644130123239, 0.022235742221856793, 0.08652606107775243, 0.038720175113168456, 0.055777758600250374, 0.056249320191601594, 0.042640174243358836, 0.03184101390351932, 0.057846368365590616, 0.004401858858463745, 0.0344782083806011, 0.012555046311219134, 0.027084592316720276, 0.037424149697706584, 0.012096022706358664, 0.030835330065700318, 0.058257688633016044, 0.044667928539697206, 0.030193478620100408, 0.037740275879660924, 0.010091264454287388, 0.06074969987234762, 0.0821683767642225, 0.029955547032577377, 0.0385398495071117, 0.018563875139901237, 0.017834967377805905, 0.003938381888738443, 0.014227517756573377, 0.04853457347640107, 0.04516905346404641, 0.03793614924014096, 0.07841168842729061, 0.03334348277759648, 0.06399491343707328, 0.04788487346001691, 0.12220023996046475, 0.08375828499875723, 0.02829933963385561, 0.06222052356949257, 0.020635451580728256, 0.009887313654255724, 0.03889930945250296, 0.0850400113831124, 0.04468026638571774, 0.09275306121356065, 0.06575258343570656, 0.027793204494481607, 0.046090381445303086, 0.04418075024600952, 0.0567144887792247, 0.09968520697927284, 0.0731791700086286, 0.0729958298465898, 0.023801696802219077, 0.058047389836921814, 0.028680137043157895, 0.11396699344679234, 0.028653036682836475, 0.01899328657365855, 0.06762060456939283, 0.14421853387067396, 0.05873209241056635, 0.44762744177733704, 2.939838017186811, 8.287177816514047, 18.685177180074877, 38.734546861340924, 38.660574882261216, 51.52419182562059, 54.8127148228307, 61.23384660290134, 57.700116634368904, 60.19048436995476, 65.28169339702976, 76.12668606542772, 72.77207897555444, 84.5653909252536, 91.88142714961883, 97.89558949009066, 100.93046065299743, 115.05831241607667, 116.26386073327835, 119.65069401648738, 123.71853705375426, 107.85112980873355, 108.19992265393658, 102.17200848364062, 89.66812779826503, 79.64043940267256, 73.08782977442588, 62.82905494013141, 66.49274872195336, 66.36239267164662, 67.18722789518296, 63.511786614694905, 69.10740852355957, 54.57758442048104, 31.30522081928869, 16.389112876307582, 4.4425607881238385, 0.7295684516429902, 0.7460154400717828, 0.23988380938047366, 0.12892035557137382, 0.07174134554882204, 0.027133698552666653, 0.044764156843866074, 0.04756620386615396, 0.057332947730056705, 0.025246111533394264, 0.09921990049582335, 0.02137872732184347, 0.027339337618961453, 0.042701572360050295, 0.09590293896654922, 0.020938854957480105, 0.056389950951861764, 0.032100482137813684, 0.03816492224652921, 0.02748379307318359, 0.06808647029702702, 0.06308257549760804, 0.03003850669389771, 0.060151676316895795, 0.05228860731867533, 0.02603593669200857, 0.02183074984068592, 0.06127735825195428, 0.009975280657771134, 0.05732082821909459, 0.059379609076366316, 0.0669202623107741, 0.04888474077527081, 0.05502415790913567, 0.041114521633473136, 0.01968829494510447, 0.010626118314722854, 0.033634186331783576, 0.04465330009078307, 0.0524550820550611, 0.0712580589817897, 0.033568249144140756, 0.013513548709001514, 0.016757052940046115, 0.01692919672707156, 0.030420920548720226, 0.027321974236157634, 0.025782003442967133, 0.05863341262503978, 0.08578642616949736, 0.02698905349168326, 0.01078014316472916, 0.05774315716999193, 0.029901689136280652, 0.11912725445243622, 0.06163205313045652, 0.05237815150570485, 0.04631931149971582, 0.020940733788114403, 0.0299124545868366, 0.04081641383949788, 0.030612419547152617, 0.05080017892103042, 0.09680378941758987, 0.02339379520215575, 0.04117527240586858, 0.03110651178435693, 0.02572911847833424, 0.051676518388933716, 0.038159000386874524, 0.03510306416560085, 0.030115025470994657, 0.06202686420311371, 0.022215230217684182, 0.027758636692118262, 0.01499968363092311, 0.1494227989666885, 0.04735209761307605, 0.04897440753636822, 0.03567342811654653, 0.08201423987385728, 0.024505245138800914, 0.03009402891620994, 0.05006490688350412, 0.06952845461426244, 0.04327829101032788, 0.015049825043177173, 0.03862377443921663, 0.05903964606864799, 0.009310830576014856, 0.054567485236592835, 0.051775795723041224, 0.06478152868728485, 0.09179879145155992, 0.031027221684193904, 0.02626294578095117, 0.12747320016064953, 0.05585688016107006, 0.013520205055453606, 0.03007994247450223, 0.01440508257327301, 0.039580196908284584, 0.08170912237537485, 0.059482820271965, 0.04967739662876533, 0.07520243119929107, 0.034161584241495985, 0.05135727422912756, 0.054921674497065046, 0.010780869990647321, 0.03707351508520303, 0.03577453640079306, 0.04446563153197208, 0.0571757005227189, 0.042867434226096644, 0.03660443178828686, 0.021381797419200023, 0.01737698852535217, 0.09633931030909862, 0.028485439627641634, 0.04475114101003255, 0.017480454445185683, 0.0763343490900532, 0.014175080953376188, 0.04113050605801325, 0.07472253074088404, 0.08348194942359002, 0.05882288149047283, 0.02616130889603688, 0.011852264062561577, 0.044180478284796404, 0.029611054530006745, 0.027740250581935532, 0.05802143477804719, 0.11442031831510606, 0.06618136284692634, 0.12986630561851686, 0.13344575951416648, 0.174534609541297, 2.4673243011197736, 7.132826235986526, 16.917559100735573, 37.85671649440643, 39.7114602211983, 51.150966536614206, 54.96925661640783, 63.110779177758005, 60.896538457562855, 65.5310502359944, 71.25794995215632, 82.04256165412166, 82.85606122786, 98.03847359072779, 108.32674857108825, 115.34484155716436, 118.85242892849831, 136.4920336200345, 138.21541324738536, 140.5366248469199, 143.276180759553, 125.11840743403282, 123.10145408876481, 116.33386719611384, 104.24862107922955, 94.95578089068013, 85.12116724444975, 73.72273598947834, 77.3127794265747, 77.75724672502088, 79.0218267133159, 72.63735340487573, 77.30453460447251, 60.4810300180989, 33.65217493426415, 16.76690870715726, 3.7497657825869903, 0.7174073880718601, 0.6627518563501297, 0.1755309222085822, 0.0835131751673837, 0.024787228697189884, 0.014221752944943166, 0.06686678937365932, 0.039254015822324066, 0.0879903921797391, 0.03981737772964182, 0.0459285223886611, 0.0538199289792007, 0.021141841444337083, 0.04092955736503486, 0.02283541861200525, 0.02876621276711024, 0.029809356389206745, 0.059440578183820175, 0.03734490173237939, 0.014630615985351465, 0.031877437553879236, 0.0708968561863707, 0.02264410922033412, 0.04571751113079729, 0.0748171809039289, 0.041887826106000337, 0.03277000467923861, 0.041301726709089936, 0.05892888507655552, 0.049614217357649926, 0.0494676877203728, 0.07534927493261714, 0.0187258567706111, 0.04545355936692608, 0.06974037751675614, 0.029571252431900754, 0.009898919886308572, 0.0209128309506923, 0.05281477565726927, 0.08671051972816068, 0.06651250435219658, 0.00984347714561849, 0.03804666891453728, 0.052379189554842255, 0.04995181315368222, 0.05012927359090217, 0.028518676352236542, 0.05104310157138014, 0.052486411220724546, 0.11954310996037339, 0.02791186002263379, 0.02096057546535327, 0.010974672998511984, 0.07910369564929316, 0.09353774209176341, 0.05967480956666893, 0.032989768491637324, 0.05542639237377913, 0.045168804485471024, 0.05786836658033633, 0.04880263147154643, 0.028626526210216746, 0.09859592188149692, 0.020653098416064056, 0.05513695669510672, 0.05930553603496763, 0.053453593394689025, 0.04506029962231556, 0.06823550504181655, 0.034056664669826146, 0.03768760733486664, 0.03246980929566968, 0.06633217491570019, 0.015497380311811164, 0.07955556495055076, 0.10811231970306366, 0.4009495819768598, 0.19098958060626062, 0.13214725580426956, 0.2036679986744158, 0.33534836985411187, 0.15413122131459175, 0.151797640888441, 0.27204079433314265, 0.2737046453741289, 0.12205786251973723, 0.15054036803062887, 0.11800475944314273, 0.13781206231684456, 0.17491354727216307, 0.127561874837885, 0.19748591427360812, 0.14455596495780254, 0.22282847053100988, 0.14115605142808732, 0.10004941283935502, 0.2171650276549401, 0.16692766288836158, 0.1347228434057005, 0.14489753291972224, 0.10559559063685518, 0.1263740555112881, 0.16593035430677477, 0.1459938047393676, 0.21029488904581917, 0.1597959665401328, 0.0922385412418554, 0.13937390108983364, 0.10526277905991001, 0.11482268301469666, 0.1320987777604211, 0.18295881879185477, 0.15994936798609075, 0.23413960551542623, 0.16526333687286224, 0.26572620736495145, 0.09848608019491358, 0.1085952308870131, 0.23294676065204606, 0.06645991241619473, 0.25918556317206354, 0.1505500207384748, 0.061477433604699, 0.09040269580098892, 0.17874539649534613, 0.21379640115605247, 0.1537797095314149, 0.14532974440484278, 0.1673824892890069, 0.1269304804924515, 0.24763232908181607, 0.11060578267901175, 0.2254302583394512, 0.12668403000721049, 0.13176853257802226, 0.2107100014484698, 0.3644044300721538, 0.20198707919447653, 0.8894713487355941, 6.7779929407181285, 15.498537748090683, 31.56899432982168, 58.90619839391401, 61.34159411153486, 74.54860671874016, 78.9958292438138, 87.4111097089706, 86.63702211072369, 90.27746015979399, 93.81253550129553, 107.08171767573204, 107.67716484685099, 120.14245725447132, 130.62153985423427, 138.24208536455708, 140.2381952347294, 155.30254425541048, 153.57436364696872, 156.03260717084333, 161.38261025951755, 145.60445262539773, 143.67508580607753, 137.91409677074802, 128.64039774863951, 119.96051419165828, 107.94948716317455, 92.6628888037897, 97.99124040911275, 97.81589477292954, 99.6039778186429, 92.27733550533172, 99.21115244588545, 83.68621518535, 51.368026579580004, 27.823436760133315, 7.488999020668769, 2.3418185066792274, 1.9254665124800898, 0.577490376608987, 0.2523574981117441, 0.13199949276543435, 0.11664491507314867, 0.141065867557641, 0.111895430412504, 0.1665716005429145, 0.1168556965046352, 0.21318106401351192, 0.18752314000120088, 0.11926740257730407, 0.12965518710834364, 0.1495210727256152, 0.22292842968336998, 0.13242877779468415, 0.13665335433137032, 0.17075733642183966, 0.10235895342644184, 0.10306317975083668, 0.16154451626202754, 0.14114033130388107, 0.25656762623017837, 0.2502195612196961, 0.15300850413980024, 0.16449499665008438, 0.16859064058911416, 0.13474440111988975, 0.1443866901700535, 0.13837924317246483, 0.1143439393490553, 0.14731806432527883, 0.18324522842322627, 0.1393203975092019, 0.085669421560822, 0.05566461124427377, 0.1500490758447878, 0.16485948596269856, 0.2791852996714654, 0.15578800902491616, 0.08660148243389784, 0.13507260850841, 0.17151669809414496, 0.2505340556343717, 0.12776614452201512, 0.20650871398468174, 0.21366524690341568, 0.14986674691880905, 0.224448302159867, 0.10021650427651983, 0.15045087363931442, 0.16818950163020244, 0.18694345659065634, 0.2540142092132761, 0.10334578958610374, 0.14289721606239197, 0.16418624789484088, 0.11426251952446277, 0.1952947955578566, 0.16656013986756726, 0.08037599915217969, 0.17984681642584263, 0.20713088463150686, 0.20545875984093837, 0.17455952272059458, 0.13962145474168564, 0.11144179144814131, 0.15647166588854405, 0.13204944169809743, 0.18656173029974585, 0.08446254196666902, 0.10839631615747368, 0.13266833348860665], [0.02804357351945533, 0.0381611799070191, 0.03764011754444049, 0.05901296705668492, 0.045512770302593715, 0.05766299756003484, 0.05261662701565412, 0.053717315332182956, 0.0287493109522808, 0.026926795441296794, 0.05838607730824621, 0.03914963251220123, 0.011943664097587669, 0.020932494512488766, 0.04941242979839445, 0.030457512738423485, 0.02704707124540883, 0.02703385239827537, 0.01999213882241278, 0.04709839610563171, 0.038915722886280674, 0.003543725470080972, 0.06145945735155575, 0.10212653767197363, 0.06681366883698972, 0.0452757541901402, 0.03507696738046023, 0.03871249508172755, 0.030326921560411012, 0.04099305073219923, 0.012309644408824464, 0.07555753593483279, 0.059562183150480834, 0.027174919828652378, 0.04231084453602953, 0.060899393452752026, 0.02033146023149452, 0.017258047629448197, 0.08019254407695225, 0.07922000311795743, 0.056718763549842184, 0.05504871102710886, 0.04029294596083703, 0.03573343578365541, 0.05704026766902497, 0.012339287223444592, 0.006910623004284478, 0.010400412532861435, 0.08748463625388761, 0.08541047618153595, 0.04876617334722992, 0.036218744822807854, 0.023622324975628047, 0.03368587428403478, 0.014393499323857889, 0.14677149123482167, 0.0985438202417666, 0.004668258273253037, 0.06608223106952445, 0.0797588846856548, 0.057084145354888136, 0.7685617141185269, 6.613029328084762, 23.353944978406354, 56.1190523639802, 67.97240795627718, 87.22942552258893, 96.114943258224, 87.31764747250466, 98.47785749743062, 98.38502284019225, 93.58945462011522, 98.25772623861991, 107.72723782447078, 102.41445802873181, 102.62227304520147, 89.94172880726477, 99.30851351830268, 96.38957977294923, 90.62695903162803, 95.65349994167205, 92.0638644310736, 85.63700599055137, 77.1060940527147, 73.35377431684925, 95.94202164680728, 93.94357404401227, 102.37173557281496, 107.37565225170506, 109.27832341963246, 114.839138215588, 122.92322158813478, 118.54547208355321, 100.56910837850263, 103.5901100404801, 108.53333196332379, 115.29247791536393, 106.85324745793497, 119.92922936716388, 104.09316970456032, 91.02738595777943, 85.08839976403021, 69.16244722181752, 55.558863378340206, 40.958620963558076, 28.15610278037287, 8.190370778883658, 1.824564888112007, 0.13132049371638607, 0.030744824438325824, 0.06852981303968737, 0.016060884903004814, 0.01951867541778953, 0.025426709100664146, 0.02148134862974046, 0.012848707922403852, 0.01658662710519087, 0.06834470321454349, 0.018878084186825062, 0.0533248714712118, 0.10672514897681053, 0.02172400889497611, 0.04442715476597509, 0.0370341879616101, 0.02645892064808117, 0.01253463389847668, 0.017616758723893476, 0.05840343303017079, 0.05880121652397418, 0.11190047127104576, 0.029590559762812434, 0.00881399957448124, 0.03296987318824376, 0.023006637347862128, 0.01915198360239306, 0.056996091208871336, 0.030122694011116703, 0.06110429898985933, 0.01248858243812837, 0.030876572409103957, 0.0843343907786954, 0.0610899769761149, 0.01849827886138472, 0.03202434257423926, 0.04473349034425713, 0.037145381793379784, 0.033785557644742156, 0.04447172576140973, 0.05529352208419193, 0.08350332327667745, 0.05420279674111836, 0.0333367565256213, 0.043625355653104284, 0.06131470886870258, 0.05948915198865918, 0.009956119841174975, 0.05852407272604685, 0.02077200866845106, 0.07296331707508334, 0.0474429173364995, 0.013588808229072921, 0.027202912681405584, 0.050391769787717255, 0.0305317715561438, 0.05568301650665461, 0.07370867466013278, 0.03719423138987153, 0.0303147848124706, 0.02185022762616075, 0.02571040103512426, 0.037572207680392655, 0.03583136097257657, 0.09857854700737423, 0.0804009123314773, 0.01843834588784845, 0.024465050420633728, 0.0292168410059305, 0.0363731881483428, 0.03883588120281216, 0.09053630919586267, 0.06189389432209635, 0.06310194986121309, 0.03203654635487305, 0.07436410118375095, 0.012641801938204276, 0.03184090856642973, 0.06445784121751785, 0.02770429999086886, 0.014162734488866503, 0.027121944848688382, 0.04824039571347737, 0.025646434608666648, 0.10270109595430475, 0.01257621619339672, 0.053131756027259176, 0.02191837689268493, 0.04534589720048732, 0.05944618211698629, 0.027810918362510782, 0.09418352356841488, 0.0034368133516005815, 0.02887041987701049, 0.03680552220753124, 0.07313100606082909, 0.06922971096731002, 0.019968604601378885, 0.03953271094829806, 0.0833871077385641, 0.08195207949968115, 0.03179845771932554, 0.014762231805962662, 0.0916886663124446, 0.015963606100769776, 0.10011633828042016, 0.05103239549263831, 0.061306335527690194, 0.07852210467981716, 0.0032681672347544305, 0.06090271061346416, 0.05287297535687686, 0.023870198469188426, 0.0276713582101248, 0.024779368635086764, 0.03414932300426787, 0.05738597250573578, 0.07875456639956083, 0.051662560266953324, 0.07381153728572593, 0.01593982290116049, 0.019763032567777464, 0.06110709521078295, 0.09816816902809566, 0.0678029717997678, 0.03961458276476591, 0.061381216791848985, 0.027413985226303342, 0.026321714300842538, 0.2784128378956549, 5.3909810704569665, 22.065795467745875, 55.483742144800004, 73.31781402710946, 96.65543017848846, 107.37897057687084, 106.02620786236179, 112.37342649890532, 112.13674283796742, 111.27028342216246, 115.69264596508397, 126.6906189149426, 117.19749466065439, 116.21191286271619, 110.02383262880387, 111.63322033420687, 114.98887861928633, 110.17195701599123, 112.78081955448275, 112.3049811393984, 106.01474669671829, 102.10753256274809, 97.76248778066328, 113.10652532885152, 111.69719419171734, 120.51321537263932, 129.65686428931454, 130.36003543484597, 132.2601256832, 137.8501307579779, 137.56944594844697, 122.4068807786511, 124.65859582347255, 129.03530982232863, 134.7218679612683, 125.75578474229383, 134.9506990371212, 117.96422389245804, 106.84208439242457, 97.74118146588727, 78.62033290247764, 61.23533318119665, 43.27211333859352, 28.367671505097423, 8.030382692813873, 1.9311717224697915, 0.05273328305432393, 0.05154697675137751, 0.04621293636098985, 0.006549825756660393, 0.042913552719138326, 0.08716936809040847, 0.020416578345541513, 0.04161658501552959, 0.047080963774914705, 0.03704847933183755, 0.041721489265440934, 0.03047804197957439, 0.022745514363651315, 0.14781320227249978, 0.0667110436986531, 0.02715845468393978, 0.03294125597383226, 0.05787736045256738, 0.05045832367613912, 0.03459258147725656, 0.0749540578333601, 0.06602866620185875, 0.038975853127457445, 0.040977127594693054, 0.016292005011271087, 0.05046640590374028, 0.02060787433067397, 0.030582584252941514, 0.01852927860924073, 0.03797437702756255, 0.050124604285003684, 0.040422135197948066, 0.050347118353050564, 0.013698624060188812, 0.0677768252189121, 0.04994858409308138, 0.03941455337729666, 0.09735641460264884, 0.0626303231523883, 0.04224015377281655, 0.06863639885259253, 0.026497119707205606, 0.027830968798709013, 0.03785190255110783, 0.026398267551896074, 0.06353781558573246, 0.01650145728020899, 0.06562843888757691, 0.016002782879607574, 0.016692781993638606, 0.05201169334712529, 0.013349463209329594, 0.029170854663055752, 0.053238744036324566, 0.0611293155910267, 0.00487193136641215, 0.05308363038385588, 0.01202702787028806, 0.021386219661742933, 0.03728434248196502, 0.019177856306815823, 0.04269314156244359, 0.03254603887457521, 0.06305395828319654, 0.0786365275721877, 0.0719615651835357, 0.017450174819978497, 0.04672667109257272, 0.1571774320496667, 0.1649263194732128, 0.22498359843607874, 0.22527552390050506, 0.17426047263847244, 0.22602722469356754, 0.10031424943477878, 0.1870714698828036, 0.05729144874719843, 0.1439377166811497, 0.150163835815845, 0.07068512480585806, 0.1253108480464547, 0.1676408907458667, 0.15345341736270537, 0.10040198948474661, 0.19650325329313356, 0.10954479686915876, 0.11877307668328287, 0.15233453062753524, 0.1605660994086535, 0.1679846956845253, 0.10163737521056207, 0.26741383777510735, 0.1400765416122252, 0.10287989321495257, 0.15681122670010214, 0.12673651469090294, 0.2005073650469703, 0.1593726569966924, 0.16953717286307968, 0.2667286487356309, 0.17081304633569333, 0.07633112385989198, 0.11408879376587369, 0.17726490093815714, 0.11829119205715195, 0.18275215891340088, 0.2364105659146463, 0.11891166964966444, 0.1332660199653718, 0.21699987442022373, 0.18257206696416103, 0.1359730222893338, 0.2216838738851009, 0.05457121608478408, 0.0864009895632344, 0.09889753069728614, 0.22915033533448176, 0.2089108592800556, 0.16679791823750542, 0.13774132175791648, 0.1379579867446615, 0.17431936947809112, 0.21278861249166153, 0.2708680362951371, 0.23461900801668245, 0.1331877564230273, 0.15562159940600395, 0.21003256521878705, 0.17108152950963668, 1.1930159767789226, 10.24754704967622, 35.74748939083469, 75.0092577165173, 98.83778987392303, 120.61766809032811, 126.57607786117063, 122.40080110488401, 130.1156090151879, 128.3691893854449, 123.03220856574275, 128.29042819238478, 139.16200668581072, 131.39797302984422, 130.05748733397454, 123.30367580536874, 134.0684638484832, 128.82475699147872, 120.30678887521069, 127.33141652999387, 120.85130799201228, 112.78500864582678, 105.5082824153285, 100.60510789194416, 125.73757709995394, 125.8022334498744, 133.29335643399148, 139.21367214572047, 140.5282780431932, 145.77165542110322, 156.49456824025802, 151.95921005741243, 133.51768462888657, 139.63397764390515, 141.85840083706765, 149.18775743053806, 137.2636893487746, 152.15175136443108, 140.04204534715223, 126.74351599908645, 119.83531213575795, 97.33975041297175, 80.99407288335985, 63.803987503051765, 41.94499508027108, 14.783261187614935, 4.09039102735058, 0.2280341452288051, 0.18788795107074324, 0.1679824280642694, 0.12249512252427879, 0.1993515375520914, 0.21444014483882537, 0.16158125783887603, 0.10895364512238773, 0.14093071432603946, 0.19832064367590413, 0.11269469760478505, 0.19857161407989843, 0.22249730604310192, 0.25798286641797713, 0.17632740850169815, 0.21361768816507634, 0.17755403784253906, 0.1139912018251996, 0.12696619551148147, 0.16438578315559896, 0.2032829935271894, 0.20989024140421422, 0.09933895055925655, 0.11941794651530444, 0.1280800567098683, 0.16737849031004215, 0.10449407877580774, 0.09789564857079137, 0.09682389922560224, 0.19725857002119865, 0.11397527485725381, 0.11081198290471109, 0.2708840015674791, 0.11778028035957007, 0.1569636322317585, 0.14167366639500664, 0.11814882993818292, 0.11857791578457241, 0.07869286567813928, 0.16923344964461942, 0.1545565226866353, 0.16246593617383512, 0.10719039417322605, 0.23583607658022837, 0.17168739780543313, 0.1454614349190266, 0.11225126293157378, 0.22809054462179063, 0.3773712649220421, 0.11131810655276622, 0.1575999142181489, 0.15676426551034375, 0.19898375406140284, 0.10780197748493765, 0.15582550136793047, 0.055933128892173695, 0.18903663862616787, 0.10708603767618056, 0.14924672131817188, 0.10611473777962309, 0.13426352772981892, 0.16271791781388945, 0.13005683168528542, 0.12734750811491283, 0.22419412950834922, 0.14801934121116517, 0.08572339245508756, 0.12561732918144236], [0.01892102533020079, 0.1004852096159612, 0.023670065659849394, 0.0754781462432396, 0.029214153952536084, 0.034202217544999816, 0.05272947176690063, 0.04245258995421952, 0.06089771188975823, 0.05382348745760899, 0.07187530368326173, 0.06594070398639287, 0.0843671793418546, 0.017879348766479283, 0.020840523741959084, 0.02783575876345558, 0.08260320060916486, 0.028938986661453402, 0.014987620618945409, 0.01736217813055602, 0.06368526452851873, 0.006335441317904982, 0.021252550725494663, 0.011879424752307036, 0.04945291754519267, 0.04603614242026403, 0.03275348782359112, 0.034595366206861315, 0.02505942739756598, 0.02720634858574598, 0.10305727321294048, 0.048670852857251326, 0.0319090559177341, 0.03412702218479207, 0.0443670743205134, 0.06317200860188854, 0.01263712592903645, 0.09602469332035511, 0.017668620961147453, 0.04718936138576077, 0.032103789722426765, 0.06071795701920506, 0.03041396447036776, 0.04145139730685661, 0.06842560976022674, 0.016515685448182688, 0.03438017593937055, 0.00786039583016968, 0.03122015901270413, 0.01129971165585542, 0.07270274758939782, 0.03916848593601777, 0.03176195362973357, 0.030649616946316058, 0.07366414196909436, 0.004062714607214495, 0.06715254016941594, 0.0054124844421993105, 0.05548008364595233, 0.9771946060561365, 11.026256180578663, 47.682504807749105, 69.09186809293686, 77.29860398077196, 82.76892969685217, 85.62410923742479, 87.08908311782345, 88.14594222653298, 84.73522170897454, 60.09251140779065, 74.9893948339647, 59.688734777512096, 65.2957982401694, 43.5024506045926, 72.30890197138633, 79.2677200994184, 49.57944931522493, 77.34843377144107, 52.68211472419001, 58.20580428646457, 48.576032500113214, 46.284121005765854, 42.84322961684197, 37.795307866988644, 34.18566826851138, 55.51790598900088, 50.09414665160641, 59.00090402172458, 65.79888143847066, 67.63549989269626, 73.55787092639555, 98.58790351498513, 81.1297005991782, 75.33467323549333, 85.24902082258656, 81.76647386243268, 77.27093558157645, 80.91360938164496, 101.80837338970554, 102.80533006114345, 96.96896091584237, 100.69350242614748, 115.43740949323102, 113.08306171048073, 105.08708261674451, 101.48914737086143, 81.06724862129458, 68.68423185040875, 38.809726930433705, 15.227288200009255, 2.155358099168347, 0.0902583341925375, 0.042505741134406104, 0.05015949575951503, 0.026796577731147412, 0.045238591264933355, 0.02079128727106558, 0.024146769616392352, 0.027153917528208227, 0.038290108674235886, 0.04891279491505796, 0.07032432803703893, 0.0739401251438164, 0.030311948371930953, 0.028051925793049798, 0.006644572159500733, 0.015362068116965314, 0.017283970129586036, 0.026689524604608456, 0.02605586838457854, 0.034116710641331253, 0.019727304142208833, 0.02901310183768792, 0.039770910666594585, 0.094540880602454, 0.04088178795251635, 0.06257553637448339, 0.0603915537677465, 0.003638207811989912, 0.041470691231229616, 0.044594269185777635, 0.01459755163053952, 0.0978786873841478, 0.05683169640119999, 0.04430579111701058, 0.04009227305951138, 0.04444271401171723, 0.07890550104240257, 0.023043424889986074, 0.03678481868137756, 0.027683119574982314, 0.055866341346934925, 0.02721679994025298, 0.03343003922172132, 0.0326401949109089, 0.08352490397350443, 0.018441350867731438, 0.03527088338629373, 0.005746152601204813, 0.0072368615468393176, 0.017647714421693838, 0.06463033357454885, 0.03708654624079505, 0.02443888085714031, 0.04886796344972907, 0.04800411121499154, 0.031629927952082894, 0.07686712493699405, 0.02017986100737847, 0.0639353730835982, 0.05998181547188471, 0.05968398730000181, 0.02274940609030666, 0.007534132389757302, 0.06281570876918494, 0.06551878872297465, 0.00781302526217675, 0.092203569328112, 0.07793337377088685, 0.061042402916017084, 0.018214065987136097, 0.03998178785907165, 0.07966533002834167, 0.025661716147536234, 0.12406069980633837, 0.035282646666371056, 0.027220044322612307, 0.07128092670632948, 0.09256157753688675, 0.12064588586649588, 0.04327278283815231, 0.05906860036174617, 0.06412574976322151, 0.018704618898130233, 0.02176402166726128, 0.10329729622049678, 0.03840063600951145, 0.05072751165097279, 0.03044383998419489, 0.024698303126159216, 0.03806982775248828, 0.06466876054483076, 0.025960350626959436, 0.017299560018845143, 0.07324139933071791, 0.010650081544994347, 0.07851607556785307, 0.11045166877128425, 0.08897596429432593, 0.12516377448675134, 0.06173258301832023, 0.04798973940553204, 0.05383778265827606, 0.03539485939508004, 0.010914849192504922, 0.032869676548627116, 0.055844714684832486, 0.01695754581070956, 0.1522058431780146, 0.05812099556468668, 0.04901561923625489, 0.07136642211867918, 0.026271388069876743, 0.032930028955301935, 0.047709554238545324, 0.016919084366471056, 0.06293913319466576, 0.037087300837400465, 0.1800085988736922, 0.03183195108337508, 0.014259823684340284, 0.03691407686640178, 0.09676738491942806, 0.026305519202123248, 0.034709758455714876, 1.1470416308410707, 11.048957878543485, 50.609899105564246, 77.61301332904448, 91.27200065120574, 97.86457138676798, 102.56155475493401, 100.46648348531416, 103.92289177063974, 93.82249832153322, 85.53127458018642, 97.5601327034735, 74.65353796558996, 83.1409429734753, 69.4529301120389, 91.4559127438453, 98.76438663851832, 82.69503224280574, 101.16410839942195, 84.12329273839151, 94.8153757279919, 85.09203187880978, 84.92590381253152, 76.92316255261822, 71.5669934980331, 68.0520320707752, 97.90417163602768, 84.53680469143777, 94.16292082878851, 105.19801508995795, 107.21647462537213, 109.7085838933145, 128.8434196287586, 114.79805531040316, 108.95635958640807, 113.17782617384388, 104.66097985544513, 100.3027323753603, 110.0427149188134, 112.52791297051215, 116.1274250092045, 114.02785085862683, 118.13718472757648, 128.94838225456976, 126.70670847738944, 124.52543135612243, 118.72172770961639, 94.42409576908236, 76.81397161176129, 42.67325370542465, 17.014169039264804, 3.0404218069968687, 0.05171216829049011, 0.07945130038405619, 0.10122892011197344, 0.039903926512887405, 0.06917689686581012, 0.026409682261967854, 0.0491324553055869, 0.028361134201047883, 0.03209402018617238, 0.0803664077313677, 0.08435212571414248, 0.027953862708302277, 0.023819244046124722, 0.06555712376270564, 0.041502185105796785, 0.027797406486746286, 0.03840402211813677, 0.017416924688844912, 0.040053244710208914, 0.01313481686426507, 0.04842087836755861, 0.03767757158305857, 0.009127656080489679, 0.010542027716104303, 0.09037481020054511, 0.02297621408116914, 0.018847009745396433, 0.0025933974698531415, 0.0441286294540811, 0.02413280766397234, 0.05127952779613195, 0.07187289816717948, 0.010547901695263723, 0.04922631639806975, 0.04272244825598694, 0.034150908806271134, 0.052074010769325885, 0.037270476290535544, 0.07771344524958441, 0.049098287784163995, 0.013894335584594839, 0.01624610868372744, 0.019760387649218884, 0.06663654164801683, 0.04530353636871423, 0.06837662609834826, 0.017493705851055922, 0.007980449947588628, 0.009265180354216888, 0.03942307227501466, 0.021294239315114195, 0.015183767855858371, 0.03569684359395216, 0.0633239659721092, 0.22577579463681868, 0.05988014794345345, 0.03189954110571454, 0.045508487871096986, 0.023604321909407457, 0.017360362502175476, 0.02147954640789859, 0.014131595887574218, 0.07157586289629822, 0.05516511808720328, 0.05410311721085061, 0.10581812385710017, 0.14543384043199403, 0.10570330259900902, 0.1659829385818974, 0.09384503527995079, 0.1632786482091873, 0.1516062108379218, 0.11954156246276633, 0.1818419238852878, 0.15358437243248188, 0.15104388697974144, 0.1614017634382171, 0.14883727796616095, 0.19163030590261185, 0.12219380482190079, 0.0935875837721171, 0.1860396413793487, 0.10621971480788724, 0.1230229494432288, 0.18756501436714204, 0.15343464820856048, 0.09792793151592055, 0.0951413173348673, 0.10073089401327795, 0.20778763648723403, 0.18873711356953268, 0.2623183418425822, 0.23711063238161229, 0.11651613569307713, 0.11735102597383723, 0.26294460339892295, 0.258996645889936, 0.1833230169910577, 0.16003676329649266, 0.24173165941911362, 0.19911993385082294, 0.09725951980198584, 0.2795528993010521, 0.1494123954926768, 0.1437218024605705, 0.14314765020483924, 0.09438562522371931, 0.2363781910389662, 0.28671628104582914, 0.2068893830742567, 0.11564286440731057, 0.17474502325057986, 0.16271954192028892, 0.16047634454744478, 0.10590968668581018, 0.14817402968483587, 0.07722746971393786, 0.36394155974830356, 0.15163763576457578, 0.1876281093685858, 0.13279270020223435, 0.29686363654271253, 0.23122664811390065, 0.1304839257030718, 2.7479534620238892, 21.099666664677283, 68.9503489771197, 97.16383995548372, 106.35187441302885, 107.72473535230084, 111.70833372300672, 110.30796912408645, 112.26914636550411, 112.06351218685028, 85.33784681750883, 102.15263197498938, 84.11675806968444, 90.66845770805114, 66.09134904799923, 99.85165980554397, 105.56648254394533, 74.15983707674089, 108.77380463384814, 77.94384956359863, 81.33571132536858, 72.09104568727555, 66.26554935209214, 64.85617506888606, 51.26908086961316, 50.9512786711416, 82.17449449723767, 71.96805584815242, 83.3879424679664, 89.41720593360164, 94.52558317492085, 100.25117674181539, 125.5231018989317, 104.78785284103887, 101.44997858232068, 111.01375256815265, 104.81598407991471, 99.7159928660239, 107.5065888127973, 127.7821360864947, 135.35473454383114, 124.58626731749504, 130.292021536058, 143.4674669081165, 142.40949384627805, 136.72230812811083, 132.14763210665797, 114.37880885216498, 100.83673954010011, 61.064745380032456, 25.920712640208585, 5.110523758396026, 0.2347114901509016, 0.22905653552903285, 0.21604194275794492, 0.19775174678333346, 0.21063178387140075, 0.20970376028168589, 0.1644408955208717, 0.10667624192372446, 0.15512750333836003, 0.15122486759097348, 0.22391879750836283, 0.19428565857871888, 0.11062142619442557, 0.09265115619787286, 0.12853502866721925, 0.09282154947399132, 0.09567868970935384, 0.12203274249670007, 0.30208982707511994, 0.19389761972331232, 0.15029856003820896, 0.09015330353811865, 0.12268482121608912, 0.21368910288137777, 0.18326447255188422, 0.20143260007664082, 0.2111737910778292, 0.12025865906428908, 0.15769558327813304, 0.09227558159299436, 0.18491257282514728, 0.2136128311676364, 0.12232871290536658, 0.20798521056290598, 0.17410085055856936, 0.10888223806696554, 0.15308043979589017, 0.21212112008323594, 0.2195799972621664, 0.20340144604204163, 0.13297794026232537, 0.13163376239038285, 0.10047837611167662, 0.1309108665032733, 0.14099172556832915, 0.11624035936209465, 0.1875894372501681, 0.09708515052954036, 0.10124609580323582, 0.12811861391509735, 0.13610897225237664, 0.15607222764482423, 0.17796545770139466, 0.19309915692335178, 0.30273698751003514, 0.20590787122566856, 0.13341641834666654, 0.11018150786478674, 0.14373139388138248, 0.1882242177042269, 0.13161707699539202, 0.13232109647604728, 0.09681170310584769, 0.20799100218761354, 0.1251671146301012], [0.06096334647267096, 0.010873684415503616, 0.0737535291080994, 0.00922617881799177, 0.03917864043145411, 0.014220578915199206, 0.03456612463079153, 0.05278950241664725, 0.052801959006296056, 0.05031549807397589, 0.027338420228672125, 0.017151994247650428, 0.015838785480046948, 0.06027469854621638, 0.05463101307771379, 0.04907264682133833, 0.05782080018111776, 0.03949868132270152, 0.029629932851680828, 0.07937672938550673, 0.0793983637084884, 0.03583216153445744, 0.020670984653876196, 0.037458259762535175, 0.028239734162906968, 0.042591163768402995, 0.05871158806727298, 0.0965746908238338, 0.041962588626530864, 0.042278109599025025, 0.06681902379158043, 0.03357617049327782, 0.013153847445914102, 0.047898260846493707, 0.12622721177796203, 0.029412262374535206, 0.03419272954605761, 0.048656128647346655, 0.0165056650181331, 0.03736276307233399, 0.04025886270908579, 0.018411714756380648, 0.01704042120235822, 0.05594344043563451, 0.06018150395022766, 0.06482216199078868, 0.014685631632023763, 0.06628827041675968, 0.021162589020546407, 0.029037865629840284, 0.03509250747400426, 0.07454954808758152, 0.12224766846385696, 0.07295676702333075, 0.029108305499258063, 0.02775365520539063, 0.21469782617303634, 0.49092860051220466, 12.06084603263486, 44.23481595131659, 58.87149326262936, 52.767108563453924, 65.4292372734316, 82.64015828409504, 74.83587326542025, 49.74966841359293, 51.93060428865495, 49.62358382440383, 39.906582447790335, 28.376222272073072, 28.72641344224253, 30.052382446104485, 31.125276204078432, 34.41144381800006, 35.518991716446415, 36.459160312529534, 25.780446721661477, 38.39005293384675, 26.063896802163896, 22.48981348929867, 22.116315595565304, 44.5849580918589, 33.563348939341886, 31.703708133389874, 24.70005339191806, 20.038834194983206, 27.34957325843073, 25.97568661935868, 20.623573295531735, 30.01953455709642, 24.20029636352293, 31.02068424224854, 24.604957488275346, 32.31200891156351, 31.590073147127708, 31.282655423687352, 45.844242880421305, 22.890267872041274, 53.29579699424006, 72.03656396558209, 52.01180127359206, 66.180755553707, 70.1405216032459, 72.5239969068958, 86.76842151149627, 93.38851159618747, 101.4262011743361, 95.4528393283967, 95.94464963482272, 88.12299636102493, 63.143778078017704, 25.488626303211337, 3.8129701200992834, 0.09038440928223634, 0.051399658043538375, 0.021607546293507182, 0.06563053796848943, 0.01075887752156104, 0.11439291535005455, 0.040325677067401915, 0.046437036231039994, 0.02507975362541695, 0.07936316196836772, 0.0268605939533201, 0.06420889328564368, 0.02059443523326228, 0.053443703199586565, 0.040036995985334924, 0.06276978945900356, 0.03359579766589788, 0.04171465193071673, 0.03363883648548396, 0.0501301201180585, 0.1095063239336014, 0.01966021399223997, 0.03310680757426927, 0.03391180893466358, 0.05145865064414759, 0.008384883084574775, 0.059465024049483964, 0.04058460712492947, 0.031390069653430296, 0.10018158598893112, 0.07857864196862906, 0.07241639924506027, 0.031108405936749715, 0.02668637023758023, 0.005553892781702621, 0.04545113469864573, 0.015996469357501597, 0.019639242335312793, 0.02595079751054366, 0.085215583413599, 0.03349568146551329, 0.04070511658585841, 0.040021739344322876, 0.028227907680575887, 0.0429015213082875, 0.04913010341565936, 0.06494922533390984, 0.00807717620890828, 0.0518352288242069, 0.021221773143136696, 0.07133757124745077, 0.012471611675385748, 0.06389297394742889, 0.04069271362236431, 0.04976251282759252, 0.050006481187958876, 0.06251702257882684, 0.0792488846327028, 0.052067813118018454, 0.06382103063045971, 0.0672113067740875, 0.02934579275578501, 0.012007364308491591, 0.0449655230547632, 0.023911278018908157, 0.014590509367295572, 0.07237195848457276, 0.050159308067973585, 0.04233242906329613, 0.02802641889561088, 0.09429605422361244, 0.11891675647348167, 0.08350337690283215, 0.059439655047871416, 0.07951710733675188, 0.07427272221614277, 0.07704538593609488, 0.072965799199958, 0.027934220213923725, 0.038080809622882836, 0.05007791505645841, 0.03606946876032218, 0.10025600376989573, 0.042251135643211105, 0.0802337519463993, 0.014547461929220348, 0.031584410838061766, 0.02041252190998245, 0.06384570249206116, 0.014369322546577502, 0.03709171733428394, 0.029008915167181726, 0.07140734653559423, 0.03546604045456456, 0.027647360505896713, 0.03605453387623833, 0.04259946050062295, 0.05947808967903257, 0.013402231345554034, 0.03873948818973957, 0.03647518126414188, 0.03912970656529069, 0.03744965276470588, 0.019330325040725932, 0.01055916031492093, 0.05685670917192775, 0.02653375786218432, 0.023644233175042658, 0.0671561484435393, 0.09064005282256873, 0.08680202893071598, 0.07356335544177602, 0.09630181796608434, 0.050205265682551174, 0.03652462457877494, 0.12368200722360805, 0.06432478706682883, 0.08995094141291995, 0.006387485979845928, 0.29509614912732957, 0.346801323035071, 14.282576518674052, 51.61563796381797, 72.75736224266791, 67.61045163677585, 79.381774779289, 93.05955025457567, 87.68985686763641, 69.54672182759931, 84.04487671390658, 76.51744827147454, 68.316894039031, 43.183181439676595, 53.133940389079434, 52.63312432073778, 54.39231126539169, 37.50323641684748, 47.79814412516933, 50.56812586322908, 36.72705427292855, 57.74981306445215, 36.780602470521, 41.140771911990264, 34.2842060519803, 52.13926261471164, 37.42866431513141, 38.911555582477206, 36.246858104582756, 34.993539241052446, 41.374980557349424, 43.90476419079689, 36.77711940580799, 44.5354538579141, 47.201445717965406, 52.984662825061434, 42.03478990062591, 53.99463392073109, 53.09736428722259, 50.298635498169936, 62.111618134283255, 40.912231091530096, 83.72436415764594, 99.3016101467994, 84.14368906328755, 92.72156746156755, 105.7448797841226, 97.92696845146918, 101.85248436466341, 107.34575594625166, 113.05195731501426, 114.14542782691218, 110.29790432222428, 102.97982846536945, 74.35419051877915, 31.460662388032485, 4.490958423383774, 0.11069459525207359, 0.0673335437632857, 0.0554238451314309, 0.05128176094243123, 0.028290062309092576, 0.02595877631627504, 0.015247179826180783, 0.10754146928628606, 0.046311175645959955, 0.02311320017812954, 0.06132260340476229, 0.07428045204329876, 0.02023848205534441, 0.01001295015861791, 0.01732014480137056, 0.05951804882516304, 0.017678241110256603, 0.02643162876577868, 0.027338866474888018, 0.03721441780667632, 0.025689854556995056, 0.05958116680924451, 0.0795744873222805, 0.04683705670158229, 0.056593554139497786, 0.06175648496155778, 0.018716862898380048, 0.050956575770772276, 0.0272147812985725, 0.014907277147886495, 0.12318043413782313, 0.03756028352185123, 0.031541048346327684, 0.029089653173521645, 0.01684898157573996, 0.08857752196490766, 0.05824645012316685, 0.053350654160303455, 0.03099788243191377, 0.0542145446994372, 0.019655567668979208, 0.023888814405748443, 0.028569245816118298, 0.05221503223442743, 0.06897953729475699, 0.014901813025766564, 0.03986595536492044, 0.06293983416511648, 0.02096366663012774, 0.02003330072658437, 0.030533073905615077, 0.03564165461988699, 0.03271660452047664, 0.009057196101263888, 0.0224319871349801, 0.029470971522612438, 0.020879822137254863, 0.04073003742603525, 0.03950378346827723, 0.04667886720609762, 0.045038960243184725, 0.032477573596782265, 0.03882722823970741, 0.14967030665326506, 0.06949544388560519, 0.14891428512430963, 0.16927572237628122, 0.1533145409437918, 0.15725903573536104, 0.11207818834772033, 0.42442870596724175, 0.23073469709244468, 0.2491816806216394, 0.1364590744337728, 0.1401149685825071, 0.07961498272995796, 0.19409908552563962, 0.1530328197705169, 0.12989314933938365, 0.09975239289023223, 0.19103396774059345, 0.12247904999962739, 0.270447607242292, 0.17264949698602, 0.26046309139459367, 0.0970549666653237, 0.1567210887949313, 0.1538718086216719, 0.18440896194548378, 0.11259768023005418, 0.174792260231991, 0.13927815542105706, 0.18845519321339746, 0.2189484343773896, 0.10846020789035868, 0.1792913720372223, 0.20861790725781074, 0.2925726555047497, 0.2160265290689084, 0.11302856638306573, 0.09607049771734784, 0.10188672916903611, 0.2009826919604694, 0.13145147942967955, 0.18001003911898983, 0.131999829844121, 0.17486131539748562, 0.21522186095676116, 0.19542120006536284, 0.13324942650093188, 0.22912575923387082, 0.1316756520780825, 0.24639407052628456, 0.12715441565359795, 0.22112941008902368, 0.3958970176116113, 0.12110310246146495, 0.22969067246923525, 0.12091916475084521, 0.49756739588995136, 1.230474244202337, 25.438882804686024, 71.73707531344506, 89.60438143822455, 79.61567355740456, 90.63498420100059, 107.49631220294584, 103.23303314947314, 72.47397884245842, 75.24267796547183, 70.11861124346333, 63.245273328596554, 42.80127986784905, 43.71578831826487, 50.46644626125213, 50.119128227233894, 52.73382725254182, 53.661024570465095, 55.506735078750125, 35.56239666477327, 56.35616356326688, 37.096172840364524, 29.388923337382657, 33.55811649753202, 58.917655637187345, 48.557440465496434, 44.62804925057196, 36.709603648031916, 31.04029413192503, 38.832041294344016, 38.09548685627599, 28.89517341890643, 44.20980299672773, 36.16056596079181, 45.625402081397276, 34.79258445001418, 43.93828084391933, 45.005749963944965, 49.779803983626834, 62.69958142311343, 35.60436602561705, 73.80288570157944, 99.83975933444117, 75.13898618759649, 86.90688902331938, 90.15451738911291, 96.12075621081938, 112.61591526769824, 117.09668974722587, 124.59459843174105, 121.55174132316344, 125.93708453639861, 121.44435467258577, 92.6028294717112, 42.63666583645729, 7.537562866364756, 0.19679905516245674, 0.26694155989154694, 0.0695920552337362, 0.19876430051461344, 0.21138451122228177, 0.1411437174125064, 0.1245110905579021, 0.22507677004942972, 0.11123924546184079, 0.1441618586860357, 0.16437395475804806, 0.17505740326258445, 0.12277171856934026, 0.2079570644925679, 0.08196330268777187, 0.11975147821489843, 0.10625026639430754, 0.1450931611320665, 0.14607672609629171, 0.16837369981071643, 0.18627545856420072, 0.08596508553431881, 0.16327267272337792, 0.18414452371578063, 0.11335361748933794, 0.19054345696443514, 0.1321362547816769, 0.1379315873547908, 0.07349277576131207, 0.14473181277994188, 0.2405497389695337, 0.15514218158298923, 0.09120238434162833, 0.15004461721306847, 0.0555337519354878, 0.20534165564083284, 0.2199891801442831, 0.13060478373400627, 0.12411919061935718, 0.20877811156453627, 0.10967098687204624, 0.08635198291871818, 0.10996021570697909, 0.130985728615234, 0.19265166964502106, 0.10455580247986702, 0.2947146373410379, 0.19012616887207956, 0.13670318068996554, 0.10588819025865487, 0.1757723011917645, 0.16199782580858277, 0.1482176660530029, 0.23268477390370063, 0.30430179870417046, 0.12559666779012452, 0.14055179191693185, 0.10557706663084608, 0.09407056390397972, 0.14637286504430158, 0.12760559547572367, 0.12985260796643075, 0.08497217429741737], [0.040196805756779454, 0.019667080055261334, 0.06579919222501979, 0.019332732472027984, 0.05239120181349497, 0.03931710699332818, 0.03598603795492842, 0.016882028693573612, 0.06812051524438205, 0.1098115640061517, 0.07516650167564232, 0.05296754891112928, 0.047886807832025716, 0.017152967179314266, 0.01714847407363836, 0.014522635892424134, 0.04921195224948949, 0.06762391406922572, 0.008687300123124114, 0.023863085342811483, 0.044335247197699164, 0.04447583199268387, 0.017752095816596862, 0.02066621575654755, 0.029758578166365627, 0.09406884786702933, 0.002772278281965203, 0.037764951571701996, 0.07850985493390791, 0.030483496525595268, 0.03912418307135663, 0.06788599274812207, 0.019538469214533127, 0.0582358819402514, 0.04183593131000957, 0.06906365374884299, 0.08472404607962217, 0.04172188763116156, 0.0930278646128793, 0.05450505673164322, 0.0387450423271906, 0.04341704102473394, 0.05204838895869832, 0.017498294717722365, 0.028976310465124347, 0.031993737361664255, 0.048706380184739835, 0.046498859526529435, 0.055814749155674255, 0.04889267361572674, 0.12246510719940548, 0.01858738063263797, 0.12576305442639898, 0.018109493070252, 0.19084272155117607, 0.27537131561867656, 6.756944521780937, 48.7030545357735, 68.26667985608502, 76.12113198926373, 61.71785531505462, 42.288367209895966, 36.28006881283176, 32.07916132865414, 32.42037811586934, 29.952826807575843, 19.645942141932828, 28.06744544736801, 21.070523454296975, 39.465766875974595, 39.34844486175045, 37.682112186185776, 52.1277779148471, 71.88862785216301, 78.4539302702873, 68.4693173439272, 109.72432044244583, 72.66185252897202, 92.91283792065036, 113.78176135401573, 100.37342917534613, 116.7830962519492, 108.35058873699559, 121.33024507953276, 126.79086685180665, 115.52260337337371, 93.0915097267397, 97.8891646477484, 111.63866458400604, 93.92111455240558, 87.1952538336477, 71.8011119288783, 72.22482204437256, 92.54849680008428, 68.08881605825117, 58.925994596173695, 79.38663067356234, 90.6988246979252, 56.19545229019658, 42.590393635534475, 37.0150621475712, 42.65029215043591, 32.515589729432136, 42.47063582943332, 49.52594034133419, 55.16275105937835, 67.63660600108486, 76.7813531814083, 88.42089253087198, 83.55954616300522, 89.13026886601602, 89.0579717389999, 61.20900623260006, 19.640299812439952, 0.5700489662347302, 0.06774486403071112, 0.05705392318627527, 0.018871350273970636, 0.037635011568425164, 0.05898667874956324, 0.031900738118096225, 0.008119345518700298, 0.09918437699877447, 0.029835321024180423, 0.03997544848149823, 0.0784118646275132, 0.04464431770987088, 0.01688276222276111, 0.0739786746881662, 0.01445677531357374, 0.02766330279560099, 0.08188820308855466, 0.0342125061058229, 0.08637093593396487, 0.02361367967340254, 0.018403050301957036, 0.03536612343704028, 0.08760961583785473, 0.04216303170147923, 0.0291526619900739, 0.07520414723624146, 0.04829684490217798, 0.012978574189717972, 0.05323112146147797, 0.012765006113406873, 0.043367448322955644, 0.01682155754327053, 0.08242143858825007, 0.021959900773400744, 0.05375992131209182, 0.0462221792117963, 0.056985672413101124, 0.015127877911342489, 0.040556078010629264, 0.06757273939588378, 0.05120341696085469, 0.02749144437632734, 0.017439853700418628, 0.08042668352925009, 0.02367646249401714, 0.009910598896714229, 0.08515512375461479, 0.04631494479854742, 0.08426019516322883, 0.03889190904315441, 0.08773648765899482, 0.044463674177325545, 0.05141526708499559, 0.028418389697288795, 0.021751411860027624, 0.06423954829393376, 0.03680824565010206, 0.04222870075834855, 0.005729172262363137, 0.01642609529587771, 0.07003195058073729, 0.022383407584481665, 0.023605436567337285, 0.06408014071864948, 0.05913474056268892, 0.031829229556024075, 0.023535898766450347, 0.018637787302835815, 0.042627403557661085, 0.05314788983894452, 0.02046540112895591, 0.05416630031240564, 0.0013237613893579694, 0.01796721522095463, 0.007987528121204027, 0.031832069827003345, 0.07812602190120567, 0.05873436003082222, 0.04787888265244904, 0.030739316266150247, 0.05195761137011071, 0.027575532102116176, 0.028834245205225966, 0.0374007955073349, 0.0641869027317772, 0.061088915944339774, 0.06994944291129228, 0.11313155924360599, 0.023041080660937775, 0.04566320698828467, 0.051004663109779365, 0.01667062098520898, 0.08176879296379705, 0.05677076559814234, 0.041730418020198425, 0.06423145840545336, 0.051018575266484296, 0.04347486917169825, 0.023737552260319074, 0.008279473216633403, 0.019257925901441805, 0.06054564469283628, 0.0431318762862394, 0.049117083751386216, 0.051017816839439255, 0.12325479063175379, 0.036559535205484404, 0.010272064077247296, 0.050650596423375036, 0.03564060507943073, 0.022430089152147694, 0.04369849023679572, 0.013594543354796066, 0.10882710271905507, 0.02580409358826376, 0.11189919956509145, 0.29894540386815227, 7.819342997766311, 60.4840188641702, 84.74924810471074, 91.67911914087112, 72.81315403599893, 53.6277275700723, 47.96947325429609, 59.260055019009506, 54.480619507451216, 38.29975605010986, 34.85406368009506, 36.37650812825849, 28.224714840612105, 35.6530975526379, 36.231027418567294, 38.2039168573195, 47.42311454588368, 60.53646487574424, 59.45908392629316, 56.616859974399695, 61.694760399480025, 56.93230090602752, 59.14216818348054, 58.60117527746386, 61.28631222632624, 73.22684641807311, 72.94768348816903, 61.67965142957626, 62.641220477319536, 59.390332621912805, 65.97676877052554, 60.74461721604871, 53.210367771887014, 63.65802434182937, 57.66860823477469, 54.05386171033306, 50.69157069729221, 49.93835403073219, 43.18712734406994, 45.15209751744425, 72.81519366848853, 57.65061632279427, 58.215527842121745, 54.67716947678597, 41.19367684087446, 56.9005532418528, 41.818243688152684, 52.86274771536551, 79.63677590893161, 86.01396145359163, 85.60036320840159, 96.85900119043167, 99.56374214541529, 93.23253462391516, 101.58859514421033, 105.5496398864254, 74.97151667071928, 26.669565669951904, 1.445963623062257, 0.11454939646946807, 0.02809418320295311, 0.02433905385494713, 0.06184789457268292, 0.042148181087067055, 0.08141612438785453, 0.06449685807550146, 0.06713934047448059, 0.056218293630668235, 0.02690033859483177, 0.08215143856021666, 0.03318584869585691, 0.05670592774667087, 0.08432969465971955, 0.06735245081325693, 0.06370628598116099, 0.037174102429661064, 0.038255109947415135, 0.06895138356353968, 0.021870617056265477, 0.02956709257447191, 0.029166543503261866, 0.02439050623516162, 0.03620074175658726, 0.05873521038841817, 0.12284300305069455, 0.08650178375143198, 0.023708810556619882, 0.06093903467239392, 0.050035895133811625, 0.01882678502419543, 0.04412212153716434, 0.03923067695371086, 0.028540860343303893, 0.03575079533601961, 0.07313592434530297, 0.13632042784123652, 0.039542405790979826, 0.03841136890133062, 0.022216651310783722, 0.05515014872916284, 0.040051337151277455, 0.02223295366181241, 0.0705686564587297, 0.07126232609152794, 0.01461239745690217, 0.06393130515672027, 0.01949488072686138, 0.06517837755382061, 0.04167821678903796, 0.03723328655225135, 0.04136416287491879, 0.015374042071221818, 0.06052699811275929, 0.03863499379686771, 0.034961230647299564, 0.03536698145551547, 0.08294356581304344, 0.0925126551620422, 0.06552875552686953, 0.07963794238504865, 0.13174948763222466, 0.06213408203855638, 0.130688134100168, 0.21529618680717486, 0.2685037357432227, 0.1446851427035947, 0.12498087865570862, 0.13115141811149736, 0.14684779359208, 0.15231335595730813, 0.14943254360508534, 0.24098855413256154, 0.20130971957358623, 0.13355685758494562, 0.15294930086501185, 0.10436768959005994, 0.15679484774028102, 0.12169263010183651, 0.125560209665808, 0.1406842791625569, 0.13562400795279012, 0.11952863855948372, 0.14419981068180454, 0.18044664794879575, 0.10437103739428906, 0.18506494771328666, 0.12785538610431457, 0.11007703645455261, 0.2582148378414493, 0.14065225668732198, 0.12141221893891213, 0.26617375593031606, 0.09893120792243751, 0.10481282497846311, 0.20060061326911374, 0.12019498949690212, 0.1986711901882964, 0.09567907275331598, 0.15584178839720067, 0.1519390607192632, 0.1629049351979648, 0.23183126002550128, 0.09556694812471829, 0.26396984354622904, 0.1818917655656415, 0.1407421188008401, 0.09790479566060728, 0.2645595473868232, 0.12908465078761502, 0.18706128091341068, 0.2120581323341016, 0.11535149818706898, 0.2887104998432821, 0.10742076447293644, 0.3141656403820361, 0.6166685420659281, 12.799272421867618, 76.59104762538787, 101.8720805260443, 104.57545649620795, 85.73240587788244, 65.2503615040933, 58.25858762187343, 54.72245324042536, 54.59834552580311, 46.95565431348739, 30.0854205700659, 42.10531411632415, 36.64814795217207, 63.32836089595672, 59.221800142718905, 52.91736672001501, 73.40391789713215, 94.5823634055353, 103.53134509055846, 98.26518658668765, 148.17475042035505, 102.78854231680594, 127.63932258852067, 148.76671452676098, 138.70829828323858, 156.3871894344207, 147.75891642416678, 161.50365460303524, 167.81823127500473, 149.08284187316895, 128.27263632128316, 130.60086111868583, 149.52798381928477, 124.25827087894564, 115.68783713925271, 103.46476677925357, 105.67931344432216, 126.50426710805587, 96.87051726925759, 87.81078354004892, 105.71903920942738, 118.50022362124537, 78.88200206141319, 63.649379437969586, 52.778338309257265, 57.72949126458938, 41.97614654417961, 60.19486957980741, 70.14254554625481, 78.78534701562698, 93.96794765226304, 102.12144128737911, 111.84795441166048, 106.88416357963317, 114.5694988004623, 123.48741531372072, 93.46304447420182, 38.399890238238925, 2.8733369275446865, 0.18745717983092033, 0.16445195783049832, 0.10639434455022698, 0.18205747038366335, 0.13804130646730625, 0.1444941723058301, 0.16959109013119053, 0.18956819639330913, 0.18464335420679662, 0.13587729194231574, 0.25552726350724697, 0.13880128100995096, 0.16031261623626755, 0.20168668079760768, 0.20590574150123905, 0.16475612537995463, 0.1226255413325083, 0.15479480667460352, 0.11740662097450226, 0.1367692174690385, 0.12495936690679482, 0.23961783897492195, 0.1376222716944833, 0.14945877445561273, 0.12433787041734304, 0.3091866511010355, 0.21693943008299799, 0.09813524256911009, 0.16115637015431158, 0.17157400147088114, 0.11784003521766394, 0.1343042376421152, 0.15977722802950492, 0.1306032668799162, 0.14970283474652998, 0.11831316345882033, 0.24211502513818203, 0.09726088343849106, 0.1585840154439211, 0.24081135799567546, 0.18918009625086862, 0.15592392834444202, 0.13297481462359428, 0.16254775436414828, 0.17627727570793322, 0.20323240108066992, 0.16349151339982787, 0.11178750394573135, 0.19387687406232282, 0.11064284601278844, 0.10312110365879151, 0.18041090228624884, 0.0852573735098685, 0.12562237770086335, 0.12810379011376252, 0.15171062862200124, 0.16522097221064955, 0.22023143246769908, 0.12870805728579723, 0.14458233370415627, 0.17400703543136198], [0.06411266881191442, 0.01954205833645838, 0.06686172553247983, 0.06405532713078203, 0.0408811520995392, 0.13717193456907428, 0.01465099296652742, 0.07435824827200944, 0.14651915719432218, 0.01159636771321417, 0.05826540696885317, 0.04758752792352631, 0.032725058300721074, 0.02101397945455486, 0.058290040526058406, 0.11214980990776133, 0.018883525326307264, 0.018017731058681687, 0.039926587393687624, 0.01967800255384176, 0.03024333370699277, 0.04352272668432805, 0.04312932138301192, 0.05594021137503367, 0.05922569818193874, 0.049784277385521325, 0.01174554322665978, 0.022838735772717386, 0.04421212537694843, 0.01742795252451493, 0.050478770562838164, 0.03687479953852393, 0.09587572752347878, 0.03856255252274775, 0.027178631524645516, 0.11936033670339855, 0.07623301097942937, 0.04417392823304381, 0.04643387994879196, 0.03815836453389737, 0.03439500740158462, 0.044295782178279855, 0.10015354717090245, 0.023038108239791567, 0.012380248987145964, 0.03783571894370741, 0.0481116125029662, 0.03632773232135562, 0.08070511052445059, 0.05419964428930994, 0.0329226668503496, 0.11639338542496967, 0.5439343159237217, 0.5124454975368515, 7.40482593736341, 37.64626956755115, 72.01262966279062, 82.16726164663993, 73.53838459137948, 79.2083824834516, 55.535407604709754, 29.17079248735982, 19.060575462156727, 30.71147007326926, 35.53011948062528, 46.13271359474429, 87.56529808044435, 73.0815226031888, 82.92403590294623, 69.5434505708756, 99.04764452288228, 95.23048800806846, 80.09027250351446, 51.21426182408487, 30.727863619404456, 33.5617172333502, 39.321015727135446, 35.59760385943998, 41.6251689387906, 77.3073979346983, 59.83415665165071, 59.79095174420265, 54.95746597166985, 69.35075236905006, 74.71159688888058, 63.84933794698408, 76.55713481287803, 70.3323333494125, 72.45442190477925, 71.79911152009042, 88.54039930528211, 68.28408733490976, 80.54971541127851, 86.9094934771138, 80.79767980883199, 68.59320148344963, 65.75579027975759, 67.0777702331543, 79.81480444631269, 71.6608009030742, 96.45510688904794, 93.8765956509498, 99.3891574490455, 73.75063188614385, 47.087296901210664, 32.35981279803861, 26.608370811708514, 28.91782902902173, 50.321228350362475, 77.95356919688564, 74.66713290060721, 79.84918794324322, 83.2550839454897, 79.63032753236833, 49.84110670704996, 14.549786025477996, 0.9743736864578341, 0.042848737850304575, 0.07701484201055381, 0.0971514477785076, 0.054504068478220896, 0.021914699670648383, 0.054573460722402226, 0.020274543729160103, 0.024201837931609443, 0.013745169647248283, 0.09673511729605737, 0.02608540873493879, 0.039609955593703255, 0.023995344677279075, 0.05557204484038296, 0.05426627861696386, 0.09617625615529476, 0.049901967642888914, 0.05592179462133397, 0.06146329928249602, 0.01848871616886989, 0.019806699579461448, 0.03207384909112607, 0.039870306744330355, 0.0183887263729928, 0.07904102199620779, 0.05736525748826324, 0.0362762933476798, 0.05401023288047122, 0.04669077604288056, 0.04357659798716346, 0.017504770075902343, 0.03732860321179032, 0.042635769237794226, 0.03134538757524664, 0.016615612041806022, 0.03868057219792278, 0.02222997549500677, 0.029273908810629964, 0.04660229671806578, 0.016423749151609598, 0.013920901598589075, 0.02367974135033306, 0.06995082186955599, 0.0011310262362390097, 0.048503389867443236, 0.021179896861975713, 0.019665132276713848, 0.04326727849641635, 0.022707432132935332, 0.09796907809833366, 0.040415171458716356, 0.05137036284131389, 0.028176520417834965, 0.02617728949013737, 0.05192245176482586, 0.05723686881303307, 0.029715307605182453, 0.07029768349903245, 0.11023291236450596, 0.07422750770685173, 0.01981544064267749, 0.0221733711735015, 0.01674707081439274, 0.06884369458402358, 0.04676284959479686, 0.028324722042006832, 0.08953499397443188, 0.10698689823789943, 0.02153194107625994, 0.031893073408413804, 0.05595234237731465, 0.04287480782236784, 0.06192389432521117, 0.030821626667954752, 0.04873156149481093, 0.04810232751732392, 0.023550580841519182, 0.0039000138114657136, 0.021645392952186447, 0.020422262717939673, 0.005945425476848839, 0.08246073123788641, 0.05361110107192109, 0.015119293896150927, 0.0021213034473945417, 0.026821919919682607, 0.011253230228659608, 0.02802436194953419, 0.04527491149342349, 0.0260471273213625, 0.05724359506500825, 0.13898987653515033, 0.02348119817343691, 0.05406166802370741, 0.062259283788021536, 0.06234137776998743, 0.03830866715420158, 0.06440405418435413, 0.02939522840953883, 0.04017615968722009, 0.06073227137207024, 0.043737173846532265, 0.02778465878368626, 0.0201691281155593, 0.05124644045868228, 0.04576826828622049, 0.06088380739393254, 0.10405133358172833, 0.08111453855470305, 0.04222411189168211, 0.12096372808540061, 0.5655609780261593, 0.7302623434412865, 10.438328193080041, 46.99332475662232, 87.17773652845814, 97.11102916348366, 86.24711498137444, 88.19881577645579, 73.138593089196, 53.62473087926065, 33.49645291605304, 30.472123122984367, 34.73584344310146, 35.234153116903, 41.73825087085847, 42.49950839627174, 58.036016648815526, 52.318711050095104, 66.87202622813564, 62.49013862302227, 54.17252517515614, 41.819914617846095, 33.586992986740604, 31.8873691943384, 37.496003566249726, 33.56673002243042, 39.208643744068766, 55.517917756111395, 44.9119072575723, 46.584896195319395, 44.55141005977508, 50.85093267502324, 49.66905978418166, 48.24523941163094, 48.02863044123496, 49.52967051536807, 57.166717437005815, 52.29493756448069, 55.62033476368074, 51.882621934337, 56.312997879520545, 67.06284169227847, 65.79375882302561, 53.75280018775694, 50.24378899605044, 58.093757860122196, 54.98447149030624, 53.741966601341005, 71.6091432879048, 67.70417274967318, 62.59186529344129, 64.07325821538126, 48.253931383932795, 35.854993712517526, 44.819735480893044, 58.92473943771855, 80.17235986648068, 97.00326596536945, 91.67365920159125, 93.36254550564675, 97.79384320782077, 98.67334058207851, 64.67857406985375, 22.00058018007586, 2.154654278870552, 0.033630742766563936, 0.06532885254390779, 0.04794513393614081, 0.0176965850856035, 0.02928578508867612, 0.030828448680920467, 0.042467015389833725, 0.05827633138265341, 0.06177047372705514, 0.0862160559383131, 0.04880180792702783, 0.050435996043585965, 0.0500667646467205, 0.0369708324902721, 0.04897694711783721, 0.03852752315241002, 0.013093690391659979, 0.0430067205020497, 0.09064250430392642, 0.012951703655773835, 0.03011235373935873, 0.0876462654841523, 0.07795042688808135, 0.12177072510483766, 0.040313300916985165, 0.045325726105441014, 0.05341602061244269, 0.017401217971177354, 0.04779326466603145, 0.06195914203060731, 0.02088981383900729, 0.07702832515802115, 0.014943927751793979, 0.11892123042695946, 0.006446960258237537, 0.023445249497590047, 0.06436925080995407, 0.05379927907920173, 0.0365880451675865, 0.08049039140103326, 0.03822240948436722, 0.05653944534940585, 0.025846163306625623, 0.017132730966794397, 0.016171539600397793, 0.04127990086412719, 0.021975582593210766, 0.0502880453132093, 0.029703048283174157, 0.04114298563029978, 0.0498184563982631, 0.02354156590187021, 0.03057207927227982, 0.009769134058226502, 0.03935479468876316, 0.058034446781441096, 0.09155730521606822, 0.02605999951371022, 0.0494186312801415, 0.26599488972175506, 0.1380444167842788, 0.1271423114643943, 0.15577369850249062, 0.11061571883938967, 0.25868107895216635, 0.09250147793922694, 0.28508319609588195, 0.2841929099973171, 0.11259801730874086, 0.16841425650542782, 0.18969853859274619, 0.11767433806052131, 0.16537058918226152, 0.14053493798259767, 0.1894476754410613, 0.1395876396207079, 0.16576320924345525, 0.15102081241146212, 0.13514244508358741, 0.11579809680340752, 0.17408414984182005, 0.2272247426932858, 0.11297598210794312, 0.28886580118729227, 0.2508557206320186, 0.10942508030923144, 0.09370276509153266, 0.1181063197192646, 0.1316684968168697, 0.15650178846572677, 0.1452653317321693, 0.30915613015813215, 0.14580144006158077, 0.12954848638224986, 0.15539312134346656, 0.14885537296293244, 0.1783168622322621, 0.1029412491968082, 0.21509475164836456, 0.17050566121695504, 0.16063916887487137, 0.18696565781870197, 0.0725805412437166, 0.19821616460479077, 0.11783324001777558, 0.10228883339873246, 0.18587905402866103, 0.2604607931308208, 0.21722112061275592, 0.24535845754848373, 0.27569221452839915, 0.7121568665869775, 1.2765786412262148, 17.219118764323575, 60.96472101826822, 104.10241865342664, 108.62873185065486, 94.11046305010396, 102.41496009211387, 77.23531261567148, 50.80697467250209, 39.39016711327338, 54.57201465483635, 58.66992265947404, 73.83969322327646, 128.43667768662976, 104.22096052477437, 114.49162406306114, 99.04241992581277, 131.18239956517374, 133.39422410534274, 111.22183430579402, 71.0142138696486, 47.42246735480524, 46.306439292046335, 56.300964047831876, 50.45882901837749, 62.037591242021136, 104.69461025730257, 83.35814029939714, 82.29012596991755, 76.6467531265751, 96.67474392921694, 104.64168963893768, 87.47259678379183, 103.40920248339253, 96.28136157989503, 102.30865601570376, 98.7237822624945, 121.15470332484092, 93.11348284444502, 111.17067090926632, 119.09236815667923, 111.12864663524013, 93.24473319515106, 90.46180371315249, 91.31367975665678, 104.57009853855257, 96.9721301909416, 125.9778222730083, 121.81394392444243, 135.59272827640658, 101.67076879932036, 64.92562455515709, 45.9173087919912, 46.00349110941733, 43.12257297577397, 68.07784126650903, 101.89304167224516, 99.55304191958521, 101.71189877294727, 105.73257923126222, 112.88207161811091, 80.63574083389776, 29.658923610564205, 3.396698044192407, 0.17650645857136096, 0.23732452413007138, 0.1696178419215064, 0.16113490437067327, 0.05025766609657196, 0.0851489337641866, 0.16445702933255704, 0.2390949073578081, 0.1619919422533243, 0.24114889633511347, 0.18385716413538303, 0.16594261171356325, 0.2060578559194842, 0.1522111751499676, 0.15196935183578922, 0.16914580918608174, 0.10725918886882645, 0.21807118709529602, 0.2597661965316342, 0.10218476035421896, 0.1567646332325474, 0.17257144794829432, 0.11169486093304812, 0.1560939538983568, 0.14484185364938554, 0.22153244894598761, 0.2088671922683716, 0.11299717976080795, 0.22283652977597332, 0.10825485802225529, 0.17094718833123485, 0.18179191366559078, 0.1703639809162386, 0.17672510006495062, 0.09030547158251848, 0.16773073753762632, 0.15688625735140618, 0.207083371858443, 0.22673063130388338, 0.2466471246894329, 0.17186646319685445, 0.2683063608504111, 0.2345772255812922, 0.10475927543255592, 0.23268929382245387, 0.18152562150311086, 0.16009281028903302, 0.1316328584066322, 0.18357804766105068, 0.1451654491886016, 0.18368586687551391, 0.13346690354087662, 0.14069793084936758, 0.1393741615597279, 0.15750582329928875, 0.13507924282983427, 0.265971539361823, 0.15827485300119848, 0.14019956001110617], [0.03611371799882862, 0.09769356223724543, 0.09370497908563384, 0.06678864074450347, 0.040225603001853155, 0.05042094241587385, 0.024991178539611643, 0.014604518242600947, 0.04724119106427797, 0.028950882091697668, 0.06708294108149505, 0.05732326054825418, 0.03723524773733751, 0.047143652749758576, 0.022238670592947353, 0.028781015501027147, 0.04343593658338632, 0.01891801268943856, 0.06841350557102312, 0.03968819998384964, 0.026864495256074497, 0.1236797625859899, 0.056314652169784235, 0.036195969028819, 0.031868629457969824, 0.00915629723514881, 0.03195302744936799, 0.008973235737592464, 0.036597575301364545, 0.0501866574068704, 0.07470494136214256, 0.031566515024150574, 0.1145361201657403, 0.03131114536025111, 0.028692381043407707, 0.03937249131981404, 0.0029840412636047173, 0.03873653492079147, 0.04688559220202508, 0.06368345656101743, 0.04527131854105861, 0.052176187746226795, 0.06368708781777851, 0.10520057272045844, 0.017989743951587908, 0.008634620087010967, 0.045249887231376865, 0.04582469449228337, 0.015542130380298103, 0.09488467788023335, 0.16528679448510372, 1.4843448732168445, 11.808640572332568, 40.65182885816021, 73.98661736519107, 83.89742697438886, 75.8744227501654, 58.11042401098437, 49.21629667282105, 38.51576882023966, 24.907417335817893, 46.484381537283625, 30.67978124464712, 65.8973172403151, 66.28534163198164, 53.68373117139263, 63.87283294431625, 56.66878038837064, 48.77150381765058, 40.43536109309043, 31.090822104484808, 13.738608494881662, 6.981640929175962, 3.3033637750533322, 0.4033837803909856, 0.09871832741003844, 0.11601857690801544, 0.06849075787730756, 0.25565805003768016, 0.7958739743598047, 1.3832986114486572, 0.9767051065160383, 0.8759301624471142, 0.3949125639853939, 0.5130752524541271, 0.11490782602660118, 0.8581784956397549, 0.892854086574047, 0.3645757886190569, 2.101513517479743, 3.227394819259644, 2.847919233383671, 3.749837120694499, 1.1783552602414162, 2.5182072481801434, 0.9715877004688787, 2.632950794312262, 0.8208407185250713, 2.7323698853292777, 5.113197834261003, 13.944847699134582, 28.774848830315378, 32.36571988751812, 38.25586865025182, 89.3049555440103, 87.0968258765436, 53.049825160734116, 41.263393048317205, 23.298039436340336, 24.845245807401596, 39.69346046447754, 60.14405919659523, 69.99613915720295, 81.57266955221854, 82.59477646120133, 78.88616761853619, 55.8098989917386, 19.38986824404809, 0.659373163455917, 0.031171497107753833, 0.056076908273802656, 0.10500134389487006, 0.04796897459234442, 0.05124054158166532, 0.025651368214899016, 0.049722523037945075, 0.06942648065066145, 0.0480680680653501, 0.012203494308426256, 0.011636538491133722, 0.058912923634653135, 0.015696326642477467, 0.03880981506118852, 0.05538200523944632, 0.07484243116191319, 0.04405675508502511, 0.05477398806702226, 0.07651519180545885, 0.055706037448779236, 0.035527710532469135, 0.057384233486147664, 0.08373778448590348, 0.021171477555687872, 0.06000348426882298, 0.030048785678621744, 0.05658271399536922, 0.024344088967829466, 0.060690412327887557, 0.03180619329214096, 0.10951379329086312, 0.05027241711955398, 0.0479791903748147, 0.09815834012002715, 0.029515128830567967, 0.03215828730214027, 0.06313876421641439, 0.03873523640175981, 0.10105790630463632, 0.08054273052802009, 0.03649905639430208, 0.05790971617604937, 0.032672293994936256, 0.01745895610281056, 0.0773163359131544, 0.018288238619964932, 0.062033965838171785, 0.040364969717038256, 0.03419269124166139, 0.03688367083668709, 0.03902753724926903, 0.06581576270682198, 0.08778240696917619, 0.04207835983364813, 0.06070342433128146, 0.04461576944337257, 0.07442636114935722, 0.030867086325381553, 0.017283634966119163, 0.12424633057127077, 0.02584531294902967, 0.031171998895344236, 0.047619569550959334, 0.0371641586084039, 0.05678549363848664, 0.06748114592365681, 0.02184388441814771, 0.02716115897431249, 0.04362100044325475, 0.01576084177941084, 0.030515992060123436, 0.04751462699665178, 0.05060263931931508, 0.08263145393181233, 0.020225056364471396, 0.038764707804206884, 0.024296231455199664, 0.043036165091419415, 0.0871997817810024, 0.010075998237176288, 0.04631268483917079, 0.02050673157247084, 0.05215038973537665, 0.10036241338257829, 0.027718191080155875, 0.050389494506582144, 0.04928684500496715, 0.01599724310630512, 0.061320113619008375, 0.019945817316071163, 0.025958270698245016, 0.017085390563513485, 0.021745057160695715, 0.029011954621021307, 0.05160852042477458, 0.09549838325549519, 0.02212965053566281, 0.026267737660917546, 0.025233277645442757, 0.027840345714902206, 0.060032139787630695, 0.022672661317272053, 0.07099857734095666, 0.06740793090073333, 0.008075983984576119, 0.08923965175786326, 0.03296798478151041, 0.09914968087668381, 2.21461015843576, 13.296201421368508, 50.54005738227598, 88.6435890197754, 96.8050293768606, 87.80486076108872, 80.89428778617614, 72.86760437873103, 70.75390969553303, 42.64096475416615, 48.60734085882864, 38.79363736798687, 55.754832836889456, 58.26482811281758, 54.672419486507295, 67.54553641042402, 58.254873137320246, 53.30710910981702, 46.18513607209729, 32.93878601443383, 17.64363100451808, 8.146351979624841, 3.655088346812033, 0.44352016862361665, 0.25376532256843587, 0.1477971910348823, 0.08094052168270273, 0.33142743992709345, 1.0702430937559375, 1.0032175096773333, 1.2325149798585524, 0.9456240001224703, 0.5981760375922727, 0.8212894621875979, 0.29162000984914843, 0.9557734393785078, 0.5751542987362032, 0.5489051846727249, 1.7383850221672368, 2.192027847613058, 1.5704689679607269, 2.3490915615712447, 1.338162426987002, 2.134408720078007, 1.008991728867254, 1.9173424258347482, 0.8800414805450748, 2.9517252502902864, 6.112475077952109, 12.425341106230213, 22.94704418028555, 32.292836366161225, 42.432702587496856, 63.24339451328401, 67.30179248317596, 53.33648766240766, 30.11451278963397, 31.78921776433145, 51.01529959709414, 65.45915711310603, 75.16903154311642, 80.25093278577252, 88.46385817373954, 96.29268154021233, 91.7948918188772, 72.30135533117479, 27.477507245156076, 1.1548719074456923, 0.04209313000882826, 0.05019326491521732, 0.04091019832318829, 0.03985030801906701, 0.027529183782697208, 0.007362979728983896, 0.03946431844885792, 0.021800416589324034, 0.042600525362837705, 0.02445065754375631, 0.0318676775937239, 0.027259476783294833, 0.05805385561900274, 0.030855665869650342, 0.042450138472861824, 0.0629354521421896, 0.03972115708635219, 0.05367718381626953, 0.05635664144891405, 0.011684212142661696, 0.03899111359890911, 0.03942786032454141, 0.0639284476487627, 0.11810964454085597, 0.03545896946302345, 0.06340959544984565, 0.02873481082309398, 0.03247714841798429, 0.06675197577644741, 0.04658954135412651, 0.04659933195779881, 0.11601157486438753, 0.04593957320696885, 0.07454389435870033, 0.02924197443550633, 0.012968166885266622, 0.0585688965304965, 0.026373082411385355, 0.08743584411399019, 0.010985296722801944, 0.038085287406800256, 0.04110656964081911, 0.08266061123821043, 0.014171307970349108, 0.06084155764490847, 0.05591268966635389, 0.03664027321182432, 0.03427638251694941, 0.08752192175316234, 0.04498395129978176, 0.08631263664292713, 0.03452389020352595, 0.08518406655639411, 0.0409105928584693, 0.039733893298093355, 0.05473404424265028, 0.07373553370275805, 0.10381471966543507, 0.2009512517120569, 0.21898404214411013, 0.16602364849419365, 0.109463085931155, 0.11149852791981352, 0.19472770663278718, 0.16496785676046727, 0.13844921764346863, 0.11166860709988302, 0.14502376888788518, 0.29792779395657204, 0.1254663409124459, 0.09120785420940769, 0.1140682855921407, 0.2220550434844148, 0.1898909492358085, 0.06072191386333397, 0.21072648766060031, 0.11538040268445209, 0.1592919266512317, 0.19636849842725262, 0.15036758456018665, 0.18828522894651661, 0.10248238551280192, 0.12895873657638027, 0.2560112625360489, 0.11148833128954135, 0.10028912941174162, 0.1383714137538787, 0.10474281220306313, 0.15711111947894096, 0.251222615460715, 0.1107239670630905, 0.08392112464794228, 0.12147937420635455, 0.11302749385997174, 0.12758640497322046, 0.2018803478248658, 0.21265388826929757, 0.168099440333824, 0.15388000576246172, 0.147046378903812, 0.2665063913070387, 0.12778756434037802, 0.20434480671200062, 0.3034912470367647, 0.1242844051411075, 0.2180596957764318, 0.2766872708114886, 0.13478212328928132, 3.2440192949387336, 20.40077482500384, 64.58662194590416, 105.75852963232227, 107.35458127913937, 96.13200556847357, 78.26993188550396, 68.85028931402391, 55.6319018333189, 39.06058603717435, 67.27137842485982, 53.885019363895545, 95.73732883699479, 94.31332803541615, 78.74968482602027, 94.29868974993306, 82.32017917017784, 70.81764036609282, 58.194703978876916, 45.83566465685445, 21.89421138455791, 10.287675838316641, 6.021589838689374, 0.652665604026087, 0.6346154693634279, 0.33434154646050546, 0.23388842060681314, 0.627676735241567, 1.2400380858490545, 2.16692614939905, 2.2478787216448017, 1.603015079613655, 0.7123762741684915, 1.0127998600083015, 0.502001237004034, 1.7595544217094299, 1.825661435723305, 0.8406538972931524, 3.377081780664383, 4.398220844807164, 4.536767784626254, 5.518747375857446, 2.0798215846861563, 4.222849713217828, 1.8972135575548297, 4.644679052214469, 1.9489053708891717, 4.072782281906375, 7.455675544277315, 18.500392360071984, 37.16756389987084, 42.72775111659881, 53.08304371372346, 117.20740256770965, 117.92313314253285, 78.89444381959977, 57.51376482748217, 38.41221824769051, 37.103178193492276, 55.60460605928975, 82.2008292905746, 90.75058429471909, 104.19333134928058, 103.15132233404346, 107.3278699382659, 84.06175859512823, 36.87891667889011, 3.0001398007715903, 0.1784500542787775, 0.14542539814306846, 0.19419850841645273, 0.1539167320175517, 0.18705564250628795, 0.17186722928477874, 0.09022805839776994, 0.1717775203888455, 0.20252245207948072, 0.12057010444902605, 0.07581156302964495, 0.16196474613201234, 0.14657328896705182, 0.159986890972622, 0.11672225164910478, 0.2210995633034937, 0.124312627820238, 0.14413771159466238, 0.22310950222515294, 0.14783866703510284, 0.20479609378643576, 0.15078707898576416, 0.26182911809413667, 0.17667392539160867, 0.11715144474780369, 0.16395632958700582, 0.17130951727590255, 0.1421973487782863, 0.10584088432933055, 0.10918828253183635, 0.13691837478789592, 0.16464438379531907, 0.1355292581983151, 0.16640575782906625, 0.12483774278793605, 0.1508448113717379, 0.15709847902819035, 0.2537918445323744, 0.2612511200770255, 0.15901828004467874, 0.08874611493440406, 0.11224374760903659, 0.12244540341799298, 0.1133829816394756, 0.10104350385165985, 0.13188981961819435, 0.2056062011228454, 0.09843375638968523, 0.11383392397434482, 0.11764064551361146, 0.09337602859182705, 0.1098579889343631, 0.18996901359529267, 0.16376303028195136, 0.13214100452680744, 0.16429602829439027, 0.2974025334321684], [0.027933948252710606, 0.028980110261228778, 0.05552938906475902, 0.0062383458979668165, 0.0417225388058972, 0.05466140378567, 0.012114593635253128, 0.018393522083398797, 0.007178909868197216, 0.06806052289903164, 0.013713860591392846, 0.04935471273417916, 0.024183289027742805, 0.025797878699978034, 0.03035987866291356, 0.017235652964201667, 0.03423690217577162, 0.06762755298686605, 0.044003052321533044, 0.0661247106449258, 0.05329070778022851, 0.017780312750067924, 0.029009725305161653, 0.0400394972624077, 0.043606996355998906, 0.02074319035595944, 0.0783544310158299, 0.07012567377739376, 0.07374504085389838, 0.01679880281669959, 0.11076574183760152, 0.08551418150384581, 0.08030808545769223, 0.05853812660901778, 0.04149802907880756, 0.028457169068015875, 0.022987594317284324, 0.13509928368993346, 0.05822948510608366, 0.03246584096022191, 0.021686685091305166, 0.021969277689593936, 0.08451748579259842, 0.06278362883735569, 0.025292705000949003, 0.0484177450679483, 0.07749425217268929, 0.04743905625336113, 0.04483450286751313, 3.620240539312363, 28.647469858969416, 55.82146213900659, 71.91071079623315, 84.61694655879852, 78.6021174153974, 74.27296607725083, 57.932148364282426, 21.55072746738311, 24.793072400554536, 27.86055022670377, 55.25061215123823, 60.50274818174301, 46.8211248613173, 31.734979229588664, 30.404927038377334, 21.721342725138513, 15.639832308215482, 10.855681127117528, 4.3457748332331265, 0.9780143814221506, 0.2313375163583025, 0.07975611144736891, 0.03725104447033617, 0.06410719894413507, 0.135218471649193, 0.15034809528339296, 0.06855860262388183, 0.11727271646621729, 0.15089653762838534, 0.19716360576210484, 0.14440211918084853, 0.022230605602324493, 0.10880061139863346, 0.10041053902598158, 0.14201855917851772, 0.07186339101603917, 0.1307708562742318, 0.0449135669717385, 0.043444421007147724, 0.004699846472395885, 0.09776467817925638, 0.021396121348164255, 0.0725694636123315, 0.06127548516697942, 0.07599521728773272, 0.15222199231145844, 0.022567745576041843, 0.0992953984607612, 0.06413668949878024, 0.04257862290908252, 0.034943920890650446, 0.04295513597166827, 0.8810446880036785, 2.864475803029153, 7.550976391761535, 24.051593426735174, 67.25477895429059, 110.21412249534362, 91.64987394886633, 57.27526510915449, 28.217897761252623, 23.57674933248951, 52.320491806153335, 57.750981930763494, 70.3932712924096, 75.29018571299892, 85.1554173807944, 76.09468736956197, 42.92710558060677, 14.175700756811327, 0.1495179930521596, 0.20143161948409774, 0.019858006402970325, 0.018569149655259905, 0.06675665657366477, 0.053588677678377404, 0.011127047886651371, 0.05633455896449666, 0.039959433413441145, 0.033337806066077565, 0.014485551491229525, 0.016031608852978437, 0.07708396612396164, 0.08210427052671872, 0.016217686821736636, 0.11673679199790764, 0.048941347011995893, 0.060621142657774116, 0.010404381825919113, 0.03570910483118027, 0.03397548999336939, 0.017187274511783354, 0.041008395473322565, 0.016301433638399167, 0.06478009610286643, 0.025355627632609783, 0.02893296137992894, 0.016332940919505014, 0.0837405807068271, 0.027420259486403198, 0.09265190696403866, 0.026130412570050648, 0.08361541726175817, 0.03327401009418311, 0.053504691459238536, 0.058801051815070456, 0.05371371854937846, 0.028298092825758844, 0.01341041316458535, 0.10064822546536885, 0.05561181629497198, 0.04713433329015971, 0.020685103654320684, 0.06152590398766822, 0.04712824289116168, 0.011468681923654533, 0.08690563466159568, 0.01970389058002301, 0.02531959851753087, 0.03456473801164858, 0.034360468327518434, 0.03202699323845727, 0.019098349786814184, 0.02748445382401828, 0.10127539866633954, 0.04055849501803037, 0.062307371127028624, 0.014621429633529437, 0.043533961363737626, 0.03193032060329232, 0.004778527053854158, 0.025331356051948764, 0.036108190674454935, 0.04054644828542106, 0.07251917760098174, 0.014440326448229533, 0.031936617846029906, 0.06194626409260016, 0.03121065760722324, 0.01721545122563839, 0.06490306853647194, 0.026935890820177815, 0.07811798563887996, 0.024712257417699984, 0.03260879296689265, 0.07781041665903984, 0.061467524257398425, 0.017320072023017753, 0.0634774363659803, 0.017707655056109353, 0.020726784583060973, 0.02724715234381297, 0.051327768352723895, 0.06134719099669207, 0.0405993236739549, 0.040681478942954735, 0.05397878114073988, 0.02693147432329434, 0.009481060100839505, 0.07255612602156979, 0.04996468343081013, 0.0437683574554901, 0.057039095554500825, 0.06840800505972679, 0.0731776454936593, 0.034216095227748156, 0.038783319910327275, 0.06648158504357261, 0.053602578343763474, 0.025616333098901857, 0.036703984914047104, 0.018925932123355808, 0.06227398501528848, 0.0802214945396108, 0.10008789343579162, 5.227650634704098, 33.375922403027936, 65.6074187832494, 90.07402250843664, 95.57792371319186, 92.14859547153597, 95.95130197463497, 82.76507792934295, 36.910527060108805, 31.411248368601647, 41.4241200108682, 42.355882967672045, 50.96146114410893, 42.44110822677612, 44.26133901842179, 39.65131459697601, 31.946047852116248, 22.4164024091536, 16.17619485624375, 6.890340899267505, 1.9206462872605172, 0.34566395825916724, 0.12793431614315318, 0.0643154561159111, 0.025417401132384138, 0.09511796697493523, 0.039767352188186306, 0.24068051017820838, 0.07392271196529751, 0.04489742932961353, 0.07895506693110352, 0.08024064673771782, 0.12415800063360123, 0.10722272308363069, 0.3362759797563476, 0.6581433165457942, 0.41909314872276404, 0.07644954573122725, 0.07380501021661105, 0.09173623271166317, 0.0907683878716442, 0.056412546715188416, 0.050930976942782445, 0.08987571923963486, 0.04295061222247539, 0.12380969109794787, 0.18074620364894792, 0.025026995065291564, 0.06757113061124279, 0.07246090129258172, 0.04074512169726434, 0.012694015618293517, 0.05976373705291941, 0.4523163901702051, 2.2665369462582374, 9.019297034509721, 27.995609198847127, 56.27995191081878, 73.5472805269303, 67.24680869810044, 39.970477857897365, 37.739112069529874, 42.12526721339072, 72.57733329649895, 80.89021636593728, 80.65408183682351, 88.17256727526265, 97.27280339887066, 95.39767511429326, 60.93971198604953, 22.928061869836625, 1.1264027318646832, 0.19405897316192428, 0.03776734176602575, 0.048518374547242164, 0.025370390146910667, 0.04298514746610196, 0.032707959218251134, 0.059077617216614954, 0.05667075281962753, 0.045172937529822516, 0.05508781598520376, 0.04053202284980686, 0.08692316275330321, 0.07001049245797819, 0.08610570863369973, 0.06835008115177194, 0.020241284021927465, 0.01904777840771262, 0.01058259685974448, 0.03554487473241264, 0.04933825716556561, 0.03416826069775609, 0.07401608276150881, 0.020965183484217813, 0.03049262063277345, 0.036103379642290455, 0.021859790318675583, 0.055526497082844864, 0.05945502660207211, 0.05120767640971369, 0.04166312485692963, 0.013113478442744143, 0.019042860123238737, 0.004957016921722361, 0.023962207544114322, 0.06421560038542075, 0.031776882768157995, 0.08446465636934004, 0.008898727941296754, 0.0576012623646567, 0.033750819387815656, 0.014222665547182965, 0.007598422009557967, 0.03214545915984819, 0.022646187233828732, 0.052124388711226564, 0.042718794016588124, 0.012641651593449136, 0.008564094032701707, 0.04120385131588386, 0.04963075719593514, 0.08077906865266063, 0.021498759893039544, 0.012612837111397136, 0.07684044975547061, 0.08586285876170283, 0.13504000380635262, 0.07079286741152888, 0.06582176883614833, 0.2128980864560412, 0.12745301374384474, 0.13002658653403484, 0.09890311547825414, 0.13922901854159372, 0.16859638624854628, 0.12234676193686263, 0.07860370836551152, 0.16438204464652847, 0.11087001406497533, 0.13646506524134067, 0.13054125972332495, 0.110607904742562, 0.1956261285851079, 0.1223060750072041, 0.19559514798945, 0.20942727914981304, 0.19427847267398912, 0.10005034746662264, 0.1644318403616067, 0.07949161193063183, 0.09504768606876174, 0.14078292064368725, 0.2048307669258887, 0.13828679168176267, 0.14468998437927616, 0.21951725466116784, 0.1860104840729506, 0.1645266054378402, 0.16655686101125133, 0.18883417690953902, 0.11971663653610215, 0.20292308542036241, 0.08929933000716472, 0.2988821556491237, 0.21836715750396254, 0.1414059646307461, 0.15805152304951223, 0.2338153204970783, 0.23874072958865475, 0.22676591731367574, 0.22024300039535571, 0.11965972386420735, 0.18004609121670648, 0.186808594472466, 0.19035303814997598, 7.81120898262147, 44.24362951709379, 83.72084971397155, 98.53879544042773, 107.8570447429534, 96.27634879081481, 93.67811587549026, 76.52250812899682, 32.706566010752034, 37.43215914695494, 39.87872185245637, 76.13919842627742, 88.55568085947345, 71.25831865495252, 53.197600456976126, 47.48213837223668, 37.82864801345333, 25.773904208214056, 18.158648014068604, 7.960582644708696, 2.316803590905282, 0.589052114275194, 0.31886133034863784, 0.25000508724441456, 0.13986300226421128, 0.3306089209452752, 0.45437989395953, 0.6353780639267738, 0.3298683590706318, 0.32337959435197616, 0.35696724850323897, 0.34554215027920665, 0.2865528898133386, 0.2328342836230032, 0.5176815246382068, 0.611847703976016, 0.4081039238841303, 0.31128959309670234, 0.1797510554353076, 0.33935657251746426, 0.16290288208232773, 0.1607264416112054, 0.16909316362392518, 0.269009169912146, 0.3285043548432089, 0.2034450364449332, 0.49575391255559464, 0.13419854815208143, 0.3323263674974442, 0.11732484108858532, 0.17865381834487762, 0.26513408268651656, 0.24127114864607013, 1.6012545482766245, 4.408857332121942, 11.144925528956998, 34.085408564536806, 89.18635875948014, 145.3297611974901, 122.4442138979512, 74.42494223194738, 41.58142274425876, 37.88763261610462, 70.46880829718806, 77.67095458122992, 92.26483883396273, 97.097606812754, 104.85068136645903, 106.27294063568117, 77.3749097701042, 30.3022962616336, 1.9847894195587406, 0.23371241956708894, 0.2517992498413209, 0.18996414127609423, 0.14778284986893978, 0.133049109830491, 0.1298957540383262, 0.21073436304446191, 0.20557947997604648, 0.12807130032489378, 0.24987040898732601, 0.18125316999371976, 0.15582202332875422, 0.13849348220373356, 0.1691752269623741, 0.20156139477847085, 0.15407649199328116, 0.0848312754063837, 0.13984095425375048, 0.09871633558143532, 0.08470943678290614, 0.09438398579556136, 0.16883281630373773, 0.10233974760218013, 0.17676807759750277, 0.10288700251088989, 0.16243215169637434, 0.15870271310690912, 0.22708813389462812, 0.11701742532633005, 0.23535491207674628, 0.14444604666242677, 0.10732637477978584, 0.09254935077361523, 0.24651376410357415, 0.13291020276806048, 0.14972641493283934, 0.16821182543231597, 0.20563690592685055, 0.30722954160263466, 0.09256398305296899, 0.1752104676298557, 0.11038362484184966, 0.15855442912828538, 0.10627010041066717, 0.14299665427496358, 0.21865779594067605, 0.09074349767498432, 0.2673099868960919, 0.12748731916109401, 0.10786085900279785, 0.18011130062082123, 0.11137045334063231, 0.09819968588530056, 0.2219271527663354, 0.21159297906823699], [0.016812954375880863, 0.0694204208951804, 0.02564368626823829, 0.03585165847213038, 0.027681206270391424, 0.03988179423275494, 0.04593112325716404, 0.09401704500158949, 0.050217396684832154, 0.056098194026778785, 0.013702298409395642, 0.006883991394011725, 0.03498829270322477, 0.05991687036810383, 0.021468309813269207, 0.02677011322380314, 0.05170700102744084, 0.08797038196315689, 0.051794970903785965, 0.016448208423812064, 0.04471767062862073, 0.05575850298027358, 0.17694225534796718, 0.024519693557052843, 0.026835359017094298, 0.03345526649706787, 0.08340376249003796, 0.06692046915451366, 0.04971390837923654, 0.03216613587292452, 0.11973067126687496, 0.0366091815334174, 0.028399545849571307, 0.018789486118382024, 0.010314191252203479, 0.05715983484180705, 0.07089096497023298, 0.03927435545671371, 0.09053795628489987, 0.02397290787719671, 0.039747376445560686, 0.091259166778576, 0.05810002007731988, 0.0311699515253666, 0.06831199892105595, 0.12397728815314271, 0.13045407891754182, 0.27938966128614645, 26.344803225609567, 70.1272169236214, 70.4555977544477, 79.19093578092514, 83.28953804508333, 66.66501137518114, 46.42345143902687, 24.828658103942875, 24.146134314998505, 43.85229464500181, 48.3026276096221, 96.63852476304578, 69.68473434448242, 40.35935340389129, 28.581858411912, 13.457376514711688, 3.738075158288402, 0.7797250860641081, 0.40036058293715604, 0.20807787655822693, 0.1687687407097509, 0.05432171656960442, 0.13263615779578686, 0.017625980507282, 0.012280221844482566, 0.07745988546840607, 0.09311571957603579, 0.08322144122493845, 0.05984105447667742, 0.06523386530217624, 0.05090171621451455, 0.20205254906848555, 0.07848127219345301, 0.08536118608448776, 0.04543652157149008, 0.1269510422923392, 0.11700057905287513, 0.2924533909366977, 0.08253807547472178, 0.07039668504148722, 0.07753623379093987, 0.03166085109114647, 0.06382835443101584, 0.10957427593248506, 0.12752204592670166, 0.07796807755385676, 0.041263950913543665, 0.027588398548804467, 0.07430015582471125, 0.02821241738274694, 0.012283940243745043, 0.008977793960741932, 0.07468211960287825, 0.17228843974730662, 0.044502867235531735, 0.005994288958684211, 0.06266965410642086, 1.4011429442513375, 4.692203469814793, 13.14781423537962, 39.13474629002233, 86.07306372734809, 83.16390452846404, 52.0590187657264, 27.0937248968309, 21.939967793803064, 55.395845751608576, 69.03161264234974, 72.26614029176774, 77.66576920786213, 82.2023747044225, 80.69561189220798, 46.803023122972064, 15.697276399981593, 0.7751704175626078, 0.1838067402282069, 0.0781951460146135, 0.030264814812389594, 0.01967242351853319, 0.03455394766323509, 0.02011174813003069, 0.04735890047384366, 0.04058793194652085, 0.12665336350760154, 0.048395850275072365, 0.055206023351920236, 0.06484584942940744, 0.043297584934700886, 0.05597992154258875, 0.06336605867310878, 0.0702519633717114, 0.03550255986591501, 0.02526737238851286, 0.038326819607567404, 0.060716765752482804, 0.04829802467758137, 0.05302056602592911, 0.027319915374861132, 0.008975814581067573, 0.06130507148261513, 0.0880166843173004, 0.043789076303402265, 0.026623719567132574, 0.018974561469569322, 0.021915812413358403, 0.04873711946270159, 0.06141115933836949, 0.07230301057138751, 0.031105439261262937, 0.046393794398153984, 0.056627212212451046, 0.025486425654361808, 0.024055840725439693, 0.04529201440633305, 0.02391527316743328, 0.010645750275392447, 0.04192663612024438, 0.021728613083401037, 0.02001237503493265, 0.024093040039822943, 0.025263028669982188, 0.044543190273426236, 0.01568787094701322, 0.037141279392545266, 0.1311793803207336, 0.018695546501886942, 0.04740994491223847, 0.033698131690823266, 0.005890177609774495, 0.034332161378716274, 0.06868362051224516, 0.05303034896872217, 0.027748861410204443, 0.005119354304512062, 0.07187753299912138, 0.10825594586710777, 0.02178365458554078, 0.009132729497768227, 0.02394641081111566, 0.0535344309924591, 0.07075634800017842, 0.04159131943578682, 0.004375738133075497, 0.0264711320895942, 0.029158871132700197, 0.06157851507586818, 0.026974846391127478, 0.04160804313517386, 0.0404778910770772, 0.03765933102958145, 0.10447648173618702, 0.0229391603234915, 0.043848995870399865, 0.02958470302063131, 0.09749853157348211, 0.02064740255234703, 0.01388383347676286, 0.04794130349651941, 0.08418275133496331, 0.1124982496783618, 0.04783342682546185, 0.023370644025083993, 0.03375326703873373, 0.05662374183415406, 0.015739719777728523, 0.033561070900290244, 0.06435101791735619, 0.02547853686396153, 0.004760161053479439, 0.039639331235159794, 0.04302557009542662, 0.009314458002336323, 0.0585496217583216, 0.09975409360542413, 0.23523880379094234, 0.06315713500483863, 34.14398916306035, 82.7405317368046, 88.94937699840915, 92.12754018845098, 91.5073585510254, 81.73689134659307, 75.73217407349618, 48.194115238804976, 43.31948380316458, 39.160422125170314, 37.0725993956289, 52.39033352944159, 62.053751407131074, 45.807658933824115, 34.1973961553266, 18.629836459313672, 5.666585430022209, 1.4120542426263134, 0.6518425191602399, 0.06171453398682418, 0.22273673916295653, 0.07809805203109019, 0.03335408926490815, 0.073169180222096, 0.3222055492862579, 0.0931649943513255, 0.15099087369538125, 0.26316676889696433, 0.10636731696825837, 0.07554844247117158, 0.35446358123613947, 0.4211909426075797, 0.18040523323560917, 0.3509134072209558, 0.22995060610194362, 0.4435867876295121, 1.0157222096477787, 2.3376529495562277, 0.6439236215045375, 1.016746132123855, 0.5288260201773336, 0.2531149445642387, 0.35934190656388965, 0.4604000886601787, 0.25796058858113907, 0.05516116507351399, 0.02667265151807618, 0.05114757681205388, 0.14479637867020023, 0.1935961488033495, 0.05353500172796269, 0.05699313410948362, 0.06659997627139091, 0.08303543507692315, 0.019685663433084567, 0.08326873183250429, 0.040845582637214856, 0.4677180669480755, 4.848427551407968, 15.310770946164286, 37.32628653126378, 63.38535293456047, 56.58804624311386, 42.72086343457622, 42.63661092327487, 36.23027432349421, 71.95357445747622, 85.36674684093845, 84.88329118297946, 85.65748076285087, 93.32823261137932, 97.61746206591206, 65.51410167447983, 24.696285955367554, 1.4858057109578964, 0.09292671036335731, 0.03663735441683281, 0.015110588264501384, 0.06276433108254306, 0.04028318217024207, 0.09550628162199452, 0.021777248175273982, 0.034448744639033274, 0.07369216546536454, 0.08837155922646485, 0.04616876756171546, 0.018661290880352743, 0.02817348096399538, 0.020471324903830405, 0.06863066085403965, 0.03196755439163216, 0.030470088071700548, 0.015322809941285561, 0.02923035479691481, 0.0352484178579142, 0.093502517369005, 0.05105497210376686, 0.05548809309520068, 0.015962963544523284, 0.013674815962721985, 0.024222608490456498, 0.03187586515841465, 0.061707194864509575, 0.03685685775933727, 0.05622623030156378, 0.12316581718022786, 0.03645555792196143, 0.03445528319946701, 0.013962160221361106, 0.007611410072704237, 0.010330839300407998, 0.04181509371846915, 0.020404558426009554, 0.07146631232312611, 0.02517622516250178, 0.001644099977584706, 0.022257709793085535, 0.03923704314436163, 0.042764801426880786, 0.06560369424762265, 0.07472868242691602, 0.018932281077028285, 0.025595459118185025, 0.037447358331372665, 0.029972190292732372, 0.007307669617265704, 0.05252695259367747, 0.07214980064741067, 0.13380969724347516, 0.29330620001400676, 0.12021457070424674, 0.1635813601915875, 0.14931553133553074, 0.09659637111209093, 0.17665979873028495, 0.1891517969629457, 0.1004247882613732, 0.24932529146392501, 0.12378551336305758, 0.1265737133461141, 0.164634884305058, 0.1036024290407377, 0.14872432596260501, 0.17740276612101064, 0.2870386814878833, 0.26521712661750857, 0.08932763695596688, 0.17843721464516657, 0.10854437030972013, 0.10238817201987391, 0.30506920429968065, 0.18078887474633035, 0.1473311797505425, 0.14524584245537558, 0.19319156244877847, 0.16821484381873764, 0.14538314073316513, 0.17704926250923067, 0.2760903351008892, 0.1564677894836472, 0.2045842857971307, 0.11793237945605671, 0.1471604953610128, 0.11232971033502011, 0.13479530000157897, 0.19491280879705183, 0.15911160487561457, 0.10401347351651039, 0.08964450624320777, 0.2285653352737427, 0.2246522807305859, 0.12930077951281302, 0.27114762774398254, 0.22342591185963925, 0.37283007956800923, 0.8320066645260781, 44.89372707182362, 100.33662949838947, 99.91962663588986, 101.10574353125789, 103.24658101604831, 87.22568358144453, 63.32155166133758, 33.369434802762925, 38.34165480829055, 62.073747650269546, 74.41619534646311, 139.4273158042662, 98.30344538534843, 61.58698935662547, 45.219581896258944, 21.60721548141972, 6.845638627006162, 1.7642725427304546, 1.2543179647576426, 0.7311406479247156, 0.5135370808984003, 0.24324468306956754, 0.3111618096309324, 0.27297594254055335, 0.6442555520803698, 0.5048941075801849, 0.253277539065288, 0.22881089709699157, 0.2208028421286614, 0.14556447374484233, 0.2747230520171504, 0.43512032096905096, 0.17269834275207213, 0.23802436077066008, 0.317802811341901, 0.20228009250375534, 0.453453571085007, 0.9144944156850539, 0.2846063523282928, 0.5659092109530204, 0.3315495849857408, 0.1646213705140737, 0.30304572094352017, 0.483682910280843, 0.37548291947572465, 0.15845756497113936, 0.15419862173016996, 0.17475378729643362, 0.37159799568114743, 0.2575456447178318, 0.3229618006415906, 0.24354368718641423, 0.1768672400184216, 0.3058411757792196, 0.14929351396858692, 0.17211136618448844, 0.3155586333765138, 2.1865907071098207, 7.564116331838793, 19.05660406235726, 53.19687874086442, 111.04084830130301, 109.55883564487581, 69.55586879484116, 40.083222466130415, 31.57894538294885, 74.22021019843318, 90.68445313361384, 95.70946431929066, 96.81055207406321, 103.70135630330732, 108.77492643171742, 76.20452157912716, 28.80147387904506, 2.196626091195691, 0.3808539312693381, 0.13165409436389325, 0.16129729968886222, 0.1048462187510825, 0.15542993952910747, 0.2535850774016111, 0.14342204757755803, 0.1386017151056759, 0.31184267793451587, 0.2156886076855083, 0.11145846152137365, 0.10737365006559318, 0.19622559238585735, 0.19547134818088627, 0.19571485688849805, 0.21173455211664402, 0.1536574878639752, 0.1244886824861169, 0.1163865902250813, 0.0976052706039721, 0.16996299517491173, 0.12882706138395494, 0.111533944164553, 0.20996089003259139, 0.11752294376492502, 0.1349270671245552, 0.14974893791781319, 0.23755199095654875, 0.10335245455104498, 0.18480807843227542, 0.2784279757930387, 0.18775293573496804, 0.21334552776909646, 0.13946267535849927, 0.22965875724630974, 0.13824442701954998, 0.13775288968557312, 0.08591571116759893, 0.08214983743645492, 0.0696151987499287, 0.10965227134405606, 0.19345779332422441, 0.08587661003994365, 0.13755842592687378, 0.2358570980328706, 0.1806683844375995, 0.12170466534312695, 0.09805407555353257, 0.11587667444180097, 0.18688397752421518, 0.09539392716701954, 0.1516924570164373, 0.1645503541634929], [0.04147744046584253, 0.03674441137381139, 0.05550447971590104, 0.015604415243761915, 0.03028190431876048, 0.05310726802675955, 0.024623789584204078, 0.04619823130328329, 0.05652859371395842, 0.06970243318186653, 0.04019027102678534, 0.07124280617121728, 0.04814707854342076, 0.06068596901792673, 0.042284299589453206, 0.029074090097339887, 0.020403162230767553, 0.045121395134276925, 0.04388080384101599, 0.04552189440977189, 0.061452796217054136, 0.03956475640617071, 0.024921428149325714, 0.09354248417601471, 0.03721587337373245, 0.009551390802728073, 0.018074017453698382, 0.016342367631413283, 0.1068186576688482, 0.06486724626513259, 0.016901519885587118, 0.06107580817995533, 0.007632794459500621, 0.02196240971135276, 0.03735121812731509, 0.03107979638321746, 0.022663648292842894, 0.061858447433839885, 0.01804786704240307, 0.020734621662526362, 0.05682718031288636, 0.06687707027360316, 0.15830753431204828, 0.06257329173686524, 0.13585297631159907, 0.12551141752591058, 5.426883505236718, 37.38437291114561, 74.97730608909362, 76.10220263081213, 91.34868298807453, 74.45727825164795, 56.83594396037441, 40.56193597855107, 17.39121275563394, 21.34658378939475, 45.440544697546194, 51.520987249189815, 42.61365721302648, 52.763700023774184, 18.270529700863747, 4.390900231176808, 0.2552927639936247, 0.2163023973304418, 0.14520171579093705, 0.1452448618628325, 0.03005256632252807, 0.0608479698008347, 0.06944113591265294, 0.0757557688461196, 0.12097612338801547, 0.11500998385130398, 0.07172145790630771, 0.015182924201531757, 0.07939061855957394, 0.15625095595755886, 0.04808216408315686, 0.05042532060836112, 0.1464620530004463, 0.07633428014214001, 0.22258542147615265, 0.18188162256152401, 0.3072517275089218, 0.5116946087969888, 1.303921361123362, 2.7195486378285194, 1.1270409750361596, 0.27012732120290883, 0.1928203928494646, 0.3300335889141406, 0.1062129425906366, 0.11183960558546167, 0.08488402055997042, 0.22032748457164536, 0.10179847584015901, 0.19446944307175376, 0.01901650478342368, 0.11969199148757804, 0.07999796540506425, 0.09098703702611309, 0.045567315762802485, 0.068617514785259, 0.025976020955450596, 0.029611738263479168, 0.041754281659039764, 0.07490077641822639, 0.06884613074362278, 0.07258126902724467, 0.8585422341862033, 7.638316788981038, 45.25437331968739, 79.51752801095286, 73.8348687079645, 45.847969132085005, 24.653434061235, 32.01494428419298, 48.773084532830026, 78.56279173204976, 76.22598478871008, 72.11296389179846, 84.02757121670632, 79.86250831234841, 53.34443830674695, 12.342060362139057, 0.3364202800777651, 0.10665094570046472, 0.045293764917240034, 0.06695884249864087, 0.1523514918141788, 0.06596589295734322, 0.057097823854776165, 0.05318263192631064, 0.03267655727423487, 0.10446034026362243, 0.01589124430827196, 0.027441313497782237, 0.027611779552253506, 0.031182559417380445, 0.04998840534338548, 0.07333287788975625, 0.07862397905198798, 0.04053362014312898, 0.03636224075190483, 0.047074187727224444, 0.030144529432178508, 0.015682642396930006, 0.019560128435372345, 0.11944249197239838, 0.029917246466802976, 0.04438040041995626, 0.02003247909728558, 0.04258520360435209, 0.04415509779186499, 0.07756635636812256, 0.041843787541673075, 0.0058480920908491945, 0.019709214891096758, 0.043528598748267665, 0.11620049214651508, 0.08265113473058709, 0.04879377932558137, 0.05123548540136507, 0.06686182512391, 0.059158489288341616, 0.01364471158012748, 0.04475489867130115, 0.02542693892704143, 0.057377350186148, 0.06559972591217487, 0.010678464144979034, 0.058827600592086395, 0.051650134320821495, 0.02730579637441664, 0.026373963412498275, 0.05955357232221192, 0.029918613933747815, 0.05830137479689814, 0.051587667511475664, 0.0213585447354783, 0.033876618685861754, 0.07743517913284802, 0.09646937671688297, 0.0019834572970378966, 0.01695725086685871, 0.049579402491931, 0.019261047709733248, 0.05829641820802804, 0.030537032664963798, 0.07200294925320534, 0.037588360644276106, 0.0393525117467488, 0.08933265483187092, 0.030746082737741452, 0.04963291756388161, 0.01707302781963541, 0.06278516101320425, 0.0710331968542549, 0.04972852916727143, 0.05533878255875842, 0.03210096668842579, 0.11624564536877217, 0.07082187916122137, 0.027755771523281455, 0.01727193488829559, 0.06402670608593092, 0.04588752519339324, 0.021378307888704925, 0.00788622304812194, 0.11446189390675676, 0.07373890448962489, 0.04944756642104157, 0.06481207261282591, 0.05581392178071603, 0.029520307584936102, 0.01857295328180396, 0.02025113591263371, 0.04961866832848999, 0.1430027829783578, 0.15163461737815412, 0.1297074189830211, 0.15266814659680092, 0.0449366913357329, 8.898592956604498, 49.75852512544202, 89.57119034182641, 89.96425105679421, 97.54911084328928, 81.23508684096798, 87.5441800394366, 61.50010885730867, 26.241103602993874, 20.807634438237837, 40.448324526509936, 41.36342133245161, 47.34658910382179, 54.52065121742987, 25.096781522996967, 8.166301154321241, 0.828096122751313, 0.017423239168560794, 0.19499384557768223, 0.14784893261328821, 0.04649394507249517, 0.09011766512788112, 0.10604735268580337, 0.12290615933917223, 0.1932807657266817, 0.38009164314116206, 0.8916561089215741, 0.40722892890053414, 0.36987488007833885, 0.8431965737573562, 0.9017176012839041, 1.0476411710823736, 0.7361622623378231, 1.1759914193422565, 1.777094280527484, 1.7640533802970764, 1.6342083412793376, 1.3164723328044339, 3.358653259854163, 6.738938881504921, 3.4358820319175725, 1.517924284262042, 1.4924907780462697, 1.2187340999803236, 1.3899719114265134, 1.2582464636333528, 0.2902451578167177, 0.8969720236716733, 0.46315849548385996, 0.60033603781654, 0.2608627134994153, 0.4293839158790727, 0.2879089880133829, 0.11645434304110466, 0.09549379438882875, 0.034844697182697636, 0.10840982994845799, 0.016842768602674047, 0.016978345097853773, 0.05880614629976692, 0.020570039163313566, 0.08370534066231021, 0.8582456049419219, 8.292445559655468, 35.39290712725732, 64.86476505956342, 56.527453468691924, 47.83930547775761, 43.02250939030802, 55.80506270931613, 70.88952172187068, 96.02466598633798, 86.77734882600846, 81.50048225156723, 93.56553600680445, 98.14615834143855, 71.6063819393035, 23.21998034754107, 2.547757894762101, 0.10859198267421416, 0.11826169001118791, 0.10619376740989186, 0.12534079442341484, 0.04669645275439947, 0.04505758001018436, 0.013889801301693004, 0.05499448349338867, 0.0653060537672812, 0.017254178885430578, 0.07982620849244057, 0.06163815502077342, 0.1531874163136367, 0.04410822087177827, 0.05350270729151465, 0.04791162141989316, 0.030476664936530496, 0.005393643467311538, 0.06198828018480732, 0.030670105967850938, 0.03635808855535523, 0.022216088236159375, 0.04940240553790524, 0.022867307021853425, 0.0449217104863736, 0.05319794602391701, 0.05745212036755778, 0.03156989155667684, 0.09233216484708172, 0.06378512025900906, 0.05731976718731946, 0.03150477025267338, 0.027922284564063437, 0.08040407627460458, 0.1050172632019366, 0.007716323419909685, 0.06549916155035458, 0.026809051557774508, 0.0703189884042067, 0.011376126053472681, 0.04975494387890062, 0.02974405696976089, 0.04214956770621, 0.04604092663935116, 0.041951955326141856, 0.01292141158163788, 0.07631912692299775, 0.04405516928302185, 0.029164030734870224, 0.015259009181341578, 0.04240322324837889, 0.21082027214429072, 0.17533731646835807, 0.17412430817081084, 0.09863351381594136, 0.23752831883968847, 0.22272719370742, 0.11515794607299952, 0.09139787465814622, 0.09620886851823139, 0.12650527871183812, 0.13913953947203775, 0.1368298150238491, 0.16718123799129841, 0.13121488083514476, 0.12944270496166524, 0.16474777502157997, 0.15073435681481517, 0.1584057008186656, 0.16921635056214948, 0.1334673325501142, 0.22321830203215923, 0.12918153026651952, 0.09678109023239344, 0.23481292019207634, 0.266585911233579, 0.13522867594034443, 0.10814238865409168, 0.1316655550392405, 0.2642948486872258, 0.13518490167635103, 0.13391593831681436, 0.15755224822750016, 0.18248194438074866, 0.13622938595231504, 0.16903366923572558, 0.13176373686761628, 0.11392799957144646, 0.10560364222093936, 0.12989710235307295, 0.1146873535828725, 0.16757896019806787, 0.2766849112606818, 0.3232821786115247, 0.27304590168979864, 0.310209286549399, 0.15449287610188608, 12.087532858694754, 65.30967166346889, 101.7844783106158, 94.62676463588592, 110.50366401672365, 90.1183609808645, 72.89608078618204, 54.136451136681345, 24.734519258622203, 35.38348559410342, 65.462957889803, 72.62991659102902, 63.41213880046722, 75.1876235777332, 29.54652220972123, 8.329531569634716, 0.6457629066801841, 0.37740439056388797, 0.3622440621256829, 0.35802877057463894, 0.11840005315119222, 0.2710381078143274, 0.23444662291196086, 0.17421637661755088, 0.2064095362420044, 0.317281074821949, 0.5180232611394698, 0.3528463389844664, 0.27480906836928864, 0.6023658030936795, 0.5001409303757453, 0.5921833301263472, 0.5481042244261312, 0.6717073628979345, 0.7225370515258082, 0.8941520846659138, 0.7136825460099405, 1.5083764998182174, 2.4253429280173395, 7.905213977060011, 2.9757571220397954, 0.7522293937302406, 0.827524192150562, 0.8229755910654223, 0.7755891918655365, 0.566382346855056, 0.15881750372148332, 0.7093161512767115, 0.3035249549054331, 0.47382292968611567, 0.4830364852903351, 0.3648280766942809, 0.32222525306767036, 0.2512021762348952, 0.30246131843136204, 0.19044193499270948, 0.27591073344792094, 0.204404546248336, 0.14002850789937282, 0.1567585504944286, 0.16754848522044, 0.34551018909100567, 1.1833082331765084, 11.010639263737588, 62.275635965408824, 107.44136764157204, 96.40552028532952, 60.77241113108974, 39.05984078684161, 45.77418934914374, 63.76468143155498, 100.66930924692463, 97.48683929443361, 91.55029281493157, 104.89640835792788, 110.34072091502529, 83.29214249887775, 31.581947957315755, 3.3880935897750244, 0.28190212324261665, 0.17637145855734426, 0.27296687205952985, 0.265319935616947, 0.14088384506683196, 0.21945844975210008, 0.1410586356876358, 0.11391182745536489, 0.264675839533729, 0.14182080124174395, 0.19977846303053443, 0.18322279736880334, 0.18527191402691026, 0.2036123040823206, 0.217473883662493, 0.14043681744125583, 0.2136903286220566, 0.1152894527260815, 0.1553806034667838, 0.12937996236066665, 0.10654910197181088, 0.1350209741823135, 0.17567195899544225, 0.242842823988007, 0.10782479158332271, 0.08674038183544913, 0.0964908425005213, 0.1649189497073812, 0.1474084627003439, 0.12901297560141933, 0.14817969873547554, 0.15480579237543768, 0.08202582312327239, 0.19698132280140154, 0.15674140544668322, 0.16537765251292338, 0.19712009196800573, 0.15405726318638172, 0.1946223082561647, 0.16302904144169825, 0.14617251773034373, 0.08422494745783268, 0.22427173421507884, 0.19396722647211245, 0.14855747201269673, 0.09821520682664649, 0.21088646214094856, 0.19547804378934447, 0.07983348632772123, 0.19969871327761682, 0.1338684255437505], [0.07012372791406608, 0.017542515227931644, 0.04408102092002669, 0.015822084763297634, 0.0406989763911453, 0.041100559681053125, 0.031274239074498895, 0.023389704292640093, 0.06858401376033021, 0.01419940903302162, 0.041668954786033406, 0.06398184397708505, 0.029684447668372627, 0.035042409154195944, 0.05064345648392074, 0.046180936868392655, 0.056874785016501145, 0.03286527920394175, 0.01744901036633359, 0.0458914743766429, 0.030400559846912662, 0.04939321248281387, 0.049901722494753144, 0.06382208017091598, 0.06655624031179375, 0.054888939560060544, 0.027798298979178074, 0.05791659181516978, 0.04092391512747254, 0.011146927868286449, 0.016233546756989053, 0.006929433335655279, 0.014077890251252442, 0.025961417404393998, 0.1301702433415959, 0.02487590337442535, 0.04898645043853791, 0.07862927271954476, 0.01790148870749099, 0.03378083088224934, 0.021715518725555272, 0.07583493637221475, 0.34290153713476274, 0.2970972320725841, 2.811929771015721, 26.91085223228701, 68.91784821787189, 71.78821517575172, 61.95421734163838, 54.02152569063249, 56.232859934529955, 46.698284072260705, 23.176085102942682, 29.337383393318426, 48.38199677005891, 79.89955117625576, 74.40631881836923, 50.310445754758774, 19.730808504166145, 3.1646589598348065, 0.1253413460067203, 0.04414516163148707, 0.03980192573620908, 0.09090485111359628, 0.010276329271765727, 0.03388297338519366, 0.01716114899834558, 0.02088303587609722, 0.04344850042534452, 0.15218356534117652, 0.2049398884898232, 0.2170464066007445, 0.07975092503212153, 0.13912921260681846, 0.4805706627666951, 0.9272902290667258, 0.5943366500639147, 0.3612810283178284, 1.3282429979693506, 1.705527694955949, 1.6234343258603927, 1.7707290091822225, 1.0641085068064353, 2.3919164894088625, 4.465277685273079, 9.512042826221837, 4.63109637460401, 5.030615272060518, 2.445313430601551, 0.8075581635198286, 1.2886510837462641, 1.1348170739027763, 0.4959849646735576, 1.5302060832900386, 0.2880266591185524, 0.31404269859194756, 0.08395574416124052, 0.3503941834693955, 0.08963499909206744, 0.13587485578271652, 0.09209852335193465, 0.1723708554862007, 0.050349918404413815, 0.05485139742133118, 0.09115877861697828, 0.09785245653362044, 0.05883757888730015, 0.037029346285928647, 0.040357059859220064, 0.03343949657714656, 0.4011303174399561, 12.354903182675763, 65.79051502289312, 88.20769602252592, 36.4718609471475, 26.297499441331436, 15.516830701981823, 32.940755044260335, 52.07844234281971, 78.11684962241881, 82.78335617434594, 66.4172274066556, 75.85128861088907, 76.52063323605445, 51.5306794258856, 21.38514461055879, 1.9125828747787785, 0.37306355252381296, 0.12206232115145653, 0.17115714238776317, 0.06112930793014746, 0.0667195089702164, 0.02998269910383369, 0.029199921954122764, 0.024953977310008583, 0.04011047913903191, 0.031822030244755654, 0.020056338905687296, 0.035611669938530655, 0.051964264843733086, 0.01754688192910004, 0.011330182803043676, 0.04862249355703112, 0.04951740299621898, 0.06727435581025577, 0.08750836965778182, 0.07444675440990156, 0.03650769403564834, 0.05553677415234908, 0.019701439098665313, 0.03675213354008813, 0.004160301759839058, 0.05618013862159945, 0.02069217081542217, 0.030318697606543862, 0.02938845427706838, 0.08196299625260216, 0.04130711230719763, 0.02011089202677531, 0.023161720356813843, 0.03704541114970081, 0.04919048263541153, 0.04533289285797266, 0.10905925800362903, 0.04192573213649373, 0.04316285305145768, 0.004479355355274052, 0.019277612445876002, 0.03569055018165419, 0.03321453868862122, 0.06789130939831657, 0.01882642879331064, 0.023219448912348, 0.035510010070978634, 0.06549826522748317, 0.029840846433334296, 0.05958186011881598, 0.058253812228119185, 0.02935262434484978, 0.030820797377776717, 0.05343135769268679, 0.026000131657647512, 0.05378842744375429, 0.07743317964336566, 0.035626600992174885, 0.018979889611082695, 0.055095496016644666, 0.037747752897801905, 0.06011142222691448, 0.06338292409876181, 0.060233260850392045, 0.014313832883002057, 0.017323186170429956, 0.08434734532549497, 0.04423482839258448, 0.010081753472707445, 0.10440851441554486, 0.14530648597546164, 0.01486028722983094, 0.027538976301589323, 0.024927606648435036, 0.004046703848401986, 0.005027060340639325, 0.03405833091106146, 0.03664084394732791, 0.030058505419161052, 0.07687494669470095, 0.06043681424231299, 0.01843215206698064, 0.060595743012644594, 0.09196982058065553, 0.08526288934292332, 0.03401730307227662, 0.09285342639252063, 0.07085157272916648, 0.07893694895169429, 0.03037563709151601, 0.1147451242732425, 0.3386799943062567, 0.7081578263351995, 6.105024535809794, 37.51200683655278, 85.75995660597279, 87.20143548903927, 73.3255018726472, 74.57460418824228, 87.15655572952764, 70.39555411184989, 25.068230590512677, 40.330876996440274, 36.8173707685163, 48.77131554388231, 50.025579698624156, 45.219319097457394, 25.918674968904067, 4.6913503543023145, 0.41361338308741974, 0.17393494655768718, 0.14464228774511045, 0.12578651969951968, 0.030456369352196495, 0.12096397323353637, 0.28464857909467917, 0.2550220438429425, 0.6267190027621485, 0.8986177643941295, 0.5830693965958011, 1.3832744643572839, 1.396933505612035, 1.3218753977167992, 2.422919883843391, 3.4120884441560317, 2.7308629597387006, 3.620030692508144, 4.866529780049478, 3.097195173463514, 4.176646644069303, 5.183183214356823, 3.1581110531283967, 6.727554692376045, 8.148117536498654, 10.290688218608981, 8.962456987750146, 8.282827907992948, 8.072280960698283, 5.5500851523491646, 2.60513432564274, 4.2827751944142, 2.3745107266210743, 1.7951943028357722, 1.2618804170239357, 1.2795209091517235, 0.5593524789137225, 0.6500433157047918, 0.5931441882444967, 0.5098313603910708, 0.11230616845310697, 0.1748220304087285, 0.0520722947323755, 0.04953466295715302, 0.10084530924476924, 0.12227240544293197, 0.0718797393323433, 0.0400025220287423, 0.0377277082072631, 0.16020755493833175, 0.6622109369885537, 13.739083101672511, 54.20711655770579, 59.21537530037665, 34.61643472794564, 34.49117383649273, 26.46893055208268, 51.71071621679491, 72.07008454107469, 90.51795636453937, 96.36453936176916, 73.10708861197196, 89.21026168331024, 91.58272297151628, 73.20672465908912, 35.22879908161779, 3.5779667044839556, 0.45442815749875964, 0.18825239441808195, 0.014292009910869022, 0.05670622269052172, 0.11742090085341085, 0.013248234266234983, 0.03591662272810936, 0.01187571018348418, 0.04619402165013937, 0.06071766973623346, 0.06526294599978194, 0.02484177224217884, 0.11241551984341876, 0.03252643085415325, 0.018132288016438968, 0.028864032618941802, 0.0172534491866827, 0.006570660954176058, 0.043575617394620375, 0.07925852201879025, 0.08172393851583043, 0.03137403926361473, 0.03260565200640309, 0.049243273754273696, 0.02198354990762328, 0.018900383091081056, 0.03003815429345254, 0.040094084857452306, 0.03084690948467582, 0.011291096997146886, 0.05008623094087647, 0.07236018371317657, 0.005913675441631988, 0.0398710843235735, 0.03706572780145272, 0.021283041024881027, 0.12485000019472454, 0.06853276247819585, 0.05327442841183755, 0.04382243560206506, 0.0748676507763805, 0.05651362052547836, 0.02388122055919901, 0.050513298145585486, 0.023484904123770616, 0.0367493717931211, 0.053406279804485465, 0.08995845673545715, 0.04992853940254258, 0.13745463633489224, 0.1330037727471321, 0.10439308540474984, 0.09205886298009465, 0.08422914561965773, 0.13266937536818366, 0.11268873744073415, 0.17094300549116828, 0.16303875543657811, 0.15505719178866956, 0.22275215285199307, 0.14708125122612523, 0.1501421248840709, 0.11200557853425704, 0.1443990854726684, 0.13434631119091667, 0.10933099705125056, 0.13159766432739076, 0.12329632791900828, 0.1619350832075842, 0.2255169488489628, 0.28255118357558406, 0.13709767000569453, 0.20556803462245773, 0.13239632631021162, 0.10089466828973064, 0.15049683891477125, 0.16634169755683792, 0.11543273415055968, 0.12059530874173488, 0.3423579517872103, 0.13396040205993962, 0.11420310174505557, 0.10042970654584708, 0.15725215626580102, 0.15257518948806872, 0.0974642414779913, 0.20368722748131524, 0.13784711850025963, 0.1864854585860045, 0.2834290896932925, 0.26936071233883985, 0.6363262356288972, 0.8780725120056061, 9.183703180282347, 48.3374111883102, 105.75828644537158, 97.2487828039354, 82.55827488437777, 72.00811893709245, 78.00166529993858, 65.17949996456024, 33.13640679082563, 43.59233171709123, 68.41903255831811, 107.48108556193691, 104.38564515882923, 71.48354115024691, 31.79042193197435, 5.462637380246194, 0.3609007116286986, 0.31793865405263444, 0.1908948461735441, 0.31912918533048323, 0.14271317109946283, 0.32949705157549153, 0.22228569723665717, 0.26257752470912477, 0.3098075500419063, 0.5171733325527561, 0.4618652164936066, 0.8759373943171195, 0.9909537290373157, 1.3216628542830868, 1.4888695723587468, 3.422437127559416, 1.604263986791334, 2.4500759234351497, 3.6196950847102753, 4.870714458727068, 4.55197383319178, 5.277400997377211, 3.5783488904276206, 8.029519771375965, 13.85292205118364, 27.93953303367861, 17.839651453879572, 9.01125813684156, 8.834823062342982, 5.093817403239589, 4.775941660327296, 4.88723450130032, 2.8877082467079167, 3.668484711839307, 1.500205344730808, 0.9866345253202223, 0.7744816125881288, 0.7593443280746861, 0.44452260999429616, 0.3505802815479617, 0.2894453313802519, 0.3563065436338225, 0.1673011154296898, 0.26153733052553674, 0.1584053637399789, 0.3563615181032689, 0.23604085188238855, 0.1770455086784017, 0.10754950554861177, 0.33037615279036187, 0.6799638908236258, 17.59242642310358, 88.09382177168324, 110.5886382441367, 54.88730653639763, 40.04850164536507, 25.492511410867017, 45.12546070160405, 68.37325065366684, 97.19018259356099, 104.71185299658008, 84.35559118947675, 96.27095945419805, 103.40315418858683, 85.52124900202598, 41.36149152632683, 3.813991652381036, 0.8184322606652015, 0.2820885277563526, 0.4834975170031671, 0.20284309051930907, 0.2218330465257168, 0.12716677265181658, 0.0985945429232332, 0.11059970760177221, 0.24197021919873454, 0.17967973264955706, 0.09904734685175842, 0.2054947353298626, 0.17421200991638247, 0.09983100117214265, 0.0823052536936537, 0.0847455808111737, 0.09799569199282317, 0.17663471701164402, 0.15940615036074193, 0.1957668436150397, 0.22871864478914972, 0.12839743927601846, 0.17868179587587235, 0.10245970164936397, 0.13320958992886928, 0.10899944185850122, 0.19726878963410857, 0.14268505567264173, 0.2051180192539769, 0.21034198813140395, 0.12284739273450068, 0.13805590810314303, 0.07351075584489493, 0.14874392249170812, 0.11054703139609869, 0.1301750543737604, 0.219155615195632, 0.11749514243415288, 0.15401148177202673, 0.16411267281059297, 0.12937401751837424, 0.13506695477952882, 0.1774261164809427, 0.16827590102630277, 0.14848578150474256, 0.12781856791867366, 0.12897269469836067, 0.196117359483915, 0.3607263806606493], [0.014609096575558428, 0.021588466873752977, 0.011968848280488484, 0.04992719491823547, 0.08086513863095353, 0.01992505250288354, 0.033661451401008714, 0.049934308044612415, 0.020457372527509447, 0.066815223995476, 0.01655311458894322, 0.025932520567890138, 0.036127308398605354, 0.027499762175965215, 0.018030982464551926, 0.06830082935911995, 0.02023265978711988, 0.10650662239640953, 0.011203616459463394, 0.026636373424421877, 0.07667484452887889, 0.02491947079467918, 0.04772183845841116, 0.035325850194860856, 0.050727507820533174, 0.03083615744065854, 0.06158823290118768, 0.027542368155874075, 0.046597604429529565, 0.02463073225601787, 0.006726989334809684, 0.013647151570166311, 0.04902193563119058, 0.09630719590331278, 0.03279477613227021, 0.022410142137819243, 0.06904364353226078, 0.15797206441000586, 0.07720566685161284, 0.05611084213840866, 0.10023419324669147, 0.04111465952929951, 4.672864223680189, 32.17243921372199, 67.33247326266381, 74.16113145889776, 73.87389629117905, 81.67272921531432, 60.83414923760199, 32.30071052428215, 67.49602825410905, 39.572624006579005, 51.81016791251398, 54.898712788858724, 70.47376617308586, 59.59637472706457, 25.020920922679288, 4.869669147076146, 0.08545534595126107, 0.035759877308361956, 0.07729437983324451, 0.06792795904461416, 0.08799321138330045, 0.10179266889369297, 0.07792922157433727, 0.09120874287139985, 0.09897987748826705, 0.3093970494885599, 0.12893393064939207, 0.7347475737333299, 1.3531581384520377, 1.0995362122212688, 1.1005307782080866, 1.6351255630293202, 1.2447023968542776, 2.2691208076092506, 2.77853078899845, 4.349187785579312, 1.8121057244077807, 2.021465541854982, 6.795622523753875, 4.514301919168042, 7.18658967364219, 2.816484868526459, 6.543436675302445, 6.775938109044106, 4.7790275850603665, 6.743812426444023, 5.0578732932767565, 2.8968206480626137, 3.4315953716155025, 4.916851337878935, 3.5567128514089896, 2.3130008530232216, 1.7119812196300876, 1.1240384006692519, 0.1059158843371176, 0.9726247996572526, 0.40034939805346154, 0.29528963229348587, 0.3036933716747069, 0.050894687357809276, 0.20863776425680808, 0.03477688691007995, 0.0611432928652052, 0.055454419700488936, 0.05077096415803798, 0.05912478141967328, 0.006892054469414777, 0.15156471951594278, 0.04490683688932369, 0.06242455959680581, 6.8494139082970165, 52.03671616892661, 84.79299037687241, 74.08670840724822, 53.34959622352354, 20.000708756908296, 18.307325455450243, 38.90513074013495, 48.77674802657097, 73.42553800152194, 83.25965742911063, 75.30462787997338, 71.43153836650234, 87.05397006004088, 52.56029375137822, 5.404204360900387, 0.27231888424965645, 0.07238476747466673, 0.017713471578674454, 0.0996915348655274, 0.05519929326950543, 0.04819516971286747, 0.05579476958260902, 0.06512400829383443, 0.05236009481332956, 0.10340777376005728, 0.0896511865299075, 0.06551838269637478, 0.03138945486787106, 0.09731934360799291, 0.0067395718501610385, 0.02280042371562412, 0.0018688036206801755, 0.047082404020212354, 0.026115487262065855, 0.04894826861639177, 0.07001487448090507, 0.02865982613706541, 0.06106700199926573, 0.00834913071875851, 0.06047544039545521, 0.0616817492541046, 0.018175616034216458, 0.016299700364470482, 0.00937462271746969, 0.01918443508686558, 0.04615957833706372, 0.06086220371446783, 0.023967378637603214, 0.027873163006358573, 0.026334546273574237, 0.023067129565583124, 0.05326698203721354, 0.04033588518899295, 0.0491594445831593, 0.052498775879822435, 0.03872317051695239, 0.05320440031467907, 0.06424822807011586, 0.09619349313359107, 0.0226670497232267, 0.034728608049091794, 0.03702278091241756, 0.07206219849326918, 0.016410850146184527, 0.03727170969209364, 0.04809610305293914, 0.07003289286888416, 0.02299541799021104, 0.01661479041250723, 0.007606057990943232, 0.06098640954963142, 0.022275168936879888, 0.013637266163113377, 0.003673320973194355, 0.04201783505719035, 0.00826160038535994, 0.05711318391765799, 0.07229217042725894, 0.0028757743665107317, 0.01070094786794676, 0.07410759962494336, 0.022745156217546716, 0.08571927090205493, 0.04070790131546317, 0.01390575220988643, 0.06305284745570633, 0.029933985487948504, 0.07779638958914627, 0.05092112888251582, 0.13266404339623067, 0.01998230416868483, 0.0427961957100178, 0.023925119312480096, 0.015499498544921799, 0.007134354194521063, 0.0879591434533077, 0.13017914528327604, 0.07399668541526602, 0.03514353276020096, 0.03136945805782753, 0.09122123776544487, 0.04935596528793535, 0.10503644604356059, 0.0407719424354934, 0.01663966528740862, 7.069922695236822, 43.88602310611356, 87.13193893432619, 87.57692398563509, 85.96854040699621, 93.02586493953582, 75.97452163696289, 43.8717496010565, 58.30225144663165, 44.50251771557716, 49.85487814872496, 36.60784559865152, 48.852241885277536, 55.31826519197034, 29.81166658862945, 7.490083065725143, 0.3761454323126424, 0.03045397915787274, 0.08445642858503327, 0.03745736727010339, 0.07577884341439894, 0.16931785721211665, 0.19288181777923338, 0.6368130998265359, 0.7966816148930981, 2.2290461967068333, 2.8931243044714776, 3.1803457438945775, 5.439027163290209, 5.898448007722055, 5.443305488555662, 6.3713882815453315, 8.532290650952248, 10.111632020242753, 6.5730339000301985, 9.30201461238246, 9.667341228454344, 11.345574375121824, 10.902166116622187, 11.847187665201004, 8.00705292532521, 7.018311167916944, 14.520950721156213, 9.679761413604984, 9.182792209809827, 12.782177752064122, 14.399545519582688, 10.284250628563667, 7.761683175640722, 7.725525296503498, 5.5813636029920275, 5.6138859352757855, 7.679139346845689, 5.198681969796458, 2.0575871390681115, 2.704512476921082, 2.3259257981854105, 2.343425452709198, 2.192743189873234, 1.1369725388865317, 0.8512938779688651, 0.6405340195182831, 0.3481659707763503, 0.09130323981685985, 0.13255735799189539, 0.12012551298304913, 0.020629880206298926, 0.01443885460180501, 0.16441763709149054, 0.08254619600671916, 5.919641554355622, 45.18196636630643, 57.580951106163766, 50.376282738101104, 37.95418347081831, 28.632364811435824, 37.419682087436804, 61.751026799601895, 68.90705385515767, 87.98654494747039, 93.47605105369323, 80.34619931251773, 82.90647937405495, 101.58184866751395, 72.22366102280156, 11.974837280088856, 0.10638580266987124, 0.03816957623066922, 0.04146800609305501, 0.113195703785506, 0.045241533042562586, 0.02842380785413327, 0.0592393805122664, 0.07378323033692376, 0.04354790799439915, 0.016713868563754425, 0.03397740138274047, 0.02262214164910538, 0.02660007426334966, 0.06346622849964807, 0.07620044458176821, 0.02456977463988287, 0.06996557672297762, 0.09733759948322851, 0.034332996414553736, 0.06038522588149194, 0.02814374909165406, 0.016641314291665633, 0.024610976763670484, 0.024933449984077486, 0.11101754727743327, 0.10202329200241836, 0.06031022204326526, 0.017600960075675, 0.06509040001659624, 0.03910693077130183, 0.03818399017496455, 0.014687355329853394, 0.034110436381231395, 0.05595045780102092, 0.02960404099505996, 0.028934016666044633, 0.030323294134089546, 0.06400854597168584, 0.03357066998198148, 0.047869153335810675, 0.053492736657180136, 0.01719883860900037, 0.032539710988320654, 0.08232723275620131, 0.04566784182022657, 0.04754811269982208, 0.07129983375630072, 0.0800369899239271, 0.10036076629354108, 0.0975258043035865, 0.1847663572839191, 0.307731696915242, 0.18848833417700184, 0.10105415247380735, 0.1767335423538762, 0.3341787374548374, 0.08839448057715932, 0.12473933113318299, 0.14576321227415917, 0.09009976165309068, 0.10909413032594228, 0.15491928064054059, 0.18783098477269375, 0.10518017945991409, 0.10588039148358569, 0.16901885309526998, 0.12038637358214586, 0.2475485956716922, 0.19493324802287165, 0.09117873520740578, 0.2512565531557606, 0.1427123590462631, 0.2210171628863581, 0.16070975621621456, 0.25441684970451944, 0.07812118022552422, 0.14716585797648277, 0.1200715497496628, 0.15062563361660128, 0.12381608027123636, 0.22559127469937648, 0.242577160017625, 0.14758401940907204, 0.19056922816220792, 0.16661365876995748, 0.30493915321365483, 0.20983261627054986, 0.2868817866809907, 0.11296488915479953, 0.2311378891669935, 10.97247067959078, 54.01958019502702, 100.57247377211048, 101.84733821499734, 94.17331510974516, 101.69317337774463, 79.31489052311068, 47.33492005255915, 80.61419133217105, 54.75798599181637, 74.04119322376867, 72.65247806426018, 91.94671107876687, 81.01357490785661, 36.995156118946696, 8.095753404401965, 0.572452214696715, 0.30508005210468847, 0.21820666208382578, 0.25989303004837805, 0.2183048132686846, 0.2437656841451122, 0.2671956252907553, 0.4758235836221326, 0.2029992345600359, 0.8414693825667905, 1.4277755925732276, 1.7991748956903335, 2.6405202333004247, 3.100520117628959, 4.2861513745400215, 5.0239060578807715, 9.396645715159755, 10.869746746555453, 10.291887483289166, 16.102414092709942, 13.478509264607585, 15.293493886147777, 22.743396682123986, 17.761790444774014, 19.57967762024172, 14.470462952890704, 21.964178623691684, 19.467950867068385, 17.540727623047367, 16.57752294694224, 15.207469444121084, 12.838097022425744, 10.311095330022997, 14.03182625770569, 9.657614731019544, 9.062724536465062, 9.066193872882474, 5.990082909983974, 1.914484856590148, 3.735495709603833, 2.355266352815013, 1.7920977141587966, 1.9258461243683294, 0.8559128365689709, 0.5249528634932734, 0.5417529878116424, 0.26186285660632197, 0.16729150868711934, 0.1696919532673013, 0.13029415040246903, 0.21002565510571006, 0.2824485277937305, 0.25666668139878784, 0.25336275868598496, 10.554393087663959, 70.33139198057114, 110.44282805535101, 98.55726980393933, 74.16833293053412, 28.98911810690357, 29.441024180381532, 53.48565147769067, 64.51477981382801, 95.0679999013101, 102.40676233845373, 95.3985066567698, 89.66245605099587, 114.30415045830512, 81.09716061622866, 13.16061979339969, 0.4580774326478282, 0.17852301649268598, 0.15377404048077523, 0.29622732391280515, 0.21905490527710608, 0.1574706598635643, 0.14692524508122476, 0.3054503483637687, 0.19570272205577743, 0.23697089794422352, 0.17090794930775322, 0.18857778260304084, 0.09607875614517158, 0.2077096334147838, 0.18323897714576415, 0.10614348139854209, 0.17931798593171183, 0.17200923134242335, 0.14672281400811288, 0.11091879854399352, 0.22955417092288696, 0.13158447229333464, 0.16729114096491568, 0.18879248640469967, 0.19812454048904682, 0.1728128422532351, 0.14759315117712946, 0.10620175770694211, 0.11173085940461006, 0.19892450482133897, 0.13589981492728959, 0.09739293401399929, 0.10059601657332913, 0.07383592952523502, 0.1364041459296019, 0.1564923042972242, 0.15016824848228885, 0.1487246630412917, 0.19959441806760528, 0.16753690197102486, 0.16750417469489962, 0.1307641453440151, 0.16599308158601486, 0.1383364801445315, 0.1402923639022535, 0.12831110116695205, 0.15090012291987098, 0.17988374186379297], [0.027551871476574775, 0.033556593116372824, 0.11276765215781429, 0.0347958131122493, 0.053412814534479575, 0.035562115541148576, 0.05777012729536622, 0.05736355677307133, 0.06454533611934993, 0.09838099591434003, 0.04326718273542581, 0.04150826784391557, 0.056870257436868646, 0.05003379605289909, 0.065503497608006, 0.047252226560827226, 0.025587662258335662, 0.022933129296307603, 0.05724594312449617, 0.010783052383621615, 0.05532636427350583, 0.06029025779195851, 0.0800284174000544, 0.04464635933418909, 0.02526859812919171, 0.04631782145870309, 0.045596189616668614, 0.04822379075771859, 0.029723623489600517, 0.00790688922748931, 0.05923989379117566, 0.07295072258960816, 0.026820634807189627, 0.07734236758082144, 0.0591578419440456, 0.01928421037812387, 0.03783827384693488, 0.09566319175064565, 0.056133449393054174, 0.09559637356188991, 1.9867730356993216, 28.804880457539713, 64.23287514717349, 89.65647835885325, 70.9543820350401, 80.71552184320267, 73.6549731223814, 42.701945843235144, 20.832264961734897, 42.76302891392862, 172.90358420341246, 111.82272572671215, 36.962321958234234, 60.79771434107135, 38.53423533901092, 11.749874641818385, 0.5014794085535311, 0.09822863634795913, 0.03945684526115656, 0.06669782868195927, 0.07529711200585289, 0.08004266663544601, 0.04066594651028995, 0.37488454351982764, 0.16528847987853712, 0.5082886738161887, 1.7793915637077826, 3.6908049593048715, 3.0785070407775144, 4.843108327158036, 3.595881149653466, 8.102627358128949, 3.2904121087443445, 3.223784277516027, 7.488942636597542, 7.164530754089356, 5.829531963794462, 8.089311401690207, 9.215555767859183, 5.014436965988529, 7.404276315243014, 6.267482734495594, 2.8133871766828724, 6.33581385497124, 7.090371972130192, 5.087211641573138, 6.00711384127217, 14.258406873672241, 17.16791810527925, 12.246574182664196, 1.5738898876213259, 3.71984324628307, 3.073819563273461, 2.247431081148886, 2.125430659901711, 4.547559205562838, 1.149639220487687, 0.7220230984591669, 3.0661275502174132, 1.9810344855631552, 0.5997422277446717, 1.0713044626097525, 0.24082942234893, 0.7236201772766729, 0.10832060368791704, 0.24806302371284655, 0.03341331169189465, 0.05175729469966985, 0.04787630093614421, 0.0862578307128241, 0.016060068061755552, 0.07356888659658932, 0.06448658483643686, 2.0395860340326064, 29.85045098489331, 79.74253869825795, 75.4474021542457, 60.5194260997157, 31.665619957831602, 13.149260609380661, 22.25573624334028, 30.33580703120078, 53.50706761883151, 68.69909763336182, 84.15824105662685, 68.05761752590057, 83.4488647214828, 60.5347272657579, 14.868054986000063, 0.2268768008798361, 0.027688989723702113, 0.16471828063649518, 0.045355224320965434, 0.026187804046898123, 0.09235440437952358, 0.07577388682552884, 0.044168990796371814, 0.12883125954578, 0.04175526991246208, 0.04754990917600451, 0.06267055809017151, 0.05691803834070602, 0.04903364911555283, 0.06822564549023105, 0.022408364813834913, 0.0568731302665847, 0.011937980682799413, 0.0068330149459201964, 0.05476128632923769, 0.039244163931617816, 0.02849225589494792, 0.04746628301819006, 0.026095952019996704, 0.04385249689221383, 0.03336857215711667, 0.06376087357620559, 0.03681748084002926, 0.08276124454794392, 0.03326089849935905, 0.03966878731584838, 0.028503984701068654, 0.06969395258854474, 0.08496355580826921, 0.05351567716007272, 0.05352001321772414, 0.034129577088019544, 0.05918503040447832, 0.003059198319416253, 0.0026754519504104415, 0.0644012196590343, 0.031053881543958863, 0.0556224687475591, 0.017511459938701124, 0.05917651916763956, 0.02083338188728498, 0.017032055522225076, 0.028841375568581205, 0.018574010483139468, 0.050587417152259624, 0.029333866682023774, 0.09038989447177419, 0.030942932860324943, 0.030554939970193856, 0.05696780341226728, 0.04229083814988694, 0.07539628208765099, 0.03782261500976259, 0.01641738487617864, 0.0490430222013064, 0.009700912013349515, 0.05442386673342797, 0.009207575330360523, 0.02765800912804421, 0.00906838768822772, 0.02563635672202274, 0.02285847019764685, 0.040159776896959355, 0.04926554776067215, 0.042974460539558244, 0.02641243251761602, 0.027566875308571805, 0.03994518417804953, 0.06816586764949946, 0.07809105764834151, 0.03588709003862835, 0.04841319067523845, 0.046476865142223336, 0.011091479381936933, 0.018391470882981535, 0.036614276018113866, 0.03890605868711587, 0.01563976158297831, 0.04061935687317483, 0.07012568143827301, 0.05934223164654067, 0.13462133675573335, 2.3645003476450523, 38.65800965216852, 83.75539010570895, 101.8701820988809, 81.99830947383758, 91.36301532868417, 84.13942152454008, 65.05131298495878, 34.80491245946577, 48.08527338889338, 152.62797417179232, 84.40168688374182, 33.201631884421076, 48.89921226809102, 37.23351070957799, 15.746143248773391, 0.7377013636212195, 0.05431692852007766, 0.019249175262126713, 0.08380652555534918, 0.06500534127436339, 0.22962797583351213, 0.741310373188988, 1.9465151765654165, 1.336249045787319, 2.968060451169168, 7.831804367803759, 8.884944088997381, 9.142766383386428, 14.048455146051223, 11.429462105997148, 11.857082824553213, 9.471681637148704, 11.087497126671577, 11.185656401418871, 13.405179573643593, 15.136885412277715, 15.753944843046128, 9.964393108121811, 12.340863058643958, 13.470437026792958, 13.715452782569395, 8.564460950513041, 16.922038447472357, 13.438609934622242, 10.523322032343957, 12.110947447438395, 9.826229579987066, 12.996567641535114, 11.153837153988501, 6.822585386614646, 6.8163895126312015, 7.764092491519067, 5.356937348842622, 4.468352333191903, 5.534422637954836, 4.828159193838797, 4.26091141277744, 7.5319582896847885, 5.470134990830576, 3.023694614248891, 4.83228111459363, 1.7288190967613652, 2.22354507254016, 1.6430233779453463, 1.0664625417801643, 0.5065278666875055, 0.5095159466708861, 0.15156482676825217, 0.1996109042797358, 0.03013891592291334, 0.11469749658698998, 0.128365179313527, 1.9917001455060899, 27.913196279156594, 61.786826272164625, 62.14644485904325, 37.18733656790949, 27.723492806957616, 23.602552644668087, 40.62205022381198, 54.65359995442053, 71.17205789012294, 87.11942657347649, 98.55384165240874, 77.38577473548152, 93.41284598073652, 84.63611125946045, 33.698662865546446, 0.36872584012246906, 0.14396621515193295, 0.1911545346581167, 0.03934986491297041, 0.017453363660963315, 0.05903967288172534, 0.07255820978072382, 0.0678145167447867, 0.03006707602781394, 0.011305163329046582, 0.07949889742679174, 0.029930245063658205, 0.05811314699390243, 0.11483262683595381, 0.021046971031013998, 0.07043691231839119, 0.05310075244896355, 0.029083013106437943, 0.030816342576497027, 0.023694854349859303, 0.010828220927637192, 0.04035702538526347, 0.060362243243763526, 0.04656404977844608, 0.028339168545038953, 0.06944343417642579, 0.03966507945029486, 0.051290900371367895, 0.04130604361454326, 0.02837373443218249, 0.05159144432494237, 0.034732212492775534, 0.01201990133737244, 0.04953612235464877, 0.0588502767946451, 0.030893579561022982, 0.06859213429232759, 0.05825383138031729, 0.0465413429323704, 0.03346465490457993, 0.033107554509995446, 0.05252963007097283, 0.060181136228024006, 0.0637831399217248, 0.025821257788207264, 0.052777405888322866, 0.0127133239068151, 0.15122734971584814, 0.11983459875468286, 0.24245038778791506, 0.1251767443553094, 0.13516083119377015, 0.1057042142436389, 0.2728761059622611, 0.12081165963243093, 0.1562610529964009, 0.2635750937606058, 0.171071601010138, 0.10698512857479435, 0.15950358142295193, 0.1697915140539408, 0.12953175502198358, 0.12157852130551493, 0.09331154697124036, 0.19651497443837507, 0.21238865330815318, 0.11949611812709801, 0.1541335042566061, 0.11518298948724424, 0.24255718044455976, 0.16930829643482165, 0.1976800409536208, 0.12204521440810735, 0.1586274373074693, 0.16322609457758167, 0.14268203728622006, 0.10862710780554241, 0.21033040488198881, 0.22504885380546893, 0.16017983787723128, 0.21687429728767565, 0.26505388860260287, 0.15555646661068165, 0.10420034534388012, 0.2513167370230921, 0.1078991327554949, 0.19624488247979074, 3.5351937480511206, 49.124481831827474, 98.9206381767027, 115.30321736489574, 89.15590547746228, 98.99708517136114, 95.63134639493882, 58.647361186242875, 35.329101931664255, 56.75520197037728, 172.05326141849642, 123.29995739844539, 53.41549204241846, 84.88210662718743, 56.85798375837265, 17.354211076613396, 0.949711783999397, 0.21201708534311867, 0.1473087333743611, 0.1939293664068945, 0.19670160877848827, 0.28658506550615837, 0.3079248123591946, 1.1863993060204292, 0.6959183153606231, 2.115468820256572, 7.21048181095431, 12.74749223263033, 11.143436989476605, 16.979595307380922, 13.310002280819802, 22.91448654667024, 15.975711730218704, 13.931364551667246, 24.318067489131806, 20.998865673618933, 25.668323809100738, 26.16047536173175, 24.27206200938071, 17.85896912697823, 17.850373252745598, 21.132498864204656, 14.423571017480667, 21.23828322656693, 18.33222270011902, 18.956199230686313, 20.18853537497982, 31.371883461552283, 37.98811981754918, 23.771063550826042, 13.232465847846, 13.23771397913656, 14.737307679268623, 8.770809981130785, 9.36765939958634, 10.922108427170786, 5.2979488238211605, 6.338164825593272, 9.747868468684535, 6.296950521007662, 3.9807122417034644, 6.735925030323767, 2.5957130376369726, 2.5020215876640814, 1.7437997316160512, 0.7148799107920739, 0.5352834059346108, 0.4311354073785967, 0.18489182716415775, 0.4291218218784179, 0.12530990575830783, 0.2223111160339848, 0.3127224533067596, 3.4701583991127634, 41.79694521811701, 101.57348617430657, 99.8799636287074, 81.62918306166127, 46.68774074123752, 21.443378079322077, 35.97452402114868, 43.70161287246212, 70.77016399752709, 89.84261051301034, 106.77585124969484, 87.55985383064517, 102.68179893493654, 97.1164655685425, 37.022593098302046, 0.420887173423844, 0.2480801227953165, 0.23179643366846348, 0.10463029686962405, 0.09945663698618451, 0.2562652513264649, 0.23565520322130573, 0.17670409393406686, 0.2704863100042266, 0.12037441494964785, 0.16925888376370554, 0.16166672260770876, 0.10960898737633422, 0.22367631535856958, 0.11084620405228869, 0.11159175315931921, 0.212821661524715, 0.1423492946571881, 0.08316492691876427, 0.11350080596222994, 0.15098643038542042, 0.1288244413632539, 0.1543969312502492, 0.10336273545098883, 0.10439257212584058, 0.17261218850410756, 0.14256238967420595, 0.12106669796330315, 0.22494736247726027, 0.18468231743862554, 0.11466556604230597, 0.08824933755902514, 0.2025635603574976, 0.2119945776799033, 0.14078304321775514, 0.18356093325682227, 0.168215517976111, 0.14566080164044135, 0.07081589601453274, 0.08268592278322867, 0.12574299824454133, 0.14099718011435003, 0.17437448184336388, 0.16270667164316102, 0.21363651860625515, 0.08093551146767794, 0.17235101380896184], [0.03068220824183476, 0.07228629453287971, 0.056764353442216114, 0.0656543173376591, 0.07516444856000525, 0.03055776491941464, 0.05945393492678001, 0.018682063354419607, 0.031121590309926582, 0.01845799029744681, 0.03744491451089421, 0.028715514983501167, 0.06814567357181542, 0.04994626667711043, 0.057806278984513015, 0.06059534847736359, 0.029816186063051708, 0.011483517216308223, 0.08918144439737644, 0.01274341105243131, 0.015299322643137027, 0.020318547819530772, 0.07201309991820205, 0.0030533604900307596, 0.06576346954511059, 0.046561992832369385, 0.004538024762540215, 0.018706334935080622, 0.036776046974644545, 0.05634036974140233, 0.0171234785398889, 0.09890578146423064, 0.08178196967609468, 0.03629146188858055, 0.10655234252373058, 0.04136507451954869, 0.006359916869475837, 0.08832635237805306, 0.0771417138316939, 3.3580330350706658, 40.46671259787775, 19.539536083898238, 60.89534997940064, 73.56578626940328, 67.64492927059051, 48.311551001764116, 33.31203876003143, 21.28572625498618, 22.2411822888159, 31.06328118231989, 36.67383947680074, 48.73078569289177, 54.17227414346511, 20.17755469968242, 4.386609648504566, 0.07405331463462884, 0.0137953388301896, 0.0462213211933211, 0.05670559066798418, 0.06671901867394486, 0.060877916177794825, 0.3095684999660138, 0.3445553983892164, 1.4849052818552142, 0.13843322172760963, 1.814730035201196, 8.801027920938308, 9.108628034591675, 11.570592907167251, 11.65226253771013, 12.692607487401656, 13.573392379668451, 10.260204538222283, 15.057459377473402, 10.127004769540603, 12.936780914183586, 4.513978813925098, 6.421596090639792, 7.323743681753836, 12.34682898367605, 9.08511636718627, 12.90965086029422, 5.996112083235095, 6.562750426030929, 14.544002490658915, 6.015683729802409, 7.808080402112777, 8.91641914844513, 11.448143374535347, 12.811059144235427, 8.067796710998781, 6.731383906256768, 6.104146905483739, 3.580473589320337, 6.5985665686668895, 4.807958987451369, 6.626645345841685, 2.438170304221492, 3.98908356024373, 5.431934047129847, 3.504976053391734, 2.0837468966361015, 1.893042729746911, 0.9499060638969945, 1.693621953168223, 1.1552381587605323, 0.3169859164664823, 0.222065998541732, 0.037630200536260684, 0.10669613722711803, 0.09847037539246584, 0.0223496958853737, 0.07164541601894364, 0.11097951867287198, 0.6578232143675128, 17.89288978422842, 47.87265346896264, 102.71327203319919, 91.82503915602162, 65.75872029027632, 36.20018582190237, 11.006474687207131, 38.340485941979196, 42.13054672364266, 35.96434154818135, 83.30386254095262, 74.98808476232713, 71.20113049784015, 73.52874340549593, 36.389769661811094, 0.910583506188085, 0.4561658287721296, 0.026279755665229696, 0.062372641818177324, 0.033086395161526824, 0.12303736721796375, 0.056550584267824895, 0.06901032636843382, 0.03283553967072118, 0.02126703936336262, 0.03660054006163151, 0.0261928468206597, 0.005824566488304446, 0.029323580036420497, 0.05040399655098877, 0.04113088910197539, 0.0453451962300366, 0.10321508732534225, 0.050343042765293396, 0.1072847915272559, 0.03016665979709116, 0.06376156305533744, 0.054662097095241474, 0.04344322207954623, 0.07475107517694274, 0.044873243933843995, 0.04192280185018336, 0.01066336359438156, 0.04085124402697529, 0.04899938583313938, 0.039745124147063306, 0.07534631783322943, 0.013183017201240987, 0.023999468145531513, 0.015176452673791398, 0.037987821870633674, 0.0451778749664945, 0.02903847850017971, 0.0721264885918748, 0.052679315990497994, 0.06800629153487182, 0.024848938994710485, 0.024468128178869526, 0.046644918019733125, 0.08206762088042113, 0.03938991215921218, 0.0754157560426862, 0.04342631834949698, 0.0396888013628702, 0.035672562437192086, 0.030758520175192147, 0.028187046465914578, 0.08825481508768375, 0.023632176866334294, 0.05559277517961399, 0.04765479044327813, 0.06239655142229411, 0.027193729202413273, 0.04249630293117897, 0.013601567423451814, 0.07203182310707147, 0.05310488166287542, 0.00655051619340215, 0.040101653806144194, 0.07600369022017525, 0.0198256085446525, 0.0019984673534993143, 0.045895526981762344, 0.0631506309183615, 0.030421761330217127, 0.01663144516398109, 0.03163773821847093, 0.021121314118405985, 0.02503976383576951, 0.04212173956236051, 0.021131192822189584, 0.031126449222586332, 0.0815593675079365, 0.10547259522061195, 0.01893712849836917, 0.12217289062156794, 0.047353200779687014, 0.03348490643885828, 0.09560098541119406, 0.03267181518998358, 6.70694459830561, 52.76635546838084, 28.319900958768784, 66.14319493693691, 87.24326364455685, 87.4982883084205, 75.30411797185099, 59.77180665539157, 27.413276472399314, 20.091372382256296, 31.34823156941322, 59.200195727809785, 61.96434882379348, 52.8792412819401, 29.219808386218165, 6.814069920970548, 0.3181170912519578, 0.17594620315057619, 0.11083436033297932, 0.14198626091163005, 0.17216802604736822, 0.9553873310646704, 1.9177425075923245, 2.2815311868344588, 4.212578006329076, 2.6942966638072847, 10.815125780720866, 14.574191993282689, 12.595278774538349, 7.999309186012515, 9.5215408455941, 9.731689672316275, 16.080139933093903, 10.022322593196746, 9.302173468374438, 10.283679923703595, 11.125159725066155, 12.527429615297626, 17.29941556530614, 14.649071020464744, 15.85630987921069, 13.059173572447992, 13.66430409492985, 8.7398075672888, 11.30165755748749, 11.445343782824855, 7.604865345262713, 6.728010177612306, 5.637619706892199, 12.237442904903043, 8.034973336804299, 4.570436919889143, 3.350548662485615, 6.1630319779919045, 3.16146100240369, 3.894481384946454, 4.2052578829949905, 2.400770749776594, 4.136217794110698, 5.119716813487392, 7.94582276575027, 5.710526272173851, 4.712293849837396, 5.0809863498134, 3.6289352082437087, 2.3758904203291866, 2.065818723170988, 0.8966917580654545, 1.071420049955768, 0.25705131882381055, 0.9566581790005008, 0.42604205649225946, 0.03879674177076067, 0.0695509622774778, 0.0500369102003113, 0.5366890240580805, 16.16171738793773, 43.89047891862931, 85.55808790268438, 65.2354290408473, 33.98468994325207, 28.21533056997484, 17.464859177989347, 42.34559459071006, 48.059801516994355, 52.562670707702644, 93.23167170247724, 89.28222148649155, 78.02709794813588, 94.3463622370074, 58.46247242343042, 3.210082212763448, 0.6091663962410343, 0.062187650736661694, 0.04031630781208796, 0.04385600174446741, 0.20982302484973786, 0.019012586243690986, 0.04868862226665501, 0.047750593568649025, 0.04687148469289945, 0.0161135716423873, 0.06421062081391293, 0.035244920666539864, 0.027044169687395616, 0.05844103645593409, 0.037937371150380185, 0.022701366631794843, 0.042824119614857825, 0.009893908713673873, 0.05150447419333843, 0.025777841670318477, 0.06852041314085645, 0.06802957294689072, 0.020946033201330615, 0.031290897656412374, 0.02788244224634142, 0.03505196993149096, 0.021717721228337577, 0.0319023430722976, 0.0028819938034435077, 0.013874914298104423, 0.0626712016040279, 0.03447302196535372, 0.016035202762953216, 0.002897214773486579, 0.03657104184610709, 0.10518443124789385, 0.04392312253795324, 0.03909075482478065, 0.025884768392349926, 0.03208866714680147, 0.04390046165715303, 0.02088216253586354, 0.04685880210731299, 0.12900954352751856, 0.04811879074681671, 0.13831918187920125, 0.2724888944818128, 0.10680449270312825, 0.20229423448683756, 0.11294839528178978, 0.07902638971685402, 0.21487053303468615, 0.11920356447057379, 0.08785310922370804, 0.10135789101402606, 0.12565096044131827, 0.12037153445905256, 0.1486500460774668, 0.08786849993010683, 0.12422655018106585, 0.10197041661388452, 0.11182383949597997, 0.2819676084383842, 0.162581063867096, 0.17619797028601172, 0.06745750445031351, 0.11032904873812392, 0.20503969442459846, 0.09508967534789155, 0.204751109103522, 0.09064131686764379, 0.07260446616959187, 0.11736767306443184, 0.13262406892834172, 0.11999427446074064, 0.1617932650110414, 0.24841637410704168, 0.26572795404541877, 0.19991001564889185, 0.18325549400141164, 0.2215619739745894, 0.1352079456011134, 0.1784922197581299, 0.1667522747189768, 11.557788329739726, 68.63110726879489, 36.49204154168406, 78.34215056511664, 94.55893901086624, 88.72402898726925, 63.8221598440601, 45.5879238344008, 32.37218591474718, 39.75956809136176, 47.91779210490566, 52.2795501062947, 68.6886876629245, 77.71999989786457, 33.53200920166508, 7.862316975670477, 0.5079429230142025, 0.3545006292481577, 0.23598751684110011, 0.2258108048549583, 0.2533069108763049, 0.26038740190767473, 0.9610327861962781, 1.3891473556718519, 2.6517168841054364, 1.4197005355550398, 11.553328594853802, 25.620392445595037, 27.061084893441972, 28.650843097317605, 27.700390046642674, 34.02265064177975, 34.48988337670603, 25.874991532294985, 32.51291663415971, 22.709748629600774, 27.00637959664868, 22.51217099928087, 22.228342410056822, 20.162539866662797, 33.04787105129611, 22.681733100645005, 30.48448447258242, 18.34214041309972, 20.935966545535674, 31.297213300581905, 24.141700075518703, 21.03846984524881, 27.300025878414033, 31.767495678317164, 30.12851957351931, 22.564893537952056, 19.38582035803026, 13.774944351565454, 13.595445905962299, 17.66479415278281, 12.682456393395702, 18.188816924248975, 11.644427603290929, 10.872668912333827, 15.248492533160796, 10.613078609589609, 7.691384496227388, 8.327080088277018, 5.77847594215024, 6.185046280584028, 3.566215773743968, 1.0107465605101278, 0.7835448004545704, 0.28506309394874885, 0.88667543424714, 0.4924655567494131, 0.10259254895631345, 0.21904154470370663, 0.34606514318335446, 1.0116192878734682, 26.83533876172958, 63.719158403335086, 125.59631686056815, 119.01731752580213, 90.78759577966507, 53.23831465936477, 18.52624470187772, 51.52142655464911, 55.50495040032172, 51.69978064875449, 100.36965585524037, 96.28414646271737, 90.6230523509364, 107.13130427945046, 67.82643302794426, 4.154868664280061, 0.8201668062998403, 0.09140920509854633, 0.1676303340542701, 0.17097223940635883, 0.30443209493833207, 0.2595595366531803, 0.1348286095045267, 0.1554177587311114, 0.1307331800701157, 0.13012614732067432, 0.21281703435365232, 0.1123502185087531, 0.13840787953907444, 0.1352645901422347, 0.22669670893059624, 0.1300267091081027, 0.20054334053589454, 0.07851659650764159, 0.1698833833178205, 0.12019760185672392, 0.19630641466186893, 0.2030153990152382, 0.10271171393293528, 0.1392466845291276, 0.14700042895011364, 0.08782116335726554, 0.09760036764125671, 0.12727236255042015, 0.1129084361356593, 0.12458447412016893, 0.2641153696083254, 0.12402961961925031, 0.0758773623214614, 0.11310257813743047, 0.08991841331965501, 0.16212291264485928, 0.18281283307700388, 0.1935707912930558, 0.11138529246372562, 0.15019667034427966, 0.1670846649475636, 0.10452462270134881, 0.09818117720104995, 0.2550295974698759, 0.1868016383941135], [0.068614864121041, 0.04613441617919072, 0.04929928244241784, 0.031141541154694655, 0.006953212226019993, 0.017466308631663843, 0.03511915584245036, 0.03115703911340285, 0.029909598994098847, 0.06209069847940438, 0.00679616851078707, 0.014979527857635292, 0.02504193186459522, 0.07105741289354141, 0.03060142235499957, 0.05232713388038739, 0.028300913944540006, 0.036895077885879625, 0.06288300959333297, 0.04846116693149652, 0.024084515396445513, 0.03566248072010856, 0.027796994714486985, 0.039103973671914115, 0.0604591342139869, 0.02961074043395779, 0.015900101242286545, 0.019968108559447913, 0.024322785977875034, 0.028508498874162475, 0.04359602980736283, 0.05781674757599831, 0.06214338234595715, 0.03548950955812489, 0.03785895056001121, 0.12025653700073881, 0.018332826852377866, 0.47563708717784575, 12.805946334715813, 67.76430268441477, 78.22144354543379, 20.838201468990697, 46.16205292363321, 65.81437480065131, 28.97333645051526, 17.69245666842307, 17.862638504274432, 46.56506469172817, 34.907200028819425, 55.28795703764885, 45.816845124767674, 34.76217823643839, 12.0112721766195, 2.847886628681614, 0.11408045106837827, 0.05594317230486101, 0.09150393953126285, 0.026097775309256492, 0.153560271306384, 0.4165903701176567, 0.7885848622648948, 1.6447862381896667, 4.798422724969925, 7.807241995488444, 4.436533576057804, 10.400274338260775, 11.40371076522335, 8.696376142963286, 8.479797570936142, 12.686896516430764, 13.048589056537999, 11.305502460848901, 5.285367331197185, 8.693974671825286, 6.622345937836555, 7.834125920649498, 12.563045717054798, 18.49630132798226, 9.143355719504818, 8.05579278738268, 11.940104692212998, 9.511920252153951, 6.391724299999976, 15.587525540782561, 10.61027019254623, 7.166771408050292, 9.602660363720311, 5.778128322093718, 7.192436456680299, 8.247979610197007, 3.74692966380427, 4.131296690433256, 4.305106228397739, 5.0645839783453175, 4.5098931750943585, 4.1843889124931835, 6.454393479131884, 5.383942867479017, 6.553261231991553, 7.539172509024221, 4.5519272550459835, 5.14843003403756, 3.571058184869828, 3.759277039958585, 1.0173925264708459, 1.5657384669588459, 0.8702092629767234, 1.2831101230075284, 1.4276743463931547, 1.0167864589921891, 0.7536177901971726, 0.1565699243257123, 0.21406724388080262, 0.16904824022804538, 0.19762368752591072, 0.2531331161698026, 12.184468353948287, 32.071600960147, 69.39699711338167, 117.91658278434508, 93.97886753082277, 52.9665179406443, 113.56497195459183, 125.8345224011329, 42.74038507092384, 47.576957748782256, 67.93239193577921, 81.62173055833387, 63.106405735015876, 74.91118277272871, 45.5977140703509, 14.065082073211672, 0.24954940282529403, 0.07842732428182518, 0.13027328216741163, 0.05286226161725579, 0.07048287759384803, 0.07946636933352678, 0.09513865900977005, 0.06318659491596684, 0.0497410164004372, 0.08103822087568623, 0.05347659901505517, 0.0610992657921968, 0.040417362470179796, 0.07281151675288716, 0.03231849543930542, 0.04521195821824574, 0.028966085106555014, 0.019264724931769797, 0.052842611461998, 0.031017252965079203, 0.028483579949205442, 0.05326642662346844, 0.028932170394147118, 0.0555587187409401, 0.033847216231327866, 0.020427638739948312, 0.031006914608541037, 0.024403094974977356, 0.023554727292409348, 0.06012990792852737, 0.022237906420242884, 0.06040904355505782, 0.019077856934839682, 0.02308271753962242, 0.03124577890811188, 0.01893221978999434, 0.007062156632122014, 0.05448058022246246, 0.016891168122510278, 0.05808233493758787, 0.014287583837886492, 0.0017251933769007485, 0.04098907090543259, 0.009829178114511795, 0.02251313691357932, 0.015172462313315802, 0.025915501924652248, 0.06306399020456499, 0.04480870102622336, 0.04994473450126187, 0.06563642918462716, 0.05897665065863441, 0.029340964486642234, 0.06090312813138289, 0.022036364009123177, 0.05171877962927665, 0.0031560351846799737, 0.056238778821763494, 0.02453661260886058, 0.07349226248240279, 0.05204595662953873, 0.023596760621594808, 0.12940043223000344, 0.03251278682822182, 0.033074340768038266, 0.027874917347705173, 0.015060014012570103, 0.06453187595452033, 0.06812311994332461, 0.04679843820931931, 0.026543330130798203, 0.014436346621462896, 0.03127182015187798, 0.010272342741729753, 0.08355255208669171, 0.0698981686465202, 0.10115340682527713, 0.009446736489002024, 0.04035209560947072, 0.004280631190105792, 0.07469557210682862, 0.434274896979332, 21.518356146350985, 79.21685480302381, 92.63200406105288, 24.437097695565996, 66.49012857867827, 89.33556572083505, 45.47481836811189, 27.353868253769416, 22.41621413538533, 45.90852660517539, 34.423756137970955, 46.13989153215962, 43.85723290904876, 38.30161917594172, 17.97588125351937, 3.5656928727703714, 0.15170227826362656, 0.06940251742038997, 0.039089249462009444, 0.11017115035605048, 0.8555223155886897, 1.5947029643481778, 2.335255891084671, 6.489930152893067, 8.556873125414695, 9.613082101268153, 9.929503625439061, 9.600117687256107, 11.211473441893055, 6.176947566770739, 5.094232193885311, 2.4749667942523956, 1.8364473408268345, 1.6930962329910648, 6.105867355100571, 3.9586430259289282, 3.5415533809892596, 6.954738372756589, 8.669958979852739, 12.413955446212524, 12.878473900979566, 13.487365976456674, 17.477651988306356, 13.64287030312323, 11.070863335363327, 11.033294873852885, 4.846636008831763, 3.0747239147463157, 1.6294818852216968, 2.3245831218457993, 2.377498592099836, 4.286283754533337, 3.0807651002560896, 2.678367183093102, 2.18077358699614, 2.878065344787413, 4.816690673751216, 4.593995165440345, 4.728704556342095, 5.612943585841887, 3.580351750696859, 3.844973964075889, 5.182329608548073, 6.1643096900755365, 3.8515000525982153, 2.659461113714403, 3.03905118376978, 2.9369227155562374, 3.6848189321256455, 1.848476024404649, 2.2016023532036813, 2.7469096212617816, 2.2789831171112676, 0.49769548579089107, 0.19789230859568044, 0.2529256289163905, 0.14979795222320866, 0.16469231025586206, 11.785092623003068, 35.13911016525761, 63.35278941738991, 95.07737436602193, 71.365109105264, 35.45344891086702, 117.22320971950408, 125.90558790391492, 37.75528400175033, 64.69301623682823, 81.48054876635152, 97.10273727293938, 70.78378246676537, 87.70432256883191, 70.13910954998386, 27.44910340155325, 0.203434050744099, 0.09217089567814143, 0.052601703622889136, 0.09322646524636977, 0.024537945601848826, 0.0535982690991894, 0.10191280680197863, 0.05037509588404529, 0.046979093233183514, 0.03743715404022125, 0.061714886387269345, 0.07090257886316507, 0.11765554592373872, 0.017341018782087395, 0.03614266463104756, 0.050708455213856314, 0.022860153675860456, 0.03001120906593579, 0.02840910854208614, 0.06279068450713832, 0.023194436141620242, 0.022459014716948715, 0.058133440663016615, 0.04094589419002014, 0.04506809839738473, 0.0744594484868069, 0.058132222583217014, 0.07596424435295406, 0.050995864589969, 0.02050451566314986, 0.016103518653600928, 0.017086610558532903, 0.04719953120295559, 0.03693629341620592, 0.02633463628890534, 0.05276348607073869, 0.06320204690939958, 0.06625894457101822, 0.03634986077104846, 0.10007095523178579, 0.030253509269847028, 0.02831225587625898, 0.018182755973670753, 0.06799342891862316, 0.10052482402252574, 0.18917583680200964, 0.19268317118046746, 0.22489609587336742, 0.09582967797835028, 0.15413206401130847, 0.18641196011054903, 0.16340212626082284, 0.13913483569218268, 0.20647972521762695, 0.11651160811344463, 0.12001379438105131, 0.09039191694389428, 0.20233682897542754, 0.12357755879601165, 0.11454774171955164, 0.12246936664826448, 0.05710922707352908, 0.16340998632292594, 0.0936380536445687, 0.11653977716642043, 0.28110211294504905, 0.1301881391555071, 0.16846895518322147, 0.14159181756117653, 0.1483195404251737, 0.22622610111871075, 0.07657068721469372, 0.11812181767797279, 0.15199181353372915, 0.1653316412721911, 0.16909641183672414, 0.1793506978860786, 0.14028526992807466, 0.1835008566418002, 0.3381702700449575, 0.18642801731344194, 0.4670714580964658, 27.531737935158517, 97.83407103630805, 102.53808329182287, 32.96764289179156, 67.13419745045324, 84.1635048773981, 40.385358718133745, 23.050557490318056, 26.883242668644076, 67.5029630045737, 54.3242738323827, 76.43594141929381, 66.43821208707749, 53.65797296647103, 22.01123922101913, 5.229638786085191, 0.34606630763699936, 0.24589923901423333, 0.2576423863009099, 0.24316111819878702, 1.0759606837264954, 2.202059554476892, 2.208685173142341, 6.688276567766744, 17.223205874043128, 22.75726814423838, 22.626457098991644, 26.737389333786506, 27.817751284568544, 26.108980524924498, 29.182800823642363, 29.320850603042114, 25.452165911274573, 24.453489280516102, 18.84989123190603, 21.234441264983147, 20.549722909927368, 23.764101343770182, 29.371337390715077, 35.70406875302715, 24.137012843162786, 25.776192911209602, 29.43848248450987, 26.81195947431749, 19.408013128465225, 35.49991723029844, 25.360086310294367, 20.69259132108381, 23.49330286825857, 16.715676669151552, 17.76215522520004, 16.851231821121708, 13.28010009181115, 10.82612410668404, 12.470852367339596, 11.129009531390283, 12.168554317566658, 8.983738787712591, 16.52453564828442, 14.557091439923934, 17.491046882444813, 16.144929643600218, 15.267654292045103, 15.173478184207795, 10.384183795221391, 10.186327676619253, 8.922185032598435, 7.999823016505088, 5.707514872474055, 4.911563492590382, 5.2098533703434855, 5.425105690956117, 4.423398048646988, 0.5989419416554513, 0.4946879471742338, 0.3695205797351176, 0.728855315716036, 0.46271453220998093, 19.270214380756503, 45.88392157708445, 93.66926700838151, 146.00895881652832, 119.26590165784283, 76.88523323305192, 120.49525876199047, 139.06057419315462, 58.11528774999804, 64.23349880403089, 85.67493531011766, 104.78140446447559, 82.04005133721137, 98.66862589313139, 82.00278097583403, 27.34672365650054, 0.2603205990406775, 0.2152791183682219, 0.2211283222441712, 0.2614640005894246, 0.15909142611968904, 0.1565001796810858, 0.17916441594641055, 0.2308806674855371, 0.11671485890063549, 0.2303946306628566, 0.18366772591346697, 0.10878631619796639, 0.23214512624807898, 0.20931527709528325, 0.14930940263213652, 0.20229340711187935, 0.11174569086682413, 0.20599423997825195, 0.12175406269248455, 0.1519562976975595, 0.12359674163763562, 0.12615211983962407, 0.1401245600033191, 0.14148730784654617, 0.1333863110912423, 0.16015959783427178, 0.11027186027457637, 0.13580570868667097, 0.1764740530521639, 0.1293257080138691, 0.1594807213592914, 0.3202397370290372, 0.11075325460443575, 0.10363836622526569, 0.09014840057540326, 0.1841889568153889, 0.11670689158622297, 0.16069109431437908, 0.15336455116348882, 0.2245853093242453, 0.14003923313031275, 0.1152533163586932, 0.1480655976000332, 0.1087348274285755], [0.08729229455873852, 0.006044946522677258, 0.07610791648227362, 0.0372034244449629, 0.07159316882250771, 0.04771438442290791, 0.0312987404815372, 0.06621814272817104, 0.04067834564334443, 0.026671536860146353, 0.017808345822437156, 0.030449003416804538, 0.05369604107052569, 0.014820378837025455, 0.0901966947581499, 0.039566702269498384, 0.06955155982605873, 0.009599035725958887, 0.07321084008341835, 0.03600745394285168, 0.033955399337555134, 0.07120858502363966, 0.039812735236820676, 0.08461045056220987, 0.06571871468857413, 0.02564744009906727, 0.04326745469663893, 0.027900700036796833, 0.062285349929645184, 0.022400267264475266, 0.06958727484508868, 0.023860515117825522, 0.02565340409355779, 0.045340672480843724, 0.10899129834386612, 0.08133421426699047, 1.8641099790411613, 31.402966283982803, 96.78093817926224, 95.22199999901557, 93.14055504337435, 53.14076923554944, 26.79679363004623, 11.714959663729514, 28.004287442853375, 70.60774649343183, 61.82935653194305, 37.5536584854126, 50.78120862284015, 54.36326611426569, 29.773841211872718, 10.083159535161911, 1.5795862722781397, 0.02240399428222689, 0.03961132689108772, 0.0808587264750273, 0.04255488184430907, 0.11554875816669195, 1.114637827680957, 0.8675831748593239, 7.429853600840415, 8.775444261489376, 5.63912001348311, 6.907425272849299, 8.205767062402542, 10.149791779056674, 8.209734539831839, 5.4865741345190235, 2.0815185000819545, 4.618164810442156, 3.0308335731106424, 5.458959667913375, 5.103720407332144, 3.5449567725581512, 3.9990444192963266, 4.776473631781917, 8.433749925705696, 13.578031562989759, 13.852692592528559, 14.28287854117732, 10.092174122410437, 7.491210747149683, 7.818436439960235, 6.390616720722568, 5.339571054904692, 5.505989376575717, 8.626084327697754, 16.36525604032701, 31.30582682548031, 18.070388801636234, 11.557539259233783, 7.245486022964601, 12.461036635983376, 11.044622678910534, 15.86995384385509, 19.583243054728356, 14.368528396852556, 18.241394335223784, 14.298459176094303, 13.86818007115395, 4.4949219784429, 2.5358196708463856, 2.7969911790663198, 1.7588349119309457, 2.7581734426559943, 2.1705526257714918, 3.187025295149896, 1.8906391748497564, 1.0514555535008832, 2.6223469116995415, 0.9030106964130556, 0.1684425098280753, 0.1192754081961128, 0.1387551318733923, 0.013653540743454812, 0.021691704882429014, 0.06722359482439295, 6.14926592957589, 26.04039199890629, 40.59736282594743, 45.949001542983524, 59.48376347941738, 26.50478493782782, 32.78897304688731, 43.410114088366115, 21.039415136460338, 35.206978936349195, 53.13035926511211, 65.6969194258413, 68.21977615356445, 74.36308645432996, 84.53776174975981, 25.92249143508173, 0.13593171482845662, 0.04895905896480526, 0.07588484700048163, 0.060304487875152024, 0.0580275404988037, 0.05184672780395035, 0.07577672901172793, 0.029284563178436893, 0.02036824968883828, 0.028594335195638483, 0.03479014789204925, 0.03251012084224532, 0.08231227105904011, 0.07675812594712743, 0.015375752362512774, 0.023892506949543476, 0.028363999369884693, 0.024130913511579557, 0.07373126659301982, 0.0331797966012551, 0.04168490856705655, 0.02666095527069223, 0.07764443604936523, 0.03564454277136153, 0.013043810406910076, 0.05966678862610172, 0.03074066075045736, 0.030310640276800242, 0.04293006574434619, 0.0402515274172108, 0.041538658551871784, 0.052690520026390596, 0.05481721457814979, 0.05370690036685236, 0.0016911123994730354, 0.026942425550171928, 0.04232921915489339, 0.11381196789443494, 0.07716313365005678, 0.07567977292403098, 0.04849315493277485, 0.008963864567058702, 0.056897208410044836, 0.12490320500106582, 0.07288814852795295, 0.03903858806757678, 0.03329030478433256, 0.04510099038241371, 0.06336377573109443, 0.04102077928461856, 0.04898411003992923, 0.03841606118986684, 0.015011094510555269, 0.03406715241350955, 0.019712265836255207, 0.036525015283616326, 0.04007692448794842, 0.03089151495406705, 0.012152791736767659, 0.07120978012080155, 0.03967876561106213, 0.06576905432607859, 0.02847655300771998, 0.11040228674368513, 0.04442032892256976, 0.038774992534590345, 0.047377826676013014, 0.020179108325992862, 0.02829573327495206, 0.031144729995679472, 0.003453537769195053, 0.10041831481841304, 0.06645107942242777, 0.08000621617200875, 0.03246305623061715, 0.051816057473901785, 0.062278275107664455, 0.022046439980547276, 0.10015601397401865, 3.927337854139267, 45.24655603593396, 113.84657459874308, 107.68428002634357, 105.95371461683705, 62.604848338711655, 31.603913230280725, 18.99550726336818, 22.86185814488319, 43.34811710542248, 34.915699804982836, 34.8928363092484, 46.01998467599192, 46.72381477971231, 31.574338559181463, 12.63425732812574, 2.029401354732052, 0.12735666286560798, 0.07618869279300974, 0.04189922932475325, 0.11833642954908072, 0.26198564517882567, 0.6555123254656792, 0.543925490590834, 2.5412906417923593, 4.3273705820883475, 4.5009285980655305, 7.8033201156124, 8.161644320334158, 5.116249438255064, 3.955848582329289, 0.9860758327188032, 1.603730421873831, 1.7954892160431033, 1.4972415037693516, 2.454975454076644, 2.6845272654487244, 0.8181678684007737, 2.4320452780492845, 3.637634534989634, 3.5410476403851665, 5.099244002372989, 6.8387367263917005, 7.317333548299729, 12.005196425222582, 9.204029883107832, 6.382985259256055, 2.5683912779054334, 3.1787444362717294, 4.030264769831012, 9.04174573959843, 14.924718526101882, 24.544898156196844, 18.93956838115569, 11.930787101868662, 8.389785059036749, 13.862828977646368, 14.125985695469765, 18.822048287237845, 20.613114295467255, 17.918183188284598, 18.48571877325735, 15.852002136168943, 12.575949334329175, 5.277410803302642, 2.2253069521919375, 1.6474194968900375, 1.7613310102493533, 0.8029387146234513, 0.4950760166731573, 1.7122615465233404, 1.9943861110556511, 2.664657028452043, 2.9711956506775272, 1.8396625812015228, 0.6015850062812529, 0.2536227229622103, 0.11086544818094662, 0.027116948040202263, 0.11403333666103502, 0.065118346904074, 5.410898866191988, 25.989905211233324, 51.02366601267169, 51.21221434685492, 45.60816718686012, 33.813388270716516, 50.103172025372906, 44.838021570636386, 24.67332047800864, 61.13380655165642, 69.34151910966443, 78.49279311395462, 77.29190457251765, 82.07568214785668, 97.768763572939, 45.66701842892555, 0.41159253507371873, 0.155041839386667, 0.09123224644891678, 0.12141817144208378, 0.04464937389017113, 0.08654510602355005, 0.11392202408563708, 0.018441975229389725, 0.008739908338494359, 0.08862269050892323, 0.07124054621184064, 0.024495410485072963, 0.054079636615971406, 0.08059562889919167, 0.06548904918975408, 0.07052873561699545, 0.0322394389959593, 0.024012775092776266, 0.05220674699352634, 0.0253443201748474, 0.042661651518316045, 0.026555497522255587, 0.013972927587136868, 0.022054550936445597, 0.01958395760025709, 0.04748486448079348, 0.047138485486709306, 0.03768956468951318, 0.0353454199108866, 0.07673368774234288, 0.06741344673378814, 0.10115339150351864, 0.010419951605370209, 0.013832431849873355, 0.005859696407682233, 0.02089748620956896, 0.037856230947880015, 0.07694277611951675, 0.02462096463498329, 0.16646489981682072, 0.03392700428864168, 0.025401282642457276, 0.03421262101901155, 0.25813764682219875, 0.221239788037154, 0.1977658428011402, 0.20090075119608836, 0.12973919631012026, 0.22840566722856415, 0.20985890840811117, 0.21758554863833615, 0.12597549060780194, 0.14634966790195436, 0.12144400392689052, 0.09821126147383645, 0.17779595308726837, 0.22366068716491425, 0.27230975248159905, 0.1554768700753489, 0.17042240278134424, 0.1577018805208706, 0.13156424757213364, 0.1523611904873002, 0.19894296754031413, 0.11285430436292965, 0.10567310341303388, 0.18696024923795657, 0.1564549192065193, 0.13360714359629539, 0.15005937206649012, 0.1216896040545356, 0.20059275320701062, 0.09572563557735375, 0.17826417070483008, 0.2061675137449657, 0.15079242627947562, 0.18864930457165166, 0.20886141596542251, 0.2255484503844092, 5.022741604235865, 57.154966015969556, 131.71988979462657, 114.20432613741968, 114.55253847183721, 73.77762563766973, 44.639737913685465, 23.314232941596742, 43.578466138532086, 96.33340358734132, 89.2427702872984, 53.88014778014153, 67.76605206151163, 73.6496308542067, 47.19578573780675, 16.915103697007705, 3.421138332736108, 0.19752955064177516, 0.3559325088656718, 0.27292191802013305, 0.5530918245354007, 0.6750041763148, 3.0939972160323976, 6.185021765770451, 17.45135053511589, 20.664830746189242, 17.280531314111528, 24.128754292764974, 22.40035991514883, 24.816047683838878, 25.366238547909646, 19.05590980283676, 13.281675904027878, 15.219479741588717, 11.706592267559422, 16.526322287897912, 14.65003102056442, 15.135641040340548, 16.000719781844847, 17.917943923704087, 21.3336125112349, 31.26567940558157, 31.253094480883693, 28.83630648736031, 27.586800167637488, 22.07938059683769, 20.196740973380304, 19.233116603666737, 17.335732790731615, 9.732980132102966, 11.017051358376781, 16.92304845779173, 34.00601586987896, 23.297831550721202, 16.858943200880482, 13.646207259547326, 18.153586195361232, 17.88443119295182, 25.071013512149936, 29.01701400356908, 22.950609614772183, 28.59907957815355, 27.620558046525527, 25.064280763749156, 11.909950490920775, 9.758569675107157, 12.468866667439862, 8.596112516618545, 7.0117309016566125, 7.654727005189465, 9.702248361802871, 9.267347724206987, 7.085298386312301, 10.259358286857605, 4.027201153578297, 1.3753441673132683, 0.6623324078898276, 0.4873798973858357, 0.1641024225541661, 0.21908990017348723, 0.33219447780040007, 11.049323639562054, 38.573929725154755, 59.012659365131015, 63.249850734587646, 79.53589254809965, 38.893230269032145, 44.6467746457746, 55.76930246045513, 34.342151226535925, 53.199632244725386, 70.98769864728375, 89.99434348075621, 90.47142920955535, 93.92610380726477, 110.46198491127261, 48.0637199647965, 0.6299531195432909, 0.1972962155817978, 0.2715946860130756, 0.2187561156648782, 0.1729690322592374, 0.13825581108610477, 0.24587803370048925, 0.13427128053961263, 0.07675791144250863, 0.14068107691503343, 0.148378330012483, 0.08831283858706875, 0.13121777664749854, 0.1982037846239344, 0.24602774260265214, 0.2055934074545099, 0.1376196363520238, 0.10755622413970771, 0.15858223811993677, 0.1062777842725477, 0.08188156110625114, 0.1685204516134916, 0.19820211455225947, 0.07987473250156449, 0.15242351940081966, 0.22768537604039718, 0.13801322168400212, 0.1006842086151723, 0.15382107827932606, 0.23657035653389272, 0.16219417414357587, 0.15452217130411058, 0.12156676185587723, 0.10637009020654425, 0.09505819679508287, 0.18230572883640567, 0.10707902031079417, 0.2834257189064257, 0.1901060054379125, 0.29439444323220565, 0.1661957578072625, 0.130776510003113, 0.17908848131135588], [0.021251658233062878, 0.05559808799936887, 0.044992274845079075, 0.05201675335786516, 0.03059570733908444, 0.059175910127739755, 0.06665795380550046, 0.06689945536275065, 0.270647770695148, 0.060773057893158934, 0.05170929929121368, 0.06073333623428499, 0.030117206906359044, 0.021226563107883258, 0.10302750303620294, 0.056447560763767654, 0.05902740781405761, 0.09287084723191877, 0.06225251540121052, 0.055590549694193955, 0.39422143010362504, 0.3013518392559021, 0.34775163978338247, 0.2803861578145335, 0.14894114416693488, 0.20459327966936175, 0.044203579666153084, 0.10260577163388652, 0.06725374038421339, 0.05141329823903019, 0.05108304922619174, 0.003549074200207308, 0.08202601464525347, 0.15313432642048405, 0.2052060887217522, 5.531942719413388, 70.01331129381734, 100.63356860991448, 89.18173036267682, 79.55359812705748, 95.76752324258128, 72.30162989708685, 56.82281578740766, 54.99119443278159, 54.11428974520776, 60.956229086845156, 58.53983725270918, 66.76037203881049, 39.04337075448806, 17.500284064200617, 3.898949209720858, 0.3027451999725834, 0.39011492303782896, 0.015280907804657136, 0.04244439664386934, 0.08404641832795837, 0.1547102765330384, 0.3687312946684899, 0.7305323741128369, 2.005812833386083, 2.509381424996161, 7.9235451740603295, 4.3019050840408575, 3.7472012879387027, 6.86789611654897, 6.804976886318577, 7.724938411866465, 6.006523524561237, 3.3145768507834408, 6.002785015490748, 6.500949071299646, 12.470579762612621, 10.781877809955228, 14.353317445324315, 13.853678088034354, 12.644572181086387, 6.10876206428774, 7.845685635843585, 9.551957845687866, 11.054518818855287, 13.779357998601853, 10.388580772184557, 8.430782652670338, 12.843985480646934, 32.24819391004501, 62.77925652842369, 97.19088077545167, 120.51801635373025, 116.42245784882577, 123.23330063973705, 69.63750900760775, 32.97480121735604, 31.744590997695926, 41.903159080013154, 43.52238016743814, 47.012893461412006, 46.97491707340364, 47.06250359935146, 35.006428149438676, 31.16983432923594, 17.729909420013428, 6.730411648750306, 1.2289809243332956, 1.5298967063426974, 1.8657874051601657, 1.7400570550272543, 1.541152070126226, 1.5761070073612276, 0.5830511943467203, 1.1417575853486215, 0.533251740759419, 0.06996625854123024, 0.21982068676621686, 0.05599245091059035, 0.2251681490170379, 0.05959438182593835, 0.030362295670314666, 0.07782869551691317, 0.8791854232549668, 11.679650487438327, 39.46532364814512, 39.267730328344534, 35.943141137399984, 29.58448486943399, 31.873376138748664, 39.95187405617007, 16.660471270161292, 23.41683626174927, 45.66641046154884, 64.63645565894343, 68.54694889437768, 67.55808799497544, 77.06559950305571, 39.125367902940326, 2.026166870228706, 0.19815921362849975, 0.07164579140202654, 0.069318906584334, 0.05052329176255772, 0.06676003502141084, 0.11008339498432414, 0.12633051107367202, 0.06708377611733253, 0.03964721044946102, 0.10776985541827257, 0.043790688918482874, 0.054501387170485915, 0.12516773516131988, 0.11652843906514107, 0.14496194559239572, 0.052837953647418376, 0.23983726187819437, 0.39343557711089816, 0.5258990127232768, 0.3515445104529781, 0.18329517735588938, 0.05990696868168251, 0.15372329481667088, 0.25374603247450245, 0.07519129994175128, 0.017219390832789002, 0.09069097468689566, 0.009374961711376185, 0.0455363389975842, 0.03158874498049338, 0.05173477554513563, 0.07381991828761755, 0.03310031880955062, 0.02335105707207995, 0.02450299092508372, 0.06868112306561201, 0.16024091040655492, 0.014769476124896638, 0.06388817823702289, 0.02601668107203178, 0.12469318965750358, 0.06915691729274488, 0.050642824461383205, 0.04187533504239494, 0.035740863006081314, 0.011292054607052238, 0.08071081787948647, 0.01225534313914156, 0.13298037642192456, 0.14160833441682402, 0.11338118899373278, 0.02122595789842308, 0.06438938360060416, 0.02076375598628675, 0.0690601297443913, 0.08343668894902354, 0.05604552165154488, 0.026187999399318814, 0.03254518851697926, 0.05300227184629729, 0.05862938683299769, 0.27901593295316546, 0.2607858289153345, 0.14856828917418757, 0.18805190920829776, 0.11069553754022045, 0.18160057554562248, 0.07768899938392063, 0.11421455475952356, 0.0035504742258889305, 0.04385682528898601, 0.04648811897383102, 0.042250959442988525, 0.08335287893010725, 0.07674681848936504, 0.1363766740166372, 13.542798872916931, 90.33177714194022, 114.60242317568873, 97.9553742562571, 84.87882752572337, 100.25837036871143, 98.8084505450341, 69.35571024494787, 32.122919290296494, 38.96108335064304, 48.551580444459, 58.637516037110366, 57.92823776122063, 41.929984169621626, 20.509387216260357, 4.708253808559911, 0.22367056969913746, 0.2731861264234589, 0.03445443667231068, 0.20411655847584048, 0.11302400815991626, 0.265437055138811, 0.3059407672093761, 0.569080263376236, 0.9103375613208741, 2.934507270974498, 5.233374843674322, 1.374871521707504, 0.9718604890569564, 3.11855100816296, 3.66796646868029, 5.437833782165281, 8.399983221484769, 6.272655360160336, 8.812282181555226, 11.11294448375702, 17.627253147863573, 15.711262591423528, 19.117896979854955, 17.361628278609246, 15.631836556619215, 9.917365850940827, 7.512695039472273, 7.84791305180519, 6.825714457419611, 5.223326711885391, 5.373988872574222, 4.364911096711313, 9.83368012212938, 30.84115343709146, 64.8131388233554, 96.04278733653408, 122.06378321493827, 122.18931474993308, 127.29435013186549, 76.16434866382231, 37.117973373782256, 39.64072419751076, 48.81074713122461, 49.93977785110474, 54.95815238645, 56.24539975197085, 53.787556309853834, 43.16461293928085, 37.111575988031205, 22.20016606392399, 8.83430923185041, 3.132349661281032, 0.7286237120147675, 0.3110971518101231, 1.4113602282539492, 0.6609593331813812, 0.7553438782211274, 0.2783152076505846, 1.0379874826438966, 1.822238187155416, 0.5840266387789481, 0.08693666888340827, 0.09297364090959873, 0.07553365697423298, 0.01782982309739436, 0.01851381895492875, 0.011887171816441321, 1.2414757570912762, 11.994969825590811, 34.96480395717006, 35.60540153134254, 26.236890977428807, 22.952727694665235, 33.55455498541556, 30.10756038850354, 25.14246144602376, 42.35776962772493, 66.07423966930759, 78.40541055125576, 82.75222824465844, 78.26187533717003, 92.82122704290575, 65.7043444725775, 7.466755259421564, 0.28123464615594956, 0.07892939532476087, 0.043426054049163096, 0.06634912078058527, 0.16828901645156646, 0.08694911781217783, 0.03840090414028495, 0.031387204484593485, 0.05909331818862308, 0.10679683182388545, 0.06592234085884786, 0.0708598081743525, 0.10810791469749906, 0.0023178445013810793, 0.1659489549215763, 0.08943232287081981, 0.18460147984085545, 0.33161442666765184, 0.37152515604130687, 0.156158703649717, 0.0839839285359748, 0.01142042891813382, 0.04762423885685783, 0.15511837157030262, 0.03261733484724837, 0.02333545186106236, 0.0652263193361221, 0.06114834904550545, 0.05561402645863353, 0.04026402231125582, 0.09096835214163988, 0.028656721565752264, 0.03698247319628154, 0.05561033774527812, 0.02357622755000428, 0.032510726051705505, 0.08389087183581245, 0.044593775059066476, 0.12371103429505903, 0.0036246054420893594, 0.10973006757276674, 0.1253120508044958, 0.15393199248900338, 0.1858480274677277, 0.21877215754601265, 0.09899841681603463, 0.23209903839855428, 0.09674683844129886, 0.18432346653313408, 0.3142140877823676, 0.20326345828512024, 0.1670205740318183, 0.18629733803531817, 0.1377270572007664, 0.12092586035930342, 0.21098116593014812, 0.2565174321493795, 0.1392977059848847, 0.1881798458916526, 0.11854810730343866, 0.21254625291593615, 0.4230835781462731, 0.3700351763156153, 0.4331998917604647, 0.2762479653521892, 0.15712671702907932, 0.2619570547774915, 0.18971177659207777, 0.18849469270677338, 0.23629113280725098, 0.09209242529205738, 0.14332051028407392, 0.2570280450726709, 0.11080265195379335, 0.2141792459353324, 0.2904409698901638, 19.318245764701597, 112.96584560025124, 125.90821589193038, 108.60921413667741, 98.8842228920229, 114.3674575128863, 93.22489384681948, 83.97933390832718, 77.48570103799143, 80.1146774907266, 90.04481654013358, 77.72378890745102, 88.57255489595475, 56.72909467451034, 27.60727493993698, 6.348406624409461, 0.815850850795546, 0.41309336260441815, 0.17542642781571036, 0.49688778397056366, 0.33227402837045733, 0.7231542732446425, 1.5970340779712124, 2.6663772329207394, 5.72909624345841, 10.23011701722299, 16.773204111283828, 11.814411359448588, 14.163565924090726, 17.220701440688103, 18.08996731235135, 16.94851444613549, 15.35965838739949, 5.179586400908809, 7.871438447506198, 9.161883035013753, 21.797774030316262, 16.156861493664405, 20.17032773263993, 19.833966839698054, 21.672585702711537, 13.370535239096611, 15.881389514092477, 18.395455229666926, 26.48682636599387, 26.541527740416992, 24.537429963388753, 19.13241171067761, 18.356619842590824, 31.911507460378836, 57.061103697746034, 90.18812425674932, 114.20498509560863, 111.23957910845357, 118.57751000312068, 81.14815927320912, 41.780102560597086, 39.03873843531455, 52.48958518428188, 49.32744487639397, 55.45639537995862, 59.38431962843865, 54.555073938062115, 41.99627614790394, 38.93703922148674, 25.72899699211121, 15.144137874726328, 7.5407777390172415, 5.157069054342085, 4.457158869312656, 6.196303973274847, 5.28646118217899, 6.403491410516924, 4.31814810922069, 5.621799807394705, 4.7240178142824485, 1.864376332490675, 0.7219906163311774, 0.5183281641333334, 0.4685920506956116, 0.1775348396791566, 0.1995693976359983, 0.35257606316478024, 1.837670262302122, 21.52685396132931, 57.76537310692572, 58.67248396719656, 52.17473653055007, 39.2313503449963, 48.1769391798204, 61.47136965105611, 25.954529354649207, 35.76674038364042, 59.43514177876135, 80.44761611569314, 92.30246220865558, 86.94328861851847, 109.2421748561244, 72.15752201695597, 5.866809679615883, 0.7439112110484032, 0.10112892265521711, 0.162713076138208, 0.2297609993406842, 0.28142396180379775, 0.4153317795886148, 0.13401297101330373, 0.16664352087724596, 0.1989667622312423, 0.15428797822565804, 0.3062791329237723, 0.21674490503726468, 0.40498153336586495, 0.14254032634198666, 0.24373775257939295, 0.21187770330617506, 0.3461522627021036, 0.5471328249381435, 0.6557704051656108, 0.4178811056960014, 0.2278744465401096, 0.11412578049085795, 0.20269051644830935, 0.24640275796334593, 0.10449349654898529, 0.14894535765051842, 0.14588066887470985, 0.17302926209184433, 0.12356314868215593, 0.17812440562392437, 0.1868328488161487, 0.08626031283769878, 0.08788586714335027, 0.13772356383983167, 0.1549375901419309, 0.2497194743444843, 0.23973641406384208, 0.11017134953891078, 0.19536294673960056, 0.13936385001626708, 0.21388034907079514], [0.01271935301877919, 0.019862074329848253, 0.06382880642289115, 0.07266592174287766, 0.09763242076000861, 0.37688259275690206, 0.013223232029216185, 0.047616539673218806, 0.09415619721215579, 0.07051427187698503, 0.043624761934962966, 0.032835440079291026, 0.014054354114998734, 0.018091817506619038, 0.1573531266542212, 0.05737556520128443, 0.14585914180403756, 0.19326153691978226, 0.1172550887830796, 0.34345912656957106, 0.514176274018903, 0.2873597336151908, 0.4342590542810579, 0.9439466352904997, 0.8062867027136588, 0.3106273254079204, 0.22540084056315884, 0.06418297270072565, 0.07852142286156455, 0.06201725746054323, 0.06329126167862166, 0.06545298177027895, 0.12607954833055698, 0.46565471637633543, 17.138521902022823, 93.46157750775738, 89.15086915416103, 92.25702547257947, 97.43527581614833, 96.68364770950811, 51.2719795011705, 27.269080338939546, 25.97227023493859, 31.20387854114656, 44.403305284438595, 49.543336053048414, 44.01613596946963, 27.081710676993094, 6.207099806877875, 1.0042407579960362, 0.13094645894823537, 0.09348783146349654, 2.034182846546173, 0.11981644247087742, 0.12318244128818474, 0.27506083550472415, 0.08936182746002752, 0.18922383987134506, 0.2801381904752024, 0.22852318511614877, 1.0459188828545234, 2.566325169417166, 3.2251561264837942, 4.312577362983458, 11.171635889237928, 16.61187114254121, 25.13660534735649, 31.810118113794637, 42.17761516571045, 45.39956377398583, 48.52244507881903, 57.63245967126662, 58.903907729733376, 54.361453979246086, 60.87058805650281, 57.23238968080091, 46.29788460270051, 38.8125471145876, 27.029960886124645, 21.64125773214525, 17.43964029896644, 19.9055245999367, 37.85739114207607, 66.6856744212489, 122.66987569870489, 116.12919007578205, 95.31687428874355, 96.32840648774179, 98.57713268649195, 97.519512637969, 79.83622843219389, 52.64584848957678, 65.03725128789102, 78.34906962610061, 74.54619053871401, 78.2693043062764, 76.00917185506513, 74.95152827232116, 66.80910356583135, 64.62137414563087, 46.81305262350267, 20.197545059265632, 10.99230218318201, 9.07973683649494, 5.100558486676985, 1.4066997170448305, 0.1115980504020568, 1.4997882251777959, 1.1056624641341548, 1.1501580765170436, 2.20123561159257, 0.5454472476436246, 0.051183088817783905, 0.22915516168840472, 0.14575173627705346, 0.057882389819790284, 0.051528085023164756, 0.09493307931528938, 0.023446335427222714, 0.6994443422844333, 6.293046782093664, 29.264372394930934, 53.14507207562847, 68.87544739630916, 82.58506467265468, 54.01121377944947, 47.074525663929606, 26.758226925326934, 15.857671922253026, 36.892256659846154, 64.82037559632333, 61.48343878407633, 64.56321324071577, 73.93631689010128, 65.25031443565123, 12.088017271411035, 0.16500861263803898, 0.04095334056464415, 0.15137014850493402, 0.06049473815026784, 0.2418747493216107, 0.21231912316814547, 0.11786892439328855, 0.07842779159545898, 0.07651460191775715, 0.12545443590610258, 0.3648313861941138, 0.2876912658253024, 0.01960080770415164, 0.49878762073574534, 0.3724547271286288, 0.4334864699311795, 0.3199015858192598, 0.34448188459200246, 0.6780179049218855, 0.12268130487251667, 0.012469464713977951, 0.014339543751350815, 0.06335443328885783, 0.04063541407606775, 0.25392759531255693, 0.17704969151846825, 0.03964937847828673, 0.033536046638243625, 0.06067666488008634, 0.0395541958841345, 0.0064074531039823935, 0.08441815483233622, 0.03226295023435547, 0.058868835274610794, 0.024714695492519007, 0.1223914631672444, 0.16783408279861176, 0.041860633815128, 0.014915633251920584, 0.10560041699077814, 0.013935774238029075, 0.039907481160856066, 0.10107972448871982, 0.043204991717732726, 0.06816293353274946, 0.19225419258638737, 0.04938906794714351, 0.03393483370722782, 0.08743730734192556, 0.013169578103829297, 0.021951923882889173, 0.0627260534994064, 0.05273039490284939, 0.06615793587820185, 0.13481177089195098, 0.10805418129049002, 0.221099256868324, 0.2067584433262387, 0.12499587099638679, 0.13913338012512655, 0.285364227790025, 0.34921594024185215, 0.30261024592384217, 0.6180685830693091, 0.5906773238412796, 0.21769283159125238, 0.19450083735489077, 0.034207595482228265, 0.12982971725925324, 0.05832781632160468, 0.09840057712168464, 0.05421688126760626, 0.0492963751387452, 0.21660045149826238, 31.176749467849735, 114.77372877059446, 99.38264631455945, 100.99371279439619, 104.7095387981784, 115.31830280057846, 80.3272307303644, 49.89208967454972, 45.3720405024867, 45.761253372315444, 50.43991534940658, 53.135399510783536, 42.93488364065848, 33.43558949808921, 9.520778925188127, 1.4569112033613267, 0.11219095649017442, 0.1662796444349712, 2.12588393880475, 0.17058521178701233, 0.34408229313069777, 0.3144740980238684, 0.2559925087036625, 0.48155382936519964, 0.3141204105509866, 0.13057784808258857, 0.17375437963393428, 1.9044472661710556, 2.3568747697337984, 4.45633517157647, 11.065177859798556, 21.08672284310864, 30.319772381936353, 38.81859933176349, 49.08086115314115, 54.328207969665534, 57.15740573021674, 67.0904944019933, 65.73344061451574, 62.200220554105705, 66.2438351108182, 62.91534708392236, 52.648762810614805, 42.80234675253592, 29.13801520101486, 25.05720873032847, 16.584700884357577, 18.242957399737453, 40.15307203415902, 76.02145671844482, 128.32908707280313, 131.6524720961048, 113.77617589889036, 113.10893366413733, 115.91331066623812, 113.16075601885396, 92.08334292134931, 61.13428115844727, 70.47366419146138, 84.94289552011799, 81.2178284122098, 81.26091172618251, 81.60942216073313, 85.23151136213734, 77.21894848731257, 70.65679965480682, 56.35925439096267, 29.157838859865745, 15.840011450552172, 10.938695150036967, 6.533896000154558, 2.5818226991161226, 0.6754249730898488, 0.618783251172112, 0.5101267638946734, 0.4814164544786177, 3.2910011997145996, 0.31049157462773785, 0.05178775435553924, 0.03796396589267158, 0.11662956267114609, 0.08730078281293954, 0.05616742156205639, 0.06412011901697805, 0.014995429927723543, 0.6311602902508552, 6.860577954399971, 28.803472326647853, 47.072850811866026, 59.87028560330791, 81.40436064812445, 60.33063457858179, 36.45382981146536, 24.101754657683838, 31.229126837945756, 52.98481579749815, 79.7907446276757, 72.43174276044293, 76.53120794603902, 85.21978347532212, 94.29917612383443, 27.174027581368726, 0.16884746390484995, 0.03454673111498837, 0.11028048642460378, 0.07059110283491112, 0.1310185937871856, 0.2055811653694799, 0.05106791515924758, 0.08029803438412567, 0.09518426422390247, 0.15316172172465634, 0.1895027111975416, 0.1785641860577368, 0.15823625749157322, 0.2570841533522452, 0.24352212947222496, 0.446732068854955, 0.23162378809384762, 0.30315128785948603, 0.32662039141981836, 0.10583017442014911, 0.07855694635861343, 0.05145937459723604, 0.05808956297715345, 0.09131915146304716, 0.12807050359345254, 0.034133327088408896, 0.022750403919828036, 0.09593090117578545, 0.03108943759974453, 0.04479250592750408, 0.0035764879383702554, 0.020594933190413063, 0.07230459637339078, 0.13678231757254372, 0.01873817546443353, 0.10527172696686561, 0.07058195574509521, 0.02466400728500899, 0.031148037580292554, 0.08827710824628031, 0.13863712368953612, 0.1393249480714721, 0.2577416406523797, 0.12180581959264895, 0.20307605785708274, 0.45443063962363434, 0.13787284373275696, 0.09930576363037671, 0.15745166088304213, 0.160688535580712, 0.050954250693922086, 0.20867891850010042, 0.15961835671576763, 0.17296357771321652, 0.26985110054093026, 0.2305951924814332, 0.3276995028699598, 0.32125373100561483, 0.36659053857288054, 0.32721600945918794, 0.7355919864869888, 0.5662869842302415, 0.7331775837848264, 1.2566999466188493, 1.0172984508737442, 0.3787322354412848, 0.41907856240868574, 0.17975994205522924, 0.21219253479953737, 0.2602515591969413, 0.20181881564278759, 0.2372056732494985, 0.26752418507972076, 0.48580705759025394, 41.12853411705264, 139.75160168063258, 110.60035044147124, 111.93543895598381, 118.82605491145965, 115.78913627132293, 68.27809395328646, 38.98785744943927, 39.362239837646484, 50.32741000575405, 62.78665411856867, 69.46759977648335, 64.94165528205134, 44.3340636837867, 12.224304926010872, 2.6619655470694266, 0.2544443522610011, 0.5285209333223682, 4.210030426902156, 0.33712934041696213, 0.73293948365796, 0.6571595370769501, 0.6603892411916488, 0.990407171268617, 0.7015670799920637, 0.5856316236238326, 1.5071943955075358, 7.59513835753164, 9.511420149956981, 12.965157301195207, 18.776158517406834, 24.360385940920924, 30.03966219963566, 36.554713172297326, 50.9710434944399, 51.46519545585879, 55.65556157019831, 64.02893935480427, 67.49836598673176, 64.58171898318876, 67.40801026744228, 63.00079984049644, 52.204232754245886, 45.283904844714755, 34.833161369446785, 30.379996453562093, 21.828282225516535, 25.686268652639082, 48.02771260661464, 78.0372255079208, 132.51487578115157, 127.02743284163938, 112.27010342382617, 114.93852323101414, 117.86791401524698, 112.84027484155472, 87.91713468490109, 68.71397910579559, 74.22425023971066, 86.80316586648264, 84.48328787280668, 82.18630083145635, 82.06610371989589, 85.93359208876088, 79.74671210012129, 77.58798076260474, 65.42236528088971, 29.10218042712058, 13.96037930442441, 10.066695386363614, 6.760436902123113, 3.3287226336617626, 1.4690341463973446, 4.718108763617854, 5.379158556461335, 3.7201205088246256, 7.220060238915106, 1.4378184536772391, 0.2304394314846685, 0.4216023931099523, 0.277648282147223, 0.5951517676153492, 0.18300363493542518, 0.4734608765331007, 0.1650823869051472, 1.2182914850211914, 10.128502134353885, 45.57807868526828, 75.66582325966128, 89.71202696523359, 95.13114221634405, 71.84163785749867, 64.2518005832549, 35.158039523709206, 22.04604437274318, 49.566011275014574, 80.62417768662976, 81.07548559865644, 83.7231796018539, 101.27726877889326, 105.79905556094263, 27.635480703846103, 0.355065634414073, 0.1931516186244065, 0.2985269053568763, 0.2655064933482678, 0.40456897969688144, 0.2754011011171726, 0.3441490347106611, 0.23361039197733327, 0.28989432019091427, 0.31642854153629274, 0.5271418524845954, 0.29091824266699057, 0.2885188552881441, 0.5899446373504977, 0.8101598593977191, 0.7133490832582597, 0.511386610807911, 0.6161545277122529, 0.8293857245195297, 0.4362682884018268, 0.23949266020809454, 0.22429332257278506, 0.2908942487932021, 0.38144587208667113, 0.3058742401340316, 0.17705896118235204, 0.10389630036849169, 0.20549668119319026, 0.09424245105155053, 0.10004124634208218, 0.09690813059287687, 0.2202938992770449, 0.14007067337872522, 0.22844974792772726, 0.15645231450757674, 0.3051675699891583, 0.27315419587877493, 0.18212824158610838, 0.17159296980788633, 0.1891173996151455], [0.050714698830439206, 0.0494935316964984, 0.01964216304552411, 0.055622537695472284, 0.07222309994000582, 0.09259826548758054, 0.02652951948074324, 0.0423621877487148, 0.03882574969001355, 0.036251724907948125, 0.06684667956564697, 0.03037607567685266, 0.037047334030390754, 0.03396111052303064, 0.0850703101605177, 0.03699917008259124, 0.029851230755147916, 0.01988236416852282, 0.06159159985761489, 0.1918539269677093, 0.2882106427944476, 0.0927193686666508, 0.14529870252215094, 0.42790689836105994, 0.5769625113856408, 0.1782065608929242, 0.07424885857730143, 0.04089648151890405, 0.0561078429041851, 0.10134426230985312, 0.03620438067422759, 0.19999810043842564, 0.46902464522469434, 31.229876010648667, 100.57682760300176, 100.32451721929736, 88.1576858028289, 71.03632034793978, 49.71422587671588, 30.81697790853439, 15.785814100696197, 26.239622908253825, 43.3125529750701, 29.595202745929843, 39.927657342726185, 30.360688586388868, 19.916615101598925, 5.706870132876981, 0.9800484367916662, 0.04938425691497903, 0.1512784937456731, 0.4900838506798591, 1.0693456064308844, 0.4862620218867256, 0.1608575958638422, 0.16793824011279693, 0.19634183856748766, 0.17954130056163958, 2.0722151283294927, 1.9937044766641434, 1.712131127715111, 1.6112013113114143, 2.5908066428476766, 19.987109899520874, 43.827328758855025, 70.22222457393524, 77.5530481338501, 84.2052153618105, 83.60098992624592, 89.08183543912827, 97.5314287985525, 96.66539299872615, 97.06920885270642, 88.2119478717927, 90.7346280928581, 88.62904487117645, 90.14146374117944, 84.82670707087364, 72.54770371221727, 63.35582140953311, 52.15837240219117, 48.7795917449459, 50.19377093161307, 91.95363798449117, 73.05972991451141, 66.38037281651651, 62.21784768566009, 65.99375263337167, 69.20998634830599, 74.0136032719766, 36.33821795063634, 39.82129835313366, 77.12344661835702, 87.63774425752702, 91.67122733208441, 92.81183688871323, 95.42073865090647, 88.07923055464222, 79.19244197107132, 85.55427535887688, 85.45930693226477, 75.23513917000064, 58.46037003301806, 48.34840951427337, 39.38531121900005, 28.26690189300045, 13.86123747594895, 2.7785910954398494, 0.3417163378288669, 0.5568791180849075, 0.6761356575354454, 0.5898120122090463, 0.16629174862417484, 0.14644041867746463, 0.25989223331693684, 0.0910695983217128, 0.1369341715208946, 0.0700532861294285, 0.07923141782802921, 0.05913462181906066, 0.18546821639662792, 0.7342515777676337, 15.124981018804736, 28.763332751489457, 39.5862973889997, 35.93376667268815, 60.29875747619137, 67.79871756030668, 29.806006608470796, 17.41198366688144, 19.39382983792213, 44.61221071981615, 67.95550254083449, 66.36382041438934, 65.0315873853622, 72.36729037377143, 27.06245380063211, 0.7096566620372957, 0.20403090984590594, 0.1013507204310548, 0.19544076595094897, 0.06459196023042164, 0.14022214428311394, 0.06479271357097934, 0.05822771161253895, 0.07158022193658738, 0.170661146422067, 0.1094140486431218, 0.01161341699996903, 0.24523675682083254, 0.1283436828863717, 0.2767319490592326, 0.07952527383402472, 0.02399243928882624, 0.018022798730300802, 0.0797814000097494, 0.06025360431522132, 0.022938947734092514, 0.04363041566384416, 0.013656182789183674, 0.06887778549665405, 0.0515758965705191, 0.04774698146408604, 0.04997884839653008, 0.03736543671918973, 0.030310682411636078, 0.02846557688298485, 0.020557362323386535, 0.02648508638113497, 0.04830684234958984, 0.06644163355832139, 0.07754603971637065, 0.02172941556050172, 0.09787141720974639, 0.059780510548021526, 0.04464322603457878, 0.06456098729564298, 0.0413609951013519, 0.05980984405464223, 0.061987479622926445, 0.06041627542506303, 0.12488989805382107, 0.07284321747119389, 0.058945129970989885, 0.09706907800488895, 0.044657632317994876, 0.06598646241811014, 0.04513328864930138, 0.042555467901571144, 0.04473174749422939, 0.0240949648357327, 0.056869679040485815, 0.05168752707240563, 0.08367884168100935, 0.12616688235392495, 0.16772850056088742, 0.237063012356239, 0.22655607050945684, 0.1808713058069829, 0.39361487232869674, 0.4126797670558576, 0.15753586926767904, 0.07745157341442763, 0.054989431143528035, 0.07340950966482201, 0.07478171869391396, 0.025607436902881153, 0.22199652968875824, 0.21331221826614874, 53.77051361145512, 117.32019424438478, 108.3509966634935, 99.36360712974303, 84.60496764029227, 72.90513361653974, 49.11320501758207, 24.918902035682436, 22.58270698208963, 31.7062125667449, 32.8610485599887, 48.14474436544603, 41.42180189009636, 26.320049147452078, 6.715856713633384, 0.9901916247702415, 0.05088898766365263, 0.20559549121366394, 1.056778209824716, 2.5921738340008647, 0.5760655143568593, 1.2587204575538635, 0.1651280610671928, 0.26456052797936624, 0.2743673420721485, 2.3014551112728734, 3.079641341201721, 1.565055974548863, 2.328635420530073, 4.854652843167705, 23.333509429808586, 48.79368089860486, 73.50975913386192, 83.38215304959206, 90.05588546875985, 86.35829848627891, 90.33039646763956, 98.88906309681555, 96.891399968055, 102.00199727089175, 96.36096216017201, 95.48567741147934, 92.32860872822424, 93.26028147051412, 87.46760752893265, 80.94751434941446, 70.29574548044513, 57.851386762434444, 56.05985203096944, 62.1236401988614, 104.35531739265689, 91.67470255205708, 78.56451757492559, 68.8254685555735, 74.12207249672183, 76.6758571132537, 84.24471362944573, 44.48764016551357, 47.6612102600836, 78.04925149486911, 92.09627105343728, 93.15629159250568, 93.3301624175041, 96.15975241507255, 90.99822705791843, 83.4331673960532, 87.73497196935838, 86.92554381585892, 78.54398788944368, 62.541631498644435, 53.64960655089348, 43.9076667447244, 32.471059060865834, 16.486082692300123, 3.9348234524649963, 0.21645345454735143, 0.9338834268912193, 1.8896645884360037, 1.3257228751336376, 0.49206578142700663, 0.28302735318579986, 0.2811768218394249, 0.11715272411463723, 0.19103456528917437, 0.08712888034361024, 0.17918456405881913, 0.04312795391606708, 0.03923458400212469, 0.8683416631913955, 15.272613148535452, 28.64228448560161, 44.37276963264712, 42.501002819307395, 46.01911390981367, 55.48865687462592, 21.480367991232104, 27.775058246427967, 38.4617107145248, 62.50954651063489, 83.89915281726469, 81.06692698694046, 78.1439688897902, 93.45095572933074, 54.36284249828708, 1.858136209268724, 0.29473109290965144, 0.233717153990461, 0.24892887160662683, 0.1514607767063764, 0.21691203477882573, 0.03549322508455765, 0.029384510839478146, 0.02008079817788976, 0.0821748731898204, 0.18054545796926946, 0.04732808458708948, 0.16990132509700714, 0.17466386389588157, 0.19296627131200608, 0.07220577869203783, 0.10958324682207839, 0.07988444649644437, 0.10528417589563517, 0.07458652715168654, 0.05599730790803029, 0.03781729835956808, 0.10424500826986567, 0.19250998934430463, 0.04509344058591993, 0.04762380984762023, 0.04258066453340073, 0.02693680821046714, 0.0075132459601117, 0.07483274781055028, 0.05641823874846582, 0.026400293854455796, 0.026683671692866954, 0.09558943280529592, 0.08735551979512939, 0.045759347192342245, 0.07962156342522753, 0.044877917070182106, 0.08216607850044966, 0.25334797318904634, 0.1123650040056917, 0.22733201032444356, 0.12926575397291493, 0.17312909867013657, 0.4753358920495357, 0.2234813306600817, 0.08252381091757167, 0.2204299718141556, 0.24643294182756256, 0.1868207293051866, 0.11117539969423126, 0.1756136903479215, 0.18229593823273338, 0.2373692176995739, 0.2004554396074626, 0.13319950821178575, 0.31047619158221834, 0.2669610798118576, 0.44102756366614376, 0.510283689345083, 0.39583459676754096, 0.361359138642588, 0.7049414215068663, 0.8188611473287306, 0.35671535879373556, 0.1733413356686792, 0.14085304833227588, 0.14567174137600009, 0.306739429192197, 0.23327306814251408, 0.3749072810094203, 0.528712700451574, 67.92038163831158, 134.64266746274888, 115.7709364737234, 111.86024711978052, 90.93501414022138, 70.07799902269917, 46.39553200814032, 20.9064781665802, 38.78765967584426, 65.06769672516855, 46.76479570327267, 62.56449107200869, 53.31370261407668, 35.061768870199884, 10.739452473578915, 1.6171088910871938, 0.19190465731005515, 0.41185928688895324, 1.4680759849086886, 5.177975777656802, 0.9436374422042602, 2.859285036402364, 0.28120550417130996, 0.6837630740577175, 0.30599509816496606, 3.8071238273574464, 3.6249066889286046, 3.542951951103826, 6.2581342554861505, 4.216706300935438, 24.241857797868793, 48.522296028752486, 74.78188576236849, 85.70744391410582, 95.19946990474578, 90.25166665354084, 94.53398489182996, 104.13776705341955, 102.27875971025037, 104.6378614056495, 102.80595764037102, 99.93018565639373, 91.7907968644173, 91.11504308639034, 89.45741807260822, 85.43672976955291, 73.70168070639335, 65.22789809011644, 63.31548767705118, 66.76492198821038, 111.45727065301712, 101.13726369796261, 83.99508614693919, 78.22867639603155, 84.02222894853162, 86.84897130535495, 90.21264691506663, 48.9686970556936, 54.41188781492172, 82.4071773405998, 93.94527635266705, 94.67183266916584, 97.36019380630987, 98.87193802864321, 93.17455414802798, 86.62512163962089, 92.11105054424655, 89.11822718958702, 79.40090810098957, 68.69293166745094, 56.66605041873071, 47.860768687340524, 35.03510459776848, 16.989216881413615, 3.321763123235395, 0.6245627410469518, 1.6701969456288124, 4.14314519013128, 3.215790487104847, 1.1434901697981743, 0.3876612659904265, 0.7360156637526328, 0.2550666454818941, 0.5921780594414281, 0.263301263292951, 0.29996840703871946, 0.28116808843708807, 0.43513751198207185, 1.5948884189128878, 24.491826526580322, 42.57658297015775, 57.80391823860907, 47.83861906297746, 81.75462045977193, 93.13486760662448, 41.45130988090269, 25.34300046582376, 30.897929745335734, 61.44198717609529, 92.09028551655432, 89.914350663462, 87.86046428065147, 108.52663255506947, 56.488590625024614, 1.278582236939861, 0.4457225181883382, 0.2505965837307515, 0.5569407728410537, 0.2917944633912656, 0.4471994437758, 0.18006567242405108, 0.1604145672172308, 0.17819534536571274, 0.38044873204442764, 0.4041101543172714, 0.1678167845332815, 0.38914839586903976, 0.5467545613646507, 0.36089703440666204, 0.19645999996892868, 0.5038826876590329, 0.3371231810700509, 0.21566587019591563, 0.3321805043566612, 0.1901227061546618, 0.2045917474935132, 0.303312074393034, 0.46016695278306163, 0.20138980640519052, 0.2213399770158914, 0.3806095492214926, 0.23391921734136922, 0.1553233154118061, 0.14750105208687245, 0.19161898312309097, 0.155372406325994, 0.30151608850686784, 0.23829555589585538, 0.227959742769599, 0.18863692459079529, 0.22361098338038693, 0.15294772272388782, 0.14478105691171464], [0.06971685861748073, 0.12100003299213226, 0.00444497237162244, 0.06868793358725887, 0.037899786876814986, 0.0968798389658332, 0.08313792231943339, 0.024921675212681297, 0.03975108431111421, 0.019935283607112306, 0.04763070463893875, 0.014396480363493246, 0.11785630692517567, 0.1193978596899298, 0.0816098373803881, 0.08414388003368532, 0.08389228909847238, 0.02278193418357161, 0.0460066786786962, 0.25258389241512746, 0.160888162772021, 0.16054019031505432, 0.08699220259703937, 0.3193095530713758, 0.24294126628627702, 0.20468438284531718, 0.03821673660328792, 0.060504624514930674, 0.02282151220095975, 0.0453281048084459, 0.07361755616241887, 1.7201789732902282, 45.00241202692832, 103.97198415571644, 91.01095907149777, 78.24865694968932, 73.1055510428644, 50.5362722950597, 25.509587449412194, 37.74448571666595, 66.22117950070289, 66.99251359508884, 59.79751779187111, 53.19335253007951, 37.34700841288413, 17.578794225569695, 3.1702995732907326, 0.11919629429617237, 0.07325175683945417, 0.08766915619132981, 0.045386534334430774, 0.6875505514683262, 2.248623971977542, 0.49253640456065056, 0.10976900782195792, 0.06057634566640181, 0.5441566652828648, 0.19761005116085853, 0.06066220880095517, 1.5059923116237888, 3.450310470596437, 12.304688999729773, 28.38470243638562, 58.29699939297092, 82.72640335944392, 91.69385940797868, 87.02777647203015, 90.18115028258293, 94.21363707511657, 94.51216866893154, 91.43492806342341, 92.13310995409566, 86.38904202368953, 90.55648188437186, 87.82222117147138, 90.34575646923435, 88.86204934889271, 92.01664693893926, 92.0184120055168, 89.4235444838001, 70.14738575104745, 59.07750398881974, 32.29737650963568, 51.54920870257963, 65.06386064714002, 69.77495670318604, 61.36116673869472, 62.23978942440402, 72.9209093893728, 63.84214824245822, 23.9790335009175, 53.904576301574714, 87.52179899523335, 88.31422759640603, 87.75714120557232, 88.67804311936902, 90.93968176072644, 84.58299452258696, 85.2056864769228, 90.02860146184122, 90.80726254370906, 90.20771257338986, 85.98750898914953, 77.23013508704402, 82.65390226917883, 79.90072788730745, 67.11581722382577, 46.66987042273245, 17.290231335547663, 4.914121858535275, 0.6306349377959006, 0.7395142340852369, 0.5055996745584473, 0.1627512119950787, 0.15563630829415015, 0.08557680919165574, 0.08469088213338007, 0.08283067509652146, 0.05418040399109164, 0.11912847253223581, 0.0792286599115018, 0.15110926492319954, 0.13365822633908642, 6.24888873869373, 25.822825970188266, 44.14837083508892, 64.47133171942927, 52.38585810507498, 76.1808853764688, 46.696060088373, 27.09841016800173, 12.488814861543718, 37.03274811467817, 58.93659284037929, 63.04922150027368, 70.4138715805546, 84.59558533084008, 46.22407736316804, 1.4855180296205706, 0.1933864705384739, 0.13028336388449516, 0.10704312909154162, 0.04577200296485136, 0.07121427705691707, 0.13254494736752204, 0.1645434287286574, 0.016633356553352168, 0.021168574082454848, 0.013503421984252431, 0.055097376762498776, 0.135832843520949, 0.07164602888928306, 0.2533104195589981, 0.024620045329474156, 0.09218139874358332, 0.10672894877291496, 0.04901035238177546, 0.03746304781206193, 0.04485640149082869, 0.13904563241427945, 0.021684271914343682, 0.06422143031452453, 0.0926895525246378, 0.019491511855214354, 0.04668181664460609, 0.037578075913892645, 0.06664207280283013, 0.04323275857454827, 0.02388858649459097, 0.054489800090631174, 0.035749987113259496, 0.05605657630029225, 0.03900388045416724, 0.05441567342307779, 0.031771962568464304, 0.007240755667519426, 0.06270891228210061, 0.07246659332585913, 0.02099310738905784, 0.0592911220906723, 0.06255417401271482, 0.04449756207665609, 0.01528427667630416, 0.022762492787273183, 0.017464734320979447, 0.04151471064335877, 0.03766061422685462, 0.043019027704553264, 0.02580021909858671, 0.11478658495170456, 0.022659685703054554, 0.07034218554655391, 0.07987443372727403, 0.06988534433466774, 0.08457728661596776, 0.18520950850459839, 0.17746941577042305, 0.16671835234568966, 0.07087269377323889, 0.09702463724440145, 0.19269631724924813, 0.11579547678270649, 0.017396994911494757, 0.05557245086698283, 0.023113650254785054, 0.053094826758869236, 0.016878809209071824, 3.1253222448210565, 64.82941665957051, 118.97232793992566, 99.880387244686, 90.7922084869877, 87.85745974509948, 64.33095401333225, 40.31844308299404, 47.07324697125343, 48.11077663975377, 51.90965883193478, 56.293762576195505, 53.703190049817486, 41.91282772248791, 20.245919650600804, 3.908747045263168, 0.340426889278235, 0.0351581075829604, 0.06680207026581611, 0.0648663192987442, 0.9803839220154671, 3.055285873912996, 0.5501813645805083, 0.12863776105786526, 0.22363681586519366, 1.0703040130676762, 0.6176647015156285, 0.9837018794590427, 2.1496262906059145, 5.322504822284945, 17.671830884871945, 32.2388586690349, 60.48404239839124, 83.73470352542016, 93.64676829307311, 93.03561595178421, 93.11416533685501, 96.65393183308264, 97.53393911546277, 94.6250387930101, 93.05671830331126, 88.18671134210403, 93.46700606807586, 89.15475230063163, 90.55550129182878, 90.14009875635948, 94.22639262291693, 94.10536396887996, 90.56848433709915, 73.39353930565619, 64.07656477343652, 35.552453456386445, 60.07253085413287, 73.10631198267784, 78.9016217570151, 70.28012660241896, 68.61617088317871, 81.55115927419355, 72.53312818465695, 32.08649812206146, 58.30534227432744, 92.01736081031062, 88.95631959361415, 90.97991743395406, 90.29122767909881, 92.79254667220577, 88.04464309446274, 84.56228440807712, 87.9887257852862, 91.36378411323794, 92.03341114905574, 89.46069717407228, 82.95663864381852, 89.26886973842498, 83.96502510193856, 72.09812948780676, 51.0694989081352, 20.55766570952631, 8.358623789202783, 1.3347804858799905, 0.04404819405247127, 1.1386547453941838, 0.321338705478176, 0.5452205469050716, 0.5624228367401708, 0.09282427674700176, 0.12775478343809807, 0.04560336786051912, 0.04233513718410846, 0.06343966823131328, 0.1001701636179801, 0.09440267068003455, 6.605423852320641, 29.20692732257228, 39.43501549382364, 55.94866852606497, 48.37338716753068, 50.1043918824965, 34.417386208811116, 24.78144649536379, 23.58351738222184, 54.34783158763763, 72.34804722570604, 80.46411360463789, 82.9127473215903, 98.55548904788111, 76.42985390078637, 7.293943474369665, 0.5366611997446706, 0.16091183488888128, 0.10615540938752313, 0.032719067493153196, 0.004620679425105694, 0.04534577079597981, 0.09557037253773983, 0.061818476796390555, 0.004796057539586459, 0.07485118754688772, 0.06990412114969186, 0.12459390466251682, 0.10016879998147489, 0.08302070320613923, 0.10309720171555396, 0.17710080490477625, 0.036702912390953114, 0.02778383715438747, 0.011610797936877897, 0.054608624158126694, 0.0921977547207667, 0.08741294574593345, 0.04464222245939797, 0.09964869522880163, 0.08501986327070384, 0.04160614323712165, 0.0128646808556251, 0.07852987281136936, 0.03070909409753738, 0.06055980199767698, 0.05463803810397944, 0.033327617096684636, 0.04669202859663675, 0.07026459616158279, 0.016180675198894837, 0.06332440264222604, 0.2139349098527624, 0.1775670766590103, 0.22581417564182515, 0.10442421155711336, 0.2668125200415811, 0.2504726460263614, 0.15933049151734, 0.13573872195857187, 0.10208609589045087, 0.12684370571326825, 0.16851154967181145, 0.1451297801348471, 0.11226717457776109, 0.20892746806625398, 0.258580323068365, 0.1318057338076253, 0.17704291930121763, 0.1741548904007481, 0.13017808808194054, 0.33527445769117725, 0.4075709718369669, 0.35973904654383665, 0.256914526164051, 0.32058251540987726, 0.5829159951498432, 0.3959117264997575, 0.27159848580918006, 0.15208325378837126, 0.14889073558151722, 0.11702635791152717, 0.23364011618879535, 0.19691347805482728, 3.1386352594821685, 77.85348599956882, 135.1765177326818, 110.98953585470878, 106.87630314980785, 93.66780788667741, 65.33434337185275, 38.442589159934755, 53.085961957131666, 89.27809515307027, 93.70599608267509, 82.72522664839222, 76.94283716140255, 56.44482089627174, 29.46223439708833, 6.7117764680616325, 0.9701537064486935, 0.1647392101585865, 0.17635137173196963, 0.2585969318545634, 1.7115705965026733, 5.939372056914914, 2.0767359051012226, 0.5746545029744026, 0.2190961054856739, 1.535897564984137, 0.5242726387035462, 1.6175950198404252, 5.0023727359310275, 5.541092138136587, 19.381676373943208, 33.798753907603604, 62.865850694717906, 86.21328061626804, 98.64239308141894, 97.91859026878112, 99.50923688950078, 103.9305482372161, 102.16220255820983, 99.46654581254529, 100.38438827760758, 92.5266021297824, 96.74708812467514, 92.26730208243094, 92.71239696010467, 92.78880473106139, 99.30400279260452, 98.040936839196, 96.1775678203952, 76.06734844946092, 69.76311114526564, 44.614619055101954, 70.526624033528, 88.01032235545497, 87.12989145709624, 76.58686637878418, 77.0848975643035, 91.83528438691171, 80.79941349644815, 36.62344094245665, 63.671721258471095, 93.80767176228186, 94.20649836140295, 93.16271643484794, 93.83524602459323, 94.06828972601122, 90.00222744480257, 83.61318065274148, 89.9256000211162, 94.64874559833159, 97.98992249273486, 93.26981283003285, 89.35799383348035, 93.76509835643154, 91.75135350996449, 77.67417092477122, 55.44811525652486, 20.32156255937392, 9.636343717575073, 1.5491019790211034, 1.0777489168028678, 2.794101617990002, 0.8646697731268022, 0.7999494395429089, 0.617660963006558, 0.4232506466008002, 0.390499254027682, 0.3326105554738353, 0.3758976488344131, 0.29004386055373377, 0.4265641300908981, 0.35993001694160126, 11.081941089322491, 39.05765602665563, 64.17583604012766, 84.29206448216593, 69.56614540469262, 99.54742508549845, 62.359304043554495, 35.76750916819419, 19.810020769796065, 48.983707966343054, 77.89848343018564, 88.68906497955324, 89.79825635110178, 114.92252780545144, 79.4661057379938, 5.985790856422917, 0.7134739249464005, 0.28242652574854515, 0.3118230967271713, 0.1782630981817361, 0.1398706478216956, 0.2630304052464424, 0.2540202613078779, 0.16997307689199526, 0.13942924328148365, 0.2770280573637255, 0.1609939901578811, 0.2143050988595332, 0.350902590059465, 0.43721091362737846, 0.2930254747550334, 0.5371373999984034, 0.26265873002909845, 0.16805635554896248, 0.10535841747637718, 0.19231019361365229, 0.33615426370693796, 0.15715930640937822, 0.21979511475130437, 0.19822327390072808, 0.22761803691185292, 0.09300781609190088, 0.25440417861025183, 0.20871789705368782, 0.05554871746308862, 0.10723945444389697, 0.2354988446759601, 0.17147506887633956, 0.19308438674817163, 0.1736115808448484, 0.15870737092148873, 0.3073778562247753, 0.31024768287616394], [0.059482157605910496, 0.038973639133356275, 0.039407432590040474, 0.08874255262555615, 0.04043327794680673, 0.04188565041629538, 0.048730347245450945, 0.008653318378022842, 0.03579003435950126, 0.09425617934715363, 0.03453078116440485, 0.042014314883178284, 0.04814274248576934, 0.05654327195858764, 0.08187929348599526, 0.11354686316823769, 0.0572023680433631, 0.09279683547755403, 0.03934259473856899, 0.06196170076427441, 0.15647741154797618, 0.014580973487858091, 0.13729991721770457, 0.14501892721220372, 0.07574692819147341, 0.07812665009330358, 0.010399733587438542, 0.05445782358067171, 0.03597389929176819, 0.19177860520299406, 2.2478885275702325, 72.74591676650509, 104.37336814018988, 89.56819365101477, 98.9478672704389, 68.63695944509199, 50.351838527187226, 26.673384097314653, 29.794984748286588, 22.564044344809748, 47.66755273265224, 56.05634543203539, 42.56614554312922, 32.74197520748262, 10.504118107980299, 1.6854161096196023, 0.10061821014049555, 0.050078999070871266, 0.018014394745771444, 0.037104181584811984, 0.080523670260464, 0.012529571014907093, 0.15532224288871213, 0.27545901736424816, 0.04758525264239119, 0.06355438989797427, 0.2525553173355518, 0.5137892157560395, 0.3651689858205857, 6.370985258010126, 23.763254111812962, 42.354651343437936, 63.973782985441154, 83.79412743353075, 89.05683425164993, 88.09000922787575, 78.73008081989904, 80.818052599507, 83.31260158169655, 80.94832235766997, 75.70008124074629, 78.22990802026565, 79.29176422857469, 81.6528663327617, 82.63628298236479, 81.71177248800956, 82.53522703724524, 86.06591716889413, 82.21314553291568, 84.96753584954047, 86.36879474886003, 92.22924724701913, 75.57185895981328, 37.62219798180365, 68.3233267261136, 62.83285963919855, 65.04768479254939, 69.53683745476508, 73.64322170134514, 41.071879402283706, 33.67539536568427, 78.49426008039906, 88.22473479855446, 80.14175753439628, 80.95442556565808, 89.36120233228131, 91.53065742984896, 84.63877847117763, 89.30503399141374, 93.7933001979705, 93.82991944589924, 87.70110622529062, 87.04783547309138, 84.66585067010696, 80.70469610152706, 80.94304284741803, 81.29007847078385, 83.57143878936768, 71.6682534064016, 49.85561947668753, 28.178038635561546, 9.944459622906102, 2.0760183565078245, 0.42905103535421435, 0.12194127159854098, 0.09497381987110262, 0.2012401128247861, 0.01913005433556053, 0.25315393843958456, 0.1326392068257255, 0.08515271823853256, 0.03441946092812765, 0.0650433392354077, 0.07745173429289172, 2.523682631792561, 13.848166177349707, 32.5301750629179, 57.18310902195593, 59.71763087857155, 63.31033760501493, 64.95256339350055, 41.54209706091112, 22.835797917458322, 39.12760757630871, 56.22479554145568, 67.0293446510069, 59.2909985972989, 70.63344586280085, 57.437686535619925, 3.5825450910675913, 0.33304137267893363, 0.02385064599014098, 0.08713883948662589, 0.03078488509110626, 0.0320788114256556, 0.07246614899486303, 0.03723886367234011, 0.12236999738360606, 0.012541164798031171, 0.04046828433450672, 0.12261931303768389, 0.08160959223225232, 0.18324124476602002, 0.1104077566114645, 0.1164267868584683, 0.08177643852128137, 0.0054184412546155435, 0.10521042461116469, 0.00669990812668637, 0.04192944766292649, 0.016680072594974792, 0.037193787058875445, 0.017153712199820627, 0.03840692942180941, 0.09642092165567222, 0.025109104369015946, 0.024409690992005413, 0.048860114878944816, 0.07337094479871374, 0.04821394269745197, 0.018507460425157222, 0.033648178927720554, 0.0728338788593969, 0.05974171968597559, 0.09345899591402662, 0.04200324874311205, 0.08755625781392859, 0.06472026463598013, 0.017095813189723322, 0.02549478750405533, 0.042824812924429294, 0.045632762654173764, 0.06194671608447548, 0.039612280670553446, 0.05538996872341922, 0.03427082837949838, 0.04158820528837462, 0.019991010757944277, 0.033522881417264866, 0.13420697511924853, 0.026720700552687052, 0.022646097218497627, 0.04509136065720551, 0.06361387662529465, 0.08377278704316386, 0.09893425695237615, 0.10486227595397543, 0.14526977504213012, 0.04935736722883679, 0.13121126490014215, 0.031087595158286636, 0.08776877826500325, 0.08266403565123197, 0.1329851261670551, 0.06840227472205317, 0.24686513799092463, 5.646850024500202, 94.95705173861597, 118.66941113625805, 103.47683983464395, 106.9789594219577, 83.03376813088694, 69.55217392213883, 45.916018332204516, 23.243879349000995, 25.59584233068651, 51.466878152662716, 53.89064796509282, 49.575279835731756, 36.712580726992705, 13.735698096213804, 2.0381629491044633, 0.10993986075083095, 0.01765657039809852, 0.02909837699975939, 0.04053771488308426, 0.20184219664623662, 0.028572863666340712, 0.3748062186904492, 0.46123527771522926, 0.1157278082363548, 0.2037226973522094, 0.5014478150875338, 0.6224958971142769, 0.9466172177945414, 7.646543960417471, 23.00923728173779, 41.109039937296224, 65.10727736257738, 84.93130099388861, 91.65144289693525, 88.23749034635483, 83.97482318262901, 83.00538586032006, 84.07533784066477, 84.29644969201858, 80.13243013812651, 80.59417155481155, 82.85747328112203, 84.6134791835662, 85.02467693821077, 84.9983343001335, 84.77819519658243, 86.37876541383805, 85.4336154076361, 87.39213328207694, 87.68507157602619, 93.54734405394524, 73.63545540840396, 45.64526888632005, 78.14397673453055, 72.36431721718081, 71.06167454873362, 76.36485238229075, 80.98185077790292, 47.50661788448211, 39.4345251975521, 82.91572047818093, 90.85976739083567, 82.47694846122496, 85.79179840703165, 90.75659336582308, 94.5833989112608, 85.87001831300798, 88.20055730881231, 93.65789213488179, 95.78960618665143, 92.57401574042537, 93.34273753627654, 88.46275991009128, 85.191008967738, 85.00541025592436, 87.01680168028801, 87.85276859037339, 77.61454305341168, 55.6601821222613, 31.2380894537895, 12.713589226045917, 3.507268188461181, 1.427874142123807, 0.49826946950727896, 0.3969625233402176, 0.9070320451451886, 0.37295666793661736, 0.4452629267208038, 0.2592570544971574, 0.18716269563282692, 0.027776783399824655, 0.05646133885508584, 0.0663364879907139, 2.7414808157951605, 14.792235570569193, 30.39419935595605, 48.07171767757785, 53.58406766768425, 61.04872249787854, 62.68181700860301, 45.42609468583138, 36.43185277138987, 62.94609062133297, 76.68924024028163, 80.8637874357162, 71.3897180557251, 78.26750001599713, 85.06298280531361, 15.358240450582198, 0.215832126597243, 0.04440842008578681, 0.07169495892500685, 0.0737862257407077, 0.02728131028913683, 0.020661209371962377, 0.013833377010849936, 0.05922336544420931, 0.0449603864352309, 0.15959506764286951, 0.06099972415775542, 0.060577571407080665, 0.1625628616180151, 0.10687380067763791, 0.02941778778368908, 0.07873173697941727, 0.08903690658870245, 0.03801710941197892, 0.05304200116605048, 0.07890506437228573, 0.021421105390594854, 0.022537758979465694, 0.04054986120712373, 0.10063242873237019, 0.08456948018001934, 0.00912461375382038, 0.0845156395207009, 0.020975039205363682, 0.09970838113898232, 0.044308537542219126, 0.02809868205428845, 0.037309615722587036, 0.06107172493131892, 0.046845506651387106, 0.056125650617985, 0.029310903196493467, 0.17715870583009335, 0.20886541494438726, 0.1117634028196335, 0.20144459701353506, 0.2074302564705572, 0.1316330575894925, 0.1639021518490007, 0.16726777528322515, 0.2216171323051376, 0.21256252462344788, 0.1130134744509574, 0.1570277384692623, 0.13582806313230147, 0.18004891042026783, 0.12718168072282307, 0.24204261450757905, 0.11712267814624695, 0.2508442446349129, 0.29340401412017886, 0.2646645320759666, 0.3205516573882872, 0.3562258286101203, 0.3752900491799078, 0.17900312379483255, 0.1444625328745573, 0.25950287679030054, 0.1736210496915925, 0.2959717569812652, 0.22688551896041442, 0.43082336444527874, 7.088630930069955, 112.03705972240819, 134.26087963965634, 112.21194251891106, 120.22937697748985, 88.40485003686722, 69.73443861930602, 41.93596970650458, 45.19884824752808, 37.08967347298899, 67.13347573434153, 76.68771836065477, 61.492428856511275, 50.6120446420485, 19.555860988555416, 3.7063708853337074, 0.4767501210012744, 0.3604996186350623, 0.4958708788598738, 0.22311501805820774, 0.38794284926787503, 0.17197230590447304, 0.5007694901958589, 0.76210837330549, 0.2150126117011232, 0.1949773900090687, 0.7110296754587082, 1.7445022035990994, 2.8119508537553974, 11.47051755459078, 31.446210415132587, 51.12766373542048, 70.51273099837765, 94.24939340160739, 94.39960448972641, 93.80491041368055, 88.58540458063926, 89.26003656079693, 90.43240947108116, 91.00533439267068, 81.7156477897398, 86.5023357637467, 86.97922537403723, 89.74717924671789, 87.90468508197416, 87.83401181620937, 89.40718820018154, 91.72042954352595, 90.24957210786881, 91.87473558610486, 92.20626215780936, 97.90146520060878, 84.50094638332244, 54.642342752025975, 86.49472636561241, 79.50843595689344, 79.70513497629474, 84.93125392544655, 90.19072871054374, 55.86322753660141, 45.63462357367239, 85.50993688644903, 92.7733898162842, 86.27784282930436, 86.86150720042568, 94.00802643068376, 96.15207241427515, 86.24647171266618, 91.86915797571983, 101.46905699083882, 103.3244243744881, 99.19123465015043, 99.05682286908551, 92.38578904059626, 89.93587663096767, 89.08131768626552, 89.62415018389302, 91.4719238588887, 83.98776700419765, 59.42347664986888, 33.295553038197184, 13.91261071928086, 4.586104337246188, 2.697039381150277, 0.7585635925492933, 0.25387531747260406, 0.808633076808145, 0.2817167299649408, 0.41026110490483625, 0.2758209172996783, 0.5001481316022335, 0.13288432431797828, 0.2172814117323968, 0.27484234722871936, 4.1747379206841995, 21.913595737949496, 49.18041875285488, 78.19109224504041, 79.10951522088821, 84.84897044397171, 89.23203083776659, 55.35844202964537, 34.65449348572762, 54.92988386461812, 72.3603948470085, 91.51048860242291, 78.7515518742223, 93.73269173406786, 96.77023795343216, 12.343798952717936, 0.6228501361704643, 0.14792299799380765, 0.2847717353893865, 0.18139604539159807, 0.14776161391167872, 0.13946747106890525, 0.15982307073089386, 0.1900088961326307, 0.15516867290341085, 0.33858362044538226, 0.3045225852439481, 0.17632354741855977, 0.31084143166099826, 0.29697646597220057, 0.36107611511984183, 0.22755301136883999, 0.213720252016379, 0.16960575305406125, 0.19105357959145502, 0.22490288341237655, 0.14072169489677877, 0.1653492153291741, 0.23673488157651118, 0.273893011072951, 0.19994654272112156, 0.14855034739500092, 0.28887462652018, 0.0944797084817002, 0.21426460345185575, 0.16551488950367899, 0.12633695387311522, 0.1496982688625013, 0.16452943996316002, 0.16118526699081545, 0.1635817585573081, 0.10231107293117432], [0.056459580683299614, 0.03065503893360015, 0.0625399056251251, 0.0381125524760254, 0.10092391752667966, 0.04939693950056549, 0.028094635194828434, 0.032707947726932265, 0.06488010888138125, 0.022936389000425418, 0.015012391114367113, 0.047041104220214396, 0.04363413502071654, 0.06384456102105399, 0.040261858112869725, 0.019492932948313897, 0.0819745641802588, 0.034971967369558356, 0.06522455733389625, 0.1566470080926534, 0.057903782825075814, 0.10398696687433029, 0.12335625897732475, 0.046285446583023, 0.028029770530279607, 0.02854589545618623, 0.10409555983759704, 0.03254793111174818, 0.06584560949235194, 1.1118913105418606, 56.00258150408345, 88.91764502371512, 90.83362871600737, 86.66690272669639, 71.51994859018635, 44.414123181373846, 20.926850957255212, 34.75345880754533, 72.07784298927554, 87.38396690737817, 63.255220459353545, 51.06070495420887, 31.15087163063788, 8.223677094905607, 0.9091761720276649, 0.04745054757222534, 0.030570593061706716, 0.08641186035087994, 0.16796339844023028, 0.16141218223398732, 0.1864269907556234, 0.1666123870640032, 0.11435527745033465, 0.012758204210249167, 0.10075649667170741, 0.6902588867852766, 0.6105609214113605, 10.220705289994518, 29.985770794653124, 43.04348622598956, 56.79479045252646, 71.4360647816812, 81.75940575138216, 91.33195015691942, 88.41443630956834, 81.44056412481493, 77.15176613100114, 71.73824417975642, 72.24057428298458, 71.23916964377128, 71.3860074935421, 74.82318832028297, 74.95644692451724, 77.04335966417867, 75.04709289919946, 75.11473809519123, 76.2334765157392, 75.94172277758199, 75.7929394322057, 76.00633205906038, 79.8207821384553, 82.68692078128939, 82.02153774999803, 70.1178659931306, 32.68538325063644, 57.66767471067367, 66.63476205641224, 70.96777300680839, 58.843491461969194, 35.5350616670424, 69.03328357204315, 86.09776681469333, 80.44057938360399, 76.0244220302951, 79.88709372858848, 87.41798954625284, 87.40526537741385, 84.22287387232628, 87.07522146163448, 85.2735827046056, 76.78021569405833, 77.15828511022752, 80.45550792447983, 80.59469715241464, 79.76105228547128, 74.45916098933067, 76.4068688115766, 81.48461234185004, 85.28649514721286, 85.80044331089144, 84.91760407724689, 71.8470036598944, 40.61584503419938, 14.942890867110222, 1.0409233767178752, 0.5625023873102281, 0.13601737878014966, 0.1706518920799417, 0.08451799907150769, 0.08648198803946858, 0.2493365069911365, 0.18667128087291796, 0.012056516509713426, 0.07526852160451875, 0.05533827694072839, 0.298174811346877, 6.084466413144143, 17.471591926390126, 40.52908220598775, 45.8592341792199, 29.998343952240486, 45.87077771463702, 41.375980761743364, 17.429991268342544, 21.040844840388147, 47.56066030071628, 68.49338500730454, 68.92085275342389, 77.66190959561256, 70.23530175608974, 13.21803544798205, 0.18602792023410722, 0.020762811782920075, 0.046195193764663516, 0.04443758505306417, 0.0319048673320081, 0.0666382730067257, 0.07733476798861258, 0.042939423508341276, 0.15551143596249242, 0.078274734889067, 0.07695511013509766, 0.025066278138828856, 0.09682908564084962, 0.06444948319826396, 0.04026211858276398, 0.0412014955955167, 0.0689450326946474, 0.0891823330593686, 0.02038120232041805, 0.03963298036626751, 0.05505964310178834, 0.06403279648492895, 0.013847701897424076, 0.041039506303927595, 0.04038154402928006, 0.03522372684411464, 0.09190828839857733, 0.06784570418418416, 0.01500344895307095, 0.08363081562903621, 0.020236034404426333, 0.052307905073487954, 0.06652619434340347, 0.0320064161168111, 0.047745805519122275, 0.03952250665714664, 0.09398636318022206, 0.0849583464103841, 0.004471547004105824, 0.06857262969377541, 0.02879440671794357, 0.0544676486583006, 0.003008326250804408, 0.0656331809718282, 0.0548090557417562, 0.005941658718286143, 0.06292195750340339, 0.06485042297431538, 0.0894377084689275, 0.05438170125407558, 0.05158016368025734, 0.02932779543522385, 0.06157275026423797, 0.068833390701442, 0.0745754954855769, 0.13928762426780117, 0.12147982619822988, 0.17320917017998236, 0.05485507847380735, 0.09880288053424129, 0.05496914896573271, 0.08003021770667645, 0.08322339474914536, 0.1271718441538753, 3.5880533245302018, 78.03662930765461, 99.10980624537315, 101.27601362043812, 98.71250937061926, 90.64540201617827, 70.49247587880781, 44.60208316003123, 36.849934285686864, 61.600325415211344, 53.03303741639661, 48.575334318222545, 53.40071255160917, 32.82692982304481, 10.473983518538937, 0.7717556266054031, 0.07225960402959777, 0.038049082091498765, 0.0615861606333525, 0.14073343136377875, 0.2850209591129134, 0.7166867751267649, 0.625488726842788, 0.7725848401746442, 0.3802792427520598, 0.1476093003105733, 0.09920689998374832, 1.9628344428154731, 10.339964955083786, 31.625611782073978, 47.52389200272099, 60.66839771886026, 72.82776878726098, 82.86390596820463, 92.09445107367732, 88.51968919077228, 83.9197531054097, 79.81987214857533, 75.07017997003372, 76.45201529225996, 74.7127971341533, 73.8065335058397, 77.2924223253804, 78.09681415557861, 79.76939908919796, 79.63713676698747, 79.18878632207071, 77.738584087741, 79.64465987297797, 79.08645168427499, 78.06860446929932, 81.77455394498764, 84.27588078283495, 86.84567651441021, 71.30639122378442, 42.73386609169745, 66.57940956854051, 73.73003944273918, 80.55756015162315, 67.59131047033495, 42.927968502044685, 74.58449640581685, 90.97949381797545, 85.77312008027108, 79.18801753751694, 83.22714098038213, 91.4729985883159, 89.04212536350374, 85.45113271282565, 88.98918905565816, 88.36446531357305, 78.86041333598476, 81.56595445448353, 84.02338997010263, 85.44102868726178, 84.71246411723476, 79.11989381236415, 81.41017360071983, 88.98754950492614, 89.32029201138405, 92.1198444981729, 91.62323321065595, 78.86256279483919, 44.64974387999504, 17.13499569123791, 0.8205918931672651, 0.465231406832895, 1.0982982141356314, 1.243706359978645, 0.2909163734124553, 0.4885101835093191, 0.32419783754214165, 0.287278589582251, 0.08240125217144528, 0.10701384155019637, 0.06943886063151783, 0.08234535073561054, 5.699301429333226, 20.421786962016938, 37.650788137989665, 37.22506976896717, 27.183988440421324, 37.551987555719194, 38.05501191846786, 29.473758320654596, 41.45823286425683, 63.2608804395122, 80.83173382666804, 81.3875493695659, 88.63907044933688, 91.81276998212262, 30.833000790688303, 0.2188543128150125, 0.009316222877391886, 0.033415671242701436, 0.05655347241929943, 0.048407977446913726, 0.03406420297500107, 0.0653724352859201, 0.01890209338237201, 0.06113309623493303, 0.047719934729919325, 0.0457888875427025, 0.14596518369451647, 0.06419141498965121, 0.01259524102938632, 0.06341542537894941, 0.02982078259059739, 0.049882493687853705, 0.024035769221823544, 0.06205953402264465, 0.07532808494063155, 0.03148688209964143, 0.08719827258779157, 0.03300083463170356, 0.03430422598255738, 0.03670397725316786, 0.04942823036183273, 0.059089269413943254, 0.006001805717636261, 0.0494733261274955, 0.008737121693669789, 0.043310911034143744, 0.054344542159308354, 0.0496165577562586, 0.05571558673475539, 0.023948500315929135, 0.13805368644816263, 0.20301752873966772, 0.15395250832361562, 0.1727327554216308, 0.2847959437677937, 0.20480504169339137, 0.1537128453773837, 0.18831049452625936, 0.13828502967953682, 0.15778582843561328, 0.11768484878684245, 0.09917398884652123, 0.13224669401684117, 0.1672149152164498, 0.1618925193625112, 0.16193787176762858, 0.1683879950113835, 0.17043156519291863, 0.22688188770365333, 0.2307800494975621, 0.14728896830591465, 0.31471820428006114, 0.332963231710657, 0.1706299666435488, 0.20342995983458337, 0.14525077606160797, 0.26981319451043684, 0.13067020764273982, 0.2447712051892473, 5.157007277011871, 96.20870359482305, 112.31472430690643, 112.16704706991874, 110.0546310793969, 92.5070922605453, 61.27459610662153, 31.698336447438887, 48.33441841986872, 88.23632148004349, 103.12132404696558, 81.45786177727484, 71.4383005326794, 48.128745017513154, 14.18211285145052, 1.8467743286202032, 0.1771077763048872, 0.32009531413355186, 0.3049659969345216, 0.30753680414730505, 0.36461816860302804, 0.5326718428442555, 0.434814713174297, 0.4338897079710038, 0.190943400826185, 0.1916696521784029, 2.7277461463405244, 4.152328929593486, 12.911031534594875, 37.473328344283566, 50.36309572958177, 65.70575260346936, 74.19693485383065, 87.38462586556712, 95.76222019810831, 94.7628551913846, 87.51014955582158, 85.63355430479973, 79.53528065835276, 81.76215925524312, 79.10453381076937, 79.44664293719877, 81.30910196611958, 82.22326524796026, 85.14687445855911, 84.58772490101477, 83.13558501581993, 83.76145408999535, 84.28600834261987, 81.40631398847027, 81.31737032244283, 85.33303014693722, 91.29773139953615, 89.06593415044969, 76.5063871875886, 50.66920926493984, 75.98064053443171, 83.51016352253576, 89.73957769332394, 77.66294510133805, 50.575382248047866, 76.14123021402668, 93.69269140305059, 91.27056506372269, 83.79373519651352, 87.59053461013302, 91.92542829821187, 90.4197794391263, 86.65771653575283, 90.9992939426053, 94.37741171929144, 84.9858376287645, 85.72182332315754, 88.698619873293, 90.33372263754569, 91.12724165762626, 83.20074342912244, 86.69668136104461, 91.92156868596231, 93.82272581900321, 94.09165920749788, 94.80640134503766, 82.49842736028856, 49.44364117037866, 19.551230630566998, 4.851895907232839, 1.9621607757383779, 1.2984484289923024, 1.4634647484748595, 0.2102563088579524, 0.43099297631171446, 0.7059514931132717, 0.6457927534657141, 0.16828252002596858, 0.26004817817480336, 0.39131360549119215, 0.5654860239836478, 10.96540060735518, 30.6600615286058, 60.81129750897808, 61.947188454289595, 42.6312804222107, 62.08591484254407, 55.89435546628891, 25.050203377200713, 32.26050623001591, 62.03604190580307, 88.58825222138437, 90.21338432065903, 97.98709054147044, 101.02113016190069, 25.03148582673842, 0.2816499883849775, 0.16574955755664458, 0.22913662236063714, 0.10253574353672805, 0.06860731049410759, 0.18525947275901997, 0.14465180255713003, 0.12813262566323244, 0.304685547467201, 0.22480278636419007, 0.19896475508088068, 0.20141562356823878, 0.23357178114594954, 0.2568227947959977, 0.152711691034417, 0.11754974918139559, 0.1410571188335457, 0.15566146662158353, 0.15565728378151694, 0.09716564338774451, 0.11647336500426454, 0.1541814460389076, 0.1361316024896599, 0.17543306213713464, 0.07143055133882069, 0.17277646839859026, 0.18801669980729782, 0.1525729678330883, 0.18485625004095418, 0.2932368230915839, 0.17257938461918987, 0.2212365857896305, 0.15049650183608457, 0.16147046620326658, 0.13049665808437333], [0.03160369518633572, 0.005666100722362078, 0.03460016191726731, 0.05764503279821046, 0.04689381615589223, 0.06844488453240165, 0.06139858783553205, 0.009266739343142798, 0.04332737043319691, 0.0611116151295362, 0.018912121473300843, 0.05561452441578431, 0.03148289461199555, 0.035189858096982204, 0.05054617863929561, 0.06381627705488956, 0.011965981196431864, 0.060573832898010174, 0.02285098934906625, 0.08060718150508982, 0.034599821008141005, 0.10005454562844769, 0.052752596130895044, 0.014510302834453122, 0.023005158798168265, 0.02981908953628473, 0.040229341510923645, 0.10303003112635306, 4.534433484077454, 67.6371943566107, 89.73383534339168, 93.67318153381349, 80.44675319425522, 67.28975080674695, 21.874464211925385, 15.106417421371708, 33.81092109987813, 69.4032258372153, 71.31283175560736, 68.34516648323306, 58.943311860484464, 23.78246980328714, 4.212633900104031, 0.07934244695089518, 0.02491589124885298, 0.042913740410679774, 1.160205472861567, 0.04481378401960096, 0.03132939357460747, 0.06295785638353517, 0.4536490460797664, 0.5139715140385013, 1.407219676240798, 0.6063308290416195, 0.2536164563629897, 4.562471566661712, 31.259407535676036, 67.56448930309665, 83.20970996733635, 87.86484164576378, 81.23420823004939, 75.3152810373614, 80.23836551174041, 84.10361812960717, 82.73806064359604, 81.91156233510664, 78.93966090294623, 75.78157240344633, 74.0677555145756, 75.42584480777865, 76.34769593515705, 78.35560429480769, 78.8653398329212, 75.53245482906219, 75.8354030116912, 70.83260028593003, 69.79671016816171, 70.47443297601515, 69.79722792102446, 70.66813530460482, 73.18289233792213, 80.31816221052601, 83.81875991821289, 90.42375672248103, 58.88172280403876, 28.956274140265684, 57.77419059507309, 66.23121292360368, 43.945509772146906, 68.85739664877616, 84.18318733092278, 77.59217769868913, 72.19807932453772, 74.09685950125419, 81.53146897592853, 87.90983123164024, 84.61327522031723, 81.30811352883616, 87.8675716154037, 83.3924061252225, 73.73127891171363, 64.04095749701223, 68.60686702112999, 67.43636900378813, 68.62535707412228, 65.81919931596326, 67.22030916521626, 79.91083191287133, 83.89626595281786, 85.01572608947755, 80.99260591691541, 84.0156707456035, 79.88680347319573, 58.64376829516504, 22.289464704452023, 2.5198034076921405, 1.545993255511407, 1.7252432434789597, 1.572973156167615, 0.5316921696066856, 0.08294437786624317, 0.146967058160132, 0.04196549593020351, 0.09291300505039193, 0.07092890930512259, 0.07804094783721433, 0.018020653684112816, 2.3341559113994723, 18.07168906734836, 50.49200834766511, 81.17838505775698, 69.36433161458662, 58.36770011532692, 53.22783408626434, 26.080927733452093, 15.313345982182412, 41.19510066124701, 54.68686557585194, 70.84337895916354, 84.46714339717742, 89.22784174642256, 20.710953897045506, 0.07544567177612936, 0.03134093468918676, 0.09794605715620903, 0.07953945412150315, 0.08741271591955617, 0.05237155931911642, 0.060684164880865046, 0.013253373758597, 0.0771244615316391, 0.029752732915503365, 0.07952164257726363, 0.043025707991252986, 0.06555271109626179, 0.04239973371788379, 0.06332320371462453, 0.027796659551020113, 0.01789206582602234, 0.07035877135011458, 0.01039972401133949, 0.04071915514707085, 0.057982793303146485, 0.028690511788872462, 0.04272914386444515, 0.05922881999023019, 0.03154435593094076, 0.02062807989967687, 0.04295056625719994, 0.027994026782952493, 0.02998761738830757, 0.06087322771969823, 0.017528855880241723, 0.05357461230408761, 0.04240055726240239, 0.04473082435828063, 0.07697946407021054, 0.029079196073355216, 0.03589528717941815, 0.13503467183439963, 0.033806671027935324, 0.02440686795800444, 0.009703885392105628, 0.0436141362954532, 0.04985451615685898, 0.04035385761169657, 0.05317226292625551, 0.02550592833769418, 0.04965177098769815, 0.04546331549664179, 0.06474645718211128, 0.01674079080863345, 0.02151778568663905, 0.09894913437986567, 0.0750523162705283, 0.06627692465460108, 0.06632146500651875, 0.015266834769488103, 0.023994737552599083, 0.07389255108371859, 0.02415228353422736, 0.05077729970517178, 0.026951545826910485, 0.10996527954815857, 8.244814257467947, 90.12182051135649, 104.6007557838194, 103.8994203075286, 98.29954654939714, 90.09015913932555, 41.31793360556326, 26.274590838340025, 38.59866026909121, 66.76282744253835, 82.63738124601304, 75.03239970053397, 60.96680771919989, 25.09102544476909, 4.924054280404122, 0.08523744756295797, 0.038626869434430715, 0.1448428342419286, 2.1417393847819297, 0.047004630774139404, 0.17607525832230048, 0.9168354578075871, 1.62930378510106, 1.53271125208947, 2.263360561863069, 1.322445244558396, 1.969616956287815, 5.08655023190283, 33.86342594700475, 70.15719167647823, 89.28910132377379, 93.62950986431491, 85.4333329969837, 76.34056506618377, 83.73283647721814, 85.24981314136137, 88.26055388296805, 86.36913991743519, 82.47583450809603, 77.54597217805924, 78.52337191181799, 77.89955815961285, 81.78463443633049, 81.2561970372354, 82.67432997303625, 80.08005080684539, 79.07851280704622, 76.15694322893697, 72.8091767526442, 73.62071514129639, 71.96940514349168, 74.11172528420725, 76.92290367618685, 85.75137446003576, 85.80021581342145, 91.63169768548782, 63.830534104377996, 36.375617750229374, 65.49012814798664, 72.92765586606919, 52.08582424348401, 74.56890106201172, 88.29347041345413, 79.67721554540819, 74.25417792412543, 78.1908804370511, 86.15793597313666, 88.58502018836238, 87.42898787221601, 80.80879580590033, 90.38064987428727, 86.56219897731658, 77.54043379137593, 65.55287430363317, 72.50574219611384, 72.66928149807838, 72.89615138884514, 69.84886200197282, 70.8607707485076, 83.97794538928618, 86.80940243505663, 87.73004547242196, 86.69273545665126, 90.31320864154448, 85.28438491206016, 62.799460657181285, 26.67705935816611, 3.7332165673855817, 0.22940394108093556, 0.8324234776439206, 1.166164656319926, 1.0507502623142735, 0.46764283711391114, 0.7800277827247497, 0.19761617986425278, 0.16476547165263086, 0.07642227300112286, 0.032980797602044, 0.06724418726779761, 1.958160571032955, 20.57335715140066, 43.0864675583378, 52.594814531264774, 40.40453126353603, 41.985379803565245, 34.83819377037787, 18.87789107138111, 30.445682425652784, 60.78755932469522, 66.91978500735375, 81.27390261619323, 93.69474672502088, 105.80214638863842, 43.24426451037007, 0.5698719079936705, 0.0939980383601881, 0.04023482287002187, 0.02009765019700412, 0.030013965067243385, 0.02425716288628117, 0.07489549041154885, 0.044305155264033426, 0.044392079430361914, 0.05532937116860863, 0.09842312308929621, 0.04271461500696117, 0.05182213638158095, 0.04161920886667025, 0.06519433516528338, 0.05602334340613696, 0.04392528290589971, 0.021441615479547652, 0.04319238957137831, 0.020277744061463786, 0.04144565547786413, 0.03408453494851147, 0.03288341633554909, 0.04354959338783257, 0.04806798379567843, 0.05371262687408636, 0.042801952860768766, 0.010350305594563966, 0.035259583589410594, 0.027040004084307342, 0.07519286276111681, 0.03785159611593812, 0.015866441254113472, 0.061639104969799526, 0.17851212272240272, 0.24024486661918704, 0.1531629168218182, 0.20482163515783128, 0.1524602150123927, 0.1924466645164836, 0.16108988904424254, 0.09515291590604091, 0.1608297102633984, 0.14982736999950103, 0.10515550376787301, 0.1662126883503891, 0.2560265842945345, 0.15324827433834154, 0.16439080869238223, 0.1477604801015508, 0.11701745596984703, 0.23507026444760062, 0.13760786924150684, 0.28390415613689735, 0.18751120435134058, 0.20435703347527212, 0.1975687896652568, 0.16921635056214948, 0.1766509121103633, 0.19565750754648642, 0.12820598624286153, 0.16432402114714348, 10.178347614503677, 105.89940547943117, 115.68209478932043, 117.67634545603107, 105.11133070914977, 87.49348732732958, 36.71059600768551, 21.61669977249638, 45.22879162142354, 86.90843443716727, 87.54508218457623, 85.78093344165434, 82.24785066420033, 37.072964176054924, 8.02326064917349, 0.31608070697515245, 0.3026176003679153, 0.2628713041063278, 2.93925799669758, 0.223432561502822, 0.25721031271161576, 0.6780456679482615, 1.6236463789978337, 1.4639214594517986, 3.582598533361189, 3.021786626308195, 4.917409785332219, 6.896562268657069, 37.907640626353604, 74.62140590913835, 91.94960578795403, 97.92991022909843, 88.00268942309965, 77.71480667975642, 83.45176727541032, 89.35254958368118, 90.24262166792347, 89.84461092179822, 87.5145818341163, 83.0971222539102, 82.76430130004883, 82.60331153869629, 86.19566917419435, 84.69673541284378, 86.56778443244197, 82.50438151821014, 82.93978029681791, 78.89631871254214, 74.67068656798332, 76.695280690347, 75.99857361085954, 77.72210228827693, 81.27370649768461, 90.39849665857132, 91.29625658835135, 97.04099132168679, 70.2666493385069, 45.55747055238294, 74.69352260712655, 81.58639000308129, 59.4081715614565, 80.38925909226941, 91.75566027241369, 83.88146292778754, 79.51571587593325, 81.06200833474436, 88.58135669462143, 93.32491428621354, 88.02038715731713, 82.87363344623198, 93.02724561383648, 92.77282499497937, 81.24390432911535, 70.02401151964742, 77.79623508453369, 76.80721729032456, 77.20558889450567, 74.3650084157144, 75.33399858782369, 89.16809620395784, 91.56369163144021, 92.15602444064234, 87.42669720803538, 91.40517296329622, 87.3605425127091, 65.53273685516851, 27.367798551436398, 5.170660066989161, 4.390569281193518, 6.325725518888043, 6.968076882823822, 2.3280860435578132, 0.3374295243092122, 0.5929068848490715, 0.40969521107692874, 0.33777165917619584, 0.3047215229561252, 0.39447230857706844, 0.17988904319222898, 4.47416675667609, 31.818790474245628, 75.48672783759334, 110.61322366037678, 91.79301692593484, 83.12738726215979, 70.24717084823116, 36.08674695414882, 26.957132277950166, 57.36007459702031, 74.42902934166693, 90.88974998843287, 101.6574562749555, 124.0535859138735, 41.17046817656487, 0.35801703410763897, 0.14304185346249612, 0.17570687728303094, 0.1807122506321438, 0.21632455259321198, 0.1987595507694829, 0.1600841841390056, 0.15074934149461408, 0.19829903999643944, 0.20771225343548483, 0.2608106501640812, 0.0982254800657111, 0.09640759172578973, 0.26168058896737717, 0.11633497888162253, 0.1795429093462806, 0.09451316354135353, 0.17670423182989323, 0.16665564038820807, 0.20809914315900496, 0.13551055033120418, 0.13649298148530145, 0.1951259038140697, 0.24118317110884577, 0.1898025733328635, 0.1630584438962321, 0.15440485259938627, 0.15941796343653433, 0.14873995415626035, 0.12580170356217893, 0.12850089945019255, 0.19832894806900334, 0.17445417030924754, 0.16206858168926933], [0.05909842799507803, 0.03538063314232615, 0.07124000995029366, 0.02700511835545542, 0.036814190492394476, 0.04702124339077742, 0.045964723873522975, 0.07455530140789286, 0.10493755175341522, 0.05426332151757614, 0.05521808923672765, 0.035111705637386734, 0.018844334183320887, 0.029051178322744467, 0.060572036421827735, 0.02434353163886455, 0.05720209225171036, 0.049131551321836255, 0.06451063233638002, 0.03970059145602488, 0.028990297315401897, 0.04491725185465428, 0.030446406378741228, 0.045232860927259734, 0.04518511066693933, 0.014926789407317918, 0.06810333189224044, 7.102402862041228, 89.10311037494291, 93.17835884709513, 86.43778924019107, 73.17030937440934, 48.10539514787736, 25.250261906654607, 24.43812535655114, 45.26880764192151, 73.05477988335394, 43.584224177945046, 41.80252282850204, 34.88970233548072, 21.27135861304499, 2.8522078548708274, 0.047625215618961284, 0.046331151388585574, 0.08493046847081955, 0.10798324154870165, 0.10241957396389016, 0.15673958215742342, 0.11702330888158853, 0.55831182507738, 1.2852316349744797, 1.4184035793427499, 3.655076824849652, 3.5107867996538844, 7.767139192550414, 49.47623998888078, 85.66858891517886, 87.76832780530377, 87.35414904932823, 81.62208357164937, 84.81653244264665, 80.86745877419749, 79.29589056199598, 79.44661940297773, 83.37326495878159, 84.95350160906392, 85.05195310038906, 78.38098202982258, 83.5465709624752, 80.27575354422294, 84.7773636541059, 83.04389569067186, 77.56188131147816, 79.51845369031354, 77.24726799995669, 71.55223754144484, 68.27110428963938, 65.62840346367129, 64.9448206347804, 66.7140410023351, 68.15715943613361, 71.97426888250536, 79.03127178069084, 79.91933561140492, 90.46185078159456, 48.567297381739465, 29.96763571616142, 36.44256868670064, 56.79599854253954, 82.54494667053223, 73.99225773349886, 71.1580785628288, 67.2597760538901, 79.73169726710167, 82.34093635312973, 89.29383954694195, 82.09463504052933, 77.40952860924506, 82.59759272298506, 83.06318590717932, 72.97178253050774, 62.34054334702031, 60.66160417372181, 62.07108436092254, 62.720679852270315, 63.0543754946801, 60.88720713892291, 63.07336368868428, 67.10617603794222, 73.65600862810689, 77.06390503914126, 82.3024029885569, 83.80783219491282, 84.94091864555114, 65.98739839369252, 53.215200131939305, 29.169886419850013, 9.549424975149094, 0.6376909140136935, 1.1792896423609027, 0.5887680488728708, 0.18786738927085556, 0.10310457914226479, 0.059675541180636615, 0.07979276875454573, 0.047397078465550184, 0.0439815673856966, 0.04315458313231507, 2.3595802245601534, 10.209954073352199, 29.054386346570908, 57.240418772543634, 62.35303217364896, 88.04699651656613, 80.6027929244503, 36.02306727440127, 14.25213892613688, 31.987964260962706, 68.72365167064052, 65.11011323621197, 75.92508408331102, 90.43304489504906, 42.85928780032743, 0.9237464289030722, 0.044507494406594385, 0.06864707811825699, 0.044738052397846215, 0.05329184925123569, 0.027439756424076138, 0.036220108459313075, 0.033843427926542304, 0.02520815570718579, 0.008901716641811355, 0.019381961282042247, 0.006856683711145795, 0.02957938253999718, 0.03326959359729963, 0.04938734041887426, 0.06225158843482214, 0.05178141497796582, 0.04467661980719817, 0.04794827489663036, 0.023746262680018143, 0.01626448330259131, 0.022663577429709897, 0.022299226012922103, 0.022133111337860747, 0.017700850280121933, 0.0560599509175987, 0.031752844844313885, 0.04498416580440057, 0.024762754103228934, 0.038089899256104426, 0.06168546478053736, 0.036405976711502, 0.06481011908861899, 0.15933439856575382, 0.044512462486783345, 0.12619825365442422, 0.02646011766046286, 0.02819382442882465, 0.035951207767451004, 0.016631897155856414, 0.0699490905108471, 0.0532849429685983, 0.0725075560471704, 0.018114828872644616, 0.022182495280679677, 0.0351000840835754, 0.020327547437421257, 0.01833018767947872, 0.03692200970685771, 0.04261027000123455, 0.05046490820184831, 0.03847394296298585, 0.04759165713743818, 0.04900444584387926, 0.03585752670563037, 0.06552790516927358, 0.060500330592115084, 0.0680615341350917, 0.08187479654987974, 0.03232517572600515, 12.867231407473165, 114.93238864406463, 104.70298843999063, 95.86248382445305, 84.3643851434031, 61.28247614829772, 44.297083577802105, 27.910344716041322, 34.61792522861112, 43.691497079787716, 30.504282636027185, 39.11108263077275, 37.17610289973598, 26.352451847445582, 4.312843103562632, 0.08155872399408011, 0.050873911053302794, 0.06734294366211661, 0.009305770565274983, 0.1534285654704417, 0.5764258208294069, 0.733034233412435, 2.022393795271074, 4.543650563686125, 2.5253545420785106, 2.2671802149664972, 1.2759147800745503, 7.112540718047851, 53.902701408632346, 89.54269824489471, 94.71643786276542, 89.42190493306806, 85.19785742605887, 86.16996196008499, 84.12313584358462, 79.66765280692809, 79.63670530626851, 83.93879229022612, 85.83976899423908, 87.81566296854328, 82.21474585994598, 87.0460468722928, 83.72860031743204, 87.63269224474507, 85.51534975728681, 83.25169501766082, 81.38306217808878, 81.02909180425829, 75.5809510138727, 70.86845859404534, 69.13060542075866, 66.7958616441296, 69.95908844855525, 71.82577579252182, 74.73047133414977, 82.66119787769934, 82.22521074356573, 91.27509147890153, 53.480764204455966, 38.033525174663914, 45.13023030373358, 61.61725436487506, 85.34595827902518, 77.85427831834363, 72.37997531890869, 70.1000270535869, 82.65399640606296, 83.97567041458623, 91.03355976843065, 81.88506280222248, 78.86843850535732, 84.65224789034936, 87.47931972626718, 76.43520401370141, 66.40581330945416, 62.69572181086387, 64.10936363281743, 65.7391280512656, 65.01945549441923, 63.52464414411976, 68.27048455515217, 70.84173940843152, 76.5911574517527, 81.00553404900336, 85.72168211783134, 88.54975808051326, 91.76796082527407, 74.19288696781283, 61.431561516177275, 35.58694285731162, 12.785945188614631, 1.989585375112872, 0.8552744095363926, 1.6656965161523514, 1.4727950865222563, 0.531576827408806, 0.21675124824527772, 0.25506908164149333, 0.08882067827207428, 0.08588285365652654, 0.04905090907648687, 2.3220728049355173, 13.42060233316114, 31.818729677507957, 55.44235329474173, 54.496238385477376, 61.67391300201417, 52.65855696893508, 29.524247069512647, 23.958703856314383, 52.74983444521504, 87.14955822114023, 73.35873219274706, 81.40792216024091, 103.10037074550506, 67.02419065660047, 3.441815842543879, 0.02745943339241128, 0.022878558938241294, 0.05415472472386976, 0.10576046807991882, 0.03660392617025683, 0.02212410405909102, 0.07433181823862177, 0.01517204862583669, 0.03289513748079058, 0.027234762786857547, 0.08161513870882411, 0.02415954604774954, 0.03874282450264981, 0.04250937239116719, 0.04431528677683204, 0.08070168611142906, 0.07329199943811664, 0.021913797602117546, 0.004458740408036618, 0.03382347899699404, 0.014077352074485634, 0.0030998148647467458, 0.06373958782322946, 0.01874705059303632, 0.019663782046747305, 0.013294934028489216, 0.05659400230093349, 0.032773946201609026, 0.03463021171609721, 0.03462490655722157, 0.03559105834292789, 0.06818330381065607, 0.17918798081096143, 0.10120419079377767, 0.202718585909855, 0.08423838464002456, 0.10575956409616817, 0.13693594884487892, 0.09303203213118738, 0.1868158110207127, 0.18556722559996192, 0.27481372618386823, 0.12055485163845363, 0.1106751979058308, 0.08493994497844289, 0.18302579019819537, 0.14759921859348976, 0.2120756910693261, 0.15621468935522342, 0.16330366864079432, 0.15983532813768234, 0.11059772343404832, 0.13227510055707348, 0.13797954445885074, 0.11191390845323763, 0.07674418314690552, 0.13880851287995616, 0.18491068824885354, 0.16960930770202992, 17.511468702746978, 135.74339435946558, 117.91225248767485, 113.69992502274053, 95.95670700073244, 69.3390009480138, 38.906154478749926, 36.09262658703712, 63.1505363218246, 95.96141384493922, 59.820687232478974, 62.794863639339326, 55.65109399057204, 35.33982176934519, 6.434556582281667, 0.21012639566775293, 0.2423153418086229, 0.3631656352550753, 0.21668277530660554, 0.7196186855435373, 0.3575277797156765, 0.46120892429063404, 2.234771631417736, 4.821674535351415, 5.342757490373427, 10.529613514100353, 9.188901301353209, 8.195765999055679, 56.97057931653915, 93.51427062865227, 95.25618737743747, 93.01485876883231, 88.83296105169481, 90.93229986006214, 84.87843528870614, 79.57125663757324, 80.06156859859344, 85.15986534856981, 91.08953983552995, 93.17824117598995, 87.28723341418852, 91.93594025027369, 87.77783563060146, 89.81192973352249, 89.75001904272264, 86.49931553871401, 85.30871145186886, 86.6994034859442, 80.43406824911796, 74.03925557290354, 74.20087291348365, 69.69101798149848, 73.55591758604973, 75.21850047572967, 78.44839972834434, 86.50552857306697, 86.88683786699849, 94.47002672380017, 59.47889581803353, 44.805167798073064, 51.24484454431842, 66.93974987153085, 87.45833504584529, 82.8833060110769, 78.87947605502221, 74.85485753705426, 87.58675344528692, 88.24804152211836, 92.72759222215223, 84.26736923956102, 80.83979821974232, 87.95544055200394, 89.88690976173648, 80.52225882007231, 71.09491271357383, 66.23488426208496, 68.50013148400092, 68.62783601207119, 68.1789364353303, 66.5495446420485, 71.75995057629001, 74.31792428416591, 80.33782112982966, 84.23657863370835, 89.49919131494339, 92.30204643741732, 95.34834738700621, 71.99413960979831, 60.966729271796446, 35.910742359776656, 12.35824994502529, 3.4795765001927657, 6.192895433595104, 3.671359318879343, 1.478520398659091, 0.35700441908932506, 0.1946995912059661, 0.4418016495483537, 0.21429523164706848, 0.2414692130180136, 0.287657588600151, 4.891198056359445, 20.86498341252727, 46.1348512864882, 79.70850036990258, 86.32348352862944, 118.77213016633065, 111.20932194494434, 49.713202138100904, 22.13290918257929, 46.989539669406035, 88.03744162282636, 85.44434701242756, 90.01660685385428, 117.01806191475161, 66.00191900807043, 2.747182471136893, 0.1701986284986619, 0.140576659130954, 0.1380809745000255, 0.18846380404166638, 0.09814923133460746, 0.07819267155061807, 0.12477749763357064, 0.0784218697358043, 0.19170555105853468, 0.10927145669777548, 0.13178725576689168, 0.1819424192991949, 0.12761711743810486, 0.14017110750559839, 0.13242064194092829, 0.1455441724148489, 0.14741600100551883, 0.11384893163678148, 0.16993541600963763, 0.06674675871768306, 0.12081091652714437, 0.09678115918030662, 0.2304870208665248, 0.11692526494903911, 0.13438144398312415, 0.05037738265649927, 0.13764364554757072, 0.1464865371705063, 0.1774690480482194, 0.16875856706211645, 0.14676022974233474, 0.11442726673257929], [0.05438402633092577, 0.028323835295234478, 0.023216731215436614, 0.04184517799125564, 0.009889671289842698, 0.047575389260366086, 0.039477885865996924, 0.04637660338513313, 0.1443815880244778, 0.03039927090398006, 0.05015892885445107, 0.07292973944136212, 0.06786250449236363, 0.04000306212072892, 0.024544037916066668, 0.026349322194413796, 0.03519275773977561, 0.025532203238277186, 0.017567870823005517, 0.045057426792599505, 0.06785703462458427, 0.06550123764862938, 0.04023271995866972, 0.077141338448611, 0.03447902426424046, 0.12811076151387346, 5.622574475503737, 93.93833375746205, 89.65684706164946, 92.8981682562059, 93.63110234660488, 95.76753893206197, 41.9272110539098, 26.39936927826174, 46.233451827879875, 61.84959988440237, 76.93476492358793, 72.27799369442847, 63.06598963276033, 33.712520599365234, 6.179508874493261, 0.11391362776198696, 0.025577176429872072, 0.06232300698156319, 0.04190286058151434, 0.11846560729487289, 0.007865600918810214, 0.0934904897885938, 0.20440620099825246, 0.895811676258041, 2.3395854523105006, 1.8341038472229436, 1.3060930058840783, 6.5220019029032805, 54.95166086381482, 81.34180668861636, 87.84611625056114, 80.00070910299979, 79.70257759094238, 76.0891725170997, 83.21822151061028, 79.32743426292174, 80.18427602706417, 76.77941553054318, 81.89936376387074, 76.76000764293056, 79.95589210141091, 77.3480180002028, 79.72175013634467, 76.1308280883297, 77.46614410031226, 73.37661820073282, 82.3990031211607, 83.34953461923908, 79.16962946614912, 73.22247689770114, 72.0682567165744, 66.32624410813855, 65.02654321732061, 61.6137634554217, 64.75644880725493, 68.7953604421308, 78.25505825781053, 81.49669324198078, 82.57991067824825, 73.61949920654297, 34.60359681037165, 29.648250841325332, 70.57664209796538, 83.71273040771484, 72.02374565985896, 62.58492662060646, 71.35782134148383, 79.84437127267161, 80.19893000202795, 79.80115459811303, 77.482618055036, 80.33020388695502, 79.1471621298021, 82.61948739328693, 72.74888207835536, 59.872046747515284, 60.08745939500871, 60.37396892424553, 61.84301030251288, 67.34678206905242, 68.7422437052573, 67.86425252114573, 66.41076334061162, 67.28876236946353, 70.0522525848881, 75.67332283143075, 77.43550254452613, 81.71760113008561, 78.96197918922671, 82.28756858456521, 88.297314336223, 85.41823187182027, 56.92885706501623, 7.328611833433952, 1.648373736008521, 1.303581708381253, 0.1372682471429148, 0.2708808452852311, 0.04990516222953316, 0.053170654141614516, 0.044584313873201616, 0.0374051622085033, 0.11921325548281593, 1.8870603797897216, 5.262149841554704, 17.678047841595067, 34.879829729757006, 45.90711847428353, 43.39058068490798, 60.781534564110544, 52.22219328726492, 16.8078209892396, 18.864227494885846, 57.82775840451641, 75.87821960449219, 65.238700297571, 86.01494989087506, 56.95603516794021, 3.0520432995211695, 0.13642896717834857, 0.09818960416821704, 0.026878936013447183, 0.03075413623704545, 0.03511971891707471, 0.022010353408874046, 0.07777398151736106, 0.04436425894739167, 0.024537635336239493, 0.07977759255276573, 0.058476134774185, 0.00790306644874715, 0.030653445470717647, 0.03350211277363762, 0.018300176185045033, 0.028149337703061682, 0.09334283400206797, 0.05406767415303377, 0.012845131249407367, 0.02773972389648759, 0.017648549457531304, 0.026594460754084493, 0.04761572378957945, 0.03651757273943194, 0.11100578782779556, 0.040995084695638194, 0.04725648984012585, 0.016684046676081997, 0.04996989282869524, 0.05979067270433711, 0.03795940000864287, 0.05817278310836804, 0.05301146490138866, 0.03278600825597683, 0.05095958266587508, 0.012975528032609053, 0.04099925221394628, 0.03556568934131534, 0.022303736355576306, 0.11984144758072593, 0.13134389004159358, 0.023855257839445147, 0.01400102673458957, 0.01797778340387008, 0.04234761675639499, 0.06333921112180238, 0.0191185591862567, 0.023558540495052457, 0.04749145283694229, 0.06793758876982235, 0.06760162091062916, 0.03209492416992303, 0.07362188455919105, 0.02686377321820586, 0.016642386814759626, 0.04416740499436856, 0.14713501527665124, 10.143720930622472, 116.40395995109313, 99.5296802828389, 103.58162987616755, 105.61982677828883, 108.71983282027706, 62.266453696835434, 34.92702761004048, 41.65219799164803, 44.34420301068214, 55.7992732909418, 60.566149373208326, 57.60551298818281, 41.38252719756096, 7.857380672808617, 0.12298668284089335, 0.056913066430077444, 0.05006852664894635, 0.06722878123964034, 0.23958725674498468, 0.46294564561497786, 0.6867505105272417, 2.022383866771575, 2.6061426199251607, 4.172133957186054, 0.33783034151119573, 0.7226573579734372, 9.116318821907043, 60.30843396340648, 88.11712849524714, 93.944546791815, 86.50981964603548, 82.58490777784779, 81.29446368063651, 87.76239718160322, 83.50101655529392, 80.39617030851304, 77.83911443525746, 84.25583747125442, 79.20398158411827, 80.78605390364125, 78.60631435148179, 81.40446262974893, 76.84011813132994, 78.44570113766578, 78.10116798646989, 85.09273006070046, 85.50706571148288, 83.35497102429791, 78.40191179706206, 73.42028202549105, 70.83615395330614, 68.1104753863427, 63.384956775173066, 69.38431216824439, 70.70854356212001, 80.34771334740424, 82.44537338133782, 84.59346725094704, 75.82859377707206, 40.74230617092502, 35.277350179610714, 73.18813262447235, 86.26926852810769, 75.11182769652336, 67.4778990591726, 72.83855530523485, 83.56502963650613, 81.02650303994456, 80.37679379986179, 79.09224894738968, 81.35491524973224, 80.95955602584347, 85.9664301718435, 76.5090936230075, 64.33529215474283, 62.33338502145583, 63.704418136227524, 64.36687115700015, 70.44218324845838, 74.05954207143476, 72.65116014788228, 69.0261213241085, 70.28244864556098, 72.87029512466924, 78.73488180098995, 83.10393148852934, 85.68393322729295, 80.60637797078779, 84.5981897846345, 96.43292196335332, 95.16018344509988, 66.35136296672206, 10.375301587966181, 0.4145832503995588, 0.22403531948164587, 0.4185263355893474, 0.9774346060810551, 0.5050652516224693, 0.10924986067919001, 0.16072434253029286, 0.02245200884288117, 0.23412226128482053, 1.0462368399866167, 5.7831543491732695, 20.454168088974495, 38.698457133385446, 44.596109390258796, 45.00280426394555, 55.472543777958045, 55.71283601945447, 23.786956994764267, 27.22479089613884, 78.06493313081803, 86.96357511704969, 71.02990335033786, 94.40966929158857, 84.5312584600141, 6.661042571067811, 0.1522746225518565, 0.11877500722485206, 0.013321474187016008, 0.03798517120641567, 0.07427341935615386, 0.08616290475812652, 0.04326507982407366, 0.07013695059163917, 0.021259275062250036, 0.04386728621959206, 0.04969261113494154, 0.06699730011243975, 0.04580720853541167, 0.06512462116417385, 0.021908664813024864, 0.022496623888371453, 0.07885171400923884, 0.03892222697275781, 0.03791801976941286, 0.005842790762413173, 0.01684578124343628, 0.04266848885304025, 0.030908357397082354, 0.03155089640659431, 0.027256192181319482, 0.04087110485641226, 0.02849253168660066, 0.06228515457722449, 0.05543301137344492, 0.0760112132035917, 0.02455319266676182, 0.13507889042938911, 0.13013337919067952, 0.08313845092010114, 0.10368132077518011, 0.13270893614859353, 0.1086240434538453, 0.10865601230292551, 0.2309681700482484, 0.19205861033931856, 0.18469955441692185, 0.20118627216546767, 0.15626238598938913, 0.1746042162900971, 0.16155590032858236, 0.1663840162537752, 0.14055364584970859, 0.14197954998141335, 0.1079577844469778, 0.28618979478074663, 0.17226956334085236, 0.16232716700723096, 0.20633452091245882, 0.18675889068793866, 0.1423162609458931, 0.1778489204063531, 0.29619208386828827, 15.328851111473577, 135.61453665456466, 109.53597607151156, 118.78044559109597, 113.42138182732367, 120.36019586747693, 59.833752647522964, 40.53986872396162, 63.99944705347862, 83.21621325708206, 102.65906487741779, 99.01978000517815, 85.96180177504017, 53.80000983515094, 10.971214540543096, 0.5095155483051654, 0.1863819754291927, 0.09134480774763132, 0.3199146093139726, 0.2514471864748386, 0.29073275745876376, 0.23796531071345653, 1.9390868203293894, 7.320252772300475, 8.136407300349205, 9.149306935648765, 5.826758357786364, 7.777032390717538, 57.380239502076186, 88.95245213662425, 97.1021253831925, 87.60918940267256, 85.63798658309445, 83.18117080196258, 92.17045876287645, 82.93567749761766, 81.51843101747575, 80.11367336396249, 87.4893060807259, 80.9599639523414, 83.92868041992188, 79.65135928123229, 82.72266141829952, 77.36176983002694, 80.05668917009908, 81.57327359722507, 88.1079109253422, 88.6373681406821, 88.46512902167537, 81.25432998903337, 78.76098125211655, 73.10795937815021, 72.3082273237167, 66.50299395284345, 72.66146813669513, 74.07068944746449, 86.29699184048562, 87.04479171383767, 88.17078651920443, 78.21880771267799, 47.57102320271154, 43.87045129652947, 76.58385399849185, 92.31779083128899, 79.0021913282333, 70.01027537930396, 77.3392475804975, 88.00620386677404, 83.69202813794537, 80.22825364143618, 81.26019785481115, 83.88125111979824, 84.33926628481957, 89.75972298652896, 79.89905695761405, 66.654491578379, 67.12013967575567, 66.6393590742542, 68.7841110844766, 74.6965899006013, 78.3838688942694, 75.01469412157613, 74.64667381778841, 72.82306978779455, 76.36292257616597, 82.57021457918229, 86.09246377022036, 85.42559023826354, 80.38567404593192, 83.15156475190194, 96.76047909644343, 96.30294246058311, 65.19924125363751, 8.402459217656045, 4.828690674997145, 5.035584915068842, 2.7566410216592976, 0.9940880092401659, 0.3193363355052087, 0.19125835489361517, 0.28357473832945673, 0.1759928119398894, 0.3282388287686533, 2.7974873588931177, 12.145777113976019, 32.01780565323369, 52.88638391802388, 62.78938408820861, 60.753113069841945, 87.71987084419497, 70.73051667982533, 23.382282141716253, 30.689742103699718, 77.81803561795142, 98.62910409127512, 83.06797119878954, 110.26246178534724, 87.5325462895055, 6.772835023941533, 0.22677100413749296, 0.18428248082918508, 0.06898589582452852, 0.12589069233546335, 0.2343036862270486, 0.17364253079698933, 0.13632169954719084, 0.12895129020175627, 0.0919081045374755, 0.15928061919346934, 0.21881625356693424, 0.12181632265809084, 0.1674245321942914, 0.17543598859300538, 0.07901570279031031, 0.14240365625629503, 0.14966379490590867, 0.2970811442261742, 0.1750050641355976, 0.1992238919821478, 0.16878516563484747, 0.1383939673823695, 0.14038781845761886, 0.11069826481323089, 0.1889831503672946, 0.1547604399703203, 0.20518782518563733, 0.0990458223367891, 0.14793298778034028, 0.16027120152308097, 0.17889020243479362], [0.033512477943253134, 0.021459980522312468, 0.023889664763344393, 0.06518690411241786, 0.10242984720295477, 0.04451476841143543, 0.060259116317836516, 0.049822034028869484, 0.03565605707286346, 0.03136697593295286, 0.023720778765216954, 0.043147297636155164, 0.02366951024610429, 0.002732568593215077, 0.05886978139319728, 0.026469094295715614, 0.0675204998603271, 0.05340047668845904, 0.07475710428890682, 0.025279037992379842, 0.043257851784508076, 0.030911687964333162, 0.09216746360424066, 0.008368036811119847, 0.08420902815076613, 5.967009077149053, 83.52222088844546, 101.27879850326046, 100.44517717053814, 89.33587951044883, 62.16940641403199, 37.745882080447295, 29.36569702240729, 39.7493463946927, 50.806900147468816, 64.68350056679019, 55.03545838017618, 36.081981274389456, 20.039803020415768, 5.836544671366292, 0.06045410101632438, 0.044214933089190916, 0.1356392684242418, 0.09431547455249295, 0.04707561648120323, 0.10172085581167091, 0.11707273687446311, 1.2935129841489177, 2.5268249405968577, 2.9530115425586705, 6.569818046785171, 2.2203571661826107, 7.051273295956274, 63.77470700971542, 82.94243966379474, 86.20455726500481, 81.00234123968309, 70.89163195702338, 67.83235580690446, 79.19623098065777, 78.20681310469105, 80.82005300829488, 75.93260718930152, 79.02791423182335, 72.97830935447448, 75.62307726952338, 75.05201155139555, 77.93217658996582, 77.55095358817809, 78.91874682518744, 73.70613651890909, 77.45485551895635, 77.87225846321353, 77.0696238548525, 80.1984122491652, 77.42404922362297, 72.99877628203362, 68.26686028511294, 64.92995877419749, 63.02309459255588, 61.76405299094416, 64.23786440203267, 70.73819668062272, 77.43589478154337, 81.2860776532081, 74.74503901696976, 52.68544481646631, 20.02136395823571, 66.64138301726311, 78.21616403518185, 65.05093251505207, 62.238232243445616, 68.9419472602106, 82.01332430685721, 75.80085477521344, 76.16386228992094, 79.08167423740511, 77.86933237506499, 76.37097912449991, 71.98930724974602, 62.79015287276238, 59.46229242509412, 57.55430644558322, 60.56478831075854, 71.55916444716915, 77.9953424392208, 79.65555621731667, 79.64555417337726, 76.47042689784881, 72.33053776525682, 74.05125802563083, 78.44610121942337, 80.39944156523674, 80.52376501021847, 74.51317202660346, 83.81126034644343, 82.18712452919253, 84.44210298599737, 92.15071355142902, 80.90455655128726, 13.906637930100965, 1.4198569400656609, 0.6863746984351067, 0.7117405437654065, 0.3580325090837094, 0.06316802494468228, 0.025029534646760554, 0.07830950761995009, 0.0647348432891792, 0.1487513841880906, 0.029893237271256028, 2.933288884739722, 12.817490850725482, 32.97839803080405, 41.28969646269276, 46.16709709167481, 41.50434817037275, 69.87010555882608, 48.342926040772475, 18.358851671218872, 38.29235845996488, 61.937649250030525, 70.03639051991125, 88.42236734205677, 40.99915473691879, 0.494120276022342, 0.009776421469606219, 0.09057584699363479, 0.0182154085562234, 0.022168062184186235, 0.009199947967464405, 0.05096120677227455, 0.012856715456432393, 0.035916603575911255, 0.04373970576712201, 0.03523960018590574, 0.02688873427799873, 0.022447226539013848, 0.05570553183074921, 0.029265047088565848, 0.02252586929488086, 0.025711820213003986, 0.01972549234426791, 0.05139047264932625, 0.05218913080170751, 0.03644032809402674, 0.007984017044486058, 0.025854663052145514, 0.01462200802991227, 0.02297141645554333, 0.07883361135158809, 0.033816722101501884, 0.014075123716235883, 0.03334929738494177, 0.09419860017876472, 0.09784479565437763, 0.008948904785117315, 0.013709255445358014, 0.03773849472523697, 0.0356679467574483, 0.09178140125567875, 0.0069796925339277, 0.023091847392460032, 0.045740708273144505, 0.02762634479891389, 0.05391213149132748, 0.06288456092137965, 0.04150897647524553, 0.006893694855182642, 0.05772437652452819, 0.027916222893362565, 0.027617843138174187, 0.016997899492121032, 0.08647041245093269, 0.05717297324970846, 0.045267131870552424, 0.09750522718194032, 0.023913354117182956, 0.06505926620335349, 0.05022683488805929, 0.04427304085824759, 9.216690313431526, 99.90714565400155, 114.51287546465474, 112.60796854572912, 102.36101965750419, 75.3852875001969, 65.03857704900926, 38.82248640060425, 37.236695674157914, 42.96914162174348, 53.60538182720062, 52.8643362752853, 41.99203998811784, 28.748253199361987, 6.266045185827441, 0.012189692276860438, 0.050668928907403064, 0.08845282583347253, 0.11414794341450739, 0.10720217660550149, 0.5544696796324946, 1.1585399364271474, 3.619403603576845, 2.3899575106559263, 5.487385574848422, 0.42115674444263984, 1.0033735464657507, 9.621824083789702, 70.23901231827276, 90.93370406858384, 90.92124662091656, 85.63495851332142, 76.04454378927909, 72.12101259539205, 80.52087030103131, 82.00653076171875, 83.50747277659755, 76.89088144610005, 79.22299723471366, 74.92808818817139, 76.70954242829355, 74.05614529886554, 76.83505827380766, 78.14516913506293, 78.92097473144531, 76.14774919325306, 78.1756067276001, 79.65782334727626, 79.6718026745704, 81.31496198715703, 81.1836959469703, 77.15793994165237, 72.56503274363857, 68.00742687717562, 65.47039862601989, 63.31531117039343, 67.33601124055924, 74.2475648080149, 81.01891717603131, 86.85311332825692, 78.75806300870835, 55.39020146093061, 24.402957385586156, 68.4494544613746, 83.56917165940808, 69.32447248889555, 63.34599194988128, 71.23445495482414, 84.53580056467365, 78.30173446286109, 79.00089694607642, 81.18339784683721, 81.05913715977823, 79.77161130597516, 73.92413400834607, 67.56939226581206, 62.6259663797194, 61.524945305239775, 63.98345162791591, 75.28973071805893, 83.6181071496779, 84.01334085772115, 84.56375137452157, 79.956190201544, 75.61507563437186, 77.597865135439, 83.38334545012444, 85.26763639142438, 82.53549375841695, 74.1003974791496, 87.61384917843728, 84.37068446989983, 87.65910548548545, 94.50641847425892, 90.48465544177641, 16.63290289140517, 0.1572243013088742, 1.17889225723282, 1.3402129685686481, 1.8907977856935996, 1.1925890513004795, 0.3153949050653366, 0.24159480547232015, 0.026773204388577613, 0.19232756848777496, 0.05148561310864264, 2.7847737314239627, 12.963434400097018, 35.70647316594278, 41.08966735101516, 40.88973629859186, 33.83309033609206, 40.04638356547202, 41.87163106856808, 27.485483384901478, 52.81599698528167, 73.05547022050428, 80.0500132960658, 93.2128051019484, 65.48483687062418, 0.9046717588939975, 0.15669772311324076, 0.04468763615154932, 0.12382686678921023, 0.0230945440219535, 0.0702329031041553, 0.06457260118857508, 0.023755495954725533, 0.032512277379752166, 0.04043437345253845, 0.05764745363605119, 0.042738195193270524, 0.004389724025743142, 0.03271353633833989, 0.048946020148334005, 0.047270792701672164, 0.009119413932034326, 0.04492162238626231, 0.008225570312671123, 0.05210962619692568, 0.03680188712033053, 0.04250297938743907, 0.04798405503313388, 0.04320445545618573, 0.016393662963603294, 0.0213028846173397, 0.023354006510588433, 0.05159149795109707, 0.027644499167499524, 0.0698666517893153, 0.03570944957074619, 0.11278281303783579, 0.07884599133244447, 0.09047824739208145, 0.15091483180801715, 0.18277586167377813, 0.0851762447986872, 0.12487351909399995, 0.14057221582099316, 0.13023723006969498, 0.12740602957144861, 0.10664418880497256, 0.13729346675738213, 0.172696350923469, 0.1578100674575375, 0.15169546008110046, 0.12206901675991474, 0.16146358673370656, 0.2117576879719573, 0.14876092964362714, 0.17796331265520665, 0.4142834035859954, 0.0885783876442621, 0.15532048088648628, 0.15794528197617302, 0.13414257776833352, 14.407874672643601, 124.51044790206419, 127.58244037628175, 127.20499853934012, 111.42020425488873, 83.59897382797735, 57.208380852976155, 43.69296796860234, 55.78066556684433, 68.58612552765878, 88.42057089651786, 75.97659264841388, 55.435387165315696, 37.070610753951534, 9.855109991565827, 0.22596871089791098, 0.15937549152201222, 0.16464459829993788, 0.3509870435922377, 0.20193210472503018, 0.31625053334620695, 0.4142571420919511, 3.276232005127015, 10.172238522960294, 14.023040148519701, 17.421389510554654, 7.205368511138424, 11.043786233471288, 72.37096955699306, 91.19758544429656, 93.61263582783361, 88.56077209595712, 78.04836503921017, 74.83392776981478, 84.73764573374103, 86.18769107326385, 85.20098747745638, 76.41418795431815, 81.02526357097011, 74.32858528629427, 77.52632110349595, 75.7739237816103, 78.86144884171026, 79.15223767680507, 80.39030244273525, 80.48183487307641, 82.80569015010711, 83.19117284590199, 81.84084200089978, 83.41950185837285, 84.2691578403596, 80.1617302433137, 75.82730723965552, 72.39525687310004, 69.53769253146264, 68.15360576875749, 71.17551742061492, 78.77568229552239, 83.95918861512216, 90.0020391710343, 79.3790683438701, 60.11465710978354, 29.999685402839418, 69.89570294657062, 86.1985089701991, 72.29121992664953, 68.74454221417828, 76.08934510138728, 90.02230213534448, 79.54192515342467, 83.02182843608242, 83.63978216725012, 84.91376015447801, 83.22060631167504, 77.57545271227437, 70.55869333205685, 64.548104270812, 63.2372050131521, 66.25621411108202, 78.8165847716793, 87.31125400912377, 87.63448084554365, 86.62952253895422, 83.06266030957623, 80.46269370663552, 80.07521060205276, 88.05870871390067, 88.55173495508011, 85.56572867978005, 75.44612346156951, 89.48029333545317, 88.07767729605399, 90.73055667261924, 99.89137772590884, 92.5311363897016, 17.176782661868682, 4.802499048171505, 4.709361878133589, 3.764328072147985, 2.3631851278966476, 0.7940739741729153, 0.2916638300784173, 0.3757558612813873, 0.18561306830135085, 0.379799916859596, 0.21636961388491818, 5.279576441934032, 23.575174500865323, 52.62625625056606, 62.52609106802172, 60.348234253544966, 56.92937481787897, 91.989849305922, 69.41843678874355, 29.71893391301555, 51.872702260171216, 83.31541784348028, 88.96192858296057, 110.97793348373906, 71.91939492379466, 1.040639372602586, 0.17592973226020414, 0.13013796039646672, 0.16532254014765063, 0.1765159120963466, 0.1591213648357699, 0.10770570321549332, 0.12173401417150614, 0.11120317804236567, 0.1543150364511436, 0.16505316831171513, 0.23046780738138387, 0.18869053542373643, 0.11482334185031154, 0.14442857985775318, 0.10419684432206616, 0.13276800152755555, 0.10652411218372085, 0.07404124874982142, 0.13082031491062335, 0.14122752743142267, 0.2004292394004522, 0.12342968850486702, 0.09914034226488683, 0.10392406339486761, 0.12432389697360417, 0.1334918167201742, 0.07902002352620326, 0.1749582561634241, 0.2869629613574474, 0.24673959150189356], [0.0276304989106833, 0.051995195643675905, 0.03283276260199566, 0.05343890748918057, 0.011530238045980374, 0.06822779053641904, 0.037790132881773096, 0.04033949346311631, 0.07511768655310716, 0.007336294013751491, 0.03125984045196205, 0.038920962927682747, 0.007254134435507079, 0.021680751740331614, 0.048358599249754226, 0.054888510550822944, 0.07575004616932524, 0.04405733731184756, 0.07284505608221216, 0.037019345008077166, 0.0333045233762072, 0.06645666420339577, 0.10042881022297567, 0.031235666547511375, 2.63825114215574, 80.8959508711292, 107.48763592012467, 92.12044854317942, 79.5575204972298, 57.9234956156823, 38.30063073865829, 37.156753847675944, 53.49122124333536, 59.482288668232584, 54.58393866016019, 42.45564453063473, 41.07614694103118, 29.698096321475123, 6.224431780076796, 0.29850453558948736, 0.0513539532379758, 0.1403241871946281, 0.043707231300011765, 0.07608810544855173, 0.09610862591333928, 0.6745992528815424, 1.7635815927097875, 4.534195690385757, 2.688769308790084, 1.0670155959744607, 2.697273497619937, 5.616410470777943, 70.93042419802758, 85.47287048832064, 84.37431658467939, 79.66731548309326, 68.81355239499, 62.54228261209304, 77.99159265333607, 77.05744097309729, 79.69178322822818, 74.70314025878906, 76.73176657768988, 74.55470992672828, 77.0385665278281, 73.6098737101401, 81.32923941458426, 74.94366784249583, 78.0856667795489, 74.0692146362797, 74.72971039433634, 73.44089015837639, 79.6031141281128, 80.14396975117346, 82.1342666687504, 75.54284911001884, 80.89946531480359, 73.52631938072943, 70.86932936022359, 58.77463817596436, 61.43542505079701, 63.21250192580685, 71.76468879945817, 73.73065917722641, 82.23177679123418, 70.43796277815296, 53.25790297600531, 18.566252877635343, 62.655125279580396, 76.90094624796222, 71.4056585681054, 61.97844582219278, 65.45484250591647, 78.42146089000087, 74.36291387004238, 78.62298442471412, 73.89819145202637, 68.89453364956763, 64.89521441921111, 60.58637703618696, 57.597444672738355, 58.28624425395843, 59.97403621673585, 69.6800902581984, 76.74973103307909, 77.47371427474484, 80.84691339923491, 81.38101470085883, 82.00130616464924, 75.55718145062848, 76.07188270938012, 77.46227664332237, 81.02910749373898, 71.05983887949299, 80.46644349252024, 84.8017764860584, 83.32643185892414, 80.52428276308122, 79.77516497335127, 85.04324543860652, 78.15287267008136, 5.025072472710764, 0.9354548264415035, 0.640147727343344, 0.755157872073112, 0.27394844519515194, 0.1532549393032828, 0.0070713717122412026, 0.06920623803331007, 0.09789246930590562, 0.10137080725642944, 0.23460711833209763, 0.03637212711656767, 3.7152844715502957, 30.50619871385636, 56.59454953285956, 68.98732123836395, 135.03890529755625, 124.515178280492, 50.897200953575876, 23.31437218573786, 49.102618540486986, 67.27992134709513, 74.9337677801809, 75.79830523460143, 29.106700958744174, 0.25424722251632526, 0.08879653118070095, 0.08546706709650256, 0.10389760271796297, 0.08128875460956367, 0.021395447190790888, 0.06720152383129444, 0.018052884918307106, 0.04241734990970262, 0.05920741932406541, 0.03333096873135336, 0.10975465133425691, 0.03378549635770821, 0.03495504831775062, 0.06609736130602899, 0.02606717967278054, 0.07367722675084107, 0.044139044419411695, 0.05710519745104736, 0.003408946903354879, 0.018960406079948432, 0.0367099795520546, 0.04592348536055896, 0.07121145785335573, 0.043794867928109826, 0.08027622386092141, 0.01444557702334057, 0.023197261090841026, 0.02959331576412003, 0.03899493254721165, 0.02994343135205488, 0.017391172643270225, 0.09609842928306711, 0.01461503184175179, 0.0314114933022328, 0.029047991396979462, 0.008823236679628251, 0.022225649013454397, 0.08524844092467139, 0.009725256372363338, 0.03029449497379603, 0.08535897975126583, 0.043178691919292175, 0.08070500327214118, 0.05948574672783575, 0.1027326587767851, 0.07827365470509376, 0.025736365670097933, 0.0029494658003621286, 0.040145274852552724, 0.07660172909738557, 0.11991329896714419, 0.023655718748247432, 0.07904945662425411, 4.067200258854897, 97.68888842674994, 119.06463699956095, 105.5510990081295, 86.29799596724972, 86.55679395121913, 65.10144872050132, 39.443715310865834, 55.13475710345853, 42.244550412701024, 61.853839966558645, 48.89638031682661, 47.610584228269516, 34.751627060674856, 6.574873981937286, 0.311342116084791, 0.14778448929709775, 0.06976387343339382, 0.21814102367047342, 0.4778085174339433, 0.510491360459597, 2.2980929045907916, 3.3481060064608053, 4.267065611577803, 4.6602224246148145, 1.7788560376051934, 1.4732107351864538, 7.028432353850334, 75.00513138309603, 89.10035687108194, 88.15824277939336, 83.28915365280645, 70.8718632113549, 65.06550412024221, 80.82055507167694, 80.38165753887546, 85.90728867438533, 74.94740978364023, 76.08094338447818, 74.17343985649848, 77.41759300231934, 75.8435772311303, 82.77663323187059, 77.18950717679917, 81.2435434710595, 78.7011415727677, 78.42836426150414, 78.35062288468885, 82.031688844004, 82.86077591680711, 84.16476003585323, 78.89071756793608, 84.9122461195915, 74.39509299493606, 72.84511350816297, 60.77554510485742, 64.19628335583594, 64.09727488794636, 73.41264124839537, 74.90669558125158, 83.62245313582882, 72.14271899192565, 57.61179270282869, 21.511264501079438, 62.71602399887578, 81.23374539036905, 75.53874631081858, 62.905733354630016, 67.69340976592034, 80.96385494355233, 75.9254841650686, 80.62705670633625, 76.16184619165237, 71.68556674834221, 68.83799660590388, 62.60309503924463, 60.15127635771229, 60.05044398769256, 63.164923575616655, 73.73691928002143, 80.81222395743094, 80.31689920733052, 81.81316575696393, 84.03005015465521, 84.89260288976854, 78.10533354359289, 80.19335239164292, 80.14876288752403, 83.66961571478075, 70.94565868377686, 83.1421353740077, 86.86048738418087, 88.2267116731213, 84.38115719825991, 85.00928555765461, 87.50927094490298, 86.62035988223168, 6.333318737245375, 0.5659351966554119, 0.6429664406084246, 1.6016536494416576, 2.312720648704037, 1.1770709291581185, 0.2859478029272249, 0.258000057430998, 0.11606777507451274, 0.027130337341898875, 0.21838257119299906, 0.009633262619195927, 3.566578102688636, 30.0503114346535, 49.165129353923184, 44.129159065984915, 118.64495123586347, 120.82228245273714, 49.55849601376442, 39.21284068015314, 61.53362158806094, 77.04572877576275, 82.31391122264247, 86.18444335076117, 50.1988660904669, 0.6085308496990512, 0.009983473010511409, 0.08099382608047417, 0.13512068818653786, 0.019492624597924373, 0.022143432457420616, 0.05257972456034153, 0.06990314821802801, 0.01009428571353877, 0.03137043098949137, 0.047937687561516805, 0.09975568706830663, 0.04441026635768433, 0.03694662411186484, 0.08286798357843392, 0.02135830150256234, 0.06895264760861475, 0.04710488103991074, 0.05118852038116706, 0.02307810377509844, 0.01753236647815474, 0.09284882220409571, 0.015388954930277842, 0.03468623572599984, 0.036645229800694415, 0.12234026551126473, 0.009195982504846349, 0.02159377394784843, 0.03236194794637061, 0.024631078910803603, 0.15819392347287747, 0.09275132985485178, 0.1461430693105344, 0.18093004942901675, 0.07810055713860259, 0.19767645566213518, 0.12318444077766712, 0.13351965635534258, 0.14449539804650893, 0.09806756636187916, 0.1385431553447439, 0.26501696316465256, 0.11167185531268198, 0.1760713972391621, 0.13962062736672742, 0.30978024666828496, 0.14613084254726288, 0.11618635016343287, 0.15276573087659576, 0.1373318171188716, 0.15601703867075906, 0.21090524661685192, 0.1456765064428891, 0.1752796760129352, 7.142147748701035, 116.19222256445117, 131.0257871689335, 118.50759767716931, 100.33902998893493, 81.6979108318206, 61.49441357581847, 51.89003913633285, 70.81195292934295, 82.56484877678656, 77.6907939295615, 62.0579993340277, 62.73383155945809, 47.251149992788996, 11.424396364919602, 0.6487192093364654, 0.3252518213083667, 0.29889095033849444, 0.4527798120773608, 0.2878358725818896, 0.3542597099177299, 1.972198733879674, 4.86857480579807, 13.317518522662501, 11.210265351879983, 4.489506165827475, 9.322614900527462, 7.818780627942855, 81.5710456909672, 92.15200008884554, 93.72961659585276, 86.20284711160969, 74.90827237406086, 68.99195747990763, 86.83399569603705, 82.83957942839592, 87.099179298647, 78.97249114128851, 77.30214980340774, 77.21783453418364, 80.59603075827323, 78.37663604367164, 84.72582371004167, 79.15736029225012, 83.33868534334245, 84.16395202759774, 81.4468163828696, 82.38906383514404, 85.20913031793411, 87.55171099016744, 88.64152585306476, 82.40277644126647, 86.70143527369346, 78.01446007144067, 76.13650768033921, 64.5042835512469, 67.6919271099952, 69.35861279887538, 77.72552259506719, 79.32898752150997, 88.35083899959442, 74.29299369935067, 65.05423907310733, 26.714961221141202, 71.65582733769571, 87.79391734830796, 79.33597718515705, 68.02069233309838, 70.82377495304232, 84.38311838334607, 79.03573543794694, 81.5855113921627, 79.08118786350374, 74.87412421934067, 70.0612897257651, 65.76815359054073, 63.432574349064986, 63.697146061928045, 66.19073406342538, 77.34651965479698, 83.2027752168717, 84.73482162721696, 84.19828061134585, 86.74992361376363, 88.56396490527739, 82.37052671370968, 83.45063763280069, 83.83272355602634, 86.99983350692257, 71.00930306219286, 83.82899730436264, 89.70136596310525, 91.09857697640696, 87.34799092815769, 86.69950546756868, 90.2110779669977, 89.74947775563886, 4.470970515281924, 3.694319157831131, 4.875185470427237, 3.3588552619180376, 2.285930370130847, 0.8701747583766138, 0.2121945266281405, 0.4521839795333724, 0.31800168776704424, 0.17813559050761885, 0.4354999941443244, 0.2114412323721955, 6.690443186990677, 46.49434435752131, 81.53095906780612, 82.14703006129112, 138.0004987409038, 133.62664807227353, 66.9195967335855, 38.54167215285763, 64.73078866158762, 90.62178934774091, 94.3949447139617, 98.42822382527014, 53.649222158616595, 0.5672774439857853, 0.21464200900687327, 0.15170912708966963, 0.18706937080189107, 0.1403932730036397, 0.12123983383419053, 0.24030100554227832, 0.11966211405853111, 0.17454680566105152, 0.20282657366366158, 0.10364052659321217, 0.3881710515387597, 0.13709367102672979, 0.17947734754172065, 0.15772225845965648, 0.15218207913060344, 0.2141017484809122, 0.14930083776914305, 0.16331722839705407, 0.14190404435559628, 0.21929649876490717, 0.36988802614711946, 0.1820100188976334, 0.16474204468390635, 0.1779727355366753, 0.27310740322835986, 0.120385431293999, 0.19118971341559965, 0.13461770549897226, 0.11433025701872765], [0.006112634221227059, 0.034292462702480056, 0.04066436836916593, 0.028474337098399, 0.021586670397570538, 0.045238541469218276, 0.10619772042358115, 0.05946612721609493, 0.05558650091951413, 0.07266627414332283, 0.02721273009815524, 0.041112591091903954, 0.04457877505750907, 0.028717784518976847, 0.02366726369326634, 0.019835404893984238, 0.14988853445937558, 0.03489012236616785, 0.09345365628119438, 0.056899311321396986, 0.059946433701101816, 0.1448650967570082, 0.11499601806844435, 0.23197799650651796, 36.85550012896138, 101.94843338381861, 96.98170077416205, 79.97646885533487, 73.85691242833292, 31.15015187571126, 59.45282382349814, 95.29483056837513, 37.094372472455426, 61.97863017359088, 45.40692998516945, 44.721691916065836, 22.502922050414547, 3.1930505460308445, 0.051272349552281445, 0.06641066828442198, 0.041855018390643026, 0.02883239701810864, 0.07471175188378942, 0.3772669237467551, 0.18898137304331028, 2.1877595734211708, 4.397893326897775, 4.983574286583932, 2.167544658145597, 1.5650694576963302, 6.002681072681181, 71.32022934575235, 85.30846826491818, 81.91200948530629, 76.18494110722696, 67.0528631825601, 64.19591857540992, 77.18888744231194, 77.29021795334356, 81.39988914612802, 76.28466344648793, 81.17479216667914, 74.44776258160992, 77.5744015170682, 76.45459621183335, 74.68457960313367, 73.40630269819691, 71.09406548161661, 72.71366703894832, 70.36610495659613, 67.05760140572825, 68.42901106803649, 69.0562137480705, 73.03306564208, 78.90370845794678, 74.59383164682697, 81.70692443847656, 75.1602925023725, 68.44998005897769, 60.35106228243921, 57.18556834805397, 56.01043016679826, 65.87208071062642, 72.06728396877166, 80.43284446962419, 69.12761657468735, 64.17554970710509, 24.02425450663413, 38.4385726528783, 75.95312903004309, 70.56211363884711, 64.2191429292002, 59.67129591972598, 74.36052906897761, 77.11383681143485, 81.16480581222042, 73.43379851310485, 62.761668620571015, 57.35053539276124, 58.059582248810806, 53.51842288048037, 60.31367424995669, 64.77593514227098, 71.91533919303649, 81.11798055710332, 77.15725744924238, 73.99288531272643, 74.81828535756758, 75.87137899091168, 78.12693795850201, 78.79530199112432, 80.3258579008041, 75.5122781568958, 73.584103738108, 79.75921661623063, 81.34827859940069, 78.18566368472192, 72.87999906847554, 81.06892739572834, 82.84234077699723, 87.45431853878884, 55.461384634817804, 0.6938286726513218, 0.601846885777289, 2.186909889982593, 2.130202223216334, 0.2989002659676537, 0.20048638955960352, 0.11319997089524424, 0.1900502035935079, 0.03525308333337307, 0.29290032663172294, 0.053803894758945515, 0.03787140331922039, 0.5932746070527262, 17.848778809270552, 58.128902296866144, 74.50583719438123, 113.82059281872166, 75.42928864878994, 15.383979043652936, 37.7156876748608, 61.20437391342656, 66.25328802293348, 71.67119518403085, 84.77975629991101, 17.363922865160053, 0.49361465799231685, 0.14152267046513098, 0.0902196773958783, 0.0380547626334573, 0.00268967556973709, 0.0629182189943329, 0.01752029867812751, 0.03627784467572647, 0.021515226952971953, 0.019417580540081667, 0.07349255359581403, 0.018834888319214507, 0.06099905766126129, 0.04868002292970496, 0.011194927107182243, 0.09738950960097775, 0.03859226141245135, 0.062383049122628674, 0.036892086312535315, 0.02306720234393593, 0.005745862924208444, 0.11389229221329575, 0.018715591192425742, 0.05548757215541217, 0.038091427601513364, 0.030369456677186876, 0.07859195657675305, 0.06976319161514122, 0.055099123442966136, 0.010283662648420903, 0.03894913964153778, 0.05315272768418636, 0.1087211910635233, 0.05595908778148794, 0.01541878735165923, 0.04962533712387086, 0.017521541655784654, 0.04878652064249881, 0.050297625242702426, 0.01814302665391757, 0.025478059974228664, 0.020547066101684205, 0.061137838319184325, 0.046285354652472084, 0.022544182626710787, 0.07538797003367255, 0.012091635895382253, 0.08137379803003804, 0.08229333336555189, 0.037841985542928024, 0.24882187976712183, 0.14072704219049023, 0.10712939825269485, 48.75308828969156, 118.47198255600469, 107.58429881065123, 91.26557580886349, 90.50462815069383, 38.88937457915276, 54.60214630250008, 74.70297551924183, 28.62108603600533, 56.456446801462484, 42.796008202337454, 48.243109564627375, 27.327549149913175, 4.223101725501399, 0.05323300603777171, 0.0922741030433005, 0.09832972164956794, 0.0705187381695836, 0.20957381644796944, 0.9979761812475421, 1.4105093190746925, 3.3206268616261023, 4.9957179446374225, 4.058573005660888, 1.3308652250036117, 0.9034973154625586, 8.044439977215182, 75.20349348745039, 87.7802675001083, 84.75078567381829, 80.58401261606525, 70.61776422685193, 67.40590787702992, 80.87476222745835, 82.28264993236911, 83.88410660528368, 79.31921297504057, 80.81810751268941, 74.96887299322313, 78.13760680537071, 80.93373114062895, 78.03009463894752, 77.32452300287063, 75.07673032822149, 74.24328942452708, 74.75660216423773, 70.44734508760514, 71.88617244843515, 72.63492153536889, 75.82081963939052, 82.07890633613833, 77.97919796359155, 83.89754464549404, 77.05775476271107, 69.49082020790347, 61.81020359839163, 59.30194985482001, 59.81246986696797, 67.38543310473042, 76.21421767819312, 84.21469965288716, 72.60148725202008, 73.38311364573818, 26.66535500557192, 45.5575882234881, 78.64648726678665, 72.95872888257428, 69.20256522393996, 62.602765560150154, 79.24862600141957, 80.29879354661512, 84.85468925968294, 74.01319534547868, 66.69424087770524, 60.09217408395583, 59.64480030921198, 55.640786001759196, 62.02989162937288, 66.62774885854414, 76.30079223263648, 84.48120901661535, 78.89274151094499, 72.95363764609061, 76.74795027702086, 78.41787584366338, 81.020321384553, 82.49300664471042, 82.39932475551483, 77.18237630782589, 73.45392811682918, 80.40728630558138, 85.52452025874969, 80.12742519378662, 76.22083079430365, 82.91727373676916, 87.43340446103005, 89.04970338267665, 64.85851280150875, 1.5932320755335594, 0.7172395841729257, 1.2867408894723462, 2.559924106444082, 0.8365320378253538, 1.1985320549818779, 0.5438037132543903, 0.15059407079412093, 0.13400866559916927, 0.04129140367431026, 0.03958814124005937, 0.02749644118481346, 0.5269305960785958, 18.210505670116795, 55.208081891459805, 74.20229281148603, 123.58548241276895, 75.87384223937988, 22.143532922191007, 53.31028622965659, 70.03155815985896, 73.3442194231095, 78.44237496775966, 98.31943296617078, 29.55887571457894, 0.4487580956230241, 0.0389941358157704, 0.08615058606430408, 0.0575351681289894, 0.10685526901074957, 0.053445446049614306, 0.037974955423945383, 0.03884936051983987, 0.016732421298060688, 0.06667155186615645, 0.04877884444149752, 0.0036163735879404892, 0.021404282099777655, 0.05046969625137506, 0.008311677637750344, 0.050671027988315596, 0.0802682948509051, 0.04410691852230699, 0.0937806072855188, 0.10019025810423399, 0.0421295038634731, 0.03221161468254943, 0.031846167760029916, 0.0309574042612146, 0.06746380935393034, 0.04917591930397096, 0.05619737559989576, 0.02031886766123916, 0.08328253673689981, 0.06528347715615265, 0.1772242676346533, 0.15803905113810496, 0.201472865657941, 0.09431263236629386, 0.22565053926119882, 0.15437344299449077, 0.0771926663395378, 0.1552231417548272, 0.12246753569812545, 0.16582696308051387, 0.13091943136626674, 0.2096366816230359, 0.15318205369816673, 0.11398265228396463, 0.17495540631634576, 0.26411965970070134, 0.16324336219939495, 0.19190850307143506, 0.2680581483629442, 0.15326284533066137, 0.46422755586043485, 0.23890099518241423, 0.35981369415117853, 63.66691243263983, 129.99771041254846, 122.25932905750891, 103.97991518820487, 98.05377083439981, 46.97070444783857, 73.14997580743605, 112.1284431026828, 51.13777952809488, 82.06028292256018, 64.86365502880466, 68.68325125786566, 36.11870642631285, 6.147627849732676, 0.20282789133489135, 0.11144184507429601, 0.1303619185402509, 0.2882323077609462, 0.20715729934313606, 1.0154795742804006, 2.123884265461276, 6.1153080098090635, 14.755395689318258, 15.270092045107196, 6.764890263157507, 3.93326725209913, 8.705893774186412, 80.70442153561501, 91.75009835150935, 87.29197948209702, 82.0194039806243, 75.55220004050963, 71.02755777297482, 83.90970399302822, 84.35934882010184, 89.71984032661685, 83.93953754055886, 83.26536840008151, 74.59052116640153, 81.77071002221878, 82.72184556530368, 81.90194468344413, 81.63086968083536, 79.88997274829497, 80.32652470373338, 78.49083192886846, 76.07025884812879, 75.99413348782447, 75.80219622581237, 79.64450297817108, 85.01232147216798, 79.37511459473642, 85.22063070727934, 81.32085338715585, 73.2867645448254, 65.4906419784792, 60.77947139739991, 62.22172690976051, 73.12029130997198, 80.31812298682429, 88.61499494121921, 74.55911082606163, 69.18839762287756, 31.33592709418266, 51.28650796028876, 83.61386314515146, 79.38557163361581, 72.47208041529503, 67.62319933983588, 82.38915797202819, 82.52615851740684, 87.62327855633151, 79.33330997343987, 68.84053830177554, 62.686202218455655, 64.99187730973767, 59.9224413594892, 66.19799829298451, 69.8215623055735, 81.37954773441439, 85.88984981659921, 81.30016680686705, 73.33326032084804, 76.48441406988329, 78.58161910887688, 84.4651351436492, 84.20690982572495, 84.1250656497094, 79.5722136958953, 75.57844069696243, 83.1015702216856, 89.1984239701302, 82.98654279401227, 80.31535379348263, 87.05764139852216, 91.75477381675475, 94.64458788594892, 64.48944522488502, 1.44248521616382, 4.789719966150099, 8.193271861922357, 6.749934755986737, 1.4748457506779702, 1.1546132761624552, 0.5824591615988363, 0.3750256569154801, 0.2774315711952025, 0.6377662970654426, 0.20900395428461416, 0.11925506856172316, 1.3552741345859345, 30.52963487563595, 78.168821027202, 81.56261259509672, 115.8026292247157, 89.97783814707111, 23.702877067750503, 54.78912961098456, 79.52753789963262, 86.93858961905204, 90.21776168577134, 108.54095705093877, 33.42382238757226, 0.6856025430944659, 0.16867898584854218, 0.17227844996077402, 0.09574499461920032, 0.31693259674695234, 0.18863703184310468, 0.12697987018092988, 0.18218523852767485, 0.14146616381983604, 0.1575367732514297, 0.11726592126632891, 0.18828935049954923, 0.1722886542519254, 0.18548530015733936, 0.13922397768305195, 0.23587507045557424, 0.1051352943684305, 0.15861793781720823, 0.16334226415041955, 0.15768427582037065, 0.152318304885299, 0.21631629416538825, 0.1561589334760943, 0.1640677187711962, 0.17030295435219042, 0.24586963737683915, 0.21784840872691524, 0.169752933866074, 0.17261764305012842], [0.034937723239343015, 0.02619968607060371, 0.09149970306504158, 0.07485529377816186, 0.03278498935903753, 0.0942462738302927, 0.019463618593891303, 0.05446964431734336, 0.04268887828314497, 0.03468936902561015, 0.0224579919895698, 0.03350209745187913, 0.08144850692441387, 0.01825032301337248, 0.04712820458676546, 0.039301490290991725, 0.049641026604560115, 0.07180504575972596, 0.070856605926829, 0.019489656007217786, 0.0926031990938129, 0.11781342132317445, 0.2825212448595032, 7.628639811469664, 91.29214594441076, 97.29228973388673, 89.92094024535149, 83.29745338809106, 36.55042209932881, 65.30358414496145, 198.40954934397053, 96.95000017842939, 71.1330303069084, 50.67337482206283, 54.49672475937874, 25.323549432139245, 1.675476210732614, 0.06987367681558095, 0.053290546901764414, 0.13366171970002114, 0.12817287592277413, 0.21241013441355, 0.43748593919219514, 1.5198533549424142, 1.3066317189124323, 3.6643603396031166, 0.9428559712344601, 0.07607639962506872, 2.4240708543408305, 15.376833465791519, 73.60710451679846, 88.25596470986643, 80.36320670958489, 83.17294951408141, 68.58763956254529, 60.88718752707205, 72.51021369811028, 78.37962488974296, 79.87091787399785, 72.05983931018461, 81.62232675860005, 73.30039870354437, 74.6371110793083, 75.52044453159456, 71.92693371926585, 68.68973885813068, 69.59491206753638, 68.13539028167725, 66.97006979296285, 66.87187717806908, 64.88176068952008, 60.566325879866085, 63.342897199815326, 65.23732746801069, 74.66979226758404, 73.86077988532283, 78.28565274515461, 68.94489688258018, 64.38906392743512, 55.04211071998843, 55.907389502371515, 60.56275652300928, 69.35627506625268, 66.37197894434776, 82.3291535531321, 70.11222562482281, 83.0308420427384, 25.24919894433791, 49.278195596510365, 82.05387376969861, 65.42044331950527, 67.6574416314402, 58.73074685373614, 73.55905548218759, 74.3223330282396, 78.37731853608163, 68.1508130411948, 61.95608046747024, 53.970899658818404, 57.99272544922368, 57.04121335860222, 65.41095118368825, 67.54137869804137, 79.79217237041843, 75.04696738335394, 70.8255478643602, 68.68649898036834, 72.95920741173529, 70.9889381162582, 73.28426991739582, 70.17372838912472, 72.19233697460544, 73.16326479757987, 72.07742721803727, 76.35299113488968, 80.8361739497031, 74.50663735789638, 69.6722141388924, 64.61101516600579, 80.04954261164512, 81.04423999786377, 87.89928790061705, 33.29520394725184, 0.6766763930359195, 1.071653308406953, 2.9337755037892252, 1.5408924582504457, 0.537003610403307, 0.07349495145101702, 0.04016344645811666, 0.10033652727161685, 0.15641186506517474, 0.02551770693952999, 0.2061928559335009, 0.07591860849530467, 0.962446800643398, 15.245273247841867, 38.73515875108781, 43.248433989863244, 39.70099533757856, 49.75184532903856, 23.570461773103286, 38.78474143243606, 61.34347684921757, 68.5290942653533, 68.82597061895555, 71.54365539550781, 7.161263419735817, 0.076291432844535, 0.053623392952666174, 0.024306937533941482, 0.04859295703711049, 0.04865699432670109, 0.06000836807934027, 0.017564511527457548, 0.041507620499619556, 0.07526986225838624, 0.028810513716551567, 0.036449080648561644, 0.015352699819261269, 0.027797617160925464, 0.03343855045856007, 0.015042818211499723, 0.01157235851766722, 0.010970813830593422, 0.10982619628550545, 0.022407142903595682, 0.023667246456288045, 0.04124779028878097, 0.044729081508252895, 0.040926588774328275, 0.04404245605391841, 0.052846874741296616, 0.03189887077878079, 0.03172377563802706, 0.017179877932874427, 0.032709744203114705, 0.029231224306708867, 0.05527117146900105, 0.026968173765306993, 0.10389077687455762, 0.03916862383184414, 0.04904616316179595, 0.02008283980220797, 0.029864298299916332, 0.03264072351157665, 0.03383987710901326, 0.02974315873166967, 0.032461052910695155, 0.035684927096289974, 0.01401510838824775, 0.07624445633301813, 0.027931083083873796, 0.0675793277520326, 0.022582705357983228, 0.0672244068775927, 0.08444105320039295, 0.14161674606223262, 0.23516902850279886, 11.241780615621998, 114.97153389838435, 108.31997856017082, 104.60920456917056, 91.41817169804727, 51.67214362852035, 70.6288488449589, 173.4466128195486, 92.59198804055491, 59.34858683616885, 46.62708520889283, 57.11193369280908, 30.326509052707305, 2.0514160250463793, 0.10209643807742866, 0.025459639390089342, 0.05902669535228803, 0.09585561005458718, 0.707868735396093, 0.7462190968855735, 1.8111027008102787, 2.3628487846543713, 4.001331896551194, 1.9800686019082225, 0.7692448806858833, 2.2814515136903335, 19.17663839555556, 78.35500024980115, 92.33530813647856, 82.52459741407826, 85.47010129497897, 69.37452977703464, 64.87892089351531, 75.38955503894438, 82.0114258796938, 81.04289854726484, 78.63184113656321, 82.76119478287237, 73.06213040505686, 75.59687583677231, 80.63654884215325, 74.34928755606376, 71.4857219880627, 73.25400490914622, 71.56673462160173, 69.64203542278659, 69.96285392392066, 66.9172433114821, 63.390283353867076, 67.35425810660085, 68.15635927261846, 78.37727931237991, 76.06011559886318, 80.05970939513176, 72.99409297204787, 68.5492709375197, 57.07371804022021, 58.49216476563485, 62.83396966995732, 74.57874621114424, 69.38548103455575, 83.94914734748103, 70.03028731192313, 84.02466081803846, 26.88258174927004, 52.244131103638686, 84.58002921073668, 68.29601134023359, 70.90027686088317, 61.34956829009518, 76.636962890625, 77.0461602364817, 81.35662540312737, 71.48901677900746, 63.925502530990116, 56.619217318873254, 60.49675087774954, 61.14783294739262, 67.49283544478878, 71.87027115975657, 82.10658258007419, 78.01013761951079, 71.61822749722388, 68.84386447168166, 73.50622115596649, 72.72490855186217, 75.0856968664354, 71.95979533656951, 74.2391787805865, 73.43645003534132, 73.80640014525383, 78.31970676299065, 84.0372359368109, 78.00070039687618, 73.39028373841317, 69.38765402763121, 83.43107285038118, 84.7208736788842, 91.52230278138192, 38.38829178963938, 0.6508512013862211, 0.8833938813017261, 1.0413067884022191, 3.092410127001424, 1.2389317323123257, 0.7685556467021666, 0.3798328586403401, 0.5772021436883558, 0.2418452855800429, 0.2910746778211286, 0.1638281783990322, 0.045175289419750055, 0.9088381740354723, 16.473146715471824, 45.96531860290035, 51.59441794118574, 39.98633600050404, 37.19312598628383, 33.81467873050321, 52.55620271928849, 70.91718227632585, 76.66518826638499, 76.28220019801971, 88.84865837712442, 13.585878264519478, 0.1938160926464104, 0.08660363514096507, 0.017164130995590842, 0.01610870698406812, 0.028839975542899583, 0.0231573632317445, 0.05390867260434935, 0.055278077751638434, 0.038075063963450735, 0.028093794413331537, 0.026509951679937305, 0.046581577870153615, 0.041688432571508234, 0.007626114172800895, 0.03175980666832578, 0.0350905807628747, 0.027476668455487782, 0.07665586853099447, 0.02783352370193649, 0.023140086033832163, 0.11267382936972765, 0.022652252734969222, 0.05408087384796912, 0.04417107455552586, 0.0265710165483817, 0.024214078101419637, 0.04301032111529381, 0.05262409637291586, 0.16493834705362398, 0.08404480188243812, 0.17896540162544097, 0.12259586308632167, 0.10876314969913614, 0.14782473955663944, 0.06022117581338652, 0.11846976715230173, 0.10078680310999194, 0.1641319322610094, 0.0973805157287467, 0.16390115593469914, 0.18902252728660263, 0.11440633721048794, 0.10892683970591716, 0.23432827764941802, 0.11428311962874667, 0.20643680897210875, 0.15711467412690963, 0.18434583630052306, 0.17956699515061994, 0.2630890569379253, 0.5390102704686504, 16.949455814976847, 135.3889689906951, 121.64009663366504, 115.43214567245977, 104.53660934202134, 56.19054540511101, 80.24947366406842, 200.13190915507656, 100.34791023500505, 88.15865855063163, 69.60627909629576, 81.7556873444588, 38.27522946942238, 3.1662796341603805, 0.24940681854082694, 0.2425119965787857, 0.3343666741444219, 0.5829621442864018, 0.5197357434418894, 1.5638764442936068, 4.556682638583645, 4.900422000115918, 9.752897927837989, 6.431643732132451, 4.353125354936046, 8.695553425819643, 21.133901111541256, 84.86116901520761, 96.61245669088056, 85.64419177270706, 89.6517401356851, 75.31922694175475, 68.25647384889665, 78.56000684922742, 84.86979038484635, 86.01231405811926, 83.25183622298702, 84.10288072401478, 73.65433769841349, 76.71182524773383, 84.56340620594641, 80.91033812492125, 74.87660315728958, 77.53935906194872, 75.75679086869764, 73.75482882222822, 75.90337768677743, 70.95116569149879, 68.23086077167143, 69.68811542757096, 71.60023950761365, 80.86266563784692, 76.98774045513522, 84.36658951543993, 75.90182442818919, 71.88105767773044, 61.00476841772757, 62.53292383686189, 68.16739682228335, 77.54984747978949, 72.54799396761003, 87.89747576559745, 71.05655977802893, 83.34265478195684, 31.105927152018396, 55.14653990345617, 87.92347323509955, 73.39556324866511, 76.00289606278943, 65.21983761941233, 80.06993109180083, 79.42255173960041, 81.75996272794663, 75.45877702774541, 67.76855453368157, 59.69847794502013, 64.66267670354536, 64.16461413906467, 70.6484842300415, 74.5394048383159, 84.83077064637216, 80.5596782315162, 73.06087524660173, 71.99076637145012, 75.66690583382884, 73.46390662654754, 75.545743819206, 72.54698984084591, 74.60633616293632, 73.16665372540875, 74.22545048498338, 80.88956525248867, 87.56833399495771, 81.93912090793734, 75.5146708027009, 71.66061262930594, 87.420178228809, 88.97038521305208, 94.3922382785428, 39.063523892433416, 1.4753994177426062, 6.56149918994596, 9.281669278298656, 6.470316831142672, 2.6513334724210926, 0.6156216369521234, 0.37889881359954036, 0.531716377985093, 0.3546964413216037, 0.3181203088212398, 0.42714127008953406, 0.20281244700233783, 1.8632878747678574, 26.10769202632289, 59.66922490827499, 54.616172698236284, 53.596917352368756, 66.00759860007994, 32.79336414029522, 57.952866323532604, 81.07962762155842, 91.57447814941408, 84.6849996812882, 101.24312062417307, 14.136173071399813, 0.5041872535742099, 0.16176246827648533, 0.11170880373327002, 0.23636576509283436, 0.09722506116715171, 0.17270270945324054, 0.12690068733307625, 0.12860226054345408, 0.17794105014012707, 0.1514198829329783, 0.08979467479812522, 0.09886859555638607, 0.08161153809558, 0.1665882246508714, 0.11330815783191113, 0.0673284646003477, 0.07835940292645847, 0.21073614036844623, 0.16143603821194943, 0.16155260615050793, 0.1697535927016889, 0.2462862819553383, 0.10029265341619331, 0.12394932594390647, 0.18267315992664906, 0.1207905156057208, 0.21503358718849, 0.14205079615837143], [0.007112088327806804, 0.021090672516654578, 0.08686900033705658, 0.03742481236376109, 0.06790035689670233, 0.03194573046188922, 0.026345426637318828, 0.010998772209390037, 0.017900092512248986, 0.0814492806732174, 0.04398650865280821, 0.03315376493358805, 0.08797327777551067, 0.10465676520740795, 0.01580242024389126, 0.07838280691254525, 0.023255552720999526, 0.037145316675906224, 0.025440967912154815, 0.0837848222844543, 0.06845920271570645, 0.030521471504001852, 0.14733651172249548, 61.44286970938406, 108.9555201991912, 90.93892082091301, 77.10475260211577, 50.293520727465236, 43.797899215452134, 51.068012329839895, 79.98824381059217, 77.40593571816721, 61.71154422144737, 57.789236807054095, 20.38123553799045, 0.6446707717353298, 0.06564065798996918, 0.05655570939603833, 0.04988386498523816, 0.13744260875448105, 0.07834929822673721, 0.20482139000969551, 0.4668489248762208, 0.7197703096655108, 0.7840317259392431, 1.1150835069917864, 2.8911567455337894, 4.802249487369291, 34.88551324413669, 76.48640663393083, 83.65110212756743, 81.39686892109533, 79.76776738320628, 72.57186551247874, 60.88136280736616, 62.812796715767156, 73.5742978126772, 78.5416893805227, 71.47721044478878, 81.43838328699913, 75.39012770498954, 70.52409018239668, 80.66203640353295, 72.51996471035865, 68.63982277531778, 61.59996455715549, 61.76665744473858, 59.07411506099086, 59.682957126248276, 57.81527350025793, 55.86097217375233, 56.434512907458895, 61.802045068433216, 63.558741308027706, 71.31231400274461, 73.5547879434401, 73.68125300253593, 63.646045423323116, 58.354352289630526, 53.48931889380179, 62.71785966811642, 70.73123839593703, 74.66242605640043, 71.88284627852902, 75.9828527512089, 64.84715361748972, 69.985533068257, 30.123849991829168, 53.97851690169304, 72.61242282006049, 54.63780064736643, 61.50014023627005, 59.144141135677216, 72.94919752305555, 73.55205797380017, 77.20201953764885, 69.6665894600653, 60.55089919797836, 51.99273463218443, 55.855618138467115, 60.1292993176368, 70.5502131677443, 76.94815589535621, 74.94506420627718, 67.5449872785999, 72.82509373080346, 73.3504952153852, 76.30127076179751, 71.65590578509916, 78.24570732731974, 74.76473715997513, 71.51218229724516, 69.58577294503489, 77.48197478632774, 75.4477551675612, 74.55887548385128, 70.57334730702063, 67.06377521637948, 66.87823926248859, 70.77485515225318, 79.93380131260042, 85.98529677237235, 77.11582937548238, 23.27058872868938, 0.3219297576335169, 0.5265559484401058, 1.0995836483855401, 1.9919173467543818, 0.34943163995781257, 0.1490905159904111, 0.19200881462424033, 0.09851463995273076, 0.10801530998921204, 0.1260212796830362, 0.09970514824794185, 0.11386255268007518, 2.254756352593822, 23.905757742543376, 41.18167831051735, 77.09624105884184, 65.10839916044667, 25.431120434115012, 26.991768767756803, 50.036978106344904, 62.70481778729347, 71.15731762301537, 78.76209520524549, 53.388788546285326, 0.8625892621855583, 0.05768029965580471, 0.04823090771453516, 0.03267766810172508, 0.009785777318381495, 0.0379412935205525, 0.002443772837361922, 0.04752619492430841, 0.018654315649802168, 0.06132991188355993, 0.04759425417550149, 0.057885722302260904, 0.037553610896030744, 0.013430699172820295, 0.025892256901809768, 0.03421385442056964, 0.00836749480391342, 0.029444208240977703, 0.061284498191408576, 0.035122641542505835, 0.032477117774467316, 0.017489078679993268, 0.04180027374757394, 0.0567581404691502, 0.0971751275562471, 0.02328360686078668, 0.028190355965747472, 0.018467060778470292, 0.0289900291846284, 0.05691022807431798, 0.020092904282313202, 0.021196204958663836, 0.031547311115108674, 0.02198163277259277, 0.027604235501419154, 0.05602936868766143, 0.010500878260861482, 0.031082475775732633, 0.028972759647595308, 0.037222507695156726, 0.01697014221140454, 0.025329461899555983, 0.006539934125143074, 0.06772758108713935, 0.06578855892463077, 0.035047637704279155, 0.047069300086267536, 0.01886647029389297, 0.028833929193957202, 0.01834889937702927, 0.4831008979630086, 78.98039079481556, 121.307032492853, 102.77723020122897, 89.1554504825223, 68.5727188664098, 60.96121441933417, 59.62967172745736, 110.69662109498056, 102.81275118550947, 64.26728610069522, 61.53815192560996, 25.3333749694209, 0.8416644591958293, 0.13925860485722943, 0.018358638269766685, 0.11945945315904195, 0.32842688803230563, 0.6796511430894175, 1.3337984224480968, 1.983680614540654, 2.2481628483341587, 1.2292460520421307, 0.3293621281702673, 1.5083448757087032, 5.508559999927398, 40.21029157023276, 79.01096959267893, 88.58287857424828, 84.07505543001237, 83.08137786003851, 77.11393879305932, 63.89448835003761, 65.4506455698321, 77.15519428253174, 80.49881873592254, 77.66511809441351, 80.40611743927002, 77.07775885058989, 72.08678599326842, 84.21981442359187, 75.65140462690785, 72.91380989936091, 64.09461552096953, 66.0652417521323, 63.55360692547214, 64.16650472148773, 61.27904015202677, 56.86398498473629, 58.28569512213431, 65.47962796303534, 66.79666180764475, 73.3547156856906, 76.56393620275682, 77.42202528061406, 67.35938856678625, 61.544933703637895, 55.00358127778577, 63.54400496329031, 73.0718735725649, 80.86612516833891, 73.61177998204386, 79.60203939868559, 66.6849370156565, 72.11756090964042, 33.417319097826564, 57.85772923500308, 76.92542968257781, 57.002625080846975, 63.035093122913, 62.90147758299305, 76.30090205900132, 75.54710095928561, 77.59763763796899, 71.44386245358375, 63.153937016764, 55.174153389469275, 57.62882755648706, 62.39833554913921, 73.0766196404734, 79.72307589746292, 76.68572579660724, 70.29788709455921, 72.59189313457858, 76.27731292478501, 79.73407422342609, 75.54862283891248, 79.11342190157983, 78.14085452787339, 71.4662984109694, 70.68660966811642, 78.07479396943124, 77.39773011976673, 76.89905566553917, 74.74747873121693, 69.77303474180161, 69.91428713644706, 74.42549920851185, 83.57401970894107, 86.45793453339608, 83.62983503649312, 29.633277193192516, 0.2608404969496112, 0.4429365934864168, 0.7855028599019974, 1.5103102283131693, 2.3133173392665003, 1.0444362269293879, 0.7138307993450473, 0.0646945930296375, 0.5114904003998926, 0.7177091041399587, 0.16131153360249537, 0.10843648214734371, 1.534155664905425, 29.718708376730646, 35.192113153396114, 74.65485588196786, 60.757231558522875, 28.54503127836412, 41.68951149909727, 62.583585170007524, 71.69955392037669, 81.33296566624796, 89.82038636361399, 66.759336533085, 2.2834859980690867, 0.12537040372168826, 0.05443026739803534, 0.05752301414407069, 0.03327897051349282, 0.031518140402171886, 0.05924240272912768, 0.05764228637300192, 0.06382019176418263, 0.05367676246791117, 0.02140732921449648, 0.026107205851604382, 0.04315570162068452, 0.020577795803546906, 0.05705435985639211, 0.026120711981709448, 0.009639792561140514, 0.06235488773053212, 0.1120745111256838, 0.021206399673716198, 0.019225372910319317, 0.012935463549388994, 0.04374564294853518, 0.02344219663721179, 0.06372475636101539, 0.01523893576250562, 0.030398184974347393, 0.035478320843990774, 0.13766685801167644, 0.11915317886779386, 0.1828813060156761, 0.15829339232896605, 0.0815720386022041, 0.0850438035183376, 0.14186733342226476, 0.1912191771571675, 0.06395404264631291, 0.1106382724678805, 0.09054254515156632, 0.1774595792014753, 0.18411665343709532, 0.23338116314863008, 0.09863953526702621, 0.17421652983513572, 0.12709070012093554, 0.0847792656972043, 0.1860137935727835, 0.1905179309147981, 0.11559149055110833, 0.11648697072579978, 1.0566394559798702, 92.75554303200015, 133.91858223945866, 116.04671832053893, 101.09276048598751, 71.76894064872496, 61.44123408102221, 63.224398474539484, 85.20025791660433, 89.75302357827464, 77.2593096763857, 83.65951953395721, 32.99711950363652, 1.5450761563354924, 0.2376245394829781, 0.08740035126045828, 0.23388923266001288, 0.3528442552253124, 0.47955844611410176, 2.244118639538365, 4.230669938748883, 6.262398852456001, 8.022733580681587, 7.191628448424801, 6.621727674238144, 7.682262043799124, 40.45721653969058, 85.01825209586852, 89.00844789320423, 88.09004060683712, 87.0405790882726, 78.96704689148935, 66.66727850514074, 69.5731899815221, 79.06097981237596, 85.07620903753465, 79.15126492900234, 79.82848567347374, 75.40967679792836, 71.17874160889657, 86.7248361341415, 79.21339527253183, 76.089384325089, 69.39632246571203, 67.68480408576228, 67.37980842590332, 66.45689041383805, 63.674094292425345, 60.70243996958579, 63.266489428858605, 69.39334146438107, 68.98510117684641, 76.99447124235093, 79.73434878933816, 81.31144754348263, 71.51951712946739, 64.3850121190471, 57.72447455313898, 67.89473718212497, 78.43439686682918, 81.77686814338931, 76.190518717612, 80.75633018247544, 66.46220914779171, 74.32432559228714, 38.797834304071245, 62.140016094330825, 81.13394460370465, 61.73074814581103, 67.5948876719321, 67.46033468554097, 80.28990545580464, 80.51030343578708, 79.55413156940092, 75.22903596201252, 66.39031210253316, 58.738889694213874, 61.15521877042709, 66.68762776159471, 76.7936929579704, 84.19160473731257, 78.84217431468349, 72.67893837344262, 74.1411195262786, 79.56084666713592, 84.52307639583465, 78.91465971546789, 83.77861053712907, 80.51074274124639, 70.91518186753797, 70.22358171401486, 81.4222074324085, 79.8758129919729, 80.06014870059106, 78.36290774806854, 71.8555622716104, 74.94624876206922, 75.62081013956379, 86.40917162741385, 90.15890259896555, 90.66608859646706, 30.275783000453828, 1.5474217336985374, 5.287376565317954, 5.616127079532993, 5.917564659349381, 3.0595901848808413, 0.9217743347248725, 0.48874264522906274, 0.6315530788513922, 0.7270525576126191, 0.655229424517001, 0.3394468483184615, 0.3255873678192016, 3.4270255652166184, 39.94203282940773, 62.5852325654799, 95.37429778806626, 84.24028135115101, 38.83193539034936, 39.70503930122622, 70.00757678862541, 81.80664677773753, 91.70597953181114, 98.37025119412331, 78.75242264040055, 2.034151222436659, 0.2352773993005676, 0.2092949910870483, 0.11115773370669735, 0.11642503251712169, 0.1183948590750656, 0.10906303481709574, 0.24020276242686858, 0.1190966492398612, 0.16578613059414973, 0.1198034649414401, 0.13684182728250183, 0.17278307207649754, 0.12861817985052063, 0.12326230595429098, 0.07691033995680271, 0.14095970309309422, 0.11856977993081655, 0.1831720670264575, 0.15972493486779352, 0.15400077186284528, 0.08670785374218419, 0.15728021040558815, 0.11773297443024575, 0.1558385555061602, 0.11002250631610233, 0.1540203377484314, 0.1539987340689667], [0.0755408582007212, 0.016296775823819543, 0.03333089595300055, 0.06470143419480132, 0.01595033458509152, 0.10277354488930396, 0.05947183457113082, 0.034054450675724976, 0.0024460330361410257, 0.0744173213118507, 0.04638954644061385, 0.04994924675913588, 0.011626346648911075, 0.07254615155679565, 0.053991954022597884, 0.019288182544011264, 0.025149549980978333, 0.05178315782799356, 0.014448957386306457, 0.14539513767005938, 0.24662545972293426, 0.5070084489641652, 14.45699941727423, 101.1367851688016, 86.88269584409653, 84.79667740483438, 65.03386628243231, 53.396405789159964, 15.890550209629922, 37.8749123696358, 37.8555868517968, 32.529549444875414, 56.199127551048036, 31.80903946199725, 1.3285277375290472, 0.08230086400984757, 0.07493177233564277, 0.19157790548859105, 0.04454481821026533, 0.36606947621030195, 0.5555513344945446, 1.0286935490946616, 0.3664983015867972, 0.9676802230458107, 1.3799004905646848, 3.865263894681008, 17.81818824429666, 65.23109874417706, 78.93939418177452, 89.7109365463257, 87.33966765865203, 79.40141016437163, 75.576291238108, 67.43976577635735, 58.65360952192738, 61.68874740600587, 73.5147483887211, 75.31086444854736, 81.85707276867282, 76.82110248073455, 68.14440388833323, 73.93682679822369, 74.5504580774615, 70.1029609864758, 61.968459467734064, 58.92575140922301, 54.79702534214143, 55.49010815158967, 54.42907564101681, 55.282438262816406, 54.62962642792733, 54.108994545475134, 56.30307820535476, 60.88075483998945, 65.34211358716412, 66.99263911093435, 61.02145025807043, 55.585625710025916, 51.72486812837663, 55.9342695051624, 69.70763314154841, 74.00057315826416, 76.39970656364196, 73.39701452562886, 74.11733427355367, 70.16571890923285, 73.01185346418812, 36.97035497234714, 55.17939759838966, 77.80598609678208, 56.534686319289676, 61.032672159133426, 60.56633372460643, 71.03581043981737, 73.06525261171403, 75.85820767187303, 69.56850667153635, 60.20685242068384, 51.61069185503068, 54.913598183662664, 61.916739094641905, 69.82596320490684, 70.2091395470404, 73.2780804172639, 68.29930613117834, 75.32779339821109, 65.63620505794403, 69.82741448187059, 68.08566247263263, 69.98190879821777, 76.05209827423096, 73.8966303486978, 72.21325105236423, 79.30115438276722, 74.53156794271162, 76.05179232935753, 67.75743853661322, 67.61981825674734, 63.06344793688867, 67.09356169546804, 72.88604736328125, 78.91604823450889, 76.47581623446557, 88.864787163273, 32.436950129847375, 0.14102273680750402, 2.5754662531037487, 0.3967849441593693, 2.0738392347289674, 0.5987296433698747, 0.1731651201243362, 0.23714849244683023, 0.3544269009463249, 0.09823158578646761, 0.09391803579825549, 0.1652296136824354, 0.12727111382710357, 6.9441813134378005, 45.9974035909099, 30.788226935171313, 28.473824570255896, 47.16314377323274, 18.434884855824134, 31.991627754703647, 46.44232196192588, 64.6779582577367, 69.96494062485235, 75.51509441867952, 20.08705189151149, 0.03779186041004235, 0.11944551035882005, 0.043000511359423406, 0.06064800553083901, 0.03301280858596006, 0.013609890011139216, 0.04871434749915235, 0.05540955376120345, 0.14324149597556363, 0.008313393674700732, 0.045008860648639744, 0.02049386704100236, 0.023865058019216505, 0.05962502151246994, 0.04182215321869139, 0.13989546907044229, 0.09249444525208204, 0.046356282902941595, 0.08114437001847452, 0.07855464043396135, 0.10381576920589132, 0.0606030093566064, 0.06892361287628451, 0.057034828444762584, 0.06377917924715627, 0.0026255470678030004, 0.009312124306996985, 0.07656314124863955, 0.028518980872186444, 0.0346421473659575, 0.05492337904269657, 0.04218141015078272, 0.03208668106385777, 0.01720293334895565, 0.10903452102455402, 0.05839249712505168, 0.03011446239637031, 0.041162608972480225, 0.0590473261000889, 0.060060301179727243, 0.03421415702529973, 0.07130364887416363, 0.05713314816896474, 0.039523299558148275, 0.025877576741960742, 0.04444791957916272, 0.12103672094282605, 0.161106942161437, 0.43403137294996175, 18.66366101849464, 118.13830652544577, 96.86599085407873, 94.9185105293028, 74.98091466965215, 63.410754203796394, 24.441600576523815, 52.140176526961795, 39.808491814521055, 37.63929559338478, 54.23103909338675, 36.48524407417544, 1.6010733838042908, 0.03454893361777067, 0.05239801616558144, 0.14824786523897804, 0.3231720458115301, 0.7615200790666765, 2.9902622920851556, 2.6347805799976474, 1.660427424696184, 1.0458794140046643, 1.9964384912483155, 3.5510933206927393, 22.65233885857367, 69.36463755946006, 82.31357389880766, 88.7404009603685, 90.18385671800183, 82.96609940067415, 78.53593134110974, 70.77676926889728, 62.70704569355134, 64.423820049532, 76.31768195859848, 78.92157093171151, 83.39064105864495, 78.08561186636649, 69.23952179570352, 76.1786025570285, 76.79214754412251, 72.66389216146162, 66.55291788039669, 61.051009239689, 58.5295057296753, 57.12431661544308, 58.42113064181421, 58.67393916653049, 57.00239758337698, 56.09360794867239, 58.9083674646193, 64.89366508299305, 67.84040451049805, 69.03274228495937, 64.08307590792256, 57.39546222071494, 55.25267531794887, 58.64912233045025, 73.0954783962619, 76.34526406565021, 78.28933192837623, 74.65188272537725, 75.5008013017716, 69.96596828583749, 75.19204801128757, 40.346421349433164, 57.966308286113126, 81.61402702331543, 59.95410665389031, 63.032300395350305, 62.04284329568187, 74.96109101080125, 76.0070223962107, 77.13369969398745, 73.0289863771008, 63.09830211823987, 53.38609387797695, 57.917117841782115, 66.08173139633672, 74.90043547845657, 73.9975372437508, 74.74509393015217, 69.1015406577818, 77.85290548878332, 69.97615075880482, 72.75031766583844, 69.97328742857903, 74.76046962122764, 77.39809097782259, 74.1827594080279, 72.06007465239495, 81.12673528732793, 77.17490027027746, 79.53013450868669, 69.73243036577779, 70.73867520978375, 65.98832407305318, 70.76989727635538, 75.86499337227114, 80.83170244770666, 78.49830012167655, 93.11977432620142, 38.24961639219715, 0.9361959705429693, 1.132438891837674, 1.0904480805320125, 1.9421039810103757, 2.448529038698443, 1.296741952819209, 0.7517312527183564, 0.7775270878787964, 0.08312227880401958, 0.34268225212731673, 0.07888071043717285, 0.25673311654358144, 7.78537085940761, 47.572647063962876, 31.1887126968753, 29.226715680091615, 41.05950040201987, 27.577219778491607, 46.080397021385934, 55.43554013775241, 70.55353933765043, 75.97587877704252, 90.2055944934968, 30.585805177688602, 0.05612779566417298, 0.07803886407806028, 0.06731803814369826, 0.05509900469933787, 0.009811473822581672, 0.07119284957767495, 0.05689586392573773, 0.05563389111851012, 0.11389673552325658, 0.011917488788434816, 0.01822688838376874, 0.027105565888867266, 0.024172669133892464, 0.044070107997545314, 0.0326683831160828, 0.07318801066327481, 0.07225734407022115, 0.019067960994077787, 0.030774058353516365, 0.16531602840029425, 0.07631205593145664, 0.10514969682140697, 0.03689874361659731, 0.01900487365351329, 0.05050161913517983, 0.052641704903855446, 0.03250538258843365, 0.1960814759255417, 0.06808393454599766, 0.14806869259524733, 0.19206951943136033, 0.11172029505213422, 0.1567156802141859, 0.1427959392388021, 0.19562986709417837, 0.14632401927824945, 0.11545374028144345, 0.1337045440149884, 0.16073056316423803, 0.18550331854531843, 0.14987777858491869, 0.2447164605461782, 0.21109940394038157, 0.15443785566716425, 0.13041381333624164, 0.14167610255460586, 0.1934636615577244, 0.3576936530730417, 0.6665412336587907, 24.21587601784737, 133.9287176439839, 108.5468327614569, 107.23754559793781, 84.50098560702416, 69.908003499431, 25.714476377733295, 53.90083436043032, 55.189987997854914, 46.15963674360707, 78.22192207459481, 47.78161917963336, 2.6136181671773238, 0.2795291812189164, 0.14505402936089426, 0.4853687020799806, 0.4282414336358348, 0.998371237468335, 5.090785411096388, 5.12582149236433, 3.087381893588651, 6.318277428227087, 7.664515770250752, 8.829138567370753, 22.108739537577478, 71.64904948203795, 83.27053808396863, 88.02088922069919, 92.28190898895265, 86.66546713921332, 80.5365127132785, 74.28539999069707, 65.82424348400485, 68.03579345826181, 78.21098650655439, 81.61606665580504, 85.83634868744882, 81.41455881057247, 69.60857760521674, 77.7608709950601, 80.14964149844262, 77.81339937640776, 70.22663331800892, 65.14234335191789, 62.13841576730052, 61.418103864116055, 60.358667758203325, 61.706990349677305, 58.85492909339167, 60.042893425110854, 62.87292272813859, 67.50111949059271, 72.39341335911905, 72.17652197807067, 66.96358219269784, 60.72429149381576, 57.42293842377202, 62.219816715486594, 77.18174872859832, 78.92275548750355, 80.31029393596035, 77.58601173277825, 79.68963376937374, 72.07476785106044, 76.5980294442946, 44.8732562218943, 63.07909819387621, 83.51840049989762, 62.34558359269173, 66.08654806690832, 66.17633112015264, 76.51843670875796, 78.45367139385593, 81.6268688632596, 76.97998200693439, 65.16060198507002, 57.610851333987334, 62.17251293120846, 69.12079949532786, 78.58962074402841, 79.19441100089782, 78.82281349551293, 71.28920339768933, 82.44236100104548, 74.72579586890437, 76.41104221343994, 75.09792681663268, 77.92566545547979, 83.74032035950692, 75.79910539811658, 73.02353428256127, 83.94441696905321, 80.83656618672033, 83.6150320114628, 72.20847360549435, 75.9392438396331, 70.99533942437941, 74.22714494889783, 77.94827399715301, 85.43406255783574, 83.0221422256962, 97.58171358416158, 38.60717573473531, 0.6736474039573824, 6.616704588936222, 6.738184315543021, 6.621422219660975, 4.018151755294492, 1.3339008943688486, 0.9151313105417836, 1.459130774582586, 0.5713863106023881, 0.3536245310979505, 0.49635587380297724, 0.32472576405252185, 11.965266696868404, 69.37424736638224, 43.51760664293843, 39.91671392994542, 62.35547581026631, 27.06583292253556, 47.717696312935125, 62.886176416950846, 84.03782429233675, 86.05524047728508, 102.77759890402518, 36.644606051906464, 0.20586509287597674, 0.30007296271862527, 0.15144199223047303, 0.16286955725762153, 0.11362805316645293, 0.10979825705890695, 0.2274289664121405, 0.12247186409489763, 0.29523701737484626, 0.08031096594828753, 0.12636171383482794, 0.09996545726373311, 0.08308704642038192, 0.157848417819027, 0.10172663211461999, 0.23688227689314276, 0.20256066454514382, 0.1896479461462267, 0.21439909784784242, 0.3732837261932512, 0.21944613105827765, 0.20832402060829824, 0.22608941571126062, 0.1588899143520863, 0.18755525440698673, 0.11863406236854293, 0.0912237122294403], [0.04452806386736132, 0.030666306171746507, 0.016530681619300477, 0.05719341247552826, 0.054434798808107455, 0.09647638642139013, 0.018273907030121456, 0.05004924038545259, 0.04158510646272091, 0.004817355262686409, 0.027621319262130607, 0.005559772027716522, 0.041522126374465805, 0.02269866234142213, 0.05079556324128663, 0.05792997537120696, 0.017657426501353903, 0.005197707383382705, 0.021716434200624787, 0.03403576196081216, 0.06949188157675729, 0.03835567430923543, 44.645052725268954, 94.16882007352768, 88.55739885760893, 74.75173842522406, 61.35451439888247, 71.37635061817785, 66.47607080398068, 27.760537632050056, 48.06307669608824, 65.67842545047884, 45.07479152371807, 4.865671271278012, 0.06539013957785023, 0.020891650534805753, 0.10316219661504993, 0.08347073389637856, 0.23628877325644418, 0.6632587001208337, 2.158828906474575, 0.9749575680302036, 1.6080038441765694, 1.6956402577700156, 11.147048511812764, 57.73048362424297, 88.88392048497354, 83.13719318759057, 77.98354394974248, 80.9263413952243, 78.45886461196407, 80.04502404120662, 74.69967288355674, 64.15019550631123, 56.67594655867546, 60.18449098833146, 68.12323093414307, 72.33717441558838, 75.92561752565446, 76.80637005836734, 70.9217949836485, 72.68164480886152, 76.7267067201676, 70.56216070728918, 60.947419443438136, 54.252098298841915, 53.31896251247775, 52.42022199015464, 51.96866304643693, 52.002132631117306, 51.344884595563336, 49.514753741602746, 53.692262326517415, 54.958972161816014, 57.018047840364524, 52.70808473710091, 52.554257223683024, 51.91630724937686, 51.91635431781892, 54.35819841200306, 66.29195474809217, 69.22070226361676, 71.38895711591168, 66.01461964268839, 74.52211503059634, 64.76994960538804, 78.51450735522856, 40.54112780478693, 50.63684578864805, 74.84205492081182, 56.836410722424915, 62.30233553917178, 60.415522513851045, 70.57071147426483, 70.92009267499371, 71.55891341547813, 67.81346567215459, 61.18603683287098, 50.67049187998618, 53.28719523645217, 61.53643784984466, 73.64300989335584, 65.26809061727216, 60.91123950096869, 69.39759331364786, 67.70046218749016, 65.83972900144516, 61.18577795643961, 62.82421473533877, 64.73772733442246, 69.6908297077302, 72.26564607312604, 71.61355987671884, 73.54017319217806, 75.42475438887074, 70.18488360989478, 65.34005434282365, 60.39438093862226, 65.10015433834445, 64.63456899889054, 66.37445003755631, 75.69347596937611, 77.29507384761688, 75.38062772443219, 82.90194511413574, 52.35834660068635, 4.4498691443474065, 2.01704221146722, 1.5410393019837718, 1.1117542727339653, 1.5949433320953001, 0.4079529739195301, 0.4438387999130834, 0.4232095230010248, 0.07612181331722007, 0.0553879615730576, 0.08018032497455997, 0.10106599619311672, 9.943233882227252, 44.848129518570445, 57.22474105896489, 47.47331696171915, 30.50186449481595, 19.10460602852606, 37.831813366182395, 59.668679698821045, 67.88361334031629, 70.27319185195431, 60.87560084558303, 10.02173129589327, 0.26867512493364276, 0.010844046388933016, 0.0468768971040845, 0.05233476794655285, 0.03612523613077018, 0.040578252425597566, 0.0609135814011097, 0.06149557839718558, 0.03392400505441812, 0.0827113798849525, 0.012795583555294622, 0.05370488938605113, 0.029906021363492456, 0.013047676278097976, 0.05742995361346872, 0.02076085825871316, 0.06853295400017692, 0.08936267781762347, 0.033492624774695404, 0.06710495078755964, 0.02783234967219253, 0.030709969352990873, 0.05210868773921844, 0.016686461768263293, 0.043898056141070785, 0.10966468962930864, 0.01420196106341938, 0.08895727174897348, 0.08784495038731445, 0.053083458014072916, 0.020719795945971724, 0.03989227048511948, 0.06836231557592269, 0.024191601081721248, 0.06437130392559114, 0.027347620944642735, 0.05158541521297828, 0.012181072830102377, 0.030351622150309628, 0.036301777262480996, 0.02082130642637851, 0.04506573501613833, 0.0015672416080750767, 0.024646540480335394, 0.026046487637945724, 0.04681553346134963, 0.11637541300226605, 0.07305115671648134, 60.351874213064875, 107.98482771842711, 97.6283819444718, 85.47604760816021, 73.72843127096854, 88.8310783140121, 49.761313930634536, 29.060881791576264, 46.5094768616461, 51.133284491877404, 50.777772626569195, 5.162696674946816, 0.174571841414417, 0.04794937040236208, 0.2646913757968334, 0.5500005678303781, 0.9734199989226557, 1.5125109231279743, 2.688564610096716, 0.7516941740628212, 0.6689132870204988, 0.7756335636781109, 14.222207319351936, 64.32695319575649, 92.57421970367433, 86.72654628753664, 81.65216815087103, 85.3527126004619, 84.14404207660307, 81.33520926198652, 78.36158983169064, 65.0842373601852, 61.045117839690185, 62.6218008225964, 71.63186165594286, 75.9200163810484, 78.77572936396446, 79.75745939439344, 72.34452493729131, 74.07776540325534, 78.21220244130781, 73.2698355951617, 65.28705135468515, 57.0477480273093, 56.21361678646457, 54.58949273632419, 56.12802282456429, 55.08969299254879, 55.296774525796216, 52.96452145422659, 57.209341833668375, 56.80318432469522, 61.19862371875394, 56.136087217638575, 55.670862736240515, 54.38499604502032, 53.303092602760564, 56.09128982790055, 67.90790065642327, 69.85851103259672, 73.52769221028974, 70.04976580219885, 76.64358385147588, 68.57062432073778, 82.13258789431664, 43.37090607612364, 54.3816698751142, 78.52594498665103, 61.26514319450625, 64.89720698325866, 63.81703722861506, 73.22913708225374, 74.27528027565249, 73.40098396424325, 69.22926087533274, 62.65040274589293, 54.1852532663653, 55.18351216470042, 64.57798488678472, 76.96104480374244, 70.4251209382088, 65.22785494404455, 71.56456162852626, 70.71433298049435, 67.97317674083095, 64.23506775209981, 65.3203797340393, 66.81807010404526, 73.11238381170458, 74.3722334215718, 71.77345137442313, 75.48424889964443, 77.91221957052909, 73.46687978313815, 68.20234514051869, 65.01288160201042, 68.90206460029849, 68.63413533856793, 70.04333311511625, 78.58976979409495, 82.18954070921868, 77.9710002099314, 87.72170651343562, 57.696104049682624, 6.4639635720560635, 0.8401647654752579, 0.812366008758545, 0.5750760964808926, 2.5512527265856346, 1.0527275046033244, 0.6350015776772654, 1.0690753306111982, 0.11233538704653902, 0.07762452542421318, 0.11697882215582556, 0.1915447492032282, 11.03920098273985, 47.067394794956336, 42.70913947013117, 42.83969948368688, 30.75192539922653, 31.56817847682584, 48.030419042033536, 67.75612846497567, 73.86276460463002, 78.45831548013996, 78.09655527914725, 17.30601691430615, 0.3614341233286166, 0.05212754116303498, 0.03007204602322271, 0.08034684950666082, 0.05164996961191778, 0.048149625785769, 0.10787862458176191, 0.03849235205580631, 0.014950798602864869, 0.027192859692619215, 0.01746906654819125, 0.018380789702097257, 0.026889431418009827, 0.0386316268404405, 0.07658389457050832, 0.02674243446709889, 0.02585719305751545, 0.08439927842588195, 0.03615272336549336, 0.06437660525402715, 0.06962652919032881, 0.029936965569973956, 0.043838672835620186, 0.0064111308048238926, 0.009798704094493823, 0.050579373229054675, 0.15109000547278315, 0.18546179657982242, 0.2131475400059454, 0.2075112626076706, 0.18640987635139497, 0.20158652246238726, 0.17130679000289212, 0.2168096088233494, 0.1482404648296295, 0.07911304192196938, 0.09329241775577107, 0.12493794708843194, 0.09573105947985765, 0.1171293814155844, 0.21283094651035725, 0.14633561784942306, 0.09581494610756637, 0.07581393790221022, 0.10723994474016851, 0.0869280657160186, 0.19428034192852436, 0.1584775445442046, 71.32150803842853, 119.3913939691359, 111.5947340380761, 97.15406540901431, 84.73417051376836, 85.76405940517303, 79.3328942022016, 39.458243769984094, 69.59076219989409, 94.15570366767146, 68.91661659363778, 7.501157877906677, 0.3092973354843355, 0.18711936569982962, 0.6078207168367602, 0.7082832196066458, 1.4620829710075933, 2.4529958828803036, 7.421066020765613, 4.623458539285968, 7.611129370427902, 5.825962606937655, 13.917283242748631, 64.16819134066182, 98.50871086120607, 86.81784337566745, 81.87284854150589, 85.78637769145351, 87.50250877872591, 86.97951562942998, 82.01066493988037, 68.89684784796931, 64.18140972814253, 65.05670232157554, 74.39618341384396, 79.99587674294749, 82.82549027473696, 81.9611567835654, 74.08281741603729, 77.43389437275549, 82.68671681804042, 77.89922868051838, 66.26884414303687, 59.256046356693396, 60.898876190185554, 57.76118793795186, 59.2285309299346, 57.030921059270064, 57.45842802909113, 55.69370269775391, 61.16988451250138, 59.21412014192151, 64.7803674205657, 58.858447459436235, 57.97082685655164, 57.43887501378214, 56.22481515330654, 59.161207368296964, 72.44026999319755, 73.34182677730438, 77.34391520100256, 73.51135161615187, 81.35606058182256, 72.44336866563367, 84.46158147627308, 48.21051466849543, 58.9173928383858, 79.93117332458496, 66.17990047700944, 66.93896539749639, 68.31526233303931, 76.27635586646296, 78.63371602950558, 76.20973833145635, 74.41086092302876, 65.86349071994906, 57.328005298491455, 57.55528311575613, 67.85526244871079, 79.32797555000552, 72.15949889152282, 66.53305499784409, 77.64218791838616, 73.81698269997874, 71.73839322982296, 67.59038479097428, 68.46029589253088, 69.37170567051058, 77.4755185650241, 76.59919831060594, 74.05798096810618, 77.44658716263311, 82.01666616624402, 76.46824606003301, 71.15386593726375, 67.3019572227232, 72.8686712634179, 71.73829909293883, 73.36036389873874, 81.68815197483187, 84.98795570865755, 83.9488257131269, 90.9121153431554, 59.42603403522123, 5.0517534152154004, 4.940059021595986, 7.29426657961261, 5.105834564855022, 4.847731330702382, 0.8429403326684429, 1.2366604348344188, 1.9527641251202554, 0.5129357631648741, 0.14549374850767274, 0.2185346702894857, 0.23681953429214417, 16.70654146902023, 70.00179521499142, 72.59223830315375, 67.856337178138, 42.335023803095666, 29.667743059896655, 53.80323010106241, 77.52792927526659, 87.6700096745645, 87.44624630097421, 89.2630018726472, 18.778184421600837, 0.533131311737722, 0.07816387430554436, 0.10591323367289959, 0.4304759282498591, 0.1587213903305031, 0.20817913806005833, 0.16303415890903245, 0.13834001947074168, 0.11159928380361489, 0.12113969082072859, 0.16776830648943303, 0.1716277961649241, 0.09953254097772223, 0.12572066678154853, 0.2237969129196098, 0.06478581877966082, 0.14283185344069235, 0.28052368591870036, 0.16416698844442446, 0.09850993617287568, 0.13495332861859954, 0.19021667449945406, 0.10030616720717761, 0.11365198575320745, 0.09343599795453972, 0.26172934280287835], [0.038857140142710946, 0.0256052439761979, 0.050570329561108546, 0.09033596954278408, 0.049390749510137305, 0.04724742701998161, 0.03243957180529833, 0.03136704871130567, 0.026443506959044648, 0.09769778338170822, 0.02440501402522768, 0.0649594909120952, 0.008469055080035282, 0.017700340831652284, 0.016723080771043897, 0.027004363758850004, 0.05927834757453492, 0.007973445031130988, 0.09128628629109553, 0.10684098147096173, 0.25068839170759727, 4.294835502101529, 77.40555917063068, 97.31102297382971, 81.27220030753844, 76.55984124829693, 47.20559950797789, 23.229137120708344, 40.91090925278203, 62.182016834135986, 51.80632006737494, 45.084660207071614, 14.436215758323671, 0.10011689752460488, 0.1833921487653448, 0.09090192465772552, 0.04340494832684917, 0.36648074285157267, 1.6865208696934486, 0.735930290914351, 1.1410325597370825, 1.7312333156024258, 0.7671996710761901, 30.97937187840862, 91.37821059073173, 85.25724995520808, 78.47078077254757, 80.51447683765043, 78.3672223552581, 77.01559712809902, 83.01631358362015, 74.5869831885061, 70.66305975760184, 58.794136278090946, 56.954866301628854, 55.20235130863806, 62.39502506871378, 68.03943341778171, 72.89898334010955, 75.08389257615613, 69.38673619301089, 70.37282789907148, 71.33954309648084, 66.86334210057413, 63.00568319136097, 55.074976259662265, 52.3907571454202, 52.607789731794796, 53.18961058893512, 50.14916573801349, 50.96221031681184, 50.19625771430231, 52.318244288044596, 48.97967184743574, 51.02933383757069, 49.443570567715554, 51.88297887002268, 51.48225776610836, 51.68052965594877, 50.41747546965077, 53.71137603636711, 55.10577471025529, 59.055373976307536, 54.25874279391382, 59.66626744116507, 59.54414444585001, 73.94336146693077, 50.19989767382222, 48.48178971198298, 75.64596822184902, 59.1801602609696, 63.94491041860273, 61.91899837986116, 71.72809308575046, 70.27485493690737, 73.64111146619244, 64.86479251615464, 58.86504880843624, 51.154853605454974, 51.67670926740093, 60.61964657998855, 73.37916774134483, 75.3370423470774, 66.520032728872, 65.41421459567162, 66.84302422308153, 62.49954838906566, 58.63136183831, 53.62471518977996, 60.6203761408406, 68.32638617484801, 71.75320409959363, 68.45066255138767, 73.99926308662661, 73.24181418265067, 69.44837231789866, 59.45643632642685, 58.99581670761109, 59.85055608134116, 66.47040690145185, 65.94016521207749, 68.28516206433697, 73.45143348939958, 76.31612870001024, 69.6279384243873, 70.95685312824865, 67.68346263516334, 20.687090196917136, 0.6482392092866283, 1.5532454728118836, 1.5888254152190302, 0.4498464614152909, 0.43497828826788937, 0.261546554224145, 0.17289553378378192, 0.261827708492356, 0.027799254673863613, 0.06392380132550193, 0.3790050240293626, 24.659519618557347, 46.94491094158542, 53.01094270521595, 47.54074250498126, 23.612480163574222, 31.886023821369296, 48.38603288896623, 60.258184479128936, 71.52554189005207, 80.9908643845589, 57.90420932154502, 3.5824980226255234, 0.09378011698924726, 0.02843691753373752, 0.04219998778294652, 0.01092661821824168, 0.025105091983512528, 0.014100220756635312, 0.02817268806299375, 0.09029181223482856, 0.02980857114908436, 0.0332233410388712, 0.03717590273628312, 0.05096216821261952, 0.03936934269844525, 0.04266719033400859, 0.030281343159355947, 0.05622542207880367, 0.02281929820685858, 0.08989480248982869, 0.10687944674563986, 0.014117217374845378, 0.07116661106626834, 0.05466065301950421, 0.04851278210539491, 0.0528612963464712, 0.019290620618830287, 0.01161569132349424, 0.023819519837777463, 0.0053839615523634905, 0.01521162472800502, 0.021078646851463184, 0.0222927104351261, 0.05929238613574736, 0.018361419168931824, 0.018651084673981515, 0.05714004679072288, 0.020351966490007697, 0.06360792412212299, 0.028344900797932383, 0.022794729767126903, 0.07223453763271533, 0.08729620160715235, 0.02529408778965233, 0.015507568323594189, 0.04371084340457474, 0.14557329907773003, 0.2687363200370343, 6.364356942715184, 96.0157778955275, 107.43658234996181, 91.55559585940455, 85.52475560096003, 56.99717690867763, 32.76231858038133, 53.20004017122331, 46.9888218756645, 40.14734929607761, 50.91015261988486, 17.711589990123628, 0.061511746682827516, 0.11204594370698738, 0.11043688327434564, 0.7407584221613023, 2.223515654763868, 3.6485691224375083, 3.1915267052189, 0.7356962970187588, 0.9473540718036314, 1.0774106123755056, 35.00677724038401, 96.1181596017653, 88.7503480911255, 82.24795264582481, 82.27732335367511, 82.56178932805216, 79.81660873659196, 87.23753698410528, 77.47256109791418, 74.99001456845191, 60.89988816169001, 58.9331333098873, 58.03631082657845, 66.21332691561791, 69.77284646803334, 75.14236727068501, 76.52344949783819, 72.11661169605871, 72.18372344970703, 74.37044482077323, 70.63976087877828, 64.67349852285078, 58.44286449493901, 55.43051950393185, 54.803344280489036, 55.10202492437055, 53.374793529510505, 54.00552634269961, 52.65146140129336, 54.434837602799945, 52.81892699580039, 54.7412492382911, 51.69528561253702, 52.32848559656451, 53.49262937422722, 53.46689078115648, 51.75976937816989, 56.699974998351074, 57.59951960655951, 61.496155108174975, 57.61674273398615, 60.770089087947724, 64.07139508954941, 78.03503682536464, 53.80973731317828, 50.86158975478142, 79.75057171237084, 62.64091845481627, 65.00774721945486, 62.76333170552408, 74.43656813713812, 72.47218239691951, 76.52644618864983, 67.36766476784983, 60.275337003892474, 52.87033750164894, 52.18115352815198, 63.44455326757124, 76.72900522908857, 74.92111421400502, 67.52344562161353, 70.30773224369173, 69.68660923742479, 66.55868376455, 60.9034457514363, 57.54034280776978, 63.71988011944679, 69.71816078309091, 74.33554357097995, 69.64161180680799, 75.69830048468806, 74.48595862234794, 73.59328208431121, 62.23867939364526, 62.21972650097263, 64.5972123453694, 68.55694309357675, 70.49175416269611, 72.92252540588379, 75.47548632467948, 80.84966690309587, 74.12943870790544, 76.6069410693261, 75.28000324003159, 26.20468047357375, 0.798210603815894, 0.5084728719967028, 0.7707289462127994, 1.9269820182554185, 1.0444060737086882, 1.0302535492566325, 0.9906452101084494, 0.592859509971834, 0.0459975698932765, 0.07967438518760667, 0.3898614092219261, 27.11206982212682, 47.5572007702243, 47.154271371902965, 41.60321151056598, 23.636255610373713, 42.423292821453465, 58.17789662268854, 68.3774789687126, 80.5327158589517, 89.96128574494394, 71.66231493796073, 7.28616149194779, 0.08508423763898113, 0.024741489417670716, 0.06896274464745676, 0.029330373321089055, 0.05074884336922438, 0.0631042596163048, 0.03157930486204644, 0.11071351762380331, 0.028007914041799885, 0.06957484889895686, 0.0291716686314753, 0.05712333458265471, 0.0780882461056594, 0.019105914905066454, 0.09260316078941669, 0.019312932929624955, 0.027642388595268134, 0.07779101931279706, 0.04733967549738385, 0.09660033944753871, 0.03701250767335296, 0.07846908373457771, 0.046101393959214615, 0.04458032638555573, 0.06763135278297049, 0.09055566823770923, 0.07785609848196469, 0.14575450951533933, 0.17420404260196995, 0.13282040194157632, 0.18220661238076227, 0.1747557178380028, 0.14057276740429864, 0.15436426526115787, 0.22360549819084907, 0.1488572115739507, 0.11260069861647584, 0.08909673805558875, 0.1109715207149425, 0.16178316797219938, 0.21108775940393248, 0.146582160265215, 0.17129175935781774, 0.20294884129637675, 0.24394022961778028, 0.6442306082575553, 10.215630723584084, 110.5265392795686, 119.6429983262093, 105.76214605762114, 98.77506333012735, 64.18299436569214, 33.88447730771957, 48.1086624822309, 88.6348892027332, 78.03046334174373, 65.43457561923613, 24.672265360432288, 0.20181362156666097, 0.5216934351671128, 0.23676969261179048, 1.038484275341034, 3.3674879083710336, 8.272096303201492, 5.888837710503609, 4.132944576201901, 7.646338526279696, 4.053279521965211, 36.795825189159764, 97.90435990979596, 91.42746771535566, 83.42369879445722, 84.8671074836485, 84.0828452571746, 83.27717473430019, 88.02312497169741, 79.49750038885301, 76.88461349856469, 64.85629273999122, 63.585758593774614, 62.14446406210623, 69.21852142580094, 72.64217792018768, 78.56870666626962, 80.04110951577464, 72.94347870734431, 73.00082375926357, 76.8341012154856, 75.36011372843097, 69.65651681346279, 61.88121418799124, 58.53503627161826, 58.92743018365676, 57.72761637164701, 56.898811709496286, 57.05671064315304, 55.74876885260306, 57.25177795656266, 55.3289536506899, 55.779739887483665, 54.05511294641803, 55.07858484022079, 56.969179030387636, 57.25674367720082, 53.06396922757549, 58.63222083737774, 60.466634919566495, 64.97342255807692, 60.16545572588521, 65.83702256602626, 67.95536918024864, 80.30628527364424, 57.67744925714309, 55.87967011236376, 81.90024237478934, 66.1448109534479, 68.75380685252529, 68.42302553115353, 76.09162007608722, 75.92277772964971, 78.4820536644228, 71.01470808829032, 63.65491782465289, 56.5403502218185, 55.16679502302601, 66.42432689666748, 80.86953763038882, 79.93115763510428, 69.48918065717145, 73.73130244593467, 72.33370704035606, 70.38395958562052, 63.005891076980106, 62.28169210495488, 65.64204938950078, 75.59956658271052, 78.48483070250481, 70.10784041497016, 78.36101716564548, 77.77511704352595, 75.87758418052428, 65.66697997431602, 64.82340758846652, 66.21251890736242, 71.43513910232052, 73.39486506677443, 77.0911890460599, 78.44552070863786, 83.53181500588694, 76.848951308958, 78.2013374759305, 78.72124764227098, 24.816441882041193, 1.7234774414570102, 5.0632842029294665, 5.402217190111838, 3.289834539736471, 1.1478085767838264, 1.2331614354925773, 1.6963331689757688, 1.1591697219879398, 0.1347128536191679, 0.3552946640599159, 0.9738461889566915, 39.49729488741967, 66.2140250975086, 71.18521351968089, 63.72186091638381, 32.773287488568215, 44.81999043495425, 65.05887923702117, 79.57804233797135, 92.43171215057374, 96.94112777709962, 81.97238260699858, 7.098503045497402, 0.2184498337127509, 0.1230906562939767, 0.21268456242978576, 0.13324446225118253, 0.08343651274880094, 0.15959499103407707, 0.15477982199480458, 0.18020142320423357, 0.12567611876875162, 0.11963091129737517, 0.10047995425280064, 0.1428255255544378, 0.21547454739770583, 0.0990721297961089, 0.23335615803878154, 0.14165002492166337, 0.13155240385282424, 0.17448323568509472, 0.22075540596438994, 0.20295428052063913, 0.08127287360689334, 0.16510152378149573, 0.16768849544948147, 0.1459354594830544, 0.15789148728213004], [0.06601646242122497, 0.03148994453611874, 0.0890804433654393, 0.07271511224849571, 0.07286209387764817, 0.060523443464790626, 0.012337808673750731, 0.013625289336027158, 0.0793504678914624, 0.062288927560251575, 0.02957716854589601, 0.1002123290973325, 0.08418508790313237, 0.018614187964328358, 0.027739164652302865, 0.02001412746105944, 0.04833741308820825, 0.14375623045188768, 0.08420311395199069, 0.24727715539836118, 0.3000435142988159, 18.23539310886014, 90.71274911203693, 84.82137264743929, 85.6130716877599, 58.16923602934807, 41.116182573380016, 37.4027374482924, 24.61776206570287, 47.04192684542748, 51.80717906644268, 28.344133361693356, 1.3410589747851895, 0.07351186667238513, 0.08313437533234397, 0.2213750331993065, 0.310804444936014, 1.26518280756089, 2.503214723640873, 1.617003109666609, 0.41339967520006243, 0.46885405276571557, 41.83819678521926, 94.59393439754363, 78.67622667743315, 78.51332279943651, 81.86330149250647, 80.81698571482013, 82.85004431201567, 83.23368349382955, 78.97087512477752, 77.6536726182507, 70.17462268952401, 56.52678274339246, 55.961820233252745, 55.531520535868985, 57.218802590524, 65.6751149700534, 67.7875623395366, 73.40256075705253, 73.36416075306555, 67.82342849239227, 72.4289264986592, 70.63670143004387, 64.97451297698483, 55.429272190217056, 50.096147060394294, 50.77034757983301, 50.55738641369728, 49.310817949233524, 50.27718405569754, 50.8091555103179, 52.033319396357385, 49.04850552158971, 51.07829678443171, 48.34375366087883, 52.051593718990205, 48.752903938293464, 54.571881294250495, 52.48250530612085, 54.34037123956988, 50.302008736518125, 51.92844306269, 50.24971177501064, 56.93288926155337, 58.06303785693262, 73.77337378840294, 53.372797043092795, 47.049477408009196, 74.15898200004332, 61.09852090958626, 60.255583947704686, 60.63470848145024, 69.23606226521154, 68.14126599219539, 69.86625379131686, 63.17359985843782, 56.10843058555357, 50.609134243380645, 50.54505055950534, 52.23433694531841, 67.47616537155645, 71.10030989493094, 71.70847339014854, 66.1554798003166, 63.796503620762984, 55.985068121264064, 56.35269618803456, 51.39607544868223, 57.46707685532109, 64.15322357608427, 72.24978400814918, 67.45040324426466, 71.86772161914458, 71.66997140453708, 67.54927835156842, 59.14722411863266, 55.55596474678286, 58.29813295795072, 66.26682020002796, 67.17105988533267, 74.05210525758805, 71.67635702317762, 74.0928194599767, 79.58488295155188, 76.71794414520264, 67.77631298188241, 75.0735688978626, 35.86345426497921, 0.056305413149417415, 1.972557385602305, 1.0548295272934822, 0.5418026915961697, 0.1443296625849701, 0.24928732414639768, 0.1834574960652859, 0.30655376012286834, 0.06347934392491175, 0.22331122849737445, 6.22118454787039, 38.72032434709611, 36.2017116238994, 56.75430766997799, 39.90593133434173, 19.150081988303892, 35.161106817183956, 50.242102376876346, 63.71886422557216, 67.47420418647029, 79.155195143915, 39.036816473930116, 0.23010409947845245, 0.08548531531085891, 0.08087951044041304, 0.04431953090393255, 0.04813425806200793, 0.027059648493905703, 0.04562828103981672, 0.0442232336518505, 0.06039476367614924, 0.04916835418571869, 0.054147063844626954, 0.07287618223457568, 0.04257203838337333, 0.05013023120080752, 0.07598729593859566, 0.03307995619252324, 0.0400274696819965, 0.1043885501642381, 0.00542519862891265, 0.04971550567255867, 0.08484438317076815, 0.06796765005997113, 0.016223834677328988, 0.04136310950402291, 0.04309831780471629, 0.030659846135325013, 0.03920002960630002, 0.03833001036377203, 0.04775372303781971, 0.020956928886833693, 0.05715162237925876, 0.07717761271182569, 0.02710924502612362, 0.04072418068385413, 0.03871644043453759, 0.025177332159552365, 0.03373534824218481, 0.0547245447523892, 0.012078678475752955, 0.07560924686972173, 0.05938746913846943, 0.03490869616789203, 0.12515920860272262, 0.040294309597342245, 0.23344841034662342, 0.4077602874848151, 24.666642642790272, 104.30353426164197, 90.6316109626524, 99.05165318519839, 70.70271492004395, 48.04709696000623, 39.151667394945704, 27.301377134938395, 41.71699162452452, 56.148336779686716, 34.93927717208862, 1.608994610367283, 0.11820631717602093, 0.08833732275712876, 0.4877515726031796, 1.0574343488101037, 2.9270238789819905, 5.081134909583676, 3.126115789336543, 0.26309763712267725, 0.9053201757131085, 46.917768139992994, 99.63277586044805, 83.11110942594468, 82.6081282092679, 84.81191973532401, 82.39654771743282, 84.72265443494244, 84.26581598097279, 81.48947608086371, 80.29150578283495, 72.11527809020012, 59.14918138134865, 58.91571406395205, 58.798419506319114, 59.79382684153896, 68.36593935566565, 72.65461967837426, 75.89900032166513, 76.95221947085473, 68.26617779270296, 74.6802257722424, 73.05212836111747, 69.11086020931121, 59.19260986389653, 53.14844139160649, 53.79393016138385, 52.6939602821104, 52.41941398189914, 52.82750914173742, 53.505490826022246, 53.07832902477634, 50.82018129287228, 55.087778875904704, 51.19368899253107, 53.967510730989524, 51.479041422567065, 55.13343918708063, 55.19564797801357, 54.56859827041627, 51.618850384989095, 53.781955165247766, 53.69834984502485, 60.67371253044375, 61.38038243016889, 75.95361540394445, 57.535439845054384, 50.66307860036051, 77.63283698789536, 63.46482407662177, 63.79897079160137, 64.63035637332548, 73.08830045884656, 71.82030016376127, 71.43856725385113, 65.78371363301432, 59.33136370874221, 54.371467790296, 53.08746814727784, 54.116482350134085, 69.13273134539205, 72.78157111137145, 73.16998774005522, 67.88567650702693, 66.35263381465789, 59.40798328768823, 58.36870424209103, 53.69101501280262, 60.509329918892156, 67.06328884247812, 75.94777891712805, 68.33453686006608, 73.45896444013043, 74.273311245826, 70.37373004421111, 60.22951195316931, 57.508057778881444, 60.555272640720496, 70.35429862237746, 71.7345493070541, 76.3663350382159, 75.25978734416347, 76.95487099309122, 84.34292977856052, 78.83594559084985, 73.44031749233123, 83.01310508481919, 41.58033232535086, 0.5204203808980604, 0.9474070238009576, 0.9687749933331244, 1.7502113359589733, 1.2783074258796632, 0.7898501330806363, 0.3634039498865605, 0.3011594592563568, 0.1679086691189197, 0.2340485023394708, 5.794424789567148, 43.46913791471913, 33.150609693219586, 44.19388994093865, 32.92603046663346, 27.996860434932096, 47.93336783685992, 61.08466709813764, 69.08862037043419, 77.61216609708725, 88.78655156781598, 54.062498769452496, 0.4797177924023521, 0.08548870908036348, 0.04876682835240518, 0.006116857759714608, 0.01977815131296314, 0.029933870574759863, 0.08247331806248234, 0.06951068903529836, 0.03602384439399166, 0.057869496560024644, 0.07081897568798835, 0.04022505141854767, 0.03870704436614629, 0.046332089846292814, 0.04471559453034594, 0.03799468984887485, 0.02283719402076977, 0.05525436349994233, 0.036354752242444985, 0.04922733146456942, 0.08273626242073313, 0.07742673684392246, 0.05277507315059343, 0.014036461173917257, 0.02505738385802796, 0.1394761585059666, 0.08001672689832988, 0.2043697198912982, 0.13822230240029676, 0.22770351700244412, 0.2332903204425689, 0.1969469867406353, 0.09192417706212691, 0.12239245142066672, 0.10181201261378105, 0.11307422522335284, 0.2201503803653102, 0.21114414347515953, 0.1558651694006497, 0.09878814866345736, 0.13128902282445662, 0.25647119108226996, 0.20320661456113864, 0.2517968443252387, 0.3338856015714907, 0.5533537653184707, 32.05794522839208, 118.51820376611526, 103.80340853045064, 110.22159068815171, 79.97308777224633, 58.05631883682744, 52.79805214174333, 36.41227229948967, 71.77593031237203, 71.78325729985391, 46.43956845806491, 2.402063661044644, 0.21365435313313239, 0.2810526849521745, 0.5199317393764373, 2.7133473705860878, 3.8461872021998134, 7.403354067956248, 5.600429754103384, 5.369056982378806, 2.469180807951958, 48.9147723105646, 101.57719673648958, 86.81096353838521, 84.8200390415807, 90.4164218902588, 84.70007727223059, 89.04476119625954, 85.93862056732179, 84.83820746021887, 86.9724710526005, 76.37219505925333, 62.10194164706815, 61.881508365754165, 61.40707808156168, 62.92174839204358, 71.69682395073676, 74.94265587099137, 78.86632042546427, 77.8192593974452, 70.34501829454976, 76.1051679426624, 76.00156245693084, 70.6089702729256, 61.864767689858716, 55.69381644648891, 56.91066511215703, 55.8165866328824, 54.266807186988096, 55.979400296365064, 56.724101497280984, 55.846702591065444, 53.35920995281589, 57.35223377904585, 53.37771569528888, 58.30094529736427, 54.36337986300069, 58.389457502672755, 58.40795932277557, 58.12975737356371, 55.035168124783425, 57.411567472642474, 55.83777527655325, 64.99476809655467, 64.63200376879784, 78.93062376206922, 61.33020354855446, 55.33662972911712, 80.22573547978556, 68.3826800315611, 67.58374814064273, 68.07783342176869, 76.28605981026926, 76.2256553096156, 73.94177682938115, 68.5552486296623, 61.86731330810055, 56.029512497686575, 56.71077720580563, 57.05942100094211, 71.81925681329542, 76.61778250048238, 77.35992631604596, 70.989502937563, 69.9340166584138, 61.655446483242905, 62.17805131789177, 56.74706305226972, 64.94380866327595, 69.88304938039472, 79.4291413214899, 70.9607284299789, 75.98968552004906, 77.40088370538528, 75.31098996439289, 63.88185047334241, 61.353796605140936, 64.00129448982977, 73.29758244176065, 73.37594355306318, 81.18157786707725, 78.57022854589647, 80.7841319422568, 86.06406581017279, 84.88332256194084, 76.80895097794073, 88.36327291304066, 42.5887462400621, 0.3853526753523658, 6.558969751481087, 6.030106284926015, 3.82502013156491, 1.0975912069120715, 0.6381476862776665, 1.3330004652661662, 0.710417601850725, 0.1475785188977757, 0.3893149740272953, 9.41011513433149, 58.40619033382785, 51.17293965431952, 75.31721084348618, 54.3950020113299, 29.347328562890333, 50.5820502773408, 67.42751229193904, 82.22113147858651, 86.05467565598028, 98.70322119805121, 60.63788560128982, 0.6794988448100706, 0.18489555035146976, 0.1871167303573701, 0.17507136138456483, 0.08924337494517527, 0.13776928396715274, 0.21529928180238894, 0.17073936399913606, 0.1196816186570833, 0.16338165639148605, 0.17409619274398974, 0.15111484204328832, 0.1356118731200695, 0.2686666979664757, 0.16752341882355753, 0.13287647957763365, 0.13698661790019082, 0.215304552487308, 0.09158213412569416, 0.19159921805464453, 0.22770134131273917, 0.16157709032056794, 0.1269811265651257, 0.15607207442723936, 0.07233255858262701], [0.08430747810991542, 0.028387675317184582, 0.00647794276911525, 0.0241890519241532, 0.022679925746014042, 0.05791848405234276, 0.03809105221843047, 0.04067268808402362, 0.044139871794369914, 0.034271391454122724, 0.02324725790399938, 0.02378662976796829, 0.08219744980094895, 0.014055658379689822, 0.031112152106699445, 0.055780773156232415, 0.049082724707982237, 0.06725095182416901, 0.06177425820140108, 0.016219782072209542, 0.40564983782749026, 60.574527555896395, 96.02497977595176, 92.69655058460852, 69.66331820334159, 55.47749380911551, 75.16132016335764, 38.95357593413323, 50.430121191086315, 56.843867148122484, 42.22921786769744, 11.264344050038247, 0.1370293349628487, 0.04340469168739454, 0.2280390481915205, 0.6708665660792782, 0.7206202382522245, 1.0679695899448087, 0.7121725560676667, 0.9174790942380506, 1.4249261132171078, 35.10048266380064, 98.54147049688525, 76.60077510341522, 85.29466152191164, 78.07790833134806, 77.50546193891957, 77.33755311658307, 77.94447714282622, 77.6367985817694, 79.92541528517201, 73.20810533338978, 60.87763263333229, 54.94015655209942, 54.669352193032545, 53.96271367226878, 54.382054267391084, 63.975889298223684, 72.45999167042395, 73.3325150705153, 71.14876685603973, 66.98002476846018, 70.8688037626205, 67.76702480931436, 67.44837930125576, 57.48861458993728, 53.05808959468719, 49.76715041745094, 50.48554428162114, 51.96294030835552, 50.813070035749874, 51.62152936381679, 52.0954458175167, 51.95853548665201, 50.246817065823464, 50.69170405787807, 51.77523920612951, 59.176465388267275, 64.95062574263542, 65.78104249892696, 63.303677420462336, 59.92813271860923, 59.760459238483065, 56.149407586743756, 62.06001543229627, 61.23542339571061, 71.89873972246724, 60.765001773834236, 49.9638690487031, 72.39135803714876, 58.64831432219475, 58.89250147727228, 62.438335880156494, 68.38549629334481, 67.7666090380761, 70.78210369233163, 62.24692813811764, 55.45171206997287, 51.0478356576735, 52.19130462215793, 49.586725311894575, 51.84263337043024, 59.75592890093404, 61.22019675470168, 57.74077592357513, 55.57811437114593, 51.41809563482962, 52.58296897334438, 50.89634195450814, 54.399712777906856, 62.98294521147206, 70.09898370312106, 66.56142157893028, 69.87171373059674, 69.93553069330031, 69.2918619032829, 63.07102987843176, 54.166559250124045, 53.88341903686524, 60.11774401510916, 68.4842929532451, 70.32464550387475, 74.35759513608872, 73.7159267548592, 73.7914872938587, 75.43867880298247, 78.99119300227012, 70.08173311910322, 75.06660276843657, 36.476701151940134, 0.1129496516659856, 1.1435876161821428, 2.2840407683003336, 1.0118673164998333, 0.28624427895392146, 0.22933525363764456, 0.40695221794228403, 0.1342938801333789, 0.1261602710151384, 0.014809347170915817, 16.37165930963332, 40.3202473732733, 64.08253854320895, 51.28399764337848, 27.25068638401647, 15.373433751444663, 41.62926781562067, 61.24586082273915, 63.00947220094743, 69.50017898313462, 77.31387769022297, 10.649074200660953, 0.2562166507085485, 0.09534129692662148, 0.10355220431642187, 0.033711097728941715, 0.019888395195706718, 0.03969007306882451, 0.044133130220636245, 0.035774053765400764, 0.0350945720809602, 0.014330780663106953, 0.01632202991224345, 0.05831242178476626, 0.11579794358582267, 0.010998156466220897, 0.03260236931964755, 0.014591127025684523, 0.04135243789923768, 0.01218681657431467, 0.06660612795742289, 0.05336475783898946, 0.037987231982931975, 0.029634757290383982, 0.07520199452917423, 0.0449827945070161, 0.0595058718576066, 0.025598730313621705, 0.012436122652293454, 0.050773381165439085, 0.015170064458112805, 0.05477174725984374, 0.023999571567401293, 0.03432535085706942, 0.027461321799144633, 0.06877166699738273, 0.048729163639607935, 0.02883783815759084, 0.014021806869535677, 0.048530811984692855, 0.03092085995200661, 0.06604930461053887, 0.07401261238321181, 0.08157016934766885, 0.03409405359097066, 0.03436237971688952, 0.8708543702960015, 74.03616474520776, 108.82075540481075, 101.05682373046876, 77.63689271865353, 60.275317392041615, 70.87251432480352, 34.82496753815682, 41.29369335789835, 49.006116467137495, 47.685501498560754, 15.160579469896133, 0.1257927633161026, 0.034823009233561256, 0.6376455003215421, 1.6543414996516321, 1.6489888126811676, 3.4654895528670284, 1.643648628265627, 0.9132111877683671, 0.6868706944008028, 36.97831738379694, 102.01205422801357, 80.95773604608353, 86.70752279220089, 80.88383074729674, 80.94510601412865, 80.59465008397257, 83.26652942165252, 81.19237222979146, 85.09794681302964, 75.39093571324503, 65.83040944991573, 58.867162965959125, 57.96301349516838, 56.13478106837119, 57.26488651767854, 65.65163173983174, 74.99723172956898, 76.91898915075487, 73.09587063327913, 67.71462978855257, 72.94177639868953, 71.10939410425001, 67.13885722621795, 59.02358316606092, 52.84836046157345, 51.335059058281686, 52.67882777798561, 54.722547377309496, 55.00157302425754, 53.31849182805708, 55.284458283455145, 54.14568831843715, 53.33824488424486, 51.05342503516905, 53.819303974028564, 59.63342543571227, 68.89417279151179, 68.95765243038055, 66.29932095927578, 61.83614615471133, 62.34212013982958, 58.27216294503982, 66.59479310435634, 64.79002429592994, 75.61622881120252, 63.13016745351977, 54.2711139494373, 73.7446306597802, 61.95925366493964, 63.01685017924156, 65.72902010333154, 71.89352297013806, 69.90224546001804, 74.16663846661969, 64.9921989440918, 57.529069915894546, 52.0956301689148, 54.43190759228122, 51.20474223167666, 55.20847805084721, 61.08685185832363, 62.41293853329074, 59.79750602476059, 57.250593400770626, 55.673769212538204, 54.90700075703283, 52.29206638951456, 56.23310704385081, 65.28509016959899, 75.50697511242282, 69.29032433417537, 71.06729138282039, 73.83916762567335, 70.72473510619133, 64.78101461164414, 58.469293425160075, 57.57380847007998, 62.4748178451292, 72.50375747680664, 74.50240119811028, 77.40585727076378, 76.11779797461726, 77.62047367711222, 78.18526360296434, 81.47373953173238, 70.86197099378033, 81.48400045210316, 42.920319880208666, 0.3834792226552964, 0.593446210747765, 0.9396045715097459, 1.6820247303093634, 1.4847709406768124, 0.6193061521457088, 0.8809535541842062, 0.7618572190403939, 0.043525411822502656, 0.01030963494427382, 17.937700902262044, 42.822197867978005, 54.30960809030841, 46.67931941247756, 31.325364151308616, 26.813132262999012, 57.1050028647146, 72.81673908233643, 71.5889823052191, 75.97393328143706, 89.6977024693643, 18.14470987166128, 0.36972337853043313, 0.12573879242183703, 0.059032667007657795, 0.06874982583066148, 0.09903458382693991, 0.04211220559814284, 0.0670776857183345, 0.10486161711836055, 0.07185179244486556, 0.030056712773418235, 0.02528684251310845, 0.05300142531914096, 0.026925950829360275, 0.02035716439657394, 0.02142074149883082, 0.020855688452420217, 0.04447061876435915, 0.04130684800686375, 0.027365216069043647, 0.015332505741577237, 0.059945636969660564, 0.009254058672776146, 0.05206134733593753, 0.02775817129370426, 0.24973642020936937, 0.13725746062494096, 0.13318089227522575, 0.17731894078033586, 0.15762476611041254, 0.1762072399498955, 0.20632900507940402, 0.16962818410848418, 0.16456924589170566, 0.13948634747535954, 0.07999058797835343, 0.11612090327206159, 0.18559049935110156, 0.16739223392740374, 0.09978541127976873, 0.13876789489821081, 0.245622773204119, 0.24050457042551812, 0.15058582768805567, 0.1969049131918338, 1.370250847070448, 88.79017583785519, 123.3534271486344, 116.15919620760026, 90.95109585792788, 72.70536730366369, 89.97528076171876, 54.050480627244525, 70.83575387154856, 80.46535307361235, 62.65152846613238, 18.454012293969434, 0.37559875196987585, 0.24979032215572175, 0.7951145054351899, 4.2035957786344715, 2.4415638898649523, 5.726636917360368, 3.960794445968444, 5.482143817409392, 4.140317651533311, 37.71176922705866, 106.58683223109092, 85.21876365907731, 91.042832251518, 86.04357534839262, 84.38399699426468, 82.75065145184918, 86.3157093909479, 86.55117711713238, 87.45504809964089, 78.8349179298647, 66.26838914809689, 62.21212494757868, 61.12755429360175, 60.03637836825464, 61.293090081984005, 70.21397975183302, 79.09345703740274, 80.01300181111982, 77.03159255366172, 70.5993918449648, 74.43805079306327, 75.74565133740826, 73.33514305853075, 63.921082019805915, 57.56335143120059, 55.0502614052065, 57.22892622793875, 58.58991415269914, 56.51143843127836, 57.219398790790194, 57.93762007067281, 58.135421276092536, 56.1970643843374, 54.22901515037783, 57.16902379066714, 64.49954925044891, 72.39604919187485, 72.40017552529612, 69.21037858532321, 65.4638796467935, 65.32668690527639, 63.304638401154556, 69.7908030786822, 68.85716915130615, 77.87041494923254, 67.13316194472775, 58.10870993521906, 77.84835553938343, 65.58339818831413, 64.89497907700078, 69.92390478810957, 75.26089345255207, 74.54107576800932, 76.52914477932838, 67.09174956044843, 62.44227786217967, 55.01673690734371, 57.906013611824285, 54.07845889368365, 59.11682182742704, 64.7852978398723, 66.45569016856533, 63.03358693276683, 60.79000688368275, 58.410171539552756, 58.39270522517543, 55.37147998809815, 59.03786059348815, 69.85204696655273, 77.60890268510389, 70.37959006524855, 71.7372400529923, 75.51323521521785, 74.64669735200944, 66.71065991924655, 60.03298551805558, 60.61777560941635, 65.90927262460032, 75.20689810475996, 76.87594506048387, 80.7522273832752, 78.687468190347, 79.41059635531518, 81.6385026131907, 84.85497167033535, 74.59761281167307, 87.44400270523565, 47.521193412042436, 0.48433718001169546, 8.243237464658677, 6.486494156622118, 4.7664838452493, 2.3221174218962273, 0.8912137391105776, 1.862311940039358, 1.1360882895608102, 0.29226413657588346, 0.15171687989946336, 27.734285208486742, 59.4867915491904, 82.20846222292992, 66.6376724550801, 37.585892523488695, 24.298808651585734, 59.4725808020561, 78.24825686793174, 83.57820095554476, 83.10055825018114, 100.84958138004427, 22.014924287796024, 0.5731928685019093, 0.21534589059170217, 0.4048925445925805, 0.12948995726483484, 0.20636257505224598, 0.12872702562280242, 0.14179516793979755, 0.15060969898777624, 0.16121102286682976, 0.17812428304985647, 0.12043667491525413, 0.11773508117203751, 0.19456486698360215, 0.11320785393998509, 0.12740254387139313, 0.10468065182888701, 0.1728101915890171, 0.19885223208656236, 0.18949716472096984, 0.2132603081483995, 0.23885064788403051, 0.10018998231258124, 0.19165969303538724, 0.13445578515529633], [0.02169412380504993, 0.036485737955738465, 0.020925630364687215, 0.11076218718963285, 0.022113646958924593, 0.019395164807417223, 0.05859376374451865, 0.05758005322047299, 0.07627751302695082, 0.020748139283950293, 0.07000520645130066, 0.02819573581819573, 0.0677495678105662, 0.014409107407705199, 0.09841192288384323, 0.07480496946241587, 0.0053566653608164245, 0.06321603567489693, 0.1025429294414578, 0.2771494669779655, 10.238896262261177, 82.17955435475996, 77.34955556931035, 79.97820254295104, 65.72414067483717, 66.91068510855398, 54.076580078371116, 50.219497757573286, 64.98855506220173, 39.25617502581689, 37.77550381998862, 1.545880609943021, 0.16257202402958948, 0.09794167513328214, 0.34247942268848425, 0.7876350970998888, 0.5971547504586558, 1.4592853404821888, 2.8989004848464845, 2.679964078049506, 12.95939337822699, 92.25017701425861, 75.85550123645415, 92.03423484679192, 73.43357101563485, 73.70013529254545, 74.69873151471539, 81.8451879870507, 75.49988346715128, 79.12490660144438, 68.44882688214703, 66.64143008570518, 57.52497888380482, 54.37795931293119, 52.632398682255904, 55.07937323662543, 53.013186300954516, 60.99986545501217, 68.27140238977248, 72.55761946401289, 70.58200005562075, 65.2240070989055, 67.84057709478563, 69.67882725500291, 66.15416972867905, 55.91301418119862, 50.26418139857631, 49.596837182198804, 49.56940412521363, 54.632783935916045, 54.433449083758944, 53.91559816175892, 48.92290338393181, 48.60332042940202, 49.587262676608184, 52.01415077332528, 60.429643046471384, 69.58188195382395, 73.91933302725516, 69.1095736718947, 68.5317300981091, 65.22432481088947, 64.52510349212154, 63.459528876889145, 67.3127672749181, 63.75470292183661, 71.68857912863456, 58.499425072823804, 53.76497522477181, 67.87051262394075, 55.39825800926455, 60.40452811025805, 62.15439158101236, 66.88490729178152, 68.61436659289946, 69.0091609954834, 58.827405821892526, 52.58378482634022, 47.415312951610936, 50.278211716682684, 50.32387595022879, 48.5747734192879, 48.43642357856997, 50.76412277836954, 48.608886272676536, 51.89914687987297, 49.24320413220314, 50.9109410162895, 50.896416479541415, 51.42925870034003, 57.91392111009168, 68.18430223772603, 67.55975107992849, 67.81909819572203, 68.95825647538709, 70.75419995092577, 63.36548220726752, 58.815748537740404, 52.596363867482836, 56.086292728301025, 63.416920169707275, 72.93502992199313, 72.605833238171, 69.42002927103351, 70.98601987285, 69.598340219067, 65.84438877720987, 80.06363961004442, 70.69374838183003, 76.10754489898682, 18.007644607174782, 0.10428183411638584, 0.27259265343027733, 2.947373380584102, 0.4929897141072058, 0.6097728314418948, 0.25064686974210126, 0.6738207849764055, 0.17434002320852973, 0.13321633150260295, 0.8006661914048657, 24.75025776893862, 38.06765763990341, 48.04297847132529, 48.099593962392504, 53.79134531944029, 26.6078628647712, 30.197984749271026, 47.16815263994279, 60.85221175224551, 74.86487527047434, 47.02689632292717, 0.88863245181499, 0.11201133951544763, 0.05771186630872469, 0.060933718022199414, 0.07038687911605643, 0.033711971069175395, 0.018472756642187317, 0.022022135841149478, 0.11257094376149679, 0.04224232180164226, 0.031625697231521054, 0.011530376899416649, 0.18823961607150494, 0.028811128502110803, 0.05162504111086169, 0.04608049891107986, 0.03460058709606528, 0.05483534404887788, 0.03476500871681398, 0.016469088150188327, 0.098812242128676, 0.03613569706137623, 0.059455620320213426, 0.050659280029996756, 0.032305230626896504, 0.020817133162410992, 0.04045334945042287, 0.05469729500492254, 0.12740403008196624, 0.02151055573185365, 0.03201791701177436, 0.0319913107781641, 0.027475942587179523, 0.02750834810637659, 0.06465317065557165, 0.053880779343026305, 0.04979759199364532, 0.03241219565332417, 0.036750739260065945, 0.06738059688359499, 0.04269423323773569, 0.07943460732818612, 0.2415687584828946, 0.32678923719832975, 14.463682155455313, 96.95116904474075, 87.58702016645863, 90.30839197097286, 79.07312347042945, 74.66017461592152, 68.2367992401123, 44.52016838135258, 44.10522476319344, 48.01208196147796, 43.6353365836605, 1.9778326057618665, 0.1529934428512089, 0.09219771641637049, 0.9590459218428982, 1.0876600107839032, 1.9743034531993253, 1.5784199800222152, 0.2523626002573198, 1.3839672529889693, 14.53945940540683, 98.59225734587639, 79.04807521450904, 94.25049166525565, 77.34266788728776, 76.9427900929605, 77.04876469027612, 82.2820301978819, 77.60856536126907, 79.33243920726161, 72.28799573836788, 70.51175825057491, 61.03334680680306, 57.49974235411614, 56.28414100216281, 57.497585050521366, 56.14714045678416, 64.77310319100657, 72.06922161963679, 74.80024245477493, 72.46507506216727, 69.46520713067824, 70.0757005137782, 74.7139189320226, 70.0885658879434, 58.996507044761415, 52.66777453884002, 51.49885331430743, 53.27149791102256, 58.79192013894358, 56.909508012956195, 55.609960094574966, 52.625463931791245, 52.15232410738545, 51.01113403997114, 53.42342307490688, 63.53835675024218, 72.06140041351318, 75.80902899465254, 70.21117917952999, 71.04111348429035, 68.40179766378095, 67.72478872729887, 69.07620214646863, 69.90452827945833, 67.5180955086985, 73.43901526543402, 61.455597800593225, 56.45763920199487, 70.78588485717773, 58.66534133111277, 62.886196028801706, 66.57471841381442, 69.40384557170253, 67.47423556543166, 69.47488754026352, 61.52996593906034, 54.314514975393976, 49.99359276986892, 50.77822762150919, 51.847159785609094, 52.437551021575935, 50.319212252093905, 52.88986306036673, 51.75760030746461, 54.21113698713241, 51.659890144102036, 52.99911283677625, 52.55697542621244, 54.55896492927305, 63.12847298960533, 71.28899943444037, 68.97251036859328, 69.65585785527384, 71.39271474653675, 73.22154337360014, 67.9335686468309, 60.79456860019315, 55.485464065305656, 60.39884067350819, 65.76339183315154, 74.62412803403794, 73.04982985219648, 71.95345678637105, 72.4531981252855, 72.00688731285834, 68.43949948587726, 81.80832555217128, 72.60906527119299, 83.47629777846798, 25.16246553390257, 0.14550560754874062, 1.048058290635386, 0.9938386935860881, 1.7979686442882785, 1.8563838903942418, 1.027500658266006, 1.0514871776103973, 0.6737541046834762, 0.23018469192808677, 0.7527882701927616, 27.235442092341763, 38.42544840228173, 43.32439068825015, 41.160826990681315, 46.161013495537546, 38.43235961852535, 42.07567276493196, 52.43561729308098, 69.48247340417677, 80.995328041815, 63.48209427249048, 1.7535091912554157, 0.13460428363853885, 0.03726686035553294, 0.031655971111068805, 0.0663622974928829, 0.0426417600453621, 0.022456825620705084, 0.028295300435274843, 0.044957613196945, 0.024403968315211036, 0.04825044678704393, 0.018536903099307132, 0.03833715413366595, 0.08081430869717753, 0.0039081443983670925, 0.03684421730858665, 0.02176424766319894, 0.05765492299331292, 0.022212066274556904, 0.015995448545342492, 0.10162555447389042, 0.020441939686274817, 0.07066349814375562, 0.07404979063017715, 0.0898892023871022, 0.1209352525972551, 0.12300571246493248, 0.2223078984647028, 0.19866645576492434, 0.1287294617824016, 0.14434682295447396, 0.10448196692572487, 0.15374577183636928, 0.16778667727785726, 0.1635731477290392, 0.1325773528867191, 0.15770794793723092, 0.1631876216420243, 0.2804021230868755, 0.19716349850979545, 0.08316894888036674, 0.16370583415752457, 0.4219059171455522, 0.5327135793143704, 18.499141123987016, 117.17215614934122, 97.66755073301255, 103.99741680391374, 89.51074661747103, 88.21699988457465, 68.32477800307736, 73.18233536135766, 88.32135062063895, 55.26629770955732, 59.30641743444628, 2.9460647798353627, 0.4116059262906352, 0.23912426384706653, 2.1849786129689988, 1.5772790605983429, 3.153783453087653, 3.706737626944819, 7.649892193655814, 6.81722350658909, 14.962756691440461, 101.99838869033321, 82.55928685588222, 98.99475528347878, 81.72051937349381, 80.7324900165681, 80.99189989028439, 86.9594644731091, 79.00069298282747, 83.82718516934304, 74.07370182775682, 74.48715102288031, 62.42825931118381, 59.744840360456905, 58.079284314186346, 61.31638111606721, 59.87703600237447, 67.71521814407842, 75.13664061023344, 78.64892698103382, 74.93050436819755, 69.70278509201543, 72.19171724011822, 77.08356395844491, 73.88676166534424, 61.48248172575428, 54.98979806900025, 55.924753835124356, 54.64519039277108, 60.83687136250158, 59.20875433952578, 59.820008662439164, 54.16260942336052, 54.82150093201668, 54.12713942989227, 56.539965829541615, 66.09977429912936, 75.59641299709197, 78.2551053262526, 74.06210730152746, 73.8910762725338, 71.48066997528076, 69.88589702113983, 70.51298987480902, 74.59331389396422, 71.45610809326172, 75.93789454429381, 66.37106110972744, 62.02352170021304, 75.00125608136578, 63.43676736277919, 66.12155129832607, 70.37545588708693, 73.98165948929326, 71.0131783639231, 75.09685208720546, 64.80797698420864, 56.729926216986875, 52.665699605018865, 54.37390750454318, 56.06906567850421, 53.6866964832429, 53.29589113112419, 54.246787409628595, 53.76654417284074, 55.436065735355506, 54.372193428777884, 55.33465677692045, 56.80463167928881, 56.68623493563745, 66.38079643249512, 74.52156589877221, 71.95541012671687, 72.43652020731281, 74.54531192779541, 77.78012983260616, 68.25568937486219, 63.84052830357706, 58.97381613331457, 62.38721170733052, 68.35165408349806, 78.5901306521508, 77.5979357381021, 74.41513630651659, 76.79046876968877, 76.39505463261759, 72.07836858687863, 86.29183784607919, 76.34629172663536, 87.21046478517594, 26.32597584878245, 1.3126729044222063, 6.952256493030056, 9.509643316268921, 5.147510238232152, 2.2849029542938357, 1.2387245821376, 2.9617101338601883, 0.9351298213005067, 0.4908083859951266, 1.509601382478591, 40.537734954587876, 52.66709989117038, 64.51950626988565, 61.93674710489089, 66.7570694031254, 36.05922368264968, 44.34383823025612, 63.97882715348275, 78.57060509343302, 92.19074526140767, 69.67718770427089, 2.0890379288504204, 0.2850091613588795, 0.11494333420189158, 0.14504287512071673, 0.28187485051251226, 0.19980634863097824, 0.11308958528623467, 0.11931161351141431, 0.23183812417330282, 0.14441633777272317, 0.15749465373735275, 0.12117679245890149, 0.2832779865111074, 0.15595593549791845, 0.1459168129029774, 0.11110656669423466, 0.08852422522801547, 0.23706852818929383, 0.10720042992503413, 0.21460250951349738, 0.19955588384501396, 0.15497609372100524, 0.16051854067031415, 0.2819251058803451], [0.021106388810421192, 0.019021677792132385, 0.038239929915195515, 0.030830543931393378, 0.014231975430682784, 0.021422716090455655, 0.016629411200542125, 0.008451986641082312, 0.03525291862446935, 0.01345970613446327, 0.050953806362926006, 0.027305472702268633, 0.08133478883293369, 0.02482354892568002, 0.06175532816879212, 0.03219351202489869, 0.06422878475859761, 0.007101373151770883, 0.1422731608392731, 0.13685777723308534, 26.063439846038822, 88.72924573959844, 77.44088403640255, 69.12975818880143, 41.20479676031297, 60.39882106165732, 19.76876331913856, 30.59621318694084, 52.68005155747937, 51.668946896829915, 14.017991077515388, 0.15023206360638142, 0.09929873094323183, 0.16407652878232543, 0.35863584928935577, 0.7055851192243638, 0.8897213998340792, 1.1639352791732358, 2.1135171959477086, 1.901215355723135, 73.98772347357966, 78.08387033400997, 85.22070130994244, 75.4726779076361, 79.43566814545663, 65.48642150817379, 68.37505494394611, 75.42678617662, 74.75519795571604, 71.36837251724737, 65.05909888975083, 56.28745148258825, 57.68656092305338, 55.46119636104953, 54.362097247954345, 53.23967179944439, 54.28792522799585, 56.89306543719385, 69.5197751445155, 68.56150873245733, 69.95871974575904, 64.80800051842967, 65.99165808769965, 67.71684200532975, 65.17542069958103, 53.87136951569588, 49.87264256323538, 49.72199609202724, 54.76283011897918, 61.412204619376894, 59.79532126457461, 57.25147201168922, 53.67889488897016, 49.099072717851215, 47.60804645476803, 57.52983085570797, 66.12629736623457, 71.84759201542025, 69.90913314204063, 66.08784244906518, 68.2669230430357, 69.32220535893595, 72.54647208798316, 65.65149053450554, 66.44940653154927, 59.95992745122602, 68.68011336172782, 57.96076989942982, 53.85083590784381, 67.73705005645752, 58.03596565800329, 64.27915911520681, 64.39525342756703, 69.16364746709024, 64.51430912940734, 62.03348452045072, 58.24283146089124, 50.96908230935374, 48.683693716602946, 47.7084905101407, 48.56397121183334, 49.88259361636255, 50.26338123506116, 48.259081455969046, 50.0827286320348, 49.39877710034771, 49.44101318236321, 51.450533636154674, 49.50492428195093, 48.395058262732725, 56.53183083380423, 64.19381226262739, 68.25562661693942, 67.39148924427649, 67.56818417579898, 68.91884449989566, 66.51409426043111, 61.11135882716025, 54.35045957565308, 53.18368388760475, 57.14723502435992, 63.223719904499674, 68.30602907365369, 64.78447806450629, 61.800946804784964, 58.62700800741873, 65.46551919752552, 69.25470921301073, 73.15009347854122, 75.55715791640743, 69.99596657291536, 7.797306141545696, 1.0317482174404207, 1.8581004176409015, 1.7674148515347512, 0.6054855582694854, 0.18970760907376968, 1.2032771422978372, 0.2769667090427491, 0.0704894965935138, 0.29289297218764987, 4.067011494790354, 35.19980492130403, 37.65807590176983, 108.27071359080654, 171.5010230771957, 55.08381335966049, 25.925556767371397, 60.58887558598673, 64.39493571558307, 66.18007306129702, 78.26664493929955, 20.15981774176321, 0.3610761764068758, 0.17204871551404077, 0.10469352976689417, 0.04442742672718821, 0.006943797484235539, 0.07974028407085328, 0.029770322294244846, 0.08282335895684459, 0.05329323970081826, 0.07965727844425748, 0.04830742074597267, 0.03433596883569995, 0.03811492734859067, 0.01946202321578899, 0.03691428371014134, 0.0741114913515987, 0.018716364941229264, 0.004293864880192785, 0.010709665948525073, 0.017723472856525934, 0.029512470505470713, 0.10870145663859383, 0.015993718144243524, 0.06033264926724857, 0.017104301443924348, 0.08696665356476461, 0.013909652555030922, 0.054973829762950066, 0.03938076506939627, 0.051101393201538635, 0.04732929117557022, 0.039862075129583965, 0.04487844567084986, 0.07075975709144147, 0.07616373364843669, 0.05037784997013308, 0.04542915563609812, 0.031180130918660474, 0.07816283242596735, 0.02983785485998998, 0.005667814844092655, 0.04983760859637011, 0.08159359631639335, 35.89617467695667, 104.79932185142272, 83.2285608783845, 82.6102384444206, 47.78346269361435, 70.30598286659487, 31.33597416262473, 38.452626505205714, 56.59127043139551, 52.41295383822534, 16.93402717190404, 0.22520472205454306, 0.03999164358021752, 0.624890381530408, 0.7356706177515369, 1.413064007797549, 2.0797151903952322, 1.5364753791401464, 0.4144248540603346, 2.4404651359204323, 79.63639151665473, 81.45546913146973, 88.71022224426271, 78.2591296780494, 81.87971268930744, 69.10426278268137, 72.01936829474666, 76.73621454546529, 78.58805964069983, 74.12819139419064, 69.66871538469869, 59.48022550152194, 59.865037472017356, 58.44138576138405, 57.937031715146965, 55.61113680562666, 56.55722818066997, 60.55330753326417, 73.10706507775092, 69.7942312302128, 72.50593831462245, 65.4148696314904, 67.82466011662638, 70.68881404015326, 68.26342428884199, 55.207885772951194, 52.3740949169282, 53.10768404314595, 57.768291350333925, 64.44668746763661, 64.17391015637305, 60.09610037649832, 55.95492078411964, 52.29541217127154, 50.56293656749111, 59.758039136086744, 67.42012254653439, 73.96077679049584, 72.97039401146674, 66.60188474962789, 70.72429580073204, 70.2700618005568, 74.79774782734533, 68.80459370151644, 69.33913430859967, 62.194874363560835, 69.53039692294213, 61.00539207458497, 57.09540482490294, 70.48016748120709, 60.970988965803585, 67.4434841832807, 65.9687122221916, 71.11492464619299, 67.46963070284936, 64.9584783277204, 61.099944729958814, 52.7035387100712, 51.238149058434274, 51.68542477392381, 50.19282564040154, 50.829402785147394, 53.317711276392785, 51.21296744192801, 52.818522991672644, 49.87589420810823, 51.101831005465606, 52.571194018087084, 52.56161559012629, 51.0028931402391, 59.17482975990542, 66.75635553175404, 71.21885961101901, 68.5252974110265, 70.38208469267815, 73.68494787523824, 69.14868754725303, 64.73919037849673, 58.47621640851421, 55.32925567319317, 59.898040294647224, 67.2387521497665, 69.53689236794749, 67.66842426792269, 64.447424873229, 60.37930334767988, 68.13598648194345, 71.98416110007994, 76.0069517935476, 77.50944706701463, 76.81685847620811, 11.474957677625842, 0.38449392143276434, 0.8693740432781558, 0.9185060197787901, 1.1815215935630183, 1.1973760589476556, 2.4630506336688995, 0.5556609157112338, 0.14960134341832132, 0.2039324828693944, 3.6962558281037117, 39.963029276940134, 33.04675709816718, 83.61688337018414, 140.1125224944084, 47.61039987687142, 33.76839476246988, 66.0308817894228, 72.68646932417347, 72.29858613783314, 89.47313108751851, 30.346999514487486, 0.22353533985874346, 0.10763457195172388, 0.03311318142579929, 0.03730289330105147, 0.02863663282515782, 0.02518628006650796, 0.07339339883577439, 0.06130255105334425, 0.04137952676824024, 0.03454984909284019, 0.041050097469480774, 0.01703736259632053, 0.04989709532369049, 0.053161242751464735, 0.053615594177596995, 0.04600954767797263, 0.040545505997274196, 0.023282049787080577, 0.028690866104537444, 0.041691320722982775, 0.08589816009325367, 0.06219016350505333, 0.01540962206725512, 0.09885481363462825, 0.17145588603471557, 0.16689567105664363, 0.18721469768112708, 0.13009470707226184, 0.1519725847268297, 0.13833955981798712, 0.12404795976415758, 0.21799237196964605, 0.18843210332335966, 0.23337414578324367, 0.2591135202636642, 0.10823189070628536, 0.14159053053346374, 0.21609345450997355, 0.1112184155311796, 0.14315572477156116, 0.13664708773214973, 0.21119704950721035, 0.17679404797813586, 43.96923618931925, 120.66743512307445, 97.88417539288922, 93.96638654893445, 58.37457995260916, 78.8254963967108, 29.603763318830925, 45.125778413588, 70.47755518267232, 76.95471409828433, 22.228536567380353, 0.4072134845679806, 0.21890377145140402, 0.7389302912258333, 1.1397910070034767, 2.4673662214509906, 3.928630275111045, 5.406425893306733, 4.898074951864058, 1.927470108193736, 83.485789914285, 83.23831189063289, 93.03771049745622, 81.16153455549671, 87.17783851008262, 71.51826197101225, 74.98297783636278, 80.76291976436492, 82.62005221459174, 77.34557828595563, 74.99046171865156, 61.25747496081937, 62.89879075942501, 62.40714911491641, 60.40707372849988, 58.192707492459206, 59.6844554716541, 61.915115233390566, 75.98896380393737, 74.1040688176309, 73.95170042591711, 66.19719812946936, 71.15767063633089, 74.1123136397331, 72.47068405151367, 59.747997868445616, 54.92627920642976, 55.555890221749586, 60.732504936956595, 66.29981517791748, 65.50152655570739, 62.65615294056555, 58.65009900062316, 54.147951526026574, 55.022259604546335, 63.7304901307629, 69.9125377593502, 76.02220981351792, 75.44334642348751, 69.68274962517523, 70.67372075973019, 73.7691846970589, 77.16200351715088, 69.03165186605146, 71.50777355317148, 64.88653813638996, 73.3667181384179, 64.26589365928405, 61.260710916211536, 74.27392313557287, 64.84164268739762, 68.74185931298041, 69.80555903527045, 73.08768856909968, 70.45364441410189, 68.30995144382601, 65.91135932553199, 55.4792941770246, 53.884074072684015, 53.128480449799575, 51.71056716672836, 53.96431399929909, 56.8615609599698, 53.06252971772225, 56.78438440445931, 52.9541624746015, 53.81082380971601, 57.24494126535232, 54.48343184686477, 53.79387524820144, 61.08482007057437, 69.93152203098421, 73.81987740916591, 71.21226218438917, 73.96583664801814, 75.62241831133443, 72.10264021350493, 67.84539376535724, 61.348979934569336, 59.17521022981214, 63.88391756242322, 70.61698759755781, 74.00265201445549, 69.37314125799364, 67.8065073874689, 62.44845951757124, 71.99983489128851, 75.77971319998466, 79.36383385812083, 81.55957668058335, 79.4474744796753, 12.66488221383864, 2.430079435148547, 7.207804793311704, 8.043001447954486, 4.249600277793023, 0.7369314146138007, 3.3465473546135813, 1.2035656816536382, 0.36850128443010394, 0.4645228674334865, 7.239061180622348, 55.19206293167607, 55.00782920468239, 114.82027161505916, 173.04929241057366, 61.47985373773883, 39.29754426402431, 81.64005587177893, 84.05967189419655, 82.74319110378143, 97.59180976498513, 31.614737010771233, 0.49839532243147977, 0.2567501849825344, 0.3384589013313094, 0.140292379224012, 0.16917081429593026, 0.2325648045347583, 0.2371383954079882, 0.22451945640627416, 0.18692116343205978, 0.19901623618939232, 0.11585580620674357, 0.17308556955427895, 0.14321911088641615, 0.14772061288597124, 0.18787529529823413, 0.2135642765149955, 0.14609931036829948, 0.10025210438236114, 0.08975689134169972, 0.15096586858553274, 0.16166042536497116, 0.25953615564973126, 0.09739271184850125], [0.07840071804821491, 0.011756299101116677, 0.02063127831676074, 0.08491034334104869, 0.020273097738203023, 0.05824886330012834, 0.060171406911385644, 0.0393414149631656, 0.09681887368881896, 0.019252484761959603, 0.09467495365008231, 0.05940757511604217, 0.06440200106871706, 0.09767173639228267, 0.056182865894609885, 0.022400793949923208, 0.04538920415084689, 0.10848238613576659, 0.06537621209938681, 1.1541394048160123, 66.7374889312252, 86.82804938285582, 70.26046768311532, 63.99859197678105, 92.03176375358336, 63.2917102690666, 38.35384945715628, 38.438168648750555, 34.349517437719534, 45.07446596699376, 1.833577514175446, 0.03918968358888261, 0.11465269576517806, 0.30615959256406755, 0.2136182703918988, 0.37331286817789083, 1.7789016351584466, 1.3620443906514876, 0.10388189025463597, 48.28534956901304, 83.57311756380143, 82.6658654982044, 78.96641931226178, 76.2337589263916, 69.69119056578606, 58.82723715997512, 61.19253620024651, 60.04883581592191, 64.19904862680744, 57.64083393158452, 56.17073743574081, 57.25458637360604, 58.98485368297946, 55.91157859371555, 55.27911209291028, 52.63152791607765, 52.60344766801404, 58.24994271801364, 64.77096549926266, 67.76823289932744, 72.46775796336513, 67.39454869301089, 69.88331610156645, 67.25487309117472, 62.75169403322282, 50.858318498057706, 49.015067315870716, 49.46309612643335, 59.12053238961005, 67.15458593060895, 65.65076097365349, 62.117038849861395, 55.52476621443226, 48.834469626026774, 50.503661709447066, 56.889507847447554, 68.2441968302573, 65.78996981343916, 63.311024019795084, 68.29914923637145, 66.66149693150675, 65.80671833407494, 63.16521383100941, 62.58478933765043, 60.63843081074377, 56.528112426880874, 68.77317551643618, 55.939784357624674, 50.501614232217115, 68.86508449431389, 59.78838259173978, 62.71717325333626, 62.38620365819624, 65.76217589839813, 62.170736097520404, 65.00331886353032, 49.52139823667465, 49.65019318365282, 51.401668748547955, 49.62885941228559, 47.557345897920676, 47.8654480749561, 48.63265975829094, 48.78988796664823, 49.04930960747504, 50.31217552000477, 48.2037172009868, 49.055499107606956, 47.159017439811464, 50.401170176844445, 48.87774905850811, 60.36220573609876, 64.51702340956658, 69.31206995441069, 67.21433931781401, 68.86698292147729, 66.57239637067242, 65.65775063730055, 61.978634095961056, 56.56340591369137, 53.85933568400722, 58.75113141152167, 58.09115340632778, 59.155731739536414, 58.980017400557, 59.73698777537192, 62.37615846818494, 70.76028746943321, 73.99275195214057, 73.02063957337411, 75.57684036993211, 69.45752712988084, 9.097864070246297, 0.6209316068599301, 0.8693669952692524, 1.315790820986994, 1.2431622536913043, 0.9539627752477123, 0.37936309352517134, 0.16145456221795854, 0.15146656833108396, 0.06804407499129735, 10.702157597387991, 44.2677991620956, 65.15464782714844, 84.96680628868842, 51.939170745111284, 31.416155253687215, 44.247630334669545, 45.79399731851394, 63.27177286148072, 62.189688990193034, 65.57662033265638, 3.331908823982362, 0.17849863957493536, 0.013353014026858635, 0.04365699125393745, 0.05024499883274398, 0.04023985223724477, 0.02938675930753591, 0.07406163434948652, 0.02241896172504752, 0.03843995164178553, 0.008446884495506604, 0.04112267280898748, 0.05518777896800349, 0.030885437961607694, 0.011308556140941239, 0.04562507113141399, 0.026191532979869557, 0.016694153291023067, 0.06412241345031128, 0.05934911494654033, 0.02273203696184341, 0.10123031439199563, 0.07323548513194246, 0.07814968635718669, 0.030386153563496568, 0.02831175983432801, 0.0301485188350442, 0.05821708597302918, 0.06583305331127298, 0.050009974548893596, 0.05203644947839841, 0.01831410366350845, 0.027535391010103688, 0.012363611472650402, 0.09418572224075757, 0.0724048083347659, 0.055806544354005214, 0.04021580856774123, 0.03375271162498863, 0.040676150801441366, 0.06149902579284484, 0.024638454422294617, 2.2746947407722473, 83.05136388347995, 96.36643778893256, 80.54649122299688, 71.65978893156975, 91.17573784243677, 79.15299077187815, 45.214984878416985, 31.848520078966697, 39.16028484221428, 49.05353007778045, 2.37509859185065, 0.1210895427052052, 0.0781055367101104, 1.6461309982884316, 0.9685527665480491, 1.8148931812855507, 2.068362625375871, 0.2349846924264585, 0.31322457797584996, 50.956781756493356, 87.48179866421609, 84.67011820885443, 85.62230494714554, 78.55233469317037, 73.13671819625363, 62.07692084773895, 62.257079232123594, 61.20383262634278, 66.46202087402344, 61.14862526616743, 60.202243635731364, 58.96945445768295, 62.65718452392086, 58.79906277502737, 57.12397536923809, 54.60576665016913, 57.39978859501501, 59.2554501564272, 67.14989477588286, 70.41460898614699, 73.5959492960284, 67.70021900053948, 72.26749743184736, 69.9731069995511, 65.2785986469638, 52.8382093675675, 53.40928685280585, 51.18081577362553, 62.053516064920736, 68.3241896475515, 68.33132051652478, 64.19750713532972, 59.172311598254794, 51.75934576219129, 52.803637596868704, 59.572711067814986, 70.92030448298301, 68.9642890807121, 64.67826812498032, 70.56238820475917, 69.52358768832299, 68.4018918006651, 66.94349181267523, 64.74082208448841, 62.619290505686116, 59.96193570475425, 70.7817820579775, 60.60333344244189, 53.33028639516523, 71.19027337720318, 62.40510163768646, 64.62483367612286, 64.28963968830725, 69.2766744859757, 66.34132954382127, 67.23624967759656, 53.267952088386785, 51.56209368859568, 52.389309790826616, 51.35949934682539, 49.796525047671416, 52.492676011977665, 51.39318466186524, 50.350646126654844, 52.641275005955855, 50.89681656129899, 49.482555004858206, 52.07268038103658, 50.27758021508494, 52.51971683194561, 52.28465310988888, 62.952746883515395, 68.23385746248307, 72.15115208779612, 69.62401605421498, 71.56454593904557, 68.55372675003545, 65.97051651247087, 64.19288658326673, 59.26397346681165, 56.90127103559433, 60.682745748950595, 61.62521677632486, 61.35920947597873, 61.0263139970841, 62.37976704874347, 65.60525755728445, 73.0509751842868, 76.78733087355091, 78.12423936782345, 79.27592569781889, 74.53877725908833, 14.067605137825014, 0.31028610984644583, 0.3254688080520399, 1.8034618011405392, 2.09977688808595, 2.634315779132228, 1.8143173283146274, 1.1901037395000458, 0.1449212969671334, 0.12228843966318716, 13.04167882088692, 44.631273438853604, 59.98377938424388, 84.56055072046097, 42.77520395094349, 38.93846304185929, 52.13562657756191, 53.36954147584977, 72.59331303258097, 69.69020212850263, 79.91718615255049, 6.023329409860796, 0.1561379273452105, 0.10839686007989992, 0.06845993816011375, 0.012821340388918837, 0.04088400577705714, 0.021526779558870102, 0.02987353348984353, 0.012379866900793728, 0.035430800410047654, 0.052734612216872555, 0.02695510813575839, 0.04411412357923485, 0.010345438063415069, 0.04544917734399919, 0.07526307471937711, 0.002225189039769072, 0.08563504719565954, 0.09755693045595, 0.07262698915456572, 0.04228424213285889, 0.06994974934646199, 0.024067561870681185, 0.1778041042627827, 0.12169970875425686, 0.08410825694520628, 0.1390287631581868, 0.17542707132956675, 0.223584829138652, 0.14557873830199242, 0.1314335223287344, 0.16597530834617155, 0.15499536849318013, 0.10813641316828229, 0.19782359050887247, 0.230434651096021, 0.11966261967656114, 0.20151234982955843, 0.1393158316251732, 0.20050477566978625, 0.24124199133967203, 0.1224713048507129, 3.4026951030377424, 96.8060335036247, 109.49284568909677, 93.23534304095854, 82.1225780056369, 106.8921652147847, 74.94580161186957, 53.13390901011806, 52.35063522092758, 52.14994322869086, 68.47777397401872, 3.5436893566962215, 0.38361849743993054, 0.25985720777703875, 2.7702192866033126, 0.9407294337307254, 2.9791161417961125, 5.100020141370836, 4.468303303564749, 0.544213846085533, 54.372193428777884, 89.5659657447569, 90.79316554530975, 86.6079887267082, 83.66556782876292, 75.29155854255923, 64.64088793723815, 67.75641087562808, 64.14360200205158, 68.75929032602619, 64.53678823286488, 61.770242491076075, 62.95467668964017, 65.4913793840716, 61.884203034062544, 59.71502642477713, 57.75637126738026, 59.341675619925226, 63.376025538290705, 72.4714449913271, 73.43204913600799, 74.53997750436106, 68.05771166278471, 74.26712959043442, 73.70829382250386, 68.76637412655738, 56.973085711079264, 54.55077109798309, 54.16850082335934, 64.83912844811717, 73.97357156199794, 72.51583053219703, 67.71810500852524, 61.881543667085715, 54.827074620031546, 56.08534351471932, 62.90317596927766, 74.35662238828598, 72.94175286446848, 67.22147018678727, 71.93190728464435, 72.26307299829298, 71.3823361550608, 69.14081927268737, 67.22902467173915, 66.5507919557633, 62.64331110062138, 75.25929312552176, 65.2919033265883, 57.783086530623905, 74.82915816768524, 67.61739423198085, 68.3264881564725, 67.87867899863951, 70.51491183619346, 70.08108200565462, 70.72909678182295, 55.362631120989406, 54.4797291294221, 56.44681738268945, 54.60805339197959, 52.492197482816636, 52.625691429261245, 53.447196560521284, 54.81936324027277, 54.658922610744355, 53.76676774794056, 52.69811799449306, 55.05259129308886, 52.04659269702051, 55.568120171946866, 53.8795711917262, 66.20037524930893, 71.4705502602362, 75.8371445440477, 70.92735690455284, 75.11070589865409, 72.21225477034046, 70.26672778591033, 68.88812449670607, 63.6055822526255, 58.66904404855544, 64.90513801574707, 64.55817299504434, 65.84678926775533, 64.3138446346406, 66.2540646522276, 68.81340334492346, 77.20516527852705, 80.07535180737896, 81.43631227554815, 79.90091616107573, 76.59863348930114, 15.21651933270116, 1.863283952397685, 6.682209151406442, 7.501782515356618, 6.689550357480203, 2.6086225384666077, 2.021391507117979, 1.307840544369913, 0.3311326799373473, 0.21992394009665137, 19.813890187971055, 65.35345708170246, 75.48198961442517, 91.61125429214971, 63.16200533220845, 42.873133767035704, 60.667217085438395, 63.246469651499105, 81.62242874022454, 78.92258290321597, 86.64245851578252, 5.251882547332395, 0.3092643937035915, 0.14133942223364307, 0.22420473216522127, 0.15068684404175128, 0.0829834713330192, 0.158070951039272, 0.24139438154956988, 0.11077004725173598, 0.11232171237709061, 0.19472818160730024, 0.17438241851425942, 0.1364106117116828, 0.14888483670450028, 0.1090927896720748, 0.12484128211414623, 0.11086895686363983, 0.1835689005712348, 0.23561475377890373, 0.24463133285603217, 0.10821076200133371, 0.14574182309931324, 0.15303404551119576], [0.09112768310813174, 0.0227502545326828, 0.05201531694300714, 0.04055233184067954, 0.020830179639761488, 0.1370305147382521, 0.05049147996150198, 0.06860616902310042, 0.03108897603177015, 0.06592987150314354, 0.052082889728368297, 0.09170588030810319, 0.058015183500585064, 0.03072260214286226, 0.02603296618608217, 0.03553277437364863, 0.0683818431571126, 0.07018256346665083, 0.5382577882659051, 10.350019951020519, 94.03107427781629, 80.5660403159357, 67.75865447136664, 77.31456018263295, 44.973370798172496, 15.26018511864447, 35.63785129977811, 45.603134785929036, 58.25330418925132, 15.390299943185623, 0.05067193963294549, 0.036572221621510484, 0.07785956119938243, 0.9211573581541739, 0.8591882608109905, 1.3239823233696724, 1.397215671116306, 0.9283794222339508, 19.42489697087196, 81.64833991758286, 76.34144367710238, 82.25012563890027, 74.77751624199652, 72.07456388781148, 62.8166445609062, 62.172767885269664, 58.83787462788244, 57.420498709524836, 55.791718805989916, 57.27395895988711, 60.78778289979505, 61.30863443497689, 58.94262152333414, 58.48415528574298, 53.46483938155636, 52.214293633737874, 50.20876223041166, 54.948789688848684, 63.576572402831054, 67.23588097480037, 69.62089384755781, 67.10964341317454, 67.96317469689154, 66.4393025059854, 57.62144957819293, 49.97023505549277, 48.81448122762865, 50.80662558155676, 65.70095554474862, 68.70039986025903, 67.6449449600712, 64.3994229070602, 59.486403234543346, 52.49597472529258, 53.587931202303984, 58.16616873587332, 66.97326260228311, 62.430777472834436, 68.0870117679719, 65.87811331595144, 63.440026852392386, 59.82492339226508, 59.63417853078535, 54.42115245326873, 54.57745890463553, 54.47286890399072, 68.74087087569698, 53.869063162034564, 48.20587842695175, 68.65073480913716, 55.17358856816446, 59.57560577700215, 59.417624473571784, 63.05826648589104, 63.22875622780093, 54.994253881516, 45.90873449079452, 49.95066242833292, 49.731135214528734, 49.21747730624292, 51.38564586639405, 50.15895205159342, 49.85490952768634, 49.96644996827649, 50.38570034888483, 49.808637326763524, 46.841054424162834, 47.841831484148585, 49.18627485152214, 49.044088932775686, 49.25395142647528, 53.407309978239, 62.523000240325935, 67.51726396622198, 70.44153213500977, 69.12025820824408, 69.44186902815296, 66.13320858247819, 66.66207744229224, 60.84219401882541, 52.45495850040067, 51.17160212609076, 54.89172312521166, 54.10345223642165, 55.26566228558941, 58.41695331758069, 67.04521456072408, 64.71098853695777, 71.37134567383798, 70.48551759412213, 76.02621847583403, 74.17103936595302, 71.89650397146903, 11.737517214590504, 0.4276104529778804, 0.3490661853744138, 2.2780368453071964, 1.3423589953491766, 0.22104374613733063, 0.466883827842051, 0.16359033874206005, 0.0720301836789135, 2.723113091722612, 26.209506950070782, 31.329051179270593, 32.79659813450229, 31.605895988402832, 19.651717832011563, 28.418781949627785, 55.51133994133242, 66.96366064010128, 66.34251409961333, 72.8771435829901, 32.23615811717126, 0.5114831378863705, 0.10225062093306934, 0.04769115663704373, 0.06758095185843206, 0.03824847562599086, 0.015530818134486197, 0.0179209090363715, 0.016617031219685753, 0.016760021530752702, 0.018657035261933363, 0.04172144330016548, 0.0545650988727087, 0.04630416594145279, 0.11493352061558156, 0.06749331906077362, 0.028285550051218564, 0.03643652829792231, 0.05346319630681988, 0.05679498163742885, 0.02542019160764833, 0.05974500620317075, 0.07266946106908784, 0.02704297650545355, 0.004518128022731793, 0.025167495590604605, 0.0250521112578891, 0.04657615396764971, 0.1041474546335878, 0.06567946034333398, 0.033107159974714445, 0.04551036478651147, 0.06506332646935217, 0.005897502846745474, 0.053101334675786, 0.03332734513547152, 0.017923923592353543, 0.02498240683287863, 0.03147394095938052, 0.041540183066841097, 0.09593997165680894, 0.6864035646280935, 16.27652124051125, 108.11035140868157, 87.63235492091026, 79.86522259250765, 83.03199521956905, 66.8202901655628, 29.644977623416533, 32.09730032951602, 42.08433728064261, 62.31007045315158, 17.768660476130826, 0.048745822221521413, 0.03436820198511405, 0.15677780994484503, 2.428991958018272, 1.9732759147882464, 1.7149860003302175, 0.9264159695275369, 0.9917074982677737, 21.340153063497237, 88.727323778214, 78.68385176504813, 85.72342365018784, 78.23798810282062, 73.66230795460363, 64.30744332651939, 65.31792825268161, 61.2814445649424, 59.678324807074766, 59.03766447497953, 59.540225998047866, 63.42202709567163, 64.7191313774355, 63.581436141844726, 62.22115816608552, 56.12683042403191, 54.92238037047848, 52.87996692042197, 58.46120549786476, 68.1161000651698, 70.50529418453094, 70.39490299840128, 67.39516842749812, 69.8236019380631, 69.79856937162339, 62.13309703334686, 52.73709066452519, 51.36343348410822, 54.591532368813795, 68.40372746990573, 69.7450525529923, 69.50050846222909, 66.19322084611463, 62.80822715451641, 56.93499949670608, 56.586908755763886, 61.74097768722042, 68.23522244730304, 64.28880422346055, 68.70166286345452, 68.86644947913386, 65.88767605443155, 62.43824174327236, 62.864375883533114, 58.54673277947211, 55.88572232953964, 57.324777187839636, 72.66576705440399, 55.275044595041585, 50.60296043272942, 71.83191037947132, 58.994349741166644, 63.33623309289256, 61.09561443328858, 65.30409797545403, 66.40196938668528, 57.42265601311961, 48.49443543341852, 53.09419501212336, 51.45936289141255, 50.67305711007888, 53.175901905182876, 51.3495090699965, 52.05933647771036, 52.383547829043486, 53.09281041545253, 51.03065567631876, 49.85918883354434, 50.15022477796001, 51.15848964260471, 52.55517898067352, 50.57118923433366, 57.0338353803081, 66.25212700136247, 70.46342680531164, 72.52601300516437, 69.3735727187126, 71.66746893236714, 69.53493118286133, 68.6399482911633, 62.319844999621, 54.74685430526734, 54.71221585427561, 56.49412116696758, 56.509253671092374, 58.58152812527072, 60.13188808195053, 68.47370255377986, 67.82999454006072, 74.57085440235754, 73.23998635815036, 78.68442443109329, 75.36260051112022, 78.83050918579102, 15.550436589025683, 0.22798258751150102, 0.7250126186878451, 1.6187372875790444, 4.357523802788028, 1.8511649317318395, 0.45190402036232336, 0.4777101823879827, 0.10906618343846453, 1.4190110564231875, 34.46927132145051, 34.028306699568226, 37.92202395777549, 29.6039084465273, 22.28923720698203, 39.03022689204062, 62.39470735672982, 74.31433139308807, 73.57938120442053, 81.95725010287377, 45.14954405446207, 0.49212866192383153, 0.07188661880190335, 0.023857852962288647, 0.03347651394564779, 0.07187954781036224, 0.03812468347830638, 0.040508959772846395, 0.04225540658338897, 0.05200073445936845, 0.0332232337865618, 0.06150951736696786, 0.0308684729445245, 0.040104737310039426, 0.08687196509732355, 0.0759464251478353, 0.02741853961901319, 0.05305095290344569, 0.05729670027991938, 0.0961981509481707, 0.011809131397204775, 0.016965507379462643, 0.012617481519438088, 0.2684430309361027, 0.1001274771988392, 0.09741859029858344, 0.15271005160625906, 0.22182510985482126, 0.3306650292248495, 0.21907974184761125, 0.09676298757474269, 0.10226340694052559, 0.21272622229110813, 0.16322370438325792, 0.13507072393211628, 0.2257582971886281, 0.14943724738494044, 0.1895095447018262, 0.1349398454711322, 0.20930099721637466, 0.14835007668983552, 1.0405536933291344, 21.0078675131644, 123.06169694469823, 98.35166700424688, 93.03281537948116, 96.85995040401336, 64.11418030338903, 23.799583104348955, 51.678592005083644, 66.12931759126725, 86.90008763344058, 23.904159376698157, 0.19183076046887906, 0.21367022647492348, 0.46861055937986223, 2.4160976563730547, 2.8997374205820026, 3.810920191387977, 7.561582480707477, 2.794857164544444, 23.087315982387913, 91.31061246318203, 84.49877339024698, 88.13000171415268, 81.70702642010104, 76.16226196289062, 68.2902140771189, 67.80623282155683, 64.7917736730268, 62.90474491734659, 64.00319291699317, 62.57553254404376, 67.80880589638987, 68.7731441374748, 65.83954857241723, 64.73036504560902, 58.37243049375473, 58.677688952415224, 54.54629567361648, 61.50350955224807, 72.16971274345153, 73.0343286452755, 72.9251455491589, 67.08693288987683, 74.44760568680303, 74.48460932700866, 64.95368126899966, 55.86519264405774, 54.60290331994334, 56.793178358385646, 72.51071576149234, 72.74535978994062, 73.89577527200022, 68.44950152981666, 66.50246835524037, 59.976020936043035, 59.91927600676014, 66.30756578137799, 71.39735098808043, 67.88065587320636, 70.97457439668717, 71.55044894064628, 69.00152806312808, 65.2710755409733, 64.85003655956638, 61.315094578650694, 58.62973797705866, 60.22364016502135, 75.23207187652588, 59.653492281513834, 56.90571900336974, 74.84601651468586, 60.727048920046904, 66.17390709538614, 65.96627250794442, 68.62158375401651, 69.10587879919237, 59.78000440905171, 51.44931377903108, 55.701382698551306, 54.78972188888058, 54.41908144181775, 55.927307298106534, 54.533426377081106, 54.92588696941253, 54.17886764772477, 54.50106290078933, 54.58155385909542, 52.56506335350775, 53.27097623578964, 53.89661389012491, 55.872962859369096, 53.67177186473724, 59.76238904460784, 69.64266300201416, 73.82208178120275, 76.25267259536251, 71.6663549792382, 73.6524078922887, 72.0813338987289, 72.0400470302951, 67.67379791505876, 58.64208167599094, 57.712040639692745, 60.87438883319978, 60.39774240985994, 61.89017288146481, 63.41981095652427, 73.03371675552862, 71.0053022446171, 80.88862388364731, 75.1439126845329, 81.03456743301885, 76.82788818113266, 81.54205937539378, 15.742061042016553, 1.6205800661156256, 5.184555553620862, 8.413594826575249, 7.962085893077235, 2.380705620011976, 0.8471553484278341, 0.8844729008213167, 0.18497876282180511, 3.8196553097617243, 44.899567481010195, 48.25135830909976, 44.32846646155081, 41.63112309671218, 27.7822087272521, 40.47222352796986, 70.38364579600673, 85.63824545952582, 81.3852273264239, 92.19283196233934, 45.24494786416331, 0.728988369866725, 0.21282034385348522, 0.19445315604248356, 0.25971278488155336, 0.1798089716823832, 0.1352476595991081, 0.08551925300590454, 0.08700154886971559, 0.172099078134183, 0.2035242499363038, 0.14045658250970228, 0.1301032566134968, 0.17528502330664666, 0.17154196367388772, 0.18464309373690238, 0.07953368547943332, 0.12119265813981334, 0.11875393980693434, 0.18047395132241711, 0.09808311794674206, 0.20313814162246643, 0.23434739920400807], [0.024187690202867793, 0.026722000986938516, 0.004833655698495287, 0.05759801415185775, 0.04314155580716268, 0.049004131747830304, 0.06278717582444511, 0.05838786995398903, 0.06504744546668184, 0.05209625796264699, 0.0334705384598384, 0.08627713612851598, 0.09942591686042086, 0.04568822358945205, 0.06828363834609909, 0.012083209885825074, 0.02293325570081511, 0.03466754701108702, 0.02061221613398483, 42.37341203997212, 91.56330723916331, 70.16498150364046, 68.10338374107116, 59.03858623197002, 23.526801870715236, 29.87641315306387, 56.776551431225194, 44.93824205090923, 42.22802938953523, 3.013969832851041, 0.10352948980946695, 0.10343298571364534, 0.3066558030343825, 1.4494041545737175, 2.0247048067469753, 0.8323021906037485, 0.9571027551447192, 1.916305694368578, 65.21533473845452, 77.41760869180003, 82.8045291285361, 77.30116921086466, 75.79443777761152, 69.70644074101602, 65.46292651084163, 59.600810927729455, 61.52973844159035, 60.13320599832843, 60.289618353689875, 62.422591486284816, 62.19402713160362, 63.262955373333355, 61.85085896522769, 58.89646307114632, 52.988263560879616, 52.61410082540205, 49.90375480344219, 58.041594259200565, 63.87805754138578, 69.46698004199614, 71.77284732941659, 66.8667467178837, 66.24163073878135, 64.80570593187886, 53.083506553403794, 48.57026661595991, 47.08823434768185, 52.726829744154415, 65.46323245571506, 64.90455750496157, 66.58649336907172, 63.931852848299094, 62.24381769857099, 58.231519345314275, 58.77070011631135, 64.12152690272178, 65.9072800605528, 64.16553197368499, 69.49653117887436, 62.120282649993904, 61.09959171664331, 54.1467159794223, 52.78351191551455, 50.6852674484253, 53.97452392885762, 53.20246027361963, 68.52547784005442, 48.91249733586466, 45.256950316890595, 68.44273151889925, 53.13192821318104, 53.904274279071444, 51.51481736090876, 55.64354342799033, 49.87713367708268, 48.43774933968821, 45.80283441851216, 49.35786285708028, 47.477051058123195, 50.159850274362874, 51.84778736483667, 57.84597389159664, 53.56531873826058, 56.43966297949515, 56.277359224134884, 57.60119838099326, 51.50248935145717, 48.18692161190895, 46.3477026262591, 49.777234831163966, 48.350790392967966, 50.35921258311118, 56.53370180437642, 65.4966353601025, 66.95050501054334, 68.71003320140224, 64.29728831014326, 70.5646239557574, 67.95689890461584, 63.722068802002944, 49.798541145939986, 54.485079242337136, 51.38439855267925, 50.308680688181234, 56.55744391102945, 62.522839423148866, 59.24604431275399, 64.67889962657806, 66.79939177728468, 72.12281688567131, 70.0881108930034, 73.42039185185587, 73.83503344751173, 73.92039206720167, 11.73550013572939, 0.9900488872681895, 1.1955935868524736, 3.1071391172947425, 2.730342510246462, 1.3687842483482053, 0.24900263055197655, 0.020201583430471442, 0.03995029015406486, 9.77847570373166, 25.17921405453836, 33.596081118429865, 24.374265247775664, 37.1458496585969, 22.000150680541996, 35.24608496696719, 49.65476666727374, 56.220096541989236, 59.823770215434415, 64.54997916375437, 7.028003834909009, 0.3634846342667457, 0.10753114242106677, 0.05846726730646146, 0.01780775593473546, 0.02684238021292033, 0.05596879411548857, 0.04140670373735409, 0.04088933391857051, 0.07276434871938921, 0.011614209900970661, 0.053442397019675666, 0.05238367499963892, 0.05015502180603724, 0.03566535354982461, 0.05035934128588246, 0.022758465080011277, 0.026564859116690296, 0.017131290721496748, 0.023985672817235033, 0.004098589547098645, 0.08348787894412395, 0.031245077937661164, 0.05008320106313594, 0.08798691414056287, 0.011044590970531348, 0.0562392806093539, 0.04016368394537319, 0.019841606375731288, 0.04936788561603716, 0.018440877808438196, 0.021985057185614304, 0.010867218633422689, 0.034409413685000716, 0.09298626603859086, 0.01556663657538593, 0.05773376110160063, 0.09736652696324934, 0.02749488028066774, 0.018331491944169807, 0.06455311191178138, 53.02401596500028, 102.47846326520367, 79.79294115497221, 75.36798200299664, 68.53126725842877, 39.82495007976409, 31.99731715263859, 39.53474960019512, 40.72948394283172, 45.33604098904518, 3.3825780018683407, 0.09115233581753508, 0.09710832468924985, 1.6758706540830675, 2.071506895365254, 3.189794488491551, 2.4086431918605684, 1.0675061373941361, 2.562024780819493, 71.17014377347886, 79.48234435050719, 85.58082196020311, 79.99418227903305, 80.00327433309248, 73.71400479347476, 68.19790501748362, 62.97184098151423, 64.33803389149328, 62.22655142507246, 62.48747925604544, 66.08994483947754, 65.10798731157857, 66.1179191835465, 64.68564218090427, 60.055852936160186, 55.72303810427266, 55.473967598330596, 53.89262091728949, 61.02272502837643, 67.3797692022016, 73.33031854321881, 73.88791484217491, 66.77565359300183, 70.33869543383199, 65.49173631975728, 57.93468613778391, 51.09957564261652, 49.5824852297383, 55.48265564826227, 70.77632211869764, 67.90763393525155, 69.9218730003603, 66.7884797434653, 65.1882037039726, 60.87092538033763, 63.23614597320557, 65.89547372633412, 68.23875258045813, 67.88471160396453, 69.66608739668324, 63.994159698486335, 63.42096021098476, 56.58286479211623, 55.697515241561405, 53.874519178944254, 57.39412469248618, 55.10560604833788, 71.74450428255143, 51.30407233392039, 47.45905130140243, 71.8840543685421, 56.16002544280022, 56.221787083533506, 54.910656406033425, 59.25876455922281, 53.49144874080535, 48.54607735910724, 49.323600953625096, 50.21882703227382, 50.40440613223661, 53.61799224730461, 54.275507004030295, 59.48812907741916, 56.777881114713615, 60.38769721984864, 60.27628621747417, 60.66339277452039, 54.88809493280227, 50.39726349615282, 49.46517890499484, 52.321888169934674, 50.18948378101472, 52.986800516805346, 59.62106996966947, 67.71958766445037, 69.14551042741346, 70.45857875577866, 66.82563243373748, 72.71968395479264, 69.58000706088158, 65.60902303264987, 52.81692658701251, 55.37423349195912, 53.47895206943635, 55.57294468725882, 57.859341329143895, 65.33534749861687, 61.92357186348208, 68.31705093383789, 68.6013678581484, 73.63338439695298, 70.80253924092939, 77.08461515365109, 74.5210167669481, 80.74229594199889, 16.823900745761012, 0.8164797783378632, 0.5136834343354548, 0.7524235510537702, 4.576302824481841, 1.8057368984145505, 0.9209077973519603, 0.014412955084304898, 0.1613308696617042, 13.718361220052167, 37.5860611854061, 34.21210112110261, 30.436466816932928, 38.07233310514881, 35.0111428383858, 47.348189430852095, 55.165112326222086, 63.59501146501111, 64.8045096089763, 78.81671028752481, 13.516958298221713, 0.528457256094102, 0.14162030071020126, 0.07570738273282206, 0.051019364337046305, 0.10718703104723847, 0.07514865948788582, 0.12301660623521575, 0.03992041272501792, 0.06558180711562596, 0.010527290099660956, 0.007441654085977785, 0.05928050028160215, 0.13793265987788478, 0.05476294107915414, 0.03613553235247251, 0.05899291470526688, 0.03298272431317357, 0.09349589070845997, 0.04569265157765439, 0.022358168817816243, 0.012631294084712865, 0.07858062613635294, 0.10778297084353625, 0.1865162093552851, 0.09338682277068015, 0.22342198948946693, 0.17075817911855637, 0.1994341677956043, 0.12231637888978567, 0.13413830299771604, 0.1846569905718488, 0.26505572721362114, 0.13374490152683952, 0.22562453823704876, 0.12099291603531569, 0.13731067309216147, 0.1396039419717366, 0.1173667154545265, 0.12298862870422103, 0.20246182388115316, 61.990832667196955, 113.53869991917765, 91.70273180930846, 88.81975050895446, 76.91195241866573, 36.51110033835135, 43.971824953632975, 77.23398685455322, 59.1019638892143, 61.92097525442801, 4.684407268801044, 0.27005849586379144, 0.38883016294529366, 1.5325537444122377, 3.6780621592075597, 6.010515516804111, 6.031654150255266, 4.760279145932967, 2.8005073387776656, 74.22537203757994, 81.78173188240298, 88.38563826776321, 84.22646676340412, 82.38392553021832, 75.89160273152014, 70.61762302152573, 65.45565443654215, 67.26254524723177, 65.48360524639007, 64.57092069810437, 68.1697973128288, 68.37867921398532, 69.01078485673474, 69.82304496149864, 65.24854152433335, 59.20592238826137, 58.016671519125666, 56.572572492784076, 63.51421848420174, 69.59662222093152, 77.82668836655156, 75.88626046334544, 68.2249693716726, 73.81145215803578, 70.91573884410244, 60.05862997424219, 53.84660367042788, 52.55804623326948, 56.43704675859021, 73.19778949983659, 70.8128236955212, 72.2206094188075, 69.1685974982477, 69.15515945803735, 64.32385452332036, 67.59961805035992, 67.6206184202625, 70.11069590045561, 70.82048016209757, 73.39662228861164, 66.53280396615305, 64.4863465524489, 60.629346601424686, 58.57660947307464, 56.555372899578465, 59.6648749997539, 58.30950783145044, 74.08022865172356, 55.98003179796281, 53.3833089951546, 74.41858799226823, 59.554032741054414, 57.47174447582614, 56.66133965215376, 62.55077062114593, 55.3841257095337, 50.57708847907282, 49.495643954123224, 54.46893084433771, 53.811392553391, 57.03863243902884, 56.61183934057913, 62.97266860162059, 59.6056785891133, 62.59544249503844, 63.14564120384955, 61.999316753879675, 57.22509014991022, 53.016233982578406, 50.89718918646536, 55.26121824018417, 52.578885785995, 56.638448699828125, 63.60490760495586, 71.90111667879167, 73.1252021174277, 73.72059437536424, 68.52875694151848, 76.96167238297002, 72.90914227885585, 70.57467306813886, 55.94178868878273, 58.496287176685954, 57.159210020496005, 57.65957893863801, 60.714928796214444, 68.11308768487746, 64.23838215489542, 71.68156593076645, 70.46461920584403, 77.92854447518626, 71.16162438546458, 81.23757362365723, 79.66193399121686, 81.20573182259837, 17.165494080512754, 2.440968425043168, 6.660919506703654, 9.773120687853906, 8.931793858928065, 3.820309364987958, 0.8750655862592882, 0.23277017738549943, 0.337402006430972, 19.27330913082246, 43.60902140217443, 46.736397743225105, 33.720275125195904, 50.38719869429066, 34.51650842543572, 50.6275733055607, 65.36052911512314, 76.29858786059965, 72.98318878296884, 90.38481543141027, 12.99058210465216, 0.68646056156966, 0.3864081606509224, 0.18255829270328247, 0.11740096724562107, 0.17537012035327573, 0.22635624413528752, 0.22744868551531147, 0.09427574523273977, 0.17910364985225663, 0.1193744480429638, 0.22796389496614858, 0.15170358061309785, 0.16884469066656407, 0.12853818494946728, 0.13689928387682285, 0.09114420762465847, 0.13229503416486327, 0.12630303916070731, 0.10674748810068255, 0.14455902930949965, 0.17174601885339907], [0.02146457321941853, 0.0038467402966137257, 0.0377982227702535, 0.03145507795946493, 0.043574115862288786, 0.010726055442055148, 0.02306050865069753, 0.013200025310769919, 0.06059663167463676, 0.08564390317206422, 0.04757928481746105, 0.029298856463884155, 0.028161447637924747, 0.028679560561994874, 0.05667570174761838, 0.0034243335399115763, 0.015606197355795774, 0.1089061936363578, 1.054845584496375, 61.03977949388566, 82.13009326688706, 69.9100588214013, 71.17434855430358, 61.987090726052564, 19.10006980742178, 56.84372202042611, 45.57605866462954, 60.94651337592833, 24.05417630749364, 0.13769082124194792, 0.024813258449637124, 0.04539437907477541, 0.934749412680826, 1.8125705252732, 2.1871339553786866, 0.39978224784135824, 1.0963838523434055, 33.698203948236284, 85.06582260131837, 82.06834731563445, 79.81585564151888, 72.00307476905085, 74.97618429122433, 67.32950795081355, 70.9893617322368, 65.92820198305192, 63.89406081168883, 61.801264516768924, 63.26470082806003, 64.19875837141468, 69.1656949443202, 64.65132536426668, 61.19891789651687, 56.97937327046549, 50.71161400887274, 50.81623538847893, 54.69429846732847, 63.01948601199735, 68.06203411471459, 69.6351634302447, 69.78406444672616, 65.72666275885798, 66.74002278235652, 58.343412799219934, 49.986183412613414, 48.048477634306884, 48.6391826598875, 57.233378118084325, 67.51663638699439, 61.88738799864247, 62.10404795985069, 65.07108565299743, 65.80461202129241, 63.06466387164209, 64.54417013352918, 66.91897699909826, 66.76503965931555, 61.020355916792354, 65.99959696492841, 60.2767216005633, 60.517339398784024, 53.363061720325106, 54.70330422924411, 51.06381147138534, 55.1726197427319, 52.98973837206441, 70.66211054402014, 49.10641147244362, 39.177123577364036, 69.26580952059838, 51.04937322678105, 51.83625167415988, 48.8572625190981, 51.806845664978034, 46.659401616742535, 47.65673483571699, 45.92171361369472, 48.09999404415008, 47.33457880635416, 49.183435055517386, 53.84096330212009, 59.84907342541603, 60.23443452773556, 66.02267619102233, 64.76431315945041, 62.65646673017933, 58.05059609874603, 47.982213112615774, 46.615380856298636, 47.50310344080771, 48.144199155992084, 49.06907835314351, 51.474832719372166, 61.17326559558992, 63.91122118119271, 66.04914434494512, 60.28952421680574, 64.04154585253808, 67.07994322622976, 62.68772409808252, 50.31939268112183, 49.939562120745265, 50.97825673318679, 54.430060155930065, 55.07190504381734, 62.287101053422504, 64.2281133897843, 64.97654868710426, 65.96729232418922, 70.63727409608903, 68.56796495376095, 67.51322392494448, 73.8515309364565, 74.68299496558406, 74.45253218373945, 10.438260532194569, 0.9093795224062858, 3.1776356312536427, 1.9617719707950472, 0.7233719035021721, 0.5792569753623779, 0.09302123795233427, 0.06716406979267636, 1.6400313449482766, 13.99317914439786, 30.766618597892027, 29.751801413874475, 44.39703733690324, 43.423983589295425, 24.02609605943003, 44.4210579318385, 51.66165913304975, 58.05360455666819, 59.02562279855052, 41.70713470828149, 0.334503926456936, 0.008753677811323395, 0.07573604974294863, 0.03411112969080287, 0.07561153747261533, 0.021110445245980256, 0.04891089118656613, 0.022002575701222788, 0.017094541483769016, 0.052533663523894165, 0.043980303340621536, 0.0301536918437529, 0.04487034046061097, 0.10351871095237233, 0.07149557688183363, 0.03305416201211272, 0.03781158334365295, 0.015341779235900651, 0.0187605241644046, 0.09311467003557952, 0.05128399408873051, 0.028533982788963665, 0.05296807751179703, 0.05145553649673539, 0.10067604211789948, 0.06173426841175365, 0.00353170890218368, 0.026512406991734624, 0.02707129494557458, 0.08321977881414276, 0.05961639919288217, 0.04083832778457192, 0.057739763400487365, 0.06193750387718601, 0.043897542862161514, 0.06869816852192726, 0.03107236149991232, 0.0485109013595408, 0.12783789631700324, 1.6832787855978937, 76.77364180164953, 91.16244885229295, 77.76328717508625, 78.57360178424467, 69.08503532409668, 23.938713496731175, 39.71991685128982, 41.15564946205386, 61.322598072790335, 27.762047744566395, 0.16873201445466088, 0.05620929209755794, 0.057862486855517474, 2.906539545905206, 1.4755134116257391, 3.4586462426570157, 2.036467627171547, 0.7443248985275146, 37.809797102405184, 86.65135445133333, 84.61011378995835, 84.57276498117756, 76.0953777067123, 76.99057240639964, 69.16391418826196, 72.699797538019, 68.0466191999374, 67.1826151878603, 65.10848153022029, 66.75563381564233, 68.34273461372622, 70.72055385958764, 66.83816832880821, 63.50509897355111, 59.73726234128399, 53.72839127817462, 54.666194685043834, 55.65290612559165, 64.95640731626942, 71.28601843310942, 72.43493556976318, 69.458099795926, 68.13591587928035, 67.78847232941659, 62.3477565857672, 53.29315331674392, 50.31269327286751, 50.20183924705752, 60.36531225327523, 69.85713820303641, 63.7111371563327, 63.98653461087135, 67.82501312994188, 68.20200781668386, 67.17007144804924, 66.79401813014861, 67.9568753703948, 67.9290500763924, 62.626633182648696, 68.89835403811547, 62.60320094323928, 64.01152795360935, 56.0240251018155, 56.19489531363211, 53.38577224362282, 59.51902950963667, 54.08613497211088, 71.20181299025013, 51.38343757198703, 43.150712059390166, 72.44041904326409, 53.7278421463505, 54.42830685646304, 51.379221024051795, 53.555861903775124, 47.579209189261164, 50.186589071827555, 47.966166696240826, 49.755096973911414, 47.58852089605024, 52.65630945082634, 56.41774869734242, 63.04084331758561, 62.371745801741085, 69.51310711522257, 67.12778045285133, 66.17865316329464, 60.22578570150561, 51.125741774036044, 47.52647684466454, 49.71759911506407, 50.18576537409137, 50.03022378490817, 53.31639728238506, 64.8141154935283, 67.49332181869015, 69.02573693183162, 60.618477713677194, 65.69082014022335, 69.99061646000033, 65.99705526905676, 52.59008023046678, 53.073092660596295, 53.85942197615101, 56.41865476485222, 57.68777293543662, 65.59251769896477, 66.7531156539917, 68.39711435379522, 67.75109214167442, 72.31674671173096, 70.331297843687, 68.53977095696234, 76.58218306879844, 75.81481056828653, 79.3162476631903, 15.197992017192227, 0.6398107099436945, 0.45376864772650505, 3.0211921420789536, 2.416098882113734, 1.3378660428908564, 0.7010447306017722, 0.012966107066360213, 0.927396378209514, 20.23527237676805, 36.43356684715518, 28.2057442972737, 35.602565657707956, 38.1442811412196, 31.089439468999064, 55.30620390369047, 59.88343338812552, 65.47534473480718, 65.4421732502599, 58.43961285006616, 0.7553620804702083, 0.0348361897762985, 0.04592952979428153, 0.03249101460941377, 0.04387430741541809, 0.07196513515326285, 0.039104751251157255, 0.006379623044913094, 0.027288509600405252, 0.03894928902868302, 0.03608768250072195, 0.03445283554854893, 0.05392556484307974, 0.0547462365319652, 0.021222508587544004, 0.059417415515429554, 0.05817474812389382, 0.08230356830022029, 0.010752755521436133, 0.027976251627889373, 0.006304896913558966, 0.09579244610523024, 0.10606862694746065, 0.176296673054176, 0.11910426415382855, 0.22407311825982987, 0.09719280120466026, 0.15406599658871853, 0.08593942924973466, 0.1465876760982698, 0.2123181578973609, 0.16696624307622834, 0.23176061139712412, 0.10323666802216923, 0.1464026352210391, 0.2414859137347629, 0.1333801517443311, 0.15261369306714306, 0.2805819392444626, 2.7144537241228166, 90.98940172503072, 100.06509950084072, 91.1096929734753, 87.92375564575197, 79.77834209319084, 28.495827105737504, 76.84075355529785, 61.229163292915594, 83.05053234100342, 39.813681110259026, 0.36494314310050785, 0.20424365246247864, 0.4358232832483707, 2.829971693215832, 6.239467205539827, 6.907073730422605, 7.66783997897179, 2.7658134843072584, 39.94904602727583, 89.45775539644303, 88.43331859957787, 86.94327292903778, 78.74438962628766, 82.1464652399863, 73.46806433893019, 76.91525505435082, 71.53231190096948, 69.23791362393287, 67.2432158070226, 69.958217682377, 72.14670412002071, 75.09333764353107, 70.00389760540378, 67.03054489627962, 63.35660588356757, 55.74816480759652, 55.72644664395241, 59.82819857135896, 68.08144200232722, 74.93030824968892, 75.86181625243157, 71.38414829008042, 69.76048315725019, 72.25577738977248, 64.63508282938312, 55.42716195506435, 52.13938028581681, 54.05375972870858, 63.538137097512525, 72.82002602854084, 66.82295737727996, 64.66751298596783, 71.35329492630498, 70.4924915682885, 70.14691506662678, 70.25111675262451, 69.64726786459647, 70.8603314430483, 64.24852148179086, 70.84158251362463, 64.62481798664217, 65.83146064512192, 58.82775883520804, 60.124937642005186, 56.566830142851806, 62.33980986379809, 57.92309945629489, 76.38657446830504, 56.160013675689704, 45.97322217879757, 74.84840916049096, 57.76464746844385, 56.36565569908389, 54.46957411304597, 57.58573247540382, 50.760102348942915, 52.12592655612577, 48.910971533867624, 52.74160531259353, 51.61288838232718, 53.82647798907373, 61.201169336995775, 65.90211822140601, 66.25847339630127, 72.92230575315415, 68.96366934622489, 70.53651625110258, 62.34073946552893, 52.898052969286525, 52.519493256845784, 51.897519096251465, 53.26444548945273, 55.07707472770445, 56.516290403181515, 67.14138323260893, 72.34646258815643, 69.86566543579102, 63.013292589495265, 67.32727219981533, 74.82092119032338, 70.59078616480674, 54.75182002590549, 55.196863912766986, 58.14474082762196, 59.99407952831638, 61.94610588012203, 69.67241025740101, 69.95147905042096, 72.0046672513408, 71.19101078279557, 76.33455599507978, 73.3083454255135, 71.37660164986887, 80.04386301963561, 80.01030322044127, 83.59623601359706, 15.670513087703338, 3.1674764473592085, 11.715715700580228, 7.383594637916935, 4.489865552994513, 1.6050554475476666, 1.113411228983633, 0.1478979009534082, 3.1804389001861697, 24.768571315273164, 45.58394262867589, 39.86157717243318, 55.83594745205295, 54.87328014066143, 34.442740409604966, 59.328323871858665, 70.66937477357926, 75.71406841278076, 76.73513197129773, 70.76630438527754, 1.0009278873762777, 0.1254976049606358, 0.1574463748763646, 0.18611741462542167, 0.19646395298261798, 0.1556352970580901, 0.19754225237955972, 0.06012925292335211, 0.09087928675956304, 0.15512655338933393, 0.2162508549348962, 0.22503157086189718, 0.1362862603198136, 0.1465557455535858, 0.0954745272775331, 0.17911173974073705, 0.12588852430663763, 0.18737347706431345, 0.09031147771184483, 0.12328445355618194, 0.12865427791351272], [0.01725499859950956, 0.09701772713132444, 0.04444813408378152, 0.04903500509117881, 0.059902479406446225, 0.04165922929983466, 0.029081193647617777, 0.02630131529463876, 0.02045013491184481, 0.010825161363989597, 0.08761190644074833, 0.10826494740021807, 0.07429549034925238, 0.011679165538460498, 0.010674462293184573, 0.04661762996787026, 0.11733868429737708, 0.1751427607791078, 16.96098758328346, 79.61432426206528, 78.20366736381285, 71.03281374900573, 60.96998483903947, 43.63137106741629, 35.840375038885306, 108.93736747003372, 64.19498505130892, 43.67651362572947, 4.300633745808756, 0.08216406368920881, 0.2774334098062208, 0.11006418149918319, 1.1620945843958086, 1.0019531581671008, 1.602037428848205, 3.1656876014124964, 3.5400427781766464, 72.143660360767, 75.96965005320888, 80.23311738044985, 75.57037630388814, 76.73009564799648, 70.28641023943501, 75.68217169853949, 70.4045912527269, 69.78938318067982, 71.1451582754812, 68.110687194332, 69.5684596030943, 69.56789478178948, 68.51149066801995, 67.53100795130577, 66.78043103987171, 54.060290475045484, 51.52311709619338, 49.423401740289506, 58.35212438337265, 66.59830754803073, 67.70378051265594, 68.3659158214446, 67.43039131164551, 67.85022612540953, 64.33457043863112, 56.85486155171549, 48.985488722401286, 48.978483369273526, 47.03654143118089, 56.84938200058476, 66.7363828228366, 63.29169065721574, 60.52896530397477, 61.86050407348141, 65.71352281878072, 63.77313413927632, 68.03114152723744, 61.03044425287555, 57.567630737058586, 56.585998765883915, 66.09902904879662, 61.0135623716539, 57.46353887742566, 50.79018692816458, 55.45767015026462, 51.36182531233757, 59.75893343648603, 54.499235076289025, 69.99103223123859, 45.1781734343498, 34.97100914678266, 67.11657031889885, 55.53636074066163, 59.77871002689485, 53.06406336445963, 51.216450506641024, 42.971506810957386, 48.224242964098536, 45.42247826053251, 47.69616250068911, 46.247556671019524, 49.90293502807618, 51.07259758057133, 57.53820511602587, 62.48049351476855, 65.19799786229288, 65.84188630503994, 67.74645590013074, 62.367309601076194, 54.14205228128741, 45.0222513752599, 49.079833492156006, 46.79140898489183, 48.58357914032475, 48.0987584975458, 59.29954151953421, 65.31854406479867, 65.01521933463313, 62.035453550277225, 65.58415128338721, 66.14222218913417, 58.081582823107325, 50.424825991353686, 52.52769885524627, 51.03019283663843, 53.41197759874406, 57.68456835900584, 61.28039336973622, 63.69119974874682, 66.99142317618093, 66.87103779085221, 67.28927227758592, 66.12752899046868, 66.03807541631883, 73.05726666604319, 72.67435704508136, 71.69362329667615, 64.00764872950893, 3.476978910546149, 0.549310598402254, 1.8280214768263603, 0.8914405011361646, 0.7658899058738063, 0.23983025983456643, 0.055523551474776, 0.1349657239212144, 13.6024591038304, 21.98494561256901, 52.59240619597897, 60.34597104595554, 93.06763818187099, 33.24690780332012, 21.988454172688147, 51.777270993878766, 52.883206798184304, 57.576103056630785, 58.284208543839, 17.39257185689865, 0.5457519054893525, 0.12521926223510696, 0.09489262987288738, 0.04325753768845912, 0.05817469832817874, 0.0656035257082793, 0.014521729035843766, 0.04307328588179043, 0.056132196839297974, 0.03154700659515877, 0.029619985199984045, 0.022196033969521526, 0.06481188875172408, 0.014557487147319463, 0.06252831854527036, 0.09124858710434168, 0.041711767609681816, 0.04879687049035584, 0.02804690791714576, 0.05113201756631175, 0.08244455912180486, 0.026474198356511134, 0.06603520859273211, 0.042115097580057, 0.08217505705092223, 0.05373711870502561, 0.04074088906148269, 0.06687118671834469, 0.020744488874991095, 0.0197498309576223, 0.08430527177669349, 0.0845690971360572, 0.039990149708765174, 0.02856242571837239, 0.07637365706144802, 0.09823209906537687, 0.06793091614400187, 0.20252856546111647, 26.43254076280902, 97.51583345474737, 85.6620228675104, 81.87300543631278, 66.13491873587331, 57.91902411368586, 31.51615215886024, 81.32516799434539, 57.5594251386581, 43.693419041172156, 5.213734065332721, 0.17432563607731175, 0.123715324387435, 1.77019078645014, 2.219986011905055, 2.3156977276648245, 3.714418608334757, 2.1530973430602782, 4.520880224243287, 77.12395652647942, 79.35012909673875, 82.80054400044104, 76.71845405332505, 79.5938181108044, 74.81026803293537, 79.52052470176451, 72.69734997903147, 72.40212102090159, 72.04489507982808, 72.06089835013114, 72.33755096312493, 73.42967217968356, 71.27792266107375, 70.91657038657897, 67.99357306572699, 58.121606688345636, 54.049358829375244, 53.139090461115686, 60.07905767809961, 69.26857086919969, 72.25169028005293, 68.38542569068171, 68.3640330837619, 70.60924483883765, 67.95203516560217, 58.494427973224276, 52.64067488331949, 52.634144136982584, 50.38582978710052, 59.54157529338714, 70.01920269381615, 65.14961934858754, 60.759855624168154, 63.59573318112282, 66.00331537185177, 67.57760570895287, 68.03092971924814, 63.288686121663744, 59.5059327156313, 61.13118640838131, 67.37708630100374, 62.170838079144886, 59.86592785004647, 53.74457889987577, 57.66967904183173, 54.75679359128399, 63.29466381380635, 58.356992044756495, 72.30942756898942, 46.50051816817253, 38.75929309475807, 68.8237819363994, 58.071796509527395, 62.79426351670296, 54.96040774929909, 53.145119144070534, 46.113521437491144, 50.046493776382945, 46.57348209811796, 48.0724472384299, 49.12582328242641, 51.116716400269546, 53.17739240584835, 59.23576378053235, 64.58105218025946, 66.2942454122728, 67.3290764900946, 69.32942252005301, 65.37688932111188, 57.91434472607028, 46.90785631056755, 50.45857014194612, 47.25018508972661, 50.49131801051479, 51.690516010407485, 61.076924339417495, 67.77637573980516, 68.35480766911661, 62.21019121908373, 67.1406928954586, 69.2625774875764, 60.562991865219615, 53.4388066107227, 53.80765061224661, 53.38581538969471, 55.252314459893014, 60.7044364560035, 65.1543575717557, 67.39658048076015, 69.46386568007931, 72.0156498878233, 69.55203271681263, 67.45527482801869, 70.31751463490149, 75.2148840504308, 74.1552165246779, 75.0589619913409, 69.5395831138857, 5.485231703327549, 0.5527423658678609, 1.0785262815413938, 3.098005388052233, 3.0055538973500653, 1.0186949985161906, 0.043109016222578865, 0.2180459828025872, 10.979702549595988, 32.608787205911455, 44.372765710276944, 57.316273489306056, 68.32681763556697, 37.05947514503233, 36.40212905022406, 62.043353203804266, 62.19784359778128, 64.62381385987806, 70.8025941541118, 32.97276942960678, 0.3925279467817276, 0.12709485231748513, 0.09701067912242106, 0.009862810331997613, 0.08592203139297425, 0.0417209989691694, 0.0454556392956405, 0.04320717889875655, 0.06406878729561163, 0.026888751514977025, 0.034356442535476345, 0.09180354119669046, 0.0691574382325334, 0.05129254362996548, 0.10610917598129281, 0.03520758920198968, 0.04869673130733352, 0.047149655048645316, 0.08135613204250414, 0.0553117549767898, 0.15768930135715395, 0.12629631290873214, 0.15143483696926027, 0.16371020085869298, 0.13327968697394096, 0.1660285054916336, 0.09785465520596313, 0.213611651392233, 0.06340045602090898, 0.15815701335668564, 0.2115930556770294, 0.3221123623511484, 0.14002044865440938, 0.12702534516011516, 0.1767245944469206, 0.2507565122458243, 0.26743452214906294, 0.3780407644808293, 32.74475812911987, 110.15698140667332, 97.97759840565344, 94.49695771740329, 79.39684452549105, 61.817593343796275, 53.77756211065478, 131.22875413587016, 82.09894964771887, 63.357519795817716, 6.864272336806021, 0.1938103623087368, 0.6067934848608509, 1.2770652602757178, 5.583344890225319, 4.501449292705906, 6.300986639914974, 7.572083155955038, 4.714036362786447, 82.14929719125071, 79.17329295989006, 85.4259354068387, 80.56962536227319, 83.96647637890231, 75.80567929052538, 82.43733252248457, 74.50515470197125, 76.97321199601697, 76.0073361858245, 74.12937594998267, 75.71974016004994, 76.71060931298041, 74.2762294892342, 73.95113560461229, 72.76587378594184, 60.45938245711788, 57.213993764692745, 54.62767700995169, 64.5915602099511, 71.74542211717176, 74.04994010925293, 72.19947568831905, 72.38164624860211, 75.69565680719192, 70.55136634457496, 61.254313530460486, 54.98446756793607, 55.3513111606721, 52.96638458005844, 63.910632825666866, 72.38436837350169, 67.8545799563008, 61.99100917385471, 66.25801840136128, 68.55295796548167, 71.27002300754671, 71.22822623099051, 66.63338922685193, 61.739420506262014, 63.06492274807346, 72.26433600148847, 67.34844515400549, 62.80577959552888, 56.71495845240932, 61.74806933249197, 58.06654837823684, 64.93469307499548, 62.771505924963186, 73.52371492693501, 52.47787298694734, 44.14661361325172, 70.89603285635673, 62.923721344240256, 65.75202872676235, 58.47466707229615, 55.84170156909574, 49.318129247234715, 50.45706787417012, 48.3422984615449, 51.36053093018071, 50.59668071808354, 54.58754331834855, 55.1954871608365, 62.80096684732745, 68.80439758300781, 71.09886646270752, 68.907971689778, 70.66022780633742, 68.46985863101098, 58.8697870316044, 48.24159160737069, 53.48139962842388, 48.61932369970506, 51.86743843939997, 54.464384817308, 66.01520015347388, 71.6607459898918, 70.19148103652462, 63.81754713673746, 70.37498520266625, 73.1393148053077, 62.695078542155606, 56.48874359746134, 56.79153488528345, 57.188070820223906, 58.58766271222023, 62.49938757188859, 67.55331054810556, 70.68408366172545, 72.26174723717475, 74.4664958215529, 73.45128443933302, 69.04971045832481, 70.95293860281669, 77.34475458821943, 79.579878007212, 78.93145530454575, 72.09256756690242, 4.736587539795907, 4.215320723672067, 10.728014842156442, 5.398222746387606, 4.907124840444134, 0.8788301423192025, 0.13380978917402606, 0.4492698729999604, 20.25002637217122, 35.62164014385593, 69.35685557703819, 73.36751045719271, 103.37524260244062, 43.48314862097464, 35.23993076816682, 68.2561679040232, 73.80410163633286, 75.13833507414788, 81.49721099484353, 37.91212389546056, 0.9127361519682793, 0.2598443068563938, 0.3256356926454652, 0.13368447251137228, 0.19036609228820572, 0.18424523363430656, 0.09245222614657495, 0.28657679175657613, 0.2060146945258302, 0.16273130903080588, 0.10319513073491474, 0.20940855596094363, 0.18204351226168294, 0.1543992754792975, 0.2260609172404774, 0.20845126781252124, 0.16411996596763212, 0.14668228795691846, 0.1682271318690431, 0.136636147996591], [0.04039043831008096, 0.11599504268698155, 0.012274683986399925, 0.01686102639312946, 0.03449467544053351, 0.0679753952088856, 0.051551534974526976, 0.026885087699479154, 0.0683560719593398, 0.061499803372087984, 0.03354970981637317, 0.03295886067433223, 0.030369583081694383, 0.08802144172331018, 0.03641873973632052, 0.0472771703836418, 0.15030127198946092, 0.36147322445627184, 52.99041301973405, 72.00802480020832, 81.23683621806484, 59.40688110166981, 61.55505341868247, 39.850390572701734, 34.04476888718144, 60.02815315800329, 66.42224804047616, 24.00556049039287, 0.21469517550881834, 0.030326004170121688, 0.12627508461235032, 0.612189440477279, 2.3907012900998517, 0.5484281876875509, 1.2642305296274925, 1.144685144385984, 21.26022496531087, 90.59984760899698, 70.90856875142744, 83.27637457078504, 74.76370949898997, 78.61051913230651, 74.1863287648847, 79.09369237961309, 74.02895542883104, 77.06483856324228, 72.48853868053806, 75.41772550152194, 67.97284726173648, 77.21266485029652, 72.4949949018417, 66.9036405317245, 59.874200128739886, 53.23059543486565, 49.31250456840762, 53.869404408239554, 62.42017922862884, 68.23670510322818, 70.1840599121586, 65.28102659410047, 65.72816502663397, 65.66095129136117, 57.873850176411295, 48.88069083613735, 49.12967504993562, 48.73264489635345, 48.68367018238191, 56.65933139862553, 64.95892547792005, 64.96658586686658, 60.52359950157904, 64.43513216510897, 66.17919445037842, 65.45731752149521, 62.62747649223574, 58.62780817093388, 58.23427284917524, 64.38161142410772, 65.03186587364443, 57.5679680608934, 56.887558429471916, 56.046359077576675, 56.56998372847035, 54.693364943227465, 60.01305987758022, 58.67461381420013, 71.56813098538306, 43.467310090218824, 31.689367948039887, 69.15500256323045, 56.14357109992735, 62.35302432890862, 50.60720443725587, 48.609533463754964, 43.78500246232556, 48.5750283733491, 52.05234681406329, 53.07286908549648, 45.795805531163374, 47.38697382711595, 45.40281149648851, 50.8875636900625, 58.313081110677416, 64.34606690560618, 53.48961699393488, 68.38953633462229, 61.59781509830106, 58.49356112941619, 47.9371686135569, 47.36404365108859, 46.6703450295233, 49.54292812655049, 47.54974042215655, 54.55279111862183, 62.9236585863175, 65.8927123777328, 65.98342895507812, 65.20824701555314, 60.866446033600845, 56.10070743868428, 47.96669229384392, 49.50762679499965, 48.85683890311949, 55.37020521779215, 56.7827566208378, 62.60427175029632, 62.66786121552991, 68.14463138580322, 63.22973289797383, 71.44206600804483, 64.49157507188859, 67.24873850422522, 66.52271563006987, 72.72795231111589, 67.06530494074669, 76.1964964097546, 45.66844617166827, 0.17878221468098704, 1.9523543600113162, 2.0576810308041114, 1.2406542656883117, 0.5649710290374295, 0.22888770507227993, 0.07940379527187155, 3.10897748316488, 24.75620604330494, 32.13763602318303, 36.171230885290335, 52.69421131380143, 51.192167112904215, 29.313704044588153, 39.04738333917434, 39.947857549113614, 55.03087312944474, 55.40098405653431, 65.00499763796407, 5.578792489344075, 0.529153476799688, 0.20585675783936055, 0.14055519334731564, 0.08230367555252968, 0.042265453826515906, 0.03837802109398669, 0.013195272692809663, 0.04334788626780914, 0.06896265271690584, 0.021529594931991834, 0.05054093093701428, 0.02133989432496169, 0.017864448356352026, 0.051441915453441685, 0.0619538598543694, 0.051362950940646475, 0.01685244620837752, 0.05598646010302248, 0.018584862118586898, 0.06554647514055814, 0.08529588474982208, 0.045632295340539954, 0.0385973175927516, 0.03471847270585356, 0.03824972051886782, 0.0642917073902584, 0.056416744877013474, 0.08322827472922303, 0.06286167404464175, 0.03137665736909596, 0.018003301792627862, 0.12015977243502295, 0.07290212197169181, 0.07783877723399671, 0.0757060497398338, 0.11174307850700234, 0.6160788995123679, 69.71435608402376, 82.03788618887626, 86.71037827768635, 72.31397751838931, 70.20847274411109, 53.38063786106726, 43.930761660299, 68.71769751271894, 71.66098133210214, 25.179753380437052, 0.45911977187760417, 0.11319826251917309, 0.6327519145223403, 1.9093227722952444, 1.8905317999662894, 2.291492291035191, 2.74875141920582, 0.9518722745199358, 22.035357875208703, 93.63478937456685, 74.02119698063021, 85.90690428210844, 76.86310322053971, 79.88038647559382, 76.76333381283668, 80.96878144048875, 76.33748992796868, 78.45879400930097, 74.51302297653692, 77.87403137453141, 70.6913165123232, 76.70123484826858, 75.9072216095463, 69.66778186059767, 62.82301449006604, 56.172333840400945, 52.817950325627486, 55.206281523550714, 65.27696301860195, 69.74101251171481, 69.95795880594562, 67.58215565835276, 68.15137001775926, 69.14019953820014, 61.13123739919355, 51.64005079577046, 50.897400994454664, 50.4831124121143, 49.23199399825066, 58.39136769694667, 68.57352687466529, 65.94477007465979, 62.124863978355165, 66.51404719198904, 66.93874574476673, 67.72893075020083, 65.62526556753343, 61.26081289783601, 61.84398697268579, 66.39766262423608, 65.8695625489758, 59.314987813272786, 61.160396299054554, 58.609867249765706, 57.962817376659764, 57.71217792264877, 61.40352833655573, 61.131464896663545, 72.48594991622433, 46.22872144945207, 36.42487095248315, 69.71574460306476, 57.89084580636794, 63.96441244309949, 54.29950014237435, 53.814314719169374, 46.343607671799205, 53.22795960210985, 54.51136304486183, 54.32333246354134, 46.86216854280042, 50.221353038664795, 47.0486693997537, 53.206268895056944, 61.69181077711044, 65.87841141608455, 58.44619850958548, 69.25612126627277, 63.29875484589608, 61.74287219201366, 49.46943075426164, 49.116809675770426, 48.01847934722901, 52.6291117360515, 49.2950657106215, 56.9002551417197, 63.74943910106536, 68.70094899208316, 67.16364660570699, 66.25542179230722, 64.28223033105174, 58.94550446541079, 50.513334274292, 52.682530495428274, 50.587117979603434, 56.990842280849336, 58.03245513669906, 65.67777041466006, 65.69067109015681, 71.85924929957237, 66.4710815491215, 72.84655694038638, 65.9859549614691, 69.01769607297837, 68.77454050125615, 75.54272359417331, 70.9017438273276, 80.7441629902009, 51.11284109853929, 0.3458173903486421, 0.9178443649603475, 2.605708952872984, 3.4562565386295323, 1.7005467751333792, 0.3195424438003571, 0.09336757864202223, 0.6073549966658316, 33.25240304393153, 33.31051688040457, 34.96187002428117, 58.458491217705514, 41.56332885065387, 33.76360162611931, 51.50443484706264, 45.51310854573404, 62.94163088644705, 61.015990318790564, 79.6514847970778, 10.207334910669635, 0.6568106912797498, 0.1093652411814659, 0.15893045572503922, 0.01863940566357586, 0.05287028255782301, 0.06314062197963077, 0.040300204643919584, 0.03373597643428272, 0.05344900069758297, 0.052941980726656415, 0.03706379725988354, 0.09518417229335155, 0.03276741147161492, 0.09264436865886373, 0.05583198996441019, 0.054096367976237694, 0.01236092824969561, 0.015890501202985404, 0.046410288271163745, 0.2081852207981771, 0.15803528198551747, 0.1604007469910768, 0.1003181028570379, 0.09131611009398777, 0.1410827981007676, 0.20526553714467635, 0.138899187046674, 0.1990292443623466, 0.15736549131331906, 0.11298937332485953, 0.08036965594416665, 0.1815374958659372, 0.14969007172171148, 0.18628863527649836, 0.2012448932134336, 0.21767777030266103, 0.8415939178197616, 85.27868178582962, 93.02134636909732, 100.95726613075503, 79.08067795538133, 81.58482889975272, 54.00989586307157, 50.760035668649984, 70.97696704249229, 82.99314806538244, 41.86592401996736, 0.576125514363089, 0.24183722633507945, 0.6479782490961014, 2.860944934429661, 6.473880304444221, 3.5157959115120674, 7.1069670300329895, 3.6887221807433717, 23.937799584481027, 96.18899760707733, 76.08233190351918, 89.64769224966727, 79.59808564955189, 85.41626284199377, 80.96125833449825, 85.46816364411386, 80.71276049460135, 81.49190795037055, 77.38929702389625, 82.03682714892973, 75.65425226765295, 78.8775933173395, 79.15965095643075, 74.95738044861825, 65.32363530128234, 60.152947287405695, 55.516591994993156, 60.37957399122177, 67.59120848871046, 72.02833483296057, 72.79747240005001, 66.94831632798719, 70.36449678482549, 73.00824488362959, 64.47225347641977, 54.05713296705677, 53.56795457101638, 54.53015512035739, 51.87075676456575, 61.84984307135306, 69.74076932476413, 69.74353067336544, 61.98431761034074, 67.71866982983005, 71.32309267597815, 69.27902790807909, 67.43772614386775, 64.2501727996334, 63.08909239307527, 68.26135327739101, 68.97095711000505, 63.05649357457315, 63.61640014956075, 61.01581773450298, 61.01237781586186, 61.70077339295418, 63.09812168921194, 64.07774540685838, 75.17302451595184, 50.99538964609946, 40.96582635756462, 73.21941744896674, 60.50891022528372, 65.85090775643626, 57.073667049407966, 54.56729604351906, 49.37101456426805, 55.60097786688036, 58.88187577647548, 55.63036034184118, 49.33783131261026, 52.97128754277384, 50.41672237457768, 56.19858234159408, 65.10406101903608, 69.35462767078032, 62.26013083611766, 69.44899205238589, 66.77359827103155, 62.10848808288575, 53.37099275281353, 51.64287490229453, 51.56542378087198, 55.48156522935437, 52.437409816249726, 61.0694286900182, 67.84445239651588, 70.50456462367889, 67.88083630223429, 70.3364126143917, 67.51379659098964, 62.026663518721065, 52.862218195392245, 55.99641946054275, 54.17610629912346, 60.56239174258325, 61.28248007066789, 69.05561754780432, 67.48309227728075, 76.53625211408063, 68.2699981812508, 74.7315852872787, 69.81035217162102, 70.71299937463576, 73.58094230774911, 78.03296581391366, 73.48349494318809, 81.62105591066423, 53.833569634345274, 0.19985455088317397, 8.685522944696489, 8.60629597017842, 6.2161335156809905, 1.9527104376785218, 0.4225423829930444, 0.18489299161780268, 5.043305120160503, 37.073317189370435, 45.914057147118356, 45.389055744294204, 63.49858391669489, 63.74906255352882, 40.20179179406936, 53.561298308833955, 54.72115101352815, 75.11739746216806, 70.0961046834146, 90.33573873581426, 10.967755990643656, 1.0716795392574803, 0.2639431836864641, 0.25447292734057675, 0.17777539128738065, 0.1751093287020922, 0.1782814230048849, 0.10832988867355932, 0.11267682477351158, 0.1417550555760822, 0.1281141476224988, 0.18112999837725394, 0.2334002847032201, 0.11621222861351506, 0.15524489865187677, 0.220017479432206, 0.20748752920377642, 0.14035843132484344, 0.1726609116960918, 0.1562937343072507], [0.010713527031663445, 0.0662310206661782, 0.10057163965557853, 0.06813202954588399, 0.02213431792634149, 0.04538427437505415, 0.016952137229964137, 0.060854810965998526, 0.04042265613773658, 0.013418570085759125, 0.1166123103710913, 0.08436910988342378, 0.056169949652206515, 0.003865456542811327, 0.07046583213753278, 0.15117916278541088, 0.28050765935932437, 10.685129607877425, 80.03655172163441, 72.02453013389342, 61.25894584963399, 49.682211491369436, 65.20068468586092, 25.985490583604385, 30.814414639626783, 27.111512845562352, 41.761887073516846, 4.67251415214231, 0.1202785467068034, 0.023872040910646323, 0.10853658685640943, 1.9553521539895766, 1.13886532764281, 1.5247249386964308, 3.41297808674074, 0.39855843770407867, 52.9180335229443, 80.62074953509916, 76.17292296501898, 70.34997617044758, 74.14302579818234, 83.23285979609336, 76.95603985940257, 77.02255541278471, 73.50688795889579, 73.22694055495724, 74.85589304277974, 70.8557971831291, 77.95366333376977, 75.96278590540733, 61.9662590180674, 70.15917639578544, 57.88783734844577, 51.27896132007722, 48.19596267515614, 57.93365063205842, 68.55032213272588, 67.51858972734021, 58.29223763558173, 62.36933354408511, 68.44337478760751, 61.37432629062284, 54.58513498306275, 46.472190810788064, 48.7153668557444, 44.923242907370295, 45.441972440288914, 56.227298013625614, 65.48653133453863, 62.84396386915638, 63.78089258747717, 63.977956387304495, 62.5653539934466, 61.30249200328704, 62.6127048461668, 62.702711474510934, 61.35958602351528, 62.947279099495184, 61.502144567428104, 57.24880087760187, 57.306969627257324, 58.69899918956142, 58.537946670286125, 55.82251333421277, 60.00497587265507, 55.815951208914484, 71.16640967707481, 38.316418278601866, 38.21200478461481, 63.747524984421275, 57.77142140173144, 60.12282740685248, 46.23525611815914, 47.912791082935954, 48.18086154999272, 58.432372154728064, 60.50108509678995, 62.84672914012786, 50.08089688516433, 46.19774649220128, 45.021655174993704, 48.47871065139771, 52.06667130993259, 66.47953817921301, 56.785368919372566, 54.021435476118526, 66.92135395542269, 60.48718421689926, 52.786218350933446, 44.88762386383549, 46.08115796119937, 46.54656287162535, 47.25600196469215, 51.20367926935996, 62.6947255288401, 63.382830850539676, 65.78831065085627, 64.25189079776888, 64.51442287814233, 53.45962655159735, 47.67305974037417, 48.50214289080713, 49.876113860837876, 50.98683103438347, 55.905342025141564, 58.73384944854244, 63.15166596443423, 66.42480542582851, 69.9915264498803, 67.29357904003513, 65.99246609595515, 63.84118726176601, 69.12583581862911, 66.29244896673387, 73.63547894262499, 65.34607125866798, 78.85986420416063, 18.742983110489387, 0.5777373020687412, 1.0711407036550584, 2.3236032647471276, 1.1666630424799458, 0.3442134167398176, 0.06998314311908138, 0.09029274686209618, 9.934423258227687, 45.817202060453354, 41.38402946533696, 25.313680748785696, 64.63579670075448, 33.917613490935295, 26.962162717696163, 37.57692206290461, 50.79676474294355, 58.14372493374733, 66.27438252972019, 33.46667428170481, 0.5652455336624577, 0.026192923429452127, 0.0725601020178968, 0.06740270618108973, 0.048876057168649095, 0.08613980720720946, 0.02114132050454857, 0.02631475439205045, 0.02398030828654526, 0.002175344965390621, 0.082651226661138, 0.02192135122905095, 0.012233333433076981, 0.019110915543992194, 0.031285297553685885, 0.033511248372134664, 0.08473936017722854, 0.02610124185711386, 0.012176855516079213, 0.027793443896957946, 0.057960477161912195, 0.05783242173492909, 0.046071761678303444, 0.08543192664341581, 0.07275662655311246, 0.04471407001537662, 0.031152272131294016, 0.014583108000337117, 0.03100828399070569, 0.04601817765843965, 0.03199852732641082, 0.05736836014435657, 0.01685755793005228, 0.09266610257327558, 0.0662253286329008, 0.3349636098550212, 14.617411609618896, 96.43432617187501, 77.24848393471011, 76.43093647495394, 54.287631050232925, 78.38407285751836, 33.75777298404325, 28.94257526243887, 31.69957199404317, 48.52441410864554, 5.894568783621635, 0.09058169990537629, 0.11049634701902829, 1.0381069923600843, 1.4767353525084834, 3.0641722486865137, 3.2687498388751863, 1.8409529184141469, 0.7316799125363751, 57.034729680707386, 82.90174115088679, 78.6355281645252, 75.3988589009931, 77.52062582200574, 82.83960296261696, 79.87407145961639, 79.41483251510128, 76.24343933597689, 76.83512103173041, 77.0083172090592, 73.55548612533077, 77.7142418584516, 78.98262654581379, 67.91612978904479, 73.08507627056491, 60.62573409849598, 55.13446684806578, 51.67297909336706, 61.01561769362419, 71.91788088890814, 69.48261460950299, 62.54015668745964, 63.893539136455914, 72.30941972424908, 63.52907250004431, 57.49927559206563, 49.599492626805464, 50.627483091046734, 48.0339374080781, 49.395854934569336, 56.947041173135084, 68.00061764255648, 64.21472241801601, 66.67339740260955, 65.46477786956295, 66.13826844000047, 63.3732916462806, 64.35722604874643, 65.58979165169501, 63.003165029710345, 66.23205231082055, 63.68785396698983, 59.400526861990656, 59.75850197576708, 60.11689286078177, 61.635658125723566, 58.83010441257108, 64.87368845170545, 59.84217397628292, 72.77651125384916, 40.03269057120047, 41.491722060788064, 66.16106525544198, 60.78280541204638, 62.661185341496626, 48.94827719657652, 51.63805823172293, 50.43125475606611, 61.636976042101466, 61.91758632659913, 63.759664720104595, 53.45518642856229, 47.75702199628277, 47.50182082576137, 50.21346907461844, 53.09194749401462, 69.46261836636451, 60.3293284293144, 57.88504069851291, 67.89256418904951, 63.61430168151856, 56.139817391672445, 48.31199422959359, 48.07351412311677, 49.39535679355745, 49.41259561046478, 53.89258561595794, 63.98768386533184, 66.6085135552191, 67.89067360662645, 67.9345884630757, 67.02211964514949, 56.71350325307539, 49.61425642813406, 52.203950343593476, 52.638992186515566, 53.500019119631865, 58.5941699243361, 62.404603496674575, 67.22600444670647, 69.17638732540992, 70.47065965590939, 70.82554001961985, 66.87782349125033, 66.87369715782904, 71.77753063940233, 69.30912817678144, 74.32856959681358, 68.49450680517381, 81.764387161501, 23.610893564839518, 0.5954331976752127, 0.857471488416195, 3.915602122583697, 2.7675523200342735, 1.2598339203865299, 0.05587265774187061, 0.32552384380852023, 7.594901544432487, 56.01166179103237, 34.33977819258167, 37.6307487487793, 60.6783526943576, 32.40083490648578, 36.61535301516133, 49.21662222954535, 59.58445072174073, 68.59630015588576, 75.36916655878868, 46.039106230581964, 0.440693028391369, 0.03990552380620953, 0.060706687865838896, 0.07757812347863952, 0.035719676844535336, 0.04970954167806814, 0.04913661899345537, 0.09211890895159976, 0.022644434807701938, 0.03751206977833663, 0.058917891714842095, 0.05833811254330701, 0.01713781587539181, 0.01578095254503311, 0.04105161815401047, 0.046748768898748586, 0.002104386071404142, 0.025464959870723468, 0.004008173935055252, 0.154824638138375, 0.201862023001717, 0.2530462877644647, 0.172633531713678, 0.17562508973623478, 0.19548187422896587, 0.19769220642985838, 0.16333820388442086, 0.1947756177715717, 0.09181259635595546, 0.21271681473139795, 0.1890846416955033, 0.3021641376037752, 0.14409681782126427, 0.20213413743242142, 0.3628656045804101, 0.44804722731632574, 18.03137690790238, 107.8768527123236, 89.80434386960923, 85.88921439263129, 63.66208399495771, 83.55196029909196, 34.88129277383128, 46.742818663197184, 40.94798741802093, 63.46526338208107, 8.582931391654476, 0.2922898464866223, 0.18940947829715668, 1.5541539918030463, 6.231211106623373, 4.125224861406511, 4.774747298609826, 9.48042852263297, 1.0491871978006055, 59.58695319391067, 86.45918969185122, 82.55860436347224, 79.55188012892201, 77.84001658039709, 83.81168396242204, 83.24422682485273, 80.5923358855709, 76.49784426535331, 78.92652096286898, 79.9287728340395, 75.06378650665283, 76.6529583161877, 81.6944513013286, 71.70253492170765, 75.21864952579622, 64.82435680204823, 57.961224894369806, 54.64197404922978, 63.06111804900631, 76.20705543025848, 71.40013587090277, 64.90187460376372, 64.13713401363742, 75.32010555267334, 67.85617243859076, 60.032373628308704, 52.571570565623624, 54.46182350958548, 49.81142613195604, 50.573048437795336, 60.64442811473724, 70.9646821791126, 66.23886154543969, 69.92420288824266, 68.82037731908983, 69.89412615376135, 66.23111878671955, 68.82650406129899, 66.03333719315069, 64.5701519135506, 69.92319876147856, 65.87202579744401, 63.25460856960666, 63.08292642716439, 64.94271432199787, 64.11593360285606, 61.42754108675065, 65.84180001289614, 63.10382873781266, 74.43492074166575, 42.57900699492424, 46.82421568901309, 69.35793815120574, 65.79139755618188, 64.39217044461158, 52.53025624059862, 54.29143574930007, 53.47175059779998, 64.89442994517665, 65.8901628371208, 67.79589345378261, 55.56324858819285, 51.33682020248906, 52.47077349693545, 52.082698114456676, 55.655067351556596, 72.75518140485211, 63.514081201245716, 60.56759280543174, 70.09773638940626, 67.74418877017114, 59.30435426773564, 50.74903734268681, 49.68404323823991, 51.16829949040567, 51.428391856531945, 58.55195737654164, 67.62667455980855, 68.85742018299719, 69.97840219928374, 69.77556859293293, 70.25898502719018, 59.25530502873083, 53.26230779770882, 54.975563787644916, 55.44705621657833, 55.30801603871008, 61.49375853999969, 64.94020008271741, 70.1034708945982, 71.32945476039764, 73.73218105685326, 71.86321089344641, 71.0807058888097, 69.48430122867708, 73.90420052313036, 73.7279841207689, 78.13360598779495, 71.03225677244126, 85.13641741967972, 23.658236572819373, 2.555508007926326, 8.958179643077235, 9.725336413229666, 5.789146259907754, 0.9653189562020764, 0.16858215233491314, 0.6294312604492711, 13.405794405168104, 64.93478721187961, 56.81342171084497, 34.925795985806374, 76.82721353346302, 47.1673289422066, 38.53640440971621, 54.15865567422683, 68.11729246570219, 77.41010127529022, 85.26205878103934, 53.91342909105363, 0.709290104287286, 0.21379601811209034, 0.14453960131973992, 0.18922408501948082, 0.15053995434314976, 0.2309437624869808, 0.15071370308437657, 0.20875442412591752, 0.15646487834953493, 0.11025509827079312, 0.21942938437625287, 0.10960000882586164, 0.11278256788970002, 0.10521460745123126, 0.15353944903660208, 0.11364896736678579, 0.12562362642417993, 0.08340311897618156, 0.11692308159845492], [0.04503402280651274, 0.022154557969300978, 0.048034095896347884, 0.060449178901410876, 0.0033458313132981744, 0.048499321940565304, 0.06362369404204431, 0.017044466146598422, 0.035732309634406725, 0.0528729830177561, 0.028756803292180264, 0.06845524204113791, 0.02170728519558907, 0.06410682356105217, 0.0592223427168304, 0.056871804934475696, 0.045042024594881845, 36.382121039975075, 83.30889101951354, 69.13642621809437, 57.80910361197687, 76.30982152877316, 45.37675126906365, 30.98621249198914, 49.08294785407282, 41.61243692521126, 31.983022074545588, 0.7603542771070235, 0.16773596225726992, 0.06816746111238195, 1.024672874519902, 1.356128475839092, 1.3940764266637065, 0.8342528956071024, 2.6086259705405084, 7.804959176048157, 69.21111599091562, 75.03915402197069, 79.3798763521256, 75.80017228280344, 72.842132506832, 72.05258292536583, 77.30642518689557, 67.41099126877324, 72.32848244328653, 70.16363220830118, 71.43962629379766, 72.58804921180972, 70.68176161858344, 61.09175089866885, 71.33278877504411, 65.97294053723736, 54.74787019914197, 51.65960773344963, 48.67637849623158, 55.96713504483623, 69.05034588229272, 63.616611957550056, 68.20495743905344, 65.23951615056684, 66.3648166964131, 59.27117886081819, 48.71137388290898, 45.03980398178101, 47.56196252761349, 44.856688130286436, 47.8275619014617, 54.45518685925392, 62.63575269329933, 65.6436457941609, 64.81815945717597, 63.07945905193206, 59.63896774476575, 57.43031247969597, 61.47719044839183, 59.172225306111, 62.5864798791947, 59.12287012223275, 61.44421115998299, 56.88873906289378, 60.25556041348366, 61.93468393818025, 61.981081654948575, 57.58070007447274, 62.48058372928251, 57.469418510313965, 68.2668524403726, 45.67902872639318, 37.422823905944824, 65.81646934632333, 57.78186275113014, 56.006445038703184, 48.62458359810614, 49.455172938685266, 53.63358366873957, 61.22492321075932, 60.18414189738613, 63.874088102771395, 57.18303841929282, 47.96406822819864, 46.58458240570561, 44.442846698145715, 49.627949422405614, 56.37931339202389, 63.67203897045505, 48.784173073307166, 62.56074520849413, 64.08011451844247, 53.411291183963904, 47.287949669745664, 45.69352972892023, 47.828966109983384, 45.54479737435618, 50.92789742254442, 57.91035175323487, 64.1144117232292, 64.79792787182716, 65.39882713748564, 63.03890566672049, 54.12682956264865, 47.245340962563795, 48.47841255126461, 49.58055150124335, 51.516335318165446, 54.215035823083696, 60.30268769110403, 62.97845017525458, 67.92879904470136, 64.54918292260939, 67.97615774216192, 63.83350333859844, 62.819092119893725, 65.29621793377784, 67.48714016329858, 67.19329187946936, 70.55519457786315, 71.64660192305043, 67.13846498920073, 1.998404579297189, 1.60400633610064, 3.1018860830414683, 1.6880868759847458, 0.6183702991374078, 0.02653845781159978, 0.013929408047378305, 2.1494899882424265, 22.38557061841411, 41.81065390186925, 41.627032064622455, 53.12446394274312, 84.34493018734841, 25.78544382126101, 24.577173379159746, 39.07363968510782, 57.16768626243838, 56.08997583389283, 64.07154413961595, 12.583332215586017, 0.4338384413671109, 0.08902797400350533, 0.027585119692488547, 0.05736728762126258, 0.09604107994105547, 0.024783386766249617, 0.07943770998427946, 0.03642021062513513, 0.005579464796615104, 0.0305394669093432, 0.008901854537637725, 0.03806086069333457, 0.020938378067747242, 0.09090238431048009, 0.05751554478680896, 0.005331266194491858, 0.042221254383724545, 0.03031614653375601, 0.05645992159242592, 0.0463445617577001, 0.01907976640899095, 0.04051977693433723, 0.043727417716816555, 0.03762561933047349, 0.07154280620236551, 0.03432902041822672, 0.0855590665953294, 0.01880709464932161, 0.14656953513622284, 0.0586932287701676, 0.03609250885464492, 0.0795667574951245, 0.08100738583673393, 0.06690415148172649, 0.013158009218562756, 48.45158353928597, 91.75875110010948, 76.3635423106532, 65.02127939654936, 77.51886860016855, 63.94221967266452, 39.809990159926876, 41.48817623815229, 44.00461989064371, 43.0126642411755, 1.5439047159687167, 0.11836485141107153, 0.2580952668382276, 2.9176852058979774, 1.6867864876985552, 4.201140865202873, 2.5442243295331157, 1.1894662317729767, 8.876859103479694, 72.73158442589545, 77.67139388668922, 82.83610420842325, 80.20369175941714, 77.16614554005285, 74.93552500201811, 77.42748521989392, 67.76719739360195, 72.26855647179389, 69.60863251839915, 72.40434892715948, 73.48936280896588, 73.36900880259853, 65.53823209577992, 72.29850769042969, 68.78360902109455, 57.82495783221338, 54.39075800680346, 51.07255051212927, 59.33476832605178, 70.82404951895438, 67.34446002591041, 70.66239295467254, 67.69165254408314, 70.27389003384498, 62.081184464116255, 52.08114093349826, 48.039758205413825, 49.2290835995828, 46.55374473141086, 50.949274339983546, 57.35618360580937, 66.73329983988117, 65.61321604636409, 67.43567082189745, 64.84149363733107, 62.33493828004407, 60.48570940571447, 63.31807251899474, 62.00091315853981, 64.23805659817111, 61.507420155309866, 65.89216324590868, 60.32788499709099, 63.263779071069536, 63.24750907959477, 65.03139126685359, 61.53766947407877, 66.56200208971578, 60.28524098857757, 70.40918827056885, 46.80109331684728, 39.06779143118089, 67.27288461500599, 60.20123950896725, 58.247032319345784, 49.98982337213332, 50.31143026967203, 56.24055170243787, 62.5865504818578, 63.281198317004794, 65.75120110665598, 58.64311325934626, 49.37036737318962, 47.897007465362556, 46.44219644608037, 51.574919839059156, 60.19461854811638, 64.79109510298699, 53.07231603130218, 63.36131272777435, 65.88922931301978, 58.212550763160955, 49.375784166397594, 47.46621747170725, 48.31530078764885, 47.70178717951621, 51.93203987613801, 60.69794885573849, 66.54934067879954, 67.77890174619614, 66.82348297488305, 65.28589817785448, 55.89935256588844, 50.02256339596164, 50.51631135325278, 51.77887916564942, 53.49040931270969, 57.57347506861533, 62.40268545766031, 66.20395245090609, 69.54041465636223, 66.89997703798356, 69.62332571706465, 66.1933385172198, 63.93474755748626, 67.71513185193463, 70.6750229866274, 69.85426702807027, 71.28233140514743, 72.94243535687848, 72.7543027939335, 3.1569203686329628, 1.5730034319623825, 2.292635907088557, 3.379340820735501, 1.9785176722272753, 0.7483958284701071, 0.0938398105603072, 0.5591579538679893, 25.065531999834125, 46.52198530012562, 32.475546252342966, 60.14924456996303, 70.9574414837745, 28.28097143480855, 35.57125337662236, 47.62406933692194, 66.9018283967049, 63.468534638804776, 76.1478276406565, 18.030486529873265, 0.5088981427252293, 0.12771082531300285, 0.05810986430714688, 0.020227350797804616, 0.12833173191475292, 0.02914592807721948, 0.0041281198425548934, 0.0635847499624135, 0.03154688785153051, 0.024289903568945104, 0.027625816198246136, 0.02882382257901613, 0.02850249466005593, 0.12123244108572123, 0.0184747580468895, 0.12540037308128613, 0.02794161296239303, 0.07256801570615462, 0.0959273465278168, 0.15262464812446028, 0.17654503875922772, 0.12786071041538832, 0.1871672002298217, 0.1586825190292251, 0.17409522747320516, 0.11474926880891285, 0.15850708489456486, 0.12702612656979792, 0.19299599552346816, 0.12993047314305461, 0.16213590549605508, 0.22867503906449965, 0.13635123989755107, 0.2359949785374826, 0.37975762880617575, 60.817475241999475, 103.96398252056491, 89.92655707943825, 76.06949006357502, 91.8802269043461, 61.19160659851567, 43.516849625495176, 70.28469224129954, 59.89047404258483, 53.211030652446134, 1.9742565073313254, 0.45844156955999715, 0.42837038155524965, 5.353936245364528, 4.689801998676793, 3.4511425033692396, 5.877716320176279, 5.443620749058263, 10.336630940437317, 75.64728613822692, 80.81831932067871, 85.9898781007336, 82.85605338311966, 79.99850473096295, 75.32580083416354, 77.31337562684091, 69.53792002893263, 73.42221183161583, 71.92677682445895, 72.52507948106336, 74.60998396719657, 75.90030254856234, 73.23921757359659, 74.99383495699975, 71.51005637261176, 59.343903526183105, 58.334332512271025, 53.95121328292355, 62.422842517975845, 73.3456628553329, 69.38923866518083, 71.66922615420434, 68.35095590160739, 71.5257066295993, 65.39731310259911, 54.17892256090718, 50.58563924604847, 52.659639543102635, 49.988376017539736, 52.98046196660688, 59.41988768116121, 69.66018815194407, 68.11832797142768, 69.99184808423443, 67.51080774491834, 65.15222772475212, 63.56595846914477, 67.42160520245953, 65.47605860617854, 67.06539907763081, 64.00396170154696, 68.04900400100216, 63.10118898268669, 65.15093334259527, 68.94878787379112, 68.02939215014058, 64.34959311639109, 69.42059409233832, 62.702099584764056, 68.99329108576622, 51.70012189495949, 43.322437347904334, 69.84969354444935, 63.270411799030924, 62.195980471949426, 54.16633567502422, 53.99884262392598, 58.1424109397396, 66.96594345954158, 65.94542118810838, 67.921825070535, 63.62313093677644, 53.07833686951668, 51.57601810270741, 48.89141851855863, 55.700009868990996, 62.59081409823511, 68.71828586824479, 55.39184101166264, 65.41430873255577, 68.35270527870425, 59.25970985043434, 51.86905445591096, 50.224918473151426, 52.606420824604655, 50.378385128513465, 55.55893005863313, 63.928228578259876, 69.4020648156443, 69.1436198449904, 69.17834066575574, 67.72320408974925, 58.3193451358426, 53.094320527968875, 53.86396800318072, 55.50895514026765, 57.80855840252292, 60.84178609232749, 66.42083598721412, 69.47814310750654, 72.46300405071628, 70.72350348195722, 72.51812904111802, 69.46406179858793, 67.87138339011901, 71.64423281146635, 74.40974696989983, 71.8560564902521, 75.96928135041269, 74.38556948015767, 78.34268400746008, 2.5215812219727427, 6.277400937772566, 9.85810079882222, 7.397880400380782, 3.7584045577433804, 0.5801008978197651, 0.2004910167306662, 3.7907415580364967, 33.26277771303731, 56.94561343039236, 56.00624107545423, 63.33566827158775, 93.74307817028415, 34.56542430385467, 36.91542610045403, 57.291476265076675, 76.0952365013861, 71.38491707463419, 86.82568027127175, 19.880901921179987, 0.8690263006475665, 0.21767090615485946, 0.12074984399782074, 0.1804710095447879, 0.24943956113871069, 0.12883774064961942, 0.2148159722527189, 0.20027949985477234, 0.051655148366285916, 0.12649229352152155, 0.133383966862194, 0.19091839571633648, 0.15546822860356302, 0.2081696845350727, 0.08140283276236827, 0.2549372838750001, 0.14977100125003248, 0.29485375890808724], [0.026294320911890077, 0.046648882524741274, 0.10046240317845538, 0.017921255691157236, 0.06528854865821139, 0.14720350353708192, 0.08518995777253183, 0.020208449493492806, 0.057838029498534824, 0.06054526164887413, 0.10087969127081095, 0.042086269691466324, 0.11563827554064414, 0.030269486033507896, 0.13638218984969203, 0.3147030050956434, 6.036494355047903, 79.82013886974704, 73.0803458921371, 70.84689340283795, 77.12765139918174, 48.23146796995594, 14.530531110302096, 28.95574462029242, 38.86223962230068, 40.29886653346401, 12.75596357160999, 0.11412175852925548, 0.058843489255635976, 0.9168417703720831, 0.7552800171317593, 0.4757363108857986, 4.509878956502484, 2.80098170042038, 0.37965160223745537, 26.169133993887133, 75.43500746450117, 71.7613547848117, 77.25829770488124, 68.41609078068888, 80.50660071834442, 77.41094066250709, 62.523090454839895, 71.10323598307949, 67.10119462782338, 66.85173188486408, 66.14949426343365, 64.0183058092671, 63.10065946271343, 70.46633720397949, 69.85326290130615, 65.2103494059655, 48.20445068420903, 49.92860301848381, 47.1298820741715, 54.34669017791749, 66.78695786383845, 65.74170504846882, 71.71478840612596, 66.39671341065439, 64.47133956416961, 58.341965444626354, 50.25339488060244, 46.558561401982466, 45.915892816359, 45.40960111925679, 45.82545080492574, 50.848743992467085, 59.53189096143169, 57.18514473207536, 61.62638172026604, 54.556678187462595, 51.3377498042199, 56.218205959566184, 61.399417692615145, 58.07522858342817, 60.10133281830819, 59.08285017936461, 59.85304678640058, 61.32557122938095, 63.88556103552542, 61.779228641140854, 61.53948160909838, 62.12393437662433, 64.60418631953578, 60.148832721094934, 60.160384101252404, 39.306667697045114, 39.07343572185886, 65.28746320355323, 57.92620597347137, 59.51757431030274, 50.22263565371114, 55.00021588417792, 52.15079438301825, 62.276953881786724, 62.05748158116495, 61.134779299459154, 58.59298144617389, 49.86455463594007, 42.85136853494952, 47.16569723621492, 46.42485956991873, 54.15241910565285, 61.80938382302562, 57.523209894857104, 57.369382381439216, 67.13184402834985, 55.388769795817716, 49.71049962505218, 45.68916413091844, 48.203171991532855, 46.117353593149495, 47.82634988907845, 55.69406355580976, 63.123220935944595, 61.3084343940981, 66.3656403941493, 62.84429727062103, 56.528610567892756, 46.38414144515992, 49.44626523602394, 47.50022049873106, 50.47576973515172, 52.31964849656629, 58.99647566580004, 60.127632310313565, 66.72080316851216, 63.99334776786066, 65.83899159585276, 61.89098873446065, 65.01301104022612, 61.74478238628757, 64.64051923444195, 61.766394645937034, 66.06066826851138, 67.33259093376898, 78.87915442066809, 32.55493306344555, 0.1635084132994375, 0.7179431593225849, 3.746431032496114, 1.2927368451510708, 0.2869915211152646, 0.11717595956138066, 0.13927879893491346, 12.385983063328652, 30.841004387024913, 64.30677652359009, 87.97219691738006, 89.9476594309653, 67.09046302303192, 23.99034365530937, 36.704594781321866, 44.18145210512223, 58.85198339339226, 63.333738465462964, 48.26857751415622, 1.145979771690984, 0.021833860157658497, 0.041157882209987416, 0.18370630610133373, 0.03938019050345306, 0.07500844241510476, 0.019999556468739625, 0.04639237330505445, 0.06507734587836651, 0.038495623251242984, 0.05436452173237359, 0.03527511602207538, 0.026153950621524168, 0.076164469092844, 0.057839569335262624, 0.0658322872233487, 0.02589638611572164, 0.03286235657851062, 0.05387355513390034, 0.02705037116914267, 0.07125524743910759, 0.06064448918726656, 0.025194210991744074, 0.0297090161081043, 0.003414138346054261, 0.033890013733217796, 0.1307953251225333, 0.036166080108453194, 0.12036290064814592, 0.04312850549937256, 0.04744228148352235, 0.07521003079149993, 0.10735922462997899, 0.34512552102246596, 9.028846044694225, 94.9259473431495, 79.84033907613447, 80.82822722773399, 82.6505054966096, 61.91011421142086, 24.586259549663914, 30.13582891033542, 29.108650376719815, 44.90926750244633, 16.919951746540686, 0.10632350439986876, 0.08933238670109742, 2.3841744661331177, 2.9730396549547873, 2.4530512863589875, 6.295499244043905, 0.8929166606357022, 0.7241026900949017, 29.74771038178475, 76.7595761822116, 74.14230408207064, 79.29910690553727, 71.0472245370188, 81.12711967960482, 76.60406989435997, 65.30697699516051, 72.71955059420678, 69.25846684363582, 69.14409837415143, 68.50490108613046, 65.66028448843187, 67.51311409857966, 71.52063108259632, 71.60802933477586, 64.9799140807121, 51.978551341641335, 52.4496829125189, 48.72859308796544, 56.61606765562489, 67.86328761808335, 68.10094402682397, 71.43440954146847, 67.01272164621662, 67.91001089157598, 62.385007335293686, 53.36952186399891, 50.125992375035445, 48.57786424698369, 48.86911592175884, 49.14151276311567, 52.85347130990798, 60.63344155588458, 59.664812241831136, 63.3141815277838, 57.38041600873394, 54.815417335879424, 58.73955649714316, 65.65065899202901, 61.84007244725382, 62.54340833233249, 61.97201313511018, 62.534555542853575, 64.25140442386751, 65.60146462532782, 63.86166595643567, 64.76425040152766, 62.98100363823676, 67.40042440352902, 63.063424402667636, 61.18360496336415, 40.904656994727354, 42.59475531116609, 67.59447190069383, 60.89846041894729, 59.3219147189971, 53.67467049629458, 56.424659913586034, 54.9878917970965, 66.46366826949581, 65.08253505153041, 64.21303579884191, 61.78504551610639, 52.71561568783176, 46.83011885612242, 48.82285156557637, 47.986417893440496, 57.97007768384872, 65.72931428109446, 59.953953681453584, 59.03124747737762, 69.76181676310878, 59.36672779821581, 51.856961788669715, 47.61194921308949, 50.07898669089041, 48.61777044111683, 49.2120252117034, 58.86067928806428, 67.29964302432153, 63.36834553749331, 67.69137797817108, 66.04372362936697, 60.191598323083696, 47.95024971808157, 51.649570388178674, 48.68862413590955, 52.77509058675459, 55.20491653873075, 61.99940304602347, 63.89004822700255, 69.05604116378292, 66.54777173073062, 69.31018721672797, 64.73369121551514, 66.54430435549828, 63.70366111878426, 67.66317613663213, 64.27110256687288, 68.27310469842726, 71.69266623835411, 79.8941461501583, 38.72525868877288, 0.22647236774284996, 0.39040327853252815, 3.811605135279317, 4.720347946689976, 1.2853268750252262, 0.24886795229488806, 0.35427503167621555, 7.566072123665964, 37.54644916903588, 57.20235609239148, 85.02647338374969, 89.0938457365959, 58.795513030021425, 29.571964663843957, 49.55301646263369, 50.381652462867, 66.73762229181105, 70.26328394489904, 60.6549753681306, 1.7783134022066671, 0.03931345275392936, 0.04124390239256524, 0.04499134787869069, 0.08215258769210308, 0.049508792167950066, 0.053165379626255845, 0.06330405534695714, 0.07229699678118191, 0.05405625561252237, 0.06647064530801389, 0.04345546416457623, 0.023811473999352708, 0.03376741285225557, 0.03807027591392398, 0.06812250707298517, 0.048365873254595265, 0.06038656653535943, 0.18542211322534471, 0.1870866997107383, 0.24136609758340546, 0.2689275355829347, 0.1585405782586144, 0.21472272403057546, 0.18063830782569226, 0.18426991698722686, 0.1783311267894122, 0.19187170020755262, 0.20384067489254862, 0.18959894716258974, 0.207353264634167, 0.10855052965663134, 0.24220911605704218, 0.6009572431925805, 11.627817346203713, 104.83481145674183, 90.39127165271391, 92.48133013325354, 93.51427847339262, 67.17511561609084, 23.681915921549646, 38.9190943779484, 54.96541269363896, 60.443543926362075, 20.98800463061179, 0.2101855070119904, 0.15551126742314908, 3.1350614899589173, 4.562544620806172, 2.4162557769206265, 10.197505451017811, 10.809040223398517, 1.204935937158523, 34.651449726473906, 82.58005188357446, 75.86574646734422, 81.93676748583394, 75.09632648960238, 81.72386907762098, 79.0639372794859, 66.47036767775013, 74.83156650297104, 72.13563519139444, 70.9639447735202, 72.19191335862683, 72.03443019620835, 71.56480481547695, 72.66938347970286, 74.61997816639563, 69.50681563346618, 53.561670934000325, 54.49900365644886, 51.277455129931056, 59.91062325816001, 71.46982854412448, 71.1979769122216, 73.34137962710473, 69.4270424689016, 70.069777734818, 66.03410597770446, 55.69651111479729, 52.33528306407314, 50.45327494221349, 50.32810426527455, 50.57044006163075, 56.659951133112756, 62.75203135705764, 61.8573740220839, 66.2412541912448, 60.2808165550232, 57.86926100330969, 62.26366096927274, 67.87293664870724, 64.710333501139, 64.28732941227575, 64.03569759861116, 63.99334384549049, 66.44048706177743, 67.57410695475917, 66.12368506769981, 68.81639219099476, 66.88755096927767, 71.46291732788086, 65.4250991728998, 61.89966893965199, 45.683829707484094, 45.60134618513046, 69.30021655174994, 64.76723140285861, 65.88695433831984, 57.41050843269595, 59.9727536016895, 59.915781174936605, 68.25212786274572, 67.33634071965372, 65.44709582482615, 64.2657877552894, 55.26512099850563, 47.63881744876985, 52.41471106006254, 50.62096803419052, 62.030374080904075, 66.63404818504088, 61.45961430764968, 60.806037610577, 70.39735840212914, 63.98490682724984, 54.70916817265173, 50.92345729950936, 52.27915394690729, 51.299710658288774, 52.086698932032434, 61.552758832131666, 70.28074633690619, 65.89307323578866, 69.85360806988132, 71.61789801812941, 62.72715960779498, 49.535306961305686, 54.51097473021477, 52.962026826797, 55.57208961056125, 58.78247507156865, 64.56008711168843, 67.98357102178758, 70.05204077689879, 69.09383712276336, 72.2457439668717, 68.33972223343389, 70.07551224000993, 68.32538989282423, 71.30964679102745, 67.9897762114002, 70.77643978980281, 75.20106161794355, 83.2146913774552, 40.29305358086863, 0.8443715687721007, 6.805637805692612, 8.08171328037016, 5.640294273053446, 1.8431465039330146, 0.47712623952857913, 0.5454048983031704, 16.073081627968822, 48.04364527425459, 79.44770982188564, 90.18140915901431, 95.80075356268114, 78.60349024495771, 37.70941580495527, 52.335789049825365, 60.19128061109974, 75.84548350303405, 79.26462927172261, 69.48394821536156, 2.5058054491396877, 0.19975610858490392, 0.1376325832379441, 0.2354924708244301, 0.19911113916145218, 0.17324367478009195, 0.1563944289040181, 0.12507727549922082, 0.1753829599868867, 0.17836216867210405, 0.17792934431664406, 0.11363271098103254, 0.13036052426022868, 0.1932437177146635, 0.11068902579286408, 0.16818608487806014, 0.19641760466319902, 0.1570571256020377], [0.037660694666086666, 0.040143823115936214, 0.039113791088663766, 0.10489345573249365, 0.0325566147183699, 0.022626759244068977, 0.03692779367068603, 0.010932362920063879, 0.06771569140255451, 0.055552180180506366, 0.03929344636778678, 0.009079019073396921, 0.04694494103351909, 0.0772937516411466, 0.0188413119664596, 0.11516652625775146, 32.638512888262355, 86.68769128860967, 76.46754787814233, 50.60984027001166, 64.42054094806795, 44.10282035027781, 30.76560074283231, 60.03096549741684, 48.685388180517386, 42.4684000784351, 11.042947826846953, 0.10749898205000548, 0.2781376284697364, 0.7160977454435441, 0.31335162599721267, 1.40793526364911, 5.837517909465298, 1.178991174505603, 2.935515074960647, 54.772628199669626, 73.48790368726178, 77.55601344570037, 74.68035913282826, 75.19437789916992, 76.2374302648729, 59.52030427994267, 67.72666362024123, 70.97405664382443, 71.00816557484289, 70.52592585163733, 72.34636060653195, 68.60595703125, 69.9698200533467, 67.13455046376875, 63.07511306578114, 54.465965532487445, 50.60254073912098, 50.00635616240963, 48.72607100394465, 51.260914494914395, 59.65220182172714, 64.87735979018673, 63.580318266345614, 65.08406477589762, 64.10346438807827, 59.31658029556275, 52.210367341195386, 48.616997734192886, 47.482648280359086, 47.35889357905234, 47.50069902789208, 49.77179058136479, 55.23475793100173, 55.163653204517985, 54.4866717246271, 49.55396175384522, 51.258451246446185, 57.556491205769206, 61.61956856327673, 57.58704254704138, 58.335995597224084, 56.30147003358411, 60.39615384994015, 61.09422591424758, 61.15058645125359, 56.71328360034574, 60.88397510590092, 60.00735675134967, 61.316569389835486, 57.613271436383656, 59.64288227019772, 38.34329828139275, 40.02923888544883, 63.610536206153135, 56.2445289857926, 58.298533039708296, 55.12483742929275, 58.21187611549132, 59.34890847052298, 63.00204715421123, 58.07419700007285, 63.3199474119371, 57.11575800372709, 54.70702655853764, 48.27714789298273, 46.185367491937455, 44.8110709651824, 53.43114229940599, 57.0814686436807, 58.17604918633738, 50.347010089505105, 65.20249682088053, 59.311724401289425, 50.84080903760849, 46.84600053295013, 44.53447718774119, 45.42819707624374, 47.46525649101504, 49.95428669837214, 61.58718939750426, 63.530257055836344, 62.62855514403313, 62.864120929471916, 56.88462449658302, 46.49895706484395, 49.06639937431582, 47.2175705817438, 47.44393448675833, 48.73574356878958, 57.51179187528549, 59.22835834564702, 61.990722840832134, 62.70226824668146, 63.608716226393184, 60.84980341695971, 60.742416766382036, 58.150989163306456, 59.73798013502552, 60.91799774477559, 62.699997194351695, 66.11100796730288, 70.95722183104485, 67.47395315477925, 3.6041860330489377, 1.4670376599796358, 2.0310830709434327, 1.402586253900682, 0.474924564121231, 0.32355294472748236, 0.11996525505016889, 0.7366409140729135, 33.33411778173139, 28.797682908273515, 44.10091015600389, 56.62681102752686, 71.84685460982784, 24.002026434867616, 20.24271115179985, 31.151905175178285, 48.42580572251351, 61.913652189316295, 70.50925577840498, 20.332951161169238, 0.24410165966518466, 0.08417934224370026, 0.09103347727608296, 0.11818625333328402, 0.0646128208045998, 0.09876165734303576, 0.04759669416554032, 0.03198267505203765, 0.06460884480827278, 0.04500411856438845, 0.04834625757329407, 0.02321324743060095, 0.04592028311303547, 0.057395793752925056, 0.03516507132219211, 0.09119584961163421, 0.053190890354134386, 0.03620268378947531, 0.08116736031708219, 0.07088775506183025, 0.021510693627680023, 0.04980983790911494, 0.04237964689250916, 0.03641244632402255, 0.06689536445323499, 0.06016026033208736, 0.07425317931319438, 0.08719690895128636, 0.05138955334381712, 0.08338500865765157, 0.12368908587602839, 0.0962861514680328, 0.1110706907967406, 40.21530043694281, 99.4137820889873, 82.70133941404282, 60.906595414684666, 67.98810528170678, 58.467402842737016, 35.256290974155554, 34.34522636475102, 44.96441210469892, 52.51355871077507, 9.772603915583703, 0.12485105739606005, 0.31359089057772394, 3.8226331241669196, 3.3111965031393114, 3.9387244947495, 3.6515768449152675, 1.4403971669174012, 3.9403169770394606, 59.8391459065099, 77.39290560445478, 80.1762116339899, 76.66125805147233, 78.32042847910236, 76.93874220694266, 60.91010201361872, 69.71308523608793, 72.484326054973, 74.95378755754041, 73.31233839834891, 74.77985397461923, 71.56431844157558, 72.39353887496456, 71.08921743208363, 65.30490206133935, 55.70338702970936, 53.30415556507727, 53.34232414922407, 50.60870278266169, 53.16323657189646, 63.28264959396855, 67.75928205059421, 67.45348622722011, 68.24779756607549, 65.6114705916374, 61.53540626648934, 55.295723330590036, 50.872870491397, 50.5661960571043, 51.048722113332445, 49.08299492251489, 49.95831105016893, 57.10758770665815, 58.176288450917895, 57.070497774308734, 53.027236230911754, 53.71627115434217, 60.616606743105, 63.67636926712529, 61.68084775247882, 58.80196140658472, 58.25345716168804, 61.788512891338726, 63.3107102301813, 63.506530638664, 58.86828084145823, 64.82668276756041, 61.69726287164996, 64.00616999595397, 58.60761188691663, 61.26807320502497, 40.13498598529447, 43.01694746940367, 65.125296731149, 59.394702142284764, 60.63898386493806, 57.64474845701649, 61.25270143631966, 61.87791547467632, 66.07201176304972, 58.3144578626079, 65.17269857468145, 59.498170345060295, 58.76398109620618, 52.16976296517157, 47.99343501367877, 46.961447654231904, 53.693238996690326, 61.54568287634081, 61.23547046415268, 52.472189472567656, 66.12985887835103, 62.86090458593061, 52.79913863828106, 49.20246247322329, 45.54567206290461, 47.71271490281629, 47.499439947066776, 52.88134367235246, 63.83068707681472, 66.93405459004065, 65.84953492687595, 65.88634244857296, 57.55121954025761, 50.761192767850815, 50.872650838667354, 49.10843149308236, 49.83524668601252, 52.19881203866775, 59.666114468728345, 60.992742430779245, 64.0148776577365, 65.10494355232485, 65.6940011824331, 63.696189003606, 61.681263523717085, 60.56063059837588, 64.11222304067304, 62.882383484994214, 66.78844836450392, 69.00552888070384, 72.40857724220523, 72.64549624535346, 6.084335504039642, 0.927008982867964, 0.3811970773723818, 2.3177253478957764, 2.5964712808209085, 1.2134191658227675, 0.15613011324838286, 0.49244710935219643, 32.824329291620565, 35.56089831936744, 53.904019325010246, 61.547553846913004, 67.64585494995117, 31.363475861087924, 32.08685701893222, 35.845136796274495, 55.612603772071104, 67.89149730436264, 80.20740232160016, 27.979123477012884, 0.3505072274035023, 0.0288144571541418, 0.06818967766218609, 0.11070535878740972, 0.04100874021288849, 0.06289318707140704, 0.07786979613405082, 0.024186675136368123, 0.043165158976109765, 0.02657284558330092, 0.136725060161083, 0.02711579316265641, 0.036354441976835655, 0.04508248935904234, 0.069056712992249, 0.028987152524472728, 0.0288382958951256, 0.19425761976069023, 0.1308901055205253, 0.18018858357062265, 0.23222930398919892, 0.11547478471672344, 0.06134669686998091, 0.1721757022483695, 0.12792660929863492, 0.24327068409371763, 0.21951320971692764, 0.1375151572809104, 0.2755420000082062, 0.21775577337511126, 0.19939523520729235, 0.1657434594967673, 0.23985802286094238, 50.37832629296088, 112.10392828910582, 94.67712786889847, 70.46483101383333, 77.92103705867645, 59.94468904310658, 44.797589778900154, 80.68978325013192, 68.71113930979084, 61.543823672879135, 14.359888395955487, 0.3209772651955005, 1.1556381179440407, 3.5207574646319117, 3.6031154711400313, 4.673201547515008, 17.53930184148973, 5.86390124213311, 4.130367578998689, 66.11427137928625, 78.26495047538512, 84.14765065716159, 80.31180012610652, 81.73611471729895, 77.53370300416024, 66.79082532082835, 71.42428198168355, 75.91651762685468, 77.2158968833185, 75.05928362569502, 79.02926352716263, 73.01889019627725, 73.95155137585056, 73.20772878585323, 68.5845644243302, 60.84666552082185, 55.88511043979276, 56.31450014729654, 54.124880144673014, 55.78444280932027, 65.14848186123756, 71.85290290463355, 69.92850180595153, 69.10620827828684, 68.27734870295372, 63.44024650512203, 58.482829524624734, 53.644036785248794, 53.19393304086501, 54.878810682604396, 52.53674384086363, 54.08381292896887, 59.31426217479091, 60.776451172367224, 59.60641991707587, 56.638558526192945, 55.36346266346594, 64.04772358555948, 66.33124905247843, 62.40664705153435, 60.09693584134502, 60.240498512021965, 63.31597012858238, 64.08844171031829, 65.74680412969282, 60.95692726873583, 67.28596964190083, 66.70092459647887, 66.02950111512216, 62.20853205650084, 60.759122140945934, 44.160640008987926, 47.39211605441186, 67.64213654302782, 63.166170889331454, 63.448742358915275, 60.515319378145286, 64.73635842723232, 64.47639549932173, 66.64589374296128, 60.29978513717652, 66.75920317249914, 61.26136595203031, 61.62560901334209, 54.51529325977449, 52.30231946514499, 50.80502133215628, 57.28301963498516, 64.55454088026478, 62.85349522867511, 56.83171956769882, 67.55454217233967, 67.24811092499765, 54.74124531592093, 52.22971639325542, 46.740806487298784, 51.22936294924829, 50.31168130136306, 53.93136608985163, 66.0809547670426, 68.96820360614409, 67.81949043273926, 69.61803051733202, 62.57997266707882, 53.10613862929806, 54.03792119795277, 52.06229394482028, 54.18066017089352, 54.48932716923376, 62.84480717874343, 63.722621856197236, 66.84114933013916, 68.61751233377765, 70.4393042287519, 67.03525958522674, 66.62798420075448, 64.34680823356875, 68.00622663190289, 66.63774305774321, 69.79387037215695, 73.21205123778313, 75.01109338575795, 74.86773860070014, 6.315849971386695, 4.1540694813574515, 10.961896950198758, 6.8969373453047975, 4.533731870112881, 1.3667931551894834, 0.4421398620451651, 1.49552044128218, 42.90859199339344, 41.37104249769642, 54.54056509079472, 64.56787301648048, 83.57434918803554, 33.91908830212009, 30.169663275441817, 45.042808517333, 67.01421999162244, 75.19262067733273, 90.12446418885263, 33.17142178935389, 0.43336101537269933, 0.21460169746029764, 0.18929655693711775, 0.2728594971760627, 0.15448046547751274, 0.19123560208226406, 0.1658292766660452, 0.17019007895742694, 0.24875705340696921, 0.08229450548007604, 0.28919852849456573, 0.0936506021647684, 0.12740007706827697, 0.17626725527788364, 0.09702662141212533, 0.1956650611734198, 0.18071269496313988], [0.037908784579485655, 0.014422812720670577, 0.022851899078476335, 0.12330549033058268, 0.054519248510440516, 0.01929614219754454, 0.07268594728121835, 0.012831308150423631, 0.03505393111657712, 0.03112516411009335, 0.048240027991273714, 0.04817862221370301, 0.008182268150361076, 0.029089434838463223, 0.028438129867877693, 0.33378732781256404, 64.833684198318, 74.47890620077811, 66.11199640458631, 59.35172080993653, 64.14157021430232, 20.24564116231857, 26.07119437186949, 66.44571165884695, 33.775843343427105, 42.09342541233186, 1.385980777202114, 0.18320678613118588, 0.16670598768659178, 1.649613327557041, 1.6683039117243983, 4.780902968299005, 2.8487664653408915, 0.8194870718063847, 15.283085876895537, 75.46175802907636, 71.16033000330772, 77.23503020501907, 69.60262344729516, 77.95709933004072, 55.42138038143035, 64.13935799752512, 74.28801228923183, 71.95338618370795, 70.93007118471208, 69.88828182220459, 69.24688800688713, 68.88789699923608, 68.46014684246433, 65.23668419930243, 52.85738583533995, 49.18164645471881, 51.84117424872614, 47.52922250378517, 48.741423160799094, 50.52432083314466, 54.84291707315753, 65.33324903057468, 67.48385321709418, 65.108748251392, 64.1329998354758, 60.863112018954375, 52.99607692226287, 53.120121878962365, 49.75702285766602, 47.202371397326075, 44.874609439603745, 44.30363393598988, 48.321305936382664, 48.30324734410932, 48.00788894776375, 50.070565362130445, 52.31245879204043, 57.93381537160566, 58.7038903851663, 62.916021731592, 57.64215184796242, 54.36606276419855, 61.075198496541674, 59.6839730201229, 62.069342828566036, 59.72381645633329, 61.18132606629403, 60.44597579586891, 62.10579341457736, 56.93697244890275, 64.67207470247823, 44.68322130941576, 38.680555435919, 63.07582301478233, 56.81961513334706, 64.42026245978572, 56.57575353499382, 61.72915174115089, 55.05075170147804, 56.807800954388036, 51.76861040053829, 60.73902391618299, 58.226741898444395, 57.45944000059559, 54.23310226009738, 51.65681500588694, 47.893500866428504, 50.75181438076881, 54.45032704261042, 61.77562006058232, 55.01001788723854, 58.08152398755474, 65.49001439925163, 52.87118473360616, 47.96756306002217, 45.158859683621316, 45.906836063631125, 46.82825573029057, 49.03676979003414, 57.00459803304365, 60.265727196970296, 61.36665413456579, 62.59335971647694, 53.32344578158472, 44.5514061374049, 49.52889780844412, 47.279194939521055, 46.790251885691, 51.459233453196866, 55.005091390302105, 57.720548260596495, 59.0678471134555, 57.091000003199426, 58.50258650318269, 57.43962026411488, 57.79784640958233, 57.65453869296659, 56.96774344290457, 59.59076573771816, 63.687924569652935, 66.54286876801523, 67.02123318949054, 75.88281662233415, 38.761928927513864, 0.19754828915240305, 2.46274812086936, 3.6894973391486756, 1.2167805144863746, 1.0740763525809012, 0.31242245327561136, 0.3139590417906162, 9.4273990584958, 44.672219061082416, 24.98891438207319, 55.46743292962351, 65.75386831837316, 58.54472060357371, 22.232735464649817, 32.232123959449034, 44.23624761642949, 57.10231604114656, 60.86313947554558, 47.724525159405125, 2.946362389672187, 0.13886477437711534, 0.0448476527667334, 0.038102658450483315, 0.04348460614921586, 0.08186209481209517, 0.05846819810328945, 0.02116194550669001, 0.05980574931468695, 0.04428858095179162, 0.07157869742161806, 0.05279519444992466, 0.05425315553082093, 0.0476095223078324, 0.021904217672624418, 0.02080147241001889, 0.07368761490309432, 0.026266251450344443, 0.04624976986838926, 0.013585712276248923, 0.02014157767858236, 0.003497582797389177, 0.03882286153853901, 0.05235691937888342, 0.10411000059496972, 0.03608438832264754, 0.025980479587169907, 0.07027728257760887, 0.02813018550495467, 0.052582191363457716, 0.055728859208043546, 0.04728738233567246, 0.7768735229488343, 81.51899583878057, 83.44446382214947, 76.58443450927734, 68.60765149516445, 82.06472304559524, 25.657058761965846, 33.88814864620086, 59.93044299464072, 38.44676648416827, 48.74291366146457, 0.8428541630987199, 0.11804047446217268, 0.635603477637614, 4.404294635018995, 6.590218294051386, 10.971655807187481, 3.0866082060721616, 0.5738973629570777, 19.721214386724657, 79.04649842169978, 73.41458674400084, 80.9353236229189, 72.82338357740834, 78.5036345451109, 57.84615432062457, 66.57371428705031, 74.58958764230051, 74.25053796460553, 73.40371393388318, 73.41834437462592, 71.34267314787834, 70.84828192187895, 70.32926605593774, 67.37418374707623, 56.25671186754781, 52.67084575468495, 53.87916718759845, 50.21030764425955, 51.6905983801811, 51.76938310746224, 58.58600747200751, 66.9164353032266, 70.21727454277777, 67.76985676057878, 66.99416883530156, 65.02421332943824, 55.05599591039843, 55.50653896024151, 52.01991665747858, 50.32492322306479, 46.191431476223855, 46.53090476989747, 50.15358624919769, 48.28230580975933, 50.36978729309575, 51.54809474945069, 54.993504708813084, 60.00836872285413, 63.000690014131614, 63.69556142437843, 58.63923795761601, 56.86593048034176, 62.684095905673125, 61.009373280309866, 61.82211975897513, 61.69643132917343, 62.51954463220412, 62.86581147101618, 63.546923206698516, 60.20078059165709, 63.964173178518976, 45.20588105724704, 41.694492909216116, 63.74593250213131, 58.397251252205145, 64.6361771706612, 58.39212471438993, 64.0944782380135, 56.904432465953214, 60.22003158446282, 50.92463401056106, 59.80461335951283, 60.23181046209028, 61.98203086853028, 56.68810982857981, 54.18505714785669, 50.212366888600016, 52.52775769079886, 58.76201991112002, 65.02480952970444, 57.9121325092931, 59.996597689967004, 67.10071609866235, 55.21957051369452, 49.9556242266009, 47.80202727163992, 47.75348401838734, 48.89834934665311, 50.54681954845306, 59.67270012824767, 62.1707086409292, 64.81178952801612, 63.34012800647367, 55.60799106474846, 48.15266363082394, 50.89132916542792, 49.52952538767169, 49.14145784993326, 53.85727251729658, 57.710809015458636, 60.90419492413921, 59.57830829005088, 57.997648023789935, 61.11876033967542, 58.55565617161413, 58.64346627266177, 59.488435022292606, 59.87094848386703, 61.62821346713651, 64.55839657014417, 67.8328186465848, 72.12402497568439, 76.67628857397264, 44.8452034304219, 0.04409585238224076, 0.37966873196344225, 2.568274832540943, 2.7633031673969763, 1.868875781374593, 0.6365674613944946, 0.29905464800615467, 7.006090533348822, 49.48661465798655, 27.37907340449672, 59.14414898041756, 68.48687387281849, 51.97452698984454, 22.502529813397317, 44.61990641009423, 49.25786202953708, 63.7163225297005, 67.92663389636625, 60.35338432558122, 3.9319547289802186, 0.12281481867596028, 0.04581397309178307, 0.018426691775300333, 0.0699761487363327, 0.017904204489182562, 0.0385163152860778, 0.03294933054055418, 0.04159631049861351, 0.00811363146039507, 0.10635366528144768, 0.034431239529963464, 0.025913071510712468, 0.01822844162703522, 0.044808685704464876, 0.024655553504764557, 0.006909203826404748, 0.1900640544631789, 0.113062082729753, 0.13827883968910865, 0.1600276621719522, 0.11451982547559085, 0.11720167713299876, 0.22562892025997563, 0.2493110422285334, 0.15417499557858513, 0.0817247582299094, 0.20693449033123834, 0.14609699678276816, 0.15327893317707125, 0.2156504718286376, 0.09546435362989865, 1.7632917050392398, 94.12135939444266, 91.40956601788922, 87.92242203989338, 77.75586605072021, 83.45379906315958, 29.912546027091246, 41.31137932500532, 90.81044750828897, 49.76921750653175, 56.86430269672025, 2.0811630352850883, 0.2506052098807789, 0.45925429691710784, 6.304975200083948, 9.399269780805035, 12.368950170855369, 11.868926421288522, 1.8839848738524223, 22.61011846603886, 84.15717417193999, 75.05697727203369, 84.91522712092247, 74.92202420388499, 80.95384505487259, 62.99185683650356, 68.12953026063981, 76.49192933113345, 75.63740961013302, 75.0723921868109, 75.6444541869625, 75.03890299027967, 73.67468695486747, 74.04323285625827, 71.17871807467553, 59.83940478294127, 53.93660245403167, 54.719056467856134, 52.37114921692879, 53.95107992233769, 55.91294750090569, 60.33161124875469, 71.3530517393543, 72.97976063143823, 70.96804757272044, 69.60032493837419, 68.30358151466616, 58.16931447675152, 58.14755708940568, 54.40760850906373, 52.6849074517527, 49.074059763262355, 49.201336752983835, 53.50372183707453, 51.82181735192576, 52.721216832437825, 55.07496841492192, 57.08435550812752, 65.54684562067833, 65.52954404584824, 65.26226197519611, 59.39209768849035, 57.53362771003478, 64.80921253081291, 64.15298038913359, 63.79932772728705, 63.640648241966005, 65.02159710853331, 64.20777590044084, 67.95787949715891, 63.40802031178629, 65.66436375341108, 47.86638552142728, 47.75300156685614, 65.5854142865827, 62.202934834264944, 69.4058616699711, 62.55854475882746, 68.0445795674478, 59.71434393236714, 60.76220904627154, 53.00099949682913, 64.21251020123883, 62.760868457055864, 64.60684568651261, 59.58147756515011, 58.81566224559661, 54.31697822386219, 55.594737375936205, 61.372996607134425, 68.40979929893248, 60.573919588519686, 62.06740910007108, 70.22628030469342, 58.96972117885467, 52.46669030958607, 51.352282185708326, 49.64441945475917, 51.87105486469885, 51.88547741982245, 62.819280393662, 64.44759353514641, 66.47276816829559, 68.64080336786085, 59.61401362572948, 49.71826984036354, 55.13262725645497, 51.60649884131647, 52.033943053214784, 57.97961296573762, 61.51229958380423, 63.615027320000436, 64.75370314813429, 61.5826629823254, 64.1855517510445, 64.48328318134432, 63.42804401151596, 63.43979151018205, 62.90499594903762, 65.76702002556094, 70.24633930575463, 69.92399108025336, 73.86735377773162, 78.19888207220262, 45.58456236316312, 0.26260626832804373, 8.80656042406636, 13.45968286837301, 4.4055757791765275, 2.7846781236510125, 1.3404514977047521, 0.5422089020571401, 11.665005337807441, 60.4448147742979, 38.175985659322436, 61.93913582832583, 74.0437113854193, 67.19294671089419, 35.03508890828779, 48.06142930061587, 58.950493720269975, 73.13201135204685, 75.41170074093726, 68.50508151515838, 5.104543614772059, 0.40451005221374575, 0.10664678584303587, 0.19179216495925383, 0.13685661277944042, 0.24856706360174766, 0.1627378054564038, 0.07924570536781704, 0.19487441247028692, 0.07011364619698256, 0.3155718100888114, 0.14392420289016541, 0.0944973744692341, 0.11018999611898778, 0.09919477281190696, 0.10939203127617798, 0.13863623502754396], [0.03626362608385183, 0.010204520977793202, 0.08845213635434067, 0.03997719516196559, 0.07268752542234237, 0.02644365634618988, 0.04391238964613407, 0.03001476371390445, 0.03531867195101034, 0.07240588851873914, 0.017963723775239724, 0.05353780944020518, 0.039520633572171775, 0.09023672285219354, 0.09060639091917584, 6.225428062100565, 82.56773564123338, 69.32648074242377, 69.23944334830009, 41.70790741520543, 13.957802307221199, 51.32830081447479, 41.432309919788, 26.908757686614994, 56.03676103776502, 31.816601791689475, 0.37474275596680184, 0.03313834358367228, 0.43461001448092923, 4.149029725982297, 3.3044698834419255, 7.021603017084061, 0.2994806235355716, 0.673701030112082, 40.15277001165575, 73.26749786253899, 73.49024141988447, 72.22475144170946, 77.17107988172963, 70.0049017321679, 64.48968056709536, 69.19544219970703, 67.66075995660597, 70.77560824732628, 72.60332292126071, 68.12340351843065, 65.28414487838745, 64.30343074183311, 63.88312524364841, 56.3416390265188, 51.76812010426676, 50.92563029258482, 50.37656122638334, 50.64688313391901, 50.433172795080374, 50.495997398130356, 54.66429233551026, 62.571190480263006, 66.45934581756592, 65.10597121331, 63.43064846531038, 59.41831481072211, 57.41822765719507, 54.45652830985285, 51.75674523076704, 48.772280446944706, 46.0602399610704, 46.40591452198644, 47.37588920900899, 46.4907318545926, 50.027564417931345, 49.376956955079116, 50.93520087580527, 55.01724289309595, 60.7810599573197, 63.276471860947154, 53.66875163970455, 60.84808149645406, 62.75299626012003, 58.535271613828606, 60.2554976555609, 57.414081711922925, 59.95344377333119, 59.60396843571817, 60.56443137507285, 57.22373693220077, 63.855280337795136, 47.45023773562524, 37.51800806291642, 58.538040807170255, 55.29091842712895, 59.609526434252345, 54.44152132157357, 56.0013851811809, 52.93277771242204, 54.56191062927247, 54.35519779882124, 55.90587938985517, 58.657378919662975, 59.271986869073686, 58.82641346223893, 56.03524308050833, 51.51913981283865, 50.216414774617846, 50.382593831708355, 57.402514642284764, 57.93842023418796, 53.87007513353902, 60.63178239330169, 55.42649907450522, 47.68807457339379, 45.865223638473026, 42.751438310069425, 47.13784840799148, 47.0537135677953, 53.051178378443566, 57.957694761214725, 60.612500021534586, 59.005920733174975, 52.423712899608, 46.31901833318895, 47.42716243190151, 45.12993612597066, 48.5767855951863, 49.33533668518067, 52.632539887582105, 53.198620273220925, 54.821049859446866, 52.365614752615656, 52.076677276242165, 53.79328297030542, 56.70637630647229, 55.467479998065585, 58.212389945983894, 60.79795752802203, 61.47331122429141, 64.95961581507038, 70.51076981329149, 64.58278194550546, 69.92546589143815, 12.298483810117169, 1.2222539369137058, 1.4458078314219753, 2.1568003056510805, 0.5211118825020329, 0.4288209944723114, 0.07432840148647947, 0.5769446155717296, 38.19089851071758, 45.58305617301695, 29.555900596803237, 55.25085926055909, 108.57858827037197, 61.69152836645804, 18.911109624370454, 38.31040528512771, 48.77475546252344, 60.914852003897394, 60.672924134039114, 20.682997203642323, 0.14229491773632266, 0.06228374497544381, 0.05907925281433329, 0.034549764823168516, 0.03275834865147068, 0.029711980868371266, 0.009502148586175135, 0.09312429209990848, 0.07809249789363916, 0.038127173264060295, 0.1263242981006061, 0.06162531155672285, 0.021781766178807425, 0.018348196491358743, 0.04239031849729438, 0.03544663544744253, 0.041691493092765736, 0.06737680474836981, 0.04376061613701525, 0.0822153379539809, 0.09059705230737887, 0.017916272289209792, 0.00656859586841517, 0.004805560381482206, 0.07427065377874721, 0.017185669557581988, 0.02837726992795304, 0.06065891462288076, 0.03429613609407698, 0.036868958118101286, 0.17615768938295304, 8.839180815604426, 95.55930814435406, 75.00345260866227, 79.2848373228504, 47.345177050559755, 27.44295116393797, 49.00487307579287, 35.88015571717293, 29.326230133733443, 63.52500892454579, 35.742037296295166, 0.25888381646044795, 0.027277947163149237, 1.1710668835909137, 2.383429951244785, 7.544518699569087, 6.36490656483558, 1.1119437722429153, 0.7345226503187611, 43.89435422035956, 77.15025209611463, 74.45525430863904, 75.96288004229146, 79.330854569712, 74.68605441431846, 66.57442815842168, 69.93933539236747, 70.71174421618062, 72.35260501984628, 74.04501361231651, 70.72428011125135, 67.88786518958308, 67.47971903893256, 66.96486088537401, 58.3513948225206, 54.20635169552219, 53.156399880686116, 52.357291483110004, 52.16544051324168, 53.288419015945934, 50.465049897470784, 56.91715663479221, 67.8345601789413, 67.46366870018744, 67.29139035747897, 64.48414610278222, 63.87422146335725, 59.56173627607284, 57.32256497106245, 54.73605209781278, 51.50857686996461, 48.16670179367066, 49.11649980852681, 49.76391446205878, 47.45362274108395, 50.64622809810024, 50.515071884278335, 53.664060484978464, 58.66469806240451, 62.78270036943498, 63.820481069626354, 54.598200398106734, 62.80346539712722, 65.00586448177215, 60.703032247481815, 61.74504910745929, 59.40911685266803, 61.77274104087584, 60.64085875788043, 62.049358352538086, 58.09673493908298, 65.66146119948357, 49.804946376431374, 39.36856269836426, 59.6465967547509, 57.42871999740601, 63.587680555159054, 57.07291395433488, 55.732138003072436, 54.08607613655829, 55.97143004017492, 56.7147623339007, 56.54397056948755, 61.10163134913291, 62.281123361279896, 62.31711895235124, 58.811379017368445, 54.622927019673014, 52.63531692566411, 55.135557266973684, 60.315611900821814, 59.021535688830966, 56.192228101914935, 64.07533314920241, 57.29333939090852, 50.10969492696947, 49.1123499408845, 46.403121794423754, 48.81885467037078, 49.13690790053337, 55.427475744678134, 60.9526244286568, 62.26351976394654, 62.013743231373454, 53.68388022145918, 49.728515071253625, 49.919095193186116, 47.2713109754747, 49.88661796815934, 51.32415486920265, 55.11351354660527, 55.378626546552105, 56.93681163172568, 53.08206312118038, 54.1791892820789, 56.99359970708048, 59.00108052838234, 58.943684485650834, 60.016025189430486, 62.94421572839061, 64.13881278807118, 68.26293791494062, 71.85916300742858, 69.0103220170544, 72.06201230326008, 16.658417909376084, 0.5736577306543628, 0.7163094921458153, 2.090425467298877, 3.115420221321045, 1.0838348418474197, 0.08987906704386396, 0.20192937745201975, 39.952956630337624, 47.38395752445344, 32.70719162879452, 68.44741482888499, 94.77857605103524, 64.07787876744425, 29.887344798734112, 47.2911189448449, 56.2554096406506, 67.6952297456803, 71.04321587470271, 27.070318152827603, 0.09537085259874022, 0.06018624603447895, 0.016263347577243563, 0.10279998258357087, 0.04387318892704864, 0.030678460156665217, 0.030332217143187602, 0.011825100499986401, 0.053296916922854806, 0.09005745061703267, 0.05834753925521528, 0.0480373211265091, 0.05235113924549473, 0.02315802398257919, 0.05022937446952828, 0.020154005539934003, 0.12986216874372575, 0.260838566408042, 0.17101651928838224, 0.13477243993791843, 0.26576524720557276, 0.17481216319626378, 0.13514773109026496, 0.1509189533610498, 0.16951288787587998, 0.15692751884700792, 0.13806185294543544, 0.19704797245081396, 0.14432656758975598, 0.3184819942520511, 0.3487109963692004, 12.876276393090526, 108.33297729492189, 84.9959965675108, 88.78375884025328, 57.20025762434929, 24.544698115318056, 64.8048077091094, 54.437936275236076, 38.49123439481182, 79.43865699152794, 38.88907255664949, 0.9337513533330734, 0.14582926437499064, 1.0682224602468553, 11.43342468046373, 8.860671481778546, 14.988778675756148, 5.495688251910671, 1.372820980125858, 50.46391241012081, 80.78119800936791, 77.35190899141374, 78.15920337553948, 83.39820338833718, 77.14814186096191, 70.92137921241023, 71.0391366097235, 69.85469848878923, 73.75499356177546, 76.74640486317297, 72.87469602400257, 71.81685632274997, 71.05788553914716, 70.47422116802585, 62.14964551310386, 57.222842631801484, 55.841403468962646, 55.75416995633034, 54.89003650603756, 56.67946100234986, 54.23854258752639, 58.67657107691611, 70.01884968050065, 72.14115004385673, 69.5116558382588, 69.20012550969278, 64.50247926096763, 62.03136644055767, 60.934601137715006, 57.81998426683488, 54.24228452867078, 51.010392712008574, 51.723499221186486, 53.03475541453208, 51.53227975291591, 53.97181357106855, 53.642554129323656, 54.98551091840191, 62.33187883130966, 64.52159689318749, 67.96468873177805, 57.92841819024856, 62.168457200450284, 68.10990272029754, 62.43709641118204, 63.83644903859785, 59.152468327553045, 62.30983511094124, 63.82787865977134, 64.74306960259715, 61.93783752379879, 69.09538253661125, 52.977194632253344, 43.74928143716628, 61.38985887650521, 58.846625435736875, 64.58107571448049, 59.71258671052995, 57.86635844938217, 55.52711963653565, 57.05947199175435, 59.01074132611675, 57.94422926441316, 62.256420273934644, 63.937038221666896, 65.30248980368337, 61.49227980644473, 57.76184297377064, 55.89577928666146, 56.69387179036295, 62.963890337174945, 61.49186403520646, 59.1969636947878, 65.06054624434441, 60.97198132545718, 51.987910116872484, 50.971576936783336, 48.270864255966686, 52.21734523773194, 52.58623630769792, 58.579664999438876, 65.16301032035582, 65.75193851224839, 65.61836611840033, 57.04740678110431, 50.993314712278305, 54.701405802080714, 50.746519181036184, 53.03847774382561, 55.561130508299804, 58.457153689476755, 59.09257373502178, 59.36689646013322, 57.96671229024088, 58.70645561525899, 60.056229483696725, 62.59912167826007, 61.959665513807735, 64.10109527649419, 65.22949449477657, 68.15653970164638, 72.35542128163, 76.83823539364722, 72.54497374257734, 76.71607709700062, 18.086009640847486, 2.0940215453024833, 6.403429142890438, 6.519146907714106, 3.551204372798243, 1.9085463881492617, 0.33634226168355635, 0.9525480866432191, 48.51440814233596, 60.34822640880462, 40.514734175897416, 64.12673188794044, 116.85231039600988, 73.11028142129221, 31.737189485180764, 54.92136447660385, 64.98428360108407, 76.19740639963459, 82.24166116406842, 32.91046650178971, 0.2883410616026771, 0.20475976589706638, 0.17377829689893032, 0.14931563858784017, 0.22801301652385345, 0.14045816065082628, 0.14646721643305596, 0.18934848237662547, 0.23724356395823343, 0.15433438783211095, 0.1648705176288082, 0.1343840640038252, 0.1800286090902744, 0.1958849437294468, 0.13803481004170834, 0.12318853168718277], [0.07110908552403412, 0.08771280022037607, 0.09455173606834105, 0.04388389883623008, 0.053244083669156804, 0.040177381597459316, 0.06647870455297732, 0.1032894974454276, 0.038199400033561454, 0.08595755489002313, 0.011055869699996567, 0.026367399954207005, 0.12825663231553572, 0.20532336146120103, 0.28301944715842126, 27.280821954050374, 83.30393314361572, 59.990137546293205, 61.42519158701743, 54.12477424067836, 40.60793361356182, 58.851724516960886, 63.25684824297505, 43.62620138352917, 65.40080793442266, 13.25839271468501, 0.23580924818112006, 0.016296590047497905, 1.3702852903835236, 1.930907085057228, 7.555310610801944, 10.774121322939473, 1.2064009424178832, 3.6361960057289373, 59.41051713881954, 70.57772467213293, 74.36028588202693, 67.59495042985486, 69.48386192321777, 65.40112564640661, 72.69926409567557, 71.8358798180857, 73.90454569170552, 72.12859061456496, 70.46358370011853, 64.30859258097988, 67.73210002530006, 57.15043175605036, 55.80771815392279, 50.999857225725734, 50.575060613693736, 49.43808709421466, 51.04161477858021, 48.269334531599476, 50.01344780768118, 47.296724011821134, 58.71497500327326, 62.68882628410094, 65.66685053610033, 65.46890028061406, 62.39191462916713, 61.95984986520583, 58.49613420424923, 56.91072394770961, 53.979042499296135, 47.97967141674411, 44.96358056222239, 44.14931612630045, 46.51969071357481, 43.70020866394044, 46.971943916813025, 46.17998600006104, 51.681871106547696, 55.61101913452149, 64.07211288329094, 55.888060062162346, 54.115858693276685, 60.82138584506128, 58.88619038366503, 59.04809013489754, 60.07568836212159, 57.171134025819846, 60.47576619732765, 58.68789103723342, 57.99476900408345, 55.67032144915674, 64.94825270868117, 51.29541566295009, 38.144520405800115, 55.025946632508315, 51.603215817482244, 55.02220076899375, 51.46124562909527, 51.60574182387322, 53.71848337111935, 58.56992575430102, 55.87521822221818, 58.934321788049516, 59.408159794345984, 59.825641186006614, 57.7118052974824, 60.90599921441848, 58.306542519600164, 56.11777367130403, 53.4538959687756, 57.08951342490412, 60.22826856182468, 53.787069935952466, 58.35031224835304, 57.427825697006725, 46.79965772936421, 44.576842707972375, 45.67449446647398, 46.349385323063025, 47.65765659270748, 48.76255296891736, 56.57869531262306, 57.2757593277962, 56.332590118531265, 49.55359305104902, 45.39717112818072, 47.102907934496486, 47.281673877469956, 44.59321075870145, 47.392276871588926, 52.28482177180629, 50.36447248151226, 52.642059479990316, 51.44751341112199, 50.799377041478316, 53.552763231339, 57.06967407657255, 58.053043657733554, 61.10695008308657, 60.49039271570022, 60.807559490203865, 64.88370226275536, 70.95244438417497, 66.7627803740963, 62.06809551485124, 53.930157999838556, 2.453800213913764, 0.8482463189190435, 1.6511502837942493, 0.7363790958639115, 0.7667864738933502, 0.15991651813589758, 0.0958591417199181, 8.552628140295706, 59.39564743349629, 38.236158740135934, 36.24625798194639, 54.30780772239932, 51.64605202213411, 23.407363737783125, 30.874907393609327, 41.609954064892186, 54.10922988768547, 60.25896110842305, 45.75265161452755, 2.296936050538094, 0.09577421321263237, 0.04909246168549984, 0.04508505192314906, 0.04971546353772283, 0.08243308312469914, 0.05499487802866967, 0.08089069532410753, 0.04241218264665335, 0.0431258280220772, 0.0346181649834879, 0.03407941365073766, 0.0483171270799733, 0.02871236061647294, 0.15672027674173156, 0.06988486936015469, 0.03585249350796785, 0.09638872298021471, 0.02306100086218888, 0.03329630325277967, 0.04975102533916793, 0.030003145990532734, 0.024781086587256966, 0.06560851294066637, 0.04436271911066386, 0.05619353366895549, 0.03806348071403561, 0.01715196934979289, 0.158151849924076, 0.19068780325112805, 0.37398834322248736, 36.53679186298002, 92.93124168149888, 68.6169396677325, 70.53002865083756, 62.04152537930397, 42.20843322815434, 74.38374165565737, 56.777190777563284, 37.80745544741231, 74.61524778796782, 11.653186255885709, 0.20373530715944307, 0.02590348775077972, 2.8098563080833805, 7.807089513347996, 9.245608968119468, 5.383123582409275, 0.5593202419338689, 5.592787996415169, 63.861591431402395, 73.50204775410315, 76.18006952347295, 71.80100210251348, 73.34672974001977, 67.96144100927538, 75.50688097553869, 74.49011633473059, 76.88757881041496, 73.92029793031755, 71.98264706519343, 66.52056617121544, 70.58355331420898, 60.23710173945273, 58.37778845141011, 52.34170006167505, 52.709998853745006, 51.04192464582382, 52.796946033354736, 49.57109858912807, 52.60126290782806, 51.23632123393398, 58.57173004458028, 65.50228357315063, 67.53318878912157, 64.96506398723972, 68.25027650402438, 63.85251898919383, 63.31045919849027, 59.95019997319868, 54.60802985775856, 50.760812297944106, 48.80712678355556, 46.46291048296037, 49.640246052895826, 45.982039666944935, 48.31280616021926, 49.050168606542776, 54.892111439858716, 58.41111290839411, 66.21939874464466, 59.50722709778817, 56.58946614111624, 65.87196303952125, 62.20868110656739, 61.85628752554617, 62.25107408338978, 59.33400738623835, 62.75953877356745, 61.25054805509506, 60.40597154248146, 59.60096782253635, 68.09932016557264, 53.13539558841337, 40.24955057328747, 56.251863818014826, 52.88176336596089, 57.19401713340514, 53.79325159134404, 52.99299786167761, 56.70221467171946, 60.24236163785381, 58.212284041989236, 63.1906896252786, 60.8236921987226, 62.77930359686575, 58.48877583780597, 62.70968152630714, 61.17684671955725, 57.69637077085434, 55.36865195920391, 59.03773507764263, 62.24639469577421, 57.58003327154345, 59.00683464542512, 59.28124366268035, 50.60902441701582, 49.06146111026887, 46.559165446989, 49.38457812032392, 48.6199277447116, 52.055316048283736, 58.411383551936, 57.491615203119096, 58.226133931067686, 51.365939878648334, 48.348048656217514, 48.81571677423293, 48.18718048834032, 48.10894097051313, 50.044199189832135, 55.06963399148757, 52.47861823728008, 55.13424327296596, 54.77113769900415, 52.94450167686709, 55.966527077459524, 59.87645549158896, 59.57600193638956, 64.08935954493862, 62.74488087623351, 63.37904576332339, 67.12817268986856, 72.6286849667949, 67.32291052418371, 65.51044602547923, 58.83868263613794, 4.349537857117192, 0.30932178901087853, 0.5420199541314956, 0.6937197043049721, 1.8566834614161525, 0.3822597332539097, 0.04329047946920318, 6.728360739446456, 67.57725269563737, 34.683777901434134, 41.21091565778179, 62.12531112855481, 47.58553989471928, 28.466005325317386, 39.808174102537095, 46.893214102714296, 61.03593164874662, 65.86276900383734, 56.553925544984885, 3.1879951011750007, 0.09265389879264178, 0.08051162735829431, 0.07704414487365754, 0.07186498447892166, 0.07095036742788169, 0.062001943362936865, 0.03977930315980508, 0.040303445195839296, 0.006464698066514347, 0.02971922231447553, 0.08341829517796155, 0.03991491604416121, 0.03970672398985874, 0.04648544149653566, 0.05466284020052803, 0.15894870393939559, 0.2059848937055757, 0.22708500825589706, 0.15734762614292486, 0.09999221671492824, 0.12283558731958752, 0.17873968147943098, 0.16606892429051862, 0.13123021791538886, 0.16307856136512372, 0.18089626495155597, 0.1018401203797229, 0.24696796231212156, 0.4118899304059244, 0.4255420768693571, 43.91233828759963, 102.46221680794994, 77.80047908906015, 81.06578949959048, 69.370144567182, 53.952091893842145, 68.81514487727996, 80.5892764368365, 64.11687497169741, 82.62406872164819, 16.28512005652151, 0.3293500546245806, 0.12393574320500898, 3.9746031501600823, 11.20258633167513, 12.447578003329616, 22.153203525850852, 6.001254800827273, 6.48589599517084, 71.51304521868306, 77.71839172609391, 80.68713172789543, 75.50499039311563, 74.72687844307193, 70.2267352996334, 79.4735582413212, 77.11546851742652, 80.30432408855808, 75.07007014366889, 74.55261538105627, 67.03927609228319, 75.74452953953897, 61.682632430907226, 62.360692562595496, 55.845451354980476, 55.44402030206496, 53.631253780857215, 56.61756207866054, 54.42261549734301, 54.857861303514056, 52.95721800096574, 64.16353156489711, 68.68156463869157, 71.10660137668734, 68.0393785045993, 70.00626671698787, 67.50633624292189, 64.37099749042143, 62.16118120378064, 58.72332180699995, 53.08806434754403, 49.13181666404971, 49.8568981693637, 52.19677632854831, 47.85153542795489, 50.251574900842485, 51.70083576633085, 57.06430435180665, 62.16970451416508, 70.04017168475737, 61.40219080832697, 59.62996590522028, 68.07890030645555, 66.17539759605162, 65.75751612263342, 65.850036990258, 60.24922578565536, 64.7348600818265, 64.9371837800549, 64.58951273272115, 62.673987957739065, 70.17335184158819, 56.44953166284869, 43.579160398052586, 59.29572113098637, 55.043279586299775, 58.28734251760668, 54.16834785092262, 54.298935321069536, 57.47986378208284, 61.49342121616487, 59.973306655883796, 65.94060451753678, 64.78406621563819, 64.61624760781565, 59.72001960200649, 66.32342784635483, 63.62802997712166, 63.04079232677337, 58.11677040592317, 61.497116088867195, 62.72332352976646, 60.38061734168761, 63.88531392620456, 60.070012692482244, 52.25289367860364, 50.77940041019071, 50.137896768508426, 51.71094371426491, 50.29062601827806, 52.9470080714072, 62.77285914267264, 59.41114864041729, 60.88156284824495, 53.816060173896055, 50.65956023431594, 52.319491601759395, 52.06999355746854, 51.07995986938477, 53.28950159011349, 58.442801737016254, 57.56759151335686, 59.768233376164595, 57.215013580937544, 56.63551476693923, 58.93462773292296, 61.68806099122571, 63.04296924221901, 65.57358049577283, 66.38342442051058, 64.83550810044812, 70.12565582029282, 74.85543020309942, 70.80489266303279, 69.37769120739353, 60.58446291954287, 4.833161686697315, 3.947829541660125, 8.399782200013439, 2.97519181043871, 3.212957310099756, 0.6547807421415084, 0.22109665216938143, 10.711097659603244, 75.29886199582008, 54.07193991445727, 43.34930950595487, 59.66365906500048, 59.43540849993306, 32.977605712029245, 43.75037185607418, 57.02080526659566, 71.69269761731549, 73.69605602756624, 64.30675691173923, 4.487114010318633, 0.23858861517040963, 0.10813023849961259, 0.14839634840046206, 0.17730277632513355, 0.18241691883773575, 0.14667790593399158, 0.22725518702739672, 0.07999765896989454, 0.10006841181987718, 0.11665685838388822, 0.18233079523328813, 0.13897764977187882, 0.12461221416390712, 0.2545258640161445, 0.17226787794741893], [0.06167161008042674, 0.033141580305152366, 0.020194818874100046, 0.03819470391458562, 0.03361042994525164, 0.005806849268640602, 0.06971760938364653, 0.07710777613664828, 0.0630381653806375, 0.0677206633131831, 0.059014855463418274, 0.05944871786801566, 0.048743631210057974, 0.045812391120219426, 0.23529733290835736, 47.08808137524513, 72.13348573254001, 66.04592015666347, 61.40564641644878, 23.291316493864983, 25.418231525728782, 30.93785947368991, 42.65985488891602, 45.52601314360096, 60.26516237566548, 5.457480934358412, 0.06977568650918622, 0.3630037455549163, 1.6217745504071637, 0.7355318026196572, 9.994274704687058, 2.2032514647130044, 0.52110219915067, 13.368137690328783, 69.2738974478937, 71.40371307249993, 73.89665388291883, 68.90899935076314, 66.39358335925688, 63.47527719313099, 71.32592462724256, 68.5848468349826, 71.09660717748827, 71.00290175407164, 74.6444929799726, 71.66901434621504, 67.65866541093396, 65.51554902907341, 60.46384611437398, 53.929075425670995, 51.09340967670564, 48.29017016195482, 46.52485255272158, 47.01912218524564, 47.64830173984651, 45.64222120469617, 55.16881504366475, 65.2716285951676, 63.40842431591403, 60.71918849022158, 61.959630212476185, 60.71677623256561, 61.2927213791878, 58.884154673545595, 54.975281376992505, 49.570572991524976, 46.10355861725346, 45.62159345995995, 45.967703403965125, 43.48639242110714, 44.50106251624323, 44.26612431003202, 54.07235568569553, 56.724274081568566, 59.8820762480459, 57.12973340865105, 63.05515604634439, 59.43610275945356, 58.37391707205004, 54.23440448699459, 56.91515230363416, 60.137846162242276, 60.30005970308858, 55.302481574396936, 57.14592495272237, 57.78185098401962, 64.16015048180857, 50.51053370198896, 39.09279654102941, 53.45859104587186, 52.55611250477453, 56.559401173745435, 50.85037177608859, 54.346270484309045, 56.4765920946675, 59.00132371533302, 55.69563642624886, 56.29689262759302, 57.52918758699971, 58.21088375583772, 58.07313796012633, 51.17507342369326, 56.35005251053841, 58.89965588046659, 55.78668640505884, 57.88440135217483, 55.42516546864664, 55.73739397910334, 55.788047467508626, 60.347253661001886, 50.98281452732702, 45.44195675080823, 45.44800112324376, 45.93706577054916, 45.32545058957992, 47.24736490557271, 51.040771468993164, 53.43655517024379, 48.971936933455936, 47.61424379964029, 46.144308120973655, 43.80961141278667, 45.26157479132376, 44.92009324412192, 46.98102812613211, 47.6229279272018, 47.88990405298049, 49.28246313525785, 52.475205775230165, 54.05268892165154, 54.59347786441926, 55.58483339125111, 61.7504462888164, 65.14617158520606, 61.0839218478049, 65.64951758230886, 66.04686937024518, 69.5566140451739, 69.02249705406928, 57.02997969042871, 58.857729665694706, 43.147864418645064, 0.850497575536851, 0.6354170424803611, 2.6098119972213625, 0.37851086667468475, 0.16973482354754404, 0.05380983960123793, 0.33299960556530184, 38.06448444243401, 54.81467600791685, 35.583506861040675, 64.84976983839466, 75.50268403945431, 23.63394533434222, 20.791962608214348, 37.78957336179672, 56.54473935404132, 52.15563851018106, 62.26849332932503, 11.317057763376544, 0.1087187932083203, 0.06412110727040038, 0.05041169573462779, 0.02583468922473971, 0.07729719137592662, 0.03336810867392248, 0.01500712521749759, 0.008146633570563168, 0.035451132383558064, 0.009074406266482848, 0.04290607187055773, 0.028234482630186027, 0.015928303811609024, 0.06240047379246643, 0.04142135133846633, 0.0454858499729345, 0.09612988485323806, 0.017419697927130808, 0.07725442068711405, 0.04894635339658107, 0.0676552317435703, 0.07452114154734919, 0.04386485772087209, 0.030564638643315246, 0.09864826100848376, 0.07211473680311634, 0.10539288377209056, 0.026031849612932534, 0.10688224296656348, 0.7416057766925904, 63.118874949793664, 82.55195202366, 74.1889802871212, 67.67141311399399, 38.14910957890172, 32.5608068127786, 27.269117601456184, 31.67338821195787, 50.63615152912755, 67.74890345911827, 5.177007932816783, 0.1670692665802856, 0.7659928680908296, 0.6721617449675837, 8.48219511970397, 12.239792404636262, 1.9422372190221666, 0.48623723128149593, 15.538706741025372, 74.99718466112691, 73.31985365959906, 76.78418513267272, 71.57911362186556, 70.26254653930664, 66.30364341120567, 73.83602972953551, 70.51273099837765, 72.13389365903794, 72.81972008366739, 77.3725877269622, 73.45261020045128, 70.24920263598042, 68.3419579844321, 63.67483562038791, 55.36685159129482, 54.217659888728974, 49.632938677264804, 49.21134271929341, 49.3153404420422, 50.056389916327696, 47.95504677680231, 58.3124182301183, 67.38550370739353, 65.9383216980965, 64.32742388017716, 64.19416919831308, 63.473080665834495, 64.62837557638845, 61.591519694174494, 57.37576407770957, 51.37675777558358, 49.75642665739983, 47.85767001490439, 48.35131206820088, 47.08994450107698, 45.14029118322557, 46.58053451968778, 55.87311583180582, 60.3146783767208, 61.69430932691021, 60.21018643533031, 62.493676600917695, 61.51022464998307, 60.71325394415087, 57.34353788437382, 59.46548915678456, 62.075889264383626, 63.21473767680507, 58.35370117618192, 59.89230971182547, 57.901981415287146, 66.1067404285554, 51.544697976881466, 40.58729410171509, 56.19953547754596, 55.53020261949109, 57.02309593077629, 51.52087350045481, 53.200259823952955, 58.68247032165528, 61.53356275250835, 57.24950298186272, 57.281348705291755, 59.23954102300829, 61.10787968481741, 58.86051847088722, 52.791282130825905, 58.79577582882297, 59.38262124215404, 58.99227088497531, 60.13379827622445, 58.771923895805116, 55.769526035554954, 57.711009056337424, 61.72660612290906, 52.167860615638, 47.035517692565925, 47.841584374827725, 48.59301244058917, 48.16021811577582, 49.746710946483, 52.41580540134061, 55.14528474500103, 50.89334526369649, 48.30025457566785, 47.27460184404927, 47.237013770687966, 47.310040458556145, 49.147564980291556, 47.88850376682897, 49.277815126603656, 50.48765843914401, 51.431008077436886, 55.131670198132916, 55.777582583888886, 56.487268786276545, 58.772053334020804, 63.16428815164874, 68.26333015195786, 64.49406969931819, 66.62973357785133, 67.87179916135727, 69.4025904132474, 69.48421493653329, 61.286959417404674, 62.373867804004306, 50.08337190074306, 1.7998613104704888, 0.1064240764225683, 1.2242897696072057, 1.7976256820463368, 0.49792512830707336, 0.08626304011070922, 0.36682695330631354, 38.413065479647734, 63.126358832082445, 23.710823789719615, 64.15340792748236, 65.98058131433302, 26.180459837759695, 32.49790768469534, 47.53951480311733, 65.54814000283518, 58.46479054420226, 71.95162111713041, 15.980725499891467, 0.09998403489589693, 0.021900686007293484, 0.010398217690958372, 0.015664659440517426, 0.04869154872252576, 0.021392811848331365, 0.054778753133911284, 0.04333414265044755, 0.02302934610915761, 0.029961242896294402, 0.023932230523637226, 0.032260625157505274, 0.0823810121284858, 0.011952929931031841, 0.012262427537221343, 0.12197813574945736, 0.2338222306101553, 0.11276637279098073, 0.32681225047957513, 0.08587505488145737, 0.13540787922759212, 0.15920989395629975, 0.17057293905846535, 0.09618891958868313, 0.23924173576937569, 0.2382652954228463, 0.2504739024105572, 0.18071591253242186, 0.21695020127921336, 1.2203805148601532, 74.24285796380813, 94.12772147886216, 83.18291233431908, 81.94912295187675, 36.047487951094105, 36.156824019647416, 41.374733448028564, 60.914973597372736, 63.44567506544052, 72.0846914475964, 7.394083546053979, 0.22475415510275673, 1.1885242500612814, 4.491678668606666, 6.992078356204495, 21.68216216948725, 9.782464754196907, 1.7485025308785902, 19.15807381752999, 80.23980894396382, 76.68192894228044, 80.27990341186523, 75.15296551489061, 72.99357521918513, 68.18998182973554, 78.70562091950448, 73.77242457482123, 76.29650900440832, 75.5157769110895, 80.71861267089844, 76.66813004401423, 72.41436666057956, 70.85418901135846, 65.45943167901808, 59.92535568052723, 57.53009365450952, 51.31448622672789, 50.3285631825847, 52.05002084855111, 52.933993647175456, 49.728620975248276, 60.66772307119062, 71.06610682702834, 69.24258908917828, 68.52138288559453, 66.60174354430168, 65.6438026889678, 69.07169926551082, 64.03414041765275, 60.36505337684386, 54.65289785015968, 51.40845444894607, 50.28839418965001, 50.37024228803573, 48.36194561373804, 48.26743610443608, 47.574019893523186, 57.36618957211895, 61.14125905498382, 64.33755928470244, 61.42745479460686, 65.43057872403052, 64.85280575290804, 63.905059137652, 60.08946372616676, 62.011444722452474, 65.4113708772967, 66.32957027804467, 60.73384638755553, 61.90215964471141, 63.6193536943005, 68.80359741949266, 55.20246897974322, 42.51171873461816, 55.922827951369754, 57.45536073561638, 60.84579083227343, 53.715776935700454, 56.22698422401183, 60.57624555403187, 61.912047939915816, 59.95464009623374, 60.14327864493094, 60.9119886736716, 62.890385120145744, 60.948651067672245, 54.32148110482001, 60.25632919803743, 63.132956258712284, 61.66011410374796, 62.318746735972745, 61.05867747337588, 59.688934818390884, 60.682153471054576, 65.63471455727854, 54.66812449116861, 49.94775595203523, 49.39103434162755, 53.16124400784893, 49.52906254799136, 51.76580982823526, 56.80272932975524, 58.05046666053034, 53.32035495388893, 51.92211627960206, 50.1386930096534, 47.71951237032491, 48.81231607929353, 51.12012886231946, 52.2324542076357, 51.61366893399147, 53.63632540549002, 55.71298114715084, 57.66492512918288, 58.38961047510947, 60.14101151497134, 60.97471129509711, 65.68459141638972, 70.87217700096869, 67.0070577436878, 69.76420156417355, 70.09569675691667, 74.44271841356831, 75.52191934277936, 63.74974112356863, 64.80603541097334, 52.0027837445659, 1.9740445767679524, 4.109608925157978, 10.033633728181163, 2.683085058965991, 0.42574735778954725, 0.179923624401131, 0.524893598931451, 45.80320704367853, 71.84544255656581, 48.95072867793422, 69.56715737619709, 83.32706728289205, 32.29169299525599, 30.620080809439386, 51.14664800705449, 74.01375232204315, 65.28503525641658, 83.37294332442745, 19.62683431563839, 0.2562170490742691, 0.13033542721982927, 0.11862355930310105, 0.2784942883637644, 0.1905362250944299, 0.08121774591986211, 0.16953197878695306, 0.1237400230621138, 0.13313803731674148, 0.126508618855188, 0.1466197138952632, 0.2575541636155498, 0.17545146356907584, 0.1533603070363883, 0.12656082774722768], [0.03383483242003187, 0.035569929637976234, 0.04659727884216174, 0.04689149490948166, 0.07103722647673662, 0.012514815203875545, 0.004010087718451095, 0.06399359576584351, 0.03176447022856484, 0.00770126021609852, 0.0816470998970251, 0.08543569579600327, 0.055300416875510454, 0.15233310570399608, 5.285552172891555, 74.40485185192478, 64.94963338298183, 63.91719102859498, 49.37588614802207, 25.627462517830637, 46.62606539264802, 93.64618778228761, 43.18669588335099, 59.08306983209426, 51.217195756973766, 0.19977334556320023, 0.03190896398718319, 0.14512947369967738, 2.745123471944563, 8.72562917970842, 12.639161271433677, 1.030498942540538, 0.6946010118530643, 29.709157405361054, 70.85005483319684, 71.36035519261515, 72.24112341480871, 67.4660535012522, 66.14768212841403, 61.15452451090659, 61.84476752435008, 62.38980047164425, 71.31083919155982, 70.23477615848665, 68.13623751363447, 68.30084370028588, 69.80040504086402, 65.54751242360761, 62.77782486331079, 53.924953014619895, 49.251272447647594, 48.4095984889615, 48.97113284757061, 47.51364284946073, 46.40060363277313, 46.05749430194978, 48.093851612460234, 62.968938427586714, 62.26209986594416, 61.467055043866566, 60.85121547022174, 59.940044956822554, 62.43301714620283, 58.01749913923202, 52.640651349098455, 49.10331280000749, 45.435818241488555, 45.25807603713005, 45.710050752086026, 42.873169068367254, 46.01812939490042, 49.78043548522457, 56.909904172343595, 59.018397792693115, 61.95037341886952, 59.39387059980824, 63.23429461448424, 57.40328734920871, 58.12849437036822, 51.99984981167702, 54.401360173379224, 54.5801692624246, 57.70097955580681, 53.06773862531109, 53.31445570914976, 53.213737087865034, 65.01585475860104, 48.75307652258104, 36.64373920809838, 58.64947534376576, 55.41937212790213, 60.42753281131868, 52.234564442788404, 53.09518344940678, 56.570897640720496, 58.13058499367007, 54.02047057305613, 54.676514440967196, 56.37643829468758, 58.21099750457272, 58.3731718217173, 55.63705190535515, 55.3857966392271, 60.61129585389168, 58.95275300548923, 58.53951169598488, 56.09917771431708, 54.64744967799033, 53.39089878143803, 57.235264778137214, 53.269862282660704, 46.293193447974424, 41.32726100183303, 45.91342172315044, 43.25801634019421, 46.206242345994525, 46.71399316480083, 49.43502372311008, 45.60833192640736, 45.71493018058039, 44.76506548543131, 47.05793796047088, 44.72965432751564, 45.88899712408743, 45.910617228477236, 46.0135559112795, 46.53690599626111, 50.690468511273785, 51.62823661681145, 56.56835594484883, 59.01522459522371, 61.605526478059836, 63.844584034335234, 66.67959474748181, 63.36063415773454, 66.13982954332906, 61.86307714831445, 66.5572246428459, 60.64055281300699, 69.93859014203473, 62.50245878773352, 65.1060418159731, 33.7992363591348, 0.5582130303786648, 0.4950398879666483, 1.459968813484715, 0.0655811176364941, 0.038667069898257335, 0.14770748213894908, 13.275555045373979, 62.67214444375808, 43.96805947826755, 33.78875970840454, 33.294948993190644, 41.6938574852482, 16.148552933046897, 25.010165783666796, 45.214247472824596, 52.52444328800325, 56.76124242044265, 34.86511299687047, 0.04962893007623573, 0.00397783589564384, 0.017010026663962393, 0.013976418075241871, 0.02776497223925206, 0.039608304674226436, 0.05625951682187377, 0.02067007109402649, 0.03531205678178418, 0.02552784036754841, 0.042313269204309875, 0.04461955391771851, 0.043104316273163405, 0.06356980741745041, 0.04186835981184437, 0.047034121328784574, 0.049284795719769695, 0.022894646784651185, 0.03363894373779336, 0.06222086064817925, 0.03771171995228337, 0.023521588244024786, 0.03819097306639437, 0.05240083919958242, 0.04358484875410796, 0.05302400959114875, 0.029344996024343758, 0.1262263997247623, 0.2171398999710237, 9.283562802499342, 89.32630108248803, 72.29394205154912, 68.6370849609375, 59.46468114852906, 32.399748409948046, 37.306098091986875, 73.1794406521705, 43.63841956661594, 70.70761788275935, 51.23896098905995, 0.18331350217903816, 0.1747394308087326, 0.8616931231752519, 4.719112890381967, 9.467951463114831, 8.962797253362595, 2.017434080762248, 0.31720201454816327, 33.322691917419434, 72.64113456972184, 74.59980933896958, 76.35672523129371, 69.71779992503505, 69.2793809213946, 64.21372221362206, 64.83002070457705, 67.03025464088687, 73.98702529168898, 73.7146088384813, 69.20938230329945, 70.3128234801754, 72.36989482756584, 69.90412819770076, 65.70036718922277, 55.71899414062501, 51.069118438228486, 51.04869857911141, 50.71486565374559, 48.42162447590982, 49.4589658706419, 48.59494224671395, 50.94982347180767, 64.7679570413405, 64.36335671332576, 64.96778611213931, 64.46512652981666, 62.69806738822692, 62.76278257369996, 60.58168588146087, 56.2160918020433, 52.14322420858568, 48.4728035619182, 49.23437487694525, 48.708388959207845, 46.42753462637625, 48.47295261198475, 52.842606344530665, 58.80957080471901, 60.45432652196577, 63.217655920213275, 59.091153837019405, 64.23965692520142, 61.47458599459741, 59.66482008657148, 54.697373605543575, 55.368640192093395, 57.51612217195573, 59.955428492638376, 55.46853903801211, 56.775833637483665, 58.006775379180915, 66.04977976891303, 50.986325048631244, 39.449912655738096, 61.19951801915323, 56.870660858769575, 62.53729335723385, 55.67064308351087, 55.199487978412265, 57.00721425394858, 61.59918792786137, 56.83490453227874, 56.678833423122285, 58.629082941239886, 60.44685440678751, 60.8968718590275, 58.25803849004931, 57.91807490010416, 61.97231123524328, 59.503751877815496, 60.17099019019835, 58.12522311364451, 54.507240633810724, 55.365823930309666, 60.15318655198621, 55.821473906117106, 48.16440328474968, 44.8940840075093, 48.41441123716293, 45.76619555873256, 49.31510902220204, 48.66565081381029, 50.89499658153903, 49.3646328679977, 47.885440395724395, 46.6553262741335, 48.97368238818262, 47.83034678428404, 48.392387128645375, 47.661516204957046, 47.218613932209635, 49.61921822640204, 52.50381162089687, 55.08933997923329, 58.59296967906337, 60.782797567306034, 64.12126018155006, 67.68131317630892, 66.7923628899359, 64.50850794392248, 68.34118919987833, 63.97597166799731, 70.12505962002662, 64.78669420365365, 71.25979346613731, 65.00756286805677, 68.45362786323794, 41.19608125379009, 1.0126728119869386, 0.31529175898721146, 0.8240494011871277, 0.8013609412216371, 0.36284412347501327, 0.15862117070824872, 12.498524688905286, 70.46799244419222, 45.52125530858194, 27.956693403182495, 33.486956857865856, 36.00795045975716, 18.89000923402848, 31.74848983364721, 51.387638430441584, 57.20589799265708, 64.9168384459711, 47.363114049357755, 0.421350380826381, 0.01047526698394288, 0.031120567582547668, 0.06032214620180669, 0.004180953575057849, 0.02381358265636429, 0.04671442134666347, 0.07144197370977172, 0.054724847357119286, 0.04616774100389692, 0.05144665753769298, 0.02150347516421349, 0.02132522565643153, 0.022478459943686763, 0.07544766360473248, 0.11067040219542482, 0.20419581793248656, 0.09542302318638372, 0.13553681182524852, 0.11580864583412487, 0.20579594577993118, 0.26384803556626846, 0.18522574956859314, 0.0956250788764127, 0.11751282374344527, 0.11574099260953166, 0.1477795403691069, 0.3013693060605757, 0.3028487137729122, 11.505608058744862, 100.90457300986014, 81.5234830302577, 80.79305141202866, 65.18793306043072, 36.9307743349383, 59.55041239338537, 112.69502947407385, 62.91274655249811, 74.69345200446345, 58.8172939515883, 0.47242052913192784, 0.16465195274401098, 1.131398483149467, 9.601650353400938, 16.643381503320512, 22.046240491251794, 8.328658842271375, 1.4044059885125006, 39.15906498509069, 74.50393092247748, 76.8211103254749, 78.96404235593735, 72.88837725116362, 74.55596508518343, 66.93595301720404, 66.8624242659538, 68.56319535163142, 77.59719048776935, 76.49924062913465, 71.01152312371039, 73.17257650436895, 76.29595202784385, 71.38895711591168, 67.8652644926502, 58.96437498830981, 53.414056454935384, 52.61525400223271, 54.32675669270178, 51.06601192105202, 50.93625207101145, 51.589165887525006, 53.16417009599748, 69.37685182017665, 68.53030235536637, 67.61781784795946, 66.39678401331749, 64.70168859727922, 67.79266926550096, 64.85199774465254, 58.32205549363167, 53.97805406201271, 50.7670331770374, 51.27946730582945, 52.42256364514751, 47.34340806161204, 50.34772788324664, 57.1836228524485, 61.899355150038204, 64.46494610078874, 67.0905650046564, 61.39975109407979, 70.07184874626898, 64.81854777182302, 64.33498620986938, 58.56840779704433, 58.9804567060163, 61.305692657347656, 62.636427340968964, 59.315556556947776, 59.71930180826495, 60.10975414706815, 69.40567339620283, 54.41877941931448, 42.24479359965171, 61.27004615722164, 60.69401864082583, 65.06732410000217, 56.43179862729965, 56.04562167198428, 60.33640830747543, 63.20448852354481, 59.49245545171923, 61.626726888841205, 62.685437356272054, 63.62380166207591, 63.93923082659322, 59.328053228316776, 58.98620690068891, 64.68561080194289, 64.01259876066639, 63.275597172398726, 60.377302938892, 56.20999251642535, 57.97637308797529, 61.85442439971432, 57.2903113211355, 51.90043733965967, 46.00196138505013, 51.501379320698405, 47.85369665391984, 51.55650038872996, 50.233194674215014, 54.307619448631044, 51.15921920345676, 51.20003538746988, 49.94955631994432, 51.86220991996027, 50.78954365945632, 50.90074677621165, 49.74456540999874, 50.423029545814764, 51.837063604785556, 55.29677060342605, 57.947935904226, 61.33795022964478, 65.23878266734462, 67.36748433882191, 68.97024323863369, 71.26443755242133, 67.380734105264, 71.5661854897776, 66.44255022848806, 73.64542607338198, 66.86393830084032, 75.61495796326669, 65.84034089119204, 70.97975977005498, 43.76153884395477, 1.1924474782520726, 2.5591908683699947, 6.925949156284333, 1.204119471292342, 0.3478300871868288, 0.27455917048838835, 16.119918650196446, 76.32472653542796, 60.918378214682306, 41.872031150325654, 40.39841628843739, 57.710793325977946, 24.91121222895961, 37.01470913425569, 58.8652684611659, 68.47127068427302, 73.33498616372385, 55.05171660454043, 0.7357924563750144, 0.10901327740641371, 0.2304741505893969, 0.10335872115026559, 0.08827772111661973, 0.2773790175635969, 0.1673618355585683, 0.15460282504077882, 0.11944890412832461, 0.1985261850659886, 0.20949392879922546, 0.21658356692041122, 0.12199391716069753, 0.1474034524853191, 0.11181578025101654], [0.04146761538821363, 0.004855949335896801, 0.0695585695305659, 0.02896183906423469, 0.10483600679905185, 0.01782050938345492, 0.046007582662446846, 0.03879409493698228, 0.058932504841997746, 0.032728812131550045, 0.07504661657637166, 0.0502221119560061, 0.1323127614394311, 0.3142014013663415, 19.190347079307802, 78.29434471745645, 64.02138486985238, 65.77074627722463, 36.29229876302904, 22.76946279310411, 55.13376474380494, 45.394009697821836, 33.17639927710257, 76.0935655716927, 26.913423345934962, 0.053951083231837525, 0.05487260656551488, 0.7671788947716837, 0.37048061047830894, 13.130993150895643, 9.004291026822983, 1.4348998425468322, 1.5813613899292485, 45.21151750318466, 66.90310708938107, 64.83424117488246, 71.56380068871283, 70.81840915064659, 70.22136949723767, 63.29672305814682, 58.728711143616714, 54.82817680604997, 60.732752046277454, 62.66334656746157, 67.22352550875756, 69.41599707449637, 67.80122003247662, 66.86359313226515, 62.86730981642201, 51.8782014231528, 49.85223839359899, 48.91829852134951, 50.96904700802219, 47.598228762226725, 45.92647537108391, 45.92048198946061, 48.76265102817167, 52.107040343746064, 60.2884808663399, 61.33085466200306, 63.16214653753466, 61.43232637836088, 60.31383114476358, 55.56764556515602, 55.21266714219124, 48.744757175445564, 45.74368899868381, 43.89661350557881, 46.3302755355835, 45.73351044808665, 49.1304712910806, 56.11938968781502, 57.883334467487956, 60.32065214649324, 58.2889546117475, 55.803560441540135, 60.835031770890765, 56.48740606923258, 55.62223319084414, 45.862870216369636, 50.59814768452799, 50.79199121844385, 51.3323369333821, 46.281442026938166, 52.68524869795769, 55.39992109421761, 65.37548903496035, 46.458062433427386, 37.40614598797214, 63.24819157200476, 55.147818596132346, 61.999708990896906, 60.7372510048651, 53.54429483413697, 56.456568394937825, 59.87692617600965, 53.702723287766986, 51.73859250160956, 50.257140744117, 56.9545485896449, 56.46477791570849, 59.31450143937142, 57.82908808800482, 56.07898143029983, 57.885079922214636, 58.43957754873461, 57.600492354362245, 61.407584067313906, 53.416531470514116, 57.08186088069793, 58.564367755766845, 50.11016953376032, 43.823029841146166, 43.84503826018303, 44.1018593695856, 45.39038150541244, 46.749110144953576, 44.51396711411015, 43.65672919058031, 43.848329128757605, 45.76604258629584, 46.16819143295289, 45.96302793871972, 46.26146931802073, 44.888298511505134, 47.42867646678802, 50.18917391377111, 53.742319614656516, 57.41368163016535, 56.75462538196195, 61.67343055048297, 62.02993477544477, 63.74231215446227, 64.64650869369507, 62.4927548439272, 62.409992833291334, 64.39084468349334, 61.55917975210375, 65.90168676068707, 58.17406446703019, 68.71152370206772, 63.60380149656727, 68.40164861371441, 30.42673149416524, 0.09694739259899625, 1.5685899075000518, 1.1508250020204054, 0.0795404117314085, 0.047108569753266154, 0.47955528983185375, 48.267102702971435, 54.31772347419493, 27.27910787828507, 29.747320105952603, 60.57968547267299, 47.7276316765816, 25.05328439897107, 44.36344615874752, 47.05633763344058, 58.70677332724295, 53.92086590490034, 2.680305569402633, 0.18918227194057358, 0.0656142815827362, 0.04479445945171099, 0.061408301830411925, 0.006883914785219297, 0.0063130294156801565, 0.012501465164185053, 0.0026808071444036382, 0.0403919666554899, 0.020889116698996197, 0.019170980667695403, 0.018805254123083526, 0.011395333792954203, 0.027628252357845346, 0.09194166684943823, 0.0619177962653339, 0.08516855327592743, 0.04480538769595085, 0.04271427409783487, 0.07539736227162423, 0.031086516889533213, 0.0669349558771618, 0.08675285374685641, 0.04574155096986121, 0.03599519653606319, 0.09608129189620096, 0.20481782003996835, 0.2441764451683529, 27.105293927654145, 88.94883571132537, 71.65532527431365, 71.42366224719633, 46.56411547814646, 31.00837976701798, 44.95869328898769, 45.528205748527284, 38.50101678602157, 84.43753734711679, 27.822920968455655, 0.07163226228928374, 0.1608304610295642, 1.6263203322887423, 2.8066931616875435, 5.912448417755866, 4.128417670726776, 1.051633408473384, 2.1829122593325954, 51.608291364485225, 68.65198212285196, 69.17113134937902, 75.15644073486328, 74.3743593462052, 73.17638904817643, 67.280760734312, 61.75996980359478, 58.13122434000815, 62.36476790520453, 63.86979702980288, 68.76744101124426, 70.56860908385246, 70.39039227270311, 71.25817744962632, 64.98445226300147, 54.53387744965092, 51.28868095336422, 51.15812878454886, 51.47016902123728, 50.38742619176065, 47.68269308151738, 50.579465435397246, 50.68644415947699, 54.0934423477419, 61.771238773099846, 64.9163403049592, 64.44312987789031, 63.69608309961135, 62.20098149391913, 59.36066773629958, 58.738517069047504, 51.22307931223224, 48.30174115396316, 46.959004017614554, 48.56573235604071, 49.075165871650945, 52.299722856090916, 58.48672051583567, 61.41020028821884, 62.420861721038825, 57.94328789557181, 58.84436222814745, 64.2074268094955, 58.97598912639003, 58.982708146495206, 47.92200080810055, 53.0515274693889, 52.59504987347511, 52.547922595854736, 47.38652667691631, 55.362670344691125, 57.2638863132846, 67.40519400565856, 50.712771108073575, 38.30649860443608, 64.04447978542697, 57.470865864907545, 63.46845226903116, 61.44533295785228, 55.94505210076609, 56.761038457193685, 63.52088651349468, 57.060456506667606, 52.445058438085745, 52.951483495773815, 58.53474993859568, 58.17513527408723, 62.46740064313335, 61.06582795420001, 59.849402904510505, 59.71081772158223, 61.66657816979193, 59.147082913306456, 62.25467874157814, 54.84583923893591, 59.89758137733706, 60.69482664908133, 52.6267740034288, 46.4283779359633, 45.71543224396245, 47.40245149981591, 48.053992486769154, 48.2894366787326, 47.15476559054467, 45.397488840164684, 47.33707343378375, 49.89837331156577, 47.401765085035755, 49.13582140399564, 47.98441748465262, 47.50528035625335, 48.52958771490282, 53.45961086211666, 55.782611062449796, 60.36398649215699, 59.932215905958614, 62.7934790426685, 63.01208842185236, 65.70565846658522, 66.55965651235273, 64.93741519989507, 65.54215054358205, 65.92737044057539, 65.10007196857084, 68.5792064666748, 62.64560176480202, 70.50039906655589, 66.65558199728689, 73.7026926778978, 36.926808818694084, 0.17914581533160903, 0.044785978858389204, 1.234099739982236, 0.5365911486648745, 0.09898501793823897, 0.4514997097994051, 50.03001589928904, 61.92751384550526, 30.694654872340543, 30.775285074787757, 52.81139604506954, 38.33515936328519, 31.16414297011591, 52.030236413401944, 54.6919999584075, 65.02903784475019, 65.89319875163417, 4.468170433275161, 0.2651416516352085, 0.06729019084765066, 0.07173701715204986, 0.04661529723014082, 0.014700517678002437, 0.061584892757837816, 0.07611347828060389, 0.022386962232450326, 0.035016994187307936, 0.06765521642181181, 0.0535467803297985, 0.006187249269832167, 0.04754543139208709, 0.0051333698830867735, 0.156443519818206, 0.11748620984895576, 0.15992060904541325, 0.1574322175715239, 0.18026764384440838, 0.24620244129290506, 0.18316362473753192, 0.12803616753268626, 0.17751259248583548, 0.18594783340250293, 0.22818979897326042, 0.3553086987906887, 0.3707642775149115, 0.32900139268848205, 32.317543375876646, 102.92964566138484, 79.1141357729512, 84.48628456361833, 48.059173937766786, 34.356432576333326, 69.1900057946482, 61.10831506790654, 47.339795558683335, 90.60249913123347, 33.324825686793176, 0.31858682572360963, 0.3733606720643659, 2.8812429549232608, 4.369284049157174, 29.042342708956813, 20.542752858131163, 4.612205749557865, 2.4764580303622834, 58.576240770278446, 68.49355759159212, 72.00871513735864, 77.68559286671301, 77.02140223595404, 76.3101431631273, 72.60338567918348, 65.83390820410945, 59.77716069067679, 66.19668822134695, 67.39341905040126, 73.13532967721262, 76.52238261315131, 71.81137284924908, 72.79551121496385, 67.64754941386562, 57.71744958816036, 53.666943427055116, 53.79734654580393, 55.05299921958677, 52.50509815831339, 48.873403072357185, 53.77793081345097, 53.38754123257053, 57.48672008514405, 64.78061060751638, 67.87789452460505, 68.83672575796805, 66.07198038408833, 63.06351853955177, 61.58288263505506, 60.17710908766716, 53.55171595850299, 51.31148561354607, 48.549234867095954, 51.7948353675104, 52.61773686255179, 54.850326430413034, 61.85630321502686, 63.79198505032448, 63.318460833641794, 60.650688217532256, 59.876914408899125, 67.29390067438926, 61.35908003776305, 60.85387483719857, 50.66213723151915, 57.2825175716031, 56.21436595916749, 55.292263800098056, 51.752756180301795, 58.06350854135329, 61.818648461372625, 70.52578464631112, 53.343630298491455, 42.058473171726355, 66.10801127649123, 61.01273082917737, 66.80428689525974, 65.82545941875827, 55.59622003186134, 59.14898526284003, 65.26217568305232, 59.32128713976953, 56.41521092384093, 56.15276121324109, 62.284637804954286, 61.663095105078916, 63.424121641343646, 64.360289419851, 62.420987236884336, 63.9004268184785, 63.55509742613762, 63.597988543971894, 65.46032205704721, 56.1144200448067, 63.12269141597133, 64.39868157909763, 53.95236253738404, 48.89296001003635, 49.03397314010128, 49.941272274140395, 49.678112614539366, 51.95024359610773, 49.53232595997472, 48.72929126985612, 48.40780988816292, 52.81658534080752, 49.62605883998256, 51.28466836867794, 50.40818337471255, 50.794564293276885, 53.091680772842906, 56.0587812239124, 57.94212295163063, 63.59681967766055, 61.96289754682972, 66.84513445823424, 66.32341215687414, 70.36911733688848, 67.47273722002583, 67.93534940288913, 67.65292306100169, 67.32382835880404, 66.85235946409165, 71.71375290040048, 65.09136822915846, 76.14647050057688, 68.86585327886766, 76.1276117447884, 37.32989511182232, 0.4214875105648272, 6.305675343159707, 4.643527346272623, 0.8074965087636825, 0.2672975762717186, 1.3668624095378386, 58.53401253300329, 67.02525754128733, 43.07263728111021, 41.569522273155954, 75.95525495467648, 58.59666847413587, 36.609681267892164, 58.505963663901056, 62.829823724685184, 72.89413529057657, 73.25650738131615, 5.683948782182509, 0.43812004548888056, 0.15957050686401708, 0.13362468700976143, 0.19907269686941179, 0.17032596763343583, 0.12509511002609808, 0.24720318194839264, 0.14656673125442, 0.11786541571059536, 0.10714972256532601, 0.1676702778786421, 0.18670463634114112, 0.10538062636530209, 0.1835433285563223], [0.025456952336694927, 0.0156909458324193, 0.06376425202395167, 0.01666354616322825, 0.009681411245236955, 0.010550504478986466, 0.019471670177975492, 0.05411331384112278, 0.04746889920845147, 0.03763195487760729, 0.07581771471567693, 0.055002952595391584, 0.019102285563525175, 0.19810800831164085, 45.915304460833156, 74.91168483611077, 61.47294644386538, 59.44352388381959, 32.81911842284664, 27.81567635074739, 33.82129576898391, 36.59061462648454, 54.32077900055916, 75.34232185732934, 5.910708846584444, 0.24628137899262292, 0.09337225943923959, 0.715050288746434, 2.147794053439171, 5.34957702121427, 3.553287151359743, 1.7310208947427812, 11.279583438750237, 72.9027880391767, 72.99388900879892, 71.4619053563764, 70.79417674772202, 71.9096988247287, 70.95493901160457, 68.78997895025438, 62.07014691445136, 57.71100121159708, 53.79256517656388, 53.22177402434811, 54.63669846134802, 55.86687926323184, 58.93164280922183, 56.43373627816477, 51.71476802518291, 49.01798163690875, 49.01642837832051, 48.53367874699254, 49.13542916697841, 47.75916753276702, 47.03132467885172, 45.22654018094463, 47.375983345893125, 47.20753323647284, 51.15470455538843, 52.882116379276404, 60.72136932803739, 57.379207918720866, 57.24549039717644, 54.966452121734626, 53.37094176200129, 45.7399784365008, 44.567464320890366, 45.72064507392145, 44.016622343371, 44.85351101044686, 50.45676585166685, 58.95118013505013, 50.11352316025765, 53.83582891956453, 58.89876942480765, 56.50259348653979, 59.852701617825424, 54.5547366142273, 49.31166910356092, 43.38801937718546, 48.77291194854244, 45.057591930512466, 48.981707557555175, 45.103001209997366, 56.13155688008955, 54.413852922378055, 67.66100314355666, 42.636607000904704, 35.66634731907999, 63.06786844807287, 52.80737169327275, 57.62118285702121, 55.96507187812559, 61.44162239566926, 55.562970099910615, 59.819561512239524, 54.68360216386857, 51.462171308455936, 48.5433199328761, 48.772625615519864, 50.966156221205196, 52.255651104834776, 52.20167929126371, 55.02689976846018, 52.895648556370894, 55.85665756656278, 54.9709040118802, 58.11706850605627, 59.431266477031095, 58.812124267701186, 57.636276137444284, 54.83023212802026, 45.646704473803126, 43.69947518071821, 44.409969391361365, 46.082926950147076, 44.95551616914811, 44.20961472295946, 43.91739030038157, 47.136091186154275, 44.41632363104051, 45.16233882596416, 47.855096940071356, 44.35046703584733, 45.72563825115081, 48.060134918459006, 51.396475530439815, 57.99684001553444, 58.915066872873616, 60.72329913416217, 62.53934475683398, 63.139588986673665, 60.642117838705744, 62.78289256557342, 66.66518395946872, 61.41569945120043, 61.79973479240172, 61.332027450684585, 64.25998264743437, 72.76992951670002, 67.70967191265476, 72.80347362641366, 64.39575156857892, 66.91663142173522, 16.770136817809075, 0.733842364242, 0.5177231998212877, 0.6037939748456401, 0.14342350314461416, 0.056199091636846145, 18.498758692895215, 69.43017252029912, 42.70657424003848, 40.20177610458867, 63.90617309078094, 61.25439982260428, 20.82271202918022, 24.01905736615581, 44.241315318692116, 48.79891334041473, 58.87320341602449, 7.355238353052448, 0.24852661415934565, 0.06545387043227112, 0.05207291909403378, 0.04264454860540648, 0.04971529499837949, 0.03412055257227152, 0.10202837116535633, 0.013755759855191556, 0.02460454354032634, 0.017126692278731256, 0.032904958727979855, 0.07607559523274822, 0.08349949283705604, 0.012117326653922999, 0.03876746955117391, 0.030822205064337582, 0.01549930702294073, 0.025804382786455176, 0.02235878551859529, 0.02440818179879458, 0.014809215020748877, 0.0847615997096704, 0.14776182841629754, 0.03498923116093201, 0.02678174435371353, 0.03866632679297078, 0.027494863043689442, 0.1416305203231112, 58.022021632040705, 86.45624006948164, 67.56692901734384, 68.5062268472487, 38.47429367803758, 22.54135539454799, 43.9093808204897, 40.946924455704234, 60.327786937836684, 81.63406249015563, 6.5937415630586695, 0.39404768136239826, 0.4765109177077971, 2.581517734835225, 5.979774430874856, 9.384005877279467, 4.980238310752377, 1.2782503063640287, 14.445267608088834, 75.99982092457434, 74.91490117965206, 74.51437227187618, 72.48669516655707, 72.2053513988372, 71.78974490011893, 70.78402565371606, 66.00366054042694, 61.0697111006706, 57.76975831677837, 57.686764886302335, 58.03127058090703, 60.2446444572941, 61.6987455275751, 59.62686723278415, 54.704528008737874, 50.54289717828074, 51.84886209426388, 50.85107388034944, 51.61014272320656, 50.21018997315438, 49.510921585944395, 48.40709993916173, 49.11817466059039, 48.597440796513716, 53.15432102449479, 54.97691308298419, 64.81477445171726, 60.478201989204656, 58.60386994577224, 56.23854344890964, 54.824238746396965, 48.35730152745401, 47.01211683211788, 47.53054826490341, 48.5267989097103, 46.6438925650812, 52.93343274824081, 61.57409652586907, 54.03741128983037, 55.74687042543965, 60.95235378511491, 60.13170373055243, 62.15701172428747, 58.19846945424234, 51.65391245195943, 45.41698301992109, 49.83043001544092, 46.28966331481934, 50.29103394477598, 48.15794706344605, 57.640320101091945, 59.560892966485795, 69.33280360314154, 45.736181582174, 38.101911698618245, 66.39796072436918, 56.18512468953287, 60.364676829307314, 58.320125687506895, 63.36368183935843, 58.141434269566695, 60.91438131947672, 57.89947894311721, 53.69161121306881, 49.92552788026872, 50.986823189643125, 54.57438376642043, 54.55456010756954, 55.35606507332095, 57.2847847015627, 57.11769173222204, 57.70834184462025, 57.483735161442915, 61.13494011663622, 62.911169759688846, 61.35251399009459, 60.25972989297683, 58.75032732563635, 48.676139231651064, 46.34692991933515, 46.38037989216466, 49.00019761054747, 47.442236100473714, 47.160782506389005, 46.213710538802616, 48.92802207700668, 46.58338608280305, 48.516506610378144, 50.208464130278564, 46.73720967385077, 48.13631126957555, 50.9224178714137, 55.711443578043294, 60.435895304526056, 62.99472408909952, 63.16977554751981, 66.91602737672868, 65.79550035538213, 63.365646946814756, 65.46776671563426, 66.92795922679286, 64.43968603687902, 63.29082773577783, 63.597019718539336, 68.44634794419812, 75.65938272783833, 69.85036819211899, 74.63575393922868, 66.04423353748938, 73.42597730698125, 20.691465600844353, 0.5160861618576512, 1.05010662588381, 1.9416627143659901, 0.1510300820753459, 0.10986412529863658, 18.56690202989886, 74.38477716138287, 50.98983164756529, 44.03936032325991, 61.043176266454886, 57.2966577160743, 29.59497524845985, 29.411578947497954, 50.82587265199231, 55.16034272409255, 68.12715330431539, 11.094860396077557, 0.45189050657133906, 0.0814452893551319, 0.016189084929083625, 0.05429019971239952, 0.02057209227895064, 0.0548256645279546, 0.061059574776839834, 0.037652133633532835, 0.0691071828647006, 0.03127093340510563, 0.04797240666624519, 0.046377503538444165, 0.034870529667504375, 0.018369037913338795, 0.17461500280807096, 0.17699664759059108, 0.25715408185797356, 0.08946406189352275, 0.1125536761396835, 0.08086647162394178, 0.10314980131243506, 0.1905804283676609, 0.28103157156898134, 0.11389609967027942, 0.09719318424862239, 0.20907962844977457, 0.15207427523789868, 0.43156781804657757, 67.73789728841474, 95.73713271848618, 77.17532388625607, 80.67496453562092, 43.63812931122319, 41.42874056293119, 49.77184157217703, 51.7988871758984, 71.50233714811264, 89.33736216637396, 8.61071353958499, 0.5083178158008284, 1.0033778978451606, 4.0517694094488705, 8.86316022565288, 20.631547474092056, 14.651208712208657, 3.415885788779105, 17.71221560816611, 80.96299986685477, 77.11926537175333, 76.59944149755663, 74.79352735703992, 76.30085499055924, 76.61382090660834, 75.72812618747835, 67.6507265337052, 63.95345334083804, 60.012389152280754, 59.41177229727469, 59.10582350146387, 61.40358717210832, 64.70584630966187, 61.35394957757766, 58.43298404447494, 53.960289647502286, 53.80175136750745, 55.23139253739388, 55.36710262298585, 52.22883385996665, 52.73352130766838, 51.11182128229449, 51.64568724170808, 50.69142164722566, 56.187309449718846, 58.086379881828066, 67.11443654952511, 61.95033027279762, 60.827473363568714, 58.752884710988695, 58.54764276935209, 49.45969935386412, 49.502759133615804, 51.075755088560044, 49.68589851933141, 49.70085843916863, 56.002357928983635, 65.61384754796183, 56.35970154116231, 59.32669608823715, 60.56704759597779, 62.83006691163587, 65.96325228291174, 60.88807790510116, 55.452276891277684, 48.07009773869669, 52.515084512772106, 50.028901946160104, 53.251203567751, 49.18859689466415, 61.615512832518554, 62.740625104596546, 73.64133111892208, 48.80472237063993, 41.79658436006115, 66.91017520043158, 58.45969146297824, 64.23993149111348, 62.222915387922725, 66.59968037759104, 61.083757108257664, 64.38666343688965, 60.78269558568155, 57.81073531796856, 52.96938127087009, 53.21099927348476, 56.93585457340364, 56.796210350528845, 58.67970897305397, 59.42197045972271, 59.77714107882593, 60.51447606855824, 60.04957714388448, 63.95054686454035, 64.56644919610792, 63.802045929816465, 62.10094928741456, 61.55116634984171, 50.501916254720385, 47.231757794657064, 49.14670205885365, 51.06038331985474, 49.372822776917495, 50.197034343596435, 48.433960330101755, 52.79325116065241, 49.66288205116026, 49.18720053088281, 52.29556514370827, 49.65411163145497, 49.82060840052944, 54.52899409878639, 58.41873407363892, 62.556587496111476, 66.34839765487179, 66.92278954290575, 69.33157982364779, 67.52303769511562, 67.1034303788216, 69.93273012099728, 67.2088715337938, 65.23135369823825, 66.01611798809421, 65.41668176651001, 71.3673448562622, 76.86537035049932, 73.72047670425908, 77.93113323949999, 69.72115747390255, 76.44215445364676, 20.91686068042632, 2.2324076679445084, 5.228801850349673, 2.214501557811614, 0.29928015364754584, 0.23412403860880485, 23.423468989710656, 81.63030485953055, 58.714233675310695, 55.512818674887384, 69.56388611947337, 72.30175541293237, 29.864893151867776, 33.66105518033428, 60.81884022681945, 63.089135539147165, 76.688338095142, 14.514244448754097, 0.6684215811471785, 0.27081012004806154, 0.1272240300632773, 0.24808415241779821, 0.11334754241209839, 0.12682643043057573, 0.21938318927441874, 0.17054972659435966, 0.25812226377667924, 0.13905549962674418, 0.1070553328721754, 0.17532015609885418, 0.19827218095381416, 0.05821076191721424], [0.07001433821935808, 0.032453560570795695, 0.047320638212465474, 0.042027809521964485, 0.1272089611138067, 0.118559192595703, 0.028570255136958538, 0.03921685289711722, 0.009259499812258348, 0.046434745628146396, 0.06880808681730302, 0.1007205211827832, 0.08980566815983865, 3.207883724281865, 68.41218409999725, 64.12317822056433, 67.76461647402856, 40.519676362314534, 31.725326276594597, 54.10344831405148, 40.56549749066753, 31.93102517435628, 68.02646606199204, 51.250088753238806, 0.5355601168928609, 0.0163187280732898, 0.3003788769485489, 1.6786848321076364, 2.175424454673644, 2.400734958148772, 0.8498313854778967, 0.19953067955230513, 50.2203449895305, 77.76703696097098, 69.99639803363432, 72.74998818674396, 70.13586967222153, 69.57574736687445, 70.84301025636735, 68.24010972053775, 68.19126052241172, 63.03360654461769, 60.03336206559212, 52.201989158507324, 50.31945151667441, 48.64560750222976, 49.64510194716915, 49.65070309177522, 49.93603198759018, 49.316740728193714, 49.84339344886042, 48.2007283549155, 46.992340241709066, 47.47079095532818, 45.18291165751796, 46.89859559459072, 45.90526319319203, 45.53946295092183, 48.167960874495975, 43.245041139664195, 50.18072120604977, 55.25430310157038, 54.57966327667237, 51.236811530205514, 49.33408152672553, 45.6707525253296, 43.369980396762976, 40.87651398874099, 46.99575270375898, 45.03142579909294, 51.4201666462806, 56.143469118302875, 59.022767313065074, 51.058222093889796, 60.839652322953754, 59.60452933465282, 56.88167095184327, 50.69255521220546, 47.358548410477184, 44.29198841894827, 49.921770249643636, 44.24501019139444, 47.29860674950385, 45.25157666975453, 55.186650060838275, 54.67365503311158, 66.53503187241094, 41.51260475958548, 40.19846170179306, 65.72958492463636, 52.44911416884392, 57.20173635790425, 54.63653372180078, 57.843702839266875, 55.28616059210993, 59.8048722359442, 56.01232859396166, 51.8364477926685, 48.99871103225216, 51.622290303630216, 49.03384762425577, 48.69906156293808, 45.40385092458418, 46.08516662351547, 48.637696081592196, 50.26050221535468, 51.60222345782865, 58.22098778140161, 57.135530671765736, 58.13084779247161, 57.422867821108916, 58.394505593084524, 51.07101686539189, 43.41479739835186, 44.93164854664957, 45.40081108770063, 45.935896904237815, 44.85313838528049, 44.017948104489236, 45.28790173992034, 45.714455573789536, 46.14629284028084, 49.13657449906873, 44.99654808352071, 45.90684390837147, 48.3597686982924, 59.93899376161637, 57.91050864804176, 61.437017533086966, 63.677106672717684, 64.26241843931138, 60.75423094534106, 62.78618343414799, 59.19997215270997, 63.24114699517528, 64.89236285609584, 68.22615392746465, 68.54014750449889, 69.26093793684437, 64.25129067513251, 67.20713000143728, 61.93651176268055, 67.29193164456275, 60.913569388851045, 51.20933140477827, 1.9444884143529402, 1.1793698058012994, 0.6880146781763723, 0.25470266178731, 0.06557754766676696, 2.0609768023413997, 55.190697946856105, 55.566963072746034, 33.8774170414094, 65.80031310358356, 78.96197918922671, 24.871315840751897, 19.36626930390635, 40.32382065250028, 51.824817965107584, 56.225815357700476, 16.10243272396826, 0.337657542718995, 0.15863923506150324, 0.06380482404042156, 0.07841063122595511, 0.014031117710645401, 0.04384863197863583, 0.04124030177932113, 0.014053001012202474, 0.055061037381810535, 0.06796987937583078, 0.10344089940190317, 0.019573534974047256, 0.0343136258813883, 0.060328585170810266, 0.018197303983352838, 0.06560903388045489, 0.05154809523974696, 0.03439504187554121, 0.10579990628626078, 0.014397307738451468, 0.03837004994913455, 0.04290296538402477, 0.05167993897151563, 0.016287105878995314, 0.044000922597103545, 0.05086851396387623, 0.041092442979495374, 5.984792122917791, 81.61637260067849, 72.75940971989786, 74.8647419098885, 50.7507396513416, 38.55318430931338, 51.557465291792354, 47.154596928627264, 34.652363638724054, 77.56349732798915, 54.31206741640645, 0.5664734806745284, 0.028857488312848636, 0.796408090860613, 2.8454373536571382, 4.3765737741224235, 6.357625174906946, 2.0685729624763614, 0.37882569816804706, 55.42694622470487, 78.7272959370767, 74.37373176697763, 75.337920957996, 72.49265716921899, 72.87082072227233, 73.09589416750016, 70.01426835213938, 71.20127170316636, 65.53059916342458, 63.417277105392955, 54.63836939104142, 53.503494339604536, 51.760012565120576, 52.28289981042185, 52.61130025309902, 52.10612250912575, 50.98005710109588, 51.48434838941021, 49.29071187973023, 49.81085738828106, 47.911469244187884, 49.1429679624496, 48.38613094822053, 47.6148949130889, 48.629925866280836, 49.16466651424285, 46.43520286006313, 52.445129040748846, 56.63104718731296, 58.228436362358835, 55.29897497546289, 51.4847170922064, 48.887809938000096, 46.435959877506384, 43.96218376774942, 48.97647119337513, 47.8541987173019, 53.379504296087454, 58.78955102735951, 62.01120545787197, 52.403818638094016, 61.632449626922615, 61.911267388251524, 58.86221685717183, 52.79991526757517, 50.962167170739946, 46.23082383986443, 51.01599777898481, 46.13131723096294, 51.48124971697408, 45.71583232572002, 56.688368705011186, 54.98876648564493, 70.23938102106895, 44.2426920706226, 42.57260960917319, 69.32575118157172, 54.37122068097515, 60.315035312406486, 55.84907170264952, 62.68795551792268, 56.92062008765436, 62.51230001449586, 59.063414835160785, 53.77381624714021, 50.75818823229883, 52.2745765409162, 51.91225936335903, 51.53121286822904, 48.29706176634758, 48.64827471394693, 51.82156239786456, 52.96746323185583, 54.898548049311486, 59.33482323923419, 59.133566425692656, 60.554915705034816, 59.51925700710666, 60.77340741311351, 53.831071084545506, 46.186865837343284, 47.951049881596724, 46.3686716172003, 47.98829670875303, 45.76459915407243, 46.00114553205429, 48.45408993382608, 48.39167717964419, 48.09602068316553, 50.98184570189446, 46.83407260525612, 47.81246469866845, 51.18303191277289, 62.13316763600996, 60.670123561736084, 65.17702102661133, 65.19491880170762, 64.99625859722015, 63.32198312205654, 65.05146203502532, 60.953232396033506, 66.89257160309823, 65.62211982665524, 70.99812430720176, 70.67622323190012, 71.52019177713703, 65.42692307502993, 69.49542507048577, 67.65326822957685, 72.01101364627962, 64.87771672587242, 61.04503546991656, 3.0300035015229256, 0.5094643736318235, 1.5140736199194387, 0.5398972164238653, 0.030327475058936307, 1.4113297073110458, 55.71289877737723, 65.53981673332953, 35.96231368280227, 66.2132013997724, 74.53213276401644, 25.116811106281897, 26.039325114219423, 45.29227910503265, 59.099359435419885, 64.98352266127064, 23.684530181269494, 0.3811748914660946, 0.11082347422357529, 0.12407828918507985, 0.10088647114894084, 0.03179634906231396, 0.05458957155144984, 0.03952892647395211, 0.07200737724140768, 0.04454281489034334, 0.04946483404285485, 0.06282748354058112, 0.019312599681377895, 0.035340256478276946, 0.017820762192469933, 0.16132369907873292, 0.16062429144738183, 0.19249388617613625, 0.14274686364637268, 0.26748189702630043, 0.2216103141226115, 0.0915776831548541, 0.16686550251418547, 0.16175097695762114, 0.12780251837665998, 0.1932704541832209, 0.33297447788138546, 0.2976593873914211, 7.421950024943198, 95.17599844163465, 79.44661940297773, 86.77972578233289, 56.37845831532633, 46.73519749795237, 71.4176296418713, 57.67361317911456, 46.52159698547856, 82.45128047081732, 61.608848725595784, 1.1032589092370004, 0.19580407548815976, 1.6914237098347757, 7.040247023105622, 8.10851679694268, 11.530981871389574, 6.642907982872379, 1.1844368951935922, 60.95443656367641, 81.57844328111219, 76.19169542866369, 79.69313252356746, 76.02906611657913, 73.84287818785637, 75.73977562689012, 72.76263390817951, 73.9800670070033, 67.87231691422002, 66.45515672622189, 56.29315853118897, 55.23518939172068, 54.02842121739542, 54.95624611454626, 55.754369997209125, 54.30543468844507, 54.22750503786149, 53.44668273002871, 52.70075774961903, 52.041321031508915, 51.63367302187028, 51.04434474822014, 50.73825474708311, 51.921802489988266, 50.71317118983115, 52.64115733485068, 47.80089370666012, 55.13188985086257, 58.52138250104843, 60.707844995683246, 55.898815201174834, 54.314997426925174, 52.36736020734234, 48.033643230315185, 45.86654155485092, 52.1298332368174, 50.41685965753371, 56.37555183902864, 59.76301662383541, 63.63006960961127, 53.351173016332815, 64.48615043394028, 65.59875426753875, 60.399009335425596, 56.78614554866668, 53.32155912153183, 48.98516316567698, 56.78010902097149, 48.17891997675742, 53.50120759779408, 49.48327672096991, 58.832418610972745, 59.10916928322085, 73.25079641034527, 47.92734699864542, 45.49012737889444, 70.28098952385687, 57.162242012639204, 61.707060952340406, 59.05691546778525, 65.70777654647827, 58.308676288973906, 64.40714213155931, 62.32122567392165, 55.39164489315402, 53.47502969926404, 57.307483457749896, 54.691650867462165, 55.58196221628497, 51.99178541860273, 51.66311041001351, 51.90827031289378, 56.22147721628989, 58.696728137231645, 62.0146296870324, 63.27473817333099, 62.24338623785204, 62.30523809309929, 63.58485252626481, 57.17227935791016, 47.99833405402399, 50.53453076270319, 49.255677269351104, 50.60138756229032, 48.58099429838119, 48.86280090578141, 51.10511795167, 52.35593042066021, 51.138010947935044, 54.77105532923053, 49.3608360136709, 50.29192824517527, 53.45895190392771, 65.38231395906018, 64.25400103292158, 67.2534296589513, 68.926955961412, 68.70506748076409, 65.20124950716573, 67.73805418322164, 64.45150413820821, 70.98520401985415, 67.53983328419348, 73.53419550003545, 73.45697972082323, 73.62862263956379, 67.85900438985517, 73.2786609280494, 68.2321237748669, 73.24720351926743, 68.47709148160874, 63.01464188483454, 2.853366179812339, 3.1097952973458076, 4.370077348524525, 0.6137725458510461, 0.22249971155918416, 2.9590120334779066, 64.53214022421068, 69.45977857035976, 46.69683279529695, 72.90151719124087, 85.21422155441778, 33.31714176362561, 29.62414395424628, 57.26354898944978, 66.76648309153896, 76.11011012907952, 28.645918561566262, 0.5127097978707283, 0.22005650395106888, 0.20084551625674774, 0.2595789033559061, 0.11075566012051799, 0.06616985620630365, 0.1052758944851737, 0.12884049856614682, 0.11951402160188845, 0.1831929352615149, 0.21965430779082162, 0.16362588522174668, 0.1562503737307364, 0.16192417411554247], [0.035371294530529174, 0.06489677129373436, 0.035975868137733596, 0.0368952885600588, 0.05032746436735315, 0.07919044744583868, 0.011753639818409519, 0.03707486723038939, 0.06040777567954314, 0.013585817613338512, 0.03383650632214642, 0.050768152615355874, 0.05197575999303691, 22.833203269589333, 76.5741422099452, 67.65978720880324, 60.45658580718502, 40.67332736907467, 25.732452600233017, 49.22213708200763, 53.920905128602065, 45.875359042998284, 80.55599904829457, 26.131088964400757, 0.09448910838053112, 0.1151140568958175, 0.7446520487146994, 1.0003274583047437, 7.764439621279317, 6.880619795091691, 2.215170321925994, 5.0743413644452255, 81.12375428599697, 66.49331354325818, 73.43556357968238, 65.31464130647721, 73.8659417244696, 70.7310030537267, 69.41933893388318, 66.87368146834835, 68.44244910824683, 65.16073142328571, 64.2392489987035, 62.846297679408906, 60.05789256864979, 54.679746473989184, 54.79838248222105, 52.934009336656146, 51.46190458728422, 47.68053185555243, 48.19837493281211, 47.758253620516875, 47.70670975408247, 45.68411604050667, 48.03891881819695, 46.73244791646158, 46.30894568658645, 45.1041151631263, 47.83080177922403, 47.342482382251376, 45.738056475116366, 48.29479855875815, 51.41736607397757, 49.22919342594762, 48.14551707236998, 43.9716798259366, 43.633198891916585, 43.01157774463777, 44.85063591311055, 45.989080321404245, 52.387564336099935, 57.37982373083792, 62.18694333107241, 60.47595054872575, 59.627804679255334, 58.086681904331336, 54.64008346680672, 49.71031527365408, 44.71343140448294, 44.77299259554955, 46.73087896839265, 44.106428930836344, 50.3574671283845, 46.24310870324412, 54.654070638841205, 53.552202332404356, 62.80325358913791, 43.61413225050896, 40.23228429978894, 66.53926803219703, 56.16068440098917, 54.136482515642726, 47.32988765162807, 56.63693858731178, 57.0243981576735, 61.35150201859013, 55.60300573225945, 54.80242644586871, 47.48436627849456, 53.24368438413067, 54.10331887583579, 53.881685349249075, 48.7163435259173, 49.88750050144811, 47.27321724737845, 47.03439197232647, 49.11652334274785, 51.75368578203263, 56.15200419579783, 55.911080452703665, 56.42097680799423, 58.69913647251745, 52.190865316698634, 45.17287823461717, 44.14014954720774, 46.191800179020056, 44.89126774572557, 45.10877101652084, 47.044166518795876, 45.856668949127204, 43.87393828361265, 47.724878172720636, 47.08077007724393, 45.31711163059358, 47.815857548867505, 52.2520072229447, 59.12385071477583, 63.65129355461367, 61.417013445208156, 61.56247062067832, 62.013139186366914, 63.82640384858655, 62.908800648104766, 64.06205200379895, 61.814561351653076, 63.04460879295104, 64.0470567826302, 64.17269422161964, 63.16073840664279, 63.40729075093424, 66.55315322260704, 63.78729389559839, 66.37169653369536, 69.2999968990203, 66.48306046762775, 23.124647140502933, 0.5343275120662105, 1.3664043502461527, 0.614172995330826, 0.22371857276847287, 0.03032280958347744, 22.722972900636737, 70.41496984420284, 44.93863821029664, 52.4084117335658, 82.29236956565612, 47.3901980153976, 16.9515738948699, 35.12245970387613, 48.36183970974338, 54.866317933605565, 34.18404048488986, 0.35866183499174736, 0.044180133545230475, 0.10000746186462142, 0.012361989281470738, 0.0675383420480836, 0.07070560999695333, 0.03484011597691044, 0.0470658220470913, 0.04477712288198452, 0.1111775907056947, 0.10090484959824432, 0.03409956559358585, 0.032249608813154126, 0.030476613225595608, 0.031746043898766084, 0.0435754603465959, 0.009626244296199613, 0.01899223320276266, 0.01856328333697973, 0.030752098443166866, 0.0598097674458498, 0.02058632619258377, 0.01125811116634718, 0.049626804182245854, 0.09387626868462372, 0.07782381553683551, 0.07731546257292071, 35.047562045435754, 86.53274982206284, 75.71056965858706, 65.78104249892696, 52.33419264516523, 37.85216262263637, 47.671326052758005, 49.78317329960485, 49.67897945834745, 88.11501826009443, 26.536593398740216, 0.05218982794171861, 0.10528160950108882, 1.193373157612739, 2.8542281206577056, 5.815290327995054, 3.362846028420233, 1.1543199564180067, 8.248169845150363, 85.56317129442769, 69.94083373777329, 76.44774775351249, 70.20113006714853, 76.29347308989495, 74.06687690365699, 71.91975578185051, 67.92731638877623, 70.85702096262287, 67.75451244846468, 67.54374780962544, 65.29230733071604, 62.66289549489176, 57.095530340748454, 56.933967913350756, 54.568335471614716, 54.33435432372555, 48.72607492631482, 50.75618782351094, 48.97320385902159, 51.16012527096657, 48.87676454359486, 50.323585694836034, 48.227420083938114, 48.33019402719314, 47.20860404352988, 51.28168736734698, 48.39891395261211, 47.01930653664374, 50.17060149100519, 53.687073030779445, 53.10770757736699, 51.29118342553416, 46.81142876225133, 47.48811998674947, 45.176812371900006, 47.35873276187528, 48.13684078954881, 55.23988054644678, 58.58655660383163, 62.59321066641039, 62.66536658810031, 62.915256869408395, 58.277462067142615, 57.31596362206244, 51.08070904208768, 47.982279792908706, 47.112788384960545, 48.239701024947635, 46.89023310138334, 52.069844507401996, 48.211981634939875, 57.654868172061065, 54.74339477477535, 66.33812104502033, 46.92577761988486, 42.96876899657711, 66.90217356528005, 58.14675300352035, 57.55130191003123, 51.24674689385199, 59.869069668554495, 59.80033013128466, 61.711108838358236, 57.152753799192375, 56.830640915901434, 48.45304658336025, 55.82873029093589, 55.49497581297352, 56.798563772632235, 52.643447999031316, 53.1469940370129, 48.663301314077074, 48.220536324285696, 50.35566676047541, 54.334358246095725, 56.48806502742153, 58.102873448402654, 59.48453226397115, 59.53982983866046, 53.81861363687823, 47.610709744115034, 44.72669293803554, 48.632906867611794, 47.46380913642145, 47.82387487349972, 48.33993719470117, 49.188855771095525, 45.34269332885743, 50.9661836777964, 47.657366337314734, 47.370817584376184, 49.7006348640688, 55.93230047533589, 61.13368103581091, 65.09102698295348, 62.63493684030349, 63.644358804149014, 64.87907386595204, 66.19203629032259, 64.6057552676047, 67.1405516901324, 65.25657846081641, 65.7017949319655, 66.65093791100287, 65.73512331131967, 65.02127155180901, 65.9785887502855, 68.89214884850287, 67.72536139334402, 69.30485279329362, 70.32278630041307, 72.22430429150982, 27.518331273909542, 0.16509636034888608, 0.5826753822545852, 0.858241253562512, 0.20688026662795775, 0.05284899680484688, 22.187059463993197, 77.43158801909416, 49.912536990258005, 53.92750647760207, 79.2813071896953, 41.897200999721406, 21.003474458571404, 39.34002353299049, 54.272498546108125, 61.84714055830433, 47.48150294826877, 0.7047123918610235, 0.0961357071214626, 0.03192189938178466, 0.044068005086193164, 0.06935234632222884, 0.052113399179952766, 0.05253097455527994, 0.019918569483824318, 0.07566229079759891, 0.039552506660261465, 0.06496594137241764, 0.02230637552847545, 0.017468304290706595, 0.0475436425767839, 0.08887173803222757, 0.09095035673629853, 0.14421534694490895, 0.08180125210914882, 0.10410701285206503, 0.1321764743977016, 0.07114309216699294, 0.14306020892916188, 0.2002006540856054, 0.11046509063171764, 0.16176257552879472, 0.22178220893106154, 0.21067587989232234, 43.41312254628828, 98.80725029976138, 85.36806475731635, 77.33818854055097, 55.87674402421521, 38.26085790511101, 60.464905154320505, 71.44327409805791, 61.38536384028774, 93.94450756811327, 32.605090372024044, 0.22750309307969388, 0.24813394813287645, 1.9354786074930623, 5.448023119280416, 14.206056960167425, 16.29007891301186, 6.908486273980911, 10.923719540719064, 90.47710880156487, 70.62268287904801, 79.32815597903344, 73.18674410543134, 80.54872697399509, 77.0688315360777, 71.98427877118512, 70.90499939457064, 73.91018606001332, 70.31661248976185, 70.56586342473184, 68.57904172712757, 67.31406165707496, 59.91438088878509, 59.411011357461255, 58.62739632206579, 56.92843344903762, 52.13788978515133, 53.61016711881084, 53.14079669214065, 54.09574085666288, 48.3753679644677, 52.81374162243259, 50.93383589098531, 50.87864422029065, 49.78589934687461, 53.52729920418032, 50.608898901170306, 50.59318980863018, 54.40918922424317, 57.422051968113074, 53.6948001000189, 53.58729577833607, 50.209946786203695, 49.246691119286325, 47.26089316029703, 49.497801257717995, 51.70189872864754, 57.58948618365873, 62.529597666955766, 63.93926612792477, 62.623444295698604, 64.66833668370401, 61.83418496962517, 59.4373304613175, 55.89419072674167, 50.411599759132635, 51.1830868259553, 52.059560052810184, 49.336721281851496, 54.75437741125784, 50.68773069689351, 59.10209724980017, 59.26487561195128, 66.3382230266448, 49.92044056615522, 46.68364186440745, 69.938323420863, 61.8238103005194, 59.419742553464836, 54.31719787659184, 61.95684532965384, 62.97865413850354, 64.20586962853709, 59.17663012781451, 60.47785289825932, 50.90230395717006, 60.48466213287846, 58.42590416631391, 58.84652345411239, 53.29886821008498, 54.32196355635121, 53.58368327540737, 50.65570846680672, 54.4225174380887, 56.4597886608493, 59.809253523426676, 61.14532655285251, 61.36146876119799, 63.624421396563136, 58.36190677458241, 50.25146115210749, 47.86432627708682, 51.85485547588718, 50.07545655773532, 50.17310396317513, 50.86169958114625, 51.47622908315351, 47.25533908413303, 54.341116489902625, 50.832215124560946, 52.37912339548911, 50.67562626254175, 57.566155925873794, 62.982270563802416, 69.09986188334804, 65.30344686200543, 67.68961291159353, 67.70068968496015, 67.87042633179696, 67.77293974353422, 69.40282575545773, 66.4744234085083, 68.92832094623198, 68.05320093708654, 70.99561399029147, 68.12909879992085, 69.42381043587962, 71.84199087081417, 72.56327552180137, 73.43331213920348, 73.63350206805815, 75.91388179409888, 29.58930350119068, 1.1398515585930118, 6.98203512737828, 1.492581850578708, 0.3705702734089667, 0.15793161496760386, 28.766168625124042, 81.23692251020863, 60.6625690767842, 61.24468018931728, 88.81629882320281, 60.58238014098137, 25.31778354798594, 50.67439071593746, 64.80880852668517, 71.0723747745637, 55.529433834937315, 1.2999080409926753, 0.2594357674881335, 0.3566575957642448, 0.2226780261844397, 0.09698198912965675, 0.3078660074501269, 0.24287084748427717, 0.1443018382715602, 0.15354563902703025, 0.2858480276359666, 0.23055440596034452, 0.10559844814481274, 0.08533246544820648, 0.14632581192399227], [0.007137169567642794, 0.14423348790695592, 0.027620193112881917, 0.05282879889672322, 0.08358603778986201, 0.05811103259123141, 0.045509253959021265, 0.030869380758714773, 0.14928680303837025, 0.055812952679491816, 0.11766689168589732, 0.037584239091243477, 0.8333084011270154, 54.276703326932854, 66.51287832567769, 58.27546950309508, 44.75693833443427, 24.32974046276462, 20.541835023510842, 58.29079420335832, 42.1038902959516, 49.74281603290189, 74.96740602677869, 7.736434388545252, 0.0927883625451115, 0.3983894999950163, 0.5510140715106842, 3.011074143071329, 7.8081039363338105, 4.092604960164716, 2.9549067827963063, 29.760458084844775, 80.5262831718691, 67.56534437979421, 64.28898857485864, 60.64454578584241, 67.73037418242424, 71.5387838117538, 72.08501308195054, 68.66737350340813, 68.8524466176187, 66.55231383539015, 63.78363432422761, 63.29402838983844, 62.972001798691295, 62.18641773346932, 59.79274034500123, 58.93125841694494, 53.67643948524229, 49.209161881477606, 47.14594025765696, 45.83535086724066, 47.508229978622936, 48.83431273121988, 46.12616715892669, 46.35089935794954, 45.23968404339206, 45.278535119948856, 46.66475565202775, 45.60663354012274, 43.99739096241613, 45.37628058464297, 45.017552375793464, 45.55749800897414, 44.90053630644276, 43.59719153373472, 44.28033505716632, 43.3920084276507, 42.61598317853866, 49.75743470653411, 52.04120728277391, 58.694370792758086, 57.111537533421675, 59.25823896161972, 59.64047001254175, 57.21284451023225, 51.894953866158765, 43.59990973626414, 45.41459037411598, 43.638494091649214, 49.194582431547104, 54.41718301465435, 58.356262483904445, 53.92327031781597, 58.41562755646245, 54.39362918176959, 62.22253099564583, 45.915971263762444, 43.32649700103268, 64.79138143600957, 54.02661692711615, 52.67232448823991, 43.59519896968719, 54.200448528412856, 55.99519175867881, 59.76808432609805, 56.5239154907965, 53.7161809398282, 47.14925858282274, 54.81909259673088, 56.021667757341945, 57.514204132941465, 56.25465262320734, 55.22630914565056, 55.72237522371354, 50.595656979468565, 46.873480658377375, 49.59564478166642, 51.05472333969609, 55.895461574677505, 54.32249307632447, 58.27198643838206, 50.44864654541016, 43.78788148203204, 43.33652257919312, 46.61285877227784, 43.649763061154275, 45.8599990414035, 45.71835440974082, 45.98644841101862, 45.52533849593132, 47.41127683270363, 45.16286442356725, 46.194428167035504, 47.12119402423982, 53.35103965574696, 58.864221188329886, 60.360985878975164, 59.06269704141925, 62.53814058919107, 60.81607103347779, 61.70284048203499, 61.431989054526056, 63.17629844911637, 61.23266596947948, 64.04105555626654, 62.485843627683586, 61.80181364859305, 59.72366740626674, 59.55434260829803, 55.143700107451416, 59.16231739905573, 62.19692968553113, 66.73424120872252, 61.51537864438949, 54.40758889721286, 1.854961173188302, 0.8255973890904458, 1.049511528784229, 0.11435078051421912, 0.045271107866879434, 2.119376236392606, 54.643288043237504, 53.11982770119944, 41.87493762662334, 67.53518135316911, 35.890475473096295, 27.24541471850488, 39.95272521049746, 47.84941342569167, 54.89233893732871, 45.367145384511645, 2.7078354599014407, 0.01683236895910194, 0.03917768282154876, 0.037473918599707466, 0.03282403303009849, 0.08085738582115981, 0.06579271112118038, 0.05803355811944893, 0.05784559844722671, 0.035174823621468204, 0.024906696278541803, 0.02062888237677755, 0.023755532343901938, 0.057506891823704206, 0.06571877597560806, 0.04874560771690262, 0.06682900591723381, 0.07125178472168985, 0.05752569545180567, 0.017879624558132023, 0.0383706130237589, 0.04806974196746465, 0.17796170387056567, 0.017998711010741613, 0.07347350865001641, 0.016490063637555126, 2.0898662844011864, 70.49447628759569, 74.00036919501521, 65.52036569964501, 53.627613821337306, 38.42051406060496, 24.79790476060683, 49.81212039147654, 46.124770795145345, 57.96692409823018, 80.72111514306839, 7.941371856197235, 0.08769279000379386, 0.5897252297689838, 2.4283773716418975, 4.942019226089601, 13.020100881976466, 9.063181492590136, 3.337696771467886, 36.083891468663374, 82.63869916239094, 72.45302554099791, 66.92314255622126, 63.63946760854414, 69.89567156760924, 74.59147037998324, 71.13230074605634, 70.53519833472468, 70.2103005686114, 69.07874384234029, 67.7832555770874, 66.54285307853453, 65.35750496772029, 65.49983601416311, 62.17935746715915, 61.927521690245605, 55.78918103248843, 52.46241884846842, 49.271009814354684, 49.26882897653888, 49.37041444163169, 50.42246864688013, 48.33508914516818, 48.60033550570088, 48.353838074591856, 49.59156943905739, 48.35583063863939, 46.892861089398785, 45.70506149722684, 47.68670174383348, 47.3267654449709, 48.95858518538937, 47.51390957063245, 45.96848003325924, 46.8317505621141, 45.80947106884372, 44.38033196233934, 52.2225227663594, 55.8900918499116, 60.65338680821081, 60.37068982278148, 61.50723188154159, 62.347521243556855, 58.582340055896395, 53.7926044002656, 46.3219012752656, 47.96042826867873, 47.08555144648398, 52.64743704949656, 57.255802308359456, 61.168990212102095, 56.223658054105705, 61.43314223135672, 57.054541572447754, 64.0950156027271, 47.99801241966986, 44.6074568071673, 66.62068859223398, 55.16569675937776, 54.24694038206532, 46.34719664050687, 56.80392565265779, 57.660414403484715, 63.03782309255293, 57.1251363908091, 57.46561381124682, 49.13987321238364, 54.975136249296135, 58.126992102592226, 60.175995134538226, 59.177410679478804, 58.72436907983596, 56.927374409091094, 54.50791135911019, 50.329700669934674, 51.89540886109876, 53.63859253544962, 59.07727649134975, 56.7504245235074, 58.64850259596302, 52.178349033478774, 46.10172687038299, 46.66526948252032, 48.91730616169591, 44.148735615514944, 48.36308702345818, 47.034894035708525, 47.54563762295631, 47.0511483377026, 50.044140354279556, 46.57756136309716, 49.257869874277425, 48.37552093690442, 57.35349285987116, 61.30315880621634, 63.61474098697786, 62.285853739707704, 65.51565885543823, 63.532928189923695, 64.60913635069325, 63.28886655069167, 65.12972900944372, 63.631928813072946, 67.45948745358375, 64.84174859139227, 66.80774642575172, 61.219714303170484, 62.318044631711906, 56.776135659986934, 62.94203096820463, 63.75294177762924, 71.7531805653726, 64.04055349288448, 63.329616054411865, 2.657587201364579, 0.24128090860622547, 1.9720483354983793, 0.6471517934433876, 0.07242875624327891, 1.7803372226415144, 58.041041205006266, 61.688057068855535, 43.69999685595113, 67.69445311638617, 28.752038286578273, 22.844407519986554, 47.35193921673683, 55.81887337469286, 60.19180228633266, 57.718547851808616, 6.428641648061815, 0.1974981870021551, 0.1220288124656485, 0.024919779145068703, 0.02920338084110089, 0.03803091048593483, 0.07764497231091223, 0.03319077081077042, 0.03269541835893066, 0.03832108926989379, 0.07668615964752051, 0.06131382020671041, 0.025481863600772717, 0.02533568444872095, 0.12784200254827738, 0.2765273422964158, 0.23891898292687633, 0.15330147148380358, 0.15226981151969204, 0.14463720092129323, 0.15479033272112572, 0.20879729440616024, 0.36419951687416724, 0.1716621935127243, 0.29250723159601616, 0.30233184957215864, 2.777415119832562, 80.96548664954402, 85.24468268117597, 75.10080583633916, 63.74059415632679, 36.677428445508404, 30.860343633159516, 72.7475014040547, 58.89336047634002, 64.56717875695998, 89.05483384286204, 10.64992339380326, 0.182343696153933, 1.5507964429355439, 3.78885563342802, 9.756569266319275, 22.508678128642423, 10.403484798246815, 4.438694311726478, 44.24441006875808, 82.04252243041992, 75.39389318035495, 69.44028439060335, 65.06617092317151, 73.09222282901888, 78.88967421747024, 74.97666282038536, 73.7919815125004, 73.46861347075432, 72.41465691597232, 69.47029836716192, 69.12604762661842, 69.23342643245574, 68.59866142272949, 62.50454548866519, 65.95854543870496, 58.19297029126076, 54.90206641535605, 51.615375165016424, 51.257451042052246, 52.10791895466467, 54.8936019405242, 51.09173090227189, 51.91407934311898, 50.15855196983584, 50.32613915781821, 51.4812183380127, 49.38732377944454, 47.884495104512865, 51.68218489616148, 50.09840634561355, 51.08048546698786, 50.4271754910869, 48.50279008188556, 49.663795963410415, 49.82169881943734, 47.64438329204437, 55.3348332835782, 58.74044687517228, 63.41323706411547, 61.40286937836678, 64.08525674573838, 64.33580598523541, 61.753980344341656, 57.74852260466545, 50.26458540270406, 50.50714477416008, 47.888629282674486, 55.50418161576795, 60.41482825433055, 63.851644300645404, 60.38730106046123, 64.75815111590971, 59.74749580506356, 65.73620980785739, 51.488882649329405, 47.893285136069025, 70.15476765171175, 57.82226708627517, 57.586940565416896, 47.30949132673202, 59.16070138254474, 59.37301143523186, 65.88198077294135, 61.87738595470306, 58.462531258983, 50.27060231854839, 59.203596422749186, 61.004827253280155, 63.6133603126772, 60.67073152911279, 62.5986784504306, 57.61449129350724, 55.34360762565367, 52.25370953159948, 54.39085214368759, 55.89953691728654, 61.69670981745567, 60.086004195674775, 62.34480304102745, 55.74363054767732, 47.68297156979961, 48.16595654333792, 51.33545914003926, 46.824309825897224, 50.67666961300758, 51.140129027828095, 50.30554279204338, 49.25144503193517, 52.01204446054275, 47.51115606677148, 51.425932530433904, 51.421508096879535, 59.27112394763578, 63.408275265847486, 66.64528969795474, 63.55468557726953, 69.84471997907086, 66.25393913638207, 67.74166276378017, 64.9611847631393, 69.83913452394548, 66.94608842172931, 71.92960093098303, 66.0962990791567, 70.3466578452818, 64.40020738109466, 67.55309874011625, 60.483246157246256, 64.67520475387573, 66.99790293170561, 74.74226982362809, 65.91964337133592, 65.19979823020198, 2.768061737860403, 2.3345089247149806, 4.581699025246405, 0.44395481626833644, 0.193529054822941, 3.5126467385599693, 66.52682627401045, 67.272429620066, 55.246642712623846, 74.56757530089348, 48.82280057476413, 41.09570387871035, 52.07839135200747, 65.30840081553306, 68.72327512310397, 70.35413388283023, 8.986379523431102, 0.590187150143808, 0.3243068058884913, 0.11560659780497513, 0.15061058764976842, 0.09909170334257426, 0.26531316339969635, 0.1400667663303114, 0.1473116904737488, 0.09143777251724275, 0.21396979749683412, 0.1252002632545848, 0.1662147108225092, 0.2290181545240264], [0.024424013005749836, 0.06646055593005111, 0.022778753003466035, 0.04123983446568732, 0.06288945239277617, 0.04762781265702459, 0.05186231386276984, 0.027803278550685897, 0.030557140557756348, 0.06993261195959584, 0.07241297483203873, 0.17871309822845846, 7.519905336441533, 70.75514916450747, 68.04421086465159, 62.34956087604646, 40.793979475575114, 31.343875777336862, 62.75526339007963, 70.30799896486344, 35.89029896643854, 74.48173030730217, 51.44080615812733, 0.8860552707506765, 0.04536178969447652, 0.02312308654279238, 0.6219508715214268, 2.6936739875424296, 1.7854083569780475, 0.3565830707309708, 0.7922479882836343, 59.97625627825337, 74.58347658957206, 68.87067779417961, 63.12916724912582, 54.76625042576944, 58.2637769176114, 67.38782575053554, 66.49525903886365, 67.01630669255411, 64.77928092402797, 67.67280947777533, 69.01313827883813, 66.59941365641933, 61.05153091492192, 64.99079865794029, 65.88808398092947, 61.51611604998189, 60.631613731384284, 57.58255143319407, 51.289885121007124, 47.97085785096692, 46.801167841880556, 47.05818506979173, 45.58287182161885, 45.74849782451507, 45.61728277514058, 47.2228265577747, 46.7257288963564, 46.18273558155183, 45.83724929440407, 44.05162165241857, 46.34685539430188, 45.91976811808925, 44.32871749324184, 44.27662057261313, 44.323183028928696, 42.541293405717425, 45.73240041732789, 50.42070358030258, 54.59510957041095, 58.88135017887239, 62.01230372152021, 60.521332371619444, 58.159885098857266, 53.76777579707485, 45.99468538838048, 44.02052117932228, 43.37411065255442, 46.01431292872275, 58.50932121276856, 57.79336314047537, 60.46423050665087, 57.9869987887721, 59.86823812607796, 56.89525804212017, 66.74500419247535, 40.993514368611, 42.034444732050744, 63.94207454496815, 51.76706106432023, 52.27945204704039, 46.48321267097227, 50.52163793194679, 50.108784937089496, 58.15542144160117, 53.35245170900899, 52.31881303171958, 43.63091215010613, 51.027094164202296, 55.736115286427165, 59.40676343056464, 54.033528143359774, 58.67093463097849, 54.04081590713994, 55.386683094886045, 52.72175811952161, 49.68232524010443, 48.55983703367172, 50.8241742657077, 52.65713314856253, 53.037469694691325, 48.03593389449581, 43.75563567684543, 43.556987239468484, 45.290125723808046, 45.19845208814068, 44.375240725855676, 43.83208267150387, 44.40514879841959, 46.1023348377597, 45.92132922141783, 45.01048818711312, 46.005644490641934, 45.84030874313847, 53.21459608693277, 58.456816365641934, 62.10723684680078, 60.92556007446782, 59.18636937295238, 60.345112046887806, 59.158100851120494, 56.64989417599094, 58.30632286687052, 55.1141607376837, 53.110264962719334, 51.66123551707114, 50.726856339362364, 47.10006029375138, 51.282056070143184, 54.60774744710615, 60.49559770091888, 63.12285615551857, 67.93860497013216, 67.54576390789401, 59.63880300521851, 21.67433507980839, 0.20773388775846652, 0.2541381009523907, 0.7131682865081296, 0.07773612911302237, 0.08823217718952125, 27.45909367838214, 69.31143453044277, 45.659295282056256, 43.469408558261016, 47.93317956309165, 37.484275679434504, 28.26246176996539, 41.80287191944738, 52.07434346598964, 53.062804283634314, 15.874025264093953, 0.48326680196389077, 0.052907878322707075, 0.024751107651560057, 0.048331092862832936, 0.03981882180537909, 0.003723041037090063, 0.093936383604042, 0.08800506276348907, 0.02924685633080381, 0.02764471175689851, 0.02754459938695354, 0.04668217287549088, 0.051664900665562, 0.025011772898236112, 0.051210817370203235, 0.0351290422071132, 0.04975156926159417, 0.07593509470743519, 0.024665855472126318, 0.024987719652633515, 0.030877821132420536, 0.08195830779450555, 0.10482202569443373, 0.12459310027019632, 0.35855810668679977, 11.08656164138548, 82.35653169693487, 73.14362941249725, 71.04618903129332, 47.345086836045795, 40.16474108542166, 56.36802088829779, 61.73696118016397, 40.444433535299, 83.59853452251804, 54.582032388256444, 0.912046488975325, 0.05583299737003061, 0.5215247119626691, 1.9613362199837163, 5.7841702430479, 3.715159936297325, 0.36645202987617065, 1.0518611510915141, 67.13391503980084, 77.59553524755663, 73.1228800742857, 66.0232880807692, 58.30396552239695, 61.28431181753836, 70.88483841188493, 69.17691292301302, 69.22956682020619, 66.29265292998284, 68.73821935346051, 71.76046832915276, 70.11483007861723, 64.3268669036127, 67.52921935050719, 67.28685609755978, 65.56166433518933, 63.02928801505797, 60.44012754194198, 54.30093965222759, 50.33926340841478, 48.92915956435665, 48.35079431533814, 46.806914114183, 47.69791580015614, 48.617307601436494, 47.636079634389574, 47.67197324383644, 48.26120738060244, 47.535953291000865, 46.079400739362164, 48.14276749087919, 47.06742617391771, 46.39680285607615, 47.15520489600397, 46.29646862706831, 45.73940577045564, 49.5729930939213, 52.34361025594896, 55.65318853624406, 61.27784382912421, 63.35806500527167, 63.8975085750703, 60.31511375980993, 55.818728246996486, 49.72333754262617, 45.92333355257588, 46.04008290075487, 47.036180573125044, 61.10962121717392, 60.04678441632179, 60.470608280551055, 59.11719837496358, 61.92166166920816, 57.99646739036807, 67.37797275666269, 43.748689159270256, 43.767426321583415, 64.76213624400478, 52.541560511435236, 54.32884731600362, 48.413795425045876, 51.20613075071766, 51.56490995037941, 59.3182590699965, 56.57815402553928, 55.503181411374, 47.73963805167906, 55.0939566089261, 58.74957423056326, 58.920358150236076, 55.96907269570136, 60.649888054017104, 55.63742453052152, 58.696280987032004, 55.52950835997059, 50.85336846690024, 49.91643582620929, 53.01208803730627, 53.353542127916896, 55.75047900599819, 49.41339577397993, 46.053936712203495, 45.17680060478949, 47.5218641373419, 46.5732349887971, 47.181712273628484, 45.56012207461942, 47.8197406953381, 48.413956242222945, 47.8323079693702, 47.26753765536893, 49.03165894169962, 48.262023233598285, 54.724849808600645, 60.66895077305456, 66.15425602082284, 63.7174560946803, 60.563599832596324, 61.66203606513239, 61.70377400613601, 60.27465451148249, 59.663721822923236, 55.78353281944029, 54.75455784028577, 52.31658512546171, 52.19999659445978, 49.12429355805921, 53.99826603551065, 56.286415976862756, 62.557823042715754, 65.56192713399088, 69.00875306898548, 68.7317160637148, 64.71121603442778, 25.947726003585327, 0.04116183139323708, 0.6386904442502607, 1.4714785184591048, 0.31211807122153623, 0.16627031348405347, 26.12210673670615, 75.76833048174458, 50.17688512802125, 47.42789591512373, 46.841960491672644, 41.74830390561012, 36.69427110302833, 47.88019618680401, 56.84417309299592, 63.55690171641689, 26.218102824303415, 0.38145117341510715, 0.05964398218859589, 0.0661411049265054, 0.053791384543142015, 0.030751493233706684, 0.06054874351848999, 0.028982931380009944, 0.05133330716841644, 0.08847940908444506, 0.06669288741484766, 0.017174115036464026, 0.029354058844487996, 0.04548666202613423, 0.2252258507594947, 0.1348009077651847, 0.1881552544692832, 0.15090533231775607, 0.1570428610448876, 0.15702969965434846, 0.1525080035771093, 0.21179999134713606, 0.19838042917751497, 0.28784898800715325, 0.419767152878546, 0.6190947731656413, 13.294121584584637, 95.36540969725579, 84.73880675531204, 81.49676384464388, 53.57117483692785, 41.86380594007431, 74.02700993322557, 82.32521549347909, 50.337168862742764, 89.83383224856469, 61.67812170520906, 1.5470201810521464, 0.12246667001877101, 0.8955922686765272, 1.7816229020395589, 7.772423115468795, 4.075093293382276, 1.101138255288524, 2.550948497749144, 74.29665719309162, 76.92029922239243, 76.20221522546585, 69.423841814841, 61.82391228214387, 62.79084713228288, 75.12429298893099, 68.87468645649572, 71.63819236140098, 68.63515515481272, 70.5739748862482, 73.45476750404605, 73.21299260662448, 65.70518778216454, 72.61407021553286, 69.94754883550829, 67.2690014685354, 65.76813790106004, 63.625045053420536, 57.34874679196266, 54.423745139952636, 51.2626285706797, 52.885309188596665, 49.14646671664331, 49.2822866286001, 48.705945322590495, 50.32249135355796, 51.323029148963194, 51.629264277796594, 49.24718141555787, 50.05177328663488, 51.20490304885372, 51.37340414908625, 48.827801596733835, 50.17286469859462, 48.28050151948006, 46.82071693481938, 51.57843036036338, 53.81787230891567, 59.977656564404896, 63.75587963288831, 65.90672308398833, 66.25875580695369, 63.436233920435754, 59.177818605976725, 51.36089178823656, 48.092353267054406, 47.90448742528116, 49.65867334796537, 63.59475258857974, 63.42301161058488, 64.10555108900994, 62.41569988189205, 64.12566500325357, 63.73035284780688, 68.20600863425963, 47.43597992004887, 47.02804557738766, 68.10350925691667, 55.806109982152144, 56.55855001941804, 51.16836224832843, 55.78839263608379, 55.324980289705344, 63.91829713698357, 60.49409935551306, 58.265247806426025, 49.365786044828354, 56.29839097299884, 62.616423253090154, 62.37042396299301, 56.98908505901214, 60.73861206731489, 57.958765568271765, 60.954766042770885, 57.68388194422568, 54.47460651397706, 53.12493854953397, 55.5589065244121, 56.4166033652521, 58.51918989612211, 52.33207064290201, 48.21869673267488, 48.31306111428046, 50.66559283964096, 48.31799153358706, 50.700933394893525, 47.17717409133912, 49.67113471800282, 51.57446484411917, 49.33778032179802, 50.002837796365064, 51.18178067668792, 51.59270386542044, 57.44136964121173, 63.01929773822908, 67.0703177298269, 66.62346563031598, 62.745351560654186, 65.82450236043623, 64.30541153877013, 63.50056471363191, 61.49442142055881, 59.41931501511605, 57.12700736138129, 55.87054275697278, 56.30010112639397, 53.79354576910696, 56.97433694716423, 60.11940317769205, 66.11009013268256, 68.53846873006513, 71.42330923388081, 71.34664258649273, 64.16419444545623, 28.93933734586162, 0.40990410793212156, 4.046897090250447, 1.782361533372633, 0.31417357705293164, 0.28946950911514224, 33.031448087384625, 82.34662378987959, 59.6184733606154, 55.78826712023828, 53.69347041653049, 49.05092562398603, 40.292316175276234, 60.56532567547214, 65.04695523169734, 74.4599925318072, 29.592243317634832, 0.5569106809073879, 0.18637296623520314, 0.2065892298255236, 0.21020030783068752, 0.14387770135316158, 0.1171207016394023, 0.1704895120835112, 0.33935810469331285, 0.16203182479066236, 0.1398019603784046, 0.1618072231330218, 0.12957310844813624, 0.24665945870501382], [0.05401092619004269, 0.09153858202719882, 0.042446373150713985, 0.027844275745953766, 0.048899909316171566, 0.046418676933934616, 0.05214479346308978, 0.03315204506619804, 0.09543966261609908, 0.0739917594699129, 0.22762801137662705, 0.30278923470647107, 20.015613763563096, 77.81556452474287, 61.68001228763212, 53.45281339460804, 36.915394721492646, 27.494991210199174, 28.620913451717747, 42.105898549479825, 48.238045784734915, 75.41821972016366, 27.842424954137496, 0.02438256956426607, 0.2563472686996383, 0.4450209348672821, 3.2475288356504137, 2.177087539626706, 3.3425641877035943, 1.3885386528507357, 9.940752983093262, 77.64107396525722, 68.95136094862416, 72.19280765902612, 64.09577654254052, 60.32945002278974, 50.23485775916807, 60.73805509075042, 65.21227921209028, 71.87269518452307, 68.15047571735998, 64.03798041805145, 61.21490155496905, 65.50962232774305, 66.67640193816155, 66.36778985300373, 65.93367761181247, 62.09712889886672, 60.923783240779755, 62.75433378834879, 58.26125091122043, 53.56744858526415, 45.31844523645217, 48.858501988072554, 45.73351829282699, 45.77415797018236, 45.89006008640413, 45.5322418674346, 46.61434142820297, 44.75356901845625, 46.782791537623254, 44.825540588748076, 43.957276882663855, 45.85328786603866, 44.4104596876329, 45.77074158576227, 44.60660565283991, 45.202821608512636, 47.59136853679534, 50.3785498680607, 53.345089420195556, 56.45693709773403, 58.98007623610958, 59.94358293471798, 57.3102604958319, 49.23844629718412, 46.333213390842566, 42.78355467704035, 45.24013903833205, 54.33016523238152, 60.8613940208189, 56.23770406169277, 61.80906218867149, 57.83155525884321, 60.90143749790808, 56.89479128006966, 64.11875378700995, 33.93994354432629, 45.66377462879304, 63.39621005519744, 53.320335342038064, 52.09932896398729, 46.843400001525886, 49.874560602249645, 43.90435626429897, 48.19236586170812, 47.91759598639704, 47.10378262304491, 43.61689359911027, 47.511226669434585, 54.900528846248505, 57.193103221154985, 54.33884543757285, 54.48722085645122, 46.32959304317352, 48.502982278024, 54.9337552439782, 56.26574116368448, 50.66489465775029, 50.76184388129942, 49.269546770280414, 49.63031068924935, 45.9845382167447, 44.16486047929333, 43.402967529912154, 43.269806984932195, 47.729192779910186, 45.262265128474084, 43.95864578985399, 46.35889314836072, 45.806360629297075, 44.59150845004667, 46.30417608445691, 46.09677291685536, 44.74752072365054, 46.35616710109096, 50.29671745915567, 54.653764693967766, 55.48847644559799, 56.86336917261924, 55.43419476478331, 52.91921807873634, 51.37174106413319, 49.53387921856296, 47.1593233846849, 45.15266233874906, 47.81021325818954, 47.79591621891145, 55.363623480643, 57.9148664013032, 61.52471780776978, 62.48733412834906, 65.14915258653703, 64.12925397196125, 65.7114008165175, 62.08601290179838, 49.00546535368889, 13.680484852483197, 1.6015732408531251, 1.648354859602067, 0.06457276972791841, 0.14370314055873504, 4.580850812696642, 58.928367630127944, 60.517676722618845, 33.10824025061823, 39.17408766285066, 28.56963630645506, 13.687328407841346, 40.432795862997736, 52.5674089308708, 53.66620209909255, 38.449598435432684, 0.7476236118424324, 0.08775999889739099, 0.09745105710481444, 0.08781148000590264, 0.11666445797609708, 0.04671851225617913, 0.06360632682880087, 0.03642260081945889, 0.05663522549213902, 0.01559336442545417, 0.1639060895409315, 0.03131984620385113, 0.04072726418774936, 0.04866735183543736, 0.05634175636054528, 0.0031744165068131784, 0.06617455998615873, 0.036422972372102166, 0.04685704010508714, 0.061658532959559274, 0.022851100431815274, 0.08192783281687768, 0.06133275406975901, 0.2619772794986925, 0.30546744744623866, 27.86461772457246, 89.05264516030589, 67.37603510579756, 59.20654996748894, 45.463059102335286, 35.01185670975716, 27.481178583637362, 48.29701077553534, 54.086119282630186, 84.72084229992282, 26.889643976765296, 0.0466692183286913, 0.13593772095778298, 1.8412276069002769, 5.067855725365301, 3.4657469584095866, 0.46747420584001853, 1.403074834135271, 13.746720936990554, 79.18942174603863, 71.46374102561705, 75.56075080748528, 66.97276053890106, 64.20043714584844, 52.78977594067974, 61.44187734973047, 68.22810726781046, 73.76944357349028, 69.40896034240723, 66.65106342684838, 61.061289771910644, 66.84471868699598, 68.9964525161251, 67.28228261393886, 67.56877253132483, 64.37272725566741, 63.17596112528155, 64.78974188527754, 61.19273231875513, 54.60843778425648, 47.71408381000642, 49.90856362927345, 48.240348216026064, 47.38012929116526, 47.80067797630064, 48.362290782313195, 48.481577903993674, 46.533195434078095, 47.89142201023717, 47.81347667017291, 47.415650275445756, 47.20021801610147, 45.579671167558246, 47.446797816984116, 47.222948151250044, 47.93344628426337, 50.816047114710656, 53.57396756449054, 56.361792164464156, 58.413952704398866, 60.508635659371656, 61.531099504040135, 59.35659239369055, 51.58852654118692, 48.01862839729556, 43.55385718807098, 48.39212040747366, 55.77434270612655, 63.553520633328354, 57.39676052524198, 63.57281477220597, 58.16125008367724, 62.57945491421608, 58.860777347318596, 64.86150556995024, 36.0839581489563, 48.06987808596704, 66.40620554647138, 55.11176809187859, 52.835526466369636, 47.21473863047939, 53.19494893473964, 45.7711063661883, 50.550035891994355, 49.71490052438552, 49.99760927692537, 46.149513106192316, 48.8200000024611, 56.56766168532833, 59.47145900418682, 56.13935455199211, 54.25704832999937, 51.230782847250666, 49.968018916345414, 55.203124015562004, 58.583728574937396, 54.490782368567686, 53.22417843726374, 51.64553034690119, 51.014652406015706, 47.027178733579575, 43.637831211090095, 45.41333913803101, 45.52949620831398, 48.116973984626036, 47.635134343178045, 45.175153209317116, 47.768804796280406, 48.32309061481107, 47.30610239890314, 46.92362031629009, 48.76843652417583, 47.75502550986506, 49.30880577333512, 52.62582086747693, 55.45223374520579, 57.12589340825235, 58.313030119865175, 57.05669103130218, 55.33537849303215, 53.39826499262164, 53.016645831446496, 49.686867344763975, 46.590705225544596, 47.79932083622102, 52.11857603442285, 56.38521263676306, 60.24061226075696, 64.70481472630655, 62.801727787140884, 67.25874839290496, 68.39158381185224, 66.49658479998189, 64.1590992866024, 56.38194138003934, 19.377791266287527, 2.5477637783173592, 0.7257924349077287, 0.280970161960971, 0.07657741346666891, 4.162498164561487, 62.194713546383774, 67.15284439825243, 38.38332214663106, 42.392427690567516, 37.95671339957945, 18.485877629249327, 47.32921300395843, 58.06790159594629, 61.140411823026604, 48.57293382767708, 1.8605336354624842, 0.16449121217573845, 0.04721932308447938, 0.12255929004881652, 0.10108636647102334, 0.02030984697593076, 0.07220043139832635, 0.04951038946127219, 0.09754313321243371, 0.047320488825320244, 0.07114909063544005, 0.01357399591905696, 0.045382462577113224, 0.2067240459784385, 0.14794037286793033, 0.13351548883703449, 0.14765296732225727, 0.11762244326453056, 0.20605437788030795, 0.11364099239149403, 0.09160064280994477, 0.22697907361772754, 0.17633411943191485, 0.4739028173348596, 0.403850726302593, 33.58679686823199, 96.97136140638783, 76.27135876686343, 69.5517110824585, 52.644004975595784, 38.50107562157416, 39.98692435602988, 59.27709379503804, 64.10427239633376, 89.30667354214577, 33.11768924036334, 0.1694411054373749, 0.7426426920198625, 1.66900908033694, 9.77805502953068, 8.558010612764667, 6.608302872027121, 3.9982991689635865, 18.25297317197246, 83.86124703191942, 75.143504758035, 77.22982914217057, 70.9342759655368, 67.55433036435035, 55.56173455330634, 64.34442735487416, 69.76397406670355, 77.46932122015184, 72.67381575799757, 67.27298659663047, 61.65547393983411, 71.26164482485864, 71.1159444624378, 71.4990266676872, 70.605087126455, 66.8575369927191, 64.56048719344601, 68.35440758735903, 63.04080801625406, 58.72285504494944, 50.347010089505105, 53.75650290519961, 50.33567836207729, 49.82748039307133, 51.10151721585182, 50.9819241492979, 50.07276188942694, 49.98177466853973, 51.50780808541083, 49.86244832315753, 48.79053123535649, 50.97722907220164, 48.39964743583433, 49.25060956708847, 49.76419295034101, 49.741474582302956, 52.96287405875422, 56.31919130202263, 57.93151294031451, 60.32220932745165, 63.57447785715904, 64.32547446220153, 62.04163128329862, 54.85021268167804, 52.03853222631639, 46.14229986744542, 49.67693982585784, 60.26327179324243, 67.037518870446, 59.90822668998473, 65.21446789464643, 62.50074078959804, 66.05527108715427, 62.86014364611719, 66.95354092505671, 37.96535045869889, 50.134245041877996, 68.52843530716436, 58.197967390860285, 56.791024977161044, 51.42244162098054, 54.70319440287929, 48.21388006210328, 53.963180434319284, 53.051480400946836, 53.41663737450877, 49.08007667910669, 52.295121915878795, 58.82166347196026, 61.04696527604134, 57.50661826902821, 56.119742701130534, 55.89632057374524, 55.76363071318596, 59.80650394193588, 59.85900486669233, 56.27861438259002, 57.365248203277595, 53.57107677767354, 54.151367910446666, 49.45412566584926, 47.565053355309274, 48.22154829579015, 47.720406670724195, 50.33063419403569, 50.0237871754554, 47.502436637878425, 51.703369617462165, 50.2629929204141, 48.451359964186146, 50.275532737854995, 51.673740033180486, 50.11241705186906, 51.657038580986764, 55.355488484905614, 58.26668731627926, 60.474369833546305, 60.80906960272021, 60.08856158102713, 57.92158542140838, 56.573231450973026, 56.10081726504911, 52.275529676868075, 49.13298945273123, 52.10833080353276, 55.625171046103205, 59.35967537664599, 63.52227895490585, 67.2417409958378, 65.85344160756758, 69.2164582590903, 71.40044966051656, 66.85211627714096, 64.9488724431684, 58.61811599423809, 21.314063418296076, 3.8494150677034935, 4.526944208529688, 0.577885494116814, 0.21749714209187418, 5.729270788931078, 71.87451516428303, 73.91746597905313, 46.557490594925426, 46.46577381318616, 37.247552794794885, 25.1438578098051, 54.73587166878485, 69.41289840206024, 71.40267756677443, 58.15548419952393, 1.9868889907675407, 0.24543641465565852, 0.14219509647978892, 0.24930684406670833, 0.26788691239010903, 0.12189234922369643, 0.20498711014947585, 0.14567316629953925, 0.18988195536357744, 0.1069459431774674, 0.19866155280220896, 0.11417618141539636, 0.1364522562512467], [0.07480355219975596, 0.04470149851253918, 0.047766240914502454, 0.0607420006887086, 0.016538181620079185, 0.021616170528314767, 0.041502587301957036, 0.03473255340190184, 0.026152642526393457, 0.06665373266103768, 0.05851525122359876, 0.09369859757322459, 34.44417991945821, 80.3238888709776, 59.53290685530632, 55.44634626757715, 21.238083185688144, 27.750951359348914, 38.95534884545111, 35.7435199522203, 60.06823193642401, 75.73022857789071, 11.588583838555122, 0.052741204403460994, 0.04513290943577886, 0.9836027783251579, 4.224131347671632, 3.7092947671490335, 1.924162201823727, 1.1874735451513723, 59.35567063670005, 65.89780361421647, 72.08759400152391, 68.646679078379, 68.49781728559925, 63.10476226191368, 59.41360796651533, 48.49737721104776, 58.97780126140964, 66.06760301897603, 68.81815725757231, 67.06860757643177, 66.35881547004946, 64.19639318220078, 61.70167946046399, 61.5892800208061, 64.12036588115078, 62.52352191555885, 65.3518489099318, 62.50239995218093, 60.246331076468195, 54.63274078984415, 48.81277891897386, 44.842355789676795, 47.70280307339084, 45.81734326577956, 47.524778458379934, 44.86547423947243, 47.54844996236986, 45.121279455000355, 45.54772346250473, 43.11488513023623, 45.655796527862556, 45.15705147097188, 45.30821961741294, 43.32863077040642, 44.33051786115093, 44.89922231243503, 49.15411141610915, 49.15512338761361, 53.670104857414, 55.559204624545195, 60.08223087556901, 54.27584040549494, 49.33728610315631, 44.200204956916075, 45.096443007069254, 41.57405653307515, 49.96457115296395, 57.74304305353473, 59.846480738732126, 53.116250499602295, 59.75716444753832, 56.50804950344948, 59.10295232649773, 55.06007909774781, 62.434076186149355, 36.00942134857178, 46.41752866006667, 62.03561044508412, 53.96394921887306, 50.23195128287039, 46.07858096399615, 50.70778185321439, 47.86831532755206, 49.15522144686792, 44.954531654234856, 47.107316678570164, 45.48731503948089, 45.06176925474598, 49.531011965967, 55.92787211941135, 58.03969583203716, 49.13908873834918, 57.696606113064675, 58.24038390190371, 45.66679485382573, 51.829685626491425, 53.74451221958284, 53.014519906813106, 51.25874542420911, 47.835826335414765, 45.09325804248933, 44.664609662948116, 43.08608316606091, 41.51199679220877, 44.224609944128225, 45.19220767482635, 46.0765334867662, 44.418920240094586, 47.24299146283058, 47.790558261256066, 44.694545192103234, 44.9952733132147, 46.96020034051711, 46.62559470822735, 45.92658519744874, 46.02059264336863, 48.286079129865094, 45.89418249745523, 46.520557557382894, 47.122915944745465, 47.179927595200084, 46.81514324680452, 45.91273138600011, 50.589204680535104, 56.03308577691355, 59.94066076893961, 60.689751102078354, 63.968115160542155, 62.308846673657825, 65.89938040702575, 66.23278971641295, 67.39754538382253, 64.95250455794796, 64.65665194296068, 65.24807476228284, 36.470974491488555, 2.6081091982703057, 1.2937034642504108, 0.5070048943161964, 0.08542169936962667, 0.27526697444338954, 34.957865284335234, 64.69090207930535, 44.72510437811575, 33.60280013853504, 34.49177788149926, 36.22831313840805, 36.02009019544048, 44.88140690711237, 53.32606592485982, 49.05378503184165, 6.09250383992349, 0.28679963141199083, 0.06762972101569176, 0.15452951042642518, 0.07750986504458612, 0.02214581882130475, 0.009915968215453529, 0.014318847886076378, 0.030633967685242815, 0.08462321358702837, 0.043606483077089635, 0.02652761766747121, 0.04551500727933261, 0.0434705292836072, 0.04238970945739458, 0.028206943684527953, 0.08586701095825242, 0.04252083306651443, 0.007967564827507182, 0.009570312216847895, 0.04013337750708865, 0.037723015918726885, 0.03474025641598048, 0.027203232523113973, 0.1439298719408051, 46.87149593907018, 86.56341491207, 68.04432853575676, 61.696082238228094, 30.289179855777373, 28.116912418796172, 30.006726057298724, 42.58618100996941, 65.10397080452212, 82.65786386305287, 11.508464524822852, 0.25998655406217425, 0.33743574494315737, 1.4296002301477617, 2.986897633921716, 0.7415060626883662, 1.026437021791935, 3.206961476995099, 61.96894976400561, 68.4246729266259, 71.87913571634601, 71.82374400477256, 73.31521741805538, 66.35110409029069, 63.47415539526171, 49.32285570329236, 61.43565647063717, 67.80257717255624, 69.91220043551537, 68.58866722353044, 66.58848593311926, 64.57961659277639, 65.55497669404554, 61.826791301850356, 66.0160630749118, 64.55500371994512, 68.36353102037984, 65.37948200779577, 62.64451134589411, 57.65818257485667, 52.263817479533536, 47.50640215412263, 49.3022632598877, 47.52123655811433, 48.65059675708894, 46.9366543523727, 50.29964746967439, 47.34554575335595, 48.57577754605202, 46.27539373213246, 47.25741401795418, 47.28798889344739, 47.652122128394346, 45.650011031858384, 45.86971475232033, 47.23833953180621, 50.14231335732245, 51.65894093052034, 55.9001095833317, 57.396019197279415, 61.86036286815521, 57.1134045816237, 52.4288982729758, 46.951657418281805, 46.70492464496244, 43.100568479107274, 51.040896984838675, 58.91723594357891, 60.38385721944994, 56.97407414836269, 60.16826806529876, 57.94442930529195, 60.23612506927983, 56.52461367268717, 63.62453514529813, 37.401070440969164, 46.644445619275494, 63.93795605628722, 55.211078582271455, 53.25422771515385, 47.30043457400414, 53.8932994873293, 50.14803609540386, 50.08064977584347, 47.26205810423821, 49.99487538491526, 48.11650722257553, 48.645685949633204, 52.11325337809902, 58.82209101030904, 58.85454862348495, 54.3035597955027, 59.330779275586536, 62.50464354791949, 47.78922073302731, 53.11809401358328, 55.615294518009314, 54.42848728549097, 52.821394166638775, 50.68502426147462, 48.77650483962029, 45.507236757586085, 45.9784036297952, 43.5122133839515, 46.83084057223412, 46.82978937702794, 47.26537250703382, 46.7558095532079, 47.094655267653934, 48.342576949827134, 48.76460436851748, 47.602900305101954, 47.42082388170304, 49.27766607653711, 49.00404545568651, 47.469382824436316, 49.21340196363388, 48.84594648115097, 47.911528079740464, 49.92447668506254, 48.8509435807505, 48.93960483612553, 48.70994221779608, 53.63414849004438, 58.970356602822584, 62.18284053187217, 63.67195660068143, 68.94197863917198, 64.88017605197045, 68.97137288124331, 68.13236221190422, 66.53958182181081, 65.98772002804664, 66.39784305326401, 68.12437626623338, 40.45081130919918, 3.191234733789198, 0.4187209832091486, 0.9669506009067259, 0.06574161305663086, 0.027607769081969897, 37.19498911211568, 70.56591049317392, 51.41740529767929, 33.12273340840494, 32.80945762511223, 44.01576334430326, 37.70588174943001, 55.27986518798336, 58.6559158755887, 63.921207535651426, 10.224863002377173, 0.4625223054280205, 0.1737380619611471, 0.09015429179154097, 0.08565622186588664, 0.05897358630693728, 0.047434042207896716, 0.011853180495240997, 0.12908474271816592, 0.08305218175894792, 0.05382238812143764, 0.044683736764014735, 0.006380836815468126, 0.21629977730974076, 0.18631934008050352, 0.10422036322134157, 0.1832884204603972, 0.07036787247465504, 0.1608922230380197, 0.11961599556548942, 0.13925440669540437, 0.11230331860602864, 0.13553771580899918, 0.21740416966138348, 0.29701679284053467, 55.24696826934815, 99.59416404847177, 74.44819404232886, 74.31315468203637, 30.393965974930797, 39.231307198924405, 55.898297448312086, 51.289630166945926, 73.53914553119291, 89.76538688905778, 14.310139013874917, 0.3515309047314429, 0.717417132710257, 3.1184620193896757, 9.862302637869313, 14.780240962582251, 10.959788676231138, 4.379987707061153, 68.87176821308752, 68.07979460685485, 78.36385696165024, 71.76219417202857, 75.36584038888255, 68.52992580782983, 68.41988763501568, 51.02724713663901, 64.86628693919029, 70.47548417122134, 73.44065481616606, 71.58513838245024, 71.41185591297766, 65.74754938002556, 66.58326918079008, 64.50873936376264, 68.82298177288425, 66.07720498115786, 69.9924050607989, 67.75345340851815, 66.19023984478366, 59.71189637337962, 55.01525425141858, 50.38221336180165, 52.346183330782004, 49.97073711887483, 52.21461919046218, 48.31631668152348, 52.77895412137432, 50.63744591128442, 51.34500618903868, 48.32486352612896, 50.11259355852681, 49.666847567404474, 48.91774938952539, 48.18220300059165, 49.49770319846369, 49.823624703191946, 54.035669757473855, 54.21503190071353, 60.583286208491174, 60.91440877606792, 65.3219839834398, 59.29825890448786, 53.37562507198703, 49.06859982398249, 49.772171051271506, 44.66960676254765, 54.51915679439422, 62.646209732178725, 64.29888863717356, 57.52658313320529, 64.73071021418419, 59.72263974528159, 62.49389625364735, 58.93158397366924, 65.16389677601477, 39.7613606145305, 50.0378998633354, 65.43936091084635, 58.55220056349232, 54.64734377399568, 49.98878394403766, 55.88126259465372, 54.53335185204783, 52.792258800998816, 50.11533921764743, 52.817848344003, 50.916722589923495, 51.4488430946104, 55.00280464849165, 61.237753283592966, 60.79647879446707, 56.80466698062036, 60.72855903256325, 61.78350402462868, 51.7869004126518, 56.50360938041442, 58.68252915720786, 55.96262824150824, 54.92261571268882, 53.79096484953358, 50.21751696063627, 47.57793441895516, 47.68502296939973, 45.31492294803743, 48.85403048607611, 47.125496864318855, 48.636342863882746, 48.490764094937234, 50.33195603278376, 50.905116296583614, 50.60116790956067, 52.02871061140492, 50.780761472640506, 51.38165289355863, 50.415345622647195, 49.37634506533223, 53.401504870383974, 49.9243119455153, 51.09355088203184, 52.36039800028647, 53.151139982285045, 51.525411682744185, 51.15671280891665, 55.966205443105395, 63.62564909842707, 64.43200603608163, 66.25153080109628, 72.1491595237486, 68.01713082098192, 73.47464607607934, 71.00131711652203, 69.28811996213852, 66.33411238270422, 71.1069465452625, 71.49202915929979, 45.56317367861348, 5.923980186062475, 7.156083439627002, 2.2377119381581587, 0.15007018922798096, 0.6663831743982531, 43.94093236615581, 78.18924088631907, 56.66392057172714, 49.22203902275332, 42.47648408336025, 52.282005510022564, 48.888382604045255, 65.06923821664626, 67.10088868294993, 76.38766488721295, 13.968351521799642, 0.6443611496398527, 0.30193602726344143, 0.2157450070784938, 0.21737420030178564, 0.12786531460381326, 0.11918697100613387, 0.1943397137426561, 0.22759745979020674, 0.15603911732473683, 0.14665389673844462, 0.12289737997155999, 0.05810122666580062], [0.04807405504247835, 0.03560680528021148, 0.036727549778597976, 0.052214112928918296, 0.04761814462742017, 0.02647830650300509, 0.07935001589958707, 0.11656619187804962, 0.019981172273776705, 0.1201653648768702, 0.08464028968686059, 1.9021363772692221, 60.831682066763605, 66.40014156218498, 58.96444166860273, 46.498607973898615, 24.336424181538245, 33.20821754394039, 39.95667503726098, 41.781730344218595, 70.27185824609572, 56.68845499715498, 1.4828204195345602, 0.09321593153741091, 0.28811696556306654, 2.7414661069070143, 3.9139407536675854, 2.1021908617788747, 2.177573423231802, 57.25153084724181, 75.07967995059106, 68.2669936456988, 70.35812685566565, 66.17550742241644, 74.47071629185831, 68.12962439752394, 65.34389042085218, 52.06231355667115, 50.99020427273166, 54.03976078956358, 66.18507016089656, 64.26291658032325, 66.73319785825669, 62.95530034649757, 63.06231437190887, 64.48095329346197, 61.851129608769575, 61.63702703291371, 60.806363167301306, 59.68523602331839, 63.115305592936856, 56.38294158443328, 52.80386901670887, 46.42192563702984, 45.44705975440241, 47.28977357187579, 50.82089516424364, 46.811209109521684, 46.78592943376111, 44.58597398573353, 45.704830077386674, 45.982337767078036, 47.32866387213431, 45.209560240468676, 45.9229060142271, 44.762484565857925, 44.280750828404585, 43.48075597516952, 48.108329080766254, 47.30054832273915, 50.4277285452812, 48.4650961045296, 51.575527806435865, 45.888028298654866, 45.17589453727969, 44.95058182747134, 44.13953373509069, 43.448980854403594, 53.02412579136511, 57.31205694137081, 60.112617477293945, 55.17098803674021, 56.34778930294899, 55.73790780959591, 61.691336170319595, 54.58615087693738, 63.63487843544253, 36.40067385089013, 42.46792154927408, 63.386580636424405, 53.54928801136633, 49.575726985931404, 45.740111797086655, 50.03561312152494, 49.62763563279183, 49.52757596969605, 46.79258177357335, 47.81399050066548, 46.130422930563654, 48.087042377841094, 45.9733320051624, 52.00756119143579, 52.383551751413655, 57.857501737533084, 56.67108281966179, 60.878142541454686, 63.866549307300204, 52.89728418473275, 54.22825813293458, 54.765995471708244, 53.527867947855306, 51.47143986917312, 46.55459196336808, 44.434162570584206, 42.701231971863784, 44.147131366114465, 45.504549934018044, 44.63256782101047, 45.07819221865746, 44.58835094205795, 44.005129798766106, 45.35772385135774, 45.179487428357525, 45.514085215906945, 44.55187289945541, 46.57564724645307, 46.58988545017858, 48.52439449679468, 46.96120446728122, 46.3774420369056, 46.08004400807042, 47.54142107502107, 49.04566572558496, 52.932157977934814, 57.821415931947776, 60.96302655435378, 64.58466860555833, 62.72820688063099, 62.97239011333835, 62.77664815225909, 65.03782003156601, 63.95109991873465, 64.38455320173695, 66.14783902322093, 63.02891931226177, 65.24871018625075, 65.807447894927, 63.096140892274924, 10.137575557154994, 0.5811757498210477, 0.6135698083427645, 0.17146867970305105, 0.056739785002484444, 11.25128451854952, 67.64845940374559, 48.555691088399584, 49.20761646762971, 41.83057169760428, 30.454507758540494, 34.17548579554404, 33.13134301093317, 51.236238864160356, 50.001786601158884, 16.08813666528271, 0.6166312795492911, 0.09639471378778258, 0.03902140088499554, 0.07603655539212689, 0.04549321973876608, 0.04775628177148681, 0.10025211970411962, 0.06286067429990058, 0.04848521443143968, 0.0033644278582576066, 0.07229265306265124, 0.03845108672976494, 0.10530150480448239, 0.068222772660515, 0.014841780460800135, 0.019080919371316993, 0.04324493554210471, 0.022848918996450883, 0.1291662238297924, 0.09830566648874553, 0.0296116367568292, 0.12238099840619873, 0.16055738132807518, 3.53736870231167, 75.59296131134033, 73.75857076337262, 64.90038410309823, 50.39840098350279, 29.629480338865715, 33.9679100436549, 44.45453143888905, 46.75795901206232, 78.03734317902597, 60.279773204557365, 1.7171955204779104, 0.27688060076006, 0.993754607775519, 3.6215378632468567, 2.842523522915379, 0.9518165646060821, 4.155792382455641, 62.857621562096384, 76.66211312816989, 72.06231824813351, 71.77542824898997, 69.18908011528754, 73.50917077833607, 69.91258482779227, 68.41981703235258, 54.92768341495145, 51.82626924207134, 57.33994107092581, 67.7118056820285, 65.31357049942017, 68.63899123284125, 64.36713395580169, 65.97088521526706, 66.16049258939682, 62.567142594245176, 61.749901079362445, 63.44802848754391, 61.31105845974338, 64.16824625384423, 61.44915334640011, 55.84248996550038, 49.04650119043166, 46.650521370672415, 49.74449872970582, 51.97711575415827, 47.89502666842553, 48.68272881354056, 46.751800890891786, 48.533851331280125, 48.46179346884451, 48.76435333682645, 47.43059450580228, 49.007097059680575, 46.846471217370805, 47.238492504242934, 49.07081988550002, 50.599991198508974, 48.54937215005198, 52.542188090662805, 52.20563696276758, 54.25970769697621, 46.825164902594786, 48.05172927917973, 46.763426796082534, 45.81540953728461, 45.4501780386894, 55.73127508163453, 61.064466891750214, 61.945262570534986, 60.227111462623846, 60.56403913805562, 58.90646511508573, 63.28879987039874, 55.80764755125969, 64.48838618493849, 37.6220214751459, 45.49188067836147, 65.11109775112521, 56.03954592058736, 51.31439208984376, 47.28250541994649, 50.29525833745157, 51.250822236461026, 52.374385172320956, 50.61988938239313, 50.842609405517585, 49.519797909644346, 50.84581398194837, 49.00307663025395, 54.32374039003926, 54.19763226662913, 60.92526981907507, 59.5345111047068, 59.88791665723247, 66.28148201973208, 56.54703394059212, 56.95952215502339, 56.528951814097745, 55.62763821694159, 52.37423219988423, 47.703112940634455, 47.662979249031316, 44.378162891634055, 47.40102767944337, 47.59596163226713, 46.93860377034834, 46.78379958675754, 46.810918854128936, 46.55489790824152, 47.339524915141446, 47.4770785147144, 48.184509354252974, 48.1300707786314, 49.67887747672297, 49.45688701445057, 51.605671221210116, 48.7350179303077, 47.800932930361846, 47.02770825355284, 49.41365857278147, 50.80097344613845, 55.51876106569844, 59.86850092487951, 65.07229766538067, 65.28969895455145, 66.29471609669348, 65.23174985762566, 65.63859378137897, 67.45155642109533, 64.58900674696892, 64.7245717048645, 68.27612492345995, 66.2708680860458, 67.29630116493472, 68.17151531096428, 67.45544741230627, 13.469495657951603, 0.0406708954382808, 0.4440823545859706, 0.5308075525587606, 0.13709554028126503, 10.831515404485888, 72.6700581273725, 55.969288426060835, 51.068314352343165, 36.67898562646682, 43.411898766794515, 40.980547012821326, 40.49926827030797, 55.677887701219134, 61.62645232292914, 23.994511173617457, 0.7481406292607709, 0.04429559831717803, 0.06554723356760318, 0.025252366641296015, 0.00493320978186544, 0.04061667939587947, 0.026812834116900643, 0.01085406969181232, 0.08354265423071, 0.0864534665860476, 0.08372404852942114, 0.019209036085334037, 0.22874414019526976, 0.12454131272651496, 0.12530144814762378, 0.12409354965653151, 0.16427753493189812, 0.16828699397944635, 0.19026470821230643, 0.2836505810339605, 0.20796840259384727, 0.32744568261888723, 0.27947056017095045, 3.8468351287226525, 85.19776328917473, 82.04688410605155, 75.2742059769169, 62.446925870833866, 35.11294011146792, 45.09299916605796, 58.43417644500733, 56.2394142150879, 84.32536540492889, 67.70122312730359, 2.381852422991107, 0.24610740042501883, 1.4327786983020845, 8.774183219478978, 14.659595720229612, 6.269218873593116, 4.748440942456646, 68.56313259370866, 79.50817708046206, 72.824309256769, 76.16982429258286, 71.36861570419805, 76.67723778755435, 72.89625337046962, 70.79479648220924, 57.36077277891098, 55.66857207205988, 60.02303838729859, 71.89097342952606, 68.12725528593987, 71.99023292910668, 66.78232162229477, 66.94287992292836, 67.73942701278195, 65.65741331346574, 64.71253395080566, 65.11313346124464, 65.26028902299943, 67.28804065335181, 63.08543674407467, 57.86414623260499, 51.54303881429857, 48.90167551655924, 51.407281660264545, 54.05910199688327, 50.27671729364703, 50.04526999688918, 48.36347533810524, 51.522073745727546, 52.341135240370235, 51.350109192632864, 52.249073290055804, 52.46434080985285, 50.213602435204294, 49.29520299357753, 50.399063864061915, 54.18975222495295, 51.53046369552613, 55.485471910045995, 53.75691867643788, 59.0632422508732, 49.763294727571555, 50.36855566886164, 50.93023123279695, 48.67533906813591, 47.831633321700565, 57.60634845302951, 62.431722764045965, 65.37673242630498, 61.87396172554263, 61.28187210329118, 60.66356928117814, 65.97755324456, 60.01534661939068, 65.70421895673199, 39.54190008101925, 48.73865788982761, 66.67240112058579, 59.45731885971562, 54.60312297267299, 49.42186417118196, 53.4388772133858, 56.20901976862262, 53.692211335705174, 53.68242502212525, 54.54368729745188, 52.06080344415481, 53.4389909621208, 53.190771610506125, 57.070674280966486, 56.98300146287488, 63.422129077296105, 63.050127567783484, 63.98937048450593, 65.75779853328582, 58.79924712642547, 57.97718501860096, 57.2013048971853, 58.87412125064481, 57.74894229827389, 52.2337721240136, 48.511199643535, 47.2661256021069, 49.594554362758515, 49.85616076377131, 49.12343848136164, 49.35609386813257, 47.29183281621626, 48.84694276317474, 49.335564182650664, 49.09466005140736, 49.25292376549014, 50.50570918667702, 51.805190424765314, 52.28615930003505, 53.826183811310806, 50.77737254481162, 49.936369311425, 49.653350691641535, 53.2764518645502, 53.155438899993904, 58.92518658791819, 62.94614161214521, 66.30823258430728, 68.64639666772658, 69.42337113042032, 69.20054912567139, 67.33502280327582, 69.74064380891862, 65.52197779378584, 65.47882779952019, 68.64434919049664, 70.40716432755994, 69.68642096365653, 72.27753085474815, 67.6481613036125, 13.97960872419419, 1.9573492532776249, 3.2031834990747514, 0.6420397193681809, 0.20796565999907834, 13.325373068932565, 80.9511935326361, 58.83613309552593, 67.0478190145185, 53.69440786300167, 39.31285719717703, 49.680536639305856, 51.83787553541122, 67.56049633026123, 71.44914196383569, 31.467671663530414, 1.5197228135601168, 0.2322107033743974, 0.14812089382640778, 0.2732704573821637, 0.19035138340005953, 0.14498704263279516, 0.3211009424299963, 0.10803857607947243, 0.1803375876718952, 0.2251089763857665, 0.20758519009236368, 0.1389670930802822], [0.028054453883199926, 0.12066826329476411, 0.03403278187878671, 0.045076245742459456, 0.007313506728443768, 0.057227595318709655, 0.019375725326338605, 0.11526466978173103, 0.06562087759976426, 0.15291732435505237, 0.4200416268600572, 11.034680451116255, 77.03823704873362, 61.604867519870886, 58.825978079149806, 38.85237878368747, 16.332984739734282, 35.668743887255275, 37.33274667493759, 45.662268438646876, 79.27412140753962, 34.920426261040475, 0.07353019915641316, 0.020628376758747527, 0.22250479838300138, 1.2750869148200559, 0.9934518498278434, 3.377876060624277, 58.40804953728953, 77.12088923300468, 68.22502428485502, 72.65563164987873, 70.2971810679282, 67.69051505673316, 67.7115075818954, 70.1025216810165, 66.4515716798844, 59.07219309960643, 48.474890262849875, 50.23694446009975, 54.28327721934165, 60.40895254381242, 61.153622365766964, 64.73088672084194, 63.73362802690076, 62.86097911096389, 64.81143259233045, 63.16077370797435, 61.12287490598617, 60.74245991245393, 61.306014291701786, 59.9688429986277, 54.89804206355926, 45.63409405369913, 44.33388717712895, 46.05772964416012, 50.24370270390665, 49.7692253512721, 46.371119176187825, 44.814601098337484, 44.97359437327231, 46.56129921636274, 47.008496484448834, 46.181319605919626, 46.347941890839614, 45.222417769893525, 44.37792362705354, 44.26863854931247, 43.22876330344908, 43.36984703617711, 45.33358558531731, 44.613336440055605, 44.52263162982079, 45.12503316325527, 44.59892565204252, 43.4935389795611, 45.54587994852374, 45.29258897227626, 53.331219919266246, 58.08328513176211, 58.89736913865613, 59.89383943619267, 59.52455220683929, 59.45951930938229, 60.98276784343105, 56.911308380865286, 56.46502110265917, 36.939784019224106, 47.2169469248864, 61.10883282076929, 52.767904804598906, 46.96698604091522, 43.7294146322435, 47.52530405598302, 47.55508269033125, 49.71759127032373, 48.99868749803113, 49.020354670863, 48.67168341913531, 46.88862885198286, 46.265858450243556, 49.208326416630904, 47.31865398345455, 50.052255738166075, 53.66125206793509, 53.0885075753735, 57.60829002626481, 65.60460644383585, 56.75671992763397, 53.91324473965553, 51.24371490170879, 50.60267017733667, 44.142565727233894, 44.8677021457303, 44.22604160924112, 43.3058653339263, 43.658282449168546, 45.25904094019244, 45.57048497661468, 43.827364060186575, 44.00989547852547, 48.38046312332154, 44.61901603206512, 46.16994081004974, 45.219883918762214, 46.25075732508014, 45.727148363667155, 46.08568437637822, 46.35980706061087, 46.966848757959184, 51.09248791971515, 54.55814515390704, 57.97609067732289, 59.78050647243377, 61.03291534608411, 63.767423168305434, 62.60539747053578, 67.20724767254245, 62.418798554328184, 64.17850717421501, 64.47564240424865, 64.14935611909436, 64.45379088001867, 63.96397313764019, 64.72609750686154, 67.51891136169434, 65.3012542570791, 73.27462088677191, 49.46710478874945, 2.713996767997742, 0.3454200665075933, 0.5393550713216105, 0.07266048251861527, 1.3679136047440192, 45.87055021716703, 64.86159186209402, 42.50889070572392, 36.25208662402245, 19.759987015878004, 33.620062489663404, 25.763955116271976, 43.121886560993815, 54.82531739819435, 32.52607030253257, 1.3181648355337883, 0.13980245067467614, 0.023504757292328343, 0.04837055405181262, 0.026742227623359333, 0.055453952386855125, 0.02573400803451096, 0.07523285255076424, 0.026578579751414158, 0.034583262017657684, 0.014269968603677569, 0.026895083231671203, 0.021482066837169474, 0.022715296025478074, 0.07288097794498168, 0.0578524511037094, 0.07086225199483095, 0.04286844163171707, 0.06998056140277656, 0.09554408040017852, 0.05968999725976779, 0.062387354536763126, 0.4635465036957495, 14.144313950692455, 88.11719909791024, 67.1957943516393, 66.87525041641729, 48.440373405333496, 28.82531600613748, 28.980273162165, 42.90622680417953, 51.12578884247811, 83.98739830140146, 36.341112659823516, 0.04719344080395756, 0.07240846257416472, 1.032591036731197, 2.6651375187981516, 0.8855599489423537, 5.841551576891254, 64.79395058847243, 81.00249028974964, 72.90534542452905, 74.45291657601634, 72.74169629619968, 69.06591769187682, 70.98166604195872, 73.20305332060784, 69.34104842524376, 60.89788383053195, 50.59509608053392, 51.160062513043805, 55.70687401679255, 65.0979538886778, 63.60400545981623, 65.30915391060614, 65.97413293776974, 64.27192626460906, 66.44837102582379, 67.28877805894422, 63.56620165609545, 63.89176622513802, 63.411185664515344, 63.03786623862482, 57.99587119010187, 47.701755800554835, 47.83253154447002, 47.70645480002127, 51.731163532503196, 51.365739837769546, 46.66761898225354, 46.65144312766291, 46.601205410495886, 48.68146973271524, 49.97095677160448, 47.13319647696711, 46.86005830764771, 46.283654243715354, 47.726521645822835, 45.5462682631708, 45.893660822222316, 45.115482191885675, 47.037604393497595, 47.54705752095869, 45.957952391716745, 46.1120544710467, 47.9516343147524, 45.700601762340916, 47.193781406648704, 46.14703024587324, 54.72296314854776, 58.75529696864467, 61.15166902542115, 60.96550941467286, 60.39194906911543, 61.29534936720326, 61.95530776054629, 57.65022800814722, 55.8120955190351, 38.52765360186177, 50.60058739877517, 62.55057450263732, 56.12485354946506, 49.232798084135986, 46.65074494577224, 49.80746846045218, 50.20346310830886, 52.986427891638975, 52.30322945502497, 50.79244621338383, 52.194391527483546, 50.76205176691855, 48.05845614402525, 50.255085422146706, 50.741879017122336, 51.43163173429428, 55.09348984687559, 56.599021034856, 56.951351857954464, 65.42217700712143, 59.75955317097326, 55.52755894199495, 52.39953540986585, 52.438249203466604, 48.79404175666071, 46.18409664400163, 45.575556601247484, 45.73075302185551, 46.929390122813565, 47.10486519721247, 47.94950446774883, 45.89552002568399, 45.94334156282487, 48.8539481163025, 47.30911870156565, 47.50331524879702, 48.4792362490008, 47.807922594008915, 48.30645584291028, 48.37973748483966, 48.3828204677951, 49.16456453261837, 52.49933619653025, 57.07278059374902, 60.754077972904334, 62.5744931159481, 63.29401270035775, 66.71070698768862, 66.80701686489967, 68.14964417488345, 64.00918629861647, 62.71503163922218, 66.6072662415043, 64.12202896610384, 68.67805019501718, 65.08703401011806, 67.46479049805673, 69.55548440256428, 68.17129565823463, 74.05463910871937, 56.02557443803357, 4.232470306657976, 0.5801346056884336, 0.26425400087910317, 0.03922960826105649, 1.0454611912850411, 48.17697448115195, 72.1844373210784, 48.84213785971365, 30.224264629425544, 22.896102397672593, 44.2379028566422, 29.44465825634618, 56.37870542464718, 61.21511336295836, 47.564837624949796, 2.445357312117854, 0.1379611736704265, 0.03890818841154537, 0.11829261698069111, 0.029649094625886892, 0.06167865042845088, 0.02503373280858561, 0.06307397616065799, 0.02554433807099779, 0.04145443101503676, 0.023560687456460252, 0.01595454328062554, 0.12772018690743756, 0.22256383311844644, 0.16352569624300928, 0.20086091462402575, 0.15078312597207486, 0.07118345733972327, 0.198605076800431, 0.21325967995630157, 0.1818247941593009, 0.24401400388488848, 0.6807168633226426, 19.07683760889115, 101.28195993361935, 77.15185242314493, 78.20004309377363, 52.7889600876839, 26.836454676043605, 49.993530011946156, 56.991054088838645, 57.693770239430094, 91.69248657841837, 41.999610162550404, 0.26086525691132395, 0.11263533345153255, 2.0903227502299897, 4.385193182576088, 6.7078599814445745, 5.235072739662663, 69.54760828325826, 82.31406027270903, 75.91832191713395, 77.89707137692359, 77.1161823887979, 72.18336259165119, 71.29416127358714, 74.74409764812839, 72.98435764928018, 63.91793235655754, 54.38088540107974, 54.368498556075565, 59.454459451860004, 67.92361367133357, 66.22413696781283, 69.41247478608163, 68.31621939136137, 66.91901622279998, 68.95184732252552, 68.39483937909527, 65.08031499001288, 64.94080805009412, 64.95238688684279, 65.81200568906723, 61.151535664835286, 49.96543799677203, 49.60748641721664, 51.282220809690415, 53.13209687509845, 53.396511693154615, 50.014722577987186, 48.731903568390884, 49.449952263985914, 52.043568549617646, 51.949812135388775, 49.164305656187, 49.618425907627234, 48.480436494273526, 49.51850744985765, 49.82273432516283, 46.40235300986998, 46.805533439882346, 51.20107481556555, 51.01628018963722, 48.084096677841686, 49.465155370773815, 48.09606775160759, 47.92720579331922, 49.812391035018436, 50.21916435610864, 56.7674829113868, 63.10913178228564, 64.28449746101134, 64.5413460270051, 63.23524775043611, 63.291965223127804, 64.17920927847585, 62.06067831285539, 57.226706166421216, 41.68441634024344, 52.95854768445415, 65.13857395418229, 58.47726760372039, 51.66360070628505, 48.635417184522076, 52.247755373677904, 52.49648071104481, 55.36953841486285, 53.49541817941974, 54.93979961641374, 56.07617693562662, 52.626813227130526, 51.97701377253379, 54.709266231906035, 52.37795060680759, 55.14754403022028, 59.26293796108615, 58.444994341942575, 60.68473046825778, 65.15992733740038, 63.9213252067566, 60.05876725719821, 54.53865881889097, 55.03285000401159, 50.393521555008434, 49.579955300977154, 47.36521251739995, 47.929759256301395, 49.77267703702373, 49.471964605392955, 52.03995996905912, 47.82086249320738, 48.411853851810584, 51.899072354839696, 48.753119668652936, 49.77677199148363, 52.095681159727036, 50.12955388715191, 51.38828169914984, 51.02585469522784, 50.596704252304576, 51.242710774944676, 55.79408007283365, 59.94526170915174, 63.727203184558505, 64.47599541756415, 65.55877747074251, 68.93341218271564, 70.01285629887735, 68.00261805134436, 63.277024915141446, 64.93017058218679, 65.96084394762593, 67.00559077724334, 70.79230969951999, 70.70247173309326, 70.7890933559787, 71.4845609664917, 71.37266359021588, 78.31387027617424, 54.8038738004623, 4.756854426476264, 3.122389782820979, 1.66345561704328, 0.21056191665270638, 2.0317068503748987, 56.632443551094305, 76.40434280518564, 57.30287075042725, 50.78086737663516, 25.836873938960416, 48.14064548861597, 40.737858203149614, 65.48044773840135, 73.8778421955724, 57.8694571218183, 3.7701385732619994, 0.3907595094173186, 0.1582634229693682, 0.20890633936130235, 0.09459776263083182, 0.19966900438791324, 0.1847778639245418, 0.27878785325634864, 0.15927202368695892, 0.14539625615842883, 0.10133584300356527, 0.12680636658783884], [0.01975267505904119, 0.02137520906305121, 0.08731155400915493, 0.0600677743674286, 0.06518125804441591, 0.041299623797737786, 0.06578289753487034, 0.062009952812185215, 0.028245518126735286, 0.04187020991418151, 0.09276251473854627, 23.034509112758023, 77.33001432111188, 59.51674276782621, 46.586610271084695, 24.072132918142504, 20.899004090216852, 42.119144393551736, 41.71787415781329, 60.24182819551038, 76.39980070052609, 12.493264790504211, 0.37582968151377094, 0.20324654306375212, 1.2067051712543735, 1.3419258185932714, 1.9095831196154318, 35.5518219547887, 76.1412537482477, 68.37219161372032, 72.15594522414669, 67.73058599041354, 70.28251140348374, 64.9662132417002, 70.28881857472082, 67.16538029332315, 67.75171972090199, 61.97434302299254, 50.62634952606694, 47.87001371383668, 46.453590931430945, 51.8066377793589, 59.584160466347974, 60.55984220197124, 60.752469801133685, 61.173481325949396, 62.15420330724409, 63.905412150967514, 64.50889625856954, 60.74971629727272, 63.00800523450298, 59.3340701441611, 49.60836502813524, 47.623724168346776, 47.42822147184803, 46.9929168301244, 45.91606932301676, 49.247346155105106, 48.563300486533876, 43.341602048566266, 46.55671788800148, 46.548327938202895, 49.67595138857442, 44.92496090550577, 46.954297173407774, 47.518663483281294, 44.84869433987526, 45.792185183494325, 46.74017498570104, 43.76622607631069, 45.28274774551392, 43.91635479465608, 43.043458769398356, 46.37455517245878, 45.04414604556176, 44.38454458790441, 45.815538975500296, 46.71602103017992, 53.48569070139239, 54.023651615265884, 58.94475529270788, 55.28814138904695, 57.9621466513603, 57.6232813250634, 60.22218496568742, 57.11129042410082, 64.33036958017658, 33.9868119455153, 46.17439662256549, 59.891729201039965, 51.199854958441954, 50.17476312575802, 43.4648193851594, 43.696878571664136, 43.30088784617763, 47.12231974447928, 47.367511026320926, 47.77372737084666, 45.20721466310563, 47.61302002014653, 46.38467880987352, 48.112573085292695, 46.55768279106387, 47.35990947292697, 45.10020063769433, 49.72614988203972, 49.11598597803424, 49.86846916137203, 53.81586797775761, 52.49493921956709, 51.05247582158735, 47.710349713602376, 46.646779429528024, 43.93391132354737, 43.45011049701322, 43.30018181954661, 44.58305574232533, 43.1842444019933, 45.188830514107984, 43.921924560300766, 47.489033898999615, 46.277394140920336, 45.23209033473846, 44.02831492885467, 44.83236159047773, 45.42399229541902, 46.3962576466222, 47.667650791906546, 45.5574195615707, 52.41753908895677, 58.95774226034842, 62.21014022827149, 59.99418150994086, 65.22651741581579, 61.96559613750827, 60.32764181014031, 63.716985410259625, 62.785932402456964, 63.78027285298994, 60.22014533319781, 63.71825233582528, 64.32396042731501, 63.22960738212832, 64.56139326095581, 64.25412262639692, 63.99251230301396, 67.73216278322282, 64.57452927866291, 68.07415423854705, 22.943537581351496, 0.10004032703657305, 0.7385432023194529, 0.09139764483176893, 0.033433241469244805, 14.32896835188712, 75.12747010877057, 47.640217734921364, 55.62076230202952, 32.61295276303446, 29.9835213153593, 45.29422067826795, 35.08626014955583, 55.262422407827074, 44.65292099983462, 5.841026959880706, 0.35399605309770954, 0.08663237109900483, 0.03573238241275953, 0.08476465640048828, 0.050203813945934664, 0.09398143723486893, 0.021842725710162235, 0.04360192868437979, 0.07749425217268929, 0.072421217938104, 0.08877245303724082, 0.05244242628255198, 0.007983310328375908, 0.02951713023527015, 0.020815865286896308, 0.040315281254269426, 0.08807564244395302, 0.04048636400951974, 0.06423590937629342, 0.03398395526493269, 0.0904651013233008, 0.04880086563888097, 31.750486320064915, 89.19290911766791, 66.57795829157676, 54.61072844843711, 32.88043879693554, 22.116845115538567, 28.719863084054765, 47.842294323828916, 65.55331360909247, 86.16607881361439, 13.189003044559112, 0.32151775554783885, 0.2590238573330064, 1.8189644789503467, 1.3400101084862988, 2.276635088266865, 41.2635499431241, 77.82599802940123, 70.82331995810233, 75.4224637246901, 68.38861850000197, 72.10345606650077, 67.87365836481895, 72.88133267433413, 69.44280255225398, 69.53561367527132, 64.89012318272745, 53.405890080236624, 49.99682088052073, 49.22673017747941, 54.02420859183035, 60.137716724026596, 60.96021421494023, 64.54185985749768, 63.44989161337576, 67.25470050688713, 67.59551525115967, 64.77942605172434, 64.25211045049852, 63.03353201958441, 60.4949152085089, 53.16653528521138, 48.490830775230165, 48.49290570905132, 48.476584726764315, 48.40336192038752, 51.69507380454771, 50.144929578227384, 45.4763324029984, 47.91588191063174, 46.65678931820778, 50.755807353604226, 46.43080196072979, 50.16261946770453, 49.146317666576756, 48.1762880663718, 48.408237426511704, 47.802627394276286, 45.83590784380513, 47.41995311552479, 44.993017950365626, 45.424392377176595, 47.017655218801195, 46.08194243523383, 47.76958142557452, 46.957721402568204, 49.486869612047755, 55.12690451837356, 57.604489249567834, 62.16593511642949, 59.65644190388342, 60.2966001725966, 60.507121624485144, 62.010158185035955, 59.09384066058744, 65.48399748340731, 35.47731261099539, 48.276218291251894, 63.59711777779364, 52.97706911640783, 51.47282446584394, 46.135341582759736, 46.228654769159135, 45.84572553634644, 48.738806939894154, 48.82588355771957, 49.31013545682354, 48.333073046899614, 50.523865838204664, 48.69850066400344, 50.35999705714565, 47.585269251177394, 50.01690733817316, 47.45756080073696, 50.906740157834946, 51.333207699560354, 52.717098343756895, 55.556211856103715, 56.22317560257451, 54.27376939404396, 49.754539997346946, 48.31332783545218, 47.88445195844097, 45.06712329003119, 45.36905557878556, 46.805909987418886, 46.19278861630348, 45.740751143424745, 46.81277805759061, 50.015279554551654, 47.33242150275938, 47.29198578865298, 45.71777782132549, 47.088057841024096, 48.18989869086973, 48.52374730571624, 48.23739074891614, 48.57800545230989, 56.13953890339021, 61.16924516616329, 62.46848713967108, 63.29260456946589, 65.93773334257065, 64.09612563348585, 62.398060983227154, 65.35070750021166, 62.68120119648596, 65.82662044032928, 61.673399171521595, 65.14505370970696, 66.25361750202795, 66.93771023904124, 66.18519567674207, 68.03445985240322, 68.08201466837238, 70.83636576129545, 67.8433305986466, 71.33309471991755, 28.61852865065298, 0.1695553444686436, 0.5689628374192023, 0.12126494619634845, 0.08636488383936305, 14.745689784326862, 79.43018467195573, 55.12046398655061, 54.352365847556825, 24.48282272584977, 38.87956080898162, 51.96993389437276, 44.066989498753706, 59.71680718083536, 59.39552584002095, 10.984227003589755, 0.5829976294790545, 0.13482289448861154, 0.10109715298899721, 0.07465788824183327, 0.05619198234090882, 0.04620054105837499, 0.03463259807998135, 0.02187447813940385, 0.011433715755570562, 0.038637372499872605, 0.07740663469678934, 0.13818162313151744, 0.07909721454545375, 0.13429726624200422, 0.17937484497745193, 0.08929693981284097, 0.15095613926889437, 0.16178067052556624, 0.19483880470356635, 0.17491895585290848, 0.19801440768905226, 0.1418038094115834, 40.36517812359718, 97.82723042272754, 76.92462951906266, 64.82864787501674, 34.801943225245324, 31.13801214002794, 58.73311596532022, 59.78831198907668, 72.58233824083882, 93.08914845989597, 15.960089910414913, 0.5141197060865741, 0.5626184649525151, 3.4592279791831975, 7.338039740439385, 3.7573962634609597, 46.17933096424226, 80.27615362598051, 75.00745342623803, 77.53393050163024, 73.05351688015845, 74.56328422792497, 70.17372054438438, 75.29689296599358, 70.50518435816612, 72.837966949709, 67.13872386563209, 55.81797122955323, 52.27013641788114, 52.16676627435992, 55.64300214090655, 61.88355192061394, 64.67407903363629, 67.85888671875, 66.33309256645941, 69.68385573356383, 69.25334422819077, 66.41707835658904, 67.2666637359127, 67.0070420542071, 64.71018052870228, 53.9781835002284, 51.941806577867084, 51.82267242862333, 50.75403444228634, 50.24580509431901, 52.36446157578499, 53.4159391926181, 46.72790973417221, 51.17138639573128, 50.740172786097375, 53.84936894139936, 49.629730178463845, 51.92286545230497, 51.41423994495023, 49.057978045555856, 51.2848448753357, 50.654649426860196, 48.352378952887754, 49.28729549531014, 48.68557645428566, 46.520569324493415, 49.239007196118756, 49.66762419669859, 50.967874219340665, 50.192970768097915, 50.655218170535186, 58.19271925956973, 58.54657588466522, 63.13867115205335, 61.91282064683976, 62.82967075224846, 66.31815618084323, 64.66720704109439, 62.34576402171966, 67.25359439849854, 39.889982977221095, 50.82551179393646, 66.12190431164157, 56.92431496035669, 53.88297580903577, 48.08399861858737, 48.70641600701117, 49.454513980496316, 52.223432756239376, 52.87638187408448, 51.82401387922226, 50.508297950990745, 54.341528338770715, 53.036457723186864, 53.35112594789075, 51.69583866673132, 52.592892569880334, 50.68513408783944, 54.15365857462729, 54.83753558128111, 55.56914783293202, 58.1003592091222, 57.86364024685275, 57.72171712690785, 54.25319264011999, 50.994295304821385, 49.923390188524806, 47.038031931846376, 48.4144308490138, 50.3491085575473, 47.505986382884366, 48.35899991373862, 49.68290182851976, 51.776792464717744, 48.71880677438552, 49.320874906355336, 47.5283674270876, 48.16434837156727, 49.15347206977106, 50.69760330261723, 51.6384308568893, 50.484999072167184, 60.04021052391299, 63.033543786694935, 65.86323184351768, 66.85902749338459, 69.76337786643737, 67.15360533806586, 64.43982724220523, 64.32041852704941, 65.65075312891315, 64.47705445751068, 64.07062238262546, 68.8079434056436, 69.91948819929554, 70.15930975637129, 70.808289435602, 69.41997435785109, 70.137815167827, 70.286865234375, 70.22984966155022, 73.66853667843726, 29.110984186972345, 0.5420487590374485, 2.1431828170053424, 0.21290133466884015, 0.11885550774393544, 18.478307454816758, 87.80595117999663, 59.99731548370854, 75.05403549440446, 43.872330111842004, 37.56998339006978, 61.44433275345833, 54.093199160791215, 71.70457455419725, 70.55820695815548, 15.553491134797374, 0.7806126448896624, 0.3037492654496624, 0.41309921551615963, 0.18532187828133184, 0.14634916228392433, 0.18252913539688434, 0.1768937773041187, 0.10382332283282474, 0.20546239109769945, 0.23648098471664616, 0.1352726647089566], [0.056311809983585155, 0.06476988415083577, 0.043494599766188094, 0.021309413601674383, 0.010878610360856739, 0.05918501508271983, 0.020339892944321036, 0.051551546465845845, 0.041058191188400796, 0.07081372032482779, 0.1911784978883882, 42.48457593302573, 70.05906181950724, 57.96301349516838, 45.14833204207882, 18.046923222080355, 37.24477967908306, 45.1727056503296, 47.500138128957445, 66.21325631295481, 62.83561314305952, 3.949444577578576, 0.12063547473160491, 0.13192006476944493, 1.404160840376731, 0.49471200233505624, 2.9245133169235724, 56.218562895251864, 80.60192215827205, 70.1213098341419, 64.37875986099243, 65.18454413260183, 67.3583059926187, 69.50728631788685, 64.46865274060157, 67.59971218724405, 64.74489742709746, 63.15223078573904, 54.094732807528594, 49.25777181502312, 48.034729726852916, 48.96572782147316, 47.93349727507561, 53.436410042547415, 55.81454700039279, 59.29832558478079, 60.11482184933078, 61.35627162071967, 58.979601629318736, 59.108804502794825, 55.81134242396201, 50.90466914638397, 45.587535519753736, 47.664336389110936, 47.779646227436686, 47.21718618946691, 44.71990331526726, 45.43628892590923, 47.596236198179184, 46.47364208775182, 45.086315447284335, 47.25334259771532, 43.9711267717423, 46.19375351936587, 45.586735356238584, 44.77195708982406, 45.11930258043351, 44.878567111107614, 45.209956399856075, 45.73936654675392, 46.487750853261645, 45.32947886374689, 45.073285333571896, 44.61236369225287, 44.91099726769232, 44.42843591013263, 44.602228287727606, 45.03372430801392, 50.38286839762042, 51.34876381966376, 54.84301121004167, 53.14693912383049, 55.08282492237707, 53.75632639854185, 59.18900520570817, 54.51737603833599, 62.56145123512515, 36.15242704268425, 44.335358065943566, 59.41577703722062, 53.059862506005075, 54.52660537535145, 51.6966623644675, 48.06848956692604, 40.73043315641342, 43.08844835527482, 41.65374340549592, 44.371071246362504, 45.513371344535585, 46.461631790284194, 46.927931001109464, 46.626328191449566, 43.91389546855804, 46.425177281902684, 45.56415819352674, 42.5773831336729, 44.74042907837899, 46.79420955719487, 45.247407190261356, 46.1047431730455, 44.93771253093597, 45.69159600042528, 45.00765623584871, 43.205535027288626, 42.449051026375066, 43.15895688149237, 41.85733402928999, 44.45340964101976, 43.07880716939127, 46.41842688283613, 45.60341719658145, 46.12380196971279, 44.242582244257775, 45.694114162075905, 45.361438335910925, 43.75502770946872, 46.932096558232466, 43.47417816039055, 49.73996839215679, 62.091080604061005, 58.10925906704318, 64.27497394623296, 61.51594738806448, 58.874454652109456, 57.62991405302479, 59.6826276471538, 67.04477525526478, 53.535163556375814, 54.146900330820394, 65.02169516778761, 62.03670478636219, 61.79577712089785, 63.80239109839163, 66.9658963910995, 64.71882543256207, 65.23706466920915, 66.68188541166245, 70.91522893598004, 70.27286237285983, 55.158271712641564, 3.0072745921150332, 0.7366935596350701, 0.1395629103025121, 0.04832848816389038, 1.7440301708636747, 53.966565439777995, 63.37016943962344, 46.97989848352248, 39.065096762872514, 16.225059743850462, 34.012385799038796, 33.911408301322695, 47.193102836608894, 47.66450112865817, 23.694918578670872, 0.8174098703649737, 0.04545010431038757, 0.05239509354015032, 0.1131169576077692, 0.060749190423877976, 0.029440609542953394, 0.023141317520170443, 0.030689413298762618, 0.06140470504760743, 0.06706611779067786, 0.03693433606155938, 0.061336607492018136, 0.04716723293606793, 0.039461916763215296, 0.10523500837265484, 0.03764909992535268, 0.03753065124094006, 0.06528280299877928, 0.024903093750077872, 0.022671002736915986, 0.027737858472391966, 0.0501026482050938, 54.014218315001465, 77.8320384794666, 64.59323898438485, 52.255866835194254, 25.098207304554602, 32.84089738322843, 43.06487883290937, 54.22914851096369, 71.6980085065288, 68.89318435422837, 3.274059502347823, 0.11024713095638061, 0.7884883964734694, 3.7934707922320214, 3.093844733891949, 3.2272514076002183, 57.39364224095499, 82.8249332981725, 75.92042430754631, 67.2124408906506, 67.68920498509561, 69.38258632536858, 71.93228383218089, 65.82390616017004, 69.46777236077094, 68.75557191910283, 67.64787104821974, 57.043774666324744, 51.394635938829, 50.42501818749213, 50.8205892193702, 50.098696601006296, 54.24177462054838, 58.305452100692264, 61.50884397568242, 62.022301843089444, 63.077309593077636, 60.7391768886197, 60.84390417222054, 57.854575649384536, 52.2114146140314, 47.65767228218817, 48.81944302589663, 47.92415811169533, 48.778387577303, 48.01236829450054, 46.81790067303566, 48.801058876898985, 48.026535895562944, 48.50994448507986, 50.11963421298612, 47.67336960761778, 47.79419037603563, 47.1352243423462, 46.53226975471743, 48.68648252179546, 47.51382327848866, 46.49869034367223, 47.12544195113644, 48.9038485096347, 46.90003118207378, 46.8451258444017, 47.832417795735026, 47.79709685233332, 45.71025471533499, 45.91851688200428, 48.934501832531346, 52.7891718956732, 52.77592212923112, 58.7027136741146, 57.36242017438335, 57.11913908681562, 56.113965049866714, 59.67690490907239, 56.464252318105395, 65.97927124269548, 38.52386066990514, 47.64350075875559, 63.68122908376879, 54.02276515960694, 57.51128196716309, 55.06316600307342, 51.71390118137483, 43.83126681850803, 44.62025550103957, 44.1405104052636, 45.21426316230528, 47.467300045874815, 49.52532060684697, 47.59630680084229, 47.42748406625564, 46.30931046701247, 47.62539509804019, 46.859968093133745, 45.32094378625193, 46.12877553509128, 47.414210765592514, 48.00125621980237, 48.46229553222657, 45.52862151976555, 47.2002140937313, 45.561404689665764, 46.67628742033436, 45.54760971376973, 45.17112101277998, 44.01430030022898, 46.34192889736545, 45.16733200319352, 45.928769957634714, 48.077001110199966, 47.362682588638805, 47.73953999242475, 48.0301836998232, 46.44677385207146, 45.861124761642955, 46.935591390056, 46.46139252570368, 50.37036780388125, 64.68564610327444, 60.42544218801684, 67.63357008657148, 61.31310593697333, 61.55307262174545, 58.732668815120576, 60.723663914588194, 67.22930708239156, 55.41188824561335, 57.355265771189046, 66.0023896924911, 63.85620993952598, 64.13334892642114, 65.42215347290039, 67.70272931744977, 67.09378919293805, 68.3058721788468, 69.63040951759585, 73.87873649597168, 71.62168702771588, 60.555915909428755, 4.207492163104396, 0.47236325639870863, 0.27391400188207626, 0.09813405513282746, 1.5241150101346355, 57.27588092127154, 68.73967063042426, 51.394784988895545, 30.657270762228197, 25.038406848907474, 44.375044607347064, 42.623286631799516, 57.24848316561792, 56.83999969113258, 37.325388308494325, 1.1974130763161568, 0.06511493781281096, 0.028046455925270438, 0.05798464340548362, 0.029171138115587737, 0.0722703445822962, 0.018839823840666684, 0.06847179720118161, 0.010798106968943632, 0.04348439164459706, 0.021817408419484575, 0.1690988939615988, 0.18984300745350702, 0.26568609500123613, 0.23314906915109004, 0.10421571306764119, 0.14010461107377084, 0.14624184868749113, 0.08482308592647315, 0.13501349716417252, 0.2258243339677011, 0.5733400186704052, 65.49943201003536, 87.52750996620425, 72.89409606687485, 63.42970317409885, 31.68009350376745, 54.63634937040268, 62.60914725642051, 63.11496826910204, 78.28759824076008, 74.99845550906274, 4.794237555996065, 0.18747127584872708, 0.9818485595526235, 5.629952944094136, 7.4985985313692405, 5.617672003084614, 63.33382083523659, 83.64586184101721, 81.08944923646989, 68.83907918007144, 71.41823368687784, 72.72752085039693, 75.99222721592074, 67.67823019335347, 72.26399083291331, 70.51939118293025, 70.43229887562414, 60.292203195633434, 54.09945141884589, 53.26148802234281, 55.154188525292184, 54.39654742517779, 57.79200992276592, 60.55422929025466, 66.29786968231201, 66.1549698921942, 68.99067878723145, 63.893311638985914, 65.31671624029836, 60.69995710926672, 55.826827941402314, 49.879643993992964, 52.38779183356993, 50.16564753747756, 51.524858628549886, 48.2880481596916, 49.57393054039248, 50.870740644393436, 50.96579144077917, 49.39408594562162, 54.04809974854993, 49.10359521065989, 50.01709168957126, 48.914854680338216, 48.30585964264409, 50.05784511566163, 49.34660173231556, 49.678434248893495, 50.30991231241534, 52.38514423370362, 50.1518564839517, 50.884366958372055, 49.36889648437501, 49.888253596521196, 47.8590859905366, 48.435972506000155, 52.06290191219699, 57.370935640027454, 57.182457908507324, 61.27104636161559, 58.013855257341945, 60.87207463479812, 58.23653605676467, 62.1655938702245, 59.98352835255285, 67.05700520546206, 42.84300604174214, 50.90874841136318, 66.82003128913142, 56.95709420788673, 60.50729028640255, 58.2602350173458, 51.36755589515933, 47.3012347375193, 47.34818158611175, 47.31045622979441, 49.22887179159349, 50.322224632386245, 53.09404988442698, 51.5136210380062, 51.451157293012066, 48.811539449999415, 53.733172647414676, 49.93786373446065, 46.66778764417095, 49.71855617338612, 49.57125548393496, 49.60024572187855, 52.38596400906963, 50.39907563117243, 50.33492134463403, 47.41712900900072, 49.96750116348267, 47.844204518102835, 47.794751274970274, 46.07822402831047, 48.315971512948316, 49.49053702815887, 49.1326678183771, 50.075252594486365, 51.41258078236734, 50.232159168489524, 50.25960007021504, 48.884311183806396, 47.12954082796651, 50.53087511370259, 49.19166026576873, 54.0630086775749, 68.42227243608045, 61.82085283340947, 69.14622429878482, 65.12990943847164, 63.21959749344857, 60.41461252397107, 63.245037986386215, 69.27700396507018, 59.607157322668264, 58.84939070670836, 67.59485629297072, 67.32634652045466, 65.22795300329885, 67.96723042764972, 71.4556452535814, 69.93965702672159, 70.38484604127946, 72.05812915678948, 78.03942203521729, 76.26473780601256, 62.63144593085013, 4.522146169216403, 1.2866483460510931, 0.6818703465884732, 0.17655833804559323, 2.62253592091222, 66.15084355877292, 73.96514631086781, 63.461917600324085, 54.459171987348995, 22.392475951102472, 44.90358398806664, 52.032691817129816, 65.03893398469495, 70.84574807074763, 46.88170586862872, 1.4276575537458545, 0.14338435605168343, 0.1546174266766156, 0.29765849872942896, 0.12274243868887426, 0.19432232354677495, 0.12367766350507738, 0.17352548788391775, 0.19213633762011606, 0.14409542354124208, 0.16895968046399856], [0.07287189980307895, 0.007751297727677852, 0.01035702322805, 0.05316360996315076, 0.02013826243309004, 0.06389984192567007, 0.021044632547625133, 0.04281933922621031, 0.029407981858258287, 0.08154496505496003, 2.585773751620324, 57.60991388751615, 59.414557180097034, 61.62536190402124, 28.432880909212177, 13.853959518094218, 52.26715541655018, 36.69030950915429, 55.641393969135905, 72.35317768589144, 46.77039292550857, 0.075638756576565, 0.10212326647653695, 0.7303389522337145, 1.3022825458357412, 3.701708903235774, 8.239769108833807, 89.68832015991212, 67.68430202238022, 71.62231460694345, 57.316222498493815, 64.18811698113718, 65.69749601425664, 69.2259817738687, 65.50883785370858, 65.85614804298648, 65.69866880293816, 66.00472742511381, 55.42293364001859, 51.90036281462639, 50.03316556253741, 47.125230143147135, 47.19887656550254, 47.404400917791556, 48.19459769033617, 49.15279742210142, 50.37057176713021, 51.343190131648896, 50.245828628540046, 49.41219945107737, 46.40203922025619, 45.96570299517724, 45.766760380037375, 45.55132027595274, 45.04830768031459, 46.539557518497595, 45.722692551151404, 45.337515800229966, 46.85270778594479, 47.330130838578754, 44.94780086701916, 46.029245391968765, 48.193436668765166, 47.34779327146469, 47.264686092253655, 45.53871770058909, 44.70701440688103, 45.66963072746031, 45.9469501433834, 44.54544021237282, 47.30939326747772, 45.332714819139056, 47.74724352744318, 44.64640986534857, 45.99323018904656, 42.588487363630726, 47.11600472850185, 47.9464763979758, 50.37174847818191, 48.455945214917584, 52.24233073572959, 49.85048117176179, 51.58501994225287, 48.27324513466128, 56.35185680081768, 52.48304267083445, 63.06437753861951, 41.83361153448782, 39.41375624748969, 65.11224308321553, 52.144906905389604, 57.744133472442634, 55.53553704292544, 54.86035985331382, 49.67138967206402, 46.397504960336995, 40.38606082239459, 43.46924381871378, 43.111049052207704, 43.368485973727324, 42.363923826525294, 44.56795461716191, 42.65303780955654, 43.743480251681426, 40.58179101636333, 45.36096372912007, 45.04571107126052, 44.587001646718676, 42.37621653464533, 44.524282947663345, 44.28554004238498, 42.30134241042599, 42.71776868451027, 43.490730562517726, 44.725739802083666, 43.300224965618504, 41.85962469347062, 43.18471508641397, 43.55890920085292, 45.455233973841516, 42.886748313903816, 44.14859833255891, 45.33298154031077, 45.736420846754505, 44.29197665183775, 45.20173118960473, 46.569316540994954, 45.08110261732533, 54.684578834041474, 60.27341504250804, 57.850225740863436, 48.209910623488895, 58.09251839114774, 60.02639593616609, 60.9147657117536, 60.8886113474446, 54.84484687928231, 63.14579809865644, 55.48749193068474, 59.12532552596062, 65.31797924349385, 64.06814344467656, 63.52279278539843, 62.98267456793017, 63.14052643314485, 64.89186079271379, 64.84094842787712, 67.68970704847767, 64.07317584560764, 67.79110031743204, 15.897832089854827, 0.23596572930053358, 0.12852023550940136, 0.10026437711090812, 0.042720023587706595, 17.753396572605258, 74.3852400010632, 48.79080187889838, 43.915687991726784, 18.429340585585564, 26.281576579616917, 30.177194226172666, 45.111383315055605, 51.49949658301569, 40.80135745386924, 5.001596106636909, 0.22219715279436883, 0.040616307843236193, 0.019571347793023434, 0.051487015049544074, 0.07394138918889147, 0.024694961067589543, 0.016861526265500054, 0.04759768624940226, 0.02194407339688511, 0.007943296119675883, 0.0012631421686232751, 0.018146891567495563, 0.08172898703525144, 0.060595677895171035, 0.03348848023902505, 0.07412587848281668, 0.09579435366416171, 0.13542169945374613, 0.0785117854754771, 0.15743365781682153, 4.105600507990006, 70.31021902638098, 67.8522579131588, 70.09692838115078, 35.35779014710457, 22.508876208336126, 43.190257395467455, 41.84003637683007, 60.636410790105025, 78.1533904229441, 48.45536078176191, 0.057420362192656726, 0.010754462939897373, 1.7828264568121204, 4.79777112122505, 3.57708441634332, 9.025646371226157, 92.58876385227327, 71.3089015406947, 74.63963708569928, 59.18134089439147, 67.48643413666757, 68.05787640233194, 72.66708497078189, 69.25868649636546, 67.39717668102634, 68.42417086324384, 68.54516813831945, 57.0486266382279, 54.75033344761018, 50.02557185388381, 50.81774550099527, 49.912890003573516, 50.4946598699016, 51.82689682129891, 52.373745825982866, 53.10263987510435, 52.99744975182318, 52.036684789965236, 51.97552719423848, 48.730675866526944, 46.406989251413655, 47.86157669559602, 47.94796689864128, 48.890088835070216, 48.979001122136275, 46.1402916139172, 47.01479973331575, 48.83126504959599, 48.64806290595762, 47.10578303183279, 49.171989579354566, 50.04919628943167, 49.434760924308534, 48.06904654349051, 47.962722855229536, 47.39357125374579, 47.33353937825849, 49.55889217315182, 47.84348280199113, 49.12001425220121, 48.390402409338186, 49.79057088974984, 46.848361799793864, 47.00976733238467, 45.60078528619582, 47.28250149757632, 49.23370022927561, 53.0345828302445, 50.865268938003055, 55.892574710230676, 52.05997582404844, 54.808423749862186, 51.49887292615829, 57.22025778985793, 55.44746806544643, 65.32302341153546, 43.873024371362504, 42.203291000858435, 67.4503012626402, 55.13130149533672, 61.58139997912992, 57.823879180415986, 57.591223793645064, 52.77341573469101, 49.28672675163516, 42.67541885375977, 44.70787340594877, 46.34105028644685, 46.28840031162385, 45.039996177919456, 45.56397776449881, 45.66575150335989, 44.571778928079915, 45.3984772774481, 45.96231406734836, 46.47183779747256, 46.381317338635846, 44.05170794456236, 46.18480267063264, 44.62058105776387, 44.26924259431901, 42.89562071523359, 46.111579864255845, 46.31058915968865, 45.88674960597869, 44.322010240247174, 45.51392832110005, 45.85544516963344, 47.514058620699, 45.626421897642075, 47.13456930652742, 46.80176404214675, 48.1821951558513, 46.251279000313055, 45.84168549506895, 47.8938695692247, 47.16538344660113, 56.21338928899458, 62.73819323508971, 59.789524001459924, 54.71282382165232, 60.04307777650895, 60.95946504223732, 62.32805452039165, 63.64697110268378, 57.752264545809844, 62.77709530245874, 57.14796850758215, 61.98520798836986, 67.40659821418025, 66.22785537473618, 66.24978926873976, 64.97905115927419, 65.10123299014184, 67.57566805808776, 67.68729086845153, 71.75292168894123, 66.5037235136955, 70.45742557894799, 19.107447785715905, 0.2264345229993905, 0.06850349791948834, 0.1684025966472203, 0.05428001074300659, 20.68302466023353, 80.30856024834418, 56.395626529570556, 41.29626251036122, 18.155139453949467, 34.36848209750268, 36.34973402946226, 58.056871891021736, 58.087772323239236, 54.81713141164472, 6.964254042794628, 0.16910255586187686, 0.03894434776157141, 0.026135805829037583, 0.061880748253315694, 0.04907142874153872, 0.026426704735645366, 0.04901135595695627, 0.008147693644728391, 0.012673584053352957, 0.08413217421020232, 0.1366592532083873, 0.09116656973116821, 0.16811108487027307, 0.15592998043904382, 0.18187402296931515, 0.2504131976034372, 0.255272294124288, 0.1549515482639113, 0.34929662462203737, 0.4778486910846926, 6.174102867803266, 82.16646148312478, 77.08607427535519, 80.41615086217081, 44.27368271735407, 26.09643678511343, 64.7535187967362, 51.833447179486676, 68.0743032886136, 85.40358574159684, 53.85213421237085, 0.3203135266179039, 0.2850514800558167, 1.848412040741213, 7.443236727868357, 9.954645037651062, 10.738460113925319, 91.62124849134877, 75.77026028786936, 77.99098860832953, 63.555658325072265, 71.50179586102887, 70.6213806521508, 74.87541860149753, 72.88578064210954, 70.76488448727515, 70.74930483295073, 71.56913511214718, 58.85814543693297, 59.56738841149115, 54.83533120924427, 53.84031218867148, 52.32052318511471, 54.34697258856989, 53.866748963632894, 54.385470651811175, 55.22707793020434, 55.70889403743129, 54.314197263410016, 54.342861944629306, 50.87665557861329, 48.476604338615175, 50.975271809485655, 50.91449076129545, 49.030399860874304, 50.70392224096483, 49.99965283178514, 47.94426025882844, 50.269421685126524, 52.949216365814216, 49.877698498387495, 50.50570134193667, 52.26480983918714, 51.93228698545887, 51.233081356171645, 51.77125407803444, 48.800003759322635, 49.676331858481134, 51.775254895610196, 49.350857503952525, 51.91647591129426, 49.525559871427475, 52.2473160682186, 48.364981528251406, 50.182274464638006, 48.14832548941336, 50.83327808687764, 53.80622679187406, 56.39014697843983, 53.85715484619141, 58.1980929067058, 54.6193733522969, 57.63547989629931, 52.248469245049264, 60.599811154027144, 58.94216260602398, 66.22368197287282, 48.98268815009825, 43.768371612794944, 69.1052512199648, 59.407583205930656, 63.20903455057452, 61.63969424463088, 61.3343338043459, 54.93806985116775, 51.03502127432054, 45.45749325906077, 48.618656896775775, 48.89700789605418, 51.579450176608184, 48.39208902851228, 48.025570992500555, 49.988905537513, 46.99701962932464, 46.34416464836367, 49.64245042493267, 49.65904205076156, 49.03104705195273, 48.36103562385806, 50.09886918529388, 47.916321216091035, 46.939121523211085, 46.32924787459835, 47.25544498812768, 50.0886082649231, 48.18377194866058, 44.71835005667902, 48.330362689110544, 49.078127261131044, 49.5057205230959, 47.19362451184181, 49.412026866789795, 48.970893582990094, 51.507243264106016, 48.417713872848026, 49.448559822574744, 51.208727359771736, 49.949811274005526, 59.67623026140275, 65.51865946862006, 60.713822687825854, 58.57979836002473, 63.40489418275895, 62.71567490793044, 64.06926132017567, 66.57118828065934, 63.07209676311862, 64.27846093331614, 59.504218639866004, 61.96140704616424, 70.57020156614243, 68.03628767690351, 68.42758332529377, 68.51180445763373, 67.71073879734163, 71.23796939849854, 70.07497879766649, 72.75336926983249, 69.20335754271477, 73.4791724912582, 19.050616564289218, 0.6293549580920128, 0.9498361966783001, 0.3761332974799218, 0.16017410753955766, 24.199815873176824, 86.64813026305168, 64.48477368200979, 58.94157032812796, 26.113463794031453, 33.95566048160676, 43.43502506133049, 66.82202385317895, 68.80942606156873, 67.09411867203252, 8.787261382226022, 0.48168768024732994, 0.14462526527143296, 0.1252824798106186, 0.2342879201375669, 0.14300305877001057, 0.21922358251627416, 0.14403211403517954, 0.09602425665023828, 0.10928769010089098, 0.16174261127748799], [0.09553586027675098, 0.029471559495094325, 0.06844596471637487, 0.0903730558591985, 0.05178491599977978, 0.04031520081503738, 0.09022409006232217, 0.05580877750030449, 0.08143527658596154, 0.3288495234183727, 7.38832256486339, 71.06584795059698, 61.243350505828865, 56.558326444318226, 32.58180129912592, 27.36026171715029, 70.99257023103776, 50.54085754579114, 52.931891256763095, 76.19485685902258, 24.011832360298406, 0.11292255513610379, 0.2214419739621301, 1.7611726445536462, 1.9235831619270387, 1.5585251056378888, 27.016915082931522, 65.84387102434712, 70.36720322024438, 70.53988164471042, 55.263524593845496, 60.87207071242794, 61.823033671225275, 65.39907816917666, 65.97095581793016, 65.50884962081909, 64.92258864064371, 60.744711352932846, 56.994941157679406, 53.23994636535645, 52.253799746113444, 48.98380210322719, 44.110633711661066, 46.31806911960725, 45.1478103668459, 45.96436546694848, 45.57887884878343, 46.136592818844704, 45.42038371486049, 44.846862593004786, 44.19763188208304, 46.76370528436477, 45.202445060976096, 43.598772248914166, 45.41945411312965, 46.27080455903084, 44.3209865016322, 45.20033874819356, 45.24508906948952, 45.062000674586145, 47.52664158421178, 46.73683312631423, 44.822869454660726, 46.625810438586825, 43.502572198067945, 44.971303709091686, 43.49425677330264, 45.83059695459182, 44.69284288344845, 43.27546696509085, 44.57967465923679, 44.237553765696866, 45.04937064263129, 47.57540449019402, 43.90966715351228, 45.506009055722146, 45.031225758214156, 47.26993030117404, 46.47260265965616, 46.84728707036665, 47.97608637040662, 49.9490777907833, 48.75645760566958, 48.84318121017949, 52.36564220920686, 54.99201813051778, 59.12686701743834, 47.82314531264767, 29.23985562016887, 57.56031943905739, 54.060769004206506, 59.050290584564216, 57.06978782530754, 55.157467626756244, 55.023275498420965, 52.2064410486529, 44.00184285256171, 42.53044412982079, 41.641831167282604, 39.74058774209792, 43.276137690390314, 42.656787595441266, 43.03047180175782, 41.515534770104196, 44.05052338877032, 42.860417442937056, 45.23599701543009, 46.5598597065095, 44.29375348552581, 41.32718647679975, 41.17096239520658, 43.288242124742084, 43.42658412071967, 44.422928902410696, 43.98593764151297, 44.44159153969058, 43.090727252344934, 41.774258229040335, 43.81361223036244, 43.815757766846694, 43.45267180473574, 45.67736564144012, 45.8535938109121, 44.41078132198703, 46.35955602891984, 44.599733660298014, 43.641361344245176, 44.30553628552345, 51.79367826830957, 59.828120123955514, 61.40489724374587, 54.636812210083015, 52.7501953032709, 57.835661980413626, 61.57574392134144, 58.849606437067834, 59.92117051155337, 60.161148963436005, 56.026696235902854, 54.54033759332473, 61.757961550066554, 61.57757959058208, 64.20053128273257, 65.13242760012227, 64.66045271965766, 63.348690540559836, 64.07478009500812, 68.68750310713246, 66.62674473178002, 72.99696414701401, 42.08174851632888, 0.30698503698072127, 0.04627097518213334, 0.03567287270280142, 0.03917607403690777, 5.258858482683859, 62.41723352862943, 56.553015555104906, 48.18610575891311, 37.60549260723976, 20.826983490297874, 32.026509392646055, 37.580883656778646, 50.706797338301136, 47.84906041237616, 11.863987176649033, 0.3880300607171751, 0.0875568323798718, 0.016763112695527174, 0.023582109190042944, 0.07218739258185511, 0.08473665588685582, 0.054317369020634124, 0.03798571129840228, 0.057887652843830094, 0.08403310371983437, 0.08186989358716434, 0.033891821700719096, 0.07079817640084414, 0.09082576019629356, 0.026920126645915934, 0.04544718168495644, 0.07837330742228417, 0.13596081084782077, 0.09400301793169591, 0.5344734977810613, 11.741755335561692, 83.12915232873733, 65.31505707771548, 64.56307595775974, 44.777350348811, 30.398347262413274, 61.62465587739022, 55.54385246769075, 59.322852165468284, 82.9654561319659, 26.0953502885757, 0.21657258121957704, 0.17799654554936195, 1.96315509657706, 3.816691713948404, 1.2523121627107745, 28.796849404611898, 69.13410417495236, 71.83566016535606, 74.77327223747008, 56.81731662442608, 63.7194251245068, 63.97134719356414, 67.08646220545616, 69.32676315307617, 68.00099419009301, 66.93359959510066, 63.02796225393973, 61.049114734895774, 56.175738457710516, 54.391785667788604, 51.421833653603834, 46.79322896465179, 48.10499898848995, 50.20790715371409, 46.83959922482891, 47.441145681565814, 49.3623657380381, 45.61138353040142, 47.5539138240199, 46.49900805565619, 48.49062681198121, 47.801544820108724, 46.67235328305153, 46.99334436847318, 47.75735147537724, 46.409021039162916, 47.018620121863584, 48.19599797648769, 46.021239834447066, 48.6445523846534, 48.31335136967321, 48.28188611615089, 47.94770802220991, 45.8400773232983, 46.557725937135764, 46.981502732922955, 46.91923902880761, 47.66306946354528, 47.223089356576246, 47.68539951693627, 45.67756175994874, 47.15451455885365, 48.489120621835035, 47.42152990833406, 47.02807695634904, 46.75825318982525, 48.617946947774584, 48.284506259425996, 48.84424025012601, 50.00226905269008, 51.228398046185895, 49.69543772359049, 51.645589182453776, 53.92784380143689, 58.11436599300754, 62.922297523867705, 50.57050674192367, 30.244213804121944, 57.62810191800518, 57.69750041346396, 61.87112585190804, 59.127274943936264, 56.6383663300545, 57.28235675442604, 56.38212965380762, 46.763234599944084, 44.878622024290024, 42.840774213114095, 42.94602317194785, 45.64979922386908, 44.41294254795198, 44.70326854336647, 44.33851949630245, 45.82711781224897, 45.28776053459414, 47.687850998293975, 48.155876051995065, 45.89166041343443, 44.78878013549313, 43.228410290133574, 43.703656427321896, 44.46147011172387, 46.101417003139375, 47.49691786304597, 48.14282632643177, 47.20129666789886, 43.692799306684925, 46.37052297592164, 46.77005167930357, 45.879493221159905, 46.72850985680857, 46.5613619742855, 47.51307018341557, 46.05732956240254, 47.73983417018768, 46.59458052727484, 45.002098237314534, 53.548421167558246, 61.03786537724157, 63.11269721677227, 58.86166772534771, 55.01696440481371, 60.35398837058776, 63.19187418107064, 60.90353204358009, 61.57899164384412, 61.30053081820088, 57.55658926502351, 57.07042324927546, 62.652293328315984, 63.30355974935717, 67.00356683423443, 66.4439073685677, 66.83121788886287, 66.72238780606177, 66.10710128661125, 71.14997494605281, 69.28362492592105, 73.98113389169016, 45.615866799508375, 0.4467558482241246, 0.7732428177710503, 0.4281593396538689, 0.11098812184026165, 5.296908415132954, 67.65403701413062, 65.82782853034236, 47.417827190891394, 32.60189952388887, 25.153155788298577, 36.10681772232056, 47.35584981979863, 59.07553495899324, 59.75108477377123, 17.295534380020634, 0.47193896626272513, 0.028542892391523047, 0.027743778416826844, 0.026027978953695106, 0.04667512869702713, 0.10308156586101941, 0.028995313276086124, 0.040900817576555476, 0.12982179591011617, 0.029556959146453492, 0.29880177770410815, 0.11412260888685143, 0.1476541011323852, 0.25726308084784016, 0.16384489443753997, 0.1168260565628448, 0.19263003532203937, 0.34092352875778753, 0.22446743903621552, 0.7413451229372333, 16.613889201994866, 95.67443755365188, 76.8363134322628, 73.11025788707119, 48.17260888315017, 43.76727334914669, 79.1546852357926, 67.3881866085914, 66.1704554096345, 91.11455671248898, 30.416672575858335, 0.31095303534980745, 0.38074631123773517, 3.1587974679085518, 9.633225433288082, 3.9763711585152537, 30.552969055791056, 77.2684331094065, 76.93921289136334, 77.11218941596248, 61.68083206299813, 67.33773708343506, 67.3722460962111, 70.24079307433098, 69.61556726886381, 71.33933128849154, 71.20729646375104, 65.23696268758466, 63.34134394122709, 59.775595664978034, 57.57563237221011, 54.63200338425175, 48.43675305766445, 49.991690420335345, 53.4232073445474, 49.47518487130442, 49.56895697501398, 52.17869420205393, 47.80744014247772, 49.508156314972915, 48.280262254899554, 51.1840085829458, 49.74601276459233, 48.19754731270575, 50.688377887971946, 50.595998225673554, 49.07326744448755, 49.206165190665956, 51.14874647509668, 47.72856520068261, 52.09213925946144, 51.44859990765972, 49.07278107058618, 50.9027236507785, 48.50783032755698, 48.68341915069088, 48.719297070657056, 50.989588460614605, 48.75665764654837, 46.77912804388231, 49.03672664396225, 48.571396258569536, 48.612510542715754, 51.42008035413681, 49.407661268788004, 50.28483659990373, 49.67712809962612, 52.062290022450114, 50.31900436647477, 52.30155068059122, 52.15878032868909, 57.275198428861565, 51.87505960464478, 55.49886680418446, 54.448063835020996, 62.20650026875158, 64.27679784836309, 52.579250566421024, 34.105573469592684, 59.20870727108371, 58.39401921918316, 62.75913869180987, 60.62358463964155, 57.255912134724284, 58.85506245397753, 57.55318464771394, 49.373807291830744, 47.92162033819383, 44.53579510411909, 43.45051842351114, 48.83563456996795, 46.285580127469956, 47.49309355212797, 46.0882652959516, 48.29638711867794, 46.97990240589265, 50.81266603162212, 49.54330859645721, 48.76800114108671, 47.49818086624146, 45.76419907231485, 48.27132317327684, 48.40139681293119, 47.425063963859316, 49.84661763714206, 50.72297319289177, 48.999715159016276, 46.944310818949056, 49.43391761472149, 49.667471224261874, 48.090870611129276, 52.48869088388259, 49.26713843499461, 49.45888742323845, 50.19961918553999, 49.56173589152675, 47.31655943778254, 48.18272859819474, 56.026770760936124, 64.14904232948058, 65.56004047393799, 63.969519369063846, 61.23486249677597, 65.21716256295481, 66.08077433801466, 64.68294359022572, 63.48569500830866, 63.75633855019847, 60.366492886697095, 58.95529862373107, 62.49300979798841, 65.51079119405439, 69.64924473916331, 68.48823101289811, 69.27698043084914, 67.70668306658345, 69.2194471051616, 73.59729859136766, 71.973327513664, 74.35197830200195, 48.163006920968336, 0.4887531865989009, 2.6476775782723583, 0.42807470225999433, 0.17587163215202672, 7.755196065671983, 76.46427662141862, 70.99482167151668, 65.92197325921828, 51.66521280042587, 27.47046462951168, 43.92928292674404, 58.595209352431766, 70.05360972496771, 70.79139970964002, 23.41837186967173, 0.6247895643595727, 0.12499580970935284, 0.17695579978246845, 0.09968398123859398, 0.20533109894923626, 0.2856313779709801, 0.1310207388333736, 0.11815702707897272, 0.2626609057188034, 0.17751827685823365], [0.10054477295207401, 0.021101842078590588, 0.0661275911355211, 0.06727388083574272, 0.042139964794079145, 0.021692470970353293, 0.09915835299198666, 0.007548190103167849, 0.08486469216164082, 0.18322678102600962, 16.964311792004494, 65.20001003819128, 59.92424172739829, 40.58946709479056, 10.723325648615438, 23.397904942112586, 41.55149113747382, 53.844638562971554, 61.53249979019166, 76.02279816904377, 8.383980931774262, 0.33292627562918975, 0.0377590641860039, 2.0018962241949576, 4.209606320627274, 0.5084719526911936, 39.05765602665563, 66.95736131360455, 73.03070437523627, 63.685127919720074, 56.415458033161784, 52.1633969583819, 59.725248121446185, 64.65413770368023, 64.73954731418242, 64.30074784063524, 66.43603124926167, 59.90493189903998, 58.608706228194706, 53.04858176938949, 53.566644499378825, 51.47418945066391, 50.849406873026204, 45.59355635796824, 46.22736430937245, 44.50537712343278, 48.361898545295965, 43.382033840302505, 47.26855354924356, 46.95897263865317, 46.74738430207776, 47.01005366540725, 47.6069168121584, 47.959894826335294, 47.60787779285062, 44.28154314717939, 45.353040541371996, 45.55516419872161, 43.823657420373735, 44.94445116289201, 46.791397217781316, 44.2999743646191, 43.29361184950798, 45.6413661279986, 45.106566644484, 43.57199815011794, 43.02600422213155, 45.00358873798002, 43.20314238148351, 43.52851867675782, 45.10447602118216, 44.59732140264204, 45.362434617934696, 43.12681305793024, 44.895927521490286, 43.92794539851528, 41.85107392649497, 44.64184814883817, 45.19224689852807, 44.63463098772111, 46.156804792342655, 45.51469710565383, 46.45181802011306, 50.12654542922974, 57.26989538438859, 55.71875487604449, 60.09491974307645, 46.57957746136574, 31.71690690901972, 58.6241642890438, 56.79246056464411, 58.61496240861955, 57.88431113766086, 55.79501359693466, 52.7680616994058, 57.127529036614206, 47.78210163116456, 42.41994311732631, 43.99770475202992, 43.3394722015627, 41.128702778970045, 41.99287153059437, 42.68603670981623, 43.51021297516362, 42.69290085761778, 43.64680559404435, 43.99876379197644, 40.12627440114176, 43.140604111456106, 41.54125767369425, 42.410651022388095, 42.39937420814268, 44.86473683388003, 43.786767528903106, 43.79200781545332, 44.88186190205236, 44.16549590326125, 42.12744412883636, 42.178580068772845, 44.64251102939729, 44.04292968011672, 45.30892564404396, 44.37660571067564, 43.73280748244255, 43.55166458314465, 45.0388979142712, 43.779385628238806, 44.00917768478394, 46.62828545416556, 51.87069400664299, 55.88338459691694, 56.17664060285015, 49.42416268010294, 52.098513110991455, 57.12532466457736, 61.259075287849676, 55.23832336548836, 61.32018189276419, 60.049828175575506, 51.211316124085464, 56.928033367280044, 62.550366617018184, 57.508732426551084, 59.360914845620435, 58.7441417478746, 62.23795767753356, 67.43930293667701, 65.77043248761085, 68.1142879301502, 69.0991166330153, 67.63633143517279, 3.9022952366259793, 0.823952261238329, 0.21741749959126597, 0.05428739583059665, 2.6405871587414897, 50.03924915867467, 67.11522102355957, 53.58535420510077, 43.17525825192852, 18.5151816568067, 21.497571506807883, 34.13081392165154, 49.647612264079434, 51.71305787178778, 33.50765520526517, 1.4130752846117944, 0.06300670598002692, 0.03690526685527256, 0.04280135914262745, 0.04154737663245009, 0.04931784092238353, 0.05321378106131189, 0.027622190687144478, 0.0645850807608616, 0.03317245747894049, 0.08830313225306811, 0.04863393891061987, 0.02038838630992799, 0.06661793337233606, 0.013595231876318014, 0.010275767154751286, 0.05094085947700566, 0.0797961088978956, 0.06655509117990732, 0.2287733741104603, 25.745316013213127, 75.4085942237608, 66.75235471417828, 51.68372246526903, 25.613720493931925, 34.60156894499256, 44.7677013181871, 60.21910982747232, 65.49483499219342, 82.46076476189398, 9.305625154126076, 0.18559186298760677, 0.06106874484929347, 1.8580283440889853, 1.2052982661031908, 0.8953330245229506, 42.71264606906522, 70.04240743575558, 75.92744535015476, 67.9313721195344, 58.100088565580315, 55.03468175088206, 62.26154288937969, 66.58087653498497, 68.30384823583788, 66.11737789646273, 67.32185932897752, 63.00666378390405, 62.106126816042014, 57.00215047405612, 57.12950198881088, 52.86938044332689, 53.12798623115786, 48.23649252614668, 49.20412948054653, 47.016035279920025, 49.071761254341375, 47.078985398815526, 49.522155254117905, 48.131400462119814, 47.762740811994, 50.39303125873689, 47.1802649190349, 48.45691404035015, 49.176688578821, 48.1820539505251, 48.05625569435858, 46.16879155558925, 46.30354850522934, 44.870934178752286, 47.40461272578086, 47.55380399765507, 46.15334526185067, 48.46056968935075, 47.22477989812052, 45.47235511964368, 45.45950543495917, 45.59453302814115, 46.449617570446385, 47.230432033538825, 48.41468188070482, 46.49653304007746, 46.19127850378714, 44.791670922310125, 46.94163184012137, 47.72542730454476, 44.59453259744952, 47.530889511108406, 48.389264921988214, 47.384969495957904, 48.0716117735832, 47.79598289920438, 48.54345721583213, 52.16086702962076, 60.43594237296813, 57.84209466749623, 63.18360190237723, 50.28509939870527, 33.080866029185636, 59.75830977962863, 57.93124229677262, 58.21224089591735, 59.47189830964612, 58.97873870788082, 56.56119369691419, 57.855238529943655, 50.3617032881706, 44.557905504780436, 46.62321775190292, 46.01930610595211, 44.57927457747921, 44.418367185900294, 45.673808051693825, 45.37777500767862, 44.03385331553798, 44.85222839540051, 46.09346635880009, 41.98938846588135, 44.36051222585863, 44.84113201018303, 44.00620060582315, 44.96642820296749, 48.55684034286007, 45.36232871394004, 45.948876027138006, 47.07600439748457, 47.79473558548958, 44.099474568520826, 46.00684865828484, 45.66333532333375, 45.7696472444842, 46.85442578408026, 45.77827253649312, 46.241861389529326, 47.480514510985344, 47.267874979203754, 45.97370070795859, 46.28997710443313, 47.87546973074637, 53.66497047485844, 58.82270682242609, 58.49351013860395, 54.98556975395449, 54.662911661209606, 58.6841098723873, 62.62264413218345, 59.20510261289535, 63.03806235713344, 60.45478936164611, 54.29300077499882, 58.285271506155695, 61.570268292580884, 57.42995554401029, 60.98408968217912, 61.50793006343227, 63.5903085431745, 68.96081386073944, 67.27494778171663, 69.51249522547569, 71.48304693160519, 71.37459339634066, 4.799735738385109, 0.9997269679461757, 0.32845434462351186, 0.04698006999528697, 1.9646599384084826, 54.44403163848385, 72.15358395730296, 57.958036007419715, 35.82215170706473, 21.902862171972952, 28.051801073935728, 40.78445596079673, 57.43361511538106, 61.50978926689395, 45.53803913054928, 2.1899149158308586, 0.0837756751946384, 0.07738179046540491, 0.023639933506567633, 0.03649930920331709, 0.03552067401488462, 0.07934328964761189, 0.003215569074288191, 0.0191660757897602, 0.021653450281930067, 0.3732350642883009, 0.14846184891798805, 0.20702838206723814, 0.2574408438897902, 0.06975723911196956, 0.12151787012454965, 0.1901677521246095, 0.12067201712559308, 0.21740029325648663, 0.2772332157098478, 33.71711369483702, 86.7205842848747, 75.22005373431791, 61.35430651326334, 21.768864200961207, 34.300648627742646, 54.81508785678495, 69.33166611579158, 74.18553644610991, 88.23068111173569, 11.85483922881465, 0.4257595539093018, 0.13665929917366276, 4.776365276305906, 13.150185308148785, 1.443103602336299, 48.728671535368896, 72.24284925768453, 78.51609199277817, 70.70913191764586, 61.99678290274836, 57.71728092624296, 64.77004374227216, 71.13080240065052, 72.0280759565292, 69.14870323673372, 71.25868735774871, 66.01038348290228, 64.91523811894079, 59.492737862371634, 60.52771799025997, 57.154220765636815, 56.71477017864105, 50.62441971994216, 52.286320117212114, 49.3543601805164, 53.1770315477925, 48.04668511113813, 53.97117814710064, 51.20687992342057, 51.40764644069057, 52.07971711312571, 50.082508979305146, 50.92237080297163, 51.482799053192146, 48.771911744148504, 51.49921809473346, 48.65373465322679, 48.26633784078783, 47.627415118678925, 51.72493873103973, 48.874740600585945, 49.26395347041469, 51.14095664793446, 50.490847326094105, 49.018401330517186, 48.986594830789876, 47.98449593205606, 47.62501462813347, 48.21861044053109, 50.13017754400931, 49.09155745660105, 48.85206145624961, 46.35085621187764, 49.12700783821845, 49.18184257322743, 47.10715978376327, 49.25402987387873, 51.62664805689166, 48.63783336454823, 51.9212023673519, 49.61349941069081, 51.44114740433232, 56.128332691807906, 62.27784033744567, 59.677203009205485, 65.08210359081146, 52.7383928914224, 36.60995583380423, 62.156525350386104, 61.377809355335856, 63.59101849217569, 63.42562783148981, 60.71843931751867, 59.49803306210426, 60.68285949768559, 52.25102270803144, 48.428665130369126, 49.30667984870173, 48.68420362472535, 46.55784360824093, 44.516602946865945, 48.519299337940836, 47.60734827287736, 47.5578950297448, 47.60245707727248, 49.304773576797984, 44.2089714542512, 47.75106783836119, 47.34272556920206, 46.76648624481694, 48.16533680885069, 49.90031880717124, 47.18110822862195, 48.23746919631959, 50.83381152922108, 50.286056457027314, 46.36726348630844, 48.63757056574668, 47.14574806151852, 49.494271124562914, 49.4598013354886, 50.109377214985514, 48.69297796680082, 48.77921127503919, 48.62958069770567, 49.43089346731863, 46.474505009189734, 51.39800133243684, 57.42300902643512, 60.69591706798923, 62.252227260220444, 58.62173241953696, 60.597544024067545, 62.059399620179214, 65.5021462901946, 62.606989952825735, 62.07497535213348, 60.6752500995513, 55.5317598004495, 59.79145380758471, 60.81105824439757, 61.16755070224885, 62.20192678513066, 64.54543705909484, 67.46472774013397, 72.88996973345357, 70.18115735823109, 74.4230830284857, 74.01741581578409, 76.38386803288614, 4.682202896764202, 2.8129846434439383, 1.0896806442929854, 0.1327737931522631, 3.2019646225437044, 58.4919451129052, 77.58165005714663, 68.80180881869408, 58.01710297984462, 25.210185089418967, 34.51677514660743, 52.84090403587588, 68.63581411300167, 71.94341551872992, 55.85060142701673, 2.7325968925030004, 0.20538746769870483, 0.18990591859384892, 0.12726316183444955, 0.18338667889756544, 0.15590306010938462, 0.20667475588139028, 0.12461990568666689, 0.11908400112823134, 0.10377955622971059], [0.037204600389926665, 0.060818513720146114, 0.020427723009619984, 0.03667231483925735, 0.09291032374265695, 0.04587603770496865, 0.03279504809348333, 0.05286738674546923, 0.0708402805931626, 0.0958955079136837, 38.26958125637424, 70.48842014804964, 53.180165521560184, 40.80746066185736, 21.828260652480587, 27.034675575071766, 36.13226213762837, 56.308020391771876, 67.21624558971774, 62.06261596372051, 1.4961895731187638, 0.014075437812284838, 0.5634449818922628, 0.9531519477886539, 3.4959872066974644, 6.331487480671176, 76.03966436078473, 69.27682353604224, 70.95333083983391, 65.72279922423824, 55.167630487872714, 49.08055913063788, 58.639445843235144, 59.00000579895512, 60.86724227474582, 63.65739284023162, 60.887928855034616, 58.28836625622165, 55.950606176930094, 54.2390093495769, 52.493138851657996, 51.04407802704842, 50.421189954203946, 46.531681399191584, 46.50041226417788, 46.187277686211374, 46.80759660659298, 45.3498948004938, 45.04729570881013, 44.74142143803258, 46.41950945700369, 44.901191342261534, 44.40354847138928, 46.52454660784814, 45.74172781359765, 45.84926743661204, 42.995131246505245, 42.58297251116845, 44.35479733251756, 45.045432582978286, 44.25420030470818, 44.089296017923665, 45.09110466126473, 44.91124829938335, 43.85961771011353, 42.8237432818259, 43.46590588169713, 43.8090975822941, 45.377947591966205, 44.336605379658366, 43.936633448446955, 45.837453257653024, 44.63400340849354, 45.350259580919825, 44.56265549505911, 42.39282777232509, 43.77164286951865, 43.81597741957634, 47.28696123246224, 46.15166256504674, 46.12222125453334, 44.1161681759742, 46.0913678907579, 51.32399405202558, 56.12427696104973, 55.69635029762022, 59.29951798531317, 48.439306520646625, 39.067144240102465, 60.87504386901856, 53.675596175655244, 57.67381321999335, 56.04503331645843, 54.52504427202287, 56.27051861055436, 58.033839733369895, 47.6244301949778, 41.08516054768717, 41.8662299648408, 42.83632624533869, 42.45737037351055, 40.62891437161354, 41.36644940222464, 41.93993914511896, 42.90154741656396, 42.14291787916615, 42.04200706174297, 41.835537418242424, 41.38743016027635, 41.120948253139375, 41.43492614069293, 42.0691773199266, 42.97596262347314, 42.275337096183534, 44.02917000555223, 45.25749552634455, 43.81059200532975, 44.95890509697699, 44.18276217675979, 44.394228919859856, 42.756180455607755, 43.17529747563024, 42.93844907514511, 44.00471402752785, 44.80508150592927, 45.0606043108048, 44.66110306401407, 43.36068045708441, 45.26994120690131, 46.1302895699778, 50.933690763288936, 55.44513033282373, 50.96495989830264, 54.990366812675234, 54.5547366142273, 59.78896310252529, 58.58785883072884, 55.07698451319049, 59.464402660246826, 59.36739852351528, 50.284020746907885, 55.69420868350614, 60.92940399723669, 60.29896143944033, 64.77608419233754, 64.99623114062895, 67.53513428472704, 64.24796450522639, 69.61067215088876, 63.21583201808315, 79.78467279864897, 23.0238716448507, 0.8095797776214538, 0.8476026212015461, 0.15130849374878794, 0.14086803301207482, 17.563424418049475, 71.76061737921931, 51.7133245929595, 52.04751837638117, 32.55234233794674, 32.25498941636855, 35.208669477893466, 39.53780120418918, 52.61437931368428, 45.91661845484088, 6.441226572759691, 0.18979056107421077, 0.08866029010424692, 0.01058113841985863, 0.04752941632403001, 0.04476701435182364, 0.03938753345620729, 0.0698712712994987, 0.012973996814370397, 0.07237264030282536, 0.08932242755808177, 0.07740624399194795, 0.010963480453938248, 0.0374456461248619, 0.11906489489539979, 0.045943085720101674, 0.05111321010777066, 0.03347231195338311, 0.011853362441123014, 0.17777424215549426, 47.47180292683263, 80.55733265415316, 60.1622982178965, 44.786179604068884, 20.510208952811457, 23.856498656734345, 42.00473277799545, 63.2439201108871, 73.12757122901179, 66.96966971120527, 1.5540184248839657, 0.06822712403992492, 0.6013372840900576, 1.5101537012284802, 2.291489349257562, 7.953706729796625, 78.52341113551971, 71.35276932870188, 73.85178196814753, 67.28622851833221, 56.89352043213383, 53.686131661938084, 61.07813635180074, 62.17771791642713, 63.64170335954236, 63.74030390093404, 65.2063838897213, 62.20649242401124, 58.079998185557706, 55.93324576654742, 56.773888141878196, 52.23699631229524, 51.50275999499906, 49.208342106111594, 50.037758658009196, 49.05098445953862, 48.92607265903104, 47.59940155090825, 47.153004446337306, 47.526598438139885, 48.39142614795316, 47.70816887578657, 48.378137157809356, 49.67238595408779, 48.39952191998882, 48.83879992269701, 46.33413907020323, 45.19434536657026, 47.66274390682098, 46.46896270013625, 47.17225151677286, 46.763983772647, 48.09205516692131, 45.86148954206898, 46.46010598828716, 44.39873180081768, 45.537278190735854, 46.590618933400805, 47.52749666090935, 45.54931594479469, 47.72489386220133, 47.69139682092975, 46.619126719813195, 46.021561468801195, 47.32558873391921, 44.10263207650954, 46.810173603796194, 47.48322486877442, 47.345373169068374, 45.587696336930804, 48.67808472725653, 47.771232743417066, 48.20652954040035, 53.986855860679384, 58.48286482595629, 58.68051305893929, 61.77094459533692, 50.62137203831827, 40.58703522528372, 63.22054670703027, 55.92731122047671, 59.825103821293006, 58.67857933044434, 55.12099742889405, 58.52153547348515, 58.46698314912858, 50.176449744932114, 43.97495500503048, 45.58877891109836, 45.338853328458725, 45.78013958469514, 43.761099538495465, 43.099156425845244, 43.123314303736535, 44.935755268219985, 44.84236755678731, 45.569190594457815, 44.56868417801396, 45.06079258457307, 43.413518705675685, 44.21147784879131, 45.20624976004324, 46.80995395106655, 45.41901873004052, 46.202182692866174, 47.188203796263664, 46.61787156135806, 47.194475666169204, 46.02221650461997, 45.33725300142842, 45.29477373246224, 44.678965537778794, 47.42205942830732, 45.487397409254505, 47.119009264053844, 47.39632083523659, 45.4149983006139, 45.61726316328972, 47.679402212942804, 49.006187069800596, 53.58351853586013, 57.71861060973137, 54.65727521527199, 57.637252807617195, 56.793111678092714, 63.103397277093705, 62.509934825281945, 55.756131141416496, 60.3983425324963, 59.78372281597507, 50.802463946803925, 55.173619947125836, 61.47512728168119, 60.252767685920965, 65.9370743843817, 66.34154919655093, 71.02228610746323, 65.93773334257065, 73.17431803672545, 63.91004054777084, 83.14656765230241, 26.711564448571977, 0.4992963950480185, 0.8947221766556464, 0.5373020169715728, 0.163562698289752, 18.235702976103752, 77.90593593351304, 58.17445670404742, 47.48896721870669, 32.52827075219924, 42.07844980301396, 40.798439210461034, 49.53761723733718, 60.56255255976031, 58.26538508938205, 8.829918138442501, 0.18730039227633707, 0.04356026882305742, 0.042447269473585396, 0.02854764788231302, 0.026625362825730158, 0.049237899647484866, 0.01626164111639223, 0.05012066659307288, 0.071166442526925, 0.13384309867697378, 0.2014627532973405, 0.07924366757393846, 0.15966415345188112, 0.2562235914651425, 0.14191411075092134, 0.11190439364121807, 0.1683479592564606, 0.10784372927681093, 0.36136866877636603, 58.977467859944994, 90.74986257860738, 71.26534754230131, 58.78245938208796, 32.91301996477189, 37.1222173783087, 51.00569371254214, 71.30566950767272, 78.85000336554744, 73.9802788149926, 2.196879574368077, 0.1329329709011701, 1.432363049637887, 7.732558106222461, 8.891520923183812, 8.57102111462624, 81.84736098012617, 73.48324391149706, 78.51442106308477, 70.57366109663441, 61.29889126746886, 54.505330439536806, 64.58581001527848, 64.24959621121808, 65.79102100864534, 68.60511764403313, 67.04109607204315, 63.26520289144209, 61.25479990436185, 60.56446667640441, 59.03104743649883, 55.728929504271484, 54.88092876249745, 52.179133507513235, 52.57974478506273, 51.03872399176321, 51.89514606229721, 49.93591823885518, 50.38140927591632, 49.60825520177042, 51.41683263163413, 50.79254035026797, 49.682678253419944, 52.52309791503414, 50.26666033652521, 52.08995057690529, 48.263003826141365, 45.216247881612475, 49.92126034152124, 48.20017137835103, 49.27192372660483, 48.49778121517551, 49.36899454362931, 49.22303922714726, 48.03289405761227, 47.81936414780156, 48.04975632698306, 47.25071853207004, 51.02280701360395, 49.87387418746949, 49.5672821229504, 50.9991668885754, 51.84875619026923, 49.016581350757235, 48.744863079440215, 47.046982780579604, 49.54571300937284, 50.1332958282963, 50.334764449827134, 50.600383435526204, 50.82327604293824, 48.13950015652565, 50.64464346055062, 55.84668297921458, 60.69627008130474, 61.167672295724195, 62.80068835904522, 56.238853316153254, 45.160695352861964, 63.4287186591856, 60.688578313396825, 64.075391984755, 62.06879761911208, 57.46010680352488, 61.52537676595873, 63.32723909808744, 53.480560241207, 46.125104196609996, 46.3761241205277, 47.69506423704086, 47.954936950437485, 44.975602626800544, 46.008119506220666, 47.200033664703376, 46.6523374280622, 46.73303627198743, 47.95414070929251, 46.8600308510565, 47.38563629888719, 47.46732358009585, 47.96849658412319, 47.19423640158869, 48.01217217599192, 45.94047038785873, 49.82111830865183, 50.47529512836088, 49.72185096433086, 50.731845594221554, 49.63982635928739, 47.90508362554735, 47.56592412148753, 47.184367718235144, 48.92213459937803, 48.21493125730946, 49.720023139830566, 49.36152635082122, 48.608976487190496, 48.43969091292351, 50.125902160521484, 49.18478435085666, 56.64131203005391, 61.716098093217425, 60.05267189395044, 63.312428228316776, 59.3449664884998, 64.2373505715401, 63.18662604978008, 60.139411187941036, 60.46035912729079, 59.38517078276604, 53.54380061549526, 57.90966141608454, 60.04581166851906, 61.11813276044784, 67.01959363875851, 69.01374232384467, 74.48333063433248, 68.27441477006482, 75.63243604475453, 66.89440727233887, 85.64547046538323, 27.62036781157217, 1.6278386572676322, 3.312849291870671, 0.48549421792549474, 0.3901802243724946, 25.380812114284886, 86.98632486404912, 66.88393454397878, 67.64299946446573, 43.293125475606615, 46.50387963941021, 50.23844280550557, 62.09988240272769, 71.55953314996535, 70.36601866445234, 11.469344765909257, 0.4343253055647497, 0.21051486353239707, 0.2161860438965021, 0.20446456157632414, 0.17161366950360038, 0.16242329571996966, 0.12939617278114443, 0.12967156606816477, 0.20232288617520564], [0.039444449958541704, 0.05829102111860149, 0.049289652717209635, 0.06863560978203051, 0.06570514727143512, 0.030905681835006804, 0.0966099308683507, 0.017749230647760055, 0.0851515461240084, 0.24356791088657997, 39.90504487868279, 68.85465883439588, 50.999288482050744, 39.976294732862904, 27.81573518629997, 44.64789644364388, 34.30590460377355, 55.873139366026855, 73.7531892714962, 44.3377624788592, 0.17093802591966045, 0.037501413495309895, 0.8112302987325577, 0.2803160148041864, 0.404728050193479, 24.370621365885583, 79.412549695661, 67.07274959933373, 68.84831243945708, 59.57865738099622, 57.66125379070159, 48.03622022751839, 52.03490011153683, 53.761864785225164, 57.46570402576078, 58.994651763669914, 58.79770171257758, 56.50756705191828, 54.22975255597023, 52.43973970413209, 52.7168002436238, 49.86804554539342, 48.54656765537877, 45.99137098558488, 45.92911512620988, 44.87111853015038, 47.39882722977669, 45.62517458392728, 46.979416031991285, 43.993805916078635, 46.97140655209942, 44.31923320216518, 46.27958674584666, 44.94195261309224, 44.87486439366495, 45.31044752367082, 46.02910026427239, 45.6048684735452, 45.44618506585398, 43.612159298312285, 43.9755041368546, 43.05166829016901, 43.58738560830393, 43.10378874501875, 43.37079232738864, 43.12312995233844, 41.40633598450692, 43.75976985500705, 45.49447728741554, 43.60149437381376, 44.23768320391255, 44.28931728486092, 43.36281030408798, 44.40416820587651, 45.33856307306598, 43.69899272918702, 44.08417340247862, 43.74575522638137, 44.93592000776722, 44.49152331198416, 42.64624426441808, 43.643251926668235, 45.87839495751166, 54.3163114209329, 58.565850411691976, 56.710314366125296, 56.71376212950676, 49.63009888126005, 38.876705323496175, 57.65878661986321, 53.236875149511526, 50.4563069343567, 51.764523290818744, 56.732330629902506, 55.34683965867566, 53.19499600318171, 44.77762491472306, 42.580246463898696, 43.67104191933909, 42.00647431035196, 41.86544549080634, 43.809485896941155, 41.996291837384625, 43.08987609801754, 41.74029834808842, 42.90040208447365, 42.07824191739483, 42.6596313138162, 40.48372783968526, 41.977248730198035, 41.58391344931818, 42.214760011242284, 44.188743791272564, 43.16551900679066, 42.84857188501666, 44.191108980486476, 42.372392223727324, 41.5726327127026, 41.59264856769193, 42.246954825616655, 44.524035838342485, 44.52853087455996, 41.896722470560384, 42.91703293400426, 44.54824470704602, 45.85727691650391, 44.31451459084788, 43.43981035294072, 45.01173157845774, 46.024205146297334, 47.648952853295114, 54.41978746844877, 53.000991652088786, 50.88604965517598, 56.26813380948959, 59.363888002211056, 60.51506050171391, 58.42689260359734, 54.20100942734749, 56.86984892814391, 51.59530047447451, 49.29259069504277, 54.5884140845268, 56.663234156946984, 55.90574210689914, 56.151580579819225, 66.52973667267831, 60.93186332333473, 62.72409231432023, 65.1109016326166, 74.1076381744877, 56.98108342386062, 0.13983021370105206, 0.4800599885563697, 0.4444711288857845, 0.034397715522396954, 6.798440746722683, 64.47490499865624, 60.09052668848346, 50.642380252961196, 39.62020627913937, 15.724394686760442, 21.744804382324222, 41.625161094050256, 50.042893040564756, 53.58799003785657, 16.281494805889746, 0.24037678695974812, 0.10997386739378977, 0.06201003325141727, 0.0961197954752753, 0.0361806319485749, 0.08170164535723387, 0.052169779420740185, 0.022901667980477217, 0.05545185330594259, 0.0448279834592775, 0.02801871205109262, 0.026532419123536637, 0.01730055976358633, 0.042270755154951926, 0.06605309674576407, 0.10294473489686366, 0.03997383586641762, 0.11010449304575883, 0.8312875837568314, 51.23500331755608, 74.72528596078196, 60.07279757530459, 49.17949307349421, 36.90775786676715, 43.07347274595692, 38.18204179886849, 64.26520332213371, 80.82896463332638, 47.685226932648696, 0.11580569639561639, 0.033641395219151056, 1.1080183377189021, 0.8139841090286932, 0.7982695619425466, 27.920613481152444, 80.60546013616747, 70.06857748954528, 74.44460899599137, 64.52395031529089, 59.40159374667753, 50.71830949475689, 54.779602173836004, 55.51158312828311, 61.01516269868421, 60.90893314730737, 61.11289247389763, 59.80653139852709, 58.514290855776885, 55.216409083335634, 55.886067498114805, 51.582211525209495, 51.27097929677656, 48.8291665815538, 48.42988498749272, 46.963922669810636, 50.34248367432625, 48.809939122969105, 48.93554126062701, 45.191587940339126, 48.10263379927605, 47.091693878173835, 48.57224741289693, 47.792523368712395, 46.54701786656534, 46.414300549414854, 47.52704558833953, 47.17245155765165, 48.59561297201341, 44.534265379751886, 46.214746044528106, 46.62489652633668, 47.04519417978103, 47.20261066190658, 46.27564476382348, 45.44378065293836, 43.98247811102098, 45.62771627979894, 47.23063991915795, 46.68486956627139, 47.24784735710391, 45.676820431986165, 46.94920985929428, 47.255539125011815, 46.54314648720526, 46.5262528388731, 47.1715376454015, 46.80295252030896, 47.31559061234998, 47.024378161276545, 46.9521830158849, 45.80636455166725, 47.89425396150159, 57.62274788271997, 60.17000959765527, 58.41525100892591, 59.26447160782353, 52.493370271498165, 42.51853189160747, 58.63273074550014, 55.986495864006784, 52.8738715571742, 52.06097602844239, 56.97237576207807, 57.804836073229396, 54.079663061326556, 47.12880342237411, 44.66726118518461, 44.64789644364388, 42.66048639051376, 43.63408142520536, 45.700868483512636, 45.22803852635045, 43.90271279119676, 44.27683630297261, 45.58084003386959, 45.85384092023296, 45.4856990229699, 44.40466242451822, 42.73718441686323, 43.309371932860344, 45.00347498924502, 44.33232607380037, 43.49712794826877, 45.6069943981786, 45.9101269322057, 44.761527507535874, 45.46676181977796, 45.582259931871974, 45.43957194974346, 47.19154565565048, 46.47141025912377, 45.1877793189018, 44.21501190431657, 47.38522052764893, 46.748235456405155, 45.421415298215805, 46.27004754158759, 47.46429551032282, 49.09236154248638, 50.599579349640884, 55.80132076817175, 57.21617852487872, 54.54839021928849, 58.19276632801179, 62.249265870740345, 61.513660646254024, 61.118925079222656, 56.286878816543094, 60.073362396609404, 53.11663881424935, 50.260062909895375, 55.697605456075365, 55.77972812037314, 55.30594502725909, 57.8477232686935, 68.18692238100114, 63.95708153324743, 66.8390469397268, 66.26328222213253, 75.66161847883656, 60.62033691713887, 0.10771865010141365, 1.160925105214119, 1.04471716669298, 0.0545880432060409, 7.586335087976149, 67.79750162555327, 69.44539916130805, 52.05753610980127, 37.74585462385608, 25.373702818347564, 29.3318469678202, 53.00838139749343, 57.656617549157914, 65.26181482499646, 21.61384624819602, 0.16168809646079618, 0.029629406166232886, 0.027678287475399917, 0.04705821862444282, 0.022821933549318104, 0.0770381234225727, 0.061605864414764996, 0.004922576960281379, 0.026751491541583693, 0.0945163811106355, 0.14676119501311935, 0.13212661739558945, 0.12292401684868721, 0.20545699783871252, 0.2086527336148485, 0.32456730642626364, 0.1881767202529215, 0.33507913591400273, 2.044273388962592, 66.27270375528644, 85.55112961799868, 70.99196618603122, 54.5741327347294, 40.03613441221176, 61.225739063755164, 49.846178331682765, 70.43771959120228, 87.6660402359501, 53.54133344465687, 0.24083719048048222, 0.15324255932242642, 2.116946818367128, 5.008238150227455, 3.4907179926672294, 29.071334908085486, 85.64001052610337, 73.63240380440989, 76.16408194265058, 66.16705863706528, 62.24004045609505, 53.44054029833887, 58.85827095277848, 59.84856351729363, 65.4953605897965, 64.59563555256014, 63.42012474613806, 62.8432382306745, 61.40162206465199, 57.59815069936938, 59.13475882622504, 56.775260971438506, 53.898924166156405, 50.151754502327215, 50.3430720298521, 50.19124100285192, 51.78537853302495, 50.66417294163858, 52.663883547629084, 47.30427065203267, 50.74073760740219, 49.702784322923236, 51.038186627049605, 50.12828303921608, 48.7651260437504, 47.89231631063646, 49.92250765523603, 50.22161583746634, 51.91637785203996, 46.53771008214643, 48.17634690192438, 49.23293536709201, 48.3683116205277, 49.006351809347834, 49.41979315973098, 46.72683108237482, 46.53539588374477, 48.34505981014621, 51.93054937547254, 47.9671198321927, 48.43273655060799, 47.59702067221365, 49.11255782650363, 50.6743005014235, 51.02826303051364, 50.10530579474665, 48.853242089671475, 48.46687293821766, 50.03413438796998, 48.996204637712054, 46.99541930229434, 47.952956153500466, 49.859498700787945, 59.8980716736086, 62.001689787833925, 61.29935802951936, 61.551240874874985, 53.910444167352495, 45.74881553649903, 61.944709516340694, 58.768432986351755, 56.513599657243304, 56.310338512543716, 59.108580927695, 61.010232279377604, 57.99420418277864, 50.61231920796056, 46.03514071433775, 48.309464300832445, 47.81461415752288, 47.228086456175774, 48.08418296998548, 47.61282390163791, 46.29213048565773, 46.741943974648755, 48.67418589130525, 47.231291032606556, 48.948904775804095, 45.35326803884199, 45.66480228977819, 46.23711139925065, 47.755256929705226, 46.09176012777513, 45.5598553534477, 48.20357207329043, 48.50800683421474, 47.34900136147776, 46.5647626692249, 46.65286302566529, 46.39145666553129, 50.49054922596101, 49.552820344125074, 46.70209269369803, 45.72994109122984, 49.22216453859883, 48.32411043105587, 47.36243940168812, 49.362373582778446, 49.92923452008156, 52.139505801662324, 53.73249407737486, 59.97817823963781, 60.15486532641996, 59.36896354921403, 62.99352776619696, 64.61685949756254, 63.81204012901553, 64.55180698825468, 59.6073220622155, 62.63267363271406, 53.55948617381435, 53.92144249331567, 59.06930231278943, 57.242556464287546, 55.5354860521132, 60.67388119236116, 70.6381134833059, 67.3815107345581, 66.92294643771264, 71.28433965867566, 79.24871229356336, 62.696290554538855, 0.1779862646494181, 4.669285060897951, 1.3794948929740538, 0.20144842745315647, 9.556544077011848, 75.23859870049262, 72.7764641854071, 68.30407573330787, 53.52284731403474, 24.34663018872661, 37.30815341395717, 62.43380946497764, 68.3876379074589, 76.38871608241912, 26.838000089891498, 0.4451455620508041, 0.16818066097555623, 0.12855064153911608, 0.17864335358383196, 0.06145822778043728, 0.2046477178772611, 0.13635476390200277, 0.13810611750570037, 0.15044901970653765], [0.024357070327706398, 0.02144177061235232, 0.02986650654835807, 0.03006756632408548, 0.021122838633375305, 0.019853157066409628, 0.056286521421204654, 0.012727046456758775, 0.01661071290953025, 3.5676557738934798, 62.93594344969719, 59.99820193936748, 50.90584193506549, 16.941640492408506, 15.73178541275763, 29.575079025760775, 44.46494140932637, 59.44192747915945, 75.65357761998331, 22.397023939317275, 0.13171803206205368, 0.10773672977642668, 0.3308390537577291, 0.7545580558719174, 0.8205769391309831, 48.955109965416696, 73.86078773006317, 69.40057431497883, 66.3987922668457, 64.75088688635057, 57.06311195127426, 51.698721608807965, 48.318521053560325, 49.35332859716108, 49.230095571087254, 51.28597451794533, 52.63884313644902, 52.20540554292741, 49.87699639412665, 49.06250053836454, 48.68976162325952, 47.83403381224602, 45.15961670106457, 47.945166326338246, 44.606562506768014, 45.572167673418605, 42.641560954432336, 46.06094598770142, 46.21020393986856, 44.08669156412925, 45.5307827457305, 46.31299749497445, 44.593010717822665, 47.464950546141594, 46.224787312169234, 45.987636889180834, 43.18940624114006, 43.839864653925744, 45.93850920277257, 43.80093905233568, 43.832055214912664, 43.60252595716908, 43.78161353449668, 43.383747916067804, 43.38908233950215, 43.759295248216205, 43.02411363970849, 43.37176899756155, 44.5065224555231, 41.97236145696333, 42.804653106197236, 43.11079017577633, 44.091253280639656, 44.34981200002855, 44.864070030950735, 44.51088413115471, 42.67101010968609, 43.361868935246626, 42.96823555423368, 44.45258594328358, 44.113398982632546, 43.75695359322333, 44.971433147307366, 52.40356760640299, 56.97676097193072, 56.57540836641866, 56.83601064066733, 54.88676132694368, 41.922519899183705, 56.05629444122315, 54.18988558553881, 48.59021971302648, 42.415518683771936, 46.253561819753344, 44.68190731540803, 42.61667743805916, 43.94018711582307, 43.15156713608773, 43.44715302990329, 42.27887507407896, 41.82035392330539, 42.303397732396284, 41.7765018247789, 42.452565470049464, 43.30292355629706, 42.87758173481111, 41.36369589836367, 43.47804169501028, 40.893242897525916, 42.57762239825341, 43.14169845273418, 42.268367044387325, 41.352674038179465, 44.691799532982614, 43.923901434867616, 43.29050925470168, 44.79281625440044, 42.13741087144421, 41.59888121389574, 44.690548296897646, 43.870314013573434, 42.85700890325731, 43.29079558772426, 44.96211751814812, 44.15779236824282, 43.85042759679979, 44.00964444683444, 44.09206913363549, 44.59206150424096, 45.81603711651218, 50.86174664958831, 56.74760433935351, 54.47700308215234, 50.03883730980658, 51.84461416736726, 61.01316228989632, 59.59794367513349, 61.199831808767016, 59.68175295860537, 58.970333068601555, 56.49277187162831, 58.306589588042236, 53.604871919078214, 54.72830149435229, 55.68723863170993, 59.63739879669682, 61.91546824670608, 63.28806638717652, 59.715834433032626, 68.33289730933406, 65.22173212420556, 78.66648350992511, 7.254274583631947, 1.5766443720748349, 1.5415332754773479, 0.11408184534840046, 1.350242591673328, 46.96602898259317, 67.01191363796111, 52.76099751072546, 43.55266086516842, 20.36629326881901, 15.194181434569822, 25.699230124873502, 49.996456100094704, 53.72786568057153, 34.56559688814225, 0.7145071630516361, 0.10148233433644618, 0.06742548963595783, 0.05231198449168475, 0.13747624001435696, 0.025224038625075936, 0.02884766131999993, 0.0306740723880789, 0.06440672783120986, 0.03262685732014718, 0.05753900239905042, 0.11336313996223674, 0.04570980428627903, 0.01872284796028849, 0.05704062389990976, 0.017908498411998153, 0.08835128087910914, 0.2269996660611322, 5.86898071150626, 73.4894020326676, 67.54854094597601, 61.953766269068566, 25.488143851680142, 16.56421826731774, 28.886863877696378, 50.101387346944506, 66.2990620828444, 80.70089140245992, 25.813755489164784, 0.20268008233078066, 0.13941442714102809, 1.2261928545851861, 0.973900979565036, 1.6861958032654178, 51.60923665569675, 77.52861961241692, 70.39826054726878, 69.66349863236951, 64.57967935069915, 59.35307402764598, 54.415920011458866, 51.51982230524863, 51.01471908630864, 51.17402615085725, 54.29061597393405, 55.706964231306515, 54.7714554109881, 51.77618841971121, 52.13966661883939, 52.06934244401994, 50.495801279621745, 48.13832736784413, 50.26001584145331, 48.411175281770774, 47.358940647494414, 44.27110179778069, 48.754045348013605, 47.827303025030325, 46.912147383536066, 46.966025060223, 47.505649059049546, 45.91700676948794, 48.06195882058913, 47.71772376952633, 47.743831065393266, 45.394013620192005, 46.380442650087424, 48.394720938897905, 46.539577130348455, 44.383728734908566, 45.891899678014944, 45.14576681198613, 46.27672733799104, 44.443917505202755, 46.42227472797517, 46.25864521149666, 44.72826973084481, 46.5284062200977, 45.098635611995576, 44.01031517213391, 45.846062860181256, 46.14986219713765, 46.017458669600956, 45.22916032421974, 44.9701113085593, 44.98327478285759, 44.501627337548044, 44.84874533068749, 47.36843670568159, 45.805988004130704, 46.07559211792485, 46.19524009766118, 54.877135830540816, 59.18977791263212, 58.76345942097326, 59.2058047171562, 56.60690499890236, 44.731764562668346, 58.57034937027962, 57.883993425676906, 50.630526850300456, 45.56277751922608, 48.48108760772213, 46.38253719575944, 44.29287095223704, 45.078345191094186, 44.664362553627264, 45.81078506285145, 45.660828928793634, 45.79720581731489, 43.59074315717144, 44.26487699631722, 42.483089354730424, 44.73981326626193, 44.92041880084623, 43.78730881598688, 44.999121158353745, 43.64582500150127, 43.97637882540303, 45.03276724969187, 44.265759529605994, 45.718448546624955, 47.23762566043485, 46.61045435936221, 47.172192681220274, 46.46191027856643, 44.41023219016291, 45.51758789247083, 46.36743214822585, 46.458101657129106, 44.496041882422666, 44.64290326641452, 45.18337841956846, 46.21293390950849, 46.27424840004214, 46.01105736147973, 44.15824344081264, 47.63222002214002, 46.834296180355935, 52.915774237725046, 59.80231092822168, 58.26240016568092, 55.897744394117794, 54.634176377327215, 63.09906698042347, 61.71970667377595, 63.07039053209367, 61.56119585037232, 61.17749783300585, 57.42327182523666, 57.64813738484537, 54.21661261589297, 56.45392079507151, 58.719336678904874, 62.13719591017693, 63.33022794415874, 65.00423669815063, 61.253835001299464, 71.03553587390532, 68.45680498307752, 82.44515372860818, 8.738740682601929, 1.4575300798300774, 3.4891269812660837, 0.013563730340871601, 1.1187533745842597, 50.23261024105934, 73.96423632098784, 56.57415320796352, 40.295289331866854, 23.890868425369266, 23.80975381020577, 34.086283253085234, 57.719599047014796, 61.993519490764996, 44.202825100191184, 1.3249501682096914, 0.08089241902193717, 0.11311433758706817, 0.03601211558787092, 0.018279798246259173, 0.02836598545282839, 0.06399763304920447, 0.043089998089858604, 0.13755965166755263, 0.1446560007189551, 0.11284666646632457, 0.14838124114659526, 0.08856135750970534, 0.09750100603747754, 0.15625944421175988, 0.2494972628811675, 0.3025692448981347, 0.32203881791041744, 9.702348382242265, 85.34606810539, 76.62495259315737, 73.21158839810279, 29.471901078378004, 24.75618054789882, 40.56223407868416, 60.9385548868487, 72.0300998995381, 86.84246017086892, 28.553074098402455, 0.23828017285033581, 0.35994058895495634, 1.7355614059394406, 4.943340084245128, 1.971231992206266, 54.79398158288772, 82.0928935081728, 74.08617496490479, 72.06374599087623, 69.16829939811461, 65.11477693434685, 57.65739025608186, 55.53645487754576, 53.76369260972547, 53.735118143020145, 57.38112595773513, 57.74774597537134, 58.129059191673036, 54.14975581630584, 54.23600873639507, 56.05230146838773, 51.740600755137784, 52.027114206744784, 52.747602616586995, 52.17995328287925, 49.703572719327866, 46.511214471632435, 51.60709504158267, 51.33708692366078, 49.05474601253387, 49.904868756571126, 50.389026518790956, 48.94060896288965, 52.39946480720274, 50.954267517212905, 50.571554014759684, 48.01039141993369, 49.19042864153462, 50.625416001965924, 50.182258775157315, 48.223854649451475, 47.85356721570415, 48.09261214348578, 48.00445687386298, 46.50341679972988, 49.10636832637172, 48.86967289832331, 48.02921095202046, 49.24510648173671, 46.04336984695927, 46.51804724047261, 47.328452064145, 49.15076563435216, 48.677276719001036, 49.91952665390507, 49.14249335565875, 46.725611225251235, 47.18690156936646, 46.50936703528128, 50.38570819362518, 49.424774569849816, 48.09840156186012, 49.045124438501176, 57.80316906590616, 63.07260274887086, 61.88499143046718, 63.817249036604366, 58.46778723501391, 48.19662555571526, 61.79883264726209, 60.85114878992881, 53.80907835498933, 45.37540589609454, 50.74415399182228, 48.83530901324365, 47.628395711222005, 47.682755839440134, 46.57720050504131, 47.55867558140909, 48.283043215351725, 46.9579489000382, 46.18885447902065, 46.55257194272934, 46.13072887543709, 49.457847995142785, 47.22734512821321, 46.78042634840935, 48.02750079862533, 45.649222635453754, 47.73511163650021, 48.735680810866825, 47.262383660962506, 46.35093465928109, 50.386425987366714, 48.91223061469294, 48.91848679511778, 50.417753957933, 46.72874127664874, 46.903949629875925, 50.6743711040866, 49.79798416937552, 47.11422397244362, 47.05722801146969, 50.17613595531833, 47.44229101365613, 48.48618668894614, 48.45593344780707, 48.8663584955277, 50.23840750417402, 51.73062224541941, 57.4674298686366, 63.14524504446215, 61.41813132070727, 59.3751452046056, 58.48721865684756, 65.89697991648029, 64.51347366456064, 66.17016515424176, 63.29457752166256, 63.705292824775945, 59.17429239519181, 59.13757508800876, 55.9342263590905, 59.88490819931031, 60.937990065543886, 64.35840275979811, 67.5219786551691, 68.87853037926459, 64.00571500101398, 74.81251162867393, 72.50226697614117, 84.49069330769201, 8.509135919232524, 3.800187360855841, 4.417950857070185, 0.2117526777569325, 2.471356497656915, 57.85972572142079, 77.86615525522541, 68.48768972581433, 56.75759069381222, 28.686152273608794, 27.741445495236306, 44.5098368583187, 70.96501165820708, 72.1722230603618, 52.33821699696203, 1.7936651913389083, 0.2166536486437244, 0.28570479983764313, 0.13718293559166694, 0.23955118932550956, 0.13133912497470457, 0.185601209260283, 0.16933190726464795, 0.2040667321172453], [0.03344804994882115, 0.04242508356729823, 0.030040264865683935, 0.04632532528992142, 0.05442297424099619, 0.07123997930677668, 0.02345929571968173, 0.12383725494146348, 0.08306671444687151, 11.998655872960246, 62.71599654228457, 58.867182577809984, 35.0312057618172, 37.79500976685555, 52.0854712301685, 41.62285474038894, 50.78732359793879, 61.2535604353874, 69.07170711025115, 5.537763026452834, 0.09818459395319225, 0.03424719839747395, 0.5542077388494246, 1.04350772836516, 10.389705511831469, 68.5312201899867, 65.87459102753671, 71.92859680421891, 64.52644886509066, 64.67657366106587, 56.93639978285759, 51.32255846454252, 50.45234141811248, 48.06695984255884, 44.846321305921, 45.83429182729414, 45.6488617773979, 44.9546101016383, 44.11225365054223, 43.70016944023871, 45.09745105620354, 44.949989549575314, 44.73642433843305, 43.822390494808076, 43.87695850864534, 45.60489200776624, 43.50751438448506, 46.037858916867165, 44.996159768873646, 44.86993789672852, 44.38198328018189, 46.08915567398072, 44.28586167673911, 43.52303128088675, 45.394174437369074, 45.49546572469896, 43.294517917017785, 44.75568317597912, 45.32742746414677, 43.966333635391734, 43.17349710772115, 42.79826356518654, 42.430549206272254, 41.41360805880639, 45.27751530370405, 43.621537685394294, 43.59614426089872, 43.257326003043886, 42.584867015961684, 42.1950069550545, 41.720474689237534, 42.34595152639574, 41.32366418838501, 44.1459781892838, 43.12576186272406, 44.0907512172576, 43.53422572535854, 44.56183964206327, 44.266932318287516, 43.03049533597885, 43.69583914356847, 44.71218016839797, 43.436966634565785, 46.14939935745732, 54.807733412711855, 54.78577206211706, 55.03559566313221, 58.16533327102662, 39.995577104630016, 55.32949493777368, 56.46935924406975, 50.9561384877851, 46.434677262460035, 45.726081478980284, 44.67025395362608, 42.7286022709262, 43.53033865651777, 42.325025681526434, 43.95465281701858, 41.903833727682795, 41.78651563582882, 40.597727606373454, 40.140771481298636, 42.07305262165685, 42.55473144592778, 42.910070726948405, 41.8158471199774, 42.923367561832556, 42.90096690577846, 40.97566366195679, 42.88645805851106, 41.85082681717412, 44.204856887940444, 42.75001448969687, 44.11946688928912, 42.6770152584199, 42.46557204954086, 43.766516331703436, 41.19952117243121, 43.252517177212624, 42.828293231225786, 42.618524874410326, 43.47494694494432, 44.85646063281644, 43.71827902332429, 44.31693077087403, 46.435045965256236, 44.743515983704604, 44.088990073050226, 44.14503289807228, 48.96421770895682, 53.45346843042682, 53.704421674051595, 50.110502935224964, 52.00433308078397, 59.79483881304341, 59.248201616348766, 59.59937141787622, 57.41583893376013, 59.548553189923695, 58.34402861133699, 57.73470801691855, 60.68025504389117, 63.66146033810031, 63.87249169811126, 66.633436295294, 62.19614913386684, 61.06858538043115, 56.79764201564174, 67.26570667759066, 62.76706187955795, 79.43856285464379, 30.075542080786924, 0.46981114173127764, 3.372109441026565, 0.08478120389965274, 0.4597586892064541, 31.395886405821773, 74.6091838036814, 50.92386130363711, 57.98661047412504, 42.101117180239775, 15.493397481979864, 25.600847275026386, 48.22006956223519, 53.589590364886874, 48.8665153903346, 5.078795706072162, 0.18408840011444785, 0.046855695620780034, 0.026114671378426497, 0.029706936179389878, 0.07346792386904841, 0.042527379287827405, 0.010545972111304442, 0.02916674843178161, 0.0064058692171989435, 0.008466577743210139, 0.04516316990878794, 0.07308634313484354, 0.09586041342587241, 0.004383003998232345, 0.058108615583830306, 0.04326946950787979, 0.11281877320500151, 15.766169890280693, 74.20177505862328, 63.77781744926207, 49.90088755084623, 46.80220726997622, 50.141928965045565, 40.527093564310384, 57.1880433636327, 66.43522324100618, 77.70755029493763, 8.018686184960028, 0.22355248490648888, 0.3295534356467186, 1.639453653366335, 1.283645036239778, 12.438331015648382, 70.64591115520847, 67.3189881540114, 74.34213315286945, 68.5154208829326, 65.92124369836623, 60.42488913382254, 54.85504504173033, 52.014386115535615, 51.877342424085064, 48.12624254534322, 48.955768923605646, 47.07842449988089, 48.64647434603784, 46.53967911197294, 47.72290914289413, 48.01488253378099, 46.64552034870271, 45.820245819707075, 44.62158126215781, 46.903659374483176, 47.60222957980248, 46.92353794651647, 47.76184651159471, 48.378921631843816, 47.65111800163023, 47.831633321700565, 46.7718755814337, 46.17625974839734, 46.27380517221267, 47.76514522490963, 45.88584746083906, 44.53795240771386, 46.363913782181285, 48.43020662184685, 46.22302616796186, 45.86003042036488, 45.01440271254509, 44.552414186539195, 43.038418523726925, 46.043652257611676, 44.86077916237616, 44.60339323166878, 46.81504518755021, 44.4897464782961, 43.81052140266665, 44.89986165877312, 45.25739746709024, 43.01815555941674, 46.52296981503887, 45.281602413423606, 46.231349437467514, 45.3015947341919, 45.96049016521823, 45.58585282294981, 45.9097856860007, 44.44114438949093, 47.2420108702875, 44.00934242433117, 50.17074661870157, 56.7087414956862, 57.36734667131978, 57.27200169717112, 60.55671215057374, 42.753164152945246, 58.04172761978642, 58.92990519923549, 52.78718717636601, 49.04766221200266, 46.874535775953724, 44.572739908772135, 45.1443822153153, 47.02047932532526, 45.658601022535755, 45.05816067418745, 44.11478357930338, 45.9647733934464, 44.54300834286598, 43.55620276543402, 43.71339567245976, 43.73857728896603, 44.0913317280431, 45.49760733881305, 45.36148540435299, 45.65162312599921, 43.16828820013231, 43.36196699450093, 45.10945350893083, 47.12522229840679, 45.15521187936106, 47.19944530917753, 43.99585339330858, 44.96286669085103, 45.84650216564056, 44.681456242838216, 44.53599514499788, 45.779292352737926, 47.184744265771684, 45.66598684557023, 46.310471488583474, 45.500180413646085, 46.28600374344857, 47.86261220132151, 46.211431641732496, 45.77141231106174, 44.220240423756266, 50.646486974531605, 56.81260585784913, 57.11993140559043, 53.520007518029985, 53.50227840485112, 61.49823004199613, 61.130143057915475, 61.73567072037728, 61.351568698883064, 62.134124694332, 60.110589611914854, 60.09794389047931, 62.7492033281634, 64.1370947899357, 67.33779199661748, 69.25047305322462, 64.46805261796521, 62.63307763684181, 57.41932984321349, 68.21052720469814, 65.03771412757136, 80.70402929859777, 34.00656500170308, 0.5546352159111732, 6.300399755277942, 0.04346631963046328, 0.3093535663379777, 35.267791363500784, 78.12551806049963, 56.98995190282022, 56.071411255867254, 39.965182658164736, 23.349436213893277, 33.78402932997673, 56.856771745989406, 61.38308102084745, 58.34314607804822, 7.108042740052746, 0.25895674803083946, 0.05610321573312244, 0.08691750136354277, 0.044479926732639154, 0.05037353689511938, 0.011811185470451752, 0.017924760543410818, 0.008269538013865391, 0.10050465292747944, 0.13085930878596921, 0.15830636985840338, 0.10073275560693395, 0.16274324468066617, 0.10094796502662283, 0.12737609085536775, 0.2405565418303013, 0.23518194474520224, 21.824506944225682, 85.99670302483344, 75.81766605377197, 54.46428675805369, 51.12619676897603, 63.01285328403596, 58.20358422494704, 69.15079778240573, 70.99496287684288, 85.79009609837686, 8.129842233273292, 0.25587446987628937, 0.4137229336605918, 3.246235924382364, 4.301930089150706, 12.197085638200084, 74.42994717628726, 69.7264212946738, 77.5282822885821, 71.08192966830346, 69.81259576735958, 62.12396183321553, 56.70511722564698, 54.700746843891764, 53.377362681973366, 51.22098868893039, 51.52797299046671, 50.806743252661924, 51.21202215071648, 48.209592911504934, 47.70548989695888, 51.13150765818935, 50.12983237543414, 49.57365989685059, 47.03460378031577, 49.315595396103404, 49.65625324556905, 49.49358078741258, 50.87312152308803, 50.50260659187071, 50.0141812909034, 49.38639810008388, 49.12971427363735, 48.82251031937138, 49.475055433088734, 49.340608350692264, 48.600151154302786, 46.56778289425758, 48.39558778270599, 51.13794034527194, 48.617911646443034, 48.41730202397993, 46.69268292765464, 48.37284980281707, 45.530539558779815, 49.681874167534616, 47.76556491851807, 48.15298918754824, 48.680610733647505, 45.756652432103316, 45.384509717264486, 48.16883164067423, 48.579762674147084, 43.65525437939552, 49.896012044722035, 47.64580711241692, 48.81077066544564, 49.020613547294374, 49.792053545674975, 48.99880124676613, 47.66975318231891, 49.55194957794682, 48.51935425112325, 48.133785263184585, 51.47304411857359, 58.53440477002052, 60.16971934226252, 58.33476789536015, 62.69248585547171, 45.451543023509366, 59.85571792048793, 62.41155785899009, 55.80977347589309, 50.55090273580244, 49.571518282736506, 48.40171844728532, 46.96802939138105, 48.85781949566257, 47.08942674821424, 48.4809503247661, 48.227545599783625, 48.413654219719675, 44.95643008139826, 45.130618618380645, 45.944333922478464, 46.223234053580995, 46.1002089131263, 47.95130483565792, 49.6504363706035, 48.22204251443186, 43.812851290549006, 46.89186480737502, 48.094902807666415, 50.74624069275395, 46.439631215987674, 49.61901818552325, 46.23536986689414, 48.560186124617054, 47.853959452721384, 47.62508915316674, 47.08530433716313, 47.23757466962261, 49.906457316490915, 47.55593384465864, 49.868539764035134, 46.17441623441635, 48.94982653279459, 52.515178649656235, 47.57947983280305, 50.023155673857666, 47.80963274740404, 51.92147693326397, 59.388885267319225, 60.322013208943034, 57.541252797649754, 57.27001697786393, 64.893982794977, 63.751678774433756, 65.73831219826975, 63.53343417567592, 63.633819395496005, 63.32080641100484, 63.81827277521934, 63.38878108609108, 67.25386111967026, 69.04085374647572, 71.72945022583008, 66.63648789928806, 66.77334723934051, 60.92730945156467, 73.1185733118365, 68.38527664061516, 82.18087227113786, 34.836440470910844, 1.0612546147838717, 7.185989551005825, 0.1674710643748122, 0.8697128992888236, 40.96970165929487, 86.50265739810082, 62.28035457672612, 74.70814520312895, 51.62893087633195, 27.563826845538234, 40.68061905522501, 68.34329159029069, 72.6326387159286, 69.84959156282487, 9.517105625521753, 0.3341692379645763, 0.18975769590225913, 0.3214495737225779, 0.19394064322113994, 0.1341511885966024, 0.1586127437410816, 0.11087100231839765, 0.11197312704978452], [0.032770747784525156, 0.012178406844125881, 0.03779957108500023, 0.02188622035206326, 0.015284946045627999, 0.0750781947206105, 0.0384548558823524, 0.03710369511898007, 0.09894863642271488, 22.20339417457581, 67.09330281903668, 48.34215333384853, 31.048791946903354, 23.784987964937766, 30.93102670484974, 34.486580741020944, 54.75636213056503, 66.52658308705976, 56.607003058156664, 3.834527711714468, 0.16813397557745058, 0.3171588071892339, 0.9155010552175584, 4.624767140034707, 38.10452791952318, 67.88988128785165, 69.44600320631459, 68.0248422007407, 66.19870431961553, 65.28553339742845, 56.286953341576364, 50.41292552025088, 48.28758139764109, 48.91300724398706, 47.17743689014066, 44.706096572260705, 44.85989662908739, 44.47565732463714, 44.22085623587332, 47.36928393763881, 46.791754153467, 46.102107340289706, 45.0770115852356, 45.06079258457307, 43.32756388571955, 42.46774504261632, 43.173661847268384, 42.67396365442584, 45.26621103286744, 42.62183927720593, 44.99994485608993, 43.45968500260384, 45.99065711421352, 46.526935331283084, 43.48521178768527, 45.598482854904674, 44.14394640153454, 43.888215711039884, 43.58405159365746, 42.967690344779726, 44.223664652916696, 43.295267089720696, 43.292839142584036, 44.67057166561004, 43.67276776221491, 44.08074917331819, 44.234431559039706, 44.06205123470676, 43.06376095741026, 41.86651237549321, 42.04059893085111, 42.676717158286806, 42.50145389187721, 40.885221650523526, 41.50173979420816, 41.683710313612416, 43.038932354219504, 42.80571214614376, 43.188637456586285, 43.557716800320534, 42.25386996423045, 43.123988951406176, 43.95975189824259, 42.73703928916685, 46.01860792406144, 55.902506151506984, 56.81630465292162, 57.25359793632262, 38.29288797993814, 52.74174259554956, 57.48551199513098, 51.724750457271455, 45.329882867874645, 44.47680657909763, 43.76982681212887, 40.74418890860773, 42.111621287561235, 41.57051071043938, 43.41326375161448, 41.87333337722286, 41.425108448151626, 40.74460075747582, 44.44513343995617, 41.73392841892858, 42.75531753416985, 40.7132217960973, 42.427391698283536, 41.327896425800944, 42.187781949197095, 41.75445810441048, 42.50911035845357, 42.61726579358501, 43.61206908379832, 42.091224962665194, 44.035402651756044, 41.00505005928778, 41.58848301056893, 42.946246747047674, 42.89660130777667, 42.223922667964814, 43.11605399654758, 43.912597164031, 44.77820150313839, 42.813266631095644, 44.81590332523469, 45.316123193310155, 44.520964622497566, 41.56398780884282, 45.30207718572309, 43.8205587479376, 46.61811867067891, 51.02676468510782, 54.843317154915106, 52.52980909039898, 53.851126163236565, 56.774158785420084, 58.2324371799346, 56.08086809035271, 58.805711192469445, 59.3821584024737, 63.32182230487947, 64.77841408021989, 60.06413305959394, 61.15006477602067, 61.125040054321296, 60.39392594368228, 57.26403536335115, 56.48226384193667, 55.752961866317264, 61.57481039724043, 67.93849514376733, 72.68741069301483, 59.099657535552986, 0.22983558566099216, 2.681438889234297, 0.48001013155425754, 0.1125296746050158, 21.867560840422108, 72.5360542728055, 57.93870656721054, 56.61636183338781, 40.27119813426849, 20.44030447160044, 26.18149926585536, 44.22526105757683, 53.96753818758073, 56.396203117985884, 12.670537291034577, 0.13564080060009034, 0.07893992137284049, 0.011896515216287828, 0.0403578182862651, 0.020586479410168626, 0.045138222255533746, 0.020730231978720235, 0.03514337571217649, 0.08084902780190592, 0.020532916457722747, 0.029629241457329165, 0.020244269849612348, 0.009835327885323956, 0.018650125148856354, 0.04437291957137566, 0.049768051643285065, 0.05341222464677788, 30.495708334830503, 75.38801746983683, 57.68885158723401, 34.16844121871456, 30.363404827733195, 29.877682039814612, 31.794785568791053, 65.11079572862195, 69.92210834257065, 66.43516048308342, 3.883546307202309, 0.03400131481729689, 0.16959954774187458, 1.8916931892594986, 5.993509100329492, 41.395608302085634, 69.66878598736179, 73.3832077826223, 69.88850147493424, 68.0437558697116, 67.90451172859439, 59.236634546710604, 53.24881092194588, 52.02482354256415, 51.13805409400694, 50.166655586611846, 46.54391527175904, 47.02260524995866, 48.11069426998016, 47.3362301241967, 48.18305415491904, 48.710369756144864, 48.16961219233852, 47.57452587927542, 46.65742866454586, 47.1480034243676, 44.703405826322495, 46.750683015392674, 44.77802107411046, 46.195236175291, 44.798354641083755, 45.317064562151515, 46.225446270358184, 48.13596610100039, 46.64689317826302, 46.50906109040784, 45.75355768203736, 48.028261738438765, 45.573007060635476, 45.563346262901064, 44.661773789313536, 45.78451302743728, 46.00344796334544, 44.76433200220908, 45.34607441194596, 47.49345048781365, 46.5435230347418, 46.623868865351525, 44.884376141332815, 45.78315980972783, 44.56545998973232, 45.68535158711095, 45.9077029074392, 44.87092241164177, 44.045314481181485, 44.921960292323945, 43.88879622182539, 43.914013139663204, 44.815362038150916, 45.62089920043946, 44.42667868829543, 43.652151784589215, 44.539921437540364, 46.14249990832421, 46.7063327758543, 49.37220696480044, 58.52239055018271, 58.66581593790362, 59.59807311334918, 41.23041768227854, 55.809973516771876, 58.57102401794926, 54.758617493414114, 46.67463610249181, 47.01657656700381, 46.08226799195813, 41.97487177387361, 45.39956377398583, 43.6101157434525, 44.78156689674624, 43.21297968587568, 43.62990410097184, 44.285900900440836, 45.274067540322584, 43.73282709429341, 43.70049107459284, 45.136737515849454, 44.198883118168006, 44.766230429372484, 45.83168345112955, 44.24319805637483, 44.29400451721684, 45.61412918952204, 44.4101772769805, 45.305497492513354, 44.79089821538618, 43.53144084253619, 43.9878321463062, 44.845226964642926, 44.92656515490624, 44.265794830937544, 45.64922655782392, 47.17783304952806, 46.00819403125394, 44.71295679769209, 47.54672804186421, 46.03634880435082, 45.78859621478666, 45.22872101876044, 46.337939846900206, 45.31586823924896, 47.91408154272264, 53.5617180024424, 56.132023642140055, 54.66011893364691, 55.83776350944273, 57.92095784218081, 60.871117576476074, 58.74349455679617, 61.10114105286137, 61.681957783237586, 65.66427353889712, 67.8246130481843, 62.96504743637578, 63.075885772705085, 62.8874158859253, 61.86588556535783, 60.99771207378757, 58.360149552745206, 57.86868833726453, 64.47192007495512, 71.39411895505845, 74.04631583921372, 63.83186771023659, 0.24592355464495, 2.8502922673379225, 0.5325986048386944, 0.17490417035596986, 23.75412283405181, 76.75620294386341, 64.25257721254903, 58.79559147742487, 45.97943521315052, 27.10328567412592, 36.48600893635904, 52.38662688962875, 60.35935025061331, 66.08060959846743, 17.828623710140107, 0.33212497830390936, 0.046982548289722016, 0.01615839353161714, 0.06874425637145197, 0.02535606813316624, 0.10367166040645492, 0.07813453313804443, 0.04116877598027068, 0.08472718704011171, 0.1632544857960555, 0.0892968555431693, 0.16866901138376805, 0.1421448564337146, 0.14068357436166656, 0.13273726608003342, 0.16160849992546344, 0.18130149481998337, 38.57058786576794, 88.42137890477335, 65.60874846673781, 47.734739011333836, 34.527891143675774, 37.49733717210832, 49.975455730192124, 69.90363397905904, 77.51598173572172, 70.40723493022304, 5.312913156324818, 0.2934416750025365, 0.970091377535174, 5.209763155829522, 7.906860882236113, 46.3556375811177, 71.8269681930542, 73.36650633042859, 72.3047834827054, 69.82282530876898, 72.40987946910244, 62.77791507782475, 55.82480007602323, 54.21098009232552, 53.52283162455405, 52.13211213388751, 50.31601159803329, 48.943452681264574, 50.17991712016445, 51.553495853177964, 51.32642592153242, 52.77365892164169, 49.484229856921786, 50.77887481258762, 48.23952059591971, 49.05327512371925, 46.11035608476209, 49.71536336406585, 48.11744466904671, 48.212977916963645, 46.31461743385562, 49.6606659120129, 47.09751859787972, 50.60386650023922, 50.79234815412953, 47.44124374082012, 49.12558794021607, 49.54956477688205, 47.770518872045706, 48.102716169049664, 47.75027159721621, 49.6317345096219, 48.070231099282545, 47.632047437852435, 48.499616884416156, 51.09128375207224, 47.926770410230084, 48.033968787039484, 48.34093739909511, 48.94684553146363, 47.243273873482984, 49.10471700852918, 48.247887011497255, 47.43098674281951, 46.34476477100004, 47.46609980060209, 46.95859216874646, 48.1071602144549, 47.35038988051876, 48.928904610295454, 47.62040192081083, 46.54642558866932, 47.959180954963934, 47.989077260417325, 48.38775873184205, 52.781582109389774, 62.99089193344117, 63.088135334753225, 60.713944281301195, 43.63257915742936, 56.716554857069454, 62.51934066895516, 56.31444523411413, 49.751190293219786, 50.03626815734371, 48.258065562094416, 44.42538430613857, 47.767435889090265, 47.038553607079294, 48.52232348534369, 46.389746512136156, 47.15352219920005, 46.17990363028742, 47.75979511199459, 47.07664374382266, 46.75417000247587, 47.69264021227437, 46.68825457173009, 47.06713199615479, 47.0788481158595, 47.28437639051869, 47.728906446887606, 47.25470758253529, 48.33074315901726, 46.816002245872255, 47.40898616852299, 45.517152509381695, 47.66017083198794, 47.68139085462017, 47.38731899569112, 47.17328310012818, 47.68126926114483, 49.78259671118952, 49.50183345425514, 46.51744711783625, 49.71079772518527, 47.69517406340569, 50.490404098264634, 47.979200732323434, 50.23756811695714, 48.09537741445726, 51.38872884934949, 57.00158565275131, 60.02634102298368, 57.91319939397997, 60.53329560064501, 62.89233453812138, 64.88200779884093, 61.994186293694284, 63.359888907401796, 64.08378585692375, 69.91771528797766, 70.50501177387854, 65.5745493212054, 67.92790474430208, 68.386092493611, 65.58686948591664, 63.40348997423726, 59.89383943619267, 62.63289720781388, 67.31624249489077, 75.68984385459655, 77.98959224454819, 66.93014006460866, 0.26446246872505835, 4.803200171839807, 1.1975061100336815, 0.3022476105440048, 27.787725540899462, 84.52289596680673, 70.51275453259869, 69.32611988436791, 51.533291724420366, 28.59734000698213, 41.87188210025911, 64.53601160357076, 72.36147742117606, 78.5236386329897, 23.37115437753739, 0.6514814772432851, 0.23004884921735336, 0.1096433847241344, 0.10579534040223207, 0.11243186049884367, 0.1647031120955944, 0.17544308256718422, 0.09036607679820831], [0.1075752997290223, 0.04204836366097293, 0.040460014415364114, 0.0368247012187156, 0.030922560667198513, 0.06328444732653518, 0.05424090578491169, 0.028624384994468385, 0.0629692059761334, 35.42099522006127, 64.49283807508408, 46.58202109798309, 49.359404348558, 16.618690183085782, 25.08921919330474, 47.98689250023135, 54.11232463775143, 70.9038148387786, 53.08823300946144, 4.276966164189001, 0.15927266720081532, 0.5232596866065456, 1.0834913893092064, 16.768811056690833, 66.01208579155707, 68.78087120671427, 69.60123492825416, 70.48125005537464, 66.82600113653368, 62.44938127456173, 52.295749495106364, 47.40610714881651, 48.07815036466045, 47.72337198257447, 47.28574529770882, 48.238755733736106, 47.65154161760884, 46.855990809779016, 45.11586658416256, 45.94423586322416, 44.88761601909515, 43.0800780173271, 44.74605767957626, 43.173681459119244, 43.572970897920676, 44.825493520306004, 41.580053837068625, 46.23290269605575, 42.32901080962151, 45.09664697031821, 43.9425640721475, 42.63641872713643, 43.94038715670186, 43.72796335527974, 42.943661905104115, 44.12813924974011, 44.452346678703066, 44.025898748828524, 44.39054581426805, 44.97823061481599, 42.663455624734205, 42.121713546014604, 43.555626177018695, 43.74893234622094, 41.342907336450395, 43.91838266003517, 44.27314927501064, 44.15013197929629, 45.36231694682952, 43.21443488520961, 42.6945560978305, 41.23590900051979, 41.605925790725216, 42.747778738698656, 42.61320221808649, 42.74509191513062, 40.67626522433373, 42.83425523388771, 42.11921107384467, 42.024744710614605, 42.99494297273698, 45.66026410748882, 43.15129649254584, 44.76490074588407, 44.67893023644724, 51.813317575762355, 50.72413421446278, 57.89670974977555, 40.58772948480422, 49.99229446534188, 58.13075757795765, 50.63571222366826, 48.659947687579745, 44.65580786428144, 44.11643881951609, 41.9053203059781, 43.825634294940585, 40.860867654123616, 41.60833804838119, 41.12984811106036, 41.77587424555133, 40.59240102767944, 40.9200522976537, 40.956549952107096, 41.15696737843175, 42.28535090723346, 40.7925791894236, 42.810003219112275, 41.37106210954728, 41.46492835014097, 42.30101685370169, 44.70305673537716, 45.418242100746404, 42.45865691092707, 44.48515730519449, 41.009254840112504, 42.04284252658967, 42.315219756095644, 43.58475369791831, 40.66831065762428, 42.33039932866251, 42.30017746648481, 42.23298334306286, 42.761228546019524, 43.70573528351323, 43.66232249044603, 44.40417997298702, 43.23027341596542, 43.1034553435541, 43.22488407934866, 45.651128907357496, 47.800917240881155, 53.67200328457741, 50.81238362096971, 52.85893517155802, 55.058396400943884, 54.399273472447554, 56.23093797314552, 59.90525353339411, 59.545701626808416, 58.160653883411044, 54.36323081293414, 56.308914692171165, 54.445981056459495, 53.944635468144575, 53.71254098030829, 51.30262497932681, 50.12060303841868, 52.36560690787531, 60.54589817600866, 69.15683038773076, 69.57088362786078, 72.07888633974137, 3.893982263342027, 4.017733287426734, 1.3772206537185179, 0.4312750498854345, 12.359227595790742, 67.95426307186004, 62.92383901534542, 58.15811218753938, 55.88092919318907, 20.994649125683694, 20.932412878159557, 46.73393057238671, 53.370890771189046, 57.934662603562884, 21.064908581395304, 0.3853898459384519, 0.031219955999404195, 0.05578523944883097, 0.033578009104296085, 0.07689008459208474, 0.06345697032708315, 0.07229699678118191, 0.057792477910557104, 0.055557420221908446, 0.04788482366430183, 0.012910101251045783, 0.0373198468268158, 0.0338885466748428, 0.11911783923184681, 0.030803813208495418, 0.05587011049952238, 0.2681440727845315, 46.343309571666104, 72.64677493802964, 55.732192916254846, 55.21530297494704, 24.54783012790065, 27.508929352606497, 47.27911256974744, 62.08855459767004, 75.32920545147311, 57.441059773968114, 4.045944199446709, 0.22121197904550263, 0.179032985902121, 0.9493511710916797, 18.8689519897584, 68.4532513157014, 70.23581950895249, 72.49889373779297, 73.77954759905415, 68.62748299875568, 65.2601360505627, 54.39986575034357, 50.37939317764775, 49.18313695538429, 51.28768859371063, 50.39687910387593, 50.39538075847011, 50.932647412823094, 49.451764399005526, 48.18116749486616, 48.94132675663118, 45.96970773512318, 46.513477679221864, 46.57262309905022, 45.24733266522808, 45.96145114591045, 46.416367638495664, 45.5717989706224, 46.366235825323294, 44.51288453994259, 47.65529532586375, 45.10928876938359, 46.33559819190733, 45.89921489838631, 46.07924776692545, 45.077254772186286, 47.68856094729516, 46.322034635851466, 45.99860383618263, 45.63232898712159, 46.98304814677085, 45.74932544462143, 44.59200266868838, 43.890671114767756, 45.46826016518378, 46.23365971349901, 45.32031620702436, 45.79354624594412, 45.16613960266114, 46.89667363320628, 45.86749469080279, 43.13767410093739, 42.5300754270246, 44.54757398174655, 44.90754558194069, 45.16111896884057, 44.93885394065611, 41.517088028692434, 45.80155180346581, 45.028503633314564, 45.26612474072365, 45.82953791464529, 46.203794787007, 46.27321681668682, 47.75371151585733, 47.433406845215835, 54.39065602517898, 54.02955870474539, 61.14359286523635, 43.12523626512097, 52.43404442264188, 60.979516198558194, 52.60268280583044, 51.09941482543946, 46.148465833356305, 47.342270574262066, 44.724421885705766, 45.50362817702755, 43.732321108541186, 46.29462511308732, 43.259965758169855, 43.20269523128387, 42.422237703877116, 43.300272034060576, 43.44598024122177, 44.5439967801494, 43.86431278720979, 44.390157499621, 44.676251257619555, 43.48229354427707, 43.73947943410566, 44.63751785216793, 46.46155334288075, 46.152101870506044, 44.46374508642381, 45.45402980619862, 42.636034334859545, 44.77579709022276, 45.600961792853575, 44.340264951029134, 44.97201365809287, 44.65231303245791, 44.086817079974765, 44.4000183382342, 45.60501752361175, 45.37106383231379, 45.10011826792071, 45.22748547215616, 43.99122891887542, 46.045884086239724, 44.359637537310206, 47.617177732529186, 48.85025324360017, 55.214122341525176, 53.665197972328436, 54.08914343003304, 57.048979651543405, 55.71875095367432, 59.76727631784255, 62.94399999803113, 61.516265100048436, 59.04517189148934, 57.13905296018047, 59.13137382076633, 56.0031698596093, 56.0093750492219, 55.80065788761262, 53.25576920663157, 51.76369174834221, 53.08916261119228, 61.92289329344227, 71.87182441834481, 71.37447572523548, 74.30480003356934, 6.035803037305032, 1.9273756035873968, 1.0961139442459231, 0.28334812952145455, 11.91084969428278, 72.03780343455654, 67.10471691623812, 61.44531726837159, 50.869944403248454, 20.68578993120501, 25.973817609971572, 55.044628881639056, 58.60107329583938, 66.15453843147525, 29.738355528923776, 0.5253200954006565, 0.08843990193018991, 0.12878244442324485, 0.010785174447171872, 0.035097866259034605, 0.022017698276848085, 0.021517381575258992, 0.011950639328138243, 0.17501407332958716, 0.1508675028960551, 0.2021505776792765, 0.12928807777502846, 0.168049966375674, 0.1990113485484354, 0.18648571905589875, 0.16438952166466944, 0.7157454062854091, 59.328343483709524, 82.56446438450968, 65.18370082301479, 67.54788983252742, 25.87230863109712, 39.76967211692564, 63.63753780241936, 68.09467607928862, 82.35096977603051, 67.85052422554263, 6.9405384121402625, 0.49051837575051094, 2.076893045056251, 3.4188231537418985, 21.407245205294704, 72.13642751016926, 70.47743751156715, 76.08888226170694, 78.45221227215183, 71.65769438589774, 68.26866457539221, 56.39712095260621, 52.26166802067911, 52.76934823682232, 54.06561313136932, 53.09960788296115, 54.91421399577972, 52.3081128058895, 51.877197296388694, 49.74241202877414, 50.88672430284562, 48.36899803530786, 48.79015861019012, 50.15564549353815, 48.80665217676471, 49.930062140187914, 48.196860897925596, 45.37030681487053, 50.22999009778423, 46.26018670297439, 50.15520226570868, 48.65323651221491, 47.424028458133826, 49.233143252711145, 47.41053942711123, 47.14752881757675, 48.83466966690556, 49.76691899761077, 48.998240347831484, 47.95250508093065, 51.035476269260535, 48.311127385785504, 44.50546341557657, 46.61038767906928, 47.97027341781124, 47.98745732153616, 48.50309994912917, 48.3725477803138, 48.40337760986821, 50.34498614649619, 48.56650898533483, 46.71936681193691, 43.5757165570413, 47.66168878924462, 47.482648280359086, 48.660214408751465, 48.39176739415815, 43.6198079201483, 47.974501732857, 48.169871068769886, 47.566351659836315, 47.05774576433244, 49.566885963563, 50.03336168104603, 48.84631518394717, 48.941507185659106, 56.26155991708079, 57.03658496179889, 63.01386917791059, 46.10513148769256, 55.456336544406035, 61.85031767814391, 55.150442661777625, 53.28601068066013, 48.102873063856556, 49.68264687445856, 46.62534367653632, 50.09927318942163, 46.71158090714486, 47.2452272138288, 46.40482018070836, 47.56302941230036, 46.304030956760535, 45.713043520527506, 46.40892690227878, 46.2016688623736, 45.59772191509124, 46.53629410651423, 48.51381586443994, 44.78653261738439, 45.1402598042642, 45.66693605915193, 49.9718040035617, 49.219238450450284, 45.56631157475133, 49.36990453350929, 45.18697131064631, 47.15009404766945, 48.302494249036236, 47.46362086265318, 47.84394956404164, 49.00219801933535, 46.21140418514129, 46.24674081802369, 47.725097825450284, 49.3072642818574, 49.455886810056626, 47.496094165309785, 46.77665302830358, 48.02633193231399, 47.36977031154018, 50.67874454682874, 52.74531195240637, 58.633703493302875, 55.56778284811205, 58.21035031349429, 59.265762067610225, 59.04135542531168, 61.99308410767586, 64.96262427299254, 64.11043836224464, 62.30968998324487, 60.755788126299464, 62.78631679473385, 59.181458565496634, 59.05595840946321, 59.96939605282199, 57.38726054468463, 55.02859423237463, 56.259230029198434, 66.9716073620704, 74.2884280604701, 73.71846845073085, 78.72514647822227, 5.879666718744463, 9.299834755159194, 2.8319963716691543, 0.5547895366626402, 15.325992684210501, 79.44130851376441, 72.09157912961899, 71.72090730359479, 67.39733357583323, 30.193660336156046, 31.84801801558464, 65.62398295248708, 72.1231306752851, 76.16332100283715, 39.006602456492764, 0.9769517255406227, 0.15535235014413634, 0.17473892519070258, 0.09397195306636634, 0.1839000037721088, 0.20889938328294985, 0.187461776358466, 0.08600931179018752], [0.10562398951620826, 0.04629192385642279, 0.045078831289203904, 0.03297572609998527, 0.017975469818338752, 0.037685914280553984, 0.04888971651633901, 0.15379489339407415, 2.3382971988570307, 42.594135576678866, 57.92820245988908, 45.03531679030388, 32.89105469180692, 13.428409810989136, 25.960073624887777, 37.598102861835116, 61.47156576956473, 72.16273876928514, 37.87498689466907, 0.5248306571475921, 0.04059368909727182, 0.15201752344446798, 0.7164207893994547, 21.30353773793867, 68.2805101333126, 62.699691249478256, 71.47468443839782, 65.36352580593478, 69.51541346888389, 61.08210186804495, 48.200857793131185, 49.94050348958662, 53.00512583025041, 57.05966811026297, 58.670256060938684, 57.46810843867641, 56.27886933665122, 53.82819206483903, 54.16579046557027, 53.89906929385278, 54.12551556864093, 50.45875057097405, 50.46772887629848, 48.892712900715495, 47.044558755813114, 42.93092596915461, 43.406674169724994, 44.11376376305857, 44.64301701514952, 43.73367040388046, 43.21435643780617, 42.425944343689956, 42.70575446467246, 43.56253739326231, 43.199278846863784, 42.8071948020689, 42.885414708045225, 42.339946377661924, 45.365717641768924, 43.066388945425714, 44.71895410168556, 43.690300756885165, 41.842001484286406, 42.577967566828576, 42.76612366399458, 43.981795618611, 44.30037444637668, 43.39769978677073, 44.999831107354936, 43.542129301255756, 41.66640481641216, 42.957405890187914, 42.05574320208642, 43.883575547126036, 42.04607848198184, 41.07524871826172, 42.98552536195324, 42.14393377304077, 40.70955437998618, 43.47369963122953, 45.61735337780368, 45.7872861431491, 44.52643240651777, 45.16702605832008, 45.53001003880655, 47.85896831943143, 52.8315217264237, 58.17263672428747, 47.55002675517913, 51.10879321252146, 55.44362022030739, 50.13432741165162, 48.04603399768953, 44.632289332728234, 45.11328566458918, 44.70289199582992, 44.05417119303058, 41.17816386684295, 40.79810580899639, 40.38929285541658, 40.45097604874642, 40.660909145109116, 41.684314358618956, 39.612612570485766, 44.37182434143559, 42.424614660201534, 42.20947265625, 41.5488160810163, 42.29698465716454, 40.39099516407136, 43.840962917574, 43.84286526710757, 43.50506290312737, 43.0805173227864, 43.610343240922504, 42.20720160392023, 42.6433377881204, 41.285730946448545, 41.45854665387062, 43.204126896396765, 41.98996897666685, 42.496531317310954, 43.34832891341179, 43.60420080923265, 43.54629878074893, 43.08995846779116, 43.15004917883104, 42.85351014906361, 43.49653174800258, 43.14325171132242, 43.09841902025285, 45.49577951431275, 50.46635996910834, 48.277610732663064, 49.75737587098153, 50.58587851062898, 52.576147971614716, 50.888371698318, 49.65897144809846, 50.65241367586198, 49.18523150105631, 45.9969642854506, 47.1265951279671, 45.51183769779821, 44.4137191772461, 47.28000687014672, 50.534311109973544, 52.96436848178987, 57.046696832103116, 58.513596596256384, 67.56331259204497, 65.97148141553326, 79.67546616831135, 14.237920334262235, 0.3379268379461381, 0.4959636674292626, 0.15966305028527014, 3.340305392780612, 59.82229540424963, 65.76955779906243, 58.22525532014909, 66.9095790001654, 49.82576239493586, 36.64311555124099, 46.832531113778394, 47.270691240987475, 58.848245374618045, 38.16449703708772, 1.4855023401398815, 0.12567520712412175, 0.010429130296312995, 0.04978081466810358, 0.09258161839698592, 0.04748269262152815, 0.07411148369071946, 0.05363175097192007, 0.04000154526663884, 0.021697483100597898, 0.023412654371631723, 0.033244852787784995, 0.017993718032695113, 0.005775632622141031, 0.03834404892498448, 0.21258423555522196, 2.9997914452706618, 55.96016499304003, 65.4068640739687, 56.04923809728315, 39.446743380638864, 19.61793053534723, 28.061122586650235, 43.048189147826164, 65.83144495564123, 75.28764401712726, 46.85572016623713, 0.7710728277602504, 0.12340813079067778, 0.3711071171827855, 0.897233229010336, 22.883513550604544, 69.44110808833953, 66.70499601671773, 72.81647236116471, 66.58537941594278, 71.1298845660302, 62.41837886071975, 51.118430476034845, 50.35781621932984, 56.67277728357623, 58.50606564552554, 60.14211762335993, 60.19800747594526, 58.47208223035259, 57.86437373007498, 55.881643064560436, 55.517290176883826, 54.75125912697085, 54.52172202448691, 53.480477871433386, 52.67247746067663, 48.661893183185214, 45.80507016951039, 44.707465479450846, 45.23376126443186, 46.52779825272099, 45.36608242219495, 44.76187267611104, 44.457304554600874, 45.394688267861646, 45.793824734226355, 44.53503808667583, 45.87553947202621, 45.54661343174596, 45.6731177145435, 46.87914063853603, 45.369479194764175, 45.715738188835886, 45.01643450029435, 46.45962353675596, 44.413801547019716, 45.27856649891023, 45.366251084112356, 44.30037444637668, 46.07487040181314, 45.916606687730365, 45.58355039165866, 44.53871726989747, 44.833318648799775, 44.84860020299112, 45.01555196700558, 44.730399577848374, 44.72417869875508, 45.583754354907626, 44.40197560095018, 43.10471050200924, 45.96508718306019, 48.15197329367361, 47.67379322359639, 47.303227301566835, 47.48087929141137, 46.24165350391019, 51.08030503795993, 55.6802999588751, 59.86322925936792, 51.82999941610521, 53.11541895712576, 58.584677788519095, 53.306728639910304, 49.89230932727937, 47.96415059797226, 46.71361661726429, 46.96499739923785, 47.998632154157086, 44.895323476483746, 43.73873418377292, 42.60126252328196, 42.454581568318034, 43.71979698058098, 44.01121339490337, 42.69341861048053, 45.696789218533425, 44.84692535092754, 44.04831509436331, 43.84444205991684, 44.67229750848586, 43.044353069797644, 46.231757363965436, 45.68905822692379, 45.37836728557464, 45.16302916311449, 45.159036190279075, 43.410133700216974, 43.59617171748992, 44.61291674644717, 43.918982782671534, 44.96115261508573, 44.37557412732033, 44.93773214278683, 44.921262110433275, 44.74862290966896, 44.565024606643185, 45.136306055130504, 46.52288352289508, 44.64853578998197, 45.93943095976307, 45.93344542288011, 45.83318571890555, 46.981322303895034, 50.92721493013444, 52.00711796360632, 53.82617596657046, 52.272074068746264, 53.26846591887936, 52.01646104935677, 51.956601758157056, 52.79024270273025, 50.48092372955815, 48.310374290712424, 50.043912856809555, 47.81996819280809, 46.31979888485324, 49.44070723748977, 52.09148030127249, 55.75931610599641, 59.4499408814215, 59.94628937013688, 71.07168443741338, 70.91722150002757, 82.55987521140807, 16.268216602263912, 1.2662237065453685, 0.6509057468464298, 0.2527906748676493, 3.466932494794169, 64.09898111897131, 72.91690857179704, 64.16251959339266, 60.23717234211584, 38.9488612451861, 37.608603046786406, 56.17821739565942, 55.887012789326334, 67.50665003253569, 48.08972527903896, 1.6207868485681474, 0.062318318523466594, 0.029450285233437058, 0.020273591864914186, 0.045447943942441095, 0.038068525403017, 0.08327615522449056, 0.019683723315416325, 0.31951897086635717, 0.1327521741510399, 0.11414946026859746, 0.16522635014787798, 0.18638030535751776, 0.15312913234435743, 0.14256476454677122, 0.3244520255154179, 5.6906295591785065, 72.84494876861572, 76.9693680732481, 65.90516198065974, 47.19517384805987, 20.748959702830163, 36.33005157593758, 55.1294344471347, 72.11294820231777, 83.07466276230352, 55.20032736562914, 1.5716133194585002, 0.20768905629313764, 1.9432391394530575, 2.516311517646236, 25.245694306588945, 74.27808869269587, 68.55558595349713, 77.39278008860927, 70.30321367325323, 75.6152403739191, 64.68088434588525, 53.11887456524757, 53.56975493892547, 58.6156488233997, 61.084416066446614, 63.093963976829286, 64.29285995421871, 61.404873709524836, 60.79129342109927, 58.219560038658884, 58.31690542159542, 57.98774796147501, 55.42670303775419, 56.331911548491455, 55.199185955908995, 51.43827230699601, 47.73705320973551, 48.25014237434634, 49.92286459092171, 47.98548829170966, 48.03686741859683, 46.552426815032966, 45.4693623512022, 47.29522958878548, 47.67284401001469, 45.40058751260081, 47.41401856945407, 46.978098115613385, 47.55971108713458, 50.1867106653029, 48.26572202867078, 48.517557805584325, 47.39537554402506, 47.47155973988195, 48.083206299812566, 47.04852034968715, 48.5819435119629, 47.07500027072045, 47.72292483237482, 50.43466329574586, 48.73246054495535, 47.170282486946356, 47.67969639070573, 47.23545658972956, 48.5816454118298, 46.92515396302747, 46.395688902947214, 49.089945362460234, 46.74958475174443, 46.52929267575664, 47.8244161605835, 51.598826685259425, 51.20060805351504, 49.67848131733556, 48.67261694323633, 49.74905652384604, 51.86217069625855, 58.68705165001654, 62.827646809239546, 53.591445645978375, 54.60929286095404, 60.41524402556881, 55.99086538437874, 53.01992101054038, 50.76496216558641, 49.12941617350425, 49.619798737187544, 50.65983087785783, 46.672878880654615, 43.968490938986506, 45.416633928975756, 43.509918797400694, 46.3653140683328, 45.851769908781975, 44.62606845363494, 49.04115499988679, 47.745066611997544, 47.82208235033097, 46.53499580198719, 47.10945829268425, 44.32659156860844, 49.2730337573636, 49.26104307174683, 46.787353254133656, 45.95133535323605, 49.167871090673636, 46.52888082688855, 47.42238106266145, 45.939230918884284, 45.911511528876524, 47.5829589751459, 46.72707034695534, 47.992336750030525, 46.92695433093656, 48.388531438765995, 46.61935421728319, 49.04732488816785, 49.75346526791973, 48.218810481409875, 47.68263816833497, 50.39343918523481, 47.195295441535215, 50.69849760301652, 55.124739370038434, 54.39168368616412, 55.65256095701649, 57.04761858909362, 57.9298145540299, 54.78135155093286, 55.646367534514404, 54.748183988755756, 53.08409883129982, 50.448575942747055, 52.45280119680589, 51.07948526259392, 49.63167959643949, 52.80779530925136, 56.24985948685677, 59.83276028786937, 61.70405249441824, 65.52016565876623, 74.43839596163842, 75.22239931168096, 86.84068725955102, 18.12832024789626, 2.1318116207276625, 1.7211390959639705, 0.22043217814737753, 4.626751859341899, 71.21765936574629, 78.12285084878245, 71.92318393338111, 82.825968803898, 63.95414367798836, 49.645345134119836, 65.23059275842482, 66.39638393155991, 73.59783987845145, 59.33533706972676, 3.060577886719858, 0.30877323941357676, 0.09411631467481775, 0.18765974879985858, 0.17922669889465456, 0.18751880394354944, 0.1703852015517412, 0.22029074299479687], [0.03709907943923627, 0.04046993525398355, 0.031475825535674254, 0.025903397735448617, 0.062195349920300715, 0.019797096667330594, 0.06957960630496664, 0.06466197300582163, 3.2981602607234835, 51.98032033058905, 54.040121647619436, 42.60818158426593, 36.82284639727685, 24.865291080167218, 43.69383873478059, 49.25789340849846, 61.139897992534024, 67.80762918533819, 40.27637958526611, 0.4196663663512276, 0.07214819186276968, 0.08197598910379796, 1.0451744905402585, 34.13547761978642, 71.89943790435791, 62.97653605861049, 66.2743668402395, 64.18728543866065, 63.32595256067092, 53.6520266532898, 51.03503304143106, 55.042157788430494, 60.863770977143325, 61.903814884924124, 62.02401591885475, 59.654684682046216, 59.631723127057484, 61.13105697016562, 61.00336813157605, 62.31215323171308, 60.63719134176932, 58.249738754764685, 59.30657432925317, 56.36183531053605, 55.054458341290875, 49.73040957604685, 46.66421828731414, 44.20482550897906, 43.47077746545115, 45.55675668101157, 43.46758857850106, 44.67668271833851, 42.84504959660192, 44.01323733791229, 43.828038707856216, 43.18637424899686, 43.2234759484568, 43.53118196610482, 42.20354987728981, 41.92581076775828, 41.83094824514082, 43.64431488898493, 42.45552293715939, 41.43078804016113, 44.17625104227374, 45.006503059018044, 44.650308701299856, 43.62120820629982, 44.70422167931834, 44.537528791735255, 41.595284400447724, 43.5448710380062, 42.8448966241652, 41.37626709476594, 42.64408696082331, 42.67332430808775, 40.3578785927065, 41.53523291310957, 41.942418083067864, 46.5285905714958, 48.160190659184615, 49.54570908700266, 47.64610913492019, 48.47050113062705, 48.68760431966474, 51.1954697485893, 54.01004099076795, 57.09767587723271, 47.83789734686575, 52.92079094917544, 55.61891486567836, 48.20337595478181, 47.20740772062733, 45.097831526110255, 44.88690607009396, 46.804807801400464, 45.558121665831536, 40.0270894265944, 41.62984048166583, 40.616551060830396, 40.05229065495153, 42.423182995088645, 40.28921750284011, 41.061026204016905, 42.5542607615071, 42.68209080542288, 43.23572551050494, 41.71789769203433, 42.979728098838564, 45.15400378934799, 44.2954832507718, 42.53940282329437, 44.4451726636579, 42.910713995656664, 44.15797671964092, 42.49250696551415, 40.244031798455026, 41.53045546623969, 42.531118777490434, 42.65374775855772, 43.04556900455106, 44.024612211412006, 42.14735800220121, 43.17969053022323, 42.93939436635664, 42.55215837109474, 44.11342643922375, 41.82113055259951, 43.70497826606997, 43.687182472598174, 43.57202560670915, 41.93785636655746, 43.231920811437796, 42.76377416426136, 43.678910193904755, 44.487518572038226, 44.33710744304042, 43.50120721324798, 44.30867025929113, 44.111629993684836, 45.1794207480646, 43.00030093039236, 47.391872867461174, 48.51312552728961, 53.4575084717043, 58.40255037430794, 60.97089482891945, 62.010813220854736, 64.64750889808901, 63.593634713080625, 68.35203847577496, 67.92233497865739, 76.0303448092553, 20.885977898874593, 0.561117239056095, 1.1369718034421246, 0.08886555570267862, 0.5532896590809668, 46.08120502964143, 72.52868021688154, 57.326310834577015, 54.94952709444108, 28.904381182885942, 11.017999591365939, 25.895821279095067, 48.430183087625814, 54.8545390559781, 53.39293449155746, 4.1588939966694, 0.13524909984440575, 0.11048702372898979, 0.03732565760372147, 0.04798322382773604, 0.02719363918708217, 0.07142056155228807, 0.04391426273110894, 0.0053185098729426825, 0.016631960358110168, 0.062186371369828145, 0.03321523199819269, 0.08258829253815836, 0.11964919781612775, 0.044783243924499526, 0.18347776675176236, 5.291809333908943, 64.8323505924594, 61.37564028463056, 52.93366809045115, 41.95073350783318, 21.807140650287753, 35.45226435507498, 53.68273488936886, 67.34489148662936, 76.71365307223412, 43.47942629168111, 0.3022336064567489, 0.05757974678530328, 0.399295904583508, 1.5197669402245553, 37.18923891744306, 74.10766955344909, 66.8128925754178, 66.5363262545678, 66.50027967268421, 66.46530782022785, 57.03521213223858, 52.962677940245605, 58.15383288168139, 63.11659213035338, 64.00268300887078, 62.97310006233954, 64.57535297639909, 62.6168429466986, 62.35234183649864, 62.66133439156317, 64.86552599937686, 61.04261928989042, 60.6209291950349, 61.092468692410385, 57.50072294665922, 55.53667845264558, 52.21211671829224, 47.61544404491302, 46.76272469182169, 46.4847816190412, 46.82305858981225, 46.292232467282204, 46.542628734342514, 44.84126537076889, 45.364823341369636, 44.755804769454464, 45.694471097761586, 44.63546645256781, 45.38731421193769, 45.21513000611336, 44.149194532825106, 44.07584228823262, 46.423086658600845, 45.484898859454745, 43.34027628744803, 46.007052621533795, 46.12418636198967, 46.00176134417134, 46.543978029681796, 44.96036421868109, 46.02127121340844, 43.741754408805605, 45.6905016591472, 43.73985990401238, 43.67971820216025, 44.42885952611124, 42.52388984926286, 42.70805689596361, 43.029604957949736, 43.7292302808454, 49.38357007118964, 50.67605380089053, 51.53456649472637, 50.14569836278116, 51.07899104395221, 48.90885345397457, 52.90841587128178, 54.7105606140629, 60.05557837024812, 50.94183752613684, 55.207564138597064, 58.48750498987014, 53.12417760972054, 50.17683021483883, 48.41276776406073, 47.286682744180005, 49.88211508720152, 48.216151114433046, 43.157203582025346, 44.32433620575936, 44.015131842705514, 44.368482482048776, 43.77485136831961, 43.746190609470496, 43.217588470828154, 44.83451497170233, 44.03476722778813, 45.06853534329323, 42.464524776704856, 44.55302607628607, 45.81150285659298, 46.47132788935016, 45.94567929544757, 46.120632694613555, 43.410471024051795, 46.20791327568793, 45.602299321082334, 43.45294244827763, 44.67414102246685, 44.75668730274324, 44.75841706798923, 45.689638737709295, 46.40804829136018, 45.12255030293619, 45.56474262668241, 45.24522243007537, 44.17135592429869, 47.44112606971495, 44.81851170139928, 45.04480500375071, 45.05429321719755, 45.971751289982954, 43.60118058419997, 44.793506591550766, 46.138636373704486, 46.59437264165571, 46.47401471291819, 46.431962982300796, 46.70508153976933, 46.551183423688336, 47.12791696671517, 46.50928466550766, 47.008633767404866, 49.8828838717553, 52.590182212091264, 57.89472110809819, 60.82596717342254, 65.30861262352236, 64.35488831612372, 67.19740252340993, 64.77498592868929, 70.57395135202717, 68.44502218307989, 77.86551983125749, 23.077968974267286, 0.7500427949332422, 1.1708527466943188, 0.10294511027994657, 0.5261331904799708, 49.456365339217655, 76.77176690870716, 65.23762949051397, 60.28165594224007, 40.716873522727724, 21.754761319006644, 32.80088136273046, 56.53456080344416, 62.49254695830807, 64.47594442675191, 6.336392404571657, 0.28231642359206754, 0.14831736473546875, 0.06104602268145931, 0.05804986047047762, 0.02301931801822878, 0.019916977936161623, 0.034160565344556686, 0.18581398252037265, 0.09774299023012001, 0.14423578617072877, 0.14408832956706324, 0.2228487871827618, 0.12858997249314863, 0.17383553898863255, 0.4567991383373738, 8.794935499468158, 80.04262355066116, 70.84011554718018, 63.14512737335698, 48.90077729378977, 38.49137167776785, 61.844320374150435, 65.56524153678649, 72.41283693621236, 82.70944303081882, 49.22146635670816, 0.705346344940124, 0.2133583827244659, 0.7887622882281581, 2.765197672190205, 40.083583324186264, 79.02692579453992, 67.80282035950692, 70.08523187329693, 69.53427222467238, 68.82579803466797, 60.45729183381604, 56.95711381973759, 60.748386613784305, 65.2645722512276, 67.67245646445983, 64.42412207203527, 67.76947236830189, 64.91348481947377, 65.93278331141319, 66.91442704969838, 70.02808293988629, 63.94744034736388, 63.86149337214809, 64.11646704519949, 60.577830191581484, 59.155127694529874, 53.96122709397347, 51.010749647694254, 48.861333939336966, 48.23771238327027, 51.50356015851421, 47.22164200198266, 50.114864610856586, 48.16494457183346, 47.63272208552207, 46.731137844824026, 47.172832027558364, 46.32159925276234, 48.3261892872472, 47.45363058582429, 46.38740877951346, 46.026927271196925, 49.57415019312213, 46.07407808303834, 46.035430969730506, 47.03008913224744, 49.129506388018214, 48.88876699632215, 49.41146596785515, 47.69372278644193, 48.74469049515263, 46.61864034591183, 47.23883767281809, 46.99944365409113, 46.84979738727693, 47.73011453690068, 46.56981468200684, 44.60535049438477, 46.96638591827885, 46.6161653303331, 52.39475404062579, 52.75049340340399, 53.85026324179865, 53.663774151955884, 53.85878262981292, 52.67866303843837, 56.37618726299655, 58.30424401067919, 60.938598032920595, 53.529421206443544, 58.89521575743153, 60.62580862352925, 54.661593744831706, 51.578857898712165, 51.87760130051644, 49.64145022053873, 52.50247409266811, 50.17963470951204, 46.1644494918085, 47.941345937790416, 46.481867298003166, 46.544303586406095, 46.209097831479966, 46.09083837078464, 44.810266879297075, 47.33011514909806, 48.53806003447502, 47.922471492521225, 45.86272508867326, 47.41585423869472, 49.123850330229736, 47.89030021236789, 48.65926519516976, 48.683729017934496, 45.83457031557637, 48.997149928923584, 47.67479735036051, 45.47937223988195, 47.4885396803579, 47.422961573446955, 48.809864597935835, 47.85157465165662, 49.40957930780227, 46.87236278287826, 47.286878862688624, 47.81126445339572, 46.89020564479213, 49.60734913426061, 46.57030890064855, 48.44813969827468, 48.515059255784564, 49.2174223930605, 47.59209025290705, 46.65982915509132, 48.92073039085635, 49.94872085509762, 48.78042328742243, 47.76451764568206, 49.68441978577645, 48.5213311256901, 50.243851753973196, 51.62230207074074, 49.62025373212753, 52.69380338730351, 54.002451204484515, 60.14520452868555, 64.23120029510991, 67.07234951757616, 65.73943007376887, 70.48021454964915, 70.36650503835371, 72.92389039070376, 72.36684322357178, 81.7129413543209, 26.204656939352713, 1.371188661263835, 3.530560938581344, 0.17119985945042104, 0.791661655229907, 55.90792686708512, 82.79054980124198, 71.90802789503529, 69.83627903846003, 42.289955769815755, 23.64945438600356, 42.15975269194573, 68.40536702063777, 70.41172996644052, 76.01820899594215, 9.247121041820897, 0.522568368863675, 0.3053205730693956, 0.12910469164771418, 0.14105713415530421, 0.08481585405646794, 0.18586230734663625, 0.11347957000496889], [0.029744867107740817, 0.030303684198447776, 0.05253619161404429, 0.038576001196258494, 0.0686269453276069, 0.02998298064114586, 0.06757433285876628, 0.2195600023673427, 9.870089523253903, 62.3895102162515, 53.8131772318194, 45.109657472179784, 23.208054381032145, 26.72466124257734, 35.15671768496114, 46.665034140309984, 66.05860510180074, 67.81475220957111, 34.02355278691938, 0.04754184227016184, 0.021103554285101352, 0.35342642076073155, 0.712163730734779, 42.0428817502914, 70.67378351765295, 63.66412362744732, 64.74783920472669, 57.72308603409798, 56.29315853118897, 49.600904680067494, 54.078988413656916, 57.387284078905665, 64.40101146697998, 63.246716760819965, 60.87228252041725, 59.080265337421054, 60.76941444027809, 57.559468284729995, 59.05821377231229, 58.22129372627505, 59.35352510021579, 58.21508853666244, 57.48325270991172, 56.95785514770016, 53.0588387673901, 50.85257222575527, 52.24233073572959, 46.64250796841037, 44.18038129806519, 42.89991963294245, 41.711841552488266, 43.8707297848117, 41.78288352104926, 43.6637580779291, 43.19352865219117, 42.93855497913976, 44.47048764075003, 43.29885605842837, 45.064401165131606, 44.02685580715057, 44.6007417094323, 45.996462222068544, 43.08997807964202, 43.02491380322365, 42.499629989747085, 43.73867927059051, 43.59079414798368, 43.47700226691462, 42.95502501149332, 42.68559348198676, 42.14643232284054, 42.13883469181676, 41.87887960864652, 43.096767702410304, 42.23853349685669, 41.722894791633856, 40.55452269892539, 42.75274445933681, 41.551636265170195, 45.343756291174124, 49.819486602660156, 50.99927279257005, 51.459802196871856, 52.67150863524407, 50.4501566579265, 51.90024122115105, 52.423681520646625, 60.54604722607521, 45.6200284342612, 51.87787978879867, 58.380298768320394, 49.111643914253484, 48.80371039913547, 46.72814115401238, 48.536118461239724, 45.87084047255978, 47.01654518804243, 42.53441356843518, 42.214916906049176, 40.63572360623268, 40.95417299578267, 41.145047295478086, 41.56130490764495, 42.747672834704005, 43.078689498286096, 42.32666915462863, 41.36531975961501, 43.20244027722267, 41.90417889625796, 43.058595195893325, 42.87653053960493, 43.083788579510106, 42.5813643393978, 42.94878452054916, 42.99895163505308, 42.499986925432765, 41.95365567361155, 42.696293707816835, 42.791046404069476, 43.22498213860297, 42.030753781718595, 41.41360805880639, 42.88936453480875, 42.75863585933563, 42.781973961860906, 42.68333027439733, 44.492692178295506, 43.45202069128714, 43.329352486518125, 41.95584827853788, 42.41501662038988, 42.73758842099098, 42.678474380124, 42.735089871191214, 43.966459151237245, 42.48154786325271, 43.406066202348285, 42.873627985677416, 45.552736251584946, 47.80281959041473, 50.528141221692486, 53.467286940543886, 54.159498983813876, 60.4091682741719, 62.856331102309696, 61.364834154805834, 66.1188683971282, 66.32966441492881, 69.78212679586103, 67.38367588289323, 66.75767344813194, 64.28238722585863, 76.07780548834032, 25.17797458556391, 0.20738908690550636, 0.08983793578320935, 0.08180928071059528, 0.06435284886749522, 30.81584042118442, 77.25526179036787, 57.63069852705925, 56.53161510344475, 27.19567318116465, 14.597612465581587, 23.328420154510006, 35.43206414868755, 51.54496469805318, 60.625643883982015, 15.107725531824174, 0.2585895161234564, 0.04414168359231084, 0.11011992971743308, 0.06485619927726446, 0.05645976454440144, 0.08493829022852645, 0.018885095806552038, 0.026803043513228337, 0.037636903805598136, 0.05336000043297968, 0.0434860808684701, 0.04366208956907353, 0.017093886478593754, 0.04733328632409534, 0.29368694571237414, 14.36385783456987, 73.66215105979674, 63.17884014498804, 55.925608911821925, 33.829434687091464, 33.50556458196333, 35.21959327882336, 54.79066325772194, 71.66098133210214, 72.61265031753048, 38.830335063319055, 0.038789977214389273, 0.053545658010989435, 1.0608682613218985, 1.1314820786637645, 47.03275242159444, 73.83471965789795, 66.54792862553751, 66.7205286026001, 60.690876822317804, 56.85255912042434, 53.47444918847854, 56.77849692683066, 60.65861140528033, 65.93752937932169, 65.7072078028033, 64.60557091620662, 61.27363120355914, 64.04458568942162, 61.406748602467204, 61.48766317675191, 58.64892228957146, 61.41043170805901, 58.49420047575428, 58.95633412945656, 61.179596301048036, 55.02182029908704, 55.687140572455625, 53.20175424698861, 49.846872591203265, 46.59920107933783, 44.97994469058129, 44.47548474034956, 46.329812695903165, 45.540431776354396, 45.039250927586714, 45.15005788495464, 45.57367386356477, 46.60622604431645, 45.68291187286378, 47.05702404822073, 45.57326593706685, 47.40626796599358, 48.828817490608465, 45.729195840897106, 46.29912407167497, 45.16948146204795, 46.983483529859974, 46.96941791042205, 45.11378380560106, 44.626190047110285, 43.50694564081008, 43.71412523331181, 44.94200752627465, 43.53477877955283, 46.07686296586068, 43.503356672102406, 43.960324564287745, 43.63405789098432, 44.97137038938461, 44.68519426161244, 48.82837426277899, 51.95604085922242, 55.56436646369196, 52.04662407598188, 52.834177171030355, 53.832745936609086, 54.72680707131663, 54.14460574426959, 61.69876513942596, 49.53371447901572, 53.032460827981275, 61.33756975973807, 52.182506745861424, 50.44334350093719, 49.88238180837324, 52.08811490766464, 50.450231182959776, 47.873583070693485, 44.65178743485482, 43.8914163651005, 43.15079442916378, 42.83254900286275, 43.92040268067391, 43.059324756745376, 44.46169760919387, 43.03653970841439, 43.21113224952452, 43.12340059588033, 45.73231020281392, 44.03012706387428, 45.84560786524127, 44.368447180717226, 45.065420981376406, 44.87907701923002, 44.277314832133634, 44.86523497489191, 44.22237027075983, 43.06111335754395, 43.2862691725454, 45.256205066557854, 44.42932236579157, 46.05277569063249, 43.963038844446984, 45.40145435640889, 45.37344078863821, 45.63233683186193, 43.517171259849306, 46.62259409504552, 46.484185418775006, 45.61295640084052, 44.29079209604571, 44.868937692334576, 44.46196433036558, 45.07564267804546, 44.88152065584737, 46.54074207428963, 44.53104903621059, 46.517666770565896, 45.59728260963194, 48.526649859643754, 50.675794924459154, 52.12894285878828, 55.433645632959184, 57.78504771571006, 62.85158111203102, 65.99018327651486, 66.26557288631317, 68.05884915013468, 68.06000232696533, 72.15094027980682, 70.46747469132947, 70.94745512931578, 65.96566846293788, 79.12929181129702, 26.893550657456924, 0.38447430958190276, 0.6554629894033556, 0.23204216403105568, 0.06744255041403156, 32.570267569634225, 83.44047869405439, 63.579157244774606, 64.56099317919823, 30.89400149160816, 21.49466306932511, 31.81415423270195, 43.68628424982871, 58.52367316522906, 69.87593420090215, 20.22681378549145, 0.16714170785440555, 0.07398815885666879, 0.009488624261481868, 0.08053369069051358, 0.06601558142011205, 0.05023559510347344, 0.0360729084951022, 0.12039360545215108, 0.14210904948413372, 0.2758594055569941, 0.13568409988957067, 0.21760235660739485, 0.13842002969355355, 0.17338570748125354, 0.4916592645308664, 21.443697752491122, 86.47713845775974, 71.23839301447715, 67.6933313185169, 39.16776087976272, 40.28415764531782, 47.788114624638716, 62.806928849989376, 77.98878423629269, 79.33325506025746, 43.3541654002282, 0.20845935770100166, 0.140456888944872, 1.9677126455691554, 3.55451240174232, 50.20270216849543, 74.82734603266563, 71.3338948834327, 69.38943478368944, 63.91692430742326, 60.250555469143784, 54.719107458668375, 60.121423198330795, 63.02128637990644, 69.41128238554924, 66.78726380871188, 66.2035680586292, 64.82032460551109, 66.70145803882231, 60.94398736953736, 63.63058344010384, 62.89204036035846, 63.61933800481982, 61.74754373488888, 61.39302815160444, 61.1632792411312, 58.264894793110514, 57.59647192493562, 58.238881634127715, 52.285088492978005, 51.11024056711505, 46.54419768241144, 46.21276132522091, 48.68383099955898, 47.50824174573345, 49.974149580924745, 48.47690243874827, 48.50661831517374, 49.9853204911755, 48.513435394533225, 49.000005414409024, 48.3514807301183, 50.43030946485458, 51.45189469860446, 47.634208663817375, 48.07203931193198, 46.663857429258286, 50.519637523158906, 48.76056040486982, 49.03676979003414, 46.60067981289279, 46.00602496054865, 46.4963722229004, 45.58660199565273, 46.16866996211391, 49.414223394086285, 46.241116139196585, 45.23502426762735, 45.65713013372114, 47.400655054276996, 47.12598716059039, 51.95891203418855, 53.63042223838068, 56.55941294085596, 56.63192187586139, 56.820387840271, 57.47229753002044, 57.973901994766734, 56.933971835720925, 64.20438697261196, 51.39363573443506, 55.48519734413394, 63.136184369364095, 55.84520816802979, 53.27444361102197, 52.44795706964309, 54.118392544408, 52.636564239378906, 51.20977071023757, 46.968268655961566, 47.36825627665366, 46.18373578594577, 44.305477449970866, 45.21481621649958, 44.942619416021536, 48.87437189778974, 46.983530598302046, 46.17126657116798, 44.22650444892145, 47.035235281913515, 47.38859768836729, 48.74775386625721, 46.67986069956134, 47.11010940613286, 46.50415812769244, 47.48313465426045, 46.195173417368245, 47.961283345376295, 46.23750363626788, 45.697342272727724, 48.807118938815215, 45.58775909485356, 46.52547228720881, 45.45972116531865, 45.87336647895075, 48.619174649638516, 48.385217035970385, 45.50211021977086, 50.28318135969101, 49.53985691070557, 48.24909117914016, 47.40550310380998, 46.862031259844386, 48.22791038020965, 47.25288368040516, 47.20154377721971, 48.891057660502774, 47.84039981903569, 48.14059057543355, 47.569458177012784, 50.696799216731904, 53.974998535648474, 55.362258495823035, 59.02291636313162, 59.419605270508804, 65.58885420522383, 69.27938876613494, 67.55627585995582, 69.88927025948801, 71.73094857123591, 75.93584706706386, 73.56266406274611, 74.47720389212333, 70.11921528846987, 81.20407658238565, 30.666311825475386, 0.8225941405661645, 2.358996036552614, 0.3104100628725944, 0.19545294674894503, 37.721924243434785, 89.03910513847106, 70.18420896222516, 71.99321393043765, 39.91050874033282, 26.910312906388317, 37.150085818383005, 56.49335238241381, 66.68046551366007, 81.48770316954582, 26.335181651576875, 0.4361621086155215, 0.2710997012834395, 0.22978556011953663, 0.10765502649930217, 0.16116761632504004, 0.21767272944411925, 0.14576039307059782], [0.05136984190152538, 0.09519193276402452, 0.013499123273387313, 0.03148735515893467, 0.06391649667714393, 0.07151519639357444, 0.03445262104393013, 0.07890209961201876, 20.464227007281398, 65.38920164108276, 49.52165711310602, 43.86670543301491, 12.127676356223322, 32.25376171450461, 41.00514419617192, 53.00811075395154, 66.64817656240156, 65.39347310220042, 31.498475997678696, 0.011985663910426441, 0.034704123879031795, 0.7458980141147491, 1.0301323235034943, 45.25684833526612, 72.65963246745449, 59.67102135381391, 60.346100484171224, 54.29955113318659, 54.9092718093626, 52.36845847099058, 60.89143937633884, 61.08607915139968, 63.48998608127717, 60.59357066308299, 61.93687654310658, 59.108447567109145, 60.20928821256084, 59.93909182087068, 62.458139927156516, 56.84101950737738, 58.94718323984454, 57.13329099839734, 58.9444689596853, 55.362897842161125, 53.90244253220097, 52.84578346437024, 52.9318481106912, 50.077947262794744, 47.61831521987916, 42.129236652005105, 44.21450591856434, 43.56100766889511, 43.61369294504966, 41.756752690961285, 43.730591343295195, 42.972004951969275, 42.92352837900962, 41.487372152266964, 42.360629035580544, 42.56476879119874, 42.29685914131903, 43.347305174796816, 43.50576500738821, 43.56547917089155, 42.403284811204486, 41.764397390427135, 44.944831632798724, 41.71644641507057, 43.633159668214866, 43.575418456908196, 41.328394566812825, 42.201722052789506, 40.54243003168414, 40.29002158872543, 41.617924321082334, 41.09267580893732, 43.0626509266515, 41.79362689295123, 41.81337994913901, 44.29443990030597, 49.6888755982922, 51.19701124006703, 51.74670788549608, 54.54279691942277, 49.27819951888054, 56.16810160298502, 53.155988031818026, 58.869198676078554, 44.30948611228697, 47.19508363354591, 56.5057784511197, 50.3975498291754, 49.68955024596184, 45.438010846414876, 49.08948644515007, 49.768876260326756, 43.45173043589438, 41.571554060905214, 41.54496039113691, 42.027333474928334, 40.63835943898847, 42.21598379073605, 40.73953697758336, 40.67572785962013, 41.666612702031294, 42.60211367760935, 43.416480095155784, 41.51899430059618, 41.55262470245361, 43.61774475343766, 42.33045816421509, 42.638905509825676, 44.98576156554684, 42.860597871964984, 41.09133043596822, 42.04250520275485, 40.69270387772591, 42.853286573963786, 43.399041237369666, 43.27792629118889, 43.79809925633092, 41.65623018818517, 42.82928559087938, 40.61554693406628, 42.62152940996232, 42.11122120580366, 41.97400100769536, 40.31988259284727, 43.31567518172726, 42.138826847076416, 42.64666788039669, 40.78132983176939, 43.63779590975854, 42.36961126327515, 45.32611347013905, 44.9352139811362, 46.47457168948266, 48.229149849184104, 54.46634600239416, 55.090234279632575, 60.73101835866129, 58.4934473806812, 65.37474378462761, 62.15387775051979, 64.37112692863711, 63.27434201394359, 65.88635029331331, 58.59715092566706, 67.13339728693809, 67.9462065235261, 79.09954455591019, 74.17276520882884, 75.06784223741101, 23.10090111147973, 0.014475139398728649, 0.12264739782098802, 0.9103930873736259, 0.13973451399755094, 17.39062047773792, 74.80505912534653, 63.03348495114235, 60.63186084070514, 55.69517358656853, 20.39017265842807, 11.937945427433139, 37.08061279789094, 48.429359389889626, 61.00749054262715, 22.581795031024566, 0.12160720363739999, 0.06118281917165845, 0.057353452073350075, 0.035605874483383475, 0.02958023098237332, 0.04494870742482524, 0.011575019715594189, 0.05115097824243769, 0.0354892069533948, 0.021761202463699926, 0.02419103417665728, 0.12409604710316467, 0.05721146533746393, 0.05112594248907221, 0.08430326462633188, 26.14582727032323, 77.54345401640862, 57.77417098322223, 51.31554526667441, 22.78680947519118, 37.038145296035275, 38.7171236930355, 61.26588844483899, 70.64662502657983, 73.93878798330985, 33.98985962713919, 0.0892239086510193, 0.026463871491291834, 2.4758431988377727, 1.7132014444758816, 48.741187818588756, 75.20443485629174, 62.38381101239113, 61.37776620926396, 57.339952838036325, 57.21896340770107, 55.34551389755742, 63.443058844535585, 63.49357112761467, 65.9994165359005, 63.88845574471259, 62.066989406462646, 61.24789261048841, 63.14408402289114, 61.5320683294727, 62.84589367528116, 58.43430588322302, 59.73269278003324, 61.271269936715406, 61.836420720623394, 56.834080834542554, 56.44965717869421, 55.01028460841025, 55.53087334479056, 51.8199424589834, 48.09152956931822, 46.59858918959095, 46.24067683373728, 44.17927911204677, 44.98960941068588, 44.991613741843935, 45.32654100848783, 45.49117072936028, 45.72821132598385, 42.9823011736716, 43.598309409233835, 43.54649489925754, 43.12555397710493, 44.901010913233605, 46.015819118868926, 45.205108350323094, 45.167861523166785, 46.234765821887606, 46.37339415088777, 45.31454247813071, 45.87111503847184, 45.36071661979922, 44.267865842388524, 45.16885388282038, 43.08104684275966, 42.79996587384132, 43.12955087231052, 44.18044013361777, 45.01216696154687, 45.47057436358544, 43.24190324352634, 47.971803142178445, 51.43863708742204, 54.27543247899702, 54.44762845193186, 55.52827673573648, 53.38277947518134, 55.8264906175675, 54.79475821218183, 60.390219303869436, 46.63992312646682, 51.062626915593306, 60.08725935412992, 51.706864449285696, 51.28509590702673, 48.889363196588334, 51.51543317302581, 51.23766660690308, 46.09747109874603, 42.97447212280766, 42.65142963778588, 44.42235623636554, 42.30565309524536, 42.671645533654, 44.52338472489388, 42.778906668386156, 44.888106315366684, 43.228516194128225, 45.47451242323845, 43.57047627049108, 42.83174491697743, 44.6071743965149, 43.86943148028466, 42.94451305943151, 46.52682158254808, 43.512876264510616, 44.59918845084406, 44.17188544427195, 41.54239516104422, 45.21281188534152, 44.70785771646808, 44.86616457662275, 45.55081429020051, 44.58609557920887, 45.35062436134585, 42.36910135515275, 44.82630937330185, 43.365869752822384, 44.71734200754474, 42.9555662985771, 45.32121050742365, 43.952287627804665, 44.82860395985265, 44.650261632857784, 45.04926081626646, 45.90977391889019, 48.202873891399754, 47.84726396683724, 50.11739453961773, 50.84759081563642, 57.15098873261483, 58.182454416828776, 62.86391304385278, 62.29314150348787, 65.92366772313272, 65.49507425677392, 66.09138827170095, 65.473018769295, 67.58378736434445, 61.177799855509114, 68.62360769702543, 66.78151361403927, 79.01025572130757, 73.97521895747032, 76.11989252028927, 25.443491589638498, 0.11774640395155839, 3.039915085800233, 1.4707977420860723, 0.1834667657291697, 19.285278243403283, 81.63654142810454, 67.1813129609631, 66.2722566050868, 53.41528023442915, 24.679011837128673, 20.774686528790383, 44.37466413744035, 53.43025192137688, 70.28253493770477, 30.059223059685003, 0.2886782628634284, 0.02430493804445911, 0.0205498393399701, 0.011385497224006441, 0.009955614223144948, 0.02406462200827176, 0.03995865200375838, 0.16738549235367006, 0.11486125554168418, 0.07881753116605744, 0.17047466529953867, 0.18742606133943607, 0.1643486125695129, 0.10720802185636376, 0.1654607883744663, 35.37133016893941, 86.34147936298002, 66.67960259222215, 63.03234746379238, 24.46488964942194, 42.052448411141675, 53.43275831591699, 69.70090235433271, 76.5551265593498, 80.266308476848, 37.067912163272986, 0.2690332557164854, 0.2257088079087196, 3.0059446634784823, 2.763455404389289, 51.437126974905695, 79.6774430428782, 65.4824677590401, 67.56772918085899, 58.62988702712521, 60.90105702800136, 58.525414697585575, 68.60564324163622, 66.19329144877773, 69.2652133203322, 66.78738147981706, 65.93752937932169, 63.00745610267886, 64.48305176150414, 63.996211098086455, 65.46711560218566, 59.48209647209414, 61.08561238934917, 61.664095309472856, 64.88048984158424, 60.566827943248136, 58.15618630378478, 58.904492162889056, 57.81408502209572, 56.15816623933854, 52.106346084225564, 47.97853392939414, 48.370684654481956, 46.73255382045623, 47.195064021695046, 46.762320687693936, 49.2495426824016, 47.36909174150037, 48.753762937361195, 45.44906016319029, 47.07639271213163, 46.19292589925951, 47.296516126202, 48.640622169740745, 48.722599706342145, 49.30000397466844, 47.2200926657646, 46.667426786115094, 48.78025462550502, 48.25693591948479, 48.170369209781775, 47.761285612660075, 45.92753048866026, 48.757061650676114, 46.064880124984256, 44.55532066283688, 45.48078821551415, 46.536815781747144, 46.29609600190194, 47.9195571714832, 47.25011056469333, 48.951317033460064, 52.87549541842554, 57.64917289057086, 57.72681228576168, 61.32162140261743, 54.70843076705933, 59.361554191958525, 57.93934591354863, 62.40776492703346, 50.879409082474254, 53.094340139819735, 61.32791680674399, 54.70072330967073, 53.32153950968097, 52.03788503523796, 53.62833945981918, 54.31313037872315, 47.529897151454804, 45.307293938052275, 45.38908712325558, 48.52794424180062, 44.87573908221337, 46.00778610475602, 45.88232517242432, 45.43021317451231, 47.05497657099078, 46.155188775831654, 48.57687188733009, 45.723371121191214, 44.73951908849901, 47.51735733401391, 44.514178922099454, 46.908138721219956, 48.40095750747189, 46.084566500879106, 45.843297589209776, 47.32437672153596, 42.966176309893214, 48.115173616716945, 47.1103016022713, 48.26255667594172, 48.91493312774166, 46.39252747258833, 47.6763427642084, 44.42336036312965, 48.623740288519095, 46.413053235700055, 47.84196876710462, 44.925702233468336, 47.29827727040937, 47.1086581291691, 48.17053394932901, 48.59003928399856, 48.182869803520944, 47.63141985862486, 51.834141439007176, 51.09211137217861, 52.99743798471267, 53.92943236135668, 59.271218084519916, 60.010710377847, 66.78776587209394, 64.66426918583532, 69.3727803999378, 67.33070035134593, 70.39466765619093, 69.50802372347924, 70.95585684622489, 62.64630386906286, 70.58130971847042, 71.07897220119354, 79.05337041424167, 75.30574967784267, 78.60675365694108, 27.30443266130263, 0.21462604373453126, 5.416962850478388, 3.077907898733693, 0.34550016866095606, 22.544646263122562, 90.04870753134452, 72.70037804880451, 74.89040205555578, 69.58982083105272, 29.75493734882724, 24.849860475909328, 55.6622649008228, 65.2208613580273, 82.18158614250922, 38.614439964294434, 0.4999513695797613, 0.15623071591459936, 0.13541362488702421, 0.19859542409258507, 0.08293824150196968, 0.08798706735814772, 0.16870160076406696], [0.015688576705513463, 0.029067360014925082, 0.045299709759532444, 0.10131878988637079, 0.09174438388717752, 0.07609046499935851, 0.04110433266408021, 0.15010654776086732, 37.966848804104714, 67.9650652793146, 49.46373939514161, 35.89910076510522, 9.617026044476418, 51.061140337298, 53.62259318751674, 51.35184288024903, 64.88045846262287, 68.74349886371245, 27.41473951647359, 0.09322127883112238, 0.06633621219906115, 0.6685216628736066, 1.1016914320568885, 40.41683573876658, 74.79229573280581, 60.28779445155975, 62.44055594167402, 51.363641369727354, 59.563105183262984, 59.67358658390661, 65.24527811234998, 60.29526264436784, 66.16268911669331, 65.14959973673668, 61.4048501753038, 59.32501339143323, 60.2565174718057, 55.71661718430058, 58.539892165891594, 58.16623933853642, 59.988623511406686, 57.636025105753255, 56.58674009384648, 54.67296469596125, 54.11801991924163, 52.818593594335745, 52.52443152089273, 49.34076132312898, 47.57419247781077, 42.92758410976779, 44.8023005454771, 41.38080135468514, 43.17998470798616, 42.500751787616366, 44.16255020326184, 43.059720916132775, 43.587181645054976, 43.21060665192143, 43.29431395376883, 41.73492470095235, 42.150452752267164, 42.498010050865915, 42.5747198443259, 41.752261577113984, 41.534056202057876, 42.48870618881718, 45.34270901833811, 40.95748739857828, 41.21428889612998, 40.273822199913766, 39.12011584927959, 40.99682092666626, 42.60750693659629, 40.55269487442509, 42.44727811505718, 41.162929381093676, 39.62017097780782, 41.07976728870023, 41.25756832861131, 44.47767342290571, 49.41772214827999, 49.92573576588785, 50.13873223335513, 53.55601095384168, 52.07300593776088, 55.24000998466246, 52.37102370108328, 56.22015145517165, 43.03216234330208, 47.440698531366166, 56.6439635522904, 48.788758324038604, 51.50557625678278, 45.98766042340187, 50.06080650514173, 46.77602152670584, 45.68476715395528, 41.044889573127996, 41.92573624272501, 40.7385406955596, 42.55032270185409, 40.59456225364439, 41.57422127262239, 39.453642829771965, 41.18244317270095, 39.86526812276533, 41.01188675049813, 42.94886689032278, 44.08135321832473, 43.30714402660247, 43.02168569257183, 41.620238519484, 42.99011845742503, 44.37023970388597, 45.738738967526345, 44.05410843510782, 43.6810008172066, 42.55432351942986, 42.42705829681889, 42.41496562957764, 44.81082777823172, 42.124404291952814, 42.385049712273386, 42.855334051193736, 43.636105368214274, 43.81337296578192, 43.76288813929404, 41.86799110904817, 42.81722430259951, 42.35112905502319, 43.54816582895095, 43.42479944229127, 44.08444012365034, 45.10624501012987, 48.43491346605363, 47.09092509362006, 52.81396911990259, 55.754621028900154, 61.304664996362504, 62.41520566325035, 61.40124551711544, 61.50398808140909, 61.40156715146957, 63.77815477309689, 64.43449281877088, 62.59211632513232, 64.07413682629986, 62.459728487076305, 61.58734629231115, 54.96570294903171, 60.22863726462088, 67.795697335274, 81.39977931976318, 20.635591437739713, 0.18731116347255247, 0.22983406880690208, 0.029434082473838524, 0.11131802228309455, 9.591127614821158, 69.94035520861226, 63.743802655127745, 64.02341665760164, 38.757453503147254, 45.92038000783613, 19.373717884863577, 27.740527660615985, 50.21783075025005, 61.69099100174443, 29.94008302688599, 0.5490533154337638, 0.03991552508406101, 0.030905926983142575, 0.027052361082525987, 0.052670689840470596, 0.08299381351999699, 0.007167097750014716, 0.033377512403193026, 0.03430766188689778, 0.07062869476935557, 0.06068355584096524, 0.017873886559579163, 0.05704233993686015, 0.15054781440525286, 0.09168577816097007, 45.558423688334805, 76.92910886579945, 57.01909119083036, 48.363824429050574, 13.672557742364946, 49.935337728069676, 55.68727001067131, 59.9747932341791, 71.44161101310485, 74.10300977768438, 29.614577293396, 0.2934253420079908, 0.04322219805251207, 2.074855864048004, 1.6638067917477701, 42.64064311981202, 77.1373631877284, 61.904218889051876, 67.32530316998883, 52.901190865424375, 62.798146663173554, 61.046922129969445, 68.11542541750016, 61.69826699841408, 68.16734190910094, 66.75948558315154, 61.19440324844853, 59.60833795609013, 60.63080572312879, 56.11211761351555, 60.188585942791356, 60.342029063932365, 62.50640861449703, 60.864861396051225, 58.05446355573593, 57.18351694845385, 55.05494471519224, 53.70706927391791, 54.6797582410997, 52.6537089194021, 49.72513398816509, 46.00866863804479, 46.300645951301824, 43.51535912482969, 45.07607806113459, 43.83316524567143, 45.63841650562902, 44.92197205943447, 46.36666728604225, 44.81495018928282, 44.890863741597826, 42.80571606851394, 45.30265377413842, 44.869455445197325, 45.042424125056115, 43.45793954787716, 44.36345400348787, 43.52777342642508, 45.55089273760396, 42.43158863436791, 45.56813155451129, 43.58150205304546, 41.75619571439682, 43.742040741828184, 42.66761725948703, 43.33392989250922, 44.97259809124855, 42.361609628123624, 41.920295915296, 43.43709999515165, 43.454401569981734, 46.60180945550242, 50.89637725583969, 54.108657221640314, 52.13621101071758, 56.10715973761774, 54.048856765993186, 55.86216457428471, 54.16831647196124, 58.48099385538409, 46.37703018803751, 50.787574629629816, 58.37187351719026, 53.10422843502414, 53.64697464050786, 48.75637131352579, 52.39651126246299, 49.31817631567679, 49.54874107914586, 42.95247547088131, 43.687676691239886, 42.80426479155018, 42.897064147457, 41.38320968997094, 43.37432246054373, 42.053409391833895, 44.16563318621728, 43.32023297586749, 43.895664291997115, 45.99436375402635, 44.99465750109765, 44.677961411014685, 44.44825172424317, 43.596920890192834, 45.98510696041969, 46.02258520741617, 47.22576833540394, 46.90752290910291, 47.048712545825595, 44.835923102594194, 44.81984922962804, 43.9568454219449, 45.91939549292288, 44.35319700548726, 44.67628263658093, 45.54116133720645, 45.4303700693192, 45.275522739656516, 45.55447386157128, 43.647386104829856, 44.36286172559185, 44.04435742285944, 46.149034577031294, 45.9417216239437, 46.19123143534507, 46.63837379024875, 50.24826049804688, 50.288084322406405, 54.03348499728788, 57.817069945796845, 62.72178988302908, 62.86770205343924, 63.89348030090333, 63.86614530317245, 62.47235459666099, 63.33617425733998, 65.60532815994756, 62.575093238584465, 65.82474554738691, 63.062322216649214, 62.61612907532723, 57.55252568952499, 61.721809064188314, 66.70319957117881, 81.46460825397124, 22.17319388543406, 0.28576890607514693, 2.178756508135027, 0.25609193159447563, 0.15056264586746693, 10.150343852658427, 74.75675905904463, 68.390258050734, 69.82519442035307, 47.293848914484826, 41.920825435269265, 24.41638561987108, 39.307679668549575, 55.221876867355846, 72.12240111443305, 38.51486667510002, 0.46881942559153805, 0.09355111798692135, 0.059448637428783604, 0.0351663583499049, 0.05256374396624104, 0.08059119325011008, 0.02441318435294013, 0.12133483639768056, 0.1279540735507204, 0.15139141510571205, 0.19846344246499, 0.2131271927106765, 0.19474958610390464, 0.290588763572516, 0.644800516386186, 57.2438665359251, 85.68034818095546, 67.62793756300404, 54.18140149885609, 20.225091864985806, 65.01477218443348, 67.21263700915922, 65.85222567281416, 75.48938720457016, 82.69555784040882, 33.14724429961174, 0.43583511164592165, 0.10414597608389393, 3.485048451731282, 3.812213592952298, 45.104538779104914, 81.02898982263382, 64.8673891252087, 69.69985900386688, 56.17503635344967, 65.01472119362124, 63.53596802680724, 70.69755308089718, 63.916033929394146, 72.14160503879671, 68.56902399370748, 64.12519039646273, 62.04407884228615, 63.41889704427412, 59.45203934946368, 63.85724936762164, 62.264135576063595, 65.56283712387085, 64.10791627822384, 59.83700037002564, 59.088980843943936, 58.35943960374402, 56.62348877999091, 57.5427197640942, 54.63743194457024, 52.155779715507265, 47.49237183601626, 50.114562588353316, 46.22807818074381, 47.43375985853134, 45.65482770242999, 47.77946187603859, 46.10253487863849, 48.62495622327251, 47.773390047011844, 47.93343843952302, 45.19156832848826, 46.97497198658605, 46.810871785686864, 47.56224101589572, 44.74234711739325, 46.71191038623933, 44.48895415952129, 50.3013183993678, 43.40623486426569, 46.85177426184378, 44.64550772020894, 43.0552690259872, 45.15914993901407, 46.25347552760955, 45.40168577624906, 47.05356844009892, 44.50250987083682, 43.317805028730824, 46.93860377034834, 46.333840970070135, 48.337222914541925, 54.023792820592085, 55.9737560056871, 53.60853149044899, 59.660019105480565, 58.97161176127773, 59.69944284808252, 56.54145633020709, 59.82406439319734, 49.918255805969245, 55.063315053139966, 61.242067890782515, 55.76899651558169, 57.43609013095979, 51.018578698558194, 55.469048946134514, 52.85368704026746, 51.63993704703547, 45.360085118201475, 46.493187258320475, 45.65796952093802, 45.7100978205281, 42.94121042374642, 45.00070187353319, 44.80536783895185, 46.13230566824637, 45.26002937747587, 44.86361111364057, 48.41116351466025, 48.29902687380391, 47.0357334229254, 46.57142285377749, 47.44160459887597, 46.787121834293494, 48.20434870258455, 51.401005867988836, 49.54283006729619, 50.123584039749645, 47.62358688539075, 48.48080127469955, 46.77565282390964, 48.02637900075605, 45.70300225288638, 46.634725985988496, 49.01391806141023, 47.92659782594251, 47.60690504504789, 49.124925059656945, 45.44827568915583, 46.8826158585087, 46.030547618865974, 47.91470519958004, 49.42678282337804, 48.42254623290032, 50.796384273036836, 52.431616475505216, 52.12960181697723, 57.21939094604985, 60.27673336767382, 66.00682981552617, 67.45070134439777, 66.31455544502505, 65.94880227119693, 65.65025498790126, 66.43225008441557, 67.97235304309477, 63.39578251684866, 65.56867753305744, 64.84440403599893, 64.40528685046782, 58.77585411071778, 66.44414271077802, 67.25644988398399, 79.98352912164505, 26.012819697779996, 0.5261710045799133, 4.405571366510084, 0.2759768621575448, 0.2880695293987951, 11.471959025629106, 82.59177977038969, 73.42818952375843, 78.90657963291292, 52.1795924248234, 59.20448287840813, 29.091707698760498, 48.11413026625111, 67.76125892516106, 80.95743794595042, 50.17802653774139, 1.0714289978627236, 0.12143932312967316, 0.3012001232033776, 0.07401877939100228, 0.132954360076016, 0.2037146227854875, 0.17935172444389713], [0.015149234527451618, 0.21776249962708644, 0.012710991169085667, 0.019770009713547847, 0.05378032989439465, 0.05622752882059544, 0.03412823260371243, 0.5273661630288248, 43.72828498963387, 65.31952073497158, 44.415750964995354, 26.673790062627486, 18.725059839986987, 36.0954350040805, 42.81451002244027, 61.21557228026852, 60.14520060631537, 70.35548317816951, 23.14333527318893, 0.08045712020248175, 0.10427850163391522, 2.6045976963735398, 0.5138953036117939, 33.415840364271595, 77.00164133502592, 59.640081697894686, 63.324214950684585, 58.32467955927695, 64.6956403024735, 60.045870504071644, 62.18363677301715, 62.788195610046394, 65.37000556145945, 52.4971043679022, 52.75487861325664, 52.76049936971357, 56.138550466106786, 55.43485764534243, 56.899062741187315, 52.548263842059725, 53.360531791563965, 56.151309936277336, 56.37420646605953, 53.52310226809595, 54.191607506044456, 54.43777153568884, 52.945815670874815, 52.155830706319506, 50.291402647572184, 43.94193257054975, 45.247819039129446, 41.895847782011955, 43.27170148972542, 41.588843868624785, 43.12512251638597, 43.59183357607934, 42.105561225645005, 42.44858034195439, 44.18302497556133, 43.11385746925108, 42.55604151756533, 42.3981818076103, 42.292556301240005, 43.252528944323146, 42.40307692558535, 42.47762549308039, 43.48368206331807, 43.51385293468353, 45.08256173902943, 43.3263518733363, 41.214700744998076, 39.44168352311657, 44.17873782496299, 41.518068621235514, 43.422073395021506, 41.01552278764787, 38.34729125422817, 40.08383435587729, 42.77604726053054, 43.96270936535251, 48.35869789123536, 48.17799429739676, 50.4872073665742, 52.35975865394839, 52.51346849626111, 56.1034256412137, 53.26543392673616, 54.01952135947443, 44.54850358347739, 42.30082465756325, 54.22558307647706, 52.80956822056925, 51.12186254993562, 48.04259800141858, 49.24892687028455, 47.640249113882746, 47.147893598002774, 41.57078135398127, 40.94646946076424, 39.59043156716132, 42.21231245225476, 42.80395492430657, 43.48714159381005, 41.111138405338416, 43.28224482074861, 43.98485114497524, 43.633861772475704, 43.88506212542134, 43.85710739320324, 41.65719116887739, 43.76693994768205, 45.28334786815029, 45.837417956321474, 43.107926845550544, 43.490730562517726, 44.59252042155112, 41.92783471076719, 42.57469631010487, 42.75728656399635, 42.1593879115197, 44.63785909837292, 42.21303024599629, 44.60471899278703, 42.079030313799464, 42.10013266532652, 41.013671428926536, 42.27021055836832, 41.47875470499839, 42.802872350139005, 42.11339027650895, 42.6985373035554, 42.49711182809646, 45.185818133815644, 45.941678477871804, 46.60531605443647, 48.838674406851496, 53.51447697608702, 54.49967045937815, 59.76530336564588, 58.98213548045005, 62.39973583529073, 59.23581084897442, 61.5920570588881, 60.90244554704236, 65.01137541186425, 63.523840058234434, 68.60996569356611, 67.50158233027305, 68.16188981456142, 61.81143522262574, 65.10308042649301, 48.72208587584957, 67.30458521073865, 22.97361235464773, 0.2643195473619046, 1.8900098795852356, 0.594600429458003, 0.14475586794076428, 3.9926323246571327, 63.45722644559799, 66.47381151876142, 64.15095644612467, 54.28419505396197, 65.09751066084831, 14.064615311161166, 30.120249256010982, 44.05186876173943, 58.54899990943171, 44.56077667974657, 0.7209345181622814, 0.033781593139734, 0.057059814402412985, 0.045776507561846126, 0.0999004700251164, 0.026055694099575765, 0.050185841523231044, 0.02914317399113169, 0.07565288323788874, 0.07618688482550845, 0.046880716052387035, 0.09049906200098415, 0.13265845095438342, 0.06758898045987853, 0.9038473257134039, 53.96910321327948, 74.15297292893933, 52.06452577344833, 35.821073055267334, 25.53772064947313, 45.11448983223208, 49.953290416348366, 66.31925444449148, 65.004017045421, 76.97458482557728, 25.49233490420926, 0.08919943214183854, 0.14482478521043254, 2.5870399417415744, 0.8200810657393548, 34.38011584743377, 79.41214176916307, 62.46911471889865, 67.23232730742424, 61.5479225497092, 66.02239378036992, 62.621412507949344, 64.31187168244394, 65.27777102685744, 66.68378383882585, 54.834028982347064, 57.71156603290189, 55.082891602669996, 58.328641153151, 57.382184997681655, 58.05191401512393, 53.46068166917371, 55.096674811455514, 59.43304331071916, 59.77132812623055, 54.458175705325225, 56.65803701646867, 57.22411347973732, 56.31455113810878, 53.57523056768603, 50.56301109252438, 46.60056214178763, 44.63241484857375, 42.735336980512066, 45.083283455141135, 43.96918127613683, 45.29441679677656, 44.38720003251107, 44.25573395144555, 45.82857693395307, 44.76108035733623, 46.06057336253505, 44.64425648412397, 43.93701391835367, 44.1042245587995, 45.250835341791955, 43.7784364146571, 45.05000998896938, 45.92552615750221, 44.288207254102154, 47.083213713861284, 43.9655452389871, 42.424771555008434, 41.42530064429007, 43.94498417454381, 41.84112679573798, 44.44973045779813, 44.70077391593687, 41.52059070525631, 42.692316424462106, 43.004309592708466, 46.46087085047076, 48.618033239918375, 50.82077749313847, 52.48940867762412, 55.506256549589104, 54.93070363998414, 58.23142128605997, 55.371840846154, 55.37115835374402, 47.05464709189631, 46.7762960926179, 56.203351943723625, 52.864677521490286, 52.4783750503294, 50.69085682592085, 52.72495485121205, 48.79237867170765, 48.48584152037098, 44.31410274197979, 41.765734918655895, 42.043536786110174, 44.13353250872704, 46.08540981046615, 45.23435354232789, 42.840793824964955, 44.79530303708969, 44.523427870965776, 45.41401770807082, 44.771757048945275, 46.6239159337936, 42.470392642482636, 44.85139293055381, 46.72166924322806, 47.06708100534255, 45.4795644360204, 44.92359199831563, 46.02734696480536, 44.34584648378434, 44.85695092908798, 45.46697362776726, 46.05448584402762, 46.3031719576928, 43.27406275656916, 46.361560360077895, 44.430632437429125, 44.357574370599565, 44.01227635722007, 43.49287609900198, 45.873284109177135, 44.53428891397292, 44.39138127911476, 44.52575383647796, 45.010029269802956, 48.19367593334567, 49.01534972652313, 50.03353818770378, 49.57263223586544, 54.11125775306456, 57.58881153598909, 61.10723249373898, 61.5813176093563, 64.50833143726473, 60.40319058202929, 62.85616244039228, 64.24324589390909, 67.99163541486188, 65.94923373191588, 69.5218147770051, 68.61488434576219, 70.58937411154471, 64.17084678526848, 65.47662342748335, 51.19628952395532, 70.06768318914598, 26.39208151448158, 0.407779500969956, 2.7923667046331593, 2.6725564368309516, 0.2720554419342549, 3.9248424912652666, 70.42900408467939, 71.388258934021, 70.59463008757561, 53.94373332300494, 67.74442411238148, 28.85907388502552, 39.315885266950055, 51.989600658416755, 64.39708909680768, 54.648900954954094, 1.8423186386785202, 0.11884252255361889, 0.08367776915791535, 0.04857024636059519, 0.03884507808834314, 0.04406771780322156, 0.0470343588160411, 0.07999583568063476, 0.33205838994153086, 0.13738990190529055, 0.11042950584763482, 0.33979483609718664, 0.2907247288573173, 0.2697338890885153, 2.302432271742052, 64.173863087931, 81.2642849645307, 63.336499814064275, 42.69414424896241, 28.164804558600153, 46.64420243232481, 56.10684202563379, 74.5955418002221, 69.04288553422498, 83.95180671445786, 27.881170126699633, 0.29050228756762325, 0.22160184119016896, 5.70125525997531, 1.8984253247899396, 36.202001879292155, 83.78918524711364, 63.787603762842, 70.64496194162678, 64.76788251630722, 71.30611665787237, 65.52670424984348, 65.81718321769469, 67.24523190529116, 67.13284031037362, 56.705572220586966, 60.89310638366207, 59.174755234872144, 61.329760320724986, 60.569087228467396, 59.77920032316639, 54.96637759670135, 58.66347036054058, 61.85696609558598, 63.17040704911756, 58.316736759678015, 59.172990168294604, 60.44836844167402, 59.864252997982895, 56.439345267511186, 53.23691045084308, 48.24091695970105, 49.099770899741884, 45.733243726914935, 47.738355436632716, 45.60182079192131, 46.931739622546786, 48.84872351923297, 47.228690501182314, 46.81709266478016, 46.58236626655825, 48.903624934534875, 47.53457653907038, 46.40682058949625, 47.017408109480336, 48.663367994370006, 45.32099869943435, 47.951151863221206, 49.03133730734549, 47.25964976895241, 49.201442656978486, 46.35864603903986, 46.16560659100933, 42.3087792242727, 48.4612992502028, 45.49206110738939, 47.61275329897481, 47.009135830786924, 42.88897622016169, 45.41497476639287, 45.48301219940186, 50.03247914775726, 52.79956617662984, 53.439191002999586, 56.098452075835205, 58.95755790895032, 56.77482951071955, 63.64809290055306, 57.200536112631525, 58.514808608639626, 50.19146065558157, 50.80497426371421, 60.1549163172322, 56.00839445667883, 56.56457870237289, 53.50112130565029, 54.970197985249186, 51.5709896241465, 52.14161211444486, 47.239316201979115, 45.22714814832134, 42.461798729435095, 47.643477224534564, 48.153134315244614, 47.52491181896579, 44.68671221886912, 48.135942566779356, 50.075252594486365, 46.5189415408719, 47.7700521099952, 48.72010900128273, 43.89085546616585, 47.47291687996157, 49.52195521323912, 49.513580952921224, 47.51430573001985, 48.74094463163807, 49.86948897761684, 46.176310739209576, 47.23557426083473, 46.55789459905317, 47.80146637270528, 48.6202964475078, 47.208686413303504, 49.604309297377064, 47.298504767879365, 46.351754434647106, 46.903557392858694, 45.31757839264409, 49.263129772678504, 47.17754671650548, 46.79237388795423, 48.40715485234415, 46.18668148594518, 51.04858483037641, 52.220781234002885, 50.918417053837935, 53.67573738098145, 57.8162972388729, 59.40584951831449, 64.6214839719957, 64.53077523939072, 66.00034221526116, 63.864674414357836, 65.98487238730154, 66.97369406300207, 69.29431730701079, 68.67436316705519, 72.88723976381364, 72.66939916918355, 72.62710817398565, 64.88929948499127, 65.76039906471007, 54.34292862492224, 68.70593824694234, 27.14035599462448, 0.46924727037549024, 13.622635775996795, 4.696771560176726, 0.3628632450296033, 5.016987977489348, 76.07215727529218, 78.51582527160645, 76.12441109072778, 69.59345294583228, 73.99912972604075, 26.766746313341205, 46.55302693766933, 64.3029796692633, 73.47528150004726, 66.87820003878686, 3.531393461650418, 0.17443497214586506, 0.2574884639151635, 0.22805294502646695, 0.23824914628940247, 0.1709195632006853, 0.12922905836134188], [0.015317602458620265, 0.01900143008829365, 0.10897876514542489, 0.04535652667043671, 0.07677357027968092, 0.042615831799564824, 0.1153291667240762, 0.4653856050102942, 52.424109058995406, 62.64646468623992, 45.63723194983698, 34.827917160526404, 13.554557158100991, 35.61867090963548, 36.08183614669308, 62.914237053163596, 62.575916936320645, 71.90338380875127, 22.651075855378185, 0.09312557146674202, 0.03407772825730424, 1.321904202622752, 0.8265093401555093, 17.040029225810883, 79.6764781398158, 57.16561917335757, 69.13701457362022, 59.88719494112077, 64.70335952697262, 61.377334748545, 67.52374372174664, 55.8705113780114, 51.24234991688883, 55.85577111090384, 59.32364448424309, 62.33501280507734, 61.178097955642215, 58.25288449564288, 58.643619245098485, 58.27545381361439, 58.25897985889066, 53.72908553769512, 56.12369252789406, 57.30089779823058, 55.799743975362475, 52.86303404838809, 56.21439733812886, 51.95354230942265, 52.427890223841516, 48.255625847847234, 44.769866466522224, 44.87744139086816, 41.058049125056115, 40.79079843336537, 42.339271729992284, 40.371179349960826, 43.417888226047644, 40.860444038145005, 43.13292018828854, 41.80763367683657, 41.61784587367889, 42.879017322294175, 42.643110290650405, 42.65552066987561, 43.15790568628619, 41.91585186989077, 42.645287206096036, 43.95141686162641, 46.65730707107052, 43.333616102895434, 42.10904429035802, 44.38851402651879, 42.11519064441804, 40.82436999967022, 42.30684941814792, 41.2153204794853, 41.323260184257265, 39.758179572320756, 41.57422127262239, 41.91243156310051, 46.89868188673451, 49.56452861908944, 50.178693340670684, 50.18929158487628, 53.56941761509065, 51.013138371129195, 55.36206629968459, 46.949358909360825, 41.487117198205766, 44.08941368902884, 47.06258989149525, 52.53654772235502, 51.03697853703653, 51.35201154216644, 48.785851847740915, 49.298748816213305, 45.17286646750666, 42.00124186854209, 41.03520524117255, 42.56043064978815, 41.489666738817775, 42.07344093630391, 41.300318241119385, 40.72442408530943, 42.36129191613967, 41.77223428603142, 42.76290732045328, 43.43030252764302, 44.0975369176557, 42.39323962119318, 44.0079225263288, 42.1004896010122, 42.2617970743487, 42.33546310855497, 44.22926971989293, 42.47163211145709, 43.570550795524355, 42.894487150253795, 43.1078052520752, 43.77911498469692, 44.08411456692604, 42.575814185603974, 42.2360663260183, 42.98041059124855, 40.781235694885254, 40.75649338383829, 42.462245879634736, 42.46800784141787, 42.327504619475334, 41.85893435632029, 40.9983035825914, 42.3723098539537, 45.21070165018882, 44.86982414799352, 43.93874368359966, 47.185383612109774, 51.72737844528691, 56.37710509761688, 58.130059396066976, 58.54506969451905, 64.39113101651593, 62.274067017339895, 64.45042156404065, 61.063466687356275, 63.6266924488929, 60.79899303374752, 63.26879186014976, 61.90549365935787, 68.25689746487525, 66.83725833892822, 74.54420581940683, 63.276507162278705, 57.45668257436445, 26.657735801512196, 0.30876818323327654, 1.1890017986297607, 1.2628109993473178, 0.08255372665101483, 1.1210712502079627, 58.21984637168146, 69.59252726647162, 63.56708026701405, 67.36542901685162, 48.38190655554495, 19.41550289430926, 15.30961286637091, 44.57241042967766, 57.97883633644351, 56.1885489186933, 4.8207316956212445, 0.33381741974622975, 0.13739267514357645, 0.043528774948490244, 0.029345379068305897, 0.04344428694176097, 0.05368339295889582, 0.03306813162541197, 0.15497799361905745, 0.061383982369255644, 0.037938416860396826, 0.03730428375063404, 0.12325291371633931, 0.12746330230466782, 1.9279391991515316, 62.09141400552566, 70.80359828087592, 52.14743291178058, 39.73452768018169, 14.989039513372607, 34.57411627615652, 43.64782933265933, 70.42345785325574, 65.81513574046474, 79.41840971669843, 23.825633525848392, 0.1432313989367216, 0.20497774855504114, 2.1795650066867953, 1.306411821034647, 19.050708739988266, 81.29706028969058, 57.71154642105103, 71.95064052458733, 61.38188862031507, 68.0284272470782, 64.07343864440918, 69.89323185336205, 57.59022751162129, 53.96812654310658, 55.835865082279334, 62.48275672235797, 61.00468212558378, 62.222629054900146, 58.882071894984094, 60.04544688809303, 58.57205167893441, 58.6660042116719, 55.65128226434031, 59.50759187821419, 58.28647175142842, 58.24520841721566, 55.62763821694159, 57.6293178527586, 54.56979067094865, 53.991919640571844, 50.09954775533369, 48.052274488633685, 46.50821385845062, 43.6978905431686, 43.17709392116916, 44.03567721766811, 42.72001228024883, 45.57934168846377, 43.38815666014149, 44.306995407227554, 44.02232546960154, 45.17965609027494, 44.596776193188084, 43.78393165526852, 44.13720384720833, 44.10406374162243, 44.22273112881569, 44.132332263454316, 44.99315523332165, 46.78603141538559, 45.17381568108836, 44.125056266784675, 43.70648445621614, 43.930322354839696, 42.14297279234856, 43.636085756363414, 43.219675171759825, 43.7248097696612, 40.89744767835064, 42.89753090950751, 44.09013932751071, 48.79211979527628, 50.46541467789681, 51.75734143103323, 54.25857805436658, 55.72860394754718, 53.45291145386235, 55.951104317941976, 49.54042957675073, 45.461525455597915, 48.19300128567604, 51.03756689256238, 53.34922359835718, 55.14316274273781, 52.66611537625713, 51.74844549548242, 50.23508525663807, 49.08968256365869, 45.125931386024725, 43.520685703523704, 42.658446758024155, 43.43939850407262, 43.77397667977118, 44.47077397377261, 42.05395852365802, 43.60940971682149, 44.526157840605705, 45.47223744853851, 43.58857800883632, 45.48251798076015, 44.81245556185323, 44.61204598026891, 43.895381881344704, 45.280198204901914, 45.15447839613884, 46.254056038395056, 46.06170692751485, 45.27338112554243, 45.08668415008053, 43.94149718746063, 45.09245787897418, 45.69087820668375, 46.011422141905754, 44.33401269297446, 43.58927226835682, 43.71594913544194, 44.5578819705594, 44.00499251581008, 45.07325787698069, 45.4522608172509, 43.89536619186402, 43.51678686757242, 44.1022829855642, 47.01885546407392, 46.07553328237226, 46.53689815152077, 49.37212459502682, 53.88347787241782, 56.42448732929846, 61.261287504626864, 60.836353609638834, 65.41338697556527, 65.4954743385315, 64.97347747125934, 62.73900908808555, 64.5082059214192, 64.16080943999752, 65.65786830840572, 63.79094169985864, 70.75210540525376, 70.07600645865165, 76.05165896877166, 63.62689248977169, 60.67772511513003, 32.228187860981116, 0.2512795204717306, 1.8765723296711523, 1.4230316084238792, 0.09580741546327069, 1.3538184449557336, 60.10428244067777, 76.43327420757663, 68.21325717433807, 69.85139585310414, 45.98916269117787, 17.495420325186945, 23.626863494996105, 51.59268817593975, 62.29750710148966, 68.2211882068265, 8.170806977056689, 0.4897779364499354, 0.12006216517259037, 0.07932131058506428, 0.08258925780894295, 0.07417931311553524, 0.08598757021489643, 0.1418779360791368, 0.22924767446614083, 0.28019261336134327, 0.43896500982584497, 0.2030335246555267, 0.3278326183076828, 0.35080434694405527, 4.361821739904342, 74.92386771786597, 78.06966350924584, 62.959199182448856, 48.480310978428015, 19.13273334503174, 45.083534486832164, 52.92057521881596, 75.82208264258601, 72.97714833290347, 85.64954973036244, 27.340296852973204, 0.19357053082316153, 0.3650522953079593, 5.902085515760607, 1.7769361599799127, 20.60552058681365, 84.10554009099161, 62.2978405029543, 73.66569688243251, 64.55519199371338, 71.24698300515452, 65.45536810351958, 72.04935089234384, 60.59463754776986, 58.349845486302534, 58.89553739178566, 63.058450837289136, 61.79854239186933, 61.992507519260535, 59.46967824812859, 62.09167288195703, 62.45369588175128, 62.30159421120921, 60.534699809166696, 62.15402680058634, 60.17026455171647, 62.49650462981194, 59.50282227608466, 60.10163484081146, 56.2670983037641, 57.444107455592004, 52.37106684715518, 50.96074727273757, 49.197892911972545, 47.0774595968185, 44.38376795861029, 45.87966580544749, 45.02307507299608, 48.74403153696368, 45.56112227901336, 47.835077162711855, 46.684198840971916, 44.84250876211351, 47.79208014088292, 46.75537417011876, 46.95210456848145, 45.854280225692264, 46.93923527194608, 46.31343287806357, 47.803678589482466, 51.19717205724409, 48.55619707415181, 46.346925996964984, 48.7566105781063, 44.3915028725901, 44.49348057470014, 47.0122854940353, 45.682150933050345, 44.584044179608746, 43.5734062810098, 45.815201651665475, 47.607320816286155, 51.045709733040106, 53.75181959521387, 54.335982107347064, 56.859058487799864, 59.00000972132529, 56.03678849435622, 58.99893499189808, 52.26317028845511, 47.88462454272855, 51.85944464898879, 54.75031775812949, 55.8962421263418, 57.494572670229026, 57.361490572652514, 55.51006124865625, 53.42497241112494, 49.51843292482438, 46.90207865930373, 45.926910754173036, 45.75484814182405, 45.67440032958985, 47.37511650208504, 46.102342682500044, 44.625636992915986, 45.669775855156686, 48.94660234451295, 47.976474685053674, 47.81543785525907, 48.78385928369338, 47.324584607155096, 45.97871349703881, 45.04341648470971, 47.90642115377611, 48.30188628165953, 47.51301527023316, 47.596483307500044, 46.96865697060862, 46.368232311741004, 46.06628041113577, 47.55312934998543, 48.13518947170627, 47.95332093392649, 45.72507735221617, 47.151176621837, 44.41460955527521, 46.39535157911239, 46.26376782694171, 47.45239111684984, 48.340180381651855, 46.380050413070194, 46.28968684904037, 47.39537162165488, 49.097754801473315, 49.14561556231592, 48.82254169833276, 51.912800650442804, 57.972529165206424, 60.59254692446802, 63.65233298270934, 61.39550708955335, 69.15609298213836, 68.34538613596271, 69.47175748886602, 66.84689952481177, 68.21344544810634, 66.7976894686299, 68.30766862438571, 68.11732384466356, 74.18996872440462, 73.82379193459788, 78.39040356297647, 64.4994511911946, 63.33977499315816, 31.69977595729213, 1.1522087406727577, 6.0163676931012064, 2.7252203850976886, 0.2769176794155952, 1.6596770262525928, 68.36950086778211, 82.02513848581623, 76.5269874757336, 80.30122541612195, 58.88439393812611, 28.38249218079352, 27.83549216485793, 65.33034647664716, 73.63752641985494, 80.35528352183681, 11.687148098022709, 0.7875853320283275, 0.3159278571125, 0.30523832586984484, 0.1841724706032584, 0.11877775748050022, 0.22405966575587952], [0.05437772142730894, 0.024276016310097712, 0.10273815928808144, 0.1046901896235443, 0.03448969203858607, 0.08742420723842037, 0.1855150703340769, 3.4900845298844003, 64.04202045932894, 55.10322909201346, 45.52817829193608, 33.52736903775123, 21.084796959354033, 49.57538573972641, 47.84059985991448, 63.543447986725845, 63.52538547208233, 69.71412858655377, 24.291358109443422, 0.07466531929469879, 0.06771251213766875, 0.8723608055903066, 0.7451638567351526, 4.923102125044792, 69.31366243670064, 68.13083248753702, 61.4480786169729, 63.09770591797368, 64.80703953773745, 61.32845024908743, 59.61280945808657, 52.30302941414618, 60.42761125872212, 60.9330008106847, 61.05593181425526, 53.20623751609556, 55.54923395956717, 55.16961912955008, 56.1321726922066, 54.84538816636609, 56.92485232507029, 57.83130030478201, 56.26661585223291, 60.49262062195809, 66.53867183193084, 58.19025601110151, 60.04507818529683, 56.58229604844124, 56.62837213085544, 55.9252441313959, 49.08581902903896, 46.0484100926307, 45.11256787084764, 40.41620815953901, 42.79969130792926, 42.14025851218931, 40.94188813240298, 42.004293472536155, 43.3935381520179, 43.152708545807876, 44.73510642205515, 42.73912206772835, 44.092273096884455, 40.65546489530995, 41.50203397197109, 43.7856065073321, 44.416672721985854, 41.26850389665173, 42.04956546906502, 44.66974012313351, 42.39136865062099, 42.20344789566533, 40.94076241216352, 42.55101696137459, 41.46488128169891, 39.64083010150541, 39.88830420278734, 40.95325908353252, 40.58495636909239, 40.99788388898296, 45.64954426980788, 46.765031045483006, 50.731739690226895, 50.701286408209036, 51.56753009365451, 52.84272793800601, 52.778267706594164, 43.98902062446841, 44.1286648473432, 44.30703463092927, 47.71320912145799, 53.78408501225134, 53.40943198050223, 50.08474865267354, 47.85153542795489, 47.94971627573813, 44.15619988595286, 39.637966771279615, 40.35807471121512, 38.61730329452023, 41.44751694894607, 39.55385546530447, 42.56334104845601, 40.63602562873594, 43.17308133648288, 41.836902403062396, 41.595300089928415, 43.65836089657199, 43.5270752445344, 43.99503361794257, 43.933213141656694, 43.611288532134026, 41.5977672607668, 39.569470420960464, 41.09278563530215, 43.44628226372504, 43.20870822475803, 42.95355804504887, 44.22542971949424, 43.19798838707709, 42.59568491289693, 42.883061285941835, 41.27449335590486, 42.58420413540256, 41.49857051910893, 41.33953017573203, 42.03401719370196, 41.42228041925738, 40.273696684068256, 41.59136595264558, 41.92631675351051, 42.951749832399436, 42.33241542693108, 43.37528344123594, 43.08426710867113, 44.85032212349677, 44.40578030001733, 47.909221726079146, 51.899393989193825, 53.35102788863644, 52.168829441070564, 54.97568930349043, 55.589383340651, 54.36138337658298, 54.060255173713934, 54.26712097660188, 59.405896586756555, 62.00609853190761, 63.15196406456732, 64.8745592178837, 64.0135754308393, 70.1234043798139, 57.60151609297722, 34.75587890994164, 0.3039341990745837, 0.018130579640367822, 2.6169105066407115, 0.10850353016247673, 0.4910392236084708, 46.019761100892104, 71.05594788828205, 66.56003305988928, 60.23380694850799, 49.67049537166473, 42.82179778622043, 19.940633735349103, 38.082998029647335, 57.38704089195498, 58.39197958669355, 6.865678506512796, 0.17549906827269063, 0.04593177060146005, 0.02765546380091579, 0.02489914839726783, 0.06355982146135743, 0.041681668015136834, 0.0288631018221138, 0.04847917382815673, 0.07620054417319837, 0.15152800858261126, 0.09213486656306252, 0.06911547193604131, 0.34608745166370947, 5.40641216501113, 70.35172554754442, 63.26555198238742, 51.21609749332551, 41.48148859700849, 21.120008076390913, 42.643930066016416, 50.67258250328803, 70.9918563596664, 67.92828129183862, 77.37579622576314, 26.21269387583579, 0.19895761514142637, 0.0855957545460232, 3.149370296347526, 2.3548182220228258, 5.702797732045574, 72.90945606846964, 68.60862424296718, 64.43428885552191, 65.60969375794934, 69.36337455626457, 64.26083380176176, 63.579031728929095, 58.29030782945695, 64.87374336488786, 62.43337015951834, 61.613281003890506, 55.917215039653165, 57.38640546798707, 58.96889748111848, 57.983696153087, 55.791612901995265, 58.4305678644488, 59.45237275092833, 57.917298270810036, 61.40774880686114, 63.002188359537435, 60.31199547552294, 62.584597141511985, 58.603320813948116, 59.29898846533991, 56.264380101234686, 51.64067837499803, 48.3086209912454, 46.184049575559555, 43.63395983173002, 44.34917265369047, 44.65613734337592, 42.26675102787633, 43.13565408029864, 45.804058198005926, 43.113543679637296, 45.9600273255379, 45.37929296493531, 45.31930031314973, 43.16551900679066, 44.24496704532255, 43.74768895487632, 46.97681550056704, 43.18273036710678, 45.319064970939394, 46.123731367049686, 44.693580289040845, 42.66192982273717, 42.54920874872516, 44.30455961535054, 43.230885305712306, 42.34468460083008, 41.08771008829917, 41.810489162322014, 42.744091710736676, 40.54393229946014, 47.536008204183275, 49.06570511479532, 51.70776267205515, 53.137592115709865, 51.783295754463445, 53.68941860814249, 54.48377309306976, 47.078934408003285, 48.132483036287375, 47.252805233001716, 51.763934935292895, 54.8824937881962, 54.148822292204834, 51.937511582528394, 49.600583045713364, 50.17582608807472, 47.738751596020116, 41.35421552965718, 40.92886194106072, 41.69042148897725, 43.649457116280836, 42.94989455130793, 43.99690458851476, 42.5747473009171, 43.6056952322683, 44.42561180360856, 44.81327141484907, 44.3739345765883, 45.10058895234139, 45.726218761936316, 45.64473544397662, 44.8925542831421, 41.63028763186547, 41.647306796043154, 43.75609851652577, 44.19694938967305, 44.45019721984864, 44.22925795278242, 45.91000533873036, 45.18131133048765, 45.53097494186894, 44.32965493971302, 44.02998585854807, 45.52151026264314, 42.31682400549612, 43.58170209392425, 44.317295551300056, 44.083753708870184, 43.224025080280924, 43.36302211207729, 45.093018777908824, 43.98789490422895, 42.973683726403024, 45.2398762395305, 45.240833297852554, 46.65976639716856, 46.03694500461702, 50.29305396541473, 53.295000753095074, 55.52297369126351, 54.77757823082709, 57.10705818668489, 59.01049029442572, 56.543425360033595, 57.29894053551459, 56.96713939789803, 61.25953420515984, 63.39562562204177, 66.96904997671804, 67.64452918883293, 67.05698951598137, 71.24048756014916, 61.1942659654925, 42.62755809291717, 0.5633322137498087, 1.5339689846000366, 5.180931283581642, 0.04901662664187532, 0.539767716921145, 50.44483792397284, 77.40189567688974, 71.87986527719806, 65.21971994830717, 53.71663985713836, 39.159178733825684, 22.4632433537514, 44.894213445724986, 65.13983303500761, 70.83092151149627, 11.25396251678467, 0.23009459998819137, 0.04075986122892749, 0.09955262014221761, 0.09366487438279776, 0.025990270190842213, 0.03814596540084289, 0.13911795111433153, 0.11655814029396543, 0.18559984562377776, 0.2168949969833897, 0.2099079380352651, 0.2446854952722788, 0.9063186027830648, 8.152681704490416, 83.4676528746082, 72.91156630362235, 62.07149228742046, 49.51137658088438, 31.482831624246415, 62.061607914586226, 64.06161269833966, 76.82536217474168, 73.98649184934555, 82.35793590545654, 29.343592505301203, 0.3599639393148884, 0.18959861008390305, 4.540397447924461, 3.200207400706507, 7.546848587451443, 73.61825973756852, 66.65848455121441, 67.58895704823156, 66.77457886357462, 71.7406682045229, 64.90748359311011, 67.93498854483327, 59.32144011220625, 64.44797400505313, 61.642557574856674, 64.39960333608812, 57.4668062117792, 63.0582154950788, 63.093877684685495, 62.385634914521255, 58.1033205986023, 61.44560360139417, 61.481912982079294, 60.47987291889807, 63.528080140390706, 62.917786798169544, 60.46893735085765, 65.95643520355225, 59.76647223195722, 62.20385266888527, 61.781672277758204, 53.287493336585264, 49.72827580667312, 48.78277670952582, 44.86630970431913, 46.860089686609086, 45.62216220363494, 44.21634943254533, 46.62466510649651, 46.829640326961396, 46.18897999486616, 49.91281547854024, 46.65784443578413, 48.291158599238244, 44.742896249217374, 45.82952614753477, 46.716197536837676, 48.792037425502656, 45.23332980371291, 45.53218303188201, 45.906498739796305, 47.37335535787767, 44.18106379047517, 44.99184123931393, 45.572171595788774, 45.76344989961194, 44.17929872389763, 42.346724233319684, 43.742362376182314, 46.67857808451499, 44.0827456597359, 50.0647484871649, 51.06609036845546, 56.00189901167347, 54.98992750721594, 56.571129060560665, 56.75599428915209, 56.888472341722064, 50.72014516399753, 51.865269368694676, 51.09106802171277, 54.99637980614939, 56.95020652586415, 57.63377366527435, 55.23573852354481, 51.90286136442616, 52.623000683323035, 49.597425537724654, 43.21563905285251, 44.97787367913031, 45.255859897982695, 45.40371756399832, 45.14383700586135, 47.7035169447622, 46.25758224917997, 48.196488272759225, 46.09752208955827, 47.07662020960162, 48.67033020142586, 48.16345407116798, 47.39441064096267, 48.1343500844894, 47.434050113924094, 42.59582219585296, 41.96079830969534, 45.12041261119228, 47.72367400507773, 48.73796363030711, 46.040781082645545, 48.2983483037641, 48.183669967036096, 47.95810622553672, 46.77800624601303, 45.933904340190274, 47.79563380825905, 44.46114847736974, 46.16550460938485, 48.335120524129565, 46.86177630578318, 45.49822707330027, 45.79991225273379, 47.567724489396625, 47.083582416657485, 45.32732548252229, 48.114820603401434, 47.02151875342093, 50.466956169374534, 47.75253872717581, 52.33562431027813, 57.27358633472074, 60.03850429288803, 58.18754173094227, 60.124474802324855, 61.901481074671594, 59.67671663530412, 58.71372768955847, 60.18406344998268, 64.8459965182889, 67.75677173368393, 69.92140231593963, 70.62019609635877, 68.48768188107398, 74.79574741855745, 59.57255417300809, 42.594135576678866, 0.7654566678308672, 5.978137331624185, 10.724006179840336, 0.21988873069565143, 0.9840086210639247, 54.94573416248445, 85.2000774875764, 78.96547794342041, 77.20096834244268, 62.6136540597485, 62.187472851045676, 35.00483174477854, 59.311104666802194, 75.99449434588033, 82.95649743849232, 18.104795832787794, 0.6597611716678066, 0.23444982515948437, 0.24489361071778884, 0.11156020565859734, 0.2053887700481761, 0.19692948929244475], [0.022338733167177247, 0.11293891877416642, 0.06225615048841123, 0.04586746901153557, 0.09573421576210568, 0.08540295319811952, 0.27816110140373634, 8.499376081651258, 63.84330926402923, 54.66260179396599, 49.91006589704945, 30.421208796962617, 16.205334144253886, 37.61872276183098, 41.48339879128241, 65.1550361417955, 61.36259448143744, 70.41057678960985, 22.879022436757243, 0.16419453696618158, 0.06322133700333296, 2.039272489566957, 1.0877098984295324, 2.291830595462553, 33.0949826394358, 62.24331955755911, 71.02791078629033, 57.66481922518823, 61.674862215595866, 55.66965856859761, 55.58639057220952, 57.9701090628101, 58.737944403002345, 57.75979157417052, 60.332223138501575, 57.71722601306055, 60.45975900465443, 58.55050609957788, 58.19428820763865, 57.74560828362742, 57.52066427661527, 54.2871525210719, 55.55694533932594, 51.87407508973153, 54.66377458264751, 51.415036186095215, 55.61562007473361, 58.04287295187674, 56.5449550844008, 55.14595154793032, 52.53124467788204, 50.49876659147201, 44.56007457548573, 42.749728156674294, 43.719593017332016, 42.70935520049065, 42.082117219125074, 41.37163477559244, 42.72161652964931, 43.39646031779628, 42.733144375585745, 42.430086366591915, 41.563885827218336, 43.239710638600016, 40.385645051156324, 41.11778290041032, 40.39595696233934, 42.438052700411895, 42.67823903791366, 45.3617678150054, 46.06884956359864, 42.86856028341478, 41.55562923800561, 40.80523667796966, 39.756202697753906, 40.810861356796764, 39.935588375214614, 38.69896311913767, 40.11249903709658, 39.019028525198664, 44.83708804653537, 44.33242413305467, 46.43002533143567, 49.701144772191206, 52.163251830685525, 49.25133912794052, 50.55456230717321, 46.79844963935114, 43.02388221986833, 44.62238534804314, 51.073433045418035, 52.75130533402967, 50.735093316724225, 46.833637222166985, 46.32463124490554, 46.293954387787856, 41.94488525390625, 38.154683266916585, 42.01608803964431, 40.4082888941611, 40.93850312694427, 40.29836839245212, 41.57024398926766, 38.507167062451764, 39.135530764056796, 42.06729458224389, 42.33979732759538, 43.96734560689619, 46.495309260583696, 44.45895979481359, 44.06440857918032, 42.40639525075113, 41.47602081298828, 40.92446888646772, 39.74170169522686, 40.19287624666768, 43.2609228164919, 40.78210253869334, 42.97764532027706, 43.31327076881163, 42.83040738874867, 41.103281897883264, 40.66056789890413, 41.86091123088714, 39.53460447249874, 41.36539036227811, 42.312921247174664, 42.90712110457882, 42.10696151179653, 44.138768872907086, 46.98861791241554, 46.938768509895574, 44.6439270050295, 44.04190201913157, 42.683848027260076, 43.39279290168516, 41.84121701025194, 44.434821528773156, 42.96609786248977, 45.273408582133634, 45.885941597723196, 47.92668019571612, 44.48552208562052, 43.77345108216809, 44.150108445075254, 45.23481245963804, 45.09100267964025, 50.48925092143398, 56.14087643161897, 65.5299323604953, 65.61449473904025, 74.56728504550073, 61.84329271316529, 41.89500447242491, 1.728507268332666, 1.243411569345382, 1.8592224606583196, 0.12836697962014906, 0.03134681441400561, 36.52059247416835, 75.00356243502709, 60.38187250014275, 64.76587818514916, 38.40539332359068, 27.56665291324739, 15.994412610607764, 36.50749175779281, 54.008927037639005, 62.24337447074152, 16.443375925863943, 0.23024922717482815, 0.04720383278665043, 0.06710074496485534, 0.031181573079177932, 0.05559528411756601, 0.024072541442189007, 0.061698143535684195, 0.09967615948088708, 0.033876323742010904, 0.0720617005361184, 0.11193774910944124, 0.09245954994713107, 0.3245704320649947, 10.457952791644681, 72.90077978564848, 63.779547214508064, 60.35670657311717, 38.255076331477014, 16.085128207360547, 38.24578031416863, 49.9494464935795, 71.80281423753308, 66.45892220158731, 77.13879093047112, 24.583588415576568, 0.1472232226402529, 0.07241068422914514, 1.6550950850209885, 1.1524253290507103, 1.5043526383176928, 39.50597901498118, 68.00135504814887, 70.91740977379584, 59.53625655943348, 64.99575653383809, 56.72822390833209, 59.204435809966064, 60.04279536585654, 61.899374761889064, 57.31646176307433, 62.897978828799346, 60.238968787654755, 62.59991791940505, 59.630048274993904, 60.1921788338692, 59.16529055564635, 58.90735157074467, 56.54590037561233, 58.094973794875614, 55.11662790852209, 53.21928724165886, 48.16709795305806, 58.79270853534822, 58.61907305256013, 59.96290845255698, 57.29517113777899, 54.257358197242986, 51.97357385389267, 48.14860005532542, 44.259534728142526, 47.29412348039689, 43.798950410658314, 42.77186993629702, 43.03772426420643, 45.06582890787433, 44.661597282655784, 45.84622759972849, 43.96725539238223, 43.552688321759625, 43.039218687242084, 42.52266214739892, 42.828575641878196, 42.709453259744954, 44.91766921935543, 46.03611738451066, 45.13291712730162, 45.9416510212806, 43.17190854780136, 43.30736367933212, 42.466187861657914, 43.25286234578779, 41.50069644374233, 41.796007771645826, 41.4255085299092, 43.080062327846406, 41.659999585920765, 46.62024851768248, 47.358999483047, 47.37393979103335, 52.13834478009132, 52.93535863199542, 51.23783526882049, 52.79167044547297, 49.33436393737794, 47.786137750071866, 47.93615664205244, 53.05410838896229, 53.598396085923724, 52.041324953879084, 48.905284097117764, 49.60009274944183, 48.65939071101528, 46.58347629731702, 40.98123734997165, 43.94306221315938, 42.483108966581284, 41.9700276467108, 41.31160682247531, 43.6809302145435, 42.17313189660349, 41.85457660305885, 44.188688878090154, 45.234216259371856, 45.05503454516011, 46.77229919741231, 45.54932378953504, 45.91219402128651, 44.22652406077231, 41.958703764023326, 43.05289991440312, 41.74931195474441, 43.56702458473944, 45.23918590238018, 42.23390902242353, 44.25988774145804, 43.267971315691554, 44.46835387137629, 43.1096330765755, 41.87652618654313, 42.11159383097003, 43.078889539164884, 43.977496700902144, 44.12419726771694, 43.70542933863979, 44.5180973699016, 46.319543930792044, 49.147388473633804, 49.06858021213163, 46.524064156316946, 46.324286076330374, 45.23387501316686, 44.77319263642834, 45.73816237911102, 45.20509658321258, 44.9348609678207, 47.15769167869322, 46.76982025946341, 47.70747461626607, 46.46795857337214, 46.90591473733225, 45.169504996268984, 47.140064547138834, 46.787580751603656, 51.59375506062662, 58.72902101086032, 68.89184290362944, 69.39425145426105, 73.53442299750544, 65.71664110306772, 50.321157747699374, 2.6172990664359066, 1.1197712296439757, 4.8647906991743275, 0.2924536360848335, 0.08743672511510311, 40.204706115107385, 80.26521021319975, 67.1501850312756, 71.77248647136074, 43.76545336938674, 32.63321964971481, 25.110462750158003, 50.12444696118755, 61.447070567838615, 73.83811643046718, 23.647036244792325, 0.27760464577905597, 0.08046150988628788, 0.08860238151805055, 0.01826619443994376, 0.04606199405726887, 0.04083763064456083, 0.13008968153547856, 0.26330576788994575, 0.2163098743485828, 0.23741518297503073, 0.16839947100848923, 0.2853607957161242, 0.5739916837023151, 13.819649565604426, 85.27970944681476, 71.8814185357863, 65.51415266529207, 46.89571657488423, 26.31664060777234, 49.85161081437142, 56.497412035542155, 77.37321530618976, 72.65286245653706, 83.0590517290177, 28.477205653344434, 0.31886899122788065, 0.3174566928177111, 3.8128737768819256, 2.4776452827838162, 2.843598497490729, 44.32152386634581, 67.26442798491448, 69.71774501185264, 61.822264886671505, 66.24166211774273, 59.59801820016677, 58.261862800967315, 59.702874921983295, 61.384516608330514, 61.15021382608722, 67.59918658964096, 63.308490168663766, 64.56490770463022, 61.68985743676463, 63.30792926972913, 60.68925688343664, 60.737549104998195, 57.9109283416502, 59.56871025023922, 58.10090441857615, 57.142685074960035, 49.578935484732355, 61.918374723003765, 60.00991413670202, 61.66864918124292, 60.688523400214414, 58.438573421970496, 55.10814774420954, 50.789786846407004, 47.798689334623276, 49.83533297815631, 47.248408256038545, 45.369267386774865, 45.92769130583733, 49.40495875573928, 47.481083254660334, 47.89878429905061, 47.95914957600255, 44.42194438749745, 47.434913035362, 43.66641744490593, 44.788195702337454, 45.16726140053042, 47.24736490557271, 49.168781080553615, 49.16200322489585, 49.04273179269607, 46.404922162332845, 44.5398743690983, 45.55208513813634, 43.23628248706941, 44.75705600553944, 44.78950185160483, 43.589946916026456, 45.62668077407345, 44.15126946664626, 49.157712151927335, 50.64908358358568, 49.85486638161444, 56.81634387662334, 54.83555870671427, 53.77527536884431, 54.757385869180005, 52.30984649350567, 49.45766364374469, 52.2408559245448, 58.95391010469007, 58.68063857478481, 55.64734812705748, 51.53068727062595, 51.59636343679121, 50.84070705598401, 47.94719026934716, 42.64924095522973, 46.76077527384604, 42.81477282124181, 44.318586011086744, 44.11936098529447, 45.70078611373902, 44.84461507489605, 44.20013827662314, 46.86869144439698, 48.53480054486183, 46.98800602266866, 49.618908359158425, 46.82078361511231, 48.71763006333382, 46.23508353387156, 45.49621489740188, 45.05701534209713, 43.76162513609856, 46.325658905890684, 47.93082614098826, 44.458300836624645, 47.83363765285861, 46.88450251856158, 46.32483913052467, 45.39970497931204, 44.22198195611277, 46.003879424064394, 44.45650046871555, 46.44868796871555, 46.92101978486585, 47.15342413994574, 46.621429151104344, 48.36815080335064, 52.044192206475046, 52.8542047931302, 48.520911432081654, 49.29609729397682, 47.38923703470538, 48.56020965883809, 48.70354875441521, 48.869680743063654, 47.53881662122665, 50.69562642805038, 50.19019373001591, 53.08618553223149, 49.71853656153525, 49.52666990218624, 47.1029903042701, 50.63339802526659, 48.86138493014921, 54.56053779971216, 61.29328227812245, 72.47186076256537, 71.53838372999623, 79.11331991995536, 65.53092472014889, 50.696599175853116, 2.9171794652938847, 3.495055888929675, 6.826213579024039, 0.2167678876749931, 0.4108915033359682, 42.62008597773891, 88.88789776832827, 71.38024945412913, 81.77439705018075, 50.65389240941694, 42.699023677456765, 29.01174626042766, 58.874972404972205, 72.12663727421915, 86.04036684959166, 35.865282089479514, 0.36020602309896105, 0.24938398912068338, 0.20254615483985794, 0.146927650597307, 0.20399298849365405, 0.16205761131019364], [0.04012205089712816, 0.04886722034444252, 0.031063369542901075, 0.028721212762438005, 0.08124398443126872, 0.04815878053646415, 0.2644069120287895, 8.63742389986592, 68.41404330345893, 49.00667344370196, 44.34087684077602, 29.699355402300437, 43.11655998229981, 69.35032875307145, 42.44186132184921, 72.0467778175108, 55.980773125925374, 72.42918537509057, 17.396166709161577, 0.03137399521355908, 0.09884172119200231, 3.532270601680202, 1.2844686114018964, 0.4565329074619278, 26.433266401290897, 47.91013956069947, 57.128509629157286, 65.85912119957709, 52.46303858295564, 53.109260835955226, 62.44929106004777, 60.024815220986646, 60.94955321281188, 63.03646595247331, 60.65279845268496, 61.77142312449794, 58.66201123883648, 58.15013800897906, 57.64601930495232, 58.8099395075152, 56.51814176190285, 55.099718570709236, 51.14197646417926, 55.540789096586174, 38.84025081511467, 31.513837960458574, 46.65088615109844, 49.26140000743251, 57.25930498492334, 56.395701054603826, 54.11775712044009, 51.50097531657065, 41.98520329690749, 40.02807001913748, 41.245671779878684, 40.657704568678334, 40.336525209488414, 40.68982093564926, 40.86941449872909, 41.4385151094006, 42.68444422752627, 41.60632195011262, 40.82112619953771, 42.552440781747144, 42.174987177695, 39.908025880013746, 41.66041143478886, 41.79067334821148, 41.212778783613636, 45.573560114829775, 45.26892531302668, 43.662565677396714, 43.24072261010447, 43.152390833823915, 39.8434675893476, 40.53806443368235, 39.218987034213164, 38.89607790977725, 40.70821292938725, 41.19887005898261, 43.55018192721952, 42.93623685836793, 46.11853814894154, 46.49266166071738, 51.117822508658136, 50.1847259459957, 52.161894690605905, 47.81970931637672, 43.48787507703228, 43.23990675710863, 51.47521318927888, 49.635060679528024, 49.61404854251493, 46.55089709066576, 48.7321271434907, 45.84755336084674, 41.14275270892728, 39.43851817038752, 40.22771473853819, 40.78675054734753, 41.92424181968936, 39.467206385827836, 38.95062631176364, 43.00612172772808, 42.740255632708156, 44.430295113594305, 45.46758159514397, 45.496846398999615, 46.790244040950654, 45.23507133606942, 43.024580401758996, 42.084290212200536, 40.03725228771087, 39.7769324241146, 39.79276311013007, 41.574029076483946, 42.225346488337365, 41.65134291495047, 43.30834034950503, 41.44617942071731, 41.8742629789537, 41.83233284181164, 40.83431320805704, 41.53152235092656, 40.772355448815134, 41.510133666376916, 40.74554212631718, 43.435523202342374, 46.09378014841388, 54.06317733949231, 54.46794240705429, 56.3893860386264, 53.277954132326194, 52.721769886632124, 51.68357733757266, 51.72080455287811, 46.745007345753336, 46.95774493678924, 44.590641606238584, 46.89928593174104, 45.30599955589541, 47.12655590426537, 47.17203578641338, 50.91350232401202, 50.32892404064056, 53.66738273251442, 52.973554672733435, 52.67658418224704, 48.88078105065131, 58.926724157025745, 60.43029023754982, 72.18162890403502, 62.67820842804448, 45.46507912297403, 4.292197217864375, 0.39666552637373254, 5.018130858098307, 0.419223046591205, 0.29142576059506786, 27.583607358317224, 74.87385749816895, 64.25795478205528, 60.76931245865361, 62.2281752863238, 38.09233327065745, 8.264673217650383, 31.0282701061618, 51.14709515725413, 63.999851057606364, 28.025376066084835, 0.07757619293707033, 0.06696250439891893, 0.04747369491885747, 0.03764102918907039, 0.027464167815783334, 0.034672449973802415, 0.0474002500695567, 0.11263686562738112, 0.14985294201441351, 0.014541531451076511, 0.03400214219225511, 0.08350377526855277, 0.34059322228835476, 12.238495080701767, 76.20076394850209, 55.227332884265536, 50.433933734893806, 35.25919352808307, 35.043498469937234, 53.7097913988175, 48.03919338410901, 74.77299767155802, 61.30786565042312, 79.23834154682775, 19.784762667071437, 0.13989597468847229, 0.2554409100764221, 5.060735642910004, 4.310157260587139, 0.8382469103220971, 29.007047260961226, 52.64551508811213, 61.79412972542548, 63.71362786139212, 54.06862551166166, 55.23579343672722, 62.47528852954988, 60.970082898293775, 63.099918134750865, 63.29234569303451, 62.651630447756865, 65.6820732547391, 61.42493271058606, 59.983116503684755, 60.65192768650671, 58.783942038013095, 57.551003809898134, 57.20622747175155, 54.405121726374475, 56.26152461574924, 40.63804172700451, 32.69578733751851, 48.567830824082904, 50.62151716601465, 60.02659205467471, 57.92448797533589, 55.409252412857555, 53.80196317549675, 44.89925761376658, 43.49192296305011, 43.18816284979544, 42.620631187192856, 43.118893792552335, 42.76720231579196, 43.35181982286515, 44.686363127923784, 45.28173185163929, 43.3217901568259, 43.2725840230142, 44.06555391127064, 44.077062145356216, 42.11102508729504, 43.653701120807284, 44.078152564264116, 43.75949921146516, 46.53065373820644, 47.06784586752615, 45.190811311045, 44.49541038082492, 43.66329916061894, 41.97329498106434, 43.132673078967684, 42.289512541986284, 41.09339752504903, 42.12840510952858, 43.652096871406805, 45.29126321115802, 45.01908994490101, 48.787099161455714, 48.978448067941976, 52.42354816006076, 53.141388970036665, 55.22600320077712, 50.807578717508626, 47.307526219275694, 49.09057686405797, 52.567820779738895, 50.573083739126886, 51.632986607090125, 47.76789088403025, 49.8554390476596, 48.30094883518834, 42.948686461294855, 41.26821364125898, 42.04954977958433, 42.7924310007403, 41.68962524783227, 42.07080902591829, 41.47582469447967, 45.43257836372622, 44.01806969796458, 45.45176267623902, 47.7888677197118, 45.55308926490046, 47.837697305986964, 46.89728552295316, 43.69402308617869, 45.12156971039311, 42.733771954813314, 41.89962894685807, 42.997484668608635, 43.345916655755815, 45.020156829587876, 43.906556713965635, 43.72651600068615, 44.00978957453082, 42.62610289358324, 42.62240802088092, 42.338553936250754, 43.46708259274883, 43.47880263482371, 43.69678443478, 44.19189345452094, 44.837382224298295, 48.05114484602406, 56.15780930365286, 57.673872055545935, 58.30622872998638, 55.48497376903411, 53.292235482123594, 53.90960478013562, 54.49833293114939, 49.385676383972175, 47.66300670562252, 48.00888915215769, 48.05444355933897, 47.1055555343628, 48.93966759404829, 49.470395657324026, 52.902387188326934, 52.58497330450243, 56.76192099048246, 56.82383952602264, 55.625151434252345, 50.65976027519473, 59.30239308264948, 62.9262512730014, 70.95935560041859, 65.68357552251508, 51.00008080082556, 5.42422806063006, 0.41681360813879204, 1.3642274348005172, 0.16536829091848868, 0.19020742015732875, 28.102244715536795, 82.81820251095681, 70.36903104474469, 69.11349604206701, 59.9561619758606, 41.32181282966368, 15.555786701940722, 36.8566454610517, 60.21200641509026, 72.22824235116282, 37.39517904097034, 0.11233227672956644, 0.03224964328711072, 0.02364205173967827, 0.018464385216394742, 0.06377655922645523, 0.033065101747671445, 0.13503384445944142, 0.2839853308133541, 0.23115561644156135, 0.14276062258549277, 0.15202809545782306, 0.25234999045008616, 0.6526507725638728, 16.35480586559542, 89.00568654460292, 64.8639766631588, 60.412737631028705, 43.46009685147194, 57.82403607522288, 80.95941482051727, 56.00958685721121, 81.05230439093806, 68.16756156183058, 85.45160339724633, 22.243975016378588, 0.40834505771917684, 1.3537157278868461, 12.020703515698834, 6.701599878649558, 0.9855427580975717, 33.062968254089355, 56.67753511859525, 61.37653850740003, 61.96940475894559, 55.896728500243164, 56.55221146921958, 62.0895508796938, 63.40409794161397, 65.04221308615901, 66.93431346647202, 64.31128724928826, 69.35500421831685, 63.3818777145878, 62.1077585220337, 63.37803379181893, 61.17677611689414, 58.58536028092908, 56.22832175224059, 55.11049724394276, 56.36423187871134, 44.924509832935954, 36.46244333636376, 47.686246748893495, 53.00784403277982, 62.694968715790786, 60.490808486938484, 59.52873737581315, 56.038392743756695, 47.5034172304215, 46.534819295329434, 45.825348823301255, 45.253545699581025, 44.57426963313934, 44.31066282333867, 44.62450735030636, 47.557369432141705, 46.67183945255895, 44.60649974884526, 45.628434073540475, 46.687391650292184, 45.18507680585308, 43.7517289961538, 45.23838573886503, 46.723630428314216, 44.75775418743011, 49.6982696748549, 49.07449514635148, 47.0567455599385, 48.600508089988466, 47.03831042012861, 44.168437680890484, 46.023899201423895, 43.566145973820845, 42.849132783951305, 45.56176947009179, 44.87951240231914, 48.45379967843333, 48.05795800301337, 52.63878037852626, 50.432137289354884, 55.813295764307824, 54.74600315093995, 55.905020390787435, 53.66557451986498, 51.65956458737774, 50.83172875065958, 56.87430474065966, 52.510020732879646, 55.117247643009314, 51.09376269002115, 55.201625670156176, 49.79747818362329, 45.67434933877761, 44.90898509179392, 44.729038515398585, 45.43375899714809, 46.04943775361585, 44.703703926455596, 44.62787666628438, 49.51041560019217, 46.730318069458015, 47.12680301358623, 49.50629711151124, 48.634683701299856, 50.21426923813359, 48.6404731196742, 47.20053572808543, 47.120452696277255, 44.378982667000066, 43.32811301754367, 43.5712528997852, 46.301053877799745, 47.754256725311286, 45.989774580924745, 46.87339436623358, 46.02234986520583, 44.904631260902654, 45.1040877065351, 45.16822630359281, 46.61472582047986, 45.35508409623177, 45.622640732795965, 46.22485007009199, 47.11985649601106, 50.048152938965835, 59.69837596339565, 60.37074473596389, 61.6466486069464, 59.0335028402267, 56.65890778264692, 56.1261087079202, 59.06003375207225, 53.427565097808845, 49.693268652885195, 49.739870332902484, 53.0562892267781, 49.89388219771847, 51.72688030427503, 52.6952507418971, 56.70622333403557, 56.08699875493204, 59.88048768812611, 59.07109091358801, 58.93163888685165, 53.98801688225039, 64.28155176101193, 65.37082925919565, 77.89608293964018, 66.5671011709398, 51.79232112822994, 6.317302719239266, 2.007477756950163, 15.809917065405077, 0.9866421861994652, 0.30925103313019203, 33.36771288225728, 88.41352631968837, 76.63057727198448, 77.91032898810603, 75.67790415979202, 50.07992805973176, 18.61687106470908, 47.5986719900562, 72.81353058353548, 82.24611697658416, 51.4260894252408, 0.15469242668440267, 0.16959355693430672, 0.14013196041266765, 0.2088022586559096, 0.10085975766302117, 0.15017197166960086], [0.022062740416356155, 0.07025976980765981, 0.07221204529125845, 0.024910011524034124, 0.032391783240581715, 0.10972419167838751, 0.43833672579738403, 8.093651013989604, 65.61081555581862, 60.2548033960404, 50.52077108813871, 20.654356056644072, 22.74427137067241, 69.22437360209804, 49.955502633125555, 70.9831565426242, 57.992886266400745, 71.59767427752095, 17.391301008962817, 0.23450303762670488, 0.43358023909311144, 0.41153471075719406, 1.248721355392087, 0.2856377211789931, 16.95566100458945, 47.50822213388259, 43.38028446320565, 47.73646093183949, 61.5645141755381, 62.26549663851338, 60.69139065281038, 61.80043297429239, 62.271662604424264, 60.1736181782138, 58.97503206806799, 57.398321628570564, 60.11416681351201, 57.90638231462049, 61.75324686111943, 57.16343049080142, 55.90903689784389, 54.41616319840955, 54.47410837296517, 53.08565208988806, 53.41170695520217, 54.90985624251827, 54.52427156509892, 54.29287918152348, 55.23557378399757, 56.68693703989829, 55.78910258508498, 50.40988176099716, 42.03256199436803, 39.422777698886016, 40.75615998237364, 39.89677259998937, 43.51299785798596, 42.16678550166469, 42.318283127200225, 41.05097709163543, 42.31260353519071, 41.65806585742582, 42.99444090935492, 41.195037903324256, 43.37921365614861, 40.95349442574286, 41.01521292040425, 38.73588831193986, 41.48261823961812, 44.34141420548962, 43.82890555166429, 41.70576972346152, 42.94743130283971, 42.85508301950271, 40.9386129533091, 42.199513758382494, 39.912089455512266, 40.658857745508996, 39.258744178279755, 39.65950058352563, 43.4590103549342, 43.62653870736399, 43.76749300187634, 47.23706083913004, 48.432654180834376, 49.15385253967778, 50.85274873241302, 47.2875338985074, 44.2316976670296, 44.251285983670144, 47.185724858314764, 49.635417615213704, 48.59250253246677, 45.17583962409727, 46.004357953225416, 41.794458435427764, 39.79955273289835, 38.92483280551049, 40.68842457186791, 39.42717859821935, 39.916337382408884, 39.83103759827153, 40.55912756150769, 44.182891614975475, 42.485403553132095, 43.939128075876546, 44.20351151497134, 42.48028486005722, 41.138253750339636, 46.34921666114561, 44.420147941958525, 39.82436956897859, 43.05807352066041, 40.197928259449625, 39.728620590702185, 39.78081557058519, 40.43857743663173, 42.448588186694735, 41.19510458361718, 42.83830704227571, 41.029596251826135, 42.384747689770116, 41.03058861147973, 42.06748677838234, 38.96475468912433, 41.14158384261593, 42.446309289624615, 43.716545335708126, 50.64731851700814, 53.65059106580673, 54.57266184591479, 54.31190267685921, 55.824521587740996, 58.464586580953295, 57.616711355024776, 56.58218229970625, 53.216549427278586, 53.24765382274505, 49.70701656033916, 50.497546734348425, 50.07298546452677, 58.352732350749356, 57.528913021087654, 60.23723117766842, 59.31776485135479, 60.99221683317616, 58.20766741229642, 63.45809721177625, 57.43445058022776, 58.48600272209414, 60.526215722483975, 72.6107911140688, 57.37064146226453, 47.2719346323321, 7.429512354635424, 0.575410968834354, 3.3343137271942633, 0.7454547862852774, 0.3026510018014139, 17.57869616631539, 75.91789830115535, 64.3885697087934, 62.08932338222381, 59.197497137131236, 46.24649370870283, 22.044449929268133, 36.64779886122673, 50.63586911847515, 60.64943698144729, 44.19776524266889, 0.5124329030513763, 0.06448257053571363, 0.02913386219241206, 0.04015446024676485, 0.015533141296116576, 0.06977977741870188, 0.06700073218634052, 0.04353482321265244, 0.10879289689323596, 0.020364576297241355, 0.05504950392811049, 0.022991913137957457, 0.3830993962624381, 11.368853642094521, 77.43757355597712, 65.29561781114148, 56.773978356392156, 27.413741273264733, 31.06294581967016, 71.54105878645375, 52.30743815821987, 76.8694809944399, 61.770634728093306, 77.61557855913716, 19.680568825814035, 0.23698140867054465, 0.2008040249347687, 4.207675043613681, 4.1537851095199585, 0.7634655746721453, 17.19711034528671, 51.00991810521772, 46.886973611770145, 55.333876225256155, 61.10923290252686, 60.37560847497756, 63.31602111939461, 63.833334676681034, 65.23220093019548, 61.24207573552286, 61.78608494420206, 60.25157136301841, 61.30077792752174, 60.08089334734025, 62.2894819321171, 59.700631326244725, 57.225211743385564, 55.655267392435384, 55.97917279889507, 52.76682615280152, 54.02412622205673, 56.49064986936508, 57.21384079225602, 55.22514027933921, 54.845364632145056, 61.1416159906695, 56.77553945972074, 52.92255209338281, 44.53828580917851, 42.44535223130257, 43.34144907612955, 42.36381400016047, 45.86025791783487, 45.26817221795359, 43.25225045604091, 41.98188104937154, 43.276510315556685, 42.14468294574369, 43.9298830493804, 42.97342092760148, 43.99950119756883, 41.733720533309445, 43.883555935275176, 40.969070157697125, 44.19844773507888, 45.353597517936464, 46.04258537292481, 44.49005242316954, 43.46279544215049, 45.71369855634628, 43.31638513072845, 43.34902709530246, 42.68920598491546, 41.27644669625067, 41.344884211017245, 41.58915373586839, 44.161322501397905, 44.477398856993645, 46.155934026164395, 48.480044257256296, 50.751990887426565, 51.72522898643248, 51.91936669811126, 50.75938063283121, 47.50032640272572, 47.54328027848275, 50.55868864059449, 50.46990971411429, 51.097390882430545, 48.83390480472196, 46.234106863698656, 45.71455755541402, 40.46837960520099, 40.700646677324855, 41.82129921451692, 40.62802007121425, 41.963343927937174, 41.7036477211983, 43.20532321929932, 44.54900564685945, 44.88968703054613, 44.36479937645697, 43.91542911529542, 44.23805975144909, 42.726994099155554, 47.19300477735458, 47.468692487285985, 42.4426418735135, 43.931957983201556, 42.93842946329425, 41.26063954445624, 43.788446303336855, 42.443936255670366, 44.22434714532668, 41.73989826633085, 43.454060323776744, 42.58013271516369, 44.31277305849137, 43.37874297172793, 43.862987026091545, 41.34375456840762, 44.08007060327838, 42.69268904962848, 44.411950188298384, 52.11071560459753, 57.15385598521079, 56.21219296609202, 56.9957217093437, 59.03226337125225, 60.197976096983886, 59.92026444404357, 59.26122780769103, 57.44235023375481, 56.01743159755584, 52.68112628690658, 52.397727197216405, 52.09310024015365, 59.32089490275229, 59.560073191119784, 61.613998797632036, 61.18134960051506, 64.49337936216786, 60.16525568500642, 66.94212682785528, 59.52208895837108, 61.5062669784792, 63.81993193780223, 74.74036355172434, 60.478111774690696, 54.09566240925943, 7.723144417808903, 0.40433624218548503, 5.914863126893198, 0.8985580095360357, 0.1956082021276797, 19.068433930796964, 82.34030092916181, 69.12727925085252, 70.82506149045884, 61.36222185627107, 38.87457547649261, 18.48252792512217, 42.18716221470987, 60.44899209853142, 70.16016483306885, 52.31835411440942, 0.968524206790232, 0.11231095650263372, 0.007738225873664863, 0.01109572733947707, 0.03184356497630718, 0.11531657223860103, 0.23086568280573816, 0.15986149770117578, 0.20776485303236594, 0.19598836559922467, 0.22392688739684322, 0.23365024387115435, 0.6220991861435675, 16.388117574876357, 88.87869588790402, 75.93576861966041, 68.84085993612968, 35.110155228645574, 34.11305342951129, 77.03692697709607, 62.95786949896044, 80.52090167999268, 69.22253008811705, 83.94535049315422, 22.331049673018917, 0.3508268699290291, 0.8299313016956853, 6.913472587062467, 5.93799138261426, 1.2595733279182066, 21.50024264089523, 51.252195066021336, 53.5397135057757, 55.835186512239524, 59.02571693543465, 59.284503152293546, 65.7641057045229, 66.52422966495638, 67.59959451613888, 62.41100088242562, 64.35430388296804, 60.56854986375379, 65.41370076517906, 60.40656382037748, 66.35413216006371, 61.04081892198133, 60.13202928727674, 57.1481450142399, 58.30098452106599, 55.63302363118818, 56.50690417135916, 58.89443520576724, 58.42422931425033, 56.252526698573945, 57.82599333793887, 61.90375212700137, 58.358812024516446, 55.595737580330145, 48.49473353355162, 43.87789595511652, 44.54995486044115, 43.83967638015748, 48.66553706507529, 48.21780635464577, 47.25737479425246, 43.923619024215206, 47.216154606111594, 44.91390766636018, 47.47873767729729, 45.429059997681655, 48.4594282796306, 44.352490978856245, 45.61663558406215, 43.206519542201875, 45.49913706318025, 46.813970458122995, 47.42112198183614, 46.67010968731296, 44.204931412973714, 48.2021443305477, 45.50637383614817, 46.003255767206994, 44.74429261299872, 44.829894419639345, 43.55450830151958, 42.92138676489554, 47.60253552467593, 46.930390327207505, 48.845036491270996, 51.0185355524863, 52.95962633625154, 54.38070497205181, 57.06779526126001, 54.100596750936205, 49.95729907866448, 50.569541838861284, 52.6969216715905, 53.80373216444447, 55.08427619934083, 50.75788620979556, 51.444167629365005, 47.090501477641446, 42.82291173934937, 43.25533736136652, 45.05261836513397, 42.74866127198742, 44.23610248873311, 44.14339334734025, 45.326431182123, 46.16806591710737, 46.081444294221946, 45.06288320787492, 45.53312832309354, 46.104072447746034, 43.77187428935882, 48.888331613233014, 50.49439707110005, 43.109083944751376, 46.94198485343687, 45.60326422414472, 44.562565280545144, 45.525405176224254, 43.43686465294131, 45.86827132009691, 43.74634750427739, 46.379391454881244, 44.87206382136191, 45.51384987369661, 45.73120017205515, 46.365667081648304, 43.29463951049313, 46.103786114723455, 46.645512503962365, 46.91650905916768, 56.86107458606843, 58.98041748231458, 60.3875756263733, 60.40083323755572, 59.80000849693053, 62.91529609311012, 63.70163325340518, 61.4895498368048, 58.69687718729819, 57.98839907492361, 54.85819862734888, 56.31188000402143, 54.237036397380216, 63.678189246885246, 62.30060185155561, 64.55689430236816, 63.42154464414043, 66.40469935632521, 62.93410778045655, 70.07844617289882, 62.964262962341316, 64.70870571751749, 67.0907768126457, 80.36075915059736, 61.14387527588875, 53.80575218508321, 9.586381546912655, 1.135079259833982, 13.587916916416539, 2.7611142396926884, 0.47140049838250686, 20.98344291410139, 88.65175539447416, 75.13995109065887, 78.49260484018635, 74.11021124932074, 58.40752786205661, 33.218447085349794, 53.22548066416095, 72.96829946579473, 80.86910616966986, 67.1586573508478, 1.846738291844245, 0.2279120154919163, 0.16028831592730938, 0.08169026129067906, 0.15729415320581006, 0.22159623342656323], [0.03675836183491253, 0.022761920136549783, 0.05547732955986454, 0.05848643865676657, 0.07867120071164063, 0.10260507449387543, 0.3115645267309681, 12.849180659940167, 63.36007718117007, 56.29464510948428, 37.01162222893008, 14.491062260443165, 18.687628661432576, 37.40694615148729, 57.90855530769595, 70.32182924209103, 56.77561006238384, 71.32787012284803, 17.82621733603939, 0.2101407061901785, 0.43651077055162, 4.2125216222578485, 2.7889133028445707, 0.15465375456598499, 10.638588724597808, 44.124099208462624, 54.60473114444364, 42.383214043032744, 53.15945148468018, 58.796438709382095, 63.582973710952274, 59.24458911342006, 59.728013392417665, 58.690593550282145, 55.589908938254084, 56.22017498939269, 58.75570881751276, 54.95547732999248, 60.72814718369515, 57.26149758984966, 57.64607421813473, 54.91984259697699, 55.87275889612014, 54.01205708903652, 51.93165156149095, 53.13437184979839, 57.677939553414625, 55.78818475046466, 56.48546057362711, 55.00907651839718, 51.37100758091096, 43.43987311086347, 40.14103035773001, 39.89507421370476, 41.96723884151828, 44.543486872027, 45.19090544792914, 42.99729639484037, 41.44869365999776, 40.93236853999477, 42.17734844453874, 40.325562184856786, 42.858048331352975, 39.99530646108812, 41.05163997219455, 39.045214268469046, 41.321867742846095, 39.932077853910386, 45.047181960075136, 47.0196242486277, 43.571943236935525, 41.268868677077755, 44.57661128813221, 44.82277139540642, 42.21347739619594, 39.86810399639992, 39.11468728896111, 37.436705173984656, 39.832186852732015, 40.00837579850228, 39.262705772153794, 41.261608369888805, 44.474257038485625, 48.0757067280431, 49.22676940118113, 49.46457485998831, 53.0914964214448, 48.46624928136026, 45.966703199571185, 43.189135597598174, 47.09907185646796, 49.745200833966656, 47.22145765058456, 44.46793417776785, 44.58364802022135, 40.97567542906731, 39.017388974466634, 39.22056382702243, 39.277873577610144, 40.467559829834975, 41.15147998256069, 42.936421209766024, 41.04501901134368, 41.236367917829945, 40.87380755332209, 40.798811835627404, 40.67230755282987, 40.86673159753123, 42.74142057664933, 43.81042334341234, 43.63172800310197, 41.5029243500002, 40.476695029966294, 39.97504741914811, 40.50566957842919, 40.977754285258634, 40.525202981887325, 42.77524709701539, 42.62996642820297, 40.30065905663275, 42.5746492416628, 40.913392113101104, 40.983186767947295, 39.564818489936094, 39.75398655860655, 41.542885457315755, 42.67367339903309, 41.95808010716593, 50.767872564254276, 56.40956663316297, 56.56799900916315, 53.680338321193574, 56.85846228753367, 55.58604932600453, 55.49747828514346, 58.11900223455122, 56.5418524895945, 55.97673308464789, 55.56815155090825, 58.64758868371287, 58.29397916793824, 59.689487872585175, 61.554665104035415, 62.111210207785334, 61.910051453498106, 68.48873307628017, 69.75654509759718, 67.21269192234163, 62.606256469603515, 64.44998618095153, 57.69472337538197, 71.24454329090734, 55.192412022621404, 51.44165731245472, 7.033611353366607, 0.10052272494161323, 0.5985873961640943, 0.7354832632887749, 0.26665822993363103, 13.951541223833638, 75.17225573139807, 65.71659011225547, 65.50344067235147, 58.801522101125414, 56.749200744013635, 23.94490888041835, 24.148421056808967, 40.29317909671415, 63.467683484477384, 47.2209555872025, 1.3405502924034673, 0.03926302118587398, 0.029360509304810437, 0.02748871135765747, 0.03719374109359999, 0.09588863610500291, 0.13743392131741972, 0.076220630998573, 0.07772385638447539, 0.04645408934823448, 0.13427943171512696, 0.15015145583498865, 0.6422510983482485, 15.810212223760544, 72.07404613494873, 63.69442785939863, 44.717487135241115, 21.669708644190145, 22.256646233220255, 46.105213857466175, 61.467682623094134, 76.20464709497269, 62.978155997491655, 77.00080979254939, 19.005299460503366, 0.39060871267030317, 0.4750335018240637, 4.002213449247422, 6.29600719098122, 1.0068243129118797, 10.761114743448074, 46.379462057544345, 56.20651729645268, 46.06122055361348, 55.70442253543485, 59.87588282554381, 65.4284449546568, 60.14356497795352, 63.93895626068116, 60.32364099256454, 57.73626127550679, 58.58830205855831, 60.44075119879938, 57.202214887065274, 61.582015791246974, 59.88350791315879, 60.163161139334406, 56.31044441653837, 57.4171176264363, 57.343573185705374, 55.01018654915595, 54.14913215944844, 59.84186803140948, 57.46629238128663, 59.32187941766555, 58.152577723226244, 54.78255179620559, 45.94352591422297, 41.73529340374855, 41.2403844248864, 45.00802101627473, 45.32475633005942, 48.38689973277431, 46.088241761730565, 44.655266577197665, 42.59212732315064, 45.95939974631033, 42.88022933467742, 44.65679237919469, 42.304523452635735, 40.58081434619042, 40.91370590271489, 41.976072019146336, 42.3723804566168, 46.73640558796544, 47.63668367939611, 44.42527055740357, 40.97928008725567, 45.604260506168494, 45.25795836602488, 43.677572665675996, 39.57017644759148, 41.761424233836514, 39.491901628432736, 42.315274669278054, 41.872690108514604, 43.4528757679847, 44.376452738238925, 45.772130104803274, 49.89321539478917, 51.97205197426581, 51.15068020359163, 53.977748117139264, 51.01136545981131, 48.47586301065261, 45.06598580268122, 50.93138048725744, 51.58906390590053, 49.28760144018358, 47.26892225203976, 46.497215532487445, 43.06286665701097, 42.68054539157499, 39.97780876774942, 42.29590208299699, 43.873130275357155, 42.38412795528289, 44.28863479245094, 43.76532000880088, 43.191630225027765, 42.25995356036771, 42.159917431492964, 42.795184504601266, 41.026611328125, 43.676446945436545, 45.5845937421245, 46.50336188654746, 41.07440933104485, 42.395518518263295, 41.97802143712198, 42.08173282684819, 42.45452273276545, 41.81132462716872, 43.96041085643154, 44.14011424587619, 42.42706614155924, 44.3005274188134, 42.80940309647591, 42.888176056646536, 42.15161769620834, 42.39164321653305, 42.41935476180046, 44.25556136715797, 44.740252571721236, 52.158223352124615, 58.277160044639345, 59.88169970050935, 57.38140052364719, 58.10948264214301, 58.43989918308874, 58.89180721775178, 60.40375932570427, 58.93070144038047, 57.41657241698235, 58.11562115146268, 59.81441536257344, 61.03495105620354, 62.46116407455937, 63.67056808164043, 64.59807134443714, 64.03911398303124, 71.972166492093, 73.09372901916504, 71.4751394333378, 64.02249097824097, 68.68092136998331, 62.46153669972574, 73.3254312699841, 61.32755594868814, 53.74641064674624, 7.826453274296177, 0.1785253453999758, 2.9412593860780043, 0.8696530218566618, 0.17900128518381428, 14.379634587995469, 81.34180668861636, 70.68824921884845, 73.2731774545485, 63.197600841522224, 65.74940466111707, 26.851094922711773, 33.22158890385782, 49.47421604587186, 72.41201323847618, 58.813787352654245, 2.2508991918256207, 0.29362017348889385, 0.06662010140116177, 0.09271703209848174, 0.03958767775686518, 0.022079435387446035, 0.24686864667361785, 0.41889911397330226, 0.21978319442320257, 0.1350093756111399, 0.2722315808698055, 0.3286644059323496, 0.886422073648822, 20.32601248833441, 82.64182921378844, 71.03713620093562, 54.37011849495673, 27.35192079697886, 29.691938200304588, 48.48558264393961, 71.17055954471712, 81.21480818717711, 67.84588798399895, 83.39219431723319, 21.24619072483432, 0.6277049272771805, 1.3708845550014128, 10.023664043795678, 6.203001910640348, 1.1847587746958579, 12.86480640211413, 49.76627180653234, 61.45063600232525, 51.352905842565725, 60.083913572372936, 61.96662379849342, 66.16034353933027, 63.20944247707244, 65.22224987706831, 63.33826880301199, 60.963877708681174, 59.67940738124233, 62.32841537844751, 58.15413490418465, 64.15812653879966, 63.32682724921935, 62.69380769421978, 58.51702474778699, 59.360232353210456, 59.58318379617507, 58.085917042147734, 57.04395901772284, 62.09162189114479, 59.10854562636345, 61.209190583998165, 60.329210758209236, 55.879932911165305, 47.33120556800596, 45.38494902272379, 43.61273588672761, 49.840188872429636, 49.38737869262696, 52.21180292867845, 49.70576140188402, 46.72442666945919, 44.58572687641267, 48.20348578114664, 45.9184149003798, 45.932578579072036, 43.3791587429662, 43.20298156430645, 40.77930196639031, 45.058937303481564, 45.113128769782286, 50.22765236516153, 49.92984248745827, 45.98491868665142, 41.402668568395804, 46.697303479717625, 49.44350388742263, 45.60743762600807, 42.85416518488238, 42.10649082737584, 41.14336852104434, 43.207833536209606, 43.41559756186701, 45.56115365797474, 47.400298118591316, 48.15333827849358, 51.97047518145654, 53.675556951953524, 54.94056840096751, 57.47713381244291, 52.67760399849185, 51.06996959255588, 47.32138787546466, 54.24515962600709, 55.58073843679121, 52.493083938475586, 51.75938498589301, 50.572373790125695, 45.05116708817021, 43.238730046056936, 42.921947663830174, 44.76274736465947, 45.62679060043828, 44.659796914746686, 45.982608410619925, 44.36679586287468, 45.05913342199018, 44.03751680927892, 43.288704964422415, 43.712034610009965, 42.38963888537499, 46.802881917645855, 46.39232350933937, 46.83181332003686, 45.3657764773215, 44.73703622817994, 44.17889471976988, 44.83875897622878, 45.12990082463911, 44.55376740424864, 46.48253017856229, 47.02682572026407, 43.74362145700763, 47.66781553145378, 46.23152594412527, 45.5029692188386, 43.24969307068856, 43.768085279772365, 46.59165836149647, 47.51273678195092, 45.51758789247083, 54.464384817308, 61.66332260254891, 61.734729351535925, 59.3388319015503, 61.59903495542465, 58.413027025038204, 60.93859018818025, 62.85638209312194, 61.57044087686847, 60.77843981404459, 63.51462248832949, 64.96915501932945, 63.503514336001494, 66.03307047197896, 66.5224410641578, 67.18983234897738, 66.71160913282826, 75.99596915706512, 74.99978127018099, 73.91027235215711, 67.61600571293985, 71.51779128659156, 66.5117722172891, 76.36279706032046, 60.06100300819644, 58.03005856852378, 9.402083100811128, 0.431894202145838, 6.293671419543605, 2.6272628672661322, 0.36916811800291466, 16.683717196987523, 89.73840882701259, 77.19236266228461, 82.59991476612707, 73.66812875193935, 71.47975998540079, 36.0888611116717, 40.95474566182783, 61.92421120982017, 82.06337375025596, 71.09092758547875, 3.113379608238897, 0.5155873466883937, 0.1654523460855407, 0.18588363523444823, 0.17387523766486876, 0.3103197257845633], [0.08039594808172795, 0.06498633463296198, 0.023679791146048138, 0.012613694172262425, 0.1065600417073696, 0.0763082714571107, 0.289628426394155, 8.871906130544602, 67.91018347586355, 53.1314653735007, 39.360098223532404, 22.573599238549512, 21.718355840252293, 42.98187755769299, 52.54641248333839, 72.52200434284826, 56.87929399551884, 72.98328291985297, 16.869498299014186, 0.24729025550186637, 0.5691256770683873, 2.0269477896152006, 4.527714463972277, 1.350582489563573, 5.639017541562358, 45.30887857560189, 49.09476595540201, 60.42787797989384, 61.92642734896753, 53.38951810713738, 57.80531068002024, 60.919272515081595, 57.86985328120571, 53.79800550399288, 53.18547248840333, 54.205088692326704, 57.38431484468522, 57.388962853339414, 57.56958407740439, 55.86954647494901, 55.34536484749087, 55.540306645054976, 54.82723151483844, 57.841988763501575, 59.13237794753044, 59.341181401283514, 54.56626053779356, 54.14642180165937, 53.061662873914166, 48.54143327282321, 44.03965842339301, 39.696049228791274, 41.66004665436284, 44.76477915240873, 44.97322959284629, 42.468290252070275, 42.98667461641374, 42.663063387716974, 41.21275524939261, 41.077284428381155, 40.375262537310206, 39.90724925071963, 41.69863885448825, 38.84778568821569, 39.19073420186197, 40.24932307581748, 40.65186023712158, 38.52593168135613, 43.80545762277419, 47.259869421682055, 44.90840065863825, 41.93067058440178, 42.49683333981422, 40.729138774256555, 44.21225055571526, 40.139845801937966, 39.8322888343565, 39.26054062381868, 40.08981989276025, 39.8138693840273, 39.07951539562595, 39.675782342110914, 42.354953365941206, 43.727292629980276, 47.48375046637751, 45.21927202901533, 50.67660685508482, 46.59870686069612, 44.54425957895095, 43.79874252503918, 46.658993690244614, 46.93190436209402, 42.827618583556145, 42.357597043437345, 42.51523710066273, 40.38060872785507, 39.799988115987475, 39.82381651478429, 40.24210591470042, 40.8338935144486, 40.75098245374618, 40.51290635139712, 39.524900528692434, 40.83645482217112, 43.525200351592034, 39.4630604405557, 40.62909480064146, 39.60294785038118, 38.848072021238266, 43.78281770213958, 43.81343180133451, 39.80587559361612, 38.146858138422814, 40.34734310642366, 40.64841247374012, 40.614876208766816, 39.45377226798765, 40.28713472427861, 40.88676314200125, 41.86147212982178, 42.529706724228404, 41.13341354554699, 40.55449916470436, 42.439856990691155, 40.33914927513369, 41.372646747096894, 42.60672246256183, 41.036456477257516, 45.214416134742, 53.804151858052904, 55.57424299178585, 59.79846700545281, 58.738764178368356, 56.808495213908536, 55.333076061741004, 57.116585623833444, 55.96985324736565, 58.30900969043855, 57.93395265456169, 56.74522738302908, 57.73086017177951, 60.94587010722007, 58.544442115291474, 60.327912453682195, 55.902004088124926, 62.0423569217805, 43.17070830252863, 62.527169719819106, 69.00123780773532, 64.71646416571834, 64.71760949780865, 73.07253253075385, 53.13119865232899, 57.10424192490117, 6.933617389971211, 0.31689613096175656, 2.5698979583478745, 0.40213514900495934, 0.09240504279131852, 9.983209698430954, 73.41863463001867, 65.8652400970459, 70.41534639173939, 51.54177973347326, 43.66074962000693, 11.080213285261586, 16.33940762089145, 40.60605872061945, 55.3881343718498, 39.505002344808275, 0.5550595060471566, 0.02864125425056104, 0.0813950722916953, 0.02370736265044299, 0.010574932150062053, 0.10187433386642127, 0.03687129468627034, 0.05131705844354245, 0.05501394978754463, 0.031538638999805815, 0.15265656334738578, 0.09472172331785965, 0.19438685879351633, 14.663657334543045, 78.00079453376033, 59.3255272219258, 47.172118156187, 29.076814459216212, 28.470610187899684, 48.37827836313556, 59.11895951917095, 78.48439139704551, 59.98820381779825, 76.82474244025447, 17.745204702500377, 0.38229279760872165, 0.3403238964176947, 6.6125630563305275, 8.771812146709813, 1.5280116397526957, 6.584270019685069, 47.032521001754276, 54.66744984349897, 62.067350264518495, 64.14807350404801, 57.01528256939304, 59.599438098169145, 62.14214201896422, 59.494181294595045, 54.743018227238814, 57.33146090661326, 55.37531606612667, 58.769731290878795, 58.0199388534792, 60.183024021887014, 57.70585898430117, 58.205129638794936, 56.908923579800515, 57.50378239539362, 57.702579882837114, 59.84031869519142, 61.00816911266696, 55.28588994856804, 56.610764611151914, 54.872664328544374, 52.146244433618364, 45.64255068379064, 41.75858051546159, 44.72685767758278, 47.01434473837576, 45.69564388644311, 45.4709352216413, 45.34533700635357, 45.04239274609474, 43.92848276322888, 42.29907528046639, 43.70798280162197, 41.79337193889003, 43.767085075378425, 40.474302384161184, 42.78843410553471, 42.19811347223098, 42.3372438646132, 39.37902365961383, 46.72503071446573, 48.02672416933122, 46.055380144426906, 42.785162848811, 43.9202771648284, 42.7441034778472, 45.18493952289705, 42.18904495239258, 42.2669118450534, 40.48999578722062, 43.54391005731399, 41.76481708403557, 42.083203715662805, 41.714355791768725, 41.85943641970235, 45.32615269384077, 49.06330462424986, 47.77265264141945, 51.17612854126961, 48.67252280635219, 46.943898970080966, 46.72776068410566, 50.17054657782278, 49.37332876266972, 45.25931158373433, 46.80897335852347, 42.660851170939786, 41.6855263710022, 41.47598158928656, 41.9505883801368, 41.145286560058594, 42.54556878920525, 42.6200153750758, 42.2057464045863, 40.76747994269095, 41.76949254928097, 44.523388647264056, 41.407446015265684, 41.22336526070872, 40.8559254677065, 39.93487842621342, 44.01160955429078, 46.217224982477006, 41.93794265870125, 40.09284796253328, 43.135830586956395, 41.717474076055716, 40.91779301243444, 41.33236400542721, 42.223612800721206, 42.81814213721983, 43.9565198652206, 44.289701677137806, 43.927859106371486, 42.543631138340125, 43.8529339913399, 42.129538674508375, 44.36345792585804, 44.66800643551735, 43.36947048864057, 46.657989563480506, 56.948088445971095, 57.65060063331359, 62.71431776785082, 61.286488732984, 58.78008242576354, 60.00692136826054, 58.68880887185374, 58.80846469633041, 62.287920828788515, 59.903923849905695, 59.94122559024442, 59.005630477782226, 62.989723067129816, 59.461001965307425, 59.76165163901545, 56.94367970189741, 61.669943563399784, 42.43074924715104, 63.68774414062501, 70.5827296164728, 67.23858741021925, 64.59301148691486, 78.05549590818345, 56.47865133900797, 59.33107737571963, 7.28928565979004, 0.17393044196069243, 2.0554066689745074, 0.9635089662286543, 0.11118431695766988, 10.834297345530603, 78.49794710836103, 70.16564830656975, 78.32147967430853, 56.22366982121622, 46.17702461058094, 19.816451495693578, 25.447094286641768, 48.86403645238569, 65.32889519968342, 50.42672049614691, 1.5732609600790086, 0.041009391387624126, 0.052533958467745015, 0.018014515404619517, 0.008273201829363263, 0.04085694755157156, 0.16127684514128393, 0.15474395375818978, 0.21333498639925835, 0.08872491728153922, 0.2793542986675617, 0.3222197678781325, 0.6298437221877037, 18.840022548552483, 87.38522991057366, 67.61362875661543, 55.53665491842455, 37.50004752989739, 35.666712099506015, 55.619781709486446, 67.0436377679148, 84.1905927658081, 66.56965855629214, 84.75914032228532, 21.69136993346676, 0.4913923594980471, 1.1733367101800058, 9.521138802651437, 9.481201229556914, 3.9713875420631903, 6.852062979052144, 54.1575691776891, 60.042250156402595, 59.6697191269167, 67.59982201360887, 59.5501103708821, 64.58921463258805, 65.49696876156715, 61.30265282046411, 58.185007879810954, 59.48946660564792, 57.15501308441163, 61.319224834442146, 60.90667778445829, 60.87987230670068, 61.74053838176113, 60.29559604583248, 60.390878262058386, 59.08942407177341, 60.1366380722292, 61.91949652087305, 63.25666781394713, 58.01482800514468, 59.81660796749977, 59.24223961368684, 53.13788237110261, 49.38189521912606, 43.46906338968585, 46.45500690706315, 49.14066945352862, 50.81613340685445, 46.918533002176595, 47.84633044273623, 46.24137501562796, 46.37783035155266, 45.146970979629025, 45.79059270120437, 44.02764028118503, 45.98908816614459, 42.73976533643661, 44.50883273155459, 45.94847202301026, 45.18988563168434, 42.39229825235183, 50.74498161192864, 49.63054603145969, 45.98734271141791, 44.25418461522749, 44.43519415393953, 43.06716557471983, 45.41965807637861, 44.38376795861029, 43.71852613264515, 43.11734445633427, 44.66853595549061, 45.37035780568277, 44.18622562962194, 43.777977497346946, 45.05366956034015, 48.47654550306259, 52.10645198822022, 49.33245766547419, 55.087669049539876, 51.304115479992284, 50.07070264508648, 48.01004625135853, 52.50357627868653, 52.38228090347783, 47.60921532107938, 48.57184733113935, 46.552768061237956, 44.380877171793294, 45.2433200805418, 44.68324876600697, 45.52029040551955, 44.62168716615246, 45.112787523577296, 43.03508450908046, 42.26213832055369, 44.4699385089259, 46.701312142033736, 41.366563150959635, 42.13200192297659, 39.76553793876402, 40.77341841113183, 46.14493177783105, 48.79446929500949, 44.427227820119555, 41.25961972821144, 46.08795935107816, 45.415814153609745, 43.348591712213334, 44.38962405727756, 43.977975230063166, 45.43611241925148, 45.64110332919706, 46.73504844788582, 45.76379114581693, 43.774561112926854, 46.803772295674975, 44.03500649236864, 45.84421934620027, 47.366750086507494, 45.836951194270966, 50.08704323922434, 59.159885529548895, 59.61896365688693, 64.0513047095268, 62.72161337637133, 60.47476991530388, 60.30395853903986, 61.591284351964156, 62.02249011685772, 63.88911078053137, 63.01006447884345, 62.48196440358316, 60.82368043161208, 64.72091997823408, 62.62108302885487, 62.31838195554672, 58.78370277343258, 64.4077108752343, 46.01907468611195, 64.93697197206559, 74.46842562767768, 70.62090996773013, 67.68280367697439, 76.14698040869929, 58.54919210557015, 64.25662509856686, 8.727545257537596, 0.5077659873472107, 7.876771890348005, 3.202489974998659, 0.16501596708211208, 12.88857106239565, 86.94519489042221, 76.2792270414291, 85.68118756817233, 67.9720078745196, 53.34736831726567, 20.68484856236366, 30.355244336589692, 60.798843983680975, 75.83715238878804, 65.29606103897095, 3.3003594846494737, 0.22434252073928235, 0.20308523559041564, 0.1586646078935554, 0.13706561688694263, 0.23624859960569491], [0.057615048116854126, 0.07403221657319416, 0.03296058437216186, 0.019346939572583766, 0.1553225952891573, 0.1507008021637317, 0.11046534344073265, 7.705999737785709, 64.29326788071664, 51.4874666736972, 41.799326096811605, 20.496704232308176, 20.53532192783971, 43.33692658332087, 55.25062784071892, 71.13332056230115, 56.96486442319809, 73.1399659187563, 17.217826343351796, 0.4727809275350263, 0.7452407719627504, 4.056077397638752, 9.71053534938443, 1.147798157988056, 4.953285253817036, 42.839954437748084, 54.86649051789315, 62.79282400684973, 63.88840867627052, 60.782566147465865, 60.62422790834981, 56.76791437210576, 53.968079474664506, 53.12205560745732, 55.87997997960737, 53.89871628053727, 55.49612506743401, 56.486323495065015, 55.42163533549155, 55.40483582404352, 56.24456428712415, 54.9875662403722, 58.48411606204126, 56.126355817241055, 54.52263593673707, 52.31127815861856, 54.690674197289255, 50.417628442087484, 45.86703185112246, 43.038575418533824, 43.06092508377568, 43.211191085077104, 42.123156978238015, 40.786350465589955, 41.096237321053785, 40.98385749324676, 41.41522407531738, 40.99616981321766, 41.04675662133002, 40.52916457576137, 40.495373356726866, 38.854579233354144, 40.54784682489211, 38.931477300582394, 38.96439775343865, 39.26654185018232, 38.44014160094723, 39.28081927760955, 41.06898077072636, 48.422106927441014, 42.72588406839679, 41.56339945331697, 41.826119807458696, 41.246687673753314, 42.408583933307284, 41.356419901694025, 41.57804950591057, 39.68718467220184, 39.49429427423785, 38.074564933776855, 39.50850502137215, 38.22155967835457, 41.30963387027864, 44.20586101470455, 47.09549857724098, 47.30689471767795, 47.970481303430375, 48.07671085480721, 44.08919403629918, 46.134168794078214, 44.61317170050837, 44.38407390348373, 41.85694179227276, 41.41341978503812, 39.85905508841238, 40.40934401173746, 38.70097529503607, 38.85099026464647, 41.99301665829074, 41.854592292539536, 39.60117886143346, 41.259023527945246, 40.53886067482733, 40.64881647786787, 40.828527712052875, 41.38724973124843, 40.46463374168643, 40.16426255626064, 40.290064734797326, 43.145491384690814, 44.205766877820416, 39.6483688969766, 39.3690961407077, 38.77884218769689, 39.72563566700105, 39.00081303811843, 40.44931688616353, 40.11555064109064, 41.348398654691636, 42.22819412908247, 38.82684807623587, 39.377054629787324, 42.21446583347936, 41.431101829774924, 42.07684163124331, 44.175141011514974, 43.66199693372173, 44.46326655726279, 41.69763865009431, 45.93450054045647, 52.02821247039303, 56.391178561795144, 56.898686193650775, 56.62372019983108, 59.94720328238703, 58.29477933145339, 57.93818489197762, 60.897181726271114, 58.91475700563001, 60.894185035459465, 57.52513970098188, 57.754688570576334, 57.6619755068133, 63.06266738522438, 61.38267309434953, 65.2788104549531, 43.465827434293686, 47.521126731749504, 64.05892587477162, 63.40460000499603, 76.09774681829637, 58.333532348755874, 57.41852575732816, 56.491328439404896, 4.950171382196488, 0.06763673838107817, 1.4836146994944543, 0.5207182358830206, 0.09950347560187502, 8.079354465007782, 73.47299083586663, 62.14237736117456, 72.12275412774855, 54.4539003218374, 59.74535811331965, 25.89248138089334, 14.789966479424509, 38.53127394953082, 54.81583310711769, 54.80053978581583, 3.466070308800667, 0.13097403811350947, 0.021889866930582834, 0.03560834128649966, 0.0319348098785286, 0.038437791273839055, 0.06551695011195637, 0.058232246853050694, 0.05960474699555386, 0.09251825526476869, 0.16132008314373034, 0.08482176059436414, 0.38297691412510415, 12.106357293744242, 77.35363483428955, 58.600171150699744, 51.58876580576743, 24.475629098953743, 21.088650688048332, 47.01623532079881, 62.39098110506612, 76.7760972053774, 60.756537299002375, 78.17526940376528, 18.31945146283796, 0.3801062907422743, 1.5084676949247238, 8.383745589563924, 9.98617991324394, 3.764844599270052, 5.536451483926466, 45.822995401197865, 57.846362206243704, 62.13960424546273, 65.9818050938268, 61.98778890794324, 63.886961321676935, 58.09657019953574, 57.04050340960103, 54.9575718756645, 57.73262523835706, 54.60130691528321, 57.98211543790756, 59.99954731233659, 59.149722668432425, 56.64293589130525, 56.74330934401482, 57.23329574831071, 60.75874559340939, 59.236438428201986, 57.84522471889373, 53.538885885669345, 57.76704011424896, 52.94292096168765, 49.837439290938846, 44.04500461393788, 42.858566084215724, 44.823100874500895, 43.929643784799886, 41.9511414343311, 43.63877650230162, 43.02262706141318, 43.20777862302719, 43.76552789442001, 44.23673006796068, 42.41670323956398, 42.84124881990495, 40.61613528959213, 42.877334625490256, 39.83088854820498, 40.317042796842514, 41.63071517021426, 41.86783029187111, 42.63049202580606, 43.12341628536102, 49.63964200788929, 43.37561292033042, 42.653096645109116, 42.74401326333323, 40.778897962262555, 41.99207528944939, 42.81988366957634, 43.29127019451511, 39.853222523966146, 40.345758468874045, 39.76719710134691, 41.452408144550944, 40.24547915304861, 43.106769746349705, 46.362525263140284, 48.27636734131844, 48.92103241335962, 49.15522144686792, 48.557577748452466, 46.960855376335886, 46.65691091168312, 46.16151948128977, 46.12335089714297, 43.80723445646225, 44.34455210162748, 43.52499246597291, 41.50116320579283, 40.53289082742507, 41.602697680073405, 42.137901167715754, 41.552350136541556, 41.50279098941434, 43.5340609858113, 40.858125917373165, 40.98462235543036, 41.450074334298414, 41.98695267400434, 40.91972674092939, 41.14285076818159, 40.79257134468325, 44.33900194783365, 46.503079475895056, 41.13261730440202, 40.49036841238699, 41.19428873062134, 41.204914431418146, 41.82963817350326, 42.0233993376455, 43.62730749191777, 44.38373265727874, 43.56177253107871, 42.3205384900493, 41.88414735178794, 44.82432857636483, 44.15042223468904, 45.40719278397099, 46.93032756928475, 46.086421781970614, 46.67564807399627, 43.76365692384782, 47.69898660721318, 55.69698572158814, 57.71699459322038, 57.6490120733938, 58.40081276432161, 61.26061285695722, 59.39241932284448, 60.86327675850161, 62.591641718341464, 62.499466019292036, 61.028985131171446, 58.75573627410397, 58.54767807068364, 59.29082601301132, 64.08391921750962, 62.20781426275931, 66.71422927610337, 45.5266446451987, 48.801411890214496, 65.31381760874103, 65.17866449971353, 76.92012663810485, 63.23820913991621, 59.171362384673095, 59.6018542781953, 5.141042740114274, 0.09968012015545562, 3.1233377706620002, 1.2572675871272243, 0.14886190003204733, 9.192262772590883, 79.24344847279211, 66.60505402472712, 79.20271073618244, 59.5794104760693, 57.24869889597739, 26.2307995365512, 19.132027318400723, 45.86092472076417, 65.32667906053605, 63.75757017443257, 5.288763123173868, 0.18550578534843462, 0.03125992663685353, 0.05667977350493593, 0.0705298541053649, 0.037483724525138255, 0.22752409921057765, 0.2687725100305773, 0.11882063542162219, 0.369542489849752, 0.37657339967066245, 0.4123730254509757, 0.5222607692403178, 17.664011639933435, 88.27259555939706, 64.55601569144957, 59.108522092142415, 31.454445431309363, 29.82544783622988, 56.460812399464274, 71.24557879663283, 81.663707763918, 65.5063118473176, 84.82926445622599, 20.151102235240323, 0.836940638480648, 2.1455418775158543, 8.052400427479899, 20.70910842187943, 5.973922744874032, 5.459149412570461, 52.29758908671718, 59.363483998083304, 65.97797686053862, 69.64484383982997, 63.92082706574471, 65.41515596451299, 62.6479983329773, 61.49648066489928, 55.80839280159243, 58.699701293822265, 58.18838504052932, 60.07890078329272, 62.148182469029585, 61.595638182855424, 58.32500511600126, 58.67020114775627, 59.48020981204126, 63.7701766721664, 61.236388298773, 61.57621068339194, 57.10990582742999, 60.32032266739876, 55.92212584710891, 50.861652512704175, 46.57246228187315, 45.86704754060315, 47.1200918382214, 46.3790855100078, 44.48107411784511, 46.461451361256266, 47.237229501047445, 46.22232014133085, 46.45417144221645, 46.32450180668985, 43.755408179375436, 44.83456988488474, 42.15033900353217, 45.46071744734242, 41.48895286744641, 43.04966788138113, 43.28473552580803, 44.07141785467825, 45.294510933660696, 45.45191957104591, 52.57118617334674, 44.215462976886386, 41.64804812400572, 42.405214617329264, 42.1023174255125, 43.653163756093676, 45.425137627509336, 44.937508567687004, 42.67407740316084, 42.45144759455035, 42.02366213644705, 43.807465876302416, 43.77745189974385, 46.28922008698987, 47.99680432965679, 52.43444058202928, 52.60965677999681, 54.378771243556855, 51.85442401516823, 50.20178825624528, 48.273970773143155, 49.009246518535, 49.06528542118688, 47.49720811843873, 46.523958252322295, 45.33735106068273, 44.398437623054754, 43.2606678624307, 42.94062206822057, 46.84724784666493, 45.22026438866892, 44.32281824850267, 45.239370253778276, 41.89156063141362, 42.873251438140876, 43.04206632798718, 42.44863133276663, 42.07932449156239, 40.33662326874272, 42.756784500614295, 43.64016502134262, 48.40744118536673, 42.600489816358014, 45.13962045792611, 44.01957981048092, 44.563326220358576, 43.797357928368356, 44.14792368488927, 44.03288449010542, 47.36822097532211, 46.59640835177514, 42.78128362471058, 42.49243636285105, 48.35091983118365, 45.836205943938225, 48.37062974129954, 49.94020931182369, 48.961068045708444, 48.7217132506832, 44.88459579406246, 50.403558900279386, 57.37279484348913, 59.038405802942094, 60.47713902688796, 59.97004324390043, 63.35299730300904, 62.30589705128824, 62.773808356254335, 63.92971907892535, 64.5608441291317, 64.67674624535346, 60.75115580712596, 59.866645643788004, 59.54752945130872, 65.33165654828473, 64.83763794745168, 69.27880825534945, 45.039321530249815, 47.80224692436957, 68.16174860923522, 67.92534735894972, 74.97590972531226, 64.86595746009581, 62.66906146080264, 62.03825804495043, 6.597993902621731, 0.3076665487981612, 4.9425663967286395, 2.724452090840186, 0.5317444474466386, 10.023488517730467, 83.33741449540662, 75.46269939791772, 85.13938273152998, 70.98901656366164, 76.57061207679011, 36.18760678075975, 29.184052059727332, 58.5835010774674, 75.00491957510673, 78.20216901840703, 8.139245625465147, 0.5836918889995545, 0.2710920404041967, 0.204604204083162, 0.24182754298371656, 0.10760745243920435], [0.03127120536631875, 0.04469517445672424, 0.016944045426263925, 0.08370082074355695, 0.0704298643094878, 0.05399928931447287, 0.17676786309288395, 7.5311546940957355, 65.35421802151588, 51.08699267910373, 39.04946219536566, 26.06304172546633, 31.78494041965854, 52.44093602703464, 50.65861494310441, 70.70342879141532, 56.287020021869296, 74.97092831519343, 18.46740914929298, 0.11957823509170164, 0.5265624448657036, 10.086552385360966, 7.28505636415174, 2.420344847825266, 7.215169533606499, 49.6969086124051, 61.56826003905266, 66.13575027834985, 59.261859309288766, 57.48186026850055, 57.97545917572514, 53.6746391173332, 53.06849564275434, 54.847290515899665, 56.80243122962214, 57.13794685179188, 56.19104354612289, 56.061515115922504, 58.28986460162748, 57.78918973861202, 58.75980769434283, 55.695467764331454, 56.06292716918453, 54.54509150597357, 57.058962083631954, 53.54338484425699, 45.545389652252204, 44.06956649595692, 40.38672370295371, 42.036590268535, 42.854592723231164, 41.84579833861321, 41.15126425220121, 38.67005525096771, 40.17766529513944, 40.94557516036495, 40.45893061545588, 40.97664425449987, 42.32212312759892, 40.64471367866763, 40.45537694807976, 38.41159851320329, 41.546556795797045, 39.81666995633034, 39.48295862443986, 38.83563418542185, 38.99161115769417, 37.69119247313469, 41.122572114390714, 48.985704452760764, 44.2928199614248, 41.09067932251961, 39.710405103621945, 40.42845772158715, 38.21709602109848, 40.819757292347575, 42.366779312010735, 40.38818282465781, 38.92189495025143, 39.60872157927483, 38.42278511293473, 40.159685150269546, 39.54058216464135, 40.77108067850913, 45.27888421089419, 45.163837171369984, 44.812655602732015, 46.42640498376662, 42.665432499301055, 42.835012251330966, 45.07561522145426, 44.167029549998624, 44.361332001224646, 39.01580433691702, 38.433512795356016, 38.33366886261971, 39.69052653158865, 39.73031113224645, 39.672448327464444, 37.890131165904386, 41.703600652756236, 41.73780372065883, 40.92588093972976, 38.89841564239995, 42.80234283016574, 39.75016224768854, 39.69374287512995, 40.98463804491105, 39.63788832387617, 42.84004857463222, 45.31350697240522, 38.444656249015566, 40.43375292131978, 39.64004562747094, 41.48983147836501, 38.27729655850319, 39.24323904898859, 40.439750225313254, 41.88998776097452, 40.285589310430716, 40.49716587989561, 39.08011159589214, 40.523292787613414, 42.41114524102981, 43.86150044779624, 46.627489213020574, 45.680640820534, 43.892224373355994, 43.03756344702936, 43.3064889907837, 45.076525211334236, 50.66686760994696, 52.84618746849799, 54.9695860955023, 55.76038299068328, 57.548324831070445, 58.39044593995618, 59.70555782318116, 58.24574970429944, 58.54657980703539, 60.14108211763444, 62.31164332359069, 62.7096736815668, 61.31005825534944, 59.48739167182677, 61.76602986551101, 66.83732894159132, 65.26058320076235, 59.71358691492389, 73.66025263263334, 60.373090313326934, 55.547668933868415, 74.17912729324834, 54.339190606148016, 3.978441679669965, 0.1417211025592781, 0.9431271663596554, 0.7817297236573312, 0.04617983370178169, 5.397445136500943, 73.64526917857509, 64.09514504094278, 71.22943432100358, 63.43021308222125, 45.78452871691796, 19.51574298643297, 17.734139696244274, 38.511971965912856, 58.127654983151345, 61.95657076374177, 4.4661915975232285, 0.45115880067310027, 0.05617363070468268, 0.05343833292323736, 0.07958689794665383, 0.012936467124569802, 0.062477465628856615, 0.04304007980071249, 0.03410485926114264, 0.06642988943044217, 0.0443138312097759, 0.13252354287091764, 0.3737967293108664, 12.5322433440916, 74.69144375093522, 57.82837421663346, 43.52195655145953, 27.75777824463383, 23.87855218302819, 50.59592762301045, 59.562422690853, 74.50007915496826, 62.49874430318033, 77.62590223743071, 21.410100690780148, 0.2950580898792513, 1.8523477714869285, 9.806140180557005, 13.852878905111744, 2.843177087845341, 7.1232228029158815, 51.86112734579271, 62.15717646383471, 66.44438589772871, 62.228983294579294, 60.55585707387617, 58.10028076171876, 55.448330986884336, 55.247317360293486, 56.267945535721324, 60.09864991711032, 59.03592294262302, 59.64354122838667, 58.959283751826135, 59.47527547036449, 59.02424212424987, 59.94479494710123, 58.495698821160104, 58.50588129412744, 57.94915576134959, 59.176677196256584, 54.9023723602295, 48.8476840911373, 45.22280216217042, 43.3172990429786, 43.64019247793382, 43.00630215675601, 44.67820852033554, 43.245076440995746, 41.10350939535326, 42.21434031763385, 43.25780453220491, 42.830148512317294, 43.50875385345952, 44.93866174451767, 43.78784618070049, 43.54332170178814, 40.89203088514267, 43.47459000925864, 42.61049970503777, 42.64151780836044, 41.28884530836537, 41.0845604250508, 40.27989795131069, 44.03603023098361, 52.914346494982325, 46.37224097405711, 43.151927994143584, 41.059672986307454, 41.07415437698364, 39.500385715115456, 42.55501385658018, 43.55982703547324, 42.31021873412594, 39.89365039333221, 41.97567585975894, 40.599971202112016, 41.55193044293312, 42.51988903168709, 42.437770289759484, 48.563782938065074, 46.71466781247047, 49.25051935257451, 48.56675217228551, 44.72182135428152, 45.10606065873177, 45.45597137943391, 46.34681617060016, 46.14260188994869, 42.66330657466766, 40.667573252031886, 40.39797306060791, 41.59308002841088, 41.11098935527187, 41.69972142865581, 39.74807946912704, 43.07819527964438, 42.77141494135703, 42.741342129245886, 42.32103663106119, 43.90605072821341, 39.96740271968227, 40.6082905492475, 42.255764469023674, 42.23120258700463, 44.29818184145036, 47.45458372177617, 39.9998995565599, 42.68100430888515, 42.043054334578976, 44.0422236534857, 41.38479432752056, 41.125619796014604, 43.4425324778403, 45.4048119052764, 41.82890469028104, 42.06789470488026, 41.13951675353512, 43.17903941677463, 43.73070509203019, 47.15237294473956, 49.50836812296222, 46.63674992899741, 45.312608749635764, 45.335162378126576, 45.17738896031534, 48.780093808327955, 53.2745377479061, 54.7506001687819, 57.2581910317944, 56.24848273492629, 60.137685345065215, 60.329602995226466, 59.35480771526214, 59.59431156035393, 59.73800366924655, 60.89724840656404, 65.97618041499969, 63.50265141456359, 62.47311945884459, 62.111316111779985, 65.6686822829708, 69.22709572699763, 66.3594352045367, 60.539963629937944, 70.68162041325724, 60.299051653954294, 58.49419263101394, 72.35107529547908, 57.11575408135691, 4.853380034046789, 0.14404170545599154, 2.2390090169445163, 0.8477521002773316, 0.11785484369724028, 5.3717408641692135, 77.62704756952103, 69.246338875063, 78.59544154136412, 69.55411157300396, 49.77281039760959, 24.743109249299575, 24.152423835569813, 52.25914985902848, 63.86738084977674, 71.2725176349763, 6.809929368957397, 0.514338133075545, 0.07944475799318283, 0.10533892053870425, 0.18118777672850317, 0.023607591189624324, 0.16529560449623293, 0.15840920950135878, 0.2242087464659445, 0.18737715428635, 0.1927680996877532, 0.3107912682237164, 0.4706451663326833, 17.131951931984194, 89.00837729054113, 65.59113702466412, 55.581954371544626, 38.13216101738715, 47.67598975089289, 65.96114204775903, 63.40826742110714, 81.8057446325979, 67.01492601825346, 85.70392162569108, 23.610144392136608, 0.30488424003124237, 1.115065856326011, 22.357564895383774, 19.44192005741981, 5.705430623023741, 8.815377912213727, 54.04888814495456, 64.27247931880336, 68.34636672850579, 65.74597650958647, 63.3609087236466, 62.41852006604595, 58.04822698716195, 58.312622193367254, 58.53836636389456, 63.220723213688025, 60.678360539097945, 60.24063187260782, 60.81379213640767, 63.003239554743615, 60.77693754626859, 61.245739229263805, 59.14149353581091, 60.288229834648874, 60.01356978570262, 62.3583548299728, 58.28417716487762, 51.23570149944675, 48.400463288830174, 45.90913065018193, 45.989707900631814, 47.4694416599889, 47.90164370690623, 45.28539534538023, 43.47418208276072, 44.329513734386815, 46.53881619053502, 45.32970243884672, 45.36803576254076, 47.083617717989036, 44.83794312323294, 46.04530357545423, 42.99531167553317, 47.0042367904417, 44.39824542691631, 44.36252440175703, 42.93590737927345, 42.57707326642929, 42.01877486321234, 44.999815417874245, 53.953762823535556, 48.89698436183315, 42.38583026393768, 42.06702786107218, 42.16653446997366, 39.98626147547076, 43.24484109878541, 45.314750363749845, 44.614658278803674, 41.993561867744695, 43.56745212308822, 43.372227914871715, 44.791670922310125, 44.96905619098295, 43.693050338375954, 50.73080224375571, 49.33795682845577, 50.485336396002005, 49.41831050380584, 46.55285435338175, 47.371205899023245, 47.98275047732938, 48.435992117851015, 49.7471502519423, 44.16705308421966, 44.21192499899095, 42.061148228183875, 43.76676344102429, 43.943423071215236, 44.74686568783176, 43.11745428269909, 45.28298308772426, 43.89747250464655, 43.445611538425574, 41.25171615231422, 44.67224651767362, 41.17884635925293, 39.52148806664252, 42.80161719168387, 41.77096343809559, 45.17358033887802, 50.560355647917724, 42.96117528792351, 44.5954425873295, 42.76673947611163, 45.91946609558598, 42.93359318087178, 43.196125261245236, 46.09418415254163, 48.161312457053896, 43.81280422210694, 46.445499081765455, 43.14507953582272, 45.124625236757346, 46.51162632050053, 49.310782647901966, 51.94472089890511, 49.67262914103847, 47.98909687226819, 48.46596294833768, 47.795139589617335, 50.588200553770996, 55.1052059665803, 58.44852447509766, 59.09134211078767, 58.82201648527577, 62.27817766128048, 63.13858093753938, 62.232866441049886, 62.20308780670167, 61.03592380400627, 62.12294986171108, 69.00981210893201, 67.33390100540655, 66.16512098620015, 66.89598406514814, 69.29483505987352, 73.05385420399328, 68.63881864855367, 62.31397713384321, 69.42009987369661, 62.196243270750976, 62.07413596491661, 74.3517037360899, 60.86866609511837, 5.477160936401737, 0.41460215744953005, 4.471172517345798, 2.4133745508809246, 0.29972469914824734, 6.754121886145684, 83.3216622567946, 77.14408613020375, 85.0113957928073, 78.65877213016634, 58.01940541113577, 31.946571488534254, 32.54365821038523, 60.346720218658454, 76.72568690392279, 83.48647240669497, 10.996864880284956, 0.8940205014040394, 0.257895685612194, 0.21514480783333703, 0.2607462681349247, 0.24377918261433804], [0.05169157584708545, 0.04769178099870201, 0.08326052703083524, 0.0754082560419075, 0.09083964937036076, 0.07345965778034541, 0.18468812438509158, 6.4920227373799975, 63.39386055546423, 53.61825896847633, 54.955512631324034, 30.01733999098501, 28.345592483397457, 53.45655533575243, 51.78977158761794, 70.3929025896134, 55.102217120508996, 76.30363202864125, 17.920150256926014, 0.2095112577080727, 3.363461840537287, 15.21545146742175, 5.1108797134891635, 3.73502821210892, 8.640757914512388, 54.729823373979144, 58.75468900126796, 58.106646768508426, 61.823657328082675, 56.27020874331075, 54.487236545931914, 50.63102891368251, 53.457018175432765, 55.34951471513318, 58.89354090536795, 58.10623491964033, 61.582725740248165, 56.13879365305747, 57.282113567475356, 55.66942714875745, 55.54006738047446, 55.52084776663012, 56.1128903204395, 53.35927663310882, 45.85772798907372, 42.51028706950527, 42.95734705463533, 41.18296484793387, 41.27204971928751, 40.346260532256096, 40.94125270843506, 39.77245699974799, 40.417176984971576, 38.86282797782652, 39.308217033263176, 38.4491434404927, 40.53897442356233, 40.91474533081055, 38.87956865372197, 39.51443172270252, 39.988132446042954, 39.59237314039661, 38.33600267287224, 40.0758287983556, 38.79255087144914, 39.0017936306615, 39.80327506219187, 40.4513329844321, 40.5639010860074, 49.96930937613211, 46.63913865243235, 41.08579989402525, 40.3273311738045, 40.65186415949176, 41.87624377589072, 41.640458337722286, 40.266695253310665, 39.32685221395185, 40.01637351128363, 38.37590494463521, 38.45257943676364, 38.792005661995184, 39.8654563965336, 39.94663376961985, 42.65355164004911, 43.20393862262849, 46.97072013731926, 48.05145471326767, 42.279118261029645, 41.13490796858265, 45.22963100864042, 41.56772974998721, 41.125384453804266, 39.70219166048112, 37.59662412828015, 39.55866036876556, 39.222579925291, 38.09444742818033, 38.19131428195585, 41.212955290271395, 40.16552948182629, 39.88890824779388, 40.6586733941109, 39.29300215936477, 38.86257694613549, 40.87774169060492, 41.17117812556606, 41.55834744053502, 39.29399844138853, 45.37870853177963, 45.12756701438658, 37.68790552693029, 41.58624725957071, 39.684211515611224, 39.84655057230304, 39.8242126741717, 42.0804266775808, 40.98585005729429, 39.904319240200905, 39.400655531114154, 39.05005447326168, 41.58934985437701, 42.86756007902084, 45.51219855585406, 46.159217049998624, 48.447096347808845, 49.62942031122024, 48.62772933898434, 45.15974613928026, 42.48942790492889, 42.153304315382435, 44.204986326156124, 45.58218932920887, 49.41391352684268, 51.59894435636459, 54.58126752607284, 55.4977842300169, 57.737124196944706, 59.73382242264287, 61.36539505374048, 60.65943510301652, 57.93886346201743, 56.286306150497936, 59.671209627582186, 61.205593770550145, 57.706031568588756, 59.13269173714423, 61.51318996183334, 68.10596466064453, 56.738692714322, 41.45409084135487, 70.02983231698313, 76.96851299655053, 59.6566850908341, 3.1832566328587073, 0.18899099510763923, 1.4887797255669872, 0.4099669271419126, 0.08420296073440584, 4.46044042225807, 67.57471099976571, 68.19905034957394, 71.62868453610328, 68.16748311442714, 59.63625738697668, 26.51337100613502, 8.125439863051138, 19.541662008531635, 54.19474147981214, 60.77788675985029, 7.898939165376849, 0.3198472855071868, 0.11110021582534237, 0.07374408324399302, 0.023490025421544432, 0.09504595471005287, 0.048545451924925855, 0.10325408120068813, 0.12391305168069179, 0.05839659569544658, 0.08872065017180097, 0.18169748566804395, 0.31322623272576644, 10.168528941369827, 75.6068229675293, 60.45984921916839, 60.85581641043387, 34.5074281384868, 33.11496319309358, 53.96815792206795, 55.43199039274647, 75.35988623096098, 61.1986864766767, 82.80941640177082, 18.777841214210756, 0.1921658932922348, 3.1898089522315614, 24.267272795400313, 11.996999652154985, 4.9966328374801146, 9.79928485808834, 54.89013848766204, 59.843648787467714, 61.43650762496456, 64.00920983283751, 58.766663997404045, 56.70584678649903, 52.43564867204236, 55.840124776286466, 56.705913466791955, 60.141682240270804, 59.588828086853034, 60.97702941586895, 59.06905520346857, 58.55810765297183, 58.523865361367505, 58.76051764334402, 58.69288813683295, 58.04899969408589, 56.01488990168418, 50.072330428707986, 45.327549057622115, 44.49216265832224, 44.27721285050915, 43.279683513026086, 42.40754842758179, 43.85236917003509, 39.57628750031994, 41.52789808088734, 41.89599683207851, 41.8261904101218, 42.17920372563024, 41.97499728971913, 44.79550700033865, 41.23936853101177, 42.20856266637003, 43.084608354876124, 41.43989578370125, 41.13783797910137, 41.19523402183287, 39.82991187803207, 41.13870090053928, 40.904688373688735, 41.654457276867284, 42.89332612868279, 51.380040799417806, 45.86252897016464, 41.85914224193942, 39.96029146255986, 39.690522609218476, 42.01970838731335, 42.545090260044226, 42.63233161741688, 42.31511777447116, 42.96108507340954, 40.23905823307653, 39.69956759483584, 41.1613525882844, 41.026258314809496, 41.3594126701355, 44.63040659504552, 44.831251559718964, 49.6929705527521, 48.92313872614215, 43.75902068230414, 44.736204685703406, 48.68848293058334, 44.47141724248087, 43.06577313330866, 41.5974417040425, 40.508121059786895, 42.31428623199463, 40.99210623771914, 39.54999193068474, 40.41549821053782, 43.45480557410948, 44.158129692077644, 43.21865143314485, 40.88322908647599, 38.86831145132742, 40.00976431754328, 39.914960630478404, 39.346009069873446, 40.77537959621799, 38.97666300496748, 46.64963883738364, 46.92909594505064, 38.92535448074341, 41.48741137596869, 41.31361115363337, 42.21700360698085, 41.78769626925069, 43.73888715620964, 42.62266689731229, 41.41551040833996, 41.314544677734375, 40.275571577010616, 43.297243964287546, 45.56413858167587, 47.604273134662265, 48.967751764482074, 50.1430429181745, 51.92720359371555, 51.61751677913051, 47.20085736243956, 46.17386318022206, 45.50847230419036, 46.67098437586139, 49.80491499747, 52.050181665728175, 54.108512093943936, 56.81825407089726, 57.4559098674405, 58.72938579128635, 60.259824029860965, 63.76027660985147, 62.05700305200393, 62.26336286913965, 59.24977840915803, 61.06387069148403, 65.09653791304558, 60.378220773512325, 61.17730955923758, 64.3382574665931, 68.66145856918828, 58.31045312266196, 41.7992986402204, 72.48172160117858, 74.40318092223137, 64.17062321016866, 3.427004482476942, 0.15414917841553688, 1.8896436282703954, 0.8002444140372739, 0.13137799627598257, 4.829113310383213, 73.11747504818824, 72.4999370882588, 77.81160293086883, 74.44411477734967, 55.642735419734834, 31.4111699211982, 17.48982898650631, 30.4340055296498, 62.55960772114416, 72.71418479181105, 10.783624245274453, 0.29508594483617817, 0.1052105701678703, 0.09473249451407502, 0.05342367766124587, 0.05609972620262735, 0.19105410053124353, 0.20385647162554726, 0.32691885927511805, 0.16764841372928313, 0.22609784267842772, 0.3383041209270877, 0.56814122344217, 14.43296411345082, 87.08191302514847, 68.16440797621205, 73.65105859694943, 41.485889496341834, 38.898278359443914, 63.615866707217315, 65.11821685298797, 79.67668210306476, 67.98088812058973, 89.45179339378112, 22.404292091246575, 0.40253397437833977, 6.613872637671809, 22.985740323220533, 8.139372612199477, 6.315559715993944, 12.257453856929658, 56.827357892067205, 60.14104289393271, 64.81987353294127, 65.69507198949015, 61.11114701917095, 60.09903823175738, 56.435854358057824, 57.48175044213572, 60.870670426276426, 63.35588416745586, 60.200725678474676, 63.46153713041737, 60.81742425118724, 60.8432020679597, 61.11463008388397, 59.76216546950802, 60.46366960771623, 61.457268730286636, 59.45070966597527, 51.174963597328436, 47.3857775042134, 47.72134019482521, 47.3785368088753, 46.32634532067084, 43.41622121872441, 45.27846451728575, 42.55310366230626, 44.302061065550774, 43.1331947542006, 44.86154402455976, 44.7681406236464, 46.18224136291012, 47.527433902986594, 43.510236509384654, 44.555963931545136, 44.26753244092388, 42.933906970485566, 43.16188296964092, 44.42149331492763, 43.79132924541351, 42.64872712473716, 43.52221150552073, 44.395758644227065, 45.270447192653535, 56.278822268209154, 47.550520973820845, 41.823727161653586, 38.9387454525117, 42.50570181877383, 43.92683929012668, 44.90267792055684, 45.20553981104205, 43.98971880635908, 44.328372324666674, 40.83012019434283, 41.239380298122285, 42.50158333009289, 45.61304661535448, 43.813494559257265, 47.71045561759703, 46.95593280176963, 52.55984660117857, 51.30845362140287, 45.520215880486276, 46.84840102349558, 50.828665379555, 46.566284548851755, 45.6043585654228, 45.69352972892023, 42.62027032913701, 44.58325186083394, 44.756244074913766, 40.44948162571077, 40.473270800805864, 45.91986225497338, 44.28940357700471, 42.89868408633817, 42.21355584359939, 40.47267460053967, 40.76164345587454, 40.29341051655431, 41.41790697651525, 41.875718178287634, 40.05221220754808, 48.810986395805116, 50.59142866442281, 41.55072627529022, 44.69534927798856, 42.39366715954196, 43.96821637307444, 43.16225951717746, 46.38416497938095, 45.90654580823837, 43.96757310436618, 44.237196830011186, 43.04245072026407, 47.03602760068832, 49.13892007643177, 50.07304037770918, 52.410882826774355, 52.5270712760187, 53.75081546844975, 54.624723465211936, 49.5418651642338, 49.11369923622378, 49.06304574781849, 48.293202154098026, 49.9927023918398, 54.0873783634555, 57.34325939609159, 58.561680932198804, 60.29894182758947, 61.041128789224935, 63.76702700891803, 69.18827210703205, 65.14872112581807, 64.23817819164645, 62.987997224253995, 63.133336728619, 68.6243215683968, 62.84373637168639, 64.19275714505103, 67.32222803177373, 69.56136795782274, 62.50571435497653, 48.69972836586737, 73.69370260546285, 75.84063545350106, 65.8739399140881, 4.541802637038693, 0.38754362552877397, 5.614629714719711, 3.3430785084924395, 0.26597818900500575, 5.281950946777098, 78.42564213660457, 78.61107610887098, 85.08698771076818, 84.11734642521029, 73.96889609675254, 37.067916085643155, 19.236809515183975, 37.68759958205685, 74.26661968231201, 84.48124039557673, 17.624536906519246, 0.6934612568828368, 0.3199553958350613, 0.27232020192088624, 0.13698021340514385, 0.19743231876242548], [0.04939338868303646, 0.07175297476351261, 0.04658299513281353, 0.022352061181839918, 0.03351067380619145, 0.13635257289053934, 0.19138960107680292, 6.921717899460947, 64.83154650657409, 57.93279947773103, 44.83812747463104, 17.350092587932465, 18.771702704891084, 46.46045900160267, 51.03463295967349, 68.00172375094506, 61.07367269454464, 71.92340358611077, 18.032065283867624, 0.5390770733356476, 4.895731825982371, 6.48214424810102, 13.518598829546283, 2.3761282140208833, 4.53056602708755, 65.12222943767425, 66.66453284602012, 63.274922524729085, 60.02803156452795, 53.29495368465301, 49.5914400008417, 50.2456364324016, 50.57616279971216, 54.44866395765736, 58.35960042092108, 58.36631551865609, 57.80789944433398, 61.0413327524739, 59.01663272611557, 57.447810173034675, 56.82829141616822, 54.46036438788138, 47.89491291969053, 41.960453141120176, 41.36206027000181, 43.33314541847476, 42.21600340258691, 40.899769721492646, 41.23648166656494, 41.117629927973596, 39.76742067644673, 41.407571531111195, 41.06287364036807, 41.01093753691643, 41.05502890002343, 38.98569622347432, 41.11451556605678, 41.022532063145796, 38.535298301327614, 39.084010431843424, 38.403938124256754, 39.01138774810299, 39.90405251902919, 39.5596174270876, 38.78577301579137, 39.115656114393666, 38.85419876344743, 40.25407698846633, 39.096915029710345, 47.83075078841179, 53.259452312223374, 41.98943161195324, 41.19994871077999, 41.59468427781136, 39.164505312519694, 37.370099406088556, 38.56313144007037, 40.713272786909535, 42.63185701062603, 37.81847338522635, 39.856132922634, 39.72788318510979, 37.83020519441174, 38.95745908060382, 40.019633000896825, 40.140128212590376, 43.473189723107126, 44.72544954669091, 43.16100043635215, 39.59814686929026, 42.12603207557432, 43.77234889614967, 41.35231318012361, 39.646631286990264, 39.13298906818513, 39.320894133660104, 38.29195053346696, 38.85134720033215, 41.19119398055538, 40.89072081350511, 40.65915192327192, 42.02867884789744, 40.75239058463804, 40.265883322685, 41.03377357605965, 39.74516122571884, 38.11593809435445, 40.747040471723004, 39.6503379268031, 49.450069935091086, 42.83325895186394, 38.3347749710083, 39.35881953085623, 39.48219376225626, 39.610616084068056, 40.428092941161125, 39.45170125653667, 41.43243151326334, 41.744950279112786, 39.52368067156884, 40.262643444922666, 42.27720022201538, 46.08512739981375, 47.0235348516895, 51.50523893294796, 50.932859220812404, 51.6234121014995, 49.861491264835486, 50.14999335811984, 45.992143692508826, 44.45825376818257, 41.59156599352437, 44.80406953442482, 42.62180397587438, 46.87547322242491, 46.825109989412375, 53.07452040333902, 54.06630739088982, 56.54733988546557, 55.81883415099114, 56.33959547165902, 54.19651046875985, 55.974458109947946, 54.09839237889936, 54.48990375764909, 55.55609810736872, 63.738276035554954, 58.68833818743306, 67.91881269024265, 54.81538595691804, 57.666011625720614, 58.44143282982611, 65.37367689994075, 56.688172586502574, 2.2747498991027957, 0.09471807673934007, 1.1079168463906934, 0.7795623689889909, 0.09367337029787803, 3.6381260570018523, 65.90482465682491, 66.3632869720459, 74.081468120698, 66.1118551992601, 57.356870020589525, 30.658421977873775, 13.706024385267689, 32.66291395310433, 54.87691225544099, 62.748077607923946, 12.4166932605928, 0.15521715094725932, 0.08688935529320471, 0.05213807104155422, 0.02641125465743244, 0.044621936451163025, 0.049670068997769594, 0.020930661647129926, 0.036998790869068716, 0.08138931131050473, 0.05774220722096582, 0.05313790388285153, 0.2545401745385701, 9.42073985453575, 76.71865801657401, 64.14085634293096, 56.52339381556357, 23.278890425159087, 24.357895235861502, 51.88334365044871, 57.24919703698928, 72.95170783996582, 67.44533554200204, 77.23633243191627, 20.085659450100316, 0.5011134330303438, 0.05782741918078354, 6.693353095362264, 10.377334356307983, 1.6119059896276844, 5.480648413781197, 65.45594076956472, 66.01652591459214, 67.3237185324392, 61.69972612011818, 56.870358836266306, 51.72855907870878, 51.634163318141816, 52.60678560503068, 56.36704421812489, 59.706962031702844, 60.20525209365353, 59.03108273783038, 61.30247631380635, 60.610578060150154, 59.993565697823804, 58.878431935464185, 55.98409537346133, 48.94799478592412, 45.06505620095038, 43.58278466809181, 45.80792565499583, 43.96044615776309, 41.794332919582246, 42.42906262797695, 42.94908654305243, 43.12346335380308, 44.17872605785247, 44.58056111489573, 42.1185834946171, 43.31283930809268, 41.81838489347889, 42.86135881177841, 42.12764416971515, 40.39749453144689, 41.61980705876505, 40.068246856812515, 39.95415295324018, 40.90851268460674, 40.39837706473566, 39.277999093455655, 41.44069986958658, 41.42727751885691, 43.745872897486535, 42.48977699587422, 50.28026703865298, 55.70787814355666, 42.628656356565415, 42.01546438278691, 40.662803649902344, 40.89856947621992, 38.88030998168453, 41.71527754875922, 41.29908269451511, 43.03275854356828, 39.897761037272794, 42.90081785571191, 41.29035934325188, 41.074628983774495, 41.055428981781006, 42.10099166439426, 43.29507489358225, 46.36963259789252, 46.2759389415864, 46.52093802728961, 42.799197089287546, 44.03332379556472, 44.471013238353116, 44.08646406665925, 40.506481509054865, 40.56292049346432, 42.98850636328421, 39.98799516308693, 42.44000604075771, 43.300880001437285, 42.17119424573837, 43.14842139520953, 42.124863209262976, 40.22924054053522, 40.51501658654983, 41.709331235577984, 38.335712417479485, 37.21370666257797, 40.98433210003761, 40.36703732705886, 50.20601657129104, 45.19616142396004, 40.47236865566623, 41.72779383197908, 40.29102179311937, 41.01079633159023, 42.768088771450905, 41.39897369569348, 43.136701353134654, 42.44199860480524, 42.84892882070234, 42.81985621298514, 45.040710049290816, 47.72978113543603, 48.8676058092425, 54.66312346919891, 51.14226671957201, 52.98904019017374, 52.882190904309674, 52.28617498951574, 48.17890428727674, 46.81258978382234, 44.167276659319484, 47.68151637046568, 45.485471525499904, 48.30177645529471, 49.727495255008826, 54.15447834999331, 55.98673120621712, 59.27266936148367, 58.90217404211722, 58.057017018718106, 56.42920594061575, 57.92576666801207, 55.929731322873025, 57.224470415423, 59.30296182632447, 66.10805050019296, 62.04317277477634, 68.93360830122425, 59.33666675321518, 60.389097506000155, 63.986754263601, 63.92839724017728, 61.48874967328964, 3.2712380924532494, 0.17188396064504502, 3.576112158836857, 1.2579175974092176, 0.1095282493699943, 4.398426278944939, 70.54988368864983, 72.40626304380356, 77.89923652525871, 75.1086191977224, 54.73418897198093, 20.285588541338523, 15.309566778521384, 35.35715080076648, 65.28616097665602, 74.49034383220058, 15.79491105771834, 0.25046233448290056, 0.09317819404626086, 0.05083806579932571, 0.08594700585930579, 0.027655664898995912, 0.1744824083101365, 0.15190120065404525, 0.12524181586359778, 0.22765001342181237, 0.12740565418836572, 0.3844581910919759, 0.6519004966943496, 13.915096521377565, 86.57358169555665, 70.92435236900084, 64.27908851254371, 29.435038643498576, 28.546153076233406, 59.706601173646995, 66.8888218172135, 78.74544866623418, 71.60232620854532, 84.00732394187682, 22.16419008470351, 0.9759512147115124, 9.334467322595659, 14.966917345600745, 29.97114819865073, 4.219708385006074, 5.783433818048047, 67.63501351879489, 66.19290705650084, 68.16866767021918, 63.590904743440696, 59.199336728742054, 53.58729970070624, 54.5104177536503, 54.206849836534076, 58.068352668516106, 61.851647361632324, 62.770333136281664, 61.2675868311236, 64.2487411345205, 64.26544258671423, 62.88695696861514, 61.337840403279955, 59.92955653898178, 52.2420600921877, 47.21086725111931, 45.18707721464096, 48.726980993824625, 46.88136462242373, 43.95938711781656, 44.63413284670922, 45.682029339575, 45.27566002261254, 46.46196519174884, 46.025805473327644, 45.06416582292126, 46.12362546305503, 44.16844160326066, 46.70479912911692, 45.82200304154427, 43.50277223894673, 43.012315150230165, 41.41536920301376, 42.68901378877702, 42.24400520324707, 43.20779039013771, 41.18836595166115, 44.32606597100535, 42.58144670917142, 44.998458277794626, 44.711466297026604, 54.32658018604402, 58.022786494224306, 42.81350981804633, 42.47689985459851, 41.78342873050321, 41.85367838028939, 38.72292095615018, 43.34483408158825, 44.0954972851661, 46.8338058840844, 42.58278815977035, 45.25186300277711, 44.28443001162621, 42.64825644031648, 41.724604945028986, 43.730293243162095, 45.402980158405924, 48.42031440427227, 50.35814177605414, 49.95716571807862, 45.651309336385424, 46.74614483310331, 48.20079503520843, 46.88821308074459, 43.60268285197597, 44.666998386383064, 44.330011875398704, 41.92828578333701, 44.37810405608147, 44.620145674674745, 42.58832262408349, 42.74347589861962, 44.38012407672021, 39.872387224628085, 39.36405981740644, 41.51356966264787, 38.825804725770034, 37.65877800603067, 40.64433713113108, 43.402445854679236, 52.79229410233037, 47.790770069245376, 42.85851117103331, 44.365383809612645, 43.541842968233176, 43.42608205733761, 42.606263545251664, 43.14269081238778, 46.74012007251863, 46.24226539365707, 44.62830420463316, 45.0694453331732, 47.312946934853834, 51.88294749106131, 52.13465382975917, 57.426346963451756, 54.570869322746034, 53.925662963621086, 55.51314815398186, 54.39679453449865, 49.622987624137636, 48.999346456220074, 46.49363833089029, 51.33955017212899, 48.5911100910556, 50.93112161082607, 52.59676394924041, 59.76729985206359, 59.72975492477418, 62.946953542770885, 63.28630132059898, 60.53572747015185, 59.232249336857954, 60.234046213088504, 59.068961066584436, 58.5307098973182, 61.2970438311177, 69.75044973434942, 65.55421183186193, 73.45153547102406, 63.43062493108935, 61.22686478399462, 65.07527474434146, 67.14776885124945, 66.62157504789292, 3.1937661334391567, 0.1601062321494664, 6.207931839650677, 2.820032407199183, 0.26426092631393866, 4.9088550959863975, 79.0967518283475, 75.52902667753159, 85.19384876374276, 79.94548997571393, 70.33683623037031, 41.846284712514574, 24.129352454216253, 50.54779621862596, 74.17680525010633, 91.3085336069907, 24.41393021614321, 0.4419487384298156, 0.20699642087903716, 0.17470265858836714, 0.18563709281865629, 0.23736403894520577], [0.01410951436076674, 0.07840958168549884, 0.0902789342968214, 0.010464772536990144, 0.04915784728983718, 0.025076342618934093, 0.33367121952676004, 7.740228791390696, 65.02151866112986, 54.348639595893125, 39.16612917377103, 19.920843416644683, 26.010589830337036, 31.283716424818966, 53.839790513438565, 70.60806812778597, 58.0856385538655, 73.10063239066832, 17.138971013407556, 0.18489043288413556, 1.012819410572129, 12.857323500417895, 14.529789782339527, 2.4962147637721035, 5.344464211694656, 60.54256808373236, 63.522412315491714, 64.56567256681382, 60.448391975895056, 54.2476934771384, 53.33745648784023, 47.89288897668162, 46.80193270406416, 50.858820561439764, 53.85888853380757, 55.488570582482126, 56.5841160282012, 54.58237363446144, 54.72466153483237, 50.750421939357636, 48.593985188391905, 42.31490204411168, 41.96262613419564, 39.96337836788547, 40.46679889002154, 39.61455022135089, 41.66884845302951, 44.6044248150241, 44.57365382102228, 44.549672449788744, 46.75304035986624, 45.604452702306936, 45.79242837044501, 43.6143950493105, 43.160502295340265, 40.376352956218106, 40.541963269633634, 38.147928945479855, 37.75353462465348, 40.69338244776572, 39.08396728577153, 37.59115634425994, 39.22216807642291, 37.2581353495198, 37.65582446129092, 36.47164521678802, 37.16018199920654, 40.04964305508522, 39.65430736541748, 45.493653589679354, 57.42414651378509, 43.505870911382864, 39.79539109814552, 41.08427801439839, 39.670820543842936, 41.6335000530366, 41.43672258623185, 39.12233591079712, 39.27429637601299, 35.770294051016535, 39.83703882463517, 37.78894970493932, 37.083817374321725, 38.22900041457146, 41.182184296269575, 40.62316417694092, 40.30152197807066, 42.704016854686124, 40.019633000896825, 38.31943850363455, 39.410892917263894, 40.49946831118676, 40.77767026039862, 38.41901179282896, 38.78916194362026, 38.91971803480579, 38.415438513601984, 38.74205820022091, 40.15755530326597, 40.48881123142858, 38.22821201816682, 38.865530490875244, 39.189875202794234, 39.442479764261556, 39.92539021276659, 39.38503273071782, 38.10887390567411, 39.58979222082323, 41.497993930693596, 52.76032286305582, 41.59862625983454, 39.859482626761164, 41.030914168204035, 38.71470751300935, 41.100999078442975, 37.412068766932336, 39.446151102742846, 41.29242643233269, 41.757803886167466, 39.873014803855654, 38.871606242272165, 43.12336921691895, 46.8071690682442, 46.256986048913774, 49.36248733151344, 48.53281974792481, 51.670927693766934, 53.39912399168938, 51.60824821841333, 49.7019527804467, 46.9448717178837, 41.9733851955783, 42.141407766649806, 42.69713701740388, 42.98752577074113, 41.66295313066052, 44.81635439780451, 44.894272281277566, 48.43778856338994, 50.27295574065178, 50.09138922537527, 46.512120539142245, 47.778861753402225, 47.22436804925242, 48.00751240022721, 52.67029662286082, 54.897532155436856, 59.414878814451164, 61.048189055535104, 67.75859171344389, 63.83455453380462, 54.07484639075495, 50.41458860520394, 47.22297168547108, 1.956957261408529, 0.09017335971997631, 0.5763877002942948, 0.7825358320147761, 0.0661164062518266, 3.7131690882867385, 63.67094855154715, 68.55895134710497, 72.9577326005505, 69.88251593805128, 69.79687490770894, 116.7067433941749, 31.94258636043918, 39.11111400973412, 54.327529399625725, 59.435330052529615, 8.338460845331992, 0.3446181256684565, 0.14419951956839333, 0.02477127108572712, 0.12142377920568952, 0.04022238543257117, 0.03394496905046605, 0.09240369447657178, 0.012870908192839595, 0.033136156402648456, 0.042647946205350666, 0.0628411352273918, 0.40006153285503393, 10.304647934052253, 76.42030685178696, 58.539735271084695, 50.0393589850395, 23.467293631645944, 32.056278221068844, 39.38224784789547, 56.97435655901509, 76.66707884880805, 60.404288845677534, 79.33419642909881, 18.34770037281898, 0.2876206631622007, 0.6536655632718917, 4.935414935311964, 9.2510522373261, 2.9316017752693546, 6.586308181285859, 62.27678914223949, 64.48263206789571, 66.72267021671419, 62.62258529663087, 56.432426206527225, 54.651199463875066, 50.690805835108605, 50.24762899644914, 52.49231907629198, 54.48445950784991, 56.51387030078519, 58.1077411097865, 58.64586676320722, 56.51651005591116, 52.93159707900017, 49.57555832401399, 45.273083025409335, 43.35850746400895, 41.06415625541441, 43.638972620810236, 40.576440903448294, 42.55350374406384, 45.91417089585335, 48.0906117346979, 45.228834767495435, 47.546528000985425, 48.47635722929432, 47.52143659899312, 45.715542070327274, 44.60411102541032, 43.7552002937563, 42.39596566846294, 40.60108515524095, 40.06985502858316, 41.35658464124126, 41.63355104384884, 39.930987435002486, 40.45921302610829, 39.83934517829649, 38.71779441833496, 38.49771022796631, 41.31490161342006, 41.8520898203696, 41.262945898117565, 48.53599294539421, 57.03451002797773, 42.99519400442801, 40.33919634357576, 39.23653179599393, 41.84691621411232, 41.55111851230745, 41.14691042130993, 41.02817635382376, 41.37654950541835, 38.19081221857379, 39.631561540788226, 40.047815230584916, 40.128969069450136, 39.49515327330559, 43.84989415445636, 42.58322354285948, 43.099011298148866, 43.64172220230103, 44.124667952137614, 41.08285027165567, 41.575672549586145, 42.12567906225882, 41.62445506741924, 39.719708965670684, 41.51853538328602, 40.87949106770177, 38.50093833861813, 40.39278376486994, 40.657288797440074, 40.28369088326731, 39.043841438908736, 38.33200577766665, 38.49782397670131, 39.565261717765566, 38.93053985411121, 39.448218191823656, 39.2137389029226, 40.18608270152923, 41.59388019192604, 54.273455604430175, 42.89225532162575, 41.40195861939461, 43.4843724004684, 40.74041166613179, 43.096485291757894, 39.43664327744515, 41.04124961360809, 44.17350930552329, 43.456931498742875, 42.348430464344645, 40.83153616997504, 44.98824834823609, 47.64710933931413, 48.434317265787435, 50.92057043506254, 51.47045535425986, 54.02558926613101, 56.83589296956217, 54.68884637278896, 51.99684527612502, 48.73920702165174, 43.83188263062508, 43.09791695687079, 44.78506957331012, 45.031300283247425, 43.71307403810563, 46.45423027776903, 48.47807130505962, 51.75956149255076, 52.13827809979839, 50.991498654888524, 50.25345371615503, 49.035530321059696, 49.09414229854461, 50.38921087018905, 54.2190601748805, 56.64410083524643, 61.90588589637511, 63.98767602059149, 69.63636367551743, 65.57494155822262, 59.15085231104205, 50.6767794393724, 52.16074935851559, 2.069409407915608, 0.22413903246483496, 5.016600643434833, 1.404369461440271, 0.14026008095712433, 3.8428968239215116, 68.25926657645934, 72.88297222506615, 78.0479492679719, 75.2250429891771, 67.46759107035976, 74.1612648194836, 25.440224255284956, 45.29082782806889, 64.53374839598133, 70.8154752177577, 13.626972936814832, 0.32297120820130076, 0.0887683697886044, 0.0688692742598153, 0.1527807002346362, 0.09758919041844145, 0.171144547902288, 0.19012926386729365, 0.2674730410498958, 0.1055101718332979, 0.18679789988504303, 0.2867713780893434, 0.7054010742614347, 16.003815512503348, 88.88494030121835, 68.73464215186335, 57.17723723380797, 33.26799838773666, 39.00471579643988, 45.77176140200707, 66.98504540228075, 83.21480904856037, 68.0616497224377, 85.0971152705531, 21.3742619945157, 0.4416674615875368, 4.361969809378348, 35.795291316124704, 30.556175593406927, 5.455009350853582, 8.060779590760509, 65.34021123763054, 67.088666577493, 69.44872533121418, 64.58795947413292, 57.448986884086366, 59.272112384919204, 52.62905290049892, 52.317565718004786, 55.880650704906834, 59.05759011545489, 60.136367428687315, 60.77736508461737, 58.69011109875095, 57.783427776828894, 54.855425511637044, 51.6191053390503, 48.566924756573094, 48.37801948670418, 44.25658118340277, 46.022702878521336, 43.56603222508585, 44.96409831508514, 49.21268809226252, 49.80578576364825, 49.01500063557779, 51.94332845749394, 50.6257023349885, 50.94670518752068, 47.988987045903365, 47.66398337579543, 46.913735943455855, 46.248266620020715, 42.99971649723668, 41.70908412625713, 43.872683125157515, 42.56168188587312, 40.654829471342026, 43.08960937684582, 40.85836125958351, 40.296450353437855, 38.89158287355977, 41.976232836323405, 44.171838375829886, 43.56973494252851, 50.64008174404022, 61.65257530827677, 43.53231553108462, 40.933270685134396, 40.214829752522135, 42.38545371640114, 44.227445817762806, 42.75123434682047, 41.43502812231741, 43.80079392463931, 40.44200951053251, 41.692661162345644, 41.34102852113786, 41.42601451566143, 41.47636598156345, 48.72166618224114, 44.87606463893768, 44.812063324836, 46.50960629986179, 44.97626550735966, 43.191755740873276, 44.34577588112124, 43.894040430745775, 43.80186473169635, 41.93768378226988, 43.71624331320486, 43.79629496605166, 41.05811580534905, 42.32396271920974, 43.32304923765121, 42.91945303640058, 38.49237188216179, 40.0064459923775, 39.544959529753655, 40.50991750532582, 41.365598247897246, 40.169816632424634, 39.097703426114975, 40.55221634526407, 42.94179877927227, 55.36987573869767, 45.77632704088765, 42.53377029972692, 45.791561526636926, 42.588699171620036, 45.761645609332675, 41.03978264716364, 42.823425569841945, 46.860693731615626, 46.13309798702117, 43.492072013116655, 42.332223230792636, 47.12335525020477, 51.98268944217313, 50.77031227850145, 52.953872219208755, 52.996947688441125, 57.05453765007758, 58.6355979980961, 58.44282134886711, 54.80577614999587, 51.4098939587993, 46.236691705642215, 46.437634729569965, 47.841494160313765, 47.97389376548029, 46.09750640007758, 51.07262503716254, 50.82773577782416, 53.53705413879887, 55.401266467186716, 54.544467849116174, 51.58927571388983, 51.871513782009, 51.07402924568423, 52.347163923325084, 56.3598584359692, 59.502700682609316, 63.969185967599195, 66.2987090695289, 74.0820094077818, 66.58905075442406, 64.48267913633778, 56.53587087508171, 56.355590897221724, 2.7930136505634557, 0.34208813562027873, 6.280935483594095, 2.412406215744634, 0.3031234022590422, 4.315182797370419, 75.542033257023, 79.60208646712765, 83.69747238774454, 83.44915497687556, 82.03639568821077, 130.58494414052657, 45.964424302501065, 56.49570972688737, 74.8304682393228, 85.92387245547387, 20.292054568567586, 0.6197870715010552, 0.3744450541994264, 0.19073326290855486, 0.23832103598021695, 0.24028438143432143], [0.06015331574505376, 0.10953377286392836, 0.026795721627892028, 0.09261234618362882, 0.1787935221387494, 0.07312819451814698, 0.34226124084764914, 10.236925271249588, 60.48022985458375, 54.3274195732609, 38.382365088309015, 23.65717164931759, 20.151096351685066, 27.0915283695344, 54.8385867764873, 70.6188154220581, 59.78324820918422, 71.22633564856746, 18.439687798100135, 0.12026586795165656, 0.1804447786942605, 2.6534395400554907, 1.9604974456371802, 1.0103633939739198, 4.895491090513045, 61.79275689586517, 62.11508550951558, 63.35616657810827, 59.40679088715584, 55.90222766322475, 48.72441184136176, 47.020773503088186, 43.842912335549634, 42.80275075666366, 41.49534240845711, 44.58173782594743, 46.0789143654608, 45.59988706342636, 44.84919248088714, 41.1436705435476, 41.24456174911992, 40.72289043857206, 41.23774466976043, 38.991501331329346, 41.57031459193076, 44.93131122281475, 48.196805984743186, 48.377372295625754, 51.51468792269307, 51.72097713716569, 52.14875867289882, 52.16074543614542, 50.55380921210013, 47.59356898646201, 45.62846545250186, 40.91844804825322, 38.77228398476878, 39.82012948682232, 38.57527509812386, 40.66831457999445, 38.78724782697616, 38.61822505151072, 38.460349652075, 39.08740720441265, 37.22921963660948, 38.08968959316131, 38.44607614701794, 38.98687293452602, 38.40453824689312, 42.93776658273513, 54.33728433424427, 48.39081425820628, 38.10006426226708, 39.60303806489514, 39.00942264064666, 39.5445712151066, 35.42576089982064, 40.758642842692716, 40.2451967423962, 39.461020808066095, 39.580111811237956, 38.15709552457256, 38.57180380052136, 36.6173416568387, 37.68633265649119, 39.46644936838458, 38.1721652707746, 38.707639401958836, 39.9823312605581, 38.64947065230339, 39.44771220607143, 41.02450501534247, 38.54471983448152, 36.94018017861151, 36.8582889341539, 38.36964484184019, 38.044433286113126, 38.864506752260276, 41.546882352521344, 39.68630998365341, 39.83329688349078, 39.89439956603512, 40.86039696970294, 38.66466591435094, 41.52139086877146, 37.387895199560354, 39.41306983270953, 37.70413237233316, 44.84596437023532, 54.5656604151572, 43.031162138908144, 40.751100124851355, 39.85502681424541, 39.61413837248279, 40.945947785531324, 37.15698918988628, 40.26383192308488, 40.88424105798045, 41.925814690128455, 39.29643423326554, 39.76014860214726, 39.09617762411795, 44.31575405982233, 48.926229553837935, 51.730061346484774, 53.30419086640882, 52.410843603072635, 54.62285249463974, 54.45216271185107, 53.61940822293682, 52.88538371362994, 49.446543724306174, 44.364030591903195, 43.28775575084072, 42.64643646055653, 42.37429065089072, 44.06811914136333, 43.05577108936925, 43.91945738946238, 45.085425069255216, 43.64045527673537, 46.259064905105106, 44.36358736407372, 46.22423818034511, 48.52967008467644, 56.9758431373104, 59.76168301797683, 62.770972482619754, 64.86875411002868, 66.54256282314178, 62.58133765189879, 53.43497053269417, 45.18195852156609, 38.77186429116034, 1.108324282592343, 0.6466166350630023, 3.716010600328446, 0.5270461834246113, 0.17035195333582742, 3.680520504713059, 63.11795711517335, 69.68941765446817, 69.53714339963852, 73.39781468914401, 50.41744016831922, 62.843085258237785, 29.247935702723844, 24.84602635906589, 54.610512718077636, 61.330281995957904, 7.689852810675099, 0.3396363478274115, 0.1439221804180453, 0.11798520121843585, 0.09828107506637612, 0.1061521994791204, 0.08836134727443419, 0.09043995065674668, 0.06103188835925633, 0.009979554470778714, 0.09609448393025706, 0.10047476017667402, 0.4466946531207331, 14.408255142550315, 73.44771508247622, 62.38368157417544, 47.39585407318608, 35.98384749504828, 18.94722680891714, 28.458684221390758, 63.63021473730765, 74.6341928359001, 64.58646897346743, 76.3251187724452, 20.571497947938983, 0.27347959938549227, 0.007357052123669776, 3.4125912429824954, 5.4461747023367115, 1.241484459850096, 6.246393620967866, 63.86711020623485, 64.00079242644772, 67.05107458176153, 62.411738288018014, 57.65359340175506, 50.03208298836985, 48.5812061063705, 45.968448654297866, 44.93366464491814, 44.52351808547974, 47.39373599329303, 47.9960943806556, 47.15689543754824, 45.79739016871299, 41.98199872047671, 44.42501952571254, 43.97810074590868, 43.58856231935563, 41.205895023961226, 43.29720081821565, 46.731333963332645, 50.55758645457607, 51.165659735279704, 52.675470229118105, 52.65099856161302, 54.691686168793716, 52.78479845293107, 52.104326063586825, 49.54110814679054, 49.85627843487648, 42.089404982905236, 41.22909976590065, 42.09907754775017, 40.91008555504584, 43.93884958759431, 41.69765041720483, 40.62691788519583, 40.00530458265736, 41.73554835780975, 40.59745304046139, 41.02004528045654, 40.47746773689024, 39.098558502812544, 40.7876056240451, 45.25243174645209, 56.46413072463005, 50.96227699710477, 38.46507610813264, 40.560268971227835, 39.31455950583182, 39.84308319707071, 37.12107204621838, 40.539394117170765, 40.00520652340305, 41.08800818843227, 41.55764141390401, 38.82608713642244, 39.71169556340864, 39.95951875563591, 39.350045188780754, 40.64243085922734, 39.25550430051742, 41.99773919197821, 42.78915974401659, 40.221999845197125, 41.55344447781963, 43.02171707153321, 40.95486725530317, 38.572862840467884, 38.27218963253883, 39.78640887045091, 39.14276361465454, 40.42783014235958, 43.23626287521855, 39.57233375118625, 39.71424902639082, 39.48958743003107, 41.53465240232406, 37.13797353929089, 40.37377988138507, 37.20709746883762, 39.77492809295654, 37.326172782528786, 44.583848061100134, 57.406233049208126, 42.8790565459959, 43.60226315836753, 41.54477996210898, 41.978390139918176, 42.22223604879072, 40.21062497169741, 41.858553886413574, 42.29896545410156, 41.76125164954893, 40.805460253069484, 41.642023363421046, 41.2313590511199, 46.66211589690178, 50.76518966305641, 52.14307908088931, 54.257252293248335, 55.075137076839326, 54.74587763509443, 56.225446654904275, 55.10997949108001, 53.80517951903805, 50.10969492696947, 46.77594700167256, 44.63316402127666, 43.73108948430708, 45.513641988077474, 45.57383468074184, 45.56262846915953, 45.62707301109068, 47.20067301104146, 46.63613803925053, 48.26213698233328, 47.34804038078555, 49.14189323302239, 50.584513525809015, 58.976487267401914, 62.530025205304554, 64.90393384810417, 67.31006868423955, 67.22101519184729, 64.78614899419969, 59.50030019206386, 45.16639847909251, 44.33916668738089, 0.879337476386178, 0.8466139387699866, 6.819361688629274, 1.1415367068782931, 0.22633197446984632, 3.896999791745217, 69.25507007106658, 74.91800769682854, 77.72119229839694, 77.26569529502623, 63.88903625549809, 91.67821699573149, 35.501074329499275, 29.345673322677616, 62.037222539224935, 73.11025004233085, 11.908104035162157, 0.5461568289226102, 0.1978111185974652, 0.09230735125921427, 0.04427281869274955, 0.15840830551760812, 0.2167857834889043, 0.32205916520568634, 0.25661251898254117, 0.37475945668355115, 0.4007467218945104, 0.26380813770717193, 0.5884928088034354, 18.811981524190596, 84.03069342336347, 69.553907609755, 56.047696605805434, 37.25350303034629, 29.948219983808457, 38.304313844250096, 68.19919939964049, 79.53440204743417, 70.07699489593506, 82.5385061387093, 23.63793242362238, 0.3565907009666966, 1.155636769629294, 7.281778733576498, 10.961625326064325, 2.5378992624821204, 8.054492031374286, 64.96034537592243, 67.84989664631506, 68.87970709031629, 63.70029572517642, 63.09772160745437, 53.60612315516318, 51.949792523537916, 48.679685054286836, 47.948108103967485, 44.99785031041792, 50.225844152512096, 50.10745917597125, 49.40562555866857, 49.03711888097948, 44.452723226239605, 46.52215396204303, 45.729486096289854, 45.65025814117924, 43.05377460295155, 43.8727419607101, 49.04599520467943, 52.820072327890706, 52.95344860323014, 54.5379331804091, 54.7707336948764, 56.24451721868208, 54.594921296642674, 55.4785999175041, 52.173642189271995, 51.72343646326373, 45.14413902836461, 42.64820152713407, 44.25061525837068, 45.593760321217204, 45.96008616109049, 42.51395448561638, 42.95557414331744, 42.37379250987884, 43.62025114797777, 42.279439895383774, 43.33897798292099, 43.56846017222251, 41.635826018548784, 42.763311324581025, 49.14538806484592, 58.395858810793975, 52.19707442868141, 38.30548663293162, 41.58603152921123, 39.20321910612045, 41.202192306518555, 36.92896612228886, 42.88232388034944, 43.651649721207164, 43.60112174864739, 44.75369061193159, 41.786829425442605, 43.02050898152013, 40.8744155206988, 40.51929589240782, 43.973946955896196, 42.77491761792091, 44.061129477716264, 44.9230154099003, 42.91927652974283, 44.7834143330974, 46.13964834520894, 43.812141341547814, 40.42439022371846, 40.42793996872441, 42.907309378347094, 41.27099067934098, 42.47983770985758, 44.08315358623382, 41.157151729829856, 42.01446810076314, 40.65506873592254, 41.51955912190099, 37.18295135805684, 41.536770482217115, 37.55958518674297, 40.29900381642003, 38.887064303121264, 46.814076362117646, 58.770037235752234, 47.167038686813854, 45.55714499565863, 43.13361444780904, 44.6008123120954, 45.338441479590635, 41.739458960871545, 44.96538485250166, 45.931244973213445, 45.87049922635479, 45.46680104347968, 43.511970197000814, 43.06554171346849, 49.438149852137414, 54.49967438174833, 56.33677528750513, 57.84896273766795, 57.73727324701125, 59.12978133847637, 58.9746476757911, 58.506520640465524, 56.908833365286554, 54.32016318844211, 50.72542859661964, 48.2518329158906, 46.061906968393636, 47.64947452852803, 48.639233650699744, 48.00462945815056, 48.4008986719193, 50.02784290621358, 48.804836119374926, 49.98113532220164, 48.27014253985498, 49.66965598444785, 52.77048964654246, 63.21771867813603, 64.7387824519988, 69.83354122407975, 68.21383768512358, 70.55073092060705, 67.47035241896107, 64.30879654422884, 50.44396323542441, 50.21808570431125, 1.731720792670404, 0.9429688006639482, 11.900973166188887, 4.383460475552467, 0.33826443757261004, 4.656409390511052, 75.75841472994897, 79.00497621105563, 83.43866655903479, 85.31588938928421, 67.90997166787425, 78.25145752199235, 43.90920039146177, 43.67252065289406, 71.92842421993133, 85.3599532958, 18.22347890946173, 0.7386194433896773, 0.3896370680341798, 0.27610927279437747, 0.14996621577489763, 0.3107701854840402], [0.07851233705878258, 0.04352623536702126, 0.0730991521249375, 0.052471763619612304, 0.08265486557877834, 0.18645985592757502, 0.25212204864909576, 18.224859583762385, 70.09313152682397, 50.92093913785873, 33.57756360884636, 13.242671855034368, 68.15659461482879, 43.59822703946022, 52.00885165122248, 70.87547963665378, 57.73222123422931, 71.46338801230155, 29.944811444128717, 0.07072485412561125, 0.06474001438266809, 0.9012885920463071, 6.031579625221991, 2.3392216524770184, 8.23320698353552, 55.290804678393954, 57.904123029401234, 63.89238595962525, 58.737371736957186, 55.475964084748306, 51.77075593702255, 51.594053160759714, 48.90527233000725, 49.01857391480477, 44.61145762474307, 41.957621189855764, 40.789931589557284, 41.00066484943513, 41.53021620165917, 43.260950273083104, 42.3201148740707, 41.998358926465436, 43.781637068717714, 46.1432530033973, 48.08807003882624, 48.530944854982444, 51.185805028484715, 54.53147303673529, 52.17594069819297, 53.199545952581595, 51.91706426682011, 52.14537758981028, 50.02067281353859, 46.80434103934996, 41.541889175291985, 38.57560065484817, 39.3705552624118, 39.82285553409208, 38.19074553828086, 39.356513177194905, 38.49781220959079, 38.75098943710327, 38.01203843085997, 38.92553883214151, 37.887742442469445, 37.72970622585666, 37.7860902970837, 40.097719546287294, 38.53171717736029, 41.70664833438012, 53.09177098735687, 52.99568860761581, 42.231441851585146, 37.82613377417288, 39.33282990609446, 37.90267490571545, 40.581963600650916, 38.16190435040382, 40.8297005007344, 39.275916314894154, 40.67877946361419, 36.90877376064178, 37.46226333802746, 37.548327984348425, 36.44636161865727, 39.73449237885014, 39.933007455641224, 40.203674531752064, 39.88517415138983, 40.00463385735789, 39.62638401216076, 38.41268893211119, 38.94964964159074, 37.47110828276604, 36.57736486004245, 38.508484978829664, 39.7183322137402, 40.60791792408113, 39.300944958963704, 37.47245757810531, 40.96328466169296, 39.98094666388727, 40.008097310220045, 39.98974846255395, 41.51515430019748, 38.88422450711651, 39.785922496549546, 37.9755368540364, 46.16597529380552, 48.49019927363242, 38.617805357902284, 41.339090870272734, 39.45675326931862, 38.57745593593967, 39.82328699481103, 38.3121350503737, 40.368010074861594, 42.280451866888235, 39.56026069579586, 39.889108288672666, 41.12204651678763, 39.8833227926685, 40.93774218713084, 43.981007222206365, 45.924145483201556, 51.55906561882266, 51.283181790382635, 54.31195759004163, 54.52202012462001, 54.04010203576858, 53.79246711730958, 51.124545451133486, 48.367068229183076, 45.97345359863774, 44.558517394527314, 43.92698049545289, 45.24495963127383, 46.442820102937766, 45.29890791062386, 46.30348966967675, 46.04271481114049, 45.41199768743208, 44.644303552566036, 45.95324946988014, 51.49920632762294, 60.618109010881, 60.04382302684169, 65.83022902088781, 64.33986956073393, 60.0845136950093, 53.5465854983176, 55.03547406965687, 53.64653925741873, 37.20142572156845, 0.5514270848324222, 0.11344239175800355, 3.8907639586156417, 0.6570631325725587, 0.17065610556352526, 3.7518010024101507, 65.03028908083516, 69.20238479491204, 65.82094084831976, 69.21029229317942, 56.893944048112445, 16.65425431343817, 12.18254247019368, 42.53010680598598, 55.92118055589738, 66.18458378699519, 8.925134654968016, 0.3700218463857328, 0.055549613785960024, 0.049189356486162836, 0.03860603184289029, 0.08024374939381115, 0.12382674421514235, 0.07200630471831368, 0.019184251225763754, 0.07976433923167568, 0.09754295701221113, 0.17313816915116004, 0.27351416527263583, 21.352333984067364, 79.67504255233273, 57.76205870413012, 43.914346541127856, 17.54570314961095, 33.98805533685992, 40.17758292536582, 58.02011536013696, 74.74265421590498, 63.8806894517714, 75.73893623967325, 31.926900802120088, 0.09161656211701133, 0.21394528268325716, 1.5732397547652646, 2.362189826465422, 1.5205684520544545, 8.482094118672034, 57.92816323618735, 60.33103466033936, 67.15043606296663, 59.84717107588246, 57.6817403301116, 54.133615263046764, 53.46202311977264, 51.1805372853433, 51.22347154924947, 46.99035944477205, 43.83837807563044, 42.369058209080855, 43.41140062578263, 42.6604667786629, 44.69995806294103, 43.155564031293316, 42.79361163416217, 44.624107268548784, 48.4822250950721, 49.674868814406864, 50.65180963085544, 53.859437665631695, 58.36934358842912, 55.043530617990804, 55.26128884284727, 53.764304499472345, 53.75222359934161, 52.342472768598995, 51.36600263657109, 45.14810454460883, 41.544207296063824, 42.25610963759884, 41.50446976384809, 42.479519997873616, 40.80580149927447, 40.930152400847405, 41.39417271460257, 41.23446556829637, 40.19269189526958, 40.49741691158664, 39.935427558037546, 37.72633690987864, 42.754254571853146, 41.53247548687843, 42.762189526711744, 55.010096334641986, 55.30170494510282, 43.393251818995324, 37.47709381964899, 39.53826796623969, 39.093278992560606, 39.724913950889345, 38.55393740438646, 41.92705808147308, 40.564458062571866, 41.78464466525663, 38.90707623574042, 38.59123522235502, 39.162238182560095, 39.673832924135276, 40.97045475436796, 41.13721824461415, 42.95254607354441, 41.95211418213383, 41.56853383587253, 41.40360209249681, 39.86393451690674, 41.028756864609264, 40.31856859883955, 38.569705332479174, 40.73157456613357, 40.46100162690686, 40.851654006588845, 42.77156399142358, 38.68843547759518, 40.6902406292577, 39.13882163263137, 41.12692202291181, 39.49050134228122, 39.45675719168879, 40.69373546108123, 39.61309109964679, 37.0613500379747, 47.81359434127808, 51.092582056599284, 39.911002958974535, 42.851254786214525, 41.39663204070061, 43.67212841587682, 40.03325931487545, 41.44596369035783, 41.47989219234836, 42.7701440934212, 41.8147135549976, 41.60256824185772, 42.90828997089017, 42.546408176422126, 42.01632338185465, 46.26792161695419, 47.57238034279116, 53.63976532413114, 53.02248624063308, 57.02224869881907, 55.80253278055499, 56.405240258862904, 56.64434009982694, 53.53142161523142, 50.810143947601325, 48.51299608907392, 48.62157906255415, 45.436335994351296, 48.51771862276139, 47.10586147923624, 47.48492325505903, 48.52606934885825, 48.82674255678731, 47.17097282409669, 46.80791824094711, 48.45580008722121, 52.37614239415815, 61.95198943538051, 62.22071493825605, 66.73878331338206, 66.89989074583977, 62.57597184950306, 58.192852620155584, 56.492332566169004, 55.508453076885594, 40.96682656195856, 0.6052760179004362, 1.0314048874762751, 11.806582308584645, 1.5839378968361886, 0.1522094744347757, 4.257331269402658, 69.03602923116377, 74.92313815701392, 72.2353575306554, 77.73007254446708, 60.10305081644366, 22.97266314106603, 17.345640697786887, 50.8799542919282, 63.53646616781912, 77.89526708664434, 11.940983303131597, 0.4227450285707751, 0.1371244371177689, 0.06104941262052425, 0.03308506216853857, 0.08194949012249708, 0.12066354419315055, 0.15997756002170427, 0.1794608919731071, 0.22739870593913142, 0.16933230563036858, 0.3217834961270133, 0.5808812043359203, 25.36129047793727, 92.91750554115542, 63.38661986012613, 48.90760614025978, 22.679920965625396, 83.94574273017146, 57.31387692113077, 64.49570532768004, 82.10453510284424, 67.39113623096098, 80.66033409487817, 35.47011898409936, 0.17548514079422722, 1.0345817621677154, 4.24069453631678, 13.57884447420797, 4.474901220490856, 10.46167512093821, 60.58646725070093, 63.848914331005474, 68.80359741949266, 65.46806481576735, 59.055393588158395, 58.22002287833922, 57.059440612792976, 54.83457811417119, 54.212572574615486, 50.015350157214755, 45.76572487431188, 44.61945533752442, 45.3812776842425, 45.27874300556798, 46.438615322113044, 46.50314223381781, 46.62395515749532, 48.12989034960347, 50.58245428146855, 51.68510706193986, 52.78006022976291, 56.47063793674592, 59.64808333304621, 57.57629133039906, 57.106156041545255, 57.752998029032064, 56.40517750094014, 54.49095887522544, 51.54965977514944, 48.2716840313327, 44.21665537741877, 44.873432728552054, 44.352793001359515, 45.1767143126457, 42.96612924145114, 43.287438038856756, 42.82521417064052, 42.8739417752912, 42.21806656929755, 43.45162060952956, 41.65299815516318, 42.481536096142186, 44.92080319312311, 43.54814621710008, 45.677424476992705, 57.16647425005513, 57.40611537810295, 43.74544928150792, 37.67106679178054, 39.88677840079031, 37.79756322983773, 41.17531230372768, 39.83710158255793, 45.04810371706563, 41.99659778225807, 43.02321541693903, 41.03289888751122, 40.97937814650997, 41.57138539898781, 42.92921581575948, 45.19572211850075, 44.468196976569395, 46.228639079678445, 44.66217387107111, 42.541960208646714, 44.01232342566214, 41.65087615289996, 45.05409709868893, 42.930663170353064, 42.038935845898045, 42.56486292808287, 44.6150936618928, 43.205393821962424, 43.459979180366766, 40.4017150017523, 42.72631160674557, 37.80528245433685, 41.90652055125083, 39.410712488235966, 42.29525881428873, 40.13184808915661, 40.33488173638621, 38.129831129504794, 48.49624364606796, 53.11858038748465, 41.86988953621157, 45.171305364178075, 43.49995989953318, 44.36410511693647, 42.67345766867361, 43.11143344448459, 44.600804467355054, 44.70355487638905, 43.73538055727559, 43.25908322488108, 47.48720999686949, 44.8933191453257, 45.64722222666587, 49.3868491726537, 49.34204001580515, 55.75707643262802, 57.26025419850504, 59.95328295615412, 58.486547931548095, 56.719994775710575, 60.774380160916245, 55.15538484819474, 53.9829570247281, 51.72561730107954, 50.62634952606694, 47.72667461825956, 49.3723677819775, 50.32577045502202, 49.11402479294808, 49.6338878908465, 50.387512483904445, 49.190746353518584, 48.76911509421564, 50.841162050924, 56.04469207025344, 64.94551097193073, 66.64768234375985, 71.22520600595783, 69.26598994962632, 66.96778697352256, 60.27385434796734, 61.46989483987132, 57.60965108871461, 46.30205800456386, 0.9236024043733074, 1.4327762468207268, 14.970129766771871, 4.235714597086753, 0.3278620054404582, 4.440658438590265, 78.41913884685886, 80.1327439277403, 78.39182346097886, 82.30010447963592, 71.32812115453905, 27.54850018408991, 24.809342392029304, 62.32702685940651, 74.30771827697754, 92.01598013600996, 16.863377440360285, 0.6058168146879442, 0.30753107380963146, 0.16468230514757096, 0.18558974858493577, 0.2749125821696174], [0.04449132229051283, 0.02244124530754503, 0.06494702666156715, 0.02146286292812757, 0.08801856123271488, 0.20315327951985024, 0.5175088790635909, 17.565236553069084, 69.00770971851965, 47.0050016526253, 28.171643210995583, 46.825702267308394, 105.9661328408026, 63.453005975292584, 60.84905424425679, 63.48777386449999, 63.53790175530219, 68.81096363067627, 38.81053101631903, 0.0508647141677718, 0.09432547966078406, 1.766917936263546, 3.2520912876052246, 0.8269380429579366, 8.127024500600754, 46.07937328277096, 49.702823546624955, 69.09406462023335, 57.30928774802916, 57.45040678208875, 56.20787051416213, 58.807621386743364, 58.26881716328283, 58.4743611274227, 54.76876858742007, 44.287293341852006, 41.704604779520345, 41.77851792304747, 42.11581822364561, 42.96351302054621, 46.025640733780406, 48.48285659666985, 49.68089749736171, 49.250150649778305, 52.76604167876705, 54.02027837691769, 54.07712528782507, 52.56980942141626, 52.569268134332475, 55.84480416390204, 50.952929988984145, 52.4052228466157, 49.522563180615826, 43.72489213943482, 38.15491076438658, 39.65649604797363, 40.56078280172041, 43.21296399639499, 41.335772545106956, 40.786617186761674, 38.098491391827984, 38.42993951612903, 37.60902666276501, 38.665156210622484, 38.24832985478063, 38.476890287091656, 38.22585467369326, 38.90548375345046, 37.61979356888802, 40.53917446444112, 52.2310656885947, 52.62250254231115, 48.49565529054212, 38.009116265081595, 38.98826537593719, 41.043803076590265, 38.8837145989941, 38.631604256168494, 37.66355545290055, 36.52917462010538, 40.18296833961241, 39.347727068008915, 37.86375714886574, 35.39038896560669, 39.348974381723714, 39.907402223156346, 38.255876494992165, 40.55373822489093, 41.823323157525834, 40.023712265876036, 40.082190882775095, 38.96823775383734, 36.643001802505985, 38.20126533508301, 37.32242299664406, 38.45702348216888, 40.51281613688315, 40.486567635690015, 40.23250395251859, 36.88775770125851, 38.49330148389263, 40.54039824393488, 41.39716548304404, 38.12713646119641, 39.69431554117511, 39.71788506354056, 39.87100262795725, 42.60183126695695, 52.652685180787124, 45.71798178457445, 38.54230757682554, 39.36256931674096, 38.77806555840277, 39.642332369281405, 38.826985359191895, 39.37565826600598, 39.122665389891594, 39.79449287537606, 39.40419350900958, 39.85443061397922, 40.151326579432336, 39.362930174796816, 39.805906972577496, 40.600528178676484, 40.8670336200345, 43.39703690621161, 47.72130881586383, 50.628726482391365, 53.20088740318052, 54.82957316983131, 56.7963868571866, 53.53563031842632, 53.25435715336954, 52.032691817129816, 51.33859703617712, 49.35412483830606, 50.036174020459576, 51.60099967833489, 50.712449473719445, 50.569341797982496, 49.206165190665956, 50.014118532980646, 47.246321555106874, 49.0008448016259, 52.990844480453006, 60.636712812608295, 62.942176095901004, 62.70668091312532, 59.99266355268417, 59.004975441963445, 63.79586427442489, 60.37254118150281, 50.59526082008116, 37.091932758208245, 0.20411447471668645, 0.8320224152938013, 7.728589648200621, 1.0640902432703203, 0.25761606351983163, 3.7079702317714696, 67.73727755392751, 64.88134491828181, 68.01861347690706, 62.37420120546895, 56.407483854601466, 54.58391512593916, 18.41687725436303, 27.96830754126272, 58.15723357662078, 64.39101726778092, 5.692304901538357, 0.3301272661455216, 0.05753879938575049, 0.03497575567434392, 0.018804152871692376, 0.06414151585270321, 0.01987766996476679, 0.022050479179128044, 0.02161248564539898, 0.06463897504633473, 0.06968741019767138, 0.2257396046432757, 0.38489890615305594, 20.98616700018606, 79.74464893341064, 53.38066531765846, 34.42438371719853, 37.80874982956917, 93.97667100352626, 63.1454646971918, 63.530006024145315, 68.85505891615345, 66.80023116450157, 73.37174661697881, 42.51917516031573, 0.06034608644944045, 0.08597505999909294, 1.0639209684825714, 1.7324018141915722, 1.0652231953797802, 9.612339792713042, 50.044395308340754, 52.49863801463958, 71.06496933967837, 59.378581200876546, 59.51972769152734, 58.89064619618078, 61.25169730955555, 61.260110793575166, 60.01787262578165, 55.07584702584052, 47.24333270903557, 43.61258291429089, 43.193591410113925, 44.03872882166217, 43.549295471560576, 47.654475550497736, 49.5973627798019, 50.98779201507569, 52.054017743756695, 54.433806019444624, 55.7886750467362, 55.31778274043914, 54.57444260197302, 54.4794035726978, 55.97594468824325, 52.62110617852981, 54.623440850165586, 52.72741417731009, 45.86721228015038, 41.92641873513499, 41.47341635919387, 42.41485580321282, 44.06598929435977, 43.40283024695612, 43.85247115165957, 40.76177289409023, 40.71376700555125, 39.53653035625335, 39.73435509589411, 39.57910768447384, 40.97624809511247, 38.51177584740424, 40.80355790353591, 40.447665568320986, 43.16890793461954, 54.730945171848425, 55.230098155237016, 48.154126674898215, 39.10288879948278, 39.31116665563276, 39.70439603251796, 40.170259860254106, 40.43737326898883, 38.02600991341376, 39.66453298445671, 41.892301959376184, 42.05315051540252, 40.46669298602689, 38.5359101910745, 40.37397599989369, 43.036437726789906, 41.937389604506954, 42.19872928434803, 42.99055776288433, 40.2238315920676, 41.278603999845444, 40.606854961764434, 38.72284250874674, 39.345585453894834, 40.03313772140011, 40.744687049619614, 43.07934453410488, 42.1571207815601, 41.690590150894664, 37.465499293419626, 37.55128545145835, 40.30227507314375, 41.64216064637707, 37.215122638210175, 39.0031821497025, 38.4999930474066, 39.51511813748268, 42.1121782641257, 54.83909668460969, 48.34676604117117, 42.02355623245239, 41.9198997559086, 39.438988854808194, 41.23412824446156, 40.023571060549834, 41.015797353559925, 40.46075843995617, 43.234901812768754, 40.72834645548175, 41.68380445049655, 40.6988541541561, 42.28798673998925, 43.743056635702814, 41.90919168533818, 43.27032081542477, 45.44813448382963, 50.623254776000984, 52.65905903231714, 54.364062355410674, 55.26873350143433, 57.11744070053101, 56.60966242513349, 55.152811773361705, 52.94997338325747, 54.044114620454856, 51.914530415688795, 54.2800961771319, 52.75021491512176, 55.2858389577558, 53.11270859933669, 52.425764299208126, 51.16827987855481, 47.89997669958299, 51.09016979894331, 56.89966286382368, 62.37115352384506, 67.0219627503426, 65.65600126020371, 62.07668158315844, 59.86879118027226, 66.33661485487416, 62.1037341702369, 56.73652756598688, 40.15889675386491, 0.298207875701689, 0.8129465195440477, 10.255909542883597, 2.0861160082201806, 0.7535037350270056, 4.766884907599419, 72.04229062603366, 72.47008785124748, 71.90290527959024, 70.72735524946644, 62.94310962000201, 56.525205950583185, 21.680671668821766, 35.78914888443486, 65.04584520093857, 75.0785267737604, 8.963262054228014, 0.2850493962966627, 0.11793928190825448, 0.0742703473435775, 0.06441544591178817, 0.0760625793989147, 0.18376311918179836, 0.20929940375349215, 0.2242999875377263, 0.2033343980269086, 0.19054952438079542, 0.3253714229551054, 0.7013315539206229, 25.982919469956432, 89.08873881063154, 63.15149338014665, 41.883723735809326, 63.46438477116247, 114.10138745461742, 69.47305187102288, 74.25842977339222, 71.94917355814289, 76.03314538155833, 76.77575203680223, 46.64593611994098, 0.1735313101521423, 0.22079128952276325, 4.6242018284336215, 10.488388422996769, 1.4643988854462102, 11.570243816221915, 56.28893806088356, 56.10195475239908, 74.01401904321486, 61.32712056559902, 63.26477143072314, 61.30713216720089, 64.46757016643402, 63.63701220481627, 62.27061533158826, 58.23237049964167, 48.46489998602098, 46.602903796780495, 46.33599435129474, 46.3536528618105, 45.13556080479776, 52.64828428145378, 52.366775774186664, 53.231760378806825, 53.71035229775214, 57.83392044805712, 57.20626669545328, 59.082650138485825, 56.020687164798865, 56.912630219613355, 58.89074817780526, 54.09028876212336, 57.085830319312315, 55.42998213921824, 48.00878324816304, 42.74359749209496, 44.45497466671852, 46.11110133509482, 47.53373322948333, 47.20319901743243, 45.95337890809583, 42.88994112322408, 43.44342285586942, 41.67332387739613, 42.45617012823782, 43.07530841519756, 43.0015992349194, 40.17173074906872, 43.744782478578635, 41.80926538282826, 45.03091196860037, 56.123092405257694, 57.08538709148284, 49.656523889110936, 38.664191307560095, 39.67486058512042, 42.166691364780554, 41.033428407484486, 39.45272891752182, 38.72134416334091, 37.73430716606879, 43.12738180160523, 44.78703075839628, 42.62573419078704, 40.2065457067182, 43.752540926779474, 47.176934826758604, 43.404834578114176, 44.41654328377017, 46.456568010391734, 43.023438992038855, 44.52914276430684, 44.4585047998736, 40.889073418032744, 43.21167745897847, 42.49745307430145, 43.40187711100425, 43.40246154415993, 44.82854904667024, 42.30901064411287, 38.64307326655234, 37.23575430531656, 41.336164782124186, 41.6161435650241, 37.67907234930223, 39.62017097780782, 39.47385088089974, 40.88660624719436, 43.85562081490794, 57.16377565937658, 50.125404019509595, 43.46286212244342, 44.95289210350283, 43.12257297577397, 42.59512793633246, 43.2832371804022, 42.98756107207268, 43.47033423762168, 45.84541174673265, 42.90680339259487, 43.41748814429007, 44.53003314233596, 44.307352342913234, 45.33394644337316, 44.42194438749745, 44.99918783864668, 48.20576467821675, 52.70029490993869, 53.951464314614576, 56.74265038582587, 57.07203926578645, 60.24180466128934, 59.819890991334, 57.964166671999045, 55.188093493061686, 56.210522036398615, 53.82214769240349, 56.067022123644435, 56.96867696700558, 55.01023361759802, 54.86108941416587, 53.5180934013859, 54.18840292961367, 51.07285253463253, 54.223755251976755, 58.8975848690156, 65.26778075002855, 68.51432261928436, 68.17971306462442, 65.88591883259436, 63.20232729757986, 65.21466401315504, 65.633063239436, 60.563760649773386, 44.95319020363593, 0.42220974761632185, 2.4408397222718885, 13.381678692756163, 2.273904873478797, 1.0536432554644923, 5.378080885256491, 80.73896977209276, 77.09680588014665, 79.99245643615723, 77.17626525509742, 73.97332837504726, 72.57635270395588, 30.18718058063138, 47.13661286138719, 74.46731167454874, 87.83791065216066, 13.447622560685682, 0.4452841013910309, 0.14766390705781599, 0.16788079884023438, 0.16495285675890986, 0.09505844194321864], [0.04361365749050052, 0.03719637643605952, 0.05805739877565254, 0.1060965738349384, 0.07676884351718812, 0.10057160135118232, 0.39495883569602047, 7.3187706066716105, 65.121017425291, 49.08447757844002, 38.948037547449914, 40.20334505265759, 91.6701526026572, 66.71847328062981, 51.11144473475795, 66.60396360581922, 61.924175908488614, 69.08262698881089, 43.214270145662375, 0.026611718799798723, 0.13277195454124482, 1.137698422516546, 1.5729143206150302, 0.6971889794353516, 8.327640006619117, 38.20101038102181, 42.787073043084916, 64.07033212723272, 56.4907322391387, 61.846658106773134, 56.05267017118393, 61.81787183207851, 55.84278806563347, 61.1053026876142, 55.038458993358, 46.44294954115345, 41.78223632997082, 43.13366543862128, 45.132046361123365, 48.18936917089647, 50.77984756039035, 52.0679303907579, 52.24900660976287, 56.74751804720972, 53.33005105295489, 56.40971176085934, 51.50522716583745, 53.70970902904388, 52.461869716644294, 54.92833452840006, 52.55822666229741, 49.86935953940115, 43.2877008376583, 39.756081104278564, 36.97186116249331, 41.661972538117446, 45.45439066425447, 42.43598168896091, 41.17483769693683, 40.90412747475409, 38.95199914132395, 38.08804612005911, 36.72268083018642, 38.435140578977524, 38.22099093467959, 38.469724116786836, 36.109280970788774, 38.445515248083304, 41.51935515865203, 46.66594805256013, 49.15683354100874, 52.36132760201731, 49.8437778411373, 40.96950161841608, 38.4673628499431, 39.619335512961115, 38.39944308803928, 38.984868603367964, 38.27642579232493, 39.037404829455966, 38.67454636481501, 39.15022788509246, 36.77160063097554, 36.28630538140574, 36.93782283413795, 37.708768613876835, 35.44432155547604, 37.9433734186234, 41.15494343542284, 40.962260923077984, 39.47675735719743, 36.92863272082421, 36.74204164935697, 38.568469785874896, 40.141414750006895, 39.68881637819352, 38.27491960217876, 37.254432632077126, 40.256583383006436, 39.97585542740361, 40.97924478592412, 39.02117406168292, 37.81928923822219, 37.68084133824995, 37.92036087282243, 39.01652605302873, 39.99238429530975, 45.42949930314095, 48.940726633994814, 44.494170911850475, 40.82089477969755, 39.207608238343276, 38.42038854475945, 37.50850808235907, 38.96997144145351, 39.57351438460812, 40.1438505418839, 39.760144679777085, 39.57349085038708, 40.66258791954287, 39.77006435394287, 41.07485255887432, 40.19495902522918, 40.012192264679946, 40.21028764786259, 41.45009394614927, 40.92013074505714, 45.79929251824656, 51.17115497589112, 54.11603912230461, 54.00127841580299, 53.90727881462344, 52.64251055256013, 53.04616558936335, 53.6892617133356, 52.69456824948711, 54.37566080401021, 55.98242444376792, 56.622174785983184, 55.87533197095318, 54.92374927766862, 53.21191318573491, 51.17405360744846, 48.73047190327799, 52.92986731375418, 56.99538438550888, 60.71775290273852, 62.65194031500048, 67.69627309614613, 64.38020721558603, 69.40546943295386, 61.62667197565879, 60.44904308934366, 38.05371361394083, 0.1486097804961666, 1.1137896151311937, 11.985856198495435, 1.437225685484948, 0.5190491448006322, 4.728803105892674, 63.61438012892201, 67.70923260719546, 68.38855574207922, 67.42420965625395, 54.385027423981704, 27.21685398009516, 13.153669353454346, 36.77229881286621, 54.90739691642023, 60.042536489425174, 4.428223054255209, 0.15603407646619505, 0.07384215015918016, 0.06484177384165025, 0.060402187068135514, 0.026391028021011623, 0.08228244725614786, 0.06482077537164574, 0.06136089630965745, 0.09789089882566084, 0.09927142756961047, 0.14388795160958845, 0.29275041854669975, 12.347383999055433, 73.6774169245074, 55.79477433235415, 39.91937329692226, 45.37073043084914, 98.54503985374205, 72.68367659661078, 57.26703989890314, 69.58958548884239, 68.18713418899044, 73.47158662734493, 46.93044916276009, 0.045084442883249254, 0.08565190879087295, 1.0796892642974854, 2.332644327994316, 0.953133745539573, 9.128008465613089, 42.52216792875721, 45.453127661058986, 66.8917400606217, 57.55937807021603, 62.61031612273186, 60.028149235633116, 64.27214199496855, 59.22866821289063, 61.95994400208997, 57.06634398429625, 48.618107764951645, 44.35481694436843, 45.30699976028935, 45.88575332395492, 49.652264195103804, 52.162608561977265, 55.331024662140884, 54.38221508456815, 58.29182970908381, 54.83631964652769, 58.10161044520717, 53.81684857030069, 56.13317681897072, 55.44568338701802, 55.65864455315375, 53.04481629402407, 51.41455373456402, 45.355754821531235, 43.090044759934955, 40.15577062483757, 42.63140201568604, 48.05134096453267, 44.94687911002867, 43.197800113308816, 42.7340425983552, 39.03729892546131, 40.07664072898127, 39.65167153266169, 39.388033343899636, 39.49103086225448, 39.96276647813859, 38.17452261524816, 39.482668369047104, 42.35450621574156, 48.17796291843538, 52.2479828711479, 53.655321444234545, 51.11897960785897, 39.56705816330449, 38.85030777223649, 39.86498178974275, 39.67978315968668, 38.28050505730414, 37.891398091470045, 38.806341924975, 40.284255704572125, 40.879353784745746, 40.120128047081735, 38.930904634537235, 39.528983716041814, 40.565921106646144, 39.020468035051906, 40.63598248266405, 42.491357711053666, 42.72495446666595, 43.1801063014615, 38.707176562278505, 39.48401374201621, 40.4299952906947, 42.11350402524395, 40.89116796370476, 40.601132223683024, 37.70397939989644, 41.58570205011676, 40.876612047995295, 40.61764540210847, 38.894924732946585, 37.98973191169001, 37.6467873204139, 38.50497837989561, 40.84476632456626, 38.769146088630926, 47.56828538833126, 50.21023704159645, 46.572038665894546, 42.719365089170395, 40.749801820324315, 40.58993385684106, 38.42100827924667, 41.600756106838105, 38.22047318181684, 40.79652117144677, 41.223816333278535, 42.035833251091745, 42.72168713231241, 42.99677471960745, 42.096433870254025, 41.96297522514097, 41.865610230353575, 42.17302207023867, 42.291524717884684, 42.256278299516254, 47.93754123872327, 55.18529292075865, 55.07690606578704, 57.46905765225811, 57.08881132064327, 55.28420332939395, 54.76625434813961, 56.85553227701495, 55.87835219598586, 57.92429577919745, 58.0760326693135, 59.40959145945888, 57.89245397813859, 57.08624216818041, 55.46088257143575, 53.60169872160881, 49.82634290572136, 54.035026488765595, 59.28057685975106, 63.47025655931043, 65.37133916731804, 69.67331240254065, 66.78779725105532, 69.05399368655297, 61.70202070666898, 63.87741819504769, 40.1915426408091, 0.008531549660068367, 0.9151517191240865, 9.734824626676499, 1.3795594895078291, 0.6917796632455242, 5.50447779317056, 70.07367657076928, 72.50688752820416, 74.9741211245137, 71.41511148022067, 58.08306547903246, 34.50549048762168, 12.297798375929556, 45.24827011169926, 62.2785149851153, 73.12746924738731, 6.63941462193766, 0.17813480909793608, 0.07870170633278548, 0.047928337458400964, 0.017931852602369843, 0.08846131408767355, 0.13785868642791627, 0.15203747237401624, 0.18536955959373907, 0.23799941694784552, 0.19252719567908397, 0.3691448595735335, 0.5831404282681404, 15.902662488722033, 87.62525543089836, 61.99602980767528, 57.02043264142929, 53.40385044774702, 95.48139418325117, 72.66621420460363, 63.55264202240975, 77.48683068060106, 74.71735492829355, 79.71405444606658, 52.80320613614975, 0.13127632108667206, 0.2321227411589315, 2.9287857586337678, 6.792321358957599, 1.625985214787145, 11.63239965515752, 50.62399218159337, 48.505751471365656, 70.97203270081552, 60.03685689741566, 65.93156737665977, 61.562478465418664, 67.1718914278092, 60.12562013441517, 65.44068274959442, 60.33855776632986, 50.739207883034986, 45.12782589081795, 46.49196740119688, 49.3579452268539, 53.89526459478564, 54.45794820785523, 56.67273805987451, 55.79971651877127, 62.217569197377856, 57.913375900637725, 60.11175063348586, 56.90276153625981, 57.04628106086486, 56.91470515343451, 59.7828834287582, 57.33867806773032, 55.160621212374785, 47.36012912565663, 45.429883695417836, 40.61494288905975, 45.22038990451444, 49.92142900343865, 47.1367972127853, 45.353342563875266, 46.7975906402834, 41.291755707033225, 40.57575056629796, 40.78136121073077, 42.230943710573264, 42.415801094424346, 42.029486856152936, 39.05549872306086, 43.05721452159267, 44.90768678726689, 50.51846865684756, 53.80020203128938, 56.950143767941384, 55.17913872195829, 40.82437784441056, 39.006386726133286, 40.117366698480424, 39.161457630895804, 39.57057260697888, 39.02861087552963, 39.740407313069994, 42.007148958021595, 43.57546160298009, 42.64152957547096, 40.48770120066982, 41.72740159496185, 43.28826565896311, 41.332054138183594, 42.27664324545091, 45.39070313976657, 45.574576008704405, 44.02465927985407, 40.95089389431862, 41.786594083232266, 42.59124478986187, 43.487753483556936, 43.37631894696144, 42.00969457626343, 38.72699629875922, 43.98895394417548, 41.39284695348432, 41.43569100287653, 38.495054783359656, 39.05408274742865, 37.86545945752052, 38.50392326231926, 39.276641953376036, 39.2811095330023, 48.74534160860124, 51.986305867472005, 48.637625478929095, 43.995249348302046, 42.64659727773359, 43.46749051924675, 40.67011102553337, 43.67796098032306, 41.4103760257844, 45.12895161105741, 44.299990054099794, 45.54369126596759, 46.13914628182688, 45.63733785383163, 44.600165121016964, 44.17052438182216, 44.25205476822392, 43.28058173579555, 46.40369838283908, 46.05892988943285, 51.11731260053573, 58.5324239730835, 59.06171644887617, 59.917350123005534, 57.01023447898127, 57.26862845882293, 57.21790436775454, 59.146031718100275, 57.49816556130686, 59.449485886481504, 61.39544040926042, 62.29420054343439, 59.322942379982244, 58.629816424462106, 57.85116318733462, 56.61176873791603, 52.033248793694284, 56.53198772861112, 60.73197933935351, 66.49347043806507, 67.41179927702873, 73.47202593280424, 67.7851696937315, 73.4792274044406, 64.99145369375906, 65.4928541952564, 43.911902904510505, 0.49767112419489895, 3.400604970032169, 21.527816903206613, 5.184419741553645, 1.2541832558570372, 6.483701919355701, 74.99542743928971, 78.94395197591474, 82.29201655234061, 83.18346146614321, 67.43112871723791, 37.89736009413196, 25.59986472129822, 58.39577251865018, 70.20198514384609, 86.67825406597507, 10.509075983878105, 0.3450407304110066, 0.22065379206211339, 0.1666548589785253, 0.16234622727478706, 0.17319818447914817], [0.04440842008578681, 0.07792329205380333, 0.026442294624904474, 0.054975503665064616, 0.0892157651363842, 0.05039695620296463, 0.15390234488633373, 7.0754821646598085, 65.4907125811423, 55.812311249394575, 49.51717384399907, 35.9687699041059, 53.08705629840974, 38.16424992776687, 55.62797161840624, 62.142444041467485, 64.51747840450656, 66.09035276597547, 51.16418492409491, 0.17055294416364164, 0.060562253479034676, 0.1824153866618872, 0.33424348720619756, 0.5766145236069157, 4.564119942726628, 43.74992862824471, 43.13838404993857, 63.15929105204921, 56.55521600477157, 58.182760361702215, 60.162682610173384, 63.61914580868137, 58.935922115079826, 60.26482897420084, 51.89199639904884, 45.044761857678814, 42.293521204302394, 46.02199292952015, 47.09022691172939, 50.45875057097405, 51.61987412360407, 54.261174663420654, 55.20739939904983, 52.54793436296525, 52.842320011508086, 52.66418949250252, 53.73452194275395, 53.11027280745968, 52.46603527376729, 49.81487781770768, 46.41890541199715, 44.07690525054932, 42.6093190716159, 38.77960704988049, 40.97595783971971, 43.069189517728745, 42.48172044754028, 40.39609816766555, 38.97884776515346, 39.87496814420147, 36.93585772668162, 37.74940044649186, 37.77902218603319, 36.511747529429776, 36.05625052605906, 36.69624405522501, 37.728662875390825, 38.02118147573164, 41.5572177979254, 47.14241404687205, 52.740432523912006, 54.48595785325574, 51.39372594894902, 42.03746495708343, 39.276465446718284, 41.21243361503848, 38.48857895020516, 39.5965269304091, 38.93773740337741, 37.669705729330744, 38.10272362924392, 38.218684581018266, 38.41907847312189, 39.612879291657485, 40.48333168029785, 37.9433028159603, 38.03259949530325, 41.06996528563961, 39.35144547493228, 39.7572813495513, 40.168157469841745, 38.879878520965576, 39.81661504314792, 39.74504355461367, 38.06845388104839, 37.93964324458953, 36.821779512589984, 39.04103302186535, 39.2937474096975, 39.14478363529329, 39.746271256477606, 38.695625182121034, 38.14639922111265, 37.97982008226457, 39.649573064619496, 38.198825620835834, 41.60767516782207, 50.11271907437233, 49.85747868014921, 44.336393571669056, 39.769856468323745, 37.29559006229524, 38.2714718387973, 37.08796331959386, 38.42031794209635, 37.44530300940237, 38.55884036710186, 38.88022368954074, 39.97111720423545, 39.064759439037694, 39.597013304310465, 38.73104026240688, 38.99912249657416, 39.90899470544631, 38.2910091646256, 41.346382556423066, 39.449218396217596, 40.82242450406475, 44.161373492210146, 52.004133039905184, 53.33429897985151, 55.71707217924057, 53.03283737551782, 54.5744308348625, 57.58706215889224, 56.09689489487679, 57.588991965017016, 60.263181578728464, 55.89577928666146, 53.60963759883758, 54.12045178874847, 55.89657160543627, 51.16622455658452, 50.251590590323175, 53.0669149275749, 54.79503670046407, 60.071828749872026, 61.46569398141677, 64.90987231654506, 61.16508353141047, 66.44247962582496, 65.27542544949439, 80.15359524757632, 38.02092259930026, 0.03084136683854365, 0.2962003269743535, 8.607112803766805, 4.500403490758711, 0.6613584343464144, 5.88004767894745, 65.3919747567946, 68.8681282535676, 68.32081640920332, 72.35202450906077, 60.15164113813832, 40.081873170791134, 23.559696828165364, 40.463264834496286, 60.70617798836001, 49.87849866190265, 2.779987459221194, 0.09917489283027188, 0.015403606361829707, 0.04834418147501927, 0.060316346916219885, 0.036073655430828376, 0.009249218912314503, 0.023589411923181147, 0.02821081242854557, 0.07778947181519001, 0.10721417354239572, 0.04356860002923397, 0.24442850341719968, 8.680054180083737, 74.987990625443, 58.43551397323609, 55.578855699108495, 34.831321777835974, 69.28413483404344, 50.98021399590277, 59.97100814696282, 69.19082164764404, 68.089153382086, 72.80380310550814, 55.713953894953576, 0.14735972418660118, 0.06367975635634315, 0.7883574873689683, 2.1360997519185467, 0.7127644662414828, 5.610958866534695, 48.56701889345723, 42.80780276944561, 64.4677858967935, 60.320012800155155, 59.08193234474429, 60.90665425023725, 65.5966950231983, 61.6448482390373, 62.0099110757151, 52.42729010120515, 47.539130410840436, 44.13716854587678, 46.66690903325235, 49.67090722053282, 52.987247667004986, 52.97373117939119, 56.696480166527536, 56.018655377049605, 53.72676741692328, 55.07730614754462, 54.60793179850425, 55.73735083303144, 55.42864068861931, 53.04691476206626, 51.56019918380245, 47.84931536643736, 44.965671185524236, 42.2191216868739, 41.187212774830485, 41.66080759417626, 43.42131637757824, 44.499254303593794, 42.20531886623752, 41.23718377082579, 41.129365659529164, 40.08589360021776, 39.868719808516964, 38.97379183000134, 39.64949069484588, 37.6307056027074, 39.87860418135121, 39.54956831470613, 39.180818450066354, 43.22014977855068, 49.208416631144864, 53.271003692380845, 54.704629990362356, 52.86138273054554, 42.77261910899993, 38.684858275998025, 40.792465440688595, 40.82739806944325, 39.063312084444114, 40.370896939308416, 39.37061017559421, 38.81018977011404, 39.592259391661614, 40.539033259114916, 41.68833871041575, 41.581324685004454, 39.99266278359198, 41.359451893837225, 43.043658810277144, 40.74460860221617, 41.633468674075225, 42.32834008432204, 40.41183863916705, 40.91842843640236, 41.9788961256704, 40.66004622367121, 38.97346627327704, 38.32971119111584, 37.96005918133644, 39.06936430161999, 40.595711508104884, 40.2219331649042, 38.029708708486254, 38.5218131926752, 39.35366945881998, 39.62010821988506, 38.44596632065312, 41.34248764284196, 52.097556052669404, 52.23777294158936, 45.486597245739354, 40.46238230120751, 38.962958243585405, 40.188569484218476, 40.26483212747882, 39.50631241644583, 38.11811108742991, 42.11095056226177, 41.78200883250083, 40.94898762241487, 41.323315097439675, 41.914710460170625, 41.056923404816665, 41.51210269620342, 41.72948829589352, 41.3220089481723, 43.09184120547387, 41.73709769402781, 41.97745661581717, 46.95531698965257, 53.43873208568942, 53.85127913567328, 56.75008719967258, 54.99107283930625, 57.606073887117454, 59.644717939438365, 59.04603873529742, 60.00949444309358, 60.58835391075381, 57.95101888718144, 56.83722657542075, 56.430790578165364, 58.66079530408306, 55.760559497341035, 52.583063110228515, 54.68013086626607, 56.39550101372504, 60.91718973652009, 64.26081811228107, 65.54523744890767, 65.30518054962158, 69.88800725629254, 68.88900310762467, 79.98230534215128, 41.24842528373965, 0.12915678562656527, 0.4020829018085234, 7.914672772730551, 1.5916149558559542, 0.4537341431263955, 5.380993735405707, 69.89036852313627, 72.12695106383293, 75.25087571913197, 76.68742810526203, 63.11576451024702, 40.79452468502907, 28.93682114539608, 48.53102330238589, 69.62705196872835, 60.07807708555653, 4.252644037046741, 0.1339436094126394, 0.1742305032788746, 0.03045189731393851, 0.0307510489027106, 0.019465359528699232, 0.11667231037732094, 0.21955641707585705, 0.2643010999646879, 0.26639111039619295, 0.3157225455487928, 0.16665515009193652, 0.3932565270412353, 12.312378806452598, 90.75353391708867, 68.64365885334631, 66.00006764934909, 48.49551408521591, 66.55052523459157, 49.37119107092581, 71.21180718944919, 71.40015156038346, 76.05733856078118, 75.5603507257277, 62.86894936715404, 0.24457790588419287, 0.3492719565908755, 2.524813009846595, 3.1848402898157797, 1.328177788565236, 7.3262907708844835, 55.87477891675888, 48.29776387060843, 68.31162237351941, 62.22948535796135, 64.04208321725169, 63.58171855249713, 66.42214605885168, 63.68884632664343, 65.43826656956827, 55.691972932507916, 50.57905358652915, 46.10336249874484, 48.435760698010846, 51.931894748441636, 56.535353122218964, 53.31008226640763, 58.140649795532234, 59.69844656605875, 56.638130987844164, 58.364805406139745, 58.225474972878736, 60.71408156425723, 59.34513515041721, 56.32646729869228, 54.1132503171121, 51.11239787070982, 46.38981711479926, 46.000972947766705, 41.769551384833555, 45.04940594396284, 45.571563628412065, 47.10461024315127, 44.888016100852724, 43.23476060744255, 43.52832648061937, 41.42190387172084, 42.78304084654778, 41.71227301320722, 40.7564070916945, 40.08624661353327, 42.1352025770372, 41.3161567718752, 40.46352763329783, 45.01075098591466, 51.518100384742986, 57.039801305340184, 59.03464817231702, 56.88504026782129, 44.602189064025886, 39.85809410772016, 42.52914582529376, 40.32871577047533, 38.8056908115264, 39.97787937041252, 38.808338411392704, 39.62520730110907, 42.13539477317564, 40.9418567534416, 45.027625022395966, 45.458728805665054, 42.33086216834284, 42.40084117458713, 45.802936400136645, 43.45976737237746, 44.835883878892474, 44.41053813503635, 42.25832185437603, 44.50269029986474, 43.958096658029866, 43.23328187388759, 39.634593532931426, 39.24294879359584, 39.8705711672383, 39.498910903930664, 40.18015600019886, 39.832528098937004, 38.01422711341612, 39.711471988308816, 38.645579661092455, 40.69584961860411, 38.106206693956935, 41.950949238192656, 55.58748883585776, 55.38716554641724, 48.63324811381679, 43.91012607082244, 40.94369242268224, 41.2249263640373, 41.07595866726291, 43.75666333783058, 41.18035647176927, 42.25696079192623, 43.07391989615656, 44.66666890728859, 44.5276601083817, 44.874876160775464, 42.510149786549235, 44.00158789850051, 44.1279705878227, 43.84880373554845, 45.05318710880895, 44.20469214839321, 44.00187423152309, 48.577460242855935, 55.938427217545055, 56.16014703627556, 59.59881836368192, 57.366766160534276, 58.67208388543899, 62.71032871738557, 61.52721635756954, 62.4962692876016, 65.53098355570148, 60.10298413615073, 58.635519550692656, 60.841040841994754, 62.21276821628694, 57.86995526283019, 56.87586584398824, 58.219359997780096, 59.457562046666304, 65.27917523537913, 66.9360314646075, 69.1507036455216, 68.2243339477047, 73.20819162553357, 70.10723636996362, 83.37864645065801, 43.90290890970538, 0.4277901772049166, 0.9218372152216974, 22.94318456803599, 10.32190832399553, 1.0565102629123195, 6.647905572768181, 78.7932780481154, 78.21286924423711, 82.82979703718617, 86.26210628017303, 74.02084396731469, 58.25075072626914, 40.79582691192627, 59.627494812011726, 77.98667400113999, 75.03150540013468, 6.054624530576891, 0.3683974335510885, 0.23307080560874557, 0.09414296687370348, 0.1896724609598037, 0.20848684493572484], [0.08318597135404426, 0.04297799986576842, 0.062146956146123915, 0.1068910529776927, 0.07444581978263394, 0.02789418637422064, 0.15914653848496177, 3.081092863313614, 58.5491136581667, 59.179866083206676, 47.40889203163886, 27.120489189701697, 17.213692165190174, 33.788324325315415, 57.02812833170737, 64.0608125348245, 66.0020523686563, 63.28616403764295, 53.1841584943956, 0.6365816799863693, 0.16171656428806244, 0.3244076843463606, 0.5576984031546501, 0.9779452496478636, 2.9747998185696143, 46.4009331118676, 47.89225747508388, 58.67906570434571, 48.52856005391767, 55.26951013072845, 54.8832586503798, 60.68936278743129, 58.38864949441726, 58.48247651130923, 47.013642634114916, 44.6461078428453, 43.636583897375296, 46.220457015498994, 47.59676179578228, 54.151356143336145, 54.37842215261152, 53.5395723004495, 51.23592899691675, 53.53317099232828, 52.552617672950994, 53.01376288936984, 54.22558307647706, 51.39769146519323, 44.22033848301057, 42.924960044122514, 40.04610899955996, 40.21162517609135, 40.087305653479795, 39.640355494714555, 41.396694798623365, 41.97909616654919, 43.66258921161775, 42.36156255968156, 39.85622313714797, 38.987990810025124, 37.52069096411429, 39.740156281378965, 39.07829553850236, 36.896355536676225, 38.45090850707024, 37.04432302905668, 39.35656024563698, 38.77715949089297, 37.069147709877264, 37.86761676111529, 45.919069936198575, 52.50173276470554, 52.63871369823333, 46.17603225092734, 37.21556194366948, 41.49866465599307, 37.902129696261504, 38.23236973054948, 38.605932343390684, 41.55207949299967, 39.37709385348905, 37.53998118062174, 38.15822124481201, 39.895489984943026, 38.724023142168605, 38.00542139237927, 39.982813712089296, 37.93452455151466, 39.82629937510337, 41.492432009789255, 38.62822709545013, 40.437216374181936, 40.354266089777795, 38.444228710666785, 38.32275682880033, 37.45668572764243, 38.396250278719016, 40.074793292630105, 39.59566793134136, 41.460217583564024, 39.996188994376894, 39.675727428928504, 36.90017592522406, 38.00225996202038, 38.721830537242276, 37.70659954317155, 42.9326125883287, 50.51908054659444, 46.839607069569254, 39.436988446020315, 40.724271112872714, 39.82765259281282, 39.48149558036558, 39.67864174996653, 38.25323281749603, 37.429946930177756, 39.98627324258128, 40.43378430028116, 38.19710762270036, 39.39463469289964, 39.334159589582875, 39.002605561287176, 38.99235248565674, 41.289045349244155, 39.14866285939371, 41.549573098459554, 39.79250815606887, 40.095472028178555, 39.54284929460095, 44.620196665486986, 51.38572039142732, 54.36840441919143, 55.64065656354351, 54.23544391509026, 54.32031223850866, 55.534124989663404, 53.910408866020944, 55.58196613865515, 56.694805314463956, 58.672354528980875, 55.747380333562056, 57.62723899656727, 52.323931724794456, 51.25287363606115, 48.71679067611695, 47.15504800119708, 50.70288673523934, 54.717628725113414, 57.945519724199855, 61.469482991003225, 63.38870263868763, 64.40426311185284, 75.65626836592152, 39.53148226584158, 0.03607357499159632, 0.19578080173702012, 5.056908880510639, 0.2646234084761912, 0.371235390944827, 7.022931229683661, 69.60041123051798, 65.12886608800581, 73.51400313838836, 66.74400791045159, 60.99910059282857, 31.54066501125213, 18.460295930985485, 47.97646291794316, 57.71829289774741, 51.622933572338475, 1.1759970577493792, 0.10252508725370131, 0.015838754836529974, 0.01455891302846853, 0.030490588584554293, 0.024433849574697596, 0.04449826304710681, 0.014702765188450295, 0.0752686211959489, 0.033252172757901495, 0.11665727973224656, 0.007068303530104459, 0.22095271957016763, 4.7704532838636835, 68.3288808022776, 66.89126153146067, 54.34306198550809, 36.696824566010505, 30.081100079321093, 38.89894516237321, 64.10832028235158, 69.38075065612793, 71.91737882552609, 67.32280069781889, 60.03176173856182, 0.6358393101442246, 0.18957282356437177, 0.8377175742099363, 2.529200671180602, 0.4926651073319297, 3.363982290029526, 50.25413620856501, 50.637504746837, 59.101618720639145, 48.346777808281686, 56.33264895408385, 57.69124423303912, 62.41115385486234, 60.88186487074822, 59.61577869230702, 48.106434575973026, 47.7850277193131, 45.127586626237445, 48.04553193430747, 50.391003393357806, 55.76363463555613, 56.59658132060882, 55.76404648442423, 53.304732153492594, 56.707145091026064, 55.29181664989841, 55.74188509295064, 56.59383173911803, 52.76455902284192, 48.53509080025458, 45.441329171580655, 43.098819102010424, 40.83210099127985, 41.52983180938229, 43.060093541299146, 42.94561132307976, 45.276848500774754, 43.31497307746641, 44.450530621313284, 41.31687064324656, 40.67080528505387, 38.740638302218535, 41.56949481656475, 39.799827298810406, 38.422710587901456, 41.24189061503257, 38.41243005567981, 39.723866678053334, 40.75111189196187, 39.23683774086737, 40.11516232644358, 49.39505084868401, 54.433194129697746, 55.61136038072648, 47.86216505112187, 36.919391616698235, 41.349696959218676, 38.279143994854344, 40.23406505584717, 39.19794351823869, 40.80189874095302, 37.55203070179109, 37.74405425594699, 40.67296651101882, 41.18227843315371, 40.61650399238833, 40.16663951258506, 41.70845654702956, 40.80815492137786, 43.238981077747965, 43.42927486665788, 40.400495144628714, 41.15275867523686, 43.146381762719926, 39.94598657854142, 39.23757122408959, 38.79473563163511, 39.13151425700034, 39.76739321985553, 40.1074666361655, 40.10525049701814, 38.50797114833709, 40.15179334148284, 37.32449400809504, 38.557526373094134, 38.668007773737756, 40.35095168698219, 44.91831248806369, 54.28859203092514, 50.474353759519516, 41.356188481853856, 40.30228684025426, 41.16538870719172, 39.331162898771225, 40.62953802847093, 39.30815035297025, 39.67865743944722, 41.88806579959008, 41.7187370792512, 41.435294843489125, 40.11698230620354, 41.8352863865514, 42.22719000231835, 42.484446494810044, 44.032994316470244, 41.053981627187426, 42.7970633199138, 42.07713188663606, 42.65089227307228, 41.32774345336422, 47.782066329833, 54.25791909617763, 55.944208791179044, 57.59964120003485, 55.688693831043864, 55.589940317215465, 56.97724734583209, 53.935115875736365, 58.27602647965955, 58.85510560004943, 60.38224904767929, 57.594055744909475, 58.62059100981682, 54.529582454312234, 52.88299891256517, 50.051592857606956, 51.55540996982206, 53.0406899606028, 58.78639351937079, 63.07598775432956, 63.958258244299124, 66.5109798985143, 65.83594783659905, 77.22316895761799, 42.05884187452255, 0.032207860851720456, 0.9957896437375777, 5.480076238032311, 0.6605887304871314, 0.6395170224770423, 7.777308427518415, 75.83690135709702, 69.57567676421135, 78.8728629389117, 74.4173171443324, 63.33624486000308, 40.72283552538964, 27.746056241373864, 54.831302935077304, 65.31898729262814, 63.22077028213009, 1.9964224340454226, 0.08938980499102224, 0.030770187694278937, 0.01298046546928104, 0.054152859299774134, 0.08542937557062796, 0.11418965690198446, 0.09183299727737905, 0.21164323443606978, 0.20523349934768295, 0.20799086429178718, 0.2952435444439611, 0.3523753787721357, 5.720680798253706, 81.29791536638814, 74.178891951038, 66.92450754104122, 42.23817263880084, 28.632345199584964, 49.90172301569293, 70.27641604023596, 76.71501021231376, 77.19850509397446, 73.52880616341868, 64.93388898911016, 0.9516865135200563, 0.5141318409192948, 2.0103428032129043, 4.574339187914326, 1.2625450136200076, 4.1738558776917, 56.18858422002485, 52.67219897239439, 59.63148386247697, 49.628051404030096, 58.72253733296549, 60.54079909478465, 65.54874012547155, 64.42552235818678, 62.80024120884558, 50.76364424920852, 50.449270202267556, 47.77709276445451, 49.809343353394546, 53.79153751557874, 58.13815909047281, 59.868387176144516, 59.98190449130151, 58.195488452911384, 59.360914845620435, 59.037652707869015, 57.287750013412975, 59.81259538281349, 55.53598419312508, 48.31629706967262, 48.06315906586186, 46.05458390328192, 42.66530306108537, 44.892475835738644, 45.62013041588568, 46.835202247865745, 47.29847731128816, 45.837414033951305, 47.7529937221158, 44.61951025070683, 42.596206588129846, 40.55419714220109, 42.730414405945815, 43.00174828498594, 39.53564390059441, 42.21468156383884, 40.2075380663718, 42.60169006163075, 42.96712552347491, 41.0974964018791, 42.35093685888475, 51.89649928000666, 55.75643316391976, 55.853907985071984, 48.75468077198152, 37.10309582371866, 42.667166186917214, 38.71180103671166, 39.04742256287606, 39.37441879703153, 43.47042052976547, 40.02583819050943, 40.466457643816554, 41.66915832027313, 44.0352810582807, 43.60262009405321, 42.63373974830874, 44.2422527651633, 41.990161172805294, 46.37940322199176, 46.56443319013042, 43.242373927947014, 42.2016239935352, 47.14535190213112, 41.38978750474992, 40.72005456493747, 39.945908131137976, 40.015816534719164, 41.0262857714007, 40.9923102009681, 41.78544482877178, 37.66270429857316, 40.21134276543894, 38.40322033051522, 38.36082343132266, 39.5994883198892, 38.20013177010321, 46.38309024995374, 57.387982260796335, 51.63741496301467, 41.98943161195324, 44.47406484234718, 43.283660796380815, 42.40756019469231, 42.99467232919509, 43.201094904253566, 40.93386296303042, 45.32786676960607, 44.09214365866877, 42.50174022489979, 42.082560446954545, 44.692403577989154, 46.025001387442316, 45.74120613836473, 46.69100807559106, 44.481819368177845, 45.46516149274765, 45.6621233109505, 45.113732814788825, 45.976548348703695, 49.72893084249189, 57.31710110941241, 59.259396060820556, 60.681639640562004, 57.72280754581575, 59.7957331134427, 59.581928637719926, 58.10437179380848, 60.44612092356528, 62.494115906377, 64.02673498276742, 60.10146617889405, 62.18765720244377, 57.654350419198316, 54.24444575463572, 52.23325044878068, 54.56944550237348, 55.4112292874244, 60.925760115346606, 65.47206955571329, 67.55981383785125, 70.19809415263515, 68.68806792843726, 79.58531441227083, 45.87965403833697, 0.12310069204578478, 2.6732815850165585, 13.437187094842235, 3.7047048586030162, 0.8433038873537895, 8.918710793218306, 83.82483959197998, 75.09632648960238, 87.24659765920332, 79.0360256933397, 78.42157856110605, 45.67679297539496, 32.107390626784294, 67.1883261588312, 73.30953782604587, 78.50790992859872, 3.5867057452278757, 0.23739624528154252, 0.16705065064372557, 0.09304291824059141, 0.19856324839976527, 0.11274635491351928], [0.044245086309890595, 0.0051191694858003295, 0.022035099964048115, 0.041936913189748605, 0.0068509145902710105, 0.026436169751949852, 0.031129249273949576, 1.4833105932320318, 57.73063267430952, 56.56980329944242, 50.452674819577126, 22.908457863715388, 17.646160933279223, 39.84656626178373, 56.48371511890043, 63.62657477778774, 65.0006438070728, 62.99931326220113, 54.47363768854449, 1.1497628977221828, 0.08345374972709725, 0.5825767714169718, 1.2569650743276843, 0.21920314329045437, 0.9825097240747945, 41.364280331519346, 49.18149740465226, 53.46698884041079, 55.829212742467085, 65.66268105660716, 59.12213271664035, 61.27174846587643, 54.880756178209865, 51.076747448213645, 44.91952842281711, 45.08101240281136, 45.687536347296934, 49.14738455126363, 52.902528393653135, 53.73629877644201, 50.687361994097316, 52.314698465408824, 54.93079777686827, 51.332886065206225, 51.71767842385077, 50.50087682662472, 46.21870371603197, 43.12877816538657, 38.814108217916186, 41.309120039786066, 40.23187245092085, 41.285362243652344, 42.924050054242535, 43.745868975116366, 40.95338459937803, 44.01370802233296, 43.42723523416827, 40.99664442000851, 40.23598309486143, 38.35960357419906, 38.77371957225185, 38.48852403702275, 37.90262391490322, 36.952155174747595, 37.10460201386483, 37.04813165049399, 36.75777427611813, 37.68071190003426, 39.09282791999079, 37.245466093863214, 42.008325669073294, 48.71736334216211, 52.86126898181055, 49.69118587432369, 38.911520281145656, 40.478828799340036, 40.35404251467797, 39.019510976729855, 40.925088620954945, 38.24532924159881, 38.41583859535956, 35.71019157286614, 37.43590108809933, 39.61925314318749, 41.220749039803785, 40.910113011637044, 38.46410728270008, 41.121054157134026, 41.67268453105804, 40.845056579959014, 39.51740487929314, 39.9930707100899, 38.790613220584014, 39.07243943983509, 36.397382982315555, 39.85771756018362, 38.95188147021879, 40.37744729749618, 39.765530094023674, 37.60331569179412, 38.34770702546643, 39.27390413899576, 39.11217304968065, 38.74717297092561, 37.26955729146158, 40.339361083122995, 47.825267314910896, 50.75506210327149, 44.84940428887644, 35.93380981876005, 38.275574637997536, 35.30454789438556, 37.61088586622669, 39.84009827336958, 39.58070801150414, 38.94991244039228, 38.30879711335705, 40.13191869181972, 38.263187792993364, 39.88135768521217, 39.26758127827799, 39.072831676852324, 40.845605711783136, 40.48744624660861, 41.920837202379786, 41.06933770641204, 40.502437545407204, 40.53897050119216, 41.41361982591691, 41.53744120751658, 47.18664269293509, 50.66906021487329, 54.620338255359286, 52.785790812584665, 54.9269970001713, 56.5098459489884, 56.60578320103308, 55.608963812551195, 56.452445983886726, 55.395100501275834, 54.91103295356997, 53.97069177319927, 50.409477756869414, 48.243572404307706, 45.54721355438233, 44.661134442975445, 47.19147505298738, 47.989061570936634, 53.3920088121968, 54.036360094624186, 63.93077811887188, 66.20519191988053, 78.71971007316344, 43.09103711958855, 0.2325382978925782, 0.17177647850926847, 3.3538571817259637, 0.4553028460471861, 0.6656295890288969, 10.85641461033975, 71.95257817545246, 64.83578266636019, 70.66200071765532, 71.74048777549498, 59.53150264678463, 28.717229212484053, 24.870392122576316, 42.30711613931964, 59.17926988294048, 50.47132568974649, 1.2549090169129835, 0.08049458190197907, 0.18173111692791988, 0.0510416268521259, 0.05250401209078489, 0.07049915696223898, 0.08536913807714179, 0.04172413609921933, 0.068725326338843, 0.057029599894679366, 0.02853934540443363, 0.09411524215172376, 0.04364933803557389, 1.9566949529032556, 66.97189761746314, 63.584452444507235, 59.994918915533255, 29.065078727660644, 23.210413686690792, 47.687545053420536, 61.91728822646603, 70.25637272865542, 68.97143563916607, 67.36056527783795, 62.81705248740412, 1.4012248237286846, 0.21754100828641848, 0.6921543108840144, 5.060959708306098, 0.4143063249366899, 0.9193623835040677, 47.87115904592699, 52.93835532280707, 53.56501279338714, 56.43746645219865, 66.87673307234242, 63.22716374551097, 63.491484426683, 56.77420585386215, 54.05441084215718, 46.51308151983446, 47.07062682797832, 47.58861895530455, 51.68770367099393, 54.537725294789965, 55.57039514664681, 53.89811223553073, 54.944706501499304, 58.50062139572636, 55.815311862576394, 53.26836785962505, 52.145703146534586, 47.800881939549605, 44.913170260767785, 41.38117790222168, 42.760083213929214, 42.27603920044438, 44.11638782870385, 44.102133935497655, 46.73469543457032, 43.49867336211666, 46.4285191412895, 45.06784108377273, 41.842734967508626, 43.407497867461174, 40.14530574121783, 38.86578936730662, 40.725412522592855, 40.66760070862309, 38.32971511348602, 39.018083233987134, 40.14719632364089, 39.57277697901572, 40.31453640230241, 41.16272149547454, 38.826624501136045, 43.41176148383848, 53.636458766075876, 55.481745658382295, 51.235399476943485, 39.35802721208142, 40.60170881209835, 40.48196277310772, 39.1269721523408, 39.38076519197033, 39.371414261479536, 38.254487975951164, 38.36966837606123, 38.62275146668957, 39.218363377355764, 42.825120033756384, 42.69206539277108, 41.897416730080884, 45.11255218136696, 42.43591500866798, 43.80421815379974, 41.9347773059722, 41.78593904741349, 41.66412984171222, 40.82934356504872, 38.91782353001256, 38.74913807838194, 41.18678915885187, 40.179300923501295, 39.912269884540194, 39.2943710665549, 38.31238608206473, 39.26232137987691, 38.67423257520122, 38.34563601401545, 37.750020180979085, 39.75528486313359, 48.26760084398332, 52.35545973623953, 47.756986694951216, 40.01581261234899, 39.543014034148186, 37.883051287743356, 39.978291219280614, 41.22698953074794, 41.18440828015728, 38.77125632378363, 41.43068213616648, 41.11413117377989, 39.71078557352866, 41.141003331830426, 41.284573847247714, 42.58878546376383, 43.65731754610616, 42.5355157544536, 43.236325633141306, 43.173626545936834, 43.461297096744666, 43.3207703405811, 42.79393719088647, 43.24084420357981, 48.847801762242476, 54.10173423828618, 57.47744760205669, 55.521345907642, 55.77727663901545, 56.70493679661905, 58.72367874268563, 58.05940574215305, 57.243893992516306, 57.24942845682944, 56.4580314390121, 55.116569072969504, 51.2939408517653, 50.628812774535156, 48.64860027067123, 47.35641464110344, 50.442013817448775, 51.84719900931082, 56.404687204668605, 57.11430672676333, 65.13051740584835, 68.65370796572778, 78.96553285660283, 45.24494786416331, 0.2619509567176142, 0.7905955059874443, 3.899723387533619, 0.8074255996654112, 0.5833644936642339, 11.114138845474491, 80.19047337193643, 69.31279951526274, 78.98829044834261, 74.82670276395737, 70.62215728144493, 33.58396491696758, 27.335344860630652, 55.46133364400556, 63.35446426945349, 63.010546930374645, 1.811716796890382, 0.11738854129948925, 0.16102228944580402, 0.07377380745545511, 0.07252134562980744, 0.03742124622447356, 0.22065117204141235, 0.07523261506350772, 0.19830507676928275, 0.1956163226596771, 0.13959505535181493, 0.14333154195018355, 0.20164204851513912, 2.968157284682797, 75.6511849741782, 72.50001553566226, 68.16869120444021, 36.27794681056854, 29.236984445202737, 54.4725041235647, 68.85163860936319, 73.70651306644564, 76.03212556531354, 72.7043867111206, 67.63857503091135, 1.5225448363250302, 0.41152882720193557, 2.579162841843021, 8.568825567922286, 0.5874055768212965, 1.1032836691987131, 54.37954002811063, 55.55429381708945, 55.24694081275694, 58.23453957034696, 68.13084033227736, 66.9173139141452, 66.17859040537189, 59.352477827379786, 55.599036293645064, 49.10138299388271, 48.294559294177645, 51.25614489278486, 54.81925341390795, 57.511227053980676, 58.96341400761759, 56.548846075611735, 55.65161958817513, 60.86063700337564, 57.377144752010224, 56.9236324679467, 54.36834950600901, 49.86734736350275, 47.11398863023328, 43.900496652049405, 44.22652406077231, 45.101577389624815, 45.2652814311366, 47.025303840637214, 49.63118930016795, 44.95601431015999, 48.99817758990873, 48.855183662906775, 44.9897623831226, 47.31877949930007, 40.877612252389234, 40.529070438877234, 43.15209665606099, 42.67752908891247, 40.45136828576365, 40.57008666376914, 42.97020850643035, 40.50094704474173, 40.75930572325184, 42.65514804470924, 39.57595802122547, 47.485821477828495, 56.162778946661184, 60.42892133035968, 50.73360281605875, 38.78131720327562, 40.51289066191643, 41.557982660109, 37.91945088294245, 41.143180247276064, 38.68418362832839, 38.960624433332875, 38.39152382266137, 39.83031980452999, 41.17111144527313, 44.982502075933645, 44.777338581700484, 45.02904884276852, 45.62601789351433, 44.91944997541366, 46.23048259365944, 44.170077231622514, 43.022081851959236, 42.668338975598736, 42.71240288211454, 39.906919771625155, 39.85061807017173, 40.834697600333925, 39.48579449807444, 40.7208155047509, 37.96826085736675, 38.27222101150021, 38.5114267564589, 39.748201062602384, 38.42887655381234, 38.22972997542351, 39.16871793808476, 50.443316044345984, 56.364377006407715, 49.12817278215962, 39.988791404231904, 42.67279871048466, 39.6124517533087, 42.526478613576586, 45.71130591054117, 43.49404496531333, 44.45384110173872, 42.892565188869355, 45.292961597442634, 42.18766427809193, 43.53750090445242, 43.37129046840053, 44.30702678618893, 46.126763359192886, 45.87895977881647, 46.80757307237195, 44.777785731900124, 44.212344692599395, 43.40565043111002, 43.85857043727752, 45.47599115679341, 52.75805965546639, 56.6924479699904, 60.46346564446727, 57.37328906213084, 59.20863666842061, 60.51744922514885, 62.17842394305814, 60.25198713425667, 61.07580646391838, 61.40843129927113, 59.55171854265275, 58.21453548246815, 53.91437045989498, 53.04063112505021, 51.15715603674612, 49.65729659603488, 53.44467055413031, 53.39295410340833, 58.683407768126465, 61.18135352288524, 68.41581621477681, 71.16869249651509, 82.13373322640696, 49.66541197992141, 0.4026423911413839, 3.456081012564321, 9.419393500974103, 3.5536786529325672, 0.9187123732220743, 13.990547234012237, 87.35611023441439, 74.33455513369653, 84.39506592289095, 82.68266108728226, 76.96596345593854, 40.7444634745198, 35.51619506651355, 65.52542555716731, 74.94409930321478, 74.08135044959285, 3.51052105907471, 0.4132373871341829, 0.35166175254890997, 0.13694984567982538, 0.16878731068103545, 0.1298705344238589], [0.041469806399677074, 0.03859141871573464, 0.02489788818263239, 0.01592193091768892, 0.05677238204366258, 0.0937666644852969, 0.07228067910839474, 0.1891111330159249, 44.970256436255674, 62.78974886863463, 48.54852099572459, 28.04656667094077, 26.864534924107215, 35.00981315489739, 56.4846682548523, 63.51223376489455, 64.1662811463879, 60.33080716286937, 58.711276208200765, 2.2027349375909377, 0.26541042592256303, 0.2924680691813269, 2.054542644369987, 0.1321398400731625, 0.1100672075464841, 39.42775910900485, 56.27153450442899, 64.58170329370807, 63.65940501613002, 58.843950379279356, 58.70794611592447, 55.79736701903805, 50.489651003191554, 46.19559311097669, 44.990295825466035, 46.04091052086123, 48.36083950534944, 49.79445011385026, 49.83646654313611, 51.21597589985017, 52.81630293015511, 54.30541115422403, 52.22494286875571, 49.88222491356635, 45.392640790631695, 42.16312200792375, 38.487355170711396, 38.88253004320207, 40.12384645400509, 42.25161067901119, 42.843433580090924, 44.56431858001217, 46.1668578270943, 47.90971594472086, 45.06919822385235, 42.52595693834367, 43.38011972365841, 40.64195233006632, 38.887793863973315, 37.312111085461034, 37.07898109189926, 36.30408940776702, 38.90219288487589, 36.17042287703484, 36.89171537276238, 37.56736324679467, 36.47365347031624, 36.73845660301947, 38.287581013095, 36.63501585683515, 41.00510497247019, 51.699823794826386, 49.94726173339352, 52.2181728578383, 41.98424623858544, 37.549736115240286, 40.74858980794107, 38.07439627185945, 38.82382392883301, 39.242893880413426, 38.001644149903335, 38.426456451416016, 36.69576160369381, 37.125751433833955, 39.74359227764992, 40.29228479631486, 42.47496612610356, 42.74477812551683, 42.96615669804235, 41.849493211315526, 42.40852117538452, 40.80013367437547, 38.52298205898654, 37.33798303911763, 36.21784041004796, 40.82891602669993, 39.81031963902135, 39.5261949108493, 39.38720180142311, 39.214441007183446, 40.09748028170678, 39.29606160809917, 37.38397675175821, 39.61362454199022, 38.375626456352975, 43.48382719101445, 46.212788781812115, 49.6314520989695, 39.602045705241544, 37.37959546427573, 38.377748458616196, 38.02540194603705, 37.60578286263251, 38.139280119249904, 37.95420700503934, 37.53907511311193, 38.579299449920654, 37.96145162274761, 40.58901602222074, 38.423871609472464, 39.179877081225, 40.13799836558681, 39.65645290190174, 40.196947666906546, 42.0987049225838, 46.208293745594645, 45.86352917455858, 45.06118874396048, 42.55450002608761, 40.16823591724519, 39.464084179170676, 42.30171503559236, 45.58431525384226, 48.951548453300234, 48.86218509366436, 49.99152175841793, 48.182916871963016, 47.391982693826, 45.727128751816295, 46.69063545042469, 45.54411880431637, 44.126574224041356, 45.81531932277065, 45.944812451639486, 44.681260124329604, 44.957669550372714, 43.87154171543737, 47.523848856649096, 50.763224555600075, 53.90114422767393, 60.099155902862556, 67.69173099148658, 72.26178646087646, 48.829064599929325, 0.08000258491524766, 0.39186586295404746, 3.376485335250055, 0.18941753754212012, 0.6184857639093554, 13.205065150414745, 72.70759520992156, 66.0227938621275, 71.2308620637463, 70.31528672864361, 56.103574691280244, 40.172919227230935, 27.456114638236265, 38.43191246832571, 67.87918106202157, 48.484272572302054, 0.8915468954270886, 0.06404748622087703, 0.03991807998728849, 0.08133206922080248, 0.028359828021136985, 0.04629694939320607, 0.0330348834094982, 0.020344089190926284, 0.011078199247769531, 0.06143360571455091, 0.016348358438981157, 0.023446584405798106, 0.028114193419535315, 0.409822749394563, 54.705504678910785, 69.18698556961553, 56.948480682988325, 35.42473716120566, 34.5872679833443, 48.00950496427475, 63.79624474433161, 69.85313738546064, 67.21401768345987, 65.80131723034766, 64.13360780285251, 2.3060131505612405, 0.3543295464929073, 0.19419222649547363, 3.16911869472073, 0.22240577385790888, 0.07825566696063166, 42.74009873790126, 58.03922122524631, 64.81486074386105, 64.64408859129875, 61.76668882369996, 61.06461594181677, 58.19641020990188, 52.595685297443026, 49.379722226050596, 45.78559167923466, 49.23253920770461, 50.45594215393067, 52.556736161631925, 54.204127711634484, 54.939270096440474, 55.77253841584729, 57.07151759055353, 54.14344080032841, 51.857765874555035, 48.32322397539693, 42.081705370256984, 41.640246529732984, 40.47569874794253, 43.148719495342625, 44.25453370617282, 45.285960166685044, 46.725399417261926, 47.475160475700136, 50.26624848765712, 47.93741964524793, 45.41604949582008, 44.774412493551935, 42.678446923532796, 42.01184795748803, 39.75466120627619, 39.64070458565989, 39.963009665089274, 39.458647774111846, 38.02791226294733, 39.035518169403076, 40.524512644737, 39.35851750835296, 38.757363288633286, 40.4803349894862, 39.66939280110021, 42.422900584436235, 53.68413517552038, 53.20101291902604, 56.284027253427816, 42.590001398517245, 37.18007626072053, 40.0959191783782, 38.6403315298019, 38.42459332558417, 40.44924628350043, 39.10317905487553, 38.30223891042894, 36.93948984146118, 39.62395998739427, 40.516197219971694, 42.2706380967171, 44.639118179198235, 44.998477889645486, 43.92541154738396, 42.77521179568383, 44.263959161696896, 41.44561852178266, 39.21393502143122, 38.53198389853201, 37.325333395311915, 41.101591356339, 40.82698622057515, 39.07343179948869, 40.039578253223056, 38.23925349020189, 39.971513363622854, 38.841105891812234, 37.373456954956055, 40.25182947035759, 37.92636602155624, 43.759762010266705, 49.729389759802054, 51.70729198763448, 43.12722490679833, 40.10010042498189, 41.85499629666729, 39.17700590625886, 39.650130041183964, 39.7079889235958, 38.46030650600311, 37.35599456294891, 41.01093753691643, 40.203097943336736, 41.650405468479285, 39.73169965128745, 41.366672977324455, 43.26653180583831, 42.003458007689446, 42.67389697413291, 44.23141133400702, 46.617040018881525, 48.442444416784475, 46.86842472322526, 44.5579957192944, 43.050911272725756, 42.727829564002256, 43.65025335742582, 48.781450948407574, 50.36084821147304, 52.802758985950106, 52.21624697408369, 50.6464595179404, 50.3525798551498, 48.753064755470525, 48.73153094322451, 47.48953988475185, 47.34608311806956, 47.01774935568533, 48.24935790031187, 46.77789249727803, 48.28025441015921, 46.60095830117503, 49.64362713598436, 54.13976946184712, 55.90959387440836, 62.85457780284267, 70.3212957997476, 76.98548116991597, 49.94975243845294, 0.10099505645132835, 0.14961502574864896, 2.7471780584704493, 0.30957793816924095, 0.7720041455280396, 14.340072581844947, 79.69806686524423, 70.30927765753962, 79.66487576884609, 75.5334040426439, 64.30350526686638, 37.80464310799876, 27.264608836943104, 47.57062312095396, 74.02125189381262, 58.59840216175203, 1.0449251748861805, 0.030939937456541007, 0.08832708016158113, 0.03915734318715911, 0.031056396227570313, 0.0036073021493071033, 0.15966268256306648, 0.1270265862225525, 0.18162220986860414, 0.16691083959754438, 0.2707725510962548, 0.1410804538717193, 0.17698181612837702, 0.49237791629087546, 60.87905645370484, 80.26545340015043, 65.45951797116187, 41.317753176535334, 38.39554817445817, 48.466421865647845, 71.630567273786, 77.52834504650485, 73.82543933007025, 70.09483383547875, 73.05669399999803, 3.043470469213301, 0.6126657020180457, 1.2024176529338284, 7.107759839104069, 1.2334966755682424, 0.3155513708629916, 46.25006698792981, 60.702981256669574, 69.49171450830275, 67.02754820546797, 64.08932424360707, 63.30255954496322, 61.63736435674853, 55.07607060094034, 51.15498696604083, 47.218719836204286, 50.577414035797126, 53.09565021145729, 54.609822380927305, 57.16394039892382, 56.44511115166449, 57.07208633422852, 58.37263445700369, 57.61134163025887, 54.88845186848795, 52.8209940848812, 44.021246817804155, 43.68385630269205, 42.12399244308472, 43.756298557404556, 46.90214533959666, 46.96980230269894, 48.91764740790091, 50.022747747359745, 52.04685549582205, 50.322318769270375, 47.382655297556234, 49.25859159038913, 44.8866315041819, 43.57963500484344, 41.82346044048187, 40.29119829977713, 42.1311507686492, 42.31001477087698, 39.31451635975992, 40.894905982478974, 41.59229163200625, 40.83342283002792, 39.45883212550994, 42.58541222541563, 40.98498321348622, 45.88440010624547, 56.48033795818206, 55.302607090242454, 57.815948147927564, 44.604899421814956, 37.08292307392244, 40.37923589829476, 37.940478709436235, 39.139245248609974, 40.24721676303495, 40.492415889616936, 39.118186043154815, 40.203439189541726, 39.77593221972066, 42.8805588137719, 43.39561308583906, 45.91499067121937, 47.165254008385446, 46.63006621022379, 45.456179265053045, 46.90207473693356, 43.477720060656154, 40.960303660362, 40.26349459925006, 39.59354592907814, 42.2266879389363, 41.40974844655683, 40.85053613108974, 40.93452976595971, 38.11523206772343, 40.80386777077952, 40.28673072015086, 37.02255387460032, 41.91516937748079, 38.94737074452062, 46.134239396741314, 52.762558614054036, 56.21135357887515, 43.98365482207268, 42.99143245143276, 44.792278889686834, 42.35696161946943, 42.39379659775765, 41.13560615047332, 40.0025353893157, 39.85530138015747, 42.56353716696463, 41.84820275152884, 43.83411053688296, 42.40138638404108, 44.66466065376036, 46.151474291278475, 44.470938713319846, 46.529414269231985, 48.79338279847176, 51.20322427441997, 51.23466207135109, 49.547434929878484, 48.04586533577212, 45.53212027395926, 44.003003874132716, 48.02730860248689, 51.267366793847856, 54.46309435752131, 54.96594613598239, 56.43922759640602, 53.86221078134353, 52.81761692416284, 48.9647864526318, 51.13542610599149, 49.8606675670993, 48.208039652916696, 50.72203966879076, 50.49463633568057, 49.361036054549686, 50.40330002384801, 48.26156039391795, 53.652281607351, 55.90536163699243, 58.156103934011156, 62.889530043448175, 73.72078264913252, 76.53944492340088, 56.71042419249012, 0.23773736891246613, 4.280860587473839, 11.46897312133543, 2.900726348161698, 1.1302057148948794, 15.853285731807834, 86.31345010572865, 75.95786725321125, 85.15881415336364, 79.32909734787481, 72.82389348553073, 55.5675200493105, 39.93898907015401, 55.865102429543775, 83.01983587203488, 69.99828077131703, 2.004943905818847, 0.2479632330998298, 0.18613794578179238, 0.11781959599184415, 0.1394234363350176, 0.12454247718015987], [0.07664777098163482, 0.003425233932625082, 0.03816523251213855, 0.06034166995255698, 0.02535459149869219, 0.03918067056445345, 0.026529437126291376, 0.14252725688199844, 27.825641132170155, 63.061412226769235, 52.78688515386274, 28.41022529909688, 21.916429650398996, 41.364319555221066, 53.487616585147, 63.15721611822806, 62.07886242097425, 61.19009648599933, 61.212654036860314, 5.6996441464270315, 0.5173123928327714, 0.5538983006150492, 2.658713657048441, 0.29256557685232937, 0.23483801723247577, 36.64452368213285, 67.32028253616826, 60.73507016704929, 58.1007279119184, 56.741014757464015, 54.77782534014795, 48.3823811623358, 44.86602337129655, 43.41431102445049, 45.3219400682757, 48.74003071938792, 49.721093946887606, 52.60223173326062, 51.32496287745815, 54.21745200310984, 54.44814228242444, 53.54080392468361, 50.63160942446802, 40.14418394334855, 39.91284647295552, 40.84611561990554, 40.36773158657936, 41.60851847740912, 40.526089437546275, 44.55557953926825, 47.10553984488211, 47.29475105962446, 46.749274884500814, 46.52287567815473, 46.53976148174655, 44.657337588648645, 40.548054710511245, 38.86740930618779, 40.51839766963836, 38.54145642249815, 36.19035243988037, 36.39558653677664, 35.63910645823325, 36.19402377836166, 39.1213474735137, 37.55974600392003, 38.07838924469487, 37.66832505503009, 38.465731143951416, 38.55019546324207, 45.02223568577921, 50.97923732572987, 51.77479990067021, 54.03130415947207, 45.96700129970428, 39.32207868945214, 38.96462132853847, 38.812770689687426, 39.15189097004552, 39.933325167625185, 37.99563115642917, 37.876422482152144, 34.79739327584544, 38.460843870716715, 37.526296031090524, 40.003672876665675, 40.94989761229485, 40.68443552140267, 43.00605896980532, 40.8639310252282, 43.994464874267585, 40.958444456900324, 38.717108003554806, 36.380763899895456, 37.61449444678522, 36.81348369967553, 41.229111533011164, 37.044170056619954, 39.304667288257235, 39.809009567383804, 38.563982594397764, 39.410269260406494, 38.99955395729312, 38.484146671910445, 40.35462694783365, 43.65861192826302, 48.57669930304251, 46.846757550393384, 36.08828060088619, 38.507092537418494, 38.850605872369584, 38.349868251431374, 39.523221754258685, 38.82815030313308, 37.84997001771004, 37.5057271219069, 37.61490629565331, 38.858399621901974, 39.97112897134597, 39.975431811425, 39.655225200037805, 40.12801593349826, 39.67975962546564, 40.585780066828576, 43.29137609850976, 48.556130393858886, 48.901910858769575, 50.57794355577039, 51.97153029903289, 47.558291189132206, 42.77168166252875, 41.9663288516383, 38.68779220888692, 39.69047554077641, 39.69759464263916, 40.89385870964297, 41.08625096659507, 40.95256482401202, 42.819452208857385, 41.8487322715021, 42.23291274039976, 44.268344371549546, 42.187354410848315, 43.807132474837765, 43.26420191795596, 47.932959910362, 51.603643355831025, 56.19976297501595, 59.36311529528711, 56.5054960404673, 62.860665321350105, 65.34202337265015, 74.60538694935461, 48.66040660488991, 0.14985309523199836, 0.4327358263394525, 2.1607430231186653, 0.6915425437112009, 0.42716321084768544, 18.231398174839637, 74.99825939055413, 62.178384719356416, 69.72703318442069, 67.20829886774864, 63.25176877360191, 34.01999127480292, 20.130729444565315, 39.16819626285184, 69.69417156711702, 47.90051798666678, 0.4374930791316494, 0.04652270784361228, 0.08819389577594497, 0.0963674946838329, 0.019482738233261535, 0.0392663536683446, 0.05878679874923922, 0.05555213038479129, 0.05789543629714078, 0.0678675300291469, 0.01374645571735117, 0.018121308061264215, 0.024428672735549273, 0.0876922230987299, 35.724296416005785, 70.77273707236014, 56.90114159737864, 30.99085657827316, 25.42530748151964, 44.75960554615144, 60.84492398846535, 68.46507333940076, 67.96002895601335, 64.16742255610805, 68.82256600164598, 5.920707458449948, 0.7076389703058428, 0.24871755391359332, 5.655516011099662, 0.37160406309750776, 0.1846166483817562, 39.709667698029556, 67.64991852544969, 61.82415939146473, 62.15063395038728, 59.5460860190853, 56.393524139158195, 51.99747677772276, 46.94309488419564, 46.20029211044312, 47.50187573894378, 51.07111884701637, 53.04513008363786, 54.8285964996584, 52.928431726271114, 56.145214573029556, 55.132686092007546, 57.18920046283353, 53.33784872485746, 42.8406879209703, 41.87205860691686, 43.11895655047509, 41.056248757147024, 42.271375502309496, 43.382696720861624, 47.62063334065099, 47.62030386155652, 50.27056701721684, 49.18902051064276, 50.24179250963273, 50.22852705370996, 46.36070136101016, 42.71209301487092, 41.16215667416973, 41.101705105074, 39.52749713774651, 38.20272445678711, 39.66057923532302, 38.2105613523914, 39.0822139863045, 41.00164151960804, 39.9035975240892, 39.48026787850165, 40.163556529629616, 40.99462047699959, 40.54631317815473, 47.461502782760135, 53.62237353478709, 52.59708950596472, 55.269180651633974, 46.97472095489503, 39.72989928337836, 38.11985261978642, 38.41020999416229, 38.95439570949924, 39.84847253368747, 38.69085165762132, 37.67187087766586, 36.363077932788485, 39.54977620032526, 41.41330211393295, 41.6182694896575, 41.578684929878484, 44.14385618702058, 45.50361248754686, 42.67567380782097, 45.25294165457449, 41.15661044274607, 39.21365261077881, 37.65567933359454, 39.24710650597849, 38.9251152161629, 42.17585009913291, 39.62335202001756, 39.3116569519043, 39.62915320550242, 39.19373481504379, 40.19024825865223, 39.16681951092136, 38.27043241070163, 40.88176996477189, 44.12456204814296, 51.67584242359285, 48.74221940194407, 37.89230023660968, 39.35880776374571, 38.81520648156443, 39.2151705680355, 40.798631406599476, 41.59186409365746, 39.56343389326526, 38.60310431449644, 39.028983500696, 40.047422993567686, 42.038594599693056, 42.169742968774614, 40.53688380026048, 42.739922231243504, 41.29565062061433, 43.9575396814654, 45.00374171041673, 50.32232661401072, 50.35011660668158, 53.43228370912614, 52.48539609293784, 48.52972107548868, 44.859951542269805, 43.426788083968624, 40.587337247786984, 43.39364797838273, 42.18210627955776, 42.28605693386447, 42.6064008282077, 44.216623998457386, 45.16164064407349, 44.867509949591856, 44.874891850256155, 45.331310610617365, 43.85573848601311, 45.55350503613872, 45.22086843367546, 52.32927007059897, 53.780598025168146, 57.83545801716467, 60.85665187528057, 60.476028996129195, 64.76330118794596, 69.7169997615199, 76.70788718808082, 53.438798765982355, 0.2630352162786069, 0.19726356491446498, 1.8360830506970807, 0.781251868653682, 0.49422945887331043, 19.223153783429055, 80.80856046369, 66.78747561670119, 78.26553098617062, 73.7153854677754, 69.89378098518618, 46.52589198081724, 31.19603183961684, 47.499357577293154, 77.54152421028384, 55.551395185532115, 0.5865246369954079, 0.01735040910481926, 0.021124460824554967, 0.08060357323096645, 0.0298736349964935, 0.04676012615222604, 0.1288691655762734, 0.13385592298882623, 0.12778930335996613, 0.15335569518708414, 0.21339322440326217, 0.18723924313822102, 0.10611918108958392, 0.23583806840883148, 41.57592358127717, 83.13644793725784, 67.68725948949015, 42.44424612291398, 32.232104347598174, 51.86835235165012, 67.92521399836387, 74.15631478832614, 73.54979868858092, 69.19366928838915, 76.53193750689107, 6.9511268504204295, 1.0694230732417878, 3.1813866428790556, 6.796236374685842, 0.9734787119011726, 0.30758185011725275, 43.82319850306357, 68.75065326690674, 64.39586139494374, 63.45202146037933, 61.03460588762837, 60.48394041676676, 54.37931253064064, 48.13973157636581, 47.04775548750355, 49.98171191061697, 54.9679151658089, 54.632838849098455, 59.06666255766346, 56.2244660623612, 60.27049679909984, 57.54208041775612, 59.76492289573916, 55.66664618830527, 44.24264107981036, 44.05544988570675, 45.59814160869968, 42.66527560449416, 45.449672052937174, 45.52830773015177, 49.48864644573581, 50.80819845199586, 52.39755069055865, 51.4113962265753, 51.504376011510054, 51.427603460127315, 51.21763898480324, 44.02200775761759, 43.23152465205039, 44.16862987702893, 42.9749898756704, 39.90803764712426, 40.36629207672612, 39.5904198000508, 40.29622285596786, 43.38739179795788, 43.53282936157719, 41.723824393364694, 41.718815526654645, 41.85740070958292, 43.409796376382154, 49.26406329677951, 57.56679134984171, 55.58111106195758, 59.33194029715754, 51.71386588004328, 40.0521965180674, 38.07150156267228, 37.98487993978685, 38.35378669923352, 41.56177166969546, 39.405491813536614, 38.55031705671741, 36.60078533234135, 40.54719571144351, 42.56591412328905, 43.512754671035275, 44.32419500043316, 45.693239473527484, 48.17497407236407, 44.18422129846389, 47.673448055021225, 45.29156915603146, 40.493612212519494, 37.14435131319108, 39.60107295743881, 38.38830747912007, 41.88160565591628, 38.36653832466372, 39.651530327335486, 39.44113439129245, 37.65827202027844, 40.902782101784986, 38.420929831843225, 39.86005921517649, 40.47317274155156, 45.30498366202078, 54.519199940466116, 50.0866392350966, 40.42205249109576, 41.67022520496, 41.91969579265964, 41.439609450678674, 43.30384531328755, 44.38368558883668, 41.36739469343617, 42.18509904799923, 40.67785378425352, 43.627511455166726, 43.932871895451704, 44.9707624220079, 43.47513914108277, 45.95423398479339, 44.02583599090577, 47.31228013192454, 48.65349146627611, 52.758028276505016, 52.909533746780895, 56.835116340268044, 56.30467853238506, 53.01193506486955, 47.9503163983745, 45.88694572448731, 43.91145575431086, 45.336837230190156, 42.46813335726338, 44.118819698210686, 44.19534906264275, 46.59254873952558, 47.540699358909364, 45.428350048680464, 47.47245796265141, 48.437666969914595, 48.67190307186496, 49.37094788397513, 47.39473619768697, 54.753608626704064, 56.18121800884124, 63.33969262338454, 64.63256859010266, 62.18634320843605, 67.31741136120212, 72.33456211705362, 80.83167106874528, 59.677807054212025, 0.3606321212024458, 1.380696609135597, 5.242509553509374, 2.1262570542673913, 1.0676453815352533, 22.610893134147894, 87.39763244505852, 72.5560583606843, 81.30240255786528, 78.79250926356163, 79.26943025281354, 48.541821587470274, 33.61252761656238, 56.845024247323316, 86.33186955605784, 68.13723379565825, 1.690459909938997, 0.2019868187245823, 0.17346181065565155, 0.16648828082026976, 0.19066938649742834, 0.12860828199453894], [0.01850848506775595, 0.032625968658155015, 0.013925982676746865, 0.079169096575389, 0.0179131064308627, 0.06301623228336535, 0.02596975435622998, 0.26425256063380553, 16.452058092240367, 72.88092474783622, 53.40589400260679, 43.285986761893, 42.84295897330008, 48.27761857740341, 52.147687865841775, 59.691394144488925, 65.04297010360226, 57.86582108466857, 66.50035027534732, 9.688544581013343, 0.675448200875713, 0.3721838690821202, 3.295817134841796, 0.7120524334811396, 0.4833443607053449, 27.882135029762026, 67.77116683221632, 60.07192680912634, 60.91127872467042, 55.172886463903616, 50.60088549890826, 47.58682250976563, 45.532865524292, 48.35400673650926, 49.39570196213261, 50.01694263950471, 51.83353739400064, 50.63802642206992, 54.93323749111545, 53.61558391201881, 52.53311957082441, 50.470878539546845, 42.48124191837926, 38.13732677890409, 39.50229983175955, 41.25131999292682, 42.61111551715482, 43.208225773226836, 47.95946728798651, 49.16995386923514, 51.43054523775655, 48.87703126476657, 50.371666108408284, 49.331198584648874, 44.56020009133124, 40.35006915369342, 40.04206895828247, 39.857164505989324, 38.88398132016582, 38.17175734427668, 36.72363396613829, 37.13477680760045, 36.52683688748267, 37.11993063649824, 38.226992161043235, 38.05904019263483, 37.366447679458126, 38.00986936015468, 38.83546160113427, 40.49379264154742, 41.99802944737096, 49.917263446315644, 49.92477086282546, 51.90894496056342, 48.83517565265779, 41.28535047654183, 38.99946374277915, 39.68249351747575, 39.23486086630052, 40.185792446136475, 38.852370938947125, 37.13348242544359, 37.946844716225904, 36.45830523583197, 37.181911929961174, 39.29144890077653, 41.143643086956395, 42.528620227690666, 43.17888644433791, 44.040823367334184, 41.22532644579488, 40.295112825209095, 37.79800253529703, 37.665375432660504, 37.49027298342797, 40.123140427374075, 39.47867539621169, 40.25437116622925, 39.52180970099665, 39.93873411609281, 39.54173926384219, 38.49178744900612, 40.012835533388206, 38.48223255526635, 41.40943857931322, 47.765972845015995, 47.728157274184696, 50.8984443449205, 42.70082796773603, 36.529578624233125, 38.45241861958658, 38.08493175814229, 38.11870336532593, 37.54579413321711, 37.740767309742594, 38.310318992983916, 38.33408463385798, 37.30049302501064, 38.84971941671064, 38.86273384094238, 38.28990697860718, 39.38373050382061, 38.93152044665429, 40.899734420161096, 42.44548166951826, 48.43730218948857, 49.11627623342699, 52.17516014652868, 53.5753325493105, 52.92944369777557, 52.10770714667536, 50.47602076684275, 44.63057133459276, 42.467878403202185, 40.955161433066095, 41.08577635980422, 40.55562096257364, 42.057425898890344, 40.83010842723232, 41.913298406908595, 42.748457308738466, 43.35684045668572, 43.53894433667583, 46.16106448634979, 50.39694186179869, 54.999278437706735, 57.671369583376, 58.97713445848035, 61.037649646882095, 62.61527792099984, 64.75450331164946, 64.19787191575574, 70.79412967927995, 44.07732494415776, 1.2495948181998346, 0.5059125755102404, 0.8307721598013755, 0.24102350306366724, 0.5600992001352773, 24.00800020464005, 74.1042257124378, 63.6401814799155, 74.80996993280228, 66.28847168337914, 57.15362064300045, 23.885594798672585, 16.447440481955006, 41.24583651942592, 68.8027423427951, 41.41284319662279, 0.10320872879557072, 0.037149472702895446, 0.03578512373590662, 0.023346426070577676, 0.036879392235629985, 0.004830171434854668, 0.01930647863886289, 0.08035127749486316, 0.08850464402067085, 0.043186234054906715, 0.06367278878667182, 0.04297499680110524, 0.04172644968475065, 0.20040461733456583, 22.657687010303622, 81.5643305932322, 60.71469737637428, 48.14378338475382, 29.382820129394535, 43.268504758034986, 58.48140570425219, 67.3525244189847, 68.12235232322448, 63.24184125469577, 72.74748571457403, 10.755606755133599, 0.7526489034775765, 0.03770110197365284, 5.176106277973422, 0.3169395834688218, 0.39011385051473496, 31.338243253769416, 68.60100700009254, 62.6929683070029, 64.46838994180003, 55.860697607840265, 53.212379947785415, 49.157818055921986, 47.29481773991739, 50.44290811784806, 53.043388551281346, 52.36973716366676, 54.14249943148706, 54.06446387690883, 55.66344161187449, 55.11359983874906, 54.22061343346873, 55.61793427313528, 45.28870582580567, 40.33357558711883, 41.20968795591786, 41.095131212665194, 44.1466018461412, 46.04615472978162, 51.49279717476138, 51.85844444459485, 53.52559297315536, 51.00756468311433, 50.265032552903705, 52.484493947798214, 46.529841807580766, 42.83325502949376, 41.471890557196836, 41.79694521811701, 41.33661977706417, 39.736481020527506, 39.07893488484044, 37.73393846327259, 38.47758846898233, 38.34980941587879, 38.60008408946376, 39.00775563332343, 39.87477202569285, 39.62607022254698, 40.701948904222064, 41.75558382464994, 43.407050717261534, 51.50798066969841, 52.76175060579854, 53.72200958190426, 50.81008511204874, 41.69509695422265, 39.3572937288592, 39.710707126125214, 40.10640759621897, 39.94036189971432, 38.50661400825747, 39.47062277024792, 39.03758918085406, 36.94258851389731, 38.94761000910113, 41.22747982701948, 41.893078588670306, 45.10233440706807, 45.366537417134936, 45.415618035101126, 41.844001893074285, 41.51486404480473, 38.49512538602276, 38.83364554374449, 37.86347081584316, 40.3520264164094, 39.19366029001052, 39.203462293071134, 38.052215268535, 40.79268509341825, 40.62603142953689, 38.67830791781026, 38.241559843863214, 39.47429410872921, 41.51327940725511, 49.23564180251091, 52.26561000270229, 53.51723832468833, 42.542434815437566, 36.98416563772386, 39.94661415776899, 39.164364107193485, 39.43756503443564, 39.816497372042754, 40.302137790187714, 40.56778031010782, 40.27902326276226, 38.63412241781912, 39.52803058008994, 40.849441789811664, 39.95274482234832, 41.265118891193026, 41.095986289362756, 44.26674404451924, 44.81437360086749, 49.44414323376071, 51.46979247370074, 54.52655830690938, 54.31648792759065, 56.145520517902995, 53.49983476823377, 52.65609372046686, 46.09244654255529, 44.67332124710084, 43.276796648579264, 43.304037509425996, 42.50802778428601, 43.90090065617716, 43.67332473877938, 45.793863957928075, 45.39313500927341, 45.02356536926762, 45.867063230083836, 47.9350152323323, 51.874396724085656, 58.94531619164252, 59.97841358184815, 59.91043498439174, 64.01279095680484, 66.04512783788866, 65.9237147915748, 66.31508888736849, 75.17700179930657, 53.60579367606871, 1.8016745486567098, 0.27423091713459263, 4.220804687469236, 1.1033329439740027, 0.5663700281612335, 25.568046454460394, 81.87221311753797, 70.86152384358068, 78.58751835361605, 71.61999256380143, 66.99436495381018, 31.186616190018196, 20.353861316557854, 46.78803966891381, 76.23124076474097, 50.62708300928916, 0.3494642753033869, 0.04277987803723063, 0.028793014353141192, 0.01376537713147099, 0.0624173277268006, 0.09494580403571168, 0.10304842489741503, 0.15613780477114264, 0.16673473130551078, 0.15744899489706563, 0.12841506695915617, 0.18117961023123036, 0.22315994145408755, 0.43909788011543216, 25.62630737981489, 93.08886604924356, 67.92728500981485, 60.6049180799915, 58.698348076112815, 62.30261794982418, 66.69417811978248, 73.60656322971468, 75.00979900360107, 69.02765889321604, 79.43324412069013, 12.222761473348065, 1.4121460506031591, 1.16743587197796, 13.209228746352657, 1.9935084807295955, 0.5190816269286218, 35.125699581638465, 70.38939599067935, 66.70136390193817, 66.50418635337584, 58.674833466929776, 54.67310590128745, 52.846281605382124, 50.2048594720902, 54.34438382425616, 55.09576874394571, 55.232365285196614, 57.02682218243999, 56.185724812169234, 58.207361467422984, 57.29255491687406, 55.88907595603697, 57.404526818183164, 46.566355151514855, 41.26306356922273, 43.48008917224023, 44.785587326172866, 46.35660248418009, 48.822647602327415, 54.818500318834865, 55.57609827287736, 57.297183313677394, 52.96938127087009, 54.622087632456136, 55.511516447990175, 49.516624712174945, 44.963910041316865, 43.865230621830115, 43.341280414212136, 43.166903603461485, 42.48495248056228, 40.63205226775139, 39.836254350600704, 41.11107956978583, 42.04661192432527, 42.24482497861309, 41.29980441062681, 41.59305649418985, 42.521681554855846, 42.22160846956315, 44.867851195796845, 46.95543073838758, 54.00610293111494, 55.97417177692537, 56.58431999145016, 54.13083822496476, 43.41513472218668, 39.41908282618369, 40.99385561481599, 40.50082152889621, 41.12114829401816, 38.881004241205034, 39.15466800812752, 39.88338162822109, 38.997400576068515, 40.70453766853579, 44.14405622789937, 45.04631511626705, 46.69383218211513, 49.27761508572487, 47.97072056801089, 44.25825603546635, 44.400681218793316, 39.744149254214385, 39.47268201458839, 37.30698062527565, 40.84199320885443, 40.55562096257364, 41.09519397058795, 38.5672930748232, 42.258415991260165, 41.336525640180035, 38.77079740647347, 38.98423317940005, 40.52420669986356, 42.1569795762339, 51.773772239685066, 53.190485277483546, 58.047320919652144, 45.170626794138265, 40.57672723647087, 43.56071741350236, 40.79534446039508, 42.279239854504986, 40.27743470284247, 41.434988898615686, 41.32626864217943, 42.981418640382834, 41.40032299103276, 41.24974320011754, 43.922544294788, 41.740400329712905, 43.72317021892917, 43.2472925801431, 46.53293263527655, 47.299214716880556, 52.126365861585064, 53.72355499575215, 57.212726839127086, 58.16807108540689, 59.06308535606631, 56.35702256233462, 56.191000400050996, 49.54455591017201, 47.15021564114479, 44.248234379676084, 47.39011172325381, 44.73882090660834, 46.46151411917902, 45.27001180956441, 47.86277301849858, 45.9479699596282, 47.63256519071518, 47.873355573223485, 49.88944599705358, 55.50402079859088, 61.67222638284007, 62.56950386108891, 64.87090356888311, 65.01145778163787, 68.88344903146067, 68.23416340735652, 69.16846413766184, 76.87777288498418, 61.11630101357738, 2.0490236243894024, 1.5533796914162175, 7.255873930069709, 1.8342962885095229, 0.762453296732518, 29.15891751166313, 88.86811333317911, 75.81732872993716, 88.71782379765665, 76.74771493481052, 74.45875306283274, 34.53627717110419, 26.144503470390077, 59.22770723219841, 87.2165366142027, 62.05695206119169, 0.7895903986307883, 0.21981916991212677, 0.21568606427359968, 0.07954328456112454, 0.15521485268348648, 0.2844063114495047], [0.032160171878434, 0.02800642208556735, 0.07566073563911262, 0.019116659288204486, 0.026298191571127505, 0.059803083328710455, 0.08526354051765897, 0.25930862753621997, 8.212629739315279, 63.06077680280132, 54.14216210765224, 39.788844662327925, 26.10116324117107, 38.48338965446719, 44.33295757539811, 53.65007723531416, 65.94509170901391, 57.8894768991778, 68.11772392642114, 16.64925133028338, 0.6261969598070268, 0.4626584239304066, 4.903518711366962, 0.44327921864967196, 0.0634490872823423, 28.16355528370027, 68.33463099695021, 61.44503093534901, 59.49838999778994, 57.859286415961485, 54.498576118100075, 54.5091429833443, 49.104940583628995, 49.582289111229684, 51.046906055942664, 51.833039252988755, 52.113065104330744, 54.284285268475934, 52.51101701490341, 54.11848668129214, 52.20679798433858, 45.76304981785436, 39.701932784049745, 40.843181687016646, 39.547293340006185, 39.55897023600917, 44.06256506519933, 44.4003438949585, 45.91850511489376, 49.140845960186375, 48.89997713027462, 45.15691418801585, 46.910849079009026, 48.86960229566021, 43.70875550854591, 38.75239364562496, 41.387994981581166, 39.71308800481981, 38.943754319221746, 37.54853979233773, 38.53563954753261, 36.89173498461324, 37.21568353714482, 37.65573032440678, 38.339030742645264, 38.6580841772018, 37.33021282380627, 39.56679144213277, 38.523425286816014, 38.54359019187189, 37.88285124686457, 44.77188256479079, 51.4276897522711, 51.62397692280432, 50.98473256634128, 41.6932769744627, 37.112144731706195, 41.2722497601663, 38.251848220825195, 39.18970654087682, 40.971600086458274, 39.22675724952452, 35.20983834420481, 36.43768141346593, 38.03849089530207, 39.90774346936134, 42.2900773632911, 42.893796813103464, 41.853058645802165, 43.430600627776116, 42.03223643764373, 39.417792366397, 36.78911401379493, 36.50507557776667, 37.18002134753812, 39.90329157921576, 40.60305418506746, 39.17019274926955, 38.236943214170395, 37.85611244939989, 39.1425714185161, 38.58049577282321, 41.335807846438506, 38.53569838308519, 39.62577996715423, 47.27733965842955, 48.61332247334142, 51.530530375819055, 53.41504096984864, 44.924866768621634, 39.79251207843904, 39.6473059346599, 38.29701823572959, 38.46038103103638, 35.319260704901914, 37.36241548292099, 38.65218885483281, 39.22546678973783, 38.936246902711936, 39.981099636324, 38.66143388132895, 39.025657330789876, 40.132055974775746, 40.89513740231914, 42.806261277967884, 45.573615028012185, 46.95774885915941, 51.570981779406154, 51.639101582188765, 51.98617250688615, 53.141851809717, 53.34130825534944, 52.94206588499008, 50.274642359825876, 49.443598024306766, 45.10353072997063, 43.600109777142926, 41.57609224319458, 42.16449483748406, 43.50396856184929, 44.12643694108532, 43.94469784152123, 46.38571039322884, 48.360255072193766, 50.384143167926425, 54.53390098387196, 59.49426366436867, 60.946313335049545, 63.47363372002879, 66.7005794279037, 68.99764491665748, 66.04005229088568, 72.17386261109384, 45.97689351727886, 5.0053297127446825, 0.43247471293134077, 2.1266934179490615, 0.29680694603631574, 0.42736420167549966, 27.75618968471404, 71.99948187797301, 64.33415858976304, 72.32296759082426, 71.94962070834252, 56.30612980934882, 41.42649304482245, 43.401163239632886, 42.652508289583274, 63.22185677866783, 32.407848104353874, 0.10775931404843446, 0.06971202460267852, 0.07467413696670726, 0.07601174180425944, 0.09962233414332713, 0.010017806198447943, 0.015104410723001968, 0.032622670649640986, 0.04337687503486391, 0.058076692700025544, 0.01886043543626945, 0.05500806623228616, 0.14474639909402018, 0.31940969608483777, 10.857393241697743, 72.41448433168473, 61.063823623041955, 43.647762652366396, 37.26123402195592, 51.21612102754655, 51.5988149181489, 62.39891213755455, 70.38742696085285, 63.90194477573518, 73.20710905136602, 17.536826825911, 0.7548452469129717, 0.27710766922081675, 7.764802440520256, 0.1181646649755778, 0.03486748829844498, 33.65920382161295, 70.43265188893965, 64.45449690664968, 60.51961437348397, 61.54406293745964, 57.23136594218593, 56.001130227119695, 51.65532058285129, 53.56176899325464, 52.41696642291162, 55.49107305465206, 53.05059786765806, 56.8333512736905, 54.81930832709036, 55.08985380972586, 54.640918931653424, 48.35429699190202, 41.154241331162, 42.984827180062574, 41.036903627457164, 42.90183374958654, 45.3105063592234, 48.86247927142728, 48.76623215213899, 50.88211159552298, 50.102026693282596, 48.94188765556582, 50.409195346217004, 49.68132503571049, 45.95416338213029, 41.959033243117794, 43.86543458507907, 41.9813907531, 40.58926313154159, 38.677044914614775, 39.92478224538988, 39.432952327113, 37.963903104105306, 38.84920950858824, 40.37025367060016, 39.12927850600212, 39.22229359226842, 40.67705362073837, 41.09741795447565, 41.23407333127914, 38.73086375574912, 47.833166968437936, 53.31818980555381, 52.71863591286444, 52.335451725990545, 42.78037755720077, 38.10442986026887, 40.75569714269331, 39.40735493936847, 39.50155065905663, 41.35311334363876, 38.22769426530407, 35.44427840940414, 38.665207201434725, 38.88853126956571, 40.71411609649658, 43.92642351888841, 45.70824253943659, 43.91486037162043, 46.48388339627174, 42.734944743494836, 40.170118654927904, 38.159374421642674, 36.94849560337682, 37.863694390942975, 39.62292448166878, 39.45714550633585, 39.56591283121417, 38.659076536855395, 38.75008336959347, 38.884565753321496, 38.95559987714214, 41.025085526127974, 37.92646800318072, 39.89667454073506, 49.384719325650124, 50.933518179001354, 52.7591500743743, 53.981219414741766, 46.96576226142145, 42.06014017904959, 41.280616175743845, 40.733131747091974, 38.23568021097491, 37.492367529099994, 40.047301400092344, 40.044626343634825, 40.398855593896684, 40.02702274630147, 40.50475958854922, 40.256779501515055, 43.05710861759801, 41.90450053061209, 41.93562846029959, 43.51402551897111, 48.64467790049892, 49.36867290927518, 51.53265630045245, 52.95521759217786, 54.6161138626837, 55.41927014627765, 55.01197514995452, 54.74507354920911, 52.88066117994247, 50.426524377638295, 47.01510960055936, 44.53918403194797, 43.567142255844615, 44.271674463825846, 46.498604051528446, 45.502243580356726, 46.02810790461879, 49.044304663135165, 52.49277407123197, 52.404838454338815, 56.27931648685087, 61.512130921886815, 62.82480309086462, 65.04180123729091, 69.10466286443895, 71.23701234017649, 69.24331080528998, 74.35105262264129, 55.97120254270492, 5.882728128663956, 0.1813696306799689, 2.7281974640584763, 0.9179373986778722, 0.3739558304509809, 30.160277043619466, 81.00470250652683, 67.2888094379056, 80.97064848869078, 72.95633623676916, 69.3255001498807, 36.4874170672509, 30.192640519911247, 50.886288919756495, 70.80872874106132, 41.92550482288484, 0.03732555035141207, 0.0761815605144347, 0.031167128491365624, 0.07649354216071867, 0.12807105517675801, 0.037259241611125975, 0.11198604329218788, 0.08996239442738796, 0.1537800159665846, 0.20893292261227486, 0.11844664661874695, 0.15352607314144412, 0.2451049896978563, 0.44396928000834684, 12.733551148445377, 83.50971637233611, 67.03694620440083, 55.32805150555026, 38.18570137023926, 49.671679927456765, 59.433188438415534, 67.7119468873547, 76.89321917872276, 65.92381677319928, 79.79498078746181, 20.969089000455796, 1.1558621833401344, 1.1938701954580124, 12.288170918341606, 2.4076030283204974, 0.1249444358531506, 38.00801800143334, 72.63555695933681, 66.16286954572125, 63.23087823006415, 63.948809254554014, 60.1975485586351, 60.0843724896831, 54.31420118578019, 55.50781373054751, 54.04687204668599, 57.26394514883719, 55.050841915992, 57.820364736741595, 56.33650856633341, 58.041809989560036, 57.85271252355268, 49.71344532505159, 42.01005935668945, 45.6712467439713, 43.70327203504501, 44.44939705633348, 48.56251209012924, 49.86184427815099, 51.75336807004867, 53.58346362267771, 52.53764206363309, 50.25852534078783, 51.452365383025146, 53.46015214920045, 50.50357933967344, 43.92756492860856, 46.736131022053385, 44.55228867069368, 42.98896920296454, 42.40586965314804, 43.42241071885632, 41.758749177378995, 39.174323005061, 41.115241204538655, 42.84650479593585, 42.03255807199786, 41.236881748322524, 43.46008508436142, 42.9259680932568, 42.55799485791115, 40.68017190502536, 49.87453706802861, 56.90189469245173, 55.95518358292119, 54.45244512250347, 43.83911155885266, 38.770734648550714, 41.26755860544021, 39.213687912110366, 40.45451794901202, 42.90115125717656, 39.80869577777001, 36.85620223322223, 39.0616411547507, 42.15771698182629, 42.62434959411622, 46.62838351341986, 48.21516267714962, 47.00161272479642, 47.80922874327629, 43.86368913035239, 42.29996958086568, 41.032894965141054, 38.796049625642844, 38.14479497171218, 40.528427170168975, 41.023587180722146, 40.42115034595613, 38.24009287741877, 39.09860557125461, 39.636593941719305, 38.29585329178841, 41.086341181109034, 38.338991518943544, 41.17543781957319, 53.50473773094916, 54.31573875488774, 55.575411858097205, 57.90575865776309, 48.4860650954708, 43.225735233676055, 42.953091282998365, 42.35871491893646, 43.60122765264204, 38.798206929237615, 42.997163034254505, 43.2498146641639, 42.42004117658062, 41.883296197460545, 44.907945663698264, 41.48388908755395, 44.66365652699625, 45.28029234178605, 45.310651486919774, 48.573075033003285, 50.3949571424915, 52.653187244169175, 55.408597377038774, 55.43688943309169, 55.499353178085826, 56.83532422588718, 56.80785978994062, 57.92615498265913, 54.293498916010705, 53.289238791311945, 51.20959812594999, 47.25032629505281, 46.78774156878072, 46.9774313126841, 49.700368142897084, 49.00126057286417, 47.25535477361372, 52.6065698746712, 53.25100352687221, 55.43268465226697, 58.42292708735312, 63.725583245677335, 67.48318641416489, 66.77137820951401, 72.09311669872653, 72.83821798140004, 71.52342381015902, 75.45290916196763, 62.63046533830705, 6.516818000424293, 0.6606633168074393, 4.885329700285389, 2.507445245019851, 0.6058629638245029, 33.81381188669513, 86.93336502198251, 73.96269090713994, 86.6612623583886, 82.50493065003427, 73.40107025638704, 58.20418434758341, 58.33740765048612, 59.37254859555153, 80.99189989028439, 52.63736832526423, 0.35901956740886937, 0.18512278735156984, 0.1939813531334362, 0.15217158372604078, 0.20894827501427746, 0.14119253253504155], [0.011493235999237628, 0.04166952552153699, 0.028298127299715436, 0.0317121674907544, 0.04914886107848537, 0.08180243954543145, 0.11104966934409835, 0.20588449022221952, 3.3764238030679765, 53.538905497520204, 56.85494784385928, 41.25637592807893, 18.08278545256584, 20.739738210555046, 38.12943889248756, 52.860598256511075, 67.31648568184146, 55.44891149766984, 69.86450441422002, 24.456174142899055, 0.32590750064099994, 0.19145926911263697, 1.8609669347924573, 0.19838191538808808, 1.5288412210441407, 48.9487478809972, 55.49578774359919, 56.75803392164169, 59.31202642379269, 58.644223290105025, 58.20550226396131, 56.48409951117731, 52.26471962467317, 53.2247785599001, 53.8012767607166, 52.897178280738096, 55.661735380849535, 56.14572448115195, 51.45622891764487, 51.81177608428463, 46.73666054202665, 41.45045088183495, 40.3491356295924, 39.863510900928134, 40.36956725582, 40.38242870761503, 42.43666025900072, 45.12549992530577, 47.159888205989716, 48.4952042179723, 47.599707495781686, 49.678665668733665, 49.44597890300136, 48.136636826299856, 42.839777931090325, 39.778097368055775, 40.2793566642269, 39.40874345840947, 39.567152300188624, 38.074741440434615, 39.42763359315934, 38.635526626340805, 36.693973002895234, 37.224567705585116, 39.3326259428455, 39.33563832313784, 36.588763267763206, 40.27014301669213, 37.497980440816576, 38.422000638900265, 36.304905260762865, 47.06626122997653, 50.65879144976216, 50.245993368087284, 51.495331025892696, 44.926973081404164, 37.51271678555397, 41.45311417118196, 38.63382039531585, 39.9648335672194, 39.328028925003544, 39.63081236808531, 37.560471642401914, 35.96807172221523, 38.16378316571636, 35.753039544628514, 41.56756501043997, 43.71510582585489, 41.33964000209686, 43.38892936706544, 39.832739906926314, 38.20199489593506, 37.89081758068454, 39.290888001841886, 38.93258733134116, 39.968602964955, 39.00986194610596, 39.319909618746856, 40.07708787918091, 39.37799992099885, 38.50002834873815, 39.01217614450763, 40.346103637449204, 39.88824928960493, 43.45738257131269, 47.67800192679129, 47.55013658154396, 47.4657585543971, 44.27632639485021, 38.86792705905053, 40.36764529443557, 37.90544802142728, 36.443431608138546, 37.55290539033952, 38.32639678832024, 37.30246989957748, 37.8438275860202, 38.62956462367889, 39.94307225750339, 39.29910928972306, 38.14272788263137, 41.192794307585686, 39.872493128622736, 38.01216002433531, 39.55800141057661, 41.81816131837907, 46.424836035697695, 49.4034251090019, 50.71889392791256, 52.401822151676306, 53.09632485912692, 53.4069138188516, 53.05220996179889, 55.13025422250071, 53.303088680390395, 53.99864258304719, 49.87412521916051, 48.70711026653167, 43.44807870926396, 43.14681322343888, 44.83739006903864, 42.93783718539823, 42.88218267502324, 47.21127517761723, 49.01500848031814, 54.767489894743896, 54.36141475554436, 58.70132123270343, 62.75329436025312, 65.65973535660775, 63.03214742291359, 66.15296948340632, 67.81749002395138, 43.31090950196789, 4.822467344422495, 0.2477365170395182, 3.1037548472804413, 0.6700611931662406, 0.015399619831793733, 36.46265906672324, 73.95533254069667, 61.01348000188028, 72.19226637194234, 67.9633786601405, 56.18754871429936, 35.10728797604961, 28.945405252518196, 49.18810267602244, 65.6867487199845, 24.51830448642854, 0.14854221154124508, 0.05913275639496504, 0.009356901188561273, 0.09111478218748685, 0.07901777122770587, 0.05127073310676122, 0.026145967985353163, 0.09162845180159615, 0.0363086337494033, 0.05962177329967099, 0.04789320849663308, 0.05112527216213846, 0.09282090596013493, 0.2518631568959644, 4.833853985032728, 65.01472119362124, 65.0436447512719, 48.07980560487317, 18.59251706830917, 27.82268366506023, 44.422822998416045, 59.62460402519473, 72.83746488632696, 62.04752660566761, 74.3464320705783, 26.533494726304088, 0.3098216767032301, 0.12435571260509953, 3.308687411969708, 0.17084646309095045, 1.3474111307051875, 53.0322450976218, 58.59245977094097, 60.79633758914087, 61.054300108263575, 60.79908324826149, 61.07885806791244, 58.99419284635975, 52.96693763425274, 54.60790041954287, 54.536423067892756, 54.2451713931176, 57.21531168107064, 58.862150176878906, 53.888070967889604, 54.786140764913256, 48.47779281677739, 42.974091652900945, 41.02039044903171, 41.97203590023903, 42.800409101670795, 42.49344833435551, 43.53572014839419, 48.36759382678617, 48.196135259443714, 51.448325341747655, 50.26016096914969, 51.58906390590053, 50.286872310023156, 51.024403418264086, 43.3457205372472, 42.28459781216037, 40.41508636166973, 42.23047302615258, 42.612088264957556, 39.947869316224136, 40.18689855452507, 39.7868364087997, 38.039267524596184, 40.06915292432232, 42.114119837361, 41.85887944313788, 40.5006960130507, 40.798419598610174, 40.52401450372512, 38.58883865417973, 36.85209943402198, 47.31350783378848, 54.40189753809283, 52.66062798038606, 55.486252461710286, 46.73125159355902, 37.869060193338704, 41.75998472398327, 38.387158224659586, 39.862867632219874, 39.24667112288937, 41.59133065131403, 39.12060614555113, 36.6957066905114, 40.02548517719392, 37.60496700963667, 43.909533792926425, 46.05754137039185, 43.12462437537409, 45.48797792004001, 41.3729017011581, 38.91264992375528, 38.6541304280681, 39.77341798044021, 40.323530397107525, 39.72075623850669, 39.71626512465939, 39.32300436881281, 39.46354289208689, 39.76230982811221, 39.19790429453696, 38.1212293717169, 39.904887983875895, 38.917639178614465, 45.14166793515606, 51.96141450635849, 49.324722751494384, 51.40443794188961, 45.38954604056574, 41.893741469229425, 42.02345817319809, 40.01711091687603, 37.425604866397, 39.263043095988614, 39.742168457277366, 39.218736002522135, 40.35489759137554, 40.659461790515536, 41.406198701550885, 40.177571158255304, 40.373289585113525, 42.582407689863636, 40.649051820078206, 41.2597805453885, 40.94341785677018, 44.13028478622437, 48.86947285744452, 51.174787090670684, 50.35432530987648, 55.87839926442793, 55.32162274083784, 56.580401543648016, 54.7428927113933, 57.891983293717914, 56.36485161319856, 56.86380455570837, 53.373526603944846, 50.93359270403462, 45.15419598548643, 46.32315251135057, 45.474916427366196, 46.66568917612876, 45.884105928482555, 49.877988753780244, 51.54389389099614, 57.92247187706732, 56.39711310786586, 61.68496231878958, 63.98538143404069, 68.86550026555216, 64.45154336190993, 69.76686877589073, 68.40038561051892, 51.558516486998535, 7.136708892160847, 0.2128463448776353, 3.4372673640328073, 0.9516315390506099, 0.005304911812286704, 37.99238343392649, 79.72477036137735, 66.99977782464796, 78.40173921277447, 73.06766094699984, 61.7942120951991, 38.167842818844704, 35.10768413543701, 55.64120177299746, 75.29653995267807, 31.77371459622537, 0.09098237921153346, 0.035708901817880334, 0.01559690087883463, 0.03937193590606894, 0.03382222644323784, 0.025907467577546358, 0.16512398547943563, 0.22755906346344182, 0.1807076847481151, 0.24668303889132318, 0.22566746980432542, 0.1657220703219214, 0.2612637452060177, 0.4315433951635515, 6.116799981363359, 77.44682250484344, 72.1479122100338, 56.909868871012044, 27.0016590241463, 31.569845484149074, 54.28841160189722, 64.01253208037346, 79.9496712223176, 66.94685720628308, 81.49539101508357, 29.715860735985544, 0.5333531095135597, 1.8576692020700825, 10.445903270475327, 1.3286148876913133, 1.7859136072858688, 54.9060280092301, 57.62796855741932, 62.58688388332244, 61.523505795386534, 62.98197638603949, 62.78825836796915, 62.883254251172474, 54.78253218435473, 56.41960005606375, 57.736480928236446, 58.277513057954856, 58.87430560204291, 60.97113801587013, 56.62447329490416, 58.15736301483647, 51.28002820476409, 44.70784987172773, 43.80459470133628, 44.69649853244905, 44.40862401839226, 45.63086594304731, 47.143881013316495, 50.39164273969589, 51.32486874057401, 54.7233396960843, 51.11416685965754, 54.27074132427093, 53.88488992567986, 53.13541127789406, 47.01441534103886, 44.01062503937752, 44.404638890297186, 44.72337461286976, 44.09048449608588, 40.8878182595776, 42.77966368582941, 41.107435687895745, 38.58536343420706, 41.72752711080736, 43.122227807198804, 43.72833990281628, 41.82638260626024, 44.01073486574235, 41.7705084431556, 40.75025681526431, 38.60561463140672, 49.90792428293536, 57.46227587423017, 56.82813059899115, 57.34748378876717, 48.25463348819364, 38.13290234534971, 41.5890674437246, 38.586944149386504, 40.07910005507931, 40.16479599860407, 41.3270805728051, 39.520138771303245, 37.56832030511672, 40.37882404942667, 38.64752123432775, 46.81916759860131, 47.174098953124016, 46.58481382554578, 49.196806415434814, 43.17388149999803, 40.8307909196423, 41.6089891618298, 40.71365325681625, 40.19672016943655, 39.94117775271016, 39.902930721159905, 38.66393243112872, 39.6417518584959, 39.15501709907286, 40.39024599136845, 37.9839660275367, 40.97698157833469, 40.104109087298, 46.865016183545514, 53.13328927563083, 52.51322138694025, 54.90906784611364, 48.68498809875981, 42.69322249197191, 44.55841149053266, 43.13523046432003, 40.10954156998665, 41.88950138707315, 40.76102764375749, 42.112244944418634, 43.54983675864435, 41.746252506009995, 44.27756586382466, 42.264511354507945, 42.581211366961085, 46.233714626681426, 42.88214345132151, 43.80624209680865, 44.48403942969538, 46.619146331664055, 52.67388951393866, 54.282304471538914, 52.89901394997874, 57.388350963592536, 59.2556776538972, 57.98405308877268, 58.06737992071337, 60.087945768910075, 57.60918824903427, 60.569361794379454, 55.730051302140765, 54.85470379552534, 46.33090311481107, 48.929245856500444, 50.11054215892669, 47.95132444750878, 47.381317769327474, 51.770740247541866, 54.578031570680686, 60.30627273744153, 58.50413976177093, 63.39169148475894, 66.95980887259206, 70.92493287978634, 67.10061411703786, 72.51019016388925, 67.64931448044317, 61.19754114458638, 10.529541930844708, 0.45168669653996346, 14.61899624716851, 4.313827618475884, 0.04224918594944381, 42.61251188093617, 87.31845548076015, 70.87266337487006, 85.19732398371544, 76.16709432294293, 72.87711220402872, 47.79764990652762, 42.957758903503425, 66.19689218459591, 85.2454436209894, 39.95227021555747, 0.22309148383717384, 0.09234747894468809, 0.09160543852035077, 0.13209125477700465, 0.17615833289680943, 0.172991831035864], [0.06860172571313959, 0.06306793938781466, 0.05821915057998511, 0.11459536940580416, 0.06930016807370609, 0.060162110434424494, 0.02721008901003628, 0.13274072879745116, 1.2422072791284131, 46.71779786386798, 57.69040484582224, 46.790220506729625, 46.09785549102291, 38.47221482184626, 39.809488096544825, 51.47355794906617, 66.43282275046072, 59.738089961390344, 67.56629359337592, 37.771291194423554, 0.0502122141000244, 0.43373207771970385, 4.518044350608703, 0.4508814155574768, 7.67916190047418, 67.68793413715979, 58.71367669874623, 62.692544691024295, 56.979965548361506, 61.83269446895969, 56.78790669287405, 59.664259187636844, 54.44176843089443, 58.682568380909586, 54.93380231242026, 55.5046130764869, 56.24579198898808, 53.69002265314902, 52.95500186181838, 44.93214668766145, 40.68660459210796, 41.62269392321187, 39.21727295844786, 37.32921654178251, 38.27642186995476, 41.68677760708717, 41.74526406872658, 44.20750056543658, 43.659976913082986, 46.50228715712025, 49.234088543922674, 49.35310502206126, 47.361454886774865, 46.97617615422895, 44.05941147958079, 41.87707924073742, 39.68905564277403, 39.51843254027828, 38.5727334022522, 38.60379857401694, 37.5306341725011, 38.61632270197715, 35.97933676935012, 37.8504720810921, 38.48158536418792, 36.24515971829815, 37.1879013892143, 38.10559480421005, 38.32024651189005, 36.57080273474417, 38.373006313077866, 50.267103564354684, 48.78131758782172, 50.12015588821904, 51.31617676827216, 48.006669090640166, 37.72405409043835, 40.77395969821561, 38.60087248586839, 41.12618853968959, 39.11901758563134, 39.977342005698915, 38.3247023244058, 37.922223998654275, 39.28093302634455, 38.08169188037996, 39.42683342964419, 43.47291123482489, 42.84078205785444, 45.64136220562843, 38.87410479207193, 36.93433584705476, 39.18407401730938, 38.86740930618779, 38.813272753069484, 39.47755752071258, 38.08603002179054, 40.121198854138775, 40.29396357074861, 39.98019749118436, 39.66893780616022, 38.748137873988, 40.25593619192801, 37.48427175706433, 48.04340993204425, 51.47655071750764, 49.544846165564756, 47.74990289442001, 40.01376905748921, 37.01115546687957, 37.78846333103795, 37.220417837942804, 35.60158114279471, 37.06881823078279, 36.853962559853834, 38.324157114951845, 36.521231820506436, 38.46038495340655, 39.15161640413346, 40.424970734503965, 39.00204858472271, 39.377442944434385, 39.364856058551425, 39.64676464757612, 38.98308000256939, 42.12628310726535, 46.240833728544175, 45.15665923395465, 49.95264714764011, 48.26901289724535, 49.51478119819395, 52.45018105353079, 53.94971101514755, 53.53091955184937, 53.76966245712773, 53.54584417035503, 51.96067710076609, 51.512624755982436, 47.02865354476437, 44.46398042863415, 41.7794906708502, 42.147844376102576, 40.954165151042325, 44.98112140163299, 46.36054054383309, 48.763812049742675, 54.8479651635693, 58.84043593560496, 61.87376168466384, 62.969416956747736, 61.51591993147328, 46.90565193853071, 56.56304505563552, 51.74890441279258, 3.2523683049986443, 0.2434548056654392, 0.8254837016424825, 0.4108734849479891, 0.05569769475128382, 39.51305889314221, 71.14813143207182, 57.89240298732635, 69.34139359381892, 69.43630710724862, 61.478610346394206, 33.832980509727236, 26.00836584644933, 44.94692617847074, 68.40779104540425, 19.966788099658107, 0.2641193532655316, 0.09590713712837427, 0.034191013509107214, 0.052824730969845295, 0.04164802526394206, 0.017050644645707744, 0.04903711949384982, 0.0672666106613413, 0.0054420688426152115, 0.07513838624882122, 0.0484271411363396, 0.06280280784854005, 0.036887018640916196, 0.20752656904439773, 1.9449258812012213, 58.19661809552101, 64.79700611483666, 53.20422141782699, 39.33158259237967, 34.93377016436669, 49.58644682361234, 56.02866918809953, 72.12203241163685, 62.874213187925285, 74.39164130918442, 38.71517427505986, 0.01246439416952912, 0.27967669910961585, 2.305446613219477, 0.27372824088219677, 8.721820558271101, 69.65807007205102, 60.49013383926884, 66.00017747571393, 60.06149330446797, 63.712635501738525, 59.260788502231726, 61.75551006870886, 55.900384149243756, 59.97014130315473, 56.18135921416744, 55.516897939866595, 57.54891318659629, 55.36813028397099, 53.62393856048585, 48.21724153334095, 43.218376867232784, 42.423947857272246, 41.096268700015166, 39.92473125457764, 42.793062502338046, 44.24061321443127, 42.72798253643898, 45.133760436888664, 45.67652233185307, 48.22635712162141, 51.28194624377836, 51.67824683650848, 50.2030041909987, 49.45316468515704, 47.84385934952767, 45.33304429823353, 42.464775808395885, 41.13121309588033, 40.56827060637936, 41.05262056473763, 38.974152688057195, 40.34324030722342, 39.715092335977864, 40.96268846142677, 40.922680285669145, 38.164398977833415, 38.49503124913862, 38.885746386743364, 38.618554530605195, 39.405844826852125, 41.024924708950905, 51.06133645580661, 51.884720402379195, 52.23546658792804, 52.48203069933, 51.395891097284135, 38.85727782403269, 41.130730644349136, 38.177397712584465, 42.780546219118186, 39.132184982299805, 39.169816201733006, 37.83594362197384, 38.881804404720185, 38.806341924975, 39.197096286281464, 41.513020530823745, 45.06016108297533, 44.59207719372165, 46.755472229373076, 39.54453983614522, 39.54465750725039, 39.9137564628355, 40.45930324062225, 39.053918007881414, 40.471862669914, 39.622759742121545, 39.91900459412606, 40.00601845402872, 39.64487798752324, 40.233464933210804, 39.04267649496756, 40.020378251229566, 37.997953199571185, 50.07025157251666, 53.45765752177085, 52.42238713848976, 50.13853219247634, 43.070507434106645, 39.02508466474472, 38.015819595706084, 39.86137713155439, 38.63002746335922, 40.173719390746086, 38.05246237785586, 40.26185504851803, 38.65534636282152, 40.79623483842419, 40.93131342241841, 41.50715266504596, 40.032753329123224, 41.73895297511932, 41.490702244543264, 42.30062069431428, 40.7049181384425, 44.23522387781451, 48.507947998662154, 47.97978516547911, 50.87352160484561, 50.37387832518547, 52.730022553474676, 54.98979806900025, 54.25908011774863, 53.97297067026938, 55.987311717002626, 56.30051297526206, 53.17130096497075, 55.1506309355459, 48.81818002270114, 48.14754886011924, 43.76442570840159, 44.86323064373386, 44.05590880301691, 47.329165935516365, 47.91061808986049, 52.061411411531516, 55.721496612794944, 62.3072777255889, 62.905843180994836, 65.76921263048726, 62.07048816065635, 51.10141915659751, 54.902846967020345, 61.159576523688536, 5.859214500073464, 0.25109179828676487, 1.2633546153383872, 0.7013403179664767, 0.07144650128940422, 40.567882291732296, 79.2635545422954, 63.56329910216793, 78.47463254005679, 73.1136703491211, 73.51197919537945, 38.55818533128308, 31.8213733550041, 53.16655881943242, 76.1688829237415, 25.672255985198486, 0.23509945239751573, 0.15020923418623788, 0.11046792515703749, 0.029764128473377036, 0.03437351097442931, 0.05473076921677398, 0.2146355891900678, 0.11303113277761206, 0.11955177441479699, 0.3100358442433419, 0.2136622131952355, 0.12632464284017203, 0.16690382223215797, 0.44881411197204746, 2.1148797292863173, 68.6519193649292, 74.1415588317379, 64.61576515628447, 59.59578637153872, 51.5742765703509, 56.76300356465002, 63.744190969774806, 77.57757079216742, 70.30277436779392, 81.55370097006522, 44.37887284063524, 0.10420823604950022, 1.0217401060846545, 12.150455520999047, 1.0041604106945377, 10.79420287762919, 73.34900471471971, 61.95981848624445, 68.58536458784535, 62.35258894581949, 65.9949371891637, 62.0727905919475, 63.38635706132459, 58.80354212176416, 63.97391242365684, 59.41409826278687, 58.94779120722125, 59.93969978824739, 57.509387462369865, 55.761194921308956, 49.707867714666556, 45.34688242020146, 45.922776576011415, 42.63117451821604, 41.02662309523552, 43.82037047416934, 47.794229599737356, 45.324552366810465, 47.06075814462478, 46.47542676618023, 51.1556145452684, 55.2960684991652, 55.514403312437004, 51.85927206470121, 51.92844698506018, 50.82730039473503, 48.007618304221864, 44.194925446664136, 44.039893765603345, 42.44367345686882, 42.54277213927239, 40.455706427174235, 41.803103339287546, 41.41205087784798, 43.658176545173895, 42.226770308709916, 40.89102675837856, 40.79727818889003, 40.479468145678126, 41.588808567293235, 40.87378794147123, 43.29085050090667, 55.012328163270034, 54.407149591753566, 54.47045272396457, 55.10109924500989, 51.68097288377824, 39.13983360413582, 41.1269102558013, 37.399501492900235, 43.73032069975331, 39.58183765411377, 38.95305425890031, 38.670596538051484, 40.001746992911066, 40.95088604957827, 39.85695269800002, 42.56405491982737, 47.5767812421245, 47.37989394895492, 49.899322525147475, 41.24587966549782, 41.06956128151187, 41.904171051517615, 40.50286900612616, 39.684388022268976, 40.50700318428778, 39.585603129479196, 40.439624709467736, 40.70675773005332, 40.50412024221113, 39.31898001701602, 38.70669411074731, 40.498405348870065, 38.77208002151982, 51.672688837974306, 56.45227732196931, 55.057913949412686, 53.47375100658786, 45.30888642034223, 41.364174427524695, 41.10551372651131, 42.59808932581256, 39.47667106505364, 42.93339706236317, 39.557754301255756, 43.39380487318962, 40.32143585143551, 43.22355831823042, 43.53199781910066, 45.1166549805672, 43.857103470833074, 43.934280026343565, 44.228983386870354, 44.50569875778691, 43.34980372459658, 46.298469035856186, 51.72027895527502, 48.5152671414037, 54.16200145598381, 52.44778056298533, 55.4806826960656, 57.95276434190812, 57.62134759656845, 56.159339028020064, 57.69418993303853, 59.021672971787, 56.032116951480994, 58.36968875700428, 51.99684527612502, 49.4953497763603, 45.77962967657274, 46.88891126263527, 46.407024552745206, 51.59961900403423, 51.11795586924399, 55.14931694153817, 57.290746704224624, 65.21404427866783, 65.62459091986379, 66.62470509929042, 61.41397360832461, 52.64403243218699, 57.8614515642966, 68.09386022629278, 10.991036238208896, 0.7991195518162943, 8.27861528242788, 2.648104871473005, 0.17701492644846442, 46.098726257201164, 86.59619808197023, 68.63230751406762, 84.43414057454756, 80.1402513442501, 76.7286600605134, 44.01932485641972, 41.7746740002786, 60.839009054245494, 90.68806955891272, 34.86137105572608, 0.38308698563806476, 0.20146278394085748, 0.16825710122864093, 0.07952943369145356, 0.14573790072914095, 0.2299047327570377], [0.03455258019629025, 0.022949780217341842, 0.07521394550079301, 0.05622963939282683, 0.0474061374552548, 0.008973967351560152, 0.018588522103645148, 0.02679796626551017, 0.25879819847403035, 43.99661433312201, 57.44984980552428, 44.36025334942726, 24.851113673179384, 13.903555927738068, 35.7363224029541, 52.25388211588706, 63.86378011395855, 57.990607369330625, 62.57474414763912, 45.91682634046001, 0.26774031380491875, 0.2879616029320225, 0.6667765145820956, 0.23572707759036174, 19.193414372782556, 75.0533216230331, 58.450642554990715, 62.81174159819081, 58.964327919867735, 60.9715537871084, 58.88838298859135, 59.847422107573486, 56.85727773174163, 56.56379815070861, 56.932826503630615, 58.384072088426166, 54.65079545974732, 52.48216405991585, 45.79299711412, 40.69997987439556, 40.16057552829866, 40.70178416467483, 39.98597514244818, 39.32828387906475, 39.5707961820787, 40.04224154257005, 41.20092930332307, 41.17866593022501, 40.589074857773326, 43.64237331574963, 43.27871076522335, 46.556066774552875, 44.61596835044123, 46.99788647313272, 44.30032345556444, 42.37738932332685, 38.54964633141795, 38.131984510729396, 37.699551043971894, 39.44211106146536, 36.60554316736037, 36.95497928127166, 36.97674451335784, 37.16125280626359, 36.109759499949796, 39.3359128890499, 35.03077430109824, 36.50496182903167, 39.71760657525832, 39.783906398280976, 43.84892140665362, 49.39296807012251, 48.76512212138022, 51.0302242155998, 52.746178796214444, 50.85885978514149, 39.24944423860119, 38.8446948605199, 37.63146654252083, 42.23348540644492, 40.303491007897165, 41.944520473480225, 38.99404302720101, 38.00033407826578, 38.25340932415378, 37.72291268071821, 41.2657033243487, 45.61450181468841, 43.96785943738876, 45.09932594914591, 38.58089585458079, 38.57493777428904, 36.71748761207827, 39.9129916006519, 39.76203918457031, 40.33412864131313, 39.11091789122551, 41.48231621711485, 39.77379060560658, 41.20820922236289, 38.64907057054582, 39.806742437424205, 38.78857751046458, 43.66163999803605, 49.66453336900281, 51.71615262185374, 49.67705357459284, 49.06333992558141, 39.1450660459457, 37.78469001093219, 37.50556630472983, 34.924026996858665, 38.835379231360655, 37.11475310787078, 37.98597035869476, 38.48940264794135, 36.24184139313237, 37.81176613223168, 38.5529411223627, 40.04665420901391, 39.45621982697518, 38.93525846542851, 40.04073143005371, 39.979373793448175, 39.0184990052254, 43.62377735876268, 45.821920671770656, 48.049301332043065, 46.34683970482119, 47.80360014207902, 46.12055424721011, 46.996301835583104, 49.558825492858894, 50.205114426151404, 51.80001681850803, 53.15093209666591, 49.77794085779498, 51.089659890820904, 47.64312421121905, 48.82274173921155, 42.471659568048295, 41.580720639997914, 41.21277486124347, 42.38928194968931, 42.97254623905305, 48.62221056415189, 54.80429741644091, 58.50479871995988, 62.301096070197325, 63.61605498098559, 63.5375879656884, 62.60906488664689, 46.982514704427416, 56.43478747337096, 3.318007944091674, 0.24740855479913376, 0.9908342193211279, 0.4656684140284216, 0.0341446383766109, 43.15905101837651, 69.29965957518547, 59.59881836368192, 67.2911314810476, 67.32983742990803, 53.699491254745, 40.75458318956437, 20.45957115388686, 41.388920660941835, 63.75138851904101, 15.352644208938846, 0.19330966256318555, 0.05098464140187829, 0.03104363128753199, 0.0723483782982634, 0.008046069208742871, 0.06706974904743895, 0.06850101579461368, 0.03278206290316678, 0.026750970601795182, 0.046011604624049324, 0.10029871317167437, 0.037292455353083155, 0.03411391442040763, 0.03460512999745627, 0.6084452317126336, 54.61462728438839, 62.94980118351599, 54.12367205465994, 33.678917654099, 27.756919245566092, 48.43956931944817, 55.09287011238837, 68.7006587366904, 61.585796956093084, 70.41931583035377, 46.970590699103575, 0.19310579124477603, 0.2236555084105461, 0.23794018302954015, 0.19841208393054627, 20.721014776537498, 75.45432905997001, 59.73465004274922, 66.29238620881112, 61.19870608852756, 63.87817521249095, 59.64545926740093, 61.85462051822294, 59.77952587989069, 59.23972537440639, 57.64095944743003, 58.43982858042563, 57.65946911227319, 54.18453939499394, 48.26019540909798, 42.74074200660952, 42.86823472669048, 42.271414726011216, 42.35376881014916, 42.189496024962395, 41.41356883510467, 42.36208423491448, 43.70336224955898, 44.49326876671084, 43.339817370137865, 46.381552680846184, 44.69462363950668, 48.088148486229684, 46.78849074148363, 49.791343596673784, 47.27703371355611, 45.13925567750008, 41.24313008400702, 40.50003313249157, 39.76038002198742, 40.388849627587106, 38.98455873612435, 39.53753448301746, 39.21765342835457, 40.36182841947002, 37.798673260596495, 39.309785981332105, 36.54868841171265, 39.70145817725889, 42.26342485797021, 41.176230138348, 45.49337902376729, 51.16390251344251, 50.95584823239235, 52.90680377714096, 55.81400963567919, 50.87333333107733, 39.04561827259679, 37.417026642830145, 37.78230520986742, 42.0087924311238, 41.227789694263095, 41.35338006481048, 38.36194915156211, 39.17312275978827, 39.84125537257041, 37.83991306058822, 41.569145725619414, 47.27024016841766, 45.6708231279927, 46.38441601107198, 39.44602558689733, 39.19477032076928, 37.977827518217026, 38.870253024562714, 39.67543325116558, 40.57455424339541, 41.0098078943068, 40.48610871837985, 39.24384309399513, 39.15225182810138, 38.477423729435095, 39.03690668844408, 38.618503539792954, 44.24639871043544, 52.546165374017534, 54.00404368677447, 51.60269414224933, 49.62639616381738, 42.7525326513475, 42.22677423108009, 40.08061016759565, 36.84156394773914, 38.74873015188402, 39.075345916132775, 39.90730024153187, 41.58401935331283, 37.92817423420568, 38.055470835778024, 40.24649504692324, 41.132534934628396, 41.063501219595636, 41.34706504883305, 40.4614213205153, 42.8118977239055, 41.79682362464167, 45.396308206742816, 46.24477571056735, 51.03765318470617, 49.09080436152797, 49.57252633187079, 49.752818076841294, 48.98264108165618, 51.865732208375015, 52.62605620968727, 53.0081735118743, 54.72197471126434, 53.09504616645075, 53.39302470607143, 51.39069003443564, 50.36980298257644, 45.23149805684244, 45.15362331944127, 43.38472066387054, 46.52766096976496, 44.910173569956136, 51.13085262237057, 57.019848208273615, 61.81785614259782, 63.5636717273343, 65.46500144466278, 63.840591061499815, 65.06288397696711, 49.28172965203562, 62.59674864430582, 8.5267150017523, 0.46114448097444355, 0.6711943904238363, 0.6281433747180047, 0.07024146796714875, 45.87682993181291, 74.0054996552006, 65.04355453675794, 72.54502081101941, 73.2495020281884, 58.27144122892811, 35.62899851029919, 26.304879380810647, 49.396839449482584, 76.19397824810397, 19.759959559286795, 0.3021745563995454, 0.13123915050058596, 0.053014743757704576, 0.03237169258476746, 0.006070397878741665, 0.07971466609066533, 0.15566638490605741, 0.13293534577373536, 0.17424302115555734, 0.12963318506315832, 0.21739609509466157, 0.12483041132650069, 0.09680937419855788, 0.12215225221288782, 1.1065402170342784, 63.55818825383341, 73.79162065444454, 62.046667606599875, 38.33656357180688, 25.015123659564605, 50.27970221734817, 64.58706517373362, 73.51611337354107, 66.60008045934862, 73.69440078735352, 54.64472363072058, 0.342112343998686, 0.9754578540882758, 4.014790529204953, 0.5473829373236626, 22.27986470345528, 79.4094196442635, 63.04865275659869, 68.43460436790221, 64.42154899720224, 65.5799190459713, 62.89661384397938, 62.20394288339923, 61.85174149851646, 59.96394395828248, 59.47172180298836, 60.5155154966539, 60.785272582884765, 58.016385186103086, 50.03156131313693, 44.565632574019894, 45.13530192836639, 45.04652692425636, 45.82255217336839, 43.34597941367857, 43.59026070564024, 45.70546157898442, 46.57487453952913, 46.60118579864503, 46.61888745523269, 49.0194760599444, 47.56423750231343, 50.465367609454745, 49.18579632236112, 50.8103165318889, 48.887060765297186, 48.51589079826109, 43.90259119772142, 43.12138449761176, 41.76954746246338, 42.9914402961731, 40.6075256870639, 40.587333325416814, 42.52870651983446, 42.68373820089525, 39.11928430680306, 42.50459963275541, 38.995564906827866, 42.75117158889771, 44.965671185524236, 43.50475695825393, 48.46271130346483, 53.68402927152572, 53.55852519312213, 56.20461886928928, 58.91041886421942, 54.23358863399875, 38.51824775818856, 39.17594686631234, 37.621621393388324, 42.59003277747862, 41.873721691869925, 43.289258018616714, 39.69001662346625, 39.79447718589537, 40.674331495838786, 39.72797339962375, 44.984835886186175, 49.00218232985466, 47.50178552442982, 48.49033655658845, 39.85458358641594, 39.93290939638692, 39.06886223823794, 40.328186250502064, 40.56799996283747, 41.48741529833886, 41.113746781503, 41.98660358305901, 39.57308292388916, 40.35391699883246, 37.9399884131647, 40.361393036380896, 40.243270858641594, 45.98082373219152, 53.86940833060972, 58.838835608574655, 53.9628666447055, 53.397849221383375, 44.511876490808305, 43.719879350354596, 42.379221070197325, 37.48698603722357, 42.40521853969943, 41.51146727223551, 41.428552289162916, 43.24253866749425, 40.45343537484446, 41.07942996486541, 41.8184123500701, 43.371533655351215, 42.79455300300352, 43.73937745248118, 43.784716129302986, 43.4515578516068, 45.662488091376524, 48.6954882837111, 51.78773979986868, 54.30214774224066, 50.837227913641165, 52.602533755763886, 51.603160904299834, 52.904756299911014, 55.33028333417831, 55.516686131877286, 56.80915809446766, 56.82201170152234, 55.1310779202369, 56.145202805919034, 54.80783539433634, 54.725897081436656, 48.07842100820234, 47.07946392797655, 45.69820911653581, 47.96890451062111, 47.68663114117038, 54.25758569471298, 60.843751199783824, 63.52877832228138, 66.56132744204614, 67.37223825147076, 66.13360866423577, 63.109673069369414, 50.40395505966679, 67.50734821442636, 13.873634126878555, 0.5783828996842908, 3.092088002351023, 2.114971169540959, 0.21640601838308, 51.89663656296269, 80.11219070803735, 69.2069661232733, 77.48979599245133, 77.61434693490305, 68.92888576753678, 54.293444002828295, 36.21481234027494, 58.624258425927934, 86.77271258446478, 29.63283592654813, 0.30377825421671717, 0.21568768837999916, 0.1528687390588945, 0.12923175499083536, 0.09999211712349808, 0.28699201141153613], [0.0749402759116023, 0.08559528723238938, 0.0391660574372978, 0.06213335808546794, 0.047311483461770325, 0.02940517223079599, 0.04903708118945361, 0.05879851223360147, 0.17904608600562621, 31.73004096554172, 65.16768970797139, 44.593618685199374, 33.417017075323294, 20.55439837517277, 37.03833356980355, 50.222212037732525, 62.63712552285964, 60.4826734912011, 60.25887481627926, 53.90549021382486, 1.3030253446871236, 0.36867181560204876, 0.4880385184960981, 0.1626809310889052, 31.384352676330078, 73.39123295199487, 57.46988919473464, 60.51301694685414, 56.432732151400664, 61.80036629399946, 59.11676299187445, 59.88000131422474, 55.73721355007541, 58.14257960165701, 55.073944676306944, 56.219076725744436, 51.406693304738695, 43.34408490888534, 40.72481239995649, 40.3548466005633, 39.294135724344564, 39.541821633615804, 37.11702808257073, 39.74695767125776, 38.52676322383266, 38.69046726534444, 38.02445665482552, 38.058981357082246, 38.332786329330936, 38.739571417531664, 40.725035975056315, 41.30925340037192, 43.153744051533366, 43.030216847696614, 41.812854351535925, 41.19213534939674, 38.63125124285298, 39.79312789055609, 38.07726352445541, 40.577401884140514, 38.37199826394358, 37.941031763630534, 37.50593108515586, 36.81317775480209, 39.182850237815614, 38.72925558397847, 38.74087756679904, 40.211444747063425, 40.87452926943379, 39.62665073333248, 38.12573617504489, 46.050088867064446, 48.647490239912464, 49.78042371811406, 50.279686527867476, 51.912388801574714, 42.89909201283609, 38.930045635469504, 37.74265396979548, 38.744439078915505, 42.27231687115085, 41.1182104387591, 39.2039918130444, 39.62000623826058, 40.25519878633561, 38.2468040527836, 40.51376142809468, 45.26965487387873, 45.69890729842648, 46.2670273165549, 36.660044500904704, 38.36592251254667, 37.72000228205035, 37.129171740624216, 41.371928953355365, 39.79131183316631, 40.18068159780195, 39.433834860401774, 41.06392483557425, 38.893253803253174, 38.63501671821841, 40.29171997501005, 39.86896299546765, 44.1473392517336, 47.727396334371264, 51.93277728173041, 50.67034282991963, 52.6778511078127, 44.94952278752481, 40.04057453524682, 38.54191533980831, 37.768133686434844, 38.423851997621604, 38.946001837330485, 37.06779841453799, 37.766227414531095, 38.198005845469815, 37.91044904339699, 38.66474043938422, 38.344121979128936, 38.861604198332756, 39.92785738360497, 38.320481854100386, 41.422672656274614, 41.68339652399863, 44.359229610812285, 46.239994341327304, 46.188791721097886, 46.902270855442175, 43.15232807590116, 43.75825582012054, 45.81959862862864, 45.09810609202231, 46.55773770424628, 46.61476504418158, 48.81818002270114, 48.224497918159734, 47.90168685297812, 46.448797795080374, 45.14970879400931, 42.83994267063756, 44.9900879398469, 41.98754102953019, 45.122828791218424, 41.428677805008434, 49.97105875322896, 59.980370844564135, 61.937186410350186, 62.06491839501166, 70.17777627514255, 62.67872225853705, 72.93804230228548, 65.15650310823995, 66.40840207376789, 9.28304014667388, 0.5354970525349341, 0.4385255817924777, 0.4131624330916713, 0.2736813256577138, 43.3065595934468, 71.38312847383561, 58.057519082100164, 76.74169801896619, 58.71452785307362, 68.08745891817155, 58.274108440645286, 25.24651408195496, 46.80594921112061, 61.33563210887294, 17.384787913291685, 0.25334611925626954, 0.11686112040713911, 0.02481420648344342, 0.007567056454718114, 0.023756438242872397, 0.03350347641014284, 0.04514359253188295, 0.024596145301456415, 0.04055601672359532, 0.00738872219845953, 0.030733608911114357, 0.07633783479010867, 0.07983268193540075, 0.06883758886326706, 0.16947082964883697, 40.677167369473366, 71.56996665462371, 49.95245887387184, 36.48268668882309, 24.446417247095418, 48.41761581359371, 52.62639353352209, 68.52687420383577, 65.38053320300195, 65.34829524255568, 58.26519289324361, 1.3492922749250167, 0.535966633789001, 0.2809048912698223, 0.12932560076155972, 32.873117693008915, 74.92142015887846, 60.07459009847334, 63.233223807427194, 60.22277724358344, 62.52118810530632, 62.5182306381964, 61.49087167555287, 58.9960559721916, 59.35627075933642, 57.16509749812465, 59.714355699477665, 52.86565419166319, 46.414406453409505, 43.661585084853634, 40.738709357477006, 41.83531776551278, 41.76271861599338, 39.38508372153006, 40.640830532197036, 41.37725160967919, 40.82952007170647, 40.60069291822372, 39.228365421295166, 40.42253886499713, 41.35065009517055, 43.485082349469586, 44.21909509166595, 44.95029941681893, 45.095854651543405, 45.873699880415394, 43.16967279680314, 41.233190797990375, 42.84147631737494, 38.753837077848374, 40.71199409423336, 39.85532099200834, 39.60169661429621, 39.720222796163256, 38.32662428579023, 41.485979710855794, 39.22809085538311, 40.335438712950676, 41.09973607524749, 42.70798237093034, 41.02265757899131, 38.68399143218994, 48.87421892535303, 52.01763383803829, 51.683691086307654, 52.11168050765992, 52.866693619758856, 44.377809878318544, 38.32438069005167, 37.78274843769689, 37.977807906366166, 41.449803690756525, 42.562870364035334, 39.965665109695934, 41.75686643969628, 41.809783135691, 38.352609988181825, 40.84117343348842, 46.16626947156845, 48.839886419234745, 45.49794858501804, 38.461181194551536, 38.74043826133975, 38.37398298325078, 38.557314565104825, 40.11489952764204, 40.56998860451483, 39.96183687640775, 39.39137128091628, 40.61100482940674, 40.51110598348802, 38.28018342295001, 39.232378005981445, 40.04857617039835, 46.20440667675388, 50.81848290658767, 55.35803410314745, 51.80735557310043, 54.302571358219275, 48.40407579175888, 41.57945371443226, 40.26922125970164, 39.19863385538901, 39.1064424668589, 39.134146167385964, 39.02855596234722, 39.62429338885892, 39.97428647933468, 40.20648294879545, 41.193543480288604, 40.91365098953247, 41.58910666742633, 40.83105371844384, 42.238627633740826, 42.2234990519862, 42.681369089311175, 47.18899611503848, 48.21231503640452, 48.791268640948886, 47.20523472755186, 46.59875785150836, 46.037176424457186, 48.267765583530554, 47.1308312877532, 47.79053472703504, 49.00796782585883, 51.57336658047092, 50.49608369027415, 50.823982069569254, 49.569164860633116, 48.58090408386723, 44.842979446534194, 46.952618398974025, 45.93919169518256, 46.19609125198857, 44.77467529235348, 52.60129428678944, 61.166938812501975, 64.52338549398607, 65.22557604697444, 68.76711153214978, 63.4865814639676, 74.94679789389335, 67.59975141094577, 70.2615894809846, 12.479515902457699, 0.4619251552128023, 0.5626566467746612, 0.7573871266457343, 0.3246377558717805, 49.18855767096243, 77.64618089122158, 63.07377553755238, 84.28627506379159, 64.87874438685756, 69.49074960524037, 52.34180988803987, 29.325320143853467, 54.26426549111643, 74.59708721406999, 22.30963941543333, 0.29829597581298123, 0.03968524288446192, 0.06558175348947126, 0.03600419423873386, 0.046136553564499465, 0.023416124749928716, 0.21405566063138748, 0.19103171544209605, 0.11278154899276073, 0.20157415780328936, 0.1032431950912841, 0.14298467265982784, 0.2016028707786914, 0.12138937419701008, 0.2521014408839326, 46.58810861649052, 81.90879314176499, 59.520421951047844, 45.94423978559433, 30.952972365963845, 53.03573208470499, 58.64143056254233, 73.64938766725602, 70.87409111761278, 70.07850108608123, 63.512304367557654, 2.0144896065035174, 0.9029287556486746, 2.0456080979877904, 0.2962124618070741, 35.981109680668006, 77.63480601772186, 64.05323451565158, 64.3887815167827, 63.42858529859974, 64.7671058870131, 63.84938893779632, 63.17054433207359, 61.64657408191312, 60.24425222027687, 60.122282197398526, 60.40922710972448, 55.541557881139944, 48.05328646013814, 45.15393318668489, 44.21110522362494, 45.24536755777175, 42.88704641403691, 42.47904931345294, 44.02571047506025, 44.89331130058535, 42.27028116103142, 43.26049920051329, 42.25679997474917, 42.555147217166045, 42.898233013768355, 44.96646742666922, 45.50393019953082, 46.17601263907648, 48.37084547165902, 48.613608806364, 46.79743374547651, 44.212489820295765, 44.910369688464755, 43.60795059511739, 44.551794452051965, 41.986470222473145, 40.62328577041626, 41.63401780589935, 39.91699241822766, 42.937488094452895, 40.96257471269177, 43.5979603182885, 44.13586631897957, 45.359104525658395, 43.26930099917997, 41.333791748169936, 49.6865378656695, 52.3153535012276, 55.87737160344278, 55.18648532129104, 55.43998026078748, 45.83631577030305, 39.28287852195002, 37.410641024189616, 37.55445080418741, 43.693046416005785, 41.620705281534505, 40.13818271698491, 40.7128530933011, 42.71913366933023, 38.527881099331765, 43.4603988739752, 48.90727273879513, 51.76489199361494, 49.328578441373764, 38.48630789787539, 40.663023302632, 39.9385929107666, 38.93200682055566, 40.38350735941241, 39.84148679241058, 40.633978151506, 40.10743133483395, 42.456758483763664, 39.27643014538673, 37.61241166822372, 40.11997899701519, 40.50746994633829, 47.073474468723425, 53.544090870888006, 57.10726607230402, 56.19048656955842, 57.25188778292749, 50.74907264401836, 43.43497407051825, 44.27542424971058, 41.52965138035436, 42.24781382468439, 42.27902020177534, 42.93535432507915, 41.11468422797419, 43.16327148868192, 40.60792969119164, 43.45982620793004, 41.58134821922549, 44.80293989181519, 43.50074829593782, 44.35620546340943, 45.99312036268173, 46.51608997775663, 48.97243115209764, 51.70979838217459, 51.494781894068566, 52.58091757374426, 48.887955065696474, 50.36850075567923, 51.092009390554125, 49.90473931835544, 51.195873752717056, 52.70975958916449, 55.32588635721515, 53.96596531714163, 52.37644441666142, 52.380111832772535, 50.69921147438788, 46.89181773893295, 48.85400302948491, 48.31145294250981, 48.844632487143244, 46.80050103895126, 55.0340384821738, 65.13682065471527, 65.85726984085576, 66.99374521932295, 73.7441207516578, 65.091266247534, 78.56197587905392, 67.14240304885372, 73.24707015868157, 17.03759147274879, 0.6531299758822687, 2.096142076676892, 1.8179639068342026, 0.4549195569369101, 52.87148675610943, 84.13382037993401, 66.54900335496473, 91.53320697046097, 69.87767573325866, 85.24778919835245, 72.8850353917768, 41.78597042637487, 65.22751762020972, 85.01117614007767, 31.0328886970397, 0.31226028778379966, 0.24830804927454841, 0.1648543378518474, 0.13660542787082736, 0.13729430945409885, 0.09981469116023473], [0.0436422708744724, 0.06822904692061486, 0.03145985068723319, 0.050224505980769475, 0.10665070055232895, 0.08297587174081034, 0.15138418323570682, 0.11083079036325218, 0.13987784904818382, 27.19925234394689, 62.89061261761574, 50.50187703101866, 31.639630333069835, 29.348191484328243, 39.03770292958906, 58.435455137683505, 66.72630233149376, 61.5359789325345, 56.1833635453255, 62.551147168682476, 6.197822420827805, 0.4622926016248042, 0.36887819968884994, 0.20830471519260638, 32.817304326641946, 69.47951593706685, 58.218916769950624, 55.67158052998205, 49.25569688120196, 56.107708869441865, 58.94852861281365, 60.051024498478064, 56.66041005042292, 56.256178425204375, 53.06918990227484, 48.92093827647548, 42.410796150084465, 42.06718475587907, 38.75135029515913, 40.121053726442405, 38.084563055346095, 37.38004261447538, 38.48786900120397, 38.31755184358166, 39.314547738721295, 38.39558739815989, 39.73795190934212, 38.9454605502467, 39.069301543697236, 37.91845067854851, 36.567923715037686, 38.787436100744436, 39.88974763501076, 38.81574384627804, 40.173911586884536, 39.99134486721408, 39.06641860162058, 38.53177601291288, 38.05708292991885, 37.86330999866609, 40.21396290871405, 37.982087212224165, 37.22339883927376, 38.32267053665654, 38.545437628223056, 38.75899499462497, 38.323427554099794, 36.88771063281644, 37.06877900708107, 38.630176513425766, 36.51885878655219, 39.41346991446711, 47.81395912170411, 49.103136293349735, 50.944230171941946, 51.069616579240375, 46.428597588692945, 39.95227021555747, 38.647293736857755, 39.25705755910566, 40.13834353416197, 40.51658161224858, 39.9170434090399, 39.46954804082071, 38.10848951339722, 36.518039011186175, 39.15675470905919, 45.16473147176927, 44.2120034463944, 44.65786318625174, 38.79743422231367, 39.938369335666785, 37.74380322425596, 38.26412523946455, 40.44393539428711, 40.50631284713745, 39.36971195282475, 39.30040367187993, 38.902483140268636, 39.10962350906865, 40.149938060391335, 37.42491452924667, 41.45400847158125, 45.37855948171308, 53.10737025353217, 51.63894468738187, 50.521845817565925, 51.6881194422322, 44.03707358144945, 40.42863815061508, 38.506535560854026, 35.55951764506679, 36.82139119794292, 37.75755113170993, 37.48409917277675, 37.495450512055434, 37.59369019539126, 38.44231459402269, 40.86126381351102, 39.24877351330173, 39.38327943125079, 39.777756121850786, 40.174696060919, 37.351542672803326, 38.35339053984612, 42.82349225013487, 42.353196144104004, 44.017516643770286, 44.5816711456545, 42.92452858340356, 42.808579398739724, 42.95968086488786, 45.90198409172797, 45.546119213104255, 46.14474742643295, 45.156329754860174, 42.25161852375154, 43.539297349991344, 44.47422958189442, 42.74761792152159, 41.049988654352006, 43.52794993308283, 42.409458621855705, 45.0823813100015, 43.21772575378419, 52.91591936542142, 63.01975273316907, 62.11265756237892, 61.05173487817088, 63.07284593582154, 59.45988016743814, 64.94121205422186, 59.04366962371334, 75.95187387158795, 17.614426997400102, 0.5279534153880612, 0.41677141201592266, 0.6876958630258038, 0.5177996247526139, 48.93987155729725, 68.67602625200826, 61.79844433261503, 72.2920593138664, 64.2869528647392, 57.50215068940194, 30.036732189116943, 31.477850214127574, 48.278426585658906, 59.65435520295174, 11.243248562658987, 0.260894950479269, 0.10892118597703596, 0.03441519381838941, 0.05303606781507692, 0.06495430449684782, 0.046840691788783, 0.08247192378246015, 0.049344688473689946, 0.09959381268990618, 0.01363614958996374, 0.027253114423083685, 0.050596334415698246, 0.07545081222610128, 0.04705520023802116, 0.19984589408962958, 31.61683155644325, 73.7458073708319, 58.19546491869035, 37.05083416354272, 29.71009877420241, 44.24358637102189, 60.15925053627261, 70.36758761252128, 66.6283215245893, 62.855962399513494, 65.75028719440584, 6.641160076664341, 0.86394811830213, 0.19264886576321819, 0.17515316425311953, 35.14320511971751, 72.05717209846743, 62.26598301241475, 57.37100232032038, 52.40088862757529, 57.99202726733301, 60.41798183994909, 61.58239626115369, 58.2319978744753, 57.15673500491727, 57.288534487447436, 49.355156421661384, 45.07975332198605, 43.59644628340199, 42.159721312984345, 42.57794011023737, 40.461464466587195, 39.53730698554747, 38.83267671831193, 41.041716375658595, 41.05502497765326, 39.939706863895545, 40.93830308606548, 40.2633612386642, 40.00275111967518, 40.97385152693718, 38.351288149433756, 42.05548824802522, 44.36911790601669, 43.13967843209544, 41.70506369683051, 41.01551886527769, 40.72008986626902, 39.856489858319684, 39.657594311621885, 41.01701328831334, 41.63406879671159, 39.605450322551114, 39.0513410106782, 40.01394948651714, 39.35511289104339, 39.87837276151104, 40.253998541062884, 38.74789860940749, 39.4003927323126, 40.09847656373055, 38.921028106443345, 40.126325391954, 50.38180151293355, 52.55207246349704, 53.11160641331827, 51.32483343924246, 46.27355806289181, 40.219642500723566, 40.16968719420895, 38.57533393367645, 41.51702919313985, 40.478416950471946, 40.06106891939717, 39.25479042914606, 38.13139615520355, 37.12257431399438, 41.203827934880415, 46.77568420287102, 48.328719216008345, 45.377649491833104, 40.4742710051998, 38.8377954113868, 38.4377646446228, 39.621116269019346, 39.6593633005696, 40.831308672505045, 39.50763817756407, 40.15890852097542, 37.86485933488415, 39.51833448102398, 39.55810731457126, 37.593917692861254, 41.72775460827736, 47.31648099037909, 55.34244660408267, 53.98160380701865, 51.28404863419072, 53.89449973260203, 45.576392066094186, 42.37023884250272, 40.61078125430692, 38.30704381389003, 39.26673796869094, 38.911508514035134, 38.675762299568426, 40.34318931641118, 39.59469126116845, 38.80022694987636, 41.64426695915961, 40.71192349157026, 41.430901788896136, 41.56974977062595, 41.359914733517556, 39.616605543321185, 40.554118694797644, 43.79533398535944, 45.00420847246724, 46.12157406345491, 46.28815712467317, 43.499453913780954, 44.91185626676006, 46.38569470374815, 47.6816418863112, 47.510638313908736, 48.64765890182988, 47.95713740010416, 44.25168606542772, 46.72227328823459, 47.441467315919944, 46.45775256618377, 43.52909526517315, 45.62742602440619, 45.1878224649737, 47.3295856291248, 45.53948256277269, 55.27682927346999, 64.93099035755282, 63.29238099436607, 64.04799815147155, 65.36816204747846, 63.08706060532601, 67.11465620225476, 62.10545216837237, 76.49993096628498, 20.019593008102913, 0.688910510751509, 0.5027005833483512, 0.6637158401070103, 0.473167801936788, 51.552170092059725, 75.63644470707064, 67.66407043703141, 77.37435279353973, 70.75683578368157, 65.41924699660271, 39.17154204460883, 35.159714375772786, 55.641480261279696, 71.9173631360454, 16.002428954647435, 0.3374142944812775, 0.09057918713698465, 0.02555621817948357, 0.11190601774761755, 0.09814385339737901, 0.043111881391415675, 0.2000741576475482, 0.13923923815450362, 0.2639071775540229, 0.12626835836037514, 0.18067091252774964, 0.30654095113277435, 0.2818460149630424, 0.3663205079013302, 0.3287688083946705, 36.39450004023891, 80.1715361687445, 66.73475896158527, 45.3226774738681, 41.45692279261928, 51.90554034325385, 66.55186668519052, 76.3977296890751, 71.64944171905518, 68.59105986933555, 72.91061709004065, 7.886583209037782, 1.0651464640132844, 0.4881661487442832, 0.41339995099171517, 38.341807780727265, 73.70219845925608, 64.87583006581953, 61.15457942408901, 53.56576588846023, 60.34678297658121, 65.79471588134766, 64.35886952184862, 61.63329293650966, 60.23252825583182, 59.669126849020685, 53.37120456080283, 46.59016001609064, 46.34411365755143, 44.202021014305856, 45.12415847470684, 42.50956535339356, 42.17055489940029, 42.390344912006015, 42.12320404668009, 44.2798839845965, 41.65572812480312, 44.50459264939831, 43.65379918006159, 41.8519760716346, 43.30912482353949, 39.84429520945395, 43.582282604709754, 48.27358638086627, 44.63563511448522, 44.25890322654478, 43.556736207777455, 44.32299083279025, 40.897937974622174, 41.77918080360659, 41.50910600539177, 44.31231414118121, 43.14511483715427, 40.90826557528588, 41.938597694520034, 41.30213822087934, 42.19772515758392, 42.78920681245866, 41.53218130911551, 42.832588226564475, 44.01221359929731, 41.834521524367794, 42.22347944013534, 52.36000576326924, 54.23700501841884, 55.03397964662122, 54.83184814453126, 48.094706689157796, 41.74235367005871, 39.720509129185835, 37.89067637535834, 42.78949314548124, 39.83556793582055, 41.16554560199861, 39.07271008337698, 40.55431089093609, 37.96161636229485, 42.55601013860395, 49.60214022667178, 49.99774263751123, 48.112894719646825, 41.05017692812028, 41.484873602467204, 38.93112428726689, 38.7354568512209, 41.5625875226913, 40.125156525642645, 38.96556661974999, 39.56846629419635, 37.32538046375398, 39.4919212402836, 40.09859423483572, 37.314284078536495, 42.526482535946755, 50.12973039380966, 57.39517588769236, 57.123355634750865, 54.51404202368952, 56.277571032124186, 48.849676655184844, 45.70413974023635, 42.81186242257395, 38.866597375562115, 42.246684182074766, 40.90451971177132, 41.419028774384536, 41.1484323009368, 41.68340829110915, 42.87577352216167, 44.54963322608702, 43.308442331129505, 43.29364715083953, 44.24071519605575, 44.57271245218093, 42.71152427119594, 43.71353295541579, 47.12406912157613, 47.10867381864979, 49.44794793282786, 50.17361387129753, 46.557066978946814, 46.4153988130631, 47.80658114340998, 51.92480702554026, 51.968992525531405, 51.78697493768508, 51.855337927418375, 46.78813380579795, 49.25873671808551, 50.40800294568462, 48.79983117503505, 45.85115409666493, 49.64092854530581, 47.278520291851414, 50.33392898498043, 48.34447145462037, 56.41847825819447, 67.86151470676546, 66.4471080226283, 66.09082345039614, 68.8643470887215, 65.8850637558968, 69.07949693741338, 66.32049391346594, 80.31855444754325, 25.023178246713456, 0.8287876856423194, 2.542662000463855, 1.8253711803305535, 0.650608566018843, 57.77580661158408, 80.60484824642059, 72.99150420773414, 85.06714836243661, 76.89641983278337, 74.2629248096097, 43.35991951727098, 47.11072914062008, 64.70454016039449, 82.88232541853382, 22.716096985724665, 0.6170048853082042, 0.24703939235018146, 0.2684558399261967, 0.37040348074609236, 0.18104163779606744, 0.17634317459117982], [0.05313365592531139, 0.06508909000624573, 0.05333191564967556, 0.008551752356241548, 0.026724940849347945, 0.015732176684504075, 0.09113696043289478, 0.018453160113084222, 0.18320537652940522, 18.14643963690727, 65.19109449078961, 47.251365723148474, 37.80648662197975, 23.313562216297274, 35.37296187493109, 57.08695996192194, 64.6692741301752, 63.85703755963234, 57.116048259119836, 63.983804641231416, 12.83699973937004, 0.6846565777255643, 0.3312708821988875, 0.32636025860424966, 23.073018943109822, 72.98372222531226, 57.955329572000814, 57.90651959757651, 44.62765701355473, 48.197774810175744, 48.96241341867755, 49.64177577726303, 48.2704367176179, 46.93852140057472, 44.44928722996866, 39.43452127518193, 39.24816554592502, 40.37509387539279, 38.25963412561725, 40.053894904352006, 39.53835425838348, 40.33958465822282, 38.18544641617806, 38.662088917147734, 39.000534549836196, 38.745666780779445, 38.023731016343646, 38.94965356396091, 38.29339788806054, 40.450285711596095, 38.98200919551235, 36.558655154320505, 36.83901440712714, 39.43340732205299, 38.40061195435063, 38.22333258967246, 38.30580826728575, 39.16774519028203, 38.864169428425456, 37.60139765277986, 41.747601801349276, 38.901859483411236, 38.85293183788177, 38.239116207245864, 38.45189302198349, 37.45404989488664, 36.072524439904, 38.34998200016637, 38.62761520570324, 38.97594913359612, 36.966416912694136, 41.48037464387956, 50.05890807797832, 49.001233116272964, 50.512467430483916, 52.05536703909598, 45.48811520299604, 38.511175724767874, 38.89705457995015, 41.329787008223995, 41.20253355272355, 38.428680435303725, 39.499514948937204, 38.59575379279352, 37.83966987363754, 37.705732699363466, 37.433571200216974, 44.696345560012325, 44.90922043400426, 45.02672287725633, 39.31890941435291, 39.69947738032187, 37.50756671351772, 39.82830370626142, 39.04091142839001, 40.86690025944864, 38.77180937797793, 39.96294690716652, 39.14470126551967, 39.299285796380815, 39.85186146151635, 39.49735372297226, 42.38900346140708, 47.67026701281148, 52.9098867600964, 50.01906856413811, 48.72606708157448, 53.62029860096594, 42.13284131019346, 38.101872474916526, 37.95226935417422, 37.688713535185784, 37.866706771235314, 37.735848657546505, 37.93523842288602, 37.937642835801654, 39.08319457884758, 37.9498492517779, 38.8642204192377, 38.90354610258533, 39.61562102840793, 40.11255787264916, 37.63970744225287, 39.070207611207046, 37.375072971467056, 41.26673490770402, 41.4744322530685, 39.83202995792512, 39.871512536079656, 39.68555296621015, 42.389011306147424, 43.07539470734135, 41.32612743685323, 42.95944160030734, 42.11230377997122, 41.581473735071, 41.0500043438327, 39.905707759241906, 41.642596029466205, 42.0930370976848, 40.9751380643537, 41.41077610754198, 40.99132568605485, 46.88864846383372, 42.78169939594884, 49.579755260098366, 58.84140868340769, 61.866783788127286, 60.9696828165362, 62.33995106912429, 54.25431443798927, 63.6192124889743, 59.60890669976512, 76.59987295827558, 18.679211255042784, 0.5013490510323356, 0.3836189570926851, 0.6665621325373651, 0.8731135329411877, 50.20952709259526, 67.0768367090533, 60.99917119549167, 70.04942063362368, 64.21797798525903, 49.20929524206346, 19.57883627183976, 39.64959267647036, 52.31698912958945, 55.00953935807752, 5.513489438641456, 0.27429882316820087, 0.16935908806420144, 0.03353064954881707, 0.019856562327233054, 0.01648938756496195, 0.01904783586430694, 0.04448892443530983, 0.039090184089277065, 0.03897118382155895, 0.047008196913426926, 0.019391324791696765, 0.05203654906982857, 0.05802449529930469, 0.042980351755695964, 0.16408664114292593, 23.461466950754968, 72.485487076544, 51.969365150697776, 37.789541982835345, 23.899046567178544, 45.34911032645933, 63.879810840852805, 70.01609617663969, 68.16934231788882, 62.29120777499292, 70.03131497290828, 14.098294742645757, 1.1471263295219791, 0.08653300949522565, 0.5262225469754589, 26.003837470085394, 73.88470634337395, 60.78125607582831, 60.5025089171625, 48.70343892805038, 49.67735559709611, 50.800341944540705, 52.946509930395315, 51.29295633685205, 51.372764802748165, 45.17161130905152, 42.85837388807728, 43.236164815964244, 43.02804777699132, 41.43785222884148, 41.01242019284157, 41.0805792193259, 42.28408005929763, 41.86908937269642, 40.29904696249193, 41.959904009296054, 40.23279028554117, 40.38580586833339, 40.55953548800561, 41.2951171782709, 42.12002692684051, 40.41286237778203, 38.73405656506939, 40.50899182596515, 41.16441203701881, 40.07588763390818, 39.60842347914173, 39.64944362640381, 40.95182349604946, 41.471537543881325, 40.40383308164535, 43.272784063892985, 40.04108444336922, 40.525308885881984, 40.83151655812418, 39.36613082885742, 39.29366111755371, 37.62608505064441, 41.20103520731772, 41.48237897503761, 41.07488393783569, 38.34785999790315, 42.77130511499221, 50.1569006519933, 52.01682190741263, 54.55867859625048, 52.75920890992688, 44.99113913505308, 37.70495607006935, 38.105943895155384, 40.75678363923104, 39.55011352416008, 40.28176499951271, 40.950454588859316, 38.35617150029829, 38.88453829673029, 37.83783812676707, 39.947461389726215, 45.49827806411251, 46.71756252165764, 46.135573002599905, 41.07545268151068, 38.96890847913681, 37.80645916538854, 38.47611365779754, 40.05838209582914, 40.787009423778905, 39.798689811460434, 39.121559281503, 38.31803037274269, 39.08920364995157, 39.067556088970555, 41.33974198372134, 41.59777510550715, 49.50776015558551, 54.72288470114432, 52.6004078311305, 51.17229638561126, 54.334660268598995, 43.829842998135476, 38.97570202427526, 40.59582917921005, 38.38792308684319, 39.89525464273269, 41.84610036111648, 39.24087385977469, 39.37852159623177, 38.91554463294245, 41.17522208921371, 40.0578486534857, 40.973027829200994, 42.58720867095455, 41.82243670186689, 40.39085395874516, 41.17066429507348, 39.960656242985884, 43.12638944195163, 44.400485100284705, 42.89373013281053, 42.83286279247653, 41.84137782742901, 45.07683900094802, 45.69209021906699, 44.72226065974082, 46.02375407372752, 44.93322926182901, 43.67271677140267, 44.569460807308076, 43.15785469547395, 43.56212554439422, 42.9156248031124, 43.700624435178696, 44.12200466279061, 43.94591377627465, 48.09034501352618, 45.357751307948945, 52.44260303435787, 60.06407030167119, 65.38215706425329, 63.60422511254588, 65.83669308693179, 56.40651110679873, 65.76548245645338, 61.29147798784318, 80.09297893893334, 21.139400274522846, 0.5288898199796677, 0.7525079432995089, 1.2218695446368188, 0.8072299714530669, 57.09545189334501, 72.79540138859903, 66.0968795899422, 76.32762908935547, 68.36743770107147, 60.76515866864113, 23.827351523983864, 44.94974244025446, 61.43918660379226, 64.91859959017846, 8.36313549549349, 0.2839659334671113, 0.17701573850166413, 0.05250370565561518, 0.047419823616022067, 0.06538617890328169, 0.0438785515425186, 0.2110956194660356, 0.17281058995473772, 0.1333161680808952, 0.20783479685985273, 0.12653836604928778, 0.1524243314540194, 0.1396834465765184, 0.1647272132216923, 0.3907606125839295, 25.63067493900176, 85.5986059865644, 62.059811469047304, 50.1844003892714, 33.828363880034416, 48.99246661893783, 67.05644038415724, 73.93592465308406, 74.66249665906354, 68.67200974495181, 75.12371247814548, 15.997726032810828, 1.7747998165507473, 0.4933356487702939, 0.5730903352941237, 28.046962830328173, 74.21690756274809, 62.90987537753198, 62.9881815756521, 52.94507434291225, 52.0401756994186, 53.14316188135455, 55.09929887710079, 52.258918439188314, 52.644950266807314, 48.72891864468975, 43.707312076322495, 45.68460633677822, 44.179486997665904, 42.72316586586737, 42.79851459687756, 44.36309314543202, 44.383277662338756, 43.99975615163004, 42.48165768961753, 45.34379551487584, 42.65133942327192, 42.884328211507494, 44.06069409462714, 44.03189213045182, 44.49452392516598, 43.31318839903801, 41.09510767844416, 42.31860868392452, 44.26570853879375, 43.97958732420399, 42.40523815155029, 43.44226575666859, 44.062804329779844, 43.89526421023954, 43.30336286175636, 46.16246085013113, 40.708456116337935, 42.51495076764015, 42.31881656954366, 41.67539488884711, 40.45924832743984, 39.850833800531205, 44.75054487105339, 43.92535271183137, 42.94013961668938, 41.907524678014944, 46.13399228742046, 54.19400407421974, 52.99458249922722, 58.21318618712887, 55.72380296645626, 47.437544945747625, 36.64051109744657, 38.29717905290666, 41.709327313207815, 40.85804746996972, 39.61483263200329, 40.068019359342514, 39.78994292597617, 39.189031893207186, 39.33933711821033, 40.94621058433287, 50.43266680932815, 50.24568742321384, 47.62508915316674, 42.029075007284845, 41.072934519860056, 39.01880102772867, 38.24518019153226, 41.069204345826186, 42.60632630317442, 40.10348935281077, 38.892677214837846, 40.74544406706288, 39.58057072854812, 41.204777148462114, 38.93585074332453, 43.14743295792611, 49.89950687654557, 58.22478463572841, 55.32834568331319, 52.552794179608746, 58.150702830283876, 46.13128977437174, 42.605479071217204, 42.69892561820246, 41.55664513188024, 42.96541144770961, 42.6490330696106, 41.15432762330578, 40.81561919181578, 43.274207884265536, 42.99688454597227, 42.22097304559524, 43.343174919005364, 44.47109560812674, 45.62589237766881, 42.708362840837054, 43.60795059511739, 43.167703766976636, 46.603437239123934, 47.21549172555247, 45.22116653380856, 45.845686312644716, 44.82835292816163, 47.75133063716274, 48.0034762813199, 47.83458294407014, 47.92697045110887, 47.23126749838553, 47.276845439787834, 47.4326184488112, 46.34869890828287, 46.663002352560724, 46.981769454094675, 46.22335172468617, 46.25953558952578, 46.84287832629296, 51.73601942677652, 48.434901698943115, 55.17714615791075, 62.470499315569484, 67.51281599844656, 68.22982526594593, 69.68828016711821, 59.027560449415645, 67.95755001806444, 64.06316203455772, 82.55570180954473, 23.68443996675553, 0.5371110465738081, 1.491062790155411, 2.2505277923999296, 0.9996078872392256, 60.925995457556944, 78.79986763000488, 73.13157204658755, 80.30651277111423, 75.09627157641997, 66.42904158561461, 30.145454406738285, 58.344907222255586, 68.17471596502489, 79.7737450753489, 14.005575795327465, 0.4695070048253383, 0.48649632221748756, 0.14581968827593714, 0.19895862637748643, 0.08246474553860965, 0.1783805547822868], [0.04829488371709182, 0.01788952624455335, 0.06075900017974838, 0.031712864630765496, 0.03820919446767338, 0.06608815292917913, 0.0757082484121765, 0.12435102414700294, 0.4025065790741675, 8.503733834912701, 63.95095479103827, 56.78569839846704, 42.84280992323353, 31.90364703055351, 36.471778577373875, 55.209360584135986, 65.87089615483438, 61.193661920485965, 55.559192857434674, 62.475378744063846, 23.385710293246856, 0.3778556776383231, 0.29051279829394433, 0.23725430451093182, 9.265788582063491, 70.27776533557524, 57.67646474222983, 61.430490709120235, 54.075297463324766, 47.31495518838206, 43.71218366007651, 45.67393356753934, 41.28711554311937, 41.75439142411755, 41.687024716408025, 42.22664087049423, 38.88221625358828, 40.62952626136042, 39.270083750447924, 39.5690821063134, 39.537146168370406, 40.21710472722208, 38.549858139407256, 36.549151251392985, 39.03845210229197, 37.34615725855674, 39.82084335819368, 38.90177711363762, 38.665211123804895, 39.29430830863215, 36.85614732003982, 38.386875814007176, 37.19222776351437, 37.183727987350956, 39.03294117219987, 40.47208624501383, 40.63840650743054, 38.612404254175004, 39.25321363633679, 38.167948722839355, 39.90679425577964, 38.755915934039706, 36.64920306974842, 39.350810050964355, 37.12925803276801, 37.132576357933786, 38.287659460498446, 37.139405204403786, 37.89694824526387, 39.08255523250949, 38.255680376483554, 44.63070469517862, 46.74623504761727, 47.99026181620937, 49.04115107751662, 50.90734028047132, 47.63051771348523, 38.83531255106772, 38.00960263898296, 39.3765486440351, 39.15995144074963, 40.889304837872906, 40.10481119155884, 38.51260738988077, 38.56140167482438, 38.5027700854886, 38.72499981234151, 43.310348603033255, 44.98100373052782, 44.84832171470889, 39.14853734354819, 38.641535697444795, 40.118080569851784, 38.34203135582709, 39.11815466419343, 40.18973835052983, 39.45643555733466, 40.42094638270717, 39.32706794431133, 40.73811707958099, 39.35731334071006, 39.01396866767637, 41.621717253038966, 51.165055690273164, 49.858855432079686, 51.32221721833753, 48.04573197518626, 49.68831469935756, 51.28768467134046, 41.39204678996917, 41.05205574343282, 38.20417965612104, 37.39246083844093, 37.680472635453754, 37.36110148891326, 38.277465220420595, 38.077949939235566, 38.238618066233975, 38.20663113747874, 39.8140537354254, 38.3558302540933, 39.6330520414537, 37.68442638458745, 39.017122253294914, 38.27449598620015, 39.227490732746745, 39.17782960399505, 40.32144761854603, 39.930901142858694, 39.36834304563461, 38.220720291137695, 40.3517008596851, 40.49928395978866, 41.844982485617365, 40.390116553152765, 41.631130941452525, 39.56877223906979, 38.925142672754106, 40.35673326061618, 41.81852217643492, 41.51164770126343, 41.07920638976559, 41.74827644901891, 41.971686809293686, 43.13306139361474, 45.63291342027726, 45.39781439688898, 53.62162436208418, 47.663179289910104, 52.14863707942348, 46.774338829901914, 63.33571141765964, 59.22628341182586, 81.86512931700676, 17.186264991760254, 0.5996696026094499, 0.21335423052791627, 0.3365942126800937, 1.1537653087608277, 54.7176444145941, 66.55666766628143, 60.53957923766106, 66.66272855574086, 63.825635064032774, 40.06137878664079, 25.368695912822602, 42.65713668638661, 50.184965210576216, 48.45962439813922, 2.6167663595368786, 0.018683122470974922, 0.044688080482545404, 0.03721884196443904, 0.0545334747631944, 0.029003962408751253, 0.07794948459993448, 0.051473003301408984, 0.03909075865522027, 0.06104639040366296, 0.10882058331081945, 0.06797929459642019, 0.031593048479408026, 0.11688686096139493, 0.12834959708514715, 0.2858655863711911, 10.279331976367581, 72.16373505130892, 62.739185594743304, 49.0013978558202, 27.301092763100904, 40.524402818372174, 61.043462599477465, 72.97992537098547, 68.66136443230414, 58.94216260602398, 67.93864419383388, 26.045020395709624, 0.5211548447128266, 0.18804126058615026, 0.27586721965382177, 10.703951101149283, 72.3935624091856, 61.66650756712883, 63.03342219321959, 57.44480955985285, 49.66807919163858, 47.71000454502721, 48.090894145350305, 44.17306215532365, 42.37811103943856, 43.923901434867616, 42.13979567250898, 42.62485165749827, 41.747217409072384, 43.34476347892515, 41.22963320824408, 42.18655424733316, 42.08524334815241, 40.99176891388432, 38.81616746225665, 41.4557578486781, 40.80174184614613, 39.78202758296844, 40.36897890029415, 40.823820867846095, 42.122474485828036, 38.527610455789876, 40.33827850895543, 39.71564146780199, 39.66286597713348, 40.71825811939855, 41.19713637136644, 41.96327724764424, 41.200089916106194, 40.06184162632112, 40.57015726643224, 40.52628555605489, 39.56047642615534, 38.56684200225338, 40.33535634317706, 39.15390314594392, 39.36047869343912, 38.27081288060835, 39.73052294023576, 40.456930206668, 41.95169448852539, 39.33392816974271, 44.599588532601636, 48.97574947726343, 50.30742160735592, 52.635265934851866, 54.637220136580936, 49.65047559430523, 39.126423020516675, 37.981322350040564, 38.062350673060266, 39.93214061183315, 39.53469860938288, 39.009363805094075, 39.96542584511542, 38.50666892143988, 39.41510946519914, 41.070169248888575, 44.879547703650694, 47.45651745027112, 46.61016410396945, 39.36883726427632, 38.73831625907652, 41.65211169950424, 38.8820436693007, 39.49267433535668, 40.55016886803412, 40.81627815000473, 40.77612484655073, 38.68217537480016, 39.33596780223232, 39.118237033967056, 40.3616048443702, 42.14553410007108, 52.25991864358225, 54.101169416981364, 53.056563792690156, 49.36043985428349, 53.299613460417724, 52.02188176493491, 42.99861431121827, 41.245852208906605, 39.285110350578066, 39.745471092962454, 39.531246923631244, 37.89371228987171, 41.18173322369976, 39.114459791491115, 40.081492700884425, 40.32739393172726, 41.86788128268334, 39.517891253194506, 42.144388767980764, 40.70793051873484, 39.31460657427388, 41.220321501455004, 42.02325028757895, 41.44476736745527, 41.91538118547009, 41.72165140028923, 41.916153892394036, 40.86633543814383, 42.707527375990345, 42.32767328139275, 43.27950308399816, 42.862437463575795, 43.360056800227014, 41.578716308839866, 42.6833067401763, 41.346900309285815, 44.43908906752064, 44.177616027093705, 42.750096859470496, 43.54973477701987, 44.789278276505016, 43.505262944006155, 48.91455658020512, 47.941440074674546, 57.181995068826986, 51.139732868440696, 55.6787702345079, 50.13238976078649, 66.28017194809453, 60.1307309827497, 83.29244844375118, 17.87994400147469, 0.7368901684399575, 0.7357647546356725, 0.803125333641806, 1.3594850441140514, 57.95686714110836, 73.41907393547797, 66.92839853225216, 73.15236845324117, 69.5820310038905, 46.49576425552369, 25.101274598029352, 52.887533172484375, 55.58974027633668, 60.360526961665, 5.046397418745103, 0.17491425207305342, 0.03206696579112642, 0.011129611408367995, 0.01568903252782841, 0.04603120498359204, 0.08699751158635463, 0.1619477696236103, 0.17196856739540256, 0.1557555115751682, 0.13783784883637584, 0.2227752120985139, 0.20514881598853296, 0.22557362403360107, 0.23684863031150835, 0.7903421453891263, 12.455947360684796, 82.7903772169544, 72.08582893494638, 58.67291935028569, 44.9648396430477, 50.44331996671615, 66.54582623512515, 80.94345077391594, 72.61257971486738, 65.48093018993255, 74.89953333331694, 31.40166209590051, 1.1652237777748418, 0.5655875153118565, 0.3478250616500455, 12.337918339237092, 73.96447166319817, 62.41794347763062, 65.13562825418288, 59.70692673037129, 51.59023277221188, 49.01696574303412, 50.871729081676854, 46.57671805351011, 44.33939810722105, 46.33131496367916, 45.51489322416244, 45.442360754935976, 44.189312534947554, 44.781880686360026, 43.956994472011445, 45.4602663747726, 45.317582315014256, 44.1535875874181, 41.086435317993164, 43.83380851437969, 41.55050662256057, 42.73711381420013, 42.77971859901182, 43.92795716562579, 44.57615237082205, 41.389905175855084, 42.259812355041504, 41.310477179865686, 40.61924965150895, 43.69576854090537, 45.02618551254273, 43.55621845491471, 43.161573102397305, 42.91163967501733, 41.8859947881391, 43.22118528427617, 41.70974700681625, 41.246526856576246, 42.73504672511932, 40.99353790283203, 41.317176588120006, 42.54458819666217, 41.21153539226901, 42.45696244701263, 42.78377432977, 42.607334352308705, 48.715147203014745, 50.56057530064737, 50.886312453977524, 55.11062275978827, 55.770400724103375, 50.24751524771414, 39.51168214121173, 38.73617072259226, 38.409162721326275, 39.78735023929227, 40.036514882118475, 39.1887181035934, 39.395411322193766, 40.36494278138684, 39.820792367381436, 41.97104354058543, 48.01658092006561, 49.86711986603276, 47.95580379424557, 41.872278259646514, 38.616558044187485, 42.998194617609826, 39.14911000959335, 40.82098107184134, 40.756520840429495, 40.96096261855095, 41.49014134560862, 38.60083718453684, 41.69621482972176, 40.829602441480084, 40.775116797416445, 44.3836110638034, 55.24848230423466, 56.24255603359592, 57.315512549492624, 51.84443373833933, 54.75919408182944, 55.216012923948234, 46.18046845159223, 43.23076763460713, 40.3860451329139, 41.96536787094609, 40.449038397881296, 39.57961759259624, 43.98005408625449, 42.318032095509196, 42.07790067118984, 41.98936100929014, 43.155775839282626, 42.7596321413594, 45.10107532624276, 44.071006005810155, 44.22475114945443, 43.692367845965975, 44.56688773247504, 43.628743079400834, 44.834405145337506, 42.84285306930543, 43.738416471788966, 43.708661371661776, 45.021796380319905, 46.10181708489695, 46.7272586207236, 45.20154683820663, 46.14271563868369, 45.416531947351274, 46.12397455400037, 43.555539884874904, 47.13421629321191, 47.50072256211312, 45.59756109791417, 45.87892055511475, 46.84644768314977, 46.695248157747336, 51.53737883413992, 51.10201927923387, 59.44725013548329, 53.34059046160791, 57.653279612141276, 52.33026635262274, 69.23080628918063, 64.89003689058366, 86.37445865138885, 20.982126958908577, 0.933471761884228, 2.8692887963787204, 1.6768916960685485, 1.6007311570067562, 64.20762292800411, 81.26813673203992, 72.54107490662606, 80.84132794410952, 75.18853356761318, 55.66296308271347, 38.32427478605701, 61.120568552324855, 64.39743818775301, 75.34199237823486, 7.85222863958728, 0.4052800318646816, 0.09711292121679553, 0.15643303973540185, 0.12412495160054778, 0.2054293573864045, 0.1490227938179047], [0.07120106970110247, 0.009727403333771133, 0.024942600904333017, 0.05845926551809234, 0.056018513221774376, 0.023144563817749583, 0.026940269012665077, 0.06753281089327029, 0.09263149072085658, 3.3747214944131914, 49.628569156892844, 51.917593786793375, 37.39824241207492, 27.890530863115867, 33.31738495057629, 55.83208783980339, 62.506475294789965, 60.50731774299376, 55.43322201698057, 63.51703866835564, 35.038254261016846, 0.045701243253725196, 0.19529553100226388, 0.029222919913609664, 0.42967432448940895, 46.351542626657796, 67.66796142824235, 55.73734691066127, 60.59081323685185, 49.95461617746661, 47.79464537097562, 45.56679402628253, 42.871792316436775, 41.66656563358922, 40.562426274822606, 41.434153433768984, 42.91404016556279, 42.147028523106734, 40.07975509089809, 39.3208666770689, 38.31111915649907, 38.7134680440349, 38.491673700271114, 37.30236007321266, 37.60046805104902, 39.0366203554215, 39.456870940423784, 38.022683743507635, 39.03520437978929, 38.264003645989206, 41.141944700671786, 41.22794658906999, 38.49756902264011, 38.13476547118157, 39.49540038262644, 38.32460818752166, 36.866137596868704, 36.51508938881659, 38.438474593623994, 40.614966423280784, 39.22179545125654, 38.81639888209682, 38.00286008465675, 38.41020214942194, 37.360011070005356, 37.76989090827204, 39.4555373345652, 38.44714695407499, 39.437576801546165, 38.029206645104196, 37.08305643450829, 41.912423718360166, 45.38788687798285, 47.548198930678836, 50.68470262712049, 50.75831767051451, 48.34888019869405, 42.109248253606985, 40.8550900028598, 40.27594420217699, 40.53496576124623, 39.779627092422984, 40.09717825920352, 38.56394337069604, 38.20864331337714, 37.125500402142926, 37.8482480972044, 45.37166395495015, 49.23464552048714, 41.890674175754675, 38.50614332383679, 38.15898610699562, 39.67101273998138, 39.62317159098964, 39.19134216923868, 40.34151054197743, 40.7162537882405, 37.90449880784558, 39.62781567727366, 39.87551727602559, 39.66771402666646, 42.19691714932842, 45.9023057260821, 48.858980517233576, 50.681070512340916, 47.45967888063001, 45.72328482904742, 46.831511297533595, 45.9420903267399, 44.380437866334, 41.6883740117473, 39.328397627799745, 40.0504667528214, 39.919385064032774, 38.20379134147398, 37.979004229268725, 38.19205168754824, 37.48085145027407, 39.30762083299699, 38.942993379408314, 38.06480999915831, 39.67950074903427, 36.97682688313146, 37.03736866674116, 37.766243104011785, 38.03302311128186, 38.384683209080855, 37.7510674538151, 37.9273073903976, 39.326648250702895, 39.03122709643456, 40.2883820379934, 40.62007727161531, 39.5997001278785, 38.959318284065496, 38.20800004466888, 39.24422356390184, 39.643403176338445, 41.01287518778155, 41.23548930691135, 39.232593736340924, 40.73802686506703, 40.78942168143488, 42.82409629514141, 41.994275739116055, 42.338965785118845, 41.47582077210949, 43.92052427414925, 45.57722753094089, 48.574749885066865, 48.05301189422608, 63.95765812166276, 59.96970592006561, 77.45789143346971, 8.994074233116644, 0.42086841959145765, 0.07401987489673399, 0.7814839013641881, 2.012317348872462, 53.677106288171586, 64.23070999883836, 60.32683380188481, 66.19878276701897, 58.2644711771319, 45.30655653245988, 25.356330640854377, 25.90066932862805, 54.918995365019775, 39.9355334620322, 1.0100643132482807, 0.024511532805439447, 0.025624708355134054, 0.02063431777060032, 0.021210017523938612, 0.010895060183810852, 0.0854899654645593, 0.07468821000187628, 0.052330144605929815, 0.012917223953521781, 0.07103950941875097, 0.05705402660814505, 0.05259453303991787, 0.045599230985728004, 0.15312335604140836, 0.1330351823520276, 4.8874845523988055, 59.84028339385987, 58.33530526007376, 44.63589006854642, 32.26245368680647, 41.64808342533727, 62.84817649472145, 69.90823884164134, 65.88957448159495, 58.06765448662543, 69.01533480613463, 37.9628558312693, 0.10641512085473347, 0.08068185975594867, 0.3256886139992745, 0.5993540356716802, 50.66810315655124, 68.30161248483967, 59.68071745287988, 62.47962274859029, 50.91593419351886, 48.98743814037692, 46.3413836879115, 46.06336216772757, 43.595222503908225, 42.47018867923368, 43.00932630415886, 45.31121238585442, 43.30373156455256, 41.899789764035134, 41.84844986084969, 41.359522496500325, 40.629922420747825, 39.596766194989605, 39.575942331744784, 39.6225675459831, 39.814704848874, 41.39076025255265, 39.93351344139346, 40.953557183665616, 40.11425625893378, 41.211707976556596, 42.41673854089553, 41.950757042054214, 40.09800587930987, 41.08613721786007, 40.103136339495265, 38.95394071455925, 39.24435300211753, 40.675492517409786, 40.74775434309437, 40.43435304395614, 40.07711925814229, 39.759054260869185, 40.033094575328214, 39.688314314811464, 40.199677636546475, 41.11250339015838, 40.32280475862565, 40.44613192158361, 40.68576912726126, 38.38041959270355, 44.6930625361781, 47.251757960165705, 48.11638170673002, 51.259702482531154, 53.978764011013894, 50.37012461693057, 42.36454748338269, 40.11999468649588, 40.63989308572585, 40.98722680922478, 39.30083905496905, 38.65681725163614, 37.974246394249704, 39.17140868402297, 39.1643484177128, 39.368048867871686, 47.99783983538228, 50.687005058411636, 43.6827580390438, 39.5549851079141, 38.02209931035196, 38.820776247209125, 40.54252416856828, 38.934470069023874, 40.70427879210442, 40.48703439774052, 39.974345314887266, 39.584532322422156, 39.08113533450712, 40.227381337073545, 40.23501426942887, 45.30873344790551, 51.591142762091856, 52.98924023105253, 50.34607264303392, 48.38264396113735, 48.35386945355324, 47.36523997399115, 45.481458940813624, 44.60027494738179, 42.35840505169284, 40.64967155456543, 41.78314239748063, 41.50379903854863, 40.39658061919674, 39.3833343444332, 39.68017539670391, 41.293399180135424, 40.958534671414284, 39.156531133959376, 39.9879559393852, 39.875862444600756, 38.95811803879277, 40.97635399910712, 39.66708644743889, 40.090000321788175, 41.649675907627234, 40.95164306702153, 41.793211121712964, 41.257956643258375, 41.592915288863644, 42.725605580114554, 41.8550786664409, 41.692304226659964, 40.67494730795584, 40.6261137993105, 42.921280860900886, 42.717172484244074, 43.74755951666063, 43.24238177268736, 42.900233422556234, 43.13409297697006, 45.8225090272965, 44.22681039379489, 45.53060623907274, 44.306014814684474, 46.02382075402045, 47.76014028056976, 50.51169864593014, 48.85168883108324, 67.33755665440714, 60.777196422699966, 79.72327201597153, 10.30451653465148, 0.624546499982957, 0.40965123763007505, 1.043685460763593, 2.560478876675329, 60.817687049988784, 70.98221517378285, 68.14739273440453, 73.84238396921467, 63.34226177584741, 50.30560554996614, 28.766586357547393, 31.089292380117605, 60.844767093658454, 51.358914913669715, 1.5099556215347782, 0.026246285283817884, 0.048349988421485315, 0.021620703853606697, 0.06392942824130578, 0.08950127078400505, 0.039995757472370906, 0.1407483700783022, 0.10758287633859343, 0.13701355355160852, 0.20533272305563574, 0.17232282177334832, 0.06609789756757599, 0.09415734634404221, 0.2577242044912231, 0.3423379415706281, 5.090218628606489, 69.7559332078503, 65.98318576812744, 53.68371155954177, 40.533687068570046, 44.85381303295013, 68.10060670298915, 73.81861440597042, 72.28454405261625, 64.10222099673364, 75.29699494761806, 42.3376400240006, 0.24069848260091198, 0.8390451739391974, 0.28273817031614246, 1.1537535416503106, 53.163354243001635, 70.82837197088426, 60.158701404448486, 64.8958106194773, 54.611108918343824, 51.11182520466467, 49.42344096399123, 47.04627675394858, 46.07654133150655, 44.51514774753202, 47.04235830614644, 47.90047876296505, 46.69494613524407, 44.54875461516842, 45.27004318852579, 43.984286323670425, 43.93682956695557, 43.320817409023164, 40.498373969908684, 42.41360848949802, 43.233991822888775, 44.09652494615124, 41.062846183776855, 43.45612349048738, 42.09322929382324, 44.61811780929566, 45.39311931979272, 43.258185002111624, 42.82650070805704, 43.413899175582394, 42.4783315197114, 41.86074256896973, 40.441907528908025, 42.57168392981253, 42.201977006850704, 43.52051704160629, 40.75335941007061, 42.41447141093593, 42.11672429115542, 42.53603350731635, 40.635700072011645, 44.292290441451534, 41.40337067265665, 42.855051640541326, 42.28682179604807, 41.46011167956937, 46.9544069997726, 50.541900896256976, 51.36741076746295, 55.90823673432874, 57.14527776164394, 52.03144450341502, 43.509436345869496, 41.2368425246208, 40.662509472139426, 40.74318478184362, 41.03557394396874, 39.678845713215495, 38.70228144430345, 39.47832630526635, 40.30597779058641, 41.64816971748106, 49.99874284190517, 53.82345384167087, 44.057807230180316, 40.71674800688221, 39.59152983080956, 39.42421328636908, 41.78726480853173, 40.71408079516503, 40.18359199646981, 40.37837689922702, 40.09165163963072, 39.70753785102598, 39.24053653593987, 41.45746800207323, 41.76614284515381, 46.61191740343648, 53.28202947493523, 54.83295033054968, 50.966466088448804, 51.1854677046499, 51.85301588427637, 50.02367342672041, 48.724643261201926, 46.63041922353929, 44.00972289423789, 43.78802660972842, 44.63673337813347, 42.70478956161007, 42.90477944958595, 42.260361486865634, 41.425469306207475, 44.12237728795698, 42.91081205491097, 42.716901840702185, 43.58558131802467, 42.511597141142815, 42.374212203487275, 44.92210542002032, 42.504050500931285, 43.890318101452245, 43.73010496939383, 43.93178539891397, 45.08363646845664, 44.46126222610474, 43.669567108154304, 46.52462897762176, 44.61623114924277, 44.193003485279704, 43.804347592015425, 42.87300040644985, 46.00283999596873, 45.985711005426225, 47.10812860919584, 44.978454189915816, 44.83723709660192, 46.37876387565367, 48.5336002995891, 46.0496142602736, 47.38889578850039, 46.476423048204, 49.28570301302018, 51.02007704396402, 54.22019766223047, 50.804154488348196, 69.6527748723184, 64.46022748947144, 82.63930320739746, 11.062806787029391, 0.6108354260363887, 4.92440386164573, 1.8516455446520161, 2.903909596704668, 65.52542555716731, 77.27871756399833, 72.63604333323818, 79.6672841041319, 68.09720993041992, 61.28263304310461, 37.64901522667178, 41.275603386663626, 70.28419802265783, 65.67464820800289, 3.059216824270064, 0.20865032809876627, 0.15349562880733322, 0.12523794711958017, 0.16464950126265326, 0.16538986395443642, 0.1477943258660455], [0.036838314601130066, 0.0716710033556146, 0.05998692144790004, 0.06675465708418239, 0.03478589610406949, 0.046836823044765385, 0.04288171793544485, 0.03571948915299389, 0.10304479364065394, 1.08630703822259, 41.42154301366499, 62.04340027224634, 35.16425255806216, 24.250820413712535, 32.99054168885754, 54.96764059989683, 62.06584015200215, 57.67993996220251, 59.60691413571758, 58.88136194598291, 46.669721372665904, 0.4161306254325375, 0.11879859507204064, 0.13271109651653998, 0.14776815630255208, 10.429080224806263, 66.86601715703165, 56.35454754675589, 62.63981626879785, 52.9382807977738, 46.24900010324294, 43.39690746799592, 42.94774901482367, 41.837494680958415, 46.30265420483005, 45.132348383626635, 48.60102192048104, 43.496402309786895, 40.47652244567871, 39.956784863625806, 39.39290885002383, 38.726431477454405, 38.40973930974161, 37.68242989816974, 38.56759117495629, 37.08755539309594, 38.810279984628, 37.83853238628757, 39.42571555414508, 37.6431316714133, 39.17252263715191, 36.97921168419623, 38.287682994719475, 36.808714097545995, 37.16959176524993, 38.5021464286312, 36.61052849984939, 37.237425235009965, 38.59398872621598, 39.81787804634341, 40.20904425651797, 38.47478005193895, 38.05500407372752, 38.370170439443285, 38.473273861792784, 39.340180427797385, 38.865561869836625, 38.098236437766786, 40.1802069910111, 38.511313007723906, 37.74352473597373, 39.78609508083713, 44.64316998758624, 48.014698182382894, 49.61933589750721, 52.268418419745664, 52.354114363270426, 39.646686200172674, 39.07353378111316, 40.02776799663421, 39.12174755527128, 39.72682022279309, 40.25343371975807, 38.65118865043887, 37.614455223083496, 37.2020846797574, 38.397897674191384, 46.421113706404164, 45.0381055954964, 43.81711098455614, 38.74972643390779, 37.16023691238896, 37.85707343009211, 40.106948883302756, 40.93911501669115, 39.41397982258951, 40.03836231846964, 40.18691816637593, 38.539024552991314, 39.782733609599454, 40.89748297968219, 44.68725742832307, 50.46117459574054, 51.899892130205714, 49.559237341726984, 48.3581958278533, 44.18020871377761, 44.671297304091915, 42.69867066414126, 41.19550858774493, 38.20556817516204, 39.196825642739576, 39.16642727390413, 37.57829489246492, 37.31635901235765, 38.99429405889204, 38.17619746731174, 37.70072775502359, 38.35619111214915, 37.64092729937646, 39.62469739298667, 38.87219852016818, 38.96405258486348, 38.82040754441292, 38.25264446197018, 38.65333026455295, 36.524765876031694, 37.95870988599716, 37.89823870505057, 39.66161866341868, 38.28372532321561, 39.333888946040986, 41.0556290226598, 38.58719518107753, 39.59209072974421, 40.8365568037956, 40.31462661681637, 39.93785942754438, 39.18754923728205, 39.9525212472485, 40.414466627182506, 39.28587521276167, 42.34658302799348, 43.02175629523493, 43.906199778279955, 46.836877099929325, 46.69131009809433, 43.743770507074174, 44.47646533289264, 46.73312648650139, 49.0476151435606, 62.5598430633545, 61.16125922049246, 74.11067408900108, 6.874300366447819, 0.4540235405006717, 0.20367451042177218, 0.559255155103822, 2.54402183717297, 58.11856685146209, 62.00738506932413, 66.73834400792276, 63.26972930662094, 58.81087303161622, 38.17927652789701, 20.152255412070982, 38.33986620749197, 57.31212754403391, 44.091563147883264, 1.0541237458106012, 0.13236759801305112, 0.026445341739623297, 0.03008646571317748, 0.06186673267474098, 0.05214523396364624, 0.041525926170570236, 0.03268364741797409, 0.027136628838977026, 0.008386209374293685, 0.029360756368166017, 0.07630308504186331, 0.07021395774978785, 0.06717608971220833, 0.03432152807832726, 0.0416062236763537, 1.5375460636231209, 48.97578477859498, 66.61388720235517, 43.04434130268712, 26.345124859963697, 34.43526437205654, 60.31785549656038, 67.39231294201267, 63.0855034243676, 61.326187041498, 63.287046570931714, 50.223726072619044, 0.4993908383673238, 0.2477131053925522, 0.3397338554984139, 0.1862019294452283, 14.52418569595583, 69.61270393863802, 57.042523430239775, 64.59210149703488, 54.448334478562884, 49.10949445539906, 44.930801314692346, 45.15387042876213, 44.217694805514434, 47.46051826784688, 47.706843114668324, 50.896863629741055, 45.94321996934953, 42.87886434985746, 42.817651840948294, 42.18929598408361, 41.63193894970802, 40.3659822094825, 39.115440384034194, 40.84066352536602, 39.87161844007431, 40.96458688859017, 40.615892102641446, 42.86002128354965, 39.48953251684866, 41.489702040149325, 40.66888724603961, 39.430979374916326, 38.24284638127973, 39.45171694601736, 39.601222007505356, 39.599829566094186, 41.1197833091982, 41.25125723500406, 40.96246488632695, 42.54501181264078, 40.919307047320956, 38.81825024081815, 40.066360196759625, 41.712374994831706, 41.237987856711115, 41.4996374037958, 39.938102614495065, 41.94641105590328, 41.380099250424294, 39.41126946480044, 42.11458659941151, 46.07238361912389, 49.8443034387404, 51.70709194675569, 54.93545363026281, 52.05951298436811, 40.945943863161155, 37.868522828625096, 40.57601336509951, 39.767310850081905, 40.203972631885165, 39.179249501997425, 39.51260389820222, 39.282058746584006, 38.78269003283593, 41.335097897437315, 46.7175115308454, 45.881485785207445, 46.1615587049915, 38.9407850850013, 37.56232300112325, 38.561127108912316, 40.053435987041844, 41.05535053437756, 39.518463919239665, 39.95553362754084, 39.28523194405341, 39.432536555874734, 40.77496382497972, 40.88607280485092, 46.79470377583658, 50.34646880242133, 53.075442160329516, 53.06218454914709, 51.33810673990558, 46.526421500790505, 45.79879437723468, 43.32374741954189, 43.33599305921986, 40.1596067028661, 41.08417603277391, 40.73164124642649, 39.68196007513231, 39.118739097349106, 41.20341608601232, 40.2413998880694, 38.98712004384687, 39.440287159335234, 41.28486410264046, 39.99213718598889, 41.44354358796151, 39.35119052087107, 39.97372558040004, 42.263766104175204, 40.292598585928644, 40.45526712171493, 39.974294324075025, 40.090423937766786, 40.98573238618913, 39.73216641333796, 41.74565630574381, 42.431384671118956, 40.8949452061807, 41.60183083626532, 42.1794076888792, 42.2321282663653, 41.99876685296336, 41.85435302795903, 41.56336807435559, 42.186766055322465, 43.27784392141527, 44.352494901226414, 45.2175893322114, 45.64039338019587, 49.13696281371578, 48.29153906914496, 46.867808911108206, 45.38399588677191, 49.38462126639582, 53.60704491215368, 65.43271641577444, 62.3777784070661, 77.5466154467675, 7.6296865940094, 0.7754194880685499, 0.8703271179429947, 0.8502220290322459, 2.802657533076502, 62.160694829879276, 68.7179877681117, 70.43218120451897, 71.68825749428042, 65.63713073730469, 47.418003697549146, 23.90698544440731, 43.68894361680554, 63.042851571113836, 54.98882532119752, 1.4599435632267308, 0.13945648536807106, 0.01262132440798826, 0.06727177409395095, 0.014257151952704356, 0.03968877838023248, 0.051413547217605576, 0.08934526463910457, 0.1606559615221716, 0.22039857753101857, 0.19075583185880415, 0.19619271189214724, 0.24949335583275367, 0.21876224436827246, 0.1885069960788373, 0.3372452648416642, 1.9993316069726024, 58.07988443682271, 77.64577296472366, 50.11202089248165, 34.34703065503028, 46.49635261104953, 68.4724473953247, 73.40009750858431, 70.21512508392334, 65.61709919283467, 69.30928507158833, 55.42887210845948, 0.7739365869952787, 0.6750071180924293, 0.6722444824634061, 0.26663086527297575, 18.06961609471229, 71.85522494777557, 60.28162064090852, 67.26442798491448, 56.592721708359264, 52.23443500457272, 47.72075183929936, 48.032376304749526, 46.40598120227937, 50.87325096130372, 48.6824817042197, 53.03438278936571, 48.10346926412275, 44.18813974626603, 44.538815329151774, 46.13620450419765, 43.9607128789348, 44.5936147628292, 41.72709565008841, 44.975496722805886, 42.04175603005194, 42.93893937141665, 42.289273277405776, 44.12915122124457, 43.56713833347444, 42.93025916622531, 43.42928663376839, 43.84570506311233, 40.90204077382242, 42.78677102058165, 44.32301044464112, 42.25254420311221, 41.944806806502804, 43.64990426648048, 43.24856735044911, 45.79127911598452, 42.23309316942769, 40.59316981223322, 41.79630194940875, 42.079520610071, 42.485474155795195, 42.53312310864849, 41.49448733175955, 45.02014898484753, 44.82710561444683, 42.41387521066974, 43.96720440156999, 49.62407804304554, 52.03434313497236, 56.23818259085379, 56.96855145116007, 55.472861489942, 41.399299252417784, 39.75865810148178, 40.349755364079634, 38.45230094848141, 41.32412702806535, 40.079484447356194, 40.597959026213616, 39.55155695638349, 41.04298722359442, 42.39593036713139, 49.96070369597405, 49.33773325335596, 47.153651637415734, 40.89264277488955, 38.92053781017181, 39.3297783021004, 40.765899227511504, 42.771618904605994, 38.772605619122906, 39.043221704421505, 40.22015633121614, 39.45367028636318, 40.4422370080025, 40.35476030841951, 49.80181632503387, 57.68544696992444, 56.40594628549392, 57.059107211328325, 53.21718877361667, 47.17134544926305, 47.61704044957315, 46.10067959754698, 46.1150864631899, 42.63150399731052, 43.886482023423724, 42.809018704199026, 39.79801908616097, 40.810002357729026, 43.82725031145158, 41.56939283494027, 39.65833563958445, 42.32327238205941, 41.75482680720668, 42.42895280161212, 43.869655055384484, 42.63319061648461, 43.47741019341254, 43.95511957906908, 42.56012078254454, 42.67819589184177, 42.365920312943004, 42.61133516988447, 43.5677384561108, 42.624141708497085, 44.33921375582295, 45.465734158792806, 45.326674369073686, 43.8720908472615, 46.73277347318588, 45.23989585138137, 44.49043681544643, 43.87370686377249, 44.54846435977567, 45.6345804276005, 44.56993149172875, 46.114658924841116, 46.554034986803615, 47.587779568087676, 51.44754871245354, 50.51864908587549, 49.700862361538796, 49.756167780968454, 52.1728616376077, 55.07651775113998, 67.4519721923336, 65.87202579744401, 81.1294024990451, 9.084819247645717, 0.8706464233898348, 2.4441055857366134, 1.6182134060129043, 3.61105949647965, 68.50164551888743, 74.12360222108903, 77.11563325697377, 75.05377661797309, 70.85684053359493, 54.507938815701394, 32.843915647076024, 54.77432658595424, 70.46248543647029, 69.02270886205858, 2.854949591621276, 0.4031198171357955, 0.21678118696135862, 0.20413860648630128, 0.17311247456217968, 0.17324540613880082, 0.16633840337876352], [0.02279971125385454, 0.012755669416829705, 0.043236592844609296, 0.015394363511023263, 0.023446546101401892, 0.020567794525695425, 0.06046330556273461, 0.045492242976662614, 0.0407400501952056, 0.17316158079812605, 35.47402958716116, 58.973259156750096, 42.16345540938839, 35.26057812475389, 30.40172246194655, 48.488693083486254, 63.175208030208466, 55.60778317912933, 64.2729696150749, 54.14008325146091, 59.98911380767823, 3.1602021667265126, 0.28441651574065613, 0.5057885611970578, 0.050976750696258205, 0.8971913086791193, 41.14748308735509, 64.24297917273738, 55.8179751519234, 54.508060409176736, 44.81054536757931, 41.86834804473385, 44.23096810617755, 51.02205784090104, 50.4408763300988, 53.46510610272808, 48.4997659344827, 45.03845860881191, 42.859491763576386, 39.834093124635764, 38.62218272301459, 40.35723924636841, 37.589195159173784, 39.92256218387235, 37.7666941765816, 38.94177352228473, 39.547524759846354, 40.14351321804909, 38.97116776435606, 39.5329531546562, 38.26754946862498, 38.03240729916481, 36.80445832590903, 38.39303393517771, 35.975779179603826, 39.0929534358363, 37.4007958750571, 36.76301456266834, 37.93975699332453, 38.583292422756074, 39.13233403236636, 38.186203433621316, 39.05687155262117, 39.05050162346133, 38.44365212225145, 35.93145639665666, 36.30874526116156, 38.044256779455374, 40.39065784023654, 38.39701514090262, 36.65742827999976, 36.67376102939729, 46.50625267336446, 50.842381908047585, 49.55467954758675, 51.29140700063398, 45.836880591607866, 44.303484885923325, 40.376282353555005, 41.01358905915291, 40.37590188364829, 38.62276715617026, 38.26001459552396, 40.1473649855583, 38.096816539764404, 38.38378498631139, 37.615753527610536, 44.295706825871626, 46.346674965273955, 43.65448951721192, 37.49972197317308, 37.63173326369255, 39.656382299238636, 40.22600458514306, 38.627360251642045, 39.432995473184896, 39.44603735400785, 41.058939503085234, 39.55904868341262, 39.39860413151403, 40.189373570103804, 45.69542423371346, 41.308818017282796, 52.19087708380915, 51.0476944523473, 48.63849624510735, 48.515949633813676, 42.3638375343815, 38.27361737528155, 39.69725339643417, 39.0031115470394, 38.394885293899044, 37.900937295729115, 37.8809057512591, 36.472370855269894, 38.63760548253214, 37.349063734854425, 37.250510261904815, 38.995207971142186, 40.07964918690343, 38.05754969196935, 39.898239566433816, 37.55362318408105, 37.331111046575735, 37.25118490957445, 39.03805594290457, 37.28750997974027, 37.17920549454228, 38.19705663188812, 36.55928665591825, 38.363984861681544, 39.218045665371804, 39.76748343436949, 39.882565775225245, 38.32054853439331, 39.841671143808675, 38.203712894070534, 40.124709375443004, 39.988842395044145, 39.11186318243704, 39.289017031269694, 42.165212631225586, 44.70813620475031, 47.90435014232513, 50.67359055242231, 59.227326762291696, 57.50654766636511, 55.07287779162007, 44.0050317395118, 45.605809842386556, 47.89976489159369, 63.793220596928755, 61.18476206256498, 69.7257701812252, 6.172780538758924, 0.7810369963126799, 0.7899017980502498, 0.8039389803044258, 6.174299966904425, 62.897355171941946, 57.13985312369562, 68.1752964758104, 60.24787649031609, 56.35319040667627, 43.01364091134841, 32.93265142748433, 33.01400922959851, 57.02444914848574, 30.052749187715595, 0.32760456925438297, 0.003728203512089808, 0.04792735686585788, 0.017354138037790696, 0.03372343174452263, 0.03942560802604403, 0.038287048152978384, 0.07738481651270583, 0.018875768686073924, 0.003604472890841745, 0.06165140451142385, 0.04172165397434466, 0.007593085249555448, 0.047445705896543885, 0.042448108339862484, 0.01256164807390662, 0.32233556972876676, 44.046044042033536, 67.3826325324274, 47.69846493198026, 34.990738668749415, 39.880247654453406, 57.48040506916662, 67.56008840376332, 61.92029276201802, 68.80785711349981, 60.67247698383947, 64.00326351965627, 2.8415792122963937, 0.31359407750348894, 0.42185943093030687, 0.0865626034717406, 1.1711427569389343, 46.68374776840211, 66.80242769179806, 59.95553439663303, 58.68216829915201, 47.01878093904065, 44.94363138752599, 45.90536125244633, 52.630704218341464, 51.35273325827814, 55.001196476721, 50.57312688519878, 47.57033286556121, 44.817358524568625, 42.56555718760337, 41.7415338946927, 41.224098743930945, 40.41379982425321, 41.05876691879765, 40.57822950424687, 40.88815166104225, 41.461390372245546, 42.00012007067281, 40.208216636411606, 41.864002058582926, 40.22654587222684, 40.93099571043446, 39.01401181374827, 37.883035598262666, 38.58254325005316, 40.3866687897713, 39.61320877075195, 39.253805914232814, 39.49079944241432, 41.55278159726051, 40.56122602954988, 41.45076074907857, 40.025190999431, 40.906347536271625, 40.291849413225734, 38.92652334705476, 38.66010419784054, 39.8809144573827, 41.86146036271126, 38.33149586954425, 37.62868558206866, 39.589545111502375, 48.675637168269006, 52.85982162721696, 51.978853364144605, 53.470636644671046, 48.76024269288587, 43.41343241353189, 39.974400228069676, 41.24900187215498, 39.79768176232615, 37.68548934690414, 39.87564279187111, 41.33268171741117, 38.89017866503808, 38.759630418592884, 37.4790628494755, 46.503099087745916, 49.470650611385224, 44.03241772805491, 37.580867967297955, 38.514619565779164, 38.69734318025651, 40.63729647667178, 39.56333191164079, 39.055020193899836, 39.10514808470203, 41.8275357830909, 39.35145331967262, 39.74028964196482, 40.01720113138999, 47.25633144378663, 46.20162179393154, 54.22666957301479, 52.77753814574211, 52.28440207819785, 49.905476723947835, 43.82558722649851, 39.517785349199855, 42.136332219646825, 39.650749775671194, 40.92416686396445, 37.299449674544796, 40.13835922364266, 38.6851171524294, 40.13878676199144, 40.078484242962254, 39.594965827080514, 40.320780815616736, 42.059579280114946, 41.216269693067, 41.69421834330405, 41.2118060358109, 38.91377564399473, 38.842600314847886, 39.21269947482694, 39.4266765348373, 40.5831128551114, 41.28274994511759, 40.39148153797273, 41.63563774478051, 39.851367242874645, 41.281188841789, 41.359200862146196, 43.27954623007005, 42.133210012989665, 41.353709543904955, 42.842700096868704, 41.94770151568998, 42.36967009882773, 43.09039777325046, 44.66331920316143, 47.02158151134368, 50.32790030202558, 53.991990243234945, 61.68790017404864, 61.420563190214104, 56.977996518535, 46.239080429077156, 47.92349130876603, 51.639387915211344, 66.24937349750151, 63.661272064332046, 71.51536726182508, 6.8852614298943555, 0.8285215160539074, 0.632965132113426, 0.664331652224064, 6.268220630384261, 69.1279068300801, 64.34680431119858, 72.6550825180546, 65.34974259714927, 63.2219313037011, 53.27966820809149, 30.333963517219793, 41.52339912229969, 66.6129066098121, 39.62839618805916, 0.2984470789951663, 0.023285447387024764, 0.0660995293348547, 0.05468538233769998, 0.04158049461341674, 0.04705672092255085, 0.06295195750651822, 0.11853287747550396, 0.14258423850180643, 0.12929584590658066, 0.09514904716202328, 0.1437218943911214, 0.10574352987591298, 0.22218336321173177, 0.1510270177236488, 0.08050888476352538, 0.288181470166291, 50.87941300484442, 73.685716659792, 57.299662251626295, 45.86812619240054, 42.92927857368223, 63.34443476892287, 75.03826756631175, 69.1989174196797, 76.65014989914434, 66.60670142019949, 71.20988522806476, 4.2917132954443655, 1.0847159042473764, 1.2831483661167085, 0.14940006147709586, 2.813727442295321, 51.06010483157251, 68.81661968846475, 63.076187795208355, 59.67338262065765, 52.13652872270154, 46.5813111489819, 49.17727693434685, 55.09727493409188, 54.821245977955485, 56.68743518091018, 54.43032687710178, 49.49678928621354, 47.52974810138826, 45.03391258178219, 44.763308263594105, 44.44782810826456, 41.89373754685925, 43.32997222100535, 41.727872279382524, 42.914208827480195, 44.15068895586076, 43.80626170865951, 41.9870154319271, 43.970416822741115, 43.05784210082024, 42.609115108366936, 41.68547538018996, 41.13949321931408, 41.8177180905496, 43.097571788295625, 44.05639125454811, 40.74249836706346, 41.61142103133663, 42.98116368632163, 44.16910448381978, 43.47766906984391, 43.26650042687693, 42.757408157471694, 41.20977817043182, 40.06343018624091, 39.99571438758604, 40.19921087449597, 44.14874346025529, 41.20160787336288, 39.3122374626898, 41.11827711905203, 50.896063466225904, 56.147211059447265, 55.276770437917406, 57.09664429387739, 50.92035078233289, 43.52748317103232, 41.25503839985017, 41.270810250313055, 39.715817974459746, 39.137103634495894, 38.371437365008944, 43.06457288803593, 40.75973326160062, 40.62983612860403, 39.29238242487754, 50.088859296614125, 51.3491403672003, 46.463377245010875, 38.64352433912216, 39.22903614659464, 40.50939975246307, 40.897632029748735, 39.524900528692434, 39.14950616898076, 38.23333855598204, 41.203172899061634, 39.29285703166839, 40.134711419382405, 40.30020406169277, 46.21895867009317, 48.51117610931397, 57.358882196487926, 55.246623100772986, 55.63938571560768, 52.810125197133715, 44.913668401779674, 41.51413448395268, 44.75063900793753, 43.25034810650734, 41.10644725061233, 39.26072889758695, 43.07264120348039, 42.07015006772934, 42.70211842752273, 41.8077003571295, 40.30327135516752, 43.36096679010699, 44.498305090012096, 44.09666615147745, 44.533504439938454, 42.857997340540734, 41.52229693628127, 41.15640255712694, 42.99464095023371, 42.73572137278896, 42.021391084117276, 43.75031694289177, 41.83242697869578, 43.27335280756797, 41.037370389507664, 43.739063662867395, 43.719471423856675, 44.268626782201956, 45.48050188249158, 43.69448200348885, 44.36553285967919, 44.89393887981292, 44.100635590091834, 44.542094430615826, 46.216801366498395, 51.31879298917709, 51.898554601976954, 55.49225368807393, 64.65870726493098, 64.00615430647328, 60.55893613446144, 48.886939171821844, 50.74814696465769, 53.49752841457244, 71.5661148871145, 65.7672239888099, 74.58885023670813, 7.686767866534572, 1.0049100124066876, 3.040617680357349, 1.4528603755658673, 7.678099428453754, 75.67269525220318, 68.42260191517492, 77.644392290423, 69.65244539322393, 68.59693557985368, 59.463123967570645, 47.046716059407885, 49.78449906072309, 74.42782125165387, 50.77311677317466, 0.7266425473555442, 0.16492100282301828, 0.21324388322330293, 0.21834992052566624, 0.15766979675860177, 0.104489543535296, 0.14987119022876988], [0.033069640818622806, 0.03373754308408788, 0.06823464702334135, 0.04782144137988648, 0.11344171760063018, 0.04400366136143285, 0.04039939770835542, 0.09902525287602218, 0.12045512997335005, 0.17244449185748256, 28.257207755119573, 61.11871719360352, 46.25871973652994, 27.032516310291907, 18.41475917446998, 46.46534627483737, 64.70744663669218, 57.09421242437055, 57.20460753287039, 53.2075083640314, 63.378022024708415, 12.371570314130476, 0.28515643410144315, 0.8709042579416306, 0.2333749425146849, 0.1319730167667712, 20.461238161210094, 67.98078613896524, 54.155862946664136, 54.16401363188221, 39.305647880800315, 45.17917756111392, 51.66942542599094, 60.24268327220794, 54.72453601898686, 50.07196172591179, 45.656082860885135, 47.37953701326924, 43.55402977235856, 44.0968426581352, 40.328892277133086, 40.873054458249, 38.3723787338503, 39.95674171755391, 37.070959844896876, 41.03821369909471, 37.98087912221109, 38.93719219392346, 39.19266008561657, 40.49062336644819, 36.985460019880726, 37.637252038525, 37.31571182127922, 37.258335390398585, 36.878744094602524, 38.251593266764, 36.474128077107096, 38.9786006558326, 38.34356892493464, 39.909755645259736, 38.517271088015654, 38.765635567326704, 38.17549536305089, 38.860462788612615, 37.87724617988833, 38.55841282875308, 34.818664289289906, 38.18969042070451, 38.47630977630615, 38.4329479740512, 35.28663835217876, 37.550112662776826, 47.59201965024395, 51.17028420971286, 51.21702317268618, 53.01213118337816, 54.126982535085375, 46.073834896087654, 40.16421941018874, 41.09635891452913, 37.84458460346345, 40.5558523824138, 40.25650101323282, 39.83800372769756, 37.71770377312937, 38.26758476995653, 37.622135223880896, 43.589872390993186, 46.69806834190123, 46.44296130826397, 39.230306994530466, 39.16215973515665, 37.948374440593106, 39.766169440361764, 39.47028544641311, 41.03127894863006, 39.79564605220672, 40.20068568568076, 39.86316573235297, 41.80389173569218, 37.80098745899816, 48.867076289269235, 51.760279286292295, 48.245141352376635, 50.06812957025344, 52.12819760845554, 49.69619474103374, 39.42878284761983, 38.01031258798415, 37.15199209028675, 38.86535006184732, 38.751640550551876, 37.045185950494584, 37.88984091051164, 37.349958035253714, 38.437474389230054, 37.118651943822066, 39.509175746671616, 39.180206560319476, 38.90163198594124, 37.42700515254852, 39.1076466345018, 37.95344606522591, 38.33589284650741, 37.228548911310014, 38.085402442562966, 36.96214545157648, 37.852511713581706, 37.587571297922445, 37.73075349869267, 37.711475049295736, 38.75710833457209, 37.821136674573346, 39.575424578882036, 39.79639914727981, 40.006132202763716, 37.53418391750705, 41.34029896028581, 40.81582707743491, 43.59418699818273, 42.65282207919706, 45.68772854343538, 47.19052976177585, 50.81125790073026, 57.10063726671281, 60.91416558911724, 64.19619706369215, 60.72522501791678, 51.340715116070164, 46.50594280612084, 44.99495952360092, 60.26159694117885, 59.768962937016646, 73.41128410831575, 9.782198033025189, 0.5650225714329751, 0.28420222562647635, 0.6881094892178813, 10.878270056939895, 67.53742494890767, 56.002075518331225, 65.8411410547072, 58.635684290239894, 59.02196714954992, 33.35235288066249, 31.06379697399755, 40.621881561894575, 62.8055364085782, 21.67779657148546, 0.1486700409722905, 0.045981562486098665, 0.04719280112054079, 0.04601641182577418, 0.01977728371838889, 0.12237892996880317, 0.025555662765738466, 0.017759559428199165, 0.05190785778986831, 0.03285611679236735, 0.09469366151719324, 0.1619647154884954, 0.014724722225970079, 0.08231677565603487, 0.06287434130846974, 0.1449623899233918, 0.10907706954786855, 35.947577338064875, 66.18848262294647, 54.75029814627863, 29.434830757879443, 27.853027120713268, 56.747541581430745, 67.43849492842152, 63.46298056264078, 64.65280802019181, 57.75460227843254, 71.24114651833811, 11.999569785210396, 0.4510388925911919, 0.26083608428316735, 0.41073727451505204, 0.05111371572580069, 25.15132208024302, 72.98677382930633, 53.80781142942367, 58.95994663238526, 41.177442150731245, 47.51444301297588, 53.047918888830374, 61.464434900591456, 56.25611174491144, 54.01214338118031, 47.72066554715557, 49.39438404575471, 45.42147413376839, 47.035074464736454, 42.865661651857444, 43.45654710646599, 39.98796378412555, 41.88547311290618, 40.6403951491079, 43.25245441928987, 40.621081398379424, 41.593248690328295, 40.95059187181535, 41.49413039607387, 38.964350684996575, 38.49631386418497, 40.5540677039854, 39.305506675474106, 39.67675508991365, 40.28813885104272, 38.66055919278053, 41.96517567480765, 37.81093066738498, 42.98774150110061, 38.89910990192045, 40.81466605586391, 40.25694424106229, 38.58692845990581, 39.92447237814627, 40.55228694792717, 38.14035877104729, 38.37382216607371, 41.693033787512014, 40.78987667637487, 36.32347768352878, 38.718978974127005, 50.00061381247736, 52.66897478411275, 53.50218819033716, 53.8369232608426, 52.50586694286716, 46.01357944550053, 41.950345193186116, 41.48452843389204, 39.76229413863152, 40.780164887828214, 40.56965128068001, 40.455706427174235, 38.64070807733844, 38.64118660649946, 37.51879645932106, 44.33844497126918, 47.57506324398903, 46.87825026050691, 39.642799131331905, 39.07576560974121, 37.631894080869614, 41.157492976034845, 39.266549694922666, 40.862134579689275, 39.051239029053725, 40.75155119742117, 40.14383093003304, 41.88397868987053, 38.34306293918241, 47.43566220806491, 53.037112759005645, 52.72398210340931, 53.124165842610026, 53.41419766026159, 52.50773399106918, 41.04185365861462, 40.17019710233135, 39.53499670951597, 40.063277213804184, 39.540284064508256, 38.659217742181596, 38.67694293299029, 38.22967113987092, 38.75052267505277, 38.4169800050797, 39.8087820699138, 40.418804768593084, 41.840683567908506, 39.31430455177061, 41.466132517783876, 42.19875674093924, 39.98260974884033, 40.004069036053075, 40.77779577624413, 39.27844232128513, 39.911414807842625, 40.5717928947941, 40.59153418387137, 40.25555572202129, 40.58717643060992, 41.44751694894607, 41.79357590213899, 42.149840862520286, 41.18640868894516, 39.427115840296594, 43.73232895328153, 42.26671180417461, 45.54171439140074, 45.28908629571238, 48.45987935220042, 49.67384115342171, 54.557019433667584, 60.23295971655077, 61.97766134815832, 62.87026336116176, 63.016359882970015, 53.62943380109726, 47.19967280664752, 49.09991994980843, 63.34472502431562, 63.37512731552125, 74.75034206144272, 10.971598932819983, 0.8079637611104596, 0.8043409006730203, 0.9751852493612998, 12.310196007451705, 74.15159225463867, 63.23438090662803, 72.07367743215254, 63.701888207466375, 64.6487719012845, 42.33086609071301, 33.903618474160474, 46.24064545477591, 72.00761687371039, 27.545938876367387, 0.02676002767627999, 0.03627370014005611, 0.0061967401416040966, 0.02060563926915488, 0.06395572803974633, 0.1056228863495973, 0.02116358301962816, 0.11067390321723877, 0.18387660744690126, 0.23099119865125228, 0.3718734808987187, 0.3319449782852204, 0.12161781395515128, 0.20820417381342382, 0.18789794085727585, 0.24988321797742, 0.1907431301210196, 42.13857189301522, 77.94477524295931, 62.12839018914008, 37.75692747485253, 29.106893154882616, 60.62885630515314, 75.25595126613494, 67.72624784900297, 68.66587515800231, 64.11504322482695, 76.49643221209126, 15.636028589740878, 0.8182664179513532, 1.454264093791285, 0.6229452536471429, 0.2007948472014358, 29.024001706031065, 74.74166577862155, 58.40939883262881, 59.85533745058122, 44.39663333277549, 48.44213454954086, 56.74905953868743, 65.41612086757537, 57.78178038135652, 54.259335071809836, 50.75388931458997, 51.07279762145012, 48.45903604261337, 51.36963867372083, 46.10501381658739, 46.24049640470936, 42.102493932170255, 45.33908867066907, 42.54268192475842, 46.16579878714777, 42.3514114656756, 45.28223783739152, 43.44741582870484, 44.653164186785304, 41.546450891802394, 41.491647535754794, 43.100246844753144, 42.220157192599395, 42.579587505709746, 42.661796462151315, 40.5638304833443, 44.48398451651297, 40.73193934655959, 46.6790723031567, 42.00617228784869, 42.77396840433921, 42.46505821904829, 40.43804399428829, 42.62898191328972, 42.98174811947731, 39.4973615677126, 42.21763510857859, 43.73404302904683, 42.703459878121656, 39.32208261182232, 40.790308137093824, 53.06316514169016, 56.13807978168611, 55.6747615721918, 56.051352254806034, 55.77720603635235, 47.65917454996417, 43.17651733275383, 40.98146484744164, 40.30196912827031, 41.24231030864101, 42.2071349236273, 40.98484200816001, 38.95228547434653, 41.02816458671324, 40.241376353848366, 46.85447285252233, 50.69067247452275, 48.221858163033765, 40.721313645762784, 39.76011722318588, 37.90886440584737, 42.12289417943647, 40.292955521614324, 42.38548901773269, 39.9271317451231, 40.625878457100164, 39.32129029304751, 41.42339045001615, 37.516545018842145, 49.8819346581736, 56.85356716955862, 54.82461137156333, 55.728788298945275, 56.21411492747646, 54.027177826050796, 42.89622476024013, 42.709841574392016, 40.54516392369425, 43.50181125825451, 42.30636304424655, 41.361891608084406, 41.060975213204664, 41.100069476712136, 40.26053713214013, 40.69479057865758, 42.23942779725598, 44.157239314048525, 43.18606045938308, 41.208228834213756, 42.648856562952844, 45.32465042606477, 42.767622009400405, 42.3153531166815, 44.04713838331161, 42.12489851059453, 42.157866031892844, 42.18444008981028, 43.40550530341364, 42.94322652201499, 44.13194787117743, 42.184396943738385, 45.098992547681256, 45.006197114144605, 45.754197028375444, 40.67131519317627, 47.046198306545136, 43.54302752402521, 48.401887109202725, 46.79690422550325, 50.85930693534113, 52.09786591991302, 57.03740081479473, 63.3207554201926, 65.1345770589767, 66.16687820803735, 66.2603404445033, 57.23001272447648, 50.33375640069285, 50.25086887421147, 66.72366649873796, 65.46102416130805, 78.21547369803153, 12.81653477299598, 0.8772934312301298, 3.6873064502593014, 1.9050971538789812, 13.595810686388324, 81.29141207664244, 66.99467089868361, 77.36256214880174, 67.38439759900494, 72.02078819274902, 46.265164190723056, 42.558198821160104, 55.202696477213216, 80.34771334740424, 37.84667914913547, 0.17963750588317073, 0.16121592582954516, 0.23149546836653065, 0.11650390126892637, 0.11589850028676373, 0.24979966842839796, 0.1383065414284506], [0.011422856459243885, 0.05410424719053892, 0.04730517855815349, 0.07060063296868917, 0.03398405868680247, 0.08210548094563908, 0.07184091399634077, 0.08012769473416191, 0.10604462541279294, 0.15857663035633104, 18.066723346710205, 60.49076141849641, 48.23573158633325, 34.77536916732788, 37.00385593598889, 42.61720303566226, 64.07996154600575, 52.552009705574285, 59.901472368548, 54.90702036888369, 63.372209072113044, 24.610731217168993, 0.1870627211587083, 0.4195216063770556, 0.29749127705731704, 0.08150356566353191, 17.404058517948275, 70.33962111319266, 48.98519846700853, 54.007836618731105, 38.83961539114676, 58.056589480369325, 55.875920326479026, 58.90988934424616, 51.97680980928483, 52.93269926501859, 48.85746255997689, 48.82589924720026, 44.85176163335001, 43.2327837328757, 39.74977001067131, 39.67806123918103, 37.24696836163921, 38.579883883076334, 39.057067671129786, 40.96890541814989, 38.04795165215769, 38.94819836462698, 36.72198657066592, 39.81747404221566, 37.35752428731611, 36.580620427285474, 36.242206173558394, 37.589708989666356, 36.08961028437461, 37.4930892452117, 37.82245066858108, 38.180319878362845, 38.083049020459576, 38.548524533548665, 38.745525575453236, 40.19507277396418, 37.31799856308968, 37.957717526343565, 36.301394739458644, 38.70841995362313, 39.01663195702338, 39.18640782756191, 38.593788685337195, 38.57867579306326, 36.10012223643642, 39.88746089320029, 48.586191438859515, 50.69858781753048, 49.880055842861054, 53.500089722294966, 48.58716026429207, 40.03397318624681, 39.91530972142374, 40.16419195359753, 39.244553042996316, 41.60037171456122, 38.939671131872366, 38.84770724081224, 37.38686753857521, 38.78693403736238, 37.75668036553168, 43.008553597234915, 45.785372026505016, 44.63560765789401, 40.26167069711993, 39.09112953370617, 40.21131530884774, 39.80694247830299, 40.40180129389609, 41.02017471867223, 41.018786199631236, 41.53823744866156, 39.18904758268787, 40.65208773459158, 42.001065361884336, 48.566740405175, 52.77573777783302, 48.40668416792347, 50.94279458445888, 50.019876572393606, 50.176359530418154, 42.64500479544363, 35.241829195330226, 37.76083415554416, 39.457008223379816, 38.43920807684622, 38.50606487643334, 37.73821384676042, 39.592718308971776, 39.87120266883604, 37.7329304141383, 38.347369701631614, 37.58700255424746, 38.87141404613372, 39.25818720171529, 39.17361305605981, 38.663281317680116, 37.91119429372972, 37.90700520238569, 36.05631720635199, 36.4459889934909, 37.01709785769063, 36.7574800983552, 37.217170115440126, 38.68850608025828, 39.00892449963478, 38.600688134470296, 39.86667233128702, 37.98397779464722, 40.24498885677707, 37.50740197397048, 39.15259307430637, 41.53830805132466, 41.64873846115605, 41.22636195152037, 45.724689037569114, 46.2654975921877, 51.32900291873563, 55.203218152446134, 57.6102041429089, 54.33301679549679, 63.102095050196496, 58.09154956571518, 51.46897269833473, 44.39159700947423, 57.19122832821262, 63.17103070597496, 68.62619646133916, 5.669897381336459, 0.3357003106465263, 0.8149178782778402, 0.36807840389590113, 12.100637497440463, 66.94158554077148, 56.335422069795676, 67.16978903739684, 56.48361705964612, 57.75776370879143, 41.29609777081398, 48.89590963240593, 53.80675631184732, 59.761490821838386, 13.76186913059604, 0.13170125473651195, 0.047963091037085945, 0.02475733403116465, 0.07037890414076467, 0.09050941950972043, 0.05793621132691061, 0.07292636099361605, 0.07930411191116418, 0.06804536201901014, 0.04723975464941994, 0.1065869773587873, 0.058959007653738224, 0.1487604240255971, 0.11474766768515111, 0.06862649333573158, 0.1023176000002892, 0.32876856324653475, 22.07256155629312, 69.52732178472704, 53.02921702784877, 35.5472602382783, 33.45143587358537, 50.521794826753684, 70.14565990817162, 60.30229153171663, 65.23483676295128, 57.2554845963755, 70.00789842297955, 24.504423218388713, 0.3314338750656574, 0.2759380981085762, 0.7010487755460124, 0.07656963767423745, 19.71430120929595, 73.50988464970743, 53.260962424739716, 57.3902690026068, 40.95138811296032, 59.90723433033113, 56.53713780064737, 61.09470836577877, 53.466933927228375, 54.68158998797017, 50.42592425500193, 49.73463789109261, 46.932331900442804, 45.14669249134679, 41.966128810759514, 41.660548717744895, 38.70702751221196, 42.0057604389806, 40.05256522086359, 42.72655087132608, 40.97767583785519, 39.741458508276175, 39.049332757149976, 40.334101184721916, 39.378050911811094, 40.244765281677246, 39.010575817477324, 40.39469788151403, 38.10744224056121, 39.369335405288204, 39.28089380264282, 40.22991911057503, 40.011552918341856, 41.18073301930582, 40.76412239382344, 39.287499074013006, 40.40621396033995, 39.96353134032219, 38.26176789499099, 39.6715618718055, 40.21937577955185, 40.23686170578003, 39.96799107520811, 39.95194465883317, 38.11775022937406, 41.67586949563796, 49.65908127446329, 52.03933238983155, 51.141180223034276, 54.99688186953145, 50.20579691856138, 44.970950695776175, 40.80652713775635, 40.469611229435095, 40.626090265089466, 41.28182818812709, 38.424118718793316, 40.3506810434403, 37.82285467270882, 41.287103776008856, 39.52749713774651, 43.64913155955654, 48.28845216381935, 47.304117679595954, 40.12090075400568, 39.602488933071015, 40.78943737091557, 38.513544836351954, 39.23948141836351, 41.699309579787716, 40.9950872390501, 40.67687319171044, 40.63071473952263, 40.42306054023005, 41.78435833223405, 51.36020929582658, 55.46786439034247, 52.17871773627497, 52.64611913311867, 52.88728998553369, 50.77307362710276, 45.690336919599964, 37.199135057387814, 40.5744561841411, 41.391936963604344, 40.480487961922925, 38.81659107823526, 39.54310817103232, 40.52234357403171, 39.52137431790752, 39.76169793836532, 39.07886428217734, 40.615519477475075, 41.23852129905455, 41.10285043716431, 41.631366283662864, 39.40355808504167, 40.408696820659024, 40.405272591498594, 38.91175170098582, 38.262646505909586, 41.110553972182736, 39.358811686115885, 41.035687692703746, 40.462209716919936, 41.47262796278923, 40.055157907547496, 43.6280252856593, 41.16427475406278, 42.35440031174691, 40.596280251779866, 42.63567347680369, 43.24902234538909, 44.77096473017047, 44.66165611820836, 47.164771556854255, 48.49317243022304, 54.66597110994401, 57.612098647702126, 60.377993276042325, 57.525755513098936, 65.86221202727288, 59.75592497856387, 52.61029220396473, 46.44538925540063, 61.05855980227071, 64.93275934650053, 71.87475050649336, 6.811612065761321, 0.29909319755050445, 1.1535777704369639, 0.9172176437512521, 13.893696069717409, 73.49674470963018, 59.199336728742054, 71.99125274535149, 61.655285666065836, 64.37392750094014, 45.85245240119196, 50.0148755504239, 56.497306131547504, 69.364362993548, 20.191938031104304, 0.28368327766656876, 0.07901641525207989, 0.09138478221552027, 0.07665504115603625, 0.02420403851917194, 0.011894170987239529, 0.040181353763346715, 0.20588753925215816, 0.21650882738251842, 0.15816783051817648, 0.3077143220411193, 0.22142159602334424, 0.16290240710781467, 0.2836822051434748, 0.2790360963873325, 0.24035368174795183, 0.41706047231151216, 24.63236112748423, 76.34448743635609, 63.06655053169497, 45.352526710879424, 53.72842657950617, 55.52715886023737, 74.46749210357666, 63.280253025793264, 70.27290159656157, 62.374260041021536, 75.46826916356241, 30.560182294537945, 0.30153012323764067, 1.3766433298587801, 1.708549390877447, 0.14124683284711453, 22.841430441025768, 76.81317144824614, 55.979098273861794, 60.556916113822695, 45.22154700371527, 63.14748079546037, 59.88171146761987, 61.40136711059078, 55.04202835021481, 57.92266799557594, 51.5732567541061, 54.00894664948987, 49.09627999028852, 47.718943626649924, 45.2136512725584, 44.473617692147535, 40.70866400195707, 44.583953965094786, 41.52302649713332, 45.173670553391986, 42.367826584846746, 42.629903670280214, 42.428693925180745, 43.90277162674935, 42.135649727236846, 43.78066432091498, 41.254281382406916, 43.99742626374768, 40.823820867846095, 43.64053372413882, 42.08515705600862, 43.075712419325306, 41.34634333272135, 42.292913236925685, 43.86618768015216, 40.55338521157542, 42.68575037679365, 41.66672645076629, 40.27875654159054, 42.41114131865963, 41.810430326769435, 42.40957237059071, 42.828630555060606, 42.37887590162216, 38.981730707230106, 45.09705097444596, 50.692053148823405, 54.934245540249734, 54.87709660683909, 56.2338875955151, 53.22069145018055, 45.18931296563918, 41.11817121505737, 40.94026427115164, 40.48987811611545, 43.60972742880545, 39.25119753806822, 41.20322781224405, 38.47755709002095, 42.581674206641416, 40.41939312411893, 46.42644812983852, 51.27845141195482, 49.530529514435806, 42.86825433854134, 41.364656879055886, 41.1785247248988, 40.23093500444966, 40.258454353578635, 42.58423943673411, 41.7696729783089, 40.32531115316576, 41.22764064419655, 41.550369339604536, 41.51374224693545, 49.81499548881285, 57.960052105688284, 53.86562716576361, 57.54376703693021, 57.00122479469546, 52.914040550108886, 46.85920715332032, 39.748232441563765, 41.55466433494322, 43.433169780238984, 43.04232520441855, 42.39428297165902, 40.988234858359064, 43.269144104373076, 42.679427516075876, 39.7375871289161, 42.03477028877505, 41.85161129120858, 42.64370256854642, 45.23903685231363, 44.1285667880889, 42.6183444453824, 43.453793602605025, 43.2665906413909, 41.15866184234619, 40.78340084322038, 43.544290527220696, 42.128860104468565, 43.23000277242353, 43.50705938954508, 43.08925244116014, 41.32889270782471, 47.37000565375052, 43.9886676111529, 44.95595547460741, 42.00414050009943, 43.92003005550754, 46.693592917534616, 46.53850240092124, 45.95765429158365, 50.1275574007342, 49.972686536850475, 56.88290257607737, 60.121176089009936, 61.706245099344564, 60.99147158284342, 66.88515832347255, 62.33383609402565, 58.71823449288645, 48.83381851257817, 62.81117285451582, 69.05701391158566, 74.08311551617038, 7.992739706270157, 0.4906170172316413, 1.7367693733784462, 1.2579564533887373, 15.887933988724987, 79.59894072624945, 65.7908288125069, 79.31306269861038, 67.32559342538157, 71.08229052635932, 56.64887043737597, 61.505725691395426, 67.63611962718349, 80.69074030845397, 27.677532434463505, 0.38418521864279626, 0.19647051069524982, 0.15292565939166855, 0.1844590640957317, 0.1602313496292599, 0.13250426809874274, 0.18215202095527805], [0.08738228690720375, 0.08518245011087387, 0.06215163694334127, 0.024625480723296924, 0.04009634098638931, 0.03722907306866781, 0.04993223577677723, 0.0660171672221153, 0.09403952202128787, 0.1451553368280011, 5.933097245231752, 55.38580448396745, 51.228676534468136, 27.307450925150228, 25.323849493457427, 45.08207536512806, 62.01756754229146, 55.55678844451905, 59.52884720217798, 54.94531446887601, 58.958781688444084, 39.00632396821053, 0.07634840680346375, 0.5665678627067997, 0.13439762376008496, 0.23084714347797058, 19.18844472977423, 72.47675588054042, 52.595508790785274, 48.322584629058845, 43.569534901649725, 58.879643947847434, 55.37323328756518, 55.14149965778474, 49.20809891916091, 54.750894346544825, 46.06272282138948, 46.8793563688955, 41.62694969484883, 43.330795918741536, 38.06987770142094, 39.943719448581824, 37.6938832190729, 39.01496494970014, 38.50657870692592, 38.26071669978481, 39.04071138751122, 38.242916983942834, 38.24516450205157, 40.03063524923017, 38.34671466581283, 38.94244816995437, 35.82696837763633, 39.012309505093484, 37.08510783410842, 37.43571673670123, 36.65397659424813, 38.22637634892618, 37.28534483140515, 39.01791457206973, 39.81060204967376, 39.202870015175115, 38.99708678645473, 38.135730374243956, 38.65489921262188, 39.344193012483665, 36.980306025474306, 37.61147029938237, 40.55429127908523, 37.709835498563706, 37.97483474977555, 41.32724923472251, 48.88666460590978, 47.307949835254306, 51.976127316874845, 46.40543991519559, 44.39830034009872, 46.26957685716691, 43.44369742178148, 40.65763396601523, 40.267318910168065, 39.52257456318025, 39.24702413620488, 39.30653825882943, 37.859893614246005, 37.96598588266681, 39.45792998037031, 45.902419474817094, 44.0637025525493, 44.21189362002958, 39.10899985221125, 39.93284271609399, 38.039298903557565, 39.46994812257829, 39.624826831202355, 39.917565084272816, 40.08890205813993, 41.90734817135719, 39.75962300454417, 41.04503862319454, 40.95039575330673, 49.38784153230729, 51.8315448299531, 51.093005672577895, 51.32759871021394, 47.87337518507435, 52.757247724840724, 46.053583698887984, 38.05863226613691, 38.88044334227039, 37.49399139035133, 37.617804927210656, 38.324494438786665, 38.088756069060295, 38.1433319276379, 39.327652377467004, 37.39482210528466, 39.19815532622799, 38.289318623081336, 39.63670376808413, 38.31854420323526, 38.18037871391543, 38.98525299564485, 37.4016744859757, 38.3661735442377, 37.83945806564824, 39.136817301473315, 38.48675112570486, 38.54093866963541, 38.64870971248996, 38.63278488959036, 37.732424428386075, 38.46019667963828, 40.398086809342914, 38.80864435626615, 38.53492959853142, 38.153122163588, 39.59942948433661, 38.60980372275076, 39.58449309872043, 38.858164279691636, 42.56073267229142, 44.2290618342738, 50.973773464079834, 55.94733099783621, 57.68296018723519, 51.69288512199156, 49.581257527874364, 63.402713344943145, 55.818740014107, 46.03576044882498, 55.01275177924864, 61.607848521201845, 63.91089954683858, 2.5479304790496826, 0.2172742717929425, 0.3380733752442945, 0.6927339023640079, 19.242234153132287, 66.68081852697557, 57.311747074127204, 66.9574946741904, 62.65506252165764, 51.19807420238372, 26.58395797975602, 49.26088617693994, 58.88773187514275, 54.994128365670484, 8.212352231625589, 0.1353469752376118, 0.1041944541277424, 0.05653870607455892, 0.016910387353310664, 0.06582700887755041, 0.00413047269009234, 0.08669652330178408, 0.0750068029869468, 0.07148173367304188, 0.03906995936807606, 0.09999931834998632, 0.04217480647287542, 0.12528791137400175, 0.0536992471484888, 0.060797032614749294, 0.09408894235328322, 0.1944673746343582, 9.930899008627861, 66.00089919182562, 58.203423407769975, 32.76154979582756, 31.742565093501923, 52.01804960927656, 67.17324072314848, 59.02350864102764, 64.74286171697801, 60.66727984336115, 64.84811459818195, 42.276015666223344, 0.06981646536939567, 0.513154128866811, 1.0056514016562894, 0.2314433590659211, 20.454209273861302, 74.93970624862179, 55.38589077611124, 50.8765261403976, 45.77433055446994, 61.39060412683795, 56.92989649311189, 56.332409689503336, 51.343009702620975, 57.51274893360754, 48.43348180094073, 49.71516332318706, 43.23712187428629, 43.762986198548354, 39.35170827373382, 41.92524986882364, 39.875097582417155, 39.5580171000573, 42.101478038295625, 40.277073844786614, 42.56574153900147, 40.55289491530388, 40.58458374392602, 41.13272713076684, 41.00683473771618, 40.8336385603874, 37.40320028797273, 40.45369817364601, 39.39164584682834, 39.10084132225283, 38.54856767962056, 41.03979833664433, 39.91667862861387, 40.08997286519697, 41.47534224294847, 40.59618219252556, 40.516295279226, 40.92758717075471, 40.20391379633258, 41.14272917470625, 38.44049461426274, 39.35925491394536, 41.71154345235517, 38.737237607279134, 40.39307402026269, 44.775408775575706, 50.52436397921655, 50.97265558858072, 51.979194610349595, 51.73698825220908, 46.52793161330685, 47.047484843961655, 42.64704835030341, 40.69484941421017, 39.42763359315934, 40.84415443481938, 39.16707838735273, 38.85870948914559, 39.00345671561457, 39.004605970075055, 41.42171952032274, 46.43099023449806, 46.38180763490739, 47.67890014956075, 41.345598082388605, 41.24061976709674, 39.04646158218384, 39.03458856767224, 40.5971823969195, 40.70087417479485, 39.339486168276885, 41.32708449517527, 40.435792553809385, 40.26934285317698, 40.71454363484537, 48.84376564333516, 53.78617563555318, 52.318832643570445, 51.551581736533876, 50.44777970160208, 52.57970163899084, 45.692062762475786, 40.062649634576616, 39.50039748222598, 38.89877257808563, 38.82376509328043, 41.038382361012125, 38.79500235280683, 39.433599518191436, 38.70493688891011, 38.30362350709977, 40.372873813875266, 39.438020029375636, 40.333618733190725, 39.23698679093392, 40.96688539751115, 40.63854771275675, 39.724878649557795, 41.540265314040646, 40.921036812566946, 39.92538236802624, 41.16910711411507, 41.213920193333784, 40.37140684743082, 41.47864095626339, 40.25480654931838, 39.69397429497012, 41.132076017318234, 42.20447947902065, 40.91884420764062, 41.24812326123638, 41.33553328052644, 40.876306103121856, 42.013781685982984, 41.78870431838497, 44.22546894319596, 48.51075641570553, 54.60749641541512, 57.29503777719314, 60.25021422293879, 53.4690990755635, 52.27040706142303, 64.56115007400513, 58.83792169632451, 49.55580134545603, 58.02165292924451, 63.913296115013864, 62.38831781571912, 2.9906922819152957, 0.43973597006932386, 0.5191432203977339, 0.8003771004657593, 21.346887773083104, 74.95050845607635, 62.642879639902425, 72.84829062800254, 66.66387388783117, 57.36171807012251, 35.620753688196984, 51.45817833562052, 63.28353604962749, 63.68136244435465, 12.76093811758103, 0.2682209880121293, 0.11062406919776432, 0.07302471902221441, 0.042622730421322974, 0.05816021543597022, 0.01666017729158123, 0.02540680805161115, 0.1351452336436318, 0.16470810698886074, 0.2863537682400596, 0.13913742506936674, 0.2153463962097322, 0.20240084328238042, 0.10602003399042353, 0.27349816935677684, 0.19181991266387124, 0.4931180491562813, 11.049124579275809, 75.91979672831874, 67.04810926991125, 41.430619378243726, 37.22671324206937, 57.95289378012381, 73.57631391094577, 66.26263110868393, 70.12541263334214, 64.56940666321786, 70.09942300858037, 47.43821174867692, 0.2188991136368244, 1.5259803422997076, 2.048200784671691, 0.2692842874075136, 25.3904591837237, 78.72679387369465, 56.31227224103866, 54.68886598463982, 47.740104813729566, 65.38496940366684, 58.21395104931247, 59.050635753139375, 53.74551242397678, 59.40648886465258, 50.89818546848913, 53.165048706916075, 45.651093606025945, 46.78087349860899, 41.14142694780904, 45.480745069442264, 42.02202258571502, 41.86588871863581, 44.62472308066584, 43.0879266800419, 42.703048029253566, 42.26402890297675, 42.018221809018044, 44.67841640595467, 43.588075945454264, 42.83257645945395, 39.48126808289559, 45.426177055605, 42.5435919146384, 42.48028093768705, 41.717509377387266, 43.747241804676676, 42.82185269940285, 43.66278925249654, 42.70083189010621, 42.47665666764782, 42.78369588236655, 42.82099762270528, 43.30393945017169, 43.279507006368334, 39.09383989149524, 40.83555267703149, 45.15257212423509, 40.225400540136526, 43.520736694335945, 46.36275276061028, 53.73371785686862, 52.78061328395721, 56.06049922204787, 53.425195986224765, 51.15825430039437, 47.42298510766799, 44.64723356308476, 40.60653724978047, 40.583712977747766, 38.66194378945136, 40.59701373500209, 41.199693756718794, 39.580504048255186, 40.514341938880186, 43.436652844952, 47.83566944060787, 48.319285915743926, 49.425649258398245, 43.43518587850755, 44.26475540284188, 39.55552247262771, 40.38867704329952, 41.19062915925057, 40.44055823356875, 39.91896144805416, 42.57568082501812, 40.92373932561567, 40.133334667451926, 38.763729295422955, 50.68014875535042, 57.51444339752198, 55.89901916442379, 55.53811796249882, 53.23899322940458, 56.285686416010705, 49.76857816019366, 42.66770355163082, 42.22713116676577, 40.831846037218654, 39.69799472439674, 42.90998835717478, 41.80318178669099, 43.36795645375406, 41.34928511035058, 40.19009136384533, 43.30346092101067, 43.0050979891131, 43.34399469437138, 43.67083011134979, 43.041430904019265, 44.012080238711455, 40.88198569513137, 45.181036764575595, 43.78156254368444, 43.01079719297348, 42.498206169374534, 43.594583157570135, 42.69876872339557, 43.100352748747795, 43.99566904191048, 42.767912264793154, 43.44884357144756, 44.079705822852354, 43.18190666937059, 43.4889772630507, 45.515693387677594, 43.11679532451015, 43.77979355473673, 42.90583064479213, 47.30054440036897, 50.04211641127064, 56.87656010350874, 61.241369708891845, 63.19987189385199, 55.25320091555196, 57.1383979243617, 66.41944746817312, 60.65618345814367, 52.14072565878592, 61.1905397138288, 66.95549426540252, 69.22682116108557, 3.818154267726406, 0.37973446230734553, 2.284989981882034, 1.0697415206701526, 24.6029806137085, 79.27497648423719, 68.2528260446364, 77.20139980316162, 74.69211055386451, 65.83141357667985, 38.14412032404254, 59.455290994336536, 69.71917275459536, 75.02625726884412, 17.598855187816007, 0.5029778152463898, 0.25934536911306844, 0.1594329327945748, 0.22532144321068642, 0.14392092403384948, 0.13588763412929353, 0.21042023635198995], [0.07015397306531668, 0.006874227603416771, 0.04776671588901551, 0.06134538685963039, 0.010199169853642102, 0.10659042475444656, 0.08239818781974816, 0.050466233533957315, 0.06252935276396814, 0.14380087805611474, 1.2275056228522332, 44.997461995770855, 53.17567048534271, 37.377732338443884, 21.114422621265536, 35.36848645056448, 58.98809748311197, 62.68115020567372, 63.27433809157341, 56.81276275265602, 55.743960026771795, 48.01014431061284, 0.8109580004407514, 0.5022730449995687, 0.1640234082456558, 0.2984969053537615, 15.549466783000579, 71.64273446606052, 48.276590916418264, 51.26331498545986, 45.10048304834674, 61.665695636503166, 52.53388835537819, 51.19505005498087, 55.20561079825125, 50.0798103886266, 46.407918853144494, 43.88439532249205, 40.36316987006895, 38.9701283362604, 37.38677340169107, 37.81248784834339, 38.9052091875384, 40.47349045353551, 38.545688659914084, 40.94919943040417, 37.27479365564162, 39.427865012999504, 36.13740436492428, 38.49388983941848, 37.62799132254816, 37.0389493819206, 37.774158447019516, 36.59433303340789, 37.77755521958874, 36.180805390880955, 37.816629871245354, 37.389444535778416, 38.5161728243674, 38.81048787024714, 38.94084392055389, 39.19810041304558, 37.43124523470479, 40.543096834613436, 39.046230162343676, 37.2812145756137, 38.21006713374969, 39.5937498923271, 36.878136127225815, 37.85165663688414, 38.302709594849624, 41.75119469242711, 47.257676816755726, 50.36457838550691, 47.91215565896804, 47.49426241843931, 53.07618348829208, 45.598282814025886, 42.99723755928778, 38.8574190293589, 40.992474940515336, 38.1662424918144, 39.16052018442462, 38.84301216371598, 36.94571464292465, 38.88601310791508, 39.090125406942065, 41.84800663302022, 43.599643015092425, 44.128233386624245, 40.75097068663567, 37.885710654720185, 38.51894201770906, 40.23610468833677, 38.71680598105154, 40.20763220325593, 39.42794346040295, 40.21888548328031, 40.667435969075854, 41.743475467928, 42.43075316952121, 49.88241710970479, 54.97466948724563, 49.896310144855136, 48.81070398515271, 50.52964741183866, 53.42292493389499, 48.85918840285271, 37.76042230667607, 38.67556618105981, 39.42441724961804, 39.18494478348763, 37.501981258392334, 38.30732230217227, 37.90846040171962, 39.074220195893325, 37.3888522578824, 38.18485806065221, 37.67738573012814, 37.45942746439288, 37.978686517284764, 38.19840200485722, 35.657780862623646, 37.00151428099602, 35.45607689888247, 35.984055380667414, 37.73591926020961, 37.58310371829618, 38.64514035563315, 41.59890867048695, 38.549097199593824, 38.86626789646764, 39.922930886668546, 38.859093881422474, 40.28636593972483, 39.85463849959835, 39.84103571984076, 39.59835867727957, 38.980612831731, 39.778611198548354, 40.57606043354158, 42.66844095722322, 42.04710222059681, 46.29824153838619, 55.81695141330842, 55.896944230602635, 62.117250657850704, 55.20274746802546, 52.12528328741751, 59.49344388900265, 55.31559013551282, 54.786423175565666, 66.36474609375, 47.8558421904041, 0.05730027024964652, 0.23237925803949758, 0.5130232197623099, 0.2575152769925133, 23.456224703019668, 67.83147719598585, 53.644146611613614, 68.80606066796088, 61.491856190466116, 55.86297650491038, 28.468903956874726, 50.42050353942379, 49.34333047559185, 47.244034813296416, 3.067886733239697, 0.15830396434232114, 0.17930485518468967, 0.04382364602098542, 0.01666417052488654, 0.05147901326117497, 0.01207769692559997, 0.04117276346791656, 0.02127988091219337, 0.06707438387938085, 0.06995571717139214, 0.03883376296970152, 0.0341440484889092, 0.034790373887986906, 0.05331427264477938, 0.12783662461104894, 0.07101944557601406, 0.09541689448298947, 2.457083728044264, 52.610825646308164, 61.03427248616373, 40.37197951347598, 27.51422651352421, 47.62578733505742, 66.42275794859856, 69.28571162685272, 65.67009433623284, 61.85179641169887, 63.04973140839608, 51.95108298332461, 0.7688824291671477, 0.6388357558077382, 0.42599639765197234, 0.426150074889583, 17.09348524770429, 74.35894443142799, 50.68696583470991, 53.24282146269276, 47.812401940745694, 63.2020095855959, 55.03792555101457, 53.46996591937158, 56.8226549702306, 52.6329517364502, 48.57698955843526, 46.8564183481278, 43.029679482983006, 41.037605731718, 40.275304855838904, 39.62646245956421, 41.00489316448089, 41.124529377106704, 40.42487659761983, 42.12372179954283, 41.28790393952401, 42.01463676268055, 38.07309012259207, 39.91824365431263, 39.56689734612742, 39.387248869865175, 37.35628874071183, 38.438521662066066, 41.65874050509545, 39.87745884926089, 39.00024429444344, 39.01701634930026, 40.98881536914457, 41.584729302314024, 41.04053574223673, 41.105360754074596, 41.34674733684909, 41.993852123137444, 40.64153655882805, 38.88972367009809, 39.892677645529474, 39.09976267045544, 39.16261865246681, 40.286428697647594, 40.72932704802483, 45.818449374168154, 49.79222612996256, 52.93892406648206, 49.61867693931826, 49.102085098143554, 53.281111640314904, 46.56448025857249, 43.112331667254054, 37.46110623882663, 42.635320463488185, 39.58163369086481, 39.69267599044308, 38.90427566343738, 37.396791135111165, 39.54649317649103, 41.54876116783389, 43.15239867856426, 47.12863083808653, 45.238370049384336, 43.146636716781124, 39.351771031656575, 39.20004983102122, 39.85508957216817, 39.30930352980091, 39.96391573259908, 40.039954800759595, 40.06753298544115, 40.33143397300474, 41.7119788354443, 43.360805972929924, 49.34022395841537, 56.683465742295795, 52.71525482977591, 51.599646460625436, 53.84981609159901, 54.77254582989601, 50.24224358220255, 39.65345228871992, 41.09413885301159, 41.03145153291764, 40.53838214566631, 39.244835453648726, 39.17276582410259, 39.394972016734464, 41.077335419193396, 38.52943435792, 38.91636833067864, 38.60020176056893, 40.68607114976452, 40.25594795903852, 40.30993938446045, 37.932508453246086, 38.49141090146957, 38.96899084891043, 39.081441279380556, 40.7912612730457, 39.662356069011075, 40.009379925266394, 43.088354218390684, 40.76485195467549, 42.43918234302152, 41.51975131803944, 40.9276028602354, 42.74623724722093, 42.99592356528006, 41.33139910236482, 40.92837948952952, 40.32768810949018, 42.56717712648454, 42.50782382103705, 44.20217790911275, 44.22670448980024, 50.59279757161295, 57.29042899224066, 58.71479065187516, 63.4561477938006, 54.60722577187323, 55.97252045908282, 62.83522875078263, 57.64469354383407, 58.09935115998792, 69.72182427683185, 49.117362729964725, 0.05321460077539087, 1.9703128092711972, 0.7250038546419914, 0.1853481244536177, 25.151163224251043, 76.3604671724381, 58.04622657837407, 76.79898815770304, 66.10271607675861, 62.025325990492306, 28.875583141080796, 51.31629443937733, 55.247980240852606, 57.6660704612732, 4.770778350291714, 0.25244418862125567, 0.0359468755402392, 0.03937658989020894, 0.04311671157577827, 0.03811693449895229, 0.06255413187787899, 0.03077065117747313, 0.11555274948477746, 0.13462729691978426, 0.1782078632423955, 0.17934862944868304, 0.1595505732562273, 0.19128777266990757, 0.18363044807507148, 0.28523383962531246, 0.1718279596177801, 0.3123623000517968, 2.883658644653136, 62.89576661202216, 70.07795195425712, 50.4557107340905, 33.53674350246307, 46.430880408133234, 70.86494415037095, 73.27822946733045, 72.21517301374867, 67.43535703228366, 67.56936873159101, 57.81413993527813, 1.494820053058286, 1.1983169374927398, 2.321270925383414, 0.48257545357750314, 19.189207630772746, 73.92758569409771, 51.534915585671705, 55.73749596072782, 50.316325387647076, 67.03667948322912, 54.2715964009685, 54.925094650637725, 59.33730609955327, 55.693204556742025, 51.15627350345735, 50.442174634625836, 45.823081693341656, 43.33802484696911, 42.24473084172895, 42.12370218769197, 43.716031505215554, 45.28746635683122, 42.08322724988384, 43.637246777934415, 41.94798392634238, 44.28670498632616, 39.638339396445986, 41.71745054183468, 41.682674807886926, 40.95198039085635, 40.38652366207492, 41.6035488344008, 44.512586439809496, 41.582909322554066, 41.123674300409135, 42.77375267397973, 44.186315844135905, 44.55362227655227, 44.47348825393185, 42.4747896194458, 42.075127555478005, 45.08083981852378, 44.03692060901273, 41.47327515386766, 42.2045147803522, 41.368649851891306, 41.72151019496303, 43.77289018323345, 43.082647169789965, 48.50915216630506, 50.49374595765145, 55.84728702422112, 53.95257826774351, 53.70646522891138, 56.85069991696266, 46.87752069965486, 43.77089369681574, 38.33516328565536, 43.986624056293124, 39.085489165398386, 40.962347215221776, 41.50309693428778, 38.50178557057535, 41.33604711101901, 43.987714475201024, 45.3618384176685, 50.509086347395375, 47.74905958483296, 44.1301671151192, 40.19770076197963, 40.23530452482162, 41.601932817889804, 40.19417847356489, 40.938514894054784, 40.06017854136806, 39.305706716352894, 40.66734183219172, 42.58764013167351, 43.74397447032314, 52.24671202321207, 60.161435296458585, 55.53411714492306, 53.54342799032889, 55.693969418925626, 59.046552565789995, 53.06354168922671, 40.95014079924553, 44.20846939086915, 44.16431134746921, 44.01437874763243, 41.81368589401245, 42.16861332616499, 41.18785212116857, 43.863500856584125, 40.642136681464414, 42.94083387620988, 40.177606459586855, 43.034547144366854, 41.733108643562566, 42.943250056236025, 42.34068378325432, 41.94058241382722, 40.35523883758053, 41.109643982302764, 41.96906274364841, 42.358648238643525, 41.617265362893384, 45.75350276885494, 42.65003719637471, 43.29423550636538, 43.318032526200824, 42.09790083669847, 44.788976254001746, 44.87124796836607, 44.17390154254052, 43.35787204004104, 42.76175022125245, 44.40056354768815, 44.7811472031378, 47.71109888630529, 46.47435203675301, 53.00964440068891, 60.188389824282744, 60.909482279131495, 65.81017786456694, 56.520871731542776, 58.9857832847103, 63.84447028560024, 59.56469374318277, 61.32748534602504, 70.6780824353618, 53.67857325461603, 0.15085310044307865, 1.4314796583306406, 3.589873549438292, 0.5112906046692403, 30.304273136200447, 81.47239808113345, 62.17501932574857, 81.1199809658912, 69.31567853496921, 70.97801823769846, 41.385712162140884, 61.56946812906573, 60.57977568718695, 69.90936848425096, 7.671254892503062, 0.6295546925356311, 0.3791785276224537, 0.11154779503422399, 0.24284242562228636, 0.1543711600524764, 0.09263326038396166, 0.11908325802294478], [0.06087834518703242, 0.03651853801021653, 0.019118434696969007, 0.06670205748730129, 0.02212587946785554, 0.05723867295009475, 0.03929040116828777, 0.02795464028754542, 0.0031439764819468463, 0.013532647280953826, 0.6544488115656761, 40.59502117095455, 59.36737891166442, 39.88639008614325, 27.579563394669567, 41.22573044992263, 51.82209976257817, 57.90771592047907, 58.28615796181464, 58.92281355396394, 51.75197955100767, 57.895403600508175, 4.736032034120252, 0.7235159280319369, 0.49887924485148927, 0.4317400039684388, 8.518645705715302, 68.26037268484792, 53.7585582271699, 50.33492918937437, 55.3547393122027, 60.519865405175, 48.930010718684045, 58.10783524667063, 50.3292574421052, 48.427233465256236, 42.106396690491714, 42.91806059498941, 39.11088258989396, 38.63804478799143, 36.629053854173236, 38.68903952260172, 37.71879419203728, 39.84435796737671, 37.187560143009314, 38.87457547649261, 37.89054693714265, 38.00334645855812, 37.25589959852157, 38.05245061074534, 37.03426214956468, 37.6044100330722, 35.33325964404691, 36.72541079982635, 35.45642598982781, 37.95592500317482, 37.13412569415185, 37.02706460029849, 37.38777752845518, 38.69220879770095, 40.038852614741174, 38.67966505788988, 40.25764242295296, 40.38635107778734, 38.9465941152265, 39.080037070858864, 37.786902227709376, 38.78332545680385, 35.805520857534106, 35.3132124100962, 35.32091594511463, 40.47283541771674, 49.831645950194336, 45.00778959643456, 49.17840265458631, 50.96310461721113, 49.24139199718353, 48.17628414400163, 41.17971320306101, 39.97198404804353, 40.461429165255645, 40.654401932993245, 37.836841844743304, 37.12056606046615, 37.60391189206032, 40.05160424017137, 39.98304120955929, 42.97424462533767, 43.094273074980705, 41.13033056259155, 42.07053446000622, 39.81406550253592, 40.16353299540859, 39.951866211429724, 39.7247649008228, 38.69498975815312, 40.63995976601878, 41.85093272116877, 41.36568061767086, 41.15355099401167, 44.46711832477201, 51.97554680608934, 53.47068371311311, 50.72982557358281, 50.313171802028535, 50.8092692590529, 49.822397001328014, 48.587552501309304, 41.21949388134865, 36.67156450210079, 37.142366593883885, 38.62640711569017, 38.62132764631702, 36.23349458940568, 37.466499497813565, 39.423138556941865, 40.15187178888629, 38.65058460543233, 38.79621828756025, 37.86274125499111, 39.53058012070195, 38.02615111873996, 37.46982566771969, 38.6393666267395, 36.48611484035369, 36.7894160362982, 37.941474991460005, 35.689779558489406, 37.77725711945565, 38.12952518463135, 38.41268500974102, 38.910504387271025, 40.96311599977555, 39.41163032285629, 40.408747811471265, 40.08127304815477, 37.84153692183956, 38.51560015832224, 39.60221044478878, 38.30931094384963, 40.14308175733013, 39.85159866271481, 42.37361600322109, 42.55123269173407, 53.024937721990774, 54.84306220085391, 58.98408882079586, 58.05581677344538, 58.74731494534401, 52.19928664545859, 64.24235943825015, 51.874969390130815, 75.85669363698652, 14.053958231402984, 0.15323920385731807, 2.240691468600304, 0.4256059379587251, 0.17172248463236517, 27.113676032712384, 68.92910542026644, 56.36472609735305, 59.323958273856874, 49.052082723186864, 53.42683945932696, 24.464569976252896, 47.3554144367095, 55.053830762063306, 40.39838883184618, 1.0673341659768936, 0.07961975545772622, 0.049182419560008475, 0.09706347024128323, 0.024947421512596553, 0.05809559208911754, 0.042025549562587854, 0.0813460503254206, 0.04921285240280052, 0.04712007639388885, 0.04711448012160198, 0.05630272801124281, 0.03505575440583691, 0.04597947872694462, 0.02579169445520928, 0.024351636849103436, 0.06586264728778793, 0.07507901443468948, 0.7212996050234765, 48.352343651556204, 70.55597905189761, 44.08431068543465, 22.36022622354569, 45.729823420124674, 59.95804471354331, 65.92908059397053, 65.0898188929404, 64.30495262145996, 57.50584556210426, 63.20240574498331, 5.450291720128829, 0.9544435107419569, 0.6995536783529867, 0.6831555356902461, 10.267724702435157, 70.3050885661956, 56.06724177637408, 54.14496267995527, 55.71546008509975, 62.41936729800317, 51.523344593663374, 60.26891216155022, 52.444807406394716, 52.11257873042938, 45.89369220118369, 44.90925573533581, 42.31709857140818, 41.106113849147675, 38.18754488422025, 39.453321195417836, 39.887417747128396, 42.634308491983724, 39.669290819475734, 40.04016268637873, 39.23545706656672, 40.07662503950058, 39.63886891641925, 38.95973797767393, 39.30415738013483, 39.746004535305886, 36.01749750875658, 38.98485291388727, 38.53325866883801, 40.37498797139814, 39.65144011282152, 39.77140580454181, 38.427433121588926, 40.63942240130517, 39.689487103492986, 40.22838546383766, 41.273520608102125, 41.440072290359005, 40.84568415918658, 40.4431430755123, 39.593663600183305, 40.581555674152995, 37.88366709986041, 38.06874021407097, 36.845941312851444, 46.03598010155463, 51.88980771649269, 47.6492666429089, 52.062058602609945, 52.452742361253314, 49.05285543011081, 48.692503360009965, 41.16193702144008, 40.34851197273501, 41.0270506335843, 39.93017942674699, 38.47484280986171, 38.35243740389424, 39.52319429766747, 41.254963874816895, 40.733218039235766, 44.79923325200235, 43.56471823107812, 43.258538015427135, 42.40504987778203, 41.60034033559984, 41.30634692407424, 40.74103924535936, 39.53206277662708, 39.41240695215041, 39.55306314652966, 40.968709299641276, 41.06419155674596, 39.754398407474646, 44.44818504395024, 53.6306889595524, 54.48951152063186, 53.17252474446451, 52.53224880464616, 52.790744766112304, 53.709556056607155, 52.07274313895933, 41.685742101361676, 38.398678225855676, 38.66597990835867, 40.20487869939497, 39.44544507611183, 38.857324892474765, 39.641587118948664, 39.014733529859974, 41.781730344218595, 39.76669896033503, 41.61613572028376, 39.387837225391024, 41.70438120442052, 40.917953829611506, 39.33560694417646, 39.590561005377005, 39.861890962046964, 39.96375099305184, 41.05974751134073, 38.2026695436047, 40.47223921745054, 40.34182825396138, 40.37675696034586, 41.75215567311933, 42.55333115977626, 41.9788686690792, 42.907089725617446, 42.240804549186464, 40.76074915547525, 41.217544463373, 41.58631001749347, 40.68101129224224, 41.47940189607682, 42.1036353418904, 43.904097387867594, 45.19010136204381, 54.85291911709694, 56.75924201165476, 62.211046295781294, 60.539532169218994, 58.27608531521213, 54.74264952444262, 66.71363307583717, 54.84270134279805, 78.72222039007372, 16.054124812926016, 0.11908644494870979, 2.436906565581599, 0.5536555426736032, 0.15282772271142853, 30.200353860855106, 75.56323759017452, 58.798878423629276, 69.83721256256104, 54.85561378540532, 63.503369208305116, 28.905138200329198, 53.36415998397335, 61.70819843969038, 48.45780049600909, 2.2900434655527917, 0.09272297694077415, 0.06802792585785351, 0.05075012656649755, 0.013326945012405276, 0.02210195262676045, 0.032560659662610104, 0.02935464873218969, 0.09392167471589581, 0.16561523170000123, 0.10141701001914279, 0.16452344915559217, 0.15334368292843142, 0.24915140482687184, 0.19063151111045193, 0.11297734574444833, 0.16561595182265007, 0.15518100691899178, 1.3797185906479437, 55.68030780361545, 76.66175227011405, 52.02942448277628, 38.88095325039279, 55.93585022034184, 65.48544483800089, 70.71446634108021, 71.11569343074676, 67.88076569957119, 63.363921103938935, 69.68049033995598, 7.051777810819688, 2.3716481318396907, 2.7539409600919296, 0.6510040512488735, 11.372564204277532, 73.69264356551632, 58.271970748901374, 56.78790277050388, 60.42883503821589, 63.70549678802491, 54.834511433878255, 61.59967822413291, 55.521961719759055, 53.706127905076556, 48.38244392025856, 47.57258038366995, 45.94289049025505, 43.69802782612462, 40.619583052973596, 41.532259756518954, 41.56326609273111, 44.0610824092742, 42.02957314829673, 43.333396450165786, 41.830524629162205, 41.93419679518669, 41.690445023198286, 39.95618474098944, 42.12421209581437, 41.85016001424482, 39.19861816590832, 41.472235725772, 40.46080158602807, 43.4382257153911, 42.516233382686494, 42.53133058547974, 41.29235582966959, 43.01762211707331, 43.89421693740353, 41.7219534227925, 44.23396087461903, 43.71400363983647, 42.564188280413234, 42.352764683385054, 41.593574247052594, 41.58399974146197, 39.87731764393468, 41.10255625940139, 39.944021471085094, 45.547813677018695, 53.84211647895075, 50.73250063004033, 55.379960152410696, 54.73747591818533, 51.02903181506742, 50.52196741104127, 42.347453794171734, 40.299498035061745, 42.659317524202415, 42.40126871293591, 38.46129494328653, 39.128027269917155, 39.8113904460784, 43.91755503992881, 43.63789789138302, 47.07540819721837, 46.902004134270456, 44.14314231564922, 44.852820673296534, 43.13426556125764, 42.8653125609121, 42.40871337152297, 40.51892326724145, 39.00886174171202, 40.6526800124876, 41.919413382007235, 41.29244212181338, 40.08770573523737, 44.878994649456395, 56.30514921680574, 56.816806716303674, 57.841639672556234, 55.59170146142283, 57.04667329788209, 54.696632277581, 54.941639208024554, 45.15725935659101, 39.85351670172907, 41.2656601782768, 42.32688096261794, 42.250681077280355, 40.600186932471495, 39.87004164726504, 42.11722635453747, 45.186135845799605, 42.91065123773391, 43.95999900756344, 41.73493646806286, 44.059536995426306, 43.36733279689666, 42.99102060256466, 42.57126423620409, 41.09237770880423, 41.62028558792607, 43.30038578279557, 39.81005291784964, 42.40089216539937, 42.16494591005387, 41.5250700519931, 44.14348356185421, 45.57783942068777, 44.58934722408172, 44.65388982526718, 44.238177422554266, 42.53983036164315, 42.94861193626158, 43.6766234520943, 43.675450663412775, 43.23645114898682, 44.617345102371715, 46.185673436810895, 47.33933664137318, 57.37763112591159, 60.620886048963, 65.33688114535424, 62.720291537623254, 60.50805514858615, 57.03905605500745, 69.18692281169277, 59.10395253089167, 80.41382097428846, 18.104350643773234, 0.15352357569481098, 6.24757033201956, 3.1785492983556565, 0.3838134514949014, 34.39790771853539, 82.55762377092915, 63.82923187748079, 74.30877731692406, 62.76439859021095, 68.74653477822581, 38.47377984754501, 62.59175154470629, 67.3903674464072, 62.24953259191206, 4.178036633999118, 0.3067849348148992, 0.24043459595451433, 0.1499312974873089, 0.1808716428856696, 0.220888429471562, 0.12511995425748249, 0.23470566788267708], [0.007192243149714365, 0.05145849359612312, 0.06931535959724458, 0.0591105398451609, 0.1086809944301363, 0.08248818782909263, 0.04583796313513191, 0.037055132805459925, 0.023016879943409757, 0.11206661275918446, 0.09124396759415827, 29.29227221396662, 55.27210673978252, 52.39515412238337, 35.156470575640284, 24.76549421587298, 44.10911183203421, 62.84873739365609, 58.93205073571975, 58.65390762206047, 50.985768072066776, 59.37087766585812, 13.343872927850294, 0.5730397734911211, 0.5547497000905776, 0.06236679656731506, 1.1430143372666453, 53.15880037123158, 59.24821338345928, 51.92661131581953, 61.78503374899588, 50.654492532053304, 60.25334819670647, 56.38250227897399, 52.1647580208317, 42.60094088892783, 41.99013371621409, 40.46203321026218, 39.51732643188969, 38.63123163100212, 40.69574763697963, 38.3068359282709, 38.86349870312599, 37.741747902285674, 37.9498767083691, 36.76962375640869, 38.56884241104126, 39.25545330970518, 38.45773343117007, 38.64599543233072, 39.33121781195364, 39.12792921066284, 37.97921211488786, 38.12100971898725, 39.401459616999475, 35.2049236143789, 38.03845951634069, 37.567763328552246, 39.075024281778646, 38.911206491531864, 40.55280862316009, 40.28070988193635, 39.008653856092884, 36.9706295382592, 40.11322467557846, 38.57744024645898, 39.13159662677396, 38.67152613978232, 36.29769986675632, 35.0409959977673, 36.563683632881414, 43.11130008389873, 45.96338095203523, 47.641304231459095, 48.37862745408089, 50.74415791419245, 52.418668731566406, 45.69966823823991, 42.27898882281396, 41.14181134008592, 39.7224977708632, 38.42674670680877, 37.36596130555676, 37.61706359924809, 40.112353909400206, 39.83084147976291, 40.60370922088623, 40.51748767975838, 43.001461951963364, 43.29238807001422, 41.225863810508486, 39.088462321989, 38.04288787226523, 37.93281439811953, 39.92130310304704, 40.068533189835094, 39.433995677578835, 41.25889801209973, 42.11214296279415, 41.23851737668438, 43.845336360316125, 49.7471502519423, 52.57939961648757, 51.962630441111905, 50.15153092722739, 49.99600502752489, 48.24515311948715, 49.31560716321392, 43.265794400245916, 36.57985948747204, 37.98833554790866, 37.24858045578003, 37.28820816163094, 38.196723230423466, 36.77035331726074, 39.317097279333304, 40.41665138736848, 37.92714657322053, 38.39587373118247, 37.544566431353175, 37.701245507886334, 37.77184032624768, 34.706257004891675, 37.12109165806925, 37.08411155208465, 35.06837021919989, 37.37756367652647, 36.392546699893096, 36.89322156290854, 37.22666225125713, 38.32270191561791, 38.994870647307366, 39.897451170029186, 37.84576131451515, 37.84804413395543, 40.89165041523595, 40.05029024616365, 40.23349238980202, 38.517431905192716, 39.10411650134672, 40.050098050025206, 38.1765857819588, 39.21960676870039, 39.988932609558105, 47.47835720739057, 53.51482606703236, 59.57260124145016, 58.48469265045659, 58.79296741177959, 56.851692276616255, 59.8570123026448, 62.56865270676152, 52.94081464890511, 0.9555995067761791, 0.11720541564206924, 1.7545760759422857, 0.5741415917873383, 0.030671902444033377, 35.370412334319084, 64.37379806272446, 50.14007368395406, 57.83834880398166, 47.82660092076948, 39.7142372592803, 25.08505363618174, 40.45197625314036, 58.77710534680275, 32.82504120180684, 0.0897130404689139, 0.04543213954856319, 0.02640967077064899, 0.07022600831283678, 0.03725254217222814, 0.031024011775791168, 0.058605726207456285, 0.05904568667193094, 0.05793648711856335, 0.052719665841469844, 0.08000021004268239, 0.061466761999913765, 0.056137004041022835, 0.024594168794611772, 0.03442475076524481, 0.07449828914456791, 0.022561323844016563, 0.1524673702736055, 0.17108592685432206, 38.904730658377375, 61.68620963250438, 51.41325543003698, 38.398591933711884, 42.183647771035474, 51.88200219984978, 66.47164637042631, 65.43997280059322, 63.95885444456532, 55.157914776955884, 65.3891271160495, 13.925115235390203, 0.864543337975779, 1.4355774319941, 0.4783666278085401, 1.991320043321579, 57.71961473649549, 62.73204688102969, 56.2853334026952, 65.63198458763861, 53.44161895013625, 60.824264864767756, 57.8216395070476, 54.428757929032855, 45.65008947926183, 44.4229995050738, 40.53274177735852, 40.87387423361502, 41.44527727557767, 43.031605366737615, 39.216810118767526, 41.58358397022371, 40.44526507777553, 40.27080589725126, 40.698811008084206, 41.17613600146386, 41.783777821448545, 41.01277712852725, 40.07182013603949, 41.787186361128285, 41.93520876669115, 39.24955406496602, 39.99850319277856, 40.07752718464021, 38.63928033459572, 40.37598425342191, 38.75606890647642, 41.13091499574723, 40.53952747775663, 42.21788221789945, 41.404806260139715, 41.59978728140555, 39.497624366514145, 42.808681380364206, 41.12925191079417, 39.53206277662708, 39.81687784194946, 39.18602735765519, 37.11072483370381, 38.7085376247283, 44.922136798981704, 48.0525412098054, 49.55976686170025, 51.92920400250343, 52.85110612069407, 52.98429804463541, 46.18337885026009, 43.46829852750225, 42.04583137266098, 39.10952937218451, 40.812677414186545, 38.34443969111289, 38.34261578898276, 41.21340636284121, 42.37474956820088, 43.27603178639566, 43.14546000572943, 44.90688662375174, 43.557999210972945, 41.92337889825144, 41.08722763676798, 40.34277354517291, 39.10282604156002, 39.1468075783022, 39.590635530410275, 40.74633444509199, 40.27174334372244, 40.20951494093865, 40.719709396362305, 45.41098571592762, 51.763593689087905, 55.122040779359885, 56.19247521123579, 52.88639176276423, 51.124419935287975, 51.321052274396344, 50.68712665188698, 44.230136563701016, 38.45181065220987, 40.408481090299546, 38.594251525017526, 40.59936715710548, 39.57857424213041, 39.32352604404573, 40.546430849259906, 42.52935371091289, 39.58467352774836, 41.494836422704886, 39.81400666698333, 40.04754066467285, 38.722367901955884, 39.248565627682595, 38.14764653482745, 39.73857556619952, 38.35233542226976, 39.41435244775588, 38.589097530611106, 39.48552385453255, 39.335905044309555, 40.21568875158987, 40.73383777372299, 42.97586064184866, 40.100551497551706, 40.45642814328594, 42.48605858895087, 41.197324645134714, 41.693390723197695, 42.09491199062717, 40.67229186334918, 41.939774405571725, 41.290798648711174, 42.35072505089545, 41.748602005743216, 49.10214785606631, 56.863298569956136, 61.00214827445246, 60.124847427491225, 61.085663380161414, 57.404311087823686, 63.49666587768063, 66.89322271654683, 57.44627260392713, 1.0866281822804482, 0.12181521949147987, 3.490303692317778, 0.5475819363228737, 0.018816739696288304, 38.546457444467855, 71.67516462264523, 56.024699749485144, 62.39297366911366, 53.59523465556484, 48.74170164908133, 27.438054084777836, 45.947075659228915, 65.33817160514094, 41.42391212524907, 0.1752573062455462, 0.04724455802070518, 0.05053776316344739, 0.05725958331998798, 0.048123973331624464, 0.034858413986981876, 0.04178488687161477, 0.07984820287674665, 0.1590853893468457, 0.1527786777625161, 0.17550407848771543, 0.15942432196630588, 0.1313059993328587, 0.14391713955950353, 0.15004121578268467, 0.20880814221116806, 0.1646917127072811, 0.27987848666887133, 0.31382935842679394, 45.54223214426349, 71.15229698919481, 65.4111159232355, 46.700241334976695, 36.70298660955122, 57.03449826086722, 73.08682564766177, 69.87427896068942, 69.71976111012121, 61.66034160121795, 70.92000638284992, 18.051857563757128, 1.7550970157307966, 3.8451720437695904, 0.40296258525021617, 2.7710648025235822, 57.44326806837513, 67.45270959792599, 57.92798280715943, 65.83380622248497, 54.80520740632088, 64.74064557783066, 61.12655016683764, 58.37046146392823, 47.215621163768155, 48.10626199168544, 44.06816228743523, 42.703157855618386, 42.59605361569313, 47.89655247042256, 39.96334306655392, 43.17277931397961, 43.22704530531361, 43.3751343911694, 41.22633057255899, 44.4249685349003, 44.8571745041878, 43.77745189974385, 42.690449376260084, 44.748720968923266, 45.2115684939969, 42.928705907637074, 43.158862744608236, 44.211022853851325, 40.04295933631159, 43.47200908968526, 44.14023976172171, 43.67697646540981, 42.0069214605516, 44.62211862687142, 43.908545355643, 43.65671742346979, 40.38842993397867, 45.25815840690367, 43.66927293039138, 43.09069587338356, 42.71463078837241, 42.332823353429, 38.79437085120909, 40.84105576238325, 47.52706520019039, 54.50944108347739, 54.086742939487586, 54.702386394623794, 55.47779975398895, 56.2856589594195, 47.354979053620376, 45.19623202662314, 42.47169879175002, 39.701650373397335, 41.00238284757061, 39.67104804131293, 39.88941815591628, 44.26223331882108, 43.50169358714935, 44.193160380086596, 43.56066250031994, 47.505386260248, 47.463664008725075, 45.81642150878907, 42.166193223768666, 40.72427895761306, 41.187922723831676, 41.36029520342427, 41.73519926686441, 40.25392009365944, 40.40681408297631, 41.48584635026994, 41.78990064128753, 44.223539137071185, 52.0989171151192, 56.1071793494686, 58.59010242646741, 55.402482401940134, 54.13669432363203, 53.63306591587683, 53.917751542983524, 48.12771735652801, 41.52681550671978, 43.66577417619767, 39.54234330884872, 40.56277536576794, 42.3560594743298, 39.89697264086816, 42.617454067353286, 44.62106743166524, 42.1747753697057, 43.9051015146317, 41.97313808625744, 41.938083864027455, 42.692563533782966, 40.41012848577192, 42.69328524989467, 43.22268362968199, 39.51434150818856, 42.18233377702775, 41.47858996545115, 41.2946778728116, 42.40009592425439, 43.1487940203759, 43.223432802384906, 45.648971603762725, 42.85307868834465, 41.06700781852969, 45.464522146409564, 43.02987167912145, 46.89395543067686, 45.184743404388435, 43.42828250700428, 44.613407042718705, 43.77319612810689, 45.74358701705933, 44.94084650470365, 53.493943368234945, 58.62791407492853, 64.72343421751454, 61.96202678065147, 62.9807290723247, 60.099787404460294, 65.66435590867074, 69.1150414559149, 58.405095992549775, 1.8792574372022384, 0.2438419405370951, 7.628176481493059, 2.2433675056503666, 0.13514443691219055, 42.1401761424157, 79.05476677802302, 62.463458661110174, 68.75055913002261, 59.92472417892949, 52.591888443116225, 36.27250256076936, 54.5883866279356, 73.5335365418465, 53.42549016398769, 0.8106697062330862, 0.22460591708940847, 0.150316103451675, 0.1711718819194263, 0.12258621803935497, 0.1092343780422403, 0.11346505263880377, 0.22446733178390613], [0.06986102870395107, 0.03445022701916676, 0.030877625779999845, 0.00966775285515694, 0.028121540202729167, 0.08249027158824668, 0.059047073291073886, 0.022416042930056012, 0.04312658644912224, 0.08976296641893926, 0.009122849836374724, 28.30427815837245, 60.98576845661287, 45.327956984120036, 14.646088057948699, 22.75762704110915, 44.79428322084489, 62.21431363013483, 58.028387638830374, 58.73465353442777, 50.06943571952082, 59.49901757701751, 24.720500707626346, 0.04018588900385846, 1.3186590541755001, 0.5679565043218675, 0.2227140169951224, 16.797567913609168, 74.08558660937895, 56.336622315068404, 57.89097524458363, 52.898017667954974, 59.92356315735848, 47.07193689961588, 48.261666297912605, 39.564281125222486, 41.979959087987105, 37.556192336543916, 41.63073478206512, 41.022092757686494, 41.268366613695704, 37.082570060606926, 39.47065807157947, 37.54566077263125, 39.19348770572294, 38.84445951830956, 40.775916960931596, 39.51973476717549, 40.80972779181696, 38.03919692193308, 40.58068883034491, 39.075310614801225, 39.41417201872795, 36.3518403422448, 38.79542204641527, 35.84535644900414, 38.23975947595412, 37.49905909261396, 39.18266588641752, 37.55933415505194, 39.533725861580145, 39.494576684890255, 40.15245229967179, 38.31265280323644, 40.55045127868652, 40.02021351168233, 40.19346460219353, 38.607054141259965, 39.18662355792138, 34.65608596801758, 35.66830458179597, 40.038707487044796, 46.27258923745925, 48.22168557874618, 48.72009723417221, 51.537571030278365, 48.24927160816808, 46.10044033296647, 41.27261454059232, 39.28764812407955, 41.67776007806101, 38.59742080011676, 39.061492104684156, 38.61123146549348, 39.63677044837706, 40.20555726943478, 40.92978369805121, 42.744319208206676, 42.26879850510628, 41.2360776624372, 40.9221625328064, 38.836077413251324, 39.85590150279384, 37.75394647352157, 39.24827144991967, 37.519859421637754, 38.4356544094701, 41.69684240894933, 42.67492855748823, 40.82983386132025, 43.93480170157648, 51.5794619437187, 49.88912044032928, 50.11262493748819, 48.84944915771485, 50.729923632837114, 50.73075125294348, 45.68034664277108, 45.46554588502454, 38.51253678721767, 36.88507480006064, 37.34174851448306, 37.89876822502383, 38.07653396360336, 37.410750850554436, 37.79242100254182, 38.76759283004269, 40.74514988929995, 39.264341400515654, 38.5769695620383, 38.96659035836497, 37.63869154837824, 36.704096640309984, 35.252705927818056, 35.873503377360684, 36.81934764308315, 37.69343999124343, 36.417347846492646, 37.8272359601913, 39.143928558595725, 37.716593742370605, 39.005249238783314, 39.676472679261245, 42.07290749396048, 43.4610225308326, 48.47804384846842, 50.44861124407861, 53.583687197777536, 48.21195417834867, 42.922284987664995, 40.21437867995232, 40.384931179784964, 38.20409336397725, 40.22804814000284, 39.6309692628922, 47.10375124408353, 52.556073281072806, 56.305886622398134, 57.314422130584724, 60.75199911671301, 57.77483778615152, 65.29346050754671, 19.201186549279, 0.14785018899748403, 1.4517910393976396, 0.4546826825507226, 0.10365754140601044, 0.024160871379858544, 39.72882063158097, 61.368807515790394, 52.26116203492688, 67.44669268208166, 56.07337636332358, 31.463396280042588, 30.27430622808395, 39.28241175989951, 61.27976971287882, 20.7422387215399, 0.255414939695789, 0.08517507268416305, 0.05240879119223645, 0.027476337122460528, 0.0267184903890255, 0.007024891721460248, 0.0009217167708782419, 0.03050540472500988, 0.09902631773823693, 0.06556578821712924, 0.07542846544135003, 0.07528041894998282, 0.07518095775477349, 0.0751767902364654, 0.09008112273389295, 0.041859427226647254, 0.0621952579897498, 0.06529984079421529, 0.07195407284363624, 34.00889881195561, 68.23793672746228, 58.18119141363329, 21.25147023508626, 27.613799802718628, 53.21630231795773, 66.6009355360462, 65.53121889791181, 62.72550828995244, 55.6597859628739, 66.18042607461253, 25.528234397211385, 0.106662092279763, 1.0687360455912929, 1.4873193781222067, 0.5398397291860273, 19.296986518367646, 74.68177903083064, 56.905126725473714, 59.73738393475933, 53.38551728956161, 61.63164161866712, 50.36398610761089, 51.22982971129879, 41.761208503477036, 43.837138606655984, 39.58934507062359, 43.188970858050936, 41.8411660194397, 43.299471870545425, 38.67498567027431, 40.69707732046805, 38.59392204592305, 40.377031526257916, 39.77928584621799, 41.852419299464074, 42.599611205439416, 41.42558697731265, 40.08294790021835, 42.87579313401253, 40.72893873337777, 40.26918595837009, 38.22497606277466, 40.596460680807795, 39.49757729807208, 39.53990751697172, 38.73278571713356, 39.794371281900716, 40.38442519403274, 41.4907963814274, 40.51072551358131, 41.68555382759341, 39.23985012115971, 41.97706830117011, 41.540802678754254, 42.07147582884758, 40.20434133468136, 42.762848484900694, 37.77050279801892, 39.38543281247539, 43.53990531736805, 49.32165153564946, 48.86041610471664, 51.1367283328887, 52.57947414152084, 51.71730187631423, 46.36080726500481, 41.97351071142381, 42.006827323667466, 40.93643211549328, 38.80442780833091, 39.00031489710654, 39.40001226240589, 41.42326493417063, 40.570843681212395, 43.0839023282451, 44.30051565170289, 45.65506304464033, 42.76777105946695, 42.84253143495129, 41.86822252888834, 41.34106382246941, 39.27377470078007, 39.724878649557795, 39.16709407683342, 39.08808185208229, 40.92858345277848, 43.544984786741196, 41.882849047260905, 43.55349240764495, 53.110621898405014, 52.55677930770382, 52.88713701309697, 53.04901323010845, 53.79574229640346, 52.129484145872055, 50.27723504650978, 46.46098459920576, 39.42751592205417, 39.23026777082874, 40.28961366222751, 39.35829001088297, 39.62971410443706, 38.312299789920935, 39.31579897480626, 39.759505333439, 41.340840247369584, 41.57255818766933, 40.384786052088586, 41.46664242590628, 39.308464142584036, 38.809381761858546, 38.524794194006155, 37.99659605949156, 38.57539276922903, 39.73454336966238, 37.92843311063705, 40.82561731338501, 41.743950074718846, 40.08738017851307, 40.91812249152891, 41.092832703744214, 44.192168020433, 44.93648090670186, 50.25898425809799, 52.2381494891259, 54.14827708275088, 50.96251626168528, 46.19127850378714, 40.97902513319447, 41.74263608071112, 42.53625708241617, 42.527090503323464, 41.783546401608376, 50.188444352919056, 56.03324267172045, 59.06397573409542, 60.48172819998957, 62.032656900344364, 58.78850767689367, 64.82424305331323, 22.70466131548728, 0.2793796102125799, 1.9277402614393544, 4.859492067367801, 1.0372307103487755, 0.06373368511577288, 44.446804369649584, 67.13873171037244, 57.27253121714438, 71.04072124727311, 58.179375356243504, 40.504610538482666, 32.149397250144716, 44.67358404590238, 65.84452213779574, 30.687186679532452, 0.04512187010878998, 0.07458070488346201, 0.09120823725336984, 0.01873960038797269, 0.05271154913991209, 0.007421919182243367, 0.03777126796663769, 0.04939082611892973, 0.15460841748262608, 0.1841322203437167, 0.14387946335538743, 0.2002168338625662, 0.270817106769931, 0.21771083465747296, 0.23823042310053305, 0.2289418215232511, 0.2803189872253326, 0.26386485885708566, 0.1069863543154732, 40.02742675042922, 76.7336493153726, 61.97778686400383, 23.69640907933635, 32.86339217616666, 59.11528818068966, 72.33564469122118, 69.09571986044608, 69.60218414183586, 60.13003280085903, 72.65879308023761, 32.58791235185439, 0.27617782234184207, 3.5947973497452277, 1.5236160111042762, 0.30995261645124805, 21.268624721034882, 78.86116643105784, 58.1281570465334, 62.379680756599676, 56.13365534813174, 64.89266095622894, 52.14713873401765, 52.19290887155841, 43.775396577773556, 45.68471616314304, 41.91156471929243, 45.83389566790673, 45.100949810397246, 44.62597039438064, 40.39571769775883, 42.85440837183307, 42.50811015405963, 41.72923334183232, 43.11255524235387, 43.536943927887954, 45.78610158735707, 44.37153800841301, 43.384532390102265, 45.57394058473649, 42.64705227267358, 43.4961748123169, 40.75998429329165, 44.55625418693789, 42.33770670429353, 43.802762954465805, 41.63021702920237, 43.5136725056556, 42.80716342310752, 42.77791430873256, 43.07168022278817, 43.959010570280014, 40.83602336145217, 43.74183677857922, 43.813902485755186, 44.45959914115168, 42.963450262623454, 44.556285565899266, 40.07766054522607, 40.69472389836466, 45.39674751220211, 52.022462275720414, 53.29384365389424, 53.844391453650694, 56.719410342554895, 52.8390879784861, 46.49192817749516, 41.416804790496826, 40.983935940650206, 41.60682793586485, 39.36010214590257, 40.37374065768334, 41.51306367689564, 42.77665522790725, 45.082628419322354, 45.384031188103464, 45.48453800139889, 49.4685717551939, 45.47223352616834, 44.995430208021595, 42.82509257716518, 42.97609990642917, 41.156084845142985, 41.2327907162328, 40.577401884140514, 38.60273168933007, 41.24118066603138, 43.1075777546052, 41.85194077030305, 43.07165668856713, 53.776126523171705, 56.01604307851484, 56.494329052586714, 54.51058641556771, 55.88250206362817, 56.513329013701416, 52.99949330668296, 50.12090113855178, 43.27096016176286, 41.77110072105162, 41.82755931731194, 42.190810018970126, 41.30685683219664, 41.13999920506632, 41.19417890425652, 41.52096333042268, 43.561509732277166, 43.551366483011556, 41.943571259898526, 44.342312428259085, 42.64092553046442, 41.04868250508463, 39.47804389461395, 39.81191996605166, 41.1935160236974, 43.882861675754675, 40.95901712294548, 42.60024270703716, 45.57813752082087, 42.02302279010896, 42.280577382733746, 44.66314269650368, 46.864957347992934, 48.10598350340321, 52.44852581331807, 56.12431226238128, 57.63282052932247, 54.333310973259714, 48.935698155433904, 44.804081301535334, 44.16113030525946, 43.66943766993862, 44.764516353607185, 43.43568794188961, 52.628099764547045, 59.1878677183582, 61.876091572546194, 63.65290957112467, 64.42557334899902, 59.91035261461812, 64.8078397012526, 25.368713563488377, 0.31382117660776265, 2.972290482251875, 10.482891221200267, 1.6842178255319598, 0.18777945769890664, 49.07574638243645, 73.36235646278628, 64.87149584677913, 78.48656439012098, 63.55078674131825, 46.06136568130986, 41.8425545384807, 52.43329917230914, 73.86799704643988, 41.90562232848137, 0.4288362243002461, 0.17306247966424113, 0.14201013221135064, 0.21202710577316825, 0.15265457151878267, 0.13168709743167126, 0.14146031090809455, 0.10913620387474376], [0.016119568195614605, 0.02771989371056759, 0.0642621402268208, 0.05096133700722168, 0.05307147639893717, 0.11326503474265338, 0.0292890926732892, 0.006110450391837907, 0.07937551896658637, 0.07851376198232174, 0.07907100667756412, 17.754251649302823, 60.431725825032885, 42.59903069465391, 44.12051416212513, 44.28525763173258, 31.16110705560254, 60.60800498531711, 60.991903043562374, 59.06610165872882, 54.66397070115613, 55.01955316912744, 42.56615731023973, 0.14618362600524581, 1.158512602410009, 1.2178693399313958, 0.2228380313083049, 0.03328190463024282, 40.38967724769346, 56.296865171001805, 50.91982910709997, 59.763471618775405, 51.79485890173143, 47.37281799316407, 40.83110470925608, 39.9702032919853, 38.79033865467195, 43.40627408796742, 43.50236039007864, 46.15886403668312, 42.219156988205455, 40.06175141180716, 38.12914471472464, 37.799336141155614, 39.36947661061441, 44.67025395362608, 47.69036131520426, 52.565647786663426, 49.12935733795167, 48.09322011086249, 42.163074939481675, 37.98421705922773, 38.79527299634872, 39.852120337947724, 37.47008062178089, 37.12911290507163, 37.8378342043969, 38.725078259744954, 39.279728858701645, 38.13823676878406, 38.06149167399253, 39.4377846871653, 39.559433075689505, 38.625399066555886, 40.521115872167776, 39.21127957682456, 38.72490567545737, 38.75352328823459, 37.86119191877304, 34.03407650609171, 37.9192743762847, 41.71873315688103, 49.02995271067466, 48.066202825115575, 48.09976654668009, 49.24607922953945, 50.31934953504994, 47.065241413731734, 43.25814970078007, 40.3977769420993, 39.11120814661826, 39.104081200015166, 38.63696221382388, 40.01980166281424, 39.9028326619056, 41.423990572652514, 41.67615582866054, 42.2501790138983, 41.14785179015129, 39.15984161438481, 39.36071403564946, 42.303201613887666, 41.44394366971908, 38.40398127032865, 39.65506046049057, 39.81337516538559, 38.478227815320416, 39.49519249700731, 40.31960018219487, 43.622694784595126, 42.64422424377934, 51.09866565273654, 51.25903567960186, 51.83141146936725, 50.04766264269429, 49.53719754372874, 50.18664790738014, 47.00562138711253, 40.17002844041394, 36.67650276614774, 36.73298489662909, 37.9048635882716, 38.62314762607698, 39.01705949537216, 39.88665680731497, 39.29802279318533, 39.967143843250895, 38.29220548752816, 39.265800522219756, 37.17920549454228, 37.20391642662787, 36.98753495370188, 35.490268199674546, 35.51329643495622, 36.47197861825266, 37.087814269527314, 35.40209331820088, 37.10545316819222, 37.12554354821482, 40.06878029915595, 38.92555844399237, 40.52938030612084, 42.742558063999304, 44.78904293429467, 50.534291498122684, 54.48071364433535, 54.52068651876142, 55.68977248284125, 56.02378191486482, 55.65442800521851, 48.71601012445266, 40.561994814103656, 38.10357478357131, 41.48143368382608, 39.66551749936996, 40.901801509241906, 46.54984197308941, 54.593242522208925, 54.66966598264633, 59.176073151250044, 59.576009781129905, 55.19043907042473, 3.5690538537117744, 0.23112313431357187, 0.8575093638031714, 2.662746589029989, 0.25291361665773776, 0.1513854089763857, 46.78401531711702, 61.00203844808764, 55.51147330191828, 64.26555633544922, 50.21789350817281, 28.806147383105372, 23.876626299273585, 32.15361772045013, 61.471161765436975, 12.356027922322674, 0.15746109908626926, 0.02899313567116136, 0.036936419820713426, 0.01594757092290468, 0.03302636834221982, 0.14897595520221418, 0.08476705425569127, 0.1248358888551593, 0.020301452567500454, 0.040857686826418486, 0.01259966901758866, 0.03695985061987754, 0.03125239599255785, 0.0303741317287448, 0.033682174079360507, 0.05723398832243778, 0.0625064390741529, 0.07268846771048923, 0.04512155984318064, 24.796065168996012, 66.88199689311367, 47.276806216086115, 32.53962013029283, 33.39163541793823, 44.71092108757266, 66.80188640471428, 64.94632682492657, 63.01881136432771, 60.04320329235446, 59.5485100438518, 44.589323689860684, 0.06790158263738118, 0.9236617915091977, 1.810219799799304, 1.1554340321210124, 0.4526899652856012, 43.395671921391646, 55.51694108593849, 53.88949871063233, 62.78068034879623, 53.59917271521784, 51.04190111160279, 44.24160949645504, 42.385532163804584, 40.16197581445017, 44.44043051811957, 45.98126303765082, 47.21820992808188, 44.685041289175714, 40.5706593298143, 39.869700401060044, 39.611008321085286, 41.1445923005381, 48.06770901526175, 51.61426905662783, 53.76916039374567, 51.04343868071034, 48.30833858059299, 43.25093253966301, 41.16030139307822, 40.931062390727384, 40.89882050791095, 40.67428834976689, 38.64845475842876, 40.11161650380781, 40.66943637786373, 42.632221791052054, 39.49657709367814, 39.85191637469877, 41.57052639992007, 41.819577294011275, 40.791002396614324, 41.32619803951633, 42.149985990216656, 40.54423432196341, 40.34325991907428, 39.85975327030305, 38.191871258520315, 41.2489273471217, 42.30153852893461, 49.6085689913842, 51.6510412769933, 50.66339631234446, 50.942786739718535, 50.97018057300199, 46.89055081336729, 42.58713414592128, 40.50406140665854, 39.873563935679776, 40.85251300565658, 38.785212116856734, 41.65448081108832, 39.62798826156124, 41.20281988574613, 44.41375840094782, 43.55012309166693, 42.77258773003855, 42.98270910016952, 39.579849012436405, 41.780749751675515, 41.95887242594073, 40.61365635164323, 40.85514099367204, 40.09471893310547, 39.28554965603737, 40.438177354874156, 40.39346233490975, 43.075877158872544, 41.89214506456929, 50.52941206962832, 53.64028307699389, 53.22319784472066, 50.377796772987615, 51.00452092386062, 52.391647523449315, 50.157477240408625, 41.79484282770465, 39.82852728136125, 37.74506622745145, 38.518985163780954, 38.86524808022284, 40.02869367599487, 42.28523715849846, 39.951297467754735, 40.17884985093148, 40.28424393746161, 41.04492879682972, 40.292261262093824, 38.208560943603516, 39.33721119357694, 37.182225719574966, 38.96006745676841, 38.620907952708585, 40.35072811188237, 37.09425872372043, 38.25855939619003, 38.25662959006525, 43.193269775759795, 41.374725603288226, 42.422559338231245, 44.32451271241711, 46.97735678765082, 51.49541339566631, 55.627555847167976, 56.751016801403416, 56.512211138202304, 57.155197435809725, 58.904119537722686, 49.33666244629891, 42.94572114944459, 40.351465517474765, 44.14704899634085, 40.36040852146764, 44.596164303441206, 48.127756580229736, 57.86151039984919, 56.127175592607074, 61.87656617933705, 59.82881830584619, 58.603611069340865, 4.580891997583451, 0.49013425926527676, 3.5383475788177985, 3.7908653578450604, 0.5514704760524535, 0.12423665488078711, 49.18052465684953, 65.19921771941647, 60.8235784499876, 70.71234041644682, 57.11773487829394, 37.735421119197724, 26.568747028227776, 35.92248201370239, 70.13258272601713, 17.980778332679503, 0.11326619919629828, 0.03792775674693046, 0.028507481892442996, 0.12203077365073467, 0.024249425398245938, 0.06577305330504334, 0.05546943885424445, 0.06334466183738363, 0.1335013928192277, 0.08702511373426645, 0.16408221315472357, 0.21122324971422074, 0.14323882998958712, 0.1799603353344625, 0.1007465068851748, 0.1290412136023083, 0.21278205477902967, 0.1223171373168307, 0.11027276425832704, 27.84831439295123, 75.84766434084985, 55.18792875351445, 56.69897087158696, 58.089694284623675, 47.369531046959665, 71.30172360327937, 72.4614429473877, 69.13426106975925, 65.69287153982347, 64.60779490009432, 51.591735039987874, 0.2661462993391099, 3.914191785358614, 3.5366717461616766, 0.6771009283200388, 0.4068960790191928, 44.393711166997115, 58.914855064884314, 57.45976555731989, 65.17947250796904, 57.15117308401293, 52.097638422443026, 47.801489906926314, 44.187708285547075, 42.29667086755076, 47.433818694083925, 47.78245856685024, 50.10381921645134, 46.45935681558425, 43.36763481939993, 42.99424086847613, 41.90820717042492, 43.67327767033731, 49.53473429526053, 54.274204777133086, 57.02948154941682, 54.02534215681015, 52.8288152910048, 47.03228958191411, 42.81832256624776, 42.65777995509487, 44.18898697822325, 41.84941476391208, 40.37663144450034, 41.53931217808878, 43.43984173190209, 45.99854107825987, 41.864343304787916, 41.347257244971495, 44.114305050142356, 44.44402340919741, 42.885755954250214, 43.33760123099051, 43.34546166081583, 44.15807085652506, 42.303915485259026, 42.424736253676876, 39.325938301701704, 44.372761787906775, 47.222144065364716, 53.7487679912198, 54.43750873688729, 53.45822626544584, 54.678032398223884, 54.13851038102181, 47.66803910655361, 43.635622916683076, 40.843789654393355, 40.04305347319573, 41.705640285245835, 41.38393532845282, 43.55992901709772, 40.41018732132451, 44.5583644220906, 46.873429667565134, 45.1611856491335, 45.41315478663291, 45.10629207857194, 43.57832885557606, 44.999434947967536, 44.640804798372336, 42.13180580446797, 42.76607659555251, 42.82950132123886, 39.83527375805763, 41.03595049150529, 40.63025582221247, 43.82774845246346, 42.27541946595715, 50.69798377252395, 56.702006786100334, 55.55701986435921, 54.81841794906124, 53.878347412232436, 55.73742143569454, 51.970671299965154, 44.42172081239762, 41.82887723368984, 39.70980498098558, 41.4263165381647, 41.694496831586285, 42.363963050227014, 45.322504889580514, 42.193061459449034, 44.86563113427932, 42.80038948981993, 43.79831106432023, 42.073072233507716, 40.81120652537192, 40.324208967147335, 39.658076763153076, 41.272791047250074, 40.73729730421498, 42.66595417453397, 39.96938743898946, 41.99811573951475, 41.218344626888154, 45.97675231195266, 42.67401856760825, 44.41890847298407, 47.45111634654384, 48.57353395031345, 54.00239236893193, 58.21099750457272, 59.422476445474935, 58.69684973070699, 61.33252951406664, 60.947639096167784, 52.92010061202511, 45.198134376156716, 42.79694172643846, 46.34414111414264, 42.660729577464444, 46.43186884541666, 50.50246538654451, 61.64350678843837, 59.464281066771484, 63.58679802187028, 60.15224126077468, 59.539767080737704, 6.112107355748454, 0.6600175966178218, 4.637913944259767, 10.42944206345466, 1.8003246404470938, 0.35651378573909887, 56.321038738373794, 71.15652530424057, 67.31181021659606, 72.21032496421569, 61.912263670275294, 39.40814725814327, 35.08143955661405, 45.26974508839269, 78.76523310138334, 28.84453561998183, 0.1693844608962536, 0.1602976775217441, 0.1493348520729811, 0.21781923609875867, 0.14895075090950535, 0.32793597889042675, 0.18326974323680326, 0.2220048953688914], [0.05769849424400638, 0.07034999198250233, 0.02512917012697266, 0.04742775262603837, 0.07641016115103999, 0.03341550653379771, 0.052460096100525516, 0.0035129241868778467, 0.13442711814516975, 0.038162332869345145, 0.2667694659002366, 13.219467113094947, 58.47152133141795, 48.03594173923616, 45.00502824783326, 65.21513469757573, 44.951966424142164, 44.390663485373224, 68.23143343771657, 56.008261096092966, 58.18898516316568, 49.39031262551585, 56.446083899467226, 1.4410998840485851, 0.532055969440168, 1.8395145117275178, 3.0402945751144044, 0.03667315753597406, 8.382309021488313, 58.34599764116349, 55.04402091426235, 58.3147834193322, 46.65040369956724, 42.711445823792495, 38.29608471162858, 40.576495816630704, 41.26365584711875, 47.88402834246236, 49.28232192993165, 50.68821707079488, 45.188167633548865, 39.16656063448998, 37.96944541315879, 39.52451221404537, 48.38777442132273, 51.68700548910326, 54.37305635021579, 52.3388877222615, 51.52317985411614, 52.16054539526663, 50.14671425665579, 45.96683263778687, 39.8998006697624, 39.17686470093266, 39.29517515244023, 37.46162791405955, 37.2348129364752, 38.22587428554412, 36.69809541394634, 37.85708519720262, 37.878972022764145, 38.64246922154581, 39.18940451837356, 38.871947488477154, 39.906939383476015, 40.28764463240101, 39.08147265834194, 39.50804218169182, 38.35495556554487, 36.60821430144772, 36.46376909748201, 41.82118546578192, 45.62914402254167, 47.02863393291351, 46.98487989364132, 48.355493314804576, 48.08002917997299, 44.85576637329594, 43.91834735870362, 40.39229739096857, 37.50988875665973, 37.28678041888822, 38.11625972870858, 39.143218609594534, 40.722435443632065, 40.480382057928274, 40.47256869654502, 41.11291523902647, 38.58202941956059, 38.454466096816525, 38.75830073510447, 39.09033721493137, 38.71311503071939, 40.234531817897675, 38.847679784221036, 40.347503923600726, 38.781627070519235, 38.625861906236224, 40.49969580865676, 40.19880687036822, 42.10270181778939, 46.780489106332105, 48.78687166398572, 50.766413442550174, 50.11300932976508, 47.32982097133514, 50.88334321975709, 45.88306257801671, 43.422022404209265, 36.77122800580917, 35.76718361146989, 37.5062370300293, 38.29315862348003, 38.50534316032164, 39.20494887136644, 36.508397825302616, 38.980251973675145, 39.25238209386026, 37.69396951121669, 39.00899510229788, 38.88181224946053, 37.17547924287858, 36.823952505665446, 38.40722899283133, 36.90132125731438, 37.60726551855765, 37.76366610680857, 37.33358606215447, 38.641551386925485, 40.8883281677, 41.01311052999189, 42.95189496009581, 45.506311078225416, 49.2741398657522, 48.15562109793387, 52.507937954318145, 52.22428391056677, 54.252635663555516, 50.41685181279337, 55.70558355700586, 58.993012212937884, 51.870458664432654, 42.054805755615234, 38.90568771669942, 40.314399119346376, 40.53977458707748, 40.62441149065572, 47.61649131774903, 54.8130678361462, 53.381979311666186, 63.082608715180434, 46.54466444446195, 0.5780825932179728, 0.09182643190386797, 1.6601493041361532, 1.6654708572933752, 1.0314985340641392, 0.4612992920221821, 51.42187287730556, 57.03504739269134, 58.36992409921462, 60.16110189499394, 59.385712069849816, 25.97689667055684, 17.562504622244067, 39.47323899115286, 55.77917898854902, 10.53318581273479, 0.09893354449060657, 0.11125253708732706, 0.01751707344796629, 0.027744521522113395, 0.02541147544228983, 0.06993550011107037, 0.05948893365360076, 0.04890229184961608, 0.10194172662112022, 0.015046369986638669, 0.05402309549671989, 0.07232243090026802, 0.04212329855128642, 0.12608117243695643, 0.0380523111520996, 0.03932452655487484, 0.060160103284062884, 0.1497558480308902, 0.2973070482332861, 17.291317832085397, 67.681838773912, 56.720692957601244, 50.36960294169765, 50.813603478093306, 41.995899600367395, 54.90864423013503, 72.43291162675428, 60.74693925919072, 62.11337143375028, 54.797213615909705, 60.23260670323526, 1.79921914492884, 0.9867159757883319, 2.501232210666903, 3.5496172837672697, 0.15270242137053322, 9.872640044458452, 60.49019267482143, 59.04328915380663, 61.07069169321368, 48.91252479245586, 44.75438879382226, 40.240897824687345, 44.06002729169784, 43.9641135738742, 51.226295655773534, 52.39675837178385, 52.91902980496807, 46.51860029466691, 41.267033007837114, 40.256995231874534, 41.56776112894858, 48.9253705547702, 54.432488103066724, 55.649293622662945, 56.61278463179066, 54.360120373387495, 56.14197077289705, 50.176139877688506, 47.65846460096298, 41.226612983211396, 41.27337548040575, 40.83984375, 40.28567168020433, 39.00618276288433, 40.51412228615054, 39.192495346069336, 39.565799082479174, 40.012823766277684, 41.96474029171852, 41.583015226548724, 40.60659216296288, 42.03744142286239, 42.040112556949744, 40.66668287400277, 40.874576337875865, 40.07999827784877, 38.579240614368075, 37.81349981984785, 43.16440505366172, 45.66693605915193, 50.10368193349531, 47.67118092506163, 51.16009781437536, 49.71220977844731, 46.5932116200847, 43.429545510199766, 39.020793591776204, 39.83085324687343, 37.81585716432141, 39.226957290403305, 40.52322610732048, 41.43141561938871, 42.0733860231215, 41.371442579454, 42.692618446965376, 40.80950813908731, 41.2448480821425, 40.80642515613187, 40.93730288167154, 40.6082199465844, 39.57194543653919, 41.64023084025229, 41.4695292903531, 39.499993478098226, 39.93292900823778, 39.947433933135, 40.93452584358954, 41.53041232016779, 47.214566046191806, 52.46365831744287, 52.351870767531864, 51.771811054598906, 50.343515257681574, 51.653131900295136, 48.924358583265736, 44.42959300933346, 38.82823659527687, 37.508398255994244, 39.01355289643811, 39.934768599848596, 40.35938478285267, 39.916639404912154, 39.81889786258821, 41.1006695993485, 40.1465569773028, 39.33388110130064, 41.64162328166347, 39.15446012250839, 39.71359006820187, 39.98757939184866, 39.66792975702594, 39.599829566094186, 39.67484489563973, 40.52598353355162, 39.51187825972034, 41.036338806152344, 42.37909947672198, 44.423026961665, 44.35071414516818, 48.247263354639855, 50.90653227221582, 49.585317181002715, 54.600106670010476, 54.2931890487671, 55.374539436832556, 51.633037597902366, 58.21439819951212, 60.75117541897682, 55.06273846472464, 44.402642403879476, 39.48025218902096, 43.27606316535704, 42.978390570609804, 44.02851889210363, 49.51945274106918, 57.754060991348766, 57.05200379894626, 65.9822287098054, 48.53556540704543, 0.8628117341187693, 0.5852180587187891, 5.159544560217089, 6.535883170943107, 0.6286809845797477, 0.5496208946551047, 55.07453695420296, 63.44957782376198, 63.964455589171386, 65.98582160088324, 64.62538280794698, 35.71367071520898, 19.993413148387788, 45.397237808473655, 65.17362425404211, 14.401215468683551, 0.2921237892681553, 0.11854760934628787, 0.025725213345140222, 0.07426950464686079, 0.07635293438309625, 0.005412856473647539, 0.07696326131061201, 0.028515845657356327, 0.16567526234974786, 0.15079132311286467, 0.07969297814152895, 0.15515517443418503, 0.13634851262454065, 0.16006667136905656, 0.09377265529286477, 0.13804643925639892, 0.3089957113467878, 0.2970660982593414, 0.45885951648796763, 20.787840197163245, 78.25379525461506, 61.57428872200751, 56.83324536969585, 70.72072644387522, 60.45288308974236, 57.23718673952165, 78.10338020324707, 65.58931704490416, 68.95318092838411, 57.733131224109286, 68.0781707456035, 2.383099001261496, 1.5834118089368268, 5.5438711374036735, 5.844482568002516, 0.24543661383851884, 11.708735842858593, 63.564307151302216, 59.891156534994806, 63.888189023540875, 51.86486536456693, 48.25206433573077, 42.47302455286826, 45.7208647266511, 48.025876937373994, 52.85272213720506, 54.7359501161883, 55.52594684785413, 49.24995060889952, 42.37308256087765, 42.393788753017304, 44.328870465678555, 52.31999758751162, 56.123519943606475, 56.60169609131352, 59.11252290971818, 57.52797949698664, 57.11283583794871, 53.54384376156715, 52.23341126595774, 46.03845119476319, 43.20314238148351, 42.97152642280825, 42.30351148113128, 41.22420072555542, 44.60211453899261, 41.721859285908366, 43.153175307858376, 42.441441628240774, 43.732274040099114, 43.970703155763694, 41.47872332603701, 44.02164689956173, 42.741773589964836, 42.54217986137637, 43.19823157402777, 43.3410019259299, 41.673492539313536, 41.19640681051439, 47.13722867350425, 49.856062704517, 53.25310591728457, 49.563697076612904, 52.29399619563934, 51.54560404439127, 45.746489570986846, 43.258165390260764, 41.06161063717258, 39.634668057964696, 39.22785943554294, 39.53193726078157, 41.7146852708632, 43.28144465723346, 43.80747372104276, 44.537030650723366, 44.65736504523985, 42.30027552573912, 43.35863690222464, 44.68974421101232, 43.17015917070451, 42.07233875028549, 43.27094447228217, 43.498579225232525, 43.432044059999534, 39.91947920091691, 40.201266196466264, 41.09842600360994, 39.5876153053776, 41.378416553620376, 47.7496361732483, 51.90737601249449, 57.180904649919086, 54.3254073973625, 53.49304514546549, 55.88545168599775, 49.390085128045854, 47.11762466738301, 42.358985562478345, 41.01491089790098, 41.46119425373693, 42.50044192037275, 42.16971551218341, 43.31107424151513, 40.22510244000343, 43.740487483239946, 42.83317658209032, 42.54882827881844, 43.46455658635786, 43.04739290668119, 43.254866676945845, 42.45393045486943, 42.87580882349322, 41.76891596086564, 42.13555559035271, 42.614033760563025, 41.16119569347751, 42.31160725316694, 43.81942518295781, 44.60081623446557, 47.54055030884282, 50.533820813702, 52.51704569785826, 53.321668947896654, 58.41379973196215, 57.92546072313863, 59.26253395695841, 54.53664664299258, 60.447658492672836, 63.12184418401411, 57.22066179398568, 47.08616725860104, 43.946670793717914, 45.34151661780573, 45.30945908638739, 45.58356215876918, 52.68147145548175, 59.316199825656035, 59.94592066734069, 67.10965910265523, 52.98970307073286, 1.518763303756714, 0.7693146253305098, 6.7857077525508025, 11.291792796504113, 3.155165598277123, 0.9462192197961192, 62.48104264659267, 65.50715123453449, 69.99566062804192, 70.7410207871468, 72.89724965249339, 37.640091834529755, 27.64677712994237, 52.89071813706429, 74.37875240079819, 22.543269511192076, 0.43103504986051594, 0.15664967407862987, 0.05264416404609239, 0.18664699588571826, 0.20354828977536774, 0.22692889485868717, 0.1792272964432355, 0.16592848505223953], [0.02238978909689092, 0.09129327301296497, 0.01709101173365789, 0.07541387146639247, 0.024487627031762275, 0.15516134910285473, 0.033622687352040125, 0.006109379783963725, 0.02702140538472562, 0.014732121677708723, 0.11552107940998771, 11.48444785225776, 62.27308250242665, 42.83569866611112, 51.966607724466634, 89.19848672805294, 73.63820891226493, 39.877164671497965, 67.03838179188391, 54.19753420737482, 59.84795554991692, 48.69613547478953, 60.11842650751914, 6.580982092888125, 1.4853449550367173, 0.7976989183695087, 2.334480242383096, 0.1757225820854787, 0.5918126661450632, 55.342932977984034, 55.84727917948077, 54.43821476351831, 44.82131619607249, 43.02396066727177, 40.13850042896886, 46.84458847968809, 51.29563531567974, 52.51015801583567, 54.71009777438257, 54.95350045542563, 44.27115278859293, 38.75757117425242, 37.603833444656864, 47.255931362029045, 52.284978666613185, 54.49866241024387, 47.89009624911893, 48.357403509078495, 49.26602448186567, 51.35143887612128, 51.21456384658814, 51.87761306762696, 45.81156169214557, 40.0806886149991, 38.0052056620198, 38.338720875401656, 37.77044396246634, 35.11150452398485, 36.99321062334123, 38.86510687489664, 38.06448836480418, 38.86831145132742, 40.58814525604248, 41.25020996216805, 39.5196484750317, 38.62941557361234, 38.53523162103469, 39.715535563807336, 40.130506638557684, 34.96263096409459, 36.370855992840184, 40.062453516068004, 45.75822922491258, 45.70433585874496, 47.3136882628164, 49.83972211037913, 47.874383234208636, 46.514528874428045, 42.944638575277025, 38.44570352185158, 37.88707171716998, 38.16714071458386, 39.3718731787897, 40.44143292211717, 41.42230787584859, 39.732778303084835, 39.83487367630005, 39.59657792122134, 40.64199939850838, 38.34228630988829, 37.873190449130156, 38.105155498750754, 37.08497839589273, 39.686349207355136, 40.1355194276379, 40.501421651532574, 41.00571686221708, 39.474870697144546, 40.43039929482245, 39.4367491814398, 39.44238562737742, 44.78881151445451, 48.67739831247638, 48.946947513088105, 50.881158459571104, 47.49778078448388, 46.40440048709993, 49.625878410954634, 42.313901839717744, 35.90433320691509, 34.6563526891893, 36.665994736456106, 39.362255527127175, 39.88135768521217, 37.59552194226173, 38.671377089715776, 37.8973404822811, 38.23018889273367, 37.74069278470932, 37.887028571098085, 36.35534694117885, 36.74832136400285, 36.04281248584871, 35.24799516124111, 38.60075089239305, 37.80250933862502, 37.68079426980788, 39.57222392482143, 39.705572743569654, 39.06310812119515, 41.15919528468963, 43.73876948510447, 48.178806228022424, 47.75224062704271, 48.887343175949596, 51.679694191102065, 52.379621536501, 51.69548957578598, 53.16014574420068, 45.39768888104347, 54.77103179500949, 56.774280378895426, 49.609745702435895, 41.34753573325373, 38.11087039209182, 41.02960409656648, 42.85251386703984, 44.31782507127331, 50.938205411357266, 55.30556063498221, 60.37340410294072, 43.75839310307657, 0.06915553067360194, 0.594084024910004, 2.7790774693412166, 2.4786454871777566, 0.7791763219621874, 2.266351123971324, 54.91663409817604, 56.77324095079976, 59.768198074833045, 60.82831667315576, 50.21283757302069, 32.98918062640775, 29.155067705339004, 41.01040409457299, 54.797711756921586, 5.51434745711665, 0.16336645720706833, 0.012594181912831001, 0.07613697419724158, 0.10320554186980571, 0.09156069132469355, 0.03906310288115375, 0.08423021814275174, 0.04513521919087057, 0.04088693606336752, 0.03630989013359912, 0.02211219522230808, 0.017491907459653674, 0.054183081468387004, 0.10987531018233108, 0.03317813419045941, 0.051448312287609425, 0.040304678597397385, 0.07747103970858359, 0.10140077661602728, 14.738675605866218, 68.27090817113077, 50.234512590592914, 52.710218506474654, 79.66835883355911, 68.96301038803594, 43.94894969078803, 73.49366172667473, 60.09841849727016, 66.05605556118873, 53.530915629479196, 65.96983402006089, 6.579152797499011, 0.8870749031343769, 1.0705291816303808, 4.078539340726791, 0.8467153688111614, 0.796786047998936, 59.5133146162956, 56.02871625654159, 59.07962599108296, 48.300905689116455, 44.81644853468865, 42.62038015550183, 48.47996580985285, 53.61522697633313, 55.239425551506784, 55.22703870650261, 56.28961663092337, 46.696503316202474, 40.71610081580378, 39.4244800075408, 49.45559263229371, 55.26164970090313, 56.23725298912295, 49.24867976096369, 50.783114894743896, 50.61022858465872, 54.57089677933724, 53.87297376509636, 52.8731772976537, 47.09944055926415, 43.432773620851584, 39.45836928582961, 40.13206774188627, 39.80928805566604, 38.334731824936405, 40.032094370934274, 41.01145528977917, 40.46470042197935, 42.27373676915323, 41.518107844937234, 42.33375687753001, 40.329464943178245, 40.85714532483009, 38.60998807414886, 42.149558451867875, 41.621062217220185, 36.617223985733524, 37.811330749142556, 42.18297704573601, 48.189984983013524, 49.93635754431448, 48.91218354625087, 51.497009800326445, 50.3876889905622, 46.82535709873323, 43.10516157457906, 40.24354150218349, 37.22812921770158, 38.96138537314631, 40.103638402877316, 40.888073213638805, 41.66323554131293, 41.564956634275376, 41.466097216452326, 42.393714227984034, 41.37076008704401, 39.98123299690985, 39.54138625052668, 41.04745480322069, 39.58450486583095, 41.42553206413023, 40.13156567850421, 42.06365462272398, 42.46099464354977, 39.89569787056216, 41.86097006643973, 39.6623952927128, 41.49518551365022, 46.261783107634514, 50.01229463085052, 50.36416653663882, 52.39278893316946, 50.31016726647654, 49.086521133299804, 51.0796303902903, 44.28157844851094, 39.15676255379954, 36.95735623759609, 38.61585593992664, 41.23483427109257, 40.8464607884807, 39.76249025714013, 40.0013312216728, 40.71777959023753, 40.175892383821555, 39.19542927895823, 40.718403247094926, 39.53692259327058, 38.41172010667863, 39.80400462304392, 38.67582897986136, 39.75583791732788, 41.40662623989967, 39.18832978894634, 40.71104095828149, 40.53451468867641, 41.82208368855138, 42.84228824800061, 46.19056855478595, 49.45087009860624, 51.1598507050545, 52.55547315843644, 53.75538110733033, 55.66846224569506, 54.59825923365932, 54.56351487867294, 47.95122246588431, 57.37142985866916, 57.62337938431771, 52.759903169447384, 42.44294781838694, 41.5101218992664, 43.47817113322597, 43.60409098286783, 46.01941593231694, 53.91490782460859, 58.842416732541984, 64.00429902538177, 47.93958087121287, 0.0683546546966799, 0.8249239671614863, 9.2670908089607, 4.494255175513606, 0.40174542475611935, 2.1153989530378774, 64.15855407714844, 59.831093280546135, 66.5996882223314, 65.42713096064907, 61.77290578042308, 32.761359560874205, 23.081459883720647, 47.91684681369413, 61.58662849856962, 8.78130526311936, 0.23474388034834018, 0.07509914722533957, 0.03584464493718359, 0.021686332690859997, 0.0865102337012368, 0.05790082189524847, 0.031206352193088784, 0.04630052702381246, 0.14973180819182627, 0.24393082205807012, 0.08392999594610545, 0.21295201904591055, 0.1469705668428252, 0.3123130559200241, 0.14143784921015465, 0.26999598308917017, 0.10979790465846179, 0.21784319932903015, 0.33631042306942327, 15.644372451689938, 79.19981602699526, 56.240332049708215, 64.25693888818064, 91.84020303910779, 76.63195010154479, 51.046247097753714, 77.88702226454213, 63.962106089438166, 72.49285328772761, 58.57687619424636, 71.99651656612274, 9.979949228225216, 2.9692714829598708, 3.3910039884428826, 8.197387899121932, 0.9493039187885101, 1.270369284095303, 61.59446147180373, 58.78649942336544, 59.9883528678648, 49.08132399282148, 47.534262749456595, 44.094983454673525, 52.038751879046046, 58.03046257265153, 56.67468355547998, 59.297321458016675, 60.89799365689678, 48.60612100170505, 43.48690625159971, 42.33576905342841, 52.371251198553274, 58.158959419496604, 58.05626000127485, 50.7524537271069, 53.30498318518362, 53.83051018561087, 56.145944133881606, 56.19381273946455, 54.62871251567718, 49.88021666003812, 45.12228750413464, 41.59937151016728, 42.778412449744444, 42.375494818533625, 40.02757580049577, 41.198787689208984, 43.46643932404057, 42.877738629618, 43.40325386293473, 43.593120113495864, 44.5928499006456, 43.678106108019435, 42.906128744925226, 41.6421292674157, 44.287563985393895, 45.15252113342286, 39.03956213305074, 42.87519301137617, 45.36678452645579, 52.2217147581039, 52.31824036567442, 48.922342484997166, 54.58187549344955, 49.9260966239437, 47.38746020101732, 43.99047974617251, 39.93434890624016, 38.50399778735253, 40.39190515395134, 41.85148185299289, 43.31214504857218, 45.185206244068766, 43.86352831317533, 44.570421788000296, 45.38187388450869, 44.08764077771095, 42.56934619718983, 40.88751623707433, 42.486725391880164, 41.0968727450217, 43.4969396745005, 40.54772523141677, 44.56964515870617, 44.1715245862161, 41.55631565278576, 42.50592147150348, 39.266337886933364, 40.0644656919664, 47.46559381484986, 52.41076907803936, 52.772792077833614, 55.0502888617977, 52.72024016226492, 51.04881625021658, 53.686857300419966, 46.867098962107015, 41.256536745256, 39.211624745399725, 40.894956973291215, 42.61601847987021, 42.27281893453291, 40.86682965678554, 41.141556386024725, 41.86371180319017, 43.32134300662626, 40.69920324510144, 43.28922663965533, 39.63902973359631, 40.43893437231741, 42.51488408734722, 40.91677319618964, 43.42224597930909, 44.54349863913752, 40.82843749753891, 44.025988963342485, 42.81869519141413, 44.19236806131179, 45.30918059810516, 48.42318557923841, 52.59065681888212, 53.32131593458114, 53.39864546252836, 54.942423682059015, 56.13423193654707, 56.15467140751501, 55.86593397202031, 50.8623859959264, 58.394835072179, 59.160885733942834, 55.235338441787235, 45.87999920691214, 42.84675582762688, 46.1233038287009, 46.07172073856477, 48.809954812449796, 54.77342051844443, 60.94998075116066, 65.17994711475988, 51.31429795295962, 0.38931264512000546, 2.1104212201410726, 12.872807056673112, 10.924309857429998, 2.1148228549188186, 2.9541250053913366, 68.8971616375831, 66.1201000213623, 71.11014719932311, 68.98360283144059, 64.69631102777296, 44.18736311697191, 42.176512979692035, 55.0582944193194, 74.08121708900698, 11.508295862905442, 0.3729117751842545, 0.16282103324849762, 0.1779678478957184, 0.2171990879240536, 0.23755409003746128, 0.19312960125746267, 0.18571950855755037, 0.10564209983473825], [0.023341228164011435, 0.11937752005554016, 0.03481146428854235, 0.1276311521688777, 0.0743953958754578, 0.014370098210600837, 0.08871948571815606, 0.040264539420604706, 0.025732740158996275, 0.1615753283183421, 0.15968731995071136, 3.4334401113371698, 54.40052470853252, 46.5771887379308, 47.48266396983978, 73.8972657726657, 77.54557209630167, 44.59590542700983, 55.63484753331831, 55.713561657936346, 59.19963482887515, 49.80040819414201, 59.82718659985451, 16.448590717008038, 1.3870734024432398, 0.2038958332230968, 1.2801318183060617, 1.1585320916868027, 0.22447995691289827, 42.57692029399257, 60.98776102066041, 54.28195145822341, 47.99975787439654, 41.649464099637925, 47.09001118136991, 51.92213196908274, 54.352883600419574, 56.78281937876056, 54.70877201326432, 52.38037463157408, 42.01881800928424, 37.21724071810323, 43.713834977919056, 50.413647236362586, 54.69220784402663, 52.691340138835294, 45.76243400573731, 51.45855096078689, 49.64076772812874, 49.51995480445124, 51.2434168015757, 52.239663524012414, 50.487474087745916, 46.67831920808362, 38.51823206870787, 39.088195600817286, 38.04741820981426, 38.46116158270067, 37.590924924419774, 39.099037031973566, 38.21776282402777, 41.572640557442945, 39.75810112491731, 40.1422070687817, 37.12730861479236, 40.16078341391779, 38.87519521097983, 42.1144885401572, 40.28939400949786, 35.53935666238108, 37.33511970889184, 40.655935579730624, 45.9466951893222, 46.6916395771888, 48.1417319851537, 48.09853100007581, 47.06761444768598, 41.526980246267016, 43.074217996289654, 37.94709574791693, 38.175330623503655, 38.61870358067174, 39.11672299908054, 39.935392256705995, 38.980251973675145, 38.26376438140869, 38.58308061476677, 40.223729610443115, 37.85222145818895, 40.046924852555804, 39.401742027651885, 39.999930935521284, 35.661864049973026, 38.35277865009923, 39.27397474165886, 40.33572896834343, 38.92690773933165, 38.801203620049264, 39.93182682221936, 42.34724983092278, 42.682318302892874, 45.55794908154396, 46.555246999186856, 47.58135080337525, 49.24640086389358, 49.841008647795654, 46.19514203840687, 46.36274491586993, 44.339300047966745, 35.94286264911775, 35.78735243889594, 37.28013592381632, 38.79832067797261, 37.04758251866987, 38.55002287895449, 40.04167672126524, 38.77777138063985, 37.145751599342596, 37.44762897491455, 36.8240584096601, 35.91027952009632, 35.68921865955476, 36.97830561668643, 37.92212593939997, 35.39031051820324, 36.63254476362659, 36.06096913737636, 38.32302747234222, 38.05190932366156, 40.282223916822865, 44.10595040167532, 47.39985096839167, 48.56259838227303, 47.94893180170367, 50.65435917146745, 48.95146608352662, 52.58158829904372, 52.04507866213399, 53.81753498508085, 49.37565080581173, 46.8646788597107, 59.13400573115195, 54.889244187262754, 50.01862141393846, 39.58967847208823, 39.2261649716285, 39.764918204276796, 43.85771143820978, 52.80191959873323, 54.797958866242446, 62.189010420153224, 41.54853367036389, 0.06854159547196281, 0.6836789882471485, 6.359718739986421, 5.245046346418319, 1.047419189445434, 7.4326218135895274, 62.7865795935354, 55.25702522646997, 60.408105311855195, 59.71522646565592, 48.198418078884, 33.79619259988108, 36.12648840873472, 44.81031002536897, 43.33585185389365, 1.0896444849429594, 0.14938962735956715, 0.04176511797272871, 0.06260528356858319, 0.0783133916857262, 0.023796389728123625, 0.01626211226046566, 0.029554976893949415, 0.03705304904630588, 0.05046539083724061, 0.04101808648556471, 0.036823973435187535, 0.00601636138819759, 0.08985406193401545, 0.04028608947391472, 0.07450271713277025, 0.042114856262360854, 0.015717186259045716, 0.15886806552448582, 0.22364496704070802, 5.057032925467338, 64.9496804514239, 52.53299797734907, 59.429462186751834, 80.15428558472665, 78.37447089533653, 48.35452841174219, 64.05725494507821, 63.34598802751111, 64.24718787593227, 54.73919783869098, 65.06559825712635, 16.39364517504169, 1.0583585572819556, 1.6282204754890937, 3.9480224732429754, 1.2998086334236207, 0.14003411566297855, 46.03980833484281, 62.222738881264966, 55.338316348291215, 50.333226880719586, 43.715062679782996, 48.65446029170867, 52.810788077692834, 55.641448882318315, 57.63072206128029, 55.60646134038126, 54.22151950097854, 44.21585129153344, 39.57919005424746, 46.01430508398241, 53.963859004359094, 54.06214967850716, 53.48535337755757, 46.06535865414528, 51.773136815717145, 51.96442296428066, 51.39522429435484, 52.21019867927798, 53.03128019455941, 51.0328600483556, 47.872284766166445, 41.61338613879296, 39.76440045141405, 40.99036078299246, 40.95643228100192, 39.385879962675034, 40.40096975141957, 40.69726951660649, 43.17026115232899, 41.0676863885695, 43.05454338750532, 41.59142086582799, 41.512632216176684, 40.43483549548734, 42.83702442722936, 42.27797292893933, 37.83877165086808, 38.43201052758002, 42.921159267425544, 48.565567616493475, 49.297752534189534, 48.686317782248224, 50.368045760739236, 48.03489838877032, 43.57788955011676, 43.115469563391905, 38.26461945810626, 37.788922248348115, 40.60210497148576, 40.568451035407286, 41.10765926299557, 41.46144920779813, 40.274947920153224, 40.18538844200873, 42.07493143696939, 41.616390674344956, 40.94766970603697, 40.93866394412133, 40.787044725110455, 38.394755855683364, 40.692272417006954, 41.59248775051486, 41.64713421175557, 40.218379497528076, 39.91386236683015, 40.769448972517445, 42.04146185228902, 43.025219748097086, 44.37235778377902, 47.805714299601895, 52.02727894629202, 50.83108155958114, 52.44724319827173, 47.433638265056, 48.09032540167532, 44.77655018529585, 39.22401943514424, 38.15472249061831, 39.93500786442911, 40.20400008847637, 38.90807251776419, 40.45409433303341, 41.14703593715545, 39.649498539586226, 38.99382337447136, 40.63308385110671, 39.48163678569179, 38.88124350578555, 37.26261077388641, 39.796654101341005, 39.2293381690979, 38.23002023081626, 40.03338090835079, 38.49933408921765, 39.90083617548789, 38.79575544787992, 40.61751988626296, 44.83108682017173, 48.856984030815866, 50.78198525213426, 49.40196206492763, 51.39821314042615, 52.30334712613014, 55.995674210210005, 53.896660958566976, 55.8660908668272, 52.421688956599084, 50.154213828425256, 60.127004731086, 55.85817160144929, 51.86718740770894, 42.51864564034247, 41.526219306453584, 41.77674501172958, 45.414445246419604, 55.2177034654925, 58.812626331083244, 62.88554883772328, 46.141311430162006, 0.13977004515547908, 0.2988964048845153, 9.74993065480263, 4.8585541306003455, 0.9527294962636886, 7.573913431936695, 70.37373788895147, 58.90868909897343, 67.21656722407188, 64.0061778406943, 53.8221320029228, 37.821368094413515, 38.7364492108745, 51.4961664907394, 53.948342107957416, 1.9048252845964126, 0.08744495289940989, 0.040546360185309764, 0.08613584653264092, 0.04458879931799827, 0.024662379348169894, 0.01655404538577122, 0.023117630081551693, 0.04069391254996581, 0.23856728728259766, 0.24882442317903045, 0.11111857895288738, 0.13866746077133765, 0.15577290177104935, 0.1246118157981865, 0.22659330238257686, 0.09353081665692792, 0.19382816619209706, 0.4276349984349743, 0.2899507655491752, 5.688596790836704, 72.17820859724476, 61.559050313888065, 61.32312367039343, 78.03924160618936, 81.85153438198952, 56.18364987834808, 67.74612642103627, 66.45531362102878, 70.38025686817785, 59.50781545331402, 69.5750178060224, 20.679894608836022, 2.081117437731835, 4.922174484499039, 8.386301013731188, 3.7660938741699344, 0.5391876964319138, 49.846456819965, 64.98861782012447, 59.60784373744842, 52.09055069954165, 44.59318330211025, 52.03138959023261, 56.83964667781707, 58.44849309613628, 61.48550195078696, 58.09904521511447, 56.057267189025886, 46.236927047852554, 41.358420310481904, 47.81524173675045, 54.46793848468412, 57.61755074224165, 56.57993478159751, 47.513101562376946, 53.014916066200506, 53.05462614182503, 53.88071260144634, 55.25690363299463, 55.66638338950373, 53.485027820833274, 50.01203967678932, 44.762770898880504, 41.82058142077538, 44.12483661405502, 44.42203852438158, 42.087655605808386, 43.15460697297127, 41.87574171250866, 44.68766927719117, 43.74716335727323, 45.27675044152045, 42.498025740346606, 44.469891440483835, 42.49917891717727, 45.30008854404573, 44.820017891545454, 41.553013017100675, 42.47009454234954, 45.34465059157341, 52.74208384175455, 51.54572956023678, 50.58657669251966, 53.33539332112959, 48.42907305686705, 44.43555108962521, 43.34275522539693, 38.49287394554385, 40.610381172549346, 41.80732773196313, 40.73495957159227, 42.98021055036976, 43.22057339452928, 42.74599406027025, 42.95320110936319, 44.8392806514617, 42.938719718687, 45.8894834979888, 44.71570245681271, 45.88363524406187, 40.10756861778998, 42.357593121067175, 44.28916039005403, 44.01987791061402, 41.55285219992361, 40.39770241706602, 41.924567376413655, 43.25361544086088, 44.36341477978615, 47.35112336374099, 47.87503827002741, 51.687523241966005, 54.136521739344445, 54.265234316549, 51.135653603461485, 50.26941384038618, 48.66280709543536, 41.63490426155829, 39.874544528222856, 43.213544507180494, 42.51048318801388, 40.590808545389486, 42.57289986456595, 43.02931470255698, 43.44358367304648, 41.62329404584823, 40.87206209859541, 41.03444037898895, 41.342197387449204, 38.70894947359639, 41.84267220958587, 42.50470553675006, 40.30371850536716, 42.5808975773473, 40.55719775538291, 43.27343909971176, 41.495922919242616, 44.91656703333701, 47.87239851490144, 53.87844547148674, 52.526875157510084, 51.76445268815564, 54.63455684723393, 53.31472243032148, 57.352449509405325, 56.84884855824133, 58.40745333702334, 53.4603286558582, 51.97754721487723, 62.88416031868228, 58.559201994249904, 55.69483234036354, 44.60698220037645, 43.46305431858186, 43.83065100639097, 47.92249502674226, 57.01406271226945, 60.843570770755896, 63.765889521568056, 48.8172504209703, 0.5906578958515198, 1.966662185807382, 17.118617834583407, 16.857611556206983, 1.9887342207854795, 8.918649996480635, 75.12135121130174, 64.94821740734962, 73.39400214533653, 68.44593217295986, 59.8109793663025, 46.872394161839644, 47.379442876385106, 58.17283676516626, 62.54586373606036, 3.595686992329936, 0.4843719297599408, 0.14519603141853887, 0.19395725200733832, 0.11087086442257128, 0.18290681674355463, 0.15571999573899856, 0.15937337711934121, 0.11367776461185948], [0.04498063413906963, 0.03979910270220811, 0.012155192464800372, 0.02380093454473442, 0.052339594300475814, 0.02636517446878697, 0.10832152299342618, 0.015899433788182517, 0.06665438383577332, 0.04418571449575886, 0.029374189719918276, 0.1630935920101981, 37.28004570930235, 54.72132752018591, 33.7336229508923, 40.56991015711139, 54.896983023612734, 41.439629062529534, 47.762819259397446, 58.11966903748051, 59.739031330231704, 54.58194217374248, 56.500514630348455, 33.354439581594164, 0.2626302315583152, 0.7106350482471528, 3.0462479975915726, 1.9172251224517824, 0.09002768044029513, 34.4471138523471, 58.58452481608237, 53.00240762772099, 51.40704239568403, 47.36820528584142, 51.29249741954189, 52.01995588118031, 57.85223791676184, 55.45861544147615, 54.99459905009116, 50.60383512127785, 38.1244888613301, 41.37011681833575, 48.77652445147115, 52.49735932196341, 53.77414964860486, 48.0941967810354, 49.39940860194545, 50.45769937576787, 51.58727922747212, 50.751637874111054, 51.03702952784877, 53.82780375019197, 51.158670071632635, 52.39819788163709, 43.73700441852693, 40.126439140688994, 37.99580766308693, 37.53375637915827, 37.21000002276513, 37.470496393019154, 37.541899219636, 39.29978785976287, 39.18203830718994, 40.10555644189158, 39.59316545917142, 38.730620568798436, 38.638095778803674, 41.23220628307712, 37.81559828789004, 35.69884415595762, 37.916803283076135, 42.060293151486306, 45.64921086834323, 45.66121332107052, 46.02558582059799, 47.72214820308071, 47.26655314045568, 44.57677602767945, 41.23891353607178, 37.60066024718746, 38.372080633717204, 39.896815746061264, 39.102390658470895, 39.37283808185209, 35.87199718721452, 38.741371785440755, 39.006276899768466, 38.50155807310535, 38.71817488824168, 38.60615984086068, 37.777296343157374, 38.41879998483966, 37.77990471932196, 38.33788933292512, 38.04273097745834, 40.82083202177479, 38.258728058107444, 38.69808843058925, 39.70577670681862, 42.21672904106879, 40.73476345308366, 41.94297898200251, 49.315489492108746, 49.71847772598267, 49.00087225821711, 48.51932679453204, 45.57401510976976, 45.87348022768575, 43.26480988533267, 37.715417031318914, 35.287061968157374, 37.70913339430286, 38.94795125530612, 39.16347372916437, 38.49053229055097, 38.06897947865148, 38.59404363939839, 38.66929823352445, 38.246643235606534, 38.73335446080854, 37.227262373893495, 36.737009248425885, 35.837025334758145, 35.56572675704956, 35.457394815260365, 37.839269791879964, 35.631344087662235, 38.20800004466888, 37.9813027381897, 40.10672530820293, 44.55696805830925, 47.339450390108176, 46.214393031212595, 47.56711259964974, 47.013505351158884, 45.322822601564475, 49.82889244633336, 53.528456303381155, 51.6070048270687, 55.978737415805945, 49.42792423309819, 54.32747056407314, 57.6038852045613, 55.63195674650131, 46.8915980862033, 38.50406839001564, 40.25997623320549, 43.53586919846074, 52.40894125353906, 56.87857620177731, 62.78383785678495, 47.7831018355585, 0.2855508468083797, 0.5648659830612521, 7.953412552033702, 1.5599861885270767, 0.48858489240369496, 16.015145278746083, 65.96673534762475, 51.393788706871774, 62.69726722471176, 54.44942881984096, 40.423954840629335, 25.398133300965835, 32.26735468833677, 45.89829314139582, 36.70963502699329, 0.3057429326638099, 0.05223029653631872, 0.0957407504920998, 0.03099701292211971, 0.029265613993629817, 0.03343246005956204, 0.03288843421145313, 0.014068798702811042, 0.039633746454191786, 0.06801342381344688, 0.018879382705856717, 0.0420352214226319, 0.0481909140944481, 0.018787913722917438, 0.027824196581458373, 0.0770037797009272, 0.005773019783514282, 0.041412617936129534, 0.03755322402162898, 0.03498822375531158, 0.4785691814557199, 46.85719497742192, 60.98464273637342, 36.54749993355044, 56.1885489186933, 70.6837934063327, 47.109579886159594, 54.02888405707575, 64.98385606273528, 65.6673094534105, 57.52189590084938, 62.88386614091935, 36.03460296507805, 0.07535699709889389, 1.5982903395929646, 3.4611065493476008, 4.427805321831857, 0.04078488166053449, 40.295912988724254, 60.746092027233495, 55.83790471476894, 52.61999614777104, 48.889645607240745, 52.034421582375806, 55.16621451224051, 58.40553137563891, 57.42375035439768, 55.97496801807035, 52.4000374732479, 39.65569588445848, 42.450408166454686, 49.878235863101104, 53.97805406201271, 56.15927627009731, 50.84508442109632, 50.39769887924195, 50.65331582100161, 51.68124352732013, 52.98736926048033, 53.779566441812825, 55.70476378163984, 52.42348932450818, 54.87690048833048, 45.32142231541295, 41.57965767768122, 41.14380390413346, 40.48511635872626, 39.56987834745838, 40.23630472921556, 40.751209951216175, 41.079567247821444, 40.68170555176274, 42.00858062313449, 42.10796171619047, 41.29601147867019, 40.66865974856962, 43.355024399295935, 41.31599595469814, 39.37184179982832, 39.21334666590537, 43.61037069751371, 47.74053235207835, 47.425314995550345, 48.49294101038287, 49.783338039152085, 49.08756056139546, 44.33886074250744, 42.304911767282796, 36.78374821139921, 38.906083876086825, 40.60864356256301, 41.21759937655541, 39.988932609558105, 38.90627999459544, 40.272166959701046, 40.205047361312374, 40.72465158277943, 42.57133091649702, 41.92717967494842, 39.491136766249134, 40.52199840545654, 39.99221955576251, 40.121818588626006, 38.73211106946392, 41.64353739830756, 40.59492311170025, 40.131875545747825, 41.42500254415697, 42.71759217785251, 42.20562481111096, 42.02034773365144, 48.81959599833335, 51.78777510120023, 50.141928965045565, 50.151146534950506, 49.05387132398544, 48.147423344273726, 45.71450656460178, 39.77252368004092, 37.65962523798789, 39.77232363916213, 40.37494874769642, 40.444959132902085, 39.4249467695913, 39.82108262277419, 40.83581155346286, 40.466508634628795, 40.29019417301301, 39.67429184144543, 39.08055874609178, 39.0080851124179, 38.162135770243985, 37.94201235617361, 37.544978280221265, 39.43840442165252, 37.988951360025716, 39.26084264632195, 40.0186445636134, 43.82612459121212, 47.02340541347381, 50.66882879503312, 50.08707854055589, 50.80262084161082, 49.498032677558164, 49.32214575429117, 52.68131063830469, 55.40985645786409, 52.96962445782077, 58.46619475272394, 49.484567180756606, 55.70288104395713, 59.71702291119484, 58.198732253043886, 47.074917900946836, 40.51168257190336, 43.34508511327928, 46.45677197364069, 53.30368880302676, 59.11518227669501, 65.55401963572349, 50.259419641187115, 0.3402168279693973, 0.8651143492710206, 12.951672192542786, 3.8971238367019163, 0.6440828452187201, 17.52219834635335, 70.50654934298608, 58.331269141166445, 68.68931524215206, 59.396267167983524, 48.81411644720262, 31.193574474703883, 36.00393003033054, 49.97820138931275, 44.20100119806106, 0.5351503517839217, 0.05329265364355618, 0.03260608484608031, 0.06858720834697447, 0.04243745971771498, 0.028405366202576027, 0.021257551364420403, 0.015164376255275022, 0.11750317103559933, 0.1796879144685884, 0.11356694233273307, 0.0935651067524187, 0.10272374151334648, 0.1438124153402544, 0.20406167593694505, 0.27109596277436904, 0.08965068857275671, 0.13439544807038, 0.1296294618758463, 0.10298368280693408, 0.4484533764902623, 52.748496916986284, 68.56332086747693, 47.046519940899266, 54.4438551318261, 65.73577834713844, 54.6125719624181, 59.71689347297915, 69.74822182809153, 70.12450264346215, 64.25172213585147, 67.86961832354146, 42.67961578984415, 0.4412905156852738, 4.032956006065492, 6.218640400517372, 5.3601326096442445, 0.21590942486880288, 41.33721597733037, 64.32913011120212, 56.969057436912294, 55.59369402547037, 52.57651667441092, 55.017501769527314, 56.636181569868526, 62.25436102959418, 59.7866371370131, 60.007843125251036, 54.53095920624272, 41.898146290932935, 45.84515679267145, 53.72621044035881, 56.017313926450676, 58.954039542905754, 52.912228415089274, 52.0795209946171, 54.125342984353345, 55.5758511635565, 52.72741417731009, 57.08883485486431, 58.011890149885616, 53.8505966432633, 57.54944662893973, 49.34153010768276, 44.22422947422151, 43.102647335298606, 41.98353628958426, 42.00218715975362, 41.188279659517356, 42.824884691546046, 42.157850342412154, 41.666326369008715, 44.79021964534637, 43.922430546053, 43.25426655430948, 42.015531063079834, 45.60590790164086, 43.421810596219956, 41.78338166206114, 43.082662859270656, 45.71132160002186, 50.135762999134684, 50.3603853717927, 49.54117874945364, 51.66946857206283, 50.57929285110966, 45.515261926958644, 42.02953000222483, 38.97995779591222, 41.031596660614014, 43.980952309023955, 43.3017272333945, 42.15925062856367, 39.9620565291374, 43.25292902608072, 42.64152173073062, 43.66918663824759, 44.825834766511, 43.34261009770055, 42.311991645443825, 43.317208828464636, 42.360413305221066, 42.00113988691761, 41.15974441651375, 43.88710960265129, 43.00111286101803, 40.93828739658479, 41.16810690972113, 44.43645715713502, 42.98233647500315, 41.79476830267137, 50.518923651787546, 52.203146257708156, 52.78433169088056, 54.53660741929085, 51.395781270919315, 50.99736652066631, 50.25614838446341, 42.46839615606493, 40.044285097429835, 43.154316717578524, 42.47538974208217, 42.536539493068574, 42.0044425226027, 41.9728046847928, 42.82196252576767, 43.74078166100287, 42.83192534600535, 42.84532416251398, 43.04596908630864, 42.25836107807775, 41.65095852267358, 40.05407141100976, 40.38499393770772, 42.34111916634345, 39.967908705434496, 42.547463293998476, 42.156905051200624, 44.97148806048978, 49.80193791850921, 52.247096415488954, 52.26786928792154, 52.22320133639921, 51.838703155517585, 52.094590740819136, 54.03105705015121, 58.24832277913248, 55.91593242460682, 61.417315467711425, 51.67228483384656, 57.45235227769422, 60.866018495252064, 62.10772322070215, 49.8723287736216, 44.208014395929155, 43.89621734619141, 50.04860401153565, 54.99166903957244, 63.74119427896316, 63.603295510815045, 55.033669779377604, 0.6473941836626299, 1.9126762762185068, 19.160811631910263, 6.638698789381213, 0.9131956821487797, 19.885632299607803, 77.88426876068115, 60.84442584745346, 73.12006381250197, 63.95414760035854, 53.1739289529862, 34.73825177838726, 43.4486396081986, 59.468379943601555, 53.02383945834253, 1.1205270213465537, 0.18175083603109085, 0.20195566958958105, 0.17422233678160176, 0.1587440512113033, 0.22013069190565618, 0.09836754341038967, 0.15038149671689158, 0.19260751233706552], [0.015910487479319977, 0.05420834321769015, 0.02069907135240013, 0.039442427486421607, 0.04616464217824321, 0.06978923860456675, 0.042211927263246435, 0.052330167588567546, 0.024279356453447573, 0.050224479167692127, 0.07694409379074652, 0.2215696501755907, 19.125445581251576, 55.07143435939666, 48.34632673571187, 25.102645466404578, 17.36946713539862, 40.01995855762113, 54.68909740447999, 60.057492486892215, 54.684163062803215, 56.42405979094967, 54.27803693279144, 42.90108065451346, 0.2525376360262594, 1.4642635636752652, 2.1977481342131093, 5.158127113696068, 10.28601569514121, 10.75566461009364, 66.19960646475515, 52.48210914673344, 55.689117447022475, 47.75541382451212, 54.062981220983694, 54.28307325609269, 57.67415446619834, 53.98828752579228, 53.35543271033995, 40.10347366333008, 38.19794700991723, 43.71542746020902, 51.89610312061926, 52.716490376380186, 52.145934566374756, 49.19901078747165, 52.3348202243928, 54.98039222532704, 53.86574091449861, 54.107692318577925, 53.42491749794253, 50.25676811895063, 54.63070507972471, 50.76436988769039, 47.591917668619466, 43.097979714793546, 41.4184953320411, 40.868465285147394, 38.001750053897986, 37.594651176083474, 37.60146433307279, 38.8801726987285, 39.36133377013668, 39.14549750666465, 40.38844954582953, 38.70020258811213, 38.44060051825739, 40.25463788740097, 38.18297140059933, 34.57943893248035, 36.451648973649554, 41.260290453510905, 46.77327194521504, 45.47384169793899, 45.848416282284646, 48.69070691447104, 47.918674638194425, 42.10091321699081, 40.354693628126576, 39.0393542474316, 39.35619938758112, 40.46765788908928, 39.60276349898308, 36.403031195363695, 36.99734087913267, 35.48280392923663, 38.351256770472375, 38.007135468144575, 38.94661764944754, 37.441663049882465, 39.66410544610793, 38.10913278210548, 38.995600208159416, 38.489194762322214, 37.793397672714725, 38.473054209063136, 39.48811261884628, 40.289284183133034, 38.24254828114664, 39.878325693068966, 39.1165582595333, 41.75269303783294, 45.66903844956429, 50.964144045306796, 50.59175029877694, 47.174903039009344, 46.087476899546964, 45.98013339504119, 43.3000131576292, 35.57843915877804, 35.84089671411822, 37.29677461808728, 38.08164873430806, 37.666458006828066, 36.621216958568944, 37.21729955365581, 37.22505015711631, 37.474912981833185, 37.46440495214155, 37.37736755801786, 37.29255807015204, 35.76647758483887, 36.91435137102681, 34.50616121292114, 35.79214165287633, 35.885086136479536, 36.032139716609834, 36.5535129270246, 38.92434643160912, 42.5777518364691, 45.358747589972715, 47.3047766377849, 48.56289648240613, 45.9881938657453, 45.56886503773351, 46.04101250248571, 46.101703336161954, 51.55580220683929, 51.46303030752367, 55.91403007507325, 53.36535630687591, 49.057927054743615, 57.118311466709265, 57.25008349264822, 51.43384395107147, 40.447983280304946, 38.468884729569965, 44.98303159590691, 52.356522698556226, 56.80785586757045, 59.02661123583394, 49.03163932984876, 2.043117147780234, 0.1842561427263483, 7.714087665081025, 1.7658462711880285, 0.2650760438653731, 32.58853993108196, 62.40949469227945, 52.75547481352284, 61.56809529950542, 54.102985474371145, 32.90577926943379, 29.99139351229514, 42.82477486518122, 50.59037746921663, 20.750246240246682, 0.10980034847894024, 0.07335935388841937, 0.07583269173459661, 0.03220066728611146, 0.02050159878337816, 0.011306560481898488, 0.03167460045416749, 0.05169812972927767, 0.036259745848515344, 0.04390102856221699, 0.04486463310557508, 0.07760295238826545, 0.04401174358903401, 0.04581578105928437, 0.06812508878929001, 0.045644020316221064, 0.07274706577581745, 0.1135709566334563, 0.056527728034603986, 0.13796008582557404, 0.35087157882029013, 26.600457429885868, 64.89868963918379, 48.88961815064954, 30.445849126385106, 34.695403806624874, 53.82236342276297, 56.44762146857477, 65.4569370515885, 59.74510708162862, 63.250960765346406, 59.11073823128978, 45.3199278923773, 0.12406063851930442, 0.12486859314864683, 4.482702814763592, 9.640959366675347, 11.149010677491466, 12.918496785625337, 67.5373778804656, 54.78279890552644, 57.95470983751359, 51.06743966379474, 56.600566448703894, 56.4255581363555, 59.98064148810602, 54.25169821708433, 56.290710972201445, 43.36805451300837, 40.13382496372346, 46.76770217957036, 54.69463971353347, 55.070285104936175, 53.04851116672639, 49.40509603869531, 52.65902373098558, 54.5720931022398, 55.47374794560095, 54.2259870806048, 55.36177604429184, 53.396617597149266, 56.40520103516118, 51.52869470657841, 50.843719436276345, 45.322202867077245, 42.782899641221576, 41.70976661866711, 39.662975803498306, 39.814591100139005, 40.88146401989845, 41.2445068359375, 41.1054313567377, 40.13280122510849, 43.13414789015248, 40.988266237320445, 40.29105709445092, 42.55596307016189, 39.598601864230254, 36.750768922990375, 38.71641766640448, 43.044407982980054, 48.00272318624681, 46.81448821098574, 47.70023392092797, 49.51765629553026, 48.967947882990686, 42.405089101483746, 40.29886653346401, 38.839889957058816, 41.05712736806562, 40.84013008302258, 40.88136596064414, 39.57995099406089, 38.45028485021284, 39.463499746014996, 39.73198598431003, 40.8485004209703, 40.63189145057432, 40.01575769916658, 43.24686504179432, 40.52246908987723, 40.10969454242338, 40.47773838043213, 40.27794461096487, 39.2340999264871, 39.66610585489581, 39.47327429248441, 39.36489920462332, 40.91804796649564, 38.95191284918016, 41.87601627842073, 47.04119336220526, 52.01514313297888, 50.31541147539693, 49.70215674369566, 49.40075789728473, 47.19729977269327, 45.32849042646347, 38.1215980745131, 37.56750837449105, 39.44446448356875, 40.181050300598145, 38.61922525590466, 38.76755360634097, 39.54593227755639, 40.75704643803258, 39.24406274672478, 40.74869178956555, 40.02883488132108, 37.935077605708955, 37.44538145680582, 38.788883455338016, 37.24088868787212, 38.241873633477, 38.06039733271445, 38.66726644577519, 39.09432626539661, 40.94746574278801, 45.04236528950353, 47.64275943079303, 49.097931308131066, 49.20143481223814, 49.57468755783574, 49.59735885743172, 49.20315673274379, 48.2759201911188, 53.935900349770826, 53.584577575806655, 55.58602579178349, 54.18539054932133, 50.69334753098027, 60.62563603924167, 59.55171462028258, 53.46345086251536, 42.91939812321817, 40.3932426821801, 48.138939257591005, 54.40767518935665, 59.546913639191665, 58.90259373572565, 52.80287665705527, 2.6021577369782234, 0.2439296576044252, 7.428809269782036, 2.561766639832528, 0.14747557200251088, 32.64721858885981, 68.54889438998315, 57.099844947938, 67.545991405364, 58.12091635119531, 41.42630084868401, 29.57293348927652, 44.537850426089385, 56.443589272037634, 26.977567826547933, 0.09041715188012009, 0.00506029658642928, 0.03413379057160309, 0.056762078161081, 0.035238045027419444, 0.023267982497570977, 0.05641362306872203, 0.050460281030785654, 0.011040435901152031, 0.12799109091922162, 0.09412088055884647, 0.2559580041035529, 0.16565376592259254, 0.1103933158540918, 0.1216636336739025, 0.10740640798523542, 0.1883807447889159, 0.15933622185501362, 0.15670953618903316, 0.2999865786442834, 0.5908903575712635, 28.40510072246675, 75.3004623228504, 60.60947587413173, 39.003766582858184, 31.935763397524436, 55.0153366211922, 64.23404009111466, 72.24269236287763, 64.99214795327956, 67.8952863139491, 65.05186603915307, 52.28080134237967, 0.4540754506184209, 5.619067386273415, 6.5664678523617415, 13.938423837384871, 15.4615419526254, 14.642724625525938, 71.42709039872693, 56.64137871034684, 61.064427668048495, 52.39074930067986, 59.64792251586915, 60.07004014907345, 62.606970340974875, 57.472183781285445, 60.00100251167052, 43.73813013876639, 41.36002455988238, 48.2605052763416, 57.35832914229363, 56.794374681288204, 55.887420715824256, 51.32801055908204, 56.42214567430558, 57.101590402664684, 56.000079031913515, 56.961247997899214, 57.77639104473976, 55.60746546714537, 59.41892277809882, 53.57890190616731, 52.521791765766764, 47.35986632685508, 47.137409102532175, 44.026934254554014, 41.90589297202326, 41.606141521084695, 41.380311058413604, 42.912443760902654, 41.848677358319684, 43.74608078310567, 45.09675287431286, 42.080799302747174, 41.00709753651773, 43.488628172105365, 42.4551110882913, 38.41037865607969, 41.304679916751006, 45.02920181520524, 53.83585637615573, 48.78562435027092, 49.164482162844756, 51.45832738568706, 50.14894216291366, 44.636156789718136, 40.93425520004765, 40.953733690323375, 42.9403631917892, 44.47075436192174, 44.43449204967868, 40.867873007251376, 41.79371318509502, 38.666281930861935, 42.22411878647343, 44.01419831860451, 43.235882405311834, 42.11077013323384, 45.482616040014456, 43.4154288999496, 43.804830043546616, 42.702102738042036, 41.653778706827474, 41.30332277667138, 42.68977472859044, 41.49538163215884, 40.667628165214296, 43.08310216472995, 40.1818936101852, 41.72796641626666, 49.04150409083213, 56.03418011819163, 55.588034045311716, 51.33243891500658, 51.32315858717888, 50.2128924862031, 48.24770266009916, 39.93176798666678, 40.42678679189375, 40.46630074900966, 42.70104369809551, 40.23530060245145, 39.904927207577614, 41.46701897344282, 41.70762500455303, 39.99250981115526, 42.89360853933519, 41.647498992181596, 40.33270482094058, 40.16135607996295, 42.17989014041039, 40.13144016265869, 41.338133811950684, 41.35054026880572, 39.96077391409105, 40.465147572179, 44.14522117184055, 47.39747401206724, 50.1402658800925, 52.218996555574485, 53.68963041613179, 51.96012796894197, 49.97568715003229, 51.48842765438942, 52.252587733730195, 56.95050462599724, 56.32630255914504, 60.119003095934474, 56.56594368719286, 51.17927428214781, 60.21505409671415, 62.83223598234115, 55.79923798961025, 45.94195304378387, 42.18870370618759, 50.59384484444895, 54.792738191543094, 62.030770240291474, 60.3855909070661, 54.92490637686945, 4.218329181594234, 0.9575961770549898, 18.874678650209983, 9.355223524955012, 0.5721018367236661, 38.81156652204452, 72.68150360353532, 61.46826705624981, 72.27327900548136, 63.53939617833784, 44.50930733834544, 40.50020963914933, 52.37732302758002, 66.33417514062697, 32.32935755483566, 0.20207044488239675, 0.1288789715017042, 0.18352054510145419, 0.14236486156380948, 0.1419220167782999, 0.0994043208418354, 0.16402841846068061, 0.12730099891702976, 0.10897564716757306], [0.05609580766289465, 0.03981422910827302, 0.03462023342088346, 0.10042212993627596, 0.048312603330780426, 0.06656748648252218, 0.04373956404085602, 0.04377283523940752, 0.04652214093854831, 0.06410349873946079, 0.011445506806335142, 0.06322457755525267, 2.697751291336552, 58.589737646041385, 45.65598087926065, 46.84568282096617, 20.37840162554095, 27.6184929186298, 53.010440641833895, 63.1379690477925, 54.3392925877725, 59.37214851379395, 50.597653465886275, 55.58429994890767, 2.722169026251762, 0.6355378392242617, 3.413108995845241, 5.704833932461278, 4.932095629553642, 3.359778734945482, 50.006238491304465, 55.576125729468565, 56.70168122937603, 56.539718720220755, 54.74081777757215, 56.472414770433986, 55.82260354872673, 54.771522091281035, 48.15950816677463, 40.3362859449079, 41.280525961229884, 50.741239670784246, 52.48594522476197, 54.27263582906416, 55.06057331638952, 53.300076300098056, 55.45602667716242, 54.336409645695845, 54.50863699759207, 54.919697469280614, 54.96259643185524, 52.59465763645788, 52.41635845553491, 50.1689854744942, 49.21804997228807, 47.84073322050033, 42.65330060835808, 41.58874580937047, 40.619818395183934, 36.79213816119779, 38.38474596700361, 39.59469126116845, 38.872049470101636, 37.85024066125193, 40.147886660791215, 40.563622597725164, 38.279461706838305, 40.441923218388716, 40.11994369568364, 35.57212022043044, 38.26854967301892, 42.145706684358665, 43.42372863523422, 45.526158271297334, 46.19828385691489, 47.228725802513864, 46.97995339670489, 41.318906353365996, 37.73193020974436, 39.73317838484241, 40.814038476636334, 39.61404815796883, 37.112827224116174, 37.78439975553943, 39.08248855221657, 36.80009272790725, 38.33741472613427, 38.35139405342841, 39.00803019923549, 37.14726563422911, 39.42764143789969, 38.51679255885463, 37.714899278456166, 37.24680754446214, 38.12126467304845, 38.462130408133234, 38.66438742606871, 39.829758905595355, 39.09070199535739, 38.128564203939135, 42.053891843365086, 41.026811369003795, 43.866070009046986, 48.52542215777982, 48.21721799911992, 46.17285513108777, 45.29469528505879, 44.02218034190517, 40.979554653167725, 34.831482595013036, 37.02376196461339, 37.08127175607989, 39.2696052212869, 38.16328894707465, 37.02014946168469, 37.933971497320364, 38.050281540040054, 36.95550095650458, 39.221465972162065, 38.128277870916556, 40.5435557519236, 37.90638546789847, 37.24908251916209, 35.277969914097945, 37.45185336759014, 36.01463417853079, 37.499655292880156, 38.74859286892799, 37.606233935202326, 41.95543250729961, 44.69431377226307, 44.26672051029821, 44.584255987598056, 46.233361613365915, 42.398954514534246, 43.444344612859915, 45.37437431273922, 45.44593795653313, 52.170645498460345, 54.03592471153506, 54.985334411744155, 50.2855347817944, 50.6370379847865, 58.05504798889161, 52.982670261013894, 45.86147385258829, 39.43825929395614, 44.050629292764974, 52.55725391449467, 59.41530243042977, 58.35955335247902, 51.01128701240786, 12.13708023871145, 0.40779448564975496, 10.848546335774085, 1.7348941127138755, 0.05877744098524413, 47.99702006001627, 54.91814813306255, 55.58406460669733, 57.33387708663941, 53.29922514577066, 29.245986284748202, 33.42702696400304, 40.83217551631313, 48.617303679066325, 9.32727663747726, 0.10220015872149699, 0.027384270590940313, 0.038237853816920714, 0.03711157433328129, 0.058722493328875115, 0.037277658364825675, 0.02899524432817294, 0.06001222916247864, 0.01146698503890225, 0.020213637823959994, 0.07811482169575269, 0.0045935345359236724, 0.06703614843108001, 0.05525339439871812, 0.01989593924654107, 0.06703710604098535, 0.02711721617097576, 0.0396985191881897, 0.0897563167757565, 0.1628420087358644, 0.09579453752526353, 5.741310504175002, 64.42126658654982, 51.63201385928739, 43.285959305301795, 26.82327158989445, 40.422240764864036, 57.228259425009455, 69.05127940639373, 58.61882986560945, 63.90176434670726, 54.59581951941214, 59.22032925390429, 2.845817823563853, 0.32029556951695876, 2.3866556104152434, 7.417084815040712, 9.996217258514898, 4.020938109005652, 55.13812249706638, 57.152024238340324, 57.80157266124603, 58.04383001019878, 57.248459631396884, 58.65323297439083, 58.45594559946368, 56.640606003422896, 51.22542488959528, 42.28923405370405, 41.80360148029943, 52.172053629352206, 53.743606152073035, 55.26858445136778, 56.267427782858576, 54.70883477118708, 57.22911842407719, 54.615937356025945, 57.15668009173486, 56.49104210638232, 56.3081302181367, 54.46552230465797, 54.12654322962607, 54.064283447880904, 52.62659749677105, 49.146674602262436, 46.7103845842423, 43.039414805750695, 41.99702924297702, 40.32100831308673, 40.32998661841116, 40.283416317355254, 41.152695917314105, 39.92309562621578, 40.264694844522786, 41.780086871116396, 38.96917127793835, 42.72580562099334, 42.482787332227154, 38.623975246183335, 40.778148789559644, 43.759475677244126, 45.70483399975685, 47.58059378593199, 47.27011073020197, 48.95725942427113, 47.49565878222066, 43.18600554620066, 39.07343179948869, 40.36071054397091, 41.93156880717124, 41.08199911732828, 39.26809118640038, 40.83071639460903, 41.28922970064225, 39.04450824183803, 40.25271200364636, 40.10095157930928, 41.24368313820132, 39.3725674383102, 41.36709659330307, 40.80719394068564, 40.67762236441336, 40.00948190689087, 40.61654321609005, 40.01223933312201, 40.34353840735651, 41.747660636901855, 41.97720558412614, 39.873081484148585, 39.65573118579003, 41.260310065361764, 46.145347549069314, 49.751562918386156, 50.03994341819517, 47.84109015618601, 47.56215080138176, 47.8795882194273, 43.39641324935421, 37.578785188736454, 37.54002432669363, 39.594271567560014, 40.48910933156168, 40.25445745837304, 38.84572644387522, 38.45426605593774, 38.7191633255251, 39.08314358803534, 41.113068211463194, 39.44635898836198, 40.97051751229071, 38.842404196339274, 38.33419053785263, 36.97256718912433, 38.91246557235718, 38.07111324802522, 39.57269068687193, 41.67461041481265, 39.90161672715218, 44.87200498580933, 46.30088521588234, 46.01727824057303, 47.312107547636955, 48.821651320303644, 45.24089213340513, 45.988331148701334, 48.189679038140085, 47.27732396894886, 53.48029352003529, 56.43190845366448, 57.675637122123476, 51.22782538014074, 53.82583472036547, 60.578555830063365, 56.4722853322183, 47.298767566680915, 40.27667376302904, 47.56070736915835, 54.21208227834394, 63.0145908940223, 60.18569123360419, 53.50241568780715, 13.824814346528823, 0.27377892525926717, 12.232270279238302, 2.778384435561396, 0.13257635697241754, 52.30483370442545, 61.03382141359391, 59.490023582212395, 63.07848238175916, 59.48928617662, 41.63204877607284, 36.123966324713926, 41.85155245565599, 56.89224566182783, 13.360862674251681, 0.23235486579998849, 0.060502655668965274, 0.031943474332952214, 0.042113086599255764, 0.030895058110716845, 0.0271654567275677, 0.008440408179716719, 0.052582018993674755, 0.04338108085756821, 0.19276336526438115, 0.24200601082655693, 0.11132868622700054, 0.16112914338948267, 0.13087034045207885, 0.1436027677188958, 0.0937359520204125, 0.15096815152754708, 0.12123864639790789, 0.20516513366132014, 0.2594291791319847, 0.22481007952122922, 5.575519271435277, 75.8906299837174, 58.318038986575225, 62.317389595893125, 31.186051368713382, 41.3347174275306, 63.40309381484986, 73.31115384255686, 64.72395981511762, 71.41176962083387, 58.95768734716601, 66.97456482918032, 4.181388299311362, 1.8202838662170597, 9.740797415856393, 10.594753296144548, 8.941728241982, 4.918638467788696, 57.996420321925996, 59.9202879782646, 60.96681164157007, 60.14582426317277, 59.62254478085426, 58.131647955986764, 62.323488881511075, 60.50433281929263, 52.40250856645646, 45.118831896012836, 44.990970473135675, 56.228529637859715, 54.44071331331807, 57.90035755403581, 56.819105225224654, 57.482738879419145, 59.28520917892457, 57.76888362822994, 59.4199308272331, 59.25698380316458, 57.98248806307393, 56.7857180103179, 57.00491574502761, 54.6698542564146, 53.8393747422003, 52.13952933588336, 47.853975142202074, 45.06465219682263, 46.27576243492865, 41.922943515162316, 42.69470122552688, 44.08331440341088, 43.23416440717636, 42.05328387598838, 43.94557645243984, 44.18118538395051, 41.11812414661531, 44.17405843734742, 45.463439572242, 39.29745012714017, 42.13517512044599, 46.282100985127116, 49.09967284048758, 50.31441127100299, 50.134229352397305, 50.85096405398462, 49.18481965218821, 43.29320392301006, 40.48271194581063, 42.40714442345404, 45.53534838461107, 44.36761956061087, 40.24532618061189, 43.743837187367106, 43.63231243625764, 41.48452843389204, 43.164499190545854, 41.918075853778475, 43.0324722105457, 42.542062190271196, 43.668104064080026, 43.094826129175004, 41.47267895360147, 41.18814237656132, 42.81183888835292, 42.92891771562638, 42.17397912856072, 44.15368172430223, 42.039398685578384, 40.64665525190292, 42.693210724861395, 43.11084508895875, 46.59374898479831, 52.310062223865145, 54.07482285653391, 50.80755126091742, 49.78718196192096, 49.529125305914114, 45.10245207817324, 39.24629457535283, 41.845021709319084, 41.57388394878757, 41.945085294785045, 43.024207776592625, 39.901879525953724, 40.466206612125525, 41.489686350668634, 40.39206989349858, 43.43735102684268, 41.44676777624315, 44.326752385785504, 42.003971838182025, 40.268311269821666, 38.710224243902395, 42.68045125469085, 40.935996732404156, 41.42915241179928, 44.498183496536754, 40.61797095883278, 48.70094822299097, 49.38510371792702, 47.189090251922615, 49.851171508912124, 50.61487267094274, 47.48835925132998, 48.719618705011186, 50.60468235323506, 49.84677453194895, 56.89910588725921, 59.28076513351933, 60.62848367998677, 54.07371674814532, 55.3051644755948, 64.63387473937004, 59.70336914062501, 49.02601072865148, 42.939841516556285, 49.855878353118904, 56.76612184893701, 66.77410033441359, 60.97566443104898, 56.46024757815946, 17.76777009810171, 1.2244431097661297, 32.12522956632799, 6.546745684839065, 0.1749674798620324, 59.37364685919977, 64.56556666281917, 67.08045313435217, 66.71291135972547, 65.39441447104177, 40.980550935191495, 45.33694705655498, 51.77142666232202, 66.31021730361446, 17.730399716284968, 0.4931888356804848, 0.19118217511042473, 0.32545946177936375, 0.15494384141939302, 0.14575527560326362, 0.10839836927311075, 0.13850296637223614, 0.12521596039615332, 0.1383428846395785], [0.026035965420305732, 0.031678042104167324, 0.04290285430127575, 0.027193325091033217, 0.0938499229209077, 0.0203874210391434, 0.05400938635331489, 0.07681592728101438, 0.056482915721473195, 0.014908347755760677, 0.10812902808069222, 0.03351958340875084, 0.007817554278224106, 28.82334501512589, 55.96365198012322, 46.53976540411673, 22.66724386522847, 21.951483872628984, 43.14873910719349, 60.89754650669714, 54.73786031046222, 58.30060797352945, 46.485950485352554, 61.09535555685721, 9.101478534360087, 0.7455209762819353, 0.5832129308292943, 4.362440003502754, 0.6012077845873371, 0.7137929239580709, 47.37324553151285, 60.68811939608667, 50.337874889373786, 50.380915057274606, 56.75268773109683, 55.033685468858295, 57.943950776130926, 49.771178691617905, 44.982058848104174, 40.40184443996799, 47.79380990612892, 51.73256774102488, 53.88249335750457, 52.7978991693066, 55.29141656814083, 53.47569650219333, 54.8394928439971, 52.899178689525975, 53.26908173099641, 50.955663880994244, 53.22988548586446, 55.43854075093424, 51.822193899462306, 51.712194950349875, 49.74219237604449, 47.55196048367409, 47.484483949599735, 43.68854353504796, 40.640638336058586, 39.47373713216474, 39.23648864992204, 40.27504597940753, 39.2310953909351, 39.34887240009923, 37.855598618907315, 37.950998506238385, 40.71994866094282, 39.8506219925419, 39.36571897998933, 33.128197270054976, 38.92367570630966, 42.076570987701416, 41.990510263750636, 43.352710200894265, 45.555697641065045, 47.201406494263686, 49.214119757375414, 46.03228915122248, 41.6793211813896, 39.35085711940643, 39.81734460399997, 37.56855564732706, 38.30929525436894, 37.20112369906518, 37.71699774649836, 37.16596357284054, 37.73420910681448, 39.13881771026119, 38.75569235893988, 37.988488520345385, 38.126908963726414, 39.15258130719585, 39.277571555106874, 38.75115025428034, 38.56426892742034, 36.24256703161424, 39.54111168461461, 37.47375196026218, 38.58342578334194, 38.30485513133388, 41.09305235647386, 38.935019200848, 42.52638447669245, 44.66863401474492, 46.26408553892567, 45.03783495195451, 45.71679722878241, 42.8063161911503, 41.75939636845743, 36.3159231985769, 34.85970012603268, 36.3828976692692, 38.90546806396977, 37.78862807058519, 38.06497866107572, 38.2176451529226, 37.495595639751805, 36.36322698285503, 37.581189601652085, 37.99604300529727, 38.3580973840529, 37.98352672207741, 35.569013703253965, 35.873287647001206, 38.00897898212556, 35.447463373984064, 37.71584849203787, 38.29203682561075, 38.21475044373543, 40.54251632382793, 43.03947756367345, 42.91509136076897, 45.80481129307901, 43.45050273403045, 42.83876595958587, 41.74415403796781, 42.74771990314607, 45.249497813563195, 49.21664184139621, 53.17439179266653, 55.33799863630726, 53.28874457267023, 43.981419071074455, 57.17329132941462, 53.42809069541193, 51.94826279917071, 38.55823632209532, 43.960414778801706, 52.61204550343176, 59.92467711048742, 57.81839962928527, 45.64001291028915, 14.90462520430165, 0.08528999353368437, 3.0481667720502426, 1.6674283651574966, 0.905601789634074, 48.07176866839009, 55.37535921219857, 57.150098354585715, 58.355583913864635, 48.984351235051314, 25.209571238487, 27.115456788770615, 47.70948286979429, 40.99056082387125, 2.8910236300960666, 0.16265670738873944, 0.020341022924009352, 0.04825467176194634, 0.1370661684702481, 0.0030970488085351406, 0.128332176245749, 0.05474337136312839, 0.1267338793484434, 0.03629794682285959, 0.07855169099545287, 0.023677031314300916, 0.02020674494786128, 0.05979635324629565, 0.07422636623584455, 0.021352276221037875, 0.056276359264889074, 0.025653126386685238, 0.08192715099862508, 0.024100649208130858, 0.030174925885794145, 0.04203001585518641, 0.04732716528158035, 39.36917066574097, 61.11296699893091, 50.658948344569055, 21.428335789711248, 33.161356987491736, 49.38118527012487, 64.38856578642323, 58.554240195981926, 62.598843189977835, 52.28885004597326, 67.7948736375378, 8.57402466958569, 0.42327448725700384, 1.447395655897356, 7.232715766276083, 1.2942975807574488, 0.8709740638732911, 48.446331485625244, 61.700589041556086, 52.51144063088202, 52.77187424321329, 57.159598335143066, 56.07744386119228, 60.527800360033595, 52.09319437703779, 46.23723691509616, 42.78931271645331, 48.9833745648784, 54.46496140572333, 56.38331813196982, 55.35288795348137, 55.79489592582949, 54.97890564703173, 55.722959656869214, 53.80667001970353, 54.33421311839935, 52.79894251977244, 56.253201346243586, 56.72419563416512, 52.90426600363947, 53.18618635977469, 51.27175984844085, 49.31055907280215, 47.59016436915244, 46.264062004704634, 42.57836372621598, 41.1957400075851, 40.537934995466664, 41.15839904354465, 40.09200073057606, 41.235544220093765, 39.0042882580911, 39.85741161531018, 43.18907283967541, 41.42519474029541, 41.70060396194458, 35.91333896883073, 39.828103665382635, 44.42982442917363, 46.22368904852098, 44.530503826756636, 47.11953486165693, 46.989527902295514, 50.27081804890787, 48.12679167716734, 42.57351959905317, 40.98610108898532, 41.42775997038811, 38.88934320019138, 41.210017435012325, 37.333123222474136, 39.73793621986143, 39.114781425845244, 39.412669750951956, 41.450211617254446, 40.70557709663145, 40.47353752197758, 39.8269465661818, 42.38126070268693, 41.355529523664906, 39.61878638113699, 40.40633163144512, 40.101567391426336, 40.57035730731103, 40.74689142165646, 38.4466488130631, 40.02837596401092, 42.4035083863043, 40.5443912167703, 43.41073382285334, 48.06713634921659, 47.307616433789654, 46.82971877436484, 46.477301659122595, 46.0788006167258, 44.20593161736765, 37.96257734298706, 37.58935989872102, 40.017561989445845, 42.376224379385675, 40.627553309163744, 40.66531004444246, 37.93425783034294, 38.95924375903222, 38.38194931707075, 40.4468418705848, 39.881181178554414, 40.09942577731225, 39.2906448148912, 37.703614619470414, 38.36961346287882, 40.4084732455592, 37.9293470228872, 40.12316396159511, 39.912144368694676, 40.51287105006557, 43.10010956179711, 46.29771201841293, 44.84153209194061, 48.503256843936065, 46.785195950538885, 45.67868355781802, 43.4817797137845, 46.548830001584946, 47.410786536432084, 51.893506511565185, 54.53252815431165, 57.624881652093705, 55.44261609354327, 46.52174211317494, 59.541477234132834, 56.820246634944795, 54.8463216904671, 40.469022873909246, 46.73553089941702, 54.81801002256332, 62.32032352878202, 58.80896675971247, 48.70312906080677, 16.30651560521895, 0.14392132239957012, 6.983347160200919, 2.5922598809965196, 1.1523699255720263, 53.6044208465084, 59.95250240448983, 63.05254374780963, 62.656090182642785, 57.063935649010446, 33.66293791801699, 27.764324680451427, 52.62484419730402, 48.71391557878064, 5.157242128925939, 0.2938830948645069, 0.061303577611162785, 0.05260760633034572, 0.038841626862244266, 0.0654225834014435, 0.12157748708681715, 0.11194245288929633, 0.048776634277835976, 0.08032890006659493, 0.1333742835108311, 0.08904424571101704, 0.20211431107694106, 0.12369811039177642, 0.23593053522129215, 0.12272627423367194, 0.15974206459378043, 0.1674309366893384, 0.19921676736445199, 0.1224085928932313, 0.14291944793395459, 0.2179772034287453, 0.13012980922095238, 43.26082083486742, 72.26737191600185, 60.56895779025171, 30.3936678747977, 32.85695948908406, 55.283332563215694, 69.12010131343719, 66.19577823146697, 66.54761483592372, 56.55890695510372, 74.90396561161165, 12.128222546269818, 1.790350053098894, 6.452096441099721, 10.537340583339816, 1.6564692628960458, 1.9479673115476488, 54.10500549500989, 63.07636430186611, 56.89009228060323, 56.657060346295765, 59.283914796767704, 58.915192388719134, 63.022721967389515, 54.99693678271387, 49.99909977759085, 44.62425631861533, 52.06180364854875, 54.631426795836425, 60.30195813025198, 56.57935427081201, 58.38429174115581, 57.7509387846916, 59.01105903810071, 56.59949171927668, 57.24400381888113, 55.776064626632206, 57.93221112220519, 59.94372021767401, 54.23568317967077, 53.565714897647986, 53.605581868079405, 51.64925267619472, 52.7887051336227, 47.87283782036074, 46.10491575733308, 44.86415240072435, 43.91785706243208, 44.45564146964781, 42.519955711980025, 43.450816523644235, 41.42314334069529, 40.78283994428573, 46.53279535232052, 45.38868311912783, 43.701428521064024, 36.57994970198601, 43.07862674036334, 48.380561182575846, 49.145694009719364, 47.167517215974875, 50.40601430400726, 50.52713709492838, 52.622377026465635, 49.89890675390921, 43.14152194607643, 43.33093712406774, 43.913969993591316, 40.73353182884955, 44.93898730124197, 39.840600336751635, 42.007360766010905, 42.43618957458004, 43.04385885115593, 45.795895745677335, 44.252619589528734, 42.61497120703421, 42.69621133804322, 44.24922673932968, 45.437579385695926, 41.58510977222074, 44.27110964252103, 40.875662834413596, 43.69655301493984, 42.572244828747166, 41.41645962192167, 40.86903402882238, 44.65004982486848, 41.767605889228086, 46.05884751965923, 48.540640954048406, 50.686561830582164, 49.526132537472634, 49.28700523991739, 48.58303000850063, 46.425047843687, 40.32654669977004, 39.65799439337946, 42.025725303157685, 44.721550710739635, 43.40723114628946, 41.74468748031124, 41.70359280801589, 40.29089235490368, 40.339969050499704, 42.461924245280606, 42.52743567189863, 42.25309333493633, 41.53284418967463, 39.826154247407, 40.09494643057547, 43.54194887222783, 38.6827088171436, 42.4406296976151, 43.01655131001627, 43.61317126981674, 44.038983775723366, 49.950470232194476, 47.38089807571904, 52.4774258367477, 48.03757344522784, 47.331735087979226, 45.49059806331512, 48.48636711797407, 50.673406201024214, 54.5922540849255, 57.61243597153695, 60.927364364747085, 57.86660163633285, 49.17014998774375, 59.80602541277486, 59.84616302674817, 56.332091977519376, 43.709379165403305, 49.351822407014915, 58.739583953734375, 65.04086379081973, 61.28986981607253, 53.44905576398296, 20.118783866205526, 0.24816235467310876, 11.049036325946933, 7.3039322803097395, 1.4216479923455947, 59.44559881764074, 64.26464634556925, 67.95261567638767, 67.94544558371267, 62.44411745379048, 34.76635163830173, 36.143276153072236, 60.5521268998423, 57.72818119295182, 6.823129615476055, 0.39517851906918716, 0.19441619996101628, 0.2227929853383572, 0.3256342830436845, 0.1897422975349811, 0.223519328621126, 0.1862993145421628, 0.4095122999241276, 0.1949741877615452], [0.022295839904296785, 0.07694791656948867, 0.06149157558778121, 0.05592537225194036, 0.02089248557064322, 0.04750171075424841, 0.04188770353193245, 0.1371705249672936, 0.03161655014170514, 0.0729572419978438, 0.12091188691556455, 0.13117207184193597, 0.08405854549979971, 6.3404383294044, 52.21925150963568, 51.017845215335974, 42.22506407768496, 25.53065646079279, 42.39394172545403, 66.21687273825368, 56.82447102762038, 58.75943114680629, 48.835842455587084, 59.00662675980599, 22.597931661913474, 0.3119727903075757, 0.20242710477642475, 6.623148062536794, 1.2100277865125288, 1.2221545293446512, 43.86256733248311, 50.875776967694684, 50.115884427101385, 38.17058063322498, 58.862793445587165, 54.1020009594579, 55.51020637635262, 48.736037746552505, 47.01721983571207, 43.685382104689076, 51.82505722968809, 50.291418337052875, 55.830903284011356, 53.63987907286614, 55.489123636676425, 50.53283237641858, 50.71494802351921, 49.760533378970244, 51.05842605713875, 49.063006524116766, 51.54086189885294, 49.428269401673354, 52.127703389813824, 48.67082834243775, 49.58626639458441, 46.39162924981887, 46.18815629712997, 42.72614294482816, 41.62340387221306, 39.30298851382348, 39.70341151760471, 40.44592795833465, 40.84577829607072, 37.52006730725689, 39.630212245448945, 38.31018955476823, 38.400964967666134, 39.46755939914335, 38.01916537746307, 34.875695551595385, 40.22163114240093, 45.72544605501237, 41.97092586948026, 42.55620625711257, 44.74590078476937, 43.78283731399044, 44.06094120394799, 42.59346877374957, 41.43869161605835, 40.03463606680594, 38.28524720284247, 38.37865060375583, 37.19740529214182, 36.83693947330598, 36.613835057904645, 39.31151966894827, 35.9347511876014, 38.331268372074256, 38.92982598273985, 38.12036645027899, 36.404976690969164, 36.50432248269358, 38.40487949309811, 37.87996438241775, 38.21580556131179, 39.14863148043233, 40.641136477070475, 37.699300012280865, 37.34585523605347, 38.5556318683009, 43.83996271318005, 40.37114404862927, 43.807324670976215, 47.67961009856194, 48.352841792568086, 45.3280746552252, 44.51234325285881, 40.6973244297889, 42.39989196100543, 36.92092918580578, 35.62976729485297, 36.8397282784985, 38.14061372510849, 37.56716712828606, 36.82741988089777, 36.52584452782908, 37.93094734991751, 36.62550018679711, 36.794734770251864, 38.318128431996996, 37.18223748668548, 37.590242432009795, 34.74769292339202, 35.15958101518693, 37.31863790942777, 36.57633327668713, 36.630379615291474, 36.447322599349484, 37.068559354351414, 37.155153520645634, 38.93535652468282, 40.0070696492349, 39.621994879937944, 40.48371215020457, 39.44410754788307, 38.635773735661665, 39.75166451546454, 41.70877033664335, 44.21032467196065, 51.057119907871375, 51.94215566881242, 56.13540472522859, 50.79892989127867, 54.26985094624182, 55.75077710613128, 51.82066025272493, 46.41968596366144, 40.163666355994444, 52.013244705815474, 55.70181415927026, 59.63202514956075, 33.37817384350684, 4.373713875970533, 1.0264490953376217, 5.26362318185068, 2.8675705530951103, 3.823547281565205, 52.69658434775568, 56.69217732644851, 49.82253036191387, 47.072211465527936, 40.8395613393476, 29.58508303088527, 30.33028825636833, 41.42408470953665, 30.509191482297837, 0.17552632568103654, 0.08011672435508621, 0.030301904959243633, 0.008652981299336159, 0.07674365454623777, 0.08163153299040372, 0.034973917063325644, 0.05522535558068945, 0.04365090851581866, 0.011851746953212687, 0.010017544770943783, 0.10336220685032108, 0.07639836339700608, 0.0626146451630179, 0.0655945931230822, 0.03358367049405652, 0.06621854875477091, 0.08586447520722305, 0.08972872228872392, 0.024097575280334682, 0.06111388274979207, 0.240867757388661, 0.3105706655450406, 12.096239539884753, 60.08080705519646, 56.8034706577178, 29.10735599456295, 30.057787472201934, 53.06503611226236, 71.55233952306932, 63.21295692074684, 62.17525466795891, 55.419093639619895, 65.28984408224782, 25.935637258714248, 0.33109216920791135, 0.7909985295226498, 3.7803016795266062, 2.212448197026407, 1.553043961044281, 47.0859319163907, 50.95081975383144, 54.5232399817436, 41.12345464767949, 60.410654852467204, 54.715028193689164, 58.848657223486136, 49.74328671732257, 49.78671127750028, 45.81041636005525, 54.06430305973176, 53.02988775314824, 57.49214080072219, 53.62735494490593, 58.99278863783806, 52.26019713186449, 54.76259477676884, 50.82379771817116, 52.69177552192442, 49.8584710398028, 52.558140370153616, 50.4799392146449, 54.17366266250611, 51.77050490533152, 53.727167498680856, 49.20295276949483, 48.71593559941938, 44.70726543857206, 43.31793838931669, 40.73541848890243, 41.73055125821022, 41.100551928243334, 40.81573686292095, 40.30339294864286, 42.10447865147745, 38.853347609120036, 42.14718149554345, 42.5429251117091, 40.20077197782455, 37.83125638961792, 40.988266237320445, 47.792413542347575, 45.54471892695273, 44.999101546502885, 45.978882158956225, 45.363489735511045, 46.90271408327165, 46.9528341293335, 43.29890704924061, 40.826617517778956, 40.81287745506533, 39.396391914736846, 40.71881117359285, 39.92709644379155, 40.56249687748571, 40.82112227716754, 38.164842205662886, 39.34675432020618, 42.52512931823731, 40.695998668670654, 39.91902028360675, 38.35019773052585, 40.42340963117538, 40.32727626062209, 39.91516067135719, 40.87146982069939, 42.085929762932565, 41.25677208746634, 39.433528915528335, 40.27777202667729, 44.25961709791615, 41.194025931819795, 42.980794983525435, 50.15409615732009, 48.86118881164059, 47.433657876906864, 44.957685239853404, 43.809093659923924, 45.016199158084014, 40.2282089571799, 37.751353786837676, 39.36302823405112, 41.31871807959772, 38.46905731385754, 40.01580868997882, 39.12143768802766, 39.839423625699936, 38.16824290060228, 38.58882296469904, 41.23762699865526, 39.26313723287275, 40.26373778620074, 37.67894683345672, 38.48067929667812, 38.418505807076734, 38.64221818985478, 39.048281561943796, 39.106367941825624, 39.46297414841191, 39.71165633970691, 41.33385450609269, 44.099670687029445, 42.9972061803264, 41.17999169134325, 41.04589369989211, 42.56132887255761, 41.186322396801366, 44.13001414268248, 48.129168633491766, 53.73733820453767, 55.03758822717975, 58.14633723228209, 51.79043054580689, 57.3496763936935, 59.32560959169942, 54.92576537593719, 47.2464745275436, 42.63992924844065, 54.889848232269294, 60.037457020052024, 60.370164225178385, 37.64863475676506, 5.338509073180537, 1.5462673311271977, 8.066929376894429, 2.0266457671119325, 3.948001390503299, 58.371932352742846, 60.13134679486675, 60.21018643533031, 52.96329375236265, 51.463869694740545, 33.35119970383183, 27.02380668732428, 48.95173672706851, 38.24074399086737, 0.5281663265439772, 0.054144650667665474, 0.049551321539066495, 0.04073625422954079, 0.0388524976498898, 0.08375144383359341, 0.09221656984018703, 0.038879234118447195, 0.14764552094763325, 0.05348195396964589, 0.11016125250006877, 0.336645050274749, 0.23051761841822058, 0.09093390882856424, 0.10051959164200291, 0.15856124731081148, 0.1531119413313366, 0.2661326629740577, 0.13814315019596007, 0.1281399034985131, 0.20900574693035698, 0.5227768060661132, 0.48241656694200735, 11.977760426459774, 69.21172003592216, 61.07562995726063, 56.0528584449522, 38.563072604517785, 56.46947691517492, 77.0122709581929, 66.20476830390193, 70.13164920191612, 60.80297423947243, 72.01604996958088, 30.90626870432208, 0.7645126636470518, 2.355000367087703, 17.909153892147927, 3.892999464465726, 2.1685968339443207, 47.917623442988244, 51.04559598430511, 53.68905775008663, 42.387814983244866, 61.25869089557279, 56.77559437290315, 60.2143951385252, 51.79651414194415, 52.96014408911429, 48.502597885747115, 57.599225428796586, 54.2482465313327, 60.41158053182787, 55.35167201872795, 60.971314522527884, 55.43026454987065, 57.686423640097345, 53.57549728885774, 55.20110007255308, 52.30363738152289, 55.52146750111734, 52.57145681688863, 57.97419617252966, 55.19614219665528, 54.631501320869695, 50.53024753447502, 51.452600725235484, 45.845305842738, 47.116173390419256, 43.103702452874955, 42.98052041761337, 44.423948718655495, 43.365528506617395, 40.845570410451586, 43.909820125949004, 43.214627081348056, 43.163161662317094, 44.6970162853118, 41.687613071933875, 39.93115217454972, 44.2642847184212, 52.09870138475972, 47.68081426620484, 46.64122535336403, 47.754974519052816, 47.05143074835501, 48.554318258839274, 46.797602407393924, 46.0216595280555, 43.02446273065383, 43.192363708249985, 41.25539141316568, 41.63235079857611, 41.65368456994334, 42.160721517378285, 43.90574478333996, 39.60019826889038, 42.836796929759366, 44.81698197703208, 42.97088707647016, 41.79174023289835, 40.687200792374156, 42.58283130584225, 43.12113346592073, 42.030734169867735, 43.88339119572794, 44.5320100169028, 42.709719980916674, 41.51267928461875, 41.71824678297966, 48.66953003791071, 42.09822639342278, 45.435249497813565, 50.52790587948215, 51.44445788475775, 49.70479257645146, 48.06729324402348, 47.25378190317462, 48.626234915948686, 42.07916367438532, 39.14308917137885, 41.30223235776348, 42.21089647662255, 40.185968952794234, 40.88432342775407, 40.15550782603603, 42.48352473781955, 41.32287579198038, 41.206040151657604, 42.18452638195407, 42.12127031818513, 43.27778508586269, 40.21630456370693, 40.26856230151269, 41.92565779532156, 39.778670034100934, 41.74244780694285, 41.58812999725342, 41.93289849065965, 39.75924253463745, 43.614120483398445, 46.29557040429885, 46.22721525930589, 44.43342516499181, 43.10902903156896, 45.078686437299176, 44.208010473558986, 47.2730681973119, 50.166549682617195, 55.85197425657704, 56.126642150263635, 60.446222905189764, 53.52043897874894, 57.055059325310495, 61.504941217360965, 57.2225994448508, 51.014617104684156, 45.88088958494125, 56.23926516502135, 63.71394949574625, 63.19733804272067, 43.173391203726496, 6.822314252776485, 1.7741884171001374, 16.42825322766458, 7.407722117439394, 5.3693536116230876, 65.55314494717506, 64.58927346814063, 62.80357522349205, 58.63280527053341, 52.32043689297092, 41.17865416311449, 40.29121398925781, 54.989095964739406, 48.03045826573526, 1.3214461433310665, 0.20452267700626006, 0.12847792447334336, 0.10252043710000093, 0.2106107624187585, 0.1367149478004825, 0.16441477192265375, 0.1372496158845963, 0.23066125990402317, 0.10124918313757067], [0.03254429602454747, 0.029034797447703542, 0.043707748409360654, 0.03356797335248801, 0.07104009930645266, 0.029057278297841552, 0.03487727507167766, 0.050997553813842036, 0.0587596102888065, 0.013697917344078664, 0.04396865880417247, 0.04985527841434364, 0.07846385135405487, 0.3348592686797342, 37.5897168344067, 51.44907451445057, 38.419788422123084, 26.982912055907715, 27.97917446782512, 53.761252895478286, 58.62164612739318, 59.314881909278135, 52.74005205400529, 49.346688024459354, 36.8518562470713, 0.20181095558068446, 1.141771068496089, 2.979486070332989, 1.1241899022171575, 0.21810582959123198, 39.871838092803955, 56.805004304455174, 55.56907330789874, 49.39502731446297, 47.389907760004846, 57.495019820428666, 54.283210539048724, 52.06150947078582, 53.12295775259695, 50.85219175584855, 49.76166302157987, 54.6536313333819, 52.46428589667044, 53.312827925528254, 50.26279680190548, 51.998853529653246, 47.50175806783861, 46.466091525170114, 47.256303987195416, 47.900290489196784, 47.819599490011896, 46.26598396608907, 45.92405134631742, 49.50413980791646, 47.48875933308756, 45.92451810836793, 46.024679753088186, 45.00807592945714, 40.63412720157255, 39.403577696892526, 37.86552613781345, 40.44375888762936, 37.696193495104396, 38.14119031352382, 38.27456658886325, 38.39847034023654, 37.72834908577704, 41.17861101704259, 37.188470132889286, 35.428726211670906, 41.17251565379482, 43.30824229025072, 41.946995489058956, 41.947277899711366, 42.67614449224165, 45.304250178798554, 45.455131992217034, 41.37984037399292, 37.30823186136062, 38.02923017932523, 38.50813196551415, 39.070242912538596, 36.60091477055704, 37.15077223316316, 38.34609885369578, 37.72023370189052, 37.7760882531443, 39.215813836743756, 39.03743228604717, 38.520032436616965, 36.62378218866164, 36.194192440279075, 38.602919963098344, 38.29220156515799, 35.26587332448652, 36.36496851521154, 37.3900995715972, 37.470939620848625, 36.90714989939044, 37.17883286937591, 37.99135185057117, 40.503469128762525, 43.192038151525686, 46.77926532683834, 45.11743553223149, 43.74060515434512, 44.44881262317781, 40.40814376646473, 44.78216309701243, 36.97590904851114, 34.78133901473015, 37.297900338326734, 37.57628271656652, 37.74752947591966, 37.09960883663547, 37.66896440136818, 38.439627770454656, 38.097436274251635, 37.33128755323349, 36.86674556424541, 37.200892279225016, 36.02960194310835, 35.84691362996256, 35.49462203056582, 34.67791788039669, 35.51888973482194, 36.0830795380377, 37.838034245275686, 36.10110282897949, 38.18915697836107, 35.47501017970424, 37.14477492916969, 37.093568386570105, 36.80836108423049, 37.947915523282944, 38.19276948128977, 38.87106495518839, 39.789181986162745, 40.86681396730485, 49.9181773585658, 50.805829340411776, 52.46349357789563, 55.27709991701188, 51.22662513486801, 55.2397354187504, 54.79569958102319, 49.817850974298295, 42.875879426156324, 52.351670726653076, 53.51618712948215, 59.41154087743452, 21.77671874723127, 0.4836870471556341, 6.353680741402411, 5.241192617724019, 2.161194831132889, 3.7276659232954827, 51.54907926436394, 55.532410913898104, 50.62632991421608, 46.20466163081508, 34.407227270064816, 27.190858471778135, 38.081766405413234, 45.84569415738506, 16.50761454336105, 0.021257545618760972, 0.04365548589116624, 0.02244344014944809, 0.08182151513474603, 0.06270448812433789, 0.05862252268519613, 0.06256476134782837, 0.02335020862970381, 0.04789033566691703, 0.012856987417645514, 0.06766591100923477, 0.009145089368816585, 0.03444200689573923, 0.0631078947035055, 0.04782927079847263, 0.04073792430121572, 0.02859471057872138, 0.10254987785893102, 0.03400262865808702, 0.04732229296238192, 0.02407159340838271, 0.08565363248870259, 0.036781482368467316, 1.0850691627110205, 46.71336166320309, 59.3420757016828, 40.195590526826926, 30.157431364059452, 42.07411558397355, 59.78525254034228, 66.14055125944077, 63.49633247621598, 58.19011872814548, 56.03814171206567, 40.895921876353604, 0.06714523169061831, 0.39766487274919793, 4.354044660445183, 2.1222863899123285, 0.2899602956829533, 43.68945744729812, 54.35994386672974, 56.7209400669221, 50.795313465979795, 47.07995422424809, 59.45232960485644, 56.318508809612645, 53.30717971248012, 53.299738976263235, 54.172748750255955, 51.711802713332645, 57.379847265058956, 54.14745338501469, 54.55761563393378, 52.85733876689788, 54.34217552984915, 50.73314389874859, 48.40868849908152, 49.33227331407609, 49.121410615982555, 49.8082294002656, 48.782372705398075, 48.508650102923, 50.7930463360202, 49.59033781482328, 48.59167098999024, 48.56162955684047, 46.68878801407353, 42.22889623334331, 40.584340556975334, 39.31057437773674, 40.95935052441013, 38.89386961537023, 40.241980398854906, 39.893136562839636, 40.35477207553002, 41.06935339589273, 41.1953007021258, 40.74785240234868, 37.236173998925, 43.48332120526222, 45.66711256580968, 44.599392414093025, 44.08911166652557, 44.33739769843317, 47.90753902927522, 46.34055214543497, 44.89583338460615, 38.43404623769945, 39.96230756082843, 39.772319716791955, 40.52168069347259, 40.29139049591557, 38.728035726854884, 38.95609801815402, 40.40406450148552, 40.89375672801849, 40.91738900830669, 40.730562594629106, 39.4827821177821, 40.888967514038086, 38.48215803023308, 41.411509590764204, 38.77733599755072, 38.9939175113555, 38.721618729252974, 39.553659346795854, 37.91349672502087, 38.650627751504224, 37.40082725401848, 40.9609704632913, 40.85945560086159, 45.41396671725858, 47.44944933922061, 46.26507005383892, 48.234248930408114, 44.440454052340606, 44.25827172494704, 47.51330944799608, 39.24127001916209, 38.669968958823915, 38.97849082946777, 40.132322695947465, 39.492795928832024, 40.143144515252885, 39.077750329048406, 38.77146028703259, 39.95424316775414, 39.842636046871064, 38.463161991488555, 39.53767176597349, 39.087811208540394, 38.01645109730382, 39.410586972390455, 37.680060786585656, 37.906636499589496, 37.38312167506064, 39.58816835957189, 38.99221128033054, 40.031611919403076, 39.140986780966486, 39.10088054595455, 38.62211212035149, 39.13671139747866, 39.26891880650675, 39.93982453500071, 40.2739594828698, 43.09298653756419, 44.60714301755352, 50.529368923556426, 54.16906564466415, 54.96264742266748, 56.28461953132384, 51.37908766346594, 58.111679169439505, 58.303757636777824, 52.239945934664824, 46.182912088209584, 53.337299593033336, 57.35719557731383, 60.8304504425295, 25.1609024693889, 1.0058329951378608, 10.380019218690935, 4.917541675029263, 1.5345633462552102, 4.861595928668976, 57.34147079529301, 60.06675320286905, 56.7580613782329, 48.31605388272194, 45.8999954500506, 31.02074307780112, 37.69993543624878, 52.63073559730284, 21.366444710762273, 0.02045568713407603, 0.030804399265757496, 0.040019119323621836, 0.054370742366318746, 0.047698311898256504, 0.046034349774521206, 0.049608215058763186, 0.052174395100483974, 0.08387469205885165, 0.05073534873043818, 0.174374328625779, 0.12413563852709149, 0.17668140240974967, 0.19801523506401048, 0.19527843191979394, 0.11012337711309234, 0.12012316109312159, 0.11997107731839342, 0.13071493185575933, 0.13351614767264935, 0.1193439347609397, 0.2260291858786537, 0.1691148745556993, 1.198720451324217, 52.854569573556226, 66.32539687618133, 51.90355170157648, 39.322086534192486, 40.99667187659971, 63.65905200281451, 68.43974267282795, 69.42912132509294, 63.669399215329086, 64.99712151865806, 48.94605713505899, 0.3551906293197986, 3.949025864562681, 11.401243594384963, 3.801431977941144, 0.8135980007148559, 48.080284134034194, 54.66201343844014, 57.4833546915362, 48.70563153297671, 49.21606525298088, 61.215364394649384, 59.58563919990294, 55.774750632624475, 57.47445483361521, 54.9105191230774, 55.386184953874164, 60.445273691608065, 54.25411047474031, 57.41823942430558, 56.63469499157321, 56.94171067207091, 53.75094098429526, 50.54063004832114, 53.580141375141764, 52.21392493094168, 52.281770167812226, 49.96861903898178, 50.167302777690274, 53.368043130443944, 51.21301451037007, 50.38041299389255, 52.10105088449294, 50.528964919428674, 45.49909783947853, 43.14554237550305, 41.752006623052786, 42.7952786414854, 40.61326803699617, 39.9066295162324, 42.989745832258656, 42.78277020300589, 42.68999830369027, 43.019822566739975, 41.70521666926723, 39.74065834476102, 44.98171367952901, 49.81996905419135, 46.73080444335938, 46.03223031566989, 46.21372230591313, 49.49376513881069, 49.065359946220156, 45.198773722494806, 41.00138656554684, 41.605745361697295, 41.464371373576505, 42.470161222642474, 41.86315874899588, 40.7795294638603, 40.675598421404445, 42.69472083737774, 42.30624537314139, 44.46207023436024, 43.92705502048616, 43.17099855792138, 42.45446781958304, 40.857694456654215, 43.11615990054223, 40.52442243022304, 39.91647074299474, 40.32341664837253, 41.7919167395561, 41.17837567483225, 41.81268176724834, 41.15484145379836, 41.36838705308976, 43.69050472013412, 48.24994233346755, 49.660889487112726, 48.487084911715606, 49.65378215236049, 47.070230668590916, 45.50235732909172, 50.16689877356253, 41.63112309671218, 42.092436975048436, 40.604215206638465, 40.915549416695875, 40.89796150884321, 42.21467371909849, 41.00918815981957, 42.75832206972184, 41.362483885980424, 40.910183614300145, 39.97350592767039, 41.95031381422474, 41.09003997618153, 40.844197580891276, 40.74300043044552, 40.59835910797119, 39.47563163695797, 39.82868417616814, 41.45464389554916, 40.54071987828901, 41.482249536821925, 41.15384909414476, 42.0674357875701, 41.713320286043235, 41.29348154990904, 43.51730069806499, 41.88414735178794, 44.25896206209737, 44.57000209439186, 46.13473361538303, 53.117427210653986, 56.078502901138805, 57.16289312608781, 58.909430426936, 51.8214721833506, 59.67594785075034, 60.34835192465014, 52.85872336356871, 50.08287375973117, 57.195421341926824, 59.015334421588534, 62.73083486864644, 29.689004267415694, 1.9622664345848946, 12.302508161913964, 13.57274813036765, 4.794539578499333, 5.247271310898566, 62.006416243891564, 67.20424313699046, 62.10122777569679, 56.648737076790106, 46.1865520477295, 37.8198972055989, 47.593164982334265, 61.28238201141358, 26.490933087564287, 0.09900215532510512, 0.16108650293561722, 0.20705283559378118, 0.14794948931422927, 0.2145323205378748, 0.17331842963974323, 0.1466834064452879, 0.11538587255223144, 0.1567125852189718, 0.09952707110994286], [0.05663653167204992, 0.01039755502490387, 0.054007118733059016, 0.027840129295063597, 0.02073762281196973, 0.10898143113140138, 0.02411043406614373, 0.06581118150103478, 0.10514545269430646, 0.05679361034004439, 0.03450579137631482, 0.06508307621604012, 0.04911208885811991, 0.08175450542400922, 19.34059739112854, 53.63548209590297, 35.833012750071866, 27.788731628848662, 29.578922948529645, 52.05113480168005, 59.7235458127914, 52.745194281301195, 55.18816801809496, 50.11530783868606, 55.37899132697813, 3.273078419508473, 1.3717679463086592, 0.6117924230713999, 9.378338052380471, 0.27698720955560285, 32.19929764347692, 50.20147054426132, 53.20930088720014, 53.312502368803955, 51.31659646188059, 50.767927477436686, 55.201912003178755, 57.52578689206032, 53.8181939432698, 52.4908991782896, 56.75309957996492, 54.27385960855792, 53.3053126642781, 54.18303712721794, 51.3933886251142, 51.14397687296714, 45.40411372338572, 43.48951462776431, 43.48913808022776, 45.376680666400546, 44.152563848803126, 45.93831700663413, 49.0282464796497, 48.196649089936294, 47.84326314926148, 45.7481251993487, 45.095823272582024, 44.40155982971192, 38.912449882876494, 37.709745284049745, 39.41462309129777, 39.29006038173553, 40.8930742356085, 38.611156940460205, 37.681629734654585, 39.24105036643244, 38.389872504818825, 39.872830452457556, 36.85429203894831, 36.06804901553739, 42.41868011413082, 44.50440045325987, 42.72462890994164, 43.72500196579964, 43.97495500503048, 45.49562654187603, 45.129587035025324, 41.59252697421659, 39.589192098186864, 39.01390590975362, 37.93847045590801, 38.01974981061874, 35.26734029093097, 37.9148107190286, 37.805749216387355, 39.02439432759439, 37.14303731918335, 39.27419439438851, 40.77022167944139, 39.43968703669887, 36.821563782230506, 39.109078299614694, 39.59182400857249, 40.25493990990424, 37.04913577725811, 35.96740491928593, 37.562542653852894, 37.21529130012759, 37.82620829920615, 37.36087791381344, 38.191126008187574, 38.790401412594704, 42.68820578052152, 41.72261630335162, 43.9619601926496, 42.53353495751658, 41.43904855174404, 42.237415621357584, 41.98873735243275, 40.253735742261334, 33.88640319147418, 37.51770996278332, 39.292205918219786, 38.60253949319163, 37.90547940038866, 38.437184133837306, 38.10324138210666, 37.767208007074174, 38.00422114710654, 36.78789807904151, 37.00299693692115, 37.02884143398654, 35.83882962503741, 35.64978707221247, 36.996160245710804, 36.35840246754308, 36.79388361592447, 38.101927388098936, 35.651469769016394, 38.03611786134782, 36.83058131125666, 37.28018691462856, 36.15617290619881, 37.31862221994708, 35.61612136902348, 37.20206114553636, 35.70767733358568, 38.554298262442316, 39.163328601467995, 44.042227575855875, 51.25419547480922, 51.79533350852228, 54.76955306145453, 53.32386547519315, 52.179223722027196, 54.19769502455189, 52.27838908472369, 46.67811132246449, 50.65253526933732, 58.16066172815139, 54.0692570132594, 15.56068083932323, 1.5887953845723983, 9.716225727911919, 4.7190310109046205, 0.4864327369197723, 5.6235648739722475, 51.423579108330514, 53.3392882347107, 57.968587183183246, 49.7895981419471, 28.205526605729137, 24.62839561124002, 32.89729910512125, 45.07403842864498, 4.518063962459564, 0.155304791405797, 0.037233864948634184, 0.05396294993378463, 0.01419592620579586, 0.033656061972461404, 0.006574325248478882, 0.044267241572660786, 0.018904113939272302, 0.027068119511128436, 0.04353742408115537, 0.028468447797481092, 0.03449740271354395, 0.04698670431671124, 0.02491270240786816, 0.08086776631253381, 0.07758756168186665, 0.05125107529062418, 0.04677266701154652, 0.053311334697589766, 0.02065857019906323, 0.030044796275756055, 0.045087170156259695, 0.02315952359969097, 0.06086177087479061, 26.92784982342874, 60.58564747533491, 40.47881703222952, 28.306837504909886, 36.3447839983048, 57.6494788354443, 65.78329393940588, 61.34081355987057, 57.28782846081642, 55.715985682702836, 55.91836429411366, 3.549533688252972, 1.7048487571939346, 3.7519919728079154, 8.278219123040477, 0.7708274344763448, 34.55122924620105, 53.045565466726984, 53.78435173342305, 54.76384993522398, 52.83593047049738, 53.25392961502076, 57.43252077410298, 57.049191459532715, 55.754016983893614, 55.86114475803991, 57.81858005831319, 58.808060692202666, 56.05519225520473, 57.95112086880592, 53.89775529984505, 52.814600621500325, 46.53290125631517, 45.75616213583177, 46.09088936159688, 48.772731519514515, 47.75333104595062, 47.20601920158633, 50.98825485475602, 49.799219715979795, 50.286715415216264, 48.4649117531315, 47.217311705312426, 44.899975407508116, 40.74662470048474, 41.33683942979382, 41.07173427458733, 40.46504951292469, 41.7697004349001, 41.54716084080358, 39.14154767990112, 39.97227430343628, 39.141645739155436, 41.89747948800364, 38.80962102643905, 38.73340545162078, 44.34678000788535, 47.01363478937457, 45.62492747460642, 45.99932555229434, 45.14805747616676, 46.07742386479532, 46.161907795936834, 42.38512423730666, 40.49862892396989, 40.85169715266074, 39.742258671791326, 39.74643599602484, 37.359206984120036, 39.736096628250614, 39.20323871797131, 41.520531869703724, 41.043112739439934, 40.220356372094926, 43.05776365341679, 42.85638524639992, 40.09382463270619, 41.05646056513633, 41.115276505870206, 40.72957807971586, 38.036890568271765, 38.79225669368621, 39.31885057880033, 38.7106910059529, 38.72269738105036, 40.01220403179046, 40.47151357896867, 40.4336509396953, 43.301523270145545, 44.594403159233835, 46.244167743190644, 44.09250059435445, 43.33915056720857, 44.25648312414847, 45.48680905372866, 41.2436713710908, 36.64688102660641, 39.031737004556966, 39.35428134856686, 41.38552781074278, 39.98562212913267, 39.216688525292184, 39.93707495350992, 38.41455598031321, 39.164968152200025, 38.97761614091935, 40.99410272413685, 39.80955477683775, 38.381796344634026, 36.72931748051798, 39.58573649006505, 38.74940479955366, 39.25394319718884, 40.73674817239085, 37.49262640553136, 41.1801407414098, 38.71629999529931, 38.838552428830056, 38.34841305209745, 40.72545959103493, 38.59905250610844, 39.16414053209367, 38.81007209900887, 40.024300621401885, 42.43342430360856, 47.930939889723255, 53.583863704435295, 53.92682398519209, 58.149600644265455, 53.89200902754261, 53.69536884369389, 57.84786055164953, 54.815809572896654, 50.062771612598056, 53.57656025117444, 58.65244850035637, 57.009469616797666, 18.23310636704968, 1.9822489494277586, 11.451993180859475, 0.4285441915835104, 0.3126561713795508, 6.228498787649217, 57.631102531187004, 58.028815177179155, 63.72843873116278, 53.11441875273182, 37.849216922636955, 25.14237319269488, 36.990759141983524, 53.104844247141195, 6.959228506011348, 0.1768282001778003, 0.17914621369732966, 0.03603147846015711, 0.01703345171746708, 0.06858977474152081, 0.04163080743784386, 0.020964114791563442, 0.05454441449875313, 0.02720013752789988, 0.06789232829525586, 0.15009406052770155, 0.13077411980878922, 0.1871252186115711, 0.18270994746877303, 0.10268144579904695, 0.278689548853905, 0.1128017124269278, 0.19151415165153243, 0.1828831905919698, 0.094510528198894, 0.1970032175942775, 0.23604417670397992, 0.10094272498522075, 0.16705920018496054, 29.347665886725153, 68.04905891418457, 49.935071006897964, 41.25133568240751, 43.039807042767926, 64.6382599492227, 70.01784555373654, 65.75845749147477, 62.99606553969845, 60.4655719572498, 62.850537761565185, 4.67461311048077, 4.3479321368279, 8.267768948308884, 16.753613833458193, 1.2597531440757936, 39.47666322031329, 52.79263142616519, 53.88016739199239, 54.19065829246275, 53.97766574736565, 53.51269229765862, 59.464759595932506, 61.59017432120539, 59.76032195552703, 58.73031931538736, 62.89776309843987, 58.93791075675719, 56.43270077243928, 59.92746983805011, 55.675891214801425, 55.39464158396567, 49.343463836177705, 48.33871341520741, 48.76710291831724, 50.761635995680294, 50.521990945262296, 49.59061238073534, 54.46887985352547, 52.80508495146229, 52.52403536150533, 50.6096363067627, 49.9916119729319, 46.24593280976819, 42.65956855589344, 43.42838056625859, 43.67827084756667, 42.467913704533736, 45.168912718372965, 43.60267108486545, 42.36761085448727, 43.79263147231072, 40.32522878339214, 43.90498384352654, 40.65827331235332, 42.278455380470525, 47.63523632480253, 49.35725488970357, 47.334625874796224, 47.43002968449747, 47.73286411839147, 47.80575352330362, 48.70722401526667, 44.24111135544316, 42.84353163934524, 42.12109773389755, 42.888156444795676, 42.575778884272424, 39.91629031396682, 40.94279419991278, 41.22151782435756, 43.97598266601563, 41.9006173841415, 42.5981403166248, 47.40531875241188, 46.04922202325637, 42.37972705594955, 44.78512056412236, 43.53764603214879, 46.272691219083725, 40.779858942954775, 41.98170062034361, 41.851364181887725, 40.23040156210623, 42.14195297610375, 41.45005864481772, 41.52599180898359, 43.101564761131044, 46.208187841599994, 44.2521567498484, 48.68519598437894, 45.46565178901919, 46.170478174763346, 47.15737004433909, 48.771672479568, 43.03482955501926, 37.4967017481404, 40.32988463678668, 41.42395919369113, 42.8656106610452, 42.355243621333955, 41.221639417832904, 43.39717026679747, 41.32118525043611, 41.26580530597318, 40.479742711590184, 43.20000056297549, 42.4784452684464, 39.69129531614242, 39.56600304572813, 41.67306107859458, 40.00202155882313, 41.58298776995751, 43.403430369592485, 39.04561435022662, 42.35061522453062, 40.17194255705803, 40.60934174445368, 39.531054727492794, 41.70461654663086, 40.6595794616207, 41.37647105801491, 40.4501288167892, 43.32810125043316, 43.715078369263686, 50.34309556407314, 55.77936333994712, 56.909421720812404, 59.1497971934657, 54.20095843653525, 55.39996031791934, 59.819581124090384, 57.004962813469675, 52.3360675381076, 55.95249283698298, 62.29664810242192, 60.00817260434551, 24.058553672605946, 2.9624468040081764, 18.256936727031587, 16.0272712861338, 2.2836019531373055, 8.648921347433522, 62.62307951527258, 62.84261065144693, 66.66571740181216, 60.28647261281168, 39.77925838962678, 34.12713081605973, 44.223182201385505, 61.87340474897816, 10.296241314180437, 0.44552921888328373, 0.20208564406681448, 0.18710943720033094, 0.17955535061417088, 0.24939871333058805, 0.12321601892190596, 0.1641910895705223, 0.15672393864200962, 0.1314011474530543, 0.13894567326191934], [0.023417737365009326, 0.010244944564727767, 0.03467238485632885, 0.03653569837972041, 0.02459626979074411, 0.04783818806191126, 0.022696982693648147, 0.03170544123877922, 0.038471828560314836, 0.09841577630610236, 0.008953580794285142, 0.04437956538411879, 0.055571002960805936, 0.06077594221419385, 2.5761788987344314, 47.00833566727177, 44.968648264485026, 29.660888718020534, 23.683441723546675, 41.33612555842246, 54.217585363695704, 49.37221088717061, 55.430397910456506, 51.642933737847116, 55.6341689632785, 7.586605731518039, 2.2615660775092343, 3.2727987054855596, 13.756760243446598, 1.4994544559909453, 32.011055254167125, 50.774956364785474, 53.98937794470019, 55.72676435593636, 55.4582545834203, 54.764340231495524, 56.468653217438735, 55.90051358745944, 55.295189888246604, 54.53088860357962, 53.0703156225143, 51.75052435167375, 56.10458274041453, 52.65960816414126, 49.57575052015243, 44.52894664579823, 41.701910111211966, 44.96139972440658, 45.56460142135621, 44.389682892830145, 45.69008588790894, 44.45699076498709, 44.925702233468336, 46.849267867303666, 46.52969275751422, 46.18555184333555, 42.73112043257683, 40.81370507517169, 40.10265388796407, 38.89608967688776, 39.60252815677274, 39.70612187539378, 39.85064160439276, 39.60029240577452, 37.924969657774895, 38.74349771007415, 40.02944284869779, 39.51292945492653, 36.47754053915701, 38.04487259157243, 44.48027003195978, 43.350497984117084, 40.906171029613866, 40.88435480671544, 44.57289288120885, 45.003557359018636, 41.71214749736171, 38.39439891999768, 38.87717993028703, 37.91219449812366, 38.78878147371354, 38.625720700910016, 37.81351158695836, 39.76424747897733, 38.907797951852125, 42.01319725282731, 42.55015011756651, 42.005277987449404, 43.56292570790937, 43.02328601960213, 39.971532975473714, 42.273874052109264, 41.69284943611392, 39.80648356099283, 39.94870870344101, 38.88964130032448, 37.55767499246905, 39.48036986012613, 36.346568676733206, 35.82011991931547, 38.824290690883515, 41.08441137498425, 39.70647881107946, 38.44404828163886, 44.597435151377034, 43.16681731131769, 42.472710763254476, 39.775649809068256, 40.98209242666922, 40.842114802329775, 35.869133856988725, 36.946185327345326, 40.0448420739943, 39.868327571499734, 36.87073853708083, 36.22697168780912, 36.50049032703523, 38.51399590892177, 36.224375078755045, 37.04167542919036, 36.68434750649237, 36.82946735812772, 36.69003494324223, 34.9524720253483, 34.02924414603941, 36.13456456891952, 37.71216146407589, 37.16662645339966, 37.40813855201968, 37.24750964872299, 36.9135315956608, 37.35128379637195, 37.2265249683011, 36.95519893400131, 38.75428422804802, 38.874955946399325, 37.03869050548923, 37.20403017536287, 39.460738397413685, 42.46803529800908, 46.5688144776129, 51.53771615797474, 52.563435569886245, 53.32088447386219, 51.43831545306791, 56.02297390660932, 55.253663755232296, 55.170125115302305, 52.454374067245, 56.73493116132675, 44.826434889147365, 4.124725249505812, 0.33351962604830343, 0.6047937502303432, 0.9941712983192937, 0.2546678047867552, 16.123822389110444, 59.1138800497978, 51.3032917822561, 56.58659888852028, 39.82919408429054, 30.22117772409993, 28.051312738849273, 35.72462589510026, 32.549916351995165, 0.671150018611262, 0.07526973968431835, 0.029694226780726068, 0.038775249174044985, 0.01899569017452098, 0.022474512675656907, 0.03376363603878887, 0.025716527823298693, 0.0743532303961054, 0.014995497918026823, 0.06950504296729643, 0.07046519628455562, 0.021806462938266418, 0.028401175701630213, 0.02870825246997899, 0.09219717249394425, 0.04862458114662478, 0.02381126332517353, 0.01445034113261969, 0.05107946776514573, 0.021166082381481127, 0.03133411267622104, 0.038498132189195004, 0.05273178918287159, 0.09177737163319703, 5.067741976630304, 56.34059175368279, 50.637551815279075, 25.612306479484808, 33.79644363157211, 49.39170898929719, 56.3208818435669, 57.40436992337627, 60.78170322602796, 57.82287897602205, 60.98543505514822, 8.584917091554212, 2.177444475312387, 3.9236268016599842, 16.81339663843955, 1.4810752099560154, 35.301374696916156, 50.569628131005075, 56.79655944147418, 57.38549547810709, 56.197397785802046, 55.28910629210934, 56.55349408426593, 56.29717503824542, 57.572392494447776, 55.9866919825154, 54.01317104216545, 51.03326797485352, 57.63306763864333, 55.66656381853166, 51.98032425295923, 46.31946940575877, 43.15654854620657, 46.61011703552739, 47.903718640727384, 46.98151450003348, 47.69386399176813, 48.646184090645086, 47.24654120783652, 47.80221554540819, 48.256606440390314, 49.50599901137814, 45.44896210393598, 42.47564861851354, 41.83307024740404, 40.77504227238317, 41.427112779309674, 42.097041837630734, 40.2034431119119, 40.42477461599535, 39.166588091081195, 40.619492838459635, 41.351783660150346, 40.804283542017785, 38.57844437322309, 39.09684442704724, 46.48262039307625, 44.66773579197545, 42.72552321034093, 43.052123285109, 44.43124824954618, 47.79261750559653, 43.14818213062902, 41.43846019621819, 41.234904873755674, 39.25187610810803, 38.552517506384085, 40.400797167131984, 40.6317541676183, 41.5176450052569, 41.54621162722188, 43.04527482678814, 43.879496282146825, 43.16816660665697, 44.54846828214584, 43.37467939622941, 42.8193227706417, 44.15232850659279, 42.71772553843837, 40.2353790498549, 41.7970746563327, 40.42426863024312, 38.79754012630832, 40.143305332429954, 38.51011668482135, 37.80595710200649, 38.36976643531553, 40.889532335342906, 40.447736170984086, 41.038013658215924, 45.210576134343306, 45.095513405338416, 44.697541882914884, 41.9270541591029, 44.03161364216959, 43.47138151045769, 37.56866155132171, 38.48073420986053, 40.54718002196282, 39.46489610979634, 39.03736168338407, 39.031580109750074, 38.443624665660245, 39.59443630710725, 37.46286346066383, 38.761536690496634, 38.92422483813378, 38.52052665525867, 37.614882761432284, 37.95018657561272, 37.879183830753455, 37.85566137683007, 38.686262484519716, 40.38967724769346, 39.39267743018366, 39.540801817371005, 38.65868822220833, 38.7843099717171, 37.92786436696207, 38.632780967220185, 40.67120536681145, 40.115778138560636, 40.13370337024812, 39.80605602264404, 42.680961162813254, 44.08223182924333, 49.57833536209599, 53.960572058154696, 55.18953300291493, 55.799206610648866, 51.990640086512414, 59.401009313521854, 57.08286500746205, 54.80352078714679, 54.941690198836795, 58.02412794482324, 47.66379117965699, 6.269568945130994, 0.32171145321861394, 0.5042144037302464, 0.5259308819809269, 0.4017071510034223, 18.542275428771973, 63.03856834288567, 57.90533896415465, 60.34160937032392, 46.95075919551235, 33.506439270511756, 20.73931851694661, 40.83550168621925, 40.6217638907894, 1.5912149966724458, 0.13871540255363912, 0.06425687720278098, 0.006977306170043566, 0.11731876601134578, 0.03652099715245347, 0.07812031454616979, 0.016731482840353445, 0.05130596549039887, 0.05690713307910389, 0.09905302356327735, 0.13916160280425705, 0.13008407377187284, 0.14398886071097466, 0.13624035633139073, 0.21289984845826704, 0.1454975176602602, 0.09024147259732408, 0.16866810740001742, 0.1463917874160313, 0.13284145403773556, 0.14484839604025887, 0.2187773209786223, 0.13139673478661046, 0.33117343581491904, 5.583106115941079, 66.75781465345814, 57.57832704051849, 42.04546266986478, 32.488786212859615, 52.04355678250713, 66.04004444614534, 64.96575824676022, 63.42587494081067, 63.251121582523474, 64.7779865418711, 10.272775734624556, 4.393179128246923, 9.79422696175114, 18.628410677756033, 4.103262775367306, 39.70101102705925, 49.45588288768646, 56.221269330670765, 55.76720399241294, 57.86522488440237, 56.16759953960296, 58.75073525213427, 57.62236349044308, 59.76913159893405, 56.47774134912799, 53.8374488584457, 51.87349457894602, 59.14104246324109, 56.41898032157653, 54.04106301646079, 48.68907128610919, 45.30776462247295, 49.247738392122336, 50.962806517078036, 49.719760341029016, 50.51344017828665, 50.24171013985911, 49.90832436469294, 49.40135801992109, 51.596277144647416, 52.55177044099378, 47.61679334025229, 44.32852137473322, 45.15190924367597, 43.41194583523659, 43.9864004811933, 44.5027962038594, 42.90658373986521, 43.479998957726266, 42.07083256013932, 42.500700796804125, 44.636101876535726, 42.00281081661102, 42.37867978311355, 41.76474648137247, 50.93467135583201, 48.78929961112238, 44.05246496200562, 44.0839929734507, 47.31520622007309, 50.27510912187638, 45.98438524430799, 42.301789560625636, 43.00217582333473, 39.893815132879446, 41.68671484916441, 44.19195229007352, 43.19886307562552, 44.312220004297075, 44.523929934347834, 46.36789891027635, 46.63002698652206, 46.17400438554826, 47.12102928469258, 46.23402841629521, 45.28605822593936, 46.51648221477386, 45.76799200427148, 44.346426994569846, 44.99184908405427, 42.49413867150584, 41.334689970939394, 42.87228653507848, 40.7607844568068, 39.893979872426684, 42.80025612923407, 44.61649394804432, 45.27505205523583, 42.35457681840466, 48.77887002883419, 46.84015620139338, 47.33563392393051, 44.30047250563099, 45.85279364739695, 46.55276413886778, 40.39054801387172, 41.091644225582, 43.32515555043375, 43.488055506060206, 40.62804360543528, 41.881511519032145, 40.59199310118153, 42.11717536372524, 39.38276560075822, 40.53541291144587, 41.45961746092766, 41.610860132401996, 39.48955997343987, 39.512046921637754, 39.4207537558771, 39.1083408940223, 40.933498182604396, 41.74964535620905, 42.490361429029896, 42.21774885731359, 41.08617251919162, 42.579214880543375, 40.2433846073766, 41.337757264414144, 44.196478705252375, 42.58374129572223, 41.54861996250768, 42.316749480462846, 45.24877217508132, 46.955760217482045, 51.38350817465013, 57.326632468931145, 58.52060587175431, 56.04152279515421, 53.180879392931544, 60.85816983253726, 60.331477888168834, 59.151056274291015, 58.02565374682027, 60.76442126304873, 51.784546990548414, 7.734480557903168, 0.5249399932161455, 3.409319986258784, 6.401377252994045, 0.9597783018985103, 21.972503854382424, 69.49904934052499, 61.213007050175825, 66.70729452563872, 52.52445113274359, 42.067675052150605, 37.42527146493235, 49.6191240895179, 49.24918966908609, 2.6315674233821134, 0.2571524271080571, 0.11736794885608459, 0.17644972209968876, 0.18491450336671647, 0.12287690244134396, 0.13454478925033925, 0.12944679587118088, 0.31299110502004623, 0.2286664742015062, 0.21412721324351527], [0.04362943507130108, 0.025934284485335794, 0.07668473472398135, 0.027723162990784454, 0.01393053994228643, 0.0549781313466449, 0.0475263174983763, 0.03823790744307541, 0.03808315002149151, 0.01717739580799976, 0.024195207440624797, 0.033112131885343024, 0.07040072998572743, 0.014605291033794564, 0.4159594201032193, 31.155890303273356, 53.87035362182125, 35.26271973886798, 28.221106260053574, 33.87355350678967, 53.90556473885813, 57.375481667057166, 55.35304484828826, 49.51908011590281, 59.161007327418176, 17.174615552348477, 1.4256751633459523, 2.724755829380405, 2.026487401416225, 27.498876317854855, 35.10969238896524, 66.73526102496733, 53.91566091968168, 60.337683077781435, 57.87355992101855, 59.573585756363414, 56.97248951081307, 55.721606439159764, 53.64964577459521, 54.93254323159495, 52.74782619168682, 53.78059410279798, 54.79382076571065, 52.10118032270863, 46.88682848407377, 42.00591341141732, 41.48243781059019, 42.674344124332556, 43.55109583946967, 42.44147300720215, 45.272141656567975, 46.592344776276626, 44.62461717667119, 45.50982159952964, 47.137852330361646, 44.77993126838438, 40.79057878063571, 39.67229143265755, 38.40226719456334, 40.13872792643886, 38.85038229726976, 40.69819127359698, 39.99398854471023, 38.57308249319754, 39.14260279747748, 39.11851159987911, 38.95303072467927, 40.54929417948569, 36.217530542804354, 40.54908629386656, 44.830145451330374, 43.542756880483324, 41.602736903775124, 42.75735716665945, 44.012417562546275, 42.58366677068895, 41.88041325538389, 40.48813266138877, 39.2273691392714, 39.34627579104516, 37.47307339022237, 39.705392314541726, 39.270899603443766, 39.45770248290032, 41.22352215551561, 42.01148709943218, 43.71856927871705, 43.616352312026486, 43.38227310488301, 43.96296039704354, 44.66248373831473, 43.176780131555375, 41.93619720397457, 42.21732524133498, 40.93869924545288, 38.27159735464281, 38.59793855297951, 36.61296821409656, 36.69083902912755, 36.76490122272123, 37.323713456430745, 38.80242347717285, 37.87773647615987, 41.05161643797352, 41.74583673477173, 42.360342702557965, 41.98955712779876, 42.04574900288736, 41.7444246815097, 42.832949084620324, 37.25793530864101, 38.6396372702814, 39.160120102667044, 39.415078086237756, 35.82981209601126, 38.05270948717671, 37.14633603249827, 37.283564075346916, 38.03249751367877, 36.881364237877634, 35.835989829032656, 36.61572171795753, 36.03755258744763, 36.46238057844101, 36.53615251664193, 36.23678938035042, 37.129242343287316, 37.048574878323464, 37.7259603623421, 40.00578703418855, 44.726418372123476, 47.108418864588586, 47.87434008813674, 47.4466448445474, 46.42443987631029, 44.596081933667584, 42.39163144942253, 42.35724795249201, 43.40210460847424, 42.40802303437264, 45.417975379574685, 52.73493336093042, 51.11954835153396, 52.97022850282731, 50.72642487864341, 53.55713275171096, 55.67047834396363, 54.54857457068659, 53.448694905927105, 58.282098308686294, 26.084091124996064, 0.0909099915635682, 0.036697672349551035, 0.9106692467485705, 0.5142215651369865, 0.25892990430997265, 27.534658139751805, 60.00103781300207, 51.406622702075595, 59.83176008347542, 33.02364257074172, 26.312355418359083, 34.3694705347861, 44.848631581952496, 16.732425189787342, 0.06835287737269556, 0.03994991860142158, 0.0881173559314301, 0.04357552546406946, 0.032541813899672804, 0.04660494355184417, 0.052251781472155166, 0.047417770500384995, 0.03657419812835513, 0.011443342607949051, 0.037511954865147995, 0.02797258398195188, 0.041605419284033204, 0.06539604611574643, 0.028903074374782945, 0.03402938427884252, 0.06457469260860836, 0.03770432337337444, 0.024436199549405326, 0.08311307808804898, 0.03209838497212097, 0.016640331783902743, 0.02174050468320568, 0.07729080986351737, 0.049796419879121166, 0.7429998115666452, 39.54205305345597, 60.59268812979422, 34.10840149848692, 28.919519570565996, 46.056396038301536, 58.506842274819654, 62.38580749880884, 57.56473602787141, 55.420446857329345, 62.95122500388854, 18.378640028738207, 2.2046088499407617, 9.039660999851844, 5.75758735979757, 26.860961644880234, 38.87810168727752, 63.94092529050766, 52.373263374451675, 59.97059237572455, 60.017884392892164, 61.28071500409035, 58.80525619752946, 56.7362412329643, 55.70483830667312, 55.19582056230115, 53.31045881394417, 54.47200598255281, 55.98861002152967, 53.68419008870279, 50.92604606382309, 45.682884416272564, 44.23141133400702, 44.08513438317084, 45.05329301280361, 45.229548638866795, 46.24557979645268, 49.51449486517137, 46.456909256596724, 46.770632190089074, 48.25824206875217, 47.26014790996429, 44.517579617038855, 41.40966607678322, 40.536362125027566, 41.94754069851291, 41.02141811001686, 42.24748434558992, 42.49472310466152, 41.56834948447443, 39.39794909569525, 39.51237247836205, 39.71936379709552, 41.44116663163708, 39.14716059161771, 41.638214741983724, 47.341756743769494, 45.3052072371206, 43.276243594384965, 44.49085258668469, 44.603479523812574, 44.43957936379218, 43.056206472458385, 40.89600032375705, 41.41334918237502, 41.242443669226866, 41.025603278990715, 41.07238146566576, 41.93917820530553, 41.20283949759699, 44.203323241203066, 43.26838708692982, 45.034598996562345, 46.801544389417096, 46.72929040847286, 44.782614169582246, 45.80348945433094, 43.59065686502765, 43.887784250320934, 43.85643274553361, 41.50539544320876, 40.42277812957764, 39.457777007933586, 39.07626767312327, 38.95985957114927, 39.28491423206945, 38.586661738734094, 41.17504950492613, 40.24693435238254, 41.94319078999181, 43.11943115726594, 43.15088464367775, 44.32803500083185, 44.26869738486506, 42.17921941511093, 44.597639114626, 39.48499433455929, 39.86166738694714, 40.06015892951719, 42.04928698078279, 39.08812107578401, 39.5597586324138, 37.96129080557054, 38.700488921134706, 39.727628231048584, 37.70394802093506, 36.715702933649865, 39.479581463721495, 38.344161202830655, 38.17476580219884, 38.10796391579413, 39.181955937416326, 39.64991431082449, 39.86090252476354, 40.239234739734286, 41.50976888595089, 46.809871581292924, 48.97595736288255, 49.96861119424143, 49.040543110139915, 47.26581965723346, 46.335135352227, 44.064318364666356, 44.5486447888036, 45.05443442252375, 45.165527712914255, 47.08395111945368, 55.212004261632124, 53.6410322496968, 55.00807631400324, 52.09310416252383, 53.93639456841254, 57.91201483818793, 55.75834335819368, 57.01532963783511, 60.01868847877749, 29.464856501548525, 0.4136538938168557, 0.8389176356215632, 1.2037769993466716, 0.1963889836183479, 0.48366476931879604, 28.711204451899377, 63.58532321068549, 56.564641460295654, 60.77869476810579, 43.562470712969386, 35.94526706203338, 31.513902679566417, 52.67446610235399, 22.297636962706044, 0.02807257760826859, 0.03897286538455275, 0.04657795810471139, 0.03932839912933208, 0.033345677619499546, 0.043533275715045394, 0.08897854601063075, 0.0032039812762260198, 0.05040470518231873, 0.04716007001397591, 0.05416392543984037, 0.14970925456333548, 0.09645483636808011, 0.249824121954941, 0.07566926219770986, 0.1173701168849103, 0.21924880213074147, 0.07885789633878777, 0.12381545207913845, 0.1867945290981762, 0.13184137221786285, 0.13480993228093271, 0.07008569164862556, 0.209445450755377, 0.08581265702002472, 0.7937178352186758, 43.922352098649554, 69.12523961836293, 46.42026255207677, 39.94040896815639, 46.3182181696738, 62.59171624337474, 67.65872816885671, 65.548591075405, 59.14192499652986, 70.83642067447786, 22.77119451953519, 3.5959282180955334, 9.410999628805346, 6.400981093606641, 33.177497540750814, 42.158509300601104, 63.21484358079972, 54.860148045324514, 62.940018792306226, 63.52511875091061, 64.36515315886467, 61.03994031106273, 57.29952889104044, 55.90731105496807, 55.49258708953858, 53.583243969948064, 54.47446530865085, 59.09737079374252, 56.32633786047659, 51.68250653051561, 47.6356089499689, 47.88669555417953, 46.472920371640114, 47.74333684675155, 46.55039110491353, 48.61688398545789, 52.366171729180124, 48.519483689338934, 50.366974953682195, 50.48033929640248, 50.16813039779664, 47.05962850201515, 44.8756371005889, 43.42647429435484, 43.73771828989829, 44.284049541719504, 44.34374801574215, 44.98373762253792, 43.19636060345558, 43.23029695018646, 41.79447020253828, 42.45358920866444, 44.79454209727626, 41.47193370326873, 43.53012292615829, 50.089518254803075, 48.99154093957717, 46.069622270522586, 44.45046394102035, 45.891327011969786, 46.104068525375865, 44.27378469897855, 41.982006565217056, 43.04731053690757, 44.054496749754875, 42.49181662836383, 43.05657517525458, 44.61723135363671, 44.08544032804428, 46.260531871549546, 45.00333770628899, 47.45628603043095, 50.45098427803286, 48.98544949869956, 47.76899307004867, 49.81334809334048, 46.4883666653787, 46.51332862915532, 47.34868757186398, 44.64917905869023, 42.753132773983864, 43.557657964767955, 39.88173423274871, 41.531098734947946, 41.597935922684215, 40.968552404834384, 42.39033314489549, 41.872368474160474, 44.872185414837254, 45.856849378155125, 46.18409664400163, 46.63911904058149, 46.85118198394776, 44.32060210935531, 46.4337045146573, 42.462869536492136, 43.2136425664348, 41.649318971941554, 43.789105261525805, 39.84951980652348, 43.95373890476842, 40.28439298752816, 41.278639301176995, 42.0381199929022, 39.227329915569676, 38.81235099607898, 41.77272850467313, 41.03040818245181, 41.17034266071935, 40.75868206639444, 41.46279065839706, 41.4614962762402, 40.974451649573545, 42.91906079938335, 43.91925734858359, 49.850849874557994, 50.44848965060327, 52.20193424532491, 51.26568801941411, 50.3961613101344, 50.06203028463548, 46.787702345079, 47.666603519070534, 48.40728036818966, 47.75686902384604, 49.880000929678644, 58.091761373704486, 55.55126574731643, 55.57564720030754, 52.00564315242153, 53.77324750346523, 60.91424795889086, 58.46982294513334, 61.40261442430558, 60.735803650271514, 33.574331575824374, 1.2909956805167662, 1.4525518566370013, 3.6586098997823657, 1.0902169058399818, 0.8485134078129646, 31.40020101301132, 70.94353275914347, 60.81717321949621, 68.73409302003923, 43.42667433523363, 38.23461332628804, 44.19156005305629, 59.95675425375662, 30.18853379834083, 0.2871853107165906, 0.11651438135173052, 0.24016477978758274, 0.0845408744569267, 0.19909056203980602, 0.19276737956510437, 0.2047457005227766, 0.09976802108388755, 0.13576069336024024, 0.1365005197904764, 0.16198362253846663], [0.029650803001958038, 0.030002261158980192, 0.055459429915513725, 0.04565613216630394, 0.09909658332265193, 0.07242098045084747, 0.0603253522797698, 0.05340772771066236, 0.02073759216845276, 0.09241575270049995, 0.04406333578029468, 0.03847095138964154, 0.05106474355524106, 0.01214970631765262, 0.05705647425906313, 8.127623152348304, 50.4889214423395, 42.745017390097345, 33.9545779074392, 26.195227561458466, 48.32850740801904, 60.62974668318226, 57.75617907124182, 51.58895800190588, 53.23100336136357, 31.89007955212747, 0.2885799584609847, 5.116097446410887, 1.0605385370792881, 7.98408450618867, 20.06284498399304, 54.966691386315134, 62.40820031012259, 57.788542547533595, 57.117491691343254, 54.648795050959436, 56.07559250247095, 56.506645294927786, 59.09870832197128, 55.718943149812766, 55.448872273968114, 54.769937453731416, 53.46567092403289, 49.675084544766335, 44.92590227434712, 39.68697286421253, 39.408696389967396, 41.136798551005704, 40.86121674506895, 40.398800680714274, 44.12290680793024, 45.27223187108194, 43.708971238905384, 43.908055059371456, 45.4745202679788, 40.59002014898485, 39.28734610157628, 40.85911435465659, 38.19673499753399, 39.2267886284859, 40.32933158259238, 40.75064120754119, 39.54586167489329, 40.72669121526903, 39.95463932714155, 38.66711347333847, 39.31846226415327, 41.16483565299742, 38.200625988744925, 41.98597600383144, 44.66039311501288, 41.15863046338482, 41.69467726061421, 41.323703412086736, 41.3744314255253, 40.85408979846586, 40.001746992911066, 39.36736637546171, 38.514882364580714, 38.64573655589935, 40.58774909665508, 39.76157634488998, 36.97452052947014, 41.30960249131726, 44.37939451586816, 44.17645108315253, 45.78743519321565, 48.216582575152, 47.198990314237534, 47.87241420438213, 47.55648297648276, 44.14119289767358, 45.042761448890936, 44.35433449283723, 44.68321346467541, 39.136209334096606, 37.77340142957626, 36.629022475211855, 37.0847705102736, 37.852531325432565, 37.66790928379182, 38.92182434758833, 38.048873409148186, 38.01950662366806, 38.857701440011304, 41.84347237310102, 38.561127108912316, 40.08794107744771, 39.67304060536046, 43.153693060721125, 38.26398011176817, 36.96144726968581, 39.33698369610695, 39.39554468277962, 36.98746827340896, 37.4618907128611, 35.890424482284054, 37.27669208280502, 36.34723940203267, 37.85637132583126, 38.024017349366225, 36.653086216219016, 37.41257475268456, 38.10992117851011, 35.87252670718778, 37.74649789256435, 37.76243840494464, 36.95566569605182, 42.14930742017685, 52.33998598590974, 49.50791312802223, 51.92854504431448, 49.41747111658896, 52.02785553470735, 50.802981699666674, 50.9869408607483, 52.2550666716791, 47.82636165618897, 46.98259707420103, 47.75519809415264, 46.18712863614483, 50.43508298935429, 52.18278523414366, 51.50777670644945, 52.07581435480426, 51.81366666670769, 52.048577416327696, 59.01817813996346, 54.571865604769805, 48.16147719660113, 5.2789871058156415, 0.2187282300644344, 0.9738511532064408, 0.26037673796376876, 0.11392200110299934, 0.34600373357534414, 41.573660373687744, 53.26508483579082, 52.49697492968652, 51.93031795563237, 28.97316582741276, 25.96885581170359, 25.391716303363925, 47.68375996620425, 5.250896561530329, 0.17571231650729335, 0.045681945498912566, 0.029825844516557072, 0.008228106063700492, 0.058287343896564946, 0.062861965158053, 0.008382758148194802, 0.02084758132696152, 0.07000778816760549, 0.045712550711487575, 0.004184343035317837, 0.018220185114431287, 0.048405028008405244, 0.07724761782634644, 0.09662495385254584, 0.15852211553963924, 0.07315928236611428, 0.11138644159561205, 0.07100808449209699, 0.054970742428615216, 0.04769733896659267, 0.06737564795560415, 0.009110751392830525, 0.10602776381757953, 0.07498007417926866, 0.05124062202089737, 14.06068999921122, 61.452514817637784, 43.4173979297761, 33.78645335474322, 35.64871234278525, 52.35947232092581, 64.77541738940825, 63.58212647899505, 56.88704459897934, 60.60923660955122, 35.401889354951926, 0.8151198190546806, 6.6335207704574835, 3.521299242011963, 9.79271782982734, 23.733716703230336, 55.870142675215206, 62.334130271788574, 59.04675260666878, 60.3418251006834, 57.630553399362874, 58.627035464009936, 57.62814898644724, 60.61765793831118, 57.84594251263527, 56.99769858391055, 55.32666690887944, 54.13155209633612, 52.17525428341281, 45.331079190777196, 41.476526798740515, 42.24928471349901, 43.415958419922866, 43.78071531172722, 42.872364982481926, 46.98460925009943, 48.34414982026624, 44.57073557761408, 45.74415183836415, 47.507359212444676, 44.150128056926114, 42.5973754544412, 42.53111093275009, 40.87773776823475, 40.916510397388095, 42.005026955758375, 41.783813122780096, 40.36699810335713, 42.0074745147459, 41.689056504157286, 41.281737973613126, 40.89234075238628, 42.13876408915366, 39.34543248145811, 42.52213654979583, 46.35218981773623, 43.947812203438055, 44.20748095358572, 44.227998871957105, 45.410114949749364, 42.65909787147276, 42.89138063307732, 41.31254034657633, 39.978840351104736, 41.00314770975421, 42.021371472266416, 40.91710267528411, 40.35284619177542, 42.456417237558675, 46.55436838826826, 45.87741044259841, 47.265627461095015, 48.7447375635947, 48.62611724484352, 49.11100849028557, 48.63916697040681, 46.423192562595496, 45.88274094366258, 45.38326632591986, 44.90597271150158, 41.393678495960856, 40.43804399428829, 39.6502947807312, 38.66933745722617, 39.847425260851466, 39.054702481915875, 39.02950125355875, 40.21314705571821, 39.77270410906884, 41.943379063760084, 43.44857685027584, 41.9402882360643, 42.18479310312579, 41.91000753833402, 45.12476251971337, 40.45276072717483, 38.69397778664866, 41.19292374580137, 41.69118635116085, 38.55266263408046, 38.59424760264736, 36.916336090334006, 38.49956550905782, 39.28599680623701, 41.07128320201751, 40.27652079059232, 39.544171133349025, 38.433924644224106, 38.191816345337905, 38.21306382456134, 38.82114495000532, 39.22780059999035, 38.42582887218845, 42.399935107077326, 53.685060854881044, 52.69371709515972, 53.196408056443744, 50.661368446965376, 53.5311705835404, 53.264170923540675, 54.27145127327212, 52.906525288858724, 50.20349840964041, 49.74054498057212, 50.44396323542441, 48.43883583622594, 52.9629054377156, 55.87332371742495, 54.90774600736557, 52.025102030846384, 53.15089679533436, 53.31154923285208, 61.0303658054721, 55.78028117456744, 49.98238263591644, 7.941589057445527, 0.6508560430619025, 2.1672313588280834, 0.06048346516646205, 0.14760232891046232, 0.16095579301397647, 44.345983766740375, 58.06727401671871, 57.84703293154317, 56.51733767601752, 39.729067740901826, 26.68466679511532, 29.03082270776072, 56.856026495656664, 7.688951155831737, 0.1742470201345221, 0.0869818450883031, 0.02176989947686032, 0.03136137391500656, 0.06806712657693895, 0.049769503379901575, 0.04550280349869882, 0.04113568864282101, 0.019633268764723214, 0.04954368364246142, 0.043291387283393455, 0.09238955249348957, 0.13985036181346064, 0.1822929198463117, 0.18091383900853897, 0.32845541714660587, 0.1659205024160685, 0.26273965955741946, 0.33552024934080343, 0.2484437234459385, 0.18067458974978617, 0.1454578343057825, 0.23963028024281227, 0.2212586338000913, 0.11829932025002858, 0.23328524894051014, 15.735125310959356, 70.34120575074228, 54.379104645021506, 47.49362307210123, 39.28392187241585, 59.64045040069088, 70.62662093870102, 68.03846066997897, 60.88617163319742, 64.48576211929321, 41.23239455684539, 1.0645376386181002, 13.606553077697756, 2.9175170342768393, 9.229181101245265, 28.227401664180142, 55.835680730881236, 65.0085630724507, 61.205323127008256, 62.23896572666784, 59.79343068215155, 62.22516682840163, 60.02891017544655, 64.41474760732343, 60.13430426197668, 60.95538577725811, 57.87161834778325, 56.82478481723417, 53.80019810891921, 47.32867563924482, 44.5821810537769, 43.97896758971676, 45.13376828162901, 45.78248123968802, 43.78799130839687, 49.972349213015654, 50.97711532346664, 47.7077531045483, 47.27736711502076, 49.92353923859135, 46.74518385241109, 42.95384437807145, 46.721531960272024, 42.81725960393106, 44.3066620057629, 44.3509102636768, 43.9550607435165, 43.76521018243606, 44.7084774509553, 43.806704936488984, 43.027541791239095, 42.31449019524359, 46.264450319351695, 42.32293113585442, 45.570743853046054, 50.74915501379198, 47.02403299270138, 45.445624166919345, 46.466393547673384, 46.90140793400426, 44.85209503481465, 44.718287298756266, 43.07306874182917, 43.18638601610738, 42.89556580205118, 44.7177303221918, 44.450475708130874, 41.42030746706071, 44.19938125917989, 50.58318776469077, 49.47473772110478, 51.2556428294028, 51.57293904212214, 51.37521628410586, 52.33396514769524, 49.29637185988888, 49.179320489206624, 48.351967104019664, 47.986951335783935, 49.018883782048384, 44.238110742261334, 44.50620866590931, 42.207032942002826, 41.55833567342451, 42.75525869861726, 40.52908220598775, 41.97174564484627, 43.184981807585686, 43.638615685124556, 43.44123025094309, 45.42281558436733, 43.69341511880198, 43.91444067801199, 43.85302812822404, 48.48451183688257, 43.35752687146587, 40.4234213982859, 42.604659295851185, 44.44698872104768, 41.0841642656634, 40.52515591344526, 40.04381833537933, 40.02754442153439, 39.775010462730165, 41.85661231317828, 43.218404323824, 41.223243667233376, 40.57538186350177, 39.15891985739432, 40.291335582733154, 41.860636664975075, 41.81772593528994, 40.13402892697243, 46.018921713675226, 58.03600095933484, 54.64290365096062, 56.733311222445586, 53.09809384807464, 56.375963687896736, 55.17682452355662, 55.99135568065029, 55.97821181820285, 52.054586487431685, 51.38894065733879, 51.98758456014818, 51.36318245241719, 54.61868693751674, 58.09724484720538, 57.27642220835532, 52.898484430005475, 52.864646142528905, 54.03298293390582, 62.88609404717723, 58.5036063194275, 52.38130423330492, 9.958069266811496, 0.6403105669925291, 3.246859826387898, 0.9551523565765351, 0.532075152281792, 0.4280443038911589, 51.008819841569476, 62.338927330509314, 62.13077891257502, 62.65312094842235, 40.80548770966069, 36.491084483362016, 37.750785043162686, 66.16282247727918, 11.455653732822789, 0.46660800554579307, 0.1688568867863186, 0.19816826878776475, 0.1899155406581779, 0.27910905860124097, 0.1477834780610377, 0.14638739007134594, 0.1274010193564238, 0.14869480093400325, 0.10455074629956677, 0.10737266181217087], [0.03232021913713506, 0.017818801007383776, 0.03197498161405806, 0.010010621251328098, 0.05125589015322828, 0.11434871207682357, 0.05719360782794895, 0.05861361691307637, 0.025476250091507554, 0.06189149646689335, 0.05797666076931262, 0.027288622598374085, 0.005380739195031985, 0.09498372538796357, 0.1011876586163717, 1.5354304352114279, 29.1671250712487, 49.26900156082646, 29.825045793287217, 29.947731648722005, 39.83442652610041, 58.39488998536141, 54.94826016887542, 53.52071354466101, 50.50661525418682, 44.45788898775655, 0.0508309948077846, 5.941092506531747, 2.6386720615048564, 0.050995378124137083, 12.978767925693145, 64.69223568516394, 59.06440719481438, 56.71111845201062, 53.406549038425574, 53.27449067946404, 53.533571074085856, 53.24248413885794, 53.32239066400836, 53.94464723525509, 54.63011672419887, 55.18070767002722, 50.12336438701999, 45.21327472502186, 40.295752171547186, 40.78808807557629, 41.128506660461426, 40.92609274771906, 40.5240027366146, 41.76680180334276, 44.243507923618445, 43.72095800215199, 43.21587439506285, 43.76147608603201, 41.20138037589289, 41.75203407964399, 40.426661276048236, 39.02502582919213, 39.82948433968329, 41.000143174202215, 40.49046254927113, 39.82743686245334, 39.15529558735509, 40.271594293655895, 39.21277399986021, 38.83804644307783, 40.56490913514168, 40.95020355716829, 38.46682156285932, 40.29019809538319, 42.48350512596869, 42.26861023133801, 40.161258020708644, 40.7290054136707, 41.291861611027876, 42.05263668490995, 41.2739912925228, 39.85485030758766, 42.418527141694106, 39.44411147025324, 38.50121682690036, 37.33781045483005, 35.755820505080685, 41.35787117865778, 47.29321349051691, 47.250738143920906, 49.64185814703665, 49.24591841236238, 49.3405455927695, 47.58552420523859, 43.26466475763629, 44.74529281739266, 47.36022718491093, 46.22232798607119, 46.19131772748886, 42.25147731842534, 37.2832267515121, 36.79542118503202, 37.47042579035605, 37.28254033673195, 38.61869965830157, 37.67572656754525, 38.75405280820785, 38.63677001768543, 39.345530540712424, 38.56208024486419, 41.74328719415973, 40.67351564284294, 41.18939753501646, 40.82165571951097, 41.302016627404, 37.39754815255442, 37.64657159005442, 39.14513272623862, 38.24518019153226, 37.32654148532499, 35.60280884465864, 38.5318152366146, 36.94450263054141, 36.3490633041628, 37.57832234905612, 37.49604671232162, 36.445875244755904, 37.52404459061162, 39.026583010150546, 38.57122328973586, 37.63680881069553, 36.145888451607, 49.01943291387251, 52.1505472736974, 49.44218597104473, 50.593766397045506, 48.98673211374591, 49.57648400337466, 49.528391822691894, 51.85358462795135, 52.00771808624268, 51.79932255898753, 49.55776645291237, 50.22629914745208, 49.34915519529774, 50.17357856996598, 51.66927245355422, 52.343347457147416, 49.036138288436405, 45.070233729577836, 49.23468866655904, 51.843072675889545, 52.052966548550515, 25.763280468602336, 0.4535645006164428, 2.2852719022381693, 4.177979759631619, 0.1296203454295474, 0.12435397358551142, 1.8835868758540002, 52.51458637176022, 48.02607305588261, 58.39182269188666, 43.85928823101906, 28.74920633531386, 30.8293176850965, 38.51848702276907, 28.51884553509374, 0.42174123888534887, 0.08147480672285443, 0.07236464234489588, 0.03156481239373886, 0.008016593018246275, 0.06360813096586256, 0.030346698120176315, 0.06648729239860851, 0.03135742473175689, 0.03560129327759628, 0.016769511444914727, 0.06399400179244338, 0.03489894386861594, 0.020409107073059967, 0.0771324594895686, 0.008497485560515236, 0.00968473223638871, 0.026629790813932498, 0.010966803360309814, 0.03381199150856945, 0.0757742009215778, 0.023251670570443236, 0.05726529833590312, 0.04705994232227245, 0.04957734171541468, 0.034769383078861626, 0.09340039784869841, 3.019398883465798, 40.45453756086288, 56.01275613231044, 25.63658791203653, 33.6897002497027, 54.4086322476787, 59.873188157235425, 62.08283185958863, 55.3895934935539, 57.91626668745472, 46.23734674146099, 0.14468351859719525, 4.2402684688568115, 6.009904607649773, 0.10369029166477342, 14.537268761665592, 64.54370337147867, 60.113990306854255, 60.10882062296714, 56.557942052041334, 56.917588095511164, 55.591795598306966, 54.811012514175914, 56.999789207212395, 57.34896644469231, 56.45494845605666, 56.59900534537531, 53.59117108006632, 45.9936341931743, 42.21225753907235, 42.613425793186316, 43.50192500698952, 42.33851079017886, 43.57082536143642, 44.414444815727975, 45.161460215045565, 45.33327964044387, 46.02512298091766, 46.01556024243755, 43.56209024306267, 43.19437196177822, 40.59589585950298, 40.095417114996145, 41.995558354162405, 41.933518225146884, 42.21519539433141, 40.84167941924065, 40.78455794242121, 40.677971455358694, 40.56798035098661, 40.048438887442316, 41.68587938431771, 41.68251006833969, 39.295241832733154, 43.020763935581336, 47.27283677747173, 43.71366631600165, 43.40019049183015, 42.77123451232911, 43.455558669182565, 42.17746219327373, 42.35658899430306, 41.5141031049913, 41.94804668426514, 41.08780814755348, 39.779360371251265, 42.03772775588497, 38.81283736998035, 43.47428014201503, 49.29150027613486, 48.679508547629084, 52.38788989282424, 50.07042023443407, 52.242048325077185, 48.829205805255526, 46.16656364933137, 47.1013193745767, 48.73850491739089, 47.647897735718765, 46.61749109145134, 43.816236296007716, 40.179975571170935, 40.441107365392874, 39.079821340499386, 37.52141268022599, 38.995353098838564, 39.12254771878643, 41.21593236923218, 39.737108599755075, 42.05497441753265, 41.198340539009344, 43.70122455781506, 40.80757441059236, 44.27339246196132, 43.617046571546986, 43.20260893914008, 39.51156839247673, 38.77166032791138, 41.18432983275383, 39.68610994277462, 37.086170796425115, 38.21539371244369, 39.41287371420091, 39.24614944765645, 38.37481060335713, 40.5339773239628, 40.2675973984503, 39.924182122753514, 40.62931053100094, 39.78921336512412, 39.465284424443404, 40.81849821152226, 39.1495846163842, 50.47665619081067, 51.632986607090125, 50.190366314303496, 53.8110238505948, 51.83973081650273, 50.88932875664004, 51.60705581788094, 54.254792967150294, 54.77380098835115, 54.83420941137499, 51.47522887875957, 53.41662560739825, 50.67343365761542, 52.137152379558934, 54.086401693282596, 53.70769293077531, 49.961648987185576, 46.14630068502119, 49.7314803831039, 52.644840440442486, 54.16002458141696, 29.945550810906198, 0.6574328159612994, 3.9175865967427534, 4.330433462896655, 0.16722000204026702, 0.1485924362655609, 1.8733303681496654, 57.81953319426506, 53.65570583651143, 62.20964993199995, 50.450160580296675, 40.45767153463056, 26.497354007536366, 38.40984521373626, 37.91128450824369, 1.6792372734315935, 0.05435005799236317, 0.09195459841360008, 0.007662279268486366, 0.01894096085321038, 0.02111112897945268, 0.023054810871760693, 0.06715637060903734, 0.03348280735794575, 0.03721857000322592, 0.020291539389760267, 0.050200983251054446, 0.10573439044697631, 0.12615228071808815, 0.2127699199463091, 0.12650881803804828, 0.08287663271109905, 0.12420921361133938, 0.1250383275891504, 0.19744042397266437, 0.23263963600320203, 0.15348468907177448, 0.16274678400687634, 0.18021122912966436, 0.13265681152622547, 0.292785290869013, 0.25762096648254706, 3.6193459937649393, 50.350748108279326, 60.62356110542052, 40.48654410146898, 41.85168189387168, 54.4313859170483, 66.5347965302006, 66.27902661600422, 64.28654886061146, 60.386512664056596, 53.27725202806535, 0.23543807858180618, 19.969382747527092, 8.717757963365125, 0.14885947919420658, 19.328255653381348, 66.57061561461418, 62.61819224203787, 61.236878595044544, 57.34063533044631, 58.76138448715211, 56.78312140126383, 58.563532290920136, 58.297375940507465, 58.53231022434851, 58.68978161965647, 60.09058944640621, 55.86757744512251, 49.144768330358694, 44.17643147130167, 43.93486445949924, 46.88252956636491, 44.58202415897001, 47.00059290855162, 46.36650646886518, 47.41371262458063, 47.72885153370519, 48.09538133682744, 47.78508263249552, 44.74179014082878, 45.550312226818455, 43.44726285626812, 42.274642836663034, 44.680299143637384, 44.8517773228307, 44.294408521344586, 44.10735068782684, 43.20925343421198, 43.976280766148726, 42.211104362241684, 41.98505032447077, 44.854746557051136, 45.51086887236565, 42.53020094287011, 43.769156086829405, 48.93312508060087, 45.73988037724649, 44.230387595392045, 43.533660904053725, 44.76736007198211, 46.50478570692001, 44.65237579038067, 43.77784805913126, 45.77723703076763, 42.46031215113979, 42.642345428466804, 42.64083531595046, 39.300619402239406, 46.08829667491298, 52.51632398174655, 52.45053798921647, 54.51554821383569, 53.329086149892504, 52.640419929258286, 52.670798686242875, 46.28319532640519, 47.98398602393366, 51.57851665250717, 50.622078064949285, 49.31535220915272, 46.92945288073632, 42.82178209673974, 40.74856235134987, 41.56261890165268, 39.580539349586736, 42.74461338596959, 39.94272316655805, 43.53826184426585, 41.625694536393695, 43.5090676430733, 42.330211054894235, 46.498286339544485, 43.7846572937504, 47.82141554740168, 45.33789234776651, 46.12306456412039, 41.02872940801805, 40.24756193161011, 43.84451266257994, 42.74145980035105, 38.66836863179361, 39.16588598682035, 42.108679509931996, 40.61784152061709, 42.09393139808409, 41.57707283573766, 41.82355849973617, 42.343637327994074, 43.4430149293715, 42.16595788155833, 42.47911599374587, 42.58607510597476, 39.59485992308586, 53.46483545918619, 54.57812178519465, 53.25633795030656, 54.60886532260526, 52.225378251844845, 52.33881319722822, 53.23128969438615, 56.780254148667865, 56.86280435131442, 56.628074030722345, 53.597505707894605, 55.507041023623565, 51.581819288192264, 53.5675976353307, 56.980773556617, 56.86316128700011, 49.70905619282877, 48.11680140033845, 49.22727146456319, 52.48170122023552, 52.61170817959694, 34.88925518528108, 0.9412414256122805, 4.138917365381795, 7.098510399941476, 0.1655149661124714, 0.5451527021584973, 2.023814796440063, 65.39439093682074, 56.5523644416563, 69.46488549632411, 53.231172023280976, 38.954933074212846, 41.287833336860906, 49.889304791727376, 45.50673077183385, 2.5157192397502164, 0.34575757420351433, 0.201862559263264, 0.1895571340836825, 0.12379318956405887, 0.2397693098793107, 0.1574867323882157, 0.13806643415122263, 0.18231133660001142, 0.14687819196091545, 0.14400606704575403, 0.17280752560304058], [0.0323363529488204, 0.03264942627039648, 0.009523529142531897, 0.09212699884008016, 0.07662737006021124, 0.05745923349393472, 0.05123395322551651, 0.11836361034863419, 0.030740241317318815, 0.05621379669455271, 0.06551213907979189, 0.097074095880793, 0.04483593928237115, 0.043738763478975144, 0.02077077718211278, 0.09801918790946085, 12.196691439997766, 46.15602816304853, 42.80364505706295, 22.349508347049838, 24.39911542400237, 53.54386729578818, 57.80740130332209, 55.55643543120354, 50.3245113741967, 52.80715596291327, 2.1011891864961196, 4.066022812358795, 5.890332623835533, 0.12342015071020973, 7.952073062619856, 63.39722594907207, 58.08034335413287, 56.30489426274454, 52.889262937730365, 51.89998626708985, 49.18227403394638, 47.938608123410134, 48.101268814456084, 48.234692158237586, 47.55969147528372, 44.31899785995484, 41.096574644888605, 38.76865186998921, 38.007013874669234, 40.44196636446061, 40.280133293521025, 40.99249062999603, 41.48702306132163, 39.98559467254147, 40.75756026852516, 41.91863675271311, 41.3479083584201, 41.942127827675115, 38.92319325477847, 40.102300874648556, 39.18335622356784, 43.03837145528486, 41.39393737239223, 39.2982110669536, 39.418035553347686, 39.39207338517712, 39.63301281775198, 38.34422788312359, 38.27556679325719, 38.111788226712136, 40.396321742765366, 41.120677609597486, 37.78331718137188, 42.5628742864055, 41.75965132251863, 40.41950295048375, 40.00603806587958, 41.26353425364341, 41.33261503711824, 41.31362292074388, 37.98933182993243, 38.92116146702921, 39.88613905445222, 39.77050758177235, 38.76743985760597, 38.18356760086552, 38.0801700007531, 41.87792255032448, 47.011344125193936, 47.71044385048651, 49.718065877114576, 50.75115934495003, 52.084776970648, 53.5076089059153, 46.115965074108495, 46.874979003783196, 51.41631095640121, 48.19297382908483, 48.01750659942628, 40.39293673730666, 37.258072591597035, 37.90511461996263, 38.08879921513219, 36.92223533507317, 37.8927787657707, 36.93784636835898, 37.87149598521572, 39.31628534870763, 39.97287834844282, 40.732774811406294, 40.85417216823947, 38.44850801652478, 40.43026201186642, 41.56341514279766, 38.58230006310248, 36.50305555712792, 37.357657647901966, 39.49839707343809, 37.21656999280376, 37.57389791550175, 37.999416243645456, 38.64780756735033, 36.66191939384707, 37.853492306124785, 36.81176962391023, 35.93191923633699, 35.80982761998331, 36.730874661476385, 37.276111572019516, 37.268235452713505, 36.66540638093026, 37.81235448775753, 42.852698218437936, 48.88789230777372, 50.81196784973145, 51.180262719431234, 49.542677094859464, 52.745833627639286, 49.956071376800544, 51.18472245431716, 50.87431392362041, 53.843712883610884, 51.61673230509604, 52.40800772943805, 51.93384416641728, 54.33930043251284, 52.264994190585234, 52.94532537460328, 49.92353531622118, 49.75666984435051, 48.76772265280447, 49.61864163798671, 48.97216050855575, 5.578688546534508, 0.03258713949171286, 2.757815036081499, 1.024903804063797, 0.11627284915096338, 0.5130209827855711, 6.0072756390417785, 58.77014706211706, 50.686059767200106, 56.659774626455004, 32.768798335906, 30.507187151139785, 18.8371866749179, 45.544769917764974, 14.996692057578796, 0.368967525540821, 0.0876484105303403, 0.06616047162923121, 0.010520257412516063, 0.0308825402340341, 0.0059003172622573, 0.05818124837993134, 0.13461960539702447, 0.04172539248341515, 0.019885240828678496, 0.0026262573749502942, 0.017582236886805585, 0.04382284162866493, 0.047132027365507624, 0.018253159453912128, 0.03750633944066302, 0.08763013933334621, 0.01859300754844181, 0.016451707530406215, 0.04635286998123892, 0.03840197283293932, 0.0286356809609119, 0.07577063095185065, 0.0992627171499114, 0.0332140177488327, 0.03156094556494105, 0.05821869475767017, 0.1128329075272045, 19.042385470482614, 55.95308903724917, 39.96459038026872, 30.366356411287864, 37.05054783052014, 58.68159563310685, 62.34353611546179, 60.28386423664709, 55.431205918712, 58.048905557201756, 1.8700660981478232, 2.1017417503941447, 3.356012769283787, 0.5136614016467526, 10.25302856199203, 63.0882804624496, 60.51008301396524, 59.836243352582386, 54.41190350440241, 55.961835922733435, 52.87767233387117, 52.31339231614144, 49.975757752695394, 51.27526252500473, 50.14076009873421, 48.26749101761849, 44.284069153570364, 40.60245798480126, 41.95649546961631, 41.655539851034845, 42.02561155442269, 44.08522067531463, 43.387438866399954, 43.179666996002204, 42.71859238224645, 45.08287945101338, 43.61418716369137, 43.27452559624949, 41.9371424951861, 42.373549322928156, 41.06588994303058, 43.21670593753938, 43.64047096621606, 40.735873483842425, 41.825370634755785, 41.84040900199644, 39.61296558380127, 40.95922108619444, 40.755712832174, 41.300027985726636, 41.92849759132632, 42.84404939220798, 40.409340089367284, 43.787144076439645, 42.95203224305184, 42.811517253998794, 41.17941118055775, 42.429568613729174, 43.839240997068345, 42.33353722480036, 40.86808481524068, 42.31917742759951, 42.38550862958355, 41.21856427961781, 40.3612086849828, 39.90092246763168, 40.26707180084721, 43.46549795519921, 49.114099317981356, 50.383142963532485, 50.860973942664366, 51.367187192363126, 53.27382387653474, 53.115650376965924, 49.55673094718687, 49.54412444945305, 52.46829063661637, 50.617351608891646, 48.957392784856985, 44.29433007394114, 39.2129034380759, 40.137080530966486, 39.7605682957557, 37.80627481399044, 38.70583511167957, 39.03248225488971, 39.74783235980619, 41.56679622588619, 42.36333154862927, 43.74089540973787, 42.31450196235411, 41.21721106190836, 42.77806335879911, 43.03142493770969, 40.649271472807854, 37.586626006710915, 40.80662519701066, 40.854897806721354, 39.1101687185226, 39.31309646175754, 39.24870291063863, 38.669596333657545, 39.60198686968896, 39.92994408453665, 39.56538331124091, 37.39460245255501, 37.166469558592766, 39.00887743119271, 38.33596737154069, 39.34030202127273, 39.158531542747255, 38.143916360793575, 45.05355581160515, 51.631311755026545, 52.61163365456366, 53.45346843042682, 52.95414286275064, 53.9428037212741, 50.55947703699912, 52.54371389265984, 53.91913613965435, 55.45308882190336, 53.69906371639621, 55.05663917910669, 53.92824388319447, 56.01791797145721, 54.86702396023659, 54.68164097878241, 51.489133681020434, 49.653119271801366, 49.173829170965384, 51.07499807111679, 50.43487510373516, 8.042484675684284, 0.01978518591532784, 5.164533324780003, 1.4266318539457938, 0.07405874619801199, 0.44816048575505135, 6.017909184578927, 63.459156251722774, 54.089790621111476, 62.32019016819616, 40.04206111354213, 35.08900580867645, 21.53744043842439, 52.971185561149355, 21.02069954718313, 0.29208009161295434, 0.07890756947979813, 0.05240371585973809, 0.014278147549879168, 0.02887107871262537, 0.022931677559691093, 0.02137152226491561, 0.05654444024267216, 0.01696241238424855, 0.08087260798821527, 0.00539155875054759, 0.049611673945741314, 0.12610898908948706, 0.1885122207984809, 0.18021850696494504, 0.15440633880995935, 0.21118690650309288, 0.11949244856594071, 0.16593173326503846, 0.28380290995682445, 0.10311142030742862, 0.1468026403698229, 0.21982068676621686, 0.22816768967576567, 0.08979193986423555, 0.18641101016152292, 0.11511267027667454, 0.28529969254328363, 25.91929666457638, 63.64680636313654, 52.12110204081382, 34.77138796160298, 35.19677292916083, 65.84921329252182, 65.91226931541198, 66.05005433482509, 59.36722986159786, 65.09575343901112, 2.3045841820778388, 7.669905106867514, 12.876049876213076, 0.3134985003740557, 11.737514272812875, 64.25800577286752, 62.6815777440225, 63.02428699308827, 57.423620916182, 58.18088154638968, 54.10688038795225, 53.46341163881364, 52.732270071583415, 53.03414744715537, 51.858032595726755, 50.41573785966443, 46.85811281204224, 43.459802673709014, 41.81732193116219, 44.80480301764704, 44.641773623804895, 45.0200979940353, 46.04012996919694, 45.2967349175484, 46.08544903416788, 46.72471300248177, 45.04083556513633, 45.784391433961936, 43.287030112358835, 45.89273906523182, 42.99513909124559, 46.702328035908366, 46.54036552675309, 43.46044594241727, 42.54951861596877, 43.16033363342286, 40.60691771968719, 41.85589844180692, 43.066494849420366, 41.49934322603288, 44.47802643622122, 44.55882726177093, 43.1047301138601, 46.2123377092423, 45.82913783288772, 44.97707351561516, 43.01933227046844, 43.71299166833201, 45.20470042382517, 45.07393252465033, 43.10653832650954, 43.563525830545736, 43.0698759325089, 44.24333926170103, 42.48900821132045, 42.191845524695616, 42.890925638137325, 44.77020379035704, 52.809058312446844, 51.78203667363813, 52.87929619512251, 56.015227225519, 56.864820449583, 58.44231144074471, 52.38998051612608, 51.40821518436555, 56.811990045732074, 53.2004520200914, 50.82218562403033, 45.906177105442175, 42.31674555809268, 42.62202362860403, 43.08032120427778, 40.421977966062485, 41.46865852417485, 40.5420534841476, 42.01753147186772, 43.567377598054954, 45.55530932641799, 46.79497834174864, 44.35121228618007, 42.98619216488254, 45.42784014055806, 44.48563975672568, 43.27489822141586, 39.81828597284133, 41.7138066599446, 43.8390488009299, 41.02426967313213, 41.009949099633005, 42.11286075653569, 40.60071645244476, 41.665385000167355, 40.832348100600704, 41.827814271373136, 38.95667852893953, 39.5930830893978, 41.608863645984286, 41.58914589112805, 42.49502512716478, 41.824033106527025, 41.4857522133858, 47.34020740755143, 53.5972938999053, 55.74913363302908, 57.36934315773749, 53.835777928752286, 55.38560444308866, 51.887179728477236, 53.85493086230371, 55.806549287611446, 58.357082259270456, 54.72291608010569, 56.625916727127574, 55.08531954980666, 58.4046253081291, 55.70517955287811, 57.87456797015283, 52.490714826891505, 50.32859456154608, 48.75046814641645, 51.514931109643754, 50.83194448101906, 11.80053597496402, 0.11763964193843066, 8.095294977388075, 3.0242913048113547, 0.2603838472597061, 0.861396003634699, 7.128487113983401, 69.76606861237558, 59.36504510141189, 65.6682429775115, 43.06496512505316, 41.665239872470984, 28.828085199479137, 59.37699264095676, 27.65456303473442, 0.3892808065058724, 0.16572911833082477, 0.12177639415547734, 0.10627111164672721, 0.15490711516430303, 0.07645026585387607, 0.0910069782947821, 0.1723465092119671, 0.12750872365769841, 0.13309424773098963, 0.09565649614218744, 0.19071643961773765], [0.045885870443476785, 0.054881596607306314, 0.04652008782291124, 0.003802085031507417, 0.029120436501539046, 0.027829409809783105, 0.03639925428996644, 0.002635977833697032, 0.06383141112183371, 0.04373896266183546, 0.052026306474280935, 0.10689456932126515, 0.028482323565009623, 0.05196237643699973, 0.12786003625801495, 0.21853493075937996, 7.235828657304087, 48.969905145706676, 42.28949685250559, 40.47990745113742, 29.355477286923318, 38.55837360505135, 57.13605234699865, 58.201744633336226, 48.165717278757405, 56.38595788709579, 5.228767039314394, 0.7187537416335076, 1.4997280413104643, 2.123603080549548, 4.473984366463077, 61.24659822833154, 58.80054935332268, 56.19020808127619, 51.723287413197184, 48.2905702437124, 46.006958484649665, 43.31285891994354, 42.985305709223596, 41.79311306245866, 39.99738923964962, 38.34506727034046, 37.91615216962753, 38.74831045827558, 40.43092489242554, 41.04081423051896, 44.09188870460757, 43.253211436733125, 43.35964887372909, 43.17345003927908, 41.58335255038354, 39.062810021062056, 40.225545667832904, 39.86196548708024, 40.0822889420294, 43.09592047045308, 42.73950253763507, 39.85639179906538, 39.11529525633782, 39.73110737339143, 38.85296713921332, 40.654794170010476, 40.433419519855136, 38.49915366018973, 39.44193847717778, 41.82926554833689, 40.92488073533581, 39.31313176308909, 40.94680286222889, 40.61260123406687, 41.53583695811611, 39.77070762265114, 39.33213172420379, 39.1680472127853, 41.4599940084642, 41.558041495661584, 38.4588905303709, 41.19313947616085, 40.37035565222464, 39.44527641419442, 39.344000816345215, 38.24384658567367, 37.88245900984734, 40.95302766369235, 48.31330822360132, 50.057409732572495, 51.837063604785556, 52.194360148522165, 54.34245009576121, 51.968635589845725, 47.52355860125634, 51.24279706708847, 52.19925526649722, 50.61220938159574, 48.24186617328275, 42.15072731817923, 36.14594336478941, 38.111682322717485, 36.48711112237746, 36.291341704706994, 37.7312869410361, 38.40599736859722, 38.090391697422156, 38.05765559596401, 37.90643645871071, 38.12549298809421, 39.15829620053692, 39.468406631100564, 41.5604341414667, 40.542728131817235, 40.78639361166185, 39.70611010828326, 38.637126953371116, 39.539107353456565, 36.622923189593905, 37.69581694756785, 37.957289987994784, 37.18084504527431, 38.31268810456799, 38.89075525345341, 38.582025497190415, 37.54179331564134, 36.907871615502145, 34.54780501704062, 38.102001913132206, 37.881521563376154, 37.77959485207835, 38.49763178056286, 38.08635950088501, 41.55451528487667, 44.3629676295865, 46.02895121420584, 45.097882516922496, 47.714950653814505, 50.03272625707811, 50.5234069208945, 52.25955386315623, 53.79862131610994, 52.36681892025856, 53.12125544394217, 52.66214986001292, 53.63548209590297, 50.24163169245566, 49.1078588270372, 51.46711741724322, 55.30006147200062, 52.1008586883545, 54.34312474343085, 31.195857294144172, 0.036868605717656114, 1.0922951491609698, 2.0872395221264135, 0.4405114655533145, 0.13450636228005733, 0.4054432698795873, 7.70763046318485, 60.034162229107274, 49.64407036381383, 47.714221092962454, 36.63254868599677, 33.16074509774485, 28.545662779961866, 46.56619041196762, 3.229865912468203, 0.09072708807164624, 0.05360661179668481, 0.03201360585198047, 0.024845028115857034, 0.06178713613940824, 0.015679612519189475, 0.074441499046741, 0.045415477136210095, 0.040838423545562455, 0.014990841061057103, 0.06737097481926603, 0.03893526195878944, 0.018780881035772544, 0.059195073817165635, 0.02342701468977236, 0.032230766880656445, 0.014606030308641495, 0.030542962185497728, 0.050548273889768514, 0.08044393582930488, 0.030726691137158105, 0.00637225758832609, 0.044296862362253095, 0.02469415859048886, 0.058352595435515534, 0.02866908814006996, 0.08639015707998507, 0.23824883985423276, 10.969134703759226, 55.549685032136985, 46.14894436251733, 32.295485927212624, 35.89472732236309, 46.924573452241965, 58.25206472027687, 62.36317542291457, 51.932679222476104, 63.40918917809764, 5.668788821466508, 1.588823454033944, 3.985829463889522, 1.5428249610047189, 5.333658081869926, 63.015308687763834, 61.80654794939103, 57.542284381005075, 53.75424754235053, 51.107985204265965, 47.77229178336359, 46.09502746212868, 45.54748419792422, 43.198780705851895, 41.79960458509384, 39.58490494758853, 40.065979726852916, 39.94463728320214, 42.90347722268874, 43.10904472104965, 46.772412946147305, 43.973237006895005, 44.8260191179091, 44.557638783608716, 43.24704939319242, 43.49386061391523, 44.02430626653856, 41.55718641896402, 41.81232875393283, 44.058917260939076, 44.01403357905727, 42.63124904324932, 40.754740084371264, 40.462825529036984, 40.05279664070376, 41.285107289591146, 40.96537136262463, 41.663902344242224, 40.08927860567647, 42.39568325781053, 43.943493673878336, 42.1090756693194, 42.7012711955655, 43.03268009616483, 43.63808224278112, 42.14265115799443, 41.40679097944691, 41.67132346860824, 43.29269401488766, 43.18841780385664, 41.12289767111502, 43.03395094410066, 41.788233633964296, 40.92885409632037, 41.10919290973295, 40.48786201784688, 39.540178160513605, 42.65139041408416, 49.36536635121992, 52.29402757460072, 53.73509460879911, 54.12715904174313, 54.75446370340163, 52.407854757001324, 49.00500251400856, 52.56128218866164, 54.06207907584406, 53.01396293024863, 49.32057680622224, 44.32375961734403, 38.57454553727181, 39.58791340551069, 39.616574164359804, 40.04039802858907, 40.342514668741536, 39.69097760415847, 39.202583682152536, 41.30198132607245, 40.786672099944084, 39.775598818256015, 40.63323682354343, 41.214332042201875, 43.69394071640507, 42.163141619774606, 40.827707936686856, 39.87833746017949, 40.68192520449239, 41.123976322912405, 37.83774398988293, 40.08396771646316, 39.48495118848739, 39.133267556467366, 39.992654938851636, 38.99869495822538, 39.672781728929095, 38.58862684619042, 38.857058171303045, 37.95919233752836, 39.31365343832201, 38.39856839949085, 39.73888543344314, 40.825244688218646, 39.009610914414935, 44.412679749150435, 47.140652902664684, 48.78863673056326, 47.78313321451987, 51.832658783082046, 51.177599430084236, 52.056312330307506, 53.33477750901253, 54.01378293191233, 53.20069128467191, 53.86634495950515, 52.66221654030585, 54.90083479112195, 52.42923167444045, 53.125005229826904, 53.33950396507017, 56.45186547310122, 51.21461875977055, 55.496611441335375, 34.184248370508996, 0.5710828172103052, 0.9553368305487018, 1.7936770810234932, 0.5081891130295493, 0.09263624046598712, 0.6539671567659224, 8.98193645861841, 65.32019538264122, 56.27000870243196, 55.19313373873311, 46.19393787076397, 35.186998382691414, 24.117451983113444, 55.33185228224724, 6.297134382109489, 0.17065789820926805, 0.06545040771485337, 0.01610865144269361, 0.0200730204702385, 0.0514639672943421, 0.04977329934556639, 0.026715952722776323, 0.036374605411002715, 0.0694432579762032, 0.016528410168604988, 0.050529489413865154, 0.037370209446958, 0.1375691511578137, 0.14286317111503694, 0.1351627923788563, 0.1326816940620061, 0.11531880155446068, 0.14813603172379156, 0.12050024489121092, 0.1924627217193765, 0.13355685758494562, 0.07780937477946281, 0.14346102613114542, 0.18047638748201633, 0.17912418100862734, 0.11855550771278721, 0.2514755930150709, 0.33667413097235466, 13.921614520011412, 68.01329474295339, 50.99809608151836, 51.487651025095296, 41.11565697577692, 48.91590979791457, 65.11587912036528, 69.7538229726976, 55.86966022368401, 69.63737564702188, 6.7682752686162155, 4.208590917048916, 10.27248057626909, 2.9445127469878045, 6.69740931641671, 63.777338920101045, 63.35394651659074, 61.63095520388696, 56.937266626665675, 52.04940503643405, 50.48374391371205, 47.59285511509065, 49.3601692107416, 45.072140001481586, 44.530401845132154, 41.207091346863784, 43.327924743775405, 42.54321144473168, 44.51745802356351, 45.989809882256296, 48.99455331986951, 45.90068186483076, 47.15300052396713, 47.35985848211473, 46.27955536688528, 46.21524418553999, 44.83029450139692, 43.9337936524422, 44.380465322925204, 46.661449093972486, 46.176153844402684, 44.88652560018724, 45.18664183155183, 42.76647667731009, 43.02328994197231, 45.01354763584752, 44.07965875441029, 43.156136697338475, 42.4309806669912, 44.96468274824081, 45.67618500801825, 44.231634909106845, 45.117070751805464, 45.10107140387259, 46.31915561614498, 44.829925798600726, 43.093755322117964, 43.2266922919981, 45.0640050057442, 47.382635685705374, 41.45207866545647, 45.12795532903364, 43.8398568091854, 42.95453863759195, 43.15236729960288, 42.49092625033471, 41.96681522553967, 44.584275599448915, 54.45430040359498, 54.141460003391394, 55.82693384539697, 56.78827931804042, 56.64498729090537, 54.16881461297312, 51.96094382193781, 53.21203477921025, 56.16705040777884, 55.86743231742613, 52.26380963479319, 46.078349544155984, 40.26326317940989, 42.56863624818864, 42.23730187262259, 41.3110420011705, 43.01804573305192, 42.186354206454375, 40.54574443447975, 43.86703491210938, 42.843480648532996, 39.968767704502234, 42.33820484530541, 42.68151029463738, 46.133576516182195, 44.79467545786212, 44.29669918552522, 42.60182734458677, 44.93107588060441, 44.6414049210087, 40.13016146998252, 41.74713503929877, 41.205542010645715, 40.531831787478545, 40.80355790353591, 41.93638155537267, 43.61565020776565, 40.9482188378611, 40.32305579031668, 38.72900847465762, 42.01205584310716, 40.423221357407115, 41.22113343208067, 42.657305348304014, 41.51394621018441, 45.004216317207586, 49.179085146996286, 49.96550075469479, 50.12863605253158, 52.14333795732068, 52.58796215057374, 54.7019745457557, 55.956344604492195, 57.53241569765153, 56.53016774885116, 56.6388487815857, 55.76412885419784, 56.823345307380926, 53.88646671848913, 54.94958592999367, 53.674572437040275, 57.90538603259672, 54.58125575896233, 54.231384261961914, 38.4569921032075, 1.2315288714824186, 2.22519148741999, 6.436303998193433, 2.1389841648840138, 0.2970990400400854, 1.2212868275180941, 9.811707004424065, 71.84191242341073, 60.30944593491093, 59.05367559002292, 47.14904677483344, 44.63121068093085, 36.75427159955425, 62.823708749586544, 8.178688979917958, 0.28250766978148495, 0.14732122060752686, 0.16914090622336636, 0.160216839923974, 0.1374417047707304, 0.09653162136073075, 0.21775932802307993, 0.14854682339054925, 0.16020991448913852, 0.08272007498289309, 0.14837425442472582, 0.13584491706663562], [0.07931630803091873, 0.014880398953063114, 0.02766182616112694, 0.011049110889284602, 0.051246268088899316, 0.021546538881657105, 0.08646590785393793, 0.02293776987390893, 0.03430542491015888, 0.04861386740700372, 0.07125861822597443, 0.02027571009802482, 0.0737309754796086, 0.03521572122530591, 0.0533266794387131, 0.10131040122359992, 0.9728068834350956, 35.47605353017008, 52.64120832566292, 35.340971023805686, 22.96321022895075, 40.19313904546922, 51.72812369561965, 62.66397022431897, 46.8823177583756, 58.58808632819884, 6.614858623473875, 1.6808398067951205, 1.205378919839859, 0.6884503064136351, 1.6279573089653447, 47.331272248298895, 61.27498442126859, 53.6868102319779, 52.1325239827556, 45.67331383305211, 47.28707890356741, 41.50754097969302, 41.069212190566525, 38.03998139596755, 41.25400681649485, 42.04042242419335, 43.85427544193883, 44.42502737045289, 47.43541902111423, 47.95260706255513, 51.40901927025088, 50.67642250368672, 51.16055673168552, 47.18847836217573, 46.41483006938812, 41.960453141120176, 40.59839440930275, 40.52776428960985, 39.74640853943364, 40.948014874612134, 38.7505462092738, 37.683324198569025, 38.7573475991526, 39.61941396036456, 40.8216243405496, 39.47165827597342, 39.51454939380769, 39.45356438236852, 39.22488235658215, 39.740568130247055, 40.54970602835379, 39.62224591162897, 40.236116455447295, 40.86508420205886, 38.4902734141196, 38.23801402122744, 41.05238914489746, 39.82957063182708, 40.280929534666, 41.88854825112128, 40.66621611195226, 38.9703832903216, 40.9567892166876, 41.768908116125296, 39.85185361677601, 35.5790118248232, 36.206849928825136, 40.68689484750071, 46.97990632826283, 49.93206647134597, 51.00683904463246, 50.89243135144634, 56.457956913978826, 55.66248847592262, 50.58900071728615, 53.72544557817521, 53.78810151930779, 49.740960751810384, 50.18613015451739, 41.53624096224385, 36.3627641431747, 38.01856133245653, 37.29868873473137, 37.28039872261786, 38.9556900916561, 36.495222583893806, 38.814826011657715, 37.688085955958215, 39.791303988425966, 40.112408822582616, 39.174397530094275, 40.36213436434346, 40.26410648899694, 39.04031130575365, 40.71439458477882, 38.558255933946185, 38.13380841285952, 40.15258566025765, 37.89491253514444, 37.05168531787011, 38.42230658377371, 38.107759952545166, 37.48318918289677, 37.202786784018244, 39.108344816392474, 37.19724447496476, 37.228227276955884, 37.2013198175738, 37.17930747616676, 39.00044433532223, 37.753707208941066, 39.99138016854563, 39.63956317593975, 42.96311293878863, 43.634234397642075, 45.78162224062028, 46.249635527210856, 46.03490144975724, 46.86146643853957, 46.11936184667772, 46.66874862486317, 50.83110117143201, 52.13070008062547, 52.66859431420603, 51.38366506945703, 53.56978631788685, 50.60976966734856, 52.779103171440866, 52.92778061282251, 55.2959978965021, 50.95291037713328, 54.73172180114254, 21.89887312150771, 0.20396923976800135, 5.099195953338377, 3.1890176140492965, 0.3842466895378405, 0.21578352597932662, 0.49970548599958425, 10.535461768027275, 57.89432494871078, 49.09076906019642, 40.65039327067714, 30.989728896848618, 18.972039722627212, 38.469100459929436, 30.824638297480924, 0.23847819125700384, 0.010732850641943516, 0.038033630098066026, 0.08771194220190087, 0.03907672392444746, 0.0310050645062039, 0.07668216832943502, 0.05535036580817354, 0.019911795351353866, 0.03341216639044785, 0.03513100339219936, 0.041783596013462355, 0.03582113752922705, 0.01662893622602907, 0.05904004443436862, 0.02222535598482336, 0.039263063320709814, 0.06036575575689636, 0.03436499590715093, 0.045923067842640226, 0.040684332620472684, 0.018672807097074487, 0.07807554436787482, 0.040948770850175814, 0.031378752619568864, 0.014260501672153272, 0.035409920683671395, 0.03877341439346633, 0.05774630962180034, 2.417504071227966, 47.719810470458, 58.31637197925199, 40.65811641754643, 30.398810102093606, 47.074458983636674, 56.5359297106343, 68.6927120147213, 52.30657915915213, 65.06918722583403, 8.434113725539177, 1.0661456878146818, 1.5764285191412897, 1.5690631659761554, 2.012024274276149, 50.3551293957618, 62.94501981427593, 58.662638818064046, 53.82650152329476, 48.070262478243926, 49.18984813074912, 43.64422075210079, 42.86725805651757, 40.170958042144775, 43.86921182755501, 43.12637375247094, 44.67336047080256, 45.90911496070124, 50.32373866727276, 48.70318005161901, 51.00789808457898, 52.37268678603634, 51.42337122271138, 48.604414770680094, 48.7409681658591, 43.60956661162838, 42.78068742444439, 44.70854020887806, 42.686079855888124, 42.49568408535373, 40.66917357906219, 39.918883000650716, 40.81992595426498, 42.401951205345895, 43.100564556737105, 41.442080543887236, 42.080579650017526, 41.00466174464072, 41.34644531434582, 41.545631116436375, 42.94206157807381, 40.823499233491965, 42.397193370326875, 42.621113638724054, 41.42239809036255, 41.096876667391875, 41.83140716245098, 41.46651298769059, 44.29359659071892, 43.686951052758005, 41.863609821565696, 41.69120596301171, 42.869831131350615, 44.0225019762593, 40.38190311001193, 38.60898394738474, 37.19701305512459, 43.691085230919626, 48.505947589874275, 50.725479587431884, 52.59557154870803, 54.50320059253324, 56.25065965037192, 57.55247077634258, 52.16169072735695, 54.59719627134262, 55.42572636758128, 50.627796880660526, 51.49965740019276, 44.28354747833745, 39.73767342105989, 40.51797405365975, 38.95121858965966, 40.930576016826016, 39.94743001076483, 39.078679930779245, 39.932595606773134, 40.04627766147737, 41.717140674591064, 40.60739232647804, 41.95036872740715, 41.847049574698175, 40.80033763762444, 41.70091775155837, 41.20369065192438, 39.4952787891511, 41.7714145106654, 43.38863518930251, 39.530340856121434, 38.847558190745694, 40.942480410299, 38.84625988621866, 39.56223757036271, 39.56053133933775, 40.403970364601385, 38.953866189525975, 38.73015380674793, 39.75930137019004, 39.06463000082201, 41.106792419187485, 39.75206067485195, 39.53535756757183, 41.70243963118523, 44.58854313819639, 45.64487664930282, 47.71522914209674, 48.36920592092699, 49.066626871785815, 48.81916061524422, 47.997275014077466, 50.5073408926687, 52.83218852935299, 52.83753471989786, 54.65736150741578, 53.712172277512096, 54.16203675731536, 52.302091967675, 55.63454158844487, 53.49448073294855, 56.90348717474169, 53.12009442237116, 54.35901034262873, 23.771742120865856, 0.07501817939262237, 6.997068101359952, 4.206448322342289, 1.0865366194517383, 0.17321857773969251, 0.730306470105725, 11.525882790165564, 63.62915569736112, 52.485776562844556, 44.07989017425045, 42.89780939778974, 22.240729255060998, 39.35267709916638, 40.283753641190074, 0.46567543139380796, 0.07098411360094625, 0.005044286306421723, 0.04957345381919896, 0.02386523230421928, 0.013563790670295638, 0.07466803890682998, 0.01853171285362013, 0.027356362007858775, 0.04482145255972301, 0.03540510965150691, 0.029852893165943604, 0.02016543940220389, 0.12519927500116249, 0.1758710192816873, 0.14892694089681874, 0.0794189101866176, 0.10501911713471336, 0.17492001305424398, 0.1468564350638659, 0.08039178822429911, 0.1020468875104862, 0.2095216765038429, 0.2437923133613602, 0.13145337932773177, 0.09536746649011489, 0.2141973409321039, 0.2224624183990302, 0.33072689848561443, 2.6782877550971125, 56.63009405136109, 64.6438414819779, 46.040408457479174, 34.63122598586544, 52.81603228661322, 59.93882117732879, 72.60395050048828, 56.71549581712293, 70.72523716957339, 8.996097195533014, 3.09847901425054, 7.4573621634514105, 3.3301851874397648, 3.331011581805445, 50.76338929514731, 65.90917064297584, 60.001994871324115, 56.829766227353005, 51.15809348321731, 53.278687615548414, 45.14292701598137, 45.115807748609974, 42.286837485528764, 45.53650156144173, 46.789616461723085, 48.47875379746961, 49.30507559930125, 52.91132234757947, 51.70115740068498, 55.41088019647906, 55.88689119585099, 55.52216568300801, 50.92560675836379, 51.05411929468955, 47.183085103188795, 44.76426139954598, 44.68801052339616, 43.158505808922556, 44.24239789285968, 42.91409115637503, 41.20836219479961, 42.98604311481599, 44.456033706665046, 45.25217679239089, 44.379449429050574, 44.455951336891424, 43.620612006033625, 44.08214161472936, 43.083431643824426, 45.04145529962356, 43.819558543543664, 44.71969542964813, 45.275240329004106, 42.86701879193706, 40.844181891410585, 44.33656615595664, 43.089707436100134, 45.45122923389558, 44.977100972206365, 44.594473761896936, 43.06716165234966, 45.14196211291898, 45.498772282754224, 43.85472651450865, 40.46271178030199, 39.92748475843861, 45.82436038601784, 50.4371226218439, 52.74384890833209, 55.477317302457756, 56.32115248710879, 60.235564170345185, 59.56705893239668, 55.6717295800486, 58.41532553395918, 55.86254112182125, 52.83565590458532, 54.99193576074416, 46.43959199228595, 41.529639613243845, 43.31060747946463, 41.37461185455322, 42.2976710719447, 42.58641242980958, 39.85667813208796, 43.10119213596467, 41.631401584994414, 43.62318115849649, 42.97365234744164, 44.14813549287858, 44.312251383258456, 43.777271470715924, 44.24745775038197, 43.47825742536976, 39.872779461645315, 42.8747066374748, 45.12185604341569, 42.4894828181113, 40.33613297247118, 43.608382055836344, 41.60750258353449, 40.562069339136926, 39.672766039448405, 41.68792293917748, 40.467328409994806, 41.82228372943017, 42.22733120764456, 40.811932163853804, 44.280362513757524, 41.5829054001839, 43.34917222299884, 44.801280729232296, 47.13755423022855, 47.640660962750836, 50.18775401576873, 49.053522233040106, 50.01206321101035, 50.637481212615974, 50.81436049553656, 53.61039853865101, 54.263296665683875, 55.012328163270034, 56.827287289404104, 54.87475887421639, 57.03187811759211, 54.89250367687595, 57.30016039263818, 56.32710272266019, 58.54911758053688, 55.05488195726949, 54.0055420321803, 28.64530667181938, 0.5755190791622286, 10.336577007847449, 9.515320947093349, 1.9273203226827809, 0.2513291170039485, 0.9632721531295008, 13.706764732637714, 69.70011788029825, 56.23278540949668, 52.08423960593439, 42.59789712967412, 28.61085061104067, 49.846962805717226, 48.203423023223884, 1.3106797275043305, 0.15995465399276826, 0.08155556005095282, 0.22188558483556395, 0.10437661451437782, 0.13250330282795814, 0.19336020904442958, 0.17273545205112428, 0.11157316020539693, 0.2659105281195333, 0.1128013906699996, 0.23022161736603708, 0.14018413100031116], [0.11952507625063581, 0.02964755861959871, 0.042621650237349734, 0.0248917518183589, 0.015408927800073741, 0.06586360489769329, 0.12036023466216943, 0.03689530388181729, 0.036141990473674196, 0.01779259313949414, 0.02697200995058783, 0.030047479498710845, 0.021954522836172295, 0.02746246901581124, 0.059145385354396805, 0.12905052923146756, 0.19955815146526984, 20.687196100911788, 47.69649590215376, 42.75932227411578, 36.65699681928081, 34.903171754652455, 47.14371235139909, 52.03051097931401, 49.23463375337663, 60.9357072461036, 7.177212267152726, 0.9077313302024719, 0.17329500267101874, 0.6306052748714724, 0.2869253004750898, 39.01591416328184, 63.977258205413825, 53.20112274539087, 56.26569017287224, 46.11925594268307, 44.818484244808076, 41.115453012527965, 42.78749665906353, 43.46458796531924, 48.51414142116424, 49.024606520129794, 51.42609726998114, 51.616818597239835, 52.03218190900741, 53.47953650259203, 56.24103415396906, 54.40942848882368, 53.8276586224956, 52.44730203382431, 48.21720230963923, 43.12694249614593, 40.01273355176372, 39.52809726038287, 41.335843147770056, 38.617824969753144, 40.5643403914667, 39.9162354007844, 39.48158187250937, 41.90010355364892, 41.65198226128855, 40.79985126372307, 39.97631826708394, 37.35586512473322, 39.07990371027301, 40.21242141723633, 40.50019002729847, 39.570294118696644, 42.035888164274155, 41.65539472333847, 41.53294224892893, 41.004834328928304, 40.562355672159505, 40.62240715949766, 40.965414508696526, 39.867696069901996, 39.943437037929414, 40.931164372351866, 40.67076998372232, 41.69575199004143, 40.874599872096894, 37.011775201366795, 37.60187618194088, 38.90749985171903, 47.14590495632541, 48.359156808545514, 49.948136421941946, 52.92660782414099, 54.18535132561961, 54.17899708594046, 50.78986529381045, 53.502713787940245, 56.58449257573774, 50.51825292648808, 46.80595313349078, 42.41811137045584, 38.08348048117853, 39.42296597265428, 37.68184154264389, 37.14824622677219, 38.0546667498927, 37.73362859602898, 39.256696701049805, 38.12059787011916, 39.2224387199648, 40.89434508354434, 40.326476097106934, 40.27684634731662, 37.850891774700536, 38.79816770553589, 38.24158730045442, 39.742046863802024, 38.57443178853681, 38.181677018442464, 38.182139858122795, 38.874026344668486, 38.6763467327241, 37.52475846198298, 38.22141847302837, 37.1916707869499, 38.2824662423903, 37.23008255804739, 35.43943428224133, 35.87224821890555, 36.57741585085469, 36.769137382507324, 38.19033761178294, 37.188736854061005, 37.88267081783664, 38.2076431089832, 44.139749465450166, 47.06439025940434, 48.305043789648245, 47.362898318998276, 44.64029489024993, 44.43863407258065, 43.26347235710391, 47.06551597964379, 46.6790017004936, 49.86400942648611, 50.772347988620886, 51.38454368037563, 47.68451306127733, 51.3176162781254, 50.63986209131057, 55.076796239422215, 51.615512447972456, 56.94831594344109, 18.598600664446433, 0.13251182172567616, 0.6154662743210793, 0.3725510703459863, 0.40080849922472433, 0.22855772035977534, 0.3757153199084344, 18.315138816833496, 56.83219809685984, 50.5504124395309, 41.004563685386415, 24.405708928262037, 27.401040638646773, 46.08669634788267, 19.42074121967439, 0.13330171966264326, 0.03562509562940367, 0.03189543870488002, 0.0440307310782373, 0.06744427411186119, 0.05178578550957384, 0.06371524920987506, 0.03460111569673304, 0.01545086824109838, 0.04626440980862226, 0.04528734126999494, 0.008907068723572359, 0.028216431683470166, 0.036329816080509655, 0.06144795071093306, 0.0557653249932393, 0.022343632299453024, 0.09660249981548517, 0.06312466819860763, 0.05149096806323336, 0.053380324745610844, 0.04365740494141656, 0.012494896917844252, 0.027102444080575824, 0.06245936297120587, 0.04274384509171209, 0.016498666804944797, 0.09704076339520755, 0.07751649170513115, 0.13167752133261773, 30.284396525352236, 55.893378796116004, 42.09974042830929, 33.92220266403691, 48.27882666741648, 52.292501772603686, 60.81624361776537, 51.68070224023635, 67.01515351572345, 7.593563035611184, 0.7241940690625099, 0.18477447781591647, 1.1760789372267262, 0.5494619160890579, 41.23454401569982, 65.72645487323885, 54.96783671840545, 58.31249667752174, 47.297433960822325, 48.56361427614766, 43.54861690152077, 44.07096285973826, 46.17052524320541, 48.30453388152584, 50.15631229646745, 53.348090033377375, 51.75002228829169, 54.43131923675538, 55.120938593341464, 57.833810621692294, 56.60128424244543, 55.55756899618334, 53.322724065473004, 50.452106075902144, 46.08402129142515, 44.05716396147206, 40.74602850021855, 43.343453407287605, 39.544171133349025, 42.31383515942482, 41.80622946831488, 41.52643895918324, 42.68391078518283, 41.9629007001077, 42.36085261068037, 41.14969530413228, 39.57729554945423, 41.85996201730544, 41.7580117717866, 41.87807944513137, 42.40055484156455, 43.94537641156105, 42.4209511664606, 42.53909687842093, 43.19536432143181, 41.42292368796564, 43.40397557904644, 43.44735307078208, 42.65954109930223, 41.57425265158377, 42.30455090922695, 41.48346154920517, 42.806881012455115, 43.60769956342636, 40.08068077025875, 38.221932303520944, 41.12446269681377, 48.37210063011416, 49.631067706692605, 53.950911260420284, 52.09666567464029, 56.26177956981044, 54.51270449546076, 51.76374666152462, 55.63628312080137, 57.306396961212165, 52.21195982348535, 51.23646636163035, 42.80975610979142, 40.083281301683, 41.11051082611084, 39.8571252822876, 39.6969513739309, 40.644203770545225, 40.35081832639633, 40.529195954722745, 39.83654460599346, 40.629302686260594, 43.49239756984096, 41.41731469861923, 42.10367456559212, 39.89834939279864, 40.35881996154785, 42.30893219670942, 40.49226291718022, 39.568348623091175, 39.89678828947006, 39.68623545862014, 41.19342973155361, 38.62248082314768, 39.95145044019146, 39.98100549943986, 40.13276592377694, 40.195559147865545, 39.899808514502745, 38.47237171665315, 38.349723123735004, 38.341415543710035, 38.37266114450271, 39.80258472504155, 38.28856945037842, 39.40276968863703, 39.69545302852508, 46.31431148898217, 50.48082959267401, 50.89360414012786, 50.792571729229344, 47.79677521797919, 48.64937297759518, 45.88394903367566, 48.604571665486986, 48.65874744230702, 52.053947141093595, 51.60663220190233, 55.44314953588671, 51.34519838517713, 54.445051454728656, 51.71974159056141, 56.04557068117204, 52.589464418349735, 57.52205279565627, 20.82936829136264, 0.10440614720385882, 2.1745071103495937, 1.2592565965267921, 0.3276751412739677, 0.22244841431177434, 0.38407165376890096, 18.803109122860818, 63.093767858320675, 53.55934496848814, 50.0721303878292, 33.13270799575314, 22.00411815797129, 51.47236162616361, 24.03369369045381, 0.30069441324280155, 0.052299190823349266, 0.03389304361095832, 0.018429489911443764, 0.028410295978368773, 0.014002856727118694, 0.0874440795591762, 0.026154161295703342, 0.10478113958191489, 0.07076385566183636, 0.02336680592458335, 0.09048840571795741, 0.017997347374236392, 0.13520783834880398, 0.2235798342453857, 0.14387368705243836, 0.09080089298227141, 0.23555040239326416, 0.1574956649734128, 0.15656071594886242, 0.13958587761848204, 0.13250645911020617, 0.13157760814553307, 0.1332693141434462, 0.12158376900779626, 0.18552696001866173, 0.13370287394331348, 0.17393952776347438, 0.17896733216701016, 0.3081753843974683, 34.74393529276694, 62.73848349048246, 50.997237082450624, 48.07394558383573, 47.00495850655341, 58.20596118127146, 65.69018079388526, 56.27963027646465, 73.71121991065242, 9.011672927487282, 2.156739018617138, 4.41012131590997, 3.2524401334024247, 1.726240628669339, 43.5789172111019, 68.91590272226642, 56.043668331638465, 62.77246298328523, 50.0075642524227, 50.67623030754828, 46.26062993080386, 47.14088824487502, 48.376038689767164, 52.83803286090974, 53.72102114462084, 56.26207374757337, 55.86154483979749, 56.352398087901456, 59.30102025308917, 61.15292418387629, 58.7661737011325, 59.154515804782996, 56.28643951108379, 53.112916484955825, 46.96926101561516, 46.36989147432389, 42.59703028586603, 46.79786128382529, 41.49846853748445, 45.74780356499457, 44.3220494639489, 44.04086259103591, 46.351166079121256, 45.724583133574455, 44.6081510666878, 44.04091750421832, 40.61027526855469, 43.85280847549439, 44.888067091664965, 43.86491683221633, 44.14486815852504, 46.772036398610766, 43.29372952061315, 45.386812148555634, 46.54783764193135, 43.54369432695451, 46.05346602778281, 45.18177417016799, 43.64194577740085, 43.638619607494725, 44.19702391470633, 45.8096161965401, 46.03321483058315, 47.370205694629306, 42.46116722783735, 40.968713222011445, 43.14587969933787, 51.46104558821648, 52.18581330391669, 56.303552812145604, 57.79042920758648, 58.79809002722464, 56.45834130625571, 54.643390024861986, 58.46583781703826, 59.89796576961395, 55.304136814609656, 52.329862348495, 44.354950304954286, 43.032640872463105, 44.90414096463112, 42.640388165750814, 42.0679025496206, 42.750704826847205, 42.88726214439639, 43.94250915896508, 41.57180117022607, 43.06176447099255, 45.82011638149139, 45.45802670140421, 44.64378187733312, 41.06456418191233, 42.869529108847345, 43.614799053438254, 43.00854575249457, 42.85614205944923, 41.71197099070395, 41.28406393912531, 42.91544829645465, 42.96957700483261, 41.66778549071282, 42.28274253106887, 42.12661650873, 43.15163773875083, 42.658391844841745, 40.915922041862245, 40.97424768632458, 41.92382997082126, 40.475428104400635, 41.39727530940887, 40.21640262296123, 42.30372721149076, 41.82318979693998, 47.42144361619027, 52.9061879650239, 53.63649014503726, 53.31848398331673, 48.049956367861846, 50.41407869708154, 48.2910801518348, 51.654238008683734, 51.91524820943033, 54.22928971628989, 55.587339785791215, 58.4380478243674, 51.16052535272414, 57.25480210396552, 55.35028349968695, 57.27831279077838, 55.04922589948101, 58.1934880441235, 24.436613282849713, 0.21969222914307351, 1.410004191340939, 1.649437433769626, 0.7641794460435068, 0.8225986145196423, 0.6302306272329823, 22.674280597317605, 68.30511123903337, 58.81852165345223, 52.558838552044286, 35.44632588663409, 37.67445179723924, 59.91345520942443, 31.550441518906627, 0.37354407351343866, 0.1584989643625675, 0.12695484208844363, 0.12639895336882723, 0.16008832101379672, 0.1486824056313884, 0.3453908325924028, 0.07354331458167684, 0.24847168565517475, 0.19493645027039513, 0.1459814400802697, 0.14238971345607312, 0.08362162257394484], [0.07659059783984577, 0.024357390169414784, 0.05311409387016489, 0.08740205197565018, 0.05366558907553554, 0.08613732508233479, 0.06645819637924433, 0.0054880542278800525, 0.03584072256701128, 0.03753262391734508, 0.01037263322711712, 0.11937734385531758, 0.029862224116861343, 0.14184520880301155, 0.22797944655101146, 0.0755776534037244, 0.27915857852466647, 6.3090760380991044, 45.5368741866081, 51.61593998632124, 31.904945335080548, 33.11987007817915, 36.073465808745354, 55.53369745131462, 52.21221869991672, 59.683086564463956, 17.84176561140245, 0.6457547555046698, 0.8202238645284408, 0.5423493719389362, 0.3832520316204717, 26.50195102537832, 67.79796446523359, 53.348533261206846, 56.86496557727937, 46.198593724158506, 47.33666158491566, 45.34611363564768, 47.33037402552944, 48.34404783864176, 53.02155663890224, 53.369804274651315, 55.93314378492294, 55.31349166747063, 56.189541278346894, 56.1660502033849, 56.5834923713438, 55.54387207954161, 55.94726431754328, 53.63955351614184, 51.910408004637695, 42.60134881542575, 41.37731044523178, 41.51554261484454, 41.56023802295808, 38.7063842435037, 39.59606409072876, 39.03394529896398, 40.434043176712535, 39.18162645832185, 41.13814000160464, 40.08750961672875, 39.89204222156156, 39.49336467250701, 39.97783230197045, 39.9680067646888, 41.14486294407999, 40.23962305438134, 41.01862930482434, 42.596798866025864, 39.29019766469156, 38.046433694901005, 41.163290239149525, 40.14809062404018, 39.73151922225952, 39.91520381742909, 41.823232943011874, 40.26034493600169, 41.16031708255891, 40.29282608339864, 39.43083424721995, 38.29617884851272, 37.925001036736276, 38.34052908805109, 44.93926186715403, 46.776088206998764, 48.13507964534145, 50.975624822801166, 55.69212198257447, 56.4769882540549, 51.30540201740881, 52.51390780172041, 55.44675419407507, 51.99071461154569, 45.55659586383451, 40.83216767157278, 39.63209890550183, 39.50257439767161, 38.36389464716758, 38.977506314554525, 39.148027435425796, 37.6271362458506, 39.79869765620078, 40.100500506739465, 38.217923641204834, 41.71368506646926, 40.67573570436047, 38.26289361523044, 39.02309994543753, 38.594773200250444, 39.33023329704039, 38.04516676933535, 37.447727034168864, 37.238460740735455, 38.90048273148076, 37.57960888647264, 38.10295897145426, 39.30659317201184, 37.753373807476414, 39.41951036453247, 37.87448483128702, 37.44356539941604, 36.3762100281254, 38.01283074963478, 37.377783329256125, 39.00765757406912, 37.686371880192915, 39.49913055666032, 40.94145667168402, 44.033869005018666, 46.41426917045347, 50.189605374490064, 49.559594277412664, 50.28791566048899, 49.16096379680019, 48.638488400367, 46.75764522244854, 45.209595541800226, 43.58095684359151, 44.251423266626176, 45.41036205907022, 47.52897539446431, 47.31528858984671, 48.119649041083555, 48.966810395640714, 52.9969516108113, 51.99750423431397, 55.10046382104197, 18.44953686960282, 0.08048120600682113, 1.9662860059930434, 0.2733019895611271, 0.27571587132350095, 0.5122037814749826, 0.30227669124161044, 18.516313260601414, 60.292077679787916, 50.46991755885463, 29.688327658560972, 20.480575446159612, 35.470319024978146, 45.23986839479016, 5.069746307788357, 0.3765466478803466, 0.14589280370743046, 0.13874008590655942, 0.05214505776342365, 0.026201003741833474, 0.015048512159996938, 0.055407554271721074, 0.0110477683201973, 0.013437177403829994, 0.07154030109485311, 0.06585664881934082, 0.009669059035067838, 0.025502538398629235, 0.03954145967239334, 0.020287278025681456, 0.03367317637668983, 0.07504899144893692, 0.05240426361260395, 0.07662851153121841, 0.0752185267065802, 0.10601463307055736, 0.012813545444289283, 0.06682555852157455, 0.06578564012963926, 0.06671364073671641, 0.05695867547464948, 0.11018400531141989, 0.09786584775053686, 0.029590203531927643, 0.11024680919945241, 11.54890710307706, 53.593402908694365, 55.793311288279874, 34.583188718365086, 43.74051101746098, 44.82061016944147, 59.6915824182572, 54.30210459616877, 65.14095875524706, 17.632724854253954, 0.8648071786569012, 0.4082625960150073, 0.22586622365540077, 0.2321988749768465, 29.433067652486987, 69.17502234058996, 54.88936185836793, 59.63039736593924, 47.56464935118153, 49.8548585368741, 46.96059257753434, 49.903778337663226, 50.02164163897115, 54.833746571694654, 55.212106243256606, 56.75883408515685, 57.46474304506856, 58.433462573635964, 56.89994527447609, 58.40179727923486, 56.48531152356056, 58.22718904864404, 54.93774429444344, 53.824799214639974, 44.654274217544064, 43.98051692593483, 43.045086553019864, 44.14704899634085, 41.039096232383486, 41.303114891052246, 41.87787940425258, 42.53412331304243, 41.09001644196049, 42.752881742292836, 41.52381881590813, 42.4490471040049, 40.994953878464244, 41.94424198519799, 42.5279926484631, 42.70093387173068, 41.79478006978189, 41.52357170658727, 42.38353959975704, 42.51852012449696, 38.804325826706425, 43.17511312423214, 41.721145414537006, 43.35900560502083, 41.18234511344664, 43.546585113771506, 40.93773434239049, 42.48476028442383, 41.45715813482962, 41.173398187083585, 39.11377729908113, 39.70524326447518, 40.76132966626076, 46.11679269421486, 48.0588326915618, 50.49406366963541, 53.14572711144724, 56.4893437200977, 57.095310688018806, 54.98666017286239, 54.03818791912448, 56.083994219380045, 53.73956611079555, 49.79428145193285, 42.096375034701445, 42.37327867938627, 42.707241042967766, 40.0798100040805, 40.480421281629994, 39.99254511248681, 39.90418195724487, 40.60240307161885, 39.791962946614916, 41.38619853604225, 41.93127855177849, 40.60404654472105, 41.62773809125347, 41.60067373706449, 40.2743556422572, 41.74110635634392, 38.97109716169296, 39.04968577046549, 40.86945764480099, 38.8380072193761, 38.643551795713364, 40.0039670544286, 41.025599356620546, 40.989768505096436, 42.08902451299852, 39.702274030254735, 38.73940667798443, 38.750554054014145, 39.78059199548537, 39.992588258558705, 40.4780404029354, 40.09662128263905, 41.31433679211525, 42.581262357773326, 45.02212585941438, 48.90049096076719, 51.2120613744182, 52.348948601753484, 51.252014636993415, 51.68689174036826, 49.52804273174655, 48.17975544160413, 47.420412032834946, 46.85342165731615, 47.28478431701661, 47.92957490490329, 49.946088944711995, 48.21555099179668, 50.65339426840506, 51.28761406867735, 55.16825414473011, 53.516618590201105, 55.87948576096566, 19.653751580945908, 0.03838134974601769, 2.7799742212218623, 0.5373091262675102, 0.36622355181363325, 0.49656161437592206, 0.4508800672427301, 20.937462929756414, 66.53488282234439, 52.134775423234515, 41.29572122327743, 24.95181268261325, 33.392839585581136, 56.4164621599259, 6.825362424696646, 0.3838226139064758, 0.06490770336841384, 0.07583734954917624, 0.03151877625514904, 0.032658152011854034, 0.04350722872561986, 0.02351147013776485, 0.011995171061566761, 0.031844924782372774, 0.07249033439063257, 0.08362174514801272, 0.03243259657474776, 0.0444077918936889, 0.24594692032664056, 0.13544342570727871, 0.12074775257778746, 0.17514395587626966, 0.11991710642412787, 0.18407278724255102, 0.12759395860015385, 0.20788070084827565, 0.13251957453546986, 0.1781328785563669, 0.2153799202172987, 0.29990549589837756, 0.11028129847780352, 0.32811095337233237, 0.3286616173723052, 0.17191206075010762, 0.617504497208903, 10.688040006545283, 61.94872994576732, 63.240048731527025, 40.473376704800515, 46.11228196851669, 45.967115048439275, 68.46319844645839, 60.98525854849047, 71.74867768441477, 22.883425297275668, 1.0506995166501691, 0.9952124424519079, 1.7651006531330848, 0.6468210886082342, 30.906433443869318, 70.45492310677805, 58.06557170806393, 62.075446036554155, 50.01624837998421, 53.207265177080714, 49.167086616639175, 52.016739537639005, 51.50602340698243, 56.91036701202393, 57.565889204702074, 58.622669866008145, 58.24662439284786, 59.486069833078695, 59.744754068313114, 60.295627424793864, 57.96477856174592, 60.40579895819388, 57.51613393906624, 56.83133909779211, 46.84729491510699, 46.96882171015586, 44.82843922030541, 45.4198581172574, 42.23194783733737, 43.52841669513334, 43.145134449005134, 44.54616977322487, 44.85687248168453, 44.58423245337702, 43.21991443634034, 44.41983807471491, 43.31131742846581, 44.08786435281077, 43.19878855059224, 45.31322063938264, 44.49537900186355, 43.93926928120275, 47.037196466999674, 44.64703352220597, 41.084756543559415, 46.72219484083114, 42.90560314732213, 45.05079446300384, 43.4523658598623, 46.088453569719874, 42.19200634187268, 44.91434304944931, 44.10131808250181, 43.77698906006352, 41.76116143503497, 42.24078885970577, 41.68500077339911, 47.613757425738925, 48.50877169639834, 51.91942945603402, 56.33897965954196, 59.467313058914684, 59.826406048190215, 55.85439828134353, 57.92790043738581, 58.454227601328206, 57.899290669348936, 50.613201741249334, 44.323147727597146, 45.7225513458252, 45.2305409985204, 43.213736703318936, 43.03574738963958, 42.690567047365256, 40.292939832133634, 45.259535158834154, 42.945976103505785, 41.843272332222234, 44.812333968377885, 44.16518211364747, 42.86384559446766, 43.09976439322195, 42.14541642896591, 44.842818629357126, 40.71454363484537, 40.79723504281814, 42.496441102796986, 41.553009094730506, 40.56050431343817, 43.45865341924852, 43.26931276629048, 40.763561494888805, 45.67989949257144, 40.81732542284074, 42.09916776226413, 41.091440262333045, 41.890709477086226, 40.8313008277647, 43.36111191780337, 41.985772040582475, 44.59156336322908, 45.507574081420906, 48.972921448369185, 52.24752787620791, 54.98689943744291, 52.53391188959922, 53.339033280649495, 53.25642816482052, 51.856247917298354, 51.71230869908487, 50.136567085020005, 49.16942827163204, 49.39410555747248, 50.94069611641669, 52.23528223652994, 52.67036330315375, 51.44706233855217, 54.361453979246086, 57.37524240247665, 55.05986336738833, 57.72720844514909, 22.158077070789954, 0.26602807665063494, 4.682908433098947, 1.6516641142868227, 0.8963884485344734, 1.0730957600378221, 0.931667042595725, 22.950215416569865, 71.27693422379033, 57.59787613345731, 40.55498553860573, 27.979554937731837, 45.50448717609529, 61.03293103556479, 9.831521837942063, 0.9856609807860468, 0.27803043744737105, 0.3080741382173954, 0.1353633848409499, 0.11997408804393585, 0.10619301664372606, 0.13027220964431763, 0.11194408465657504, 0.15304477074213568, 0.18976831388088966, 0.1696275252728693, 0.11731894221156837, 0.11943866919365623], [0.05386051631742909, 0.04242267805121599, 0.07192538285087194, 0.03966481131952136, 0.033587010637406385, 0.027366292422577262, 0.0041181195223133175, 0.0351765779628148, 0.06295461583161546, 0.003512180123981389, 0.024630887388822534, 0.04294151109793494, 0.02663037112553514, 0.060326826999024044, 0.06974653686366736, 0.07449936932854115, 0.06968616147435482, 0.05306415259838105, 18.47706602465722, 53.429283095944314, 35.84868261891027, 30.182365871244865, 27.83214834428603, 46.38721266100484, 54.54567201675908, 54.81160479207193, 31.857725881761123, 0.26518501221172275, 0.4048594802377686, 0.4830584873355204, 0.24394448906663926, 14.32093337658913, 66.25543748178791, 56.28983236128285, 59.85941671556043, 48.938071189388154, 48.75150757451212, 45.92997412527762, 50.45459285859139, 51.55102475996941, 53.8093097748295, 53.728952177109264, 57.6707027804467, 52.62537763964746, 53.237200706235825, 50.6138724665488, 54.8920290700851, 55.69500492465112, 53.691532765665364, 51.8573461809466, 48.244462782336825, 41.34444098318777, 41.24854687721499, 42.516606007852864, 42.102419407136985, 38.84410650499406, 38.07050135827834, 38.50882622503465, 40.108239343089444, 38.75001668930054, 42.82333927769815, 40.191456348665305, 39.514933786084576, 40.780160965458045, 41.46651691006076, 39.923468251382154, 40.15383297397245, 41.145941595877375, 41.580430384605165, 40.358686600961995, 38.280552125746205, 37.37802651620681, 41.39830689276419, 40.612663991989635, 41.38604556360553, 38.60859563273769, 40.70847965055897, 39.87747846111175, 41.23771329079905, 40.6098908762778, 41.57850842322073, 37.86219996790732, 39.05354538271504, 37.264081662701024, 41.221745321827555, 43.05737926113991, 47.91137902967392, 47.973262263882546, 54.065440547081735, 55.06970851652084, 53.70639462624827, 55.12030709174372, 55.566374717220185, 52.58776210969495, 47.375595031246064, 42.49493099028065, 40.92255084745346, 42.65679936255179, 40.38284055648312, 41.37673777918662, 39.69243672586257, 39.083104364333614, 39.02780678964431, 40.39294065967683, 40.37634118910759, 40.781839739891794, 40.67820679756903, 39.18472905312815, 41.62205457687378, 38.84590687290315, 39.590596306708555, 38.91966312162338, 40.946908766223544, 37.53794154813213, 37.49934542563654, 36.82570972750264, 36.474539925975186, 37.178232746739546, 38.250808792729536, 36.644602129536295, 36.50405183915169, 36.27202795397851, 35.94481991183373, 38.024750832588445, 38.21015734826365, 37.48754301378804, 40.19369602203369, 48.75902675813245, 50.74760959994409, 50.83392527795608, 47.25582938040457, 49.811147643673806, 50.040061089300345, 50.95517750709288, 52.46077537536622, 51.5120207109759, 48.744172742289884, 48.24054825690485, 46.40030553264003, 46.240402267825225, 44.890314609773704, 44.9450042170863, 45.28682701049313, 46.977792170739946, 49.44344897424021, 54.81730007356214, 52.2760356626203, 48.60376365723149, 11.172227186541404, 0.221805160925273, 2.5283867793698467, 0.21692682027576432, 0.05682616524638669, 0.4989048628316772, 0.3346777058416798, 23.82851842911013, 60.990369396824995, 36.851389485020796, 28.074103670735514, 30.101835689237042, 49.005885047297326, 25.099309490573024, 0.19848339139453827, 0.06093271444701861, 0.019074436352257768, 0.06984383003005097, 0.02444543665455234, 0.016326724115999478, 0.07695127969547626, 0.050731985604450594, 0.058452692483702016, 0.024301350837753668, 0.08492496029864396, 0.052547031758172866, 0.041844921351801005, 0.007385868042136633, 0.0374047331992657, 0.026979762760381547, 0.01753352710136002, 0.04182362027706639, 0.038879234118447195, 0.02481792200987618, 0.0321925659063122, 0.026110291270719423, 0.03572364517998311, 0.017353073175575946, 0.0554690902842389, 0.014589707847804794, 0.012526798734231102, 0.019906875151660175, 0.023902006439804554, 0.0639601981627845, 0.06059881119478134, 0.812568255970555, 29.246029430820098, 56.247458996311316, 32.118630178513065, 36.333146326003536, 37.85234305166429, 51.549816669956336, 60.79201905958114, 61.1097938014615, 33.508882907129106, 0.3135721673888545, 0.26616848524539705, 0.9049742716935374, 0.13048873673523628, 15.070468898742432, 70.20681750389838, 55.90143534444994, 62.74076630992275, 50.362609355680405, 50.11211502936579, 48.30227459630659, 53.03787369881907, 51.935864187056026, 56.60512032047395, 55.41700301631805, 58.41806334833945, 55.14555146617275, 54.76837242803266, 52.96995001454508, 59.21170396189536, 57.31877988384616, 57.440718527763124, 53.696541632375414, 50.751386842420025, 42.793152716852006, 44.14289912869854, 41.86369611370949, 43.30451211621685, 40.372238389907345, 42.627048184794766, 40.580806501450084, 41.331924699967914, 41.41165864083075, 43.93601371395973, 41.467685776372115, 42.231637970093765, 42.49443677163894, 41.02115531121531, 42.895883514035134, 41.7830051145246, 41.60365866076562, 44.667410235251154, 42.90248878540532, 42.767123868388516, 39.0185696078885, 42.212508570763376, 41.8215424014676, 43.137254407328946, 39.42058509395969, 41.72265552705334, 42.105596526976555, 42.94288527581, 41.23011958214545, 43.297102758961344, 40.5657995131708, 41.108055422382975, 40.19641422456311, 43.23132853354178, 45.92975839491814, 51.06512546539307, 50.394572750214614, 57.64960435128982, 55.52012997288858, 54.62955582526423, 56.427778197873025, 58.15584897994996, 53.291180364547245, 48.78904073469101, 45.14220137749949, 42.46978467510593, 42.99553132826283, 41.72900584436233, 43.78223719135408, 42.46719198842203, 39.742866639168035, 40.910415034140314, 41.717438774724165, 42.28684533026911, 42.19579142908896, 43.468820202735166, 42.468254950738725, 42.47291864887361, 40.14473699754284, 40.92479444319203, 39.47087380193895, 42.17833688182216, 38.741407086772305, 39.6749625667449, 39.57333395558019, 39.33860755735828, 38.38384774423415, 39.96659471142677, 38.40706817565426, 38.45196362464659, 38.50012640799246, 37.95244978320214, 38.62857618639546, 38.99812229218022, 39.22028926111037, 42.68899417692616, 48.90263257488128, 51.54327023413874, 52.643753943904755, 51.00168505022603, 52.940053709091686, 52.30031513398694, 53.639667264876834, 55.3433487492223, 53.23504732501123, 50.20953101496543, 50.59149142234556, 48.53593410984163, 48.38445609615695, 45.432178281968646, 48.51531813221593, 47.444409093549176, 48.9698306206734, 52.81002713787941, 57.48974815491707, 54.56438172248102, 52.423148078303186, 11.898662890157393, 0.5410502706804584, 3.983089933472295, 0.12005174637682016, 0.10918878048898713, 0.8809625020911618, 0.7457744594543212, 26.30707394692206, 64.83650830484206, 43.18706850851736, 34.26315469126548, 20.054253032130582, 52.36989013610348, 32.64716955923265, 0.402130154111693, 0.0389012859593476, 0.02317832339735281, 0.008098762651394692, 0.035216560091583, 0.027912277540552522, 0.028626474499281858, 0.04148645732071131, 0.023024720853314768, 0.045430829538212675, 0.061324158563248576, 0.059398998761729854, 0.035566041741760514, 0.021269607673128767, 0.09418864869662831, 0.0878181679534816, 0.24695846282186049, 0.14836002051109268, 0.17818049858174018, 0.15622647178749885, 0.1090438443145925, 0.12244256889267315, 0.11081133939085469, 0.1351143603002833, 0.08417038667586543, 0.1559668445899602, 0.1777842779073023, 0.15336052154100713, 0.2069576108647931, 0.14937283471226692, 0.1651211356323573, 0.7254178485562726, 31.908606867636408, 66.87454438978627, 44.517312895867136, 42.55875579772457, 38.80648705267137, 57.33899185734411, 63.3439915410934, 66.7868088137719, 37.78085001053349, 0.3525046331267203, 1.4878476723547907, 2.5874039867231926, 0.3133240161884216, 16.611859375430694, 69.74259714926444, 59.36311137291693, 65.86642465283795, 51.726794012131236, 54.353954407476614, 50.24145910816808, 54.96942527832524, 55.349812815266276, 58.611808823001006, 56.881447376743445, 61.14738579719298, 55.72369706246161, 55.36445502311953, 53.55834084172403, 61.59170796794277, 59.09339351038779, 60.672065134971376, 57.06255889707997, 53.39980256172919, 46.1489482848875, 46.703681253617816, 45.81482118175876, 45.988813600232525, 43.51586511058193, 42.91932752055507, 44.132191058128114, 45.137431775369954, 42.657713274801935, 47.68372858724287, 43.99699480302873, 43.88624275884321, 44.856511623628684, 44.388843505613266, 46.01630941514046, 43.70395060508482, 44.686433730586884, 44.51489671584099, 43.45000067064839, 43.671371398433564, 39.794304601607784, 44.97712842879757, 44.25927192934098, 46.27220092281219, 41.32923003165953, 43.12226703090053, 43.249802897053385, 45.66780682533018, 44.64047531927786, 46.75626454814788, 42.729080800087225, 44.53707771916544, 41.06162632665327, 45.495387277295514, 47.38000769768992, 53.60294603532361, 51.321134644169966, 59.3788008536062, 57.414046410591375, 55.38471798742972, 58.90844198965258, 59.12263085765224, 55.92449888106316, 52.112206105263006, 46.91562652587891, 45.44785599554739, 45.995767962548044, 43.45553121259136, 46.46023150413267, 45.7359266281128, 43.16007083462131, 43.0946143211857, 42.69578772206461, 43.571299968227265, 45.232917954844815, 45.016214847564704, 44.79278095306889, 45.84097554606777, 42.03201286254391, 42.87428302149619, 41.53615859247024, 44.511535244603316, 41.318843595443234, 41.39278027319139, 40.77371258889475, 39.314029985858554, 39.81724262237549, 42.17778382762786, 39.4956474919473, 40.88652779979091, 41.0338088773912, 40.49224722769953, 42.45757825912968, 42.12747943016791, 41.54037514040547, 45.63829883452385, 52.288296991778964, 54.601675618079405, 56.17216517848354, 52.606507116748446, 53.55809765477335, 53.60680956994334, 54.018019091698434, 57.768024629162205, 55.412323628702474, 53.74004856232674, 52.77302742004395, 51.04467030494444, 50.78660188182708, 50.34761021214147, 51.168597590538766, 49.01700496673585, 51.307178851096864, 56.0972479081923, 60.2259425963125, 56.37541847844278, 53.8747388316739, 14.049416126743441, 1.243885563265893, 7.375508671806705, 1.9085054484105881, 0.4009457821807554, 3.3508587748773637, 1.086883136341649, 29.241930553990027, 70.89382063957953, 47.584696585132235, 37.997043209691206, 38.34600863918182, 60.291297128123624, 41.94486564205539, 0.8677028071495795, 0.28301276687172155, 0.062388044015894976, 0.19743443316509648, 0.13130979912896312, 0.16082515970112818, 0.28544626048495697, 0.10319051888561058, 0.1898949635365317, 0.17298003328183006, 0.16577776491401658, 0.22748717377262734, 0.13517083630206125, 0.07812142537365999], [0.06548192457205827, 0.0738932329019712, 0.03571528716072921, 0.01182707604922114, 0.051295267072536295, 0.022555380916943955, 0.011801326876476169, 0.04675120122790818, 0.0724011923997633, 0.02497759580071415, 0.06819019094109535, 0.013331746468470703, 0.05765150624117064, 0.04320372767265766, 0.026350275973879525, 0.08324656124797561, 0.03407030103487834, 0.05276811324180134, 5.535745457295449, 52.64611128837832, 43.91994376336375, 33.03621768951416, 31.995002954236924, 36.08381302125993, 54.58296591235746, 54.003149386375185, 39.878627715572236, 0.0982222241920329, 0.5403368896053684, 0.18221899236161865, 0.0685706761695685, 1.9815217174829978, 55.446746349334724, 60.08565510472944, 57.06654402517504, 53.16986537748768, 49.30678575269638, 46.69385571633616, 51.48978087209886, 49.56113576889039, 58.12906703641338, 55.43028023935134, 53.05395933889574, 53.179949791200706, 51.22245173300467, 54.78755281817529, 54.03781137158794, 52.80550464507073, 50.77523485306771, 45.43133105001142, 40.01304734137751, 38.18421479194395, 41.065144692697835, 39.9663632915866, 39.77068801080027, 39.81122962890133, 40.153197550004535, 39.06513598657424, 39.47134056398946, 39.976486929001354, 40.24619694679014, 40.87398405997984, 39.025535737314534, 40.29296336635467, 40.626925729936175, 40.69183703391783, 42.1354575310984, 41.474746042682284, 40.7475229232542, 41.159528686154275, 41.10913799655053, 38.95644318672919, 39.69047946314658, 40.56398737815119, 38.934113133338194, 38.258249528946415, 40.31316749511227, 39.23417445152037, 40.46301380280526, 41.1905546342173, 39.87088887922226, 38.55001895658432, 39.26139570051624, 39.294096500642844, 38.165559999404415, 42.53238962542626, 45.75068650707122, 49.74175699295537, 54.975814819335945, 56.83082918966971, 56.988026019065614, 54.06556214055708, 55.00406372931696, 51.20207501995949, 46.45956862357355, 43.98764387253792, 44.82539153868153, 43.27478839505104, 42.324417714149725, 42.4476585849639, 42.14389454933905, 39.940436424747595, 39.92119327668221, 40.29550113985616, 39.45303878476543, 40.10276763669906, 38.942793338529526, 38.149709701538086, 39.121986819851784, 39.69695529630108, 40.06989032991471, 40.13806896824991, 38.59325132062359, 38.29551596795359, 36.999988478998986, 35.79638173503261, 37.46540123416532, 39.222572080550655, 37.69185143132364, 38.837783644276286, 35.95183703207201, 35.27814249838553, 36.3036540246779, 36.704504566807906, 35.48941704534715, 39.862636212379705, 45.379696969063055, 48.60294780423565, 50.14052867889405, 50.9109410162895, 50.56441922341624, 50.83143849526682, 49.485496782487445, 50.250578618818714, 48.83417937063402, 50.78164792829945, 49.353556094631074, 51.27969088092927, 49.49007026610836, 47.57945237621185, 44.64318567706693, 45.96013322953255, 44.47716351478331, 50.23634041509321, 49.70659686673073, 53.17436433607533, 52.003525072528475, 41.21114315525178, 4.888480834422573, 0.18091213829334707, 0.6251200240465903, 0.0963974180781553, 0.04520488339626501, 0.5505846945508834, 0.5206377047204203, 32.49504827683972, 56.57343933659216, 32.76856887725092, 25.174101245018747, 32.384555109085575, 46.09928715613581, 7.426804448327712, 0.14354189437243248, 0.014858276249029705, 0.040586939862658905, 0.13888057111011398, 0.10460541433384342, 0.04848991821129476, 0.01906421865456768, 0.0295045395802346, 0.023692182618223374, 0.05930207714798951, 0.025068538098205483, 0.023334637892642812, 0.05466362544065041, 0.09703984408969842, 0.03672235187203173, 0.056715025040771694, 0.04361149712255405, 0.03193485967424368, 0.06130566903119607, 0.01793601820545812, 0.04185496476448832, 0.029547714380427238, 0.09844856486926157, 0.03680679391348555, 0.02216770020764201, 0.011460064392116283, 0.026270595168875113, 0.039429158843573064, 0.02478872831430166, 0.01878690057163758, 0.023974834588326277, 0.20810904101498667, 9.520180763736848, 62.23895003718715, 43.327214794774214, 32.56575292156589, 39.07791899096581, 43.33105479517291, 59.17085247655069, 61.86041778133762, 45.105731179637296, 0.11390060426727419, 0.2056761449503322, 0.1302424241458216, 0.057859001155462, 2.2290057472644316, 58.55641711142756, 60.82210363880281, 60.31467445435063, 54.77741741365003, 51.67576789855958, 48.08532045733545, 53.76148431531845, 51.00790200694915, 60.00257145973944, 58.74820532337312, 55.59544340256722, 52.83127069473267, 54.67223121273903, 55.620570105891076, 56.50980672528667, 56.12992517409786, 53.772451262320246, 46.58548847321541, 42.84700685931791, 39.42574693310646, 42.5982109192879, 40.99713863865022, 42.146067542414514, 41.41032895734234, 42.65513235522855, 41.02499923398418, 43.6503553390503, 41.11237395194269, 42.19651314520067, 41.69787006993448, 41.13370380093975, 42.0979675169914, 43.0208110040234, 43.72299371227142, 42.67753693365282, 43.48709060299782, 42.89533830458119, 42.692441940307624, 41.467042507663855, 42.59551625097952, 41.78109099788051, 42.862825778222856, 41.93780537574522, 40.979570342648415, 41.46783482643866, 42.200259008715236, 42.19344585172592, 43.211210696927964, 42.894455771292414, 40.376941311743956, 41.34332703005883, 40.86915169992755, 42.04962430461761, 43.93172656336139, 47.429378571048865, 51.68876271094046, 56.55979733313284, 56.82170183427873, 57.51464343840077, 56.172318150920255, 56.73403293855729, 53.2075789666945, 48.12004520047096, 47.29051097746819, 46.101499372913, 43.390310041366085, 44.20175037076397, 45.08537800081315, 42.83411010619133, 41.14644365925943, 40.98312008765436, 41.715104964471635, 41.881837075756444, 42.7613736737159, 41.90839152182303, 37.91686604099889, 41.30893176601779, 40.690789761081824, 41.94807806322652, 42.49252265499484, 39.83475208282471, 40.283863467554895, 38.8716729225651, 39.51576925093128, 39.59099246609596, 40.194845276494185, 39.44085590301022, 40.18595326331354, 37.561169824292584, 37.26466217348653, 37.99851017613565, 40.091027982773326, 38.19796269939792, 40.570216101984826, 47.42824108369889, 51.15767771197904, 52.47575490705429, 52.12703266451436, 51.82835594300301, 52.02863216400147, 50.82970873002083, 50.730974828043294, 50.631366237517334, 52.44383073622181, 50.50988258854036, 51.38513203590147, 50.926865839189105, 49.810916223833644, 48.269777759428955, 48.93308193452897, 48.537840381745376, 51.65814468937536, 50.52486996496878, 55.97300291061402, 53.097356442482244, 41.63356673332953, 4.927584413559207, 0.57426753664209, 2.627700701836617, 0.271862571638438, 0.07762870826427976, 1.012299819098365, 0.9691765459795153, 36.1206126982166, 61.775004248465265, 41.29195574791201, 34.54816979746665, 28.428707507348832, 55.903718163890225, 10.511864789070623, 0.1538498678635205, 0.02419330562735277, 0.015572841887572601, 0.060610528509583206, 0.07246233387700013, 0.012966930610878814, 0.0269238613245468, 0.06973827843584361, 0.05606019606573447, 0.03569360304203245, 0.030144447077726646, 0.030342157134005142, 0.017513668187142863, 0.0666865059024384, 0.1879914801928305, 0.14990503599326457, 0.12093755086102795, 0.17788339436294573, 0.14428550527701456, 0.09681288288125107, 0.19818614927991746, 0.1758606770947095, 0.15201980638648235, 0.1546369159534093, 0.16460163608914422, 0.057419611426490935, 0.14213668993644177, 0.11200111224165848, 0.11848010933927952, 0.21621734624908817, 0.17398907833041685, 0.35242955651014085, 12.285704728095764, 69.81923241769114, 53.5302488265499, 46.645175180127545, 41.20953106111096, 47.31795187919371, 62.992704068460775, 66.36403222237864, 47.96509196681362, 0.45500226378921543, 1.3506555437080323, 0.520558154150363, 0.2525131824997164, 2.9639301953777193, 60.732198992083156, 62.119121628422896, 63.39719064774052, 58.84466817302089, 54.600263564817375, 49.58231264545072, 55.135980882952296, 53.36465812498524, 63.92804422686177, 59.24567560995779, 57.036122122118556, 54.678809027518, 55.5087080309468, 58.34423257458595, 56.90224378339706, 58.76816626518004, 55.77253841584729, 48.99296868231989, 43.55592819952196, 41.500527781824914, 45.32128111008675, 44.72985044602425, 45.67895420135991, 46.0030988724001, 44.2697681919221, 41.63615942001343, 45.87048745924427, 44.02259611314343, 44.84592906890377, 44.05291603457543, 43.075802633839274, 45.276538633531146, 45.973512434190326, 44.19279952203074, 45.49496758368708, 45.37671204536192, 44.74883864002843, 44.882309052252005, 45.82356022250268, 44.41567251759191, 44.29708750017228, 45.547566567697835, 44.492425457123794, 42.07038933230985, 45.04758988657306, 44.24047200910507, 45.75886857125067, 45.64891276821014, 43.64113384677518, 42.53437826710363, 43.57054295078401, 42.38687361440351, 43.039967859944994, 47.151027571770456, 49.13133029014834, 53.55599134199081, 57.7140018247789, 60.11687717130108, 60.52750618227067, 57.62952573837773, 59.18539662514964, 54.41440989894252, 51.59146047407582, 49.06033539002942, 47.678268647963, 46.9878020594197, 48.02292339263424, 45.96698561022359, 47.20670953873665, 45.269698019950624, 44.83323627902616, 43.30163701888054, 44.55872135777628, 43.82344561238443, 41.99418160223192, 38.536384797865345, 43.32140968691918, 42.00920035762172, 44.33132194703625, 46.31917915036602, 42.13054280127249, 42.88823489219912, 42.142388359192886, 40.405323582310835, 42.37902102931854, 42.68882943737892, 42.54731032156175, 43.52234486610659, 39.89566649160078, 39.51465137543217, 40.77666221126434, 41.598955738929014, 39.59065514226114, 42.91245552801317, 48.55719335617558, 52.95215422107328, 55.52999865624213, 53.765320393346975, 54.59057923286192, 53.27292957613545, 50.774936752934615, 52.55070355630691, 50.74361662710867, 53.02706756899434, 53.9474085838564, 54.481298077491026, 53.06163541732296, 52.28245266022221, 50.51705660358552, 51.26311494458107, 49.52399484572872, 53.75298061678487, 52.561050768821474, 57.421604817913426, 55.80251316870413, 44.552147465367476, 7.016568164671622, 1.1500041234877802, 4.332488784866949, 0.5333637734574657, 0.320397551141439, 2.798659412130233, 2.1096887175113928, 41.80432319641113, 68.0415750318958, 45.36415653844034, 35.06300833917434, 42.23836483493928, 61.390360939887266, 14.580028480099095, 0.39441503584384924, 0.22035347027403696, 0.128920171710272, 0.19279135811713435, 0.2562850623601868, 0.09103109474263846, 0.11966789036148018, 0.145426930318917, 0.16971299004170204, 0.24160939178639845, 0.16711515524694998, 0.11525497110860965, 0.15044914228060555, 0.25242264622882493], [0.029645538062698422, 0.035750075213370786, 0.030712499358360807, 0.13178357854485512, 0.04009552893318957, 0.09733965259886558, 0.12175224706410401, 0.09772426704125059, 0.005484546502796753, 0.013162445825254245, 0.010553269098783213, 0.019243013999995687, 0.051723843470456145, 0.03585218324235851, 0.14221218024050036, 0.059820071328431375, 0.01947014183256655, 0.08159943390637636, 0.32128183111067743, 27.15094247171956, 51.93125932447372, 33.5083023963436, 29.734937183318603, 31.57047698574682, 50.85489034652711, 53.011852695095925, 47.499161458784535, 0.621745130948482, 0.4184545378290838, 0.1392299991341368, 0.24681849855809446, 0.015373076800437225, 28.77028907499006, 63.8630074070346, 57.97177999250351, 58.387696358465384, 50.95638559710596, 48.30177253292453, 48.43381520240538, 53.956167236451186, 53.41087933509581, 58.687883192493075, 50.885367162766, 53.371137880509906, 53.12914725272886, 55.24982375483359, 53.04764432291831, 50.88030338287354, 45.95247284058602, 40.97256106715049, 40.56222623394382, 39.98548092380647, 40.52455186843872, 41.39141528837143, 38.183457774500695, 40.21503371577109, 39.48178583575834, 39.45138354455271, 39.545222328555205, 40.553534261641964, 40.34309910189721, 40.61789251142933, 40.406445380180116, 39.89400732901789, 39.21758674806164, 40.62709831422375, 41.332156119808076, 41.31359154178251, 41.64742054477815, 41.1729000460717, 40.958871995249105, 40.31688590203562, 41.83818501810874, 42.955142682598485, 40.76767606119956, 39.055200622927764, 40.516326658187374, 40.99384777007565, 38.80099573443013, 41.225385281347464, 40.2615334141639, 39.06889753956949, 37.91827417189075, 38.14501070207165, 38.95154022401379, 39.25459823300762, 43.08664798736573, 50.22658548047466, 54.006499090502345, 55.65580867951917, 54.39788495340655, 55.984872002755445, 53.84567014632687, 51.509082855716834, 46.13893055146741, 46.34414895888298, 45.15168174620598, 46.621821388121575, 45.69811890202184, 46.06482128943167, 42.42037850041544, 40.27931351815501, 38.47477612956878, 39.55634224799372, 39.03852270495507, 41.5923269333378, 41.4984332361529, 39.09269455940493, 40.15665315812634, 39.56177865305255, 38.92106733014507, 38.878097764907345, 37.551465880486276, 37.86473381903864, 38.080856415533255, 37.752620712403335, 36.791130112063506, 38.16159056079003, 38.071732982512444, 38.154969599939164, 37.686897477796, 37.957364513028054, 35.717169469402684, 37.114592290693714, 38.70891024989467, 42.94231653213502, 46.97086526501564, 50.053734471721036, 51.097892945812596, 48.200179223091375, 49.266353960960146, 49.626502067812034, 47.88651904752178, 48.790656751202, 48.09884086731942, 49.131020422904726, 47.56521417248634, 52.77648302816576, 51.213120414364724, 49.02014678524387, 47.09662037511026, 47.43281064494964, 45.70124895341935, 47.89581114246, 51.013208973792295, 52.329066107350016, 51.925473828469556, 24.293248691866477, 0.6480232337790152, 0.4088084796263326, 1.4614716941310515, 0.2627285359607589, 0.052249950522016135, 0.20463086394292695, 0.8235416381109146, 43.010958010150546, 53.15266970665225, 34.03306061221708, 21.628796362107803, 37.34543162007486, 38.807385275440836, 0.5113246802601122, 0.033426055564515056, 0.031204504005971457, 0.04360406223924891, 0.06397960700034615, 0.06463578812056972, 0.040356542749871174, 0.036031413342683546, 0.07991623148442277, 0.05368542309189516, 0.10001752825994646, 0.07146022192412807, 0.05665424362485928, 0.03763329553147478, 0.025462512219805392, 0.03583181296445189, 0.08643393134397846, 0.022898186110861363, 0.11362580086795554, 0.08814805307455602, 0.030089558793171763, 0.03777815509707697, 0.04422724412213411, 0.04555109768144546, 0.015564367997520154, 0.014778761110538918, 0.033125603541491494, 0.03804949194853825, 0.03801969112828374, 0.02235446478270235, 0.0824252383843545, 0.08455939846293581, 0.17182458883091328, 0.9143947629678635, 35.92941676416705, 57.32352595175467, 34.62012960064796, 36.9141121064463, 40.81818442190848, 56.52607279439127, 59.09547236657912, 51.150699815442486, 0.8189228020848767, 0.26227583928454307, 0.11452860484320311, 0.17885745983690987, 0.0032122476043314825, 31.771572982111287, 66.0248334946171, 59.17733223207536, 59.8776557368617, 52.03624548450593, 52.006149138173754, 51.86263353593888, 56.07192900873, 54.93478682733352, 58.752543464783706, 52.64558176840506, 56.81333934107135, 53.111367148737756, 56.0025893488238, 55.52695097461824, 53.34096308677427, 50.77103791698333, 42.8294111067249, 42.52402713221889, 41.85249774686752, 41.7999928997409, 42.881421735209805, 41.67972126314717, 41.84962264953121, 41.78412299002371, 41.40708515720983, 40.71541832339379, 41.19857588121968, 41.843876377228774, 42.93222427368165, 41.960025602771395, 41.330763678396906, 41.03776654889507, 42.4528714149229, 42.396832512271025, 43.21365825591549, 42.130483965719904, 43.32198235296434, 41.666989249567834, 41.96652497014692, 43.701106886709894, 43.208178704784764, 42.98304642400434, 42.06031276333717, 40.23272360524824, 42.6569954810604, 40.51661691358013, 43.3623396196673, 41.64954646941155, 41.49334984440958, 40.85495664227394, 41.0090430321232, 39.91894968094365, 42.51356617096932, 47.190910231682565, 51.98511738930979, 57.217147350311286, 57.87884727601082, 55.04305601119996, 57.048873747548754, 57.005209922790534, 52.839217416701786, 46.72252039755545, 48.845146317635816, 47.25254635657034, 46.697550589038485, 47.22839632341939, 47.79535924234698, 46.3174101614183, 42.202279029353974, 40.69541031314481, 42.640101832728234, 40.3519989598182, 41.8837708042514, 41.994895473603286, 39.813963520911436, 39.532439324163626, 40.54121801930089, 40.99492642187303, 41.492235891280636, 39.1314201201162, 40.37099107619255, 38.74647478903494, 39.72461977312642, 39.10990984209123, 40.08264587771508, 39.28935827747468, 39.76355321945683, 39.60292039378997, 40.86092256730603, 39.346585658288774, 38.60353969758557, 40.43216828377017, 46.17766003454886, 49.64074027153754, 51.65836826447518, 53.29034882207071, 50.612966399038996, 50.998594222530244, 50.7045929662643, 48.64563495882096, 48.77295117224417, 48.01133278877505, 50.091259787159586, 48.685356801556004, 52.94431340309882, 53.523804372356786, 51.506941241602746, 49.58181058206866, 49.96970553551951, 47.83360235152706, 50.57097350397418, 53.12590345259636, 56.00307964509534, 54.07341864801223, 27.46919966513111, 1.1115052022280232, 1.2640650546358478, 4.385761435954802, 0.7951753634598948, 0.029928010002139117, 0.45516853551230124, 0.7777013882033287, 47.29255453232796, 57.49304686823199, 44.25449840484127, 20.83749151998951, 36.62240543673116, 48.894426976480794, 1.094263688691201, 0.11877177433381159, 0.003624725622132481, 0.040991541538988395, 0.07351625635619126, 0.04589666079189028, 0.052510814951552506, 0.007388297498466508, 0.0134712549099218, 0.032394453056997834, 0.03573418654982121, 0.04588943275232469, 0.043589652125393195, 0.04565985152317632, 0.018992612416285182, 0.07217443037417627, 0.14938198180208284, 0.15527545023829709, 0.15823029732752233, 0.22761399196761273, 0.24055499433269426, 0.19182360520766628, 0.13639623990222333, 0.11310259345918895, 0.0639173891695757, 0.12023170809111289, 0.1684122493550662, 0.11989934084516381, 0.1589516610387833, 0.13863902358758834, 0.2193116979493249, 0.2504567726845703, 0.2970948112347434, 0.8703550035434385, 41.65730099524222, 66.69597456532141, 47.173188963244044, 40.28708373346637, 42.62370632540795, 61.237612078266764, 66.07147047596594, 59.09023992476925, 1.5821318905199728, 0.8575613964949885, 0.31146306604627644, 0.3692154315931182, 0.23493259844760742, 33.011408698174264, 64.87650863585934, 62.180985250780665, 61.922940361884336, 54.8734409578385, 54.56868064018988, 52.6568821168715, 57.88511522354619, 56.90773902400848, 60.578249885189926, 54.32172821414087, 60.78736712855678, 55.328086806881814, 57.19400536629462, 58.923711776733406, 57.070890011325965, 51.17153544579783, 45.70942709522863, 44.23537292788106, 45.49930964746783, 44.28188439338438, 45.382995682377974, 43.75149757631364, 44.67483528198735, 45.4036626508159, 45.7814771129239, 43.23145404938729, 45.176098500528646, 42.77012840394051, 44.78568538542717, 44.5438124287513, 42.8079596642525, 42.53149924739715, 44.922266237197384, 45.273726294117594, 45.022651457017474, 44.631697054832216, 43.84220630891862, 44.1087156726468, 43.621753415753766, 45.51541489939536, 45.82462318481938, 44.39655880774222, 42.43619349695022, 43.31125074817289, 46.27487205689954, 42.52584318960867, 45.995462017674605, 44.57894902075491, 44.74754818024174, 42.7448683400308, 44.12811963788925, 42.870580304053526, 45.18599071810323, 49.80541706085206, 54.848914377151004, 57.4693988984631, 60.4738599254239, 57.29123700049616, 60.312756415336366, 58.5296900810734, 54.586750999573745, 47.94572330290272, 51.16318471970097, 49.73401815660539, 50.49135331184634, 49.593056017352694, 50.29392080922281, 47.370170393297755, 44.88875742881529, 42.80694377037787, 43.20401707003194, 43.125240187491144, 45.01792107858966, 44.45215056019445, 43.672132338246996, 43.824030045540106, 42.06290545002107, 43.22287190345026, 43.35305536946943, 41.48011968981835, 41.94398310876662, 39.85166534300774, 42.331321085653, 41.18615765725413, 42.44464620467156, 42.61853271915067, 42.26928487900765, 42.68487568824522, 43.51161718368531, 39.50922673748386, 40.59677054805141, 42.6684723361846, 47.69060842452511, 52.323453195633434, 55.00745657951602, 55.4006741892907, 53.30789358385148, 52.68986532765051, 53.992970835778024, 50.26493057127922, 49.94272747347432, 50.922817953171275, 51.32635139649915, 48.959338280462454, 55.2801005301937, 54.213376660500806, 51.79503540838919, 52.0278202333758, 54.10074972337293, 50.5552722561744, 54.14405661244547, 56.022828778912945, 57.093941780828665, 55.16485344979071, 28.542662166780044, 1.05247451172721, 2.4253696491641383, 9.789039627198251, 0.873524094781568, 0.10066006152379899, 0.8776545957211526, 2.6717109209106815, 51.9545268243359, 63.039717597346154, 43.02328209723196, 31.32017093320047, 46.88002709419497, 56.81632426477248, 1.9477108865976336, 0.20670363739613565, 0.29478710925867485, 0.22706011039835794, 0.17829135150438358, 0.2687352168704233, 0.2376361380541517, 0.09671897582349279, 0.14672402442703325, 0.1306874752645531, 0.12274837587028743, 0.24731758951900468, 0.13422730709275893, 0.17662411435477196, 0.07169908047803948], [0.01830980782547305, 0.07415090657530293, 0.016884087554870114, 0.04476401128716046, 0.021938584376907638, 0.08578997315658678, 0.042611066732675805, 0.0295113405257824, 0.02019635871082785, 0.06820295396591387, 0.08535318046567902, 0.05188656437601294, 0.024158163259046215, 0.0731812997330581, 0.05411154417801769, 0.02333043206993851, 0.04502521662582313, 0.02415101757393249, 0.04218604881316424, 4.68866107925292, 46.64669313738423, 39.32070193752166, 32.033644183989495, 34.30880715770107, 42.228484384475216, 52.39856658443328, 48.12636021644839, 1.1670980578468693, 0.4486624878500739, 0.06549029025219141, 0.3546957671642304, 0.17811219418241134, 5.146172710003392, 55.46041188701507, 59.14751437402541, 56.54799884365451, 54.0977491101911, 50.18387086929814, 48.42661765313918, 51.498382629886756, 54.36129708443919, 56.22556432600945, 58.52262197002288, 49.90249180024671, 53.656251045965384, 56.004836866932536, 53.79546380812123, 52.44532123688729, 48.51521222822128, 43.15177502170686, 41.30592330809563, 42.53934006537161, 40.28049807394705, 40.38790041400541, 42.63351225083874, 41.46493227251115, 39.088823180044855, 38.53893041610718, 40.02099798571679, 40.25689325025005, 41.10410559561945, 40.07561306799612, 39.82101986485143, 40.570165111172585, 40.651315027667636, 42.5045721761642, 40.25896426170103, 41.741471136769945, 40.0080463194078, 42.04523909476496, 40.970301781931234, 39.712185859680176, 39.96839115696569, 41.424649530841464, 39.46955588556106, 39.09440079042989, 40.63796720197124, 40.71495156134329, 38.651376924207135, 41.80742579121744, 41.89827180677845, 39.25992481170162, 39.162226415449574, 40.30063552241172, 38.57133703847086, 40.24751878553822, 42.19295555545438, 50.856486751187234, 54.4096520639235, 58.46908946191111, 57.24695344125071, 55.04563693077334, 54.44525541797761, 50.59082854178644, 46.28528987207721, 48.65877097652805, 47.62822312693442, 47.7454274700534, 48.72680840953704, 48.09272981459095, 45.90449440863825, 42.794117619914395, 39.64409351348877, 40.94148020590506, 40.84056938848188, 38.09800109555645, 39.588176204312234, 39.35826255429176, 39.24601608707059, 39.88958681783369, 37.98214997014692, 38.86505196171422, 38.94929662827523, 38.189910073434156, 37.097686875251036, 38.08375896946077, 36.8351234159162, 38.70777668491487, 38.175271787951075, 36.26554819845384, 36.02575017559913, 36.09255206200385, 38.9246327646317, 37.2185900134425, 39.59928827901041, 44.41397020893712, 46.07039105507636, 50.39986402757707, 45.692380474459746, 48.93641987154561, 49.111392882562455, 50.811179453326815, 49.49996248368294, 49.893890042458814, 50.32116951480989, 51.357522472258545, 49.3332068381771, 50.54323450211556, 51.1424667604508, 50.79368175998811, 48.42125577311362, 45.770757275242964, 47.02792006154215, 49.974506516610425, 50.19750895038728, 53.24645357747232, 42.94498374385219, 9.941875761555089, 0.046980188738915234, 1.2981977650234777, 1.4665602339852242, 0.3839687834824286, 0.009317276248287772, 0.3803377412259579, 3.3946851328496015, 57.42395431764665, 42.92305769458894, 28.883904449401367, 32.20505568288988, 48.335049921466464, 18.02630332208449, 0.20833382653372906, 0.06291314366183455, 0.02191607671369228, 0.05692726203931436, 0.019066292837622668, 0.041423270388716654, 0.009233154048542342, 0.021799261711778182, 0.03447957584754594, 0.016108021335375887, 0.03855711329848536, 0.02555947022272214, 0.05420276992804101, 0.05948234912789157, 0.0797814000097494, 0.027759894991533893, 0.08282410206213113, 0.0467223733393175, 0.0728065831466548, 0.03316395007254135, 0.05927441371304374, 0.0590712548564038, 0.07386912411499409, 0.07778181093594722, 0.03758803505690829, 0.05142229594170086, 0.0407481937098407, 0.08017443375842226, 0.01927596344161899, 0.03795280399161481, 0.04778114132462971, 0.03466314583596203, 0.007734221149040687, 0.07784983188274407, 8.956370449835255, 59.585800017080004, 38.10810119875016, 32.117524070124475, 43.85815858840943, 50.63663790302892, 56.74385455346877, 54.99608955075664, 1.062550100107347, 0.4246092575692362, 0.3857404077726026, 0.511028878390789, 0.0964723721206669, 6.342406868934632, 59.68189808630175, 59.30811582073089, 59.77648212063698, 55.41179018635904, 53.957120372403054, 49.917667450443396, 53.52851906130391, 55.86771865044871, 58.119198353059836, 58.03165889555409, 53.204786239131806, 54.11792970472767, 55.88571840716947, 55.235059953505, 54.845027308310236, 50.36377822199176, 45.43595552444459, 42.43057666286346, 42.58466305271272, 42.17044899540563, 42.78681808902372, 43.11543818443052, 42.98024585170131, 40.57705279319517, 40.87008130165839, 41.034424689508256, 43.17651733275383, 43.081293952080514, 42.00845902965915, 42.01088697679582, 41.81124617976528, 42.74878678783294, 44.82610933242306, 42.385638067799235, 43.43113014774938, 41.82566873488888, 42.99875551654447, 41.62700460803124, 42.52691007429554, 41.32930847906297, 42.38075079456453, 40.997166095241425, 41.91152549559071, 42.48388167350523, 42.928062638928814, 43.51412750059559, 43.46407021245649, 42.997072819740545, 39.77033499748477, 40.696312458284446, 41.04205369949341, 41.23507745804326, 41.33052833618657, 45.14360558602118, 50.664667160280295, 56.23035746236002, 58.96554385462115, 59.37074430527226, 56.589422995044345, 56.374983095353656, 54.260213682728434, 48.4526700358237, 49.99433802020166, 50.48096295325987, 48.2123464153659, 49.624627174869666, 49.5526320703568, 47.66710558245259, 43.290485720480646, 41.364515673729684, 43.223754436739036, 41.41702444322648, 40.79389710580149, 41.29351685124059, 41.69481062120007, 41.52340696704003, 41.3303675190095, 40.60650194844892, 40.23843065384896, 39.47217602883616, 39.49516896278628, 39.09604818590226, 39.347672154826505, 38.92082806556456, 40.78915103789299, 38.68512891953991, 38.327922590317264, 37.994587805963334, 38.0649668939652, 41.81684340200117, 40.78168676745507, 41.58476852601574, 45.964745936855195, 46.299253509890654, 51.56277618100567, 48.930042097645426, 51.52843190777687, 50.232304296185895, 53.17269732875209, 50.992083088044204, 50.77898856132261, 52.320174094169374, 52.43437782410653, 51.752881696147305, 52.52345485071982, 53.13921989933137, 52.212583480342744, 51.42314764761156, 47.72407016446514, 48.85986305052235, 51.03805326646375, 53.140376998532204, 55.69567172758041, 45.8315775471349, 11.527949879246375, 0.24698120031145313, 2.468406630139197, 2.886423670476483, 1.2424172485067, 0.07714008206441518, 0.7375482073233974, 4.170461066307561, 61.284837415141446, 50.38734774435721, 39.189282924898215, 26.2311113649799, 52.80569684120917, 24.937792170432306, 0.07010570186520777, 0.052307054715892004, 0.09523989752896371, 0.08115762333956458, 0.04096905302797114, 0.02491283264281529, 0.0352440320045477, 0.01414726525845547, 0.01618537706353011, 0.015160591780929076, 0.04348075272695672, 0.02033585374574027, 0.06709781084810534, 0.048293623502456376, 0.07193990787791629, 0.15761227887724677, 0.20972648244952002, 0.2607950219704259, 0.1836425675860336, 0.09905238004942095, 0.1658075657342711, 0.2117892814379546, 0.15266414761783617, 0.23558696010901084, 0.14321112825024512, 0.11187280017522075, 0.13137217400775802, 0.12605422146378026, 0.1329958973632705, 0.18878517792590205, 0.09667718572722328, 0.09995257166484672, 0.1354683542083348, 0.2837003154620048, 10.714965116593147, 67.96296288890224, 48.045214222323516, 43.60461658047092, 45.892539024353034, 54.99361845754809, 60.38990551425565, 61.87174558639527, 1.6405275247750746, 1.040936369569071, 0.8881291626922546, 0.9563298643596712, 0.24360826839843105, 6.712026028863846, 59.413380469045336, 62.36881579122236, 62.0174341817056, 58.62221487106816, 56.22525053639566, 53.30073133591683, 56.47007311544111, 57.84174949892106, 58.55790368972286, 59.22563622074743, 55.27506812926262, 56.580974209693174, 56.769683361053474, 58.272413976730846, 57.553674943985484, 52.84527747861801, 48.173809128422896, 45.566711656508915, 44.33513449084374, 45.49360652123728, 46.19111768661007, 47.35973296626922, 46.297955205363614, 42.41533433237384, 43.867003533148, 43.85052173368393, 46.0474883356402, 45.041082674457186, 45.301002456295876, 45.06950024635562, 44.53802301037697, 45.21613805524765, 46.719339355345696, 43.29105446415563, 44.40468988110943, 43.0939906643283, 44.54348294965683, 45.103664090556485, 45.077133178710945, 42.85179999566848, 44.1806911653088, 42.7390161637337, 43.39013353470833, 45.01508520495507, 47.579370006438225, 43.99429228998, 46.4178934404927, 47.1134747997407, 43.20212256523871, 42.74014580634333, 43.14786834101523, 42.357863764609064, 44.672901553492395, 45.352581624061834, 53.26744610263456, 59.04381082903955, 62.47933249319754, 62.88970262773576, 56.23713531801778, 59.21939965217345, 56.10379826638007, 51.7793498500701, 52.92856508685697, 51.41900954707977, 52.12644823135869, 53.14720976737238, 52.10243940353394, 49.27616773113128, 46.930335414025095, 43.15068852516913, 46.21584430817635, 43.33271788012597, 41.6997802642084, 43.198298254320704, 43.53930911710186, 43.12271810347035, 44.56582869252851, 42.34569657233454, 43.9257449488486, 41.51500525013093, 41.62797343346381, 41.49830772030739, 41.63883839884112, 41.201188179754446, 42.94655269192111, 41.964112712490945, 39.2925157854634, 40.60922407334851, 39.5498977938006, 45.023239812543316, 42.42208473144039, 43.36371244922761, 48.75526520513719, 48.58732892620949, 54.95031941321589, 51.56457262654459, 53.28128422460249, 53.583969608429946, 55.94355767773044, 52.30310786154963, 53.833569634345274, 54.52559732621717, 54.69975448423817, 53.832691023426676, 52.63786254390594, 55.02925711293375, 54.6423545191365, 53.875942999316806, 50.99441689829673, 51.59459444784349, 53.821159255120065, 55.20299065497614, 57.213691742189475, 46.464040125569994, 11.922160829267195, 0.29692130764165237, 4.033807650689156, 4.440642749109577, 1.6842699195108108, 0.12969142306716214, 1.3812320126641182, 5.9686049915129145, 67.09631519932901, 51.444548099271714, 42.09926189914827, 43.29440416828279, 59.77789025152884, 28.847524466053134, 0.2014970433928313, 0.17774292448114964, 0.12689137936479625, 0.10922621920584671, 0.10479131322954932, 0.10636948499708407, 0.12933385918938345, 0.07498746692773796, 0.08087800124720221, 0.1050881339958118, 0.13097180113677057, 0.12078906003866466, 0.3352477365443784, 0.14707527574031584, 0.29683280916463944], [0.013706124060967518, 0.04878625251172532, 0.01892295204133036, 0.04551442505251016, 0.020341390646213008, 0.09176329093714876, 0.022918707691133026, 0.0445539231652454, 0.047876005992293365, 0.05156093104291828, 0.05410356920272593, 0.04393614603266601, 0.045351819060142004, 0.042538820810976534, 0.013171465552952743, 0.07481842962724548, 0.011241643148804865, 0.012273250444371615, 0.08164308559630187, 0.025648091273802905, 26.471711512534853, 47.68269700388755, 32.05510739357241, 27.359730235991943, 32.79930849229136, 47.06799099522252, 57.68329751107001, 7.819954397216921, 0.5231012596238045, 0.20313090975246123, 0.25378714075251935, 0.04206712132379894, 0.012167500624913844, 21.21015394887617, 63.18983062621086, 59.41547501471735, 55.52956719552317, 53.82690552742251, 49.84875925125615, 49.27330440090549, 54.71708743802963, 54.97496366500855, 57.84592682315458, 57.65739025608186, 50.56499581183157, 55.36216043656873, 54.46857390865203, 55.272244022738555, 52.87590726729363, 46.45987849081717, 40.94568890909995, 41.25798017747941, 42.379895717866965, 42.47526814860683, 40.52548147016957, 41.02189663917788, 39.973223517017985, 39.847982237415934, 39.76258831639444, 41.035424893902196, 40.93431403560024, 41.409332675318566, 42.69464238997429, 41.14392157523863, 42.02685494576731, 43.72431162864932, 41.53220092096637, 42.54552564313335, 40.80479737251036, 39.82720544261318, 41.432564873849195, 41.2674880027771, 41.0570881443639, 43.342865051761756, 41.09674722917619, 40.248703341330256, 38.92683321429838, 43.588217150780466, 43.2067431173017, 41.685369476195305, 42.94450521469117, 41.93724055444041, 39.552784658247425, 38.56209593434488, 41.233261400653475, 41.563599494195756, 45.09192443663075, 51.430745278635335, 54.01385745694561, 54.72353581459292, 54.39696319641606, 55.888389541256814, 55.29776296307964, 52.70065184562437, 47.92869629398469, 47.73085978723342, 46.62453959065099, 50.66086638358332, 50.677756109545314, 49.43715749248382, 49.65783788311867, 44.8932759992538, 39.8124102623232, 41.250182505576845, 39.18138327137117, 40.34595458738266, 39.666419644509595, 41.15597109640799, 39.26125449519004, 39.37413638637912, 38.24068907768496, 39.38992000395252, 39.51679691191643, 39.85795290239396, 37.29073809039208, 37.53883584853142, 37.79756322983773, 38.82267075200235, 39.42160883257466, 38.340682060487815, 36.03032365922005, 37.12417464102469, 36.996509336656146, 38.05437649449995, 42.960167238789225, 46.46882933955039, 47.17915881064631, 48.05460829888621, 51.78988925872311, 48.29939557660011, 48.971956545306796, 49.8424324681682, 47.95180689903998, 49.731225429042695, 48.84620535758234, 50.21723062761369, 50.66613412672474, 50.27602303412653, 48.77258246944797, 47.74197186193159, 45.64265266541512, 46.435567640489154, 47.95128522380706, 50.870960297123084, 52.401414225178385, 52.36558729602445, 30.655076196116788, 2.25469678159683, 0.512441789671298, 1.3265692490723826, 2.955717242533161, 1.2494571675216, 0.0606209434749138, 0.8858676098527447, 19.600703485550422, 60.63438684709611, 33.422932009543146, 33.55301349393783, 29.899355096201745, 42.627867960160785, 3.318733092277281, 0.1403382372471594, 0.03918038711192147, 0.0710108270868659, 0.11114502430803354, 0.08078437764197588, 0.03384661868274693, 0.04743249854072929, 0.0747211594434996, 0.06175216805610446, 0.014895665170174214, 0.07981476313885182, 0.040418603532617135, 0.014802782755014638, 0.05023911527748551, 0.042499309826281764, 0.011538612344602664, 0.01858434117879839, 0.02100565016359812, 0.04401826299726964, 0.0857766815311005, 0.0505558428384604, 0.033164842564973145, 0.03566904609361964, 0.07827043713581178, 0.01608716650685716, 0.05046323429973376, 0.10213230631404346, 0.05811123177409173, 0.023540370804708333, 0.016662075274413633, 0.03851683239542669, 0.07173419794848851, 0.016851396667921258, 0.03342975193874971, 0.11657857185890598, 35.647241453970636, 54.00339257332587, 30.89180300312658, 37.38662042925435, 41.29369728026852, 50.797757102597146, 63.19447079012471, 6.293368906744066, 0.651675389418679, 0.4120910131642896, 0.4640434496104718, 0.021928994871315458, 0.0564549956470728, 24.073027218541792, 65.14512823474023, 61.16651519652336, 55.75842180559712, 56.81838350911295, 49.08946683329921, 51.53844179645662, 56.10604186211863, 57.956714168671645, 59.29774507399529, 59.08605083342522, 53.44583157570132, 55.73017289561611, 55.87783444312311, 56.59085466015724, 55.387769591423776, 48.42431522184803, 43.43444455054499, 43.27873037707421, 42.55440588920347, 43.488130031093476, 42.39347496340352, 42.11612024614888, 41.88970142795194, 42.11715967424455, 41.9266305431243, 44.530472447795255, 42.98823571974232, 43.15929812769736, 44.43156988390031, 44.365022951556796, 42.683138078258885, 43.56072133587253, 44.516889279888524, 43.76662223569809, 42.78376256265948, 43.47366825226815, 42.58963661809122, 42.58738909998248, 43.399453086237756, 43.269430437395656, 42.525160697198686, 42.47747644301384, 41.10354861905498, 44.84911011111352, 46.367389002153956, 44.75716583190426, 45.229211315031975, 42.71817268863801, 41.93445567161807, 39.872410758849114, 43.329423089181226, 42.930427828142726, 46.71185547305692, 52.280397338251916, 54.26290835103681, 55.4280052646514, 55.7918207876144, 56.76398807956327, 57.63630359403549, 54.69267852844731, 49.03101175062118, 49.1911268234253, 49.23877185390842, 50.77793736611643, 51.533558445592085, 52.393271384700654, 51.50349347822128, 44.70608480515019, 42.4908007344892, 43.82899184380808, 39.869390533816436, 41.54272856250886, 42.812015395010675, 42.312168152101584, 40.56800388520764, 42.62486734697896, 41.261769187065866, 40.55711930797946, 41.72570713104741, 39.63141641309185, 38.50000481451712, 39.59476186383156, 39.652212819745465, 40.059954966268236, 41.39876973244452, 38.81999569554483, 38.24008111030825, 39.06835233011554, 38.68644683591781, 40.58208911649643, 44.42609033276958, 48.83711330352291, 49.001605741439334, 50.39783223982781, 53.388255103941894, 49.70754215794225, 51.25343453499579, 52.07559470207461, 50.14133668714955, 50.924583019748816, 51.35718907079389, 52.25040689591439, 52.00025381580476, 52.507318219830914, 51.863115987470074, 50.07260107224988, 47.8493663572496, 49.080190427841686, 50.43356895446778, 51.125063203996234, 53.99014280688379, 52.895825063028646, 32.20225118821667, 3.1549677637315567, 1.392977304996983, 5.638305141079811, 7.901549502726525, 4.994754512463847, 0.0927893124941376, 1.256725932321241, 20.996826041129328, 63.302822343764774, 41.085772437434045, 37.778406373916134, 28.085860975327034, 52.19784713560536, 5.205052879548842, 0.2702467389885457, 0.09123744818592265, 0.10490354511045641, 0.11340412566618574, 0.0806687290089265, 0.039546910387974595, 0.0444018853557927, 0.10444743934297755, 0.052668525642084504, 0.052841684495609616, 0.03757086319608554, 0.03310611809513742, 0.03918294584558856, 0.019300451442118616, 0.027881310351433295, 0.18429162791900097, 0.1252455926770645, 0.21906967545228623, 0.19315466765434514, 0.1594662422975225, 0.3167021268558118, 0.15843648223146317, 0.15232975023888773, 0.3681043283112588, 0.16444350021981424, 0.17544413976851972, 0.18464686288948984, 0.22533022257829868, 0.11514967998429654, 0.12790801634471263, 0.09862982893302556, 0.32067481368299455, 0.07863236005387961, 0.13575474851794783, 0.23822740471411138, 42.74168729782105, 62.066620703666445, 45.28581896135884, 38.300156131867446, 44.894252669426706, 55.50646051283806, 70.8020136433263, 10.6628534870763, 1.0769915316374072, 1.797753281651005, 1.2977263451583925, 0.25788140573328544, 0.10231795240073435, 25.89066532350356, 66.12496376037598, 63.90321170130084, 58.498071855114354, 62.10848808288575, 52.760452301271506, 53.617486261552386, 58.9930239800484, 59.67111549069805, 60.05475467251193, 61.36162957837505, 55.17563604539441, 58.98060967845302, 58.09849216092018, 61.97850858011554, 59.397726289687625, 51.48739214866392, 45.84736900944864, 45.39503735880698, 46.50113398028959, 45.37566085015574, 45.366447202620975, 44.0528925003544, 44.03622634949223, 45.752820276444965, 43.70326811267484, 47.34798154523296, 44.64833574910318, 46.370832843165246, 46.7541935366969, 46.14192724227906, 47.26385062740695, 47.06186817538354, 46.19844467409196, 46.060840083706765, 43.9632075063644, 46.16027216757498, 44.343720559150945, 43.40885892991097, 44.34957273544804, 45.783877603469364, 44.89842214891988, 43.65028081401702, 43.85474220398934, 47.599601591787035, 48.61284002181023, 46.28312864611226, 47.86934691090738, 47.178660669634425, 43.041285776322894, 43.09091552611321, 46.090504969319994, 44.40566655128233, 48.84872351923297, 55.287823677062995, 57.382989083566976, 57.9751257742605, 57.54952507634317, 58.39611376485517, 58.54481866282802, 56.85794453467093, 53.95495130169777, 50.242447545451505, 50.95288292054207, 53.73753432304629, 53.937237877999586, 54.48712671956709, 53.53934480297951, 48.307467814414736, 43.9256037435224, 46.590261997715125, 41.234277294528106, 43.13895279361356, 45.837500326095096, 44.877033464370236, 43.07939160254694, 44.32681122133809, 42.27891822015086, 42.95248723799183, 42.92375979884979, 41.95482846229307, 41.73483840880856, 41.40159776133876, 41.55690793068179, 42.52470962462887, 43.860527699993504, 41.82118546578192, 39.797301292419434, 40.869583160646506, 41.20538511583882, 43.22340926816387, 47.47859254960091, 51.876036274817686, 51.91717409318494, 52.192042027750325, 55.54656282547982, 53.198941907575055, 53.99352781234249, 54.99807427006384, 52.805422275297104, 52.57011144391952, 53.307956341774236, 54.6662417534859, 52.72006365560716, 53.94095628492294, 54.582024543516106, 51.40206098556519, 51.70669970973846, 50.908615050777314, 52.58177265044182, 52.80346501258112, 56.81853648154967, 54.78961598488593, 32.47621109408717, 3.7137209167403564, 2.0782136580636426, 4.7157283752195305, 9.6550779381106, 7.089910113042401, 0.18341076470190482, 1.6292664000103552, 25.389653136653287, 70.97625317112093, 42.68053754683464, 45.667622473932084, 38.04162486906975, 59.881919353239006, 7.896017980191016, 0.44457093482055976, 0.18315731217303585, 0.17856522793731383, 0.18833551495786638, 0.29734216570373506, 0.10320384881549305, 0.10538367539524071, 0.19718727787896512, 0.1070667322604887, 0.1777456517541601, 0.13519642363873222, 0.08907496583678069, 0.12203290337516416, 0.1761142981629218, 0.109104280990939], [0.05562734106675752, 0.050081155608378114, 0.07332661129053562, 0.02731480173796656, 0.023461461833287633, 0.0935319964323313, 0.00999124784533295, 0.05614256583935311, 0.057693767481513565, 0.03013145614175066, 0.03455341523212772, 0.05699604524359588, 0.08861616343980835, 0.0515307778222186, 0.013816495305828512, 0.09335713686361428, 0.017869743939128616, 0.0448889947015672, 0.14123771640081562, 0.11118401052250017, 4.58588517481281, 42.11275093017086, 34.33551457620437, 29.05825184237573, 43.01489214743338, 34.740040379185835, 60.25934157832977, 23.08339165103051, 0.24885126689989723, 0.07064340365750175, 0.17924768970377986, 0.13385518754441894, 0.03134905139074451, 0.8264345699740995, 34.28313524492326, 60.239808174871634, 56.50003610118743, 53.926008132196245, 52.52989146017259, 50.593393771879136, 53.089974541817945, 54.34155579536192, 56.553713736995576, 58.37270113729662, 56.22595264065651, 51.980814549230764, 54.00914276799848, 56.142543438942205, 55.11327820439493, 45.35165986707134, 40.382699351156916, 42.255756624283336, 41.24691517122331, 40.156927724038404, 40.75947046279907, 41.167589156858384, 39.68275239390712, 41.58838495131462, 42.20770366730229, 39.668863281126946, 38.57363162502166, 42.615477192786436, 41.59381743400328, 41.9519768991778, 42.45806463303105, 41.622897886460834, 41.34457042140346, 41.63327647793678, 40.87623157808858, 40.749123250284505, 41.47892728928597, 41.62631427088092, 42.7708383529417, 40.1651176329582, 41.26901380477413, 40.99105504251296, 40.24942897981213, 43.35451841354371, 45.76762330147528, 43.51803418128721, 45.04518155128726, 42.55568065950948, 42.31349391321982, 40.57937091396701, 43.517073200595, 41.98452080449751, 48.46391939347791, 53.26958771674864, 55.748702172310125, 61.00656878563666, 59.303954185978064, 52.95210715263121, 54.94420051574708, 54.21267455623996, 48.765118199010054, 51.09736342583933, 48.60127687454224, 52.86899997342018, 52.37684057604883, 51.32531196840348, 51.16538124699747, 44.219938401252996, 40.00642638052664, 39.18278747989286, 40.12384253163492, 40.09726062897713, 40.42717902891098, 40.360734078191946, 38.41329297711773, 37.20446555845199, 37.08673561772993, 38.940549742790964, 39.053612063007975, 38.23953197848412, 37.51685880845593, 37.82697708375993, 37.95233995683732, 37.79841046179495, 38.71118522459461, 37.030547665011504, 36.52313417004001, 38.11802479528612, 36.36178747300179, 35.480105338558076, 40.26986845078007, 45.66237434264153, 48.01179955082555, 51.43347524827527, 46.79283672763456, 50.63206834177817, 49.56992580044655, 49.012588377921816, 49.24029765590545, 50.068529652011016, 47.001451907619355, 49.71529276140275, 48.38334606539819, 49.845558597195534, 46.79988130446404, 45.95892513951948, 46.22594833374024, 45.70811702359108, 49.88602176789315, 52.27951480496315, 51.355204351486705, 44.91367624652001, 13.133122017306667, 0.4865103569482604, 1.3577120102220968, 2.6891483078079843, 4.586204847981853, 2.226138739816604, 0.031811193931066704, 1.9173273492243983, 45.37795935907672, 48.79322590366487, 34.66237744977398, 26.206802475836973, 39.000232527332926, 23.42384357606211, 0.31902466029409443, 0.0735778115209072, 0.107480067339155, 0.0447297633265055, 0.015518318452391655, 0.07437695613912038, 0.042233887173595934, 0.04117354104715971, 0.08907547911568996, 0.05062862119126705, 0.0054267767700366685, 0.009168681046444803, 0.057666567529761986, 0.03972995560616255, 0.01719217747449875, 0.03462878296211843, 0.03439099310086139, 0.034468842955726775, 0.03770502817426478, 0.049079710152000196, 0.010692542925807498, 0.04033085199133043, 0.04697725845260486, 0.008193227038117907, 0.026236441053990877, 0.06669911570967206, 0.014140105209193163, 0.05204963385157528, 0.03289306904339502, 0.06287153742666687, 0.03156954681711092, 0.04546457954171685, 0.04234701537737443, 0.037726865510546395, 0.11400601030477595, 0.2198129799216986, 8.257808089256287, 54.09885521857969, 34.33836221694946, 28.489818034633515, 51.95686063458843, 40.9929338578255, 69.20146696029171, 23.00565811895555, 0.352528381852373, 0.43381380397946606, 0.8690156979906944, 0.14953412686384496, 0.04516228124679578, 1.4480801094924252, 36.83542936078964, 61.41324796984273, 58.49795810637936, 55.67960962172478, 54.86907143746653, 52.257255354235255, 53.498752194066206, 55.64823458271643, 58.98175893291351, 59.558680749708614, 57.192173619424146, 54.91792455796273, 56.88305947088427, 57.32913494110108, 54.92850711268764, 48.120539419112674, 40.86940273161858, 45.77686440560126, 42.09438639302408, 43.362884829121256, 43.2294693300801, 42.105129764926055, 42.2980397747409, 43.788944444348736, 42.778800764391505, 42.91234962401852, 40.774846153874556, 45.89158981077133, 44.150535983424035, 42.5407011278214, 43.3004524630885, 43.30101336202314, 43.52001890059441, 43.488028049469, 42.76246801499398, 43.371729773859826, 42.763880068256015, 43.367881928720784, 44.54474595285232, 42.60415331009896, 43.28917957121327, 42.35753428551459, 42.32374698885026, 45.81773158042662, 47.84902511104461, 45.68107620362313, 46.655369420205396, 44.67615712073542, 44.1767531056558, 41.76788829988049, 44.60108295563729, 44.89206398687055, 49.860334165634654, 57.11174149667063, 57.15983759972357, 61.97270347226051, 59.276266174931685, 56.03207772777927, 56.3862834438201, 54.622122933787686, 51.373086437102295, 51.362354832310835, 51.10068175100511, 54.796660561715406, 54.7911221750321, 53.975375083185014, 51.59947387633785, 45.825646923434356, 41.64481216861356, 41.491663225235484, 42.83991521404636, 42.04444285361998, 41.99573878319033, 42.76016166133266, 41.10403891532652, 40.7043807737289, 40.23368850831063, 41.63356281095936, 40.2567167435923, 39.76809924648654, 39.42817488024312, 39.56847413893669, 40.63854379038657, 39.723403838373, 39.33750144896969, 39.48939523389263, 37.93550906642791, 38.35102142826204, 38.87534033867621, 37.57656512721893, 43.85699364446825, 47.589136708167295, 50.21102151563091, 52.58822887174545, 48.537538359242106, 52.16556210671702, 52.33939763038389, 50.94992937580232, 51.48116734720046, 50.25292027381159, 50.500135498662154, 51.575257162893976, 50.77932980752761, 52.808375820036865, 50.977107478726296, 48.079609486364554, 48.71396656959288, 48.85651334639519, 51.850862503051765, 52.275800320409964, 54.28796445169757, 45.93916816096152, 15.960219348630599, 0.5565391589076288, 3.0071731007868245, 5.788937883992349, 8.635848087649192, 2.1803551191283814, 0.06594295628489026, 4.043477518904594, 52.11477918009604, 51.99860249796222, 44.37850021546887, 26.27024877455927, 39.85885112516342, 33.70828443957914, 0.27214568709173514, 0.014384827208555034, 0.047380691844849825, 0.04944637898475893, 0.02041539090925888, 0.03591296465827092, 0.06769460866287833, 0.023516332880864223, 0.011103265644651989, 0.04133446930697368, 0.05336676498935108, 0.018275624982291655, 0.006835043642504682, 0.02865111763258615, 0.04317940821150138, 0.039923538363748984, 0.14070346200418088, 0.09220342377140638, 0.14711604693964606, 0.10058472443732525, 0.10706493195386664, 0.2113742609658549, 0.14072491246606075, 0.14385772178009634, 0.16924101859331134, 0.177594012310428, 0.19119835488738554, 0.17003388895142466, 0.23004394625463795, 0.14309632231391248, 0.15511811110040835, 0.1526381159501691, 0.11015683217274566, 0.13502521830941402, 0.2878710819828895, 0.5511817528355507, 10.150238929256316, 61.135065632481734, 43.89055736603276, 39.4364236247155, 55.54956343866164, 44.230932804846, 71.49425706555768, 29.629984363432857, 0.5127205231016683, 1.7842304201856738, 1.6144171645564418, 0.6744723274342476, 0.12189873839698492, 1.691732106189574, 36.2630614157646, 64.37166429335072, 59.43580073695029, 57.9961222217929, 56.621315786915446, 56.02105586759506, 56.48333464899371, 58.58709396854524, 60.221016099376065, 61.66447577937957, 59.435702677695986, 57.78149404833394, 59.709542951276234, 59.78864146817116, 58.16096767302483, 49.58348543413224, 43.39167502618606, 46.98594285595802, 44.89861042268815, 46.08468809435445, 46.47617201651297, 45.16052276857438, 43.882504740068995, 45.6335880679469, 46.531873595330026, 45.04709959030152, 41.35334476347893, 47.71344838603851, 47.229420062034364, 44.43580996605658, 45.91381788253785, 44.77652272870464, 46.328169222800966, 45.517344705520145, 45.44388655693301, 45.04013738324566, 45.09445436539189, 46.702026013405096, 46.28132435583299, 45.66850500722086, 44.885745048522956, 44.50424748082315, 43.50751830685524, 47.808585474568034, 50.81259542895902, 47.08097404049289, 49.143128779626664, 45.689015080851895, 47.772444755800315, 44.70677906467069, 47.06603373250654, 45.38797317012664, 51.81582789267264, 58.334085402950166, 59.56912994384766, 65.95235593857305, 61.53653983146914, 56.42620140506376, 58.211868270750976, 58.15310332082934, 52.941803086188536, 54.01454779409594, 53.81622491344329, 56.28210921441355, 57.548560173280784, 56.37788564928117, 54.98726421786893, 48.97253313372212, 44.05901924256356, 43.73853022052396, 44.18700618128623, 44.30247291441887, 42.943975694717906, 44.07085695574361, 42.09093470727244, 41.45198060620216, 40.67487278292256, 44.99913292546427, 43.38006873284617, 41.9254538320726, 41.90859940744216, 42.19499911031416, 41.49225942550167, 42.93703702188308, 41.23102957202543, 41.340891238181825, 40.079892373854115, 40.961692179403, 39.281615518754535, 38.318167655698716, 45.29991988212832, 49.79086506751276, 53.07127660320651, 54.52562870517854, 53.013386341833304, 55.65478101853402, 54.60865743698613, 53.30996067293229, 53.90330153126871, 53.64838669376989, 52.74408425054243, 55.23045116855253, 52.747920328570956, 53.72623005220967, 53.09531288762247, 51.64533422839258, 51.23045729052637, 50.715089228845414, 54.32021025688418, 55.8322133556489, 55.0640053902903, 47.33743429183961, 15.292129881920355, 1.4257941827658684, 3.9275839828675796, 6.515851626473089, 14.919892049604847, 4.470006592812077, 0.23924044874166292, 6.204484566565483, 58.04035479022611, 55.61052491587978, 47.27084813579437, 36.42843246459961, 51.06409388203775, 42.182184726961204, 0.5601461460032772, 0.18265678096682797, 0.20624525634752167, 0.12604727304630703, 0.08582815497873292, 0.2675236334964152, 0.30344071587727917, 0.11545511157882792, 0.20886636489341337, 0.15018988280527054, 0.21543610510566544, 0.10656728123825406, 0.11469174326667864, 0.14982753853884437, 0.08258880581706762, 0.1614206245229129], [0.059769118820587476, 0.057278069021600875, 0.03807728944887077, 0.07110170043644405, 0.05932829650719801, 0.0258738822829459, 0.02773311830336048, 0.06613263199406286, 0.0757644103179055, 0.01622059029496966, 0.1248229879345144, 0.04660183323487159, 0.06068104690301323, 0.02643570052309623, 0.06367825099357194, 0.028207891718334252, 0.01947095963142572, 0.032659959979355335, 0.02194090562331821, 0.04868697900805743, 0.023639745815026186, 23.24281834786938, 44.018481546832675, 28.140831032106956, 39.09245529482442, 34.279718860503166, 45.65454136940741, 44.876319592998875, 0.31749931794981806, 0.21041079814876282, 0.5645872496308819, 0.21271462371993452, 0.08096527398353623, 0.0871260075138942, 4.954897347957858, 48.29459067313902, 58.91521984531034, 55.73294601132793, 56.39448119748024, 52.766551586889456, 51.48878851244527, 53.102577117181596, 56.38059992944041, 58.65679840887747, 59.26464811448128, 53.45413915572628, 53.53855248420469, 53.69972267458516, 53.462850739878995, 45.594474192588564, 41.2813731931871, 41.90120573966734, 42.232461667829945, 41.285750558299405, 40.72973105215257, 39.52130763761459, 42.64758179264684, 43.8963036383352, 42.17589716757498, 39.861067264310776, 42.99753958179105, 41.50978849780175, 40.88387235518425, 43.65477977260467, 42.1144453940853, 40.70759319490002, 40.278140729473485, 41.054840626255164, 40.872615152789706, 42.28426048832555, 41.46222583709225, 42.26721778992684, 40.913749048786784, 39.89240307961741, 40.99292993545532, 41.05381688764019, 41.221549203318936, 44.85652731310937, 45.52561306184339, 47.625297038785874, 46.74430916386266, 45.92219998759609, 43.88948655897572, 42.829560156791445, 44.23450216170281, 46.03198320634904, 52.01412331673407, 56.609407471072295, 53.892613072549146, 53.960164131656775, 58.81256749553066, 56.20429723493515, 54.651109249361106, 53.08642087444183, 52.04840875441029, 53.4960183020561, 53.00150548258136, 55.41368469115227, 55.3380927731914, 54.38177185673868, 52.65805882792319, 44.57288503646851, 38.21196163854292, 38.72421533830705, 40.22489063201412, 39.534726065974084, 39.16974952144008, 40.5788060926622, 37.99598809211485, 39.12692508389873, 37.98741379091817, 40.08473650101693, 39.03996613717849, 39.55483998021772, 40.11154197877453, 37.97189689451648, 37.40277667199412, 37.47900793629308, 37.052010874594416, 36.40728304463048, 36.424749359007805, 37.549010476758404, 36.33215788872012, 38.62881545097598, 39.37861181074573, 44.839696422699966, 49.612412914153076, 50.55886906962241, 42.420562851813536, 44.3140439064272, 49.932768575606815, 48.90948495557232, 48.540472292131, 50.05469153004308, 48.64929453019173, 49.827692201060636, 50.17461407569147, 49.95021527813327, 48.60167695629982, 46.65591462965935, 47.12227659840738, 49.116456662454915, 50.951235525069706, 53.51495550524805, 50.43424752450759, 29.69979863012991, 3.7390236364256952, 0.13728747594981425, 2.836371285300101, 8.013901873942345, 9.858707785606384, 2.4171589026528024, 0.07718292936202019, 7.187946813721811, 56.72937316279258, 40.0877449589391, 28.071765938112815, 30.132277204144387, 44.62134984231765, 8.484651504024383, 0.08089939808292736, 0.0593547648449819, 0.049748424470665, 0.03933704060111796, 0.04554587296180187, 0.08925193214728948, 0.005736724931686636, 0.00955000705641484, 0.009733940936594961, 0.04901475355690045, 0.03605733009716196, 0.03256561242104058, 0.03375709747835513, 0.022791561993560003, 0.02118682612725083, 0.04342342636758282, 0.03260737570423273, 0.0834805321609301, 0.020368785950385278, 0.021738137471519654, 0.09070353086797461, 0.048491496352418784, 0.07328164959025961, 0.08301042996707463, 0.042682627005682844, 0.03914914221592969, 0.04798870518683426, 0.035205750590971405, 0.0971013532891389, 0.07878965322649287, 0.06200006644752237, 0.12729130790478763, 0.01616628423723723, 0.03124835296353746, 0.156424336976582, 0.04325243554288342, 0.3512845308549943, 33.15751306472286, 49.36978294003395, 27.75279683451499, 52.33356898830783, 41.78761389947707, 49.490701767706106, 45.874731463770715, 0.3773210095542093, 0.1793551565177979, 0.7521568911690867, 0.08490915590476605, 0.0866870774376777, 0.08612243999396602, 6.449385593014379, 52.09415928010018, 59.80697070398639, 58.484535755649695, 58.40669239720991, 55.16027212142945, 54.19476893640334, 56.25329548312772, 57.812896543933505, 59.88819514551471, 59.812858181615034, 58.19178573546871, 55.83399803407731, 55.97026509623374, 56.8820631888605, 48.5847480066361, 41.896742082411244, 43.807434497341035, 44.1063779400241, 43.516959451860004, 42.92882357874225, 42.73745113803495, 43.68916326953519, 45.24084114259289, 44.08408711033483, 42.102525311131636, 45.55416791669784, 44.148147259989095, 43.7583028885626, 44.409973313731534, 42.04745131154215, 43.86228492183071, 40.25654415930472, 43.58663251323085, 44.066671786769746, 42.860723387810495, 43.37931171540291, 43.31779326162031, 41.34090300529234, 42.367042110812285, 42.72140079928983, 41.543775835344874, 43.47698265506376, 47.26719248679377, 48.18376410392023, 49.1673807944021, 48.08068421579177, 46.765815519517474, 44.45051493183259, 43.61641899231942, 44.00208211714222, 48.84724870804818, 55.41828955373457, 58.81789407422466, 57.8569604504493, 55.46157683095625, 52.62768007093861, 56.34780499242968, 58.22867170456917, 55.439042814316295, 51.63182950788929, 54.08819813882151, 54.02049802964734, 57.513705991929584, 56.571917456965295, 55.067217811461425, 52.87905300817182, 46.203888923891135, 40.8236639730392, 42.60574971475909, 41.13460986844955, 40.382236511476584, 41.66423574570687, 41.94202976842081, 40.3415419209388, 39.35618369810043, 41.417675556675086, 40.785742498213246, 39.69904984197309, 40.982210097774384, 43.4486396081986, 39.66078712094215, 39.18717268974551, 39.70343505182574, 39.53238048861104, 37.55843200991231, 38.09567513004426, 39.14079850719821, 37.51843952363537, 40.72755805907711, 40.26908789911578, 47.74658849162441, 50.13064822842998, 51.94918455616121, 45.27227109478366, 45.65116813105922, 50.8738197049787, 50.31488587779384, 50.77235583336123, 50.36634345208445, 50.44802681092293, 52.00744352033062, 52.22572734279018, 50.99927279257005, 50.82224445958292, 50.01755060688142, 50.558429764163115, 51.157603186945764, 53.14178905179424, 54.19242728141047, 52.19240680817635, 32.67034292221069, 4.174952180154862, 0.8430894440220249, 6.241529391657922, 9.183336438671235, 9.498455735944933, 1.7024523115927175, 0.1843192836930675, 8.572571431436847, 60.71698019581457, 45.18133486470869, 40.72094886533676, 29.615171532477106, 51.675881647294574, 12.641941251293307, 0.252974106960239, 0.046047204729890635, 0.04468210882717564, 0.02165976284642614, 0.04983591937249707, 0.05176406308648087, 0.051982267909953674, 0.05091820625708469, 0.030894217329219948, 0.029379753433468363, 0.002424468139877483, 0.1528537390573371, 0.0658049761888481, 0.0507931960296006, 0.05097317689609143, 0.017429839016028473, 0.1351481907430195, 0.18969208813242375, 0.12156163672766379, 0.13451498843008472, 0.15954579286757978, 0.11757647798907374, 0.16662012455203842, 0.18689949846556111, 0.12338527838789648, 0.12894339949613617, 0.15261560828695375, 0.16729681001555535, 0.215907693510094, 0.1408009696751833, 0.16115261632348263, 0.22318833267256138, 0.12064205542687448, 0.10186679556124634, 0.21816930763663786, 0.12275057454263011, 0.36878967056832007, 39.0254416004304, 56.42368324341313, 38.001146008891446, 50.13989325492613, 46.76668628569573, 54.42420797963297, 55.503757999789336, 0.931626593153323, 0.7076423410927096, 1.6181079923145234, 0.4340898407803428, 0.2667967692738579, 0.15061133841593422, 6.928884069765768, 52.602019925271314, 60.191919957437825, 61.960081285046, 62.14781768860356, 57.4320932357542, 57.33810147931499, 57.46529609926286, 59.92391617067399, 62.46537277775427, 62.21669058645926, 57.3186190666691, 59.3792676156567, 57.649945597494806, 59.613911644104995, 51.814368770968535, 44.67810261634089, 46.65820137146981, 48.57227879185831, 45.158518437416326, 44.420524489495065, 44.66191499463974, 47.34648712219731, 48.18052030378773, 45.51038642083445, 44.05341809795749, 48.9933216956354, 45.70300617525655, 45.52391467555877, 46.29511540935886, 44.562275025152395, 45.32342664657101, 42.26704912800943, 45.412091824316214, 45.84446253315095, 46.65522429250902, 46.67236112779187, 44.77060387211461, 43.93257771768878, 45.023777177256925, 46.17728740938249, 43.892024332477206, 44.24092700404506, 50.38944621239939, 50.81413692043674, 53.06809556099677, 50.35553732225972, 50.272841991916785, 47.42061991845408, 45.510555082751864, 48.69876346280498, 50.844033225890136, 55.9268876044981, 61.41520915492889, 58.425272664716175, 55.709745191758685, 53.78654433834938, 57.68292096353347, 58.9578442419729, 58.775101015644694, 53.22166027561311, 56.07532185892905, 55.358226299285896, 59.24270245336718, 60.334972719992365, 56.76065014254663, 57.201536317025464, 48.93349770576724, 41.9277209620322, 43.93182462261569, 44.547958374023445, 43.67301487153576, 43.39065128757108, 44.94738901815107, 41.66383174157912, 42.96532907793599, 43.086353809602805, 43.305371115284586, 41.0835680653972, 41.8897210398028, 45.035328557414395, 41.51747242096932, 41.16322748122677, 42.572409568294404, 42.280173378606, 39.87055940012778, 40.437612533569336, 40.91432563720211, 39.62674487021662, 44.269215137727805, 41.931823761232444, 49.280156781596524, 53.72338241146457, 53.41086756798529, 45.91941902714391, 46.97251266048801, 52.33046639350153, 51.84811684393114, 53.41862209381596, 52.19108104705811, 52.146738652260076, 54.59287381941273, 52.99829306141023, 55.25365983286212, 52.48094028042209, 52.70817887398505, 54.14138155598795, 54.37373099788543, 54.63700048385128, 57.40699398902155, 53.48900118181783, 32.54980064207508, 4.767470811643909, 0.9982031884212649, 7.4091753555882365, 16.42708436135323, 16.353888030975096, 5.579108240142946, 0.2496302557448226, 11.242661187725684, 69.79843601103752, 49.439412855332904, 42.172182683021795, 39.69582957606162, 61.32514761340234, 18.957073919234738, 0.29653927491557214, 0.2309789259227053, 0.11735272668902913, 0.14797697654895245, 0.18986464177648868, 0.2625672284874224, 0.12885945158139353, 0.13841111243011492, 0.08349563941479692, 0.16056947019552031, 0.13667891102452434, 0.2379512913044422, 0.14614028075049001, 0.16750898572706407, 0.22187821506973238, 0.13694144935617525], [0.030926578798361366, 0.04618013247607216, 0.01916342895598181, 0.057674802974948, 0.05169768156784196, 0.04866419555318933, 0.050892350789640224, 0.028424744396620703, 0.025819022726688175, 0.02469716548559166, 0.09411527279524073, 0.044321932589575175, 0.04692640936663074, 0.05591196571326545, 0.06527865080222969, 0.044795892036129395, 0.03287464462881608, 0.046406511457697044, 0.02924216404226759, 0.08220050649176683, 0.05388018562488499, 3.762200676625775, 37.49159482217605, 35.688500865813225, 25.483686077979307, 40.571145703715665, 41.46077456012849, 60.496421398655066, 7.009573107765568, 0.4136978366201924, 0.08550559365821463, 0.02952035355021156, 0.017154905381762696, 0.13843766503757046, 0.07593431329775242, 10.101451508460507, 54.297256546635786, 56.77708487356863, 56.09467091098909, 52.524282470826186, 53.01722241986183, 52.216458782073, 55.02524060587729, 53.1755018234253, 55.83533948467624, 53.11960020372945, 51.57706929791359, 56.2387905582305, 54.97384578950944, 43.92618033193773, 42.72861403803672, 40.298446839855565, 40.05513437332646, 43.29076813113305, 42.51482917416481, 42.8381109237671, 44.52518509280297, 44.23657709552396, 43.4715070263032, 41.557700249456595, 40.2844439783404, 40.099927840694306, 42.61956822487616, 43.151782866447206, 42.99492336088612, 41.29734900689895, 39.978675611557506, 39.13568765886369, 42.03974385415354, 41.44765423190209, 41.36118950382356, 40.912905739199736, 39.95751050210769, 40.877592640538374, 39.829115636887096, 42.12952690739786, 42.14209810380013, 44.01660665389031, 46.49198701304775, 48.45682382583619, 47.29362141701483, 47.22539571023757, 42.592711756306315, 43.17822748614896, 41.399773859208636, 50.35543141826507, 52.731681716057565, 56.88436169778147, 54.67796571793095, 86.01737391564154, 82.0625892762215, 49.783973463120006, 58.82267936583489, 54.24207272068147, 54.79187527010518, 52.89545636023245, 58.208412662629165, 54.364811528113584, 52.12457333841632, 54.363791711868785, 54.24798765490132, 42.45930802437567, 39.82260842477122, 38.28205047115203, 39.19810433541575, 39.046194861012125, 39.159974974970666, 39.434423215927616, 38.17174949953633, 38.6551933903848, 38.298767612826445, 37.67141980509604, 38.50166397710001, 38.26016364559051, 38.60116274126115, 37.930923815696474, 39.077001156345496, 38.835183112852036, 41.688452459150746, 39.11880577764204, 37.02953569350704, 36.07431696307275, 37.13927184381793, 35.41348388118129, 38.49216399654266, 38.46105175633585, 47.031952258079286, 48.760019117786044, 56.58891308692194, 53.04632248417024, 50.484336191608065, 50.99352259789744, 51.63073124424104, 52.656144711279104, 52.53936398413874, 49.130290862052675, 50.8268375550547, 50.840044175424886, 51.991032323529645, 49.640175450232725, 51.06982446485951, 50.30213032999347, 54.49384573967227, 49.81231650998516, 47.789110906662486, 13.513404630845594, 0.6553447667148806, 0.7034349862125613, 3.5722711778456167, 6.027488102835994, 8.264491808029915, 1.6917176424495637, 0.022849221601180976, 37.458658679839104, 55.33375463178081, 33.61826996649466, 30.587525137009163, 34.521042685354914, 38.01820047440068, 1.6489468923499508, 0.052362155589845874, 0.019616644656766328, 0.047343823863493825, 0.04022199472772979, 0.01212115326310478, 0.03442437538216191, 0.09999825348777157, 0.021209917932508454, 0.07218458870005223, 0.09800535236154834, 0.05819196594999202, 0.082649112258467, 0.05328207013888225, 0.04045310813272673, 0.034186780873325565, 0.06637787972126277, 0.032213640985109156, 0.09164724393837875, 0.02632879295326289, 0.04175935699153812, 0.07914933150694256, 0.04536903305580059, 0.044979959981696266, 0.060258748595632856, 0.03150148373547822, 0.05810152160965147, 0.07491022228233277, 0.035855829820878087, 0.06563262938852273, 0.06054438830864045, 0.026467807268002824, 0.0946406405719538, 0.0225240862252371, 0.031186004897819895, 0.11197558619202146, 0.08094132607502323, 0.05551334335318497, 8.337095860512026, 47.30171326668032, 33.2362703354128, 32.333156370347545, 53.07513621545608, 46.967256684457105, 66.90385233971381, 6.033844793996503, 0.2582525906543578, 0.06329364421206617, 0.039111542620606, 0.07781662197122652, 0.3941710828052413, 0.09557089347752834, 11.989825637109819, 55.29185195122996, 60.38315903755927, 57.45872612922423, 54.60337792673419, 54.614258581592196, 55.673145555680804, 58.45364316817253, 55.59866366847869, 58.770056847603094, 56.96808468910956, 54.219346507903076, 57.58775249604256, 57.094585049536924, 45.675502515608265, 44.28564594637963, 41.5473138132403, 41.4818847563959, 44.65638445269677, 44.84079076397804, 45.16225253382037, 47.303207689715975, 48.06141361113518, 46.1669284297574, 42.79289384042063, 42.62242763273178, 42.566306360306285, 44.87930059432984, 43.67966721134801, 44.870526252254365, 44.310862864217455, 43.73482750308129, 41.67702267246862, 42.71383062485726, 43.64837846448345, 43.21339153474377, 42.658054521006925, 42.919127479676284, 42.23214395584599, 43.29156829464821, 44.21265848221318, 44.3231398828568, 47.80558093901604, 51.549675464630134, 48.259371711361794, 48.85524642082953, 49.18587476976457, 46.543911349388864, 42.39076852798462, 43.63026103665752, 50.35379578990322, 58.241556690585234, 57.65543299336588, 57.68066952305456, 66.71217395413306, 72.0342105434787, 54.17258008833855, 55.928480086788056, 57.10662280359576, 54.8893226346662, 56.0014989299159, 59.67239418337422, 56.68166929675687, 54.58177351182508, 54.99715251307334, 55.170125115302305, 44.160749835352746, 40.94224506808866, 39.88814730798045, 39.86271073741298, 39.63576632161295, 40.62817304365097, 42.34237824716876, 40.778913651743245, 40.27700716449369, 39.42380143750099, 39.86546031890377, 39.378941289840206, 40.26722085091376, 39.585250116163685, 39.76870721386325, 39.146744820379446, 39.10054714448991, 42.096484861066266, 40.24207061336887, 41.16700472370271, 38.40369493730607, 38.02508423405309, 38.13713458276565, 40.21280973188339, 42.24989268087572, 47.366502977186634, 52.446344975502264, 58.60437985389464, 53.326764106750495, 49.98380645628899, 53.66504107752154, 51.45688395346365, 53.556269830273045, 54.29646422786098, 52.26076587553948, 52.87617006609517, 52.11039789261357, 52.529310949387096, 51.198176184008204, 53.808984218105195, 52.26630033985261, 54.22759525237545, 52.35454582398938, 50.53396201902821, 15.127928679989232, 1.229621496412062, 3.8895026714571066, 6.581249304356114, 8.21122209871969, 6.5809943502949135, 0.3441418334841729, 0.04021226158065181, 37.50770791884392, 60.7611813852864, 46.729384545357, 33.96796495683732, 33.099658104681204, 48.82499710206063, 2.6775138224324873, 0.028274692670111696, 0.04547026008367539, 0.02089593296630248, 0.04332675756285748, 0.07954264104726814, 0.04325822716759097, 0.09204842120168671, 0.06942258126312686, 0.0062337800139381045, 0.08063904310186064, 0.034372327368586295, 0.06838066338170921, 0.06042143502723306, 0.055425499881347345, 0.07215496408002031, 0.10680308310134758, 0.13424158697166752, 0.19679779877826092, 0.09724597536748457, 0.10305204849329688, 0.22160505875945094, 0.19134204233846358, 0.2523999087392323, 0.2531968853286197, 0.22073343456272157, 0.0794031594188944, 0.23892668977139458, 0.1589488878004974, 0.22028187169663369, 0.13983151605052335, 0.12564634093113486, 0.2593802414353817, 0.14039684297336688, 0.18271336422091533, 0.20148939783534697, 0.27105263284137177, 0.317474864423275, 10.368223670990238, 55.330828543632265, 44.44472551345826, 33.1398545542071, 51.679039155283284, 53.15739616270989, 70.09364143494638, 9.221824695987086, 0.5506217119193847, 0.6066127493977547, 0.16808995616532144, 0.19430902426040944, 0.3050583564946729, 0.16209901070162175, 12.302285567406686, 56.469386700660955, 60.691214146152625, 59.924226037917606, 56.877705435599054, 58.58386193552325, 56.543229241524976, 61.0646394760378, 58.71515543230119, 60.307963278985795, 58.46310000265799, 54.46608712596279, 59.50221038633778, 60.69310865094585, 47.24839648892803, 47.56857564372402, 43.841821916641734, 43.51350776610836, 46.58367241582563, 47.65597389590356, 48.44664527523903, 50.10149717330933, 50.69792493697136, 49.802573342477125, 46.312444440780155, 44.036132212608095, 43.99427660049931, 47.14806225992019, 46.64150384164626, 46.652482555758574, 44.70583769582933, 45.89822646110289, 42.316074832793205, 47.092768607601045, 45.1335721631204, 47.19769593208067, 44.99077043225689, 45.08479749002765, 43.90767458946475, 46.25478167687693, 45.406439688897905, 46.75092620234336, 48.960138443977606, 52.44540360666091, 52.673112884644546, 51.68501292505572, 52.90158702481178, 48.80286708954842, 46.156239971037834, 44.82258704400832, 53.4714642647774, 59.524560051579634, 60.78622964120681, 59.94611286347913, 70.97375854369133, 78.80450387154856, 54.49937235924506, 60.50737265617617, 58.419236137020974, 57.83743096936134, 57.628321570734826, 63.32259893417359, 58.853007132007235, 56.754582235890055, 58.03062731219877, 59.814799754850334, 46.44221213556106, 43.630484611757346, 42.69614465775029, 42.36133113984139, 42.17708956810736, 44.05570091739778, 44.19142277010026, 42.31789481255316, 43.393714658675655, 40.56630549892303, 42.724048399156146, 41.738529359140706, 42.80022475027269, 40.68082694084414, 41.90982710930609, 42.76318973110568, 42.99619028645177, 46.800755993012466, 42.85919758581346, 43.56291786316903, 40.06485400661346, 40.24195686463387, 39.44921055147725, 43.4578493333632, 42.04370544802758, 49.376925576117735, 53.11485021345077, 61.2428641319275, 55.91129618306314, 52.35371820388302, 54.113109111785896, 52.580693998644435, 56.04149141619283, 57.69336231293217, 52.22296207181869, 53.48947971097885, 52.78601046531431, 53.81577776324365, 52.62220836454823, 55.727038921848425, 54.349945745160504, 57.88123992181594, 51.84715194086875, 51.532452337203495, 16.19090178320485, 1.255768751425128, 3.425977556936203, 10.335495414272433, 15.55577983779292, 19.87893485253857, 4.32503039798429, 0.16302066043980662, 46.03913368717317, 64.68124912631127, 45.30477185403147, 44.4710720739057, 44.9528685692818, 56.37099796725858, 4.75132780690347, 0.3066947815879699, 0.14572403453771146, 0.1649592918974738, 0.12241026296490624, 0.1987281564863459, 0.11596995330746136, 0.2781969849621096, 0.16930592156225638, 0.14533041856221615, 0.33136964625408577, 0.14547075054818584, 0.1315754630993451, 0.1432162916828548, 0.21185193210840228, 0.11534888582724719, 0.27749368560410315], [0.044664400704805894, 0.04087440286492629, 0.05828616029072193, 0.02213737844759899, 0.018503128197945414, 0.04545964976592411, 0.05788299885969009, 0.03197448940256671, 0.12068028321429608, 0.009174741759535768, 0.03516972530633211, 0.03636798258089731, 0.034522959406697945, 0.011865001231912645, 0.022387534883173726, 0.03285785964239509, 0.08821662560465836, 0.05657281230894789, 0.038150339762890534, 0.07396030389974195, 0.007949689123404003, 0.07795864701150887, 21.341043441526352, 50.06889443243704, 27.100351741237027, 39.47937357810236, 36.31515049165295, 52.723178017523985, 22.910489651464648, 0.2711122651253977, 0.22739015639789645, 0.08530159210485798, 0.11928663904508276, 0.10147851921858327, 0.08194406621999319, 0.41255805100644793, 26.18136786645459, 58.947175395104196, 56.19368722361904, 56.489798715037686, 55.012057519728145, 56.3212074002912, 56.254523184991655, 58.61065956854052, 57.40594671618555, 53.49068387862175, 53.918485026205744, 53.89573920157648, 51.936848701969275, 41.40263718943442, 41.98623095789264, 39.862189062180065, 41.36437839077365, 46.29839058845274, 48.062723682772734, 47.913606935931796, 49.59944163599322, 48.86271461363762, 45.911613510501006, 43.04998951573526, 43.7963459568639, 40.89592972109395, 42.85265114999587, 43.06325889402821, 43.30525736654959, 41.98295970116892, 41.892121530348255, 39.18706678575085, 41.76971612438079, 42.81525527277301, 40.90729674985332, 39.92260532994425, 40.3466292350523, 40.233782645194765, 41.4453439558706, 42.26633525663807, 42.07588457292126, 44.92606701389436, 45.95941151342085, 45.24203354312528, 47.006299957152336, 44.95522983612553, 45.821869680958415, 43.545322110576016, 46.38733425448018, 49.696759562338556, 56.51529019878757, 53.66087552039854, 57.89971428532755, 51.71803928190663, 44.37094180814682, 68.10335236210977, 60.842397982074374, 55.65977027339321, 52.30584175355973, 53.55320645916847, 56.918192140517704, 54.86647482841246, 52.055355271985455, 51.301828738181825, 52.10458101764802, 42.68985317599389, 38.62617961822018, 38.17504821285125, 37.64115479684646, 37.92028634778915, 40.66533357866349, 40.35640770389188, 39.574800922024636, 38.50859480519449, 38.43402270347842, 37.19569513874669, 38.95436825290803, 38.60150790983631, 39.56059801963068, 38.24581953787035, 38.63163563512987, 41.992208650035245, 43.61414793998965, 42.19900385026009, 39.58772905411259, 38.43510920001615, 35.69778903838127, 39.11506775886782, 40.159971483292125, 35.348764773338075, 37.61271369072699, 46.201947350655836, 49.52401445757959, 50.623078269343225, 49.945716319545625, 47.2378021670926, 51.86192750930787, 48.791962900469386, 52.40416772903935, 51.47910418048982, 50.95071777220696, 52.04835384122787, 50.44879559547671, 51.291650187584665, 52.368611443427305, 51.36453174775647, 52.61411651488274, 51.472710717108946, 35.44476478330551, 2.6435240334080112, 0.31299652892255014, 2.304081138103239, 5.874795625286718, 7.8489706208629, 3.1224643078542527, 2.496131168257806, 4.077333702195076, 54.06754685986427, 37.73262446926486, 28.64678736655943, 28.007550854836744, 44.93712025303995, 24.814094343493064, 0.03389961281490903, 0.0978256740997876, 0.026305373645417636, 0.08000284538514192, 0.08830418945440362, 0.072792801224897, 0.048754260680007364, 0.07468008180899967, 0.014901229841334206, 0.020514116660060904, 0.026808444433094516, 0.05567832804855801, 0.0446731532593408, 0.03740514305630519, 0.012053269254524383, 0.013890000484553317, 0.03406934342497299, 0.0811244823759602, 0.027546192849836046, 0.04488373550796702, 0.06784362042503012, 0.01598634550558223, 0.01796388273848401, 0.048596032880126476, 0.06384121321682489, 0.05648960366905217, 0.032340838393617066, 0.010124298165582362, 0.08570536640622924, 0.03295435607733746, 0.06633045121787057, 0.048337160279193235, 0.04611114242805108, 0.06491023145856396, 0.071176823018299, 0.11795960622088564, 0.051157823238041134, 0.05020175699985797, 0.5125367845739088, 29.787302786304107, 54.79294607716223, 22.571494886952063, 47.747839727709376, 44.16076160246327, 60.77873006943734, 23.18026831073146, 0.38152324696702344, 0.27665463546591423, 0.1434913938564639, 0.23701790509925735, 1.8156992283559616, 0.19584466282638813, 0.5115814422888141, 30.194580131961455, 60.21407350417107, 58.81866285877844, 57.437737526432166, 57.175130921025435, 57.031132867259366, 59.07945340679538, 60.12837756064631, 57.98117014669604, 55.49995722309236, 57.165678008910156, 57.71087961812174, 53.44793396611368, 43.13867038296115, 43.89508770358178, 41.46958812590569, 44.21296442708662, 46.97801966820994, 48.10439494348342, 48.515522095464895, 52.932746333460656, 50.308817971137266, 46.71084350155246, 45.948115087324574, 44.726135961471066, 42.406195209872344, 44.65416046880907, 44.44599243902391, 46.04269912165981, 44.869831992733864, 43.52984051550589, 42.036186264407256, 41.96323410157235, 43.303806089585834, 40.68874228385187, 41.669821200832246, 42.25443086316509, 41.70139235834922, 42.61453190157491, 43.6023808294727, 44.99839944224204, 48.58037064152379, 50.593178041519664, 48.79174717010991, 48.08228454282207, 47.05615328204247, 47.281226727270315, 45.80912982263873, 45.90962486882364, 52.35850741786342, 59.64756950255364, 55.57942836515365, 57.51792253986482, 61.42033961511428, 49.181940632481734, 58.121838108185806, 61.07566918096235, 57.32650695308563, 55.11260355672529, 55.589763810557706, 58.23961903972011, 54.00196875295332, 53.33624447545698, 52.8406177028533, 52.77924437676707, 46.684414571331395, 42.24496226156912, 40.2723160097676, 39.85690170718778, 40.22428658700759, 40.2528335971217, 41.431937294621626, 40.128898466787035, 40.87899684906006, 40.80548770966069, 39.507787227630615, 40.25095870417934, 39.094993068325905, 41.70974308444608, 40.16999706145256, 39.646450857962336, 43.524462945999645, 43.79519670240341, 41.31618815083658, 42.28772786355788, 39.93199548413677, 37.477391919782086, 40.358329665276315, 40.0558796236592, 37.84130942436957, 39.86576626377721, 47.67652319323632, 50.989125620934274, 52.43323249201621, 51.83418458507907, 47.88384399106426, 53.74008778602847, 51.260577171079575, 53.08157282490885, 52.8934088830025, 51.79875773768271, 52.73319575094408, 53.14077315791961, 51.86802679492582, 54.38319567711123, 54.11090866211922, 53.39522907810827, 54.46747564500379, 38.113733722317605, 3.7602583679460713, 1.5898943836650543, 4.637246651034202, 7.171497373811661, 9.727612368522152, 3.1607216356262087, 0.8084650890481088, 3.479129104844986, 63.966079450422725, 44.50108605046427, 34.99229584970782, 28.91728185838269, 47.793911887753396, 33.50969483775477, 0.08730301212879919, 0.0694920807596176, 0.07258791867042742, 0.07019694293698958, 0.005170709966126109, 0.09147007844500965, 0.1390479306780523, 0.0015210854091433689, 0.023191860170974847, 0.06806569399252053, 0.09088865601487699, 0.035214740632762837, 0.023727338393068603, 0.058619320437672644, 0.00734484690662113, 0.01744071171889382, 0.014962558052502574, 0.15621378537147276, 0.15587044008556875, 0.08747284616073293, 0.14112278789041505, 0.11628096968296076, 0.096875510569061, 0.1546193725399433, 0.1439811691882149, 0.2689956254776447, 0.12364608536083853, 0.17289544185323102, 0.2279545027281969, 0.09103054315933297, 0.2015005520755245, 0.09720426954088673, 0.27005969096095334, 0.18573479967251902, 0.13384668396845942, 0.3023113797028219, 0.18334137245772347, 0.1846230681985617, 0.7732696614919171, 34.429800510406494, 62.95251154130506, 35.69611810868786, 48.5030528806871, 49.361593031114154, 62.754055300066554, 30.08070391993369, 0.4447238459702461, 0.7051987657623907, 0.24412677202734256, 0.39512473969690265, 0.9760280686520761, 0.17116031399176967, 0.9183508410088478, 31.610645978681504, 61.26311532912716, 62.230705215084946, 59.94703462046962, 61.180914217425936, 61.999587397421564, 63.8186885464576, 61.06282734101819, 59.99244389995452, 56.1683173333445, 59.146977009311804, 60.75057921871063, 57.95995796880415, 45.87842633647304, 47.23649209545505, 43.51354306743991, 46.41295517644575, 49.67858329896004, 53.23108965350736, 52.12093730126658, 56.229384714557284, 52.30310001680928, 49.557738996321156, 48.330001831054695, 47.046700369927194, 45.66962288271996, 47.76515699202015, 47.11290605606572, 47.23651955204625, 47.465711485955026, 44.49514365965321, 43.942917085463, 43.56202356276974, 47.38330248863467, 43.39949230993948, 44.43923811758719, 42.72554674456197, 43.17229686244842, 45.27694263765889, 46.4683468880192, 46.767027531900716, 50.29090842893047, 51.545149049451275, 50.504693292802386, 49.70736172891433, 49.721937256474654, 49.969709457889685, 47.88666809758833, 47.97902422566568, 55.00165539403116, 61.84432821889078, 55.316970809813476, 57.47948331217612, 67.71167232144263, 54.85229546023954, 58.47233326204362, 62.96757736513692, 56.79559061604162, 58.20423926076582, 57.64680377898678, 59.68900149868381, 57.44767681244881, 55.274079691979196, 53.48843636051301, 53.803488977493785, 47.317367446038034, 44.753698456671934, 43.41877075933641, 42.362048933582926, 43.08654208337107, 45.36729835694837, 44.589374680672925, 44.0084755805231, 41.462339585827245, 42.577116412501184, 40.75606192311933, 42.48865912037511, 41.15168786817982, 43.932911119153424, 41.285005307966664, 41.49561697436918, 45.41341366306428, 47.304733491713, 44.264920142389116, 45.701354857414, 41.561587318297356, 40.15280139061713, 42.71810208597491, 43.7395735709898, 40.410995329580004, 41.095362632505356, 49.863562276286466, 54.71247865307716, 54.04859004482147, 54.39931269614927, 51.12319615579421, 57.693609422253026, 52.67875717532251, 56.02308765534432, 54.96318086501091, 53.43839868422478, 53.0066006414352, 54.394244993886645, 53.67902432718585, 56.066261183831, 55.45374778009231, 56.24868669817525, 53.24621431289181, 39.364020593704716, 3.6867825686931615, 2.2814399917279524, 5.019924852155871, 14.535058506073492, 17.897673114653557, 15.78836952486346, 6.650241834502067, 5.265077890888338, 65.78156417415988, 49.55197703453803, 41.623682360495295, 40.50027631944226, 56.211910555439616, 41.459182077838534, 0.2173202830336748, 0.2284698347531019, 0.1274355239565334, 0.28553144946213693, 0.14227873795936186, 0.16296050721599212, 0.2767955956439818, 0.16931249459664668, 0.18291896689803372, 0.13372164309745835, 0.174801284747739, 0.14218037226988425, 0.17231761237546322, 0.16361060942853653, 0.10687574654096559, 0.13221548359480598, 0.12579769692233495], [0.009298226514440632, 0.08154194666853837, 0.059193867228684895, 0.04041231012031917, 0.08634292775945318, 0.07230833488246126, 0.08620993489579809, 0.04111592740481419, 0.01833029493178812, 0.0232878701400853, 0.09216110507446913, 0.04128072823908541, 0.021443306618640502, 0.044681155047709906, 0.011450860803315957, 0.05353831888867482, 0.04650058705479868, 0.07805092230198846, 0.061992815425319064, 0.047307833052811124, 0.026119639458615455, 0.04813539570257549, 4.1765623131105984, 39.652816864752005, 40.59089091516311, 33.713979721069336, 39.969944415553925, 38.4989300850899, 55.307761084648874, 2.342167352476428, 0.11943764263583768, 0.09477071464061738, 0.38562184800544097, 1.5431908445973552, 0.10478821823433523, 0.06702946048350104, 7.393664833038085, 50.3350664723304, 56.82639691137499, 57.0075947238553, 55.02834712305377, 57.403138299142164, 58.96419455928188, 59.33845535401375, 55.755531018780125, 53.297032540844334, 54.76407743269398, 55.17902889559346, 46.62772455523091, 41.48406167184153, 42.69069256321077, 44.609590576541045, 46.2164326637022, 47.04715536486718, 51.61878762706634, 53.10585229627548, 52.70979881286622, 55.59577680403187, 50.434506400938965, 46.15148213601882, 41.109553767788796, 41.62836174811087, 41.108859508268296, 41.8445667143791, 42.61979964471633, 43.0271730884429, 42.63229631608532, 41.31665491288708, 41.50943156211607, 42.01702940848566, 40.568945254049, 41.454514457333474, 39.168925823703894, 39.50111527596751, 42.342707726263235, 41.257368287732525, 41.37683583844093, 45.981039462550996, 47.81364533209032, 44.671273769870886, 46.837379163311375, 44.472009520376886, 46.28221865623228, 44.42370945407499, 48.194809498325476, 49.70504753051266, 54.95478699284216, 55.380266097284135, 49.535291271824995, 15.891475888990588, 57.4334817547952, 76.33551305340183, 48.46968527763121, 55.369357985834924, 52.84414783600838, 54.146845417637984, 54.57590172367712, 54.628469328726496, 51.769336039020175, 54.81209508834347, 47.78603576844739, 40.87476461164413, 38.47498793755808, 37.67130605636105, 37.83144466338619, 39.104618564728774, 40.00934854630501, 38.47986344368228, 37.028370749565866, 39.72887554476338, 38.6694041375191, 38.33318248871834, 37.24916881130588, 38.773123371985655, 37.989524026070875, 39.653781767814394, 41.773905215724824, 46.290357574339836, 46.623508007295676, 45.8864515058456, 43.26692012048537, 42.27648242827385, 38.944511336665, 38.530642447933076, 35.49075457357591, 37.29910842833981, 36.0576194332492, 37.54538228434902, 42.328544047571, 44.32798008764944, 45.63380772067655, 52.242067936928045, 47.6452148345209, 45.76193586472542, 49.5150165404043, 50.88348442508329, 51.514181936940844, 50.32287966820502, 51.856714679348855, 52.10931531844601, 50.50521104566513, 53.08939795340262, 52.977994795768495, 49.47816587263539, 18.50937851013676, 0.22427211725904098, 2.502491536640352, 7.502725355086788, 7.7164665825905345, 5.832189369586207, 2.029023581454831, 0.24645393263668786, 19.101980001695697, 50.427124500274665, 29.300691581541493, 60.37150959814749, 31.536507298869473, 40.95728735769949, 10.55661020740386, 0.4220544462723117, 0.19062581141629528, 0.07860679569984637, 0.05655715730221522, 0.03996574980837684, 0.05811012094660152, 0.050257340509204135, 0.028578906184843475, 0.027408567069458867, 0.050914502221970796, 0.06812418480553935, 0.04942639558125408, 0.02796539616200232, 0.040979942967814785, 0.03787656675183004, 0.041256136816716006, 0.014210090213905902, 0.018653428903029814, 0.10072690269519245, 0.03802731753356996, 0.029579058867849173, 0.0660504001162706, 0.009782559749099516, 0.022851517949734005, 0.08390316754699716, 0.05343444885746126, 0.05018616328015924, 0.04193980900210239, 0.048098619651770404, 0.04707895279411347, 0.043180576495585904, 0.11000627291298683, 0.040632422502723434, 0.022664209452247428, 0.015154495636271614, 0.015326843394206898, 0.014181103362070938, 0.08885037950089864, 0.07776351675631539, 7.884253811451697, 53.75398474354898, 35.55232401817076, 39.8962156234249, 48.88708822188839, 47.48998703495149, 55.68971364728866, 1.6594052795440921, 0.17659848105282555, 0.09575563558046857, 1.1961582855832193, 5.40751729280718, 0.8371281768045119, 0.05821786355227233, 9.6459319514613, 50.65022499330583, 60.49284811942809, 57.54106844625166, 56.89786641828476, 60.09910098968014, 62.32598350894067, 60.15926230338312, 57.31552039423297, 56.178036966631495, 56.76061876358525, 57.065359469383, 50.62144656335154, 42.96359539031983, 44.49501814380769, 45.32661161115093, 47.60446140843053, 50.305625161817, 53.556677756770966, 52.98256435701924, 54.51430874486124, 56.782446753594186, 52.00130893338112, 48.21520582322152, 41.955032425542036, 43.830019504793235, 43.147989934490575, 42.77863210247409, 44.62614690103839, 45.52313020152431, 45.29011395669753, 41.5997088340021, 42.44257519322057, 42.58671837468302, 42.63988217999859, 41.85095233301963, 40.75461064615558, 42.335329747969105, 44.957865668881325, 42.23017884838966, 45.04762126553444, 48.45004597017842, 49.62549401867775, 47.34570264816285, 47.73714342424947, 45.655478815878595, 46.88083902482064, 45.33655481953775, 48.032948970794685, 49.883225117960286, 55.50400118674002, 57.117346563646876, 51.367418612203295, 19.77223461674106, 47.329840583186, 73.15859717707481, 53.19511367428688, 55.795982422367224, 55.88693826429306, 56.35539870108328, 56.302215283916844, 55.89063705936555, 53.785022458722516, 55.441113825767275, 49.64016760549238, 42.836298788747484, 40.11325605453984, 39.13873926285775, 39.863867836613814, 39.8249775363553, 41.085199771388886, 40.52368110226047, 39.89641566430369, 42.0541311079456, 40.44182908150458, 39.73632020335044, 38.65605631182271, 41.17427679800218, 40.14354459701046, 40.323157771941155, 42.07424502218924, 47.956003835124356, 47.163488941807906, 48.38020032451999, 44.0968858042071, 43.58168640444356, 41.74264392545147, 40.11136547211678, 38.21673516304263, 39.30949572593936, 39.70002258977583, 39.61736648313461, 47.301156290115856, 46.29207557247531, 48.37223399070002, 53.795448118640536, 49.22525536629462, 49.65412732093565, 52.00385455162295, 52.90971025343865, 52.98695741161224, 51.49085560152608, 54.00374558664138, 54.33579775594897, 52.32618708764353, 52.28812440749138, 52.630543401164395, 49.253782764557876, 21.14536619955494, 0.5956909709399747, 3.4705145993540367, 7.411845018786769, 7.134688381225833, 7.28043532179248, 0.6806331452342772, 0.5166144560902349, 20.91011224254485, 56.232965838524606, 35.255863435806766, 57.029724736367505, 30.626278154311645, 51.72204794422273, 13.808116816705274, 0.49109251268448373, 0.18756843111928434, 0.041449926418041995, 0.05704351971226354, 0.05200392138513346, 0.06932164917910291, 0.1535995716168996, 0.022411523011302757, 0.02026978057749089, 0.05018525546596897, 0.02356483773779004, 0.011055627424690512, 0.06682568875652167, 0.008225271538380654, 0.07316509697345958, 0.018655129618221716, 0.03301602615524204, 0.06634428676578306, 0.20189125691690754, 0.16048460297526854, 0.1525023651699866, 0.15636913268075836, 0.12388317425164486, 0.14346657260771722, 0.17174033448100093, 0.14274009142912206, 0.18325619880230198, 0.2302433282978112, 0.15680846878357474, 0.1518653783827059, 0.14873511248057888, 0.17503314891890173, 0.14259349284393175, 0.10610448752319622, 0.14558229294996108, 0.10425966353185716, 0.12396282441313229, 0.22231925188774065, 0.31670249457801547, 8.955026057458694, 60.57984628985005, 51.58674970749886, 44.51532817655995, 50.18475732495708, 49.4671126334898, 63.96182760115593, 4.621577272492071, 0.6093894197575508, 0.1850330784556366, 1.4887700422156243, 4.089514867913339, 0.29253140933090643, 0.14235415165462803, 9.249435240222562, 53.892044328874164, 59.99597795547978, 62.4199438864185, 60.178654501515055, 64.13857352349066, 62.77793861204579, 64.0982594028596, 58.55523647800569, 61.21575663166662, 56.8423060447939, 59.50171616769607, 51.60673418352681, 45.529186341070364, 47.313994207689845, 49.33307739996141, 51.18284756137479, 51.19361838986797, 55.69289468949842, 58.3511673250506, 56.135624377958244, 60.946795786580736, 56.00696279156593, 51.81753804606777, 44.46357250213624, 46.20216700338548, 45.93552820144161, 44.98743641761042, 45.50400080219392, 47.47154012803109, 45.98664845189741, 44.02875815668414, 45.15077960106635, 45.57556052361765, 44.21996978021438, 44.517348197198686, 42.36308051693825, 43.66764906914004, 45.874998184942434, 44.21155629619476, 45.26517552714194, 51.710896645822835, 51.87387504885274, 48.95964422533589, 49.133373845008116, 49.13110279267835, 52.10317680912634, 48.69477833470991, 50.45218452330559, 52.78007984161378, 56.67135346320368, 59.60361934477284, 53.613101051699736, 26.384389746573667, 52.69834549196305, 74.9203218952302, 54.29084347140405, 57.62417954783286, 57.71982262211462, 57.422499118312714, 62.37167912144815, 57.61074542999268, 57.91786309211486, 58.66990696999335, 52.43572711944581, 46.81522561657814, 43.229532088002856, 40.50517143741731, 42.93965324278801, 42.27914179525068, 44.32586200775639, 42.10892269688268, 41.516178038812455, 44.33524431720857, 41.932553322084495, 42.55065218094857, 40.517071908520116, 44.223311639601185, 42.478755135690015, 42.35350208897745, 45.12367602317564, 50.801032281691036, 49.200748397457986, 51.11899137496949, 46.933704730003114, 47.74766322105162, 43.77591825300648, 41.547874712174945, 40.53949217642508, 40.888610578352406, 41.06223429402998, 41.66136457074074, 48.51398844872752, 48.53058007455642, 49.78444414754068, 57.04532008017264, 51.46147312656526, 49.83352868787704, 54.370247933172415, 55.43570095492948, 55.5639075463818, 53.87809245817123, 57.122449567241055, 56.27956359617172, 53.36903156772737, 53.47621033268591, 52.70603725987097, 49.99258079836446, 22.756014946968328, 1.3474119887236626, 5.980097045821529, 14.74140557550615, 15.924610111021227, 13.084196332962284, 3.6304994984980556, 1.3810450872105937, 24.151335377846998, 62.92261131348149, 38.30883633705878, 71.60344800641461, 40.09689977092128, 56.867593565294825, 19.818479361072665, 0.6027120135484204, 0.2992671301528331, 0.18752759863292018, 0.14826338618032395, 0.20353068507486777, 0.2435374052654351, 0.37151608556028337, 0.07798598868952644, 0.1744535727606666, 0.3304768167436123, 0.16512824492829462, 0.11843297194929854, 0.11705957548392397, 0.11942169268525417, 0.1910739422084824, 0.13642696002798696, 0.15492897931366198], [0.045588118880386316, 0.029394067786333543, 0.03238854268866201, 0.024584837843694037, 0.040849148776502385, 0.02480590783600365, 0.010164332962895354, 0.025408646662629424, 0.053090831610344114, 0.08204138236901454, 0.06613146754041796, 0.07237689209080513, 0.02579270952170895, 0.05690458200631603, 0.0452334814584784, 0.04769733896659267, 0.04364674099751058, 0.04912571373185323, 0.04915575586980389, 0.03427370887009367, 0.02181247864369183, 0.0669591336120521, 0.10829156129470757, 17.896729784627116, 48.32675018618184, 23.280447606117498, 38.97621193239766, 33.42076686120803, 53.9499738139491, 26.075689408086962, 0.29283943796350115, 0.22622913482689092, 1.0207327311077425, 9.803881875930294, 4.287871824156854, 0.21084889318914185, 0.8335857862426389, 26.61535655298541, 55.096439469245176, 58.91744382919804, 56.26194430935768, 58.56296746961532, 59.08401904567596, 61.38678766066029, 53.59617994677637, 54.593528855231504, 55.66697566739975, 52.772364539484826, 43.629115704567205, 42.118610951208304, 43.73746333583709, 48.619276631263, 49.864538946459376, 54.463223795736994, 54.856421793660815, 55.305407662545484, 58.12946711817096, 57.280693669472974, 53.1675394119755, 47.45292848156345, 42.06545891300325, 43.335483151097456, 41.626000481267134, 42.27991450217463, 41.289013970282774, 44.21531000444966, 41.71228478031774, 41.66957016914122, 40.66749480462844, 41.37177598091864, 42.35359230349141, 41.09298959855111, 40.4282380688575, 41.404394411271625, 42.35619675728583, 42.23105745930826, 39.74942484209615, 45.38490979902206, 46.14690080765755, 46.552893577083466, 43.868301837675034, 43.41369128996327, 43.49475491431452, 44.53506162089687, 45.477214936287176, 50.18071336130942, 52.388117390294234, 57.719246033699285, 52.38970987258419, 52.27368616288709, 36.170054174238636, 33.56783613081902, 52.19886695185016, 48.24960500963273, 53.92149348412791, 52.37428711306665, 54.63944804283881, 55.54073026103359, 53.999030897694254, 51.023367912538596, 44.13398358129686, 38.871994556919226, 40.05228281021118, 38.189553137748476, 38.40894306859663, 39.41350913816883, 38.19650357769382, 38.34178032413606, 37.97689399411602, 38.75203670993928, 39.791880576841294, 39.042488221199285, 38.14269650366999, 37.45068057890862, 39.36380878571541, 39.396733160941835, 43.450498811660275, 48.35328502039756, 49.58601928526356, 49.660803194968935, 48.01498843777565, 45.696447972328436, 43.67032412559756, 40.69906988451558, 36.76778416479788, 37.404918286108206, 36.99271248232934, 37.089253779380556, 35.52010566957536, 37.41560674482776, 38.3390542768663, 41.50856079593782, 41.886237975089784, 44.23287437808129, 45.03795654542985, 48.50657124673167, 48.06779530740554, 48.12998840885778, 49.440193406997196, 50.410293609865256, 54.229477990058164, 52.32730888551282, 51.91446373539587, 42.572189915564756, 4.78945569645974, 0.40458203383511115, 2.2333007426031175, 5.611244218964731, 6.15208464284097, 5.056251393210504, 1.349271682481612, 0.08323412764096454, 36.72080985961422, 50.883170635469504, 29.320430909433675, 30.94574736010644, 36.869040150796216, 43.80097043129706, 2.677503771358921, 0.12103292114672162, 0.0942166032449853, 0.0564337520289325, 0.0745094204021077, 0.08517383928260497, 0.07097973923889861, 0.07135103907315962, 0.046431275249849406, 0.040600618362546935, 0.04532366915936432, 0.02582982839686015, 0.0628263535608928, 0.08263294014238542, 0.014276012079790236, 0.06769962653878235, 0.05119481762390464, 0.014088520678811738, 0.054038980329829844, 0.028385744775615396, 0.05320550348129004, 0.05644120606443575, 0.03153266734443605, 0.02258333355008114, 0.057749749356580365, 0.018955863178557446, 0.0405408175391776, 0.04728541348970706, 0.010589151699546604, 0.00878816517445469, 0.08990776469750751, 0.06303703157050956, 0.03323663266435747, 0.03735318697328049, 0.07616719636585444, 0.03354087299216659, 0.09955950727265689, 0.05168381154597287, 0.01866929649916147, 0.03636699432747499, 0.28053045813595096, 27.148638079243323, 53.21156409478957, 23.24008837822945, 47.73968512012113, 37.320591249773585, 64.21751906794887, 23.637587255047215, 0.3058403484042614, 0.04587860409951499, 0.5684417137695897, 6.570726565776333, 6.874236627932518, 0.3530126413510692, 1.3813387746772459, 30.983076557036373, 55.78818082809449, 61.60548333198794, 56.34028973117952, 60.88793277740479, 60.93586414091049, 62.776589316706506, 55.10491963355772, 57.77657147376769, 57.741191694813395, 57.25899904004989, 45.497877982354936, 43.89569174858832, 45.136306055130504, 49.867178701585345, 51.515213520296165, 56.32782051640173, 57.23450383832378, 58.306201273395175, 58.79536005758471, 57.413705164386386, 54.80721173747894, 50.424775000541445, 42.55193087362474, 43.7572556157266, 43.008643811748875, 43.69589013438071, 42.64912328412456, 46.3660514739252, 42.49352285938878, 43.94668256082843, 42.67642298052388, 44.53166877069781, 43.11449681558917, 42.38923095887707, 41.706922900292184, 42.9168015141641, 42.62454179025466, 43.42600360993416, 42.28117358299994, 47.12065273715604, 47.6534753461038, 47.61681295210316, 46.07853781792426, 46.60440214218632, 46.09332515347389, 45.680507459948146, 47.77379012876942, 51.70597799362675, 55.19773860131541, 58.76284753122638, 54.91379430217128, 49.43448635839647, 43.4668315610578, 39.79579510227327, 51.20707996429936, 51.01061236473822, 55.66329648417812, 55.340261843896684, 55.8403326619056, 57.25279777280746, 54.93679508086174, 53.03491623170915, 45.77197320999638, 40.136602001805464, 41.57328774852138, 40.88303689033755, 39.773547418655895, 38.794123741888235, 39.23092672901769, 40.24085467861545, 39.17222453701881, 38.48784938935311, 40.5074542568576, 41.1873657472672, 39.04368062173167, 39.716571069532826, 39.8166895681812, 41.648008900304, 44.4384850225141, 50.10307788848878, 51.28822203605406, 50.35460772052888, 49.56087297008884, 48.15121235386018, 43.156525011985536, 41.69430071307767, 38.20365405851795, 38.68206947080551, 39.038530549695416, 38.52124052663004, 37.45781929262223, 39.82691518722042, 40.287279851974986, 45.13182278602354, 46.126712368380645, 46.71210650474795, 48.037761718996116, 52.62993151141752, 50.43132535872921, 50.98388925675423, 52.18446008620724, 52.490663836079264, 55.13665553062193, 52.44535653821884, 53.150626151792466, 43.32453581594652, 7.023589207280067, 0.9520111509388494, 4.347221697530439, 8.933503031730652, 9.395712191058744, 5.4213725751446145, 2.1394876991548846, 0.11028653085832635, 37.991430297974624, 56.00125182059504, 37.51794138262349, 46.36613384369881, 38.42354213037799, 53.18653937309019, 3.8727151722677298, 0.21634011949983337, 0.07633166012143897, 0.030280877760941946, 0.04470179345639003, 0.037511108337991664, 0.08041815697065285, 0.04068810177306014, 0.017286097938795725, 0.060260345888954986, 0.032018378579748735, 0.026251873895225507, 0.04662575433030725, 0.07071821980418698, 0.03093191651597379, 0.023047264905706532, 0.06250474985027987, 0.012697542495574924, 0.17127429255314414, 0.16078377563145854, 0.11204559896742144, 0.2544654503224358, 0.11997379693052462, 0.08966754250709089, 0.21549604382486115, 0.12265289833228435, 0.18242779728626052, 0.219205119797299, 0.2189989042498412, 0.22017544676219264, 0.19032559688052825, 0.1532459760745687, 0.23344528470789236, 0.1627270342601884, 0.22771381322414647, 0.13800459553397473, 0.1694879593748239, 0.12426520697772504, 0.09068291544193223, 0.20307711505841827, 0.3113637810512897, 31.53091596018884, 62.059862459859545, 30.872573583356797, 52.28326066847771, 45.00518906501032, 65.20238307214552, 33.84225691518476, 0.5624640216269802, 0.3764792627865269, 2.3321496190563327, 20.723074020877963, 8.720325154642905, 0.3841467303854804, 1.475599826343598, 29.839058460727816, 58.597190149368785, 63.33444056972381, 59.88901099851055, 64.23510697580153, 63.38405463003344, 64.73633489301129, 58.44612006218203, 60.020555526979514, 59.910034902634166, 57.38365588649627, 47.803309886686264, 45.855084311577585, 48.81977250499111, 53.68738289802305, 54.48978216417375, 59.23381436255671, 59.27615634856686, 59.56989088366109, 62.23002272267496, 60.71302644668087, 58.325134554216945, 51.79745943315568, 46.09569818742814, 46.61850698532597, 45.58801404891476, 46.22816839525777, 44.18316618088753, 48.295206485256074, 44.94538076462285, 44.474527682027514, 44.74595569795178, 46.6517137712048, 46.10948139621366, 44.96778926541729, 44.79179251578547, 45.11372889241865, 45.895343519026234, 45.80854146711288, 44.26745007115026, 50.917130516421416, 51.271967734059984, 50.990070912145804, 48.65560562379899, 48.221465926016535, 49.52123741949759, 48.74369421312886, 47.53034822402462, 52.4253995187821, 55.29794731447774, 60.05769645014117, 58.075577674373505, 51.92236338892291, 46.911508037197976, 44.29289840882824, 50.43790709587836, 49.229593507705204, 55.27038481927688, 56.8474208154986, 58.07428329221664, 60.575115911422245, 58.01059969009892, 55.478976465040645, 48.50207228814402, 43.60281229019166, 42.938131363161155, 42.48630177590155, 40.46293927777199, 42.06911456200385, 42.52025381211312, 42.43122385394189, 40.838117907124186, 42.114080613659276, 43.11399475220711, 43.58039594465687, 43.33726782952586, 42.50754141038464, 41.00592474783621, 44.79116885892807, 48.25783806462442, 51.68316156633439, 52.32331983504757, 52.19413265105217, 52.638207712481105, 50.16608292056669, 45.1331603142523, 43.517151647998446, 40.98342995489798, 41.42655188037504, 40.631330551639685, 39.79587354967671, 38.97696502747075, 42.87570291949857, 42.03953596853441, 47.37956446986045, 47.50027541191348, 48.70239557758455, 49.93274896375595, 55.832633049257346, 52.21215594199396, 52.64353429117511, 52.13009603561894, 55.09491758961832, 56.858807456108835, 54.15633363108481, 52.56410629518571, 44.87791207528884, 7.3542891394707475, 2.026148851840727, 6.120224700820062, 15.409462682662474, 12.421253015918117, 11.555385878009181, 4.701415156164478, 0.2614617636126857, 44.57729770291237, 63.09753725605627, 38.66267727267358, 45.19889923834032, 44.89544506995909, 61.831160822222316, 5.537839512671194, 0.5454714560220318, 0.23191808843083922, 0.1820236552626856, 0.17420411921076237, 0.18017346099499734, 0.13560914584705908, 0.15791650771373705, 0.12593947681448153, 0.11711815822749369, 0.08525119118031957, 0.15082337623161657, 0.12178044676059678, 0.2465032686990115, 0.21604183550563552, 0.19994773781828343, 0.1838704174564731, 0.12114775006569202], [0.03802691150697009, 0.02730210574584142, 0.04053752719154281, 0.01250753353815526, 0.014808574379722198, 0.07406749492210728, 0.04649308705401998, 0.02827884678188111, 0.01491541970491169, 0.03880962736964707, 0.04889677984700088, 0.056062578599178986, 0.02846065093763173, 0.014441475580115954, 0.04907440116268493, 0.030788119897366534, 0.045666420727127024, 0.03775688849629895, 0.03730297757072314, 0.016409074737420006, 0.029890272510989063, 0.07753526852015527, 0.15781650259610147, 4.8135081606526535, 40.35474461893882, 37.45574435880108, 39.579492076750725, 40.01262764776907, 37.6017310542445, 50.14235258102418, 1.29405990963982, 0.09267735640488325, 0.5700210806342864, 5.752851097814499, 3.5563644959080607, 0.5389389936481753, 0.11232000400101948, 7.676290725508045, 44.73648709635581, 54.28637589177778, 59.719776415055804, 58.066309113656324, 61.40732126851236, 58.19362140470936, 56.41275552011306, 55.77199712876351, 55.861038854045255, 49.18495693514424, 41.05189100388558, 42.189688221100845, 46.64459074697187, 53.619043442510794, 53.666107962208415, 54.21106246209914, 55.49266161457185, 56.350170181643584, 56.51156394712387, 55.232275070682654, 53.12594267629808, 45.79859433635589, 40.705855584913685, 41.33075191128639, 42.93518566316174, 40.509101652329974, 40.8277589274991, 44.27191372840635, 42.73823561206941, 41.394945421526515, 42.097324248283144, 43.43819041405955, 41.406284993694676, 40.602414838729366, 42.0473022614756, 42.0809797317751, 42.02049286134782, 41.75816474422332, 43.157368321572584, 40.79814111032794, 43.949110507965095, 42.53996764459918, 42.99931249310894, 44.050448863737046, 43.906250769092196, 43.45171474641369, 46.19857411230765, 49.742596380172245, 52.62049428878292, 53.4614190747661, 55.08320539228378, 51.96616841900734, 31.806301647616973, 45.49741122030443, 51.889427246585974, 52.46578031970609, 56.23145964837844, 55.86102708693474, 55.66084108045025, 52.22999488153766, 50.183274669031945, 43.82485374327629, 38.597263905309866, 38.48235414874169, 40.22989165398383, 38.81846597117763, 40.83532910193167, 40.33374817140641, 37.981196834195046, 38.68325402659755, 39.039456229056086, 38.77601415880265, 38.42020811573152, 37.54641386770433, 39.0710352313134, 37.701869164743734, 37.890076252721975, 36.610783453910585, 45.78805885007305, 51.491004651592625, 50.17594375917989, 50.44210795433291, 50.61548848305979, 48.589172440190474, 47.303890182125954, 43.386634780514626, 42.906932830810554, 39.51134481737691, 37.02659783824798, 36.24034304772654, 37.24694090504801, 34.509240273506414, 35.039929113080426, 34.392216359415364, 37.95887070317423, 38.73066763724051, 39.967163455101755, 40.52077462596279, 44.46024240985994, 45.329294512348795, 50.26116117354363, 49.21431195351386, 53.501427250523726, 49.8764080386008, 55.12998357895882, 25.98893246343059, 0.6333576755658273, 0.7567822236207224, 2.5546396932294293, 4.977886849834073, 3.1501878653803184, 2.5030840596845074, 1.0227107088412009, 1.8683048313663853, 49.869500744727354, 36.265363847055745, 31.00501241222505, 21.25852854021134, 35.65575691961473, 25.534672967849243, 0.14192941718764845, 0.025207688393551978, 0.03580412271642878, 0.023790469783688747, 0.02726121963332257, 0.09635486955484075, 0.026278223489381136, 0.04288720695542232, 0.06931396531722239, 0.05584463424560043, 0.03247791833634819, 0.07813379769363711, 0.05021771844176035, 0.04301894726532121, 0.03860950222118728, 0.02368935383856297, 0.03568538674904454, 0.07673433125619927, 0.00713759474644077, 0.0948758831908626, 0.016668742154574683, 0.026639426284800136, 0.03656760211132708, 0.013834857475763608, 0.014102806303379758, 0.00824313766638478, 0.02018702009903087, 0.024455208106026537, 0.01616811901781588, 0.03818128205415222, 0.03691070607953495, 0.06276590156278784, 0.03385576960300246, 0.038812549995078195, 0.041702911633277134, 0.042082749517454256, 0.03830136250584357, 0.030233589068595922, 0.12569094257008645, 0.03808699961331102, 0.16002911773900833, 7.435955337939724, 51.615622274337284, 30.965908342792144, 40.86248367063461, 48.21800247315438, 45.63587873212753, 54.37344466486285, 0.8204262956015526, 0.1223447164821048, 0.7407589737446078, 3.5506750979731163, 5.390017638283392, 2.5962452542397285, 0.23158949799835685, 10.8762716093371, 46.158585548400886, 57.05451019348637, 61.71095586592152, 60.02308153337049, 63.060698355397875, 57.973278337909335, 57.82542459426388, 57.728016453404585, 58.12241469660113, 51.96252845948743, 43.12448709241806, 44.18907327036704, 49.51340836863364, 54.14000872642764, 55.716915284433675, 56.748471183161584, 57.64860806926605, 57.89643518386349, 58.507622826483946, 57.05920134821246, 55.872625535534276, 48.84187898328228, 43.10389072664323, 44.048930906480365, 45.11395638988864, 42.01813943924443, 43.474154626169515, 46.33236615888534, 44.9345903242788, 42.45985323382963, 42.235901586471066, 44.41799456073392, 44.3353541435734, 42.81797347530242, 43.59055880577334, 43.46271699474704, 44.11879616398966, 42.77954601472424, 45.36987927652175, 45.91387279572026, 46.63119193046324, 44.08178467904368, 43.56289825131817, 46.3293263220018, 45.58583713346913, 45.96344763232816, 47.415614974114206, 50.50174759280298, 53.238463709431315, 56.408809615719704, 57.71202102784188, 53.94918541754446, 30.632685345988122, 45.1258215596599, 51.246684135929236, 51.83131341011294, 57.34651496333461, 56.15651099912582, 58.16059112548829, 54.941815714682306, 52.14259662935811, 45.21037609346452, 40.00241771821053, 40.10275586958855, 41.385978883312596, 41.04367756074475, 42.71461509889172, 41.26897458107241, 40.24452993946691, 39.62981216369137, 39.442821010466545, 39.919008516496234, 40.53635035791705, 40.24479666063863, 40.441821236764234, 40.35646261707429, 39.501189801000784, 39.27923856243011, 45.8397949126459, 52.07914052471038, 51.55266431070144, 52.14472255399151, 51.404610526177194, 50.2714652399863, 49.197339857778246, 44.97761480269894, 45.63489421721428, 41.50807049966628, 38.35373178605111, 38.34955446181759, 38.130756808865456, 36.45703831026631, 37.327051393447384, 36.633890136595696, 40.13224032617385, 40.495318443544456, 42.616673515688994, 43.96676901848086, 43.85298890452231, 47.539773679548695, 50.902300034799886, 51.119446369909475, 54.071394705003314, 52.42670959041965, 54.37904580946892, 28.512891377172163, 0.5999969366577365, 1.882877907445354, 5.418934331786248, 5.66526064949651, 6.344164581068101, 3.637922093752892, 0.490725954934474, 1.810839411712462, 56.919580659558704, 42.62580479345014, 35.713690327059844, 21.330455003246186, 38.82875434813961, 33.39025866600775, 0.09101250178871617, 0.014063269463217547, 0.025439987319611737, 0.0615642543491577, 0.07573614933437879, 0.02766493839331933, 0.08699673017667187, 0.05209664866748837, 0.025791162024101904, 0.07016631474177684, 0.07300783444436328, 0.04785435251711358, 0.01647493340105059, 0.03969438614383821, 0.07323596010645551, 0.0606407200346791, 0.02726613600257664, 0.042673353511359424, 0.1257148598350825, 0.23258217940888098, 0.1118701801545197, 0.05363465827559272, 0.10566624692611157, 0.10521119835996821, 0.15330396893043674, 0.10185015613153096, 0.12010108243914382, 0.22497305706624063, 0.10103026585232827, 0.144916424647935, 0.11324096426007249, 0.16332712625303578, 0.1072216505605367, 0.09973429023258149, 0.13524631128436135, 0.17046868981372926, 0.16493710599118666, 0.15438162481352208, 0.18218804240947772, 0.2123489239884, 0.3531385862058209, 9.447219775569055, 57.61344402067123, 46.23053750684185, 49.32013357839277, 50.91488692068285, 49.167961305187596, 62.206213935729004, 2.024208872068313, 0.2560599550845162, 2.4365763510427167, 15.376599104173723, 13.32440620468509, 0.8880660370472939, 0.6892329418370802, 9.128343828262823, 48.57070984378938, 56.473077650993105, 63.53131609578287, 59.985093378251605, 65.70359529987459, 60.49374241982738, 60.548553620615316, 59.82384474046769, 60.22047481229229, 54.67882863936886, 46.690827646563136, 46.47677998388968, 52.042944892760254, 56.91898838166268, 57.8328182620387, 58.33135151094007, 60.82586519179806, 60.40551654754147, 60.770391110450994, 59.19956422621205, 58.85683536529542, 51.56970700910015, 45.51669751444171, 44.53885455285349, 48.1258620754365, 43.29655754950739, 44.85495444267027, 49.390900981041696, 46.195797074225645, 43.94610989478327, 45.567480441062685, 47.7556295548716, 46.201880670362904, 45.38360757212485, 47.61248265543292, 45.59410941216254, 45.78673701132498, 45.932119661761874, 48.13371073815131, 45.90461207974342, 49.247738392122336, 45.9496565788023, 45.20450430531656, 48.14684283348822, 47.87443814739105, 47.35101353737616, 50.303471780592396, 52.215662540928015, 54.994893227854085, 56.962993452625895, 59.483445767433416, 56.38100785593833, 36.54436988215293, 47.583931722948634, 52.396958412662634, 55.35113857638452, 59.17839519439205, 57.733703890154445, 59.59762204077936, 56.79936001377722, 53.900704922214636, 47.63712690722558, 43.19885915325534, 42.997747467410186, 43.695827376457956, 43.89557015511298, 44.311310014417096, 44.97415527220696, 41.96388129265078, 41.33153638532085, 42.51608041024978, 43.36970975322109, 41.28388351009738, 42.006113452296105, 42.26912798420076, 41.90000941676479, 41.80699825286865, 41.87700079333398, 48.75379823869275, 55.84218794299711, 54.658636277721776, 53.14682145272532, 54.657141854686124, 51.30107564310874, 53.61675277833016, 46.8462319527903, 49.60854937953334, 43.111460901075795, 40.088321547354425, 39.963562719283566, 41.80002427870228, 38.975741247976984, 38.933203143458215, 37.79025193183653, 42.35301179270591, 42.98102248099543, 44.681299348031324, 45.33238926241475, 47.633494792446015, 49.80347156524659, 53.70391568829937, 51.0089296679343, 56.82210583840647, 54.79025140885384, 55.6058886743361, 29.883897035352646, 1.2756067514419556, 2.3380662693131358, 8.052860815678875, 12.789461593474112, 6.841242630635539, 12.879173063462781, 3.2118364928230165, 2.504142854482897, 61.23899667493759, 46.72187712884719, 44.03533204909294, 29.889500141143802, 48.11788005213584, 42.93008265956756, 0.2952510827491361, 0.12302690245691808, 0.11878979272179066, 0.19078618426236416, 0.11112364279406686, 0.10668037879851558, 0.1148805532964968, 0.09870736469184199, 0.29706003084298105, 0.13481796088237918, 0.20436346861383609, 0.15002181843644188, 0.11431022381950771, 0.19196622013565035, 0.1758201050782396, 0.27905423734937945, 0.13355063695100047, 0.18784947813518588], [0.01868729381972263, 0.08449949038725707, 0.0244380381604236, 0.01697716149201076, 0.04158263199872548, 0.029977167949020386, 0.07085723411892692, 0.014227531163112052, 0.03928522624435925, 0.03180248925702707, 0.024657740685788375, 0.01847550115217605, 0.01841078970521208, 0.05519215716049076, 0.009029251129005947, 0.029318006746771357, 0.04718868339794779, 0.04441345328344934, 0.029222295551951376, 0.05079929025903825, 0.03871378977031958, 0.057722369374166575, 0.04408657505747773, 0.3355245394331794, 21.95592203447896, 51.647695495236306, 27.916442040474188, 35.100031591230824, 32.37712613997921, 45.76484234102311, 19.834149229911066, 1.2142884611122071, 0.645843866852022, 3.373299880373863, 3.880805305896267, 5.837963588776128, 0.18020859378720486, 0.9425300467879543, 22.027530785529844, 50.105862771311116, 55.236162139523415, 56.920329832261615, 54.893750990590746, 54.715969562530525, 58.40034600227111, 55.5075313198951, 51.712500895223315, 42.99052246155278, 43.56607929352791, 46.93910191136022, 53.3847681168587, 54.506565986141084, 55.66499487046273, 55.73473461212651, 59.47106284479941, 56.539346095054384, 58.74442415852701, 55.34135618517476, 53.57165728845904, 41.23787803034629, 43.4633602634553, 42.73642739941997, 40.83467014374272, 41.87692234593053, 43.03011878844231, 40.990015614417295, 42.838691434552594, 44.53242578814107, 41.964359821811804, 40.96060568286527, 42.05158548970377, 41.58738082455051, 42.31636901055613, 42.38293947712068, 41.44348083003875, 43.445054561861106, 43.427498032969815, 45.54975525025399, 49.08624656738774, 46.611886024475105, 48.064363233504764, 44.01090352765976, 43.76257827205043, 41.922515976813536, 44.322096532390965, 45.14237788415725, 52.36876049349385, 55.36374899648852, 55.424443752534934, 57.8036593621777, 55.31650797013314, 49.58180665969849, 54.55060243606568, 56.64398708651143, 55.03724698097476, 53.49662626943281, 48.972246800699544, 48.34820947339458, 43.340550853360085, 38.91901985291512, 39.52740692323254, 39.59888427488266, 40.983190690317464, 38.547222306651456, 38.74831438064575, 38.9009573382716, 38.859607711915054, 38.46559386099539, 39.042935371398926, 38.78258020647111, 38.885048204852694, 38.03172480675482, 39.786597144219186, 39.80666399002075, 38.52523349946545, 38.318665796710604, 45.9458597244755, 51.34324896720148, 49.927336092918154, 50.51641725724744, 50.745538588493105, 49.183827292534616, 49.1032539644549, 47.794484553798554, 47.23037712035641, 44.60253815497122, 44.59858440583752, 39.039491530387636, 36.70078615988455, 36.337833558359456, 37.41860343563942, 37.23580921849897, 35.187049373503655, 36.31959061468802, 37.221096407982614, 40.15773180992373, 42.90385769259545, 41.33771411834225, 43.93242082288189, 48.62867463019587, 52.34991350481587, 53.8586296573762, 52.12371826171876, 16.88302459255342, 0.20317221721333845, 1.4634615615490945, 3.8088102013834066, 4.688733152804836, 8.302797675132751, 1.9474081286499578, 1.26796156167984, 12.817580084646902, 39.62273620790051, 25.194224965187814, 42.09502966173234, 33.02320718765259, 48.86157320391748, 9.892161680806069, 0.16951106458662019, 0.10229058007919982, 0.015606989299187498, 0.042915632647852746, 0.04859990162414409, 0.058585045663940336, 0.036843715520996245, 0.07064478261576546, 0.011318919395336942, 0.0949490292658729, 0.025992323306479284, 0.05002705830960505, 0.005713272586299648, 0.055666737138263644, 0.031073087368220575, 0.013055042213489933, 0.03336510943969892, 0.06245760862985927, 0.04900177219702352, 0.05426927785118742, 0.019882601655779347, 0.06212162544890758, 0.04357562505549962, 0.015179034390096224, 0.04615071469977979, 0.039599981128929124, 0.0421429448761046, 0.09527292357937944, 0.037991292248930664, 0.0723075917771747, 0.016499390758033243, 0.037547531988351576, 0.008184213056078842, 0.016389681221616846, 0.05258280040335752, 0.03141999113253288, 0.02885714740372233, 0.013508924410768576, 0.045805277993842486, 0.09850450460949252, 0.03213982458316511, 0.7396989532055394, 30.207927957657848, 55.55762783173592, 30.607984219827962, 45.61205425570088, 37.667724932393725, 55.82858516323952, 16.252615374903527, 0.6879471398649678, 0.628402802732683, 1.6395873816743975, 5.909682656488111, 6.182983604169661, 0.25088431103335274, 1.8844868146604108, 26.23107606364835, 51.74328365633565, 58.699293367324344, 56.46553101078157, 57.75183700746106, 55.078380876971835, 61.1941247601663, 56.83839936410227, 54.84200708327755, 45.52204762735675, 45.210434929017104, 48.39485037711359, 55.409660339355476, 55.10225242184055, 58.319717761008974, 54.849628248522365, 61.60819368977701, 57.86603289265787, 59.385782672512924, 56.3087813315853, 56.58654397533786, 43.856746535147394, 46.16585370033018, 43.534355163574226, 43.28771652713899, 43.83167082263578, 44.100364946549945, 42.700270991171564, 45.18885404832902, 44.13142227357434, 44.93858329711422, 43.82599907536661, 44.51288061757242, 43.22893196536649, 43.637815521609404, 42.361252692437944, 43.74919514502249, 43.692034444501324, 45.324568056291156, 47.15074516111805, 49.81366580532443, 47.92932779558244, 49.34869627798758, 47.396414972120716, 44.28055863226614, 43.83607172196911, 48.04133107585292, 47.589172009498846, 56.2554096406506, 58.041453053874356, 58.605646779460294, 56.6032297380509, 55.09283481105682, 48.2385439257468, 55.60337835742582, 58.564709001971835, 55.89376318839289, 54.761704398739724, 53.75725992264287, 50.8426917752912, 47.49961253135435, 41.75723514249248, 41.414165035370864, 41.58365065051664, 43.57797191989037, 39.74027003011396, 40.99852715769122, 40.82429155226677, 39.898863223291215, 40.19636715612104, 40.12853368636101, 38.621853243920114, 39.14654085713048, 40.926673258504565, 40.72709521939678, 41.44362595773513, 40.07549147452078, 39.28371006442655, 47.14786614141157, 52.94336026714694, 53.46490213947912, 51.91713486948321, 52.41939437004828, 52.34404956140826, 50.3586438394362, 50.16101521830405, 48.20311707835044, 48.44363681731686, 45.00653051560925, 42.37957016114266, 38.31650064837548, 38.2122754281567, 39.67568820522678, 38.33717546155376, 38.730640180649296, 38.301603486461026, 40.19548462283227, 42.52674141237813, 45.84445468841061, 45.22554389892086, 48.461095286953835, 49.701842954081876, 52.8424455273536, 54.97913706687189, 51.87167459918607, 17.733539573607906, 0.45481399002094425, 3.333390254166819, 5.796037374004241, 10.54932342421624, 10.185386307777899, 1.1575412029220213, 1.392915282518633, 13.926276256961208, 48.23597085091376, 32.97285964412074, 47.76458824834516, 33.74289151160948, 55.12403334340742, 14.240328669548036, 0.24164541324059813, 0.0474505590635442, 0.0182708905589196, 0.026523750838673404, 0.06287419575176413, 0.05332427009219124, 0.006914344755181622, 0.04004636141020925, 0.03929052374235565, 0.07742450752806279, 0.017576678918914932, 0.03128983470941744, 0.05588516029679487, 0.02918111449558168, 0.041791766341174805, 0.03413969327905967, 0.06415293439321461, 0.1285222656424007, 0.1039014025140674, 0.14847922379211073, 0.20590097643435004, 0.23949192476368722, 0.13221104028484515, 0.11628468520939352, 0.18800736885638009, 0.05914071987893793, 0.14246741009335365, 0.14157611275872878, 0.1841112601781084, 0.12233422107754216, 0.17037778582063415, 0.13514480463439418, 0.18508751666353596, 0.1338431906075247, 0.11700280070785554, 0.10597329496616319, 0.08794192945764912, 0.10883018239251069, 0.12403742605519873, 0.2518809301358077, 0.15045007690787315, 0.6926020126669639, 32.846259263253984, 64.2755623017588, 37.40143129902501, 47.53037175824566, 44.065581367861846, 57.496981005514826, 24.2927780074458, 1.502498705540934, 1.7322170950712699, 4.6029759222461335, 19.216262179036296, 12.580413972177814, 0.34573796235265275, 1.8696973953516254, 26.19027556911592, 54.66673204975744, 56.44279695326283, 60.04153236266106, 58.85487418020926, 58.60343456268311, 64.09779264080909, 59.99267531979469, 57.090913711055634, 48.30417694584016, 49.84077330558531, 51.721592949282744, 57.57507539564564, 59.25821934976886, 62.02166641912153, 57.91326215190273, 65.1394368756202, 59.94229639730146, 62.994947664199344, 59.436361635884936, 59.5384217077686, 45.06090633330807, 48.46990885273103, 46.17421619353756, 45.76947858256679, 45.10937898389755, 45.57415239272579, 44.88013605917654, 46.64646171754407, 46.71818617851504, 45.9155672596347, 46.94868818406136, 45.56356199326054, 46.20971364359702, 45.64652796714537, 46.4749913830911, 45.353597517936464, 46.22582281789472, 47.51569424906085, 51.954107130727465, 53.95949340635731, 50.78434259660783, 53.639686876727694, 49.80204382250386, 47.358658236842004, 45.854868581218106, 49.21667714272776, 49.86652758813674, 58.259991830395116, 61.64466781000937, 58.73342975493401, 59.38925004774525, 56.92464051708099, 50.648448159617764, 57.39918455000847, 59.559555438257036, 58.482805990403705, 56.82684406157463, 53.234164791722456, 53.72978371958579, 49.283263298773, 42.99253855982135, 43.26202892488049, 43.31657340449672, 46.36289396593648, 43.14983344847157, 42.528102474827925, 43.31929552939631, 42.47774708655573, 41.36400968797746, 42.16267093535393, 41.35874978957638, 42.50601953075778, 42.81572987956386, 43.283911828071844, 43.194693596132346, 41.74561708204208, 42.14653822683519, 48.27632811761672, 55.67611478990125, 56.03914583882978, 53.384332733769575, 55.263810926868075, 53.00486303144886, 52.95935177033948, 52.55569281116609, 51.28191878718715, 51.77221113635648, 48.380459200951364, 43.070170110271825, 39.18658825658983, 40.29962747327743, 42.34390012679562, 40.324118752633375, 41.234587161771714, 40.03510282885644, 42.5216737101155, 45.44495736399005, 47.49792591218026, 47.86982151769823, 48.838140964508064, 51.49318548940843, 56.14341028275029, 57.40968081258959, 52.761401514853205, 20.02456461229632, 0.6958519415028634, 5.31576717092145, 10.659132138375314, 14.377800879939912, 19.23545433628944, 8.101355039304304, 2.714007064219444, 16.98020523594272, 52.02578452325637, 36.16770467450542, 54.99430879469841, 39.844044177762925, 63.657067283507324, 20.223044387755856, 0.5382043459723073, 0.2074890154143495, 0.10120667291865235, 0.11573229751159107, 0.25513996009624773, 0.15049473983385872, 0.15300395357753002, 0.18400118866514775, 0.1432121088427882, 0.2192218511575653, 0.1358245084843328, 0.16678687124963731, 0.22993971233166036, 0.1371288957494882, 0.1532840812879224, 0.19844117994991042, 0.1691427601561431, 0.2831926136728256], [0.02564288953679704, 0.04037417809388811, 0.05747883768391706, 0.03666761105940227, 0.03542720362724316, 0.04884092437644159, 0.08178750083090798, 0.03752295588774066, 0.06453605879458689, 0.014183334593150406, 0.03646133039447089, 0.039418613643295346, 0.037026235968956066, 0.042036765089799324, 0.02424169940152957, 0.027645788110432126, 0.024915749522586985, 0.07099693025191946, 0.052835226374407934, 0.030757485956494367, 0.06879595964546166, 0.02306877856984014, 0.05039921233190164, 0.0480138213794318, 1.8332741433574309, 37.19208263581799, 34.722785872797814, 39.82677790426439, 41.03950415888141, 29.314886639195105, 40.16071673362486, 0.29601291122455753, 0.5399125994693849, 0.7869128294048772, 1.9338375858722197, 6.8028784182763875, 1.2849655266731017, 0.46317777025603485, 5.411612247267078, 29.850733395545717, 53.71751062331661, 53.0622394623295, 56.255182143180605, 59.34033024695612, 58.6374258225964, 54.92207050323487, 47.393202550949596, 40.39790245794481, 47.73658252531483, 54.71658929701775, 55.17394550385014, 55.99928671313871, 56.515368646191014, 56.54927753633069, 56.742442500206735, 55.26674878212714, 53.33402049156928, 52.10495756518457, 44.549476331280125, 41.14003058402769, 41.826994496007124, 42.922159471819484, 41.152111484158425, 43.04898146660098, 41.96386560317009, 42.50823566990514, 45.50638560325869, 42.92206141256517, 42.59471608746437, 43.00565888804775, 42.44654855420513, 41.845374722634595, 43.94430168213383, 41.1587324450093, 42.5084121765629, 42.38190789376536, 47.05707896140314, 54.15275250711749, 54.482867025559955, 53.12467575073243, 52.27609449817289, 52.81222366517591, 50.009717633647305, 49.254857493985085, 45.90309020011656, 45.70524584862494, 46.33464897832563, 51.8210603344825, 53.961129034719164, 53.97133504190753, 51.85465151263822, 54.627653475730654, 57.68547050414547, 55.046291966592115, 53.036116476981874, 50.57969293286724, 45.08737840960103, 41.988231366680516, 40.10455623749764, 40.426006240229455, 41.7066091106784, 43.07920332877867, 45.60560195676742, 42.97830427846601, 41.29199889398391, 40.88143264093707, 39.47080319927585, 38.577852095327074, 39.188914222102014, 39.287110759365945, 38.924142468360166, 39.323926125803304, 38.556741899059666, 38.23051444945797, 39.14443846671812, 36.561828351789906, 45.393495867329264, 52.42891396245649, 51.275764588386785, 51.51548024146788, 50.64824811873898, 49.77738780360068, 49.56006103946317, 48.639390545506636, 49.71693231213478, 47.47460742150584, 45.563895394725186, 46.0025458182058, 43.622431985793575, 39.75833646712765, 39.589329381142896, 38.74434494203137, 37.39068792712304, 38.12700310061055, 38.98499804158365, 39.72449033491073, 42.42768979841664, 42.0077294688071, 44.60300491702172, 51.04070478870023, 51.40414376412669, 52.19804325411397, 48.204011378749726, 5.126810910240297, 0.7793289879637381, 3.4708266729308717, 3.9877381872746254, 5.184962009229968, 6.7658875257738185, 1.1699893349601378, 0.1526511088013649, 30.50047793696004, 45.15543153209072, 28.20845465506277, 44.71400799289827, 44.1733524107164, 37.90544409905711, 3.0952602192278835, 0.2248934605309079, 0.021501762957702723, 0.13170016689165948, 0.027228852418521722, 0.12492447926272308, 0.017908720577496196, 0.030572688312179623, 0.05116141235996639, 0.08793233037595788, 0.06324655278736065, 0.03486282282298611, 0.05050579814480678, 0.02200458093636459, 0.035159521015180696, 0.04355777137642426, 0.034118108751793066, 0.05109020448740452, 0.020584393735794772, 0.03822456985231369, 0.012623145782028236, 0.03457758530613876, 0.028113446483809142, 0.0643911992289847, 0.02347374605315347, 0.10901603532294113, 0.03573584513017728, 0.05218750286486842, 0.06317712606922274, 0.1275695050736108, 0.03255155087719041, 0.022107301835691737, 0.03322970339908235, 0.0339218178733943, 0.037141022753090634, 0.03723556949426571, 0.06792002237371861, 0.022137424412874446, 0.05004328405184131, 0.017008283813934655, 0.0308148525354843, 0.04422252119008092, 0.045720069864464384, 4.164157327144377, 47.42022375906668, 34.81427123469692, 39.72382353198144, 45.66563383225472, 36.75572287651801, 43.055567126120295, 0.027066648622313817, 0.07687231901312068, 1.1155337215431276, 4.424205566606214, 8.87318286203569, 2.966068377417903, 0.9710157698681279, 8.046797321688745, 33.57236646836804, 55.54630394904844, 54.19097208207654, 56.97670998111848, 61.702444322647594, 60.426713035952666, 57.8217807123738, 50.03302435721121, 44.07263771180184, 49.32202416081583, 56.387601360198, 57.95358411727413, 57.50213892229142, 57.296951893837225, 59.70190609655073, 59.69055083490188, 57.34075692392165, 55.626190862348004, 55.26168500223468, 48.44670018842144, 43.038465592169, 44.02726373364849, 43.901885171090406, 44.29659328153057, 43.687927722930915, 43.31436903245988, 44.148770916846495, 45.78597607151155, 44.01831288491526, 44.03685000634963, 44.61940434671218, 43.755019864728375, 43.755698434768185, 45.59712571482505, 42.20995903015137, 44.119780678902906, 44.986318542111306, 48.55089010730867, 55.81260934952767, 54.986781766337735, 55.435496991680516, 54.117086395140625, 54.07979249954224, 51.32629256094656, 48.88792760910527, 45.68480245528683, 46.517596167902795, 48.878662970758256, 53.79292603461973, 55.62874432533018, 57.761156558990486, 52.31351783198696, 55.67260034622685, 60.4404648657768, 56.54395095763668, 55.006354393497595, 53.339103883312596, 49.529588145594445, 44.2531059634301, 41.45621676598826, 40.93527893866263, 43.02194064663303, 45.82906330785444, 45.95062932660503, 44.78650516079318, 41.42433966359785, 42.179152734818004, 40.479079831031065, 39.41695690155029, 42.09586512657904, 40.689613050030125, 40.236810714967795, 42.126487070514315, 40.427018211733916, 40.11339725986604, 41.0308200313199, 40.17790455971995, 47.59326304158857, 54.356001884706565, 52.47722579586891, 54.38020290866975, 52.266386631996404, 51.3607584276507, 51.339036341636415, 49.77506968282884, 51.026952958876095, 48.491721153259284, 47.73733169801774, 47.56827362122075, 44.90911060763944, 40.84936726477839, 41.473749760658514, 40.350610440777196, 39.613306830006266, 38.752872174785985, 39.244784462836485, 41.52595650765204, 43.79966820439985, 45.143542828098425, 45.98952747160389, 52.8220295906067, 53.565291281669374, 55.12259775592435, 48.92539408899123, 6.3453309958980935, 0.8098665396532705, 5.723483822038097, 7.719671159021317, 13.143476093969038, 8.498523946731321, 0.5994464565188654, 0.09729323533153343, 32.01036295583172, 43.858954829554406, 33.66112578299738, 49.15136575698853, 42.67692504390594, 45.72873300121677, 5.4266275705829745, 0.3057773146898516, 0.02566141354280614, 0.05822580022316787, 0.040241334617378256, 0.017191281151627342, 0.026622953479208296, 0.07931589434343962, 0.04814424018766131, 0.011079853040076072, 0.03840751164863187, 0.030299936113278234, 0.059198762530521046, 0.03766299292985951, 0.0026373814504157995, 0.07003561248101535, 0.03623883547862211, 0.06612972852082984, 0.01763938896117672, 0.15346772788513094, 0.16564133997646072, 0.08400904855901196, 0.10932668397623686, 0.12504469377980118, 0.12823378757363366, 0.22898262336609826, 0.17503109580326467, 0.316800952198044, 0.10915948528676264, 0.23775835972159143, 0.18403313453159026, 0.1280811981808755, 0.07670348855636774, 0.15870334129900704, 0.10668175775677928, 0.08628863510825942, 0.15318534787624113, 0.1775565506109307, 0.12823476816617674, 0.16400992509818849, 0.1318387828406788, 0.18685538712288105, 0.17667846063212042, 4.245109163945721, 53.08296918869019, 45.689995673394975, 52.14241227796001, 51.26034182886924, 41.366974999827725, 48.021789827654445, 0.4376680229700381, 2.6016431710412427, 3.64292630264836, 8.732644338761608, 22.814825004146947, 4.133709928681774, 0.9711148097149789, 8.138572938980596, 31.174027342950147, 55.38606728276899, 53.322790745765936, 59.195735992923865, 63.71228641079318, 61.52514926848873, 60.07059320326775, 52.40498358203519, 45.394511761203894, 52.53624962222192, 58.93740869337513, 60.246617409490774, 59.365672680639456, 59.521402543590916, 60.72214203496134, 62.074551736154866, 60.07706511405207, 58.30344776953421, 58.09840194640621, 49.23947788053944, 46.101467993951616, 45.742410306007635, 46.806588557458696, 46.81582181684433, 45.93087627041725, 46.099396982500636, 45.95409670183736, 48.59240055084229, 46.91453218460084, 46.262473444784845, 46.762108879704634, 44.125507339354485, 47.18087680878178, 49.79097489387759, 45.33861014150804, 47.24803955324235, 46.44769168669178, 49.76322804727862, 59.91835817213982, 57.57186689684468, 56.80246260858352, 55.59582779484411, 56.97175210522067, 52.044725648818485, 53.33370277958532, 49.70406301559941, 48.618943229798354, 50.257685953570956, 56.1975742924598, 57.77024076830957, 58.558221401706824, 54.732318001408736, 57.10257491757793, 62.40966335419686, 58.88498229365195, 57.41535648222893, 56.62296710475799, 50.34141286726921, 48.336101116672644, 44.310505928531775, 42.87504788367979, 46.418077791890795, 48.5282305748232, 49.429446112725046, 47.09469841372582, 43.2717054120956, 45.58980657208351, 43.09927409695041, 43.013884098299094, 44.02243529596637, 41.81693361651513, 42.16249442869618, 43.80054289294828, 43.05007188550888, 41.78270309202133, 42.57896384885235, 41.68047435822026, 50.73732514535227, 54.91957979817545, 55.15238815738309, 54.96480472626225, 54.97434393052132, 53.32253186933456, 54.12949285199566, 52.132657343341464, 55.664551642633256, 50.686008776387865, 50.817631752260276, 51.21559935231363, 48.24623569365471, 42.54223869692895, 43.520830831220074, 42.97003984451295, 43.12379283289756, 42.824849390214496, 43.55936419579291, 44.15749426810972, 46.68250437705748, 46.1006207619944, 48.65273052646268, 54.85558632881411, 55.327423926322695, 55.505668194063254, 52.05780283097298, 6.828756255488242, 1.6106498505800002, 8.271312809759571, 10.049652687964901, 11.094558373574289, 13.767772297705374, 5.272166104085985, 0.35999776975762465, 37.22117093301589, 54.244096663690385, 38.24080674879013, 52.162216324960035, 49.991000083185014, 54.47493207070136, 6.923017184580527, 0.5857117870642293, 0.2102055172285726, 0.2499776612967253, 0.1260043491399096, 0.1999092495609676, 0.11140795334452584, 0.14517899362310288, 0.18535253712006156, 0.12843091731830952, 0.1637257371217974, 0.13828463131381621, 0.1844386401916704, 0.17654398155789222, 0.2420615062357918, 0.17154328134511748, 0.20698396428938837, 0.21612135543217584, 0.12433762526920727], [0.025830734295830615, 0.033270895946770906, 0.028373623349433465, 0.011980692957407765, 0.011268798092890893, 0.014820335744579714, 0.05977103020995856, 0.03223963817881961, 0.09652419796874447, 0.05574316973046911, 0.0664968838194205, 0.056288946089485, 0.045557931185730045, 0.029417937170834314, 0.025073184421466246, 0.05851282655531841, 0.022165524517937053, 0.03069371105201783, 0.08775819859076893, 0.03641018636464592, 0.03610554001023693, 0.04911329161616103, 0.04631570705603208, 0.07839330231710788, 0.059396447688942, 8.00058444661479, 46.433892788425574, 27.769629686109482, 49.27320241928101, 33.24218526963265, 43.80567335313366, 6.931843498060781, 1.5693825939970634, 0.055425683742449175, 4.085751353733001, 3.8923096176116703, 2.0572341257526032, 0.6426661954291406, 0.47106418578374776, 7.207805773904247, 35.55498338514759, 56.15807602482458, 57.15481304353284, 59.104811529959406, 57.84464028573806, 51.90101000570482, 43.04610636926467, 47.13655402583461, 54.353864192962654, 58.05237293243409, 58.14298360578476, 59.03247910161173, 57.04677920187674, 58.04734837624335, 55.00223198244649, 57.220787309831195, 51.22635449132612, 45.36923993018366, 42.32320962413665, 41.43234129874937, 41.181184091875636, 42.54355269093668, 41.06453280295096, 42.56164658454157, 42.1690369421436, 42.707135138973115, 42.245613375017726, 42.658662488383634, 41.26240068866361, 43.3640536954326, 40.68882465362549, 42.81824411884431, 42.76494303057271, 42.16602063948109, 41.33221887773083, 44.13128499061831, 51.231084869753936, 56.55240366535803, 54.68073883364278, 55.90212568160027, 53.99663432951897, 56.19658585517637, 54.64798312033377, 54.380395104808194, 53.77449481718002, 47.74182673423521, 47.7653766447498, 50.98556803118799, 55.23536589837844, 59.88917573805779, 56.656456301289225, 56.359313226515255, 54.897351726408935, 54.035261830975934, 49.71600271040394, 44.95857169551235, 41.05920230188678, 41.482680997540875, 40.9861050113555, 44.571402380543375, 48.97961301188315, 51.06590209468719, 51.08416072783932, 48.103834044548776, 42.02571745841734, 38.95165789511896, 38.955450827075595, 38.8201839693131, 39.89735311077487, 39.495412149736964, 39.29666957547588, 39.05037218524564, 38.495788266581876, 39.71564539017216, 37.45636017091813, 38.61369863633187, 43.028149758615804, 52.388329198283536, 50.99910413065265, 51.59138594904254, 52.44956524141374, 48.91099899045883, 48.02377846933181, 47.64644645875501, 47.66584650162728, 48.09091767957134, 47.48495855639058, 47.60386520816434, 43.62268693985478, 43.64011795290055, 42.85316890285861, 41.28826087520969, 42.37232554343439, 39.446241317256806, 38.96842210523544, 40.85258753068986, 42.45237327391102, 44.97498681468349, 47.931136008231874, 51.72313444076046, 53.3374878668016, 55.185743993328465, 32.26211440178656, 0.8673340430663479, 0.17760058534481835, 3.0957541927214596, 7.28395466842959, 19.887091421311904, 10.311010999064292, 0.26057169201873964, 0.23814776221350317, 40.66469815469558, 42.25338359032908, 32.31146958566482, 35.48141148782546, 48.154558135617165, 14.80727295721731, 0.14103770616554445, 0.05811757498210477, 0.045041664533557436, 0.04181518947945968, 0.050351937046094294, 0.06787320674066583, 0.03843687579876954, 0.06424797143066122, 0.04529811629664995, 0.06537741485742793, 0.024249789290009968, 0.03849429408869436, 0.023966369316762975, 0.06658665400238768, 0.02200375547662618, 0.013583234939423781, 0.04541361171211447, 0.08919811447060878, 0.0363568130189613, 0.05711467395867071, 0.05148800713340602, 0.0810322760333938, 0.012441221925039447, 0.033920818128653114, 0.037796050910988165, 0.06656361007762533, 0.020989931954611695, 0.03296194417822746, 0.047148965569513465, 0.03719349594546422, 0.007013402796620804, 0.0069444242399185905, 0.04789613112206421, 0.049842699250626954, 0.040628320101888916, 0.03291707440850235, 0.027527837383170283, 0.07229960914100371, 0.025388762850554723, 0.04752660861178752, 0.09207469035661028, 0.07190694311453451, 0.07641695635092836, 0.04344897923029719, 15.800701456685221, 53.1613616789541, 31.458518812733313, 55.348404684374415, 34.551582259516564, 50.22351818699991, 6.543514632409619, 0.7950684175856653, 1.1483175043136844, 2.6016230688941095, 5.624355231561969, 7.338953162393263, 1.7798800213683037, 1.4148437832632375, 11.28779786248361, 36.99005311535251, 57.61405591041812, 57.93646689384215, 61.25103442899643, 58.84110273853425, 54.99650924436508, 44.868741573825965, 47.765517850076, 56.5494030521762, 60.02920435320947, 59.66316092398859, 58.73579886651809, 57.983048962008574, 60.37154882184921, 56.7354763707807, 59.69097445088049, 53.46963251790693, 49.05119234515775, 44.71769502086025, 44.34966687233218, 44.9181555932568, 44.53486158001808, 43.38574832485568, 45.123895675905295, 45.464416242414906, 44.23121129312823, 43.657639180460286, 46.074372260801255, 43.267029946850194, 45.593619115891, 43.09701088936099, 44.21387049459642, 42.33754980948664, 42.8518392193702, 42.83247447782948, 45.13998916072231, 53.61849431068667, 58.2070476778092, 56.42995903568884, 58.16427815345026, 56.44268320452783, 57.38549547810709, 54.59108129624398, 56.52559426523025, 53.50997017275903, 50.95043143918438, 49.01754233144945, 52.2412520839322, 58.30658174330189, 59.12217586271225, 59.00879583051128, 58.23967395290252, 58.369276908136186, 54.305960286048155, 52.525906332077525, 47.564249269423954, 43.95975189824259, 43.01225239230741, 42.70829616054412, 45.06222817205614, 49.36367188730548, 52.932656118946696, 53.38892190687118, 50.29966708152525, 44.06295337984639, 41.24123557921379, 40.98746999617546, 40.77226915667134, 42.287567046380815, 41.499190253596154, 40.691252600762155, 40.33277934597385, 40.208444133881606, 40.929061981939505, 41.02431281920403, 39.89789439785866, 45.46438486345353, 54.69217254269508, 51.65485774317096, 53.438783076501664, 52.84922338301136, 52.4118398850964, 50.03144364203177, 49.739281977376635, 49.791626007326194, 50.178281491802586, 48.63118494710615, 49.062614287099535, 44.30193554970526, 44.745924318990404, 45.059894361803615, 43.87996304419733, 43.467447373174856, 41.55659021869783, 41.067768758343114, 42.47851587110951, 43.055586737971154, 46.1488776822244, 49.04816427538472, 53.114293236886304, 56.506504089601584, 54.798496230956054, 33.95123212568222, 0.9416922530339611, 1.2018997774970148, 5.789340907527555, 10.672930056048978, 18.869305003073908, 2.956031522443218, 0.835843968295282, 0.26441065053786, 44.13116339714297, 48.262988136660674, 40.96317091295796, 37.01638006394909, 53.08476563422911, 24.937456807782574, 0.2755517140030861, 0.06619881432984145, 0.05735814436188629, 0.04550642709458067, 0.03175734369564922, 0.043473574483106216, 0.033166983780721505, 0.024671074446110476, 0.013582692932217352, 0.038707726184398904, 0.07785405302720685, 0.04130984724108731, 0.036023369419478604, 0.09353537488007739, 0.02926540714989026, 0.02912413862143313, 0.08753656169339534, 0.061257309730975866, 0.04867038171317789, 0.09307565317759592, 0.24181019875311086, 0.20869848438568656, 0.1504740861034201, 0.13857528507228822, 0.14114241506303513, 0.15388880045183245, 0.1405453261348509, 0.1348231396367473, 0.17453758196244318, 0.15387971464905048, 0.19630483652074493, 0.13785378346520086, 0.10356069257062289, 0.13936259363207126, 0.12605887161748064, 0.1123368502744744, 0.1377960510792271, 0.18712462106299016, 0.14699670576280163, 0.12400308999443248, 0.12826546530930266, 0.13668903870688331, 0.15246922420638223, 0.21816832704409478, 16.47340363071811, 64.1485010423968, 40.593393387333045, 61.05152699255175, 43.05134665581488, 57.97544348624445, 8.566065199913519, 2.8649705119671363, 1.957406863089531, 9.257150542351509, 12.651080373794803, 6.906112749730387, 2.545425800546523, 0.9313662458331355, 9.619102939482659, 38.208439350128174, 60.29689042798935, 57.74551414674329, 63.77918635645221, 62.14866492056078, 57.72117583982406, 47.35923874762751, 51.81163095658826, 59.63202122719058, 64.08123631631175, 63.13703160132132, 60.546345326208304, 57.98286461061048, 64.14859125691076, 60.09326450286373, 63.28073547732446, 54.938375796041186, 50.97574641627651, 47.108332572444795, 46.74781184042654, 45.853750705719, 46.66259834843297, 44.44269764807917, 47.08884623742873, 48.25024827834099, 46.30297583918418, 46.321254084187174, 48.62132018612277, 45.83300921224779, 47.67953165115849, 45.50229064879879, 46.584574560965265, 45.93348856895201, 45.205692783478774, 46.55472532395394, 49.27464977387459, 55.8343392802823, 60.253622762618534, 57.89533692021524, 60.160023243196555, 57.61178485808834, 61.070150406129905, 59.0886748990705, 59.44285708089029, 57.22134036402549, 53.140977121168575, 50.59168754085418, 54.20192333959765, 61.77991897829118, 60.730649655865086, 59.521473146254024, 59.63476296394103, 59.734426467649406, 56.842243286871145, 54.043298767459014, 49.10633694741034, 45.25884482168382, 45.227532540598226, 44.2404680867349, 48.46058145646126, 54.052849738828606, 56.098738408857784, 56.02115392684937, 52.941355935988895, 47.124551573107325, 42.69259491274434, 43.9293299951861, 43.7843591936173, 44.60519359957787, 43.74145630867251, 42.700733830851895, 41.146655467248735, 41.228915414502545, 44.342614450762355, 42.421170819190245, 41.83557664194415, 47.24752964511995, 56.69929642831126, 53.63921226993684, 54.22333163599814, 55.445804980493364, 53.449581361586056, 52.82046848727811, 52.38954905540713, 51.61644989444364, 51.33520810834823, 51.100152231031856, 50.8471554325473, 47.75546873769453, 47.747169002409905, 48.13120826598137, 45.127947484293294, 46.80220726997622, 42.3076182027017, 43.85215343967561, 45.4024741726537, 46.603045002106704, 50.09185598742578, 52.05643784615302, 54.62510785748882, 57.92742583059496, 57.03822059016074, 34.14270262564383, 1.4773500614589261, 2.413593468166167, 8.1431380875649, 18.29130453448142, 29.52556106352037, 19.21732121898282, 3.1613607368161603, 0.37376924207614315, 51.22783714725126, 51.14920931477701, 41.45538522351173, 42.22646828620665, 58.262004006293516, 30.06394559337247, 0.3722568006525117, 0.24078102091387396, 0.24739459667715336, 0.1827379556432847, 0.1769959734332177, 0.21305789239704612, 0.2003060524622279, 0.17953163253203516, 0.16539905700952778, 0.1742250793763707, 0.1246125129381976, 0.08296422720436128, 0.23244121923081337, 0.14648402440211467, 0.16208122214001996, 0.10739970471589796, 0.12422674170304691, 0.21279705478058708, 0.10383049341579599], [0.06827236153185368, 0.015986603102646768, 0.038159674544247894, 0.09635647067860251, 0.05946157282338508, 0.026354675233784704, 0.027880105678172364, 0.04804679380369283, 0.037323075887416644, 0.06527358696105019, 0.013139150049086782, 0.017296851898032813, 0.06788094422870106, 0.029605647864481135, 0.03292784943515736, 0.011230297386646272, 0.04035781445582548, 0.026758326961088087, 0.06850805614263782, 0.1197836692294767, 0.031453743051256866, 0.06583184289235262, 0.07480783463125268, 0.033675091596500534, 0.07181862849862346, 0.11156867093016064, 23.339738153642227, 36.43657530507734, 29.257051291004306, 42.69003360502182, 36.24736409033499, 24.00409548513351, 0.3028981417657868, 0.7615065959192092, 1.5597406726691032, 4.574632385084707, 6.102068049292411, 2.5085452247050504, 1.06509571834918, 0.8423577994108201, 17.465447533515192, 54.90189775343865, 60.83981706250099, 59.16895404938729, 53.82635247322821, 49.8344700567184, 46.56332708174183, 52.330941000292384, 56.94360517686414, 59.03993160493913, 55.363623480643, 57.078644537156634, 56.069093135095414, 55.4858680694334, 53.39712750527167, 51.2450877312691, 45.309721885188935, 45.490727501530806, 43.97412346255395, 43.20936326057681, 42.7874574353618, 41.32999489384313, 41.54176758181664, 43.04691437752017, 42.7641938578698, 43.644001099371145, 43.2061194604443, 44.92499620683732, 41.12070898855887, 42.82658700020083, 42.28530383879139, 41.44973701046359, 42.18081189740089, 41.003496800699544, 40.33478759950207, 43.52567103601272, 51.080830635563025, 57.60663478605209, 57.35670528104229, 57.34928807904644, 53.44542757157357, 54.79962587356568, 56.07389019381616, 57.549411327608176, 55.86933074458953, 53.89431538120393, 51.617461865948094, 53.38508582884266, 54.50874682395689, 54.71717373017342, 55.03594475407755, 57.82297703527636, 56.759324381428385, 52.34961932705295, 45.55326577155821, 42.4565976665866, 42.65490878012873, 42.504321144473174, 45.768388163658884, 50.1675969554532, 50.080281073047274, 53.31278085708619, 53.50366692389212, 56.014289779047814, 47.73360936872421, 39.67586078951436, 39.984900413020966, 38.89743504985687, 38.17541299327728, 40.06506973697294, 40.71878763937181, 39.83550910026797, 39.351359182788485, 37.153882672709805, 38.43834515540831, 38.2616816028472, 45.22966630997197, 50.584764557500044, 52.53527295204901, 52.557693219953975, 50.57481742674305, 48.34920575541835, 44.68693971633912, 44.88769838886876, 43.26127582980741, 45.895057186003655, 45.35821022525911, 45.4436041462806, 44.34899614703271, 42.28923797607422, 40.54217899999311, 41.37210153764294, 38.70938877905569, 41.946262005836736, 40.68074064870035, 42.4224102881647, 44.32689751348188, 50.56617644525344, 50.14073656451318, 54.30146132746051, 54.0347715347044, 52.888603979541415, 14.829013674489914, 0.2023115633956848, 0.6573869732599105, 4.711373563735716, 10.67705148650754, 16.358168317425637, 4.342888949378844, 1.3306302505154766, 3.613537944132282, 39.30618916788409, 32.96254381056755, 30.36754685063516, 31.30051789745208, 35.26417886057208, 3.37458249542021, 0.02114036480986303, 0.02404919491269656, 0.0350952347470147, 0.05448123905807734, 0.018528820871705973, 0.0219852353010567, 0.027955743454156384, 0.06904216498256692, 0.024157615506180355, 0.03009944707305441, 0.039539123104224284, 0.043683651113702406, 0.05767437779615003, 0.036171504010957096, 0.033764425109350876, 0.01954585430212319, 0.033624518302179156, 0.0356695402203308, 0.03982071404255206, 0.08131352989303489, 0.07612201250008038, 0.04628447365135916, 0.05187709935970845, 0.017438091698192784, 0.0729220402577231, 0.00717927759040087, 0.053367186337709434, 0.12031095222600045, 0.14682329410026151, 0.00578004959782946, 0.03655385849396548, 0.028661090182140473, 0.03759076616035835, 0.05903997165601581, 0.05085424174584689, 0.08733632929262616, 0.06961688414336213, 0.03690450842822752, 0.017586473353026856, 0.01726316126634277, 0.08005269472637484, 0.07528173662121258, 0.0107602306243573, 0.0427842409079594, 0.3765091402155738, 34.591817932744185, 37.41610880820982, 37.4359481565414, 50.37208187964655, 41.88313930265365, 22.30008452169357, 0.45940469529840255, 0.31894137121496663, 2.111017175259129, 4.122006066383855, 8.28301323998359, 5.2872995888033225, 1.6741125742273948, 1.8988344770285392, 19.08755156301683, 58.01455736160279, 60.069063478900546, 62.518666021285526, 57.51842460324688, 52.134045862382465, 47.44617023775655, 55.42423978928597, 57.73563369627922, 60.88606572920277, 57.49508257835143, 57.719191120516875, 57.41830218222834, 58.96931325235675, 55.76106156072309, 53.48110937303113, 47.34530648877544, 48.067183417658654, 45.18060138148647, 46.32392129590435, 43.970275617414906, 44.61068491781912, 41.89736573926864, 45.11447414275139, 43.31911117799821, 45.11888288682507, 43.40800385321341, 46.100095164391306, 42.983536720275886, 44.77019594561669, 43.174638517441295, 43.400359153747566, 44.36318728231615, 42.3139645976405, 43.53164088341498, 46.032434278918856, 53.21631016269807, 59.114193839411584, 58.01482800514468, 59.227538570281006, 56.10509264853693, 56.6308863701359, 59.105454798667665, 58.527858334202925, 57.4488692129812, 56.014019135505926, 52.106393152667636, 54.251051026005904, 57.839286250452844, 56.777814434420684, 55.86432580024966, 59.932678745638945, 58.175613803248254, 53.59497577913346, 46.87946227289016, 42.96499567647135, 43.306018306363015, 46.05211673244354, 46.726984054811545, 51.63468891574491, 50.87252924519201, 54.50655421903057, 53.989903542303274, 57.52953275557488, 48.55261202781431, 40.78952366305936, 40.53627975525395, 39.83332041771182, 40.8682809337493, 42.22750771430231, 40.7556422295109, 41.01966088817966, 40.67776356973956, 39.78842104634931, 40.1075372388286, 40.414843174719046, 47.19801364406463, 53.016896863137525, 54.879473563163515, 52.83602068501135, 52.596701191317656, 50.79690987063993, 48.030705375056115, 46.9974785466348, 46.301803050502656, 46.41446136659192, 47.594161264358036, 47.013203328655614, 46.87181365105414, 44.53609712662236, 43.20491921517157, 43.189974984815045, 41.23947051263625, 42.34860304863223, 42.58374129572223, 43.56871904865388, 46.90752290910291, 52.123655503795995, 51.65111972439674, 55.609638460220836, 54.97200227552845, 53.31109031554192, 16.28809125192704, 0.5504207517350874, 1.6084093191931326, 4.449748041168336, 7.103119675190219, 9.614763817479535, 1.286561195888827, 0.6068535461541146, 3.806550180719745, 44.16007911005328, 40.39365453104819, 37.650074266618304, 30.424784037374682, 46.88598517448672, 6.235726244987981, 0.11608282104134561, 0.020897491955228394, 0.026075422778845798, 0.03228032127803853, 0.03263587800545558, 0.06190324825565181, 0.0369133107784775, 0.03963042163260041, 0.03335604278911506, 0.04095199608033703, 0.14077942728275253, 0.03756476513620827, 0.02389661892647705, 0.004818063415211416, 0.04696881616367929, 0.0588075022753929, 0.042404008488501274, 0.08406518748210323, 0.043918602619199984, 0.1896856376721013, 0.17938511055563727, 0.15843652819673862, 0.21047027721520395, 0.15195528646149944, 0.21533827567773484, 0.19764912164499684, 0.14799117981906862, 0.18297484535123074, 0.16496215706631062, 0.12696167559272822, 0.10138216834034651, 0.15321703327278938, 0.10902393368944045, 0.08174784045906798, 0.16266265223103185, 0.1537073295443289, 0.21933035985116037, 0.148966042024474, 0.3596208851423956, 0.11580463919428088, 0.17629509491305198, 0.1124078129989005, 0.14801085295696415, 0.3541899959166204, 0.3258124444513552, 37.56081681097708, 49.27675608665713, 40.44687324954618, 52.943819184457105, 47.64591301641157, 30.178200314121863, 0.5827035742901987, 6.335203436113173, 5.926591504004694, 11.703606363265745, 14.357402593858781, 8.559802155340872, 2.7202524581263146, 1.6203149384067905, 19.903747766248642, 57.854257937400575, 64.880211353302, 64.83811647661271, 61.116983505987356, 53.65452912545974, 51.79525113874867, 57.0524940952178, 61.279401010082616, 65.05351735699561, 58.18628265011696, 59.7627499026637, 60.272610956622714, 59.46039007556055, 58.0800138750384, 54.903133300042924, 50.190299634010564, 50.41771865660145, 48.705411880247055, 48.01584743684339, 46.71800574948711, 45.87015405777962, 45.39884990261447, 47.51348987702401, 46.78747092523883, 47.65111407926006, 45.605009678871404, 48.62054355682866, 45.97929793019449, 46.019525758681766, 45.8642352011896, 45.13268178509128, 46.03394831380537, 46.44112171665315, 46.483040086684696, 48.15535437676215, 56.78363130938623, 62.9798073153342, 60.521061728077555, 61.54276463293261, 56.291797468739176, 56.394987183232466, 59.64415704050372, 60.61422586441041, 61.203397243253654, 58.09562883069439, 54.46611458255399, 57.120111834618356, 59.18216459212765, 57.07655391385479, 58.46555540638586, 60.7070722887593, 61.69383864248953, 57.05770692517681, 49.522367062107215, 46.08931649115778, 46.870142721360736, 48.44607653156404, 49.781855383226954, 53.911777773211085, 53.450550187018614, 56.53200341809181, 57.59892732866349, 60.111923217773445, 50.5944763460467, 43.115112627706225, 43.49458233002694, 41.18092521544426, 41.75208507045623, 45.2787273160873, 43.711552158478774, 43.578893676880874, 42.79854597583894, 40.755916795422955, 42.298408477537095, 41.49404802630025, 49.41902045280703, 55.74824325499996, 55.86938565777194, 54.82725897142964, 55.54857107900805, 53.1228949946742, 50.49499327136625, 48.52403363873882, 47.07868729868243, 48.78402402324062, 50.12066579634144, 49.523061321627715, 49.502649307250984, 45.87256239306542, 46.037874606347856, 45.89723017907912, 42.306963166882916, 46.20539903640748, 44.569048958439986, 46.208701672092566, 48.73584947278423, 55.79861825512302, 55.34614539915516, 57.94188760942029, 56.64059423631238, 53.68729660587927, 17.005977169159923, 0.30139247255940593, 2.932613991921948, 12.21014222791118, 20.13696797432438, 28.11193100867733, 12.095300132228482, 2.6228367176748093, 4.550486274303929, 51.73771389069096, 41.49384798542146, 40.92016212401852, 38.49749057523666, 54.028942892628336, 7.273720714353747, 0.17798906853122098, 0.08159888232307089, 0.1428885592688476, 0.17709795505769793, 0.17469063100795593, 0.1427941159495423, 0.11076820097983846, 0.14210877369248098, 0.04987700083743661, 0.15195165520473836, 0.21116711079112946, 0.1877306119328545, 0.16483019076047406, 0.1308464231870828, 0.25180306495918386, 0.1669356148810156, 0.274107056038995, 0.14804451486035702, 0.19381008651708403], [0.05588654691593782, 0.053384986390630086, 0.03969455468318155, 0.1050623091718843, 0.03191090793529105, 0.02089803779287444, 0.022586045501333092, 0.042102813360191164, 0.06400405286600994, 0.05462141782646218, 0.036861714756777214, 0.04061933772097673, 0.029449676193537253, 0.043529483579820206, 0.011885949906202094, 0.06041897588499612, 0.020512073120522886, 0.04653501121567623, 0.04652774870215405, 0.005702484631910921, 0.03292437522642074, 0.04612271418614734, 0.05156804799973484, 0.014680676000763573, 0.01031927424558108, 0.02229563689099685, 2.188300125060543, 43.46077542151175, 25.209082903400546, 36.04329101500973, 34.036312257089925, 38.55943264499788, 2.9607866608327438, 1.2532145529985428, 0.12587441296707239, 3.1045684939430607, 7.351757249524517, 2.8077997603724083, 1.3771844943684917, 0.8720443193470279, 4.606447219848633, 46.38314124076597, 59.01667587218746, 59.406210376370346, 57.66837681493452, 50.68414172818584, 53.44223083988313, 56.989328245962824, 58.473866908781, 60.037939471583215, 55.92990390716061, 57.326636391301314, 57.1117179624496, 57.75179386138917, 52.83204732402679, 47.775904286292295, 45.43783826212729, 44.18021263614778, 45.19608689892677, 43.7047193896386, 42.31818114557574, 40.87236412109868, 42.216183831614835, 43.85553844513432, 42.378542500157515, 41.784703500809215, 44.302519982860936, 41.153900084957, 42.283064165423, 43.121568849009854, 42.122513709529755, 41.55282082096223, 40.886916114437966, 39.613597085399014, 38.665458233125754, 39.37667415988061, 45.18693208694459, 52.141106128692634, 54.253898666751006, 53.99641467678932, 56.37481051106607, 55.33410372272615, 51.21206921915854, 52.63723888704854, 57.075024189487586, 56.168839008577415, 56.455870213047156, 55.78821612942604, 54.95434768738286, 55.173514043131185, 58.22703215383715, 55.74111630839687, 54.49015478934012, 49.186431746329035, 44.43930087550994, 45.469695752666844, 49.2309388806743, 52.56863663273474, 52.019500886240316, 53.97292360182732, 54.48177268428188, 55.58940295250186, 53.202503419691524, 53.47307243654805, 48.33223365968274, 39.31597548146402, 38.93940048833048, 41.23616395458099, 39.23633959985549, 40.514345861250355, 40.63988131861533, 39.5062457361529, 39.69972056727256, 39.563767294729914, 39.43980863017421, 39.60256738047446, 41.866249576691665, 49.39829072644634, 51.07397825487199, 50.68817784709316, 49.91417261861986, 46.662053138979026, 45.61182283586072, 43.10418882677632, 41.05655862439064, 40.73022919316446, 42.15568519407704, 42.218498030016505, 40.99766815862348, 43.21112832715435, 43.918092404642415, 42.448337155003706, 44.31105898272607, 43.196725383881606, 42.948211854504, 45.739986281241144, 47.17065118974256, 51.31898910768571, 53.398920028440415, 52.82317492269701, 56.0133287983556, 36.57780416550175, 2.046088588333899, 0.19810024018008865, 0.7467612419878283, 2.9853093191500637, 4.244369306871969, 9.732739886929913, 0.22979469188759405, 0.2774844925490118, 8.360774228649756, 40.08817641965805, 40.749750829512074, 28.315388271885535, 34.840449133226954, 17.55245354867751, 0.10177075111817929, 0.02745724812660727, 0.12601097580045462, 0.02719228129623638, 0.033765214179912885, 0.044345960937320225, 0.0496909755372232, 0.08223505705715188, 0.030822986474020347, 0.03838916384284535, 0.03828226393389125, 0.008825649856589735, 0.029516124744869532, 0.027321483939886097, 0.07763520468987765, 0.038120542773075645, 0.09899061804096546, 0.06588962890448109, 0.05139744021899758, 0.03369340492833046, 0.010713107598524903, 0.013269412766901717, 0.01372206922350151, 0.022669079856226043, 0.03081965590676954, 0.07572766108017775, 0.06277370033785701, 0.05742562138625691, 0.012290308349615624, 0.035448857102422945, 0.0066522761311892786, 0.07064294400474719, 0.033953782892034906, 0.04024403507731134, 0.022448634225574714, 0.011915369597714276, 0.034949532484695796, 0.02576219432446505, 0.04233099264843811, 0.03120969233643865, 0.04706144385460404, 0.07628567186334441, 0.02962258798370679, 0.016476498135635932, 0.029481587586023157, 0.07014068910070966, 5.044923097856584, 52.17184574373307, 25.715192210289743, 45.94538904005482, 39.32676984417824, 43.83188263062508, 2.5827981435483505, 0.4609546750303238, 0.2526939026410541, 2.9082921099278236, 7.6296537441592065, 6.479537833121515, 4.01224319492617, 2.330316646445182, 6.401381175364218, 46.767027531900716, 62.44715729067403, 60.65464196666595, 57.944111593307994, 52.5454907263479, 54.758672406596524, 58.45784010425691, 60.41859372969597, 60.08004219301286, 56.14130004759758, 59.00763873131045, 59.259399983190725, 58.316681846495605, 55.01541899096582, 51.25527804897678, 48.28601244957217, 45.35469578158471, 47.09455328602945, 44.881614792731504, 44.81001976997622, 42.13291583522674, 43.12689150533369, 46.56380953327302, 44.691548501291585, 43.07856006007041, 45.449354340953214, 44.06837409542453, 45.576286162099535, 42.99294256394909, 43.934652651509936, 45.39904602112309, 44.08814676346318, 41.77264221252934, 42.35530637925671, 41.89941713886876, 47.111592062057994, 55.157530384679, 57.1558524716285, 56.093870747473936, 58.23906598552581, 56.569740541519664, 54.27640522679975, 56.85950563799951, 56.42940598149454, 56.6446578118109, 58.564638399308734, 56.58015443432716, 56.99149339429794, 56.91365395822833, 59.090514490681315, 59.316752879850334, 55.6909844952245, 51.578555876208895, 46.23699372814548, 48.08624221432594, 50.27207320736301, 52.44578015419745, 52.714478200481786, 56.20126132042178, 55.53542721656061, 57.18442301596365, 54.8920996727482, 55.258786370677335, 51.604674939186346, 41.519814075962195, 40.47748734874111, 40.58468180318033, 40.90204469619259, 41.59673567741148, 41.82636299440938, 42.81013265732796, 41.1952300994627, 40.549517754585516, 42.050416623392415, 42.23813733746929, 43.654112969675374, 50.35758479948967, 51.95182823365735, 53.483047023896255, 52.12811523868192, 49.908136090924664, 47.952422711157034, 45.07525828576858, 44.82442663561913, 43.253544838197776, 45.420360180639456, 43.254596033403956, 42.84267656264767, 45.885231648722005, 45.49692092403289, 46.06400543643583, 45.75427547577889, 44.012229288778, 46.493438290011504, 45.82403875166371, 50.44708936445175, 52.096602916717536, 55.788278887348795, 54.04400479409003, 57.56215118592786, 37.09017553637105, 3.427786014733776, 1.9342641436284589, 4.000447156929201, 6.172992837044501, 7.912020760197794, 5.938905785160681, 0.48175518791521754, 0.6941514101720626, 9.087076571679885, 43.64135742187501, 51.260804668549575, 27.64605345264558, 38.975505905766646, 25.095451839508552, 0.5275772355737225, 0.09596137615341334, 0.05872225584161859, 0.056487033444066206, 0.025312418358460553, 0.0192029265341379, 0.0450366466576534, 0.021433123394907005, 0.01838558349728344, 0.026851730316036174, 0.042069078678445476, 0.08032063397789195, 0.038721642171543454, 0.0668941310516769, 0.022084426450272723, 0.0093351069447254, 0.04086936583682414, 0.03843609055864715, 0.02139512351864288, 0.005707604014464925, 0.15089407082526915, 0.1459991060678036, 0.12778620836475205, 0.25339223774931124, 0.11318541522468291, 0.12675439518305565, 0.10786733244575801, 0.13417617838469245, 0.17490413971245292, 0.08150557281389352, 0.15157921389947016, 0.2150426270259965, 0.1134092890987954, 0.12093051051300381, 0.13902741484344006, 0.14609085275761544, 0.16937716773921446, 0.142842379488772, 0.12569725513458252, 0.11481253234969993, 0.11767386308600826, 0.17984464073613768, 0.12131831188115383, 0.1383304127281712, 0.1199081278736553, 0.17373058494300614, 5.3243071513791245, 60.91494221841136, 35.40789450368574, 47.27148355976228, 45.435159283299605, 50.10006550819644, 4.124105024722315, 2.5004626906687215, 2.3288972387390756, 8.295001964415274, 18.691866782403764, 7.149482580923266, 5.307613543925747, 3.6222286906934555, 6.167638801759289, 49.984308519671046, 63.54399711854997, 64.28665868697628, 60.89064705756403, 56.27149920309744, 58.57597012673655, 62.59910206640921, 62.16971235890543, 61.90416397586946, 56.72948691152758, 63.09505439573719, 62.63974566613475, 62.924297932655584, 57.737194799607806, 53.028322727449485, 51.82301759719849, 48.575318628741854, 48.530799727286066, 49.218626560703406, 47.616287354500066, 45.46137640553136, 45.01688557286417, 48.33459492652647, 45.12399765752977, 45.5118808438701, 49.537307370093565, 46.10673181472286, 47.074902211466146, 46.645885129128736, 45.40986784042851, 47.39275147837978, 45.95714438346125, 43.46405844534598, 44.14393463442403, 42.65581484763853, 49.65195040549002, 56.14472035438784, 58.381667675510535, 57.437043266911665, 59.79607828201787, 59.999676750552275, 56.57012493379655, 57.72049726978425, 58.70711065107777, 59.640724966602946, 60.291010795101045, 59.342267897821245, 58.892230833730395, 58.700007238695704, 59.66198813530707, 59.561908860360425, 57.775794844473566, 52.9302752402521, 48.69080105135518, 49.904762852576475, 52.82813672096499, 56.05943625973117, 54.41468446485458, 57.07354937830279, 56.966668713477354, 59.99692324669131, 57.30012509130663, 56.70661164868263, 53.247285119948856, 43.98816554777084, 43.52805583707748, 44.665872666143606, 43.3029039444462, 44.30327307793402, 44.40213249575707, 44.07716412698069, 42.98160299178093, 43.64285184491066, 42.22086321923041, 43.94282687094904, 45.55051226769724, 52.456131289082194, 52.26735153505879, 54.50471070504958, 54.46519674793367, 51.27112442447294, 50.00720731673702, 47.14544603901525, 45.35136961167859, 45.53188493174892, 46.96512683745354, 46.59652994525048, 44.769333024178785, 48.82447542682771, 47.85630503008443, 49.580002369419226, 48.16198318235336, 46.66688942140149, 47.84813473301549, 48.899023994322754, 51.5186652060478, 55.44827215133175, 56.65378908957205, 56.41326935060563, 57.87578390490625, 40.437808652077955, 2.5851567137625913, 1.0548534292367198, 5.760983151774253, 8.114785234774313, 15.634668507883626, 20.53996797530882, 3.149405597679077, 1.0767972517398097, 10.780213744409624, 51.031867688702, 51.236740927542414, 37.01746656048683, 49.55890786263251, 30.092488681116414, 0.5107252011376043, 0.1556059099253147, 0.2364002237276685, 0.17063594212935818, 0.17792893062916496, 0.16122321898658432, 0.1751347628211783, 0.14055720049767725, 0.04726475975926846, 0.10671908156045022, 0.10306055206925639, 0.18035626489548914, 0.1199174358419353, 0.177621177788223, 0.14809438718422768, 0.13514731740278585, 0.23919774700076352, 0.18209559091877553, 0.14736637382978393, 0.22432733687662312], [0.06244055168222516, 0.03481454396199796, 0.07201367448414527, 0.009785236268784973, 0.018285411755524335, 0.007839862279774202, 0.06326320370839489, 0.05085718352347613, 0.06734473630785942, 0.039408282947636424, 0.021303219780806574, 0.04894233143497859, 0.07183280112522264, 0.06640210342142852, 0.05309587246888588, 0.017033984148574453, 0.04940624363840588, 0.07381181307737866, 0.031097862651691805, 0.06515446794970382, 0.05635325917072835, 0.08203051924224823, 0.03898727932884809, 0.04791063316647084, 0.06763162091374397, 0.07463807720811137, 0.05569606681444472, 17.243492372574345, 36.69225500475976, 28.516343062923802, 39.09562456992365, 28.86603609208138, 12.781960060519557, 0.20460489356229383, 0.42713161738168814, 2.314693355752576, 5.7909696717416095, 7.800520033605638, 2.2395272601035336, 0.5943793671265726, 1.134416134126725, 29.402765381720762, 64.50249102807814, 58.61775905855241, 59.19910138653171, 53.61703518898257, 56.87104917341664, 58.08037473309425, 58.52171982488325, 57.232217096513324, 59.243106457494925, 57.95542763125513, 56.595608572806086, 52.58824848359632, 49.52566185305196, 48.90180887714509, 49.32405987093526, 47.03938122718565, 45.918799292656686, 42.12992306678526, 42.529883230886156, 41.156802638884514, 41.95201612287953, 41.84016581504576, 42.83360019806893, 47.380352866265085, 48.19136173494401, 44.77842115586804, 42.73191667372181, 42.46615648269653, 39.824161683359456, 41.22054507655483, 40.44174671173096, 41.59089134585473, 39.956070992254446, 41.58882033440375, 41.47296528662405, 46.25657027767551, 53.337036794231786, 52.173049911375976, 53.039983933971776, 54.90067789631506, 52.63681527106993, 52.619203828996234, 55.15316478667721, 58.25630872480331, 55.18480654685728, 57.18330121809437, 55.58321345236994, 54.83105974812662, 54.923364885391734, 56.0159214850395, 53.018607016532656, 50.03454623683807, 49.1893970581793, 49.74018020014609, 54.148932118569654, 52.96684741973878, 54.84473705291749, 52.928361123608006, 53.94476882873043, 54.65995027172951, 56.00151069702641, 52.2417776815353, 46.24897264665174, 37.1566047976094, 39.46006374974405, 39.642046036258826, 38.602884661766794, 39.63775496329031, 41.014746158353745, 38.45299128563174, 39.92230330744098, 36.7413277779856, 39.80304364235171, 39.178892566311745, 42.58119175511022, 48.464425379230136, 51.271701012888265, 52.25680035929526, 49.70468667245681, 49.10616044075259, 47.923130450710175, 42.2136107567818, 39.945323697982296, 38.243999558110396, 37.931421956708355, 39.1313495174531, 44.018626674529045, 45.220703694128225, 45.96547942007742, 46.27944946289063, 46.78101862630537, 46.85854819513137, 47.23841797920966, 45.928146300777314, 50.32507619550152, 49.276477598374896, 53.52362002095869, 53.26831294644264, 47.80531421784432, 7.367881623006637, 0.0868248506899803, 2.9891851111765835, 1.895105161013142, 5.553620188466964, 4.048979378515675, 1.5751190603740755, 0.564795809407388, 0.05544442991395632, 13.671423196792604, 43.24750831050258, 29.971232529609438, 33.66664063545966, 35.13722350520473, 4.482660158987969, 0.184397010973865, 0.04364518966946391, 0.028801523674760136, 0.00176561193638331, 0.075131437831348, 0.06746669750540488, 0.04841676447540522, 0.03875955969335572, 0.04954819973077505, 0.09169206008194916, 0.014926212926154897, 0.014894974733432455, 0.05907990015862931, 0.031343694520933975, 0.06206900669982838, 0.023740298685527617, 0.051129979772433165, 0.04213560575378999, 0.0770420611145035, 0.060547127072969754, 0.017263073166231477, 0.06577188119051919, 0.012704963014731485, 0.03507978658402159, 0.028166034589371378, 0.02958569318927344, 0.036806924148432674, 0.02470509066516834, 0.03245279448287141, 0.03759885604883875, 0.021651203729092114, 0.06539975398129995, 0.03828758058408576, 0.003642953966083306, 0.046240500204505465, 0.08187467397581186, 0.01720397331331286, 0.07737310302834358, 0.02934557250550678, 0.056757868507937084, 0.015059765033994713, 0.057375400492380706, 0.08231840742331359, 0.12252768892193995, 0.0412249761903959, 0.0876507930637848, 0.047957828013046135, 25.19718243229774, 37.41020564110049, 31.22901308921076, 47.56828931070144, 35.024063125733406, 14.293502280789038, 0.45631245800083686, 0.42104455852700823, 1.9748290508024156, 4.182270832600133, 8.280609807660504, 4.439144403703751, 2.874543546668945, 1.1826544230984104, 31.366399988051388, 65.26254438584851, 58.60151260129867, 61.26421359277541, 53.3665761639995, 60.3975070676496, 58.92855982626639, 59.018417404543975, 57.46042059313867, 60.17693258100941, 58.641281512475786, 58.18570606170162, 54.6326623424407, 51.24348348186862, 50.299973026398696, 51.356326149355986, 48.94164054624496, 48.29933281867735, 44.59811764378702, 46.1329097132529, 41.61007565836753, 43.56600084612447, 44.25203907874323, 45.39715151632986, 46.7091804165994, 49.83243826896914, 45.757778152342766, 44.13075154827487, 44.671524801561915, 43.43952794228831, 43.33835040369342, 44.2837945876583, 41.873439281217514, 43.203397335544715, 43.01621006381127, 44.95462186874882, 48.4301713205153, 56.151404073161466, 54.928765989119015, 56.949798599366225, 54.793930592075476, 54.30637605728642, 52.08829533669257, 57.094926295741914, 58.854670216960294, 56.08985031804731, 60.45940599133892, 58.423244799337084, 57.881965560297814, 56.3544887112033, 57.69877518376997, 53.92375669171734, 51.63527727127076, 51.233030365359404, 50.8343606610452, 54.12155005239672, 55.91864670476606, 56.544405952576675, 54.40343510720038, 56.78491784680275, 57.00527268071329, 56.52872039425758, 54.12278167663082, 49.09761359614711, 39.54791307449341, 41.685098832653416, 40.19801455159342, 41.085721446621804, 41.860205204256125, 42.18071776051676, 40.68931494989703, 40.48794830999067, 39.45350554681594, 43.48232492323845, 37.99656860290035, 42.505372339679354, 51.389525090494466, 53.62140470935453, 54.141526683684326, 52.077316622580256, 50.53082804526053, 48.265106216553725, 43.7241861128038, 41.967266298109486, 40.101088862265314, 39.63101633133427, 41.045215129852295, 46.41793658656459, 46.46453434421171, 46.97292058698593, 49.44985420473161, 47.78483944554483, 47.274366501838934, 47.936980339788626, 47.723046425850164, 52.53053080651068, 52.18065538714009, 55.070626351141165, 53.895645064692346, 49.99940964483446, 8.862594423755523, 0.44984808552169037, 4.577488851162696, 3.347124678473319, 8.3359662179024, 8.072859510298699, 2.1305093938304536, 0.3168155078686053, 0.05072335562398357, 14.81789081327377, 50.219748789264315, 35.984357403170684, 28.484332599947532, 44.730109322455625, 8.175846242135572, 0.11131089766539874, 0.02688370299555602, 0.05637543741613627, 0.048529448348187634, 0.10434987804582042, 0.08818139322102071, 0.04426020888551589, 0.03996928147370777, 0.0839872763402039, 0.030082033894535516, 0.046031450131727804, 0.04197699874038658, 0.050725010373900016, 0.009399872975453976, 0.032415918840636174, 0.0248294516331366, 0.014508640423657434, 0.08502919422162157, 0.037478852205939835, 0.006321628752630205, 0.1795597173153393, 0.11639907745824707, 0.1500625896357721, 0.06534138574234902, 0.07766856781898007, 0.12291873850288892, 0.22188080444691644, 0.15822662010548577, 0.1891353260725737, 0.15640458722989406, 0.08406648983157451, 0.1783219796995963, 0.1897192995754942, 0.20260712011687218, 0.11609422809053814, 0.16775209606895525, 0.21683570177805042, 0.1660794963038737, 0.15804874981122632, 0.1314865509348531, 0.29465111333035654, 0.20063687987144918, 0.2510601741772506, 0.1509387490730132, 0.14456210898295527, 0.14438987709581852, 0.16615333185801584, 28.290808739200717, 49.68195653730824, 40.69807360249181, 50.730327636964866, 41.86870105804936, 18.080920365548906, 0.4450297295566528, 1.805489421371491, 7.023321995812078, 14.459767630023343, 14.777104047036941, 8.160508303873002, 3.4199248494640475, 2.0204331004811875, 31.94437300005267, 67.90029125828897, 62.078191695674775, 62.5322570339326, 57.62304206048289, 64.53034377867176, 63.0675664255696, 62.6981262237795, 58.649749909677816, 64.05386209487915, 62.6127048461668, 60.74932013788531, 56.52428419359269, 53.092575073242195, 52.97957158857777, 55.737170404003514, 52.03933238983155, 50.76706455599878, 47.48589992523194, 47.709157313069994, 43.7911605834961, 47.60484972307759, 46.660417510617165, 47.89759189851823, 50.37587481160318, 52.1647854774229, 49.90240158573274, 47.54961490631104, 48.080072326044885, 45.21982116083945, 46.12515126505206, 46.14772842776391, 45.63963636275261, 46.388326614133774, 45.88648680717715, 45.568547325749556, 49.83103406044745, 58.22011309285318, 56.623276972001605, 58.15135786610266, 56.72774537917107, 57.39380305813205, 55.41072722404234, 58.75103727463753, 60.65921545028687, 58.33204577046057, 62.99458680614349, 59.82778672249087, 60.68333018210627, 58.625019365741366, 60.053554427239206, 55.36927169369113, 54.48615789413453, 54.28740355276293, 53.83213012449203, 57.7987289428711, 57.583524180996804, 59.56398771655176, 56.309004906685125, 59.33009286080638, 59.24400860263456, 58.52604227681314, 56.43409713622063, 50.531032008509484, 42.056904223657426, 42.86873286770236, 42.43698189335485, 41.70613450388755, 44.54347118254631, 44.530809771630075, 42.22332254532845, 42.71470531340569, 42.031836355886156, 45.2099956235578, 42.56682411316903, 45.46880537463773, 52.314055196700565, 55.75159688149729, 56.02467229289394, 53.877927718623994, 52.54967981769193, 51.25956127720495, 45.29320870676349, 44.66909293205508, 41.72953536433559, 42.07836351087017, 42.86233940432149, 50.050898598086455, 47.49410160126225, 48.761191906467566, 51.53732784332768, 50.41277647018433, 50.32432310042843, 50.54908275604249, 49.40128741725799, 55.87499856948853, 53.371769382107644, 57.40150659315048, 55.13106223075621, 51.7554194696488, 9.00210234426683, 0.19138161844063192, 5.127485557909935, 5.494526249747123, 15.724400570315701, 14.683580033240782, 7.564331081605728, 1.7637409389980379, 0.1742647933743654, 19.854674993022797, 55.635988943038456, 36.99781156355335, 40.536216997331195, 52.73261524015858, 9.225671560533586, 0.5242499012139537, 0.1614516204403293, 0.1554704962238189, 0.16533459837157882, 0.2517863182771591, 0.24574663429971666, 0.10469646388364416, 0.13904871208773506, 0.1558446229225205, 0.14419375858720274, 0.09835914708673955, 0.0828941991072028, 0.19014915150980796, 0.11473511150407215, 0.21156562972934018, 0.09337318640562797, 0.09774251525560695, 0.1640271467547263, 0.1395075834326206, 0.1589405987291567], [0.05772203995635914, 0.035965625542185964, 0.014808785053901376, 0.057648913033546946, 0.003173997313077111, 0.071591537055229, 0.04275507977112167, 0.043546858453942884, 0.10967702364488956, 0.06284302363412515, 0.0585640280417377, 0.03406469327127261, 0.04469633124948991, 0.008200366019962296, 0.014982000406410907, 0.037425007716181784, 0.02889371852600767, 0.019636174153176048, 0.03743041246648758, 0.024940957645735434, 0.018297253559613903, 0.02847092992235576, 0.05919982739273579, 0.04199768694478177, 0.056164472123547915, 0.14095342117211512, 0.05296199094323863, 2.3022731706019375, 36.51536003235848, 27.256201236478745, 33.80284101732316, 39.50343731910952, 18.567355063653764, 0.4824564648011039, 0.35404545044706714, 0.9409951130228659, 3.0912214036910766, 5.968321600267965, 2.6603335959296075, 1.78806294356623, 0.046964001301075184, 12.052083457669905, 58.204721712297015, 59.81371718068277, 60.31533341253958, 56.07392549514771, 60.896950306430945, 61.26362523724956, 56.44209484900198, 60.24042398698869, 57.50125246663248, 58.945069082321666, 58.04417517877395, 52.90692144824613, 50.70462826759585, 49.85104207069644, 49.130879217578524, 49.29401451541532, 44.23128581816151, 40.99574619723905, 41.63980722427368, 41.660623242778165, 41.68411431774017, 44.383869940234774, 53.57441079232001, 56.297877142506266, 58.75539502789898, 54.39801831399241, 49.39814952112014, 45.290804293847856, 43.464278098075624, 42.00665866175006, 40.43527480094664, 40.1500714209772, 41.11436651599023, 42.27243846462619, 40.400314715600786, 42.2420597076416, 46.348283137044604, 52.98696133398241, 54.959321252761356, 56.832829598457586, 56.1944010949904, 57.65182833517752, 54.83804941177369, 54.59417604630994, 57.97323519183744, 54.665994644165046, 55.076329477371715, 52.27026585609683, 54.928981719478486, 54.03016274975192, 54.992912430917066, 51.847136251388065, 52.35328282079389, 55.002969388038885, 57.26935017493464, 67.59733523091963, 55.26615258186094, 55.82572575538389, 54.772949834023755, 53.40404656625564, 54.187457638402144, 50.30741768498575, 42.27826318433208, 38.41751344742314, 40.56124564140074, 39.21633943434685, 40.483143406529585, 38.12217074055826, 37.72918847299392, 38.95275223639704, 41.705706965538766, 39.734347251153764, 38.45305012118432, 39.82186317443848, 39.64530944824219, 46.97892573571975, 50.844998128952525, 54.15905183361423, 52.822241398596, 49.9933260486972, 47.32274109317411, 45.47941930832402, 41.641725263287945, 38.241540232012355, 38.93374835291217, 43.29106623126615, 50.90361010643744, 50.37861654835363, 51.47870802110242, 48.673228832983206, 52.461944241677564, 49.729903590294626, 48.177500078755045, 49.887167099983465, 51.343146985577, 50.766805679567405, 53.58722517567297, 50.85825181776478, 16.526324249082997, 0.055401513668438124, 2.3237802617011534, 5.127834648855272, 3.246000582172025, 5.073479423599859, 6.15056864676937, 1.199882943784037, 0.17104860305065112, 0.08617953652696264, 15.244539764619644, 44.41298961639405, 30.903595609049646, 37.63012116955173, 24.343606041323756, 0.30617617070674896, 0.03513306416871567, 0.11129779756189355, 0.016939483372674837, 0.038797971341879144, 0.0247393386258233, 0.04094088014455573, 0.020027570388910752, 0.021775888369208383, 0.013908287003305892, 0.0374670697736644, 0.013790756666792497, 0.08074799612645181, 0.07208692015058572, 0.043330641628633586, 0.012515831227985122, 0.0429477317318801, 0.04774966660226065, 0.038363833145629016, 0.035562992711821874, 0.030420422591569445, 0.028535377068985856, 0.030758399516344074, 0.010260431032117096, 0.009840181052324273, 0.01415884659265078, 0.03575185636779474, 0.02127960895098025, 0.06146895301137721, 0.006760059435281062, 0.049896811871158506, 0.02924407160119905, 0.06641419994975291, 0.04419615244372718, 0.04190305210349541, 0.03446292109607208, 0.04743379322932132, 0.01908347618976428, 0.041351476458892714, 0.028237366951220942, 0.021457490736558553, 0.0814092985444492, 0.07448298270784079, 0.05285314517095686, 0.06896812258468521, 0.03332000218271729, 0.07377920837532129, 0.09333021653395507, 4.642166283822829, 46.264842556368926, 25.84361453210154, 41.47067070007324, 47.080236634900494, 22.196516298478652, 0.6722507337408682, 0.2424030741977115, 0.43598842116132863, 1.8783154554905432, 7.373552879979534, 5.186300027754999, 4.515602675176436, 1.0626989050257591, 13.185173830678387, 62.02988770700271, 61.15819584938788, 61.57968590336462, 58.6036346035619, 62.23982864810575, 62.387396058728626, 58.501723581744784, 61.1163676938703, 59.899844584926484, 59.849763762566354, 61.14206706323932, 55.18817194046513, 54.91472390390212, 50.688766202619, 50.23698368380147, 50.15496300112817, 47.27248376415622, 44.73874245920489, 43.99980714244228, 44.74805416599397, 45.05806653730331, 45.81216181478193, 53.58200057860344, 59.284412937779585, 59.70846822184902, 55.08634721079181, 49.035604846092966, 46.28780018898749, 45.81558212157219, 43.447517810329316, 42.57835588147564, 42.26367981203141, 42.75562347904329, 41.18934262183405, 42.43567574408747, 44.40069298590384, 48.455176430363814, 55.5372707305416, 56.86775830484206, 58.26612249497445, 58.57867263978528, 59.423880653996626, 56.02071462139007, 56.65712310421852, 59.618457671134706, 55.94497757573282, 57.61460111987207, 53.72522984781573, 55.5627465248108, 57.78355721504458, 56.067273155335464, 53.61505439204555, 53.473401915642526, 58.71883461552282, 58.30399690135833, 60.553119259495894, 57.90812776934717, 57.0938241097235, 56.545441458302165, 57.56069206422376, 54.97546965076078, 54.93344145436441, 44.42131680826987, 40.87436060751639, 39.99692639996929, 40.57576625577865, 41.59986572880899, 40.59424061929026, 40.03742879436862, 41.207518885212565, 41.883578608112956, 40.30868030363514, 41.652809881394916, 41.587831897120324, 40.62804752780546, 48.484766790943766, 52.20889645238077, 54.81410726424187, 51.105435663653964, 52.03375085707634, 48.12088851005801, 46.866490994730306, 41.33301904124599, 40.75025289289413, 40.45134867391279, 44.403909329445135, 51.1589446375447, 52.61041771981024, 53.531437304712114, 51.24951608719365, 52.72527648556618, 51.86708542608446, 50.0503259320413, 53.60329512626895, 52.30522594144268, 53.37023573537027, 54.49344958028486, 53.5862288936492, 19.006982157307288, 0.3096288983379641, 3.47392657110768, 5.480020344257356, 5.704002389984747, 7.15469443028973, 3.5144446549877046, 1.0492519169084489, 0.12202148866509238, 0.05635078470673292, 16.909488824106035, 53.450495273836204, 30.673797668949252, 38.47781204408215, 33.26366416869625, 0.8480723250296809, 0.019559385330085794, 0.017714237666598732, 0.058703157269666274, 0.03846642381000904, 0.027849111675975785, 0.019430638508751027, 0.0579729529037591, 0.04394529312248192, 0.02399746674082933, 0.017320190766646017, 0.02654419772537245, 0.0502098698709761, 0.01959755566091307, 0.018218277555499828, 0.01809723183302389, 0.03287025111457033, 0.07272548507899046, 0.05572699378394792, 0.09415549241126546, 0.08904332640550791, 0.12570203552323003, 0.11520797161445503, 0.12613074598653665, 0.2729798342672087, 0.08518262631109647, 0.09731434105384736, 0.1301122504857279, 0.12831095561024644, 0.2425221242611447, 0.16709221857449702, 0.15964710033468663, 0.17238113638614455, 0.13640953918858884, 0.07569810540805902, 0.13929012171443433, 0.14745209906851092, 0.08340082837328797, 0.06957042091075452, 0.11131640583757432, 0.11922922075515795, 0.12401396844295726, 0.1432443917879174, 0.28961132731168504, 0.1356242224574089, 0.1603589951992035, 0.3161419633655779, 0.22884273571112465, 5.017930326923247, 53.16760609226843, 38.565441716101866, 43.63156326355473, 53.26387674577775, 29.557326378360873, 0.9839865577317054, 0.8635026228524024, 3.821834431540582, 9.88652229309082, 16.518889396421372, 10.79319384790236, 4.405466933404246, 0.8643592317258159, 13.910715233895088, 62.76762670086276, 63.22997216255435, 64.47057077961584, 61.7380908227736, 66.2609209552888, 66.00869686372819, 59.11712777230048, 63.20243712394469, 61.716494252604825, 62.882669818016794, 64.83823807008805, 58.09336170073479, 57.59547564291186, 54.286026800832445, 53.478736339076875, 54.49102555551837, 49.99358492512857, 47.24675301582583, 46.60779891475555, 46.23824104186028, 47.554298216296786, 49.051792467794115, 58.43054433022776, 60.24714300709387, 64.96955117871686, 57.50863828966695, 53.65941639869444, 48.98672426900556, 48.169459219901796, 45.515940496998454, 45.059019673255186, 44.10530321059689, 45.53721935518327, 43.78991719215147, 45.085585886432284, 45.167559500663515, 49.38220900873984, 58.30547563491329, 61.19246167521323, 62.10417739806637, 58.766361974900775, 61.425736796471384, 58.24464751828102, 57.9214834397839, 61.407474240949085, 57.122665297600534, 57.44478994800199, 52.55963479318927, 56.131521578758, 59.01008629029798, 58.002747105013945, 54.434198256461855, 55.78157947909448, 59.59915960988691, 62.08546769234442, 63.10818256870393, 59.42893658914874, 58.73754824361494, 57.90869651302215, 57.89220294644756, 57.407605878768436, 56.503436796126834, 47.2956100586922, 43.13132770599858, 43.06443952745007, 43.22950855378182, 43.632575235059186, 40.99725238738522, 41.09636675926947, 43.598238806570734, 43.95961853765672, 41.73280269868913, 42.69955319743003, 43.52773028035318, 42.23345010511337, 49.74551070121027, 54.8109144549216, 57.07521638562603, 55.648097299760394, 54.84068132215931, 51.65642276886971, 49.18735350331953, 44.92057569565312, 43.176548711715206, 42.18372621843892, 47.3691858783845, 55.82438822715513, 55.833672477353005, 56.76586297250564, 51.9593591843882, 57.423244368645456, 54.474916381220666, 51.92186524791103, 54.88330964119204, 54.89673591429188, 53.88005756562757, 55.23445983086863, 53.09881948655652, 20.826518689432454, 0.2745138487267879, 5.794219845725644, 11.21633521972164, 11.871200415395922, 12.824042189505793, 13.812553997962707, 5.576845522849791, 0.3587828462402667, 0.28861706776003687, 24.596540081885554, 54.674415972925004, 38.841584420973255, 47.50931255279049, 38.44569567711123, 0.9889878248495441, 0.09727789059041009, 0.2125546185960693, 0.2271640685296828, 0.21708797453151596, 0.14713933601254417, 0.13366199549167387, 0.08650508559038562, 0.14256580642634822, 0.1469049590729898, 0.14884555171574318, 0.13814423804081258, 0.21517416432259545, 0.13184445189131846, 0.1028382333536302, 0.14096094415553156, 0.13655400804934964, 0.12052616164568933, 0.08437752918971163, 0.21608813785977904, 0.12979282246481988], [0.08632258812506353, 0.009806010658071648, 0.08714066277588568, 0.03788064617002684, 0.08694339513538346, 0.028165209129632964, 0.06749396257463001, 0.009113804253208782, 0.040820964401768106, 0.04782383157421024, 0.07622789351209518, 0.045324201590471694, 0.046082793344413085, 0.006748935838620509, 0.042805358121592196, 0.030143370724193035, 0.01989937898132109, 0.05834327597591666, 0.025006326013094476, 0.011834232268043825, 0.03107301458986777, 0.11537724640220405, 0.048015529755502946, 0.03177053381448552, 0.02185339731494746, 0.05923114506708038, 0.0760643337402613, 0.023953435837381312, 17.542080840756817, 43.558120804448286, 22.396778791181504, 38.47258744701263, 29.33246670230743, 3.634273063751959, 0.10872570332139732, 0.3575895264023735, 0.9568950533866883, 5.860612334743624, 4.062153394183805, 4.460563976918498, 0.18991813003536195, 1.2930316357843339, 38.70401513191962, 63.60758266141338, 61.04005013742755, 60.23658790896016, 61.390396241218816, 60.68581696479552, 61.45050264173939, 62.80674842096145, 57.849174545657256, 56.348918945558616, 53.13384232982513, 51.13544964021253, 50.54020250997236, 49.927673416752974, 49.09414229854461, 47.37248459169942, 42.27643143746161, 42.364622008415964, 42.52659628468175, 43.788089367651175, 42.83445135239632, 51.799451997203214, 56.64449699463383, 60.0867102223058, 56.957466833053104, 56.90417358952185, 57.965504200227805, 52.73049716026553, 45.936238150442804, 42.33433738831551, 41.493589108990086, 38.608305377344934, 40.56726647961525, 41.311296955231704, 43.22753167921498, 40.253712208040305, 42.70448361673663, 45.02964504303471, 49.940225001304384, 54.13727483441753, 54.02777794868716, 57.168764914235766, 57.27736357719668, 56.69276960434453, 55.56395853719404, 54.14078535572175, 55.39333935706846, 50.25500697474326, 51.37936615174817, 56.091070175170906, 57.93301128572034, 54.73449883922454, 56.53926764765094, 54.73081573363274, 57.070607600673554, 70.29422360081827, 54.48975862995271, 56.051085533634314, 57.69155017791256, 51.387756101546756, 51.01599385661464, 45.985675704094675, 38.53186230505667, 38.02589616467876, 39.45740046039705, 38.835218414183586, 40.47024665340301, 37.86419253195486, 41.78605671851866, 39.26431002155427, 40.663117439516135, 39.11513051679058, 39.109184203609345, 40.297372110428356, 39.316434398774184, 44.436033541156405, 50.05580156080185, 50.94896839511011, 51.35398057199294, 49.09468358562839, 48.317716967675, 44.075320612999704, 41.2740618951859, 38.02561375402635, 38.643798905034224, 48.55739731942454, 51.82844615751698, 50.855141378218136, 50.87118387222291, 51.09158577457551, 53.69120328657089, 49.412850564525975, 52.368380023587136, 49.68044250242172, 55.580867875006895, 50.147118260783536, 53.48332158980831, 23.560371475835, 0.2800379248876726, 0.5716701921436095, 3.0067570844004234, 4.713203349421102, 3.188745989914864, 5.049328409856366, 2.3515915822598243, 0.7259385431966474, 0.03486445842070445, 0.5065016358369782, 28.035686016082767, 40.19209177263322, 24.709888735125144, 38.468512104403594, 7.698636468379729, 0.06490892910909268, 0.02929209382273257, 0.06825399840430868, 0.042774542234838016, 0.01456183948433928, 0.059744638480967095, 0.05403455617206712, 0.038327060925263556, 0.03158728558299763, 0.09529196086429781, 0.03624045958502158, 0.028225144018389048, 0.0699038070536429, 0.04164427526355271, 0.005311425953667852, 0.019621019018813968, 0.019208262336530516, 0.01419689243419036, 0.07211890432142443, 0.013054572984636312, 0.07546512274852685, 0.07946916555445041, 0.058557933812300046, 0.04521158283516284, 0.043578053554219585, 0.05697575923536093, 0.03728703911145849, 0.01728462896520092, 0.03421965370615644, 0.024323743587780385, 0.038218046613638444, 0.03702569970740907, 0.022503235227157994, 0.048463078320867596, 0.04303053434517595, 0.05877497035168833, 0.007911779262470983, 0.00862543373518894, 0.030735324948064746, 0.06579536944627762, 0.04511145897389901, 0.020177235241017995, 0.065953612567917, 0.04801482878505223, 0.03740689739765179, 0.085879965505052, 0.02891966592400305, 0.06858244328008545, 0.08068838682506355, 26.08919805096042, 42.9368212915236, 23.842654651211156, 50.643827607554776, 33.78732804329165, 5.141396243726054, 0.27598970179115573, 0.24601675690181796, 1.6966632609405827, 4.495598097001353, 5.968853081426313, 5.662883693172086, 1.330041894989629, 1.74898584042826, 43.36985488091746, 65.08283315166351, 65.22567018385857, 61.131747307315955, 61.299169755751095, 62.032170526443, 60.71459931711997, 63.72090385806177, 59.58034007780014, 60.05603728755828, 54.40112875353906, 53.89308767934, 52.4036931222485, 52.39036490840297, 52.20894744319301, 49.89699655963529, 44.72047990368259, 42.81895014547533, 45.59132452934019, 46.95690554957236, 45.506973958784535, 52.16231438421434, 60.735517317248934, 60.072487708060976, 59.27576411154963, 59.331889306345296, 58.19915194665232, 54.99870577166158, 46.83349993921096, 44.473649071108916, 43.207821769099084, 41.113746781503, 43.02471768471503, 44.44499615700015, 43.4793282324268, 42.26802972055251, 44.10596609115601, 47.9604047344577, 53.299754665743926, 56.7245525698508, 57.71073056805519, 57.42298549221408, 56.22316775783416, 57.18189700957268, 57.09937034114715, 55.94406366348267, 55.131454467773445, 49.90794389478622, 53.30663058065599, 55.81146793980753, 57.95188965335969, 56.489210359511844, 57.732472265920336, 56.48060860172395, 57.29680676614085, 71.21105409437611, 57.20254436615975, 56.35524180627639, 58.7271539626583, 54.46495748335316, 54.53532872661468, 47.87490098707138, 39.826067955263206, 40.4030329181302, 42.06912240674419, 40.88597474559661, 41.84471968681582, 39.82310264341293, 42.95513483785814, 41.2360776624372, 42.8145335566613, 41.248182096788966, 40.39980480747838, 41.85506297696022, 40.175998287816206, 47.01031646420879, 51.61880331654703, 53.79497351184968, 53.243919726341005, 50.842629017368445, 49.19649262582102, 46.79595501192155, 42.915581657040505, 40.64534910263554, 40.00990944523966, 50.108059298607614, 55.703222290162124, 52.464062321570616, 52.224381969821074, 53.800464830090924, 55.12850092303369, 51.91979815883022, 53.705508170589326, 52.26865768432618, 56.656350397294574, 51.007968687242084, 54.96225126328007, 27.39193681747683, 0.49974590479846925, 1.37049354372486, 6.1192127293156044, 5.698263962422648, 4.677979974977432, 5.204327731363235, 2.6356854217667736, 0.1294886242718466, 0.07143774490442968, 0.9731901112583377, 29.518016384493922, 49.78330666019071, 25.41609383398487, 44.54750730145363, 11.564110209864955, 0.07374027578700935, 0.03719633047078406, 0.06825834978371859, 0.0717422342108142, 0.03303358872090617, 0.030114152130760977, 0.023305415468771132, 0.04187468769809893, 0.04929431053178926, 0.0684318840203266, 0.018173032402691823, 0.04059037193655968, 0.021675839201517163, 0.022830191977141846, 0.0187285419087857, 0.0808289256547728, 0.019857925963738275, 0.011113617407728829, 0.009904861855771272, 0.041430613341470884, 0.06778964953076455, 0.11132982003712848, 0.12181460662114045, 0.16687802039086821, 0.13569628068756673, 0.23560939116343377, 0.10581452324385605, 0.15751020532221566, 0.13229144887337763, 0.23273817023202298, 0.22251664210231076, 0.1901073997179347, 0.16574243293894877, 0.19720374876933713, 0.18466538689549894, 0.19697335548698905, 0.14047967239974007, 0.10581955644151858, 0.1086816379439927, 0.1525200618010375, 0.24585662920388485, 0.12774886157844337, 0.2068642553903403, 0.12085377148562863, 0.14580402943876483, 0.20931621172255088, 0.16291222835500396, 0.23618205720859192, 0.30200721215336557, 28.140782002479803, 59.62517276886971, 31.13113622511587, 47.562433212034165, 42.86982720898044, 7.214063915514178, 0.4606498026799771, 1.139360526877065, 4.171840269719401, 16.49395881160613, 10.245089684763263, 9.7907684118517, 1.0837040553169868, 1.8613736355496993, 42.71496811220723, 68.00726213762837, 64.68194730820196, 63.38762006452007, 64.16158214692148, 62.50079178041028, 64.75424835758825, 67.23571623525312, 62.184268274614894, 61.801695977487874, 56.03913014934909, 55.269623879463445, 54.61248959264448, 55.15766766763503, 55.28811785482592, 53.404925177174235, 46.778794642417665, 47.97301515456169, 49.125925264050885, 48.34240044316938, 49.43619258942143, 55.83557482688658, 61.63650143531061, 63.1531996111716, 61.202863800910215, 61.40834892949751, 60.93606025941911, 57.706659147816325, 50.6853380510884, 47.979604736451186, 46.04444849875666, 43.39609553737026, 45.310953509423044, 46.31689633092573, 46.42206291998587, 44.262119570086085, 45.67638504889704, 49.56859219458796, 52.84210035877844, 58.97624800282141, 58.90113853639173, 61.29740861154372, 61.29840097119732, 59.4907452983241, 57.89304625603461, 57.89193622527584, 58.26782872599941, 50.62540423485541, 53.90410169478386, 59.34027533377371, 61.707916029037975, 59.075303539153076, 61.133869309579175, 58.339859131843816, 61.21251675390429, 72.40079525978335, 58.464547357251575, 57.580805978467396, 61.06705957843412, 54.44222342583441, 55.57968724158503, 50.205953813368275, 43.26558651462678, 42.81159962377241, 44.16017324693742, 42.356526236380304, 42.65850167120657, 42.13168028862246, 45.98288689890216, 43.87503262489073, 44.58518166695872, 43.57315524931877, 42.77229355227563, 43.44374841259372, 43.673826802161436, 49.41630225027762, 53.52590676276915, 56.06183675027663, 55.72362645979851, 52.725480448815134, 50.9020999939211, 48.69266025481686, 46.764854538825254, 43.69755321933378, 40.35840419030959, 54.512265190001465, 56.82584385718069, 53.05901135167768, 55.58035012214415, 54.97099030402399, 58.10841183508597, 53.9018149529734, 55.10238970479658, 53.701640713599424, 58.99362018031459, 51.94650557733352, 55.93998047613329, 26.97766980817241, 0.7982400215921864, 0.9164741094554625, 6.228121259520131, 13.22122629611723, 10.223783369987242, 12.234712935263111, 11.246471770348089, 1.885078602260159, 0.17679456891792436, 1.7332776059066097, 39.06052327925159, 52.438374719312115, 34.381516133585286, 52.18391487675329, 14.767343228863133, 0.2388168174412943, 0.20931368363240074, 0.14076709326717163, 0.14854955066355968, 0.15743502145332677, 0.1683279490398784, 0.1857563267431913, 0.12088101357221605, 0.10080743385779281, 0.23982014747396593, 0.17058974702752408, 0.11838155212782084, 0.0988986874900518, 0.17544015611131347, 0.19849105227378108, 0.21447752992953026, 0.08706301976475986, 0.12892055475423414, 0.15318193112409886, 0.15954157938399624, 0.18618176601106123], [0.02858141129235587, 0.03276736167589984, 0.031996702121931224, 0.042353936981770306, 0.08211537114074154, 0.012791530950175179, 0.036976378966843894, 0.10263711229086885, 0.03557215512339627, 0.06347706481333702, 0.06416041524179521, 0.026409419876853787, 0.04787656523647809, 0.006386149156418059, 0.046415578108280904, 0.06149927477142023, 0.005171642199368967, 0.02782720922222061, 0.07842187739668355, 0.07216592679821676, 0.008201040177335663, 0.04346329358316237, 0.04754785222992782, 0.03037572327640749, 0.051824373358319846, 0.002025995166942237, 0.19955389201641086, 0.031576058564467296, 1.3892007979654497, 35.07044123065087, 30.46698677924372, 29.906635015241562, 41.68517728005686, 14.955898427194166, 0.08479813444277934, 0.061743767902014725, 0.5676375053101971, 1.2887525750744728, 6.20368734482796, 6.292092665549248, 1.261585258668469, 0.3042451388412907, 6.4304366227119205, 54.71692269848239, 61.17361076416508, 60.14049768447877, 59.494232285407286, 59.90708920263476, 62.64322480847759, 60.25837667526738, 57.60968639004616, 52.52766747628489, 53.08281621625347, 51.7563686832305, 50.79057916518181, 51.31756920968333, 46.0614872747852, 46.47882353874945, 42.77864386958461, 42.31349391321982, 42.92528952321699, 42.797377109527595, 51.4861056112474, 55.77639410572668, 59.891019252038774, 57.695833406140736, 55.72973751252698, 58.8630719338694, 59.034389295885646, 57.38729192364601, 51.888321138197384, 44.88721593733757, 40.73558322844967, 40.38082053584438, 40.8362743931432, 40.96283751149332, 42.74246784948534, 40.94513977727583, 42.44964722664126, 43.6890063747283, 45.28175538586032, 50.16281558621315, 50.23808979219007, 55.05600375513877, 55.05539186539189, 53.44237204520933, 56.44910412449991, 56.416611209992446, 58.28476552040347, 48.33506168857698, 49.29845463845038, 55.226905345916755, 55.646920588708696, 55.64415139536704, 56.59228240289996, 53.99563020275485, 51.54960093959686, 37.43714840181413, 54.32377961374099, 53.27250988252702, 53.8805204053079, 52.18048280285251, 48.14441488635156, 39.742760735173384, 39.81076286685082, 39.33965483019429, 38.52543354034424, 37.71950806340864, 40.00275111967518, 39.80886051731725, 40.11976326665571, 41.83388610039988, 40.887720200323294, 40.88464113973802, 38.052278026457756, 39.515361324433364, 38.659594289718136, 42.007803993840376, 49.58901597607521, 51.003406970731675, 52.45973986964072, 48.08774840447211, 50.20045072801652, 46.336582706820586, 42.38628525887766, 38.510889391745295, 39.59195736915835, 45.861607213174146, 48.95012855529786, 50.77579575200235, 54.37922623849685, 52.50716132502402, 51.722322510134795, 52.245523545049856, 53.9144253730774, 51.72062020148001, 53.27938579743909, 50.97665248378631, 40.86803774679861, 1.8533380473813705, 0.47469115245246124, 1.964094259085194, 4.902213052395852, 2.123022814912181, 3.0250426838474893, 5.920023495151151, 0.6512812525033951, 0.0508755045161853, 0.045335283052296414, 5.181387749410445, 45.742304402012984, 26.493731698682232, 31.91817548967177, 35.463364662662634, 0.8576664424711659, 0.11515117385574888, 0.12144344468270579, 0.05944966015616252, 0.03307424883748735, 0.05779510176169777, 0.07231863110416359, 0.04340957932835145, 0.07527579943979941, 0.031511327965305216, 0.03250265148498359, 0.03503361063438558, 0.04328400219580339, 0.048363483060271516, 0.046483939964204066, 0.09020544348224517, 0.017914722876382932, 0.012135289500527566, 0.012844649571624976, 0.021227781187682863, 0.04098928541005139, 0.052035886403774066, 0.011283861296702058, 0.051533007138078256, 0.031020725258596005, 0.017787795513868332, 0.01782017613520786, 0.07423497706411347, 0.05711779576696216, 0.12011730818138008, 0.037671668875601985, 0.045334493981734406, 0.04087433774745272, 0.05045749247074128, 0.0235398096453038, 0.0048847154586485805, 0.03979835959692155, 0.026051331228846987, 0.05577095956992238, 0.021682396914149006, 0.0738651711013048, 0.05063612502248538, 0.05825117305522004, 0.0470774014660668, 0.018597387656148885, 0.021940700694798462, 0.035132470450574355, 0.03135755879714364, 0.07069970345905713, 0.03481953119438502, 3.98423477526634, 47.38764847478559, 25.15329307125461, 35.38256383711292, 48.8882060973875, 15.4523322274608, 0.2017157308516964, 0.07582292411356203, 1.4165015975313804, 2.059728998330332, 4.787801927135837, 5.021633534662185, 3.319690395747462, 1.0574646246048713, 9.459967478629082, 56.47889452595865, 60.59899137866113, 60.848277614962676, 59.98594061020882, 60.855608524814734, 64.4578544555172, 63.64459806872953, 60.18506365437662, 55.734781680568574, 52.999265809212964, 53.8818383216858, 53.53250811176916, 53.416813881166526, 49.905547326610936, 48.25586511242775, 44.471738876835, 43.807767898805686, 44.477485149137436, 45.48067838914933, 52.92614106209048, 58.46036218827771, 63.07576025685957, 59.185290721154985, 57.99270191500264, 60.53943018759451, 61.38814480073991, 59.42600265625985, 53.73159977697558, 46.91352805783672, 41.713626230916674, 43.54971124279884, 42.82808534560665, 43.26409209159113, 43.59286123706449, 42.217215414970156, 44.64634318505564, 45.22921915977232, 46.960392536655554, 51.5949200045678, 52.838456476888354, 57.48142880778159, 57.30927990328882, 56.80615355891567, 56.65446373724169, 58.24470635383361, 58.89206609418316, 49.52754851310484, 49.67448442212997, 54.73254157650856, 56.664838406347464, 57.614381467142415, 57.09854664341096, 54.31142414769819, 52.91621746555452, 44.247606800448516, 55.18931727255545, 57.258065515948886, 55.58196221628497, 55.60356663119409, 51.222298760567945, 43.06699691280242, 41.99237338958248, 40.75321428237423, 41.28686451142834, 40.63888503659157, 40.06839982924923, 40.91915799725441, 41.91827981702743, 41.78855134594826, 40.71463384935933, 43.54842470538232, 40.883174173293575, 40.51343979374055, 40.26467131030175, 43.88669383141303, 51.72750003876225, 53.00677322572278, 52.53326862089096, 50.76941405573199, 50.894616111632324, 47.82586743754726, 44.77884477184665, 40.311300446910245, 41.208538701457364, 49.77856843702255, 50.55047911982383, 53.3093213265942, 55.197742523685584, 55.36187802591632, 53.422968079966886, 54.99900779416485, 53.322347517936464, 52.72281323709796, 53.576183703637895, 51.96190480263003, 43.10353771332772, 2.4601610725925815, 1.5590632057959035, 3.7041873508884064, 7.7452960033570575, 7.637743632639609, 7.18913431129148, 6.307511502696622, 1.1002010539654763, 0.2791328992574446, 0.10366065172298301, 4.781198616950743, 52.58929575643232, 33.153822114390714, 31.310888644187685, 42.19652883468136, 1.6697517566142546, 0.08650376791915587, 0.06109361589375523, 0.0801248831914798, 0.02323723172829036, 0.020825422233751705, 0.01726928230885777, 0.023571598463721817, 0.02313330041004285, 0.032313335837135394, 0.033954587284355395, 0.032255346811706984, 0.031017833276681846, 0.0921342536927231, 0.015705842412106933, 0.047436148949688485, 0.04946630876210909, 0.07171981847814976, 0.05540003894918388, 0.06028469982406786, 0.05348244426591743, 0.01698182888268944, 0.16814293880616465, 0.21918582970336561, 0.11537789757693968, 0.1004941728446753, 0.13670946261094463, 0.16540920001364526, 0.0930487864740914, 0.21872239247445138, 0.146412854833949, 0.19581273228170412, 0.12432624120265247, 0.11976078618317844, 0.14135097483954123, 0.16437150327669037, 0.11612749928908965, 0.12011077345138597, 0.14488449410325097, 0.0780155137181282, 0.15082870820356956, 0.17208963993095583, 0.1362761632809716, 0.10900996024570159, 0.10571602731943132, 0.12180580427089047, 0.15811867831695467, 0.14570929500604832, 0.23126965628996973, 0.21513074245904723, 4.6546997274121935, 54.55841579744893, 45.140746178165564, 39.74904437218943, 54.32871787778793, 25.566665780159738, 0.23201513644908708, 0.42465859363155983, 2.899583712700875, 8.1381473618169, 13.47344450412258, 13.75888812926508, 3.945893851980087, 0.6300095649015519, 7.662633522864311, 57.23855956908196, 61.613924272598766, 60.79516480045935, 62.09457935825471, 61.73478818708851, 67.1259996967931, 66.77844632056453, 62.5904885415108, 57.03796171372937, 57.62534841414421, 56.74353291911464, 57.30580076094597, 55.94131408199188, 52.62559729237711, 52.36700327165666, 46.53061451450471, 47.5994368522398, 47.20728220478181, 47.37412022006127, 56.33267248830488, 59.337572820724986, 64.6659871839708, 61.44749418381722, 61.74354291731312, 62.25105839390909, 63.455229959180286, 61.640619923991544, 55.369836514995946, 50.20941334386026, 42.954852427205736, 46.003961793838016, 44.62495450050601, 45.648402860087735, 47.26431346708729, 44.279840838524606, 46.575517808237386, 48.293292368611986, 48.56158641076858, 53.93428825563001, 53.2407190722804, 59.96695633857482, 60.48655271530152, 58.34448752864715, 58.03440847704488, 59.701788425445564, 61.76438639240881, 52.37382035101614, 51.59259796142579, 54.229121054372484, 58.98154320255403, 57.97769492672336, 58.882420985929436, 54.43581035060268, 53.89424477854083, 45.59548224172285, 55.77436624034759, 57.51631436809417, 57.562896436260594, 57.072902187224365, 52.49162089440131, 44.10930795054282, 44.522309995466664, 44.701323047761, 44.28011540443667, 42.395906832910356, 42.54223869692895, 43.07547707711497, 43.839543019571614, 46.19758567502422, 41.49755854760447, 45.410824898750555, 42.79271733376288, 41.92794061476185, 42.84062124067738, 46.976384039848085, 53.163495448327836, 55.744513080966094, 56.76746722190612, 52.70298957824708, 53.0610352946866, 50.60707892141035, 46.409268148483775, 42.35504358045517, 43.07400226593018, 51.959155221139234, 51.86490458826865, 55.032398931441776, 58.07706425266882, 55.32016361913374, 55.544923274747795, 56.41315167950046, 56.87192386196506, 52.161518143069365, 54.60885355549475, 52.7378829833, 43.91619789984919, 2.6049033960988446, 1.5731439018441786, 4.687876114922186, 12.154539688940972, 9.161236824527863, 9.536983216962508, 16.94057360772164, 4.264996561311906, 0.7072076934479898, 0.23719902360631576, 9.469983250864091, 58.66912249595889, 37.16818755672824, 42.12432976691954, 50.646216330989716, 1.9264537240228348, 0.26739174379937114, 0.2228429036275033, 0.1506331872435347, 0.13125281750915513, 0.1049313541021078, 0.0792530368292524, 0.07871342747802697, 0.16549466478247798, 0.10264596826727353, 0.13004932402362748, 0.10581243948470201, 0.22312822541402233, 0.15776572628848015, 0.13113821075568277, 0.15523504676117053, 0.2686783731464417, 0.21448221838762685, 0.09882962466367791, 0.10201917811026497, 0.1378437323916343, 0.12780061847860777], [0.02584153996600259, 0.03795611732188733, 0.019678787793964148, 0.05169027732805379, 0.04491708331531094, 0.01760043722066668, 0.03194116840830013, 0.021060588243868084, 0.04879672110321061, 0.021724127638604374, 0.05852382757791108, 0.03545097533553358, 0.05752683692281285, 0.04020145208004021, 0.01028211419320395, 0.030339399217477733, 0.062135146900771134, 0.015432056952117672, 0.05438350539113726, 0.05999270541172835, 0.03342956424720826, 0.0014126682869954818, 0.09497237962580497, 0.05545275345925362, 0.061872344268786336, 0.09662441759099884, 0.11029626017496472, 0.13574927865016845, 0.06172064736845994, 12.833849095529127, 45.297825336456306, 24.154128105409686, 37.736417401221495, 33.37835427253477, 2.956734117000334, 0.11678523173735988, 0.8354133043077685, 1.5347600776341654, 3.076337479775952, 3.079201790594286, 2.8367848502051447, 0.4677904775786785, 0.1284427610376189, 10.082233855801245, 62.59650153498497, 60.45029040305846, 60.189189987797896, 63.48449868540611, 57.71596693223523, 58.17841829792146, 57.20267772674561, 54.34160286380399, 53.63319535409251, 51.293772189847886, 48.6868316127408, 47.57463178327007, 45.387753517396995, 44.27705595570226, 43.94053228439824, 43.80908189281341, 42.598846343255815, 47.23738639585434, 55.353805788101695, 59.22701689504809, 57.18655286296722, 58.184772537600615, 58.66630231180499, 57.731417148343986, 58.44277428042505, 58.087038840017016, 55.923361393713186, 47.265913794117594, 43.52403540765086, 41.023587180722146, 41.44082538543209, 42.77045396066482, 43.846065921168176, 43.174662051662324, 42.71571336253997, 44.25973869139149, 46.555815742861846, 49.09790777391004, 48.412744229839696, 51.32792034456807, 53.139266967773445, 53.827968489739206, 53.11045323648761, 55.13446292569561, 55.75968088642244, 48.107458314587994, 48.637805907957016, 53.47857944426998, 53.42579610886113, 55.567943665289114, 55.242563447644635, 54.95095875955398, 53.183676042864406, 43.37027849689607, 57.092635631561286, 52.662848041903594, 51.932722368548, 48.46486468468943, 43.228535805979085, 38.79206841991794, 38.56459840651482, 39.781462761663626, 38.93838459445585, 38.961961961561634, 40.24588315717636, 42.32005603851811, 41.45909970806491, 40.43057187911003, 39.736359427052165, 41.6703664102862, 38.174601062651604, 40.09089462218746, 39.98257836987896, 43.09272766113282, 48.48206427789504, 49.30040013405585, 51.21739972022272, 50.41310594927881, 48.569254644455455, 45.820924389746885, 42.587365565761445, 42.53025585605253, 37.71095337406282, 42.97772376768051, 44.84353642309866, 48.78397303242838, 47.37550873910227, 49.16566671863679, 49.52678365092124, 51.26104393313008, 51.14625184766708, 55.10472351504911, 52.7873166145817, 53.41037334934358, 14.014275612369662, 0.06548492763672145, 1.1394728047232474, 2.579162351546749, 8.84399748617603, 5.844290862160345, 5.490242531222682, 1.8191371858119967, 0.5966160374303019, 0.0431752598453914, 0.024500545189385454, 19.0353173594321, 50.271932002036806, 21.631677342999367, 37.500263260256865, 19.260963470705097, 0.07727623887119756, 0.08136889506732264, 0.0348862114873144, 0.07417575080668734, 0.06879210622320253, 0.10128096812554907, 0.013413042761385443, 0.041752511995934674, 0.005569126440076939, 0.012492597696461506, 0.03596734157913635, 0.06835004284737572, 0.032150251039814566, 0.018922452168959766, 0.014534516958519818, 0.03653597034093353, 0.058806452734936634, 0.05310278258196289, 0.11345087235132534, 0.01696751644504407, 0.03857339649731594, 0.022256679404827378, 0.04417081791607123, 0.04832119883729085, 0.01827659791395549, 0.03549845363464087, 0.027534178675963517, 0.041579943030111255, 0.011829435600027924, 0.04546035839725406, 0.02192733246051977, 0.054309210184240536, 0.18708702146766648, 0.09010766768046925, 0.028532751302625385, 0.06423363026471869, 0.05481713796935735, 0.009768890825310543, 0.046064709838960445, 0.01355805841740221, 0.013981748131975053, 0.049876981685238506, 0.05110235464188361, 0.044521743641986, 0.05910326967075948, 0.009528740455636816, 0.025131470305965315, 0.0704740139565641, 0.04813555658103959, 0.043049797626031984, 0.23755508595176283, 21.656892299652103, 49.357886391301314, 22.43139566913728, 49.55264775983749, 38.38656594676357, 3.247109877486383, 0.05945944309895558, 0.8291524047813108, 1.1415679632656037, 3.481800238932333, 6.087042429754812, 5.798709488684132, 1.8391041337482392, 0.6334309748584225, 14.86686650783785, 65.72237560825964, 58.850673321754705, 61.428176510718565, 62.8521930017779, 60.248166745708836, 62.1658056782138, 60.433169257256296, 56.01234036107218, 56.20908252654537, 52.5112170557822, 53.15402684673187, 50.6479892423076, 47.740763771918516, 46.92062362547844, 44.64680994710615, 45.28944323139806, 45.06950024635562, 50.314525019737985, 57.59115711335213, 59.71424587311284, 59.76371872809626, 59.99651532019339, 58.737556088355284, 59.671480271124075, 60.160792027750325, 58.00587715641145, 58.357282300149244, 47.75801435593636, 44.249913154109834, 43.40629369981828, 43.32710889077956, 44.34924325635357, 44.667053299565474, 44.18919878621256, 43.855475687211566, 45.3307536340529, 48.812202330558534, 51.419586135495095, 50.37146998989967, 53.52655003147741, 54.88069734265728, 54.1326738942054, 53.54555783733245, 57.666756876053356, 57.938067220872455, 50.99141236274473, 52.1961683611716, 53.47714385678692, 53.57980797367712, 57.15005128614364, 56.93856493119271, 55.17191371610088, 52.714136954276796, 44.03095076161046, 58.10913355119767, 55.96681733285227, 56.088046027768044, 50.138257626564275, 44.74097428783294, 42.51591567070254, 41.083438627181515, 41.074840791763805, 41.06818452958138, 41.10914976366105, 42.97775906901206, 43.7029621678014, 43.86993354366672, 42.60888761089694, 42.82301764334402, 43.62219272121307, 41.05511519216722, 41.355384395968535, 40.683462773599935, 44.224825674487704, 50.447485523839156, 53.05312779641921, 53.2434529642905, 53.39966135640299, 50.62602789171281, 48.433407275907456, 46.059286825118534, 43.643004817347375, 40.76305943150675, 44.334608893240656, 47.16066875765401, 50.338879016137895, 50.475263749399495, 52.25953425130537, 51.71408161040276, 53.595505299106726, 53.17266594979071, 56.56764207347747, 52.26396652960008, 55.18237859972062, 16.33812108347493, 0.2411537533325534, 3.166626028476223, 4.903514788996789, 10.421944452870278, 9.519908159009873, 7.5554660347200215, 2.114094274659311, 0.4132828314698512, 0.06804383750404082, 0.10853541474188529, 19.061326596044726, 62.29552630455264, 24.08241737273432, 40.91414913054436, 25.83869587990546, 0.07160174134638041, 0.04698103143563194, 0.020838834518086047, 0.04903255360982111, 0.023657854218336365, 0.00893489016415251, 0.02846269447716975, 0.11964446339275568, 0.010495040670878465, 0.0643192865555325, 0.06428748624579561, 0.04691799772122214, 0.030726141469072432, 0.058908001519739635, 0.026278794224884723, 0.015388470379665736, 0.04070289876131762, 0.06240028227048536, 0.029501940626951478, 0.07123914427093922, 0.08394942393586521, 0.03479302838264454, 0.13254502397631446, 0.2662577804538512, 0.14092115354874443, 0.13452744501973354, 0.17379654511328668, 0.1958832123707379, 0.11540552270748924, 0.16027910755045954, 0.14208238962436878, 0.11063303242647841, 0.37197120307433995, 0.16474670249848597, 0.1278640735413759, 0.14832140967970894, 0.1478217058484593, 0.14982605232827126, 0.18776162317202938, 0.05878447367238903, 0.12687104739128582, 0.17995796046189724, 0.20167785546471997, 0.20733979680845815, 0.29969310568225, 0.12979806250622197, 0.14711062303714215, 0.2350771132736437, 0.22588424204337984, 0.1760678579129519, 0.2879249532857249, 28.615116188603064, 61.64001587898501, 35.70962675156132, 47.000734113877826, 47.9540426500382, 4.969135551683364, 0.4296653152954194, 2.4467963316748222, 3.3423300712339343, 10.678786154716246, 13.282846731524314, 6.707808990632334, 2.8411747178723736, 1.0160633945657362, 12.708279317425145, 66.56887408225768, 59.740490451935806, 61.929879034719164, 66.74178784893405, 62.015559288763235, 63.95625391314107, 64.20768960829704, 59.66357669522686, 58.651354159078295, 55.58333896821546, 53.54986459978166, 52.413306851540845, 49.84292668680991, 51.34692422805294, 47.76176021945092, 48.001915177991314, 47.15140019693683, 54.12697469034503, 59.05135354688091, 62.890192924007295, 62.02420811499319, 61.78401785512125, 62.499379727148245, 62.91506859564013, 61.02136788829681, 62.60637806307886, 61.612837776061035, 52.04812634375788, 47.075474877511304, 45.23606761809319, 44.70168390581685, 47.03827511879706, 47.279536185726045, 47.42683295280703, 46.457101452735166, 47.08661048643051, 52.970475612148164, 52.540528928079915, 51.87980959492346, 56.74125402204452, 57.25213881461852, 57.936000131791644, 57.34700525960615, 58.618908313012895, 60.67847036546277, 51.83155267469345, 51.711414398685584, 53.83737433341242, 55.15108985285605, 57.20707470370878, 57.175864404247655, 55.26707826122161, 53.33524034869287, 50.06699600527364, 59.35199145347842, 57.399392435627604, 57.15907273753997, 52.69193241673132, 46.84875795918126, 43.564526034939675, 42.36536333637853, 43.04589848364554, 41.46605407038043, 42.58265087681432, 44.89220911456693, 46.87614394772438, 46.582880097050825, 45.02759364343459, 45.08309125900269, 47.310981827397505, 43.250944306773526, 43.99064056334957, 42.85585964879682, 46.17862493761125, 52.44592135952365, 54.2636614461099, 55.61765186248287, 55.62086820602418, 52.95852415023312, 50.79081450739215, 50.04338333683629, 46.54464875498126, 42.99007138898296, 46.46391853209465, 48.041778226052564, 52.94450167686709, 51.653328018803755, 54.15478821723692, 53.10586798575617, 55.99070456720168, 54.65992673750847, 57.137319272564305, 53.09092375539964, 55.272283246440274, 15.950235935949511, 0.29569155266208036, 3.1033072067845255, 7.699079696209201, 17.580473000003447, 12.963149047666981, 11.507008344896379, 8.20614213905027, 2.616314306374519, 0.297435965509184, 0.18313681166018211, 27.606388484278035, 62.941874073397734, 30.285847802315992, 50.92037431655392, 30.069246676660356, 0.18259068290072103, 0.15598926032262464, 0.13154642836701486, 0.12831074110562765, 0.19231509657636767, 0.16018353042102632, 0.07302199941008322, 0.24472058209921085, 0.15120833541356749, 0.09599098545168677, 0.14311188922053383, 0.18145121904390474, 0.11201907700348286, 0.17335886376038676, 0.10921338723311502, 0.07071608241887824, 0.14826295717108637, 0.14849676720557675, 0.27356641246907176, 0.12870439538551917, 0.11731423077083404, 0.21378129390218567], [0.04386366262371021, 0.04424698237750319, 0.030591457466324492, 0.046142889111633265, 0.11896282134036865, 0.015153563881833709, 0.040041324382107106, 0.02344913164814634, 0.03915104594442152, 0.0861578562387055, 0.06180540733640233, 0.06205081594206634, 0.045274290962204825, 0.030336177817756133, 0.05211960832257906, 0.0579643803798864, 0.015362669495985875, 0.02521463489580539, 0.06537347716549713, 0.049248268647540006, 0.1017568083179574, 0.07378340653714634, 0.008901228260759626, 0.044312080698868925, 0.031246098749820265, 0.010191085710821134, 0.0550677253293895, 0.07443645818819923, 0.07373365678734357, 2.8446087529582362, 34.13858021459272, 35.86112437709686, 26.685225732864875, 50.7076955610706, 14.257731245410058, 0.0988686032172653, 0.5864112559826143, 0.8082524230403285, 1.6914175811313814, 2.7127845104663604, 7.697533792065037, 1.9771428814818783, 0.357795542766971, 0.1399565569215244, 14.722366390689729, 58.414042918912834, 61.58323957074074, 63.145645126219726, 65.27638643018662, 60.462583111178496, 58.38238939162224, 53.349156918064246, 53.70906968270579, 50.452890549936605, 50.89380418100665, 48.730103200481786, 47.187152601057484, 44.314145888051684, 42.763009302077755, 42.8759970972615, 45.14601392130698, 53.77046654301306, 58.29847420415571, 57.352378906742224, 60.60610655815371, 58.53397723167174, 56.95141853824739, 60.49696268573884, 57.309444642836056, 60.11526899953043, 56.9195100568956, 50.171452645332586, 41.80065578030002, 41.03402460775068, 43.3017272333945, 42.34486110748784, 41.71233577112998, 42.17154725905388, 43.46118334800967, 45.624350886191095, 48.6776650336481, 48.944629392316266, 56.12055070938603, 52.30896396021689, 51.83279998840825, 55.625202425064586, 55.74082605300411, 55.37101714841781, 51.92948249078567, 53.814652043004195, 47.497463072499926, 57.481385661709695, 56.21407570377473, 59.85223093340474, 55.62084467180314, 58.08186523375973, 53.36303818610407, 51.71909047711281, 58.31321839363345, 53.01541028484222, 49.09692325899678, 43.06310199922131, 41.088161160868985, 39.2022345912072, 38.521746512382265, 39.251668222488895, 39.56325346423734, 38.77588079821679, 43.42201455946892, 46.031312481049575, 44.673203575995664, 43.382320173325084, 41.080049699352635, 40.0662229138036, 40.30010992480863, 40.21016605438725, 39.581021801117934, 41.81423502583658, 46.15816977716262, 48.671020538576194, 50.74517380806708, 50.32861809576712, 47.14471255579303, 48.02673985881191, 43.40357549728886, 39.431089201281154, 37.69172591547812, 39.129101999344364, 40.45638107484387, 45.41266449036137, 43.821037277098625, 45.44505934561453, 45.43361386945171, 50.22207867714667, 50.393631381373254, 56.00970452831638, 52.4415792957429, 39.60196333546793, 1.2659480374666954, 0.16894736177017614, 2.0936697577276537, 3.8864895557203605, 5.5768229692213005, 11.10383968199453, 6.257749372912992, 1.7608233084601743, 0.21015403612006098, 0.05033349347931724, 0.8551642767363979, 38.24625492095947, 34.21764735252627, 22.1038483419726, 42.593429550047844, 3.6278739619639615, 0.09553280358593311, 0.06665004011724265, 0.09751508673352581, 0.058364653659443703, 0.10377875949826934, 0.05586303567754165, 0.03508899113043182, 0.10822446731429909, 0.051769517632501746, 0.04682597907019719, 0.05650876352803842, 0.022952363848866477, 0.06499685302016235, 0.059734909164328734, 0.021607368178064787, 0.0221686290892502, 0.022317642766621806, 0.058342371992166006, 0.06271799808488258, 0.05456578069096131, 0.05734671816049565, 0.03469072500123613, 0.046461734905718796, 0.06608193229523397, 0.04637780614317425, 0.04624207834562948, 0.046115283133281816, 0.010834911748045876, 0.03339184973869593, 0.061690647365345117, 0.035186793745285085, 0.027598631568253044, 0.015368839376606049, 0.0347361425238271, 0.0676789268430683, 0.07819379003898752, 0.03613370906321272, 0.03325628665005488, 0.0476182557101692, 0.030725576479228276, 0.013946861445513225, 0.015407500961314768, 0.02962442084906563, 0.02966009564847956, 0.07097809981074064, 0.01663631173752008, 0.045287279982961, 0.08368989632975671, 0.024892150184079528, 0.07154629956330023, 0.0821940407096859, 5.978076534886514, 48.4440565109253, 32.53019075239859, 28.642986589862456, 53.984110201558764, 15.281599298600229, 0.11366139331291761, 0.18622253721039142, 1.0994311662450915, 0.984755648720649, 3.789506501728489, 5.416919704406492, 4.1239795088768005, 1.630499495133277, 0.23575315522330426, 17.29261809779752, 64.33266416672738, 60.45015312010243, 63.567852973937995, 63.68584963583178, 63.01057438696585, 60.79348602602559, 52.9845255421054, 54.239032883797925, 54.2809747880505, 51.51307190618208, 49.65016964943179, 47.42963744748024, 46.3862124566109, 45.18316268920899, 45.54625649606028, 48.693217231381325, 54.84282685864357, 60.40545771198889, 61.27696129583544, 62.19033225890129, 60.08201122283936, 58.32010215328586, 61.05016985247212, 59.07209896272229, 60.45311450958253, 58.585356358558904, 51.36796774402742, 43.36949402286161, 43.25916951702487, 45.36933014469762, 44.04150585974417, 42.661635644974254, 45.21847578787035, 44.923580231205115, 47.76649452024891, 49.294343994509795, 51.82873641290973, 56.56131529038953, 55.425549860923525, 54.097478466649214, 56.75570011138917, 56.76760058249197, 58.8949647257405, 53.493653112842196, 53.05965854275612, 48.977694972868896, 58.517142418892156, 57.63828046860234, 60.51393870384463, 56.76210926425073, 57.892069585861705, 52.930538039053644, 52.775325928964925, 59.31449751700125, 56.06078163270028, 51.23493271489298, 45.2617669874622, 43.92601167002032, 42.57779498254099, 39.712970333714644, 39.8109785972103, 40.90562582015991, 40.4191852384998, 44.99666575462588, 47.427723330836145, 47.33225676321214, 44.098191953474476, 42.40010376899473, 41.485069720975815, 41.310316362688624, 41.26568371249784, 41.5863766977864, 43.93008309025919, 48.05219996360041, 49.6045171829962, 52.38497164941604, 51.51379362229378, 49.28910763032975, 49.866504053915705, 44.54597365471625, 43.03214665382139, 39.56448508847145, 42.68319691381147, 43.1859859343498, 45.886820208641794, 46.78262287570585, 48.145426857856016, 47.87491667655207, 53.02198809962119, 53.29923691288118, 56.853120019358975, 52.21759626942297, 42.32950502826322, 2.087014230989641, 0.7708924600193579, 2.28209845962063, 7.20100389372918, 9.876533977447018, 12.017430297790035, 6.536325908476307, 1.633018637376447, 0.3140866413952843, 0.03589986838520535, 1.0464986581956188, 42.465505369247936, 48.87111240817655, 22.14017733450859, 50.04498758623677, 6.796349633124567, 0.07152115655762535, 0.014701755867610055, 0.07405922117252504, 0.05454393186336083, 0.03689186797747689, 0.05322544858039868, 0.07206605191552831, 0.02691959613002837, 0.05039228306662652, 0.04214336622446295, 0.07557161663088106, 0.060959722876789114, 0.014568130981417434, 0.013951858253999343, 0.0386804496238549, 0.02136355112006347, 0.05793072613737276, 0.06954248934503525, 0.0666058062004947, 0.03210215795514805, 0.052786461047587864, 0.010357806552952577, 0.14891180299943493, 0.09170026488361821, 0.14653579662403754, 0.18271797607021947, 0.3148932706925177, 0.17538754119267388, 0.13611067296756854, 0.07448083000077356, 0.18851168453693393, 0.17481015604590217, 0.10304496217999728, 0.14765981614830034, 0.12569449721805512, 0.13485971267425245, 0.09407346737721274, 0.13014537612757376, 0.1413340596181731, 0.10340239582282883, 0.19973891757188306, 0.08007128768029713, 0.19692192034375286, 0.17250761750244326, 0.16839539542073206, 0.1559677026084354, 0.1263874007629291, 0.14956997977870126, 0.155972391066532, 0.24387782409546838, 0.2511966757235989, 7.974358008753869, 54.90296856049569, 48.11464409674368, 35.7952638595335, 63.744100755260845, 22.426090663479222, 0.14318816093427522, 3.9536738732168755, 3.1553144031955354, 6.686224677870351, 11.513385138204022, 17.35248523373758, 5.806025199351772, 0.6444818238096853, 0.2818539516339379, 17.604874064845426, 61.83426733939879, 62.947616423330004, 65.95578409010365, 69.27933385295253, 67.45333717715356, 64.13753017302483, 55.6438454504936, 59.23141779438142, 55.57507845663256, 55.87209993793119, 53.530527314832135, 50.1326015687758, 49.005885047297326, 47.3439807276572, 47.40274959994901, 50.385245353944846, 57.49683195544828, 63.95604210515177, 62.0943832397461, 63.52870771961828, 59.810861695197325, 61.08235289973598, 65.84770710237565, 61.14778587895056, 63.43545336877147, 60.577861570542865, 56.51025779785649, 45.4108327434909, 45.030154951157115, 47.28267800423407, 46.068555385835715, 44.71714588903612, 46.97649386621291, 47.52785359659503, 51.73802768030475, 53.04523206526234, 55.02741752132293, 59.80482124513196, 56.59071345483103, 54.961643295903365, 59.88116233579574, 60.45710356004777, 62.41188341571439, 55.453535972103, 56.15947238860592, 48.98287250149635, 58.03233354322372, 60.25980049563993, 63.375954935627604, 59.52976895916847, 60.26133414237731, 56.77989329061201, 55.647861957550056, 61.77800878401726, 59.04129658975909, 53.58735461388865, 47.64952944171044, 45.84805150185862, 43.77558092917166, 41.96244178279754, 42.6085542094323, 43.340817574531805, 42.73657644948652, 49.80237722396851, 50.30793151547832, 48.864993510707734, 46.422109988427934, 43.70911636660176, 42.48452494221349, 43.9842039538968, 43.59914095171037, 45.08226363889633, 45.17095627323274, 50.36541385035361, 52.05090338183988, 53.80667001970353, 55.43923501045474, 52.48126191477622, 53.82428146177723, 47.840831279754646, 44.14351886318576, 43.05427274396343, 44.1218791469451, 45.04578559629379, 48.19233056037657, 48.8256246812882, 50.02805079183271, 52.01551183577507, 55.21968818479969, 55.00484428098125, 60.738564998872825, 53.156207684547674, 41.44723846066383, 2.6218073406527123, 0.4863686306822685, 4.612045912973342, 12.40853080826421, 12.482654779188096, 19.438199689311368, 13.549515931837021, 4.88373133444017, 1.5986673774257785, 0.17055675928150454, 1.638930997540874, 51.514868351721, 44.01966610262471, 31.06914120335733, 59.15026003314603, 7.8298931929372975, 0.30438692639431647, 0.1516739330104282, 0.14351894237822102, 0.1846604073239911, 0.19464063307931348, 0.14701950453942822, 0.13888073964945732, 0.1319740739681067, 0.13931664367837293, 0.16143283596442592, 0.20036062856595363, 0.25101459194575587, 0.18980813513119377, 0.10735930889965066, 0.10382345306777185, 0.15889052722242572, 0.11892164411443858, 0.22051767355972723, 0.1580598580861284, 0.1333066532688756, 0.13038335368037224, 0.147963615975553], [0.021439054830660744, 0.06601485363658398, 0.009525466387370422, 0.03602387503750863, 0.07654936698776099, 0.035049863189699194, 0.05300722077428814, 0.0631505964444049, 0.027951409311724768, 0.04702349568927481, 0.0433413285551773, 0.03199562385317779, 0.042116196916228345, 0.04534291711846187, 0.040083294509038817, 0.04349149327965514, 0.05870287381713429, 0.014081198793475427, 0.04515515662909997, 0.009724029674074583, 0.04645871651929714, 0.06189700463906892, 0.057575142596878355, 0.011676189286874668, 0.009857799159362912, 0.049143054132019325, 0.044695044221777114, 0.04181726174729486, 0.11743510412352702, 0.33946912615529956, 7.369983523122727, 41.28659779025663, 41.24084726456673, 56.886385640790394, 34.187441179829264, 1.89866115729655, 0.20936882664119044, 0.618335917111366, 0.4318151725155692, 2.2592413377377296, 2.799651526635693, 2.8777287563970013, 3.3854070113551233, 0.1043137570001906, 0.05870812151941562, 10.611098793245132, 57.241752378402225, 63.146970887337964, 61.051664275507775, 60.567129965751406, 60.991675546092374, 57.126438617706306, 55.42359259820754, 51.81531013980989, 51.49715885039299, 49.19307231903077, 45.119333959394886, 44.89137364972023, 46.023667781583725, 44.34821951773859, 49.83920435751639, 54.036971984371064, 56.387467999612134, 61.47234632122902, 61.82654027015933, 60.091687710054465, 57.03756555434197, 60.55816734990766, 57.78711480479087, 57.90448388745708, 59.15918342528805, 53.51580273720526, 46.26289313839328, 42.7529445002156, 42.97802971255395, 40.065238398890344, 41.83592965525966, 42.38240603477725, 45.68270398724464, 47.61460858006632, 52.16374604932724, 55.17252168347759, 57.30050163884317, 56.115408482090125, 54.91086036928239, 55.55946350097657, 51.7154505175929, 54.23199222933862, 57.548932798447154, 53.79716611677601, 51.25416017347767, 60.19868996835525, 56.87992157474641, 58.709848465458045, 54.222327509234034, 55.95680352180235, 55.05390528709658, 57.86413838786464, 56.41429308922061, 51.50669805465206, 45.25328290077948, 41.58763970098188, 40.49446728921706, 40.42585326779274, 40.29960001668623, 40.493714194143976, 40.14448988822199, 43.380374677719615, 50.43545169215049, 49.5180759891387, 47.8090718484694, 43.36639535042548, 41.29432093712592, 39.656237171542266, 38.9538348105646, 40.127419733232074, 39.568329011240316, 41.98075532913208, 45.726881642495435, 46.28050458046698, 48.75428853496429, 48.391383001881266, 45.037074012141076, 45.1610444438073, 42.963787586458274, 40.8876064515883, 39.42289929236136, 42.76699443017283, 46.17061545771938, 46.00404416361163, 44.71339218078121, 48.64510936121787, 48.713131104746175, 50.39458059495496, 52.93273456635014, 51.46434037916122, 54.72857998263452, 22.121950080317838, 0.11645651873080962, 0.3660574026646153, 4.537828785757865, 6.3138466208211845, 10.877095307073287, 17.350480902579523, 6.990524117023715, 1.2880588058502445, 0.1211312638535615, 0.06364051733286151, 6.226270881391341, 45.85391936763641, 26.15912606639247, 31.3710734921117, 30.323135814359112, 0.19739720129197647, 0.09913248220278371, 0.03495799009537986, 0.02637782066519703, 0.029356211551555225, 0.05118773514104467, 0.04160439655665429, 0.00881207382096158, 0.048257678657049136, 0.01654157922002337, 0.02484974338703098, 0.044633377974312154, 0.08494821872802512, 0.08776040492399086, 0.05399294993689945, 0.056138428964562, 0.08779823434569183, 0.027726474405837157, 0.04436333964188253, 0.053840356713701645, 0.050171485035530025, 0.050080611685951876, 0.023339897086242997, 0.018360153208636952, 0.042941062936499234, 0.04585066487291648, 0.012397049295325435, 0.1076130985072063, 0.05393016903150467, 0.05614424357190729, 0.01909680611964676, 0.03264176156071406, 0.07268832215378362, 0.03075669880115217, 0.03435106459824789, 0.04937935395226364, 0.03846766104200675, 0.047638300400707996, 0.035230663770269004, 0.04065174707061341, 0.06368631789941462, 0.06609978980474895, 0.04445093796558438, 0.029883732035335515, 0.07683136395268864, 0.03078573736392202, 0.032138369016108975, 0.042796318284085685, 0.03375443532281826, 0.024448864898013494, 0.041836061544956706, 0.08512444193324736, 0.28880555603292685, 16.472319095365464, 45.54018074466337, 34.43699413730253, 67.2429177068895, 38.56938762049521, 1.5168165824105664, 0.09835992849642232, 1.2459538780873822, 0.4084301547658059, 3.3453669663398498, 4.2203482216404336, 8.366747998422193, 6.408732677659681, 1.024166030749198, 0.2097446387333255, 15.808101988607838, 58.77813693015807, 63.17478833660003, 64.00610331566104, 65.18751336682227, 62.170434075017134, 59.22562445363691, 56.13490658421671, 53.660094968734256, 54.001474534311605, 51.38892889022828, 46.60353922074842, 46.12078566705027, 47.39099033417241, 45.72295534995295, 50.220176327613096, 56.439737504528416, 58.13819439180436, 62.93758300042922, 62.33991576779274, 59.224957650707616, 58.528246648849986, 59.34471545680877, 58.263274854229344, 60.06033620526714, 61.81279628507553, 55.914857695179606, 47.33087608891149, 44.82631721804219, 44.51475943288496, 43.03154260881486, 44.333538086183616, 44.027616746964, 47.37690118051345, 50.42041332490983, 53.10832731185421, 57.7143705275751, 58.474478798527876, 57.74575733369397, 55.66633239869149, 57.05916212451074, 54.34551346686579, 57.32368676893173, 59.249241044444425, 53.6870651860391, 51.91672302061512, 61.6296176756582, 60.15655586796423, 59.78600171304519, 57.06048788562898, 59.09280907723212, 56.61900158851378, 58.12234017156786, 60.05234633722613, 53.875574296520604, 48.041064354681204, 43.12086282237884, 42.857267779688684, 41.06261868630686, 41.222047344330825, 42.012601052561116, 43.03788508138349, 44.97158219737392, 52.318514931586485, 51.511608862107806, 50.573385761630156, 46.47065716405069, 44.23663593107655, 41.434204424581225, 42.053644734044234, 41.22426348347818, 41.299902469881125, 44.41096175101496, 47.54771647914764, 48.78716584174864, 49.032125703750125, 48.7006462004877, 46.51163416524088, 46.62829722127607, 44.62040455110612, 41.66501629737116, 40.550412054984804, 43.635924939186346, 48.12702309700751, 47.41282616892169, 46.48939432636384, 49.5868782843313, 51.37371009395969, 52.358377979647734, 55.312942535646506, 52.14682494440387, 54.36057536832748, 24.60237656870196, 0.2653715699430435, 3.1569005116339657, 4.223021316912867, 4.265986469484145, 11.386034604041807, 16.12573552516199, 3.589725970260559, 0.42342620330952835, 0.06777923073499434, 0.03544793779691381, 5.969196288816391, 57.60030408059397, 27.694632007229714, 30.70688678372291, 39.484676622575336, 0.4056715027939889, 0.015938405638500568, 0.09853822779991935, 0.10622681644294532, 0.13055840477107034, 0.012610676743450665, 0.006546821255582355, 0.030921447924488497, 0.07646489813322983, 0.055597168693859736, 0.013657274464475773, 0.037280385637836116, 0.08699729708173583, 0.06352294581912218, 0.03558081957781988, 0.0464763212197971, 0.031740076073835936, 0.008862108938516149, 0.005932877435454078, 0.07713768420921219, 0.022835196446507208, 0.06834420525739271, 0.01343302999532992, 0.12000092410392339, 0.12963603491023665, 0.16259241729013382, 0.07894146887044753, 0.21424229497150069, 0.13749012152754492, 0.1855499886216656, 0.14151531602105788, 0.10065933374027092, 0.2053172327578068, 0.16575439923232602, 0.1470663584768772, 0.12138624855827902, 0.13216778696064027, 0.14439395268357572, 0.17865775603680842, 0.14852537292866938, 0.1337893193046893, 0.22450028888640866, 0.19379649611730732, 0.12786282481805933, 0.1535211088916948, 0.12792423442606965, 0.12296897854896323, 0.20623823898213528, 0.12561661671967278, 0.125882571803466, 0.15592870873308953, 0.1870333493476914, 0.44987587919158323, 23.50741751732365, 58.44655936764133, 47.79152708668863, 66.41579181917253, 47.69447195914484, 3.6217339817554723, 0.6858902244317917, 3.0918609951773, 1.752456157438217, 10.874609504976581, 8.34032004879367, 11.895065096116836, 10.276146031195118, 0.30331437265680683, 0.21485196306340157, 14.082902381497046, 58.31227310242192, 63.92314126414638, 67.65319762691375, 66.23089128924956, 66.51301953100389, 62.69912642817344, 60.38348851665374, 55.915520575738725, 56.71060854388822, 54.35329937165784, 50.67645780501827, 49.20389413833619, 50.936761979133856, 48.56658743273828, 53.855032843928186, 57.19609206722629, 60.642200208479366, 64.7430343012656, 64.9038750125516, 63.36975759075534, 59.71075888602965, 63.072198744743105, 60.78318588195309, 61.978018283844, 63.81360515471428, 57.93978521900793, 50.4462185982735, 48.73554352791079, 47.0049310499622, 43.70022043105095, 46.83610439300538, 46.68065694070632, 50.16319213374969, 54.857523979679236, 56.609050535386615, 58.756661953464636, 60.04932611219345, 60.674328342560806, 59.11097749587029, 59.52517194132651, 57.54860724172285, 61.10190983741515, 60.78760247076712, 55.16586934366534, 56.865279366893155, 63.77315767349736, 62.04432202923683, 61.83152560264834, 58.201301405506754, 59.62063066421017, 59.20978200051093, 60.45813514340309, 62.991915672056145, 55.32969890102264, 49.88230336096979, 44.79424791951334, 43.99682614111131, 44.68492361807054, 43.10226686539189, 43.79720495593163, 45.446177221113636, 47.174349984815045, 56.30464715342368, 53.208583093458614, 53.16127538681031, 48.803839837351155, 46.72660358490483, 44.29409080936063, 43.93401722754202, 43.54600852535617, 43.07720291999079, 47.27201700210572, 50.47780152290098, 51.180596120895885, 53.20017745417934, 51.686813292964814, 48.22470972614904, 49.41722792963828, 47.45948668449156, 43.99990127932641, 43.77312944781396, 46.18236295638546, 51.391164641226496, 50.028580311805975, 49.102163545547, 52.65754107506045, 54.15837326357442, 54.3301966113429, 57.42990063082788, 53.93298210636262, 56.397952495082734, 24.46829034436134, 0.35572900526946594, 4.106671560195185, 7.5649267915756475, 16.13920102196355, 15.985481373725401, 28.73210087899239, 17.878786902273855, 3.4218446045152606, 0.37563098894972957, 0.15587659943247997, 9.642809744804136, 59.99154175481489, 34.02719274643929, 44.37262450495074, 43.52396088261759, 0.6496008233197275, 0.19344873816495944, 0.19278320694162002, 0.1786817499105969, 0.2610273611161017, 0.1412927828008129, 0.12069657790444552, 0.1157272719748078, 0.20822441385638332, 0.1675854106583903, 0.11012309366056036, 0.07967194902800745, 0.26647752511405176, 0.18837791026359607, 0.34107879945828073, 0.11082240936136055, 0.21417049721123713, 0.13624794060184112, 0.06672458813315438, 0.19847934645029808, 0.12048036490957584, 0.20477410706300891, 0.0757187744602561], [0.018633338247215556, 0.031153743020108635, 0.04520955653260312, 0.0502196604746484, 0.021937825949862603, 0.008808214653043017, 0.03662313199451855, 0.05978148731012499, 0.05537008874178414, 0.0457792578174943, 0.034046468039553975, 0.017136199429871577, 0.07047917738917374, 0.04651280615719096, 0.06127422495234398, 0.08250202337700514, 0.022250215537966262, 0.0291608227416873, 0.00436549410111301, 0.023615633197609457, 0.03613834772559424, 0.09878925183006833, 0.011591677339897763, 0.025236500960384167, 0.056189297202734224, 0.04385447722949809, 0.09262571441790751, 0.045945345679478306, 0.12116194567492894, 0.08038175247249105, 1.3811376306318468, 35.07873312119515, 37.929084224085656, 21.187898420518447, 51.17780339333319, 11.28643778062636, 0.048991656005983396, 0.6006242707371712, 0.12761770732580655, 1.5470444507175878, 2.479035763009902, 4.349862433248951, 6.160953121800577, 7.096168744948603, 1.0044258448385424, 0.12145289820769142, 13.010382229282012, 69.91649935322424, 62.11934128115254, 66.3730928974767, 57.01663578710249, 59.62357244183941, 56.14379467502717, 55.385918232702444, 50.41614186379218, 50.94296716874646, 46.7422067734503, 48.137978276898785, 45.424015829640055, 47.4813578205724, 50.437236370578894, 57.2417131547005, 53.02068587272398, 58.6809366749179, 55.581652349041356, 59.39693397091281, 57.77213135073262, 60.041253874378825, 56.29419403691446, 59.8673830493804, 58.20758896489298, 57.156166261242284, 46.71473057039323, 42.85868375532089, 41.956872017152854, 43.10408684515184, 42.53704155645063, 43.273501857634514, 43.23784359039799, 47.51312901896816, 54.65667509263562, 57.785173231555575, 58.93552595569242, 53.80006474833335, 53.11406181704614, 50.60518049424695, 56.30291346580752, 58.03532238929503, 57.24682400303503, 55.023200973387695, 55.59362734517744, 59.483716410975305, 55.43202569407802, 56.3836044649924, 53.18521753434212, 54.996317048226636, 56.75593153122933, 54.255914765019575, 53.42989106332102, 50.27334797766901, 45.336680335383264, 43.563827853049006, 41.42725398463588, 39.67136183092671, 39.97439238332933, 40.2013603333504, 44.461226924773186, 50.99558968697825, 53.26606150596373, 51.93252625003938, 49.038491710539795, 43.628205714687226, 41.37088168051935, 42.09319791486187, 40.89683971097393, 40.24411809059882, 39.15986514860584, 40.99120409257951, 44.86192841683665, 45.36239931660314, 46.8454239445348, 45.370122463472434, 43.95781816974763, 42.84100955532443, 42.11966999115483, 40.57222043314288, 41.78332282650856, 44.691940738308816, 46.67112558118759, 50.81710615465718, 51.960492749367994, 51.27516446575042, 53.45943435545891, 54.89010318633049, 53.62805704916678, 55.327208195963216, 45.231470600251235, 7.163356494519019, 0.5822836968206591, 3.75275144173253, 1.0070310953644015, 2.427463214243612, 10.45549346554664, 8.680688623459108, 1.4685884670865152, 0.48808209357723115, 0.1350193653976725, 0.06828286459729557, 20.1956505544724, 47.1311568444775, 26.641581519957512, 43.151123908258256, 12.016090808376191, 0.11042534599020598, 0.053386510905599406, 0.008593704288585052, 0.03762218725657271, 0.06614219277135788, 0.010309522903914894, 0.016818665561356375, 0.042038155539381894, 0.016949260569808465, 0.06955167473924738, 0.07832860619190239, 0.05655691215407945, 0.019035724014224067, 0.07493872841399524, 0.05531902515119123, 0.03223239864793516, 0.04643087688412878, 0.04643643485201944, 0.02889107360744909, 0.08082940829016509, 0.010930437166544219, 0.03112063078480142, 0.021191838257495436, 0.04927921476924131, 0.011656655002415422, 0.0536903337154898, 0.051315124071533644, 0.08508345622929835, 0.027894523452907324, 0.031030801230020104, 0.10797161233401108, 0.03560576723107407, 0.01939073681921488, 0.008441429949485728, 0.04334513601216097, 0.0145256188472793, 0.028667550218561967, 0.015419838807335304, 0.01931190445658661, 0.09897454551631406, 0.013803884540984948, 0.017772473755382726, 0.06506023147413809, 0.0790005419102888, 0.07665357792810087, 0.06562982550671985, 0.009954869202638586, 0.09027833674824046, 0.06708891656730445, 0.060329707489619334, 0.06862787229399528, 0.038689435835206704, 0.15296879014180553, 2.6108362261326086, 45.594274151709776, 40.442550797616285, 35.6144190603687, 60.32854787765011, 11.914613208463116, 0.04502729272409793, 0.486066792040102, 0.09310351579540199, 0.22845921677447137, 2.200893629943171, 6.809225303511466, 16.023919620821555, 10.687922335440113, 2.5522737685711157, 0.6649855848762297, 19.239510067047615, 68.75937661816998, 64.51782357308173, 68.34895549281951, 60.94490128178751, 61.62317714383526, 59.45833475359025, 56.53680047681255, 54.14519409979544, 53.018928650886785, 49.28836630236719, 49.48459855971798, 47.911932083868216, 49.427304498610965, 53.37567998516945, 58.89901261175833, 57.132808546866144, 59.78364044620145, 58.12953379846389, 60.86798360270839, 59.46680315079228, 61.800731074425485, 57.50709679818923, 61.49497447475311, 60.31691805008919, 57.259654075868674, 49.46169191791166, 43.830647084020804, 43.85965693381525, 43.84852916963639, 45.24319456469628, 45.64341360522855, 44.77100003150202, 48.33987051440824, 55.776033247670824, 60.04666674521662, 59.73206912317584, 56.952493267674605, 56.70850615347586, 55.07651775113998, 58.591541936320645, 58.67382541779549, 57.809134990938254, 55.11752613129155, 55.23946869757868, 61.52819695011262, 56.63198071141397, 57.254237282660704, 54.60251500529628, 56.732958209130075, 58.35422677378501, 57.23660622873614, 54.8551627128355, 52.436558661922334, 48.35611697166197, 44.773129878505586, 43.23558822754891, 42.08581601419757, 40.84578221844089, 41.71379881520426, 44.49421798029254, 51.82372362382951, 53.829235415304865, 53.341084680249615, 51.25983192074684, 45.79973182370586, 42.02893772432881, 44.052374747491655, 40.68087008691604, 41.631189777005105, 40.11660968103717, 43.19695680372177, 47.71955943876698, 47.760591353139574, 47.365110535775464, 48.045253446025235, 47.346604793302475, 43.991562320340066, 42.958241355034616, 41.888877730215754, 44.20702595864573, 47.27752400982765, 49.00806980748331, 51.37466715228174, 54.20069563773371, 53.457449636151715, 56.61467913658389, 54.278503694841945, 56.314602128921024, 56.22627427501064, 47.89304194911834, 8.291846417611646, 0.961559793401149, 4.282674193382263, 1.9185105567016911, 4.375857451269704, 8.404019340392082, 6.879189110571339, 0.18021815456449988, 0.24156086777727453, 0.08397867317281424, 0.023041802698806412, 21.665503863365423, 57.04852073423324, 23.752548002427627, 46.25838241269512, 16.183960168592392, 0.04345265645233374, 0.07468252562947812, 0.05023312446991763, 0.021169114174441468, 0.03077131384352763, 0.05333558521083286, 0.0400523292351394, 0.06364440522907723, 0.01611701137716732, 0.08981165130652728, 0.15176065416345674, 0.035822347948147405, 0.03718608021435719, 0.03215477478900745, 0.0834528457433466, 0.02125224620554476, 0.043341255776824496, 0.05441989456754058, 0.05552911327310628, 0.05067587732487629, 0.07722336348266372, 0.05385035033067388, 0.11131105854386285, 0.0958719200664951, 0.17564831752209895, 0.15557253913533303, 0.1313681597070348, 0.1385939469741237, 0.09805104950623167, 0.09551495373729738, 0.29745432097584973, 0.23229302718274056, 0.09183056877865907, 0.14892433619787618, 0.1369377721341387, 0.14247952960431576, 0.11278154133188148, 0.0929526960657489, 0.19992950492568556, 0.13271134166467574, 0.13811858941710767, 0.13696326754025875, 0.14118784407694496, 0.20978499624517657, 0.18973359477616128, 0.22630212768431635, 0.166839363594209, 0.27927143859767145, 0.15176958674865385, 0.19217586775700893, 0.14190419757318112, 0.2879352801509442, 0.2965913076073893, 4.204732775688171, 55.79148738614975, 49.935659362423806, 30.03009749997047, 65.95474073963781, 18.330638062569406, 0.21504086502377065, 2.8911059998696853, 1.1186230783500979, 4.448556130932224, 13.789644414378753, 10.290045930493264, 21.311323642730716, 14.971768336911357, 1.701305018317315, 0.9463639184832574, 15.704542590725808, 71.54138042080787, 65.00790019189158, 73.3548725804975, 62.76472806930543, 66.74262723615094, 60.47504055884577, 60.30775147099649, 54.21617331043367, 57.66958098257742, 50.719760771720644, 55.05695296872047, 50.40288425260975, 53.06152559095814, 55.40184697797222, 63.84881234938099, 56.86314559751942, 61.84386145684027, 60.267421660884736, 63.27079226893764, 61.260091181724306, 65.47883564426054, 57.4688889903407, 63.70719125193935, 60.48576824126705, 59.76777838122461, 51.92543068239766, 45.820190906524665, 45.38575310860911, 47.49328182589623, 47.61481646568545, 48.04205279196463, 47.13094895885837, 52.50650236683508, 58.03571070394209, 62.291074414407056, 62.03444942351311, 58.23304122494113, 58.3126300381076, 58.1638192361401, 61.79795795871366, 59.39020318369712, 58.60779623831473, 56.1423747770248, 58.21227227487872, 62.31373002452236, 60.57431967027726, 59.24371834724181, 56.60967026987384, 58.479224866436375, 61.42342259806972, 57.929190897172504, 57.087077633027114, 55.426816786489184, 51.021673448624156, 48.20252480045442, 45.754910899746804, 44.67750641607469, 43.061093745693086, 43.89907675404703, 48.46751620692592, 54.444784733556936, 56.80206644919611, 54.98487549443399, 54.55928264125701, 47.20250475791193, 44.281786334130075, 46.59353717680901, 42.958155062890825, 43.89007099213139, 43.70942623384538, 45.88966000464655, 49.470615310053674, 48.74665168023879, 49.66532568777762, 51.74242857963809, 48.786526495410556, 47.71211870255009, 45.419646309268096, 44.40466242451822, 46.18936830951322, 48.58809378839309, 50.435683111990656, 55.91308870623189, 55.67499299203196, 55.784019193341656, 59.57176969897363, 57.48654357848629, 58.793089005254934, 58.96720693957422, 47.78647115153652, 8.322627217538896, 0.8976017479454318, 8.578096089824554, 4.637171635704656, 12.0404379406283, 22.42248208292069, 19.30761221916445, 6.452710292031688, 0.9896896839622529, 0.545039137284602, 0.17648376704704377, 29.358644600837465, 60.69021001938851, 35.993982899573545, 57.75923067523588, 19.14328452079527, 0.2577166968295651, 0.18535115816179784, 0.11226235588471736, 0.17818454352598037, 0.13131136194832865, 0.09588094458224312, 0.12669744420676463, 0.14357059202607603, 0.12787007200982303, 0.15824843828956928, 0.25982343862133644, 0.11975458087099176, 0.12385541888614818, 0.14317149086104286, 0.17235230083667463, 0.08733701111087877, 0.1525934377024251, 0.15681720218591153, 0.20297373915391587, 0.13743790497462596, 0.21035665105427467, 0.26884259175389047, 0.1928766083813483], [0.026532082044849956, 0.08640750897147002, 0.046698984674989216, 0.011344299888268355, 0.040185770260230194, 0.04216390121127329, 0.07524500270524333, 0.02655058498344114, 0.028934708060396296, 0.08990714416628884, 0.05986030626621458, 0.07429178248369887, 0.02279026347452835, 0.045013951302896586, 0.09994787554587088, 0.058282375816375985, 0.09974877695522963, 0.07271185637481752, 0.07357102398189806, 0.01630329906249479, 0.017246847423995217, 0.03701474465009186, 0.08466296588941928, 0.04209151356330803, 0.019966342726782448, 0.03922543308186916, 0.08424714868587833, 0.04681706946763781, 0.04103029792707774, 0.01569413658862393, 0.04646555768446096, 21.32436356236858, 44.528028811177904, 28.85881304740906, 53.95109561181838, 39.19387209799982, 0.918795662301202, 0.16009061927756957, 0.07034923355545729, 0.620206703822459, 2.093843322607779, 9.474953874464958, 8.189628470328547, 21.128154839238814, 3.4592647514035626, 0.33253373217678844, 0.0884084540208982, 32.50855103615792, 69.89232186348208, 61.98446273803712, 62.86905919351886, 61.21779234178605, 60.58861670955535, 53.78075491997504, 54.887690928674516, 52.295192518541896, 50.88754407821163, 50.18712251417099, 48.74095639874859, 48.732472312065866, 53.15414451783704, 54.13927916557559, 54.84938898394185, 56.92925714677381, 59.30004358291627, 59.736375885625044, 59.41868743588848, 61.97632381992956, 57.369154883969216, 59.159885529548895, 61.42825495812201, 57.25550813059653, 45.89382163939938, 42.478825738353116, 42.25421121043544, 44.43249948563115, 43.48244259434362, 43.85055311264531, 42.23382273027974, 48.27522200922812, 58.90934805716238, 59.376765143486764, 57.61791944503785, 54.12946539540445, 47.05952259802049, 50.45611473821825, 53.865795827681026, 59.17528083247524, 59.33781600767567, 55.505719184875495, 55.3614975560096, 60.49071042768417, 56.49323863367881, 54.39749271638932, 50.535079894527314, 51.249076781734345, 54.12543319886731, 54.056991761730565, 50.85275265478319, 47.3074399271319, 43.66763337965935, 42.71034756014424, 38.65258109185004, 39.570451013503536, 40.78519336638912, 43.34545773844565, 51.57451583493141, 55.904675222212276, 57.20755715523997, 52.527247782676454, 47.38920173337383, 43.55254711643342, 41.05720581546907, 41.7422281542132, 40.29531286608788, 39.322227739518695, 40.239858396591686, 41.971169056430945, 44.096375896084695, 46.94125529258482, 45.194212005984404, 46.03147722059681, 43.7055548544853, 46.11538848569317, 43.64210659457792, 41.55972419246551, 40.090729882640225, 47.51037551510719, 50.35283088684083, 50.91282767634238, 51.76045579295005, 55.22240246495893, 52.053339173716886, 54.70843076705933, 54.820269307782574, 52.639882564544685, 27.792840311604163, 0.5881196320537598, 0.9597523774831527, 3.170817081005343, 3.6537596439161613, 1.994580023231045, 5.139439961602611, 3.774070013915339, 0.7811643507692122, 0.07444355216237807, 0.02984525335411872, 2.0589969859969233, 40.572765642596835, 32.2091761327559, 26.048632898638328, 37.881250919834265, 1.5317195053062134, 0.06379551607214155, 0.083294058699281, 0.050736965175958416, 0.02862964418806857, 0.11865728249352787, 0.011569646566415267, 0.08006545009031411, 0.015410528923835487, 0.05689117546764113, 0.037859345095292214, 0.010373051702645759, 0.04072683134807214, 0.041116674340540366, 0.05581689803230186, 0.05624669251002132, 0.09884205060980975, 0.007822058875218876, 0.017589003358396794, 0.047135666283147956, 0.08735810151143421, 0.030319358357378555, 0.0341948056443324, 0.04839827877379233, 0.03908950227102445, 0.044752378242030266, 0.05795395009279732, 0.10207335584827008, 0.06230503072841995, 0.03316782264699859, 0.055576243002208016, 0.06615620451949297, 0.03688303881414956, 0.06397660010524335, 0.023721901084026022, 0.04831635333116978, 0.012492336268957346, 0.021578816081126852, 0.050086073892851996, 0.04011377331710631, 0.006213314453845905, 0.07243170568178739, 0.02723688101996818, 0.026054192567244176, 0.0566127063376048, 0.07867652502271437, 0.04685787514092461, 0.03403236053042835, 0.020577629179423376, 0.04721820459610993, 0.035433087182501634, 0.024309239628153945, 0.09527171316045908, 0.08030230915474315, 0.06185574314346718, 28.07027935981751, 45.60544506196053, 23.307692389334402, 65.94444059556531, 41.05855118843817, 0.6253097074166422, 0.07710403762757778, 0.16468707021446, 0.31599288265551295, 0.84931688082795, 2.6068177578910707, 11.138678173865042, 9.501048422628834, 6.33217046337743, 1.3321176868292595, 0.08293740646613222, 40.28830751296013, 69.59353139323574, 65.61186282865464, 64.75868455825314, 63.256844320604884, 63.19457277174919, 56.028743713132805, 54.77424421618062, 55.41464959421466, 52.73195628196963, 52.440245689884314, 50.666934290239894, 50.2429299969827, 55.975744647364465, 55.52244024892008, 56.95937702732702, 58.734680991018976, 60.352552783104684, 62.167849233073575, 61.17933742461666, 60.754968350933446, 57.42141654414516, 60.198890009234034, 62.50838941143405, 59.30373453324842, 48.60972173752324, 44.24086032375213, 44.28144116555491, 46.287560924406975, 46.59902849505025, 45.04549534090104, 44.28944672307661, 49.905708143788004, 58.869532077543205, 59.39436481844995, 59.062795100673554, 54.68844629103138, 50.89901308859549, 54.19279598420667, 56.33358247818486, 59.93899376161637, 60.40526159348027, 55.77322875299762, 57.20967131276285, 61.69269723276938, 59.88706550290508, 57.18440340411279, 53.866497931941865, 52.86445002402029, 55.85164869985273, 54.83282089233399, 52.393710690159956, 50.89089770470896, 45.30962382593463, 44.55793688374181, 41.62094454611502, 41.00577962013983, 41.75589761426372, 45.074803290828584, 52.24713956156085, 58.207698791257805, 56.829315154783195, 54.19313723041166, 49.19492760012227, 46.35301743784259, 43.65812947673183, 43.3592801709329, 41.78138125327326, 42.03151079916185, 42.03138920568651, 43.16813130532542, 47.17249862609371, 49.39902420966856, 47.11213727151194, 47.27983036348897, 44.748673900481194, 46.69115712565761, 46.10262509315245, 42.04747092339301, 43.93720219212194, 49.019934977254565, 52.96578837979225, 52.05072295281195, 54.26043725782826, 55.79173449547061, 54.25193748166485, 55.334146868798044, 56.04457832151844, 52.65462283165225, 32.02459919837214, 0.8903825030692163, 1.1920504608461935, 5.4212107773750065, 4.061869022346312, 5.245160585449589, 4.739240042624935, 0.7807438604293332, 0.18278454911083947, 0.014874670530609308, 0.010250837696085294, 2.0750458538532257, 45.9958307204708, 41.33772588545277, 26.405095938713323, 46.605829884929044, 2.878748817789939, 0.09111433019561153, 0.01804917705275359, 0.04139713912961945, 0.0319274535192357, 0.04931862999294554, 0.03364105814046437, 0.10703386708853707, 0.032255293185552286, 0.02258358061343672, 0.05240345922028346, 0.03707814225626569, 0.044055713205448085, 0.05019222686607992, 0.019658858016613993, 0.02083624131046236, 0.011433786618703557, 0.06854914909889621, 0.030592980066074, 0.07117637102642367, 0.0038614431996980025, 0.02166110541551344, 0.043133841301765175, 0.05749442757317617, 0.07423575081291699, 0.26931640181329947, 0.15460451043421222, 0.12341304907515166, 0.21510328586784103, 0.10190971180676453, 0.1416662659856581, 0.16797369466193263, 0.09106462641108422, 0.2613487809656128, 0.14692971903470256, 0.17484726534495432, 0.17316573299467566, 0.13652555554384185, 0.2362874709069729, 0.1830083080717633, 0.16211561948782013, 0.13880961604656714, 0.10201303408511224, 0.08897612517279002, 0.1572174678045896, 0.21517388853094271, 0.13805917163770046, 0.1318095642472467, 0.08594877552241088, 0.1709228727005182, 0.1924195143604471, 0.17511012543353344, 0.2514672886219717, 0.16884895011542306, 0.10710947230578431, 33.173194700671786, 58.4778755710971, 40.16593348595404, 65.29076583923833, 52.43939453555692, 1.7863611252077165, 1.4339761243712519, 0.8927031366094467, 1.7577772202991673, 8.115062252167734, 21.660020389864524, 23.405302532257576, 39.9003537239567, 10.130551572768919, 0.8946336781786335, 0.2073093984396227, 34.74203294323337, 71.41266392123315, 65.88238869943928, 69.19439100450086, 66.51349021542457, 66.77308836290914, 58.172275866231615, 59.84700633633522, 57.626752622665904, 56.761571899537124, 55.93679551155337, 54.01199433111376, 53.07126875846617, 59.218626945249504, 58.474392506384085, 58.48566539825932, 61.55110751428912, 64.07375635639315, 65.10156246923631, 63.418277309786895, 63.27338495562154, 56.50526069825696, 63.927553930590236, 65.38199232470605, 62.47595925484935, 51.89677776828889, 45.90695373473629, 47.132415925302816, 50.83052850538685, 49.72967609282463, 48.804730215380275, 46.062173689565356, 54.61926352593207, 63.24130388998217, 61.8304979416632, 61.02884000347507, 54.40721627204649, 53.93291934843987, 56.81799911683606, 56.126336205390196, 61.41442075852425, 61.525674866091826, 57.41627039447908, 59.59198951721192, 64.36540419055571, 61.915150534722116, 59.23819957240936, 56.56172321688745, 56.14403786197786, 57.847982145124874, 57.581790493380645, 54.71515370953468, 52.64137698758034, 48.482989957255704, 47.37070775801136, 42.06547460248394, 42.88630116370417, 43.63363819737589, 48.059942722320564, 53.74226077910393, 61.58753064370925, 61.00185801905971, 55.88968000104351, 52.10069787117743, 50.555668415561804, 46.2561466616969, 46.10363706465691, 43.652775441446614, 44.47125250293363, 44.4169355207874, 46.123394043214866, 49.82300889107489, 53.306120672533595, 48.97813820069837, 50.45829557603406, 46.00490708504954, 50.06401500394268, 48.12446571165516, 45.09671365061114, 44.60325202634258, 51.54691411602882, 55.52297369126351, 55.49501503667524, 55.112929113449596, 57.09447130080193, 54.475606718371, 58.887986829203946, 53.982164705953295, 54.28545021241712, 30.998522850774954, 0.8592348389567868, 2.363428069699195, 9.01934116117416, 8.018399361641176, 6.677694503338107, 16.680020363100116, 12.364249210203848, 1.7429078826981208, 0.354256431061414, 0.2690600381503182, 4.210718802867397, 52.108103306062766, 44.78792113642539, 35.6068528083063, 52.80486922110281, 2.934081938958937, 0.23639688358431865, 0.20012019953179747, 0.17296685656953245, 0.18529716428489457, 0.18518168419118852, 0.1854144523461019, 0.17717929827349801, 0.09005322181169065, 0.16732976711805791, 0.1410792894180744, 0.18587575985058663, 0.17696641776109898, 0.22497621334848866, 0.16211880641358514, 0.12938518708031024, 0.21094054794840275, 0.16070686040386079, 0.1091679965236014, 0.25462623685598373, 0.24986227313357018, 0.06895126865035103, 0.1599733618598792, 0.13731142385832726], [0.021869104032615022, 0.041310575024615374, 0.06827715724225968, 0.10278214039581438, 0.0017053228516634856, 0.07283620010580748, 0.021401118156650377, 0.023646866602282372, 0.047985139047546733, 0.06095917129348363, 0.052528247282269507, 0.09889424418009098, 0.05322056093944177, 0.03138584276330808, 0.017950261695190303, 0.05056071515765883, 0.04428978370983274, 0.027417899935596415, 0.028421884973443327, 0.04958006132754588, 0.056855740070703535, 0.0209378877714757, 0.05758801670444589, 0.027276608424501556, 0.029745790243689573, 0.007579065840541115, 0.015795249660919993, 0.017979666064944, 0.015939145870957405, 0.042100637670486205, 0.16491590067744255, 1.4563065454844506, 40.25035858154297, 42.5732175765499, 37.72305780841459, 58.28775436647477, 14.236927974608637, 0.10182121332975165, 0.15749454648504335, 0.11433954200436992, 0.34963210984583826, 0.6185593696371202, 8.170327957599394, 5.823403750696491, 5.595495412426611, 0.2613547258079052, 0.09031062735424888, 2.911885246153801, 55.783038600798584, 66.88255386967813, 64.88977801415228, 60.42848986964072, 63.16452349385908, 60.111338784617764, 56.632455318204826, 55.84875006829539, 54.29782529031077, 54.04240054468955, 50.07283249209004, 51.63588523864747, 51.53817115291473, 50.215598921622004, 53.61801578152565, 56.12354347782751, 56.455372072035274, 59.9859719891702, 62.270627098698775, 61.41808032989503, 56.68422275973905, 61.5927238618174, 60.08888713775143, 57.813288780950735, 45.74484217551447, 45.04380479935677, 45.05295176659861, 43.170257229958814, 42.821817398071296, 43.498845946404245, 42.78467255253946, 47.77487662530715, 56.21835108726256, 59.17624181316745, 56.73546068130001, 54.63680044297249, 42.53863403874059, 48.06854448010845, 59.981355359477384, 54.37157369429066, 58.02174314375847, 54.371514858738074, 58.51262777082382, 57.66034772319179, 55.29300120569045, 54.43003269933886, 47.07661628723145, 48.4828918980014, 49.39681199289138, 50.655206403424664, 50.43209022091281, 47.4929601915421, 42.60822865270799, 42.39908003037976, 40.7229414293843, 42.61890926668721, 42.84433572523056, 49.95954267440304, 56.75266027450562, 59.21825039771296, 56.333358903085035, 51.197572139001664, 45.789086511058194, 40.90608865984025, 41.28510336722098, 45.07232043050951, 41.36669651154549, 38.86227100126205, 38.44053383796446, 41.605815964360396, 45.75712311652399, 45.327972673600726, 44.73502797465171, 44.33504819869996, 44.53814068148213, 44.01638307879048, 41.72879011400285, 41.73086897019417, 46.7731503517397, 46.33837130761916, 49.51377707142984, 53.33164353524485, 55.25852749424597, 55.674196750886985, 59.1650277568448, 57.39193600993003, 54.5008118690983, 45.70674419403077, 7.508812383297951, 0.21967336805837773, 1.1125762544332014, 2.4794794811356455, 1.0977938218462853, 2.8720474483505374, 3.080788389328988, 0.5063660076308636, 0.03872982399057477, 0.07424589381703446, 0.04038423299789429, 16.85362446692682, 48.50178203275127, 21.253747170971288, 38.1538870257716, 15.835586036405257, 0.047365573099664146, 0.034143676936265924, 0.1004562514924234, 0.05105398001990492, 0.047879736840484605, 0.015646320253220058, 0.028184332599442814, 0.029988825892008124, 0.053723451696456447, 0.06000108258318036, 0.03525153200532641, 0.02246812350236841, 0.014940964906746823, 0.06201195613210721, 0.030461747289424947, 0.03021517039967641, 0.06353744403308918, 0.08268002390621171, 0.009921829745684181, 0.020659401404461073, 0.06847438657836569, 0.025334500842877937, 0.0247298889312773, 0.013107208970693812, 0.11478049455270653, 0.06634607175064665, 0.05341333930470771, 0.07827812865857156, 0.010244603655601462, 0.029360227767498265, 0.02318517222339588, 0.06847172059238919, 0.01888879026556688, 0.024182289283001618, 0.028868496996320547, 0.0739824361798744, 0.11871575032390895, 0.013994095554094643, 0.036170657483800765, 0.06269075599829517, 0.07297814087641817, 0.0671989574367481, 0.02175006354528089, 0.03278423476243212, 0.07100397826082284, 0.03991262161082799, 0.025152966733120626, 0.04596631350596586, 0.021950558331164143, 0.009239962654969385, 0.013521237358931574, 0.030195895627501513, 0.02537796101082237, 0.06373903240948435, 0.13282800153378518, 3.3957770226463198, 52.1061146643854, 39.615985808833955, 43.506937796069735, 68.1655768425234, 12.616838082190483, 0.022648297806060123, 0.07905056745174431, 0.11511458549648525, 0.04339577059351629, 0.6920096734839102, 5.918780103806527, 7.337577391055323, 5.31418155277929, 2.8795134348254052, 0.4501702101720918, 4.404305911833241, 60.535288164692545, 67.83255977015342, 68.55945341048702, 63.905212110088726, 64.44138834553381, 62.55987836468605, 58.506481416763805, 59.217681654037975, 56.40561288402927, 55.291887252561516, 53.22213096003379, 55.140260188810295, 53.56119632720948, 53.5473072144293, 56.79937962562808, 58.68484335560953, 56.94711962053853, 62.65919669981926, 64.91844661774175, 61.42854521351477, 57.51139571589809, 62.27249022453063, 61.83960176283314, 58.626396117671845, 48.393987455675685, 46.576733742990804, 46.391284081243704, 45.30508956601543, 44.42097163969471, 45.25524408586564, 45.67579277100102, 49.698775660607126, 59.02650140946912, 60.457629157650864, 59.827818101452245, 55.2281173583, 47.18598373474614, 52.25874193253056, 59.81480759959067, 55.39919153336556, 56.02675507145544, 55.0145717590086, 59.338502422455825, 59.281094612613806, 58.14151271697014, 56.5834217686807, 50.915153641854566, 51.485529022832075, 50.3188160927065, 52.72557850806944, 53.06777392664264, 49.70638113637125, 45.45837186997937, 44.1979339045863, 41.81771024580925, 42.412612207474254, 43.5659263210912, 51.59903457087856, 57.53104679046139, 60.64151771606938, 57.73460995766425, 53.74715589707898, 48.1783983015245, 44.119459044548776, 43.20633519080378, 45.337284380389804, 42.87267092735537, 39.67739051388156, 41.31882790596255, 43.9398576367286, 46.59389803486486, 47.82169795805409, 46.1944007104443, 46.81190729141236, 46.42803668975831, 45.93123320610293, 42.13587722470684, 43.12879777723744, 47.461773426302024, 49.325220892506266, 50.86430403494066, 54.0655307615957, 56.17886458673785, 56.91513269178329, 59.11051073381978, 56.33546913823774, 54.64957560262373, 46.623406025671194, 10.073729176675121, 0.4961962210795572, 2.9609989591183203, 5.76659998586101, 5.6953981807155, 4.113767127836905, 1.872718478402784, 0.05682341882117814, 0.04029605244736999, 0.14020651608945864, 0.16845970084109615, 15.955221268438525, 56.08731646691599, 23.76913178351618, 39.93413317588068, 23.755756501228582, 0.05982344977617745, 0.057841289202652635, 0.07289722666985567, 0.026821716906382676, 0.01832624807232811, 0.03747949955023585, 0.01932977154220064, 0.0668679308446665, 0.023968872509055564, 0.06922948880181198, 0.03554762881850043, 0.04474439943629888, 0.004145827486119684, 0.051233991529912724, 0.03961469384751493, 0.05785310610888466, 0.10477676521986724, 0.059764028166330634, 0.04358690570018465, 0.022155800946958126, 0.0349243511746247, 0.034000583203329195, 0.10724426547606146, 0.010020578479123934, 0.15193847849244072, 0.19102914138667046, 0.25710017991162115, 0.22120382786998827, 0.14684361075201344, 0.2413736052450634, 0.11059239912297457, 0.11504971317105717, 0.1541816452217679, 0.14821179781950292, 0.15597090485595888, 0.1477343718250913, 0.15482195683064, 0.12278727781508239, 0.08489231729219038, 0.15065194107592106, 0.2058381725463175, 0.25242122130528577, 0.06845495092772669, 0.09168021636263979, 0.24991603718409616, 0.1879851982718514, 0.23175100465455364, 0.10350548827479925, 0.13903703690776903, 0.15119476033554924, 0.12770805207471694, 0.2508708125641269, 0.11408161552202319, 0.22842428316512417, 0.40681134969476734, 4.944447663522536, 58.98011153744113, 55.466589620036466, 46.59578077254757, 69.70137303875339, 21.480546459074944, 0.19347340619612127, 0.32311290382377567, 0.3811152285385517, 1.526225000139206, 5.790750019011959, 26.659359662763535, 13.712692414560626, 15.257340419676998, 3.5198026126430886, 0.4298836197103224, 3.946496426097809, 59.79042614659956, 72.05042562177105, 70.5664517802577, 66.0428685526694, 68.4947343026438, 66.89436020389681, 61.50738093160815, 63.10472696058212, 58.983245511208814, 58.08997669527608, 57.26910698798395, 57.80053323315036, 56.55543565750123, 54.301908477660156, 60.6364853151383, 61.820986193995324, 61.098567978028335, 64.17145083027502, 68.10137548754292, 65.12242555618286, 57.69702188430294, 65.54762617234262, 64.72297922257455, 61.65388930228449, 50.35496465621456, 49.297787835521085, 48.451163845677534, 47.406397404209265, 47.51276423854213, 48.9636254310608, 49.01807185142271, 52.734105740824056, 62.44603157043458, 65.0832450005316, 62.382304822244954, 56.86580104212607, 50.5505261882659, 54.36517238616944, 61.98284279915595, 56.53551001702586, 58.12092419593566, 54.78178301165181, 59.45338080006262, 62.112579114975475, 60.00459540274836, 58.91226237820041, 53.4358177646514, 52.54924051223263, 52.22178928313717, 54.51275156390283, 54.863925287800456, 52.93864165582965, 47.823023719172326, 47.17525212995468, 43.86921967229536, 45.756154291091434, 46.79838295905821, 55.07177168323148, 59.91693435176727, 62.74965440073321, 58.73171175679853, 56.08114657863494, 50.16378441164571, 46.59695356122909, 45.24866234871649, 49.19214271729993, 44.817342835087935, 41.88020144739459, 44.01630855375721, 45.117886604801306, 49.75021754541705, 50.1574380167069, 49.06306928203952, 49.539323468362134, 49.663850876592825, 49.18527856949837, 44.30788970762684, 46.144382646006925, 51.468023484753026, 51.092742873776345, 53.228426364160356, 56.253789701769435, 57.619229516675404, 59.27674470409271, 61.62083156647221, 58.625074278923776, 56.63617372512818, 49.81954936058291, 8.790523813616845, 0.7460906392624302, 3.928509662228246, 6.1129374273361705, 9.99159082289665, 11.290637658488366, 8.975921503959164, 2.9816191042623217, 0.10191245440153346, 0.4542671258170759, 0.2197066162742915, 24.252671772433867, 59.99713505468061, 30.065785184983287, 50.53861395005257, 25.946572826754664, 0.18970059170838327, 0.15820392858116858, 0.1684124791814435, 0.15642527160384964, 0.10999898741682691, 0.12208135843637491, 0.08858319867642657, 0.20863293790288512, 0.15736495505177206, 0.1335684867996362, 0.198006700844534, 0.16212084420746373, 0.050189128040426204, 0.21539747895252323, 0.13558274645718837, 0.18468164328125217, 0.13282164300401367, 0.23753504509166365, 0.10628670153598632, 0.10755823129006933, 0.14823709404276264, 0.09993521211248252, 0.27979053977516394, 0.10631647937360311], [0.09005586481502942, 0.006563249532313597, 0.05981418394273328, 0.0868669089170233, 0.019054510405347235, 0.043303269307099046, 0.033766432259712494, 0.09427013746913403, 0.03284583589242351, 0.0676252547230932, 0.04555575166558547, 0.049675519713350845, 0.02256864189891325, 0.020019446026473757, 0.028855986780517047, 0.04106686330370365, 0.027206578412123268, 0.05194972449493024, 0.03640393891762342, 0.033275040482441266, 0.058963320728751926, 0.10967089494149532, 0.03991612646308157, 0.03154529630386781, 0.011844577327851328, 0.021524146131630388, 0.0745952375713856, 0.007293282007242764, 0.0618429686273298, 0.05434976304851232, 0.03558779480837045, 0.2052314155885289, 16.419656372839405, 50.11634334441155, 38.853618252661924, 47.74082652984127, 45.926075289326334, 4.094002059390468, 0.013653941024395247, 0.03210437386446903, 0.2222995021410527, 0.35056845315041085, 4.161278307437897, 3.5704337925680223, 3.359082514239896, 4.8942006307263535, 0.1582094290924649, 0.13594064741365372, 9.835140224426024, 60.713501053471724, 65.62013902971822, 65.12414747668852, 60.73239511059177, 64.56330737759991, 58.7221529406886, 58.02402988556893, 58.00109970954157, 55.62457484583701, 53.39499373589793, 52.84655617129419, 52.47880258867818, 50.332316890839614, 53.362995040032175, 54.53756055524273, 59.47444785025812, 62.18215019472184, 62.54747190783101, 63.22157044564525, 59.18521227375154, 64.3438389993483, 61.22257371102611, 58.974420178321104, 46.33368407526324, 44.238412764764604, 43.77543187910511, 44.790941361458074, 44.64064398119527, 43.41117312831264, 43.64011010816021, 48.94595907580469, 59.92607739663894, 58.89381154890984, 61.221765702770604, 54.354362333974535, 51.11957580812516, 42.68706437080137, 50.459378150201616, 57.11535007722917, 56.80047004453598, 54.37665708603398, 58.74423588475874, 61.4617794559848, 56.52326045497772, 57.7041684427569, 51.96867873591762, 48.569223265494074, 48.16993774906282, 48.68185020262196, 46.42145887497933, 46.34106597592754, 42.94379918806015, 41.509812032022786, 41.5119497237667, 41.95451075030912, 47.679668934114524, 56.38374959268878, 59.8197497860078, 55.80324272955618, 56.44991213275541, 52.00997344909176, 41.17681457150368, 40.14017528103244, 48.74804412164996, 51.03575475754277, 50.477256313447036, 41.35264658158825, 40.04518724256947, 41.285750558299405, 44.06572257318805, 45.364152616070164, 46.487111506923554, 44.52095677775722, 44.01792457026821, 42.918680329476636, 41.56409763520764, 41.9033081300797, 44.01575942193308, 47.91209290104528, 52.572421719951016, 51.356279080913914, 53.022529386704974, 54.032492637634284, 57.00071488657306, 58.881997369950824, 54.70155485214726, 21.67690815464143, 0.6195177149868781, 0.4922175281230481, 1.4119842528335511, 5.832637010082122, 3.9334594482375733, 3.6611175200631543, 0.9423816708787796, 0.14315187901018128, 0.11813278039616924, 0.09647326078265907, 4.116807455016721, 42.59750097028671, 28.53454874407861, 22.81238332871468, 40.49843280546127, 2.7832523420933755, 0.07719584560442357, 0.029000593537104227, 0.019387766313288483, 0.07970283769311444, 0.04048499271213528, 0.027619591733861356, 0.051944128222643375, 0.07843482428260388, 0.033481007051323695, 0.016404857423396844, 0.026306072700648542, 0.05512831139288122, 0.06841653161832402, 0.022403373751008225, 0.01287126538133429, 0.041536053852929224, 0.024797607273344072, 0.02975309489204759, 0.05988271816843941, 0.03681574948132038, 0.05534772663527439, 0.06870444278202711, 0.03439437537904709, 0.03055717311649313, 0.026684736555081703, 0.06338857016676376, 0.02470453716664305, 0.04003699981577454, 0.03494107487401174, 0.046694713734811356, 0.07967078457436255, 0.06791407753142618, 0.07045044143113398, 0.06943379679033834, 0.014093857438814257, 0.006654663452683318, 0.048854185358410886, 0.04126431097486808, 0.04195048826776686, 0.06621588276879442, 0.035584086942816937, 0.08727282060370331, 0.05540608721334608, 0.019712388410323092, 0.008943952984296748, 0.08332755972420977, 0.047805250111606815, 0.054225940257310874, 0.05626164271586365, 0.008993567711102867, 0.0295371308757533, 0.03259910961552974, 0.03312800522713411, 0.036261760659756205, 0.06682536699959347, 0.1295824240772955, 23.158654089896913, 55.4643460242979, 32.838822449407274, 59.47383203814107, 49.374246597290046, 3.3897042130270316, 0.027549944765445207, 0.133328624670544, 0.040846061442167535, 0.3472992495423363, 1.951873501943004, 5.171225378590246, 6.06728054823414, 5.633036417345847, 1.0740941258207446, 0.28864103099030836, 15.154458611242234, 64.08267582616499, 66.28078383784141, 68.78631545651344, 63.98052946213753, 65.23406013365715, 59.34077739715577, 60.13102516051262, 59.24404390396611, 57.59287511148761, 54.94390633798415, 54.11160292163972, 55.16328842409196, 54.10757856984293, 55.38167815054617, 56.18971386263448, 61.326610657476614, 63.63667880335162, 63.276491472798014, 63.391624804466005, 60.68966480993456, 65.11429056044548, 62.29574987965246, 61.24049109797324, 48.306079295373735, 46.97689394797049, 46.21220827102662, 47.55965617395217, 46.480117920906316, 45.321128137650035, 45.35916728358115, 50.44576752570368, 61.08028188828499, 59.46958018887428, 62.73842857730005, 54.76639947583599, 54.73171787877237, 46.308380865281634, 52.63600726281443, 58.82231850777903, 56.95912207326582, 54.742390648011245, 60.934922772069136, 62.79050196370771, 56.019973293427505, 58.54048836615778, 53.699710907474646, 50.777376467181796, 50.5464586903972, 51.065980542090635, 48.40572710960142, 48.50214289080713, 44.34425007912421, 42.899335199786776, 42.90186905091809, 42.70640950049124, 47.25080090184366, 58.25059383146225, 62.480105200121486, 58.943970818673414, 57.35659937704764, 52.49197390771682, 43.489357732957416, 42.844425939744525, 49.83973779985982, 54.49325738414642, 50.085874372913, 43.641078933592766, 42.898950807509884, 44.00716943125571, 46.20037448021674, 48.65808456174789, 49.75292398083595, 47.059016612268266, 45.175706263511415, 45.186084854987364, 42.6854601214009, 43.63377548033192, 45.97381445669359, 49.45159573708811, 54.004467302753085, 53.26675576548423, 54.42305872517248, 54.61182671208536, 57.12561491997012, 57.81679537988479, 55.47990998914165, 24.737508104693507, 1.0242620675313858, 1.422045867769949, 2.152438384871329, 4.816432287616115, 5.137605763250782, 2.2737023811186514, 0.4826838090535134, 0.10021890979260208, 0.08358569305029609, 0.1455740958091713, 3.7473454350425355, 45.34083804776592, 37.704736417339696, 23.171654785833052, 48.25049931003202, 4.978886073635471, 0.10888066758672077, 0.01508014584561029, 0.048056090280653975, 0.052667675284488555, 0.09789406276878812, 0.03033638466149569, 0.02373525208132642, 0.09075398541866772, 0.04246374802483667, 0.05217875414077313, 0.08700180933960984, 0.038755924606155005, 0.041943949707333124, 0.02492769857898595, 0.046145754280470075, 0.02786884418568544, 0.032040585553453814, 0.029454268890643315, 0.03028503570315098, 0.05572040159735949, 0.04559243578583964, 0.024209927820089846, 0.0408088295690475, 0.06847422569990158, 0.19098389623386247, 0.0934483243092414, 0.11123381389845764, 0.14377031114793595, 0.11266532579376815, 0.11236694220814014, 0.17761823601059376, 0.19511997429353578, 0.12104157027938675, 0.28634797661535205, 0.10671369596234254, 0.1052394899870119, 0.16674682017295592, 0.17558431853690457, 0.15150413728289067, 0.16678958320088927, 0.13718694989239016, 0.21496738187007366, 0.10307447188684057, 0.11286530538552231, 0.10980833111511124, 0.25882151819044547, 0.20405646653905993, 0.16525886291938444, 0.1888356937636291, 0.06892869203922249, 0.1265708328555188, 0.1295715609505292, 0.11063743743204302, 0.09711450701879878, 0.11933581422894232, 0.23733672024982594, 27.193082455665838, 65.77188376457461, 49.37634114296206, 59.835819736603774, 57.97720855282199, 8.128371834754944, 0.12102825567126275, 0.26513889371868105, 0.31454460875641915, 1.9272112317623633, 11.002262061642064, 14.213672241856976, 10.480172038078308, 10.482377390707693, 0.6499850317355126, 0.3266190431050716, 13.153682101157404, 62.687394618988044, 71.33542460779991, 71.48502380617204, 66.1732324477165, 72.31923349442022, 62.29509876620386, 63.48234138181133, 63.57314032893028, 59.51429128646851, 58.05148255440497, 58.16152857195947, 57.894783866020944, 55.480372828821984, 59.104434982422866, 58.52461453407042, 64.95878035022368, 65.6173776811169, 64.07854164800337, 64.97994545967349, 60.89278867167812, 68.32826106779038, 65.31491587238928, 65.11487891597133, 51.29089709251158, 49.74054498057212, 50.562818896385934, 49.37092434975409, 48.073937739095385, 47.48255414347495, 49.369155360806374, 51.803527339812256, 64.49379121103595, 62.90483513186055, 66.62525423111455, 57.09749152583461, 56.6554678640058, 48.581916055371686, 52.8326827479947, 60.38896806778447, 58.42000099920458, 54.10944954041512, 63.675643628643414, 66.8695943586288, 60.890494085127315, 61.64156521520307, 57.714186176177, 53.644534926260675, 52.879315806973366, 52.96163458977976, 50.65102515682098, 51.78385665339809, 45.92708333846062, 45.80805901558169, 44.5265422328826, 45.63361160216793, 51.51117347901868, 59.81376032675467, 64.56104417001048, 58.65185230009018, 61.81546741916288, 56.19281645744078, 45.96968812327231, 44.82717621710993, 53.79347516644386, 56.857807251714895, 55.16694407309256, 46.15780107436642, 46.45021377071258, 45.39211911539878, 49.039205581911155, 50.39151722385038, 53.48705176384219, 49.62172854331232, 47.98823002846011, 48.07186280527423, 46.024699364939046, 45.41056994468936, 49.192636935941636, 52.000493080385276, 56.99958524396343, 54.752855531630985, 58.63933601687032, 56.17242405491491, 59.138308571230986, 58.830724147058305, 56.528661558705, 24.56943846517994, 1.2135877051661093, 2.0031219648738063, 4.03688058257103, 11.299933675796757, 8.964918275033275, 11.562163733666944, 5.027971594564376, 0.5131734342825028, 0.305006048011203, 0.2699923365106506, 6.811990574482949, 53.47652019992952, 38.77407258556735, 32.42365329496322, 56.527273039663996, 5.070353784868795, 0.29972215573633876, 0.06852910823879704, 0.12910806243458103, 0.1365141255120116, 0.21586578850063587, 0.10458731167619267, 0.18123930380229028, 0.20941267751397627, 0.12367379476105976, 0.1661193022324193, 0.23707560684171416, 0.17016133533850794, 0.08464184484534687, 0.12607245435637812, 0.26338397014525633, 0.1746750181360591, 0.173764277489916, 0.09616705543932416, 0.11089262898050009, 0.13432458493738406, 0.11043096141469096, 0.1734429495709558, 0.10692742683233754, 0.1652754257403074], [0.04204582790994356, 0.06922198880103327, 0.010542509393886694, 0.07042247156101851, 0.02075901007159583, 0.07661581745431309, 0.0650882090051328, 0.05304210841835988, 0.032614285817309734, 0.01478532073839057, 0.022255863521188017, 0.04154228597819325, 0.08837940396680947, 0.015833309866608154, 0.004481316061555258, 0.020877958628379052, 0.02484584399949639, 0.04854709518352344, 0.05614222876066643, 0.06373046371605127, 0.0759859093194527, 0.05855657783667407, 0.016552928812621583, 0.01418079022363189, 0.02678916966091962, 0.04496124062326647, 0.03778334534276397, 0.043560176892506505, 0.017705113559420553, 0.0460627869582705, 0.04250095308487935, 0.05793970851828495, 0.9794934826993174, 38.10654009542158, 44.2490110089702, 33.421794522193174, 52.7869479117855, 39.785228237029045, 2.682523914883214, 0.01750648228241311, 0.06271949961721417, 0.027532868665612997, 0.5953533406699858, 3.951220185525956, 3.233672572720436, 2.616079454460452, 1.5752223903133025, 0.038837375074264505, 0.015951452115851066, 16.967383007849417, 68.4806529937252, 62.72621039421328, 69.22994336774273, 62.52742859625048, 65.50292291948873, 60.86919953746181, 61.57186077487085, 57.03117209096109, 57.252935055763494, 54.12113035878828, 54.360442007741625, 49.777152461390344, 52.82812495385447, 56.58620665150305, 58.607976667342655, 63.74446553568687, 64.45298679413335, 58.79330865798458, 62.048381682365175, 61.57371605596235, 60.43508729627056, 56.3554810708569, 47.8311469477992, 44.495869298135084, 43.716109952619, 44.010370085316325, 44.59273222954043, 43.939932161761874, 44.409330045023275, 50.09100483309839, 58.044053585298606, 60.03393865400746, 58.75303376105524, 59.8180200207618, 58.35559175860498, 49.666686750227406, 47.21898263500583, 46.30217567566903, 52.92788651681716, 57.776653843541304, 59.82281315711237, 61.39875088968585, 58.77166894174392, 56.33974844409574, 53.17178341650194, 50.65099770022977, 47.01947127619098, 45.20257057682161, 43.35422815815095, 42.151166623638524, 42.010781072801166, 41.70795056127733, 42.203094882349816, 42.89866839685748, 54.193090161969586, 57.644011051424094, 58.621971684117476, 58.32229475821219, 55.828247839404696, 45.224127923288655, 40.65124050263436, 46.79695913868566, 54.21675382121917, 54.88276050936792, 54.66834022152809, 49.17817123474614, 41.5853411920609, 41.15599855299919, 45.379571453217544, 47.00016929257301, 48.491101418772054, 47.08361379561886, 46.1402210112541, 44.35229093797746, 45.52232611563898, 43.09163331985474, 44.61972990343648, 49.56481887448219, 51.712818607207275, 53.4956652887406, 55.834347125022646, 58.553353740322976, 60.43185918561874, 50.400507296285326, 22.48446337638363, 1.1286634879727517, 0.05217308509013346, 1.4133433540982585, 2.48318170828204, 5.853124530084672, 2.674775762904075, 1.565978957280036, 0.20346307015467077, 0.03143652522515866, 0.04503940840462043, 2.5687992044033545, 31.396731676593905, 40.19519436743952, 19.24559170199979, 35.996497138854, 18.939862558918616, 0.04260225672154658, 0.018856652877143314, 0.05470916936774889, 0.010807782659427294, 0.010860477059689021, 0.012497796560637655, 0.031164460590169318, 0.026681982468993917, 0.05236644185178223, 0.0169768646329401, 0.027849375976309664, 0.05881805896698948, 0.039140562031177745, 0.028785435828350248, 0.04554465105156264, 0.028210006121005264, 0.029053687260696487, 0.036099353850248365, 0.04878619888557061, 0.03684478038321099, 0.026607537874951962, 0.011516524114525847, 0.007930466062163995, 0.022314662684596354, 0.03675617465388872, 0.03938932227151048, 0.04604572234975715, 0.0064925827093482505, 0.037576662481672345, 0.02219280107848106, 0.06479884993525283, 0.05564241001622812, 0.036278208567490505, 0.03657927346085349, 0.05856860541708528, 0.010540440956491136, 0.02777884034590135, 0.08869447294742831, 0.03910573950457958, 0.02113238025847222, 0.038493616100881374, 0.06467924828851415, 0.032410579207803936, 0.03407714986092141, 0.038925812264243444, 0.04905688839273588, 0.10524129029363395, 0.00710410186119618, 0.01970422382827007, 0.03725055417406463, 0.03851421237472565, 0.04453295916919747, 0.07043588576057265, 0.016683129285792672, 0.034455608786834825, 0.021278528767007015, 0.12201883800087437, 1.7245538869211752, 49.03734637844948, 45.02939793371385, 35.748022833178126, 65.53684749910909, 39.68915370202834, 1.3691793045689984, 0.10334303166957633, 0.040204922458337206, 0.1494353781304052, 0.33332926852087824, 1.8468587821529758, 4.6175185999562665, 6.073619098432603, 2.829384073134392, 0.28055693413461413, 0.06551682753788848, 22.455426069997973, 70.786983120826, 65.59219998698082, 69.50278343692904, 65.00979861905499, 67.05686400013586, 63.58968880868728, 61.47751600511613, 59.874129526076786, 58.98086463251422, 57.039801305340184, 54.257468023607814, 53.398182622848026, 55.747917698275664, 57.68195606047108, 60.93290275143039, 64.34111687444872, 66.9691990267846, 58.561288695181574, 63.28918034030546, 62.772455138544885, 64.14908939792265, 57.48955203640846, 49.17144436990061, 46.60672418532833, 45.36254052192935, 45.21935439878895, 47.085316104273645, 46.65069787733017, 44.90095207768102, 51.81002670718778, 62.13714884173486, 62.3496550129306, 59.70175704648418, 61.093417905992084, 60.22716245343609, 53.051821647151826, 48.796010786487216, 48.28494164251512, 54.223680726943485, 56.737998454801506, 60.74717067903089, 61.297263483847345, 60.642580678386075, 57.82384780145461, 54.99958830495035, 52.14649154293922, 47.59695006955055, 46.83920698781168, 45.691886255818034, 43.50277223894673, 43.60964505903183, 43.465011581297844, 44.74457502365113, 46.43539505620157, 54.78611330832205, 59.779110108652425, 61.214717203570956, 59.53175367847566, 57.18805120837305, 48.07102341805735, 42.44785470347251, 47.217935362169825, 55.47309683215234, 55.767596229430175, 55.43678352909704, 48.954396094045336, 43.14362825885896, 44.35118482958886, 47.7582065520748, 50.4036138134618, 50.12618064880372, 49.21854811329996, 48.163167738145404, 46.508413899329405, 46.41962320573869, 45.289074528601866, 47.38369080328172, 50.8900426280114, 53.374213018725, 56.48005946989983, 56.953218906156486, 59.82563726363644, 59.63098964383526, 54.16883030245381, 25.977306558239846, 2.517096236828835, 0.8720008055529288, 1.6268194538931695, 1.6413539191407542, 7.931324214704576, 3.2987576867303545, 0.5521017937890945, 0.2138582550950589, 0.11554551761477225, 0.07103049256388219, 2.219710710548586, 29.676548780933505, 52.690300710739635, 22.15666501752792, 38.299199073545395, 26.51002718556312, 0.045157811123757594, 0.03710326610974247, 0.011860241910683052, 0.022732827947625232, 0.05352959314721727, 0.03856179792614233, 0.04784423632607345, 0.044335170588906736, 0.016553758102799618, 0.06991003534846729, 0.03589151419639107, 0.010333068616267656, 0.022397744919984572, 0.030492599565355532, 0.027211598203247114, 0.04484200669873146, 0.008773980098926734, 0.03873468864889395, 0.04617507629577191, 0.04509438670450642, 0.03987603325156435, 0.038007797613259287, 0.07948996484159462, 0.03239483993139959, 0.06772507597962696, 0.15049679294949578, 0.12841433917562808, 0.1438718177979031, 0.2311119187863604, 0.16771993569789395, 0.1438914143270062, 0.13072674493155173, 0.13846156698080803, 0.16364696796142286, 0.25083086873975496, 0.15384042966029338, 0.21636754544752262, 0.18257329270483988, 0.1257509042719199, 0.07436518136772417, 0.11174356880327387, 0.1133377901128223, 0.12086094972947914, 0.17030572759047632, 0.18993449367342458, 0.21723835759105223, 0.13895290513192454, 0.1445615573996498, 0.10642933944660811, 0.1648285360105576, 0.1900016642626255, 0.13330392599586519, 0.17806808283973127, 0.09672435376072124, 0.11502796393488685, 0.17957140781706382, 0.24019441206849393, 1.6059540380393307, 55.04232645034791, 58.14201870272237, 46.55095984858852, 63.73634230706, 53.30372802672848, 4.543552504431817, 0.22123695351183417, 0.1338894163528758, 0.3651608346450714, 4.513734156085599, 11.822404169267225, 11.786698833588632, 9.885008258204307, 6.0460953366371895, 0.19588069960234628, 0.22339845526843305, 20.470530256148308, 71.15094769385554, 68.35597653542796, 73.81802605044457, 68.05484048781857, 71.4736803116337, 66.48946962048932, 64.17558500843664, 62.35507965087891, 62.75165088715092, 59.28316170169462, 55.98907286121, 57.38076902204945, 57.90143228346302, 62.132563591003425, 63.442329283683534, 68.4353417734946, 68.6219524568127, 59.91749525070191, 66.14041005411457, 65.28725139556393, 65.49655299032888, 61.36568138676306, 52.325594809747514, 48.606426946578495, 47.41359103110529, 47.621853197774584, 47.321591838713616, 49.047368034239746, 48.0676305678583, 55.315888235645915, 64.65558898064398, 65.05324671345373, 61.209210195849025, 63.5654720952434, 61.08124679134738, 55.6250729868489, 51.28256205589541, 48.47538840386176, 57.047218507336034, 58.803981427223455, 61.38329675120693, 62.64691968117992, 63.963302412340724, 60.456738779621745, 56.52733971995693, 54.3824347372978, 50.04456397025816, 49.704357193362334, 46.46715448748681, 46.043008988903416, 46.01869421620523, 45.734028200949396, 48.71454315800821, 49.448861845078014, 58.41598056977796, 61.1936423086351, 61.98465493417556, 61.93036148625036, 58.6883891782453, 49.840561497596006, 43.71081867525655, 50.7598630843624, 56.136659883683734, 57.44204428888137, 57.726749527838926, 52.453899460454146, 45.92429061089793, 45.461239122575336, 50.06445430940198, 51.82573972209808, 53.35376962538689, 52.72211505520729, 50.19454363853701, 49.65657487992318, 50.20186278127855, 48.061864683705, 49.51230226024505, 53.542733730808386, 56.12864255905152, 57.57595792893441, 59.16204675551384, 62.35487568762995, 61.525894518821474, 53.465235540943766, 25.175544677242158, 2.3933081953756274, 0.6335091158266991, 3.1265011622059733, 7.86716208342583, 10.560276642922434, 10.538689878679092, 5.762905113158688, 0.41739246417437836, 0.3718907944858075, 0.19870028620766056, 3.879520239368562, 41.57076566450058, 52.20598997608308, 28.567914385949415, 50.19466130964218, 29.299911029877205, 0.14174881962037858, 0.11427476927037201, 0.15432796801530546, 0.11673804838210346, 0.17020593697745956, 0.1799825059189912, 0.10633627508556652, 0.16757862311938118, 0.138537195180693, 0.1467080285111743, 0.12072053347383777, 0.08680405140283608, 0.10781924510675092, 0.1194764986153572, 0.15902105328296462, 0.1577986833909827, 0.11915360021615222, 0.1549622888166097, 0.1664048385235571, 0.13751446780177856, 0.16490503755067626, 0.12359321763318394, 0.18536130116591532, 0.1228534448291025, 0.23763596951480837], [0.03820449451825792, 0.03432363482011903, 0.04381982324224326, 0.01323219046988074, 0.054897688284155824, 0.06970240253834956, 0.016489266906113877, 0.04593699149066403, 0.02619468351645816, 0.0112752246129657, 0.05382943996078065, 0.013253014654882494, 0.06397262793935596, 0.05349179053859365, 0.01775907296236725, 0.01322732964200118, 0.009094780374829088, 0.05075486865074885, 0.03165540995166427, 0.017943382225630265, 0.031776748702771244, 0.022400813102121317, 0.1485647498479774, 0.13071592777006089, 0.08320481711698156, 0.017072254070831884, 0.03944730363605965, 0.05046671999978924, 0.04943619767624525, 0.017950420658434593, 0.048379195523598505, 0.04327255684221464, 0.17268600873649123, 8.104279656564037, 47.28219947507305, 38.58885826603059, 41.50080234773698, 52.32724612759006, 36.10675104202763, 4.885533173238078, 0.16949822495300926, 0.05402363558870651, 0.10730096364333745, 1.0977362120343794, 5.431359419899603, 3.4745639562606816, 1.4610508973560026, 0.6393528958001445, 0.03622763527316913, 0.08112132609371217, 27.37061481322012, 73.89029964323967, 68.00085298476681, 65.98746115161528, 62.261142807622115, 64.67299253709855, 63.12957125325357, 62.84220664731918, 60.121564403657, 57.250989560158025, 57.092890585622484, 53.05400248496763, 52.91112622907085, 59.86213099571967, 62.462136822362105, 64.87949355956047, 63.380124415120775, 62.90428600003643, 63.348192399547955, 59.716462012260195, 58.875043007635306, 54.65281548038606, 49.11754708136282, 46.896567729211625, 44.69883626507175, 46.257625395251864, 45.124613469646825, 46.928036905104115, 44.119357062924294, 46.53341508680775, 58.23683807926794, 58.84840226942494, 59.36488428423482, 59.49436956836332, 60.85819336675829, 56.89953734797817, 51.74067920254123, 50.927846431732185, 52.30360208019134, 57.28426302632978, 58.35534072691395, 62.123165592070556, 58.2584071928455, 59.62858130854946, 54.117568846671816, 51.221424072019516, 48.518338357248616, 44.062643512602776, 41.61980705876505, 42.2663587908591, 41.448022934698294, 42.250626164097945, 41.11839086778703, 48.4756512026633, 59.80730802782121, 59.5755430190794, 59.33489384189729, 58.06115904162007, 53.95726942246961, 44.98564389444167, 41.18238825951853, 52.73408220660303, 58.228742307232274, 57.81024502169702, 54.720076284100934, 53.43406446518437, 45.39818702205535, 41.40528086693057, 45.968150554164765, 47.19159272409255, 50.49047470092774, 50.256599457033225, 50.065195637364546, 45.698016920397365, 48.44990476485222, 48.9994994286568, 48.42174214701499, 52.27707116834579, 54.32606243318128, 53.73720092158164, 55.21942538599814, 56.96389559776553, 49.452038964917584, 19.628134581350512, 1.5319309455733148, 0.35875777984338425, 1.9557120314528866, 1.4667045036631248, 0.6598142462392008, 5.532732096410567, 3.1709293588515255, 0.3398684418249515, 0.010104022691056374, 0.015124706307335969, 4.186320679803049, 29.132312074784313, 43.986714270807084, 24.45038276333963, 29.626646426416215, 36.79130661872126, 1.544826472959211, 0.0634590387644787, 0.03527713466375586, 0.016853618322901668, 0.02373347475734209, 0.048992605955009504, 0.04269940050078496, 0.061800676743469896, 0.03173724537895572, 0.0301673473610032, 0.022691003377399138, 0.05794656117476764, 0.027687742915605346, 0.10330552400480356, 0.051605118994390776, 0.013058737630114682, 0.019902889579234105, 0.049640965317526174, 0.030842920081810127, 0.03226132612795599, 0.060725683015921426, 0.056324247421035846, 0.03408698642986917, 0.06973306137707926, 0.020874633806787675, 0.05425773673660813, 0.010525733025954857, 0.020828166743740443, 0.05153833911003125, 0.06496945005511084, 0.04125538988098983, 0.05261138697425204, 0.025457490513461734, 0.05377006048576967, 0.012967343340748021, 0.032356818987717556, 0.03217586902000251, 0.03395206685508451, 0.017354277848836877, 0.01801683665103009, 0.020123204974938306, 0.0747973315658108, 0.015888011417231493, 0.026252551883038495, 0.0712857453993732, 0.07377851123531019, 0.059807292981854374, 0.04822026292282728, 0.08858592594943701, 0.022974892579499754, 0.07114977245369265, 0.10864357869591444, 0.03805396973245567, 0.03733056439687649, 0.08730164849229398, 0.022415378348781698, 0.02140060487774111, 0.06659926380962133, 0.11507612788268637, 13.021180514366398, 55.63793836101409, 36.65252923965454, 43.23778475484541, 65.8745361143543, 34.81813476931664, 3.7572410846910174, 0.08894217981686516, 0.04256025978153752, 0.08480823148162135, 0.3892864449129951, 2.6387127560953942, 8.918281293684437, 8.452956791846983, 1.951296178083266, 0.08658685015454408, 0.12849128504674281, 34.58612657362415, 72.90272528125395, 70.31087798456993, 67.85034379651471, 65.35936417118197, 65.75646884979741, 65.22960432114141, 63.177753648450306, 62.043635614456676, 59.352054211401175, 59.92586558864963, 53.824759990938254, 55.15899342875327, 62.36603483077019, 64.89006042480469, 64.68288867704331, 65.96624897372338, 61.57547327779955, 64.5927918341852, 61.65638392971408, 61.183950131939305, 57.294527869070734, 49.22603591795891, 48.02138582352669, 48.01623967386062, 47.56372759419103, 47.85486159786102, 50.25038642268027, 46.59838130397182, 49.83823160971365, 62.15609388966715, 59.81204625098937, 62.07025281844601, 59.71889388176703, 63.24798760875579, 60.16994683973251, 58.75458309727331, 53.97936021128009, 54.21684403573313, 56.96213053118799, 57.83347329785747, 64.03226160234021, 61.30587308637558, 60.77993423708024, 55.6906432490195, 52.5183714589765, 51.0813013199837, 45.22734426682995, 44.089205803409705, 44.95326080629903, 45.050468906279534, 44.55197488107989, 43.218066999989176, 49.52542651084162, 61.54394526635448, 61.643965705748535, 60.73267359887401, 59.71751712983655, 56.266929641846694, 46.22212402282223, 43.24412722741404, 54.63185041181503, 58.99236109948928, 58.888841905901515, 56.99581976859801, 55.16610860824586, 44.89317793999949, 42.40727386166973, 48.52460630478398, 49.1736565866778, 52.264033209893014, 51.30433905509211, 50.49825668334962, 48.168439403657, 51.08271729561591, 50.015287399292, 50.87461594612368, 51.15968988787744, 56.4972355288844, 57.04508866033247, 57.78367880851992, 59.39695750513385, 53.106585779497706, 24.474193511470673, 2.740316117002118, 0.6661217239114546, 1.5160187478027038, 1.7201229569412049, 3.998856635824327, 4.803361479313144, 0.6332943660597647, 0.26369172298619825, 0.09838357763064486, 0.09892130240557656, 3.438794391770517, 27.978388032605572, 51.55992069552022, 31.77710548523934, 25.55973691325034, 45.81697456298336, 3.402813264439183, 0.06258935277019778, 0.025580901532403888, 0.027604022912020167, 0.029873537320283153, 0.040444045312582486, 0.0360800139605999, 0.019191519484945366, 0.008149833902866851, 0.04383697212042828, 0.03042563198945455, 0.05438331386915619, 0.0108709073467781, 0.02316182569390343, 0.04362427546913105, 0.027507076400422284, 0.031028458916191614, 0.08176502381120959, 0.02950497625035144, 0.0978896041370688, 0.08824897749770073, 0.04836932448069415, 0.052320189293353796, 0.026934548251090512, 0.03078912155732753, 0.027224240569217552, 0.12813989583763385, 0.11161123477523366, 0.1945851376700786, 0.1637742611309213, 0.19386745118085416, 0.14131754276252564, 0.11734559441045408, 0.12820178042015723, 0.12979328211757446, 0.0548902380790922, 0.09055998131272294, 0.08859703422433908, 0.19469683328943868, 0.12223140441722448, 0.09378084477277533, 0.1417692435244399, 0.08484350983053447, 0.1973334780984348, 0.09231474400768358, 0.1740755849788266, 0.11031699051419575, 0.07784139725469774, 0.17639701525049825, 0.3072550982957886, 0.148357538386218, 0.1674314729508854, 0.13785621962480007, 0.1072537573054433, 0.18687829315181703, 0.10759737072212082, 0.11581987668309482, 0.16871709106189592, 0.2881044630081423, 13.381159959300874, 66.22863984877064, 49.947281345244384, 53.014488527851725, 64.35944218789378, 47.84354948228406, 7.0690612446877275, 0.34740726793965987, 0.17502283737544092, 0.5095263961101733, 5.324305190194038, 12.525123261636304, 7.466602777281116, 6.836425469767663, 1.9357157883144196, 0.14002892158685193, 0.22101582989336985, 31.651136605970322, 78.41026644552909, 70.9676867146646, 73.03651732783165, 66.59274562712639, 68.4509998752225, 67.1941077324652, 66.79102928407731, 62.69108949169036, 61.077532306794204, 63.47898383294383, 56.5022365508541, 58.11002785159696, 65.56816370256486, 68.18333733466365, 68.64104655481154, 65.47064573534074, 63.28646213777604, 68.14001083374023, 63.749450868175884, 62.424219269906324, 61.24577060822518, 52.22306797581335, 53.33293007266138, 50.7379448798395, 50.43633422543926, 49.15531166138188, 52.28134655183362, 48.38625646406605, 50.85130922255978, 63.96188643670852, 65.33317450554141, 64.62342946760117, 60.699360909000525, 65.83502215723838, 62.62557806507234, 60.31858505741243, 55.029782710536836, 56.44051413382254, 57.52259408274005, 61.23535279304751, 66.56504584896949, 62.31922918750394, 63.87515106508809, 59.753418584023755, 54.353915183774895, 53.99699126520465, 48.05391011699554, 45.89652807481828, 47.26374864578248, 47.202088986673665, 46.130458231895204, 44.79215729621149, 50.90357872747606, 65.1165537680349, 63.523906738527366, 61.65769007898147, 61.78820302409511, 57.87507003353488, 48.74626336559173, 45.11277967883695, 57.48939121923139, 62.39969268921883, 61.421508481425626, 58.43995409627115, 57.491081760775664, 48.99644390229256, 45.18573576404203, 52.26607284238262, 51.061489428243334, 56.96069886607509, 54.93491234317903, 53.179204540867964, 49.586992033066295, 54.2460500040362, 52.72509997890842, 53.33262020541776, 55.532783539064475, 59.311120356282885, 57.59584826807822, 59.67534380574381, 58.79261047609391, 51.16958210545202, 23.003369415960005, 2.23988444093735, 0.5619847570215503, 4.007920742996277, 2.78543048327969, 4.822989509951684, 16.039655189360342, 10.272636490483439, 1.3789653730007911, 0.13044001354325202, 0.19970530163376563, 7.319613916258659, 39.44660217531266, 53.95841083218975, 35.4100674967612, 40.71260206161007, 51.96286970569242, 2.956134974956513, 0.11098186290192028, 0.19316211402896913, 0.17659668840708273, 0.20139872366862915, 0.11517108448090092, 0.24387733379919685, 0.1681264832375511, 0.14419224173311265, 0.118392821281187, 0.1934887126328484, 0.09502172334900788, 0.12678016638082842, 0.2872696416752954, 0.10480471976822424, 0.12773203828762617, 0.16016960294256288, 0.15966134957007824, 0.10710754176421512, 0.22257635099512918, 0.2421124204392395, 0.12963765901663613, 0.13560343083114396, 0.18413738377632635, 0.1299905344363182, 0.14478047468489216], [0.023198105702777545, 0.021649912870939703, 0.025535891951632597, 0.02855644640212338, 0.03200866650008867, 0.03559147586084662, 0.06836872007096968, 0.012947464316722848, 0.04033973095037284, 0.04828508162210065, 0.05318411813688375, 0.036674911877320665, 0.03350177952539056, 0.024514150910920674, 0.03963122985536053, 0.04270877358653853, 0.023894311086605155, 0.031571632491484765, 0.03135204104886901, 0.037212456621590166, 0.03103765197128298, 0.05994434994194777, 0.01093681772134357, 0.014979547009833399, 0.03950987386727526, 0.04513452588129909, 0.026736545166180983, 0.06503144955082286, 0.08858084678649904, 0.03980682486848485, 0.09125173572571048, 0.05336199226158281, 0.1205138965780216, 0.05242574471800078, 16.71043638260134, 49.61362100416615, 40.580626072422156, 42.251375336800855, 49.478248242409, 41.88407674912484, 7.183078171745424, 0.2670635823761263, 0.028164693935503884, 0.21020609945539506, 0.9130033021492343, 12.256338923208176, 12.260532917514926, 1.8778445259217296, 0.5463778912540406, 0.03381335514507467, 0.6623436234170391, 26.897445571038034, 71.8722794132848, 67.02436324088805, 69.4966253157585, 65.171345356972, 65.31756347225559, 66.0103521039409, 62.983125640499985, 62.68188761126611, 60.00970625108289, 52.85402828647245, 54.036309103811945, 61.89831964431271, 61.29139169569939, 62.56317707800097, 61.479594861307454, 62.651971693961855, 61.530683732801876, 58.38590383529664, 55.063440568985484, 47.163720361648075, 47.59942900749945, 45.644994320407996, 45.8266745844195, 45.018764388176706, 45.189520851258315, 44.87128326969762, 47.61798574078468, 46.55480769372756, 53.58913536994688, 61.31462389423002, 60.984964370727546, 61.27989130635416, 62.25612609617172, 62.970311257147024, 56.876297304707194, 55.94052568558724, 56.974227120799405, 55.276578241778964, 56.56616333992251, 60.357365531306115, 58.17922630617696, 58.46425710185882, 54.45027212942801, 53.61181451428322, 50.43037614514751, 45.09386600986604, 43.964090039653165, 42.089389293424546, 43.06347854675786, 42.05887325348393, 44.637404103432935, 55.73495034248599, 57.977467429253366, 60.59299407466766, 60.0861571681115, 58.271649114547245, 55.19744834592266, 42.98682758885045, 48.58512847654281, 57.2537273745383, 57.11166697163736, 57.849249070690526, 58.7759639370826, 55.07209723995578, 51.350089580782004, 44.91879101722471, 45.57421122827838, 48.810739286484264, 50.41776180267335, 48.32212178937851, 49.16289360292497, 49.11013380173714, 50.01151015681606, 50.34778671879923, 52.85643269938808, 53.9184340353935, 53.701660325450284, 57.508391180346095, 59.11022832316738, 53.17705900438371, 19.91839389647207, 1.0409192091995672, 0.05732530217257239, 1.4837827485415245, 1.9180022420421725, 1.4992506153160527, 1.8738275285690063, 4.610938823992207, 0.19707614916466898, 0.0731195530463611, 0.033354954944262584, 6.4771956878323715, 32.44098036519943, 40.80172223429526, 31.04047456095296, 24.089897332652924, 41.80735518855434, 8.687549829483032, 0.032380525578534415, 0.06363803903842646, 0.022865334345448404, 0.02873168901480254, 0.05307356015809121, 0.06593315035945947, 0.06973427179599963, 0.06905504292057407, 0.02541273565692527, 0.06277065896879762, 0.05143630002895671, 0.007975835704259695, 0.02940066763380122, 0.00901856899051176, 0.03552737345378246, 0.0699580537395612, 0.02085842721674952, 0.03787177870230329, 0.09133901612292375, 0.06602049970458593, 0.05720478122032458, 0.036609124076823076, 0.029080563540300055, 0.0235856446858135, 0.03992694745501203, 0.024049133625662616, 0.016547972223751487, 0.022046738754837744, 0.08718925573292279, 0.06882628906638392, 0.05679309706113512, 0.015278399824315022, 0.10839620124428503, 0.04444230415467774, 0.0068399399019507395, 0.018072157775262193, 0.06491015484977154, 0.023471468856798548, 0.012427206346464735, 0.02462983401792665, 0.08403900259685132, 0.03236422322750573, 0.03510137877216743, 0.004879213032132436, 0.034269683078051574, 0.004713116551659281, 0.016205726274018808, 0.009209134319286433, 0.025741950451065938, 0.013114036729318962, 0.04712961801898576, 0.02336374731854566, 0.020779887882752285, 0.036604278570702004, 0.04528672073877627, 0.03404803851979875, 0.021969921203450333, 0.0692500582625789, 0.07493810022189733, 0.05187562847089383, 26.102422321996382, 55.3034503998295, 44.482780348870065, 45.981627818076845, 61.651386830114554, 43.75402358270461, 5.675483326758108, 0.12111741298389052, 0.00673267801645242, 0.31812983895501784, 0.4374738043594745, 4.521254810594744, 9.296200679194543, 4.388971895940842, 1.2795907763704177, 0.24353749719598602, 1.7780286626469706, 36.63271734791417, 71.67833389774447, 68.03376167051255, 69.49010633653211, 68.62425881047403, 68.30224006406723, 67.40287196251654, 65.02921435140794, 64.41614397110479, 60.803264494865175, 55.03724698097476, 55.79135402556389, 64.68151976985317, 62.83740958859844, 65.68723509388586, 60.946136828391786, 64.18302182228335, 64.68644234441942, 60.97318549310008, 58.24695387194234, 50.92555968992172, 49.27621087720318, 45.91313539012786, 47.93952595803046, 48.185937096995694, 47.787083041283395, 47.43210069594845, 48.83338705185921, 47.76032855433803, 57.83228089732509, 63.89804201741373, 61.18322449345743, 64.32162661706248, 60.51186769239364, 63.57627430269795, 58.16463116676577, 59.08601945446384, 58.38056941186228, 56.592988429530976, 58.10238707450129, 61.746535685754594, 59.47040388661047, 60.61379048132128, 56.78774979806716, 54.690085841763405, 52.943391646108324, 46.64599103312339, 44.401230350617446, 43.04997382625457, 46.089932303274836, 43.73479612411992, 45.800637891215665, 56.461808681488044, 60.446579840875444, 61.28047573950983, 60.30636295195549, 60.1732926214895, 56.8431415096406, 44.83687231617589, 48.723223363199544, 57.463840899928925, 60.48125751556889, 59.0696749379558, 60.0811130000699, 57.22438020090903, 52.957582781391764, 45.4437453516068, 48.43662754181893, 51.31876161021572, 53.4206852605266, 51.838848283213956, 51.22856278573313, 51.04241886446553, 52.079901464523815, 52.05879519062658, 55.4918614510567, 55.45557952696278, 56.24894557460662, 57.85981201356458, 60.28073418524958, 53.15862386457382, 24.104231634447654, 1.6186989218957963, 0.38234939618456754, 1.9939300129490516, 3.309272335421655, 3.8899402608794555, 4.808518415497196, 0.6760502234101297, 0.13526757788513938, 0.2312589463807883, 0.03708445099032214, 4.693105614954426, 33.88350455991684, 46.641464617944536, 39.563767294729914, 22.579824040012976, 46.78410160926081, 14.578688990685249, 0.050268088722781795, 0.03256025746644985, 0.06314988781307494, 0.02062609573195298, 0.04137881430647066, 0.034431802604587815, 0.05498868420780186, 0.04402011693004639, 0.05820015542990258, 0.05456814024176809, 0.015034507115131185, 0.10434957161065071, 0.10841015936626543, 0.020873551707594626, 0.0880941434673244, 0.05044698557485977, 0.056259823257043484, 0.037383501072444265, 0.042270349128352064, 0.0686466874134156, 0.03748855087906122, 0.06320518786988913, 0.023519253591075543, 0.02618734056370393, 0.029498703905471393, 0.03525704017750198, 0.06809988449658118, 0.0955627269802555, 0.15624825932806538, 0.18808290512571413, 0.27443319499011964, 0.1013283659854243, 0.14528612335843427, 0.13824543825561, 0.13800540758717444, 0.1464137281741827, 0.10886156135388922, 0.13124003916257812, 0.09658126385822412, 0.12757690548295939, 0.1942608066864552, 0.15439333063700508, 0.2023138769812161, 0.13626199065437242, 0.19144151119455216, 0.1342946462213032, 0.14438808445007573, 0.09829511745802819, 0.11403956495585943, 0.11910873044642711, 0.12506956865470256, 0.11851139637010714, 0.19446218055823158, 0.21995954786337193, 0.18675581101448308, 0.1439841569311196, 0.23444047888680813, 0.22923201562896853, 0.18232367061559232, 0.17362396082570478, 26.417765194369903, 67.1973083865258, 54.946169545573575, 55.177561929149014, 61.76127987523233, 57.53370223506805, 11.953349555692366, 0.457121477492394, 0.13389274117446717, 1.0452850523494905, 4.034768386233238, 25.401894853961085, 24.763115298363473, 6.887795771321943, 1.8848840772144257, 0.1726331180261989, 1.1955118299491945, 31.036026593177553, 75.70695323328819, 71.72218599627095, 75.24848307332685, 71.49634376648935, 72.38028910852248, 71.81000786442911, 67.58366969323927, 68.6381047771823, 65.0582948038655, 59.36803786985336, 58.43060316578035, 67.66054814861667, 64.9637617603425, 66.72911074853712, 63.22681073219546, 66.52675567134735, 67.38585672070904, 62.825615021490286, 59.00880367525163, 51.95608008292414, 52.90432483919206, 49.229483681340376, 49.14623921917331, 50.95304373771914, 48.43211681612077, 50.07790019435268, 50.63757927187028, 51.474048245337706, 58.82447973374398, 67.18703962141468, 64.61265863910799, 66.2246939443773, 66.01179553616431, 65.10869726057976, 60.250645683657744, 62.42236791118499, 61.76260955872075, 56.15411835332071, 58.20766741229642, 64.2198960242733, 62.07417518861833, 63.234882970010084, 58.69200952591435, 58.41492152983143, 55.19396920357981, 48.620017959225564, 46.92502452481178, 45.51032758528187, 48.16133599127493, 45.32903171354725, 50.95150224624142, 60.93230262879403, 64.05126156345491, 64.83636317714569, 62.80602670484974, 63.702421649809814, 58.8298886822116, 48.631228093178045, 51.54310157222133, 60.26883371414677, 62.99661859389275, 59.535738806570734, 60.887183604701875, 60.42346139107982, 56.368511184569336, 49.610012423607614, 51.14316494234147, 53.64675498777821, 54.940819432658536, 53.23907952154837, 53.74528884887696, 54.12105191138483, 53.20771624965053, 54.00493798717376, 57.77544575352823, 58.859302536133804, 57.637911765806145, 61.57133909963793, 60.755984244808076, 55.91473217933409, 23.042914752037298, 2.092100319362456, 0.2334665359869119, 4.084903876627646, 6.710193791697103, 5.380293592329949, 10.109458046574748, 15.529886311100377, 0.873538006938273, 0.2309917961998332, 0.10654330268622407, 9.556260685766897, 45.227783572289255, 51.64777786500993, 42.7472060726535, 33.2968827216856, 57.70060693064044, 15.231945033996338, 0.16042281032329606, 0.12300361338401995, 0.14216961639542736, 0.27843330776499164, 0.11954122538407964, 0.2159510387648498, 0.14919364674677774, 0.32823334357911543, 0.23253475856636804, 0.20368872901364682, 0.09725136862647149, 0.15813709507065435, 0.24425427970145983, 0.06888422063521801, 0.14550979038880718, 0.13552095380521592, 0.14821815634927443, 0.13372513645839307, 0.23021479918351098, 0.17716967620916907, 0.16910364370672934, 0.149783764274851, 0.12126767346935889, 0.14643632776794896, 0.10117799058676728, 0.14465552574444204], [0.026430690308071436, 0.058955177214116826, 0.06128968460665596, 0.03941623110985083, 0.025322425381971464, 0.03822006908575854, 0.0431871610212951, 0.024610903985317678, 0.08618585675233796, 0.018808111631041093, 0.017701815550906524, 0.02358611582988693, 0.0329043765011574, 0.029901940030075853, 0.014037775972317305, 0.051815084542237946, 0.01637877021435528, 0.02906342040777447, 0.029199487199225736, 0.021367281968254718, 0.048581756831657504, 0.03310458208884924, 0.08401631107253414, 0.0665244629846946, 0.06707735630052705, 0.009538349113427103, 0.01372044224427232, 0.04406332428897581, 0.05091373230360689, 0.09592254315653155, 0.0213639322488058, 0.012375580638857379, 0.033107577492633176, 0.039531557985972014, 0.10866483763581324, 21.0053591574392, 46.88473786077192, 34.57294740984517, 36.88265469766433, 49.73041349841703, 45.810761528630415, 8.764929367649941, 0.2244428476138461, 0.34356696110579277, 0.4973020536764976, 3.823864748401027, 5.803971838566565, 4.835350859549738, 1.6833919214625515, 0.26095096682829244, 0.019971961981707045, 0.3412927524937738, 25.06257257153911, 62.721946777835974, 68.43469850478634, 66.6267918002221, 68.42063288534841, 66.99735379988148, 66.1246342812815, 65.51607070430633, 60.907395578199825, 51.07457837750835, 60.84098592881234, 64.71624843535885, 65.43807437342983, 61.434216960783935, 64.52564085683515, 65.25688048331969, 61.615567745700965, 58.251060593512754, 53.02079177671864, 48.55726395883868, 45.53203005944529, 47.044060614801225, 47.55724783866636, 52.28372350815804, 51.248398211694536, 48.135852352265395, 44.727649996357584, 45.06038073570498, 50.56231291063371, 54.196067240930375, 59.24660521168863, 61.69643132917343, 65.48467213107695, 60.482214573890936, 66.38223986471853, 56.05536483949231, 54.705237957739065, 44.19532552842171, 41.736375977916104, 66.6064582332488, 58.57286360956008, 61.64882552239203, 56.056561162394864, 55.639950536912494, 51.11011897363971, 46.18355927928802, 43.64274986328618, 44.829843428827104, 44.467553707861136, 43.785453534895375, 49.15346422503072, 57.967147673330004, 61.55237051748461, 59.35087357797931, 60.17736404172836, 59.08634893355831, 51.28602158638739, 47.05089730601157, 53.574328422546394, 57.194546653378396, 60.725068123109885, 60.59095051980788, 59.18782849465648, 59.41372955999067, 54.45789721704299, 50.65827369689942, 45.40760855520926, 48.06911322378343, 50.821667871167584, 51.66873116647044, 50.5551585074394, 51.279596744045136, 50.86749684426093, 55.73935124181933, 53.31835846747122, 55.87583011196506, 56.48454666137696, 58.475377021297334, 52.25308195237191, 19.008821748918105, 0.7972656803265695, 0.058443863320374684, 0.9336753574109847, 1.0170232108043087, 1.791024210472261, 1.8122219246241356, 5.398295310235793, 0.4897673644365803, 0.13851012163344892, 0.11675568372612039, 6.297925720291754, 38.10912493736514, 39.367103576660156, 34.32939567873555, 24.187519242686612, 41.46550101618613, 19.460972970531834, 0.13055990630340192, 0.04379224024652954, 0.07862979365933327, 0.027725821315881707, 0.015505686620130174, 0.026690849936717463, 0.06583620193264177, 0.13769840551239831, 0.016396235103809064, 0.040762757041281274, 0.05350886663842586, 0.02401003058278753, 0.05996704529670458, 0.03964072551518198, 0.05328540645179249, 0.030341312522068623, 0.03635940239614537, 0.022422031822404074, 0.01901618111127567, 0.11359491220284855, 0.029269492313746485, 0.05677539659964462, 0.031846600599707134, 0.041704007139008854, 0.06388951506045076, 0.0671521034992991, 0.015144319115807454, 0.02096055056749573, 0.059878554480570945, 0.06577892919942256, 0.012464043684303762, 0.033307924806591005, 0.06654498648018607, 0.11823051789354895, 0.07389115680369639, 0.0384536569547509, 0.04372918737992164, 0.05021293805311284, 0.016556998654719324, 0.054037723945634025, 0.025130876587823998, 0.02900635451829482, 0.0897381681528303, 0.024400065097236828, 0.02788547403930176, 0.0537297604305129, 0.02179840943896242, 0.008851238150870609, 0.050314234028900826, 0.04632961155185777, 0.0914972209401669, 0.0292967344003339, 0.04728843953700797, 0.00872534021900426, 0.012942410051642407, 0.039290370524770794, 0.09359926661296238, 0.08447091530768142, 0.002716288267214212, 0.02495851063530051, 0.03508303479682054, 0.7290771134918737, 31.219507225098152, 51.5864751415868, 38.82684807623587, 41.524807253191554, 66.89751378951534, 46.91442628060618, 7.855596484676485, 0.30486447496279595, 0.09218720569004936, 0.23374454929463326, 0.44476377447285964, 3.4983548473927284, 5.685378486110318, 2.724082652599581, 0.7985953638149846, 0.07150915962073111, 0.9416576258597836, 36.664037473740116, 65.77414304979386, 68.03510312111148, 67.64907129349248, 71.8941427046253, 67.82533476429602, 68.75589355345696, 65.70158704634636, 63.26678360662153, 53.30624226600894, 64.81263675997334, 67.79813704952117, 65.24701964470648, 61.44117132309945, 63.401160086354906, 67.0598763804282, 65.07025018815072, 60.82587695890858, 57.09493414048226, 51.31103454097625, 47.98571186680948, 49.87319953979985, 49.670679723062825, 51.91545217267929, 52.72748477997319, 47.51910278874059, 47.14836820479363, 47.277304357098, 53.86789821809339, 57.74539647563812, 62.71678101631903, 64.7194020209774, 65.98315438916607, 62.68071874495476, 67.46634375664496, 58.137727629753854, 57.8320533998551, 50.145604225897024, 47.0591107491524, 65.88442048718854, 61.50600417967766, 63.199405131801484, 59.687707116526944, 57.809633131950136, 53.03403762079055, 47.93235194298529, 44.75326699595298, 46.080487235899895, 45.92715786349389, 45.53146523814048, 50.689056458011756, 59.124796005987356, 61.63932161946451, 62.301131371528875, 62.067279661855395, 61.08996229787027, 53.46671427449873, 48.798725066646455, 55.86088588160854, 58.80764099859423, 63.014579126911784, 60.90581878539055, 60.7947176502597, 61.973860571461344, 57.03643591173234, 51.0021988807186, 46.177436459449034, 51.079583321848226, 52.32077421680574, 53.57431665543587, 52.69965948597078, 53.4176101223115, 53.19270926137125, 56.69694692857804, 56.66308510688044, 55.92851538811961, 57.92552348106139, 57.689239901881066, 55.86746369638751, 23.163711986234112, 1.9959018619791156, 0.6796738192919762, 2.4837639351044936, 4.898837852862574, 5.2328203185912106, 5.1948306925835155, 2.503835929016913, 0.435183078891808, 0.10645765405628951, 0.20501223783339226, 4.949822781547423, 43.73450194635699, 47.161237501329, 38.916638974220525, 25.983631380142707, 41.721059122393214, 29.975807974415442, 0.12273494634897479, 0.007094359616824096, 0.024624055799757762, 0.129259824452381, 0.03901735594075534, 0.005676693324330113, 0.09492694295101589, 0.11905390153368635, 0.06476658997276137, 0.04605053338192163, 0.05149779007619908, 0.026643051795901793, 0.058938373075497735, 0.05409216598397302, 0.05846794146383482, 0.03151085107557235, 0.10065373363754443, 0.019945554930957097, 0.021104475505830302, 0.047826826977994175, 0.07086910848175326, 0.08216925010445618, 0.056242095982475634, 0.07082060745526707, 0.014219992857937132, 0.02539003455650903, 0.06388109575416293, 0.07245108770627169, 0.12494274279883794, 0.09846272983498151, 0.16316136014797997, 0.10381527124874054, 0.17129323024663234, 0.17734426764711259, 0.12412081472575666, 0.17599796005074056, 0.1434164398139523, 0.12229727265695411, 0.15269624670186352, 0.1455655615896948, 0.13990453955146576, 0.12981171419303264, 0.17609563626108632, 0.1737053040415049, 0.08396859145573071, 0.08375424771539627, 0.114783980252762, 0.24882816168810093, 0.10632070051806589, 0.15806240149803702, 0.15246263585023342, 0.14567764025301705, 0.0928748079064873, 0.13733698055148125, 0.19972597068596273, 0.18044280218741587, 0.3666743792353138, 0.1940977065673759, 0.14410300781169247, 0.12242136357892906, 0.1104954200526399, 0.7001702872014816, 35.22177411663917, 64.6850852043398, 49.45989155000257, 50.662266669734834, 63.99292807425223, 57.55883286076208, 15.274777316278028, 0.5810276190600088, 0.5574396492973451, 0.845135756798329, 9.89642039422066, 22.49723461366469, 11.630807172867561, 6.046742527715622, 0.675996474681362, 0.08274890287148376, 0.9768824099052338, 31.214443445205692, 66.89048490216656, 70.81840130590624, 69.04552136698078, 74.46522497361707, 70.71992628036007, 70.8902826616841, 69.57070319883286, 66.95361152771981, 55.6980957523469, 68.1184377977925, 68.82408003653251, 68.87743211561634, 63.11963196723693, 66.53832666335568, 69.20436951421922, 66.51845593606272, 62.47484137935024, 57.70303095540693, 52.47841035166095, 49.7103976434277, 52.56018784738357, 53.03473580268122, 56.84405149952058, 57.76959749960131, 51.32481774976177, 48.24874601056499, 49.099982707731186, 55.02839419149584, 58.20181131362916, 63.86919690716652, 66.50874414751607, 68.78093396463703, 64.44831132888794, 69.68402047311106, 60.03227164668422, 59.48028433707453, 50.43617340826219, 47.8854678523156, 68.00217874588506, 64.55965565096948, 66.4233619936051, 62.751450846272135, 59.62148181853756, 55.19334554672242, 50.435702723841516, 47.758689003606, 49.69154673237955, 48.27565739231725, 47.51212096983387, 53.867117666429095, 60.360526961665, 66.35641497950401, 62.60812351780554, 62.41989289560626, 62.40514086138818, 56.53379201889039, 52.79113308075936, 59.01976277751308, 61.52267425291, 66.1280781222928, 63.471390124290224, 60.96347370455342, 64.3628821065349, 59.392701733496885, 54.85783384692285, 50.07073794641803, 52.98422744197231, 54.67084269369803, 55.59940107407109, 54.47694424659976, 54.9338964493044, 55.11336449653872, 58.74797782590313, 59.83393307655089, 58.39934579787716, 58.67514725654357, 59.983096891833895, 55.074372214655725, 20.905026889616444, 1.5970152015647583, 0.5513658590855137, 3.42684121381852, 4.2794740296179254, 2.8376453201616965, 7.31042968650018, 13.646390630352883, 1.6769893876006527, 0.35968048678290465, 0.2995063947333444, 10.082701598444293, 50.610150137255275, 52.73480392271473, 45.44001517757293, 33.83438471824893, 53.93204465989144, 30.98140758852805, 0.2087717990000402, 0.11662033897253776, 0.07099286998592078, 0.1774328427329179, 0.11260075224263054, 0.17190672877815463, 0.13159873685048473, 0.20382032759727972, 0.1650759824101002, 0.0982977528004877, 0.2899792333764415, 0.09058350021199835, 0.1745409680710685, 0.09077385773942356, 0.0927113324043251, 0.0777578094012795, 0.23372568820993747, 0.13124747021544364, 0.1258124900801528, 0.1758275667746221, 0.1100510124477648, 0.13423620903443906, 0.12869376208513014, 0.14331193009932197, 0.13134519239106487, 0.20681340247392657, 0.15472130819914803], [0.03647065368450938, 0.05377320144625922, 0.018218323520775286, 0.02856319563673629, 0.025061271754243684, 0.0681127547737091, 0.01201120145138233, 0.0032416313854722128, 0.05919401278539051, 0.017378505379442247, 0.02090611619003598, 0.02273771558858214, 0.02328533438905593, 0.05757419264785225, 0.020841780126154907, 0.025560682556862314, 0.019076336250309984, 0.0730384779613345, 0.05388986131536865, 0.022584601425595825, 0.06915811238990677, 0.020449251995512077, 0.029953840571726044, 0.07541956349966988, 0.028217266719307632, 0.016371706883693417, 0.02685434267585797, 0.09203051772689627, 0.05247455984053593, 0.04933082994313971, 0.030756329163728707, 0.03845826880405507, 0.02018273958275395, 0.04429282124845251, 0.030678350989136006, 1.2726427879064315, 22.26413207669412, 48.61654666162307, 35.46907563363352, 31.63458420384315, 49.72909165966896, 46.579726511432284, 10.310171611847418, 1.219637716008771, 0.057981724610492114, 0.17999332308048205, 3.0924667562207873, 3.9829543665532148, 0.6789402747827192, 1.3078925157746961, 0.15680822363543898, 0.022899260549175165, 0.16961995632417742, 15.70350806559286, 59.806170540471236, 67.25939950635357, 66.87009642201086, 64.78329743108442, 67.553388995509, 67.09645640465521, 62.58862149330878, 53.60922182759931, 65.04774755047214, 65.00758247990763, 62.86283439205539, 62.51049180184642, 66.28077599310106, 63.40002652137511, 62.66910068450436, 56.05233284734911, 48.189271111642164, 45.74617970374323, 49.55215354119578, 53.686123817197746, 59.61362138871224, 60.03382490527246, 57.741462338355284, 55.34983634948731, 51.58034839937764, 48.218112299519206, 48.096848303271884, 48.44318966711722, 57.795406695335146, 59.53070248326948, 63.70601061851748, 63.40091689940422, 65.11917783368018, 64.25752332133632, 59.74475799068328, 42.196568058383086, 39.913375992928785, 66.57420066095167, 58.646917958413404, 60.473671651655636, 55.895551789191465, 55.88808751875355, 48.992548988711455, 45.860199082282286, 43.8397156038592, 43.78993288163216, 45.96983717333886, 49.82407969813193, 54.08453464508057, 62.34135527764598, 62.508577685202326, 62.779727212844364, 61.29636526107789, 60.98782377858316, 50.96272806967459, 45.50778981178038, 54.50003916217435, 59.65282155621437, 59.27530911660964, 60.740969411788456, 60.22908441482052, 61.65973755621142, 57.49939718554097, 55.14962288641161, 49.2713902842614, 48.15693116957142, 50.33742381680397, 53.26059764431369, 51.30005974923411, 54.29170247047178, 52.81551845612065, 55.68433215541225, 60.611484127659956, 57.26429031741235, 57.354802931508715, 53.50769519805909, 17.749689932792418, 0.60429671238507, 0.26668176415466494, 1.2963710436897895, 1.2575607842976049, 4.049240706428405, 4.071851209286721, 6.922571995565969, 0.8151075003608581, 0.21690691731149153, 0.12593454320824918, 5.647265795738467, 39.48233496758246, 34.63679182913996, 45.542341970628314, 36.90668313733993, 34.90695291949857, 26.826119230639552, 0.2732453603417643, 0.18090927312451024, 0.0396302224497401, 0.024395849698433475, 0.13507446244118676, 0.10579733989171444, 0.0492029162424226, 0.12044321730612748, 0.06325933113393765, 0.048244969258385326, 0.041769005868944435, 0.022648299721279935, 0.09403697094850003, 0.03936307609922463, 0.03815050064135463, 0.09354699643388872, 0.021667860395785783, 0.08927225645992065, 0.0678787302345999, 0.02920174524338255, 0.02343411057917101, 0.02442107505856022, 0.01732134755941168, 0.034488577380656235, 0.028513336719404307, 0.014255297062317691, 0.026580676917106878, 0.024140767317505616, 0.02068446397090391, 0.11249556070974759, 0.019558274502595587, 0.0015226358992813697, 0.01104167409075965, 0.058065450359736724, 0.023635354216000246, 0.04421767185352022, 0.05682167214071078, 0.0599527845699941, 0.005120432094460534, 0.049570523532888586, 0.02360397333940191, 0.031105985098908988, 0.0288754511594532, 0.011227989546774376, 0.031245338407555417, 0.08287680125044239, 0.09360426150622869, 0.04489595077991967, 0.02361455109841641, 0.04844804001491397, 0.02610812515711352, 0.06059113882421967, 0.04287463545258488, 0.011884496254365773, 0.03771666121939498, 0.038121465909024405, 0.07069744349968049, 0.023896438895814845, 0.01479404360701841, 0.05833912760980668, 0.0328776553543585, 0.0941289398038099, 0.03928110852176624, 3.0557092447434706, 35.70024051973897, 53.60198113226122, 36.05912562339537, 36.634352976276034, 62.84577208180582, 52.29812252906061, 9.58367903386393, 0.7928717677151004, 0.03329262603074312, 0.06799855404683659, 0.5816922769431145, 2.261260622932065, 4.566077695738885, 4.586761824546322, 0.6518789236584018, 0.030056425490446632, 0.6777880785446013, 23.915948060251054, 64.91953311427947, 67.8019025248866, 68.16732621962025, 68.64634959928452, 67.95647528863722, 67.85709027321109, 65.53558057354343, 56.173902788469874, 67.02921913516137, 66.76990339832922, 64.49466197721421, 63.389216469180205, 66.9243271120133, 67.49269423946258, 64.85050332161688, 59.28055332553003, 52.14382040885187, 48.18363858807472, 50.360271623057706, 55.25779008865357, 61.233866214752204, 63.50709153759865, 57.48970108647501, 55.33951659356394, 50.99716647978752, 49.844432876956084, 49.33847458131852, 53.28320618598692, 58.56733698998728, 63.34527807850992, 66.88435031521705, 63.092610759119836, 64.75495046184909, 63.511308085533884, 61.358122979441, 46.91046860910232, 41.45510281285932, 67.67888915154242, 58.87693751242853, 62.80816047422348, 58.009968188501176, 58.87576864611719, 52.300581855158654, 48.39239497338572, 45.502831935882575, 45.591854049313454, 47.513972328555205, 48.94742211987896, 54.960678392840975, 64.31941832265547, 62.898355376335886, 63.29789192445817, 60.666161967862045, 64.09308187423214, 54.344273997891335, 48.327075742906146, 56.80387073947538, 60.254693569675574, 60.382319650342396, 60.162643386471665, 62.24210754517586, 61.76768118335355, 59.373360526177194, 56.40250244448262, 49.47053686265023, 50.13245251870925, 53.50243529965801, 55.45383014986592, 53.63192450615668, 55.33064811460434, 54.778954982757575, 57.85538365764003, 60.849630832672126, 58.812041897927564, 57.44826909034484, 56.66465013257919, 23.049780861023937, 2.346448374371375, 0.4311377669294035, 2.2444885680752416, 5.348791566587264, 8.33505524742988, 7.919371281900714, 1.0154510145225832, 0.27537949743770784, 0.10762858880503524, 0.039344866189264485, 3.554259408866206, 39.984845499838556, 49.211833015564956, 45.999313785183816, 39.39557213937083, 35.473633427773755, 37.23926482662078, 1.052208648573968, 0.024225787755342263, 0.12471866208098589, 0.018014998040011814, 0.06981804351051969, 0.0723444942324873, 0.015373791177426616, 0.08712530271300385, 0.0038401148330810815, 0.03262920154919548, 0.025819453651145585, 0.019134480408543063, 0.04439032508901531, 0.05185930696766704, 0.0032122332401829023, 0.06972266556394678, 0.04647902167973019, 0.07872592237207197, 0.04096420369141045, 0.058330880673301805, 0.02226017659620172, 0.034682206103518125, 0.011701689481044249, 0.08166484249335143, 0.00887772276802289, 0.026828900895892616, 0.020486564307864157, 0.031128755147238413, 0.08792681454290306, 0.2259698753515559, 0.10884259301688402, 0.09181597480370153, 0.13994843638952703, 0.2418871139807086, 0.09938676976749014, 0.1485690246185949, 0.13799575487932852, 0.14222607707544682, 0.08164551409502184, 0.12955648434017936, 0.15982605847379855, 0.12496208651892601, 0.08271904842507455, 0.08443593573305877, 0.08112349412253789, 0.1676680255801447, 0.17855997257415326, 0.12113542371099034, 0.16327466455198106, 0.1376120520815734, 0.12769214042852964, 0.251809316236646, 0.19967392267238712, 0.09555996140284885, 0.16530606925727862, 0.17018031899727162, 0.30651968453199635, 0.14919629741099574, 0.08384148214733408, 0.19663803880253147, 0.11621250440516781, 0.13522916623661596, 0.1107810942396041, 2.2053192892382225, 36.048664662145804, 65.00845324608588, 48.03901687745125, 44.501109584685295, 60.88449285876367, 59.56437995356899, 15.900783673409494, 1.696199930963978, 0.1364511224411188, 0.4894605615446645, 5.803440357408216, 11.932941463685806, 6.787371327800136, 5.101343941303992, 0.42159243396693663, 0.1496308378034061, 0.8604957583931185, 19.733405113220215, 65.35273536559075, 69.6658520544729, 69.02363454141926, 70.35288656911543, 71.69512948682232, 73.04869236484652, 66.98243310374599, 61.40509728462466, 69.95459341233777, 68.27466580175584, 65.64756031959288, 63.34540751672561, 68.8217423039098, 68.36041665846302, 68.29587797964773, 61.00642365794028, 54.39783004022414, 49.898612576146284, 54.56117714605024, 58.96609690881545, 64.40169003701979, 65.75981463155439, 60.441527828093506, 59.13544524100519, 54.81114587476177, 53.8930445332681, 52.24200125663511, 53.655090024394376, 62.27227449417115, 66.14455992175688, 71.2484029031569, 66.9503402709961, 67.0065870592671, 65.54735160643055, 62.4061724447435, 49.696743872857866, 46.10126795307283, 67.06241023155951, 62.339586288698264, 64.17429454864995, 60.88772096941548, 61.59081758991365, 54.49674437122961, 49.06545800547446, 47.98101286734305, 47.78241542077834, 51.89681699199062, 53.58408335716494, 57.83542271583312, 67.96137040661228, 68.47585985737463, 66.59125512646091, 63.89421770649572, 65.81519065364715, 54.59807880463139, 50.38925009389078, 59.01530304262715, 62.62523289649718, 61.917131331659135, 61.14047065857918, 61.9431641024928, 66.72336055386451, 61.95153444044052, 59.38418626785279, 51.40673645081059, 52.327014707749896, 55.50489548713931, 56.90692709338281, 56.17089825291788, 58.93220763052664, 56.21563288473315, 60.47451888361285, 63.16954412767964, 60.0218891328381, 60.17104902575093, 56.040248024848204, 20.71582155842935, 1.8545251772288356, 0.5584066974059229, 2.639121663185858, 5.561156042160527, 9.580522506467759, 10.692931202150161, 15.673379359706757, 2.5176912113543484, 0.5025847814977169, 0.16808070182319612, 8.766000174706983, 52.62062372699861, 47.10571635153986, 55.48615048008581, 45.69171759390062, 46.529398579751295, 41.29228914937666, 0.8336353674530984, 0.2694602424819624, 0.18424707224532483, 0.1513324876225764, 0.19968397374595367, 0.2693066878184196, 0.11806557916345135, 0.21453959837315545, 0.11755103620910838, 0.1150984516847999, 0.10834057560010303, 0.12273332224257531, 0.24885762542966874, 0.16187584928927884, 0.17097505860992018, 0.21054861736634087, 0.1445481508609749, 0.15841500112606635, 0.14341087801562202, 0.13620603559238298, 0.11550992516981018, 0.18878815034704824, 0.14044337515388766, 0.13580125005495164, 0.1114335023768006, 0.1571375035470532, 0.17848055989992234, 0.0705580078365822], [0.06724465458143143, 0.05259960454197661, 0.02911362214945257, 0.031021263435362812, 0.07740246717848125, 0.10085898391421765, 0.013873023976151262, 0.0173299775398787, 0.06957002254503389, 0.061113396283960154, 0.04922112998282237, 0.029788273649530548, 0.023940408512228922, 0.06228691657945033, 0.00899186603830106, 0.021645214836744052, 0.03961363664617942, 0.010458206205869154, 0.06059297743523794, 0.04190451533143078, 0.01085906841551825, 0.026538568894348802, 0.02380601945333183, 0.03473387873401085, 0.01377287234420017, 0.011896093867929473, 0.01925987942564872, 0.03428299385573595, 0.013165234385298626, 0.009921676528099324, 0.025874719234003175, 0.012103766897663236, 0.030174514113534844, 0.015070618584661957, 0.0482741725300589, 0.007582046401371519, 0.05308103334579257, 19.419560586252523, 51.52672567675191, 36.67931118319112, 37.77890451492802, 49.72094097445088, 51.80167990346109, 17.448679401028542, 0.7521013651163347, 0.08304373180914311, 0.25898343853412137, 1.745189231249594, 3.7787797998997474, 2.572380573518815, 1.3796392852260222, 0.06270390972795506, 0.01107079692320117, 0.3088120647495793, 14.881117459266418, 51.13337470639137, 64.98418161945959, 65.69113785220732, 66.66291682950913, 67.66876943649785, 61.67176746552991, 59.613966557287405, 65.40157279660626, 67.29507738544096, 63.373013157998365, 62.54390647334438, 66.91776890908518, 62.8223829884683, 62.43951651357836, 51.80382936231552, 51.35956602711832, 54.237730656900716, 61.421688910453554, 62.5881508088881, 61.34607345827165, 64.15622418926608, 60.77532545212777, 61.06717724953929, 57.85294394339285, 50.57790040969849, 48.81818002270114, 46.77922610313662, 53.847419523423724, 57.55372201242755, 60.6145671106154, 62.90956551028837, 63.91303331621232, 58.32000801640173, 61.65719193796958, 46.611281979468565, 45.21374540944254, 70.48262288493495, 60.29538423784318, 63.39459011631628, 58.180336336935724, 56.02506452991117, 48.0507839879682, 46.60387262221306, 44.881132341200306, 45.733941908805605, 48.131518133224986, 52.81086260272611, 57.37348125826929, 63.11932209999331, 60.48970630092006, 62.15616449233025, 62.548444655633745, 59.43711473095802, 52.687998279448486, 51.9580687246015, 56.26094802733391, 59.56368961641866, 61.18093775164697, 64.18843861549132, 60.55699063885597, 60.29923208298222, 61.40486978715467, 57.85785475084859, 52.86736042268815, 50.33095582838982, 51.97676274084276, 53.028428631444136, 53.56485589858025, 53.2922197926429, 56.771479806592396, 58.75280626358525, 56.13017620578889, 61.0446471552695, 50.438640579100586, 10.80602195955092, 0.6050011455532044, 0.5640748287400892, 0.21319123766114637, 2.4585408885632796, 4.365743619780387, 11.212216731040709, 16.40488374617792, 1.3215248358826484, 0.08756093095026671, 0.10208506167175309, 6.908771136114675, 40.84665690698932, 42.716654731381325, 28.50662539082189, 49.85260317402501, 37.96200467694191, 31.501127519915183, 2.1095651628509646, 0.05898488993426004, 0.008132644805065807, 0.026700569677256772, 0.08284141564921987, 0.02536986346146272, 0.023716751057955048, 0.018657967973981174, 0.04103647642618707, 0.05337306223208866, 0.051454241808143356, 0.03986309019608363, 0.030696721777560252, 0.06793855404060695, 0.119226225351374, 0.026704978513261004, 0.049757422173335675, 0.015906994118385257, 0.09482746643404807, 0.04979906288245994, 0.03340919396930164, 0.06400718233518063, 0.0830775928953963, 0.03102279178077175, 0.07636461722394151, 0.006587318099674679, 0.02459826736500667, 0.0197509762590691, 0.05627701427006433, 0.024488477389358228, 0.038499790769551075, 0.03821957495904738, 0.03323741024360061, 0.03740183738691192, 0.07137743080215109, 0.038697663619513475, 0.004454427811827872, 0.04860586178819499, 0.07729819495110743, 0.029137591125383496, 0.13525515193900756, 0.0320834098684211, 0.05053867480807728, 0.06849648821498118, 0.05940859784342109, 0.024777240825877078, 0.026415835863219637, 0.08052328721650186, 0.045515750384619164, 0.05237439767487588, 0.060457556072862885, 0.045119464592707735, 0.0843231369470877, 0.05877158807350263, 0.035875648515479225, 0.025042630919826128, 0.027822005569994934, 0.031170464804275867, 0.04554657010181297, 0.044463758446997216, 0.0719638174820331, 0.005310736474535999, 0.010331750945037892, 0.037944062928398775, 0.03732166628563597, 1.1963170190011303, 32.32762778958967, 55.59196426022438, 36.519447142078036, 39.13636230653332, 61.711250043684444, 54.17413334692679, 14.884415191988792, 0.6007086629829099, 0.10993279742016909, 0.07054191232929308, 0.17468716829053818, 1.7126990133716216, 4.906996873117262, 3.1265136647608975, 0.2081498888231093, 0.0972563252153416, 1.158247474701174, 22.19609268250004, 57.46335452602756, 65.48162837182322, 66.32552239202684, 68.78707639632687, 71.22222500462686, 62.43193849440544, 60.02353652831047, 67.80448344445998, 71.25165847039992, 66.8893317253359, 62.78579119713076, 68.23130792187106, 63.570888888451364, 64.6793036307058, 55.448633009387606, 53.94409810343097, 54.81661758115215, 62.46769482089628, 65.14148043047997, 64.85926981895201, 64.95296347525813, 63.11927110918107, 61.02287407844298, 61.08286673022855, 53.47385298821234, 49.384519284771336, 49.25964278559531, 56.16881547435638, 60.14452203627556, 63.34492114282424, 65.52488427008352, 67.90747704044466, 61.37349474814631, 60.74626068915091, 50.124121404463246, 45.73988429961666, 69.70368723715507, 62.54994300103957, 65.38400450060445, 61.77612996870472, 59.06085352743826, 51.212190812633885, 48.16522698248587, 46.941584771679295, 48.158868820436545, 50.01551489676199, 55.76827087709981, 59.04439133982505, 65.11842081623693, 61.27527075429117, 63.370389092353086, 62.685786447217396, 61.62730347725653, 54.54495814538772, 52.133673237216094, 57.873477551244925, 60.123105895134714, 63.6438371289161, 63.76586598734703, 60.49565261410129, 60.46402262103174, 64.33810057178621, 59.058421657931426, 55.44910761617846, 52.33396122532507, 53.5834793121584, 54.594348630597516, 56.110132894208355, 56.695425048951186, 59.21970951941706, 60.14465931923159, 59.225455791719504, 59.48989022162653, 54.46497709520402, 16.877466594019246, 1.454059517671985, 1.1528777499352734, 2.2020504839958686, 3.333295626986412, 6.113278673541162, 4.088636011846604, 2.2123143461442765, 0.5086687760006997, 0.06162770558148623, 0.09463889389148644, 5.586684788427045, 45.09837281319403, 56.88902931828653, 29.038849838318367, 54.381085441958525, 41.6600937228049, 39.309836972144346, 4.824149060633875, 0.09840921093259128, 0.03729140964306651, 0.08192345079395079, 0.09382319411322956, 0.03730931694829657, 0.04799685636234861, 0.058448536456712795, 0.00966129760678497, 0.03194681639152189, 0.04749500365447133, 0.010784653507383361, 0.03093699567891177, 0.07686007692809067, 0.12024492310780673, 0.011966330724047318, 0.043619510402242025, 0.08879636264135761, 0.054940750086379636, 0.07806298818679587, 0.06641581639527314, 0.019990970538328254, 0.06343046751534266, 0.033613904153988246, 0.04571549248911681, 0.011612254461543936, 0.09263165159932069, 0.048035697020109624, 0.04104337887838483, 0.15710908168506238, 0.19951232408563938, 0.18081296055066973, 0.0958890114880858, 0.199474954316693, 0.20541391305385098, 0.08547861970240071, 0.13051911978231323, 0.1509715376361724, 0.12301312053516028, 0.15192643559027105, 0.182981479672655, 0.18272186779687483, 0.1590945517584201, 0.2097722178985996, 0.14365201185066856, 0.0921456377592779, 0.194385081469532, 0.25500774864227543, 0.11957481833955935, 0.18797511655476787, 0.12445607778405952, 0.13636435532281477, 0.12109716528005178, 0.09896600363595832, 0.06806704230726728, 0.07643065400301449, 0.09306754796735703, 0.13572811930169984, 0.12637815408168301, 0.12318686161550785, 0.19521723681640243, 0.14291929471636974, 0.15331789640890015, 0.17586830733043535, 0.0991391012024495, 1.0380475439371601, 34.32018203120078, 67.70469834727626, 51.480822178625296, 49.08581902903896, 61.64475802452334, 63.464682871295565, 23.46899005674547, 1.2566240732708287, 0.4873726961593475, 0.7615851658967234, 5.95097589877344, 14.13615934310421, 10.058269154640938, 5.67789803589544, 0.09671277051130611, 0.21854986947390342, 0.959481611367195, 18.69874858087109, 55.76716476871122, 67.12541134126725, 69.64280420734038, 72.21252149151218, 74.44069447055941, 66.3988079563264, 63.56804909244661, 70.99099343822849, 73.99846292311146, 66.75120938208796, 64.81743774106427, 71.53992914384412, 65.8102955356721, 67.71016613129648, 56.86980970444218, 56.917297840118415, 58.791076829356534, 66.95976964889034, 67.86069885376962, 67.95863259223201, 69.24697429903092, 66.72791834800475, 66.12108061390539, 65.0734547645815, 55.65240798457977, 54.0368543132659, 50.31116354850031, 58.25509279004989, 62.27977798831079, 65.19672309198688, 68.12050880924349, 68.75449718967562, 61.73914201797978, 62.62091828930763, 54.847204223755874, 49.409391034033995, 72.30315962145406, 66.05094079048403, 68.7287115281628, 64.43893686417611, 61.44083399926463, 53.95944241554507, 51.50396808501213, 47.90785674125918, 50.19023295371763, 51.40472427491219, 59.36928126119799, 62.49977588653565, 67.48987013293852, 62.24304499164705, 62.822481047722604, 66.09771897715908, 63.597004029058645, 58.240164249174065, 56.642606412210775, 61.36270823017244, 62.638137494364095, 64.53518006109422, 68.47850353487077, 62.01055826679353, 60.3783227551368, 66.09796216410976, 62.484776742996715, 58.94594377087009, 54.88989530071136, 56.312158492303666, 56.58579480263495, 59.18808344871768, 57.857199715029815, 62.079937150401456, 62.42942817749516, 61.451549914575395, 62.04106253962364, 53.937543822873025, 13.476321562643975, 1.6294468290382818, 1.7654445959675698, 2.2628776200356024, 7.058050661317765, 14.461100255289386, 20.65053370691115, 24.88788197117467, 4.0769919656938125, 0.21132492490353125, 0.338295326237717, 9.899122907269387, 53.18288764645977, 55.27150269477598, 39.44367216479394, 56.019796786769746, 50.00495195388795, 45.804615174570394, 3.9351463125598047, 0.12582582001003528, 0.09299511435411631, 0.16205411794925892, 0.15359397917505235, 0.1189859342130442, 0.0937006047235862, 0.1505125283954605, 0.32036175951361656, 0.14422489240044548, 0.1368582368858399, 0.14829891733825207, 0.17313191787369792, 0.14523940731681165, 0.33583848226454954, 0.11466086226245088, 0.14825744133803154, 0.15879275908152904, 0.10495649710778268, 0.14934174686429963, 0.16904231070751147, 0.15581621638228818, 0.12881258232218604, 0.16010315247601078, 0.17912410439983492, 0.11282508576949758, 0.14754484167262433, 0.09244298712620813, 0.1841261529273564], [0.012282156216491376, 0.020879305027905973, 0.12670454584182272, 0.07982890512193404, 0.015069214728540711, 0.029219690853008823, 0.07829790138789723, 0.01213618869622869, 0.03319587678678575, 0.10347017162148991, 0.004945822940733765, 0.05597080509628981, 0.05798888753258413, 0.01571978521232884, 0.02856193733732066, 0.04307482188807861, 0.029575147988995718, 0.03982523013086569, 0.042414189797014966, 0.03650894275896492, 0.07116233629565086, 0.015749973864595018, 0.07570231889164256, 0.043183403360026504, 0.051795009208182176, 0.028510107658803466, 0.06673874543799509, 0.1205223082234302, 0.018257462952826774, 0.0181764644765926, 0.07508911913441074, 0.030434650759543144, 0.11741456530627706, 0.07559328925825896, 0.07408067163440489, 0.06823191975033091, 0.029658967584011056, 0.35638594098629495, 20.686109604374057, 48.988838426528446, 40.738297508608916, 32.45265530001733, 45.08323638669906, 56.44932377722956, 22.990566799717566, 0.9450571563455367, 0.03286943523093097, 0.05691873931115674, 1.1905106854054237, 5.152706888414198, 1.180798161414362, 0.27280069226699494, 0.025767560770374634, 0.03151922250136493, 0.6401630491018295, 15.341992032143379, 49.88196603713497, 67.06574424620598, 67.17448803686327, 66.26392549084079, 63.37051853056877, 66.73486878795009, 66.78610278714088, 67.38523698622181, 63.05377537204374, 67.69205262584072, 67.54650131348642, 64.85106422055152, 57.963546937511815, 54.873319364363155, 60.150484038937485, 64.70258289767851, 63.32481115095077, 62.43397420452487, 63.45672438221594, 65.75002047323412, 61.30055043005175, 58.56090038053451, 58.093420536287375, 54.842297338670306, 50.78239710100236, 46.87987019938808, 50.787574629629816, 57.29452002433039, 61.577720795908284, 62.127182099127005, 64.68408892231604, 65.40618942629906, 57.90117732940182, 49.88969702874461, 39.333139773338075, 69.27588216720089, 61.336663692228264, 60.2150462519738, 58.134644646798414, 60.085200109789454, 48.66003005735336, 50.109392904466205, 45.07877272944297, 48.517557805584325, 49.8220439880125, 55.44242389740483, 59.39247815839706, 63.41799882150466, 62.365552379239, 59.81511746683429, 60.23048862334221, 62.128092089006984, 55.35208386759604, 51.534590028947406, 54.82892205638271, 58.60467403165756, 62.234823703765876, 62.76789342203448, 61.967047414472034, 59.860797389861084, 60.41800537417012, 62.06443202111029, 57.77048003289008, 54.95577543012558, 54.36522337698168, 55.675624493629705, 56.77217014374272, 57.95659649756647, 57.57147858219763, 58.90115030350224, 56.608552394374726, 38.119330944553504, 9.549008223318285, 0.26881633025984614, 0.4565705377007685, 0.9266757652644189, 2.6954260612687757, 1.3255164604033194, 5.4087204798575375, 5.2439716169911055, 2.7002660209132783, 0.08300725070218887, 0.055606668184120814, 8.51588337652145, 41.13353906139251, 43.78460238056798, 22.003839669689057, 29.1231043108048, 35.339453066549, 23.46364582738569, 2.255403543672254, 0.10028181327206474, 0.057386581545635584, 0.08953798937821582, 0.009398167472212546, 0.0715270554346423, 0.02680724742071283, 0.02068044775496087, 0.03912622469567484, 0.07162676177798741, 0.03728724595519804, 0.02608659808644124, 0.07866034524575358, 0.10136551358887266, 0.008146677620618815, 0.08255549631411992, 0.097475495309599, 0.023332544557389714, 0.12010191747498129, 0.03939393412081465, 0.037279477823645844, 0.0031575379140239453, 0.04978970128802523, 0.03991137288751141, 0.027367173423690182, 0.08075094556496029, 0.009688929440603863, 0.05815978642673262, 0.04915350357130651, 0.0983022803801202, 0.006396529647792059, 0.010401030191250387, 0.07444102407222794, 0.0282921613900051, 0.025249143326354605, 0.02510477405702395, 0.021553008494177656, 0.07395202248928047, 0.06476939385456425, 0.0352749934480075, 0.025746194578166452, 0.06841080894152965, 0.050375770041418653, 0.026362745970067, 0.028322155647460493, 0.026795970606467417, 0.02952030183927667, 0.055749639342989654, 0.05324969909364178, 0.03804191533896712, 0.023170528452723257, 0.00956961124639718, 0.006738062656950206, 0.0567037137525697, 0.0759674389395983, 0.022361616213475505, 0.05002159993314455, 0.023307273231987512, 0.03797092580146367, 0.03044725673633718, 0.07324138400895942, 0.0455190866975294, 0.03606844603294327, 0.046330990510121475, 0.027979750734483524, 0.018958444894862272, 0.09413073244955271, 0.8738373940990818, 33.38646573405112, 54.882132930140344, 41.232873086006414, 35.607150908439394, 57.08896429308, 65.28976171247422, 17.6961221233491, 0.5355170321079993, 0.018829665514790726, 0.049519065407014666, 0.19897010237459214, 0.8134110139742975, 2.29847141331242, 2.3081733959336437, 1.1587885166368177, 0.42910895160129, 1.3790011646286136, 21.158235496090306, 55.27016516654722, 69.085019634616, 70.19728614437965, 69.00436001439249, 66.12216318807295, 68.7907712690292, 68.26028639270415, 67.51826024824574, 63.54932761961415, 66.76347855598696, 69.31816531765845, 64.74318727370232, 60.463532324760195, 54.582063767217825, 61.4440111191042, 66.75710862682712, 67.75443400106123, 64.221072735325, 64.57510586707824, 65.66099051506289, 64.65139988929995, 60.82478654000067, 60.65520678797076, 57.18991825657507, 53.023776700419766, 49.698316743296964, 52.28586512227213, 59.46020572416244, 62.886121503768436, 65.30763595334946, 63.53912161242578, 64.26494836807251, 59.58745133492255, 52.43959065406553, 41.74144368017874, 70.29353326366794, 64.0417576605274, 63.044365606000355, 61.091523401198856, 61.55162918952204, 50.79474472230481, 51.67904700002363, 47.332072411814046, 48.78772674068328, 50.84394301137617, 56.505417593063854, 60.40099797710296, 64.16974067687988, 65.50805730204429, 62.51477503007459, 61.46325818953976, 62.376597773644235, 56.97567447539299, 53.15534084073959, 56.14619124320246, 60.75194812590077, 61.35508706492763, 63.859222319818315, 63.20601432554184, 60.37860516578921, 62.767120715110536, 62.26336286913965, 58.15447615038965, 56.17367921337005, 55.85619080451227, 57.70661207937426, 56.76985202297088, 59.033659735033595, 58.35974554861746, 60.26359734996673, 60.16680502122449, 45.71504785168556, 14.960911216274386, 0.6110137100181272, 0.6956363950044878, 3.320687658363773, 4.819550081606835, 2.738777077005756, 3.728958344267261, 0.6240250698981747, 0.3859411534522811, 0.03654955691027065, 0.07460727281267605, 5.46061392753355, 42.18421259234029, 49.74039593050557, 28.151970563396333, 29.654354049313454, 42.460833826372706, 31.91800682775436, 6.3250312593675435, 0.05256741352739835, 0.015211438951683382, 0.04247398678994468, 0.058458120216645544, 0.07335759954707277, 0.02797525954402743, 0.04185087002453305, 0.018389634187183073, 0.05151824079333775, 0.04494926283857034, 0.02418481545793193, 0.0213103118397656, 0.07846506943385448, 0.032082187958181865, 0.07506761504637618, 0.0545291961621373, 0.049376059774189233, 0.031983895047057065, 0.029721315649728623, 0.03174626797948393, 0.062007248521812504, 0.05575601319451967, 0.024636627302595207, 0.06256169316569163, 0.03395692768296407, 0.06636696296834177, 0.05824173868243253, 0.02175194620635481, 0.10117346300713478, 0.09023196544618377, 0.11297385238351361, 0.21124932734716326, 0.1449796269016881, 0.1512854038587501, 0.22813366005016913, 0.1817520464500112, 0.2030567217978739, 0.2069098223000765, 0.14174149581982246, 0.07584084291011095, 0.1730750894714748, 0.21907382764883582, 0.18223707203663167, 0.1091841916223207, 0.09916411397317726, 0.11864912365713429, 0.11529673822224142, 0.17517527355061424, 0.14186914138976606, 0.13754878854078634, 0.14436715492798438, 0.16892073255392814, 0.25119829982999836, 0.07848524818978003, 0.1482836721885589, 0.18793799193395724, 0.17762594285511202, 0.1063587674270234, 0.12956169373806448, 0.10823601225931799, 0.14976654261831315, 0.2817539924815778, 0.26077586977231887, 0.18878479488193992, 0.21587337277108626, 0.16838246385657019, 0.96854982477042, 33.270685211304695, 68.23726992453298, 53.42434875426754, 46.7536130259114, 58.93312154277679, 69.23312833232265, 31.751253143433605, 2.005886132678678, 0.10567256715148689, 0.2545840560548729, 5.022242972927709, 13.651255349959097, 8.385463587699398, 3.1540813080726133, 1.1266661435365677, 0.2668940317967246, 1.4263224769984524, 18.618502770700765, 53.40718446239349, 69.78913214898878, 74.15313766848656, 72.72599112602973, 69.1779484287385, 72.46136449998426, 74.35658316458426, 71.76334734885924, 63.79595841130903, 70.12019588101295, 72.20046412560248, 68.6733433508104, 63.461741093666326, 60.52676093193793, 65.07892647097188, 69.80765358094247, 69.8382951367286, 66.2753160538212, 65.68912175393874, 68.68184704934397, 66.0795662480016, 63.37737091125981, 63.52514228513164, 62.66717087837958, 55.7469488728431, 52.863893047455825, 54.49358294087072, 63.7057242854949, 66.13691129992085, 68.07961417782691, 67.98215896852555, 69.08414886843774, 62.08404387197187, 58.05056079741448, 46.62397476934618, 70.42446198001986, 65.95522711353918, 64.90721294956823, 62.59810578438544, 65.62503414769327, 51.741204800144324, 54.29593470788772, 50.47720140026462, 53.2547454680166, 54.643033089176306, 60.01694694642098, 64.08266798142465, 68.1573163309405, 67.7629533890755, 62.5090915156949, 64.86609082068166, 65.2521461825217, 59.08451718668784, 55.77133424820439, 58.52085690344534, 62.33271821852654, 65.08373529680314, 64.39378646112257, 63.940034912478545, 61.48282689432944, 63.208991404502626, 64.88070164957355, 60.709237437094416, 60.31790256500245, 58.898381110160585, 60.61012698758034, 62.18466835637247, 62.80270445731379, 60.52835733659806, 61.33911125121578, 63.011327482038936, 43.03252712372811, 12.283119886152207, 0.537074948510816, 0.8170605342715018, 6.858050477120185, 7.149260476712258, 6.12698539610832, 14.685778521722364, 12.456508259619437, 7.28495438252726, 0.22410282714953347, 0.18564749629266802, 12.034394548785302, 52.91415037647371, 54.226340093920314, 31.940489853582076, 41.88001317362632, 48.4964083856152, 35.93020516057169, 4.71981450434654, 0.43238121956106157, 0.12204814086397811, 0.1651261305256236, 0.2012899391833813, 0.2302671536322563, 0.11917983106667958, 0.1605988573282957, 0.10391869311851841, 0.15649788141731294, 0.13928296645322155, 0.08896982793005244, 0.18421062178188757, 0.20053312092298464, 0.1617482190410937, 0.16446928673934552, 0.19050132212859971, 0.14549379447294822, 0.22212374624946427, 0.1632124275690125, 0.19611925938196723, 0.0751573009596717, 0.1574696792710212, 0.10813057557829928, 0.17921566722854493, 0.2779380778872198, 0.0992726150058931, 0.2141947975201953, 0.2394398614283531, 0.22406544205882858], [0.04229384887542936, 0.026761400888884262, 0.0710880334278749, 0.01721372752780876, 0.014021222727493414, 0.03616877290750704, 0.04021279018131956, 0.026887217423908656, 0.0065832477787719865, 0.004398740880611924, 0.08565616057885271, 0.013060093605740657, 0.12914296540041126, 0.08755372206289923, 0.07726216583602852, 0.036434084477443854, 0.04457953731499372, 0.04224175489657829, 0.08165741910136516, 0.02554256074701346, 0.060765469792268934, 0.08804515214456667, 0.012495572032827525, 0.05897689580677017, 0.0016992584278341385, 0.04698634425538683, 0.04432751354010356, 0.037796813168472825, 0.026823000103655844, 0.024937851159202478, 0.11589706770234531, 0.039577622852859, 0.04612862072404354, 0.04714625361826151, 0.007571873232542027, 0.08324757248403565, 0.022616141265438452, 0.020305888216582038, 0.0497179992887522, 20.353220009034683, 49.92387656242617, 40.76567957478185, 29.697849212154267, 37.08974407565209, 53.683099669794885, 30.667498342452514, 1.9824505837694293, 0.29031094944765495, 0.14656452492119806, 0.4171289912154598, 1.5606770159736758, 2.2611324104570576, 6.685433339688086, 0.4003694695570777, 0.05407383733038461, 1.4813680394041924, 21.342559437597952, 54.504259632479766, 70.01291121205976, 68.09961042096539, 67.25183717666134, 66.52773626389043, 71.84427369025447, 67.271041101025, 65.61414957046509, 68.45973891596641, 65.4043576794286, 62.72453946451988, 58.29674443890972, 64.9411375291886, 67.0560089234383, 67.50445350523918, 66.89104972347137, 68.95285929402998, 67.64391729908606, 64.34767507737683, 64.67561660274383, 60.773811417241255, 58.777862364246005, 57.799023120634025, 53.953033262683505, 50.653955167339696, 51.14867587243357, 55.64323356074672, 59.86541794192407, 60.15536738980202, 65.02474284941151, 62.142389128285075, 60.11954046064808, 56.03201889222669, 43.425642751878314, 68.17576716023108, 62.265582930657175, 65.55857350749355, 61.77761262462985, 60.21478737554243, 53.20825753673431, 52.746190563324966, 48.492811572167184, 47.086508504806034, 48.46765741225212, 53.17939673700641, 58.835058366098714, 63.18621420091199, 62.979097366333015, 63.35664902963946, 63.74448514753773, 60.363978647416644, 59.392431089955, 58.87831818672919, 55.56921843559512, 59.023622389762636, 59.738462586556714, 65.52673955117503, 65.70048878269812, 60.514695721287886, 62.28792475115869, 63.79154966723535, 59.10969488082394, 60.70427171645626, 58.452395854457734, 61.309120808878255, 60.2449268679465, 62.82731733014507, 62.62587616520544, 61.56478874145016, 28.17622846172702, 3.0453762508207753, 0.07301355712115765, 0.011810807214539138, 0.11554451403959144, 2.9027326405048375, 3.9261074556458384, 1.4436458700126218, 1.6663278951760263, 0.35136328469361033, 0.12162166737741041, 0.10074604723242023, 10.337192819964502, 49.23746962701121, 46.2593630052382, 56.207364528409904, 42.60266673180365, 30.18242862916762, 21.440665760347922, 2.9108149293930303, 0.0971514860829038, 0.03806459920240506, 0.05091514190538757, 0.06419971172187118, 0.0381472371067972, 0.0850861145543956, 0.052791777697782365, 0.03417065855295908, 0.043715424610361944, 0.035951046888986905, 0.026639993189864104, 0.05436336877004755, 0.026078856767966382, 0.040423904861053156, 0.0029277876667272783, 0.09473057163338508, 0.024938069494260896, 0.022408563996695226, 0.02843047473429432, 0.07857595300001484, 0.0243750044460138, 0.030870010866032496, 0.05125566415729062, 0.05422917314835134, 0.03221322729763004, 0.08930574216309095, 0.016290997605650656, 0.07962440561142661, 0.11993870244271333, 0.021298092737373327, 0.04664509805039533, 0.07397130492233461, 0.05244780421978044, 0.06461857412491115, 0.004062571923338598, 0.04333541052596223, 0.019088459591711723, 0.016821191736286687, 0.02750182486770134, 0.05340669349196458, 0.04640023336715756, 0.05216610985958288, 0.05947943416333968, 0.010817166278889824, 0.03777262011182405, 0.07112029339036635, 0.040067379032411886, 0.04415140524806996, 0.033768351309962814, 0.06519579073233951, 0.03258707820467892, 0.12699349888510283, 0.029425879587389292, 0.04771099065340335, 0.042685185739349936, 0.06041262501610383, 0.017632063245400786, 0.06623271372049086, 0.041420907007470247, 0.04751870258440895, 0.039701330730871814, 0.06442188871123138, 0.017355857905180707, 0.033872719298327164, 0.018116518096517653, 0.10388813387121885, 0.03487372425414863, 0.07634109832466611, 1.4297009860315633, 31.648228168487552, 55.331024662140884, 38.76181125640869, 33.431600447623964, 51.82657518694478, 70.44182239040252, 25.187547129969445, 1.0356909349080057, 0.10210146361421193, 0.1418843099306668, 0.4842419706044659, 0.4678146246700518, 2.1273830196549817, 7.5441803951417254, 1.8028157132287181, 0.5142642821996443, 2.6814489403078636, 26.924753112177697, 61.76463350172966, 72.46054080224806, 71.08615798334922, 68.38547275912377, 68.34368382730793, 74.11702832868023, 69.32835563536614, 65.47674502095869, 70.05436282004081, 65.85160593832693, 66.27329995555263, 59.45209818501627, 66.04057004374843, 68.40887361957182, 68.9973311270437, 68.35671394102036, 69.62728731093868, 68.85516874251827, 66.46429584872338, 65.59451026301231, 62.67809467930948, 61.120976478822776, 58.32257324649442, 55.153815900125814, 53.80867435086159, 53.021976332510675, 57.85854116562874, 61.41375395559496, 64.69862130380446, 67.32637789941603, 63.14478220478181, 63.45383359539894, 59.94479102473105, 45.93839937640775, 69.63434757724886, 63.98052553976736, 67.28105098970475, 62.923776257422666, 62.40208141265377, 55.898136631135024, 54.75659747277537, 50.796007725500296, 49.949085635523645, 50.48719952183385, 56.42813905592888, 61.38248874295143, 64.10308391817155, 64.47977658241027, 63.98764071925994, 63.98473816533243, 62.16848073467132, 62.02535344708351, 60.975072153152965, 57.48144841963246, 60.219372626273866, 62.856284033867624, 66.0781620394799, 66.37779974168348, 60.94504248711371, 62.96305094995807, 63.578588501099624, 61.76132302130423, 60.41634621158723, 58.66240347585371, 61.5256356423901, 62.32137080161803, 63.20878744125367, 65.81399825311476, 61.4233402282961, 36.43632819575649, 5.518788070447984, 0.5775418577174987, 0.3282996255063242, 1.0642933485008057, 6.416074374029714, 3.6301354535164374, 1.7911864985381405, 0.7519357062635884, 0.17285034991800788, 0.16679526757328741, 0.11388227178324616, 7.1303752449251, 52.052558622052594, 55.907303210227724, 49.75583437950381, 38.73330739236648, 36.11513706945604, 29.825808694285733, 5.687026371878963, 0.082613964144501, 0.009243626470467257, 0.03822718221213549, 0.013520688648455808, 0.043211871187292764, 0.05344147771416653, 0.008532375119806779, 0.04416015014172562, 0.048070879608032205, 0.026222199479478504, 0.03173700023081995, 0.050113679871203444, 0.05658682405708298, 0.059709589958431265, 0.025017418966238058, 0.019530130347477335, 0.033849457038506385, 0.022714242654582186, 0.03011716860196283, 0.013605855600607973, 0.015041926676677841, 0.08797590545709096, 0.05006967195039315, 0.06048200959940592, 0.054941416582873756, 0.07387563586235046, 0.003936068782012069, 0.02868006426480509, 0.020732917116894838, 0.0033110672009042316, 0.18832298175942516, 0.10649068776758448, 0.18398002931667914, 0.19823234438175158, 0.13513014171152346, 0.21046771848153686, 0.21676252505952315, 0.1304036396886072, 0.14713765061911077, 0.15295513845499487, 0.21210012927411065, 0.19280361552392283, 0.15916403593315234, 0.2516544439018734, 0.11088501406653274, 0.18427590779479475, 0.10329820020424743, 0.15268322320715075, 0.3339101470285847, 0.19579633800012453, 0.18026824139298933, 0.2059612522322324, 0.11681690181214964, 0.18008195945332128, 0.047197937740073095, 0.14675895803638045, 0.16435480255994106, 0.16799445564468063, 0.14536325309065082, 0.1363428282521425, 0.20894862741472262, 0.17574485992231678, 0.1003307739513055, 0.24761158342082656, 0.1044175619139306, 0.16577946562920848, 0.18962775206854268, 0.18670151070241006, 1.1509187711823372, 31.464690662199455, 64.54315031728437, 53.36672521406605, 42.83114479434106, 49.4349217414856, 65.79883044765842, 39.65163230895996, 3.101590679537866, 0.4094654766301955, 0.5639645733660268, 4.414438374580876, 8.92868341938142, 8.774775497374996, 10.6124706422129, 1.9857577546950311, 0.45670867867527476, 2.4527536765221627, 24.88616201185411, 61.43516225199546, 75.76755385245048, 74.15010959871354, 74.78579244306012, 70.09890525571763, 77.52416379990117, 69.21322622606831, 67.02878767444243, 73.37286057010775, 69.15344145990187, 68.70460464108375, 61.27010499277423, 69.13253522688343, 70.63970596559587, 73.74226939293646, 71.79693852701496, 72.52387139105028, 73.4743558206866, 70.45667248387491, 70.64216136932373, 64.1484304397337, 63.78845099479922, 62.5693783452434, 58.54929408719463, 56.85337889579035, 56.262399304297666, 59.54882775583575, 62.74525742377005, 65.74217965525966, 70.97787703237226, 63.87351151435607, 67.15734727921026, 62.823261599386896, 49.96357094857001, 68.96581096033897, 65.40030194867042, 72.07216339726602, 66.15604462162142, 66.00256227677869, 59.09799445059992, 58.174346877682595, 53.48873053827594, 51.064999949547556, 53.49329225478634, 58.71514758756084, 64.14869323853524, 65.87867813725626, 65.74700809294178, 64.84364701855567, 65.86668352926931, 64.9668957341102, 66.04743419154998, 65.16870167947584, 60.33376462997929, 61.590464576598144, 63.83792384978264, 70.10773058860534, 68.86606508685698, 62.111884855454974, 65.41324969260924, 68.65808533084008, 64.87587321189143, 64.41877195912024, 62.75581252190375, 66.57198059943416, 62.98563203504009, 67.04873684913882, 70.08337266983526, 64.39644582809942, 32.88796190292605, 4.299198158325688, 0.3370586151797926, 0.14615578637007745, 0.4606862684651729, 5.281051253118823, 9.282475325369067, 8.45471009131401, 8.838524799193106, 1.6977566216261157, 0.5581798128062679, 0.2390200452458474, 14.48627991061057, 61.139964672826956, 55.55360347993913, 62.45777514673049, 50.28214193159535, 44.8594141775562, 35.49413173429428, 4.981594470239455, 0.1262757970741199, 0.11994076321922964, 0.15644411736678693, 0.13106694925696621, 0.11294089528101106, 0.27106023243358063, 0.18316112729089876, 0.13232095858022092, 0.18622311943721387, 0.10060221422463657, 0.13832491221687487, 0.15528187005510255, 0.18702211849872144, 0.2046650008208329, 0.1224097726686347, 0.1631626012104173, 0.08562707222036778, 0.14309505060795816, 0.12887327180754754, 0.156038397202088, 0.09680372813055593, 0.1344687013976997, 0.21710515022277835, 0.1477342645727819, 0.10912688058470527, 0.1374755811787421, 0.06113766211896174, 0.16595163622931128, 0.1698640166150947, 0.24474096003799672], [0.02363510906786448, 0.041324943003635255, 0.015094108755640207, 0.07602372341939519, 0.046611677464698596, 0.033913632223923365, 0.03701894664235654, 0.09922358537873915, 0.1297998398302063, 0.006871586994102766, 0.01814751018349442, 0.07934518188478486, 0.07823654540604161, 0.03449328499095094, 0.04779278203063915, 0.028419389442029982, 0.03368862837012257, 0.06623587766361815, 0.06853202703378855, 0.07624345275783732, 0.020552641306553158, 0.06100418661991435, 0.047355598634890014, 0.02528340277832843, 0.0523314661075992, 0.02412119568626006, 0.0640219793234381, 0.015306447260832835, 0.048706985394200014, 0.02592575218107912, 0.05481176769300815, 0.024455169801630323, 0.01517980526607003, 0.011036589182162238, 0.03191426723083902, 0.031163148664598985, 0.051838630254590706, 0.02598494013410903, 0.05785798608896233, 0.738482405581782, 19.50891217877788, 48.70254855002127, 47.07954629775017, 39.449273309400006, 32.95210246116885, 59.85767126083375, 35.79664845620432, 3.1630654969523033, 0.045562692422179446, 0.14066485117279715, 0.6786430326680983, 3.376093833677231, 6.892702166111239, 2.0945005647597776, 0.40837058376881386, 0.12116961421505099, 2.775272034829663, 23.59303697463005, 53.51533989752493, 68.69928590713009, 69.76818669226863, 73.01089640586608, 70.01077744268602, 66.30502408550632, 68.84400567700787, 65.79272331730013, 67.50367687594506, 66.2859692112092, 64.32820050947129, 68.00060195307579, 68.7952898394677, 68.7941837310791, 67.52401044291835, 66.08610091670867, 64.79740619659424, 60.97975546313871, 59.10145398109191, 59.56367784930814, 62.009016775315814, 57.08730513049711, 59.54295204531763, 53.82998851037795, 51.82764599400183, 55.68557946912704, 63.93987017293131, 61.651131876053356, 71.287807033908, 64.33984602651289, 56.649968701024214, 43.62482855396886, 29.14871934921511, 68.36546082650462, 63.780437592537176, 64.94090218697825, 60.37853848549628, 64.91014688245713, 54.82692949233517, 58.26410639670588, 51.38817579515519, 50.52168107801869, 47.620354852368756, 52.44539183955039, 62.01154278170679, 65.51803581176266, 65.50038514598724, 64.74665464893465, 62.67616095081453, 62.64083608504265, 61.05015808536161, 60.74681374334521, 60.41143148176132, 56.69608008476996, 58.26727174943494, 61.80010349519792, 66.0989898250949, 64.476242526885, 63.34993393190446, 63.14285632102721, 61.72455864567911, 61.322523547757065, 61.13912136323991, 59.33940456759546, 59.589326227864916, 63.6942199737795, 50.974522636782744, 16.10673752523238, 0.7307007908821107, 0.2772669235785162, 0.20998042527466051, 1.2470864624746385, 4.527204555849876, 12.448342865513219, 5.026896374840891, 1.6564612955816331, 0.19449129189935424, 0.04100799710760194, 0.37705968164147874, 15.285597174398362, 50.66095659809728, 36.84634139460903, 21.819058772056334, 32.33598439924179, 38.90994741070656, 20.04945008985458, 2.10895057647459, 0.11662319648049532, 0.024949610608840184, 0.07029756092496457, 0.027020051324319456, 0.11797348773407361, 0.05880211284684558, 0.04556920416953583, 0.03992703938556295, 0.024328629313517484, 0.0634819639456128, 0.0349564234455747, 0.14590280881572157, 0.02374221199011851, 0.02007672642057221, 0.10113050845722038, 0.0640496121148669, 0.08417693672761803, 0.07457468343237716, 0.06008592682079442, 0.010888986064181214, 0.06586269325306339, 0.009215899833267736, 0.08906833917623566, 0.0752522269143693, 0.01649702737678684, 0.02931492707331575, 0.03503718826499197, 0.03792389183335247, 0.04790978663931451, 0.01836804391425704, 0.011083922882173813, 0.06248613391371985, 0.02617266614951434, 0.027288354467600587, 0.09286602087799581, 0.07675782717283695, 0.03664340268099501, 0.05658904954250302, 0.04128433651320877, 0.05720808688971785, 0.01987326687442199, 0.028248825711348367, 0.01955915167326889, 0.039891443110161254, 0.03159156226883492, 0.018658098208928303, 0.04550984767716258, 0.042102273268204544, 0.02369665465648136, 0.015824293969349278, 0.06652727452737671, 0.03446713074921601, 0.049276943318545825, 0.06295869141937264, 0.030223760160527406, 0.011489163284310171, 0.01828405577989836, 0.053448426131639755, 0.0659850221728125, 0.05961839485192492, 0.06918498675429052, 0.019782433744459864, 0.05603234493924726, 0.04675209372033996, 0.11526406457227086, 0.037887820583437724, 0.07125472649931908, 0.03745699571746011, 0.010242149301414049, 0.08453093063566955, 1.8932377450889157, 29.587008914639874, 56.936235043310354, 47.04351540534727, 33.772705447289255, 38.9838997779354, 73.72627396737376, 30.95052088460615, 2.371113708903713, 0.064223307229939, 0.02963188063022831, 0.44135600088104127, 6.501836997847404, 7.2452634284573225, 2.6591338409531504, 0.11613202686872214, 0.35269250852927087, 4.4560164789999686, 29.184644337623354, 61.07808143861833, 69.74929655751875, 72.6806406820974, 74.4141870929349, 70.14470284984958, 66.19005157101539, 68.14825565584245, 68.48791722328433, 69.50046923852736, 66.42774720345774, 64.54904563965337, 67.85026534911125, 71.0546927298269, 69.96471312738234, 68.824888044788, 68.4962091138286, 66.81007631363408, 63.18434323033979, 62.811706296859256, 61.74839488921627, 61.69527030760243, 58.304808831984005, 60.526768776678274, 54.856829720158736, 52.76931293549077, 57.25992471941056, 65.4040164332236, 64.00846458250477, 71.68027939334993, 63.2202878305989, 62.17830627195297, 49.41863213815997, 34.90632926264117, 67.39720021524738, 63.510951149848204, 66.33300627431562, 63.29735063737439, 65.5590324248037, 57.47367428195093, 57.62217521667481, 52.76979538702196, 50.949631275669226, 49.83697252888834, 54.534265764297984, 62.39655087071081, 67.42202881843814, 66.73314294507428, 64.98444441826113, 63.682629369920306, 65.22280685363278, 65.47634493920111, 64.26067690695486, 61.533131291789395, 58.348951185903246, 60.98046933451007, 65.37911722736975, 65.88872724963774, 66.46599031263783, 63.46587527182795, 64.4329317154423, 63.080341585220836, 62.44849481890279, 62.711944733896566, 63.06931580266645, 59.28210658411826, 62.90723562240601, 57.36830372964182, 23.327716089064076, 2.7797349566413514, 0.6075340160919774, 0.9722390590656189, 7.120627664750622, 6.525605090202824, 8.905381598780233, 5.205962379132548, 2.5759430662278207, 0.373338210366426, 0.038669467753460335, 0.17502227047037694, 11.205450642493464, 56.0542901100651, 49.21000519106465, 26.795622802549794, 41.87233709519909, 45.76035514954598, 30.338466398177612, 5.484711989279717, 0.06531436582125964, 0.03846710945870127, 0.02712885496176539, 0.03277393854072979, 0.057026072059788054, 0.0423624558794883, 0.053353841086068464, 0.026799536745754943, 0.005512284631315138, 0.05230995052824578, 0.04957534988681155, 0.027723540289087162, 0.07336670833249247, 0.06489883207025067, 0.0147311870504411, 0.06324982781323694, 0.010598658850686926, 0.053891975718039664, 0.05192323700494824, 0.07293851880897438, 0.054130765324037884, 0.0844674219467467, 0.061089000214011445, 0.042688050908186746, 0.06867903930645797, 0.04911253318911599, 0.03020202624611557, 0.018169648209286314, 0.03439217287626478, 0.05807480812373181, 0.04153744813295142, 0.09762703516190091, 0.19852292153143114, 0.09264623791339899, 0.1993177990399061, 0.19852725758908257, 0.1767942165174792, 0.15097115459221025, 0.12911933924882643, 0.21912187668344668, 0.10813029978664652, 0.16109229456032478, 0.16472306102514267, 0.22689823601995746, 0.1663232961248967, 0.10562215090518999, 0.1857518527897135, 0.1464443716911539, 0.10120249773946502, 0.14186082167490838, 0.139109447538372, 0.1661344094862861, 0.2020740148521239, 0.11717720828469723, 0.15539883635938168, 0.22720021255795034, 0.12649808514622912, 0.1989280901128246, 0.14094349267261644, 0.1347326646528898, 0.14572699163709918, 0.19691332483724241, 0.1606076213741495, 0.10946339236632471, 0.3208531283082501, 0.13508485059344, 0.15155751828945455, 0.16539845946094683, 0.07498674680508914, 0.153926017003194, 1.5448343176995556, 28.99560178479841, 67.64239541945919, 59.462002169701364, 54.778978516978604, 44.566036578147646, 73.88370221660983, 45.68037802173246, 5.262375377839612, 0.10038225505981715, 0.2632005686961836, 2.075305465729006, 6.3323450088500985, 11.944581097172154, 4.997220212413419, 0.8739304891036404, 0.6555703029997888, 3.7719472762077086, 26.146860814863636, 57.739155984693966, 72.88539624983265, 74.26141861946353, 78.1755204354563, 72.74062156677246, 65.73137352543493, 67.90222106441375, 69.92151214230445, 72.68410805732974, 70.90017487925869, 67.6402694948258, 73.58057360495292, 74.0559805593183, 72.91177811161165, 69.87955847094136, 70.2305164644795, 68.01841735839844, 63.72471247949908, 66.09052535026305, 64.67910751219719, 66.33023708097397, 63.453096189806544, 63.90671830023489, 58.10621923015964, 55.044224877511304, 61.41325973695325, 68.77366189033755, 67.19818699744441, 76.89611388790992, 66.5875602537586, 63.95439078730922, 48.84271444812898, 35.645868624410326, 68.5138911585654, 66.64108491713002, 69.50989077168127, 66.02283308582922, 67.64106965834095, 59.653547194696245, 60.74255404933807, 55.63083494863203, 54.32948273997153, 52.20005935238254, 58.39270522517543, 67.20667500649729, 72.72156669247535, 69.06087352383521, 64.48606021942632, 63.64834393224409, 67.22593384404337, 66.19767665863037, 66.22645901095483, 64.65544385294761, 61.705723424111646, 62.275388856087964, 66.42189502716064, 68.88711252520162, 68.17004834451984, 65.06910093369024, 65.26723946294477, 65.12284917216148, 64.24836850935414, 64.85237429218908, 65.43865880658551, 62.766728478093306, 65.20836076428814, 53.60652323692076, 19.808602832978774, 1.9526789361430754, 0.3961687030330781, 0.6280157751133365, 5.0308182547169356, 12.686554289633229, 22.094114980389996, 11.183540282710906, 5.377334164034936, 1.229116736400512, 0.2039586677546463, 0.7874396527486464, 20.60210812476374, 62.524769229273645, 47.07980909655171, 33.00012403918851, 43.026631801359116, 52.002167932448856, 34.01651605483025, 4.310768169741477, 0.18095084105528172, 0.1679815853675527, 0.12140036755872351, 0.10235605761408807, 0.175624844588099, 0.1823184918612242, 0.1685068152484394, 0.1731621630249485, 0.16269890351160882, 0.2921691723167896, 0.18480126024974933, 0.2950841981557108, 0.0812757311148509, 0.18178984522819522, 0.18583603053083345, 0.13288597906789473, 0.1528732130123723, 0.10564743946757048, 0.1634790414884206, 0.12027797214086018, 0.1536939842926879, 0.13432925807372217, 0.17301954809696446, 0.17877449251471028, 0.16837258132234698, 0.155033856750496, 0.10309252857921586, 0.11774417463569872, 0.07400128960369096, 0.14867106753010906, 0.13945821672677994], [0.0530560358968233, 0.019670770683836554, 0.030049687747152585, 0.007107414712663741, 0.034153567131368384, 0.02896186779253185, 0.036817614905416005, 0.014174833890020609, 0.06924891679157173, 0.031809619620382305, 0.039664144823027235, 0.046257955517860196, 0.06729464181849072, 0.06592156711004435, 0.003994893322082898, 0.026982124226408142, 0.06302021211013198, 0.016166224865423098, 0.027371358178976565, 0.030632540846483845, 0.05100016617366383, 0.03817855478114179, 0.03927311439427637, 0.04468531490513875, 0.020272299091541962, 0.04015327281048221, 0.04508395258697771, 0.058439052288210204, 0.05248144314053559, 0.043878804351533615, 0.03289011960488654, 0.025397231952557643, 0.029599093982288917, 0.06653285930834471, 0.04046342733706679, 0.10257004129309809, 0.02188125610231392, 0.04246408510352335, 0.072520479950453, 0.07267592685116876, 0.31142142150671254, 12.467655635649159, 42.85449074160668, 49.9678659439087, 39.547022696464296, 37.884981093868134, 63.88645141355453, 46.52821402395926, 8.406074662362377, 0.3410687483847142, 0.2761972809751188, 0.1142021747786672, 2.233758924468871, 1.4896234028762387, 0.42362140251263497, 0.22198300057601547, 0.1748654982375522, 1.7996905647939252, 17.676371028346402, 47.41808214495259, 62.16835129645563, 64.43707373834425, 68.27440692532447, 69.51412693146737, 69.59446491733675, 69.79292900331559, 64.21579714744323, 64.9702807395689, 64.49358332541682, 70.62833109209615, 71.33435772311303, 70.21976917020737, 67.90457448651715, 65.70132032517465, 62.92823206993842, 60.76302882163756, 63.12582538973901, 61.611449257020034, 60.594049192244015, 57.52721463480304, 57.24069726082587, 53.02881302372102, 56.209827776878114, 55.26081031368625, 66.40619770173105, 62.654572225386104, 70.64482073630057, 58.73823465839509, 64.03557600513582, 41.207487506251184, 18.351306992192423, 66.68994980473673, 60.725660401005904, 75.64916103116929, 64.50780191729146, 65.07125823728501, 61.63423822772119, 62.0357124267086, 54.12986547716203, 51.401272589160556, 47.134659521041385, 50.79198729607367, 58.3706065916246, 65.63512248377647, 64.32648643370598, 65.97196778943463, 67.01352180973177, 67.244886736716, 63.615650976857836, 64.94468727419454, 60.77474886371244, 62.87020844797935, 62.679122340294626, 63.06492274807346, 64.44156877456173, 66.62003747878536, 64.37874024914157, 66.07071738089284, 64.77355034120622, 62.83455802548317, 63.136772724889944, 65.77165626710462, 64.06820228022914, 37.74881993570636, 9.2271924595679, 0.11090265707142892, 0.2528727688496151, 0.2659547467145228, 2.9554647399533183, 6.723255774667186, 15.835372267230866, 28.375726092246275, 5.916090828757133, 1.1626972810875986, 0.06209739791830221, 1.7629781605735904, 20.750822828662013, 56.964436884849306, 30.24740661344221, 25.69909284191747, 34.90652930351996, 37.79762991013066, 16.035713207337164, 1.8214086058639714, 0.021106036409976024, 0.045700729974815925, 0.05253756674186838, 0.058614325544406334, 0.0591618868882858, 0.0014367779118812554, 0.1097012473450553, 0.07204976488625811, 0.03652863121861893, 0.034305984154343605, 0.04417727603727291, 0.09000656705710197, 0.03809007928676663, 0.06274466560552679, 0.024041748538072553, 0.01773375950212921, 0.09391045918868435, 0.04055124782626668, 0.028888430604110324, 0.02461626085512821, 0.05016997584231919, 0.052022912704776374, 0.0675426398013388, 0.020349993813602675, 0.050421490168739716, 0.03605503949426836, 0.02707816483903556, 0.023199358256533745, 0.040426302716256156, 0.03594805531564259, 0.05925309348611101, 0.10712834871223859, 0.024865384987224976, 0.04083239443359837, 0.03794192937352965, 0.011910875534428465, 0.033100468196695855, 0.03710364915370461, 0.013588904947673362, 0.013234925403770421, 0.0451777677141851, 0.02884652367943237, 0.037071852674407345, 0.038085716416037856, 0.04745659966682715, 0.04420824514161195, 0.08740587475439233, 0.030683288425807993, 0.11023621420345961, 0.048397474381471836, 0.03412753929414096, 0.010819878230141777, 0.0952031712738737, 0.03130130879130335, 0.019991870691639282, 0.011689955886873988, 0.06339012532525005, 0.07039140669568893, 0.024463202233516404, 0.08109652016672396, 0.03230411596896668, 0.018944707023160114, 0.02035625466716386, 0.005980372492734704, 0.03193531166611901, 0.11007185003930524, 0.07638265093367907, 0.05055434130612881, 0.02263225400970588, 0.045759864301691135, 0.03354868708899425, 0.09650224954971383, 1.117297562379991, 22.073697082458004, 54.380661825979914, 50.25689363479615, 32.42025260002383, 48.47932646351476, 78.06028119979366, 45.11743553223149, 6.356020435210198, 0.06563433010371462, 0.16341171768163482, 0.24941530679502796, 0.78853240056384, 1.420156143365368, 0.7013585202155576, 0.48729890657048075, 0.1374249734104641, 2.951099877395938, 24.065914000234297, 55.334515571594245, 67.28516947838568, 67.19803010263752, 69.71843534900297, 69.6252162994877, 70.38139435552782, 70.33388660800073, 65.16862715444258, 66.46297793234548, 67.49121942827779, 71.22749667013846, 70.97120900307932, 72.67438842404273, 70.65468157491377, 69.76782583421277, 64.62541810927853, 61.677211715329086, 64.18317479472007, 60.65550096573369, 62.450707035679976, 59.78884935379029, 59.0271839018791, 55.75927688229469, 59.328394474521765, 58.98537143584221, 68.27257125608384, 66.54229610197007, 73.8651886293965, 61.7453315181117, 65.334394362665, 45.41878731020036, 21.601194643205215, 67.24703619557043, 62.51584191476146, 76.58037877851918, 64.33654731319797, 67.92132300715294, 61.74226422463695, 63.05347334954047, 55.275809457225186, 55.13340388574908, 50.66705196134506, 55.38301567877493, 60.64237671513712, 68.14999718819895, 65.14453203447404, 67.1984301843951, 68.23094706381521, 68.26533840548608, 64.75107516011884, 66.66068892325124, 63.09071625432661, 65.98549212178877, 64.70037852564167, 64.14441393267724, 66.18993389991023, 66.32230604848554, 64.2810457752597, 66.51486304498488, 64.0779846714389, 61.96057550368771, 62.67018325867192, 64.57447044311031, 67.44775956676853, 47.930935967353086, 14.484951207714698, 0.32880910461948765, 0.22587803673119317, 1.6824710224905324, 4.725705414049087, 8.200446367263794, 19.05405059937508, 24.589756342672533, 5.581641110681719, 0.656581539059839, 0.042002183880897305, 0.8803683242970898, 17.727246130666426, 62.40629011584867, 44.35189870096023, 27.659073760432584, 34.262731075286865, 42.74766498996366, 25.08355332959083, 4.040434004799012, 0.05660345965635873, 0.030823990049201156, 0.04118869426630197, 0.02704635495319963, 0.02175894633476292, 0.040109230415715326, 0.06176133046767885, 0.05590694400692179, 0.07781435435097064, 0.04919778728376954, 0.026250347465036378, 0.08453170438447306, 0.025284002242129178, 0.044933535053484866, 0.04393490497022868, 0.038150312949813185, 0.020226098244048415, 0.07398250512778759, 0.02630331478412113, 0.016264523522207336, 0.016199321778971824, 0.054203528355086045, 0.10051769940482994, 0.019399631100015777, 0.039240877414422656, 0.08811652855647188, 0.023826839807893962, 0.08352309600600312, 0.008538842817107517, 0.07077347006528609, 0.01954421104352561, 0.07622704315449923, 0.29687773256051925, 0.11429531574850121, 0.16080920975054466, 0.23019990643426297, 0.11156279503578141, 0.10407911192986274, 0.11384702407785001, 0.1438336206539985, 0.1636392764386631, 0.1258035574949557, 0.16811123808785794, 0.2132213295948121, 0.1507570176956154, 0.11356201638737995, 0.22177643262811247, 0.12208520419775479, 0.22274098329005704, 0.06015170696041277, 0.10339750052099267, 0.11129369133061941, 0.2256785780792275, 0.151614515231021, 0.24938610352335439, 0.10957043783198442, 0.143359795272831, 0.20977275416014657, 0.12004236179974773, 0.15068413209049933, 0.1408809339327197, 0.10299865216497453, 0.13612705192738964, 0.12004492053341483, 0.1930917718357617, 0.19855146596748985, 0.07973469928988526, 0.21082863782442388, 0.12401362370339133, 0.152408795190915, 0.11780471090347537, 0.20675438306024, 0.8443355319961425, 21.02976610583644, 64.1865441106981, 63.603405337179865, 52.106051906462646, 54.018642748555834, 77.48381045556839, 58.10870601284889, 12.355127738368127, 0.475266331266011, 0.4900215217663396, 0.590776915271436, 5.901722206223396, 5.573963561365682, 1.3988269072386528, 0.85839667748059, 0.46376045673124255, 2.3562290495441807, 21.11169461281069, 52.13115507556547, 68.65042101952338, 65.61235704729634, 68.77302646636963, 70.15581100217759, 71.46780460111557, 73.85677906774706, 67.46376283707158, 68.91298447885822, 69.1925004220778, 74.23024362133395, 73.7848114198254, 74.64233567637783, 73.27250280687886, 72.9610195467549, 68.17776756901895, 65.90694273671797, 67.34400503097042, 66.49919709851666, 63.91040925056704, 62.66064797678302, 62.54992338918871, 57.94353108252249, 61.11057043075562, 61.1719359121015, 70.46489377175608, 68.58341909223988, 72.85612752360683, 63.55590151202295, 71.0655890741656, 47.21003570864278, 25.72411952480193, 69.52371320416852, 63.49217084146316, 78.25909829908802, 68.08588212536228, 70.13049602508545, 66.24679257792812, 66.69311907983595, 59.17737930051742, 56.084029520711596, 53.38850221326275, 54.975206851959236, 63.2306585773345, 69.85735001102572, 68.54983575882451, 68.14296045610982, 67.6657021430231, 70.08929544879545, 67.6329738863053, 69.54507443212694, 67.67014226605816, 67.82946894245764, 69.74308352316581, 67.07783299107706, 70.26110310708323, 68.72277305972192, 65.36686374295142, 67.79321055258474, 66.03922074840915, 63.22645771887995, 65.90415000915527, 67.72506329321092, 67.16478409305697, 42.25956524572065, 13.497483730316164, 0.3138541183885067, 0.684921031277026, 1.2008385312172676, 7.804936622419666, 19.679037140261745, 23.08244243744881, 44.368360888573434, 14.710243325079642, 2.6513155766071814, 0.09583601352548408, 2.3935293189940916, 28.16536153516462, 66.6772021016767, 41.648087347707445, 37.41375930847661, 45.26815260610273, 53.66889676740093, 28.100371783779515, 3.038619723050825, 0.12879477843882578, 0.09645331951399004, 0.1173217767368882, 0.1899901576220028, 0.11183135481851716, 0.10615059835535866, 0.22469622353392266, 0.17692661183255334, 0.17947091240315668, 0.13303383403728086, 0.15359374934867506, 0.18934146501123908, 0.09879974723463097, 0.1835172356016213, 0.13101868571773653, 0.1701006918184219, 0.2614285153967719, 0.22779535562280687, 0.0804529603450529, 0.1471803217164932, 0.12866451284818112, 0.17706758733237946, 0.18895785414403488, 0.10570308809439022, 0.10931359153361091, 0.23507078538738915, 0.14812670077287382, 0.22736925751932208, 0.10242742636511404, 0.24223684843990112, 0.09599257125369004, 0.20756396945686112], [0.06575213144383123, 0.018127915569611134, 0.055597969255740606, 0.04237633739267627, 0.018200699668077212, 0.04338797181844712, 0.052385230158125205, 0.05995676439676074, 0.07304927980106685, 0.048109555556889505, 0.02648983804148532, 0.012553294842702248, 0.050679703934058074, 0.09936701235992294, 0.034451242085666425, 0.042504952063844095, 0.011751002560730183, 0.03516286115853056, 0.03705442800456959, 0.053493020109712124, 0.005608497134920571, 0.1069140126327834, 0.018435748849785136, 0.12666997229379992, 0.05142838634069889, 0.0570097045912858, 0.030013469025312416, 0.038997613854946635, 0.029972556099716215, 0.07204650135170068, 0.04086862656197721, 0.0524426254654123, 0.08859400817703816, 0.050244569823506384, 0.06500069878154224, 0.051081647285290306, 0.07438465532275938, 0.017989263231415423, 0.08942661551578392, 0.019757823169892354, 0.010286079655822006, 0.17588290896627212, 8.67870782652209, 42.10956596559094, 50.720309903544766, 33.97455453872681, 27.146625903344926, 42.20367931550549, 56.705929156272646, 19.761157843374438, 0.5743160146859385, 0.04972217829837915, 0.07602390728049702, 0.4983731671687096, 0.33963503015618174, 0.09302231047542826, 0.0632918783794007, 0.10684013111336578, 0.5754507441193827, 6.5500841121519775, 22.16076389435799, 39.31729732021209, 60.81450993014921, 64.47927059665804, 71.91681400422128, 70.2744548551498, 69.83137607574463, 69.2765489701302, 66.97650248004545, 67.30528339262932, 66.44306013661047, 61.716494252604825, 62.84430903773155, 60.046745192620065, 64.26047686607608, 63.998529218858295, 68.50654848160283, 66.45453699173467, 65.97778858677034, 64.49045719638949, 65.20292828159948, 60.34299788936492, 57.056965597214244, 62.737632336155066, 72.15702779831426, 67.28078426853304, 72.06194170059698, 64.2777156829834, 58.61613519730107, 37.4682371077999, 37.08609627139184, 55.71881763396725, 61.09322963222381, 60.218411645581654, 65.676107329707, 68.91780899417016, 67.31890970660795, 63.62883014063682, 60.40907021491759, 54.55278327388149, 49.625023334257065, 51.662561278189386, 59.722255353004705, 68.152342765562, 65.09886780092793, 65.08440994447278, 65.02681778323266, 68.71449685865834, 67.02037026805263, 64.66128426213419, 67.2337079817249, 63.711356809062345, 62.09493237157022, 62.63049279489825, 64.75563687662925, 67.17119324591853, 63.66722229988345, 65.65112183170935, 63.89000115856048, 65.05865566192135, 67.18894589331843, 49.714716172987416, 16.74779695849265, 1.035636021725593, 0.20311653794300175, 0.14816684378010614, 0.6630231740493929, 3.0433010718514844, 1.9353423051295744, 9.817724900860942, 5.47214912791406, 0.3213204112985442, 0.15544956670172755, 0.19390420807946115, 2.4751940465742543, 30.14553285414173, 54.49213166390696, 26.434666687442412, 23.11527463697618, 31.640073560899307, 33.704279699633204, 13.824672160610078, 0.2536220947701124, 0.028131679376407016, 0.029725804924964908, 0.022658053935775836, 0.021385792567725145, 0.005414146852994999, 0.006912677556336407, 0.03605246543884277, 0.015228160735850614, 0.12697900450157543, 0.10341298315794238, 0.020269487548859853, 0.03033425876750581, 0.035866646982368924, 0.07269547741499639, 0.06768638853945079, 0.021535332930544694, 0.06004181930855398, 0.0829199703049756, 0.09526872541755439, 0.031987501405960614, 0.030384742046496084, 0.09614067137121193, 0.04025932619227998, 0.060680755789602, 0.04820108774208254, 0.04844887888119106, 0.03403873821239799, 0.0201277497915491, 0.028904585483213587, 0.06594076527342682, 0.11856001230978197, 0.04585194807018965, 0.022222592322636518, 0.04649767592068642, 0.04935075205961063, 0.046783752303810856, 0.06572978465907997, 0.0531593045490163, 0.05685239992735367, 0.08046911713937599, 0.07871905822427043, 0.044479076375043204, 0.017967755312941248, 0.012887173197081974, 0.02746154013420305, 0.056393999726541584, 0.04535215613882869, 0.04531984255018254, 0.05082734056838578, 0.06176342954859138, 0.05357425607320282, 0.037727378789455666, 0.03541334509669292, 0.02329177718849913, 0.05280500420579507, 0.023952947456329584, 0.02783147058629942, 0.052166067724747044, 0.045543452123961145, 0.028890700139586004, 0.055663400825353405, 0.02594975371574683, 0.055631738411442894, 0.008172645128422208, 0.02696261579741634, 0.016430379642594247, 0.05281014082532737, 0.03335693911198647, 0.07238052334756621, 0.046791849853170496, 0.010981032485893417, 0.02477986659223755, 0.038017136225056265, 0.0197652408162192, 0.25169964308940596, 16.16788923740387, 52.78128400925667, 54.43280189268051, 34.95539811349685, 38.79874037158105, 66.21883392333984, 65.20540329717821, 16.018409671321994, 0.3868893557979215, 0.03951249771841592, 0.29962565930139634, 0.5794508262507377, 0.707400318595671, 0.44448979078761996, 0.1694123618184559, 0.20763251900432572, 1.1389274726952276, 10.94060730549597, 30.23732416091427, 47.816159571370775, 62.9955203302445, 66.42529179972988, 72.2122783045615, 71.62204788577172, 70.8311019405242, 70.29795769722232, 70.37969204687303, 69.57247611015075, 68.86873229857414, 66.2132013997724, 65.60749330828267, 63.94447895788378, 65.90028255216538, 66.24712990176293, 68.14502362282046, 68.57638236015075, 66.03668689727783, 65.78668678960493, 65.02834750759986, 60.00659188916607, 58.46273129986179, 63.24101755695959, 72.35503688935312, 66.68522727104926, 72.24810523371544, 63.82470938467211, 62.53340236602291, 39.81793688189599, 31.886153259584983, 58.28741312026978, 59.76371872809626, 65.65082373157625, 68.8633821856591, 69.4811397983182, 66.47476857708347, 64.84209375996744, 61.16147495085194, 55.485683718035304, 49.98908204417075, 53.70014629056377, 60.65750529689174, 70.07762247516264, 67.37712552470546, 66.67455057944021, 66.18430922108313, 69.23869025322699, 67.73765410146406, 66.73541791977422, 68.56673332952684, 65.15392611103674, 64.63639682339084, 64.94598950109174, 66.87037098792293, 67.3336656631962, 65.19747618705996, 67.79966677388838, 63.68477882877473, 65.1822966144931, 69.41459286597468, 58.59406402034145, 25.468577108075543, 2.3315673922338793, 0.46508520661342534, 0.608347969189767, 2.7646617783654124, 5.46077621559943, 3.910383163921295, 5.5436122609723, 3.3325893552072587, 0.534894478417212, 0.11941717276650092, 0.04774727640793689, 1.1217260408786036, 28.689056788721395, 59.993597076785186, 39.28318838919363, 22.853323067388228, 34.7283556384425, 42.90254369858773, 23.873343275439357, 0.970350253966547, 0.04281782620255986, 0.07541901957724365, 0.030692937303214308, 0.03715611468519896, 0.03825384207190045, 0.033295188594849846, 0.030160860511504357, 0.03018539447727944, 0.052616393358837214, 0.0439621662090142, 0.010210623825720001, 0.04546229276926287, 0.0215044251132396, 0.07440721661212944, 0.039044655483937075, 0.01846470314288332, 0.009341649335598754, 0.030783751280978325, 0.027905639388688633, 0.10602363460366765, 0.013975799459243014, 0.04721025643389552, 0.0925319682386133, 0.03484155622220809, 0.024460689465124762, 0.04296862294957523, 0.06560618403337656, 0.06474183001104863, 0.03273546943561204, 0.05179570251775365, 0.01167154009078419, 0.07565803134873991, 0.0463144583327155, 0.14134977974237936, 0.2039887750100705, 0.17026728529843593, 0.1808439717898446, 0.09803859291658287, 0.1735569587758472, 0.09681994621191295, 0.17353958390172453, 0.10770516695394632, 0.12423474732185565, 0.11981686381923577, 0.047411312379183314, 0.18617939113849596, 0.13401324680495647, 0.11950967788335778, 0.18957116881445532, 0.14739641979817422, 0.15781058839732603, 0.15131670621133622, 0.14753759448086062, 0.1661785208289662, 0.13906490718645437, 0.134611576795578, 0.1989211953215061, 0.18707534628770045, 0.13264037127937042, 0.11134762392048875, 0.11263365571897839, 0.2333681243321588, 0.11356765479450265, 0.13872784382152942, 0.11854747911134075, 0.20064533748213323, 0.1280703580367469, 0.16171782067225826, 0.20048727822159568, 0.22346367999430627, 0.09427998935984028, 0.20781340768500683, 0.10894639026974479, 0.15659275374585585, 0.34203230313235716, 15.660949368630687, 61.468718128819624, 63.97962339462773, 48.97636921175065, 41.30921025430003, 53.307940652293546, 71.72057782450031, 26.664654862496164, 0.8569959623198357, 0.12166957085531567, 0.7818827573810855, 2.0094603924982013, 1.6054886243035718, 0.418746080249548, 0.33705723622152883, 0.3948312360913523, 0.9602795685491256, 8.638023041909742, 26.057619048703103, 45.8404891721664, 62.77158044999646, 67.15316603260656, 72.96294935287969, 73.1108933110391, 73.89561837719333, 75.41399924985825, 71.58218876008065, 72.96486346952378, 70.70626074267973, 68.10584698953937, 65.68476792304747, 65.33739889821699, 69.58432166807114, 68.6112992994247, 71.42475266610423, 72.02107844814178, 71.2414603079519, 72.1837156049667, 68.4734985905309, 65.93224986906975, 60.98856510654573, 68.94522636167466, 76.14944365716751, 72.87682979337632, 75.60391256886145, 70.3573110026698, 63.397308318845695, 44.81583272257159, 45.57689805184641, 56.81835605252174, 65.68600346965175, 63.112112783616595, 70.18034150523525, 73.10596681410267, 71.55741507007231, 67.22944044297742, 64.63609872325775, 58.517036514897505, 54.07668598236577, 56.90696631708453, 64.57030096361714, 72.87101684078094, 69.10144652089765, 67.50144896968719, 67.59442483225178, 68.70662858409267, 70.46902010517736, 67.17945375750142, 71.50602417607462, 67.228452005694, 64.37790478429487, 67.64033225274855, 66.40957094007923, 68.80138520271548, 65.87040978093302, 67.2507938261955, 63.911958586785104, 66.05006217956543, 70.34595966339111, 53.185798045127626, 20.094945661483273, 1.475939601659775, 0.3532887087954629, 0.3921392031254307, 2.505256562463699, 9.01598753467683, 5.851324162175579, 23.8721469525368, 13.573800306166373, 0.5856644121869918, 0.72700904381852, 0.22562718890126676, 3.4986987902272135, 41.431282258802845, 64.40917391930857, 38.933630681806996, 32.50808427410741, 46.121417168648016, 49.212586110638036, 23.392829395109608, 0.754313520606487, 0.09215162090596654, 0.26647963951672277, 0.11833636060116753, 0.1969576506845413, 0.0819629502873267, 0.15102491864273626, 0.12508764832971558, 0.11335188613062906, 0.31773695842392985, 0.1726978371340421, 0.12455190006162851, 0.15347063901924318, 0.0847943499684334, 0.17239190758235995, 0.17928280717422887, 0.13373152563168159, 0.1491657764680924, 0.19778813595973677, 0.1900440289248382, 0.302426262247947, 0.14944270193096132, 0.11563644459050511, 0.1682784137946944, 0.18137474814730306, 0.11653259126169067, 0.18291427843993713, 0.15481607327538152, 0.1783158969614775, 0.07447361345252684, 0.1830316124664199, 0.18617709287472312, 0.14268096476312608, 0.08616223826163238], [0.04969520817300485, 0.022867912231313608, 0.01793287724496857, 0.03319163265968523, 0.030197636562309442, 0.03536201337532651, 0.03422258399246681, 0.07696663975835809, 0.02360736519368666, 0.07372544432479529, 0.01839596015821782, 0.026062655923587662, 0.08724164848606433, 0.012382233154869849, 0.09194859994515296, 0.02099412628599713, 0.04439232074805806, 0.028563187975857048, 0.02415812112421038, 0.035721140072470715, 0.053612591112933816, 0.015580919327124234, 0.04112498639451881, 0.018037358231301752, 0.015588529453042056, 0.07908895611763, 0.03297840740772025, 0.0261280051387486, 0.058774575816407326, 0.051277417223900564, 0.008987208223721434, 0.07442678249771557, 0.019291407774172483, 0.027804398954275156, 0.039838751582729245, 0.05188341192420452, 0.007360581394975946, 0.1643871314703457, 0.03386754437439865, 0.05734251616823097, 0.06393091062143927, 0.015307726627666385, 0.01815283066412855, 4.660329799498282, 35.84155567230717, 51.830022950326246, 36.02398118665142, 33.38928199583484, 37.6348711598304, 53.07884285526892, 39.088434865397794, 3.939406987159483, 0.040895500926360975, 0.3975341475057987, 0.5929833710674317, 0.3519336524749956, 0.02005258315963851, 0.09957020952095909, 0.07486936681333088, 0.2004009247907708, 0.397705230261049, 3.6212302023364655, 16.490148228983728, 37.220755161777625, 59.61792815116144, 71.65603130094468, 73.63830304914906, 74.83606153918852, 71.7365889395437, 68.75544640325731, 67.61692354756018, 68.17405700683594, 65.85948205763295, 68.11355836929815, 68.05966500313052, 72.02089801911386, 72.47698337801042, 72.69112909993818, 66.80224726277014, 67.33391669488722, 66.63990036133798, 65.73576658002793, 61.39552277903403, 62.84905902801022, 65.25290319996496, 68.77932579286637, 63.94964079703055, 59.87355686003163, 62.550849068549375, 42.51409569094258, 53.644570227592226, 43.73443526606406, 72.62065195268201, 58.82460132721932, 64.00752713603359, 62.28171171680574, 72.29195733224192, 67.57966103092318, 67.18809866136121, 59.67675193663567, 56.09482780579598, 48.96261738192651, 54.46380822889267, 61.01744159575432, 69.53025571761593, 70.93286391227477, 71.78768173340829, 66.21892021548364, 72.94487507112565, 70.44573691583449, 65.91466196121709, 68.97571886739424, 68.7833736788842, 67.91751046334544, 68.21939960602792, 65.4122337987346, 67.76232580984792, 66.8108372534475, 65.65422834888582, 51.039684972455426, 23.222776997473932, 2.444936637916873, 0.01702345810049484, 0.024094807787708217, 0.6989107160798965, 0.8794680177684754, 1.4989846295887426, 4.162485907154699, 4.460353639818007, 2.2906749671505344, 4.279042078602699, 0.44488374384180196, 0.09042229999097125, 6.621224139967273, 40.32264394144858, 51.93845687373992, 29.036215966747655, 22.54868434321496, 37.345819934721916, 28.440833514736546, 7.229161608603693, 0.08868088254765158, 0.006089811983157791, 0.034036167987412026, 0.09806302346048817, 0.07673437722147473, 0.059803205902778336, 0.07303906018815695, 0.06104183984139274, 0.030791234044778733, 0.019397610543115486, 0.04598938424380557, 0.06796808673008796, 0.04372127752210345, 0.06739290791653818, 0.027203812834716616, 0.03868449073765547, 0.07890503372876875, 0.04087625679770305, 0.013882172023577076, 0.025597935497400262, 0.06152881895222011, 0.027890055245088956, 0.019393395144312132, 0.012677070711018338, 0.10170390228590659, 0.09981154253886593, 0.04034322431130756, 0.07784401727539879, 0.020191386800199267, 0.04198154930265681, 0.031954751147197626, 0.005267847999705063, 0.06426869410901301, 0.03702475358882258, 0.04548995620420864, 0.03693177732789228, 0.022330832885458105, 0.0794117855689218, 0.06128563966241576, 0.015724280233224554, 0.07636426482349634, 0.0348542656208719, 0.032925367310282685, 0.02909450251008234, 0.05027989030725533, 0.01665536817463656, 0.03696282687146337, 0.03950745302943453, 0.05882921703760663, 0.04794562806285197, 0.02325938316062093, 0.08756391103229216, 0.023910287850266023, 0.05324280047188363, 0.023235663163265394, 0.07666965811363152, 0.029206228772959406, 0.03208172447498768, 0.0012166613399336537, 0.02204093755403113, 0.051885059013241724, 0.021366870195995417, 0.059233910644487034, 0.045029135165555824, 0.010828206563488612, 0.052522076444039424, 0.029502815882404967, 0.0375898813288058, 0.015375259193411518, 0.0393700321775771, 0.04550025625635059, 0.02178691428965859, 0.10548442361816283, 0.02127643734697373, 0.08878742239528126, 0.04521879172253032, 0.08268024607170975, 0.11639513976631627, 9.528132388668677, 47.117420704134055, 54.392460315458244, 32.333785910760206, 30.72310578438544, 54.29764093891267, 75.46469980670561, 33.50131273269653, 2.47166391341917, 0.0301986133244129, 0.3384340800825627, 0.230403226169367, 0.6384906485196084, 0.33236258813450414, 0.37163004879989936, 0.09722316892997873, 0.17893837404347238, 1.5807825951806962, 6.743406461131189, 23.739719890779067, 45.35504879490022, 65.69338144794588, 72.36019872849988, 75.42331880138767, 76.24824816180815, 72.90176822293189, 69.41000369287306, 71.0410350368869, 69.43307507422664, 67.79463829532747, 69.52971443053215, 67.5131925459831, 72.57536426667245, 73.73731151703866, 72.92811870574951, 70.75155627342963, 70.18864908526021, 68.13820654346098, 67.94572014962473, 63.0367640526064, 66.91408972586355, 69.00628982051727, 70.79708714638987, 68.4560832669658, 62.177007967425936, 63.44914636304302, 46.555427428214784, 52.398994122782064, 48.72683194375808, 73.28026909982005, 59.24714649877241, 67.91891467186713, 67.06255928162606, 75.40620157795568, 69.55342908059397, 68.25035495142784, 61.94088520542268, 57.24676908985261, 53.27981333578787, 56.691596815663004, 63.45871694626347, 68.15381757674679, 71.23632200302617, 73.74489738095191, 69.31247003616826, 71.54696587593325, 68.41642025978335, 66.68983997837191, 68.87343129804059, 68.53769994551136, 68.74097285732147, 68.88404523172687, 66.7913430736911, 66.91114794823432, 65.40283187743157, 65.47411311057307, 56.77379400499406, 32.35410574943789, 4.838342647398672, 0.28992766033737893, 0.018554423530135426, 2.4311872595740907, 2.2565182322455994, 3.6276055247552934, 5.485806330557793, 2.212375633178219, 0.456129179125832, 1.1203760100949196, 0.18045467655024222, 0.03323768986569297, 2.6641238312567435, 42.75808280514133, 59.61656316634148, 39.40992016946116, 22.42601025489069, 37.27844538227205, 37.95284594258955, 14.078375966318193, 0.24539414192399672, 0.05155743385154394, 0.062065076668776815, 0.03702471528442637, 0.009407613336318925, 0.046449190215958704, 0.04087521491812603, 0.05095764063298703, 0.06440083661507215, 0.07541817688052693, 0.045432947771323305, 0.09941174423382168, 0.06318137402676287, 0.06849458831692896, 0.028237022211655017, 0.07564449457511788, 0.06525131678509136, 0.018316371283764322, 0.015004460189131, 0.058702034950857206, 0.04362506453969306, 0.03247697987864095, 0.0362701723051648, 0.02456477017051751, 0.053390655441269766, 0.0855827616948274, 0.05262616481031141, 0.03545887753247254, 0.1016065095280928, 0.03969771862630883, 0.045952543075526917, 0.008897276204680244, 0.02985331068386234, 0.03396726603950224, 0.03047814731666398, 0.21670952709692143, 0.13527457992876732, 0.19987924955785277, 0.10215773277225033, 0.15122776340332725, 0.15922532296709477, 0.16225022113611623, 0.1857336505406326, 0.12695536302823213, 0.19134455510685522, 0.12422684129447707, 0.19327004049574176, 0.15538461776750703, 0.19567777823296287, 0.15333761551207112, 0.10444914005816945, 0.21166681462237913, 0.09719490794645202, 0.1291194771446528, 0.10369032996916965, 0.14771408581685636, 0.2245528425180143, 0.12638183130371955, 0.1060693164265925, 0.1616017430299713, 0.18810026467807833, 0.0954503495426428, 0.09185977971121188, 0.29199925401518423, 0.0976578165746985, 0.14720532682634171, 0.17924756712971196, 0.15433011306149347, 0.10771746266513102, 0.1297596815012155, 0.14068830878503863, 0.09102855899160908, 0.255719413680415, 0.16234463381190456, 0.1556944084023276, 0.10841741421890837, 0.2160900837231067, 0.16676649331085144, 8.418687043651458, 51.355474995028594, 68.34108721825385, 48.27075442960186, 45.37252295401789, 47.005695912145804, 66.69554310460245, 49.515985365836855, 6.316330952029075, 0.10405079732018133, 1.2985887763000306, 1.9212125794541453, 1.2875106546186632, 0.26581697346222016, 0.4554234895735018, 0.28070647449743363, 0.5984587546798491, 1.4624247075088563, 4.593024869118968, 18.501386680910667, 41.84335470199585, 63.94993889716364, 74.85393185769358, 78.51301685456308, 80.4636586096979, 74.1356360527777, 71.06837395698794, 72.23300410855201, 73.48466380949944, 73.06659406231296, 73.6372204749815, 74.17827221655077, 77.8552746003674, 76.76873883893414, 77.69197064061319, 72.38493319480651, 71.44925179020052, 70.428494176557, 69.22669564524006, 66.84819390696865, 67.37534476864722, 70.7358746374807, 72.50742881528794, 66.56198640023509, 64.94013732479465, 66.61697803005096, 52.95659042173817, 56.50935173034669, 50.23713665623819, 74.87582652799546, 67.8185647533786, 71.73566326018303, 69.7672688576483, 77.91360808957008, 72.25598919776179, 69.89673060755577, 62.89747676541729, 59.803475872162856, 55.43502630725984, 58.56293609065395, 65.19630339837843, 72.86732196807861, 72.82352478273454, 75.12270050664102, 70.84475963346421, 72.29535410481115, 70.41799006923553, 68.4822533207555, 70.77022675544985, 71.40852974307153, 72.54242420196533, 69.77409378174814, 66.92532339403706, 69.59181339510026, 68.56798064324164, 68.25686608591388, 54.79977492363223, 27.326596013961304, 3.724339753389359, 0.4281872252543127, 0.12769516647583054, 2.2901113715864, 2.390056060206506, 5.939231832181254, 12.27123216275246, 11.931939298106778, 9.180459380149841, 11.491762092036586, 0.9239112297373434, 0.2216092415995175, 10.344609041367809, 50.262180989788426, 63.45013087795627, 41.40878746586461, 33.093382312405495, 50.55451131636097, 44.786591452936975, 12.6676082611084, 0.19101757345901382, 0.12612174445342633, 0.17530385374782548, 0.1220935468952502, 0.18243593314001638, 0.17427536538772045, 0.08339475329604842, 0.19610835028992546, 0.13039306767525213, 0.22739003382382855, 0.13405885967996814, 0.14311815581975446, 0.24407610297203067, 0.08407378298861366, 0.1675694607078068, 0.09821280131056424, 0.14029061722178615, 0.09633665198400136, 0.08308877011821156, 0.27280449206309937, 0.14911794193810032, 0.09259030583404726, 0.17751983967759918, 0.12913964057881988, 0.15774012363005072, 0.16607653920448598, 0.12785454340759786, 0.12234653211048535, 0.2145577699787194, 0.14315342650778834, 0.14998276327406207, 0.11733447081379353, 0.09493305633265166, 0.0970783400078935, 0.11959453744273033], [0.01569721530446963, 0.06715964180447402, 0.03224421938460681, 0.051514322253605055, 0.030434715877016707, 0.01884563078713273, 0.011974521161567782, 0.028215713476041154, 0.0685383549200431, 0.033029352254684896, 0.06464481263631774, 0.01871047947075098, 0.02729835957589169, 0.10017905023790176, 0.08201271535888796, 0.046393238984408884, 0.019398663914011374, 0.046615714748059554, 0.01877644538669096, 0.05608536971492633, 0.0370633605897667, 0.042644675009913986, 0.05671317493843456, 0.024979968758059606, 0.023768467738503413, 0.03043482695976573, 0.013020336515300218, 0.05950111828203644, 0.0762830748252811, 0.05221669464522312, 0.05013989923041194, 0.021413572831079367, 0.027581737414302848, 0.11938888113945724, 0.02493123790519613, 0.03269518470211375, 0.009068734343013456, 0.07157724185456192, 0.039104578881374294, 0.037136165755650694, 0.08706075980538323, 0.02104662437622826, 0.03805755119350168, 0.1422543150763358, 2.1424937055956934, 33.75395651786558, 49.87899680291453, 49.07459712797596, 31.177769284094538, 27.759117734047678, 41.96422253885577, 53.46367835998536, 14.981293812874826, 0.21250983309601584, 0.23733528000452828, 0.12784496730854436, 0.2892970780451452, 0.2907560771751789, 0.09512222642379423, 0.1930819965538479, 0.22619642287252412, 0.20704243211976944, 0.15166034261065145, 3.929757466239314, 18.79753543484596, 43.453260160261586, 66.23904197446763, 74.39237871477681, 76.35092796817904, 73.38678498421946, 70.8865564100204, 70.25511757020028, 68.2718966084142, 69.17390838746103, 69.46896476130333, 71.40261480885168, 71.46450981017082, 70.80770108007616, 72.50897422913583, 75.2228464618806, 74.39876433341735, 74.47188515816966, 69.97022797984462, 71.05225301557972, 70.01013417397776, 71.83169857148202, 70.36117845965971, 74.37826602689682, 48.68925563750729, 34.39114162998815, 45.40048553097633, 39.57948030964021, 68.51989238492905, 66.25761047486337, 68.13463718660417, 71.51479459577992, 67.96730887505316, 72.39043235778809, 68.73429698328819, 71.44522743840372, 65.80738513700425, 61.45663722868889, 64.5708736296623, 66.57316515522619, 66.95769079269903, 71.12580530105099, 70.99760655433901, 70.19584271215624, 65.41626207290157, 68.30304022758239, 70.83166676182901, 69.4372170971286, 67.70447869454661, 65.42244372829315, 66.7368221282959, 70.2213381182763, 67.41277986957182, 55.70641902185256, 33.393416173996464, 8.520272508744272, 0.1307231596400661, 0.10422920387598777, 0.38550635258997645, 0.30069910170089814, 0.8942426669020808, 3.0993196272080947, 4.441102156716009, 5.27255981199203, 1.9992427407733857, 0.17217732635476898, 0.08145822091929375, 0.608821717962142, 16.017418292260942, 45.8857572463251, 31.97232969345585, 27.46888783670241, 29.41913147126475, 41.36400968797746, 29.81046634335672, 4.922602022847822, 0.038566700888857726, 0.036631574283444115, 0.018925685060000228, 0.049973512594137466, 0.08358259805508199, 0.019941569358531027, 0.05785459231945777, 0.0315648372915964, 0.044548097066581256, 0.06997985660188621, 0.12203926956581494, 0.07663946658853563, 0.004840523676736461, 0.03644438836002543, 0.08045093021205357, 0.014986726211293813, 0.019811700218387192, 0.035795565514314565, 0.04197778398050897, 0.06035994881043031, 0.019029947711274992, 0.06372575227531695, 0.03930139069956157, 0.02777494287358657, 0.02936024500447656, 0.028000437023658908, 0.014299881464291005, 0.022226911143309647, 0.041529664679640726, 0.0532979358197941, 0.049526274294382146, 0.011094239213684154, 0.011063287346323412, 0.04027484330318628, 0.027511293714445446, 0.013661176724840077, 0.006822558803363674, 0.06339010234261233, 0.026395930983727018, 0.010592339582921518, 0.018000689432806066, 0.015914947068649196, 0.023709297022451798, 0.05884571857149563, 0.07313606224112934, 0.027374495309026494, 0.04955372322470911, 0.02741491027747191, 0.06990685608358153, 0.040111900232131445, 0.0691362482405478, 0.029285522703562054, 0.03674130105683881, 0.048217723341358286, 0.03838902211657936, 0.011585821555326543, 0.03160591684131613, 0.030577143113459312, 0.043864187393938346, 0.07065697873552, 0.02117630774005046, 0.02568396525607715, 0.05424902631690907, 0.07521253589901232, 0.058190249913041635, 0.06145970633013114, 0.03339489110775533, 0.017039235681295395, 0.04334046670626249, 0.04649790957750333, 0.05748395515125125, 0.010087122791446745, 0.01755488371746915, 0.033083859410497456, 0.03467757127157623, 0.08427250619617202, 0.03340686889245145, 0.013936944437333414, 0.09359876099493235, 0.09384496633203761, 5.320521083570296, 45.60995971002887, 55.24562289637905, 44.18579416890299, 24.234530810386907, 35.864034775764715, 71.3510670200471, 59.23110792713781, 8.966013596903894, 0.1779711420737928, 0.08436341018926713, 0.24586911643705062, 0.5126098387183682, 0.4652955437139158, 0.1711763711946626, 0.30385075677787104, 0.14620477003195595, 0.253981267432532, 0.8115923212420556, 6.401161522634569, 25.481038478112993, 52.28588473412299, 71.56999018884474, 75.56249233984178, 77.58146178337836, 73.28805108224192, 72.02667959274785, 71.2812880546816, 69.2010590337938, 71.17007317081575, 72.62149918463923, 75.00211115806334, 71.20578242886451, 74.03700413242464, 74.00298933829032, 76.07460483427971, 74.38055669107746, 72.97686592225106, 67.81093182102327, 71.48219185490763, 66.24247012599822, 70.16029819365471, 68.85522365570068, 71.62377372864755, 54.97268476793843, 38.965668601374475, 47.806679202664284, 43.19897290199034, 70.10621655371882, 67.4968990202873, 70.52552576987975, 70.30300971000426, 70.5975797099452, 72.72941927756034, 70.53661038798671, 70.1117157167004, 66.84109441695675, 60.45430298774474, 64.08404473335513, 64.9758191262522, 68.61873611327141, 72.89244867140248, 73.46768779139366, 72.05696029047813, 70.46265017601752, 69.5765475303896, 69.06447425965341, 69.91394196787189, 69.97118503816667, 67.33470901366204, 67.63873192571825, 67.85134007853847, 69.6042473085465, 60.0761825807633, 42.95300499085457, 13.962271848032552, 1.0975437707478002, 0.09316267310491494, 0.9223494522513883, 1.3960479079715669, 4.15438425156378, 3.972791995733015, 4.99998793486626, 1.5314486166161876, 0.37890316497895027, 0.7517841434286487, 0.13547673521022643, 0.23518321645115656, 10.480585848131488, 59.75148877789898, 50.84224854746173, 36.79979070540398, 29.60800143980211, 41.26844506109915, 40.30861362334221, 9.837226925357696, 0.08913148014295487, 0.02043834290347032, 0.04594940594547699, 0.030599440102495497, 0.026393954476882375, 0.031054588260069012, 0.02921415969819552, 0.034591221671190955, 0.023384854956079396, 0.09409804347782366, 0.05589637582400634, 0.033772423067280365, 0.01993520699831988, 0.0430540226009344, 0.04490783280362526, 0.01901224724978449, 0.04441902657309848, 0.0458024894337981, 0.031228990091251272, 0.04539295032079663, 0.05328168326448049, 0.04405426529927119, 0.05612725174174674, 0.051020547942889315, 0.00802140835965533, 0.04293109996304397, 0.028622148017729485, 0.05982782796866471, 0.04325613957799731, 0.0449833499207612, 0.04042444112260015, 0.016642388729979436, 0.04694635063529976, 0.05823046186818712, 0.01512441136348512, 0.05719179603000803, 0.06775077056860732, 0.2070536629687394, 0.09529595984326256, 0.06853309955688254, 0.11323965424972196, 0.10138311828937262, 0.14340689435841578, 0.07705165253531548, 0.20201148675574412, 0.09837371041818012, 0.14723555665583382, 0.12270842438503621, 0.15301688514169187, 0.17330684639032812, 0.17626307243781705, 0.10815301429360144, 0.16529485373006714, 0.2909513989523534, 0.11998512737092473, 0.2247503706284108, 0.12667974757571376, 0.2232222856893655, 0.1558160631647033, 0.13344611191461164, 0.1519193569378507, 0.18768711346051387, 0.13562584656380838, 0.19114071443196268, 0.15626731959562148, 0.12752170884801498, 0.1186541032286421, 0.08733273634026129, 0.15398293733596802, 0.24415291094731903, 0.14812955061995214, 0.13204509031868752, 0.10567132608904954, 0.15549767702337236, 0.1172151602804661, 0.1977497855982473, 0.1630874326632869, 0.09639020919078782, 0.16504710089535485, 0.3183348747270723, 4.039674290726262, 48.15116528541812, 67.46661832255703, 62.14586827062792, 42.294305678336855, 36.24198652082874, 51.91664457321168, 65.9383923007596, 20.067061531928278, 0.5573330098582853, 0.7950349548651326, 2.4172204348348805, 1.8222498316918652, 0.6602604771333357, 0.2668025302550485, 0.522676908200787, 0.39447843728046267, 0.45671771851278126, 0.6173219844218224, 5.402366240178385, 20.613665388476466, 48.595412931134625, 71.08914682942053, 78.80633169604887, 82.74410109366141, 77.60612564702188, 75.83778781275596, 74.65621302204748, 72.01404171605265, 74.07143469779723, 74.55916573924404, 74.50124017653927, 73.21358880689068, 73.7102863865514, 76.71970921178018, 80.39981811277329, 78.76018893334174, 77.41358434000324, 74.10573974732431, 74.85697561694731, 72.3795360134494, 74.16775241974862, 73.8220739364624, 72.2388719743298, 57.09757389560823, 42.10316073509955, 48.95260749324676, 50.82372319313788, 64.98966117059031, 70.1963996887207, 70.51870869052026, 73.25890002712127, 73.479031285932, 75.38600137156826, 75.16972972500709, 75.52461008871757, 70.65691732591199, 68.08599195172711, 69.9237008248606, 71.61725474942115, 71.7597544577814, 75.51550234517744, 73.48872738499796, 74.99627467124694, 68.92072723757836, 69.3225819064725, 68.61872042379072, 69.53672762840026, 68.39663582463419, 67.34803722750756, 67.19893224777715, 70.74407239114085, 70.5318800095589, 57.846166087735085, 37.26695676003733, 11.522019255545832, 0.5214072860056355, 0.1597987397784187, 0.5535894139639793, 0.5422763790815108, 7.074311827459644, 9.43036437034607, 15.367336427011798, 10.6232669661122, 8.78351257693383, 2.802113304215093, 0.20831346391670166, 0.6913707561550603, 22.122579620730495, 57.53942105077929, 42.08277225494385, 40.85584702030305, 40.55309887855284, 54.03011175893969, 44.45140923223188, 8.285914813318561, 0.22424297527440135, 0.13050465604230282, 0.12258284725248815, 0.15086866734970003, 0.22127951735690718, 0.15095223222048054, 0.15141942328022373, 0.11597809682209646, 0.2158051603023083, 0.2229170456168152, 0.25860594104855295, 0.11681697842094207, 0.12010475200030113, 0.1813475673477496, 0.1649117331591345, 0.14396613854314053, 0.18497286394478815, 0.1855725575719149, 0.1889598612943965, 0.12234833241710741, 0.14460612839508444, 0.15432116515453786, 0.2042188465354904, 0.23827847213514392, 0.1695668357875078, 0.17151623844139038, 0.09835768385880417, 0.1856318834207712, 0.15003399923443794, 0.143783564469026, 0.15052173677231037, 0.1335487983399822, 0.18065871640799508, 0.12182080427244787, 0.09483135816070343, 0.15952259572523256], [0.04342499684782759, 0.04569704509190014, 0.022960287113223347, 0.05918422601215782, 0.01081206317570421, 0.015414815185771836, 0.04552126621767398, 0.05012038697098052, 0.0672970013692975, 0.05000025289313448, 0.0966701377183199, 0.028985942105552363, 0.028883985378929687, 0.026410233845273336, 0.0630018719652247, 0.026238400323857224, 0.0063724294793041005, 0.023222417503054586, 0.054538527113055034, 0.012978439166721319, 0.02996967752434073, 0.0434757731554489, 0.04319396771250233, 0.006141990710485486, 0.01225657845591946, 0.04082371465741627, 0.006901244651676426, 0.010439263724331415, 0.0499265207608621, 0.06831760668466169, 0.03580180913089745, 0.03962638434923945, 0.0875400780369678, 0.02118873751662191, 0.125058728510574, 0.02883592293778014, 0.0767115171578142, 0.02267546711429473, 0.011375533292941269, 0.0743083606263803, 0.016678243560055574, 0.012506919710205929, 0.07920511036870942, 0.07514061556468088, 0.0995488050243547, 0.9728252695452784, 19.07299368612228, 43.98839696761101, 51.34834804842549, 43.878107763105824, 31.787382095090805, 33.60429456157069, 60.16425155824231, 35.938822607840265, 2.2494153101598067, 0.1253104573416133, 0.51188490503738, 0.43269130130929334, 0.2829087627751212, 0.034910680335615916, 0.1323253406031478, 0.15674007245369498, 0.1353285738056706, 0.046133240234226956, 0.6595529183264702, 6.827865387162855, 25.718992986986716, 53.45980698062528, 67.21585335270052, 74.2412027235954, 72.88888715928601, 73.078886770433, 73.55498406194872, 70.65096316799041, 72.65103463203677, 72.13265419006348, 71.3922126831547, 70.99867343902588, 76.5369502959713, 74.03770231431531, 72.66863038462978, 69.28192261726626, 71.64757467085316, 68.00766221938595, 69.65116670054775, 70.8601902377221, 66.48814385937106, 59.377494704338815, 38.29619061562323, 30.04346101514755, 46.739523872252434, 32.53073988422271, 61.47840246077507, 80.15565841428696, 61.84517152847783, 80.20578630508916, 66.7462593509305, 68.3120067657963, 75.25194260381883, 70.60576177412464, 69.7123948989376, 68.16051698500111, 64.73001987703385, 64.87898365143808, 70.07355105492377, 72.41988151304184, 73.02642114700811, 70.37562062663417, 71.430142002721, 69.24873152086812, 69.8702153851909, 73.00658964341687, 70.54704389264508, 69.33627882311421, 65.5197302756771, 60.88549306315761, 44.379202319729714, 19.778581011679865, 3.328145309802025, 0.038933660835027695, 0.20333758495267362, 0.6214759582954069, 0.23937437623258562, 2.372424515985674, 3.830313615260586, 2.160705270305757, 3.896731599684685, 1.2214868683968823, 0.14494237970680962, 0.16616022664933436, 3.360516630834149, 33.27078327055901, 45.3855569901005, 23.686179537926954, 25.896272351664884, 34.73268201274257, 43.28588478026852, 23.87837959874061, 2.070344893201705, 0.11352324467753211, 0.031932475225579356, 0.06719892679323113, 0.08963424832590165, 0.055484657190860286, 0.031633605174119436, 0.12129007388026485, 0.025497645012012897, 0.019456448010920037, 0.016605384768016877, 0.01201013467394777, 0.0035329839597726545, 0.05696586137937923, 0.055578200356854554, 0.01985101202022164, 0.04353363960680943, 0.044379163187958544, 0.055472418936269904, 0.03062777961003444, 0.0178253912787524, 0.04850920447478852, 0.08153050897582885, 0.058698097258926406, 0.026594056642704436, 0.10310398159368385, 0.03914243894659224, 0.025480930888724905, 0.011744445805708248, 0.014793562886845923, 0.019403040191278826, 0.10811861694580126, 0.01857723954374031, 0.026092127326034734, 0.007455142979104553, 0.026087076891393914, 0.05583751345834425, 0.04379148948036375, 0.021818277929278634, 0.028347507412094745, 0.01850352273322642, 0.058046639070756016, 0.04680747804682582, 0.05438945789430892, 0.041076339811327, 0.07075806403712881, 0.018289912522079486, 0.03343705658710772, 0.02032140532748834, 0.058743641186024875, 0.025241334975186377, 0.01982918042959946, 0.052705332336406556, 0.04666320836892532, 0.07000796436782807, 0.12144044927892186, 0.019195123928629102, 0.05557230147983759, 0.022771793094673948, 0.00852352871950115, 0.027638780321144772, 0.04277432773021921, 0.059981555001990455, 0.043731060464896505, 0.018691892262488123, 0.03585833109795086, 0.04875399637967349, 0.06610624792595064, 0.04914706077186331, 0.07981513852193471, 0.0337406802141378, 0.05248367628683487, 0.0723213507162948, 0.029755460188513803, 0.06998059204629353, 0.01768000885814188, 0.08222993958981768, 0.09782840903367727, 0.018473877045776577, 0.01468849297042095, 0.027935746644112854, 0.03575752158799479, 0.042900096384748336, 2.6338573521183384, 28.65001939958142, 55.35902646280105, 44.091680818988436, 25.96767713946681, 25.6882494495761, 53.544090870888006, 80.66318173562327, 26.694596275206536, 0.3665037254893011, 0.16242590041891222, 0.40350914301891483, 0.4217191755531296, 0.4643702933624868, 0.7563680458453395, 1.4378826824888107, 0.8876121452739163, 0.3793241149715839, 0.16123872460617175, 1.5148976853778287, 10.756890350772489, 34.302947136663626, 59.70622462611045, 72.5665860022268, 73.67718158229705, 76.05487531231296, 75.0069356733753, 73.78721975511121, 70.66335001299458, 73.2736873626709, 72.2690663799163, 72.89223686341317, 69.8005776251516, 75.4363489151001, 75.19589193405645, 74.61595381459883, 74.48958289238715, 76.2812666739187, 71.39554669780117, 73.42353759273406, 71.08280827922206, 70.25165019496795, 66.41917290226107, 46.21927245970696, 35.137964833167295, 52.373051566462365, 43.34987824962985, 62.13727827995055, 77.25159045188659, 66.08442214227492, 83.15164319930538, 67.24061135322818, 73.8228976341986, 75.14422647414669, 73.60021683477586, 73.29033390168222, 71.00895004887735, 67.75793275525494, 65.91081019370787, 69.69210055566603, 73.65470640120968, 74.87292397406794, 76.00633990380072, 71.81443229798349, 71.28941520567864, 71.24033851008262, 75.83895667906731, 71.0023840012089, 68.95940965221774, 67.9917452412267, 67.51197661122968, 50.09855931805026, 26.461509427716656, 5.679498853222017, 0.4456676662929597, 0.8338395758501945, 2.027141824364662, 2.217050608127348, 6.840688105552428, 5.0470789305625425, 2.882246591391102, 1.4026187360286715, 0.7263079814372525, 0.3835321133655887, 0.08422380598682551, 0.0569375774132148, 31.32147316009768, 65.15477334299396, 35.43744956293414, 21.85436598716244, 34.717471061214326, 48.23247209672005, 32.958868549716094, 4.58600971006578, 0.05706761700792178, 0.044481684904425375, 0.00882768765046832, 0.05968755726972896, 0.013142732467742698, 0.019316211785940875, 0.051492121025559404, 0.0733940270278723, 0.021917957459546385, 0.011255630956692322, 0.03253640531892738, 0.024560918663478187, 0.07445941784328992, 0.06493489948972579, 0.034265695590405695, 0.011886567564591045, 0.03393178467728919, 0.03422287893631766, 0.017033382769553893, 0.038129559627944426, 0.013940122744609273, 0.01711329340093559, 0.03482247297201426, 0.05744776515770824, 0.04700718184692725, 0.016391454715161555, 0.07680608305118738, 0.01683782733556244, 0.0462907977071741, 0.09336012460651899, 0.03992988157176203, 0.04906999998755994, 0.052804088730725555, 0.045988675612475605, 0.05662947983270692, 0.015783790900792568, 0.014336683370563534, 0.19998211984432515, 0.1392454281449318, 0.10999517229896401, 0.24125046427211455, 0.10015302623111395, 0.1336745440118736, 0.11108079549646187, 0.16853479277943412, 0.0927930356814496, 0.09883593722817399, 0.20435756973681912, 0.169524563055846, 0.1079121256066907, 0.14475612841065855, 0.17714234219203073, 0.1103415742756859, 0.20217922936764457, 0.17763777125266292, 0.09856167009040233, 0.1565327537396262, 0.07616049309651698, 0.10171042169414221, 0.23681072428101496, 0.1264085754331562, 0.12738957400283507, 0.1313675008714199, 0.1074096791806721, 0.09472320952843274, 0.2103311709699131, 0.23677586728046018, 0.13315349697105347, 0.14085605139693907, 0.19872087865106522, 0.14452824789670207, 0.221715712499234, 0.14436583725675461, 0.18106071338538202, 0.131746469245803, 0.1360059334265609, 0.20306317225819637, 0.09523168506641543, 0.07745050089133364, 0.1284699878024478, 0.2135396850926261, 0.21772189696709957, 1.7088365819185012, 31.75340456347312, 67.42033435452369, 64.67896238450082, 57.70811042478008, 40.126811765855365, 42.77554519714848, 76.37117524300852, 44.89743371163645, 3.135505943529068, 0.38105378828702435, 1.7367995265991458, 1.8733780494620724, 1.0040157120073996, 0.49696267672604133, 0.4617311204633405, 0.6484144902037037, 0.29326878427978487, 0.2556925086725143, 1.3700880687082968, 8.327704725726958, 29.713844637716974, 56.42664463289323, 71.17627836042836, 74.17555793639153, 78.1042274352043, 77.93281985867408, 79.5455494234639, 73.82583941182783, 76.86009084024738, 73.76195184646114, 72.00011730194092, 69.61124481693392, 76.60403067065825, 74.63626384735107, 76.21205252985801, 73.93054316120764, 77.46725020870086, 71.27914644056752, 73.27393839436193, 70.69625085399997, 68.15751244944911, 65.28201895375406, 54.42084258602512, 39.266769347652314, 57.05169393170265, 47.575482937597464, 63.23098805642898, 80.79084703999182, 66.89008482040899, 79.70639797949022, 69.78981464139878, 74.94613109096404, 77.36400558102515, 76.79770162028652, 74.08644953081685, 74.10843833800286, 68.61675139396422, 68.52885107840261, 73.48242021376088, 75.56865046101233, 77.2839500058082, 75.80771107827464, 76.35397957217309, 72.62749256626253, 71.17805127174624, 74.69129470086868, 74.14388087487991, 70.51488830197242, 67.88386437200731, 65.36762860513502, 47.845487133149184, 23.707203442050567, 4.837903832235645, 0.291098763625468, 0.4965613998713032, 0.9986606348426113, 1.7043615252740922, 10.397789516756612, 9.863134180345844, 10.781160996806237, 7.1867284274870356, 7.574307139842742, 1.1980769374678213, 0.4367942537271208, 4.576949034967731, 43.43784132311421, 57.62337546194754, 34.34282587420556, 36.40038359549738, 47.4704340196425, 56.63106287679365, 34.153779399010446, 3.604598862509574, 0.23035727621566868, 0.11567940680129875, 0.1544024624050625, 0.19918952527786457, 0.12574590937865357, 0.10750677316419541, 0.17078653969351323, 0.1065749497783761, 0.22160355722711933, 0.0683204718534985, 0.13097422197461128, 0.14910098075145675, 0.24618773240475889, 0.15247113942619295, 0.23863398289728552, 0.10463202822833292, 0.13421900269965972, 0.1386882677193611, 0.11038190114402002, 0.10082113150987895, 0.10261767664022985, 0.24538873334325131, 0.14182365108882228, 0.1696556253779319, 0.2666306814118739, 0.22044405251020388, 0.08490377030665837, 0.0834795132639908, 0.12181734921590937, 0.16637350552745406, 0.1890256376035752, 0.17337101391486584, 0.12413645824117046, 0.1293990839152567, 0.11764932528979356, 0.20374669122599787, 0.1701114323711203], [0.044045259935721275, 0.042572501866567525, 0.03057863890013147, 0.009093001135624945, 0.027371821662170753, 0.015290936853195873, 0.0630717583361172, 0.023065951705399542, 0.04750819568852744, 0.07190282922238111, 0.16155389317822072, 0.03544706828711975, 0.054590781970370206, 0.021665510421078053, 0.05147309140152028, 0.0212401726598581, 0.08422546073674195, 0.017923988709827105, 0.055987475169522155, 0.058380408257606535, 0.04971071762303191, 0.07127598543921787, 0.06375360723224378, 0.004977618462421121, 0.025061932505078377, 0.024671583894580126, 0.03796307340023979, 0.03776108282768438, 0.05227063489597171, 0.0739984167739749, 0.02150295613964479, 0.013431130097277704, 0.07554288833372055, 0.06916294640470898, 0.0328522595396686, 0.08170632615445123, 0.0559880382441465, 0.021711753403407433, 0.004141995610083424, 0.062011010013520725, 0.057166174219380465, 0.11084161518562226, 0.026768132886518876, 0.03693117594887172, 0.05764407135786549, 0.043318426356680935, 0.1292508918671839, 12.751677401604192, 45.19703611250847, 53.20422141782699, 59.320016291833696, 35.59425023294265, 24.593355117305634, 52.901563490590746, 59.1693070627028, 11.839832240535367, 0.034969251587866776, 0.4695221427227221, 1.329491537424826, 1.1169022610110622, 3.36352655964513, 1.0478703845893185, 0.6439312210967464, 0.2907498871847507, 0.012183117327250302, 0.1718334294855595, 0.8616260751601189, 9.19156753247784, 25.856450488490445, 48.31306111428046, 60.75125386638027, 67.73624204820203, 71.57301041387743, 70.22612340988653, 69.94692125628072, 71.20735922167378, 72.23770310801845, 74.6740205826298, 74.32517282424435, 77.61784568909677, 78.01577014307823, 83.54646113611038, 76.5132042669481, 77.05960612143241, 77.16252911475398, 79.38728178701093, 76.6686164179156, 61.305390634844386, 51.741220489625015, 37.70524240309192, 34.086836307279526, 32.761781215667725, 52.50443135538409, 74.7426228369436, 66.9008791831232, 74.507994497976, 83.67269085299584, 66.99048180733958, 71.52422397367417, 78.40108809932586, 72.70801098115983, 73.80592946083316, 72.49055477880663, 76.30650320360738, 73.67477324701125, 72.46025839159566, 72.00874651632002, 71.74946215844923, 65.18729371409263, 59.58457623758624, 54.22871705024473, 50.746605473179976, 43.7887797048015, 35.873550445802756, 30.83799396791766, 19.83563384702129, 6.311695200781669, 0.5430506181813056, 0.03590856348314593, 0.15706235032168128, 0.8885737388364731, 3.521840774243878, 4.500353970835286, 7.523896838388136, 2.4327682199016696, 2.1555919704898714, 0.9809784675317427, 0.41627995129073825, 0.2409833906999519, 14.268302033024451, 41.84399404833394, 34.00897725935906, 19.641753050588793, 30.87587033548663, 41.0886122334388, 41.96703095589915, 14.781317653194552, 0.29395670059227175, 0.06096875505341638, 0.057924792786399205, 0.12066128423377392, 0.08136542468902566, 0.05829602367274704, 0.044114112087915984, 0.05806428590609182, 0.07887220686121334, 0.035442310881109974, 0.01958889503692908, 0.033076248326969725, 0.08229788392782211, 0.04283230526432876, 0.023757298176567403, 0.07276438702378543, 0.011675905834342684, 0.08222367299059707, 0.0375428282084965, 0.06602625302489727, 0.02602392060291623, 0.02487290414020179, 0.014801021710398697, 0.056067784166624474, 0.04045187473116864, 0.00467226778592674, 0.08702008053660394, 0.03468081948437518, 0.04430721221011012, 0.03243294897519293, 0.041352449390556545, 0.03460548239790144, 0.03444966777498203, 0.09001429688425795, 0.06901569664478302, 0.03779297123753256, 0.06430302250890002, 0.09317905206473605, 0.039032773460231485, 0.011632772211375977, 0.029995736005085132, 0.061347202488010934, 0.08037122642441143, 0.02482278283775574, 0.06075904997546346, 0.025309859624793454, 0.019054933668925397, 0.08079707937976045, 0.03845374122442257, 0.042117380522071354, 0.02928793779574335, 0.03005497375383012, 0.061860439262443015, 0.0261867985564975, 0.025649018240191286, 0.10433984229401236, 0.046322169007673386, 0.038162555034843185, 0.047472231690922094, 0.05080831477478628, 0.017933541826242884, 0.032221788330183875, 0.020782965640988083, 0.025226193247362975, 0.026771702856246023, 0.03645855332574537, 0.0518925705053393, 0.027209332498211055, 0.07453866197817749, 0.005675706028517697, 0.03167534930511348, 0.05250313108967197, 0.010776394121949712, 0.0323539997841562, 0.034286939208545995, 0.011113099340770033, 0.02678016238214989, 0.031086852053000085, 0.05468490736318692, 0.017397948690960487, 0.053694826821165706, 0.04307461504433905, 0.10052775813927574, 0.03929783222115329, 0.13329009044795267, 0.5575407116163162, 20.325086808973744, 57.714931426509736, 53.495241672761985, 45.72544997738254, 24.35625764631456, 42.4879805503353, 80.02757733868015, 54.985303032782774, 5.2869480463766285, 0.02152011267870905, 0.4775939208845939, 0.1559452409104955, 1.228775122473317, 1.6883953949136121, 2.513536931045594, 2.6319067084020187, 0.875314901913366, 0.18037043752208834, 0.1382939009777, 2.5733410639147607, 14.100746224003455, 32.95464807941068, 53.76485363129647, 65.1010957071858, 69.23494046734226, 71.28684997558594, 72.08861381776872, 73.08785330864691, 73.96784490154636, 74.70710185266311, 77.20661655549081, 76.16377599777715, 77.7569329354071, 75.39877260884931, 77.17433544897264, 73.07003005858391, 73.42973493760633, 71.84334016615345, 73.49315181855233, 71.6720659502091, 60.70591126718829, 55.786353003594186, 36.20191950951853, 40.291614071015395, 39.089533129046046, 53.36385011672974, 77.68245497057515, 68.46249241982737, 74.17304761948125, 79.1611885255383, 65.29874394016882, 72.72217858222224, 75.36487548582016, 72.93278632625457, 73.51016706035983, 71.76621067908503, 74.30159153476839, 75.74956586284023, 72.65930298836001, 72.88639253185642, 72.98008226579236, 69.50023389631703, 64.9497667435677, 60.04481538649529, 55.51506227062595, 50.12081484640799, 44.35253412492814, 38.21348744053995, 25.64338145717498, 10.696563316929726, 1.8700430542230608, 0.08267733493759748, 0.9957443526194942, 3.6557536788525122, 3.5500095207845015, 4.454609818996922, 5.9914542686554695, 3.2502695918083195, 1.3813933201374546, 0.24007032114651897, 0.2088053230076067, 0.2566319776158179, 9.228488802909851, 51.629636902962964, 55.20126088973015, 22.990254971288866, 21.76769925702003, 37.49801181977795, 52.101227391150694, 22.73878005243117, 1.1513171369029631, 0.137370795672459, 0.010496452187878952, 0.08921051743410288, 0.07219625621913903, 0.05085181324712692, 0.019569183594637343, 0.043916656755872314, 0.02996673000105206, 0.07366326862886068, 0.03124340978120604, 0.058134857925676534, 0.01854559053636847, 0.06110424536370462, 0.03070829736609613, 0.06470428404187964, 0.027695828973646128, 0.06904929726114196, 0.04083378871362056, 0.022396300844247305, 0.07180042624954255, 0.043590414382877855, 0.037111769685701984, 0.08239087934095053, 0.013092513489086303, 0.02690817950473678, 0.03851284107734119, 0.08359362972119162, 0.04227870714760596, 0.00914687818411978, 0.026077090935300917, 0.01477870939960403, 0.02502703145446797, 0.10884153581554852, 0.05890146678974552, 0.06506210838955256, 0.032959994484460166, 0.018810308388163968, 0.029209940468952544, 0.13021781740169372, 0.09326247137881095, 0.11283579567867903, 0.18924620963873404, 0.08259439059803564, 0.17214443053930037, 0.12160150394324334, 0.14563585781762678, 0.1454162050879771, 0.08967265997442508, 0.28688114316713426, 0.1004270252381121, 0.19908308502166502, 0.10436657876256974, 0.09511571467643785, 0.1307557336986065, 0.29180399352504366, 0.08433678863389839, 0.14777646069565128, 0.17309856240547475, 0.14887051086031622, 0.14708403978616963, 0.09403055113169456, 0.09819515064478883, 0.09520215237693441, 0.15417835104369348, 0.16288135501165546, 0.17904680612827503, 0.1638978924001417, 0.3008937186771824, 0.08681727408040917, 0.10702835125548225, 0.2791117858742514, 0.19583104178309443, 0.1051473219488417, 0.1833134715355212, 0.11260263681892427, 0.06607549715667002, 0.0531492458145705, 0.18013884914257836, 0.11653365612390543, 0.21906092672819094, 0.24463519393917055, 0.20856792768163068, 0.13202874200238338, 0.23075792487830887, 0.42962811406581636, 20.32951516489829, 66.43647055472097, 70.34741094035488, 72.05202594880136, 49.991031462146395, 34.98281940337151, 65.01998893676266, 71.98493772937407, 15.731980550673702, 0.07966570541142456, 1.7481458403410453, 5.825248245270022, 4.777124254934249, 5.375593612270971, 3.1247333989989374, 2.2455959022045135, 0.5955729933996355, 0.22648808786705618, 0.3250200337459964, 1.9770067016924582, 11.589686024573542, 28.61128991649997, 51.058065199082904, 65.29707693284558, 69.31523138476958, 71.1558271223499, 71.83123573180168, 71.01701444195163, 70.70546842390492, 73.24233978025376, 75.88692726627474, 75.61571890308012, 77.38430776903706, 76.0660776015251, 82.87830891147738, 77.74429505871188, 81.22510048650926, 77.78284411276542, 80.86441501494377, 81.79246348719444, 73.6749928997409, 65.12439850837954, 46.49886685032999, 46.74609384229107, 50.462304238350164, 57.210004714227495, 75.48723774571573, 72.09378350165584, 76.22237620815154, 80.59944322032314, 69.44905481030865, 75.03534932290354, 80.55052341953402, 78.56859683990479, 80.57907827438848, 78.3003459438201, 80.62949642058342, 78.68135713761853, 76.03130186757734, 75.26706726320329, 75.25131502459126, 66.4617855318131, 62.14693907768496, 54.90814608912314, 51.92441086615286, 44.233807902182306, 38.62040588932653, 33.12993880241148, 21.687292629672637, 7.5640197434733, 1.0753257500548516, 0.12173588342604139, 0.8639506310705216, 5.4287530049200985, 8.274329112422082, 14.251828078300724, 20.77020522086851, 15.115615379425789, 10.733110981602824, 4.903855054609237, 1.1165520668991151, 0.6595918355930237, 18.451248984183035, 52.03994035720826, 44.877406089536606, 27.930342920364875, 41.033428407484486, 51.891262915826616, 59.39920110087241, 22.1242368221283, 0.6720647275928529, 0.31079957261681557, 0.14727530129734548, 0.27113150925405566, 0.1428606583466453, 0.13571960040398184, 0.09351125843222104, 0.20470713565666832, 0.2096288828479667, 0.20120963784715823, 0.11222400552322788, 0.17617697947688643, 0.14927849864527104, 0.22055446110185117, 0.16394816308973298, 0.17746638206224288, 0.19831050067178665, 0.30050543467364005, 0.1755161520334021, 0.11925054864296991, 0.2540421867442708, 0.13582176588956388, 0.13267058578710403, 0.16996305646194568, 0.10696573888943081, 0.05505296281508862, 0.168284711037432, 0.2192960544339111, 0.21867593690272302, 0.17230080440640452, 0.11044055283550294, 0.15365462269513838, 0.18639401833136238, 0.19206227223959663, 0.14262998927264445, 0.18880049968438764, 0.18519645436636864, 0.18027364997373474, 0.10030167793194134], [0.03967065657038362, 0.051219723142322995, 0.01962770888161275, 0.040409981213029356, 0.03526664692007246, 0.09402249954761037, 0.05041079941175638, 0.02765321916329765, 0.0582428073750869, 0.01658622490903062, 0.02794027230852554, 0.006572613041968115, 0.07209734660723517, 0.09999927238471086, 0.024676766479387883, 0.05399388456416707, 0.04963687440801052, 0.05173399796589248, 0.03890312457036588, 0.03736171736231735, 0.05210647757555689, 0.1276964841470603, 0.08308284059767762, 0.07843265625377817, 0.05131224358093835, 0.04730207973249978, 0.020201232945246082, 0.0977384243460913, 0.03349737835026557, 0.08890344641141354, 0.09755473178360732, 0.08345410212754242, 0.01901675567721888, 0.030554779091729756, 0.08249923481696075, 0.025004759363289324, 0.056288463454092705, 0.06209532182002741, 0.019055504404428988, 0.036191150335775274, 0.03733782307995904, 0.09741399377103775, 0.053119835699157375, 0.09987803897069347, 0.04541150880076232, 0.04834551829844714, 0.03893158856719252, 0.0460564514111367, 4.062656193010269, 36.42421591666437, 53.010777965668716, 45.85771229959304, 36.687783502763324, 29.06456489716807, 32.10077947185886, 59.107149262582105, 33.0627211447685, 3.3325354226173896, 0.2526462826156809, 1.951767843096487, 3.7326306633410917, 3.3751196149856817, 3.4176611515783497, 1.2463988219538045, 0.5813205710822537, 0.05891417235796971, 0.16489241242168412, 0.177291652728473, 0.8702111628747756, 5.764041129619845, 20.37859578286448, 31.57460528035318, 38.41805473450692, 35.23686739706224, 36.55677633900797, 40.524398896002005, 44.468589213586625, 45.38795355827578, 43.496453300599136, 45.157055393342056, 56.62522638997724, 58.072651586224964, 63.253118068941184, 58.67491975907357, 50.30417780722342, 42.78228775147469, 32.36578068425579, 22.12307187818712, 34.99887758685697, 72.04819771551317, 52.76690460020497, 58.13719418741042, 55.63381987233316, 81.38527439486596, 67.7883154346097, 69.95088285015476, 77.39701624839537, 81.59031237325361, 66.49755754778462, 73.78132051037204, 73.05135173182335, 74.87497929603823, 70.78264497941541, 70.81274524811776, 76.67406851245512, 78.20194936567738, 68.42130753301805, 54.15866744133734, 44.265547721616684, 31.92345499992371, 22.57777656278303, 18.45805037406183, 10.138671859618157, 5.436798276439791, 1.9922561414780158, 0.654951487818072, 0.05160586593011695, 0.19249813030323676, 0.1066847684823217, 1.67033790580688, 3.981951220381645, 1.939324736595154, 2.409804213431574, 3.621571203393321, 2.376247356014867, 0.624187664399224, 0.08254163778356968, 4.747495160948846, 30.482295790026267, 44.030056461211174, 22.831253851613692, 24.74947721727433, 38.790825028573316, 51.873380830211026, 34.19123411178589, 5.623679113003516, 0.05977682949554536, 0.01985419894598665, 0.036565859261299336, 0.04297341099910198, 0.012742911180060719, 0.03181137013128929, 0.046594938443553065, 0.05254841071643657, 0.03932911542154128, 0.061117870237437956, 0.0423990021039161, 0.06193908584874965, 0.026908574040017785, 0.05693974544204051, 0.051348556148549246, 0.03502381620027366, 0.10197220159874809, 0.06223129859614757, 0.06292754228437139, 0.0495012998280506, 0.025365136698969913, 0.07615146858076896, 0.06559582652464029, 0.04758682695307559, 0.06708420512657012, 0.0586226950549791, 0.03403865011228669, 0.020978844747127547, 0.019665335290013783, 0.11005163297898347, 0.059756930361712174, 0.04851960411836063, 0.031245794229870363, 0.09698216532987934, 0.05624450149855787, 0.03285987062319633, 0.03744079295786158, 0.05510577691658851, 0.04454911213308092, 0.0041165183985515715, 0.02769709876438062, 0.0668430176653689, 0.04657225841055474, 0.0634371133280858, 0.0054416106262755014, 0.04487053198259204, 0.07483032697270955, 0.08729503715350743, 0.037537197462253036, 0.043327764968477914, 0.05305307113655633, 0.1498441013597673, 0.04074059411763184, 0.08847593870614806, 0.056783038326689315, 0.04130394070319111, 0.03918317567196585, 0.031669898589532224, 0.04135198973780198, 0.04118671775945733, 0.06507517018866155, 0.11459332395104632, 0.02140659185486936, 0.07404422883184687, 0.09621706565902119, 0.07231806419909963, 0.03837624760044198, 0.06157089250102159, 0.04654194814183059, 0.05073649020144536, 0.051141432786901156, 0.05835386714146984, 0.12368275798977384, 0.06049332471804754, 0.02394204602516707, 0.04692251380953578, 0.010698990513300224, 0.08481949297410828, 0.01141771026361253, 0.06223188082297003, 0.05918343311115619, 0.04397537739526841, 0.04471732971949443, 0.025754451090770385, 0.18877889600492295, 0.06504391380135091, 0.1155403005560079, 0.0302377010455295, 10.37188716473118, 50.175837855185236, 62.6770866301752, 40.84548019593762, 20.79943080102244, 31.112814834040982, 65.1759345300736, 75.62610533929642, 25.206672606929658, 0.5820566896469362, 0.057942792022180174, 1.402297591970813, 0.6000097456478304, 1.7023386854317881, 2.7774053139071313, 1.618578063864862, 2.4441408870681642, 0.5129750481536312, 0.21986666736343216, 0.21100519044745356, 2.285707530475432, 11.007970090835325, 25.2785716133733, 39.87825901277604, 46.09517258982505, 45.25651493380147, 45.521773061444684, 49.060276554476836, 54.46338461291406, 54.515061839934326, 52.93839062413862, 56.36831114369055, 64.84451778473394, 70.1783646306684, 73.13549441675987, 68.91048985142862, 65.86091764511602, 57.36240056253249, 51.16645205405451, 39.14413252184468, 48.765886983563824, 72.31349114448794, 57.741564319979766, 64.93818398444884, 63.15004602555306, 80.39910424140193, 74.64792113150321, 75.98180940074306, 79.36354360272809, 81.80485817693895, 67.31783497718074, 79.06192902595767, 74.7090316587879, 79.6050282447569, 74.81743028087001, 73.88542805948566, 75.10290038201117, 79.7607934090399, 73.108045670294, 61.172685084804414, 50.67258250328803, 36.96423215250815, 30.1719186382909, 24.78682798724021, 14.600623865281383, 8.916809424277275, 4.847302811761057, 2.0325674429055183, 0.43707942229605495, 0.968596586777318, 2.5721025755328517, 3.7578701348074026, 4.344313260047667, 2.677175518005125, 1.5840022482218281, 2.028752079894466, 1.8474189456432097, 0.4896173950645232, 0.10096406053391196, 1.2717896723939528, 30.659345696049353, 63.5514025534353, 34.15615635533487, 16.45603145322492, 30.245092415040542, 53.5043062702302, 43.44318751365908, 10.579873784895867, 0.19846353439554093, 0.10220916025460729, 0.03858519808178948, 0.05173302503422864, 0.031526285832026796, 0.0231389828672212, 0.026206856653574976, 0.03360906630874642, 0.02551824703151661, 0.12111441758010658, 0.11530151095000968, 0.008519533570976028, 0.024752540235978462, 0.02260035219331903, 0.03543477257593505, 0.0267978111327055, 0.06014781906419705, 0.04325475678929398, 0.012102020217195876, 0.040153763106753754, 0.058818901663706194, 0.03840505250639493, 0.013609165100440865, 0.03901590420413883, 0.07021205019085638, 0.1010577607479307, 0.054622681871537244, 0.07179956823106735, 0.05007103558689837, 0.10155473730616993, 0.058747368203776504, 0.03027927472196039, 0.03877060285078422, 0.06590282093853721, 0.053247320390636885, 0.01175755931575212, 0.10335198723741117, 0.05105516745618755, 0.03246266169533615, 0.014053668466306502, 0.09087557123313028, 0.16906723920856753, 0.09970911658338963, 0.29066528043439316, 0.1604836683480009, 0.17277512008384352, 0.09753318939117656, 0.19769802869808292, 0.1430894581661109, 0.09520038271382933, 0.13422770545847956, 0.2660255332387263, 0.18297764923303358, 0.18425658705734438, 0.13118849676703254, 0.18584603563912455, 0.11623590073037533, 0.17331266865855263, 0.155911716902929, 0.17423813351460044, 0.20919282560146626, 0.18002088692399765, 0.1560674625779352, 0.24413084761509973, 0.16781312263300344, 0.17567503866889786, 0.11371342600473475, 0.20154981152905574, 0.19381721113477984, 0.23351138277399927, 0.21141434268605327, 0.11858716246581848, 0.16713721857916924, 0.17180463990136502, 0.19571684871710118, 0.10017196392460216, 0.22091905766677475, 0.17121358774602416, 0.12797751584120337, 0.20177766139949524, 0.16080216174164128, 0.1962671756383873, 0.2158573462117103, 0.13347791988522778, 0.2929046167240989, 0.22815757731516517, 0.19278253278424665, 0.09465453740690025, 8.55755954019485, 58.40633546152423, 72.47725009918213, 57.14436384939379, 49.02290028910483, 39.531819589676395, 41.32983015429589, 72.66270760566958, 40.09918651273174, 4.364634569614164, 0.43981123054700516, 4.47216683818448, 10.799848148899695, 10.980007513876885, 7.248173336828909, 4.285217360142739, 1.7839986326233035, 0.27145335811280435, 0.2664927242984695, 0.30847820363217787, 1.2140221076626931, 6.703410542780354, 21.217351498142367, 33.77284273024529, 40.94347669232277, 40.600932182804236, 41.13834004248343, 45.94336117467573, 48.63960235349594, 50.38706925607497, 46.80980097862982, 48.15670367210142, 60.81794984879033, 60.54609821688745, 67.37539968182965, 61.885395434594926, 54.63484710262668, 46.98395813665083, 39.84349896830898, 31.042263161751535, 46.95518755143689, 82.63651047983478, 68.9279914671375, 73.71395772503269, 71.69704360346641, 83.78460391875237, 79.24607646080756, 76.0540908382785, 78.20477347220145, 79.08696943713774, 69.27093213604343, 78.39464756750291, 75.34156876225626, 78.35030125033471, 74.24074772865542, 70.49152666522612, 78.49070641302293, 81.18855968598398, 72.999968682566, 58.93302348352248, 50.341514848893695, 35.271658820490686, 27.064717008221535, 22.74292992007348, 12.796419878159801, 7.279241940667553, 3.494157421012079, 1.089815108045455, 0.3613977801174887, 0.5525214873975324, 1.8309286885684537, 6.532058860025098, 9.03106120324904, 10.54466659022916, 9.997189025725088, 13.236858902438996, 7.12492315038558, 1.3383068192389704, 0.1759120049856363, 7.036229045160356, 39.48631617330736, 55.848416666830744, 30.68502937593768, 35.81173389188705, 49.805617101730846, 66.89927885609289, 50.386928050748764, 10.129194432689298, 0.1792719134039456, 0.1984529164169104, 0.18797557620752245, 0.20821572641932196, 0.2295122965569458, 0.1601661708686621, 0.1649928312267988, 0.18611027468596736, 0.19116388093079292, 0.20102447439585963, 0.13869024422620574, 0.21261694750958876, 0.0828130703960215, 0.15031310038701182, 0.2061546434678378, 0.14143104634938702, 0.13905490207816326, 0.10338842237908995, 0.20239603225021593, 0.14759944841986702, 0.13683116333859582, 0.18869125554638524, 0.15173932627564476, 0.14460410592296433, 0.15815342806520002, 0.19792785507536706, 0.12814026355983751, 0.21713475186017253, 0.18496656670205056, 0.19014559686183932, 0.22366868512284374, 0.19103974404354251, 0.07346557197912086, 0.18241135703940548, 0.10819701072309287, 0.10779677574793178, 0.18222080032911994, 0.10762390800781789, 0.17260731618490913, 0.09341475433639942], [0.06711882463986836, 0.0591752742747626, 0.06022843449646908, 0.020700480954180804, 0.02456879787777941, 0.048620762198322245, 0.019386714857612408, 0.06501377590240971, 0.05228171635779643, 0.04833003566149743, 0.10259067204089896, 0.03162357325275098, 0.034400753061016726, 0.007839430397706888, 0.0582966058995695, 0.054201720387584744, 0.05810414546079213, 0.13696512147303552, 0.057574736570278486, 0.027203312962346023, 0.03933185418587058, 0.09208656471943663, 0.04237772018137959, 0.025218095698003328, 0.018963669614505865, 0.3233093287675612, 0.02406580752933458, 0.07296817407252328, 0.04752427970449771, 0.02529821891878401, 0.07294816385594106, 0.09739752288066572, 0.09599388126404056, 0.01493923929369738, 0.10092065399212223, 0.034980221966942476, 0.06754381191586295, 0.032709043232663985, 0.058031865065136266, 0.029450888527677428, 0.04065390743855988, 0.0332267769432116, 0.07651185932298822, 0.017767496099094712, 0.012774529543915584, 0.03873670729057443, 0.008425917626628953, 0.03768446254393747, 0.0800772248617103, 1.5052400745691792, 27.665877111496467, 55.89471240197459, 52.37484801200129, 41.409458191164084, 32.585529511974705, 22.997525084403254, 45.17524734620125, 48.16452095585485, 17.383185625076294, 0.2238011723684688, 0.035902197292495164, 1.0072416776130277, 1.6347840716761928, 0.9528935616535525, 1.782764066611567, 0.4050534537001964, 0.7099118612466321, 0.11936517837907999, 0.12066182815620016, 0.08871914097859014, 0.2026325542359583, 1.149299567745578, 1.1213432420645992, 0.9275006887412841, 1.8740116348189695, 2.2622439121046374, 2.253402399439966, 3.238871184087569, 2.149775830968734, 2.197459104561037, 2.4956558260225483, 3.231725851374288, 2.960308131671721, 2.1207064101772923, 0.22345238785830238, 0.028831064025120392, 0.17674212253862814, 0.05170812717668953, 1.1761439014827053, 21.423393603294127, 14.057496209298412, 7.538650343495031, 7.836022876924085, 43.27479231742121, 66.50857156322849, 65.13964476123934, 81.06797818214663, 77.29299499142554, 78.62685972644438, 75.44148722002583, 75.37373219766926, 80.07492819140035, 80.82770947487124, 73.0491630492672, 50.77928273908554, 25.338801568554295, 12.595705332294589, 8.944159130896292, 5.3029640643827385, 2.614274673884915, 1.6331227027600812, 0.24281870754015064, 0.09553522442377384, 0.03147820232345933, 0.855203623012189, 0.5040197254669282, 0.5104205126483594, 1.7797221459688681, 3.9001862272139523, 2.921401651636247, 3.83320513752199, 1.9202411799661576, 1.9345156656157587, 0.4707266168007928, 0.042586954115259076, 2.3424242677227145, 22.99988635124699, 41.64360800097066, 32.26666435118645, 21.69351350876593, 36.356645245705884, 49.166035421432994, 42.65477541954287, 22.457069543100175, 1.868110183746584, 0.17925866008285554, 0.028788345047242703, 0.006697718072832833, 0.06091073155403138, 0.11412089284990104, 0.016336420873901056, 0.039618309782517534, 0.05452742649903221, 0.10963150270042882, 0.046489091905494856, 0.03644046215941349, 0.015895637822517707, 0.03106250577876645, 0.014037278972776427, 0.0428921788660509, 0.05927167494871444, 0.0077405940429607955, 0.03141576041197104, 0.07816087890176043, 0.10779155868916743, 0.09580732353271977, 0.05109561689858956, 0.10071623109040723, 0.026476634516110344, 0.12123550543741834, 0.03533898477232264, 0.009461056587526636, 0.12472826882355637, 0.033285524395685044, 0.012612788273291963, 0.052562422464571656, 0.030783084784484202, 0.07527311047118518, 0.06188332230874127, 0.021831577215644143, 0.003389118872057166, 0.0665044910725086, 0.052833280511080265, 0.10448195926484563, 0.04737647070038704, 0.05474448602105822, 0.0487655604768905, 0.05421873520038301, 0.05135397622061353, 0.04221308022557248, 0.057551324923312476, 0.035368352752899936, 0.03827566025598395, 0.05334557499736548, 0.057690507777395754, 0.03757533714956334, 0.11133997070212519, 0.06585699355890674, 0.05029903101404348, 0.09540582451248363, 0.04469665683685772, 0.0352061259740543, 0.06272143015878336, 0.11641984610187432, 0.0616272880635675, 0.05592064548944754, 0.03458100205828105, 0.08175334097036431, 0.06821948614331984, 0.03947729597829523, 0.04041061706600651, 0.14029651609880311, 0.029036308556134184, 0.03917730360802624, 0.05748714207701626, 0.022335634341523535, 0.10415863185640305, 0.037762703103644234, 0.01209038429923596, 0.020692617061638066, 0.0932108293918352, 0.03120505750449675, 0.04044196921430769, 0.04416397292046778, 0.04552029711644977, 0.03651170450593195, 0.03360150119049415, 0.09053881430337507, 0.017671051375087232, 0.05993912139186456, 0.08531309108460143, 0.018850886150293292, 0.05279360098704215, 0.016889002008904374, 0.04912919560146909, 4.991821560167498, 41.548251259711485, 65.07753402956071, 47.52682201323971, 30.260860343133253, 19.806543588638306, 41.037762626524895, 72.08087105904856, 55.063636687494096, 7.995961933366715, 0.3523318956215536, 0.04528626874690095, 0.9921157924878983, 0.6015492759404645, 1.710785264449735, 1.6444145936158396, 1.4365630500739621, 0.6078220651515069, 0.5802388549331696, 1.1039237509812079, 1.5910630048282686, 2.2464698553085327, 2.003288420457994, 4.078226286557413, 2.788672567375245, 5.622881400969721, 6.055833601182507, 7.325997083417832, 8.115591281844724, 6.507689664440771, 5.6265880407825595, 7.043021609706264, 7.7521910398237175, 6.879869641796236, 5.830329185531986, 2.0266943064428147, 0.2929893766920413, 0.36805232626295864, 0.05414628243494419, 4.208085421592959, 38.84238458448841, 30.719718817741644, 17.294012500393777, 16.514029579777873, 56.528249709836906, 71.60420894622803, 68.69610094255017, 79.9666472404234, 75.66637239148541, 74.54794776055121, 69.71885896498158, 74.20682707140523, 77.64059543609619, 77.97727600220712, 77.9980645641204, 61.42654872709706, 37.95215168306905, 19.71664482547391, 14.77904954264241, 8.40958224188897, 5.995937537762427, 3.5955364713745737, 1.3633580169370099, 0.25652941376451527, 0.1377436506652063, 1.1594692930098505, 2.0260436832904816, 2.4109372881151017, 4.449537704067846, 3.4889757248663136, 3.0091379630950192, 3.3766819440549423, 0.7091182554441114, 0.22968394621726007, 0.9580556459484563, 0.07005855681434756, 0.5521807314888124, 18.701029439126295, 57.316630424991736, 49.32417754204043, 23.559379116181407, 21.90583925093374, 42.953875757032826, 50.925763653170684, 32.554305484217984, 4.773670117701254, 0.21809599302228422, 0.05295488547774092, 0.05875356202464431, 0.012103187543670497, 0.013741069161633571, 0.02355983901408411, 0.03005271187923368, 0.030408100067307393, 0.07907192598307326, 0.05062857522599159, 0.048533849523312626, 0.012597746136898716, 0.05721132361119794, 0.023448693062809688, 0.04628248182275603, 0.05070087860428518, 0.005324793230336641, 0.055213542504897045, 0.05365785924837955, 0.14229393714377958, 0.05085663194017065, 0.061376378946607156, 0.01250939321659145, 0.02101499643627434, 0.06895909806893719, 0.0044480630575919585, 0.02332586427068999, 0.10184531445584952, 0.08498040208172414, 0.016116647485403285, 0.012214835282535324, 0.01615460139639195, 0.08342344328881272, 0.028516037179337397, 0.016281413845717907, 0.04022586730218703, 0.05409831767000499, 0.049553585328882745, 0.05907912640982579, 0.029393083363350843, 0.10641496763714861, 0.1999303016571268, 0.1549285503044244, 0.14743815626828902, 0.1559557822803336, 0.06905498929441937, 0.1303924394831542, 0.16015547628123916, 0.37642232713199436, 0.19897350380497597, 0.13134114744682468, 0.27105336828577903, 0.14339563286592885, 0.17932134139682018, 0.17621785792852604, 0.17722242902363503, 0.10755873690809935, 0.29829965303501776, 0.35740100748596654, 0.2959410215337431, 0.12176553868959028, 0.12296253574952004, 0.30144695673258076, 0.17611219908200926, 0.0973111464672031, 0.21198310168279758, 0.44817850414303045, 0.0978644764531524, 0.2132430558483447, 0.20947903604997745, 0.08259069039336137, 0.24720658337877643, 0.3500056543177174, 0.2002646377490413, 0.15244555208952199, 0.24714259971534056, 0.1531413131423535, 0.17808878253544533, 0.09868599849963382, 0.17481510497389302, 0.12466931069690375, 0.20431186493125655, 0.17168316900009112, 0.1585651696809838, 0.17088332724186683, 0.11249056581648127, 0.20074849888201685, 0.1255874364306369, 0.14714777830146974, 0.17647031454309342, 3.498648289711245, 43.817244345142, 79.33556925865912, 66.21640205383301, 54.85336626729658, 44.04835039569486, 33.60432986290225, 56.5045036808137, 60.35378832970897, 21.344706935267297, 0.9271628746101934, 0.13461788936007407, 4.226899070124473, 9.184101300854838, 7.394351738114511, 9.633725535485054, 1.2945374582082996, 1.8835204407092065, 0.7196775823831559, 0.5468390148974235, 0.5419849592351145, 0.843364009934087, 1.7797334227831134, 1.8015181441460888, 1.3421741536548062, 3.1237135827541356, 3.1586476823975964, 3.685217788142543, 4.265988920965503, 3.9237917863553573, 3.3061197303956558, 3.543112523132755, 4.529668784910633, 4.112502653752604, 3.275278869175142, 0.8944578456782526, 0.20273376977251423, 0.35090050630031094, 0.19387494352075363, 2.7220305175550523, 31.70750498771668, 25.384187313818163, 13.3053836899419, 12.300701910449613, 49.86874764965427, 80.11293595837009, 75.77728133047782, 82.30572915846302, 78.57743001753285, 78.71375591524186, 77.22826803884199, 79.93213038290702, 85.22976198504048, 84.61394986798688, 82.93788971439486, 57.7323349829643, 28.442182810075824, 13.111446019141907, 10.305639313113305, 5.202613655597934, 3.174404823972333, 2.0711801129002727, 0.4587026829681089, 0.17568905807791219, 0.1706913762515591, 1.1136940073582435, 0.8551254820439124, 1.1620564638606965, 4.498982121867519, 6.738294632204118, 7.311947153460595, 10.64648739753231, 8.874668459738455, 8.168696251607711, 2.605967829304357, 0.18701341573990163, 2.9505801633481057, 28.558261432955344, 51.95934741727768, 43.42754117904171, 31.00142932707264, 46.210737382211995, 60.320036334376184, 59.60076385928739, 33.60370620604485, 3.53907419789222, 0.3928613176028575, 0.10259602699548968, 0.19408426938518403, 0.14045387055845032, 0.21060307089599872, 0.10531034545912858, 0.14348632235440517, 0.14912921875234575, 0.3100191435265926, 0.13833910016523254, 0.12725752342732685, 0.09254103105875755, 0.1701485876354479, 0.1884332064899706, 0.18511724087499803, 0.12351693059768408, 0.11476190925966348, 0.14653941255904016, 0.168005226840896, 0.2627333469929234, 0.18340509565126512, 0.19926087870713205, 0.19273295157378723, 0.07550358036232573, 0.2773188336962654, 0.11791805361187267, 0.09518458598083067, 0.3131104615186492, 0.15404499045783474, 0.12435097052084824, 0.1049180394939838, 0.14418750730974061, 0.216838781451506, 0.1668972798412846, 0.1195406814616534, 0.14049266525093587, 0.20619665572960533, 0.11823939685259136, 0.17765329219400885, 0.10839514404294953, 0.23869168463974233], [0.016469296909147696, 0.02237490017808253, 0.05078111099259508, 0.06221872709331013, 0.020329372641900857, 0.036654897830298835, 0.03095835804068033, 0.016730251354015162, 0.028646155298056624, 0.04397599409604746, 0.02189911935748833, 0.021501061987252008, 0.09001960587357322, 0.010789089156464945, 0.014877568258182898, 0.037334368023420536, 0.05631217387534919, 0.051553197385322665, 0.057679667633267186, 0.08093165038453956, 0.006183435109579155, 0.055949576799907995, 0.010953731985101777, 0.023524118249394724, 0.013639133502428812, 0.04649612459263975, 0.044495991596411315, 0.024124150870427973, 0.006622496378352686, 0.0337184866469714, 0.09867863639468148, 0.041234920011653055, 0.11621885527406009, 0.07041808953809162, 0.014745528216383632, 0.04251308025672071, 0.09317817106362312, 0.020523267580316435, 0.056706383568985816, 0.06613011156479198, 0.020702428732728286, 0.046238680745685296, 0.0260454457583687, 0.055238746797605875, 0.019417570963982615, 0.045748805822504145, 0.02969152632079298, 0.020559566741388653, 0.030221544251206423, 0.08337986820767965, 0.15286383609617912, 10.321626893935665, 51.162949377490634, 58.666255243362926, 53.10639750572943, 40.73540672179192, 28.884941916311945, 42.52563922635971, 44.57357537361884, 40.88975591044272, 8.466357569540701, 0.3107569781282256, 0.45608241711893394, 0.944823591459182, 2.58470245426701, 2.8970371138664985, 0.047841352005038536, 3.984450015329546, 3.626618313212549, 5.466125347921926, 1.6349760226665007, 0.38328705716036987, 0.5235965814321272, 0.11922741278765664, 0.46289128401587093, 0.3761451871645066, 0.8221460097739774, 0.38780023433989097, 0.19883677243225037, 0.23254195979285627, 0.03394643610884105, 0.09535356965516845, 0.07461460427411142, 0.02916752218058513, 0.1545583459758951, 0.22941926283942116, 0.3103179791040959, 0.20689658430074492, 0.03432587945773717, 0.12891248018751222, 0.11504520091318315, 0.07459126923593783, 0.027602649699415893, 1.568299161811029, 16.189748606374188, 35.613320796720444, 52.85474215784381, 66.81845449632215, 71.87146356028896, 72.80060245144752, 60.76466052762924, 45.03540700481784, 28.388324745239753, 9.454835057258606, 0.40149503657894753, 0.1645620599869759, 0.5394371346600595, 0.30639594601046655, 0.08241021540015936, 1.2009150174356278, 0.1762055392347036, 1.9523137879948465, 1.3676631859233304, 1.6268638257057437, 1.516613599754149, 6.858944777519473, 3.344805577108937, 4.0879066961426895, 2.625105073375087, 3.207581456630461, 0.8836704696859083, 0.4784925113762579, 0.04983853939319811, 0.9272670012808616, 14.909196726737486, 40.41667884395969, 37.764870274451475, 22.89061696298661, 27.70202567500453, 39.813594818115234, 52.31557707632742, 31.459081672853042, 9.821397219934772, 0.13801136775122536, 0.045466912279446284, 0.06723724651120364, 0.039156699673302715, 0.08155487057182097, 0.011937296949326994, 0.03774833895506398, 0.1667068303833085, 0.02442345950722454, 0.03953200614740772, 0.02363541167259457, 0.04372425377368928, 0.10668171179150382, 0.03351125986345353, 0.10281078442330323, 0.013110513682477178, 0.06062903719383383, 0.019645868995857817, 0.13138843039351125, 0.012859664894940873, 0.13086879295447182, 0.05403334192270714, 0.06834539269367534, 0.0406252749023899, 0.02595006015091654, 0.04788637882278812, 0.05754791966248905, 0.10619470969803872, 0.0828172762187258, 0.00871240386679288, 0.07552733674885766, 0.03425711540565376, 0.06774839569604205, 0.21325214165112666, 0.09563631738626188, 0.01118433881445878, 0.027022889680078915, 0.05664355669831557, 0.20546177822736003, 0.13042043233590742, 0.026127662314402483, 0.024652605981475884, 0.0464921064614769, 0.030898608928245884, 0.08083263352032631, 0.04786130859546604, 0.02589062896497067, 0.04327155326703384, 0.03054238761955452, 0.036275477464040445, 0.03189963878192489, 0.08042849915763063, 0.03942424055909918, 0.03249376103462231, 0.05421056104223094, 0.04675368718322247, 0.06485299702974097, 0.03694933606311679, 0.043135699064981554, 0.01908505816132792, 0.045530263920344656, 0.14756681307429267, 0.021160641241998925, 0.05261177001821418, 0.07026394498684714, 0.009989436047392027, 0.036053446031385855, 0.01561956080202494, 0.08701305551033828, 0.009958573237752483, 0.010193191495003, 0.06676626331623524, 0.02251005340968409, 0.022246457876697667, 0.09650688438165574, 0.0634591077123919, 0.02847658173601714, 0.06550657728146161, 0.021457515634416092, 0.03570260840558237, 0.030270003142856786, 0.0706174256159894, 0.03767418930487287, 0.046409231069828236, 0.02480891473110645, 0.01800028915186563, 0.05911546579051403, 0.05666239096993401, 0.07234782671495792, 0.058230105637302326, 0.05596201423735869, 0.0514323968109825, 0.0808355676370763, 0.7520797307933531, 21.8115121318448, 63.205476960828236, 60.811372034011356, 37.64224129338419, 19.187083667324437, 27.377157326667543, 56.97032436247795, 74.50163241355651, 40.165090176366995, 1.9532502538734868, 0.10628822605095564, 0.32649539651409276, 1.3958852521834837, 0.5441156642571573, 1.5350786476365983, 1.8295032747330207, 2.8766101454534843, 2.445107015871233, 2.27935329079628, 2.0184701993580787, 1.4917485920652267, 2.418254959967829, 0.7459767679533651, 0.48933878420822086, 1.0979222794694286, 1.3860700111235342, 0.5559048381063246, 0.9130082051119498, 1.691524465718577, 0.10363992904463123, 0.2631251550009174, 0.9710858209479241, 0.19139370730807706, 0.15356417835479783, 0.4967611649584386, 0.7362985034142772, 0.2778210502959067, 0.010432010786908289, 0.6781533492668983, 0.6080802674255064, 0.1580520746328177, 0.15596468422201373, 4.0996988117694855, 30.148604069986654, 47.7588302089322, 66.20501933559295, 75.65609578163394, 77.75781939106604, 84.20481528005293, 69.88555969730501, 58.96255893092002, 44.23769497102307, 19.137875572327648, 2.0501046050940794, 0.4849780278821146, 1.3925813907577147, 2.084628939628601, 1.6180921802597663, 2.587264987730211, 1.3096991349612515, 3.567377530759381, 3.9393383456814677, 4.666890453907752, 4.381243355812566, 9.450796977166208, 2.40817888129142, 4.775893120996414, 2.0211853375357967, 0.8269774505207617, 0.7750762193914383, 0.7605694558831954, 0.07287569193830414, 0.1258699083700776, 9.779710269743397, 48.30990752866192, 57.077146191750806, 31.875003922370176, 20.633643980949156, 30.837756664522235, 56.206274109502, 45.61405858685894, 16.373247869553104, 0.4812943094199704, 0.056949589671867515, 0.057968302750058716, 0.018915714425665718, 0.038114640065619064, 0.031139160536469954, 0.03451970736345938, 0.1433753315359354, 0.031760967291531064, 0.052389179341374874, 0.046567094977945096, 0.08768612503885262, 0.07059029078171139, 0.03769227664076513, 0.05227887417159734, 0.024411217422194542, 0.08855759601799712, 0.17715967110087796, 0.12305435138724505, 0.015128857546275663, 0.058296019842307416, 0.17466098340528627, 0.06700101563887251, 0.06893942493104166, 0.014753822075773873, 0.07503271974142521, 0.008440346892682776, 0.07126144509041502, 0.017491106897772803, 0.0309214306875102, 0.12896327181689202, 0.008845608362237052, 0.059882488342062126, 0.07313461433495246, 0.09412170793380469, 0.0882221797421094, 0.013295747996908764, 0.00568671519079456, 0.1023443058253296, 0.12163787779788818, 0.04499801284363193, 0.1073036372901932, 0.05651773824807137, 0.1838187678086181, 0.15751714607880962, 0.24520842688939265, 0.11628103096999469, 0.1464691929399006, 0.13500104057452372, 0.1607048226099822, 0.13606722046050335, 0.25151653275374447, 0.23143670942273833, 0.16072596663669234, 0.11348503987274824, 0.23781007065648035, 0.2322495593539169, 0.10280853212480584, 0.1613611301347133, 0.14357480550965956, 0.14331111804612223, 0.1919721036909088, 0.15274234987314672, 0.09699455297161495, 0.29206035718802487, 0.09444449141982103, 0.11602069897156571, 0.05952721123673743, 0.1973121961758983, 0.10311443103297104, 0.10294043714360845, 0.17821650471418135, 0.18425992720069426, 0.25601094077912073, 0.19232361547408566, 0.18774815534632053, 0.2310050188774063, 0.15981473569427768, 0.21965401667741039, 0.15874072638971193, 0.10274925224122503, 0.2026242498428591, 0.2856032778659175, 0.09731365923559475, 0.09601691752792367, 0.1597313393628405, 0.14939621571571599, 0.17818327182002608, 0.1293333842148704, 0.2566697763940019, 0.13958380918108648, 0.1429905715368448, 0.16540826538637762, 0.475472868570397, 18.14052470268742, 71.12194568880143, 79.51430382267122, 65.07076009627312, 53.59911387966525, 39.85357553728166, 51.630919518009314, 58.14123030631774, 49.358419833644746, 10.66183170964641, 0.505102789930759, 0.6364019251158161, 3.31144287701576, 9.197002956944129, 10.334798212974302, 4.405712571836287, 8.096354997927143, 5.866704756213773, 8.436037648108698, 2.739826801323122, 0.9225987066184321, 1.1080511875690953, 0.4759126949694849, 0.5480688618075463, 0.7859399590280749, 1.0451672586702532, 0.4713551459773895, 1.1344271657928344, 0.8349891980328868, 0.19662593461332784, 0.17971806768928805, 0.38495290002995924, 0.19988190022207078, 0.24951073070687635, 0.5024045976179262, 0.6756902846597856, 0.6803794169137556, 0.3189150177903714, 0.6153609219097322, 0.6364692795661189, 0.2668864628480327, 0.3096544550311181, 2.648516475192962, 21.332369119890277, 42.1305977144549, 60.16396130284956, 71.91441351367583, 74.6752678963446, 76.20871067047119, 64.08901045399328, 47.79611625979024, 33.86120196311705, 10.674409770196485, 0.7142206461679551, 0.3098905020423474, 0.7582453902690642, 1.108318766759288, 0.9568041034283178, 2.6645349446804296, 0.6011259051099901, 4.439218928737025, 3.9258878029161886, 5.8607452050332105, 6.527999206896752, 16.264914947171366, 11.563817012694575, 11.57664708552822, 8.078269929655137, 12.921690575538143, 6.503915854038731, 2.6955969295194073, 0.13162342020340506, 1.47056374819048, 18.588139703196866, 53.40387790433822, 50.512130106649096, 33.285107766428304, 40.12268151006391, 51.56369793799616, 68.91589487752607, 51.27714134031727, 16.409235615884107, 0.4825204484645398, 0.1133505148332446, 0.15262303933981927, 0.16745566600753417, 0.14333932540349423, 0.10208886146785752, 0.20002109839791254, 0.2124725092923449, 0.12015545169913, 0.15070990328827213, 0.15096044468302883, 0.23171993212834482, 0.1893156784917078, 0.15560299879120243, 0.20895101760904636, 0.10091771987537224, 0.10822268232943551, 0.298849857382236, 0.23554306327094957, 0.1153031273955299, 0.19856634339497936, 0.2916541160835374, 0.14361622022284617, 0.14992198185814967, 0.07728691813686202, 0.19577157803841178, 0.14865447406566915, 0.1301457591715359, 0.140333364927961, 0.10127971174135324, 0.2854681705995914, 0.14775303372692677, 0.16431631430262522, 0.2590139594770247, 0.25733690108022383, 0.11554953191549548, 0.09709764542358537, 0.20289417326210007, 0.23340489655252428, 0.2635526320626659, 0.1975522881313678, 0.13194601982831955, 0.12330060268962577], [0.07082182553506668, 0.042101782971933004, 0.028864658895819902, 0.04112338144031744, 0.02485392048143812, 0.05169763943300613, 0.11196761887760893, 0.01516975036206385, 0.126726861983057, 0.07381396578444589, 0.02812057684716438, 0.06366522749885917, 0.06744107186433769, 0.05190335319287354, 0.14016263457315584, 0.02972766843384072, 0.03284557159208963, 0.07128145530699723, 0.16672688656516615, 0.013298414940495166, 0.039378374875072515, 0.07123168257455673, 0.04635870757122194, 0.01351501193693689, 0.04589487963746633, 0.022120400023977124, 0.041422259152656606, 0.03045962905631431, 0.006753520874847328, 0.04335776497159274, 0.020298062628435514, 0.009954785890576821, 0.10507975299392017, 0.00454939398614149, 0.04250009889684377, 0.04623321087790593, 0.08639218721298442, 0.18141705152248183, 0.09544319428143003, 0.07389739275940004, 0.04909083757910037, 0.03452650639378736, 0.044911651751927795, 0.03423630079675106, 0.11293951632274736, 0.07310215518960068, 0.029164440591909715, 0.0440913669374441, 0.012832032103512078, 0.04186359091451572, 0.04952530136271831, 0.03630630484211349, 1.7254285754696017, 25.27547686330734, 48.430288991620465, 51.331799568668494, 42.48357965100197, 55.92299269091699, 29.470710639030706, 24.734603589580907, 54.939395612285985, 37.794986232634514, 12.308861421000573, 0.9896158943733863, 0.07951657873608413, 0.43700943250329266, 0.5475429577692863, 1.1451213854935862, 2.492530187291484, 1.544463285996068, 3.359119776756533, 3.641042584373105, 5.403273778577005, 0.9719651673109302, 0.4977767830414157, 1.2675025217956113, 1.7100603614122638, 1.7803629631957703, 1.5565651462924097, 5.416041583784166, 0.5857965470321718, 1.0245332013695472, 0.6365838250325573, 2.0819261814317396, 1.1147776846924136, 0.28664086735056293, 0.5607203442242839, 0.28752667949565, 0.016427321036556558, 0.035595490161569855, 0.1506033557797632, 0.056851239304148385, 0.06354459929430196, 0.13550304266954624, 0.10053995425903028, 0.5547591382938047, 0.9529584033354637, 3.0780118415432596, 7.503533853638557, 5.819057764545565, 4.882600711238, 1.743008883730058, 0.05210463513409899, 0.04075444881774245, 0.04891212841856384, 0.15508117034069954, 1.2873667526629664, 2.9253801607316543, 1.7902024739211606, 3.4768146612951836, 5.327205782936466, 1.5968298695741163, 5.30657607701517, 3.937956935936405, 2.1895562641082273, 7.727156021902639, 6.413559154156716, 6.56654384828383, 0.7859676607674169, 0.41408412879513157, 0.108491801356356, 1.746145554127232, 16.14337246264181, 39.8094057267712, 49.56416776103359, 27.646808508903753, 24.152617992893344, 37.48532295227051, 48.59296144977693, 50.93187078352898, 23.167014621919204, 2.1809689700603485, 0.24288806914081498, 0.055236682190649936, 0.009506791078996275, 0.10492942356053861, 0.04018724880992405, 0.011175314298710756, 0.04567032394510123, 0.010605615886649298, 0.032058084916864196, 0.06002578508829879, 0.013294846885987829, 0.02954857239890243, 0.08121728626710754, 0.03386282144234546, 0.058712652929487734, 0.027463359593023217, 0.03710433480239684, 0.08044786586035645, 0.06371108935244622, 0.025161594798367833, 0.023693643930938937, 0.048211682738075336, 0.027741595066242644, 0.054169514051247994, 0.08645762644347646, 0.05808374070892892, 0.03269384021780664, 0.038861974157513156, 0.04760966020365877, 0.0318149152031589, 0.07411965018799228, 0.02857761532669106, 0.04862864141262347, 0.03343837808877711, 0.08338319302927102, 0.03471862592343842, 0.1395803004983933, 0.05872010313455136, 0.06115055537872738, 0.05488964436095088, 0.07475173401255762, 0.09453682799733455, 0.03939131026967399, 0.17742343517320772, 0.06486892399768676, 0.034610067434128255, 0.08036003387983769, 0.08561596394546571, 0.018441325969873898, 0.013703478184799034, 0.11772079363224969, 0.06426922270968076, 0.06431163333716892, 0.08489835406503371, 0.037335229872335354, 0.08522811661204023, 0.17958403294605596, 0.12466100630380454, 0.1001051610576049, 0.0735646577912473, 0.02422118931257677, 0.025129106924718907, 0.16694252499409262, 0.060025532279283776, 0.0422016846676988, 0.07108931279470844, 0.05970649879365679, 0.06207830317678952, 0.11442198072590175, 0.048170191416096304, 0.031234917696565393, 0.06348061946130569, 0.05156152859149922, 0.01757438640080152, 0.045220779720693834, 0.04921626532450319, 0.029305684222509305, 0.0405467240770738, 0.10336598366378777, 0.06764384001613626, 0.04735984659243015, 0.025709135074829383, 0.04529145899258795, 0.06591540010225388, 0.03491938309443574, 0.06669382970299452, 0.036863940242197246, 0.09647634045611467, 0.028101083739931067, 0.03640129208384502, 0.050940794359532096, 0.02956648928023154, 0.05426656973037509, 0.03031251527699492, 0.08482201340337915, 0.07493119776969956, 7.171703298245707, 40.057087713672274, 60.65561471446868, 53.833891268699404, 32.616516236336004, 40.48399456085698, 29.11908780374835, 48.43967522344282, 75.1435596712174, 30.547422824367402, 4.202419067582777, 0.5175523315706562, 0.07923786828835165, 0.32504206643469874, 1.0035164065418705, 1.4379380859674946, 1.176927640072761, 1.6263132229928048, 1.9219917828036894, 3.4992074726089357, 2.622016206864388, 2.0834637505392877, 1.7237137642598923, 2.6120989841799584, 3.020062989765598, 5.211326710639462, 1.9767244136141193, 7.839730987625738, 3.3229957280620455, 3.004051874722204, 4.4261049743621586, 5.503605556103492, 4.829627140875786, 1.572610949797015, 2.9663500526259026, 0.9476209155494167, 0.8874843005211124, 0.1254960498021495, 0.6585688937094905, 0.3369065314050644, 0.2821377412446084, 0.20087930073420848, 0.16409948077653685, 2.23537003801715, 3.3423222264935895, 8.484536774696844, 15.243981807462632, 12.121319174766542, 10.093242968282393, 3.599079597380854, 0.3958842699085513, 0.1632263856909929, 0.6843852600263012, 1.291013944052881, 1.8524072199098527, 2.5442189362741288, 2.7136162980910274, 2.584507316350937, 2.5603700309030475, 2.5266111714224664, 3.721839732700779, 2.3397803450784376, 1.6468997828422056, 0.9705517044471157, 3.594254101476362, 0.1673501144133268, 0.5393282276007437, 0.1075726337430458, 0.24949116482129022, 0.29231120501795127, 7.476042451397066, 35.88447816910283, 64.63485533191313, 43.57477126582977, 19.571713247606834, 20.364402686395955, 46.61362363446144, 58.504465318495235, 33.25776492395709, 4.351907458997542, 0.15212166543689468, 0.04988017627188275, 0.028466523001571337, 0.053183018800712405, 0.05989445463543939, 0.045746124514769164, 0.07882861645832177, 0.07052526523869845, 0.036274964185131174, 0.048960706053842465, 0.00874987035433972, 0.06561834950961414, 0.08622387769602, 0.0325889359678953, 0.09975071515767805, 0.035325149224410136, 0.04317506832341033, 0.11111977405004925, 0.08265279714138278, 0.04582590491120373, 0.025751032423408284, 0.017645747490948247, 0.032959270531371716, 0.05462062875590017, 0.11025224076283556, 0.0920386995459276, 0.02177868459013201, 0.0534703400767138, 0.09731271694744788, 0.06979074013689834, 0.02069367043253395, 0.04283623912581994, 0.13295973801324446, 0.07746710967753204, 0.145193763798283, 0.08570469990973512, 0.11231613525700186, 0.022748184180067434, 0.04535614362647457, 0.195334785347504, 0.08586220758696718, 0.09647007385689406, 0.07478796231049685, 0.08841400815834922, 0.11742483088446241, 0.13626922252437762, 0.15990746297663258, 0.20513124193154997, 0.21223931212819394, 0.2515448167199089, 0.20789772332195314, 0.10114476535349123, 0.19425993334622155, 0.25178215075885096, 0.15316179833344876, 0.11506047670639331, 0.27396327665736603, 0.1374704483896494, 0.35917088509567324, 0.13173470213528604, 0.18928347215537103, 0.29536011238251964, 0.37669229651651076, 0.14925369271828284, 0.1154392688805538, 0.12916732699640338, 0.16843844956207663, 0.1309598348433933, 0.20851396444824435, 0.10361954344496613, 0.1379317865376511, 0.19270270642253662, 0.12472164982389058, 0.1222718921640227, 0.24421070462032674, 0.18626617357855846, 0.2433408577475817, 0.08442052204402224, 0.22509036044920647, 0.13865858947317447, 0.18302191379329852, 0.20704192650173942, 0.21923666729802088, 0.2397099840304544, 0.10893627024826505, 0.23590074972279612, 0.11665592375662058, 0.16242013943772163, 0.2705827451521351, 0.23492521336001737, 0.23944931495333874, 0.11798209856234251, 0.1166413757469385, 0.09706163163026495, 0.29060126612744025, 0.09937415229937724, 4.301052458824651, 39.39625463178081, 73.20432416854366, 68.06962782336821, 57.82511472702027, 70.51053447108116, 37.31156195363691, 33.00351688938756, 67.91495307799309, 47.16708183288575, 15.249285832528146, 1.7116090847599892, 0.20240531723585822, 1.9586922973394396, 1.283756701215621, 2.2829194607273227, 7.340360802988853, 3.836883585299215, 8.971954026529867, 5.630755068794374, 11.537009573751881, 2.7417639618919742, 2.5766515443401956, 3.8558671214888176, 5.659852191325157, 4.254403710365295, 3.231732960670225, 9.016144429483722, 0.8783881402304097, 2.303407471026144, 3.4970982180487726, 3.4286930628361243, 3.250820439669394, 1.1189645697032253, 2.962138652801514, 0.6277703205423971, 0.4964023906617396, 0.2785699165636494, 0.3972581719919559, 0.2586469420742604, 0.20266782492399218, 0.2720380977036492, 0.15632109896790597, 0.9870762822608795, 1.6650129205757573, 4.616947404799923, 10.426087456364787, 7.861209396393069, 7.279236547408566, 2.4911436294355704, 0.30093836628140946, 0.27025032428003126, 0.3307480118688076, 1.5687246164006572, 1.6874985204588984, 6.467635400833623, 5.5877957997783545, 9.318878842938332, 11.735868838525588, 6.071393153359813, 10.205110926781932, 9.393170495187084, 9.763573638854488, 19.17929776253239, 19.72222439704403, 16.493860752351825, 4.934991319333354, 1.1404866148387234, 0.37505553434452704, 2.512712988161272, 21.15151647598513, 51.0380885677953, 60.94833727805846, 39.829350979097434, 35.01440625036917, 48.140669022836995, 62.558909539253484, 71.07916831970215, 34.878492201528246, 4.052255783350238, 0.48997561777791676, 0.21854921063828855, 0.13209588194806732, 0.28681905940175056, 0.20346362173797625, 0.18223327224052724, 0.13837538208932648, 0.0564771355880845, 0.1540003275318492, 0.13363884431460213, 0.20450065963931624, 0.14312623038647637, 0.19345374837998422, 0.07818760770943858, 0.3202566522504053, 0.14499511719951708, 0.18591014187662833, 0.2835802235189946, 0.2122915133593544, 0.11805922063367984, 0.10017475248464655, 0.20432946963175652, 0.213994940502509, 0.2454858426485331, 0.32725599924883536, 0.1944613225397564, 0.23724371717581827, 0.21081751422776332, 0.2664386691345323, 0.3142414217995059, 0.10512858343821381, 0.1094379046210839, 0.2592664007698336, 0.1875886098752099, 0.2579477795910451, 0.14193314037496044, 0.20221938769663536, 0.13124353252351284, 0.14264276761922146, 0.3036720744304119, 0.19093284413458841, 0.22358262280543006, 0.20932122193757566, 0.2821788035573498], [0.03239412746963001, 0.02923517157473872, 0.03075838802502521, 0.07266419804504803, 0.0624933734446043, 0.050547212857993386, 0.08175643596557841, 0.07862342746868249, 0.05672908658462186, 0.14895214518952757, 0.0728508094025235, 0.08435870640941205, 0.3279968062716146, 0.07937928045829458, 0.044070437415352756, 0.10547219685489133, 0.0271557561392265, 0.2687876172844441, 0.08402859146196036, 0.03944181461608218, 0.09338545913417494, 0.06431876561574398, 0.06537975908647622, 0.03993018417649212, 0.08964519572233962, 0.026624755701050166, 0.027812829751881863, 0.023025799122068192, 0.03627695984417393, 0.09839371297388308, 0.07060381989445418, 0.08204978635354389, 0.07535867483144806, 0.05263825367775656, 0.04034830730468516, 0.0781586342641423, 0.019772254351165988, 0.06799214955178962, 0.03285991275803216, 0.11706941205287173, 0.03712722934001396, 0.009459361617994166, 0.040588464377628225, 0.024240416204256397, 0.016489787845902385, 0.061505338357340913, 0.02886684416162391, 0.03674141597002745, 0.05967492064941795, 0.01198898394396829, 0.04520622021969288, 0.031223321040611596, 0.11843450412514711, 0.1750370100020401, 6.264519383830409, 29.926403760910038, 60.9272623831226, 42.40244934635778, 58.83137526050691, 43.93236983206965, 27.970317755976033, 38.29674366981753, 48.81122566038563, 42.634037848441835, 22.1305557604759, 6.243477338744748, 0.48113241971981147, 0.21413809169204007, 0.4783873428260127, 0.2897775683912539, 0.6830955356840165, 3.717648925319795, 2.563779306027197, 1.8619508368353692, 0.882826485941487, 2.940006188807949, 2.2693051590073496, 5.102822184562683, 0.5700058201628347, 7.645730558902987, 7.725603253610673, 5.025190143815933, 7.7538923678859595, 7.209417868045069, 5.367021272259374, 2.9869295031793657, 2.7034865319728856, 1.7357588727628033, 0.6654418668439311, 0.14845101643473874, 0.692888161828441, 0.4345202596197206, 0.10678691864614526, 0.18777057107898498, 0.6314393301163951, 0.250737160864857, 0.15148023533965313, 0.09059234852752379, 0.1245778474596239, 0.11718639367890936, 0.2967231053738825, 0.2471675741816721, 0.022059909721475937, 0.24746670087258665, 0.6325029665904661, 0.9822990192521004, 2.9513504187906943, 2.9997031919417845, 3.3405532375458753, 0.19505983639147975, 2.4880751102201404, 2.634522929306953, 3.401232058963468, 1.9583984872987195, 0.6778133288025857, 0.37384664760001246, 0.5732917244876585, 0.05497251975259954, 0.8713848095747733, 6.948865604016089, 20.883832362390336, 45.35814746733635, 44.721283989567915, 35.11749790560815, 22.499550773251443, 30.160400598279892, 48.981750703627064, 54.48180406324325, 35.772933806142504, 8.244423981635801, 0.07402351381437433, 0.05519534408625576, 0.0903024685178553, 0.057547843053696625, 0.015182333356220157, 0.020129506048115513, 0.0693569198671368, 0.04753039691657309, 0.005410832086307628, 0.057593003936832955, 0.05067869269799802, 0.04543363342001554, 0.11777009905105638, 0.026653213952217373, 0.10933250624446139, 0.04685688305706267, 0.08448514922131455, 0.08714271589152275, 0.03760977663219937, 0.04310006831562327, 0.04899252551577745, 0.018216224439862757, 0.0446629336464309, 0.020417453600995002, 0.06643504520217258, 0.03447924259929888, 0.04793892479351452, 0.00810429955186743, 0.026799659319822828, 0.01914550824421308, 0.06237417016358626, 0.06603978979851931, 0.026776174894504012, 0.04234655572461986, 0.019576091792494543, 0.026142740839972135, 0.1647794910616452, 0.03906260875444259, 0.11250952649260722, 0.03568164823997406, 0.07341270425146626, 0.0356546321493243, 0.08273223279825143, 0.056249661100727905, 0.027291955080844706, 0.0649636967347995, 0.09430347761559872, 0.011590925616122062, 0.01968305298848258, 0.042622075416147716, 0.0729279621173778, 0.09332801020073314, 0.09431334482806344, 0.06874666188753421, 0.03464385191158902, 0.04707685754364056, 0.15208057248063628, 0.045971886795615, 0.37321772005769516, 0.052261698480334975, 0.03600467687412616, 0.056444385329321514, 0.09043875555958479, 0.1579274321275373, 0.11105804268511073, 0.056794234701702674, 0.0660019527159391, 0.07483719112051111, 0.04718902430707409, 0.016166355100370223, 0.08166035321811516, 0.03387198768435948, 0.059263987256394285, 0.07339899893850088, 0.055287650020252314, 0.022883220583260543, 0.021931145663162874, 0.06838149841754668, 0.08622132662323215, 0.022877057405909704, 0.03602166104340746, 0.013070256719666143, 0.02072839145248215, 0.011461194371804597, 0.024539360949288935, 0.0641231335729601, 0.053336787968873985, 0.03437169151560914, 0.055470499886019584, 0.0774705570731913, 0.10944886733928036, 0.07629881793212506, 0.03359639904491844, 0.0021003260448079317, 0.08177464587553855, 0.0541855329497447, 0.04339250322851924, 0.08209766684881142, 0.13210510564667563, 0.402755159283838, 15.54449615939971, 50.342636646762976, 62.55474790450066, 45.803324714783706, 38.10476718410369, 17.850667430508523, 40.46575946192588, 65.51422326795517, 63.82719616736136, 40.484159300404215, 13.485196905751383, 2.2671674672634374, 0.4132728723268355, 0.14819855982017133, 0.2837842786985059, 0.3943515731202018, 1.0759300402095242, 1.098817315313124, 0.12258467054174793, 0.44408149656749546, 2.473856028049223, 2.1739199805644254, 2.3872559781997436, 2.896419585712495, 4.759330422647538, 6.599301032481655, 7.745260211729235, 3.977021046223179, 4.646005793925255, 3.948509337440614, 4.334413197732741, 4.3544599413871765, 3.7073048997309903, 1.5837138314400951, 1.7525373014711565, 0.7893248419127157, 2.9113111092198283, 2.061646056752051, 2.4638708993311855, 1.3448838985735372, 1.081875617946348, 2.544343961823371, 0.661291876627553, 0.22128244381277795, 0.09543611562900967, 0.10278066950699977, 0.08051261561171663, 0.43071862490427115, 0.13997180207121757, 0.4728578427626241, 1.5010813815939812, 2.1234167679663627, 1.9492339919651709, 4.881744653947892, 3.080822955216131, 1.7518419387840456, 1.3420244907179188, 1.4891430351041979, 0.8741910815719636, 0.8907116757285212, 1.142532253457654, 0.532045244209228, 0.252780286715396, 0.031606062398021745, 0.09348773953294562, 1.869622257448012, 17.660114765167236, 41.70640122505927, 69.10979332462435, 52.15533648767779, 30.849431599340132, 22.03852911149302, 40.548807805584325, 61.15861946536649, 47.75672781851984, 15.173141840965519, 0.32151542664054905, 0.041226259387669065, 0.014906136634489222, 0.08873206488187275, 0.02602930045536449, 0.11066349974322705, 0.05054483415498849, 0.045983615601735736, 0.025410247786391168, 0.027555293974376498, 0.06293920214257895, 0.008368070327466535, 0.0698407197130784, 0.032094600497775023, 0.10257789369432196, 0.07061999201053573, 0.053191384480845545, 0.01401229301512602, 0.02636763744146353, 0.007642574050659014, 0.07903298573388208, 0.00799684805960785, 0.027877707822969364, 0.0471282658737994, 0.06621033629222263, 0.07199197121325039, 0.021757293500066287, 0.03425478649836394, 0.05162267006873604, 0.017183451733041196, 0.09631412899902753, 0.06693199111689484, 0.006774956014968696, 0.01622471759366172, 0.07081538273562347, 0.06435733048185226, 0.013984023413110166, 0.022622168462182728, 0.10566273058253912, 0.03741987109664948, 0.061576220642534964, 0.06146524897626331, 0.03400227242720223, 0.02596218349231828, 0.014129466163144718, 0.01883931822263666, 0.18266747555425092, 0.17807493166577432, 0.07307100605459944, 0.1809435019329671, 0.20868964373104035, 0.2261531235830438, 0.13456064727037184, 0.19055097994785156, 0.12724152751146786, 0.22432313871479806, 0.2897725122109536, 0.15216163990478362, 0.49191994892974056, 0.19894892770436504, 0.12417943577372259, 0.1998171198271936, 0.20533739619197386, 0.34317549017648546, 0.20398243180205747, 0.21123898516018547, 0.21207009862747886, 0.12767560825112367, 0.23228450828502256, 0.12790261542484646, 0.30345812139491884, 0.09484196081757547, 0.10041506660561408, 0.1515782026634101, 0.1709372138664607, 0.133621392831687, 0.17726454853771195, 0.2316738749223371, 0.1683078315709868, 0.13710392128315665, 0.15544143084797168, 0.20834105840373426, 0.17542917041047928, 0.11436841585823607, 0.14192737939376987, 0.23824628112056564, 0.10398328199141449, 0.14268410572361562, 0.16134530275819764, 0.14052246607119037, 0.13718668942249593, 0.1866932829181033, 0.09601294153159666, 0.13897335967950283, 0.25572834626561214, 0.19032668472538072, 0.22916024851222194, 0.1856396515523234, 0.23718339541266042, 0.24203976466050073, 14.897211924675974, 59.26649947320262, 82.1162865238805, 59.2785019259299, 75.2004732624177, 57.12108850479127, 39.6478158427823, 50.276195618414114, 61.602784741309385, 54.85166788101197, 27.257064157916655, 7.678110214971728, 1.0641324087496729, 0.2357530020057194, 1.4934061611852338, 1.1023131277292006, 2.856690633681513, 11.12343192100525, 10.905680560296583, 10.964723998500455, 9.84396065435102, 9.762655804234168, 11.43423072753414, 17.60833163415232, 10.723732594520817, 19.1151415148089, 19.900833445210612, 13.344205348722397, 19.59371970545861, 15.515538281010045, 15.34949944865319, 10.83422282049733, 6.098234913041515, 3.431809876234301, 3.050464790674948, 0.4568119779709847, 3.3706615961367086, 2.6728074685219796, 2.004916081505437, 1.1070077145291914, 1.6022051101730717, 0.8170317293655488, 0.22795179077694494, 0.3139869886780939, 0.15081525569961918, 0.20322904561556157, 0.18273144389592832, 0.445843008497069, 0.19208606693052477, 0.33446102553317625, 3.145789662676473, 7.432894418316503, 8.601124325106221, 11.222181512463479, 9.338462256616163, 7.646789108553241, 10.441336651002208, 14.649155351423449, 10.544623444157263, 6.771701458961734, 5.400703645521595, 1.8973937414346205, 0.780917670457594, 0.14285955518003435, 1.1349875744312041, 8.777734925670009, 27.44035847725407, 55.68880365740869, 58.83254804918843, 49.5132867751583, 34.76620258823518, 43.52181534613333, 61.677823605075965, 72.99905869268602, 53.48776955758372, 14.188091524185674, 0.2702406409286684, 0.1597315691892178, 0.2549397659998748, 0.1485229980561041, 0.08764631144942776, 0.17050317909208038, 0.23319569326216177, 0.2551412164804436, 0.15486658911310858, 0.13427688830321835, 0.16408703950864656, 0.15350307518195722, 0.12062544664067608, 0.2015283610671759, 0.16054633434020704, 0.25138769208663897, 0.1432750353048886, 0.1394466641208818, 0.1119204891485072, 0.14231992284617118, 0.2689492311929503, 0.20987487368045316, 0.19206086263781597, 0.19432996910425926, 0.16808833205892196, 0.21843242819511124, 0.14387010176095272, 0.14549555647517406, 0.12376440764074365, 0.08478825190855611, 0.19381325812109057, 0.18741435551595303, 0.11243309390040175, 0.14739445861308806, 0.22773317992687228, 0.12964774073371965, 0.17179299536491596, 0.12871631571362097, 0.21007503713330916, 0.0666391846513556, 0.2170825046637366, 0.14667312554534406, 0.19831701241914304, 0.15626607853318417, 0.14288350308854736, 0.12339117726491344], [0.033165915088067134, 0.09877427481114866, 0.01828861783348745, 0.047681886973159934, 0.07897295508413546, 0.05880996524806946, 0.012752338849578895, 0.03688896450424387, 0.07217933333689167, 0.02588344114502111, 0.022601346192400784, 0.08204159687363333, 0.024740725244966247, 0.04322420137243406, 0.12429354457004417, 0.010905208933587757, 0.05280817197936197, 0.02692917988996112, 0.12200195342302324, 0.03130498218290027, 0.02657058562392429, 0.07432844745175493, 0.06888675638624737, 0.01959067810657284, 0.06615231279283762, 0.017922533142770973, 0.014815902010717941, 0.03634139932992478, 0.02368200897058893, 0.044511727042376034, 0.03253994081469794, 0.03372917357351511, 0.06175311417469095, 0.047306660938286976, 0.029460001143536745, 0.06254192426680558, 0.013697316922668009, 0.05403441061536151, 0.015173573140806008, 0.012869132784075074, 0.033254903861351555, 0.050297552464349624, 0.03966468874545347, 0.06429728451034715, 0.02596851903945208, 0.009313017757038676, 0.016675598641496994, 0.016106877949148897, 0.041495504819097064, 0.04713173625209639, 0.06710357182929594, 0.0563601041663318, 0.043872920796275146, 0.07038943018884429, 0.39003469831039833, 0.20254117526835014, 23.31521941769508, 57.79787386617353, 48.739210944021906, 52.852698602984034, 58.986634439037694, 32.56873196171176, 21.34247902900942, 33.1667031780366, 44.63843176441808, 38.91661543999949, 33.61292377594979, 22.03000383992349, 9.003819361809763, 1.0312015370976542, 0.1172829207573687, 0.08560772083940045, 0.44440901447688386, 0.9661493342249625, 1.3464112940334505, 1.0667135734711926, 0.9674462904372524, 0.7796831657328914, 2.260975270502029, 2.523688025051548, 14.413976900039183, 3.7926924469009524, 4.70527574900658, 5.054793252098945, 2.7943357344596618, 2.96511352542908, 0.9114425665428563, 1.6963180923654189, 3.0281756770226265, 1.2571648700583367, 2.6291161871725515, 1.5149316383946327, 5.142440574784433, 2.811334796490208, 1.1688247587411635, 6.46247209079804, 2.043631345995011, 0.2826565972739651, 0.3102655174030412, 0.3678410392134421, 0.3281011474469016, 0.06718703710864629, 0.10738799889241496, 1.3358570539182233, 2.206559983953353, 2.866962830866537, 1.768317977266927, 1.198191053925022, 3.1473512563013264, 1.749824982497, 1.7696352807744857, 0.4189677248078008, 0.5372030384117558, 0.18605346160550273, 0.1662768865184438, 1.2449857880992274, 10.145607590675354, 18.87849315520256, 39.2173239492601, 46.10996384774485, 52.418033307598485, 50.96635233971381, 18.34237575531006, 24.797610582843905, 40.99408703465616, 57.46081675252607, 47.747718134234034, 18.970935575423702, 1.2603548601750405, 0.14716467820107937, 0.0768043133880823, 0.042015138427696885, 0.09778181556612255, 0.033340020060178735, 0.030405644755510074, 0.02736410524155344, 0.013957291732602304, 0.02696832506767204, 0.04116809799245769, 0.0036923350360725197, 0.12381671612421352, 0.054891509785046505, 0.06312676727952016, 0.029926309286947214, 0.04539023836954467, 0.021306879765864824, 0.021969597531302322, 0.08302195192945581, 0.058590569157874396, 0.06991135301969706, 0.032864938294815446, 0.06827994580230407, 0.021621019864875465, 0.025676327359472072, 0.07220862087823691, 0.06978660326210723, 0.016459960212570526, 0.10088365194537949, 0.0052704761600902966, 0.030795480087099057, 0.057744735311115944, 0.061001290807560574, 0.02063661411915335, 0.028534419459080505, 0.053775086022552945, 0.018567452770507625, 0.054722472484554016, 0.028690429434420604, 0.046613178997030186, 0.018998524699840817, 0.08006713548374754, 0.022069522209705848, 0.009999098331337015, 0.0590096345742143, 0.013777741790568877, 0.05490811091036566, 0.04399689297462183, 0.03844326880249766, 0.040707483797544436, 0.03561782928544187, 0.03566152311020321, 0.08345076198419256, 0.06720899318855617, 0.06696994311266369, 0.03749139306526031, 0.06382017261198451, 0.12335483405378558, 0.1005741217804532, 0.09056291542947294, 0.10569555745009454, 0.06915713945824294, 0.017343027847668818, 0.02924358896580675, 0.05121611486819964, 0.06431534886360168, 0.0065387093420741305, 0.01934801784133719, 0.14660973943048908, 0.017188959905216773, 0.06379270452945944, 0.01927146267506384, 0.016519837644732287, 0.029800691934783134, 0.012998488645309643, 0.0060888457547632925, 0.033776065815360315, 0.05220864306113893, 0.1190754592478756, 0.04192534143165235, 0.041802667772337314, 0.017129505736633174, 0.0847417886759485, 0.02280878748053745, 0.047683472775163195, 0.055499320113731015, 0.029622440511781364, 0.0466527167948023, 0.04342518453936904, 0.14537310498135705, 0.04370252752015668, 0.052244132084231225, 0.0027129057496260373, 0.027924615386573058, 0.09046572185451947, 0.09526151653018691, 0.040091541445543694, 0.022301631529004346, 0.08698467961362294, 0.07352246932925717, 0.03898038453752956, 0.4672765245120372, 2.2795273459726766, 42.19192004972889, 66.64457582658338, 54.62848109583701, 49.97498504577145, 33.44385393204228, 20.250375463116555, 30.271362489269627, 53.305406801162235, 64.93106096021592, 56.26177956981044, 40.00181759557417, 16.58799175293215, 3.675321157901518, 0.5418875741381799, 0.31483700919535856, 0.26385155957072015, 0.09952209919931428, 0.3297757237188278, 0.5042591432650243, 1.1185812805929491, 1.2147331598304933, 1.391777182298322, 1.844870875920019, 1.1614864944450318, 2.0190967979931065, 0.8624956155976943, 0.6921329829962023, 0.5907787538824544, 1.6255388000319082, 2.2239252972987393, 1.457166402570663, 2.1584197542359753, 1.9932074388188703, 1.8125262760346936, 3.8382230747130612, 3.3192714375834314, 1.8022709940710377, 2.3258262680422876, 1.8413465037461252, 2.712420955781014, 1.976477672015467, 0.7930708280013454, 0.4585170445422973, 0.20934775922327273, 0.31439491517601476, 0.5692745432738335, 1.0461643987124967, 1.3664270264487113, 0.29063384018598065, 0.6510191278592233, 1.9539723377073965, 1.5104334152513936, 1.1151557031177706, 0.887792329153707, 0.7217695539997471, 0.26304045632000894, 0.27774419635534286, 0.2731088741171745, 0.1485050256334005, 0.5623850839272623, 4.587572774579448, 10.459921821471184, 28.252122402191166, 58.12200284773304, 61.832478738600216, 62.46209367629021, 24.413004536782545, 23.439784088442405, 31.508099532896477, 56.47094780398954, 60.87538511522355, 30.00987375936201, 3.615917351938063, 0.13749965166132297, 0.09763596008621878, 0.027799536211175785, 0.06286574197151969, 0.042780759038343545, 0.014195727980545452, 0.08757293554804019, 0.025502908036052704, 0.036696036751832695, 0.02501982256710049, 0.026740862071634303, 0.050434762642027876, 0.058422726954543786, 0.0585831074614919, 0.0473775202408433, 0.031373820928556305, 0.019306733363097715, 0.03610403464746571, 0.08733193194794078, 0.09325500202154921, 0.057324248801676504, 0.04183531460923053, 0.048413477958210056, 0.1007107842052656, 0.09359843923800415, 0.07044910843814574, 0.1114777286326693, 0.046804471151723016, 0.09653161369985151, 0.03908188735705711, 0.02362519397490448, 0.01754133162208863, 0.12359216043184842, 0.024276292101750453, 0.017227421349455273, 0.02440116634862798, 0.04321173712190601, 0.00495213263240012, 0.01775138335482728, 0.037159094767224406, 0.015844437293708324, 0.03608846007996509, 0.01813069263833665, 0.0703448132281342, 0.08147935728512465, 0.0033431952526312204, 0.01863099976382669, 0.20200937235307312, 0.16559816326104826, 0.1481421604271858, 0.16730745863770285, 0.13201498306326329, 0.12957116258480858, 0.2016071455493089, 0.2212421322662023, 0.13658509589731693, 0.12254399127296864, 0.10466168349188183, 0.21869622291095797, 0.16842087550509363, 0.16936097264049516, 0.23433016222571176, 0.14154303308215835, 0.1344035379588604, 0.1265915938382668, 0.4193904521244188, 0.119101659454886, 0.09654368724553816, 0.3317460712165602, 0.18299534586408447, 0.13274221500802424, 0.13734421242148648, 0.17064505857565712, 0.11730699123994959, 0.10066503343442756, 0.17451878216478134, 0.18497271072720328, 0.13529845122848788, 0.4315390131406246, 0.13903830861372335, 0.16403778005511532, 0.21629211643049795, 0.1206116340754013, 0.1601842658654336, 0.10402495717449535, 0.21658684577672713, 0.11554750178249613, 0.17188563071671994, 0.1884818837166794, 0.2862284362556473, 0.2237847627651307, 0.12424788572975706, 0.16594889363454235, 0.1145796109772017, 0.17395029895968978, 0.15605748811316106, 0.1393672361248924, 0.12489123870768856, 0.15177787581999458, 0.1352036861522544, 0.1560771306075396, 0.8405843977966617, 1.5384951546307535, 44.8794614115069, 84.99644371771043, 69.14273338933145, 68.60215233218285, 75.3806120349515, 46.389267982975134, 30.855744654132476, 44.769117293819306, 61.296180909679784, 52.53183695577806, 44.7404133888983, 29.22044381018608, 11.884498230872616, 1.4352605780286174, 0.34883301885377976, 0.4540110992327814, 0.8378465834163851, 2.4447037471878916, 3.6841418329746496, 4.561742986402204, 4.303652990248896, 5.399818660751467, 7.148042090477483, 9.478915468338998, 28.85543392550561, 14.997765806413467, 14.739303185093789, 16.501470150486117, 10.886849261099293, 12.228733281935416, 7.67766208417954, 5.604692389888148, 7.931840986974779, 2.6218953488334535, 6.548714224369296, 6.95257910797673, 12.376465432105526, 9.564485896018244, 2.6513994172696145, 12.370499507073434, 5.2157447703423045, 0.8855688355622754, 0.6566747566384654, 0.8661702635788149, 0.6502090358445722, 1.1022504923805114, 2.280226508455892, 4.643045385037699, 9.854078408210508, 13.072509631033867, 11.300631857687428, 6.923805580985162, 8.672059409080013, 4.451358664420344, 3.6324758827686314, 1.9087197078812508, 1.1692875984214968, 0.4005859966479963, 0.2352371337192674, 2.3861464377372497, 14.084768449106525, 24.492736516460297, 46.780489106332105, 59.54723135117562, 62.226429831597116, 61.26256619730304, 28.251630144734538, 38.64553259265038, 54.225771350245324, 73.13863231289771, 66.87855305210238, 31.623993804377896, 2.5149886983056224, 0.25668420949049536, 0.2744777200202788, 0.22179495663412158, 0.24542414192711157, 0.13474441644164825, 0.16435138580779876, 0.2001211188373066, 0.12595158100368517, 0.1084149320940337, 0.16942373056325222, 0.1412190851424971, 0.21910287770292453, 0.09617190477588484, 0.17884851192995427, 0.1908296980564633, 0.18114292994141581, 0.1642660589347924, 0.07486411911104957, 0.24205465740974874, 0.13750412561480077, 0.13917401342863037, 0.16952897572228987, 0.1134686915564441, 0.16979506870190944, 0.14555569437723007, 0.15482233987460214, 0.224878445207592, 0.08741906678844845, 0.16941003291116608, 0.11491671264652284, 0.14891989288791535, 0.1248978347247166, 0.23475509587555166, 0.16641758622661715, 0.07819136154026755, 0.20275523555615257, 0.11027113249104832, 0.11718096977640545, 0.13059693899366165, 0.12273681560351003, 0.17818287345430545, 0.24310073514859526, 0.11735238961034244, 0.18305828764794335, 0.15739683963118062, 0.10454194394931679, 0.127298608722706], [0.029701985336179217, 0.0738055005128826, 0.013738189628648182, 0.047813945209547404, 0.019707458634530346, 0.08334028444463208, 0.01123846196869929, 0.020237505293240952, 0.03893758703563963, 0.045924190161449295, 0.026498563782942873, 0.011064311031312233, 0.03269780089237517, 0.03125169502210713, 0.02813444303859386, 0.08660211828687499, 0.03556532544955131, 0.015834588275831795, 0.03252496379577825, 0.0282752480838568, 0.0393219065341738, 0.012567313294106675, 0.0389099465833316, 0.010200802578530725, 0.021447759504700382, 0.035854554284484155, 0.06519404405187215, 0.04306979635129533, 0.08347023593922777, 0.0646894755623033, 0.05270760378710205, 0.048548428176511685, 0.008550534276441943, 0.0010681070759141398, 0.025047698591445244, 0.046572204784400044, 0.03138441975498873, 0.033691738687095144, 0.03790924806267985, 0.014110922047327605, 0.020278745721424782, 0.0786900234919402, 0.055100870123433496, 0.004410375362156981, 0.0884722231797153, 0.045675165620782686, 0.032864585894370274, 0.017139361457779043, 0.028513865320072062, 0.07093143739527272, 0.028386053126004916, 0.05168431333356327, 0.047570988085241094, 0.06208628581296052, 0.029089601462586757, 0.0912633726012803, 0.2434796115924274, 8.384172147320163, 50.173362839606504, 60.915169715881355, 51.892227818889005, 55.97716062299667, 47.4714812924785, 40.887116155316754, 36.426404599220525, 23.500227812797796, 23.160013191161617, 33.87436935978551, 47.95598030090333, 54.015324423390055, 36.90347463853898, 27.959315507642685, 18.274844308053297, 10.732416722082323, 6.011031798778042, 2.1504482723051503, 0.6779283645652956, 0.1065139921622411, 0.2132667126434465, 0.4394187483816378, 1.5110859995888126, 0.8152949161106541, 1.0461581474350345, 0.707624874288036, 0.15573392321746196, 1.5029180314271682, 2.3041108010276674, 0.996625169871315, 1.2566211314931994, 2.389914364584031, 3.4358141258839643, 2.286558194506553, 2.226067646857231, 1.5954560594212626, 2.2275686888925494, 3.3253265965369443, 2.9024350306680127, 3.325385432089529, 1.1312996884507518, 0.3759921227972354, 1.095645588732535, 0.8590905079918524, 1.3002872851587113, 1.7277313744829548, 0.8484111810403486, 1.3128347021918143, 0.4740459225591152, 0.12113070460937678, 0.18276144389904317, 0.5012598477544323, 2.1791227594498666, 7.320941638561988, 15.126190089410352, 23.65491040291325, 33.75521952106107, 48.762176421380815, 41.619277538791785, 74.77305258474043, 93.1980569901005, 30.038097173936908, 56.611764815545854, 39.24122295072002, 47.869162559509284, 53.77360836152108, 56.66126120475031, 34.27814599006407, 4.879930067446924, 0.2445558272302151, 0.039961241380942446, 0.11319687590003015, 0.05758258897150236, 0.027239682986551238, 0.03840789086215439, 0.07325115929087324, 0.05292196667963459, 0.12908454353530563, 0.04885917259079795, 0.017020163922420433, 0.04798319701465869, 0.07845240600046613, 0.034753739563447815, 0.06513723863228675, 0.008718238583946181, 0.11062552476482046, 0.03976111240204304, 0.030859028995637933, 0.03500335782225575, 0.044199496417516665, 0.04594999200273906, 0.02411593074700044, 0.09143107690878453, 0.027430630401678147, 0.029143003536568537, 0.06841310720530248, 0.07145735675529127, 0.022667831132909464, 0.07734609842901269, 0.052816552981253595, 0.031079976413879665, 0.01270849659528223, 0.037142041650029926, 0.021219143546336604, 0.07100630716811265, 0.0831890740101376, 0.030901428131807237, 0.041310103880541946, 0.04564915310531374, 0.07012774987566857, 0.03453002273735981, 0.10224865208710394, 0.029726867871959845, 0.05366800608293665, 0.026274052140633428, 0.09961622842257062, 0.021076846544841127, 0.061821207899840615, 0.02926030308909474, 0.09264794628947012, 0.01713907609002725, 0.08542452623406727, 0.031701538020805005, 0.025764542383952968, 0.0161200680679852, 0.023715511910737525, 0.02392127738153983, 0.044939108343134006, 0.011580299976612292, 0.04477828350518981, 0.06972903175459755, 0.09797786512682516, 0.04239866885566904, 0.02528585809012575, 0.015511848839871107, 0.01930127881707684, 0.05269770976155997, 0.04173157098252447, 0.020756910990683303, 0.025539703239055894, 0.03591497180863254, 0.010329334895246694, 0.014086489588202489, 0.060093304247505246, 0.026243648026138548, 0.031734677069189574, 0.03476579012649675, 0.05090473077049659, 0.04013318598510758, 0.01111476845483506, 0.03417230947243591, 0.025632771430537108, 0.0330926196259116, 0.062332368575997894, 0.05040003587642024, 0.03317661350592971, 0.08181314945461289, 0.006366667540503607, 0.023247374732407834, 0.12795095557286856, 0.04024166020474607, 0.022239691405106458, 0.04639059981150974, 0.03394485030683779, 0.07840893817164245, 0.08103943129460658, 0.040424559866228414, 0.07773964545659481, 0.04015801489473351, 0.06277514441359429, 0.08217167094229691, 0.01387998580016316, 0.09120018566928564, 0.20937107893968784, 0.4601630610564063, 20.281711278423188, 61.302629286243075, 62.88378377114574, 57.44528808901387, 44.99406914557181, 26.48723429249179, 28.98623516482692, 33.78237801213419, 32.601118972224576, 42.086839752812544, 60.57058949624339, 65.66834103676581, 51.92521887440836, 35.70804603638188, 18.80113224829397, 10.692552693428533, 3.3936199641996816, 1.439157820517017, 1.0308133450246628, 0.8247532214849227, 0.42211508979239776, 0.5572011201612411, 1.0627270970613727, 0.14742749232438304, 0.17258623344523294, 0.2124299454472719, 0.5886431458976962, 0.498578233584281, 0.8083354056842866, 0.92460481510047, 0.8658714892883456, 1.335204592154872, 1.0118308507146374, 1.063533757002123, 0.4426299131685688, 0.9327238762090284, 0.7867081307115094, 0.15765752403005479, 0.8527232141744706, 0.4601204972113333, 0.39457049040544423, 1.0787956993426047, 0.3191129442664885, 0.6648752069280994, 0.648419515740487, 0.8623281794209635, 0.6928442190251043, 0.21601635542127395, 0.5748852486571958, 0.7450263899180197, 0.31882792891513917, 0.13650841049609647, 0.3620727035787798, 0.5540538471071952, 2.1800597156247785, 7.6140789927974835, 16.38180353949147, 33.509796819379254, 45.07844325034849, 61.14866056749898, 73.70492842889601, 88.3817158975909, 48.517306773893296, 55.96708797639417, 42.421547366726784, 31.68183307493887, 51.125420139681914, 63.07903935832363, 48.894423054110625, 10.45559250539349, 0.428098450985647, 0.1797114333678638, 0.09452381216350103, 0.03195390270482148, 0.022476830091627858, 0.061075482592587514, 0.054485329967593, 0.014784594870082315, 0.07274901163914511, 0.0171993633792285, 0.039879212516450116, 0.03143401820242646, 0.03758938720209464, 0.04626780357812682, 0.04459957434465328, 0.022571350019725583, 0.06143947011761128, 0.0031549403971556818, 0.10996863501326692, 0.03206748098525549, 0.035625003698852756, 0.04257020360279468, 0.030668845753215497, 0.025621372042223815, 0.0794729040635209, 0.04916195352111132, 0.07712484457560125, 0.11416695771678803, 0.007218756016358854, 0.046240699387365775, 0.03863492101851491, 0.08648155903023097, 0.013712781365029516, 0.04291452182036254, 0.06871994840161455, 0.01644522068090737, 0.048380471059992436, 0.03679176326841116, 0.02026184007615572, 0.09406336267749149, 0.016712912869068886, 0.05199772373382604, 0.0869074273073385, 0.0759092009355945, 0.04260784150251458, 0.0444921764785484, 0.03457334883991749, 0.025762619503263025, 0.043045905899376645, 0.14794538308295513, 0.24663878965281674, 0.09706209128301951, 0.17394971673286733, 0.139419851043532, 0.16431692717296464, 0.10861896429090731, 0.07021506091639881, 0.16481315296503807, 0.13602641861765616, 0.16988920558604503, 0.15068036293791187, 0.16704118179698146, 0.18807602565615408, 0.14149256320970674, 0.1698635876058571, 0.08698502435318886, 0.15973780514492145, 0.17733662208962828, 0.21410102835826336, 0.14823900926257336, 0.11172183488886203, 0.2195904313796951, 0.19316750728795606, 0.14540152684334787, 0.10350184935715892, 0.231380631786681, 0.12700253872260933, 0.17846091740554382, 0.12322553373392552, 0.12527944610243844, 0.11984068149280165, 0.13351513643658933, 0.08991182496350619, 0.09334238967107189, 0.13355714869835686, 0.19311218041806452, 0.12323148623709718, 0.15147404534922493, 0.0991765782237053, 0.08179765915678394, 0.18319425293274466, 0.18022878786488888, 0.07393669306991563, 0.16929452217394308, 0.27394424703332687, 0.0887987758183191, 0.15552449010072217, 0.15867608389066112, 0.2104351137794795, 0.1483780082555548, 0.16242822932620204, 0.14024099004605126, 0.16772886828309105, 0.27671647408316213, 0.31936183091132875, 0.34897590957341657, 15.12105570685479, 70.2404792847172, 79.85350255043276, 68.91224707326582, 72.2919181085402, 62.28435931667205, 56.30878917632565, 52.60835455309961, 36.61891844964797, 33.59040152642035, 47.42022375906668, 61.12227478334981, 67.54403022027785, 48.87493279672439, 36.19920522935929, 24.283784012640677, 13.961055913279134, 8.620936216846589, 3.173699042489452, 0.9200015459810534, 0.3127732296143809, 0.43645070925835644, 1.6211733246041884, 1.6946224027102994, 2.202112751622354, 2.1499082109620495, 2.1690724213277144, 4.429386527307572, 5.921488500410511, 9.532565647555936, 10.17165703158225, 6.996696456786125, 13.673974698589696, 10.91535802810423, 12.592934177767846, 10.427684841617461, 13.051926012962097, 12.148801261378873, 16.513039181309363, 10.943210778697845, 8.165981971448469, 3.285893048009565, 1.3402835712317498, 2.5765449049011355, 2.479023015306842, 3.2952643257956353, 5.273755154302044, 1.7460358503364748, 1.7649867818240197, 0.8135231692464122, 0.353342917176985, 0.25867075208694706, 0.747806063342479, 3.4770416684689063, 9.79103611361596, 19.27873572995586, 30.471893664329286, 42.87146675971247, 60.7642133774296, 54.50757403527537, 85.45524335676625, 101.60072311278313, 40.314348128534135, 68.03176126172467, 50.912784530270486, 63.079259011053274, 67.71729700026974, 74.05477246930523, 50.47548340212915, 8.772269102834887, 0.4126359468265888, 0.2558164310551459, 0.17555044212889287, 0.15588046051561832, 0.11080825971739908, 0.16279726920108642, 0.13742869659777612, 0.12140280371832272, 0.1745139251673414, 0.20437181897221074, 0.1334854581904027, 0.11399192960872767, 0.16108634971803235, 0.11146318828386646, 0.1372120469327896, 0.12352126665533551, 0.22289355736105676, 0.14138266023608947, 0.15569197224272838, 0.11998158804471455, 0.0789761113663835, 0.16182162558599827, 0.1398719042058914, 0.17011299519048584, 0.16576258105135735, 0.15168153260263706, 0.144329754515521, 0.22501496207569877, 0.10400186728445754, 0.19892556202267447, 0.07424647604385692, 0.15589362190615746, 0.1131037119475584, 0.13820426869055918, 0.19353826319979084, 0.15221241621240494, 0.18258964102114403, 0.07557217587506579, 0.12626990585798217, 0.1992138715520982, 0.19111042331543662, 0.11856273958279241, 0.2715727758984412, 0.09745043657359578, 0.12665055962579866, 0.15210232937768584, 0.13852346688508987, 0.09484124835580589, 0.2113302875190012], [0.07915382078217884, 0.07477027334032521, 0.012483922708328935, 0.03518236958752236, 0.02770673615046807, 0.048588755044845805, 0.10549131840948137, 0.040249037631456895, 0.03185162613649042, 0.039168585527447924, 0.020488339716628678, 0.055672333410550515, 0.01884156094503499, 0.013049001610206981, 0.005584492727423148, 0.01693693229988698, 0.07955024830035626, 0.006398775243020106, 0.010760027611057365, 0.02780473220252222, 0.043374856393183434, 0.07106112841997417, 0.009271119450849873, 0.048881251244775714, 0.046513782919294415, 0.10812023339132149, 0.06102428493660785, 0.01756771377498104, 0.04478274596734874, 0.04364934569645313, 0.03389470985219364, 0.026107876178538127, 0.029971290139421344, 0.0208641862827203, 0.0702222008558531, 0.032750274084748766, 0.05287550344702698, 0.10026251551725211, 0.02636702648634392, 0.025417255575678525, 0.07233972916559828, 0.06663861774629162, 0.02628646276500677, 0.03949192442720936, 0.01807825008948003, 0.051530609282875256, 0.052412181131301395, 0.09387872016598141, 0.02832465883975308, 0.042360582794513435, 0.01384589297231287, 0.01633544985745703, 0.029908359846881324, 0.05277580476456112, 0.06628385008943659, 0.011159047379248567, 0.03557085660436461, 0.40139826435235243, 0.7777129714527439, 18.744807012619514, 49.425327624044115, 57.2229406910558, 55.738217676839525, 56.550807260697894, 44.070645147754306, 43.52513759366928, 40.141163718315866, 30.483439160931496, 29.982340681937437, 28.15624398569907, 34.3419276514361, 32.317270771149666, 41.59745347115302, 41.29219109012235, 43.08707552571451, 46.85601826637022, 39.352363309552594, 33.02463100802514, 27.03366752593748, 24.55801652323815, 23.506725218988237, 11.66895124220079, 7.013509206233486, 4.306477096772963, 1.1127114536300784, 0.545489535697045, 0.23494703154410088, 0.045425972540772734, 0.11938390922882866, 0.22029533952234254, 0.9286095550464046, 0.909090921763451, 0.5672967494014771, 0.6774829916896359, 1.0381589637648676, 0.8650347374139294, 0.33235777710233966, 0.20145783501286663, 0.23355108145023548, 0.6844405409309172, 0.32264978835178965, 1.08843210483751, 2.1958175926439227, 4.77485663467838, 9.136011081357157, 15.458332473231902, 18.07020641142322, 25.106297193035005, 29.711701062417802, 37.411641228583555, 46.766258747346946, 38.55673405431932, 44.0387955019551, 35.238816815037886, 29.09834827146223, 33.17510097257553, 33.51722186611545, 52.2530270391895, 55.571473798444195, 38.95881622068344, 38.348134563815215, 44.30562650003741, 60.54251709292012, 42.599948529274236, 13.59837297470339, 0.37956478915387587, 0.2848653206902166, 0.07113517081785588, 0.025528480050965183, 0.04850921979654701, 0.027436812731227087, 0.007069141438771641, 0.03325609512807381, 0.05164153115343183, 0.03041300686046241, 0.0450284495168636, 0.03439213457186857, 0.02454538814603321, 0.08051179589763766, 0.02461773557438245, 0.02738238601464658, 0.022820954871994835, 0.027576372883613073, 0.054815165292952335, 0.039882560320679224, 0.04065111504807588, 0.02567381267586062, 0.06183685907613366, 0.059742079747299996, 0.06879017568163334, 0.03375259671179998, 0.03029203391633928, 0.03737474468746974, 0.04364829998643648, 0.03511893367695232, 0.011225024786507411, 0.044050856208008145, 0.03704527708431406, 0.006924909107657451, 0.02880172285762045, 0.06173756258982805, 0.017150209262786854, 0.05301627593355314, 0.043251922263974146, 0.01677602319227111, 0.02131465172785665, 0.08244666586359663, 0.02007929473033836, 0.03820797638787377, 0.06648577554451843, 0.03343825551470922, 0.021116505001461314, 0.02548331533738923, 0.02643726717290138, 0.046044201665227456, 0.026823302708385934, 0.04568437399763254, 0.09555358755131883, 0.048395421265834765, 0.016519531209562576, 0.07404938460357728, 0.0161090976889095, 0.029532440502436894, 0.1497588357737949, 0.04893692285423318, 0.03086425946094096, 0.021755345721518802, 0.012851755994732582, 0.06713695794103608, 0.04904065115918075, 0.06163522473446304, 0.04863306940082581, 0.07996727592281758, 0.009335362626570127, 0.04682824286001344, 0.05224709684449819, 0.027826282255832228, 0.05032534613424251, 0.03824620800573499, 0.07818025326536548, 0.0097992729147776, 0.05884482990950347, 0.06354760235896514, 0.004853967562197678, 0.037298557243400046, 0.054770349149381926, 0.053078601016632976, 0.05238698449947181, 0.08285932678488955, 0.013559394283220174, 0.024423467168103785, 0.02704056715893169, 0.03465260829656355, 0.03403185874283795, 0.028198265823565667, 0.04816555658415441, 0.012802712003430052, 0.061107501237382816, 0.05885445963471167, 0.09584891444612896, 0.045555111982168696, 0.03904721038716455, 0.021379970299500613, 0.05039226774486804, 0.010964422742085112, 0.036122914884359605, 0.03659911513809235, 0.07168849314292593, 0.049718918594261335, 0.0388616600614642, 0.04958157818163595, 0.054919889512201475, 0.08283955405556387, 0.2923448822431026, 3.1632128309819008, 35.44904801153368, 60.79241521896855, 66.69191883456323, 61.48951061310307, 53.20483722994405, 45.023471232383486, 28.190856941284675, 19.081744493976718, 24.218949194877382, 40.711809742835264, 48.92237386395855, 55.58360568938717, 60.438429155657374, 68.15230354186028, 68.05904526864329, 59.409030560524236, 53.94329401754565, 41.54579977835379, 36.135949165590354, 26.88051466018923, 17.881491376507668, 7.580907017953935, 2.5398173014963827, 1.363909355094356, 0.5989074370553417, 0.3331796362275078, 0.2998215326618764, 0.24746357523385556, 0.025616670177588542, 0.2614938780184715, 0.25794302984591455, 0.9269942126927838, 0.4578451547891863, 0.755015318432162, 0.3247613105322084, 0.7528019372013308, 0.336102047154019, 0.4723254729422831, 0.28894587269713806, 0.6017406753474667, 0.3896441773301171, 0.2642880458264582, 1.1246702699891984, 1.1133391554317167, 0.7296887580906192, 1.7956872957368053, 6.683419202604602, 14.091345283292956, 23.0150874968498, 30.359451078599502, 39.88074579546529, 48.70424693630588, 63.89558269131569, 65.1757933247474, 65.85769345683437, 53.60345594344601, 57.55425545477099, 39.68079513119113, 69.49756668459985, 76.41794558494323, 27.45148231906276, 39.214280190006384, 45.35042824283723, 67.53817804398076, 56.53552962887672, 22.679789566224624, 1.0373094029003576, 0.34534103687732454, 0.08521849454771127, 0.10786336411031024, 0.020479569925115477, 0.028619518420929392, 0.05775649859119327, 0.019861262276648514, 0.04616716260751409, 0.015339491505836769, 0.04556012602763311, 0.007819317238059858, 0.021871471244301048, 0.05549104636414878, 0.017545887930018288, 0.08154841245061929, 0.03893120169279076, 0.0476425790017651, 0.07362337076976415, 0.053696351336135026, 0.025463613471196547, 0.043693169756161596, 0.06841929719573067, 0.02293986129394222, 0.066728993138719, 0.02803545681789758, 0.09024708802180906, 0.0619733682833612, 0.02626255316088998, 0.046654796723516724, 0.014424384158525257, 0.06301345138420021, 0.04484957947786297, 0.060800353605901046, 0.011875761894419069, 0.08291583343018448, 0.003340721985648176, 0.037555123919681195, 0.031548467907874335, 0.018679609957842097, 0.03868035769330398, 0.052795022080141696, 0.038484993781293594, 0.04189325000850424, 0.03568003945533307, 0.03750836191278312, 0.00811314978261268, 0.03251837160918982, 0.010984135141986753, 0.06737906470774643, 0.06339701628612895, 0.13936221058810913, 0.28837124546689374, 0.09692532160589773, 0.10283432630521637, 0.12475292919383896, 0.07568375658123724, 0.17528036549206705, 0.2783950340122946, 0.11195588241060896, 0.11015699305120977, 0.12017394506162214, 0.08066104514704597, 0.14985865703032863, 0.11490416412632312, 0.15714927065757014, 0.15660640543266652, 0.16307586473563027, 0.11082499107766537, 0.20267203840757572, 0.12697082268254412, 0.11303821143003241, 0.14405256858275783, 0.14697729309480037, 0.1604864415862868, 0.12915393577948694, 0.2089643015736534, 0.11673278535806364, 0.11210379866702903, 0.13945172030118205, 0.08628299670113672, 0.1964582686102198, 0.12324917520726882, 0.22817697466140796, 0.1366041101995976, 0.1984296273440123, 0.10799022827057109, 0.14191656223227903, 0.21770634538223668, 0.16215577781681093, 0.07534455583100358, 0.13750407964952532, 0.1681930562781711, 0.20629010313460905, 0.2481985140231348, 0.12997826170777121, 0.09240125065609332, 0.17721144332280084, 0.24313131737853252, 0.07161886341148807, 0.10751578235818494, 0.0909090416145421, 0.11218875781783175, 0.1342861273235852, 0.12541985469720057, 0.27252566670217826, 0.1260745074720152, 0.1127306807545885, 0.40108392315526165, 1.4100766326150587, 28.951963455446307, 68.37202687417307, 79.25458800408148, 74.48275796828732, 76.2528451796501, 59.94692871647497, 60.20842136875276, 53.346713281446895, 42.51313471025036, 40.481201833294286, 38.36626375875166, 47.56934442827779, 45.83146772077007, 53.91151497440954, 56.58012697773596, 55.5457861961857, 61.19927875457272, 53.64976344570037, 45.961376620877175, 37.11489823556716, 32.95552669032928, 29.092805962408747, 17.220424913590957, 9.98572099593378, 6.248546021599924, 2.0354632552592986, 0.8779677111775646, 0.33821540794545607, 0.18989186854131762, 0.325180207409205, 0.6109048642458454, 2.0842112072052497, 1.5884141792212765, 1.2558914480670806, 0.9790771598777465, 1.978043065436425, 0.7628961568397861, 0.6056814929169994, 0.5143016060033153, 0.6303747743368149, 0.6240666837942216, 0.6005200827794691, 1.9024990739360934, 3.309682223104662, 6.565100416060417, 12.118183239813774, 20.01604130191188, 23.033201002305557, 33.73919663890716, 39.0588641166687, 50.149742326428814, 58.37431715380762, 50.66824043950727, 57.15536217535696, 46.394406287900864, 41.246919093593476, 44.06376138810189, 44.645162551633774, 62.83635447102209, 63.23944076415032, 54.363725031575854, 49.885523626881266, 59.54558395570325, 82.33803379920222, 64.64392777412169, 21.12003161061195, 0.5844590800904459, 0.42385855269047523, 0.2589981167787506, 0.24759848331732137, 0.2837037168923886, 0.05797722384393696, 0.2346790080229121, 0.19999237010075202, 0.2056889232969092, 0.09965841688456074, 0.1334785327555672, 0.10243262044124066, 0.0946996676465196, 0.2526044235714982, 0.13640439107773766, 0.11029897212621667, 0.15064749776596023, 0.19138166440590737, 0.13088134147467154, 0.11896378661115324, 0.17803291940400678, 0.1260879982803618, 0.23803171521473318, 0.14826937698789183, 0.21117874000582004, 0.1406881402456953, 0.12957202060328377, 0.1878746671061362, 0.10944777183354863, 0.15601222763859457, 0.10547966621215306, 0.15548499060734627, 0.1982873341729564, 0.15286221198977964, 0.09505929996169384, 0.16908076832131033, 0.08827975124961908, 0.1379226394478352, 0.22079712711274627, 0.1427736767237225, 0.11754303059029965, 0.19889995936424504, 0.12793636925879026, 0.20520561374723914, 0.08800573692086243, 0.10822432175759347, 0.08614784346953516, 0.16011482765597684, 0.1060720360387237, 0.21124272366925595, 0.12381110836060778], [0.04158414119193631, 0.011978461726328299, 0.06202976767634673, 0.04896855845506634, 0.06176730978392786, 0.02418890445222778, 0.05842202215365345, 0.03439909831110028, 0.015241160290315749, 0.03771029119830459, 0.02577632290100859, 0.04650092030304574, 0.05255974881771592, 0.028524031306827263, 0.07302025272961586, 0.04101561202156929, 0.04513547199988558, 0.0355309434235096, 0.04072806858006985, 0.007684575778717596, 0.05449396377849964, 0.016620796541833592, 0.041129211369421215, 0.061263128168760776, 0.015371094547933149, 0.074347002101281, 0.022165583889751185, 0.04325658007855377, 0.048125448050878705, 0.018197700433853655, 0.06366151197242641, 0.0653876651138548, 0.06072417382271059, 0.028733016262131355, 0.03250793749166112, 0.04690562157080539, 0.009042293775916822, 0.07365605208061396, 0.022663460601301446, 0.04312907623487615, 0.04140948463651923, 0.02579256971066277, 0.011646295578459339, 0.16316218752293818, 0.013189352748374785, 0.07710888696413848, 0.030893468478273962, 0.026253362021018422, 0.03233768977224827, 0.0435424572788179, 0.038920411344377265, 0.03148921866781049, 0.09645407028015583, 0.07674635883661048, 0.023389761749234413, 0.013251667297745665, 0.017543396229044567, 0.056430925164491906, 0.09259146262681292, 0.32409285285299827, 0.9281788297718572, 15.823808139370335, 41.880927085876465, 60.7006396016767, 60.852878555174804, 54.16162883081744, 53.68544132478776, 51.689519728383715, 41.88652823048253, 45.969060544044744, 48.1431479607859, 29.68299911868188, 25.32521643946248, 23.72436381155445, 22.598119935681744, 26.254708343936553, 36.91580657036074, 31.268578037138912, 35.37168710462509, 35.21625141943655, 32.579092902521936, 43.321241025001775, 51.87811513100901, 42.980775371674575, 43.7750514091984, 37.308063199443204, 34.769564059472856, 27.350867640587595, 24.57464541158369, 17.819145302618704, 18.345529340928604, 16.27709488714895, 15.639650898595011, 17.664572538868075, 19.143741476920344, 20.486715916664373, 20.932001029291463, 22.821804861868582, 20.627799649392408, 23.432765007019047, 35.53078628355457, 44.26637926409322, 49.40727295414094, 51.092582056599284, 45.023008392703154, 39.26043079745385, 37.232357532747336, 43.868972562974506, 39.086469757941465, 39.06883478164673, 35.835315181363015, 23.045458409094042, 23.111660172862393, 24.868509384893603, 32.43263356147274, 33.03721397153793, 43.24405662475094, 30.438898686439764, 39.04636744529971, 61.22828075962683, 64.83490405544158, 52.642965547500125, 19.595220012049523, 1.0432522840076879, 0.3420247035401483, 0.06245930934505117, 0.054987190336349516, 0.11291435799531399, 0.09911171355915648, 0.11861173090555015, 0.0065600846315764134, 0.02703455719916571, 0.06374151453435903, 0.024762294450474363, 0.01714292759706657, 0.0303713221012825, 0.03554195210698151, 0.05514967375464978, 0.027770382735217293, 0.0544141527385481, 0.06421642776037897, 0.06203044566415972, 0.013807635498984207, 0.02427817284760456, 0.022307672132287296, 0.047542106570495714, 0.025975821772590283, 0.011028791364702967, 0.015741327604759606, 0.014799193633089383, 0.03381202981296567, 0.016556094670968673, 0.04561027414315651, 0.05372236768204359, 0.006654216727662471, 0.03369938041413984, 0.07360159089007685, 0.045887257062619737, 0.07683609071518145, 0.005732401322963978, 0.018643787686502742, 0.05360627471799812, 0.07052367177581595, 0.026063347317939325, 0.09486651393554865, 0.01712597215608243, 0.00672626729694105, 0.045962015752710646, 0.023627227938343442, 0.07117188941206663, 0.025549520655805548, 0.008444192654062665, 0.04458686877642909, 0.024406733892617688, 0.06765618935347566, 0.02089483363013114, 0.02100245940739349, 0.048690671551852464, 0.04839870012215069, 0.019905651326201135, 0.032722097370893724, 0.023719056982607133, 0.04733680649810741, 0.04484651129572623, 0.03732832358969796, 0.027171278995792233, 0.035323456170097474, 0.030868842581947966, 0.08630642366986122, 0.0677163502381694, 0.03719819589487968, 0.060289514686671965, 0.07869988304352568, 0.013241916913689386, 0.03666430155956938, 0.05657832048112347, 0.01490595181577749, 0.061889531451367566, 0.0303408969193697, 0.08620676329179157, 0.03486909708308597, 0.09395331414716859, 0.06086154870929257, 0.08958557876007212, 0.05135794838650092, 0.01147374289200431, 0.038610210852517236, 0.02575807468665223, 0.025419532772033446, 0.015748033746926775, 0.03270202586727758, 0.0697288632152542, 0.013503653725849525, 0.07393967315194107, 0.03652361334271489, 0.046180335489372094, 0.06276353818154143, 0.09214553050696851, 0.052651844077533295, 0.07224653456960956, 0.02425879848399951, 0.013959300798183728, 0.01635824671886381, 0.04794609537648578, 0.0665118455165817, 0.054941328482762467, 0.03316262090999273, 0.031466354773710334, 0.026937013138986887, 0.04970901690784001, 0.03507476870811755, 0.042558578218543724, 0.018432029492912755, 0.03024300620440514, 0.27263065139132164, 0.04331860255690352, 5.971632570989671, 30.17346993569405, 56.48995560984458, 73.24504621567266, 67.89014800902336, 56.79664573361797, 46.24238698713241, 38.56902284006919, 25.995157264894058, 27.218923030361054, 32.564891961313066, 21.909128158323227, 26.12909051679796, 29.91105748761085, 35.765591129179924, 45.315656431259654, 54.676000610474624, 53.71204283929641, 58.66826741926132, 64.69192189555015, 72.03994504867062, 64.39194686951177, 49.3321870219323, 47.72563126779372, 38.29065222893992, 30.943058575353316, 26.02050558213265, 17.75702476501465, 18.19617529069224, 10.108431366182144, 9.738305730204429, 7.814343936981694, 11.554033640892277, 10.3498101042163, 9.712163133005943, 12.025478020791086, 17.05271024857798, 17.103046024999312, 26.775555956748228, 22.823324780310354, 28.890576401064475, 48.455372548872425, 53.567409361562426, 66.26769096620622, 64.19864854504986, 62.497967673886215, 58.31578362372614, 61.552044960760306, 53.7062769551431, 51.37592623310705, 51.54164245051723, 30.598923544729914, 29.284423551251813, 17.77905083471729, 20.947578722430816, 22.64951082967943, 29.673389311759706, 33.93865700690977, 39.31478308093163, 51.8874542943893, 65.15186686669627, 61.34177454056279, 33.55989725359025, 4.0315074257312284, 0.11421610991800986, 0.07766460714441153, 0.16935927192530326, 0.07073522695610601, 0.050183255976486596, 0.07251962193197782, 0.03361707958843439, 0.042674077464447874, 0.048930196602257996, 0.016764152659884384, 0.07874301379366268, 0.0503165016491567, 0.03318134409886214, 0.023223622176315517, 0.04410839707200085, 0.05427155696276215, 0.07150722907916193, 0.025710044804239468, 0.02916385644986745, 0.04130511664815488, 0.021963830804452304, 0.07440042907312032, 0.056025660822107914, 0.09674465509071466, 0.009707283949659718, 0.04492544516500446, 0.03526087061712339, 0.0598710659711111, 0.023500829176496596, 0.042848059862491586, 0.02694478127053909, 0.04636400889965796, 0.04896874614660779, 0.05547531091818406, 0.06377915626451855, 0.034808422919482954, 0.07277498968065747, 0.07952220182144835, 0.014959931328532197, 0.04414046934295086, 0.021640771526783224, 0.034365781147273324, 0.0044195981031554124, 0.0775381566716298, 0.09511160078428446, 0.03525914691929375, 0.04741001769059128, 0.03470384808737905, 0.027989317257437977, 0.028666460458489678, 0.01941226772032678, 0.019411867439386346, 0.11707950909171375, 0.127633182301877, 0.13449061151233413, 0.12053720097267821, 0.12877179580109735, 0.08828244787911255, 0.08357657660399714, 0.10377507461535354, 0.20424385164533893, 0.07302337836834692, 0.173518838240735, 0.20398220197568018, 0.20305728870293788, 0.17807897661001454, 0.17313317425789373, 0.12372730600257074, 0.19085824249252198, 0.18101710766073198, 0.21924204523524932, 0.08189284558137579, 0.18312335915623174, 0.1602463649525758, 0.13974908498987076, 0.1986032688329297, 0.09020043326722038, 0.1814316684800771, 0.1129171695379961, 0.2515036931201335, 0.15671382628140912, 0.07073729539350157, 0.1445190548416107, 0.22586392539162792, 0.17164052854622566, 0.2283503710021896, 0.12919245468031976, 0.2734201509625681, 0.12382227026166455, 0.16801500212280981, 0.17551630525098694, 0.12008877140620064, 0.20279727846143708, 0.14698031148122204, 0.09896896073534604, 0.2779852076163215, 0.13668182215863658, 0.14459718048812883, 0.08920297912892797, 0.11236057601748936, 0.2044608843542876, 0.16218544074123906, 0.1693370860190161, 0.1299282668098327, 0.10767773334537784, 0.22349766365462737, 0.14391468807814584, 0.17075051823931356, 0.1697900125216092, 0.19190361543047815, 0.2661080868734468, 0.408724976042586, 3.089901035831821, 27.116525634642574, 60.330124670459384, 85.90093443470617, 85.24713808490385, 72.27141195727934, 69.64672657751268, 68.20151359804215, 55.342595654149214, 60.67051972112348, 63.210917288257235, 41.09008312225342, 37.92926857548375, 33.686487828531575, 35.380375154556766, 37.67324370722617, 47.908194065094, 43.73419207911338, 47.84516157642488, 46.82292915159657, 45.271388561494895, 58.532937803576075, 70.2652451299852, 58.489081782679406, 59.99655062152494, 53.93091893965199, 49.657716289643325, 40.36922600961501, 36.42853836859427, 27.868073332694273, 27.73658960096298, 23.66462415264499, 23.23642880685868, 26.213078268112678, 28.909203737012803, 28.17449869648103, 30.638192353710053, 32.827180854735836, 33.017860997107725, 35.27885636975689, 49.29394783512239, 57.980746530717425, 62.342688883504565, 63.94318457572692, 59.83784760198286, 52.63241044936642, 51.22959436908845, 55.7587512846916, 50.59439789864325, 48.121696518313506, 48.260293468352295, 31.110614384374312, 33.878299574698175, 35.767014949552475, 42.557504561639604, 44.540721601055516, 55.45585409287484, 44.52420842263007, 52.662722526058076, 77.79730981396091, 84.50988154257499, 72.09390901750135, 30.218994925099036, 2.5249267585815924, 0.46000926124472774, 0.12932235254876076, 0.3195432098882814, 0.21995928739347767, 0.18407638785579514, 0.19671493870837076, 0.1494551891641271, 0.20208339176831708, 0.1448037484360318, 0.13053617289950772, 0.11488471315392565, 0.17069503815183718, 0.15590843804661306, 0.18152382885736806, 0.11408146230443833, 0.0993789250271455, 0.25282579233809827, 0.20260943370240353, 0.12027572750324204, 0.09339218538615013, 0.14178032115582498, 0.14475983627621206, 0.1667966618533096, 0.15675116540683856, 0.09714158822692211, 0.10319290907993432, 0.10913667118837757, 0.10312101938911986, 0.0970115984279302, 0.19302195058234278, 0.15429787608163972, 0.09894338872043357, 0.27045391980678807, 0.10171252077505474, 0.10187633335590364, 0.15002428523955808, 0.14139335482351242, 0.19609716540623098, 0.12111135322840945, 0.0942763427813207, 0.10687600701085984, 0.14876177234034385, 0.13736999894101776, 0.16009959782804215, 0.1772955904204038, 0.15827594084605096, 0.19408897316503912, 0.09447269877719303, 0.1600178562465214, 0.16101331089533147, 0.1332369239460076, 0.1390627468185079], [0.02322076083791833, 0.030741857762839046, 0.06885237436020566, 0.06423803527028331, 0.04380294632527136, 0.027503121471513185, 0.02592534615447925, 0.08821290241734636, 0.04484786344091258, 0.05125423540331183, 0.029643119140077504, 0.024321600456812212, 0.03164280014443061, 0.0262425123007908, 0.0175694604554484, 0.04341688397670946, 0.034626833268351136, 0.03357517074853663, 0.06734753252878305, 0.014533856207685126, 0.07349485185958686, 0.03332281755583902, 0.09867800054170432, 0.033916868945403446, 0.015926417320095483, 0.1098621258091542, 0.0511454853920206, 0.038976596232744, 0.012345319208238396, 0.08311627267469322, 0.050686541268782276, 0.04678047727793456, 0.05726056774297068, 0.05747892578402835, 0.023574078673376672, 0.040356075436237364, 0.03929582890123129, 0.07961666812339137, 0.010784497416968788, 0.06039308211315544, 0.08434606595866143, 0.016654600171492468, 0.03866821903014376, 0.0352331152516267, 0.011451463139946423, 0.04877615930332292, 0.06501333923229287, 0.08649609937903383, 0.029758786925324993, 0.059850373936276284, 0.05703630699445644, 0.0357085379261163, 0.07401188459968375, 0.12695900194587248, 0.060126395415394544, 0.06850325277135258, 0.056752567179501064, 0.06106274255040673, 0.020322577442012487, 0.10239462248019635, 0.046689500506486625, 0.3221374593915478, 0.380273757562522, 4.515184942753085, 24.276223644133538, 44.83652322523056, 59.762047798402854, 57.82551088640767, 70.0167316006076, 67.88912034803822, 68.20818947207543, 63.1343133987919, 59.87734979198825, 54.367804296555065, 53.870612498252626, 45.51422642123315, 50.909274008966264, 44.088440941226104, 38.7281886992916, 37.8351983716411, 27.601522784079275, 19.37526525989656, 77.63005994981336, 52.39453046552597, 31.465822265994166, 35.943313721687566, 25.695766672011345, 32.63399824019402, 27.697399239386282, 33.1485112251774, 30.061015582853752, 32.7042753465714, 25.740081610218173, 33.070099123062626, 34.58325147628784, 38.54897560611848, 35.64262090190765, 34.39586024130545, 29.571537125495176, 76.21016194743495, 64.45275929666334, 29.53029536431836, 34.319903542918546, 23.017072216156993, 36.64841467334379, 58.98140984196817, 62.39431119734242, 48.87976123440651, 44.70460214922505, 37.07707481999552, 52.20779426636235, 58.82703711909633, 50.74236931339387, 60.12400411790418, 67.88817113445651, 70.19892569511168, 68.1820821762085, 73.33389574481596, 75.89473278291764, 47.13351418895107, 18.09414267539978, 2.1287460432898615, 0.28267161259728096, 0.08404694692862612, 0.15616460252673398, 0.03802837090446584, 0.04218238691288618, 0.1383314852512652, 0.023284790466629693, 0.032625918862439936, 0.014439208917469989, 0.024625398368845065, 0.09455322227891415, 0.035323835383619995, 0.055752810946996176, 0.04226161955645488, 0.07392673392689998, 0.01799947135300646, 0.04720676690340043, 0.010231102313545924, 0.019173794125597325, 0.03505107360861955, 0.04165518818603408, 0.040967210586513245, 0.02215926557959568, 0.08302781250207655, 0.014531799261608433, 0.024406511727119648, 0.07290448918337784, 0.041603733890599785, 0.04421017951362076, 0.0547190863759287, 0.017715988177505713, 0.031104686579877333, 0.06578757067120845, 0.041470250730673154, 0.08334262101280113, 0.004144715701019572, 0.06407156436433716, 0.08358273595090836, 0.012449285000442498, 0.08862989173541147, 0.01977719944871722, 0.02944133349604184, 0.01976119204153938, 0.021663869077700283, 0.044835468138297724, 0.08484458235362846, 0.05730437648092067, 0.12068786748474646, 0.11046976376805576, 0.010361029867893987, 0.017419450863775228, 0.02352293847399133, 0.01472647082165725, 0.07160195585099921, 0.034126723410501596, 0.02672192246292628, 0.03686141215204712, 0.059579833816256256, 0.014235231304360975, 0.021279813879499995, 0.03546777947415267, 0.0557616745842801, 0.03831909744129066, 0.0037139083114227345, 0.030936227675767678, 0.061885854229331023, 0.04640569174361806, 0.013948968187304995, 0.04164801760306282, 0.03318875599952956, 0.027821377377897024, 0.06015877795195388, 0.04790984409590883, 0.024025151243193016, 0.016156062709107515, 0.05225062084894988, 0.0837395235054916, 0.046596570210831786, 0.005002096886821693, 0.06657494817890468, 0.033850698100943724, 0.03391794529893706, 0.02353181360259412, 0.054532264344274044, 0.005832065052668294, 0.05784786223704296, 0.041874385093368834, 0.016696191084901654, 0.027647237931828827, 0.05646776250233093, 0.004169612122143829, 0.03783761118088038, 0.034985220690648404, 0.0598391545786252, 0.005712517032084326, 0.048312714413529446, 0.01618246018375841, 0.013395561592563266, 0.03253019234586147, 0.03173148439776513, 0.052894138535785104, 0.06263029633931096, 0.04288846717005776, 0.0823078124273208, 0.048583166433438185, 0.05653869841367968, 0.03819903614179742, 0.03060082097597901, 0.07236314081256429, 0.04055890870550948, 0.06553615593621809, 0.045976900841079416, 0.080727556900632, 0.04242973372099861, 0.032311638952383114, 0.3485903834864017, 2.532910497919206, 14.180932218028655, 40.925782880475445, 61.462622765571844, 70.29068562292284, 64.98156147618448, 65.2473295119501, 66.52590059464978, 65.03227380014235, 49.336685980519945, 38.63958627946916, 29.17775861678585, 24.970718506843816, 25.37794093931875, 37.43584617491692, 28.214163664848577, 26.69272726581943, 30.77704425781004, 23.183292458134314, 29.242922913643625, 82.10678654332315, 57.90312674737746, 49.929779729535504, 56.78452168741534, 51.82032292889011, 49.85811802648729, 56.21792747128395, 60.86657547181653, 60.981955912805375, 60.78535887502856, 55.26389721901187, 65.41094726131809, 68.8535213470459, 68.23550485795545, 62.781668786079656, 62.73885611564883, 44.87684911297214, 65.81952879505774, 67.77600703700897, 53.06369073929326, 51.859358356845, 38.240026197125836, 42.79507467823644, 45.55324615970735, 40.73982723297612, 38.88762127968573, 30.766547995228922, 28.23240072496476, 36.7331810151377, 25.154964000948016, 31.499248704602643, 36.33902203652167, 51.186016836474025, 58.713394288093816, 62.43242094593664, 68.81555280377789, 76.78118844186106, 65.9192511343187, 36.261496390065844, 6.809274823434892, 0.43532045377839, 0.04593900630190488, 0.059397129507194606, 0.02206606715316734, 0.019733758432970896, 0.08736714134894072, 0.04654210902029469, 0.048081777208755096, 0.027662123020197597, 0.060205237354121866, 0.046576027563142205, 0.027095206464911183, 0.07308025273584551, 0.01065062067937106, 0.074215778900731, 0.029040025997786757, 0.01225964759566611, 0.028053773980167125, 0.059525089173187176, 0.05165885240139981, 0.02100344383037619, 0.03255405981514243, 0.045350918906830975, 0.07450611856315406, 0.016415927393902695, 0.07436199444195918, 0.04920184754976823, 0.020005202536741575, 0.02643283535425942, 0.04296464695324821, 0.04935510343902054, 0.09555707325137432, 0.03346280097180317, 0.05828463577575261, 0.05327803285552129, 0.05147164349534339, 0.023418892242555178, 0.13966506046633567, 0.053749533159838575, 0.022589186461822643, 0.027877675264232585, 0.05514123912660345, 0.004581138275698909, 0.06599770092795934, 0.05910232738261262, 0.09573809982788178, 0.10637553709168589, 0.023734254251805045, 0.08108367287223378, 0.05476911574782384, 0.004668255400423322, 0.014694085412268198, 0.03538098554277132, 0.05448426893581787, 0.09975472179752204, 0.23715347201833803, 0.22290702518676558, 0.159726022712646, 0.11000572132968134, 0.12876171408401382, 0.07342303877756481, 0.15099093498241517, 0.182347986246309, 0.12544400944945314, 0.23436768521224302, 0.11964644756047957, 0.09866563588260643, 0.18962222091372938, 0.1567356751090096, 0.17732568235406954, 0.16338582390979414, 0.14701994887042433, 0.20322717636102633, 0.116000956885757, 0.20482068520880517, 0.22230820489987252, 0.18515813464839614, 0.1683651962347569, 0.09970945366207631, 0.29569081721767304, 0.17280158076074817, 0.14861174168125277, 0.13037652017608767, 0.1475636108267692, 0.10497344297266777, 0.10592583581925401, 0.11670192733647362, 0.19216020891983665, 0.12294375127361667, 0.15054917804175807, 0.14762773238603147, 0.2558963033821314, 0.12638750035435925, 0.17838887449714447, 0.11296303522202278, 0.13966047926054848, 0.14388180758443572, 0.10412466351784046, 0.12275017617690949, 0.14352415177610614, 0.12922535049578837, 0.20575486814543126, 0.19617136868257679, 0.13671746056887413, 0.16982744357758955, 0.13868201644189898, 0.13063152020256366, 0.163663883182791, 0.19764904503620442, 0.1632787707832552, 0.21053743248264636, 0.24341152169771735, 0.17001591652872103, 0.15109549066232097, 0.12884786833197842, 0.4824556680696626, 1.1723542790259085, 9.482452465641884, 36.68153124470865, 65.74538815406062, 83.22029252206126, 78.8282734347928, 90.51448898930704, 87.74455824205953, 85.63629996392035, 78.4318002577751, 74.17496173612534, 65.52600999032298, 65.51244251189694, 55.896818714757124, 62.9592070271892, 56.04931262231643, 50.59441751049411, 48.96211139617428, 37.369671867739775, 26.757622880320397, 90.14204425196495, 69.28205597785212, 48.01376073591171, 51.424022336159986, 44.4549197535361, 48.17633905718404, 46.3921352355711, 52.141227722167976, 44.227018279414025, 50.44178631997878, 41.2821380553707, 49.48254323774769, 50.43452209041965, 55.873104064695305, 51.345790663073146, 50.09708842923565, 40.816886117381436, 90.96753843369024, 77.42595549552672, 41.86108381517472, 46.419109375246116, 33.50057532710414, 49.6893580498234, 73.35560214134955, 71.2841356954267, 60.564070517017, 53.65958898298202, 47.8076127267653, 64.29229905528408, 72.2548124867101, 62.336267963532485, 74.3981053752284, 82.51741163192257, 85.89580397452079, 87.90253562311973, 91.82259944177444, 96.7747800580917, 68.71441841125488, 29.99552965164185, 3.526750110810803, 0.6803314291661786, 0.22231522226525893, 0.24007756833828267, 0.12003617180931954, 0.3190816265921439, 0.16604382725011918, 0.1571572073284657, 0.1850419037885243, 0.10707401775664861, 0.2490238818309961, 0.2183917795698489, 0.16977741803613403, 0.1194436027998886, 0.08580285875547318, 0.19337439699278725, 0.06022537014477196, 0.11043756509259825, 0.2301910657796168, 0.15927925555696412, 0.17622550348601035, 0.06889753524334201, 0.10333343258788509, 0.23880322704151755, 0.1423822824032076, 0.1290431441438775, 0.12177225728068622, 0.17835600932519283, 0.06355243254332774, 0.16071340279473414, 0.16998245380818847, 0.24117334986165648, 0.15583325417772417, 0.16373736633648797, 0.11484584185264765, 0.22243644801839707, 0.1475503881491961, 0.09219498914336005, 0.20726237596283037, 0.12228162148066106, 0.10982759822640689, 0.10012295728008594, 0.17406682093297282, 0.12976899713037476, 0.20132118024893347, 0.16097189618214486, 0.19214942240186278, 0.17465289351680588, 0.1976355312452201, 0.2682589859731736, 0.08060626986045992, 0.0963839962177219, 0.17197370018449523, 0.1193676298604377, 0.1487943004336088], [0.05040453664297539, 0.036452056900147474, 0.036463781875828584, 0.0029648301724885264, 0.033177659215946356, 0.03641514678395564, 0.11586357433829578, 0.06461203173403779, 0.06902228500093184, 0.02384168467664671, 0.037247803918416464, 0.06920020126046673, 0.11758158013464944, 0.017077116813931256, 0.03931229979160332, 0.023830266136135307, 0.05100769298751989, 0.03407950558128857, 0.024678358027050575, 0.07347934623999942, 0.06555748382403005, 0.11548386285862616, 0.03655581584861202, 0.044739684165124936, 0.06891834985224471, 0.023026942508295182, 0.02258387172684795, 0.024974504635939677, 0.043627098503132025, 0.06024990028010742, 0.03520280498290255, 0.059433618275028084, 0.0017691409682870033, 0.04243651742956812, 0.02896672478997179, 0.019643949945607496, 0.03792895184409234, 0.02792895910510373, 0.03527217424444614, 0.023551097950868072, 0.03155843854220885, 0.01468592657587461, 0.011538348044268789, 0.05787620365980172, 0.06280028741926917, 0.023453768395308047, 0.020214183661606044, 0.060512902094952525, 0.04082406322742182, 0.03553506114610261, 0.05263527742617073, 0.08251126239737196, 0.03534498324076976, 0.01661140621910172, 0.08704323171367569, 0.05035488265416315, 0.08687119134852002, 0.1136172743093583, 0.039964378510992375, 0.09369759399804378, 0.04835205685888087, 0.09103316318003402, 0.03737356874250597, 0.3844273024268689, 0.08692934508285216, 0.8517285869006188, 7.083892216605525, 21.718104808561264, 34.231191296731275, 45.346588242438536, 53.674274336907175, 53.357256612470074, 58.54466176802113, 67.18889098013601, 71.54298859257852, 74.51288961595105, 64.59603955668788, 62.54216886335804, 54.597717946575536, 65.71816298269457, 71.26116629569762, 53.791313940478915, 50.62378429597425, 58.02753256213281, 31.85937131604841, 32.71559138451853, 31.81047897185049, 27.930097772229104, 29.717162962882753, 23.418146333386822, 35.333275333527595, 27.56163816298208, 36.56360518547797, 36.873892122699374, 32.75528773184746, 32.44433006932659, 39.449932267588956, 34.67385822726835, 42.351533059150945, 79.927258799153, 59.790218260980424, 47.491026463047156, 50.6379165957051, 59.4901922441298, 61.027573077909416, 61.35398487890921, 52.40677610520394, 57.22024994511759, 66.38779394088253, 70.4913854598999, 71.76613223168158, 73.65250987391319, 67.07497750559162, 57.11131788069203, 53.234027508766424, 37.60396680524273, 29.83443202510957, 14.4122245811647, 7.458731070641549, 1.4125776338961817, 0.28391730220567796, 0.1003506386111821, 0.10616215096125681, 0.08345057812309073, 0.10898159200986547, 0.04457464967403681, 0.10795562407903134, 0.06131345631494638, 0.05469636037765492, 0.05313990720277352, 0.022074080432855317, 0.10133895332053786, 0.057556894382522, 0.058032887792515184, 0.05085402724122809, 0.034698998750818354, 0.026652629810175108, 0.04294041559220322, 0.03801195747068813, 0.022113250508423776, 0.06099767104211835, 0.04383347875949356, 0.029991375049576167, 0.008186206799901782, 0.05887185749147208, 0.046466457837771986, 0.010199208158038316, 0.006809328943716303, 0.02039070372589894, 0.036776230835746375, 0.043853377893326745, 0.08794166132687561, 0.05982287904067386, 0.012224212198728516, 0.07679465301935712, 0.12018765803546676, 0.00978456306902151, 0.07002417478830585, 0.03730742471112359, 0.02714507495834222, 0.05406699233478116, 0.010802828943386916, 0.04385079617702192, 0.014236943510871743, 0.045736847190006126, 0.0728217593484348, 0.05791885943542566, 0.006998571334406734, 0.012222020229655168, 0.048251837236626495, 0.026368972349671588, 0.10899830038749403, 0.05025730986568717, 0.053280484336878986, 0.03429416724811158, 0.016247608300839222, 0.010650338184448981, 0.011906090357731427, 0.013391385455766033, 0.06445686062497478, 0.13456171979346584, 0.06962334992544306, 0.09478593680767283, 0.03257797324969884, 0.0042470679205331595, 0.06803207039352387, 0.06552211354456602, 0.02142813616251994, 0.0298435679606853, 0.017905794121625445, 0.033827815054645466, 0.053275022129978866, 0.04639427320310666, 0.022615742899717826, 0.059347494670580474, 0.07546765083867697, 0.019021244952455163, 0.1472733707557763, 0.0468841289740897, 0.04252262571225724, 0.04984361855613609, 0.003466934252965955, 0.04469772935995171, 0.05025879224582065, 0.011468960588136989, 0.03743513922898039, 0.036736566633466756, 0.02091900944980162, 0.13690473842284373, 0.054952318014036265, 0.04429654826620414, 0.09526657271048716, 0.05680794384510768, 0.11796049488287781, 0.0756065579011075, 0.012978991707636705, 0.060755774949587164, 0.04752960018513184, 0.05434461493766116, 0.02684082505443404, 0.03530035861918042, 0.042287804441706794, 0.02225753359286295, 0.053959743855821515, 0.028255283832550052, 0.024286067383664272, 0.03031426961834152, 0.027311208785601684, 0.07761864952983395, 0.02610720202116476, 0.08643052991359465, 0.036972046739632086, 0.03798171998031678, 0.09335629416689759, 0.04944552096628374, 0.2081942912792006, 0.1019357281526731, 0.11523034904272327, 0.05911957202178817, 0.3412247851731316, 0.2364258723513734, 4.013778067404225, 18.15493352951542, 36.50802520013625, 52.27745163825251, 61.65510131466774, 67.0043513082689, 67.5854661387782, 72.60273456573486, 73.14981891262916, 75.94304853870024, 68.04345776957851, 60.08500791365101, 50.99359320056055, 43.5153159787578, 42.74835924948416, 34.86766645985265, 25.773409989572343, 62.7630179159103, 58.1630543739565, 29.90745871297775, 35.42608253417477, 22.945090839939734, 29.45514863537204, 23.733002831858975, 22.523334064791282, 25.770152461144235, 24.801162289034938, 22.412821285186276, 25.744531539178666, 24.390466597772416, 26.742627659151633, 26.67222111455856, 23.4440633943004, 25.045092528866185, 86.23953696220153, 63.555430827602265, 24.790112972259525, 33.11879142638176, 28.316684615227487, 43.990173801299065, 58.992710190434615, 54.41481390307027, 54.56286768759451, 63.521910252109656, 64.14660653760357, 73.70051968482234, 79.06263505258869, 76.6284356578704, 70.43735873314643, 68.88086026714694, 56.207137030939904, 48.70174446413594, 33.38172358851279, 20.149513675320534, 4.72876682396858, 0.46057484863746556, 0.09312291314164478, 0.06845633754686964, 0.06548979995591987, 0.11861038259080342, 0.030705922493530862, 0.044789349645256035, 0.04182873391396096, 0.033864709849078814, 0.10745690084032475, 0.02997339113555368, 0.056577010470772945, 0.06578345677905506, 0.03351657651364803, 0.0449823654977785, 0.0654670394836895, 0.007088411901701963, 0.02647333842281613, 0.12730314396321774, 0.04120013195901148, 0.024439013007307248, 0.030818085426524765, 0.07145813816497404, 0.02758106900258891, 0.025560356969494494, 0.05039116457825707, 0.027628715841039538, 0.043082298906219584, 0.027019005614302816, 0.0015910458751022818, 0.04178882456354557, 0.06356949715184108, 0.010284040904333516, 0.01620335140145354, 0.03367381989054623, 0.0353519354886826, 0.04204471708245335, 0.06400845021069532, 0.051281929481774575, 0.012675611313522584, 0.017344680682365454, 0.019598999736650337, 0.06897263484255922, 0.12498895322243053, 0.015440493495383812, 0.03115761176412625, 0.07129573518590582, 0.014015492389819795, 0.012237620652623236, 0.00432513946209163, 0.04338565057203655, 0.09182705243508663, 0.03335203231883145, 0.06255871308366619, 0.007874695818886281, 0.033640878109802166, 0.07961384891983002, 0.13064530978520073, 0.10253973485481355, 0.13389765945894105, 0.22824129540353055, 0.23360190372313225, 0.38742013215537996, 0.10544382861905521, 0.16832272432023482, 0.24043248155184332, 0.1352089874806904, 0.13474196496029056, 0.15112970414901936, 0.0908029997240632, 0.1161244119547548, 0.16588949117689364, 0.15452327447072153, 0.20790305529390612, 0.1922754591871654, 0.179972087123221, 0.10532705383675714, 0.27408995695652505, 0.1482377835218945, 0.15545039407668576, 0.1637202825757765, 0.13076518722359212, 0.12255244122277345, 0.1961601684771238, 0.14051642929834707, 0.14497870759617898, 0.1094088928713914, 0.15873395417246128, 0.20729041478085905, 0.1982858786059003, 0.13265120376261974, 0.2012348268181086, 0.2379575732254213, 0.14659199683416277, 0.1455412919242536, 0.08171807028233044, 0.139163778493962, 0.20271711502104037, 0.08053742153870483, 0.14815438719045732, 0.11189608924811888, 0.12453988014209656, 0.06624410544792492, 0.1550188414271801, 0.1143253617168915, 0.10513793737176927, 0.16997796453295216, 0.10757016693992962, 0.1925552804623881, 0.1722916419948301, 0.2787728072895158, 0.10224865208710394, 0.12075071733805443, 0.18575712347463255, 0.08265454382185014, 0.20665384168105744, 0.23455693957305726, 0.21312786686804988, 0.16248519562425154, 0.4141999000022489, 0.24390770152451532, 1.6846152106600425, 11.504787302786305, 30.917633771896366, 46.96239686781361, 61.626083620132945, 71.95151129076558, 76.65627664135349, 82.92193351253387, 91.473524185919, 94.73744607740834, 93.16611320741715, 84.58301805680799, 80.65841213349374, 70.87888425396335, 78.84451989204653, 88.05604150218349, 67.7201524857552, 64.36443144275297, 73.64347273303618, 48.20744737502068, 50.480025506788685, 44.77574609941052, 43.788697335027884, 42.5784029499177, 33.00318741029309, 45.638773441314704, 39.32067055856028, 49.26110190729941, 47.04287998137936, 43.49183274853615, 43.58132554638771, 51.25097128652757, 44.54425957895095, 57.77355517110517, 88.52199554443361, 70.11814055904266, 64.69138845320671, 64.56338190263318, 72.76570120165425, 73.70023727416992, 73.94223966906148, 67.68388625114196, 73.46847226542812, 82.27839023836198, 92.03803170111873, 92.82572207912322, 96.63865027889129, 90.36828656350413, 78.8690503951042, 71.92763190115653, 54.17196819859167, 43.607825079271876, 26.5111921295043, 12.758716094878412, 2.154239978521101, 0.4939226253378776, 0.10529561358834467, 0.3066995619766174, 0.2510034989926123, 0.2871152289932774, 0.1749360855788954, 0.17039981850933644, 0.24212469316778645, 0.18225188817708723, 0.2326861068966889, 0.13604434507508434, 0.09831659090254577, 0.1979058683519402, 0.22633520736088678, 0.21674380187065373, 0.1975294893547412, 0.06229666121784718, 0.10549467387458972, 0.2562151644979754, 0.20507976082303833, 0.11741842638941542, 0.09360159552025218, 0.2530930344496043, 0.14438451448034856, 0.10612245994589983, 0.22919705137610438, 0.12050252783322528, 0.06428341831891768, 0.14811646583820545, 0.19715145560762576, 0.13694944731410474, 0.2033134531830588, 0.15807165584016233, 0.07490275292507104, 0.1351768271096291, 0.34398116952469276, 0.07882216599799934, 0.233548384820742, 0.10579027656105258, 0.14451162378874519, 0.1478231001284815, 0.19892697162445516, 0.16081844877091148, 0.19743876922274792, 0.13575523881421936, 0.1977843668071493, 0.1821862497637349, 0.11548704978439117, 0.15789861189982585, 0.10983976370264446, 0.16883137605844006, 0.27272647366889063, 0.2429099792554494, 0.1500671708415593, 0.1070370233707851, 0.07681565915024088], [0.06855779823156134, 0.04926355593206902, 0.05044028230552232, 0.023527569475493604, 0.07824527880837841, 0.039566491595319206, 0.03562291610925909, 0.06277784870396699, 0.040558337970005895, 0.01668697696239237, 0.036949374367513006, 0.029538596018908486, 0.05733582439021238, 0.0313365928858759, 0.044410519166699344, 0.007887345845735963, 0.029556482256720626, 0.07226841404072701, 0.04415773696476414, 0.0036775990954465085, 0.05635329364468494, 0.01622471567844191, 0.024222794266778137, 0.07050039036379707, 0.05839543890268092, 0.02837717991262194, 0.023233006753387953, 0.05870132631952724, 0.04290745465926105, 0.04002815533068873, 0.08365026660143368, 0.03154237176321688, 0.017684994175309138, 0.05913229291177085, 0.05672090093515093, 0.020957179780628894, 0.06065259439750545, 0.07700489052841741, 0.05802582829229294, 0.02390213858997149, 0.0361474143761781, 0.09061460338172414, 0.05608241261553861, 0.020865705052030184, 0.03842031680828622, 0.0283462108082829, 0.04660061515507199, 0.0073965846545874115, 0.05030256267937441, 0.007478180679402525, 0.05561672691856662, 0.00687346869756678, 0.03503438055274948, 0.033662861002789396, 0.029968290905197783, 0.07319564089900063, 0.02866477123461664, 0.026923399756572423, 0.05180316038369652, 0.13104336907065686, 0.0658953745639132, 0.051500693549432104, 0.02575796360390321, 0.06978278814424431, 0.04206548189564098, 0.06403669587246354, 0.24739214519579567, 0.16826456292502343, 0.16527588539306196, 0.5749378942193524, 2.958892156039515, 4.925631563509665, 10.919384341086111, 12.454216614846262, 23.060628175735477, 37.716162281651656, 53.3452110136709, 65.05984806245374, 69.67095898043725, 69.54718466727965, 68.28250269736013, 74.2538013765889, 67.74512229427215, 53.97588499130742, 60.076751324438284, 61.266723909685695, 65.30185437971546, 58.16954197422151, 70.3252181699199, 68.23133930083245, 79.78435900903519, 73.18786590330063, 80.89859454862534, 82.04289113321613, 79.25996165121757, 74.50059690783101, 73.25818615574991, 77.59225614609258, 66.47778095737581, 57.3385682413655, 61.921089003163004, 69.55300546461537, 68.07907289074313, 59.61659454530286, 63.74519901890909, 57.576691412156634, 64.73944533255793, 55.790683300264426, 40.03318871221235, 31.269448803317164, 28.181943355068086, 17.145484109078687, 7.733257268705676, 5.929420513491477, 2.337612500113826, 0.2970799797725293, 0.08412667369890599, 0.01584313302901724, 0.08052990621616764, 0.09949272738829737, 0.18573593348264697, 0.051829303134112596, 0.01458968773799678, 0.03307861170821613, 0.1841349782602441, 0.030546424902915478, 0.02701967594123656, 0.03353008647419272, 0.07191471890696595, 0.04392164015781976, 0.040778699330985546, 0.05579150604805159, 0.027541929570537423, 0.017939143844189185, 0.06691824749953325, 0.04580043248772141, 0.04302048710204902, 0.037990503178368655, 0.021286300728998838, 0.026121943468047727, 0.03497982743166147, 0.10172215816114219, 0.039080355181208545, 0.03056976377152868, 0.03943359449265465, 0.028500433883539615, 0.010006862632449596, 0.01883943505104511, 0.02793483116904334, 0.03566119752283539, 0.03366157014463698, 0.06593913350614809, 0.026952384693187573, 0.0432928811548458, 0.029039265655521906, 0.047873470241263996, 0.035374282273433866, 0.02114901968818759, 0.022481792426157384, 0.022702186345873822, 0.008112860584421264, 0.07425279626923223, 0.08642048650090733, 0.03619799916181834, 0.10080867492023016, 0.02163515418707844, 0.022421263819259983, 0.10640802688055462, 0.06694037211878646, 0.020186181232753782, 0.14087569389131763, 0.018857767535073143, 0.09389201179146768, 0.08545428108904632, 0.08510400270742756, 0.046842645312989914, 0.046388466256640615, 0.023946834074693824, 0.04800614517843051, 0.06743349525476657, 0.06136391086563949, 0.08195552689534041, 0.06718547428928076, 0.047958701353279815, 0.04789687422735076, 0.011927147241940182, 0.06687434300059272, 0.08222233999760882, 0.020807784974514958, 0.05103692307227081, 0.03184548977221693, 0.03222860268227035, 0.033477785651602095, 0.029850050979744525, 0.0432844158832825, 0.041550801045471625, 0.06805001217271052, 0.00727665837809083, 0.02519534671709182, 0.0391065132533831, 0.08888220279327325, 0.01811847353594438, 0.022517028640234665, 0.07206697122103746, 0.019604048256071347, 0.039906056237316904, 0.07844116749061693, 0.04327110510559813, 0.007948832062538713, 0.08962885506691472, 0.0219362324869801, 0.054477400957576694, 0.038511511914792566, 0.047201174461553176, 0.027023701733278654, 0.03730072910266538, 0.015045760946738866, 0.05205675846927109, 0.05697531490436485, 0.043435905939869346, 0.0572100097704078, 0.044978757223655144, 0.045094049625819733, 0.0919900759453735, 0.07269101112239784, 0.028409853562592503, 0.048252572681033806, 0.03779885862323065, 0.008875396733562793, 0.11448512935350019, 0.05653069662531057, 0.021607410312900623, 0.03623553747010808, 0.01797248590587368, 0.006395264166302138, 0.11230455200758674, 0.01143424722906803, 0.029009625713731495, 0.10227696669678535, 0.028217902572284785, 0.05410318998920341, 0.10647850696958842, 0.09337657251425328, 0.2949451991627294, 0.6234070514478992, 3.5129585669886683, 8.217029658056076, 12.164061242534268, 21.729687567680113, 26.46079751753038, 39.774920248216205, 56.96826904050766, 68.07644490272769, 76.21668877140169, 75.99068180207284, 75.6652819725775, 74.33770871931507, 73.84422748319565, 63.40539624614101, 58.721525361461026, 59.23719544564525, 49.7608510909542, 56.584163096643266, 52.19681555225004, 50.905210433467744, 42.82199782709922, 53.46304293601744, 50.765519142150886, 57.24898522899997, 55.99020642618979, 52.65406585508778, 52.06324315840199, 55.56083633053688, 61.880563074542636, 63.15366245085194, 69.49358940124512, 69.512479535995, 72.55041014763617, 76.59416983204504, 76.46937570264264, 75.42452689140075, 70.47254239359211, 72.86407424557594, 67.55914703492196, 58.80839409366731, 49.95778153019567, 44.18429582349716, 32.138851957936446, 20.216701915187222, 14.014579596058017, 8.179125833895899, 1.721329085769192, 0.5006912572970313, 0.056857536546885974, 0.06363988531032397, 0.11491963144151435, 0.03534810887950082, 0.05511030832666063, 0.03794134331626758, 0.12641114182770252, 0.006291804470933013, 0.08341450304273637, 0.06044583492762139, 0.047892024890790065, 0.020499779324557994, 0.05141181968933633, 0.00639123406501547, 0.048507044106842055, 0.09164133740048255, 0.0332554133098212, 0.07696281697961592, 0.021562818250048067, 0.03445703754081361, 0.09200372763218419, 0.05760071461179084, 0.06356793433247555, 0.0417257065794641, 0.09726140437827957, 0.05523351824752266, 0.022962049115449194, 0.03725202889331887, 0.011727793927064106, 0.04652600202168669, 0.0675707399064014, 0.026252329717540455, 0.04623276654690985, 0.05168812845142619, 0.04594676677257784, 0.03185551786314576, 0.05777759665262796, 0.06211313336426693, 0.04244214817581158, 0.0338391684776833, 0.011418244609939716, 0.022528418452448906, 0.04063931729404196, 0.08424548627508265, 0.055285681174286914, 0.04514777537194952, 0.05705842395283042, 0.07592098336786994, 0.05201809401173265, 0.0070406013119575245, 0.04466244718059898, 0.08569970501646881, 0.045812145972083655, 0.10358229625008761, 0.03250878018837783, 0.059183682089731585, 0.021982136475402984, 0.07930978096180386, 0.02918114322387884, 0.13219515162129558, 0.22128400663214348, 0.20940941397941884, 0.1783119439477882, 0.1735998750213654, 0.1640988985497144, 0.11367165889110296, 0.18560444215132346, 0.12749339423833356, 0.10013337607585615, 0.18581153103901496, 0.17586541151808155, 0.22395216829834447, 0.17013588589766335, 0.1619388217166547, 0.06417935676572305, 0.07679684403082056, 0.13157891049500436, 0.1245559756493857, 0.17496178016787575, 0.161549357937709, 0.20122563376301722, 0.15977496040924904, 0.19248680752371589, 0.19769284994371478, 0.16197349485610762, 0.1490003321199648, 0.23276245521922267, 0.12034371014564268, 0.12928755683523993, 0.21763218807116633, 0.13358051438004742, 0.06208191911179212, 0.1393356120153781, 0.10114402990908393, 0.13890755272680713, 0.1490926303930821, 0.17431265854787442, 0.15184860105716413, 0.2038441069664494, 0.1093389873483008, 0.23161077992089335, 0.23947093395456193, 0.1512928502333741, 0.1647226166941466, 0.14810273754260234, 0.11301780284772958, 0.14178643453746073, 0.22022783185445496, 0.1065678251606803, 0.18582407955921468, 0.08318486052655405, 0.07875516394814176, 0.1885588602313111, 0.10453906345872149, 0.1889880380082515, 0.14462486690571233, 0.13075731183973052, 0.1837611733184707, 0.28093081568517997, 0.12821984477341175, 0.170390717384796, 0.18800196027563465, 0.15519521018910795, 0.14326336012492258, 0.14556330929119743, 0.4331482267908512, 0.21484352077447602, 0.26566467518287323, 1.3650489262034817, 4.181985480170097, 8.102164518448616, 15.665152188270325, 20.005270473418697, 32.097616080314886, 51.56979722361411, 72.17314873972248, 84.85730940295805, 90.13087334171419, 90.898175239563, 91.08171862940635, 95.22148224615282, 88.20746068031558, 70.63780753843247, 75.94966165481075, 79.49859865250127, 81.96211384188744, 76.01947199913764, 85.78259652660739, 85.42778676556003, 97.93006712390532, 88.36554004300027, 97.99656698780676, 99.86199132857784, 99.0183287282144, 91.6266848964076, 92.76124615823069, 98.8497374134679, 90.5534302803778, 77.86204461128482, 85.68967557722523, 92.30686310798892, 92.88738958297238, 87.39997017768123, 89.67867112928822, 80.19026156394713, 86.22187060694542, 72.65041489754954, 60.24142026901246, 46.62055054018575, 39.124606963126894, 24.603667028488655, 13.410393384195144, 9.114283111787612, 4.086615255763454, 0.6468793112904795, 0.2289502178469012, 0.0755173393014458, 0.25046821803815905, 0.17675571293840486, 0.18672427883551967, 0.14532755339337936, 0.2174905230922084, 0.26465533902087524, 0.3473711392331508, 0.12867093266498658, 0.1880552493516476, 0.11074722549247165, 0.27303226532474645, 0.1660476423679821, 0.148096164508212, 0.14324316604723855, 0.16413096699022478, 0.17585572816671866, 0.1426589014309068, 0.12607862136416859, 0.2910261078467292, 0.17987128527414414, 0.11724958061090401, 0.21298853079638175, 0.1230899591539656, 0.16790064051747325, 0.09865101892501117, 0.1290450440419297, 0.11564854877970873, 0.15110571027523087, 0.11413446026704005, 0.14257345198383256, 0.06635344151647822, 0.14100620463009805, 0.22070941004541614, 0.12670757955000286, 0.11636921535095862, 0.1340831599889263, 0.15594901006308295, 0.23372017237688267, 0.10865673242557435, 0.08251129304088893, 0.0856602591492476, 0.14400678716840284, 0.16565292322587583, 0.14668449429014038, 0.24121615885486528, 0.13565295075456943, 0.15435878007162004, 0.08792761893522355, 0.11657540791577871, 0.21538846975853368, 0.14973543944858736, 0.12725702547017606, 0.31870085025025957, 0.1184800863566418, 0.1286357845510206, 0.23602850254504915, 0.1572024524812737, 0.0817815789712533], [0.039369373341962215, 0.007855141903423976, 0.029371433718610677, 0.07349233909119522, 0.031410882347113186, 0.0790865199580308, 0.03199593794922675, 0.10823325434279059, 0.0036311487905726202, 0.03180847048849589, 0.06352262023175437, 0.060720849001119216, 0.030315424495887373, 0.05443369564149649, 0.026912373836122216, 0.03385222644635266, 0.010441027641777071, 0.0804344363390438, 0.04570853641076435, 0.04243701921715852, 0.031057160400274782, 0.03069387576092155, 0.0586968791791268, 0.026507691720560677, 0.04416445172542045, 0.052965377051863945, 0.014317395191849961, 0.04149155946628701, 0.08031835103587759, 0.01674338401625714, 0.016337072048636696, 0.0762660906559998, 0.02972395099218815, 0.04841231733500477, 0.09909780906333078, 0.06832352088343713, 0.011962642010691906, 0.03500001384846626, 0.05331771620999902, 0.0360318883171966, 0.057630534584243456, 0.07249940487165606, 0.04623777676193465, 0.11165954427973879, 0.05139854338560855, 0.017528666273480462, 0.0418968046564729, 0.020008678660697995, 0.10396969159163776, 0.017515989433553432, 0.015142467098250506, 0.016788127381474744, 0.033939552808841394, 0.07797877214127973, 0.004250947198259735, 0.048091188598904884, 0.06816987428934344, 0.006682163615140223, 0.03346693018571504, 0.05913480951060211, 0.030933282067698818, 0.03863667919030113, 0.04984554526726565, 0.057736637761756304, 0.11101260601032166, 0.031185378620941794, 0.05418672804690657, 0.06853689935298697, 0.06791299734745296, 0.06339797389603431, 0.015153741039666197, 0.23855417185733396, 0.24519376396652193, 0.084914012902206, 0.07069549763635283, 0.2341348557702957, 0.9765710104857722, 4.256227122199151, 7.7100848863201765, 14.075393003802146, 26.52186489874317, 40.97567935143748, 51.37431021659605, 58.76935082097208, 54.68048387958158, 62.35029435926869, 61.576449947972456, 56.06141313429802, 58.85826310803814, 64.521836157768, 58.95205482359856, 59.27927463285385, 58.687526256807395, 59.25955295562745, 55.45950581950527, 54.1935412345394, 53.20075404259467, 44.44125421585576, 40.918275463965635, 47.728835844224506, 38.33386105875815, 30.79048033683531, 22.810783001684374, 12.107030960821337, 10.56388718466605, 6.301343085304384, 3.9308645552204506, 1.4879541892197825, 0.3071438316856661, 0.056759592205766714, 0.11406555065825102, 0.18394028467516746, 0.21042864799739855, 0.27206791384566215, 0.059664750832223126, 0.006529242889354787, 0.06344972696575908, 0.054319655793088104, 0.033886409289534056, 0.036389379416622465, 0.06775108466465628, 0.031155968505528667, 0.0365468104850621, 0.016008687502283965, 0.06972657261236061, 0.10099556973023761, 0.06260867733808775, 0.016899773205119758, 0.04535751492385903, 0.046434140418686216, 0.0374664798859627, 0.04653505718095168, 0.009123005926789296, 0.07493538827064537, 0.011704863957880486, 0.03507915073104444, 0.014663468708374329, 0.027013415087675376, 0.07118040064890539, 0.03774171612495857, 0.04338709847821344, 0.03986925337343447, 0.10186786042346109, 0.03121764624431249, 0.03339844958616361, 0.048641381454804254, 0.027770830896652998, 0.017575322943288955, 0.002868385687883523, 0.023864816701520356, 0.02790552064506037, 0.051267902411881, 0.0109758929935314, 0.026293271371433814, 0.01063075123144494, 0.039221434102904414, 0.04925190373474071, 0.07027459360899464, 0.0630101916800824, 0.029420624224228725, 0.017433684777408358, 0.023968692478393356, 0.03697087462510794, 0.03552912013424981, 0.06743771639922935, 0.018293086041305816, 0.007858288130768004, 0.0603216290924578, 0.04809797230747439, 0.020376546421058236, 0.053714660837525324, 0.05810869985350198, 0.028531086976609887, 0.05537473889548452, 0.038258668425823414, 0.010454347037950592, 0.16777294898225417, 0.07402755875861453, 0.023104330795186184, 0.05295830989076246, 0.020340019348828543, 0.041000340058798754, 0.12549533734037993, 0.012341546225211313, 0.02224744613011999, 0.04926310010975407, 0.04505885554657829, 0.03133811548562541, 0.008142296555301836, 0.05312642788574581, 0.07051141436902747, 0.03928460188270096, 0.03654984802368187, 0.10039716313082366, 0.038455514717967286, 0.017142749481624173, 0.06158441395288514, 0.028044017850451415, 0.08674646457356792, 0.0259648360717561, 0.06334673027477919, 0.016017817355121578, 0.012606598282863778, 0.038446624267606005, 0.052498687779711145, 0.03897841569156416, 0.08414118340419185, 0.03381055509371143, 0.07349714246248046, 0.014394163905132203, 0.03949054163850604, 0.0510519728695433, 0.10320797802940493, 0.04470476587753623, 0.04163709318926258, 0.053067308880629084, 0.017329393397836436, 0.07640423163050607, 0.014266162104303799, 0.008612895748698184, 0.03953120941596647, 0.021398138074624925, 0.058513067873014565, 0.020925055798744003, 0.11570046655833723, 0.016954092669390866, 0.0005485804203706193, 0.052277924222571236, 0.05922051942757061, 0.07119166214139232, 0.06513049705855309, 0.13904685815495832, 0.028593825747168837, 0.05209743007717114, 0.073142014744301, 0.08911317830244381, 0.03827816153305673, 0.08738175064565674, 0.03239750974781571, 0.06147310137748719, 0.09240479764318274, 0.025339693003784747, 0.023131394766331203, 0.10128819999555427, 0.10908121408353891, 0.14017490730170282, 0.1551650110031328, 0.1646042101445698, 0.13982805333310558, 0.24212717529266115, 0.3309122917632903, 1.514393660810686, 5.3865125102381555, 13.766207272006621, 21.58496387543217, 31.12844744036275, 45.34695302286456, 58.18864783933086, 69.52813763772288, 73.18617143938619, 72.78100629006663, 79.68206359494118, 76.87932614357241, 74.02893189461001, 78.57798699409732, 84.51338814150903, 79.92326582631758, 79.13366133166899, 79.89057679330149, 79.56537308231478, 77.32804529128536, 72.82605863386586, 72.61797689622449, 65.45432475305373, 61.24397024031609, 63.437991142272956, 54.72768568223523, 44.967918703632975, 37.081554166732296, 23.054228828799342, 22.000150680541996, 14.763593442978399, 11.756136705798488, 6.0651796287105935, 1.6832657927466979, 0.8744260560600989, 0.37569693379825164, 0.29763156307801125, 0.11486400579733234, 0.19249587800473938, 0.09093462129033382, 0.03304351338996522, 0.06922672322440533, 0.04223518952306721, 0.049383035004739805, 0.02355345558645504, 0.12152046716261296, 0.06010978662919614, 0.03148006583233515, 0.0071291620336142525, 0.01867590209228858, 0.033548595158443335, 0.03471711289978797, 0.047036431083876284, 0.07853417822550382, 0.03350248049584127, 0.022753150345036582, 0.03910277091387299, 0.03828045213595033, 0.06717339308271486, 0.025365035192319946, 0.008274661226859017, 0.015508304725611403, 0.04767446358117366, 0.08085180104019181, 0.05352462123658869, 0.0136554358534575, 0.057511480690370646, 0.04226321301933739, 0.005390952104672549, 0.05384282734725745, 0.026144529655275327, 0.04303892683838645, 0.04359594936813078, 0.021204181849175406, 0.018239990402493748, 0.027595178426934347, 0.06861706279338368, 0.04672182175601202, 0.050365960285548246, 0.0305618922181067, 0.06579610489068494, 0.025667549907079628, 0.05314993146326273, 0.03844846287862428, 0.009091184549634496, 0.02313147137512363, 0.010572384907713821, 0.036146839810234886, 0.009799303558294573, 0.04076015234233872, 0.012440497971951, 0.03425062281049548, 0.0707836207302828, 0.059225801603808526, 0.012932534220688527, 0.026684987448876905, 0.05126883703914862, 0.028119690100392027, 0.021274734716562015, 0.022363341826524948, 0.05762350572753818, 0.2513245357981613, 0.1390116027886829, 0.058782769126757506, 0.17985035575205283, 0.12178652949871556, 0.18025864997217733, 0.15377963292262248, 0.17348315386522203, 0.06360835696180021, 0.12598201767691683, 0.1614365897952549, 0.14319379934139792, 0.13115204630359528, 0.1826355603313254, 0.15120813623070717, 0.19735813080783815, 0.14830003582662152, 0.21334577291723222, 0.20577916845438943, 0.22045814852801063, 0.21676828604071371, 0.1169778798676787, 0.15660415313416914, 0.08683127816766502, 0.1523931516755012, 0.25189516404944085, 0.1028543595044363, 0.10851508276837488, 0.20538607341868265, 0.17015267854496358, 0.18872255789897135, 0.1420902190429549, 0.22778133621379254, 0.13613527971169642, 0.16262548164494578, 0.13117824651060567, 0.2867666589877298, 0.12071598291156754, 0.2481962004376035, 0.12030105437001876, 0.14830887648126773, 0.1903733394799694, 0.12876169876225535, 0.17961046297944364, 0.26691321463834855, 0.08839625790114365, 0.11266550199399072, 0.10559431127002163, 0.1712191495443544, 0.18402398744177434, 0.10440520491571197, 0.1855368731964019, 0.18104251113630113, 0.16584519597311176, 0.15307405062260168, 0.23864873775070716, 0.12883843012875126, 0.12943119832104252, 0.18921772648970928, 0.27841660704824234, 0.10508143072647434, 0.19102457550264176, 0.11382997096065553, 0.22439672912080444, 0.3121804920656066, 0.22565248512452651, 0.17817683668146211, 0.18724048420065836, 0.1786021227317472, 0.18495659223727642, 0.27778841495033235, 0.3789169852051043, 0.5591732143394409, 0.2198633272200823, 0.15744835138320923, 0.40742896977932225, 2.2629859755116124, 7.375661153947154, 14.149971969666021, 24.737406123069025, 41.30744126535232, 56.39892524288547, 70.46123027801514, 80.42736099612328, 78.68717793495425, 87.74265981489613, 83.94074563057193, 82.81230326621764, 84.34286702063777, 89.2211344934279, 83.9233224622665, 84.9988598977366, 81.51278280442762, 81.75834671143564, 80.01399024840325, 74.05103837290119, 71.89564105003112, 65.82227445417836, 64.20617557341053, 69.32375861752418, 57.466049194335945, 47.01116369616601, 34.584545858444706, 20.530756288959136, 16.178116817628187, 8.755719642485342, 5.572115144421978, 2.573888969998206, 0.490173360392932, 0.28095664816998667, 0.19021604630735614, 0.24750069985466622, 0.3043504912526377, 0.45010625715217284, 0.316425109462392, 0.11049869890895583, 0.12293905515464083, 0.1853942123031424, 0.16596357187917157, 0.18722831872442078, 0.19510135835697576, 0.16708662613264977, 0.2179270553132219, 0.14244612817081714, 0.23368226634638928, 0.1947313225677898, 0.1983443157927644, 0.10406465585073156, 0.21055600245393094, 0.13389723044970345, 0.0634890502589124, 0.14967926988197913, 0.13822922783513225, 0.16617993043074686, 0.1660398589146714, 0.15763497040156396, 0.31372088037671586, 0.18258110680166753, 0.19660057710303416, 0.07807489319313919, 0.17332727029438944, 0.2041598730870793, 0.20835340774107367, 0.1833347534580577, 0.2346441050570819, 0.16469071679297956, 0.12056487206850322, 0.10543663505344622, 0.1188384622876202, 0.10596346605809466, 0.11465860230307426, 0.1574676721206596, 0.13061196963873603, 0.1442177524609912, 0.091815201054898, 0.16992488996155802, 0.11697836250307099, 0.1835764235546512, 0.12799912718154732, 0.1297251769011059, 0.12317286518913124, 0.10112942827324714, 0.07296456579839991, 0.1825988187544769, 0.1505059400393117, 0.14404538267802808, 0.17644814395856473, 0.19797823301726775, 0.15764658429449604, 0.07934616247732794, 0.18718638307144567, 0.14265333963257654, 0.09927438466899818, 0.21988139157333683, 0.09116059424535883, 0.12336266347237172], [0.05238655165979459, 0.0023636386040673265, 0.037890750869748094, 0.022545550093655626, 0.016303415890903245, 0.024121911978469263, 0.014258150739835636, 0.014202080764657548, 0.047511336649016994, 0.06833367154843385, 0.03556658949462637, 0.07181907282961954, 0.03595935894296535, 0.056049156738745595, 0.040477469728718844, 0.034215428731254036, 0.09027366361190235, 0.012729199163826003, 0.12168594981513678, 0.0019027057644580643, 0.00674914890682445, 0.015951785364098126, 0.06910030339514056, 0.03203794638055467, 0.013918344780141789, 0.0366137818914027, 0.03755999240844, 0.02267653772216891, 0.036789848048600464, 0.029936151601554408, 0.015198461422246071, 0.015164806222122525, 0.065336337222928, 0.08695432721006294, 0.05433008224973756, 0.039488806449357546, 0.043588916680985884, 0.02523306697126358, 0.02559569277500193, 0.02790756801503801, 0.05005071510470683, 0.055825194764521816, 0.0278895975075542, 0.023132835011628848, 0.03689839121615214, 0.03620027061251383, 0.05988900775029775, 0.04586268479244844, 0.02085148454493573, 0.01766088538833203, 0.009850318310782313, 0.054381582510447314, 0.05106772746770613, 0.0462231827869771, 0.040697693193872134, 0.04556342786658676, 0.037085063860661564, 0.02899164563014863, 0.022298576753406275, 0.061981956128992384, 0.059799367802277695, 0.039325886360940435, 0.013256643996423772, 0.02788790636846135, 0.023923922300098405, 0.06095475862703978, 0.08842241980375783, 0.04233455495728601, 0.05589906862306018, 0.022489656318700122, 0.027600550618503365, 0.10579280465120271, 0.05184919077662691, 0.12439332752218171, 0.11861706287750315, 0.03745272477728225, 0.04375819529917452, 0.11904891430129928, 0.13949172541258797, 0.2401823078792903, 0.42091389457064293, 0.05949825694363925, 0.43842075032091915, 0.5139874180238093, 1.0909619110245858, 2.5435197737909134, 4.195418617417736, 2.7581553016939475, 3.4416376198491747, 3.9115267799746607, 3.548648213186572, 3.7587730153914425, 3.0181971673042547, 2.671096334534307, 2.568628336152723, 1.7035362340750235, 1.1344612413837065, 1.361318874743677, 0.42898674525560876, 0.27227386892322575, 0.23923326283693316, 0.05537331397194536, 0.1280350950095923, 0.2282118316619627, 0.3104757625729807, 0.32215501812677233, 0.06692311981873167, 0.06646418718681221, 0.06167976125594109, 0.05493374804275171, 0.04458146402612329, 0.09785225735076013, 0.16870023712756174, 0.08357207966788162, 0.01102615889507316, 0.08364361695825093, 0.09476643220912065, 0.04501898833099873, 0.02821638188775509, 0.02651144172095003, 0.020839872567223448, 0.0725679237756037, 0.06140952374065115, 0.033023154603377465, 0.059532727069792256, 0.006005724257368956, 0.03597490669738862, 0.05121735593063697, 0.06566096698084185, 0.018423255870959932, 0.0382162309852579, 0.04641193536020095, 0.01072081731587288, 0.057943795597360986, 0.014813504155514943, 0.10802235799811541, 0.020367903034052542, 0.035356409442160404, 0.0650177825422537, 0.06018482494137942, 0.052763114518095414, 0.024480531142363628, 0.03858668812280221, 0.029169088830390287, 0.029086221099620866, 0.02825892083497057, 0.012485637787669417, 0.05713394873084561, 0.03077027579439023, 0.024910971049159288, 0.04689176687069478, 0.07470279631595458, 0.04890278980676686, 0.04486230419828527, 0.08904665122709929, 0.019776948554922017, 0.08069681379223063, 0.05674319792418711, 0.024406182309312206, 0.044931493429166657, 0.07713008461700332, 0.06501743014180852, 0.05698720458894969, 0.013063879995306414, 0.011195279507627411, 0.010699192568990252, 0.033090171974993525, 0.021195680188435703, 0.05550604253526657, 0.035780151825278037, 0.012854241950046873, 0.01048531614228963, 0.04227185449112327, 0.018125998434580622, 0.048236113281980644, 0.032021205444189335, 0.04297212014094957, 0.040246394628118125, 0.06986963187134074, 0.013173815527660473, 0.14712805919829877, 0.02074753024405049, 0.02772222453307721, 0.015225681483805662, 0.06563384746832233, 0.06009989643409368, 0.07437951487278746, 0.020595521162894946, 0.02083387792921595, 0.011631800237322047, 0.07191058969305408, 0.04456031233853391, 0.0194787411695166, 0.018351731987129298, 0.07786890747205866, 0.050651052245689984, 0.03180450598348773, 0.05360793329835419, 0.10577167594625105, 0.031015475641094872, 0.020206582154177373, 0.05164423927424416, 0.01415798570134587, 0.019470511469990015, 0.03657353929274025, 0.03737317037678534, 0.03743176461167393, 0.08563291747123004, 0.06830678952317085, 0.07483387395979897, 0.03312440078345037, 0.013153707634867921, 0.04756006750188047, 0.0095287557773953, 0.048154923283765395, 0.0818793700947877, 0.051395502016549154, 0.046550294669765624, 0.033584168451207305, 0.031267669870548194, 0.02604451113110108, 0.016624356935461684, 0.07763900448598209, 0.03725561801524412, 0.04574360408549828, 0.012449576113853725, 0.034782854735010096, 0.07227972149848938, 0.00735035029074718, 0.05038715410797347, 0.03770204809223933, 0.005836387703781047, 0.0352298210735523, 0.019650126529497006, 0.026840805902235934, 0.0683040622501604, 0.03801619010646978, 0.06128758169530381, 0.010858586737735858, 0.06012295951105415, 0.009976646209496164, 0.030912505763192332, 0.061317133536982926, 0.054356734448623274, 0.07750873889533744, 0.03041095182960553, 0.05668075792791863, 0.11341681974309106, 0.08613907176280215, 0.03191500842090576, 0.07121280616810245, 0.07051922080497589, 0.05911188815990764, 0.025272081914027373, 0.07035774479229605, 0.1711962741589354, 0.4087932497983979, 0.8918654041424875, 2.4963753358010323, 3.64123355477087, 5.996496965808253, 8.198081178049888, 10.773159361654713, 8.671339654153394, 10.081884764855909, 10.820204269501472, 9.857169235906294, 9.846483718964363, 8.550812082905924, 7.006937765306042, 6.827849697682166, 5.359845786325393, 4.786231017881825, 4.392531937168491, 2.775778510878163, 1.7259698625533813, 0.9216073888444132, 0.30488439324882727, 0.2047721918431982, 0.2682695579865287, 0.07038022947287367, 0.1590998837303731, 0.13253353265745024, 0.043419523149608605, 0.05284449603829173, 0.052034584054302786, 0.09184094927003307, 0.04589882499027637, 0.10931666354618727, 0.14579125109218782, 0.06435788206515775, 0.04487331288175718, 0.017126452876254916, 0.06712108459924498, 0.051702132538682034, 0.04556487960320327, 0.042558195174581585, 0.10884833867631613, 0.04792030502651488, 0.010474226061975764, 0.03693747319160931, 0.026392830242853493, 0.048322769317535624, 0.02508887773259513, 0.027983565852346442, 0.04631449280667209, 0.05829979665577412, 0.06810970574377045, 0.016925571215969902, 0.05503260402850086, 0.07871637691653545, 0.032105090156678236, 0.02296723936113619, 0.06684334708317634, 0.026424126849780162, 0.0486903574558035, 0.12281176964602164, 0.05249298425511487, 0.04893893766547403, 0.02065846869241326, 0.14796030647572012, 0.00529062187847411, 0.07504331473741802, 0.07719199984304367, 0.026833792367289146, 0.03328527158667003, 0.023272458366268588, 0.021448607947076523, 0.0459494250976751, 0.045705269045767286, 0.07503117224381817, 0.037050099607797406, 0.052723649498676105, 0.07107388378391344, 0.03669830437208857, 0.030845731624492237, 0.07993995722743773, 0.03818360330056279, 0.07037384796046442, 0.060531031565680626, 0.006479373917118797, 0.02252685754830318, 0.02695420223678793, 0.04146296906495287, 0.04425227604505997, 0.01347200854891731, 0.013941856018537957, 0.05586732960035724, 0.03145756008433959, 0.02174660082786314, 0.013233476539983625, 0.027974368966815454, 0.11197066024666834, 0.1832003969578974, 0.13699469246691273, 0.0961907045735467, 0.2003412005761939, 0.13051397167146206, 0.10553086386813272, 0.15932327496909326, 0.14772893260082892, 0.16852985917320176, 0.2503629882008799, 0.1358123889733707, 0.14855459152210146, 0.13783268540376617, 0.128943614000755, 0.10457756703779583, 0.17222460930145558, 0.1287501155128402, 0.22285715286289492, 0.13359056545361397, 0.10414889487888544, 0.1770329448364435, 0.25242604765920873, 0.15232878496810315, 0.14270658274331402, 0.1051285298120591, 0.16871791843685413, 0.11492323205475846, 0.15001311567762207, 0.1682578979600822, 0.13011408909674615, 0.3344448763997324, 0.22053054383685514, 0.20741421458942277, 0.13257045809540058, 0.07474741327666468, 0.17255843977534002, 0.12162386604975309, 0.11904617170653037, 0.14282759399183337, 0.19046815052147836, 0.12423208899675839, 0.14891171106888404, 0.11170013161796717, 0.1277450387997012, 0.09260843913521498, 0.17817148938775065, 0.11863322733270547, 0.19066920263632653, 0.08404769003391267, 0.07760282215331832, 0.14003439145463129, 0.16859024222339355, 0.18182726096241705, 0.12651070261434202, 0.10597511825542297, 0.13044502375827682, 0.07293684873729944, 0.11520714423949681, 0.08692340790143899, 0.15009350894439608, 0.15116863673733127, 0.18237291474736508, 0.17206290346239844, 0.17261490045535952, 0.18584222052126162, 0.1953522674739361, 0.12264608014975825, 0.1460010212876143, 0.1459802603048663, 0.16071904120185684, 0.2278560144646514, 0.26795837307168596, 0.1839751723192392, 0.248326082984286, 0.1567860377291518, 0.22739122892099045, 0.23873276227424223, 0.30817348449941606, 0.30791405648473774, 0.41730984925262393, 0.28897385022813277, 1.0371579013524517, 1.1562650843012718, 2.651130734912811, 4.3296029010126675, 5.820292330557301, 5.1366697876684135, 5.382447463850822, 6.512273444283394, 6.353878821096113, 6.315763679242903, 5.086344307468784, 3.7512538317711126, 3.443338457615145, 2.516323039608617, 2.1635982634559756, 1.9481668621301653, 1.1118026894907798, 0.6192841501005235, 0.29720163453490506, 0.14104539768830424, 0.12843562875904385, 0.3741766782777925, 0.4212272551751906, 0.4072783875369257, 0.1363399324397887, 0.1297051973280407, 0.09522177954955448, 0.0866624860153083, 0.13343229168845763, 0.29483350354336924, 0.4187754367388064, 0.19869167537939167, 0.10728335128195825, 0.18264657667567655, 0.19095666946903353, 0.26043658475241355, 0.12662251314689077, 0.09005819372231923, 0.07693468623103634, 0.16405763705411266, 0.26374498141869424, 0.12764873388673992, 0.26213625806473917, 0.12232711178160484, 0.17643820013730757, 0.22064628440045544, 0.174352525763454, 0.11255658727379576, 0.14763556180461762, 0.12908799093096487, 0.13696838500759295, 0.15964227398076367, 0.15652326957112359, 0.13830545358359814, 0.1352634103668313, 0.15169452545383286, 0.15818967934577696, 0.19598867203439438, 0.3082795110681365, 0.12917097357492294, 0.1274513743156868, 0.1143442611059835, 0.21994436400071268, 0.21695622273029821, 0.20493080268704122, 0.20177723239025763, 0.15115950496927386, 0.1968869254473717, 0.14259879417236776, 0.1260093976593306, 0.0963574895755418, 0.10204416023747576, 0.28807103093112674, 0.12023571473095687, 0.15532072603462205, 0.18741211853921416, 0.10638604015712777, 0.15442746751491102, 0.2119931833998811, 0.11421557365646286, 0.21414255032375937, 0.18821966714195668, 0.12349942548861428, 0.11000138527202992, 0.07585438734461224, 0.09241051265909787, 0.18414783321561354, 0.09718225217394291, 0.08314867819389028, 0.10883949036079069, 0.18665925329250677, 0.12751233193182177, 0.1425812814024187, 0.09985212987709431], [0.08191464078282157, 0.02731414290235168, 0.01788508484981233, 0.03189038443979958, 0.04435221221478236, 0.0269242730968061, 0.046754970380495635, 0.05571922948283534, 0.05451125055251103, 0.02655085885987407, 0.04828369117251808, 0.05703403171332133, 0.03143010540835319, 0.0503079827514387, 0.046573545438267534, 0.06133691775762747, 0.015724398976852818, 0.03900458525505759, 0.04976136752614572, 0.010540314551983631, 0.08066820806913799, 0.06392311567680971, 0.03427134548884726, 0.029956922160401463, 0.03498789433750414, 0.024514767611699722, 0.016543222478620948, 0.0863670212246718, 0.046304851590145024, 0.07321466286216052, 0.0520772896256418, 0.1387153106230882, 0.04292603229142485, 0.03353164546311863, 0.04687331564303848, 0.039547289601497115, 0.08499553997910793, 0.052689378555383415, 0.05525030323394364, 0.02023779832187199, 0.05661755950460511, 0.019631711691017115, 0.026990275401922486, 0.1247988791475373, 0.009097217492038205, 0.021852583346527912, 0.017045326080293428, 0.06348203289352598, 0.05977478404078753, 0.028585272375494245, 0.032633572080803495, 0.031492284934727416, 0.049665307761320186, 0.039749751318125956, 0.08600596398595842, 0.02094150753691793, 0.03650481354505305, 0.04895896320381472, 0.04047468116867446, 0.05321226037678219, 0.03291828865786234, 0.05799629560281193, 0.028693897897497784, 0.03746192166281324, 0.08094118817919686, 0.04373836511325452, 0.01978747077256201, 0.07439442294379396, 0.05141187714593065, 0.057605943161874056, 0.051214383509490764, 0.026288659522129644, 0.057547908171170184, 0.1348382622123726, 0.030110800496092247, 0.05441214175774686, 0.032089015716807015, 0.06290549810435023, 0.11930261963918326, 0.1192684980830358, 0.16068216172918198, 0.06712732821582787, 0.04445019486029783, 0.09937245158418533, 0.0940484929108812, 0.09645518876852528, 0.09451225189672363, 0.01476823985050883, 0.11171383693093255, 0.11559719024526498, 0.27609376717479, 0.11844699135831288, 0.13805022373074485, 0.22658535038992283, 0.18600533596209942, 0.0371445965532574, 0.06757365870139292, 0.10002668301064162, 0.1256506616670278, 0.040682463365937435, 0.07614123364610058, 0.06431577021196004, 0.08266159949163276, 0.07636696911386906, 0.1504229880388706, 0.10454403536935007, 0.025384143340371312, 0.02395463476498281, 0.05198376944228526, 0.03561602897881981, 0.053405234094468824, 0.07288551318549341, 0.10421126209680112, 0.028956171928814826, 0.030693588477949944, 0.009873873599234128, 0.040751376805166085, 0.0745578678024392, 0.10477290413672886, 0.01255029943891831, 0.0398985562365382, 0.06471364563631435, 0.08465268498947544, 0.07083869479115933, 0.029736941928164135, 0.054805619837415796, 0.03331872664632336, 0.08386524619474527, 0.02557580513248761, 0.03528569186587007, 0.04754589487528128, 0.0426538948780827, 0.040677024141675046, 0.016117089901179556, 0.016912741158458016, 0.04406749946816314, 0.10154719134011578, 0.017196281790553082, 0.029559485321383805, 0.06951903939367303, 0.012495382426066265, 0.030842722814169624, 0.02694625407457352, 0.011596120649858589, 0.024438541863233815, 0.023044512734838554, 0.055439216685631586, 0.03376920932843801, 0.11024845628848962, 0.07389505619123098, 0.05719807795098713, 0.04747096764584703, 0.07127809984188888, 0.033322499629350445, 0.03938241598887309, 0.06414213255348225, 0.017085932570719914, 0.035247896918125694, 0.029264160341793494, 0.07939490865194991, 0.015889734157451218, 0.03183586196222853, 0.07760057751570018, 0.03812474476534032, 0.09002701394380101, 0.03075118296809735, 0.01284493302415696, 0.05120071267048198, 0.039671721432598374, 0.042517600175473964, 0.02137523587612856, 0.03647315879202178, 0.014468860350579265, 0.03815552234769829, 0.015132080861217072, 0.02059041710209943, 0.0796462391172686, 0.05086486355491704, 0.02933563251468924, 0.050920029546344475, 0.03902450354108888, 0.03274364359376412, 0.034697252070350994, 0.01423015118381309, 0.028867671536582134, 0.01630609145297879, 0.023541140723072236, 0.05102371571645622, 0.1275151971006586, 0.0315259104489439, 0.02860429625387394, 0.0190372695966113, 0.04989188592580538, 0.024206541711464528, 0.02629356631528466, 0.015808529795087393, 0.010351768822499342, 0.027480012429277265, 0.014801181631252892, 0.04599966131330979, 0.024842352553781484, 0.027637974013604467, 0.03809633056422876, 0.03147819466258009, 0.0158295952977853, 0.09572783424969643, 0.06555677136226047, 0.024615916115562284, 0.05167979724524964, 0.020490185988526192, 0.03537977895429058, 0.04836489266205219, 0.06622444763178788, 0.03175879351704592, 0.03757911396303004, 0.014909551471411703, 0.0380254099746385, 0.02265426563099027, 0.03952829062097496, 0.0277557083210277, 0.027260687202215198, 0.08826485083949182, 0.06483650315673122, 0.015944187687109077, 0.050537924041911486, 0.02704846361021121, 0.03610490798769939, 0.05099964140343571, 0.012553416459160227, 0.0224482377750739, 0.028780756946352702, 0.011437257954610452, 0.051492695591502616, 0.08926490967672679, 0.04258804196011155, 0.09347252502676942, 0.020108406071461016, 0.0034134081685014313, 0.03177883246192529, 0.03024415342107175, 0.03670437178844887, 0.07830514857966094, 0.046609490283674775, 0.028440098713843093, 0.08753896720947758, 0.022393383964475606, 0.08967992248794726, 0.016997872679043683, 0.04507385171769608, 0.03670257148182681, 0.012407628969559747, 0.047604569549401926, 0.06034876392673581, 0.02246337567245768, 0.10912341020640828, 0.0695587840351847, 0.07692177764951222, 0.05778722637783616, 0.15439751347707165, 0.20249715585622097, 0.14862340153946033, 0.15454913759904523, 0.15565789665185636, 0.12721361126750708, 0.11316736619318686, 0.1458519865428248, 0.17363107012164208, 0.21049129866784622, 0.2275039357764106, 0.12942614214074227, 0.201649081202284, 0.04251422172772788, 0.11311896475813082, 0.24363710394790097, 0.15642580786539664, 0.01749377479896911, 0.0486501225180203, 0.0627478525312918, 0.07930247248300622, 0.08496557828038932, 0.09414717269640777, 0.1322051414078282, 0.009730477261567309, 0.03356396671264403, 0.0469177219295694, 0.11462386787658739, 0.03236910320758339, 0.06862105411146918, 0.062370845341994885, 0.024892450873589805, 0.046704768638817534, 0.044124270413791945, 0.054682122633582166, 0.026100186570998163, 0.04333409285473247, 0.008369735611091939, 0.04323103104627902, 0.030105296154356295, 0.06490366608505288, 0.03391978007951572, 0.029920389342512337, 0.044424664980221185, 0.05076986099142702, 0.005249467156376811, 0.021698260679841045, 0.05229654015913125, 0.02847701266047455, 0.015440535630219647, 0.019771990050832113, 0.02320127922200388, 0.02873461164023367, 0.021400244816416697, 0.04012218113207529, 0.006677771537309333, 0.02203787320233401, 0.11626260655541575, 0.03989020587816354, 0.03887267640581535, 0.01722224834074657, 0.048185321652600845, 0.03525432439581041, 0.033198378063858516, 0.09906942550573619, 0.032686236795158155, 0.05492522531459409, 0.06210367217840207, 0.04630520399059019, 0.011494784454454579, 0.010857863742257319, 0.055130211290933435, 0.06661423316766178, 0.08281690849652214, 0.012363930356748884, 0.06298579944057331, 0.006807561195831025, 0.04710336035538105, 0.003407440822376239, 0.01938388799317181, 0.022845563531342535, 0.034382830434028185, 0.019566408441131635, 0.07136497421250229, 0.07536789086917717, 0.05444471581628727, 0.02858717801920589, 0.03127638220546707, 0.0005558183951389736, 0.03654552728778893, 0.05780671565462986, 0.0728159983672442, 0.11258450351775655, 0.05607045015260097, 0.2727554624359454, 0.15292876970864114, 0.11156875519983231, 0.0965540217716367, 0.1511389278476277, 0.09275263220432306, 0.16267310167031904, 0.12467592969656953, 0.23156285346035035, 0.13394780757446445, 0.21449695791929, 0.09191432517142066, 0.29954031710663154, 0.20027508718832848, 0.12702192074709362, 0.24216391686950964, 0.13542094868758034, 0.1941147596845704, 0.2359033237782217, 0.059995160723525676, 0.27486493150072716, 0.16019368874690226, 0.04752752025641742, 0.16686643714145308, 0.12911166304782515, 0.08823696523904802, 0.11850846225335715, 0.14676660359386476, 0.13137877768566533, 0.20696810626935577, 0.10215901213908389, 0.29738696652554697, 0.1459538609149956, 0.21948192268610003, 0.21877087051829985, 0.13657925830733392, 0.20455278426168427, 0.09241750704184656, 0.16902174890762375, 0.08378166600220627, 0.10311531969496321, 0.10213052899005914, 0.10909381622989332, 0.14834335043786034, 0.11887095973736818, 0.25640178351633014, 0.25554367311058507, 0.11534509369202199, 0.18375954921207122, 0.13095585118618705, 0.18068900752452113, 0.13072651510517444, 0.10123520203295255, 0.14172618938309534, 0.2222746042835136, 0.06697022656519568, 0.15436717639527014, 0.1606978818533882, 0.1807199115113866, 0.1904850657428465, 0.17604283748134492, 0.15995626277740926, 0.11814489224625212, 0.21042785126595728, 0.21724588057446867, 0.21611632989539256, 0.11829173597957819, 0.12394927997863102, 0.12815090452110575, 0.14136082673024747, 0.13923788983975688, 0.1663241541433719, 0.20173502094562978, 0.21138235085433532, 0.27908491150986764, 0.15316051130573596, 0.2812470567803229, 0.2969649746533363, 0.21528956780750907, 0.19121389115048995, 0.31752046197652817, 0.22908907894405628, 0.32114699963600407, 0.21891438943003455, 0.21537376087038748, 0.322880442104032, 0.18603383443288266, 0.20452839202217518, 0.2791350136601156, 0.22519431858053132, 0.32324258718759785, 0.48987740530602397, 0.41202758108415916, 0.3911009088398949, 0.5650727042267399, 0.13364413032127967, 0.16089557850312802, 0.24592808988546175, 0.22845526376078207, 0.1124077057465911, 0.17873384388944796, 0.16946185109836442, 0.18853371722563622, 0.2078387651953005, 0.31281383227436776, 0.21866387867879486, 0.10590217902415222, 0.17895030969333264, 0.18461683224285805, 0.29114328865562716, 0.1594741330031426, 0.23424713361647823, 0.21588541567325595, 0.22781999301045175, 0.04665272062524192, 0.13825858432439067, 0.1598086529561589, 0.1777429857681836, 0.21630023696249534, 0.06719678174704313, 0.11607435576978231, 0.12560986748505987, 0.22108794941056162, 0.17001150386227717, 0.1369802593704193, 0.2270863412488853, 0.16186990444698643, 0.17497789865780264, 0.09813141979036794, 0.12571434655617322, 0.12433911147978037, 0.1300672811245726, 0.09846521195985618, 0.15028659374483172, 0.09010602059143205, 0.1182353059430757, 0.18590087221274454, 0.15584701311684426, 0.10006019935732889, 0.3461543158177407, 0.13730043815749307, 0.13905928410109014, 0.07979371104269259, 0.14811755368305793, 0.16543259633885277, 0.1915192844406251, 0.17113979815715746, 0.14885160381034498, 0.2187996907460113, 0.1419833191340008, 0.2178292105635328, 0.17185636615801245, 0.1722710189079085, 0.12495366721263818, 0.20985238133899628, 0.18100993707776072, 0.10775924510052128, 0.08042275349819854, 0.09397644234160263, 0.1785465353919614, 0.12677946924081734, 0.1736965399956511, 0.1686143433494914, 0.11398573195742023, 0.16986873571670827, 0.1126155454004484, 0.13145105042044194, 0.1693862688637549, 0.10660119595066195, 0.08755764443307154, 0.09869467061493667, 0.1553622939653935, 0.15107636910773095, 0.15722791724387677, 0.16333363800039216, 0.17718703576153327], [0.053425569898418845, 0.01969629673347358, 0.037078260999893954, 0.035361331557073904, 0.0333664117891702, 0.03017337455774748, 0.02797219902276993, 0.003033977507936558, 0.0686430178522583, 0.03993259352301398, 0.04695514915511013, 0.05366236767581394, 0.013605329872769936, 0.02119755327341057, 0.009417542793427505, 0.07347940752703337, 0.02819360226332661, 0.011185222688401419, 0.013675942111970677, 0.0503612450143743, 0.017051138772418904, 0.017374515976576556, 0.07590982146681317, 0.03103011558132787, 0.05926705543853103, 0.035912198570346644, 0.02042216887216895, 0.026693872153578747, 0.024316777933328867, 0.05605761434942965, 0.1319335172733953, 0.034787332518927516, 0.10825547855347396, 0.0583903176049071, 0.009887816399456033, 0.015584842654906455, 0.05024279249952205, 0.05751628789209551, 0.0695887074295071, 0.028932850297179916, 0.04749288159092108, 0.02755154014354752, 0.07429626409805591, 0.0728213303391972, 0.0394349811117976, 0.02775579067547956, 0.06719946305477811, 0.015189289434572623, 0.016066667909223228, 0.011293520707817329, 0.02535297505317196, 0.03317672075823911, 0.02941487090391738, 0.03463177070502312, 0.058858856979397044, 0.07023607470816182, 0.03650641083837517, 0.03571146821242667, 0.0718742618036847, 0.06981667221313523, 0.013696989420080378, 0.019829659234552134, 0.09336237690501636, 0.05718408918548977, 0.022615120453279347, 0.011775053891112969, 0.05432339047171897, 0.037134185418366425, 0.01747694767771229, 0.08597604825251526, 0.046556017346559994, 0.09294099024226589, 0.03212455836605401, 0.11281102805608705, 0.05058396209572112, 0.030049327685828173, 0.03887070755984995, 0.02229727823437462, 0.07001231574723799, 0.026892428737013575, 0.23454783844851682, 0.05190283608352465, 0.06930369973903702, 0.049929573621240356, 0.05380574486128265, 0.043462872234804016, 0.0019080184645117113, 0.075521384245686, 0.07905964559364705, 0.0276806470262067, 0.08083146140580216, 0.12565943337376081, 0.11402428916264927, 0.10593875972253662, 0.023595628726686683, 0.11242759338910542, 0.07395751533969756, 0.06314254486032071, 0.023432218341998035, 0.04170575764991584, 0.14233591876203014, 0.10590799363149751, 0.12491154003768198, 0.06020388903937513, 0.04753138516999541, 0.10903353277113169, 0.0353214911545717, 0.044887516151873336, 0.03856525298268084, 0.05196270202436755, 0.033823226187979026, 0.03417403317026554, 0.1294617958727383, 0.09521964216424574, 0.04058485227306524, 0.05540851954250567, 0.09767050299072459, 0.060960029311958826, 0.015931304961052394, 0.046314852867996505, 0.06984926925431337, 0.03466776534614544, 0.04177340704406943, 0.02364485945192076, 0.039709635123971014, 0.08326939066811916, 0.04026099243351529, 0.07827295756508267, 0.08757758570174057, 0.05014031674833067, 0.0852765946558887, 0.021079217586966775, 0.05342852699780657, 0.04237259505316616, 0.024187169263079285, 0.029885034384806792, 0.024737003972874056, 0.030559670563126286, 0.020747959253288085, 0.05863414040856785, 0.04279499295197668, 0.045411210026471846, 0.037519067991524935, 0.028325440249435847, 0.036655169791511955, 0.0467977372388686, 0.058657923608177134, 0.09160611267772414, 0.007776958800311531, 0.09750649122701538, 0.0689799509822361, 0.01483542959190785, 0.06314748612743232, 0.024136170789959933, 0.05107634978729391, 0.020369728238532142, 0.022691342371305632, 0.01994986226031136, 0.019921484448376204, 0.03684062052578215, 0.050291684230849634, 0.06457935808406723, 0.03874209288868212, 0.040383129831283324, 0.011815433427991887, 0.05605101833240159, 0.03434393615011246, 0.04132822185995118, 0.022492720670397245, 0.0390107982281235, 0.04297718015168944, 0.031396320930892424, 0.06397917799110855, 0.015391427479053458, 0.008587409918677182, 0.06561903898874599, 0.008859312717592525, 0.012115932373900809, 0.03963836979481482, 0.01768598625917108, 0.06301779510273088, 0.009972119587473571, 0.027678501980018713, 0.04673862589463111, 0.04805117582661971, 0.029616821256856767, 0.039857796528526855, 0.012286353420706527, 0.023698363032552506, 0.04275334458197317, 0.05583742535823295, 0.06350856634878344, 0.020446978629596775, 0.025520334621110273, 0.028999741264288465, 0.008238582316065028, 0.06445682232057856, 0.018673567439339334, 0.021390113303618088, 0.017001988486416878, 0.026930978281363368, 0.05232484710793342, 0.05989490662731471, 0.04617343686761395, 0.0679282731406631, 0.0745754954855769, 0.057578547857701785, 0.021502584587001515, 0.01884857639520159, 0.10857966398039173, 0.049264364154829134, 0.041985368250959346, 0.016292502968421867, 0.014098499931635396, 0.09479852363226876, 0.014527006424032153, 0.05552990234366829, 0.03637016210104189, 0.0975587001190551, 0.04574208340096859, 0.019494131875915394, 0.09275778797605345, 0.042961054000883334, 0.022668535933799805, 0.047419095832494, 0.022252584664872097, 0.0417195855369491, 0.06553092355569524, 0.06736347481848733, 0.07642494664797861, 0.011087479445362284, 0.022982509408686912, 0.021401817211881283, 0.03711964890000321, 0.0973770070460535, 0.08173166068210717, 0.029121011067482255, 0.02314130602885158, 0.04004819236034828, 0.08185432668054297, 0.06360801605267391, 0.05666557406525939, 0.03377258777618408, 0.01987113523477268, 0.058308407484043034, 0.026285713914060788, 0.03910252959617684, 0.049773490867547454, 0.06405797396456042, 0.03854688985513584, 0.11906373044175488, 0.04988935400521563, 0.020068213268513643, 0.07451781672575782, 0.10491955634807387, 0.05993747047238773, 0.07486588111327541, 0.06763408005598091, 0.004208334036276586, 0.07832332018522487, 0.05226308509947793, 0.11928083209861672, 0.0212470444685389, 0.04112559160397899, 0.07234522201601537, 0.03639944581194751, 0.09245151368480536, 0.055672333410550515, 0.03176171805769686, 0.08997072946400413, 0.026283630154906746, 0.02978604241845108, 0.03920492873857579, 0.05489784916261992, 0.03350491665544049, 0.025670275264870257, 0.04228227328689348, 0.05910683964048663, 0.06674497373281948, 0.1371155658196057, 0.0636441677418207, 0.15798062927299933, 0.08847305821555276, 0.0808011319848799, 0.024174961652005875, 0.02662408537411642, 0.022675861649575735, 0.03744623601256359, 0.09594219331178935, 0.04707364763523783, 0.06111404362825617, 0.04036937472260287, 0.09848741318790183, 0.04878403851762415, 0.05463961241466384, 0.012355281224083758, 0.06914086008985197, 0.03349064443741114, 0.03618665723009937, 0.10522887200838137, 0.058774774999267636, 0.05083801600361063, 0.04854248333421927, 0.0671487020689153, 0.021633595198152528, 0.005897139433786394, 0.02940637881927673, 0.02485750002726432, 0.0559535144918388, 0.048332805069343704, 0.016568275468964732, 0.03100266473578109, 0.018855959567571842, 0.042183451775100925, 0.01790245206305577, 0.027005995526128722, 0.019113679206179037, 0.02552126158749865, 0.06068156401236212, 0.06661445533315982, 0.05324446671311894, 0.013953392345067716, 0.05138890982996072, 0.06396515092121498, 0.029893723737087943, 0.09461283158030241, 0.0380667174355157, 0.034245853913166834, 0.01910629028814935, 0.02435410556743943, 0.017496921505118092, 0.058625874319864865, 0.018686929927958597, 0.013114188031684007, 0.06333679794484089, 0.027459638320931026, 0.04708058839183181, 0.021638417721635873, 0.017583527744958, 0.0116072547802281, 0.036195478732547456, 0.07907717368535458, 0.024381914559090813, 0.008834349742579845, 0.06887849795842363, 0.07202078378008259, 0.10561994457196806, 0.04264554451970805, 0.12157991558553712, 0.02865277812816203, 0.019826374632576783, 0.04901978292412335, 0.11019472288148058, 0.08488083363420541, 0.10243891768397824, 0.11900724677909767, 0.09864806948650269, 0.08101778931074566, 0.14230578086308895, 0.17940325151768424, 0.31492955261661165, 0.14498794661654582, 0.1585160021580035, 0.15789242190939767, 0.13422943681718844, 0.14313778299237453, 0.2847726853384126, 0.22539082013310927, 0.11535554313130918, 0.14816002559758004, 0.13167578997390886, 0.06650088279838524, 0.15614779455767525, 0.11713563269304654, 0.20220988820637428, 0.08259000091422951, 0.19120311995427455, 0.2011824264040878, 0.07578025301617962, 0.1416967256415275, 0.16365309666481712, 0.21862284700957038, 0.11590843644714165, 0.10326801634003079, 0.14643563828881712, 0.2244763103343787, 0.1250845916388977, 0.09314936615767018, 0.09966802362713123, 0.10649456417248135, 0.2540742398630227, 0.1968256230916708, 0.14053573471403893, 0.12237886868176923, 0.16446266773967974, 0.1622007318562077, 0.15697676297878066, 0.1083039872408394, 0.12457127442523358, 0.10576271271753697, 0.08840209549112667, 0.10166178277182965, 0.19510166479214547, 0.16937767335724446, 0.13815327787831908, 0.19555589364420986, 0.10319408119445848, 0.17978856310008035, 0.07586306712079434, 0.10702540947785301, 0.17202381765650165, 0.19668743615188908, 0.08020688524289478, 0.23142724057599423, 0.1635466410868591, 0.26450889365326974, 0.15546470459911133, 0.12695552390669623, 0.12433525805752124, 0.2271136905877821, 0.16556952689443866, 0.07574426986637615, 0.12340508942161837, 0.18746799699241118, 0.1448896881793776, 0.4130954463635722, 0.14840391734915395, 0.11946425653032719, 0.06965837546534116, 0.13114220973464752, 0.2585108848589082, 0.2023977636089248, 0.42623915559341835, 0.1218903956994895, 0.1417592384161488, 0.25684885710718175, 0.13095493188067792, 0.18354835409310558, 0.1206448516477981, 0.17121666741947975, 0.2212739708803354, 0.1346216891561785, 0.30812632412679736, 0.33701366114039577, 0.3054161808423458, 0.40705769292769894, 0.1571044851575167, 0.20884736591289121, 0.09977128461844499, 0.16712958834344344, 0.2099605529539047, 0.1310268062497339, 0.25365713563176895, 0.2287611167036718, 0.23294453899706566, 0.22716796025633815, 0.22628004903033858, 0.27418390997955877, 0.17884872643457306, 0.1388481809126754, 0.21869050789504282, 0.1482541778034741, 0.12215041360186955, 0.177490743658235, 0.27605993673205376, 0.266010977568165, 0.13818759861732685, 0.14544553093371854, 0.19091991257042656, 0.19197752759341272, 0.14860855475548776, 0.1609875856628341, 0.203381895478214, 0.12494008447374068, 0.11952622538252224, 0.24464164439949299, 0.1785947682876741, 0.17591675473076684, 0.1555226514897039, 0.10607922960433269, 0.248600771470416, 0.16910644758853222, 0.1804830218034406, 0.17558329197908604, 0.31158089036903075, 0.13706201627369852, 0.07462932848401609, 0.18588216434563362, 0.0875518374866055, 0.10880316247142131, 0.08283969961226949, 0.13625123477991552, 0.13201257754718104, 0.1694888020715406, 0.16301666146084187, 0.14502465754987734, 0.10518138987883445, 0.06491611501382244, 0.136685652598258, 0.16846504813480764, 0.11489190671953464, 0.2427391110048179, 0.13088938539787648, 0.15654747794953086, 0.08541714880735644, 0.1262006821531442, 0.1664541745858808, 0.11562964939061673, 0.09279917970660234, 0.06789479509837205, 0.14162374810586054, 0.06629587766984779, 0.13705953414882385, 0.15245800867917078, 0.056701660636932626, 0.07539753847184681, 0.11045421218319286, 0.17522565149251493, 0.10128375668559345, 0.08815573693643655, 0.1949873797956013, 0.1392621441834396, 0.23411199570663516, 0.17030217294250766, 0.20609099688308857, 0.15544668621113225, 0.12099038794516556, 0.17016332716711108], [0.02347166803965886, 0.03633500249575704, 0.02720946081793837, 0.046041853605739536, 0.05939114636050598, 0.03462394128643698, 0.029972985108953812, 0.07680280419487147, 0.09923899140689643, 0.036327245855523695, 0.011760527906458706, 0.02812840818097034, 0.025175943625189608, 0.03841821006649444, 0.06928897552913235, 0.05768722126020059, 0.016387379127404383, 0.09825536515563728, 0.036682871530853936, 0.11396059661262459, 0.08798681454913271, 0.032873648714514515, 0.029065345203684225, 0.027609391273149562, 0.046646959644051335, 0.01280764752488223, 0.047141400451261195, 0.04085150832730917, 0.03957971427289229, 0.03235678834420058, 0.05130804158867367, 0.024750705455399813, 0.058259136539192936, 0.04959836699849656, 0.027971249073743824, 0.00839083654535634, 0.051272104404145674, 0.022081522977039702, 0.02810194558884588, 0.014133909473105544, 0.05385446805326689, 0.013412135904805075, 0.026361591092521147, 0.027422306856380838, 0.06671013205402321, 0.06125465140587861, 0.07432348320200559, 0.05616405077518956, 0.018160575813043024, 0.045489067542216474, 0.02830849055411114, 0.07586816926637004, 0.08459759560684044, 0.06893948621807561, 0.04983367473487893, 0.05007990688506154, 0.06925679217543333, 0.13754281305497693, 0.06143212333441742, 0.06504035915338224, 0.05368776732094346, 0.03841670087328361, 0.018034343675319708, 0.020210163615223382, 0.01148238915183972, 0.01776815110426997, 0.06113930537755932, 0.04114562863363855, 0.03583983390501911, 0.04986229194929043, 0.08891307613662175, 0.01225239370063308, 0.07861079467881112, 0.047752757767035116, 0.06362169455256193, 0.02384575643396426, 0.03437798875834673, 0.02161336090085247, 0.019319956040670796, 0.060545476153492934, 0.11368422273306117, 0.04774200189257822, 0.039296744376300805, 0.03365145395359686, 0.015789142982553572, 0.09782633293540248, 0.059675345828215924, 0.013863339667178452, 0.0721081254643298, 0.03581980836667842, 0.058255719787050644, 0.07978994955098437, 0.05969657412459774, 0.023109846628241004, 0.04981978556081172, 0.04395122264301585, 0.03265706033656194, 0.041951438216792966, 0.025630725975779277, 0.01104500465801046, 0.0184045116146726, 0.07862250816317336, 0.12265264552326934, 0.07418144283996475, 0.07446617473878207, 0.06175673010969355, 0.01870463613510853, 0.04182804060438949, 0.026260496214813283, 0.030551743468329794, 0.05213381925357446, 0.029823463898332372, 0.03092235765389858, 0.0604855144516595, 0.07838999281727499, 0.049111648357563445, 0.0349298287032833, 0.04133669862283334, 0.054449354478668784, 0.01211734293329139, 0.025661400136267467, 0.0236684377230103, 0.03461149235766742, 0.018932849897312063, 0.03241015785944558, 0.017311277333647013, 0.058772266061315616, 0.0482632557771379, 0.030989260112325993, 0.028204986329881415, 0.09032221060366401, 0.047789541478719444, 0.1235743105832127, 0.01652451461151002, 0.014938493315581114, 0.07834876962606946, 0.011969069488376621, 0.010627306708615395, 0.02537832681780621, 0.030234933552903034, 0.012035775636773438, 0.05757777410889826, 0.09828088354439506, 0.05284136273868142, 0.04868888273654927, 0.0222239310612842, 0.0420127788768901, 0.010879906007058678, 0.06983834484051313, 0.05188007178085466, 0.035029355015966206, 0.059556805213252385, 0.02643496507868892, 0.02909859916525743, 0.001832738475528576, 0.08602898492808304, 0.012118983319059256, 0.033410902345372785, 0.05332112530126207, 0.042797881103451216, 0.04475359632182987, 0.04223415913480905, 0.06299767380339966, 0.010610911469425886, 0.02080246257866102, 0.052048967355081154, 0.041077619178160545, 0.016751414532923413, 0.026626006339586554, 0.0715017132461071, 0.007258416867003807, 0.02005230928320558, 0.08995710075983117, 0.01912505369663479, 0.037973404095898715, 0.06356320373954312, 0.028753097341846556, 0.04364954487931344, 0.0446032285840521, 0.06626763200807957, 0.039837744177108815, 0.03537525903553732, 0.013771398582555836, 0.10071377960904952, 0.0685805740255502, 0.029614923274024364, 0.06145484933269121, 0.040171352485495235, 0.020596193405048504, 0.04756590126142387, 0.06471525442095534, 0.05551047052346891, 0.008273734260470638, 0.1420557604081208, 0.04880067794733951, 0.030231160569875955, 0.09540374841420882, 0.0372519982498019, 0.06813631963825996, 0.031814465126503384, 0.06043879074915763, 0.0637349414999687, 0.0242834416173038, 0.01643665007225448, 0.02877339675662018, 0.03915799053145513, 0.059597066964112946, 0.11586314532905818, 0.05577386687359503, 0.040818003471940756, 0.015471817872997735, 0.02600498865508745, 0.03289587292519789, 0.029731234573128245, 0.05653220198808178, 0.026141539997150822, 0.02492920202653735, 0.06281215029077665, 0.052166975538937316, 0.03812132418275841, 0.036233089819190004, 0.07245663418284348, 0.051580125375861124, 0.04525603508696922, 0.052568095345650954, 0.06049862221604394, 0.021085317562063857, 0.028176466791680264, 0.050836587249631845, 0.09214896258086928, 0.030545503682186528, 0.03461206692361063, 0.01070423917319145, 0.07656760754123812, 0.03583321873579295, 0.027069950461267468, 0.040966015489351366, 0.0338137535107953, 0.03967464022758988, 0.22607931867241862, 0.018300049780537526, 0.04569629432573434, 0.05496460989478135, 0.04699916090636004, 0.040020793225736394, 0.03811930171063831, 0.024637772604042006, 0.026041113531156897, 0.05281007570785381, 0.02807694430943699, 0.03117496174039139, 0.05136450992957239, 0.01806158384668731, 0.03146060719905842, 0.038188992729110104, 0.0447258064823766, 0.019045415026466214, 0.10224080734675932, 0.0101578623927649, 0.07048103132195051, 0.13531872191496436, 0.021399451915415067, 0.031429337405209104, 0.009208153726743355, 0.050636266748751366, 0.0585667476538689, 0.059852300647405855, 0.1741727708929008, 0.053579561232078465, 0.09335304595409863, 0.0929292154708697, 0.0606745274947776, 0.04769717042724933, 0.10183311833609497, 0.02437305475224651, 0.10057226784767644, 0.10890609404492764, 0.03955060293176963, 0.10782955665021174, 0.02852582012213046, 0.04178746475747997, 0.04667129059652648, 0.12163125113734316, 0.05603690699283635, 0.02338538355674715, 0.007542679536967509, 0.048100094371024645, 0.035796971285655614, 0.09190143957253426, 0.02949959639790318, 0.016179135362167033, 0.05570627876647538, 0.07875605261013394, 0.08498499094839058, 0.03425568665167497, 0.05861491926254765, 0.03062605208176519, 0.0372067186230373, 0.029004699768378373, 0.025085123901766156, 0.02874753745873609, 0.02003345968982866, 0.029261959754230998, 0.03083204929416459, 0.015892600283897933, 0.030008089172864155, 0.0577519212158457, 0.11076494510616026, 0.03951844639114795, 0.04504129681135378, 0.0550303019342884, 0.052063235742670876, 0.0223230819908842, 0.01731552912162677, 0.05543726699186429, 0.07553838373672578, 0.019715981362687967, 0.04266301132438164, 0.03581046975488144, 0.04810053104114148, 0.05979130472687464, 0.04048651339666497, 0.007268639352743424, 0.02543049165979028, 0.028463537173886454, 0.007647546440092547, 0.016070188083235296, 0.03821816535726671, 0.01281094074534673, 0.01228400919165823, 0.0323842985615615, 0.033763934813079335, 0.06792048202647318, 0.10671286092650507, 0.03398834494873881, 0.03665779747309224, 0.02641521150156135, 0.020070480888769514, 0.07903555212842842, 0.03493087824373957, 0.03048236080024752, 0.02215863164183834, 0.05667066854995586, 0.015574521535346586, 0.03184444980785972, 0.046380629177175225, 0.040121667853166024, 0.023418800312004263, 0.04699679752511363, 0.02749704256383402, 0.016149753975051067, 0.0600194342194065, 0.08018591741640722, 0.11328446273241313, 0.1498991371162476, 0.11520221829414369, 0.15021327913047808, 0.14148318629351356, 0.07468092450571638, 0.243506133556366, 0.20892471014972658, 0.16543103351948724, 0.15865987347018334, 0.22153330696446283, 0.08183246253118401, 0.22947518725789365, 0.2093372638187101, 0.17027620256187456, 0.1749485574903027, 0.26074960827827454, 0.13153911988821723, 0.2184088326870434, 0.2839628691154142, 0.2824499986825451, 0.1915120525706199, 0.14438301294801698, 0.15751520021548196, 0.1665558344534328, 0.2200445223359331, 0.1698444047642331, 0.11498463400188955, 0.12118954782284076, 0.2276792626587614, 0.1334317707486691, 0.10561245989294783, 0.2645315698558285, 0.07330134571079286, 0.1881830174956591, 0.14655741562526073, 0.1003844843756768, 0.19745047504623092, 0.1180891593497607, 0.11563040781766178, 0.11403743523142992, 0.12376129732377107, 0.15193506174029844, 0.1250652249361719, 0.1502178143709898, 0.09727903206141726, 0.10783335644631617, 0.07927042702513357, 0.13607212342321873, 0.1451681304963366, 0.21397588023495293, 0.21025655400608817, 0.14762403984223643, 0.09310586002445029, 0.09302013478572331, 0.11845760933694341, 0.1731182968304042, 0.16273826510915834, 0.11399784380750311, 0.1966613431971881, 0.12876278660710783, 0.15018062846314523, 0.23930489205785338, 0.16032361725886024, 0.10622637211194924, 0.32490695916837264, 0.12560596809752528, 0.1561733052855538, 0.26184143678795907, 0.21483016020107656, 0.14505249718504568, 0.20429269741139106, 0.13609329809344586, 0.22006876135785736, 0.11622162085146674, 0.181082577534741, 0.14051567853218125, 0.09883993620713873, 0.27420058005279113, 0.2902537073579527, 0.2370580174629727, 0.14397641944308437, 0.11809383248609882, 0.15657412248753733, 0.1423500301015954, 0.1429751425260498, 0.13164396668153425, 0.20962626282726565, 0.16402765237275632, 0.17351370545164232, 0.20680940349496182, 0.22894923725435812, 0.1668929131401162, 0.2539100825426079, 0.1487214914372852, 0.10975308851489138, 0.17813929837317238, 0.17662926246562313, 0.1733488126868202, 0.15297599136829376, 0.20542541969447367, 0.25398365762685576, 0.22442512033927828, 0.16648294884831677, 0.30435821341891445, 0.13852092347318126, 0.1595320492502182, 0.04933196375326765, 0.10713476086816481, 0.13937560180502553, 0.10379202048023863, 0.3767728889661451, 0.2337770773878982, 0.23882452428581255, 0.10710217148786592, 0.1381083238389223, 0.2340915871243323, 0.11365377839895026, 0.1967909039869424, 0.16182317308360533, 0.12240745142222413, 0.11925982596773295, 0.18119926804736738, 0.12845455113077356, 0.1047755241574299, 0.23112131102431208, 0.12328122832602072, 0.11957771415191314, 0.07573514575919799, 0.1642620139905522, 0.22847659164859405, 0.1738583684087761, 0.12024072494598166, 0.14363750214538268, 0.1640568403226714, 0.11800957813618645, 0.11246208266745653, 0.1896704231659251, 0.22303643275893506, 0.14790243619391996, 0.11706648559700097, 0.13425404356131632, 0.13425526930199516, 0.1415459748597876, 0.12710278132750144, 0.10683796308454006, 0.10328983452411429, 0.22901265401273008, 0.20851263145525611, 0.09305860772128068, 0.12418572535558094, 0.08449195208208216, 0.1553763593396833, 0.1121507368741497, 0.08867218744971099, 0.15192879514107782, 0.18205644382584482, 0.1701235978473579, 0.12146966021147468, 0.0984798212565722, 0.1792298704986611, 0.19160986667679203, 0.15470980155852534, 0.1539926360090894, 0.19243256849867685, 0.1307293343087358, 0.09022658750895532, 0.1381845342656297, 0.1877696977387513, 0.13071692368436244, 0.12844411701324487, 0.16432860235293067, 0.12287520172615206, 0.12694731910502718, 0.11723925374568471], [0.08290826448149259, 0.03591247436199938, 0.01933543101674126, 0.0344893932642956, 0.021203902227083044, 0.04055785150417397, 0.11051479441624497, 0.009141259886805088, 0.03558394521655094, 0.04144420757168724, 0.044750907353215644, 0.029399593195487416, 0.04896184752484964, 0.02595983543283036, 0.0765717214333915, 0.010020221290629237, 0.025257055099392613, 0.013174741536438947, 0.04482504934252751, 0.0201404208858167, 0.009664948973354072, 0.034615001040360624, 0.018645354336307898, 0.03258683305654315, 0.03749091426030763, 0.03839117865408621, 0.027454561073212858, 0.04378881583350801, 0.015054226218302165, 0.036631953496966636, 0.03186786145482573, 0.028734512048803514, 0.0654083188442934, 0.024256325935223894, 0.03916593486322992, 0.03692770174013511, 0.07040558698316736, 0.017346151571180073, 0.06179858149299699, 0.014282644485994695, 0.022732404684047067, 0.06211181952347679, 0.04481082308977362, 0.02468621808915369, 0.06118962203242606, 0.05003481111939877, 0.014572444056431133, 0.05828800656261945, 0.07001844445063223, 0.032951755208834525, 0.030184134262643998, 0.014341842015123656, 0.053168700617407604, 0.02726660140099064, 0.044756798569353363, 0.03784946639150862, 0.05018296869351499, 0.06643260904257337, 0.07433014816694683, 0.054822508245706565, 0.0034796379059703363, 0.04493185732093069, 0.007565098142461672, 0.023008629176465255, 0.05462006568127582, 0.05000009201467038, 0.011660324563572725, 0.01918329170063859, 0.020691010192216888, 0.07318366694474414, 0.05534575395886937, 0.04012921381922018, 0.08612302222078846, 0.035551489901638804, 0.052328826934700055, 0.07320159340217229, 0.016671197466372002, 0.033392646470137184, 0.022809204998456185, 0.047998200846655716, 0.0979582226324466, 0.06541357420745396, 0.02699386260862793, 0.05762550904746017, 0.0038436103486380875, 0.0712186667407232, 0.08346874206777542, 0.03266452969382367, 0.02940224577492524, 0.02585486989588507, 0.027505159265391772, 0.05136411156385176, 0.044988042209297426, 0.06802412606174908, 0.03153880753914916, 0.0476777117939726, 0.09695000495881805, 0.20700326970508023, 0.020281702820812503, 0.024678515075075052, 0.05369048310263504, 0.078437099563739, 0.013065577837668601, 0.035009957669723424, 0.07421374110685242, 0.0364973595095498, 0.0749654418999149, 0.06518020850395964, 0.046530575566594644, 0.0222596365042151, 0.08356263380377524, 0.12117516835250201, 0.0023504025199555705, 0.020214832921121872, 0.009375525743610436, 0.08731118628695127, 0.025333673467919714, 0.07951155319930085, 0.06700241757977395, 0.0811745768653289, 0.013049200793067295, 0.04807431934281223, 0.06487806342662343, 0.04005121840764919, 0.058170802771083774, 0.07739133592094145, 0.02026658216040702, 0.02732955276094858, 0.02045327204189474, 0.01293765168802272, 0.012786582979794233, 0.014948866146075872, 0.049633495960264444, 0.05518721206293953, 0.08845857149290462, 0.007157633691320137, 0.05314673304617886, 0.04426357201150349, 0.05592260284409408, 0.056597924671105804, 0.041265069401913115, 0.05419794357411804, 0.048553434561096856, 0.02205104033853258, 0.02878358764123292, 0.025348451303979082, 0.005839868615786996, 0.03090326674282551, 0.035802134718265266, 0.057124322836077025, 0.021167829061948487, 0.016574193498179797, 0.045097899217639244, 0.08586838991651613, 0.01921903927840533, 0.02396644017989597, 0.06556002723593866, 0.06445941935864187, 0.056349099313299504, 0.0509268515593102, 0.031162861381627383, 0.01749632012609753, 0.011117742791201079, 0.008263744473938019, 0.0255002765240328, 0.003064122349549566, 0.033925625330377976, 0.07914560065875131, 0.11700544371119431, 0.06943391936440622, 0.02352367583361845, 0.03863290237683443, 0.015951222289473783, 0.04818460152995202, 0.06874620989565888, 0.09991262784047474, 0.03558567657525982, 0.011969688104375476, 0.033350622717050776, 0.039817841212836005, 0.017443333654814673, 0.0025723508799508697, 0.07291120777447378, 0.02957307189072092, 0.026035019301719246, 0.06375238532200456, 0.017639565161399303, 0.018894426757469773, 0.028778514223954374, 0.06299241844023909, 0.07254298761366837, 0.013160715424155277, 0.026895483512611642, 0.059445841207859985, 0.03195720645899494, 0.035941918951369105, 0.020630642463783586, 0.05666640910109686, 0.036267249679733674, 0.03145771330192445, 0.03723566908569586, 0.028563291397726828, 0.04465416960057713, 0.039508318708788966, 0.008528777379392376, 0.11350826765861242, 0.02706051800369976, 0.054006701215140285, 0.04213685830754619, 0.08666218724101783, 0.033777394977908944, 0.007806228147068573, 0.04635803341384857, 0.037396110879677924, 0.022770624810589418, 0.04306403537010474, 0.03266744848881518, 0.010617342777550222, 0.0661193403685766, 0.06519056601269592, 0.06297603948041797, 0.03361008520568571, 0.03127335807338598, 0.046171513986924005, 0.03305670542402133, 0.03453033683340877, 0.0909879869751392, 0.03429693665595786, 0.06368566289423935, 0.024317333347073967, 0.04808412909868264, 0.04508426285258705, 0.044551678527627266, 0.12244819197803737, 0.006709746132048989, 0.0729396679408608, 0.03485694309816726, 0.049198040092784556, 0.0755743055994953, 0.08921178914005719, 0.08629457228967259, 0.01149779134955738, 0.0003837445136366202, 0.05290443092704781, 0.02061279453036766, 0.09274887837349408, 0.04610149738108439, 0.12444854713976385, 0.03156366326185244, 0.028898753638890003, 0.018172890676425833, 0.03662992336396729, 0.03475775386417105, 0.009223294496956852, 0.0698969352449621, 0.04186984985285709, 0.021246061960776007, 0.06492327793591446, 0.05956507513239499, 0.03829664723466962, 0.03557586681938941, 0.07178173370419011, 0.0687146240905408, 0.036683388640202826, 0.09175974395005934, 0.03751736344589341, 0.05489375442266465, 0.07188887110040074, 0.06834969810780979, 0.029715366976996584, 0.07086755332326697, 0.03467928730852662, 0.042272969149053104, 0.07122542363621535, 0.037544000323020646, 0.025726207344221975, 0.055357655134773066, 0.06425607281046049, 0.06209611472102904, 0.034203745890408754, 0.02313772265258576, 0.01847475421644988, 0.09133078833861698, 0.037481223248065486, 0.06153985061832975, 0.021648968667573026, 0.055087953881030126, 0.05525370466432745, 0.011229421173582875, 0.0248467403223678, 0.01662937481136572, 0.03142307655164792, 0.02230125806114126, 0.09739422104171208, 0.03958313868591382, 0.05418907610639449, 0.03914143920185105, 0.06296894933667875, 0.04570747920942884, 0.02783920807433465, 0.03782015969796527, 0.019267758639949947, 0.01830560966364799, 0.01727799655899646, 0.032426475532232754, 0.008867788522864782, 0.0161869149850381, 0.0373968578154041, 0.021505262064296874, 0.01288576934096073, 0.03972280417538939, 0.14826583766168164, 0.07553440007951952, 0.02626843097048902, 0.05960750874252089, 0.04416497266520897, 0.07046892713274687, 0.08734919190887483, 0.017962850435006044, 0.033942146016465086, 0.011400513504932245, 0.04991578403860331, 0.031670252905197205, 0.048220427631731, 0.015077805447001612, 0.07614212996897197, 0.04502960247918964, 0.030159328335655794, 0.04958224467813008, 0.0563446598337783, 0.030366821334727352, 0.015161893172790448, 0.04690531130519606, 0.1157467076254468, 0.03629011357383382, 0.025971592967248252, 0.005026805616404501, 0.007680895683851334, 0.026182657851266767, 0.03861034108746437, 0.09673707082026428, 0.051759481880693674, 0.009864379854632482, 0.03638474841512019, 0.04271476439410641, 0.011005375887297336, 0.06565566565240584, 0.025410500595406182, 0.059740371371228854, 0.012703477761768287, 0.029741164987846732, 0.06078810002955218, 0.15499523059735376, 0.11708656476149637, 0.10252262045058513, 0.08475311911634861, 0.1267267700525061, 0.11738503261679605, 0.26593476714145753, 0.0959041340637111, 0.14003250687833757, 0.10111050590151742, 0.1591391687191302, 0.1447998260658595, 0.1750873879439408, 0.12193407037205274, 0.20269658386466965, 0.15093870310773774, 0.14005633221278269, 0.1296235170335539, 0.16536594668944038, 0.10013511509544427, 0.1300883638642488, 0.1330495541614871, 0.13158591253863228, 0.11848594692926254, 0.12301243105602842, 0.17520266885478653, 0.08602759064806086, 0.09623933583498002, 0.13717368124954163, 0.22447039613560324, 0.21123386769285127, 0.07723972712072634, 0.1209470120468928, 0.30721376019139446, 0.12139985427981424, 0.14662691512175147, 0.15999141089137525, 0.14436219067823503, 0.08678951105403324, 0.1564202001017909, 0.12431812067065509, 0.10143363412709967, 0.13123642322757553, 0.11621757590722655, 0.1524072936585834, 0.15166406579796346, 0.09708906523883344, 0.1634364469998306, 0.1678983422537004, 0.0647490542201746, 0.183466459294, 0.14219601578529806, 0.09385122527037898, 0.17619141257337986, 0.1542919618828643, 0.12233537020942858, 0.1851863726492851, 0.16358013445090863, 0.14541229803956326, 0.1826547125294324, 0.08107994968492178, 0.1576440868478629, 0.17646306735132972, 0.19045166430934785, 0.31196834699761483, 0.14306665938948432, 0.18139295039638398, 0.13246084623519452, 0.1046112442629472, 0.18150795551557697, 0.13477276169484662, 0.20373162993740654, 0.2585613547313598, 0.11452092098132258, 0.19846096034011534, 0.17682761795097784, 0.15032669078678856, 0.135370739285023, 0.1491579164059893, 0.1459947546883937, 0.2487840963106963, 0.16670987941324714, 0.15790829525118874, 0.19400782913209932, 0.12286727271613576, 0.098612331484835, 0.13949753235905402, 0.09996413959250336, 0.13936784899523183, 0.17264824060182418, 0.11109297629445793, 0.22272940004064193, 0.10830449285886942, 0.1953902807567389, 0.2475193617565017, 0.1603231116408302, 0.13811232281788705, 0.28048755721219126, 0.09024154154523727, 0.19856288067756162, 0.17061528839891957, 0.18804303791013458, 0.16671677420456565, 0.15077448450028896, 0.18660156687180843, 0.16947882760676647, 0.24700854965034993, 0.17142770932086054, 0.20523679352575736, 0.11007253951843708, 0.18688075995493322, 0.22181849085515548, 0.20072536302670357, 0.10967801189831189, 0.11492665646778, 0.1259642750805905, 0.08531846136095063, 0.12417242606921543, 0.18285165841300643, 0.09886875643485016, 0.12444968861077102, 0.24444203252994248, 0.2092901800548838, 0.13012502883230487, 0.1536210680440549, 0.12598370307035026, 0.09782061791948735, 0.10532552932178783, 0.14490260442178096, 0.11695358721959977, 0.10672839718960947, 0.11947636071953083, 0.097501841073315, 0.11950556399120439, 0.14503958094264233, 0.2887314906524074, 0.16831386834383014, 0.11827398572237262, 0.23272986583892377, 0.1492005875033717, 0.13141110659606997, 0.12047605949544138, 0.09976474222757163, 0.0902575451219755, 0.16210851019188283, 0.22778960996337477, 0.10720146414373191, 0.19622899381624115, 0.15711700303419945, 0.2706759627307615, 0.07994981677902323, 0.10878089995634173, 0.25830207993426635, 0.2526026156039969, 0.09422736678032145, 0.12218490288022066, 0.1965989223531177, 0.1783290123867412, 0.15816318802535534, 0.15891920955431077, 0.12282526045436822, 0.07762745188008394, 0.29908354484265853, 0.14872185915948885, 0.27194665744900703, 0.12166821487968969, 0.08725333898778885, 0.19269991786249224, 0.26529220323408803, 0.09411627637042154, 0.12422226008868988, 0.08453114514028834, 0.10277432629898672, 0.0762457586824894, 0.21109102293848994, 0.2772533791440149], [0.036511003535481236, 0.09177090585111611, 0.05064236480862864, 0.07218581444073109, 0.04300968143187704, 0.05710788258922197, 0.1049773346993231, 0.0311632405951499, 0.0725045683042657, 0.04753800033922157, 0.06985503023550396, 0.019708682459989385, 0.03503153070567116, 0.03760614154499866, 0.030018174720387307, 0.03238947731592963, 0.021865242949476647, 0.061550644797182856, 0.03336828104370544, 0.03791384842066515, 0.05456291169168488, 0.008627177542826582, 0.050249859660623536, 0.07827996726958983, 0.01568271996333234, 0.05243889844766068, 0.04528801159692868, 0.08726545083787172, 0.021083040365708933, 0.0726209906861186, 0.02635370613256049, 0.07544882039749816, 0.11182821385802762, 0.02950793334973916, 0.020456922450853933, 0.04129732936440457, 0.08102685213088989, 0.0508643196324908, 0.02796307300037194, 0.08544553236495103, 0.10651816734142842, 0.038251643399557764, 0.03401724178524267, 0.01921267883341399, 0.07732716073552448, 0.037229019442513105, 0.005843695224968777, 0.1126357701216494, 0.09294451424671758, 0.041842891218801664, 0.06929092905333928, 0.028303934246181484, 0.04588882754286451, 0.012378321318406493, 0.04685493719373499, 0.022944383127915285, 0.03927563482354726, 0.06149069841710791, 0.04275894085426004, 0.08449901541274402, 0.07546961202376312, 0.024029104256882303, 0.03549568422679459, 0.06508915895415891, 0.019230655086557233, 0.08516669168227142, 0.007568004967329363, 0.01633894513361156, 0.05589012071610459, 0.014088343520979247, 0.04506273578191477, 0.04220700514833293, 0.019956634477562, 0.02300664883918099, 0.05276529786867961, 0.06366321651805794, 0.032468529928836136, 0.03833102159983209, 0.04433751098751541, 0.06530712629037519, 0.050451972807246837, 0.025892415865054055, 0.1319707951117908, 0.05868634163972832, 0.03275740253288419, 0.006144638023068828, 0.03048727142384216, 0.0543939471695452, 0.056156539283091986, 0.052641440603521564, 0.08204569544402823, 0.04921746042166506, 0.10284410924800944, 0.0804572197939119, 0.061364719088399605, 0.10476454611747496, 0.05140812714554129, 0.042758714858322375, 0.043219252444443204, 0.03654653852384898, 0.0070840241331156465, 0.06686594667694261, 0.03126328401718169, 0.036704019388003696, 0.019577468835538434, 0.047599072868545214, 0.04325698227471402, 0.044120604683074265, 0.021693026384098396, 0.05088818327133214, 0.0209277217847205, 0.025821554647277922, 0.017921799613583474, 0.04837628438948624, 0.012842734351814275, 0.04793036376096068, 0.05748488977851887, 0.0773147424502719, 0.057971934006819804, 0.054226024526982546, 0.06437845918680392, 0.07004603127678556, 0.009087391456799402, 0.023395995789718245, 0.1395417509540435, 0.053695887852940834, 0.018717276585859158, 0.06833541822890121, 0.014930661981775156, 0.01951148759783997, 0.018861178541556, 0.037104438224266616, 0.022653853858730966, 0.023903417956805038, 0.026773181405939886, 0.042531830258667476, 0.031237989709141756, 0.04261056877552502, 0.041676424143295136, 0.09364677172514702, 0.011112628196696601, 0.05569323995000413, 0.00836421977803712, 0.04229299851783341, 0.03186077897196576, 0.022464990202758103, 0.02284757068170415, 0.08184416069378776, 0.059429592482985995, 0.05572735001483271, 0.0345632020053604, 0.02833342671604647, 0.07107091136276722, 0.09069986896769655, 0.05288150957635334, 0.031567363466526714, 0.04798452617720731, 0.016364189645936413, 0.03936855745832286, 0.06772531346688349, 0.016450696294346166, 0.07350723184044324, 0.024901733944012273, 0.09201433794993548, 0.034346073535421205, 0.053859424642136985, 0.03222882867820802, 0.03341434974103205, 0.04769473809808974, 0.06596825250815, 0.06323948179581954, 0.07777496210990414, 0.01661304181682006, 0.043801965732728286, 0.043106001666596824, 0.07758799069110425, 0.032450005922827034, 0.08191444159996125, 0.05977153582798858, 0.043434235868194414, 0.14886219114545854, 0.05930152939512365, 0.08419339229623157, 0.01855022345309056, 0.017072173631599834, 0.05330803285863611, 0.006852911685728619, 0.014064584261617594, 0.030195648564145933, 0.06510554557485927, 0.030111715971161763, 0.02762549827175756, 0.06196668033578223, 0.04694043643652432, 0.026621153172586235, 0.03259963055531825, 0.0760145610078208, 0.02710552949969086, 0.009198243421832881, 0.030607489771359873, 0.0350874857676606, 0.043615676132181, 0.016481690296542742, 0.01879261558755271, 0.0658130124511738, 0.06879029059482199, 0.048416369940124215, 0.0682224509035868, 0.026097566550297123, 0.02977232944460646, 0.040114187004585425, 0.06100366568012584, 0.057265731175580335, 0.04059806728975908, 0.050326487605249694, 0.03942444740283874, 0.04175631562247873, 0.01604431442120263, 0.015357537664503101, 0.03328892199562923, 0.025542413275088036, 0.10246381554151736, 0.027122797121504144, 0.07288857753719054, 0.026168289872246887, 0.02051596676239804, 0.030959980231859995, 0.025979001037476045, 0.0249843699331846, 0.04408139630310959, 0.037073978568397226, 0.03786805934543091, 0.06063535741920914, 0.11856968800026564, 0.004396087343564197, 0.022006264414578196, 0.028367071382461057, 0.03146052675982637, 0.08128924490583521, 0.008227462549844097, 0.028112663158906565, 0.02164132502530852, 0.01904884135470756, 0.04958068185876455, 0.052431582307983796, 0.054541920882559596, 0.025006477315459522, 0.04606274482343466, 0.012936515005065069, 0.053862339606688875, 0.046831560020725575, 0.08964429173858897, 0.10623940326754125, 0.04693043898911246, 0.04012234967141863, 0.021876134804540107, 0.023337822903188008, 0.09617251764622428, 0.08327743459132411, 0.08344388251463253, 0.015774319181218743, 0.031101608821641535, 0.06537437348836853, 0.03864999762886474, 0.0665238730969929, 0.043888499194215384, 0.0050953451089651115, 0.08120680618430338, 0.03156116581521928, 0.06523928154380092, 0.08434229680607397, 0.048661613836884506, 0.07394692800458401, 0.0477753765129995, 0.0580849894322455, 0.032818762345179435, 0.03744153606314813, 0.021162085317736192, 0.05785329763086573, 0.059559854243191025, 0.10600135676682958, 0.018772850519106276, 0.04457476841766508, 0.04947589635248146, 0.010416795323122173, 0.0414939190170938, 0.06103207222035816, 0.013669368119970446, 0.04488520639678163, 0.07422570740022967, 0.026787928598482284, 0.06233839768796198, 0.0558579794972414, 0.011429689963528467, 0.08465198018858511, 0.03580911377925546, 0.056673748223411466, 0.056424754326261824, 0.08809687840121408, 0.030709865931121093, 0.04041318729099247, 0.006279611702813137, 0.039706475011283354, 0.017697500560673016, 0.02335869879912465, 0.040954623761917316, 0.08514838984176036, 0.12186083236649153, 0.018472296989432747, 0.03527556035307146, 0.06530872741413694, 0.07465169059052583, 0.007723417394088522, 0.022830301144671057, 0.08133357841401331, 0.025392840353531704, 0.02612298917806437, 0.04533142579959766, 0.019612766336649656, 0.034015464461258346, 0.00688634041110955, 0.07874004137251647, 0.048842977492078665, 0.024434558206027555, 0.03182198810991982, 0.04391718152610045, 0.007212679023899499, 0.03147473769082177, 0.058982476757298556, 0.07272340131983643, 0.04572603002851529, 0.04598159312961563, 0.016619777644894296, 0.025342182789538658, 0.07500523250670203, 0.020961768647295334, 0.042069771988016945, 0.028149044674430645, 0.07198093188626152, 0.011441638062317527, 0.017080749985912157, 0.05410946807974289, 0.01178639199239232, 0.02961459194099711, 0.036983737241356604, 0.10635712033798618, 0.028254774384080406, 0.059984017974667014, 0.04481622017920018, 0.022614099641120242, 0.09848018131789663, 0.030284516678582278, 0.13067166320979595, 0.18448937053401626, 0.14246175636447247, 0.18413756763742817, 0.1579133667532475, 0.32820064694650714, 0.2674324690334259, 0.07475522737349234, 0.19852810028579929, 0.16569262190211206, 0.15426710999060064, 0.10591006206889307, 0.09270026243381924, 0.11027665598498237, 0.0998529878955695, 0.16191596165299416, 0.19190399847444028, 0.15072876437296792, 0.1690106406327217, 0.08798485336404654, 0.12871438517205178, 0.1182812482358948, 0.10181425725139918, 0.16904635565175166, 0.18686188354847894, 0.16014058353199115, 0.0877534871500346, 0.14613661885021195, 0.13059119333422956, 0.20555102747053872, 0.13990202678307412, 0.16315513951403482, 0.15358740614066202, 0.13701778235695056, 0.11096487107175974, 0.09165942473637481, 0.13020801147626293, 0.16582014489798777, 0.13988132708736006, 0.09393589330777045, 0.20264380040668672, 0.11590299722287925, 0.15917636994873324, 0.09886003069339261, 0.1482945046718082, 0.28507614808697856, 0.11043620911697227, 0.20598972005949867, 0.1954807710623549, 0.10407299854822698, 0.23287981988922243, 0.16376747359191218, 0.11714563780133763, 0.12761995196342468, 0.09287516030693248, 0.19752339129486393, 0.12554575358667683, 0.22887072856387786, 0.16116226903132855, 0.13661019293771637, 0.09302488453085385, 0.08055563910954422, 0.20633442898190793, 0.17291981877098161, 0.12689969907965393, 0.13215016693838183, 0.14858606241403088, 0.17045159073125932, 0.1994518337831382, 0.21004183488267086, 0.13266321602127246, 0.19573584769762334, 0.15568504680789289, 0.16110150293717462, 0.1965230030398215, 0.14070225158526053, 0.22194402202242808, 0.09627488231466663, 0.13710612761637858, 0.15593569545495897, 0.11625999419559395, 0.22687563642619119, 0.2100296387629163, 0.20420516420516277, 0.11647785427950083, 0.20333375451305222, 0.14255963175767852, 0.1184307273116804, 0.15062917294281145, 0.13731773642282333, 0.22186133049188123, 0.15745103269094424, 0.10605532000021589, 0.12084244104522852, 0.2624088934352321, 0.14922620548355967, 0.16084305551503936, 0.12312680032224425, 0.1290961880717547, 0.15406607319751095, 0.09858896580314445, 0.16288331619674162, 0.17581976799955293, 0.17006100846394417, 0.3460693107016625, 0.1308541147098426, 0.1308678276836872, 0.11763263223392349, 0.09105731793228658, 0.12885356802613507, 0.12997438530287436, 0.10477768452537638, 0.1605649196332501, 0.20833607883222643, 0.07678975005664172, 0.1865485689092067, 0.1484723136790337, 0.19437067901655553, 0.22024984922139879, 0.10192180833508892, 0.21182776969527045, 0.12760514348384835, 0.24182274727331055, 0.0802737340751675, 0.24916407592113943, 0.1720430464634011, 0.19717141985893252, 0.13353536115779033, 0.11012427343596375, 0.12241977777692581, 0.12495429540473608, 0.19951491346282346, 0.15537038385387392, 0.15677621648196252, 0.10566183425966771, 0.15450186997411713, 0.10817307813633835, 0.15947515956096112, 0.18094284309735223, 0.19112327827080605, 0.07855682378454555, 0.2389024201059534, 0.09413265533024266, 0.13753361999988556, 0.19681800817770345, 0.15538366781848093, 0.18569407443846428, 0.20485935732722285, 0.11725573229693598, 0.11689591612065993, 0.1327566481045177, 0.11693327056784784, 0.1263285958538613, 0.17746557000904314, 0.16254977683626837, 0.17146071238863855, 0.19971090939737138, 0.13045636185955617, 0.17699891521084696, 0.13480096905221864, 0.10079316163976347, 0.2131420088511321, 0.13612760351069514, 0.2453799999409145, 0.11669352335194427, 0.13446801191856786, 0.11822755313328198, 0.1434162253093335, 0.13218061127249273, 0.1584394546526094, 0.20429015399948244, 0.1606147306700868, 0.10838158428668977, 0.1452322060903234, 0.2366584106799095, 0.11529867642468984], [0.02356800359613713, 0.06647901098814703, 0.0186323978742885, 0.18883937098566564, 0.04934416370346181, 0.08030377238267854, 0.04045808770423455, 0.053447480013053265, 0.05853150377891237, 0.023172188948299137, 0.09117034654463492, 0.027506459699643236, 0.00905341833018728, 0.010405057898512291, 0.02723523967659041, 0.024750132804676413, 0.0492270786555544, 0.0218999907825022, 0.021963932311102267, 0.043457965441649, 0.01894459402519128, 0.05208154524406118, 0.03291112956620994, 0.03681122190168789, 0.07488396078828843, 0.05115868891739557, 0.04349410180903731, 0.06622429441420302, 0.09618704267326864, 0.05398628114151859, 0.09955979838606813, 0.03335072996936018, 0.05023786272372931, 0.0355208502151072, 0.03309020644895012, 0.02396627355577244, 0.045144963829267415, 0.048447174335559534, 0.00287687657551179, 0.014446373754781822, 0.030645349836577813, 0.03677191776073268, 0.11551520351560847, 0.03137529947825017, 0.08826233041022094, 0.03985747094115904, 0.03737455316548867, 0.06352334801528244, 0.061724110085877686, 0.0331463645242395, 0.03096703973208224, 0.005627122168774687, 0.03229247909339686, 0.03562622943953161, 0.018793201644814784, 0.03430776530876756, 0.04721146302237626, 0.0647090720914064, 0.06636418206917663, 0.029497512638749137, 0.04866835541061817, 0.026811481971714287, 0.055597046119791854, 0.10483370087439976, 0.02732663205073726, 0.09294436102913273, 0.016776425388431358, 0.036634516061073354, 0.025779527063751896, 0.01971506588761845, 0.01931851771059296, 0.007945986524704964, 0.04352907372278072, 0.08129836901301339, 0.01754665784838219, 0.03800210557998188, 0.019921411670023398, 0.03347315848053944, 0.029454801321750688, 0.12513152984601836, 0.042792847905788696, 0.03961285140605704, 0.012140951847897903, 0.07843042693791852, 0.030255035700036154, 0.023410275668626832, 0.018048376490872715, 0.0660828132963469, 0.10963960024978846, 0.03830114034034553, 0.02666413070513837, 0.06766807903806049, 0.05056528870256678, 0.024814895962575273, 0.011328895775330885, 0.04182866496604778, 0.04028207517319149, 0.07755475779694897, 0.10228072052761432, 0.07270673124660408, 0.02486427799017439, 0.050555406168343565, 0.07697553403915898, 0.051830708905453646, 0.05693842777081075, 0.07191390685376621, 0.05996075188440662, 0.01743709578389122, 0.10205778128076946, 0.009082294099273221, 0.023022639009380536, 0.05345179308806697, 0.033652679694275704, 0.02398236523262195, 0.08436102765582262, 0.04724173881714383, 0.01735928040298243, 0.03275111295102585, 0.02682577525716155, 0.08086476324787063, 0.06766973378797693, 0.06513490206411769, 0.155093458391005, 0.039127052070633064, 0.0688971751820176, 0.00850483330131899, 0.027221396467798663, 0.049796925497151194, 0.02281538924322494, 0.08206369851024882, 0.07439672120756681, 0.005345829047127477, 0.02940153905881509, 0.01759901804278695, 0.061477169304365115, 0.02788082963126081, 0.018478113511997848, 0.042762564450141885, 0.015973251147736466, 0.029224208856542266, 0.018195298748211037, 0.08756083135883655, 0.0961673312309769, 0.048934245376937816, 0.016254093235118255, 0.07260479558739932, 0.046651119501480175, 0.07971287344492252, 0.005778094637207688, 0.06316065900929033, 0.11574119179239196, 0.021478196177932046, 0.052022085329818155, 0.05902463840621133, 0.01575992726195123, 0.01994625015574838, 0.026386301258518815, 0.03013333305716515, 0.032208473722059885, 0.025513723282323732, 0.040689450087806875, 0.06471393674972557, 0.012968791246924911, 0.033861450144960996, 0.05628406227896771, 0.0441406915084489, 0.014003731982572185, 0.01128979656289542, 0.014953406174637139, 0.007393514557230858, 0.026571460879377784, 0.06490965689262075, 0.07072339855855511, 0.035518498325179663, 0.015289004396406874, 0.06658889097912658, 0.017822958949592807, 0.06659484348229824, 0.018525907822373896, 0.05179027861524975, 0.05002435018879272, 0.04035424448609833, 0.028336640454888828, 0.013391942784730947, 0.012152692145337502, 0.0193015048130145, 0.11009586689573143, 0.04525566353432594, 0.018727400437778523, 0.07359368486269828, 0.026128141119355158, 0.013236041019310155, 0.028284130873338833, 0.011139039077886171, 0.07623263559634648, 0.02544106750358497, 0.0014830478269892236, 0.03891427498010378, 0.05209967088434966, 0.013617095068067074, 0.014239508947808177, 0.029490953010897485, 0.02597158722158882, 0.131563849206413, 0.07031058441967734, 0.07242164694734159, 0.09380404191512255, 0.03779011756001461, 0.036648117952168956, 0.024201644494408564, 0.04033123503529257, 0.04622269249070556, 0.017884293864030513, 0.030293131337290814, 0.01773299724464455, 0.023662523524234855, 0.024552905383790215, 0.07655945636572377, 0.18614076498535373, 0.040702638291423364, 0.030092979375753674, 0.0166905794908563, 0.04410793741924628, 0.03231250463173755, 0.009462289031474821, 0.035705825974864346, 0.011748986791879421, 0.015509800512283562, 0.01725642543826853, 0.024495404739413532, 0.06454443979647852, 0.05451116245239974, 0.06018123964989378, 0.11387261141452099, 0.02459724655284757, 0.023285181171471075, 0.08922999138913809, 0.11630502484378316, 0.04583452723079151, 0.0652341793982252, 0.014643044804313011, 0.06358464271010411, 0.0746366676063307, 0.04779048759730593, 0.06390746450051665, 0.017482894435224515, 0.04280245081791955, 0.02146654781104336, 0.07787970165091176, 0.0683599713468744, 0.03296962037922875, 0.03362282524786649, 0.03778822915328126, 0.05115580842680028, 0.022643063510317477, 0.08323424255415317, 0.07463256137505656, 0.030392477619311506, 0.015951833244593396, 0.1356544676086595, 0.02963720302608225, 0.03856626804918051, 0.06092801449760314, 0.03387055126950145, 0.09273340339742361, 0.04833981860429049, 0.05017118626123956, 0.02533153416739116, 0.057023448208647395, 0.04390268331213344, 0.05313853973582868, 0.015865037397992228, 0.050857524432602434, 0.10050967080338348, 0.05021178126034718, 0.09306162610770234, 0.017954722242129427, 0.01718362793326378, 0.05478300492189104, 0.04833406528397914, 0.01890996110535437, 0.07045044143113398, 0.03817288190006249, 0.00911315786652267, 0.08161805750381562, 0.020402986030544967, 0.04486776640518539, 0.09666037775816456, 0.09051089039853505, 0.027203504484327092, 0.03981293441968099, 0.07145703499836308, 0.04849932960144455, 0.028382599984686223, 0.030247384396892403, 0.05638181126766628, 0.04425190449241669, 0.06298645061530894, 0.06385335571042473, 0.014133641342332047, 0.052870703906181364, 0.05891907915112473, 0.01366668776984537, 0.04718548115042429, 0.029392269394931295, 0.04731372809938846, 0.05533797050555868, 0.025228058671458595, 0.034584024275142344, 0.029463961818105275, 0.01787312047165488, 0.040156195435913346, 0.0378299005059225, 0.06837476450469225, 0.016966116419362447, 0.020961456466466192, 0.03319217658211147, 0.05291046386945152, 0.06113359419208381, 0.01630144321449822, 0.05708287364893383, 0.030271498929528944, 0.02341394906022376, 0.12334701995695792, 0.033930551275731094, 0.008352064835508505, 0.05084465798591414, 0.024230156371730472, 0.053984251008519245, 0.06524308900078458, 0.05387520222293754, 0.027101059376652685, 0.03570222919205985, 0.01884347233440607, 0.07007069930794739, 0.028491650685487736, 0.009144679511777096, 0.01616822627012528, 0.028999398439942353, 0.08827625788868436, 0.01672006046940242, 0.02990927723717065, 0.07022479789391642, 0.023985410432120966, 0.021737396281452912, 0.10153834302459033, 0.030653872564735434, 0.07420244897084852, 0.028429746950766253, 0.030472757888116667, 0.017111144524307984, 0.03365788909216081, 0.22101457350917403, 0.16223318334068024, 0.09764522208922333, 0.22605802142812362, 0.195608431954057, 0.15595060352596546, 0.1681034852780642, 0.16005951610784377, 0.23584059649898162, 0.10262412710055228, 0.20345105789601806, 0.11478853847591147, 0.19711131260039347, 0.13046002375983423, 0.12545437461906864, 0.10886926053752823, 0.1382662145601165, 0.06880669253728083, 0.13182931399393466, 0.1571722073300231, 0.16715863839753214, 0.1448101682528373, 0.15743174259701084, 0.17650255152294714, 0.34039394749749097, 0.16438599766021775, 0.10510180100438096, 0.21479639104537426, 0.21868157530984572, 0.12141711424074828, 0.23387060140169438, 0.18118261329589352, 0.13686278744811012, 0.16527323472884395, 0.12927554457658721, 0.08190818266161988, 0.11767503520053242, 0.09092291546685081, 0.09458634792076004, 0.1293750134326758, 0.10921884944001514, 0.11388372735030229, 0.28822271634013424, 0.15636072103534976, 0.12861264869570732, 0.1003087412626032, 0.15738893360380204, 0.1726750690009325, 0.20510027665765057, 0.05665545404377965, 0.11318710061811632, 0.12201672359820336, 0.1418242639591617, 0.08217101210668203, 0.11035807580957491, 0.10351608327079205, 0.12724842230278638, 0.15899822386282106, 0.1161940340253134, 0.2574724679993045, 0.1800050748692405, 0.16016765707923522, 0.17323697917163375, 0.1658024482669369, 0.0756188536122922, 0.1919594632401582, 0.12217564087721611, 0.2741460958796163, 0.1134529790931171, 0.06712735119846559, 0.09622374594572092, 0.13056916064552723, 0.2459234320708821, 0.19730786011824686, 0.10208804941465778, 0.06087819579988719, 0.11193291509463904, 0.16549248909277303, 0.1712581280979418, 0.19012036192561352, 0.222283736051571, 0.14181386048515, 0.15968857633490718, 0.2354058722454694, 0.14438710385753264, 0.11721729766577484, 0.1655223205565445, 0.23534982525292905, 0.2884281198343923, 0.19400663403493745, 0.11261124764719319, 0.09704133030027152, 0.17691843001352203, 0.10604913767066695, 0.11197758568150383, 0.15812070078907475, 0.11532574231105468, 0.2935066086149985, 0.13362166862333977, 0.23905879397305752, 0.11313271603637165, 0.1825624295780736, 0.20486798347725024, 0.1618259616436497, 0.17051745897098897, 0.1458933706124944, 0.1558551489706001, 0.12119383025433748, 0.24967874911042953, 0.09066246855523317, 0.11239171749161136, 0.15281143568215833, 0.17703538099604268, 0.1178803850686358, 0.12072206564968634, 0.15142098609958926, 0.12270021958336716, 0.12463596288955982, 0.17356619779621402, 0.18522760350136988, 0.15118593500266153, 0.1712448441333348, 0.2507481772092081, 0.10719470724823976, 0.15742782022683852, 0.24467717555742113, 0.18636979463119663, 0.11576967494141673, 0.16977185623780375, 0.1740444052003084, 0.1641491692393057, 0.10797150508170167, 0.08295787633546899, 0.10232739826484073, 0.21518023173895576, 0.12256246165282304, 0.049111008674146674, 0.12744349893182516, 0.11028480716049673, 0.06576667179263408, 0.09426754043107072, 0.1583310378895652, 0.14596699166201776, 0.08293596622083457, 0.11577771886462167, 0.123378605762076, 0.11478491488002962, 0.24402607743057514, 0.060512017263399984, 0.19437562794454638, 0.2040704399827988, 0.08692394416298597, 0.18166120374395003, 0.2043647403197904, 0.17559729606634186, 0.08291345089673996, 0.1785364077096024, 0.14424678719332143, 0.139547067604238, 0.08745889569963179, 0.07015638624227817, 0.1533294490147983, 0.08204600187919794, 0.19228998421420976, 0.12743873386493615, 0.15013345276876805, 0.23144265426503075, 0.13500209777585923, 0.08619246043024525, 0.1542232897613318, 0.13165502899116086, 0.20526641048491004, 0.11986359518261687, 0.17385893531384009, 0.14650844728514073, 0.18121835895844046], [0.06317593480250047, 0.05503602078064315, 0.0967999283344515, 0.06790047180989096, 0.058402923581701134, 0.04078718375474696, 0.08863975128699696, 0.03677641086640858, 0.02069167668871101, 0.07607967082050539, 0.010156173168891862, 0.013451304065153725, 0.04971226129019934, 0.04862706710193907, 0.026212209692945885, 0.05392623900045311, 0.04953046862576758, 0.018927674973383546, 0.010324941381000945, 0.03694108146573267, 0.056156895513976776, 0.042895963340396845, 0.06566786943303962, 0.02524584723306039, 0.05330527877254833, 0.09584895275052517, 0.11182248352035401, 0.024486182956025008, 0.06541940413655774, 0.07286805404169906, 0.05643187894395763, 0.01776363693117615, 0.013934231528471556, 0.031520419513746616, 0.07318959646527806, 0.0312769242126735, 0.041055670759129914, 0.1083043473021638, 0.028392664464791457, 0.04370876347586032, 0.021894708606264284, 0.050204319563964685, 0.02617133124130628, 0.05287997740050478, 0.041300684829512914, 0.029862917426432815, 0.04565118706875271, 0.03758845640526664, 0.056381907028656815, 0.04841001524079231, 0.018382295064868468, 0.03798160889756776, 0.0213967552859216, 0.038148455186596805, 0.09097844151960266, 0.02532672888088611, 0.009293131072134262, 0.05286504251642093, 0.043111831595700596, 0.06551838269637478, 0.044435895829191135, 0.0740889224013494, 0.056377498192652586, 0.10350392545543372, 0.04468154575255129, 0.027009444837007793, 0.0320753563691171, 0.027072480466637402, 0.03915911668070382, 0.06570802010115116, 0.02319686847077983, 0.1106497637867447, 0.05655506971262156, 0.014970047519572321, 0.02248115274274061, 0.11017403850752501, 0.02932806739643697, 0.01621617188286637, 0.07366982634149252, 0.006044813414900414, 0.06362472826074209, 0.03905744915227256, 0.039035577342034354, 0.05294198455709604, 0.06661886033872444, 0.03378695958564359, 0.009097396565090505, 0.07084684596667368, 0.02824735482253375, 0.05599039013407404, 0.021927615913051753, 0.038903457818612944, 0.0459111436840988, 0.03745643647327539, 0.054669723500527685, 0.06237121689463816, 0.013358626578513895, 0.03247541705927542, 0.05746848400562041, 0.011598014802251373, 0.030699000889134985, 0.025479394882436723, 0.12048090883200208, 0.04525602742608997, 0.02992525974649095, 0.052028972460257436, 0.035840481249315125, 0.04957795841619373, 0.04683691880575592, 0.02076728190595825, 0.032674622902226065, 0.04013051999913108, 0.050164655361685066, 0.07001210890349842, 0.09056907477638415, 0.007822418936543287, 0.06470806851622558, 0.03169428508338188, 0.03217093924420976, 0.027566808275878433, 0.0670658573207836, 0.05854107604752626, 0.025319661719784625, 0.023749886275899988, 0.08357094585775368, 0.03371723026277558, 0.04592301421648553, 0.02909171778047758, 0.04370085744848175, 0.03411500992613935, 0.05104626168406779, 0.004262571146095833, 0.05429793720043475, 0.0884632905945182, 0.030725974844948902, 0.05094062965062838, 0.03771237495745863, 0.06381222828020973, 0.036242803814069885, 0.06218890712085751, 0.04929299669099912, 0.017288507285317587, 0.048173891620770584, 0.018395646062168865, 0.051525909333459796, 0.050898797419523044, 0.022492280169840784, 0.0326512916944921, 0.029829763056289767, 0.08206552179950861, 0.04040601287758158, 0.07792010512803832, 0.03645020296737071, 0.011322971042846481, 0.04322462272079241, 0.03418390804360952, 0.016019033519701374, 0.05481514997119385, 0.06891669510232826, 0.057458536353923624, 0.07012129175446688, 0.10214705350658587, 0.045477897980280464, 0.016037946315332046, 0.004106898249442419, 0.02148618264454267, 0.02211282341440599, 0.0927012583481208, 0.03371747541091135, 0.02689790818089199, 0.03691441777552809, 0.0369622408142013, 0.04190099515741871, 0.017179684495673548, 0.07054570446451826, 0.054257307727370536, 0.04250562239077784, 0.011267714078478035, 0.07220199421769188, 0.059624757212136066, 0.049985069030475233, 0.040170233997125784, 0.04743423756031741, 0.014196162735442481, 0.04482797196795864, 0.014702265316079703, 0.06119791110376678, 0.03171209471240159, 0.030872793680417444, 0.0732820249733425, 0.022674764228624203, 0.03246176154202512, 0.03443675919345791, 0.0038145188779209653, 0.016537907743646253, 0.057230387709193656, 0.04925427094642674, 0.04586103770341124, 0.0571679515433648, 0.05887849564333597, 0.06113641722608478, 0.058293495582596916, 0.07231953508791424, 0.015803842294600703, 0.008252251239854002, 0.07754816944080015, 0.007844483705177423, 0.05677318260554345, 0.03743182589870788, 0.0409007677808404, 0.006189886527511502, 0.06637689146784044, 0.040358277939019666, 0.07221721638474735, 0.02019532640734988, 0.022567624917193767, 0.0318860751952255, 0.05113879361400201, 0.01585114630870521, 0.055442905398987, 0.050701637031330224, 0.030233246244249806, 0.02653990763299648, 0.014778406794873938, 0.037779913268863194, 0.041777065113907864, 0.022330003595280073, 0.07381172880770699, 0.04966885857884923, 0.06763094675637062, 0.056364447884862466, 0.030620545824809425, 0.033255214126960884, 0.04104972208639787, 0.03538051822913751, 0.05742321970061429, 0.05199575105742101, 0.009969376035094743, 0.06857506585337463, 0.007340250379075447, 0.09765106734008559, 0.05836973665282131, 0.05246688363953464, 0.05894616802012729, 0.03393456557645433, 0.10345032994425106, 0.038427004755865184, 0.03269657515169632, 0.019029622123907172, 0.10450507213752117, 0.03760681570237202, 0.005910020723428217, 0.042316379521282456, 0.12413834281746419, 0.06098961945803416, 0.01794784277256939, 0.025306207300614447, 0.024732256142963326, 0.011101543862042169, 0.03374525375904576, 0.02928985684599367, 0.07022059973209135, 0.02510201614049654, 0.07771616486171562, 0.05945408048348562, 0.04713900642649782, 0.03578890054937332, 0.11860075286559521, 0.021717251999483957, 0.008079161334242071, 0.022567458293070237, 0.04765955551016716, 0.04687865527587072, 0.012831410614683503, 0.04655875228044968, 0.0074430498024148336, 0.009600757508568708, 0.04602331810841157, 0.03451137998772245, 0.01752311979690867, 0.04072948584272977, 0.005895244323783705, 0.045715170732188615, 0.016886251753256205, 0.011008812749247638, 0.08000138981808579, 0.07147311518389372, 0.030617600216740565, 0.07542209158982001, 0.06494148018499536, 0.03928254110618465, 0.04448707816341231, 0.08359078753499255, 0.015589743702402039, 0.004404759458867052, 0.04012929808889185, 0.008782712543653625, 0.0707403444234402, 0.023685136524539803, 0.03135886497705454, 0.051082964956520066, 0.028343320741588553, 0.07020731576748433, 0.017722061339525447, 0.012269899767312792, 0.08017607318658022, 0.01380828380089013, 0.04866690367400166, 0.05879858118151465, 0.09858271452568232, 0.07452226003571864, 0.045793656440031145, 0.03952315017100304, 0.07867856281659297, 0.008553208880907586, 0.048017747580043735, 0.03503484786638329, 0.05203336214406356, 0.029097923092664253, 0.01146476721436146, 0.04326278156030082, 0.05623339322365581, 0.009990480799798765, 0.030204950786766507, 0.014189501600940863, 0.06254126926163031, 0.03593736455865926, 0.027834199774529667, 0.044372984688849225, 0.03724756260072032, 0.07473944596225217, 0.025662648859584046, 0.050020875980056105, 0.018315145543085474, 0.0360095338715661, 0.038435699853805766, 0.07961592501810483, 0.008106624628717621, 0.05317499019926595, 0.015554230739062112, 0.11194054533036486, 0.056581204802158384, 0.016627909668210535, 0.061082549753689, 0.03547063698211024, 0.045337362981010834, 0.017794990994697137, 0.05593029436685386, 0.1126961378500827, 0.04968652073594351, 0.04550752260031239, 0.019987105624750257, 0.1714109319953188, 0.1798076693329119, 0.17128363882582034, 0.21849350072443488, 0.09334854135710387, 0.32147920600348906, 0.12636768932063736, 0.21218263694355566, 0.11988585769769647, 0.13593842575867332, 0.16007111467901738, 0.17749866500737208, 0.156674005031105, 0.1969413483335126, 0.2263919285108005, 0.17238637642754664, 0.1425663886531707, 0.08150536597015397, 0.11422791533292302, 0.1962484218060009, 0.08588583373855199, 0.15837726363491628, 0.1454289527910371, 0.10154906825553026, 0.09325853368688015, 0.2902172722162739, 0.2352629202387987, 0.11344243772327901, 0.21082745804902048, 0.20435732458868336, 0.11949231833099358, 0.19637189985763645, 0.23447314487589946, 0.16384716205779584, 0.1325464948651291, 0.1297576896726124, 0.1602030350195785, 0.22732761297975818, 0.1282746353817563, 0.09157156211233909, 0.10173293701823681, 0.09784629718670923, 0.16740210113986848, 0.15924334135507384, 0.14554078630622358, 0.18500263412152568, 0.15155290644015038, 0.134394375547286, 0.13756463123906043, 0.12397859050261399, 0.10635446201288894, 0.18871839038066326, 0.2924719915514992, 0.2272657437189933, 0.19159546422381557, 0.12709953311470248, 0.1759062440044457, 0.15571316223471396, 0.20342943889479484, 0.15348816711095073, 0.215301365561543, 0.2449420121528449, 0.18821065794796715, 0.16095360200251305, 0.1956192031502724, 0.10535061870130802, 0.18325432954776674, 0.1951638098445631, 0.19048621487473288, 0.14323890659837954, 0.11131766988264938, 0.17168450199307936, 0.2623327136520417, 0.25365137465057835, 0.10417008487087104, 0.18403550940415553, 0.13945267025020816, 0.27965592280510937, 0.17788750059421987, 0.1461102654256167, 0.17223470634029758, 0.14310536215141897, 0.10943537653093377, 0.16767617675565905, 0.20733238107735114, 0.23011932930638715, 0.10868421199941829, 0.12532743385001538, 0.12379621561135977, 0.1506681974616743, 0.16598277004255405, 0.18424716417587575, 0.1548570896228475, 0.1408973435360578, 0.1792509379165788, 0.12254891721832177, 0.1316755448257731, 0.16675775990851466, 0.09647601869918647, 0.09101678422021289, 0.1975938100968638, 0.2002769870863807, 0.20183432126237502, 0.10002205583957896, 0.1755048445756397, 0.1057582464249384, 0.10540954618444366, 0.10261454334061954, 0.11062481996393013, 0.12700766385082277, 0.09130946045080501, 0.1638675706400987, 0.19454629701231757, 0.294120398259932, 0.1244995839172794, 0.16613002746335923, 0.19753814614828558, 0.17161350096425704, 0.1406744885588846, 0.18037383895247214, 0.1806552077253019, 0.23120631614039022, 0.1082427078677762, 0.18744558125974672, 0.202114877982005, 0.17004024748119617, 0.13405695978191592, 0.15596062395601504, 0.1568320336481256, 0.1264183660368285, 0.10602964073299401, 0.09653187416974576, 0.11641978481484037, 0.17162572772752854, 0.19914984192338683, 0.11358595663501371, 0.16067166632461935, 0.15872235560128767, 0.148292604773756, 0.14407331424374736, 0.13868489693249428, 0.11327903116902999, 0.12281087332315023, 0.09190547685589522, 0.17986662745956453, 0.13412932444724346, 0.22487677513591706, 0.1183710030971035, 0.11282712356337618, 0.16639057396640702, 0.08993977185098395, 0.2209333835109588, 0.09389234887015435, 0.10493634133449486, 0.17739481412835661, 0.12028816877113235, 0.1397566079732872, 0.14490848797703945, 0.1107280120073307, 0.24652018392037964, 0.27326687209067807, 0.20886083373860007, 0.2095123915182006, 0.263981580013229, 0.16062245283636356, 0.12436044702847159, 0.12218434363603593, 0.2643423461385312, 0.14109430474139031, 0.10911760325994223, 0.10705551673327723, 0.17001651407730195, 0.14132953969941986, 0.1700042260269965, 0.11827254547707497, 0.15259834066514047], [0.05035337346095232, 0.020364739090925264, 0.06408217468208845, 0.0734931588052742, 0.016467659396209543, 0.03186008183195466, 0.026914961298086473, 0.02266295498327142, 0.0063990601319669485, 0.027973681402903412, 0.09057900327588282, 0.03148612367259639, 0.030911980992964203, 0.09475491024673947, 0.07469489794945525, 0.027784007608950622, 0.06057782421609568, 0.019260551667802276, 0.018679278624814846, 0.025251742279637727, 0.06823817868867228, 0.043218133956073754, 0.08220291200784907, 0.05356937226268554, 0.09872694589918661, 0.027037657940039234, 0.02436832607453389, 0.03176532633182022, 0.06913541320471034, 0.07613485979457056, 0.0450716185713968, 0.12650396104060835, 0.058423067863670096, 0.026049191928318432, 0.02726173674267146, 0.07271975474131685, 0.07363081714438816, 0.07485182339986486, 0.039970246744492365, 0.05487986141815782, 0.05226960067727393, 0.06068190492148842, 0.02599684514045235, 0.061114047458695794, 0.05537629788441043, 0.02439943690513892, 0.04087121210872166, 0.07406882025421628, 0.03381578364379464, 0.03482643364658279, 0.016968994994737932, 0.04791737474020451, 0.031131865464210994, 0.05672200410176189, 0.006039999509906216, 0.0027088579325561203, 0.04717558329444259, 0.04459058430286185, 0.06661020354518006, 0.04513300136632977, 0.06080068302370849, 0.0646439086525671, 0.09196929197998778, 0.06434143415742344, 0.054798349663014376, 0.0512016472977496, 0.035953153630778674, 0.09542493074531518, 0.023386019409724304, 0.06120154619096749, 0.019639443433392915, 0.04253844925833326, 0.04780223938606439, 0.034265435120511445, 0.014248192554429896, 0.03585640821726092, 0.05632610135381261, 0.042960582856809905, 0.0409562670205149, 0.04257796790390726, 0.020398799360038775, 0.06705536191622097, 0.04470742803307311, 0.06348812329252401, 0.04152404542471613, 0.038966713698520776, 0.04759016326598583, 0.0457414781915084, 0.07206746917818824, 0.028132414820814328, 0.061456890957009416, 0.02184055002045728, 0.04597139266890384, 0.022177316526311542, 0.05357503748288559, 0.03297695567110374, 0.04030049192689119, 0.03952455211190447, 0.04998635222774841, 0.019542797611305313, 0.010740528758164617, 0.03776715790492393, 0.0703206354932439, 0.06297567558865394, 0.03826120800729241, 0.018956138970210187, 0.06446582385368886, 0.017020749979682507, 0.0324413912641185, 0.04710739380830238, 0.02774704961226352, 0.03032090393976579, 0.0738015091947971, 0.036039901596884576, 0.01652046775205001, 0.008054202189669013, 0.045154589724036, 0.032623643581304825, 0.0569233320082628, 0.03415436003237002, 0.046338486680460554, 0.08409187798538516, 0.029484726631292896, 0.014742276173145061, 0.018691131920223276, 0.011253863208807044, 0.03126573358331958, 0.077398200068743, 0.02746809018595565, 0.10792942387202095, 0.04506152919343403, 0.034028602869159756, 0.00862851436625445, 0.05668647294383376, 0.07512753078293416, 0.004328197110519415, 0.04993314742140713, 0.021380925994186152, 0.024991710970719016, 0.028494693969766942, 0.038870588816221685, 0.03809573301564782, 0.021733167476110885, 0.03438464606240873, 0.036495065076216575, 0.03630352011250873, 0.04230710985739866, 0.027188939237666708, 0.037806841259401654, 0.0227344329018266, 0.03450540833235268, 0.0400562669270702, 0.061619140718492775, 0.02288812737641556, 0.018463352912916772, 0.02735437592491508, 0.09200335224910129, 0.00880244696858309, 0.01763395356735395, 0.061203097519014156, 0.03531871025540656, 0.09188689156285218, 0.025626294157137314, 0.051191795407043356, 0.035490497811547214, 0.014624773607318921, 0.022642546400968588, 0.0262618770882968, 0.02171130332675192, 0.03805842453373536, 0.06484091582317507, 0.034704985727946606, 0.04031681726055761, 0.036452968544777364, 0.028854150084718585, 0.048561432519026344, 0.05080118632665084, 0.01713369240713937, 0.03812584027107205, 0.061749440783094016, 0.0155131004360174, 0.04015351795861798, 0.04522543370483383, 0.03579017608576725, 0.02536346854251479, 0.025013498511285554, 0.0750179342444866, 0.022895219435374585, 0.03912633577842386, 0.06613502984926586, 0.029948240468999552, 0.005372803002941393, 0.08361004698540896, 0.0846564541420629, 0.03217623674220616, 0.01650047668766591, 0.05850638758631484, 0.02024222631007433, 0.04384793483862474, 0.01782514996105625, 0.06723127868627349, 0.030378737832389535, 0.01830850164556215, 0.02413141338395015, 0.03444258912256168, 0.018361151038158326, 0.05042733158916236, 0.037430665275502595, 0.03747763795657985, 0.05887775636848904, 0.03708658454519126, 0.037572835872490565, 0.03861969119058021, 0.05591866515216328, 0.06450726921039243, 0.03265364358441965, 0.058407401365618554, 0.03276399088903301, 0.014328520703730325, 0.04683183964281794, 0.02954345684678805, 0.07590389194627924, 0.024750749505455458, 0.05449623905963475, 0.03980315147688793, 0.036448000464588404, 0.0471814017322275, 0.03888710184142955, 0.06539364826054343, 0.07823764857265257, 0.08389826458428176, 0.05827592535605354, 0.035082398943843386, 0.008690555996802306, 0.05290476034485525, 0.0193349905161848, 0.05099870677616808, 0.027545647012189995, 0.08577388531017689, 0.015516360140135212, 0.01479157584629232, 0.023103281254729918, 0.03264748040706881, 0.08830882428634552, 0.03370421442894205, 0.06274835431888219, 0.07620740066012067, 0.08334082836705832, 0.0513594116144363, 0.04990133178991176, 0.016158322668484142, 0.01789625058130872, 0.06641190168598006, 0.12895535046775497, 0.08638595125728077, 0.03559772713830875, 0.04549512346725791, 0.07388864403530475, 0.007471915995401721, 0.0945828698815838, 0.004687758562560644, 0.038311241209627166, 0.10038266108641702, 0.04492318903606746, 0.029127204888350064, 0.04491725185465428, 0.0547968328089243, 0.024289514779323534, 0.06465729220860428, 0.04212501075779719, 0.011635679515048621, 0.039269778081366134, 0.05703912619801779, 0.06789854892920102, 0.05510407620139661, 0.08316299637719508, 0.0658157856894597, 0.044743955105302796, 0.021627487562176202, 0.03027499037524385, 0.05586420396162618, 0.032566317221930915, 0.027773933552746332, 0.04343192611310271, 0.00973136879638919, 0.04810941000018389, 0.05911031767966286, 0.054266623356529785, 0.10980254715128292, 0.04093761277955867, 0.053459791045996456, 0.02829887806588123, 0.04566785714198505, 0.04753083741712955, 0.04471593543947224, 0.06387547649923833, 0.026024675199521646, 0.07216713721713713, 0.01928491709423402, 0.02510655329622809, 0.040318422214758974, 0.041657099575405164, 0.061999028398384975, 0.050079742176157814, 0.06898975690766689, 0.055029742690103675, 0.026920975088292075, 0.04728093570578964, 0.06682091602875341, 0.03274365125464336, 0.04884219991283552, 0.035238669389077736, 0.02526674611163476, 0.06096709264262069, 0.0643195393645475, 0.035469855572427475, 0.08896612006449893, 0.026851782026971062, 0.08025360894539664, 0.021080749762815335, 0.03883081353119305, 0.04869665469854109, 0.08241178588040414, 0.041992194094364686, 0.06003213212675145, 0.04446714838606216, 0.050168619866693215, 0.04248670001904811, 0.022608009242122213, 0.0364226391238551, 0.049534467604732325, 0.026821994613255226, 0.03544233769418732, 0.0348567707283843, 0.008759082561629194, 0.04868601756771246, 0.012791010010386667, 0.03405975583460062, 0.00698604962728437, 0.028477196521576376, 0.0696796803705154, 0.02354184360874276, 0.022871872905882138, 0.03194914146837208, 0.02123421632624682, 0.036198409018857826, 0.057161880296564875, 0.060085750620571844, 0.05431610497555906, 0.016241065909965866, 0.07510250269044792, 0.0663914318166433, 0.15443289141741492, 0.07864382839010609, 0.12980117282319453, 0.14612385582539344, 0.09787569964124311, 0.10246917049610808, 0.12083671836843415, 0.13416784334807627, 0.11130004219951169, 0.12256817666873818, 0.13907137296853528, 0.1574541583296753, 0.1472041623726968, 0.19546889669952855, 0.1948750406623848, 0.11219746057665157, 0.23816582656675772, 0.16139974096609702, 0.12893003892273674, 0.1187365189675362, 0.1572549448258454, 0.2887173946346006, 0.1629870445016892, 0.14116098503431967, 0.13420703640628245, 0.13502399256873515, 0.10727347640861427, 0.13999038736426062, 0.1364573583968224, 0.1346091253142203, 0.13641222049632382, 0.257947902165113, 0.09031671775324691, 0.14899015847233035, 0.11139905906372494, 0.2111526010858436, 0.12992193892357812, 0.17343927234891923, 0.2673869634107236, 0.10882604551771957, 0.191332021908414, 0.13200579000817192, 0.15660540951836496, 0.20605063937123747, 0.11806315832561064, 0.18585810918481122, 0.15372056754366045, 0.1473201940497083, 0.2063003993563114, 0.14502903957280422, 0.1174444274135655, 0.08789280789994425, 0.1900519043086998, 0.15856428101899164, 0.15218734981552248, 0.18747843110993986, 0.1857346158114172, 0.12233652700219425, 0.14056198088632477, 0.15964970503362919, 0.18454406921180988, 0.08372338203292701, 0.21925983379685113, 0.16859096234604237, 0.1960565474244856, 0.11788907250569713, 0.1987219818176762, 0.24800749766009472, 0.16341844393361002, 0.15102203815214096, 0.10268426500260831, 0.18037489615380767, 0.16922364371918863, 0.16110421488842658, 0.07871148161469929, 0.10628136956403333, 0.16516792828277235, 0.1508512158667849, 0.2538930447471719, 0.07238303611595785, 0.12915499298082245, 0.15300770740835898, 0.20911863764687894, 0.2191532556448252, 0.1084441047221903, 0.14638072510640468, 0.1280160883681909, 0.16560082924702477, 0.21283679942209877, 0.14999488278502418, 0.22984782774602214, 0.1293876845269434, 0.18252551946188175, 0.1357352898846711, 0.11356236878782512, 0.16326021613372912, 0.16519955239228665, 0.15764664558153, 0.20726050670829513, 0.14088885528185677, 0.16347965435876002, 0.10463016663467693, 0.18927948849816478, 0.17673579465237357, 0.18668180692099756, 0.17011812797957854, 0.24805107274122778, 0.11169420209743323, 0.12002361562824058, 0.2409690035687339, 0.1519710985162566, 0.2018470076784011, 0.19813546490284706, 0.14108308921417884, 0.2481190860271454, 0.11186634205401906, 0.10514827955874706, 0.11654031342796742, 0.15055987262918105, 0.17484885880783682, 0.07860553931565055, 0.2438848414608548, 0.10374297553132619, 0.24390869743881688, 0.19573132777887006, 0.16271266245072888, 0.11058384192086036, 0.17314302614859997, 0.1962827272232502, 0.2016541986696182, 0.129034104306371, 0.07783894577334005, 0.1409417459921491, 0.18552406420630796, 0.12884163237627477, 0.09098475408409873, 0.11788452960430615, 0.13090003402002398, 0.08449988109209845, 0.16836070695952063, 0.3182785212993622, 0.16597526238089608, 0.14636079149861492, 0.11474730762382669, 0.11085527453331218, 0.08355763124962969, 0.25264568506709995, 0.09074073209757767, 0.10426805985550727, 0.16044220766953884, 0.13609933486628917, 0.09203588800324548, 0.2947403778952937, 0.21617055359867313, 0.14481917744682682, 0.185324375727965, 0.1510269104713394, 0.14707556685372708, 0.1147838730004526, 0.15643216639516816, 0.059737601963382576, 0.19397522443004195, 0.11459845674013901, 0.10707985534663163, 0.13924460076997358, 0.0960322086428923, 0.08590533833710418, 0.11633670257945215, 0.12984350684189028, 0.1304616631879922, 0.1995818389038886, 0.1528652303762013, 0.16459795886710768, 0.13686045854082032, 0.15887572640372863, 0.14291875845482274], [0.04254547428459891, 0.08273682932579711, 0.01565149517714857, 0.054480300600370096, 0.029488930538777384, 0.08382705671171989, 0.04628823514306738, 0.02191053789799973, 0.03509965124389818, 0.06767799221580068, 0.02713519050889919, 0.06171669052433103, 0.011763174740237095, 0.04021723349128039, 0.05903899106347273, 0.050292607366798386, 0.03181892184300288, 0.024021020114061334, 0.02548844812648191, 0.13042714326612412, 0.0503254687083104, 0.043655983848317016, 0.09725948915846887, 0.008156786150779695, 0.08470519265580563, 0.029147161478777567, 0.021680937516653252, 0.024663398245109186, 0.03583500372065652, 0.037130408604899724, 0.014247064489961393, 0.011808731116264338, 0.09234906474669134, 0.03157334661321535, 0.025149440813449123, 0.018088226469473976, 0.04087807242608359, 0.1208149461496261, 0.054242154508228266, 0.03139390392349132, 0.044647929814433863, 0.013028724220461183, 0.011774542527423512, 0.018912663480507273, 0.03044875826866877, 0.04755467041245392, 0.08814351017316503, 0.039312682835565466, 0.10973051956464207, 0.030127150727616205, 0.012708673753114718, 0.024187556137481046, 0.039501504356702494, 0.057249333063561114, 0.010469522282120683, 0.049977879295305866, 0.053601249181214845, 0.03457239123001214, 0.04298875957066494, 0.055050534316368645, 0.06068045318487191, 0.05156764197313497, 0.027069163305925268, 0.06533603844863754, 0.0413628222210513, 0.017857666563002333, 0.06456977432413448, 0.04795251519329125, 0.019829034872893846, 0.042811031002671494, 0.03294027155084956, 0.011884371765078077, 0.013600266031590442, 0.0386979892068813, 0.07348644021417826, 0.018275923756582123, 0.04535987830510543, 0.0023511207273845835, 0.04640633142703483, 0.042770068281360214, 0.04711068032549755, 0.05287929941269179, 0.0030394095501246592, 0.09506106962479892, 0.07751851417725125, 0.031011197040037766, 0.04810544166473612, 0.01954773887841692, 0.12732506939961066, 0.044483075354007945, 0.05073987631007068, 0.03981362772925247, 0.07401520176039589, 0.05648032634428913, 0.07111424129576453, 0.04443290425584682, 0.05318730123220913, 0.05499348374864748, 0.15621891816056546, 0.017351487373572685, 0.06784866894445113, 0.07112242311479584, 0.029230463964444016, 0.02673187202984287, 0.01639043007256283, 0.03069024641938027, 0.011377801870807044, 0.061746855236349575, 0.03670152577181016, 0.04435582431934534, 0.03850061048363005, 0.021538441332297462, 0.053598701938866615, 0.025769818814531453, 0.09527535973897866, 0.02377780443508058, 0.02656926603747472, 0.04866339499130846, 0.0452796382559163, 0.017188249358667, 0.03295956164478295, 0.07725982160698022, 0.060387746310762824, 0.06194859299988997, 0.055744602314887516, 0.06631062486239019, 0.007857088245556601, 0.018951596068819205, 0.047348496999831936, 0.054743386684886874, 0.05708372400652978, 0.048031843597850496, 0.015723383910353148, 0.026937129967395338, 0.026643005830626336, 0.011323014135292221, 0.009518396353439219, 0.03339955275277457, 0.04995281672886303, 0.06008516839374939, 0.033480489941974806, 0.050550055044192466, 0.04696562923791428, 0.05949770536033377, 0.05647632736532439, 0.020305759896854722, 0.04105131937972, 0.09765562556323507, 0.016318569110045512, 0.014448492945502362, 0.052694986318989154, 0.019592057064836545, 0.030446427446159146, 0.032448270733678536, 0.016543454220218044, 0.01824581267071828, 0.04299635150199456, 0.049406776069513256, 0.051354129438198386, 0.05571744449797177, 0.020220042319006978, 0.041915114157863205, 0.03715834017061899, 0.0376154916481145, 0.03733989534779422, 0.027159052232520717, 0.04934501406105776, 0.010702963636797524, 0.020232644465361393, 0.10009459670512907, 0.02370941193564044, 0.040278512864343585, 0.010532244773311241, 0.031588693269558495, 0.031496272422373295, 0.037418043976950074, 0.04413484242714701, 0.019906509344676332, 0.07465558231718118, 0.03474301816294751, 0.05287583669527404, 0.03903627448204545, 0.01465979818960712, 0.015947238632267522, 0.007054701639008859, 0.08625041498171707, 0.05323124786598548, 0.018810386912176208, 0.010814767466076921, 0.04947591933511919, 0.015479910634307852, 0.031056915252139012, 0.05805949019568582, 0.08580835926676951, 0.04269507210401278, 0.03277804860244355, 0.009272922630301647, 0.03342612451242824, 0.05274329199305466, 0.008936138887469088, 0.02848996529205432, 0.04261742526244733, 0.023328200838859045, 0.0285421320492582, 0.06529954201992481, 0.036956276819710775, 0.06957277280068205, 0.0946083193224284, 0.11580244818281744, 0.03797199449411804, 0.01728177337246316, 0.02575253204052006, 0.06034365795072048, 0.010315015754331986, 0.03684450842199787, 0.011920605808676732, 0.02070609063300635, 0.02356579534769539, 0.007498508822473307, 0.04493315200952273, 0.06143581587821246, 0.16063415865984657, 0.033592116613421714, 0.05301153767974146, 0.05423907483477266, 0.07820716593414545, 0.019996158868795442, 0.02697592657510071, 0.0688767895823525, 0.036620477499860915, 0.010361767227521107, 0.026142426743923176, 0.040624018518194076, 0.03629628824250352, 0.05054373481881715, 0.045057181644463734, 0.013051939557396598, 0.023745772383746602, 0.007096498438547696, 0.027449183135984406, 0.00837376619118356, 0.017771117779756748, 0.021902986186286135, 0.06426322424123365, 0.044588167295460744, 0.031738871400575006, 0.04273684304808417, 0.02793955410109653, 0.03390245883154773, 0.05147950355744651, 0.044091968316464655, 0.020650723543498787, 0.02853588077179607, 0.06289674938025494, 0.10345828193690508, 0.03305930246208464, 0.05517830246038014, 0.01728900332724856, 0.02667920923070802, 0.04006921764343016, 0.040655263414185856, 0.04330538370977006, 0.06276434257386193, 0.06424683762053329, 0.020878492974706238, 0.018553521461604584, 0.014364840932220463, 0.08591023363894032, 0.013843473092082047, 0.01530078874390212, 0.05514668601174509, 0.13947421264263893, 0.04464885678082224, 0.03267626999126327, 0.06449098984200148, 0.018626696264912045, 0.027004168406429312, 0.040764944222305095, 0.010255986764546364, 0.05159737001503668, 0.012249673130891979, 0.07467526311595594, 0.025407934200859843, 0.06784258620633234, 0.06734391659378045, 0.03846176982586903, 0.04907580693402598, 0.022064494757702755, 0.03698093718999336, 0.03237489100185133, 0.015130001890112557, 0.03258774470117304, 0.03492028707818639, 0.03658021957943997, 0.018527731111633684, 0.021894848417310465, 0.029420664443844752, 0.023008385943549297, 0.02056717399447676, 0.03549514030436835, 0.07912867011562472, 0.0290386738526004, 0.019994996330370347, 0.025812355846527125, 0.031000402861184655, 0.028355892244425994, 0.09519315850470336, 0.04823441256678874, 0.046768193058068716, 0.03520314589202885, 0.05235855880704138, 0.05335854486592355, 0.02044262533496705, 0.05905771808278176, 0.029476968075839743, 0.041611210908740766, 0.06742735889049307, 0.05797395647893991, 0.05442520738729546, 0.05765031497444838, 0.055358823418857596, 0.048003540479487954, 0.0516684438222118, 0.05946904218064682, 0.05558860383086628, 0.037806419911043304, 0.06821390136235184, 0.03352663141765422, 0.026697683441002044, 0.032051774267587936, 0.051559027314426444, 0.036988433360332446, 0.05082438729943768, 0.021251997226969372, 0.022582247620448474, 0.061084476464818564, 0.012834453898962709, 0.02615843989676045, 0.06723644211888313, 0.029826470793435172, 0.0042270347213132255, 0.023917667192196655, 0.02468135343083451, 0.032311232925783244, 0.05717189689617484, 0.0857031217686111, 0.034182770403041955, 0.031031553911405708, 0.044064584503611254, 0.058399093142079736, 0.02496145624336937, 0.03284069161201197, 0.1849212755839671, 0.2009341373078285, 0.2206952987058509, 0.17923002371624594, 0.1563597251210482, 0.20641886719292213, 0.13210797081551245, 0.13246156635784334, 0.17557699473634844, 0.25719826980944605, 0.12694446159706962, 0.11141149267073601, 0.13665651061361836, 0.1216130948535377, 0.0941744530873914, 0.14921259976202442, 0.09792237737846952, 0.21965875110078245, 0.12911221463113062, 0.19171011694256337, 0.1569955627764425, 0.1567002358816324, 0.20455155852100543, 0.09118304062154024, 0.19396908040488922, 0.15703516952212782, 0.10997830304287134, 0.1014661928638816, 0.155070583005586, 0.11936622025865702, 0.1322663518329782, 0.152706925967528, 0.21918549262467893, 0.10329726557697981, 0.1761751868311436, 0.1787740481837142, 0.11311230745406882, 0.22728868039144626, 0.1773515914476687, 0.08540833113534797, 0.10778626502161065, 0.13212661739558945, 0.08929552255018104, 0.08929747607438795, 0.12780015116497395, 0.2263070766123072, 0.16723276506508553, 0.15944751910865307, 0.2802793651578888, 0.2164172798755669, 0.07353778342686354, 0.11085816268478671, 0.19482115403779093, 0.18234217929984295, 0.0805304884429901, 0.10738683443877006, 0.1375000347052851, 0.08976229226156589, 0.1313796663476575, 0.11206768528227845, 0.15488100688784354, 0.11885622020570502, 0.09059509878317196, 0.11271431711652588, 0.14004444252819787, 0.10331972727491971, 0.161592458044329, 0.14414670546689343, 0.09554105435287762, 0.1157264139563326, 0.13340789944894854, 0.09143866884011416, 0.0659353566926814, 0.1532430036534225, 0.28407759844295444, 0.11408467221284106, 0.1320848196384407, 0.10849331821044607, 0.22107700967500288, 0.17265485960148996, 0.14405163395549023, 0.2162693789409053, 0.05149972827864751, 0.27315971171182973, 0.18303199551038205, 0.12070425410544681, 0.10925208233417043, 0.13276565729850723, 0.10685797330112227, 0.08887005263879415, 0.1917306480989341, 0.18362814981129863, 0.22291870036673164, 0.18792619417992332, 0.18069587167232268, 0.23342175048685845, 0.14674596518518465, 0.11749285183125928, 0.2676306406576788, 0.07845065165911952, 0.22161760727965066, 0.16170603823998284, 0.13429682191100814, 0.2611760128169291, 0.16197104337474993, 0.2095761913205347, 0.14587513771989655, 0.18959234348468243, 0.20479027151821122, 0.08917746840104943, 0.10094378218655625, 0.09800473949120891, 0.1408296213635514, 0.20138197698660437, 0.18519646968812714, 0.1174989575520158, 0.11102391346808403, 0.08310344070196153, 0.2099373251680405, 0.1223733145443182, 0.10745231197365832, 0.07272279611037624, 0.12415500522981729, 0.10410659150370669, 0.14870972432676824, 0.09695024244607457, 0.09358825792949046, 0.07191081185855212, 0.14436024481490736, 0.11922258643373368, 0.22867359881920202, 0.1992805058797521, 0.13520872701079617, 0.14178171543584717, 0.13744858424029044, 0.17851200014833482, 0.08419138514586995, 0.15297347859990212, 0.1468595147373215, 0.19102204741249162, 0.2103964263393033, 0.14461628672096039, 0.10360845815270178, 0.13845203684702997, 0.16245781564183776, 0.13991949358774772, 0.13774686823448828, 0.24845709934109644, 0.09559952218325869, 0.12163118985030921, 0.10441410685739211, 0.11796342133874856, 0.10944972535775555, 0.0949118203753906, 0.12282634063834146, 0.1628618197695863, 0.09632404983764696, 0.10957783824133296, 0.14676202238807756, 0.1357616892745418, 0.13625212344190768, 0.12145838339722927, 0.12472037811793628, 0.12803808275249698, 0.13754949334167665, 0.16674737175626142, 0.08097549359644614, 0.1404136202989086, 0.1713145887779613, 0.20129576145160585, 0.09331575279394466, 0.1186644300938614, 0.14546013256955534, 0.09933308232575656, 0.1166742179362524, 0.17452794457635573], [0.0216023234890834, 0.05553769728829784, 0.02170246075688591, 0.061986996987534154, 0.04959104702838006, 0.07358071499414022, 0.02432752040124709, 0.06118740420788527, 0.04439546553898723, 0.02609359246918992, 0.03219789404782557, 0.10287377217243757, 0.06554532600867172, 0.04472472629840336, 0.016830139643242283, 0.026708887476894646, 0.027250553774196776, 0.0283182907338825, 0.023732289236279267, 0.024294601603140755, 0.018545207492406332, 0.08497165335762887, 0.04123258727392362, 0.03596307063895849, 0.08584047367255535, 0.030203813146198952, 0.09497248687811437, 0.019570675550869877, 0.04056922407940992, 0.03076029941439629, 0.05154703420797183, 0.034003697350741394, 0.017054712572585673, 0.04619686000589882, 0.0372806154642134, 0.12122065865344579, 0.014095584009473604, 0.058249924331903465, 0.028373611858114604, 0.03816507163367445, 0.049145356226231784, 0.041023498896749756, 0.06502447815071191, 0.05327385001545472, 0.06264029378672281, 0.030157411200625282, 0.03691760853173272, 0.042706502135843045, 0.028518435034540393, 0.07574416261406676, 0.013904988037181959, 0.05037339899929301, 0.051898749004448616, 0.021789911608662338, 0.04878298897716788, 0.08558797875359174, 0.031544618316054825, 0.01740232496822794, 0.03456091523290642, 0.04851922107439849, 0.022799728490832834, 0.06730955755037647, 0.06759102591463635, 0.06057985434909502, 0.03373261330829513, 0.03464021299394869, 0.05762368575820039, 0.11986664421255551, 0.05073577007879654, 0.042939879330656225, 0.005347188853193075, 0.023518744142605894, 0.08820852805529872, 0.028507208016010064, 0.08954861501772558, 0.11405771357878564, 0.016707236157549966, 0.02390749354456221, 0.010997787786407337, 0.015539313091956561, 0.05728888618309171, 0.058699181273339264, 0.04341232958399961, 0.040295205920213656, 0.051827092970451044, 0.07950393062445425, 0.024603107125468315, 0.015064236114642795, 0.020843724074262767, 0.033845247385362466, 0.04347484618906052, 0.009058971510028407, 0.0034419851632969036, 0.031505362055594885, 0.03601310001085362, 0.026223086226250858, 0.02114541524450385, 0.05791030223331144, 0.004854650816865145, 0.034044571971941384, 0.022117232250410224, 0.012376079553618066, 0.06960987443885497, 0.05766204378056911, 0.0830412803277854, 0.10359825386155037, 0.04334567993458721, 0.06157255108137766, 0.06146501914988603, 0.0031123145468412872, 0.037831011333412705, 0.05688943261761339, 0.08630045584493107, 0.03855309899776213, 0.05644892823071249, 0.009757265441059586, 0.017188009956190665, 0.06120814603843516, 0.05623881329572009, 0.048323064261386474, 0.03788057722211365, 0.02451892172346913, 0.01704153969072767, 0.008401407601101505, 0.032382850655384605, 0.05927966524576468, 0.033256156415107756, 0.00980421418188921, 0.0016842482516714824, 0.01814095821652201, 0.052106129005551345, 0.045667788194071864, 0.032278781441310724, 0.029251223031972206, 0.06907025742675028, 0.06314413066232397, 0.019188232967750202, 0.10078960699179482, 0.019155283526126898, 0.02356729113436755, 0.03241944284508786, 0.032190834547603325, 0.0357454786858251, 0.00789639621695143, 0.037375541418910994, 0.03123215020393893, 0.013392064401188926, 0.057300446449869105, 0.020453951944927537, 0.06446800720427306, 0.03719347296282649, 0.020202541040376793, 0.027494863043689442, 0.04811690234008336, 0.11671046921682936, 0.11142997071146966, 0.06494572431209587, 0.020806800551532258, 0.02999670510630935, 0.036621350840094595, 0.04261084456717776, 0.07355888914917746, 0.019047004658909097, 0.1094041507871401, 0.04393585491925479, 0.029018947088550177, 0.029953400071169582, 0.07984195159928453, 0.051369715497017875, 0.00551171389581155, 0.07464339385830587, 0.07971327181064314, 0.07457123603671789, 0.018691871195070205, 0.022201967320495078, 0.02024353440520504, 0.025222198098837852, 0.06034579150558961, 0.06966032132866883, 0.018705775690895897, 0.018148180510428165, 0.042316567212823904, 0.036357222876000794, 0.02003335435273907, 0.06110702626286976, 0.02312496728864649, 0.0445793534538919, 0.03936083146160649, 0.03533685504789314, 0.017600130785496968, 0.03737061930399749, 0.04367389115354708, 0.05308123252865288, 0.04683712181905585, 0.040599894409458485, 0.06210657565163509, 0.0555484991280302, 0.026936059359521158, 0.09953423403203489, 0.058930467048119155, 0.017617298815880093, 0.048884334748670946, 0.06178729701787234, 0.029888336223760442, 0.05621047953384058, 0.07550315901396737, 0.04380504923662351, 0.03393485668986555, 0.006913221957567599, 0.06859518332226623, 0.06590754770103001, 0.14497454007787092, 0.03821579048470144, 0.03133917268696091, 0.02844522958771596, 0.03204425319939131, 0.05753460122392543, 0.04761457848813265, 0.0695431788241671, 0.04926141854676028, 0.012564884795386706, 0.03331509155912265, 0.027868495615679893, 0.03282150877038798, 0.06446308891979918, 0.0246630784034008, 0.08661657436600617, 0.045777047653832746, 0.06053755863479549, 0.03150800122849403, 0.027553899694354306, 0.05940834120396645, 0.035714398498737046, 0.04551277413303333, 0.03563478664164582, 0.011234370101573727, 0.01840644981712103, 0.022710027255778833, 0.0251919778454448, 0.04817719345972423, 0.024171251871232546, 0.07082571726172202, 0.039241570723994125, 0.06260843602039161, 0.02509267369825994, 0.02048611231598883, 0.03758923015407017, 0.0227314796328785, 0.02822954710873385, 0.033428319354331305, 0.014479508972726764, 0.08094517183640311, 0.01960250267368411, 0.03598643249020942, 0.041555206051036235, 0.019097254281082464, 0.03566770160931253, 0.017413473462746028, 0.0706755563676838, 0.0717912178726927, 0.0190150587924666, 0.04222995331210475, 0.07594855487226479, 0.033225895942098675, 0.032570327692214525, 0.014323373550489066, 0.04275862292777147, 0.022299982524747332, 0.03672957991159732, 0.06572531836648142, 0.03657471523770402, 0.012883867527688704, 0.018480691397863052, 0.0192640814179134, 0.06058610562655715, 0.007120076230832286, 0.05468227585116702, 0.0351383846493498, 0.037601636948003885, 0.04156585467318374, 0.03272183307055985, 0.03970765861712637, 0.08248564441718402, 0.04239078964136782, 0.049158567412486004, 0.04808534717848224, 0.024629489278360724, 0.04939861340268005, 0.07064231581264926, 0.07660953553333398, 0.06343114550315565, 0.016471522394567728, 0.024789944478881457, 0.0809301718348457, 0.062250646146675276, 0.017359740055736997, 0.05243066683291428, 0.05412992262732118, 0.023078442769004934, 0.02870735040144815, 0.04315154942413492, 0.051430952735245235, 0.009076783054267928, 0.021415828960016373, 0.018943460215063348, 0.020510797584128958, 0.08898830597078608, 0.0209191128716714, 0.03357667994174746, 0.08205910964358239, 0.01829486719572977, 0.05855291976683563, 0.03959502454005903, 0.02281180969739874, 0.028567409120319832, 0.0636944767358082, 0.08292791463675038, 0.04385978238837373, 0.0598419469691092, 0.01392148382541153, 0.04717069565348568, 0.016391450884721933, 0.022593401860625997, 0.04932789582638972, 0.0024859711148535776, 0.05470599393330274, 0.013747149026922643, 0.011116043033619082, 0.03424991800960514, 0.059163756142821045, 0.01747924211104551, 0.035504164820116375, 0.05644335494106335, 0.02784237010224212, 0.01881728553393435, 0.1056525262913877, 0.047440331789755055, 0.004233618768217463, 0.03303032901678835, 0.012498827906505717, 0.05382702678381916, 0.04241043979662561, 0.04608118839021172, 0.02568030910145852, 0.03365819935777015, 0.03248646404714354, 0.01674812993094806, 0.00774969756152601, 0.0713755538867366, 0.05415925613394188, 0.03532567782507789, 0.024962863929930235, 0.10994479435706332, 0.14871110328503195, 0.13263226606913153, 0.12806003883240685, 0.15305319770930276, 0.13451477392546593, 0.09937784484317226, 0.13718612251743195, 0.22917011572468668, 0.12780310060348243, 0.12191810509971074, 0.19658759957359684, 0.16358882188796997, 0.08134496248056812, 0.12895409408355915, 0.2457632124423981, 0.08001543220973785, 0.15729767721026175, 0.1450469507084739, 0.25219553180279275, 0.2413598769494603, 0.17250740299782447, 0.18752847197315387, 0.16679643202693234, 0.10144106517996519, 0.15267779930464684, 0.22533055965698537, 0.10914999345738081, 0.07327841669921914, 0.1384872462480299, 0.16014493491140105, 0.10454058797369081, 0.10154413464929789, 0.1452848056872045, 0.18847587758735304, 0.20074489826877273, 0.2908083243716148, 0.11919695313178724, 0.09894709658598709, 0.056003827316265915, 0.12550550332713512, 0.08362945965341023, 0.15960346396651962, 0.15212362662198084, 0.12489424943323098, 0.10295723745178792, 0.1785564332479431, 0.08134391294011185, 0.18815640360116961, 0.2099947204753276, 0.13793186314644354, 0.1470032634754335, 0.12287658834529501, 0.09018218505286402, 0.16099279506071923, 0.1815743753386121, 0.2339737474798195, 0.11087383684371749, 0.11143314231547619, 0.12299765321996906, 0.09025032857372876, 0.0797493085866013, 0.0791388514241384, 0.15750675792655638, 0.15634985790858347, 0.168071263619969, 0.1231875357728812, 0.268919752129624, 0.18659101018021185, 0.19425097011750747, 0.1345585481894593, 0.16720054340699028, 0.1167985157019669, 0.16626501215561745, 0.09595487206693619, 0.24014443249231388, 0.11857809198479499, 0.11559984857036222, 0.12155346256951172, 0.12776058272368487, 0.18372830814651905, 0.09547245884013754, 0.2501610014587641, 0.1400004384378272, 0.12009426425661772, 0.2291683690442193, 0.12117694567648635, 0.12228039573998221, 0.10933585404869049, 0.10519408395573979, 0.12888615740643394, 0.09761302341376582, 0.18359490159538486, 0.24074066340202288, 0.12755101937199795, 0.1412391106808378, 0.13685244526113235, 0.2036032489230556, 0.12384221919121281, 0.14256677169713283, 0.23433316529037493, 0.12407425190171889, 0.1964164555313126, 0.14170250194447656, 0.16978774490135332, 0.1486236466875961, 0.14972382555565528, 0.09336056893751507, 0.18715927888068462, 0.1112445621120353, 0.1883478336516888, 0.15889941384234738, 0.14326659301596303, 0.19136490240212412, 0.1894377929068381, 0.13375878304002747, 0.17598597843560482, 0.21541178947494877, 0.14648572511730656, 0.17393816412696916, 0.1815793702318784, 0.19189685853498598, 0.10901942143156644, 0.1474578906932185, 0.15405858085761148, 0.09401491527716, 0.12434508696558977, 0.13359857873330194, 0.12688952543201948, 0.06827289013252144, 0.10450506447664193, 0.17902123411336254, 0.1261845176979419, 0.21783468043131216, 0.17136242330795334, 0.12471174430702964, 0.2111598329558488, 0.11377231518347418, 0.11280886002726133, 0.13178003921864495, 0.19061902387728616, 0.17415349612072592, 0.14071116884869916, 0.09584407277044751, 0.12424300574967939, 0.1266235014003131, 0.1889852800917241, 0.2516082641217978, 0.05878967540939489, 0.17180016594788722, 0.14918538831895398, 0.11654601312212406, 0.17698204595475428, 0.15221356534429137, 0.204365674947058, 0.18363695982242786, 0.16470744815324584, 0.0872596821958019, 0.14382983617965253, 0.2520833458871611, 0.1036049341482501, 0.15615694164749117, 0.1252708659176865, 0.09672809993067095, 0.15069890226567947, 0.19221486163235482, 0.1466971500626495, 0.14298701688887613, 0.12259390956211476, 0.12776520223386828, 0.09929595004406669, 0.1525338820271915, 0.17283685144878205, 0.10840036876259312, 0.11009874738632672, 0.13713824202216443], [0.03723999748246805, 0.06880998671535524, 0.04565210254382222, 0.019214766423007654, 0.06747913111241595, 0.06488701899445827, 0.024313479924814838, 0.04683018872334112, 0.04376757987624696, 0.050202017469752225, 0.05075754995848383, 0.056199064823768796, 0.016548554450573943, 0.019978500542140776, 0.07582313861818084, 0.04460489865572703, 0.025733669040604465, 0.0065487719069595544, 0.07398920839712506, 0.07269494881432864, 0.030403294780802344, 0.033089386734871135, 0.047629432932984446, 0.04293063264941016, 0.026625418367104667, 0.030428315212409345, 0.028286620659092744, 0.0536704499034151, 0.026268362022575834, 0.017267707998173374, 0.07188914689205347, 0.020053462245531624, 0.04279172558697962, 0.016018747194339673, 0.015812442589160657, 0.044952124176967534, 0.022924192880670873, 0.08607969994867042, 0.020016343370380423, 0.017754225541026365, 0.027312637539580468, 0.007759565252795696, 0.05158323952327332, 0.05749005704156815, 0.04461187771671722, 0.05627979516922947, 0.06920026254750068, 0.04171192082726667, 0.01661680330852828, 0.05608907375004023, 0.04098597974065812, 0.032358014084879434, 0.018883500428449725, 0.04266831265281766, 0.02671094633819115, 0.03651532810181379, 0.008520477774342703, 0.03280513364100649, 0.02740491474527986, 0.015028506731464258, 0.07507791126807851, 0.04561576316313398, 0.04142694378031358, 0.028774611005980163, 0.048178679670297334, 0.041903695617351806, 0.026520167462407585, 0.057776853547341404, 0.027066313458846945, 0.04675896935946038, 0.05236690533497641, 0.01605851481848907, 0.07720195132518008, 0.0974558987804959, 0.03666843460392087, 0.007459158716242641, 0.06186555289933759, 0.055553597443166285, 0.005556428053927038, 0.06355180435122983, 0.025929243626794028, 0.03085412794814235, 0.043761409038016875, 0.047521422196540146, 0.03462070456495689, 0.03328882240419907, 0.0837748861240764, 0.10897223041543078, 0.08818615828790972, 0.016079909738994414, 0.03140311613078079, 0.015285958239297955, 0.014274098775199345, 0.017691685953327728, 0.011366812339533242, 0.02536638925272611, 0.05625859751636463, 0.04085531578429284, 0.04982095767533587, 0.04317803691411692, 0.06101711818407621, 0.035457540709044666, 0.09025468761401792, 0.08030826165791481, 0.11183995798590685, 0.06481274677019927, 0.06209552866376697, 0.03779598196307498, 0.008648673012371986, 0.04896257913881733, 0.021169024159110362, 0.039103973671914115, 0.015029748751511498, 0.03337568911393324, 0.013132203546833369, 0.04461604906546493, 0.0142278261069629, 0.020479546942477746, 0.0443075837627534, 0.08166339458717455, 0.08148352480343274, 0.09049343125474069, 0.04594427315638431, 0.01936751669422994, 0.06778732828435398, 0.04442316727832921, 0.08009164263644526, 0.03230269104542752, 0.02914921459441464, 0.030829210938405127, 0.049505670359658624, 0.03429687153848429, 0.035012811347241365, 0.018057355041345282, 0.03580940872310631, 0.021537937629487247, 0.06532512935659578, 0.020373483984580925, 0.02236995699575111, 0.05839571852477328, 0.027651361400081266, 0.047864235051336794, 0.03449622293814056, 0.0509195315891937, 0.027454202927108255, 0.005517121040142112, 0.03772325340598341, 0.06842915674731617, 0.10644474547476539, 0.06354033218456373, 0.05963596890890791, 0.008599630936289267, 0.05308729228413394, 0.021652824005051967, 0.01915845513013342, 0.046507619741943576, 0.05645937383956006, 0.05338330865807591, 0.057464354791708534, 0.03775772353213641, 0.044072850592314236, 0.04617251756210481, 0.0436296534063595, 0.05667949388284357, 0.047728633658299525, 0.0458921370426974, 0.05928581693179666, 0.017949304085284952, 0.06170741319956799, 0.05956178478476021, 0.00811385841394264, 0.060662021109413725, 0.008332678022974683, 0.01799501463650696, 0.03678041750625257, 0.07255218832963899, 0.09157971328785343, 0.013636828535386633, 0.045219622927928166, 0.017139058853048953, 0.07697633077060023, 0.06409777223222679, 0.02769444043928337, 0.015715700048472614, 0.018430583501955675, 0.02222035726111743, 0.01763990798574542, 0.01713653842377807, 0.038080009061001965, 0.04764653967633363, 0.0664006861587686, 0.05789620621550468, 0.013825428848635527, 0.033867586509234486, 0.03505736702091752, 0.07731796001955386, 0.05763164924217328, 0.06152391598950471, 0.058301386288217, 0.05681546299808449, 0.02805506483831954, 0.02774720474506819, 0.0379354061348544, 0.033601072181256554, 0.02191865076911786, 0.04749890687244554, 0.02829371271805177, 0.01307080543014191, 0.018117671058843696, 0.059728228877629005, 0.036144181485137636, 0.005450065364129842, 0.053176499392476775, 0.06639655694485673, 0.034563420340418816, 0.04576017456730047, 0.026069837997877793, 0.09449904454090903, 0.06078441514663639, 0.04571657650352967, 0.06963602868058989, 0.06816766795612152, 0.042468160691280524, 0.06562869169659193, 0.020819515695855505, 0.04277289514580081, 0.004918342888084871, 0.020069055965230353, 0.01700597788928257, 0.01899867408698605, 0.05965871788981942, 0.027344374647063595, 0.06896231563821917, 0.0448314729897726, 0.014608742259893448, 0.016612015259001526, 0.032828441866102724, 0.032194642004587, 0.02625792024416789, 0.009550984776128204, 0.028077484401423606, 0.037631836133979024, 0.07238636859842847, 0.036962734940912456, 0.09678635325643326, 0.018015271916444746, 0.03149196317779922, 0.10110934910875174, 0.031085090050774238, 0.04768363748406691, 0.0105829224471123, 0.07134576072736133, 0.04262330115682656, 0.03768186167543454, 0.03696117978242617, 0.07921752099308275, 0.03528227511372778, 0.08982305835571983, 0.01774265761336973, 0.025900118879132697, 0.03692371042204961, 0.020160649437457323, 0.09313924613619044, 0.06649572702665484, 0.06860993817568788, 0.038778964700477744, 0.06713204731744143, 0.05485865993485336, 0.05292226545392506, 0.015333973757562139, 0.07570885362163668, 0.004498425198929204, 0.052090485490137534, 0.01851231933781697, 0.031300822325471434, 0.03654639679758299, 0.026567209091398026, 0.04368080126662408, 0.03484331056355469, 0.028277222675481634, 0.050738761652140855, 0.061905718889207616, 0.03786500648505265, 0.02515497579870205, 0.031663438553110726, 0.03056104952138999, 0.04671795684243402, 0.04807029355077013, 0.029490727014959823, 0.03192365755357089, 0.034027978507501465, 0.05656108350282716, 0.05214332640471478, 0.024699111348919334, 0.03580160994803713, 0.02524563272844159, 0.07630465552210808, 0.0033559755144280294, 0.020474917856195284, 0.03038052664769273, 0.07161376892679161, 0.039535813604391394, 0.05744320310411915, 0.01779309109664492, 0.04652124078523728, 0.025468424503361026, 0.03228461903129374, 0.030395486429634116, 0.029421631629849156, 0.03557358004693543, 0.0425994873137003, 0.037501363699594815, 0.016575442221496376, 0.05057962603806969, 0.07864189018765766, 0.0034849883119140064, 0.06828325530213696, 0.056572406282348026, 0.02209266955633798, 0.0462379836056742, 0.04803886479367653, 0.036902692799846974, 0.03255707437112447, 0.010246306286013175, 0.059009860570151965, 0.03852072029164241, 0.03777046740475682, 0.023396687184069908, 0.05705888360558499, 0.02386976945995083, 0.05173470276678282, 0.027608651998302633, 0.02165916721306501, 0.0011223179711622277, 0.07686789102491833, 0.037302851166215636, 0.015027804803403636, 0.043939616410963, 0.03149611920478844, 0.032243771223171104, 0.03628312302152476, 0.016199417539962357, 0.0685659494070757, 0.023953070030397466, 0.03826140719015272, 0.05915815220965494, 0.008884788971514472, 0.06146371680041475, 0.05417936594195424, 0.03142963234905995, 0.05685335753725902, 0.08332372162370913, 0.20226950516864178, 0.1217762639205302, 0.09514500987866233, 0.11853234121395696, 0.18049596868936094, 0.16322171255465479, 0.1160534875347249, 0.1489534781825158, 0.19261759405414905, 0.11103756515489471, 0.12128700952856772, 0.12861660170939662, 0.13809695509412598, 0.15261922422195637, 0.2477895456456369, 0.21449234606998585, 0.08265648202429857, 0.1370154840931777, 0.18877569375739944, 0.19520732363866222, 0.12410468091407131, 0.1019987618670829, 0.1935662254090271, 0.18797219009889712, 0.16961980310659255, 0.08565026936271498, 0.12164548505097629, 0.25549456687463873, 0.0780557103515152, 0.09498577084272139, 0.19309839083542749, 0.07588991084166112, 0.09049410541211406, 0.3084442199718568, 0.11052971780900994, 0.09743343708255599, 0.12455913193163373, 0.1347293551530569, 0.1695623771557885, 0.12383193063038973, 0.21949486957202036, 0.1596581166790378, 0.22446526334651057, 0.2707922855211843, 0.1596709869561657, 0.22589315930681847, 0.12660067198016953, 0.14984066928586653, 0.11404964667294296, 0.12381732899455294, 0.12650279658696345, 0.052945546865943945, 0.09000783110217703, 0.1012222015208775, 0.17647002342968218, 0.14184251217351806, 0.21746721869755178, 0.12332547756452715, 0.08696377307416932, 0.10909678865103953, 0.12509438224257002, 0.2725893439304444, 0.10705174758068978, 0.18336432445193493, 0.17641380789779848, 0.11097401816157565, 0.1416121801782039, 0.09121058914329737, 0.11500831377962906, 0.13530336951296176, 0.1129651343029353, 0.1511280340773444, 0.13267866035382594, 0.14146700651655275, 0.14432554103193745, 0.16569625315887315, 0.18297217936525423, 0.11969481835201864, 0.12033213455710681, 0.18339593323969072, 0.14739706331203062, 0.12673928026830958, 0.16595099271545488, 0.21075495548786657, 0.09306661334008941, 0.15671505202208796, 0.23656245050651414, 0.1590720747387217, 0.20404889759036804, 0.11230835180369117, 0.13171895136756281, 0.1435739168476674, 0.12041500228787623, 0.16575965459548658, 0.21938243850825295, 0.18227021300023605, 0.2043347096731586, 0.15066908612366647, 0.15944975608539197, 0.11907119213813737, 0.24491717558233972, 0.1494607203189404, 0.19698921350702164, 0.12207546722023718, 0.16726990500765462, 0.1602517735333212, 0.13450551958334062, 0.11500269069426483, 0.14329853888240554, 0.07349132785513517, 0.10992569578511101, 0.07454053123271273, 0.0941221752474385, 0.2222924694539078, 0.12376710427023711, 0.12113857999323838, 0.11195990437221144, 0.11235432474002724, 0.10548092259634888, 0.21265859204915263, 0.27128671866751486, 0.11302904135757878, 0.11429234332735501, 0.17054028839113253, 0.24014660818201883, 0.10861282026575458, 0.2740606923978175, 0.09558566365270846, 0.12077933072202629, 0.0808429220811494, 0.14197458573166402, 0.14507854417447122, 0.11732638858619238, 0.1438487125861068, 0.13834337493585003, 0.10094694612968354, 0.17420307733118537, 0.10909611449366617, 0.16872387860090504, 0.144244565538341, 0.1630922436954514, 0.133893461297116, 0.12297469356487836, 0.16423181480457708, 0.12516314629465342, 0.08110032762370764, 0.1657198333451825, 0.16886744347791519, 0.18560721538960936, 0.22936487059679725, 0.1973829980218603, 0.08742315003708487, 0.12142847532466536, 0.1080508641297779, 0.1534714970377184, 0.14023164377337502, 0.1779868009109651, 0.17206288814063997, 0.16824786220827412, 0.09122958046294029, 0.2089430196511169, 0.16903530866388353, 0.15638489877024006, 0.14018186338005528, 0.16295793316056653, 0.13793607663002708, 0.25094961236801844, 0.0982968028514616, 0.17069238748761917, 0.1502499900638096, 0.13658198558034437, 0.18634028492435334, 0.08142826688145438, 0.0929302190460505, 0.1288211471851795, 0.27805057023802116], [0.027377858435014085, 0.050044877514723814, 0.01068210018978965, 0.03425092924566519, 0.03102713932974204, 0.021920156131889072, 0.021779766689325054, 0.02376228540895447, 0.0654551727817424, 0.012971224533694406, 0.02359789060128312, 0.03376418762209435, 0.021924804370369644, 0.0290717477835114, 0.03293201312302582, 0.045254843820246964, 0.05300226801585767, 0.02168223986612453, 0.054509802646334135, 0.008497616753072269, 0.01433656271171546, 0.041958647104160446, 0.02647695052737911, 0.06381982787241859, 0.07871049336127697, 0.04750896560689134, 0.004985641318208148, 0.0331547761696481, 0.01213311381082261, 0.013353540712306577, 0.036210624290810484, 0.08874688868320758, 0.03135685974191273, 0.05382218127769809, 0.06731205499700962, 0.01792612801035566, 0.004233323345561662, 0.04198739072307945, 0.04176969151763667, 0.010309893498948265, 0.028667377848779003, 0.048047579043815215, 0.027865381468267694, 0.03806274143918868, 0.022870009397006324, 0.04032736629127495, 0.08940455218356463, 0.05286927515220258, 0.031378135918789817, 0.03377619221986782, 0.052746639797283765, 0.05835141566011214, 0.041951465029870315, 0.041419995362840356, 0.062060916811347976, 0.06442666909987889, 0.03960926228413179, 0.06491308896652152, 0.05632876350934948, 0.035860958779531146, 0.045083270768725106, 0.03833081858653215, 0.008626936225130433, 0.04534410072430488, 0.07301996927708387, 0.022670550745040662, 0.06362425711666865, 0.03378500223099705, 0.07656497985965784, 0.02124705404463795, 0.06473806851934041, 0.022516764339900786, 0.07810364447293744, 0.03587048891330919, 0.04284727845280882, 0.052011961477898785, 0.03624066259832152, 0.02674402601476158, 0.01306081181316967, 0.05128247723464043, 0.028615122991463834, 0.014854159484046602, 0.04507006724335013, 0.01734157994149193, 0.024822832633470817, 0.053803266566847606, 0.04660202092641304, 0.03713818439733117, 0.022042008161905314, 0.041821402452525594, 0.04955022220289515, 0.15566004169804437, 0.14768183351524417, 0.05381114961158845, 0.04099329204989537, 0.06572361765128952, 0.05049975371108421, 0.018989233968539104, 0.017788463925582268, 0.05747083206510833, 0.007978730080198617, 0.02691097189522078, 0.046624153206545504, 0.06727922046857496, 0.039490802108400294, 0.07614825867236623, 0.02128925399794694, 0.012317814736536915, 0.01052882610594914, 0.030015880287054087, 0.03374469834530065, 0.01689793076366186, 0.03344183314531561, 0.01941988071907432, 0.06357240445551372, 0.0623245659704891, 0.0520091729178544, 0.07924591987243584, 0.08599990423047736, 0.017639773920358672, 0.007825522550246529, 0.04486560986767854, 0.028301074823004105, 0.020212661061856537, 0.05954523345515613, 0.011270129170659329, 0.016490509883771022, 0.023278242330096906, 0.11018370653712943, 0.023580695757822647, 0.03772426081160384, 0.024930171127761566, 0.08081371880947583, 0.05112996445067468, 0.017240728296700026, 0.032482001584984606, 0.04399540676404873, 0.0367861861483224, 0.05047946004197002, 0.09112366114652927, 0.01176365162996996, 0.05434109476364909, 0.019411425023610075, 0.060056669922966155, 0.052066300094368, 0.002369241819026009, 0.08193554732227519, 0.022691805854499824, 0.047142764087766416, 0.03741967574422879, 0.036374295145393386, 0.0726899998863378, 0.03871791132335221, 0.04997142883498342, 0.0511529662406012, 0.06011117707877871, 0.046236160316414414, 0.03251827584819929, 0.04671991036664094, 0.016372028640621615, 0.019098660052423517, 0.04636841007478295, 0.027840286343088074, 0.02753154333350399, 0.01898695294174456, 0.004363006230578908, 0.010410053749388505, 0.05153057863935829, 0.04695181284219988, 0.09455273964352186, 0.08377871656369779, 0.03086198609502566, 0.031147549199240825, 0.027454222079306364, 0.06276990437219221, 0.02423777511613744, 0.07054040313608224, 0.04039017017930746, 0.020612103136015997, 0.04611420294930858, 0.048857238218789144, 0.07128197624678574, 0.016679639755297574, 0.02961350026570501, 0.06102725352731444, 0.019511993215869994, 0.09368562770466651, 0.006307311048130355, 0.05125844122601613, 0.0046700322456027, 0.07802543455674764, 0.015634320443496108, 0.055440656930929234, 0.06094829284495885, 0.04134860745961628, 0.0655322029225288, 0.04207845942507829, 0.019287458590922818, 0.028365968215850093, 0.028830631185443174, 0.0020710507129889826, 0.03411487203031298, 0.027874394492696852, 0.03205462602988607, 0.06299893018759548, 0.030631307444925752, 0.0460723975312806, 0.07352450712313575, 0.06430493006783147, 0.03507641579715475, 0.042803504188815435, 0.0505451214379601, 0.015150334821232866, 0.026799739759054877, 0.04644250226837974, 0.027785633630569906, 0.009261395879870942, 0.04195670890171201, 0.06799758111517276, 0.03522636218657417, 0.02126546313745841, 0.02319230258675112, 0.026777214858861222, 0.07837480129373652, 0.044431824071873585, 0.00834647813932069, 0.028561667291327354, 0.03145718661647651, 0.04574955658866994, 0.016392762810292266, 0.04119661944587866, 0.020834393123345032, 0.058980358524187926, 0.011580133352488762, 0.09510118198851425, 0.055885654423506036, 0.024259522437087955, 0.04390039270923984, 0.020614031762365374, 0.030441371265858896, 0.11042569839065114, 0.02589955197406873, 0.024037655713337085, 0.02855127913907411, 0.04249108204197499, 0.043676603104799025, 0.025462117684524388, 0.019014279298003645, 0.036070422539787914, 0.05792005070214791, 0.06281788828932951, 0.039895978350672996, 0.01887370216389818, 0.02336383733387676, 0.08492692914460936, 0.010023310540183898, 0.04783133923586819, 0.010400445091598218, 0.024226253153756264, 0.05187063740806715, 0.027742531608730078, 0.018197269509396246, 0.04870360694645394, 0.013695575030250175, 0.03899154643858633, 0.046411667229427446, 0.018837186582987348, 0.05242780932495671, 0.05150103445855841, 0.0710392642706152, 0.05827766820608128, 0.019167765013633237, 0.01391877091654967, 0.03272398577762708, 0.04033195898838101, 0.007655776618424082, 0.008806256340786574, 0.05301781193984132, 0.044694538603747086, 0.07715652231127024, 0.0066952752099642835, 0.05134288326746995, 0.03559321104999512, 0.03959957893276888, 0.04304160814612143, 0.048459079341902855, 0.0592518907280699, 0.020602199534374862, 0.044446682347165006, 0.03003162147867824, 0.05447373522685901, 0.08265065209519479, 0.060649338523827256, 0.05397883093645496, 0.07021896030393339, 0.05591870345655949, 0.007197419510057737, 0.09444698886645418, 0.06918964456887015, 0.015224751644587566, 0.03408048234339203, 0.0328290279233648, 0.11312880132707859, 0.023146846759763938, 0.036322001983682, 0.030149242788132642, 0.008676920589360019, 0.06995034689504294, 0.04190957151173104, 0.054683819518334446, 0.06739908258520788, 0.022958592143690875, 0.021564047821166537, 0.002587872300101745, 0.05368679055884, 0.01449448503403654, 0.02488915478029559, 0.011296781369545048, 0.01568008940892234, 0.07758800601286274, 0.04520732721674346, 0.055443966430762125, 0.049635035796992244, 0.05633781100773523, 0.028603336728748777, 0.03188487435240419, 0.027466270727135485, 0.06608465190736518, 0.01627797794137751, 0.042926468961541696, 0.07575251297244141, 0.02253979485812447, 0.058048868386615673, 0.06188306949972626, 0.06774571438830707, 0.03807012652677875, 0.05231122223420009, 0.035294015411167376, 0.029935998383969552, 0.013494671344937337, 0.028041106716339147, 0.018186507889279918, 0.031583526006509224, 0.03334480044882625, 0.03790092834782216, 0.05533846463226984, 0.03214905977309231, 0.020855931685336178, 0.023311212839138125, 0.006863073842044199, 0.03936006154324259, 0.06986619979743997, 0.1286961829229709, 0.12955141283812063, 0.10793015931642826, 0.10175622609113494, 0.11936037500779476, 0.1768597017132467, 0.08179575925873173, 0.09467142964563063, 0.13944621978988572, 0.1394761585059666, 0.2036171917232775, 0.0796351078597288, 0.18209024362506407, 0.09013651855169766, 0.17488679548184718, 0.14365109254515943, 0.1702039757923734, 0.2851124300110725, 0.10020415493918043, 0.21978481852960205, 0.1382961226326804, 0.12943429331625664, 0.1571903176485531, 0.10846310370271245, 0.10227618528710258, 0.1386296926366706, 0.16259548164183096, 0.18827965182642784, 0.10797649997496798, 0.10079718360136594, 0.16912889396471364, 0.16495284143715136, 0.18000440071186713, 0.17757662211454686, 0.1908837838639175, 0.13249446217331196, 0.1733539148323959, 0.13834110731559415, 0.14575527560326362, 0.07892338919543451, 0.13381847661108742, 0.1745321274164223, 0.16081110964859688, 0.12137412138643766, 0.148913350497042, 0.07373131255829528, 0.17233270430757155, 0.1868685485134202, 0.09135292061874944, 0.11615851052826452, 0.16585950649553732, 0.1975377018172895, 0.1380529356819968, 0.18713269562971208, 0.14073759888208684, 0.09948014056370144, 0.14677323791528904, 0.16321874013350857, 0.1598675191522606, 0.15180133343223604, 0.1460546934075894, 0.12830331005276213, 0.11228693198532828, 0.14892193068179393, 0.17987781234325903, 0.11205555811043709, 0.20410232456220737, 0.09901894031152611, 0.1642085563751959, 0.09483400882492143, 0.22040018631565958, 0.18973808405139755, 0.1496651278988969, 0.1897547234811129, 0.14542253297423163, 0.12032548491392406, 0.1353762704398363, 0.11413566302508117, 0.17353572281858615, 0.21491896511325914, 0.15736693155861672, 0.12475731887764509, 0.16622762706491256, 0.16446940931341342, 0.27307495174388735, 0.13480864525321992, 0.1260670457756327, 0.17413524790636956, 0.16527098243034657, 0.15106910659420877, 0.15569692117071923, 0.19556868731254534, 0.26319067084020187, 0.15603363213519897, 0.1359005197281799, 0.14876102157417806, 0.12052092160428725, 0.20973570614812836, 0.11190544318167434, 0.08809060414111422, 0.11403632440393972, 0.09363269102909873, 0.15234760008752346, 0.1678281685998363, 0.13119916071093854, 0.22914200029786558, 0.16073063977303045, 0.09916841172643247, 0.11577204215310274, 0.15793938309915606, 0.0974941648723137, 0.09622879446514192, 0.12104782155684887, 0.17338774527513212, 0.2016386624065138, 0.1257679420673559, 0.15345118038596647, 0.21244275443736585, 0.19458199670958906, 0.1441280895303334, 0.12346717318700207, 0.16567898553705987, 0.25869385729874333, 0.1526601792823884, 0.15421948996522736, 0.1604811402578508, 0.32087133055733097, 0.0973075305322005, 0.19184081154244562, 0.135007674895948, 0.1407807449539823, 0.14489215498249378, 0.21726716249700517, 0.11206664340270144, 0.219933393621637, 0.118623337137603, 0.13249446217331196, 0.2251209733226607, 0.1665871674495359, 0.23476723070827224, 0.1205256560276593, 0.12161868729538496, 0.09246796159253967, 0.22747330758119785, 0.12384812572910903, 0.1282495996283908, 0.24440650137201433, 0.10665060096089879, 0.13518726122715782, 0.09372953220360702, 0.12708815670902693, 0.19746579680471651, 0.10725437017578272, 0.12484246955042887, 0.20317367278039458, 0.22110293409036053, 0.13257401274336925, 0.13728260363061584, 0.2559564719277044, 0.09629480060069792, 0.13577002431115798, 0.1113867020655063, 0.13663717455440952, 0.08911791272581586, 0.11119469744904388, 0.07461651183304287, 0.14447229283471263, 0.18034180115547874, 0.16360003741518145, 0.20122912712395194, 0.18673233808048312, 0.1267497143858383, 0.15399432140252284, 0.1049749521658786, 0.1399786049319852, 0.10448182136901926], [0.031567901643293525, 0.04663654467872074, 0.017633970804332245, 0.13916702670676095, 0.010042651387442265, 0.03751548270003931, 0.03455199413902817, 0.010776418062197346, 0.03202720391263645, 0.06288980096278173, 0.02211648722990386, 0.057484123690594593, 0.03429203369324246, 0.03722004472248016, 0.05538488573004162, 0.005428248137656239, 0.019688316012522387, 0.03724043798302451, 0.012234588859662896, 0.02750434338175241, 0.01896674545752185, 0.0640927083910473, 0.023846995581181783, 0.0437130190942797, 0.06557334184406266, 0.07921653273966044, 0.01204098599226845, 0.018385616056020224, 0.05039555809250282, 0.03564456192355964, 0.028161418909627586, 0.029780566805012287, 0.02890065545216203, 0.0658314828310282, 0.051607888402237054, 0.085285059927452, 0.03275037367617892, 0.02920570017229165, 0.03856043428963712, 0.03685802221298218, 0.06994356701691305, 0.06318049302564994, 0.04193307125880834, 0.017938243690878153, 0.062335946206604285, 0.028178025780606176, 0.04526052053176588, 0.029714903493802396, 0.05177055951207877, 0.04300085609898933, 0.056635884327753905, 0.035146294507168, 0.031027673676069227, 0.06119311539336078, 0.0546692255433769, 0.059878753663431254, 0.06920269104622065, 0.057033081764295224, 0.03988454831884273, 0.016979838969306122, 0.033490789994116754, 0.02158369797642433, 0.05044130503290123, 0.07300460155332282, 0.023803876322363655, 0.030041954089556972, 0.05511084458820763, 0.03806562959066322, 0.05764231318607927, 0.054805903289947784, 0.05685018976369212, 0.015868672485192938, 0.07827582273391948, 0.021214728964672937, 0.012724776921283095, 0.04044309536355638, 0.02319377922122517, 0.02311036373758989, 0.018770753353413556, 0.04808273098822083, 0.059278577400912205, 0.028186289954089352, 0.015528598394725594, 0.04132646368816495, 0.022344768024800767, 0.03666425559429392, 0.02247817457593497, 0.04252066835761071, 0.01088246186789606, 0.02694967274193562, 0.04329189290142348, 0.061338710403370286, 0.02048013108452001, 0.03571255988771877, 0.027176729711373488, 0.02555204491551605, 0.03799218474136245, 0.05157893793957849, 0.026958727901200616, 0.026801898211781538, 0.014445599048368394, 0.0235467542323374, 0.030531064840033654, 0.056044878137688485, 0.014347125148971476, 0.06128717566870394, 0.04834929511191384, 0.05788462296608956, 0.03912774921064416, 0.03857684006253558, 0.03946723724384943, 0.0009098972910695951, 0.015500185151223936, 0.01567227531209468, 0.07100803852682153, 0.06828309442367285, 0.04776568167031773, 0.02574779761714801, 0.01232018865149228, 0.022399746324686755, 0.006187743396543328, 0.04760866428935721, 0.013813574595617191, 0.026166976031456745, 0.054677426514606324, 0.037517171923912344, 0.16286283100564636, 0.011283839271674234, 0.0452567667009369, 0.015439857642406659, 0.03826351776238411, 0.031848921846117706, 0.03330796694142684, 0.055063718689545516, 0.018529426081166155, 0.07829343509529868, 0.084737797357863, 0.040529529233613325, 0.005400916514542675, 0.03451111951782819, 0.06840841108632666, 0.041417425137854395, 0.049955861928362044, 0.03835613013155038, 0.014447722069528556, 0.04472077328471407, 0.01905428823984919, 0.03782298273196624, 0.02107353321456861, 0.018730782715964223, 0.026529712917944117, 0.06504479480246383, 0.0890785281456286, 0.05031760098532804, 0.02575124501280727, 0.02288056608860291, 0.02641858037320837, 0.015653908354110055, 0.03810710176044414, 0.043947311764162396, 0.0627225831211094, 0.030894652084116975, 0.07494598326663818, 0.07258500753631515, 0.06248481241205047, 0.02545026247389615, 0.02797031253125639, 0.06781608722503148, 0.06679719028573844, 0.03285948757923419, 0.08992881679366674, 0.029559590658473394, 0.021615061616044373, 0.028203754843543136, 0.009034073652489292, 0.03544588851171636, 0.04890800686553121, 0.10436418856824599, 0.01038366872366638, 0.05264351287135675, 0.024534247312394362, 0.03692184116751437, 0.04476678452544636, 0.07083427446383624, 0.013119061308492337, 0.039706842733487006, 0.008156595586408532, 0.11105389814944037, 0.05647001480082831, 0.007823980798298914, 0.04505043240985082, 0.021430091601946664, 0.02964029419085672, 0.021629435340723684, 0.02063104274472402, 0.047201963532115185, 0.03062999360413561, 0.0811170360013362, 0.027439900065561938, 0.011878172198550837, 0.03318559205640228, 0.016921296445352417, 0.04922173519228255, 0.009814012446440756, 0.08545255739121668, 0.010709825869379266, 0.06048669039662327, 0.038701697072434815, 0.055773280816332954, 0.03526022710326699, 0.038468840817410144, 0.04176151735948459, 0.07773104995008438, 0.08391778450459243, 0.0360617580853643, 0.050431319076808236, 0.03347236940997743, 0.06470462112056632, 0.0639482433607261, 0.03979768926998781, 0.025669694953267614, 0.035335679102929375, 0.05835770141153086, 0.02243477377980467, 0.0735746092733837, 0.02260368084535003, 0.11213867098934228, 0.052813327751092376, 0.04268488313461985, 0.10642904833319689, 0.08317556021915329, 0.042828585907456376, 0.02006334669497465, 0.07802401729408773, 0.018071133132663467, 0.02284150709578347, 0.03456981717458656, 0.013546635088841281, 0.01803445858850835, 0.0591745388303553, 0.11436326008650566, 0.10224820009522861, 0.047271773294215245, 0.029023827068627845, 0.05372019965321787, 0.024610135982173587, 0.022641686467273582, 0.033924751990144296, 0.09586312537712437, 0.005151355233524116, 0.031054871712600997, 0.012838252737457234, 0.02656066670052467, 0.01986428640872961, 0.03845474479960338, 0.03358807166918151, 0.03524073016559405, 0.04744736064646033, 0.03378049763400228, 0.011975098600340708, 0.020516326823722453, 0.026497738323204463, 0.04743473934790781, 0.049875127752461744, 0.11103653093619693, 0.05830328618626922, 0.08071719173101649, 0.0407007652064485, 0.04662158681199916, 0.017003938180184173, 0.029900388702029185, 0.07810037327750076, 0.02278488362208009, 0.027491971061775283, 0.04403143587912764, 0.05420244817111281, 0.06112282682630805, 0.03796650930458019, 0.013365695654835193, 0.10267697184556916, 0.06378544584637688, 0.020169474770345037, 0.02617881017466707, 0.059408977056943604, 0.031060010247353106, 0.04921014428198819, 0.043953363858764215, 0.04099328055857651, 0.024275861177293044, 0.06608754771971895, 0.04777376389791889, 0.03161858410514411, 0.029534742596649358, 0.0743861798377287, 0.01329429242985263, 0.01894146647124041, 0.022742792836300308, 0.038041846391053936, 0.04423670913843859, 0.06753665665465017, 0.014540661941282453, 0.03674651428516354, 0.12903460992440102, 0.011822650933848515, 0.011608954537810098, 0.004494771917140292, 0.07882397396550064, 0.0379950384188804, 0.016115272357579202, 0.0683065290532766, 0.07612418052890609, 0.02376690300391807, 0.06431374773983994, 0.011463760766350936, 0.014385338572244492, 0.02328418717238932, 0.051404492058340585, 0.15872189594853311, 0.05618730920457071, 0.03555790588800465, 0.017105306934324965, 0.0901204536879255, 0.03618086177495219, 0.029660731501456712, 0.049950031999258265, 0.013824928018655029, 0.01937871498446311, 0.06322027214111821, 0.04518456674451309, 0.024433397582822272, 0.059412248252380284, 0.04881868867443935, 0.04290938137039062, 0.04775980194549888, 0.047817587957627354, 0.05332738423960344, 0.04814202236312051, 0.048246053272798184, 0.025855925182000767, 0.026283825507327437, 0.030663385461535186, 0.04785788418244451, 0.06530197817952403, 0.05800024095562197, 0.038425771354307095, 0.024524866565761548, 0.04668560877983128, 0.06709103863085471, 0.01134622851461773, 0.023340937050600207, 0.03571233389178111, 0.01805076860041628, 0.12500899408252972, 0.2448114707705475, 0.07225301567344897, 0.1707250534767105, 0.09647409581849653, 0.1275039968952056, 0.1186049203839033, 0.19940729343122054, 0.20895625765044845, 0.16434203953512255, 0.11357048931982248, 0.1601457469646008, 0.15583863211495264, 0.1912114856344077, 0.2611809770666784, 0.16001355083238694, 0.13003092259168625, 0.1277760347171176, 0.10583664786310927, 0.12017795170146613, 0.1687442412179324, 0.271039578703142, 0.15956519021382257, 0.10838332330627788, 0.1566626516080672, 0.15401186481598886, 0.12238207859017196, 0.07195876130173284, 0.1996614814044968, 0.12269301069599968, 0.22826741900174852, 0.12695830480586137, 0.12343111342840618, 0.232181852503169, 0.08009329738636171, 0.16012642622715043, 0.14680470880721846, 0.1510942955651591, 0.07483646333698304, 0.15784118594902177, 0.16054325466675146, 0.12324696887404689, 0.18612893658780283, 0.11654438901572459, 0.11747766796860004, 0.09035783369214305, 0.17336079430195594, 0.07725664234209446, 0.13008244966547336, 0.1330598657049479, 0.20280253382459765, 0.08924380395441286, 0.10922412778581343, 0.18161145399414724, 0.13598364026796433, 0.1894858266196905, 0.17399174431639333, 0.22035123329729805, 0.1243964761435505, 0.1024856567082386, 0.15391739085316658, 0.0995502376087731, 0.12764668077110283, 0.11781578087398123, 0.1541757923100264, 0.17999638743217916, 0.16833142707905463, 0.08178048346552157, 0.24243328870544512, 0.09329216494675606, 0.19393771676526916, 0.11518061461467897, 0.2145638373950797, 0.22140828141522026, 0.09408308944154171, 0.250240475420029, 0.1155435564296861, 0.0751453270054152, 0.09436813543640798, 0.19994147121906283, 0.11162555295853846, 0.1575727640621124, 0.0942493535037483, 0.06875958579081683, 0.11427917427593663, 0.09401960373525658, 0.1135320470277821, 0.19129938656283965, 0.22899509527750556, 0.12201649377182608, 0.1338372151217153, 0.17786741376884524, 0.1707038328412079, 0.14406877900323561, 0.10486583826282334, 0.1478251072788431, 0.08776108674224346, 0.1815799984239763, 0.1543474266485822, 0.084980555299309, 0.1711340065324499, 0.17537247990408253, 0.17843742914978536, 0.24144244590593925, 0.14473590368945755, 0.15792910219921222, 0.06564457269926226, 0.12121234659946735, 0.19293054097121765, 0.09006574734925263, 0.18455499362561012, 0.11751644733932712, 0.08315658422126886, 0.15057288080213532, 0.3188005948980009, 0.17526148908561276, 0.09324988455421503, 0.07318361331858943, 0.08956438110720727, 0.14290879931180708, 0.08891172782187501, 0.08840200356057576, 0.11337001943179678, 0.14863112370573706, 0.1274666271262592, 0.09888296736584556, 0.21997929761005988, 0.11623162595975785, 0.13377520796512404, 0.06775465463438342, 0.17510024289931023, 0.23276237861043025, 0.1732249822347395, 0.19424894764538736, 0.18320471769379032, 0.15814740661411517, 0.1713443742764573, 0.1534694592438398, 0.10057121830722017, 0.1158746213261639, 0.18225702096617993, 0.19970648140916902, 0.17756287849718527, 0.13025111158288297, 0.13931540261593559, 0.21351812737843684, 0.12992331788184183, 0.10783820578287687, 0.09743282421221656, 0.07410664967591725, 0.0777397680306627, 0.2566121206168206, 0.13702092331744012, 0.19219999952662378, 0.1181015086871001, 0.11708567609950421, 0.14229485644928871, 0.10189842733163988, 0.10707905095431114, 0.12728150964023607, 0.13185257242331583, 0.1423785592158956, 0.2899503058964207, 0.16192587483073437, 0.1501013383629822, 0.06893094433771987, 0.17467849617523534, 0.17679021753851445, 0.1343609741137874, 0.07492259460230989, 0.21151839274792902, 0.16351798939849102, 0.09467025753110649, 0.09911253327323545, 0.11715451676038005, 0.05323628106364801], [0.040084501097519556, 0.010381998651991449, 0.02218397957603297, 0.05613346854525228, 0.051555239009640874, 0.05595939804709727, 0.01645593250530862, 0.024094269610941414, 0.12468372081075946, 0.019428847778228023, 0.03492384172615505, 0.04756787776826851, 0.04679448902606965, 0.04946294180568188, 0.028396058234296022, 0.028079026153371222, 0.006516296961044352, 0.060279712591680794, 0.010325004583254698, 0.04631148208112967, 0.032225170608369574, 0.061477303369751865, 0.05768172074890426, 0.01469477680661986, 0.09969958644961158, 0.04230547425968032, 0.06257717963308096, 0.05076331477011404, 0.005246669977843281, 0.06849040547686239, 0.02300446165815717, 0.06710826794827177, 0.04712967164514046, 0.06390209422416745, 0.036429618184845296, 0.01449172328706951, 0.009211568563665834, 0.059880350956753384, 0.03798776058359973, 0.045918973102684946, 0.05289743271385951, 0.044240964756857966, 0.07276375883168752, 0.05232852816040959, 0.020841295575542797, 0.024229698634195714, 0.04916502936412731, 0.023024659566280824, 0.039634198446067116, 0.08194226591337113, 0.009796005549780544, 0.026269273667205727, 0.037508212525637886, 0.050162023849665165, 0.03786130244993875, 0.03339058569362087, 0.04277191072281811, 0.052697644644086404, 0.022805135156358444, 0.04167809038453045, 0.0184950000050688, 0.09713917504996063, 0.012517102933939428, 0.04241785552773265, 0.07059844195722573, 0.02906683907513657, 0.04065581499749134, 0.030136983466124347, 0.05298845928102251, 0.020442171427871914, 0.12670549579084883, 0.03536459892207096, 0.043527468768579346, 0.03926237767201759, 0.05073192048697703, 0.03506717677678793, 0.04675784321021169, 0.06407934781764785, 0.08115974540311484, 0.03646174791238962, 0.05473749546874916, 0.05191986621808141, 0.07168894513480126, 0.04269850034747393, 0.048952328882390456, 0.05343845549730524, 0.09193547685901005, 0.008818014832814376, 0.06125125763637405, 0.004183999253361817, 0.035372022314057235, 0.01914981940400697, 0.00868888496751747, 0.09523034441254793, 0.010360827812203958, 0.04638639398880544, 0.01622501253751257, 0.018747401078261675, 0.030691885847538233, 0.03903659240853402, 0.061603627438026096, 0.05119246956441672, 0.04971732513137883, 0.022945417346613064, 0.019304569164711623, 0.08093723516550758, 0.042039362127862634, 0.043107943699484876, 0.0358862588332305, 0.04001045486919823, 0.014043559936145622, 0.027489193993049766, 0.04162921780540098, 0.02338407163117682, 0.004017244894883686, 0.01046421712324504, 0.08150226331406063, 0.03606406017957676, 0.0367266955905624, 0.033483745815653, 0.03401706941545971, 0.06947117422016398, 0.017942277143799493, 0.038356846423759576, 0.012202960919708976, 0.10075664988929227, 0.045499842568871476, 0.03909274282294416, 0.016622100806524678, 0.07506079686385009, 0.06778700652742578, 0.011561857367445146, 0.08122158402036275, 0.09261764751206483, 0.03842013677762401, 0.008914805253997685, 0.06530082138675837, 0.057607977125313015, 0.03915389962193947, 0.047212466597557075, 0.026149306213483218, 0.009429004426384646, 0.032695598389592864, 0.050202377531076633, 0.043654336759279815, 0.04585260307536491, 0.04720997681180316, 0.03552939975634217, 0.0237439644162453, 0.04119447823013029, 0.09133314022854452, 0.04464930877269757, 0.040236814698625, 0.11810642697157399, 0.007789045752536867, 0.039138064584544593, 0.046008222345863624, 0.04523105295975843, 0.058037472828742, 0.032772682156533964, 0.04804513522333676, 0.08030280711189394, 0.06547064009693361, 0.09299955000319789, 0.04240247248221309, 0.01723653971097402, 0.08848107915611998, 0.07877124413367241, 0.0495474566254885, 0.02865638257184577, 0.04827665465493356, 0.029546276050349398, 0.07046432294432195, 0.01799969160328469, 0.05035670211298331, 0.024473128817795266, 0.039416403479633794, 0.02885709569278744, 0.05920034450208468, 0.01714773479879143, 0.036415583454072475, 0.02797568855326503, 0.04204902632702743, 0.039208782160834926, 0.04325341613542649, 0.027955929230478023, 0.0673655815602791, 0.02341250306926668, 0.037201156824707024, 0.022339595016092065, 0.029378447253557465, 0.019470528706968315, 0.013251999588382822, 0.054768675247267376, 0.0563668342487466, 0.046783445868641145, 0.0590502257428823, 0.03816881014274494, 0.057147807261395844, 0.07525259463657295, 0.03518322377555794, 0.06117181814906578, 0.05016560148027155, 0.04003423040792827, 0.02010917982026454, 0.026851714994277687, 0.026245262556438966, 0.06524585457819124, 0.08670859684747073, 0.025143767932369828, 0.04762682057316265, 0.025851522091655962, 0.08455557568419365, 0.016319340943629225, 0.021983703125208136, 0.012410247075040976, 0.04554739747677119, 0.031579011833415396, 0.03490066756644557, 0.05805410842801775, 0.03252175771781514, 0.045323646176726594, 0.06117467182658373, 0.014725976694946089, 0.01957948364677929, 0.056166318395445426, 0.04353517561309761, 0.023717042171366276, 0.038458088773392865, 0.015532393402780498, 0.020710712058409568, 0.05252032210269282, 0.07693913720187641, 0.015706878546024525, 0.04206860370393242, 0.07091984648497836, 0.0180578415071772, 0.07828234980303435, 0.043744627882035515, 0.03484226868397767, 0.0638318209788732, 0.053993746668340704, 0.015396569844245192, 0.019969615837438934, 0.028096912391183358, 0.05213280418707479, 0.058362213669404875, 0.055046768994220806, 0.07132124591378436, 0.061950584828493103, 0.06507268806378688, 0.04539613341612201, 0.0375002145677084, 0.0492403932636784, 0.03049290025486581, 0.0492598480665155, 0.04571975576841543, 0.07359563072602596, 0.05790102873898803, 0.01253763696313986, 0.07074432041976722, 0.04093887299419411, 0.05108843482429943, 0.0744186619657182, 0.025454542990173065, 0.04489410450802215, 0.01945030781620693, 0.020076586609526027, 0.03361639393974216, 0.05316161813454763, 0.03279830013672191, 0.02144649737484513, 0.04028743395822183, 0.011586149057914174, 0.021099313988440463, 0.044642957903805285, 0.10780866543251662, 0.037331196419414014, 0.026104920994370215, 0.035984988414472154, 0.04919528217625715, 0.07538412427229267, 0.042386258231295694, 0.04610468813728902, 0.0547109428612936, 0.031656624201024254, 0.040284442384877515, 0.01848068756742343, 0.041296019354054046, 0.014718897084915831, 0.039473837091317104, 0.042557383121381846, 0.026325238305294228, 0.038630408760640896, 0.028833695537140294, 0.028191292508234902, 0.028468250529840592, 0.028179195979910514, 0.07173523982806553, 0.04435942876302908, 0.027281789094089504, 0.08344234267790472, 0.013892719139074607, 0.05280627208130975, 0.033792804836505846, 0.044372494392577684, 0.06176562439049445, 0.06308340287256627, 0.05148260238310022, 0.03353538780262874, 0.02376409146123596, 0.04746491938168484, 0.014904517316139274, 0.05815211022573133, 0.038621322957858924, 0.10275069248652267, 0.0457975136927299, 0.053353580616174213, 0.0618851341066822, 0.03016633420972334, 0.04588158035110082, 0.07066111561031112, 0.06697715200003117, 0.027418905425997033, 0.008438095551795297, 0.08515104050597838, 0.014560752597096709, 0.06491502716896996, 0.05730819159878358, 0.020628888122436982, 0.043182468732758876, 0.07782348611902806, 0.04978053121557159, 0.0159509752261182, 0.024028642688907927, 0.044778620583876494, 0.043559119691170996, 0.10846494231373073, 0.03911320886184131, 0.031772223038358555, 0.0771964967791592, 0.07593632810899327, 0.08016994448318597, 0.01571892432102393, 0.01449731094086723, 0.08875626559940078, 0.059482858576361215, 0.0074056948764219645, 0.08389382127432093, 0.021391396500891256, 0.01550600071617913, 0.05248432746157051, 0.11966806656170277, 0.0831419672636736, 0.1511846020096733, 0.09654975466189847, 0.18702129112376323, 0.15041293696530406, 0.2519797248345229, 0.1047515762489169, 0.20237026105244316, 0.13711122976195428, 0.1694231023711543, 0.1478501430322086, 0.1264570075117292, 0.22943931902127884, 0.10447877999995986, 0.16434559418309122, 0.10676064183034244, 0.1327622865116404, 0.11267961333355597, 0.13470801194348644, 0.17357384335369835, 0.1932338198586818, 0.1579210123107318, 0.13352924777615455, 0.19421318666108195, 0.16133077773115329, 0.27353368519294646, 0.11584584706372793, 0.19856447414044412, 0.16140491972046514, 0.1271773140216547, 0.1701743894767377, 0.1322246306846219, 0.1705805386506742, 0.12611117244007128, 0.14742942286595223, 0.1755134554039086, 0.13328711802680648, 0.20351962276524116, 0.14118808922508072, 0.15231727832748046, 0.10211840947909702, 0.1430933039274908, 0.20915897983697154, 0.13204291462898254, 0.15660234516666782, 0.2083563341969444, 0.08089273311798612, 0.08363303728401662, 0.11979624073231414, 0.12679172664760582, 0.09864761749462736, 0.14264183299195382, 0.10672596103001027, 0.14589603659847092, 0.08629654113563799, 0.17729045763131113, 0.179690457880497, 0.16189232017965088, 0.22755665794735958, 0.13966001960779392, 0.35992897506202426, 0.1002079623961641, 0.16235987896159773, 0.18006409428292708, 0.22962616786601084, 0.10968263906937455, 0.22427499774963627, 0.08439709507529775, 0.1901804385406356, 0.22181793927184998, 0.17933169890555645, 0.16476501199987628, 0.1634396339255956, 0.17724364965913758, 0.20214808023264333, 0.1458801939001968, 0.12960255686794558, 0.24622352403258127, 0.18583929406539088, 0.14038501457581598, 0.2632630201837709, 0.15663375477156333, 0.14441947873321273, 0.13564578017159817, 0.14618089873223536, 0.23578361487917363, 0.1717013865709305, 0.10296253878022395, 0.13939493786423438, 0.19729382538747406, 0.12466499762189005, 0.10899308332872969, 0.21278131933462238, 0.11684768322494724, 0.1372298201726329, 0.16895468557073226, 0.09496436634611699, 0.18749507053965525, 0.10906251387730723, 0.34715326382748546, 0.12960231171980982, 0.14738299793774082, 0.12829633099177193, 0.13027720453758396, 0.3407762866587408, 0.1552455115222162, 0.1230642032779513, 0.0955093383128124, 0.17826562627188622, 0.20824983265371094, 0.14747583247240514, 0.13506364527969592, 0.14165036200035003, 0.13100704118128748, 0.2345400549952061, 0.22832006456390505, 0.1627176573439952, 0.2281344414598519, 0.11212441409307142, 0.11211928896485798, 0.11114943697447739, 0.19385044402893514, 0.11709322206555836, 0.1312431494795507, 0.25741571620587383, 0.13480435516084396, 0.13786692953398152, 0.15097081751352356, 0.2724199772121445, 0.25354885676455113, 0.07755096566172377, 0.23159642343319234, 0.16228745300923625, 0.08675849215397913, 0.1703983782640388, 0.11021689346600926, 0.1144026599884514, 0.120125382748102, 0.20334544501477675, 0.1552236626946157, 0.17890408394798157, 0.21909304113397676, 0.18129170421631108, 0.16172698308383265, 0.17896661204436135, 0.11094711315367492, 0.11246983547725024, 0.12013484393396687, 0.13559354829692072, 0.19186730286286724, 0.13896689389742192, 0.13318674518696724, 0.24225407009643896, 0.1566411245373949, 0.10423244442790748, 0.13527602017406495, 0.14237552550771546, 0.09675238491787065, 0.15594580781555947, 0.10139663974123617, 0.2867585690992494, 0.12953969169287913, 0.18587689366071455, 0.20663111951322327, 0.177248552621853, 0.1693250431168464, 0.17744514610498183, 0.10890227126618547, 0.1714298850105655, 0.1390571850201776, 0.1254674134355399, 0.14023843131238414, 0.11663661068004948, 0.15836854555433796, 0.13207761841195245], [0.03988558253754051, 0.030543442905670216, 0.013570633750679273, 0.011724381005361438, 0.016230354085564613, 0.028958182909616062, 0.013664061045874993, 0.034386963478379676, 0.017349173788041357, 0.0440813082029983, 0.03985369412769233, 0.03286601847878868, 0.05037195109311612, 0.020871232376403866, 0.013228968112549234, 0.031128215055251797, 0.006767987966492412, 0.02706065398430632, 0.007926700261211204, 0.07135642467126732, 0.06874759651480183, 0.07512909360229969, 0.02678483360326819, 0.030729734421437307, 0.02798566684847878, 0.028267112230100942, 0.023643250667279767, 0.027099963870920965, 0.024934177767605554, 0.035262755193417115, 0.10013688475854936, 0.040156716375701854, 0.06286168936640024, 0.035868688606687134, 0.01767000374985078, 0.029652438599676378, 0.02564892247920075, 0.023727675471755288, 0.029907597589396664, 0.03134132922446776, 0.03258191094162964, 0.06340458140438122, 0.04492472504235564, 0.059304448190115155, 0.01915686932813016, 0.10302606279090529, 0.009226793603551005, 0.03082372766408709, 0.017862125194721648, 0.03846525935636413, 0.027484892409354932, 0.017802466097618305, 0.036250545132544734, 0.033606028770126646, 0.03235396147975999, 0.027582356030301704, 0.05076175195074851, 0.01692111258425059, 0.06731773170852853, 0.020617917743361285, 0.06430883711624531, 0.08193396918115117, 0.02388752546281584, 0.062153130814793615, 0.05720388489745318, 0.046436293125753446, 0.06681542317833632, 0.05577808035717857, 0.06641963151313605, 0.04242461625366442, 0.010373785231833257, 0.0115638539840978, 0.04324690821850973, 0.03358753157719489, 0.05018831981766609, 0.024499095367988753, 0.04311462015574498, 0.04623119606666508, 0.061496321502472126, 0.011532626325084318, 0.02498038436075853, 0.012728533624941784, 0.06959895768593397, 0.0683194529565592, 0.030699286256886782, 0.04014906698777791, 0.08562053749037367, 0.02137556912437562, 0.03327139007348207, 0.03881113273241828, 0.01780390059725652, 0.03089411199213036, 0.007764707139182476, 0.061158886584903926, 0.009573857288717503, 0.059508890244028265, 0.008119160699988566, 0.0700851247435616, 0.06891776762542225, 0.017269651946281234, 0.05518781727239971, 0.03830022486527601, 0.0319999024542349, 0.08299892332645194, 0.031125696541200724, 0.0198148699071739, 0.07427787798787318, 0.002510443793594717, 0.031093440409148895, 0.039770960462309664, 0.06245714514666508, 0.02311239961624867, 0.008406214802826365, 0.05812520138739098, 0.008864664799353529, 0.0819616632596139, 0.04705657919628486, 0.067405870124217, 0.02168645718014769, 0.06620890370780422, 0.0441922722083907, 0.03609232499354309, 0.046244510674789074, 0.07746073582600202, 0.025494228259870605, 0.018159480307311304, 0.021579231683825775, 0.01763573089133828, 0.03447599821693955, 0.047626874199317354, 0.04628324408024069, 0.11269105868714471, 0.05530778664134203, 0.0320577459229577, 0.04674872676391275, 0.01446424179800576, 0.012591000732725427, 0.03828164340267259, 0.023670504245186047, 0.06386903369979513, 0.022904674875580018, 0.036834652700852004, 0.019569007394414757, 0.021386964682249293, 0.04891320477209745, 0.03546389157793695, 0.03200378077435157, 0.05346831377415408, 0.020393473133745215, 0.026952698789236527, 0.06440708789253427, 0.005488907937110672, 0.09480112067033207, 0.01176036415516489, 0.055293108396712816, 0.01624115975573659, 0.0459368076295622, 0.06980969315214504, 0.04860515315686503, 0.008220093741622424, 0.05681655467337659, 0.02368089622787891, 0.014375624577364614, 0.029065726332426555, 0.06632653650857749, 0.03328158287331462, 0.040675082108786995, 0.09743637119930598, 0.012256119760774798, 0.01893945357521936, 0.0707487024426941, 0.02726743835204792, 0.03606076217106274, 0.008053299163528269, 0.029772392646860213, 0.02964092046773482, 0.030851917784480803, 0.01882631579534181, 0.11370391119271518, 0.024008584591830452, 0.02026893788077418, 0.03264774853784231, 0.028633018805375023, 0.0197710037126296, 0.03197718220162055, 0.023632885497664253, 0.017392183879330274, 0.058449865619261424, 0.02791029911848807, 0.01573818568666015, 0.04756154605157433, 0.04535585634350296, 0.030021578065990925, 0.052840611972515626, 0.05385507709316669, 0.05996974958707729, 0.05623567999610978, 0.13289713330807226, 0.0329196063290921, 0.009636314521964279, 0.04540288265073492, 0.026122219259700468, 0.015823083550428912, 0.02488918925425218, 0.041499036484427994, 0.05443214814388945, 0.040896056340106075, 0.08421151793652004, 0.0215054095362223, 0.041346470074307536, 0.029979730513127103, 0.047757821608214616, 0.026181589158612396, 0.0354819942355877, 0.03151782630612293, 0.024039433037321416, 0.05859749076227027, 0.009116717302540859, 0.026759363095005675, 0.02205666916955623, 0.03494377150350521, 0.026876124470765074, 0.05654222241813137, 0.01694773988527877, 0.023382420711699995, 0.04895479568550664, 0.054887093288163026, 0.01830014171108844, 0.03170056125870155, 0.03907865446601664, 0.024897007181519465, 0.03534482236230566, 0.024022420139742956, 0.018080854788422585, 0.01987766038866774, 0.030887163574657137, 0.02884250554826952, 0.04478972502833894, 0.023485143526246952, 0.07546860844858232, 0.034767035019373706, 0.10064679288095045, 0.03019561600540915, 0.08353858630383208, 0.06386336464915546, 0.03828781807134229, 0.025676819570963422, 0.10353220942159815, 0.0318522141089723, 0.09855982381850482, 0.025397011702279412, 0.021020119649267966, 0.03791048912511718, 0.04369805356667888, 0.010805617503431297, 0.051843353186643897, 0.03760413822507666, 0.0290177519913883, 0.061024675641449234, 0.057889977920680284, 0.05148267516145303, 0.01898190633754336, 0.04363104002550245, 0.044270539581174814, 0.03260659046411034, 0.012502657388517214, 0.08257962808373474, 0.023661541016471964, 0.03272430370411566, 0.04274700903483937, 0.027014644658793847, 0.06183520432621722, 0.038615462385238185, 0.056708501802096446, 0.00839946652582336, 0.039215133029727206, 0.0733363252854155, 0.02818576709908103, 0.09999764827831138, 0.04939507407646987, 0.08614880874031976, 0.125470508430754, 0.0711321677531927, 0.016965541853419235, 0.012382445744268838, 0.03295473529085998, 0.08180461523513641, 0.015803208356843363, 0.00681502337101847, 0.021872497802119584, 0.02985102199618855, 0.02662187138001525, 0.06300141231247014, 0.05849814064980996, 0.05564082421422486, 0.014842867348042708, 0.008622114659256993, 0.03041814539521452, 0.03453892850947957, 0.01599949253197279, 0.05468707539201264, 0.0015336285427873656, 0.025917782951446793, 0.06526561198575843, 0.08529924787580968, 0.09331522419327691, 0.014795757728748986, 0.030683047108111844, 0.05204597195129722, 0.020794204150837277, 0.08205761577213004, 0.05123280409363009, 0.020313694652530457, 0.02526158459424492, 0.05152477552333186, 0.06497598478510495, 0.0569042525885086, 0.07426686930440127, 0.06498097967837127, 0.02508898498490453, 0.01705987025953589, 0.09108225409422191, 0.018384198793360305, 0.017330293551147465, 0.0664584415273801, 0.024291104411766417, 0.020026379122188496, 0.016562600672665625, 0.028366933486634688, 0.024010614724829796, 0.04322680224093699, 0.01128423955261467, 0.023431268392971927, 0.02977527696789513, 0.0177909575417758, 0.017523368775484063, 0.034343009183724085, 0.08347010570428065, 0.09577515550077924, 0.005770883355815445, 0.015330398999785465, 0.030551776027066574, 0.06285600499400208, 0.03974995050098627, 0.012868129208894267, 0.04621563682092294, 0.05275733821514634, 0.12059957585147313, 0.00849532998061829, 0.0250499279073049, 0.036970066402347825, 0.026533177550581676, 0.22303848587457212, 0.05095112505519102, 0.29190346238113224, 0.06541185817050357, 0.1544933663981576, 0.09562153188932328, 0.08966368142395251, 0.1025401562031719, 0.09447515791942997, 0.10026734187117509, 0.16123083390055165, 0.12880201030883098, 0.19456940222411387, 0.17636350656469024, 0.1289102738542903, 0.11623580113894517, 0.11969599812742203, 0.14308643977968924, 0.1361337015705724, 0.14391473404342128, 0.1886378898615799, 0.19751056698301148, 0.24128123036315366, 0.09185702945556372, 0.13876196537767688, 0.09836988763943796, 0.07544685155153275, 0.10825212308836561, 0.16322272379071484, 0.09204936348983357, 0.23676419210049415, 0.16158484313036167, 0.1614832139063266, 0.16131444473660764, 0.0784315530871672, 0.1074015892921917, 0.13228654591066222, 0.1633392304422394, 0.08283213832445684, 0.08428235808687826, 0.15122371845908705, 0.2741994462426632, 0.10573106562538494, 0.0999455696212188, 0.12224433598138633, 0.20067650193889297, 0.07404150921971568, 0.11217759591677498, 0.12886115229658543, 0.11116633687408702, 0.11269174050539733, 0.15989218718342244, 0.11025291492020893, 0.11767071446463948, 0.15622113981554586, 0.10110114430708271, 0.1400930584678727, 0.13817223089356578, 0.14183616896550502, 0.1469696168937991, 0.18860534644655644, 0.16538447069544948, 0.14634108771720242, 0.23264639289869418, 0.09857915987771365, 0.21185161035147407, 0.151598549958679, 0.1874205608281397, 0.19713568951814406, 0.16958915958962134, 0.11382696789599235, 0.24784456608035874, 0.1625399402673206, 0.3342245188691924, 0.08733007801516403, 0.10175896102502462, 0.24714964772424391, 0.13006383372891334, 0.14277785956378908, 0.17278812825679782, 0.16281458278817518, 0.2166951706092204, 0.11722149582759989, 0.16635187120447237, 0.12735409647106163, 0.19620506122948664, 0.15315236013022163, 0.11019826220769076, 0.2035961089836013, 0.14381673607614734, 0.18024030982727007, 0.15666897949432174, 0.11779007862412161, 0.13739636768737148, 0.13728767513267456, 0.14460248181656485, 0.11263072926310763, 0.15383618553319287, 0.1558678200648677, 0.11298731254834322, 0.24011611788263246, 0.24275403439758286, 0.19086362042975044, 0.2098381014600877, 0.25628872426046484, 0.20907976634560094, 0.19568421337152683, 0.11523519071840471, 0.08425291732794817, 0.197015980619096, 0.16680907247768295, 0.19553563827949186, 0.21221436830537938, 0.13094085118462964, 0.20701771812333217, 0.15848825445338605, 0.17994426280981113, 0.1253763715466184, 0.18845640363231783, 0.15208921395242214, 0.17861750577726673, 0.1574627844797027, 0.2643661867947348, 0.13608102536489888, 0.15786424519554262, 0.0676920805727282, 0.10682301670913735, 0.151448427369037, 0.23604898773614438, 0.2053922940526278, 0.16613620213202893, 0.1867757905875483, 0.1453116494080713, 0.12364243112143972, 0.21984216787161368, 0.16446639092699175, 0.1512986112145647, 0.07349024767116194, 0.13311966652831725, 0.11850666960761433, 0.12439207879886513, 0.14266090858126843, 0.11719485128959341, 0.19952330978647356, 0.11677218526000939, 0.2443446014677325, 0.09350673085258854, 0.15166238040453003, 0.19418718563693185, 0.10154534506821826, 0.17904688273706745, 0.11369464918971063, 0.15943532298889854, 0.10240362401330665, 0.19190807406219745, 0.11903474933557934, 0.2420677115479785, 0.14292522423690365, 0.14140780324176436, 0.09418977484587701, 0.1277786853813356, 0.15716828495985077, 0.19758596535651915, 0.10488452314729653, 0.14581650135017213, 0.24265471875907915, 0.17549543701592954, 0.10947809359359165, 0.14182613321369694, 0.1611747869080113, 0.16514952685083115, 0.1619237910715803, 0.12947307268698371, 0.14059198088943958, 0.11667856931566231, 0.08599444968445648], [0.05803640030564801, 0.06105057707416916, 0.03520994492235684, 0.039515171365271655, 0.047659927062810435, 0.08089598133078507, 0.03459227121164722, 0.04589687529650908, 0.08131002121034168, 0.049908498542443405, 0.061983147395714644, 0.03604438704168124, 0.05078087350533855, 0.023784885002720742, 0.053774480813092766, 0.024148048983225902, 0.039928184687009746, 0.04555393603720492, 0.052026268169884725, 0.016311913721203324, 0.08867582636735133, 0.008330282082991495, 0.03309425522362994, 0.07294458622533469, 0.035075745470221006, 0.02815758655478637, 0.029515645939916856, 0.03836364545408757, 0.02334978536612565, 0.029777640349141536, 0.04215597220125698, 0.07576526833638068, 0.0409313538412173, 0.040347499081925045, 0.053319010898591056, 0.012891808029023871, 0.022620722471225648, 0.06521744037707967, 0.017081590767409054, 0.04143879899094182, 0.023350009446843498, 0.028788052018611666, 0.04306334206053326, 0.05435889481656975, 0.11011505739823466, 0.02817511081605429, 0.0456013951841141, 0.12132593445600041, 0.016127728947228002, 0.09900665226122064, 0.056161040049647136, 0.020728690226772623, 0.09730597537371422, 0.034868193099335316, 0.008082592450532942, 0.02735700360649536, 0.053628560215715444, 0.07787820011858018, 0.031964645172739704, 0.027563234475711663, 0.00985020148237386, 0.036917600870853474, 0.04329782242195741, 0.04805238624554008, 0.03221764379451352, 0.05175493514886306, 0.05008266480158895, 0.015770417878464345, 0.03328271285300294, 0.02045760043866692, 0.1249676866216525, 0.11406067067817335, 0.005852783421775507, 0.022256817300653747, 0.035672547115433606, 0.028005782402150577, 0.04652551555585477, 0.02293484150281837, 0.07212129451574818, 0.08628419179829859, 0.08412427584370298, 0.04308599145001462, 0.050442714634681904, 0.04711210524903671, 0.04110671902796434, 0.06955175900891905, 0.03140999751556064, 0.044202384568991206, 0.03949383581658045, 0.0211671874633119, 0.03428995759496766, 0.05223527610782654, 0.053497302541208845, 0.057156640255162795, 0.04863286255708626, 0.024540199815566023, 0.02407345500203871, 0.10366608328636616, 0.09283363068055722, 0.033279127561517304, 0.029415897461735917, 0.023402616704603838, 0.0442329706293681, 0.10257790901608045, 0.042719150247472915, 0.03586907165064927, 0.06257785379045433, 0.07144090118667773, 0.013411894587108926, 0.06030696616958707, 0.013878788787781472, 0.11183664848607396, 0.044337974470709605, 0.01169625983288091, 0.007771926081453962, 0.0500561504985296, 0.013142837804832287, 0.007053267618175597, 0.01783591924205182, 0.042216420368922335, 0.03334390795639446, 0.05507242527880496, 0.01796279297841172, 0.03999360476530368, 0.010868579397098193, 0.051505611833905986, 0.03393292997873599, 0.03823105861703235, 0.03416676299586412, 0.02263629512350646, 0.01310590183317301, 0.03375135181892303, 0.046019625564616536, 0.07076055382288272, 0.04411289017767676, 0.06804818888345072, 0.015175975784058533, 0.02835707968070863, 0.006036798698797582, 0.03290837164968252, 0.05165795990896802, 0.05534415666554725, 0.016403752341566068, 0.035975833663777, 0.04641857734250446, 0.012560184845971245, 0.02358827045217397, 0.06706545895506298, 0.08406625234431798, 0.054382406054965915, 0.014415927505451105, 0.025695468066260222, 0.049511833537009456, 0.040478143886092215, 0.03660092310559365, 0.04416658528028958, 0.015404196249531403, 0.02351043017340764, 0.01018003010446386, 0.028580493902066545, 0.017581409511847362, 0.024999705098208883, 0.07397147346167796, 0.1223298084110983, 0.041777892488866084, 0.07068540825839005, 0.01884855341256386, 0.03783700980185982, 0.03627453517589358, 0.04765595106648342, 0.009822113826240023, 0.04628292232331249, 0.018588707879966786, 0.043261912050506765, 0.05942152940758294, 0.02726022946468044, 0.03497168391702637, 0.08865131921465359, 0.02288797224361089, 0.045190553721641345, 0.06875256076455116, 0.04505705907039585, 0.03428932557243013, 0.03236759784481218, 0.051312745368528756, 0.04544731191990357, 0.09869238767292231, 0.03868914472179548, 0.10041442309175769, 0.009171687941547603, 0.037741800394630244, 0.01153044680493974, 0.013539315118724781, 0.1004234093031095, 0.010558139502761826, 0.0716024921125462, 0.02768433573956211, 0.06922185856608615, 0.030801807973353617, 0.05975974190439429, 0.02318850853630612, 0.05308753743226971, 0.02022913578266819, 0.034021198629371585, 0.006818054206368904, 0.03490431797540477, 0.05401789759015364, 0.06283935407296785, 0.07016106703949553, 0.04783762115684729, 0.04410919763388173, 0.026879502918511152, 0.03869760999335878, 0.017594394702163917, 0.03205263037084332, 0.04769263135629797, 0.04630409699353961, 0.029976675737529036, 0.04849157679165083, 0.02665689500469354, 0.05066151317629603, 0.021784744345613068, 0.035091147667938666, 0.061799286293887326, 0.03913902985532919, 0.04867182195847554, 0.04204026611161329, 0.025830257406097748, 0.119243010337795, 0.06593429949134588, 0.04610209876010495, 0.06662714941006515, 0.038824776758349715, 0.024316258908760165, 0.023599892005985303, 0.08418139535933734, 0.07271268374977574, 0.03859087096286878, 0.031113958158980937, 0.030886502823822444, 0.046095146512192105, 0.04916124105934174, 0.009686427205921182, 0.01155337677412336, 0.055237490413410056, 0.07581473463365147, 0.034910952296829036, 0.0206359782661762, 0.005199487580196752, 0.06878413124791077, 0.022757126341363596, 0.043640596972357844, 0.05881548108112428, 0.0412575847228929, 0.06611737918349044, 0.03193583835156695, 0.0919909339638487, 0.03767640712941366, 0.043019472035549344, 0.02829671578271495, 0.04478338565076551, 0.028524228574467764, 0.0627521847585036, 0.05736471739627662, 0.096258518676604, 0.014179606617788875, 0.0400100565034776, 0.03069224016320321, 0.06108543790516354, 0.015014996770919572, 0.052907583378856225, 0.06816821187854775, 0.01793008485448457, 0.07293180021787844, 0.05827463449790113, 0.042030452525303255, 0.09438176414058094, 0.045019080261549646, 0.021773898455825065, 0.03979294718573651, 0.035873400047421455, 0.034878784264888496, 0.01512177506341569, 0.03292661603359926, 0.027978469452430165, 0.07126819432502793, 0.028821685193707387, 0.09084526479484574, 0.015231966277614478, 0.007400048808420018, 0.03725205570639622, 0.05876908296599023, 0.027032473440011664, 0.04201089047015675, 0.02737511200980554, 0.07188508662605478, 0.05996668140494055, 0.03329352235361453, 0.05224975900003507, 0.04665343691745112, 0.06592407221755674, 0.04150410798648673, 0.04258891530034523, 0.017508355367387977, 0.013531123723594413, 0.01945653994147095, 0.01655040455291108, 0.035860828544584014, 0.0379835126260596, 0.019028902001258348, 0.01130745584715999, 0.051512935634462104, 0.031156776728288784, 0.014891420085463795, 0.022279949325527397, 0.03202673851422245, 0.06171780901270048, 0.011510061205274636, 0.048292259865951155, 0.08964478203486051, 0.015935895742938643, 0.03942649668803619, 0.04303037729715148, 0.04626901399704718, 0.023340701478563493, 0.07464479579920731, 0.028456489164983074, 0.015044968045737236, 0.01776625695187719, 0.032463588661724524, 0.030496052706674225, 0.01837743998264834, 0.040743700604164795, 0.03947758326126684, 0.03869379104505624, 0.0256937999098051, 0.04657123951361545, 0.033588190412809776, 0.04127987788148946, 0.05614299867903033, 0.03348019116768434, 0.0597499359789635, 0.011000236394935319, 0.06811310717415425, 0.03250660066823325, 0.040658975110179, 0.015054361241298818, 0.06508662320312954, 0.03768461576152233, 0.02280766516172838, 0.012159121538242026, 0.037975062676254785, 0.18300346639608184, 0.1595974118719178, 0.08298257501014779, 0.12454528872284198, 0.1723201711091303, 0.23703025443659675, 0.19644728290938562, 0.11465324734848355, 0.17492646351456645, 0.1554109865138608, 0.288183584568962, 0.17265891986748866, 0.2081812064974539, 0.12375858537251912, 0.1694924333283017, 0.0836967145122828, 0.14470628673030486, 0.2091516866799324, 0.17332906294013226, 0.18342242456011235, 0.1600739645260957, 0.24488412654928624, 0.11563807635778382, 0.23921643954611596, 0.1854063624576215, 0.15193642537680366, 0.1147508699326746, 0.1811495489410816, 0.07298916488164857, 0.08230947483811649, 0.24181963695633799, 0.23955324244114662, 0.16106592581397103, 0.08252902797633603, 0.127561338576338, 0.12998497263798792, 0.13708623997386427, 0.09301369964715936, 0.1367817966327552, 0.11688457801938058, 0.12804802657375414, 0.12000473922178631, 0.14780128194439798, 0.10981167891934035, 0.2686108654785541, 0.1753008353614038, 0.11621848755185643, 0.22538400195058317, 0.07588867744010303, 0.1399120472131237, 0.11162562190645164, 0.0752363535725782, 0.3171822188361999, 0.10803581816294502, 0.09948644546731826, 0.20290364210884418, 0.1579684025097278, 0.1346736758827202, 0.08391316499440901, 0.1265747015995364, 0.14004891648167564, 0.20883990421650872, 0.1373926138565425, 0.21349990980759745, 0.13582182717659783, 0.14420122028358523, 0.1585647406717462, 0.17512216833570313, 0.13086842523226816, 0.18739953937549747, 0.26705016051569297, 0.17121942533600717, 0.21558590593837926, 0.1203546115768052, 0.11233390083596592, 0.1775507896297401, 0.19796643526323382, 0.10630277406063773, 0.23265854305317327, 0.1584863851988508, 0.1816843395992633, 0.0664404001567633, 0.11234102545366173, 0.1364365054835235, 0.15440997006672044, 0.19819859054780778, 0.09529079641065291, 0.12601427763940828, 0.1820347328940707, 0.11023505741069395, 0.08453570336343781, 0.16492270353821017, 0.16521715709278662, 0.1279427124668033, 0.12299426711134373, 0.12874895105919532, 0.15037962746235634, 0.1797657183581783, 0.2551530142344775, 0.09685582977028624, 0.13406129583956736, 0.13646200088964355, 0.13691195497109046, 0.17960896144711203, 0.13428445725191024, 0.1525124009217947, 0.1219004697556938, 0.15666778439715986, 0.14452368201267335, 0.21071675834396195, 0.14243515779174146, 0.20662307559001833, 0.16190151323474225, 0.12295691266415582, 0.1876977314391444, 0.13601273628732852, 0.11101907179240258, 0.1256339839329162, 0.059956178339498664, 0.09607412897410894, 0.15015617493660222, 0.0949398668542985, 0.09317954236100759, 0.10567818257597186, 0.12874519722836633, 0.15638791715666173, 0.11313848467844148, 0.055228787654590224, 0.1761113104200171, 0.14772870277445163, 0.10645455906107541, 0.13661235330566285, 0.1371701878886069, 0.2054328507473392, 0.12199039315624584, 0.1936259343018455, 0.191828171091695, 0.11564826532717674, 0.10982005226035273, 0.12753352192380737, 0.2782388746498093, 0.08861827784247937, 0.0864678000911109, 0.31410940952839395, 0.12461910895522564, 0.08203929860986049, 0.10601492418396859, 0.1561013083424299, 0.2592796387691652, 0.11109476894020073, 0.15068071533835706, 0.12971509518402238, 0.13970494300367373, 0.10751038909919801, 0.1775079040277389, 0.09705475216070492, 0.08998247359188334, 0.18211523341315408, 0.21699783662634514, 0.1157382423538835, 0.168490742723788, 0.09050539754811796, 0.21223805574399812, 0.18819257827295413, 0.1027735525501832, 0.11942934590361773, 0.08028125705858392, 0.15682786612981753, 0.12119710911065341, 0.14513927962510817, 0.0474835621313222, 0.19858214012797804, 0.21070437836310557, 0.14563539816487223, 0.13877405424512204, 0.125289527819522], [0.04268590586199876, 0.05773671437054873, 0.08018310587372511, 0.06179927097212884, 0.04242106543613538, 0.0506895519943247, 0.03372639650478959, 0.024545581583234093, 0.06775070162069413, 0.03284790049937945, 0.026352624033367442, 0.06353049561561597, 0.05888439452035293, 0.06976553584418951, 0.05931238869145032, 0.027306254111951398, 0.027528023159491922, 0.009892690633874266, 0.03661609164649441, 0.020126594914003246, 0.04575765796846921, 0.0032542397562910115, 0.0522256578739372, 0.09637274238611422, 0.027272000405637008, 0.055566486872492306, 0.04529148197522567, 0.02185227116569877, 0.01574168096281468, 0.02242628169516402, 0.04145312100468625, 0.03264186498258383, 0.03506961676682677, 0.028239703519389998, 0.03267712034885922, 0.07274544933029721, 0.06725784661548753, 0.020833613628882076, 0.03506444567333787, 0.08108700535470441, 0.027762311998935, 0.0851490563382545, 0.0506902146603792, 0.04751031392163808, 0.03379865774824735, 0.03534700188245024, 0.08442707975665409, 0.013657758057477975, 0.021331842740877502, 0.0808844976728001, 0.0481654110274488, 0.04539198121957241, 0.025474204636749723, 0.11105135473753176, 0.03501830419765846, 0.030026170763096986, 0.02550806763822273, 0.016007743298917288, 0.03753527075112347, 0.04442520124176818, 0.028968571061869303, 0.02167782719968067, 0.013771311440054449, 0.03130918992082438, 0.05181044971029605, 0.051550462451432986, 0.06523410278943277, 0.01263384707272053, 0.004630031443441347, 0.021604336385104447, 0.034608454819047646, 0.01248744575517072, 0.04715433967630229, 0.056855717088065805, 0.013227189830955, 0.02587476136883901, 0.08670068315921292, 0.025831289709575718, 0.02163119351250991, 0.04778858386881409, 0.021477460733524734, 0.04187522779008554, 0.025825860061412378, 0.02249462248366927, 0.031706688046875986, 0.014493022763711071, 0.011808268590680054, 0.03617926831206968, 0.035382636462248145, 0.06159224720191091, 0.028702592995438366, 0.03872779385757543, 0.01808442092771011, 0.0042659692248449696, 0.06031856474076068, 0.07975559816845963, 0.07792038091969106, 0.07639621835081808, 0.009474751366783054, 0.039424953020868764, 0.039706942324917165, 0.009323853113117718, 0.0216408921856313, 0.012778346576998311, 0.04723185628292061, 0.05020012140213963, 0.02976880352493496, 0.024579394788992022, 0.03679582353440985, 0.031518636444102854, 0.020721014025771332, 0.052034338906167016, 0.03720481106410584, 0.04230695280937418, 0.014222293036929784, 0.030458338198161898, 0.00234297864916434, 0.062286728887908885, 0.02545051336769135, 0.014386978958012357, 0.059558279932506626, 0.056399952229713245, 0.024229727362492876, 0.04312020493671299, 0.09188954988794942, 0.01602458095388307, 0.03370557423500765, 0.05602459979033279, 0.03686874744392211, 0.07481560276280488, 0.04622895525948656, 0.05796742174894579, 0.02563416762577911, 0.022023985943486615, 0.021026778868549777, 0.023950331266068166, 0.01924847812211562, 0.009306822978560964, 0.010782225966273297, 0.022208678250711773, 0.017374868377021725, 0.03616706070099627, 0.029780802377049, 0.0135035416854906, 0.024046831531450156, 0.07109315089520908, 0.04056991355854177, 0.06250895567298417, 0.020119918457743143, 0.03504270026760717, 0.031226603727367137, 0.011673552986805238, 0.0759529215734332, 0.011403510823935993, 0.05682796938344837, 0.003801792242278856, 0.06804237427610545, 0.02476720124362938, 0.057665901033267866, 0.031031785653002804, 0.029580569976279815, 0.0785552379825423, 0.024000860510333896, 0.04355032117136064, 0.03935869024585813, 0.00897886552622602, 0.04919119509718111, 0.06406538969566745, 0.018275029348930525, 0.04704530621247907, 0.02972144779989556, 0.03509050415408227, 0.029396178358564937, 0.01731325958615109, 0.024137402276298212, 0.04974531415369242, 0.007429391412334818, 0.02782606775121343, 0.01740386097451612, 0.04160329722048294, 0.046486326328088204, 0.04745198015664374, 0.03887113273864792, 0.021478437495628194, 0.05061775806450075, 0.03213924618678228, 0.04926114275510754, 0.02353047869438606, 0.07187438437775259, 0.007180506682714388, 0.055479172001322435, 0.10574772803773803, 0.012250618291868558, 0.009677444825008994, 0.04404611412375685, 0.043116481749400984, 0.03920214017853141, 0.10021533216199568, 0.07838051630965165, 0.04963791628758754, 0.020993254860983263, 0.07880242391219063, 0.02651415367220198, 0.011797151697288838, 0.04886661513498233, 0.03999596431611046, 0.056391915967387546, 0.01656843251698921, 0.06662157995085563, 0.03601404612944011, 0.05330923944711686, 0.007613694451133451, 0.0437915699195958, 0.04249954348309867, 0.05615114602410505, 0.0841368243639027, 0.0217015280448381, 0.05942049135844554, 0.0509558824612008, 0.1257685166332991, 0.06815392433875991, 0.07589859827872246, 0.042025461462476564, 0.11527003239720099, 0.007523974542686295, 0.0270023048975535, 0.08263276394216285, 0.03680651046095356, 0.021984191506259868, 0.0980988763753445, 0.02661834737556356, 0.06467160273102984, 0.008831138876567205, 0.027215918939140056, 0.04922271195438601, 0.06409627069989521, 0.024633982384036628, 0.0747710777326457, 0.04526823120672376, 0.09232486402916332, 0.10765161740803912, 0.07254244369124213, 0.07523129739227795, 0.06366844123770153, 0.029241277295495235, 0.049616190034054944, 0.03247232589450094, 0.03797167273718984, 0.03223885293869722, 0.0177872879806185, 0.041288615114265875, 0.04824231859416731, 0.038618967237491766, 0.0224580992418792, 0.034834060051869, 0.044597712750997276, 0.04559675269129296, 0.02843606717614157, 0.003118802114547561, 0.032877279971275604, 0.03097545520793046, 0.007855052845702778, 0.01711570083223764, 0.04450709604087376, 0.04767813314233096, 0.046255473392985524, 0.021109370807666453, 0.08693442424579013, 0.09697548504317961, 0.015148473227576864, 0.07948860120508941, 0.02571422955952585, 0.025916993880884785, 0.09159903402530378, 0.035045546284245874, 0.005745816480128035, 0.07360786515017671, 0.024040766030309663, 0.03776895438110636, 0.03947529648881286, 0.01662188630190588, 0.04318343400354347, 0.02635796366619968, 0.11611187875631357, 0.01460020229475753, 0.011010575709083389, 0.07625878983808142, 0.04172996985876272, 0.025486186251885472, 0.07050193786140412, 0.022556982040705702, 0.03319877642957914, 0.06417036672393162, 0.0935023028643862, 0.008516216410263892, 0.027283757940054904, 0.020742565994301153, 0.032907440852854526, 0.017743490733987382, 0.09366872780505689, 0.0930117384620732, 0.06809775477215167, 0.03138271712457701, 0.09689164438074636, 0.037186834810962605, 0.06519716969060321, 0.022464861883030787, 0.05159389580630007, 0.048764591375666286, 0.04538946845118077, 0.047113170111251455, 0.012763725788963419, 0.049429253089211644, 0.03268978378224758, 0.039456600113020796, 0.029929159134025538, 0.022184693953022364, 0.031506553322317145, 0.045767402606866056, 0.03174690000202147, 0.047852743732472586, 0.06725561729962788, 0.024027244578446114, 0.05771624833165158, 0.044802227583263195, 0.08064054463419222, 0.042206036047108715, 0.04733336293288777, 0.04310006448518365, 0.05399717108136224, 0.007462216364670426, 0.020553231194254853, 0.03771384201583363, 0.00979087371829777, 0.043937827595659805, 0.035737316018991896, 0.008924061511342805, 0.07813444886837276, 0.051421740527955756, 0.014629120198679308, 0.04721284581107959, 0.0651919756144766, 0.0983444075550764, 0.060683659262835025, 0.04502002254969651, 0.03962490962998521, 0.05471051002161638, 0.07165081693880981, 0.08368446476637356, 0.03082091612140498, 0.03135657628938075, 0.05533188776743989, 0.07373989274304721, 0.13091094311206572, 0.2169681430584, 0.19743136881339937, 0.14981566417601802, 0.14569401921283814, 0.09640510960091507, 0.09161742779636577, 0.1769112287870338, 0.10558454364898706, 0.11105929906930655, 0.17606295495023652, 0.11006069579912771, 0.11674703459345526, 0.14607425929317552, 0.18651000404309842, 0.11995865903314083, 0.1343272202798436, 0.1481809091543959, 0.19483623064814076, 0.10130348344964367, 0.2778036447782671, 0.18581580580963244, 0.33178511105718156, 0.15460495476520833, 0.19818441792120858, 0.20183403014896378, 0.07477429530192768, 0.12403144290851009, 0.13513720504218532, 0.1350798710219322, 0.15094607287356931, 0.20305422435124076, 0.11249017511163989, 0.1767446965940537, 0.12530167797400107, 0.15441560847384317, 0.1495882586365746, 0.22515507955704966, 0.24288109774070404, 0.11393772888808482, 0.23983395237836147, 0.14049278782500377, 0.22334980868524124, 0.15073636396517678, 0.19542622560214615, 0.21475810197091874, 0.14008545887566384, 0.13696646978778226, 0.17154698921067102, 0.2112524683076528, 0.12982521266225847, 0.10081934652501538, 0.24983910663473993, 0.11195818833526104, 0.12755191569486934, 0.10247670114040376, 0.10399401488323366, 0.09860922882874167, 0.10483357830033188, 0.0971641188727752, 0.2548322532205813, 0.2381119399421638, 0.15124795748101127, 0.14943073563758405, 0.20889163047315615, 0.20018599116273467, 0.1656435922749581, 0.08478942402308026, 0.1653082143034666, 0.14507828370457695, 0.12826429319477853, 0.13575888539273895, 0.1251091064524747, 0.12349257666257121, 0.13658849732770076, 0.13477348181749546, 0.10565929850863834, 0.13344603530581922, 0.1663940060403078, 0.1387407753856913, 0.10300308781405611, 0.103778590958926, 0.09566411871703402, 0.05269673299945651, 0.09804551069053913, 0.094145602216163, 0.20429767698289888, 0.24255410077110415, 0.1403391105873931, 0.07952588670436414, 0.15763189072810835, 0.135287128448967, 0.1305481238711265, 0.16244820889926728, 0.11686819905955946, 0.19623538298952967, 0.23297957985872225, 0.12114614128105103, 0.10947634691312429, 0.15455423974462096, 0.08304963068616006, 0.10477907880539856, 0.095999259201269, 0.2095281576076823, 0.172239609303013, 0.10771447492222633, 0.20556218171071625, 0.06101794938947405, 0.15972056816662514, 0.1396484210366203, 0.12491656557446527, 0.1735479036165822, 0.16227741725742817, 0.10375140249849328, 0.1180559954035186, 0.12339368237242584, 0.15466962790777608, 0.08023045010744564, 0.14939767128277212, 0.09368175129976966, 0.16062435273441578, 0.09786191771948531, 0.17132099327300826, 0.13090401767723023, 0.12456973458850577, 0.16858930759612592, 0.2072284995548187, 0.14682606733854742, 0.1793616682651543, 0.10972594601973411, 0.11778010415934748, 0.18640092844443937, 0.12132651668282286, 0.14070746098314563, 0.05627413377946904, 0.16602717249864535, 0.11005492715705788, 0.165840124471053, 0.13950444247213103, 0.09528091387642969, 0.11406170489687113, 0.11160893651146082, 0.14848326873635093, 0.10235786558158937, 0.20197705876442695, 0.16294896993185246, 0.18794507058637758, 0.11733996366421062, 0.15714418383375292, 0.12643937982859152, 0.1652640263519941, 0.15633260560852869, 0.15571708460488629, 0.12220935640676368, 0.06669128629108591, 0.2157864524351974, 0.11564322446863498, 0.21765538521351355, 0.08705034100961301, 0.10395335093621286, 0.1777635322463128, 0.10578037870507087, 0.08864552758994604, 0.12076206310021302, 0.15057000031154003, 0.1555029630300499, 0.19179513738040002, 0.13822967216612833, 0.1720510290995721, 0.12884877231572905, 0.15511063408226738, 0.17017751511546875, 0.10929819316633287, 0.1569060224198526, 0.11196207240103714], [0.06881865116977884, 0.12314650410365675, 0.033336833134413726, 0.021594291057197318, 0.034058622024472684, 0.06789549989926238, 0.0409244820325365, 0.021955729424653035, 0.03179179850004373, 0.009574110097732515, 0.03878679411906389, 0.014432196340133107, 0.013543064161504229, 0.06295337859961776, 0.018767018674782688, 0.024907387672893466, 0.03404781252386109, 0.01300071987638911, 0.040322739120212295, 0.035051326417634567, 0.03017370589077473, 0.0043093039458918, 0.07345511487895444, 0.029237473668951183, 0.01670385004892465, 0.04437468923448075, 0.055700896998807314, 0.0734796450142899, 0.11353944743713064, 0.01785104756333655, 0.025379464458373767, 0.065105568557497, 0.028347767881989002, 0.04561531117125865, 0.0015141761339750263, 0.0468244047595128, 0.09594620761251259, 0.005083353438925359, 0.04116737786980887, 0.05142493511460001, 0.021425837898747097, 0.014453869925120906, 0.007919069067875465, 0.0799700721437412, 0.030938533600419763, 0.04858598180655991, 0.026827020150038506, 0.08100420657184818, 0.04999459150337404, 0.04400233219888422, 0.046543196865147164, 0.02681818715627155, 0.037195468621869246, 0.019072817991517724, 0.02574001990949675, 0.08723207238701083, 0.029004278420020017, 0.039193923885543505, 0.10857175029213391, 0.028585318340769703, 0.020267957288231102, 0.06342068074210998, 0.039727067454688014, 0.04714195203456668, 0.043117454681064815, 0.03486990913628571, 0.03096846082518178, 0.0028603257247126635, 0.00970997962154328, 0.01472305598473477, 0.020234569261271148, 0.013301034961196204, 0.04073800091000815, 0.032182863402751186, 0.05131938352039264, 0.012839420063931857, 0.004148603118430343, 0.0334981367773106, 0.03840224862459206, 0.022843759394280856, 0.06499204964887711, 0.01702190102678874, 0.05483247504960145, 0.025911788313439297, 0.027658874807398648, 0.049768323604498184, 0.0396149389956507, 0.05583158393781032, 0.03094216677240066, 0.07649184910640602, 0.037595040930975834, 0.04484744975343347, 0.05542262322119167, 0.03281693905591965, 0.10652710758750478, 0.10883595103458052, 0.012152309101375361, 0.026357894718286493, 0.011572362348106841, 0.099410870893588, 0.026245473230618144, 0.03268393087050608, 0.06077376652448889, 0.06134729058812223, 0.06816513986597139, 0.04561859385801419, 0.024072577831365412, 0.03532174013314709, 0.06710614588472151, 0.05472063004309612, 0.0812535375476845, 0.013513804390846242, 0.05197251561067758, 0.012097434223359151, 0.08589690370905785, 0.01648908112979224, 0.06827349534198161, 0.05076593096037546, 0.041195726953446865, 0.06131140702974893, 0.06544854612119737, 0.06662104368930863, 0.035496404349443414, 0.060622115589437954, 0.13260133143874908, 0.04631418637150238, 0.06895545149041761, 0.020470510935410857, 0.02785332707477914, 0.01439246127472049, 0.05275404020663231, 0.029139908541354443, 0.03242411598142597, 0.0519442048314358, 0.05692715478700496, 0.018371343837990876, 0.0186716100846928, 0.04041062472688575, 0.07775910408987154, 0.03522520539380851, 0.025380333968167825, 0.05783593424806192, 0.02673864424709351, 0.0381309156035704, 0.0052227163236708415, 0.017345996438375404, 0.048917996652063825, 0.02533151309997324, 0.016414703568443656, 0.04763799013509866, 0.02348914825087113, 0.04723271047095618, 0.003089374522753661, 0.12158789822170812, 0.068880497447906, 0.06951691733012277, 0.06013718193336841, 0.055277583624927275, 0.016046817613495214, 0.12444270954978083, 0.07847142796362601, 0.08029162222819944, 0.05264392655883586, 0.09515806401689207, 0.03120133814762437, 0.03589632139811593, 0.0614740513265133, 0.04377157502477208, 0.04558979661294049, 0.014364455015428606, 0.02307941761588858, 0.011329400435751005, 0.045830773399962534, 0.02241194052922149, 0.030685655637494022, 0.04735776666371573, 0.009147148230113089, 0.08155852481121979, 0.05682529956703225, 0.031331720566677476, 0.0306925063787569, 0.03966588384261535, 0.008205581163506835, 0.041806712716577515, 0.016295578811437856, 0.015420549353885074, 0.04436842646569975, 0.032452503369460185, 0.010984401357540441, 0.022373525050258445, 0.0612169215756078, 0.05016734816073891, 0.053071602803444674, 0.013616104899424941, 0.043818486418815396, 0.028270450458230994, 0.04878242590254353, 0.0490342160206168, 0.06522761402471412, 0.04947789584196383, 0.052555190594566446, 0.023785536177456382, 0.08022830506125767, 0.11107405392272819, 0.008840028369318574, 0.04787414056819774, 0.018333403333540887, 0.03589976879377519, 0.02087189504245837, 0.033088157163752664, 0.04329947717187386, 0.014105535491610007, 0.09344021143812327, 0.02546788632659422, 0.011753995091684405, 0.012808874223170983, 0.018919686591553114, 0.08658426077736002, 0.02755871838739803, 0.019004638081476576, 0.021134527219880014, 0.08515886226368528, 0.038635847984903285, 0.10293280690788262, 0.041999759212616956, 0.01166335731414297, 0.06428184017779366, 0.03688293156184016, 0.050099189318115675, 0.014610763774403642, 0.02824514657409201, 0.022315131913449977, 0.011576323022675371, 0.08805900301423766, 0.06960186115916699, 0.041067096960520556, 0.012855169874045157, 0.03936224489382679, 0.02836874145413599, 0.05374372621337253, 0.055791866109376, 0.03916539094080368, 0.07214900391596941, 0.04512341760639702, 0.02906486448351174, 0.040673507798102596, 0.03209743693831467, 0.06488258334537668, 0.09103236644859276, 0.04333475169034735, 0.033851805097994306, 0.03607637887339919, 0.032818701058145494, 0.017746037976335616, 0.06764839823928571, 0.01425368253201727, 0.032474865475969936, 0.03925018155226304, 0.02267776346284776, 0.010438668090970287, 0.040339236823661674, 0.06749410813133563, 0.025640577866485523, 0.032829744215574, 0.057496557297605666, 0.01244473252295246, 0.07496413955044362, 0.045758818591674494, 0.05475817984270473, 0.023556916388652982, 0.029788982280860507, 0.05809660332517759, 0.04502481059922327, 0.038540190416238004, 0.012334382345509386, 0.03624681045391387, 0.03599475986594635, 0.055782481532303564, 0.06685298446926378, 0.045372557060252276, 0.11207359182017465, 0.047834598939986005, 0.02772339281716174, 0.028599695895888635, 0.05596111025360804, 0.0166044578016285, 0.017187023617988153, 0.04586771799011096, 0.06385609447475403, 0.012976761434167143, 0.018146920295792724, 0.009163026359953709, 0.06258078790720432, 0.05307378232358925, 0.010728366154756759, 0.015318257463795525, 0.03663145553981585, 0.04036637931881894, 0.04085413600888945, 0.012641252270118605, 0.022083717818942764, 0.013118187010648751, 0.021944469847385923, 0.004552535904240945, 0.02578996884215984, 0.013103345014725723, 0.014947685413062574, 0.033658965445694425, 0.02634138743873806, 0.07456220386009063, 0.0495850945252084, 0.02139832193572675, 0.02011676792115454, 0.06893628397055211, 0.07909251076559867, 0.03967115835797402, 0.03976239176887659, 0.021551181374478246, 0.05285184282148558, 0.020293969803700046, 0.016948703240843552, 0.026665321971860625, 0.02537733281872446, 0.027884909049457604, 0.04955418287746368, 0.030562233127233003, 0.040146753402246584, 0.08423040200385355, 0.06604207274053367, 0.05692811622734993, 0.08128578218841746, 0.058587891680579034, 0.03762935783954398, 0.07640952529806284, 0.044423856757461064, 0.02559502819372762, 0.02337877796362004, 0.06830416950246981, 0.04019568343797038, 0.07406816907948063, 0.058811125871274746, 0.053901593951929005, 0.06260712984048071, 0.02128622412020641, 0.033031210017901276, 0.04629553213054615, 0.013764670415360843, 0.04057587372259267, 0.025408790304115223, 0.05957848933194915, 0.06200991067734938, 0.01177207955474695, 0.17062290331288693, 0.18145006991201834, 0.11337606386551935, 0.0824064462475719, 0.10758583343798116, 0.2543730294752506, 0.10245445394708265, 0.09851718336463937, 0.09361677938291142, 0.0986060648856144, 0.24590323799319808, 0.08391690350347951, 0.062273881593418706, 0.1156540186474881, 0.11213579049874699, 0.10923243983979188, 0.1388916334197406, 0.13957810948692984, 0.16222403625086432, 0.1357216535196189, 0.16456935314401505, 0.11620321175864629, 0.13311880850984206, 0.13422674018769495, 0.13236551425389706, 0.1066995156748641, 0.249155480414629, 0.22837811870680702, 0.19318698124299127, 0.078835028614248, 0.1180793687460884, 0.14914860077683004, 0.08070720960536311, 0.10729623688084465, 0.1385914801710075, 0.11332360216446462, 0.21951524751080623, 0.141689800206692, 0.1935061641157635, 0.19632245654300337, 0.1253556258856289, 0.1711530514782475, 0.1309609073664873, 0.13637483540561893, 0.134506193740714, 0.14716080179618252, 0.13277190857596938, 0.19434136849257255, 0.09550138632015837, 0.09741326598750968, 0.1651574481999682, 0.085617519103952, 0.17374650425007268, 0.1311051770443878, 0.19585082217329935, 0.1606325498752056, 0.12719262811926105, 0.19700657305938585, 0.17327080961436997, 0.13389522329934184, 0.08331727116338669, 0.25280101705462704, 0.09119732816132808, 0.20859564474273115, 0.13348358893586745, 0.16281514969323913, 0.17436093740886258, 0.10197987013887014, 0.09370814302876111, 0.11486140875926903, 0.053194295614957816, 0.18559007034186395, 0.16077905652984498, 0.18556721027820341, 0.11652408768573116, 0.1580594290768908, 0.11868328351767794, 0.09710075574055796, 0.2145143174716542, 0.0835725239988777, 0.1241793668258094, 0.08307415316061628, 0.0958952934090649, 0.09816703521796773, 0.31977205567302247, 0.12582251051020238, 0.17157343456581717, 0.11103381132406574, 0.13852599497524, 0.13623413569744558, 0.21493356674909594, 0.1804739972876926, 0.1555696280012208, 0.1413662353109929, 0.20469331543051428, 0.1885357550195148, 0.12199387885630132, 0.15655673229165618, 0.11748796419030237, 0.10555578470830956, 0.11340504497169487, 0.15047310551087703, 0.17216419560774682, 0.19404965753276504, 0.2657932860236014, 0.15955765190864765, 0.13782140858952077, 0.1368296005192303, 0.15623803971515549, 0.11064972548234848, 0.2259072859681422, 0.12349739535561494, 0.1983801074205868, 0.17489310804634325, 0.15779093058118898, 0.06460115328551301, 0.11432871718199984, 0.15254535802429722, 0.16184396470987028, 0.24895668059827822, 0.126165495734782, 0.13135181139073066, 0.1273759759421791, 0.12792428039134512, 0.207165343266341, 0.0775638742432479, 0.26667336783101486, 0.17435053393485087, 0.0664722770752926, 0.12144829401926649, 0.12363555165187967, 0.10698653051569577, 0.13066970202470982, 0.24990905046222672, 0.13298728653500158, 0.1178045193814943, 0.057059262819107504, 0.1790969848873154, 0.24085617413924587, 0.20212408635885487, 0.1127177415295474, 0.2899873232649219, 0.14221038759475754, 0.12030429492193846, 0.12276172112192839, 0.12161082723328184, 0.10854896683726581, 0.15660092024312866, 0.10089368003630832, 0.0848164362832904, 0.1807234201940798, 0.17613864443715543, 0.08226477360773472, 0.23412904882382965, 0.11523510644873304, 0.14755043411447158, 0.22336738274222423, 0.13494811922071442, 0.15192844274063266, 0.19447992315455792, 0.1700614068296648, 0.145055347032124, 0.12324809502329558, 0.16902243838675562, 0.13754616852008528, 0.10521138222107004, 0.15810951590538025, 0.12989987559135885, 0.12762302397600106, 0.12653558515012264, 0.07594815650654417, 0.19133749177619336, 0.10944787142497879, 0.12868331264584296, 0.2200077041502922, 0.3111323305676061], [0.06666535421484901, 0.016784011574101546, 0.07464903226542859, 0.048400366363385995, 0.016601824374388785, 0.07631451507369358, 0.05122370296908964, 0.05559674734550138, 0.023138203372758244, 0.0196288637591586, 0.01788879271536585, 0.0857123224845817, 0.016329506930384426, 0.055861262183996944, 0.01886013474675917, 0.05691772424465707, 0.04015323833652562, 0.011828930939607804, 0.07590007682841632, 0.02335448531554111, 0.01775287914149944, 0.05859809214129083, 0.03517154476515228, 0.08195260043946967, 0.03722192163789465, 0.07030985663614928, 0.07003496896715895, 0.03008176576376202, 0.01996324198590892, 0.026345169997864196, 0.029693305559997118, 0.07826481405044756, 0.011679395364837782, 0.033508739434182644, 0.05205889968501945, 0.0482706293734091, 0.004884161960123288, 0.02722794843477107, 0.08289179359112056, 0.01601047248714754, 0.034943108837450707, 0.07235703509180777, 0.043982410082413305, 0.05284187218715107, 0.051735185402175116, 0.03224793108059995, 0.08709686552925457, 0.04155987535693473, 0.025059281840860367, 0.06118128316537027, 0.02861213524855914, 0.013700419578761345, 0.02439005041284667, 0.08264906629319153, 0.03616109287606613, 0.042051933630700075, 0.06702703964566031, 0.027853916962480837, 0.036953629985932386, 0.028012778700119065, 0.08315683703028387, 0.01767123906662868, 0.055549943203767466, 0.02906002663826991, 0.021550715976064245, 0.05346117383469978, 0.024751320240959048, 0.009990432919303497, 0.04405870094835278, 0.08210840740150983, 0.08498921975373261, 0.007829657509817832, 0.10085139198288803, 0.05768368959486966, 0.05304896107484257, 0.09979694856390839, 0.02631610079157737, 0.08805733294256272, 0.08567754975369862, 0.036657000741650986, 0.013249469583012886, 0.023598390473653714, 0.09927722685519727, 0.06503739439311527, 0.048546597226372654, 0.03312233234605482, 0.030346542987371647, 0.026284583934372472, 0.04924405899439608, 0.021085593353716597, 0.03665917260091632, 0.052611482735242576, 0.03817237245159284, 0.03738942293209895, 0.07576991849008106, 0.09102354111570506, 0.014626264605941552, 0.012143704018765881, 0.06616914374453407, 0.033708416421206734, 0.017024484658313375, 0.04163016392398746, 0.05768861554022278, 0.06335166771145118, 0.01843906409527746, 0.019406998950627544, 0.014294896147123749, 0.07672486240945517, 0.017385873230054014, 0.023760144193206104, 0.02119009732268751, 0.15962715140513836, 0.02469893897913637, 0.013982095744370693, 0.03023210860368225, 0.02935251326210076, 0.02293292628300767, 0.00675342990190632, 0.054407503095365344, 0.047106708159610156, 0.01844203077076424, 0.019982662314789432, 0.049045377921673565, 0.03332085637075286, 0.01807368612067113, 0.035921337999283307, 0.053497754533084176, 0.036582161612328024, 0.04523519366498917, 0.01565509387517288, 0.01513757658446388, 0.06837072722133129, 0.08361402298173598, 0.027847548856610255, 0.020986810146320253, 0.04298093398251841, 0.045373591278950055, 0.04504277536104764, 0.028217023486391674, 0.03915606382032556, 0.050562163063835715, 0.013929206949298181, 0.010257962313781102, 0.036525792862859466, 0.040073197470196796, 0.04469949136217756, 0.03646056047610698, 0.0325767666612181, 0.07170331694426076, 0.004984121591288356, 0.03766165610643164, 0.0023741088713699534, 0.07702676233865562, 0.045208120117745096, 0.04864096393688552, 0.021295851930194808, 0.031591315205479344, 0.03349539035210206, 0.06751945798075007, 0.03126492153011984, 0.03441172344009242, 0.017994137465833657, 0.021439407231105913, 0.0822571280502504, 0.04782935123770468, 0.08750617864631838, 0.03720173522108986, 0.007761813720853459, 0.05319893044689971, 0.020006514462311904, 0.04055821922637763, 0.07919363437160369, 0.043147297636155164, 0.08740657955528268, 0.039955078203591614, 0.009623937413937623, 0.08916362519225768, 0.019465665963868943, 0.025006429434964256, 0.10342987539667277, 0.016881385179717216, 0.018950450767372406, 0.0693996599124324, 0.028740343893127098, 0.029825764077325023, 0.03673395810408458, 0.027420738291355874, 0.04527393090088041, 0.006689085219536098, 0.10457988062332715, 0.03536059994310622, 0.012364610259781682, 0.047284528658154516, 0.007750416247759976, 0.028128360300475073, 0.021961630216889808, 0.039433008435392575, 0.0344244634822732, 0.02831717033029324, 0.04672302451405314, 0.1010592086541076, 0.05622386308987776, 0.00985571348498906, 0.028674067711577784, 0.01898687250251251, 0.07957428047854094, 0.009991509272837111, 0.029485523362734148, 0.01583515996894529, 0.014282905913498855, 0.02049090994161464, 0.10460802669366522, 0.07577145832680887, 0.028119929502868367, 0.06717316325633757, 0.04201808403576574, 0.049798151237830046, 0.017551696791704145, 0.01924613389306732, 0.04697957586857581, 0.07284376139362013, 0.05969007386856022, 0.04255759762600065, 0.04555243833531295, 0.013338027431839898, 0.08859630644081101, 0.023409678120045893, 0.03184846027814333, 0.04160156203133445, 0.03133889114964874, 0.040009367024345745, 0.01401701786239902, 0.02029876359888623, 0.014641343131511202, 0.06687646506414299, 0.046593532672212015, 0.008789840991789056, 0.07118584753404703, 0.01473220882021011, 0.05098862122864493, 0.03216472244070422, 0.032716003141456076, 0.102828067366875, 0.02981807255456525, 0.025067670503631238, 0.022826037865372437, 0.05035561809857046, 0.013769657647747909, 0.06344159111200322, 0.09402778555428791, 0.03591452747763645, 0.020637012484873977, 0.026949465898196065, 0.08546600989516705, 0.05389515881336505, 0.03241866909628434, 0.054729486019500805, 0.04755765049447937, 0.021643370480066346, 0.07297243352138227, 0.053187458280233614, 0.019590676191353032, 0.00930425754162453, 0.015341001656657506, 0.036841896062176076, 0.029156649477719784, 0.06823309952573431, 0.026384995078607917, 0.029743694993216666, 0.06284413829205499, 0.030848916635037433, 0.055702643679274674, 0.027688478360012658, 0.02449515193039852, 0.02310317974807995, 0.0075955956239223245, 0.02218081180246607, 0.009499107217115742, 0.06064936150646499, 0.0341402716754425, 0.033415897238639095, 0.031419347618676485, 0.026401374038429033, 0.020250900340596997, 0.03857451881612501, 0.06170048393429287, 0.05060706730751742, 0.05564036456147029, 0.0439840380192524, 0.043896914670063604, 0.09955484945807727, 0.039198466786934484, 0.016786476461997917, 0.0051420668962471675, 0.04585699275917104, 0.04117351423408236, 0.02716990578318796, 0.011884700225275612, 0.02625966883985506, 0.04692864634336964, 0.032788153302164814, 0.08133678832241605, 0.026079285777203982, 0.040516341029996836, 0.02297335274277195, 0.04066683134184249, 0.035831031554769126, 0.012353277904161764, 0.023775787708619912, 0.02429595949398654, 0.01952364732841811, 0.023068399356317618, 0.008437015367822062, 0.09703971385475128, 0.054020931298333796, 0.030122121360393304, 0.026124195766545115, 0.07020296438807441, 0.050654691163330316, 0.012032786936258838, 0.031141866742062475, 0.02962325064976129, 0.04997201106180588, 0.05692792087492924, 0.049682418335108995, 0.027065842314773512, 0.06378626939089549, 0.04044774168681714, 0.026080440654749834, 0.04885141212012499, 0.04063413853967383, 0.03273976335842763, 0.03747879857978514, 0.025488166589169733, 0.05001605345657276, 0.03184753714219457, 0.017260458891189868, 0.028511810289215178, 0.005591235258766721, 0.12329610575351024, 0.07980779173874086, 0.05767122534434161, 0.028208121544711535, 0.067853587228925, 0.05612165546945988, 0.04632503417651019, 0.04757836551195191, 0.030934743380414385, 0.03526879196626044, 0.08265367048161645, 0.04315303946514765, 0.011727188717603925, 0.19529367706948714, 0.11915202973590744, 0.22319775555403004, 0.17154227010905745, 0.06560056860889159, 0.1724313457887019, 0.1311933231209555, 0.1524919463742164, 0.11140478174051932, 0.11473922539622554, 0.21535497639448414, 0.1380999121935137, 0.12524699461796593, 0.17325626926556711, 0.12148699678120115, 0.1429920271039009, 0.18035154579387558, 0.11202489927170739, 0.2816766788882594, 0.11650595438456345, 0.08798071648925544, 0.16728731052529427, 0.13856696535743054, 0.13436324173404326, 0.16878547207001718, 0.18548548401844117, 0.14825532693536053, 0.16209475125276274, 0.11309633452084758, 0.14097756826348845, 0.057769250124692924, 0.2097044650825762, 0.1582384025377612, 0.1430124969732377, 0.12328816142173545, 0.17344999757985916, 0.13727423795048269, 0.08772154128359211, 0.17332094240813486, 0.25973135485283794, 0.15775731464307155, 0.273023133556689, 0.10957504202040935, 0.19763007669919924, 0.14742309497969766, 0.1735333173025039, 0.2218687155794713, 0.21506803050156564, 0.15870663547708144, 0.15775337695114075, 0.12029453496178312, 0.1542189996689558, 0.18821096438313686, 0.15843222278260416, 0.16783218290055954, 0.08289334874960684, 0.23100526402554206, 0.09874610575817286, 0.17907918100395512, 0.15626692122990088, 0.1459839834921783, 0.16299539486006384, 0.08881031310245877, 0.06344663963142423, 0.11742153670638801, 0.12146658819889831, 0.18551874755611344, 0.1425645653639109, 0.14672733392686615, 0.18332709257881488, 0.20425863714227754, 0.12299727783688616, 0.13941545369884661, 0.1760238078573058, 0.18364849710656753, 0.1952334165933632, 0.11548339554499235, 0.22031109029006576, 0.10104908097174861, 0.10714319549621114, 0.14299887592994398, 0.16311035401398138, 0.1491905977168391, 0.17682734215932508, 0.2128085614212098, 0.25499015926353397, 0.07799089165224184, 0.09879768645811467, 0.16774389892816546, 0.08127683428146186, 0.12207885332886251, 0.14912802365518388, 0.14475248183213896, 0.09613062029764538, 0.1155254461111561, 0.15653155864246432, 0.1424273130513968, 0.1244878244676417, 0.12340363385456225, 0.14761766599070641, 0.11198019038044638, 0.12444520699641398, 0.28367754732889516, 0.24058441210898662, 0.1673507579271832, 0.08481286631356325, 0.11967491538774584, 0.19049928433472113, 0.11795071960096398, 0.13948699098921594, 0.17950750076242034, 0.21384261157964507, 0.16186668687770445, 0.1829526134796681, 0.21246458794320786, 0.19567180274715348, 0.12018605691170502, 0.08796875019587817, 0.10334607303863573, 0.18178279721929183, 0.11752268329503075, 0.15404724275633214, 0.23213870643127352, 0.10949604303365755, 0.1434805307296976, 0.1919989627335341, 0.15577288644929088, 0.11988340621633876, 0.12402323044596181, 0.20459905597231082, 0.051964797274840456, 0.16919975709770957, 0.18911269583529045, 0.07900584323872482, 0.06943531364442841, 0.11590085217669127, 0.11735609747589597, 0.19053363571724585, 0.11061028727600652, 0.10150828173444157, 0.1189831456529998, 0.07323782936099076, 0.1333165970901328, 0.11621802789910186, 0.233008599269294, 0.10577015909216098, 0.17471680057144937, 0.13252712816240328, 0.14632568934992438, 0.08906633202587405, 0.0998574618490473, 0.11576439659561842, 0.23227163800789466, 0.11589177403478854, 0.17137448153188153, 0.21258152360397004, 0.1833719240441438, 0.09339231562109725, 0.13762473849759949, 0.17646561076323833, 0.12340521199568627, 0.20008727307281188, 0.13317649493054037, 0.2089073352756039, 0.24674644032793663, 0.12651631037794775, 0.11808594178047874, 0.19386406507222884, 0.1769299672976617, 0.11992859774299207, 0.06674358711367653, 0.11487800222370895, 0.10664191352383745, 0.24656953530446177, 0.14036011671827686, 0.09145342369353579], [0.008156196263078, 0.06242895311105156, 0.04923888790090719, 0.02993096710152684, 0.044760475791389906, 0.03137438208796084, 0.030912339139068802, 0.020569439699512818, 0.0035229194796674197, 0.037266515615967014, 0.07566284238090439, 0.054655083560294686, 0.04288773555609007, 0.0018449082610107238, 0.050022155346889655, 0.06793362043437458, 0.03509095614595759, 0.027834596225030483, 0.02070432096990126, 0.03359326574530813, 0.06570959824227518, 0.12020202218404702, 0.08721943959713944, 0.014303564431986982, 0.007070110539995855, 0.05366211103635931, 0.009202448286927276, 0.02980267035684759, 0.07513852414464758, 0.02522123857371269, 0.011435884742006179, 0.02745347322836038, 0.00968753133014205, 0.05860577983361098, 0.02524006326923207, 0.02207164044281648, 0.00939220826577155, 0.025953074706898584, 0.03249556134124437, 0.028273005361458468, 0.061020937132378744, 0.10281036307494487, 0.0363496539273089, 0.026653876618271875, 0.14418671057829935, 0.04043258080679563, 0.014689183407162708, 0.0022065719061966746, 0.03875280662830319, 0.03314542606653225, 0.06558890875068403, 0.04070857164239691, 0.021613048720023325, 0.017913964449337894, 0.007777338971443956, 0.06470051488929218, 0.03874177496219355, 0.08148341755112333, 0.01889925119617293, 0.05267027998343111, 0.037460067730036475, 0.06067477264291337, 0.028028155999979185, 0.040564845886922656, 0.022932227227776762, 0.05998937675969736, 0.016577983718185176, 0.09670988235983158, 0.03767691274744369, 0.03312841125373398, 0.06706358970052774, 0.0282406707053944, 0.015369701225520864, 0.03608631120333749, 0.04094651855167843, 0.04931101890941782, 0.059826395384246306, 0.07796630789075168, 0.04046781319043329, 0.054301668048625996, 0.06098844351307039, 0.010347528525838449, 0.05036379225672253, 0.04097112529580632, 0.06723490994303458, 0.03001331772294737, 0.010528785886333115, 0.04027366352778289, 0.02910578698520699, 0.03407432299648081, 0.04489438413011451, 0.022506196156985337, 0.01986468860488986, 0.011036323924218456, 0.03486810499922403, 0.04366150351181146, 0.07947994441154503, 0.06264677489056222, 0.0321618725936259, 0.032885350707557895, 0.02534242793767443, 0.012623529783600282, 0.08119324642804363, 0.022123133042646993, 0.006318867963273079, 0.08091927806456244, 0.03796260608660598, 0.032853684463207765, 0.024311016952138276, 0.060507895710367354, 0.07543401191792182, 0.04416364350266034, 0.06278409232054988, 0.06291387144536262, 0.02583062321308159, 0.019709885218030503, 0.03947941804184549, 0.02626911661918125, 0.028222543149886113, 0.01578754760445126, 0.031056095538060033, 0.018827252337829243, 0.07152158556686294, 0.028870649703387773, 0.026317784269790978, 0.012099402111714647, 0.060502839530067104, 0.04157052397908222, 0.015065272248560383, 0.07079429233506804, 0.03493134555737338, 0.05174735087841269, 0.04985200721890696, 0.012696483379019605, 0.02565468729083096, 0.009293426973595014, 0.028636661553454977, 0.14990102169254135, 0.09169304067449224, 0.08661462084179924, 0.020891744380576477, 0.022639807636639284, 0.01193354503371783, 0.019811137143762845, 0.05344253108506242, 0.0031050613700156853, 0.016580582671468298, 0.014348525174653098, 0.04002381161215805, 0.03248838309739386, 0.01943388863676979, 0.008065590086663443, 0.06818872771315998, 0.016253087744717638, 0.050995194263035254, 0.01790671151191477, 0.059194250272647034, 0.03206257419210048, 0.057265313657661604, 0.022765942098152255, 0.04935115425577087, 0.021118663454187975, 0.004127679820803385, 0.018247990275643045, 0.020525983362008008, 0.06804604383726275, 0.034217286494470416, 0.04459768593791993, 0.02790435236097584, 0.04127591720692093, 0.03119000196156483, 0.027016655639595082, 0.04730507896672334, 0.08011893834918737, 0.01854503895306299, 0.013310702990800624, 0.07344016084267248, 0.10078805949418776, 0.025449599807841644, 0.03178589387736734, 0.04614000479059835, 0.03733000898313138, 0.07058230814554038, 0.01670879514647588, 0.04370241643740766, 0.006073387058061218, 0.11150384457000803, 0.0858067274994908, 0.06288802746923701, 0.07677386139309214, 0.07273189723491669, 0.027680283134442665, 0.08162031746319226, 0.07203155497629797, 0.05867027677595616, 0.04940380364836705, 0.014060949174416883, 0.0789730699973241, 0.05867227626543853, 0.07289369500452474, 0.02076905539950296, 0.099235727872339, 0.026410706904566577, 0.0367758056569484, 0.04770542502463345, 0.04550145901439171, 0.023406180928671555, 0.03478262873907243, 0.027775199513041207, 0.02799563365237367, 0.01075627378022839, 0.04316086888373379, 0.03274466632114303, 0.017732700385573893, 0.03333758773101914, 0.01572047086102107, 0.07211947888736764, 0.0702530741992016, 0.02711581614529414, 0.030425034440873615, 0.1287805904904681, 0.04133661435316167, 0.05360686843613944, 0.0390357650335758, 0.09202199116829904, 0.02423892424802386, 0.0373144957026647, 0.035135507989194126, 0.08746949835650383, 0.0455786653554007, 0.028805583940758824, 0.03502160220617249, 0.08712503458223037, 0.013907977695306464, 0.027678593910569628, 0.04977450593404713, 0.026754552062841195, 0.007659972865029329, 0.06760332162582106, 0.042740788400894215, 0.020357373155533307, 0.057116765378704, 0.07347212969175271, 0.0325541977109688, 0.01130760427669532, 0.030957932861882354, 0.07909202046932713, 0.04093685052207401, 0.016908177189649116, 0.010408208435100895, 0.04293315690912066, 0.006113819742289883, 0.03139534608400878, 0.028160986069950367, 0.029476906788805803, 0.1639636993528374, 0.05198468491735478, 0.0751083326195517, 0.02560459471668207, 0.018259200057195082, 0.05552477721545485, 0.05374864449784641, 0.011943320315631648, 0.017271536522574963, 0.012372048973526445, 0.041404581673803835, 0.004053642210971204, 0.07278061276602169, 0.007651165247924867, 0.017952579111161254, 0.06799022667109966, 0.017932381203037598, 0.03376775376138187, 0.009764845881070341, 0.0415680495150868, 0.008544898742148954, 0.04014823578238007, 0.014571218315752284, 0.07784471441540988, 0.03913590421659812, 0.022462460197388165, 0.08628066013296766, 0.019849050835135485, 0.07555554410622967, 0.03387635438552788, 0.07308942280829915, 0.08486541994516889, 0.05569159286096693, 0.04625192257545648, 0.05224075746692477, 0.03294519366576307, 0.04318422307410548, 0.05641377628630689, 0.06465936830687909, 0.03580657036734685, 0.014793208571180943, 0.05585267433836576, 0.04856218711563176, 0.06684191449875794, 0.03758009838601274, 0.014579089869174265, 0.02256692394674305, 0.02888523027180664, 0.05024099219289999, 0.00827949236883151, 0.03308901518222786, 0.04898848823241649, 0.035539780247716174, 0.03862285896414711, 0.04286536195826146, 0.05131270706413254, 0.019767389692846807, 0.03523199293281763, 0.02297305205326167, 0.13189119857645806, 0.05585357832211641, 0.031795864511701855, 0.027209569985467582, 0.057465634158542084, 0.01304044632331258, 0.023376094740665248, 0.025077217874387582, 0.02197207774095718, 0.030527062030629288, 0.02369485051941968, 0.0435530714270088, 0.04339435716129599, 0.049868298078616785, 0.03320695058773122, 0.06883776506348964, 0.07566254360661392, 0.047729629572601094, 0.02876654410013749, 0.02326910673159986, 0.04496178454569271, 0.033786817859377594, 0.028258710160791397, 0.07199106722949974, 0.019955764967767943, 0.03231918491843728, 0.02739153118924268, 0.0552032424527551, 0.023624701763413126, 0.03409471625702516, 0.02645173665857123, 0.03491536496327289, 0.004676940443459898, 0.04333244576569527, 0.028562400820514852, 0.08544562429550194, 0.0823767526796268, 0.02359302402774413, 0.11233349480936605, 0.1843522867608455, 0.09967226009335249, 0.13031777655405383, 0.13557491703860222, 0.12020952984570496, 0.15715611948361322, 0.07570576628730183, 0.12299710929754282, 0.09213012447881122, 0.16551544108698446, 0.12560783735206052, 0.21754925139248374, 0.17355769422025452, 0.15413646135599385, 0.14347761959558533, 0.18731015223649242, 0.17121283697985834, 0.10797386463250845, 0.11627115609665072, 0.17293373092768655, 0.27354606517380287, 0.17943240882408235, 0.18541633692239562, 0.1360176392500439, 0.3125009619660916, 0.11855366144088969, 0.20558407650359217, 0.23624251686757614, 0.1572738825193336, 0.09743722155690195, 0.2343678843951033, 0.2514964765718868, 0.11146793036811775, 0.05897505336531228, 0.13887844138568448, 0.10745374455807671, 0.15914612479748266, 0.08160406873831827, 0.17704036056755051, 0.148297400484162, 0.15780499595547878, 0.17201048772661917, 0.11369448831124652, 0.29282068413111473, 0.18978138334087788, 0.18521635733064146, 0.10049822544979473, 0.15874207470445864, 0.10536666824332169, 0.10893921202589428, 0.11779011692851783, 0.19152403418575564, 0.11836625335197296, 0.0976202323011333, 0.15768766192899597, 0.15420380048453808, 0.11762880945518134, 0.1862204381294789, 0.17591108568012717, 0.15267919358466903, 0.14325096482230773, 0.25318663507219286, 0.1220374539374344, 0.14846161909161076, 0.19136154693701576, 0.2151499406224297, 0.14496445836078736, 0.12928397154375432, 0.10110490579879093, 0.1724046093201445, 0.15379619574354542, 0.11721068632698829, 0.24692593472859553, 0.10822514147167245, 0.10720795290845056, 0.21009573682902322, 0.1189660159270129, 0.12265675175454348, 0.3074043015799215, 0.1342921947399455, 0.1774712697031998, 0.12139266071420525, 0.12074173878758185, 0.1096418985135613, 0.18192440091121584, 0.24194156751036647, 0.10472788881029814, 0.09026401856493566, 0.11763606430782426, 0.14848582747001804, 0.19453897321176147, 0.1456649998022664, 0.05874547979704315, 0.08006964059125993, 0.15123297280121237, 0.20231648168015867, 0.10520002113715296, 0.14054141908643708, 0.07696733689836918, 0.13403115794062614, 0.11283860722136115, 0.20088455609736905, 0.15111050598563688, 0.12823394079121853, 0.2953348008375014, 0.12786565934337918, 0.11648035172613398, 0.07257681039552535, 0.14036318106997397, 0.23770677136077037, 0.2234981539508989, 0.13423997818702652, 0.19592989776884356, 0.09069216978405753, 0.10939383924367929, 0.2601405683784716, 0.10545561871220989, 0.15402507217180345, 0.14250965218149847, 0.07847476044609662, 0.15497183427214622, 0.1377714443350992, 0.18218968183763568, 0.10936133413305206, 0.08478196998757702, 0.15228200763944658, 0.1700854773122457, 0.10849363230649503, 0.10357830493200211, 0.14998705336643806, 0.24717774782930654, 0.2647080765135827, 0.12538865959692386, 0.10798567770830086, 0.13300315987679268, 0.10658817245594918, 0.1875482217198418, 0.22289919576817946, 0.11912990511665422, 0.14042603092328196, 0.1694466519139467, 0.13208170932146812, 0.1846966126392926, 0.11586231029322071, 0.1349322765224403, 0.07585420348351041, 0.17520225516730742, 0.09059921267532534, 0.12204043401945984, 0.09558154976055508, 0.14232549996625993, 0.1731157227749786, 0.1395439879307824, 0.24882793186172364, 0.18539658717570767, 0.1493332432883401, 0.11373495307540703, 0.16329396996767293, 0.07077297976901455, 0.1304653863753042, 0.15132458159519782, 0.09276864344194051, 0.13855823195509373, 0.14520968310534954, 0.20917034858176786, 0.14730012254609218, 0.10051956099848594, 0.11664522916919763, 0.10556410442316726, 0.09196069647347735, 0.13967072951697534, 0.19196071962435401, 0.21206822937294362, 0.28177639289248374, 0.27370219389277123], [0.05323782090037581, 0.039814692591467214, 0.01624760063995998, 0.05905184218840254, 0.01950505245927601, 0.054019234413581516, 0.025932231369698723, 0.006353523386942764, 0.046505761978727196, 0.024446309994786017, 0.02605792341543542, 0.06859390395543269, 0.04178382200940002, 0.05716111037820097, 0.01673357426038673, 0.06361778750414811, 0.03584630734797928, 0.03864727035585431, 0.03195480477335232, 0.03501095741446461, 0.036987448937349746, 0.027299501046898867, 0.059766192364716725, 0.0544834338999804, 0.009792673067309925, 0.05606912865093159, 0.11149730984001391, 0.03476352250624088, 0.01930988198446651, 0.04265924217179418, 0.04543755195974823, 0.039722095544059435, 0.045475745273213235, 0.023380890451071244, 0.029870861758207603, 0.10364845560322847, 0.032205558757507996, 0.0623789199087168, 0.05048267378081238, 0.021579392562289874, 0.058796267595983324, 0.020173109857545748, 0.06133450075022637, 0.061249648851733056, 0.03315327463731651, 0.04684193285122033, 0.05428978985536003, 0.07951765125917812, 0.021157360470463193, 0.07191845741603645, 0.041229971083662206, 0.00854789031549327, 0.04020238670730784, 0.03769578532345834, 0.055883616629627444, 0.029891074988089746, 0.03709755875470658, 0.06790390388379175, 0.11028866824363509, 0.07029306398884905, 0.013900140615841074, 0.046510779854631236, 0.044657904279207995, 0.07885852453088568, 0.04064314007278412, 0.042956928617411086, 0.04643853776337159, 0.03888978697960416, 0.020142734471348026, 0.006645368412137032, 0.02285832655616105, 0.030459826323954813, 0.02109610791047735, 0.04226073089446272, 0.048606999428762544, 0.02147906377250629, 0.04237788105984369, 0.046185081404063015, 0.029160606321848692, 0.023760958161625653, 0.00995495730274988, 0.05591616004465088, 0.054922754681038286, 0.031135713140810692, 0.018919104364730658, 0.054214904760761615, 0.03511383536181623, 0.02409918214975586, 0.011444653575909475, 0.04140350532027022, 0.022141572778984424, 0.04471631848343438, 0.08406903324348312, 0.0339503469876945, 0.03538892604410648, 0.05157841699978998, 0.039484516356981574, 0.0528135652383489, 0.039393865172901464, 0.03433012741527731, 0.014793042904667318, 0.07753119293239809, 0.047362719422146204, 0.016505349006864335, 0.03138641158359186, 0.09675774753334061, 0.046499966523580016, 0.06494052257509002, 0.05347862914805451, 0.0424269566522731, 0.015818848999427454, 0.019510325059414874, 0.07131761465702327, 0.016032941845966684, 0.048289107414142746, 0.0312710176747773, 0.017111096643812714, 0.03962626177517157, 0.025972874249301614, 0.03415950048234194, 0.02907054311025047, 0.034139218304546616, 0.04783051186090997, 0.03434781255500932, 0.04846105967918712, 0.012863246355986884, 0.031964869253457553, 0.024399955929707617, 0.04753518113566022, 0.07015434078752034, 0.055771288987729824, 0.0642674760292134, 0.024056041823519815, 0.07469740305696765, 0.03240069667358072, 0.06627250432727799, 0.015274507140049772, 0.018050017834250486, 0.07915414253910703, 0.01046828696534278, 0.037656251356125846, 0.02932585723277542, 0.05489666172633729, 0.02227834245610622, 0.028175449809960784, 0.04930580185065347, 0.030868509333700906, 0.03717995534140257, 0.024984842992477843, 0.030146846848149455, 0.024325691366327867, 0.03728096403421895, 0.042991199560703776, 0.04426069152090819, 0.04107145217037009, 0.031187881813234383, 0.024820798670031854, 0.01591331242854076, 0.08482955170855408, 0.05711480802405746, 0.05398686336834104, 0.02633832500226075, 0.029790114175768632, 0.07245471896303278, 0.021301823585564574, 0.031331624805686936, 0.03704425435693514, 0.01166551576686963, 0.01884438014859634, 0.014255622649685511, 0.0536921416829911, 0.027473736253957597, 0.05265951644809497, 0.09167154424733694, 0.04322029049358061, 0.029577974853436315, 0.0171350579588644, 0.052460295283385826, 0.053580028545712276, 0.017154300172302513, 0.0293756433717546, 0.016703771524912408, 0.04320503768300818, 0.04234123524398573, 0.008649982065112602, 0.034588356502354145, 0.04758050289726065, 0.03467385574514347, 0.02128966002454681, 0.11012394401815631, 0.020110531965450897, 0.016254254113582355, 0.002205715563538815, 0.02430125124632351, 0.05269380271314614, 0.030834320744860078, 0.023324211435993353, 0.07541216309032134, 0.06740648299455643, 0.04920181690625126, 0.11793788762823229, 0.035255082822855444, 0.05751292859654754, 0.04373230535777346, 0.0075067887965199215, 0.023704068472368583, 0.010539334917050457, 0.032161964524176814, 0.03608255737250851, 0.04291403535453062, 0.04289031344195528, 0.04417289784478565, 0.05597804845761388, 0.09217571437118516, 0.01835659664544848, 0.015564532706423875, 0.03839730352704083, 0.04253610885972458, 0.014960003149275099, 0.03813982903656941, 0.04944020814652886, 0.08034870343943758, 0.03775955448227544, 0.012400097367654165, 0.00983319720328455, 0.07233494111607153, 0.07838237790330764, 0.0291605182217374, 0.014698377419863979, 0.015787846378741727, 0.034303321998806736, 0.04411761310972995, 0.04219608073453269, 0.037368037587692665, 0.11470336482048997, 0.04135190163769069, 0.05138160901204233, 0.039343353165614034, 0.08031961508095264, 0.05258757313112578, 0.04018052638838849, 0.044049316371280345, 0.0410191934826153, 0.029797206234727657, 0.01436021950681724, 0.023195506749494423, 0.05594764242789919, 0.031098801109399048, 0.04414105923065255, 0.07226841404072701, 0.008389873189791557, 0.012606553275198227, 0.026938602771429766, 0.044735072315820766, 0.04149004644263656, 0.05291071667846653, 0.05836130202477498, 0.03848069602803838, 0.04713657792777785, 0.0874899145996859, 0.027905024603129398, 0.02995410870249954, 0.010560560340602553, 0.08589289706921385, 0.020595706939216585, 0.028458666769907843, 0.05283220798798627, 0.062241138995534954, 0.06741628891998722, 0.014962938223634998, 0.038528848484519033, 0.05479979373875165, 0.03338763625511239, 0.028608161167451934, 0.0576611283054996, 0.015723151211146147, 0.02173291083665625, 0.019200971094711174, 0.08117098391296403, 0.0033223124140227636, 0.028395137013567072, 0.021380709574347543, 0.016369454585196033, 0.014859348772123698, 0.04368878390279509, 0.07007428459943303, 0.06428218491735958, 0.04309009385084914, 0.054032399634560274, 0.01760719028571921, 0.027255638682794188, 0.03900216441721686, 0.060687018558382995, 0.059604030703344656, 0.024846112130269892, 0.06755888086533354, 0.041409331418934374, 0.035754357644867514, 0.05041244267035396, 0.017302099600314133, 0.036077838270894946, 0.026457740872677778, 0.02702418436867095, 0.04176162844223361, 0.05250264462384005, 0.05058871567129128, 0.04826001139477857, 0.022112135850493948, 0.03659089501466482, 0.03913655539133376, 0.04707813691047411, 0.11341079829200623, 0.0362428076445095, 0.03321522816775307, 0.03579734283829889, 0.030608296078900178, 0.030200645372632052, 0.022412823445554224, 0.014941565328157477, 0.023487083643915194, 0.05578635793720042, 0.04645403572207978, 0.02431594864315083, 0.023947523553825678, 0.012770565038907432, 0.03650476757977759, 0.04327766281822997, 0.05232722198049869, 0.012388843536046485, 0.010212870378557955, 0.04041268550340207, 0.07938564664894536, 0.06494835199367616, 0.02452110315883352, 0.017287103429196343, 0.06749091354469139, 0.06921509400971475, 0.06952666962939887, 0.01618799708423115, 0.061052059454302636, 0.0741721272108055, 0.06609458806774308, 0.06996108744774135, 0.05213294208290116, 0.046444007631150946, 0.040873851281620806, 0.020216755801811814, 0.04504515406405253, 0.05213832002012961, 0.06464943214650117, 0.02843683517928566, 0.0465597941600267, 0.12037567133384368, 0.10925854045537212, 0.11608412339081688, 0.11348269564369995, 0.12719774558659525, 0.10834317263816634, 0.1621231271494781, 0.16418943482060588, 0.15765320329416185, 0.1166684186506656, 0.17465493131068446, 0.161437034126251, 0.12569308761627446, 0.342598901761155, 0.14213072977239086, 0.17051212699903598, 0.06711168470041406, 0.07780179050901244, 0.14251014247777002, 0.11257205458898699, 0.11344570125783644, 0.17583580988068737, 0.2319349423651734, 0.1959728753013957, 0.22440446660883967, 0.09490799759664843, 0.23223909459287123, 0.08447016454151562, 0.06584577803169528, 0.11089584654978207, 0.14803149136564425, 0.10346493158008783, 0.09081841341309971, 0.15823642603091656, 0.13306990145675598, 0.16342454199348727, 0.2570915690833523, 0.1852267454828947, 0.1601942862954832, 0.10785150506924238, 0.28039878294352566, 0.12666528383570333, 0.14445606709247635, 0.26434277514776877, 0.16276552251750426, 0.13339879832440807, 0.11815134270657456, 0.15008551098646658, 0.11644675110977505, 0.2784503149169107, 0.17585850140500456, 0.09636582461215797, 0.12325875130632233, 0.15952098694059158, 0.14611545950174332, 0.14886376928658257, 0.137606107239281, 0.19915799309890117, 0.2000720279231187, 0.1580167426577499, 0.11662839821750119, 0.16691738198841774, 0.14372301287949085, 0.1494871197088111, 0.12090964993882565, 0.12125447377442353, 0.14401571975359995, 0.14973736999015655, 0.09717160355179541, 0.06804980532897097, 0.12590444361370418, 0.08843646219540989, 0.09494220342246756, 0.12481656811770894, 0.09135691959771419, 0.08975702923752608, 0.1509179880902652, 0.11335478194298283, 0.11917366405888913, 0.0575467475479649, 0.17041475722385993, 0.08825554287121182, 0.2200161157957008, 0.24171025492250922, 0.18831371209554135, 0.1179369759836024, 0.13827130138393373, 0.19583729306055656, 0.11556883733118735, 0.16402592101404745, 0.15946518509618698, 0.15197713528909992, 0.1968327630311251, 0.08763554791409163, 0.13940561712989885, 0.1325358462429816, 0.15619435738171303, 0.09619218312324056, 0.1295649572726219, 0.14250416699196064, 0.1734223724493096, 0.17912480920072527, 0.15867576213373294, 0.10169874651417618, 0.18678515218198302, 0.074545840222028, 0.1370802185227794, 0.15155784004638273, 0.12996392054182868, 0.20326229383147534, 0.14105419237767497, 0.18104732216846559, 0.16945849563325607, 0.100450559459146, 0.11568511415633465, 0.09709366176637912, 0.16030588998429238, 0.22283530403529445, 0.174040574760687, 0.09886834274737105, 0.12400884331474382, 0.10966917890454493, 0.15978786132989392, 0.10338009500335302, 0.15029993899647268, 0.16209963889371964, 0.10533484495094708, 0.17423516109345422, 0.2261158610664068, 0.17659242895822372, 0.14416098534580202, 0.1263816627643762, 0.10968262374761606, 0.1667035362052341, 0.14503401914431205, 0.22128477272006775, 0.10378815939710026, 0.08924220283065112, 0.10445504659606565, 0.09222627617418767, 0.1220493589437777, 0.070633819897569, 0.146851516779392, 0.1030582461446043, 0.2547087904907042, 0.3031291632402328, 0.1627021210808908, 0.10191099883447732, 0.09879744897085814, 0.10872555010381246, 0.13837096942288263, 0.15243589938167604, 0.08800395959687811, 0.12646799321256338, 0.15841700827642796, 0.14304379932582378, 0.13759582633933715, 0.09728581193954715, 0.14313571455497898, 0.1192137840834837, 0.20079633341200892, 0.11615414382709612, 0.10903650519227791, 0.19860798793454326, 0.15673913782642734, 0.16525366884325782, 0.1648454818754427, 0.09798040087785452, 0.11439574987537439, 0.1604123455622504, 0.102531545374903, 0.11819366906439105, 0.19353847770440966, 0.1929820986885217, 0.1132958927642434, 0.13395723045593308], [0.10124357537396493, 0.01515661578460206, 0.015507044510975962, 0.04919219101148267, 0.05127108550720638, 0.05284132443428521, 0.023587797392880725, 0.047534292473668055, 0.006137960609198819, 0.07566681837723141, 0.0801346737951521, 0.04570741026151565, 0.02615038448223664, 0.042207487783725225, 0.039433831979911176, 0.038455089539169304, 0.018538479325211337, 0.04000500032317735, 0.018829586990778486, 0.0402003221003519, 0.01768697068215378, 0.01256350200668338, 0.008271201382270985, 0.017967933428383643, 0.0024372656386525884, 0.03694838611409068, 0.05578050885589854, 0.06830633753129552, 0.01708417822937331, 0.05346686203753757, 0.03517356723727238, 0.02908720743782338, 0.0356747304660178, 0.0011657891516205705, 0.011686686606657122, 0.06904290808785347, 0.05031533719551179, 0.10212116739562443, 0.07388820736518792, 0.021280821285120422, 0.04041067069216121, 0.0077412983650461805, 0.031549724292070154, 0.04391712023906651, 0.06600528519840972, 0.04284913238558558, 0.07156790324276494, 0.05835103644658962, 0.04817763396028069, 0.05409570914062281, 0.06759615870372904, 0.05453320280198128, 0.070312530283005, 0.08490669676252911, 0.039748621338437644, 0.05637227730344861, 0.018631124253114386, 0.028587587876245383, 0.04563998686329973, 0.013058028041174816, 0.03880483932012031, 0.03756927739408228, 0.024437352511731368, 0.06063745266968205, 0.026130697937802445, 0.06086460540011045, 0.018534528226741863, 0.0062705072266380155, 0.11150017500885072, 0.012831161636108113, 0.061365527311159726, 0.06003611195351809, 0.02833894637954091, 0.043487586231241306, 0.04976118366504389, 0.05481090584409334, 0.05606176271553963, 0.040006057524512854, 0.02545037547186498, 0.023487547127109383, 0.04622455408436157, 0.04402687382553855, 0.04437064045980092, 0.01374499919268513, 0.03501584888586114, 0.02336008733348741, 0.032758754678070545, 0.0397645061715476, 0.01987746886668667, 0.026826692647450877, 0.032813104785858624, 0.04721427073461875, 0.05237593751160368, 0.09011831630261675, 0.0340308475067779, 0.04428595327021134, 0.0035577312331541533, 0.04377160183784943, 0.011803357009475511, 0.018439590780725403, 0.061213753802040895, 0.02868133022509996, 0.011933197421322187, 0.06188085167518547, 0.014803436802579992, 0.026165386399013862, 0.02322810379067256, 0.026615938029041695, 0.05229412315173015, 0.056159427434566526, 0.00565479374340465, 0.058283988431456595, 0.06937096225878886, 0.03825569983511683, 0.0377072153552886, 0.06828114856034517, 0.011438123633964889, 0.017863768453319228, 0.02977317022610336, 0.04339677799913672, 0.03866803516904193, 0.04498538005376055, 0.06987480296482963, 0.012686731079743515, 0.013032932915995199, 0.04056656575431267, 0.012460126102180972, 0.007584189053534741, 0.03867056708963167, 0.046941574077091874, 0.006486641697495455, 0.04742859149231546, 0.023871893438720898, 0.06183656796272244, 0.05591886433502359, 0.05902139402385201, 0.02267653772216891, 0.05034974603463085, 0.0277751803608431, 0.0244491521809851, 0.0203364857682778, 0.06643801762331879, 0.019926979214013107, 0.01943567170641355, 0.04256079604308452, 0.06843725429667581, 0.004903135085177999, 0.04315831398050632, 0.050466995791441975, 0.0017604795063943454, 0.03730971914445681, 0.01853020749084892, 0.04997956468873928, 0.027799760291893637, 0.01159591667894875, 0.10308835340002853, 0.0721999564238133, 0.03608128949699383, 0.01820995401020252, 0.0767448573042789, 0.039896828708268946, 0.09327437638515428, 0.02719497792572985, 0.03216437004025906, 0.029230793382251458, 0.023483753076664383, 0.06560140364472905, 0.04287417196939069, 0.06391045607386098, 0.004108759843098421, 0.04820510587324539, 0.10016431836711784, 0.037320946162987145, 0.035815349734959104, 0.011438327604874728, 0.12463900425861921, 0.021813800145361214, 0.04176145607245065, 0.041504644248033726, 0.04329241001077237, 0.05720213438654619, 0.028842706646349643, 0.0075546984988895645, 0.07647596810373568, 0.02324118665719946, 0.047309158384920134, 0.048197314759055455, 0.03340835893346417, 0.03150391797985762, 0.018282533180148854, 0.009908845512977531, 0.012874232056821066, 0.025580853651908618, 0.0443012482156196, 0.048885656250340324, 0.005865526336786007, 0.03068956077068804, 0.05139655538744504, 0.02063341570206948, 0.024224818654118047, 0.0918172924749313, 0.02505837402667009, 0.0299649469314083, 0.04621423104958189, 0.028494435415092497, 0.052273591995359435, 0.040224312143700744, 0.08630647729601591, 0.035862973590772, 0.050836131427316904, 0.03865470906959907, 0.10701283031413633, 0.060609233820991176, 0.038499089799100356, 0.018234399875866312, 0.08899647246805892, 0.03202157316639299, 0.061157607218070384, 0.04005947683547293, 0.035588101243540164, 0.04619326705353395, 0.07820976297220877, 0.07911520228991586, 0.051447534708366285, 0.050818565031213146, 0.0575184520904816, 0.015437898372540311, 0.04040170746344713, 0.06878315065536769, 0.02784254055680527, 0.0413544450495993, 0.07946920385884662, 0.027346776332706216, 0.14871482647234394, 0.02620498739903973, 0.023432534353266803, 0.03224060344960421, 0.19765973962362737, 0.05442278271901512, 0.04626214984924563, 0.03658775022373565, 0.05914444689668956, 0.027451111762333783, 0.05396426760501439, 0.024389424135968573, 0.0536015096511091, 0.05412921782643084, 0.08570536640622924, 0.03988951639903169, 0.07402778092411257, 0.05203635371740788, 0.01876950654531679, 0.03498178095586839, 0.0320825154607695, 0.009881683865622168, 0.05001576234316153, 0.02908923565560291, 0.039880430596249725, 0.07384388151788905, 0.05010433742896684, 0.07595528112423998, 0.007862539439942808, 0.03521307822196715, 0.03301690715635496, 0.02506404499252958, 0.0544032896117818, 0.02774328045967606, 0.03267846866360596, 0.08397357102723853, 0.056248036994328426, 0.02501605149929322, 0.06446717982931484, 0.030216219940132676, 0.02495700144208968, 0.055506517509779627, 0.034143784188575325, 0.08738774145322462, 0.02167520717897963, 0.04965164841363027, 0.008589567413793938, 0.06720177664030945, 0.02835087628374177, 0.021844119990184423, 0.0974926786617406, 0.023664321915637103, 0.02575958004942344, 0.0541142484683904, 0.035794485330341325, 0.04877149765830367, 0.06733866889149913, 0.05400916801825647, 0.03064358783435197, 0.00520080620903642, 0.045123229914855574, 0.03479379447056882, 0.06980775494969661, 0.08636818567831671, 0.0201772716301944, 0.04300232698780395, 0.017214499361392473, 0.0052403329942946235, 0.09181006060492608, 0.03428890039363215, 0.012153528138784873, 0.03969816295730491, 0.023767196032549107, 0.024869029650524743, 0.005793655319364682, 0.03883541388917835, 0.034790446666339715, 0.07298127417602847, 0.1219735085783947, 0.025415796178182768, 0.024777899661491957, 0.061523249493010586, 0.03315417096018791, 0.044614015102025964, 0.04801884691621508, 0.05498633231787432, 0.014513046386831952, 0.01758307192264305, 0.032855270265211026, 0.0376488700989754, 0.04014525570035462, 0.05164853702749937, 0.023517506910608183, 0.07591588122229423, 0.0349517886136328, 0.02109551610755584, 0.030219491135569352, 0.052076937225196636, 0.07873360623395251, 0.06637705234630455, 0.0628867902372393, 0.05906687666391654, 0.03032753443075044, 0.06572365595568573, 0.0168039949776064, 0.049187854953831246, 0.023271558212957556, 0.05817911482506222, 0.03808110073629407, 0.033747670766446865, 0.04802759180987074, 0.026196675345061288, 0.01558017239139806, 0.0496445850829684, 0.2356941204878592, 0.01194854503527524, 0.01628906323364185, 0.059283361619999336, 0.007263289186202231, 0.1706121627601885, 0.11743749431785076, 0.2089196692911848, 0.16501089558005333, 0.17690490090077926, 0.16376500678879602, 0.10520972747115359, 0.1495653832511556, 0.11261975888403193, 0.1371699887057466, 0.13025299615917668, 0.12339640964543629, 0.11813310981397668, 0.05977828889304112, 0.12469292152673007, 0.1128304560458468, 0.16545879654586315, 0.10563875969138839, 0.14937877955455936, 0.21715814818538007, 0.09175043598177934, 0.11247136765309881, 0.10168682618607437, 0.10252179307562691, 0.14149950396630073, 0.11552834192350989, 0.11218753973803214, 0.2996958942422944, 0.15350756445719352, 0.13843539741731462, 0.16684848004050795, 0.14444564829670614, 0.15607788137370543, 0.14318480546916687, 0.0957246626456899, 0.16019223317984613, 0.18868423818099886, 0.25621320331288927, 0.10386947196938338, 0.16598254021617675, 0.23131267978779732, 0.1410509901301515, 0.11085086186686832, 0.1714127399628201, 0.09224907495081426, 0.33641510132339697, 0.2515977074302012, 0.17148197898941656, 0.15530217138509597, 0.17845184692452032, 0.09949287294500297, 0.12553483683375583, 0.3919457812463084, 0.2043006340822866, 0.16256577275212736, 0.14548522960995475, 0.149585148319602, 0.2675091391128879, 0.08485814210988822, 0.1429716031998396, 0.16561014487618403, 0.24376965248055998, 0.08970674322617632, 0.14179037222939153, 0.10893846125972849, 0.16514431745294603, 0.12085004829831662, 0.19879233933264212, 0.17549994161292432, 0.13956801244808784, 0.1303831851410289, 0.1951827628598098, 0.1345363316396552, 0.08953257313659115, 0.12646089923838455, 0.14108244570032244, 0.08810142130260507, 0.16718991010660128, 0.1577817681696146, 0.17006335269299247, 0.11311629877215433, 0.21330702419002212, 0.128182873370186, 0.110052659536802, 0.23831015753169216, 0.10296201784043543, 0.18420755743019043, 0.11694007342861545, 0.14184770624964468, 0.11487736637073179, 0.2131247718728358, 0.15303245204831326, 0.16560852076978455, 0.16748220329323124, 0.09585305132092008, 0.3215763765958048, 0.08817295859297437, 0.15201000046105156, 0.1349963674381856, 0.14046150079417613, 0.19950659374796575, 0.12924663241832487, 0.18134943660228484, 0.14523094970612757, 0.1575812676380719, 0.05996646690032175, 0.09142388334317554, 0.21756504812548239, 0.1519259452939995, 0.15853858643001126, 0.16575252997779077, 0.1719299718857773, 0.11388841580839888, 0.14073307896333356, 0.17453957379104632, 0.11384021355620316, 0.15295501588092697, 0.1472761286723037, 0.12951111661330347, 0.10773235541437903, 0.15599160455167294, 0.15568846356003516, 0.15282740095450034, 0.08659798907296312, 0.11853983355385643, 0.18393161255986462, 0.11327790501978129, 0.11969131733020467, 0.121444838962728, 0.11306375280142793, 0.07042190465595453, 0.1376107650538606, 0.18276389538040086, 0.23562621445425097, 0.13199330277500615, 0.1419294631529239, 0.13182859387128584, 0.13277405362215736, 0.20357936230157653, 0.09697932314368025, 0.12132042628382483, 0.156335455455607, 0.15188396367574894, 0.07093450174696984, 0.1686350124016885, 0.197424826422526, 0.18147548870934596, 0.20312459718796516, 0.14865528611886888, 0.16458010901847195, 0.14778205313749854, 0.08528954154180904, 0.1195439373353316, 0.1577897354840271, 0.0970129773861939, 0.30202532247189556, 0.2152611306237598, 0.17096275523785623, 0.14478350839307233, 0.2251053451290054, 0.14337179220972524, 0.20601282527129497, 0.18400526425290495, 0.15107572559387455, 0.13943011662171734, 0.1075720055509479, 0.16639317866534958, 0.11321174566664043, 0.24028646519347546, 0.12494378467841495, 0.21669504803515252, 0.24644041884570356, 0.08340438302125662, 0.14208073487445233, 0.09678202485966106, 0.21587370984977294], [0.01666305586695671, 0.061351691763247215, 0.0238549092694396, 0.024957570262373458, 0.04890472417877567, 0.03691707610062534, 0.053621573493846005, 0.02081346934691312, 0.020884328649469444, 0.05662551149725915, 0.011699537731586926, 0.05788465744004615, 0.03190326620824635, 0.03246829244157961, 0.036527784691462596, 0.04332316461049261, 0.04023168573997194, 0.016922903314773596, 0.04966216297039101, 0.07955073093574855, 0.017686388455331326, 0.04466405213480035, 0.024896304295848937, 0.056775408090963486, 0.07159804114170613, 0.007508643686906585, 0.025171312623687332, 0.03638150403276086, 0.04434738203041977, 0.03633899764428216, 0.03313167478829142, 0.03679725611882825, 0.04585226599667822, 0.0751199311907253, 0.03550879199117903, 0.1417762302463093, 0.06663481028930796, 0.02619976650983576, 0.028446980098622943, 0.04135859341570928, 0.04677803728789572, 0.07735018933852834, 0.015440388158294223, 0.059144623096912145, 0.026613936624339512, 0.011154633755194805, 0.08052543226268985, 0.04090029280632734, 0.02878457014899581, 0.04501743700295206, 0.03694440245688443, 0.027473083164002148, 0.04154316314886655, 0.018755693980042013, 0.06787560459586882, 0.03246327456567557, 0.04640293765753027, 0.031105693985497763, 0.0382471579547611, 0.013655215603179269, 0.09556012994219219, 0.011521519965402061, 0.037997034077923146, 0.05581265390520135, 0.03539765178556404, 0.014408467724288424, 0.06260266737832178, 0.06818960105339367, 0.015159080672498434, 0.068920694081293, 0.023323320858781377, 0.054672320538590995, 0.05782879813904724, 0.08268783034216012, 0.03743084913660442, 0.11099596658060629, 0.010644627956583375, 0.022910816985512936, 0.06636080362143056, 0.09491214979319804, 0.08691548655230193, 0.06353805690342862, 0.058560075028048414, 0.029405421209371382, 0.037894267213320544, 0.039447905015080206, 0.05938129063936011, 0.011776871434713324, 0.045888957777811636, 0.05030756140308035, 0.1022386393179336, 0.08146663256470235, 0.03090657049699897, 0.025536104541031585, 0.03540782543319849, 0.0582975022224409, 0.058923342430423346, 0.04320894473142201, 0.008395957843130155, 0.10064087102129575, 0.011859943136392583, 0.01872208953324345, 0.04045979608030569, 0.05512007977813483, 0.11176082876420791, 0.020601741796840104, 0.026355366628136367, 0.030040366372333902, 0.028891787984438484, 0.028493094761225007, 0.08309143610418805, 0.019404905615374446, 0.02014299302602247, 0.07043427697593166, 0.06957039792811678, 0.010014707372794229, 0.016842607724209948, 0.0594045912035771, 0.013874311961473958, 0.008357793257962312, 0.02979070597869014, 0.039910572325630535, 0.04065093118697405, 0.06892739735063046, 0.01779175235799724, 0.05065113268492203, 0.03216589455522838, 0.06467632183264341, 0.03909481892121896, 0.007142349279620835, 0.09758682320675544, 0.04715053988019786, 0.025928531165024447, 0.023568704566587845, 0.03224463690252554, 0.020833910487952734, 0.010116546313398549, 0.03919272112750238, 0.027609726436616435, 0.02644447414504905, 0.023975727080758062, 0.00792074871564945, 0.010431654556023498, 0.046585982875718225, 0.035657738635857264, 0.05190328424496036, 0.015803273474316926, 0.07380236721327228, 0.01865060586902884, 0.008449824357916032, 0.02594517059473982, 0.044156097536606174, 0.07665086597684892, 0.02195336221296701, 0.008997175027616322, 0.04361793609155763, 0.0304996992851938, 0.022959681903763164, 0.07449204552798502, 0.016333029019616304, 0.08034289649297154, 0.04393503903561542, 0.0731467568285523, 0.018577683874736392, 0.06246903100081029, 0.03542751772329211, 0.028117640815194578, 0.047587187014400005, 0.03283172072241864, 0.06964130702638818, 0.01722203192090796, 0.03192469943314791, 0.031204256942615877, 0.06053259438504616, 0.0395942852652121, 0.05817955149517906, 0.030627850473167437, 0.04716087057585678, 0.04223442726558255, 0.029971150328375162, 0.03305940971439404, 0.03817245289082489, 0.04410698363978056, 0.03468594844302824, 0.01942525865630277, 0.01925520628931061, 0.021266652488960855, 0.05320154663716113, 0.08129240884896248, 0.05370719531070321, 0.06327210948051465, 0.05753214208168849, 0.012071164110825669, 0.046942424434687824, 0.053215849498707446, 0.04966988896710738, 0.05683098393943041, 0.024984697435772227, 0.018102259285026984, 0.06412686059071172, 0.03344133901860445, 0.03986329320938357, 0.03820578537641033, 0.02097647562022171, 0.059601326412971944, 0.06765766024229027, 0.008164975630690255, 0.019239323371420466, 0.037629082047891234, 0.06483815024576842, 0.008526228221824333, 0.053684519108144514, 0.06858965982833216, 0.009435284432143936, 0.03567643118120971, 0.09488657011740631, 0.006929272935996133, 0.06733352844152721, 0.025254980916337624, 0.0051150809703094345, 0.029179787248252865, 0.051458769387775855, 0.046792121814383615, 0.0931766082442576, 0.0210762336745017, 0.02230419217789125, 0.02435563582806818, 0.012626933129203897, 0.04090068734160835, 0.05750367808486185, 0.06608059164136648, 0.1262583455912048, 0.018056269111712615, 0.02037900747851499, 0.008488230260780022, 0.014079996035434307, 0.042655270005906784, 0.019757191147354823, 0.04016644952277984, 0.011611587007439906, 0.008190471994420214, 0.048424563250474395, 0.006350010873809938, 0.04247006058933274, 0.07981719929845103, 0.016853656627297882, 0.010761895907982703, 0.067179897169192, 0.021710853250096404, 0.045677896724232746, 0.02724955019901597, 0.046450936896426064, 0.06575879640877247, 0.03107810715934442, 0.06417527351708663, 0.055250054255368254, 0.045663873484778794, 0.0055516285130814205, 0.019393502396621534, 0.06160182330096441, 0.030362784051366394, 0.0266167079474056, 0.04721820459610993, 0.013319780175093443, 0.055010785844417355, 0.035350920422182935, 0.043323103323458664, 0.05208879243582488, 0.06719478991844001, 0.010486328335959586, 0.007553733706909924, 0.06988863085186289, 0.019254853888865442, 0.05669837028929784, 0.05033527080330157, 0.0767698777358859, 0.034921815423595334, 0.020257362292238304, 0.013588552547228194, 0.049593490848858515, 0.13532722549092385, 0.05880474435886549, 0.01795057962167888, 0.084801941899763, 0.053474863825906674, 0.0385890323518505, 0.06315504741524497, 0.03617997694339964, 0.06730159789684319, 0.08713004479725515, 0.018202124591616374, 0.02596967008655831, 0.023220090510984583, 0.0491664236441495, 0.04265993165092603, 0.029751499513945276, 0.05216539356737368, 0.04711192138793488, 0.05805599300431148, 0.07388741063374667, 0.015244028331982273, 0.05178132687785453, 0.035069704866938056, 0.0102216842201268, 0.02251177136185429, 0.04159676632092845, 0.07951788874643465, 0.048825089339046716, 0.05730451054630741, 0.04705290963512756, 0.0410196952702057, 0.02028229079329439, 0.04683902937798731, 0.07078058702210266, 0.019773254095907175, 0.027694241256423058, 0.04159685059060012, 0.03801668423318094, 0.020622014398536375, 0.0793795332673096, 0.01862553372648695, 0.02035131148483244, 0.019764880754894788, 0.06736650086578823, 0.03378749967763021, 0.06709616375906814, 0.06042262246351569, 0.039405659096495765, 0.08125169893666621, 0.05227749904377326, 0.07659963001647303, 0.017418031685895497, 0.06197691527045062, 0.08548343839544444, 0.03721502684657613, 0.051116067615728226, 0.06950380190485908, 0.02989509886491203, 0.08065133115216609, 0.04910811286179289, 0.007385923104706191, 0.05783917863042124, 0.054866412744647076, 0.05320690159175185, 0.012496055625829727, 0.04652753036709563, 0.0360269662022831, 0.022222498476865794, 0.048574348761429714, 0.06657435829120298, 0.04500193904424387, 0.044800699237854257, 0.1020280417475489, 0.1546372377103375, 0.14552889662163873, 0.14306693518113706, 0.18686962103651417, 0.15321102714346302, 0.13502314987201847, 0.08906032589654769, 0.0826274779354853, 0.11086326483036242, 0.14138269087960645, 0.10109038843262581, 0.23148865018400455, 0.14730461182132845, 0.14794619513615487, 0.17094197893334975, 0.13081820050795234, 0.16719907251817567, 0.17570485481091086, 0.2837999988227122, 0.2696053395348211, 0.15241832532469304, 0.09560189705582396, 0.20466218161727154, 0.07961197200441554, 0.11132965149778513, 0.08080832555048889, 0.17305478814148134, 0.20676020532846454, 0.10692352744480295, 0.10631731440944057, 0.19141010158965666, 0.10454165283590557, 0.15434025606561094, 0.15145357547988816, 0.20682630339457145, 0.1910056684526705, 0.1275840913876891, 0.16893433827546336, 0.22407785268320193, 0.07818242895507044, 0.15911142101451275, 0.12711611125738392, 0.12613076130829512, 0.12739387941696953, 0.13625111220584762, 0.2070143779799823, 0.14173775731075194, 0.12733507450790177, 0.060497499897234866, 0.18896002983373983, 0.11674017810653295, 0.20261493421369986, 0.24038293098490085, 0.17142873587867907, 0.3181617082126679, 0.08768643913490158, 0.12730937991892138, 0.09270822208735252, 0.0676843507455722, 0.15868909206361542, 0.08940036934349807, 0.1813374703089076, 0.10517798844845065, 0.1126844703309959, 0.22756392046088175, 0.12663964287287768, 0.09305536716936097, 0.16127466945157898, 0.39645666016205666, 0.11015218201904528, 0.20657012359269206, 0.09818819456643636, 0.22817493686752938, 0.11090884706185711, 0.24164686880765424, 0.14707207349279236, 0.07618949718533025, 0.13860243522832472, 0.10252586866338408, 0.21665164149336277, 0.12742523539571032, 0.18226422219266816, 0.16931782656859967, 0.09019467228602979, 0.10585737054146106, 0.20199018951144912, 0.08904387798881339, 0.22831033524726668, 0.11547195785228284, 0.1371380275175456, 0.18731553017372088, 0.17350900167178723, 0.12396806445453437, 0.12099458610699063, 0.16167165621394114, 0.11771195297760349, 0.2072250828026764, 0.19868787558328724, 0.12371213746167, 0.1102140742624479, 0.22346374128134022, 0.10495026115207903, 0.05645227220450198, 0.244826348198037, 0.13524301710628694, 0.08041041948261761, 0.12190571745797513, 0.19564308977175146, 0.1158813858825353, 0.23216397201101627, 0.1153017484372662, 0.1804981597008244, 0.08986431985132157, 0.11675950650486255, 0.09860762004410067, 0.08686948297244888, 0.24204336527374484, 0.13661618374528425, 0.11757328340242948, 0.12470034491871634, 0.1043596992930097, 0.15751405108359554, 0.21456210603637083, 0.11254200862059671, 0.12016064577525663, 0.1882936559136837, 0.1752215605829993, 0.08407895408210256, 0.13246433959612924, 0.20927107382205226, 0.16933926170872104, 0.21319868403577039, 0.08842828803725782, 0.1392560767670793, 0.1342208566324365, 0.10680610914864849, 0.1299564588454462, 0.09771960922667096, 0.08591587970694227, 0.0982418053993775, 0.12930436480429866, 0.058335017548092914, 0.11559005796668992, 0.14938952010725776, 0.12277243103110984, 0.13223978390376415, 0.1633545675224835, 0.09181747633603313, 0.23097195452259434, 0.14138843653903854, 0.08403917113619466, 0.28924571951070144, 0.10807164043428437, 0.1570362420452218, 0.14846770182972954, 0.10961509309709074, 0.1455855871280355, 0.18481301203850778, 0.18299234279942128, 0.20071289111529628, 0.19765109815184148, 0.15543467395247954, 0.09387789279102318, 0.15626808568354578, 0.0988284219056368, 0.11670581906312898, 0.11008264421815835, 0.10218925729033448, 0.19032591863745646, 0.10393769209904057, 0.09268058163504447, 0.1421373794155736, 0.17309301592890294, 0.14787718593593568, 0.10749333598200353], [0.03442684984615734, 0.050704218747635046, 0.03485127021708796, 0.07347795195997724, 0.01762163295831171, 0.09567020911603205, 0.04552365641199774, 0.026155513440889698, 0.008011943822155797, 0.05775560992920111, 0.035986980243075284, 0.033778513466278394, 0.025725927722129612, 0.0054613785675516535, 0.016998255723005822, 0.007529689558601428, 0.03366647310735237, 0.07084573513918346, 0.03349173994314286, 0.023425608918431307, 0.06679576536219928, 0.06636401352983329, 0.03199511248948834, 0.0308033439796418, 0.032903273334546436, 0.0321005204422099, 0.05127410006318843, 0.04591204383740983, 0.028654974885284904, 0.009275611598915871, 0.0018913914837251089, 0.018255528580817967, 0.07309506121542185, 0.026687745365404317, 0.01904537863728981, 0.0677253900756759, 0.01482300364577602, 0.01618808901478206, 0.03285477230806024, 0.04674236057326198, 0.035738189359225576, 0.05003186934176953, 0.12345700720024687, 0.05421175996983244, 0.10161260758797008, 0.027558218515027436, 0.030076010528230862, 0.0512627849445468, 0.05269848734080311, 0.024716897995301315, 0.02823943155817688, 0.030297976843411886, 0.039165900389273325, 0.046641191001981504, 0.06832522159862904, 0.018727856260093472, 0.042943039443343885, 0.05268489694102638, 0.024570301325330814, 0.06549225143727756, 0.02882734658346782, 0.043795373546139854, 0.04648109011712574, 0.053537981809988144, 0.0460282095798081, 0.019124333573985967, 0.004232590773984069, 0.04675954392540359, 0.024957564516714024, 0.02624357333256593, 0.053906673114866986, 0.02146974239768761, 0.022307231631730835, 0.09160474138033968, 0.02020896085718226, 0.03568018118159906, 0.02104159500900536, 0.01806649830072157, 0.04490539664402605, 0.03440732609540705, 0.013507989783500953, 0.022806686484405113, 0.031256140247287775, 0.03313803331806295, 0.1338280833536579, 0.09069727192963324, 0.052503770773088744, 0.08406092037236498, 0.087298178113997, 0.023884700513595057, 0.030623656141782002, 0.01593844011245716, 0.05114410643375689, 0.048525326795155005, 0.014754814159635816, 0.021386150713829745, 0.03571370518916557, 0.049079576086613445, 0.057586032536722, 0.045233979415629184, 0.010066422138122783, 0.02795171191645486, 0.026400209584784125, 0.067320964599569, 0.0162224231603285, 0.02083109128439138, 0.04215442853408956, 0.053001950089369095, 0.06147075714843889, 0.1174284621412235, 0.08713912293915788, 0.055286060387809435, 0.05186116473088342, 0.06335254488212448, 0.020538505069130374, 0.05816891436435043, 0.03606484925013877, 0.03078674668476226, 0.01690838594860848, 0.04801923379061684, 0.04147886921982131, 0.06847679975532717, 0.08640075973685711, 0.01869079292631678, 0.05004215024171337, 0.04022443088732901, 0.036174330875397696, 0.043674163114760196, 0.013233938107958004, 0.033864587275010925, 0.07232654479242141, 0.02978805722969194, 0.0714295860680361, 0.030535736061151952, 0.04085851420137671, 0.03249578350674241, 0.03592050679388546, 0.020511496639359864, 0.013853147824955805, 0.0438162149681199, 0.04212426382207102, 0.033156564984951294, 0.013467034723068918, 0.015501652209598933, 0.019908535647236054, 0.02874699162109004, 0.043649993040749145, 0.08802527982381084, 0.05083720395041089, 0.03289989488680036, 0.07697151973843575, 0.004853903402334019, 0.011658194839143226, 0.09237924095002875, 0.034516746433632034, 0.006560494009810951, 0.06979558181257979, 0.08136229138941535, 0.04778330935345543, 0.04715868339483296, 0.03805230349122036, 0.07899430595458516, 0.053683695563625906, 0.07869308018275807, 0.024021629153961138, 0.013158114555652344, 0.05150499896356656, 0.026041080972420114, 0.006512080604631093, 0.033364278234301076, 0.016203307351397894, 0.04427282252318917, 0.023632479471064383, 0.03592187043039068, 0.051281105937255975, 0.013550708761378644, 0.027889122533041145, 0.04725165199488402, 0.018366255098953843, 0.059277152477373043, 0.02402829986456181, 0.02281339932984162, 0.030880937195052544, 0.01693310377548539, 0.018330586045199347, 0.03467740273223289, 0.03168285696677143, 0.035475991936700965, 0.006974051253975279, 0.04247040149845904, 0.018446592824353326, 0.044909142813975775, 0.010605286468841858, 0.02856278003403737, 0.044550230621450373, 0.03987853069819751, 0.0571515036356305, 0.05845005331080287, 0.04894914578706507, 0.04762336168618453, 0.04495141554563757, 0.00935718176826354, 0.06469417168127914, 0.02525232642167999, 0.00508425742267601, 0.04264240738965812, 0.040494951855150924, 0.004775154830572466, 0.00994806155382145, 0.0462805244681095, 0.0689537660969842, 0.08399224058995325, 0.01685094276082612, 0.0169898574841359, 0.037404748521024184, 0.04489650236322515, 0.026235663474747734, 0.045183612965047366, 0.0581740816273997, 0.03710485957262497, 0.06414924951029882, 0.037914637491227164, 0.027923157904297117, 0.013688023318536581, 0.01255822940654452, 0.05483276233257306, 0.07171968058232339, 0.08062438017898992, 0.05003553507248721, 0.07365940754572231, 0.03370868838241985, 0.04051624909944592, 0.022732567477730975, 0.02306148924324061, 0.014156172945795041, 0.05157875407847667, 0.023143414685863162, 0.04433195301962476, 0.07831855511833584, 0.028343947018466653, 0.10348614455471117, 0.028083593952619744, 0.04055346182036785, 0.06237067297221192, 0.022654430339893988, 0.06519811963962932, 0.04926703780168488, 0.040019647924289595, 0.08859829826941414, 0.021216556084372347, 0.04362178951381676, 0.030218765267261097, 0.0293356076168317, 0.01824636616924357, 0.043299331615168246, 0.026718293121385, 0.05511451797980455, 0.06697267804655337, 0.06897194536342736, 0.007500303383435935, 0.06290598073974252, 0.005421276258740334, 0.005026260257563404, 0.025740818556157813, 0.005766245172238879, 0.024901772248408487, 0.06817159032629383, 0.02943931485436136, 0.023691016249358657, 0.02401295512343847, 0.034676249769906846, 0.036135585978627205, 0.05427083684011333, 0.02403895423236874, 0.015531804472688707, 0.04953530647100941, 0.01618030747669118, 0.010739343237101791, 0.002044726734898324, 0.04039177130306921, 0.0958822086273182, 0.030248460750426018, 0.022064676703584772, 0.013368621153096038, 0.07213634048258105, 0.0728750943897232, 0.04871721649842878, 0.026690200677201636, 0.040159018469914314, 0.02902321228306861, 0.009901442230799267, 0.012623267398486215, 0.04585398969450786, 0.014978301159346537, 0.005094065263326611, 0.03894001553435961, 0.031862690361336835, 0.0165916794550515, 0.03261221354947456, 0.05178362131118775, 0.04915903855655943, 0.02771379948112994, 0.03133573869784032, 0.0025531723475714606, 0.08795368124640758, 0.07889485242025507, 0.04027552129099927, 0.010260766195583968, 0.028050487462971962, 0.0634031986156779, 0.02118622283301046, 0.013082190454306622, 0.04779221512557519, 0.011056258489618139, 0.036602616159906315, 0.04580909694214502, 0.01436383639942975, 0.019854710309676105, 0.010313381114223552, 0.06023414951238421, 0.06153680158839111, 0.10966845112101686, 0.05674191472691394, 0.06348517385401553, 0.027957047718847473, 0.030766654113728194, 0.06091921597779278, 0.0005388865951493744, 0.017350309513389103, 0.0212021766140336, 0.08111456919822001, 0.043305644179664315, 0.047835966406930844, 0.09014478464040065, 0.06290774274196836, 0.04090628744433484, 0.0760016754089344, 0.04037589796127812, 0.04873858269063696, 0.010216343629684661, 0.049183898109702334, 0.05407808911836436, 0.035372217666477926, 0.026515605408818494, 0.030358177947721658, 0.026874195844415697, 0.010546423145569863, 0.01852185330203464, 0.010782568790619413, 0.03255719311475273, 0.01605856078376453, 0.02028865698394516, 0.10867151026163371, 0.13775915628479374, 0.12060159832359323, 0.19813811556706507, 0.11671290537642857, 0.21077018531580127, 0.11020631379177494, 0.1481684832082641, 0.1475282635299429, 0.15052795740625552, 0.13408236325748507, 0.1093359076748452, 0.16188677370307908, 0.11642700902396634, 0.12356961446423685, 0.11910435608437947, 0.12234527572628953, 0.12626628992297959, 0.1507618900148138, 0.10663878022422714, 0.1789075619871578, 0.12063944306705268, 0.22287510996384008, 0.12453625654621471, 0.1609697204924399, 0.13396433975187041, 0.14506037256890728, 0.11585133991414502, 0.17121568682693666, 0.08815172263571332, 0.0963877194050339, 0.1420566950353884, 0.1269564661948431, 0.19278942757556516, 0.1083170183964314, 0.2558003891740115, 0.15528982204775657, 0.07886612412309454, 0.1564244595506499, 0.14611499984898876, 0.12724253874752792, 0.12596167804252717, 0.1677735465308351, 0.2832669548449978, 0.19516238492102395, 0.2442802807256099, 0.16443115088247484, 0.12192225729626034, 0.10537066722228643, 0.13026493180903698, 0.19324408543686714, 0.16607019599647294, 0.1574206956091427, 0.11271245552286988, 0.17557322558376098, 0.121426192382651, 0.10029347313027229, 0.2093065896582219, 0.1658006249776771, 0.15824869875946354, 0.06484744289228994, 0.0802782080286453, 0.18402086180304328, 0.14814625133670148, 0.2723628270529932, 0.14582744108573084, 0.2014605009988431, 0.17595410917795476, 0.1191417488359636, 0.12117208101816716, 0.214165824074899, 0.13783889071595284, 0.18581372205047839, 0.1593207928442186, 0.1003521401435137, 0.09670479553601435, 0.1546600211652056, 0.1120605530037034, 0.11134948551414475, 0.09020490722069818, 0.18535849728411247, 0.1256419129429325, 0.20449047066992332, 0.08236334614095189, 0.16280955725139187, 0.13024692874281638, 0.2838082419287774, 0.1488956691877496, 0.12263704797313099, 0.1815970208976538, 0.1392528745195558, 0.06758587014290594, 0.13753650049048086, 0.13475531021193152, 0.15348833565029407, 0.18895555588026203, 0.14678909593532163, 0.10417126464627444, 0.1611428410415688, 0.12909347612050273, 0.08146575156358943, 0.1159350963069066, 0.2011386368183359, 0.11937267071897946, 0.14369537242718283, 0.12933991128398528, 0.10761068533024482, 0.08920423551312379, 0.17274876665924827, 0.17466622344668836, 0.147711802874842, 0.1389918377202365, 0.17695621346994755, 0.16263927122758282, 0.10331486261660054, 0.2188546192501822, 0.1471398416305742, 0.10792402295215477, 0.13619520310913363, 0.15711901018456106, 0.11487836228503336, 0.09641715250308476, 0.18462790987424313, 0.21170398520846523, 0.14137029557699157, 0.10165184661145173, 0.18265753173299376, 0.0945883627320009, 0.11306300969614137, 0.11674351824988281, 0.10237243657390918, 0.18096869090391746, 0.14633963215014628, 0.17480637157155623, 0.167973296296212, 0.07735121589634689, 0.14413008135893654, 0.12187606985530547, 0.07330989525202783, 0.1564076362598327, 0.13572027456135521, 0.09331843410167964, 0.08802400045697728, 0.13992778265908842, 0.17405719886864388, 0.19130278799322345, 0.12095869488773808, 0.21856995629927806, 0.11608525720094481, 0.11726485640411416, 0.26505658523209635, 0.18878067332890727, 0.14022563764404866, 0.12824193108826876, 0.12305695608618761, 0.1295582616641637, 0.1443104950651046, 0.17829020237249715, 0.2286089563201512, 0.16311461346284037, 0.3129335871386913, 0.09640990531132107, 0.13418275141908279, 0.16598848505846917, 0.1895891872024344, 0.09783488247663745, 0.17051535989007643, 0.09566983373294916, 0.05518882084758051, 0.06546443478474695, 0.1326911935522672, 0.1716416470345951, 0.054130650410849246, 0.09128142929365558, 0.1222800356786578, 0.14763485700372728], [0.022428160525798317, 0.024121946452425855, 0.02806695452290437, 0.06727632465622119, 0.07888763587200835, 0.017495293568278995, 0.029018037359140096, 0.032512534019206805, 0.04148903903701613, 0.042440799861064846, 0.02399248908454132, 0.011403649677372268, 0.02689785838517691, 0.06301755761547435, 0.031138674070638035, 0.0029708231346786866, 0.05233568725206199, 0.03193161912232397, 0.05998995898651981, 0.03499218442988011, 0.029086347504128373, 0.0012942087097701828, 0.05367053034264715, 0.013365010006142961, 0.09286095703681631, 0.01827536642761721, 0.07209505600434157, 0.02718705466137298, 0.038280930940903006, 0.040633069847019455, 0.03999849623670021, 0.04665847011511365, 0.033519954961394115, 0.04725925158709288, 0.03483120637435106, 0.05788496770565549, 0.047499305238166166, 0.0465711590743834, 0.02852555007613715, 0.023896772144061905, 0.02744593683840527, 0.11809840603100678, 0.04387105920261914, 0.05220674699352634, 0.03595420317123494, 0.047254969155596155, 0.06684612032146224, 0.025295847876658364, 0.03764157311149663, 0.012200931744319538, 0.006555481400761393, 0.054896971991946625, 0.009481084041087138, 0.06428745560227864, 0.009921649715021975, 0.03444444305533844, 0.04593980686378576, 0.02234621593097766, 0.03210303321060154, 0.030306189305960175, 0.04659219584878414, 0.025506956810732524, 0.0183478843105296, 0.0455988900766017, 0.024945609714655627, 0.04911508426190384, 0.028184110433944774, 0.03648930409502599, 0.013305722461682896, 0.0385700601844057, 0.015803055139258504, 0.09232658772699295, 0.041517970347476583, 0.013676845138111423, 0.048295508078750105, 0.052981319341568224, 0.05932227505611316, 0.026598842777011376, 0.04780172610715513, 0.03192038827335402, 0.009684286947782722, 0.02359961046867313, 0.02906254706754079, 0.06678234350176589, 0.013312629701930189, 0.04002285783269233, 0.04064702413856022, 0.05665589454433611, 0.03600168913122147, 0.007456175761387474, 0.03817194344235524, 0.03444696731504894, 0.02614912618282101, 0.01179665086730834, 0.03695135087435765, 0.0592481330668013, 0.06956380191108874, 0.031452636054206284, 0.0031676079003861357, 0.003131933340374681, 0.012887966098083604, 0.06319345906376839, 0.018297881751711813, 0.08738686811299094, 0.06165774771943689, 0.02336290845226857, 0.015384231998224654, 0.029227617947805314, 0.028758502092152357, 0.03008493736776854, 0.04931739659138745, 0.006902567589760668, 0.050729599240566456, 0.09123427658191613, 0.02149812020962277, 0.030480137230047298, 0.04942512387529977, 0.054612335854119835, 0.018106664290591594, 0.00964863513100652, 0.03630077751773981, 0.0331367539512294, 0.022922532385094993, 0.02975301636803535, 0.031035686955757202, 0.028298200078068242, 0.04741946355469766, 0.020272094163022215, 0.046974163457390763, 0.014167155773799508, 0.0621177452135711, 0.07945543725884731, 0.014914883443364694, 0.08877640605093011, 0.041970617227977326, 0.03174036144158773, 0.05450156720114812, 0.05115781557716189, 0.08627606360542198, 0.01289875357366738, 0.04844749226204811, 0.011257808561617089, 0.058850602382012916, 0.013423259501465628, 0.03487488487735391, 0.018039777153922666, 0.04679930771911337, 0.029885015232608687, 0.018093822741760843, 0.06946379679345316, 0.04203578449725624, 0.047465424999714866, 0.01861163114588107, 0.03845109439064418, 0.012637897762620162, 0.050403073415040016, 0.028316448292424603, 0.04154914246511556, 0.15833646179206912, 0.08854706230903826, 0.06249619264816565, 0.038220590025547056, 0.030345933947471843, 0.026126635756583947, 0.019231294769974008, 0.11505861511273731, 0.09930921102603597, 0.009676412521531026, 0.02441383935811539, 0.04725916731742121, 0.10101590936462726, 0.07908416040722402, 0.024403064331460386, 0.03296484765146048, 0.07072606454453162, 0.02738196658150804, 0.010553320809718101, 0.024152699136926283, 0.040786988402326266, 0.026246829206244122, 0.01450200514462326, 0.05026961706819073, 0.05051971796239096, 0.04993765967928114, 0.02553856942892796, 0.05123511384872179, 0.04055975140222619, 0.02203527233383108, 0.02628219757048834, 0.06526851545899146, 0.01399335244880809, 0.034464426458843296, 0.02492573739389979, 0.06859110773450906, 0.04378910694691924, 0.0622970940575244, 0.045594454427520116, 0.035710219489110094, 0.044566402737531936, 0.0340670183481228, 0.09201615357831602, 0.022085192538197004, 0.06968287495715965, 0.028465281939134005, 0.04887056814867163, 0.021847889142771883, 0.042717020523043416, 0.049376132552542036, 0.041870079679234375, 0.05038872841865786, 0.06242559764594321, 0.03829994524318365, 0.04829221773111532, 0.010406321943587354, 0.046492895532038905, 0.022862547700623834, 0.03534043650893915, 0.06457204960526959, 0.06934827073447167, 0.0481561949897197, 0.017588403894596042, 0.028306881769470153, 0.08322881099077002, 0.04563285458472468, 0.03355536737569398, 0.032149228312435656, 0.029132670925689802, 0.10290273029597537, 0.045219278188362244, 0.02921624154212975, 0.0349987689555893, 0.028163740156038154, 0.041416590102016926, 0.027403830730867003, 0.03363427826233449, 0.021549158902358145, 0.07540994909622016, 0.021119017769852956, 0.01978922702912842, 0.03236208201175736, 0.025116093006105195, 0.020445875462985808, 0.04544178076509026, 0.042119146354736826, 0.06631072445382034, 0.03513204527177638, 0.06403750409522364, 0.05041796999472765, 0.0075626117083424284, 0.02552167335975795, 0.03518878174344859, 0.04658516699207887, 0.03583874989060625, 0.03346504560942131, 0.045263895149072336, 0.03425289043075135, 0.06680728732458045, 0.046276422067274975, 0.0437797759960015, 0.025229050755320538, 0.011846669705494518, 0.02867088653147221, 0.05106201628223062, 0.05291593373723088, 0.08434313184191143, 0.04101524046892601, 0.06417970150528897, 0.0425288999723571, 0.06650934806994854, 0.024025254665062796, 0.02970384692983522, 0.040686780271390756, 0.08406933201777358, 0.040606858148690195, 0.03123267688938687, 0.04421834601089359, 0.023059457195021456, 0.08953834177866098, 0.05053865948631879, 0.007967979472596198, 0.02289889282697151, 0.047636863985849966, 0.03682553242411345, 0.016995009425426685, 0.10032581736243541, 0.03161575149504408, 0.021863655232253577, 0.06767949374813227, 0.030394425397858988, 0.035228752380897926, 0.0027834459286814016, 0.005072981087235554, 0.03623660999320207, 0.06217178888618947, 0.005684481086885376, 0.05701891296813565, 0.02950817466743531, 0.06890194024890661, 0.049129593967189716, 0.02241371976842563, 0.012974441145366479, 0.026283065165062586, 0.08403473548711309, 0.04329878769274201, 0.06927559197309517, 0.019899685416490804, 0.01914182144607748, 0.013324932116384228, 0.02847998891206038, 0.0986737717363623, 0.04943245916717476, 0.028354875262706514, 0.07208646815871039, 0.06123285237399321, 0.05416441573611191, 0.08289318021026351, 0.021372765242572755, 0.003616185417594088, 0.06252540741115808, 0.01123065840558059, 0.017047670309341723, 0.011648668535804797, 0.06282566408176096, 0.013066065261110425, 0.01697978342793161, 0.09552026272661264, 0.03063768321167558, 0.018415550941661484, 0.029198362965196855, 0.08299933701393106, 0.044641188240700194, 0.03897859189178675, 0.03545174142345786, 0.019784668805978952, 0.007464143554604943, 0.0300321692315441, 0.08600296092129524, 0.040074859880992485, 0.07996990360439786, 0.03320320824822111, 0.041959179535267815, 0.009060661691511351, 0.044993542720593756, 0.0750791063652404, 0.009120552530211788, 0.03470304752549818, 0.04630480945530919, 0.013551711378949545, 0.03139950785665743, 0.038263391357876604, 0.061402548510100574, 0.02329745773045767, 0.08576850737294844, 0.11165200597456387, 0.10093375409562742, 0.09118688638292013, 0.23129481461740312, 0.22020400652000982, 0.18127169399972887, 0.10948482750644607, 0.16374107420204148, 0.12539611363242711, 0.09344673084635889, 0.09560237203033702, 0.12105496915718242, 0.2744130009124356, 0.07539083520250936, 0.13464997312234295, 0.16345919981118173, 0.20517490894323398, 0.1194145757284376, 0.22572550862546892, 0.14285878909211006, 0.16998020150969106, 0.17661006430224066, 0.19951643031691352, 0.2343476596739023, 0.07815342486625718, 0.16481614070794276, 0.04839341028503353, 0.11486638833077685, 0.16767055367029485, 0.16756057408788513, 0.15165355507164233, 0.14652618988146707, 0.111731709762206, 0.16372078819380653, 0.21612795911008315, 0.09404841630208878, 0.10536364219602078, 0.0903757065234165, 0.1299711370900754, 0.1519452200661744, 0.19951521989799317, 0.13166460509021438, 0.11043165855470205, 0.06290446388565245, 0.2581078000366688, 0.16311377076612366, 0.11252415877196098, 0.12299441266804935, 0.14725971906896562, 0.1227982328723996, 0.1628262579681412, 0.14368480041382775, 0.122238299208543, 0.10003055941553847, 0.19671634831015142, 0.1528165837930095, 0.16525978222489357, 0.16181082374626593, 0.13149211273318337, 0.21321506299559148, 0.12886315944694704, 0.08440879323790151, 0.12901725037203682, 0.12795374413291294, 0.09812960416198739, 0.086624740863279, 0.10619807282402631, 0.15442242665636927, 0.10940968960283265, 0.1540122631817095, 0.14637520927334988, 0.14026751200998985, 0.12948899199405026, 0.20243658894492736, 0.13923876317999057, 0.17101025268916162, 0.10295972723754183, 0.109084056269738, 0.10575458452466036, 0.16366602822897897, 0.15136438752374343, 0.07988663750790781, 0.09898069720234602, 0.07495202003948151, 0.13017730667225777, 0.14352965228740247, 0.17232590144680393, 0.1718574693246234, 0.10014430815053564, 0.13088383892130467, 0.224067663713809, 0.13019010034059325, 0.09251021900244298, 0.1970859397683413, 0.23288009568087517, 0.26264426628908805, 0.10585138739477243, 0.1484144433972336, 0.13565189355323393, 0.0698410414700066, 0.23623991216863358, 0.26467954739928246, 0.1622192558622168, 0.13443693939235904, 0.212313239612887, 0.10511461765535417, 0.19711178757490652, 0.1500958072081689, 0.24552094479722364, 0.12624276336282492, 0.1322584764491166, 0.10269886663844509, 0.22858862434664082, 0.13310103526999875, 0.09955234435056487, 0.1207193383766759, 0.18215552963797124, 0.09731447894967372, 0.16201726912010103, 0.10781837176651725, 0.18223390043262513, 0.17071616685678884, 0.17257088104323035, 0.17235610063277906, 0.11044851248903621, 0.17354857777395558, 0.2056371817185033, 0.16559604885837725, 0.08676866580161356, 0.18988380929635418, 0.13730014704408186, 0.07979347355543606, 0.22864655591547492, 0.1438798004340741, 0.08367234525541145, 0.17371393019153228, 0.16644694271587557, 0.235382353346194, 0.17335570747813872, 0.11863583969252726, 0.07963860122066352, 0.1879396313621152, 0.06450941425658042, 0.13581182206830672, 0.10007732142243655, 0.08700200852247016, 0.18968911571127756, 0.10978581579101664, 0.16390665644599547, 0.12620923169437917, 0.14874816661880863, 0.10807137996439012, 0.19925660393651456, 0.07756591969800573, 0.09756128183535992, 0.12396265587378895, 0.12342270944387683, 0.2792556265429143, 0.10816596117952179, 0.21355850021204642, 0.08614090271294118, 0.21036953665316108, 0.11458528768872062, 0.11471655685454608, 0.21209003223526865, 0.18635813477298907, 0.23994152644468894, 0.1253811825787829, 0.15337020489237002, 0.14430134797528868, 0.11993771418929101, 0.12138522200046048, 0.08999427134591727, 0.21937627916134175, 0.1458922061588495], [0.02519256007226725, 0.07210480830361767, 0.07302766079984366, 0.03674670963758423, 0.03552824679401613, 0.04296345951696558, 0.017206036005048983, 0.013665440961748604, 0.009748350092840773, 0.0430002240764518, 0.05276024168837936, 0.04968454422909887, 0.02696524347899662, 0.02437723759231308, 0.048666045655526464, 0.032267964279819886, 0.04436418233859924, 0.0451123169923742, 0.03188227922956069, 0.09540118968054172, 0.047499960243341424, 0.04559709360041926, 0.050133211282832976, 0.05689361162724034, 0.03272971994574032, 0.03261706671647487, 0.0750320379231726, 0.0718030845746398, 0.08781901831107755, 0.06592323718171927, 0.036894794433347644, 0.03844226522731685, 0.0618602209273846, 0.02536939614782891, 0.03461398214342133, 0.04916265449156204, 0.04522896537016477, 0.04355901626930122, 0.024744645699918754, 0.0460965407922143, 0.049256634327673146, 0.013574674864479852, 0.07656168568158343, 0.0665847617652147, 0.040884618647396564, 0.06048838728137555, 0.03650693943904292, 0.07340449944979723, 0.011832879165247565, 0.042212015363357724, 0.035902124514142354, 0.04806949298888926, 0.059407230376476244, 0.031072459176122665, 0.023728058515717427, 0.05813082830319482, 0.057234647158052654, 0.041144253505814465, 0.012262814411623104, 0.0301728593636184, 0.056572777834991296, 0.016141819219375332, 0.03438361567415057, 0.07242730067622277, 0.035416417109269294, 0.007222161755987233, 0.03978655035156877, 0.014383379302378145, 0.032996816500540704, 0.051032970058581525, 0.0681494810287991, 0.03528004962830775, 0.017936010544578877, 0.04528386706125833, 0.032312347583713076, 0.008221123172270675, 0.030449317512853496, 0.03638996547388454, 0.025203505553485408, 0.04626706813371951, 0.0827343778444394, 0.0068480034561587445, 0.11338585446919165, 0.006329321232999886, 0.060367284102305296, 0.0564167142334965, 0.006631883349449885, 0.03715041499104231, 0.010880275644482145, 0.015789576779840695, 0.07166920304899255, 0.04304433924957149, 0.02989458558600276, 0.052542508008979985, 0.031471054723125794, 0.03249746890017583, 0.03701649899143846, 0.07586191032802866, 0.052453898449218085, 0.0664187428511439, 0.03356791206545407, 0.07549644808375067, 0.011425462115796344, 0.0785278043739738, 0.06806535691383385, 0.019985544720604535, 0.04610455024146265, 0.00370131406535004, 0.04468977353685806, 0.007674738730964883, 0.06368496192378864, 0.08033950272346697, 0.0709697341306075, 0.043783058682757045, 0.03638700071361758, 0.045626021080440095, 0.022921193646447315, 0.014127689796770293, 0.05956679883022463, 0.010484985766872283, 0.03296267579219515, 0.01381463754261213, 0.03895327268588928, 0.023746278001776627, 0.036265119955304174, 0.06683861265980429, 0.0747691088866803, 0.029768876303287766, 0.0737001404406563, 0.038648580366204825, 0.006670451567192833, 0.03893237380731491, 0.019638344097221573, 0.018454483529973417, 0.03804435149856633, 0.021946873448248354, 0.06451889076420377, 0.01998464839773313, 0.044419091690572045, 0.028109541350615122, 0.005038228466160475, 0.057928381908324465, 0.10272220933749791, 0.02718451507990399, 0.05228049061711758, 0.0471123006014574, 0.05005088747448979, 0.02400147721111294, 0.0683718380488215, 0.02878036432629151, 0.07415987746489626, 0.07104828878636323, 0.023461741455379995, 0.0066293849452068255, 0.05801233748394636, 0.02102761773482686, 0.10737957192524787, 0.06940188156741281, 0.059349838899628776, 0.042547925765956604, 0.027359338259444605, 0.025410975569919236, 0.04560557419374105, 0.030886782445914807, 0.06676060958735405, 0.060314450848607294, 0.08311870883429244, 0.07463747199865119, 0.07568925709253357, 0.018678102679851077, 0.06010672227749902, 0.06488673554192628, 0.0376977656607426, 0.04910069713068586, 0.12378175187134936, 0.030977621321536364, 0.12735789626716607, 0.03881957885178347, 0.06494278253446664, 0.07791369297211209, 0.030591945847376224, 0.03040457031719627, 0.023933613312340552, 0.015152273981291202, 0.041261648819331205, 0.03332673609557171, 0.02475769026204944, 0.037922463079373685, 0.027802481819244645, 0.04898271575990704, 0.021918518618950923, 0.04328200653676064, 0.03299936757332856, 0.03945227937712785, 0.052455411472868536, 0.043038428881235664, 0.05705040684270282, 0.0033745919297929975, 0.024185889896245736, 0.03438410213998249, 0.028434632676503355, 0.015934091605876964, 0.052460038643931194, 0.06955433306434462, 0.049258235451434894, 0.0735909499288086, 0.06509463648281752, 0.05096395702792272, 0.020859536129019914, 0.029210195193187367, 0.012983056761684918, 0.10352713025866017, 0.09214870977185427, 0.0546276844256828, 0.02390279359514675, 0.056169371255823684, 0.03847159107305831, 0.001744629626045935, 0.04399911079916262, 0.09559518612560727, 0.08674913055954442, 0.03409699919903952, 0.019033693881224722, 0.04369013604798144, 0.08190023066896586, 0.022990354149031545, 0.018908076529060642, 0.03561211809996636, 0.057335786085816166, 0.010996754525319464, 0.02627151830482387, 0.016469134115463784, 0.04936594358314911, 0.06807142433019416, 0.0395135510893118, 0.04146913607274333, 0.008426378236993427, 0.06651204469944201, 0.06422746708736786, 0.0503298890356335, 0.015016411160749775, 0.07491614414198745, 0.07232127410750236, 0.04896472418500532, 0.0910738577705718, 0.0576711334137907, 0.030352692758183808, 0.05621427932994501, 0.02510182844895509, 0.02674178712280287, 0.02309274563055125, 0.05061906041397203, 0.00220520994550879, 0.037214096049748124, 0.04276976567663012, 0.0027030177091458634, 0.02016361419772429, 0.012401111476543932, 0.09213056880980731, 0.029915796645406275, 0.07569369274161517, 0.07409748726434286, 0.05226245307694039, 0.014164709080491337, 0.028538740194973447, 0.017161283063732328, 0.11571019587497558, 0.09715511733966489, 0.026417904300615195, 0.059865711016520384, 0.028890688648267143, 0.06440185551201144, 0.045799053529457706, 0.028813541679072286, 0.12438020443603878, 0.014847547187650157, 0.09051046138929744, 0.05721789281514864, 0.05321309158218004, 0.03251733739049204, 0.028569100259412682, 0.03441112589151148, 0.045697665623118805, 0.03979597323303742, 0.024762032065360297, 0.01443646728031097, 0.03530941377844542, 0.029507092568242264, 0.04054850140105813, 0.016633111405216398, 0.03679407302350287, 0.033791280321536526, 0.02534170015414636, 0.05870079771885949, 0.05556810714845216, 0.03979907205869113, 0.026272196292636857, 0.02531970385462046, 0.04752537137978981, 0.022054539445126732, 0.047429077958147374, 0.03948804036143326, 0.02311188250689978, 0.033562411554157734, 0.07743495696734998, 0.0376500690265769, 0.00751337475864397, 0.06142603676585902, 0.04057501570411748, 0.048210292288492766, 0.0429965736674926, 0.052742357365787036, 0.09620188179636195, 0.019504682821852547, 0.0260199599283477, 0.0355813596698065, 0.03537961424538686, 0.04148717361292051, 0.025854015707849495, 0.03976592343420752, 0.04697478015816981, 0.06855443510557375, 0.011520557567447184, 0.06409919715576595, 0.10347099899644814, 0.07388335036774797, 0.06089522210400432, 0.07444365941468747, 0.036017355629273, 0.008783419259763774, 0.008593952309550538, 0.03761732642869315, 0.05225813617148707, 0.07976039387886563, 0.02677177946503845, 0.06264793168332788, 0.03778096280931946, 0.051730952766393466, 0.015838056738908975, 0.019705821121592196, 0.038423511394930464, 0.06718427153123964, 0.04341181247465072, 0.03466070967636282, 0.07816360617477087, 0.040793729976059935, 0.03033444837426707, 0.026927835405654004, 0.027514066952731342, 0.07381179775562018, 0.058510340600004124, 0.02264593442481372, 0.3496168493743866, 0.1429393508982274, 0.15696084367171412, 0.14297259911414117, 0.07432136113845533, 0.1341439567265972, 0.18048577971996801, 0.20857892870422334, 0.15239471449486672, 0.21038959283501873, 0.13435280761651455, 0.21963544670612584, 0.15995862232821603, 0.13872134739593153, 0.17517924188606201, 0.1436943305476058, 0.19704264047886097, 0.13867014207907263, 0.1772002890826233, 0.12142627665232267, 0.1703256918417831, 0.14910401445963692, 0.12464943071526867, 0.13663466178601788, 0.12205482115067783, 0.1580772023167341, 0.3278495641725679, 0.3608542867004872, 0.2419835950938925, 0.2820930936403813, 0.17613286813420637, 0.1331515511077258, 0.11311598467610537, 0.17786578966244576, 0.11469022641258855, 0.12692645853084902, 0.15564611421958094, 0.15734275382372642, 0.14568517855819196, 0.1786011268174456, 0.15752053218743495, 0.08874353321809923, 0.24030842127338534, 0.28565662822896437, 0.1497411544645025, 0.15641191103045018, 0.09598140935263327, 0.10137988539833216, 0.24529491821604393, 0.11129822657113114, 0.14972733423834847, 0.09427942245477632, 0.18633847695685204, 0.1674088886788776, 0.1558151285374357, 0.11948477236493943, 0.12326483404444111, 0.16191328034525918, 0.12564669333158002, 0.12331701229296385, 0.10081175459368576, 0.12671524042924567, 0.17552287828537727, 0.17318467068816387, 0.18317479429946792, 0.15481938277521443, 0.10232850909233095, 0.1135644065817037, 0.22729148427324913, 0.13360547352462046, 0.16070502179284252, 0.17142937939253547, 0.06592179693642163, 0.1420145448777945, 0.19134840086823512, 0.1460514911600659, 0.07353537024990206, 0.1912923998409702, 0.10624625975446356, 0.11393644952125127, 0.192433993422216, 0.0925551960244775, 0.17495234196464862, 0.08467605833204524, 0.16712805616759485, 0.3107170496256121, 0.1450826197622284, 0.15916506249097087, 0.16425792308103654, 0.10009226779783927, 0.1845323327448099, 0.22002043653159375, 0.08988917174358522, 0.24239259411490735, 0.17484614685658487, 0.11789490243480091, 0.11507373768836261, 0.14889856500010337, 0.3352379612624646, 0.11622211114773828, 0.29065792599032003, 0.11343640861131492, 0.10357297296004911, 0.2724346861002907, 0.14186538755893707, 0.13962741490573655, 0.09410964204899727, 0.1037646864631003, 0.10440253892973547, 0.1288052891651469, 0.1667426986199233, 0.2443354390561581, 0.18071465614822604, 0.09130726943934157, 0.14940019937292223, 0.10509712786804284, 0.1803142526337216, 0.09584981842987961, 0.2014863947706838, 0.09795922620762741, 0.1125387297642808, 0.23424362493378503, 0.11759897799140985, 0.09269918991072525, 0.13375633155866978, 0.1701091953943814, 0.16021831081278864, 0.08814098208301491, 0.13199933954784948, 0.14127268065367976, 0.12007430000531098, 0.1593828919313608, 0.08098087919455382, 0.10559693129072267, 0.13464231224310014, 0.16983075307742243, 0.1828633795582479, 0.15276360115216625, 0.11355048676411952, 0.1758691959924275, 0.20233414766769256, 0.10282179310677514, 0.2308071077230477, 0.12004971624382081, 0.19191840092741674, 0.16584305092692375, 0.14244956024471792, 0.11835060983655915, 0.147936481141275, 0.19344529076930017, 0.2465716497071328, 0.15877645673050036, 0.06352594888378536, 0.08068737558900349, 0.07176836546991142, 0.12285864656610836, 0.1843542939112071, 0.1923540598081966, 0.14335826309698244, 0.2046165380987429, 0.12137683333768962, 0.12549321527682966, 0.1409462046238684, 0.0978386133248287, 0.134568476688958, 0.15228612919247922, 0.18954188893398932, 0.3288896051385711, 0.16182115061148522, 0.07344992846370706, 0.10387448218440819, 0.12292523492848682, 0.24264570956508963, 0.17989016168059843, 0.22195247963311213, 0.18859043837554995], [0.020113944887153564, 0.07497142504660353, 0.11446528767626132, 0.04476137977514056, 0.03300327845218201, 0.011768259648834507, 0.014152574247770734, 0.039392191270786914, 0.02217313368624497, 0.03022183344939784, 0.07517584028743929, 0.03150491580937899, 0.024520921212951505, 0.07950855779551691, 0.03677097164214619, 0.05906850843119526, 0.043648123786213903, 0.060039080544224674, 0.07360425687605336, 0.014304751868269617, 0.050153045299192595, 0.00661582327372725, 0.06804120982246054, 0.02799210581748236, 0.02724223788977871, 0.014285750972527652, 0.007150057081749002, 0.028494816543834827, 0.03266485145075187, 0.016178129871766415, 0.019478921200178807, 0.009293828212145356, 0.03604205047351218, 0.050955679447900866, 0.0577047799954251, 0.04554236427910867, 0.02311087510127935, 0.025426714846323577, 0.04009094389696275, 0.047597916075779546, 0.06554450629459274, 0.03680616572138764, 0.07176568416217644, 0.015127009359158337, 0.05862982350311453, 0.13027962537542467, 0.05928901534888053, 0.04460711648026782, 0.031374667455712636, 0.07618965806379434, 0.03925430310529567, 0.03942203805631688, 0.07827171650264533, 0.018454914454430826, 0.011394180830628162, 0.053451084456737005, 0.07110100329643296, 0.042617501871239756, 0.02401488949544728, 0.05010409994171031, 0.01169991981793916, 0.022914160959302418, 0.016677238069654956, 0.03425373312746806, 0.016065201808458135, 0.06638924080517984, 0.06223655395930814, 0.060636441433622, 0.07197042115994039, 0.09376724671211936, 0.032613768707960844, 0.050426711057943684, 0.04634437023571903, 0.019518031903933135, 0.08899577532804782, 0.024728780019006903, 0.010795360543735085, 0.0222900444491496, 0.021257421129473278, 0.057390703098668214, 0.04775931547966696, 0.013738996893798393, 0.040711164850020604, 0.00977386943920846, 0.01772837773446114, 0.05761658795358193, 0.02872795242095186, 0.05668900869486313, 0.04792053102245254, 0.0848415639672068, 0.009331202769141284, 0.03783986347937777, 0.0491280886044185, 0.02971923189057458, 0.026252530815620578, 0.04272711373144581, 0.06359855869724866, 0.03457203882956698, 0.06803838295801994, 0.08310550913935708, 0.03540742323703824, 0.05522286579493554, 0.1369153104361988, 0.016923669402697877, 0.0352230028910262, 0.021747625470461867, 0.04488467779611388, 0.09702898096293212, 0.01376902275238066, 0.06872589324390696, 0.002256812670478417, 0.018233838716461774, 0.023678820129604112, 0.02356783888723341, 0.01947679722140874, 0.025622469463175344, 0.007861311784044148, 0.03171807211343079, 0.037720261832639095, 0.03353449914063658, 0.051999428279457555, 0.07564898385035415, 0.03446754443669512, 0.05464598626619386, 0.07013157265441072, 0.012248418661915969, 0.014976389769975458, 0.0984057788586905, 0.013481285873680346, 0.03807688725271052, 0.02467446821561504, 0.05693684962968673, 0.048993835526127974, 0.017602206883771766, 0.03612642356705281, 0.015320096074813798, 0.04284232569437835, 0.055794539756231734, 0.008666625325267595, 0.030598674014571215, 0.10533792462440268, 0.0698990113432369, 0.02594601520667634, 0.04353667331498958, 0.06287498099188651, 0.05283270594513705, 0.04127665265132824, 0.049436101915254715, 0.03002541999693119, 0.04404417975174804, 0.033083652566757896, 0.03826362501469351, 0.01703804824501276, 0.046281838308899634, 0.018307586170492635, 0.029152181269901416, 0.01884525348883002, 0.01371661946553016, 0.014410698955367892, 0.06554535665218869, 0.013335196736959681, 0.024815884215997595, 0.07628830720580394, 0.00785785960033536, 0.04704243338276302, 0.034985021507788094, 0.0077453998082707975, 0.04582320062083103, 0.019785950088032314, 0.044206054130148505, 0.03205057725520625, 0.10114032970440966, 0.01164620269029852, 0.02000309196451018, 0.04741241554579428, 0.024851287054198406, 0.034027511193867654, 0.04234018953396909, 0.06673876842063281, 0.08171753402078345, 0.004957150987109109, 0.012549252771291763, 0.0583184777098077, 0.0412472042315189, 0.0614439134275721, 0.0457045910579543, 0.02383530124901764, 0.024554090904853037, 0.02081393666054693, 0.030770925053906058, 0.021896474438929753, 0.05380424332895106, 0.012730643239563272, 0.07017224426231078, 0.02447226313844083, 0.07496188725194625, 0.03118804460691829, 0.019069514237344265, 0.024724752311745, 0.03642725863403851, 0.014197999431240945, 0.03194512908286866, 0.031175923180736365, 0.017209973696979786, 0.03325957316725004, 0.015964460288805347, 0.028349169822890433, 0.058319010140915076, 0.04587326446668275, 0.05830530099751008, 0.03674182582706694, 0.032872273586690426, 0.008011984041771822, 0.06797286711873547, 0.02004654255635556, 0.04718128681903885, 0.06868395759093185, 0.043909719829717954, 0.0389311557275153, 0.0432591617948586, 0.031115032597294742, 0.08711947278390009, 0.03809923020702216, 0.03949177120962451, 0.022919581031366702, 0.03658814475901666, 0.050384488121996966, 0.045175063423812396, 0.02082013814229398, 0.013822557934139286, 0.03677670197981981, 0.04085072308718678, 0.09942972431740454, 0.02516511114194028, 0.09054992257827714, 0.11974017075713604, 0.04505957183878749, 0.03485076459905794, 0.10939596130722955, 0.030053843774141806, 0.08099341239299505, 0.012157185251013407, 0.06750530833678861, 0.097356230741547, 0.07731184663791811, 0.010085461338260963, 0.06569401601389532, 0.04642412381907625, 0.03036463989936296, 0.037762837169030984, 0.013350186204808134, 0.06507206753256821, 0.04060110482837885, 0.03964030033638401, 0.09464928204373968, 0.013981893688680665, 0.022210920973110105, 0.03724096658369226, 0.04689119230475157, 0.03798884459801259, 0.017955783273904555, 0.07309807194096428, 0.019781037549217863, 0.024670402203956922, 0.023850791546846592, 0.03663841544860794, 0.04715684861425431, 0.07285373585839426, 0.05344125937910811, 0.023985567480145444, 0.011152697467966186, 0.06370550457147822, 0.07925561854555722, 0.03169271077269749, 0.015438599342991029, 0.11329252963825581, 0.04114121213675507, 0.06007760710593674, 0.0628516765972299, 0.03612780635575614, 0.035876694225495866, 0.028791832662517988, 0.01022370477702709, 0.023274720240865025, 0.01813516084615502, 0.023424925184958888, 0.022396337233423706, 0.011333452083260543, 0.061383664442767064, 0.01597744835195162, 0.05677044767165377, 0.008180421878463559, 0.02319934676521488, 0.047817622431583946, 0.05274817197313232, 0.046195488708514365, 0.05661008248646414, 0.029260892976796436, 0.010658339972818091, 0.07280275270703339, 0.025107664123718298, 0.03991179806630939, 0.020618404209193204, 0.060972171805558674, 0.04511166964807818, 0.022049029357731346, 0.027859189562619697, 0.0904154358431697, 0.022846592004380883, 0.046530230827028715, 0.04803521438471733, 0.07987456396222115, 0.021710968163285046, 0.053062425070111795, 0.07409170330051454, 0.026632671304527792, 0.035986122224600084, 0.01343873926558562, 0.03174215025689093, 0.040837783862145684, 0.04930685522154935, 0.01726144522939238, 0.0762705263050814, 0.036299996108057044, 0.06935576307437114, 0.02819461924504609, 0.024675540738709034, 0.005768077558792767, 0.017993503528076316, 0.06179325335148362, 0.045494169687792185, 0.022580589040092403, 0.04340043606897516, 0.013010407058191637, 0.04271659534424544, 0.03464926432277407, 0.0359899181902649, 0.03634758165947372, 0.05221900440031483, 0.045305712058419184, 0.03248851333234099, 0.046072558409744696, 0.009376152020488537, 0.027396529912948612, 0.03033652638776168, 0.02637891425570894, 0.051599706583205736, 0.053513060969811295, 0.07792393556765972, 0.052042137681236195, 0.027277068077256123, 0.05238479348800836, 0.09984759463658256, 0.10920660735498514, 0.23930320666441995, 0.15605716635623287, 0.16350174833449627, 0.08039014879614115, 0.3186654569881578, 0.1145709848271743, 0.14991804416621887, 0.15655811124991986, 0.21516962908208373, 0.15847869367609102, 0.11414572175952697, 0.13518801199332361, 0.1085152666294767, 0.14166841103184608, 0.11540116366720009, 0.20627108883232842, 0.14739183859238703, 0.19122293098799645, 0.11344556336201007, 0.15970965907458337, 0.1548576258843945, 0.1145900450947304, 0.10655562904092575, 0.11057967440255227, 0.12028482862778249, 0.0888300781709052, 0.12494651961230463, 0.13036905847970517, 0.13340975338172528, 0.10092229342028018, 0.18163544786793573, 0.13146732212795367, 0.15215483704401603, 0.12922142812561604, 0.17211240806406544, 0.08856247599807479, 0.12280422367996748, 0.14316333968552852, 0.21361908244509853, 0.16279852558528224, 0.18958095941812764, 0.10596538127790536, 0.09789904234029594, 0.21867006866922303, 0.17724731155941564, 0.10470189544702731, 0.08510900526157311, 0.1462899743308944, 0.08263778181806689, 0.08448894135653974, 0.14821979577743238, 0.1398518939893092, 0.3071566406757601, 0.11567410547286273, 0.13736531048292114, 0.14520062794608457, 0.1841982418010312, 0.29754220658252317, 0.15648527161007927, 0.10998237863062851, 0.20458499059802104, 0.1297043086660485, 0.2245028169765588, 0.18624496826481435, 0.19722179780083318, 0.17126791870161412, 0.3362948561628019, 0.13105919644717248, 0.12340796991221367, 0.16524916424626307, 0.17894064166372825, 0.12238590136891413, 0.23651763436294373, 0.14523916216867586, 0.17910626987295766, 0.16467761668947437, 0.19010214435477413, 0.25515060871839523, 0.21980482874618423, 0.12724135897212452, 0.14319081159849323, 0.11564092620486215, 0.1956965780306247, 0.20487639512265884, 0.1507891780666767, 0.14038833939740736, 0.11686135023351639, 0.07282390439462277, 0.16642080379589913, 0.13086745996148358, 0.10298367514605485, 0.09322187637970333, 0.11378080343767522, 0.2027006900959438, 0.12816451024264097, 0.18441492210953467, 0.10132205342092823, 0.25504304997382626, 0.06848613836712415, 0.21942270408955314, 0.2837328895205452, 0.28047321604624875, 0.1023323854972278, 0.10512796290699514, 0.32102467071625496, 0.13959611255315044, 0.12831158380234434, 0.18401430409041145, 0.11285333143126582, 0.18434972802717842, 0.20767903586308803, 0.16955802577637857, 0.12828799595515575, 0.1297302177596477, 0.13083565199086744, 0.10198744674844128, 0.13799146478695257, 0.1381856067887237, 0.13852147505648676, 0.19549555655929352, 0.13789725129402455, 0.15510298852478305, 0.09149823217622696, 0.0985620761170022, 0.13902074987849883, 0.2359824453390414, 0.19254495359716878, 0.10738313423409578, 0.12903801135478482, 0.114988939416024, 0.12517825354852025, 0.1752396249362538, 0.15840029223792015, 0.13117230166831326, 0.1608895417302847, 0.23901718007701062, 0.2448507404375461, 0.06878393206505046, 0.20337238066619445, 0.12890524831750702, 0.17728507969408266, 0.0879643528511928, 0.17277217830621427, 0.13189613218269042, 0.12237428747598203, 0.15683028696765824, 0.20042006166711931, 0.0872883185624115, 0.13439262886681866, 0.11591099518080873, 0.1510159247705052, 0.18048915050683484, 0.09637144003664294, 0.10107004113735692, 0.13632422763734095, 0.12434607521901209, 0.11438474885278171, 0.11365481261764804, 0.09769848818259855, 0.1321199677524067, 0.15641623176634312, 0.06286796745693972, 0.10645131084827647, 0.13417689850734127, 0.08480206447383089, 0.11134960808821263, 0.11891838824076038, 0.10279401475864072, 0.16649575783841072, 0.14803147604388578, 0.17568473734201925, 0.1267911674034211, 0.17742234732835524, 0.1462136413301191], [0.024357891957005186, 0.015069489562583548, 0.026392784277578036, 0.04103074225807383, 0.06724172046468144, 0.05077185282003015, 0.06153951737008268, 0.040277034314649726, 0.05563558417282278, 0.027683711377903823, 0.03938074208675854, 0.03370972643155725, 0.022582232298689987, 0.018494877431000915, 0.045114431395045215, 0.026328785292383645, 0.03189220772905937, 0.06323429155013253, 0.032757797068165194, 0.06172554650073571, 0.05931856336012002, 0.059237220144319924, 0.03564282290397152, 0.06215427994668003, 0.05500591735565855, 0.04596673102388459, 0.06493639336117814, 0.061867537067061475, 0.032936402806831945, 0.0838566430273556, 0.01099823594784304, 0.04375947849644769, 0.026045620043371475, 0.015194545755343092, 0.015579209993443182, 0.08191531494019494, 0.010590099733352903, 0.07722396869212389, 0.05006848834455014, 0.02377894590608776, 0.054221389695040645, 0.018676763941203395, 0.03951702529804842, 0.10030313349899747, 0.01815614590962087, 0.08326442641836983, 0.015581800328237156, 0.04029934279500477, 0.012805137629320305, 0.03312469572730122, 0.058378945029671156, 0.0225149946767957, 0.034502956850994984, 0.0824881112203002, 0.031259018822663256, 0.02990141717506753, 0.08613088228289159, 0.009169168469886626, 0.04442467264110043, 0.05867881865631189, 0.03482255341124631, 0.022734231803746476, 0.058729813298991615, 0.029717222824993155, 0.048226077530172565, 0.029547595636798974, 0.04803674273012627, 0.04446897167532195, 0.01853856742532263, 0.04896840140704186, 0.0561617142070205, 0.06578499661578287, 0.15820158435212028, 0.037355443102217493, 0.05968910476733601, 0.03454888765249522, 0.07451002561156789, 0.04479827073913428, 0.08759696006534562, 0.014863525866530837, 0.0692995245598497, 0.034083554355968396, 0.037208204833610405, 0.03602169934780367, 0.07415475233668282, 0.05986939206899655, 0.026241131427307284, 0.044435957116225076, 0.07156904471377212, 0.03371900758675991, 0.050416705949652585, 0.015175166603688513, 0.07300987989912111, 0.01068751068575488, 0.038352000917638504, 0.04404115753488676, 0.0904694143983145, 0.041627367703063835, 0.04374264754475125, 0.05224059275802105, 0.027269501043784044, 0.03338011327169595, 0.025665900902822617, 0.06731433793902397, 0.02722570188193312, 0.025897544823707114, 0.014543172794454282, 0.00938013472008489, 0.0165788647192981, 0.042348401996517376, 0.006063787018760078, 0.0805379884437688, 0.00955759707252465, 0.03920371448921581, 0.0461375264961633, 0.03899440777698352, 0.01579611342505462, 0.013445924212705466, 0.056794380258408286, 0.03747686803821595, 0.051527016330510385, 0.029535449312759504, 0.019223526638421803, 0.026371387441852884, 0.03821778231330457, 0.04577203743880795, 0.027957356069236997, 0.028264302602638642, 0.024596147216676224, 0.048611029051244266, 0.046621360816061504, 0.04809922869167021, 0.05336961866686902, 0.01195773138709727, 0.01111262628147679, 0.029918843760125102, 0.058660110789200956, 0.017846006704794786, 0.06961477740157036, 0.01832469099862201, 0.022013523097660755, 0.05113125530882709, 0.02633183049188266, 0.07351204287260771, 0.06762393705186344, 0.08244412245168802, 0.01720058528946773, 0.022581730511099584, 0.014108811475096211, 0.040463258797723445, 0.04598701703211954, 0.030611318295761466, 0.02328636477731409, 0.02190949793364252, 0.031989996937373956, 0.09157310960994614, 0.019561951724632133, 0.02155504054239681, 0.06499316047636733, 0.03852587606337282, 0.05364431098343865, 0.017173573029257597, 0.021796733621628057, 0.01005690924132303, 0.040622888538505764, 0.013302996146282362, 0.013848241031800788, 0.03492665709927678, 0.038233372202563676, 0.043211526447726835, 0.04954815759593922, 0.06816527010091851, 0.031043077789006696, 0.019147593918586933, 0.004474148351413709, 0.0068972040166808, 0.003846151127119459, 0.0706301350146532, 0.0201602510717367, 0.027953180890049667, 0.020801978028048913, 0.03851583648112513, 0.05403200126883965, 0.06110611461823987, 0.02405832285031436, 0.09705007136348756, 0.05110061945273511, 0.04436934194076927, 0.07860519457608461, 0.07081660847630232, 0.04952498726666935, 0.05011101388522694, 0.046533233891691894, 0.10135939254635766, 0.02939853599415191, 0.049661090447297024, 0.07094799255531642, 0.05230235093603692, 0.038804011945162094, 0.056606474212340774, 0.02297192590401298, 0.04155048311898305, 0.017952433554455638, 0.04817424019077613, 0.0334674779385809, 0.055944593397960554, 0.03347224683590955, 0.0761204420198356, 0.10609348650060355, 0.09299066338327625, 0.0376928435458291, 0.02763301933995418, 0.04620368584930416, 0.0435349764302373, 0.10872246276947761, 0.023546934262999607, 0.03271427944362645, 0.02035940903419208, 0.024421147836913026, 0.0540043952904882, 0.033152121674990466, 0.04930746043100954, 0.05065598202148273, 0.048868135819512035, 0.014269105797152848, 0.032244039353944605, 0.0016065718439002073, 0.002840545813312694, 0.07165684605077391, 0.0790874852288154, 0.05935573011576649, 0.027348804550485748, 0.024142077327856136, 0.010060296307558255, 0.006474692162291538, 0.030113089183766036, 0.013119511385147851, 0.04619648462281593, 0.045791649289669535, 0.04159026989533056, 0.045080367295492085, 0.04891026299446822, 0.020242291427547895, 0.010444404174303337, 0.04126507706279236, 0.09468629941224091, 0.05120454311010338, 0.02579379928178124, 0.10445198224436854, 0.031018607025485367, 0.023575775558128956, 0.04046873632638205, 0.057674933209895134, 0.05007567807971951, 0.016148173918707237, 0.008820737317775287, 0.03445657405761942, 0.0024724075281541916, 0.049719657869108265, 0.04705378680580086, 0.04104962632540734, 0.05058791127897078, 0.09643857998232688, 0.04979155905124161, 0.06049015311404102, 0.00634915572816446, 0.03079857508231315, 0.02347275779973115, 0.027676625064604228, 0.054027404741293965, 0.01195363664714199, 0.03916665881631836, 0.016597668347399563, 0.03373509926360942, 0.08171008764615945, 0.07616329697831985, 0.0178074226864884, 0.03806001033573862, 0.06079943046995229, 0.06438614304868445, 0.011767219684477295, 0.02439681688443788, 0.018977985882590857, 0.021093495550655553, 0.038518234336328123, 0.06712768061627304, 0.026391956902619813, 0.053334796140270854, 0.032460757966844306, 0.01986249759342642, 0.0715038046661404, 0.0210247966160457, 0.021547410306670976, 0.07467076617984042, 0.023726602948661295, 0.024011185460333383, 0.030471913276180148, 0.08379842034511029, 0.032773911727652434, 0.025910279120228467, 0.03905326248176637, 0.04979511752964989, 0.05690261699079026, 0.048911745374601696, 0.05747332568130186, 0.04192658249408968, 0.03946121196232496, 0.05985279094367739, 0.03696337079388961, 0.02266227508023862, 0.047240796528996966, 0.013676575092118115, 0.07592896600404093, 0.018407060772240646, 0.034565167020886176, 0.02827127974840903, 0.011769473898194492, 0.025175416939741662, 0.054673377739926504, 0.05914262743786939, 0.07215626642949159, 0.0034180188207932178, 0.04942410114792086, 0.03336112195205304, 0.03904905282862244, 0.030795882283259305, 0.025548503674086065, 0.04260851565988795, 0.04094741104411022, 0.08622325716480132, 0.036336875580731905, 0.03457131487647853, 0.035312160203653964, 0.04402699256916681, 0.07397849082706437, 0.05491055856128374, 0.028950621621803414, 0.01796136613965275, 0.015592390536180428, 0.05258601031176025, 0.014839187253176447, 0.04182832022648185, 0.024795734188369205, 0.061672897108139536, 0.022646353857952262, 0.0570734890718614, 0.009631013193528258, 0.030441899866526647, 0.05637159931563562, 0.0763743695232176, 0.014768743553319046, 0.03196434256800961, 0.13439394653804843, 0.13593297121265244, 0.177374696659465, 0.21511368934185277, 0.10108375411120155, 0.12002156251260351, 0.23527721543946575, 0.2466932431824746, 0.12291781153650054, 0.171911662384387, 0.21258746844626245, 0.13257304747258464, 0.11501573717161534, 0.21338395473937835, 0.13657680682597623, 0.14387521922828692, 0.18296310888423076, 0.17861919117070016, 0.09768371800741843, 0.09334718538147789, 0.17051817909363778, 0.17157973180855476, 0.12335818185801468, 0.15435038374796992, 0.19983994924733717, 0.17575628995414705, 0.1344168372452259, 0.14665242584963, 0.20451659426814128, 0.13490330307714402, 0.17954381333003122, 0.17261551332569894, 0.22828139244548737, 0.19809184385643852, 0.12207096262324242, 0.19275133768396993, 0.07799645345057211, 0.12275782173439381, 0.1981478755272204, 0.16165127827515527, 0.18894757324409103, 0.1020457613612375, 0.12548957635918934, 0.1603008797692676, 0.16333798937980207, 0.18947179188891766, 0.08695881648529923, 0.1529253682782573, 0.07355250763676821, 0.11033071114891961, 0.1135074556054127, 0.1262500258763471, 0.38246391100748894, 0.1485347345231041, 0.10296192590988452, 0.17684578955654176, 0.26671283668087375, 0.054061576093156496, 0.1337597176672951, 0.12743395347628864, 0.15387220698739254, 0.1987975946958027, 0.12173558465175091, 0.1143765670337504, 0.11190545084255357, 0.12066807943366228, 0.13140252641131803, 0.10163488542480816, 0.09897839893857319, 0.16549780574296752, 0.10589527657195445, 0.2227975665441444, 0.22373698952217258, 0.13838224623712803, 0.17118334259477355, 0.11994423359752664, 0.17302655014059237, 0.14436525502993217, 0.15476974027772106, 0.09189495080781561, 0.10663141045839557, 0.12283861336688842, 0.1547858894111649, 0.20027925470663657, 0.1469410571359819, 0.1562135555450955, 0.16589853101440016, 0.12444962732373707, 0.14418583723806566, 0.0845164056086252, 0.10617819284239124, 0.13972761920623242, 0.1141207779367124, 0.13456933470743318, 0.16533001716579163, 0.1576864668318341, 0.18240518237073577, 0.09485143732519881, 0.17579108566766785, 0.13496164833345722, 0.09203019596996809, 0.1664499917458142, 0.10073579697599334, 0.2037336983748021, 0.06562336738551817, 0.14586713976196705, 0.1223958298684128, 0.12390401950406453, 0.13475285873057383, 0.21464343393041244, 0.1516896837781514, 0.22228367476453706, 0.11637641657744685, 0.09291318891149375, 0.1419140034986119, 0.13074670918285847, 0.19429304366630895, 0.18574305810034278, 0.25895662545677156, 0.11538961106130194, 0.11370922784290968, 0.1439876656138128, 0.1459118946185035, 0.0833574524750152, 0.17368376164907412, 0.11893393982562328, 0.1970925281244901, 0.12254701732026956, 0.19510649114606843, 0.14682144016748475, 0.14085502483912055, 0.09010682498375255, 0.13739267514357645, 0.08937659763520764, 0.11715769602526581, 0.13011070298812083, 0.24685851899125885, 0.08487779226514601, 0.11983501244216196, 0.14519816114296838, 0.1054781340363045, 0.14146570416708149, 0.09968483925706918, 0.1261677173897624, 0.16260931718974345, 0.20023128228081813, 0.1442816135503592, 0.12827281209249652, 0.10330625944921087, 0.11381697810945973, 0.18240720484285586, 0.09877160882517215, 0.10046847825569492, 0.19041348248720172, 0.10388008994801391, 0.1841178638560157, 0.10049514577633913, 0.09459558694112687, 0.23035814955590234, 0.1535375951038253, 0.19834488269782838, 0.10500168097355675, 0.2102437603377527, 0.14935020447498368, 0.08975293066713119, 0.21244584943257996, 0.09062879899096105, 0.21539754023955715, 0.1223315091262902, 0.20022081751977244, 0.14041771120842428, 0.20517565970939977, 0.12621082515726167, 0.13512375253823497, 0.2038756238236543, 0.1459925177116548], [0.02248771428581207, 0.028681276598945264, 0.0758092264614759, 0.02748655482015062, 0.047336346845352845, 0.07023128665863507, 0.038577046906275135, 0.056425110557146614, 0.09555963198504142, 0.07674992114545838, 0.013262323580772407, 0.02306340829349093, 0.04695321861354094, 0.049083119243263244, 0.013863855818917435, 0.035378564704930594, 0.052002894827314926, 0.09353470072270402, 0.08113673978274868, 0.030218008755435868, 0.03609483393149511, 0.006624151128269131, 0.010466699248119708, 0.08795055560767652, 0.03680086056251199, 0.028446141232345856, 0.03591262374914462, 0.037286184923422915, 0.03282461908736056, 0.05286950497857986, 0.011094658646822698, 0.018395979310415925, 0.02533107068419697, 0.09231704227145641, 0.027362892907413266, 0.08699671485491338, 0.0775429523820358, 0.03990523652323792, 0.007911822354916723, 0.07644020711943027, 0.09071146753887016, 0.08221913775008532, 0.029088260808719263, 0.06456055828640539, 0.0932417716830969, 0.047631574148732814, 0.047462942874840194, 0.05005890841505701, 0.02816634677020052, 0.06265606370664413, 0.04212489584460855, 0.04284842375425562, 0.021338028900866068, 0.010586327707935727, 0.05785590616024791, 0.13536431946821753, 0.021175963000484535, 0.026000476397213437, 0.0779306081934802, 0.05904786619207552, 0.057710743989915624, 0.05996198145552509, 0.0055081965946291965, 0.05663244842341351, 0.021978401796772115, 0.08434845615298518, 0.0020148224927740354, 0.04675307814332266, 0.012998762521742573, 0.0502559194161046, 0.06649856155197467, 0.0627488369542745, 0.019066798455652692, 0.018005707308710102, 0.03052718268947736, 0.004387036972348729, 0.028968484876977823, 0.023253765820916143, 0.024310224051136645, 0.09844294178389734, 0.025018474252353755, 0.08324525123762508, 0.02491316397584254, 0.0568572722465521, 0.036607032656789794, 0.011890031239618699, 0.02648333970066761, 0.020475277917519696, 0.03974948701779208, 0.0174089937636088, 0.03795312574854301, 0.08098754415949506, 0.027989167870292743, 0.07217483640077614, 0.025641106467153278, 0.038845702450001435, 0.012752100404712462, 0.03004145230196657, 0.03361917866934692, 0.029491878062066053, 0.03146868751143977, 0.005177377803897065, 0.0060582850710488865, 0.09660671329906872, 0.03959547270149474, 0.043804922832116004, 0.04524837420772641, 0.05195020329988292, 0.03496051818552998, 0.03723197271146121, 0.08592300432463808, 0.02554736603351851, 0.031490833198110905, 0.032131391870338595, 0.05444544743025496, 0.04846640697289859, 0.039767578184123964, 0.020761469213832772, 0.02747530673420237, 0.041324253524503404, 0.03020287851893133, 0.002670321794745002, 0.03229269742845528, 0.006126569839374673, 0.03825930044836095, 0.04249068750669399, 0.038940065330074686, 0.041118654677824634, 0.02856671006508893, 0.02989272590756657, 0.02411248335134118, 0.041533908806741245, 0.020380497519527713, 0.07609578931043226, 0.028046549771041162, 0.06641243028664781, 0.0643858672570317, 0.009409459608216441, 0.01809078137270145, 0.013760589081944238, 0.05407631179438003, 0.023168965633357727, 0.04955183098753614, 0.03922010110991617, 0.02600670469203784, 0.02000478884926246, 0.06217192295157622, 0.019957086469437328, 0.016690462662447846, 0.051256863084892114, 0.043792002759273016, 0.01076662362808542, 0.011787853305107884, 0.0626294996078697, 0.03998670997398515, 0.015758419983960208, 0.06403796374797821, 0.02095738279392883, 0.03884114422685197, 0.033257661777878963, 0.022369610340965372, 0.04265705499077036, 0.01331772131379694, 0.05229439894338289, 0.010424967566054436, 0.016351602821340485, 0.05403995326149368, 0.04906531152946334, 0.018808552131597555, 0.03710709654936387, 0.05554425500092968, 0.054169215276957526, 0.026120250413735068, 0.11957494857450647, 0.045301701588135575, 0.03392621904851929, 0.03713717699171074, 0.12624714538575182, 0.004477574679655053, 0.005924604643481754, 0.023773746084301703, 0.03964979216576584, 0.01375657669644082, 0.04384273693205849, 0.05633026504168107, 0.0368733094975112, 0.04629002395837058, 0.02006557984127393, 0.05200881668696961, 0.011194601519814423, 0.054520282729138295, 0.024463537396983277, 0.0813501488958155, 0.05436601177338631, 0.058198910537025625, 0.032874315211008635, 0.011760438848737509, 0.035167407890361164, 0.013328797029962224, 0.06197726001001655, 0.02326717235959105, 0.038621196553351424, 0.08385843567309842, 0.025448061886333653, 0.027299150561673508, 0.011913486936640356, 0.020283974271507996, 0.030670092561312264, 0.053373020097252824, 0.045312426819075505, 0.020690872296390515, 0.06737611526923795, 0.07690084046654164, 0.027764162101272135, 0.025804664323767348, 0.061427909850833885, 0.07936538362334813, 0.05143738404336957, 0.04764910224044035, 0.058380569136070634, 0.04406784037728945, 0.0230261227942162, 0.010161719645463653, 0.04080459310282623, 0.03343106194910023, 0.07604624640436904, 0.04210182127632922, 0.05268084050546731, 0.06587889601266192, 0.020288568883833867, 0.061995450767778584, 0.12746704847461757, 0.09930005627534083, 0.031568614105063106, 0.023903465837300308, 0.0635187246746594, 0.04451572602134078, 0.0030662989968644277, 0.025193502360414115, 0.06460588770888506, 0.009586392402378543, 0.08597990167477439, 0.018841986123832966, 0.07214316632598639, 0.007233793364702574, 0.10327319509439892, 0.012696127148134815, 0.035215238589913614, 0.06238763415885549, 0.016339801236866944, 0.04087227314049679, 0.023906411445369164, 0.022025730708734165, 0.02800904019104858, 0.06907549746815236, 0.10733590491356389, 0.014134821117735438, 0.09965343731305293, 0.025363006974540414, 0.04103996595668216, 0.025967448431577896, 0.05448881949808809, 0.05196469385297068, 0.04513474804679713, 0.02378594028883644, 0.026080115067382014, 0.03791309382405974, 0.10763674764142883, 0.06681532358690616, 0.08816652345441042, 0.05267253228192849, 0.03683552987152531, 0.04439300256631067, 0.02876110870631472, 0.01415678485852456, 0.012092142471022183, 0.032851125729540666, 0.03172922252316869, 0.09243206271240789, 0.0450239219372311, 0.012279883808185978, 0.01830877169155546, 0.032286947938583554, 0.03995048550648555, 0.03923012153996576, 0.016653970064174746, 0.05168201890023005, 0.00577427042205067, 0.009206777641309366, 0.03825332879299118, 0.14404253283094975, 0.03041707095690072, 0.024871442827486226, 0.017957619969703017, 0.029176303463417198, 0.014848318063623965, 0.038024479177810495, 0.001308446214440459, 0.02472007917540689, 0.04080538600382786, 0.03452970864131086, 0.02474709909649626, 0.06008817145841257, 0.04914904110914758, 0.024541896700318304, 0.05065553769048664, 0.021014427615990563, 0.03862815263170389, 0.039547557732270616, 0.03861545855479856, 0.0620685278948757, 0.09002477696706211, 0.06232187700187487, 0.0771557792059837, 0.062351593552457715, 0.04055172663121935, 0.07405081718799568, 0.04834191768520302, 0.10124395841792708, 0.013529579098817083, 0.06820885284293084, 0.0374320097598097, 0.026327379521042592, 0.011942804163892665, 0.036653779341929385, 0.01772671149322583, 0.02865084567137303, 0.022075943941731128, 0.0362728382911413, 0.07081086281687021, 0.028484213886962786, 0.014794938014670005, 0.07463297506253566, 0.02014541769430282, 0.016028952443100992, 0.027308839658695846, 0.04493551156032951, 0.032220999259621866, 0.07276063319295645, 0.045056564943684686, 0.02651982463806147, 0.05968843444040226, 0.04887044174416412, 0.07475850622980826, 0.04703797475104371, 0.05485303301904952, 0.040622260346407854, 0.05375534393674424, 0.02901701463176118, 0.0699283448498576, 0.03173825278457615, 0.021754156370016358, 0.10765760055472774, 0.18588086199616233, 0.1732280925517121, 0.0711612714334361, 0.09641789560837132, 0.17758543212567607, 0.10795368587658291, 0.11694325269350123, 0.17734975283665044, 0.1569789539902441, 0.059150552617446076, 0.1358644369869463, 0.11333435803892151, 0.14726270681187031, 0.1643091896849294, 0.14454877905307278, 0.17139033955191413, 0.16561671791057433, 0.1259047883532701, 0.1553615431992277, 0.13564027966030184, 0.19163563787456483, 0.12111959633447471, 0.14620106216640244, 0.0911530712619424, 0.08955878100448078, 0.1863951674632488, 0.13582561165094376, 0.13082681133622123, 0.15555660450650802, 0.0882062144697674, 0.12251626655098893, 0.11145234047885864, 0.23212597404997196, 0.059080064867533026, 0.17927172954284376, 0.24148654192686084, 0.15969412281147896, 0.10543791442027978, 0.17129205047122895, 0.2577276059216069, 0.18550521844337065, 0.13947033623774208, 0.1391645292601278, 0.13781206231684456, 0.12474462480073976, 0.2619791793967447, 0.05334352188172841, 0.10174144825507557, 0.14318244591836007, 0.18719104088602528, 0.17076397074326394, 0.0963558961126593, 0.09578096244724528, 0.15809561907043382, 0.21207595153922038, 0.24132466754846035, 0.1604426826440519, 0.15436408140005606, 0.15467802423142618, 0.11997490009713559, 0.15188108318515364, 0.23685098986231515, 0.1869301879478078, 0.2161747517604982, 0.21602432273568647, 0.12454834541365986, 0.16907482347901792, 0.1042304985645798, 0.2231155083544793, 0.17208844483379396, 0.16351201391268164, 0.12247430025449685, 0.11211688344877575, 0.16742450155077443, 0.18683346168648812, 0.07940912724382455, 0.15076044976951616, 0.19177595453877605, 0.14752074054652645, 0.08470971257455888, 0.15626549630636172, 0.16324051235231662, 0.2706284959229731, 0.07063878414731833, 0.14419621006856043, 0.1704361770422228, 0.13584598958972963, 0.1756484860614423, 0.09998412682644783, 0.14524835522376722, 0.2276166579535892, 0.13495565752588934, 0.17165286256180656, 0.15890500628419463, 0.1314190739104825, 0.16208666136428235, 0.09065559674655238, 0.1137532932203143, 0.09489773201846308, 0.17093355196618265, 0.13662626546236778, 0.16394958801327214, 0.17756854754782495, 0.32310343497703153, 0.18011805751631338, 0.1769894923293783, 0.11951828871162669, 0.21448019591550674, 0.18537397226018293, 0.16361923557856392, 0.12540952017110202, 0.12195650142647567, 0.13921631680380914, 0.23419376793167285, 0.19677686925616958, 0.08356372164862771, 0.09173198858456266, 0.34643332503976365, 0.12186568170305222, 0.12855555982358996, 0.1299823066520114, 0.12483450223601635, 0.15372053690014348, 0.12411074066955237, 0.0911460922009522, 0.14485830921799908, 0.17824610635157556, 0.14272260930268996, 0.11631309941050508, 0.10386153529848784, 0.17641670371015228, 0.15551741144830183, 0.17332468091720538, 0.15235878497121796, 0.20384943893840238, 0.14603034713335578, 0.16810846484957204, 0.1691508806881405, 0.07963527639907214, 0.15317816197151138, 0.09392808687182204, 0.19123339574904213, 0.10989803235016524, 0.18499290480488734, 0.08058022287103438, 0.12482444350157054, 0.06588025964916715, 0.10819867313388856, 0.1363519753419584, 0.19719034223066223, 0.08842098721933943, 0.10945300421407146, 0.14574258918723754, 0.12688293707587067, 0.06021319317721552, 0.14165595444219728, 0.10428531215556207, 0.07773840439415748, 0.15387999044070322, 0.0990273672786932, 0.11275532580311261, 0.14033796145550667, 0.10420652001254982, 0.06551448330884019, 0.11731956274278703, 0.15778913793544616, 0.20809523611059114, 0.17424536538460564, 0.14165095954893098, 0.147321067389942, 0.12375362112276977, 0.18454794561670673, 0.1550741989405886, 0.2175939909272617, 0.10521576424399692]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.06874401888419544, 0.04288907620995756, 0.0234025918067463, 0.055115042750032685, 0.031031923548829173, 0.07422373089338503, 0.019424484907499245, 0.017411184775072242, 0.020445187899073767, 0.05062040106783952, 0.1174111715367725, 0.018559801467363874, 0.012376046994881285, 0.029407594983856526, 0.02901496343134392, 0.02196273338350077, 0.012938277007290914, 0.03876323308495264, 0.010545113135219343, 0.024602693437989202, 0.021281313496611772, 0.035198135677004055, 0.018418804900119864, 0.04306660176465108, 0.03075877872986659, 0.09143299212859524, 0.03260095205698763, 0.03896822289173161, 0.013793136327407293, 0.0332830652534481, 0.06827996878494179, 0.02160399164553852, 0.034537978560453465, 0.02642433752395934, 0.05061123865626512, 0.014851139182405127, 0.009407761765854254, 0.017850900091411128, 0.04533157135630327, 0.08393879829635544, 0.051283419522787296, 0.04997333256347526, 0.008612047306322044, 0.009475582572180898, 0.02478825717022823, 0.02881719017281167, 0.025144524444195054, 0.03527479043470756, 0.03174151057347415, 0.021297522001869736, 0.05262113161264889, 0.016901858879493612, 0.009372112821907768, 0.007347680474331062, 0.04868212967149673, 0.01221455183000334, 0.030556531517856547, 0.03971304804567368, 0.0028570344194679734, 0.022841060849567576, 0.020349557143485835, 0.026870915072879968, 0.05549489595596829, 0.03581151546489808, 0.06411179164124113, 0.04128594146741014, 0.03662732249546436, 0.09368228756131665, 0.043868040816197475, 0.016051153671146644, 0.055814255028963096, 0.029195658674824144, 0.007165154280711807, 0.03298670030950058, 0.043220305815339095, 0.02193416404958454, 0.03422229287905559, 0.006925104938883095, 0.039268349327387354, 0.05519140639432496, 0.08378502912819387, 0.004936302383054769, 0.008237478191844158, 0.05008816148244566, 0.033591231781869166, 0.026636930753386794, 0.026465593273901654, 0.03462794026540172, 0.02084032072865915, 0.046557315865591656, 0.02893692971537671, 0.060921058419250676, 0.02952933976156337, 0.032164802879936276, 0.08667355598581415, 0.05071921108831322, 0.048454555592709975, 0.028679259872484594, 0.09115782866795218, 0.04121825376886033, 0.035885036922991276, 0.005382350852502691, 0.06900307151579088, 0.0022669688417320893, 0.004635549191715977, 0.011890649855617556, 0.04046598607073388, 0.06965799242137902, 0.03780278482384259, 0.028394323045147524, 0.024513823408333045, 0.046217425636226134, 0.02664681903326944, 0.04024618778437857, 0.04302170518184862, 0.04484623550407348, 0.02067634535412635, 0.0464766621289234, 0.018632595141929005, 0.07577747211701448, 0.015004973468040268, 0.06812610002535005, 0.025530469964348504, 0.05534733976087263, 0.0137552130599356, 0.06300599351825734, 0.048383696290153655, 0.04670240142713151, 0.042363091732465455, 0.04216242266157943, 0.08600876786776128, 0.07296016079283531, 0.07038474939162694, 0.05436119308034259, 0.06667041805602851, 0.006204199922766778, 0.0330921714644759, 0.048223262157050834, 0.01411521309731348, 0.04139395986473368, 0.045306029984907764, 0.0358228305835397, 0.1207693256137352, 0.06305096670985222, 0.08021524326214868, 0.032873135435605244, 0.02036466439735265, 0.06135530003737058, 0.021542737170332865, 0.04277030576861674, 0.03705222167134766, 0.0051423302389711385, 0.053574799995629065, 0.04448941473158137, 0.020558404202963558, 0.03380320448007795, 0.03770922250565022, 0.02742083405234641, 0.06943805623919734, 0.010191292554560688, 0.06229859175941637, 0.028285858401608084, 0.057807964377946434, 0.004799906652601015, 0.012913828268797408, 0.02031348589357109, 0.018709516115186196, 0.016688627881869193, 0.016316113798248193, 0.014302768658155636, 0.08276704383353073, 0.034175818155129115, 0.024587070989993312, 0.01702818677820746, 0.012761232172769886, 0.056383998448690104, 0.06769755810138679, 0.007604492298747985, 0.04499172326177359, 0.07595430819257613, 0.02824741610956769, 0.04371929718481918, 0.05054544702532792, 0.036596996904981714, 0.03486513257807782, 0.00803982271933027, 0.11715655455425864, 0.05658215858162411, 0.027180759333855203, 0.09984683620953753, 0.05126139066452461, 0.13643610711780288, 0.06395996067552798, 0.08237748046315486, 0.03989752584828004, 0.031746647193006454, 0.13084340480066117, 0.030129330247760783, 0.04938452504575253, 0.04589016053585276, 0.03352083213206741, 0.03487727890211729, 0.02343594152931004, 0.015289841347464151, 0.02815211860222682, 0.06256644291082217, 0.02790331239661863, 0.010126017075362466, 0.0828491148328589, 0.024897259990534475, 0.0238445824042203, 0.02140284951535925, 0.025140190301763437, 0.022713367399128697, 0.046370604916686015, 0.0543799507431686, 0.06132901173024889, 0.021207269183510256, 0.02458912027519076, 0.027932770392527024, 0.057649947252244725, 0.07261418782535099, 0.014801907499561147, 0.005734232273103009, 0.007362929933268818, 0.03689838738571252, 0.03810278868543045, 0.029706443967898528, 0.016613683415456645, 0.059104238771983696, 0.07243420312842054, 0.05047036274786919, 0.05443391780699453, 0.044250904747675505, 0.030694844862145763, 0.025455914287557526, 0.057625922734939286, 0.03369250860545905, 0.018968919232006998, 0.012917999617545115, 0.016395061074065107, 0.0317764729111185, 0.0426783062697899, 0.04479471609116562, 0.027548766905261625, 0.02921577614371575, 0.04228855903831221, 0.04407091238986581, 0.052216564410275994, 0.0645579842309798, 0.06741527768392717, 0.031168137812205864, 0.040296768739579186, 0.05211404652424878, 0.013296824350442379, 0.03540155117309863, 0.060378208516105536, 0.04994828148835129, 0.0035071569812228725, 0.030119576033264883, 0.0429074623201403, 0.08914619669198029, 0.01043331217876966, 0.02344563828721162, 0.023018494473710176, 0.036448157512612885, 0.048160852804299326, 0.04667746526519618, 0.04713372808069952, 0.03359763244647653, 0.0055914253443329325, 0.07584097314505808, 0.037394352707891695, 0.08361999846754536, 0.044250575329868064, 0.11816786722310128, 0.03871441030153825, 0.005106367198975697, 0.1215671142563224, 0.020661960138128172, 0.03567293398983536, 0.036731269135470354, 0.04220558788567301, 0.03976961214756293, 0.036542313548946576, 0.02647415430645549, 0.04703359655855645, 0.05137752193296629, 0.02848176240560509, 0.021311359465002053, 0.06177584400340434, 0.05544217378501931, 0.04252919491620795, 0.07770912451369148, 0.05921221886491103, 0.02727729407319379, 0.03483462312649335, 0.016200505384814837, 0.038710472609607444, 0.10494885155029836, 0.05538299349286864, 0.053323821930755536, 0.028763558272452607, 0.05255884100352565, 0.05380152754725949, 0.0915293276850735, 0.05792670417577029, 0.049641689270614624, 0.020545507112758297, 0.04221515632384727, 0.11051937562203216, 0.020223202431694638, 0.051510767605636394, 0.04739645027345227, 0.010797056470877461, 0.015663473919454603, 0.04454846095834528, 0.05731273066973495, 0.046121925115585334, 0.03510588719960182, 0.023967236911337224, 0.026272293968847202, 0.02702457315829252, 0.04023046766017233, 0.023538126167090192, 0.007646110982844427, 0.012968286586504792, 0.024965805707559473, 0.04516992297384047, 0.03585118732805695, 0.0505193847141439, 0.020526443014762575, 0.04772573784594575, 0.02246233187766085, 0.04944229956656214, 0.047202059293105725, 0.023463122328863512, 0.03113684886615844, 0.00925663655864135, 0.016246949465224342, 0.026246857934541283, 0.05398229748431233, 0.03248026256539649, 0.06354497467738486, 0.025714491944639914, 0.02066671179847852, 0.019295831931935205, 0.045385695468153686, 0.02216639402773111, 0.020703438053568526, 0.032502597858828884, 0.059609814667172974, 0.139554513978862, 0.14691968328289448, 0.16472246347656175, 0.1404547285769255, 0.14979145579761075, 0.15526677812299422, 0.17394839906163756, 0.15368004149246603, 0.14641123072754952, 0.11949034182414894, 0.16235036414957818, 0.17524662697988172, 0.1191326400505439, 0.23744858440852937, 0.19303751748896417, 0.2542368190423135, 0.10795065216840276, 0.09704574296671538, 0.0883890719964139, 0.17283531927293347, 0.26525206022685577, 0.13745688863338965, 0.12119448142907313, 0.12094803860471134, 0.13363536627542588, 0.11940570443027443, 0.1306007081462491, 0.08045829997788514, 0.08884701637491103, 0.13686514699891691, 0.1415411485058646, 0.27337351152973793, 0.14816013284988944, 0.11888910836029438, 0.12013534189111764, 0.08776219756973368, 0.10126698702093094, 0.12299075842865052, 0.18873207271099093, 0.13903332904221552, 0.11613245587795974, 0.11920910328626634, 0.08576567284762861, 0.17457345019905798, 0.11527871217338309, 0.09343236669777863, 0.1433500046691587, 0.12361086829895936, 0.09465913393444593, 0.12064720353772565, 0.1443582836298212, 0.12505244658959488, 0.1234649055667462, 0.10669605295744636, 0.17617777620832767, 0.1090328356311206, 0.08530071876462429, 0.13520972292509773, 0.09375381719080672, 0.09509086278417418, 0.15316466350228558, 0.13152856319662065, 0.11778404185127829, 0.07778313626805622, 0.12504075608787038, 0.1231519892931946, 0.1525837390293037, 0.17017400643277555, 0.15360199245474032, 0.11280425583883641, 0.2398442639218223, 0.22151174925027356, 0.12551862641327804, 0.2309246409323908, 0.1321384764366573, 0.10108987515371654, 0.1524921762005937, 0.11667506829384836, 0.134451893428641, 0.1134403616250042, 0.14399946336784672, 0.12642958156403997, 0.16470360239186596, 0.1443098362294897, 0.17550266888593474, 0.18472570865865678, 0.10361300871497202, 0.1022769743576646, 0.08789558113823015, 0.1786238336635213, 0.1230116036810702, 0.19413015805184844, 0.12515395323956205, 0.12866897147990045, 0.17536966070052118, 0.17139257652865303, 0.0809885860390721, 0.14714163427631702, 0.1423969912913538, 0.18089087169256904, 0.11536721065039597, 0.05452487542624435, 0.15326722735358825, 0.10213780682533981, 0.1393738398027997, 0.16470905693788684, 0.10145129245375434, 0.10273795244434189, 0.11844306898814057, 0.14556550030266086, 0.24484058211167015, 0.15884428615531615, 0.15537438283283866, 0.22482854224020438, 0.15641580275710554, 0.13425753692225104, 0.11880557413303083, 0.21768667224434116, 0.19468558711871026, 0.11089917903225269, 0.14798184886815088, 0.18882680714370745, 0.13775360980822196, 0.1569131623593069, 0.133984487864279, 0.1388514904125083, 0.19099448356897603, 0.16615181500392576, 0.1212632378202773, 0.18991186343614133, 0.2081868602263351, 0.16122029253071354, 0.18791056598626799, 0.15159943862067116, 0.2566148632115895, 0.07653237515760046, 0.12979786332336166, 0.0986431128976326, 0.1037241680727851, 0.11801529315210159, 0.25780813708420725, 0.11713032370373128, 0.20447681898311262, 0.1340091865389578, 0.24558267616216214, 0.1242656819522381, 0.09674249472276819, 0.10566718921425844, 0.15293289126167375, 0.1077790944386394, 0.12108389663720324, 0.16615713165412027, 0.13599303250591602, 0.14097375314562552, 0.11646035683131027, 0.10107736493791304, 0.11766235644538557, 0.138552624191488, 0.1672256710909067, 0.1076495030053681, 0.1955305208121577, 0.18111283800775008, 0.11116898753830504, 0.0773722296881099, 0.1448216289281845, 0.14922321774065495, 0.15270715579390526, 0.17235898112337436, 0.13071957434858048, 0.08480489899915072, 0.17884923205260309, 0.12964487556488286, 0.10124840938876714, 0.0893032293946993, 0.08594740422502642, 0.3336815157484624], [0.012987835235112618, 0.04601981708659761, 0.03923405923189656, 0.07753641765204168, 0.004211894908709633, 0.014296504931764738, 0.032535083817258, 0.08348919661535371, 0.07993343015832287, 0.03500663284813205, 0.02903615533854933, 0.007604302691986725, 0.09446401134013169, 0.05217251818506949, 0.058513933552369, 0.08311949790485444, 0.030363588443686886, 0.01562544052684379, 0.05707861803051445, 0.035391837178218755, 0.040020103746604536, 0.01066901540804294, 0.04718006490879963, 0.043845613592214165, 0.06179257153323101, 0.04272614079978197, 0.0500800792548445, 0.04403127500066354, 0.06515046897073908, 0.03164749817862626, 0.06381372215166208, 0.05074738780216825, 0.005160496098875639, 0.04685044408805909, 0.04617517205676244, 0.04055081881702908, 0.021449676639730894, 0.07991931881875762, 0.05070913703210893, 0.032103408593684435, 0.051308811507037574, 0.018797281063011578, 0.05335369935980248, 0.07674599877528607, 0.018283008154661908, 0.06309408979910998, 0.022015781141817573, 0.03220586902311733, 0.02509114343763119, 0.03723649263021447, 0.003243000049429435, 0.06329051091245587, 0.035401049385508226, 0.055403245027147, 0.01825422623134669, 0.014388588700263251, 0.0269007024865958, 0.04374720959834034, 0.03972963001879473, 0.03414740778445717, 0.04083841205424359, 0.029557162159753424, 0.02295537648962871, 0.03762099215941083, 0.018074272177933205, 0.07939281723191662, 0.06015818806425218, 0.04559009155679134, 0.07215717041324224, 0.05350271878283351, 0.08548639549483215, 0.05001688083153098, 0.029866901083639073, 0.026797437664842414, 0.08555997057908005, 0.045650819346549056, 0.07365658068128171, 0.04028361117947967, 0.06938965480414129, 0.0373742543911982, 0.004774086137918095, 0.033443143155666134, 0.02519892626291802, 0.04333177543876152, 0.09555992309845264, 0.05008224345323059, 0.08598420708890885, 0.009033637939982356, 0.029034491012533827, 0.02035691924843817, 0.01553543285662008, 0.059888601723697886, 0.08081528162884136, 0.04854118098474799, 0.0338085096389536, 0.03952724874139794, 0.02809904786127229, 0.04995886499302522, 0.03569428102984544, 0.03252176920913401, 0.055897678173477613, 0.043237971802873, 0.06654002989131598, 0.016291840302367366, 0.0449386601816983, 0.06404231129694851, 0.01808761359913455, 0.022172867470691283, 0.03378882500973921, 0.03388354795113687, 0.034081838319018, 0.10743510563887897, 0.10103553653724733, 0.03730441781602079, 0.04751799778351861, 0.036263212396372715, 0.03760171738723594, 0.05161868258109016, 0.08532534083051067, 0.01797595245373105, 0.019582932957658367, 0.04543861299152336, 0.026775924000708808, 0.029185465874991594, 0.028185652185892387, 0.10427893830403205, 0.030847907314197193, 0.02348215769856207, 0.08367273596025283, 0.01987463242614702, 0.06183506643039085, 0.09292717001611188, 0.007251244368812731, 0.09941994903549072, 0.031170514599990942, 0.030561551308980396, 0.03646641721828811, 0.04045547917485237, 0.03573301443529706, 0.05538673200193913, 0.07695340941990576, 0.08124969944718384, 0.0736390219460572, 0.03452163407458894, 0.03129610705429749, 0.02793442897288309, 0.06037281908755822, 0.03911931841303745, 0.03156913887529123, 0.015079910273573574, 0.03408663019898438, 0.05603056378482331, 0.020516556650099736, 0.05396238685916028, 0.04854924406015104, 0.013225311000320702, 0.010686784817446626, 0.01853455695503902, 0.03146262775595871, 0.080551624808821, 0.025264091616977128, 0.018596713498775518, 0.02361635523547809, 0.07453341427589617, 0.07196659838119823, 0.05763940971284624, 0.016950246908010978, 0.012799227260984482, 0.05804683825361633, 0.0738410469925692, 0.008790170409596496, 0.029063384018598065, 0.0523899186162218, 0.025355830645909714, 0.040413612469790444, 0.03939752707317953, 0.052496312907145876, 0.06974768599555378, 0.027178365309091828, 0.05637762076672047, 0.02707864747442786, 0.030368470338984366, 0.01780608777828034, 0.07998278154240501, 0.05355983829846787, 0.04555411223742751, 0.040645154884024974, 0.04102546391227553, 0.10275244682786927, 0.02922142795737713, 0.03354500986695771, 0.04181614325892541, 0.0314158600034012, 0.04887419557499309, 0.03044777384568607, 0.06695367140515197, 0.026712411481346336, 0.05390990217546782, 0.07108502270233247, 0.015909821940435758, 0.021167781181453217, 0.03866353057204716, 0.023285623587247346, 0.0455198374636952, 0.05786583082930696, 0.025972261378962188, 0.07663651715002714, 0.04475669514748358, 0.06325281938658127, 0.05942260193067694, 0.030991751813299717, 0.0384363318763433, 0.014009388584283092, 0.03528507516509102, 0.04546286733520608, 0.07355231611478714, 0.02897779476047764, 0.0393672589392912, 0.03449765552255896, 0.05998349703487851, 0.01853135470751553, 0.03403449408529747, 0.01623364634841921, 0.044004143996825146, 0.05862678213405514, 0.02689149219452614, 0.009401982590075462, 0.08153816219419241, 0.057306866266674576, 0.039931681878384084, 0.055231970749915614, 0.033910889629154436, 0.029812826767503738, 0.063373290543114, 0.07083741542432578, 0.023251754840114908, 0.017043523858451558, 0.013965941822877335, 0.05739926030078242, 0.031201491365209225, 0.028035071858715628, 0.06092345244401406, 0.05126610593569856, 0.031494927938066186, 0.0713594813620852, 0.053384863816562204, 0.028703493148749395, 0.04377171675103807, 0.0315367735757102, 0.0267895067396063, 0.0991294714772413, 0.005009658174634341, 0.06833560209000303, 0.04450822219012245, 0.030571498960677176, 0.0559059442621806, 0.04462533788154683, 0.017086953382879015, 0.077262717419334, 0.009001037068364602, 0.0365547931212331, 0.040141509530404886, 0.086330080464963, 0.05650195683683119, 0.02937901224340162, 0.030473698261043722, 0.022824616772272897, 0.026377022018535968, 0.079162692080342, 0.030820843343052174, 0.045616720773039326, 0.072297441112178, 0.024915427765658787, 0.07615480106323957, 0.018946248775107727, 0.05603214958682657, 0.04888227397215463, 0.06981504044585651, 0.053721781624781514, 0.03902075737113914, 0.01302744581123754, 0.041502859263170155, 0.00874467819343291, 0.14704526041544255, 0.036660494102585706, 0.07622686695427665, 0.023814097850493366, 0.042469451549432935, 0.053700315841143174, 0.019271822736388253, 0.015361901492841784, 0.012587889458142943, 0.06219484430227069, 0.06417460319015288, 0.007215327294092746, 0.0345263876501591, 0.02628942752527374, 0.05408379264296063, 0.019129822593963435, 0.03654320604137836, 0.005242321950068037, 0.07134641190209697, 0.022218547378396316, 0.036954859557050856, 0.05627751222721512, 0.023484312320849108, 0.11630775977767284, 0.05872450430967635, 0.03299725317065755, 0.06644137308842714, 0.03870041387516164, 0.06202031798180073, 0.035668946502189484, 0.02216204073310139, 0.014151834015313898, 0.04301195288257253, 0.0038576292788474673, 0.04159282862899765, 0.006088627898509825, 0.0371008912371772, 0.044460969886952834, 0.06548045368324365, 0.02668084099798674, 0.06225729195941841, 0.10949254967272283, 0.023357555412897663, 0.03457769255844816, 0.05634081024195879, 0.02625414917636062, 0.0022806751123073724, 0.022723257594231158, 0.010463963356620122, 0.02048214972620049, 0.025810028854457122, 0.05110148896252917, 0.03611807320867816, 0.047607484513953816, 0.03922819099839657, 0.012975266605104892, 0.06562974123704819, 0.049005694567195834, 0.06970388108804342, 0.02551857836454386, 0.05221280291856778, 0.07761454329855981, 0.04194553167889676, 0.03984389203270117, 0.06721425621259598, 0.018909673822382768, 0.04336157625901603, 0.03651025659975506, 0.032142207116609624, 0.08279110665523237, 0.1945129568658529, 0.1868305045871004, 0.15184164497881167, 0.13876412574562336, 0.12109921839568885, 0.2040879067874724, 0.1882132473251512, 0.28366412546846176, 0.1756912797328926, 0.08317864755348814, 0.17229533453862514, 0.2276522197550343, 0.1268768236942349, 0.13794151585428946, 0.13551540732864412, 0.08361617568880321, 0.11564316318160105, 0.14023024949335283, 0.1637558596989801, 0.12423190513565657, 0.16815868957388788, 0.17260677992336212, 0.17495741346670737, 0.1403154844358083, 0.20587325937324957, 0.16735889378093904, 0.13055871120624005, 0.3035798680878455, 0.11051953650049626, 0.2295479656107003, 0.19563936658443945, 0.12577409375338786, 0.15026767137310199, 0.10824010316883365, 0.15119338137728555, 0.1248281590280033, 0.12762094021684703, 0.12856928811919305, 0.10542819276452066, 0.13542232764584405, 0.12370897351854271, 0.1050723142801754, 0.17542828174848712, 0.09625609017788403, 0.14482726733530724, 0.14775042902798424, 0.11011904105544092, 0.10316620325489391, 0.12631440790550363, 0.07335464244768505, 0.1509072475375668, 0.21120878597421033, 0.14338889129219518, 0.16788525747195368, 0.13079325668513775, 0.2306667604153195, 0.23925986140966418, 0.2174144812048443, 0.10013944349221646, 0.09342508120161873, 0.18675881407914624, 0.17467276583756172, 0.1196974766771159, 0.059346199981988444, 0.24819636897694683, 0.15004780413883348, 0.12472990825171433, 0.2056799600681951, 0.13940881937742233, 0.18046935479487144, 0.14242121499151955, 0.1615571260692612, 0.12596003861436922, 0.16981771426095119, 0.10902017219773225, 0.1735714225158576, 0.1413692230538976, 0.3206592161328562, 0.12736528901563537, 0.1788956569808145, 0.08674072657501505, 0.10779919658577251, 0.14840975493913697, 0.2377885282640496, 0.12382723451141389, 0.25179975545935096, 0.13768676097594923, 0.1417023640486502, 0.06832012711393257, 0.14435854409971546, 0.14029251711983837, 0.10362583302682447, 0.17399752061934243, 0.1318141607747924, 0.11751550505118025, 0.18337909462711505, 0.20600991413718273, 0.12669988802724308, 0.2196466622333373, 0.15011322804756705, 0.165392943627892, 0.24302821726568286, 0.13427498840516613, 0.13535846655647601, 0.23267461557782468, 0.0829811271039709, 0.24851581231961328, 0.16429814269706128, 0.17711499285313392, 0.12001542614833002, 0.17784683664719905, 0.18670011642238787, 0.15819527178762421, 0.09244985893488893, 0.11750897798206537, 0.12742077676399102, 0.15996424541358026, 0.17063100852312582, 0.1832012243328556, 0.06445185040994998, 0.14005414120131923, 0.18179077985546283, 0.0855394853879848, 0.23811889602051628, 0.20373654822188042, 0.12618448705442492, 0.1239025639370084, 0.11128886497669643, 0.1195018408038924, 0.17718449234962466, 0.13079262849303985, 0.15061369796674098, 0.21895286236559192, 0.15654531758158438, 0.1442438147721752, 0.13816239432461802, 0.11834759911101674, 0.16021236597049623, 0.15147916281655913, 0.0878614442603242, 0.19530336042085003, 0.11356764713362341, 0.1448999997228384, 0.1421697696130122, 0.1090576951842635, 0.15565227356649217, 0.19783247712879412, 0.22520654534380283, 0.17101541612177126, 0.0752868770711845, 0.23101318537467913, 0.12527888685825372, 0.11416629888117315, 0.08201720463412424, 0.1007884042337537, 0.07775954842086762, 0.1238323902831443, 0.16579012957311448, 0.13080163768702938, 0.13941677137007638, 0.09736265055835248, 0.10727863984122392, 0.20337025094176495, 0.15996010853878914, 0.2724385165399121, 0.10562665550218475, 0.07110058960895385, 0.10826460266065215, 0.19344529076930017, 0.1366896975424982, 0.14429944807723646, 0.10139788080367351, 0.12717521494074216, 0.09583949922553955, 0.1568514003508514], [0.03179658463435068, 0.0687752599497476, 0.049784120337496844, 0.020135715190741806, 0.01129743158667078, 0.04136137048443479, 0.033267218724734364, 0.039567391748630235, 0.06436177379181308, 0.05628871626310772, 0.11060847930850522, 0.10925873963823242, 0.044604036806812214, 0.03924740448353752, 0.03364157908025288, 0.017841754916815028, 0.026142497607056173, 0.013770079953716168, 0.07326624356210232, 0.11002064472244633, 0.03091225103895751, 0.03981358176397701, 0.03130723831183728, 0.04829419806839959, 0.043286748621011936, 0.02770310297848717, 0.02737123560490868, 0.03177138608730128, 0.015350754913543502, 0.01613047537243655, 0.045798586215823896, 0.06431731004868785, 0.00673627719328168, 0.04691157790441667, 0.04949568823400525, 0.009088680399732004, 0.03501452355375213, 0.02366980135951552, 0.04639192897405836, 0.01677154349313388, 0.04287061732142203, 0.06107221905803008, 0.023388390451849952, 0.03186654378359597, 0.07024448635357042, 0.021264195261943727, 0.018290019774388884, 0.021707059199651404, 0.032278164740531676, 0.06437894948307546, 0.04953318057701953, 0.06746923325643425, 0.061483033707425486, 0.04455555876296374, 0.01403515499400636, 0.02244697756043846, 0.03501781390138692, 0.015945283192840796, 0.007067016502391668, 0.04302684946226017, 0.09019744552431569, 0.027200449708729025, 0.017390676601339253, 0.045110520516191764, 0.038465014208228364, 0.011952221299701882, 0.10872001128811991, 0.013255141506482278, 0.018801605629344142, 0.0585988927031717, 0.05734364231747966, 0.0743341701285493, 0.03375766055297948, 0.036619531381274426, 0.03635816899458728, 0.03382359391018268, 0.037136127451254476, 0.021037515590808565, 0.10640339204861272, 0.06204357641118188, 0.06426625028853455, 0.019529879453682134, 0.03896429286068005, 0.013625871562849612, 0.08929193725869541, 0.031737013637358626, 0.03369411355966041, 0.04393546804485302, 0.06901001993326411, 0.03494096379126272, 0.06716714180525273, 0.05092013296821425, 0.02550500328652561, 0.022633883861764785, 0.02459260406002643, 0.024810025558596658, 0.04758037649275315, 0.006806134835877006, 0.018201634295344837, 0.05713351972160801, 0.08501663804054262, 0.015260864071728242, 0.021659940961868535, 0.0262549152642849, 0.07326429769877466, 0.026568237564436374, 0.08888697552104151, 0.0363220211358801, 0.011349222003181857, 0.03712744001419314, 0.027112968213435625, 0.07165329906368448, 0.0175785883930662, 0.0386694792447792, 0.009773798576075464, 0.09453836783406236, 0.024278781887504364, 0.06762768322181317, 0.02731438996570726, 0.08040915543754255, 0.023137385573899074, 0.04191216471935472, 0.0366050829630225, 0.06428144947295228, 0.06347770066631418, 0.04071957266498958, 0.03348812783857988, 0.08934814512969987, 0.03212472115973792, 0.05714533279740042, 0.039525440773896636, 0.060297144922397794, 0.011526654669714552, 0.03530210529964778, 0.06449752457199559, 0.04778420567632683, 0.04792043526146201, 0.03279260427300488, 0.0574070054496969, 0.03159744773931321, 0.05300409513555708, 0.04068742378524715, 0.09880337849139206, 0.08243839977489364, 0.02845746401186672, 0.029378016329100056, 0.03016302662511026, 0.04116462378372108, 0.08694767756688018, 0.06763785686944762, 0.015571881404837534, 0.04172967491491188, 0.06645971323333441, 0.05053161913829465, 0.07532657574742072, 0.0255416376110647, 0.10447517172583651, 0.024297960898688725, 0.045443129079837, 0.010953977133237548, 0.04385746497240278, 0.06710687366824958, 0.02076411604761116, 0.014916202072204362, 0.04402235390678529, 0.0728822343291775, 0.025280363324488846, 0.010936921143213348, 0.04666489759279836, 0.018944032865786747, 0.015565253786682604, 0.013931655557826163, 0.07731063621899775, 0.04015972327080466, 0.0520077939595907, 0.03126656670393723, 0.05191942954796457, 0.028999160952685826, 0.04398187382086631, 0.035001580498271415, 0.02412889295467927, 0.05147970274030682, 0.17284792908016713, 0.0288810704143778, 0.05241555957904747, 0.039790005408107273, 0.09246062247022506, 0.08181699521599278, 0.03494680904212498, 0.0029507973569355187, 0.0076609721309655624, 0.035302097638768536, 0.029028059704409494, 0.07756703818637518, 0.07488557723380866, 0.06500148785210426, 0.0344125967803261, 0.034503217320889235, 0.03599697769048714, 0.04387774715019811, 0.014975435032899824, 0.00485661487478102, 0.07756444880919111, 0.04843559108614441, 0.018943617263087825, 0.02613442495555407, 0.03453785598638558, 0.02279343124809525, 0.03094149836068673, 0.08496813701405641, 0.02185657083417379, 0.01610117250933282, 0.0327962585124037, 0.03153391223731301, 0.04070084947612017, 0.07843479363908691, 0.037036459412305586, 0.11579671784514382, 0.021284699605237094, 0.013125879491018433, 0.013304608761362973, 0.06073112224018382, 0.049223715529566815, 0.03802033081170052, 0.008501461556842251, 0.015575988593721583, 0.04846338092559769, 0.04300577438346321, 0.07013249195991986, 0.05998258155980899, 0.038248985074460506, 0.021381422036117124, 0.044398288572988207, 0.0563434953801334, 0.0639031054602275, 0.03291273835085092, 0.03895804541365754, 0.04063999528185495, 0.038505586224698254, 0.06034182700058145, 0.08756999377041094, 0.02427401490539553, 0.05163505771047166, 0.04818707216350783, 0.09044685310894444, 0.031044577406118476, 0.04080093503298779, 0.06839497390413476, 0.021437880800916784, 0.05604264499138921, 0.03832345265114019, 0.03333097256179298, 0.04234059939100858, 0.03306593678350891, 0.07685860603927605, 0.06181802480451523, 0.0013394884562360184, 0.051353880459623, 0.017550777486195008, 0.01933883436234488, 0.0622397868503486, 0.03794270312233317, 0.007994924221308002, 0.040823783605329456, 0.10143296763060555, 0.06514316049194144, 0.07621581996640853, 0.0877458262707918, 0.026738558062202027, 0.042793931920201554, 0.038133206206464, 0.07695481902168644, 0.01964671935345377, 0.015789080737909723, 0.023288645804108634, 0.03548323529802504, 0.07339965011323653, 0.023315483779315988, 0.057540377526874506, 0.05539603613977952, 0.04233478095322367, 0.023860022906334172, 0.030060060577647343, 0.04115033624393325, 0.02106292289681733, 0.024595001915229425, 0.04972467957545192, 0.0842585097697954, 0.023212069570417368, 0.023471020695362842, 0.08251218170288109, 0.022644593770946228, 0.045198835132102815, 0.11514185822658962, 0.040930943984177806, 0.10232357548609858, 0.032071006904926994, 0.008100057339986727, 0.005112363752203002, 0.0297922381545387, 0.02883087058791951, 0.03487738998486631, 0.04469896659194943, 0.02585929979930722, 0.006713407074717144, 0.07924352967811209, 0.039299004335677436, 0.03866754104233077, 0.019274695566104307, 0.08181972248900322, 0.07291260971537522, 0.016641433035293897, 0.041057455743993485, 0.008681798654217875, 0.05733169900674013, 0.059139838877825014, 0.027231642893785914, 0.046882933876927824, 0.006780476157268089, 0.02625411853284365, 0.03144405203901472, 0.009707727323045895, 0.034778093498560696, 0.008355395402759314, 0.08488528460504548, 0.01669090699344393, 0.04173113814284725, 0.05690306898266558, 0.006915667214460912, 0.012863851565447067, 0.07475768651572928, 0.020481969695538282, 0.035759570873192245, 0.026535630947159185, 0.061381461939984755, 0.03686451097770083, 0.031627738855839256, 0.05113101782157056, 0.010221897767135694, 0.015005581550330166, 0.02250489380751406, 0.12079218567739572, 0.053582403418277545, 0.009476687654011674, 0.023771673816466526, 0.0768663282055528, 0.006508156798043919, 0.08330478393022092, 0.09247377619988496, 0.062293554731314225, 0.03665766340770549, 0.022506140615610827, 0.12782496475284139, 0.11885689436307839, 0.10178991097716555, 0.11259193457062207, 0.11859800260994705, 0.14931436688188585, 0.2539519415867906, 0.11841038001641152, 0.11893287496340853, 0.13966751194769336, 0.24082151632155144, 0.25604604292781125, 0.14636275268370105, 0.12803796783930835, 0.1899004027607941, 0.1082340280915941, 0.13450254716219442, 0.12231791106563424, 0.15330317219899547, 0.35962661548006924, 0.12524683373950182, 0.10171861883493201, 0.09375551790599862, 0.18090274605539539, 0.08844176352384592, 0.12238656020452901, 0.15838743728255072, 0.16226672267000522, 0.09456666712198528, 0.12280853675498117, 0.11228331605032568, 0.1526656951154432, 0.07207096253912296, 0.15735924003585694, 0.09465796181992178, 0.0688069913115713, 0.09713504583604875, 0.09294549483926066, 0.1466312358576444, 0.07600465549095985, 0.12703838397658643, 0.19326054100548068, 0.1314516479690229, 0.08613676583815007, 0.16921045168513255, 0.16146541002296633, 0.06359930180253522, 0.1369758007387, 0.10474633620751482, 0.12357018136930083, 0.18045435479331404, 0.11932142709772434, 0.18129728133639983, 0.2097065948070057, 0.0814708843526821, 0.10518947210643562, 0.10955674784077753, 0.15192801373139506, 0.12440125653219801, 0.07731655041777319, 0.1703275917398353, 0.12931579483612893, 0.1329380730467458, 0.19321341127637895, 0.1735767544878106, 0.18176883909731142, 0.14980055692215122, 0.0836212395299827, 0.1718551250955751, 0.39213206318597643, 0.18533646459541014, 0.13325969207911723, 0.13788816549124258, 0.1461787383642889, 0.13711204181515402, 0.2244044512870812, 0.1155926320221155, 0.12860921662180655, 0.30626212577185324, 0.10625633381066785, 0.11193157444077154, 0.12440279636892582, 0.16172908216474519, 0.14641460151441638, 0.31564363849259197, 0.10242472973562057, 0.15144864187365578, 0.1743958403746928, 0.2278278071072794, 0.10597490375080418, 0.14040917698894778, 0.13927921262239257, 0.18462650027246247, 0.21209410782302582, 0.07697729604138483, 0.2490192853034504, 0.20335281478060832, 0.1746588536808568, 0.07855730641993784, 0.18278249599520238, 0.18683113277919833, 0.12373238516550873, 0.22043701982305897, 0.1994720738260977, 0.2558247507700036, 0.09960250012696752, 0.1542469312346751, 0.16031459274311222, 0.10955456449019332, 0.19707331463934916, 0.19608348307590331, 0.22254313342273238, 0.06920376356931464, 0.09802939220061226, 0.10983704409051327, 0.15552982207267516, 0.09343449642220814, 0.22310692816972735, 0.11623489715519453, 0.16415247873913857, 0.12170910099220854, 0.10001164470468799, 0.08610935521221931, 0.1272670535611049, 0.18120599429934256, 0.29154566867697623, 0.10166143037138448, 0.22871124437980114, 0.08336696728703477, 0.1498171657083496, 0.141530622457785, 0.09814465012882026, 0.09787602905905056, 0.190010198482102, 0.14669783954178134, 0.18867029538077695, 0.1507863741848738, 0.18239894641503213, 0.13958287455381888, 0.14992809523978542, 0.23080796574152287, 0.26534941468027334, 0.1756374084300572, 0.13305871657306148, 0.08934233052235457, 0.08407878554275922, 0.09292870985283967, 0.08976494292578391, 0.18490342573533136, 0.10556561361637809, 0.14309929473505867, 0.12406754863238144, 0.11309569866787042, 0.06488968498043476, 0.15488618564221168, 0.18313647458149543, 0.1664184902103678, 0.11836015529209569, 0.15803656901323027, 0.16468615090895086, 0.1878741461663477, 0.11600884759137708, 0.1374395750463009, 0.07073834493395782, 0.10920045566895317, 0.22302835819221314, 0.15274038868806056, 0.24634182332984864, 0.0898616232218281, 0.1153081912367094, 0.11199778742006711, 0.19140627115003525, 0.20996675826609137, 0.19539431037922061, 0.12112062289229325, 0.10757783548005166], [0.09429997659378475, 0.049239611853995634, 0.06925453987693594, 0.06597872493007491, 0.055819533374761386, 0.01513762829539877, 0.022878631716594103, 0.01568194717213872, 0.014788729829653619, 0.022555087888312918, 0.03281090228307632, 0.029909487911349827, 0.1449852806305693, 0.022683179704472426, 0.03850939751212155, 0.0730591316917731, 0.03437482864565907, 0.09085497878972562, 0.07287893249022384, 0.06046632394915628, 0.02028502189674445, 0.04381041951297272, 0.04399981176961334, 0.0412873127647946, 0.03228240503719257, 0.01110105356577063, 0.02808514719588622, 0.03934922905999326, 0.05679528424215894, 0.04317308415568644, 0.023044673613302653, 0.05023297891321202, 0.05471291553769862, 0.007252761701707759, 0.02113583531501072, 0.025014927265264338, 0.039189990024052324, 0.057245996750650875, 0.061703690012255986, 0.07735040384314715, 0.026618985143760522, 0.026455567098192634, 0.1002809092883141, 0.0374747842790619, 0.02503780456590316, 0.048356362273015326, 0.045797088513931924, 0.04101897131711726, 0.03896565649718527, 0.006192845063314083, 0.013278131805089934, 0.029758001685202606, 0.027453555582812237, 0.08498578001895259, 0.017382921876325723, 0.05391798440306898, 0.08409894897692627, 0.018733126945012522, 0.02377420382183646, 0.05373816441504225, 0.02318197572153182, 0.05633236795303322, 0.025337626481609, 0.048972614890625404, 0.06120246549647662, 0.023664226154646566, 0.029554457869380716, 0.06310561559193077, 0.038168595638126135, 0.016678933039187424, 0.0665360615558682, 0.05894975331161292, 0.07447890712008362, 0.03221379037225439, 0.0721260749043957, 0.06964185094881443, 0.07332641976855456, 0.0821780754373439, 0.039808268944222125, 0.025663914819878918, 0.06037284590063557, 0.029616616328337023, 0.020241167193519014, 0.015637894243662877, 0.04348501983669497, 0.04341248663202409, 0.02329660928808153, 0.03480279983411874, 0.039562825864601525, 0.03656105972045372, 0.010108598151184138, 0.050030015408992774, 0.03486662644953017, 0.04721787134786287, 0.05565893070231523, 0.027791588048961376, 0.03058855016265185, 0.03572615411793513, 0.059337945384604324, 0.0225899487193073, 0.018346007395115112, 0.009963091241285927, 0.027573802658627113, 0.016776053835788084, 0.017120594218853983, 0.021182591576249372, 0.0483831676894859, 0.009379332242984205, 0.06896356436153574, 0.04650541340872165, 0.09167303045791003, 0.055155549649029016, 0.04682504061248995, 0.051725207106961366, 0.039095646296177185, 0.027294492747093883, 0.029003975815289927, 0.06613948848098516, 0.05558827441305884, 0.03674601249757313, 0.09606486697110439, 0.027875193139357914, 0.07963645617447554, 0.09956313852941799, 0.03110069717701164, 0.0441272160218608, 0.051048150090801145, 0.03912450482828483, 0.021328822439236027, 0.05858098156750203, 0.042879676311126644, 0.0024972460138791754, 0.06809251473074959, 0.020840883803283496, 0.047465930617744886, 0.05026239668950439, 0.019694201483000672, 0.048909627141491066, 0.03186132864005143, 0.03775734048817427, 0.05314107931729767, 0.0390238983316287, 0.011343694678808173, 0.02606497525477842, 0.08424985297625104, 0.0014703237050731157, 0.02798956623601337, 0.060951395501052184, 0.025008526600656972, 0.0797947146178734, 0.05722417090568812, 0.03271909813667017, 0.020760584382280227, 0.03376353644735871, 0.03897684521131939, 0.020959746175175233, 0.02757259607014637, 0.029444399762958772, 0.04562052056914376, 0.07755407597869635, 0.04171565933633716, 0.031103901339754946, 0.031543969056539, 0.01330977889724196, 0.03344487451437501, 0.026070257431016337, 0.05303949222809846, 0.018434653344053416, 0.04536347508790993, 0.01844492849833783, 0.010572878076815078, 0.012969945166860859, 0.07885958939310043, 0.045716193459567525, 0.06212760093471697, 0.041572094459327004, 0.03315584869274209, 0.01803363504398975, 0.035938869921430465, 0.06352159750437544, 0.05599092639562103, 0.01769519463602093, 0.0674967511346744, 0.026138851028536598, 0.01809809559715852, 0.05478238439067237, 0.026001093097992485, 0.034585859055720994, 0.03283175902681486, 0.07070576321453818, 0.10020163450990954, 0.06425467469999868, 0.0712907402926395, 0.07918032742435895, 0.07204002024786127, 0.01954653420515599, 0.03677227782205709, 0.02040826246112345, 0.03881083778856743, 0.03857722310649772, 0.03016021125198853, 0.020526952463232224, 0.006714341223179814, 0.03419228521506152, 0.06450158483799427, 0.04076707777717421, 0.06781748150505366, 0.060135301187514305, 0.04720954397212594, 0.044381488264808734, 0.049626926756313736, 0.04936068438954892, 0.037102139960493774, 0.018142333344346093, 0.0917308854179517, 0.1080557517707348, 0.010701157584516032, 0.06354805052040086, 0.09526181530447737, 0.033108600220012094, 0.0384041523530839, 0.0752412029091389, 0.06142027578466843, 0.02445292324879237, 0.01434114104467294, 0.06136974079474326, 0.022895384144278306, 0.0186260259379783, 0.017736595942668857, 0.07722740842690391, 0.03897414858182592, 0.0438917588983332, 0.0712661105658739, 0.11182598454216797, 0.04288514617890601, 0.03227230416791093, 0.0362168027899198, 0.018558234817558722, 0.043418400830799536, 0.028052186262944055, 0.042901226364436655, 0.0133893036118318, 0.022246997968684283, 0.030080969032320767, 0.008688216555803534, 0.029710341440213305, 0.11435897765500892, 0.05383134751971211, 0.1349800957306739, 0.013337545754057507, 0.04377612941748193, 0.08763741716862687, 0.047734191626190185, 0.01595097905655782, 0.07684488540455219, 0.03185652335354638, 0.028436115056636836, 0.09241605913566966, 0.037811376499913396, 0.03976113538468077, 0.05906217671450108, 0.07696275569258199, 0.05069989418130248, 0.05397202424524773, 0.003085816044345378, 0.04547083081917898, 0.05160409243657224, 0.1155820906522774, 0.023575208653064988, 0.025746064343219324, 0.07752298813072905, 0.06854351069177352, 0.04434265526792696, 0.043137491710724375, 0.03719875130862479, 0.07031555633030592, 0.012613907719271318, 0.046443524995758656, 0.09347889121742019, 0.027738387073059718, 0.026868965379112673, 0.046610758159189455, 0.0803689128388801, 0.02847228781320155, 0.013129752065475672, 0.03238942752021455, 0.03877440647732827, 0.07517028614998826, 0.11893826822239546, 0.02225406512978577, 0.114211697251566, 0.0646350679979209, 0.100887359810933, 0.013881742056729573, 0.09182018062640583, 0.01752280761607953, 0.032258947424951105, 0.03287023579281184, 0.012105132449388266, 0.05237513694972281, 0.03650875889786309, 0.0899845956554336, 0.04859382654690454, 0.009111451405671336, 0.08979883465555408, 0.018091361684304093, 0.04824258289450119, 0.03629931045936481, 0.01967898506160465, 0.05585779563613957, 0.042189297025963184, 0.05680749568367197, 0.03692835291487075, 0.04534359127583523, 0.06707291299056622, 0.08082393076150649, 0.10912383921564588, 0.04115790519262514, 0.0017105329677560219, 0.10649288643992717, 0.0015914620763073947, 0.05772262984406083, 0.032137752315329934, 0.02807012038125146, 0.04809493476885462, 0.011171223389195099, 0.047552019748235905, 0.01231167166899409, 0.013308764788352195, 0.10450131064581294, 0.07693050339096978, 0.016610665029034983, 0.020364325403446154, 0.044920718402511654, 0.07139644510443173, 0.06662827555931385, 0.011148479196333117, 0.04461654319217609, 0.025160748271211505, 0.03115692994587364, 0.09332899079327622, 0.03435096500681774, 0.08989507828148142, 0.0582598106965663, 0.048833975958968365, 0.05709565199551083, 0.03704760599160387, 0.03179277526214719, 0.016244011518034725, 0.06348698565195646, 0.012851823985035862, 0.08950987395139472, 0.22299736227479675, 0.18386044299169896, 0.1921068125915143, 0.22795019731406244, 0.10355007459199238, 0.11939067378520005, 0.18335154610535792, 0.09281810207833206, 0.14793364661595515, 0.10408763848845998, 0.16862542098087652, 0.11372684786516814, 0.23681849241256717, 0.1547726667335918, 0.13790351789324515, 0.14168696568137215, 0.13085327201312588, 0.17975079496541332, 0.1722756614007296, 0.18893530051554405, 0.17048447122496946, 0.21044283594575622, 0.08274763116552945, 0.08912460067339482, 0.13841137290000916, 0.07731876441187437, 0.13279236312354767, 0.12011471114331677, 0.1589368602200862, 0.10188150444939252, 0.169395737710499, 0.14431288525942834, 0.20068780939665534, 0.1489914914653186, 0.1543687085711187, 0.17873995727108372, 0.16761723395076492, 0.308570685766397, 0.20866408703788636, 0.17717882329898496, 0.06679852327872669, 0.1414279819976899, 0.26723935358947326, 0.11739820166821442, 0.2013207205961789, 0.23526603055577125, 0.20118306991794419, 0.12229868991961404, 0.1053103990852833, 0.18791416659951213, 0.15482021015017264, 0.11158539462954768, 0.10676994979862245, 0.13876680705335834, 0.13696277724398723, 0.16313457771414713, 0.1833357034070838, 0.1890636355646195, 0.17482846554729248, 0.16933255077850434, 0.10332877477330547, 0.20625734521496683, 0.22680468136264434, 0.13486164321582164, 0.2338490743310221, 0.07139125102830511, 0.08577865037706592, 0.12244760209033567, 0.12371936167079596, 0.07806653517388529, 0.14161412604153156, 0.1775448447874477, 0.2331117606691776, 0.061995289889314485, 0.1870069499578207, 0.1660583829206805, 0.16678573743950936, 0.16399088015239086, 0.2533813286572695, 0.09195423069139642, 0.2786945437471713, 0.20768540971461805, 0.13984044863572045, 0.11275258320834368, 0.15344712011996778, 0.1813660913537587, 0.10795413020757899, 0.14505568411081068, 0.13869706240873184, 0.13393426313996315, 0.16143229970287892, 0.21567589062596523, 0.12481263042577814, 0.11025057835203987, 0.1864905454098217, 0.15488918870687485, 0.21582346980369863, 0.2357254381622038, 0.2386599992431941, 0.1751895840730398, 0.09162123525334943, 0.0880870035278701, 0.11279763683917061, 0.1189688810958497, 0.08472996027839762, 0.1252850079007687, 0.14543361060561674, 0.12127718828137844, 0.13684230225701488, 0.14282207815877854, 0.35586227392477376, 0.14786552607772813, 0.2773273832375004, 0.07734019189111649, 0.20925817290140739, 0.11271155153911923, 0.19654947903848466, 0.16269928655557095, 0.281294921953832, 0.13164074911225226, 0.2318431497100861, 0.17687444124490986, 0.19486328887362636, 0.20396432148352747, 0.14684164956692727, 0.15271959706179558, 0.16164188603720359, 0.152452431559082, 0.15625490897124814, 0.22040107497765174, 0.2583956039480625, 0.18380531530466773, 0.2024212978299587, 0.13136065204537686, 0.14658468835536512, 0.16545187111102766, 0.13166742429377573, 0.1641203030463188, 0.17595974758507746, 0.20879951606114067, 0.1435263274658111, 0.19989999521884227, 0.13429303743666218, 0.17262285244801354, 0.10125349621258437, 0.21063277978570233, 0.12638842732074762, 0.16448964935637292, 0.09406727738678457, 0.17133029358040902, 0.19741900415430147, 0.17121849070873954, 0.1634793785671073, 0.17143120268179526, 0.18697564760523458, 0.10095512028783561, 0.0859770211841791, 0.14049513205405206, 0.21120140088662026, 0.3790049320988117, 0.1497677836807505, 0.17827647407689404, 0.09777112863957883, 0.13607051463857775, 0.15386129789535077, 0.2104784437124768, 0.14323755828363283, 0.10885973806462942, 0.19087923330164727, 0.141907001454984, 0.16239649796437833, 0.1259345125647322, 0.11209945494849836, 0.1786331799361975, 0.16431272901113958, 0.17558698452288107], [0.0517692226886509, 0.0722812460134587, 0.051287824528351914, 0.0660047642586212, 0.059178576113716255, 0.047964186542817665, 0.05521743806199201, 0.009071166672173047, 0.06978670285353739, 0.03704376023022398, 0.0063630798549932106, 0.026185523020103577, 0.07281759949100595, 0.05481607310714261, 0.041874959659312046, 0.030823639563975797, 0.03818482904124164, 0.015449223067280988, 0.07616263814270496, 0.06156783581020371, 0.07846747494993672, 0.017003775386500265, 0.031045466068110643, 0.032229621579209645, 0.0862608720818835, 0.02660908537255901, 0.06749380169616592, 0.055189713340012304, 0.05492025340396551, 0.0594682875840414, 0.011576652440482811, 0.06113432963649112, 0.12803845813557987, 0.04679308325472859, 0.055193846384363796, 0.07137403703264653, 0.025800366570512136, 0.04053828561858785, 0.0683844018907797, 0.06199799801012682, 0.06301615567457292, 0.03803159613462706, 0.03557513903586134, 0.04409981688724891, 0.026699455019326943, 0.07109944813794668, 0.08215649474051692, 0.03755905778117238, 0.022988528944551948, 0.02583373544527398, 0.04174969662281294, 0.03720525539510193, 0.01970585368032898, 0.05887514783910686, 0.022384838253680258, 0.008431070525529645, 0.0068150904037118445, 0.027858618827116106, 0.04552666330710054, 0.05973700058436202, 0.035736274139414874, 0.0637314519694736, 0.013547372448468402, 0.055158541222373327, 0.017503226408734918, 0.05348892153931722, 0.04453208582896379, 0.0072514727587751565, 0.03945050205314352, 0.0165207167306254, 0.044675187222779765, 0.06583997108522924, 0.075115725368021, 0.03670410748811499, 0.025791953009883725, 0.025817772088151787, 0.027323784118878747, 0.04664574922513097, 0.03486741168965255, 0.016563583180428516, 0.03193141036336461, 0.0635124236014822, 0.036892691521995494, 0.02605792150021561, 0.019040469928914984, 0.10559148440558104, 0.028860822710539066, 0.08786873741736335, 0.015066442447864722, 0.005825229633163902, 0.03708716294157409, 0.09219985380167924, 0.018641707757788322, 0.0212246555489518, 0.0350416507271509, 0.05560877875635221, 0.026142547402771252, 0.030344924626631603, 0.07851144073591118, 0.13494456457274576, 0.02731786417444387, 0.029705070755294258, 0.049282148885991306, 0.0052792224901608165, 0.026700064059226748, 0.02062338569592084, 0.0268889794261345, 0.04807285994531647, 0.061545998473922094, 0.039714419343058145, 0.01625542048244707, 0.048422165395271395, 0.04192817595697219, 0.0432600389655319, 0.01986976202216841, 0.05017335429006527, 0.038168323676913016, 0.045891133467516596, 0.05705085500413853, 0.050590332116811514, 0.08882226407407753, 0.03326603511889135, 0.03203012079240815, 0.05547161454394941, 0.09637974442974215, 0.05982416606838665, 0.0464039986893054, 0.03487665837089862, 0.0033348848744701115, 0.05403359856216177, 0.027555226941683122, 0.051968807745124065, 0.08359837180544293, 0.01572970413572846, 0.07399507663062505, 0.06565886789992934, 0.06978562266956415, 0.022093389678986806, 0.021136149411059676, 0.05424666676610228, 0.055635243263696475, 0.032823446972836415, 0.023871778525532256, 0.018755594388611855, 0.027993990393776088, 0.04182503370928668, 0.04483618443050692, 0.02979682127554571, 0.03545539183241706, 0.023582247085869316, 0.023928421151433742, 0.03675900151832931, 0.05717525619172281, 0.014936549367473252, 0.019801932597352613, 0.03943910266483023, 0.04891728802073387, 0.014480146740923726, 0.04194591089241928, 0.0579320399781629, 0.021143457889857314, 0.009764284721665807, 0.05047372587385678, 0.01829670389152823, 0.01966403485576232, 0.02485216805531133, 0.05286860865570846, 0.04334867916881077, 0.06266147611782917, 0.04729078376605626, 0.07776378488708889, 0.047981687821447856, 0.05220534888306453, 0.04219805724137733, 0.013786865897747058, 0.10887453888332653, 0.014890858926059259, 0.037778361940816525, 0.03617324686098484, 0.052777877032396295, 0.047997450080489924, 0.04692817136885659, 0.0413055494878321, 0.02341638713504278, 0.05186812463967551, 0.04191675358602116, 0.043531770352274186, 0.04681624592311921, 0.09555816109622679, 0.023044298230219754, 0.04404071320389067, 0.04156777755387368, 0.009830715078409883, 0.04916317543135055, 0.08066746496385144, 0.08021689035118588, 0.013310622551568575, 0.025158649190298976, 0.06841358217981554, 0.01632662452456932, 0.07817383344856002, 0.007626306652391871, 0.052299512580277464, 0.06354870935601574, 0.03324733108222004, 0.03843467329598723, 0.006960219536502396, 0.06279572536568008, 0.05240999778071719, 0.026949954279247793, 0.04628484137356282, 0.05619232325003513, 0.0172613590445009, 0.03255517830351188, 0.028525703293722005, 0.029499399130262678, 0.059423728079925624, 0.01888611278827152, 0.015305252163670959, 0.0034857129832098805, 0.03280973399899179, 0.02121906119188474, 0.04046147764329949, 0.03575418527508455, 0.030096558921579874, 0.026171063110532782, 0.06609320910947938, 0.04175837639899504, 0.03971906183587928, 0.0254440073659944, 0.03780155908316374, 0.03239275234180593, 0.028173235815859614, 0.03470066116161404, 0.02417071369446574, 0.02047218100708579, 0.07954651745216501, 0.010598135995678605, 0.0026486041597015555, 0.08583370145530471, 0.02907372237513623, 0.09169032106236105, 0.05119201374210177, 0.03092984041769899, 0.06973919774135275, 0.0998699184386961, 0.06240460683681792, 0.04647782275212869, 0.015432330828550604, 0.049939536594695626, 0.029909625807176196, 0.037535634642887505, 0.07791695650666952, 0.014780982765519332, 0.0387435024904628, 0.008744682023872533, 0.04117040008667015, 0.01726138585757825, 0.03930282328397997, 0.008105565512162304, 0.06284948941620608, 0.0241185718351194, 0.012899915154482569, 0.09967553128878917, 0.03332427695333477, 0.03479981592165367, 0.021188396607495604, 0.027850000337967952, 0.05254124779434455, 0.1375823585136283, 0.02600399848644532, 0.07674838896960982, 0.04974539076248485, 0.019848233036276315, 0.0308432916344534, 0.028329812696263678, 0.011642144339519643, 0.09058608958918242, 0.04695982612188786, 0.007632118386907444, 0.04151660671097137, 0.012757057951192462, 0.02020324775648694, 0.034203523724910714, 0.022657351050105308, 0.017044989001606742, 0.028217873843987624, 0.03460448648359987, 0.007582968100905419, 0.03463987974570163, 0.10037654004390202, 0.04509355932954819, 0.044019546194542805, 0.02768469771610633, 0.10926662268297327, 0.031541011957151276, 0.018086207827793497, 0.01598966745434389, 0.08026677033593578, 0.00857911222884732, 0.02351233390189948, 0.00889131221018972, 0.024505243223581104, 0.05080261508062963, 0.06938105163675162, 0.031241119178312442, 0.056472849326148156, 0.08121376992353509, 0.07119414426626698, 0.011350408481854585, 0.029718565394080458, 0.024393164560258872, 0.0456420936050915, 0.03190854455404465, 0.02342617007783584, 0.040971738166145744, 0.07052879690402938, 0.020615429872827187, 0.0651705174917175, 0.03045059304924742, 0.016434752089422078, 0.04259489844703386, 0.0690088018534645, 0.04036919852238029, 0.0446194083610129, 0.02433096396646673, 0.04275362803450516, 0.10332954852210899, 0.03136665609124447, 0.02672843037984304, 0.032777267192760785, 0.032844027924922206, 0.08743097179479177, 0.03802280910613556, 0.03318302949229556, 0.05170831486823098, 0.025617229421773267, 0.04457954880631259, 0.03582735050229296, 0.05436416933192842, 0.0234644802197093, 0.024246280607316765, 0.0430313119244191, 0.02263474379545979, 0.03646528340816017, 0.03846823560794996, 0.049598704077183246, 0.030458493330966563, 0.06302805685047662, 0.029268065474987514, 0.03366966003311738, 0.036563020905539874, 0.12817863690396472, 0.22098572263794564, 0.133765677831346, 0.16556601821174546, 0.11644173323387101, 0.22524486506177535, 0.08785261126655726, 0.19854450988913738, 0.11565447063936342, 0.12103485168829081, 0.12239746163569151, 0.2898511434755018, 0.2570421717339947, 0.20362382604470178, 0.14538462694373824, 0.19829995930194858, 0.13603964129522925, 0.10704320570033406, 0.19844744654913105, 0.19889566927186905, 0.11343558123635669, 0.08867082381320578, 0.0997638765482172, 0.10946195212102706, 0.23083294020785441, 0.17694000304946977, 0.20385466365804597, 0.25181357568550494, 0.2577904251313979, 0.1556603174896971, 0.06005650521406244, 0.13295828244618832, 0.30506571093874596, 0.1434607350177342, 0.1800865100155915, 0.19481949928787448, 0.15469444915652275, 0.08142806003771483, 0.16265169717371464, 0.11915486426122728, 0.1342164592877511, 0.12355054653580151, 0.18696066292543567, 0.15937040469819502, 0.17467823570534108, 0.15811092550716094, 0.22904400233059163, 0.11737177929570598, 0.13419105581218196, 0.10678257492761459, 0.172097974967572, 0.13507784854981209, 0.08811069096648887, 0.1671785873270804, 0.1503349492146123, 0.0916849967512873, 0.1423916593194008, 0.16484105388724035, 0.16170282067070085, 0.13693470778244157, 0.21214664613287296, 0.18268610681256942, 0.20730064971552742, 0.21663936876481582, 0.11774899332874245, 0.1970928805249353, 0.1714049565095094, 0.07915545254945755, 0.21793914418066704, 0.19514884048652267, 0.14044722091526757, 0.15687029207906417, 0.12668357801533517, 0.26382106927133375, 0.14133160813681542, 0.12267397341108131, 0.109026821840915, 0.20660344841739825, 0.1534503989762837, 0.09221048710206825, 0.21907611059085016, 0.12093753553926946, 0.16853819420981794, 0.168349675293411, 0.12556692825690394, 0.18221623444509122, 0.05215777099252709, 0.15000113406248633, 0.2279811472662034, 0.16603304073214534, 0.15366674220610052, 0.15768078245943593, 0.11167321894918719, 0.21078936815742524, 0.09282194783971195, 0.19734331466738256, 0.15672835130845347, 0.09715256626687704, 0.12163102897184512, 0.24537848308682444, 0.1365425626957609, 0.19174644483193276, 0.16871725960123926, 0.12111565864254391, 0.1826982569670485, 0.18621631657644627, 0.12441156041477958, 0.08014774325514033, 0.13363997812473005, 0.09325830386050286, 0.11448518297965489, 0.15699688044767227, 0.1554817883598228, 0.16116314237156223, 0.22354886897148626, 0.12222162913531066, 0.1901577316945599, 0.11645466479803286, 0.22306784236383057, 0.15801061395435564, 0.18907053035593804, 0.08109426020734734, 0.18797548427697153, 0.1589655885172467, 0.11508388835335932, 0.1159635871168106, 0.08941214411489426, 0.1622778156231488, 0.09396824520081283, 0.15807462826130853, 0.11095639047843796, 0.12803302657219673, 0.19363577087079326, 0.06576281837037494, 0.15688716133515682, 0.25084162461421183, 0.15538087925843655, 0.09135580110934474, 0.17971052938411314, 0.1185418866694935, 0.13136417604982853, 0.25576962308297235, 0.12585818722483613, 0.10286254898434687, 0.1345741304178392, 0.11149803762354198, 0.1267522961021431, 0.18915404926144308, 0.13074395126633107, 0.09077499921043074, 0.13300769511730443, 0.1463144891444714, 0.12696602697213813, 0.12491475760696397, 0.08886848215854938, 0.16359113547350132, 0.19786387141193115, 0.0532530315761124, 0.09781814345549192, 0.11410803023365237, 0.11211841562462431, 0.06613146754041796, 0.1367353563827853, 0.22115720375891657, 0.10911653839772749, 0.12889533513976684, 0.14031534653998193, 0.07429837850072692, 0.16040508304872822, 0.1537784225037021, 0.18497836445608448, 0.10997998843630476, 0.12370461447825357, 0.1467773135030462, 0.14725987228655046, 0.17967945685790432], [0.022419032588180517, 0.049889185465872295, 0.05744796434056856, 0.06417818465119889, 0.030247081792162313, 0.05153350892566866, 0.042919853792315533, 0.06767364849727, 0.1032974417772024, 0.06032242965433867, 0.03522509814149911, 0.06794981553309387, 0.01547110828405787, 0.07133168003131306, 0.06262853816752473, 0.045834998374864946, 0.07451403225141187, 0.0309262627870926, 0.06537601291652649, 0.030572316759536346, 0.06791131195401953, 0.031360349272407835, 0.03092618617830017, 0.12045515295598777, 0.033459468489332546, 0.009073459190286456, 0.04179549335892643, 0.018431374487737497, 0.06739525214558648, 0.011712695291686443, 0.06125857760649055, 0.02653678965514466, 0.03714328271246726, 0.05545411709575884, 0.029344545947688244, 0.031022881796102852, 0.0322343751547798, 0.03803044700274064, 0.0451065177067874, 0.045031866269005884, 0.037580033268539176, 0.013473830880567193, 0.023314482119354992, 0.04324422691077475, 0.1020403910848883, 0.027752356686358972, 0.07179142471643225, 0.00836849550626451, 0.017935660059353518, 0.024768599354091193, 0.017290388031171697, 0.06058949939606171, 0.0314936236733751, 0.039531420090145646, 0.04966030520717463, 0.03690984040018051, 0.07377580694493747, 0.050588807601842194, 0.02127998624928296, 0.04251561600775008, 0.06742332160713212, 0.06085469222237026, 0.02710118386594038, 0.056116813793778426, 0.020849860438536254, 0.010862177774880924, 0.0746571604583052, 0.04994564231545214, 0.02593965284646519, 0.05170880516450252, 0.04994770309196846, 0.07482936936280421, 0.015742829137091196, 0.024162882360659783, 0.018067463571506164, 0.03769114666107682, 0.0327231124373934, 0.05965044797067681, 0.03165376477784688, 0.018731960576147805, 0.039870934936428265, 0.01382598426238063, 0.08652394667508141, 0.019034582543216886, 0.06518212372377034, 0.050856578314015945, 0.06712951922729131, 0.08155469437159839, 0.03947263433327598, 0.08733373991544209, 0.013619513033078083, 0.06673257076932539, 0.08185608868276881, 0.0338783806880876, 0.07121152680126891, 0.016272414227827423, 0.04814130990135093, 0.029095038771629337, 0.03351468427647506, 0.04456349926429891, 0.12408876160700476, 0.02552800699167194, 0.043788153167453506, 0.011361221812905805, 0.04321685458924021, 0.09716395033343185, 0.010010520702288037, 0.040550416620868834, 0.04032947303306672, 0.02199253420375528, 0.09012442968425252, 0.054351122854577924, 0.062364915821460955, 0.02988925552926958, 0.028129896306763255, 0.008749260356830013, 0.043079920203214696, 0.02662417347422771, 0.03944311696555346, 0.027177242990282756, 0.1280055163548358, 0.017979428577687473, 0.04510674753316468, 0.042126765099143794, 0.017676984726060784, 0.061778950489937305, 0.027856320563343265, 0.009250516473736254, 0.023973932519795436, 0.08525321365243967, 0.03490770025359046, 0.056470095240060365, 0.01142323663037631, 0.06428559400862263, 0.02757540761282848, 0.1241386492526339, 0.03733855852436635, 0.007145797632890003, 0.022152589123335578, 0.056868744413218195, 0.025719329789881746, 0.023782161560149926, 0.038376603831326773, 0.10316407353046442, 0.08821831865897102, 0.019407849308223497, 0.0770795764401555, 0.10766714601026428, 0.04366252240875075, 0.005459121959809695, 0.06623054569166514, 0.027082037413492802, 0.07231673120611137, 0.036350569402378415, 0.0926555841860752, 0.04517774090110775, 0.06979398068881805, 0.046031768058216384, 0.07640800078309352, 0.06505493014570206, 0.03956602045124577, 0.030004069126481493, 0.041895441019967686, 0.055546767769321326, 0.026022104974535686, 0.037232179555200764, 0.030935595653230147, 0.047171071036568576, 0.06308887274034562, 0.005322187094979229, 0.02620547961053108, 0.03827165744657959, 0.03066490040040545, 0.04220681745679148, 0.0675026040464159, 0.02373117266312963, 0.004303262863803896, 0.0018668246001095302, 0.04414636055908857, 0.02943942785233019, 0.02052200545046118, 0.07482783718695564, 0.03493344846872553, 0.010940478664011726, 0.1154377673482222, 0.005364394230362509, 0.043288299949058605, 0.023646631030245654, 0.07792903005235619, 0.01848169114260424, 0.04020245565522102, 0.014249105156669694, 0.023625571273207188, 0.027636742527266184, 0.08024027135463492, 0.018989174596724973, 0.040524963349584615, 0.0177367644820122, 0.02042358805004868, 0.03730036521090135, 0.03271859251864014, 0.020698353144971114, 0.03913191672895224, 0.05373855511988363, 0.042498532247038624, 0.02013088883681884, 0.06608099000708711, 0.07352643000382571, 0.01500039034703326, 0.03037036832181677, 0.037776182420671954, 0.022463023272012512, 0.036331206530092225, 0.0900435844256032, 0.04009031953530447, 0.03764975493052795, 0.03503091400489211, 0.023381279240692818, 0.03753152458117374, 0.03014019337452708, 0.15490922956697403, 0.06946456288137744, 0.029659994141829592, 0.027732518839559732, 0.04762000622107618, 0.04484214842499745, 0.05703329626891402, 0.029280035598804394, 0.012918479380107695, 0.08311937533078656, 0.03148576935693141, 0.07820645347237587, 0.028033501378470854, 0.0070976681590470825, 0.03456816242467012, 0.02631932027607916, 0.1268330494302415, 0.04802204533329895, 0.053244233056302034, 0.04829131374736467, 0.029284612974151972, 0.04980089000215934, 0.017504099748968598, 0.007733276466869059, 0.014409298929686268, 0.10750825171388927, 0.05036665742555934, 0.045587628584114775, 0.057745110694198847, 0.047186473234286236, 0.02554898247903874, 0.05558528283971453, 0.01834527003548799, 0.03201902209360513, 0.035865685542023955, 0.06421134093656175, 0.03199218603361759, 0.05840388885248573, 0.036406210368318905, 0.0075579026616328674, 0.021493958436974117, 0.06138836439218252, 0.042530577704911275, 0.08479300165368665, 0.03109161903510892, 0.09765480584915608, 0.035221355801989, 0.02473767621502761, 0.07211277561803019, 0.0751425537671293, 0.02916172481021814, 0.027336865070185838, 0.06803380175223274, 0.04083200755919661, 0.0282681790075355, 0.021384704722872665, 0.05929846504342653, 0.007900317629513843, 0.009756669807698458, 0.010736399544252744, 0.027747794632769884, 0.1432409903575336, 0.021832130714169434, 0.018843918580621965, 0.022834968535349737, 0.01070114130514764, 0.06360613913725942, 0.01973560087442879, 0.022385903115895008, 0.042579009783484285, 0.0531568875416152, 0.039818274052513224, 0.02096841637525828, 0.03965860600733469, 0.01917080446747282, 0.010743950298356434, 0.05746346996015599, 0.03449344203897542, 0.0842262038420285, 0.012050879060200626, 0.038975163648325595, 0.051575938705354936, 0.029587868878978397, 0.05268115460151627, 0.029695375912612485, 0.057771820349678885, 0.05364960848143505, 0.0020982363005919804, 0.07133056920382284, 0.06212090915669838, 0.019681486338677428, 0.14877807469137255, 0.017624009746096788, 0.014672707728741151, 0.02947887180433158, 0.06282739544046984, 0.02666221548532767, 0.020697066117258325, 0.05698542726496535, 0.02477746490659493, 0.067120012076151, 0.10571980413289801, 0.030267704879083944, 0.0576688964370518, 0.07910609350449617, 0.022969072226495035, 0.01842753830245666, 0.020818743862271793, 0.05865860159599012, 0.05084585308307602, 0.009204892107405731, 0.03269608102498516, 0.03795139438983414, 0.052312183674545064, 0.06673591857355449, 0.057443969192043434, 0.029401856985303666, 0.04329291945924202, 0.07049469833051966, 0.07234458616303821, 0.037180832512075865, 0.038372348212907394, 0.0292216558685346, 0.040250466385435675, 0.02248342610865591, 0.03113251472372682, 0.0512221401497241, 0.01563073227918076, 0.016586642426949356, 0.0689935720255298, 0.02526491707671554, 0.014526451967896955, 0.16037270817304813, 0.09884014305087829, 0.16530849009511933, 0.13310825181824545, 0.1452569200867607, 0.17651365979784922, 0.19997327918967894, 0.11237883955360421, 0.2485415835173861, 0.10667341505928386, 0.09251971083182482, 0.18245195969939235, 0.17689083552648946, 0.28903381959084545, 0.16738274975890116, 0.1405008317482087, 0.08727345645668046, 0.1789637928408, 0.19038394213684146, 0.15081882566934632, 0.22267260228193578, 0.18652990700737124, 0.11013217180246308, 0.19265585248508763, 0.14377886068917092, 0.1346789925329147, 0.21381040524330833, 0.16021198292653407, 0.13729035644040954, 0.13022819023218848, 0.2442319558993463, 0.15937737609830596, 0.08609270046074545, 0.23306806301397665, 0.15405807523958145, 0.10794233245354508, 0.11630876335285364, 0.21312979740961907, 0.11205573431065968, 0.09257828591451531, 0.1208424716887455, 0.16098288188297905, 0.1045384735710198, 0.12869878762191342, 0.17938000841006158, 0.18617461074984845, 0.19877504106731186, 0.11816029061353016, 0.13166963062699766, 0.1079994826126964, 0.11798759907363884, 0.1386743249191392, 0.07134712436386655, 0.223256912863543, 0.1385979919183639, 0.18372032551034806, 0.16210155411353036, 0.15059005649339768, 0.07645499261636889, 0.23429317550072748, 0.18686795096483924, 0.15765913281469576, 0.18895390113034558, 0.18538797634743875, 0.14252537230570472, 0.14214481046843913, 0.10242349633406247, 0.12361353428493585, 0.06315678260439346, 0.19620469350728298, 0.14789477531467715, 0.24567529619220765, 0.0911929308166427, 0.1576993524307205, 0.09474726468925515, 0.0969582097604871, 0.10149102943438677, 0.13578790480331068, 0.13403043781797733, 0.15829831061343994, 0.16901525248202587, 0.12914276621755094, 0.1272543288406826, 0.1006955926817271, 0.1696075303780456, 0.23366443181951202, 0.09431373553290483, 0.16149193198690492, 0.1549608179277951, 0.19347769628849723, 0.21557652902218605, 0.17858980403792474, 0.1718647011946286, 0.15801001640577472, 0.19252166452427066, 0.1373253513367907, 0.19290021921117462, 0.13950684798821328, 0.0980438789232604, 0.08354759549782162, 0.2112156194784949, 0.06337886766320275, 0.1187004362263026, 0.1308098348278192, 0.22233520183832417, 0.23755196031303177, 0.1549949701274595, 0.08497535356230314, 0.10547096345333323, 0.13572013666552885, 0.23510668426752093, 0.13339764919252167, 0.29900696669374743, 0.19087368682507547, 0.18552381905817217, 0.09055834954544421, 0.16842413903965106, 0.09844041369374722, 0.1299116273801173, 0.09554074025682865, 0.18803169980885523, 0.1229632635330481, 0.21532900601385102, 0.11465965184353052, 0.09639215505411548, 0.14805225234839225, 0.12775043205868813, 0.1507751893011793, 0.16006628832509442, 0.18498827763382467, 0.0948978775751687, 0.11730471595881448, 0.2103220238800972, 0.21826509927068988, 0.14927384083069142, 0.28893851825306494, 0.15696295807438512, 0.07719318727932631, 0.12509229848341596, 0.22312802623116204, 0.10518628518067061, 0.11719223126889237, 0.13070498803450217, 0.2860241665715172, 0.18091324145995802, 0.1990790860427003, 0.23572772110421814, 0.2294542424140438, 0.23104364503054853, 0.1184030945202516, 0.19025755295109367, 0.08148179344472387, 0.1279466118543379, 0.15980287665320983, 0.1609454355052402, 0.1503631565719843, 0.14713193560319562, 0.18414812432902475, 0.26339022142271845, 0.15724374462039242, 0.16784301538380886, 0.14053879906573605, 0.15779028706733259, 0.21211152866242394, 0.11480079588269997, 0.20867858142141374, 0.14703536255946084, 0.14508562282689158, 0.10937621156054159, 0.08032010537722419, 0.11811107712527437, 0.09383650872135356, 0.06439433252859501, 0.17880702060797524, 0.15521224798454394, 0.09916824318708913], [0.026030183371697223, 0.04349071186997237, 0.06549055838296491, 0.02846322690827712, 0.05344615851138389, 0.030120696436854142, 0.01964155400562431, 0.03355738601737446, 0.029404507649521676, 0.032349031703967246, 0.09790660362810859, 0.022336856251762762, 0.015960733271053722, 0.01932872966262362, 0.01946519098935589, 0.0398683455592442, 0.05209555699219627, 0.019063142301034064, 0.05280686196901145, 0.03310162881990114, 0.06076496800467853, 0.0061684523450000394, 0.05950512875232005, 0.023342831202992992, 0.03442435239952418, 0.06628673824091112, 0.0611512755013762, 0.024803529132998763, 0.04598855686884734, 0.026478653157790823, 0.018524810401422363, 0.03280351336504663, 0.013553526049720184, 0.06447340046326, 0.01912333382924478, 0.0413743480138721, 0.04006364818422064, 0.08410999596479439, 0.026569197089561535, 0.10522898692157, 0.046736948162076936, 0.012770216468901885, 0.022064408572811275, 0.05330339802669422, 0.03513442397478127, 0.06386383962366851, 0.026064948441701073, 0.09054224637727584, 0.041812676711068045, 0.034063773965763475, 0.040130006720221816, 0.024889248626066313, 0.04822518120730116, 0.07732961987776142, 0.05536794369559615, 0.059676019985589294, 0.04710069819984417, 0.05639335238224557, 0.034574995928954695, 0.05233810425946309, 0.030472175661294214, 0.0556366260523998, 0.039039120498684146, 0.061542857513432546, 0.03203250715629228, 0.052433489866915255, 0.030635193425921664, 0.04265782107869464, 0.026456990106511983, 0.016826565843075514, 0.033467244281763994, 0.007029037693545463, 0.0775016449211586, 0.059668504663052103, 0.0584372443207089, 0.011815461198679142, 0.013221438425863463, 0.0607927386919337, 0.03216222499407107, 0.03982390862919631, 0.05976846381541222, 0.07594162177655005, 0.012287718014821652, 0.05914787514015071, 0.09154638080226798, 0.04112158879457463, 0.006295007197261458, 0.015262302401806078, 0.03737495919208854, 0.03935883580256374, 0.07215658818641979, 0.04147529925009416, 0.0386178104447261, 0.05239638439830273, 0.06792892431539875, 0.0397069308335983, 0.018282402945201726, 0.0673262812497635, 0.03129304270260036, 0.026621099546431538, 0.03578503946623495, 0.05271683897702925, 0.007982331651052641, 0.025832814224545034, 0.06325881402458876, 0.07604748746680637, 0.016646272795755538, 0.10008120548821266, 0.03734519667623024, 0.030794329039992827, 0.031938969735957445, 0.012020648273098613, 0.02319533246449165, 0.05595108216267921, 0.04437298851928884, 0.0990063764695679, 0.0479176773449346, 0.011071071757244007, 0.026695724171135696, 0.052161118796756195, 0.03936258580295309, 0.08574300430594914, 0.05037680426011643, 0.026407449115668575, 0.02966020098556915, 0.08471853024656735, 0.0418195600110677, 0.04932516089250003, 0.03305213953999262, 0.02411177472001122, 0.004615212430156047, 0.04982381901373306, 0.03214728244910798, 0.1032563334991855, 0.05777688419085838, 0.021929195969395583, 0.03641701220805126, 0.02687255641625774, 0.04402590089387471, 0.038001132648318045, 0.014891020762133262, 0.05874901912325333, 0.008055157884354553, 0.024195071460018237, 0.04274244698125028, 0.0538083840341818, 0.01072095712691906, 0.02295265113183808, 0.02662517704940852, 0.013491280448262491, 0.04837535359265824, 0.024140242547277483, 0.01782063770318224, 0.020242839180413755, 0.039048359519050974, 0.026341211238515475, 0.028084337057906295, 0.06576408241545001, 0.035212300642724, 0.06471589793481174, 0.04085736889992991, 0.07731704071404473, 0.014685401805646479, 0.04132716082817605, 0.023504868375077367, 0.034073307929981145, 0.03436831306786307, 0.041873845001382214, 0.04226190300898687, 0.07559594758335622, 0.029046556897341248, 0.09019115594245734, 0.029742622470122673, 0.01825952947500252, 0.04300100165569494, 0.02510843021164258, 0.09672902689705934, 0.008087288569508782, 0.1185014908532462, 0.08057800121605396, 0.04496510936728409, 0.045987626072019346, 0.05139398516245908, 0.10328021245978533, 0.034922700255147876, 0.027473757321375514, 0.07131768360493645, 0.04473160959840302, 0.05684397296018659, 0.041781002805838664, 0.030192725938714804, 0.042919555018025066, 0.01556938204298457, 0.04002520206174062, 0.08293690850898143, 0.08442034584379966, 0.06682735882819661, 0.049291889693948536, 0.1026523191361658, 0.024295557297826297, 0.053716357722277605, 0.042262929566805406, 0.019371354794730584, 0.02534291823394597, 0.05686754165517707, 0.00883417162713745, 0.07901748011429464, 0.061232534447504636, 0.0471909586790829, 0.005638883533632203, 0.01123486805872451, 0.04758467424600836, 0.0630150946427978, 0.06816612045851446, 0.029000852091778672, 0.055544258831369306, 0.03695254597151953, 0.02203036937111568, 0.022316731121991912, 0.029820956875600164, 0.09068601043714632, 0.08966300726657914, 0.006975204695106274, 0.04926696502333207, 0.024604800179780974, 0.027842527150266597, 0.021552047053832683, 0.05282051748626175, 0.03778607644621403, 0.06952088566557055, 0.05633564297890952, 0.050260278456393755, 0.043842943775798046, 0.03621333624206243, 0.09669859788470692, 0.06051706578282099, 0.030899710179637038, 0.015550830266288212, 0.036179869691090244, 0.027443674963808833, 0.011097782370333951, 0.04863245653048639, 0.053262251444281115, 0.05252394569857467, 0.050912426123695995, 0.02499461635917185, 0.0376857572325295, 0.04556134410743271, 0.013259830922188779, 0.02785630141114516, 0.0410776459912379, 0.011623252611306888, 0.014358447928492342, 0.029596774651098157, 0.006489966519086832, 0.025224366127663565, 0.01498995622950456, 0.038722143959133856, 0.06612764476167579, 0.010305759496986866, 0.12664332775579346, 0.07059719323390914, 0.07901000309615366, 0.015904692024172797, 0.01521448989684183, 0.050523448810582204, 0.027395118395948125, 0.024928328686303673, 0.06184116449026812, 0.06701914894004023, 0.0393619959152514, 0.011533839616834397, 0.024953898785996343, 0.06738648809973272, 0.0024319468338357946, 0.011325160139090112, 0.07356242847538765, 0.01167126238391164, 0.023347077245313316, 0.028521800075747797, 0.06689270612813773, 0.09803124613338902, 0.035933641371347254, 0.028214405380910444, 0.033137152316950025, 0.014939746826947218, 0.06495056598777733, 0.07016781627410842, 0.014449194873562984, 0.027012480460407755, 0.043479059672644066, 0.03636787915902753, 0.0382869792050652, 0.03406425277071615, 0.03605755609309962, 0.041856286266157706, 0.05111691031244494, 0.08620197524226482, 0.021723520513924382, 0.01156766239869138, 0.021303399811468778, 0.019869449841339263, 0.008447776030328487, 0.024726926086230144, 0.052724411756160765, 0.029245456305122184, 0.04817360433779898, 0.04162407735542905, 0.03625169809487078, 0.021199696404378743, 0.03245172579021704, 0.020061481270879027, 0.10403528403971465, 0.01893625515813549, 0.02546293931382318, 0.0677205560608737, 0.019907989809590004, 0.04987276437121534, 0.013604551335916886, 0.03462028321659854, 0.055075045299506, 0.049950729139269366, 0.036386046934151844, 0.023991272919961525, 0.018290132772357717, 0.019994793317070412, 0.049972961010831984, 0.03527433844283223, 0.048310278253930236, 0.042025522749510505, 0.018827884360366774, 0.02502359363490776, 0.029839390866278164, 0.06796811737360493, 0.024429731852104588, 0.035507458998190786, 0.043345905930524876, 0.012584716896526517, 0.029863842477601384, 0.036482122020735856, 0.06260326492690271, 0.04833553234235414, 0.02055885044917945, 0.037005693321266485, 0.011461868529177962, 0.005569669404893273, 0.05132167029284662, 0.04657241928901884, 0.030603513775032856, 0.04091467227666609, 0.005473780573435849, 0.013320575948924789, 0.2663205690201252, 0.15844297865706106, 0.12868933409692782, 0.291665147749647, 0.24372236953387338, 0.2181971625935647, 0.14563532155607978, 0.14184848765932745, 0.15404261558526947, 0.2546619671967722, 0.21656616140277157, 0.11661172814426884, 0.1260398190108038, 0.13645944215597647, 0.12495282451592146, 0.15429263604023766, 0.17296975238188622, 0.22071854181347356, 0.13375567272305489, 0.09044131429325189, 0.13512801198709395, 0.12647768422480554, 0.1730826277766497, 0.09994914725182519, 0.09345178702665914, 0.14983271729321251, 0.2254731899067279, 0.07694945640621648, 0.2067942043105441, 0.08878232024970556, 0.19637553111439754, 0.15170417816167878, 0.0979561465341718, 0.11834615120483984, 0.07406552607614188, 0.29379527054486737, 0.1360384155545504, 0.3142531582665059, 0.05541035432308432, 0.1510517163983276, 0.1682501145067715, 0.10523925249975537, 0.18227186775015247, 0.15028535268239437, 0.1894312811594817, 0.16083657441119995, 0.17508639202963922, 0.16965875101666297, 0.20032958668326178, 0.16661794886233347, 0.11552904672440022, 0.11486616616527881, 0.19391041339164783, 0.23544057602843932, 0.18952500435613817, 0.1634905481290433, 0.14407832445877214, 0.21954491043523436, 0.14824015839445978, 0.15129694114288977, 0.1375337885392289, 0.15883883160929527, 0.15185571035310147, 0.10871742191093584, 0.11330189889356976, 0.12399102410962506, 0.14351972378790379, 0.1286309888406146, 0.12854003888224402, 0.16280024162223264, 0.12206683340933054, 0.1266668696377066, 0.16718022675523836, 0.10263422413939431, 0.13613471280663245, 0.09069809164371222, 0.09628349314293555, 0.1407747694681729, 0.06649868412604255, 0.06825432782211611, 0.10021619018047087, 0.21764443015619633, 0.14585882004710937, 0.1726501404998764, 0.23231792504027968, 0.13474346649262214, 0.15989614019711174, 0.11745866132719864, 0.16399625808961932, 0.1643014215533772, 0.1825348197692825, 0.09536260949267496, 0.13191844066304545, 0.13572674034343613, 0.21443453707521964, 0.1822272201459254, 0.1292786548935598, 0.21497439923546008, 0.14867848326121608, 0.11206026189029218, 0.13614010606561938, 0.11390221305191518, 0.09332610264180169, 0.07695732412919884, 0.16036748345340454, 0.15815272326430968, 0.14211900862714938, 0.16888311763684596, 0.09804691263144055, 0.09774428491871204, 0.13882916661039477, 0.2651595474491196, 0.09209181242171796, 0.09817301070377712, 0.08745527210374994, 0.24469560763287931, 0.12638442834178287, 0.20551555759964452, 0.14318155725636791, 0.14447587812619825, 0.1054991478280675, 0.18343080556200397, 0.1211276479185589, 0.14086962647495732, 0.06953307412444584, 0.1576883973734033, 0.07475963237905696, 0.13546706718062201, 0.1617715540792673, 0.09015572437595937, 0.13730866594179986, 0.12930137706139397, 0.15040049569741373, 0.16648849532488855, 0.14358603635862952, 0.1145936763514915, 0.153016731924107, 0.18050385939498104, 0.1583453177684738, 0.12587239815583154, 0.10229389723991195, 0.19555575574838346, 0.09904887902760699, 0.05696864993942361, 0.15928604309597325, 0.15841901542678957, 0.15499193641927936, 0.12072531386248528, 0.14750883554018315, 0.12565744154515768, 0.14720071497703754, 0.11012163809350423, 0.150460894069364, 0.12044235162677304, 0.21802022692657289, 0.07469409355713476, 0.1427534213590045, 0.19537842171567102, 0.11878832949385529, 0.25911477664786003, 0.24553884061113482, 0.17812408386699616, 0.0946374383244303, 0.1612505836472396, 0.14458723666687168, 0.12180573532297728, 0.13580733279307045, 0.11860534173226166, 0.13646843602820752, 0.2259816884273483, 0.11850159044467634, 0.26629372529925843, 0.15323028659387944, 0.12321757408039224, 0.09061274944894737, 0.06751421027846875], [0.015175499851935574, 0.05582221468249637, 0.030613227769912734, 0.012112254194254357, 0.04468922961443182, 0.0639248317137601, 0.028685147258182688, 0.06294227798559493, 0.022200019541947592, 0.06520778766923374, 0.01831163877561208, 0.020190392801117514, 0.03146317742404438, 0.06058693683195499, 0.03693338611253327, 0.03204639058470005, 0.0526238895291763, 0.10306779926102008, 0.02827926813023946, 0.042859746533776485, 0.04613622797713165, 0.05606736664870574, 0.03702480338453766, 0.026564020250413208, 0.05389664502393815, 0.018357866436182972, 0.04911058732578832, 0.04464548599395541, 0.00299860387683786, 0.03779125903102179, 0.006117374390258544, 0.026971255353982412, 0.07740461988554848, 0.035927390093885125, 0.027907841891470938, 0.05220591961856812, 0.060954862048909556, 0.035116800122083194, 0.05780236044478032, 0.04211971325980079, 0.03001349009273033, 0.03449568284615394, 0.04611367051820121, 0.024084042337152268, 0.11477404409238409, 0.053673326563570774, 0.024912901590728474, 0.0380041127303435, 0.02521224470148164, 0.05660764632686492, 0.06243224728912596, 0.026887433843747265, 0.043300994025963935, 0.053873769638519135, 0.05677486033809762, 0.033984131465155276, 0.016699379925886472, 0.04535350828401504, 0.04341602212779465, 0.03847861609932396, 0.067212363975423, 0.007538141423626053, 0.005465882206936517, 0.05625670144875204, 0.0892438269370506, 0.024353785725731044, 0.014982463889605096, 0.04869921343220819, 0.04073048558747096, 0.05289216585938008, 0.11051479441624497, 0.02388588028899845, 0.03151363772039693, 0.04231231542484414, 0.10809126760690443, 0.07181161113323704, 0.03923786285844061, 0.03296991532307959, 0.028846809047184167, 0.04087961226281139, 0.06938775490608907, 0.04767016199747882, 0.03038085606550017, 0.02688194099333017, 0.02714209870675639, 0.00882778053862914, 0.03481829396238731, 0.014099035235572488, 0.011805998097594467, 0.03605151932025629, 0.036062757830105485, 0.034026683818909435, 0.0791707436644262, 0.02961770608840931, 0.030525658174508044, 0.09267503515847268, 0.054617859348053896, 0.04398175124679843, 0.028345954168828267, 0.04359899456762979, 0.012835516845957648, 0.04346678311365747, 0.05975953123021511, 0.014912386954341446, 0.06288140463913161, 0.07917969923226104, 0.10167376438696539, 0.032565960991046125, 0.07123040320772318, 0.03160991007462144, 0.0035885315587473737, 0.010841098865644347, 0.03904958525972982, 0.017703895479620948, 0.02503176587784002, 0.05931694308416017, 0.041145892933972424, 0.017032731594818256, 0.07199035476773016, 0.038911099545657635, 0.024473021565485868, 0.010352148036021861, 0.020826803107235222, 0.04709985167268784, 0.046609463470597426, 0.03352075169283537, 0.05800240898444768, 0.020914740424843568, 0.045851722074251984, 0.012974820358888998, 0.07891391268781117, 0.06362878086586153, 0.05939059094676088, 0.06544411813299503, 0.09708100599387, 0.07052413908944977, 0.0222882000924719, 0.0521875181866269, 0.05283210073567687, 0.02387225350004531, 0.060109024371711485, 0.014981808884429836, 0.001732554165139464, 0.03350571721732136, 0.020430971222418933, 0.017262224723855336, 0.039090689707307086, 0.03370992178397794, 0.08297338195505642, 0.05394988430423602, 0.052413878016053676, 0.04640853776025676, 0.06207114791557674, 0.052250402513891465, 0.006768581205828777, 0.02251996658742428, 0.04696149619356279, 0.03233468287714547, 0.024765443071843158, 0.008849218551580225, 0.06417557612181672, 0.05873793000054937, 0.13043498800646874, 0.023863617773918856, 0.07237060250894678, 0.0440815954859699, 0.10167893548045429, 0.03028935643904392, 0.010783878800969933, 0.011856750464968145, 0.043532731792619156, 0.024563272468625538, 0.03570304507569921, 0.02741895139127249, 0.04169721959999973, 0.02841400384392229, 0.020379955512321284, 0.07273464749056487, 0.029662495418902368, 0.05218233177137952, 0.01259858979122533, 0.02011436815073173, 0.056772631022237965, 0.02886566630144033, 0.027005562686451504, 0.11186913061406344, 0.025250430354067398, 0.03833040489905304, 0.008956482352298355, 0.035383130588959304, 0.0041609792688470934, 0.06573742255568504, 0.016003122831123973, 0.03824220902677025, 0.057467993709348866, 0.09243837527690396, 0.0395421146775686, 0.02081223977579465, 0.031552721611073906, 0.05162840423684928, 0.04654992311712235, 0.023324537023361173, 0.08645283073307046, 0.042171159894355846, 0.037508289134430314, 0.01659970997171777, 0.028904213930570313, 0.016835982978884733, 0.03346004305527576, 0.03841599607239327, 0.01815445285530821, 0.05153311439038766, 0.03756658076458881, 0.017267602661083785, 0.0499995404313649, 0.07224671843071138, 0.08673941656466454, 0.042034056968986995, 0.0188693392931694, 0.06518996080323573, 0.09109213662844512, 0.05663928958857733, 0.05979466402242261, 0.05775994598685254, 0.026018571393984943, 0.00809346994144782, 0.09623107740715628, 0.059964295041056416, 0.05012918549079088, 0.06689361011188838, 0.022832622391081626, 0.02698452591205076, 0.05465244438739554, 0.045722245554169344, 0.05008212087916271, 0.032461926250928835, 0.04966882410489264, 0.055678580857573025, 0.029504587460729866, 0.025709219344501055, 0.01894391220693867, 0.006782916626111875, 0.021677719947371273, 0.12929331781643053, 0.02495975935861709, 0.05389702040702105, 0.03643020041166775, 0.022991648837623578, 0.057949468478440284, 0.052049580225420576, 0.04549713827849877, 0.042574964839244084, 0.06195812696410764, 0.05275971691815123, 0.04131450122522731, 0.0190720614796925, 0.04546480936809413, 0.036995692043415004, 0.028218343072841247, 0.04717427711453169, 0.04885661385713085, 0.02136542995069777, 0.07993486274274127, 0.027267752448096875, 0.049964078221349954, 0.05181042672765832, 0.004214098369101844, 0.01763748331746507, 0.04210545253309031, 0.023585100763387257, 0.044359639437208255, 0.06312440006783412, 0.024146166322151982, 0.05095859824289238, 0.01093916386561168, 0.04801151545477971, 0.04987092959063669, 0.01623263511235916, 0.020476294899239175, 0.07335326348942134, 0.022529843375988068, 0.0313122887464781, 0.018817283618714542, 0.09344637078503448, 0.03120811228009482, 0.11850822476610062, 0.08327350456027255, 0.0074062129433807595, 0.022813705765011332, 0.03893716568728128, 0.0507162922933217, 0.03892259469496147, 0.06289266996205815, 0.04643568025541402, 0.06618617387909083, 0.03535636347688494, 0.022572535540788405, 0.023838400074671355, 0.010636945052312748, 0.0297030387070751, 0.04037212114781141, 0.05188791269075967, 0.04087200500972329, 0.03557313571593935, 0.0324384379951704, 0.02831728141304226, 0.021226337111945597, 0.0850401339571803, 0.03954952274779639, 0.01718619432781012, 0.05626200277718806, 0.007086737520782458, 0.022897163383482445, 0.07548495676488647, 0.0317335183612041, 0.024467611069520636, 0.05948713717741832, 0.021221721432201808, 0.017541310554670713, 0.03328641305767721, 0.009878718147745297, 0.058713265799827156, 0.04427394101155862, 0.037374622113401854, 0.04235649954587702, 0.0042625270960401865, 0.022861708834346746, 0.07317171597312536, 0.03392694683204736, 0.08896681720451002, 0.023649628349249403, 0.025269345064917882, 0.07624716828427008, 0.03190344815412837, 0.035417845863248074, 0.014125081267388118, 0.040533095372900854, 0.01830305859086014, 0.07174429498733052, 0.04544681779319241, 0.08170807283491859, 0.019264481698853836, 0.025497196850577192, 0.04635126119659794, 0.042969105584967526, 0.06803544884126994, 0.04225482818700614, 0.007881581991715658, 0.038247334154983686, 0.05294457010384049, 0.05250233435823072, 0.01868135855352927, 0.0830071128063625, 0.1604874987876223, 0.14027635266463603, 0.1602620084679896, 0.15627360151660058, 0.11430254761850643, 0.19751560784155325, 0.12358597810229949, 0.13478998335138445, 0.17979577964832708, 0.13557320100165185, 0.16022051714601057, 0.14568018366492566, 0.21180285651597286, 0.14401529074436234, 0.09102241496645636, 0.12637812343816604, 0.19319127133536726, 0.1304475058831515, 0.23569703162197145, 0.15248158886548013, 0.10295947442852682, 0.10846819818740892, 0.11795137077569963, 0.10399683408679501, 0.19291687396264848, 0.15906294297066428, 0.15421480150713077, 0.16063694721989094, 0.07196383280379158, 0.10560319022906405, 0.0945207478118039, 0.27461583035126813, 0.10635740379051817, 0.2079507978933473, 0.21794234642819052, 0.09304552293953397, 0.18282659201612397, 0.16091037932182514, 0.15921487352780758, 0.1725549464144053, 0.1466883094080033, 0.10426488825150075, 0.12607083024997867, 0.22690468648027992, 0.19328678717776654, 0.20208510780526748, 0.17789059558943396, 0.18357023356422303, 0.10933301186249142, 0.1331789157683811, 0.17829617785830654, 0.16184240189050475, 0.19372661357685445, 0.13973567845119586, 0.11665731037576353, 0.1461805310100317, 0.12161172355615324, 0.09946966048089728, 0.07197230573623412, 0.1501421402058294, 0.12450499249802482, 0.0911349609434124, 0.1266650999746015, 0.14368072482607058, 0.15073840175905537, 0.1325557338854959, 0.3284940279779896, 0.12200959898050755, 0.25856641091166005, 0.21005213110437318, 0.0681473896087658, 0.1731138228769264, 0.089682848943818, 0.2100316918785534, 0.12936197461620455, 0.18736866603214897, 0.17778884379133103, 0.1350451519172038, 0.12580689763830555, 0.1353578536861366, 0.24199170030413136, 0.2018299852047236, 0.15401742661431914, 0.15402272794275515, 0.15904630354094892, 0.1442826707516947, 0.09124206003522681, 0.16465757582937518, 0.1347454123559498, 0.08862814505494411, 0.13805227684638194, 0.18276726616726768, 0.10491533520361108, 0.10262111637500987, 0.18411096906469715, 0.07908415274634477, 0.15249125689508455, 0.09223959078231166, 0.11570852580330065, 0.11457750423540992, 0.08071390521382132, 0.16323695770434796, 0.1887081401242364, 0.17534332259768443, 0.1238903601563746, 0.17750482435428327, 0.19160419762615236, 0.14632717556049749, 0.1468207506883529, 0.14733323286617958, 0.11639897786681691, 0.10093565399367964, 0.16710487434700613, 0.07826970935228371, 0.1261716704034517, 0.1318472557731213, 0.1268591040805463, 0.15184573588832734, 0.10884184225071823, 0.11770548719552257, 0.0533198957301436, 0.14571876385279242, 0.13625676593472882, 0.10722055505480498, 0.14300261443901446, 0.17479098852603667, 0.08754723329818057, 0.2026631977529295, 0.13459286892846709, 0.23778642918313705, 0.16754722883624418, 0.18361483520317465, 0.07971674218894013, 0.1590881625851316, 0.1120001852752701, 0.20732586932999475, 0.19979056721973806, 0.12735539882053293, 0.10366031464429633, 0.17956730158578965, 0.1291088285225053, 0.1091417043860401, 0.10136922911530542, 0.1625008851049408, 0.23833336999579785, 0.300783371372569, 0.14903616971306263, 0.15020986237833578, 0.059714879795548424, 0.14476444812551623, 0.0822095922945488, 0.1194222902338351, 0.1401520165945253, 0.08030967892057474, 0.11441382188950816, 0.21163800971642618, 0.059733250583972664, 0.10251172668030185, 0.27152628968319586, 0.16348114056933313, 0.1224333068896686, 0.17778830752978403, 0.12195601879108338, 0.1211176428102678, 0.1318767654799646, 0.2946698978062599, 0.16643039521671113, 0.09623015810164715, 0.17907095321964833, 0.11036339245976941, 0.17536299573557992, 0.09724016076013928, 0.10574655592321389, 0.11201406678845806, 0.08947865586848029], [0.02646831863169228, 0.022824856174749233, 0.09628970611600146, 0.03486874085220118, 0.0534936253191723, 0.02417167513481071, 0.041534636590269305, 0.029830655548721555, 0.03591840388253331, 0.08899420484780304, 0.11499612532075375, 0.021510172687891512, 0.07354130743131523, 0.0368779098554965, 0.013022124372993507, 0.03134145179853565, 0.03932690525787973, 0.027011702881164612, 0.04110187735228289, 0.02740125092978199, 0.03170211641718784, 0.08983006039934774, 0.010957149694853974, 0.08226773070712244, 0.048414044863274025, 0.053809789805522854, 0.04441532253798458, 0.038953525494904294, 0.008413905367976236, 0.04244314409011314, 0.028969145627812515, 0.014294276573514987, 0.02796594583008799, 0.0677709569854121, 0.025022902240556096, 0.02883698779999489, 0.0343215357392065, 0.013745349677910489, 0.03645352778896209, 0.042168616482447234, 0.03824331985426046, 0.06525290258709462, 0.01774115608103814, 0.03709957739638706, 0.07256657546085697, 0.10485167329710339, 0.05290972842504421, 0.0903837581075007, 0.027525579339013468, 0.15374888215334187, 0.030600978024003488, 0.04522106700366543, 0.04345458699390293, 0.028533132431367715, 0.04819334259316806, 0.032615599658099875, 0.07816272517365795, 0.07838762560558897, 0.02192340434468802, 0.049888618560808326, 0.06137809498355754, 0.039531492868498455, 0.039053143738138105, 0.042477349915932265, 0.0802403939287028, 0.022763810458502943, 0.028984120731512387, 0.03743221277310964, 0.034774603968065594, 0.014032372179621411, 0.038057892102627985, 0.045554916629748005, 0.05359815035556113, 0.018078834231522296, 0.08531545829628745, 0.06275072919144746, 0.018754845537665873, 0.017750837517181234, 0.06891808938235044, 0.08500965131867318, 0.039336661387595444, 0.04232058534398676, 0.03568605324553867, 0.054631158634419405, 0.06661435574172966, 0.010325947829011467, 0.05095163833410029, 0.09446429479266368, 0.004154965957446445, 0.031141261532602292, 0.024446892221608472, 0.033538482797842835, 0.06622199615043017, 0.05543467378424061, 0.03859104716309136, 0.027248822415487903, 0.011943615259482496, 0.049902657122020765, 0.00802583443263786, 0.05622637968870902, 0.02025309901293968, 0.06134390830993653, 0.02225925920591239, 0.04574629688455213, 0.07786244935085697, 0.03935716573088881, 0.04605891055337364, 0.0348480373260475, 0.03814604967051456, 0.02134221940181188, 0.03640947007243672, 0.019738649904367425, 0.01201062880065893, 0.046570925417566494, 0.04355239726963543, 0.02196958220954384, 0.05655069152013429, 0.044363102154626, 0.045620397995075876, 0.021728886959833965, 0.010812190537821623, 0.03125577827074355, 0.03832235331496885, 0.07945318496034992, 0.03251860526600673, 0.09865510983452683, 0.06648597472737874, 0.08575688581913711, 0.06830803824648743, 0.016688489986042825, 0.012113539306747337, 0.08216868319939222, 0.024137635933115117, 0.04528351466081316, 0.04272993676544678, 0.03230817240452574, 0.05018735837732112, 0.02995076855914968, 0.026653236934855103, 0.047723604291076624, 0.04142011793690824, 0.02801534892510503, 0.09402950925211753, 0.07500560788978493, 0.08383916090092353, 0.1037086318096807, 0.08235762346415751, 0.031369636173269926, 0.02491029689178592, 0.03384690213527891, 0.053863768360667655, 0.05789016178178211, 0.03224435728043318, 0.04287565817996379, 0.004048396423909693, 0.05154405412594638, 0.03969372347778371, 0.056536622315404884, 0.018309162396396843, 0.012216111776539156, 0.07411624109672924, 0.026288542693721193, 0.05954251384302493, 0.019321078359479868, 0.08040760793993551, 0.0875613063333496, 0.06806229256213674, 0.06732825009572892, 0.018965734221461802, 0.03382606454373848, 0.011045448989006541, 0.013859353137142478, 0.19448661876301612, 0.026969194577466098, 0.06004535097388491, 0.1091017758834266, 0.03748363259458735, 0.06447521609164054, 0.03521868598557288, 0.04531664796353829, 0.017004137363044486, 0.016936396038339987, 0.059362352945871895, 0.04799376136713451, 0.0667827035630903, 0.017031369873532848, 0.12159756625131254, 0.03266180625125285, 0.030042557383797346, 0.0778749825492982, 0.03929473339549957, 0.017286256902040015, 0.06566439905474264, 0.004844096519293324, 0.0009048669063861693, 0.05162548161141815, 0.018417280385150545, 0.05257442323190551, 0.02314098235670357, 0.056587356488190355, 0.031537001486867666, 0.09114884245660036, 0.04974953146771558, 0.02512577444224829, 0.13283247548726299, 0.024593741700593984, 0.013913642915506518, 0.010556857263098561, 0.06780325525229977, 0.05422811594701583, 0.014307949327743583, 0.045039427556818536, 0.024073954874409303, 0.008884955595638002, 0.026166683002825708, 0.019790841559428844, 0.07982395619394318, 0.06708019848672614, 0.03501113361468719, 0.04906620402189513, 0.024103778677301544, 0.047806391582613995, 0.0531929511306507, 0.03268185094179165, 0.01256672340640498, 0.04162811463879001, 0.04595038653802007, 0.026622041834578402, 0.0629356513250499, 0.02095206614373432, 0.012353655202464472, 0.0344540651196674, 0.01765001460068649, 0.15256791165278805, 0.048103576240640496, 0.06151664198466367, 0.021518992275119792, 0.06770028537439723, 0.033298034611488544, 0.027410087753988566, 0.046258327070503466, 0.02528343725228502, 0.018804034128064112, 0.011289562906078514, 0.020236777509712887, 0.08155614993865452, 0.016382198457816438, 0.023841694252745762, 0.0474259676411748, 0.017711424208696813, 0.0409018594561325, 0.007157052422107588, 0.031145769960036686, 0.06779119702837161, 0.010548831534481818, 0.05717667345438273, 0.08168684453853677, 0.055490146210837754, 0.02474493489811017, 0.08202052179483638, 0.07335479566526991, 0.030487196730269544, 0.029720112891687505, 0.026240893940050757, 0.0387722461093818, 0.015579055818248422, 0.0521227837570252, 0.022410126816060756, 0.010079840168116555, 0.03983216705702005, 0.03331239492962918, 0.06261362626607861, 0.022554346698246176, 0.07802248511823916, 0.12349836828727877, 0.08749097180102142, 0.014247378586010348, 0.06246379095940821, 0.0783349953651909, 0.023733951647074956, 0.028690695649974292, 0.0749314888831108, 0.028887810072891658, 0.060666564010804704, 0.08164977354388084, 0.04532989745418872, 0.03667758169373678, 0.017713331767628272, 0.02258567969434925, 0.04374482323445621, 0.024824845529491865, 0.05865640675408706, 0.05904205541516985, 0.02793157721058496, 0.06154149004648771, 0.018640414984416098, 0.047623737069267424, 0.07922784019742282, 0.09427651898154328, 0.05755324780400242, 0.059727983729493235, 0.07643316677140613, 0.010699023072037005, 0.06355050200175855, 0.05685651764994668, 0.012145658500582702, 0.07898734221535345, 0.07357140702586021, 0.042006592716901534, 0.06866685850846191, 0.023064237583668965, 0.06652552784690935, 0.07960622634498343, 0.029523345123555873, 0.03299097891055769, 0.02903476488896676, 0.018708744281602484, 0.059632544495886376, 0.06642855643745392, 0.024425248322527737, 0.04076364953371306, 0.06091820857217235, 0.06726628890441311, 0.030961723081887733, 0.01766482308026283, 0.03334104661799727, 0.02573409038896282, 0.0648778259393669, 0.024321311258620793, 0.04104712504833456, 0.04111199354332301, 0.03365732601753647, 0.02259547029802155, 0.05189922014852205, 0.012499197543929181, 0.02152516119813006, 0.036544772691183516, 0.0494524578924381, 0.005252608595671313, 0.0433271176241819, 0.033383284875702475, 0.03700370532310298, 0.0650411941892197, 0.053585712918110436, 0.06593922543669901, 0.03383423104101131, 0.020022899167792454, 0.06534845673389013, 0.016537693239027457, 0.029337781391316847, 0.0495312768485277, 0.0398897692080467, 0.12483180560652288, 0.114279312171763, 0.19799346284520244, 0.07730905807787374, 0.10648416069846962, 0.1496478755988421, 0.11951906246043022, 0.11153212853617246, 0.23979054583657175, 0.2106595468977767, 0.26844664687110537, 0.12094931797154489, 0.10027723972715678, 0.15087268165042325, 0.13708381913602352, 0.06192433482576763, 0.09869887643764097, 0.1544534532173026, 0.14311348268341634, 0.14559404473871956, 0.147698518910235, 0.14405509667290797, 0.15335079222436876, 0.31207366876544496, 0.1759263921168543, 0.17131187682670934, 0.10076330719335426, 0.10768642078243917, 0.1951967056600317, 0.107715095453445, 0.10236052390668662, 0.07042259413508639, 0.1606769370095384, 0.09690133539298851, 0.17155115672897908, 0.23886371734401873, 0.1187365725936909, 0.1230345480144024, 0.1463208783177599, 0.197124044981695, 0.1226429928154234, 0.23958250699985414, 0.10817991930150217, 0.11503260642770799, 0.08284382116530212, 0.26548354135405633, 0.22140465015845917, 0.22177050310757854, 0.1899371290158841, 0.2543450059789804, 0.1234623621548376, 0.18132449277947027, 0.20559313166285717, 0.10343827172032288, 0.17732398163887764, 0.16676796419966608, 0.21622922061191452, 0.17663157605115445, 0.2437543920091083, 0.09188114590342007, 0.16592106932113249, 0.12987998794884453, 0.11352339023423773, 0.1674091951140473, 0.1346367044794944, 0.07097243842098021, 0.09270096723470958, 0.11167806062486865, 0.10142272503505792, 0.16791392448208026, 0.11828235140250576, 0.16823643217644385, 0.12338894794905379, 0.08357331306943971, 0.10280891516876799, 0.19651724205863094, 0.18692212870284436, 0.105174686609497, 0.13999847725274103, 0.1979329112556673, 0.10030104973984343, 0.23353810392079816, 0.21640549744329146, 0.1633217483158073, 0.1728434857702063, 0.17035183076175953, 0.1619453181422526, 0.1238477120416299, 0.1914921496063471, 0.09404759658800979, 0.14750949437579802, 0.15903669679837842, 0.20177219153171588, 0.12421670595123885, 0.1864052798238493, 0.14074887569633224, 0.13552499874945612, 0.16417179947658894, 0.17222506895421014, 0.1703437561950376, 0.11958326828936416, 0.18723437081902258, 0.1369883645806582, 0.08609117594577613, 0.16368703435986273, 0.1300191708029278, 0.16536516527975761, 0.13799926356202172, 0.12648903764784336, 0.13009605538700858, 0.1519130750168716, 0.13291250103183333, 0.1247347346056373, 0.24043150095930024, 0.16275095152518443, 0.19007102586328986, 0.17864623407442726, 0.1488901227111778, 0.16160617101817362, 0.22858870095543324, 0.11981681019308106, 0.10926350470512144, 0.17401751551416614, 0.18808466712793998, 0.09186845948739399, 0.21535508364679354, 0.1643672131843144, 0.1516881822458198, 0.12620619032531977, 0.13632148504257202, 0.09448515536684184, 0.11950010944518352, 0.14119754275006635, 0.12871896637783897, 0.11274839270739787, 0.09601061262430684, 0.192710290692987, 0.14097536193026652, 0.11102162286519043, 0.11458793069205939, 0.12911264364036823, 0.08180755701276564, 0.15076728327380073, 0.18356205174519172, 0.1477749438415612, 0.2744325208327463, 0.1660185923138934, 0.11420715435017502, 0.2000448930888407, 0.09351164147618318, 0.1743041856154319, 0.2248772654321886, 0.15383707419518503, 0.13795735855256358, 0.10893961805249415, 0.11343140605716936, 0.14092207285425357, 0.10436647151026035, 0.08507347410364498, 0.0838659663173941, 0.15035393287337598, 0.14221680741156303, 0.1821471792795966, 0.1849913266637633, 0.17587039108958938, 0.17481740323766587, 0.13419234283989476, 0.15479422444778104, 0.19603989267301178, 0.10576009269683592, 0.12624511525275248, 0.14031934551894665, 0.2709800996367009, 0.10024918558736963, 0.12062615910244566, 0.14077953453506195], [0.04245830113969503, 0.015170865019993677, 0.029478054005472414, 0.04707448267107529, 0.06456517013570955, 0.049270944850098704, 0.0480440320567258, 0.10942169420060613, 0.017127054255275477, 0.03249032129984229, 0.029993838022252726, 0.0339385339119021, 0.01829637255850098, 0.03497731083283021, 0.06186562184725077, 0.022352564884650133, 0.012249321688056715, 0.038110702373688264, 0.005668997492325763, 0.025816929391435078, 0.04479512594820512, 0.05077056962275698, 0.07006817121779726, 0.03677364911944155, 0.04788378944560405, 0.049191424923558394, 0.04546119343309153, 0.03923885494230255, 0.013627353942983094, 0.00549107117788686, 0.02768977879426412, 0.03893613529902312, 0.05553067609247181, 0.02531102216321855, 0.0551313680836991, 0.014429679741301845, 0.009056912648731904, 0.01739782803211241, 0.05651730540839415, 0.04283260403861923, 0.04325284156948329, 0.008136222435672196, 0.039418529373623674, 0.0427209735367327, 0.024864515477430918, 0.01960135354179769, 0.021727956163005966, 0.07057794144437199, 0.00864394146182965, 0.03609681426877937, 0.007987296858411885, 0.03440486695317011, 0.02744279779313553, 0.04790944956062783, 0.03434845606886572, 0.03141139371080264, 0.012634699345536292, 0.01963143398414456, 0.09699623836504837, 0.042655024857771014, 0.04568363472278561, 0.03715863128403022, 0.007481566788027845, 0.038208524140739636, 0.04293323351791309, 0.0710634803099017, 0.06842756328443367, 0.03346452850007242, 0.023689485988729907, 0.056608071505662896, 0.02105243132269431, 0.07097697366149196, 0.04106253107649185, 0.08884085702799982, 0.0721484293500262, 0.035480128811492075, 0.019253283408620668, 0.019162373669866114, 0.031187705613011797, 0.01319528801456815, 0.13367840509501197, 0.025370815325708642, 0.04153022775426508, 0.06029274757771243, 0.06506709562193963, 0.06164648239651035, 0.037227100392262784, 0.03620464880500109, 0.09508864112919378, 0.01752442980725919, 0.014920559197273708, 0.03415657402647119, 0.029368911374119983, 0.05564258238601108, 0.05556624938523578, 0.042636090994722424, 0.07185992829862141, 0.049605755916526245, 0.01342752852642368, 0.038265693452089064, 0.06831372261888559, 0.0167568173680094, 0.02051512023524171, 0.050501550187266646, 0.08738216433313586, 0.0461468153122452, 0.019821511889477412, 0.036483229017786445, 0.028704502469589634, 0.03947751814379327, 0.01983278870372282, 0.05305239314874334, 0.015865081448047873, 0.029701190519957777, 0.04123009365773009, 0.11148217194263013, 0.04558450677582333, 0.04120237276619, 0.024969481014376207, 0.02937845491443671, 0.014108348949511927, 0.06584521112663132, 0.028087560372847705, 0.0018144419018719948, 0.009587775191081869, 0.032372504637967196, 0.029112112956241738, 0.03835202006983661, 0.07786887682854168, 0.02927977704412995, 0.04285399321346514, 0.021294478717590534, 0.0790650618352717, 0.03946224618102274, 0.051276777540483785, 0.04023925468866383, 0.0032019834625609824, 0.023458633053627227, 0.045377896693084514, 0.022011866432524497, 0.02423836500383914, 0.015692925212093662, 0.038772862810160846, 0.07631240067102256, 0.05578764113447359, 0.04234675107704055, 0.015234186974984985, 0.02990294360525666, 0.09798611589376965, 0.04113918966463497, 0.026481476191791798, 0.013837245754867554, 0.017805252742442875, 0.08340633654546353, 0.19054793091791292, 0.02912017986208441, 0.038236903867894606, 0.062066846331881906, 0.027929874580173243, 0.04781421717076052, 0.046330071204612334, 0.050055591254344875, 0.11970309210160088, 0.0871401111925802, 0.01442867137807151, 0.015163331502868284, 0.013394851046013496, 0.023554472568174525, 0.07690441809714803, 0.06433981771190321, 0.02542265266510508, 0.06294739928336875, 0.04401450916644066, 0.01309433486312628, 0.05657802553727262, 0.056809793947444814, 0.041900807465877266, 0.03286937777433665, 0.026701190208475438, 0.04567564825617498, 0.021693650745756684, 0.01597642849740242, 0.03282751489971434, 0.04634374587406074, 0.03033420705657092, 0.018592452134696708, 0.041509344197449186, 0.04419665040087797, 0.054610933913218404, 0.006451453363913442, 0.033408772620943286, 0.02197122355292161, 0.07374986720782134, 0.07202152688536914, 0.06108038555530291, 0.03425342669229835, 0.05033227539951763, 0.07765811071881364, 0.0376708836354796, 0.07403174925956034, 0.04516074141006797, 0.025223318502427112, 0.02409452816561586, 0.01918945679320924, 0.03326173736563614, 0.015453962278702568, 0.050560531296557, 0.04702325820201828, 0.04254719415198892, 0.031610306525122256, 0.019389551298152057, 0.020886318562852762, 0.0044129709638054335, 0.03682352144331221, 0.034495721150550156, 0.040283886971132415, 0.027405721052820166, 0.025380307155090476, 0.05273764592505271, 0.023279410614181432, 0.019941479343199925, 0.03056754403176808, 0.00913040537852794, 0.030619015564180674, 0.04022999268565928, 0.012485828352040582, 0.08603204161890092, 0.03224662873112867, 0.0435727407344647, 0.041306587536969495, 0.09360087539760337, 0.02072467209560977, 0.03565233005511184, 0.023127564326709798, 0.12052289045025265, 0.0496621055137967, 0.017315249499534408, 0.016667897542638165, 0.06263172509328974, 0.02761492434318268, 0.0182979334626467, 0.022311866463672732, 0.023809782860259858, 0.019585715772043315, 0.052559545804415984, 0.02189499588923589, 0.06164041881058967, 0.04582036992595081, 0.01588009868658358, 0.05558664264578012, 0.018211953499684894, 0.016711815448117354, 0.10922509305659803, 0.044549954829797636, 0.03150208319927896, 0.05222287697477206, 0.10043988019348153, 0.021069930686104684, 0.011048910748814384, 0.06287849733545896, 0.04760840764990257, 0.06377715677503618, 0.05740848782983038, 0.064317409640118, 0.05098556453782705, 0.020287739593655835, 0.04526527793777566, 0.04037564132182349, 0.0075549197067777, 0.039274772974632444, 0.04742517090973355, 0.06219347300488622, 0.027718129793121934, 0.025415587419223402, 0.0403182651667345, 0.06238941148283982, 0.057656922482795296, 0.02258660857595744, 0.008874301227831073, 0.033796482058542396, 0.040143256210872245, 0.02988671977824021, 0.032996188308442795, 0.009821149513065335, 0.014363032007109255, 0.025780025020902677, 0.071181082467158, 0.010413921535796216, 0.05215102941879342, 0.03455039684570605, 0.04559352746113174, 0.06903224414394749, 0.08973670492489493, 0.04498634915498476, 0.03836504356454938, 0.08013825142575849, 0.029077966502236745, 0.028192391844406247, 0.028546416395974737, 0.026529929337782726, 0.01236009800190767, 0.0037065019170122765, 0.01779281530499218, 0.04421506332413805, 0.04484925389049515, 0.016158309261945468, 0.020308008364912485, 0.02673293689205762, 0.07081072492104384, 0.02216644382344619, 0.03212153614919273, 0.12669168322557403, 0.08877340298626693, 0.13275234269038325, 0.06472315278745468, 0.03613716795019085, 0.014905534297858757, 0.030868072663584066, 0.018248505469772126, 0.09812872316087447, 0.03923102169327679, 0.05807876496786072, 0.04276814157023065, 0.014014180464249466, 0.02343578065084594, 0.0537604384214407, 0.018207971757698446, 0.021340375045134176, 0.032056537419257146, 0.06991402666655279, 0.048193020836239865, 0.04346396391009612, 0.05413716598864525, 0.016535435194870638, 0.08195232464781693, 0.06922463180437204, 0.02843643489834522, 0.026215731782177766, 0.027027124231080377, 0.018098605045628165, 0.019449604930536404, 0.01981413254754678, 0.016441853724480156, 0.04771138135824473, 0.013736972506458481, 0.036831649636188825, 0.07218895540122064, 0.046330343165825454, 0.025682752921936974, 0.0256256832020177, 0.012218434938169535, 0.033253406159459584, 0.14908947411083406, 0.09147727201061864, 0.07760100652493777, 0.12140922353512819, 0.14773147601273753, 0.1495520533212731, 0.09465465232008889, 0.1657213042339971, 0.1830516380047606, 0.15619475574743363, 0.09648045434826806, 0.16167939370197637, 0.12252094734820629, 0.07359609037878052, 0.1048131620571498, 0.11212232267303814, 0.12427125907232686, 0.1834385430500392, 0.12510763556366006, 0.14147264492367545, 0.1403214139563422, 0.20665488356063444, 0.09562966008219989, 0.1702164477037807, 0.16186422007458826, 0.16717227476258434, 0.0902315057934292, 0.13134742936780378, 0.10518204871444933, 0.17102395034124776, 0.18102882880597346, 0.11763813274521982, 0.20366931634564556, 0.0954143740537186, 0.0723113302862452, 0.14826487239089706, 0.13979241492286806, 0.2058535249483201, 0.14885416254401207, 0.15421098638926783, 0.1561905422638501, 0.14138287474070826, 0.10525755434026642, 0.1807223783145028, 0.11873948372780316, 0.11640636295440698, 0.13481413044275778, 0.183744365349412, 0.14168281348482256, 0.12996894607861198, 0.18932399820656548, 0.12070158811947032, 0.15241559805168262, 0.11445332138288407, 0.20999187062824928, 0.12034958604002192, 0.21307785664835285, 0.13441456962497006, 0.25691264158775734, 0.16725988457760504, 0.2012412926001895, 0.11879014512223583, 0.10495825911000853, 0.10620335116982461, 0.07785756170990006, 0.2104074886489299, 0.16274237134043248, 0.05225645077805366, 0.12626543956538364, 0.22066085539277525, 0.1944087076211168, 0.1675846598922245, 0.13593778224481692, 0.13427166358357476, 0.10841993464817924, 0.0940078289638604, 0.17636320012952053, 0.13098215864550683, 0.11067012640377207, 0.14490386080597678, 0.28336633177053544, 0.2868046569487741, 0.12376560273790553, 0.11994772695846136, 0.16251147244005434, 0.15104086859331978, 0.12280294431313393, 0.1513141474776691, 0.21461298959630154, 0.10754428848984743, 0.08415789944269965, 0.13706241463941915, 0.1882142279176943, 0.1365883441101159, 0.17029350082720482, 0.22222388926292622, 0.20718873959154854, 0.11272812968180065, 0.137618885585858, 0.15207036818948486, 0.17496927250777522, 0.10021726270356487, 0.11491928670194843, 0.23548804283622773, 0.19558829916340692, 0.10030412175241979, 0.14119398810209768, 0.14798935652980882, 0.16625223380904045, 0.23738362015255038, 0.17882205125304962, 0.11212361736163018, 0.19500955038013, 0.18660217974214785, 0.14933679793630877, 0.2647658701865904, 0.1400834670470607, 0.17885510028610307, 0.1460160366109302, 0.09877535499512188, 0.08905206746872395, 0.15205729872949664, 0.09035754257873183, 0.23193448271241882, 0.1263498394720016, 0.18062336911116877, 0.1194291084163612, 0.1160006887549835, 0.1814761935102363, 0.0998898903508821, 0.2190494660528437, 0.08556016976194036, 0.21552622768907778, 0.12166758668759178, 0.10610292470383068, 0.17493983940972438, 0.23817247620994048, 0.14488588838327318, 0.12719830483077996, 0.08133159424628943, 0.15432145626794908, 0.08887472577513227, 0.09170631697822003, 0.1887529562678068, 0.17042059481384295, 0.17269999750198858, 0.10094451763096357, 0.05604660566595774, 0.14751091929933718, 0.12060559730255797, 0.0957838122943236, 0.08308674764609145, 0.08208589207741522, 0.17339989542961123, 0.2790257082350793, 0.15736196730886737, 0.1699671933367368, 0.11148671484402112, 0.24669555676800592, 0.09703219853221409, 0.10575273825276284, 0.09063019327098325, 0.20607634928197632, 0.17072087063664393, 0.15010818718902527, 0.10304833296686412, 0.06787430990727679, 0.15369950012574274, 0.13394598428520466, 0.12696686966885484, 0.10881862212573329, 0.22055919552522324, 0.10142856262504094, 0.15539218671619892, 0.12086414431612338, 0.11406901337566877], [0.03352524096807165, 0.07242471129903871, 0.05812711277676206, 0.05631640268069121, 0.03235760422783994, 0.043369118394630576, 0.04175009115809395, 0.022246385098344857, 0.02312013901950371, 0.02466299796416875, 0.01067080901139566, 0.013240164487562595, 0.014465907081631164, 0.00967736725860666, 0.023137904598467776, 0.04243753249606779, 0.07443619771830498, 0.06830877369089473, 0.057031503623171206, 0.07531864673740442, 0.01854392237991335, 0.07104243587462172, 0.016522076536690997, 0.0355046168119917, 0.024732553002033985, 0.009699421014726884, 0.05461089560882219, 0.061632574070245034, 0.05691307026051706, 0.00283355166996649, 0.033591798686933134, 0.07876848621714501, 0.055288596138838804, 0.033676321167619, 0.008696668420828158, 0.013371641454737515, 0.05392425866316884, 0.08408579524726638, 0.0429235884709464, 0.04433697855640804, 0.09714278332408398, 0.017671421012510697, 0.028483827012561025, 0.005478305759043583, 0.05777866917572195, 0.04143634750958412, 0.024956695006919966, 0.04476555495432789, 0.039408528095772194, 0.01919741261630289, 0.056275225454761144, 0.023238938189141696, 0.014792186801411934, 0.04121697440202679, 0.03804488009923408, 0.0359798786080172, 0.014222444339294829, 0.03409610670660773, 0.020676125103848118, 0.006455854539038434, 0.05776100318818804, 0.024244671822675777, 0.04964188845347493, 0.06311029255870851, 0.03963260115274499, 0.07867601940468436, 0.05805636838739438, 0.07992953843166752, 0.04299381192052557, 0.01989022423062594, 0.03789319085978693, 0.027772734625144836, 0.08271508775050603, 0.052177432639103745, 0.05197169206615898, 0.01807250826048755, 0.04085233187182777, 0.02980786060253459, 0.05178779649037508, 0.02902826654814905, 0.0041411366339983244, 0.038181335680306926, 0.022632920506200003, 0.015959334202982005, 0.035909884984815316, 0.020621426426054492, 0.07494458132573674, 0.01446871096343403, 0.05536947204100509, 0.019138879668448242, 0.01783205815891345, 0.13526195479977515, 0.03311067248784727, 0.09325815064291801, 0.07221913926543728, 0.030713583372773665, 0.04014667296301454, 0.024407375491254275, 0.08837609446697658, 0.060709939909077464, 0.03200308171912067, 0.005935853208234955, 0.054568768433866, 0.04811737348415679, 0.004983505369314263, 0.07273243349646369, 0.03426691750064492, 0.03247262466879141, 0.09618253807627386, 0.06755347994546737, 0.02038341631451922, 0.031354036707911766, 0.02405419363640249, 0.07398976764130978, 0.05559246108356503, 0.043345737391181534, 0.016394756554115205, 0.022853180360529694, 0.06720619696763254, 0.03119331337661753, 0.06375085697659562, 0.015817290968111446, 0.05363785286223697, 0.08749159233224008, 0.011860578989369736, 0.04361091872617122, 0.040433749090880156, 0.01592799641882941, 0.006544862943325913, 0.060924295140730764, 0.016728428064755375, 0.07175215504943364, 0.03536025137310067, 0.04370014881715179, 0.023577447545023698, 0.04278774192977337, 0.030732720249122193, 0.031641764010513024, 0.02344948404859151, 0.046612776800869934, 0.021606900864430977, 0.027489253364863898, 0.06332962736186963, 0.031625770009873856, 0.025434663008537986, 0.011466362592463773, 0.030555240659704132, 0.04708223931130864, 0.032418217104409015, 0.0722984446873588, 0.03756893265451636, 0.03640482757961558, 0.03811741330390496, 0.04884544429519484, 0.005312508531665851, 0.029743775432448716, 0.013621134266647841, 0.015996136109254534, 0.01836310073192562, 0.04206635523587466, 0.05286293960506878, 0.01853862105147733, 0.04077543579642812, 0.02292298246175051, 0.03789223324988158, 0.0408589240584162, 0.02882204333981199, 0.08655514943623736, 0.021093964779509172, 0.04016721178026449, 0.007690337717518091, 0.03846288448379886, 0.0432353594430512, 0.03936779137039858, 0.02000581732230081, 0.019104028413552913, 0.029801739560019587, 0.08907417676621869, 0.06818130432117371, 0.0412942037256735, 0.015404624301159095, 0.02336847791147809, 0.04906661770937424, 0.01166890187549495, 0.03299803074990069, 0.009931831981145568, 0.020695813563502124, 0.07222090892854237, 0.023194409328542893, 0.027163627692648483, 0.012531292797516913, 0.04640305257071892, 0.07639642519455764, 0.04379134392365814, 0.0896364240156066, 0.045950160542082404, 0.02684284178089471, 0.028662842608267264, 0.036925070228115205, 0.050189162514382796, 0.07807304692124167, 0.052678886981260394, 0.04365639370535651, 0.057353869591268807, 0.12609031952677235, 0.05378735109022068, 0.02924017029844465, 0.019591432703178258, 0.06158161390152189, 0.07329098820205658, 0.008184052177614743, 0.03381543124334947, 0.08353035085864606, 0.09515942765339729, 0.015962099780388657, 0.041578751763389, 0.05636437893694928, 0.056936734716498086, 0.06784047946454057, 0.044185691513121135, 0.04267663236767535, 0.020037167555382176, 0.02811177258169459, 0.034535753075033426, 0.044467608038816726, 0.05911452733280678, 0.020761065102452715, 0.091906511074593, 0.026252161178197113, 0.06448566553092773, 0.027782209217548374, 0.04336056119251636, 0.05501621357736088, 0.03498849954696433, 0.032912033549960584, 0.028547245686152772, 0.06966959099255263, 0.05663888356197746, 0.07429850107479481, 0.07943914256869786, 0.015619880643733328, 0.10340431104263953, 0.053118483553971016, 0.07598806968739918, 0.043114083894197984, 0.00383081691970508, 0.04277757594301816, 0.031573066991122986, 0.026003251550719145, 0.1332943039315362, 0.03238162874514538, 0.020808395929634575, 0.045168019245348634, 0.0644171313052216, 0.07840221191966727, 0.02048261129417487, 0.03899000660185853, 0.06914273700526646, 0.05690123803252655, 0.02252261342120267, 0.053071687073116346, 0.01422008766131776, 0.04253206391548438, 0.0479161566604049, 0.03981024162062714, 0.045927262174025665, 0.02508101384005239, 0.06081279487379136, 0.0504648354234955, 0.07183404984853922, 0.02548763415806236, 0.02460429073131133, 0.017614489188417792, 0.04713821735593581, 0.05450863819268923, 0.01987705709442737, 0.038083586691608357, 0.04212097730487586, 0.038480244036163055, 0.008508761417150738, 0.023060527802895636, 0.0285383379988132, 0.017203986719851534, 0.020409980413293647, 0.03105969232086453, 0.04163446933812192, 0.03190218602427312, 0.037568641541105126, 0.03450325945572507, 0.05231295359290896, 0.04146268944286051, 0.05613267181381103, 0.037929806032127915, 0.015680997223112614, 0.05027344367737251, 0.025145242651624065, 0.09117091344969888, 0.0171099130379697, 0.0686255663693432, 0.04119258599295732, 0.04155409905398565, 0.05628306636466615, 0.03237769105321458, 0.02793868076086285, 0.007785963206251543, 0.026651633895873546, 0.024584506510666782, 0.06465143163598354, 0.007619643602670441, 0.07655390222827274, 0.03600006119438237, 0.039866012821514765, 0.01853572715434336, 0.012892328968812383, 0.07489071002290135, 0.019311894880487554, 0.08261775627972619, 0.025651385451877312, 0.07609362894248578, 0.02524268328993311, 0.03818472561937186, 0.044859615229671045, 0.025916664463077343, 0.010114523841278448, 0.01915951999234817, 0.03954714787523112, 0.04490571840095424, 0.054002874605958505, 0.034475619003417037, 0.06944599291009289, 0.010765666975789975, 0.03436603395628833, 0.04622152420662103, 0.04872703008473881, 0.012818768248713065, 0.055627233814448125, 0.07894737540834373, 0.03638928365563193, 0.035841833394501484, 0.05628136564947425, 0.018902832657218944, 0.02737410460418511, 0.04700523215315996, 0.04263855396739898, 0.029588046994420792, 0.018111697488254117, 0.0025833016280235065, 0.012720492574566556, 0.02473982892209484, 0.025979001037476045, 0.054180093725482305, 0.07622914223541176, 0.13915064774693983, 0.28664426878094673, 0.12043889657023454, 0.14859364668448127, 0.12130819952055333, 0.1331492988092284, 0.13269784319544994, 0.14114235377600118, 0.12781433145245238, 0.1649568557378746, 0.11477709312232272, 0.15628748302978857, 0.07431003069805522, 0.0942061844492151, 0.12922522792172048, 0.14593173629574238, 0.1534162161331023, 0.13256941621582355, 0.11610538233071567, 0.1754670611192142, 0.11309625791205515, 0.14636659844508096, 0.14116996358479225, 0.1680318713789025, 0.19377241031296794, 0.12855867014056252, 0.16717647292440938, 0.17046902689241594, 0.20113817716558136, 0.09450010174224455, 0.16367410279570088, 0.29439971391712466, 0.0882584923097203, 0.15649038907741347, 0.10511898435652257, 0.1485378141965597, 0.13398684741508576, 0.21813252009451392, 0.11710355659165692, 0.07143346247293296, 0.1553869007095214, 0.16181667665800742, 0.2159390265061971, 0.16073859176568447, 0.09077763455289026, 0.1378189264646461, 0.08391907919318446, 0.14071755802198765, 0.10255216080094538, 0.12305381512569806, 0.13069797066911576, 0.18738369667722335, 0.11182737116131092, 0.16824976210632633, 0.12535702782653033, 0.1342715256877484, 0.0794473473703669, 0.10436480909946466, 0.10165699472230288, 0.12274329670734944, 0.21097460821751626, 0.1651655227666901, 0.11384340048196817, 0.1785684301848373, 0.12232885080119296, 0.32174261767537365, 0.12547207891099876, 0.18213421707191776, 0.13885262422263622, 0.1115307036126333, 0.08539728414747985, 0.1399273842933678, 0.17120208110540144, 0.2674689654621386, 0.1934450302994059, 0.11314882686541927, 0.14014242517371334, 0.14275516803947189, 0.09391212926035929, 0.05978645539031394, 0.09501922590237472, 0.12304377171301073, 0.14648405504563164, 0.13954953440735418, 0.16710492031228158, 0.0866512475054591, 0.18072816993921034, 0.13946345676818203, 0.1809301107160507, 0.14948793176201083, 0.11628436345246532, 0.206167176666279, 0.1152952137072721, 0.2096491228909262, 0.19874778365896595, 0.22576212762824951, 0.12880099907277093, 0.1832546819482119, 0.16406181989417923, 0.14035596452172727, 0.15009813611545872, 0.20240946943240784, 0.12875722480877755, 0.15616409690870395, 0.12784276097532243, 0.27642401235718883, 0.07580091440749746, 0.1475011133739064, 0.2857633289550581, 0.1745278679675633, 0.1375835382890317, 0.10152305190962169, 0.13966339039466075, 0.13327201077293965, 0.1114779967634428, 0.14770887641897126, 0.13518868615069699, 0.0749926073777099, 0.17945721475107057, 0.2079758949337467, 0.20488560349950868, 0.11687505554648177, 0.15109751313444109, 0.12640829964150346, 0.09319420528387831, 0.23050344579162138, 0.14367585250687215, 0.08505432190553797, 0.10676608105460483, 0.1253779267051047, 0.09290279309836127, 0.14154473379735025, 0.0915831606835127, 0.15374961759774916, 0.1817503610565778, 0.15458128264834806, 0.09231342633645381, 0.13857085708408587, 0.16723316343080613, 0.13094622912185808, 0.11810570684892517, 0.07776906323288718, 0.18889022390207938, 0.16958457838383414, 0.09087865090658588, 0.16830879684177139, 0.15919236586459223, 0.17223841420585112, 0.12163193295559577, 0.1246912974203306, 0.14413539800913105, 0.22520662195259528, 0.15537620612209843, 0.17818708693788898, 0.1653103287061376, 0.14483931023747693, 0.1802225059439098, 0.09510989240821331, 0.09023650834757475, 0.15281503629540244, 0.13664336454483772, 0.2169470756404823, 0.09006794602159532, 0.08047876218634267, 0.1017105289464516, 0.16227743257918667, 0.08901253733183108, 0.19789803893335406, 0.11167237625247049, 0.10086639964532468, 0.24181986678271528, 0.08870298418426707, 0.11230812197731388, 0.13027533528304872, 0.18946210853755477, 0.14750944841052258], [0.04517061628341194, 0.04539375854355674, 0.04522135045619742, 0.021354382962829644, 0.0691990674503388, 0.012502555881867246, 0.03297892068662951, 0.04011727816935989, 0.0509922486549664, 0.030195240622326255, 0.03399727753393593, 0.0843059535949461, 0.031838859281232285, 0.04343119832957464, 0.05282116866099739, 0.03397118840967456, 0.02610582880856049, 0.05696756592501075, 0.01989140209080952, 0.022629528651915254, 0.08563756762493042, 0.020180042953260487, 0.04040823070212238, 0.04265446561358629, 0.02103959551952299, 0.03773033971928301, 0.012547658350799355, 0.047066434917430726, 0.02569101326498053, 0.039210199423494844, 0.0367804060149337, 0.06789395240165534, 0.051414026022558255, 0.04723762875543006, 0.04800390437125199, 0.04654206688545885, 0.02401961625794009, 0.02346201916225255, 0.0715287714715927, 0.029676223714505474, 0.023843998262178034, 0.10739817254004941, 0.00943361531807891, 0.061569379477371136, 0.02534988197317768, 0.03569123966078605, 0.011911685672408391, 0.05572360001444336, 0.012299689096248439, 0.05395350406967825, 0.02103820890038004, 0.07800010768997093, 0.01165875599854776, 0.08616295072340197, 0.051270537754340526, 0.03674903471443442, 0.012629517718338439, 0.0746759525950878, 0.05762800649409333, 0.05002361474438541, 0.06237843344288488, 0.006526656863805388, 0.10651199267275872, 0.09825221653426848, 0.06656264480684074, 0.03222310983185326, 0.058508344940961375, 0.0350932467488512, 0.015074572555961148, 0.052505199527067524, 0.013849110541594847, 0.0382970915656657, 0.03808804915376729, 0.06440930954751468, 0.07165817138288291, 0.048555970312126225, 0.0558468827136582, 0.04282607696950436, 0.03416217029875806, 0.05013953916908753, 0.04401221473310744, 0.09954489031506163, 0.06272099731910614, 0.026354901229722366, 0.007048836757143539, 0.0733472956644912, 0.029075325414117788, 0.06846798974419795, 0.022312086713950963, 0.030376140794326222, 0.009818766022010917, 0.033545446537074544, 0.05769463699130763, 0.047786205165809205, 0.038790088297138293, 0.024463123709504164, 0.07005091891774247, 0.07458733920488628, 0.022322959416816314, 0.03189116010382291, 0.027896823631899974, 0.010771100454392933, 0.05151038073123463, 0.04323266664399736, 0.047409960233996955, 0.013320955162447308, 0.07461632797194105, 0.0790056057514683, 0.010937133732612335, 0.03038031214307393, 0.03547472023074666, 0.003813965618798149, 0.06883564299993938, 0.029626611860529072, 0.046371918757476156, 0.05140577908605338, 0.060015802962645415, 0.055996924864068154, 0.03594507523361714, 0.02444877105224277, 0.07688037825808411, 0.05565146517549312, 0.044542144563409596, 0.03785328533981116, 0.023907591220772555, 0.015571055945099123, 0.05955094081019202, 0.044314428758356846, 0.0073126108843773125, 0.05546472358307051, 0.06643957278180508, 0.020376860517107194, 0.024109034040462107, 0.013064572347267983, 0.012340216105052782, 0.005560500290049541, 0.030020750691032702, 0.07849273286880025, 0.009830426837828372, 0.0154116052773691, 0.011004274635906182, 0.0030823952223609894, 0.03122849979497973, 0.04570300142551142, 0.09647293902573087, 0.022121903471528523, 0.0598422150998827, 0.07858084830185098, 0.027776637843119043, 0.023607213891321616, 0.016195209802038247, 0.06124236335557315, 0.07298973178671253, 0.04571466128371897, 0.05356017920759417, 0.009298921739231915, 0.0813691555372169, 0.03140586064076953, 0.022060788807369048, 0.07962245974809894, 0.05654933554450831, 0.04310166177850577, 0.06603843382289333, 0.0699002830491912, 0.05219453938245293, 0.03532767731456026, 0.03186693448843735, 0.09878406541482096, 0.06737220055994488, 0.022574887430715947, 0.04529676415146359, 0.0305068047506915, 0.03182401441247954, 0.01936075405307835, 0.04820740030657861, 0.04615556403634049, 0.01532852783003041, 0.027681116255060322, 0.016835848913497983, 0.014903019614247306, 0.07189906006979366, 0.02723159884373027, 0.052084261025752754, 0.034420621551332936, 0.06522198327847066, 0.020430147677900332, 0.035306268987516244, 0.03347407778604858, 0.05262812216495795, 0.04554820952997093, 0.06275466305293864, 0.04979913183037312, 0.04396157249087288, 0.028270063583829233, 0.10805886208770737, 0.08631046861410142, 0.0809489639716283, 0.06393890857936875, 0.038113632659998634, 0.013422699299670998, 0.06900082687817274, 0.061312387622292006, 0.04697740017887085, 0.037909497041255236, 0.0273993376251911, 0.08257113982953372, 0.05219178146592552, 0.032718270761711944, 0.045674208010877335, 0.006837873379774993, 0.06130684497615984, 0.029530778091641206, 0.02896703505558112, 0.018554563341181607, 0.015179804308460125, 0.06129313966319446, 0.03321132878021848, 0.04859307578073875, 0.049013638898970625, 0.05830980559450485, 0.025583289811507832, 0.06620226172550071, 0.03550863494315455, 0.006229845194837019, 0.02959648736812655, 0.03148240814616363, 0.03837298789632417, 0.07358965524021657, 0.07917969923226104, 0.04179571552442447, 0.12349063079924354, 0.02466791433342282, 0.007557323786445083, 0.07058302060730996, 0.032175409367247935, 0.010560338175104511, 0.12594932870518777, 0.03192590027596922, 0.06143463610280907, 0.06768169242047495, 0.04117800350931864, 0.00494150699289035, 0.042994646956363035, 0.06872348772782473, 0.04249052662822989, 0.08264527415796634, 0.04371127624425196, 0.07660906821970018, 0.01939660696793468, 0.05273975266684448, 0.03653376783815123, 0.008679119261702704, 0.03895112380926167, 0.03844866972236383, 0.018918600661920446, 0.06347044581367124, 0.039435184125097535, 0.04899855462774154, 0.06598943483925636, 0.06924170790420425, 0.03930830847351782, 0.07440813591763859, 0.04788673888411253, 0.016347404659515428, 0.05275496717302069, 0.04855911127261577, 0.019833652467857447, 0.06473968496486064, 0.05784208976453351, 0.03857021340199056, 0.06781934309870967, 0.05848240903428486, 0.0629348622544879, 0.028120605575461543, 0.012377750582902903, 0.04121719656752483, 0.03959845661395981, 0.009358392187183904, 0.030435305764718406, 0.04065311836799787, 0.04945986596266589, 0.03782730729829881, 0.05812666844576598, 0.03799116584442316, 0.0198469958042786, 0.0467382466811086, 0.012758312420168472, 0.04301331651907775, 0.017832808925079244, 0.03270584864601974, 0.012141861577307986, 0.04410255565157822, 0.07074645780507596, 0.047275527125044216, 0.028131675545967398, 0.028199809490733092, 0.08812070373565921, 0.04862053237194496, 0.0644852671652071, 0.010816889529627179, 0.06193301460194973, 0.04631821982442372, 0.045554315250727444, 0.01651655687319656, 0.008872414736317532, 0.027133390202277133, 0.04844431682760197, 0.02897830995460672, 0.11131900287563763, 0.015398597104414819, 0.028663987909714063, 0.09620929752746898, 0.04182466598708303, 0.010212533299871271, 0.035177999055914344, 0.03535321868595577, 0.03945190782448457, 0.028844311600551013, 0.024421797096428853, 0.09706836554311937, 0.028526191674773733, 0.045706276451387716, 0.012876788875268353, 0.03983110985568455, 0.03416458347571954, 0.03509204016037045, 0.05892543768089625, 0.01785500823790508, 0.07347733142875856, 0.01853851379916793, 0.05828395012706038, 0.013023119329685166, 0.043843426411190344, 0.0891314878038341, 0.03991390097766154, 0.030090853481763796, 0.027129358664575606, 0.06372868639206694, 0.03155370220361698, 0.07227317144673678, 0.02788268739447719, 0.0593408411969581, 0.02391830687561343, 0.04641441748507562, 0.06789317865285181, 0.05360670372723572, 0.04595065466879357, 0.04870320858073331, 0.037053742355877356, 0.05501449370997087, 0.0251902062671199, 0.03731945612197442, 0.1584771308567255, 0.06967419518097755, 0.16649191207703085, 0.11197514186102538, 0.16961312281989283, 0.1058474267202039, 0.17228922115698939, 0.17524449725545224, 0.13402829277178935, 0.09603472907216319, 0.202628601222269, 0.14975615446605992, 0.17268875133126013, 0.0993466727255333, 0.14541078118547318, 0.24161835501511253, 0.1411338042347662, 0.14262263482857135, 0.2491500565121251, 0.13448812938745947, 0.17162327624617085, 0.1415345601497158, 0.15546141042103692, 0.07983150215999735, 0.11991181275657109, 0.19574505607447318, 0.15513629802773077, 0.12345625643408108, 0.1468473799046009, 0.2167942870648638, 0.20576072105717277, 0.19840221671808153, 0.12938299606884682, 0.14392095467736646, 0.1397031503579309, 0.12894983463470014, 0.1082059816126862, 0.0830993191489289, 0.17692989068886927, 0.19480633789733534, 0.10887574930224689, 0.18199652042840758, 0.15943126272289984, 0.22092556941413113, 0.23553702649810623, 0.1753532204536661, 0.1331574193412258, 0.1307676846702253, 0.07528497717313229, 0.17615669346865148, 0.09982287297926604, 0.18897565802739513, 0.1357972663977454, 0.17499626944622687, 0.20525580782803798, 0.08022142559169762, 0.1314015917840504, 0.16739318387642985, 0.16016718210472217, 0.10904280243501549, 0.18064351722357735, 0.09841123340471138, 0.23090689833606445, 0.22788181630594118, 0.14348169518334253, 0.1851081397504576, 0.14254052552484697, 0.16516031336880502, 0.1487948213733973, 0.1730582661806576, 0.12369170589672944, 0.17585166790071996, 0.2618237248351497, 0.16021543032219335, 0.22148155006429843, 0.20201914763498693, 0.20761779479442105, 0.2009589432348167, 0.11723772923071539, 0.11296961591729235, 0.13979394709871662, 0.18409082095228857, 0.11625096967984593, 0.0917641566165032, 0.2227263663324618, 0.1285304934267075, 0.2003377838240516, 0.1721722854962272, 0.1317973221622167, 0.08999234080434808, 0.16225979723516973, 0.12064108249521065, 0.14237854389413712, 0.08424714868587833, 0.12960912990233592, 0.09230713675459547, 0.18390015698969367, 0.0935020347336127, 0.1478952502891902, 0.1575218651804232, 0.15341028661256836, 0.2695577195094478, 0.13509321627357315, 0.12254841926117098, 0.13455563705534707, 0.11687199885566389, 0.15848816252283512, 0.11425406957465796, 0.2402367001219142, 0.23083102498804373, 0.09116044868865321, 0.10848445457316215, 0.11748640903181608, 0.10795228393568147, 0.14120996869619817, 0.14510022446272836, 0.16118105350723191, 0.18754976921744887, 0.2143086381857434, 0.09372135038457571, 0.2542460887061973, 0.12548302630743674, 0.11188454430309996, 0.10755536612123252, 0.16217713634813988, 0.08465838468363208, 0.1274341066938735, 0.10288891006982136, 0.11990418252084525, 0.17830507979998667, 0.11521157222769915, 0.1384884260234333, 0.14782924415363421, 0.08936195769497464, 0.08336830794090226, 0.25039855000232497, 0.1026746889035548, 0.18867496851711504, 0.1820540076662456, 0.23239701595758241, 0.17462151455542735, 0.1385058775063484, 0.2346502797257516, 0.2337270518464427, 0.14685612862869618, 0.10198085839229246, 0.10207103460185951, 0.21005087472017736, 0.148393759023278, 0.19970516373793926, 0.12538022496887755, 0.07153352121672324, 0.2593661760610919, 0.09326333705816539, 0.19162719558563926, 0.10157611115925735, 0.14370442758644783, 0.1708264222308513, 0.12430951750326542, 0.11780324767554, 0.10852651280020514, 0.23067060617669938, 0.14049948343346197, 0.16450028265676192, 0.11986659058640081, 0.14897365693844136, 0.14796281924411175, 0.1736270251774019, 0.1913241465245524, 0.11987573767621672, 0.14192917203951266, 0.16163276959090464, 0.14850133308960548, 0.1814560607195862, 0.18209856333992175, 0.10946005988385409], [0.007807974827535932, 0.0071213852835729004, 0.06290971158793376, 0.041159276490009604, 0.03957421376159595, 0.032132378208541104, 0.061933608320091045, 0.04293173964646074, 0.12581034503396482, 0.031013248240455028, 0.043860165432335875, 0.0014464713181481668, 0.035978530293270465, 0.049982912492968386, 0.05084866462575813, 0.026198738036797415, 0.03778466684443336, 0.015651604344677782, 0.05599423589545393, 0.01873493299729401, 0.007012904839470022, 0.030090499166098815, 0.08723152080370535, 0.024271247412769065, 0.04112576014332233, 0.020109030433119308, 0.0014224138830022347, 0.017698186209365245, 0.0035218546174526698, 0.031289434428477, 0.08406152558182517, 0.07028027032051357, 0.020254822710769314, 0.037303640236777645, 0.037934345103079276, 0.10669244468332299, 0.04626340623344145, 0.04088079969909403, 0.051747400674127766, 0.09008977952743731, 0.014140734358900979, 0.090698336791848, 0.08075321318521615, 0.04184211363955852, 0.022597284011182286, 0.07862217874536592, 0.027194361224950805, 0.030064090200129057, 0.01848614402866412, 0.04399065701891819, 0.06900084219993123, 0.026893066505210537, 0.015041709299229327, 0.032107342455175616, 0.001931456685152596, 0.057847069336041335, 0.03371309721842408, 0.026676633260062626, 0.018368767867345485, 0.009705878178318663, 0.09465392453656082, 0.03496917880951397, 0.04252530701999222, 0.036370334470824855, 0.05734294134702894, 0.08397373190570263, 0.034713473982147636, 0.08186443138026422, 0.03105365746324101, 0.031891142866844614, 0.05420570021435138, 0.039106938432181076, 0.07864135392611066, 0.005145762791676868, 0.041324004545928016, 0.029487628189306107, 0.03656114399012539, 0.02303319953141674, 0.055525144937658505, 0.03319273965673582, 0.04840373715025283, 0.12086558456142103, 0.02362563830590056, 0.03323560993697855, 0.015538241526472475, 0.0419840352579711, 0.05869041722748549, 0.08493783823665112, 0.05160164861609379, 0.018146022057701505, 0.03417299512112814, 0.02807590626029959, 0.050086062401533134, 0.09463758388113591, 0.05370949740491567, 0.04193751073832955, 0.07232051568045732, 0.039196804376138795, 0.04571183441927837, 0.016163352035707044, 0.0484469713222596, 0.008633583953093377, 0.04926051839344925, 0.04912484039161955, 0.024938879632240823, 0.054040343966335065, 0.04487058943918636, 0.043507182760344404, 0.06986116659977744, 0.04409789017611935, 0.012142327933331892, 0.03539940995735026, 0.0026367341061197826, 0.030058313897179983, 0.03654461181271942, 0.02201595925725997, 0.06279357265861285, 0.02758237518249981, 0.024621408965979374, 0.03221260676641138, 0.021279570646584037, 0.02935496857389808, 0.034424593717220335, 0.04817946874085934, 0.04445065834349202, 0.005105081607677764, 0.02485736404665776, 0.09331186872816856, 0.05136652474081324, 0.0392131986577184, 0.044556623625178496, 0.06085209135386733, 0.05408925484986075, 0.037118204824265935, 0.10157705344740423, 0.028776905439313383, 0.04843742203628344, 0.05479781340146738, 0.014530618528595135, 0.0580320680784362, 0.014266771144203603, 0.018428970886875066, 0.08851628855711992, 0.04812588472099555, 0.034458029624675555, 0.02021577712448855, 0.0327885631592043, 0.056340683837451284, 0.03033835159224128, 0.010385152061409768, 0.020213938513470274, 0.06476405422173201, 0.08003383364167907, 0.003320828597474423, 0.05668748801033344, 0.05258532466306802, 0.0403829459701815, 0.009618122806592334, 0.07852054952133088, 0.03432439324716407, 0.05049763164753395, 0.02167916402310854, 0.03350814954648095, 0.02189242566424993, 0.030521540451915036, 0.06479957005790164, 0.0540155993263808, 0.053451712648834915, 0.04072360994835054, 0.0217625220501495, 0.0684829974066346, 0.06548599249893619, 0.034366800044212616, 0.05919151533875735, 0.064206016625488, 0.009312523630327516, 0.01217783036296286, 0.033118172488625974, 0.03181294444197368, 0.0071137947886581385, 0.032287009225617495, 0.05371464168532722, 0.08824041263470728, 0.02116677952149222, 0.058951595753070817, 0.09809277831546723, 0.025432856956256494, 0.033294564233191555, 0.02740289227315976, 0.11337397244548607, 0.03735553120232878, 0.029559870280565757, 0.023551819988736705, 0.010329586746651801, 0.06123702372274092, 0.02528334723695392, 0.008729469432916132, 0.04271749932799609, 0.053429829347277843, 0.02013600438893322, 0.02569887907274308, 0.05897559728773852, 0.0033701086396186225, 0.07400390196351275, 0.034632517640749295, 0.05326972846242209, 0.013997870452341535, 0.0648557932506646, 0.02573654187032052, 0.023456614411946748, 0.03829118885820912, 0.025158806238323454, 0.030201013094835708, 0.08083218918933023, 0.008072359431084366, 0.050624618381862684, 0.059521549846977, 0.06557475144584334, 0.08238424501952626, 0.04962792650105492, 0.07351704542675326, 0.05573730149696912, 0.06032920570202893, 0.02429980525536643, 0.018663481891816183, 0.09420708843296575, 0.04555418884621994, 0.017504837108595718, 0.02364475603005098, 0.030983522113773133, 0.01294094299326741, 0.08513299913536157, 0.014390766305188018, 0.07525804918259382, 0.043855771918090126, 0.031006250027266723, 0.10440634638671914, 0.04751035988691354, 0.06480549191755634, 0.04393947468469701, 0.015364550241839983, 0.04186033887127715, 0.03839415107523242, 0.006751091418517453, 0.06116871932341207, 0.07149384552312475, 0.11123501665649876, 0.06955753531186812, 0.018884308651209842, 0.060181603541657816, 0.01749320214824571, 0.050986778787187034, 0.038475766252245636, 0.023023188677466205, 0.023557640341741425, 0.05235903761199406, 0.02054959419183433, 0.054013699428328586, 0.006799512963381506, 0.11489958292053593, 0.013501153406386655, 0.0396292380267574, 0.04948539201230292, 0.10656843037014047, 0.04675212436385694, 0.036724600340089494, 0.02208108822214267, 0.036775629456725814, 0.01728917378181171, 0.04038387293656988, 0.037992606089720805, 0.06713452944231611, 0.08402361189045253, 0.014184809312404645, 0.03364235282905641, 0.044395032699310014, 0.04987462596487134, 0.026276292947811947, 0.06519040513423181, 0.004126054756794005, 0.005713404736466586, 0.0563978684705592, 0.017222520301959688, 0.01452104242954163, 0.019047682646722085, 0.03795440511537656, 0.06971308946489327, 0.058035565269810546, 0.03149021458211205, 0.03079594931595268, 0.005669057342944848, 0.012681605951530079, 0.022574904667694243, 0.034149740522186604, 0.047006071019437046, 0.03393653442241973, 0.01985209028897507, 0.062164817486078515, 0.02724772499453637, 0.09421850314303752, 0.05012699830976706, 0.04630976604417928, 0.03026365610440412, 0.04372937124102347, 0.035419699796024835, 0.015970114017686537, 0.007928082092304625, 0.04837177596205185, 0.06914615375740875, 0.0174696832489703, 0.0402935664920557, 0.05882078623999992, 0.02054434074389358, 0.09202722354882187, 0.03796435659751296, 0.05216769183114652, 0.038961864361960086, 0.012562652606697334, 0.09567877397902551, 0.01594052865966073, 0.037708157643435464, 0.012204460536820755, 0.02976390822309881, 0.028150632391653718, 0.05645347113210348, 0.03838529509882774, 0.05369226808749861, 0.04631833856805198, 0.03639478799736789, 0.03165217897584362, 0.06376574972584363, 0.05461743416925592, 0.040279501117765903, 0.024515491564788168, 0.03061592056896658, 0.034413167515829686, 0.049234149647095514, 0.09414960885600698, 0.03270932285475635, 0.07558661663243849, 0.09794867717691007, 0.043552389608756195, 0.02505612747383214, 0.006611986609641463, 0.03709005109304863, 0.023919166809308435, 0.037185643544240345, 0.028478315009945826, 0.04594670165510428, 0.0037100706897270417, 0.05927042239495824, 0.034622826628507145, 0.08874800717157703, 0.11625669235664031, 0.22032820469429418, 0.12129465508605204, 0.12540120045624434, 0.12710403771169726, 0.27820296044791903, 0.1376058927346622, 0.23065615775844744, 0.1508903016726817, 0.14787326356576336, 0.13958914115303947, 0.16594500190788702, 0.1255375334632493, 0.1804330728707775, 0.13106575415980432, 0.141008380319803, 0.10526786588372723, 0.11959448381657563, 0.15334063389849278, 0.08804191159264696, 0.13976472850528457, 0.1653379078714117, 0.09813246166994495, 0.1125168273105256, 0.10040999510355535, 0.12994872135741095, 0.12796745710675755, 0.08244684972469846, 0.12851229883850585, 0.09969731882935572, 0.20220253376230118, 0.09455464720245331, 0.14503829391492953, 0.1579223146602031, 0.16221732532064762, 0.24192760938838606, 0.1152771570148968, 0.11368284377479747, 0.16204970528281507, 0.1981806794121381, 0.1607242046344665, 0.19797409614247663, 0.13948221060056842, 0.19605637888514227, 0.15591524090738068, 0.13827179168020526, 0.16261812720087268, 0.12725350146572437, 0.2767878428341881, 0.11495414370250319, 0.20994123221645433, 0.11954050526143083, 0.13453075451956642, 0.08895630647818889, 0.10013743634185485, 0.1599992249882029, 0.12298245403555133, 0.17319691277319388, 0.10229465566695699, 0.17233301074274127, 0.12350513284365017, 0.184366689213822, 0.20322127748400937, 0.1316659534049611, 0.14481209879440649, 0.10833398724395422, 0.16354317836944135, 0.09290786460042001, 0.10407217117326875, 0.28133990663674574, 0.15724239630564568, 0.17154417000710967, 0.16691801018051564, 0.13805707255678792, 0.11045043536972617, 0.13631472814707987, 0.07467699447466482, 0.13098896150627445, 0.11414165383264904, 0.15703605818411998, 0.2787213874680381, 0.09254795649359304, 0.14688511739575094, 0.08543072388537469, 0.1527921915535004, 0.11316199591683765, 0.3325827311604254, 0.2078809306746529, 0.0865301366655096, 0.16457767285887273, 0.14149905963530465, 0.10615932409681621, 0.20822822897424623, 0.10608460754156114, 0.15559230420377948, 0.14487899359195464, 0.12354392753613573, 0.11530366365707691, 0.09805908576855737, 0.228642710154095, 0.16125344881607642, 0.16302300466885492, 0.126821075475985, 0.12327854701828574, 0.1042895945870588, 0.1093541635500808, 0.133783757506359, 0.12004470602879602, 0.17989414533780468, 0.1279719387211146, 0.157898964300271, 0.1377772972468407, 0.20123677268143625, 0.09873872833146204, 0.0915696851969246, 0.1879881706929976, 0.16218749385687614, 0.09430441990374558, 0.11635624548240055, 0.07551908598191316, 0.20452525106168565, 0.23130731717232736, 0.23722110226029353, 0.09314686105015779, 0.09615309731734377, 0.15181190544559112, 0.1716339861553523, 0.14575515302919573, 0.1408477163603229, 0.1185401323281469, 0.08636191141821685, 0.18996893698650022, 0.1189944377890037, 0.14664787528735979, 0.1056804808397447, 0.11144028991580972, 0.1712160851926573, 0.10346915272455062, 0.12012987968421752, 0.12993221982352196, 0.13160972255131892, 0.15515961774414586, 0.11318150051538983, 0.18217838970163178, 0.06764977719754943, 0.1151023893767307, 0.19351293633301414, 0.13429167380015697, 0.1605192454712045, 0.14733315625738713, 0.16637060971510026, 0.1555544747820785, 0.10989135972434476, 0.13240217922195313, 0.1331075623391136, 0.11589893695688057, 0.07253780119842099, 0.14765155772047658, 0.1729505082532283, 0.11254341056149815, 0.14337854910521738, 0.1777302074216066, 0.19828731885119794, 0.25988034363235196, 0.1181229131837045, 0.1336883795597861, 0.08471054761039634, 0.12560444358255596, 0.17818051390349868, 0.12661112908033595, 0.13295417621491418, 0.21191007818185517, 0.1993669665628864, 0.11325254750948761, 0.12627919084362446], [0.009681905371948116, 0.04693845609924005, 0.029994906714907097, 0.02485340337208923, 0.05001625646987269, 0.037197441298274264, 0.022500235992934436, 0.09055036690927322, 0.03252554219216108, 0.03387320193371946, 0.046298895256533745, 0.10960832087984008, 0.06395344892817159, 0.04246716860741858, 0.020413761057199973, 0.057165530705524076, 0.037318720677567106, 0.04024690407658777, 0.06902592391857217, 0.021176596938241875, 0.05479314026512927, 0.014400073315858122, 0.03379511076115793, 0.022479794851894823, 0.021910830926630768, 0.004102642631023041, 0.040315848159333395, 0.02528061613350386, 0.039758201267930775, 0.022053564598243085, 0.0543620013031027, 0.02325945976941336, 0.025714380861890894, 0.02738595598437373, 0.021079627444006262, 0.030283905723462665, 0.03507164689982611, 0.05021863391682987, 0.04768040076258683, 0.025904384073651126, 0.008581282172892845, 0.09734800295724023, 0.06574645473231232, 0.008426758408125852, 0.046146872768839525, 0.04166856791163164, 0.030335204886092298, 0.012497343611152423, 0.028372083512705662, 0.1326414438024644, 0.015309744311736958, 0.0330769416365412, 0.0356212345462653, 0.0424520307100348, 0.030527577224758365, 0.04289548836588379, 0.03197776442844301, 0.020118415010191744, 0.038105439349648454, 0.0665971111025541, 0.08152928323515, 0.03593310894023988, 0.03608362606516288, 0.08207613211725989, 0.03149739665640218, 0.0419527865315397, 0.12006494607175551, 0.028556319997615875, 0.11437956243753435, 0.06008680399146773, 0.03250940838047574, 0.01809892297211674, 0.08193337929344947, 0.01282833860210714, 0.07515071260352289, 0.025978941665661913, 0.026571711773172985, 0.02461011874519529, 0.007429540799480053, 0.019085709336063555, 0.021416388204201095, 0.020184576278552413, 0.03361471237674837, 0.025055623771021926, 0.027091121301054958, 0.029544837720271562, 0.040632533585472454, 0.019382034060395053, 0.05230983561505714, 0.03240439687825499, 0.028940961253078237, 0.028578913845722715, 0.0068280406412668535, 0.10187239566397283, 0.026810551174886288, 0.04481407896345181, 0.047125335587489034, 0.028284130873338833, 0.05029795083007024, 0.04757781392864643, 0.027906355680897835, 0.026863598933203087, 0.03446626890030119, 0.04060799578925775, 0.05490924089005398, 0.012413158209153242, 0.09163659531623126, 0.05651108094400937, 0.05080604715453041, 0.030294579243467703, 0.02862843951480764, 0.06564390620276814, 0.045653822411212235, 0.05253750928527406, 0.06991069418408218, 0.018667180181270646, 0.03916331484252888, 0.029774227427438866, 0.019005850415616747, 0.03838961200428106, 0.023126355823009245, 0.0276398413529199, 0.08071480919757197, 0.04515215739487641, 0.020155888201007922, 0.08586110442035622, 0.08913189383043398, 0.03923955591275327, 0.04536140665051438, 0.10528242155428856, 0.01557659476079167, 0.03111830953839085, 0.03912193077285925, 0.05654879928296132, 0.03745882666759914, 0.06340991720677384, 0.02452118168284576, 0.026649850826229782, 0.06356492360693312, 0.04890117336124663, 0.021872666341462926, 0.03227710370875655, 0.04821388141041802, 0.038245392122095635, 0.02013578030821537, 0.0960673031307036, 0.016197010108660308, 0.0497255529156856, 0.03513349700839289, 0.03678986720079857, 0.015817174139702996, 0.030794359683509798, 0.011346313741899306, 0.029049694027391174, 0.029685504869708133, 0.05084125655553034, 0.01973395761583121, 0.044446119272540656, 0.052641770021329005, 0.01583236279041176, 0.03945591446432856, 0.019952240963316253, 0.043651027259446924, 0.031592359000276175, 0.03545109024872223, 0.02377627800489145, 0.061943115471231366, 0.03917985468081409, 0.05569408647716046, 0.01186460286619202, 0.036742706828179865, 0.03906142897903919, 0.061505104700524005, 0.031134581245902567, 0.04813791230140675, 0.06959829885031908, 0.09344919764947507, 0.13647730732637067, 0.06970922838175489, 0.008010706111353131, 0.052070333547289335, 0.009391323434219006, 0.03863546111050152, 0.12016967029100466, 0.02193323133753673, 0.054046855713691444, 0.013879280041662917, 0.04957392113283277, 0.015451017628243614, 0.04199517034595052, 0.06446022375096237, 0.06886606435141257, 0.07407094231776654, 0.08795541260511645, 0.003168079523264521, 0.01106873327385514, 0.02147072873589012, 0.02528965788623018, 0.03461501636211911, 0.02258350017420467, 0.01407797930897364, 0.061347114387899644, 0.07719252078283219, 0.023726871079434792, 0.013108439499422187, 0.052636947497845664, 0.073202436098889, 0.04221902506786489, 0.0023839758444322095, 0.05974816631585841, 0.050570712605070685, 0.04584508009194847, 0.019617156020455787, 0.028445708392668637, 0.07630754367358263, 0.05881073133599374, 0.02482384578475068, 0.05053920340874503, 0.07751424706751302, 0.042685503665838516, 0.06037046719763068, 0.04783219342390376, 0.035805233543918985, 0.020032959817458066, 0.007315909371696293, 0.04742365405564347, 0.040720698814238274, 0.013741268344493884, 0.1691960032668806, 0.01951231305757838, 0.008867008070791922, 0.020463418876451832, 0.061676823308751474, 0.0452510746676595, 0.03899249255717282, 0.028533785521323164, 0.017022667114713022, 0.07302504077914261, 0.008766506911225377, 0.03728928757951625, 0.048035720002747355, 0.0072884015483601445, 0.029513221271636508, 0.01416816222181003, 0.02994112734262261, 0.01769087198490818, 0.029587627561282248, 0.042459745215432304, 0.13755045861246126, 0.056615808993698134, 0.08041500834928406, 0.053619248416995814, 0.06954687902884138, 0.027833782256610935, 0.031423287225827094, 0.020343277137726545, 0.05922914557759801, 0.034101603387464444, 0.03886764320815283, 0.034941772014022834, 0.01338314139209087, 0.02646104845729086, 0.029291775896243995, 0.04420024335324284, 0.020902193819863663, 0.031202500686049465, 0.0920748895394706, 0.07660340682993974, 0.05808234642890673, 0.02783054361991104, 0.03648637380871562, 0.01503252869306673, 0.03220724798138103, 0.04170150586193608, 0.07086061256667299, 0.02498087274181026, 0.02698072420072652, 0.03891184265094419, 0.011792859689693057, 0.05906982993286464, 0.026281092488657565, 0.016372007573203697, 0.044397353945720586, 0.05915640169874795, 0.054961886452210534, 0.024579854441746592, 0.030850780143913244, 0.07281888651871875, 0.06484244799902363, 0.02632054984719763, 0.029975308270584193, 0.0271941639573103, 0.1260907561968892, 0.016026436801879637, 0.020324536711878834, 0.05366870322294774, 0.03777898630247482, 0.0667014522778411, 0.0552490966454629, 0.025634295945506425, 0.03857937581356495, 0.04355189548204503, 0.0385525933797321, 0.035136726068993734, 0.04869981481122875, 0.11981436637260261, 0.05333894833682045, 0.010344914250796842, 0.023648624774068597, 0.022008512882635962, 0.031244445915123632, 0.019771095643180515, 0.03900678392740027, 0.016653567868014498, 0.027074972167611126, 0.04163167694763791, 0.05159472701169791, 0.025865089508794972, 0.06758493551563832, 0.10426838927331472, 0.054709188519946994, 0.05647075407567525, 0.016786049367980133, 0.02965226239945379, 0.05488978225677725, 0.07007904200544281, 0.00515185893633433, 0.032620349403230414, 0.020749817016504465, 0.04900687817303885, 0.05078074327039142, 0.01887425949286309, 0.028662302516280647, 0.031220398415180466, 0.05562547947310152, 0.01895122834661555, 0.02603251802464647, 0.026606132103610906, 0.037194177763716835, 0.031352560073437716, 0.03298787242402473, 0.010511958765076294, 0.0338215752685022, 0.061404636099694244, 0.037090081736565604, 0.031104780425648057, 0.04498097504819593, 0.0738338687487187, 0.04463989738254778, 0.0205054541208571, 0.08778950860423428, 0.06601919735511465, 0.11382284634295972, 0.2658464525255465, 0.11390854093816974, 0.11085476891528215, 0.09739444320721012, 0.09853342442863411, 0.10331262563986164, 0.21245573196680317, 0.09634550796040604, 0.18730736367644804, 0.11218956221015224, 0.2631216309964657, 0.10166455601011554, 0.1476199489327208, 0.09782490801186332, 0.17938681127082917, 0.19727550056432525, 0.16901991029660549, 0.24625796734565691, 0.13272120887714048, 0.14338011192458291, 0.08016106552414357, 0.14688658828456558, 0.09122432509977972, 0.13934596952411438, 0.13214195447583355, 0.10075890984866889, 0.13111959481912275, 0.12889959458862582, 0.15613696207442593, 0.1162497132956501, 0.06805873025328883, 0.10373580494835492, 0.24014680736487914, 0.13710657194737466, 0.13104920666063988, 0.11291474870015537, 0.13959894707847026, 0.11198589773548227, 0.16124583390210906, 0.10322611133057265, 0.2026354194047951, 0.12555601150398293, 0.1012197653612783, 0.13019434446769376, 0.07675891501768943, 0.08948565791210822, 0.09775869503256776, 0.09543194044982234, 0.22673420127361055, 0.17737434425901982, 0.1119379559531808, 0.26868097784538425, 0.1915155765750716, 0.1431794275319384, 0.05511737165732249, 0.17279808739981345, 0.15426888731458496, 0.07507149911215229, 0.17116613625999422, 0.11925002004230216, 0.2099497970794478, 0.12892717375389992, 0.1826143703393398, 0.06062160614096831, 0.2559028764165217, 0.2229093694158139, 0.11010963349573075, 0.18614001421918794, 0.12593353963306836, 0.18018973270250907, 0.13005989603698254, 0.2524058382597662, 0.1543477330837519, 0.32139925706771116, 0.14853597558554144, 0.13272647956205955, 0.08450599447373422, 0.06736474652444163, 0.10131794718965408, 0.16395343377465205, 0.08179917601087401, 0.20578183444036593, 0.2030687800218021, 0.10472313140428836, 0.0934251654712904, 0.076606065155037, 0.1276801971177901, 0.21613580385042777, 0.1396770880467469, 0.13263977373078947, 0.15045205341471782, 0.15481369840281625, 0.20838616566071588, 0.10966409974160696, 0.22095029873232688, 0.15573137980555335, 0.14192953976171632, 0.23398880876841086, 0.13596035119506622, 0.08779205201614289, 0.16675861792698984, 0.11639235886715113, 0.13692295599368312, 0.10973545317087444, 0.281763369397771, 0.18294372685974647, 0.11689086760123892, 0.15127959691228407, 0.14296472373027957, 0.16379693733348002, 0.20004716070909656, 0.09885880495271376, 0.21026337218861427, 0.18618921238568523, 0.14149938139223284, 0.22078848564096037, 0.14200873793132845, 0.2972126662010147, 0.11001427087091631, 0.15188482169422413, 0.12712722719316522, 0.12744490853360585, 0.11578107432973002, 0.12456827902144964, 0.14317501486549455, 0.12218167765005944, 0.09863845508305297, 0.13234403314850024, 0.22496322049729287, 0.22725186220580534, 0.11071712589792668, 0.113815629794713, 0.14233473898662677, 0.16850623302161696, 0.20933262132588895, 0.07443396074156608, 0.07823934162696523, 0.1550062622634634, 0.12966453338101988, 0.21732403686450374, 0.23392847168349454, 0.14835890202272325, 0.14230881457126912, 0.12462141487987773, 0.1975070276568013, 0.14454410591673467, 0.18392762890265835, 0.1452090089479762, 0.09042784646754304, 0.17307705065656095, 0.13435302212113334, 0.11485760130228535, 0.11440532597442789, 0.19280896281763432, 0.17028262237868003, 0.15545719693745338, 0.13271503420847078, 0.14164503002839704, 0.1535830547612521, 0.13661276699314195, 0.11724734363416511, 0.1856168527756968, 0.12267400405459827, 0.10171689513710239, 0.0933604846678434, 0.12493181072415845, 0.21835278569450303, 0.09345055362510105, 0.09008029535893472, 0.25547395910947557, 0.1733361415925526, 0.15799248831406718, 0.14250519354977917, 0.25073880029301493, 0.2233562131802882], [0.09603066880616451, 0.030235942873743274, 0.03625642868780321, 0.0425221354159857, 0.012997699574747635, 0.008266240005351363, 0.07873981920701843, 0.052456273321783355, 0.04334450782006306, 0.016772746251175003, 0.04404024589025686, 0.03844593095803454, 0.02443052283788641, 0.10707167352760032, 0.02451194840813837, 0.005469180215450545, 0.03631031914283672, 0.07448845257562015, 0.016062294504785492, 0.07813702292379834, 0.06242595004638838, 0.04623022313500124, 0.05248924574604439, 0.02378329345505805, 0.01644626256048439, 0.013150419202452947, 0.009557497481094494, 0.05981279732359033, 0.011084057905170466, 0.04012306213318821, 0.038504000422694994, 0.07613461464643478, 0.0717743409557208, 0.03677146193841773, 0.06819738450670434, 0.03305928714032615, 0.12346661394281734, 0.022452215686620727, 0.04335864980314528, 0.09360953219114773, 0.07377383043809284, 0.010660578864776801, 0.05911677963130417, 0.057761524127976555, 0.035559905377487024, 0.04096472846163858, 0.06436839279147887, 0.009699675738961707, 0.03624889038262829, 0.06183275667529914, 0.09245853105019178, 0.01080420598643081, 0.031877550551848065, 0.05996949677806228, 0.014142709908135718, 0.0297891776332812, 0.01466486873405595, 0.027438785407632112, 0.0334812943342953, 0.009920578149537887, 0.014245862689530178, 0.0184514919566291, 0.020278697840929515, 0.023678211089704308, 0.03990779525690502, 0.07513077899573312, 0.04683461288110383, 0.07056341641732762, 0.01564798362162565, 0.05149955590886455, 0.026508295014801047, 0.04576898074799007, 0.025854831591488856, 0.037447925236436634, 0.049124909339532744, 0.03370174762582587, 0.03261347376411, 0.04976796354317377, 0.037322252342898043, 0.0560614179759737, 0.06947193264720902, 0.046461390166152874, 0.04149739322583041, 0.026980239650114413, 0.00805586268524489, 0.029379567657146725, 0.01749739073397171, 0.057690595877507043, 0.044721799842532606, 0.05203227429921108, 0.014122542643529034, 0.03255497145977232, 0.04233976435517112, 0.03285545029587323, 0.04930177605861137, 0.06960533919834322, 0.013750718039039884, 0.013979191313527766, 0.05344120575295341, 0.009275376026879155, 0.0167763794231559, 0.03357998178070111, 0.08567129081535725, 0.04121548436101406, 0.045513930925798994, 0.029610420592249404, 0.021783976342468973, 0.055599543566425005, 0.05290323199944631, 0.032168522236808654, 0.0549063642298983, 0.08499836684354851, 0.0859819777730492, 0.006184317068301983, 0.08198852230223917, 0.023101605437395555, 0.05595357577887274, 0.053248044343725334, 0.0408564534248604, 0.04592032141743168, 0.040632050950080156, 0.02738887669458505, 0.058778084499100526, 0.014670894015580417, 0.017915146139961098, 0.07900980391329335, 0.026618234377594727, 0.07271400908188475, 0.07416720126545237, 0.1182576757104647, 0.06421570380729053, 0.030655408571023616, 0.04572481194871568, 0.044685027622167146, 0.01742566000640152, 0.05645511439070106, 0.07583950225624346, 0.10599148955436484, 0.11866378658000501, 0.03673510340553138, 0.06783947588935976, 0.03276256213505422, 0.03166437509559816, 0.019541772968706586, 0.061792318724216, 0.036168566063767484, 0.04874477268106515, 0.03323474425762411, 0.028677375296190865, 0.011789905463135051, 0.05806172717242472, 0.04588492815532992, 0.05699920535628354, 0.06091507910300167, 0.05881037127466933, 0.05845112200345724, 0.04818997563674085, 0.057512059086753484, 0.005079547418356543, 0.04543816866052728, 0.014970629746394773, 0.027279119277673385, 0.03201029826736739, 0.06318538449704647, 0.007469824096563483, 0.03931597701363987, 0.02818075879927605, 0.0213321281086293, 0.03445419535461453, 0.05228604858500823, 0.06460548168228519, 0.04159587765893629, 0.05848086919755705, 0.04220498650665245, 0.023542923792715997, 0.03790334152478365, 0.014377435417695632, 0.03529157159068892, 0.03091555479313097, 0.06114597417294018, 0.021937157538148667, 0.01947483412110277, 0.070742420521715, 0.03972684911962959, 0.09856740042807595, 0.026432165027325673, 0.03244868442115765, 0.09115778270267672, 0.01811098694170435, 0.03384913145113857, 0.054436323323076775, 0.03718585421841952, 0.06090749483255129, 0.05105931582229753, 0.048839959105657, 0.07455431315447054, 0.0365438035899593, 0.010790005589144365, 0.057102194386384184, 0.016339776339009404, 0.025662118343696482, 0.06191842445743181, 0.058156101543816834, 0.0724355361214088, 0.021405191829187736, 0.08103214579844668, 0.035596229436416785, 0.0499289722422198, 0.027190038573838053, 0.04139953315438282, 0.05069678769476953, 0.010683896665972088, 0.03857207882608618, 0.05458707793525631, 0.0340845043049945, 0.0851774245740906, 0.0241465091464981, 0.051685546735121365, 0.017409332757515293, 0.01962309894752839, 0.018070491534026883, 0.025078868793864405, 0.0293301128511948, 0.06502918193056699, 0.014560197183351605, 0.0595064617453083, 0.07674801358652693, 0.03524323144266683, 0.048680352347512404, 0.052406228628129735, 0.007819422096344493, 0.026667715996624004, 0.028786795634415843, 0.021810431273714192, 0.0221977653282304, 0.07066404972706111, 0.01865937183010242, 0.034345288295298815, 0.018384736970127113, 0.030169978873023105, 0.023480525931283355, 0.039923756698807406, 0.008524698918805489, 0.025930873478852937, 0.06038102388922727, 0.014272060981320759, 0.011723397539988642, 0.04645092923554682, 0.03246368825315468, 0.033646650582311616, 0.015491637525208777, 0.01729441956887322, 0.0536911572600084, 0.04446273188917868, 0.02021092778792785, 0.05114706736358424, 0.045911258597287445, 0.0601918921024809, 0.04909268002055826, 0.030389934207402894, 0.012004964538068782, 0.022285520699956728, 0.08057143584254288, 0.02200380527234126, 0.05592570550018742, 0.0910486075125875, 0.10880336165428163, 0.03825797511625194, 0.04215757332501873, 0.03853748612586529, 0.025413402153419393, 0.06091397976683033, 0.016241006538151734, 0.053880894256214944, 0.04391554592838211, 0.00570158974545437, 0.08701349218045512, 0.023584085696887587, 0.08786846162571062, 0.020412575536137147, 0.04101073970237086, 0.02417410363353068, 0.05776005323916193, 0.09961317939263198, 0.03172904823816592, 0.014917649978381253, 0.05092616208017834, 0.08607285112262734, 0.0432006556600813, 0.024132024339069764, 0.059291577912987246, 0.03528976745362725, 0.05255261270870125, 0.018204208350770416, 0.06063708111703877, 0.034157355436153954, 0.04935560905705056, 0.02350922166970709, 0.06537235101624843, 0.04841250502654622, 0.016383701905367837, 0.027696382472171422, 0.0247853345447971, 0.0757004649588658, 0.07491101135289477, 0.05257138952372536, 0.04269519084764104, 0.024398914050130595, 0.04132714550641756, 0.003764286732128371, 0.009494758710535544, 0.037035440515366294, 0.01824862421340039, 0.023160969590648048, 0.026180510889858972, 0.07566670346404276, 0.05594290034364789, 0.05620950277173712, 0.05124633320637288, 0.0360456510867563, 0.05002304783932144, 0.028161819190568024, 0.021196070893277085, 0.08028555481183915, 0.03569780886473675, 0.03164331150812007, 0.07931797044171442, 0.05098581351640244, 0.033077615793914564, 0.032574437753928286, 0.05123066670832135, 0.0063766357808133535, 0.02655427561201636, 0.02998119948672191, 0.04828629587146063, 0.009551294084127632, 0.07243965767444142, 0.013567815504727826, 0.02917737407129138, 0.013113685286483698, 0.06535866102504154, 0.07717618778828653, 0.08240911989442765, 0.07894359859487704, 0.027362546252627528, 0.08648943441409258, 0.05112506914883853, 0.04800226877353365, 0.04675958989067905, 0.04607992051469703, 0.029057891168180975, 0.03726444334813184, 0.1808786755728145, 0.114246561913, 0.12003815597704343, 0.1424513069251853, 0.17651816439484397, 0.11132242728865917, 0.13857278762565506, 0.1564442552626133, 0.11871747402173859, 0.12480247209990218, 0.13416762884345748, 0.11365574724491566, 0.12795198979156633, 0.18430227654114847, 0.09179120718110954, 0.11271203417451152, 0.18640734826124486, 0.16455861259131663, 0.14193603618731424, 0.1910983038044745, 0.14488400380697944, 0.19154098005064074, 0.22428621327684772, 0.08581582862403124, 0.08782706223428251, 0.09261642943226522, 0.19607470370829108, 0.2691217235499813, 0.09993591691337286, 0.24171638362590345, 0.1219284089822923, 0.15739446475861535, 0.16281416910069604, 0.12723527623400574, 0.22000428739814992, 0.12488644299728256, 0.20524351977773253, 0.09483615387110941, 0.17797875698776017, 0.26815648340890486, 0.1527932487548359, 0.13293036620222753, 0.16277416398929012, 0.2073146231592663, 0.11310264708534365, 0.09854796477743695, 0.12853740353978452, 0.1554763184920434, 0.15970878573434968, 0.17504709171912364, 0.16346004250789845, 0.08775334925420823, 0.1127981347963214, 0.10753711790687616, 0.14451289549469948, 0.09272541310037337, 0.09223867147680252, 0.1534571099065004, 0.17875452826340354, 0.09369462923777681, 0.12303282431657277, 0.07860871091965707, 0.09500952722925333, 0.16896839854457688, 0.16732428192852006, 0.14584464742051018, 0.11616817089698969, 0.17101011479333525, 0.1473947497264993, 0.17310982389796167, 0.08143274083493218, 0.10262384364802031, 0.102685391151857, 0.1286189612602034, 0.11172712855641881, 0.11955904458919842, 0.10247457141597426, 0.1414190340907343, 0.2208046347744042, 0.13638412039126122, 0.24766568455003926, 0.20795404610614623, 0.13387568805727268, 0.20173439275353186, 0.09390530341695394, 0.08405933457036173, 0.17856936481210495, 0.21598975684854294, 0.13139736297870838, 0.12480697669689694, 0.19578438702850573, 0.15122126697772934, 0.17710855771456996, 0.19519469850967008, 0.18624144426036268, 0.1510045407039504, 0.0895039444308608, 0.15752682943017254, 0.09585615397701341, 0.1148546365420184, 0.21245629887186715, 0.12246230331760262, 0.1777908049764172, 0.16650095191453734, 0.13294829265965571, 0.12711318480151315, 0.1060022377679425, 0.16014753961034361, 0.2112920750533381, 0.11775827831438473, 0.17416869530514364, 0.1847742326677807, 0.12701174709945917, 0.05439249926336831, 0.14247802807198418, 0.13713693967269314, 0.13513964120178454, 0.10172394314600576, 0.20245348884453698, 0.15123049067633768, 0.11591735371058026, 0.12327934374972699, 0.12688414749479102, 0.14569996405513058, 0.13492541237463876, 0.1905820371523019, 0.13700402341783047, 0.21418949619175928, 0.20430982713737797, 0.20989125264027428, 0.13589409991137444, 0.0986070684607952, 0.08429011855755122, 0.16712393461456224, 0.11218051471176649, 0.15487212026792188, 0.12908095824382, 0.20752188058630114, 0.17570752079688734, 0.24386466270492924, 0.10665493701855022, 0.11366359964613953, 0.07038421313007993, 0.13150035583924863, 0.2205222854090314, 0.14440371264373103, 0.10900308843702079, 0.2802200699525495, 0.219347796012317, 0.15760806539366323, 0.15876285100896514, 0.09500865388901965, 0.13933023407814965, 0.1415596725118737, 0.11228631911498886, 0.12859741886777262, 0.1231805720336495, 0.12026277295644246, 0.2565203126399748, 0.12390624881992418, 0.12228945089924721, 0.12639276337839905, 0.12520397112013834, 0.13688278234293386, 0.19045103611724992, 0.1832360506898934, 0.20165999029432574, 0.12047381485782324, 0.11377272121007405, 0.20227085348338852, 0.15835152308066047, 0.125971169871909, 0.10348730134747683, 0.12812830492733948, 0.10809846883339268, 0.09047905944528119], [0.07251242070548958, 0.010343343770552066, 0.024869966193012176, 0.033128123970762376, 0.0788550541525887, 0.05705183559668161, 0.008756975819837422, 0.054442486500427614, 0.029156653308159405, 0.009332194853003227, 0.034671197420046214, 0.057378472504957076, 0.04269423706817531, 0.03901653622667636, 0.03668760978466561, 0.07132407277822495, 0.03192089197616423, 0.036428622270543734, 0.03954345150099647, 0.024364041727817348, 0.04148679822983761, 0.0257681985385716, 0.026673586145343802, 0.06503372483195798, 0.034635470909697395, 0.040066915549217694, 0.03664262893219148, 0.03616773868880926, 0.020706408559494925, 0.033701184551201524, 0.0248256575826916, 0.03178130309548109, 0.03094757152270646, 0.06089799534229021, 0.05674366906826055, 0.07735226543680315, 0.04004536932634731, 0.09879723446623934, 0.06968511193389855, 0.009532087302256015, 0.02391806172747766, 0.042797191624319365, 0.018387203773243294, 0.05255863032934647, 0.009505347960868911, 0.060717550992605195, 0.03964745942803641, 0.06653135777601311, 0.0858712321027152, 0.06367125278038364, 0.04800278205244292, 0.04816584386712602, 0.0502035343238423, 0.06465980497699592, 0.019186930618278922, 0.0038518963077466095, 0.03566446105739282, 0.06589997875233812, 0.03441294151989203, 0.037988672228229624, 0.025988209414325898, 0.05486738950675053, 0.014327215481429331, 0.01233274195974152, 0.050817078820640044, 0.017463309397440285, 0.05030134459957481, 0.020453097756891962, 0.05031502692990246, 0.05495178175248927, 0.03522035605724781, 0.02054937777199572, 0.029126044265144778, 0.04370992409906561, 0.04491419516383641, 0.051232149088454824, 0.01615028257571882, 0.053301298945781686, 0.11974397821411972, 0.050250338465576215, 0.05777867683660119, 0.008352793576646476, 0.0740078319945643, 0.05137760237219834, 0.03875338502468602, 0.007725944047823789, 0.0035620060037716383, 0.013675339775340212, 0.036534196847388824, 0.04337714316563741, 0.01704932888969779, 0.05101300197683516, 0.019462528833819014, 0.0138536122657599, 0.041895529120078975, 0.02044284175480566, 0.05174867238008207, 0.10405094287688695, 0.025216967633534825, 0.021008773887109373, 0.04526726976637879, 0.042995949305834315, 0.04758609916954752, 0.04584034566857642, 0.035981552510131756, 0.0493538087504285, 0.0689765495518523, 0.051104553314226295, 0.06737023937485873, 0.049189766343202324, 0.08126382610850758, 0.08389162260197824, 0.06942565327570324, 0.04252008230034863, 0.06042893502801176, 0.02895151602945501, 0.008353368142589686, 0.07939337647610134, 0.11030834904240985, 0.05036878331954922, 0.039188377408971714, 0.059973365522079894, 0.057968490441600164, 0.025436842528682564, 0.061600429020942225, 0.05004277843381128, 0.011697338101634336, 0.045329330549124754, 0.02012114419842199, 0.04097577161906708, 0.056487849327705564, 0.06614853597937093, 0.019786683617219813, 0.04036064132026607, 0.016944250354783672, 0.032282799572473576, 0.015783536176557745, 0.012141724639091522, 0.07877292952710584, 0.1700832556572653, 0.038115130361890605, 0.05500242399472383, 0.06995040818207687, 0.053476292579885454, 0.032866259796484824, 0.013766047458404736, 0.04545709869313625, 0.06504794342383262, 0.03750835425190387, 0.036433701433481715, 0.040798383960199934, 0.08054061612534909, 0.021539322333410386, 0.024906261523644772, 0.06192527328347487, 0.050279074423615976, 0.014201166247197939, 0.03278652153488609, 0.013794880135044938, 0.04970241322993271, 0.017656229488972216, 0.02053057988955369, 0.06263419572684555, 0.013012890140676211, 0.018301922865512393, 0.020315138728267724, 0.05844167996979049, 0.015328493356073817, 0.026504328594573086, 0.035378576196249456, 0.04110494553441963, 0.1003671937712258, 0.03656909981321904, 0.03167553699665493, 0.04145995833941045, 0.024376979037638635, 0.024850082380937475, 0.04698632893362834, 0.18230640299377904, 0.05959885577941614, 0.009919226004351533, 0.02189500163489532, 0.029500241826979384, 0.05172113151920419, 0.053313759365870114, 0.04354556759579047, 0.029964272774034933, 0.04587496135143503, 0.06407490450768702, 0.03402329771028411, 0.03194205132463286, 0.039485447153809576, 0.02964294485507473, 0.027681533772979054, 0.020257358461798682, 0.046441514014957413, 0.01613648916264215, 0.04734433714240309, 0.02466283325526503, 0.05569365363748324, 0.07360274002196328, 0.028607965815031243, 0.13494770553323532, 0.07382732635784535, 0.018705676099465742, 0.014337079821064348, 0.0052275110764669315, 0.03854782831284308, 0.0692752548944085, 0.027918300906857176, 0.04165394712359675, 0.058242286435298385, 0.021841572747836192, 0.060489306586884686, 0.024384293262095704, 0.03773706597125819, 0.021567569910398415, 0.07346424664701186, 0.06145412154916314, 0.041413663646146175, 0.11242610717853231, 0.02689807480501552, 0.021133100381121043, 0.07147197371288654, 0.0614466521919014, 0.06923407000759918, 0.0333222774638524, 0.03361750476723237, 0.049018698909710494, 0.024171303582167434, 0.05245610861287964, 0.019309000983353586, 0.03961964277550578, 0.04889482249235434, 0.07240962702780962, 0.07018840871751308, 0.05467879781199079, 0.029142530477275292, 0.013979685440238927, 0.02987500054821853, 0.02904883026325655, 0.02504462849408869, 0.030276371248727365, 0.08937865075084472, 0.06305240695514987, 0.007074393450297536, 0.10112832510663618, 0.02838319370282754, 0.02769048742559408, 0.06388792542800789, 0.047112993911028876, 0.02164334941264843, 0.08825486871383845, 0.010646455076282785, 0.10211155299217471, 0.06411244281597676, 0.038446831111345565, 0.04785341405940633, 0.04023902103184693, 0.02548165101137373, 0.035047614721641425, 0.032612412732334874, 0.035736948296788244, 0.03362682422683124, 0.0246608414266619, 0.02003589393420806, 0.015094185364432635, 0.03270284941179618, 0.03151481941102013, 0.05044436555415873, 0.08602523875813331, 0.008266899798576149, 0.052196791680950316, 0.0947390062614314, 0.03345269627208191, 0.02152723921162467, 0.042460702825337655, 0.06737252231687307, 0.04497031110428995, 0.020030922023579478, 0.1107726289680408, 0.04454518210202937, 0.07546106248252815, 0.029600610836378993, 0.051456084249601255, 0.04282342247484673, 0.023337878444562518, 0.03591803232989004, 0.02993626459952324, 0.03955097065397328, 0.03986886266859309, 0.029374653203112465, 0.06444127839659491, 0.09692785735692709, 0.07258164441032756, 0.038925590098745404, 0.05499438773239813, 0.06703803300737374, 0.10487405072537162, 0.10117644308916024, 0.04651862842541549, 0.06340241337555551, 0.05488600161287093, 0.02564772738203887, 0.012916062372706592, 0.058246155179316, 0.023630045226684982, 0.021906454649363315, 0.07415423139689431, 0.09736903973164097, 0.029232798617393262, 0.014809547311386034, 0.004852487576088959, 0.031791645282458876, 0.03355407651754157, 0.07652177250072842, 0.06234840662669271, 0.08775195497418604, 0.04696019384409151, 0.022945453735789465, 0.048110095648876125, 0.022341724740521565, 0.06719004783418871, 0.09582738737545668, 0.03832889187540259, 0.024206214208876895, 0.014646143629966725, 0.07280603156334932, 0.025514169528539625, 0.07933827177170785, 0.06724153660357961, 0.028251202499133446, 0.10789412254047011, 0.08450896689488042, 0.015602997981101997, 0.0326967858258755, 0.009932377818791617, 0.04515235657773672, 0.06905899593426336, 0.0738581920403146, 0.029301620126070998, 0.006060430596041824, 0.08019249045079754, 0.03784702640146979, 0.08766619909194209, 0.03748731747750313, 0.002659809632009016, 0.0881944933245259, 0.016363404405814026, 0.010768010247228368, 0.1008684067956863, 0.014614260008168078, 0.11285005257494989, 0.13696634721371437, 0.2232700895758406, 0.18620582117188364, 0.19966610857555944, 0.13736837483461828, 0.09125368158903815, 0.11703022665554479, 0.1336408821084807, 0.1082659739580366, 0.15165755405060707, 0.11615910807684546, 0.13348148985495492, 0.10543042974125956, 0.20123321803346758, 0.12907417070481086, 0.1246642545166035, 0.11905543370953492, 0.10680817758604404, 0.13488932963340514, 0.1864511838122722, 0.13205474302653344, 0.15364329991561754, 0.1626722896171193, 0.09017420241669302, 0.22792054971139278, 0.1808440637203955, 0.10920089233907, 0.11597315555498486, 0.0928150836919104, 0.09224904430729729, 0.1089691584028544, 0.08125650230795145, 0.08703294315285261, 0.19427102629936513, 0.26821709628547397, 0.2720832049606308, 0.15041705851833667, 0.12446274274900077, 0.15624092020575078, 0.17927988071835813, 0.2067597916409854, 0.16760972628910698, 0.12031416979528244, 0.19749389690977914, 0.20548670672841612, 0.1904308420395659, 0.19651043919786332, 0.15972472036317473, 0.1092423760001698, 0.22276330709217057, 0.17773826666657003, 0.18170341518857788, 0.18174015676542637, 0.10944948020961978, 0.22619341980786095, 0.07173225974604007, 0.12203582983103492, 0.24476138394205804, 0.14708141976546857, 0.1115282521312756, 0.11034162024096136, 0.1299519695702099, 0.20808198278950107, 0.2581539185297105, 0.12946538116422393, 0.11156759840706665, 0.14331733868006738, 0.13574802226597263, 0.12125229042383934, 0.1804248910517462, 0.07024100065351495, 0.09567154976989954, 0.1351708975890952, 0.15460323872825793, 0.12302650409119746, 0.12525722189175506, 0.16196820884943008, 0.2920441161240301, 0.1014544180924854, 0.20056165003728485, 0.1440986257887656, 0.11500642154245608, 0.17564776593879347, 0.10644900492362439, 0.10853363741790095, 0.19368113859766917, 0.06195138155993435, 0.17734451279524835, 0.13143942120575136, 0.09101265500630103, 0.1722596041978367, 0.10254972464134617, 0.15887028717946622, 0.23035992687988668, 0.11197296617132042, 0.13550367086164414, 0.22395072805304683, 0.1077843574626792, 0.11767479005239664, 0.06222666376420568, 0.20203799339792422, 0.241395867760143, 0.12860305727489535, 0.1444130282728903, 0.14887582751051073, 0.17815121870127418, 0.1487122064516429, 0.2400679462739537, 0.15216634368463872, 0.21973329145581494, 0.1754636443670719, 0.1782984301568039, 0.12055914939170885, 0.09988436685694803, 0.12341403732857398, 0.17299324063764465, 0.2569110940901503, 0.33109124990240224, 0.2633849507377994, 0.18641670985567957, 0.14185541309416294, 0.22054439470652612, 0.13346929373520036, 0.14819574061660998, 0.14511792109377925, 0.12640587880366272, 0.16367744293905076, 0.19212412617860303, 0.07642717596383826, 0.1284839995505829, 0.14718773744760022, 0.1196892642145676, 0.1803489870602085, 0.19665155259351577, 0.14073255802354506, 0.10296970936319522, 0.1520646684953282, 0.15849594597614583, 0.3821776699154608, 0.1727439403053253, 0.19424163916658974, 0.20266468396350262, 0.14499853395165938, 0.14792684375518753, 0.10004367484080215, 0.16779410833072278, 0.2263546659941635, 0.10904518496846, 0.1097531651236838, 0.07922113692808537, 0.34725846302124763, 0.1352196361028379, 0.11966432039175304, 0.1283117370199292, 0.12123758919657239, 0.11592539763378522, 0.1539828760489341, 0.09302913631883361, 0.16625932778321928, 0.11547525203035724, 0.09496779842001778, 0.17207133042956554, 0.1652954206351311, 0.20251008742038282, 0.11371682743511854, 0.16234518539521003, 0.11118109938838791, 0.20317272283136847, 0.100839969611937, 0.14590516836652834, 0.238922001313298, 0.11250833139544535, 0.13862468242164583, 0.2162545015134158, 0.12545872599847857], [0.028593961727775397, 0.04468728758154377, 0.07684915251429043, 0.07227068932186212, 0.03344291715972847, 0.027753149587360602, 0.01970454366997846, 0.008817693075886177, 0.04662234906948382, 0.012322903475573948, 0.03084813905579429, 0.04180838278825245, 0.02489761813663908, 0.09283587531817537, 0.001929901766068783, 0.011531281840777206, 0.01829700649625832, 0.05328754000666161, 0.07701850391083187, 0.014804912479444137, 0.0834735147955437, 0.020329885920810125, 0.06739098503584824, 0.010184666851625569, 0.02825282085987349, 0.036702483381715514, 0.04588382498871896, 0.05087174302447708, 0.00957630302441577, 0.014245230666992646, 0.03277472378085217, 0.031165667178650058, 0.044395722178441864, 0.0727844815100393, 0.08193314180619295, 0.0399416525127186, 0.018987734351427327, 0.03923238916022163, 0.04635618331151144, 0.044420030148279284, 0.03189533911344986, 0.018996958050035664, 0.02145425209985866, 0.028209303235334736, 0.041844070994205056, 0.04015789232066563, 0.040035494453003334, 0.013460525848542251, 0.0668844860047102, 0.0407681311480701, 0.08789585692988289, 0.02077375917935804, 0.08441577995977095, 0.045209403315018264, 0.030607273351521264, 0.024970831244342753, 0.03682174411932788, 0.08630241703001723, 0.03173221792695263, 0.03427782276224706, 0.013480154936382127, 0.0870289518347671, 0.020752596000449795, 0.06883473901618874, 0.08525253183418706, 0.01580992886315911, 0.06172081590780328, 0.02754689382028676, 0.03590757522972361, 0.03225872908989268, 0.024764202009405822, 0.041435937652544635, 0.035115666311955264, 0.035622946752776066, 0.013839985476806762, 0.039136873317822334, 0.029821420358794353, 0.027406891252124504, 0.0479634587592896, 0.041888186167324745, 0.0037290883436423517, 0.05873947366771679, 0.00885457637900066, 0.05639440958358108, 0.04780960149101673, 0.03289148324139176, 0.05794382624087795, 0.01796046598634172, 0.011032519340064498, 0.0024777742134662528, 0.023204718956783898, 0.06922384273381003, 0.04850550043967463, 0.026806140423662243, 0.028987780716570637, 0.02332770288170826, 0.07686878734778974, 0.014007728088707214, 0.0329119109758927, 0.04793835788845055, 0.08717420210521068, 0.024106178447724353, 0.00983380720079426, 0.09018989955826152, 0.021013178892673987, 0.01782536829611467, 0.033545136271465215, 0.034296251007265625, 0.025917767629688306, 0.03596688192638178, 0.03999068980075179, 0.028238743994264837, 0.038597168205606366, 0.03592342175843735, 0.022403785523267526, 0.08221261068097047, 0.01717900650786056, 0.0042972658317716374, 0.02911826655749352, 0.030316497018981366, 0.04475174238905311, 0.07206114895281292, 0.01585310940901118, 0.04157872111987203, 0.010298521881322227, 0.021135626556051355, 0.013475218457320045, 0.04835821620579209, 0.0636269690679206, 0.04066892276187578, 0.03099299096051724, 0.047336653280522556, 0.027626984482330662, 0.03699838484246885, 0.03449667876045551, 0.03705489914864302, 0.025140353095447345, 0.03269489358870253, 0.032188287305255095, 0.023066562660519156, 0.024359642467912168, 0.07199307437986135, 0.06449844387750472, 0.010904546267533255, 0.0946757733641613, 0.03844211967061124, 0.046561391453348824, 0.07413925437797463, 0.012996675889758814, 0.058160602310371984, 0.036509222381057284, 0.1044515838786479, 0.021142975254465016, 0.06087121673889699, 0.06295975628158738, 0.039576569481963114, 0.030646031654830423, 0.05064132675949124, 0.021099279514483867, 0.0693133601077622, 0.025652785477558934, 0.06155139173290903, 0.014622723364511566, 0.011450047792506315, 0.03385621393399854, 0.024162447605762753, 0.025911976004980748, 0.013534076034932608, 0.02231538089202537, 0.040910336219014666, 0.025154087136709885, 0.12129697633246261, 0.05744748553561588, 0.017350123737067465, 0.0802975211052164, 0.04494602994752988, 0.08464017477367194, 0.08491721514972948, 0.1344072764679309, 0.034745251309246786, 0.07627230362906572, 0.05744079375759729, 0.02064748490679889, 0.0067398629635722655, 0.005599280139581571, 0.040183395387664925, 0.06741130168760015, 0.07590943076197179, 0.025957864671645146, 0.0417216080090692, 0.013403736708325245, 0.05409635265447921, 0.07145818413024949, 0.029089021150984114, 0.06294453028409232, 0.013209712492572445, 0.024482524886186567, 0.05120151323236285, 0.02279681927194038, 0.05496082158999578, 0.024945931471583825, 0.02453762001448101, 0.02904299075805372, 0.007341627422119341, 0.048670768587579655, 0.03296389004155513, 0.025559265294202396, 0.04700654216351048, 0.02720686569509487, 0.057358090735731594, 0.029682400298394987, 0.0380672728492608, 0.0356667478298468, 0.013595906991301285, 0.045054745484864524, 0.03297553840844381, 0.030385680504203327, 0.024411475976868987, 0.020841916106761466, 0.018284798885184913, 0.0393478041364541, 0.025836524005318363, 0.020070810306576953, 0.024121611288958983, 0.07310028593506544, 0.03448260189484685, 0.06250068958428118, 0.026499467766693523, 0.06896509653738431, 0.1367778742625829, 0.05211120816848932, 0.02951753817708983, 0.025678468575220437, 0.04862168916471062, 0.02383571685171656, 0.058487974663054755, 0.04216752480715514, 0.05122468739207234, 0.031822721639107314, 0.05173658734307655, 0.03834560408347076, 0.008392809221761362, 0.06335030790538558, 0.02407574177449269, 0.050505514692274794, 0.03597185383701036, 0.00955858149550735, 0.007015713988127368, 0.017474249132999012, 0.041563889657657956, 0.046241955771561594, 0.01866783901688553, 0.023980672178309292, 0.10599617801246144, 0.030517560625148397, 0.028258844226178144, 0.051128428444386496, 0.050240781518720815, 0.02638937901675461, 0.01825971908176378, 0.06288385229004968, 0.042814846120534406, 0.08424450568253956, 0.018807950752576994, 0.04702280621014295, 0.028960703338886944, 0.05027286528098968, 0.06007099193671058, 0.037823469197798165, 0.015438060208614317, 0.0016547270535093343, 0.055277177598327405, 0.03282179222291997, 0.005316371051219082, 0.06310714393733971, 0.03969471173120603, 0.09407300006357894, 0.022841441978309906, 0.03963343235814283, 0.06746542579945057, 0.04328263472885855, 0.03590369882482675, 0.027975675146726352, 0.05568178310509651, 0.02883589037904336, 0.05187545610111087, 0.04132313886657357, 0.061252364633424636, 0.0603220581016954, 0.04294088290583703, 0.05557294499369399, 0.02634725758745786, 0.03423789425963356, 0.06318872847083597, 0.03228621249417624, 0.02220634742820215, 0.009282796546035718, 0.10770398717854293, 0.03708814736455679, 0.03731315121835759, 0.010648889320662186, 0.042789469458042614, 0.03353636073429258, 0.04956729064184812, 0.04041244418570592, 0.033445996833184076, 0.057326550895888964, 0.028304346018440785, 0.04346599021265584, 0.07826824612434834, 0.03910159496890922, 0.06485562471132125, 0.013712137851173119, 0.049294754862785346, 0.08514280506079236, 0.04780871282902457, 0.08247050651980024, 0.046848141993846626, 0.028227892358817404, 0.06161961569300583, 0.008196748169739882, 0.04779578509530233, 0.05452993160654461, 0.060248820096134185, 0.02568823045059558, 0.04849721136833391, 0.07706587878806938, 0.0269580269307499, 0.039570728061540474, 0.023409840913729805, 0.05125386768110818, 0.035513798375764204, 0.09118849516756113, 0.019777078789869146, 0.006598764889678288, 0.0615912436267301, 0.07476553891695316, 0.0190998379126071, 0.05434745329342062, 0.03461156513602023, 0.02239088651784245, 0.04201207024556014, 0.016034112045271023, 0.0269551809141112, 0.023546524405960115, 0.040223316229399175, 0.051025627105827295, 0.03705187693178173, 0.011672415346237681, 0.014538138639181854, 0.039716120058250044, 0.0633087552963726, 0.21367528265522373, 0.24276999966992488, 0.2619718555961886, 0.21227237648300587, 0.13013483475773566, 0.2215072446532788, 0.14472792105328652, 0.11767416952117798, 0.12267175941698014, 0.13650672510266304, 0.20236472989762985, 0.2161988069213206, 0.1205226299803584, 0.1696303904417061, 0.08151864227388175, 0.08314635694747971, 0.1596049808206097, 0.09185433282607025, 0.22519814902015273, 0.056310668512577974, 0.18618591820761082, 0.1867717609650666, 0.1160315084721773, 0.14225457554623006, 0.24064785951087553, 0.11886100059435253, 0.07007822995224307, 0.08032044245591087, 0.10225343247575146, 0.10973159974861531, 0.13782029010115132, 0.09643327865389087, 0.1333231854462816, 0.10526801910131209, 0.20783735559351985, 0.13221330790510102, 0.20655120122096232, 0.1635351344462364, 0.15807484276592731, 0.14867833004363123, 0.22573483957638665, 0.12443150934432784, 0.15748915322605642, 0.13553583123270543, 0.1472074718725297, 0.22858051913640193, 0.23831997877888142, 0.23849103089061477, 0.14904369269647907, 0.1754457638749192, 0.23650513180801946, 0.0714014859629735, 0.11885060478122005, 0.16150000655362684, 0.21002738646441893, 0.13512652577652087, 0.06602832146229283, 0.1614063446440043, 0.2644132245932856, 0.27454743402138837, 0.12168558209293312, 0.15868644139939742, 0.17636479359240304, 0.22193718851814348, 0.18138453875097538, 0.12323056693158804, 0.14951943329745723, 0.1464899386008901, 0.11745232578006484, 0.09103014479361235, 0.0994251890768928, 0.11694033389850972, 0.12235262250948338, 0.1776933739142072, 0.10206891253830926, 0.09348061491524981, 0.1273351894210904, 0.2489450973488631, 0.10146779398764334, 0.11317656690915746, 0.10603712541201424, 0.07814857552969649, 0.170322566203052, 0.1447894072700893, 0.09293877624816473, 0.15779925029604666, 0.18469783837997145, 0.10410145105373475, 0.15158126701510724, 0.14409959105955017, 0.20849426066683185, 0.15425900478036175, 0.13395810379616677, 0.07243117708111964, 0.14481914680330985, 0.15114370823627518, 0.1660401959933581, 0.10623943391105822, 0.23250193935969185, 0.21415163612654134, 0.16489054316714888, 0.08876875283256655, 0.21566013985824203, 0.12962347106827846, 0.08545574431698169, 0.1619310229415855, 0.2580771258761806, 0.11379477688141408, 0.11431440665957429, 0.20237016912189223, 0.2420888862182056, 0.17034412391724127, 0.1170516694565454, 0.12718142025292883, 0.19332827849974557, 0.13528430924540566, 0.0894047590273042, 0.2382083138030383, 0.09706730068090463, 0.09990885102700803, 0.1195291901427892, 0.12977656607906665, 0.11381479475887553, 0.11538827040743445, 0.07162077863129877, 0.10757605815606733, 0.07674531695703346, 0.0869547332366628, 0.18770264972361828, 0.13087905853265716, 0.17657313886429035, 0.18706575486688845, 0.11331567315444832, 0.12021455538248825, 0.14475367692930086, 0.15750251379945587, 0.1268143262413721, 0.18353724581820352, 0.1513574774106664, 0.09053001195312509, 0.24512303872935234, 0.22567269452396901, 0.0880704100634302, 0.1359934921586706, 0.17975038127793422, 0.17249313844067438, 0.10047299817444817, 0.1567782542758411, 0.08812530026320489, 0.1776679091516041, 0.12258456328943854, 0.22037398610864917, 0.15165291155778593, 0.17839881831840163, 0.15329543471096024, 0.1773456312836178, 0.2021659760465545, 0.08799406940177565, 0.16248994536938208, 0.15998083887802017, 0.1397041156287155, 0.22660857817578703, 0.1870131246264904, 0.1307864997896456, 0.07383985189540733, 0.09580160851680464, 0.10643811115334112, 0.1161999022588134, 0.06938042344465371, 0.08563510848269348, 0.1549431212967442, 0.1934237483768694, 0.12211683596814833, 0.1138840874116267, 0.2121674837244134, 0.21959349573139222], [0.02785422722809017, 0.08303975581281609, 0.017063756240531802, 0.08069847620302632, 0.09605488484545101, 0.058600919005731424, 0.04954435396939517, 0.027868493700460083, 0.036509050011274316, 0.07929239076592269, 0.03391229923093512, 0.02077441801497292, 0.03669706330965123, 0.09089712128644029, 0.04217652250982581, 0.08879830084380605, 0.03731805035063336, 0.06834453467520014, 0.03338413906373805, 0.05314269959325752, 0.0329122327328209, 0.014717424280881403, 0.015963666430193812, 0.08855856128878171, 0.05655822982530921, 0.02749579001007782, 0.03316349808066603, 0.0520147730205809, 0.0435901002868289, 0.03481801050985533, 0.017900826041436484, 0.04118898921015282, 0.02808818090406637, 0.06881331153694661, 0.031141537324255033, 0.019199804725846457, 0.007477058839398407, 0.045977073210862376, 0.04365784927241264, 0.007165658941131927, 0.03789395311727159, 0.016033963615735693, 0.028980753775085175, 0.01615981653993649, 0.0762501790098125, 0.03269888873722765, 0.0673430126100298, 0.01299458638494534, 0.04328592124605372, 0.05727942116678723, 0.09267952443370897, 0.04739078505325222, 0.07330192027673607, 0.05992148987828724, 0.02929902691844731, 0.019051536068981214, 0.027765881968662146, 0.07665704830639786, 0.019569241051231662, 0.037700404833641746, 0.08298242945344218, 0.007220998738757185, 0.023456294570238363, 0.017574562601024107, 0.006830022893770929, 0.017741002863453283, 0.02355661186870308, 0.09441267578832566, 0.06563716462903446, 0.005689488907885408, 0.06339097951328562, 0.04997349344193936, 0.03914938736406546, 0.03728375642470295, 0.02986315108324972, 0.02834134423474391, 0.02286142155137514, 0.02324674079465049, 0.049799212269605174, 0.018529724855456623, 0.08310920168315211, 0.044043919281853784, 0.04748072760600237, 0.03513929246354007, 0.033309939617831866, 0.01700021882331179, 0.054615744945382884, 0.025400418878322648, 0.02485944206015237, 0.020798111199251106, 0.07494416763825763, 0.035944833915920994, 0.05695583711889002, 0.056441087320807486, 0.032869753157419544, 0.012328198100740631, 0.062204186744507284, 0.003650549249047594, 0.01385391295527018, 0.015523137145435378, 0.042599579244251215, 0.016369921898829843, 0.029695649789045417, 0.011328681270712087, 0.02063224358754533, 0.018447289964364424, 0.020798509564971732, 0.020403123926371336, 0.04947002428854185, 0.08901809913016136, 0.02686420797310289, 0.00981833701277332, 0.06206461318558263, 0.04662182046881607, 0.05051469242560768, 0.04561970085506478, 0.02023932858250074, 0.059726849919365305, 0.04198305849586764, 0.07625916522116431, 0.012521343230600319, 0.009945519099522744, 0.035226687773941986, 0.06454506798857643, 0.031547692243851004, 0.019161446703477733, 0.07415082230563126, 0.015149902939165552, 0.05914422473119152, 0.01566527518368657, 0.07914541679764948, 0.042930862475787444, 0.043083279498762665, 0.042366428045375694, 0.027474929435899662, 0.016228714657406655, 0.00780476922837777, 0.02271435565255102, 0.03275312776226671, 0.14635149119121416, 0.028989408653409734, 0.02254307179922058, 0.020364193253279216, 0.08159071582579806, 0.05504114973929621, 0.03483493339210268, 0.09086792567564596, 0.009570839859905743, 0.031740962820608294, 0.04950978808225163, 0.06737901108159174, 0.04438102861205417, 0.03280143343633221, 0.0237559192183037, 0.034022788261814464, 0.01654641323482558, 0.03135486025243037, 0.05274884613050569, 0.007482423848893134, 0.1507195253526011, 0.04834527698075099, 0.03557300548099222, 0.017792438006689473, 0.027047038686672048, 0.019791728306201198, 0.03669133297197762, 0.09627177199769406, 0.05986398731869075, 0.0373307099535821, 0.00515937569528638, 0.020597403823968866, 0.017188456202406558, 0.04602252137697032, 0.020626630078280167, 0.022767631322025292, 0.078435490779098, 0.06020149118417214, 0.03270458077050505, 0.022239649270270622, 0.09288081403581366, 0.026664306905360955, 0.06143838993363804, 0.03362464853712628, 0.06019152438027724, 0.0325262431626118, 0.029807452660714908, 0.045328851744172075, 0.0379851597150968, 0.06684926128195179, 0.07926831262246256, 0.021080207755608905, 0.007629823474769271, 0.056068496628394054, 0.03131074507931068, 0.01114164473443863, 0.03730000514957694, 0.036686096761015155, 0.07893042188257941, 0.016108256907412605, 0.08527003694325687, 0.028584100260970094, 0.04346242407336832, 0.02132120944048849, 0.061897985231612, 0.024543683600401687, 0.044296406539938146, 0.008813545667386104, 0.06346217206408901, 0.012964832487576192, 0.041355647807640415, 0.02435726568012709, 0.007517827165898897, 0.051157267824296034, 0.03715472040517676, 0.0526737695139262, 0.01626207204084964, 0.06395765092043627, 0.02446964120251998, 0.022733168856751536, 0.04962279754240186, 0.03156453660208612, 0.024053611409580036, 0.09297847492440094, 0.016847623684894175, 0.050362443941975796, 0.05397008221235968, 0.041372436624501026, 0.033636760387209155, 0.05377773285633134, 0.039956729123068434, 0.02951082533165332, 0.010858342547209994, 0.0593133692839934, 0.04311274707077011, 0.05122765981321854, 0.00559755644175194, 0.07078010438671035, 0.029306343058124188, 0.04117366362122759, 0.011210093732863184, 0.09984041639273206, 0.02628053707491246, 0.012840633355681936, 0.11051539962570514, 0.058523624564611146, 0.005248067130695188, 0.08452199805047243, 0.022182822783267307, 0.03936825868403239, 0.05291560814986306, 0.028760742899330876, 0.07770516383912295, 0.008025886622377703, 0.0009250913881846974, 0.0369326391768071, 0.01923712469907778, 0.06495512421092679, 0.04334943376541619, 0.03166764246059522, 0.07564640213404933, 0.08684702893538822, 0.06357822289329863, 0.0545178312477806, 0.004330675883759415, 0.06741165408804532, 0.019307464977065404, 0.06723827306902216, 0.03458308198699548, 0.054470927514616525, 0.025929559638062795, 0.015819802778893183, 0.03376833981864395, 0.03872832245824318, 0.04205859859564132, 0.03755180675896906, 0.053860079647312244, 0.022263403741582748, 0.03103515643986964, 0.026602167598602754, 0.029919479613102255, 0.016019570738858274, 0.02418854822134299, 0.023263935638110966, 0.06455495052279965, 0.05305786684696233, 0.11235738909172435, 0.01817783002831763, 0.06491089795505808, 0.06910781871767775, 0.0698781431081795, 0.13644059639303915, 0.021499121869583766, 0.055732318095021674, 0.048035892372530316, 0.030413554613328272, 0.06341425326442526, 0.07731571538193573, 0.12168057187790833, 0.023243180401022398, 0.005457921116988385, 0.02114229535143222, 0.052844549664446426, 0.02899046968518486, 0.029534765579287085, 0.03211378142417919, 0.035509872175152266, 0.011312542670977213, 0.007378717090168427, 0.05707511317826087, 0.02992714623800449, 0.03930832762571593, 0.06495389847024795, 0.016056267308041213, 0.09543046190012848, 0.05509454606761856, 0.019820586838308844, 0.015981655132265824, 0.041405861040637384, 0.05672412233487253, 0.0025053794736102706, 0.016154871442385258, 0.026923951339877905, 0.062060158384302934, 0.027724739216688662, 0.03074481869266639, 0.04102793454583134, 0.03616013526616078, 0.10457590462700014, 0.02385357053079192, 0.0478218742195637, 0.018189516699602528, 0.029123933692913384, 0.03814459793389805, 0.04322626597938999, 0.026992242332668077, 0.017340116713556553, 0.022277654892194177, 0.015717335646190954, 0.05058059513929391, 0.0381553269952776, 0.03832531041435657, 0.03825012271502807, 0.07161799773213363, 0.07935493418406095, 0.036568617177826744, 0.05275687090151253, 0.04102089036736758, 0.04253264997274645, 0.07239441252163342, 0.03935793564925271, 0.04141647135838866, 0.10109517648215256, 0.17448418563412083, 0.1513915683232969, 0.11433268551744762, 0.21672877122557935, 0.19525246153916084, 0.22030879202629292, 0.10975534081338875, 0.1899403465851661, 0.2262890735460866, 0.15601608872173295, 0.1624667941923103, 0.11631543597867412, 0.23208766965375793, 0.1987434782448315, 0.14404541332154505, 0.1926677115261555, 0.10239898918136474, 0.13614525417647055, 0.12934314417502574, 0.1796283894368718, 0.15353290664572872, 0.1317562292059583, 0.09908847811241304, 0.1437920680449855, 0.09790969862332267, 0.10726448253638322, 0.1156947362206636, 0.16265681464104884, 0.13201984006070322, 0.25130892292626444, 0.14462082196147213, 0.24263012733670974, 0.040747243760814594, 0.18267561140800678, 0.1436479209411529, 0.09181827306747438, 0.10908901285860809, 0.22864813405659892, 0.2843413165500087, 0.10357583046800668, 0.1903945141501965, 0.08710640332391185, 0.15824494492863456, 0.12213387376358434, 0.19736749240227286, 0.17851489596068862, 0.13915795622573746, 0.10143259224752266, 0.15688322364322602, 0.09111806104380278, 0.12561119281716887, 0.14422398841669484, 0.1721793488268891, 0.1037025643933204, 0.1448334573257354, 0.09775649636022507, 0.21694157512918597, 0.1141602238039336, 0.11166684509765719, 0.12839808278987486, 0.13841797657791646, 0.20247899957241552, 0.0747592110306986, 0.16746754037036052, 0.1367659386127226, 0.11113801460352637, 0.14511790577202074, 0.21991853151590596, 0.22876874693939764, 0.06172922755321188, 0.18411979439758486, 0.16266789227243394, 0.13244229158566845, 0.1588517018864232, 0.1516323037926228, 0.14869202769571735, 0.11520501451506732, 0.137734365679564, 0.14431138372709676, 0.19332630199290093, 0.23382051457320494, 0.13165343552827835, 0.1962496935119552, 0.13503552985287484, 0.18394264422597426, 0.16229402604362658, 0.1816407032310963, 0.10237815925070357, 0.20751539948246173, 0.12381431060813128, 0.21382882199700803, 0.10857270790203925, 0.21814188168894863, 0.12167501007957805, 0.19138457554001964, 0.12812777632667174, 0.1276812160147294, 0.15868354558704362, 0.08172217651360458, 0.074370160939232, 0.10818071603294342, 0.14069874290256731, 0.08504984029118093, 0.08917277228207358, 0.13835641375232127, 0.10441333310858858, 0.07224394519242548, 0.10971544295429222, 0.11629945538457363, 0.18185140805379038, 0.0992797549453474, 0.14494555131081613, 0.1442960006815772, 0.179753813351835, 0.24635386623201833, 0.1417430126739125, 0.09338895249510966, 0.1728087819872364, 0.16617053819279518, 0.1504524824239554, 0.20270838161870358, 0.18165590241551402, 0.21073378081763947, 0.09673664947190593, 0.20327130302546487, 0.08310707961960186, 0.1455049793566427, 0.08181992167186353, 0.19331729279891138, 0.15857842300207386, 0.13154881856133863, 0.07119546959837598, 0.27655761809118334, 0.09939018651963243, 0.1094770823575316, 0.12476425963423907, 0.17719397651812724, 0.1896804589177332, 0.09436717782650264, 0.27893380832768255, 0.1385789163290493, 0.09943638162146654, 0.13360755728377452, 0.17777594287068615, 0.135320162160262, 0.14280231309033212, 0.1787520154950119, 0.05646306638335509, 0.1251893771451808, 0.15570473526754688, 0.16775382742766412, 0.12963165288730977, 0.11959626114055996, 0.09664567653089763, 0.10808072623706634, 0.22467779145846445, 0.09902220384608354, 0.12200751522135352, 0.0751905874799817, 0.3181198185249683, 0.08297245498866805, 0.15374727336870087, 0.15622539926440487, 0.2088520696927463, 0.12343094488906285, 0.15414265134642202, 0.29005890652056665, 0.1957208630178244, 0.08445060631680874, 0.13163287372839066, 0.1052129143969186, 0.08410961292083226, 0.1603296233881866, 0.17683037586750525, 0.13381951849066442, 0.16476291291896375], [0.029772226022736683, 0.10370392036894638, 0.03083281729730868, 0.012325849083642806, 0.036216722350687756, 0.09181261933859318, 0.029401096643038818, 0.03967518798045574, 0.03289058308808073, 0.04740551309359651, 0.019183159550471653, 0.0924860795719489, 0.027042775407373428, 0.030920543940737847, 0.060562253479034676, 0.017060670821416764, 0.026267486767122344, 0.025349493183556105, 0.020968948806365652, 0.012595781121372938, 0.018503492089709448, 0.025950912423732302, 0.043996084751861717, 0.040865056592250065, 0.036313280072664066, 0.017526977049607425, 0.0055650881991060755, 0.08252733492202337, 0.017703070019882534, 0.05711797962806398, 0.04092127212413377, 0.09488810995413412, 0.03507209889170143, 0.05883585901991014, 0.024248327977294405, 0.04207155697288052, 0.02766890289832748, 0.0817823144156606, 0.006713048449807591, 0.03815806959004652, 0.03232106949473101, 0.0375888969058231, 0.06152801839033924, 0.01725131180137396, 0.010409034852449213, 0.050531519546864495, 0.03128206657786523, 0.007079050786072209, 0.010021000785092193, 0.0779445126893059, 0.047458526377956715, 0.020229645231137836, 0.09040025198051045, 0.05522502999332163, 0.06956085247258026, 0.060805593647303126, 0.026075259985161886, 0.01909680995008638, 0.022279912936350992, 0.037517466867763194, 0.025111345176194465, 0.02459996424975895, 0.01644956248421823, 0.05527818500394783, 0.07521872588944051, 0.07426819463651027, 0.049824952823861, 0.053526004025292014, 0.0378071170510544, 0.04537983489553294, 0.021934914815750335, 0.014377994661880358, 0.02275446227060691, 0.053842463455493414, 0.020293339696382324, 0.03477506362082016, 0.05432143311707243, 0.013509953841416827, 0.02636361739508087, 0.03954380773188126, 0.02721178014912913, 0.06627879390913634, 0.023697275187700026, 0.0727644176673024, 0.08443797352693735, 0.05854477242176091, 0.02152776589707261, 0.03212420405038903, 0.022436091451034434, 0.11058788686510056, 0.025668603277975516, 0.0182671137454529, 0.03253020383718033, 0.04514285325703602, 0.0882461965985356, 0.10097140731710581, 0.03315320951984294, 0.061805376692885355, 0.07013944037739309, 0.039610706359869054, 0.027335518670658913, 0.041245695038308064, 0.05576520241917141, 0.04261673578331548, 0.050783393934609435, 0.03427866545896377, 0.09300993815545114, 0.02430091991329626, 0.014726763850288286, 0.09289602854198988, 0.02515916055398843, 0.059155903741597175, 0.02306630027540509, 0.0056161144429126815, 0.07827755409262835, 0.03194271590590718, 0.05257171511109318, 0.00972780552993138, 0.03796623351292745, 0.031748861187107624, 0.009588547982275486, 0.02856562605067607, 0.030568685502775257, 0.04990347300566012, 0.037270043450858326, 0.01787785872546656, 0.023359261873748996, 0.04237658254081204, 0.043909398072789756, 0.04015505779534578, 0.033900604898770975, 0.07161679497409253, 0.09316489475989535, 0.03176933680210383, 0.07315429513372722, 0.03991023141650423, 0.0028508884790954332, 0.04993615048607031, 0.03769906034933464, 0.017241306693082856, 0.090466748412338, 0.046909697158562566, 0.08110033528458688, 0.05331166411539721, 0.07166906515316618, 0.030544017471613425, 0.06804686355134172, 0.03694483146612202, 0.08314923743807501, 0.030657241436382456, 0.02258920944446037, 0.03968302122948151, 0.07385035496084921, 0.046705772213998346, 0.05521647662164704, 0.01595538885017196, 0.04491090481620162, 0.04691681794581875, 0.08019137962330734, 0.025593490272219625, 0.031888900144446286, 0.06139588354515934, 0.034730756925719405, 0.037089001552592364, 0.037174408864830776, 0.04954568313194379, 0.052749003178530166, 0.052192256440438574, 0.01645731720923176, 0.030126846207666303, 0.0820767603093578, 0.041501901653264804, 0.07339447901974763, 0.026630164281795585, 0.0872387603345898, 0.11600677149310229, 0.0763941269307848, 0.10851484528111835, 0.06610956508666277, 0.05179644179260058, 0.09404516808928982, 0.038935698628906286, 0.060797584198054776, 0.02982338154388051, 0.12613415507779968, 0.024238602491095666, 0.007733358342515966, 0.04937990170512949, 0.026500249176376292, 0.05137958653992222, 0.03693163943206591, 0.01805469863146784, 0.06719270615928596, 0.04465167215394397, 0.00608562387623674, 0.006483647730126376, 0.07795989573482545, 0.04405685084601564, 0.07526919576189212, 0.022087170960261457, 0.04147971574697764, 0.038389263434275504, 0.050128059341542186, 0.041880264818187685, 0.024913728965686697, 0.01622836991784073, 0.007876657482777393, 0.12197129458429352, 0.028747895604840694, 0.0009262389041044029, 0.008711248031637121, 0.04538002641751401, 0.03467525002516566, 0.03031210158951581, 0.0313064185977583, 0.0034395480460877865, 0.06912474159992511, 0.01779128121392381, 0.025719634309831648, 0.045672411534694896, 0.03584233135165226, 0.021094727036993832, 0.03372099941536304, 0.03634850479542248, 0.07815098870665797, 0.04680605312328666, 0.01649067267745493, 0.01894095893799057, 0.0336022442957807, 0.025998940390925256, 0.07479697150448639, 0.002574217261656398, 0.058182952925562866, 0.004648754153505809, 0.013553457101807, 0.04648384803365316, 0.053685070691449996, 0.04616677573311233, 0.033247928630800984, 0.07295127417291365, 0.01634475782573704, 0.018046357849192236, 0.06025377285456466, 0.059625446691267917, 0.037977326466071035, 0.039765904282009414, 0.01165584390682559, 0.040878401843891035, 0.041085686084003224, 0.0504340693324564, 0.007764270469065636, 0.07306632525738209, 0.004338982670883378, 0.08273914291132843, 0.026099983557698228, 0.02372961750464334, 0.04498845206633691, 0.036439374314561006, 0.1191495169675158, 0.025214531473935615, 0.043365862520952383, 0.08600972547766664, 0.09555256865437954, 0.0854495007003988, 0.0405448088572631, 0.07320501781519383, 0.05013438722779674, 0.05276021487530201, 0.025137014867317294, 0.04463495611543617, 0.01324608443199747, 0.03846208392191799, 0.0404387133406295, 0.05085537555597482, 0.01697825508252267, 0.011076997447338317, 0.08453972532504028, 0.03528300289725585, 0.055345895685135364, 0.0624159142945803, 0.03844233417523004, 0.019698822908403895, 0.031715779595317385, 0.09826840397210852, 0.044419091690572045, 0.04045403892955473, 0.011775949256374471, 0.00644693200874533, 0.05649550637650875, 0.05181552887323403, 0.06907074006214257, 0.024764868505899946, 0.017679995451603207, 0.015423653925198223, 0.04948800054168509, 0.008577405767995984, 0.05994012879748499, 0.1264570611378839, 0.062125329484021476, 0.06139288431093578, 0.018806286426561496, 0.02956343450463347, 0.035368954131920496, 0.05377425098671548, 0.0360251046086271, 0.060182737351785746, 0.007068907303149782, 0.04341667330253028, 0.030905902085285035, 0.033975842393814557, 0.10806604033155788, 0.04979448550711236, 0.013361145092564966, 0.0904099966189073, 0.06316550451541139, 0.046798369261406125, 0.0577602792350996, 0.048076586963068095, 0.0816202714979168, 0.03750920460949983, 0.029393715385888374, 0.037001376415813164, 0.026743357603047645, 0.021215274802318985, 0.01185359801315973, 0.02522448870173145, 0.06575446801200029, 0.037335375429040966, 0.02628063666634262, 0.027373922658303095, 0.11961031119309126, 0.02452394151459298, 0.056662149652237856, 0.024036203976720575, 0.10839758020254875, 0.08471726620149228, 0.04454011059997063, 0.03704899644118644, 0.04883544301734336, 0.03590872436161003, 0.030536651536221468, 0.06676260907683643, 0.035475635705816175, 0.02141702788761787, 0.054973496514703, 0.03376841642743638, 0.02811550917554527, 0.0333896242532759, 0.06456890098390079, 0.03917956739784249, 0.13885221053515712, 0.0556938796334209, 0.1234825868760386, 0.24368389659831602, 0.18458549924675496, 0.13360391070525493, 0.20063775321168287, 0.2576768296139856, 0.1856714595229395, 0.1774282615271307, 0.1955341061036433, 0.11831194537902072, 0.21646603371106812, 0.257172805046843, 0.13368281776145582, 0.10869600209257296, 0.2256862236367118, 0.09506594194399734, 0.15409903030001348, 0.13402173505915752, 0.1487918642740096, 0.0840862472391417, 0.1125307318063513, 0.22510220416851584, 0.10489138729509809, 0.2072870439939922, 0.22459721433058863, 0.09731560509892241, 0.14403444294246937, 0.11456600525566649, 0.07546089394318481, 0.2137964930866034, 0.19648727269903307, 0.2927462203848747, 0.13914102568261086, 0.06843976706506745, 0.10353217877808119, 0.16806423093282408, 0.07844027116774552, 0.12896143320587375, 0.10164011014445175, 0.13644491712893211, 0.16540955241409042, 0.11694883747446923, 0.1989004343387581, 0.10008656044280338, 0.15892012885981993, 0.11080039199441673, 0.21328848486225452, 0.06040113752767925, 0.20457578222117118, 0.23293571366417795, 0.13981734342392416, 0.08912727432025057, 0.1034964407764135, 0.11447091076162555, 0.16200156431765328, 0.1411852240562439, 0.13172468170523643, 0.07799366489052773, 0.057300875459106705, 0.13103923219586575, 0.11236685027758922, 0.08627530517837695, 0.137776990811671, 0.16455686591084928, 0.14440602622926235, 0.1969234831631184, 0.24866506156902163, 0.15789870383037677, 0.16067336703981125, 0.17692685698068913, 0.07181903452522333, 0.1792693546702785, 0.1389601982889637, 0.1411051678681566, 0.1779367600477511, 0.22457983945646595, 0.1293027253761407, 0.13558245534377714, 0.15486409166647544, 0.07694419338217667, 0.11934174374947626, 0.20378493433517797, 0.1959360571157548, 0.1535586778435015, 0.18704553014568745, 0.16637865363830523, 0.11562971067765068, 0.12987359877555602, 0.15813153327232407, 0.23210573400701248, 0.1409952036075054, 0.11879784430587485, 0.14149254788794827, 0.135696541157461, 0.14379307928104557, 0.3183859574698633, 0.15144573073954354, 0.2469368284988788, 0.15086299829906033, 0.10241799582276614, 0.12277859803890029, 0.1288295588305881, 0.12222599583647906, 0.12824805213078377, 0.23141217928740287, 0.11027372186823238, 0.25938005757427984, 0.19581780378376284, 0.14321167983355063, 0.17333776569895207, 0.11018552216550997, 0.11927838061725902, 0.12237126142868113, 0.18463385471653554, 0.26502578849754027, 0.162343101636056, 0.1026512619348303, 0.05404796654118165, 0.10084753089974965, 0.1436915573093199, 0.1321183589677657, 0.23819654669252135, 0.2152067996681698, 0.16153521595462678, 0.19567141970319135, 0.106153701011452, 0.11475663091386519, 0.21862168255592548, 0.08436656647151516, 0.15445051143967337, 0.09926660887656674, 0.1130852951938587, 0.13643062192826502, 0.22546549838396812, 0.18083367556814225, 0.11092557076124415, 0.09046140877950577, 0.1389159184069403, 0.11720330890027747, 0.11580635523123127, 0.1633994143095709, 0.11902492808839006, 0.19272685351390995, 0.09226251979388538, 0.1690923209272085, 0.12434215284883977, 0.11682552796217704, 0.09365952708908627, 0.13476451858878136, 0.08550547874502598, 0.14116248656665126, 0.1711675305400164, 0.09957209409725282, 0.17818192350527934, 0.2177384904315395, 0.15729787639312207, 0.21146076761426466, 0.10485811609654658, 0.2418870220501577, 0.11043788684952645, 0.07142469842707919, 0.13006254670120057, 0.13663259334862232, 0.1365749222496825, 0.08328785338709432, 0.16737924107620794, 0.16278884223391935, 0.13776618897193862, 0.08413581312784264, 0.2138445267994558, 0.18993778785149898, 0.13924221057564984, 0.23659911547457022, 0.09343802808753907, 0.1885213985318138, 0.1461865064958411], [0.0655299123196352, 0.012817650717953521, 0.0125867364958169, 0.028902687500381184, 0.010191196793570154, 0.06347622211662031, 0.05156167031776521, 0.0403275539828164, 0.02764033931007068, 0.0083715541123022, 0.039259995138573076, 0.016234199846944502, 0.016540830369077383, 0.052304212529692924, 0.016977646042622866, 0.04913999361076182, 0.027652355399163022, 0.029382679889339115, 0.025723797997700113, 0.07118647572614493, 0.11421797151166586, 0.05888155616459347, 0.030979322036728266, 0.027963722259887767, 0.03489219846444265, 0.08374037386308755, 0.054058565367614074, 0.009738202300673772, 0.04240526487269709, 0.05145150687425368, 0.07290307958159717, 0.031706960008089105, 0.024487807062424483, 0.03349693401926949, 0.07139499719825483, 0.06755135022103786, 0.04157516264146374, 0.044014800279851884, 0.019920312333852053, 0.06405514710011982, 0.06542917175759232, 0.06771433542692853, 0.03917025942956248, 0.02425891339718815, 0.07105914425225028, 0.06633772905315123, 0.031184057119272413, 0.04127924968939155, 0.02372893568639073, 0.00869251813949837, 0.06623546397613903, 0.015741659895396762, 0.04247487162149722, 0.08819471549002394, 0.06772997894234235, 0.03335990387225344, 0.05016206981494062, 0.0465391404295881, 0.026352380800451485, 0.022926655853347435, 0.03500797350199954, 0.06004125240349001, 0.053397178679945013, 0.007953165726165378, 0.014126641213923935, 0.015609677310191817, 0.024819023261267333, 0.011686712462124566, 0.01574475010256133, 0.024411336165822806, 0.0854131498283917, 0.04352899711398829, 0.055877009121280526, 0.07109501248886509, 0.02668554477784182, 0.026695825677785664, 0.054193255116021445, 0.019152688403283397, 0.017105008160034497, 0.035339505712111155, 0.047576879301378806, 0.021655815578396284, 0.03342539672890017, 0.009902458254908843, 0.014847337471080885, 0.04542461273470714, 0.021262527105488607, 0.05809660332517759, 0.06070151677235, 0.003764802165659926, 0.02453394087722465, 0.039813631559692086, 0.018400315368067355, 0.032215069739087936, 0.06498520082283406, 0.028174114901752725, 0.15052621072578817, 0.01601256294957092, 0.062196506713066375, 0.03347187145282665, 0.03930832762571593, 0.060585714921715765, 0.04678595863703278, 0.04795433848255104, 0.05314744933838806, 0.028852037597267382, 0.015056515863585859, 0.11583173572416268, 0.09033672030894987, 0.01983860714150773, 0.02888609786638089, 0.0541076792644397, 0.10560993946367696, 0.02352895034897712, 0.022033891460347562, 0.006457812372489923, 0.0839476159683639, 0.03839978182147588, 0.06572829844850687, 0.02812297661758719, 0.008264395648673659, 0.06027267224365666, 0.024900092600634503, 0.03076718846005538, 0.02601694920280528, 0.05837636714380595, 0.07292838346573614, 0.015689826386439946, 0.10766939830876167, 0.01053019357289398, 0.04757692526665427, 0.04803891458939161, 0.030453998310070847, 0.017389977546108347, 0.014023018246065947, 0.030724731867291757, 0.06583692971616983, 0.0711309879777893, 0.010009655022933599, 0.019607509058269284, 0.03695419306055673, 0.0499964990623055, 0.08812482528869184, 0.036455477482729384, 0.0332034572267965, 0.06174691269294389, 0.06529842353155536, 0.030305256593912363, 0.07697205599998275, 0.06799072462825045, 0.09002760383150271, 0.011992528058227994, 0.10032475250022066, 0.005268604511530289, 0.047012283992502964, 0.049500836344856414, 0.05964864383361513, 0.04863562813449291, 0.035049434180461594, 0.022256625778672677, 0.08576499869025524, 0.0163701651317458, 0.04651956305268311, 0.019469109529088584, 0.03837624377000236, 0.03751561293498643, 0.032847437016185255, 0.04315148430666135, 0.024084743307602983, 0.03820240692866426, 0.05116309392296019, 0.06354717718016717, 0.021468989716302005, 0.012038840946080464, 0.023476193704071547, 0.05806376879674293, 0.004590273395391001, 0.01848434180682225, 0.008266515797004104, 0.0254936192199708, 0.016624169243920236, 0.03825285381847813, 0.03962293695358019, 0.06097097287795717, 0.024465044674974297, 0.030529480953250202, 0.04614614881575108, 0.04385024842415606, 0.009517984581179917, 0.018776238542951403, 0.027607416681524728, 0.013515876658681421, 0.0676238757648295, 0.08002998788029918, 0.011394812853165693, 0.0208985491565639, 0.04685234398611131, 0.07455998220511022, 0.06642349259627443, 0.05697970075773136, 0.06644163355832139, 0.07445248474757518, 0.056395436141399614, 0.07244688188356739, 0.0896434183983553, 0.041298715983547514, 0.07563832756732741, 0.06561307882469508, 0.05090434006565521, 0.07719195387776821, 0.04329326419880794, 0.05327434031172626, 0.01914291120614977, 0.01371712412595028, 0.02254665326026659, 0.05099055177021412, 0.020616107860640175, 0.02613024977636674, 0.02249420879619016, 0.029068482333734155, 0.008715817746105454, 0.05178712999388095, 0.04847312173355491, 0.051363418254280285, 0.03501092294050801, 0.02897478786537484, 0.018940116241273862, 0.012611483050990972, 0.021993560761573817, 0.014433570510347285, 0.03533915714210561, 0.04194049848123424, 0.05938557307085684, 0.010562739860747131, 0.013619796485610068, 0.04549810354928336, 0.07643010241970902, 0.03773366071043476, 0.07020982853587597, 0.00489811864568882, 0.02950664249158675, 0.0323639857402492, 0.029059176280673955, 0.026387722351618355, 0.019486978529922424, 0.030342356316865455, 0.03947420864396038, 0.04336034668789756, 0.010401192984934296, 0.012014178660578065, 0.08466516456176197, 0.044468592461799426, 0.05510404938831926, 0.028361358281765735, 0.007066091451223099, 0.02989918211354844, 0.04478682155510591, 0.06616247111871358, 0.03819282316873151, 0.028209462198579026, 0.02078087805139442, 0.09859539328082915, 0.09026597208914258, 0.034001050516963005, 0.05939335652416753, 0.07996797306282867, 0.03921388047597101, 0.02610367801671307, 0.029184607856516397, 0.08791302496026601, 0.029131150241160107, 0.06853467003712732, 0.0416643544280481, 0.059780533530659256, 0.04085403641745929, 0.1367913880535672, 0.014586694249432656, 0.06070904741664568, 0.0553232079912578, 0.02489055480597721, 0.049260893776532144, 0.06082767613172051, 0.015993269025197914, 0.0855990487240976, 0.12456504613040917, 0.043928316614079865, 0.09610651151066828, 0.055439182211674994, 0.014413915567039965, 0.013808376689050949, 0.03230618440636224, 0.01892189483999485, 0.03983950617933466, 0.08878955211971076, 0.023670341451502135, 0.07904830749236769, 0.03779333512929659, 0.05026129352289343, 0.07394530389818453, 0.001672395075964291, 0.017236045584262862, 0.04205043975924773, 0.06552326267645245, 0.01960286273500852, 0.05202491985513799, 0.030546411496376803, 0.060233383424459934, 0.06472758077565702, 0.009947983029809211, 0.06583935821488981, 0.02208078178697296, 0.047936078776875814, 0.03691770046228363, 0.06748215715971685, 0.03645712074132697, 0.024412127151604623, 0.013712380126479172, 0.024682575341073737, 0.0630482049628852, 0.007021874771453441, 0.07022285969146798, 0.07251645798885054, 0.15094550596850534, 0.0039918691900018, 0.1425642436069827, 0.03222323240592115, 0.05459295382963554, 0.019831850246015578, 0.07648184399811492, 0.0285090217291708, 0.02866493402830055, 0.048315610225883224, 0.015179847400905866, 0.018701916522977334, 0.02059503852750265, 0.02267472975466761, 0.03312613980303849, 0.02528512456093825, 0.0049302962537284105, 0.06280902465204559, 0.1098036349961354, 0.02351698214038005, 0.03571870008243188, 0.05470077687453839, 0.07265276801321777, 0.027175955962569966, 0.034667060545255104, 0.060800353605901046, 0.039882460729249065, 0.03430921321494445, 0.02329537971696306, 0.007759091235892548, 0.17584904788001893, 0.12667951008845724, 0.17365498738663812, 0.10697767453929109, 0.09216010916016756, 0.10295340701216653, 0.15309827432276743, 0.16663454232677338, 0.0960323848431149, 0.11388234073115934, 0.09711839874545414, 0.10618879549926329, 0.0991728550363933, 0.11796668487330599, 0.06916489226803665, 0.13024057021304486, 0.13342173499686102, 0.21762920032826163, 0.1428472518079704, 0.12262565624569693, 0.16596113571957236, 0.25260030201846556, 0.15519038383518496, 0.1271161802052971, 0.19102316590086107, 0.22351563607733096, 0.12290861848140917, 0.1730023570839436, 0.18529132669491155, 0.1816206470492386, 0.16295957258872448, 0.10315099640959695, 0.15550546047668304, 0.24201848273796422, 0.17340328153823653, 0.174359435876531, 0.13551099466220026, 0.2240093031357373, 0.20348692613263286, 0.21967240278759312, 0.12425857265630078, 0.13356896177414926, 0.09923368241758117, 0.10224698201542902, 0.1665777598898257, 0.15103040383227412, 0.09095843130302045, 0.15588982211005303, 0.2092421769855484, 0.09037697056849157, 0.1862391613183483, 0.1388888601814547, 0.10465723252104175, 0.18026120870584444, 0.12268611590468115, 0.09451821206077453, 0.17914357835487013, 0.3102049351699891, 0.11121307589834738, 0.12924994191815778, 0.17992089712812057, 0.10977102263319878, 0.17499956362430127, 0.20095014854544596, 0.14055415146773861, 0.12559728066046394, 0.1707643384654676, 0.07752167045949929, 0.16247091574534295, 0.14260518334565625, 0.22626520224636604, 0.1776759071095336, 0.17800324115782015, 0.10864341781745035, 0.14529998954986373, 0.198702477219124, 0.1393139930141549, 0.17203291878104213, 0.1294023627715726, 0.17426157580508342, 0.20831544042354633, 0.2103940055014626, 0.07356238251011218, 0.11774861028478031, 0.13405679124257258, 0.21054832625292966, 0.2127507371046851, 0.19009305855199216, 0.1806666837224076, 0.13621081598103046, 0.11815443770178866, 0.06401879622811271, 0.11325386518071737, 0.10391824878752233, 0.2746198752955083, 0.1768142420558199, 0.24780790111230266, 0.11090056565139564, 0.24710840155040067, 0.10743466896876212, 0.16755196325961622, 0.22014252030320708, 0.1018643364190094, 0.14007320146887534, 0.12872627485663662, 0.1482226456245107, 0.07555527597545617, 0.16190845399133622, 0.1914526501129712, 0.13102384915034618, 0.19204459093030424, 0.17481914991813322, 0.1268747859003563, 0.14081667447763105, 0.08552075453823613, 0.11817761952237738, 0.12772740345568429, 0.13250439067281064, 0.1608696234442534, 0.1392027570475494, 0.17206426709890368, 0.1170738093975571, 0.08678109940862463, 0.11659257594616183, 0.11798002246406772, 0.10037158345503193, 0.19543832979134976, 0.10204440538561153, 0.2283421738613998, 0.12021763505594385, 0.14868234434435446, 0.13445301191701045, 0.14670145547678395, 0.13657637781673862, 0.12176130988424826, 0.09757526293997804, 0.1648799711537938, 0.16113746310434035, 0.11842693517645521, 0.05766381727411382, 0.13882610225869765, 0.10657848910458627, 0.10504667331734974, 0.15603976083859322, 0.15662255456611035, 0.21021028229546165, 0.23329344608129995, 0.10043787304311992, 0.26725213193605024, 0.1926594837418487, 0.13951869170752265, 0.09656594209973851, 0.20338980150559258, 0.0947698949265384, 0.09865750002885058, 0.10464290667685772, 0.22250853689207187, 0.13523580055804024, 0.12373047760657727, 0.10300828955106198, 0.13361497301488154, 0.07702963516837166, 0.15159700246107194, 0.1579386936200242, 0.17691096831713954, 0.08997271363172801, 0.14385240512990183, 0.13559520304683717, 0.13521160750139144, 0.15759380083651314, 0.14558295178557598, 0.13804809400631537, 0.21097699841184003, 0.09296325275734549, 0.13666046362730766, 0.12954784286839346], [0.02602369269175876, 0.06799277008300827, 0.040450024628831495, 0.05209959044511761, 0.08438688312326709, 0.049944665553348686, 0.03463447882583545, 0.05320925348167939, 0.0590149320722107, 0.046083888850144805, 0.030260626226663593, 0.031122252975981084, 0.036180080365269415, 0.046646113116895004, 0.08437611958793095, 0.021027437704164657, 0.018549390332472902, 0.045926021111588326, 0.042276699997244344, 0.032292494415155346, 0.04625532783627991, 0.021297807369621533, 0.0470162101931149, 0.04103460717165182, 0.02354874606094053, 0.015869090003111673, 0.08284829511877992, 0.01321461162484822, 0.03373846238959701, 0.02586602030562297, 0.037277574095154004, 0.12138984151064389, 0.08493369370098076, 0.08207216378181212, 0.038665284913393765, 0.041431819929951624, 0.0333779912081457, 0.04721701332938768, 0.05405505285448125, 0.07580102165980686, 0.12620766887501364, 0.027212958009312713, 0.06324524660744975, 0.011697112105696673, 0.03450166599284257, 0.005047626928576539, 0.054661258228964386, 0.014176346913671062, 0.03785792017175305, 0.0356385059985182, 0.06723530064787596, 0.07223939463015526, 0.026306735366703044, 0.026840288792887045, 0.022569748895963835, 0.03293375980349318, 0.010969894525084284, 0.01813843778725113, 0.014733464246796025, 0.040421752153985926, 0.05088480482358606, 0.03434716521071331, 0.07175004830764187, 0.02824525765684103, 0.039401759708961176, 0.006632344917424264, 0.012456166385222348, 0.01641403324150991, 0.020724631875993747, 0.02598076303970189, 0.02318451530300081, 0.03550425292022767, 0.014405520200999755, 0.028872279555446682, 0.03656492846447133, 0.025966946643987493, 0.03022579412396637, 0.019518148732341586, 0.027198046107866594, 0.050598785897055944, 0.01641315224039699, 0.0384526189056135, 0.07615342976585512, 0.03708054394190831, 0.05029339260692078, 0.03593383289332833, 0.0196457406761305, 0.08132008760566674, 0.025908942296800595, 0.024522447643140634, 0.03883978059034675, 0.03740442293365637, 0.053308913859749035, 0.061164199404658816, 0.05485694772834259, 0.009727928103999266, 0.026689513113289594, 0.02132350004338209, 0.027426675472769047, 0.02005640210794105, 0.0397223943183499, 0.04123629130903752, 0.07065096494531439, 0.009232933798264112, 0.08660447017680253, 0.04895375763636924, 0.08521600476195736, 0.09309659802144574, 0.01724844280209753, 0.044890676264560996, 0.024486265310476867, 0.037032728564114346, 0.015341999486178882, 0.04120936331849906, 0.027743699892814604, 0.035645806816436594, 0.08064319529841024, 0.041832495405669176, 0.052816664064002615, 0.04542249833203612, 0.00432306527903664, 0.02778268802250105, 0.062036436471727595, 0.08247018476287205, 0.015811302075763384, 0.1244979368282422, 0.04463927302088949, 0.008552550045292704, 0.07361541877711013, 0.06723060452890012, 0.0620105235476888, 0.04450408148489172, 0.02831015871056626, 0.05911871017287335, 0.029298684094101194, 0.03571187423902654, 0.06719505804921351, 0.04896463608489402, 0.027637820796019612, 0.005678482139633308, 0.026975658444327213, 0.01631706183205449, 0.025134865990689686, 0.0544583406900206, 0.03716869384891564, 0.036551736430415226, 0.02394185641840581, 0.08008965080784214, 0.01767620906203745, 0.04993009839146849, 0.021690050132512566, 0.01882566462060617, 0.017180881508055235, 0.04737316120055415, 0.011386361945750973, 0.028794207535083258, 0.041909763033712105, 0.02860946926258264, 0.050538146207409526, 0.03340170929028142, 0.009031432564370334, 0.03551253433068914, 0.0815182745516781, 0.08269061124132526, 0.02860306668275547, 0.009434391939712149, 0.03906899409729146, 0.03910968868782924, 0.08004055989365425, 0.0262500295385478, 0.06226963746631819, 0.039019535460899916, 0.025129486138241428, 0.06725144212044055, 0.0859094598901368, 0.03818790105381801, 0.05718261446623553, 0.030480192771421808, 0.01918793036302011, 0.11238458521303632, 0.03940148391730843, 0.018358387375971483, 0.03231374952461451, 0.02947484984272911, 0.09719127668969094, 0.0948103060645442, 0.021599121241559906, 0.0487139989291468, 0.00591049186750165, 0.04227570408294278, 0.03192559384079951, 0.030946958652367035, 0.017347982521319104, 0.07788301115074465, 0.014491077857993305, 0.0017014638034461608, 0.0641938626405693, 0.034019651131764535, 0.03499637110038631, 0.03605312044401804, 0.05456854626836796, 0.02493004472325406, 0.02092107980241699, 0.020776308336926085, 0.02930460403853607, 0.0110476610678879, 0.03135752240796724, 0.08023935204912579, 0.020317697461934823, 0.026292708296809467, 0.014539250424281966, 0.03291674116025529, 0.022958674498142737, 0.06143651684866317, 0.05951534836522995, 0.0265235171818565, 0.023655559785003145, 0.032010074186649536, 0.061853142274964246, 0.06614284394609352, 0.02006585946336629, 0.0068988391355941855, 0.027705485511931683, 0.03655375890253532, 0.0523605314834464, 0.09250005301568778, 0.042885015943958875, 0.08384351228033343, 0.08127473520054933, 0.05452631184110238, 0.0716080922152727, 0.09839414964399992, 0.035873668178194956, 0.01901756964563843, 0.012604077853592894, 0.04896018128361433, 0.04074535152364162, 0.0373879635346032, 0.03887172262634962, 0.030635442404497056, 0.06066103668643102, 0.0486643526012138, 0.05157406945081969, 0.04551636708539821, 0.03030517040902088, 0.024923278251662854, 0.024346877527873845, 0.01845138087388008, 0.04514300264418126, 0.02003801791297813, 0.022982988213639588, 0.030066237161536852, 0.035011915024369955, 0.04427565704850901, 0.05160149922894855, 0.036259577309172, 0.017767480777336225, 0.0498470736126746, 0.04979930420015609, 0.0218443306643636, 0.07926569260176151, 0.03406013121768352, 0.032982961800430095, 0.016962990780631383, 0.016382909004366206, 0.05093385360293812, 0.04765966276247655, 0.04565740770269786, 0.05259162573624523, 0.05208001689865224, 0.017644584952523152, 0.051695057716701305, 0.031235118794645515, 0.04870482119581392, 0.025328739861687346, 0.026321813892272693, 0.024390362593675816, 0.07062209875232751, 0.05336103465167746, 0.03945260496449567, 0.058785661108671665, 0.03975955341311713, 0.04124445780631035, 0.09500257115090087, 0.03229422960430384, 0.03436935877787971, 0.030089945667573524, 0.014292575858323085, 0.06436253221885813, 0.024311378928682497, 0.040578072394935355, 0.03371045804552494, 0.09598332457244398, 0.050522146461110924, 0.0186812034207246, 0.0771605595946312, 0.06807983597560276, 0.07058151907497837, 0.02965214174060572, 0.030249267057966323, 0.02724990642990076, 0.047998250642370795, 0.020363693380908623, 0.05182672907868701, 0.08590336183025953, 0.06743568626623, 0.03807108796712372, 0.039345823799169836, 0.018767627714682492, 0.017477729087395054, 0.026040699843677784, 0.026948646184117086, 0.03262106952587924, 0.0835994060241407, 0.063577966253844, 0.06379720912645422, 0.023616525690041246, 0.012636918127686988, 0.05580694271972584, 0.024146631720565984, 0.011810828281957056, 0.020682836034064813, 0.03779618880681453, 0.08511749351577413, 0.07276231858638987, 0.08397866551193499, 0.00943865904945039, 0.05047009461709569, 0.0398405327371532, 0.012050715308906812, 0.032336245696511, 0.007863471673185667, 0.005277061643409393, 0.04926381640196328, 0.0473531088491361, 0.024733064365723444, 0.04926447523757816, 0.0777023829399578, 0.05636660825280894, 0.01965668998778828, 0.023284288679039287, 0.025200579097614657, 0.01896386688214637, 0.0928578390589645, 0.05707850311732581, 0.040173650749268076, 0.050649700100503625, 0.06415335574157296, 0.003806138594236766, 0.038975987192844196, 0.014340912175905562, 0.026146054170244647, 0.10299332019302154, 0.2279450492032113, 0.10581370352977708, 0.1619267941362435, 0.10423059049513071, 0.11773717259207081, 0.11867295665245865, 0.1444039577918668, 0.2616751957083902, 0.159537059465243, 0.1485429316638939, 0.12513388173594592, 0.08051309824710892, 0.13721944734213815, 0.1499634578583702, 0.14591269134994478, 0.10558316469072335, 0.2056855218665254, 0.09735514289669453, 0.11299900305006774, 0.18756329833019167, 0.09661767601726517, 0.1649694195798328, 0.147006971340987, 0.16230459805698166, 0.19836011252576308, 0.1619844039481494, 0.10027901705114112, 0.09547753034219628, 0.12775417056775865, 0.12618634098720166, 0.17852972742290268, 0.16158913322273763, 0.13658095902252582, 0.1096335941204621, 0.10970154611934578, 0.12627940534824325, 0.20780199297493507, 0.15651939316622673, 0.1610972588100741, 0.2316013723611832, 0.15068272248871867, 0.092667504514177, 0.15685475581595976, 0.1126825014850305, 0.16908896546210014, 0.14068329857001383, 0.0726172291944104, 0.12331644538789989, 0.1429033447657862, 0.18340696490580038, 0.12501798029388153, 0.28742267539904964, 0.1677231685889344, 0.21056970010601708, 0.10438095057202924, 0.14456664422346702, 0.12074990528485469, 0.13513035621614228, 0.1591491738274213, 0.18422983526702852, 0.19497820206226843, 0.2065174780305355, 0.19735718085881204, 0.10691438035498704, 0.21265506804470094, 0.1040258075320913, 0.12234640187553822, 0.14224081660710997, 0.11273851783405389, 0.10542436232489925, 0.14980863148887313, 0.23904132716838392, 0.1462123696241648, 0.1255724364290795, 0.18965323215290425, 0.0967068103472552, 0.12638846562514383, 0.08468938060104848, 0.14851038824887047, 0.17360889953711342, 0.1397310666018917, 0.12498934392727191, 0.0685162686051861, 0.1665325300587762, 0.13511224589761228, 0.15782235550784296, 0.1568407517287039, 0.11567789760808792, 0.11278798413132468, 0.18285792501222703, 0.08003810841229655, 0.15559587417350662, 0.189688625415006, 0.14873039337896532, 0.1355903613711557, 0.15869667633406578, 0.11201267250843587, 0.10247759746327516, 0.11511940418952897, 0.0916230738643677, 0.19211078092696207, 0.2031895001569102, 0.20953217190840553, 0.1231157303517384, 0.20006674191644117, 0.18346108135677155, 0.2530018240213394, 0.16785047708019135, 0.11518164117249752, 0.11537774435935483, 0.16162716182729892, 0.11777884777515166, 0.09532036740453013, 0.19911267133730076, 0.13781282840476883, 0.17902264371514323, 0.15643083340217992, 0.11199308364021202, 0.19366134288570575, 0.1527588667287942, 0.21895474694188566, 0.0969911055759557, 0.1541323398029612, 0.12658241610493393, 0.2689875049456474, 0.10273013068663497, 0.17386985972764032, 0.1988870278000832, 0.11973890671206099, 0.11636524701551085, 0.13900850779346882, 0.13662628078412625, 0.11525918459219318, 0.1345039261204581, 0.15294447451108886, 0.07831971957198075, 0.15084343241347423, 0.17591321540455665, 0.19439482610792885, 0.1446745094032057, 0.061235437920737656, 0.1612443017262605, 0.1293821380503716, 0.16088552742956147, 0.2117953641760734, 0.13192145904946712, 0.1540632539939496, 0.15670910717979555, 0.17570151466756098, 0.14424635818408382, 0.09977324580353114, 0.17372405787389125, 0.22661463027038883, 0.11134005497179686, 0.08657845383089396, 0.12407909357740034, 0.08736175575083302, 0.11436016509129156, 0.14904470393253913, 0.13735406431219271, 0.08999054815860526, 0.18941346195436295, 0.11010299917430648, 0.11717567610884867, 0.09545322237235886, 0.11855313284022194, 0.2518501027577347, 0.21931730571293065, 0.17464423672326151, 0.13633381905815295, 0.08841386260164362, 0.11251420728982457, 0.09175997377643663, 0.12893612166085552, 0.08730691151633378], [0.06438870944323079, 0.06544523662136448, 0.04160778649571923, 0.021232603711166212, 0.04015562853084938, 0.01425863816327746, 0.03251658662432625, 0.034324324299250884, 0.08713755245891311, 0.051051704738769806, 0.023982485891470028, 0.014266123799907585, 0.05930401535043794, 0.03817084793662352, 0.019984700108668017, 0.02651997019476708, 0.026923321232560183, 0.01842371360849469, 0.14472176170637532, 0.02383560193852792, 0.014121243166887473, 0.01554851572314698, 0.032912439576560454, 0.03445643999223267, 0.02579854136603254, 0.04129563247965228, 0.09742558468133213, 0.04292296793972773, 0.06627863303067223, 0.04252605778615802, 0.007307430214789366, 0.0280375539835903, 0.10149586344918898, 0.016236883069899295, 0.00883667003138051, 0.05700572859495879, 0.052434807538145015, 0.060737668461496794, 0.04785154480487109, 0.02580671743940442, 0.05480020359579114, 0.03293930628006497, 0.06930305622518063, 0.016195656048254143, 0.039375103679635835, 0.03950101406043095, 0.019166223261685624, 0.04347799864086894, 0.010602428960884291, 0.03988909888111296, 0.004658191877927992, 0.07802102189030378, 0.020919758300747604, 0.04258521892611058, 0.04651665957945009, 0.0996600716344772, 0.05615603749550158, 0.03170492412943033, 0.04289286451474313, 0.04343484107765459, 0.01131197480830334, 0.007988642779133854, 0.06547053284462422, 0.02622609503657347, 0.056985936713435, 0.035955501690266595, 0.06560054562625385, 0.012059905491168461, 0.0336354082420228, 0.06885536210311037, 0.056998757194847836, 0.036202220306281126, 0.04792673633463922, 0.05369220297002504, 0.08629585165650615, 0.014925883508347457, 0.05864985670233446, 0.04217389482824553, 0.030138724400932272, 0.026488428439704642, 0.03439485418399976, 0.05412259882676506, 0.012843825069496469, 0.06634902885003437, 0.05831088194803846, 0.05978778455286257, 0.07631218616640376, 0.01994750270950458, 0.037359821294704755, 0.038808340341934276, 0.04982009199598143, 0.04504656749627283, 0.057164013851434, 0.05186127581363244, 0.028706729870229482, 0.05219838897427244, 0.01916102535511938, 0.01126167826324461, 0.03166258244985535, 0.02398511548827012, 0.08861987130536188, 0.0711105870563657, 0.04442968285612522, 0.06713631442717968, 0.030385515795299606, 0.03338428845088328, 0.048654738197764086, 0.005163181715855195, 0.030863863010440144, 0.11699605147324263, 0.08300104539000219, 0.04462819155906478, 0.08761723075182208, 0.007096588453878799, 0.046020326535067255, 0.0110418799768893, 0.09633508916463583, 0.061043460117352594, 0.027947542482926965, 0.05842740775176114, 0.04799613623969978, 0.009241765834421161, 0.061662960947761615, 0.03633693303732622, 0.01887210295535624, 0.05723995997780754, 0.07655131285108867, 0.026765920807637518, 0.026362248012916218, 0.0792206772753308, 0.08757930173869095, 0.02265347847564807, 0.04623573513761644, 0.04797598812729121, 0.024967452796596675, 0.01769699877308261, 0.020088328822185437, 0.04893652831895217, 0.036128154925761685, 0.01504053048143584, 0.04599883010791195, 0.022012737857538368, 0.02373366436410335, 0.03917297138081443, 0.025407692883163694, 0.02409385017780287, 0.04698294282500302, 0.04162404671191208, 0.022166644921526316, 0.08576365803638775, 0.04054927898030128, 0.038614784397425196, 0.04825645291637029, 0.029297203629187522, 0.05248020590853788, 0.030701542385823788, 0.023459542783037312, 0.03254723397173709, 0.042292676760905215, 0.06728781597508539, 0.013228323641082933, 0.01471583464843852, 0.01628139660873961, 0.09651050797753757, 0.02993541807236691, 0.02056632555210062, 0.05169817569455312, 0.040294026144810265, 0.04032450495287776, 0.03423686770181503, 0.041747049789034554, 0.06887621501640928, 0.065917675383389, 0.021135837230230534, 0.08065129284776988, 0.044037690987029386, 0.03940198953533846, 0.04579866665505594, 0.012233938642537162, 0.00086625368097767, 0.01691302078055038, 0.004666946347682707, 0.03846381145018724, 0.044822329730396314, 0.04039727947524479, 0.06783444269169724, 0.04918653345216186, 0.01918503263544652, 0.07494851901766754, 0.04280345056266074, 0.05498834712911518, 0.035664886236190796, 0.025468388114184625, 0.026402427409324917, 0.1727679035355968, 0.05625312381814565, 0.045440673768039674, 0.042739938043298266, 0.009974608415617578, 0.006675138588874571, 0.06664091601006447, 0.07323992078102405, 0.05347593634900066, 0.039591270709230054, 0.023362173007861264, 0.013382401159634034, 0.017911863453205557, 0.1389840389451673, 0.07096256354763623, 0.033505207768851714, 0.036148808656200286, 0.021727172838103388, 0.0483692976676168, 0.02237564136814927, 0.018136829002610138, 0.12389039079989157, 0.06574169732630253, 0.003857406395141997, 0.07269426699607603, 0.08086388990763696, 0.006983327621128411, 0.029377160225844676, 0.005429316351505658, 0.006482979797217394, 0.07112900381006541, 0.028095594719953598, 0.020591746264648055, 0.1274134146590387, 0.07451438465185704, 0.029435032422864632, 0.059163641229632406, 0.02172791402817013, 0.039873692852955674, 0.08545121673734919, 0.03613457091212754, 0.09667120258053465, 0.0367776136244497, 0.0345158999064757, 0.016442585338447845, 0.04657146167911349, 0.021769604533009475, 0.024396399366519144, 0.0280177601868467, 0.038599964426529985, 0.00760271784759337, 0.0257145072663984, 0.03243589075282216, 0.05355582782818426, 0.047786500109660054, 0.05888182812580659, 0.09043999662202212, 0.031686403953860846, 0.00279217143073648, 0.03904249894643023, 0.02392713029328133, 0.03570198021348446, 0.05527994317573406, 0.028270504084385695, 0.012826666615212397, 0.03182225624069331, 0.03633037532469438, 0.05603291567475085, 0.050753485862045526, 0.032935468179564324, 0.038212040484312086, 0.06296281297240527, 0.05521835736750115, 0.008675104003369568, 0.021877199666754856, 0.043796863587152575, 0.03748622963265066, 0.023147825437087207, 0.027965434466398535, 0.05496365994575524, 0.09081487408688954, 0.04335470061989562, 0.024900063872337345, 0.030658660614262187, 0.001862575325855775, 0.05491473374047107, 0.03381405994596501, 0.003555225168031851, 0.01399778714027977, 0.01902250899753023, 0.033943601583521214, 0.026823994102737597, 0.07723299320787191, 0.006629346162005658, 0.05710772554119749, 0.03087707802713398, 0.022865539273968147, 0.00557653067986511, 0.07815278135240078, 0.022257242479451725, 0.026494239216610312, 0.07488684127888373, 0.01636702417125625, 0.00879829285681368, 0.0470353777129804, 0.058296682508361924, 0.02259655814287403, 0.03608223944601994, 0.02653640852640233, 0.01984816600358294, 0.03847132677272443, 0.03729105724262134, 0.15888920955119595, 0.06094575709392948, 0.054742425244541905, 0.016691223004712694, 0.008637246810981344, 0.0315163171129121, 0.05093283087555921, 0.039675605498374476, 0.1049119184514688, 0.02906166798164768, 0.006667555754839053, 0.035760961322774815, 0.05635333577952078, 0.008962513379482253, 0.06604129899173014, 0.030922365314777822, 0.04866542895474742, 0.05623324383651057, 0.0018291116477132986, 0.07265573277348474, 0.008919743648279578, 0.0220536929179704, 0.025950203792402343, 0.010198080093569813, 0.023376782304577293, 0.06840015265850291, 0.004744810566696669, 0.040460799655486504, 0.07269559998906429, 0.027022263403200818, 0.03458519638966649, 0.03496377022876855, 0.057631051693592346, 0.08851807354198349, 0.12481168047675203, 0.07233484152464137, 0.059959595091640956, 0.027628537725597143, 0.014710206775024775, 0.01791892678386742, 0.03243394488949449, 0.08753136761726872, 0.04809760458527073, 0.013421825001827412, 0.05327861891278336, 0.021925436392907175, 0.1667472798257105, 0.12641950750783568, 0.11916020389405951, 0.08827805053442718, 0.1281900209705195, 0.11753959851639888, 0.08019256705958998, 0.1211276479185589, 0.11112596404047743, 0.1505584477056419, 0.10410034788712379, 0.09771819962489028, 0.16944050788879397, 0.13602468725894729, 0.15395387196012084, 0.1097244751309195, 0.0842576670730787, 0.16876164673557206, 0.30358415818022144, 0.1391242790005861, 0.1179354208251161, 0.16422236127959144, 0.10290969403520708, 0.2236484757234012, 0.17873750578972603, 0.12259577881665, 0.26773289807381173, 0.08057784033758987, 0.15532604268481656, 0.09160648039992779, 0.09353272421585937, 0.1963642543001521, 0.17702261797122418, 0.11636709328740837, 0.08151583073119964, 0.09107143693273106, 0.18509286395724744, 0.15127973480811044, 0.17367170342514593, 0.2488070176613908, 0.1637391589822308, 0.14568114893571024, 0.20068145086688383, 0.13093305240956046, 0.1361423277205998, 0.12694756425316298, 0.11373927381129996, 0.14422526012264913, 0.17971252121271628, 0.11654795132457249, 0.08991077542304994, 0.22013804634972928, 0.09576226990189284, 0.1626100373123923, 0.13099194924917915, 0.2790177409206667, 0.17709294484267313, 0.1878300807889431, 0.1607493323183829, 0.2291211014192912, 0.10979679383097157, 0.10797954134402737, 0.1954486260130521, 0.22107878699898723, 0.16421971061537344, 0.10303402244443856, 0.1917567257318766, 0.22180960423523383, 0.09280008369035299, 0.08368222778963466, 0.15326165023349947, 0.09491414162180117, 0.16296738668555216, 0.15603329505651228, 0.22204585042932343, 0.12690060306340456, 0.21121759598533954, 0.1003720814121827, 0.09100773672182715, 0.12413065129470442, 0.16745304598683314, 0.10802962817251684, 0.09425108486245717, 0.12441540617615947, 0.11598804064335362, 0.2186639246440703, 0.20548016433754276, 0.10448063393273663, 0.09518797975033523, 0.152663258955844, 0.12645991864584147, 0.09254539009904669, 0.15785989381613272, 0.09995097820196422, 0.2734169640368031, 0.13605744517858953, 0.11465619678699202, 0.10142201257328834, 0.22174054906973917, 0.13038422702060593, 0.1356948404422691, 0.12826561852688753, 0.21094805561006072, 0.170417346601044, 0.12136536500146314, 0.10048657325246643, 0.08018047053126559, 0.05450658507705216, 0.14183319654435883, 0.15229025074551183, 0.19334202211710716, 0.17094211682917612, 0.12465339905071644, 0.09799906277968999, 0.12667819241722747, 0.09121358454708131, 0.1938994889778476, 0.10561435213012081, 0.15247261031500756, 0.240117113796934, 0.17718161185902936, 0.10011587862766559, 0.18352402314063043, 0.12035238226094555, 0.12117429501226834, 0.18155793509175702, 0.13671669448094984, 0.15802328504862326, 0.14962025046829255, 0.2734118772129859, 0.2244063358633749, 0.19893271728388726, 0.21776944038368043, 0.18040203098808566, 0.0673264957543823, 0.10581605541970461, 0.16692639118240726, 0.14684883547165703, 0.19629631762302693, 0.10814323901168763, 0.1186401068022655, 0.08944777486425254, 0.1477116956225326, 0.08113161465453525, 0.29408993860406263, 0.2152864268470195, 0.10358111647468421, 0.09951264567432866, 0.12904455374565818, 0.2340758670001261, 0.1645781325116273, 0.11614377099660136, 0.1274105188466849, 0.1422916848452822, 0.11906468805166022, 0.11337867622534115, 0.19962637925580626, 0.16019704421201061, 0.1560821714660814, 0.13053408914035367, 0.1562208793456516, 0.20047630784252, 0.14694718583937616, 0.22923586139034843, 0.3079614620054922, 0.12664155043180914, 0.13053626483005862, 0.09010872488180477, 0.09648361829139533, 0.11833271402264796, 0.17677894072426906, 0.22083776041625008, 0.15274241116018067, 0.07799932628028816, 0.13650992735018655, 0.206196992808292], [0.01595440059674964, 0.02128450233759659, 0.04565491408650433, 0.0030750256959318875, 0.007080283708825347, 0.06045125499968568, 0.004118011312394013, 0.03604085154591068, 0.01814243485099606, 0.014922468671424976, 0.04671507635183873, 0.005887633240255978, 0.009948505884817532, 0.010941495645731207, 0.03867530534344335, 0.028711682628659953, 0.04727720868803802, 0.048988813819784316, 0.018467191013417417, 0.008832197993122523, 0.03324933823258166, 0.05427356794356339, 0.04613145141892376, 0.057607176563432144, 0.033880456786362395, 0.023849108068632986, 0.020509566097790678, 0.06258232391349251, 0.02975487796169135, 0.043255086207101424, 0.04951265708152806, 0.053418728733255025, 0.05166342594630776, 0.06295378462621762, 0.04912518513118548, 0.03879571138250251, 0.035875690650315054, 0.054865171682209744, 0.06194351766739161, 0.013374440548490855, 0.022437874520678195, 0.04955286520623392, 0.023017804994578325, 0.0320899963093501, 0.0037763832604527595, 0.09853367723764912, 0.006999493033940634, 0.0021624095707891452, 0.10093369280859348, 0.006427059687989494, 0.026925044930389812, 0.028302995788474238, 0.04974463616587943, 0.024123750589487535, 0.13863649549743823, 0.014009072573014326, 0.019613490289738102, 0.048803378407272606, 0.016673528288881627, 0.05601680101526361, 0.05421578576187453, 0.04254214946300753, 0.04834868990245366, 0.019941998367768624, 0.06881485137367441, 0.025538998438165556, 0.03085554712602208, 0.03108465912631683, 0.05836045166717903, 0.04455538639318078, 0.04953316908570067, 0.05773039414517342, 0.026605253017717795, 0.02485078335138819, 0.02145594515417132, 0.004924036357777133, 0.056694118501318086, 0.04935637131453522, 0.04640756482859293, 0.020302199503226627, 0.050720850516471176, 0.03184058680950153, 0.03385349815230697, 0.018141195703778538, 0.029218526399363915, 0.03844928259270326, 0.025531847007392396, 0.07848627474759856, 0.021767235406103636, 0.03912546243819018, 0.032422449740190665, 0.11447924579824172, 0.04795251902373088, 0.014569700504052303, 0.04543929864021559, 0.06924875591310763, 0.06514676110518557, 0.02415523105751603, 0.0770372654040975, 0.024505980583208225, 0.04171798824362698, 0.007204470391790833, 0.0545265838023155, 0.05842028313406533, 0.03017783893512622, 0.05096985590493968, 0.012699997807372243, 0.03940152605214427, 0.05465512952557015, 0.05889692388835454, 0.06664581131190062, 0.007948939314848113, 0.00821474549030104, 0.05930223036557437, 0.060738384753706, 0.00933449694721569, 0.039391907818254926, 0.040622222042011644, 0.024201537242099166, 0.028975078978786067, 0.03730765453750088, 0.034144856711669315, 0.0760564583563997, 0.0380361313751388, 0.02710093488736499, 0.03476654855354178, 0.047863250628354094, 0.0513106960833313, 0.08376671196592432, 0.012819246096055836, 0.01915286077306636, 0.04983307718629799, 0.02761744477245356, 0.049483147374684774, 0.02369783443188475, 0.062067229375844045, 0.03422601606636759, 0.027173395313683058, 0.036897008427448814, 0.01882571824676087, 0.01769669808357233, 0.016479579724311348, 0.036339373027365056, 0.07535663703756948, 0.02841556091762839, 0.020355534544515035, 0.02804001695626686, 0.08145605289046803, 0.01930046101821767, 0.03987153248500921, 0.027550073085172523, 0.0755704598381154, 0.04087767406036297, 0.048659499434213487, 0.06326180176749345, 0.04344930098722539, 0.0546856006727584, 0.024946425598294988, 0.05399182378765076, 0.035938831617034254, 0.023109879186977784, 0.059316023778651035, 0.055371433226091255, 0.04366776245015283, 0.018318351621048588, 0.01382781521251966, 0.02980838920320234, 0.053946015560218406, 0.06455524929709013, 0.04394306380662226, 0.05765163647611776, 0.048277731008467176, 0.09532017588254907, 0.03651712840843586, 0.031939645808550625, 0.013789157458250562, 0.016516849901827595, 0.021777372664561676, 0.018398534213643403, 0.030698855332429373, 0.03216372652640266, 0.05396823977090178, 0.05698502506880511, 0.023438138286432913, 0.02869916092153759, 0.028117441632334265, 0.012315810459005016, 0.04525127002008019, 0.01589896743215861, 0.0617065743332909, 0.014023846578634074, 0.020974644670082677, 0.08422365276924065, 0.01860898239688287, 0.01590113450337442, 0.018980274570264646, 0.09328284931759681, 0.038143464123770114, 0.003072562244450373, 0.043575728477369395, 0.09009390108046994, 0.05003742730966018, 0.06272388164014106, 0.03947735343488955, 0.0514350283230024, 0.03161401630589559, 0.024294097900330543, 0.05700840990269377, 0.04544243960070514, 0.04891069200370581, 0.03329198251688673, 0.024471345748151505, 0.03999581492896523, 0.017201366699150494, 0.06865293869087774, 0.021185115835959875, 0.012748481596880143, 0.03152686231318982, 0.03765971407354359, 0.024645795459829034, 0.022978757493077748, 0.04969605470016118, 0.01759803745024387, 0.0709389680395684, 0.02688365128462113, 0.056925086349609404, 0.039669764077951836, 0.009573399551182745, 0.013614861921767795, 0.017964078090904702, 0.07624838636406968, 0.08790485080211394, 0.05333151345351531, 0.05653891291829848, 0.030096700647845868, 0.06769421029715769, 0.026639885937554703, 0.05232862392140012, 0.09985564622066675, 0.04672449923330738, 0.03771817424304543, 0.02521741579497053, 0.0662163807259452, 0.08661683483590042, 0.03055007531187467, 0.016827552181278026, 0.07217082976093216, 0.031166686075589353, 0.0275413530893744, 0.06312166513394445, 0.045273501891642816, 0.020994164590393345, 0.06129506254388441, 0.08323288657852719, 0.031339820031256925, 0.02739169206770678, 0.0427758292625508, 0.07139333478745914, 0.007970978228014805, 0.06685375821806731, 0.061282605954235604, 0.02067627066055373, 0.018216057815739227, 0.03182884076640251, 0.08001788369109554, 0.02375838219098026, 0.06378308246513048, 0.047999526178764726, 0.040482759565836, 0.06415358939838987, 0.06217224470850441, 0.020353722746574113, 0.060347568829573935, 0.05989245897639663, 0.07873853217930564, 0.016330512420785044, 0.025750513398839582, 0.05673865885323575, 0.01613550473965945, 0.10606380825441693, 0.06516772127079387, 0.030633138395064784, 0.042887953891148495, 0.1085344877754969, 0.0336880078389039, 0.045254525893758384, 0.04759800034545122, 0.048210108427390944, 0.03533711934822702, 0.0440668482934275, 0.016854922587592757, 0.03994015864126625, 0.018786423681904713, 0.034555276825783715, 0.017125920445147543, 0.05373567462928834, 0.012428343029422386, 0.026424764617977124, 0.0737093028522307, 0.05884489885741665, 0.022080555791035298, 0.04040032084430418, 0.02223374464759423, 0.018110266819055525, 0.040926171256409544, 0.03404008652714472, 0.04946236723973867, 0.029616752308943582, 0.06873798211135211, 0.07430540352699257, 0.03784113901577169, 0.038763757855180776, 0.04067203690928798, 0.02635788514218744, 0.04580952978182224, 0.039376716294716445, 0.01778822069266631, 0.005748526037355224, 0.07421811546890006, 0.04416630948863683, 0.0274478750408537, 0.016594422049820423, 0.02512771264469672, 0.03012926513028722, 0.04414316980288394, 0.009369177747547868, 0.025197880552901376, 0.036731870514490915, 0.011231610269826508, 0.049986072605656046, 0.044346351642161615, 0.09752375118794943, 0.015632091127636454, 0.01875131961799437, 0.02042537111969244, 0.02443323287391855, 0.016761195560496663, 0.062101661197600834, 0.014055156592099417, 0.03291463441846352, 0.030195981812392993, 0.023240596769497763, 0.022237958131177772, 0.05035550318538182, 0.0011382407495646829, 0.021643630949960604, 0.06849563785738523, 0.06740878891920851, 0.10998715135839679, 0.035108825146791436, 0.028571622603903377, 0.07837114705433769, 0.08294768736607606, 0.16448715190973975, 0.23123432431490193, 0.07717475520386811, 0.14448304870916953, 0.1508551688804742, 0.17235737233873338, 0.1770762594476823, 0.12021873822255481, 0.06298825475237062, 0.08957610225244876, 0.0943588121463695, 0.07343132784890552, 0.12365619006055979, 0.13877455986315204, 0.10979438831488933, 0.21505724398359177, 0.10944986325358191, 0.08216015664079497, 0.08283187019368334, 0.13948688373690651, 0.1427046828452618, 0.08957831624654994, 0.13637428382231345, 0.21525063521919713, 0.1335103713697003, 0.11152273629822078, 0.13661319600237956, 0.1904955917909261, 0.08879272372371728, 0.26496321443588505, 0.1679299663632147, 0.22571034008456817, 0.1251787132012748, 0.1454563174516924, 0.14793873343977237, 0.10411863440587636, 0.11113098957726072, 0.17160326602958864, 0.15822182439507979, 0.08066252369673983, 0.0861175676747676, 0.15107345797361868, 0.11299143410137585, 0.13890733822218834, 0.25921078278653087, 0.07564849355408261, 0.14812902968016364, 0.16360281065346735, 0.19229265020018627, 0.1302282821627394, 0.10057602933938466, 0.16478142160321438, 0.09592769892826196, 0.2855791614180611, 0.17115629969104645, 0.226746489323916, 0.09319603623401734, 0.08674905395075198, 0.14600764028728008, 0.1948646218666146, 0.16681107962804456, 0.13799963128422538, 0.1004335752898647, 0.20430507739224743, 0.1497018694757454, 0.18334747051760075, 0.2672129388778441, 0.11353988410724748, 0.09680702230863034, 0.19057593909242462, 0.17637378746463409, 0.07914286572486162, 0.20534740130026496, 0.1521417522622693, 0.10704375728363953, 0.155428315422708, 0.17280153479547272, 0.17208208630402244, 0.09858144281972801, 0.13301348674201197, 0.1588953229328317, 0.1376916026516307, 0.13567541245250933, 0.1057993010768006, 0.24208779837335312, 0.10973811915685093, 0.12573883838711247, 0.17742004906458242, 0.11706405709828101, 0.22985211783839812, 0.18598272104657468, 0.3079906652771658, 0.121437109135572, 0.14591520411833642, 0.18984060193742477, 0.23777351294073368, 0.13977808907868403, 0.19307551545000848, 0.14412825806967675, 0.11387046636833299, 0.11096269538205479, 0.09826537792480762, 0.30584782542240235, 0.1191141696706895, 0.10549784547859624, 0.1346462805785479, 0.1970506844020659, 0.13557226637438421, 0.16942328623225614, 0.09515233367921845, 0.18224742954536793, 0.10260102188875599, 0.18661452907948725, 0.17490452275641505, 0.1559323553116091, 0.13235783805289578, 0.13558786392452257, 0.17799536577395855, 0.25015383087579285, 0.10946386734083777, 0.24360589352586579, 0.19338484643207443, 0.10338801635249008, 0.13472097415116527, 0.1631256604507085, 0.08534374992333113, 0.13900388062240618, 0.14068990224792113, 0.10178318472519036, 0.12502611614763737, 0.12606280930941144, 0.10431202564148173, 0.17990543747380858, 0.11967317636815772, 0.2862477110278222, 0.10382096328201795, 0.12727166541040907, 0.1925445245879312, 0.12920117276089807, 0.12075781131223326, 0.16407321928249252, 0.1742813715170468, 0.12722647388375577, 0.10909693420774515, 0.07899595304362236, 0.11406204963643705, 0.2270169030394285, 0.15679766694384237, 0.12403077641201597, 0.12405146844685079, 0.17084670823908624, 0.075814972120908, 0.21300074223789478, 0.115749680046593, 0.16323035402644068, 0.12521096550288702, 0.13044978882516586, 0.12377557720267966, 0.15473728879324852, 0.1426927471954015, 0.17588191305197057, 0.20985639563971953, 0.06505750420112764, 0.11662424602095159, 0.10248869807729799, 0.08652285883022894, 0.1430060924781907, 0.11065357124372838, 0.12582135371743672, 0.2709687921789385, 0.1983480543018349, 0.27143515586372347, 0.16277010372329145, 0.14256165422979863, 0.1415046367553934], [0.03838303896989073, 0.04410190064640295, 0.12401495669637957, 0.03312213699363413, 0.08973567836707638, 0.025293517054148743, 0.05418480133577701, 0.043918575806122635, 0.09890978044319539, 0.07050913908789236, 0.027261311563873486, 0.06727925111209193, 0.028362086065293803, 0.018425875891660972, 0.02626625528078406, 0.006109718299065267, 0.014943898065886913, 0.07063674635343975, 0.045434116055407835, 0.027865197607165867, 0.03597504459321499, 0.05077242738597336, 0.03194169317852826, 0.07869281971286382, 0.01611864697488566, 0.03439628293797855, 0.021837792103929866, 0.049713295508897117, 0.04718266577730256, 0.035630400788279316, 0.03447217160775777, 0.02577001225173233, 0.08608862487298828, 0.018464565247056947, 0.005556484552911453, 0.08527137759712436, 0.03452755210380401, 0.03485854422192901, 0.026666928841281804, 0.038422389076121395, 0.05412540270856792, 0.06993140920155472, 0.029915771747548735, 0.07903903016760465, 0.04223789764387954, 0.03736346787322433, 0.03422854798695734, 0.07508302107453346, 0.04990878582541501, 0.11040539706065772, 0.09301205255812214, 0.030193413502626845, 0.023505352925689473, 0.03711140579393795, 0.042273375175652966, 0.0140306877437979, 0.08490553996976345, 0.060532870176698894, 0.015099966455431236, 0.04709724697374529, 0.08084305997697577, 0.07036126113586849, 0.024833632557983362, 0.0396142763295962, 0.0394747142619904, 0.033669177397725084, 0.01443357146795719, 0.07794903260805915, 0.08796282833622349, 0.06084329666449659, 0.044515143794518326, 0.020497670667546413, 0.04836521824942001, 0.05435767290633052, 0.08272130838445119, 0.008542125503863058, 0.008616427414029116, 0.01982353053115789, 0.02246328565712658, 0.08181329501131851, 0.03724379727857248, 0.04029606010824923, 0.006892611319574738, 0.011669361528249518, 0.05311904279815574, 0.06079652316627964, 0.048933961924405835, 0.10048157069832088, 0.009903362238659494, 0.0620548723776254, 0.0009623317002420194, 0.03968819998384964, 0.038840891417836955, 0.05279904787218379, 0.042226678286228454, 0.08533399762405504, 0.015348314923504669, 0.04804120136184558, 0.03522810886704153, 0.017169386358751405, 0.03659183347237207, 0.05401866750851755, 0.060573476667125384, 0.00648777359240358, 0.11933661096038357, 0.04218216474738814, 0.044968729132726315, 0.029707326884231264, 0.011990834046305429, 0.09943111093654748, 0.024385944181572528, 0.03536164182268324, 0.026877223806936416, 0.033055789948951815, 0.016914325045241464, 0.016698305487572666, 0.04476857334074955, 0.11283757300266337, 0.02522818124552648, 0.054231869777844804, 0.04920557839795948, 0.05276029148409444, 0.041832702249408736, 0.010533534673853748, 0.004171553197421975, 0.021448177022619114, 0.0515968720578859, 0.045193556786304524, 0.05803053973302726, 0.054308486231152094, 0.06940041833947744, 0.01046072184709051, 0.010598259527356395, 0.06633392159616755, 0.015794291093404737, 0.11184856115329651, 0.05634931381791831, 0.09931570745163387, 0.048439877348080765, 0.06676374288696436, 0.08204177307385592, 0.02736659311208754, 0.026760636716179793, 0.036590128926740545, 0.038966886068303744, 0.06104804515357941, 0.017875541309495608, 0.0295018908312364, 0.022507910278715917, 0.09139232818157443, 0.08124729393110161, 0.0482488494937218, 0.050559995035010005, 0.029287485803868023, 0.0496799323797947, 0.04073638446448792, 0.04944999108932192, 0.022487248887398073, 0.009039345295018247, 0.012285594036051584, 0.016552963286578175, 0.08976819113858285, 0.03331534436813766, 0.042303612666024316, 0.08060281480392141, 0.06715965712623251, 0.05031594623541159, 0.05133237254114882, 0.031640346747853106, 0.04353991386690929, 0.027659296155757004, 0.0291761962111078, 0.0638676164371352, 0.011137493495498935, 0.00884853577571771, 0.0727928931554479, 0.007896008863744718, 0.077498818056718, 0.04362881454008241, 0.021352611384504748, 0.04286874040600754, 0.03987984836942727, 0.04478590991047602, 0.0814282515596959, 0.05616503136773264, 0.022557357423788598, 0.028622826005542473, 0.041654885581303994, 0.02346470238520734, 0.03027256187652388, 0.031340902130449974, 0.05164379494324808, 0.04766374984155259, 0.10579657380379016, 0.03406889909397691, 0.017200185008527293, 0.05077802365826023, 0.04635955026793865, 0.05536985125452761, 0.04581130327536695, 0.013691316539001082, 0.04652779849786912, 0.01641359657139307, 0.015787989062617625, 0.13929287963096174, 0.09955854966275154, 0.03876579564905936, 0.02012772489369156, 0.030461931150526773, 0.04071782598452222, 0.029699960948839307, 0.04543454123420581, 0.013000475685863246, 0.02419805154204369, 0.03939258963650754, 0.08738494523230099, 0.02959068233688032, 0.07166949416240377, 0.024834186056508653, 0.043040370914123716, 0.03164009202361828, 0.040892551487852494, 0.014984596486864312, 0.07630193590997689, 0.03485367190273058, 0.052289400219676964, 0.033502829065846826, 0.07665617496616418, 0.016125603053238124, 0.06260609945222255, 0.032393284772913304, 0.03757569338044813, 0.020022106266790823, 0.05064170597301376, 0.055668901336649736, 0.009588964542584314, 0.021520775344763553, 0.08170863207910331, 0.011724274710661942, 0.03641210924533587, 0.06373337485016355, 0.03800090282194076, 0.0273121606498476, 0.024133066218646786, 0.03456601737848213, 0.03355357856039078, 0.05688174109485361, 0.05551808543743626, 0.10211710712962574, 0.012641284828855386, 0.10408578455568322, 0.08028509515908458, 0.02356669550100642, 0.011205578602159457, 0.04666307813397819, 0.06039130478917111, 0.0329570488763913, 0.08016955377834459, 0.017895503645582546, 0.03244139892499774, 0.06028926570809657, 0.014396671885474315, 0.06549194500210785, 0.015721143103174625, 0.039468685150026314, 0.015613394751844388, 0.03828634335208805, 0.02381413232444996, 0.10093900179790874, 0.07705244926675674, 0.017208119764203028, 0.04914008554131274, 0.013947804691269996, 0.05673854777048673, 0.041432605170074015, 0.027883102997176112, 0.004111031293793912, 0.04409817362865133, 0.12239478798883578, 0.02008333201369932, 0.07150037259223961, 0.023836053930403247, 0.0783578324462137, 0.03256827074613783, 0.03453973290180007, 0.05246078174921775, 0.026367788743828575, 0.0628094383395247, 0.07094039296310756, 0.039170512238577496, 0.021984543906705036, 0.04052817325798735, 0.013545462974317133, 0.03925532583267458, 0.05204763053165329, 0.04996531162290804, 0.028865402001106454, 0.033910533398269646, 0.05630337535553882, 0.019477835270546136, 0.024091959855849707, 0.010481463677640404, 0.039282878184871334, 0.04330415796909121, 0.01333259395323694, 0.02300705678100067, 0.02393521635132211, 0.06339246189341911, 0.049733531721416986, 0.024419150262650464, 0.025501850834717194, 0.09578605693194175, 0.021122097443308563, 0.04476599162444473, 0.05793092148979345, 0.04556329380120001, 0.040587077758485274, 0.06552030557706472, 0.005240875001501052, 0.12297148365647563, 0.0834190536050066, 0.07522340668665786, 0.013864393038074336, 0.03292586909787309, 0.04412212153716434, 0.10635781747799729, 0.09117394715787903, 0.050191288408372677, 0.05792416076386168, 0.04678324285534121, 0.0795801640337994, 0.038825600302868316, 0.06179806055320848, 0.038120102272519184, 0.05822737836429189, 0.030384326443797162, 0.03815670212310168, 0.04691331692400479, 0.037281814391814896, 0.07841132070508697, 0.044942885156600706, 0.06739628636428426, 0.010600694729345701, 0.02506131388907952, 0.007165757574952178, 0.05031763545928463, 0.05044693960958431, 0.06727153660669442, 0.05787508517143227, 0.03148711384123853, 0.01279946666346082, 0.010013029640240055, 0.07107654210901068, 0.16974531895210668, 0.2246024850155077, 0.11934182801914793, 0.15381766152718376, 0.14788362107449962, 0.11699903921614732, 0.14010684805050974, 0.17490964022374925, 0.1076713748156063, 0.1855400907656839, 0.1777551206009042, 0.14220294122013355, 0.10878928861911259, 0.12736895091591344, 0.12560541651421978, 0.08414146685672384, 0.1778323116201547, 0.08728019036953488, 0.09362116906671755, 0.1455513276760617, 0.18324388010847956, 0.15158954076468945, 0.2831454839437239, 0.20327568504839175, 0.19845156810216366, 0.11766676145095019, 0.15299312109428068, 0.2392892178989226, 0.15510864225366425, 0.17835864466765236, 0.08207561117747138, 0.21285216714585983, 0.08702262394851254, 0.0853305732110335, 0.1474915219530944, 0.11176104326882672, 0.11556788738216124, 0.14030082151293755, 0.23088207708731776, 0.17756629524932754, 0.1837652948715033, 0.07189962697485763, 0.15041685933547636, 0.08043331018979512, 0.15984681945654655, 0.1523861189883563, 0.14770875384490337, 0.14224155205151728, 0.1680950736326556, 0.16013348955781231, 0.11871066350009173, 0.19112732321504625, 0.1782039255504647, 0.08524281017842793, 0.23400953910764188, 0.2428304593289091, 0.14481478010214147, 0.13335788922925151, 0.11400758078502071, 0.17447362894252424, 0.27993848667510096, 0.11289195758440804, 0.09326764247229985, 0.14810489791054882, 0.10501975298769052, 0.11220553514337349, 0.12297520684378764, 0.1781493034814635, 0.19498377918235718, 0.163199664544194, 0.18064261323982672, 0.2532965227240517, 0.11269346420322696, 0.27654784280926953, 0.2863220215564774, 0.0752589914707407, 0.20555910203726063, 0.20010656316674527, 0.09561480563734809, 0.10421092501811444, 0.12982893584957048, 0.0891005608343309, 0.20929249364041516, 0.2521124112630083, 0.20965275414768728, 0.13332854806175157, 0.1701727653703382, 0.1307414691414564, 0.26774864884153493, 0.15134793195512988, 0.09659522198020451, 0.2147635718386981, 0.144036955710861, 0.19426390168166932, 0.1537832488576251, 0.11451875295249686, 0.12138703762884102, 0.16016699824362032, 0.06986897303572587, 0.1327718626106939, 0.14020040270782289, 0.2729566064813445, 0.15194966337613522, 0.24711662933470743, 0.10878094592161718, 0.14825356493313468, 0.17430697417547628, 0.1112664875484282, 0.14083095435653964, 0.08307831301804512, 0.16993523214853581, 0.1315042322441455, 0.17999019744175096, 0.1561914922128762, 0.14840417781904822, 0.1178576016137677, 0.18159570322642404, 0.09993695113207064, 0.11894596740603448, 0.28006927320553415, 0.09382636571723608, 0.1832588341447615, 0.09595021425235657, 0.11986178721511558, 0.06911403935162291, 0.1547050518133948, 0.10438436732417154, 0.12899868040075227, 0.17019973166527289, 0.11982829385106603, 0.15143407088133598, 0.15291033763318293, 0.13039784806389965, 0.08514586175161024, 0.23094842030156046, 0.16076309125750296, 0.26697989493127794, 0.19874736997148684, 0.1704090268861863, 0.18387152062308404, 0.1296951768979911, 0.09585603140294553, 0.1403376396985785, 0.1746241192543699, 0.2055654146017567, 0.14770110828741906, 0.12202476752140831, 0.09690303610818041, 0.29791991857271044, 0.16277905163024703, 0.19270511193861886, 0.1411956581737726, 0.22388567186651692, 0.13836759863601578, 0.1917429974362735, 0.13884130144311538, 0.1316673323632248, 0.23782854869721398, 0.12762814144333526, 0.12376901949004782, 0.12859507463872433, 0.1927666134771801, 0.10449968653941348, 0.19956910652258705, 0.18036605549916146, 0.14289556131247552, 0.13924126062662373, 0.11323262922345631, 0.17108624861125024, 0.23179081058309925, 0.1282974724627791, 0.14411103641313894, 0.10696154072760575, 0.0855520339081845, 0.11849840351891135], [0.010336980452731011, 0.032922486819687395, 0.013064150998909629, 0.03723964125158326, 0.01953137332513448, 0.0457326720108188, 0.040209377259616895, 0.053450011933643016, 0.08666186548408963, 0.029171726088069623, 0.030293202200423808, 0.025992428643568873, 0.036998400164227334, 0.029330748704171954, 0.029572001282846736, 0.11944676674301587, 0.08398579779051005, 0.04645305129909708, 0.02966828895882974, 0.09492721108178939, 0.005556696663505488, 0.06250925061683502, 0.06453101027516589, 0.03645931175279041, 0.09955028357404856, 0.031065146866885406, 0.022138675051410834, 0.051614434623550025, 0.056625649393085516, 0.0674249457135316, 0.06330800453020681, 0.02186043957819141, 0.0590648656831153, 0.05253911806991505, 0.08557677854813876, 0.0790861982011026, 0.06534104866366233, 0.06186803885465188, 0.03126777329241797, 0.04969975490483546, 0.007675263022388062, 0.06275198174520366, 0.1110276826206715, 0.04996746432997527, 0.04874037533637978, 0.041255091106699365, 0.01989449325558399, 0.05715756722155118, 0.06953815328738383, 0.0538686445103057, 0.008226091252459634, 0.029136938035428047, 0.055152489127771515, 0.028405986733794696, 0.027142194467746926, 0.026858046710971865, 0.07500576110736978, 0.03539174907810746, 0.02364551828753564, 0.028391180169438163, 0.036351086511727304, 0.02165870564509063, 0.017267527967511166, 0.022509281576100378, 0.10525432144922596, 0.07310706581319533, 0.0648924122534452, 0.020466374060619744, 0.016615897409557816, 0.04984255752436096, 0.005824448702286088, 0.03993410654666443, 0.026297119048033512, 0.027676617403724985, 0.06181897475354134, 0.025301289016140566, 0.008134874120925464, 0.06543874019576658, 0.06732723885966886, 0.053652351076203975, 0.006919696358137674, 0.052439813922730186, 0.025094190552350015, 0.06354875915173082, 0.012162987409429926, 0.012350937505553087, 0.023814367896486676, 0.04590381988354268, 0.018708039480712146, 0.024358426303332372, 0.024649541629778764, 0.07887498776037848, 0.028088431797861576, 0.05286742121942582, 0.029205914676910447, 0.060688864830280506, 0.03169993498182345, 0.06867909293261266, 0.032764940838059115, 0.06115941135513206, 0.06162311671481979, 0.030592876644204223, 0.050413890576530854, 0.07736518934008575, 0.0586156968417908, 0.02434730079145201, 0.06121070860254188, 0.03894681839512722, 0.06578899559474762, 0.06432453425781381, 0.08733438342929849, 0.0461836832936012, 0.029022660699763128, 0.0658111508575178, 0.022077033701803417, 0.0087158617961611, 0.024007615490606236, 0.02543115049540516, 0.043692633494614594, 0.005912818380766699, 0.03290441097511399, 0.049865260539997014, 0.004543802023099195, 0.07947881060141711, 0.04453642188661522, 0.03737492471813195, 0.037277953308676524, 0.11665875828194043, 0.019421311388272914, 0.027464600655460553, 0.041080346451170986, 0.024828515090649168, 0.022857225304769895, 0.04325511302017877, 0.03155120858742345, 0.036978160121267846, 0.038611788993641254, 0.07965708692227641, 0.019331173483102072, 0.00633741686713972, 0.07283502799128333, 0.045770160523393465, 0.047816354556069265, 0.02585557852721503, 0.04077804432581029, 0.10013920600495993, 0.023399303374331326, 0.019498944823299686, 0.0541997975068948, 0.02790037061898939, 0.026488139241513227, 0.07317605969165603, 0.021983592042459116, 0.10376469412397954, 0.06894359244934975, 0.05066434770161587, 0.03428724181327609, 0.042985090009507634, 0.031148403387276397, 0.033053978151010896, 0.019258278301886974, 0.028544834424411098, 0.04648763633843872, 0.05907997293698211, 0.023804874151885033, 0.07508079941955305, 0.0037948952963380448, 0.017799849907356887, 0.015071688234926233, 0.04634106456632576, 0.07818756174416312, 0.012696694053198784, 0.044447459926408146, 0.042031253087184126, 0.052899746299390836, 0.021583487302245154, 0.021709185093641285, 0.04290480016460342, 0.05276150573345442, 0.07167637363196382, 0.03978711725663274, 0.02210268615594795, 0.060717907223489985, 0.04797334512395244, 0.04547386452735913, 0.02281766452436005, 0.01034020855572195, 0.024575859293221466, 0.028263563327791712, 0.01456015696373558, 0.02415687048567399, 0.055594265220626715, 0.08293297847792988, 0.02617919513384902, 0.05921033045817768, 0.12774274819680762, 0.06144061158861845, 0.04656136080983185, 0.018528121816475066, 0.05823627264509278, 0.04466482971404349, 0.042406490613375945, 0.0119771555464174, 0.04269963415760187, 0.04255107821776502, 0.04115702802195184, 0.04439539276063443, 0.027913275370073896, 0.03563339619206325, 0.06480284125333832, 0.04590653183479463, 0.053052485079294255, 0.010759294081869866, 0.0601432301975306, 0.016615476061199463, 0.027187041254834305, 0.039381094487203706, 0.04134646624386792, 0.10070975764744705, 0.06257616839702092, 0.04134444760218744, 0.046293831415354245, 0.04040641124330221, 0.06986177180923762, 0.05016191276691614, 0.011083844358161574, 0.014439594834261845, 0.05421795379070025, 0.04193683275051656, 0.013375118536303842, 0.0214364692839163, 0.07462896076181243, 0.10170222455335241, 0.049479010499893665, 0.012317413497986573, 0.04861951347500567, 0.06787398815034859, 0.04206513715607505, 0.01911578786319062, 0.11636749165312898, 0.05175909883673153, 0.050754646485250805, 0.03737499366604513, 0.03656040471527846, 0.048943128166419846, 0.005129997659805081, 0.056304022699834845, 0.048698841879564914, 0.026351532358075344, 0.11319828550181082, 0.0777715913230373, 0.02423722161761215, 0.015169757065333188, 0.03516312162842482, 0.040447305016700304, 0.0003060534723889789, 0.024386865402301474, 0.0861260712507271, 0.0706371293974019, 0.03714042520450969, 0.02258018684393216, 0.03805590027402486, 0.03491222400278334, 0.025614956055857965, 0.048883894248114484, 0.022989593806766698, 0.06542457523004663, 0.10432151747086357, 0.027027068689705867, 0.021744733488547708, 0.043639413366514834, 0.03919560927897692, 0.06296740566951133, 0.01213127424219443, 0.03450056665667123, 0.029525141599738312, 0.008840353956686394, 0.03762646585762982, 0.09514139394365972, 0.1520736164022838, 0.057442555759823134, 0.008573261232325628, 0.016256763051534374, 0.05883154977533606, 0.016699282249676126, 0.09322481049645333, 0.02428330755191705, 0.029540530390917297, 0.03334458594420745, 0.08020899198468655, 0.02649022683110689, 0.03493620255481332, 0.023591453547499353, 0.06560566309358805, 0.03908529644832015, 0.05952467931614769, 0.045371790972328, 0.045651424556009235, 0.00911263692673416, 0.09769433598604896, 0.0641560293884287, 0.06163705568460207, 0.04666020530426214, 0.03434600841794764, 0.014811838871889539, 0.05517752871157662, 0.017878172821515513, 0.07829618535094685, 0.044008081688755946, 0.026297272265618368, 0.023246618220582608, 0.014233080512513558, 0.02369768887517914, 0.02075092784399467, 0.010410916555913226, 0.02670928009695584, 0.08517938575917676, 0.05547480913059366, 0.023578518152897878, 0.04650284318373569, 0.02847810242054684, 0.04534577079597981, 0.03995578683492157, 0.05975580038202386, 0.030885962731835824, 0.033600064775636124, 0.03109845062417369, 0.02211850395636453, 0.0728141903997429, 0.0302339606212392, 0.034228850591687426, 0.061190388120350346, 0.021524626851802873, 0.08809588248691252, 0.05376111640925369, 0.026646656239585533, 0.05928617699312107, 0.010852303859146853, 0.021219038209247015, 0.021473720309234435, 0.041992577138326825, 0.031195148157196182, 0.010401607630023313, 0.0652794398727917, 0.01708699551771485, 0.03481420688331127, 0.07118261464300656, 0.04802746923580285, 0.044987651504456036, 0.01263487650336878, 0.04062943092937912, 0.0832329402046819, 0.253245010972023, 0.17410172389880305, 0.1555863287179701, 0.19932170608831992, 0.13896609716598066, 0.14968351400907964, 0.20692051688749946, 0.08024247768785685, 0.17647987532038845, 0.13217592281439614, 0.10589188280244989, 0.16518924084882583, 0.1060808613716114, 0.0995570557912992, 0.0949778801371013, 0.20380770246828758, 0.1264361162940341, 0.09000832139844857, 0.0868293782696128, 0.17128527825397832, 0.23880301253689876, 0.11991182807832958, 0.14560562798813467, 0.19105851319768738, 0.24922026080950616, 0.13390371155354286, 0.14846952511898934, 0.11500212378920087, 0.13430152569086323, 0.18889920245255196, 0.19493093443734033, 0.16771256593206238, 0.19498290584212352, 0.17900759774831035, 0.1535691119610302, 0.1884665466364353, 0.19344524480402472, 0.17412384851805626, 0.06330561433588305, 0.1801902383205391, 0.11808516037079597, 0.1449239629531099, 0.16574088544134172, 0.17727136672023805, 0.1504571862038105, 0.16236393922759643, 0.12488352420229105, 0.17615552901500658, 0.1313613415245087, 0.14279886569467284, 0.0978328523436381, 0.13949227699589345, 0.17950747011890336, 0.10314331254771641, 0.11843894743510794, 0.12280660621341198, 0.23871825256895637, 0.15391921414242637, 0.10715316230010603, 0.13402435507985855, 0.0941202064014731, 0.2423657044287651, 0.09360469051546629, 0.25370268721974665, 0.2123522028447159, 0.17471433376833317, 0.16468356153176678, 0.11937037245520662, 0.13060833838197494, 0.16855774477364557, 0.2117315796954978, 0.10272849125847702, 0.15704021038066956, 0.2586205886496652, 0.1760745688431686, 0.1060893802693294, 0.15883268758414254, 0.16615970570954586, 0.12302104954517658, 0.14244811999942028, 0.12197917762903437, 0.2504474723771695, 0.16480926123838271, 0.15405426012171855, 0.12545571527293614, 0.12454672896813963, 0.12334695100904473, 0.05098857143292985, 0.1819362446305252, 0.10639373167988755, 0.09522018608667197, 0.21960359277023425, 0.08406354805394527, 0.11369284122220932, 0.17523914996174075, 0.19638267105385182, 0.12821182383284455, 0.10170899677060305, 0.092311886499726, 0.1452100661493117, 0.172993409176988, 0.1417088451524896, 0.16997923623890648, 0.26022186562899624, 0.12787002604454756, 0.10601202071073557, 0.17992868058143124, 0.11855497145124021, 0.1826437421503567, 0.13758480999498598, 0.12401966047623467, 0.1287221379818455, 0.0931813503285089, 0.1587527846136401, 0.13746238914468598, 0.23209726107456993, 0.08220598402042543, 0.19040942222120302, 0.1597051697993471, 0.16655142178698895, 0.11608246098002119, 0.15311808535648933, 0.06182174416138761, 0.2600818553999547, 0.1403622157991894, 0.143817640059898, 0.0832778636005617, 0.28358748603251677, 0.2251613155127533, 0.10478413498569882, 0.09338247139127025, 0.17502228579213544, 0.21711975185861512, 0.12018881482823242, 0.15364400471650785, 0.1389856170862913, 0.08846071653909261, 0.1634678566047261, 0.09104162079071806, 0.13605082617892375, 0.18111899735466128, 0.18654620935839994, 0.23997045392470978, 0.10500019476298364, 0.20170947957423427, 0.15023191038879657, 0.09650722912122166, 0.20104351934165726, 0.10942296590656043, 0.1008111876886218, 0.17000942010312312, 0.16036054269681055, 0.15570170155936675, 0.278986607107424, 0.09240711888959331, 0.1338650241133667, 0.10093553141961176, 0.22887926278335435, 0.1950406229063388, 0.17914347110256074, 0.14995423415976186, 0.13039038636751715, 0.13481221522294706, 0.1196270502142368, 0.23909974903348954, 0.1270108201330708, 0.08629109425049636, 0.11465684030084841, 0.20952129345988074, 0.14164265515583177, 0.14174318121325585, 0.1280429014455407, 0.09010490976394185, 0.1179305178624007, 0.17697654544345795, 0.19991387673203023], [0.03242138870841554, 0.04431077451895803, 0.025401822734443892, 0.07292471390457884, 0.00685766717651859, 0.031180437353830186, 0.013962166924630443, 0.02817125930901497, 0.06623013200418604, 0.0402125105592272, 0.028596997351175355, 0.054489417046669035, 0.06216429654629, 0.02832422408485605, 0.006678684139549132, 0.06251577768594989, 0.06297289851992842, 0.0718844431121984, 0.04305198863749543, 0.055096135700061444, 0.061368890437147314, 0.09661114128727107, 0.009304071765302891, 0.0918775912554514, 0.04972557589832333, 0.04232650337320182, 0.038502744038499175, 0.042397623145652395, 0.016301736243129257, 0.06435890096209704, 0.028953170779371457, 0.009928762841398918, 0.016019182906846608, 0.012324933608573292, 0.03837486098129903, 0.06371221550169491, 0.07694246202346779, 0.0529307192341695, 0.041697583491763765, 0.014371482914523974, 0.028407681703327164, 0.06709523679267976, 0.05395371091341781, 0.07992181626539077, 0.06747430475849299, 0.01183356385632989, 0.03616988756543687, 0.07746916279316911, 0.043481384749494256, 0.020801173635728417, 0.02666260427494924, 0.06322405661546415, 0.049407637918428074, 0.059049252811218464, 0.020453262465795683, 0.014002224704581163, 0.07708208920854716, 0.04415022547266657, 0.022918495101734035, 0.04361759518243132, 0.02575351071784333, 0.04952004216911812, 0.05225055573147632, 0.007939977043743936, 0.05082358673755681, 0.022948914537987402, 0.09802759955486945, 0.09147221583031839, 0.030248292211082675, 0.030703421216458086, 0.035470299903423555, 0.012950661776196814, 0.020390939297935656, 0.04020927000730749, 0.030716444711170854, 0.006972746031674287, 0.035112552164543065, 0.05470469924471071, 0.018082490386140924, 0.0335712637001228, 0.02578669573150335, 0.016827626874850645, 0.04923124617386249, 0.057158681879481005, 0.03258080777501868, 0.00688782949451237, 0.02861765682727339, 0.026135807744257396, 0.036513087294635274, 0.0029212215750087657, 0.03662976248550319, 0.024738011378494483, 0.019587883800869028, 0.05610045015571579, 0.011403584559898705, 0.06864366902699394, 0.029868977181913874, 0.03191668998389956, 0.019799768398966522, 0.018180471116436586, 0.042271934930355325, 0.036691570459234144, 0.05913812284087462, 0.05370061844587327, 0.04046782851219177, 0.07680284249926768, 0.08045516667827483, 0.026529737815801657, 0.05778866662313381, 0.023142173623425827, 0.0734116010848553, 0.025603997168101134, 0.04561858619713495, 0.05079356375180426, 0.02793374140897105, 0.08268415312012357, 0.04081453692408339, 0.04291605782665072, 0.04350960359818513, 0.03863908853682299, 0.010729717342333208, 0.034167245631256414, 0.13881248121540393, 0.014188308418998796, 0.031224893436076182, 0.022363529518066395, 0.021813909312890425, 0.039143622552435246, 0.08648556567007497, 0.025027014217489672, 0.020138329465783412, 0.0983886338109451, 0.09222871233378688, 0.018794509739945495, 0.011757803506277984, 0.006839764659338061, 0.023741683389450756, 0.057093346070858746, 0.06584747874688718, 0.1528292395655186, 0.048691705770550237, 0.029821809148415927, 0.007235575476736432, 0.02670911538805212, 0.03138183420824428, 0.02894582974183704, 0.04523372277617455, 0.01804784405976534, 0.02817699730756783, 0.03235169768994374, 0.033077933720403144, 0.01635847079958166, 0.02474026559221168, 0.034205599823185516, 0.03434899233041271, 0.014061873267975547, 0.04458442112551101, 0.030591869238583796, 0.04444831794488334, 0.02165695704940346, 0.049537332773569136, 0.01897744196016462, 0.04005001948004769, 0.044859699499342716, 0.004970556568174113, 0.05287037831881354, 0.06311262529643794, 0.03284742169442677, 0.018028236039343382, 0.02606516103110006, 0.008161748485309223, 0.024861499006229065, 0.034213904216284716, 0.016104300063283696, 0.01898492663918484, 0.02090753536791571, 0.04331685587643616, 0.04057493909532505, 0.012199745265646808, 0.11367525950434709, 0.03508562034356498, 0.0485779608659927, 0.010442820287519887, 0.01172575613318552, 0.03642289193287011, 0.02289469083470683, 0.028643510379498045, 0.023551272235870845, 0.024633810014253663, 0.029163479151564742, 0.04065256678469239, 0.054762772539810795, 0.038338096421812816, 0.015063380011387411, 0.03259139511013224, 0.07183476997118804, 0.0750495047278462, 0.019122720958905357, 0.012812094665282677, 0.044151075830262516, 0.023708414106119065, 0.06984491021402421, 0.03136953083618033, 0.03277537112514819, 0.01630411877657377, 0.025456588444930893, 0.06295554279800385, 0.03485570203572993, 0.004843749385702634, 0.04719746276556004, 0.06111269148306982, 0.011871883574302399, 0.018201605567047675, 0.02345298507040547, 0.08830331611416994, 0.0343077193434921, 0.03675093078204701, 0.03120601894484172, 0.01766271633847106, 0.03160117284184502, 0.0513161353075937, 0.0500880618910155, 0.027552670123235836, 0.020709852124714566, 0.05023705833140881, 0.05566732319552572, 0.049494585067394285, 0.012454028999913606, 0.05667589326959945, 0.04186187870800496, 0.019445358888216076, 0.02443954352319481, 0.07531099351904086, 0.04862596776576773, 0.017160151168824207, 0.04233385398683529, 0.06857335747730348, 0.044429943326019475, 0.024369352632352424, 0.06850347493685062, 0.04838052468614713, 0.036270471079455274, 0.05938766449089012, 0.04181220939743423, 0.048282415636124155, 0.03032189219318811, 0.06691990224944969, 0.03387514013616789, 0.07311320217746882, 0.029173288907435153, 0.037250286043291135, 0.017436096039150032, 0.04757830805535759, 0.02218014339075214, 0.03449030873936511, 0.03500145409376391, 0.028598632948893695, 0.037739781752949765, 0.03001056172163977, 0.024425414946651267, 0.008319359584411067, 0.07916793212174408, 0.038467783616074634, 0.025852675053982005, 0.00804053518109985, 0.050002964844386426, 0.04063840181897244, 0.0442576156778922, 0.06012958617159917, 0.0639216294662366, 0.03682620658148681, 0.10204582264827144, 0.05973074547646027, 0.01706767861070412, 0.07518392251504045, 0.02251534516202106, 0.026939179252592788, 0.11708176139021113, 0.03979488155774532, 0.022538216717000452, 0.0210311857893342, 0.02721360343838892, 0.0768680825468994, 0.03299094060616147, 0.05210107665569071, 0.02757355176483191, 0.024743291639512586, 0.04430409040181868, 0.022123330310287497, 0.0155130468098627, 0.04184978601012019, 0.008624870660564592, 0.02861145151508672, 0.036733126898686734, 0.018713302504751953, 0.13461698537632344, 0.05336454716481028, 0.03887431966441293, 0.05067396210506559, 0.03850109694946197, 0.04689355568599798, 0.05804793758978767, 0.04420996883944158, 0.026211091204576438, 0.08458543013060286, 0.10851802454600412, 0.02579705132501981, 0.03101992086627551, 0.010137539995353549, 0.04492883127362979, 0.06330393277288926, 0.03375364625225625, 0.052370260800084764, 0.04489323116778847, 0.048843042609552224, 0.046468549257805275, 0.033846086251639554, 0.015202707464566395, 0.07018861556125265, 0.015517093669322711, 0.02907227063851972, 0.0706680563669051, 0.0485254148952663, 0.0731407813427429, 0.010665288390291315, 0.06014772330320651, 0.054695287854560924, 0.014624281395827572, 0.04694934220864408, 0.08937588517343806, 0.03960206871852279, 0.046968429289277525, 0.00593280082666165, 0.05736511193155762, 0.02373122820450414, 0.03433643231889413, 0.008351581242506304, 0.0431228019747763, 0.02499590530210445, 0.03799270185071134, 0.05331894195067787, 0.014532183263180478, 0.07300576600696772, 0.03140570167752524, 0.03124982959801151, 0.10123742368793297, 0.01857131576886581, 0.04127013324309261, 0.029197169783254786, 0.01849270557173558, 0.024810646089815327, 0.06823585744226171, 0.11543381433453291, 0.19440138382056069, 0.13974677140433944, 0.2286040686791943, 0.0811122402909302, 0.13987685313388226, 0.10687658923768228, 0.11105460295033072, 0.1267839202116574, 0.09267441462725402, 0.12283035493906468, 0.14044273164003127, 0.23606216444844202, 0.1114368501810297, 0.1403331197798252, 0.1748575309231397, 0.1845618271298947, 0.11754680740376634, 0.11658873784566119, 0.2182683934487643, 0.22593497238572569, 0.1889975068549956, 0.17567588136561457, 0.1420330688838036, 0.11004225606279028, 0.13028273569239726, 0.12639775827166536, 0.14554066373215568, 0.1358814747823823, 0.13733926349349562, 0.1395242688276114, 0.15944966415484108, 0.11303405923348282, 0.16670601833010876, 0.17797298068481107, 0.14465195577471487, 0.13495093842427577, 0.09297854387231412, 0.1898341821206193, 0.10869761853809319, 0.12307192544422804, 0.10707404073928634, 0.13705645447536824, 0.17577231651352299, 0.20936297372944895, 0.15700300915106652, 0.1635391793904766, 0.13542730721735186, 0.18993844668711388, 0.1313548604206693, 0.18039904324518097, 0.1407950095111324, 0.1587692555040121, 0.15024701764266338, 0.09473165947823756, 0.11044713353077251, 0.1819296562743764, 0.18468668413979394, 0.09787099586138803, 0.1896960871113885, 0.16466430208135038, 0.1316572200026243, 0.10606828986877397, 0.10514210489007736, 0.15175967357091366, 0.07772695137968949, 0.17549813364542302, 0.11562983325171856, 0.1239123545406807, 0.08890219768809696, 0.20165113431792106, 0.14764647089665936, 0.19663319712685, 0.18077651008723244, 0.21467311217659907, 0.1656214523339464, 0.16948681024293746, 0.15504888739557038, 0.19670415219039689, 0.14767355976566193, 0.11768601324048736, 0.12881063645885837, 0.12129511473880661, 0.16347269828040756, 0.26569338815827526, 0.08133748546242714, 0.10386161956815951, 0.07491020696057428, 0.08769228438576383, 0.0835165229716128, 0.24640902456256653, 0.1282110960493165, 0.13374752154754055, 0.13041114735026516, 0.1051634097952516, 0.18261461548747557, 0.08800395193599886, 0.1834884000521514, 0.22587431354388116, 0.09628714738233436, 0.18548643396746728, 0.2909267002776746, 0.10684377769188536, 0.19796628204564895, 0.1591820696428899, 0.18744386522279632, 0.24852200231004148, 0.19175254289181004, 0.19906137408989094, 0.09081097469935495, 0.14843575596328706, 0.12356748473980736, 0.1328693089946624, 0.10037939755185958, 0.11843567623967126, 0.17436289859394874, 0.11173627564623473, 0.11452064518966984, 0.15380509768522557, 0.22354341442546538, 0.11076820097983846, 0.17887891029878972, 0.2339813164285114, 0.14424762989003814, 0.06837165418771968, 0.1892511432449664, 0.1571869162181693, 0.2025254245006269, 0.20601475581286416, 0.29428201216843825, 0.17154590136581854, 0.22150145302857124, 0.19672440755511486, 0.09874881004854556, 0.193096766729028, 0.09065031073987485, 0.11587999926339235, 0.09100318615955692, 0.09430595974047339, 0.25543994480563753, 0.12104157027938675, 0.12837906082671496, 0.11709857702014909, 0.1346652489155531, 0.19180832941445614, 0.12012518356524168, 0.14520563816110935, 0.2848528487788093, 0.16025561929470108, 0.12033165192171452, 0.20610964346316554, 0.09927609304506933, 0.11910707569651066, 0.14941265596257103, 0.10280591210410481, 0.12059402171402209, 0.17236014557701929, 0.1153004231051572, 0.14179696058554037, 0.08816522110493914, 0.14646862603483662, 0.11046288429849571, 0.19647634828523283, 0.09202641149562213, 0.16282510883625478, 0.12475804666117316, 0.1806088747276414, 0.10445719930313288, 0.11827461391447053, 0.17366378207600888, 0.11880062520503999, 0.17695152501185096, 0.09101782609978992, 0.1790172504561563, 0.09535928467108358, 0.09594259933838922], [0.03599905378876194, 0.06984111807879902, 0.03809454557936519, 0.014661226943585903, 0.08306917358910845, 0.021933227507097107, 0.039188438696005655, 0.005345068226057676, 0.07188912390941574, 0.0391655748019055, 0.03498114127245161, 0.11290960825018345, 0.1033593493423635, 0.040398501385484016, 0.029209206939765045, 0.020924349082633856, 0.023268765822473555, 0.025581223289332083, 0.07437295716015563, 0.04423726455218369, 0.04795768628678015, 0.0506603448922115, 0.06155554009901901, 0.029413097410372673, 0.030812132923353105, 0.010953338407430678, 0.028412025421857837, 0.058632742298106034, 0.1264848165033806, 0.020052518042164947, 0.025839059756347732, 0.036342828083903565, 0.018805005144508138, 0.06318775553917212, 0.019349640032516855, 0.045850243524558125, 0.0380196298412498, 0.027870723016319737, 0.15176949481810295, 0.03924422904909138, 0.04116261280291984, 0.03235800642400019, 0.02034560604501636, 0.07374242849407658, 0.04090184796481364, 0.03784342578822567, 0.08900755009944401, 0.10888757769979777, 0.04455891805851171, 0.06065289700223554, 0.02233046707847426, 0.06298547002276586, 0.007969448924995959, 0.08665696252137424, 0.04184387947222398, 0.032003529880556374, 0.03817942046049622, 0.11015847926178288, 0.024972671770580837, 0.0371304392484167, 0.012329462145815694, 0.032078962728020646, 0.04164294227056446, 0.02146729091632991, 0.0369158695121446, 0.06453740710933363, 0.009874469232595256, 0.02224098417847868, 0.05385394711347838, 0.0030671335538969406, 0.00835625725167413, 0.049702275334106344, 0.06624925355877608, 0.04828413550351416, 0.04117614574610226, 0.02480469741708329, 0.05182629623900979, 0.05868176809482037, 0.01587709849475012, 0.025337178320173296, 0.04196210599113857, 0.03740237747889854, 0.047814929632530104, 0.015230319188577274, 0.012321988958114339, 0.05419485240934357, 0.05677816983793051, 0.0391956054485373, 0.010713011837534366, 0.07604375661861512, 0.02239724313239417, 0.028668858313692674, 0.05792021158061201, 0.06077168276533485, 0.03687872190869624, 0.05724310093829709, 0.014858349984992417, 0.017410336332696102, 0.044960463044023326, 0.02634442114691821, 0.02345875754291492, 0.03364564317669119, 0.05990581954979609, 0.06319721289459737, 0.025771797236595905, 0.04344722871939021, 0.03735056312213983, 0.016241512156181758, 0.020462382742534244, 0.16044328019263285, 0.03889192819535252, 0.008360837499851422, 0.033022105062921206, 0.06731401618209577, 0.008861177184078242, 0.05691833711499649, 0.00612178178984792, 0.0682679258827721, 0.01413475695787178, 0.037967696740862825, 0.08310194683050917, 0.05868123949415261, 0.09551503800696905, 0.04291166431240497, 0.08085658142883932, 0.053238732545005704, 0.018969262056353114, 0.06548351037406153, 0.03960693720728159, 0.03890133192462306, 0.024097337793078155, 0.014650888587047738, 0.06792029050449211, 0.06130638149296565, 0.04052168832370832, 0.05980274625002377, 0.08489592556631373, 0.08236897688719534, 0.051638516597449786, 0.05725494848804609, 0.031294239714982054, 0.024829654646436536, 0.056434939465215134, 0.027962714854267337, 0.06472975646536197, 0.04000467090536991, 0.02534857579326678, 0.014511657852469193, 0.05102274278479238, 0.04326805607565949, 0.03237529319801158, 0.021985775393043316, 0.08458004453249517, 0.042961751140894434, 0.053687583459841634, 0.04175371092353617, 0.034702381029004054, 0.03101771644827339, 0.04645906125886306, 0.03334473533135268, 0.030202591235959725, 0.03205021910910164, 0.032889583343339544, 0.04971550567255867, 0.053968737728052565, 0.011538063634126898, 0.024400271940976385, 0.06941590863730639, 0.033119731477551886, 0.09285498155100692, 0.09243265260010959, 0.023192172351803993, 0.016456348108007543, 0.025232501981419422, 0.024677088236316078, 0.025890100364302917, 0.035251057030813354, 0.018453817033479293, 0.05201864942547776, 0.025346765910545667, 0.0732817185381728, 0.04376269606572967, 0.03248984632532924, 0.06625070146495296, 0.02349160356266845, 0.0418738603231407, 0.015491038061408027, 0.030697269530426112, 0.027120483535972816, 0.0031432719204589846, 0.06145087333636419, 0.05268594265104302, 0.09934720898708028, 0.04719568544157571, 0.04974266731991403, 0.024151465735368194, 0.06565119935980727, 0.03580822894770292, 0.016268551229469238, 0.04249474011181344, 0.006338809710747052, 0.07472909611439513, 0.06364575737426359, 0.02202238673494468, 0.03254648320557129, 0.04388701298364228, 0.004320160848193712, 0.04373071572533058, 0.05132162049713154, 0.15425108343122468, 0.030654866563817187, 0.010452782303365249, 0.010749888437379514, 0.04654074538378947, 0.15129885636270046, 0.07854078956429036, 0.027123858153279272, 0.08631038434442975, 0.011370602559538619, 0.028016206943580223, 0.12024227244358872, 0.032713927043181275, 0.04321416179018636, 0.04449122269908267, 0.018670753981437416, 0.08702296102719922, 0.05021791379418104, 0.03544561655050324, 0.01912477407454243, 0.028787933274983402, 0.07414696888337213, 0.016170457501204747, 0.008546962391494984, 0.03181462408974767, 0.0083883955977076, 0.033320902336028316, 0.04089122615574349, 0.04587126114676076, 0.05984661627500769, 0.048073829046540686, 0.06649546655676057, 0.09844779878133729, 0.00864943239702693, 0.06450407462374819, 0.03625384314105876, 0.009576810557665605, 0.05214818340215472, 0.06890172574428782, 0.03650378698723451, 0.02744700553105964, 0.01538366222033097, 0.007426766603584252, 0.02371481668594624, 0.07434360833177645, 0.030079490482626908, 0.04637489117862237, 0.0840767630706391, 0.016667133369933695, 0.052382181128186565, 0.03369121008642739, 0.07792385129798805, 0.04542107340849696, 0.04104419476202419, 0.026523614858066844, 0.017098879456640254, 0.09846168795540448, 0.10066617490543474, 0.02642613974580121, 0.07471414973899242, 0.020828348689622456, 0.0585142553092972, 0.0816647812063175, 0.05311918835486135, 0.052188406848619064, 0.032511059299952565, 0.038349220018473365, 0.05325243019709184, 0.03404856329002688, 0.04960619258664308, 0.024919154783410412, 0.02375000118908863, 0.00581061794242311, 0.015149266128578495, 0.0659938628274587, 0.02082991725464742, 0.003511825568913933, 0.03232498037358446, 0.018925393946589004, 0.03195256013573418, 0.032541430855710665, 0.032844066229318424, 0.010490229638713983, 0.057366923729498545, 0.02733400756222827, 0.02113017775568991, 0.039849224004654155, 0.04120648665834339, 0.043372148272371104, 0.0200745411547682, 0.0315329086621322, 0.04325377236631128, 0.05534911708485696, 0.01120875786704522, 0.03954383837539823, 0.03274139895614597, 0.07623223723062585, 0.027197082752301812, 0.023754195520474065, 0.03696716675955442, 0.05099728185262892, 0.022515483057847428, 0.06724701413223821, 0.062280466119127895, 0.09652175414826601, 0.034007470333768476, 0.06243280270287107, 0.019011622888126203, 0.029382264286640192, 0.10822309601691463, 0.050560439366006085, 0.029327697759013505, 0.01929726068591399, 0.03620146954011533, 0.027954190210889907, 0.04708058839183181, 0.058016868894018477, 0.004988353748265053, 0.03929639197585564, 0.04981664843076179, 0.05007332618979197, 0.014717183920795159, 0.015414068250045663, 0.02321212319657207, 0.031258984348706664, 0.030511027810374097, 0.06085534722754552, 0.011398307171710318, 0.009918636116649835, 0.0031624866026123207, 0.059925435231097286, 0.0527543964375171, 0.010803306790729685, 0.03105808162100373, 0.07044732345328217, 0.09484886326977322, 0.05196343363833524, 0.04483110909800857, 0.03935719637440578, 0.02027253657879849, 0.025795503827412764, 0.03590194448348015, 0.0557219605862854, 0.07662271224563161, 0.14453649100276733, 0.12097308967983532, 0.1494681360500474, 0.12125644262038893, 0.10679691609355713, 0.1209384931491748, 0.1432563121160192, 0.0909561483610061, 0.23913218519620358, 0.06295715158264484, 0.17543632567169207, 0.14336068393482318, 0.12849319260567427, 0.17877253132962412, 0.17737006948840234, 0.11762927676881514, 0.14676706324661934, 0.177930478126772, 0.12461105737114146, 0.14730546983980364, 0.1414765366503308, 0.15277950513747432, 0.14398506091487023, 0.2044360477837824, 0.1270222195213841, 0.15899977136042812, 0.15695888248662795, 0.20079702289114076, 0.20555856577571363, 0.08356482481523868, 0.10182583283993507, 0.10071890473726297, 0.25171539385712915, 0.10982949812445911, 0.15372000063859648, 0.1441337432592146, 0.15418976575376528, 0.22552566692954112, 0.21272331115699586, 0.15845885199885215, 0.11754375071294847, 0.0887275985892742, 0.17466922651135153, 0.21521996105870894, 0.17518461982329048, 0.14728671600741727, 0.3074379788050729, 0.1063320845846207, 0.22877653039270834, 0.12981631072057834, 0.11791038507175063, 0.1777896252010138, 0.21240164615934898, 0.19312059206347312, 0.09020867637328564, 0.11247223333245325, 0.21481378124125544, 0.1362234564317811, 0.1487290450642186, 0.0995457636552953, 0.10422247762401259, 0.10569335111687261, 0.17162123845229227, 0.15185846826962887, 0.14401435611709473, 0.1555289487324415, 0.12654631804194183, 0.21864213710350378, 0.07561540621663294, 0.1163211586554685, 0.13046979904174805, 0.09213976952577792, 0.1704979390506783, 0.13384683718604426, 0.12566559272067201, 0.10112213511620799, 0.2636351550538694, 0.14014029544928383, 0.1685962330309614, 0.16789990507306593, 0.1547580804195135, 0.11122974597157971, 0.11828136314908344, 0.1329773580355029, 0.14524809475387299, 0.2167835465121654, 0.13682200092702143, 0.0889200475367327, 0.18519349726698092, 0.20519386195848066, 0.1149947540233693, 0.2664907324698664, 0.22961656112344037, 0.19076364595563183, 0.20353043992673198, 0.09461552820979588, 0.15069501053902412, 0.21265727437792287, 0.08685485835397437, 0.18022734761959125, 0.09270554077961753, 0.15833358130147382, 0.11724384261235116, 0.15519027658287557, 0.08861673034487233, 0.12724465315019892, 0.14656985689315105, 0.11211666894415695, 0.3040421868283903, 0.1652893685405293, 0.1385125118277727, 0.24881591960307092, 0.12340107512089515, 0.11845413895864641, 0.10334668590897515, 0.14738731867363378, 0.12509919327473448, 0.09847483402418514, 0.10356908123339377, 0.185161474791746, 0.14698918277938522, 0.12381814870863192, 0.20552245239096306, 0.18267072376704988, 0.11988951193709528, 0.10532598131366315, 0.13769192440855887, 0.18192372675384247, 0.24641961189768008, 0.14433373817272727, 0.07300382780451929, 0.09660722657797799, 0.10522970704421883, 0.0839729198525029, 0.16765060474074658, 0.20856495526048446, 0.1956577220511052, 0.1120014723029829, 0.10620614739074823, 0.098813567460785, 0.07023108747577475, 0.23947082670225253, 0.11839976203778099, 0.20162760009688718, 0.12829515887724777, 0.11994510693776032, 0.09113291548865457, 0.09332858476667635, 0.11506003237539723, 0.1576754045222075, 0.09721362347444219, 0.1965377119279677, 0.12377795973612417, 0.12236090391994485, 0.12659279659630793, 0.12789842492390063, 0.09464401901969988, 0.085671819416025, 0.10161846816059082, 0.12110913923430829, 0.1944634522641859, 0.07778276854585256, 0.290015944309773, 0.11360451894541902, 0.2069423810368584, 0.09580024488029942, 0.2070290868681285, 0.17456816419238047, 0.20945709529182605, 0.15976801965265505, 0.09604297983910769, 0.15017806972947814, 0.11214443197053288, 0.12849974265742686, 0.1317121791503122], [0.0284681624297293, 0.07109416979214839, 0.034988602968834104, 0.031839280629590634, 0.112747733871783, 0.013771662882889711, 0.064231037057095, 0.13825476920652774, 0.01664475211122584, 0.07287673381788116, 0.0235519981041791, 0.005234817640044757, 0.021649893718741594, 0.12188522460600063, 0.035561797614659996, 0.02722726278607884, 0.01672740150693684, 0.021765069292497732, 0.05301729483049243, 0.005306990304586268, 0.0469484152422557, 0.047346960993543755, 0.05855441363828798, 0.05603316082288662, 0.025247664776660746, 0.05468505291989254, 0.020005183384543466, 0.050528501160442836, 0.058652040052918665, 0.038041739138744535, 0.022446439383671652, 0.033641422032228405, 0.031239403141362053, 0.05400834064329824, 0.01625817073809524, 0.027894527283346945, 0.022089700965631395, 0.029221636716336496, 0.031296306237157796, 0.018302183335406647, 0.06823464702334135, 0.025891864281748573, 0.02074556714374452, 0.023934519211311015, 0.03076098314786871, 0.069453852972196, 0.013177719703244587, 0.011502686651393531, 0.043760206279975754, 0.017791738951458566, 0.0911084543012323, 0.07998482699716285, 0.03255193392115255, 0.016887282141514363, 0.01995425002889768, 0.026683286733685002, 0.011530708232443902, 0.044786691320158785, 0.08640206974720763, 0.03134754985841292, 0.042407367784049244, 0.09701686145197, 0.021467945921505173, 0.047480984245457, 0.024464680783210263, 0.021980046970589508, 0.04302041049325659, 0.04325503258094673, 0.01627010447273572, 0.05619005946021888, 0.02573534102749921, 0.04453606182529081, 0.01781294809564227, 0.03462117953946994, 0.023085902550167615, 0.025952563343209126, 0.04354472489907377, 0.07155408301661093, 0.0483513635493094, 0.034198540322963274, 0.0439247964400678, 0.07550788577646017, 0.07196692779900567, 0.03226481565845109, 0.04478858738777138, 0.03857399021545726, 0.02484272410642476, 0.04429253779592053, 0.028851782873032555, 0.05159591061754092, 0.026123870179177295, 0.04766719340677223, 0.026867816247226253, 0.018773317832740086, 0.05488729247102334, 0.0894914188932988, 0.04906362613602992, 0.06843228238604723, 0.05563662222196018, 0.0030587539884201704, 0.09057779285696246, 0.019721167777935346, 0.04970326358752866, 0.04757277690054429, 0.08108741138130426, 0.050047777157517216, 0.02491114724938187, 0.06583365852073317, 0.036517971105152564, 0.032241886646877375, 0.002964516076439571, 0.012908342121649655, 0.04975534990550049, 0.017375312708017808, 0.007059105208158614, 0.013428155760911685, 0.035888396218539245, 0.02722712105981285, 0.07160626126513367, 0.025171760785123034, 0.004341638123150915, 0.03935501302382158, 0.039520277341286984, 0.046078338543133396, 0.0468480117588995, 0.051769249501728246, 0.03909005768476956, 0.03143392244143592, 0.015066272950911475, 0.04887712203086384, 0.08692828022063741, 0.06421427505331175, 0.05905772957410063, 0.013001179529143678, 0.05568650986758932, 0.012116860297899093, 0.0374662998553005, 0.017014604039309968, 0.0878813089202008, 0.05054126418526134, 0.044263120019628156, 0.1114209232130839, 0.03131903798109101, 0.03492841910150263, 0.015157853016599774, 0.058020511642098434, 0.039854441063418504, 0.05399196551391675, 0.06714353863630565, 0.05521176901135234, 0.05662017952530615, 0.01568549224400833, 0.04043072687401887, 0.0050542722625147194, 0.017513922911377686, 0.007363041016017839, 0.039483382546853636, 0.058576434835671425, 0.025253889241045522, 0.022540710333193985, 0.02977956322983148, 0.02293511920969092, 0.09376841116576426, 0.03387496776638493, 0.024256440848412535, 0.019894361105417053, 0.07920982947032298, 0.018127256733996254, 0.029057563665593346, 0.05938802072177491, 0.007081941331571509, 0.027631590585975398, 0.032505363436235536, 0.035244897683902134, 0.1051264000876296, 0.021921420176964135, 0.062316165816399365, 0.03931235724819764, 0.05631467132198234, 0.02112102300499476, 0.06233111985268132, 0.015906321876231703, 0.0318603576236074, 0.10129539356116327, 0.010052933244996015, 0.04048583923929161, 0.07845026095427814, 0.06527884998509, 0.021451172426403053, 0.0528932077389571, 0.04931231742844947, 0.04119762685149908, 0.06060340006144778, 0.07262033951138297, 0.08174399469768809, 0.022227414846119863, 0.036455044643052166, 0.0369989670692913, 0.05597756965266121, 0.07098229031168646, 0.0470070286293424, 0.017308136373157465, 0.04074622103343568, 0.03827946388252801, 0.0015047248833129304, 0.03194471731060936, 0.08035094807705573, 0.019002075517369856, 0.038524983570941036, 0.03912618639127862, 0.08078856814292171, 0.05831803337881162, 0.02719719575027064, 0.029644082495642286, 0.051627975227611686, 0.0300965991411959, 0.037114466315195445, 0.0558608255138801, 0.06902857458279019, 0.04872481609063764, 0.0035341553560893743, 0.016499028781489018, 0.00620561431259698, 0.018101334233858415, 0.03226068644453922, 0.035579291232410944, 0.10660989104860252, 0.0415622693816981, 0.037579860898756215, 0.02448430987105014, 0.078641522465454, 0.02715204444323336, 0.04207732944538997, 0.02151953811276584, 0.09123248393617331, 0.012259326796347817, 0.03218092520030276, 0.04865686026131434, 0.09383913640293384, 0.03845160383911383, 0.023733156830853513, 0.02466097740726846, 0.04856504079314971, 0.06854065318381594, 0.035254761065927245, 0.034812578946472175, 0.10763640290186291, 0.04920884193251691, 0.02597586390742612, 0.14166611276807325, 0.045129649731661045, 0.02676134343228994, 0.08409927073385447, 0.0703630691033698, 0.06628857685192939, 0.014572431607502363, 0.05647169636382211, 0.06194088615537171, 0.09189317348383128, 0.024297893865995353, 0.05318388064962722, 0.05693633252033784, 0.050055012857962045, 0.02334209192814606, 0.018666628597965165, 0.0440293712721717, 0.06013903203570555, 0.07376194841438725, 0.021727211142499602, 0.04636933321073171, 0.04771503176720393, 0.08677805803956525, 0.03604992202693417, 0.011734666693354807, 0.030176448485543652, 0.02503474404464566, 0.02755682998066468, 0.04433655720804969, 0.029344825569780606, 0.02963833109055075, 0.04057351800222551, 0.08857755260842462, 0.019457966780229922, 0.037900847908590114, 0.057696054253967545, 0.01815688326924799, 0.012230862799521175, 0.03409552064934566, 0.008253359194514493, 0.03163435977072485, 0.02914314717805434, 0.09231547179121165, 0.060112916098366824, 0.06806484363492459, 0.024267374838311827, 0.038069835413367524, 0.008325896229624988, 0.03061518895499889, 0.046995709680261157, 0.036173227708786726, 0.024315324281492544, 0.006667469091142618, 0.022159681182294604, 0.005436327971232635, 0.03211384654165276, 0.029454102266519785, 0.11389829068174286, 0.02839966076275995, 0.08065452573881035, 0.05821659184631802, 0.013623450725008885, 0.07136459116854015, 0.05854359264635752, 0.009379336073423826, 0.05657257482169136, 0.05666120736409099, 0.03612876013522187, 0.031852748455299486, 0.029559370408195163, 0.07513808747453075, 0.05355344912517936, 0.10531761563353001, 0.006384017995573701, 0.0473914975150218, 0.017070982364877578, 0.0357179339945076, 0.030131977081539172, 0.02792811640838702, 0.0425516298010705, 0.050503430933120756, 0.07640328168147996, 0.019613951857712482, 0.09449417988258986, 0.04767531393876961, 0.03889651706201896, 0.022093194326566114, 0.03088510471336063, 0.006984683117949434, 0.03763978812663305, 0.02864062605846313, 0.031300770614536545, 0.051391675407367374, 0.05774535201189499, 0.027304968999458418, 0.024860133454504035, 0.03906492233997391, 0.040962265488962014, 0.0025542209304178195, 0.056297070451922, 0.07635361620134885, 0.06261418934070295, 0.029244749589012037, 0.15823599702167898, 0.2680826938200382, 0.09535565341432249, 0.18018925772799602, 0.21855570706388644, 0.1077253686925096, 0.13211216897733752, 0.26343312234647814, 0.11592294615242751, 0.24051230791355335, 0.22583852191605877, 0.14182168990373611, 0.13208664292770048, 0.24778632807635495, 0.1001574925237125, 0.11448185815806351, 0.09258888857138735, 0.10864140300620949, 0.16951757633397657, 0.13002419633971107, 0.11902659049918575, 0.16559391913394775, 0.12730833803934435, 0.18506644924561824, 0.12489085566372642, 0.1838386707728909, 0.1260443848948325, 0.15701744224755995, 0.17279405777733173, 0.11020937814347206, 0.15088342220312165, 0.16189434265177097, 0.11420055067226773, 0.1464167005953289, 0.10561688788115017, 0.14336361039069392, 0.11886051795896023, 0.12371222173134166, 0.07661400948681178, 0.1226067491957257, 0.12372129987324439, 0.06617876580886303, 0.14740426453851885, 0.17282865430799224, 0.10329189530063061, 0.18808258336878594, 0.13168328231380833, 0.1308039665943192, 0.15130932112374615, 0.09693517349660398, 0.19751280395975038, 0.15045660397698804, 0.12935891026450744, 0.08665224341976066, 0.17691236259716173, 0.1357999170619634, 0.10294180078011367, 0.19154747647623863, 0.20652382123854854, 0.10527744964365998, 0.1227618283742378, 0.2137107831696349, 0.1390311073872351, 0.22307668301847675, 0.10763123946925325, 0.13889262933404217, 0.11252864038631802, 0.1463019253025132, 0.1394585997707421, 0.1084202487442282, 0.2151013859697888, 0.08541911765332184, 0.21543285689286648, 0.17029834250288625, 0.10121150693345456, 0.1376938396283696, 0.15697702344867492, 0.16168299431522049, 0.19209184323347386, 0.1257871478916176, 0.22613475279461956, 0.2117943222964964, 0.1535133254383841, 0.14994062843822664, 0.20180787590722885, 0.15020667545257077, 0.08237103766371166, 0.08107867797896748, 0.14930970906730623, 0.15590260045663004, 0.1757615606390661, 0.20879783066770724, 0.1928549740583666, 0.12640870566810333, 0.1512845611620334, 0.21906236697348858, 0.09963468348066654, 0.10501046800204825, 0.12973443124323122, 0.07351059496643082, 0.18914387561380866, 0.19167290039120183, 0.19638742079898236, 0.0967897623476963, 0.2943041674312084, 0.23153717419312847, 0.09846983913091883, 0.15642278947897498, 0.15396396899896284, 0.26250738169877763, 0.1533466093843022, 0.20702516449795616, 0.1543732897769059, 0.08463063697901466, 0.10745848664232802, 0.17550449217519454, 0.13540404878797072, 0.21373459318232155, 0.191128671529793, 0.09730748456692505, 0.16945704006619994, 0.10290651477032131, 0.14878766611218452, 0.20359613962711828, 0.18251082589549406, 0.1764965147501038, 0.11563270608143461, 0.09132324237256281, 0.12363538311253633, 0.1333899576697619, 0.16801776003933724, 0.2511651435446355, 0.13360915074665702, 0.15920503695885982, 0.09331910059817376, 0.10252234465893238, 0.15583302435134688, 0.11396967475452732, 0.1330672354707795, 0.09773745141442745, 0.13715986102338762, 0.19712078144713757, 0.08537499098888329, 0.2337058618544571, 0.11806285189044093, 0.2290842679118918, 0.11876793623331094, 0.11892324523820032, 0.18226603016016946, 0.15089492884374436, 0.20823397463367832, 0.10223922154475605, 0.09452869980445794, 0.12669693092785536, 0.16449692719165357, 0.10787839475538462, 0.11789399845105027, 0.11018226629183178, 0.17427944097547762, 0.25898037418242426, 0.11270244275369953, 0.08576078520667169, 0.12780258732457317, 0.09587636337645593, 0.11930309461369631, 0.07747651723724219, 0.18027459992276085, 0.11114976639228483, 0.07984192861664681, 0.20792969983191262, 0.09612604675273742, 0.1381200296624053, 0.1872319193376649, 0.21461243801299604, 0.2667916824500407, 0.12424295978440393], [0.03246549239021636, 0.029416441384162155, 0.054277187709005616, 0.021873646934006005, 0.030778484426498897, 0.053299697822019945, 0.07141768106169279, 0.06855399077457767, 0.034631690265791076, 0.0298627891067055, 0.00868988375464875, 0.021967236065275727, 0.030195918610139243, 0.05321295368635366, 0.05732531366389125, 0.031478792211161025, 0.030890718222625797, 0.026860306670348492, 0.12929690310791617, 0.03279816224089554, 0.032744903808399554, 0.007952229183677944, 0.004982052675087847, 0.03432918129669082, 0.03696412156005541, 0.028537198443025834, 0.03194899016600703, 0.17073582467292586, 0.02601878015294431, 0.04413916316303996, 0.05792530223486885, 0.042863151794599916, 0.013289441178072126, 0.06628046398081126, 0.04667565729769488, 0.08109465857306797, 0.04791988367815653, 0.06761538751062847, 0.07280296721165219, 0.03903889450274649, 0.09525293634543497, 0.04945282561464175, 0.11651809687816328, 0.03297005321890597, 0.043159907443388816, 0.027026434751948523, 0.049542771997831525, 0.04126542180235829, 0.0778352149251488, 0.02346183913159034, 0.08172791451215744, 0.05013944340809699, 0.09460301799399239, 0.06561286432007629, 0.06563823715212845, 0.01802083371477502, 0.05249543573647257, 0.03265001232765856, 0.09091900841843698, 0.07506634334042188, 0.033519035655884974, 0.043638758361339576, 0.01179755102061937, 0.031234978983599334, 0.01151717050121196, 0.048319923300896926, 0.029612569468877012, 0.04657344201639776, 0.03757986855963546, 0.04189290526893832, 0.09512674634254749, 0.03006411892842622, 0.04382962533723443, 0.05778977362018439, 0.06248732901088173, 0.046966311056166894, 0.025585829392976822, 0.06021310890754385, 0.028599969772321564, 0.012750668777903963, 0.01114613879772444, 0.044721443611647815, 0.09042344912285767, 0.030844111348532384, 0.023665901971980933, 0.015810618342290965, 0.089746204415156, 0.05122614678956809, 0.05232225006987011, 0.02245736379747189, 0.0023781576460497754, 0.04041142528876662, 0.029932562479629155, 0.029632319215564962, 0.1504914762993013, 0.04059700625798395, 0.025893183868198145, 0.03980168441851293, 0.0691382707126679, 0.04772102640521142, 0.04847491437929773, 0.009079270924802029, 0.03860367612252313, 0.03450907023263074, 0.023274005863875635, 0.045344571868378314, 0.04444439174427141, 0.032722966880687786, 0.037606555232477766, 0.08610587717304308, 0.08158195177994429, 0.102366246583481, 0.026494461382108352, 0.10690649731024619, 0.09824074053716275, 0.062441570579164454, 0.07971551644826129, 0.036076520599665186, 0.03528612853598691, 0.06026231090448076, 0.01960407698436851, 0.05499182133785179, 0.030286226969873233, 0.027050604825959574, 0.03910588123084557, 0.07499016355723143, 0.012210185128834941, 0.025382109376932346, 0.02317904926566107, 0.026921938443856857, 0.05997400137505705, 0.02422914896611004, 0.07827222212067536, 0.07491613648110822, 0.020402991776204398, 0.00588675128153315, 0.01740110688842833, 0.03356384413857614, 0.026089754368689273, 0.025647166222634337, 0.021493638595265728, 0.059188654000360164, 0.004375637584035435, 0.052815396188487934, 0.07673109070427957, 0.037491113443167946, 0.033884022925649925, 0.0364815206417153, 0.020035928408164653, 0.044350411908160296, 0.04275658130345326, 0.02587970072073081, 0.06437839789976997, 0.041609479550031886, 0.0234857966162024, 0.02835467224940658, 0.06503157978577, 0.06329429921724143, 0.03777150928433384, 0.024099149591019078, 0.02593088305495199, 0.03561764159390042, 0.063056796638956, 0.06800085997148868, 0.1198194455355406, 0.025391744847799984, 0.08390745763937313, 0.03578039314297419, 0.0623718335954172, 0.031781732104718685, 0.045808319362901875, 0.03017691005351803, 0.027349806210446744, 0.024099433043551062, 0.032074808616251234, 0.09868210677297846, 0.0258532285525073, 0.06569609211217012, 0.021319196544467442, 0.04059665002709916, 0.08517693427781906, 0.01527168793648842, 0.10680900496100226, 0.0690683268851811, 0.0314790909854515, 0.07425733917062322, 0.07963732185382998, 0.09226612040712949, 0.06397431333278937, 0.03875708522936029, 0.09567931024057251, 0.03628239906843632, 0.03707737233790179, 0.04642229286893722, 0.046213020630661523, 0.03129763923014604, 0.009309761883360485, 0.05147332505833718, 0.0632935254684379, 0.07164000743819822, 0.08830815012897215, 0.010007209287235334, 0.031197860108448133, 0.08963704454682528, 0.021971438057540406, 0.014374241788661288, 0.019184770250332453, 0.026887544926496285, 0.08584332351963367, 0.07475949448323058, 0.0868043578380058, 0.05579108853013285, 0.007537343734574895, 0.0741118131085269, 0.03231759528599439, 0.030931690520036127, 0.05865688172860011, 0.03802057595983629, 0.026633196074755925, 0.05436750564483866, 0.05914684475189256, 0.02719741217010925, 0.0662351192365731, 0.03264103760762561, 0.08059182144220799, 0.06358698310871279, 0.05552710612274467, 0.04132585847870477, 0.04288931369721409, 0.07542080456210722, 0.034616376168184707, 0.02410227139931052, 0.019910519814959938, 0.037705449522623134, 0.08708613263743539, 0.03165735198455232, 0.03996510629452044, 0.03804853050819328, 0.030229362178473707, 0.028984469301517934, 0.04805634692010861, 0.058299585981594945, 0.024284596494849653, 0.04003747862072722, 0.05000685274060215, 0.015156826458781239, 0.06294932216405869, 0.0470140804686854, 0.01635147450161317, 0.039278522975021796, 0.064767777409044, 0.058586608483305866, 0.022397042034314047, 0.025615143747399413, 0.03505412646899781, 0.022458874905902534, 0.006743524863850326, 0.03356446083935519, 0.0383252261446849, 0.02501831528910947, 0.03927743896060894, 0.04243440685733672, 0.025157670512975707, 0.009144916041423718, 0.03784102793302267, 0.037689591502590526, 0.04429359882769566, 0.04871671088039876, 0.022307848332509882, 0.06774461888257535, 0.09095704468387751, 0.024058717385595365, 0.030341052052174366, 0.04271867910339948, 0.014265808746248726, 0.04102279409585942, 0.03000441195082761, 0.029958484979766994, 0.004935815917222851, 0.003936728814639331, 0.08368865526731938, 0.04387061487162306, 0.05142480104921326, 0.030114720951044754, 0.035075707165824796, 0.04458066729468204, 0.040838178397426685, 0.02812374462073128, 0.01544058255310501, 0.06326912173760996, 0.017284157821127487, 0.023867685700796788, 0.0303019164505625, 0.0372996221056148, 0.023170850209651456, 0.05365031711276501, 0.053086304030711615, 0.048380019068117106, 0.10961157675351828, 0.04695084374097567, 0.05768106957416862, 0.06665271376409838, 0.0653497590833614, 0.018465766089878256, 0.03179326747363854, 0.04402613455069162, 0.06647672038525343, 0.04243540277163829, 0.01615994869010343, 0.0536613219657973, 0.018182790447627346, 0.04226112926018335, 0.03618871034573644, 0.023517974224241994, 0.05986694441807847, 0.034028074268492005, 0.06733096970786011, 0.10929536630189228, 0.06426837235208481, 0.023283403847486745, 0.03510814715897845, 0.03523296969492109, 0.025226137705988465, 0.022790964444979064, 0.021163228703963182, 0.008298402291632468, 0.06033968961527271, 0.04842192790801487, 0.044450290621288364, 0.041124599520117044, 0.04329953462846818, 0.035656436286385984, 0.02356098048509129, 0.0071192191699669975, 0.02905675735805304, 0.05988236193755462, 0.03124078401484557, 0.04170980642459566, 0.06502067835460748, 0.0667387837423913, 0.10152130522915434, 0.05588247515862027, 0.05165485342243507, 0.03473812669155098, 0.09803831712493012, 0.05888141443832748, 0.012175213215091537, 0.07880977069538447, 0.02064420222004335, 0.04065512168791987, 0.01946104262324591, 0.018425607760887475, 0.15915878056999178, 0.09286513987688289, 0.13544120405229831, 0.07178671327569792, 0.21700920537114146, 0.1118277618661523, 0.23258959513998803, 0.15874187552159832, 0.10363774569404703, 0.16484767288690613, 0.14138102080793152, 0.15772717674413037, 0.18479047373177546, 0.09694086552988138, 0.1904936612493569, 0.14437689956638122, 0.12002913912217464, 0.11900910071187443, 0.18134084109577442, 0.13708763425388645, 0.07856436208972047, 0.12605817447746956, 0.15248957150165113, 0.2289088950642655, 0.1781789970494086, 0.1493545405326351, 0.10462573864647459, 0.3584792609176328, 0.20315145623059044, 0.126822400808094, 0.21834000734792602, 0.15076642525532555, 0.2751434504264786, 0.2425258474484567, 0.12174200446855639, 0.27151642247073116, 0.08407473293763977, 0.1610788573781329, 0.14855512778364843, 0.09588947880171961, 0.21243779018761652, 0.11796843155377335, 0.11816566088987936, 0.13911295622106523, 0.1707200585834442, 0.1654155432216583, 0.1358017403512232, 0.1606628716352486, 0.20252868803518437, 0.12551169331756332, 0.1596351033977924, 0.11176414592492004, 0.18341617328265022, 0.20667838713815137, 0.22520217864263445, 0.09451891686166487, 0.14089187366827843, 0.19733926972314236, 0.17067459892601738, 0.22321680049982764, 0.14911355991517344, 0.11020719479288786, 0.08499424529051589, 0.08246157393460313, 0.1134479841998508, 0.16600509384466758, 0.15462076681996548, 0.20374483729322113, 0.09653040328093114, 0.10926856854630095, 0.13432723560160206, 0.11818606947218219, 0.10650730421466213, 0.12585038078888772, 0.3214966421646457, 0.16529512952171987, 0.11157166633394458, 0.1334657544089902, 0.1125594217991156, 0.17825969675135228, 0.1489370685791777, 0.20824876013061694, 0.18792945771448075, 0.19795632290263332, 0.2307733385673454, 0.08840979467476569, 0.2448149488097237, 0.13994115855424635, 0.19731858534918678, 0.07896529420489266, 0.11612210603010271, 0.11806115117524901, 0.09874763793402141, 0.13508650534335645, 0.19737834020728068, 0.1375990745521361, 0.19313094957220941, 0.11135778224636471, 0.1761107741584701, 0.1913841005655066, 0.34852762556364464, 0.09131584196321427, 0.13355956953619758, 0.12510478571658173, 0.13687587222985684, 0.1226808069153659, 0.09468542607200724, 0.09480220085430531, 0.16425942461336815, 0.3641679846952039, 0.10622084095713594, 0.19695424925415747, 0.13827860986273136, 0.10534180102929955, 0.1680615496250891, 0.16409240212411652, 0.15297729371776506, 0.09968754354744189, 0.13726801731653754, 0.22798136177082218, 0.10209292173385622, 0.1812943242370121, 0.18813931984045815, 0.10341131308626744, 0.14730289578437805, 0.18480041755303261, 0.14024166420342463, 0.1709018818913929, 0.05584121366301852, 0.1698284241701326, 0.15318948475103225, 0.0929797925956307, 0.212555461292786, 0.10447694138894159, 0.11845305877467317, 0.12959843531491297, 0.06830417716334905, 0.1374563983371181, 0.08628736340230511, 0.19802897868137206, 0.11081118617326983, 0.2748325413032886, 0.15367380553676238, 0.11465455735883406, 0.11728522668202078, 0.16904774993177385, 0.25408271279546524, 0.17340455324419085, 0.06577589549124241, 0.15021524031556424, 0.20373956660830206, 0.09524233368856293, 0.1837289056951, 0.17991610141771455, 0.1859272103155813, 0.15957436794715543, 0.19082494831133276, 0.17248448164712998, 0.1799861371757523, 0.13989019838552322, 0.10381694132041547, 0.22864110136945404, 0.14561128171701587, 0.15555260552754327, 0.15419998536667517, 0.12178118986588334, 0.14934481121599674, 0.12958355788742343, 0.24591096015947483, 0.1745669384517016, 0.1271579396580496, 0.11242551729083063, 0.1579520082281482, 0.11164935531034587, 0.14073597477568736, 0.27522821039442097], [0.002993888126858961, 0.09845424924165973, 0.09614173623342669, 0.025053185696202903, 0.040443355833450635, 0.042715522821151444, 0.026820899107523506, 0.046873510995459174, 0.04366475172461041, 0.08626905390091481, 0.026942438956710602, 0.012615500224543916, 0.028928690439751072, 0.0626537692733109, 0.027896928968989564, 0.013077191730600693, 0.010387848690903236, 0.01742746222824339, 0.06081888910322901, 0.06761106677473554, 0.04369881199372392, 0.00474968240709014, 0.043708610258275465, 0.004984039715641449, 0.02558125776328868, 0.06807563015289846, 0.06670645483198666, 0.07551268914774542, 0.025613766704355518, 0.05345881811433262, 0.042859585655312386, 0.02883504959754646, 0.008858609831921996, 0.043824170791213556, 0.025277517307850144, 0.03274963440133199, 0.06506342606078233, 0.01421568648619277, 0.08252452337934126, 0.0460975979935498, 0.07746156320096025, 0.034288934867588744, 0.03809728434369449, 0.04055931473210935, 0.0410576549268538, 0.014991254748536215, 0.04057806473405611, 0.050334631119884794, 0.009587986822870952, 0.0804474828163943, 0.03864326754644994, 0.05744866531101927, 0.0037426605488308858, 0.051955585067550984, 0.015891269206129495, 0.06769706780511527, 0.044826301896283706, 0.03501600593388562, 0.07212796714156866, 0.04624996905124957, 0.08142429854600661, 0.026971866309102026, 0.038734619700980764, 0.027653046793514685, 0.05481888464982471, 0.02486971146877735, 0.03633552726598517, 0.010354611966308328, 0.06790588805151564, 0.04780488621984278, 0.015569363848396368, 0.05175338765125602, 0.023681704450639027, 0.04549046182223866, 0.07813662455807771, 0.04271528533389492, 0.01823451287383514, 0.06137545964109802, 0.05303417174746433, 0.09201093651955167, 0.007960751433030613, 0.0465549792974226, 0.1012222015208775, 0.018607032703115575, 0.03196389440657391, 0.10117703297686192, 0.04033622226767963, 0.04243130803168301, 0.037715558052784016, 0.01369491906746501, 0.05448525718924019, 0.05177257815375925, 0.011673976250383402, 0.016481067850104263, 0.018255225976087877, 0.02837374592350135, 0.01831374360218404, 0.03902560287726022, 0.0395706782658254, 0.0459059534384118, 0.08369213330649561, 0.037970500622665694, 0.04819661378860474, 0.009756027251451967, 0.05885814068718784, 0.020661037002179413, 0.024382515938111374, 0.02251273471741907, 0.021977980448413762, 0.07484542656569712, 0.04682373826301867, 0.05509616251313879, 0.048679808425086166, 0.06338074840905686, 0.04557472000259065, 0.09541644249111415, 0.023906905572080327, 0.03912471167202439, 0.017990450667698058, 0.03477035218008584, 0.05914328627348427, 0.007345200743481157, 0.01829047176626421, 0.03778376669112233, 0.046357711656920375, 0.019907290754359097, 0.03075945480245977, 0.0513051113023633, 0.06813887837192706, 0.016627993937882207, 0.05176252324975306, 0.003598022430519303, 0.08535716412288528, 0.05318610230460764, 0.038517383978732174, 0.03745477023204008, 0.046332752512347315, 0.052191333304489815, 0.025793619251119036, 0.07560278874852004, 0.022140174668522614, 0.02943672547717729, 0.01506070061887224, 0.020736427714807854, 0.038715513468149214, 0.05400156459560799, 0.0626195672779314, 0.10329777119500984, 0.006191033744178112, 0.02840922920093421, 0.10612141806632282, 0.05748433436477377, 0.04576816103391109, 0.04775003049402468, 0.038575867130871744, 0.02076566929087764, 0.08999172793400866, 0.06097334775052244, 0.01322191914603595, 0.005753815395667428, 0.06321122847317208, 0.015565522875066008, 0.003792120382234815, 0.0065149151299509316, 0.038325069096660426, 0.017075804888360926, 0.01962836580200782, 0.08844138047988377, 0.010867079779986414, 0.015160505596037595, 0.021554404689419656, 0.052453986549329375, 0.07323902445815264, 0.028508598465592633, 0.04642761718001097, 0.027318503857860645, 0.04478610143245709, 0.0557264690137198, 0.07524324836389673, 0.027533872240793802, 0.06631158247229553, 0.012663369228492581, 0.04212059043047409, 0.03580655504558836, 0.06799451676347563, 0.07639075614391796, 0.0539126715833141, 0.006452376021057248, 0.03181138353782796, 0.04823914315972117, 0.024260642840677214, 0.023026419653286858, 0.01768907359350593, 0.031192099127257546, 0.03445240653931134, 0.026433316074431907, 0.03390332068046255, 0.016677575148341638, 0.03653156916580854, 0.007767122710168723, 0.06720337776407119, 0.07404339379600941, 0.06700258611911727, 0.057452580020312345, 0.026126867498181043, 0.03824117097763285, 0.03789248222845697, 0.03731637644851881, 0.005845064607133428, 0.08376531002502288, 0.04518562777628822, 0.10841701585318773, 0.05470016017375935, 0.09364202198001648, 0.07806504130243294, 0.04722398472949863, 0.02940698019829729, 0.020520888877311544, 0.045885020085880836, 0.0861171922916847, 0.03626454155892134, 0.026531273822089838, 0.08230270262086585, 0.06835554335867206, 0.012214475221210911, 0.07770962247084226, 0.04162550227896821, 0.023693213006481532, 0.008648649072124353, 0.010088813930539595, 0.013663379227622383, 0.021001750776063532, 0.029685349736903465, 0.03547557441878223, 0.016679427165898587, 0.013309324990146825, 0.05005904248044376, 0.06699168468795477, 0.01286336893005477, 0.03149214320846143, 0.014272512973196084, 0.04182596833655431, 0.023881278015793334, 0.0659075630227885, 0.024791168304340496, 0.07366441009986786, 0.013030466112879016, 0.029142287244359334, 0.01673397645654698, 0.07559715034139734, 0.10634149214433086, 0.023326477141029412, 0.03554451850152785, 0.049457203807129015, 0.0305935699537757, 0.03234804345054492, 0.015476835748901772, 0.10692821590289955, 0.1482692850573409, 0.04906081076290819, 0.07255470109803062, 0.08821995042624974, 0.0765774824145821, 0.014996035137183726, 0.02174782465332218, 0.060251390321120146, 0.07562459161084506, 0.023396011111476732, 0.04011639716824697, 0.025156762698785435, 0.05387221064959323, 0.03199010418968336, 0.027885163773692427, 0.011683481486303913, 0.0931216644183282, 0.010399951922496962, 0.0521277594980934, 0.04270163364708424, 0.005763922489413451, 0.046681184622068564, 0.031154692969134742, 0.07404383046612625, 0.017244022474774433, 0.01963629289680431, 0.050884306866435275, 0.04954371428597839, 0.049715042189364476, 0.011933104533161367, 0.0023896530347560807, 0.020458874059841037, 0.010557857007839748, 0.048867250987959486, 0.04415610519748542, 0.050766677896101634, 0.054504030173824686, 0.024884315019833948, 0.008346081688819874, 0.02265301307723407, 0.032791857337278706, 0.05320929944695485, 0.06219837979804124, 0.025834235317644574, 0.07538823816444605, 0.05551957930888861, 0.07148042366269135, 0.032409376449762814, 0.0899757550007874, 0.04030410403145417, 0.04020802128399092, 0.02400538234430696, 0.010409618036881571, 0.04057801876878066, 0.034384209392291885, 0.049997920155405044, 0.019302703740616, 0.08780263935125644, 0.03319181269034743, 0.035416662257405064, 0.01354292818089767, 0.06759134767156455, 0.046130708313637206, 0.051921271989422466, 0.02317602896401959, 0.04972410117906909, 0.019995553659335263, 0.006032596227727951, 0.0738589964326351, 0.020678519128611492, 0.010035869594092571, 0.011695566523309437, 0.01551866127673777, 0.07805719656208832, 0.024672744517785408, 0.03076991381784601, 0.014218546866980052, 0.02871049902281694, 0.04485911727252026, 0.014221872646181334, 0.029930597464103374, 0.040316093307469165, 0.03404743714077819, 0.02536256264354433, 0.043967429233054, 0.036957789843361226, 0.018121926677263072, 0.09009295113144383, 0.016553137571580948, 0.024213863596800837, 0.044649488803359776, 0.0054864507100935425, 0.03857192560850132, 0.0738994075706409, 0.14757386108319606, 0.1772229806069405, 0.19448105696468584, 0.21173986876683853, 0.12116333229407189, 0.08863753729289578, 0.12549244152802613, 0.13618709789889474, 0.2841739723038289, 0.13922307369930131, 0.1763225361824997, 0.17924275609754747, 0.10449820032884037, 0.16151845395084352, 0.12184190233388256, 0.10119811571653813, 0.09386876102296576, 0.10972567022808137, 0.06606638837125033, 0.10707785585714925, 0.141956506056651, 0.09480384028246326, 0.17748292956140735, 0.1361007904333453, 0.14878968858430464, 0.13673082114227358, 0.21212898014533907, 0.23770444245348055, 0.12466882040063221, 0.1048674623692228, 0.15194934161920703, 0.10823510061468809, 0.16507454216480255, 0.18445105081604374, 0.15677382628763878, 0.2136063347420385, 0.1453476248969955, 0.15511682407269556, 0.1772227661023217, 0.09867607766101438, 0.245296971331681, 0.12254716287697516, 0.18714208786766376, 0.18549147482600906, 0.11481705992933243, 0.11694765003818659, 0.13120401770837847, 0.1840253051130041, 0.15854938826974363, 0.14152064799301087, 0.13605284865104383, 0.12770891009319213, 0.11676555859946436, 0.13965114830963074, 0.14639909589482894, 0.24904557744101172, 0.21263867376312134, 0.12708005149878804, 0.1199303750669764, 0.140418553905141, 0.18394296598290244, 0.0899316206754696, 0.13313892597873367, 0.13868397762698514, 0.1537368086076552, 0.18241819054369005, 0.12815994435861228, 0.19718631260818054, 0.09929615688780624, 0.21516351570044795, 0.11982584236970834, 0.1404135283683577, 0.1749358710742766, 0.2469107508659363, 0.19588851369917396, 0.1392573637947921, 0.14119317604889794, 0.2129617636843074, 0.13100299623704728, 0.1391358775717597, 0.2743780060160545, 0.2786326131993725, 0.2869968224437006, 0.1722178677277219, 0.19513312036231642, 0.25031190545808885, 0.22983019240200522, 0.1254835549081045, 0.07556358036855537, 0.19938743643222318, 0.15745129316083847, 0.1603256703744973, 0.13634298146972734, 0.11194939364589031, 0.12057342160973819, 0.08676245282854765, 0.15081456622048733, 0.10273138707083079, 0.22877133631658172, 0.15677122158869622, 0.14286926917491422, 0.3107152110145938, 0.1226719509389612, 0.14923536789513406, 0.16088960301731864, 0.17411123871082262, 0.08950730755684838, 0.0684044810552751, 0.17218777579405617, 0.19358764522738997, 0.13181665822142555, 0.09498577084272139, 0.11424748121850914, 0.10197704327442955, 0.10257589420483959, 0.2200285723853496, 0.11978798230449039, 0.08891185805682214, 0.11644583946514515, 0.12256812304258348, 0.15825766198817762, 0.10378130291017795, 0.18206033555250015, 0.12776888711678405, 0.16736888356747168, 0.11443324987926792, 0.1708760034413107, 0.15433930611658483, 0.20397938277211883, 0.09418851846168119, 0.16418937353357194, 0.1081734994846967, 0.24924109840104658, 0.1690361973258757, 0.1211735365852233, 0.1747804471561986, 0.22136447650770988, 0.1540007412193283, 0.09826543155096232, 0.141177655107552, 0.15022066421806812, 0.13787584679742015, 0.11254249891686825, 0.11598866883545153, 0.21468547683569694, 0.1878509183804835, 0.2368224760697734, 0.18169328750621888, 0.10822478907122728, 0.13708792536729766, 0.1665082450715765, 0.12078024236665619, 0.14071705240395763, 0.1516207052214492, 0.10484709209131618, 0.2000005672415418, 0.12914287346986034, 0.11945412118708897, 0.11155530269588194, 0.10804930131041235, 0.3751579143347279, 0.13916040770709515, 0.2428888045852223, 0.12506584546739055, 0.15376809563848282, 0.1078036705392503, 0.1842872458960741, 0.16655215723139627, 0.16320386270601905, 0.11352529779316918, 0.15639809080429617, 0.13583137263213435, 0.13647336963443987, 0.11224619142951504, 0.08538264420724685, 0.10212350396379348], [0.013591831403544113, 0.012347718021051298, 0.0957682607094607, 0.012587461406515251, 0.0514883442120927, 0.035317549632201274, 0.04547446207594007, 0.03715927096744699, 0.05988654477762119, 0.050173526659848235, 0.04078856654345028, 0.025077225535266826, 0.017856350806992383, 0.06355754618022232, 0.013530931244003437, 0.036158281333384015, 0.012380051719505462, 0.04037257697012636, 0.04221061342245629, 0.04705349186195001, 0.026595027659148462, 0.038192899777523936, 0.01883244258351624, 0.0416717280243193, 0.029674505762335275, 0.02559183743752299, 0.012477157194347633, 0.07562056198836335, 0.047807176822736386, 0.00723286544070429, 0.059343959174809925, 0.06758153408525452, 0.07531214265092727, 0.06908769358790691, 0.005934123764745892, 0.06087973946705461, 0.023655745561324784, 0.01983898252459063, 0.05186064379109491, 0.03245349928376175, 0.026999995142461795, 0.03959166907495068, 0.015126324668076011, 0.055622304038655375, 0.044573466068193804, 0.04022548808866451, 0.0334495629724716, 0.06391967594202969, 0.036035607674068985, 0.050028146154457526, 0.06552650322837215, 0.03604491181190937, 0.022567699610766385, 0.07260988241121655, 0.03682691904325639, 0.01716349514261369, 0.02414689602089986, 0.040118174492231304, 0.032379334311812155, 0.06915395253247793, 0.036917823036351514, 0.039693037829091476, 0.011641242270988804, 0.04797791100798115, 0.03709310395342689, 0.03923453037596999, 0.06365024281906025, 0.049159858270638415, 0.16132494014117027, 0.07314599074062801, 0.08814330332942548, 0.06440243007795465, 0.052752852770349676, 0.031442918228886785, 0.018594076241096182, 0.027324713000486937, 0.007827960625065552, 0.10364392036271673, 0.04188066318390831, 0.024925551617578156, 0.0403458979581633, 0.012511453035497859, 0.06414339659855732, 0.5268291047503871, 0.47290307259367365, 0.182338931087044, 0.055790674842653744, 0.021221489690604712, 0.03403046829325538, 0.07959019212472825, 0.03794319724904434, 0.09859106488405697, 0.02040086779743433, 0.06627697828075578, 0.10019014319104534, 0.09774013272216243, 0.06198688590478513, 0.04316987424728371, 0.03635382144561699, 0.037914671965183756, 0.05072567303995452, 0.0466099422755501, 0.05702422578789054, 0.03553632519117767, 0.03479404344914421, 0.042308140245656815, 0.04139793203062108, 0.039285436918538426, 0.033132812428858974, 0.012682111569560103, 0.04286812753566811, 0.06455190149286101, 0.09520984389969418, 0.03997278249552173, 0.056833132816058014, 0.07729147636001149, 0.06570372234789595, 0.05918134935200215, 0.031415275861358935, 0.08437637239694597, 0.09052373003214599, 0.05613330766678818, 0.06795331655490784, 0.054965261069516984, 0.03069501914714854, 0.08578842565897973, 0.03194433618186703, 0.09670894007168471, 0.015585966888935337, 0.0009847100262695384, 0.05347193737003592, 0.042945969729654254, 0.09415019108282943, 0.013254856138730483, 0.023781774685748165, 0.07798437224400621, 0.054526779154736194, 0.05295477822543152, 0.11284963122659153, 0.01603216426672354, 0.03443881996997422, 0.04222090964415862, 0.07161877914181641, 0.014576747555345779, 0.01852392940030944, 0.039037189957114964, 0.01880643772892654, 0.15368690564026757, 0.013796059910448329, 0.03965482536342837, 0.0551877444940469, 0.02954930975852955, 0.05552202312936706, 0.017797909789688645, 0.06367004236146327, 0.018174717796125242, 0.010412584712368347, 0.06962250722872634, 0.06284868502388559, 0.02583164977090013, 0.04691394894654232, 0.05478266018232512, 0.00852152061152963, 0.06549533111073318, 0.06331522873933278, 0.05266189898153948, 0.09939516609114024, 0.040526219733780434, 0.01576482926705672, 0.02715622536808012, 0.050393064476309285, 0.05934163409795973, 0.02984233455912721, 0.01297763764723054, 0.034693977044474696, 0.04174497752119938, 0.09555584751069547, 0.014556035410702951, 0.007263091439756775, 0.05292994548536597, 0.07450583511062207, 0.027103813462740472, 0.026154306852408958, 0.10097720660269262, 0.08784413067323547, 0.0472037025517033, 0.014596891837314734, 0.03855195369631533, 0.03501980956042967, 0.07383736210965341, 0.017627330737248544, 0.10569255438543136, 0.030240334472769213, 0.06825878645383543, 0.01956420593834933, 0.020379562892260093, 0.06370498746212933, 0.054721786835861784, 0.02596325984585189, 0.07412158839044071, 0.07332316389487636, 0.08265619857176658, 0.038100996039687626, 0.08330528954825095, 0.03487904856522237, 0.01628272960172786, 0.08897817828842709, 0.11297556075958476, 0.02558287612402872, 0.04251839307647559, 0.02318475853591677, 0.06083007398692351, 0.0425350746410268, 0.04327653283854166, 0.05241813363447305, 0.03114436801913525, 0.07612087868995245, 0.002433193402530085, 0.01937079746576567, 0.0294984185377196, 0.05135745809022939, 0.0792961675793894, 0.07283557957458882, 0.0234724628558803, 0.033452048927785895, 0.03151122454343544, 0.09307047442322777, 0.020338874047381744, 0.06212389689960307, 0.05603840469472832, 0.0012624380859403662, 0.009846056946703504, 0.01252586410696348, 0.09061791288155703, 0.010810442899744357, 0.06494346435271925, 0.019024609993662567, 0.06344365571895916, 0.011842202455286058, 0.11629292065457952, 0.06790612553877216, 0.03100422180948719, 0.04544595211383797, 0.010028025811357845, 0.17619878233921143, 0.09782716797123994, 0.0049784918026548, 0.011867639447201886, 0.06167866191976975, 0.028576561955795176, 0.030513234143596024, 0.012994703213353793, 0.013148567184896, 0.055847790527848475, 0.034718062848814076, 0.028775273672034665, 0.16414184543874957, 0.008690747518783376, 0.06733123017775436, 0.4674497216699585, 0.30378291203129676, 0.06957183817341443, 0.055517135488410155, 0.10207897127275506, 0.024591830311222904, 0.031399023306045326, 0.0397026177585846, 0.030328863593299064, 0.041208558926178564, 0.021268238290964116, 0.19753715023398402, 0.02616835498972045, 0.025424253788866827, 0.03776098323625423, 0.05676266038790346, 0.013647441725967633, 0.019475527430674242, 0.011315670224928088, 0.026513946828462427, 0.04399662101340871, 0.016229450101813963, 0.062310810861808646, 0.026457836633668314, 0.07789375936432232, 0.05312346312547884, 0.026210643043140733, 0.04192219281028356, 0.1017279038205743, 0.04902318435450716, 0.026144246202743342, 0.038998931526176395, 0.08954829326079738, 0.09272673077160314, 0.040559544558486635, 0.07146247422262546, 0.06990461144596338, 0.06758629915214355, 0.08728769803119284, 0.022905280085040197, 0.005645758215142715, 0.014916147488439757, 0.05991321612870502, 0.06562211100132236, 0.03515026284261577, 0.039166256620158116, 0.008007356391904216, 0.02942051888713914, 0.0613284946209, 0.08027450782397101, 0.040336061389215534, 0.04554287755801793, 0.11190668424411167, 0.021082193838552605, 0.04789903842573685, 0.05206149672308276, 0.038164520050368966, 0.05028654761131733, 0.03826906040851628, 0.01836785047705616, 0.01704312166229131, 0.03220593414059089, 0.031229187358891776, 0.050563143656378796, 0.04204637566280942, 0.03245190965131887, 0.031327627741942005, 0.042124340430863445, 0.0401053961456543, 0.04530307288552004, 0.024042457169402513, 0.07258781907899726, 0.02606311174590261, 0.039401870791710196, 0.014030209896455129, 0.12740270474985724, 0.01999274594709277, 0.02984135779702375, 0.009691239195695568, 0.048690330642726154, 0.0813960375624799, 0.053816542870575385, 0.006984019973089979, 0.02670586334481355, 0.055346263407339016, 0.036510854148336, 0.03483093824357756, 0.00706101420350493, 0.04009834813675092, 0.022215373859169985, 0.07123425662998231, 0.024505467304298957, 0.09362585752481416, 0.2880542382838265, 0.17425895578438239, 0.16068442934943786, 0.10206300600041306, 0.2003616091584967, 0.12887825137905537, 0.09859958378177497, 0.23318505996177274, 0.24002228743366658, 0.1938638046023346, 0.09154193749230716, 0.1558392909505675, 0.10477610638425236, 0.21073678388230263, 0.057100849902077075, 0.17994266934692862, 0.14497878420497143, 0.16401645216730334, 0.11763982579953249, 0.13223840494550046, 0.23609835444198501, 0.13723607145009503, 0.12692037579273024, 0.1491897396983639, 0.12016413913619135, 0.123944514911742, 0.14672762504027737, 0.22348522238673704, 0.10906453634942732, 0.09620126892602253, 0.1301125569208976, 0.17285604961216453, 0.10213375422022036, 0.12057747421485764, 0.1534550721126218, 0.1542939690332259, 0.20938085422160166, 0.1688748745307807, 0.13636547381118422, 0.12828334580145537, 0.11033624996461215, 0.10123393032699825, 0.10336789122271924, 0.1736800384617621, 0.13904891127059538, 0.14976156304680532, 0.19335417227158624, 0.13328480444127513, 0.14571317141094517, 0.15361357570415543, 0.2002302557229996, 0.19749879987249452, 0.12874910427678016, 0.14057872756834955, 0.07626839658065189, 0.11075195225496447, 0.1432633294814056, 0.153786527713941, 0.12319145814305353, 0.21671985396214072, 0.09726528844405567, 0.11175764949932215, 0.306123984797347, 0.1722848391340625, 0.12999773566280642, 0.2226614940070337, 0.16879022181514772, 0.15455442360572277, 0.2754182921301934, 0.30480934727576475, 0.17688211744591115, 0.18694958529405056, 0.092373916638955, 0.136298073395606, 0.11052710544918815, 0.1505066908054775, 0.08963273147181158, 0.10776106838978107, 0.1501947091591935, 0.23715026977081455, 0.34580758442321136, 0.12560943847582226, 0.27741376731184225, 0.9675204477483227, 0.8547486280722003, 0.403845455617674, 0.23931964691127502, 0.3029179068342332, 0.15778392853756107, 0.19916303395744295, 0.12183912143471742, 0.11625352075263379, 0.15995686032599019, 0.17142216284428874, 0.3378459084178171, 0.17021615659036946, 0.11780976708377562, 0.22622228600084784, 0.13873103074729443, 0.1234042160813847, 0.13525486082559632, 0.10068223210832766, 0.17725253627905924, 0.10626667599764564, 0.13467223563742253, 0.1705234957438323, 0.09974437194966501, 0.22544075374401387, 0.12289996168786481, 0.0769825897089416, 0.21840527803907472, 0.16471232047244427, 0.21281456755053615, 0.17517418570576176, 0.13731343100868887, 0.2103751444167668, 0.2709376583656957, 0.13139166328455174, 0.11170085174061599, 0.21599124305911604, 0.17754351179445946, 0.14245087791594768, 0.1556406137082846, 0.20988273374255628, 0.1304383434715771, 0.16462475662269901, 0.14407896797262854, 0.23575664858423898, 0.18778155677981917, 0.11460918197107893, 0.1513372526894654, 0.13716908472199596, 0.18380425810333223, 0.0965906024700211, 0.16958552833286025, 0.21062539469811226, 0.15754285598954848, 0.08398698522679268, 0.17167506378985223, 0.12779123390153532, 0.09131598751991989, 0.1450019200602847, 0.19346127136340066, 0.10889415839506734, 0.23122701583610428, 0.16016568057239056, 0.19025821178670854, 0.2910545450304785, 0.11913503790574691, 0.23776905430901438, 0.10068367235362531, 0.11595626331625447, 0.16755023190090734, 0.11724909031463247, 0.184112194805376, 0.09865879471744261, 0.08957663085311653, 0.16926940981178515, 0.26635369466197106, 0.15572719696548679, 0.14330868188652301, 0.13954553542838943, 0.09506877646931718, 0.1768909887440743, 0.16154151319736437, 0.1694386539560172, 0.16736152912339858, 0.19038300750957382, 0.15566097632531198, 0.13332742957338212, 0.1524115684292009, 0.2712009474635124, 0.1780775210429584, 0.17500894054049448, 0.0906834287208415, 0.18088023839218004], [0.05144369660786564, 0.056473109796042406, 0.01999515912405426, 0.03249492931870684, 0.0424214446496579, 0.04601959875153919, 0.13113992679263317, 0.016862211914192286, 0.036520809460912025, 0.03290673988240381, 0.04910339759061894, 0.05208523778785622, 0.05314851803104243, 0.027936708084457827, 0.03951278883182714, 0.057571427070445595, 0.09929909866543547, 0.037279320775621363, 0.08079864219912598, 0.018156890930127234, 0.012176163164117645, 0.0340313492943683, 0.02279550734637005, 0.08598945479119018, 0.04239790659818438, 0.016794660196249044, 0.05958043902571644, 0.016571280448847724, 0.027554905184754924, 0.07811977828462278, 0.04419526761217464, 0.0012516609046630742, 0.03460939327675489, 0.020183455874963153, 0.035471073652227084, 0.02154832961218011, 0.05056937578164282, 0.03035017998979217, 0.008359403000213206, 0.03725356106916743, 0.06174846402099056, 0.011578947831425938, 0.0510925448860132, 0.016189086844303435, 0.03319949655222797, 0.01738834386360982, 0.0719488940892681, 0.03377031249504897, 0.01763374289317477, 0.004431509333963116, 0.03455235803079221, 0.09574594456822642, 0.07924973499029875, 0.06302573943450566, 0.04118516260097104, 0.04734700695881921, 0.08153711265373616, 0.02711745940389172, 0.06757019598397516, 0.0416058482932708, 0.07357052602474728, 0.011709372385314876, 0.10660538645160776, 0.030149712016986265, 0.049599780430716854, 0.07149039812746548, 0.02835577158557792, 0.0274944436105509, 0.42118662187168676, 0.17037499726058977, 0.19472533176022191, 0.32650048333791, 0.3281613006707161, 1.0748771289663932, 0.7665058405649278, 0.7260899834575192, 0.6286553665995598, 1.1630402433295404, 2.8302724899784213, 6.189525137024542, 14.884891759964729, 25.330776399181737, 37.23679373341222, 38.12240216039842, 41.02433635342506, 35.69265073345554, 11.959204673767092, 8.369626037536129, 7.418267899943937, 6.937433365852603, 2.8064154088497166, 1.423578166192578, 1.4093900952608356, 0.7199077764826437, 2.630634879873645, 1.928197340138497, 1.5104549882873413, 1.0089474183417138, 0.7192402381089427, 0.24571916238675195, 0.04916699054921347, 0.04018472071977393, 0.0752211926925567, 0.01209124519054087, 0.03508688438864004, 0.05073350628898029, 0.10727226598969392, 0.07486215026508417, 0.07029006092418587, 0.0050278345682478005, 0.08312339729238903, 0.045595599728966915, 0.006693502674029479, 0.01238520940645568, 0.018992461113920136, 0.043817122782310175, 0.0350844252464031, 0.08051508241483281, 0.03579753819071958, 0.054238327899046486, 0.020098764854933948, 0.021372054696022984, 0.04671944305300713, 0.06438680188429934, 0.016606650728311752, 0.03581015182839286, 0.01949422380646631, 0.0881183058804562, 0.05395238941174842, 0.027734696444484497, 0.029207954386008844, 0.01359082112509397, 0.03302891558456806, 0.05424691957511729, 0.0308242486038756, 0.05467445792389974, 0.03269067244423974, 0.01874767878513423, 0.024325155104780873, 0.048296576771404476, 0.05196581234134013, 0.04879882784500238, 0.061810911678138285, 0.03872115570571154, 0.015486255757540706, 0.04297360252108305, 0.005911341746292648, 0.03906987892884401, 0.005780684493196708, 0.041845928757421436, 0.067550944194438, 0.05882917873321041, 0.003418341535331321, 0.036559657779552286, 0.029666546108802, 0.03359516947379997, 0.07907622373632847, 0.05377843382678205, 0.02745421441842712, 0.04898098823163779, 0.07481962472440735, 0.08616895685272832, 0.07029630454076875, 0.06481485351199104, 0.01444337547816817, 0.03684240551064572, 0.03642917002340959, 0.03659011360498206, 0.03165889373649994, 0.0024540187845442205, 0.04685325180030158, 0.07766005658214131, 0.051707395562721845, 0.010877952482851764, 0.08186843035922897, 0.020884083501333674, 0.017908304974797274, 0.021494906470780412, 0.029628814363311377, 0.0071433667401452705, 0.0657971544311412, 0.023441951489076022, 0.053184761650740146, 0.02748554166887076, 0.05075269679148352, 0.0145651183406552, 0.039836732941048766, 0.02821119930294733, 0.025055644838439844, 0.06766424859843909, 0.0390206769319071, 0.02082857660077993, 0.03001891591045405, 0.0415058201929975, 0.06557059924929373, 0.010342489582516495, 0.007395382375351244, 0.023197496662877744, 0.024668416121013226, 0.022355219379307765, 0.0431000376721063, 0.03560367581104079, 0.03568227260163234, 0.026681304481180928, 0.055542132937379425, 0.041991274788855545, 0.04290475419932797, 0.028012774869679447, 0.09551073259283459, 0.014999281434762864, 0.022743248658615257, 0.013787253729758725, 0.0649757779413654, 0.02035577011655175, 0.03990260501121802, 0.006740985282381336, 0.09624315861372218, 0.08783162045743197, 0.009909728429310266, 0.02764770333024283, 0.03990122988339394, 0.04174235750049834, 0.029519281027117567, 0.007625656435266138, 0.01183412405812452, 0.03233163384720683, 0.05064222308236265, 0.013712185731668387, 0.01936153546276112, 0.04155516008576078, 0.016098755501931714, 0.07698031442780649, 0.03307398070671386, 0.045197494478235324, 0.06298317941987226, 0.08654032563490253, 0.009673522454836677, 0.04319198354477844, 0.10675905602833918, 0.09143684555085436, 0.04746309609242505, 0.031521499697719856, 0.027037091034975265, 0.05302841842715299, 0.3765840329710515, 0.0999684067022416, 0.1283718136349513, 0.19411627653866045, 0.23692522378217792, 0.6900731870724309, 0.39136474952101713, 0.5124429541249429, 0.6799003974564615, 1.3565931541304435, 3.1107687805929496, 6.266724246163522, 17.260782180293916, 27.74738592486228, 42.33279197446762, 44.92272907687772, 43.7355923652649, 40.562002658843994, 13.942051049201721, 8.853807333976992, 7.325448441889979, 6.212696538817498, 2.963465149364164, 1.1620488642684876, 1.2973570294918553, 1.2164957749266778, 3.0560990302793445, 2.2191118136529, 1.582953872219209, 0.9097181945558518, 0.6029683159243676, 0.11818668234252161, 0.03109555481181991, 0.054232448174227635, 0.030797876027082245, 0.04519689309921476, 0.05383365727480381, 0.023907865097205487, 0.04327475168411771, 0.0445181277069834, 0.03769436039991918, 0.05675602989691881, 0.10318275075405837, 0.01036361828746815, 0.03377276014596705, 0.02397031275435321, 0.011110311738335559, 0.058430338038071516, 0.029381178357007525, 0.06511817836473066, 0.03901843229428895, 0.04363283650168488, 0.018644854463937304, 0.04724667625381582, 0.04919797497531099, 0.009520426486438562, 0.04784371921672456, 0.04439305236202575, 0.05791699784176965, 0.052067219399877136, 0.03913088251025446, 0.006926765434458973, 0.056756026066479184, 0.08035641794483508, 0.07979334332048893, 0.04976820486086992, 0.037341036818801396, 0.06418851917729744, 0.03415737458835206, 0.03123753580204662, 0.019628400275964412, 0.03279571842041708, 0.004697181444029294, 0.02571834728211886, 0.02263541986805297, 0.06889662359871211, 0.02457353613159109, 0.03881657578712029, 0.07279830173619332, 0.06596125812540132, 0.0646048917945835, 0.03893961716863898, 0.060751481026771574, 0.028722495959711172, 0.011156133372306584, 0.1401286049475593, 0.02988267866443963, 0.028419063854662162, 0.07043436890648258, 0.011042184496839202, 0.05517239592248394, 0.040693303510066, 0.07485520950849019, 0.0664373051615492, 0.040868572935822516, 0.035220256465817654, 0.04015495820391563, 0.06920380187371085, 0.017469777094741023, 0.08788446520244883, 0.10149418571663481, 0.0390128743263983, 0.05213083534110939, 0.02942571296326576, 0.027865143981011167, 0.036880376658612685, 0.014442262735458152, 0.06853747391893018, 0.17734537081372354, 0.12170229047056168, 0.08824307862068377, 0.24000356424479719, 0.15020708914004988, 0.10981013142173329, 0.15470135926959977, 0.06506357161748795, 0.16436132962905592, 0.11113511879117259, 0.1460418997392539, 0.08633295329467905, 0.12894805731071582, 0.14378895772801292, 0.06630469534185625, 0.1548008894127223, 0.1968716190106446, 0.18524828787532546, 0.15147334054833458, 0.12909028919473772, 0.11440268297108913, 0.18008286343707194, 0.09486556398652254, 0.21007739668411596, 0.13968646496294007, 0.148588084886151, 0.08271636711733957, 0.09342181000618205, 0.1482892033433722, 0.09624105953280965, 0.1780160807914311, 0.11344010881598919, 0.09152601052436138, 0.11899436884109052, 0.0859109461007099, 0.0995166982794481, 0.0967281075915502, 0.187451679319624, 0.17799430857262305, 0.0657546135687059, 0.21013673785473072, 0.13761923798630316, 0.14650417251452325, 0.1306219900687856, 0.10643969695534437, 0.13081118314256593, 0.12395096537206443, 0.17325112115471594, 0.07152942264632833, 0.12389573043272381, 0.13797074976948, 0.19325618962607077, 0.1352739670584279, 0.1682791952043772, 0.1315084916930045, 0.18249490658842749, 0.1871561225984366, 0.11560501200297188, 0.16377600781138868, 0.219939767473167, 0.17853683671884, 0.18049943140677868, 0.22938477356107007, 0.21698525746262845, 0.06958699905343595, 0.17094600855583147, 0.23883949364385298, 0.17200581459028108, 0.7131943334975551, 0.4259574803854189, 0.6680833380068503, 0.6792617252757472, 1.2873739845329717, 1.5050971532060256, 1.0268466643268064, 0.9965881525028137, 1.1972374276768778, 2.2913586853011965, 5.03698569151663, 10.65102263804405, 25.931332457450132, 37.83059743142898, 57.99392961686658, 60.729778889686834, 60.12289408714541, 52.49816340784873, 21.19025576499201, 14.765990991746227, 12.755905716649949, 10.43269665010514, 6.006678948479315, 3.51301642194871, 2.1024303715075217, 3.4401620732199762, 5.424913985113944, 4.742858919405169, 3.6337109390766393, 1.8421362484655075, 0.9240762144327165, 0.3634746138366961, 0.11385134481374296, 0.13922566307648537, 0.12261578137235296, 0.08985203180101611, 0.1272393135173667, 0.10172837879508735, 0.25046544479987315, 0.1921986052466016, 0.13021577960781514, 0.10673835633262511, 0.20061213523149493, 0.2094116969214332, 0.07810191311422857, 0.16771290301074906, 0.20879685007516416, 0.2967301533827859, 0.11240465671665247, 0.30046572067564536, 0.1450077729720262, 0.1515552047039232, 0.13874318090177354, 0.19543213980092158, 0.14938015851282305, 0.16694580385040853, 0.1581266149878502, 0.10870334121488756, 0.10181146869135481, 0.25269719681912856, 0.1544882642525819, 0.12728792945704154, 0.17107788293111711, 0.21075520063600234, 0.12169552591419029, 0.15943647212078496, 0.14102422301807713, 0.1565817220797462, 0.12029029849556186, 0.1602390105085027, 0.11854918748741189, 0.1981950358998391, 0.1461381510260605, 0.15826509304104314, 0.16707482837861584, 0.16606434308473142, 0.14634068935148178, 0.25745285614844293, 0.10626879040031664, 0.16870440464586983, 0.09905116196962134, 0.10944381881985935, 0.13225605561127587, 0.13895071412046112, 0.10727173738902616, 0.24750333519712572, 0.17732850155763089, 0.16565747378814608, 0.18759101539129214, 0.16395766257999406, 0.10646382872495921, 0.15129864185808167, 0.137831260480227, 0.12437839646853747, 0.2458615934536342, 0.1627646032119951, 0.18734661802168817, 0.12183034972798441, 0.1292634403873836, 0.272032949592798, 0.21877856204105964, 0.12894323095679283, 0.14333471355419006, 0.23777473868141252, 0.1643136329948902, 0.28149404352711094, 0.18658140343764137, 0.1885291513416075], [0.0029773403882920263, 0.006266293264249521, 0.04062421770105439, 0.06807445803837431, 0.03739846276960546, 0.01574429906829591, 0.08812260363371142, 0.11466859975048613, 0.08065110132578882, 0.08727370160481623, 0.05543099656220406, 0.07948769722133875, 0.03365475196211088, 0.06746269086556089, 0.021817843174381603, 0.07200802841614332, 0.02181237139138243, 0.09117351048776219, 0.08068739091076198, 0.033046746281005686, 0.1358663675285155, 0.014174886558565402, 0.0654881758495204, 0.03545260327237268, 0.023682790380271695, 0.012778223045320522, 0.04905472419434979, 0.04383459724786301, 0.017261920203905434, 0.023794305968969583, 0.012136165713590961, 0.05199117751251306, 0.041849916245067315, 0.019360574022416147, 0.026174169597065738, 0.03653867846174586, 0.11059760852085967, 0.07169389406279211, 0.007268520609115161, 0.055094427323990294, 0.023706933641205394, 0.02587721285019671, 0.08843390346174279, 0.11020176322950472, 0.025457055758564703, 0.047290124930441386, 0.022417686188653595, 0.20982417398162428, 0.018060557288868774, 0.03937518411886789, 0.06331790238618851, 0.02047018151760342, 0.008088348643674005, 0.05220202789191277, 0.026604622910400073, 0.04520878661423922, 0.0343337050458837, 0.0150784298086599, 0.024832431715162053, 0.02373647399156565, 0.05531998276109657, 0.022821879923163403, 0.041233736405810045, 0.11206217711010288, 1.1103179498064903, 1.4906302262698452, 6.696857733111228, 11.437436284557467, 16.962258431219286, 21.458610603886267, 25.141422017928093, 25.373971500704368, 30.15194592937347, 30.521123332362023, 28.062422852362356, 28.377118533657445, 42.876322653985795, 62.331314010004846, 85.75348469518846, 90.35397775711553, 111.12543813643917, 103.60107698748189, 103.27148022190218, 98.81253765475367, 116.41149090182398, 111.73419783192297, 101.36743622441446, 91.21708746879332, 84.57769147811398, 85.72821678653841, 70.96291711253505, 63.89795180289977, 64.7666391249626, 71.11499524885609, 83.26310911486226, 66.54461814511207, 61.06083869934083, 44.733780660936915, 26.28263169719327, 13.005014465701196, 8.635284246936921, 3.7620994304457023, 1.5016680210828783, 0.33200936031437694, 0.0897146339317964, 0.08307869606200727, 0.12372813337752897, 0.10712149222531628, 0.05039115691737783, 0.06840188401721178, 0.04364682909762187, 0.03695231231470262, 0.04706118721514941, 0.008251028372004868, 0.06945058943763857, 0.046061771891770825, 0.0670328542530056, 0.028584339663446433, 0.047804962828635215, 0.0280207134557948, 0.027213534490475734, 0.12462501549312185, 0.05370627217475445, 0.03159785185069327, 0.033347500908759334, 0.014266420658978244, 0.07644717851954122, 0.06480716198923127, 0.006576935693080868, 0.013290578818639681, 0.02269655176919074, 0.06359326119925227, 0.08058594554782876, 0.05058803768347829, 0.01114493603968332, 0.02670813288028923, 0.03752805420287675, 0.08280883392980022, 0.027379697046032356, 0.044006936387309147, 0.029218193151116855, 0.06375770963307831, 0.028687288473931052, 0.0616733567608941, 0.014790191142369184, 0.024158569285646084, 0.06970695310061978, 0.1125585791023989, 0.014905293937772514, 0.05638702832643063, 0.03946358300445061, 0.013023018780645105, 0.04158335595181392, 0.07421850617374144, 0.11246622720312689, 0.08509376777275916, 0.04303752489748501, 0.03457770788020665, 0.08204017961097342, 0.02761219898539205, 0.015971727590377054, 0.02556629798134729, 0.05780187780938803, 0.10581290679833583, 0.054485785789907946, 0.019183002502447175, 0.034380873079381646, 0.11520442462736562, 0.08724102029396642, 0.11446317327359032, 0.046166791054870815, 0.04460440069857625, 0.08979082903674535, 0.03887093738622723, 0.06417862132131573, 0.032454188762893604, 0.027399663212558916, 0.016251256794578606, 0.043800897040073915, 0.09478993578663758, 0.11253513681191592, 0.02477504023831458, 0.030977460443072265, 0.0973564605679243, 0.05144907837553371, 0.04775294928901619, 0.046059201666784864, 0.013881665447937145, 0.02285133408863218, 0.055780056864023216, 0.03325630963269261, 0.047473411466325485, 0.017940540039431185, 0.03236972373880206, 0.07381777324142956, 0.03136674036091614, 0.026143757821691614, 0.014462479795779914, 0.03297772941990726, 0.0754071452144173, 0.06096200964924309, 0.03960884476621305, 0.015563547325831269, 0.030471905615300904, 0.04466100693530133, 0.034296879199363535, 0.15560494465453012, 0.08989274937419162, 0.07125139401684846, 0.03647068049758673, 0.11354874008365216, 0.047488369333047065, 0.03463354419856783, 0.07544113653561763, 0.06001985556776485, 0.10385814918986253, 0.004677188943230337, 0.05798949657248394, 0.050046417351451614, 0.06601041032662315, 0.032895780994646975, 0.037348942846179976, 0.03997032335328479, 0.07672844004006156, 0.031358861146614916, 0.032098398378659646, 0.025317373032110835, 0.03779192552751592, 0.06436959554951999, 0.03754398117082254, 0.0785224340976246, 0.051919575104670185, 0.032652590213523756, 0.09890592702093626, 0.014104285810683525, 0.05299592480784463, 0.07802404027672545, 0.05706519233964144, 0.02497423650516618, 0.10300657351411159, 0.44236674664481995, 1.6411005585424363, 6.343923355302503, 9.508136145530209, 16.123584105122475, 18.35300341729195, 22.335019111633304, 25.02335083100104, 28.702139854431156, 30.754106237042336, 30.550256736816902, 35.15742763396233, 50.15313517662787, 73.08215802715671, 98.82611690029022, 104.10075556847357, 126.27720894352083, 119.77805337598248, 122.74989205022013, 116.72971279390397, 134.83710719693093, 127.30953754917269, 116.29975826509538, 106.0726644146827, 100.014846094193, 97.51895566140452, 80.93133849482383, 74.5520740939725, 74.28089710973924, 82.66800711231848, 96.02377168593868, 79.4796222256076, 68.91945638964253, 50.407198859799294, 28.578883294136297, 14.269806261985535, 9.052028233005155, 4.212466709075436, 1.6792311447281993, 0.30952314756089644, 0.10034522236955744, 0.034252878939432484, 0.06939995102584362, 0.11807962155510342, 0.010606243121137303, 0.07029455019942216, 0.03733670076114997, 0.05796687016564031, 0.05171184653356191, 0.03344393222622814, 0.03850044960516595, 0.057135921407250635, 0.036351193764036706, 0.016395662453085665, 0.05559146516926347, 0.03491725337000624, 0.023281210920803493, 0.08599009830504657, 0.050185879827627254, 0.016546131697513403, 0.05037859690585925, 0.03075784027215935, 0.08953680194193318, 0.0635441932677021, 0.012109786433528268, 0.028461024405494816, 0.06156038177470046, 0.03221408914654486, 0.02546081725027292, 0.010442401811991249, 0.04349641156412902, 0.0663981810512562, 0.0430573704051635, 0.03369667612376713, 0.010795473541703918, 0.025779663044358456, 0.02966202619004875, 0.07317516336878462, 0.056661130755298564, 0.029123548733731432, 0.07201947376973207, 0.06179925948080998, 0.026531176145879493, 0.09991819729968425, 0.06793457038340069, 0.03397588452865039, 0.020228817856179613, 0.03092047116238504, 0.01625522321480657, 0.05341819630214765, 0.08227560609098404, 0.00943456047905549, 0.03898038453752956, 0.024673874497473724, 0.04304172688974969, 0.05017411654754993, 0.014703985183469713, 0.036578997669200745, 0.0715381866921821, 0.07400287540569421, 0.06541810178708646, 0.03789181573196285, 0.07563860335898015, 0.025561264783684767, 0.09849335803019424, 0.06359257172012041, 0.04880912023626509, 0.05501692986957008, 0.012746019581813487, 0.05316639469275552, 0.04569281245611849, 0.016147511252652735, 0.1176938962852282, 0.15350880551963084, 0.20729329527145435, 0.1276267011980376, 0.21899182559742084, 0.24162569413742713, 0.17899386945270723, 0.22106584011306687, 0.17101285738810418, 0.20470551155026884, 0.14076526997791183, 0.1450352295632324, 0.10633026129536091, 0.17866311865227838, 0.09673563823584588, 0.17056229043631785, 0.12519680819804632, 0.13872845669186887, 0.1560497812686428, 0.14742884063912978, 0.19063679711712947, 0.1449396371120407, 0.1955686107037529, 0.17495347577477657, 0.19682789071192666, 0.14423984643672744, 0.14442816617027407, 0.12032376121609442, 0.16691952703460572, 0.13163659691570267, 0.20845542000907086, 0.14913588371728698, 0.19729102150567118, 0.129676652891982, 0.18150712814061873, 0.12007144249735341, 0.17865101446307477, 0.2100558389699267, 0.1457667975656448, 0.22087503825464558, 0.14070254269867175, 0.14366106700993356, 0.17738983455684879, 0.2049300978861509, 0.1720510444213306, 0.22734786834447618, 0.14930604716702817, 0.3049699499482109, 0.12137694825087825, 0.1422375071072771, 0.16596167198111936, 0.14174672053946605, 0.24519578643864204, 0.16021086443816462, 0.13864135249487816, 0.12672749783603415, 0.12369920589750814, 0.12824710218175767, 0.15501801405222188, 0.17446002322098902, 0.15745564454024838, 0.11536427653364598, 0.15061417294125404, 0.35098964829118023, 1.9311856959135303, 4.37216503004874, 12.309412514009784, 19.409125120409076, 29.146693445021107, 31.8876672944715, 36.267932999518614, 40.36974376247775, 42.948600169151064, 47.03716508803829, 43.91549187321817, 50.02512862605434, 67.29401050075408, 90.55972176213419, 118.12898697391634, 125.5148256978681, 148.5360634711481, 142.2213612833331, 140.9220055610903, 136.37757885840634, 153.8499964437177, 147.12096644986062, 143.222962041055, 128.00079253412062, 120.93276777575095, 116.70602167806318, 104.46544970235517, 95.63884596670829, 94.59140839115267, 106.78575131200977, 119.36410211747693, 100.31231080332111, 87.19942723551105, 67.55607189670687, 43.282609601174634, 22.997034788131717, 14.391580166355258, 7.560847526596439, 3.0787406669509028, 1.2697055455177062, 0.20762689591896152, 0.15516504164664977, 0.16401066054259578, 0.20876522596564986, 0.123564665536246, 0.17329083515271065, 0.12351778861615928, 0.19818061812510415, 0.12166240793322364, 0.09003264469004447, 0.14868671104552286, 0.22688418596742616, 0.12743282732703995, 0.2460874208519536, 0.13614280269511286, 0.1569207159862403, 0.07707792169023907, 0.2210307073208594, 0.22350909368645763, 0.11648873272802561, 0.1644555737655009, 0.16640132984086392, 0.22420019692470952, 0.150344847070594, 0.20631429619125782, 0.16153365313526125, 0.12250673641721088, 0.19742799802653252, 0.21097505254851234, 0.15846384689211845, 0.1933080231350276, 0.12875786832263394, 0.125442553882397, 0.20151112408887958, 0.07562957118235289, 0.20373277906929294, 0.07756889978003118, 0.19765474473036107, 0.1718442466470503, 0.15795937799397977, 0.1421331506102316, 0.10599884399843794, 0.11170681956554614, 0.21198828043716572, 0.20031417299422527, 0.12264032682944691, 0.07004760941790958, 0.10217427261053555, 0.17513473217766132, 0.20633441366014943, 0.20728653837596217, 0.2151994605458552, 0.15395382599484536, 0.19529358513893622, 0.14275640910190923, 0.24606256895968992, 0.16832552820203767, 0.13533594357150217, 0.2284735579404139, 0.2248009324314133, 0.16411297924576268, 0.2130124174178608, 0.14226225174723134, 0.13954329845165053, 0.16382074734616667, 0.1881678029894829, 0.11448758849573713, 0.20111476551861535, 0.30613832596328955, 0.1755190938110313, 0.16363428154539678, 0.14502295683468544], [0.06161231870552706, 0.019948529267323115, 0.0392759642413547, 0.0315789582072607, 0.05004511883241996, 0.06770510406744096, 0.03403586538268193, 0.021595459341281847, 0.06661229496521336, 0.05607544504586728, 0.0435375887900591, 0.033121888015058734, 0.15452807018112752, 0.012941416052560653, 0.08674415864891584, 0.06977131980801783, 0.09767697643368475, 0.015232263136685137, 0.1357715105217311, 0.03703045328297923, 0.0405595024236508, 0.03312893985440174, 0.0047332996168294025, 0.04248493035594302, 0.019613704794356902, 0.04668977629813937, 0.06216926462647896, 0.03735484172319693, 0.07666437976783322, 0.023521503974353115, 0.02721491919439887, 0.02015490569324503, 0.02537930549512948, 0.056158764768512025, 0.07189623320535307, 0.012828333814057612, 0.050589137019649635, 0.047350419880521875, 0.06404358683334244, 0.04470231822661815, 0.06106130230510908, 0.054924283026447224, 0.069692604273798, 0.048528218777069164, 0.03663257019774568, 0.0749032662039803, 0.08835642898996031, 0.06072906912454675, 0.028055430645303383, 0.05458459964082126, 0.07999611913316673, 0.018318543143029657, 0.06198477533255374, 0.09580333987551351, 0.02757633457921686, 0.03699281921369895, 0.03147243559660931, 0.007774990433151083, 0.049063756370977055, 0.051765978306291566, 0.1123031500666853, 0.4153308909266226, 4.581549975179858, 19.174585034770352, 37.808208542485396, 46.369303118798044, 55.161586115437174, 69.09577477362849, 63.80053581730012, 81.03569707562848, 80.01968552989345, 89.61407753729051, 84.99302341092019, 85.21106796879923, 97.42520316954582, 102.45588610249182, 103.13824515188895, 98.08420842693698, 93.07007005137783, 97.20973953124016, 79.35133718675183, 76.29608538842972, 65.26718454976236, 79.78612407561272, 74.45519939545663, 88.71711777102563, 87.6833692673714, 94.51937798530825, 99.71371789132395, 86.82722568511964, 106.50814948543426, 108.49814045813777, 104.20127022650935, 104.71379849218555, 97.7674299670804, 114.56647857542961, 106.96977323101414, 101.52646480068084, 86.63284870886034, 89.86149280301987, 87.68248281171246, 76.34797834580945, 56.824255297260905, 48.44065973835607, 33.90995702435894, 14.086812984558845, 3.8793910463010115, 1.3750892132520678, 0.2756660756084227, 0.08540268506734602, 0.08387734272306965, 0.027581890631887703, 0.012563998048614352, 0.02554216046607302, 0.09113116114730797, 0.18715402351752405, 0.008354285532879013, 0.05307624912670544, 0.037106246191767916, 0.0389906462852753, 0.050001635681837804, 0.10879299648466612, 0.03801924296684804, 0.06341546368334564, 0.08938885504199613, 0.07452740048569056, 0.027876470590971654, 0.04161727066422182, 0.061680577139580445, 0.05139188991198617, 0.11540416673186327, 0.03557120517437016, 0.020527314439776446, 0.06034793272133797, 0.03227606949005877, 0.06282995800457655, 0.014258303957420492, 0.02997756822996082, 0.026501687506454128, 0.017037839486053395, 0.023455189488407586, 0.07237526032352641, 0.029857832517835404, 0.013759711911270936, 0.08034635921038928, 0.005343569087750849, 0.05061436429499619, 0.01762748012439378, 0.03416436514066112, 0.06167403474870709, 0.03592498457780288, 0.027116028734693126, 0.018555222176796487, 0.07883197958430938, 0.020606830535877137, 0.08757719499689919, 0.009983377249520874, 0.05100626806398073, 0.04632170935491881, 0.059409628231679244, 0.05379910287897914, 0.024268456937504873, 0.036556574275657054, 0.029337633919391422, 0.07346447647338913, 0.0277113767280694, 0.029723167667285572, 0.04191998264662201, 0.04931526686695795, 0.07038981323280642, 0.14389464721804665, 0.07683606007166448, 0.032591180605513435, 0.06041604176824612, 0.05871860926309901, 0.06068332601458796, 0.018574665488314726, 0.015778475208207965, 0.07214737214869069, 0.029789191039819873, 0.04614102368753764, 0.15045764585656507, 0.06698996099012514, 0.01665231148381868, 0.042760174255818136, 0.0337845464086821, 0.03225254676034374, 0.041790854696544914, 0.04529893984116855, 0.05486954221381776, 0.028777539377070727, 0.06308033085998989, 0.06479445259056746, 0.09233190437718745, 0.07332683345603366, 0.03932066164129684, 0.017802211373383482, 0.03522938823387508, 0.03192186490782807, 0.022815322210531563, 0.04535398708896772, 0.03245616526973825, 0.05402766521118822, 0.04995516478835095, 0.06278293552778422, 0.012088803285282227, 0.026965419679219206, 0.11701586250696452, 0.06217499496415258, 0.054233777336776264, 0.060618193219265634, 0.031147003361594774, 0.05733232719883804, 0.04363917204881868, 0.011528743216918122, 0.012237350606629926, 0.0356125011439285, 0.040196434204136176, 0.04312095570287878, 0.03468945712572144, 0.030093967629175995, 0.0395764239252575, 0.06859497647852668, 0.026483979384084384, 0.05217631798117392, 0.0889095444712908, 0.07847841468549545, 0.03492112594446348, 0.040534658192266385, 0.048074422764682004, 0.061579074320052905, 0.008725797956539019, 0.0024184438159629224, 0.015204121854396598, 0.06450911548228995, 0.10033169325681464, 0.07119495631946672, 0.3884926858928896, 3.8830604235972133, 17.06784667507295, 38.415579718928186, 45.48179234227827, 60.48364623900383, 75.49334095370385, 71.8792926111529, 93.00038522289645, 91.66636359307074, 98.82757602199432, 99.69712626549506, 100.73618565836261, 111.68817274032101, 118.29786854405558, 118.82480759774487, 109.3636820393224, 111.39483436461418, 112.40676664537, 98.11464601947416, 98.52696557198801, 85.64291308003088, 103.31710523174655, 97.81824819503292, 112.79507344768895, 107.4849137952251, 112.06428097140406, 117.30472441642516, 105.74507590263121, 125.0093420090214, 125.9957318152151, 124.37416122805689, 123.71603458158432, 115.53045595845869, 128.88166273793868, 124.86697566124701, 118.09210884955623, 102.24348975766091, 104.52889011752222, 102.59377310352941, 87.24694282777848, 63.96111372978457, 52.725260796085486, 36.88215263428227, 17.579023684224776, 4.387555430012365, 1.7248758889975089, 0.16391229485311817, 0.05136350635439158, 0.06569792306230915, 0.044774499030843865, 0.05318451267216475, 0.02959505478370815, 0.06854852856767756, 0.08844280540342293, 0.057787099973328655, 0.0683874968859938, 0.014965931712199124, 0.07955528915889802, 0.002119090410903277, 0.07773258978681219, 0.03839546874646218, 0.06430928144724139, 0.030858703408270117, 0.0018942839444442204, 0.033748555597999406, 0.07978128509656077, 0.016014633302186287, 0.03173601197739763, 0.04997182337026443, 0.03940849745225522, 0.03820353307791295, 0.015005847765883852, 0.05638647291268553, 0.017256293288101594, 0.04357998026534916, 0.019792548020280177, 0.025382331542430386, 0.08565007017985468, 0.06680539508740749, 0.0639056833460927, 0.05359620832267308, 0.0038394121868130303, 0.08805624509771025, 0.03636125249848251, 0.017557545873006026, 0.029485984930708527, 0.060214978162079096, 0.04788258285712331, 0.03635423130265648, 0.040608133685084126, 0.04465497399289762, 0.07585790368818468, 0.044223088095144886, 0.027503452804540435, 0.07271396311660928, 0.03649423387081873, 0.034136318661753214, 0.06750038239143549, 0.03495364637684918, 0.05711638233474186, 0.04081745954951452, 0.06479768548160791, 0.01199332383205934, 0.027155258182075717, 0.027428060176692186, 0.04489273704107731, 0.041681465001836907, 0.023458625392747984, 0.12907239338082652, 0.012687255849971647, 0.014419277224900022, 0.0927348513036005, 0.07383429009707705, 0.049851333061533595, 0.17381065645285193, 0.1833485736842117, 0.19450086799840774, 0.09798548004079251, 0.14932469374710514, 0.26185553280576584, 0.22798880814544617, 0.2101575141592372, 0.16341162575108392, 0.14552008661050952, 0.1466408119566979, 0.09263412606331611, 0.20311350423482158, 0.19798161912589304, 0.17918104005436744, 0.16948469584026646, 0.2037230497526546, 0.19794233413713594, 0.23621424822317016, 0.1500072168006051, 0.26393196815925263, 0.10634336905974535, 0.12400310531619096, 0.08820514194667341, 0.10687321078993621, 0.19662489273375083, 0.13368936015232918, 0.11899404708416232, 0.18307457467721355, 0.09272982576681722, 0.14222734878140111, 0.16307845411281433, 0.1596430707122049, 0.10603377760778512, 0.1589828714608185, 0.10326033247815025, 0.14482544404604744, 0.1227137027308345, 0.11907856190396894, 0.09054151859374777, 0.16068210044214803, 0.19608187429126234, 0.13084936496471206, 0.17228413433317216, 0.0821714181332819, 0.22907124441717902, 0.16093397482989297, 0.24066892692879324, 0.10295025839079773, 0.19975502074005144, 0.16466860749548481, 0.12015174383357649, 0.09186107439980393, 0.20029477564798248, 0.08346844329348496, 0.19523839616487104, 0.19705243108253326, 0.1496269154332338, 0.14228074510972347, 0.19007753761064625, 0.21735310224035095, 0.6638086286763991, 7.577237150361461, 33.78351549948416, 61.098297334486446, 70.49636687001875, 86.502547571736, 99.47177040961482, 96.9419514748358, 111.28437257582142, 108.28748564566337, 117.44101109043245, 117.83126338835686, 117.90050106663858, 127.69889554669781, 138.56091130164364, 138.45637229181105, 125.58056462195613, 123.72665636001096, 126.03207649723177, 106.9873768283475, 102.31734014326527, 92.07081487101894, 105.66753848906487, 104.38541766135924, 116.36325359344484, 116.02503545822637, 121.94495893293812, 129.05128955841064, 117.0430160337879, 137.1034997509372, 140.08834500466625, 138.02753171613142, 134.1783215922694, 128.0915012667256, 143.77000716424757, 141.6703937899682, 135.56437738480108, 121.2243175506592, 124.18311042170372, 122.66719279750701, 108.20756343103226, 83.16256307786512, 73.25562092565721, 52.104075031895796, 27.390209013415923, 9.021123878417477, 3.5457721352577214, 0.4768329504276476, 0.22540672411841733, 0.2690169533654567, 0.11002485820602988, 0.11244690646567654, 0.13442181681673374, 0.17441508450335072, 0.33281467194038056, 0.1424009136615261, 0.1319571587467386, 0.11238830073946908, 0.13637151058402755, 0.16819599805580032, 0.14401322230696678, 0.10134375669182309, 0.168386937810048, 0.2078465333268527, 0.14742884063912978, 0.09577665703311082, 0.21831878671242347, 0.21066806579549469, 0.06986796946054505, 0.17383543173632315, 0.15464256968229048, 0.13056922193256118, 0.24978895851921654, 0.1523638871167937, 0.15525473522082453, 0.15925909212279707, 0.10600453603171534, 0.1413708011950216, 0.12619079195804175, 0.11777489476146237, 0.2073612625920965, 0.10857456949569526, 0.1022653068385778, 0.15935865290943654, 0.10295804184410842, 0.09126052275420198, 0.036505874576828176, 0.07801817970410471, 0.1580731726942524, 0.15058519949595775, 0.21131960825333673, 0.09728898354355367, 0.1813436449775773, 0.09252279816615967, 0.12723163731636541, 0.15174652750213302, 0.12881489590771739, 0.1737181743186328, 0.11724342892487204, 0.12826250820991494, 0.1513821760853452, 0.10952428869542577, 0.11889014257899216, 0.1090094622885508, 0.21314184031178876, 0.14757300306472088, 0.11445299196507662, 0.1745187974865398, 0.215520681212506, 0.3890937584782801, 0.15220162969443107, 0.11535811718673476, 0.17735568235718435, 0.1544410272711708, 0.15191597082922537], [0.05066962604741416, 0.08442646688631467, 0.026304530948700926, 0.047904335923733256, 0.06481789488105044, 0.051803692814803896, 0.008378257381639654, 0.07999567480217065, 0.038429218749966354, 0.029527164071858413, 0.06691010398489815, 0.06014903714399665, 0.03456281896139826, 0.025726726368790673, 0.1213413251623992, 0.09051437609859052, 0.060787609733280644, 0.06114999996498228, 0.06684890888150662, 0.029277731589372122, 0.015978058349461328, 0.04395858857840781, 0.057923770059020295, 0.04038743524541778, 0.06567182244672891, 0.0805753582127152, 0.12298606230967468, 0.04257844287842032, 0.06374806458611162, 0.04541178842285468, 0.0658269552513957, 0.017399178262078957, 0.08424409199506046, 0.03032797684652671, 0.06347831736709322, 0.048071603561120654, 0.13630801721686317, 0.032583060073516065, 0.004131169351298482, 0.01447133098413507, 0.02805722712148582, 0.010544075086081942, 0.025993968480296677, 0.02082420989961153, 0.017600942838696704, 0.00986198678747901, 0.0664439088394565, 0.04652109522853167, 0.02771501181527011, 0.08430246789489063, 0.07183465505799941, 0.04840120522966308, 0.006113053654365603, 0.02817022509031719, 0.018606212989036596, 0.0721081254643298, 0.05321686456520712, 0.010645782834129229, 0.03735171225402625, 0.0633929062244152, 8.502392384313769, 19.44728978218571, 37.8466752267653, 60.72206358755789, 76.21071892399942, 79.2050249345841, 80.7969424032396, 95.32277353348272, 89.92274453563076, 62.99523007485175, 69.0389004061299, 85.84504850449102, 76.13046723027384, 82.15296068499165, 77.3478061922135, 62.14955922096007, 68.34961445100846, 85.75755611542733, 60.21462263599519, 69.24572698531613, 61.86283003899359, 37.26261077388641, 42.11816772337883, 28.987139271151637, 50.68551848011632, 48.67325236720424, 60.92398720402872, 57.226282550442605, 63.07911780572707, 52.00938117119574, 69.6872603508734, 64.13087783321258, 69.15184897761192, 63.50061178207398, 66.1492040080409, 74.28034013317478, 82.39606918827181, 84.8508688711351, 111.52677505247055, 99.41658266129033, 95.66089753181704, 109.45923882146036, 100.25895087949692, 103.02530442514728, 87.05899069386145, 83.373547369434, 61.6532931020183, 49.40076966439524, 24.10465721161135, 9.386753497585174, 2.5380343391049296, 0.189769554943327, 0.008375042685187392, 0.03320519624638461, 0.05175646349427201, 0.04792337703909125, 0.021800274863058043, 0.07108584241641146, 0.007799736030715248, 0.06018863622880271, 0.025964665617192947, 0.03439630592061627, 0.012062759168686406, 0.0820353455961712, 0.00815784814016473, 0.05851950684201814, 0.04794947382423186, 0.026354914636261044, 0.09965077898795567, 0.06684047425346029, 0.023295622949879018, 0.03879260489596956, 0.08208866531570112, 0.03951907841368549, 0.046767714253116044, 0.0061755056207578995, 0.06930980545979354, 0.06990138621580216, 0.03637578135596649, 0.02971387310554424, 0.060875518322591825, 0.04530277794166919, 0.04202859093164725, 0.012835629843926478, 0.034245038029527476, 0.01310355760412471, 0.01727062487794507, 0.03917333910301809, 0.07261454788667542, 0.02802008334847708, 0.07864930591876469, 0.012898313073110918, 0.032251803655057185, 0.004321646101156911, 0.11480544603640035, 0.0221493887910319, 0.025688343448564414, 0.04488183944035442, 0.03631042639514612, 0.06316985589482131, 0.08614624234577341, 0.021731648706800995, 0.052510646412209164, 0.017089625114514943, 0.05384817847140855, 0.11095062183636813, 0.07177544412233176, 0.027025151554675355, 0.00523606205411676, 0.019579623457825473, 0.040552102014302246, 0.010629006466197391, 0.03543597150353655, 0.030835046613168333, 0.02437483782189027, 0.04288962396282343, 0.09554097008320594, 0.07641335573768424, 0.023692163466025266, 0.08385269001366631, 0.12413987499331275, 0.04330257216708795, 0.04130618917124887, 0.058076175590676654, 0.03078725996367153, 0.07116418256754838, 0.03270251616354912, 0.042124834557574604, 0.06114728035285108, 0.04506561244207044, 0.029389637882911393, 0.04955715912904951, 0.05396792184441321, 0.0901271646181422, 0.0893125526847378, 0.022017615922396223, 0.027992469709246393, 0.032981019767542044, 0.02923440740203425, 0.12064406257723609, 0.06788962400488316, 0.015438230663177469, 0.046214127627712105, 0.026328881053374182, 0.049970858099479834, 0.03321075038383565, 0.09004389086077291, 0.03493738616065633, 0.014258752118856197, 0.031168384875561443, 0.046843851901470654, 0.02455403727869834, 0.041194236912434144, 0.010206388317108636, 0.0337692974285493, 0.03145143712660478, 0.02790718688629568, 0.030310307028553182, 0.053503760662410534, 0.003407533231732105, 0.014059611393379108, 0.015901334643844637, 0.020939073292538527, 0.03479802710635047, 0.012754515496893756, 0.09157799725090304, 0.03243300260134763, 0.012231986075940152, 0.05300630912965825, 0.05253365586301493, 0.026428529940124963, 0.014350153111492195, 0.014813539587081441, 0.11061401812419777, 0.04218826280726541, 0.27339817956089973, 8.278988888186793, 20.602696480289584, 45.240280243658255, 75.4712893885951, 88.89133376459922, 95.70877398214033, 96.76315415290095, 106.28719452888735, 103.06662267254245, 79.81186266868346, 89.38423448993315, 102.91791777456962, 93.15789976427632, 101.8161867510888, 96.49697426826724, 85.7972034331291, 96.28122821930917, 113.96508509112944, 89.2343528809086, 102.08410816807901, 83.17318485629174, 53.23387845869988, 65.28520391833398, 53.16237757282873, 68.95432626047443, 65.3114131958254, 79.33411798169537, 81.62751213196786, 84.6587590248354, 78.42211200344947, 100.18716366060319, 91.66143709613432, 89.85854318065029, 84.15126708246048, 82.10165608313777, 89.8460465092813, 101.79992460435437, 101.25069079860565, 125.21208147848807, 112.8977140303581, 109.70772881661694, 124.98277187347414, 118.15750260506908, 119.23068661843578, 102.35355930943643, 96.64101154573503, 70.84628935783141, 54.874786330807595, 26.28933502781776, 10.165812700025498, 2.235665196372617, 0.13726472313846313, 0.01640217420044205, 0.018638405918834672, 0.023246214109202547, 0.04384964321469588, 0.0074465278415910665, 0.006671223400776545, 0.09058713912963869, 0.030899620164305936, 0.031948771830948616, 0.0453832095128394, 0.029539900283599575, 0.0258255421349238, 0.08141917341779317, 0.07339628698724894, 0.07613718870186037, 0.026144922275336522, 0.06548073713577564, 0.010656520513997925, 0.05535731805608638, 0.05178949337512736, 0.025254113321763375, 0.031477018717616316, 0.015697513121150194, 0.03183156229375351, 0.0858958924729978, 0.04413835110984022, 0.038389692443513104, 0.014819878007044957, 0.09081625304515324, 0.0260159686102622, 0.0744600230527501, 0.01838746615835736, 0.033718011672458345, 0.011214802300767794, 0.04459094053374664, 0.04165086745014114, 0.03604796850272725, 0.028310765835246252, 0.050786791534553614, 0.04641803342007822, 0.038700088287793824, 0.03311367938295007, 0.03731556056487945, 0.010132433061728315, 0.03891212610347618, 0.013933616742912321, 0.05753073631034744, 0.03138294312051468, 0.0937125786778427, 0.028401949450433738, 0.0298845345124362, 0.056325109269950664, 0.02572056893709927, 0.09726405504249758, 0.021837893610579834, 0.05253735989812882, 0.037934184224615176, 0.019541656140298135, 0.08975037959434333, 0.00982587340272843, 0.0588503304207998, 0.060149757266645475, 0.07399130747803757, 0.025888916758459904, 0.24220712422843904, 0.28127852767225237, 0.19366210897363004, 0.16905053849181823, 0.18149445704635114, 0.1837482877195843, 0.1280802712144871, 0.20015170106724386, 0.1149045165267683, 0.117037175073018, 0.18434520810842517, 0.11206721796864465, 0.17029520154239672, 0.19636578647600067, 0.1181920296362331, 0.21755686630645107, 0.1069168241754655, 0.277089252467117, 0.1802301668231526, 0.12550767135596083, 0.07955461500152465, 0.1071124064225343, 0.16985215757402683, 0.16190192692222136, 0.18190607608806703, 0.12800027631343375, 0.17079806165589442, 0.16396798944521337, 0.163677167147398, 0.13510783323116843, 0.15239967874461605, 0.10161967091863194, 0.20170633861374473, 0.17012237210667905, 0.18182784318923953, 0.14138233847916126, 0.16881259158253673, 0.06353160644310617, 0.16662645243829297, 0.10233409387329895, 0.11358274672661098, 0.1662231224679178, 0.10710532777011396, 0.09904206850596013, 0.09533941235032775, 0.1328232058233792, 0.1816591046630375, 0.13850880396221915, 0.09180708818377988, 0.16150233546091666, 0.11507678671830124, 0.13554765963025633, 0.09927694340266528, 0.16853038011299026, 0.12249447901042239, 0.12562407841605525, 0.08973219266702091, 0.2324718474260261, 0.19231456031482067, 1.3305346427425262, 16.05256861256015, 37.5572003856782, 66.95773001640075, 93.72385071169947, 102.89073574927546, 106.8038099042831, 108.79046686234014, 120.57323548101611, 117.48782850080921, 91.13552570343019, 96.31281898867701, 112.51856204002135, 103.47389021227437, 112.66526652920632, 100.63564746610581, 85.36387566597232, 90.5800239501461, 111.43133594143777, 85.7107622392716, 94.66895364945935, 85.11737039012294, 57.97985223031814, 63.8345584561748, 49.41520790899954, 71.84803132087954, 70.92395228724327, 85.8329205359182, 80.64969662697085, 86.38255442342451, 76.06055490432247, 90.72977219858478, 90.86939288723855, 92.27094204195085, 88.14973123611944, 91.48367527992495, 101.510375238234, 109.52292242357808, 113.18470601112612, 135.64364064124325, 124.20109841131396, 119.90299655545144, 135.8522636659684, 129.67901783604776, 132.0204374867101, 117.51069591891383, 116.25974224459742, 94.02903464532669, 75.12293584885137, 39.47108953229843, 15.71560073283411, 4.317892664863217, 0.6090066209435463, 0.24078339578643923, 0.17184142744348896, 0.18144803211813976, 0.27913856830808426, 0.2051059916735657, 0.1831433234075385, 0.14010340065485047, 0.14346847250576944, 0.17176347033631417, 0.11877398832791275, 0.10929527437134136, 0.19722215020127837, 0.26799900637518975, 0.12792742135183466, 0.18135495243533967, 0.10144403760111141, 0.22895619333271058, 0.09931756138441064, 0.17171716798217068, 0.1067559457113666, 0.20993868880454572, 0.0675346571651678, 0.12254923131437072, 0.15957744762061105, 0.1712764682428491, 0.10616860142157925, 0.1161468736526947, 0.11184967198078671, 0.14910389188556902, 0.1433615879185738, 0.09943704811796066, 0.14305991781575067, 0.12690045750669895, 0.14810620026002008, 0.17309205065811836, 0.10235916793106065, 0.136302899749529, 0.09304360771972327, 0.17828453332185748, 0.17611233697783563, 0.10586785062426522, 0.21505437881475498, 0.306770225926753, 0.13599332361932726, 0.16728328090281258, 0.16127626291446148, 0.26854118212096156, 0.12215771441978794, 0.16441985874647097, 0.0954414552618419, 0.0863336963999656, 0.14539673113294188, 0.09948423913409633, 0.22086166235948765, 0.1369094575244573, 0.1861036403645431, 0.1519909861587709, 0.11866884276030526, 0.24187527026139924, 0.10337262564609129, 0.18608899276343085, 0.14338383511189493, 0.13901531065423645, 0.18904855895426967], [0.011301273517611047, 0.028832414255086935, 0.007454379285205036, 0.08082701809584134, 0.024748556578772205, 0.07989930860217541, 0.04199450001901677, 0.042660433438516436, 0.04650556279586689, 0.04069788088541358, 0.04202548827555391, 0.08249902031234196, 0.025749170829752283, 0.01250577440875913, 0.014715947646407351, 0.02278971572166249, 0.02303829976177264, 0.04031610096834841, 0.032440042949371764, 0.04158944635081195, 0.03610416105197322, 0.07046430762256346, 0.08273106834460651, 0.03134279245240314, 0.07874265373233827, 0.05072083136427307, 0.03274319543232841, 0.06547195010728414, 0.01806774702403815, 0.03671553751994525, 0.02161401399080792, 0.04964182716644099, 0.030524834629989443, 0.041202242531242876, 0.06466342091199852, 0.05586816080575509, 0.04409339324000382, 0.03595047998392294, 0.07006779583471437, 0.05881098414500875, 0.018062137345212604, 0.027019834904480847, 0.031562747786782926, 0.02945297611727109, 0.03410495885257279, 0.04529870618435164, 0.031844405757804076, 0.03842035511268243, 0.03953543439086887, 0.09775936152906188, 0.04069714161056665, 0.037594742156685367, 0.0255318833965688, 0.08235610661006744, 0.08498642353280898, 0.04311582674422572, 0.06923227736185636, 4.318389334986287, 15.32155550295307, 38.63166309172107, 66.53780891049293, 64.92714251241377, 44.71628296759821, 55.75189890400056, 61.80523395538331, 52.065796621384166, 42.69381084749776, 47.23789238160657, 64.52943378879179, 30.789185954678445, 32.76563102199186, 40.733935832977295, 36.84510192563457, 38.34324729058051, 40.411014941430864, 45.97928616308397, 34.78023682871173, 30.204019315781135, 18.848602733304425, 14.978219655252273, 19.79925778604323, 23.380658280464914, 24.86398296971475, 30.763153183844786, 18.86071893476671, 21.099380331654704, 21.660249848519605, 23.51517008196923, 24.54140332437331, 19.4300764606845, 14.569709704768274, 27.268356661642752, 41.80385643436063, 34.94849866436374, 32.537233368042976, 27.163739204406742, 40.03786025508758, 49.98574802952428, 46.257664618953584, 60.759902692610225, 69.98746287438178, 65.4352581116461, 66.20717663918772, 76.15269922441053, 92.16826223557996, 90.50710708864274, 97.18746831340175, 91.06034171196723, 87.91064708463608, 69.68915093329646, 52.607099394644464, 14.750804555031563, 1.40206653985285, 0.27249168304185717, 0.01806171408163444, 0.015792131683068172, 0.05448551382869483, 0.04982544312013253, 0.0317133300291795, 0.07854173951331647, 0.05340962377827495, 0.09221869956461654, 0.0508241574730604, 0.05617128264519477, 0.033681844661553065, 0.023415473575193076, 0.033431877832739584, 0.04497522938876383, 0.09047456250916566, 0.06158835547525556, 0.017796030959054347, 0.009548340815179532, 0.019430958350459417, 0.06164753193696661, 0.06962954757675048, 0.04157870579811354, 0.03167164718521939, 0.08352558579175703, 0.04045772764291014, 0.04419145249431172, 0.02877906006160042, 0.034972116756703586, 0.08226594572225887, 0.00785676074296897, 0.05312137170544556, 0.041324291828899615, 0.033840524453309276, 0.09750976242245206, 0.05238396611305014, 0.021892393105513146, 0.012106857104827801, 0.1168547465556091, 0.03638267997772463, 0.07642908352276973, 0.022248263928979155, 0.023443219364590706, 0.047138780430560155, 0.058245668713484085, 0.044216729565373356, 0.02487028603472056, 0.025308821575656056, 0.04919363125678032, 0.077669448820093, 0.079294987803986, 0.0555194529043811, 0.05793351852785676, 0.011014368801918483, 0.0430973716861298, 0.04109284900609524, 0.04037699346700984, 0.055567229977778854, 0.05224449214555564, 0.06268356243268618, 0.0409659848458344, 0.02693194355214796, 0.05014746817910383, 0.055242500628434846, 0.06966929221826215, 0.011588564150095468, 0.1433986818958675, 0.05703669386885821, 0.029089442499342467, 0.04765428865568773, 0.03775011244860869, 0.08039438526236242, 0.019760416377516046, 0.020440484119218685, 0.04744823398669401, 0.01835722292232658, 0.019444575563313502, 0.015143667941071816, 0.09602172856008816, 0.05325239572313525, 0.012328406859699999, 0.02207909064788011, 0.04793785227042052, 0.014552158048196186, 0.04704950437430413, 0.06165088357163533, 0.020982045079431227, 0.062452640549670306, 0.07428412160445606, 0.07682090685252221, 0.05223395077571754, 0.08351209498341046, 0.022456701131417386, 0.03336210637503574, 0.03756293035562962, 0.04299447841701969, 0.07033633263481241, 0.028064478143689134, 0.08876735089166511, 0.03465727760246204, 0.018345679892527483, 0.06802099276213877, 0.025388586650332137, 0.03402682937561505, 0.027253112507863875, 0.04187906589058619, 0.031384572972573584, 0.007668214534679729, 0.03770263797994103, 0.02083256025798619, 0.039783577930422566, 0.04931865297558327, 0.04136889346785123, 0.12680758466763845, 0.03244415684152515, 0.021962867448887518, 0.05172046502271006, 0.07260579916258013, 0.0826747608821719, 0.05522480399738397, 3.7922303426650266, 15.576555652003135, 39.05795412678873, 75.50255067886846, 76.53982147093743, 56.70647828809677, 67.71260584554365, 75.3575014298962, 65.6754679833689, 60.65608539888936, 67.54010000536519, 87.55160116380262, 51.86777968560496, 54.75701716638381, 68.01851149528258, 58.552961503305745, 57.24010890530002, 65.39536760699364, 64.03217531019642, 46.74911406732375, 49.0806415004115, 32.25266345085637, 27.43879737392549, 36.72364573324881, 38.32494943372665, 38.31681836035944, 34.35445177939631, 33.78612387564875, 41.83975004380749, 41.95619736948321, 34.306159557834754, 42.15151179221369, 35.251050687605336, 31.97279449432127, 41.541422413241484, 55.90482034990865, 54.120651829627256, 64.87466512187835, 50.004010585046586, 69.30420167984502, 74.44268703460693, 65.4767136419973, 84.31508879507743, 90.75281220097696, 92.09765172773793, 84.38684463500977, 87.17112341234761, 103.13267538624426, 104.54421089541529, 108.69103477847193, 106.22690769933887, 100.21844064035724, 80.12123569365471, 60.24678999377836, 18.83370557138997, 1.827452242855103, 0.21801297973480918, 0.05858953493917662, 0.09054487405885613, 0.04476720204336509, 0.07696384353743446, 0.04698690349957155, 0.06639282609666548, 0.07558637148430271, 0.1124515719411354, 0.028569715044971918, 0.02321944316668857, 0.05268279019923461, 0.0570380345227257, 0.02385357053079192, 0.034890064909573526, 0.02693306204051741, 0.049598213780911705, 0.025487699275535923, 0.022034421976235126, 0.057615369873782324, 0.022265025932762413, 0.025518679871193828, 0.08896023650924045, 0.050929996350239364, 0.24845910649145805, 0.02766690532406492, 0.014434438104921532, 0.038587481023803834, 0.009302853685503286, 0.011267870168892608, 0.02193566941235575, 0.0568558588143318, 0.03773967450064036, 0.013571192994863998, 0.05203267649537133, 0.04471101715499836, 0.010898095807210814, 0.020503228635437066, 0.041858515582017364, 0.034214444308271336, 0.05360724381922234, 0.03047404683104927, 0.017919622008658705, 0.06515665896116726, 0.03685646705449589, 0.025934395568084814, 0.02772552254159124, 0.00892492144503781, 0.026652941991004254, 0.08068105536362818, 0.010205314836404737, 0.04078183263059586, 0.054593516904259884, 0.07000431012842925, 0.06712126079946756, 0.04379867921553312, 0.05069656169883186, 0.049762811601882985, 0.034042124321023305, 0.04037302896200169, 0.0373005184284862, 0.02235182177936358, 0.009441663071723476, 0.08506929892445765, 0.12305903984534165, 0.12493098334920023, 0.25457685482838466, 0.09670513261470104, 0.22551549328190668, 0.13260491673023472, 0.11215969244198454, 0.15477429083999128, 0.11625682259158743, 0.12538950229364057, 0.1449935084148761, 0.2455536567515904, 0.14605935122216904, 0.09249967763260489, 0.1980138561057468, 0.17512556976608692, 0.1766907333606674, 0.21474137061065246, 0.155408090701507, 0.1620288064042407, 0.24518116948104676, 0.21110033856764918, 0.15321419874746955, 0.18229212311487045, 0.166894200167829, 0.11791309702300257, 0.21198694744417745, 0.21816769885199688, 0.09977916766318584, 0.12399888417172818, 0.1723402119692295, 0.14898390719486823, 0.15259601175785065, 0.16037532819374917, 0.264424532051048, 0.13742226145921216, 0.14116772660805335, 0.21471153914688096, 0.15573369339108467, 0.1623106195080665, 0.08706253712936755, 0.12116936906691521, 0.16988938944714685, 0.10908133665760679, 0.21040396464447822, 0.12955705124524333, 0.1340857493661104, 0.16659179462059853, 0.15254192595039645, 0.2216439300607289, 0.11359436061954307, 0.1779746660782445, 0.23065039677725685, 0.18145391567339822, 0.28805043848772205, 0.20228257462863, 8.276027498706695, 29.01382903898916, 62.16096155105099, 96.33935774526289, 97.12685984949913, 71.0910217223629, 81.19047380262806, 88.09939153732793, 74.35768927297285, 62.26374333904636, 70.41520518641319, 89.46608651068904, 53.83858242342549, 52.43945729347968, 59.97893917945124, 58.22627121402372, 54.45082518362231, 59.25586592766547, 64.78998899459839, 49.60632539564564, 42.768928158667784, 32.542177515645186, 27.013365337925574, 31.844444736357662, 37.22608958521197, 38.74724749595889, 50.835721723495, 35.62414653839604, 39.7790152026761, 37.370652460282855, 39.026959557687086, 41.563403375687145, 36.25246709392917, 29.01581964185161, 42.39738164409515, 57.145928875092544, 52.60626392979776, 54.65863235535161, 48.58419103007163, 60.5648353792006, 74.4986592569659, 66.49405879359092, 82.51803921115014, 93.22681580820392, 84.36434591970136, 88.31036798415646, 99.78188084017847, 117.09084541566911, 113.5221867407522, 125.661938113551, 119.68776041461577, 116.91764923834033, 97.43951982067478, 77.00335933316138, 31.30357146263123, 5.265987390472043, 0.5076814112403701, 0.1788778684192127, 0.1621760485032874, 0.2609206603900079, 0.32774899214986836, 0.15608044010737251, 0.1703774180984305, 0.14360485147804986, 0.21107481251801216, 0.13159303715632809, 0.14297552557001192, 0.17296985963419562, 0.2616187809936462, 0.12654906063671076, 0.16633668734181314, 0.17019789305425462, 0.20635658424467812, 0.11306490193331435, 0.08430763898837952, 0.16619342889997268, 0.18747198064961743, 0.16812914922352762, 0.16139024147583594, 0.13807677633820042, 0.32220717339265736, 0.11837512465013612, 0.08154054472763693, 0.11999976731115773, 0.1730470506534461, 0.2656040316627872, 0.11141988133350689, 0.09853249746224574, 0.11469989444219297, 0.16691375073165665, 0.23729803280964976, 0.1598656958630008, 0.09941420337605862, 0.12003648590536849, 0.2241630569821404, 0.13454822132424002, 0.24698215026047923, 0.1523051894600353, 0.13720884468526612, 0.14155378895661525, 0.12816888460468862, 0.08951410275673674, 0.15772907664218258, 0.19685920838627124, 0.13439888014428078, 0.1819440280838359, 0.3337169702975981, 0.1695120298574048, 0.12026282658259715, 0.1708510136532207, 0.3037114513497199, 0.2535365533924872, 0.12082755595685975, 0.09000728717975079, 0.1504855008134919, 0.1942879721642502, 0.21014401569001137, 0.12292606996432429, 0.10614818517839718], [0.02445281216604335, 0.020224677150948875, 0.08043729384700138, 0.03087846847671655, 0.06291203283434434, 0.08360847650516419, 0.024148048983225902, 0.04398837790734345, 0.04118391004721484, 0.03190726710243091, 0.01297915737415033, 0.07413594487814174, 0.04950968082994223, 0.013042719689227883, 0.010440620657567297, 0.052501418883161205, 0.027548575383280555, 0.003643548163029576, 0.06579975913008375, 0.0718244890712442, 0.02879692140155502, 0.08510813192133942, 0.031326865484457345, 0.029080146022381324, 0.026269652880728248, 0.004065630529376288, 0.04811082726284381, 0.05674969818022463, 0.004898177059893046, 0.003511651283911159, 0.010638185157140177, 0.05367430332567423, 0.03092276751093807, 0.039677516887745554, 0.06450385245825015, 0.07559718864579355, 0.04419478114634272, 0.03220193516162615, 0.07097770144502002, 0.05276303024842374, 0.04686186262857049, 0.049933928831089894, 0.03140628965000712, 0.09812883807406311, 0.023747005785304694, 0.05773399858885716, 0.006682244054372273, 0.031111878230266517, 0.031170135386468425, 0.026161458283182115, 0.02962693361745727, 0.03697403090735597, 0.09318750967542011, 0.005259571856098069, 0.061814221177971175, 2.893800423029931, 23.06761391701237, 55.020545528781035, 70.91357369576731, 76.11095736103674, 75.28985623390444, 59.642419430517386, 54.39890869202153, 29.656379953507457, 37.304066304237615, 37.88722076723653, 27.381087541580204, 31.56577014154004, 35.499646586756555, 35.12696650720412, 28.84154873509561, 31.844152519779822, 32.698162332657844, 49.36773154043382, 51.14935836484356, 69.98235594841742, 87.88282963537401, 85.24322355947187, 81.11333647081929, 83.15649124883836, 56.88536190217542, 70.29825579735541, 75.74484332915276, 88.37371426243936, 73.94645229462655, 62.455684523428644, 47.509947976758404, 66.54206860450007, 59.74683292450444, 64.15462386223578, 56.819673968899636, 54.795236741342855, 53.2596052846601, 60.13359431297549, 39.468743954935384, 41.85087388561618, 36.96806823053668, 37.35434716747653, 46.77773560247114, 39.45305447424612, 31.83928093602581, 24.37439468599135, 32.61265074053119, 57.39814904428298, 44.547817168697236, 71.21716514710458, 85.10998848945864, 68.80255406902683, 88.21182235594719, 78.77590979299238, 89.97763418382215, 75.49409404877694, 56.928174572606245, 17.254053354263306, 1.9661564452032891, 0.44639584818674677, 0.11639156979658913, 0.061349278586285735, 0.057214150475638534, 0.08029441844912306, 0.039320064092715906, 0.06943257871053873, 0.08078780971587667, 0.06183148496934484, 0.0797624469945027, 0.08011870086193085, 0.058165696795068444, 0.0798383663077989, 0.03591556169633423, 0.11136990941820607, 0.06129075329931033, 0.06093442665352937, 0.021042167659728758, 0.013860641122465173, 0.06243905014989357, 0.06064134056589777, 0.03143034289560972, 0.0501678652700878, 0.01114335215289987, 0.03805226518682415, 0.04167507965898803, 0.006167391792029864, 0.0577302485884678, 0.029610696383902145, 0.065517884739224, 0.021358784137954636, 0.02856269959480532, 0.03474392597713778, 0.08198224038126008, 0.03019440941692841, 0.02250128361817089, 0.07849236514659659, 0.004432446834060454, 0.0625399784034779, 0.06270479072906798, 0.09042105892853392, 0.0575108984635482, 0.01865625768269022, 0.021039813854581407, 0.0291435876786108, 0.04254671151659662, 0.044863798069737615, 0.018190104672084415, 0.06271187704236758, 0.016437238044736367, 0.0102484044093158, 0.005460530125175513, 0.043418588522340984, 0.019779313851388234, 0.06011914439319123, 0.08996584182304722, 0.06294253462504956, 0.04018362138360258, 0.05971767601647204, 0.048896404463917985, 0.0491910495404755, 0.09799395297323504, 0.05356282604137256, 0.055980626343479084, 0.018734892777677987, 0.06092544044217756, 0.03170419060024283, 0.022342435287071333, 0.0873327746446575, 0.06069736074536078, 0.041644083741571636, 0.025979376420558944, 0.015243902885084672, 0.08880870431781777, 0.04850938067501111, 0.05851345474741632, 0.03726835805742491, 0.02862866359552549, 0.0460924958479741, 0.08253960765057033, 0.03320618066936731, 0.02163915125082337, 0.041612011470621636, 0.02327154097597926, 0.14490680258360603, 0.0550805036759665, 0.03644308218011453, 0.060886684054088216, 0.041278832171472817, 0.056687135609888264, 0.017171244121967785, 0.03665145809551881, 0.029235160083419857, 0.0634039149078871, 0.013979852064362457, 0.012155757454644528, 0.0161769998920781, 0.07527854203456834, 0.07230848043916688, 0.042143025315336646, 0.05087614419960207, 0.04899708373892692, 0.02530492601856109, 0.044388103434034896, 0.01641263704626791, 0.04730882896711269, 0.03285905856999659, 0.09836975740449083, 0.027059137130216248, 0.03488582844335226, 0.0463041850936509, 0.0263350767894618, 0.05649389376142814, 0.012913046859114641, 0.05198951893215699, 0.08690230217912505, 2.8040090347490003, 23.88734417576944, 61.66460129522509, 82.44984488333426, 89.96156815559634, 88.43013363499796, 75.43940836383452, 69.34702611738636, 45.08012202478225, 48.48468834354032, 48.57387127414827, 33.92972577002741, 36.28747817008726, 47.22821589439146, 37.947931212763635, 34.49600619654502, 35.21572189946329, 37.12243703103835, 40.73620688530707, 44.45816747603878, 67.57387161254883, 59.60904006035098, 56.99564718431043, 47.749447899480025, 44.62333848399501, 35.09368911866219, 51.86515561995968, 46.791240322974424, 64.34071287032097, 52.55480635550715, 51.849222952319735, 31.840035992283976, 52.63504235975204, 47.00276197925691, 43.411843853612105, 34.07393955415295, 47.21481315551266, 53.11141421717983, 54.57301093686012, 39.59190637834611, 45.32377965988652, 43.10543614049112, 43.847674092938824, 44.91973238606607, 51.140093726496545, 51.59953271189044, 32.59816934985499, 50.056001601680634, 79.04203476444368, 66.79443390138688, 81.60557823796427, 101.09290953605407, 84.78454943626159, 101.76440362007388, 95.67105647056334, 101.57587097537134, 88.77594547887003, 64.84913049205657, 22.92215478035712, 3.0986319866872605, 0.22301758699599775, 0.052378293231970845, 0.014012520926283493, 0.054590709192017396, 0.11069942160599655, 0.03649748974449692, 0.026220671134069565, 0.06153000255806312, 0.06466817065712906, 0.0124862429971296, 0.11906867936974573, 0.07174715249528808, 0.04667782149608097, 0.041649189717586965, 0.028665983568756815, 0.030730293665622032, 0.022679519719414176, 0.02800448771355854, 0.0363630757877423, 0.014476345029599486, 0.020825590773095048, 0.0333546178655759, 0.03769978430242308, 0.022925079627443227, 0.06646081639994537, 0.03200946323152992, 0.023775079077289953, 0.08351601735358277, 0.013196335639804603, 0.0016119015415296742, 0.04907365805739838, 0.02416909916416532, 0.043589406977257425, 0.06481761142851845, 0.03681979825600021, 0.05046338751731862, 0.0842873759627823, 0.041045657989959565, 0.11210395188461389, 0.026260764345586784, 0.015959059368939172, 0.10584393335926919, 0.026877953505684293, 0.05756943141140285, 0.04655774104438963, 0.054136717827209545, 0.05770404838145741, 0.037183525311129714, 0.0779431337310422, 0.03967591193354419, 0.027681748277597854, 0.018218629955944997, 0.07287537784225519, 0.03174864093682939, 0.03453050537275211, 0.07364479824900627, 0.07657699977918979, 0.03135945677997605, 0.02560364476765596, 0.03418357479536245, 0.0701391032987064, 0.14819368750097292, 0.11827609246416439, 0.19283340102241886, 0.08384623189246462, 0.27116674929857254, 0.11637914385045729, 0.08849947292718197, 0.1312677715454371, 0.1998589788713763, 0.12778911949886432, 0.11986468302746935, 0.17315756649740283, 0.24245092404946206, 0.1976444791521757, 0.18802051492516073, 0.10463307776878919, 0.1144357166823841, 0.12199429254378043, 0.16347453689142583, 0.19849215544039206, 0.2634763297054076, 0.28089600464990067, 0.19817398380367987, 0.16149603821817907, 0.2617504868295885, 0.1053036728333081, 0.2546454656628832, 0.1799245896719156, 0.2008853834723273, 0.12427984691795804, 0.104849420998606, 0.12244631506262288, 0.13631595388775872, 0.2051872276370564, 0.14846800826489925, 0.22717497762172456, 0.20196288613782776, 0.12451656808656071, 0.1889506988828221, 0.18512703147867035, 0.13848038210022834, 0.22563840442847824, 0.09801476758213774, 0.2771796814856991, 0.16047717192240302, 0.10359479880501186, 0.18772878864359474, 0.1240804648747848, 0.09274578337827999, 0.14676205303159454, 0.1577373810352818, 0.18360815491647492, 0.14938933624615594, 0.21595836256540593, 0.2549788364840131, 5.91519799924666, 41.569663478482155, 82.60001674775155, 98.95560218441872, 102.5999390694403, 98.63158302922403, 82.90795418523973, 84.02048741617511, 53.75527520333567, 57.97606714310185, 55.932010219943145, 41.95141207787299, 49.162721018637384, 51.906842570151056, 53.41643341125981, 44.31408313012893, 48.037302801685954, 52.65262634523454, 73.38477673069124, 69.91635814789804, 94.06562251429405, 115.29114430950536, 118.30778429585119, 113.50767397111463, 115.10298821233935, 81.78315178040536, 95.80426800635554, 104.61977927915513, 124.8814021387408, 101.82327055162, 84.05716157728627, 70.62814281832787, 98.70985000364243, 85.44899894345193, 96.2007333386329, 88.37540088161346, 84.64310876784786, 77.30539752591041, 83.98450359221428, 53.55769757301577, 59.73001380120555, 50.881515395256784, 57.0310151961542, 70.0071688621275, 59.43100760059973, 46.091309055205315, 36.00212574005127, 50.39237622291812, 76.63956734441942, 62.26908168485088, 92.3567242776194, 111.40496976913946, 90.31854306497883, 113.23195488222184, 105.52061434715026, 117.49619883875694, 106.12800905781408, 87.13949341927805, 32.6850204313955, 6.086644309182321, 0.7647561570329051, 0.37889277682669703, 0.10198521743258161, 0.13209862454283622, 0.2573524066998113, 0.19156705768358326, 0.11312201378806946, 0.17854376215367548, 0.15408292713184513, 0.1236809270396348, 0.14290587285593634, 0.35803879100468855, 0.22425077404947052, 0.19812567429917474, 0.1648150222195733, 0.2008128349458979, 0.13408841535208688, 0.11311187844483123, 0.13185880837901948, 0.13923436583530518, 0.2003286214124772, 0.0846107263538626, 0.23452651056070484, 0.11948068145542376, 0.11554756306953008, 0.12741589678391335, 0.08389349185651349, 0.14741886617435565, 0.06475527485411975, 0.10933722534607496, 0.1780314025499167, 0.07494212984437905, 0.10361657868469916, 0.20536658414188894, 0.13432800168952636, 0.12818859604698035, 0.21088296878001384, 0.14452184340165508, 0.2342254533282211, 0.19765080703843027, 0.1499310063738977, 0.17110979815404262, 0.10661052690157968, 0.1785741911660279, 0.11580172039928938, 0.09884712211186848, 0.2278287570563055, 0.12239648870402768, 0.19583061277385683, 0.14978454568453375, 0.10653091504448846, 0.06246064616847904, 0.16458586999966254, 0.09146713666738042, 0.1956785902861626, 0.22584759239708224, 0.2918402141621036, 0.1614934335192365, 0.19499891707974096, 0.11578704215466015, 0.23457747072942797], [0.024000257216093522, 0.06825113323547187, 0.03947612386377108, 0.10539864475328116, 0.03778021587359329, 0.04722139535231456, 0.06366160007253771, 0.07801569757923003, 0.04980207743844198, 0.06317172897979617, 0.03734295969949134, 0.027580278016807094, 0.025199188648032087, 0.0060651243209929, 0.03384438170600803, 0.011614711688561066, 0.07457776310583276, 0.03451782661760527, 0.0511570111848414, 0.07512605989411955, 0.026234675221325412, 0.03994880011305213, 0.04572061761733025, 0.023945121868183056, 0.006797537414146768, 0.0397228769537422, 0.021875809217172287, 0.050483715660389394, 0.0730740933889343, 0.0870784717581926, 0.06258631523157801, 0.07140520915028549, 0.02770018609871547, 0.016594450778117584, 0.013505448286812152, 0.06760367402626623, 0.033095005989795735, 0.04304463419342234, 0.018372100349816105, 0.019064917709798585, 0.038002680145925095, 0.04366783905894526, 0.04450919512178629, 0.033399181200131293, 0.024253719321061528, 0.04727818161970185, 0.009310189934988177, 0.08458782032492661, 0.05082420726877548, 0.11683716483774687, 0.01655881811353949, 0.04858860948814019, 0.03517357872859125, 4.592629200027836, 21.005133621154293, 54.85963813720211, 69.94881968344413, 78.2723637550108, 75.19149887946345, 78.97963769974248, 63.71179611452165, 33.72333065156014, 29.468290536634385, 46.013093071599165, 50.8803229947244, 56.87766228952716, 61.63643083264751, 50.013659615670484, 54.593579846043745, 75.22741210076117, 96.07357009764641, 89.30298651418379, 78.49598592327487, 51.96776874603764, 71.2323917881135, 58.39705121132636, 51.186412995861424, 51.72520937458162, 57.07271391345609, 65.1663443350023, 90.33334609000914, 94.14741177712718, 90.84627443744291, 61.98841648717081, 80.7057237625122, 98.34641887295632, 88.74454298327046, 62.002631156675285, 75.74508651610344, 73.66745410426971, 93.67569969546412, 70.68072611285795, 72.91862656993251, 89.33375358581544, 117.81500908636279, 87.44139040670088, 104.4228841412452, 77.24908797971665, 74.7186493104504, 77.5279135857859, 61.603796712813846, 79.2248329039543, 46.99818457326582, 37.91782309932094, 39.11268295780305, 41.1110128894929, 34.64578190157491, 41.12238384062245, 46.62808149091659, 55.265266126202, 73.75864136603572, 77.03077670066588, 89.11317517680507, 76.28351811439761, 56.91369318193006, 15.421493572573509, 3.734512910727532, 0.3572913956257605, 0.2202471525919053, 0.15186626704469805, 0.053670522681767904, 0.04959097808046688, 0.11397057873827797, 0.0066182307050293016, 0.013096067179445059, 0.016738500205739852, 0.09834144279480943, 0.053406452174268426, 0.017716378882347096, 0.05481139614036488, 0.02650074330308745, 0.06432327021273875, 0.01684673885334163, 0.020222647017949534, 0.014567085271400791, 0.04472902405165857, 0.0608334371129111, 0.02978718771989788, 0.03538910990520831, 0.026863836420459614, 0.040864098982344714, 0.07111902934529128, 0.12989932400805335, 0.016958495759735667, 0.02235818797001435, 0.08116365245152866, 0.04417787741629347, 0.060931155458092696, 0.05713105291849183, 0.07831027370787437, 0.038447949599715016, 0.025426222634832227, 0.033271351769085855, 0.022082034340729157, 0.09032615595647404, 0.028206512760070544, 0.036300769856860565, 0.06928872272011734, 0.04337434311427417, 0.1004130288117355, 0.05995864131217522, 0.07226387113933602, 0.0974331689517825, 0.05505620719744794, 0.10020282960707143, 0.02616983545463412, 0.07354074818713051, 0.05187008965520128, 0.07599868000515046, 0.03381556913917584, 0.06738721588326078, 0.06274850753646705, 0.020338492918639414, 0.022707403404638175, 0.013306676241148625, 0.039695772762981155, 0.0854263571842063, 0.06360321268138867, 0.08789013425308852, 0.04285040792197951, 0.03349825935137849, 0.06769234870350169, 0.13683988141917414, 0.07141479291021824, 0.021723032132872654, 0.04387778545459432, 0.020386338939950354, 0.017990799237703605, 0.06053123457898056, 0.05175081359583044, 0.020698969845750162, 0.033216400282277216, 0.02794370438242632, 0.013416729559521041, 0.02103619217391937, 0.0420593110574109, 0.035816736354102055, 0.09556112585649376, 0.04195785803359844, 0.022459665891684355, 0.00726276106433943, 0.05168511389544414, 0.05252111883413407, 0.030242749564950506, 0.05605659545249036, 0.036214623269775224, 0.013088021341020302, 0.00931030676339663, 0.049622843507677324, 0.08289259032256181, 0.07722142528021529, 0.05268619162961841, 0.0947918893108445, 0.06061511354581003, 0.00620878735301836, 0.07599278878901275, 0.06379043307876395, 0.06018842172418391, 0.04977725618969529, 0.06622263966428657, 0.059431833290164514, 0.028391507672025796, 0.024829143282747077, 0.05220743647265819, 0.04238008739306562, 0.006018741527617339, 0.04505788644535407, 0.13468683727325934, 0.04250288362644854, 4.742191135883331, 25.202483515585623, 63.981702250819055, 86.26014509508687, 87.25010425813737, 86.96113540280251, 91.04702134286204, 80.18568808032622, 52.62063549410913, 44.26972112348003, 48.49795379946309, 53.94448641807803, 52.22815136755667, 46.02620555508522, 44.38074773357761, 37.40508694802561, 56.16857620977587, 64.3687185933513, 61.06475714714297, 61.50129341310071, 55.171415575089, 54.029229225650916, 45.34197553511589, 53.59406971162366, 55.103754689616544, 56.15749551403908, 62.431648239012695, 69.41246694134128, 71.13467770238077, 66.88103983479162, 54.51223381104008, 62.431397207321666, 61.62929996367424, 60.59821474936701, 51.27283457786807, 55.55915755610312, 60.703714739891794, 71.13510916309973, 61.38005295107442, 57.259995322073664, 67.39487817210536, 68.82559407141902, 61.38468527024793, 60.38795217390984, 58.050545107933786, 75.18715289331253, 64.11821249992617, 44.97089186022359, 54.76739968022993, 44.141353714850645, 36.931782384072584, 44.05336710714525, 67.77173165352114, 61.386473871046505, 54.37858296978859, 64.98137320241621, 69.17635594644855, 88.82479467699605, 86.65324503375639, 104.1190730371783, 87.02346186484061, 69.3923451823573, 21.97098981949591, 6.076254440892128, 0.25497027162101965, 0.09506234133075323, 0.05576590338962213, 0.031088872609900373, 0.09177835988661937, 0.07254377668423038, 0.04504434201085279, 0.05321495700627566, 0.001000416923488956, 0.0695391875060816, 0.04247047044637223, 0.030721650278616338, 0.05943021301420466, 0.00584052266335235, 0.08517597666791371, 0.05940033558515772, 0.03734554907667541, 0.05986486831980367, 0.007045708724387712, 0.026282841084344734, 0.045777158736581766, 0.02917592616511449, 0.008213704568333924, 0.030677862608084278, 0.02626652532677737, 0.02158533548936248, 0.0524772756222275, 0.0802054373367179, 0.04447266038867735, 0.047743212311498584, 0.008518643951373956, 0.027905869215065916, 0.03639343585218153, 0.034989158382579204, 0.08301865775138141, 0.010869627022334646, 0.03095682394961196, 0.05527566457467695, 0.08254994217666888, 0.04979527457767437, 0.012560802504360195, 0.032067216684921615, 0.06237714258473247, 0.06033341152473323, 0.07657247219955729, 0.05280105885298503, 0.041454760432844205, 0.09036167179264369, 0.0511238472385993, 0.08346246014679633, 0.045475143894192674, 0.04418188405613746, 0.052662485038801554, 0.06930213691967149, 0.019406889783098333, 0.04510567501007069, 0.027875570437660622, 0.09568855692181857, 0.01648580227347632, 0.16473416930004475, 0.11595974901630995, 0.14019651098116753, 0.16886298484619588, 0.22283746440324093, 0.14137855400481533, 0.19111895753491312, 0.11648991250342901, 0.11197600754037981, 0.12219716028700914, 0.11901522941526868, 0.16300429680174397, 0.22756165284062588, 0.14000996857160522, 0.1484456231757518, 0.16769270893306504, 0.16150467968996496, 0.10592150742248183, 0.1803738849177476, 0.2125894143095901, 0.10414114972997097, 0.22337850633888479, 0.16701041570594236, 0.1724690373145765, 0.10024120295119864, 0.17216761235988912, 0.10354464302860922, 0.12212338601990093, 0.18764108689802309, 0.1327693191987853, 0.19077627108462397, 0.1391874199673053, 0.09745120266152006, 0.16010690630683977, 0.09648944822049911, 0.1311258307748264, 0.29020299233736535, 0.12546550587660846, 0.0976906204596162, 0.11533579338462123, 0.15019714531879272, 0.24247298738168133, 0.15432536331636293, 0.15939973054393647, 0.1634392202381165, 0.1636171518194099, 0.2575487703565629, 0.14980582760707026, 0.15535489355604495, 0.24569052602014235, 0.14959195118036964, 0.18876706760737205, 0.18090063165272438, 9.272569379498883, 39.667329634389574, 89.1305983451105, 96.8976051576676, 100.4593369268602, 94.82892359456709, 100.51787437931185, 85.50133905103131, 52.28619852373677, 47.13440064461001, 70.46068114619102, 74.10655560032015, 82.65795015519666, 87.32870855639058, 76.13325211309618, 80.7882425861974, 105.05246377760365, 127.40095230840869, 126.5252596332181, 110.86598119428082, 79.91153793950235, 97.49595488271406, 83.29961069168584, 72.73668350711947, 75.04772832316738, 82.80405059937509, 94.56522264788228, 124.58123883893414, 136.03033927179152, 127.10418578117125, 90.45893253818636, 118.45589299355785, 142.90650521555256, 119.98491133413008, 85.48259012160763, 100.35010676230155, 101.67436953513854, 126.55852133227934, 98.6388707930042, 103.99261582282283, 118.79282459135979, 149.7553400839529, 112.14265777218728, 133.19305358394502, 101.76926735908755, 98.31630291477327, 99.73525954831032, 82.38901676670199, 106.95489960332071, 65.23205972486927, 52.52878142941383, 56.67791558850197, 59.91105864124914, 49.736552007736705, 57.68190899202901, 67.96366107079291, 73.46142768859863, 96.848355877784, 100.63319990711828, 114.33170903113582, 105.87009752950361, 87.2977924346924, 36.756970190232806, 11.20973583190672, 0.7642456973271986, 0.35085769730710215, 0.32959128039017804, 0.13019353241449402, 0.18679595402171537, 0.24214933055543134, 0.14466059724650077, 0.15629917353151307, 0.156596323715583, 0.2088094752041563, 0.14789906540705314, 0.10502447975018334, 0.18064333336247554, 0.23363604060103818, 0.14559712441217515, 0.08847124258717222, 0.10759971495116911, 0.20927585421069977, 0.13032061107937368, 0.11510998130806031, 0.13108905855446093, 0.21592747390029893, 0.12868908894879202, 0.15822087444605368, 0.16504988945539922, 0.21196638564428977, 0.18250509555782043, 0.13527753702815504, 0.14944912174776678, 0.12964735768975752, 0.2367002697240922, 0.1408012148233191, 0.29007287996430553, 0.17857497257571067, 0.2127041129936134, 0.12486110080874736, 0.18323963598137905, 0.1905164600259835, 0.14067462645471096, 0.11849848012770377, 0.19863662430115286, 0.13327251639096968, 0.13314119359898952, 0.15031746708818022, 0.1377121338080014, 0.17828007469013815, 0.1400618786893545, 0.14423770139053946, 0.18256333356182422, 0.1448989578432614, 0.14223615879253035, 0.18388221521050702, 0.1535825184997051, 0.16597336248284386, 0.10803304492465912, 0.13935883980124228, 0.12476553900107262, 0.2143772796637589, 0.1520620178311102], [0.05377569123201313, 0.01371735874037709, 0.033993424111676794, 0.03544656649952935, 0.09570812280740469, 0.05510050623166946, 0.07035613600765506, 0.05194416269659997, 0.053896782919764526, 0.01737741370415015, 0.03634749355936243, 0.046940099357837634, 0.029246195579969117, 0.03928706868581715, 0.042825104037840525, 0.036590190213774486, 0.01867783454907758, 0.067455910987431, 0.1512521709645948, 0.07872248263729197, 0.04846501652331603, 0.0060587131226765775, 0.041893399395649476, 0.04974560909754327, 0.09076850278483284, 0.03723876791134958, 0.03990203427571443, 0.061271593440324075, 0.0590056241039307, 0.026571416829322136, 0.04522146153894644, 0.03946795353605863, 0.08218994980017025, 0.06160447396518243, 0.0502501929088706, 0.031687214091840776, 0.029012536847843762, 0.13849032592148552, 0.036934232639689604, 0.01813677154601582, 0.02303037841263558, 0.0443342321311995, 0.05090629742030175, 0.04172340831569126, 0.016786409429304542, 0.01722497944419663, 0.05401743027651983, 0.07543215798514505, 0.03426901275111783, 0.06244566148868012, 0.056597047500432505, 6.34375665457018, 28.44961177918219, 60.077516186621885, 76.3504651284987, 84.84951957579582, 77.86720645043158, 75.37183377050584, 49.00932496593845, 26.110049370796453, 35.296408976278, 36.715004751759196, 41.61111116409302, 42.00983185921946, 33.19237116844424, 43.989765874801144, 65.8532533337993, 52.47324851251418, 47.04665330148513, 47.90231050983552, 62.4687538608428, 36.838681005662494, 21.307597391067013, 9.77587321112233, 4.563282516694838, 5.8053789888658835, 2.0099868481197665, 3.5824472769614193, 4.51578212361182, 5.080972131221525, 6.335378471882113, 8.75527641465587, 6.992593657585883, 5.875800242347102, 5.0632513530792735, 3.3639938119919073, 2.4403670766661247, 3.8576495935839996, 4.576507768323345, 4.315644166161937, 4.027884871728959, 5.879822632958812, 8.602534417183168, 10.944233536720278, 18.737495714618316, 19.376585137459543, 25.87035332956622, 26.42489410215809, 27.305356379478212, 48.800788233357096, 69.81025018999654, 63.605029198431204, 79.79509845856698, 71.89022817919331, 59.437381452129735, 34.12658560660578, 31.77387345221735, 40.61357398186961, 37.4246125067434, 32.99714303785755, 43.46078718862226, 82.54147929529991, 81.36055561804002, 86.41478061676027, 83.01239121344783, 75.93610594349524, 59.776042815177675, 24.95828655458266, 2.6065806996437813, 0.6115842310170974, 0.1945277423627915, 0.06693992012691113, 0.04675203243330602, 0.04264377485660296, 0.04776489259975572, 0.062410160974268956, 0.11784443256234932, 0.019095091997916182, 0.03695129341776333, 0.056439857749689015, 0.04559063547921758, 0.04790209511655474, 0.024314872289617217, 0.05440152760955596, 0.04233687237325696, 0.022951877383034558, 0.06684034401851316, 0.025077001454548973, 0.01647471698121198, 0.056765077395304564, 0.026912076977051558, 0.08020962783766371, 0.03399483371345747, 0.06429237388675252, 0.04591366028293006, 0.020389514374396494, 0.03750397605941661, 0.013217396354452978, 0.0032557479918919386, 0.036125469787587086, 0.013573967190759798, 0.021669656871968222, 0.03995123627265135, 0.05540243297394726, 0.030839342451203736, 0.015492010993071863, 0.03273882873116001, 0.03800343857297013, 0.0382805900317767, 0.009497652607669514, 0.07369970377053946, 0.06173616447936624, 0.030547845996015018, 0.02363014290289533, 0.03201060853297672, 0.05489322199155727, 0.045944648539467205, 0.02593285573135701, 0.03818709283105789, 0.058295085215039795, 0.10602899721913761, 0.01683897072178943, 0.07387926711911157, 0.027433667940297918, 0.0265085554846953, 0.053478529556624355, 0.08284740645678774, 0.011220366971927785, 0.09015580864563104, 0.04643677576114574, 0.05203564891651754, 0.02842569434564681, 0.05137512407776329, 0.027143441275843692, 0.0707019021313998, 0.04647925533654709, 0.011606772144835804, 0.08499028461594736, 0.011271366402657043, 0.027662082800581574, 0.08138850691818422, 0.030340305116448193, 0.0337706572346149, 0.03181254224581344, 0.029994238303193164, 0.010241669538851467, 0.04434973008990769, 0.05514762446945233, 0.05478339562673242, 0.05684115375662523, 0.11354379881654056, 0.023102802449777242, 0.01980803831810913, 0.02238014213470442, 0.0167649072564898, 0.0460738837418537, 0.08013881066994322, 0.04236907487915408, 0.03804681447124289, 0.04241919235116051, 0.02484170712470528, 0.06037378818878244, 0.08159958712396123, 0.07443665737105955, 0.006002372622700228, 0.030805178760220448, 0.06223559634940279, 0.06531597460590063, 0.029099443777193947, 0.023933919747510267, 0.060854370465442065, 0.0345496001142648, 0.015345404747002309, 0.003909853253243191, 0.03212253780915372, 0.05848490265047839, 0.09346713176778249, 6.014612922745367, 31.866794401599517, 72.75241221151045, 88.90449723889752, 93.85132774229973, 83.71196946790143, 89.4967516006962, 69.79496079106485, 55.480423819634225, 51.215379699583984, 34.79092528743129, 39.03625949736565, 51.943889356428585, 42.76954789315501, 49.52088832855225, 59.818420102519376, 51.17907031889885, 53.812279009049945, 48.68374470741519, 60.58429033525529, 36.40969530228646, 22.47124302771784, 9.717905482938214, 5.224193065397201, 5.929271953721201, 3.3277440023037697, 4.045938806187722, 5.5475753257351545, 6.037965243862522, 8.190094742082781, 10.285769566412895, 8.617640445309302, 6.932181802488143, 4.530163984144888, 4.6060549828314015, 3.77618343599381, 4.058872086386527, 4.919434218637405, 4.938843577138839, 5.448464876221073, 6.240609595852514, 7.961337210670595, 9.767132209193322, 16.526385045820668, 15.962644353989633, 20.01347214944901, 20.89868441704781, 21.516767586431197, 36.20018582190237, 47.145195007324226, 55.853531437535445, 56.98309167738884, 58.43187401371618, 56.078526435359834, 32.95205539272678, 27.537337118579497, 36.967009190590154, 45.95758761129072, 49.13713932037354, 59.908340438719726, 98.62953555199408, 90.09516408366542, 96.98905914060532, 96.73535239311957, 90.64054612190493, 76.80467559445289, 35.69477273571876, 5.866623367032697, 0.48319402361108416, 0.23486158209702662, 0.1493691421684719, 0.0723892031237483, 0.08797029769348522, 0.0338768600035579, 0.03541311143987602, 0.045189596111735994, 0.04504671688341806, 0.057950698049558755, 0.022754634640389876, 0.04363514242633697, 0.08745188599512463, 0.030958076503368157, 0.01679658690737861, 0.06435937593661009, 0.027669282111849998, 0.052841217181975805, 0.09668480830206987, 0.03753406799308235, 0.03203842327028754, 0.015137313241739909, 0.09119079343133396, 0.058178996081433954, 0.04752721382124771, 0.04573053462551006, 0.055138025387761094, 0.09757573025361185, 0.02450965397480515, 0.013194520969033964, 0.020691337694804517, 0.005513902992055181, 0.0250552254053013, 0.01844300178720826, 0.042449816715933626, 0.07244838341589897, 0.02360772525501107, 0.04933076099522653, 0.014579070716976159, 0.03863875911901555, 0.10667620361932825, 0.021597384137191603, 0.045554644668534885, 0.019903335825449998, 0.08378827734099281, 0.06659689659793532, 0.04404527142704014, 0.06633150075832683, 0.038123162793776685, 0.06088703645453338, 0.10032260745403268, 0.061562626412318605, 0.014817110514418494, 0.06736832415504802, 0.07645486238142175, 0.08502551699958502, 0.05085686559698755, 0.22280364928226318, 0.11704153411330716, 0.17978568260948505, 0.17791949242593783, 0.1545543010316549, 0.1227182839366217, 0.1444998873217452, 0.13687098458889993, 0.17341393016038403, 0.1459846270060347, 0.1810827613958428, 0.12291728293583279, 0.11895046434215001, 0.16665418482115193, 0.15454542973349172, 0.07423702251887129, 0.13233176041995326, 0.13108309839041005, 0.1848029762866997, 0.14363285965256153, 0.11144997326717263, 0.14420393223483718, 0.21806531886179603, 0.21427569640499933, 0.23739215437202688, 0.13485261870007362, 0.14189439164775033, 0.15295267165187867, 0.20242479119089343, 0.0998328551049194, 0.27399217349386984, 0.1383392380610589, 0.12901613188366737, 0.13087695945174466, 0.19451255850013227, 0.18388782297411274, 0.21960733127930473, 0.22320293430839816, 0.0896723228957384, 0.14303966245103267, 0.12395784484162448, 0.14943787557703836, 0.09522669017314912, 0.12062725460817739, 0.18238842036695252, 0.20296661453622006, 0.2459460163428899, 0.13224274100315186, 0.16373129892012767, 0.17047789819057912, 0.7497654098176187, 11.37994610494183, 45.99646614443871, 90.84886320175664, 103.12998464030605, 104.34992021129978, 98.90215596845074, 95.97146295732068, 66.29963474888956, 39.651926486722886, 48.404668069654896, 54.33695877751997, 63.97867418104603, 65.26851815562095, 54.02400070621122, 67.35050047597578, 92.33774785072573, 75.06046818148705, 68.4766992445915, 67.45886771909653, 84.5814569534794, 49.129718196007516, 28.74923771427524, 13.73308873945667, 6.8634824695125705, 8.932999987756054, 3.847384995991184, 5.653232701363103, 7.499248173929031, 8.554660908637508, 9.39764395836861, 12.013693259608361, 11.216103799881475, 9.88195469302516, 8.574484567488394, 6.379763032159498, 4.379299331095911, 6.562062050065687, 6.847475276839349, 7.053019240979226, 6.090295545516476, 9.24724655766641, 12.38939650597111, 15.522293583039316, 26.284057478750906, 27.48649339522085, 34.413248108279326, 35.454986479974565, 35.24979945152037, 63.24770519810339, 94.07178063546458, 80.00312528302594, 100.51465803577055, 98.47823404496717, 83.66132382423648, 46.5559922495196, 45.430095503407145, 52.329674074726725, 53.51930149139897, 46.0217301307186, 62.686437560666, 107.38981200802712, 105.08392903112598, 108.23174876551475, 106.99928514419064, 103.92830464147754, 93.83198261260988, 50.59077362860403, 10.83875511923144, 0.8932381111287302, 0.3287589411822058, 0.3274466938549473, 0.1561679733136008, 0.20524689056459935, 0.16868310740157483, 0.2473989327348048, 0.1405543966158744, 0.18506736855112738, 0.18316123454320818, 0.14018328830359444, 0.14865320235971483, 0.18992249673653036, 0.12354525286824473, 0.20260122123985522, 0.14845740560802723, 0.20313193631027976, 0.21452682002657847, 0.2854661481274713, 0.13085138743683217, 0.18208406895639437, 0.1187302217247986, 0.18606342074851837, 0.1679810644277642, 0.1292821788980115, 0.1468572624388241, 0.1474770428913255, 0.17954839453581842, 0.13969794096004579, 0.17384332244194325, 0.08763360205076395, 0.07590900175273418, 0.10517919120649177, 0.11826375078770424, 0.1044004321879437, 0.22473679555039253, 0.11468442712700176, 0.164826528860196, 0.1495877223750276, 0.18029128531775168, 0.16779752508286508, 0.11785301274710125, 0.09721143246297875, 0.07438509199287623, 0.14728864654898643, 0.22698216861294163, 0.1643034593472558, 0.13032966623863868, 0.20100841719296672, 0.19100382984165223, 0.16403565033068582, 0.14811027584777725, 0.13408859921318872, 0.18973342623681794, 0.16888474174324544, 0.1484827631183209, 0.20670515425022573], [0.010870238935064164, 0.06183156157813727, 0.012379041441055316, 0.04051295492137152, 0.03665037408110596, 0.018819152873249787, 0.013399370964766752, 0.08909961854618403, 0.020209512440487742, 0.04149445144820117, 0.02989209771546866, 0.06516485610195706, 0.04856991311234813, 0.020685134297837655, 0.023582107274823134, 0.05815587554787917, 0.07154326585512008, 0.031123204840227004, 0.03223574262172465, 0.09219741764208002, 0.08781265978130602, 0.028159440487563133, 0.04664790576263782, 0.052389845837868994, 0.03248005189121731, 0.05007322659836181, 0.11180962856498458, 0.07426556695492999, 0.019745830063437744, 0.06848013989867703, 0.031333900086822054, 0.03775924804710573, 0.0584207427868199, 0.03540144392078923, 0.05520912983845319, 0.04019170744164337, 0.05977290329493343, 0.07426814101035557, 0.04034301363712838, 0.014937943647495441, 0.03449240398983802, 0.06256836579151212, 0.03699557329978674, 0.026042226273866913, 0.019749036141400857, 0.02561183233234671, 0.05824128286011758, 0.18648625531744573, 1.0760203772975554, 8.900128564526959, 37.97166939704649, 71.88890241807508, 74.3493503139865, 77.91425135827835, 69.72392666724421, 66.38739385912496, 52.0120366158024, 31.577186199926565, 24.887226935355898, 22.120561561276837, 43.42570158743089, 81.06130230811335, 64.10473131364392, 55.335017634976296, 32.840893460858254, 28.818969611198675, 21.657008009572184, 16.823224136906287, 9.72203181635949, 6.664019650028599, 2.4177558383634015, 0.6483455422905184, 0.14139470313825916, 0.02666812010800406, 0.06683510397711108, 0.06888776762230743, 0.07662550080567598, 0.1324210556284074, 0.03341118962834439, 0.07080525505326449, 0.14998043436677228, 0.08915643162664869, 0.08348573389793597, 0.07125330157577991, 0.055630382435816916, 0.02519087467883383, 0.05539049349364735, 0.06877101582264708, 0.038571128877060074, 0.07059782142600707, 0.1418783650883744, 0.132011566311121, 0.09381901127316299, 0.015696149484644976, 0.15791286113521746, 0.028584753350925543, 0.07130870505446388, 0.8614870761671375, 4.22744280868961, 5.560619658039463, 11.99326555575094, 18.470080283380327, 36.73344773630942, 35.94594563207319, 53.91064813060146, 90.98754252156904, 86.39999328121063, 71.85908456002512, 50.57818674272107, 31.20409231032095, 26.5869076021256, 27.298835439066735, 48.26333722760601, 70.56089770409369, 81.6666966099893, 70.68075749181932, 73.7429597300868, 76.04673247183524, 67.4878461899296, 30.865699629629816, 4.2278566187427895, 0.1560810836212289, 0.2335894930987589, 0.047063692322661804, 0.05968780241786473, 0.16015279497350418, 0.031059954705978596, 0.04206032995435019, 0.0574581571404011, 0.08985179431375959, 0.096596562634072, 0.05474773423385717, 0.06152727145461306, 0.003051335863288372, 0.008587424282825763, 0.0839530551926263, 0.018183794022808154, 0.07119318665636164, 0.05907598927977586, 0.005701785097875062, 0.04513405090678604, 0.054710931369974736, 0.04207656718790532, 0.022917263615395755, 0.03410310108935641, 0.08090821575493583, 0.05739783537724326, 0.025764456199061488, 0.01892361470738486, 0.02734683953495997, 0.019460364635432922, 0.031154679562596065, 0.018959015630365863, 0.05805170291193551, 0.05044508950724717, 0.009367553641148394, 0.02929621920620482, 0.06611648286061902, 0.04911207353636142, 0.024911545615102497, 0.020947973318998853, 0.07146417493781737, 0.08029661712146575, 0.050055123940711065, 0.054446707644890395, 0.02525794950704421, 0.018953047805435715, 0.0459310811223282, 0.0902562580942627, 0.05758064310817469, 0.08630469231115234, 0.09685365408058129, 0.025581661874668735, 0.02390072515775119, 0.09165583178400995, 0.024627445738822706, 0.020577924123274225, 0.05674685982446517, 0.011985296188222786, 0.035156977603272084, 0.01452380609172847, 0.027403618141468016, 0.007398738798069498, 0.06574882960487759, 0.025296882095356143, 0.10023397874207267, 0.03845490567806748, 0.029727547774992646, 0.02510924801050175, 0.031909237863616116, 0.02062980168228669, 0.06445126818312753, 0.08296577470196832, 0.03983115199052038, 0.04133387941927199, 0.08044110130398505, 0.023130421834667365, 0.10037249509966183, 0.06759644215626102, 0.01603955797280275, 0.009907480918862408, 0.010924848555136594, 0.06396023646718071, 0.09541618968209914, 0.04351004409874159, 0.052179160167373, 0.07288801829300581, 0.02174675596066781, 0.013577302546060134, 0.021666724670438037, 0.05329107933287179, 0.06429001433594574, 0.020240569644938075, 0.117206733313299, 0.02754183763998651, 0.04421514759380971, 0.031026128093681993, 0.028219300682746598, 0.02168628672558454, 0.02124833915713093, 0.022016470620949424, 0.008361924387093994, 0.0565054310455678, 0.11849739228285129, 1.1192410968003736, 9.978682302659559, 43.73652981173608, 83.86815824816304, 90.75507148619621, 90.44379218932121, 79.69098306471302, 91.12127965496433, 73.11935778587096, 53.103738138752604, 36.0728499966283, 22.62838690511642, 40.69349619650072, 63.81436217215754, 63.211042804102746, 52.096304816584436, 40.248099296323716, 36.04251438571561, 32.34192875123794, 24.387607189916796, 14.702960464262194, 9.128081029461278, 4.65474630555799, 1.2841714918613434, 0.2962500920459148, 0.2759025209853726, 0.019517164309358886, 0.01364616331674399, 0.059096585553620136, 0.0367328702592321, 0.12030034190824918, 0.0887208876590575, 0.22464166275195538, 0.1026190632593728, 0.041784519149411115, 0.1618257624607894, 0.21924679498037986, 0.34057572484016424, 0.13339247043815353, 0.18026366018720213, 0.020402068640255643, 0.1458954237281315, 0.07906070279498255, 0.150788304726443, 0.051349628671643235, 0.054601794484281735, 0.1338728841754698, 0.11723981298986944, 0.05295170621285516, 0.6446402507924265, 2.65002683285744, 4.783281885808514, 8.67766643724134, 14.961763351194321, 28.656871780272457, 31.30253007335048, 37.32935382473854, 51.93067881368822, 61.414699246806485, 58.97574986180952, 47.44648010500016, 29.25270138248321, 41.925602882139145, 47.44047495626634, 71.35385190286945, 88.21594868936847, 92.77114622054562, 80.49288026748165, 82.23773094915575, 91.96717016158566, 82.41878755630987, 42.019661318871286, 7.114543578317089, 0.18718161800455663, 0.1321826490663713, 0.013430810255569317, 0.055053855307520404, 0.043101462595645464, 0.04881798387354901, 0.024405730317436883, 0.08502344856218946, 0.038377561441232125, 0.07997846080651207, 0.0101651287367267, 0.03037268956822734, 0.044795474518210664, 0.02229834309658937, 0.04283019469209737, 0.051270085762465195, 0.025821646577828837, 0.009651991553724775, 0.06485581623330232, 0.05090346289498191, 0.041987065135711626, 0.022976645005626545, 0.0533000655442236, 0.047889661509543664, 0.1142048407646437, 0.057030817974478974, 0.03344798483134758, 0.04032763825248807, 0.015547752508052416, 0.04759687802664215, 0.053688272938973484, 0.040800325993087985, 0.09587313048541547, 0.057510411997716275, 0.028996592642919674, 0.01699239706560489, 0.022961763747697397, 0.03957109195330451, 0.023587701631890192, 0.0027584092177060106, 0.043787302809857556, 0.08635183736201256, 0.07023468042813963, 0.03143429016363958, 0.02325070529965864, 0.016737104010497852, 0.024650696507324616, 0.07636462488482076, 0.008635096976743832, 0.03938237002359764, 0.0788404142123557, 0.027664465334026084, 0.03744437824934721, 0.030118817606219844, 0.029584969236184994, 0.06760670007356713, 0.14489581688277184, 0.08923974368841418, 0.16682621752542837, 0.16316065534708962, 0.1483435036554452, 0.16188194734915612, 0.16099242733851557, 0.19153273694457548, 0.15809316758907613, 0.09428866147514313, 0.2351091663923956, 0.1989539992064238, 0.18343986072126897, 0.1752398394408726, 0.13896517786047152, 0.22486601926146016, 0.12454369525995948, 0.10269846061184522, 0.17455190780662722, 0.1680343994690526, 0.22095621293110235, 0.1752070355559549, 0.19135675122660978, 0.10866133661399927, 0.142149223134883, 0.1522664407328252, 0.22186235704969978, 0.19350784950919692, 0.21846926170251063, 0.14562586803109417, 0.12536966827728097, 0.16277212619541154, 0.13018919635684262, 0.18999274699918686, 0.13177331296666978, 0.16836078356831305, 0.143957634967181, 0.12406426977606551, 0.10416189539096049, 0.13966815546154976, 0.17206236720085147, 0.0952158423681413, 0.1648232500038801, 0.12940423202610787, 0.14949225249790377, 0.17591713777472898, 0.23105435493972995, 2.8107155522992535, 18.328963210505826, 60.43239262796218, 101.05605494591498, 100.40721647201046, 100.23197281745173, 88.96465070786016, 88.48342295615905, 67.75282582929059, 45.34491731274513, 37.25287545111872, 31.506532546012636, 62.11552481497488, 109.44884454050373, 86.64111706518358, 77.77750184459072, 54.85193852455386, 47.315437639913256, 37.09898517977807, 27.47970573363766, 17.925198347337787, 11.271319985389711, 5.048131596657538, 1.9056834256456745, 1.0215347332339133, 0.3762270359983368, 0.17632334823569945, 0.20489404578843426, 0.3450901584038812, 0.3727011010050774, 0.4151784394296908, 0.7790402034598013, 0.625507848397378, 0.49318837602773025, 0.39233072510650085, 0.23279679127998892, 0.3308296461980189, 0.20251060836017135, 0.25008491360612456, 0.21805401140403366, 0.11734864344039272, 0.23599526965089385, 0.3274638235809342, 0.2641829385632469, 0.21202689126854946, 0.11658556624165467, 0.33447867619895166, 0.30086800876644354, 0.2769451360068014, 1.6049063974811186, 6.647050496070616, 8.02577586904649, 14.508055929214725, 24.180421713859808, 47.211769396258944, 45.68153119856312, 68.58728654922979, 118.59883200737738, 114.27288132329141, 96.98851000878119, 68.38671222809823, 47.748557521450905, 41.631574169282, 41.09882608536751, 69.70612695140224, 90.44427856322258, 101.99689818966775, 89.98732243814777, 95.69721083487235, 103.73020925829488, 99.76703859144642, 55.73937085367019, 10.919028385992974, 0.24937144060048366, 0.32895904334802784, 0.10952857112692249, 0.2166457426163458, 0.23601806842752043, 0.17740347092190098, 0.11270972824985943, 0.11342441933529993, 0.20553972001277632, 0.24557760466010342, 0.19826579178052567, 0.12753242641807566, 0.26653973145350335, 0.11993768354577404, 0.1309239666067785, 0.19646272724193914, 0.16788317371279965, 0.0995775486432737, 0.19486437671847884, 0.16340059408497426, 0.22008618219725548, 0.12057685368363896, 0.14153238446001085, 0.20243839691242865, 0.18549714387664873, 0.1504605569906773, 0.11408700112013087, 0.14628609792599756, 0.21912140170893363, 0.13436930915040357, 0.17045702995552173, 0.17252335294840798, 0.1927451017282663, 0.23657847706589008, 0.15196869300017435, 0.09462809205175408, 0.10409045003114209, 0.1701851147076776, 0.16778981823834682, 0.12569790630931818, 0.23295368608688158, 0.21833412379266756, 0.11004244758477134, 0.1066597480507147, 0.18045069289303597, 0.06730148298365456, 0.1322808308947471, 0.28757684293293184, 0.11081965910571237, 0.16075792782489332, 0.2689584548915586, 0.09499018350916524, 0.08859757048588607, 0.1646516003435658, 0.18912541289483348], [0.05298926750378263, 0.011086895303320021, 0.056063206791276896, 0.026085435548016143, 0.08158003656013359, 0.02053595591156233, 0.02481043924607577, 0.04490915047485502, 0.012995770948398258, 0.0174821934647738, 0.05373331507848156, 0.047103869803850694, 0.07556809262642938, 0.06023098173881731, 0.02691077462758028, 0.01677339742591064, 0.10314865218054864, 0.01400414088200177, 0.062478545812829855, 0.032175210184387626, 0.014704693814799672, 0.04534092912029836, 0.022053740798465667, 0.02866343249596896, 0.0815383920205697, 0.03910143409044512, 0.03729398752893171, 0.05940602761843513, 0.0171562307138717, 0.011683977528234885, 0.043786184321488106, 0.08758923789906888, 0.08381114506553258, 0.031919928620599454, 0.14187286457707807, 0.0685179156942233, 0.1127726317293221, 0.04933545711420236, 0.029156007879083196, 0.01962948620559708, 0.018493969616810643, 0.048266756798951864, 0.056123532384874365, 0.06512747867213142, 0.05523803816627591, 0.07423537542983409, 0.21776001750221177, 4.970416205544626, 44.28810527247768, 61.720004773909054, 66.83528930910173, 79.35007418355634, 71.10389494126844, 74.50766501888153, 56.20719194412232, 24.13786203630509, 15.776755386783233, 28.324321469952984, 51.31039519463816, 85.69844599693053, 65.38886039487778, 41.99785294071321, 32.79606469215886, 20.202877521514893, 11.803474810815628, 5.149446418208461, 2.989478308346964, 0.9714181805329939, 0.3662207326100719, 0.0792717370354841, 0.06336264575140611, 0.02312877283041035, 0.07251439721233423, 0.01564207229567992, 0.15098811577885382, 0.04631320960939892, 0.04171821040912502, 0.06699440430008596, 0.04537078356670757, 0.030839750393023415, 0.03496892217005934, 0.16899979282771388, 0.008137024912772881, 0.11873382999892197, 0.05267797150619088, 0.2308291250899915, 0.19148021395648682, 0.2597287195103784, 0.12208486711906812, 0.035855795346921494, 0.02811336221413747, 0.08126836134901932, 0.14166291052054975, 0.08643985320363315, 0.050396029236576254, 0.051517141457166404, 0.1152742228981468, 0.14751991317156823, 0.10772513886613232, 0.053317107170099215, 0.22557396111228775, 1.3254755206646458, 4.1536958755985385, 10.948443220507714, 17.83751376213566, 22.57507993328956, 29.78746360348117, 41.278906022348714, 60.40772091957831, 75.76357656909575, 55.241633845913796, 35.14241672331287, 18.253628207791238, 29.418531348628385, 44.22384900431479, 62.083949735087735, 70.31041514488959, 74.03784351964151, 73.46310646303239, 77.82928497560563, 71.39426800512499, 46.8308444946043, 7.279892563819886, 0.16034264688289937, 0.24927892782274755, 0.04829434745554482, 0.011245328031720654, 0.0823951004854133, 0.06311803004674374, 0.06562371978596335, 0.02789766058295725, 0.09359867672526068, 0.049202127171860593, 0.02068370171341925, 0.06369269175094462, 0.033504219515429395, 0.019775219111432953, 0.010630504168089359, 0.05173688994780664, 0.0028634748248864087, 0.13429316001073008, 0.08574406916816389, 0.01603907821024017, 0.08730940896296695, 0.05663508759631265, 0.030073781212371205, 0.02175301681422899, 0.023089535722148516, 0.02248016257409848, 0.041130046405258684, 0.02910851234299762, 0.07044947616034938, 0.01084281969064426, 0.0319834545465006, 0.020035901595087304, 0.03587774759639175, 0.034843115211134, 0.016838792606347033, 0.011521089040944654, 0.03209053257089709, 0.02003815963924412, 0.04374853493044934, 0.025586804239860466, 0.03782370285461507, 0.08128846349615244, 0.05632861029176463, 0.0380070659992916, 0.02311648286488508, 0.02471636556419394, 0.032832624706169294, 0.04077250551011774, 0.03196978945315125, 0.01749129075887463, 0.0400716767856671, 0.09986100883613672, 0.07037224683670268, 0.04827774633022566, 0.0617330081971182, 0.03902440394965872, 0.06424610983700522, 0.016442504899215796, 0.04398446702849, 0.06787656986665341, 0.03405332452647629, 0.031765801306333274, 0.048852733621794375, 0.04598888628665478, 0.0010225368145432684, 0.02513407883534749, 0.03721841678564106, 0.03907239552767527, 0.03410605435830451, 0.040624202379295905, 0.011429782851689286, 0.042898127538782936, 0.03259957309872393, 0.054228759460872224, 0.028111454655206012, 0.07994008746238486, 0.07161119487136602, 0.023284470624921304, 0.04046443091224759, 0.026264734596254367, 0.01789892805860408, 0.027436263063141418, 0.09188795642506692, 0.061429622057344646, 0.10688614235409807, 0.03628258292953815, 0.10116833787892135, 0.09454215996928754, 0.10443892810613879, 0.07974946180418616, 0.03717802479983338, 0.05938878297925957, 0.028490604975471095, 0.0407776880949255, 0.03307112702919591, 0.060197584135758306, 0.12715406325315276, 0.03186169636225508, 0.018493402711746675, 0.14492639911270913, 7.547955676432579, 51.30802216068391, 74.91823519429853, 76.06831335252332, 87.46677598645611, 77.42463757914882, 89.58487156898745, 78.96503863796111, 40.97228650123843, 31.732370853424076, 33.109875878980084, 38.57945242235738, 52.47879866630801, 54.736326663724846, 50.51610346763365, 40.45739304634833, 28.444094965534827, 16.053137356235137, 8.278109296675652, 4.62994662984725, 1.6078643548873164, 0.5923939736620073, 0.09635516066825199, 0.0812822275404488, 0.0326660925131892, 0.04093754383164548, 0.13184860408786805, 0.0694256302930655, 0.0785203043731951, 0.2759901920874273, 0.09483852874367468, 0.1265015555245261, 0.13203568275897734, 0.21039875524659313, 0.15048255903586266, 0.14803316143731918, 0.2065839131753291, 0.9254515567614187, 0.9018391947592459, 0.5342114344239235, 0.8410675847722638, 0.18050223528858156, 0.15135104227210247, 0.11543899308890106, 0.31635720342878376, 0.13783430951016565, 0.04760835402374787, 0.08111176531641714, 0.05280577795459859, 0.1635655787803473, 0.08291958726101345, 0.05869401784072961, 0.05269694750407531, 0.20601665571091637, 1.2199440286044152, 3.3164081073576406, 7.309182372785385, 15.338870806078758, 21.45929897985151, 25.778679693898848, 39.33669736308437, 47.351947061477176, 54.641538666140654, 40.32067098925191, 35.52485565985403, 36.44609881985572, 47.79231156072309, 64.07089694853752, 72.12888086995771, 82.02655053907826, 83.09953843393635, 86.40470797015776, 90.80418740549396, 87.58582776592624, 58.64985973604264, 12.538445591926576, 0.2783144722061773, 0.29888037832513936, 0.01389791321520123, 0.06052250117664376, 0.060091212827471964, 0.03901719123185162, 0.09439854912700192, 0.04663185622062414, 0.048378207270176186, 0.06345172645524144, 0.009850152644268688, 0.06575556351773201, 0.041857370280570565, 0.024980790387358398, 0.054982555504407615, 0.0480950573429225, 0.05255382312762161, 0.08415587697057955, 0.07648762796194324, 0.010479140516010024, 0.029181214087011836, 0.03163668484757504, 0.07535493632237758, 0.022209097683850317, 0.019293347891840725, 0.04954532307061938, 0.045180824405002984, 0.04635083984823958, 0.06054080301715482, 0.01051762781571597, 0.010211721246671534, 0.052128935443057176, 0.021798296440993587, 0.04432656742151707, 0.022517631934475035, 0.06523722842816385, 0.07470551592808578, 0.022401412565922065, 0.08109831281246678, 0.057572790706950816, 0.031940015445974086, 0.09436259662071544, 0.045711727166968974, 0.011227263678466121, 0.01667831825362819, 0.01981328218995083, 0.022362072035790454, 0.005891280297580506, 0.05510012701814694, 0.022256926468182957, 0.03873653109035185, 0.08557648743472754, 0.052464612188839146, 0.13764182225831095, 0.1289105036806676, 0.12433590157137764, 0.14618376390107218, 0.19090270623564723, 0.11549246602601583, 0.19493127151602702, 0.1591701493147881, 0.14171852850385253, 0.1310111780560786, 0.18325466662645343, 0.2014591526840964, 0.17187082989802285, 0.11742810974077833, 0.12137474957853557, 0.11535549716603373, 0.12555290118701037, 0.06329774661290069, 0.1756751918864827, 0.13526282814000884, 0.2758062390550491, 0.08619744766263232, 0.24303854413090215, 0.13856318088308459, 0.17806083564796757, 0.18884225147626094, 0.14161267047447545, 0.16672962915993508, 0.18786959560407748, 0.2407497798483218, 0.1978283555757615, 0.3227707076697581, 0.1737297728898064, 0.40431672226517434, 0.3070746692678621, 0.16321779018448246, 0.23960775725783842, 0.22325640724551296, 0.14159561735728096, 0.10478688524134698, 0.15581753405351795, 0.10454707673840946, 0.22496951774003046, 0.256278412717004, 0.12502383320562302, 0.212146615489356, 0.3507221303880215, 15.4854085945314, 68.16801655677058, 92.52962235481509, 89.85878636760097, 97.35682056796168, 89.51829325768256, 91.59352517897084, 75.12765838253883, 34.09119406054097, 24.212816569112963, 40.07212608091293, 71.75813059653007, 117.24115064067226, 90.77178862787063, 60.218195915222175, 48.83036682682653, 32.0171663068956, 18.096909907556352, 9.200606634539943, 6.358739618332156, 2.0623942488624207, 1.074936822537453, 0.29385110303278894, 0.24948071538200303, 0.13703457500425079, 0.23230467171918964, 0.13741446268414298, 0.3548490766796374, 0.30156698738855703, 0.3541559203257484, 0.2297601260004505, 0.17649302138916909, 0.14221397288624318, 0.3366016284112008, 0.22300258699444034, 0.20590981708899622, 0.3365962045086969, 0.7139184398035849, 0.7264474094394715, 0.5465463693103483, 1.1759479055481574, 0.3585974529625908, 0.2575859715861659, 0.1679068611514184, 0.3725807639139314, 0.3444124463825457, 0.34086496899685553, 0.490118048844799, 0.368536401900553, 0.39384322781716624, 0.20353911204203484, 0.1476864760080653, 0.26543371499546115, 0.9929969161748887, 2.4388956975552345, 6.480569906773106, 15.259552636454183, 24.624736039869248, 30.226837704258582, 39.11621701332831, 55.72321853330059, 80.28762263636436, 100.42637332793205, 74.71489167982533, 53.18293471490183, 27.694055418814383, 41.54950249579645, 62.7096030789037, 81.70832080225792, 95.61899877363636, 96.56444687997141, 90.98650701584356, 100.29006311970373, 101.15778553870418, 67.91503152539654, 16.83123165561307, 0.6587924075222785, 0.5030020236247971, 0.12858464052119564, 0.1304935018021253, 0.18843893682764423, 0.26028060925103, 0.18658986104832542, 0.13686756783675763, 0.18884278773780794, 0.1393911993551639, 0.18190380846781118, 0.11400091582007947, 0.15168258980397256, 0.14592090381249306, 0.24318158806812382, 0.1334484867871769, 0.17710740858268353, 0.22615336873117955, 0.23470454939430763, 0.09391877890354204, 0.17405241847999636, 0.0910254103702403, 0.1494084424789875, 0.0946971089128525, 0.10994641846346279, 0.10817281000556485, 0.10664076439195103, 0.13455709262240317, 0.1774106721483892, 0.10789690343963523, 0.07513457879183755, 0.13838095920941523, 0.11654258104822329, 0.1626790158690945, 0.15310115481336273, 0.1367592276825059, 0.12961332806416098, 0.10938975599504287, 0.15410065440641296, 0.177437010251226, 0.06795067355156907, 0.19611351372253513, 0.18058504939319628, 0.11855614356576435, 0.16849805120258562, 0.19560789569251, 0.14345981571222508, 0.12149083488170179, 0.14290300768709954, 0.06635355642966687, 0.1050576743399424, 0.16938922596314263, 0.18690225638208852], [0.011069133554795578, 0.08286970727626355, 0.05318315669653877, 0.0413273676719156, 0.08170507743113464, 0.08987895213067533, 0.027663944394237576, 0.05997532670716605, 0.03917815396562219, 0.025617997424917358, 0.06076004972020465, 0.01376922289285088, 0.05249330218160345, 0.018011173346049843, 0.015219096958096472, 0.05452701664199272, 0.06641505030734886, 0.049576234718364094, 0.0621152745800153, 0.055186097405009696, 0.0542172834637665, 0.037585319275216716, 0.0559826334938407, 0.03548862089613273, 0.08387865273342018, 0.06574851550882863, 0.07309384313562224, 0.06487067833903336, 0.028625949729053725, 0.025055349894588994, 0.03137963170546197, 0.04158771116166346, 0.01265908775460576, 0.012234078453583343, 0.023405336316735036, 0.052394135930244966, 0.11750891669503144, 0.03469172091553769, 0.061325315356014244, 0.0778161546575927, 0.04126775454008772, 0.06217227535202138, 0.024802063989843574, 0.16539001717202126, 0.05772534945619203, 2.528783919349794, 33.15445753835863, 66.32436137045583, 78.57547667718704, 76.73163321710403, 75.3869584298903, 76.04371224680256, 56.44818628987959, 28.19176693116465, 19.57393134793928, 31.42789294642787, 42.126134057198804, 56.94422491135136, 58.24940535330004, 58.96913282332882, 42.405622543827185, 16.493652866732692, 6.279180222941983, 1.350388577388179, 0.19918705847474838, 0.04864354948362997, 0.04760727383977464, 0.06288986608025528, 0.04337802416675034, 0.03604681170996159, 0.036214106160426335, 0.06807436610782339, 0.10161384098952818, 0.053165574978676536, 0.08850702655411537, 0.04384658269343838, 0.04326420648383998, 0.1893561279341098, 0.057623080548740206, 0.05873996013354871, 0.12029982862933991, 0.08837865320064368, 0.03542584382117756, 0.08425794286473144, 0.4683379546528863, 0.4221608712067528, 0.2821485890496162, 0.26221632957458496, 0.03049432517840497, 0.09800099332125918, 0.19683662411426345, 0.11401510376843715, 0.021569561739001545, 0.03555785226184995, 0.06363220144844343, 0.04231571302478833, 0.053363018819401344, 0.03817337985721327, 0.1262572347637146, 0.05380696677152188, 0.05761435480728265, 0.05914057432223232, 0.07774838651981085, 0.07453586575725386, 0.15020658352201985, 0.7663035320658839, 4.5020165654920765, 8.69456793031385, 20.51485303909548, 40.96351608153313, 67.94125649236864, 59.478307462507686, 40.53078843701271, 26.715086736986716, 18.168326462468794, 28.197448484359253, 41.69851333864274, 78.37881688148745, 83.75622164818549, 75.80586756429365, 82.4752147736088, 71.87420137466924, 73.52987304810556, 28.412262970401397, 3.995447360700177, 0.3483635908172977, 0.16363369931857433, 0.08863199847720324, 0.09556556916645459, 0.03505535604011628, 0.14322595971245922, 0.04005593367882314, 0.05321555072441698, 0.07702337623003029, 0.03196321450354111, 0.057178056243086056, 0.0412540415662431, 0.07786215057656651, 0.021029827898488413, 0.034969795510293014, 0.06603636538549777, 0.05969990660706836, 0.1320495642721653, 0.03476748701124903, 0.0535998280881153, 0.10228546261186562, 0.10392842243515676, 0.06843395245772216, 0.04028297532650252, 0.02262739318182632, 0.03463961161492813, 0.06170346401631833, 0.027641174345908147, 0.06752453714368806, 0.04380053314830988, 0.0601189605320894, 0.027992079004405007, 0.052271278409828106, 0.050135835133973634, 0.07679821532820502, 0.0707920323756914, 0.03930134856472573, 0.010533735771933872, 0.03822299937206892, 0.04890789195234257, 0.050464758814703074, 0.04511638491925213, 0.02565570044211082, 0.03609141334891319, 0.02271747171518303, 0.040594865042235584, 0.029102333843888297, 0.0041409633066054555, 0.042513838683765744, 0.05290225140690323, 0.02300216530960414, 0.06588585975189364, 0.036891963738467426, 0.014261460239668528, 0.03424707582340606, 0.04572590362400778, 0.09323634778059299, 0.046073937368008404, 0.017163466414316528, 0.08702057083287547, 0.03303807416570283, 0.036360375327809204, 0.04383786844329969, 0.0016565662630337982, 0.009296178186853087, 0.05371642283975117, 0.0154606080914457, 0.046501935369545416, 0.00941800531901179, 0.02507527201105991, 0.03661267106391249, 0.018881131301543886, 0.030347519749475103, 0.014374679416388035, 0.0346827921607802, 0.034337723177046545, 0.011152079809577236, 0.13299307815970915, 0.09614400385368256, 0.04542214210115133, 0.019738695869642883, 0.07151371018300134, 0.02207463967704004, 0.008425367000933376, 0.04399093664101055, 0.072573454930417, 0.06257245670102778, 0.07121046193905416, 0.04512765024217867, 0.05285642402727277, 0.09509935103837522, 0.024550199178197694, 0.03574917122962014, 0.030217750200761423, 0.12580128987469982, 0.039557095526927905, 4.010194737103678, 39.88387584686279, 77.48937237647273, 90.20911678191155, 86.09695880643784, 95.04193182914489, 96.17399061879804, 75.35994114414339, 45.93035067281416, 36.95448898500012, 36.02195332127233, 31.76956080621289, 42.48543493209347, 49.20595730504682, 55.727344866721864, 42.9775276491719, 20.86149838662917, 8.771821952635243, 1.5738298263280623, 0.31607601851705586, 0.05518938775264448, 0.0552786446567024, 0.08422138514898478, 0.07217961678942365, 0.13632048912827047, 0.060443421750659906, 0.2937401735013531, 0.21437639100176675, 0.17414240316758234, 0.26604168237217013, 0.32563140255308926, 0.9558977294833431, 0.5422606896008215, 0.5248261831941143, 0.31826650904070947, 0.42749511078000074, 0.4157863148758489, 0.33595311966153885, 0.5453848574430712, 1.597114363985677, 2.5759327700061183, 2.157823799117919, 0.7417374825285328, 0.6704754322286576, 0.6769615616048537, 0.421653782287913, 0.16725069152251368, 0.09163890124088334, 0.16703652398240182, 0.1861069345426175, 0.11208395698979018, 0.04552305120253756, 0.07675650184072795, 0.14764656282721028, 0.06285317046868225, 0.10404744951595223, 0.037694276130247506, 0.0962477628021471, 0.04408541443427244, 0.08650307077914478, 0.6317495650822117, 3.8786475120052217, 7.41934213907488, 18.82771807332193, 38.397395610809326, 56.134859515774636, 46.72791757891255, 32.0869590005567, 29.56480241590931, 23.735405283589518, 49.783314504931056, 60.018970889429895, 86.4721570476409, 95.99455787289529, 83.81687718053018, 92.44798998678885, 84.48469208132836, 91.78703923379221, 40.64479604844124, 9.208267023486476, 0.24230133772136705, 0.12663346820420798, 0.014504331179083356, 0.10209083797470217, 0.04077891383560435, 0.06155726762728826, 0.05738985274107226, 0.09555999204636582, 0.018426511744638125, 0.08285714343430535, 0.011863253593835379, 0.058642812523870706, 0.07834356022818435, 0.03952060292865481, 0.03904726018287963, 0.11227199327080481, 0.053713488723001176, 0.07088668253873626, 0.06585723870704252, 0.06122665089224616, 0.03722200973800594, 0.03484090121703283, 0.05901374080548844, 0.01441062713462499, 0.04458600309707465, 0.02891966400878324, 0.025722171976080826, 0.03196132992724738, 0.06263983413396824, 0.07595935671199715, 0.05261759228643872, 0.049062944317777316, 0.06855822724079894, 0.07192738234035431, 0.048365455736676534, 0.04551804098751276, 0.04848169808786723, 0.04135978851287116, 0.0342590382863437, 0.0841955986294535, 0.06520937347123701, 0.0702053775650359, 0.030205565572325743, 0.02293314461806609, 0.04355683674915664, 0.06862612561352792, 0.01697725150734186, 0.05426994051724192, 0.04521034560316513, 0.007694363509560185, 0.03739808738652257, 0.1709144457333511, 0.10368533507590333, 0.13685610716141042, 0.2382814751998071, 0.1846410559430238, 0.17244562566761049, 0.12326461953982232, 0.09924502817973976, 0.1173266260734489, 0.1014435166613229, 0.11429195262251363, 0.12586941807380608, 0.1050485655545227, 0.1592281728141731, 0.1329728994037836, 0.12201904484461393, 0.21441857180287763, 0.1341053152516965, 0.1523256593293721, 0.14516923366294754, 0.1717237563383195, 0.11110894922767917, 0.16279618135623394, 0.1705055999299211, 0.20397576683711624, 0.16526768825227217, 0.2024916859884416, 0.13849277740284321, 0.18694601532432342, 0.06395241470947381, 0.16344979225147158, 0.3159424740700953, 0.1263725309963188, 0.15301841731754043, 0.15931659468239354, 0.25488230940555373, 0.18191169917343125, 0.12317349338122915, 0.0850809587826652, 0.14516799260051022, 0.14378650624665523, 0.09834542645201569, 0.15679228900661393, 0.2690449002529344, 0.2645540009102514, 7.933830609244685, 55.78333670093168, 94.50290403058453, 100.34294451436689, 93.50240938125118, 94.53564013204267, 94.72523966143208, 75.42793150871032, 39.0821865297133, 28.69761932280756, 43.59380260590584, 57.37808219848141, 78.07065979126962, 79.77542384978264, 78.85184687952842, 56.36658530081473, 25.28412961190747, 9.785166286653089, 2.6401380473567597, 0.567397014989007, 0.24969466841749607, 0.12915768961031593, 0.11940709104941738, 0.14485703751204476, 0.40982002212155255, 0.07702827919274569, 0.2648923666246476, 0.32795935989387576, 0.4319114850894098, 0.17813984995647786, 0.24761519935582918, 0.517500298878839, 0.3977515939022265, 0.49533706879423517, 0.28610019313712276, 0.2851153411451848, 0.34728622604762355, 0.4340360920515753, 0.24768626167168542, 1.2001239244014987, 2.143435319585185, 1.6159250707395616, 0.5462183611046884, 0.5700766066870382, 0.4781560455599139, 0.6883734524730714, 0.43377804299516065, 0.1878166589285097, 0.14870453025064162, 0.24910274292192153, 0.14282891166306314, 0.15783131873655706, 0.2098246795996543, 0.44267673646250083, 0.17822376722770353, 0.1924731711586637, 0.14267783912439502, 0.21615414399533503, 0.26292394966848437, 0.24911932106460297, 1.5160872667066514, 6.896112176679797, 12.32000683584521, 27.109316318265854, 54.74814476505403, 96.08844372533984, 82.18977605142902, 56.77757516984017, 41.36730055655203, 31.75342025295381, 44.95320981548679, 56.974101604953894, 97.6954387849377, 107.7819391988939, 97.38935270617085, 100.65773041017594, 95.8440722188642, 106.36597141142815, 54.810428081020234, 14.135854378823312, 0.6699007437113793, 0.2240381846504827, 0.25407590993469764, 0.3203807584941387, 0.1205149537793571, 0.19581089367068585, 0.08641059630580487, 0.20898386745923953, 0.20612635950167335, 0.14276325792795228, 0.1362316842160879, 0.13759945759609823, 0.22827884903357876, 0.10675298095109964, 0.14641182827613047, 0.23797001449331162, 0.16995953245749398, 0.15153577671416346, 0.16556899063289165, 0.13270573390107002, 0.2353311480293351, 0.19525999984433576, 0.19236837033062212, 0.1339807493552085, 0.1955569202020284, 0.07360895299502919, 0.1509136213890968, 0.17353803640411747, 0.23576063224144522, 0.1746459527602119, 0.28622436066789014, 0.16497993030615393, 0.1316800187792509, 0.2352419447514319, 0.1936996319601613, 0.2125108596538344, 0.17885534543423884, 0.11624131697199999, 0.09827638660827953, 0.16237110981056768, 0.23574365573304318, 0.11022833115871876, 0.11908675904475874, 0.16348172279615558, 0.10689997790201057, 0.16506112030436917, 0.0924734084776813, 0.1375578590218098, 0.19930436185771422, 0.08584660237594958, 0.13913164876641768], [0.05289028511352597, 0.07203237469037695, 0.07686912442647642, 0.028653695518451355, 0.029689501933453065, 0.025419469569779696, 0.04834408954446835, 0.02989374480450586, 0.04538715103520982, 0.027896766175305652, 0.01597996686600269, 0.04244570665421986, 0.02724725193524313, 0.03286776898969566, 0.053867974183371956, 0.01826304964901459, 0.027473787964892485, 0.05877179491724219, 0.05058603053311667, 0.10282471956264588, 0.003413323659427284, 0.015155484847303842, 0.02862434477485236, 0.07533602927240633, 0.014147248979087078, 0.05956915838103141, 0.0785469718938393, 0.027119874496073015, 0.05237267780748587, 0.03755165737182383, 0.006283686332960403, 0.03308580144338551, 0.04950964635598564, 0.06382252450191206, 0.021599416185410756, 0.05934672092177695, 0.0317504316673524, 0.05425574107756538, 0.08134726074434097, 0.04876209392903313, 0.01984950665745043, 0.14995486235185979, 0.3647445118235004, 6.535767461023023, 25.45935365461534, 61.83883690064954, 74.29584918483611, 74.23540546048072, 75.0779462629749, 48.211032421358176, 27.467460093959687, 21.05716190030498, 18.382425115954494, 26.390287030127745, 40.657061299970074, 63.09168900212934, 76.82487580084032, 73.9235927212623, 41.8297323103874, 20.70484676668721, 7.312999329259319, 1.674719070715289, 0.071196258668938, 0.07942742908433562, 0.08376079010626963, 0.13302579011407592, 0.04408905335191277, 0.01901063654992369, 0.0461617770094064, 0.1600530196822459, 0.0816451310510597, 0.014812878836246749, 0.10772723794704485, 0.1643879588453039, 0.12830562363829345, 0.19812149145910818, 0.8681812137365342, 0.785818488126801, 0.3250420051476648, 0.07638892519377893, 0.682043114737157, 0.4647506100516166, 1.0893639129015709, 0.24716421871656374, 1.7713250868743466, 2.9748137920133533, 2.198112424342863, 1.1249132117917462, 0.41856286266157705, 0.17349901188525463, 0.4140792564759332, 0.621214936817846, 0.08162967139674772, 0.051726658843577876, 0.06959477484586739, 0.03289627895179776, 0.0563752458941552, 0.018395649892608487, 0.056089468285321235, 0.039267096773631154, 0.07741794215455171, 0.06311063346783481, 0.07070420805605189, 0.015186615787716884, 0.05213269693476539, 0.07230993600622301, 0.08286881095339214, 0.295592941824467, 1.0109608812678246, 8.387235518424742, 21.25598292196951, 68.97099633370676, 101.34963650857249, 57.347593615132, 36.95885066063174, 14.485301279252576, 22.13980470934222, 41.19495553355063, 48.88798252228768, 69.11308811556908, 69.95944930661109, 79.19134370742306, 74.59194890914425, 74.4665507347353, 64.89801891388433, 39.743494218395604, 5.623682545077417, 0.15923640059847988, 0.010451116062129938, 0.04031299831225507, 0.1049561064029413, 0.028653036682836475, 0.06623205488487598, 0.0792804014899077, 0.0836171945857425, 0.0343049269530081, 0.04404392694273303, 0.053727979276088945, 0.03654385338567438, 0.04474156108053942, 0.030482282276235284, 0.09462365640267249, 0.0947148974744543, 0.07036002007343116, 0.010649035834977704, 0.04630356456243223, 0.021042290233796643, 0.04950256004268604, 0.028148219214692235, 0.01260254855057405, 0.057112820025893955, 0.06190326740784992, 0.04761572762001907, 0.052258254915115335, 0.04424491777054725, 0.03992059275568013, 0.03348580276172969, 0.03663262765434, 0.057683494242448966, 0.0350261872423993, 0.03041499294340611, 0.04470339841059139, 0.012982300249859692, 0.004084659674610462, 0.024982000806278763, 0.07378320735428603, 0.0587976235716093, 0.022957241913724332, 0.05219529014861873, 0.08152376740209519, 0.049910195427195686, 0.007930602042770555, 0.09189285938778231, 0.012087275897483192, 0.02152480305202546, 0.023739201264576088, 0.03472717163423377, 0.06533058390261666, 0.04211454982719114, 0.04526731573165425, 0.034960667572675214, 0.02178300724124476, 0.02494482830497286, 0.0452143139386129, 0.012717517280590632, 0.0464759458367142, 0.03364279716005249, 0.04093763959263602, 0.040172869339585304, 0.04974392370410985, 0.05313400066487732, 0.0190154705647259, 0.07566825862252906, 0.04643883270722243, 0.04513671306232291, 0.06852625839171872, 0.004285368007502609, 0.049312554915706, 0.048216593361669974, 0.045402016971380486, 0.11168042783655467, 0.0427820039312205, 0.02692847700429059, 0.0613196884402104, 0.04343608214009193, 0.0545217689397114, 0.04846432321374455, 0.06914093669864439, 0.03393541593405028, 0.05472655956363005, 0.04121183395205487, 0.0416057946671161, 0.10642714077426542, 0.06622424078804832, 0.0670938654952953, 0.03861295727772578, 0.0800250159696706, 0.10054266621028224, 0.4134699714279944, 8.190810084342957, 33.89476568468156, 71.76508103647541, 88.2532504297072, 82.87310000388854, 84.42471904139366, 67.73331596005347, 44.1892497770248, 32.63857956855528, 35.227673361378336, 28.97892582801081, 29.261709105583932, 40.4055118560791, 46.942204506166526, 56.14588922069919, 40.351826375530614, 24.524346897678992, 8.859863473523049, 2.138200181145822, 0.12620682617829693, 0.09525043889880182, 0.013753723018922874, 0.10208274042534252, 0.20685015937253354, 0.7718424703324995, 0.21622712153100201, 1.2276680334921808, 0.602523984928285, 0.30930668175701176, 0.7055011559878627, 1.4909468350871917, 1.863677905451867, 2.281118602521958, 2.542402388588075, 2.842935126635336, 1.3417566663795903, 1.5898154459653364, 2.1560293147640843, 1.583011359457047, 3.1118599349452607, 1.3762019406403265, 3.7394175894798773, 5.518558121496632, 5.093618833249615, 4.138074546091018, 3.887197788684599, 2.576881248143412, 1.0756943302769815, 1.5231537842942824, 1.3018760902266349, 0.4988972632394683, 0.997836814532357, 0.3490794540172623, 0.46004526737716894, 0.09727872562624755, 0.1140329382953144, 0.40302448515449807, 0.2374490747048009, 0.17553746459945557, 0.032436449997006886, 0.041772093203279285, 0.14950225760619487, 0.022972383641547734, 0.0986144612092645, 0.4824534617364407, 0.8223914030578829, 6.9644864432273375, 20.471534382912424, 52.68617829968853, 65.47394444865566, 44.91539424465549, 37.819100964453916, 28.041624484523652, 35.08095710508285, 65.44942963507869, 67.73465741065242, 80.29156069601737, 82.55436820368614, 89.3330240249634, 86.23565381573093, 87.33074034413984, 83.32328611804594, 56.616859974399695, 11.861882825051586, 0.14902303896604047, 0.010322785801104, 0.027004231608683066, 0.08819014194511599, 0.09906806186923096, 0.02697316291291387, 0.07574698181762811, 0.02097508517063914, 0.038487993015517155, 0.02146759160584019, 0.053491357698916435, 0.06719625314637538, 0.07529633059617012, 0.02516980726091612, 0.05618923208526066, 0.06273309767787015, 0.0682911230251193, 0.05997305142603094, 0.03562204276902541, 0.030545660730211005, 0.013806679804298668, 0.03009515506545863, 0.02382788934835023, 0.026999556557125142, 0.01548933638860622, 0.011054522342859738, 0.01026673689334383, 0.04127608957670389, 0.06256712472907479, 0.042087066422907576, 0.06919363588695565, 0.034279155755235304, 0.03746507028418203, 0.06863681254007163, 0.051602525786767085, 0.028003118331393892, 0.067204917600799, 0.046291812773673766, 0.039969285304147395, 0.03889358677570859, 0.012831811853233847, 0.015179487339581455, 0.02833317773747108, 0.06266824067420056, 0.023605312078049587, 0.046100692988763896, 0.06928682282206512, 0.06277308363707797, 0.013792488025501372, 0.3142662124047357, 0.2217562845157039, 0.1788126896586149, 0.09642764024676816, 0.2234376636483977, 0.1213661464111459, 0.11381718495319929, 0.1460198823723101, 0.11524570144472585, 0.12603100133879533, 0.13277759294836752, 0.2781937061057937, 0.23268914060486903, 0.1582718346147768, 0.20127117002923645, 0.09943757671862842, 0.09478425141423942, 0.11086770814032325, 0.13775891113665797, 0.21814929742005565, 0.104056213561806, 0.17880679078159795, 0.21438605903137117, 0.1777914331685151, 0.2525615839347724, 0.15211313121741818, 0.1319586602790702, 0.1587935558129703, 0.10831085904952019, 0.12123445589696208, 0.29217015290933274, 0.17629301115389795, 0.11215953156352045, 0.16908415442993566, 0.1530129014844856, 0.3830122461001719, 0.21245507313118828, 0.2186512535498027, 0.2668769940012886, 0.09499888626798507, 0.2010841373234026, 0.30614926569884826, 1.2103636394585333, 16.474570535844375, 49.758944819050456, 91.02111016550373, 98.54676569661787, 91.58332701652282, 94.87310517218806, 65.79958354273151, 36.60250333047683, 33.732214820000436, 31.126235223585564, 40.743008275185865, 56.73371522657333, 84.49511774124639, 106.49138527531778, 95.79901987506499, 56.73480564548124, 29.822502136230472, 11.105462562653328, 2.198901556191906, 0.21619652397930625, 0.3874726551434686, 0.1926101936448005, 0.19904335570191184, 0.11822187642176306, 0.31295436344319777, 0.1885696314275265, 0.563428740828268, 0.31092514974936364, 0.18346884948832376, 0.24141829881456592, 0.5062593681918037, 1.010498348022661, 1.4329435604233898, 1.5965339757742423, 2.473830532643103, 0.685347956755469, 1.0734328387245056, 2.0981728838336084, 1.8208101992645573, 4.926227763775857, 2.949668702579314, 5.096303205336294, 10.399826207468587, 7.139909546221457, 5.966253530594611, 3.4434367620175887, 1.854252940224063, 0.7188411369439095, 1.5131548047065737, 1.3659564646021014, 0.45195896418825277, 1.2903081625699997, 0.45388641076222547, 0.3397572977888969, 0.2291396254253003, 0.15233879007639425, 0.3614984747142561, 0.27822048853962655, 0.2159093942252859, 0.2560972788881871, 0.3485342752068274, 0.5460036113377541, 0.3296447226837758, 0.15988019024652822, 0.9573880462877212, 1.748678302091937, 11.840534344796213, 27.277105508312104, 85.81979628532164, 127.81921032936343, 81.48846410935926, 55.06028306099677, 21.881342088022542, 33.09422954436272, 59.91043890676191, 63.86138354578326, 90.44647509051909, 91.56992035527384, 98.48111306467365, 93.23317004788308, 99.7395976897209, 99.85837490327897, 70.30673596166795, 15.41403812746848, 0.26136523653422633, 0.17105805657563672, 0.20183905568574706, 0.3437239784867533, 0.16403180456930594, 0.14295790554775348, 0.266036503617802, 0.15276796785333466, 0.22485495695183355, 0.1173053824553086, 0.10572701302026549, 0.1949064655890388, 0.15571800391039542, 0.08310946981392561, 0.24790225250105707, 0.18832299708118364, 0.18838753232792502, 0.1730774337005231, 0.13055837412755336, 0.14205926909081398, 0.11441033618945269, 0.1179683319623432, 0.08473857110666652, 0.10060888685045705, 0.10372405315959647, 0.09279547950192805, 0.13482951348827732, 0.13673884974372003, 0.1904534109898152, 0.10734668377065852, 0.10505594298123352, 0.1122798303502702, 0.1892999124022261, 0.1828168626994856, 0.08606288431873245, 0.10301536820348232, 0.11716946313578276, 0.13150424756590398, 0.12736106021029334, 0.12601192574948072, 0.1084176900105611, 0.15385723762935208, 0.33122179128469964, 0.11384950620272469, 0.13215036612124215, 0.20229679322050464, 0.13723550454503106, 0.16551945538770768, 0.08635064992572992], [0.012738754195461591, 0.00716971489788604, 0.02126766755546053, 0.03973713768045268, 0.10173514335145874, 0.040747883444231366, 0.07095979030935035, 0.07171068671009234, 0.032045197402757984, 0.058513404951701244, 0.03902752192751054, 0.059961652037717646, 0.028697952417837038, 0.008588354122043859, 0.010985305341291092, 0.016827201696052667, 0.043283105872931986, 0.14562922349620253, 0.05843558574035283, 0.05165688738587403, 0.07913516654122262, 0.01960829046795205, 0.013021278803447082, 0.1019897603339726, 0.02832252911532358, 0.08192347377658853, 0.03715395814769211, 0.04582761328727488, 0.06369744532651479, 0.005332334408341277, 0.025381611419781566, 0.05323994296392607, 0.08091092770618778, 0.008922256416671218, 0.050968423320521275, 0.032060806444215204, 0.06764038495959775, 0.07941715584527101, 0.03571653588404579, 0.06895624056097961, 0.060433002954889695, 3.486799054568814, 42.682035892240464, 69.13043283647107, 84.55844048530825, 82.94521670187675, 79.14915469384964, 84.70391335025911, 55.990363320996686, 42.449784509597286, 140.7382660527383, 104.1963594190536, 39.08759940055109, 49.7153986653974, 81.93877573936217, 81.23933869023477, 44.15798064201109, 24.16800152870917, 9.039168742395217, 1.8893586435625631, 0.30023451534009754, 0.06136839247999653, 0.016227676608269254, 0.09211282621348098, 0.1460292439667448, 0.03186689043838171, 0.1444949843590298, 0.23522953412705855, 0.05721777407152038, 0.9205935787289374, 0.4581461966999116, 1.607692383470074, 0.5739346867607487, 0.6495483616186727, 1.9944997372165805, 1.2493659724150936, 2.8252609266388804, 2.621585971886112, 2.162656649466484, 1.0346713638113392, 1.7210993819659757, 1.1057291444270843, 0.19979332513626546, 2.017328912212003, 3.4649539041903714, 3.4274631546389673, 3.8014582087916717, 2.797291975828909, 1.938086493361381, 2.367887559436983, 0.7789707039633106, 0.19254935094185416, 1.1831031667609369, 0.27572711749422935, 0.14467536742168088, 0.17385377188123044, 0.07885434935169836, 0.110519276030602, 0.1256811060011387, 0.04241097605817261, 0.09257752748747027, 0.01948977475084605, 0.04164253241352497, 0.064888367309205, 0.14176732830462918, 0.05474189664387415, 0.0470774895661781, 0.015134893361509088, 0.0772170968834431, 0.5757241455777999, 2.8816467139028736, 11.720995210832166, 54.27722892453594, 67.2450985447053, 54.90810686542142, 63.703900383364775, 41.998978660952666, 15.789300107186842, 20.80479660341817, 27.119596850487497, 46.28730597034578, 60.503375760970584, 70.26710433344688, 74.99996169920891, 71.65432114754954, 74.5980913408341, 71.21215235802435, 28.977056818623698, 2.0918421783754906, 0.35132470450574355, 0.10046982657044165, 0.03188042529678393, 0.006541989155999956, 0.02075589400896382, 0.09111672038993529, 0.050028674755125284, 0.12705356783924565, 0.08849488406051552, 0.09942132799375443, 0.036640334498858264, 0.05777952719419714, 0.04173856919571277, 0.04148893178470674, 0.11642244313993763, 0.01970929916076843, 0.06776967761857856, 0.029491588863874638, 0.10944636223176796, 0.06237923017432613, 0.021744407901179888, 0.01476227968645793, 0.029755441036315698, 0.11387199854418156, 0.006762348601759802, 0.04049823837234609, 0.021351579081026778, 0.07957528405372175, 0.022376141240519863, 0.03281074906549147, 0.013724952586926522, 0.054530038858854005, 0.02882503108271668, 0.017695895606471647, 0.06492128610731134, 0.054191064104558005, 0.06321156555185876, 0.06352143279547173, 0.04834058852265439, 0.08313627523039618, 0.07524854203145351, 0.042834174518864, 0.008036985321180716, 0.04451856054666062, 0.08268057548951718, 0.04436939173648435, 0.03020074496406221, 0.026400881826937683, 0.041922840154579574, 0.02852287834450122, 0.049571534768948634, 0.05158814631642834, 0.05757558692787444, 0.058645926671282905, 0.009457214656586369, 0.026987695600837473, 0.03584973942188006, 0.0785034274562232, 0.02876419029499014, 0.06385267772261174, 0.02276745512180271, 0.031635217789200046, 0.07891220431174002, 0.03172502436134363, 0.029967252856060386, 0.043608708562509674, 0.04838016462482272, 0.07483222687076177, 0.005600577222198369, 0.06142116061622097, 0.13800870176524888, 0.03416030104422281, 0.07617409115717297, 0.025824982890739076, 0.06407149158598435, 0.01608429559236092, 0.03717934630150276, 0.1027077072930913, 0.01673621534850569, 0.009594393233137747, 0.06013746155546077, 0.10861582333041776, 0.14183282882215517, 0.08428442652427381, 0.07828917564643968, 0.0648571722089283, 0.039630241601938204, 0.06465884736709057, 4.9614658471076725, 51.674026366203066, 82.67473005479383, 98.08195698645808, 93.68519183128112, 85.70526307629001, 90.12545262613605, 72.80323043946298, 47.1575387062565, 97.26007923003166, 71.91242879436862, 34.38397153731316, 39.47372536505423, 54.006589305016306, 63.880865958429155, 46.46918627523607, 26.02027612347757, 9.85683681503419, 2.4732755172637204, 0.4457001177774322, 0.035064464825535976, 0.06480391377643233, 0.04885769021066447, 0.25754129333842185, 0.7841987331067363, 1.620726542126748, 1.2029271933340258, 1.1578565859986891, 2.1277296591189603, 2.35966676185208, 5.970542642378039, 3.7844598822055326, 5.056559299269031, 5.829015681820532, 5.560550035968904, 7.602070166218666, 8.117190628282486, 5.519424475008442, 7.018676928935513, 9.181465468099042, 7.832511375027319, 6.2061589283327905, 10.169715458346952, 6.329946479489727, 8.142571305075, 7.479105822501644, 9.428492419181332, 6.137875366595484, 5.6932291100102095, 5.0313144345437335, 2.5827640679574784, 2.203661842692283, 0.8758129203511823, 0.9891024316030165, 1.1688696208500093, 1.032402762962926, 0.927703119814396, 1.3746600814404026, 0.13459484543531172, 0.35414295811806956, 0.6428856030106544, 0.4019924727899413, 0.10018747720506885, 0.07161229803797699, 0.12058008657467943, 0.028854443113349622, 0.0518515503274337, 0.03685031536846392, 0.19721995918981491, 2.894845244384581, 12.456802437382361, 50.232924030673125, 54.7141731169916, 40.871944427490234, 35.32105322807066, 33.28593930890484, 27.48319664309102, 37.73060052625595, 52.27218389511109, 62.081878723636756, 71.58626018031951, 80.78761500696983, 86.29167310653195, 80.58986479236235, 89.6048991910873, 90.3450269083823, 41.968584214487386, 3.063502258831455, 0.32652184186923894, 0.08014647154918603, 0.053879277810694716, 0.08729974093336253, 0.05516727079427051, 0.02261649366588362, 0.01805535555186291, 0.08746821898967029, 0.02181058832173867, 0.04242005036963571, 0.08253842787516695, 0.0460547506959448, 0.048102687578648336, 0.0494340411387384, 0.061685434137020385, 0.052041869550462694, 0.04721904729282664, 0.010182630972966794, 0.052084207399598056, 0.015130917365182073, 0.027404949219236453, 0.06538082394869098, 0.03235826689389444, 0.04310574502714219, 0.03659727269663446, 0.12541854468685004, 0.024862289992010882, 0.04290583055286158, 0.02369124799095575, 0.036932658329005205, 0.006686061087455, 0.00365215300623658, 0.027667554583580747, 0.0656256273448948, 0.06092134570222228, 0.04269150213428563, 0.03944649924373916, 0.018851671390415683, 0.017923061743438724, 0.00990680676148904, 0.04272646638714979, 0.024178029834142616, 0.1444592233747244, 0.03559625241905451, 0.07016972383303989, 0.09949304914522557, 0.002878981641486227, 0.16070240177214146, 0.13135741915433638, 0.11939834998620134, 0.14737260978548758, 0.18006196455849757, 0.09981068452039074, 0.17196326606696652, 0.18107410460229845, 0.16068027715288824, 0.1705954620434392, 0.16385273917788462, 0.13287958989460624, 0.09329099283223191, 0.09997175450647071, 0.1622608850800222, 0.19545014286714216, 0.1299981799938025, 0.2628971672346515, 0.18141211791624948, 0.13178644371369194, 0.22714111653547134, 0.12968469681518693, 0.1845484205912198, 0.4114049661063379, 0.10735882626425837, 0.21257527232650789, 0.1955761643306863, 0.14358111807415563, 0.13394342555153754, 0.1300771943023128, 0.1182486741773544, 0.1432233090482412, 0.17276289332057201, 0.22023241306024216, 0.15968926581403903, 0.14562249724422732, 0.2674537356342039, 0.2493376714447814, 0.17608132573866075, 0.2001301586748131, 0.31182116618560207, 8.407135663493987, 68.47109025524509, 98.7411662070982, 111.02818689038678, 101.1059239602858, 96.87608703490227, 103.35125338646674, 77.2086718774611, 55.37604562697872, 145.81853558940273, 113.23029964200913, 52.939006436255674, 68.93258848497945, 112.59139260938092, 107.23843205359675, 62.09749367929275, 34.824920469714755, 13.545789680173321, 2.8486970884184686, 0.7275348865697462, 0.1927227472826358, 0.2069727487621769, 0.16318032848498515, 0.5657394458689998, 0.35942280544869365, 0.4305256320343864, 0.382395759825745, 0.7090153545141221, 2.549142001136657, 1.243095328250239, 6.089377710896154, 4.0520113706588745, 4.627993289501437, 4.992604563313146, 4.71461344149805, 7.9520902229893595, 7.973915271220669, 8.90342531665679, 6.261204000442259, 7.523650219363551, 4.8552235480277774, 4.514828987659947, 11.224481001976999, 9.827157220532818, 14.459479335815677, 12.559355747315193, 11.508494923191687, 6.244741812829049, 7.559557557106019, 5.106766127770947, 1.7569383233785631, 2.5636702151067796, 1.2566820508049381, 1.0370428043027078, 1.1319082686978004, 0.7139802784208329, 0.3582030096121373, 0.8641902020862027, 0.1335270874082081, 0.3193738738134984, 0.7261787883697018, 0.43786591880263825, 0.24612390195890782, 0.17945382864244525, 0.15567176284328585, 0.2166960286276956, 0.1076585045384784, 0.30168698740101635, 1.126891557247408, 4.956483456396288, 16.221723768018908, 69.48863152534732, 89.94127381232478, 78.47351858692785, 84.26169749229186, 61.06159963915425, 26.47721459788661, 33.70974356128324, 42.00998090928601, 60.57534340889224, 80.43007527628254, 91.83861055681783, 96.75907488792174, 90.43923439518099, 100.13971082625851, 107.1211531854445, 50.396337816792155, 4.70379505426653, 0.5064384795485005, 0.15317529680267458, 0.16521213155600334, 0.2031420180273633, 0.21137311183396848, 0.20913457227570398, 0.10479151241240964, 0.24264904970843948, 0.24448681802999592, 0.1503037387925771, 0.19614797235736925, 0.13228680638055648, 0.18754311957426612, 0.17174949689257532, 0.21830072235916892, 0.1176445525620253, 0.1788991656635077, 0.0882674248949174, 0.18463390068181101, 0.11459754509550911, 0.18239220484129845, 0.1724034448664996, 0.1366288088742764, 0.10734839214672966, 0.1551770232617855, 0.23721158744827395, 0.09653862340435868, 0.12255930537057501, 0.1397476600663316, 0.14626458617708377, 0.07179069693290419, 0.22260031422540066, 0.09165657488929649, 0.21450596711327954, 0.1899738705927326, 0.11352946531147727, 0.13177602491792173, 0.09703430527400586, 0.1506602148255033, 0.16890263755715665, 0.1498186825624397, 0.1419224457875375, 0.1367695239042082, 0.12226384057993851, 0.15250624157488346, 0.16853442505723046, 0.1809159380894515], [0.014619236706846185, 0.041650358001671495, 0.042359832028347644, 0.027274880896232305, 0.024050656225412123, 0.049716792700271455, 0.06083931683772995, 0.041135546916555014, 0.03461480568793993, 0.014841365815711119, 0.011125001474283637, 0.06336594759035977, 0.038392285651136795, 0.10991255737720959, 0.01628581693606271, 0.078972120048298, 0.03585755734914734, 0.046864946132465723, 0.040230647690834544, 0.05732682285710208, 0.024237736811741226, 0.04146000813512553, 0.040585775409014, 0.015222046396604951, 0.06577939651305638, 0.011452490655374865, 0.041983805431593815, 0.02350031972802695, 0.14835151693513318, 0.05668872524233115, 0.05024211451170906, 0.05454128886002207, 0.04393333065954428, 0.0802049930057218, 0.061467719609819116, 0.07695184660054023, 0.0354815116001954, 0.035530786375485124, 0.2654927037656307, 0.2651620295739943, 2.9862992273223017, 21.09990200688762, 20.1111077877783, 81.92035628903298, 76.51871911941036, 87.67040975632207, 70.84514402574109, 49.31620728585028, 28.542771993144868, 35.29404378706409, 119.97901208939092, 89.62360889680924, 57.613314582455544, 60.75878873948128, 48.16361881071522, 35.14137729521721, 12.078947770980097, 3.7243125419462886, 0.53780751242753, 0.15521892827124367, 0.017675236130373615, 0.028733583167195324, 0.01113712385807547, 0.06673348241395528, 0.042351615735359734, 0.25498069041678983, 6.157454367606871, 6.472971295156787, 1.7562131751929562, 2.7611267422476127, 4.218689549353815, 4.188068095714816, 3.715726228490953, 10.945796601233944, 6.653389046269079, 8.259452542951031, 8.514519372294027, 6.82273639786628, 5.000218374113883, 5.076931599647769, 5.072536583869688, 3.74595201303882, 5.192528751588637, 2.644606117279299, 2.5202630604467084, 4.994690773948546, 4.866456235608747, 3.744233524607074, 6.594218131034605, 6.057014234604375, 4.762708073662174, 3.900155828845117, 2.711687227410655, 0.9226333950796436, 1.791709644659873, 0.691446629503081, 2.0277728356661338, 0.37231045745072827, 0.9511845114250338, 0.7595794864239231, 0.3787529504587574, 0.10583721476817325, 0.05728813541692592, 0.3656820808687518, 0.2280663055998664, 0.08982041535238106, 0.03957507561051077, 0.056141604399008144, 0.02225627529344732, 0.04601984389967496, 0.07581908601306139, 0.34038840102091916, 2.2044705863921874, 30.822937950011227, 65.67816657404747, 113.24949572163244, 88.09386099538496, 69.96707439422607, 33.92442664792461, 13.76596506564848, 18.790522236977857, 47.09985240813225, 62.82332435730965, 60.24332261854603, 68.61394297692084, 68.69806212763633, 68.73789771910637, 86.40518649931877, 57.32085481766732, 5.88166908871743, 0.39777567970656585, 0.02120727875960931, 0.10238526854664089, 0.030751543029421763, 0.05352056863146925, 0.04859119503488464, 0.05262902231826898, 0.04453010932211915, 0.07693034251250568, 0.038836107198749824, 0.06684484095462868, 0.026875036625912594, 0.06322725503254803, 0.04660958987510493, 0.029416948917411992, 0.04191225664990564, 0.09260843913521498, 0.03781369391588434, 0.00353102971735831, 0.038709327308160645, 0.09685398349838872, 0.041249077316493764, 0.06086993737206344, 0.021392980387674707, 0.018101916460680868, 0.07435490812865958, 0.060025045813451854, 0.03998381799207099, 0.0512101661954676, 0.021326189011996313, 0.017013659835943294, 0.05468766144927471, 0.0824785887474014, 0.06018774756681054, 0.02668341313819251, 0.047484692111010515, 0.05059479074853082, 0.07645821018565087, 0.023518114035288175, 0.024607853040159233, 0.04337459209284956, 0.01155090326773784, 0.02970363242521642, 0.10503129793270942, 0.058842592932764566, 0.03783932338739115, 0.014504914363515715, 0.012936705569436234, 0.06684405954494592, 0.033404566798238985, 0.05459698728255687, 0.04465246122450598, 0.04717830290657379, 0.03504124470055103, 0.026561691343123396, 0.0213702141697849, 0.039220802080366886, 0.01737647141600328, 0.11699471848025439, 0.02132601855743316, 0.0678915468855731, 0.06886545914195238, 0.042369178301023866, 0.07920247502624989, 0.026056632557283008, 0.030480188940982186, 0.03218140783569506, 0.08427223040451927, 0.03778661653820065, 0.08127108096115052, 0.02858441244179924, 0.03141213490086938, 0.053751563292837916, 0.015459575787967732, 0.16866159565266103, 0.041343995610312115, 0.027562851431749524, 0.05167494790868894, 0.0209300660137688, 0.03613813705141506, 0.045180724813572826, 0.04986444465635766, 0.07261399630336993, 0.07158340886235237, 0.2589459615128656, 0.29556686419152445, 4.700764042715873, 33.749406568465695, 28.697837014352125, 91.24611300806846, 82.76139090138098, 99.51027239522627, 86.8988089407644, 70.95707278097831, 41.94335552953905, 41.30888469757573, 127.21804434253325, 101.51774929415797, 43.30149973592451, 47.848272015971524, 50.005905089839814, 41.472890761590776, 14.506419320260326, 4.498926718388835, 0.5931756284929092, 0.08292821341104085, 0.03638207476826445, 0.05170852554241016, 0.08911022120305608, 0.386150969612983, 0.3007705010954411, 1.1526500073171433, 8.775753148140447, 7.167891244734488, 5.891028844541119, 3.3194724590547624, 0.9728972205231268, 7.90081552920803, 4.75735011600679, 8.211609923070478, 12.85984460384615, 10.012172479783336, 8.908290036263006, 10.905044155736125, 14.259980724703881, 14.069836966453062, 8.887217102512237, 11.00664629090217, 12.170351743698122, 10.379904489363394, 9.395862221717834, 8.739175085098513, 8.457568518577084, 8.885664824516542, 10.754506530300265, 9.033572500751866, 8.769519521344094, 7.119230810673007, 7.161867955038625, 4.250288163461994, 5.979475350149217, 5.938670933246613, 4.687591743084693, 3.4640522493470103, 2.4927255703556925, 2.6192560840037564, 1.9541776492711038, 0.384277087906676, 0.0537834172287295, 1.1204499222578541, 0.4242621278089862, 0.1972062615377288, 0.04187264607378072, 0.06548644449081152, 0.033304921741927826, 0.10615003911117393, 0.09015963142437321, 0.2157106403742106, 3.8856773799465554, 29.295270865963353, 58.945982994571814, 90.42333310650241, 75.65246366685437, 53.40041837384624, 36.09345812951365, 21.96742242382419, 37.07148544249996, 58.91752227660149, 72.67745571751749, 71.84393636641964, 78.38885030438824, 81.5504297133415, 77.64799302624118, 100.55612533323227, 75.24687490155621, 11.31594479084015, 0.3603610792948354, 0.04147416543996623, 0.07879250307357119, 0.12666590436692202, 0.08270133647226519, 0.10056840676453807, 0.032773995997324105, 0.027116216426234574, 0.05324067074745413, 0.01700551632130819, 0.050514650290771845, 0.03497853274306944, 0.04588505072939781, 0.04889615548534259, 0.04636099434367592, 0.0035056396483278446, 0.0682389677592343, 0.07471303891150222, 0.0171041501415593, 0.0629924375924372, 0.04452870355077809, 0.013525717058068803, 0.06274092709645629, 0.049441920353039626, 0.07715901209702415, 0.02354568745490284, 0.032819474806949016, 0.011866822605952622, 0.058620634278462785, 0.039879101433701096, 0.07808833037533107, 0.05716223269701005, 0.12004742564092721, 0.03693849591898822, 0.023507710561276447, 0.05021504862534423, 0.033983238972723484, 0.03617660232609318, 0.0334711474997382, 0.022197527840973872, 0.024721272357348955, 0.041686992326210585, 0.04156039246628362, 0.09121047423010872, 0.024813176095185262, 0.019806636377207695, 0.0991289352156943, 0.09780473691681701, 0.11395213900194054, 0.0938024407913608, 0.1384962860855364, 0.1283990940259349, 0.2722925308250612, 0.12325324313414675, 0.18506625006275793, 0.08000641535486906, 0.12875060580911177, 0.09103759116823636, 0.19415818154811862, 0.2131665236647091, 0.30211412738407817, 0.1832520312839939, 0.11158172506839038, 0.11652907491811823, 0.13587974342367343, 0.1752083225836677, 0.19615384059086924, 0.22181925694307975, 0.16041965404104802, 0.1905230483821323, 0.10337981155082103, 0.08387510574633077, 0.1125505428400732, 0.09319120221921513, 0.2641418456069885, 0.16458786182826565, 0.2046173961172181, 0.20129278903045963, 0.25476584871930463, 0.17635307244716153, 0.14224766543315304, 0.1391697233362544, 0.13126256214755197, 0.2598740617113729, 0.3376914038052482, 0.5228637723672775, 8.336012305751924, 52.17692129073605, 37.454677474114206, 100.93004488175916, 95.6476006969329, 109.9909867009809, 90.01987811057799, 66.58907428864511, 45.88707516270299, 52.689088698356386, 121.51866005313013, 98.87038477005498, 76.64181878489833, 83.77399782980643, 63.88768696015882, 48.46595902596751, 17.82812753031331, 5.526408745396522, 0.9853101738037603, 0.3122525962610399, 0.11689305095182312, 0.20792997562356536, 0.1998190656905213, 0.41363100310967815, 0.17487735727862005, 0.42490168865169253, 9.685491996426737, 14.453240806056609, 7.283829642880348, 14.843634309307223, 13.777096752197513, 20.011077542458814, 15.406434612889445, 25.813720187833233, 21.215153009660785, 22.406676892311346, 24.279940089871808, 17.843722874118438, 15.290901199463876, 16.096098096139972, 11.970942366507746, 12.498209918698958, 10.577618422046786, 10.786605246605413, 12.162622713273572, 16.042040971017656, 16.391627115588037, 19.918382129361554, 15.508027922722603, 17.892401449141964, 11.364830270890268, 10.123715862151116, 11.122278744174588, 9.507317350756738, 6.16012599199049, 4.700642449240531, 5.896620183221756, 4.561982250982716, 2.2498641763964007, 5.1799472589646625, 2.561686476392131, 1.3373715791010088, 0.7002662014096015, 1.6689920425415041, 1.30022881732833, 0.4021670795496433, 0.11606934555475751, 0.147888554680732, 0.09461622534980697, 0.29143719062689816, 0.18372553490823318, 0.5275348862332683, 5.350935632182706, 42.958402172211684, 88.53122880381923, 143.32238628018288, 110.87544979587679, 88.19188102599114, 44.59674873659688, 19.881762881432813, 33.370395783455145, 61.903775661222404, 78.82427261721703, 79.71382694859659, 93.8176267377792, 92.10305675383538, 86.75841162281652, 108.96310606310445, 89.11371646388885, 16.19787379618614, 0.5544335202824685, 0.20779088470003299, 0.226770437232429, 0.28072498318168426, 0.11248642128081092, 0.2386777571612789, 0.12906241891605238, 0.18297300674021247, 0.1792599011452929, 0.1138314341885909, 0.13291898213567274, 0.12575727046257065, 0.20829493991069256, 0.12989284290421393, 0.15994998085643017, 0.2011429269107119, 0.2159694555185495, 0.11703372767735874, 0.149094331108274, 0.11221223075183169, 0.24161715991795066, 0.07482511757482445, 0.10207907086418522, 0.1535152406581948, 0.1263142776705565, 0.16417985872155236, 0.12604679807179398, 0.0822541020029495, 0.11643755805468368, 0.13497963607791932, 0.23579542795496605, 0.277005136013031, 0.28911634258204894, 0.1648763552187912, 0.07898234732208714, 0.11578788485137687, 0.21636143206588684, 0.13414348175208415, 0.09253152390761722, 0.09468004047389954, 0.08561541236216023, 0.08662413565381881, 0.12013292105327691, 0.1916534724014421, 0.19484736956655982, 0.15357044495401845], [0.045030717137119466, 0.024099768207017935, 0.05294058261619461, 0.05140585186440618, 0.03972383073320793, 0.051307060996130596, 0.03672862996257121, 0.07428271966355462, 0.07173264279000222, 0.01311039972689844, 0.04410155590683703, 0.04501777025119913, 0.02058419838337408, 0.06961398067012911, 0.03723943823828332, 0.02838420110844797, 0.0109517315380095, 0.01620827543158685, 0.06944544898766665, 0.06089230330901281, 0.08839695504115475, 0.048022937825730735, 0.034790852692939585, 0.07066788782756175, 0.05014833768889789, 0.06091769529326309, 0.01617314646981897, 0.06692841348628845, 0.09798241568909538, 0.058075834681550344, 0.042315153780603604, 0.06100152063393786, 0.049149535235858736, 0.05448558660704763, 0.05082272488864199, 0.24100131715738007, 0.1646863041265357, 0.046746110573651335, 0.29698115443029716, 3.958374098423989, 46.6204720927823, 69.91389489942982, 17.60104779274233, 59.32650781446888, 77.99201626931468, 38.8075460926179, 23.57598250912082, 23.354449002973496, 28.565402107854045, 27.29246158753672, 22.92219792642901, 30.1511339987478, 49.05864877085532, 42.04912616360573, 23.6772894859314, 8.816171211581077, 0.8819282018849928, 0.06723209073947323, 0.020215055086619912, 0.09233859232476643, 0.060484189119550495, 0.11686968527013257, 0.1832773734725291, 0.7244928433529793, 0.5680030824676637, 4.558435447754399, 11.886085810199862, 8.644402776995014, 7.395658377678164, 0.38098689348947623, 4.747242168072732, 5.774746258412638, 4.181576082783361, 6.386876740763265, 9.723620376279278, 7.666381837860231, 8.730785135299929, 11.01634729293085, 7.011658337808425, 13.582976691184507, 15.570829972144097, 18.951082498796527, 16.07728836997863, 18.677822736001787, 7.173833635545547, 6.660511089909462, 5.006738333932815, 11.332354026456034, 8.087852770282376, 4.082861302360412, 5.907874934134945, 4.518041899127345, 3.8044735308616393, 2.038128873513591, 3.296847002160165, 2.9267000382946384, 1.9353609363878927, 5.5205805936167325, 3.8624768055254415, 1.8778926975304082, 1.5169849991798403, 0.5882466187880886, 0.14932568966140672, 0.5012467936162026, 0.5470867983756528, 0.490878222570304, 0.1589601799365013, 0.08992100269683907, 0.01790720946906555, 0.050369568559671604, 0.19975002584678514, 0.02566710940652317, 0.2526640405337657, 0.5412145199314241, 12.063181804072473, 34.583757462040076, 59.85586697055448, 66.9367531807192, 80.71650243574574, 97.97672763947519, 34.19095954587383, 28.50020839321998, 41.77471322398032, 41.73577193290957, 56.23353065982942, 73.47049620843703, 79.31387855160621, 64.95368519136983, 76.40077344832882, 69.08521575312461, 11.350861730114108, 0.39339650662675985, 0.022212100748513496, 0.05115639831450197, 0.060432669706642635, 0.04665203114611007, 0.004373072625903954, 0.03494254576282636, 0.046856212730128924, 0.023520460179556283, 0.0147380416221436, 0.06306090287023014, 0.07557911663165978, 0.07273046465049829, 0.04862243226999718, 0.019758778864577897, 0.012116362340748312, 0.09602611824389427, 0.01489236620405028, 0.021677880825835372, 0.015869343769736588, 0.04940452760145549, 0.10038525046360108, 0.012930857445744258, 0.0469319328605648, 0.013241435235906995, 0.02391951154887436, 0.019064404430889317, 0.024565856100150177, 0.03873944605490373, 0.04748487214167272, 0.04983830190594158, 0.019203432152167927, 0.010001539278985753, 0.019462442648927533, 0.031728169152272806, 0.06327636892937365, 0.006167536869930525, 0.0240425088803374, 0.06531188369638498, 0.06249339259680241, 0.033826156474289396, 0.07459757413955466, 0.012478181836946357, 0.04259236652644412, 0.039173787264453794, 0.025599797091056264, 0.02447570670366047, 0.04493977867006775, 0.052168254905770865, 0.01865374299907877, 0.01566840944090678, 0.0069388930851052855, 0.024899663591396906, 0.022838536589857072, 0.017927367157573183, 0.030191153543250217, 0.0574014934470817, 0.0377887194495528, 0.025338147421397512, 0.048052118114766576, 0.019770934764716416, 0.049786851440946904, 0.03428566367215207, 0.09132127352659741, 0.05306735867634416, 0.12627327664484903, 0.06810340850103287, 0.03362503158108842, 0.024670519032365373, 0.03185872202588907, 0.03193621181943004, 0.06079288041819969, 0.04421618181250749, 0.09748101114265381, 0.06342247721829242, 0.07467004605719159, 0.043175577771879976, 0.06260569725606231, 0.036869402449097366, 0.06278422255549701, 0.18720607153109967, 0.13775170991016975, 0.11039713863283397, 0.23854033630942148, 7.613614682228335, 57.55243547501103, 77.52473646594633, 21.040901714755645, 70.47651183220648, 86.96756024514475, 59.79239909879623, 38.67261655869023, 30.44534117944779, 33.97560181156282, 23.727950819077034, 32.020429718878965, 40.56838827748453, 48.18025750498618, 47.788063633826475, 27.36501955216931, 10.535889306376058, 1.1759145654016927, 0.13728001425343175, 0.03343923993769192, 0.11330563740264024, 0.03305988085846747, 0.058070663588061455, 0.4137033830967642, 0.996475016638156, 2.98845162795436, 5.903298508736396, 7.557020273900802, 3.914062837439199, 2.3215119060008758, 1.1675164031405603, 1.4758734116631171, 1.9409322954954642, 3.9497291945642043, 3.6370206840576667, 7.596772515004681, 10.741010635129868, 12.126502586949258, 18.12345847006767, 13.399947131833724, 12.188756485139171, 14.882122566623075, 17.630730329021333, 18.47599521760018, 17.914739347273304, 8.694767971192638, 9.070050543354405, 10.23583681352677, 9.132921234253915, 9.263276303968123, 9.337433615038472, 10.745158541587092, 9.052014504709552, 7.101179572843737, 3.801760966739347, 6.800512738766209, 6.322090952627121, 7.982510655157029, 9.419013031067388, 6.62843983019552, 2.6750638119636045, 3.4083366970862117, 0.680917700932872, 0.27389978329020165, 0.3389989013873762, 1.104224915466001, 0.5345363782778864, 0.1645329026805778, 0.019462754829756675, 0.13773954443393216, 0.06760324501702863, 0.2032477534826725, 0.014136150280284065, 0.08337233756338397, 0.9615570967716556, 12.481629079388036, 38.51608653222361, 60.67548544176164, 61.68959463796308, 60.0228108898286, 52.11296704507644, 28.484167860400294, 41.37543162991924, 58.113993367841175, 56.88606400643626, 64.3442665376971, 82.8430389588879, 90.38870642262121, 76.64488607837309, 87.08512152394941, 89.89746093750001, 24.363545410094726, 0.3186727501451969, 0.05840365519566883, 0.06022504838784376, 0.06134435264093261, 0.0705668484912284, 0.06497614566356906, 0.13787134220042538, 0.08393921198383456, 0.09995556706863065, 0.02027807922493066, 0.02966839812635895, 0.07105645528363605, 0.03218948623285659, 0.08061570040280781, 0.03567634691153804, 0.06638054570723927, 0.03373755840584636, 0.04963446123104903, 0.03630302598579757, 0.06512927897875348, 0.06505158234147296, 0.03167901695105097, 0.01089870005906109, 0.028319460933186838, 0.08538612990730232, 0.028140001006484516, 0.06591711613920427, 0.055846426891343254, 0.003026189505978818, 0.02350614008103167, 0.05083727289832408, 0.030919967459574826, 0.02380536827859619, 0.051500394775141636, 0.022765750576171185, 0.024693107134812785, 0.042168800343549064, 0.03740540735663907, 0.01673510643623529, 0.029699941796641198, 0.012374455447218592, 0.08999653130529389, 0.07175007895115884, 0.009684970681255144, 0.013619130946725849, 0.14166068886556935, 0.1772869489486179, 0.15781734529281818, 0.12345471659735327, 0.1595393577290158, 0.10648531749123528, 0.1120203180659202, 0.08733507290843033, 0.19970764586281395, 0.12108196609563406, 0.1947972367727949, 0.1560052715602421, 0.14801073038289625, 0.13060979394903108, 0.11191795339747784, 0.09149765761028375, 0.16725079877482307, 0.14659104688513666, 0.2758427967707957, 0.12735438758447287, 0.3812424910645331, 0.2046271867208904, 0.2074540971267608, 0.1704986898168441, 0.13105153556792967, 0.10580136185331691, 0.14553349314918443, 0.15911355073894226, 0.22703515125378487, 0.1491496886216825, 0.1920710516072089, 0.13598927867508706, 0.20279688009571648, 0.09881321506033983, 0.15435501091903256, 0.2600268196434744, 0.3484125591574177, 0.23768365082721557, 0.5535718245852379, 13.009684047391339, 75.12961956762499, 90.27892712623843, 31.012833618348647, 81.6080807101342, 94.74527512827228, 55.654263265671275, 34.38093170042961, 38.262611204578036, 47.33769709064115, 41.85019531557637, 34.96188963613203, 45.932154963093424, 68.97120814169608, 59.907669713420255, 35.546977827625895, 14.092702423372577, 1.8440502425355298, 0.4604024788545024, 0.11870143214060415, 0.2665649817114876, 0.1472201123232803, 0.6693438284339444, 1.2410657468342012, 3.418483623573857, 4.083329290151596, 13.01834071836164, 25.089419234183527, 22.60462714779762, 27.766627111742576, 14.949092134352654, 19.862186331902784, 26.541025677034934, 20.967251370030066, 23.355572762027865, 28.077225877392678, 24.7297731907137, 26.056291326399773, 29.351176408029374, 24.72103807233995, 30.86172038509, 28.29419178347434, 33.46033180913618, 33.58556916636805, 33.98388585736675, 18.480635381514027, 22.106162540374264, 19.814319687504923, 29.443397214335782, 19.4982688273153, 17.41761815163397, 18.770594635317405, 13.915277930998034, 17.478452151821507, 8.177463239239108, 13.012981780113714, 8.102668543015758, 11.460312527994956, 17.722419654169393, 10.371560627414334, 6.4763190380988584, 4.6474923722205626, 1.4819875287432827, 1.1656022864964701, 1.1593013665368481, 3.316929292294287, 0.838784765331976, 0.6322141820865294, 0.3956392749903664, 0.5540053077763127, 0.25944042530271316, 0.5933893363802665, 0.13334411496837295, 0.4428808529290461, 1.428663028824714, 18.653237319761708, 48.97886776155042, 77.64756941026258, 87.25483463656518, 108.48313346985849, 126.76597549069314, 45.36478019529774, 40.675245408088934, 57.278783475199056, 61.99678290274836, 73.01172010360226, 92.06380951789119, 103.69344880503994, 86.29507772384152, 95.2523434546686, 101.72859238040064, 31.545587585818385, 0.6112276630536203, 0.26173522635813684, 0.24329856969416144, 0.24842758963425315, 0.16525852584069775, 0.13223051423988036, 0.24762062325833306, 0.18952056104617734, 0.1387871849921442, 0.17742599390687483, 0.12266113377747037, 0.15704411742908342, 0.2041153787004371, 0.19713100106004747, 0.1302133740917329, 0.14911385102858468, 0.1786889817806021, 0.12224911637003384, 0.14666472922169393, 0.11802719815844491, 0.14511406001064087, 0.19008677663101306, 0.1937359138842552, 0.16431870449694896, 0.12283994635987668, 0.10931275649777344, 0.10657831290436369, 0.14957678263946889, 0.139550254530003, 0.16612273430632007, 0.13979330358486022, 0.17156085540210048, 0.1848027771038394, 0.10913007517134952, 0.10795566238342755, 0.14986400432404012, 0.14725014296991212, 0.12392458130395222, 0.10131987773122327, 0.14890178256938535, 0.1228859652614882, 0.15145293196603177, 0.19210783914933283, 0.1567429223007733, 0.11348444998504655], [0.020118261792606885, 0.03951225257028015, 0.05498032235810834, 0.024572789195864916, 0.11254730994903273, 0.05046141484091359, 0.0704852907708095, 0.06502885251275956, 0.021128802627865827, 0.0398610255891277, 0.05088235334222836, 0.033443353829845306, 0.07637191804185992, 0.051322378924176584, 0.06686063768762736, 0.06869102092159372, 0.05518250828308444, 0.029163345086177992, 0.024944786170137026, 0.018088981066079392, 0.049998498551787875, 0.14433356963338392, 0.0521977377995368, 0.04809180529968393, 0.028733154157957727, 0.04734445588603135, 0.10400732949135766, 0.014796820675743925, 0.05247082133146544, 0.03668728036685817, 0.05526764746454935, 0.07595970145156307, 0.09686624856605645, 0.07073680509723003, 0.041311620734632015, 0.20941025667613555, 0.4756507848299319, 0.8391574517853799, 24.708831656363703, 87.31410949460923, 89.82583845815351, 80.82354391774824, 51.8968052248801, 44.416747247019124, 30.420200747828332, 13.855655943193744, 37.07836920215238, 47.15253376191663, 32.570865731085505, 40.91593380897276, 52.60619332713466, 49.38046747638334, 37.66429285849295, 16.987928382812008, 5.1858494454814545, 0.23101775125870783, 0.07833779924699376, 0.08754835944742927, 0.11588993542377027, 0.11509213145942458, 1.0449105885721024, 1.155580140409931, 0.33057086169719696, 0.9285787276683316, 4.039844913828758, 1.5084071433351887, 7.1141405547818835, 4.867540280665121, 3.949165108703798, 1.8599378029184959, 0.18924184293756563, 2.9097115176339305, 3.5706605545936094, 2.6748147414576624, 8.71958480727288, 4.707346270161291, 4.616438477270065, 10.539059562067832, 16.57811914720843, 15.517381794991033, 9.260351196412119, 11.88845786356157, 13.955752868806163, 9.804901692175097, 8.746684462793413, 3.708802019396136, 6.43553864571356, 4.674270883683236, 8.138575390461954, 6.39921308525147, 7.721424458488342, 5.306102450816862, 4.463753354164862, 2.4415285885334015, 7.922977901274159, 9.755595537923998, 7.421585244517173, 3.2772655496674203, 4.095517565165797, 1.6295948985122866, 2.662507079301342, 0.29810463769301293, 0.23044005967676642, 0.21511735124213083, 0.21199577277706516, 0.48288908997370356, 0.3386380739750401, 0.12270669302632733, 0.13308579012030555, 0.5249876745285527, 0.14114898809742543, 0.05137751044164743, 0.0997870890123229, 0.07365776811756435, 0.41512898079329924, 6.376641315798606, 32.21216890119737, 50.68860146307176, 78.46134354991298, 128.14689297829906, 80.97107994940974, 36.4287462542134, 20.398307654165453, 38.176417120041386, 67.41224642722838, 46.1194638283022, 38.40660533597393, 66.5381383895874, 68.83402716728949, 77.5796418036184, 81.07734480211812, 42.168158331225, 2.084616437073677, 0.4930179061428194, 0.03089094613378327, 0.012408571257706613, 0.06364024154120876, 0.099120469944131, 0.045069542473122004, 0.045676004487059774, 0.045098588696771094, 0.08295891821504602, 0.09731654738706928, 0.038514108952855876, 0.023048971366557865, 0.017045354808590586, 0.03720743491524651, 0.07513558236701835, 0.054006996158991134, 0.06427278501852866, 0.026738199916097428, 0.009983362885372294, 0.0077391983265237465, 0.09052359213631961, 0.041849621301216465, 0.10011652214152199, 0.020115739448116194, 0.03461990400307602, 0.06785468273465672, 0.05303833160489317, 0.023006223660383015, 0.0016810946028506866, 0.026396976693743662, 0.07432151435604019, 0.0204287285000206, 0.024473096259058486, 0.04267603098865479, 0.02268970102792786, 0.08478901033560116, 0.018235347909672607, 0.07609500023987024, 0.03482603145042255, 0.0667698715903586, 0.07365210672780391, 0.01082643977321324, 0.026352807894469272, 0.08027198739470014, 0.01908719746185647, 0.03844702263332663, 0.07599202270108847, 0.0505796451902678, 0.07354610314172122, 0.07664328936727778, 0.08906905163800524, 0.02631194284936834, 0.028354620538471688, 0.05900986823103121, 0.04661077348094794, 0.04123355637514784, 0.04764508793971712, 0.024381841780738007, 0.044385199960801876, 0.07267755095756824, 0.15802041987978643, 0.05291670748603441, 0.05221853708668102, 0.051236194032695026, 0.017862875960887443, 0.048865381733424244, 0.033852299224705465, 0.07114671576287478, 0.03917884727519366, 0.08563123973867587, 0.02071770261071863, 0.016614445672941305, 0.009576461987660058, 0.028541685803042307, 0.09435996127825591, 0.03533947123815456, 0.05880204006849278, 0.03856091309458979, 0.3414392897919301, 0.39215875368925834, 1.4764064862843485, 36.0077896425801, 100.96040402689289, 102.88523658629387, 94.34480113367881, 62.14132616596838, 51.90184547055153, 42.0007594170109, 14.553961388526426, 28.20446364341244, 42.33023851148544, 30.706269010420773, 38.889151004052934, 48.939087083262784, 49.53125123054751, 39.287444160830596, 18.991573126085346, 5.570179945038212, 0.5035969062197594, 0.019566485049924063, 0.07928224776180522, 0.20809045572194362, 0.07739557238716273, 1.2530162281567052, 1.8515963924507943, 0.2556829938604947, 0.7777961992448377, 2.8037504034657634, 7.572286628907727, 3.578301331689281, 0.5604701092646969, 0.8855353728417428, 0.7872190194264536, 0.5364002395541437, 0.7267629763772412, 0.6441816399174353, 2.0646130846392725, 6.269801835859976, 9.016312110808588, 11.77183501182064, 12.008690276453573, 13.178768600186995, 16.027343849981985, 15.614403582388356, 14.675517601351585, 16.997461703515825, 12.192184636669776, 7.893949420221391, 5.100992398877298, 4.521998099742397, 2.6520936767901144, 5.815347202362553, 5.669496809282611, 4.23599406596153, 5.85689490841281, 6.765722786226581, 1.8103165107388652, 2.502274090243924, 1.3856336474418642, 3.441912676057508, 3.113889761509434, 10.222088906072802, 7.513324579884929, 5.5466212091907385, 0.7696705804236474, 0.13143234255333103, 0.231522235478605, 0.5641588532636242, 0.9007823611459426, 0.4492697504258925, 0.132018476424198, 0.1301724803183348, 0.5539047970406471, 0.17033666222085878, 0.07405823291910273, 0.046573411372880784, 0.09355829623077186, 0.2040953531620964, 6.370090957610838, 33.494389749342396, 41.22838981689946, 75.12090406110211, 116.64939834225564, 52.859276417763006, 31.10391889849017, 28.53548226817962, 52.30119374490554, 77.15421368998867, 57.088113138752604, 56.78541991018481, 76.7015721721034, 79.69329726311469, 86.94300620786606, 98.10474595715924, 61.72093437563989, 5.831076397049812, 0.5469817523994754, 0.07315004334574746, 0.018638815775874163, 0.02681288582783553, 0.13127964590826344, 0.012753848042789728, 0.018961811851289485, 0.038545024431040215, 0.02495987235658592, 0.043470720805588274, 0.032188854210319064, 0.015583178328890956, 0.07402280135260475, 0.05746531623205351, 0.023295124992728237, 0.030337819161133903, 0.0401979242451489, 0.030838924933285005, 0.024311668126873916, 0.09328396014508702, 0.05196267138085058, 0.04384866645259242, 0.11197029252446468, 0.0976600535514374, 0.06484332133925731, 0.08439760069332777, 0.04616175402676867, 0.04532094188635388, 0.005008443925274356, 0.07789986508507883, 0.05531008490511487, 0.03951777606421421, 0.02495129983271322, 0.030734283068487724, 0.03794595516557175, 0.10308606279713493, 0.021719891172383102, 0.017861776624716098, 0.08641640325227092, 0.013363340892077935, 0.05466017804499115, 0.04532215230527424, 0.07064192510780788, 0.11166984050144112, 0.08513560383430413, 0.0809590763322288, 0.13541770047478138, 0.20547072613431563, 0.21742846997034168, 0.2564357518548927, 0.20486979144475154, 0.1171467945941033, 0.13140854786240286, 0.1503758123444934, 0.17202639171192724, 0.15278256948917143, 0.1661427292011438, 0.1924991721828138, 0.14399027031275535, 0.1452987484874264, 0.20281725803450232, 0.16924556915558156, 0.09621834502585473, 0.24594834525017972, 0.32978025895933955, 0.08800051986209809, 0.19507684354339877, 0.18093761837770864, 0.14187657244263158, 0.1459596372179447, 0.12696971951593317, 0.19902484701766124, 0.21970578889933326, 0.06094376143488673, 0.1566816965538648, 0.19492756365047348, 0.2606108237899119, 0.20453683431110076, 0.36501530858297504, 0.8113511567634921, 2.980051136785938, 47.66709381534208, 118.75464424010246, 110.55493723961615, 104.91950327350249, 74.17133746608611, 64.13598083680677, 49.14399170106458, 24.074096064413748, 56.301536713877034, 68.19711269870882, 50.43426713635845, 65.15651487535047, 74.54702992593089, 72.66030711512413, 53.944972791979396, 25.91897503022225, 7.908546520817665, 0.9828430642524074, 0.1978614505740904, 0.15430446443778856, 0.6035064773694162, 0.751770047410842, 2.6215347359257364, 3.650782564955373, 0.9972037807587655, 5.757345643735701, 14.308253334414575, 19.957707812709195, 26.696543731997092, 16.44877016544342, 13.106419501766084, 6.47102972192149, 3.594049402782994, 13.89364900127534, 13.786513382388701, 16.353463434403945, 29.44946119862218, 21.39034567340728, 22.820416342827585, 27.408085215476255, 31.30896079924799, 33.224024695734826, 22.11466427772276, 26.19552173922139, 32.10467438543997, 27.39358617413429, 25.588364331952988, 18.73739177180875, 23.145982873055246, 16.020922930009906, 26.03745218246214, 22.45501029875971, 21.091918022401874, 20.10697360961668, 17.119329744769683, 8.10208950311907, 16.554261330635317, 23.146202525784894, 20.923169812848492, 12.66074215212176, 14.308045448795443, 10.618466965613827, 10.929548182795125, 1.781734321867266, 0.6030454150130672, 0.9030541489201208, 0.9146212185582808, 1.4383727336122145, 1.0231675423922078, 0.6536860331412285, 0.728335662955238, 1.2726034416306404, 0.6259475215788811, 0.2568604097130799, 0.185732685269848, 0.1291332360837729, 0.8298201883031476, 11.497640744332346, 50.31736873811292, 71.61650949908842, 96.59533162270823, 152.49863009299003, 101.83961899049821, 48.63961804297663, 33.14729529042398, 54.892201654372684, 84.14085711202314, 63.15052847708426, 55.389820991023896, 87.46791347380608, 90.58786084575038, 93.20157927851524, 112.69655135370071, 70.88369307979461, 6.843478381633759, 0.5967762417370274, 0.2291246101019844, 0.1493870379823831, 0.17803039131385667, 0.25977238652206236, 0.13042962539099878, 0.10639856569468976, 0.09765891208043022, 0.188459437340498, 0.19128340596873916, 0.11110185525350033, 0.09681656010328762, 0.14461863095000868, 0.18104654075878282, 0.13965591337651978, 0.16879633519678347, 0.1949337076756262, 0.2027023908111357, 0.17645611127297725, 0.1580420848462851, 0.12427777848056248, 0.142390908553235, 0.1970707099404066, 0.13143238851860647, 0.14385248173869428, 0.19001785936134477, 0.10336647396005931, 0.13355917117047694, 0.14587726744432605, 0.16816872532569593, 0.3253713003810375, 0.11865929730476872, 0.1289706415827236, 0.170329506959646, 0.19007188388176505, 0.1942586922837842, 0.15347549601668312, 0.10932954148419442, 0.13413200575497844, 0.11525187611339555, 0.20178840195219364, 0.2006709401405627, 0.17107411377852963], [0.046328014258535645, 0.04943766090418062, 0.02031774917286971, 0.01361687960583837, 0.053274616103379004, 0.01660555330736022, 0.0682345474319112, 0.04882628826664821, 0.06191141858336426, 0.044098549011734225, 0.027292012537439025, 0.07481967835056205, 0.04813542634609246, 0.06936167727314657, 0.039042108241588845, 0.0936710567123467, 0.039402165735561046, 0.0441753416652641, 0.00404697293678539, 0.047093052642359856, 0.044682239062122764, 0.00808329342098366, 0.09370229777789886, 0.09112990476311215, 0.0411526728121023, 0.04983791503153982, 0.041004078567869244, 0.019656245656792196, 0.02059880768009011, 0.025589931793811343, 0.013247368586880547, 0.025180712522518252, 0.05134848720063606, 0.007675272598487115, 0.034449296222338756, 0.3630448078676578, 5.696255218598151, 51.400617553341775, 101.64290428161623, 79.8983979994251, 73.10652379066714, 78.58096799542828, 67.47347462561824, 50.60603557094451, 28.162025559333067, 39.25919917321975, 48.2470593913909, 38.71665693098499, 54.54578968786425, 51.64192176634266, 41.42573210500902, 27.758229317203647, 9.911053776741028, 1.57898124667906, 0.061263538025800264, 0.06352543177443647, 0.12591660908994176, 0.12899861911371832, 0.022226790484461575, 0.0590414195621927, 0.5805324811127879, 0.8594335928078621, 0.2066455526097167, 0.7628991599044492, 1.6637850961377545, 5.810972288731606, 3.90564420530873, 0.860795451989097, 0.19479090888654033, 0.809396529389966, 0.4820200091888828, 0.17733990094594418, 0.6056518912796052, 0.6731349217795557, 1.6201845195985611, 8.24545850676875, 10.488330568036726, 12.323857622761881, 9.568337663527458, 6.782752736922234, 11.609828376000928, 13.052128995618514, 14.495913251753777, 13.507990779415255, 4.976587074418222, 5.15578055574048, 8.786182730428635, 5.24531698996021, 9.412064552307129, 8.75093827324529, 6.680597547561892, 6.614586999339442, 1.7082255501900951, 3.4490562927338386, 2.549422940900249, 3.6812530073427387, 7.128342476583297, 7.686949276155041, 5.093437913925418, 3.2591488572858998, 3.046715004790214, 0.9867188562789272, 0.1464875943718418, 0.2794658104258199, 0.1631706910988977, 0.11945494090116794, 0.26448422562210794, 0.06278877694820685, 0.15133189007399545, 0.351859770955578, 0.344270474968418, 0.04614688426015839, 0.08009733466972267, 0.04149568484975927, 0.05105114549458508, 0.0789270740783503, 1.9485932973123368, 24.158066165062692, 51.53269552415418, 50.95078053012971, 45.719464440499586, 54.87457060044812, 62.09549327050487, 36.88529837516047, 45.235322367760446, 39.371116161346436, 21.572133802598525, 50.593338858696725, 68.33310127258301, 67.37980842590332, 64.74575642616519, 83.082640863234, 58.28939783957697, 11.307226342539634, 0.5069982140294967, 0.14700871802145435, 0.016796989103538856, 0.11960002263226818, 0.035105504155639684, 0.03673884957548111, 0.024072416952901313, 0.056819190015836116, 0.015568790240063062, 0.01876710677489398, 0.05657664274856929, 0.094326866279927, 0.016847489619507425, 0.03705500640095242, 0.035056298328263145, 0.0635532139530105, 0.025517850581015793, 0.054475554685679176, 0.03135434314308148, 0.09167643188829384, 0.005685416671762904, 0.05198731259893506, 0.06719050748694329, 0.037752958465247385, 0.005393575477008258, 0.02632333074636277, 0.02102323379668017, 0.08113874693311031, 0.05371477575071397, 0.020400243435776042, 0.007650862643194776, 0.006961346164556041, 0.009903613132454697, 0.03397344070817194, 0.0365009026661996, 0.017729597729480556, 0.09100035929511632, 0.023859572829678658, 0.0216695630261975, 0.07574200990699953, 0.09992174428677368, 0.010402416810393335, 0.02642947031305202, 0.09592532405569669, 0.018836941434851578, 0.020307315055341012, 0.03381793252042225, 0.04195757075062683, 0.11729471085052337, 0.03862356376503745, 0.05911204520793212, 0.04561643349006773, 0.03778052613920262, 0.04017889845154939, 0.03138917907621832, 0.03971908481851701, 0.03044567667999335, 0.08974042811220692, 0.069595203855105, 0.04896341800509442, 0.020020012931537726, 0.02667975698357388, 0.05298845928102251, 0.038851608987897635, 0.0472532416273269, 0.0021834461057874104, 0.0069796661996553025, 0.03096013919510428, 0.04646931917616918, 0.05885164043115032, 0.0175295319528349, 0.02052216824414509, 0.04918816138900096, 0.04819376777196604, 0.05871761717923707, 0.05835089088988401, 0.08311289422694715, 0.19702284476689755, 12.787776935485102, 68.81327782907795, 114.13764584449031, 92.1253122821931, 80.22727304889311, 88.30940308109408, 76.51423192793324, 59.857247644855136, 30.097234749024917, 26.763710398827833, 47.2653175938514, 38.4316732037452, 50.744875707933986, 50.4162948362289, 45.68803841067899, 29.74669448791012, 12.643492548696457, 1.9965291960585503, 0.09516894246541685, 0.06762232060634321, 0.05646682787506331, 0.0345879006800392, 0.1285513616617649, 0.07200710144975493, 0.9786349126408178, 1.0617256669267532, 0.039135149619992704, 0.3172324129169987, 1.9116127010314696, 2.049677802189704, 0.49975390275639875, 1.2238706888691073, 0.28507191928163655, 0.7802815723323053, 0.6553835614073662, 0.2546399345080699, 0.2017244489322747, 1.1345429982869857, 4.379557226934741, 4.089026042530614, 6.640655561800926, 7.39606483328727, 7.78228787645217, 10.816553523463588, 11.07962198795811, 12.181726617197837, 7.439714439453618, 6.119861881579123, 2.797758737879415, 1.782266906192226, 2.251330897692711, 3.887876113576274, 8.012824202737502, 5.950435101985932, 3.1233632660681203, 2.551055137188204, 1.9777425138219713, 2.128290803201737, 1.248398863019482, 2.1386024692366203, 1.0360215171690912, 1.8651486716924177, 3.5322848202720767, 4.866105183478325, 5.255345509898278, 1.6149957141568585, 0.0977083936994595, 0.4780992324794493, 0.3708507228762873, 0.20012836602907028, 0.6751516942054995, 0.22353869532385182, 0.28522427884801743, 0.5012598171109154, 0.5829292944362087, 0.010860999914697342, 0.03722314354813388, 0.029152345978805137, 0.049153017105474595, 0.12503165496332994, 2.335148271053068, 23.573336870439594, 46.51601937509353, 56.23502508286507, 44.82309695213072, 49.78386755912535, 53.45909310925392, 38.33588500176707, 52.35582451666556, 47.02145599549817, 39.696390474996264, 64.6252376802506, 78.8849046153407, 76.32711918123307, 73.81482539638397, 90.91246051173057, 78.94223397777927, 23.610868069433398, 0.4341149071772253, 0.14109067348462923, 0.025736628055212, 0.14503679238259792, 0.029329643622341178, 0.043233317818733, 0.02885495639225889, 0.07087911359004437, 0.07401203015638937, 0.05241107413425081, 0.0466934152157797, 0.04267435325610061, 0.03940553269198826, 0.012436727861753635, 0.07559423154640584, 0.06072260334246582, 0.014829408140823007, 0.04894322009697076, 0.06715689154882586, 0.038661914126526926, 0.030182738067401998, 0.0932949458459212, 0.08681698296699794, 0.03886786154321125, 0.08286498817464999, 0.04756748706342713, 0.04379651501714703, 0.04600570574703236, 0.023197364512710802, 0.015344178048713554, 0.008964713967044749, 0.01411238336004317, 0.04869938580199115, 0.040996007831586946, 0.029159221617925554, 0.01897244898211812, 0.1290322810171112, 0.039080577346706585, 0.07166274492779086, 0.05404336235275673, 0.06775444012976463, 0.019933397115598765, 0.12398942298586331, 0.16446706508436512, 0.12386293420868537, 0.1255807025177825, 0.1343598709471764, 0.11211647742217588, 0.2863094883580362, 0.10379906082826276, 0.19426995377627113, 0.16435981277496586, 0.12716542433706984, 0.12629537062058527, 0.20688091014181414, 0.11628419491312197, 0.11943447103183116, 0.288683993201102, 0.1397668275861971, 0.13680356885156325, 0.08758941409929145, 0.14358940714549634, 0.1048857182444584, 0.14443092408680147, 0.26105350003607813, 0.16087702385360197, 0.2282614435159391, 0.1675219632565014, 0.1331905296613132, 0.16706152909225033, 0.11646391914015818, 0.11070817799097109, 0.21187453170216855, 0.17788944645754753, 0.20539109895546592, 0.17182270425461954, 0.1467660060452838, 0.27601280700295205, 22.574352333622596, 90.04510679552632, 127.19067404347082, 100.09233643931728, 93.88364022777927, 101.39395144677933, 88.35043891783684, 73.53405429470924, 44.094269583302165, 61.52956977967293, 75.90519766653739, 54.06131421366046, 77.53957086993803, 68.82976747328236, 59.09307187603366, 41.34228760196317, 16.93037348408853, 3.433814942836762, 0.3009468238920935, 0.37572245984788866, 0.38406797654686436, 0.3386899228057554, 0.585459836067692, 0.34563916765393754, 1.443947034497415, 2.080102769597884, 0.4625788733603493, 3.30079609347928, 8.306950484552692, 13.816876449892598, 8.02276643053178, 4.974465072154999, 0.41773898106428886, 1.4286010063463643, 0.8752620724901077, 1.4165698712871921, 1.9813912986747682, 6.6103317179987515, 9.251636670481775, 22.426329928059733, 27.220713592344715, 31.08792151174238, 27.676955846048173, 19.223618584294474, 32.96402646649268, 29.743150626459432, 29.300364063632106, 30.152420536164318, 18.041490739391698, 13.18498359572503, 17.462378278855358, 12.880929304707436, 20.53821271465671, 20.295729829419045, 17.276583448533092, 16.707588741856238, 11.332145160244359, 9.963508613647955, 7.690155323474639, 13.842426769195066, 18.24181010646205, 19.085849254362046, 17.77436948591663, 10.74591261725272, 15.025359680575711, 3.5490862929051925, 0.21226666146709075, 0.6472193930418261, 0.8844444023505335, 0.7178185014955459, 1.0617303247413328, 0.3757066784366485, 0.9328825483399054, 1.2870110427179646, 1.4493138174856863, 0.4842958419073013, 0.2945336260862889, 0.18756375798294622, 0.31767606975570806, 0.20094696161968095, 3.354870869267372, 36.64178979012274, 72.51241022540678, 63.74079811957575, 66.54685389611029, 75.03383528801703, 77.78649191702567, 50.29601143252466, 58.61255407333375, 52.16575430285547, 35.04938986993606, 68.75424615798458, 85.42063236236574, 89.85464434469901, 82.91965069309359, 105.60249774686753, 94.65773567076653, 30.065612600695705, 0.9855208173394204, 0.2661325710435068, 0.11989227751450193, 0.2327045083286301, 0.12758255155096132, 0.16308940917013154, 0.1006731309837872, 0.18359269526216293, 0.12019063811749221, 0.12077966780071298, 0.20073558263961347, 0.24447068421831056, 0.0532071084354914, 0.14208202190216512, 0.125597755634977, 0.1701151708801908, 0.13546872193053847, 0.08521700067625892, 0.12787463789385173, 0.2734293440176595, 0.11928785712488237, 0.23382285880225323, 0.2011935040354729, 0.1741200793654688, 0.26358922042192956, 0.13226468176130327, 0.16967169790258332, 0.15460578214016654, 0.1609810126284438, 0.12301387130132607, 0.10533535056897711, 0.11136522862098872, 0.1296067090644952, 0.10831306538274212, 0.1068659406155348, 0.16384812732858045, 0.17832403281523337, 0.1315854682076362, 0.18810919726327543, 0.1937788301297734, 0.18245727634958683, 0.19343421313791506], [0.09507295930938375, 0.041104815299472505, 0.025184395490214232, 0.037459439537938566, 0.094727193185639, 0.04121653773190995, 0.11552787460987607, 0.02679043562121449, 0.03182608093465528, 0.05275144699900862, 0.023656841067056504, 0.06672270355686065, 0.03146108408879129, 0.10744851217755388, 0.04472085755438574, 0.05758781752158558, 0.024486866689497427, 0.05013554785100203, 0.03046711373533453, 0.036650986951445384, 0.10328702298143219, 0.05682167214071078, 0.03733839764590225, 0.10426669621900206, 0.10584347370651462, 0.20002005651833552, 0.10866463079207367, 0.05424906462130528, 0.05619974664202141, 0.15126629762591856, 0.04561049247821493, 0.015026151968707002, 0.04848436024340411, 0.01839789644544644, 0.5569117840739989, 28.479572803743427, 78.90296320761405, 88.81451022240424, 76.08554040232013, 85.40331117568478, 78.74686071949621, 44.72246070061961, 42.94949446955035, 37.44109822857765, 44.32583455116519, 52.095606634693766, 29.381237453030003, 54.3331854574142, 52.83074509712958, 41.999037496505245, 19.437226941508634, 5.603864279485518, 0.4664003957183131, 0.057795377553350506, 0.12126532157943135, 0.005731133926254247, 0.030540121914518457, 0.06407844000345757, 0.13703463629128473, 0.1500377837087839, 0.07534026573862761, 0.013329448204697862, 0.10985778975150279, 0.4071501137748842, 0.8534050324270803, 1.855828752440791, 0.2690648798259997, 0.22729430347681048, 0.3730969539573116, 0.1673961103323006, 0.17027342932358866, 0.12238025530091218, 0.3441125076384314, 0.35588210028025413, 4.043178438178955, 4.218608650469011, 9.197558952916054, 4.818564095804769, 5.936888216003295, 10.64758271940293, 13.38064024525304, 10.872967993059467, 10.776669882958936, 6.729513425980845, 9.71208272441741, 15.099462078463647, 36.567425574025805, 43.39537382125855, 58.64590990927912, 41.59635520750477, 34.48658466339111, 8.280195997607324, 6.564524317941358, 2.0258116505799757, 1.4299510371300483, 0.7819342997766311, 1.4221848667629304, 3.605905502073227, 13.788484373400289, 13.906583016918553, 9.019473541167475, 1.362634829936489, 0.31455282121896744, 0.13470251143219011, 0.3642035924619244, 0.09563610288164309, 0.3836311225689227, 0.2045181724092653, 0.03424375866269393, 0.20709202865198736, 0.16945261207799758, 0.2614754919082888, 0.026404476694522366, 0.01857612297059067, 0.22423719897145228, 0.20727795819121025, 0.06412262412449045, 0.11270654132409443, 10.849566152018886, 29.311968395786902, 50.188977795262495, 49.06290846486246, 56.08977579301404, 54.09905525945849, 70.5718489616148, 79.01713555858981, 22.656716223685976, 22.501682581440097, 35.784218465128255, 58.66945589742353, 65.62333968377882, 56.86979009259132, 76.65204048156738, 80.5984861620011, 42.56776155964021, 2.865365690761997, 0.25934962856192745, 0.2658688835799694, 0.08262573125501795, 0.011229135805831082, 0.07387358274671339, 0.030726943946173115, 0.13461727648973465, 0.04320208058362046, 0.021395822573873787, 0.050034826441157254, 0.04728608764708043, 0.06862850814697243, 0.033851927672062194, 0.06673057894072225, 0.009352116969474142, 0.1551720436902777, 0.13193506477100234, 0.04483652533963323, 0.06399232405988921, 0.011945328423603168, 0.03613630227083641, 0.052229921153235825, 0.0904855405491206, 0.02075858872323748, 0.03378232475370169, 0.03968718108691035, 0.059450062352322766, 0.009579092542070055, 0.03712469358898459, 0.07797698715641614, 0.03311816099730711, 0.07407589124575739, 0.013201368837467125, 0.06274905528933292, 0.04573870112278289, 0.09367700921551836, 0.014554465888068082, 0.007579592525989058, 0.050561914085260326, 0.08297774865622483, 0.04433787870971907, 0.05943752915388154, 0.07680799827099809, 0.15232141520227158, 0.033379404640366, 0.03684972931120185, 0.10744947744833847, 0.07293774506017085, 0.05038401314748391, 0.049554470160435286, 0.062925037176859, 0.07309126141931742, 0.03406773847077162, 0.08061553186346447, 0.042607979398340955, 0.05705108483051581, 0.028671319371149428, 0.06339485591818249, 0.06843510158960858, 0.013440510843910519, 0.023126101098774422, 0.05499496229834134, 0.01350292594232146, 0.09912779374468712, 0.11485608444819528, 0.20879570094327773, 0.10632666834299603, 0.04444824133609091, 0.0905377111367641, 0.0531542751817934, 0.08248852490777932, 0.05808708085227878, 0.04770371281812268, 0.06596279030124988, 2.0264654606580734, 47.54253110577984, 96.97231061996953, 102.28847149879702, 84.81888586475004, 97.46934552346507, 89.51346089763027, 66.28924046793293, 68.25281819989605, 52.24422131815265, 47.239951625947036, 47.993352643905155, 32.3500951259367, 46.50628012995566, 50.73287717757687, 45.37182084975704, 23.617873422561154, 6.674976300808692, 0.258188484416854, 0.058463999941464395, 0.1843308822642411, 0.12377281928615225, 0.020029039362505562, 0.06759548454635567, 0.15374718143814994, 0.15077302893323286, 0.1770634964228638, 0.3359505149625963, 1.54084122229007, 0.9840647599870159, 1.6132025781177706, 1.1272720271541228, 1.4370897508436635, 0.6692259734676731, 2.1392464733892873, 0.544779280260686, 0.45944021113457223, 0.8461814361714548, 1.0662400698469532, 1.0466577593357334, 3.2498464661259807, 2.1140798109193004, 3.146722206184941, 1.0283792691846048, 2.0801856296677745, 1.6914537404814076, 5.684314052904806, 4.103956544591535, 2.0854803391041297, 2.1503661476796676, 7.358586095994519, 16.520572093225297, 34.93708064479213, 45.365843157614435, 56.33905810694541, 45.430809374778505, 36.23519297569029, 12.451313080326205, 6.024158010559698, 3.9603803907671287, 3.9164986293162074, 3.5533736886516696, 3.52256273550372, 7.051132580926342, 5.276223305732974, 3.152729316103843, 2.2914435065561727, 0.5948225336690104, 0.561371764108058, 0.41067270862479366, 0.2612414980126966, 0.48062563723614143, 1.0269154283788897, 0.6143343640911965, 0.2587712321790957, 0.416000175980791, 0.03236649467820122, 0.20276445925476091, 0.09133947577567832, 0.09236619447267826, 0.1400382218942527, 0.17555759739010565, 0.06790853105485439, 0.1060068725998844, 9.48835269097359, 30.774086790700114, 49.16959301117928, 44.30268864477835, 48.52781872595511, 41.18534572662846, 60.34187216912547, 72.14446052428215, 31.787899847953554, 38.61467922887495, 49.241945051377826, 68.94928993717318, 74.18168467860069, 69.81021881103516, 86.97575015406456, 98.0423096687563, 66.63576618317636, 6.135900453213723, 0.3358892279286539, 0.25680528202604863, 0.09204970056852026, 0.024932034636637377, 0.0922858624929382, 0.03822524017924744, 0.06726818880246532, 0.012833329664933826, 0.006436989623903027, 0.01180017295654022, 0.06357938734694354, 0.053001793041344614, 0.016898752392960653, 0.06305788065336886, 0.04429423468067281, 0.03414882504711709, 0.06388258962561527, 0.027567898035950722, 0.07286796211114815, 0.08321134418609642, 0.04696778960586075, 0.08492498328128169, 0.0691349229084388, 0.016333036680495547, 0.04888886615874306, 0.022940483740380695, 0.057668409971219886, 0.03309140920699124, 0.049245836318380413, 0.042014448948565035, 0.048810725190466454, 0.06050474708899856, 0.040637674035444375, 0.05899658043598456, 0.04683515680353007, 0.08967298173135327, 0.0245532788516533, 0.06046817788193303, 0.05356404029073254, 0.05599031352528161, 0.11954075807044584, 0.0985853958334173, 0.17305215279902184, 0.33272436549586637, 0.17888839446729232, 0.17980066728928398, 0.20713604806411653, 0.21023776953018483, 0.14690105202457598, 0.27206472691989714, 0.06976944289260334, 0.18675804799122198, 0.07758065156878964, 0.4374759800491795, 0.16551775467251578, 0.13121114232607428, 0.1453898056981064, 0.17427387917714734, 0.13787639838072563, 0.1610214467490873, 0.2067500010373131, 0.15644008774430523, 0.1661148436007, 0.1880716589549857, 0.1868227517773067, 0.34880764602172765, 0.2680547775760774, 0.19662048006730695, 0.22269452771832868, 0.3143547415252655, 0.15255441318356222, 0.1702595478104007, 0.1608057776766439, 0.2569329888830262, 2.6395141453512254, 62.68549226945447, 118.89900315192439, 111.74936171500914, 95.32833545438706, 106.48562723590483, 99.08804493565714, 63.07885500692553, 59.776113417840776, 58.25097430136896, 63.54101219484883, 71.73061909214144, 45.85444888760967, 77.43404342282203, 72.48514190796884, 59.5397396241465, 32.209576214513476, 9.557113801279376, 0.9719137474894525, 0.15291415275104586, 0.3944358121483557, 0.32206109574725555, 0.4262201259693792, 0.33048211807204836, 0.39414552611208736, 0.2383155507906791, 0.2383231963481634, 0.2638380764232528, 1.4297882587678972, 1.7407856352867621, 5.1164529112077535, 7.411531719469256, 3.100897400609909, 1.0760968635159156, 3.610300762999443, 1.4715170067164207, 0.6865673848698217, 1.580995874058816, 1.2258859291192026, 1.8858330456479904, 10.080874754536538, 13.828379781015459, 17.250329063784694, 18.607843729757494, 20.72482143678973, 27.188689401072843, 27.85892636545243, 23.574817565179643, 24.989859673284716, 14.816273816170233, 13.430521026734384, 15.586395898172933, 34.57246495831397, 40.3844448058836, 54.910672095514116, 39.603489137464955, 36.42272149362872, 16.12282708767922, 12.281424441645223, 5.8356086957839235, 4.152338735518917, 3.3416397340836066, 3.1918610872760897, 12.305194985482002, 24.009596609300186, 27.096188145299113, 23.57494111984007, 6.800976559039086, 1.3078677558129834, 0.4887943408421932, 1.0766462404881756, 1.1724690083534488, 1.3151799118326557, 1.152188148229353, 0.38379892646785707, 0.4639933781037408, 0.9425975850993588, 0.7756883542864554, 0.29001248159235526, 0.3360000042425048, 0.29928110359657195, 0.4312431193407505, 0.16861815846735434, 0.4109604206056364, 18.100389049899196, 46.253616732935754, 69.44432443188083, 68.9552519398351, 80.13159859564998, 73.80811029864897, 84.95706312118038, 90.0107232985958, 32.69854868611982, 34.85406368009506, 54.42082297417426, 76.63672754841467, 87.19353583551224, 78.74685287475586, 94.97507110718759, 113.49547539987873, 77.08213621570219, 7.682086517733913, 0.5469701691500602, 0.39583171627694563, 0.189087598794891, 0.19265744594797013, 0.21995079913927665, 0.17643234722556608, 0.16223851531263322, 0.21640246373511132, 0.09696043141546751, 0.14519169536088744, 0.14432053081691265, 0.11913139898810657, 0.14353918242118052, 0.21795510945300903, 0.1647390109757262, 0.12804147652200154, 0.18008664791141787, 0.11019119121614965, 0.16838647815729343, 0.21691370485050065, 0.16163402597510046, 0.2792779043797524, 0.18213640808338122, 0.1771572809065542, 0.1702924589476278, 0.14265223646596556, 0.15911761100494093, 0.09343253523712197, 0.06410597703389584, 0.21874359778819547, 0.11362450617936351, 0.16326564003623303, 0.1878053667925058, 0.19039183284246153, 0.22805455381110792, 0.23279270037047325, 0.12115656773770049, 0.08951183513648088, 0.17440930820040165, 0.25146477585358007], [0.19170355922993154, 0.04005144057314723, 0.05079778489626704, 0.10147382309960742, 0.02792574345104156, 0.06758796156293924, 0.06456363029898175, 0.06793910562391244, 0.16523010397870697, 0.1467614248394966, 0.05407099514418552, 0.11280073949526395, 0.0752826176223255, 0.03738537798785875, 0.03817925192115288, 0.1471780694179958, 0.04075376316905022, 0.06559087759664943, 0.06857783143078128, 0.11543524691895132, 0.1370783339464857, 0.16753080391114758, 0.1173532935940931, 0.22961954886634506, 0.49449786543846136, 0.2830441151895831, 0.3481871148030604, 0.09494057931606809, 0.021683569028673154, 0.19347067892311082, 0.2837689569400203, 0.22925541195417606, 0.012061897319771591, 1.5471459420457965, 48.70445089955484, 100.4353084871846, 80.33058043449157, 69.84700279851114, 72.13740025797199, 53.24372360783239, 33.077088786709695, 28.917019059581143, 14.326198177952921, 25.935878484479844, 43.47530388063, 41.56327001510128, 44.836276115909705, 33.50342296784924, 24.921145631421, 9.29359132243741, 2.196774405817832, 0.15390052159707393, 0.19645644532096004, 0.5051203486659835, 0.04547789031940122, 0.19291860532135735, 0.09946284995925042, 0.0593948733782576, 0.05573590338650731, 0.36768000753175833, 0.5116155178796861, 0.5879824103847627, 0.8342869099109405, 0.8205580627245288, 0.888267181092693, 1.983116528680248, 2.748755341575992, 5.948817614586123, 6.437842057597253, 6.706481758625277, 11.812314852591484, 14.665891124356179, 15.576306581497194, 15.068954863855916, 22.41642398218955, 12.849297350452794, 8.58519656042899, 7.607025590635116, 6.79511457681656, 7.799706632091154, 7.570184238495366, 7.2702209795674975, 6.366855982811221, 34.33933888712237, 78.3023306631273, 93.3290719985962, 104.36177361396052, 102.7243095828641, 122.17836349241196, 117.39333075861778, 107.13625431060792, 54.66627705481745, 24.59768737516096, 23.737260564681023, 23.582415196203417, 24.46556821946175, 19.662612215165172, 14.01486396789551, 10.699624726849219, 12.207296548351167, 6.623791821541325, 2.422843642773167, 2.1579446571488536, 1.5342456342712527, 0.1610606704508105, 0.5049190820465165, 0.4521806700335395, 0.40162983741010394, 0.13125831802045146, 0.18498107640733644, 0.077555516223994, 0.22051474710385646, 0.35807286659556053, 0.08783896724062581, 0.11218328795005238, 0.06522499400401308, 0.14399483619678405, 0.12240532169779464, 0.04456620355467162, 0.4419605055403325, 10.610521224237258, 37.201590461115686, 59.7516417503357, 48.03742047279112, 95.88262911765807, 122.16545889454504, 57.80513417336249, 25.48760256459636, 15.74341327913346, 36.37280148844565, 39.920828496256185, 71.1255072009179, 71.22245250209686, 68.59498223950787, 75.78567520264657, 62.16546443200881, 7.36911177635193, 0.7304210155721634, 0.01442409496033384, 0.039062470858616215, 0.10702340998837065, 0.15361726824795047, 0.10883339996179266, 0.1883475272165191, 0.06837297185894943, 0.03716041243845417, 0.08164808815044743, 0.12773786821672994, 0.20473181900958862, 0.20473672197230403, 0.30788077762530697, 0.23122873187305468, 0.3388512915661258, 0.11392851285035573, 0.12420577387655936, 0.06823968022100388, 0.01658454143081702, 0.01396265339046236, 0.014366109765345051, 0.036352649331092834, 0.1596838878768106, 0.11382158229788465, 0.06310910895286549, 0.1498523138223156, 0.08966710583697404, 0.039698664744895314, 0.08264733493448266, 0.06846173080585657, 0.022912012082674814, 0.0565893521472331, 0.09852639174148922, 0.11171261885113294, 0.07908426765953341, 0.013763092274236825, 0.012768897840062217, 0.21352748897287155, 0.1618743937222227, 0.03474831566094391, 0.07814848359914557, 0.07710815918061041, 0.02829448072119586, 0.019767950852251342, 0.10499346851100845, 0.042231512301030665, 0.11166498350400118, 0.059444611636741515, 0.06615365344670511, 0.0961546601367093, 0.0920632220203838, 0.08040825911467114, 0.07395056692222435, 0.07921395102335561, 0.039845726813279816, 0.022394475639767708, 0.10104046248260046, 0.0836620796772261, 0.11240965160991877, 0.06834416695299649, 0.1836562958816367, 0.1698940472617265, 0.35075326420126424, 0.3136309416544053, 0.3464880850045912, 0.09939890460021074, 0.04479912492716986, 0.1488118744905918, 0.19576672104097184, 0.09516357984994689, 0.09798949434151573, 0.885434065374636, 71.07395941211333, 114.19819155047017, 91.40878154385476, 79.43059259845366, 87.18104700888358, 67.36693520699778, 53.340641452420144, 36.98949613878804, 22.939281809714533, 36.94116469352476, 49.442676267316266, 56.36746783410349, 52.5450788774798, 43.526216245466664, 31.32267732774058, 11.12430170659096, 1.773337017624609, 0.10399057514845364, 0.04168708042632188, 0.40337372931741905, 0.23875871733311685, 0.10817767466388403, 0.22006309230721768, 0.3401916696419639, 0.1973970480743916, 0.9427318649907267, 2.337504634934087, 2.655486526989168, 3.4939897396872124, 2.5049444888868644, 2.195659472096351, 3.9606792263446318, 5.958246992480371, 9.107848463519927, 8.494117163842725, 9.524505176851827, 13.303879460980816, 16.265894559121904, 17.753021986253803, 17.769843070737778, 22.403268352631603, 15.791504479223683, 11.637178082619945, 9.01015006726788, 6.805955517676569, 5.979852387982031, 5.4100482021608665, 6.0204901041523105, 8.369337743328463, 36.8204733633226, 79.04824779879662, 102.72782402653849, 117.76731306506743, 117.21226630672332, 133.4422025372905, 128.67201205222838, 115.7736272196616, 65.00172638124036, 29.562013610716793, 29.9997305100964, 29.200196535356586, 26.0940323721978, 23.840091382303548, 19.16094107012595, 16.37844991299414, 16.021002358005894, 9.255267804668797, 5.555801516579044, 2.862098111260322, 2.399560698578435, 0.9443542553532509, 0.5868069863607807, 0.4880214807006621, 0.3873976091704061, 0.38158254217236276, 0.6305970011218902, 0.668324257337278, 0.2062458845396196, 0.08070592257765033, 0.21280773404625156, 0.06731618421092149, 0.0887877518130887, 0.11462747615071074, 0.09256910052030318, 0.03836519678213424, 0.4049928714671443, 12.184409518395702, 37.519184773968114, 53.24342550769929, 42.92036302628056, 93.61580510293284, 126.84825112742763, 41.290096544450336, 28.137708825449792, 25.62490709366337, 52.856138521625155, 55.54479775890228, 76.99885645220357, 83.92555036852437, 79.32421007464009, 86.35148925165977, 89.2418759868991, 16.68415650244682, 0.9613878219839066, 0.09362738203978346, 0.0601483476648648, 0.04248517933451841, 0.11995043890971331, 0.02123631157671973, 0.0804287596275249, 0.09054099765395926, 0.050276688059731844, 0.02050452140880929, 0.13084421685386088, 0.0652005328165908, 0.15944765700447946, 0.21062263678158485, 0.27705284796895524, 0.14654817660489391, 0.07234450189336654, 0.03367224941030145, 0.07266550805539855, 0.01564350583770823, 0.03190338686709443, 0.015318921087459933, 0.06075539956650427, 0.13655382418824782, 0.046594911630475716, 0.07076418507964381, 0.07199801564697297, 0.0475908374233592, 0.047417881583134015, 0.059896465616240624, 0.06175924670852481, 0.0369746974038501, 0.039131395789163734, 0.13154598403601878, 0.0881604713598086, 0.03558819317409108, 0.04454454241861259, 0.04002864562696026, 0.0787425158365119, 0.29949876449761853, 0.2237667596989101, 0.14165462144920904, 0.1933149485698631, 0.09568084241642107, 0.13312403322948566, 0.17516140735918478, 0.19499363107306344, 0.22792845573877135, 0.30760170711625007, 0.16565471587161865, 0.23706857415456928, 0.18550662804515133, 0.2655524586237246, 0.1951382531514091, 0.28754077551345675, 0.15740532788538164, 0.18426578011243575, 0.24564019404351714, 0.2358867303137818, 0.17625832269268651, 0.34798459179939767, 0.3273811780156628, 0.34985421405684564, 0.7180741297141199, 0.42450421159305884, 0.4335399428682943, 0.15963976121237203, 0.22667430851969028, 0.2061669928051772, 0.41700755095770287, 0.34018400876272115, 0.3057640154034861, 3.049168937629269, 92.64155895479264, 127.86987166250907, 101.25077709074944, 91.41800695850004, 97.65099048614503, 72.60646081739857, 51.32190735109391, 40.58705875950475, 23.93125314866343, 43.15829007856308, 60.98841605647918, 62.004043209937315, 66.88058483985164, 53.538603475016934, 41.11354281825405, 15.77179947207051, 3.472415723146931, 0.37084211204801837, 0.40018383113126604, 0.9676695591019047, 0.6523760840777428, 0.46792650415051373, 0.21147386771776985, 0.4690489148901355, 0.18153361946104035, 0.703166916726097, 1.7707363636262956, 2.9623136885704535, 3.121825206664301, 2.6277002115403456, 2.400211321730768, 5.164699044919783, 5.1066572819986655, 11.922632494280416, 10.430558958361226, 11.798359059518384, 14.745563287888805, 17.12163805961609, 18.038978461296328, 22.994961815495646, 32.87540443481938, 18.640595520696333, 15.183679288433446, 12.850199495592426, 13.942881611085708, 16.20037038480082, 19.032818809632335, 18.35270139478868, 12.440074509189976, 41.54385428274832, 79.75104239679153, 93.08147630383893, 108.47117808557327, 109.31359337222193, 124.09784593889792, 120.1008487516834, 106.75769067579701, 64.60173091580792, 33.42458724975586, 31.58269713001867, 30.982313656037856, 28.767770913339433, 24.949437687473914, 18.563056145944905, 15.218345196016374, 18.568702397807954, 12.619006172303232, 6.367329118713257, 4.887732152015933, 3.2018275847358093, 1.6926995833073895, 2.433147709215841, 1.1580582203403598, 0.42734367051912897, 0.3705940221346194, 0.767669436191359, 1.0020973052709334, 0.5047836683450208, 0.5213635270634006, 0.2645260233792567, 0.4419723645814004, 0.201716696122481, 0.40303560875115857, 0.36648190730521757, 0.16302902611993975, 1.0664743088906812, 19.15276881187193, 55.16323743327972, 77.3429189189788, 66.17218125251033, 106.66840968593475, 121.33285737806752, 74.74067734133813, 39.11930391865392, 27.76087299469979, 54.3863453403596, 55.64391213078653, 88.88294773717081, 94.79597568511964, 89.52233329896005, 98.18422886633105, 101.93289295319589, 20.663675608173495, 1.1799843921776743, 0.21318452673092966, 0.26378181492609365, 0.18443870147870434, 0.4406964298217528, 0.30078098117824525, 0.26494970064490075, 0.33308019801493616, 0.17523415506847445, 0.2595489033527913, 0.2567634842688999, 0.2098049758182418, 0.26415732058305896, 0.40307513888805147, 0.4420061030935857, 0.44412099606087135, 0.2753130316493973, 0.25423989871576913, 0.16844062525178158, 0.21528743808307957, 0.1678618151814707, 0.10097803397765083, 0.1193291875683973, 0.2259569897526695, 0.22965258257764004, 0.13071117802493035, 0.27794301149345213, 0.24376306412441118, 0.08053689293803708, 0.11695933287903187, 0.16194821395460637, 0.16240578295002062, 0.12027293128231842, 0.29917342227793514, 0.16941985415835537, 0.24267426932290678, 0.1570805525707622, 0.16245334168835995, 0.2779196304900031], [0.05956594081174943, 0.018898310823245876, 0.008321837878846114, 0.06394944994920684, 0.05277021615315349, 0.02368518248981526, 0.1995732127538612, 0.03758280267638545, 0.19736651180972978, 0.02060523324255501, 0.1467610111520175, 0.07652675973311548, 0.05615213044708776, 0.008880449083423423, 0.100352339326374, 0.07063888373874849, 0.05425266906498902, 0.0456180575964672, 0.08374049643715543, 0.13903026469051838, 0.02094447038196508, 0.0452828060294832, 0.05656675638390645, 0.30485457710681424, 0.43494583678341686, 0.30791926588262286, 0.22348586590059344, 0.22235306700871837, 0.1496095558808696, 0.21974268369376662, 0.18862333419101854, 0.06925417981561154, 3.9607647830440156, 50.72601302977532, 70.74090311604162, 73.51421494637766, 78.18068227460309, 70.1823889824652, 32.748335330717026, 25.073831735118745, 20.7885266119434, 29.822504097415557, 67.75577545166016, 60.10842446357974, 41.93600108546596, 48.23446466076759, 35.36070839051278, 16.992645032944218, 6.430987715721131, 0.40418247301732346, 0.09583819687606827, 0.0587786705563626, 0.08179505445784138, 0.07787480634907562, 0.16964004314955206, 0.123781613975523, 0.1614161505694351, 0.05502645234246889, 0.14358317118979272, 0.9566146039193677, 2.5011643046332948, 1.5793493366049183, 2.68983815466204, 1.2040423722036424, 4.7380726472024, 10.65113442559396, 22.94029574240408, 32.360860070874615, 39.6552683461097, 41.39194480834469, 48.51977786710186, 54.20229204239384, 58.13885727236348, 52.95935569270965, 54.433237275769635, 55.455038239878995, 56.087453749872026, 37.820030566184755, 37.135251414391306, 25.53437879008632, 33.42959219409574, 31.860328374370454, 44.98825227060626, 79.83562438718735, 92.38155288081016, 80.64844146851571, 64.8573164786062, 66.12778002215971, 69.48275581482919, 73.15748322394587, 71.21762014204457, 55.611689859820956, 47.267161107832386, 58.7995687607796, 66.05116044321369, 61.64285567498977, 61.043427298145915, 62.79764067742133, 59.127274943936264, 54.50755442342451, 44.546287444330034, 33.95625275950278, 31.70307270942196, 26.56768014354091, 14.717912539359062, 5.141730135486973, 2.343547291332676, 0.5658363406696628, 0.901427039455983, 0.5946105418186034, 0.2270522503362548, 0.0805960655693085, 0.18347044295120626, 0.3623218660152728, 0.27329193848756056, 0.1642673612842637, 0.06483166148104975, 0.05123583014093099, 0.09366788510834018, 0.12068506360294358, 0.12461612121232095, 1.9342097207423181, 23.7923365254556, 41.20979778228268, 32.68880944098196, 30.429996867333692, 62.466467119032345, 42.57270374605733, 24.752216992839692, 13.795138674397624, 18.681341102046353, 44.41734344728532, 54.669940548558394, 60.23036702986687, 60.75068512270528, 74.73622937356272, 64.31850048803514, 11.571940241321442, 0.4687920302873658, 0.11646071689263468, 0.2356008569439573, 0.03644623463192294, 0.1680678468678267, 0.07683700235981135, 0.05718992294503316, 0.07700466836291937, 0.2479477734455178, 0.21659544128323757, 0.13785995813387056, 0.1270274442410277, 0.34096413141777443, 0.2791687521723009, 0.1740945533158318, 0.05264182364748371, 0.07258108516614284, 0.12160852130862976, 0.023970705374414404, 0.016119152592915683, 0.07759563624858856, 0.058779352374615214, 0.06055539699211236, 0.012728324865982419, 0.045205733753860965, 0.06484517527203407, 0.04737344082264651, 0.09847349337031765, 0.042159657084172776, 0.09199266532255758, 0.018427781535372622, 0.11722650604262469, 0.20285948480088867, 0.10130981133589823, 0.056955162961516655, 0.022573269069975904, 0.03370736688075047, 0.05317020598017881, 0.09135804574696288, 0.04587642457937041, 0.018659065394932707, 0.023377395174916715, 0.07265523481633394, 0.023520737886428836, 0.06851200149544785, 0.05329799327638842, 0.1302844057640722, 0.05303811326983476, 0.16942005334121568, 0.13725827267814067, 0.024956499654499274, 0.06851300507062866, 0.03801111477397142, 0.06745300751419799, 0.039515650170224334, 0.05486997505349498, 0.020314382216442498, 0.04984802739214032, 0.08190595334576023, 0.08501765693748191, 0.053228447814622236, 0.2896084468210897, 0.38137061160898983, 0.43445811456730293, 0.3246771021475715, 0.08210319800362473, 0.120281373571244, 0.20969358663405144, 0.13744349741647321, 0.14971843229666834, 8.091048031084, 75.46667668127245, 88.0409089980587, 84.75110730817242, 89.83606799956291, 84.09621269472184, 50.37548257458595, 45.39274277225618, 29.684277811358054, 34.08455348783924, 43.730167727316584, 55.681398222523356, 53.140463290675996, 58.36224017604705, 44.05868191872874, 20.783052944367935, 7.029349207878114, 0.5680582407982119, 0.038779075783226764, 0.10615062133799638, 0.18819619420795672, 0.03844401956866345, 0.29464719096018427, 0.21745520643889907, 0.38391782331370544, 0.9027763960822937, 1.5964997776093024, 2.29053498756501, 6.426285774477067, 4.34574737664192, 5.100700182299461, 3.1298655752212774, 6.730010586400186, 11.252998594314823, 26.965457508640906, 35.111100519857104, 42.79065024468207, 43.19912195205689, 50.293865896040394, 57.41824726904593, 58.80518559486636, 60.12403157449538, 60.59204093871578, 59.28183594057637, 59.26872737946049, 42.98353279790571, 41.99366384936918, 31.23157047456311, 38.079946425653276, 35.45124846120035, 51.44586993801979, 90.1783497102799, 107.44533708018642, 97.77491384936918, 79.04720444833079, 79.86933323644823, 79.87971182792418, 85.92657889089277, 83.99421538076093, 66.9718897727228, 56.145861764107984, 66.6755154825026, 72.87193467540126, 69.11733212009554, 64.83877935717183, 65.42515016371205, 63.06925696711387, 60.874894818952015, 49.040578411471465, 39.77409655048002, 36.54010626577562, 29.910345577424575, 18.29770584260264, 6.6956594490235855, 2.704994683304141, 0.13114748041956656, 0.8182241911849668, 0.29839032720173564, 0.16662807654469244, 0.7034403794715482, 0.7238830373652521, 1.1659445132940047, 1.4884306346216511, 0.30847323938242854, 0.28336908968706287, 0.20512892834601865, 0.09659117703596432, 0.07207840891374696, 0.11481386534268818, 1.479577599994598, 23.339744037197484, 42.734521127516224, 43.91582135231265, 39.55078424945955, 46.8657692786186, 41.61704571016374, 30.274463122890843, 26.95640075591303, 34.767657787569114, 67.36800209168466, 70.43351481037756, 75.50710062826835, 76.00203314135152, 83.58890118137484, 86.44976815869732, 25.545028025104155, 0.284578466727849, 0.15223389731780176, 0.24667553122966523, 0.09770539063479632, 0.09520141693252711, 0.09519865135512046, 0.0979673314178663, 0.14374092401516053, 0.13984139858474656, 0.05695886316619093, 0.089273214069826, 0.10553493179501065, 0.1891061074791416, 0.2305089616246762, 0.1195410032185816, 0.06250455449785917, 0.0986740934932905, 0.0029629906038603476, 0.05311591715942468, 0.04472479524631654, 0.020378049868609638, 0.011395914104556846, 0.03980829958773909, 0.04228533763859061, 0.0028027386560420236, 0.021667245610226548, 0.05827499838966516, 0.06871332940194877, 0.049266762010032134, 0.031282773293975386, 0.047986364788225586, 0.14280713944425508, 0.08731321641995061, 0.05762671563594092, 0.05622400864658337, 0.033773001463663195, 0.024097690193523324, 0.03663847290520226, 0.19862291132730825, 0.12237111587197551, 0.11940858492086973, 0.17218958376155746, 0.15648203871903882, 0.1196528597164058, 0.2781313159052403, 0.19244510169711807, 0.271213143583267, 0.16964856204727005, 0.21627230539677605, 0.2250379293916687, 0.11297443461033607, 0.19934756921664362, 0.1755629906490926, 0.24884254881931892, 0.17713042186392894, 0.2645338681196013, 0.2889233190686472, 0.17653042180163248, 0.16584645235730758, 0.3289459585662811, 0.21822990519144844, 0.55343754469387, 0.742915909617178, 0.7693219184875489, 0.48050358410804506, 0.5101495626713, 0.27649577947393544, 0.4861887225941305, 0.30001906077227286, 0.4365844988534528, 12.160286941835958, 103.62746669400124, 101.49976914928806, 96.53690399662142, 101.97762366264098, 91.28801961098948, 50.31537617406538, 40.7908494241776, 32.913706379552046, 46.43400653716057, 91.15168586854013, 79.24459380488243, 60.582286004097234, 66.62059445534983, 52.21010454239384, 29.578450302923883, 11.166842752887357, 1.2465380660949217, 0.15713283041071507, 0.2654027343998032, 0.32761857334163885, 0.26800583987947435, 0.4059502668678761, 0.3469421912825877, 0.3073712678686265, 0.5944941577411468, 1.4597225621823342, 3.0642438319421585, 5.87397143725426, 7.419987368968226, 7.927969607614703, 2.1788538319449273, 7.272388579383974, 13.032722088598437, 32.72312233524938, 41.62748705956244, 46.07432126998902, 45.382015089834894, 57.48126406823435, 62.646496065201305, 66.14589352761546, 61.84884286695912, 67.97982123590285, 61.0199244560734, 59.82443701836371, 47.84609117815572, 43.66351881334859, 32.839822653801214, 41.336133403162805, 38.32269407087757, 55.067594358997965, 94.99018007709135, 111.43350108977288, 101.31924598447739, 83.18721125202795, 86.63089536851453, 89.11309672940163, 92.98648434300577, 86.8701050358434, 70.92075163318266, 64.55275620183637, 71.1978513963761, 78.18979786288354, 74.35964261331867, 67.18939304351807, 69.69833712424003, 66.32469084955031, 63.80087706350512, 50.12265051564863, 40.88555505198818, 38.024821435251546, 33.32733600370346, 19.045631231800204, 7.763066301422735, 6.167564767022287, 2.6399402128111933, 2.6310180464098534, 1.6999638128665187, 0.3922544227492425, 0.6409610675707941, 0.43631685837622614, 0.8741992327474779, 1.2285847649458916, 0.4143339653889979, 0.2653390265280201, 0.31118859206476523, 0.25741311150693125, 0.16655335232855814, 0.2576513342078655, 3.4094555531778648, 35.21907944833079, 55.720692526909616, 51.09207214847688, 43.61848215903006, 87.54095585115495, 60.53829662261471, 39.265463198384936, 24.14038412032589, 32.06503099010837, 64.95323411880001, 74.48465639545073, 87.28814340406849, 89.02958946843302, 93.82525967013453, 101.02021232728036, 29.99377439098974, 0.7252349680469883, 0.31913332220527435, 0.4424731102922271, 0.2581618245570891, 0.36466615635060495, 0.23697789998785143, 0.2509050873378592, 0.23938117909335324, 0.3401696982402956, 0.2658723156538702, 0.21523106933361102, 0.3382037021219731, 0.6044523201642499, 0.4813297946126231, 0.4023514922347761, 0.15047327405022037, 0.21563712657699663, 0.2584858797490597, 0.14582235426191362, 0.1619971669729679, 0.15276180850642343, 0.11705838038676208, 0.2338551570691409, 0.1312793701166107, 0.10915533309021305, 0.16857161096507506, 0.2817240844090139, 0.2683672801621499, 0.2722028678944034, 0.2665593433043649, 0.19735629219681988, 0.21254056854353798, 0.26354981285910456, 0.15639387732071264, 0.08394247551839198, 0.1293924955591079, 0.1632918708867604, 0.17264070229664927], [0.10373660934067543, 0.06240500520253855, 0.007484521493390804, 0.029329256747939417, 0.05716401768187362, 0.032985597142889615, 0.030463204771700888, 0.09475943782637197, 0.04569594958616842, 0.059138375649889635, 0.08060673717409372, 0.07487485200286874, 0.11381140098937097, 0.012919018514484409, 0.07490807723614477, 0.09813841417311661, 0.03395493968480057, 0.04206886417382667, 0.026967338729469527, 0.0670254998089325, 0.15180586867274778, 0.05650526250622446, 0.07984058796277932, 0.1293067703203809, 0.25319657889345004, 0.13922995316886133, 0.1697434803410884, 0.15221100661062426, 0.19510581698869506, 0.24489883543743243, 0.03726564610617296, 1.4023547114864474, 72.93379045301869, 80.31041160706552, 81.79821368186705, 73.1057785403344, 78.80150718073692, 33.39739345735119, 26.056964012884325, 18.37272313333327, 28.262775559579175, 50.86738309552593, 61.04074439694805, 51.699415868328465, 42.83572220033215, 36.03056292380057, 10.430400102369248, 2.9756899514505943, 0.037400381819855784, 0.0625528103762096, 0.17064078380503964, 0.09946520184917797, 0.0447507388138723, 0.21757485405091317, 0.10182220924405322, 0.1413396060947449, 0.4295021998545816, 0.28796672039935667, 2.5366139508062795, 1.7452909677259385, 5.41576603727956, 5.8480264294532045, 5.402347608920067, 10.454820779062088, 20.185566140759377, 32.98565833799301, 50.695069451485914, 58.625717547632036, 62.74279809767201, 66.37842732091104, 72.50850354471515, 80.9917429954775, 79.75431365351524, 80.14303622707244, 87.52090469483407, 76.42157769972279, 75.66527412783715, 83.31917547410535, 76.87740418218797, 73.62995624542236, 63.36843575200727, 68.36768088802215, 58.58593686934441, 56.18677992974558, 49.69153104289886, 58.11320497143654, 55.54478991416193, 63.471209695262296, 63.82488196895969, 72.52314967493858, 46.612282183862504, 29.370682354896303, 58.797795849461714, 70.69472112963277, 76.83634481122418, 82.398053907579, 82.28352069854736, 85.65195022090789, 85.81308118758663, 85.79870962327527, 89.57436746166599, 87.41010558220648, 77.51071791495048, 75.57312980774911, 66.34420856352776, 48.02308813218148, 26.70478463172913, 15.608185645072693, 4.343017407001988, 1.0599484655164904, 0.5821892535013538, 0.5179242825796527, 0.05869723157957197, 0.30251040934554996, 0.11148976387395976, 0.2812663315524978, 0.12240915213741603, 0.2538081315616446, 0.0539665428861495, 0.034261179502092065, 0.10061981126425729, 0.16498981284037714, 0.6167289710813953, 8.109247338387275, 26.935153276689594, 54.823673925092145, 49.7538378930861, 43.483030949869466, 41.17924644101051, 36.80014764108966, 31.763341888304684, 9.780815397539447, 26.8070133655302, 47.12481829427904, 59.78486030332504, 61.81442799106721, 64.20844662574031, 66.10157858940863, 19.26861797609637, 0.7320582986839357, 0.08589357122658722, 0.08617202120442545, 0.021145183502906756, 0.017410353569674398, 0.05605440827146654, 0.03133068251754007, 0.10999449048071139, 0.05603564677820091, 0.04195691191501195, 0.057102523804191625, 0.19114638348260235, 0.04406590983572026, 0.0565552918781196, 0.1038271302898084, 0.10581443897418438, 0.05622276375370641, 0.053527413627072695, 0.01955612179552836, 0.01909855280011412, 0.11294955207455544, 0.07762139978548212, 0.042240774304035215, 0.08629437310681229, 0.12761070528217863, 0.03511686140911714, 0.05891381612708492, 0.12059084244913633, 0.16479763202369213, 0.11258213630607052, 0.030025739838639577, 0.019433503677587838, 0.03715222678898323, 0.017917321829666055, 0.02766420486413183, 0.023936064793698253, 0.05148884983012273, 0.06397270071770876, 0.03136776691873468, 0.08146539150226502, 0.04408090983727767, 0.01197854408078016, 0.06151336695878737, 0.029483144659729257, 0.04110131810809817, 0.07023392200109459, 0.062629304255449, 0.06898539786737773, 0.07677058253677622, 0.05231188106981497, 0.04055921514067919, 0.05678177428161425, 0.023059935999974128, 0.06687387568695892, 0.06344390086709492, 0.022869651250901724, 0.06291826879004798, 0.03340151010742111, 0.020988009073921753, 0.06878369457779393, 0.07865836107802969, 0.14261981562501, 0.027159452513461153, 0.09898390711074877, 0.21316217228529916, 0.20555036863492382, 0.13769630643148578, 0.08074667845522204, 5.372691548639729, 95.11841804750505, 93.49768684756373, 90.28917235712852, 82.70990587049916, 85.17585292939218, 54.10521730299919, 42.22462477222566, 19.50117530361299, 22.07514443705159, 35.06020384450113, 60.024603412997344, 59.20983299132317, 44.20952058607533, 34.46545877764302, 13.912374396477977, 3.512062305404294, 0.11773016288756363, 0.15807236064105265, 0.23454367093020873, 0.13096823116704343, 0.01569227691018774, 0.26713740260851, 0.8804965980591313, 0.8454225188301456, 0.8572504260847646, 1.0631085475606303, 3.4831250194580328, 2.966607213020325, 2.2174688308469714, 1.4620368831580686, 2.3058761127533454, 7.183323319881194, 17.988185728749922, 31.77676227784926, 50.0584726948892, 61.67023774116271, 66.0184164970152, 71.96885601166757, 78.56241518451323, 83.3727393611785, 86.42332353899556, 84.80019969324913, 94.15513884636664, 80.92602760561051, 78.91027450561523, 86.39846355684342, 78.86242943425333, 78.34177401758011, 67.15644513407062, 71.14922185097971, 63.46019960218861, 66.76484354080694, 60.62547522206461, 64.86763623452956, 61.69981241226197, 69.76611568081763, 70.54109757946384, 78.59818720048474, 56.093839368512555, 35.95598689971432, 65.89946669916954, 72.26670511307256, 79.83615782953079, 86.34642939413749, 80.98686356698313, 85.96230383842223, 91.09397995856501, 88.8388132279919, 94.42500575896233, 89.84118277026762, 82.4776231088946, 80.4565748091667, 71.96076023963191, 53.10691918096235, 31.666945718949844, 16.49317825994184, 6.6828014293024625, 1.4119060505782406, 0.6316522412723111, 1.074164851057914, 2.4841245480122107, 2.583019022018679, 1.4543737975820419, 1.7237152351487068, 0.9582740729374271, 0.6532018655730832, 0.2636177188927128, 0.25212033261214534, 0.08853197803780918, 0.13937842100858688, 0.5435277377405475, 8.105371056064483, 27.60113839180239, 42.32637105449554, 44.0535593032837, 37.34753401048722, 36.341579421874016, 36.29028266476047, 39.32605597280687, 22.313755942929177, 45.399732435903246, 63.73154524833926, 66.66608610460835, 74.81852854451826, 70.88161422360328, 86.78601726408928, 39.62190466542398, 1.225355183405261, 0.08080855537686618, 0.02869840440971236, 0.124678626326063, 0.09181613568216564, 0.04389156354591251, 0.0643527722587028, 0.039096102118492126, 0.010868797732156613, 0.01590262933243667, 0.06376601402617751, 0.16755989993051176, 0.04381204744981181, 0.05532497765436288, 0.12090650131745685, 0.04915706971059403, 0.06221069466142405, 0.02960634691971204, 0.04862657297522791, 0.02491652518661032, 0.04277863314435367, 0.032321295490668665, 0.03569632648460327, 0.06514011912288205, 0.08864538969411966, 0.04066756295581018, 0.0249347408422299, 0.11601437874619039, 0.12666618015857475, 0.09908486983828968, 0.07075176679439123, 0.010116725386450849, 0.03835183237829516, 0.07861551378042468, 0.09470307673778265, 0.030080451922971877, 0.08373564710059474, 0.32963736823970274, 0.1509777123048421, 0.13813797144159196, 0.13999905947956348, 0.11805905975521573, 0.13580978427442814, 0.10279237533048277, 0.12824720943406706, 0.11633904680850045, 0.1585488673299551, 0.11692658262026888, 0.15462510287761688, 0.24225384027006167, 0.14299823241608758, 0.2235972857283008, 0.22960286347135422, 0.21597039014581712, 0.17025554883143595, 0.16322486883690282, 0.14636489772988906, 0.25494267713398705, 0.17553170361826498, 0.1780653862102378, 0.21467366375990454, 0.3276720156352366, 0.43646753254917364, 0.3218654675349113, 0.268438495695591, 0.40164102229379844, 0.291074279455408, 0.2459378192021001, 11.078773775408346, 119.13557698649745, 102.0616251422513, 103.99682060364755, 94.89397218150478, 96.73359517128237, 51.25557614910988, 42.945513263825454, 31.55541704547021, 45.56724509885235, 69.4414532569147, 78.05654710338962, 70.00102643043765, 59.99335781220467, 52.95535879750406, 19.282101123563706, 5.77448885287008, 0.1832606267905043, 0.2565267018132633, 0.27839426792437033, 0.17005454268186324, 0.16409287709862957, 0.37779270521094727, 0.7760696822116453, 0.733168329442701, 1.3307772168228704, 3.1372631653662655, 7.2944769167131, 11.615934525766681, 16.78844448058836, 14.798303477225767, 16.096972784688397, 21.37362657054778, 27.541789008725075, 40.61668442141625, 61.194042390392674, 67.9559418462938, 70.46777279146256, 76.32842140813028, 83.54628070708245, 87.86226072619039, 90.55391665427916, 90.3678237238238, 98.07687359471475, 88.02889085585072, 85.6081844145252, 88.1319393650178, 82.69138443854548, 86.3670845954649, 73.82652190423781, 76.04641868222144, 69.13750094752159, 73.88698916281425, 68.40277825632404, 73.92644820674774, 70.50905965989637, 80.20766119803153, 80.0057924947431, 88.4915893308578, 62.30930951333816, 43.015915886048354, 71.66018901332733, 76.64075974495181, 85.1169938425864, 86.36091078481367, 83.29093440886467, 87.5142994234639, 97.21005332085394, 97.71337186136554, 102.3223372428648, 95.80407188784693, 88.06562777488463, 85.53367507073187, 76.63893192045151, 56.59793846068844, 32.57437821357481, 21.2421840237033, 10.2780895656155, 2.78661038125715, 2.68594618285856, 1.5282176867608102, 1.933591211995771, 2.556585188834898, 0.7675423268829623, 1.5596362395632652, 1.2345439484042506, 0.4970168851075634, 0.2337730477654165, 0.24975839161103774, 0.2771422657514772, 0.3427219661253114, 0.9357972983871737, 13.588919081995565, 40.29989811681932, 78.33778888948503, 69.30344074003159, 59.89248621848322, 58.10756460312874, 53.27172540849256, 45.06132994928668, 17.644762608312792, 43.96416848705661, 63.623742826523326, 81.85889274843278, 86.77719977594192, 81.98928802244126, 99.18611987944573, 46.71098078450849, 1.5447943585534252, 0.16233720275903904, 0.27239874125488345, 0.2518067881464958, 0.2624620599371772, 0.17571636145153355, 0.30481143103491876, 0.18256842038564144, 0.11455629892166584, 0.12044045172872082, 0.3048349346124357, 0.39872887694547254, 0.18791741481231106, 0.21926377148878193, 0.19139390649093738, 0.29598049038360197, 0.17581219905086104, 0.1460166035159942, 0.19346478004609385, 0.06093425045330679, 0.15528902531631533, 0.13053260292978058, 0.16788230037256596, 0.15161584822400925, 0.2720804776876204, 0.12935390004948263, 0.15284109860658646, 0.2717928269938115, 0.251243882061493, 0.25719238625418755, 0.20286823352498395, 0.0754904036500281, 0.18753142907254158, 0.19914792670357614, 0.17127937937696136, 0.16249495558440685, 0.2158794708309635], [0.054129803883692915, 0.08749627312945743, 0.031040963386335683, 0.09090066061265047, 0.04205239711389427, 0.04113102316736214, 0.02042099867286461, 0.03155578979321065, 0.07568017128975162, 0.03658116569802646, 0.013345906646141123, 0.08950535403264147, 0.12933943630947223, 0.10184824857259951, 0.1097416738048196, 0.0806864103182189, 0.019311100064266114, 0.03541541353408848, 0.03297656879670197, 0.03703710292616198, 0.19249581671770544, 0.017652569503913966, 0.05770489107817412, 0.17840552924861833, 0.17407187711327307, 0.11975412887911643, 0.011021463733707226, 0.06912638868896231, 0.10230790898804704, 0.027240851270635764, 5.560919229061374, 72.41535509786299, 84.672816799533, 91.03757627548711, 77.95247877797773, 77.49404784171813, 46.06566459901872, 25.582916159783643, 31.558786361448227, 68.10801213787448, 71.45913616303476, 80.10888807235226, 57.126175818904755, 47.17364395818403, 33.79887942344912, 8.474929909552298, 0.6696012952635366, 0.03052703713277175, 0.04759233895569079, 0.08035598127471824, 0.04927488637246913, 0.10996118863864292, 0.14773274771869183, 0.5042378153772124, 0.04200596835524325, 1.0063859880451234, 0.9362320073189275, 1.966314075454589, 4.1568921169927044, 1.3086139867382667, 5.815055966377259, 8.565286609434313, 16.326275525554536, 27.43719312452501, 42.7083706855774, 53.944329523271136, 71.27327073004939, 73.13157204658755, 77.79701955856817, 77.14124633419898, 83.6819633360832, 82.02953938514956, 84.36723278414819, 82.50881379650485, 78.35619265033354, 80.69103840858706, 85.22404316932925, 86.1513856149489, 87.61075050600114, 78.32650815286945, 78.97119675913166, 78.1439688897902, 63.455908529220096, 38.93950639232513, 59.2308255164854, 54.357359024786184, 54.675518158943426, 56.28607473065777, 68.14479612535047, 59.185290721154985, 33.926987955647135, 40.08187709316131, 64.77981828874158, 72.77346749459544, 76.5701727713308, 78.52722367932721, 84.31129978549096, 90.26302583755987, 78.9729461362285, 74.75100886437201, 75.1505885585662, 84.54874438624229, 86.185714198697, 82.05216361630349, 82.42214510517736, 81.87798684643161, 71.2500189196679, 56.23498978153352, 39.97694192394134, 17.97469473654224, 7.214115886918961, 1.5386964212502203, 4.4391355783708635, 3.387182129006232, 2.90163315111591, 0.6086223512407273, 0.81981158665111, 0.37074399150667653, 0.3232895636991147, 0.08766842840780174, 0.04469905852250034, 0.11144252689254862, 0.06735196817786464, 0.06512247611798587, 2.4304049918728494, 16.972254591603434, 44.9671773756704, 58.643917345231586, 53.681365982178725, 39.35017070462627, 36.54604865658668, 32.0919325659352, 18.335144865897394, 19.111456448032012, 46.53219130731399, 56.77173868302376, 63.22191953659058, 70.30046016939225, 87.07730031782582, 32.24150038534595, 0.7667736036162224, 0.026883852382701252, 0.17453162179839227, 0.03819444727513098, 0.062148469169774366, 0.09880114151465316, 0.06684489458078338, 0.053272819627196565, 0.030218525864784757, 0.09841648876787194, 0.06842526502066082, 0.09409369975929299, 0.03061983144782003, 0.11822476457323759, 0.06698243034582946, 0.05625521523817893, 0.06393250025388214, 0.02019424047771721, 0.061897575374572515, 0.07145572498801255, 0.013707201372111037, 0.040000790670033426, 0.025031551373221224, 0.03481945075515298, 0.046638521185565385, 0.03680799667152666, 0.2032803428629714, 0.07213653200456212, 0.12698890235755714, 0.15408168606940778, 0.09361429725803676, 0.04741769772203219, 0.014988751556243629, 0.013152525944244719, 0.06877158272771106, 0.043943952468614426, 0.041961933621355606, 0.03924732021386585, 0.058748965497098626, 0.031199195016656193, 0.015929703837290646, 0.046413157270440174, 0.04314260151717932, 0.035899967976635506, 0.048073855859618035, 0.0391543171398582, 0.06842698871849046, 0.09614621784778372, 0.04378476705882819, 0.20563529714220957, 0.027866756596091776, 0.02494586252367064, 0.04523244723978062, 0.018628575095546343, 0.022331627701679548, 0.0249974527997115, 0.14140746616307767, 0.10728391052614297, 0.0804352560531228, 0.16342314771346508, 0.011361553145933056, 0.06948497912455952, 0.07514344242912147, 0.018369459261697148, 0.06602597723324453, 0.06506883464152775, 9.760337683462328, 91.57527046818888, 97.25436041432043, 99.79334200582197, 91.0578941529797, 88.93305209375198, 79.21042996068155, 41.55587242495629, 40.186714203126975, 57.249228415950654, 67.49112529139366, 89.61678397270941, 60.009396383839274, 46.25218114545269, 31.20987584514003, 10.022587353183377, 0.6749142069489725, 0.06833547951593515, 0.08105813150083827, 0.15707779465423477, 0.0744988943540281, 0.299709101598109, 0.9299761946162871, 2.547175667939648, 1.4783682842408459, 2.127910823591294, 0.5394902705184875, 0.3936088355558534, 0.6443002916151478, 0.9700523989815867, 3.460100216250266, 6.152636226146452, 12.678989018163374, 24.076635799100323, 40.70114089596657, 57.811645307848536, 72.57126146747221, 75.82980186708512, 80.24755170268398, 81.03248073208718, 85.44961867793914, 84.26262317165252, 84.3340495324904, 84.87314008897351, 81.8882477668024, 86.9876584699077, 87.3277436533282, 87.12327049624535, 88.99544915845318, 81.87547652952134, 82.84489031760924, 79.41582879712506, 65.38527927091046, 46.96187911495086, 66.97440008963308, 63.006200944223714, 62.18311902015441, 64.55954974697482, 75.45061065304664, 66.8860290896508, 41.11016565753568, 46.052728622190415, 67.17408011036535, 74.11007788873489, 77.88958749463482, 78.90104124622961, 86.42762245670443, 92.81404910549041, 82.87421395701747, 79.09284514765586, 76.89984798431396, 87.82776740289505, 91.66824633075346, 86.63997173309328, 87.61100153769218, 88.9975280146445, 79.01220121691304, 64.3573554869621, 45.55098295211793, 22.251572647402366, 8.697758778449028, 1.6899037913930033, 1.9801248634053816, 5.784762030647648, 5.793120111188581, 3.067959051939749, 4.413321479674309, 1.3903522587591604, 1.2674268935957265, 0.46904486994589534, 0.22038288805032932, 0.07396694588204546, 0.06342329693237139, 0.03179962791862988, 2.641712388684673, 19.97233433108176, 41.30020057001422, 52.001901211277136, 38.63843702500866, 24.27939880278803, 25.661234125014275, 22.364538869550152, 34.70095788278888, 36.89906981683547, 66.67349938423403, 63.65536889722271, 76.80570325543805, 81.02093327429988, 102.60950180792041, 55.13450999413767, 1.550773766732985, 0.0802370997506284, 0.14632446360924553, 0.08033509771790236, 0.03136436740357069, 0.08424729424258394, 0.010905998961759672, 0.038676048448729905, 0.024625666499618563, 0.08371842544405692, 0.054941282517487006, 0.03094246363147132, 0.10725437783666196, 0.09203340587837082, 0.004209113051934589, 0.05430224644500883, 0.040908103072715384, 0.027271027473973173, 0.06314107014106647, 0.09632381235039043, 0.04945068056845377, 0.045148828742845405, 0.08090562637775175, 0.0458458002145973, 0.06017787652390619, 0.04566303078806208, 0.06810274966541799, 0.045883434283877575, 0.1189962610782635, 0.09011895215559391, 0.02615808366587566, 0.07343646829887744, 0.05479239715984272, 0.028371924549461375, 0.04531229658412837, 0.024868822806785186, 0.09757211431860925, 0.1268144871198362, 0.14439284951696474, 0.14612894264921067, 0.15965230973257175, 0.26905918013184305, 0.16355998633850008, 0.1286448397102856, 0.16708677935023464, 0.11724711380778782, 0.10278816950777847, 0.15217971957979665, 0.15011833019314275, 0.34520029120387574, 0.15356915792630565, 0.19716974978725757, 0.19617852394378957, 0.19946076636833532, 0.15258225281873058, 0.17468859321407734, 0.25133245714729835, 0.18343609156868151, 0.15767410217273622, 0.35503352000828714, 0.3024697760420461, 0.27592326664636213, 0.15712201324922426, 0.16921520143026308, 0.21437567087911794, 0.2258847170178929, 16.626370183883175, 113.09589570568455, 105.12210153764295, 115.55745755472492, 99.14627644323535, 95.69505353127757, 65.18126895350795, 39.14667029534617, 44.56005104126469, 93.52144072132727, 89.39083191656297, 96.73933752121465, 74.38081556750883, 66.46388792222547, 45.38845954402801, 12.799048846767796, 1.0209132827097371, 0.15728431663686232, 0.21586555867425858, 0.24906566426638635, 0.12474479334008311, 0.501354995874628, 0.9109863458621887, 2.647371388250782, 1.8565895696801527, 4.458622403683202, 4.343302759432024, 6.060088882523199, 11.871106278511787, 8.557548753676876, 15.281748348666778, 13.680632921957201, 26.78069033930379, 36.601405066828576, 51.47293429220877, 64.39243324341314, 78.66434189581102, 80.56425171513712, 89.26559063696092, 84.3712963596467, 88.18859407978674, 84.97790659627607, 88.80292354091522, 86.93244718736219, 85.72416890052058, 88.3976407204905, 91.726258185602, 90.43385290330457, 93.32371404094081, 82.09376427435106, 85.41851428247269, 80.45324079452023, 71.84534057494133, 53.788991897336906, 75.79066445750576, 70.63404990780738, 69.79008136257049, 70.8055986896638, 87.42729340830158, 78.46621513366699, 49.41296823563115, 52.935064454232496, 72.71407496544623, 77.73031573141776, 78.7085940760951, 76.3976747758927, 88.20633103770595, 99.64082456404164, 87.25357947811004, 82.67294145399525, 82.31179314274942, 93.57515365846696, 96.34833212821715, 91.4098954969837, 91.23171006479572, 91.86756549342986, 80.21448612213135, 63.75888024607013, 46.40947211173273, 22.886861293546616, 11.238518184231175, 6.656969189643861, 14.077198274673956, 11.218776895153908, 10.22253409508736, 2.893133620100637, 3.8491976213070656, 1.3301967060373676, 1.1020553544644387, 0.3110725450659952, 0.4007716963608419, 0.22339139193777116, 0.25713244753499187, 0.17241233148642127, 4.496708127760119, 27.953737897257653, 64.71893918129706, 83.988935870509, 78.93339295541087, 58.28789949417115, 55.04933180347566, 47.529857927753085, 28.26925531510384, 33.77711811373311, 64.1966873599637, 73.18948191981163, 88.55386872445384, 88.88661907565209, 114.00084926236062, 61.28821849822999, 1.6264904650949663, 0.12622028634312654, 0.2684943894705465, 0.2015167318524853, 0.14368466251800138, 0.32134845011657287, 0.16134334157311148, 0.20765798376692882, 0.21049315260062296, 0.179886898146041, 0.2619732345544523, 0.1879043759958398, 0.18788874780218448, 0.20936256004196985, 0.19722853937456686, 0.17224572268464874, 0.15210968382175893, 0.09036914881078467, 0.19331140924365292, 0.2820622662623083, 0.0915464344284227, 0.14047132204136542, 0.25193622636218227, 0.1307976846733401, 0.1039915863845137, 0.11596868160150706, 0.31022203425245903, 0.1571722226517816, 0.18077272561288651, 0.24268819680137022, 0.16369319370677396, 0.1587202871638921, 0.1243923086252424, 0.26605139636705, 0.1924470782039627, 0.1229362742554757], [0.026545456024788083, 0.0800944771617651, 0.023461603559553627, 0.16688154439531988, 0.0050026230934646825, 0.003667741219678353, 0.07217158052709795, 0.04469148957380845, 0.06293726394013052, 0.027095907435361898, 0.07549479333383423, 0.024802613657929247, 0.0796306492280095, 0.15051326383986782, 0.13438130608729779, 0.030176285691859744, 0.04464169385873022, 0.047112396362447934, 0.06225039716809989, 0.024775852291514317, 0.04906752552356451, 0.013071140593608782, 0.07507287040953675, 0.10696012346494584, 0.11020878825577037, 0.05288151340679296, 0.10449155068565762, 0.019869677752496737, 0.036581533420230114, 3.8216799882150467, 65.59178813811272, 85.56889011013894, 85.16602346974035, 80.35193381770965, 73.78597244139641, 37.66331226594987, 12.130195498466493, 26.016096838058967, 42.52927526350945, 48.22245828567013, 45.24191194964994, 35.78841540121263, 39.17661366924163, 22.74082164610586, 3.007222865858386, 0.10703453358503119, 0.011498947184713138, 0.06064226753228615, 0.035024769979739384, 0.2179914679858954, 0.13535459015157916, 0.5584413245801003, 0.7386574413507216, 1.5557700083140404, 2.053450019128861, 2.0720962314836444, 0.25842011876163945, 1.450418332411397, 10.19459701353504, 27.44179798710731, 32.69877030003455, 44.39700203557169, 48.174366104987364, 50.262730121612556, 62.99993691905853, 68.48797213646674, 72.21624774317588, 74.399211483617, 73.61960118816745, 74.22380308951102, 77.30779017171552, 76.35903942969539, 77.36173060632522, 72.28986278656991, 79.76768893580284, 84.7545668386644, 83.72620767162692, 88.02422323534566, 85.03836601011216, 83.36087811377742, 80.50350989064863, 84.00995192989227, 89.22304861007198, 66.89486226727887, 36.55632918880832, 61.46144997689032, 60.17596767794702, 67.01961717297955, 71.6857236431491, 50.49196127922305, 40.05838601819931, 68.05957871098673, 78.00810583176153, 79.03994021877166, 76.40516650292182, 84.86415001653856, 84.57921335774084, 78.93194167844712, 76.68428236438383, 72.9183598487608, 74.35733625965734, 75.20876515296199, 75.18270492553711, 76.70249785146406, 79.62743282318115, 78.92645036020588, 81.42216036396643, 84.90895132864676, 77.9835831734442, 59.420421123504646, 33.94425815151584, 15.370561595885986, 5.394643093309095, 5.095803103139324, 4.957693017298176, 3.324292071403996, 1.0989082652714945, 1.9400867795751942, 1.5451813248857376, 0.3518003531761708, 0.14669601625252157, 0.018522709405290026, 0.09535752266885773, 0.052460969440759196, 0.08355999080043647, 0.3380531198795765, 7.953142889084355, 21.87548795054036, 47.24971440530593, 56.3836044649924, 59.75818426378312, 44.34563859816521, 34.71146199011034, 16.378512670916898, 11.932676703699174, 36.31028283026911, 61.898962913020966, 67.16825146828928, 62.47595925484935, 82.67972715439336, 35.63589403706212, 1.0211109333942014, 0.06536292813477979, 0.15312666554124127, 0.017053844978011424, 0.012978347236170404, 0.07522059514397576, 0.012154016519836601, 0.1688383627803095, 0.085974462450512, 0.10968097665857886, 0.04140321420685899, 0.1326187522781472, 0.10019288578581426, 0.032705549871729266, 0.06619881432984145, 0.04660442644249528, 0.04570497793235606, 0.015724737013149408, 0.04337735767025621, 0.041993879487798105, 0.04214436596920414, 0.043067544052797946, 0.07082593176634082, 0.03824459539065438, 0.06778926648680242, 0.02625458393125765, 0.04480337671514961, 0.039778058266928124, 0.08828807096447676, 0.06931785704387773, 0.04938752044953647, 0.08500278717087162, 0.021915574926101876, 0.05765916712041344, 0.04453227735094486, 0.015102055960244712, 0.016628313779590592, 0.06842888861654267, 0.1202118817356325, 0.017775375313395937, 0.05101404385641218, 0.061544370537083, 0.022630718003417698, 0.01855143578723073, 0.028546952657521735, 0.02146425912336957, 0.04426264887555473, 0.053214903380120956, 0.07880608581246869, 0.10699203868787135, 0.03304921691456149, 0.03167551209879739, 0.07722900955066567, 0.06426946785781654, 0.07204598807279142, 0.028883700011177894, 0.08517688065166436, 0.05327774940298931, 0.1494951023449821, 0.05854477242176091, 0.02863795049638758, 0.0588753700046049, 0.07667819999398724, 0.04009727178321731, 7.400403955290395, 82.52243226574313, 96.56177966825425, 95.65017377176594, 93.03655732062556, 81.0080914343557, 57.11193369280908, 24.56990326604536, 29.707662982325402, 33.144765361662834, 55.52728829845306, 55.88515358586466, 38.46843365700015, 45.62842230642996, 25.163116647351174, 3.024914226224346, 0.07464637394033133, 0.018173773592758565, 0.06447683253716077, 0.1523356644376632, 0.7706166070795829, 1.0135566323034226, 1.8810386835567414, 3.972430157084619, 8.11121734880632, 4.570517328477675, 1.0386935092749134, 0.0594310786935591, 1.9147749894088315, 10.714520908171131, 26.68615141222554, 35.879936064443285, 45.68337863491428, 51.64425949896536, 51.86861122808149, 64.0802086553266, 70.77913838048136, 76.40463306057838, 78.24411484502977, 75.40199679713096, 77.55140073837774, 79.89365193151659, 77.59628834262972, 78.55922237519296, 77.01536178588867, 84.42054563953032, 85.78422823259908, 88.50589813724642, 90.18613169270178, 89.67735321291032, 84.07617722788166, 84.48733575882451, 86.68181557809153, 89.97244881045434, 69.86754032873338, 45.6332193651507, 67.21108375057098, 67.34006697131743, 74.63806029289, 79.35178433695148, 57.703984091358805, 45.98697008625154, 69.70563273276053, 79.95430746386128, 80.24104841293828, 78.34531984021588, 83.99149325586136, 86.52776056720366, 82.8466396947061, 79.3530002717049, 75.21212270182949, 77.97106296785417, 78.92499908324211, 80.54586364376931, 82.90766392984699, 85.18287397200062, 82.56942226040749, 85.43123845131167, 88.60169026159471, 82.91280223477273, 63.33155370527699, 38.96542541442379, 20.28480798967423, 7.842202080834297, 2.899212803571455, 0.7182527201310281, 1.53501944436181, 3.3835323635608923, 4.388380598637366, 2.4896955393975784, 0.825952853887312, 0.7155402172957698, 0.1868817252257178, 0.3137125759836166, 0.03641940623281464, 0.1462367465419154, 0.297849070761473, 8.693247072158321, 24.52920671432249, 47.20181442076161, 50.76467583256384, 45.415531742957334, 34.39407948524722, 23.551214702667732, 17.20968742524424, 20.759499111483176, 54.35763359069825, 72.41631215618503, 77.36372317037275, 71.39661358248803, 95.36123629539244, 58.968371883515395, 1.8447137359649906, 0.112450675618264, 0.14528600078436638, 0.03728726127695653, 0.07312361331235978, 0.15271262566168464, 0.03779726132990853, 0.056296729542795694, 0.10369586112398295, 0.04190941446370656, 0.034245091655682174, 0.1300030063477255, 0.05873364373861302, 0.016820523324572755, 0.0674571980151438, 0.05345055968650887, 0.06849916952271616, 0.05218306338534721, 0.023406412670268648, 0.0873165259197835, 0.08512313192289683, 0.05632143587835374, 0.05018275418889619, 0.0337066390972224, 0.04384420782087311, 0.10070559779001821, 0.053724596997903246, 0.04491477739065886, 0.15861182443557248, 0.031235097727227597, 0.02564062383176098, 0.03832438727840781, 0.10008856759316499, 0.02372184171221189, 0.08050571315951886, 0.18186852245801882, 0.1879737988835381, 0.21361174332278393, 0.19759653736987423, 0.08504235561216071, 0.1880720726424648, 0.16809518088496503, 0.12611637417707713, 0.12011148591315556, 0.12071440477044353, 0.17692353215909776, 0.20728050160311884, 0.25874153861115057, 0.23758128615877322, 0.2530013643685849, 0.13440117840805363, 0.07297851625950107, 0.10936494240717543, 0.18712069869281786, 0.16628243299501558, 0.07836524817732074, 0.14463645015512744, 0.20719045562849892, 0.31943730589362884, 0.257150404635937, 0.1342770721643202, 0.21380853598877309, 0.18353804254964476, 0.16445577294836122, 14.557794524777321, 104.88721432224398, 107.23858894840365, 112.76163131959977, 100.8913310881584, 92.83966218271564, 53.74220978829169, 16.699243899314634, 36.919297479814105, 59.040025741823264, 62.95399027486002, 59.86286840131206, 49.061578781374045, 58.06028827544182, 35.659922476737734, 4.862450024773998, 0.3074672127202634, 0.11468172283662904, 0.17341985968091797, 0.1195180742070079, 0.7228729657588467, 1.0106626585606606, 2.6407386602893954, 5.2693145409707105, 9.756019153902608, 8.774174394146089, 6.176847546331345, 3.058020991663779, 3.774113650283506, 13.230311486028857, 31.578741419699888, 35.428153545625754, 49.80446784727035, 52.09969766678349, 52.43440920306791, 66.83471664305657, 71.93980693817139, 78.3615819869503, 80.24952857725083, 77.46189225104548, 78.52330130915489, 81.86604715162709, 79.50490582373835, 80.81579331428775, 80.58404399502663, 86.58531742711222, 87.12855785123764, 88.58072127065351, 93.3773563754174, 90.99360650585544, 85.22707123910227, 87.05510754739085, 92.58949341312533, 93.99953842163087, 77.07911599066951, 53.479108964243245, 76.49276871835032, 76.37455632609706, 83.62175495393815, 89.79781704564249, 66.86855100816297, 53.87987713659964, 77.51876661854406, 85.53801321214246, 82.82038334877261, 76.94674384209418, 85.83219881980651, 88.925199508667, 86.58501932697912, 81.85988903045654, 82.10924194705102, 81.69008178095665, 84.13479312773674, 84.03106997090002, 85.76034884299003, 88.62420466638382, 86.36959491237518, 88.94498394381615, 93.9929880634431, 84.88119663730745, 66.77064864866196, 37.640005542385964, 20.613369249528457, 13.727586634697454, 17.037899378807314, 14.435676432424977, 9.109920455563454, 8.606312640251653, 10.062707316490913, 5.026454127603962, 0.6474030702825516, 0.6567999047617759, 0.18918285416739603, 0.396851379304163, 0.13916721056786277, 0.24756368760380054, 0.93715560292044, 17.172003253813713, 35.45549246572679, 69.75867886697093, 81.93203710740613, 89.73717720277848, 69.01509946392429, 48.47459608508695, 25.96167002954791, 20.692842352774836, 53.73720092158164, 79.0865772001205, 89.43846517993559, 81.93639878303775, 106.08207810309626, 68.73240640086513, 1.9275174217839397, 0.1952265371238032, 0.20123121088310597, 0.20626327473550074, 0.24123836008291094, 0.25078582276980727, 0.10929218703700651, 0.2451445811217831, 0.19557277822206098, 0.30064832539327685, 0.3150674177994651, 0.48579768067406076, 0.1965333605485578, 0.24102655209360585, 0.13122271025373092, 0.11001659977820613, 0.1568356495831282, 0.09478486428457884, 0.13612458512427347, 0.1643848944936068, 0.24050765009897374, 0.12928996235132217, 0.19678381001276357, 0.16190451629940542, 0.3396875531442704, 0.2260266118232281, 0.13804150565016654, 0.1393007856583403, 0.27100970127409507, 0.12407719367934812, 0.16808321459158776, 0.20295639492331013, 0.18669587229528736, 0.10314329722595793, 0.14584757387638092], [0.05056855606756384, 0.05867804107706874, 0.044090972402163094, 0.03588270418526184, 0.027382001055464632, 0.00768561095502528, 0.05395290269065769, 0.00699016256182785, 0.009405029704794288, 0.03480532792426887, 0.02271905560196648, 0.02679047967127014, 0.22528145342103897, 0.05518061221547185, 0.011065877681117386, 0.09952662677894678, 0.04278802921274497, 0.023676368648246415, 0.06035688828917281, 0.050210961546268196, 0.06671885013460152, 0.09020368914089857, 0.12262712713451156, 0.036299111276504495, 0.07296923893473803, 0.01290306186063155, 0.054330863659420324, 0.056542762510117986, 13.161360140769714, 76.67209163788827, 94.63868864120977, 80.11943140337544, 82.95320264754757, 63.71043505207185, 51.738494442355254, 18.482004288704164, 32.510712262122865, 47.076063233037154, 47.72913002198743, 46.673412322998054, 49.7841578145181, 60.664989179180516, 13.855830488666413, 1.9874873973669547, 0.0745100102898094, 0.2548126413697197, 0.012685128998371863, 0.033860921544293245, 0.185250923217785, 0.45619297892816607, 1.0816410111804162, 0.5778941355885998, 3.194454264256262, 4.7220429009006875, 1.8278350416691074, 0.22345491594845251, 9.122073919542375, 43.83703662503151, 69.9703299614691, 80.8504984455724, 84.93676093316849, 77.3049189967494, 77.39601996637161, 76.81156327647548, 78.21236718085505, 74.55105427772769, 75.03926384833552, 73.94422438836867, 72.28027651386877, 73.29823355520926, 72.77546790338332, 75.00712394714355, 69.14655377787929, 74.9171212411696, 79.55187228418167, 82.91567340973886, 80.61019835933563, 83.75879472301853, 78.95663692105201, 77.71592063288536, 72.07449328514838, 76.82946497394194, 78.33165430253553, 87.40252756303357, 64.06489572217389, 35.074104724391816, 56.59377682593561, 65.10784610625237, 56.3276832334457, 42.001618416078635, 64.53628224711265, 75.83687782287598, 78.49483274644422, 73.46040787235384, 75.45457224692069, 80.55919185761483, 79.07662222462316, 78.0797440005887, 70.62920970301475, 65.80056413527458, 63.08389133022678, 63.367004086894376, 66.00830462671095, 64.74741951111825, 67.24791480648902, 68.43210974047261, 70.06944041098319, 73.57925568857502, 84.82510674384334, 82.86125444596814, 68.29538376100602, 46.56165222967825, 24.478449283107636, 16.64385611011136, 6.0114980705322765, 3.596262355004588, 7.765688405882928, 2.235904706101264, 1.466248528130593, 0.2600925193438607, 0.7270663471952562, 0.20645951581818445, 0.1261521121787448, 0.05354869171916958, 0.028757220810098995, 0.038908736164411234, 0.11437521105812443, 6.631174212501896, 18.115254832852273, 30.722072239845033, 50.35898508564119, 50.93135303066623, 73.95350471619638, 49.29831735549435, 33.851862799736764, 17.733070850372314, 34.935633290198545, 51.98772576547439, 62.62566043484596, 65.4139204179087, 75.76229787641957, 50.395321922917525, 1.6587120006161353, 0.08926287954372746, 0.058576745101280754, 0.03247041067469024, 0.07712482159296352, 0.01642681541852653, 0.03875716183815272, 0.05739301285375992, 0.06516270339488983, 0.08078247774392366, 0.12043123569099173, 0.15100653253255353, 0.08996817073033703, 0.12032745375988946, 0.08835144941845248, 0.043643684306692694, 0.0374614505187398, 0.03332935611627275, 0.06926356439268397, 0.03952537565642307, 0.09791278595765752, 0.02738456553479116, 0.06757438648492098, 0.06934540556563486, 0.026705637348875887, 0.051121024204598325, 0.04916131766813417, 0.04237703453268736, 0.044890837143025095, 0.028857430856254314, 0.01704221959376047, 0.15136746719719904, 0.015741803536882565, 0.04915716930202419, 0.041941548021690506, 0.04433677554310811, 0.08717027207415912, 0.029104394620404612, 0.05686618950999072, 0.05422999669286994, 0.07192420307546854, 0.11759264244427604, 0.03304629811956998, 0.06301621313116725, 0.04753788159559331, 0.03691255235143247, 0.053578787483274944, 0.06005230705223738, 0.08215421179850256, 0.047773334888681296, 0.05548912348345884, 0.036527562525964556, 0.03973040376759825, 0.0834109483947677, 0.019399046957973513, 0.11664351313224725, 0.052269003128692995, 0.03683602016779684, 0.10946398991490565, 0.04092183136831849, 0.06738543855927645, 0.06749531088937676, 19.316863129215857, 94.26443176884806, 106.94113992875623, 88.83220795662173, 90.81749208511846, 75.02763794314477, 80.68175808075937, 30.978656045852173, 27.396386746437322, 31.720615510017645, 38.17014525013585, 41.80363678163098, 42.586004503311656, 49.591471379803075, 15.782310443539775, 2.3222939285539814, 0.02815520019090224, 0.12152076593690342, 0.05049409232132378, 0.26393855651540143, 0.5049115437413416, 1.2037944048643112, 2.278269490888042, 2.0774171717705268, 4.291380384275991, 4.412903256954686, 0.5673765451196702, 0.9137731285825853, 11.66138400954585, 46.43543035753312, 74.6901572135187, 84.49562764936879, 88.09822267101657, 82.45497534351965, 78.11663781442951, 79.54534546021493, 79.29298800806846, 76.59103193590718, 75.92675501300444, 73.93789368291056, 75.65885713023525, 73.59860081826487, 72.91261749882852, 74.87633643611785, 72.87851641255041, 75.9664180201869, 78.5262744657455, 84.05821277249245, 82.70328490964829, 85.12965525350263, 81.81006708452779, 82.02658976277998, 74.65681706705402, 81.77494618200487, 78.39127432915473, 89.49069546115014, 68.0965195932696, 44.06924878397296, 64.8483067943204, 72.74081768528109, 63.614011426125806, 49.617139370210715, 66.43436031956827, 77.78894732075354, 81.32256354055097, 77.14417242234754, 79.14729549038795, 82.43038208253923, 81.8736251708, 81.10620560184603, 75.6631560479441, 68.17197030590427, 67.10621526164394, 64.47179063673943, 71.09488133461245, 70.68264807424238, 71.45383311856177, 73.22251612140288, 74.296233577113, 78.51572328998198, 88.02367410352154, 85.21938339356454, 72.40735346271147, 50.72310655347763, 29.62751130903921, 16.977608626888646, 7.558588241377185, 5.50605752775746, 3.961483067081821, 0.43212540748138584, 1.7321813034434475, 1.3502761769679286, 0.9460102310103755, 1.0602681386855342, 0.525665509123956, 0.24188490764748669, 0.013538911964954629, 0.05005399396102275, 0.09375501994884784, 7.17955147066424, 20.82847006859318, 32.96386564931562, 51.310544244704715, 49.86935953940115, 56.39309660080941, 42.6788430829202, 37.84808335765716, 28.275262425022742, 58.14131659846152, 70.76254675465246, 73.88553004111014, 75.06512795725178, 87.76497810117661, 76.53414187892791, 5.199016351853648, 0.13768803268190355, 0.04454780978360965, 0.025569649616016016, 0.05531353613121375, 0.035686673776757334, 0.10102292673001367, 0.05048851520123501, 0.07213568930784542, 0.07199950185754607, 0.1196903367376616, 0.09589845735219218, 0.13199446722865105, 0.03152390904424172, 0.05606397287920118, 0.06788007088846738, 0.01726337768618138, 0.05433305850132339, 0.019487112595309174, 0.02824738546605072, 0.11367250158781968, 0.033975807919857964, 0.11226521339267494, 0.033570869164841796, 0.04740732872197705, 0.05155440780424303, 0.07030411097671717, 0.05024298785194274, 0.09742851113720287, 0.025708945468068126, 0.04798982750564333, 0.03320986172184348, 0.04448116779507649, 0.029523136364596508, 0.1098241814742646, 0.15685926041295453, 0.15990124234268743, 0.1874867048595221, 0.12235590902667855, 0.15803532795079295, 0.19133669504475212, 0.1706041035152251, 0.16551711115865939, 0.19178943768624337, 0.1426266338075361, 0.08977547663474277, 0.3385091260556252, 0.2641845320261294, 0.19114359492255797, 0.18976808405451237, 0.23327165854073342, 0.17389175452051625, 0.1311772812398211, 0.15903328004623615, 0.17615683136447785, 0.23116229672826108, 0.21046831603011779, 0.193782476708293, 0.3041000724319489, 0.16510567597804532, 0.2230491804619951, 0.12209592942869472, 29.542176223570305, 122.78554639508648, 115.16332211032991, 105.07061650676113, 104.70816596861809, 86.08291672122094, 73.01880390413346, 28.85903270013871, 49.95552616734659, 68.61847723684004, 66.23049120749197, 66.39891778269123, 68.18189390244024, 83.1392720437819, 22.13033610774625, 3.29985668582301, 0.1763188283169462, 0.5640369533531128, 0.13785431972674786, 0.40295409699601514, 0.40481688574917857, 1.777138162043787, 3.203798575747398, 3.263235967005453, 9.283977593145064, 12.37972786349635, 7.358068833428045, 3.026536371438734, 12.39793158346607, 51.117791129696755, 79.55624180455362, 88.94562721252443, 92.98201284100934, 84.52379811194636, 79.9101729546824, 81.49144511069022, 81.12278153819423, 77.47180015810075, 79.73667867722051, 75.59406741972893, 76.03564000898793, 75.75096222662157, 74.42810366230627, 77.78112611462994, 76.29161388643327, 78.10479225650911, 78.62529077837544, 87.8689052212623, 85.31341829607564, 88.57520641819124, 84.59852710846933, 84.8432908519622, 76.96346882850894, 85.3174348031321, 83.74459574299475, 90.203413655681, 72.90423147140011, 50.45642068309169, 69.63179803663685, 79.70628030838506, 71.3075993137975, 57.80892710531912, 72.51237100170505, 82.37044042156589, 84.87358723917316, 78.27328943437146, 79.88990214563186, 86.30005913396036, 83.58067989349365, 85.2047529528218, 78.42332009346255, 71.13372064405873, 69.97842573350476, 70.05527280992078, 74.42401655258672, 74.05441161124938, 75.44024775105139, 78.11528067434989, 75.5796330974948, 81.76415181929066, 92.48762161500993, 88.64107870286512, 73.81652770503875, 51.93056114258305, 29.563066767108058, 23.476897555012858, 12.648836778056237, 14.850663196656013, 19.67466958107487, 11.392170171583853, 8.670286497762127, 3.742400306847788, 2.197606928886906, 0.6885456077514157, 0.4740285170414756, 0.22115775534222204, 0.07538231630479136, 0.3109515031739589, 0.43631817604745593, 13.144323325926258, 31.67399225696441, 47.537314353450654, 68.41249788961103, 71.20475476787936, 108.36439548000213, 69.59346863531297, 51.04687075461111, 26.227806768109723, 52.03288401326826, 71.00668291891776, 85.31983529367756, 86.5413555022209, 102.19886102984029, 84.3575680640436, 4.48023711481402, 0.2146509109485534, 0.17824005425697376, 0.13906512169107316, 0.23447446254712923, 0.07455202255157695, 0.16724584984683222, 0.12737900198948, 0.17988302174114412, 0.16571543600049712, 0.2257291552039885, 0.23580434521840465, 0.25223660943729265, 0.15377805478149845, 0.2311854785488498, 0.14803175183553852, 0.16106940385314727, 0.13375150520474682, 0.21887895020265735, 0.12700754893763413, 0.2504499238585272, 0.11383022376967054, 0.16274984835857348, 0.20711196225977715, 0.14795479064266528, 0.1903926142521443, 0.17716776098935835, 0.1970796578473622, 0.2541917883941243, 0.16121742736187675, 0.13381193422021406, 0.2094296999876538, 0.0799682641762399, 0.20530739618885904], [0.028642173556070176, 0.05583747898438766, 0.0909037632687438, 0.09180074497576683, 0.016826590740933053, 0.013503151938259123, 0.056442416483356114, 0.03771892500921123, 0.06050009310485856, 0.015022662438211903, 0.04452301151750069, 0.004604187467315745, 0.03053097865514217, 0.03281801923989289, 0.017611018810120803, 0.10388907615936573, 0.07550577137378917, 0.08595697266320068, 0.03945833530216929, 0.036873512510811134, 0.0255177624809045, 0.06066767100785529, 0.04278224907935627, 0.043672244064509876, 0.06038863497275499, 0.061804196917481964, 0.08880833659561412, 16.90015358309592, 78.60862854988345, 84.23915955328172, 92.18016270668276, 79.15751718705701, 70.00295623656243, 40.69370408211985, 21.543561297078288, 29.01905755842886, 41.58245824998425, 53.530095854113185, 57.47379195305609, 57.348276107541984, 50.0528048699902, 10.956010453162655, 0.6251142630653997, 0.08114298339933157, 0.03779374498633608, 0.1061376131650421, 0.07315693813706599, 0.027455945777135993, 1.3761017976268646, 0.7631264122263078, 0.6578439906720193, 1.2444402109230719, 1.7900493789103724, 4.527242308662784, 2.038959803119783, 27.627400621291134, 79.51329185116676, 83.78736526735368, 82.91046450215002, 78.67919198928341, 77.63228001133089, 76.32698582064721, 73.77893570930728, 71.61956110308248, 74.63714245826968, 71.76537129186815, 72.73465956411054, 70.36803476272091, 72.19487082573676, 72.28302217298939, 74.68678397517051, 71.36168879847374, 76.87786702186831, 81.5603062414354, 80.31323571358958, 77.54960429283881, 77.69346114127868, 76.56526196387507, 81.21069754323652, 77.64960119801184, 74.48500156402588, 65.56571222120716, 72.91492385248985, 74.25124399123654, 82.82779662839829, 45.95242184977378, 32.71422443851348, 54.876476872351866, 39.9376868432568, 63.17634159518827, 75.75941101197274, 76.64192076652282, 76.95285489482265, 75.77850510997158, 78.2002313675419, 80.02881680765461, 78.54219144390476, 68.72041179287818, 67.74598521571006, 63.252223768541896, 61.44159493907806, 64.0234519589332, 62.60457377279959, 63.3803479902206, 66.59626007080078, 69.68136895087459, 71.02003466698432, 74.96314633277156, 77.21195097892516, 80.81820164957355, 80.9333545930924, 73.81584521262877, 56.80773819646528, 47.93706270956224, 40.448595170051824, 29.77345093604057, 24.798122452151393, 12.30011159373868, 2.4568013173918573, 2.1198182384813986, 0.9650825108251265, 0.9003631578337763, 0.6636478114993342, 0.176496330889002, 0.03171379925803312, 0.03842452646143014, 0.14238641927799872, 0.0737958554659159, 3.551149214467695, 13.763204697639713, 25.472105280045543, 40.648247734192886, 45.07880803077452, 44.94132503386467, 29.565510403725412, 30.172238311459942, 12.704834495821308, 17.462721486245435, 41.34872813378611, 57.06685389241865, 70.9127264638101, 74.39851330172631, 59.569577094047304, 3.130873134059291, 0.03943370174496405, 0.04441036211867486, 0.031203571293923645, 0.1198446651500079, 0.09496490260766399, 0.03626664447027349, 0.029669867099953756, 0.055983445547040434, 0.022910811239853505, 0.003844151158832134, 0.12622588644585303, 0.0425352891456456, 0.07985377233595618, 0.018033711652782176, 0.03064268768104094, 0.023412089381787567, 0.007132747803904838, 0.05220557870944181, 0.0312515456349619, 0.035492083613550475, 0.04969597043048951, 0.07423772731976164, 0.029648719242803996, 0.01853313394671967, 0.07528131527285423, 0.06425445636494026, 0.03550752794610397, 0.050898046653357246, 0.053176487901157914, 0.04631882886432352, 0.04486032003056138, 0.06616937357091135, 0.017869960358967225, 0.005843461568151871, 0.01433692277303987, 0.12175966279521105, 0.021059205455164758, 0.07791265109253508, 0.03851636125135326, 0.026384700134757067, 0.0659214521968557, 0.11067618615925313, 0.06636120964803043, 0.018288876388161894, 0.12224199175233803, 0.0856304583289931, 0.03292014259063909, 0.06669358455485876, 0.02014932474271665, 0.0343705385532831, 0.07416502557574742, 0.01526205916889012, 0.033228504471480846, 0.08156822348434119, 0.059398014338747154, 0.1478258427232504, 0.04366592766957418, 0.07902907868546825, 0.05801814059997278, 21.672744558703517, 96.01690753813713, 97.48439958018642, 102.12616382106658, 86.94084890427129, 89.51946212399392, 59.03069442318332, 34.67175191448581, 28.515442878969257, 20.564004259724772, 47.32873839716758, 57.41685482763476, 57.67427605967368, 50.96981187020579, 14.24719968149739, 0.730814355756006, 0.1040661497221839, 0.01975595391535711, 0.13290223545364796, 0.19547818168517084, 0.3450181767825158, 2.313444571148965, 3.1881838652395436, 3.0224029287215206, 2.4846467135414003, 0.6803475476561055, 0.16606406729307868, 2.863291737533385, 32.499659022977276, 84.27752033356698, 88.56191742804744, 89.1912381879745, 83.12683028559532, 84.03216823454827, 80.52949167067005, 76.98208439734675, 71.30086068184146, 75.07922495565107, 73.25595824949204, 74.77250345291631, 73.15668306043072, 74.0691283441359, 72.80544265624016, 74.97085771253033, 73.22012347559776, 79.7342860314154, 83.45440310816612, 81.57381488430886, 79.70914363861084, 79.99468434241511, 79.92236368117794, 84.05123879832607, 81.08547979785551, 77.28307139488959, 68.50477557028493, 75.51318814677578, 76.12880414532077, 86.90927382438414, 49.99790345468829, 40.019381969205796, 62.49754798027777, 48.20555679259762, 68.84091484931209, 76.57883336467128, 81.819700425671, 79.24263261979627, 78.939268665929, 79.28089141845703, 82.7553661407963, 80.21205425262451, 72.54020414044781, 70.78127999459544, 66.21404863172963, 64.19381618499756, 66.20420348259711, 65.62896044023576, 67.05724054767241, 70.79458467421993, 73.10840652834985, 75.27777533377372, 78.36219387669718, 80.67337989807129, 83.60288050866897, 85.21812039036905, 79.41689568181192, 62.979422923057314, 52.67148902339321, 45.653764740113296, 36.17550626877816, 29.99889700643478, 15.20989150770249, 3.667092515576271, 2.1350046751960634, 2.138581141348808, 2.587766560815996, 1.6292758382135824, 0.7885040859541586, 0.20396139502765673, 0.11665425368494566, 0.0897988576381918, 0.0380888573765274, 3.44433841686095, 15.557647866587486, 26.270138948194443, 42.48716469733946, 40.96390439618019, 38.17460890739195, 25.186505740688695, 29.74432929869621, 17.12025542413035, 28.881031313250144, 52.27791447793284, 65.48597043560397, 80.70655530498874, 82.12228775024414, 85.96275883336222, 7.993542811562938, 0.05023971665650607, 0.032256637669859395, 0.02560322341929761, 0.0821708971934934, 0.0645511813702122, 0.07945142295812407, 0.01096611005073834, 0.10819406128458439, 0.08637599977514437, 0.016827412370231845, 0.06258143142106072, 0.099606774897585, 0.014799473255181746, 0.0431135859370472, 0.07631123621737765, 0.042042817184401136, 0.039883372373878956, 0.05043559767786534, 0.025160401616425767, 0.04626799126966827, 0.03447023723574896, 0.026898218446501324, 0.038002117071300745, 0.010503069272324925, 0.0415913156053472, 0.021981460402809808, 0.06053406527386077, 0.04897651044772037, 0.05610252625399059, 0.06523452413779113, 0.029865893678018646, 0.04722174009188049, 0.11324012156335578, 0.14488570452217134, 0.18683612767246463, 0.1775107691965757, 0.2194350074616171, 0.19394468816538013, 0.11401154145958925, 0.16684690189938392, 0.18836586736142638, 0.18712485088936745, 0.14795788563787937, 0.08622583888110616, 0.1417731812163707, 0.1901503772504868, 0.1809408512687491, 0.24400288028822792, 0.13649665870733801, 0.21633304084741303, 0.14281188918938562, 0.19617542894857545, 0.12011141696524237, 0.18474374236839433, 0.15505552171699463, 0.20729145666043605, 0.15653777927640947, 0.1442893970036699, 0.20075401471507168, 31.958554329410678, 115.14190596918907, 104.41534534577401, 114.02934135929232, 95.78952773924797, 93.48868108564808, 56.91360296741609, 31.802202770786902, 43.34255518451814, 62.615407359215524, 76.73184502509334, 76.2778385223881, 79.27372132578205, 69.44021378794025, 18.478936995229414, 1.216010259043786, 0.33653105639161607, 0.1236657508378548, 0.23742535662266517, 0.30522055263000153, 0.2672761564533557, 2.891689697580953, 3.4289806215993823, 4.3817669922305695, 5.082291028191967, 7.057799139330465, 16.705543225811375, 7.643763490261571, 34.80042919035881, 91.423537500443, 91.90058400554042, 90.72630482335245, 85.1567352971723, 85.19310351341002, 82.07088116676577, 76.0727926992601, 70.11330035425001, 74.0190161428144, 73.69486362703385, 75.03196039507466, 72.74529703201787, 73.48809980577039, 73.47484219458796, 75.78150180078323, 73.34127764548026, 83.44664465996527, 86.07347165384601, 84.94138148523147, 81.83068306215348, 83.3472204208374, 80.81053733825684, 86.37601975471743, 84.33533606990692, 83.26703932977493, 72.2782604156002, 80.31918202677082, 81.44099558553388, 91.03360683687272, 55.21695037041941, 47.13627553755238, 69.29710218983313, 53.50398855824625, 74.43992568600562, 80.45727299105737, 86.252135615195, 82.41643413420647, 81.01890933129096, 82.79509190590151, 85.5979391836351, 84.73302518167804, 75.93194038637223, 76.40199722782259, 70.13925860005041, 67.33324989195793, 68.67232353456559, 69.06836525086435, 70.92788250215592, 76.64823578250024, 77.92518692631876, 78.44344969718688, 83.6490938740392, 84.96805360240322, 86.74491866942375, 88.765974813892, 81.88463134150352, 62.99677941106982, 52.55412386309717, 45.74001373783235, 32.84060516665059, 29.108771970195157, 20.85943521991853, 7.281032992947487, 7.192486957196267, 3.849417764332987, 3.695679975132789, 2.6784348439785743, 0.7423405469425264, 0.23076492692193679, 0.15423802929299493, 0.29741307480200646, 0.17884003899751172, 6.55526654374215, 25.33582841196368, 42.831627245872255, 57.713005542755134, 62.65112838437481, 63.185618000645796, 44.7306937556113, 44.864658386476584, 18.73518543858682, 30.10955491373616, 57.471540512577185, 77.02529322716498, 91.67510263381466, 95.95043120845672, 93.63440498228996, 7.618669636787907, 0.09255187120288612, 0.12487127445638181, 0.15937077242039865, 0.24014426395297053, 0.22093447135581126, 0.2038467576306674, 0.09517441233319622, 0.162020486689383, 0.15051167037698532, 0.08028972233014722, 0.262917974182675, 0.14503711413952614, 0.11585746095666002, 0.1536091323941946, 0.0891613192676056, 0.07346554899648314, 0.10453107316167125, 0.18195017210898862, 0.13211584619937405, 0.11953446082770826, 0.17982744972311682, 0.12705578183334681, 0.1039652789251939, 0.07529148892048868, 0.1791655497565385, 0.15130280937638976, 0.12944555480874356, 0.16142005761784894, 0.1420071904337214, 0.1941640497816186, 0.111718678606614, 0.17392037556536738], [0.008968249462815303, 0.033623978210192536, 0.054103343206788265, 0.0343605870711467, 0.0875854687464814, 0.034978452303837386, 0.08561594862370722, 0.04400552295508885, 0.020893933476820108, 0.04234655189418024, 0.026646194671611154, 0.05782062781133479, 0.040951501953625874, 0.047333343780689666, 0.02762856453867449, 0.06737362548348404, 0.04200935063342895, 0.03417717413075509, 0.01864796095047026, 0.0718146448414172, 0.09800688453739691, 0.03657728546268998, 0.03482661750768462, 0.026908309739683906, 0.0481727309975653, 0.04899311157303953, 10.501130242501537, 81.46897777434319, 95.88337436799081, 94.11761745329827, 86.02397134227138, 65.07483936125233, 21.565487346341534, 18.06790594131716, 45.23478500304684, 53.68667294902187, 55.835598361107614, 48.02538271873228, 42.48215583062942, 31.25397309180229, 12.258054960158564, 1.4487887101788677, 0.07439920333244147, 0.1216696857685043, 0.04384244581864726, 0.1862135126946434, 0.019749689231356306, 0.11831920023166365, 0.7469925392539271, 1.2189590233948924, 2.198138164897119, 1.5785408380531496, 0.10447542453485151, 1.9341752774292424, 40.70771478837536, 83.12621839584844, 80.62814712524414, 78.21836840721869, 74.53973431741038, 77.99160834281676, 79.14028229251986, 81.44005421669253, 76.13555062201716, 74.85374358392532, 73.60027959269863, 75.16538373885616, 75.3412235936811, 78.56937346919891, 74.71963774773383, 72.70055847783243, 77.32038097996866, 79.20082799849972, 75.61973541013657, 71.67525875952937, 75.41142617502521, 75.16238704804452, 75.80038409079276, 77.93671869462537, 75.76386682448849, 76.157194260628, 73.69633059347831, 65.4349757009937, 59.895451530333496, 73.04426793129214, 77.40255463507869, 77.7206039428711, 30.2687737249559, 33.41159243737498, 42.77355655547112, 76.05778571098082, 72.88645528977918, 74.24003385728406, 75.34684042776786, 75.06812464806342, 77.4210839117727, 74.70001020739156, 68.1248861743558, 64.61439624909433, 59.43249025652486, 58.12527018208658, 58.19573556223224, 63.399344028965125, 66.19199706662086, 69.82502968080583, 72.08620548248291, 76.50139008798908, 75.28507878703456, 78.27653715687414, 79.91991612219041, 77.81248938652777, 80.6093668168591, 78.13945816409203, 75.02766147736581, 80.90037530468356, 77.51163574957079, 75.28117210634294, 70.79688318314092, 49.16439194833079, 25.053362846374515, 2.686917704920615, 0.45410146696432946, 2.6061727731458606, 1.470411511198167, 0.899229531566943, 0.10573846603473348, 0.03957269690750588, 0.04362337531582002, 0.03788614668132317, 0.08225757238124648, 0.5532018347613273, 6.3574364108424035, 24.703185404500655, 50.30635080029888, 70.95468797991353, 66.53388654032062, 39.53011728102161, 47.75232299681633, 41.80995964234875, 30.930487378951046, 55.62295098458567, 59.11298967176869, 72.57751372552687, 76.96319426259687, 60.15468489739203, 1.2082002071603652, 0.04876990036498155, 0.025368465351000912, 0.045108957696826234, 0.03609289572904668, 0.05475475926012282, 0.05502033513039351, 0.035829334670016845, 0.024670710554346446, 0.04934309884124706, 0.02893686842834277, 0.019153644097968936, 0.038808639116224744, 0.03497949418341441, 0.08253479661840586, 0.03399766440833769, 0.02658626361329469, 0.06251152972840975, 0.040190837931849306, 0.04397785185926384, 0.10606650488391038, 0.053265675857302644, 0.06026894522590503, 0.1573240459566155, 0.015045147118789536, 0.03697463994725578, 0.04613088068342017, 0.04049152361168977, 0.0570035835487708, 0.03350110536801719, 0.03618123332759546, 0.0461230282821963, 0.1247723188792025, 0.04166180718569987, 0.02333263648794063, 0.018726419845235445, 0.05391273287034804, 0.0765258863928818, 0.044371433360802556, 0.09002597206422398, 0.0468660339773182, 0.042725252137789806, 0.05432052530288216, 0.02211601800105024, 0.04467693773368674, 0.05806841128956407, 0.052885883938400984, 0.06363453418617288, 0.018807424067129052, 0.025110872116901224, 0.10102170098933483, 0.012667601864274233, 0.054448860351957624, 0.02641289600081021, 0.04868825454445136, 0.02740179293698842, 0.05060764953433987, 0.03469493082394043, 14.856651675316597, 102.47396038424586, 109.91714416011688, 106.67506987048735, 97.03309166815974, 92.69069056357108, 44.801029697541274, 30.224896131023286, 41.69584220455539, 40.802624379434896, 52.03993643483808, 48.67938695415374, 50.79908286371539, 38.606677593723425, 15.972852322363085, 1.312762873788034, 0.05214706874422489, 0.166128127565307, 0.024015638346393264, 0.04115601295545217, 0.3081202260669201, 0.94926567567933, 2.910483243965334, 2.5071299845172517, 3.1768263972574666, 0.9463998939721816, 0.6286057241020665, 3.204430077345141, 45.76145341319423, 86.83116374477264, 84.80618523013207, 82.07554094253048, 77.50967456448463, 81.18635531394713, 83.82630655842443, 84.84330654144287, 77.31070057038339, 76.94838339282622, 75.82729939491519, 77.4638299019106, 76.86139306714459, 79.15637969970703, 74.8141590241463, 73.82874196575534, 76.85113999151415, 80.88124198298301, 77.81568219584804, 74.61745216000465, 77.68435339773856, 78.12412169671829, 78.70536204307311, 78.52315225908833, 77.60492540174916, 79.51051481308477, 76.20437252906062, 68.65627319582048, 63.9694409216604, 76.38811988215294, 80.3335222121208, 79.81440436455512, 35.35401682699881, 39.70476081294399, 46.79077356092392, 77.88919525761759, 75.7930100348688, 77.2118725315217, 76.55442837745913, 76.90601395022485, 79.39740150205552, 76.57840974869268, 72.16744561349192, 66.01060313563194, 62.7862814934023, 60.72431110566663, 61.26579038558468, 65.66028841080205, 70.4473529323455, 74.45115935417914, 75.79985849318966, 80.1179095237486, 80.26744596419796, 80.98558487430697, 83.77789666575771, 82.64968179887342, 81.07612102262436, 77.9390956509498, 74.7550489056495, 82.24129246127221, 78.31402717098113, 78.65679525559949, 75.45170107195455, 56.72769046598866, 31.8832605115829, 5.9084132794410955, 1.540496176288974, 3.7978099142351462, 3.250958948366104, 1.1884709303417516, 0.7154435063562086, 0.32257921633220493, 0.09534854411838517, 0.07721089923213567, 0.0758553296327591, 0.44727062866572415, 6.634209146422725, 24.421725926860688, 46.94503253506076, 53.108244942080596, 40.663921525401456, 21.683584028674712, 22.39221315230093, 27.546317385089015, 42.15866227303782, 73.01677996112456, 70.42768616830149, 81.35670385053082, 84.69715118408203, 80.53647348957678, 2.8702769885140085, 0.02772279143814118, 0.0049913419699747, 0.04581409566585095, 0.016840278816920136, 0.06323557857784533, 0.04816680147703137, 0.02704204570862555, 0.024968647893758553, 0.02938760966513186, 0.026826254062114224, 0.038705094672378995, 0.011025239589564022, 0.05178822549961267, 0.035339237581337654, 0.013976849957309185, 0.0404749914342838, 0.008450729299276587, 0.08467437293861182, 0.020948500004446795, 0.03284095591234584, 0.05397654416400099, 0.07748771744269518, 0.05480341350419387, 0.020638649997812127, 0.056723314112112413, 0.06509242248871634, 0.042724133649420355, 0.045757083402525996, 0.023911189918796864, 0.02817098926302166, 0.0330086640502897, 0.2493169870708258, 0.17495401203632358, 0.15678665059949123, 0.19844824328057228, 0.12063517595731443, 0.1423600352098865, 0.14444811509982233, 0.19021708818693317, 0.1568900724692691, 0.10993776166991842, 0.14060440683557143, 0.12711966590535256, 0.14694646571672734, 0.19431175153341987, 0.1241695762221371, 0.12502557222521113, 0.09065665394788788, 0.09067036692173251, 0.2521011038052459, 0.2168281328293585, 0.11765946063303179, 0.23664131159743956, 0.2970673546435372, 0.13557500896915314, 0.13872367630322135, 0.27374199982131686, 24.172641692623017, 124.01359342759656, 121.58200633141303, 119.41080185674853, 106.91493065126481, 90.01218242029991, 36.643519555368734, 30.466425880309078, 65.3425136689217, 74.31759480507144, 80.1586001919162, 69.13999557495117, 66.27501010894775, 49.83905922982001, 21.087536734919397, 2.565523535013199, 0.23552585693617023, 0.3144197057812445, 0.22366741341688942, 0.31851772459283956, 0.3428571040351545, 0.8263252339055462, 5.813186466693879, 5.4646113130354115, 8.691038777751308, 5.663909883268419, 3.148529928538107, 4.059074333598537, 50.63110736108596, 93.54286470720845, 86.39556884765626, 85.70680064539756, 79.11366508853051, 84.43517608027305, 85.79273193113266, 85.83510921847436, 77.70671090772076, 79.40041388234785, 77.39153277489447, 78.00958848768666, 79.87542859969601, 82.41636353154337, 76.10061014852216, 74.07847142988636, 79.62094522291615, 84.80459274784212, 84.60306136838852, 81.14907710782944, 82.0961961438579, 81.79939039291875, 81.98473807304137, 81.43112690218034, 80.53215888238724, 81.40798491816368, 80.93285252971035, 73.56800633092081, 68.12421937142649, 79.82541837999898, 84.56666961792978, 83.74709037042435, 40.4650769695159, 45.515756145600356, 52.80710104973086, 79.37244738301924, 79.29931086878624, 80.3121845183834, 80.36847837509649, 80.8290901491719, 83.52538231880435, 81.36203827396517, 76.41308969066989, 71.1791338459138, 66.99226256339782, 63.593795530257694, 63.967813138038885, 69.1808823616274, 73.61953058550435, 78.01241259421073, 79.87277707745953, 83.61909558696132, 82.8746924861785, 83.44378132973948, 85.7385483095723, 84.1896749311878, 83.28876141578921, 79.23496830847957, 77.35314061564785, 83.55799290441698, 79.47650786369078, 80.72310770711591, 76.4011029274233, 52.588483825806655, 31.347843254766158, 6.799779745840258, 5.6151690406184045, 9.165126835146259, 4.997410447366777, 2.4114118949059518, 0.9288384008311457, 0.2208282762477475, 0.19036189412638066, 0.18050572864951628, 0.21761148837545227, 1.4212479105880185, 11.530527857042129, 39.6627208494371, 73.78572925444573, 94.60567797383955, 86.57597434136176, 58.91943247087541, 63.93571638291883, 56.410449166451734, 47.45297162763534, 74.60391213816982, 82.18151553984612, 92.67041975452055, 97.69039461689611, 90.1662217417071, 3.6305286711262124, 0.13117809329302083, 0.07002248939487242, 0.1267748267479962, 0.08430888005081685, 0.17310355729874105, 0.12736702803522348, 0.11470240721058463, 0.2489034528092992, 0.11871403428695856, 0.2666576477068086, 0.18980038232140004, 0.12848050618964818, 0.32641811356429135, 0.13066337413845525, 0.07064369477091298, 0.15891372436477294, 0.12526240830700244, 0.14495115907442185, 0.15020915757744543, 0.17055009431656332, 0.1288215915161756, 0.19235156236156342, 0.22223279120460634, 0.16450003750862616, 0.17790613185253837, 0.1123415770369672, 0.1767195842318958, 0.1088659433768161, 0.07515366204203137, 0.13389730705849587, 0.12806147907770452], [0.015046407333424976, 0.025433023580380028, 0.004546360756766292, 0.0549838042277242, 0.053155562209506194, 0.06653559424223439, 0.03850136124979585, 0.027507762049114513, 0.07156481590843009, 0.035868933754822904, 0.016774040939767036, 0.11530937101211279, 0.02444909280917097, 0.08157976076848085, 0.050170228651334206, 0.04477146532266371, 0.02590671298094094, 0.04487233611965372, 0.049980181389518326, 0.043916656755872314, 0.008768890402279794, 0.03633571112708699, 0.08101526888147478, 0.09299735899173445, 0.08272058826180236, 2.1025531907235426, 73.97395595427483, 87.88887008543938, 92.49696470076039, 64.1469830851401, 41.18509469493743, 20.11138431487545, 36.28054734199278, 42.41215721253426, 33.0879694415677, 37.594078510038315, 36.62716719412035, 44.99856025941911, 32.59840076969516, 17.74061749058385, 2.4099059499079183, 0.22352878214611163, 0.05132611743324707, 0.020927853934887438, 0.14861711961848123, 0.04423020888240107, 0.1565272225848129, 0.7178998906766215, 4.457524140034953, 3.133123103649386, 2.8029137128783814, 1.710249615773078, 2.178716548988896, 53.18095784033499, 84.10530474878128, 81.56508368830528, 80.4152879407329, 71.62213417791551, 67.67745356405935, 75.75905015391689, 74.76105013201314, 78.51890040982154, 73.93847419369605, 81.77811545710411, 76.1735583889869, 74.27850446393414, 72.22286870402675, 77.4000286286877, 73.67516548402848, 79.08739305311634, 75.65414244128813, 72.36595676791283, 67.40021259553971, 69.13427675923994, 67.34999841259372, 69.41753464360391, 76.80619747407975, 75.75666535285212, 76.34693499534362, 77.34218935812675, 75.61946868896484, 62.929036155823745, 59.3529014433584, 68.49398120757073, 73.72188875752111, 81.93648507518154, 55.1972875287456, 20.700689054304554, 38.596840289331254, 72.64174645946872, 70.40240257017075, 69.69844695060485, 74.64758380766838, 74.09771457795175, 74.26618037685272, 70.45147926576676, 62.589017652696185, 56.169427364103264, 54.44492201651297, 61.520775825746604, 66.75769698235297, 68.5383902826617, 71.26035044270178, 76.31350855673514, 76.8591651608867, 76.57746837985131, 76.98617935180664, 75.35106089807327, 74.53229750356367, 76.93430992864793, 75.68227368016397, 72.54783707280313, 75.2490714288527, 75.92221290834489, 86.07597412601595, 86.26724458509877, 83.08940302941107, 80.45490387947329, 63.1755296645626, 20.685701677876136, 1.2615364741894508, 2.6234655226430585, 1.6144264801856012, 0.5270493090633424, 0.46569099830042937, 0.25076561337036474, 0.050557535892773064, 0.027379325493389083, 0.0629049924863202, 0.07305420574641998, 0.06011550164511127, 1.0116862133145332, 10.32790856976663, 31.135176266393355, 58.9637238748612, 72.76085315212127, 90.85742965821298, 133.29299557593563, 76.00031514321604, 11.985661060579362, 35.59895707714942, 51.35602412685272, 68.01367913523029, 81.12744915869929, 35.861665664180634, 0.41984927750402884, 0.05214521098100851, 0.04009978072116933, 0.10351918592688539, 0.0394741396960472, 0.043557373010703636, 0.032083894419033206, 0.0303897560919605, 0.05512515128019357, 0.13038238840958766, 0.07348224205235321, 0.008357902425491523, 0.05047459538365084, 0.014193260219819365, 0.04156614578659496, 0.01861188012445646, 0.06371319992467761, 0.029672596288184007, 0.06023550548801019, 0.075037477147435, 0.036081875554255904, 0.05265203942995399, 0.044355835810664206, 0.0373142620458478, 0.07161406770108208, 0.029002554722190387, 0.07404838102839648, 0.019829247462292834, 0.025946819598996834, 0.05427458301006306, 0.04065071668235525, 0.03226460115383229, 0.04227520995623162, 0.009863211570547955, 0.06746687370562746, 0.03683416240458046, 0.05169254111787004, 0.03636212966915581, 0.07385279878132767, 0.031141437732824878, 0.003132137311284521, 0.051214050261243704, 0.057535420938004414, 0.043284496322514555, 0.10133631797807832, 0.01177408383227885, 0.02747573191300035, 0.008797895448702958, 0.05675051023342437, 0.05939995254119558, 0.06074770421330487, 0.05788353512123708, 0.04544379940677074, 0.06069075323701386, 0.05683473777025939, 0.031188623003301122, 3.5565108493451154, 89.70914794552712, 101.21575032511066, 100.8980461858934, 73.59051289096956, 63.961019592900435, 35.572351640270604, 24.0385829248736, 25.058075574136552, 33.96437206575948, 48.698830143097915, 44.82080628795009, 52.48514506124681, 37.90412226030904, 20.65074747608554, 2.4394914075251553, 0.1048852509308246, 0.04052901978514368, 0.1392626651232281, 0.23543855355631924, 0.41906443574736196, 1.3365330499026085, 3.271793107832632, 5.515800204969222, 2.8769724743981517, 1.1745618379885152, 0.6262757136456428, 3.6439819105209845, 56.76497259447652, 85.97847184827252, 87.36950905092301, 83.43518349432176, 74.64376341912055, 70.07572404799923, 77.83371725390035, 78.72129471071305, 80.41279331330331, 76.36830406804239, 82.59467447957685, 79.10360028666835, 78.17697171242007, 77.39612194799608, 80.46612970290646, 76.28264734821936, 80.32762296738164, 78.00528172523745, 77.55693912506104, 70.74717890831732, 72.96665991506269, 71.83580137068226, 73.60555125821021, 79.8752324811874, 79.78495520930137, 79.36133138595089, 79.52360768471995, 77.91338059210008, 66.0224094698506, 62.17331701709379, 71.7522156623102, 78.76938296902564, 82.7798495754119, 56.45795299160866, 26.52674432723753, 40.962562945581254, 74.84380429790866, 74.03942031245079, 74.58184488358037, 76.09754285504742, 76.3746504629812, 78.57730450168734, 74.48395821356004, 65.29677883271249, 58.86683740923482, 56.861886516694106, 66.18204209112352, 70.95058518071329, 72.99334772171514, 74.48594293286725, 79.52392931907409, 80.90907512172576, 79.90684678477626, 77.45654213813044, 76.42757892608643, 75.83886254218318, 78.52639998159101, 74.68842352590254, 73.90975459929436, 74.44780180531164, 73.83366061795142, 85.46308025237053, 87.94170441166048, 83.06047162702008, 84.42949648826354, 66.45255227242747, 28.869923160922145, 4.991280763379989, 0.568061243862875, 2.2808732092380524, 1.2867201744548737, 2.4100282788276672, 1.3797612464235676, 0.25723170188646166, 0.05586695421727435, 0.0689767487347126, 0.021163757304630933, 0.1016210575377749, 1.4211936102759455, 11.686764686338364, 33.04724739443871, 53.71122698630057, 56.64368506400817, 79.52465103518578, 121.08034303111415, 77.64288610027683, 24.139266244826782, 47.09005040507163, 60.84171156729422, 79.16657786215507, 91.31305217742921, 54.095536893413914, 1.1934299094061698, 0.05844222006177711, 0.028125462572901484, 0.05437975156030828, 0.02897721827931462, 0.02620787363529446, 0.07462310018919169, 0.007468488709550472, 0.07306527571692582, 0.17940530463332133, 0.05642459727823735, 0.008804266427403257, 0.01777545958306761, 0.03702275792977983, 0.019815214646739826, 0.02562909803894018, 0.04037019443668185, 0.04894941774827819, 0.02454101186876576, 0.04898065881383035, 0.06512983056205897, 0.04606091770373526, 0.03918587230145931, 0.02379151166326577, 0.015067892269261423, 0.023730919854114615, 0.03458192519422981, 0.04375041184586383, 0.041700448660600575, 0.11084238127354654, 0.11533736386486601, 0.0881769345893014, 0.09396911088016727, 0.1133765388400324, 0.16302858178894367, 0.2499382537339003, 0.2174711104242071, 0.13586232258427527, 0.16281475132751852, 0.17866278157359172, 0.1140722769102262, 0.21167341830028644, 0.2926686922869375, 0.08630067801042911, 0.2031362723679312, 0.20905606358522372, 0.15803617064750966, 0.12517014067740212, 0.152450317156411, 0.1800089053088619, 0.09633710397587669, 0.10386122886331813, 0.09584183579370861, 0.1505116856987438, 0.1442566084405107, 0.21227078302012337, 5.637623629262371, 110.24686644154211, 111.94514289979013, 115.39174525968491, 83.40072939472815, 63.680868225712935, 33.51173054787421, 51.36892872471964, 57.2376613463125, 54.0153322681304, 56.445017014780355, 50.32704914769819, 68.0436852670485, 48.65990846387802, 26.974994751714892, 4.079065918922424, 0.24299086281849494, 0.25816280514963214, 0.2156413247388217, 0.27164481880684055, 0.4458897398604501, 1.6052693392961257, 5.287778117964345, 15.276946386983319, 11.174824776188022, 10.971062548698919, 7.131551955976795, 3.496327227161777, 61.7764163017273, 91.0871236555038, 91.11341138039866, 87.78500572327646, 78.61748526173254, 74.86884470908873, 80.6505830826298, 80.44837705550655, 83.28384276359313, 76.83192822241014, 82.63036804814493, 79.50474108419111, 83.64978421118953, 79.87908424869661, 83.69099263221987, 77.4845164821994, 86.57484469875213, 82.31118125300254, 80.6111946413594, 75.63420895607241, 75.88069069770076, 75.98781847184705, 75.61087869828748, 83.93819608995992, 81.24210788357644, 80.93155814755349, 83.17889582726264, 81.71779724859422, 69.3667713288338, 66.08657160112935, 74.95094776153564, 82.87451205715057, 86.17020514703567, 65.65753882931125, 32.38928548751339, 48.3849738490197, 82.02612692309965, 75.97887546785417, 78.55903410142469, 81.82457985416536, 80.96909523010254, 81.74501849759011, 78.16300807460662, 68.49463232101934, 61.56519274557791, 60.823943230413626, 69.0075606684531, 75.12779174312469, 76.54390073591664, 77.97956666638775, 83.68228497043734, 84.33175886830976, 83.47343444824219, 77.99125532950126, 76.50859155962544, 75.1153499849381, 78.53672365988456, 77.71101767016997, 74.66089633203323, 75.6622931265062, 72.7964682732859, 89.21745531020626, 91.86816169369607, 90.45608489744126, 88.40278687015658, 67.26264722885625, 26.009513139724735, 7.049817606326073, 10.031979468560989, 6.252797870866715, 3.198299167617675, 2.873725732488017, 1.53554969977948, 0.33849830889413435, 0.18329719982800946, 0.18690181205109244, 0.1323947328473291, 0.1743408046182125, 3.135006331628369, 18.24373402903157, 49.89828309705181, 80.96269392198133, 91.82412916614165, 101.0629818516393, 145.229944721345, 83.31395872177617, 23.52342470999687, 52.34810529216644, 73.2153852524296, 86.76824892720869, 103.40393081788095, 58.59986128345613, 0.9781562609057274, 0.13319725591328838, 0.19130292588904982, 0.2011761291613502, 0.1026495612196384, 0.1133147385271807, 0.18377048894762996, 0.13118489615378842, 0.27457734209395224, 0.22578601424972858, 0.21125979210820892, 0.12400533463205062, 0.1955142337828875, 0.16924985924795752, 0.1495922116502639, 0.09232327822716006, 0.16865174376195477, 0.30548598677400624, 0.10646277918450295, 0.26276083422764657, 0.17020849571112665, 0.18476686290194913, 0.14328349291557266, 0.07328004846649785, 0.16894294910373228, 0.191796776808558, 0.17252562056866386, 0.09628307945545643, 0.1055847658144851, 0.1837751161186926, 0.1753199262724769], [0.04656919405885762, 0.031103631293761636, 0.04397108730289244, 0.014605040139999362, 0.08381509807922187, 0.11156630371847462, 0.09891754091386834, 0.08647369896812786, 0.09806053367473426, 0.03379567000534266, 0.038915129168139356, 0.02842001380368827, 0.04045253739722314, 0.0908110206646304, 0.033692117900617664, 0.05899871016041406, 0.0429738438387792, 0.07422458891186022, 0.017384049940794226, 0.10678419137313482, 0.014566831504775873, 0.06964035707736208, 0.014331535259712369, 0.10830072370628196, 0.20414226838657934, 36.912186222691695, 97.77990310422837, 90.84050855328961, 86.52357932059996, 77.40197412429318, 42.38423778164772, 113.17281338476367, 151.63914465135144, 72.2878937567434, 53.830659235677416, 45.02220430681783, 60.35397268110707, 33.64354964225523, 16.127038732651744, 0.46789325593459996, 0.13438430915196098, 0.08120489862537192, 0.07259682061210757, 0.028890125573642796, 0.1023758226825345, 0.14137317606758687, 0.6945138616907982, 1.1107402174703538, 1.998055243203717, 2.071916292751989, 2.7746876016739876, 4.104948168800724, 61.00867117604902, 84.00974012190296, 80.03527302895823, 79.09238230797553, 70.58094101567423, 63.108496358317716, 70.67998870726555, 75.89909445854926, 79.85387125322896, 77.44086050218152, 73.46926458420293, 76.8468253843246, 75.05515729227375, 65.1395506243552, 72.2208918294599, 66.24880867619669, 72.2586799437, 72.57633701447519, 71.19949879184847, 70.91610754689863, 65.64869780694285, 63.28547762286279, 63.50200422348515, 64.60134652353102, 72.32579169734832, 73.22086088119015, 77.27461476479807, 73.03813334434264, 67.06044904647335, 55.92310251728181, 56.232965838524606, 67.57969240988454, 76.27808170933878, 67.41146979793426, 44.76383778356737, 25.566130376631214, 31.484869295550933, 68.49121985896942, 68.24464398045694, 68.24788385821928, 69.22001977120676, 74.36678132703229, 70.40968248921057, 70.30848533876481, 58.64516073657621, 54.44650273169241, 56.840619425619806, 63.119157360446074, 66.77721469633042, 71.19373290769516, 74.01267759261593, 72.2314037815217, 72.5167562115577, 72.088347096597, 71.04557714154645, 70.86605025875953, 74.22995336594121, 69.95847655880836, 71.58123954649895, 73.56286802599507, 69.59326467206402, 77.23793275894658, 82.59406258982997, 79.8915809200656, 81.7843363361974, 80.71957757396083, 83.92875886732533, 62.726151558660696, 15.522188659637207, 0.8387852556282475, 3.20669254949016, 1.0055609419941902, 1.0344205772684467, 1.0128933227350636, 0.2544398476640063, 0.17837237296325548, 0.06205305291880524, 0.02571018461528565, 0.11153529247929973, 0.03769863134009704, 0.09567536488776246, 3.457445997384287, 21.817499629912838, 35.32053155283774, 71.23058749783424, 100.89204495952976, 121.39611736420663, 42.27530571722215, 25.42369930974899, 55.078879017983716, 65.75942239453717, 72.1156781719577, 76.1555939335977, 24.830066234834735, 0.2501137797991114, 0.07502135865750813, 0.010683998172622054, 0.011024030128253565, 0.04210865861105342, 0.007158595131665108, 0.025963729074705514, 0.024302737456896616, 0.06167273622967544, 0.04501992678870598, 0.044370893268815936, 0.04438786211633875, 0.061483466547102704, 0.036204484096097375, 0.04297939414579061, 0.040768881914235895, 0.02964641523337172, 0.04060910661674796, 0.04278189667891111, 0.056047620732457414, 0.037918904600965406, 0.06612617387286117, 0.012707382894962305, 0.0383745507156897, 0.08566398999743885, 0.03325764645612048, 0.0206432273731597, 0.042962612989809246, 0.05007084023447768, 0.030288925514586514, 0.046262609502000195, 0.063909494633516, 0.044312119003265135, 0.0015573587147481441, 0.07507653997069405, 0.06560445267466769, 0.06062744756139094, 0.09565173873617765, 0.016754318006156434, 0.0698958780436266, 0.036207119438556895, 0.1315534150888843, 0.023054487199612686, 0.07196966273289535, 0.04964193441875039, 0.04633654847801213, 0.03112786648524625, 0.003447771760552461, 0.020924121171476382, 0.04830147973411987, 0.04432346476542373, 0.06339067307811591, 0.04495197862026192, 0.10884241681666144, 0.18854114827850174, 47.591796075144124, 114.82127574182327, 98.94172483874907, 98.19700794835245, 84.49001081528203, 47.83119793861143, 91.85991687159385, 126.92016386216687, 63.8188022951926, 45.84470179773147, 34.84965885839155, 56.031136358937914, 39.185078144073486, 20.807410863138017, 0.8020847410924974, 0.08424217677524976, 0.07952263083068595, 0.12429525294611532, 0.5714253504430095, 0.5560777288290762, 1.3879647610648986, 5.053826878147741, 8.69013172964896, 2.1453835118201474, 0.7345483908730169, 0.5151833425606451, 5.500864799945585, 65.1710747134301, 87.79988719571023, 82.24669748736967, 81.76787022621401, 72.40411358494913, 67.1110240874752, 71.82379891795497, 79.88172008145241, 82.41038583940076, 79.06223497083111, 75.37381848981305, 78.5232699301935, 78.49084761834915, 69.01438559255293, 75.59325156673309, 67.35021806532338, 76.60280689116448, 76.88378980082851, 74.32907166019564, 73.09206593421199, 70.59978408198204, 66.66234416346397, 67.46190363360991, 68.5694319202054, 74.16985481016098, 75.16358729331725, 81.36567823348507, 74.93592508377569, 70.99851654421899, 57.449881184485655, 59.193296278676684, 70.03040498302829, 79.25326224296325, 72.9909864548714, 54.032280829644975, 28.797829997154977, 37.98335021541965, 76.07214943055185, 70.2211812234694, 71.4846315691548, 71.6031499062815, 78.30306806871968, 72.19155250057098, 73.12125621303436, 60.083270303664676, 56.799630657319106, 58.98352399949105, 66.19834346155967, 69.14460043753348, 74.24696860774871, 76.85915731614637, 75.76221942901611, 73.85343720836025, 72.47145283606746, 71.09801923075031, 72.37409176365023, 74.32579255873158, 71.46028933986541, 69.62174892425537, 71.60977871187272, 69.81953051782423, 79.0183436486029, 82.53033976401053, 82.95839586565572, 83.2439914826424, 82.55286985828032, 85.43847130190942, 65.30537274576002, 21.49741461200099, 1.555000733463995, 1.1568278218469312, 0.9601775869246453, 2.8423144115555674, 2.776173689673024, 1.0269290953874588, 0.5865785082982433, 0.0904903362595266, 0.06125492336709173, 0.012423103945630213, 0.07723113161421592, 0.1355982520767758, 2.6079763279807184, 21.53956832424287, 40.92102504545643, 74.59386302578834, 112.36220852021249, 119.1503486325664, 42.06488624695809, 40.64822027760167, 62.596383863879794, 73.93942340727776, 77.27065317092404, 87.85789120581843, 35.81339305446994, 0.3487970127213386, 0.030545549647461985, 0.06755243806589036, 0.02463022663798784, 0.018433912153986674, 0.029774367238485047, 0.010931648543074487, 0.017539565789423162, 0.10388880802859222, 0.05917428219090066, 0.03935480234964241, 0.0598390473263158, 0.05114554667905454, 0.04253620845115474, 0.04696999210864306, 0.0030803624559344067, 0.025102678806551044, 0.07964697456167591, 0.07141459372735794, 0.06874637843500223, 0.026294851427777644, 0.009472877324198284, 0.01581737044973359, 0.09111437616088698, 0.014489844456435213, 0.007999719452909044, 0.05611988580635479, 0.0317423609310701, 0.020385143842788476, 0.06416369792855074, 0.19285912625491622, 0.09874243619701556, 0.27505381813933777, 0.06817043353352817, 0.2101871157966314, 0.19092282370453884, 0.14495428471315294, 0.2200775560472281, 0.23591464655774258, 0.19301910073526446, 0.13666717455752436, 0.2468544127599847, 0.10730724556431656, 0.2068035659049788, 0.10028837864557583, 0.23373929393147272, 0.12939102467029326, 0.21987008411557446, 0.17291148373436543, 0.22216391990021353, 0.26640557413620336, 0.1220977144135583, 0.1989173495601262, 0.2119233468247037, 0.2638358394465139, 68.61322910554948, 123.06630180728052, 111.15433031512846, 108.9426391355453, 97.53409601026966, 55.6954050064087, 127.48362802690076, 155.7674078787527, 84.56181372365644, 70.75740844972673, 60.934087307222434, 88.10955047607423, 51.87855835883848, 27.52374610593242, 1.7422863095998766, 0.23059079513674785, 0.4887167208137051, 0.46664820984005934, 0.48117590287039363, 1.4141949987219227, 2.0523689158501166, 5.465105531677123, 6.0260745786851455, 7.319396224714096, 7.783762197340689, 8.622543408024697, 4.929834383149301, 70.42173201037993, 90.02091361630349, 85.19102465721869, 85.53038027978714, 74.78806741776006, 68.331006726911, 76.53233758864864, 83.00595068162488, 86.83266993491881, 80.44083826003536, 74.69935909394296, 78.78329169365668, 83.07709463181035, 71.84697228093302, 79.42309302668419, 71.89023602393367, 79.6577605893535, 79.47762181681972, 77.08671754406345, 78.57544529822566, 73.13749482554775, 70.41934720931515, 70.19219490789598, 72.84592936115881, 78.6195876521449, 78.658309290486, 83.04349560891428, 76.79136307008805, 73.086990387209, 61.17076312341998, 64.38934633808752, 73.22959992193407, 83.65992746045514, 76.55906461900281, 54.35349156779628, 35.34386181062268, 41.46279458076724, 78.1715274626209, 75.79200590810468, 74.33373928070068, 76.8882534580846, 80.83460500163417, 74.64764656559115, 75.92905352192541, 63.368361226974, 62.67501561872421, 61.63684268151561, 68.83106970017957, 73.27614276639878, 79.26598641180223, 81.39167570298719, 79.22451126960017, 76.24657723211473, 74.06122084586852, 72.25819356979864, 72.44035628534132, 75.9877400244436, 71.38503474573936, 70.68914351924774, 73.10123643567486, 69.87875046268587, 80.03315494906518, 86.8595773943009, 88.36956439479705, 87.36406480112385, 86.03223185385428, 90.53166112592145, 68.45620878281133, 20.619178279753655, 3.6755292886687867, 8.462066496572188, 3.9484139748157996, 3.5797584922082963, 3.219138965491326, 1.368843329048926, 0.6834815214237859, 0.19584585792355, 0.1700339349167001, 0.2139027494817011, 0.14250732327420867, 0.27895207186379745, 5.631697908524544, 33.608883734672304, 53.05366516113282, 81.40341143454276, 103.67643356323244, 127.81666863349177, 55.73332648123465, 40.25322191176876, 71.19558426641649, 85.06334366336947, 91.43033104558145, 98.57251213442896, 38.19851183122204, 0.48308284893151254, 0.13152241917146792, 0.13974059673566974, 0.08107194406611305, 0.15711738607816159, 0.07455038312341898, 0.15114347840989792, 0.1418124508833693, 0.27152442042866065, 0.15553437263494538, 0.1475758375900407, 0.14542314584457106, 0.1811088543505438, 0.17319683616440143, 0.13250561641348949, 0.18673601530251965, 0.12128709379823939, 0.1707975407161059, 0.12254808984336354, 0.12946916563856986, 0.11914331165532913, 0.11564907738037648, 0.15316274828247486, 0.2401449227885854, 0.13789319102802586, 0.12322573291678583, 0.14046940682155473, 0.10021816668731552, 0.10909024626016618, 0.17612474760220898], [0.07029464212997306, 0.06401134219260947, 0.03517195079175215, 0.11962748688435364, 0.04841679128848257, 0.05697777787704141, 0.029850602563050006, 0.005799630326369117, 0.04787168525640042, 0.010926857620718019, 0.09691806675325479, 0.07226338850394373, 0.023193195079182907, 0.07657095534546722, 0.09465504302493027, 0.035066284284356146, 0.019642911896470095, 0.01626170240342617, 0.019637533959241647, 0.05581138602968666, 0.10442735251760292, 0.08633771836156807, 0.09555530358826923, 0.32448971704129254, 21.051531337922622, 100.00658558261011, 88.09767353919246, 88.85684044130387, 62.193093607502604, 54.96767590122839, 54.13569411923809, 81.01894071025234, 61.544843489123934, 40.462496049942516, 57.87161834778325, 77.49757797487321, 34.48984807537448, 9.915811611760049, 0.6849713479318927, 0.09557444046461776, 0.08966162830831544, 0.02901201399283544, 0.11539532607721707, 0.3389843150732979, 0.7447406697657801, 1.2923295315234893, 1.092598274830849, 6.394148815062739, 1.0323681970757823, 1.4852785198919236, 6.832064284432319, 75.67659408815446, 84.13300452693817, 80.35360474740305, 78.50314817120953, 71.10365175431775, 63.0788157832238, 66.88198904837331, 71.10297710664811, 76.0824260404033, 76.68184265013664, 72.32625453702866, 69.82907756682366, 73.71365962489959, 70.34480648656046, 67.44288798301451, 62.27257259430424, 62.91031076062111, 67.51219626395934, 66.883848251835, 70.80672833227342, 63.43745769992952, 61.590907804427616, 57.77553989041237, 55.25037288665772, 57.013023284173784, 65.78796940465128, 68.44336694286716, 71.57163758431712, 61.493354535871944, 56.38911931745468, 54.04703286386306, 62.56845266588273, 64.06109886784708, 75.2107028038271, 68.68633424082111, 80.1736464038972, 19.35223114105963, 47.25570778692923, 85.57856267498386, 61.582745352099025, 73.9531046344388, 67.75839559493527, 74.37675983675065, 70.77560040258592, 68.06650561671104, 57.53654987581315, 54.5483039271447, 56.854116301382746, 68.0764841264294, 70.68325996398926, 79.0529703324841, 69.08295646790536, 70.60525186600225, 68.9651127784483, 74.2132205347861, 74.57672226813533, 74.71074965692337, 72.81011812148556, 76.5373033092868, 71.55295141281621, 66.22193259577598, 70.88668192586591, 77.70150200013192, 74.93016704436272, 77.16832637786865, 73.3699893951416, 79.23443486613613, 77.79098695324313, 82.60695934295654, 57.17128307588639, 14.389302249877685, 0.8474104250631026, 1.217277307183512, 2.7541483554147907, 2.2472665867497845, 0.24045005560882632, 0.3382428645366623, 0.1728215603338134, 0.05184535650656589, 0.028521570249370513, 0.0399885447545638, 0.07926691834244036, 0.05782823889486252, 1.394795446145919, 19.46749979449857, 31.125719431907903, 52.657996070000436, 38.84041163229173, 33.204597196271344, 22.84677859275572, 41.72905683517456, 55.15837369426605, 61.53120933040496, 76.7198896408081, 62.1307671454645, 6.502652850843246, 0.04023345540307703, 0.035981357157711065, 0.06386023517998476, 0.0569930958050874, 0.010985646250417397, 0.0854115410437507, 0.03758950211528329, 0.03660577627259397, 0.065536247866769, 0.07045653949101126, 0.018956244307299776, 0.03456529725583331, 0.011977293442243771, 0.043570978732238856, 0.07765356781742266, 0.03488858252944004, 0.060892885535835266, 0.0740707584566647, 0.014289484693548613, 0.04853159722481524, 0.014723892935792045, 0.04489267575404337, 0.04370833446662273, 0.06966949140112247, 0.027765937510036656, 0.06004013774556018, 0.12745637686983233, 0.03537641582830298, 0.022623064785054135, 0.05821975961988492, 0.0381222703013449, 0.019510361448591276, 0.08169824392685006, 0.04879032426904287, 0.013677816154555449, 0.05053335432744315, 0.053269119422522285, 0.052234594289573937, 0.0329640815635362, 0.04689542877097284, 0.05033730476674053, 0.06944783152111116, 0.0331422659538446, 0.05524945287634769, 0.01874675947962509, 0.13899922280782653, 0.028128092169701576, 0.04131651986690779, 0.0302564395561574, 0.18383447261106584, 0.1316535121370708, 0.13760650560500162, 0.2468451584178594, 30.71615338325501, 119.20365364320817, 97.8106858653407, 99.03564207015499, 70.94135192132765, 71.07644619480257, 66.5687721006332, 100.56256586505522, 92.78011275875954, 60.5965163630824, 56.46233427909113, 69.7273861977362, 40.51617368575066, 12.23776650044226, 0.6783919396900362, 0.05727230420997066, 0.09060417692507468, 0.025717253691606948, 0.20806381118393716, 0.45897302007482904, 1.9680245965719225, 3.058071247031612, 3.2669033831165684, 2.4180698731253227, 0.5349120065089196, 0.6988999295619227, 9.246009049877044, 76.4471358637656, 87.97623695865755, 83.446456386197, 81.57864724436115, 73.22601487559658, 68.09844939939438, 68.02697597011444, 74.0745569044544, 77.6156020933582, 81.98633840007167, 76.01170570619645, 72.8061173039098, 75.62794100853705, 73.27577406360258, 71.4592852131013, 64.59876168158748, 65.46759413134667, 70.79035635917418, 70.60197276453819, 73.97754884535267, 66.91784735648864, 65.18914115044379, 61.51661419099378, 58.9388011347863, 60.183094624550115, 68.05650357277163, 71.29576160061744, 74.108532474887, 65.17054911582701, 59.27224574550506, 57.26977771328342, 66.2723115182692, 67.61868076939737, 78.43951948227422, 70.80218622761389, 82.8431958536948, 21.72414133625646, 48.59875086815127, 88.72719041762814, 65.64730144316151, 75.24562758784141, 69.1891428732103, 77.45941331309658, 72.38683946671026, 70.67095941112888, 59.48809377608761, 57.737857680166925, 59.23688165603146, 70.9915033463509, 74.43555616563367, 81.23799723963585, 71.75823257815453, 68.9898080210532, 68.8194751739502, 74.9530658414287, 76.54574424989762, 77.31613697544222, 75.37645432256883, 77.70418490132978, 72.58731965095767, 65.34287452697754, 73.11751427188997, 79.99055016425349, 76.84460532280707, 77.36129914560627, 75.82258470596807, 80.40028879719397, 80.15086527793639, 83.57001889136531, 60.35997782984088, 17.818288264736054, 0.7131963559696752, 0.9380142342659735, 1.4770323494749686, 3.4768139258507764, 1.2541741853760136, 0.6556519373290001, 0.3463615272795001, 0.005716813827729634, 0.15142762042101354, 0.07464669569725953, 0.03753083127160226, 0.09517181529513291, 1.1983526065464944, 21.636992154582856, 39.09516565261349, 62.46549437122961, 42.98715314557476, 30.754959352554817, 30.546548135818977, 53.453150718442856, 62.309862567532456, 70.38979607243692, 83.97666669661, 75.9726232097995, 10.552391698283534, 0.05516492273478259, 0.045044728885254556, 0.02732780608048122, 0.07771339162342972, 0.05790749069062933, 0.052146884883123065, 0.01997717137959215, 0.06168983148170575, 0.029699658344109214, 0.06440881925124316, 0.03881769427548974, 0.048568097483967586, 0.02624778490092966, 0.036109822441733656, 0.04988710936759749, 0.04221368160459303, 0.015882007203124944, 0.05048701749934305, 0.040287296062395464, 0.0206081482071069, 0.01781630356075062, 0.06630808145048157, 0.07162180518911732, 0.017142496672609163, 0.045008431639402144, 0.01380720648974661, 0.0494940871102435, 0.027092555800693172, 0.049672922675287536, 0.14905421874455868, 0.12225760462423488, 0.2162383064146965, 0.20748235044940827, 0.1608186326320133, 0.17223231614597384, 0.11202372715718324, 0.15793641067800984, 0.14571422861228067, 0.11006824942606111, 0.11958784183427212, 0.14631105707057063, 0.1590226773893641, 0.2100622281432152, 0.18937938636349094, 0.18167701579870718, 0.24339313558753461, 0.12660313878328572, 0.11910467018042842, 0.15166824863803002, 0.2414600812499562, 0.24243857471212266, 0.3006374163012351, 0.45663724863721483, 42.458343121313284, 133.4603395769673, 108.89928910040088, 113.34612723319762, 84.22896923557406, 73.55959676927137, 69.86018980703047, 87.5799834343695, 70.359068224507, 53.16707264992499, 73.78644312581709, 104.02743862521265, 52.29045821774391, 16.66009472262475, 1.1308397905480478, 0.254695751674233, 0.4148477652380544, 0.1649736637069333, 0.4040419724920104, 0.5251624651493565, 3.2550159048649574, 3.8035132856138296, 5.834309410664344, 14.286608715211193, 6.545606726600278, 5.505395627790882, 8.769026283294924, 82.88593399909236, 89.20672370541482, 86.94329646325882, 84.06962686969389, 75.40191834972751, 70.4522402055802, 73.46509118233958, 77.81426229784566, 80.90444672492244, 83.68631716697448, 77.90945822192778, 71.84546609078684, 78.56937346919891, 77.33776492457237, 76.3364387327625, 69.29641969742315, 68.57992818278652, 73.99436796865156, 73.87308043818321, 78.05133819580078, 70.68366004574683, 67.99827990993377, 65.84915837933941, 60.93443639816777, 62.68971666213005, 71.42877701790103, 76.58776852392381, 77.0845837746897, 68.33655295833465, 62.23803220256683, 62.0172655197882, 69.16662846842121, 73.27112997731855, 84.1264541687504, 73.62887367125481, 82.17065841920915, 28.189480189354192, 49.82214204726681, 91.67572236830189, 67.92235851287842, 79.43420902375253, 73.85976791381836, 81.2095679006269, 76.15055761029645, 73.98529944881317, 62.756495014313735, 60.97171068191529, 62.65114799622567, 75.24336830262216, 76.7901392905943, 85.64129706351989, 72.91631237153085, 71.81254956030077, 69.84050735350579, 79.87172588225334, 81.7429082624374, 81.05540306337419, 79.62231020773612, 83.66483042317053, 75.85666225802514, 65.44668005358788, 74.7119499021961, 84.46033416255828, 80.22009511147776, 83.08266439745503, 79.67866682237195, 84.88092207139539, 84.89479157232469, 88.24461337058776, 64.35572378097042, 17.077246635190903, 2.610886726648577, 5.874422019527805, 8.730134021851326, 5.976295288532011, 1.5024458761176758, 0.7640721324470736, 0.34533962727554385, 0.17180824051460913, 0.1840524705907991, 0.1466618946963741, 0.2689774538720808, 0.2631677801330244, 2.6719891640447804, 33.22603687163323, 51.23933361422632, 66.05591435586253, 48.17122036410917, 48.4603500366211, 31.874395954993467, 61.4492396385439, 73.66488102943667, 82.00552663495465, 95.12189326747772, 90.31522473981305, 11.986356300692405, 0.40468478154751564, 0.11835722883622493, 0.1365923584108391, 0.1837478433885882, 0.11669369955216685, 0.11721276242526309, 0.16301537443312908, 0.1422163937240839, 0.15292192088259807, 0.1698833833178205, 0.07231566634389662, 0.15300058279066317, 0.06081886229015166, 0.1504498317597374, 0.09793945347830173, 0.1916391925225335, 0.16097914337390856, 0.16674488963138673, 0.12582267138866648, 0.14403680249327613, 0.07910809299397854, 0.0796853632275616, 0.15176117510324524, 0.12234634824938352, 0.08259457445913747, 0.2374256477360764, 0.25586613483967324, 0.15608286094521323, 0.10320024820224893], [0.08824042795646576, 0.03583875372104588, 0.024606464505796472, 0.01411062231542723, 0.019479216144029653, 0.04852893506927837, 0.06327043557840009, 0.07287789827152606, 0.01768388526303874, 0.022803738961116444, 0.06521777745576636, 0.014683115033192501, 0.04792221641588596, 0.08214004683278261, 0.0691665316961946, 0.029981921524590546, 0.023403857767041174, 0.07677291910494528, 0.018273857234406377, 0.09251165924774063, 0.02860689712237687, 0.06476144186191021, 0.05020698171950156, 2.4528267306666223, 79.15970586961316, 95.42008753745787, 90.4165787850657, 74.86658542386948, 70.67767450886389, 33.493515060793975, 27.616535655913818, 43.37420478943856, 28.59837551270762, 46.35837539549797, 60.97566050867881, 29.554078655858195, 5.765113897861974, 0.11215517252323129, 0.07698245181311524, 0.047085564132900014, 0.07762750550623863, 0.20738199293132753, 0.04965420331685774, 0.8164228426833308, 0.9868956693718511, 1.1908933616453603, 5.003629855571255, 7.986199644304092, 1.19256294302402, 16.39447181455551, 79.66762142796671, 80.3419396185106, 79.347516798204, 78.02451702856249, 71.12950801849365, 61.628793977922015, 58.67918729782105, 64.33425664901733, 66.6741426529423, 72.8240268461166, 76.91968733264555, 74.58981513977051, 72.05575220046505, 73.79884566030195, 71.44719646823022, 63.71855043595838, 55.014767877517215, 52.82852895798222, 56.422298646742306, 58.89273681948262, 59.20298453300231, 57.04745384954638, 57.95217598638227, 55.755527096409956, 53.320370643369614, 55.472026025095296, 58.998558444361535, 59.335952881843816, 56.61708354949952, 52.18440125065466, 53.80241817043674, 62.960238610544515, 71.35499723495977, 66.59045496294576, 76.35323432184036, 65.39483808702039, 70.68926903509325, 24.811158449419086, 40.90426475771012, 78.45507560237762, 61.96364671953263, 71.96697327398485, 65.45962779752671, 73.15250181382703, 71.69378019148304, 67.77464205218901, 57.13208290838427, 52.72919101099814, 56.87662286143149, 68.72019998488888, 70.0374181808964, 64.23660139883718, 65.73881818402198, 69.89362409037929, 70.97930477511498, 72.09893749606225, 67.87383879384687, 69.95709588450771, 68.61710440727973, 68.32857485740416, 71.76247658268099, 69.25692927452826, 72.19562392080985, 79.69767462822699, 67.97586748676916, 69.66897426113006, 65.33653597677907, 75.39224578488258, 73.56562937459638, 81.52890374583583, 74.95449358417143, 60.27311694237494, 12.528895601149529, 0.3778390994956417, 1.498133352687282, 2.239622867876484, 0.6817665876400086, 0.194232813833702, 0.13208031504144593, 0.02084081677059012, 0.11257002445598764, 0.02051159814600983, 0.009122042571224514, 0.12121289052189359, 0.1313316326348051, 0.8467394546155007, 25.255798332152832, 39.448186812862275, 30.479960018588653, 54.95553224317489, 37.8438981886833, 19.503522842161118, 46.69989224403135, 54.62053045149773, 67.95723622845065, 71.36632504001741, 39.730923021993334, 2.143453460547232, 0.026839302454684532, 0.09984925704737825, 0.0020745091211621563, 0.087712072436848, 0.027139635734079827, 0.01880023050152006, 0.05892972011239298, 0.054030358010242065, 0.04511594058825605, 0.017226302861085823, 0.042630195948145086, 0.04204149568273176, 0.1428991159604442, 0.05134693204214977, 0.04176601429560012, 0.023835699614738266, 0.038622035419628505, 0.04776956573609383, 0.011110071378249315, 0.013219247414400021, 0.03250828606166667, 0.018009315582833463, 0.025080422037130883, 0.018459815501926408, 0.031356411580477035, 0.07264032674532744, 0.04856234416365624, 0.03531183461628614, 0.03956483684540276, 0.11301756536047305, 0.014951720781203721, 0.052480876235471624, 0.04933961697163121, 0.026409925494883812, 0.020653730438601588, 0.034439429009874026, 0.02206370760236056, 0.030702524893586675, 0.046240599795935616, 0.04013093751704982, 0.034507028608312534, 0.06490764208137989, 0.01037364637839698, 0.008320010759146705, 0.011512439908279527, 0.03518692398023221, 0.05878725457155417, 0.019555311657548435, 0.08520328770241431, 0.05073832881246364, 0.011527125813787984, 3.35958531306636, 96.76580567513743, 106.65505009312784, 99.23324323469593, 85.55838600281747, 82.55089298371347, 47.85510870718187, 36.93240996330015, 42.543278125024614, 35.398080733514604, 49.75646195873138, 53.88312485910232, 37.51282661191879, 5.833991698680386, 0.28925791563045594, 0.029838126821203098, 0.05276585328242472, 0.025652164946340268, 0.5674530926250643, 0.8796631556845481, 1.9762065381773057, 1.7897140162606395, 1.3775525842943501, 0.9699824091888244, 1.161786310615078, 1.108685263222264, 18.12022251467551, 83.06335064672655, 81.77061588533464, 83.846145906756, 82.44145885590585, 74.87344957167103, 64.38204288482666, 62.26286080575759, 64.9851857462237, 70.71026940499583, 75.98391963589576, 80.68320935772311, 76.51660888425766, 71.9110010516259, 76.37138705099784, 75.68757672463694, 66.68701587184783, 57.945821746703125, 52.83752295278734, 59.44395534453854, 62.25936989630423, 63.79798627668812, 61.28914025522048, 60.982559957811915, 58.43893820239652, 57.59203572427073, 58.685568994091405, 61.79951513967207, 60.7667629180416, 58.95360415981662, 53.23253308573077, 56.09280778515724, 63.9245690068891, 74.2843880191926, 71.35913141312139, 80.92501563410606, 65.54454318938717, 75.20059093352288, 29.247037479954383, 42.51919869453677, 81.82601544164842, 64.899650619876, 74.29547263729957, 70.37767594860446, 76.48765394764563, 74.20969824637137, 69.62249417458811, 59.45817785878336, 54.44242738908338, 58.99633838284401, 70.22985750629057, 72.90562783518146, 68.1683381911247, 66.46153450012207, 72.10951220604682, 72.22897975675522, 73.68913696658227, 71.714811940347, 73.39043278847971, 71.76051539759483, 71.65746688842773, 75.38301252549695, 68.17482579138972, 72.32499153383317, 81.17890281061973, 71.70971285912299, 71.97052694136097, 67.96922299169725, 77.40668096849996, 79.26797113110943, 86.28505214568108, 80.07070772109493, 64.31064790295017, 15.694206164729213, 0.48125468735252663, 0.2908758013959854, 0.9419546228262686, 2.3262462067988614, 1.7262424672803574, 0.8359403115126395, 0.2764079551542959, 0.20450069028283321, 0.17967973264955706, 0.14146988700714805, 0.025652163031120456, 0.10045808244256244, 0.7414354600252644, 27.343162144384078, 37.00435407700078, 27.895163182289373, 44.59922375217561, 29.588062071031143, 33.64258081682267, 59.94772495761995, 63.500874580875525, 74.47424642501339, 81.48720895090412, 52.257416171412316, 3.458558724772546, 0.05130864679813386, 0.07384948928149478, 0.03654006891132843, 0.07426804907980465, 0.0754539455257116, 0.02800427129371993, 0.04100724634143614, 0.05059678640757358, 0.06395372471982433, 0.04444305109040392, 0.028348549291671767, 0.02556903100001716, 0.017882328848504735, 0.03529869620838473, 0.04604209109299606, 0.05196799569192433, 0.018896502855744575, 0.026034770323143854, 0.03819135994079613, 0.036154703702777624, 0.03750623218835362, 0.02696676799396594, 0.03988324213893183, 0.0358324411565498, 0.051531444318712726, 0.09156251461395333, 0.04199415527945084, 0.02742438486987545, 0.14773797243833542, 0.17052075314906337, 0.1298796968354333, 0.09796467309276904, 0.08506167634961107, 0.1516238921472142, 0.1242025946116736, 0.19373073512988706, 0.12194101878952597, 0.0940629872944086, 0.1289560705904038, 0.14935735973619646, 0.1215939273336722, 0.20092759491695514, 0.18752101027677137, 0.11374017779505062, 0.14034225154788266, 0.14013304825752013, 0.1845382009783099, 0.14477100583814806, 0.14718122570024383, 0.17701573850166413, 0.14360387088550677, 5.139587540780345, 111.45037512625419, 118.89792057775684, 113.12894559675648, 97.53218189362558, 89.99621052895823, 48.81301818355438, 38.00550376215289, 54.100879161588615, 41.765256389494866, 63.79613491796679, 81.17076781488235, 43.23698066896008, 9.393074397117863, 0.821865376445555, 0.26547566597019473, 0.19441908045161158, 0.15636859641921136, 0.8517042559481437, 0.7779454331724875, 3.246023135800516, 2.6230867687732946, 5.417137886247327, 13.779744352063826, 21.515928199214322, 5.835969553839776, 19.193924280904955, 89.56908010667371, 84.01002253255537, 86.65466493175876, 85.34311848302042, 78.27520355101555, 65.98979103949763, 63.76102970492456, 69.34821851791875, 73.93736808530747, 78.55861833018642, 82.77569186302924, 78.01460912150722, 75.45829065384405, 77.76522482595136, 79.80976812301144, 70.13184532042473, 61.22810425296907, 57.11179248748287, 63.367910154404186, 65.66869405008131, 67.48112324745425, 64.4279581500638, 63.948201287177305, 61.30878348504344, 58.24596935702909, 63.49562644958497, 64.65143126826133, 64.67733852324947, 62.859955372348914, 54.912331258097005, 58.92138581122122, 67.29460670102027, 79.39584039872693, 72.56304802433138, 81.92259988477154, 66.94094227206323, 79.04071684806578, 34.639866967355054, 46.38948371333461, 85.56091200920844, 66.88582512640184, 78.56819675814721, 72.86087359151533, 77.61298979482343, 77.20820903778076, 74.46273034618747, 63.05662301278884, 57.93236801701208, 61.238965295976215, 74.51813774724161, 75.77059761170419, 73.35299768755513, 70.9358762925671, 73.11604730544552, 75.79501828839703, 77.619171450215, 76.51690698439076, 77.12307007082048, 76.00874823908653, 76.29705813623245, 78.94880787018808, 68.21282571361911, 75.56247665036109, 86.09310703892862, 77.13082851902132, 76.5962016197943, 71.68518235606533, 81.44279203107281, 81.32599953682193, 91.71351048254198, 79.84201000582787, 69.45790367741739, 15.098624652431859, 2.119933948401482, 8.504506541836648, 7.847437464421796, 4.793828158609329, 2.394320902324492, 0.48513244056413257, 0.31163561969034137, 0.28823463666823607, 0.4070120034438949, 0.10503523562464023, 0.25295804975734604, 0.2599552976748636, 1.682836538360965, 40.6024109163592, 60.385692888690585, 45.50271818714757, 75.2370846656061, 54.759096022575136, 32.40223519263729, 66.99449046965569, 72.03910566145375, 88.77469816515523, 90.58846489075692, 60.860346747982895, 3.6867994839145295, 0.1273128886016146, 0.23551139319615982, 0.1315089207022421, 0.1394087427686299, 0.1070302741361722, 0.14455507629581038, 0.16687820425197003, 0.2724909782409668, 0.14539876892682047, 0.220861294637284, 0.16015448036693758, 0.06771320927767985, 0.20487120104653223, 0.12301397089275623, 0.13999106152163399, 0.14033331896268553, 0.18077404328411628, 0.1351047688794713, 0.11605259887273274, 0.1597200472268366, 0.12522314630088308, 0.07055647566073364, 0.16748300002467248, 0.11898173605121913, 0.08996741996417124, 0.22778020240366462, 0.11642225161795655, 0.13230632630086717], [0.02923115727401549, 0.012705159324762082, 0.05534226442837427, 0.03656862483870599, 0.003312464832561091, 0.037660771274879094, 0.03829825601931061, 0.039221215767846, 0.015734123505441653, 0.05681543618500714, 0.02862391193517514, 0.06453789740560517, 0.048209112513089375, 0.012190782036932727, 0.08233860150099763, 0.0275340331192579, 0.02459470697137858, 0.032562846843633926, 0.03422199410476512, 0.05840367434786693, 0.05324334056387025, 0.05421292059303773, 0.18606674557010974, 33.358503157092684, 98.18431515847483, 83.6480583683137, 78.59027970221736, 65.89585027387066, 29.69687842553662, 22.29119250851293, 31.04199055702456, 48.4547528143852, 69.3883208305605, 59.58626677913051, 33.15737970413701, 3.8012527746538964, 0.0934246828358981, 0.011445206116824862, 0.07485272738361552, 0.06888313279036554, 0.391010357247245, 0.43836865634206806, 0.23819840062529812, 1.5476183425034247, 1.728453090594661, 1.5161456119629646, 1.9389208550414734, 2.0674972524566035, 25.763486393036384, 82.9503942305042, 79.24131470341837, 76.70381576784196, 79.40477555797946, 69.2019219552317, 63.95604994989211, 57.74000713902136, 61.484297783144065, 58.609812336583296, 65.22523480076944, 67.92473546920284, 75.39746253721177, 74.28374475048435, 72.54578175083284, 70.96771809362596, 72.0181837389546, 63.63544717911751, 54.887961572216405, 51.17065291250906, 52.08904058702531, 49.822985356853856, 53.365952507142104, 49.52107267995035, 53.82628579293528, 49.82296966737317, 52.988871528256325, 48.369260834109404, 52.00769062965147, 49.722027470988614, 53.451456254528416, 50.94513623945175, 54.112438386486424, 62.64325618743897, 75.87285380209647, 69.08029710092853, 73.61043853144493, 64.71645632097798, 79.74610805511475, 31.331226133531143, 43.235294049785985, 77.08747063913654, 63.55303425942699, 71.31581275693833, 66.40242438162527, 71.46850278300624, 68.01436162764027, 64.52487991702172, 54.293800938513975, 51.387638430441584, 57.01279578670379, 68.2666955455657, 73.94307905627836, 59.91197255349929, 64.66121365947109, 73.43703054612683, 71.0881034789547, 66.78623614772674, 62.98144686606623, 57.60596013838246, 61.46523114173644, 64.14107207329043, 73.11020297388878, 68.55412683179303, 69.6507901530112, 77.11170304206111, 70.90202623798002, 62.68970097264936, 61.72434683768981, 72.85827698246126, 73.8105421681558, 76.72454941657283, 71.15747451782227, 72.02378488356068, 64.2077092201479, 17.815695578052154, 0.6731168421045427, 1.2892178662361637, 1.7896524840785613, 1.0745520625383624, 0.13606213363668612, 0.10120816679010469, 0.03429299513358743, 0.057902082109883915, 0.14039082152228202, 0.10461576418170046, 0.09886700209350356, 0.13199831299003095, 3.206324827286505, 42.591746853243926, 54.521125824220725, 57.28072112606418, 46.06735121819281, 21.750554576996837, 33.87312204607072, 53.34041395495015, 55.65092532865463, 67.22447472233927, 65.0301988663212, 22.557207653599402, 0.19038758871536102, 0.0908680942149893, 0.07400057714192138, 0.04571991664687953, 0.059437969654438004, 0.006370985403566832, 0.07993884639994753, 0.02815406255033468, 0.058522134523598425, 0.04599099685888618, 0.016890446084641644, 0.02418354949763706, 0.028947865620495814, 0.016063859239370835, 0.07705021995089709, 0.03237455775360427, 0.03015463413189977, 0.047093696156216246, 0.07123322241128453, 0.050489101258497086, 0.048370351038512685, 0.06623894967619451, 0.03434511975595548, 0.03593759055459692, 0.04726421583684222, 0.009602687092527989, 0.046451584240722085, 0.04905017746251918, 0.04053154021441456, 0.034505921611261946, 0.04811080044976646, 0.027600816834057053, 0.017269927737933975, 0.030990483937785033, 0.08941453430921802, 0.036824712710034464, 0.02554630308652357, 0.017215351634208235, 0.0619651175164167, 0.0433363528141091, 0.0480398262340215, 0.056429339362488645, 0.04786138520425847, 0.005951304722862739, 0.037444186727366144, 0.05389596703612516, 0.0172957755444992, 0.20614211026939655, 0.0974187281944098, 0.107652276243654, 0.06634932762432484, 41.02095527033652, 115.47311090653943, 92.85175877232706, 92.11817356847948, 81.60293456046813, 42.36154687020087, 29.61283183866932, 37.46280070274107, 50.82329173241892, 53.18306415311752, 53.92533348452661, 36.524244200798776, 4.2823697193976376, 0.13839490200963714, 0.02446945542619834, 0.0459057197815949, 0.18702910522059088, 0.5349351730077497, 0.9324539681115459, 2.224983601800857, 2.4894548039282522, 1.6343884025850606, 3.0069791886114308, 0.7767152798271949, 3.665575293763992, 29.187788117316465, 85.74296489838632, 81.30011973842498, 80.6542387316304, 83.17900565362747, 72.7589782591789, 67.00964650800152, 60.11690855026246, 63.92221950715589, 62.228002702036214, 68.80719815531086, 70.27832231213971, 78.66150994454661, 76.30880171252836, 72.89483347246724, 73.57994602572533, 74.73133425558768, 66.77872088647658, 58.17429588687036, 54.69603215494464, 54.01307298291115, 52.325951745433194, 56.2904481733999, 52.565114344319994, 56.18659950071766, 52.62567966215072, 54.84672961696502, 52.09452798289638, 56.29258978751398, 51.702428248620805, 55.90669916522119, 52.18761367182578, 58.076197408860736, 66.58494795522383, 75.8287428271386, 71.59298312279486, 76.25195087925081, 66.33935266925444, 80.86214004024383, 34.67161070915961, 46.49120253901328, 80.11055115730532, 66.24956961601012, 75.04504542196952, 69.79633362062516, 73.15079950517224, 70.59690506227555, 69.55124039803782, 55.858042163233605, 53.01395116313812, 60.01259311552971, 70.0873185742286, 75.39631720512145, 63.76085712063698, 68.21488103558941, 75.82255332700669, 72.95377885141681, 67.94692039489746, 64.54167942846975, 60.721090839755156, 66.02841854095459, 67.47770294066399, 76.50447307094451, 69.41432614480296, 69.50785113919166, 80.3913850169028, 72.16833206915086, 65.37508110846242, 64.39382176245412, 76.62167349169331, 75.25222501447125, 78.86341787153675, 76.80316940430673, 77.80805710823306, 69.45213779326409, 21.059593769811816, 0.8569732861172769, 0.7749310916950627, 0.8340353879236406, 1.4138022714084195, 1.2264509955721519, 1.0288115879220348, 0.34652877959512896, 0.7252977259697453, 0.02224193412750479, 0.1768480878203146, 0.07438090149193041, 0.05095340799720538, 3.4060376978689626, 44.730019107941665, 52.245347038392104, 59.43160772323609, 39.76444359748594, 28.32697887574473, 42.052464100622366, 58.939750348368, 63.195408236595895, 75.59616196540095, 79.14283183313186, 32.317759106236124, 0.45139904584615465, 0.12379138925743681, 0.031838602641777645, 0.01685708678597885, 0.032304763313262694, 0.03549846512595973, 0.08769431451876318, 0.0861210227313061, 0.03742303503977676, 0.030639947001491825, 0.05450103860048037, 0.020100013578250524, 0.033267475364188996, 0.02887041796179068, 0.08052105023976296, 0.03995578300448195, 0.016341869674262502, 0.04902297368032798, 0.023036315594048753, 0.061133789544504505, 0.05778603511111391, 0.012066572371329512, 0.07777493912726641, 0.02696753408189022, 0.04264261040295805, 0.036834798257557616, 0.056458186403277426, 0.038867501481886835, 0.1288875823299731, 0.2092188572691333, 0.19633387125307517, 0.08625112744348665, 0.07013482852808892, 0.15049930571788742, 0.23518778233518525, 0.17927577448708398, 0.08338941366321619, 0.13949410028515324, 0.14828148117709547, 0.24541079667547058, 0.12586276843062333, 0.12170708618096768, 0.16335412319148743, 0.1366682777241353, 0.10818274616594277, 0.11361100771013768, 0.13974983575603656, 0.3681909881772534, 0.277854788808092, 0.16011962336638283, 0.3107844347194318, 48.129882504863126, 128.20615999160276, 106.1246358194659, 103.82753110701039, 89.76330803286645, 49.66670636207827, 34.423626699755275, 43.8399274118485, 64.43860346271147, 88.59196278356737, 82.7653838742164, 48.26212521522276, 6.233758195754021, 0.24085022929695346, 0.1302253097415932, 0.20322512324538924, 0.3516371458047821, 1.2540686491035646, 1.4991849156156665, 2.9634720135119657, 5.830350758567934, 8.271893320545074, 10.20288105933897, 7.282529867464497, 6.300330623503655, 31.094269867866274, 90.46050148625528, 83.47007689937469, 83.20799981394123, 86.92978782038536, 76.60177923017933, 69.50019467261531, 62.62028678770989, 67.15573126269926, 64.02728019222137, 71.46137975877332, 73.32175993150281, 82.88136836021178, 79.14184339584844, 72.29398127525084, 76.0526317165744, 77.59124417458811, 70.1394860975204, 61.828846623820645, 58.40650020107147, 57.66598809149958, 55.48344796703708, 58.304008668468846, 55.358371426982266, 59.32433482139342, 56.17373412655246, 57.0711253535363, 53.061215723714525, 58.995773561539195, 54.77755861897623, 58.52019402288622, 54.20599475983651, 62.553167189321215, 69.79496863580519, 79.8043474074333, 75.36839777423491, 77.70798960039693, 69.6575366297076, 82.08067140271588, 36.662268484792406, 51.49365225145894, 80.21853400814919, 70.02146982377576, 75.69851229267736, 72.38775730133057, 76.3764782874815, 74.2738760671308, 72.13109308673491, 59.74400097324003, 56.77471183961438, 62.38725093103225, 74.52824961754584, 79.76954813926451, 65.82047016389909, 69.83550240916591, 78.08682780111991, 77.29559160047963, 73.55423096687564, 69.42477533894201, 64.26434824543615, 68.9884901046753, 72.19094845556444, 81.0700648830783, 69.2055226910499, 70.52926771102413, 83.19777811727216, 75.2046545090214, 68.89150557979461, 67.36975931352185, 81.37094205425632, 79.01139320865755, 83.85212359889861, 80.6093511273784, 80.27988772238456, 75.00633162836876, 22.911658517775997, 2.0426800486541565, 7.857202695262048, 7.203816233142731, 4.758891117188239, 1.85108783264314, 0.8001139952290444, 0.2398575632081878, 0.8878799696122447, 0.35094003643720384, 0.3787496103154075, 0.5314971542646808, 0.22202798525892922, 6.316098061300093, 65.35427685706847, 75.25974812046175, 75.20008887014082, 60.686475922984464, 32.56847504646548, 48.81513626344743, 68.18893063452937, 76.03005455386254, 87.13956402194115, 89.10534612594113, 33.607153969426314, 0.45117099679285483, 0.19371426423951504, 0.2086423301408368, 0.1394428336812604, 0.19927589403044796, 0.14112359994361479, 0.1581175751503437, 0.16498670252340455, 0.14844910121492802, 0.07575366976520709, 0.23122693922731186, 0.11947492047423318, 0.1464614094865899, 0.11625620206036877, 0.13659268016776732, 0.0777534963262658, 0.1644729333178651, 0.19618279871440705, 0.22428868007996391, 0.08775006273701307, 0.07515013037670044, 0.1592760839529576, 0.14789662924745392, 0.15466388224834396, 0.12833174723651142, 0.15367847867310047, 0.17686924716878324, 0.10400294746843078], [0.021990959893070886, 0.04247450389929357, 0.043121526438382365, 0.062155934696596485, 0.06938219310775881, 0.013876685876429323, 0.0331188926112748, 0.011693722166631733, 0.014717552600608719, 0.0937105562057226, 0.05919739123313658, 0.026109858431042205, 0.06099883166532363, 0.023250745519274668, 0.011883374893166607, 0.08036339700582527, 0.09937026823360114, 0.045484145427302974, 0.06180388282143301, 0.0528380838823655, 0.10018235973773465, 0.16409192714960347, 1.4122784305964748, 61.56196071255592, 92.1827357815158, 82.99765094634026, 63.542553686326556, 37.20534809174077, 65.57329808512043, 35.33301645709623, 39.77869356832197, 46.85102116677069, 51.223204828077755, 45.657067375798384, 4.792441600753415, 0.06606067335533519, 0.043280573952342236, 0.07820150454438503, 0.17897713809244095, 0.20588507244904197, 0.7330338656902314, 0.8974212576304713, 2.2046757753818267, 1.8539047072972021, 1.7783015125220822, 2.9480497442906906, 14.884935886629167, 57.147780233813876, 88.80897968046128, 79.14245528559532, 77.80270699531802, 73.4364971037834, 67.92994437679168, 58.901428791784475, 60.48485825138708, 61.58824059271044, 57.76913858229115, 56.49797685684697, 62.32134334502682, 69.03897100879301, 72.96951540054815, 75.52097797393799, 70.58720111846924, 71.3406099811677, 71.23623571088238, 63.70690884128694, 53.1885790055798, 50.893082464894945, 51.678360585243475, 51.29343878838324, 50.46796029613864, 50.61619058732064, 49.407269031770774, 52.302578341576364, 51.35833832525438, 49.380934238433845, 50.53692340850831, 49.10120648722495, 51.352195893564534, 50.169973911777625, 53.28048013871717, 55.563895779271284, 64.4378464452682, 64.35580222837388, 71.41061644400321, 65.09685562502953, 79.055676767903, 43.50418036983859, 40.0942325592041, 71.26320592818722, 62.7366635107225, 70.02138353163197, 64.72952958076232, 71.19003803499284, 65.16536766482939, 62.834620783405924, 51.54113254239483, 53.88588620770363, 51.55191121562835, 64.4103467079901, 69.58236048298498, 70.04847926478233, 70.4883103216848, 72.33982593782487, 66.75679483721333, 64.18968592920612, 52.52843626083867, 51.664914700292776, 52.58127058705976, 62.811368973024436, 73.90259235135971, 66.81159819326093, 64.0441228497413, 74.14137055796962, 71.33534616039645, 65.43794493521413, 57.24971478985202, 70.45861797948038, 73.82088153593003, 77.22877010222405, 74.2721188452936, 71.42468206344113, 60.97196171360632, 62.810000065834295, 23.448425069932018, 0.81623628495201, 1.5478817541753094, 1.698410186556078, 3.519837178530232, 0.512088377990069, 0.2094975140907111, 0.22247110583609153, 0.34915229365710293, 0.06631457787607947, 0.21588379156685647, 0.051261007620562474, 0.021961838975849173, 6.367705666249798, 32.77010252398829, 28.930080552254957, 38.72437223311394, 29.6142085905998, 25.15977086559419, 29.243646590940415, 42.60713823380009, 63.39489998355989, 73.43018993254631, 66.30924455581173, 7.157322908601454, 0.2877397132256339, 0.06261885864660144, 0.058751390165378975, 0.009020458354855017, 0.13236411997387487, 0.010692771794574877, 0.030371655349529562, 0.011425033106558747, 0.04506478889755184, 0.04256721585988999, 0.07826886665556701, 0.13776173034021932, 0.04887308857794251, 0.03135607450179035, 0.06144258043458385, 0.02410824305468029, 0.06112091543693697, 0.020124765879084027, 0.03560526544348367, 0.004340851446613669, 0.05315430199487075, 0.10231137936634403, 0.033163183984617074, 0.08043059823854316, 0.07969745209500675, 0.01345974539646939, 0.04887161002824864, 0.02456138214667238, 0.02053120233599217, 0.08741843093547129, 0.046163048715360706, 0.0145591763711925, 0.09264944016092247, 0.03289724039214273, 0.015263974388700821, 0.006753537154215719, 0.05367997620675353, 0.04232312492545574, 0.08599036643582006, 0.037057729843523235, 0.09329981816511962, 0.08020074887862129, 0.05735887597585398, 0.08974320901137206, 0.07303929767541348, 0.04771577104205086, 0.0570041198103178, 0.031701880845151124, 0.08825595655869092, 2.2357286897397812, 76.07837815438548, 102.621716068637, 92.69069840831142, 71.53078217660227, 47.5931885165553, 67.85956921116, 32.571987528954786, 30.157509811462898, 35.23245865298856, 48.2968460359881, 44.943196004436864, 5.587512898829676, 0.05718493954308572, 0.03174355219779236, 0.2153097772069516, 0.3983213488132723, 1.00946658080624, 1.9006344772154287, 1.405540656658911, 2.027438331034876, 1.105120196457832, 0.40778979719165837, 4.341125843986388, 17.16183647032707, 59.61045995835335, 91.0265387258222, 81.40812612348988, 83.20456381767028, 78.8840103149414, 71.34639939954205, 63.58531536594514, 62.711532885028475, 64.58161700156428, 59.80871615871307, 59.36268775693832, 64.09367022975799, 74.20447364930185, 76.72942100032684, 76.32483636179279, 70.90857659616779, 73.87831287999308, 74.24869445062454, 66.82036861296623, 56.77156609873618, 54.48263168334962, 54.66233899516445, 54.012045321925996, 53.550829502844046, 53.7894312027962, 52.001085358281294, 54.805682013111735, 52.90936508486348, 50.449415329963934, 53.93380188172864, 51.63545770029868, 52.91665677101382, 52.25091288166662, 55.49848633427774, 57.55175690497122, 67.62044583597492, 66.95999714636034, 73.50076121668663, 68.73064917902794, 82.405224000254, 45.644837425601104, 44.26133509605162, 74.64439884308847, 65.70973773156443, 73.86023859823905, 67.36869242883498, 73.57001458444904, 68.00417915467294, 64.91501846621114, 52.8395547405366, 55.26215960902553, 53.653607368469245, 68.0832306031258, 69.65548130773729, 71.59156322479248, 72.91346473078575, 74.01716478409307, 69.37851490512972, 67.48452002002348, 55.12022864434027, 54.609610572938, 55.626096725463874, 65.88453031355336, 77.02354385006812, 66.89847869257774, 64.53498786495578, 77.81510952980288, 73.75470330638271, 67.23679096468034, 59.692068792158565, 73.40294514932941, 75.13383219319006, 80.1851075695407, 76.50049578758978, 75.42499757582142, 68.0446501701109, 69.45016091869724, 28.13471017345306, 2.0744141071073474, 0.8019583059414741, 0.40049958193013746, 1.4407022537723666, 1.183011603932227, 1.087678274320018, 0.6910593567355987, 0.5478880650574162, 0.2653563707586258, 0.36348680995645066, 0.10278127471645994, 0.13564689865996762, 6.032163077785123, 39.15916696671517, 30.74718717605837, 35.8128753016072, 25.979720777080907, 38.733456442433024, 40.31213983412712, 49.895580584003085, 70.40292816777384, 79.8826143818517, 79.98444695626536, 11.805051603624898, 0.3122379793034446, 0.07142304367716275, 0.05671005696058274, 0.020720924010440227, 0.02923076656917411, 0.02308241876533195, 0.061741285777140054, 0.05544015131289921, 0.04443554342874596, 0.027471091335399017, 0.0205395661009055, 0.04936674414502998, 0.018563488265499473, 0.03726798267434201, 0.02487215911969543, 0.03111664712759516, 0.049153472927789536, 0.01879723509773612, 0.005337887588182404, 0.021045797001270038, 0.010646246317323419, 0.06030966279908054, 0.05467164638121763, 0.04135530306807449, 0.022283220520964073, 0.03446176430330642, 0.14351054605457092, 0.10150848091730189, 0.07513234181509865, 0.21132783603764352, 0.20546308057683133, 0.1368490744742655, 0.14667344730227225, 0.07198527560479219, 0.12828578196105458, 0.1834754072009556, 0.08668637263678736, 0.1307521177636039, 0.34711410141279625, 0.12943473764725272, 0.22234692298356565, 0.22871901251135335, 0.14817107258544815, 0.14691628185251068, 0.15376616509691363, 0.2361686659916755, 0.1787281748388083, 0.2138593122963944, 0.2871137581044628, 2.8803167852663227, 85.2081967938331, 115.38889761893981, 103.63516238427933, 84.03576112562611, 53.56797026049707, 75.954219448951, 47.57146643054101, 56.420286470843905, 65.0668377261008, 72.38235227523312, 68.31683912584859, 7.553534757706427, 0.225443251190647, 0.1540215175238348, 0.5008675494501668, 0.7091110848611402, 1.3244067973667577, 3.1620312169674905, 4.3215527265302605, 6.096247742252966, 7.789032391963467, 6.822225018855065, 8.180468265087374, 17.353155959037043, 63.010099780175, 94.56661116692328, 85.34719774799963, 86.27534035713443, 80.41423674552672, 74.11367862455307, 65.80820883474043, 66.31317477072439, 66.4867788745511, 62.8192372475901, 61.75480796444801, 68.42717539879584, 78.57138172272714, 79.2468217111403, 78.5804973110076, 73.57279946727138, 75.00044022836994, 77.5567037828507, 69.2282175248669, 59.2557914026322, 57.496965316034135, 57.607835031324825, 56.52246813620291, 56.56262536202708, 58.1860629973873, 53.72163303436772, 57.664403453949966, 56.32240764556393, 54.05141807371571, 55.77324444247831, 53.53396723347326, 56.443946207723315, 54.67496118237896, 58.231558569016, 61.60668357726067, 71.80234355311241, 69.96057894922072, 77.58520372452276, 72.46067416283393, 85.2615410281766, 49.426359207399436, 46.924216516556285, 79.0038622579267, 69.38341002310477, 75.65280883542954, 71.12350679213002, 77.26274567265665, 72.57552900621968, 69.2112179725401, 55.79591574207429, 59.04789401638893, 55.32574122951877, 69.90993330555578, 75.15884907014909, 74.76796919299711, 75.79644603113975, 79.0358138853504, 72.93212736806562, 71.20171100862565, 57.769715170706476, 56.190623852514456, 60.56141115004017, 68.73679945545813, 80.34598750452842, 67.8455977286062, 65.78904805644866, 79.82486924817486, 77.85540796095326, 72.19567098925191, 63.086762505192915, 77.13786525111045, 80.21078340468868, 86.13631586874686, 79.502120940916, 80.60098863417103, 71.18958304005285, 72.34018679588073, 29.560736879225704, 2.178992585789773, 4.066924712350292, 6.17509424686432, 9.999198259845858, 3.2183895476402777, 1.1408453891354224, 0.5612108243569252, 0.9885616961025423, 0.34394700200326983, 0.46667290851473814, 0.15544841756984112, 0.23803012175185068, 10.582131108930035, 52.54600847921064, 43.679816261414565, 52.96528631641019, 42.56676527761644, 38.664120704896995, 46.10729663602768, 61.51499425211261, 83.46006701069494, 90.44765180157077, 90.06629543919718, 11.622630992243367, 0.7007959665309998, 0.197638840745053, 0.21001917400187065, 0.088327486188181, 0.2697383936855101, 0.13459904359713679, 0.2914220220859974, 0.14993961720216661, 0.0908288092262322, 0.10302362663130607, 0.24509994883931455, 0.22950321075416383, 0.097998526518143, 0.11824785446327542, 0.1833193091255042, 0.10256654793216337, 0.15516763102383385, 0.09940406803282038, 0.22891343030477726, 0.13506362995793744, 0.1110322638264587, 0.13450996289330144, 0.1504229114300782, 0.16443295884997616, 0.16773306644491612, 0.12078806412436309, 0.23754036174185816], [0.03014060323156657, 0.039797681609108564, 0.03825349733233452, 0.008307167295096143, 0.09795688197857912, 0.004550673831779991, 0.07705598093208767, 0.04407150610800713, 0.0939673105735452, 0.13534957993655436, 0.05937305902461371, 0.03839583646866583, 0.09478452720589216, 0.015846332403711014, 0.07787255405057823, 0.03775992986535834, 0.059962073386076, 0.016423655305838874, 0.1595897356709165, 0.0682738324206683, 0.16898133010873873, 0.4357704844686293, 13.593943638186301, 93.3635574771512, 89.45345647873418, 84.63691142297561, 75.10706593913417, 43.15572092610021, 43.83994702369937, 38.73084806626843, 50.1667614906065, 68.88821863359021, 43.71500384423041, 16.003228137570044, 0.08287958214960753, 0.08683281800439281, 0.11411233564778683, 0.24822134344327837, 0.43887114873336214, 1.2146087471515903, 0.35038400982176104, 0.4835296620524699, 1.3232091261494545, 1.7421311308299343, 9.093076817450985, 36.600051849119126, 69.60492980095648, 79.12855440570463, 75.77699107508506, 78.06864369300105, 73.34778093522596, 67.77402231770178, 60.95402471480831, 60.86651271389377, 61.61031176967006, 60.87492619791339, 61.01357021639424, 57.29870127093408, 56.86772300351051, 69.43181207103115, 72.76272804506364, 71.61196739442887, 68.35006160120811, 70.64869603803082, 72.0043142380253, 64.38276852330854, 52.83270235984556, 49.55781744372461, 50.58416835723385, 51.044050570457216, 55.355982703547326, 53.46297233335434, 51.28429966588175, 47.7148525945602, 51.36647724336194, 51.55373904012865, 49.48973294227354, 49.857729711840236, 50.865257170892534, 50.492435886013894, 51.72654690281038, 49.64822415382632, 50.493785181353175, 49.97915060289445, 56.86720917301794, 57.74155255286925, 72.44940911569904, 50.21729338553644, 41.198014982285045, 69.48176737754576, 60.59470030569262, 68.78231463893768, 65.80478460558, 68.64697717851209, 60.35530236459548, 58.6602657841098, 49.29978824430897, 51.038190549419774, 49.92432763499599, 59.984348127918864, 69.06802008228918, 68.98976879735147, 67.42778685785109, 66.90884159457299, 62.77628729420324, 53.89200118280227, 51.15955652729158, 51.351858569729714, 53.19502345977291, 64.07720804214478, 72.33970042197936, 66.07222357103902, 63.737315054862734, 75.29239008503576, 68.66592222644438, 64.43559892715948, 56.586481217415106, 60.72461705054007, 68.70123924747591, 72.43692813381072, 72.67270964960899, 74.93567405208465, 71.01044054954284, 62.38765885753017, 69.32986967025265, 46.669615468671246, 6.6257726184783445, 0.7594204465708425, 2.2753473251096668, 0.313311881355701, 0.4148212892393912, 0.9613164225893637, 0.19686976507786783, 0.2791279043641783, 0.0220632498648258, 0.05717778428187294, 0.04497959992037185, 0.30660107371307194, 18.576894267912834, 60.877271775276434, 53.065530330904075, 48.79348870246641, 15.067678132364827, 24.166212927910593, 44.41940661399595, 57.77685388442009, 64.82971868207379, 69.69578758362802, 53.49168800538587, 3.2687601350968887, 0.05323209439314181, 0.05732361294869935, 0.0422848703249568, 0.040596251661378535, 0.03663653470275383, 0.07830796012234303, 0.017339846667563243, 0.005030329620856191, 0.02234999274444436, 0.050726044592597795, 0.053821342411421, 0.025502921442591378, 0.10981618351633511, 0.02338431677931259, 0.06671698088006628, 0.06173676968882642, 0.035965181211189884, 0.03075689032313324, 0.049290277078867926, 0.013956098550660236, 0.08561686026833712, 0.021074249506777814, 0.03779196000147251, 0.012951083124555167, 0.026958706833782698, 0.054844923978371006, 0.06667184297956767, 0.0246753377254091, 0.03846629740550153, 0.04277536194891699, 0.05908733504193445, 0.02672107785098976, 0.19024437623879603, 0.00903913270561926, 0.08115570811975388, 0.030065497886689923, 0.06258245797887926, 0.009296673271174153, 0.05989471510533364, 0.06558471824973822, 0.0590228955561836, 0.06176932842560834, 0.07406649134692646, 0.024529216029951652, 0.13330122936637173, 0.12397716557907483, 0.19776049550742875, 0.5654787921136426, 19.606018297133907, 111.45572523916923, 97.83909167012861, 94.50364928091727, 82.71381255119078, 49.57979056142992, 66.8720889860584, 53.015163175521366, 40.08205359981906, 62.419171179494555, 44.975696763684674, 18.875886740223056, 0.05295562858302748, 0.0753669485810303, 0.23350438073037133, 1.0313945912545728, 1.5452359929200143, 2.432578475244584, 1.1565468820833391, 1.049254981260146, 0.8792046060965908, 1.9398015497192262, 11.464779127028681, 42.4950800403472, 74.42871555205315, 84.05770286437004, 78.41328667056176, 80.36295567789386, 74.4408513653663, 70.53242129664268, 63.159522471889375, 62.05468100886192, 64.85050332161688, 64.85256256595736, 64.47741139319636, 59.129467548862586, 61.00292882611675, 72.04131003349059, 74.3585600391511, 74.20867843012657, 69.02370514408236, 73.72839989200716, 74.90369889043993, 67.58634474969679, 55.642339260347434, 52.81299637209985, 51.3868421892966, 53.84004546749977, 59.89678121382191, 55.790632309452185, 52.62657788492019, 50.89056822561449, 54.024400787968794, 54.25974299830776, 51.225652387065274, 53.17605487761959, 53.98158811753797, 52.91648026435606, 54.49856435098956, 53.960505377861764, 52.80358660605646, 52.97309967779344, 58.98417511293965, 61.209653423678496, 76.44558260517736, 52.5200855347418, 45.720766667396795, 72.14005178020847, 64.09236408049061, 71.7340393989317, 69.69798411092451, 71.71413729267736, 62.33066681892642, 61.84787011915638, 52.442665792280636, 53.37562114961686, 52.25778487420852, 62.66037733324113, 72.08686444067186, 73.43976836050712, 70.81238439006191, 69.24664481993645, 65.64791725527856, 55.70380280094763, 54.34837679709158, 54.3622737546121, 56.06572774148757, 67.03606759348224, 73.54993204916678, 67.50183336196407, 63.6641550064087, 75.92271497172695, 70.57162930888515, 69.03530751505207, 58.90588068193006, 62.65980466719597, 72.99146498403242, 75.47201894944715, 74.43656813713812, 76.93509440268241, 74.59492991047522, 67.11796668268019, 73.71346350639098, 51.081183648878536, 8.57005326978622, 0.4127788069027086, 0.6615958603159074, 0.18979756311783869, 2.263829530246796, 1.4502456255497471, 0.9940358539742808, 0.7781628182818814, 0.5387890242761182, 0.14242129160031197, 0.08402747297359091, 0.07702771228768172, 20.392041667815178, 62.769179959451, 49.43246633775773, 40.96743452933527, 22.023892787195024, 30.124893342295003, 52.10578126292075, 66.16221843227264, 73.18757564790788, 79.123486703442, 69.85633803952125, 5.14964351730962, 0.007245672515578449, 0.10837499593054095, 0.04020435555327324, 0.014587231468589557, 0.04766542374366715, 0.03215085624927475, 0.023053062276073524, 0.018047097124039166, 0.06162624618399048, 0.07297447897614011, 0.06782930224172531, 0.11185579302330172, 0.08398882383781095, 0.04392822468352895, 0.020125445782116825, 0.038572764474778407, 0.09537929488766579, 0.016003025154913628, 0.06982887599376902, 0.07925055470437774, 0.10054019940716606, 0.07085289806127548, 0.020569433953853387, 0.038098153853488546, 0.1229907890721675, 0.029733036794970115, 0.23690181213521191, 0.14058557639439262, 0.11240492484742597, 0.117413554070217, 0.2140465748286055, 0.2323529352584193, 0.36672555390865574, 0.11375901589710867, 0.162673132313836, 0.21713669772350022, 0.12449301088288908, 0.1506426560902788, 0.2705362589368897, 0.18362568300818244, 0.2454669049550449, 0.15045072042172955, 0.216906396371703, 0.10458181882577558, 0.20541918373877005, 0.17854540158183346, 0.29577971406040654, 0.7656067597769922, 22.158494803213305, 123.7656133405624, 107.11500290901431, 107.69967925164008, 97.05174646069928, 61.03819093396587, 52.37366345620925, 46.945597356365575, 71.74457488521453, 94.41953013020178, 63.90773419410952, 22.597645328890895, 0.2150292204873216, 0.2415570526594116, 0.48791698630779023, 1.8335354712701615, 2.392174140099556, 4.954237899472637, 3.2503958430982407, 2.946576894290986, 5.016052492203252, 6.465423184056436, 11.258540903368305, 39.42367592165547, 79.24167556147422, 84.85424995422363, 80.64411117184548, 83.09931878120669, 77.41095635198778, 73.47848215410787, 66.4073508785617, 66.48283297015776, 66.97817340973886, 67.87596471848028, 66.93636878844231, 64.01952958876088, 63.73058034527687, 74.2429599454326, 78.22788407725673, 77.38272313148745, 69.02615270306988, 75.30036034122591, 77.83399966455276, 69.30364470328055, 57.72200345993043, 54.324979859013716, 53.74136255633447, 58.49072917815178, 62.795055835477775, 58.407763204266956, 54.92719311867991, 54.54644080131285, 56.39863498749272, 56.454179671502885, 53.843371637405895, 57.21414673712946, 57.04910124501875, 55.736899760461625, 57.892410832066695, 56.0929411457431, 55.76803945725965, 57.85302631316647, 63.3885653557316, 64.84309788673156, 79.44117515317856, 57.78006238322104, 49.939577810225956, 73.47809776183098, 65.96976341739779, 75.23640217319613, 73.70171993009507, 74.802839063829, 65.90267519797048, 64.72894122523647, 55.574446955034816, 56.42753893329252, 54.640824794769294, 66.67230698370165, 76.72155272576117, 76.41010868933894, 72.69678515772667, 73.55636473624938, 69.1358692415299, 59.34407218810051, 57.04834814994567, 56.75621394188174, 58.9989036129367, 70.2892029669977, 79.85555002766272, 68.3252408427577, 64.7840230695663, 80.54892309250371, 73.28709402391988, 71.20417425709387, 61.58069003012873, 66.5263085211477, 74.13914265171175, 79.67101035579559, 77.21632049929711, 80.32633642996512, 80.09733276982462, 71.49453947621008, 77.66808340626379, 52.89580152880762, 7.781362197091503, 2.8300128781026412, 6.80170415870605, 6.964041744509052, 3.026262050674808, 1.8691681205264985, 1.205750809561822, 0.8085504618863907, 0.7465015688250143, 0.23334550941663407, 0.26333328576818593, 0.48487095943381714, 29.007231612359327, 85.21369595681468, 72.22680676367976, 65.00417394022789, 22.577829514780355, 37.79583738696191, 62.26985046940466, 76.59573093537362, 84.27468838230257, 89.95067181125765, 75.62214374542236, 5.585470324562443, 0.22214433869286893, 0.11959982344940787, 0.1313730320262332, 0.26846377659709225, 0.17590152490283215, 0.17987631081092745, 0.11695252235738501, 0.08396274620486845, 0.12249795704959862, 0.15742046578276545, 0.28206664828523514, 0.24907128735175058, 0.222457300931696, 0.11581051508866011, 0.20256501592455373, 0.1327192936573298, 0.21772770391356563, 0.19087762451700627, 0.1552038976261693, 0.23841514222083554, 0.18843700628607504, 0.1641501191883318, 0.21439940428301213, 0.14646050550283926, 0.15578056265029216, 0.14227268586476005], [0.03542325061355387, 0.018462839634007504, 0.053614502502304894, 0.021823653951287273, 0.07129673876108662, 0.009129015886555276, 0.04542832443070027, 0.02421313198283315, 0.024299675020419305, 0.061743089914201736, 0.0616153332615091, 0.02097282138082289, 0.0544181976827883, 0.04061451136705376, 0.1277475975333683, 0.03648942283865425, 0.04325701291823099, 0.04323854636881621, 0.03639501016286593, 0.09721565360744154, 0.10249715568798204, 0.06130661131934293, 42.50397597589801, 92.24840410294073, 85.84193414257419, 86.06014344000047, 59.27275957599763, 28.025844789320423, 19.462530151490245, 30.16361498063611, 58.02805423736573, 46.321234472336315, 28.43733083817267, 0.9900695409986281, 0.06934673089774386, 0.03471633532054482, 0.23589849742429875, 0.9307172161436851, 0.4602758291988604, 1.350749680592168, 1.3434122743145114, 0.4406941928450139, 1.5006647523372405, 19.80676716373813, 60.32818701959426, 81.39198164786063, 70.42396776137814, 76.82682914118614, 81.02251791184949, 73.74534453115156, 68.15908924225839, 57.933038742311545, 57.684317327314815, 64.6160711011579, 66.66832185560658, 63.83773557601437, 59.221819754569765, 55.77579398309031, 57.12924311237951, 66.55352192540323, 71.63741573210686, 72.53555220942344, 68.18452189045568, 67.67884208310035, 71.57192783970987, 63.49412418180897, 53.01237829269902, 49.0667288534103, 52.06749893003895, 57.02264878057665, 61.641969219330825, 59.78470340851815, 56.160194104717625, 50.40557892091813, 54.896979101242565, 51.70816275381273, 51.71258326499693, 47.65251436541158, 50.192653056113954, 50.46163743542087, 53.84032003341183, 50.64731459463797, 52.272105447707645, 48.96544148845058, 54.948146420140425, 60.008200060936716, 71.82665440344041, 51.72016128416985, 42.48785503448979, 65.39736409341135, 59.41440813003048, 69.88160594817131, 65.26579603072136, 65.84834252634357, 57.66223438324467, 52.26390377167733, 48.49439228734663, 51.242891203972604, 50.229523335733724, 50.90464953453311, 55.594133330929665, 63.71796208043253, 63.775334588943, 60.80235058261503, 53.00877755688083, 50.900283936531316, 50.067172511931396, 51.69434424369566, 51.33216827146469, 63.96835050275249, 68.41074851251417, 69.7524344536566, 62.29133329083843, 72.38696498255577, 69.28379751020863, 67.13496623500701, 59.396055359994214, 55.4836440855457, 59.660305438503144, 71.61983566899454, 68.7212590248354, 71.47992472494803, 68.05605642257198, 71.09099818814185, 67.26567529862928, 76.06622665159165, 71.47226825837167, 24.66453044645248, 0.17430531942555982, 1.082442032714044, 2.168013381381189, 0.9305069403302286, 0.0432858101633047, 0.21214601794077506, 0.8523194551948579, 0.18707223597072786, 0.14223405971161782, 0.1862654840994266, 0.8445922633813274, 21.408192457691317, 37.33388023991739, 34.23270533161779, 27.765479818467174, 22.042518161958267, 43.016394415209376, 56.103304047738355, 68.28812737618723, 67.99532244282385, 78.22095717153242, 32.221710066641535, 0.518937663685891, 0.052806107372406035, 0.049641233448299675, 0.028289250255892837, 0.09376459604790134, 0.04452151381560872, 0.044462356506095785, 0.045188155866438345, 0.027733361536276438, 0.08057724278900893, 0.09091740729467523, 0.05818463448855666, 0.04324212782986222, 0.0652246569253264, 0.04872893381323065, 0.02138881286936662, 0.033168347417226726, 0.053252556601599346, 0.03281814181396077, 0.08053041949507692, 0.09806355206115593, 0.04032340561670642, 0.0026850431318199567, 0.005123221133309867, 0.019713656285837777, 0.07694411677338424, 0.04193802784767844, 0.046892107779821085, 0.09309529567197447, 0.037954975850880146, 0.05560452696837245, 0.03582208364781353, 0.035522259816887884, 0.11937800269093245, 0.05906587691917535, 0.0543733470652613, 0.01904887774388396, 0.050213631362684315, 0.053642388102748705, 0.03818998864341167, 0.13912430964410305, 0.02829401723800167, 0.05296546898241486, 0.03854881273582578, 0.03536389412118062, 0.07317474202042626, 0.06916391167549357, 0.043100968468934305, 55.70924312837663, 101.81487667945125, 94.74736967394429, 95.76159261888074, 71.79093730065131, 42.58680466682681, 25.43641955621781, 31.438400976119507, 47.92294609931208, 45.66390406700873, 33.62128234678699, 1.0397890762936686, 0.04553403690337174, 0.0033877119037037298, 0.8217431700998737, 2.5282217946744736, 2.6415530423964224, 2.423484705148205, 1.775707232375299, 0.30641969473611924, 2.0320683213010913, 22.788566697028376, 64.63063093923753, 83.78152878053727, 75.2522014802502, 81.32477575732817, 86.55096530914308, 76.78891551110053, 71.20721801634758, 61.35895059954736, 60.18513425703972, 68.70520868609029, 69.62964073304208, 67.5884000716671, 63.17334098200645, 58.32716241959603, 60.2010198562376, 70.17870195450323, 73.83985796282369, 73.9259853670674, 66.91405050216183, 68.75003353241952, 74.65392235786685, 65.89690146907684, 55.060392887361594, 51.57231930763491, 54.28132780136601, 60.59471991754348, 63.44840111271028, 62.87042417833882, 58.942880399765514, 52.10925256052325, 57.48741434466455, 54.58666078505978, 53.70897946819183, 51.22995522714431, 51.77783189281341, 53.318068212078465, 55.16124094686201, 52.809391713911495, 54.4226586434149, 52.118960426699736, 58.31827825115573, 62.14608792335757, 73.21156486388176, 53.770670506262014, 45.227814951250636, 66.89361495356407, 62.56838206321963, 71.8037477616341, 67.45990322482201, 69.21510896375104, 61.293113616205034, 54.07106130353866, 50.998001944634225, 53.511539120827955, 51.57211142201578, 53.17967522528864, 58.53802904005974, 65.80773815031975, 64.8268671189585, 63.293494947495006, 56.385538193487356, 54.31030234982891, 52.3569659263857, 54.13346229061004, 52.15300659979544, 67.22624763365715, 72.28965882332095, 69.47145938873291, 61.695117335165705, 75.85905490383026, 72.52769177959811, 70.25207381094657, 63.477826733742994, 58.385268411328724, 64.2399589477047, 74.21241252653061, 72.86255236594909, 74.68809404680806, 72.26123732905235, 74.72881609393706, 70.43335007083031, 79.39448325864731, 77.56571738950669, 29.17917851478823, 0.6092713196431437, 0.11845756337166795, 0.4512899549257371, 1.5918509109366326, 1.0309250100005058, 0.6765473225424368, 1.0204243347529443, 0.26517244836976456, 0.08851983554420934, 0.23112986056554705, 0.7087666517303837, 25.351472785395963, 38.18258700832244, 31.32949244591498, 23.670278249248383, 31.41181907346172, 57.865687724082704, 64.45827414912563, 76.12470134612053, 75.72196806630781, 85.84580944430444, 44.40770226140177, 0.8296586356816754, 0.014579133919229912, 0.04984752560454992, 0.028068151535286058, 0.022958864104903998, 0.061827198707408486, 0.027495667436009938, 0.03193988904146658, 0.062012821811461644, 0.04222699238227741, 0.057185276621772405, 0.08799966950450214, 0.03599255736316404, 0.033039893624523, 0.036057184540456345, 0.03355198126706866, 0.014889881206345896, 0.03471377658687773, 0.03716489405281121, 0.02003891615106935, 0.033852640133831775, 0.05682167980159002, 0.0821101923863734, 0.023030508647582704, 0.05262926746640475, 0.02524396265676666, 0.16931954260555007, 0.1911782527402524, 0.17986105033947578, 0.11103078527676483, 0.16809980805602767, 0.13611749115009464, 0.1205945962799653, 0.18897950378877504, 0.12560177759657945, 0.3416017004318776, 0.1967353319689151, 0.11251448308147731, 0.15263557253826052, 0.13266384421337035, 0.27669370595005255, 0.12609758204029453, 0.16038709530426612, 0.14181291053612388, 0.12863811345831042, 0.17693004390645414, 0.2013027328517168, 0.1475192083706779, 65.86359270157354, 114.99751567840578, 107.49469618643485, 106.49250707318707, 77.57524090428507, 42.80363328995244, 32.98998863466325, 43.25607476695892, 76.71863448235297, 65.63018421972951, 41.420978192360174, 2.035424521853847, 0.27085075335156533, 0.29634021462932714, 1.752462408715679, 3.5846977368477857, 3.5333252289602837, 5.261331046781232, 4.934933464373312, 4.198695267400434, 4.569586746154293, 22.911676168441776, 67.42052262829196, 86.96835256391957, 77.74132190212127, 83.74384264792167, 88.0559552100397, 79.97436646492251, 75.49709073958859, 62.99755604036393, 62.690426611131244, 72.03774852137413, 74.63300828010806, 69.52352493040024, 65.37834059807562, 60.29724344130486, 63.2280658906506, 74.772064147457, 79.69926711051696, 76.2547436068135, 68.85159154092112, 71.01026796525525, 77.95637761392902, 70.4135028777584, 58.135409508982015, 53.325712911544315, 58.84236574172974, 62.52063505111202, 67.76853884420088, 67.14859254898565, 61.178137179343935, 55.36518850634175, 59.505677761570105, 56.21744501975275, 56.03664728903002, 52.66542896147698, 55.73728415273852, 56.52538637961111, 55.85539456336729, 55.171713675222094, 58.41033235672982, 53.832279174558586, 61.7396911498039, 68.66563197105162, 77.25250828650691, 56.99300742918446, 50.54761578959804, 70.61252394030171, 63.56449150270032, 77.16505512114495, 70.7239035637148, 72.12884164625599, 64.42860141877206, 56.36955453503517, 54.82765905318722, 55.780187037683305, 55.45647774973224, 55.27108300116755, 61.13414387549124, 69.03039670759632, 69.27130868357997, 67.33388531592585, 59.125776598530436, 57.07744036951373, 54.88502763932752, 58.06617183070029, 55.67419282851681, 70.96567846113636, 75.30743629701676, 71.5064791710146, 63.33773536066856, 79.0173787455405, 77.19904638105824, 74.26596856886341, 66.18876503359887, 61.80070361783428, 67.13934360011932, 78.67763088595483, 75.70381533715033, 77.73557170744866, 76.26693433330905, 79.305861226974, 72.76184943414503, 83.72622336110761, 78.05990465225713, 27.98187501968876, 0.6858660160533844, 5.036318888587337, 6.857340528118995, 3.9622285625626965, 1.0084916266702837, 0.6120175916341044, 2.3975776953081933, 0.33325333388582357, 0.3400224867847658, 0.46683176450671693, 2.042555145678982, 35.70962675156132, 56.3050550799216, 50.336113745166415, 40.661085651766875, 35.0604627209325, 59.59926943625174, 74.35229993635609, 88.08084657115322, 84.03828713201708, 95.88567287691178, 50.70298479449365, 1.2984246496231326, 0.13243162764176247, 0.17754171914871664, 0.15525154829505952, 0.1963500050647605, 0.18368324685481288, 0.1542838719943839, 0.1141839725295863, 0.09241920009615923, 0.17258220382275122, 0.1303706366208292, 0.20742552204718515, 0.2748131133135288, 0.08281141564610504, 0.16506482816992268, 0.16801273450255397, 0.21956208612649672, 0.1396172412581021, 0.16275657461054865, 0.14902757420655222, 0.1519203068868768, 0.18097667354008845, 0.16200841314369635, 0.15973618103852197, 0.16943379695857727, 0.15191800862310395], [0.055461743501045054, 0.030500185751025716, 0.02707315462401077, 0.06728959329906972, 0.010083818079663381, 0.009098220109609107, 0.0449992232625523, 0.047778663030194665, 0.0036949131613402, 0.062184954107168226, 0.08416225082210957, 0.03753320997460716, 0.029493525151103258, 0.07123866163554692, 0.021414995839398716, 0.09150346455674979, 0.051374480563906894, 0.03456642723552162, 0.011362577788531782, 0.12031033935566103, 0.32886959492198886, 4.655927429276129, 83.6437516058645, 83.61728345194172, 86.6010618209839, 71.62229891746276, 52.05009145121421, 23.30364646450166, 36.54424044393724, 65.62359463784003, 56.36681279828472, 46.45970198415941, 8.192163792348678, 0.16405533879033982, 0.04651104415496511, 0.25684044546177315, 0.40090928575204265, 0.7997205937581678, 1.5754232892105657, 0.8795810310590653, 0.2336291917749951, 0.9963252311272006, 19.26992608654884, 64.70345366385676, 80.36291645419213, 76.73288053081882, 77.35212864414339, 75.55144694543655, 74.75056171417236, 68.71845060779204, 58.70481214215679, 60.88211198006908, 63.761045394405244, 64.81379385917418, 68.4589465971916, 65.66549339602071, 61.439998534417924, 53.866497931941865, 58.4706780218309, 66.44534295605075, 69.54989110269855, 71.5374815848566, 64.94955493557838, 66.39814899813744, 70.96715327232116, 62.11839598994102, 52.137823104858406, 47.3939674131332, 54.213627692191835, 65.10406494140625, 68.81988310044812, 63.101024243139456, 60.73153218915386, 53.078383937958755, 49.01196864343459, 47.099719047546394, 49.59811195250481, 49.497428632551625, 56.656832848825765, 60.428607540745894, 65.68989446086269, 61.38542659821049, 63.763818510117076, 56.02645697132234, 64.62524160262078, 58.87257583679692, 75.34097256199007, 48.898274821619836, 37.40078018557641, 67.43512953481367, 60.126792923096694, 69.71122603262626, 64.95462656021118, 63.55252042893441, 54.18471590165169, 51.99514296747024, 46.59831462367889, 49.47848358461934, 50.627534081858975, 49.67042084663145, 48.52197047202818, 50.711696378646366, 51.23334023260301, 51.63080184690414, 47.9178430957179, 50.81194431551042, 49.74753072184902, 50.90986236449211, 48.8387724661058, 59.55952405929566, 67.13332668427499, 69.92833706640428, 60.81279193201373, 69.6686290925549, 67.98308464788622, 68.18637324917701, 64.7445483361521, 62.13884722801947, 54.56130658426593, 60.057206153869636, 65.63917821453464, 73.35018927051176, 68.9358675864435, 70.567824609818, 73.53178716474964, 74.90547180175781, 68.44182152901926, 83.90727996826172, 35.83091820439985, 1.0054970196177884, 2.264497804064905, 0.8819074255804863, 0.5810830225386928, 0.8440083818089578, 0.5339480227520389, 0.17025041604234328, 0.14131499935061703, 0.10611384145675168, 0.10422699754276585, 9.783652251766576, 33.35257645576231, 36.905196559044626, 49.56498361402943, 19.04716487853758, 18.917575651599517, 38.857803421635786, 48.5125607059848, 64.0396748819659, 66.87089658552601, 70.87646022919687, 17.385707709097094, 0.17926521779548737, 0.03222813536863654, 0.0731546858385686, 0.061449402447549574, 0.07119053599214362, 0.06140843206535905, 0.02546622008535891, 0.007965086533072135, 0.0421837505493914, 0.1232322599859007, 0.07706324344560986, 0.04147126579717283, 0.05721513106818161, 0.07236272712508518, 0.06267392887703835, 0.028283098569860863, 0.02957279801428799, 0.04717561776839918, 0.07361168026803963, 0.013451963858378511, 0.004058191815631524, 0.02799852754950764, 0.04738356467456587, 0.038900876102308114, 0.05511939029900297, 0.054841442108755155, 0.02326384370756005, 0.05875214476198439, 0.04051825624980754, 0.054177584787530285, 0.029364793651526975, 0.029572644796703133, 0.009553480307541547, 0.018568925574542056, 0.015857704021337054, 0.0770251841975316, 0.0642522462012787, 0.08538688067346813, 0.04377480791581254, 0.02273883407695159, 0.030486907532078125, 0.027222220012317264, 0.03733134963699887, 0.08186718929679164, 0.1688816927133068, 0.3675891495039386, 7.705172117679351, 102.68936126462876, 91.3271648653092, 95.598845635691, 79.2537093931629, 59.791853889342285, 32.05197341980473, 39.259814985336796, 50.69657171926191, 54.30488163425077, 52.0979679015375, 9.195692885306574, 0.0768988486379385, 0.020702453630585826, 0.650832018544597, 1.495979726314545, 1.6247445200720143, 2.54455209259064, 3.1971222114178444, 1.9237247349754458, 1.0835687335460418, 24.26657069113947, 69.72741757669758, 86.43293334591775, 76.93747135900682, 81.36876906118086, 79.3707529191048, 78.45793108786307, 70.54283126708, 61.478218109376975, 62.49560640704248, 67.25308449037614, 69.07738670226067, 72.9573089845719, 67.04009194527903, 64.16175473120906, 57.6363741966986, 61.52935797168363, 69.53110294957315, 71.49304113080426, 72.6176081934283, 65.16270829785255, 68.59868495695054, 73.90643627412858, 64.02506405307402, 56.561432961494695, 50.620297308891054, 57.13434611597369, 69.2250168708063, 71.11562282808366, 67.3367408014113, 63.849130061364946, 55.41742663229666, 51.30604528611707, 50.41927975993003, 52.330960612143244, 51.16743264659759, 59.88738321488904, 64.42784832369897, 70.11854064080023, 64.41421024260983, 67.63397016832906, 59.5386766618298, 69.4580291932629, 61.907486223405414, 77.9062811020882, 51.17340249399985, 41.09298567618094, 70.29951095581055, 62.28366113478138, 72.02173740633073, 67.37263048848799, 66.53427093259751, 56.75533925333331, 56.68255183004565, 48.84564053627753, 51.00915324303412, 52.793580639746885, 52.663557990904785, 51.285872536320845, 52.61486176521548, 54.20415516822569, 53.1068838796308, 50.044054062135764, 52.56070167787614, 51.35881685441541, 52.31130561520977, 53.054139767923665, 61.86478730170958, 69.64044294049664, 71.16538986083, 62.88041445516772, 70.75769086037913, 70.92931024489864, 70.61265730088758, 69.72326770905526, 64.26148883758053, 57.330503848291215, 63.45846983694262, 70.31229788257231, 75.13052171276462, 74.16816034624654, 74.72463484733336, 76.70281164107784, 76.29087648084088, 74.05321136597665, 86.3787026559153, 43.88193991876418, 1.5404882089745615, 0.6462884429962404, 0.2400523793673323, 0.9495494959335175, 2.0228571252476786, 0.806446232863011, 0.49069126647326256, 0.4146784291632714, 0.22274792404665103, 0.13204974813326714, 10.942465528365105, 41.73545029855544, 36.29632703719601, 45.914947525147475, 30.010252268083637, 34.185158360388975, 50.8966165204202, 56.27601385116578, 71.66668445833268, 73.2271602076869, 84.13432244331607, 24.76714357253044, 0.16042124750393053, 0.07503547765795263, 0.27384487010778924, 0.022655238562654105, 0.03916041136929586, 0.05015882926302091, 0.040064636437642964, 0.05469846328900707, 0.07231049525040774, 0.059164097051947355, 0.07410555417018552, 0.022873897293222048, 0.018616809900249207, 0.03505822120895309, 0.030933590418088342, 0.05400558655721046, 0.01961088559079555, 0.043637015511311834, 0.045640232011435494, 0.03791131266963579, 0.06721506060491647, 0.021312131298585765, 0.05581995089268012, 0.02040687009632107, 0.1481729418399834, 0.14659080173700087, 0.10690464337746944, 0.14962411155143093, 0.15475208961194561, 0.09966929533308554, 0.08040160181060915, 0.12030790319606183, 0.179161305629438, 0.198795112570928, 0.14665332983338064, 0.16328595668798493, 0.2383950553954609, 0.15823982746130036, 0.1857496158129746, 0.13072931898697732, 0.22141310776914322, 0.17630255660943447, 0.15592069545340154, 0.19626424918251653, 0.29389847791002643, 0.5202580315451468, 9.302568647169299, 115.90927846970098, 103.6723856772146, 108.67625528766264, 90.96882497110676, 69.90463810582315, 35.250889870428274, 49.4786600912771, 89.7441747111659, 78.57031483804026, 68.98820769402289, 12.23338423236724, 0.25418291709596114, 0.30021254393842917, 1.3935492355977337, 3.026286810636521, 2.7667526468153927, 5.508214831352235, 3.9215474551723855, 5.908116159900542, 3.5919023954099227, 24.06970693219093, 73.37104843508813, 88.81523193851595, 80.60515419129403, 82.38508655178933, 81.6120344592679, 80.29477703955867, 74.62829359116094, 63.79737046457107, 66.76669489952826, 71.1335402150308, 70.64932361725839, 74.17715041868149, 70.88527771734422, 66.19591159205284, 60.7306339663844, 65.67161229348952, 73.32467817491101, 75.56116657872354, 76.2445140654041, 64.92225916154923, 70.93451130774714, 76.61247945600941, 68.54712932340561, 57.605587513216086, 52.93157746714931, 59.843056509571696, 73.96614259289157, 74.63207475600704, 68.66367078596546, 66.39051606578212, 59.48600707515594, 53.492590150525494, 52.68280898371051, 55.93383804444344, 55.07268167311146, 62.551131479201786, 67.40590003228957, 72.74706994333576, 68.56416809943416, 71.80658755763885, 61.782154729289395, 71.11421077482163, 65.24991827626383, 80.07450457542174, 56.60727370169855, 46.096066890224336, 73.5102141288019, 66.32385930707379, 75.34891928395918, 71.2823235604071, 69.5764063250634, 60.49584088786956, 59.301098700492616, 51.44455594401206, 53.31678559703212, 55.515242699653875, 55.6481953590147, 53.18427224313059, 55.86188608600248, 56.820297625757036, 56.76820854986868, 53.032194106809555, 55.73054944315265, 54.23374160643547, 54.201166322154386, 55.952316330325225, 64.58127967772946, 74.41178660238944, 74.09725958301176, 64.17256870577413, 73.08822985618346, 72.85262876941313, 73.6490660329019, 72.70896019474154, 67.8810167312622, 60.74135772643551, 66.59407138824463, 73.32569014641547, 79.38124918168592, 78.15914061761673, 76.44351159372638, 79.64336549082111, 81.22907776986399, 76.19906948458764, 90.50658933577999, 43.862504574560354, 1.535151211484786, 7.164161070700615, 8.59634393645871, 4.822716905224708, 3.2023012109341162, 0.9899649240316885, 1.578997303881953, 0.3852948510358411, 0.49399096038072343, 0.27141634074430315, 15.83206472858306, 54.18401771976102, 57.778736622102805, 68.21061349684193, 29.305280754643103, 30.071876625860895, 55.94345177373579, 64.80751022215813, 83.11697729172246, 81.61944773889358, 92.5609464030112, 25.95867922229152, 0.3489395050752548, 0.1853750447832769, 0.26858374596603457, 0.17494198445591236, 0.22968184713634754, 0.14586275773904017, 0.13731240445087034, 0.16033529243882627, 0.36386875075197994, 0.3081717684624657, 0.21502087012894694, 0.15976708502538745, 0.18745875797204434, 0.22341198438117582, 0.17234712208230651, 0.09744875884104161, 0.18936270096850014, 0.145824100942381, 0.1461005820742538, 0.14110320668307044, 0.25288236027042715, 0.15973746806623476, 0.17941129544088918, 0.10612878783215439, 0.27820099926283287], [0.0532403604818448, 0.02494545266663115, 0.04089399173315014, 0.052528863983048554, 0.049876307527865135, 0.014525494357991605, 0.02325965512183405, 0.011770607708322426, 0.09497214979942768, 0.07387599592367489, 0.06464498117566109, 0.027690763217246825, 0.0363756051557439, 0.044345811550174995, 0.016511780314988667, 0.050610012915586276, 0.026894966403262752, 0.05829249583785573, 0.03423499844727978, 0.16953732608066452, 0.3688888942762729, 24.64558343733511, 92.82572992386358, 79.24914375428231, 77.97493042484408, 65.27382904483427, 53.75065465127268, 33.394432067871094, 43.52569849260392, 49.72251384488998, 49.129184753664084, 22.753832147967433, 0.45095891301189706, 0.022329898258190484, 0.09457969061669805, 0.4296895543173437, 0.0680826551791641, 1.49987316900684, 1.1894746893836607, 1.6007092162486047, 0.41795762255787855, 12.965680937613211, 66.25005598991149, 80.44936549278998, 78.66467921964585, 75.02613175299861, 72.15772598020493, 70.53792045962426, 70.24812006181287, 60.57084837267476, 62.33570706459784, 60.25420719577421, 68.88720666208576, 68.36004795566683, 70.60031752432548, 64.57544711328322, 58.05036075653569, 51.98380339530207, 57.90171077174526, 67.2544651646768, 72.77022761683311, 70.33582425886586, 65.00490350107994, 66.84246724651706, 67.64549409189533, 56.01819645973944, 49.54672890324747, 47.040420655281316, 59.85430194485573, 65.81795984698881, 67.15223250850555, 65.9756548173966, 62.03179397890645, 54.018423095826186, 50.85141120418426, 48.64842768638365, 50.999625805885564, 55.2151539248805, 61.38346933549451, 62.30732479403096, 65.95137534602996, 65.5948240526261, 70.14468716036889, 65.85619511142855, 69.15235104099398, 65.37661867756998, 73.48742515810075, 45.19304706204323, 36.35980667606477, 65.34629875613798, 58.5920439997027, 67.17257392021918, 62.36878048989081, 61.12179625418879, 53.60887273665398, 50.5664784677567, 47.348958215405865, 50.06565847704488, 47.519804893001435, 49.08208493263491, 45.34423089796498, 48.10349279834379, 49.095468059662856, 50.921217626140965, 46.44728376019386, 50.274873779666045, 46.316225605626265, 50.52112802382439, 47.841298041805146, 53.84026904259959, 64.07044979833788, 68.41286659240723, 64.96387943144768, 65.91459135855398, 69.86419846934658, 68.50274378253569, 68.67197052125009, 67.23210765469459, 60.72281668263098, 53.643146407219675, 62.25791861934047, 67.03480459028675, 68.40265274047852, 72.81719407727643, 70.9266116542201, 72.15362318100469, 74.55018351154943, 70.3785780937441, 80.05078208061957, 40.451733066189675, 0.271550681922705, 0.7878351379786769, 1.6039857436572353, 0.635916470519958, 0.1953682327462781, 0.029591770181732795, 0.14238418230125982, 0.04218335218367077, 0.04305247127288773, 0.03365005201269542, 19.394016150505312, 43.15382249893681, 44.441493480436264, 29.844608614521643, 15.822942276154796, 14.663870123124893, 39.230981642200106, 55.01089257578696, 65.70081433942242, 68.5559154325916, 53.59535624904018, 1.9181971348101094, 0.06102508932892835, 0.013673143018217338, 0.03191935596987605, 0.1201325609919525, 0.03796357135739058, 0.06775450907767781, 0.0641647627907655, 0.060327072147159815, 0.01945552295975147, 0.04763128686576121, 0.07595209419847497, 0.043452403643318725, 0.06990209101669251, 0.03609481860973662, 0.004162105896900739, 0.0468606292270124, 0.04615942894991848, 0.04681696604576804, 0.061330482619063514, 0.049639513580909664, 0.035251635427196185, 0.04558723787927339, 0.010884596380375085, 0.044853563135069226, 0.05903168641511471, 0.11028368867212728, 0.019926377834992546, 0.032564436476076805, 0.049544947687536485, 0.06158562054136588, 0.056763392001871145, 0.013874908552444993, 0.049261046994117, 0.04229420893675378, 0.05198581489704309, 0.03750013795891597, 0.08476683975107248, 0.0570122633249529, 0.01411671654486488, 0.09440419519500387, 0.043524331638529416, 0.08219348912638041, 0.107653065314216, 0.0853242529856582, 0.29423779357344876, 33.780499196821644, 105.21332802311068, 85.92864990234376, 87.40627734891831, 72.97577550334316, 61.785202410913286, 33.980818563892, 29.401298415276315, 43.58853094039425, 55.412998276372115, 26.198930278901134, 0.4833430430341152, 0.13691825221382803, 0.13583198550247377, 1.009003618551839, 1.6454836846359315, 3.6102475658539808, 1.873560807397289, 1.332758136333958, 0.31430142180573556, 16.092884694376302, 70.0506365683771, 82.1013266040433, 81.86308183977681, 78.29279145886822, 76.1228499873992, 72.9612470442249, 72.08757046730288, 64.57702782846266, 65.06302910466349, 62.55466945709721, 72.22297068565123, 71.47823810577393, 72.67075630926317, 67.25589290741952, 59.478346686209406, 54.283171315347, 60.77833783242011, 69.69184167923467, 75.39828623494795, 72.72551259686871, 64.67964879928097, 69.51737465397005, 71.59339104929279, 59.66825216047226, 53.67388994463029, 49.21379027828094, 63.226751896642874, 68.45870341024091, 70.88264972932878, 67.98752477092128, 66.31930151293355, 56.62988224337178, 52.77013271085678, 50.91749921921761, 52.52062289945541, 58.31448924156928, 65.58926213172175, 64.46636599879112, 67.84304034325385, 65.62587745728032, 73.00894306552026, 67.98008011233422, 73.22493230142902, 68.66592222644438, 75.28723609062934, 45.26255930623701, 39.44491947850874, 66.46503325431578, 60.656108933110396, 70.00085384615006, 63.55710960203602, 64.01403827051963, 54.99529330961166, 52.748865619782485, 48.929759686993016, 51.73393664821502, 49.59174986808531, 50.18467887755364, 48.7440433040742, 50.6262985352547, 50.5004257540549, 53.990080048961026, 50.817278738944765, 52.48570988255163, 48.913321033600845, 52.68778254908901, 49.75390457337903, 58.53682095004667, 66.02742225893083, 70.03692396225469, 67.58037490229454, 66.3142651896323, 72.53650142300513, 72.63641203603437, 71.15343447654479, 70.1186740013861, 64.85543374092349, 55.51203027848275, 64.33162473863172, 69.25648212432861, 71.95361368117794, 75.14059435936713, 74.34160755526635, 74.55489820049655, 76.72243133667978, 72.27856636047363, 83.65210625433153, 46.553195599586736, 1.3709145856480445, 0.7694275773340656, 0.7639244306952723, 1.6695942489370224, 1.9846895216934144, 0.8797045244324593, 0.6741633182091098, 0.23904079090683694, 0.08146237311584335, 0.10538845578388822, 21.309407564901537, 43.22973212888164, 35.72521817299628, 20.805075091700402, 19.059612520279426, 25.12346540727923, 50.26045514691261, 64.69554616558936, 74.27449580161803, 77.37269755332701, 67.64603537897911, 4.513222286778112, 0.09111265246305736, 0.1574827793745264, 0.03193748927104377, 0.034171118205713655, 0.01781245396893111, 0.025981837478015694, 0.06377358680530902, 0.031072250417163296, 0.016309521611659758, 0.039642418569494645, 0.06260427616296277, 0.055439599729593725, 0.04497125722287644, 0.04366455637218972, 0.031691128801133846, 0.024917586218385447, 0.052490222508147846, 0.05633613710562068, 0.039938017425517884, 0.036896675179201754, 0.05268902615493825, 0.06643469280172741, 0.0361637014054483, 0.040315714093946645, 0.11511961103326852, 0.2912689270752092, 0.2904576399633962, 0.15951206967715295, 0.18190625994916887, 0.1171488170662234, 0.206930598604583, 0.19661655769713465, 0.26686562525649227, 0.23680643418863898, 0.21207866349047233, 0.10096533223986627, 0.16437599255192667, 0.25122053170156095, 0.08396409451961519, 0.19944890732726744, 0.16384553795139636, 0.12329897858322629, 0.2240566933347333, 0.20879602270020595, 0.3878313068660998, 42.46869425619803, 119.9124808465281, 99.17645515934115, 99.14080081447479, 82.22031562559067, 70.81926422734415, 45.743461501213815, 60.8689877294725, 70.75527468035298, 67.83274019918134, 35.11582697591474, 0.9955095619924608, 0.20547996515468245, 0.3298373784749739, 1.8059387779043568, 2.3008907802643317, 6.157178330805994, 5.780451836124544, 6.630751577115829, 4.084603815309463, 16.382919453805496, 76.65520191192627, 84.87616815874654, 83.88031759569722, 81.76382234019619, 79.61148446606052, 77.3765806997976, 75.2135504445722, 67.07773100945258, 68.94895261333835, 65.2407124734694, 75.49207795050837, 74.0331994333575, 75.96888126865511, 71.57075112865817, 63.69931513263334, 57.97382746973346, 62.7545730529293, 73.23443228198637, 80.25844020228233, 75.6624343318324, 65.50037337887672, 72.16332712481099, 75.05175267496418, 62.01177420154695, 55.861105534338186, 50.549373011435236, 66.24908324210875, 70.29077191506663, 73.3630624894173, 69.69609352850145, 69.50556831975138, 60.599913135651626, 56.274805761152706, 54.53134752088978, 56.02472328370618, 61.365296994486165, 66.79910152189194, 66.35218666445824, 72.21444345289662, 71.23808706960371, 77.42797159379529, 71.31946840593892, 74.5653630841163, 71.8428930159538, 76.7800352650304, 48.87934938553841, 44.65609027493385, 70.58927212992023, 64.00354593030869, 71.46963242561587, 66.58785050915134, 67.95431014030211, 59.64863246487033, 56.910990668881325, 52.49486469453382, 55.30742768318423, 51.5376651671625, 54.15523536743657, 50.84295849646292, 53.351478961206254, 53.35402457944809, 57.290778083186, 51.64879768125473, 54.53067679559031, 50.926477524542044, 55.93368114963655, 53.753498369647616, 60.986623533310436, 70.54330195150068, 73.04557015818935, 71.69920875180152, 68.18688315729942, 75.26214076626685, 75.87719194350704, 75.71343298881285, 72.69831488209387, 67.95829526839718, 59.38980310193954, 67.0844304177069, 73.73535817669284, 74.58164092033141, 78.79316037701022, 77.39290560445478, 79.17110427733391, 80.13560725796609, 77.79297167255034, 86.73342612481888, 50.18067805997787, 1.0662812547337626, 6.050176562801485, 6.54990662490168, 3.7890098316054193, 1.44683965992543, 0.804683004896487, 1.2884257926094917, 0.3438378497958184, 0.09293814039518757, 0.27999468688522616, 30.25845593021762, 61.6357248060165, 59.0286430235832, 42.95517013918969, 25.020777756168, 23.99585262421639, 55.15260781011274, 72.58953186773485, 85.36187525718444, 87.79767497893303, 73.65655775993102, 4.655621974698959, 0.23001360917283645, 0.24026997898134494, 0.11482714164641597, 0.14778979062553377, 0.19808056704219312, 0.17595786300878372, 0.17369477799342525, 0.12264292386751022, 0.16150625783108896, 0.1426148207317437, 0.28685292048800376, 0.1757352378579878, 0.10353499032076328, 0.1633695828457994, 0.10744701830610152, 0.12005176935945788, 0.08563914576605444, 0.2077927999198437, 0.16620046158711757, 0.12467834287353101, 0.14074458560395625, 0.10521594810509875, 0.16350551748708372, 0.11041244506956109], [0.009445862191158437, 0.04666102501834112, 0.0323578110715795, 0.06671543338245924, 0.048760228504937504, 0.029743323440573392, 0.06079616693539485, 0.07519532190335375, 0.06493856139000385, 0.061497160368749214, 0.019397620119214542, 0.06418902862576709, 0.03337259028827952, 0.03722869385514529, 0.03602394015498219, 0.00576826955957879, 0.055815814017889, 0.024532180790218617, 0.13594659225594613, 0.08063492920970725, 0.9674141147444326, 60.68863322657924, 89.79461639158188, 80.73836572708623, 68.15193483906408, 43.93774347920572, 34.23291321723692, 40.4349257100013, 73.6246375114687, 53.30190020222818, 50.423633590821304, 6.3415880741611605, 0.08209971230356924, 0.1282607845120853, 0.2181729848586744, 0.41736828643948803, 0.9390972374427704, 1.6506613358374567, 1.5582323987637798, 3.0813566427077017, 7.105341207596564, 54.69264322711576, 82.26208886792584, 81.25483205241542, 75.29323731699299, 69.3570516955468, 67.32259673456993, 63.15896157295474, 61.77640453461678, 61.21336790823168, 63.3307300075408, 68.50981189358619, 73.74459143607848, 70.57096250595586, 70.44122619013633, 59.70372607631069, 53.134630726229766, 50.55266780237998, 60.17342205970519, 64.81018135624548, 70.85242394478091, 66.90478586381482, 64.51289707614531, 66.96005205954275, 65.19785665696668, 53.2448414833315, 47.102841254203554, 49.30788401634463, 61.649688443829945, 66.8217492872669, 65.58279022093743, 64.75498968555083, 65.501495176746, 58.21095435850082, 50.73532865893457, 49.98742680395804, 51.37511038011121, 56.14341028275029, 63.314377646292414, 66.00258581099972, 67.405272453062, 60.20959023506411, 63.49947429472401, 60.8362869293459, 67.6032187861781, 62.966686987107806, 66.85260265104233, 42.52345446617373, 37.37711652632683, 64.01196725906865, 58.754183015515736, 69.47520917461765, 62.095344220438314, 60.14120763347995, 52.59673257027903, 50.529659178949174, 48.40604089921521, 50.311422424931685, 49.81963173035653, 49.58432482134912, 46.65708741834087, 48.55119997455228, 46.34986385222405, 46.853637387675626, 47.43897661086052, 49.50194720299014, 47.58917593186902, 48.319984097634595, 49.27210415563276, 49.85331704539638, 59.1657651624372, 63.722139404666045, 67.9369967983615, 65.62453992905156, 67.14269330424648, 67.64135206899336, 66.91196380123016, 69.91551876068115, 66.41993384207449, 53.24346865377119, 51.39507916665847, 65.30007754602741, 68.99107886898902, 68.70999397770052, 70.8299409189532, 70.55755584470688, 68.4062691657774, 73.61817344542473, 72.88072862932759, 79.1152967945222, 33.699768973935036, 0.019162425380801002, 0.4779090588131259, 1.423932527822833, 1.221207031799901, 0.09178362291065917, 0.4990003786740765, 0.37883847651462405, 0.09299644734710456, 0.07261629456714278, 2.0146718741424623, 30.139098205874046, 47.773460649674945, 63.51291233493436, 50.43096450067336, 22.41230353232353, 18.778392307219967, 45.17415300492318, 61.09537909107824, 66.05775786984351, 78.8001500406573, 36.0886767602736, 0.5726880472033256, 0.05420453959114609, 0.02284970232135346, 0.02155034250820116, 0.069450382593899, 0.005561689162747034, 0.03364214598531685, 0.09673746152510566, 0.003112347105578069, 0.03688855464720438, 0.059316268926786805, 0.033065335404488354, 0.030042069002745614, 0.08839716954577355, 0.05870774996677234, 0.04682813177726442, 0.0357468921180454, 0.04709813180529783, 0.06568363552252132, 0.009394950860540473, 0.10966076725913633, 0.04448686748923314, 0.018394441388907935, 0.03178457046047815, 0.05135081610792587, 0.035634882402636354, 0.02872877021981103, 0.04455778041794416, 0.10165006928746739, 0.020394126223700664, 0.02391890825463399, 0.0674624074130289, 0.04899155258411362, 0.01978066599657459, 0.08971160022361625, 0.0491400970326316, 0.028879543984188672, 0.013641419317272883, 0.09779441005159771, 0.04251849649834537, 0.09982853436902647, 0.027885410837048007, 0.1539881007685777, 0.06719051514782252, 1.7941018001687143, 78.75348952508743, 100.2413002137215, 89.41544871176444, 78.0725895973944, 59.82111869319793, 50.3976635779104, 40.16792997237175, 66.8672409365254, 49.06053935327838, 52.42855310440064, 8.402633763128712, 0.17484269946092562, 0.07064943276946584, 0.8240238444939737, 1.4537912030373852, 1.6054579807866005, 2.5254589751843484, 1.7004039763442933, 0.7993900114970823, 8.488600350195362, 62.316801240367276, 81.93788143896288, 84.13435382227745, 74.38925650811966, 72.13380736689415, 69.67656012504332, 66.94562558204898, 64.27047498764531, 63.670650451414055, 65.93968668291646, 71.17754920836418, 76.60224991460001, 72.8080863337363, 72.77378912894957, 63.50445178247268, 56.89013542667512, 52.63297919304141, 61.19654486256262, 67.68852249268564, 73.215895160552, 68.4659048818773, 65.26927909543438, 69.75820033780991, 66.62963159622686, 55.40236473083497, 50.02915297785113, 51.6237376582238, 65.12678723181448, 72.56330690076275, 65.58295888285484, 67.8810167312622, 66.73515904334285, 60.42281812237155, 53.83589167748728, 52.32228040695191, 53.514641715634255, 60.44138270039713, 67.24731860622283, 67.61933188284597, 68.54381884298017, 63.00300421253328, 65.32252527052357, 63.90808328505486, 68.18274113439745, 64.01211238676503, 67.81690951316588, 44.21142685797907, 40.49415742197345, 68.80978691962459, 60.05912811525407, 71.93424501726705, 64.50102798400387, 61.38839583243094, 55.475379651592625, 53.44436460925687, 48.88715882455149, 53.17250513261365, 52.36466946140413, 52.47768471317907, 50.55586845644059, 51.34523368650868, 49.41432929808094, 47.744901872450306, 49.37288553484025, 51.2162975342043, 50.73534827078543, 50.20767181150375, 52.792203887816406, 52.07131931858679, 61.201902820218, 66.73603765426144, 69.33956576931861, 66.28947581014326, 68.55145962007585, 70.24341321760609, 70.10867195744669, 72.6005615726594, 69.39699711338167, 57.63491115262432, 55.19598137947821, 68.43446316257601, 70.77857355917655, 72.45759117987849, 72.56988079317155, 73.63151734875095, 70.87929218046128, 76.98404558243291, 74.91491686913275, 82.26713303596743, 41.77255592038555, 0.5088831580454304, 0.4600933470552968, 0.616369461340289, 2.562725169043387, 1.8138483599308999, 1.363226862684373, 1.2969988680654958, 0.4044429429115788, 0.025109230773523453, 1.4253887077493053, 32.830807085960146, 39.64362675143827, 49.82373452955677, 41.08216385687552, 25.768901225059267, 28.295042937801732, 53.23253700810095, 67.18989510690012, 73.11058736616566, 87.64260799654069, 49.49854650805074, 0.7214848757270844, 0.01633741870342243, 0.04613294145993648, 0.041118037977045586, 0.06301972564430007, 0.014643511160336917, 0.04778847278606507, 0.04150660926355951, 0.03693956461164259, 0.053799378670631885, 0.0606308221786974, 0.07204966529482795, 0.09468038521346547, 0.025803511361441305, 0.0533044513975901, 0.04397201809972044, 0.042523935722607764, 0.018220208097069014, 0.07354522980148755, 0.028052462054596796, 0.06107525659664985, 0.028803465707648187, 0.050594614548308235, 0.08719531548840385, 0.14468396292819133, 0.22575710209146624, 0.11922340614781265, 0.15734868334426036, 0.22242271972279395, 0.093959006180446, 0.1763779090176667, 0.13823077533273928, 0.20979006774723533, 0.1646164675513583, 0.25076984217570675, 0.1546037903115634, 0.1200187509699214, 0.08774677621981791, 0.1411608318167348, 0.16755151892862014, 0.17740311852145582, 0.13885933515285293, 0.33199701097703754, 0.25099216089133297, 2.4975552337784923, 92.33470409147202, 109.88508270632838, 101.24778824467813, 87.19400651993291, 64.07334450752505, 50.130644306059814, 57.91612940449869, 98.1054598285306, 68.84981862960323, 74.92742922998245, 10.889979312496802, 0.3106781630025756, 0.584433400823224, 1.184717344660913, 2.071237967860314, 3.678279115307716, 6.277377893847804, 8.783008552366688, 9.813484818704667, 8.853458243031657, 64.0875199533278, 86.04769383707355, 89.58141203849547, 78.50570555656188, 74.42523248734014, 71.7387854668402, 69.1846086132911, 69.4787863762148, 67.42096193375127, 69.8368360150245, 74.89144540602162, 81.0344732961347, 75.57383583438012, 76.04513214480492, 66.19796691402313, 58.18566291562973, 54.824776111110566, 64.79814360218664, 70.52553361462009, 75.9788990020752, 68.5694319202054, 66.26864017978792, 72.56973958784535, 71.87128313126104, 57.7753790732353, 50.617261394377685, 54.70199415760656, 67.28827599556216, 74.27297392199117, 69.48663111655944, 69.35387457570722, 71.63771383223995, 63.951943228321696, 56.67518169649186, 54.45398269161102, 56.28488625249555, 63.359143657069055, 70.47546848174065, 69.91466368398359, 70.03158953882033, 64.38356476445352, 66.13597777581984, 66.59400863032188, 70.42233605538645, 66.47776526789512, 67.87509395230201, 47.811899877363636, 45.42203111033286, 70.32951708762877, 63.33089082471786, 74.24172047645816, 67.97663627132293, 64.41647737256943, 58.302031793902, 56.4131320676496, 54.28320269430838, 54.736742434963105, 55.635726144236905, 54.83275813441123, 53.46736538794733, 54.89839507687477, 51.73247752651092, 50.10114415999382, 50.867430163967995, 54.01546170634609, 53.852020463635846, 51.75691781505462, 56.229400404037975, 55.403247264123735, 64.98295391759565, 69.61042111919772, 75.0442687926754, 69.76124409706362, 70.72853980525848, 71.10032558441162, 72.04214157596712, 76.281933476848, 71.97938365321006, 59.890301458297245, 58.91236828219507, 70.86739955409881, 76.20867929150982, 74.03637655319707, 77.0458778258293, 77.2504529645366, 74.08460601683586, 79.33938180246662, 80.85425607619747, 85.15205198718657, 44.38571737658593, 0.5762942988545664, 3.140131643702907, 6.5970491017064745, 5.352331015371508, 1.5788910321650969, 1.4612939617326184, 1.7638158317535155, 0.3708232356415641, 0.21196911291730022, 3.599445603547558, 46.6042491697496, 66.05011709274785, 80.2588559735206, 62.60441295562252, 30.940895388203284, 29.694291622407977, 58.681501496222715, 80.2176397077499, 84.06942290644493, 99.33527192761822, 51.132605921837595, 0.6794458315257104, 0.1700474640294429, 0.0882000934272524, 0.09506938933965661, 0.15327543981613653, 0.08677048909087336, 0.21289353589377097, 0.1635916717350483, 0.11964144500633402, 0.1469506485567939, 0.16958456306207567, 0.11830380186438562, 0.1881142228000587, 0.17357133058530672, 0.11713862043595123, 0.17856711251360757, 0.14162210867770259, 0.0967712383416872, 0.260738484681614, 0.07978267937658295, 0.21390527757185124, 0.1377626956110039, 0.09710984920421917, 0.16189380639022397], [0.022625636925259908, 0.08220198504146069, 0.013643624692884906, 0.05631114348709103, 0.020527957953632842, 0.0371098582963309, 0.030477925151165937, 0.13713667920279887, 0.05466827942479042, 0.044027666726540175, 0.0892358289791211, 0.09313370732049789, 0.026753031378311497, 0.05023727666646723, 0.028147675292265993, 0.053306726678725214, 0.029922894450024735, 0.0232400662536102, 0.12577480621515744, 0.22242229071355638, 12.908434925540803, 91.59998924501481, 71.16149102487873, 74.57842457679011, 63.50703662441623, 38.771715241093794, 17.18868705534166, 38.253111224020685, 37.3459219163464, 51.838350142202074, 29.516096384294574, 0.28635052002726064, 0.09493672589380896, 0.1489182381379989, 0.3897218280021222, 0.5996423911663794, 1.0787892029170068, 2.2101773898447714, 1.3277568692161192, 0.6518629277425428, 40.31942367553711, 76.90726126393965, 81.09296368014428, 74.9871120145244, 74.92920214130034, 68.31789816579511, 65.23276967387046, 66.46941061942809, 64.5673748754686, 63.724598730764086, 68.67808157397856, 72.15505092374741, 75.62980021199873, 68.79171263787055, 66.2539077574207, 55.27855511634581, 52.593728034727036, 51.646303053825136, 62.471621113438765, 69.23454823032503, 70.22423282746347, 63.40052466238699, 66.82936653014153, 65.37016637863653, 59.55669603040142, 50.18904447555543, 46.81965005013251, 49.2221410043778, 61.11274734620125, 67.32405585627403, 64.61503559543242, 67.71737544767319, 65.68490912837368, 60.70786852990428, 56.46179691437752, 55.317315978388635, 56.02267188410605, 60.680392326847205, 65.99570597371748, 64.351024781504, 67.41914195399131, 63.428757882887325, 66.4389887163716, 63.034669506934385, 62.322735786437995, 59.701913941291075, 67.21002471062445, 40.95593806236021, 39.91031654419438, 63.67062691719302, 57.77010740772371, 64.99179493996405, 61.27363120355914, 61.718380912657715, 51.02576448071388, 48.88309917142315, 45.90265481702743, 52.35649916433519, 54.776017127498505, 55.52241279232887, 52.478520178025775, 50.62310572593443, 47.53427451656711, 49.84278155911354, 50.36781826326924, 52.068028450012214, 48.44337794088548, 48.26259589964344, 44.789623445080174, 48.769503408862704, 48.864420844662575, 58.50172750411495, 61.188386332604196, 65.99250531965687, 66.25535118964412, 64.34243871319678, 65.64993727591731, 69.00299502957252, 67.53965285516554, 61.2298850090273, 50.188993484743186, 57.48340568234844, 66.80409862149146, 71.81989223726335, 64.9337830851155, 69.77432912395847, 67.21391570183539, 68.98260654941683, 71.76781885085568, 72.47061344885057, 71.44339176916307, 33.22057300998319, 0.3145892870041632, 1.0484554306153329, 3.1690620655013673, 1.0619411521380948, 0.4378602191084816, 0.26096331616563184, 0.4136238325267069, 0.04962074442676479, 0.05733104400156487, 7.458758527232756, 37.87254325805172, 39.61990033426593, 79.20768430156093, 88.21069271333756, 40.523634033818404, 30.100753115069484, 53.27425141488352, 55.51633311856178, 66.29113105035597, 70.75908722416048, 11.850239269195065, 0.5484612826858798, 0.1164585028985335, 0.18008447222171292, 0.0561476641544892, 0.09171995334327222, 0.04787225216146439, 0.034047096231651884, 0.02688375662171072, 0.03347217022711712, 0.047410806761153286, 0.09491002006876854, 0.04175663737940692, 0.048237024926610535, 0.017292958256157658, 0.07813266388350919, 0.034248290072766044, 0.03029042130125867, 0.018516716682502342, 0.01379857459405978, 0.09290568891071505, 0.048659399842783335, 0.01106564593952029, 0.09617076330487767, 0.07173013768248981, 0.057082314404749104, 0.06893302043599468, 0.06059748203223271, 0.07532933366394813, 0.07472936424516863, 0.004916749425202368, 0.03278785452787434, 0.0475688775130097, 0.04703368082822812, 0.0400435422066479, 0.033455113279483015, 0.08888074722621711, 0.054614488561187065, 0.06892141420394182, 0.054142743108734015, 0.03428708093481199, 0.07655898139121071, 0.14806339126681128, 0.2540314615133309, 17.524114424182525, 105.33175222335323, 78.29248551399478, 83.49798848552089, 68.69969383362802, 49.36346007931618, 27.099943814739106, 34.935935312701815, 36.41712034902265, 53.078046614123934, 32.46397722151972, 0.2623871058946656, 0.013438289188930105, 0.31258648802195826, 0.8714795593292484, 1.3222391975502814, 2.756456425113063, 3.194814386867708, 1.095766937059741, 1.320210351578651, 43.93924182461154, 78.31362708922356, 82.6702428633167, 78.45285554086009, 77.57548409123575, 71.77551454113376, 67.06919593195762, 69.33609054934594, 67.32958639821699, 66.7205992052632, 72.00586749661353, 75.28132900114983, 75.98683787930396, 71.9139349845148, 71.20250332740046, 57.37380289262342, 53.89060089665075, 54.38676895633821, 65.48335029232886, 69.53639030456543, 72.00607930460285, 65.4689081253544, 68.03240453043293, 68.85377237873693, 62.02729894268898, 53.896590355903875, 49.64128940336166, 51.1821101557824, 62.79189832748906, 70.00018704322078, 67.35172425546955, 68.70991553029707, 67.64629425541048, 63.20581036229288, 59.29080247879029, 57.86029446509577, 59.2078168930546, 63.82391314352713, 69.0399359118554, 67.142591322622, 69.66538921479257, 64.35215834648379, 65.90635438119212, 64.35176218709638, 64.5346583858613, 61.01824568163965, 69.55260538285779, 43.35305536946943, 42.67667401221491, 67.58482287006994, 59.20307474751627, 66.52731264791181, 63.66230364768737, 62.827580128946614, 54.39466076512491, 50.787417734822924, 47.818854239679155, 55.565500028671764, 56.974599745965776, 58.4183967498041, 53.485082734015684, 53.149539655254735, 49.07262809814946, 53.77184721731371, 53.629649531456735, 54.064707063859515, 51.31117966867263, 50.37018737485332, 46.5238013575154, 50.77212833589124, 50.90794432547785, 62.807501516034534, 64.19855440816572, 70.22582530975342, 66.92964584596696, 65.41632090845417, 65.61602446340746, 72.041364946673, 70.19150457074566, 64.04546430034023, 52.28433147553475, 61.24579806481639, 69.0859688481977, 74.76363889632687, 69.84356680224019, 73.33297006545529, 70.80999958899714, 71.41392692442864, 72.70730495452881, 76.80955502294725, 73.30017905081473, 42.43732706193001, 0.9543836333097951, 0.7101017284777857, 1.0829612564656044, 2.1303743172076444, 2.486209778055068, 1.0183215153313454, 0.5503602001455523, 0.09141375566081655, 0.10853074160554718, 7.274674340601891, 37.90878988081409, 39.80117659414969, 67.54115120057138, 71.03119773249473, 40.631656108363984, 37.92736622595018, 60.596814463215495, 62.20923808313186, 73.12311541649603, 81.97415551831646, 19.561471939086914, 0.5177897575401491, 0.21739254044669293, 0.13704612761014892, 0.01748124160052788, 0.08291478388972821, 0.08607245275690671, 0.0733194483684436, 0.02607076496426617, 0.031483243182001096, 0.022899720201929732, 0.06292532062939098, 0.005683939558483901, 0.04450769741989432, 0.012445082050567914, 0.07866020734992721, 0.05321350910009877, 0.059646092760827274, 0.043948185104396076, 0.022089369632604144, 0.0371681307742913, 0.025389479142763925, 0.034940071298830935, 0.07878574617807904, 0.1568271306854102, 0.1566689335290463, 0.13611693956678914, 0.14795437695518618, 0.23595901837031688, 0.11291947546264819, 0.1374352083451325, 0.2116127594584419, 0.17281504858645702, 0.18330763394553817, 0.1419211740815832, 0.2756001001163837, 0.14697767613876253, 0.10238286303055864, 0.09476418757150251, 0.13790383965017336, 0.1867591818013499, 0.15044304422072827, 0.2848319499002349, 0.3676380565570247, 21.636533237272694, 117.89523724586734, 88.89428338696881, 97.00886710997551, 78.80363310537031, 54.53909027960993, 25.936343285345263, 56.00964961513397, 51.22110636003556, 71.2174161787956, 45.65288612919469, 0.6254446001783495, 0.18061307288946646, 0.6496345924754298, 1.052028709842313, 2.6701792353583924, 4.228186588133536, 7.971521644823014, 4.49186792296748, 1.2162111579410493, 47.97936547187067, 81.26965861166678, 87.36557883601036, 81.0931754881336, 81.11219898346933, 73.73412655245873, 71.84001399624732, 72.87237398086056, 70.43591530092301, 71.17674904484903, 75.92298169289866, 76.61670777105516, 77.9167381409676, 72.5318887156825, 71.91599815122544, 59.82040482182657, 58.36789623383553, 58.14709032735517, 69.6516687639298, 73.67908000946045, 75.89308538744527, 64.42833469760033, 69.34825774162047, 71.32630901951944, 65.13199221703314, 57.584143915484034, 51.54823987714706, 53.555108808702045, 65.6698864506137, 73.73341268108737, 68.24200814770114, 71.43727287169426, 70.76306450751521, 67.20978936841412, 63.05851751758207, 61.715458746879335, 61.77611035685386, 67.53731512254285, 71.9051488753288, 68.77252440298759, 69.94117890634845, 65.97902021100445, 67.33128870687177, 65.5802720592868, 66.45882021996283, 63.35220106186406, 69.2846368974255, 45.52546401177683, 48.0620764916943, 68.61123654150194, 62.580121717145374, 68.138685072622, 67.56083365409606, 67.81976499865132, 56.60717172007407, 53.01973665914228, 50.080602707401404, 57.89763150676605, 59.129447937011726, 60.36629284581831, 55.29582138984434, 56.66119060208721, 50.99433845089328, 57.40435423389558, 55.8647729504493, 57.30228631727157, 54.617949531924346, 54.255291108162176, 49.62246987127489, 54.13122261724165, 54.46787572676136, 65.92331470981722, 67.9305091980965, 73.4148769993936, 70.04885581231886, 66.44594700105729, 68.354384053138, 75.70285043408795, 73.2248067855835, 67.1762138797391, 56.02950073057606, 63.72532436924597, 72.76275942402502, 78.40977222688737, 72.6582988615959, 76.1900794121527, 75.21088323285504, 76.45710652874362, 77.39681228514641, 80.20657862386396, 75.5469205302577, 45.38157186200542, 0.8628568413757509, 5.753793447248398, 11.33947999246659, 4.992895799298441, 2.7399900699815443, 1.1021197058500782, 0.7425842241894814, 0.3676619278567453, 0.1571533768888443, 12.273640498038262, 55.91158643845589, 53.57899604305145, 89.4526170915173, 99.59876891105407, 50.66478875375564, 42.590448548716886, 71.34876066638579, 72.12493496556436, 81.87717099343577, 91.33098525385704, 18.870724901076287, 0.91786943135723, 0.4403797290738552, 0.3095196848434787, 0.11167932466994371, 0.32045430293486965, 0.15075514844108015, 0.14875798786599792, 0.11260626807568536, 0.15306681875259648, 0.17480247984490088, 0.26243261151736785, 0.15496267186057183, 0.10740627008940905, 0.16097742733695816, 0.15119664491184298, 0.12595449213779744, 0.13324126000365905, 0.1695509930892337, 0.10533671420548232, 0.1767785730020654, 0.12962242918870143, 0.16643693760758446, 0.19346553081225967], [0.042747997288261695, 0.07968681113373849, 0.10315276607270203, 0.026193653128200003, 0.02139954193074617, 0.021775285074968013, 0.04891941391472374, 0.07087572748141904, 0.06332041515458016, 0.03916346806011373, 0.035390496524351264, 0.007174617381796482, 0.04925023366306578, 0.03376016183005225, 0.07843697698967111, 0.01334637683260465, 0.037702128531471375, 0.03770105217793777, 0.027448267660914894, 0.024331243588559093, 45.47704235199959, 86.34003593075661, 70.45849246363487, 77.7727871556436, 60.33656520228232, 39.84870787589781, 31.04929989384067, 46.66265326161539, 44.006235907154704, 49.12213625446443, 8.65480294150691, 0.14655047486866676, 0.08522057830686532, 0.4182529341309302, 0.6087498282713275, 0.6614677704149677, 0.996156691783859, 1.426756266624697, 0.6472904860011993, 21.06332786621586, 74.42946080238589, 75.67882983915268, 81.26951740634057, 76.13973186862084, 73.04806478561895, 69.66510680414015, 72.44252143367645, 68.72000386638027, 67.16674527814313, 68.77650953108265, 69.72881394047891, 76.7624238229567, 71.94182303643996, 70.10928384719357, 64.6017191486974, 50.89075649938276, 50.96303009217786, 51.99699824856174, 66.31741093051049, 65.9909991295107, 68.22613039324361, 62.561384554832216, 67.72571440665953, 65.46143993254631, 57.19111457947762, 48.26410601215978, 48.02714778530983, 48.10379482084706, 59.30549567745578, 65.39148838289323, 64.32402318523776, 61.96537648477862, 68.03672698236281, 65.25790814430484, 60.83875017781412, 58.055432381168494, 61.932408963480306, 59.94188847080354, 64.71081203030002, 67.74448687030424, 64.36673779641428, 58.36630375154557, 62.38732545606552, 63.47870142229142, 67.47840896729501, 61.009604700150035, 66.98003261320054, 43.15617984341037, 39.09391049415835, 64.17309430337721, 60.91749568139354, 61.94870641154628, 62.34827826100012, 65.22776472953059, 53.68433129402899, 48.83580323188536, 46.976509555693596, 51.25974170623287, 59.55613905383695, 63.44499649540071, 61.372745575443396, 57.813559424492624, 54.52946478320707, 57.3431025012847, 60.685577700215006, 61.53968557234734, 56.72343077198152, 48.05230194522489, 47.127352145410356, 48.41300310627107, 48.21150702814902, 49.19767718161307, 58.34045925448018, 60.33781251599712, 67.66186606499457, 59.919507426600305, 60.4618457055861, 67.66654153023997, 64.92777401401152, 61.863092837795136, 50.03893536906089, 49.89025400530908, 59.46077446783743, 68.02514814561414, 67.37797275666269, 65.38329455160326, 63.86527061462403, 66.62930996187272, 67.2874915215277, 72.81947689671671, 68.75154756730603, 78.82333909311603, 35.32974912274268, 0.05226301232112512, 2.312292129762711, 3.012028995060152, 1.6751923291913926, 0.9805816339869654, 0.45757255006221037, 0.07202725722304276, 0.10421137700998977, 0.17678136156210977, 17.342508685204294, 42.35901694143973, 33.47005928716352, 80.771525444523, 65.97032039396225, 23.67251007787643, 51.62828760762369, 56.75213467690253, 62.92804771854032, 64.3026815691302, 61.874805035129675, 1.2803661799238575, 0.055545649280951875, 0.01692911054218008, 0.020122982809440266, 0.04334278795267305, 0.035166285571552096, 0.04807686275472084, 0.050323545827620456, 0.06556958035235444, 0.032905265163149566, 0.015541527086057732, 0.08281463321538703, 0.019633745654456077, 0.018872798180147525, 0.05661564428479441, 0.0068558185105963105, 0.033790161833167076, 0.0354817797309689, 0.06212247963694315, 0.06303529638136107, 0.0811664869768485, 0.05146274921454249, 0.008219159114354802, 0.1037019745056187, 0.027898139387909925, 0.029306902302308913, 0.058883486706162655, 0.06397196910374107, 0.022206745793922775, 0.016192109061164722, 0.04186019714501116, 0.046674121291406696, 0.03737210168413097, 0.006366805915134929, 0.009515157716739322, 0.020942641347045862, 0.020206101434004885, 0.07618421883953196, 0.02489002620530946, 0.05096701754918022, 0.0465527959468384, 0.018044517322954153, 0.20193107816721165, 55.83118177229359, 97.80645755029495, 79.60456540507656, 87.72420898560556, 68.69608525306948, 52.790838902996434, 30.945521823821533, 39.002107420275294, 49.69228021560177, 51.129468025699744, 10.536709081742073, 0.11055146704518026, 0.0508407854114569, 1.239181660836743, 2.414961639911898, 1.494329143916407, 3.2230701609965298, 1.7164148462395517, 0.342720280731878, 23.383990333926295, 76.52281407387026, 78.02047698728501, 82.82643164357832, 78.84866975968885, 75.50757915742936, 71.22497850848784, 75.96928919515302, 71.32342999981296, 69.62335709602603, 70.37055292437154, 72.09707829260057, 77.38539818794497, 76.1462273136262, 74.34729499201622, 66.07033298861596, 53.78517150878907, 53.98736576880179, 54.82262665225614, 68.46356714925459, 70.60777787239321, 70.80228820923837, 64.65610673350673, 69.8526039431172, 67.2332686762656, 60.083560559057425, 49.16902034513412, 49.82151839040941, 51.64802105196061, 61.80856797002978, 70.2106535819269, 65.59516922120126, 63.16749272807952, 69.63111554422687, 65.82277651756041, 64.0398710004745, 58.80005513468097, 64.18856413133683, 62.931428801628854, 69.82943842487951, 69.03284426658385, 63.466698969564135, 61.50227792801396, 66.3257420447565, 63.79398938148253, 71.11620333886916, 63.01590488803003, 67.83878064924671, 45.205822221694454, 42.90110811110466, 66.2278945984379, 62.98352572225756, 64.51803145870086, 64.28335212892102, 66.56913295868905, 57.16271661943006, 50.72784085427561, 48.03194876640074, 53.437873086621686, 62.0925122691739, 63.30856077132687, 64.8763007502402, 62.27933083811114, 56.54860681103122, 60.43362032982611, 64.233341909224, 62.406403864583666, 60.09716726118519, 50.411650749944876, 49.972137405026345, 50.51746845245362, 50.55462898746614, 51.591397716153054, 62.7766324627784, 62.14845703494165, 69.28397009449621, 59.44446133029077, 60.92595231148505, 70.3557106756395, 67.68676527084844, 64.8158021127024, 52.23651386076405, 52.22879463626493, 63.523181100045484, 70.85314566089262, 69.51030654291954, 67.81841570331206, 67.1681494866648, 68.76550336037913, 70.83380053120275, 75.2169079934397, 73.43762674639302, 80.63298733003678, 44.31363990229946, 0.07794294986994037, 0.36031489951475976, 1.3527281486218976, 1.8752551487376614, 2.4159383100848046, 0.863768179570475, 0.33770298705466334, 0.07564263298146187, 0.04704240656968567, 20.609221343071233, 42.79556889687815, 29.72968512965787, 78.12275671189832, 60.329426488568714, 31.372901316612, 62.98923669322845, 64.31613137645107, 70.53308809957197, 70.36699925699543, 76.21150339803388, 3.6874358884749876, 0.12734089677612628, 0.0798832513992825, 0.11775144481010015, 0.08357844585853239, 0.022149612871749748, 0.0491181907484368, 0.04131507962161014, 0.03474487592616389, 0.04114650197387223, 0.006857661909664111, 0.07022793885440597, 0.02428611909459916, 0.03511888388123724, 0.01741178423887299, 0.04129429182578479, 0.03365862453656812, 0.07809441311344986, 0.04096508469252337, 0.017242756514479558, 0.036993267375134656, 0.006885432118114325, 0.026411266148751302, 0.22496398658521716, 0.12318938970565797, 0.1889918990913899, 0.12795544484810484, 0.19208796682857698, 0.09994756911070117, 0.19590110818464912, 0.19166563787767965, 0.1703903956278678, 0.13984525966788494, 0.0963405054062605, 0.07478964004305101, 0.10434072329512528, 0.12055057686783614, 0.2164693585326595, 0.11408024422463872, 0.09422404195873008, 0.21701772426885946, 0.21536792328040447, 0.34351885078414796, 67.20905980756207, 107.41956710815431, 89.72368424938571, 95.48250029163977, 78.02013181870984, 53.99770121420584, 44.50348654100972, 64.39509261038997, 60.42495581411547, 73.65704413383239, 14.194570299117798, 0.3477624263013563, 0.22028104432167547, 1.9472718262864699, 2.840261786214767, 3.025641090446903, 4.491002550048213, 6.629371883407717, 3.0248610290788838, 25.64034358147652, 79.00470164514358, 79.23065370129001, 85.68845964247181, 83.25812770474343, 77.17704188439154, 73.90074099263838, 78.10871462668143, 74.5297008945096, 73.25927657465782, 74.36905630173223, 75.23437038544687, 79.38284166397588, 77.82803766189083, 76.91891070335143, 70.1267776181621, 55.87999566908806, 56.57269408625942, 59.155143384010564, 72.19921681188768, 72.71944861258231, 73.21118047160488, 65.10323339892973, 72.82825516116235, 72.50363980570148, 62.57169646601524, 51.98465454962946, 53.16751587775446, 53.71519642491495, 62.71448250739806, 72.25733849310106, 67.03645983049947, 66.54768543858683, 70.36203353635727, 70.24356226767264, 68.51083955457135, 62.181357875947036, 66.0015816842356, 65.08990910745436, 71.44168161576795, 72.80214786529541, 66.90640972506615, 65.29544130448373, 69.21878814697266, 64.77083998341715, 71.20030680010396, 65.8336728618991, 68.79651361896147, 49.14518802396713, 47.54649662202405, 67.97196865081787, 65.96856317212506, 65.98450368450534, 69.31767894375709, 71.23025017399942, 61.51739082028789, 54.27328302014259, 51.4891807494625, 56.894661841853974, 66.83592473306965, 68.70307491671655, 69.46544247288858, 63.796625214238325, 61.638941149557795, 63.991163007674686, 68.17678697647588, 66.31442208443919, 62.518560117290875, 54.62120509916737, 52.99192313225039, 54.018340726052564, 54.83205603015039, 53.244649287193056, 66.89323840602752, 67.08833709839853, 75.19018880782589, 60.4396294009301, 61.96290931394024, 72.6369611678585, 70.71357204068092, 68.33255214075889, 54.9650243789919, 54.96778180522304, 66.77462593201669, 73.87060934497465, 72.24994874769642, 72.22253138019194, 70.81928776156518, 72.64231128077354, 73.87788141927412, 80.76706963200724, 75.92918688251127, 85.75612052794426, 45.32124973112538, 0.15321631315014056, 8.068692972583156, 8.122830996590277, 6.00355330974825, 3.9627656821281683, 1.2158480935519742, 0.7122253854909252, 0.38771378897851516, 0.31658589599593995, 28.05357006288344, 61.93000455056468, 46.77119308902372, 86.29059837710473, 73.72017075938564, 35.100419905877885, 68.12836139432846, 74.22585841148131, 81.7371972914665, 78.43276516083749, 84.00107168382215, 3.905940099108604, 0.34559133312394547, 0.14041423316924803, 0.25057468893787554, 0.1233995965712013, 0.19720819207929796, 0.20152135902354795, 0.07913012568268084, 0.16865529840992344, 0.11537611259207611, 0.18449206716350972, 0.19539918269841902, 0.11001990927803902, 0.12554497217699406, 0.1952898772733827, 0.13496481993746373, 0.1407154742628336, 0.16117271847061573, 0.09719011223604603, 0.1843521795085361, 0.1337611119473173, 0.0969586770741209, 0.14182368173233925], [0.021606360772444357, 0.07548197668286101, 0.020563090745840343, 0.0352640766950865, 0.03463293515866803, 0.003468969413417302, 0.01221266916892942, 0.052513327719944145, 0.04240122375889652, 0.02176961793954815, 0.0713137918782811, 0.05273519444369501, 0.10578302170840964, 0.058772231587359024, 0.0685698334728518, 0.044806115479478915, 0.016808765790154858, 0.0078339739364662, 0.030311046303400112, 2.775747622213056, 77.36247585665795, 72.04343595812398, 73.93884289649226, 54.62730438478532, 28.451119930513446, 16.736635854167325, 39.343875300499704, 31.940842866897587, 43.78419837644024, 37.814876571778335, 0.69867494486032, 0.04814790591837899, 0.21831691745788823, 0.3879973947280838, 0.42607662237940297, 0.8052585514322405, 2.7428190794683274, 1.5393948482890285, 7.082467905936703, 59.25306143299226, 72.90116417792537, 78.86103307047199, 78.10982073507002, 74.79431967581473, 76.0011153067312, 74.56793615894934, 71.78346126310288, 70.80141744306012, 72.78032379765665, 71.00109746379238, 74.84861312373992, 74.2103022913779, 69.89289452952724, 71.33121198223483, 57.50672417302286, 51.99679428531278, 51.52830639193135, 58.220536708831794, 66.31996831586285, 70.64231041939028, 65.22136342140936, 64.25398534344089, 66.42532317869126, 59.425790848270545, 54.54919430517382, 46.90766803679928, 49.12536044274607, 47.42558563909223, 59.844629380010794, 61.67057114262735, 65.88853113112911, 60.67601103936473, 60.44512856391169, 62.74202539074806, 65.4447502474631, 61.37169045786704, 64.38079557111188, 65.32024245108327, 68.3178432526127, 63.61888300987982, 61.54303919884467, 60.821464292464725, 63.693380586562625, 59.34842601899178, 62.33610714635542, 59.84953234272619, 65.646493434906, 40.36367193345101, 37.29257375963273, 66.41392477097051, 60.1317939450664, 66.86405597194549, 61.83976650238038, 64.44186687469482, 56.298842045568655, 48.13298509966943, 46.88663236556515, 52.4009592302384, 57.52413557421777, 62.549993991851814, 64.68859180327385, 63.52135327554519, 64.47991778773647, 65.2312909403155, 64.59177594031057, 64.54607248306274, 62.954566863275346, 50.28329903079618, 46.46642100426459, 46.51919257256293, 47.72708646712765, 46.329059600830085, 52.198051098854314, 59.64528668311335, 63.71971930226972, 63.14843785378241, 58.380883201476074, 67.71674786844562, 65.05042260692966, 62.645586075321326, 52.40277528762818, 50.47670325925274, 51.66121198285011, 62.62762161993212, 66.87459930296868, 64.19847596076228, 63.315825000886, 60.500080970025834, 64.56954002380371, 64.49767435750654, 71.30041353164181, 68.75910989699825, 81.9381481601346, 39.807189587623846, 0.11386492755264045, 1.5292897195585313, 1.821706951145203, 1.1825857816203948, 0.2965449133226949, 0.2526150415501287, 0.04985937315429892, 0.2662035720723291, 3.6017066048037623, 30.686515954232988, 39.4693087762402, 65.09500818867838, 91.76443069211899, 29.696201816681896, 23.641835181943833, 41.63439043106572, 49.45049355106969, 62.930534501229566, 70.3851676756336, 36.1592911904858, 1.0933740461064925, 0.10923925036143874, 0.09126556361274374, 0.02013851524210505, 0.13805437592729447, 0.09455083974546964, 0.020676169153903762, 0.011035285875081055, 0.009850957994199088, 0.05623864858681637, 0.018971719283370242, 0.07601899665690239, 0.059430308775195194, 0.03529355192797319, 0.08476192912747783, 0.029777699720955668, 0.012828069513723736, 0.03712873087234555, 0.06380875407147311, 0.04163544226978575, 0.05227416273086302, 0.0593990792009619, 0.05005361474750023, 0.05542728869665054, 0.09893850107947666, 0.021247362395027475, 0.04633524995898047, 0.019410622546509392, 0.017024130342648398, 0.04073239314640242, 0.06364952269641143, 0.03390487200850922, 0.024701198938512997, 0.05021612497887785, 0.03994980368823294, 0.07949292194098234, 0.02967522971542372, 0.07568790877778685, 0.074805099697363, 0.1184001220991054, 0.12341302609251392, 4.258344221499659, 89.87646841233777, 82.33713165406259, 82.18604979976531, 62.91782994424144, 41.30960249131726, 26.771794403752974, 34.63208890730335, 34.85504035026797, 43.40965517105595, 40.16955383362309, 1.082996680371223, 0.09216331140769106, 0.45061383636728414, 2.142525820001479, 1.8623528797780315, 1.3768240040348423, 3.9718300344482547, 1.26432454393756, 8.107394999073398, 62.405321290416104, 75.46848881629207, 78.07662963867188, 79.35990364320817, 78.56567859649658, 78.11211139925065, 76.82318133692588, 72.94373758377569, 72.8112320746145, 73.96007860860517, 73.85721837320636, 76.36908069733651, 76.50440246828141, 70.37427133129489, 74.60692451846215, 59.77618009813371, 52.95100496661279, 53.81553457629297, 61.498237886736476, 68.84362128473097, 72.10071825212049, 67.61754328204741, 66.55223538798671, 69.25801969343617, 62.50611051436394, 57.61634657459875, 49.61627252640263, 51.047725831308675, 50.398102883369695, 62.62477397918702, 66.48346054938533, 68.10271693814185, 63.060984688420454, 62.26213516727571, 65.79661430851107, 66.49329000903715, 65.37721880020635, 68.67763442377891, 67.17053428772958, 66.94443318151659, 64.21725234677716, 64.83669265624016, 61.80926615192045, 67.2184185827932, 60.19699550444081, 64.81655913014566, 61.09437104194396, 65.92915904137396, 41.2425103495198, 41.14903242357316, 68.5722795609505, 61.02899297591179, 68.7586784362793, 62.75829145985266, 66.18904744425129, 60.427697550865915, 49.27110002886865, 49.532816256246264, 54.81087915359005, 62.181879551179954, 66.32311405674105, 65.54624942041212, 66.13342039046749, 66.9954239937567, 68.08463481164748, 67.28214140861266, 68.32102821719262, 66.4947412860009, 54.493990867368645, 48.05736572511735, 48.292511816947695, 49.30300851022044, 48.77476722963395, 55.50849622295749, 64.12064829180318, 68.15311939485612, 65.0467630355589, 59.13373508761006, 70.56036426175025, 67.66831444155785, 64.9817419052124, 54.969162479523696, 52.33530659829417, 53.53395546636274, 64.44857020531931, 69.13300591130411, 67.73216278322282, 66.50706537308233, 62.12762140458631, 66.57791906787504, 65.78110133447956, 73.34511372350877, 70.89979833172214, 83.34134471031928, 48.24163475344258, 0.23568373233560594, 0.7167905340752294, 0.7151256105111492, 1.8508798244499394, 1.9144787278867539, 0.7851292541430843, 0.13055425257452075, 0.29240267591611036, 3.1028024467729756, 39.2423878946612, 35.86930644127631, 63.3735191437506, 77.64572589628159, 35.356735029528224, 38.008441617411954, 48.41114782517957, 55.48552682322841, 68.3659315109253, 78.78376237807736, 49.04626192585115, 0.9365781564866343, 0.046625038038098046, 0.06864345452237515, 0.049721599901996316, 0.021484062496212222, 0.06197867344223684, 0.06479511908706158, 0.012680338076015395, 0.08294854538455125, 0.053824130971465385, 0.041537723924604156, 0.07242521691706873, 0.03405533933771714, 0.017310921102762222, 0.05185218234997123, 0.06650456768130103, 0.04982441273187438, 0.06985544392298307, 0.03061337907227778, 0.0366852808773758, 0.039146296199290984, 0.07021778052853, 0.12151914183050395, 0.2651287200710466, 0.15268947448461287, 0.1688433729953343, 0.10567527910273884, 0.11036546089716497, 0.07196462953523283, 0.15166187478650003, 0.1703154415853562, 0.13517768512810432, 0.15177110360274393, 0.1706656203755448, 0.21828451193869117, 0.14465005587666266, 0.10088608044409945, 0.19615365672976742, 0.07446862622013978, 0.18797687855699372, 0.3205170608576267, 5.207283237288076, 102.35264147481611, 90.0330964980587, 95.55076522211876, 71.1605025875953, 47.07207810494208, 25.833475205206103, 55.626849820536954, 46.55865946123677, 60.7478767056619, 54.49683850811374, 1.4264877068419612, 0.17496985473459767, 0.8551001704988942, 2.974684108649531, 2.931200222622964, 2.8923859182865392, 9.128067301165673, 4.89060087550071, 7.706220861404174, 65.52551969405144, 77.96688172125047, 81.53059036500993, 82.72026877249442, 81.08893148360714, 79.88062181780415, 80.71734966770296, 75.73676324659779, 77.52467370802357, 77.74140819426506, 77.5855645825786, 78.0646977886077, 77.49600902680429, 73.6660106720463, 76.75378676383727, 63.319829740831935, 56.86086277807913, 56.46411503514936, 63.076650634888686, 70.71724337916221, 77.04921968521612, 66.98667710827243, 67.85467409318494, 71.63915726446336, 65.79845782249205, 60.07281326478528, 52.32295897699172, 54.102969784890455, 53.3101293348497, 65.14219822422152, 67.76791910971365, 70.2950551432948, 64.96003550867881, 63.061035679232695, 67.89483916374945, 69.37722052297285, 68.23122162972727, 70.83668739564958, 71.35336552896808, 71.1851115380564, 70.06509442483225, 66.19915931455552, 66.00009118357013, 67.85290902660739, 62.77616962309807, 66.35711316139468, 64.20071171176049, 65.95664701154156, 43.75087391945624, 48.25393922867314, 70.86626991148918, 64.45572853088379, 72.47586158014113, 67.39557635399603, 70.1747089816678, 63.78021401743736, 51.08441568190052, 51.39204325214509, 57.269848315946525, 65.17055696056735, 68.0068620558708, 68.77461110391926, 67.7778034825479, 70.2703599006899, 70.7520975605134, 71.28426121127221, 71.1213259543142, 69.19762303752285, 56.002381463204664, 50.662227446033114, 51.20914705338017, 51.447858579697154, 50.61584934111565, 58.391971741953206, 66.84776244624969, 70.72169919167796, 67.64710226366597, 60.125455394867934, 73.16936800556799, 70.86903910483085, 70.96342702065745, 57.85829405630789, 56.70499170980146, 55.92192972860029, 68.4825357314079, 72.67432566611998, 70.56852279170867, 70.05738304507348, 66.21274640483242, 72.06106308967837, 69.95019251300444, 76.33133180679815, 75.16091223685973, 87.76149503646359, 50.10580393575853, 0.31585112574600405, 6.807193515762207, 7.017518849142137, 4.730387253146018, 3.119066309544348, 0.7852618792845357, 0.16322306086940153, 0.37661982459887383, 5.292097628116608, 50.564529049781065, 56.265647026800345, 70.28014229189965, 97.95210299953338, 40.014871243507635, 35.04603232106855, 57.03647513543406, 66.12674451643421, 79.03921065791961, 88.23109688297396, 54.38491759761688, 1.3777435546921146, 0.23990807904591485, 0.14648315106188098, 0.15426188527095705, 0.22775112170605893, 0.1709052833217767, 0.18366253183734033, 0.1820753049105406, 0.1878293300227773, 0.16644983852822937, 0.09956916764138207, 0.1982765016897071, 0.15728742695383488, 0.11992464472930278, 0.22742240869950867, 0.13561248599040893, 0.11250611740134417, 0.10277955101863032, 0.18333391076134098, 0.1595802821459309, 0.15959241697865148, 0.09574386846995163], [0.05855227242253962, 0.07502589389801988, 0.03576735432650294, 0.08121941599153704, 0.05745186372810314, 0.03440604289813388, 0.010855404600020378, 0.07781542687406463, 0.07888229623917611, 0.08563579796182533, 0.01926535695430733, 0.03671893895032906, 0.06322172387773473, 0.03771699063720242, 0.011833802301196322, 0.05659713177010418, 0.04577030224965946, 0.11449495060068947, 0.17850296031082832, 14.794713527925554, 84.2674712211855, 71.82205738559847, 86.64741639168032, 58.399941998143355, 38.24461537022745, 28.96693514239404, 51.329512826858036, 39.58353211802822, 65.91849019450527, 12.257547013221249, 0.08219855296755992, 0.17774822580958569, 0.1265460269285306, 0.7449854501793463, 1.820950914294489, 0.9217116380891494, 2.370888908063212, 0.2427239731074341, 36.4658675655242, 75.30854240540536, 78.48261064098728, 74.48639792780723, 77.52534835569321, 79.20981807093467, 74.41119040212324, 71.8414495837304, 73.91637556014523, 73.24689757439398, 72.54773509117865, 72.95384945407991, 72.73917813454905, 64.65600475188225, 67.92373918717908, 70.60491454216742, 52.844653821760616, 47.98731611620996, 56.76780454574093, 66.86779006834954, 66.90975942919331, 66.79279435065486, 64.98866488856655, 65.9537366128737, 63.170305067493075, 55.06377397045013, 49.98543816228067, 49.16779656564036, 46.243857875947036, 49.069392142757295, 55.75874343995125, 63.70970156884963, 65.96677457132648, 60.71440319861136, 58.867178655439815, 58.84431908207556, 62.126146593401515, 65.56427663372409, 66.10489691457441, 57.94671604710241, 56.49137550784696, 52.696117585705174, 65.11394539187032, 62.01809706226472, 60.48101825098838, 61.218745477737926, 63.98852325254872, 58.37666273117066, 62.8825560692818, 39.28991917640933, 37.78252486259707, 67.25716375535535, 50.50051989093904, 57.59252994291244, 57.20538023979434, 64.80667083494126, 50.56974972448042, 48.256390710030836, 44.96772650749453, 47.31863437160369, 53.15816494726366, 64.14103284958871, 62.16268347155664, 66.3379406159924, 56.70164592804448, 62.76548508674868, 60.22851174877536, 60.855196675946644, 64.00511095600744, 55.76602728136125, 46.346749490307225, 45.90053281476421, 45.49553632736207, 48.56273566522906, 48.75902283576227, 57.61840189656904, 62.05739528902116, 65.79084842435776, 60.20859787541052, 66.67441721885436, 63.04840564727784, 60.20164743546517, 51.378973914730935, 51.65137467845794, 50.08367392324632, 55.88275701768937, 59.40952085679578, 63.58235789883522, 59.289865032319106, 62.213666439056404, 58.86291503906251, 65.76600020931613, 63.212647053503225, 73.14446879971412, 66.48058152967884, 80.65605086665, 40.11830022258144, 0.7067010948254216, 0.9347668181984656, 0.74536046554004, 0.6792006221029067, 0.48838246133058305, 0.2326568270162229, 0.036236962393647244, 0.16279510883313997, 14.374510011365338, 27.299131578014745, 58.483551240736446, 56.255503777534734, 27.252416149262462, 15.015425297521777, 43.51517869580177, 57.54445737408054, 59.79733344047301, 54.38792213316887, 73.12519427268737, 15.616754062714117, 0.6557444194632193, 0.16205555819455655, 0.07288408826195425, 0.033360895956115376, 0.061363669547943346, 0.053575217513547796, 0.08320949025331967, 0.049045983131133744, 0.02409186409485917, 0.0643493018804058, 0.023386186033847834, 0.055421500902382605, 0.0717806228766999, 0.08627143643435933, 0.06033449553914609, 0.05499386679260962, 0.04414091367394694, 0.04616562277078629, 0.09155836241740374, 0.04738318546104336, 0.00968699794142477, 0.021905382126269322, 0.028963336766126658, 0.017711948978924946, 0.012732121789257133, 0.016408576780269225, 0.02734228322703031, 0.008621404112707223, 0.06125417260092594, 0.04095176625395975, 0.0183865430224086, 0.03302711144750638, 0.007195532539739244, 0.04029428661470452, 0.06224997581974153, 0.014877922573847877, 0.04882329286286428, 0.04471557154770821, 0.04602431785315276, 0.21677393976959491, 19.94051410305885, 98.18921812119024, 78.82975609071794, 96.98789811903431, 67.41579224986415, 43.77766370773316, 24.241728359653106, 47.07455312052081, 38.581343004780436, 61.79845217735537, 15.174491136304795, 0.03798208004164119, 0.049305054914927295, 1.0666280167718087, 2.0436116115700815, 3.6350518993792997, 3.3991149596629606, 1.2996724536342006, 1.7846555070530985, 38.570364290668124, 79.80593988972326, 78.29503505460679, 76.8656292269307, 77.86946573565083, 80.91369567378875, 75.19182051381758, 75.41816480698125, 76.88671588897705, 75.43747071296939, 75.81100586921939, 75.49618074970861, 72.12275412774855, 68.73424991484612, 71.23377246241417, 71.86923565403109, 55.22859196509085, 51.551707252379394, 59.653437368331424, 69.00757635793379, 71.49355103892665, 69.4474309490573, 65.94759418118385, 69.41938600232525, 66.12589728447699, 58.53455774245724, 52.578501393718106, 50.42290795233942, 48.43820041225803, 51.34956790554909, 58.59119284537531, 66.12738778514247, 66.38770764873874, 63.9331276186051, 61.11205308668075, 61.13616389612998, 62.57808208465577, 66.09934283841041, 66.59288683245259, 59.766076072569824, 57.17926117681689, 56.921349648506414, 67.27930945734825, 64.00238098636751, 63.06799396391838, 64.3456668238486, 65.09536904673423, 61.27369003911173, 64.00843712591356, 40.9921964522331, 41.32220114431074, 70.48128927907636, 54.03230436386601, 61.41575828675301, 58.747483607261415, 66.52749307693975, 53.07014303822672, 48.870084747191406, 47.71387592438729, 47.239579000780665, 55.94242411275064, 66.52311571182744, 63.97236700980895, 68.27483054130309, 58.91544734278033, 62.14207533867129, 60.947172334117276, 65.95579977958434, 65.71087521891441, 56.83320614599413, 48.14725075998614, 48.37079055847661, 47.02453113371327, 49.81971802250032, 50.30230291428105, 60.79517264519969, 65.45491310857958, 68.0437009565292, 60.94953752333119, 68.02515599035448, 64.76766678594774, 64.72040222537133, 53.11030418642106, 53.83411092142905, 51.86036248360911, 57.5156161862035, 62.353440100146884, 67.5916870178715, 61.62589534636467, 65.78454517549085, 62.181326496985655, 70.0496873547954, 65.96964574629261, 74.0867397862096, 69.54545882440382, 85.19500194057342, 49.61701777673537, 0.4746400697096702, 1.2440150014815794, 0.7998773047039587, 2.353698140190494, 1.5014475103347533, 0.7004637295199979, 0.17873333827141794, 0.2788721535715365, 20.513137002145093, 34.33582836581815, 51.36787752951346, 56.52774764645485, 20.455821368002123, 21.766367612346528, 53.1171134210402, 64.43366912103468, 68.47291023500505, 60.75028896331788, 84.82730327113983, 23.635771197657434, 0.6124754670646884, 0.14424496390406163, 0.14791682332513795, 0.04607203363951656, 0.0570599063329639, 0.04915672497102811, 0.013080650617578819, 0.09474328103204889, 0.027830650872220437, 0.038173169183034095, 0.10693350190957708, 0.11560599259551495, 0.07539742355865818, 0.04613195703695378, 0.016274852302646445, 0.02226479610638513, 0.0973041827279714, 0.034753934915868506, 0.04977588489231083, 0.042119445129027294, 0.06128405002997287, 0.27961099940922957, 0.22416203042432187, 0.14819707360959825, 0.14452559723248407, 0.11628612545469116, 0.1656092102489164, 0.05359592870058072, 0.35620952625909164, 0.22677655061406476, 0.19684203269500888, 0.11676109230686581, 0.1413806071204524, 0.21375909267414003, 0.14266378907186372, 0.12547480618400922, 0.2440893716148792, 0.20171767671502408, 0.22035377670920667, 0.38666293085102116, 25.204974220645045, 111.80527117944534, 89.09176688040458, 106.69352069977792, 75.18020245336717, 53.1478020452684, 40.44550434235604, 71.04254122703307, 51.68146710241995, 90.98258464567124, 18.860216871384655, 0.3707268924242066, 0.17916029439337794, 1.5862547918673486, 3.2841524962456, 5.018035740621629, 6.315066968241046, 7.33617514371872, 2.9398054124847537, 38.96988907167989, 82.7020925091159, 78.58434907851681, 79.1982235447053, 80.9848710029356, 84.72864781656574, 77.7497471532514, 78.20980195076235, 80.77760511829008, 77.4349847916634, 76.39081847283148, 78.0725739079137, 72.94125080108643, 70.50322317307996, 73.38177219513925, 76.48021713379892, 58.193974418024865, 54.656463284646314, 63.193282311962506, 73.17373752593994, 74.16356332840459, 71.2655750397713, 68.79406605997394, 72.43000907282676, 68.15452360337781, 60.72862571285617, 56.27209148099346, 53.20031865950554, 51.059257599615286, 55.31080092153242, 60.427446519174886, 68.10197168780913, 70.55393157466766, 64.57532551980788, 61.52932267035208, 63.669281544223914, 63.76814488441714, 68.7393097723684, 68.48646594632056, 61.26520987479918, 57.192118706241736, 59.109412470171534, 68.45548706669962, 64.49301458174183, 65.64780742891374, 66.90445638472035, 66.95367428564256, 62.93264865875245, 64.55261107414, 44.15115179554109, 46.245195404175796, 73.90665592685824, 57.61898632972472, 63.394064518713186, 63.546570193383005, 71.00629852664086, 56.57678511834914, 53.144315058185214, 50.16024643375028, 51.06145804928195, 59.379863815922896, 69.79248185311594, 67.84096933180287, 71.00812635114117, 61.411490748005534, 63.4726256708945, 63.579372975134085, 68.2071304321289, 70.29673391772856, 60.83352558074459, 50.363942961538996, 51.35435711952948, 49.512972985544515, 53.4040230320346, 53.423250490619296, 64.41143712689801, 69.33340764814808, 69.61351979163386, 61.13292794073782, 70.65694086013302, 69.20344383485856, 66.54377091315486, 57.996616440434615, 56.699084620321955, 55.650129087509654, 61.12830346630466, 64.65862097278719, 70.20535053745394, 66.30963679282897, 68.36195422757056, 65.04784560972645, 73.49064150164205, 69.45305562788441, 77.95325540727185, 75.06534760998142, 87.08531764245804, 52.83971163534349, 0.9418110273057415, 7.082129111213069, 8.910565010962948, 3.7419320739084676, 2.765765190124512, 0.978176914636166, 0.22117368997104708, 0.5521903535531414, 26.50176863516531, 46.881576430413034, 70.95118138097948, 62.22216229284964, 35.59840010058495, 24.75056371381206, 58.13413081630584, 73.88444746694258, 78.71370100205945, 69.80856357082244, 96.3043466691048, 25.769742573461226, 0.8162435781090491, 0.2579890870519223, 0.16822739233893735, 0.18860686330064652, 0.2121949249938611, 0.1689000175364556, 0.142626756381604, 0.14597206316407652, 0.12123326846067944, 0.1858474912061807, 0.1647049353848542, 0.2169231124102108, 0.22339683116203357, 0.21082517510700613, 0.1395713525914377, 0.06315009848725411, 0.1844182009658506, 0.12799569510764655, 0.1607512322164351, 0.18008096353901973, 0.10512132092469162], [0.03934544841608694, 0.04069044600210844, 0.010400350288217588, 0.04672344969285112, 0.05284530809149147, 0.017168641338245045, 0.0629557496417434, 0.06053490030969824, 0.019828584796238332, 0.019094475297137134, 0.057108725285938675, 0.05084620548352119, 0.05873676937734408, 0.0957552831800234, 0.016809572097695163, 0.02001423662858865, 0.056374797732719494, 0.017651527624336943, 0.3140310540554985, 49.57286757807578, 74.86893884597286, 75.8557601128855, 59.177869596788966, 43.354310527924575, 25.693219092584428, 44.032354970132154, 47.889523583073775, 44.497489237016254, 43.378397803152765, 1.641511917114258, 0.09237404687390213, 0.10356797040590357, 0.07531233417290835, 0.8684161269376356, 0.41918648887545834, 2.0735631979280904, 1.3639012652058757, 5.340336407384565, 64.96156523304602, 82.55672947052987, 78.78631191868936, 77.70420843555083, 76.22186630002915, 72.55026109756963, 75.00225236338954, 72.22952888857934, 71.77146665511593, 69.69069634714435, 71.99389642284763, 64.89584592080885, 71.96629862631522, 59.115241112247595, 70.67301473309918, 61.732285714918575, 49.018950462341316, 49.84103610438686, 62.758189478228175, 65.09446297922443, 69.04821995765933, 62.650559640699825, 65.81842268666914, 64.12739869086974, 60.95969253970731, 49.28610701714793, 45.60721012853807, 47.32272932606359, 45.83455070372551, 46.77017719514909, 53.753714100007095, 60.22706439418178, 61.170323817960686, 60.80781836663524, 57.305024131651855, 59.84691612182125, 63.07274787656723, 65.52264067434496, 64.66335527358517, 55.55445463426652, 58.105850527363444, 57.79577932050152, 60.613398244304044, 58.94582609976492, 62.758264003261445, 58.16501163667249, 61.86889010090982, 54.94537722679877, 60.61884249410322, 36.90167819300006, 36.26146893347464, 64.34498433143862, 50.715336338166274, 53.476418218305035, 48.83544629619968, 50.37824000081709, 42.78075018236714, 47.17740158880911, 43.163875533688454, 46.21248675930885, 46.10979126345727, 57.00240150574715, 61.99268010354812, 62.773376895535385, 61.933369944172526, 47.233267907173406, 46.630960510623076, 61.85937050850161, 61.4341934265629, 54.87074236715994, 46.39566536872618, 46.39979562451763, 46.03979264536212, 44.69980509050431, 48.558075889464355, 57.526112448784616, 62.662813125118134, 63.90322739078153, 63.390891321243785, 64.51201454285653, 62.89332297540481, 59.99198498264436, 51.66453030801589, 48.77176269408196, 51.59653209870862, 51.192367153783, 55.647956094434186, 58.13468387050014, 62.950985739308024, 59.62183483185307, 62.02283528543288, 59.83345846976004, 63.781437796931115, 62.55478320583221, 72.12723347448534, 65.02836319708055, 83.50031052866291, 28.80674554455665, 0.7598460850215728, 0.5245115355618539, 1.7703226761471842, 1.0376875438997823, 0.773576464383833, 0.06515930962538527, 0.18861581120760212, 2.8348413157847623, 19.3293107709577, 33.99551568492767, 29.758849913074126, 42.04701592845302, 29.796828262267578, 18.201415577242454, 31.57370117402846, 45.267823127008256, 58.781317972367816, 62.058167995945105, 61.52659270071215, 2.6046320171125474, 0.11190570365156859, 0.04322759897237824, 0.04495884276806347, 0.03221829496924916, 0.026552739605728178, 0.011884734699232204, 0.019385054362036528, 0.1150227468761225, 0.010828718884787973, 0.02907021752288265, 0.043508017796181866, 0.05101895448000682, 0.06393141240902966, 0.013873561195308163, 0.04145071931904362, 0.02946890116999707, 0.0033501984932715256, 0.06335551347283107, 0.10818695198864707, 0.06964736678186925, 0.05580172566096148, 0.016952610289257382, 0.04109468761711352, 0.022029074682523648, 0.05635247393060596, 0.054513211737597184, 0.07758880274430399, 0.0408992470963107, 0.015453733409935189, 0.036232679962150516, 0.024365775001746033, 0.022786563269854076, 0.06762877106666565, 0.11097846147153648, 0.018276913925224257, 0.03791493626551763, 0.07705703813342318, 0.1373408875998951, 0.6750879556901994, 63.41848519540603, 84.69683739446825, 83.47103395769673, 69.90110012792772, 54.39913618949152, 41.4703647551998, 40.259238827613096, 44.24328042614845, 50.39865201519382, 43.16784497230284, 1.994632362358032, 0.14031402886875216, 0.1794387673538539, 1.849019027525379, 2.520767575310123, 4.098043326408633, 1.4110395744923623, 1.0447250114333246, 6.557571916810929, 69.53707279697542, 82.79068316182783, 79.79738912274762, 81.12979473606234, 77.56749030082457, 76.27366512052475, 77.1259412457866, 74.52813979118102, 72.64627287464758, 71.87568403059437, 72.83691575450283, 67.8620324596282, 71.40329730126166, 64.1299403867414, 71.94342336347027, 64.18200200603854, 52.34983113504226, 52.96480778724917, 64.48797433607041, 69.51578217168009, 71.80912140877017, 63.038360457266535, 68.62365476546749, 65.85335531542378, 63.00324739948396, 52.871380852114775, 49.44439426545174, 49.17985785392023, 48.60080619012156, 48.64158315043296, 55.72006102531187, 62.10941768461659, 64.24872544503981, 62.23552973039689, 59.886026074809415, 59.32554683377666, 64.64884642631777, 68.214598624937, 66.6978886819655, 59.27078662380096, 59.410175892614554, 57.13718198960828, 61.538583386328916, 61.99513158490581, 63.27363990968274, 59.511329896988414, 63.829839844857496, 57.78739329307311, 62.12118087276336, 39.56015871417138, 41.18065457190237, 66.37093559388192, 52.73183076612411, 55.229956949910815, 51.734195524646395, 52.53229587308822, 45.999278483852265, 48.90584499605241, 46.34653375994775, 49.55748404225996, 47.38838588037799, 59.97260847399312, 65.05610219893917, 66.39650944740542, 63.28639153511294, 48.2352138334705, 49.77157877337549, 63.91761072220341, 63.14854768014724, 58.872403252509336, 48.8165287048586, 48.811202126164595, 47.3416704516257, 47.412265269987046, 52.023819415800034, 59.814572257380334, 64.17136061576106, 65.46763727741858, 63.51763486862183, 68.47549115457844, 65.85155886988487, 63.15387818121142, 54.67390214243243, 51.83445522862097, 53.54062349565568, 54.84551760458178, 58.14319149140389, 60.80528843787409, 65.42465202270016, 63.10387580625473, 64.2145262995074, 61.802139205317346, 65.89392831248622, 65.1783428653594, 75.81750131422474, 67.54296333559098, 87.21893710474815, 36.287419334534675, 0.6455773295414063, 0.42638023834555383, 2.010202578479244, 2.5269423665538913, 1.4790504089286252, 0.1266747450215682, 0.20411236031401545, 2.259512471575891, 30.702301532991473, 37.67540493319112, 34.55383762236565, 32.63308825031404, 25.34800737134872, 27.778198103750906, 42.3655241535556, 51.16456147163145, 64.78678049579744, 68.27053162359422, 74.32647505114156, 4.759773160180738, 0.2599267685605634, 0.09604035981840665, 0.059563592752261516, 0.06817729002045048, 0.06242121562301632, 0.023376678882707513, 0.06708325517754402, 0.0763678730976197, 0.051974476795763745, 0.027766866391644846, 0.050659145964610006, 0.015953032172194893, 0.04695335650936731, 0.07161485677164409, 0.06028276928249867, 0.03875571776241545, 0.14465466772596683, 0.02095282840121898, 0.10363792189426961, 0.034956247245352116, 0.10348730900835607, 0.13285072370161935, 0.18487907946109775, 0.1408944630454625, 0.15794204908513254, 0.23474049423971485, 0.18580601520596013, 0.16833035455596063, 0.1137428054766309, 0.11088853807098444, 0.07215604426399355, 0.17578601416560913, 0.13332533049246958, 0.2037120640518204, 0.09283366898495345, 0.15855478152873057, 0.1937487075525907, 0.23959582160797813, 0.8509881169565263, 75.90384052645776, 95.36139319019934, 95.12357204191147, 80.17804730323054, 59.68697755567489, 39.246906465099705, 62.47528460717971, 64.04957102191064, 59.41378447317309, 59.32311104189966, 2.5124126816949537, 0.4146477550027832, 0.2851863115304901, 2.8512417260677587, 3.257600256512242, 7.8985483992484316, 7.623747144975971, 6.470940978296342, 7.472624105791892, 73.86245865975657, 83.98500565559634, 84.45798858519524, 84.3607138049218, 82.22499893557641, 76.13931609738258, 80.5266518746653, 75.61245549109675, 74.68640742763397, 71.07328476444368, 74.06799870152628, 66.81052346383372, 71.47744578699913, 67.40993222882672, 76.51161178465813, 67.64674140561011, 56.75846930473082, 54.77440895572786, 67.73636756404754, 71.20364865949078, 74.65446364495062, 63.561847825204175, 71.89963402286654, 69.13390805644374, 65.30458827172556, 54.76809393975043, 50.42863853516118, 51.71104961825956, 50.907344202841486, 51.417283704203946, 60.81653387315812, 65.68044939348775, 65.15660508986443, 63.852303258834354, 59.779839669504476, 60.3611506185224, 66.08287672842702, 72.07579551204559, 70.45245985830985, 59.46772883015295, 61.566130192049094, 59.204541713960715, 62.72582207956622, 62.9799916667323, 64.61845982459285, 62.40050069747433, 66.29430817019555, 60.87462417541012, 62.585205108888694, 43.98798904111309, 44.874036773558586, 71.01892071385538, 56.90399316049392, 59.07838259973834, 54.407259418118386, 53.80127283834643, 48.53740107628607, 51.71897672837781, 48.40269119508805, 51.8844223022461, 49.73290812584662, 63.56113787620299, 69.73932589254072, 68.7655504288212, 65.94328741873464, 50.499241198262865, 50.730990517523985, 66.76223124227216, 67.99817792830929, 61.46605091710245, 52.74466083895776, 51.79208970838978, 51.2316143897272, 49.91551014684862, 54.97634826167938, 65.14401428161129, 68.79915729645761, 67.41323486451181, 64.26745084024245, 71.23670639530306, 70.23080671987226, 65.05779274048345, 58.44738698774769, 55.93986672739829, 57.06125274781258, 57.004123426252804, 60.131640972629675, 63.74787799773678, 69.65304159349012, 66.73372345585977, 68.2165833442442, 65.3617254380257, 69.56048934690415, 68.99355780693793, 78.91764071679886, 70.52623964125111, 92.75227177527644, 35.487098924575314, 2.115622037841428, 6.86139282680327, 5.672012029155608, 5.819592187481542, 2.037616759057968, 0.19913357021587513, 0.31551055369838593, 4.334805434749973, 36.46376517511184, 48.707012207277366, 40.41676121373331, 56.15113735198975, 42.88681891656692, 29.985056923281764, 47.576318402444166, 60.30768871307374, 74.96740602677869, 78.09133068207773, 85.74304334578976, 5.748189360864702, 0.6249852538589509, 0.2059083768436986, 0.2309067297967211, 0.15501304980247252, 0.11966104153543712, 0.13267435493969149, 0.18237622424719796, 0.2417304949654687, 0.10841266447377783, 0.14497313047609023, 0.22388842978304435, 0.13837208791125205, 0.20372223769945486, 0.16561206009599472, 0.1634061865268215, 0.15940429642796516, 0.21259194239974025, 0.10438605271760495, 0.21961342933918201, 0.18407093330977425], [0.03035979822368151, 0.14390649093735602, 0.02162805063680055, 0.03503188310611633, 0.0155699958709339, 0.07996989594351861, 0.06500647508449132, 0.020926676074703856, 0.02816279212223186, 0.005660805618390442, 0.02199438239087261, 0.0551571048075153, 0.016249289863833016, 0.047338070543182474, 0.03535326848167085, 0.033484182485769835, 0.09055554566364135, 0.21663369971417615, 7.716106214830953, 77.66809909574448, 71.76463388627576, 72.81495048153785, 45.25965282993932, 38.26338783387215, 15.73468110253734, 66.0335333116593, 62.72186048569218, 47.12554393276092, 19.100673852428315, 0.014695806237268112, 0.12459866972940585, 0.1947090753744687, 1.0850736979515323, 0.3987411037087441, 3.3651381634896804, 1.5766471912783961, 0.5645705182706157, 33.90022170159125, 77.34101264707505, 73.42804831843223, 81.70262552076771, 71.08525583820959, 76.66252105466782, 74.18919993985084, 74.3662400399485, 69.2106060827932, 73.36152492030975, 65.60729326740389, 63.848451491325136, 72.01788563882151, 61.21859642767138, 61.30861090075586, 70.81875431922175, 55.54288364225819, 51.04844362505021, 50.954216526400664, 65.64620710188343, 66.34951945274108, 63.42613381724205, 59.17657913700227, 65.8754696384553, 60.44665436590872, 58.005316257476814, 47.973783939115464, 47.97026165070073, 45.388184978115945, 45.010582323997255, 45.16467655858686, 53.45963047396753, 57.56062146156066, 62.36955711918493, 62.26974064303983, 63.196957572813965, 63.38729450779577, 64.63188609769269, 63.09358742929275, 63.205822129403394, 61.996237693294404, 63.109727982551824, 54.868259506840865, 63.55423058232954, 57.88062018732871, 62.00989146386424, 56.42785664527648, 61.43972004613569, 54.680083797824004, 63.09001807243594, 31.95071351143622, 39.842455617843136, 67.00624973543229, 47.16836052556192, 50.8411189048521, 43.69610194237002, 47.42905301432456, 46.76614499861195, 53.06383194461946, 48.73849315028037, 45.7774684506078, 42.85602831071423, 45.73754656699396, 53.682154378583355, 58.99130598191292, 61.99652794868716, 61.58829550589285, 50.89124287328413, 58.66389397651919, 61.4693300185665, 54.7920713886138, 46.992238260084584, 45.43422183682842, 45.11463888229863, 46.6058926428518, 47.76888324368385, 56.27098929497504, 62.17504678233978, 63.027981865790586, 61.48974595531341, 64.01571312258321, 61.809803516634055, 58.73302575080626, 52.426748814121375, 49.452996023239635, 50.328716155021425, 48.939993150772594, 49.52576383467644, 56.207493966625584, 56.45873746564312, 60.57758308226063, 58.736661787955995, 62.22476674664406, 58.63754741607174, 63.25191782366846, 63.57439156501525, 72.43773614206623, 66.26343911693942, 82.35188761065083, 12.143758073929819, 0.9600942365584836, 2.1467443291218054, 1.7496956668553816, 0.4687365961651649, 0.14312325796533015, 0.19584412656484113, 0.5207584401772869, 11.385428597850185, 28.630450694791733, 21.20480187477604, 15.982193446928456, 39.48582979940599, 12.574073460794265, 21.93916370791774, 35.49452397131151, 54.63452154590238, 52.79178811657814, 70.9499889804471, 30.31446541509321, 0.2852387119445109, 0.10821378804863462, 0.06758441457584982, 0.033258186548107097, 0.08413157666162138, 0.09641283942807106, 0.07361584012546847, 0.01166659307801315, 0.10321086618087946, 0.06484516761115482, 0.0030782176491488977, 0.04735590123962011, 0.04404401887328394, 0.10728457702263709, 0.05319349505307694, 0.02492974211852397, 0.0062922722633717764, 0.031606161989451896, 0.023583283219786904, 0.02515486471595303, 0.01634339227401201, 0.0720902449721771, 0.13961028517974963, 0.02716187143608207, 0.03467371018843786, 0.04739419797495489, 0.034354439215554346, 0.03762030268027898, 0.053336259368206226, 0.031194500812900164, 0.05703960883341009, 0.004936445545735619, 0.10631609632964097, 0.09490336276470654, 0.08247321081017295, 0.06485229988972988, 0.1310927357764975, 0.22759240360990649, 11.147593721266716, 93.05717329825126, 79.29966388210174, 84.42585652874362, 55.533799432939105, 54.19511802734868, 23.425114423997943, 57.08157847004553, 50.75073180660125, 41.7861077093309, 21.989940750983454, 0.03441780234777159, 0.04906652194838371, 0.6452408024380285, 2.414625051521486, 3.0946806890349237, 4.016194737726643, 1.1762032273315615, 0.37699888490380784, 37.81084045287102, 80.8184919049663, 75.43866311350178, 83.4263660061744, 73.18133123459356, 78.75850231416764, 76.66182287277715, 77.19805794377481, 70.96257194395989, 74.74552539087112, 67.91612978904479, 64.42984088774651, 69.7419931042579, 62.342720262465946, 65.2803990148729, 72.72279831670946, 57.85155934672202, 51.13553200998614, 56.05804774069018, 68.22063123026203, 68.94190019176853, 65.31813221593058, 59.563544488722286, 67.49216079711914, 63.84166579092703, 58.02090375654159, 48.941079647310325, 50.28661343359178, 47.373947635773696, 48.82242010485742, 47.380246962270434, 55.69712300454417, 59.238752626603656, 65.45870211816603, 63.41156221205189, 65.17885277348181, 67.02538305713286, 68.26095319563343, 64.66398285281274, 65.91590143019154, 63.55410114411385, 65.08510028162311, 55.54285226329681, 63.53553656608828, 56.39050391412551, 62.5467227351281, 58.462233158849905, 62.61659583737774, 55.57861643452799, 65.38336123189619, 35.11141038710071, 43.51390784786594, 69.13091136563209, 49.882868182274606, 52.84744262695313, 45.939960479736335, 50.953200632526034, 48.80477728382234, 56.49627454819218, 48.00126406454271, 47.63243575249949, 46.053226763202304, 48.77843856811524, 55.011735885374016, 62.23460405103622, 64.77245599992814, 63.292431985178304, 52.01297013990341, 62.6250877688008, 63.88478832860147, 56.63440865855063, 49.817474426761756, 48.766259608730195, 47.79744594327865, 49.65792417526246, 52.14721325905093, 58.17824179126371, 65.87070788106611, 66.47367815817556, 61.71581960493519, 67.31214754043087, 64.19341610323998, 61.487647487271225, 54.61640019570628, 53.28253938305763, 52.28495121002198, 52.52832251210367, 52.00014398943994, 58.63045184843002, 57.438808333489206, 64.40937396018737, 61.37798586199361, 63.01967036339545, 61.59430457699684, 66.19216965090844, 65.39566962949692, 75.22672176361084, 67.05334955646147, 87.38201356703236, 16.187810955509065, 0.8776976192189802, 0.7829993458524828, 3.8345027066046193, 1.5961674793112663, 0.5910396527859473, 0.15674630840939863, 0.48271926360264905, 11.991563247096154, 38.220253529087195, 24.32044052308606, 15.960596876759684, 31.522412261655255, 15.603364071538373, 30.859304205063854, 45.50555406078216, 61.86379494205598, 60.33922456925916, 80.42623135351366, 40.27247682694466, 0.21687890913697982, 0.06766862296048673, 0.02831736568271393, 0.03137213553512289, 0.04681230057030917, 0.05893335136915407, 0.024937563876230872, 0.018704810420111306, 0.010674202780900224, 0.1407525375966103, 0.055857435574815165, 0.009207843461134022, 0.10386335092686838, 0.032703213303560213, 0.05809133264025854, 0.006977908027869079, 0.03547174397916083, 0.04406626223616543, 0.027148847941369302, 0.03233382485867028, 0.10959812424956791, 0.2106071464837559, 0.22260973710686932, 0.095897852142732, 0.1161812556787364, 0.13097435987043765, 0.1181791440373467, 0.0863338572784297, 0.1572616404343036, 0.1001253474744097, 0.17921586641140524, 0.2254685167703898, 0.2178803086280823, 0.18648645450030604, 0.15720321856919797, 0.22964852231164135, 0.2642384952595157, 0.5872594685323778, 13.670183727818152, 106.77168569257184, 88.21703126353603, 93.98000501817273, 62.096697438147764, 57.21395454099102, 26.168708416723437, 87.5453567504883, 77.5984299567438, 64.626088834578, 28.96891986170123, 0.1813044365976126, 0.16954466520297914, 1.2859038311627604, 4.333968008718183, 3.7928924877797408, 10.924565792083742, 9.89684989375453, 2.338124369421313, 39.42488793403872, 85.47652613732123, 77.0296549027966, 84.33231584487423, 76.558272300228, 79.83815039357832, 79.7281357549852, 80.04241174267185, 72.76295554253363, 76.58436390661424, 67.48934453533542, 64.36950306738576, 71.12913147095712, 66.30003483064714, 70.4444896021197, 74.72226573574927, 61.00248167591711, 54.69491427944553, 57.0000010152017, 70.59385345828149, 72.47491236655944, 69.00398346685594, 61.55540643199798, 71.87866503192534, 66.48288788334017, 62.20389189258699, 52.521917281612275, 51.886505080807595, 49.07915099974602, 51.871670676815896, 50.17930523041756, 59.24636594710812, 62.642146156680205, 67.92504141407629, 67.0362009540681, 67.80610730571132, 68.86736731375419, 70.57426514164095, 69.01234596006333, 70.50233671742102, 66.51895015470444, 67.79190832568754, 57.400161220181374, 63.561153565683675, 60.23463064624418, 64.19418096542358, 60.22624461881576, 65.14845832701653, 58.47279217935378, 65.2701694734635, 39.56543430205315, 48.0964207649231, 69.67287309708135, 54.17212117102839, 55.77060860972251, 47.04471172824983, 52.852463260773696, 51.46266552709764, 60.802103473294174, 51.62941332786314, 50.97189072639712, 48.903550409501605, 51.291379544042776, 58.67459420234927, 64.53967117494153, 68.9849913504816, 65.460408349191, 52.12311813908239, 64.96942566287133, 67.95621641220586, 60.2626520587552, 53.20018137654951, 51.642168875663515, 51.48263823601508, 51.0786380306367, 54.207296986733716, 62.06431042763495, 68.02060604095459, 68.53629573698967, 62.902454253165956, 70.38410079094672, 66.09792294040804, 64.89088412254088, 57.48916764413157, 57.54441030563847, 56.47819634406798, 54.22731676409322, 55.973010755354366, 62.796020738540165, 61.459229915372795, 67.64660020028391, 64.91772097925987, 67.56174364397603, 63.919673888914055, 69.5999405460973, 69.83002678040536, 78.96692137564384, 68.49279665177869, 92.93148486844956, 15.684361996189242, 2.1019802795302485, 10.052653301146723, 6.946723989902004, 2.5371844105182157, 0.7223557031923725, 0.4459285039094187, 1.1527038173329447, 18.81110095208691, 45.19647521357383, 33.922979293331025, 26.699328614819436, 56.81459842189666, 20.376152146247126, 34.68105577653454, 50.971918182988325, 71.79082747428649, 69.05742968282392, 87.50200671534385, 45.69793847299392, 0.40448762115932285, 0.2571731727690466, 0.22995469701145926, 0.13202451319704134, 0.12648571282625198, 0.1536569516024282, 0.15273504139434907, 0.12763204083086985, 0.13627944213728752, 0.28568825233847867, 0.2145844911255183, 0.12273011233417258, 0.15623336657881737, 0.10732650501473297, 0.22228367476453706, 0.1188501681111032, 0.1456709752880758, 0.19386129183394296, 0.1300318265754369, 0.11945984386388334], [0.10252658878603291, 0.020211261036174915, 0.08785558368770346, 0.1025886036035034, 0.028921696057002393, 0.05978703378669678, 0.13721765469639532, 0.033291894416775436, 0.026368922553956512, 0.04333945930064206, 0.03937877707123276, 0.04098340568523254, 0.10633112697471535, 0.01510018191765994, 0.04195582790059909, 0.03436524871616595, 0.10351704854157665, 0.08968050471476971, 32.65871309464978, 80.78020172734415, 68.48806627335088, 62.42461542929373, 46.8412152413399, 27.767607704285656, 29.85833298775458, 64.31754735208327, 88.51542949676515, 45.09044178070561, 1.9721831669730527, 0.0660184389280696, 0.1901945958454763, 0.8973654864295837, 0.5388014042569745, 2.999792916159476, 2.518798790631756, 1.2156362855626692, 3.9983533467015917, 75.47391737661054, 75.62544638110747, 67.00212340201101, 68.48659930690643, 76.26201568111297, 69.81065027175411, 72.19207025343373, 73.02097689720893, 72.28589334795552, 71.32422231858777, 71.16198524352043, 69.75517226803687, 65.73949283169162, 57.5158005376016, 69.88097836894374, 60.894365464487386, 51.07962646792012, 48.00624939703172, 55.559490957567775, 67.73071935099941, 62.4254273599194, 62.810266787006015, 66.78205490112305, 63.529649088459635, 60.94219484636861, 53.90902034697994, 51.893188799581225, 49.79128083875103, 48.11985692670269, 46.099651936561834, 45.08179295447565, 51.042375718393636, 57.55883286076208, 62.055085012989665, 62.580141328996234, 62.93223288751418, 61.055265011325965, 59.67291193623697, 57.39183795067572, 57.940440254826704, 60.03040852085237, 60.549459688125125, 57.895619330867646, 58.00356295800979, 54.28107676967498, 61.09334338095881, 54.500070541135734, 64.25606812200239, 52.73866745733446, 60.7143129840974, 32.38737725442456, 37.83371571571597, 68.19570849018713, 51.78804574474212, 54.96647957832583, 46.666477572533395, 54.88156418646536, 57.462985823231364, 61.35931930234356, 56.33120552186043, 52.3172950744629, 43.98961290236443, 45.94058021422356, 43.957422010360226, 54.61263472034086, 56.882733914159964, 60.77531760738742, 56.21571525450676, 57.94723772233533, 61.35945658529959, 55.30044194190733, 46.438725148477864, 45.297848870677335, 44.287156058895974, 47.25825732754123, 48.38253413477252, 57.580099951836374, 62.65078321579964, 63.05003343089935, 61.150017707578606, 63.146845371492454, 62.51583799239128, 60.94685069976315, 51.391745152012, 47.15811529467183, 48.209683126018895, 49.08408926379297, 49.67867351347401, 50.47265537323491, 52.11908594254525, 53.51694806929558, 57.59108651068903, 56.972889592570645, 57.94244066361458, 57.04005233703121, 61.87253398279991, 66.25928924929711, 69.77498808214742, 69.61999954715853, 64.8065923875378, 0.5446469002673703, 1.6907466106837796, 1.660391510494294, 1.1329397294790515, 0.2876272515183495, 0.12931941077113152, 0.03439260188550238, 4.131988498472398, 19.25780204034621, 31.047899607689153, 23.355276623079856, 19.365216147515085, 22.416596566477132, 16.981931078818537, 31.981853208234234, 50.16327842589348, 58.008363939100704, 62.77967229966195, 63.50729942321778, 3.9022150731855825, 0.1538127125991929, 0.04982499112825721, 0.037572211510832274, 0.06115319455162652, 0.025520811510843136, 0.05224282973475995, 0.03199350945050678, 0.0473118013882589, 0.016249443081417875, 0.041874741324253624, 0.03638967053003369, 0.05611991261943214, 0.03439683835172365, 0.061122619982568495, 0.05645074385909304, 0.041551835264169404, 0.009151714114141802, 0.01606375485989115, 0.011875575160487525, 0.08091679593968777, 0.01954184000139996, 0.034836576650700266, 0.027875139513203216, 0.012889396767282199, 0.08277105047337471, 0.04773214617143235, 0.019708444972732858, 0.02592458198177478, 0.028467679794337, 0.07646097576305752, 0.005073820432317594, 0.06286937705872041, 0.0425736969637294, 0.06433474620984447, 0.01940247711665448, 0.05198356259854571, 0.12397999244351542, 42.39962131746354, 93.01630220105572, 75.08113907229516, 68.39586704008042, 53.76295520413307, 37.87184507616105, 27.208044336688136, 62.077085587286184, 84.00689248115786, 42.569444256444136, 2.2823257119424882, 0.13955258343729282, 0.11336233556991625, 2.2699883868617396, 2.615438146937278, 3.770256244367169, 3.708571335000377, 2.431627545625933, 4.582903192889306, 79.48261891641926, 77.56383465182397, 69.69279089281636, 69.5093337951168, 77.5055560758037, 73.54611166061895, 74.62860738077472, 75.63689970201062, 76.30855852557768, 72.53321447680074, 72.29019226566439, 70.43529556643578, 65.81821087867984, 61.66862956939205, 73.89639500648745, 64.35423720267512, 54.53759585657428, 50.5474510500508, 57.968697009548066, 70.65406968516689, 65.62293960202125, 66.94117761427357, 66.39754495313092, 66.74494927929294, 63.96391822445778, 57.08159023715604, 54.79418946850685, 52.6908302307129, 49.336564387044604, 48.044790606344904, 47.18656424553164, 53.880900875214614, 59.50119449246315, 63.56768038965041, 63.327407760004846, 65.05440773502474, 60.91446368925033, 62.37912378003521, 59.07447591904671, 60.57396273459158, 63.668704955808586, 63.29397347665603, 58.00481027172458, 60.16244334559287, 57.45278373841317, 62.171504882074174, 58.24880915303385, 65.90855090848862, 54.37606480813796, 61.29842842778852, 34.84946273988293, 39.877772638874674, 68.81101069911834, 54.92020345503285, 57.11524025086434, 48.5924280074335, 57.402185163190296, 60.02573305560697, 64.40036035353138, 59.10896924234206, 53.39099684069234, 45.58256979911558, 48.28689106049077, 46.580491373615885, 55.94058059876966, 59.17735968866656, 62.621271302623136, 56.430770966314505, 58.32917067312426, 63.82281095750871, 57.26132500556208, 48.85983167156097, 48.913697581137384, 47.37947425534649, 48.694801868930945, 51.38312770474342, 59.02364984635384, 67.20485502673735, 64.35407638549805, 61.84055097641484, 65.69209491052936, 67.73318259946763, 63.497473885936124, 54.90078772267988, 50.389634486167665, 52.41547984461631, 52.066530104606386, 52.484690066306825, 51.70019641999276, 54.95649714623728, 54.33656261813257, 61.22675103525962, 58.82021611736667, 60.35744397870956, 60.7858060252282, 64.9721360206604, 67.51150592680901, 72.4876130011774, 70.69229710486628, 69.77495670318604, 1.1195990130785973, 1.1460644703718925, 1.4893264059097537, 3.2744036903304443, 0.9983559769968834, 0.4031207977283386, 0.056111355417317925, 1.2104565506019902, 26.711466389317668, 33.38928591820502, 27.33469963073731, 23.600569886545983, 22.63417632349076, 25.788028663204564, 41.68738557446388, 57.77403762263637, 64.20436343839093, 69.24645654616818, 74.52106383539017, 5.914062963378045, 0.2578364210503717, 0.04237173320425134, 0.0380448111513209, 0.16050885731895126, 0.048372392662830895, 0.1013669002080156, 0.013387644073865829, 0.026269806098313104, 0.0677293813937614, 0.06566882704294498, 0.046443724178618966, 0.0512816307074841, 0.0438189882064058, 0.034594075348708904, 0.07471849345752309, 0.10649187520386712, 0.07353514808440402, 0.018971232817538323, 0.039586260494205265, 0.2329715206137588, 0.11962243836493262, 0.1674318866383645, 0.16261742239998234, 0.08294384160469617, 0.13511927858475717, 0.30343789667371784, 0.14982125661786527, 0.16118587986115487, 0.10546264373847555, 0.11640591096253165, 0.08922608434072427, 0.15816577740253943, 0.07506612883580309, 0.1480553013783309, 0.17657482425772375, 0.13655903358613292, 0.14720943305761586, 53.14826488494874, 103.8536148686563, 88.80668901628064, 77.83432914364722, 61.828701496124275, 38.55554165378694, 44.75534192977413, 82.09599218060895, 101.55480000280566, 64.66178632551625, 3.0300638079643254, 0.27242864932744737, 0.8509507931528554, 3.1614906653281185, 2.70923966842313, 10.597254787721942, 12.44425085283095, 8.29680625469454, 4.468213579347057, 86.7884099098944, 79.91836286360218, 76.24996615994361, 71.25204286267682, 80.81404393719089, 74.12569676676105, 77.75246143341064, 77.86685343711608, 77.1096634095715, 73.95183378650297, 76.83599179790866, 71.47272325331166, 69.85109775297104, 65.68476007830712, 76.52508120382987, 65.0049231129308, 57.69000476406467, 52.62482458545316, 62.16409552481867, 74.01503101471933, 69.70052580679618, 68.08837675279187, 67.40622951138404, 68.93668343943935, 66.20635294145154, 60.058210280633745, 55.34208182365664, 54.24975272147886, 52.75422749980804, 50.45103919121527, 50.485724710649066, 56.59491823565576, 63.824022969891956, 67.70446300506592, 66.66877685054656, 67.27781111194243, 66.08133131457915, 64.83187598566856, 63.331416422320956, 62.968577569530865, 66.33827793982722, 67.25542222299885, 57.527720620555264, 61.36438308223602, 57.959248019802956, 63.9890919962237, 59.041453484565984, 68.18501610909739, 57.65601742652155, 61.98818898970082, 38.87892538501371, 44.43437045620334, 70.5220740841281, 58.53733085816907, 60.808881328951934, 52.43211069414693, 60.95192232439595, 63.92526718877978, 67.0638301295619, 61.873326301574714, 57.19690399785196, 48.931010923077984, 51.317016155489036, 48.186627434146025, 59.15029533447758, 63.450868283548665, 67.12640762329102, 59.100979374301055, 60.315772717998875, 65.60113122386318, 61.023599716924856, 50.248401703373084, 51.65405365728563, 50.702055192762806, 50.83513336796915, 52.97906952519571, 62.884948715086914, 71.81482453500071, 66.77969363427931, 63.177718347118756, 67.84253827987179, 70.11732470604682, 66.95332127232706, 56.21578977954004, 52.81436135691982, 55.09671403515724, 54.71286304535405, 55.80287402675998, 56.1694352088436, 58.907257433860536, 59.256367991047526, 65.65737801213419, 63.74293188894949, 64.34751033782959, 63.66809698843188, 69.16402401462679, 71.9414778678648, 77.55704895142587, 73.78140680251583, 72.79468751722767, 0.8225594521049531, 6.002127528190614, 7.254819793085899, 4.557770606010191, 2.032206829997801, 0.317802780698384, 0.12924903793440712, 5.911070194936568, 34.04060333005844, 47.52861453640846, 33.37345523218955, 30.62349915504456, 37.07197181640133, 28.54042249341165, 47.63924498711863, 64.8977521927126, 75.24244262326148, 77.33035948968704, 84.85564631800499, 7.069026923948719, 0.4164970606084793, 0.12678106270369985, 0.1113077030787545, 0.2366176548023378, 0.23436083638619995, 0.277902776555669, 0.06662812234172899, 0.17665664244803692, 0.20620014909054005, 0.22495460966902397, 0.13245549894148304, 0.12308786007305308, 0.20276902513878964, 0.18060443141768057, 0.23366740424065824, 0.18387774125702921, 0.2529457463852821, 0.08722123224288227, 0.232223343825148], [0.05625133883328207, 0.042116579960190484, 0.05294285789732972, 0.03131619962533155, 0.033121838219343655, 0.03928744789933966, 0.021380408884837263, 0.09189574753925686, 0.05015663825155747, 0.03692392109622879, 0.030874540360884804, 0.014495037574951929, 0.12916755682278064, 0.07113728522052688, 0.03562734792790106, 0.038873009654062415, 0.024615123214560653, 1.5875094600262183, 61.43561724693545, 70.55764998159101, 76.57348325175624, 74.75019301137617, 56.51891054645662, 25.42036529510252, 46.243830419355824, 39.802784765920336, 44.412040402812345, 17.249326898205666, 0.09375923343243138, 0.066891894074938, 0.1567280295515253, 0.6586944708420385, 0.9605174848148901, 3.174804170285502, 1.763317077871292, 1.0010858240627474, 29.123853483507713, 88.6118099766393, 70.40126508282077, 77.70030959959954, 62.696572965191265, 68.3220244992164, 70.33569874302034, 69.98799631672522, 68.3211301988171, 70.18773909538024, 68.90131150522541, 71.10344779106879, 69.69941969840758, 66.2570534982989, 67.14020652155723, 65.74834562117054, 53.316711071998846, 48.69516664935697, 47.781701549406975, 52.76208400726319, 67.73919167057161, 63.062945873506614, 73.12810467135522, 62.71813423402848, 62.84084558486939, 58.479028747927764, 53.73753824541646, 55.93168466321884, 54.41011882597401, 49.483837619904556, 48.416384189359604, 46.908401520021506, 46.920082338394664, 50.143372397268976, 59.493130099388864, 61.56542808778825, 63.44467486104658, 56.727160946015395, 51.75191287071475, 48.216398223753906, 61.385905127371515, 60.06019892231111, 64.47918430451425, 54.26925082360545, 56.56509645523564, 61.82368086230371, 62.27530648631435, 60.175963755576845, 63.63894201094105, 58.81971405398462, 65.92773914337158, 34.39986105888121, 39.856199602926935, 69.13735189745503, 51.43188668835548, 59.19481423593337, 53.79751520772135, 60.96732939443281, 59.9123961694779, 65.89834490130025, 57.219559607967255, 56.41247310946065, 50.34220518604402, 49.92213110769949, 49.19269184912405, 50.61280165949176, 56.21147124998031, 62.685488347084295, 58.31656417539043, 57.54432793586486, 61.2379180231402, 53.09512069148403, 47.42541305480465, 45.167241788679554, 45.557423483940866, 45.818429762317294, 49.066748465261156, 53.75979769614435, 58.597762815413944, 63.55584659884053, 59.55890824717861, 64.06736681538244, 62.967169438639, 59.06799616352205, 51.92591313392886, 47.96200113911783, 49.47090556544643, 48.23636308793099, 49.01245109496578, 47.83266490505588, 49.976467701696585, 48.94544524531211, 50.619567748039, 52.245276435729004, 53.70533950867192, 52.98418429590041, 56.66864310541461, 57.8822793499116, 67.38688438169419, 66.19847682214552, 78.27952600294545, 32.34619432880033, 0.450043284724797, 2.2798401549939187, 2.062377823937324, 0.29728097060034353, 0.10228350908765871, 0.037796947233859575, 0.2033135604353682, 11.614751931159727, 27.27069635545054, 24.855565563324962, 16.838329184439875, 65.86109022940359, 29.1604237018093, 32.644229742788504, 38.94548016209757, 49.89801637588009, 53.28627347946168, 65.0670495340901, 21.73488078578826, 0.02972748074229927, 0.054830360646930434, 0.021539548329348047, 0.09147591603499267, 0.05421421911206938, 0.11972897821256231, 0.02794827984255408, 0.07671238283716864, 0.02834738483802686, 0.037853032530796145, 0.025278557272207354, 0.07190377151052799, 0.015156935626310448, 0.05693509528834013, 0.04355481044659692, 0.017371417150922844, 0.02759045166444154, 0.04602711024363676, 0.017800422558080287, 0.022126358272808216, 0.06544129892943368, 0.07793391003243386, 0.0437391848273335, 0.06324532321624218, 0.11462617380123948, 0.0685371368402435, 0.02514014433648798, 0.01278355980532304, 0.05894318793810183, 0.031203128878147374, 0.03208173022064711, 0.04215603348829093, 0.013423680849823982, 0.026270305970683697, 0.057393273323654175, 0.1577321563156382, 3.1521274774305286, 76.16255221828338, 79.44955333586663, 85.30566769261515, 81.18985406814083, 59.963559566005586, 28.752481514407744, 40.98182178312733, 47.29794386894473, 56.546508342989036, 19.58627896924173, 0.13858119927106366, 0.026436736657013817, 0.1471164453053667, 1.1503410796003959, 3.8383517774843403, 5.6438783387984, 1.7824204914992856, 1.7969987156891056, 32.842915442682084, 93.68599199479627, 71.7132822159798, 80.64936714787638, 65.64856836872717, 71.02647519880726, 72.63066968610211, 72.21989554743614, 71.3622457750382, 72.8970221550234, 70.39291043435374, 72.93848945248511, 70.94601954183271, 70.21105366368448, 69.8856459894488, 68.83305441948676, 56.964652615208784, 51.75349358589419, 50.029631507012155, 56.40061186205957, 69.76940262702205, 66.43829837922128, 72.02839759088332, 63.91081325469479, 66.54330022873418, 61.548871763290904, 57.774602443941184, 56.20191243387038, 58.90395872054562, 53.29596565615747, 49.206416222356985, 48.01895003164969, 49.94519464431271, 53.53781900098247, 63.123938729686124, 63.07233602769914, 64.25378530256211, 59.82974398520685, 54.58766491182389, 52.17823920711395, 62.80025689832626, 63.596807910550034, 66.3838166575278, 55.31510768398162, 59.63073468977406, 64.49006103700208, 65.09827552303192, 60.411011788152884, 65.30529037598642, 60.73028487543906, 67.73481430545931, 39.47800074854205, 41.838938113181825, 72.46007011782739, 55.31853583551223, 63.28081000235773, 56.199504098584576, 65.04030289188509, 61.133547675225046, 67.57660158218877, 59.902299988654356, 58.93920121654388, 50.7485431240451, 50.98385003305251, 52.01917140714584, 54.135097918971894, 60.009059060004454, 65.43568564999488, 59.23418698772308, 59.41118001937867, 64.45709351570376, 55.56839473785893, 49.00775209549935, 47.34909157599173, 47.92012199278801, 47.566088861034764, 50.79978104560606, 56.19872354692029, 62.63447792299333, 64.25629954184255, 60.04473693909184, 67.33418341605895, 65.82758534339168, 61.014013444223714, 53.943352853098226, 52.43666848828716, 51.316341507819395, 49.531565020161295, 52.8564013204267, 49.20783219798919, 51.2382314282079, 52.516014114502944, 53.808909693071925, 54.65125437705748, 55.64941521613829, 57.066626394948656, 59.132162217170965, 60.85882879072621, 69.91983336787071, 69.30072645987235, 80.39349525205552, 37.439168422452866, 0.5402079416859535, 1.0560002322158506, 3.0028339787837, 3.4652797060628093, 0.5651642057684161, 0.10537822084921984, 0.2396601729936177, 9.921275473410084, 35.488895370114236, 25.678774964424875, 18.033846039925855, 52.63506981634325, 27.290127777284194, 41.942504375211655, 45.49831336544406, 55.36188979302683, 58.03180402325046, 73.65711473649549, 29.796936127447314, 0.29610959152060173, 0.029965534903890187, 0.04525567502564481, 0.06158421860046445, 0.05145941290163225, 0.09473699145019056, 0.05818937274236834, 0.11003185258877855, 0.03455397064587282, 0.028119383665222316, 0.01517628317683815, 0.06050365541370646, 0.09254627110015962, 0.06237743752858332, 0.04889889424967189, 0.032538412469289, 0.06998999194512445, 0.03703977657301772, 0.03715442929176554, 0.2170851706497131, 0.1787799317389727, 0.12463276064203632, 0.11203459028394953, 0.20453013870264256, 0.1578247763456837, 0.18920159267802394, 0.13749936054791176, 0.11107616066451996, 0.14548136852681637, 0.15934818814839088, 0.1367802951004236, 0.15566037877673106, 0.17807042706877957, 0.10357010779121231, 0.18102539673207269, 0.2438093511567962, 4.177519371432643, 93.47268566008538, 89.14290674271123, 96.64145869593467, 89.91988905014531, 72.88855768019154, 36.96945674957768, 64.56340935922438, 52.72397425866897, 61.684546547551314, 26.314593130542388, 0.5929358736161263, 0.2498176102075846, 0.7796710309001708, 3.882628472581987, 4.7860172487074335, 11.963409454591813, 9.742645832800097, 5.414270633651364, 33.495382108996, 97.04486662341704, 73.76558396124071, 82.92744836499615, 69.28670006413614, 74.77262112402147, 74.27477821227043, 76.71479840432444, 73.94409887252316, 73.88650278891288, 72.51383012340915, 76.47637321103004, 74.13699319285732, 74.01325025866109, 70.66648790913244, 70.30945808656755, 58.93318822306972, 54.23327876675514, 52.051844750681234, 58.89997359245055, 72.19989930429767, 70.29344697152415, 73.90864064616542, 63.742429825567434, 68.79396407834946, 64.64634003177767, 58.21270765796785, 60.31148164503036, 59.734073454333895, 54.29170247047178, 51.23872956921978, 51.33538853737616, 52.847242586074344, 55.878740510632916, 65.1910670341984, 67.3956940251012, 66.31332382079094, 62.591998654027144, 57.48126406823435, 53.78109224380986, 66.20670595476705, 66.1157932589131, 67.3918971707744, 57.174789674820445, 60.9252933532961, 67.07856255192911, 68.20001525263633, 65.34896204548498, 68.53682133459276, 64.87618700150522, 68.34492329628237, 43.389792288503344, 45.83843777256627, 73.6996332291634, 59.15608083048175, 63.90032483685402, 58.47636545858076, 67.7140728119881, 66.12753683520903, 70.33678916192824, 61.80333945059008, 60.446058165642526, 55.099440082427, 54.13249738754765, 54.7481918334961, 57.28411789863341, 63.55122996914772, 68.73060211058586, 59.45318860392417, 62.752788374500895, 68.11517438580914, 58.14855337142945, 52.189723906978486, 50.099269267051454, 49.61089103452621, 51.1673032083819, 52.008271140436975, 57.98370007545718, 64.66632058543544, 67.43723192522603, 62.9744375905683, 68.18390215596845, 67.0309449780372, 63.660346384971376, 56.58634393445907, 54.44732250705842, 54.870059874749955, 53.40088513589675, 56.23677053759175, 52.78754018968152, 55.58406460669733, 54.80861202363045, 57.19523306815856, 58.62376028491605, 59.76787251810874, 61.5166102686236, 63.234537801434925, 63.22351594125072, 73.73298122036842, 73.17243529904273, 84.73129149406188, 39.51706363308815, 1.2039238430799977, 9.863298919893081, 6.365190936673073, 3.3909905052954152, 1.2393195566631134, 0.18468553500790752, 0.5987696025160052, 16.481181690769812, 43.91751973859726, 35.778531028378396, 23.264685561580045, 75.94140114322786, 41.462370964788626, 47.63054909244661, 52.26796342480568, 65.49938101922312, 67.28449483071604, 83.59360802558162, 34.81606768023583, 0.3342684923160461, 0.10414923195757213, 0.1782464893955377, 0.24052905459557813, 0.11476630660434885, 0.2543818241646213, 0.09914817934435222, 0.19044124551357763, 0.10872093059362904, 0.11942098788436382, 0.11730804078040585, 0.1657495269131276, 0.16720405208968347, 0.13949088271587126, 0.17400001806597556, 0.0841889949515462, 0.11472618657975428, 0.21502509893428898, 0.0966274896035752], [0.056965711992234, 0.07706817705184221, 0.10752298358467319, 0.00948943152663208, 0.05400539120478977, 0.019653445605428952, 0.09633002532345634, 0.03697588867057235, 0.060062155112504005, 0.0056172061182047815, 0.00409484816519844, 0.04573690464660045, 0.039075521166406335, 0.09857116191978417, 0.04867058089603821, 0.10600135676682958, 0.14720080690758844, 23.52956125813146, 81.2013779917071, 70.23465064264113, 74.59367475202008, 54.73882129115444, 36.558780670166016, 27.807060864663896, 43.856264083616196, 40.362965906819994, 36.23535379286736, 8.941183032528047, 0.29758544458496955, 0.24992328437585987, 0.17385993122814164, 1.0677742068806002, 3.9934599447634915, 1.332049903369719, 3.459076232487156, 1.369918793920548, 74.07050901843657, 73.68695612876647, 74.46295784365746, 65.8637809753418, 74.57141922366235, 66.60699167559224, 65.34858549794843, 70.02091284721129, 65.19749972128099, 66.09212567729335, 64.79935953694006, 65.7650980641765, 67.86007127454205, 66.82342806170064, 67.35093193669474, 58.15948501709969, 48.7318015867664, 48.44595101571853, 49.79288901052168, 53.02802854968656, 59.299423848429036, 63.353577813794544, 63.005181127978915, 64.02420505400627, 63.12749631943242, 58.936231982323434, 60.84377473400485, 60.691198456671934, 60.16482422428747, 55.1138626375506, 49.61629998299384, 46.30153632933094, 47.310036536185976, 45.50401649167461, 51.057194432904645, 57.37888236199656, 57.07127440360285, 53.462489881823146, 48.097613165455485, 53.372102783572295, 58.25609299444384, 63.34351301193238, 59.51788417754635, 55.32409775641657, 64.10451950565462, 58.11297355159637, 62.57649744710615, 60.17721891403199, 65.63846826553345, 56.66948249263149, 64.87611639884211, 33.588330514969364, 34.426015423190215, 65.21059651528635, 61.4747154328131, 61.56123899644422, 57.25618277826617, 60.63930942166237, 52.821249038942405, 54.548194100779874, 59.866555429274044, 60.53478610131049, 53.37772746239939, 56.42612295766031, 53.53467718247445, 52.665931024859034, 54.495473523293775, 59.02435979535503, 57.67064394489412, 57.95349390276017, 57.75701453608852, 54.12783761178294, 48.510046466704345, 43.96656113286173, 43.93073812607796, 46.29404460230182, 48.063774877978915, 53.512484412039484, 59.557558951839326, 61.46104597276258, 56.564696373478064, 61.767104594938225, 62.3132279611403, 59.955659912478545, 49.83188913714502, 46.951943751304384, 46.70672501287153, 48.2476399021764, 48.30714225769044, 45.698138513872706, 47.90322442208567, 47.96942226348385, 50.8938394823382, 49.6355313639487, 52.96964014730146, 51.91456963939052, 54.66038565481863, 59.27321064856745, 63.19955025949786, 64.63216850834509, 70.09029957555956, 64.41158225459438, 3.3007889841833427, 1.2386667271775584, 3.4235035219500145, 1.452920436859131, 0.4959690606882496, 0.11389873501273895, 0.04551516815779671, 2.338566371510106, 32.42325909676091, 27.98804294678473, 87.90277096533006, 123.33383883199384, 97.35272561350178, 18.694375138128958, 36.108065036035356, 50.36516674103276, 53.68451956779727, 58.3829189115955, 52.583812282931426, 3.7722247838974003, 0.16544399572716606, 0.025046629898790872, 0.026245804563645395, 0.15313337647145794, 0.07903182894111642, 0.09383991015173736, 0.032254289610371474, 0.09526064318995323, 0.01839896130766119, 0.003487909022125326, 0.03326000600692726, 0.024619859553152518, 0.047831243474877654, 0.07087462431480808, 0.028762738558373628, 0.07234259433443509, 0.02694691482540821, 0.1084597482376041, 0.04837259950657045, 0.04749265559498341, 0.06909076560048327, 0.046384222129540104, 0.01737013586886948, 0.05251146229584852, 0.07596640472090052, 0.050352392868409236, 0.015756421452087742, 0.03074869318234344, 0.03170809956387647, 0.05047015973456925, 0.04983583127238578, 0.029112237445529432, 0.04926114275510754, 0.08310381608504443, 0.02618703987419365, 28.13204492292097, 95.076032915423, 75.49027366022911, 82.97451680706394, 60.797169131617395, 50.87727923547068, 32.45445174555625, 41.29632526828397, 40.118665003007465, 44.74268444122807, 12.921163016749968, 0.34921667568625947, 0.11790425636835637, 0.8610214785702768, 2.543805616517221, 5.342992342287495, 2.9801464994107527, 3.1394702340326006, 1.9629681711235356, 78.26531133344098, 75.67635874594413, 76.47099171915363, 68.60672581580378, 74.58486510861304, 70.28291148524131, 66.80165890724429, 71.24159366853776, 69.21212796242007, 67.68168187910511, 66.85395979112195, 67.86593129557949, 70.85474598792293, 69.02066138482863, 70.9068899769937, 60.19369286875571, 50.511420157647905, 51.50536444879348, 51.9052069417892, 55.041102670854144, 62.0247454797068, 65.36318063735962, 63.94756194083922, 63.89133868678924, 66.9677948182629, 63.21223128226496, 64.67262775667253, 62.74128406278549, 62.862430387927645, 57.422067657593765, 52.866626939465924, 49.63355448938186, 48.51847564020465, 46.92390664931267, 51.85849935777726, 60.47562891437162, 59.99458551406861, 53.504420018965206, 49.269385953103345, 56.36596164395733, 62.18131472987514, 65.42669949993011, 61.01252686592841, 56.57994654870803, 64.07479186211863, 60.599524821004565, 64.60593569663264, 61.951930599827925, 66.9294261932373, 60.888858456765455, 66.86329503213206, 38.678131411152506, 35.71572603717927, 66.13185928713891, 61.894130552968676, 64.9373092959004, 58.641956160145426, 62.40754135193364, 55.655891049292784, 55.78547439267559, 62.89538614211544, 62.282872738376746, 55.14363734952865, 58.38859458123484, 56.4196353573953, 56.80443556078019, 54.914539552504024, 61.545573049975985, 59.58880063026183, 60.7752077810226, 59.92537529237809, 57.201140157638065, 49.26335334777833, 46.46390284261396, 46.06999489568895, 47.73247972611458, 48.559448719024665, 57.48763007502402, 62.259875882056456, 64.4609845069147, 57.650267231848936, 63.65693000055129, 65.20445800596669, 61.57888181747929, 51.348481409011356, 48.04562214882144, 48.42642153463056, 50.80806901378017, 49.61835530496413, 49.284561603300034, 50.6269927947752, 49.7266911691235, 53.42994989887361, 52.68002017851799, 56.710188850279785, 53.36379128117716, 56.38936642677554, 62.9594619812504, 63.55415213492609, 68.19592029817643, 71.02813043901998, 68.39316060466152, 4.8213288764799795, 1.3249168280632266, 1.1845587338170698, 3.0041165938300476, 1.822302048244784, 0.3563523556916945, 0.09143888334473295, 0.5553116409047958, 37.731741935976096, 27.29953362095741, 71.60537781253939, 111.73690426734187, 86.21003289376536, 29.890168905258182, 44.04438880182082, 57.19899069878363, 59.966819055618785, 66.30976230867448, 64.37861865566623, 6.118232627068797, 0.05114419836430781, 0.059063666755513805, 0.02010362759803332, 0.029836531443100785, 0.045365715895088456, 0.03659407810999021, 0.03822937705403855, 0.029416014290144368, 0.06858843408765332, 0.039917716095524455, 0.029113796434455344, 0.02579371501210957, 0.02038416899590483, 0.03901085951515744, 0.03617320089570938, 0.029888305580243472, 0.01847617913998904, 0.06905865119469744, 0.1215864809590482, 0.11636519338935615, 0.21022699833396943, 0.24079785952644966, 0.10115240325009632, 0.11808676915543696, 0.42566912489071973, 0.15977957225855322, 0.1296301053897027, 0.1273337798193097, 0.21190178911051444, 0.18219524363596595, 0.11688792582360968, 0.1204395707276079, 0.12718262301096994, 0.3347006271923742, 0.2840391101856386, 33.51640993548978, 105.79681196520406, 85.99532235053279, 92.94525238775438, 70.5928885552191, 51.32497464456866, 38.868844893670854, 58.19797523560063, 54.76776838302613, 57.18064577348771, 15.672447796790832, 0.5445808941318143, 0.39354748723487704, 1.3776177936984648, 3.260580767546931, 9.887651935700449, 7.8989774084860285, 11.067511670051083, 2.061067997447906, 86.94961932397659, 77.13671207427979, 80.63478377557571, 71.8325379586989, 79.54467081254529, 73.81387618280226, 70.00436828982446, 72.52256131941273, 70.47720216935681, 70.07371579447101, 70.46648625404605, 70.44320306470318, 74.83448474637925, 71.05830915512578, 73.63605160867014, 63.79981017881825, 53.55632474345546, 55.38136828330256, 55.29382882579681, 57.703576164860884, 64.80032836237262, 68.74738201018303, 68.0112551104638, 66.03320383256482, 68.37184644514515, 63.863744812627, 68.00967831765452, 65.38010958702334, 66.34548725620394, 59.180117114897705, 54.42245468016594, 51.505552722561745, 52.244974413225734, 49.66281144849716, 55.79982242276592, 62.92801633957894, 62.39067516019268, 58.3720382567375, 52.74641021605461, 58.93583190056586, 64.52915137813937, 67.34286754362046, 60.419193852332334, 59.194076830340975, 65.19684468546222, 63.568582534790046, 69.08767900159283, 65.20357547267791, 68.7969607691611, 62.58781348505328, 68.98634849056121, 41.885257382546705, 39.608517616025864, 67.06612863848287, 66.00761428956064, 66.19894750656621, 62.313628042897875, 65.18970597174861, 58.204400077942886, 57.2155862469827, 65.17526380477413, 66.61628769290063, 57.70097955580681, 61.2435858480392, 60.341068083240145, 59.23284553712415, 58.39581566472208, 66.65020050541048, 61.46993798594321, 62.5594743605583, 60.9345030784607, 60.6918691819714, 54.04376552950952, 48.7852595698449, 47.90149857920986, 50.794458389282234, 53.0775837744436, 60.32845766313615, 65.99505486026888, 66.52655170809838, 57.655938979118105, 65.33411195201259, 69.68667984008789, 65.28768285628288, 55.32923606134231, 52.520116913703184, 50.636249588381865, 54.097851091815585, 53.43694740726102, 51.37360811233521, 54.3207319321171, 53.82236342276297, 56.04284071153211, 54.72368878702964, 59.59359376661239, 57.67743749003257, 60.71491702910393, 65.25265609064411, 67.42456266956945, 72.36559590985699, 74.93270089549404, 71.78594804579213, 4.976499801681888, 3.8540155176193487, 10.091294530899296, 2.815863172854147, 1.6309163695381534, 0.5858471088351742, 0.24772710947980806, 3.2859489417845205, 43.793796416251894, 42.84764228328582, 95.32544858994024, 122.59603315784086, 105.0868864982359, 28.546176610454438, 50.56942809012629, 65.51117166396111, 71.53927018565517, 72.06360478555003, 71.92287798850768, 6.936657717151027, 0.3037988466601218, 0.1973865986351044, 0.24507046977598823, 0.3221273776744643, 0.19166341622269925, 0.18372948792192245, 0.12059506359359912, 0.2297438389711803, 0.1940288505847416, 0.11735714701635223, 0.0847687779535209, 0.100202752998279, 0.11314289734488535, 0.2546359968161391, 0.17092527821660045, 0.18784089795043393, 0.11587413102989236, 0.2251095892561059], [0.016860248813886317, 0.08644398241754501, 0.062215356306443294, 0.07527561557869758, 0.13508373210507055, 0.0009997605417494573, 0.0387224733769413, 0.056979654792455904, 0.061332290586564815, 0.03016917448070261, 0.06075109032193019, 0.10246394577646449, 0.06886337538279834, 0.09710611835602792, 0.07355983909820357, 0.02929007326583228, 0.39390865172589984, 58.33211637312367, 71.99891705666819, 69.42956063055223, 61.28021294070829, 48.99100749723373, 19.444934398897235, 34.56963300704956, 61.711677582033225, 41.39713410408267, 32.31866125137576, 0.9084840575533529, 0.2018460424076165, 0.048718239225807695, 0.1234360010693631, 0.5049538930817958, 4.097449087327527, 1.8039067450069615, 2.2413107127912584, 23.186726493220178, 86.34702559440368, 68.9603510210591, 72.86729843385758, 64.17289034012826, 71.58819783118464, 66.65407580714073, 73.67183146938201, 67.21862254604217, 69.83096030450636, 64.17628319032731, 67.66485491106587, 60.273285604292354, 58.81736063188123, 56.255503777534734, 55.38344713949389, 50.04192813750237, 51.061665934901086, 48.35697204835954, 50.94694837447136, 50.33501548151816, 56.46431115365798, 62.89643733732162, 66.07927599260884, 59.86151910597279, 61.72635509121803, 64.47321445711198, 62.33207102744811, 60.52897314871512, 64.06924563069498, 59.316541071861025, 54.65623970954649, 44.91836347887593, 44.360174902023815, 44.71246650142055, 47.22525058254119, 45.774428613724254, 50.21850932028986, 45.19598883967246, 50.15220165252686, 54.58517420676447, 63.232898250702895, 60.91038442427113, 54.74668564334993, 59.265695387317294, 60.670551100084865, 57.39180657171435, 59.20574195923344, 57.489014671694854, 61.00716106353268, 57.62665848578177, 68.23958412293466, 38.232840414970156, 31.603005201585834, 51.6981646322435, 50.42011130240656, 58.00471613484045, 57.490830729084635, 60.405300817181995, 56.63367909769858, 52.412573368318625, 54.31469932679207, 62.01404917624689, 57.11447146631057, 59.70663255260837, 57.370684608336425, 57.029720813997336, 55.91275138239707, 59.73895680519843, 57.21910461302727, 59.76189482596613, 59.02277515780542, 55.814594068834865, 47.045719777384114, 44.557070039933734, 43.10881330120949, 44.02043096480831, 45.978631127265196, 52.2761494113553, 60.72509557970109, 62.168327762234604, 60.54417233313284, 61.20137330024474, 61.55480630936162, 56.797853823631044, 46.21700140737718, 46.805039221240634, 47.393775216994754, 45.08549174954815, 46.36547488550986, 49.59478970496885, 45.75211817218412, 48.88849635278025, 49.539609801384714, 50.27600734464584, 51.729418077776515, 58.481539064838046, 58.52663063233899, 63.17544337241881, 62.472833125822014, 71.61672915181806, 67.79438726363644, 77.68693431731194, 30.668294583597493, 0.11341822934487175, 1.0563496908833905, 6.181915248593977, 0.9316737841694587, 0.6711605599811, 0.2655352676107038, 0.13957817077396378, 16.850178664730443, 42.1167125240449, 39.3530418795924, 50.14712218315371, 30.33690529484903, 25.416280146568056, 22.07533859437512, 31.861930662585845, 47.452018491683475, 58.814414931881814, 65.72917307576826, 23.297702112505515, 0.4310421285129363, 0.044065997935831554, 0.019696145431108533, 0.02940847981540907, 0.10235083289444448, 0.08950726925245217, 0.019677445224876848, 0.07003876110238415, 0.011932963764505282, 0.08011254917589888, 0.08663917395977244, 0.03824367991558487, 0.04169735366538648, 0.046875498993622686, 0.02138400375242195, 0.042899874219250296, 0.014218572722447496, 0.031063045870753068, 0.05388253751481253, 0.0446441070356917, 0.0865498940730768, 0.014542926688708607, 0.05940558328743904, 0.03568236453218326, 0.020154040013890595, 0.08592142618351406, 0.019955029523360635, 0.05058158339271623, 0.04319854125741028, 0.03125268136030965, 0.049959182919513796, 0.043134109432538675, 0.04857725989554198, 0.055638273141437, 0.5398199334740639, 68.17713214505103, 81.34605853788315, 76.14780410643547, 72.01455162417504, 58.41993431891165, 30.0000560668207, 27.781675284908665, 51.813639210116484, 41.52257150219333, 41.62119165543587, 1.760863022458169, 0.187253094007892, 0.12007894249813211, 1.6266138971813264, 2.9573518903024736, 4.667410167955584, 2.0650830336155432, 1.582066926263994, 26.725704593043176, 91.45029590975855, 70.4468822479248, 76.0521924111151, 67.55195340802594, 73.28998873310705, 68.26886853864117, 74.83533197833647, 68.26839000948014, 71.77727960771131, 66.87685858818793, 70.1140691388038, 62.45939508561165, 62.71247425386983, 58.2095266157581, 58.025065391294426, 51.03644901706327, 53.062749370451904, 51.70932377538374, 51.784005703464636, 50.83174051777009, 60.443524314511215, 66.21921831561674, 66.93665904383506, 59.93072148292296, 64.00764480713876, 66.34237289428711, 65.87026857560681, 62.456025769633634, 64.66606170900407, 60.107216373566665, 55.89737176895142, 46.462149543146936, 46.389248371124275, 46.20577558394402, 48.42445250480406, 47.473611139482074, 52.7983541642466, 47.23811203433622, 54.35360923890145, 56.47863957189745, 65.14916827601772, 63.10896312036822, 57.83238287894957, 62.202609277540645, 62.12360489752985, 60.13710091190954, 61.4537032958, 59.17390800291493, 64.58755154763499, 60.31977353557464, 70.70528015013664, 42.370058413474794, 33.00110463173159, 54.06392258982505, 52.379448952213416, 59.18255290677471, 58.558660707166126, 62.52142344751666, 58.964253394834465, 51.848171757113555, 56.07282330912929, 64.8657613415872, 60.462371303189194, 62.46330568867346, 60.39167450320337, 60.46200652276317, 58.38754338602866, 61.43717050552369, 57.85430892821282, 61.6407964306493, 61.51623764345723, 58.2347317664854, 49.099872881366366, 47.144810615047334, 46.39420232465191, 46.614988619281405, 47.3765677790488, 55.05058303956063, 62.294588858081454, 65.92329117559618, 61.80679898108206, 65.39385357210713, 64.0494337389546, 60.138399216436575, 48.821239471435554, 49.1528719471347, 48.26262335623465, 47.89653678094187, 48.6175194094258, 50.09167555839785, 49.103873698942124, 49.948760078799346, 53.06040771545903, 54.422019297076815, 53.4528330064589, 62.267610796036266, 62.35581705647131, 66.67331111046576, 65.99917334894981, 72.08568772962018, 70.84706598712553, 77.93315718250891, 34.83766425040461, 0.02974004075381785, 0.6390017210956543, 4.65329748007559, 2.894393926666629, 0.9135278578727477, 0.12200429765207153, 0.3143053441759079, 15.21177718716283, 50.37607877485214, 41.54433281190934, 73.07249330705213, 37.52660982070431, 28.074403732053696, 32.97937470097696, 39.13607989588092, 52.76252723509266, 64.00950008823027, 74.93783920041977, 30.670469537858043, 0.54980690080312, 0.02159767908104245, 0.019851257168357412, 0.04093894960298654, 0.032234972703360745, 0.08812064244862526, 0.011042299410027843, 0.03220085114721329, 0.07987540665893786, 0.05793302823158522, 0.07300546723267726, 0.005713177304114065, 0.045386151290468635, 0.03171043421682571, 0.03676330310202414, 0.07296405251949065, 0.04844787913644987, 0.04747399752358756, 0.13934990721604518, 0.1843091866542255, 0.32678795017061696, 0.1888677315606225, 0.1773561573316974, 0.09964777592329249, 0.14428883009860594, 0.2449939529141111, 0.23198312929561063, 0.09791807196433507, 0.11053064477539833, 0.14539666984590793, 0.2574010379612446, 0.18978849263681521, 0.19246961651069505, 0.15234004646059007, 0.9733306424271677, 78.92677199456, 88.50479202885782, 87.5936254378288, 79.54374513318463, 66.97048556420111, 30.07728949669869, 46.95798812373992, 81.87804175961404, 56.115820330958215, 48.154185510450795, 1.8076062755238627, 0.4623088733323159, 0.17279232641862285, 0.9230605044191884, 2.9726415343822974, 8.830854604321143, 10.685976839834645, 4.145798183256581, 30.249505081484397, 94.61942980366369, 73.59829487339144, 79.87672298185288, 70.42412465618503, 76.71607709700062, 71.08185122090002, 77.23326513844152, 71.5067772711477, 75.74064639306839, 69.40845827902518, 74.12385325278007, 65.11112520771643, 64.81568444159724, 61.45901026264314, 60.37365513463175, 55.306152912878225, 55.71180835846932, 54.03905868530274, 56.26685119444325, 53.63746681521016, 60.299404667269805, 69.02642726898193, 69.89932721660983, 61.63127683824109, 66.21273856009206, 69.76418587469286, 68.37506278868645, 63.431201519504675, 68.88029544584214, 63.76233193182177, 59.4330236988683, 48.25502964758104, 47.76423915739983, 48.943774315618704, 51.428638965852805, 49.71508487578362, 56.3680758014802, 49.52255925824566, 57.26117595549553, 59.80364845645044, 69.19742691901423, 66.9404088297198, 59.461288298330004, 64.07892211791008, 65.33061712018906, 63.58883373198971, 62.903313252233694, 62.45155819000737, 66.80443594532629, 62.10476183122205, 72.4233881119759, 46.43252780360561, 36.76354800501178, 53.8761704967868, 54.284085227597146, 61.95090686121295, 60.14267067755423, 64.55014782567179, 60.268723887781945, 53.65963212905392, 56.97372113504718, 66.58797602499685, 62.66193059182937, 65.11699699586438, 63.24117445176648, 62.80086486570297, 61.175693542726584, 64.23675044890373, 59.74023942024478, 63.73781319587462, 64.24217900922223, 61.42631338488672, 52.23179524944675, 49.641422763947524, 49.32090236294655, 48.66086159982989, 49.41572566186228, 58.378706286030436, 66.85323807501024, 66.98244094848633, 63.5531597752725, 65.8489465713501, 66.36415773822416, 63.73434189827212, 50.030608177185066, 51.05657077604725, 52.70343672844672, 50.83740049792875, 51.77929885925786, 54.97744652532763, 51.44416370699483, 54.51424206456831, 54.766905461588216, 58.051113851608775, 57.82302802608859, 66.59784470835041, 65.82591441369826, 69.4701571618357, 69.83296071329426, 76.2657811564784, 72.47008000650715, 82.42905632142099, 36.48814270573278, 0.26199872996057233, 6.8438686574659044, 14.751744943280375, 4.217103440915385, 1.3000010747102, 0.7027919626524372, 0.4342043862467812, 21.285096714573523, 60.677325033372455, 49.0318315259872, 59.859636368290076, 38.25478215371409, 35.642840554637296, 35.42267007212485, 45.40903629795198, 64.00527569555467, 73.40249799912976, 84.73402146370181, 35.22891283035278, 0.7634210189984691, 0.08148881847098952, 0.15313297810573734, 0.07384571246802807, 0.16225086464997263, 0.17045270921962877, 0.07092995118469962, 0.1445820885560205, 0.14243057658595426, 0.23350775151723818, 0.26384506314512224, 0.17457386388653712, 0.16901384288024518, 0.12638507185563927, 0.11370377329688881, 0.15431918864769323, 0.11616260143778018, 0.10425843013029906], [0.05117927369992099, 0.03688959269634178, 0.037017257418483496, 0.06602112789668384, 0.031040499903141495, 0.022930719949785742, 0.04244300619428677, 0.041232012707980416, 0.04391939552020162, 0.015528332179171905, 0.024445610939555114, 0.04979211829542633, 0.05708419898104283, 0.10760939830253202, 0.17068769902952258, 0.1731195532146, 8.765546160359538, 79.80264509877851, 66.26399609350389, 77.8823938677388, 61.6270249889743, 31.79724293370401, 24.718223771741314, 60.90636007247433, 57.411034030299035, 44.95714395276962, 25.90761192383305, 0.7486946640476104, 0.04854837071991736, 0.09684688952420989, 0.8135881335023911, 3.5029084740146517, 2.7614417576020767, 2.461136026728538, 0.5088544144265114, 60.61704212619413, 79.85522054856824, 70.76879901270713, 66.18576049804688, 63.46428278953799, 67.78567175711355, 70.70772770912417, 69.42461844413512, 70.66127115680327, 70.24255814090853, 68.50644649997835, 66.5673678921115, 62.71690653216455, 57.466802289409024, 52.441226282427394, 51.098414621045514, 46.19461251843361, 49.82462882995606, 47.02294257379348, 49.13515460106635, 51.01742552172754, 60.51704129865093, 65.01422697497954, 64.34399197178503, 61.47830047915059, 63.35050659794962, 63.74574815073321, 63.44169385971562, 62.878763137325166, 60.52185404685236, 59.785597708917436, 52.918857220680486, 43.516014160648474, 46.27549571375693, 45.79062408016574, 46.28181072973436, 46.8350100517273, 45.693937655418154, 47.2812581062317, 54.279221488583474, 55.910668603835575, 62.258573655159246, 55.01681535474716, 60.11388048048943, 57.20331315071353, 56.788400911515765, 54.0553443662582, 56.047147473981305, 53.37545248769945, 57.31922311167563, 54.92183516102453, 66.31357485248198, 42.407709244758856, 35.20306048854705, 59.15258207628804, 51.249971082133634, 55.28073595416162, 50.98075136061638, 59.39354112071376, 57.22563143699401, 63.06644855007049, 58.66657295534688, 59.581234378199426, 59.05889626472228, 60.214544188591745, 58.794532437478345, 58.14907112429219, 55.519576918694284, 57.138743092936856, 56.33691257046115, 58.33407363583965, 59.193598301179954, 54.65065425442111, 48.75458271272721, 42.65212781967656, 43.396064158408876, 44.60812753246677, 45.68175477366294, 50.43856213169713, 57.69653943277175, 60.53285237281554, 63.2265636228746, 61.75384698375579, 60.435950217708466, 55.98855118597708, 49.371418568395804, 46.65957420103012, 46.3322877114819, 45.923349242056574, 48.545904774819654, 46.56410763340612, 48.42943783729307, 46.970590699103575, 49.98467722246724, 49.836160598262666, 58.5127728985202, 58.9307681206734, 62.99483391546435, 60.839130647720836, 71.155897725013, 73.2636853187315, 71.46885579632175, 54.87072275530908, 62.87507610936319, 6.12878135135097, 0.9571886795663065, 3.344872747698138, 2.392307745833551, 0.31355454736659605, 0.12155119494925584, 0.03425000227927681, 1.4687459747637472, 38.57349434206563, 32.97512285171017, 10.86131953424023, 24.536647450539377, 54.97217093744586, 8.935106300538587, 22.569208145141605, 42.75572546066777, 55.07574896658621, 68.9342123462308, 48.27677919018654, 2.137645656062711, 0.07857213022127267, 0.04968692676254338, 0.04010276080319478, 0.018788672149962476, 0.0043353078428715955, 0.11588909272705356, 0.035927305824213454, 0.05237358562167614, 0.04599278567418937, 0.07144402682540879, 0.06989901900411614, 0.03949152606148874, 0.07428268902003765, 0.060182258546833074, 0.03126601703585156, 0.0298203191074032, 0.07888060318486345, 0.05396591469405159, 0.029337990150276213, 0.04512607593149428, 0.053809085004632516, 0.042311771502417904, 0.02549779056871851, 0.07340436155397086, 0.057282730666620124, 0.051837312583360946, 0.1164375427329252, 0.05574355660487087, 0.053454551004594376, 0.02388329282703419, 0.08316925531553646, 0.11249507807435528, 0.2452541623384722, 11.496195350923847, 92.94819416538363, 72.39856735352548, 87.18955070741715, 66.99971506672522, 48.852175204984604, 29.2219146990007, 52.84593251443679, 61.41068273975004, 48.41171656885455, 27.909258219503588, 0.284666811987277, 0.04726925669538398, 0.7530557880959203, 1.8731055673091643, 4.5783694232663805, 6.2465529672561155, 2.3052828542647825, 0.2328761273454274, 63.03963130520236, 85.71070732608919, 72.73309846078196, 69.78033819506246, 65.57370208924817, 71.46268198567053, 73.22424196427869, 72.99190428949171, 71.6247307869696, 74.04748470552506, 70.00464285573652, 70.0877578796879, 66.06659104747158, 62.09957645785425, 52.65142609996181, 53.355664130180116, 49.16857319493448, 51.88046463074223, 48.26158785050916, 51.77436059521091, 51.42298290806433, 63.2759266514932, 66.16240670604091, 66.86733507340955, 62.79362417036488, 66.83517163799655, 65.76334476470947, 66.06874050632601, 64.98227142518567, 62.03177044468542, 61.6856958020118, 55.33555892206008, 47.28261132394114, 47.95063411035846, 47.94414651009345, 49.11078883755592, 48.2723351447813, 48.14413639806932, 49.584658222813765, 56.636401222598174, 59.97047078224921, 63.97905857332292, 54.8854551776763, 61.76832837443199, 60.46716443953976, 59.55616258805799, 57.20585484658518, 58.04111965240971, 55.24330477560721, 58.84602139073034, 58.24586345303444, 69.2340853906447, 44.663091705691436, 38.429056982840265, 63.828306198120124, 53.59175943559217, 57.11047457110498, 52.66659782778833, 59.90606938638995, 60.05157755267236, 63.84717672101913, 59.505089406044256, 60.839150259571696, 60.69575625081217, 60.61759518038843, 61.51278203533542, 61.80221765272079, 59.40236645360147, 58.996185410407286, 57.60226134330996, 61.37520490154144, 61.684848570054584, 56.33817949602681, 50.8617348824778, 46.32222683198991, 46.84627902123236, 46.5404635860074, 47.5354237710276, 53.337876181448664, 59.66784031160417, 63.679118848616085, 65.17241224165886, 62.235486584324995, 64.00246335614112, 56.1709374766196, 49.8504654822811, 48.254711935597086, 48.656864704624304, 49.576582062628965, 51.46099459740424, 49.430356102605025, 51.301095254959606, 50.949133134657345, 51.900335358035186, 53.918892952703665, 62.25079559510755, 62.47648485245244, 66.05796183309248, 64.91366917087187, 71.99808551419166, 74.51379176109069, 74.3773481922765, 59.8108656175675, 68.935059578188, 7.645722223866371, 0.8183267856797865, 1.296482340943429, 3.4047857263395866, 1.828349730180156, 0.6813899175293985, 0.044168619243728544, 0.8063182042491052, 44.25601636209796, 38.91765094572498, 12.560606983400161, 28.43155710927902, 54.92509072826755, 15.612572816110427, 29.38783880203001, 53.70614359455725, 60.9158718201422, 76.24136047978556, 59.041739817588564, 2.758487722566051, 0.04472289917870395, 0.14560714484222476, 0.008766841117082345, 0.04213041550810299, 0.11709188907257012, 0.12344902456407586, 0.038421431466216044, 0.0032033138221219904, 0.03217334092985238, 0.04506178966332828, 0.02395906658362477, 0.11140118878815444, 0.037800352494683, 0.06680989968440225, 0.06896301277823026, 0.03808779251431266, 0.03092951291511136, 0.17159278594678448, 0.15881656909421568, 0.17943729646503928, 0.18999662340408374, 0.11956296695937073, 0.13355789946452265, 0.14895398380054584, 0.17959445174182617, 0.16678809699031616, 0.18533396714877698, 0.27721372643305414, 0.09897557207413259, 0.1066424421245052, 0.22815514115556595, 0.3027266912883328, 0.3606516411227565, 15.009666277516274, 101.83853641633065, 84.52364906187981, 96.91409480187201, 77.78485236629363, 48.47377238735076, 35.111759478046054, 82.61116412378128, 73.1927296423143, 65.14036255498087, 34.866909442409394, 1.2812657510080647, 0.14236017310571286, 0.9467402821586979, 3.009875858983686, 10.304870528559531, 11.628134077595128, 9.158720624062324, 0.6261146513204421, 69.27585078823951, 85.73792857508506, 77.36003614241078, 70.59083323324882, 69.84158992767334, 71.70244078482352, 77.15645728572723, 75.17927677400651, 74.32333715500371, 75.62419906739267, 73.94431852525281, 71.15370904245685, 68.71033130153533, 63.6283084654039, 56.01709427372102, 56.37617549588604, 51.16389074633199, 55.72968652171474, 51.12367076258506, 52.62456178665162, 55.336229647359545, 65.89079826108872, 71.98685184601815, 68.56114787440147, 64.36509040094191, 67.47672234812092, 68.26391850748371, 70.97808099562123, 67.51628337367889, 62.898265161821925, 64.15363150258219, 58.89321927101382, 49.17441360412106, 49.79321456724598, 49.87428603633758, 49.958903328064956, 51.458378376499304, 49.38427609782065, 54.59512525989164, 58.32156519736014, 63.20933265070762, 66.21966546581638, 56.50818678640551, 64.30658432745165, 62.562847598906494, 62.52687554205618, 60.427646560053674, 61.78350402462868, 58.33184572958178, 62.65043412485431, 61.5443806494436, 71.30808568769886, 50.346402122128396, 41.464014437890825, 62.94857348165205, 56.53888717774422, 59.393093970514116, 55.42325527437272, 62.90346230230024, 62.319727328515825, 69.05728063275738, 62.309227143564534, 63.112756052324855, 62.26323735329413, 63.04618950813048, 64.99899248923025, 63.17741240224531, 59.705671571916156, 60.54392130144181, 59.3219853216602, 62.53083321356005, 64.98338145594444, 61.17412851702783, 54.128123944805516, 47.40451466652655, 48.981440836383456, 48.230824701247684, 50.573942738194624, 56.201143649316606, 61.24739446947652, 66.21921047087639, 67.3184625564083, 65.20881183685796, 66.65093006626253, 60.485207342332416, 52.41458162184685, 52.04354109302644, 51.49788841124504, 52.46462714287543, 53.59038268366168, 53.73670278056976, 53.91368012274466, 54.177788995927386, 55.73127508163453, 57.329362438571074, 63.659314801616055, 66.70613350406771, 68.30620165794127, 67.86141272514098, 74.34918557443928, 75.97798116745489, 77.2220471597487, 60.40753264581004, 72.52340855136995, 8.79877353868177, 2.055918047985723, 14.266602666147294, 7.740181232652358, 2.577562514812716, 0.47092628995737723, 0.08045008751533686, 2.1818115442029895, 50.57590000091061, 48.49638485139417, 16.876797829904866, 38.34463580962151, 75.47162671242991, 17.758711384188747, 34.914256372759425, 59.40669282790154, 70.38498724660566, 84.38798996710008, 68.45079591197353, 3.3679907071974973, 0.13550406922736477, 0.19018740994074654, 0.0804710170374282, 0.2198798440757298, 0.23807084698590542, 0.3293396358288104, 0.10739618071144628, 0.1846845850588814, 0.1723857942007242, 0.18582121439037785, 0.259068995233505, 0.17266337849920796, 0.20931513919945688, 0.32640625452322347, 0.20473836140046198, 0.09404781875350783, 0.1552683869076352], [0.07922507462001617, 0.020811014035115802, 0.015039729919554967, 0.08742456729974478, 0.04154391391503234, 0.06391184652344355, 0.008775028681773092, 0.04855535361134718, 0.06379153241493529, 0.03478222271247256, 0.05044441534987381, 0.029183638755292184, 0.10886002151716141, 0.08426068545950037, 0.1666927650090187, 0.17025109019971665, 30.051456766743815, 83.0377140352803, 68.23403004677066, 73.71191024780273, 45.05334008124567, 32.16298041805145, 24.292789774556315, 38.486323587356075, 28.786394326917588, 61.723126980566214, 23.01049832374819, 0.21842233115626922, 0.08202499574831418, 0.991178039581545, 3.530848252196466, 4.0881540506116805, 2.252308793606297, 1.874268550065256, 8.469782779293677, 82.84354886701031, 70.90955718871086, 72.32135157431327, 62.98877777591829, 64.99371297897832, 63.922470538846916, 69.86034670183736, 68.91181561254686, 69.33122681033227, 68.00333192271572, 69.68305557004868, 64.93205331986951, 64.69179245733446, 57.78573413049021, 50.54059082461942, 48.95382735037035, 48.01087779383506, 45.76833717284664, 48.507461624760786, 47.57125854492188, 48.17726473654471, 61.82081360970775, 63.87445288319742, 63.166508213166274, 62.848309855307306, 62.74107225479619, 62.37845697710591, 60.64667563284598, 61.619168481519154, 63.455304484213556, 59.77216359107726, 51.63394366541217, 45.66682231041693, 45.32217541048604, 45.19545539732903, 45.14779859973539, 47.8352262127784, 44.462207517316266, 50.29335991028817, 53.83095733581051, 62.63152830062374, 59.99168688251127, 58.016691130976525, 61.900567162421446, 59.57732377513763, 56.56679091915008, 50.41236069894607, 53.09919603409306, 48.743203916857325, 54.665590640037294, 55.28936516854071, 63.89655543911842, 45.679279758084206, 39.30242761488884, 61.77971501504222, 57.32264734083607, 60.02217154349051, 57.533353144122714, 58.765706939081994, 54.89895205343924, 58.485822293066214, 60.66002738091254, 59.90480246082429, 55.69708770321262, 54.14617469233852, 55.71162008470105, 58.526646321819676, 54.8876517049728, 56.75690820140224, 50.28934340323172, 56.02488017851307, 58.708193225245324, 55.22026085084485, 47.22278341170281, 44.887157101784986, 42.51411922516362, 45.06062000028549, 43.490357937351355, 48.85462276397213, 54.75371060832855, 59.55678624491538, 60.974464185776256, 61.947933704622336, 58.45598874553558, 53.654733088708696, 43.85317325592042, 47.64672494703724, 43.74051493983115, 47.84182756177841, 46.3941748680607, 48.41386995007915, 47.572847104841664, 49.36221668797155, 48.68235226600401, 60.9729423061494, 60.75543511298395, 66.99007388084166, 64.27148695914977, 64.18299044332197, 73.65988392983714, 61.64265955648115, 66.776226259047, 72.37831223395564, 59.34251892951227, 48.68789849742767, 0.4018338619460983, 1.6899931478884913, 3.1672783676655065, 0.6099199816103905, 0.6985676925509208, 0.3538711501225349, 0.26690631984703006, 21.653915220691314, 53.6700342547509, 44.666782656023585, 18.59499796744316, 28.411176473863666, 33.46391685547368, 21.99815615530937, 38.02824958678215, 50.14452165172946, 57.543280663028845, 64.86919733785814, 12.48409232785625, 0.42755403826313637, 0.04233470434443124, 0.09552449153195466, 0.06520234078409211, 0.06436869156576934, 0.06073579920696155, 0.03395129693672061, 0.04681586287915707, 0.02004588563596049, 0.12188507138841576, 0.09215551263262188, 0.059333613157392516, 0.01628719014866698, 0.0532509018516829, 0.05140616213001552, 0.019870236996681463, 0.0411774595868924, 0.026152912572386767, 0.043819696837735754, 0.020638531254183863, 0.05145987638482644, 0.006501921799950182, 0.06978989744018163, 0.06278254482294283, 0.03421055258161599, 0.025083919228505225, 0.03392980434000492, 0.04905707225383771, 0.029016828855439544, 0.06308436814335085, 0.12455706349423817, 0.11342634987686911, 0.027938527543277993, 36.675145626068115, 94.15718632359659, 75.70667082263579, 80.67490177769815, 54.96276901614282, 36.69012908012637, 30.38719400282829, 41.48431270353256, 30.33573054498242, 68.76412268607848, 20.17980025660607, 0.5053715948616305, 0.01437711461837734, 1.2923431372450245, 2.4733201342244304, 3.5332774250738086, 2.47139964372881, 1.7958966522447526, 10.54747304608745, 88.84690115528723, 72.47251972075432, 75.43692942588561, 65.40667187783026, 68.2894217583441, 67.17586871116393, 71.84053174911007, 71.15825114711639, 69.13368055897375, 67.3278840895622, 72.21121141987463, 69.4457600193639, 66.87187717806908, 60.7519285140499, 53.15399939014066, 50.60381158705681, 51.02309726899671, 49.66658476860293, 50.02945892272457, 49.773437976837165, 50.43403571651828, 63.32443852578441, 65.71320510679676, 67.08330077509727, 65.768683110514, 65.49989092734553, 64.59313700276037, 64.38358437630438, 64.35529232025146, 64.14364907049364, 62.089401829627256, 53.957724417409594, 47.620962819745465, 47.69187535009077, 47.046967091098914, 46.71451876240392, 48.265066992852, 47.308953962018414, 52.99460211107808, 57.0540669656569, 63.24869363538681, 62.09877237196892, 59.44163330139653, 64.55647068638956, 60.62993495695053, 59.04060233023859, 53.44349384307862, 54.789545382222826, 51.20474615404683, 57.11376151730938, 57.508787339733495, 65.81325300278203, 49.86130691343739, 41.41991915241365, 64.97948654236333, 58.47962494819396, 62.74053096771241, 59.41845209367814, 59.49745255131876, 56.66099448357859, 60.370183837029245, 60.01784124682027, 61.904116907427394, 57.31190004656392, 55.331075652953125, 57.474305783548665, 59.85505503992881, 57.24896169477894, 57.94947347333355, 51.58307052427723, 58.09172215000276, 60.947262548631244, 59.359875417524776, 50.71927047544911, 47.86116484672793, 44.924682417223536, 47.36187850275348, 46.33255051028344, 52.08194501938359, 57.07726778522615, 63.51450089485415, 61.68840615980087, 65.78074439879387, 62.41543316072034, 56.52129142515121, 46.27106343546222, 49.505163546531435, 47.08296660454043, 49.24202349878127, 49.57478953946022, 51.88830544871669, 49.79495609960249, 51.75360341225901, 51.881990432739265, 64.25879809164232, 64.14202913161247, 68.34552734128891, 67.35377173269949, 66.46665711556712, 74.45015522741502, 67.69720662024714, 67.20705155403384, 74.6501176587997, 62.88199909271733, 55.19076462714903, 1.0667114897120384, 0.5023583259072997, 2.2135209652685353, 3.371021228451883, 1.2348878912387358, 0.10653579502456612, 0.28683248126218397, 18.703861390390706, 64.76158711218065, 31.732131588843565, 19.13374335535111, 35.034241676330566, 32.71684850415876, 28.494191477375647, 44.17953798847814, 58.4742905247596, 62.70546105600173, 75.83013919091995, 19.236199586622178, 0.5900969969168787, 0.04780573657743874, 0.08242778179626312, 0.10174711730571524, 0.01570580410771072, 0.01767394144178158, 0.04620408038458517, 0.025360907893627885, 0.03175941787870421, 0.01697001197645741, 0.014831749497041588, 0.0075967663020316155, 0.0823533257109023, 0.03893126681026432, 0.06712728225055241, 0.03262047580773792, 0.08643747067018863, 0.2424221344652676, 0.11790041826785573, 0.13958316566723009, 0.23457544825730786, 0.14169989724553403, 0.18055580015624725, 0.13980470297317352, 0.13040782252867378, 0.12075541345703027, 0.1783150695865193, 0.11353797654831603, 0.1459870784873924, 0.3254664178577162, 0.29780068464817544, 0.3201722293611496, 0.21047695750190368, 42.330426785253714, 102.69803754744991, 85.3036202153852, 90.22246852997812, 58.80318910844865, 45.75656221758935, 38.113392476112615, 54.02440471033896, 42.03225997186477, 80.26866189895138, 27.633056679079612, 0.6231242730732888, 0.18400054515129138, 2.90639441820883, 8.75993226805041, 13.169579467465802, 8.42573848462874, 6.0945836767073605, 11.504722583678461, 91.57781216406053, 74.81387661349389, 80.1393727333315, 69.46385783533897, 71.45567663254278, 69.14114875178184, 74.12120173054358, 73.401274219636, 71.9275926774548, 68.4487876584453, 75.35873305413031, 71.9452747221916, 69.12094854539441, 62.900693108958585, 56.41898032157653, 52.47375449826641, 52.692061854947, 50.96415189004714, 53.8584453059781, 51.83757351290796, 53.613744320407996, 68.30599769469231, 68.35177959934359, 69.74705296178018, 68.18530636449015, 69.79372916683074, 67.52786221042757, 65.87955674817486, 66.37186911798292, 66.58022542153635, 64.70607380713186, 56.39409680520335, 50.56989092980662, 50.295752556093284, 49.64969112027077, 47.828871973099254, 53.2152864240831, 48.920510738126694, 56.34007007844987, 59.28060431634227, 67.67262904874741, 63.34592526958835, 61.542831313225534, 68.57178534230879, 65.45495233228131, 62.96330590401927, 56.305596367005386, 56.92963369431035, 54.28471280682472, 60.75337586864349, 59.193029557504964, 67.29617564908921, 54.34299922758534, 44.87326406663464, 67.71892870626142, 61.70267182011759, 65.38245516438639, 61.997233975318174, 64.49543468413815, 59.72085114448302, 62.767607089011904, 65.17055303819718, 65.27681789090558, 58.87752586795438, 55.85745773007793, 60.62545953258392, 63.98731908490581, 61.43381295665618, 59.69841518709737, 52.29206246714438, 59.305095595698205, 63.68026810307657, 62.54420457347747, 54.2259596240136, 50.70680126067131, 48.547650229546335, 49.69707335195234, 47.877776084407685, 54.81518983840943, 60.773183838013686, 64.89299828006376, 65.24647443525254, 69.0748763853504, 64.49241053673529, 59.51235755797356, 48.45015187417307, 51.647821011081824, 49.747162019052816, 52.233277905371885, 52.6827815271193, 55.87528882488128, 52.41474243902391, 54.17798119206583, 55.65358077326129, 67.41981660166095, 67.38157349248087, 72.69057212337371, 70.83343182840656, 69.58066601907053, 78.69336743508616, 71.32826235986525, 69.22176914830362, 77.18905218185918, 66.7290872143161, 56.71210688929404, 0.9256930276751519, 5.400656086783256, 11.22573321865451, 4.313941367210881, 1.2700796415728908, 0.5223333330885057, 0.23048024864927416, 25.384436384324108, 70.26176206527218, 70.21332079364409, 27.92590279732981, 39.36515023631435, 45.43331184694844, 32.32068519438467, 50.78706472150741, 67.74050958694951, 69.68983342570644, 86.31935719520816, 20.880692505067397, 0.665697617636573, 0.12607862136416859, 0.19992651718278087, 0.20587695191704458, 0.17076099832211772, 0.11855120229865275, 0.1337317094927834, 0.13194353770344489, 0.16885915440657448, 0.1925838095766883, 0.1788002637124831, 0.19218136826830526, 0.12387088620133939, 0.14414152671252528, 0.19848642510271844, 0.10287548820938795, 0.19467283941565022], [0.04668163661394389, 0.10778916849484367, 0.02850990081506391, 0.024383395024004485, 0.08236005196287748, 0.017036280497127486, 0.07093382758959647, 0.16600789772647043, 0.0646649913922433, 0.02522604769065736, 0.019041394980083552, 0.036063064265275196, 0.017903859749616637, 0.07842509496596553, 0.035789329558610916, 1.246378964954807, 53.25580450796312, 67.10019050105926, 64.0138578414917, 64.1018719057883, 52.13343005026541, 62.69656904282109, 33.76845359802246, 41.70604428937359, 49.474357251198064, 57.77280207603209, 4.1367316246032715, 0.03699482253362094, 0.04412296423388105, 1.1371702508580301, 1.5726391418326287, 3.05741768210165, 3.3615141385985963, 1.7146269808853827, 30.808334965859693, 83.76934589878206, 69.58766352745795, 65.42902938781246, 62.141659567433024, 58.6148839612161, 62.83449526756041, 65.81044458573865, 69.30420952458536, 67.33851371272918, 67.12499557002899, 63.37205609967632, 64.85673204545053, 63.80783142582063, 55.7918207876144, 49.51421245451897, 50.254285258631555, 47.03857321893015, 47.26112850250737, 45.76142203423285, 44.99230407899426, 46.180237031752064, 60.31684352505592, 62.95824996886715, 61.50101492481848, 62.29358080894717, 58.46390016617314, 60.084592142412745, 61.889513923275864, 63.61430952625891, 63.15903217561784, 60.581838853897594, 53.42028517876902, 45.42250179475354, 43.688520000826934, 44.32265350895543, 45.880132567497995, 44.946224074209894, 45.399355888366706, 50.65900325775147, 55.47681131670552, 61.828419085471864, 54.38578444142496, 57.81950181530368, 59.68096848457091, 56.82372969965781, 51.37233726439938, 43.68102827379781, 53.469373641475556, 47.37167658344392, 56.17379296210505, 56.416293498008486, 68.16256446223106, 44.148645401000984, 41.66964861654466, 63.62185224410027, 55.28730592420025, 56.92464051708099, 55.5733722256076, 59.41818537250642, 52.763484293414706, 55.60777925675916, 55.9718301219325, 58.75230420020319, 59.98534048757246, 54.86058342841364, 52.65562303604619, 56.633475134449625, 57.52924250018213, 53.40334838436496, 50.64255675961895, 57.7700093484694, 59.48614828048214, 53.94567489624024, 47.367393355215754, 45.02393014969365, 42.9925738611529, 43.21510953287925, 44.090629623782256, 44.180200869037265, 55.13320776724047, 60.8815550035046, 62.16847681230115, 62.1753409601027, 57.33654037598641, 51.11419039387857, 42.95278141575475, 45.982200484122004, 43.49293101218439, 47.583896421617084, 45.28084931835052, 48.82386353708083, 48.299662297771825, 49.836125296931115, 55.74273624727803, 62.24115048685382, 61.62826838031892, 67.09616614926246, 60.816635854782604, 67.4954398985832, 59.57735907646918, 66.6182174990254, 65.78901667748728, 66.93802402865502, 64.95117095208937, 72.48991935483872, 37.64804640123921, 0.19016004528009123, 1.873046486608444, 3.161974342599992, 0.7299358061244412, 0.21773073762174577, 0.07285235690013056, 0.9568530104814038, 50.82560593082059, 40.78549146652222, 32.401995928056785, 29.09814234702818, 25.34762494025692, 14.602377164748408, 29.782729302683187, 53.753357164321415, 57.859321717293035, 64.53505062287854, 36.126233454673525, 2.129432458070017, 0.05979604298068632, 0.11731119706265389, 0.005446183213573551, 0.039441358793767235, 0.046619663931309216, 0.09315811488176547, 0.0685514550235483, 0.05827682167892495, 0.03895753979562752, 0.02108835127024401, 0.035119489090697426, 0.06086349074218062, 0.060103439590743477, 0.01946688595888836, 0.08003731934173454, 0.017363995674156377, 0.06442372732224964, 0.0794177610547312, 0.036244968012455976, 0.10915056802332403, 0.15017586339625622, 0.07703504374911709, 0.014830713363123998, 0.06996268857150309, 0.05240138695244828, 0.0670775248398704, 0.03345963702867589, 0.07815237532580092, 0.035433956692295696, 0.04559120238428155, 0.07822484724343785, 1.6898443429700791, 66.54535555070447, 73.63236458070817, 71.4914486485143, 72.25756599057105, 59.747197704930464, 65.55140733718872, 28.737825578258885, 39.129149067786436, 52.8000956966031, 66.23065594703921, 3.98230791091919, 0.1568020183232523, 0.1274313334555876, 1.9269959916991575, 2.8361293240900967, 4.064260687558882, 1.0055447622172295, 1.032952017361118, 33.44323027518488, 86.13748473505821, 71.84610151475476, 68.42255484673285, 62.38877673302928, 61.10573022596298, 64.88478483692293, 67.93990719702937, 70.2767925877725, 70.2331522972353, 66.55941332540205, 66.61763698823991, 68.779066916435, 64.64569284069923, 58.754253618178836, 51.927380100373306, 51.18844870598086, 49.09706446432298, 49.20458447548651, 49.397266987831365, 49.0787430732481, 48.575338240592714, 62.998316980177364, 66.82328685637444, 64.03851778276506, 62.938167433584894, 62.80748974892401, 62.09738385292792, 63.95914862232824, 65.07276834980135, 65.22431696614912, 62.118376378090154, 57.02012277418568, 47.211020223556034, 46.83402945918422, 46.420466515325735, 47.527418213505904, 47.32239984696912, 47.835073240341686, 51.71933758643366, 58.06337125839726, 65.06952454966884, 57.22225427627564, 59.76053768588651, 61.20881403646162, 58.119237576761556, 54.202519539863836, 45.8201281486019, 57.146497618767526, 48.98942285968412, 59.101285319174494, 57.79965854460194, 68.55295796548167, 46.9633186248041, 45.4867894418778, 65.51205419724988, 57.69508031106765, 59.65503769536173, 58.70510239754954, 61.89321271834835, 55.67544406460178, 57.0073397697941, 57.25914416774627, 61.638905848226244, 60.13958377222861, 56.26193254224716, 53.69745554462556, 58.414897995610396, 57.93564711847613, 54.95383777926045, 50.7315121927569, 58.60112820902179, 61.71599611159294, 55.641040955820394, 50.800910688215694, 46.640252605561294, 45.070610277114376, 45.62992457420596, 45.11895741185835, 47.25867702114967, 56.76352131751276, 62.6060603510949, 63.58779430389405, 61.87606803832516, 59.91726383086174, 53.88399562528057, 46.74927880687099, 48.90955555823542, 47.081946788295625, 49.62985177193919, 48.56446543047505, 51.46790581364786, 51.42859974215108, 51.877926857240745, 59.394678608063735, 65.3988036032646, 65.04904585499918, 66.93327011600618, 62.52497319252261, 66.67087924095893, 63.07614072676628, 67.0343731295678, 68.13615906623103, 68.75230850711947, 68.20745206648304, 74.80158390537386, 44.05493213284401, 0.12923275090513692, 0.9217085737374522, 2.422277350579539, 4.177141843303557, 0.5494529068950684, 0.0008060474295146584, 0.38621032610535627, 55.293617017807506, 46.79787305093581, 27.997684132668283, 20.481440328782607, 24.259241742472497, 21.020497545119255, 37.216475855919626, 61.85506766842258, 62.817770281145656, 72.17197987341112, 46.39597523596979, 2.6851134146413496, 0.08105092261347079, 0.039581920606114214, 0.00935688107875326, 0.011946470852220252, 0.02571144291470128, 0.036224540277955034, 0.06786010663716063, 0.017938191979943265, 0.06219807719331115, 0.06270681703162771, 0.06805550502312761, 0.0577797876640914, 0.03384911995981971, 0.019798881652194168, 0.0462372136873103, 0.06806521135712824, 0.1793091759205826, 0.2244279701863566, 0.09947999500699582, 0.24250217533159643, 0.17430964016145276, 0.1398511432231434, 0.19067217505747275, 0.22958273068070414, 0.08826920221890174, 0.10660746254988256, 0.11586385779082777, 0.15807916350182027, 0.08164852482056426, 0.1923337125129277, 0.1764356107601235, 2.4431279349711637, 76.18339569337907, 83.61703242025068, 80.72297434653007, 81.42009719725579, 66.19772372707244, 70.15513635450795, 47.842011913176506, 57.0616606743105, 67.70250966472011, 72.99052361519107, 5.111158201771398, 0.2593005376477396, 0.14074833943478524, 2.9701481326933834, 5.920934465623671, 8.45529648565477, 14.026039781108981, 3.5877780231737324, 39.44329169488723, 88.70326395957701, 75.85481874404415, 69.18593437440934, 66.10415166424167, 64.4675858559147, 68.85867534145233, 70.01559411325763, 74.03497234467538, 71.90281898744645, 71.43082449513098, 68.28813522092759, 71.31945271645823, 68.22388679750505, 61.61372815409015, 54.70912894895, 55.33408411087529, 52.298173519872854, 52.29568281481343, 50.75144175560244, 49.61235015623031, 49.86366425791095, 65.8252005423269, 69.81529435803814, 66.92940265901628, 66.89468183825093, 64.38724787004533, 64.11864396064513, 66.43959276137814, 67.20953833672309, 67.99735423057311, 64.09630998488396, 60.453404764975275, 50.93598534983974, 48.73722230234454, 48.66594106920304, 51.42531279594668, 49.213421575484745, 50.87829120697514, 55.50819027808405, 59.93784450715589, 68.58157557825889, 57.77486132037256, 61.93846510302637, 64.58234656241633, 62.432722968439904, 56.72522721752044, 47.521675863573634, 60.02453673270441, 52.92510947873516, 61.35090189595377, 63.74389679201188, 73.85495908798711, 49.21555142248831, 47.61686786528557, 69.05818277789702, 62.55393597387499, 60.7940939934023, 60.99308367698424, 64.11572179486676, 58.954827939310384, 60.21788604797856, 61.51483343493555, 64.75848059500417, 64.05352477104434, 57.13449124367007, 55.645779178988555, 62.321064856744584, 61.017931892025864, 57.317987565071356, 52.25352125783121, 60.28273067166729, 66.40353049001386, 58.32940993770477, 52.17990621443718, 49.26921729118594, 48.522331330084036, 48.763141324443204, 49.0294937933645, 49.79385783595424, 60.02874935826948, 66.96294676872992, 67.28020375774753, 67.54133947433965, 62.82188092508624, 58.31392834263464, 48.64658809477284, 51.741663717454486, 49.654084174863755, 51.84165277788716, 51.27274044098393, 54.79528380978493, 53.34577975734588, 55.56324074345251, 60.55393119012157, 68.97428327991118, 66.69984986705165, 72.23698139190674, 63.20663013765889, 67.63451930015319, 66.87350103932043, 70.6823185951479, 71.37030232337214, 72.35894357004474, 72.58929652552452, 79.5906174567438, 42.87309846570415, 0.6614034190293282, 8.917745890155915, 8.310788523766304, 3.5896337945615095, 0.5618051247250649, 0.169351565080785, 1.4581476079840816, 63.68560252651092, 55.570030366220784, 45.94509093992172, 40.70118011966829, 37.705630717738984, 22.126096025589977, 43.33694227280156, 69.22539341834285, 71.89195402206914, 79.61278669295773, 53.80621110239337, 2.711230761581852, 0.15705151783843196, 0.1372961480651171, 0.12071090374862957, 0.142696485704472, 0.13746208270951626, 0.15261485752078796, 0.16729926149691307, 0.07610332761560717, 0.13013837408394585, 0.1513928400292512, 0.1270783661053546, 0.1964242236628648, 0.16068116581488043, 0.15698872927215793, 0.1714651250550824, 0.2051140815620461], [0.04024868523101172, 0.06956573245265792, 0.06036944447025176, 0.005747990254613181, 0.023462501797644843, 0.07100015548208068, 0.07869713278787752, 0.04911559754081311, 0.03180285123357129, 0.03746737620883411, 0.06750207544574816, 0.07714352946007445, 0.06498316302895546, 0.07741211222544794, 0.3430855514541749, 6.5388264194611585, 78.82253108486053, 62.004074588898696, 70.63510110301357, 48.00647689450172, 32.78885929815231, 12.862349037201176, 52.470212598000806, 43.32148421195246, 47.32509843764767, 49.804263884021395, 0.3076747612607095, 0.06277450473017751, 0.2725061467818676, 1.4349979018011403, 1.2757926963029371, 1.1635513771926205, 1.0902426463942374, 0.25192729377698514, 59.096084256326, 78.6328923317694, 71.35185149408156, 66.90902202360093, 60.13036620232367, 58.126921499929125, 53.55292404851606, 61.11914080958213, 63.81201267242432, 66.3248477443572, 65.95990257878458, 67.74690305033039, 66.35905081225981, 58.56965511075912, 50.95023139830559, 50.08548213589577, 47.16600318108836, 47.08106425500686, 48.21361726330173, 47.09707537005025, 46.30478405183362, 44.03813654376615, 52.079007164124526, 58.56248501808413, 57.84154945804227, 57.78480845112955, 55.525672281942065, 55.31680607026624, 61.95463311287665, 63.89883825855871, 63.32110058876776, 60.845194632007235, 54.56750785150836, 46.76510949288645, 45.90034454099594, 44.85128310418899, 44.52551849426762, 43.32776784896851, 45.0810633936236, 52.45006338242562, 59.58532541028915, 62.029279739626, 54.64583758384951, 55.307847376792665, 58.301153182983406, 51.48101045239357, 48.3850444516828, 46.25543671269571, 46.73662131832492, 49.95574582007624, 60.21046884598271, 57.586960177267756, 65.22320693539035, 43.465937260658514, 45.38157970674577, 62.51939558213758, 54.595525341649214, 55.85269989505891, 53.144115017306426, 55.34946764669111, 53.25366681621921, 48.89168523973035, 51.56969131961946, 56.93585457340364, 57.11353009746921, 56.325227829717825, 55.82190536683606, 56.562735188391905, 53.71697718097318, 55.23924120010869, 55.110524700533965, 54.917249910293094, 57.80167856524068, 54.99377927472515, 51.56930692734257, 43.973519417547415, 45.40524336599535, 42.28067544198806, 43.85120422609391, 43.23805932075747, 50.524662079349646, 58.31776049829299, 59.877075226076194, 59.40471203096452, 57.57912720403364, 46.514422970433394, 46.2070385871395, 43.871918262973914, 46.94641713173159, 47.518361460778024, 47.19707619759345, 46.661786417807306, 50.13440193668489, 55.18073904898859, 61.52666722574542, 60.98801989709178, 65.27389964749737, 56.047374971451305, 66.93846333411433, 61.3883448416187, 67.77282991716939, 62.62712347892023, 66.38908047829905, 62.99425732704901, 68.43556927096459, 61.52586706223027, 80.02051707236998, 25.675144810830396, 0.8710908769599853, 3.2027883202798906, 2.0683150666375316, 0.26263565546081913, 0.0686416925201493, 0.1107369062881316, 20.43794712712688, 56.48204811157719, 29.73637277080167, 52.32921515741656, 37.48760184934063, 30.99977997041518, 20.66389722208823, 43.15355577776509, 49.504771309514204, 61.602733750497144, 56.372308038896136, 12.693792043193696, 0.5422384424075004, 0.13193748560884308, 0.08413615786740858, 0.11728030073666766, 0.14380467785221918, 0.0008090713820438983, 0.04019445386685191, 0.047519346098265344, 0.019993077280120026, 0.05605849918098219, 0.04511179222214607, 0.013142209612734377, 0.05207768416092281, 0.015007811823799727, 0.04237291681009435, 0.06660268056176363, 0.016477798569887396, 0.09760173893864117, 0.022351339143971284, 0.09638665454281915, 0.04882252677493999, 0.05368692079378713, 0.027266107274279482, 0.07177788028193098, 0.057839404626358906, 0.044045194818247715, 0.017561613799883954, 0.07842481151343354, 0.15292385142416726, 0.06185384707585458, 0.26749522695618294, 9.448507293578118, 89.76023289465135, 70.48164229239188, 79.6716614692442, 57.10455571451495, 48.988759979125, 23.039617999907463, 43.18967688468195, 41.332422840979795, 55.93547759517547, 52.29270181348247, 0.1794926386566893, 0.13130128023124513, 0.6712944721502643, 2.314894622372043, 3.0198166158891495, 2.5825184295254373, 1.0516983727293632, 0.38262763931866617, 64.1778286041752, 82.61746345027801, 75.04719488082394, 69.02401108895579, 62.98329430241739, 59.846370912367306, 57.00660628657187, 64.65980552857923, 66.74315283375402, 69.05441730253159, 69.17635594644855, 70.94562730481549, 68.23628933198991, 62.62028286533972, 53.2157963322055, 52.62700934563914, 48.73282532538138, 48.71742217771469, 49.22752641862439, 49.35621546160791, 49.06581886353032, 47.61048224664504, 55.01385396526706, 61.61306527353103, 59.6962578835026, 59.12361145019532, 57.15465222635577, 60.4074110523347, 62.28288058311709, 65.07602391704437, 67.39378775319746, 63.69247844142299, 57.398407920714355, 48.835787542404674, 46.32219545302853, 45.676981249163234, 46.960584732794, 45.77345978829169, 49.52868992282499, 55.08676690440024, 61.47746109193372, 62.205037224677305, 55.91291219957414, 59.26461281314973, 61.4486591277584, 55.94599739197762, 51.917609476274066, 48.01720457692301, 49.71873268004387, 52.867281975284705, 64.1450297447943, 59.074377859792406, 66.56481050675916, 46.26883160683417, 48.27550049751036, 65.00503293929562, 56.49807883847145, 57.928351509955625, 57.08188441491897, 57.89325414165374, 55.02580542718211, 49.533279095926595, 53.37945722764539, 60.286958986713046, 60.69880393243606, 60.27998893491684, 57.207882711964274, 57.65512704849244, 56.50005571303829, 57.183187469359375, 56.75059710779498, 55.510092627617624, 59.891085932331706, 57.62939630016204, 53.79905669919906, 46.215354011904815, 46.922043523480816, 44.10527183163551, 46.293872018014234, 45.506522886214725, 53.55313977887554, 61.07171935419883, 60.696207323381984, 63.27029805029593, 61.61525787845735, 47.89022568733462, 48.57990780184346, 47.199021693198915, 47.96316608305901, 50.23362613493397, 48.87236756663169, 50.27204182840163, 53.3057088236655, 57.34709155174994, 64.6075007223314, 64.92243566820699, 66.71864586491739, 57.22166984311996, 68.76303226717057, 62.87468779471613, 69.73033582010578, 64.77224419193884, 68.58772585468908, 65.45572503920525, 71.88225007826283, 63.993896899684785, 84.26756535806965, 33.19256336458268, 0.33221629598448355, 0.720612270937812, 2.47773892937168, 1.1301298415468586, 0.07502438470480904, 0.1954038864782741, 20.31727344759049, 65.99951851752498, 33.22584859786495, 43.38357140941005, 40.0212097937061, 31.32899234371801, 29.13872515001605, 47.81828941837434, 56.077667436292096, 68.26755846700361, 66.69462526998213, 18.184339538697277, 0.5916654546895336, 0.1731000792595648, 0.1004480160472374, 0.10277886920037771, 0.0785240428822656, 0.012224516718678418, 0.009672975659580722, 0.03590554892716389, 0.015137553601826151, 0.03951846171290644, 0.018510365813610055, 0.10552508756518365, 0.043743126349703926, 0.02135936444955728, 0.0499099119746637, 0.06767199374735355, 0.12964007985447684, 0.3769389461846121, 0.12681948967398177, 0.2579014465933846, 0.18230727633401272, 0.1455624819162392, 0.23826584700615178, 0.1360839824642866, 0.1687807529684036, 0.21636794381324323, 0.14042422295578066, 0.22682954857666648, 0.3288802282223779, 0.18666809394715295, 0.7049319220166053, 11.908670817652057, 102.03743196302845, 78.94927855460875, 89.88612528770201, 64.27627617313017, 46.18191972855599, 20.004123180143296, 73.05005734966647, 61.93712757479761, 61.73844775845928, 60.08820072297127, 0.586357323392745, 0.25400884659780615, 0.7664006107276486, 5.404490203626695, 5.903148968373576, 6.563065196237257, 7.182429509778177, 0.42404697967633126, 68.83099909751647, 81.64858310453354, 77.77515626722767, 71.98881303110431, 66.53171354724516, 62.36644275726811, 58.836784208974535, 66.63545239356257, 69.38287658076133, 71.8121337890625, 72.00483983562839, 72.37743362303704, 71.63530549695416, 63.79805687935122, 55.382639131238385, 54.78672519806893, 51.77769460985738, 50.938727086590184, 51.90257503140358, 52.4797635693704, 53.13120257469916, 49.13553899334323, 58.00988974109773, 62.48432959279707, 62.68237398516748, 63.010280209202925, 59.3604245493489, 62.380375016120176, 67.1049601031888, 68.67714804987754, 69.07993624287268, 65.07834203781621, 60.33206232132451, 52.29862851481284, 49.13131852303782, 48.31126074637137, 49.30449901088592, 49.26505565643311, 50.252253470882295, 58.75885455839096, 66.31231184928649, 66.59420474883049, 57.29132329263995, 61.11339845964986, 63.28674847079862, 58.27859955449259, 54.41026787604056, 50.08596458742696, 51.58032486515661, 56.05359192817442, 63.9820513417644, 62.34021386792583, 69.69119056578606, 48.90033014359013, 51.56890292321482, 66.87124175410118, 59.472161108447665, 59.094240742345015, 59.54343057447865, 60.27133226394654, 58.538672308768, 53.791062908787886, 56.446993889347205, 63.24606956974153, 63.17739279039445, 61.83165111849385, 59.37381552111719, 61.889659050972234, 59.593409415214296, 59.33614507798226, 58.87149326262936, 57.925284216480875, 63.08522493608537, 60.468953040338334, 57.1303217641769, 49.63939882093861, 50.08577631365869, 46.362384057814076, 48.40442096033404, 46.26775687740695, 55.513085396059104, 63.49764254785354, 62.62363256946687, 66.48244073314052, 65.20255957880329, 52.119819425767474, 50.392631176979314, 49.84818266284082, 51.15001732303251, 54.015269510207645, 52.608236881994436, 53.24571617187993, 55.161566503586315, 60.278063051162235, 67.19136991808492, 68.29886682571905, 69.51750016981556, 59.833909542329856, 70.84617953146659, 66.03663198409542, 73.08189915072533, 67.44492761550411, 71.3612259587934, 69.87572239291283, 75.76693411796325, 65.89026481874528, 86.32410326311665, 33.755929470062256, 1.1129399316926156, 10.852728562970317, 7.5119983284704155, 1.1955957931856955, 0.3265831901902153, 0.19227277787943042, 25.81792496865796, 70.59915650275447, 45.236875626348684, 71.35372638702393, 49.546132702981275, 41.30100465589955, 32.62537883174035, 56.84888385957288, 65.72772964354485, 75.77183708067864, 77.71458702702677, 21.52059581971938, 0.6755303255011958, 0.2693173517623256, 0.1966128804750981, 0.23783775707406385, 0.17931542719804472, 0.11396668701162262, 0.17955188789675314, 0.14500352884492568, 0.08545123205910768, 0.18873810948383427, 0.13848019823912652, 0.21412056360033252, 0.18947396757862262, 0.07415295203006075, 0.1615197563003148, 0.1482524770882822], [0.07355386361239419, 0.030439264524067124, 0.03322222255050175, 0.014751749807938695, 0.09021034644496057, 0.056042307912702524, 0.012878206137928271, 0.03846818198179526, 0.05274736375037221, 0.047453064171056596, 0.0570768368760905, 0.06320975375391784, 0.04682192646507775, 0.047224632073794647, 0.09443544392143527, 32.23591296903549, 71.50775001895043, 59.837780921689934, 64.60852053857619, 36.24257095398442, 17.84326199562319, 23.580140221503473, 45.32730587067143, 29.955703866097238, 74.38937417922482, 23.02902171688695, 0.23396956463975294, 0.2229074541960032, 0.7615473517967809, 1.1811403882118965, 2.1904201661386797, 2.340242449314364, 0.9498453284463576, 8.510545030716928, 75.90630377492597, 71.1652486555038, 75.63018460427561, 67.86104402234479, 65.67637012850854, 60.17448109965171, 55.31715908358174, 52.91347572880407, 56.880984537063114, 61.090782073236284, 64.59896956720661, 63.99648958636869, 58.91081110123665, 56.394669471248505, 51.56600036928731, 49.93307059811008, 49.6183317707431, 46.10997953722554, 46.52420143927298, 46.62250388053156, 44.82300673761676, 44.73256080381332, 47.21619775218349, 49.80263217802971, 52.00832997598956, 52.77490623535649, 52.075998706202355, 53.20125218360655, 58.13650777263027, 61.13543041290776, 62.138894296461544, 59.4127764240388, 54.767423214450965, 46.27728039218534, 43.218376867232784, 46.338316394436745, 44.983572882990686, 44.55663073447443, 46.78978904601067, 53.76023307923348, 57.45543918301983, 57.5697252827306, 50.798647480626265, 58.40292299947431, 58.10062985266409, 51.97672743951121, 44.92154059871551, 43.84310845405825, 48.49321165392476, 54.87093848566855, 61.21916124897619, 56.7269765946173, 63.60998707432901, 43.24082851409913, 41.08953791279947, 64.71981779221566, 49.88835557814568, 53.96587902499784, 52.517779181080485, 59.27441873858052, 54.64653576574018, 51.46491304520638, 46.41285319482127, 56.42828026125508, 56.18290070564517, 58.14808268700877, 55.54946537940733, 56.79157803135534, 56.98100497645717, 55.854241386536636, 57.081068561923125, 56.2379119473119, 56.698319758138354, 55.133929483352176, 52.51796745484876, 47.47350131311725, 44.06862120474539, 43.672759917474565, 42.120372095415675, 45.024859751424486, 45.240762695189446, 55.50430320924329, 59.27789395855319, 60.56981286694927, 55.41881515133766, 46.207277851720015, 47.356340116070164, 44.345003174197295, 43.4371352964832, 48.61890400609663, 45.495375510185, 48.54601852355465, 52.89256557341545, 61.6652092626018, 60.457821353789306, 63.11732169120543, 57.225902080535896, 62.019356143090036, 64.4446203785558, 63.256326567742136, 62.25660070296257, 63.78821957495905, 59.11489594367243, 61.144706818365286, 61.29380003098519, 67.13316194472775, 61.79219599693053, 78.93629550933838, 13.064017699610803, 1.090177191841987, 6.537239330430185, 1.7475462080009523, 0.23039449276703022, 0.12286167261340927, 2.2385591701153786, 55.12127983954645, 46.49228903555101, 27.213659209589807, 49.132126531293316, 50.595688358429946, 17.316136629350726, 33.61554784159507, 48.92168744917839, 52.01366439942391, 61.101384239812056, 32.35782611754633, 0.9466061248413978, 0.0574932171542558, 0.08127736288212961, 0.032348269446482586, 0.06503101288070602, 0.01887283456932393, 0.004348505143782184, 0.08930764206114317, 0.041813783708118626, 0.06232574191545287, 0.08888768032193185, 0.08133137208079139, 0.06508381932132667, 0.051410850588112116, 0.03089845379544122, 0.06876775228808965, 0.03708135216466842, 0.03509698142748206, 0.010198682430200279, 0.02116672589533752, 0.04909424283992379, 0.03167217961632677, 0.029228627268645554, 0.043246732018287146, 0.02911739321725984, 0.08167199009368498, 0.03911874384709424, 0.0379903499607838, 0.062150560589807655, 0.10503885922052207, 0.06493025699690466, 41.981406442580685, 82.3406853214387, 68.12752200711158, 72.66026004668205, 44.49933275099724, 26.543449701801425, 29.57426513395002, 44.76366519927979, 34.57893294672812, 82.41151548201039, 25.9539351155681, 0.5221273473674252, 0.05434294869642585, 2.4338360851810825, 4.599100620515885, 3.314304981500872, 1.960318855220272, 0.8818074051410922, 10.647094384316476, 77.69806600386097, 74.45369320531046, 78.2787964420934, 69.08744365938249, 69.87969183152723, 63.338727720322154, 58.46129571237872, 53.378508014063684, 60.61852085974909, 62.969832727986, 66.30106249163228, 64.88290994398056, 61.92634105682374, 60.82683009486045, 53.31832708850984, 50.24920971162858, 51.48241858328543, 48.08297880234257, 49.78839005193403, 49.453352958925315, 47.570560363031205, 48.29676758858466, 49.97722471913984, 52.46010465006675, 53.15369344526722, 54.79833149140882, 54.94793068978095, 55.377622419788, 60.02972995081256, 61.25426646201842, 64.00923336705854, 61.629401945298724, 56.500428338204664, 48.23165624372421, 44.523682825026974, 46.95928642826696, 46.848200982616795, 47.54726148420765, 50.137582978894635, 56.00705300607989, 61.99039336173766, 58.65548441486975, 54.29013352240286, 59.939813536982385, 62.15252845518051, 54.7554599854254, 46.30409371468329, 46.824129396869296, 50.774313096077215, 58.00293930115239, 62.18020862148654, 58.557346713158395, 66.05663607197424, 45.7741383583315, 43.32780707267023, 66.45423104686122, 54.324164006017874, 56.09067793815367, 55.0581963600651, 61.02314472198487, 56.399756785362, 53.534481063965835, 48.64143410036641, 57.2151469415234, 60.35828336592644, 62.178168988996944, 59.567929698574936, 58.676084703014745, 57.07030950054046, 59.112872000663515, 60.65713267172537, 57.907421742716146, 58.44851270798714, 58.2737946510315, 55.781775597603094, 50.12652973974905, 45.81905341917469, 46.44747203396213, 44.387078439035726, 46.578765530740064, 47.98985388971145, 58.191550393258375, 61.61687781733852, 61.13502248640984, 56.651820059745546, 50.09052238156719, 47.793445125702895, 45.877069196393414, 45.262367110098566, 50.85832634279805, 47.93505053366385, 50.93060385796332, 56.08006400446738, 64.493359750317, 61.673795330908995, 65.69230671851867, 60.36227633876186, 64.22896062174152, 64.87637527527349, 66.33981550893476, 63.2515569656126, 64.64493190088581, 60.27773357206776, 63.534552051175034, 63.27067459783247, 69.40219817623016, 63.5366818981786, 82.43156663833126, 17.265773396338187, 0.7059943327499975, 1.3520322956385151, 1.4004466009716834, 0.6254278075310492, 0.18178106586058296, 1.7458550535863446, 58.24989172720141, 53.828788265105224, 30.661295114024995, 42.62466338373, 43.25470585976878, 24.931787021698494, 39.50185660393008, 56.4417379133163, 58.761015784355905, 69.21691325403029, 41.631221155966486, 1.2933429739167615, 0.007209237852704622, 0.07121452986593209, 0.02333018117614331, 0.07129862333738035, 0.05351077802779694, 0.051981452026314316, 0.1333112344746628, 0.05730954374396994, 0.07483531420509662, 0.05392343511865024, 0.06002912523164865, 0.05913533045039062, 0.02037048283513756, 0.038249663062273495, 0.10003336329734135, 0.17890986025093064, 0.0974082940768811, 0.12406734944952112, 0.16482698851295058, 0.2681772290698944, 0.17654194376401364, 0.12005028314888479, 0.20333753898739818, 0.1464351326707871, 0.20580703873307477, 0.11499299968202269, 0.17214564095822074, 0.12888549857081907, 0.21869087561724648, 0.18340144907274555, 48.73886969781692, 93.6385077814902, 80.44643940464144, 82.8228073735391, 49.88245241103634, 26.254520070168283, 35.758864264334406, 64.82406654665547, 43.6076799515755, 92.68838420990976, 28.295807799985333, 0.5301924145990803, 0.2902406838632399, 2.2337510797285267, 8.184798561757612, 7.486071951927678, 10.574077502373727, 2.915082713288646, 15.08661533555677, 81.8096120895878, 74.78412935810705, 81.6771536488687, 73.54764138498615, 71.52944072600334, 67.60245784636467, 61.23993412140877, 56.53038740158082, 62.80208864519673, 66.03581613109958, 70.02889879288213, 66.95176016899848, 63.55022976475378, 61.98659650741085, 56.50135401756533, 54.747477962124734, 52.588432834994414, 51.270343872808645, 50.7945054577243, 52.391255286432084, 49.99117658984277, 50.03891575721003, 52.73477646612352, 55.87368065311063, 55.98107907079882, 57.65888467911751, 57.55764830497004, 57.32396525721396, 61.95405652446132, 64.43999590412264, 68.68257661019602, 64.26164181001725, 59.370328534033995, 50.67419459742885, 46.29349939284786, 51.14612633182157, 49.92348824777911, 51.336306371996486, 51.750473360861506, 58.6832744075406, 63.74452437123945, 61.805135896128995, 55.23145529531664, 63.05378713915425, 65.5214443514424, 57.790625326095096, 49.855411591068396, 49.04914879029798, 53.32607769197034, 61.440939903259284, 65.55202707167595, 61.04973839175317, 68.65478269515499, 49.067717290693714, 46.0284609179343, 68.76347941737022, 56.41197496844877, 58.889610690455285, 58.562441872012236, 64.86637323133408, 59.78252649307252, 54.854672416563965, 51.73210097897438, 60.974876034644346, 61.58100381974251, 63.36369360646894, 61.97705338078161, 63.468103178085826, 61.86909406415878, 62.63723927159464, 64.53066541302589, 60.030114343089444, 61.66738225567726, 60.41009003116239, 58.25426124757337, 52.69561159995295, 48.970226780060806, 49.68469827405868, 47.64665826674431, 50.459393839682306, 50.804993875565074, 61.46220307196341, 64.04058487184587, 65.0526858145191, 60.5968419198067, 51.98333271088139, 51.8747026689591, 48.4233424740453, 48.115958090751406, 54.61137171714537, 51.08015991026356, 53.55222586662539, 58.344495373387495, 67.68941679308492, 66.81965474159487, 68.39371758122599, 61.01066374009656, 65.12091544366652, 69.6028587895055, 69.56998148272115, 66.09101172416442, 69.08646306683941, 63.63603945701354, 66.42692350572156, 68.68835818383002, 72.00903677171277, 65.59326687166768, 87.40056637794741, 18.03861564205539, 2.9774160394745492, 20.07646933678658, 3.8421177431460354, 0.5924727275006233, 0.2659202727579302, 3.4390929821998846, 66.84336154691636, 63.00296106646138, 40.633417252571356, 58.956483179523104, 59.10154811797604, 28.140529009603686, 46.85177818421395, 65.90792332926105, 67.73201373315626, 76.1884790851224, 46.51057904766452, 1.7301714564523392, 0.11727239470928909, 0.17367991588769421, 0.18981814023948487, 0.16398259108105015, 0.08922895717044031, 0.10518750326047022, 0.2322120823326611, 0.14756906537279008, 0.21713334225839187, 0.15793258023838844, 0.16922566619130874, 0.14816528096074058, 0.18436940116507394, 0.1189743203201121, 0.15536416321992874], [0.031219471448792085, 0.0049707332472016495, 0.08229303459126143, 0.010847428667118714, 0.0657160257199599, 0.055331271066660845, 0.015684079769397938, 0.05552032241417516, 0.061278124339878566, 0.04632954260394458, 0.13723873743607154, 0.05615397288854565, 0.009778722606208778, 0.034859432883921175, 0.25192897917041857, 53.214109713031405, 72.2889135729882, 68.62501190554711, 62.662789590897106, 29.1354166307757, 27.238528997667377, 51.03568415487967, 53.37064758423836, 39.86974354713194, 72.40190921291229, 6.211376661254514, 0.05433077172886941, 0.09466112576304905, 1.0152036600535916, 2.083124955815654, 2.2413381693824648, 0.9550479234706972, 0.5212951307335209, 35.99045276641846, 78.73253622362691, 71.24319399556806, 72.41741041983329, 70.01550782111384, 70.04105814041631, 68.4546398347424, 67.35471310154085, 57.66122633411039, 51.004740576590265, 51.99748854483328, 56.30227804183961, 55.43748171098771, 57.60485010762369, 52.15267319833079, 47.79668500346523, 47.86066670571604, 46.78810634920674, 46.4535830866906, 46.10379003709363, 43.86075911983367, 44.93929324611541, 45.9370893047702, 46.54618632408881, 45.87618666310465, 49.89919700930196, 49.17105605525356, 50.532043980013945, 56.63189049690001, 58.74405545573081, 60.536484487595104, 60.95250675755163, 60.325523730247255, 56.24681572760306, 47.84541260811591, 45.32825508425313, 43.74140924023044, 43.948828097312685, 44.522713999594416, 50.93800537047848, 54.37264057897753, 57.05980931558917, 54.39917933556342, 53.73469452704153, 59.05377364927723, 59.597939752763324, 47.699386688970755, 46.98098890243038, 45.613101528536895, 52.13325746597783, 53.68686906753048, 60.25530938179263, 57.55890738579535, 65.03172074594806, 42.673528271336714, 40.89643178447601, 64.9714143045487, 51.78850466205228, 54.01410456626646, 51.20998251822687, 57.86005912288543, 50.823962457718395, 51.78176995246641, 44.42923215127761, 48.545367410106046, 54.75247506172427, 60.839401291262725, 56.153008322561945, 55.54933594119165, 53.3646777368361, 54.66808918983706, 54.075532805535104, 57.67575479322865, 56.59185486455118, 57.533243317757886, 52.8527025253542, 49.45349024188135, 45.2568365681556, 42.85642839247181, 41.55922212908345, 44.33313800442604, 43.025525692970525, 47.5297990922005, 57.048603104006865, 57.60570126195108, 51.365335833641794, 43.69102247299687, 46.093246706070445, 44.27318065397201, 46.44169046032814, 46.403549332772535, 47.0727409855012, 52.50341546150946, 57.722831080036784, 60.85947990417481, 60.628566049760394, 59.72247892810453, 62.538532826208304, 63.01305724728493, 59.642666539838245, 60.36162914768342, 61.153371334075935, 60.93455799164311, 57.738234227703465, 60.02049669142693, 58.79435593082059, 63.388094671310924, 65.12373562782042, 68.50529332314768, 62.35093370560677, 3.0779738435822153, 1.6829748019095392, 0.859321989119053, 0.35285148709531755, 0.09286233599508002, 0.056257854411078084, 21.19502732830663, 64.97860008670439, 29.920208377222863, 53.536603066229056, 56.65762516760058, 19.268145330490608, 20.93809639253924, 41.02592883571502, 55.063958321848226, 55.579495045446585, 59.66287851333619, 7.210015539200076, 0.35828164087668546, 0.09032425605842183, 0.013700879231515913, 0.014286839774990035, 0.06384571781381965, 0.03748257156281221, 0.04249528786467929, 0.030152611659779668, 0.004280613474322543, 0.013170052120732445, 0.10781672467748005, 0.06092624866493768, 0.05723362826111336, 0.03469477377591595, 0.04001693597303764, 0.04016217092172273, 0.09525005585483967, 0.01796596075197862, 0.03860931452964583, 0.02259904218296851, 0.0624108849273574, 0.0413897387202709, 0.04402137331424221, 0.168652571136913, 0.050288876518607147, 0.030878014569621415, 0.036977336576749245, 0.10480680352737827, 0.025151174087377808, 0.7660081285622813, 65.73238941930956, 79.45578205970027, 77.2110096100838, 70.7847709040488, 42.003473697170136, 34.7869989948888, 42.92001001296505, 46.71626813950078, 47.83549685632029, 79.55866582932012, 7.338090731251625, 0.47361299095134585, 0.19669149641788777, 2.23703557445157, 7.636924347569866, 6.492963615925082, 1.6736727784718237, 0.5234491248284617, 40.08884322258734, 82.54653915282219, 71.83784884791221, 75.49464318060106, 72.31649568003994, 73.61978946193572, 70.86682688805365, 69.52212072187855, 60.317718213604344, 52.9760963686051, 54.907177263690585, 58.29632866767145, 58.02964671965569, 61.65792149882163, 55.026891923719845, 51.86401421023954, 48.545316419293805, 48.65149105748823, 49.10719594647808, 48.2684676877914, 46.17276883894398, 47.75974804355253, 47.23413867335166, 49.85967912981587, 48.02245663058374, 52.486419831552816, 49.99971166733773, 53.22890489332138, 59.945893210749475, 61.286677006752264, 64.79687275425081, 63.82825520730788, 62.28497905115928, 58.55479325017622, 51.23674484991258, 46.217817260373025, 44.48269797909645, 46.94292622227823, 46.13758125612813, 53.10583268442462, 56.26475664877123, 61.53073080124394, 55.18521839572538, 55.32409775641657, 60.85016427501556, 61.1523279836101, 50.57721791728851, 49.074075452743045, 46.728058784238755, 55.97516805894914, 57.55480850896528, 63.24394364510814, 60.045992097546986, 67.79324193154612, 45.79456213981875, 44.96435719151651, 66.25058158751457, 53.52960555784164, 56.96483696660688, 52.96627475369362, 59.23897620170348, 53.99983890594975, 53.7813981886833, 45.85034608840943, 50.86205651683193, 57.207204141924464, 60.70412658875989, 58.11099667702952, 58.39179915766562, 53.5715788410556, 58.54551292234852, 58.4565378773597, 60.59775190968668, 59.54626252574306, 58.89947152906849, 56.65303991686914, 52.741593545483006, 46.77142450886388, 44.673631114344445, 43.69686680455362, 47.942918808229514, 45.996548514212336, 51.006148707482126, 60.69566211392803, 58.953129553025775, 54.197298865164484, 46.564841116628344, 48.00789287013393, 46.18005660272414, 47.40380471752536, 48.51065051171088, 48.49725953994259, 54.15685530631773, 59.56286591868247, 63.75001176711052, 63.6742707990831, 62.11839991231119, 64.74080639500772, 65.42526391244704, 61.214434792918546, 63.567641165948686, 62.90270920722716, 62.18209528153943, 59.774207145937034, 61.024635222650346, 61.44418762576196, 64.83215839632096, 70.43946896829914, 70.65448545640515, 67.97207063244235, 4.4926612223348315, 0.9794565879048841, 3.1919008012740844, 0.8981655886577022, 0.13798345150726457, 0.22117163685541, 21.10087279350527, 73.15465127268146, 33.77813400760774, 44.50027411983859, 50.811128462514574, 22.112404992503507, 26.586774241539743, 48.52819527349165, 61.49465284039898, 62.086197253196474, 68.90852082160212, 9.74363721186115, 0.33952023954160754, 0.1309055192095618, 0.010620807410187779, 0.03257654832615968, 0.02575285762788788, 0.036107313503781636, 0.0315482648945744, 0.0650268377015187, 0.03581430785538208, 0.0484218436383432, 0.04227745076341014, 0.07651857791408416, 0.09628519385812745, 0.021914940988344532, 0.08534122949406024, 0.08871328806684864, 0.18443084141660124, 0.2020607921745508, 0.1243499439630297, 0.24640415224336812, 0.17991007996662972, 0.1889200094005754, 0.16471872496749126, 0.32788719441140857, 0.08803526961034344, 0.1941053980901357, 0.1166323205876735, 0.1964799029332015, 0.17547392526701575, 1.3735792233097939, 77.6500326587308, 89.24564146226453, 88.15027252320321, 78.30753957071613, 41.739564864866196, 39.614899312296224, 68.56427008105864, 69.2822442516204, 55.958054757887325, 88.46760795962426, 8.39286215843693, 0.42039942056421314, 0.3937182022679237, 5.140571565397325, 4.9502365916006035, 7.825172620434915, 7.517396980716337, 0.8101293997418496, 47.01219527952133, 79.70762175898399, 76.06348099247103, 75.1675331977106, 73.72225746031731, 75.19110664244621, 73.59375276873189, 70.6328731967557, 64.84628285131147, 55.00345576194025, 58.029882061866026, 60.633649441503714, 61.667821561136556, 63.09673317017094, 58.49575373434252, 54.1781694658341, 51.929878650173066, 49.81024549853418, 51.95762157440186, 52.10881325506395, 48.6705655436362, 49.39339168610112, 49.90439807215045, 51.67374395555066, 50.564866373615885, 54.95161379537275, 53.11554839534145, 55.420325263854004, 63.695788921848425, 63.04243579987557, 68.7974863667642, 65.97174813670497, 64.64735592565229, 61.29960906121039, 55.37658299169233, 50.05513475787256, 47.36734628677369, 49.96772473858249, 49.48460248208816, 55.65751491054412, 60.834604232541984, 63.051590611857755, 57.1975786455216, 55.51553295504663, 65.23322859118062, 65.41860372789445, 52.331368538641165, 53.53606177914528, 51.490628104056086, 58.294716573530636, 60.174253602181714, 65.91009632233651, 61.66486409402663, 68.89680077952724, 49.982551297833844, 47.4184351582681, 69.49149485557311, 57.54737169511857, 58.95767165768532, 57.36891561938871, 62.55817213366109, 53.591692755299235, 57.333747648423724, 49.52034704146847, 54.64135431474256, 59.115617659784135, 65.38218452084449, 60.46940803527833, 61.130405856717026, 56.77706526171777, 61.2784125727992, 60.2501985334581, 62.56004310423329, 63.52642097780782, 61.09321394274312, 58.881428626275834, 55.60446877633372, 50.07493880487258, 46.10058153829267, 45.38532557026033, 51.41765632937032, 48.44635894221645, 53.47699872909054, 64.4671622399361, 63.62871246953165, 56.17074920285133, 50.32762181374335, 51.44811745612852, 49.47332959021292, 50.22230225224649, 52.77057201631608, 52.94225415875835, 56.047661304473884, 62.23626321361911, 68.27224177698936, 65.73404858189245, 65.13442408653998, 66.48098945617676, 68.26448332878851, 64.21924098845452, 66.50925405563848, 66.7517271349507, 67.28289450368574, 62.34996880254438, 66.19278154065533, 63.48425157608525, 68.76522094972673, 72.21142322786393, 73.7547189958634, 68.52055918785834, 4.6099042988592585, 4.6728465730144135, 7.866511460273498, 0.5004941888393895, 0.5033366814736397, 0.2423043714295472, 27.9640458860705, 77.63872054315384, 46.339226384316724, 67.80696238240888, 65.08552389760172, 30.176639210793283, 32.86608880566013, 56.500087091999674, 70.93894358604186, 69.60098389656314, 77.07170271104383, 11.845281393297258, 0.5504892093520011, 0.3464122116565705, 0.11645389871010858, 0.15537516424252143, 0.12550866727026241, 0.15725742695072006, 0.13060046299811334, 0.11872014000771508, 0.19236100056479055, 0.08533841795137814, 0.2401077675242578, 0.19620683855347096, 0.16087343856211633, 0.12443002313375474, 0.23943079094732964], [0.0617197816891055, 0.03319293883959613, 0.01416418909831273, 0.012587052507085666, 0.06395984576233933, 0.12764817464255518, 0.09168915660871614, 0.04267489717852685, 0.03928860469210533, 0.04589718939255803, 0.03569659461537677, 0.009239761556889261, 0.06144553370353195, 0.10719954892392121, 4.482437074184418, 69.94374413644114, 65.30725940581291, 62.43524113009053, 44.710250362273186, 23.719084301302512, 23.558241628831436, 62.881096947577696, 42.317749684856786, 62.93273495089624, 54.69084285920667, 0.4076120341497083, 0.024782777726349813, 0.2221478933408376, 2.136021549663236, 9.682595326054482, 5.113827374673659, 2.902815255426592, 7.087404208798563, 77.28311061859131, 77.52041401401644, 72.96945264262538, 72.44467873727122, 68.81855733932989, 67.91982466174711, 68.95935473903533, 68.45542430877686, 68.28018849895847, 59.22259246149371, 51.96837671341435, 49.98241009250764, 50.31871018871185, 50.2876175603559, 47.951834355631185, 48.242556510433076, 45.9741674700091, 48.12293990965813, 45.905820169756495, 46.162884466109745, 43.58118041869133, 46.13838141964328, 43.77010922278128, 45.28077871568742, 45.295868073740316, 46.93936078779159, 44.10253009488506, 49.28328683299404, 54.52475793900029, 58.25509279004989, 60.3665203432883, 62.32665815661031, 60.18820155051447, 54.931209625736365, 48.17266379633258, 43.75338423636652, 42.53816335431991, 42.76409972098566, 43.65544265316379, 51.48792559100736, 56.29668081960371, 61.41961005426223, 55.58625721162366, 53.12012580133254, 58.679128462268466, 55.32749845135597, 45.02508332652431, 44.547264114502944, 45.41189962817777, 54.15881256903372, 54.60287194098196, 58.68240756373252, 54.67802455348354, 66.37917257124379, 43.98553363738522, 41.30753540223645, 64.92536567872571, 52.7969224991337, 50.2509355545044, 48.57151785204488, 54.814311227490826, 53.61401888632006, 52.64071018465104, 44.54413798547561, 44.44885969161988, 47.43621133988904, 52.08734220074069, 53.45974030033235, 49.9152865717488, 49.00134686500796, 53.4864124175041, 52.80244519633632, 55.00105134902462, 56.470065270700765, 58.92889322773103, 54.61865948092554, 53.37260484695435, 46.636918590914824, 44.667622043240456, 42.887819120960856, 44.81230651178668, 43.62748007620535, 46.779900750806256, 50.020735571461344, 52.622977149102, 46.08495089315599, 44.771011798612534, 45.563185445724, 44.66656300329393, 46.47396372210595, 46.14829324906873, 49.45582405213387, 56.90589943239766, 60.50253245138354, 61.3396329264487, 61.61310841960292, 62.211328706433704, 61.49331138980005, 62.516869575746604, 59.300620171331595, 56.820160342801, 56.73637459355017, 53.285916543776, 54.229458378207305, 53.32315160382179, 60.40164124581122, 59.85520801236553, 63.817162744460575, 63.870020604902706, 73.69975874500891, 37.59819307634908, 0.07868567211253029, 0.4124307578369495, 0.2920949537186854, 0.12600443340958128, 0.08828057096369805, 2.9983703215276045, 57.99252540834489, 48.29277461574924, 28.565957123233428, 31.89072282083573, 26.449826648158414, 16.178289401915766, 30.7123428006326, 48.97508267433413, 48.22072852042414, 53.50802075478339, 14.890636071082085, 0.013395026288626176, 0.027645483590482224, 0.029923382831076463, 0.09361903934228806, 0.012736815993013162, 0.022697995844928008, 0.051539296719936595, 0.0489877910924054, 0.028790369434582613, 0.023672231773455298, 0.009782969606139008, 0.008152481694255144, 0.07515165489166975, 0.031954814349451376, 0.04955431694285043, 0.040573383936838764, 0.01698595426616169, 0.04982984812569715, 0.04384271777986039, 0.08276646160670827, 0.04838740415570717, 0.08577470502425587, 0.013736049370509724, 0.019305419522307573, 0.025471176674229004, 0.05456566577777267, 0.03369284185370611, 0.053534905966972156, 0.18205448264075866, 7.284726394760994, 81.29488729661512, 70.4156288023918, 68.7469191705027, 51.69360683810327, 29.167568299078173, 25.449867402353597, 52.79116445972074, 45.28061397614018, 70.42443060105848, 59.23988226921328, 0.3885527471861532, 0.08184111932472837, 0.6467562469263232, 2.5917811066873613, 9.10124123096466, 6.694246415169009, 1.6487949005057736, 9.198676828415163, 83.9882141543973, 77.87606316228067, 74.34531027270903, 73.4292407189646, 70.63281043883293, 71.40142240831929, 72.30996101133286, 69.53811614744126, 70.00389760540378, 62.260358333587654, 53.38803545121224, 51.07853997138239, 53.08644833103303, 51.80118960718955, 51.557575118157175, 50.82817900565363, 48.26780872960245, 50.58596480277277, 48.7353160304408, 48.29708922293879, 46.99612532892535, 48.53045848108108, 46.98616643105784, 48.47901659627115, 47.77395486831666, 49.75615601385794, 47.81857575139692, 50.845606096329234, 58.02862298104071, 60.43633460998536, 62.6108495650753, 63.45472397342805, 61.9551783223306, 57.51281953627064, 50.928242591119584, 45.38563151513377, 43.78890129827684, 45.269839225276826, 47.824380859251946, 54.375649036899695, 57.327648362805775, 62.96632612905195, 57.102853405860166, 55.63207441760648, 61.24226008692096, 58.89391353053432, 47.50047153042209, 46.64584590542702, 46.81544526930779, 56.480545843801195, 56.543037045386534, 60.10143479993267, 56.18641122694939, 66.84473437647667, 46.75042413896131, 43.78430035806472, 66.57498513498615, 52.93551552680231, 52.163620533481726, 50.5898008808013, 57.70728672704389, 54.31109859097389, 55.05112432664441, 46.836269132552616, 46.21723282721735, 48.633118675601104, 53.83040820398639, 55.39212734468522, 52.48065002502934, 50.883990410835516, 55.13645156737297, 56.23072616515621, 55.789647794538936, 57.50371179273052, 60.10376468781502, 56.863424085801654, 57.04622222531227, 50.80088323162448, 46.073654467059725, 43.09375924448813, 46.799995053199034, 46.50083195778632, 49.018169910677024, 52.25398409751154, 56.817265633613836, 49.185345249791304, 47.746058971651145, 46.89912511456398, 45.99330863645, 49.46532403269122, 48.847123192202666, 53.31032153098814, 58.566066142051454, 62.18848090017996, 64.63607126666655, 62.785857877423695, 63.64086789469566, 63.06991200293265, 63.73905266484907, 61.860347178674516, 59.428889520706676, 59.743930370576926, 57.668098326652284, 58.03161574948219, 55.62632422293387, 62.37833538363057, 62.07012338023033, 64.92714251241377, 66.39012382876489, 75.82445175417008, 44.42141878989435, 0.04426710367683442, 0.2875283648890834, 3.1855399425952666, 0.20859178365959277, 0.12833174723651142, 2.776756161643613, 64.6813314960849, 53.28677162047356, 32.115623681775986, 35.15592536618633, 26.709936664950465, 24.77300947712314, 39.08930955394622, 55.70191614089474, 55.25420896468624, 62.723586328568004, 22.06938051408337, 0.0804369414465562, 0.06930415939179159, 0.0267453360251121, 0.04856557322425708, 0.06377514962467455, 0.03869925325195636, 0.032433569506411596, 0.03779721536463307, 0.06474585963353034, 0.01760104434534667, 0.09888881261670783, 0.022821571572773883, 0.04114787710169631, 0.02139541463205411, 0.0196858128202298, 0.15013843234027588, 0.21471582923925694, 0.13386035097702859, 0.11934124579232548, 0.16586289260416262, 0.2042903072170673, 0.12755209955597116, 0.11162526950600649, 0.12236792128533126, 0.11799778038215254, 0.20600957705849604, 0.1264308915743905, 0.16299413847586802, 0.27104846532306365, 9.040406250184583, 93.75294685363771, 76.81528952813919, 80.83941382746544, 60.18121973160775, 34.39369117060016, 34.72826934629871, 81.28452439461985, 57.67813174955307, 76.47235670397359, 67.4876892951227, 0.9147697170415233, 0.20252951541014258, 1.8436457481115096, 5.087520528224207, 17.513261225915727, 15.659083301021209, 5.66060479610197, 11.637754671035275, 85.976730315916, 81.2771660281766, 77.39964423641082, 73.01960406764861, 72.8387749579645, 72.19199180603027, 75.42412680964317, 72.18839107021209, 72.49119804751489, 64.86659288406372, 56.9746115130763, 53.433021114718535, 55.59415294278053, 53.97216658438406, 52.88110833014212, 53.51719910098661, 50.9065479616965, 53.268258033260224, 49.798505844608435, 51.58722039191954, 50.34416244876001, 51.59435910563315, 48.90090673200546, 50.03948057851484, 51.397263926844445, 52.161627969434186, 50.17974061350669, 53.295926432455744, 60.99760616979292, 63.007263906540416, 67.75033904660133, 67.01715392451133, 65.86331029092112, 59.925995026865316, 54.21069375930294, 47.42763703869235, 45.626935728134654, 47.420945475178385, 49.53047067888322, 56.814821996996486, 61.04996588922317, 64.77014572389665, 57.334994962138516, 56.85065284852059, 64.34298000028058, 61.53074649072463, 48.85647804506364, 49.15976747389763, 49.78925689574211, 61.00876923530333, 59.2568818215401, 62.58185932713171, 59.4870896493235, 68.50727804245489, 50.22460860590781, 48.08114313310193, 68.62807135428153, 56.154310549459154, 54.367608178046446, 53.63010060402655, 60.0865964735708, 57.78800126044982, 56.6121845091543, 49.114389573374105, 48.42275804088962, 52.21148913906467, 55.79238560891921, 58.83508190031975, 55.09485875406573, 54.17046593081567, 59.6464555494247, 60.0780378618548, 58.97058802266275, 61.87832340117424, 62.730842713386785, 59.69627357298329, 59.49100417475547, 52.481818891340694, 49.87077551503336, 47.147924976964156, 48.894693697652514, 48.48894411517728, 52.44185386165496, 55.8168847330155, 58.70083878117224, 51.28848875722578, 51.21866664578838, 50.27066507647115, 49.6426308539606, 53.1506222294223, 51.970298674798784, 56.01250902298958, 62.50630663287256, 65.86917815669891, 66.56477128305744, 65.89672888478925, 67.57283610682335, 67.4818528083063, 68.01516963589576, 64.54109107294391, 61.89150256495323, 62.3248185649995, 59.92373574164606, 61.67654491239979, 59.805048742601954, 66.46455472515476, 67.25859149809807, 68.54639191781321, 69.73353647416639, 77.50733683186193, 44.35486793518067, 0.13650448812592414, 7.039950884157612, 6.051004182907843, 0.2577362473933928, 0.23257200576124654, 4.369792976687032, 70.61071180528211, 63.0402353502089, 42.32667699936898, 42.939825827075595, 39.15730384088332, 26.908787104391283, 45.21918181450137, 65.17633068946101, 64.47111991143996, 71.22417050023233, 30.12667017598306, 0.30291107332994865, 0.16534351563501745, 0.11551555591605364, 0.1483055056944009, 0.2312670362692687, 0.08004204610422735, 0.251701190587013, 0.15992762641079966, 0.1301067806179485, 0.10918015433895974, 0.15714654338455972, 0.09163958305913596, 0.19827044959510529, 0.11621173065636428, 0.10574067236795541], [0.07134151660026082, 0.02698913776135493, 0.07804819502897802, 0.018080764773091482, 0.05581742663296962, 0.017860541307938196, 0.02630847630151097, 0.04020650442990084, 0.039093665958892916, 0.06950684327391848, 0.025340861287869276, 0.03189712984397287, 0.1625989443592487, 0.1603612474977009, 21.391995030064738, 74.90899409017256, 62.6709794998169, 61.1445773801496, 43.754392285500806, 30.152259718987253, 41.02910203318442, 49.51524011550411, 36.08789228623913, 80.42369750238235, 24.513058316323068, 0.011829063089774742, 0.04455256718961943, 0.48457347217106056, 0.627036837320174, 6.635215234371924, 8.062514749265487, 0.815027704642665, 49.88717886709398, 79.88842733444707, 71.75495347669049, 73.20539889797088, 70.79205082308862, 73.3606541541315, 68.11175407901888, 64.65692258650257, 68.31556827791276, 62.831427974085656, 63.263743769737985, 56.18899999126312, 49.71244904302782, 47.842851300393384, 46.473524416646654, 47.200327842466294, 48.77606945653116, 44.926023867822465, 47.22344236989176, 44.109013772779896, 46.97661938205842, 43.111904128905266, 44.66449199184295, 46.44097658895677, 45.01112753345121, 43.38938828437559, 46.789596849872225, 44.53886239759384, 45.40256830953783, 53.61190080642701, 57.21678649225543, 59.174770924352835, 61.692371676045084, 58.949764159417924, 54.30137895768689, 44.916825909768384, 43.42996128143803, 41.35810259849795, 43.80831703062981, 44.140463336821526, 51.95160465855753, 56.1492036234948, 57.48103264839419, 52.89406784119145, 55.21520491569273, 59.36166009595318, 48.60998845869496, 44.621055664554724, 45.6025738869944, 44.52001148654569, 51.94308527054326, 50.52419139492897, 56.11258829793623, 52.93591168618972, 62.95687321693667, 43.01853602932346, 42.35557310042843, 63.42902068168887, 53.51550071470199, 49.98868588478335, 44.75387104095952, 53.61181451428322, 49.30710738705051, 54.95864268272154, 47.879556840465916, 45.112897349942116, 42.10437666985297, 44.01107611194734, 45.640554197372936, 44.47688894887125, 42.36049959736486, 46.50693516577444, 52.166978082349225, 54.05335572458083, 56.419753028500466, 59.166765366831136, 55.7651839717742, 53.13143399453933, 49.16642373608005, 45.758723443554295, 42.432047551678075, 42.033118970932506, 43.36242983418126, 44.83307938421927, 45.79978673688827, 47.019349682715635, 44.840500508585286, 45.77714681625367, 42.9532560225456, 45.22289237668438, 44.332475123866914, 45.09992607178227, 52.14277705838604, 59.72985690639865, 60.28944969177247, 60.2474920980392, 61.00797299415835, 60.506548958439986, 59.4354320341541, 58.243976792981556, 53.67882036393689, 53.49408849593132, 55.69838208536948, 53.57496384651431, 52.456076375899784, 57.14777238907353, 54.09461121405325, 61.20991230010987, 59.412670520044145, 65.13742862209197, 63.91611629916776, 69.97827668343821, 10.126957701098535, 0.8350142031427353, 2.9476018586466393, 0.34687174183707087, 0.09811451222987906, 0.10342505670362905, 27.643309754710046, 61.8670230527078, 37.24440705391669, 30.135111116593887, 25.41709403837881, 15.426114124636497, 16.65009071750026, 38.76662400461013, 48.150169003394346, 55.67845252252395, 28.68846254964029, 0.3342524964001871, 0.03488832588998541, 0.07900933659965954, 0.06129642234995, 0.006772367595394533, 0.09013519321958866, 0.03769290483286304, 0.004265760944690555, 0.016541818622499704, 0.0625038267143311, 0.01537141151681182, 0.02695337869226933, 0.05288986376516762, 0.018597500654117718, 0.030825543292467634, 0.07659718619599458, 0.03440181026235223, 0.06184227531775833, 0.05677526253425787, 0.04076887808379628, 0.06677430723944018, 0.02170117564439293, 0.04259634635321075, 0.020630106202236587, 0.03418799895312517, 0.05140277985182982, 0.02827683388586006, 0.12256479056011285, 0.08299652547124894, 29.793415800217662, 84.28916977297875, 68.20599294477894, 69.6176382803148, 50.74292628995834, 39.98837171062347, 35.98600479864305, 41.840883608787294, 43.084180816527336, 84.69673541284378, 26.014973079004598, 0.18884055076106904, 0.04333505046463782, 1.7901323615543305, 2.5029948257630874, 7.278045617764996, 3.2011041525871526, 0.5095292766007685, 55.68536766113774, 82.28288527457946, 74.1720199584961, 75.3290956251083, 71.61394426899572, 76.77939199632215, 67.37493684214931, 66.16569365224531, 69.69865091385381, 69.19408505962741, 66.39428154114755, 57.98608487652194, 51.38462997251942, 50.49265161637337, 50.37298794715635, 48.81490484360726, 51.859244608110004, 48.96822637127292, 49.39693358636672, 48.65371896374611, 47.22932200278006, 44.83748812829295, 47.31359020356209, 49.22454541729343, 46.19922522575625, 44.86043791617117, 47.70481132691907, 48.503970715307425, 47.892892899051795, 56.93103005809169, 61.17835290970341, 62.6819033007468, 62.814887339069, 60.62900535521969, 56.031403080109634, 48.4189925655242, 45.33084384856686, 44.66515487240207, 44.57483445444415, 47.42902948010353, 54.19989155184839, 57.7421252189144, 58.157315946394405, 53.35748803231024, 59.31198327772079, 61.82180989173151, 53.00316072279408, 46.62912091901226, 46.43015476965135, 45.39593165920627, 54.49463805844707, 52.31897384889665, 57.97379609077208, 55.72467765500469, 64.28819233371367, 45.13392125406573, 43.285661205168694, 65.46818640924269, 54.92417289364723, 53.0345828302445, 48.243180167290475, 57.15012188880675, 51.427301437624045, 56.56171144977693, 51.00535638870732, 47.308381295973255, 43.96367034604473, 44.43340163077078, 45.62020494091896, 47.99807517759262, 44.97253141095562, 49.10577212610553, 52.43906113409227, 55.999596580382324, 57.679900738500784, 58.554240195981926, 57.92978317506852, 56.14594021151143, 51.915867943917554, 48.25205256862026, 44.18176197236584, 46.02278917066513, 46.13305091857911, 46.37435513157999, 48.808185823502086, 48.9296773172194, 47.391245288233605, 47.79271164248067, 45.49620705266153, 46.59987572700747, 47.790719078433135, 47.43971401645292, 54.75012556199105, 63.04437345074069, 63.778048869102236, 62.87602924531507, 62.679671472118756, 62.11662307862313, 62.57470884630757, 60.20424404451924, 57.29571634723295, 57.06631260533487, 57.534012102311664, 56.126159698732444, 56.41830175153671, 59.499688302316976, 58.796152376359515, 64.5660138130188, 62.40693338455693, 68.70059597876765, 65.6800610788407, 74.18923131881222, 12.659838045797041, 1.2110780011261664, 2.3435862698862633, 1.2840353120719235, 0.2836145749015193, 0.21820787250274615, 28.144998550415043, 69.01869235500213, 39.423491570257376, 30.149337553208877, 27.807617841228364, 22.242129541212513, 22.405900263017227, 43.416248675315614, 54.44390220026816, 63.65998160454535, 41.53509955252371, 0.48267464664193893, 0.04769446613687662, 0.02830876060010445, 0.057357523830667625, 0.029044530594781525, 0.044512450995464484, 0.02961857751342318, 0.06934366654604673, 0.013160442505332251, 0.021932945969784935, 0.08149624952385504, 0.06524583159555351, 0.015307053427902922, 0.05274121972521948, 0.05190965809649037, 0.16596580885591047, 0.1879736916312287, 0.16724520633297582, 0.10269905049954692, 0.31493436364877614, 0.23078144377758428, 0.1486528193157527, 0.11747694018507197, 0.10550955130207924, 0.13552985574689605, 0.15362315180320896, 0.13133039157236778, 0.25070440294521473, 0.34188251762140187, 36.68588507559992, 95.54416779548892, 78.92373608004662, 78.92286531386837, 57.50865005677747, 41.57945371443226, 57.49108960551601, 70.30195067005774, 50.15047973202121, 94.94956001158684, 28.879225061785792, 0.38956747660713814, 0.19775471920447965, 3.6861937228710424, 3.204406297975971, 23.505760315925848, 19.405143914684174, 1.4113064182381476, 62.27459653731316, 83.03927513860887, 77.64152111545687, 78.10361554545742, 75.95055595521005, 77.96606586825463, 69.60741658364573, 66.6294276329779, 72.17547862760483, 68.7374270346857, 67.85870628972208, 60.431015876031694, 54.988115372196326, 52.59313183446085, 51.66700924596479, 51.38058600887176, 55.33965779889015, 50.33317588990735, 52.50761239759384, 49.70833055434689, 50.9131650001772, 48.636625274535156, 49.52695231283865, 53.2009619282138, 48.32072934796734, 46.32914589297387, 51.48627427316482, 50.403417694953184, 50.58469787720711, 58.55542867414413, 64.02297735214233, 66.31213142025855, 66.18290501256143, 64.52498582101637, 59.68671083450318, 50.00487742885467, 48.673209221132346, 47.066382823451875, 46.97879629750406, 49.24193720663748, 57.048316770984286, 61.44769422469601, 62.022046889028246, 56.35058595288185, 61.167648761503166, 64.69570698276644, 54.20946997980918, 49.72397688896426, 47.734260482172814, 49.01534972652313, 56.126426419904156, 54.47160197842506, 61.587542410819765, 58.1381041772904, 68.80160485544513, 49.38693546479749, 47.57206655317738, 68.36164828269713, 59.86028748173868, 54.26585012866605, 50.25045702534337, 59.79095174420265, 54.527903679878484, 60.46912954699609, 52.952213056625865, 51.06725531239664, 47.08806960813461, 46.84104265705232, 49.27518321621803, 49.485163381022794, 46.85886590711532, 50.92450457234537, 56.00623323071388, 59.084434816914225, 61.19785101183, 64.388059800671, 60.40821513822002, 59.401064226704264, 55.55534893466581, 53.689426452882834, 48.171279199661754, 46.11278403189875, 49.497067774495775, 47.94226377241073, 51.06873012358143, 51.809371671369, 50.591005048444195, 51.8596407674974, 47.164489146201845, 49.17944992742231, 49.73557925993397, 48.486249446868904, 57.72190932304629, 66.84294577567809, 66.10400261417513, 64.14381381004088, 65.2173900604248, 64.47903133207753, 66.2579870223999, 63.576592014681914, 59.63917170801471, 59.81530574060256, 63.148379018229825, 59.00574422651722, 59.77408947483186, 62.8187273394677, 61.31531423138034, 67.19431169571416, 64.60759485921552, 71.49583385836694, 68.6766852101972, 77.26755449848791, 12.8319614548837, 3.191130545831496, 12.430803006695164, 1.1983461101208965, 0.31676997160238607, 0.2603169831056749, 34.72225243045438, 74.31139746019917, 50.442723766449966, 42.6801609992981, 36.51815668229134, 23.01990612860649, 27.612472080415298, 51.75509783529466, 65.04982640666347, 70.9978497412897, 52.18444047435638, 1.1649159942903828, 0.18884131684899333, 0.19285526517177784, 0.180803629599752, 0.0916950171813369, 0.15184261024959628, 0.14661850347634287, 0.1655216617209296, 0.1403684977201685, 0.14708077625161217, 0.17223559500228974, 0.1392624965838848, 0.11429055068161219, 0.14530129189933502, 0.21886989504339235], [0.09042486638551758, 0.03559574297058486, 0.015683114498613343, 0.052435791961127715, 0.05980485299181554, 0.05651077833927928, 0.01484335094104491, 0.059769325664327036, 0.06795885537060038, 0.015427195166628209, 0.07103094455575751, 0.05747077843895363, 0.013504269469018667, 0.21225291784972916, 41.79343861918296, 73.18801495336717, 63.53858817008234, 59.07945732916556, 37.50904544707268, 22.389106635124456, 36.961357055171845, 49.12474463062902, 46.66148831767421, 81.71396901530605, 8.942736291116285, 0.0795853351272883, 0.02736900054338959, 0.3192270913672063, 2.6145742449068257, 7.00048791785394, 5.013443135446118, 2.9961831098602665, 83.38780910738053, 67.56419904770391, 72.15203069871473, 61.03031089228969, 73.03075144367834, 67.72612233315745, 73.76534861903038, 63.25268268585206, 66.69926935626616, 64.32135989589077, 67.7620747781569, 61.53429623573058, 55.4947522378737, 48.36617392878379, 48.89084585251347, 45.98491476428124, 49.01156071693667, 48.56778375564083, 48.26317248805877, 46.52191861983269, 46.74197143123996, 44.386992146891934, 44.25633799645209, 46.09749855533723, 45.472421799936605, 45.3788693489567, 45.4641769778344, 44.48384331118676, 42.70997493497787, 46.34144644583426, 57.24454118359474, 56.49052827588974, 61.846740476546756, 55.79633151331256, 49.04657571546493, 42.48558005978985, 42.33681632626442, 43.40322640634353, 44.8445091709014, 45.33933577998992, 51.521595216566524, 54.10203233841927, 58.46451990066036, 55.78946344314083, 61.496617947855306, 56.11145473295643, 47.12068019374725, 44.09883914455291, 44.749701561466345, 42.05129523431101, 49.50071165638585, 46.61938951861474, 53.268183508226954, 52.71601969195951, 64.28745492812126, 47.08208407125166, 43.13949408069734, 62.50016027881254, 54.340881147692286, 52.2928116398473, 44.38167341293828, 49.681077926389634, 49.31996883884553, 50.63672419517271, 48.264235450375466, 45.627775115351525, 42.33216831761022, 44.33838221334642, 41.750743619857296, 44.357272348096295, 43.65967096820955, 44.65672177653159, 48.70190920368318, 54.026518867861846, 55.39339819262105, 53.72979548669631, 55.847290946591286, 50.93090980283676, 48.07565573723086, 43.62766834997362, 42.448321465523016, 41.85603180239278, 44.02581245668473, 45.483933956392356, 45.20391594979071, 44.54588736257246, 45.22825817908011, 44.466290704665646, 44.94200360390448, 44.476277059124364, 44.846760611380304, 45.18609662209788, 56.279496915878795, 60.02842772391535, 57.7657025860202, 62.25574954863518, 60.03083213683098, 58.576585938853604, 56.53004223300565, 51.69489337551979, 51.19844290517992, 50.11280536651612, 49.48902299327236, 53.035881134771536, 53.07666986219345, 51.87273756150277, 55.091309009059785, 55.645116298429436, 56.5663202347294, 63.25969980609033, 65.06199359893799, 69.9240852171375, 47.42708398449806, 0.3303325777092288, 2.2438597631069923, 1.1098141703874835, 0.04921102911354073, 0.0411650029972436, 5.733115692292491, 61.70571165700113, 49.491223442939024, 37.272228425548924, 36.59228555617794, 23.45001559103689, 23.582611314712032, 32.14098964968036, 49.96130774098058, 54.07270477664087, 45.02393407206382, 3.6826255917549138, 0.17250095253750203, 0.059722395118085615, 0.04058225523500193, 0.05247103200564462, 0.0550783203253823, 0.005741198406359482, 0.07462656290660943, 0.010206897765578283, 0.07495059511594235, 0.06049177339000087, 0.04554756218567491, 0.03841352926927709, 0.040599695226598176, 0.06500295874091887, 0.07126123824667546, 0.12443004611639247, 0.025829820735980908, 0.0886810127825987, 0.12410727795213462, 0.05003250902518631, 0.04921011746891084, 0.07386903218444317, 0.020657857737293648, 0.051800593989150184, 0.054197794186972806, 0.05223876180788202, 0.01234402260442655, 0.5212764381881684, 53.45852436557893, 81.92562010980423, 69.93681723071684, 66.26432557259837, 47.97088530755813, 28.193837942615634, 29.63078844931818, 46.38455721639818, 56.247710028002345, 86.50114336321431, 9.67971238397783, 0.13395876263178166, 0.16169675325434055, 0.6684099366107296, 3.428044155720742, 5.456108104798102, 2.54277820068021, 4.057468613309245, 86.64066991498395, 68.24067454184255, 74.70983966704338, 63.8246113254178, 76.24097608750867, 71.50455720963018, 75.10418691942769, 62.93677106980355, 68.42402965791764, 67.56396370549356, 69.15507316589355, 63.66424129855249, 57.778771923434356, 51.83682826257522, 50.993193118802964, 48.318164117874645, 52.75163481312414, 50.97917456780711, 50.442759067781516, 47.54997968673707, 49.14215210945376, 46.77073024934339, 47.56484154731997, 47.11188623982091, 48.413242370851584, 46.41517523796328, 46.44643652823664, 46.76439562151509, 46.70872542165941, 49.04342605221657, 60.21027272747409, 59.87451391835367, 64.41113510439473, 57.44322099993306, 53.354169707144464, 46.672114018471014, 45.310718167212706, 45.219350476418775, 46.424463410531324, 47.79918355326499, 54.561541926476266, 56.019384937901656, 60.51984187095397, 58.097095797138834, 63.03970583023564, 57.28551034004458, 51.28529202553534, 45.71492625821022, 46.8847692397333, 45.64389997912992, 49.991247192505874, 48.600331583330714, 55.3480948171308, 54.92321583532519, 64.99394047644832, 47.37319454070061, 45.11944770812989, 64.07175986997544, 56.722171691156205, 55.42884465186827, 45.269517590922696, 51.97995555016303, 51.86697952208981, 51.77119916485202, 51.62045855675974, 46.96938653146067, 44.45761834421466, 46.33836346287882, 43.70981062612226, 45.27480886828515, 46.083907542690156, 47.15246315925352, 51.15430839600102, 57.080680247276064, 58.74900548688827, 58.625580264676, 58.76999801205051, 53.145436856054495, 49.951450824737556, 46.96309112733411, 44.416190270454656, 43.896468377882435, 46.8154295798271, 47.02056953983922, 46.9360306955153, 47.21043579040035, 49.44613972017842, 46.08284850274363, 47.124288774305775, 46.53094007122902, 46.82629454520441, 47.34217251500776, 58.32257324649442, 63.02399673769551, 61.077391101468, 63.37664135040776, 61.41977087143929, 61.19351287041942, 60.69489332937426, 52.80341009939871, 53.56768784984466, 52.03312327784877, 51.75871818296371, 54.16590813667544, 55.740214163257235, 55.308451421799205, 58.02151956865865, 57.68251695940572, 60.79878514812839, 65.62584215594877, 68.16775768033921, 70.59241002605808, 54.33020053371307, 0.49530526082361903, 0.6670309170599907, 3.617527975190071, 0.7502977489944428, 0.020662595991105325, 4.614008568948315, 66.96369201906266, 55.82094830851401, 39.21289559333555, 36.50313400453137, 23.348930228141047, 28.865135908126835, 36.05942764589864, 55.41278646838281, 61.20050253406648, 58.27960760362687, 7.017377153519662, 0.3628773410474101, 0.1009229752385328, 0.032125784106732856, 0.05568515772240297, 0.05841799636161136, 0.02539517117604133, 0.021914146172123092, 0.01283690633793031, 0.11258184519265929, 0.0718858603748583, 0.05264859203429473, 0.023899863308836377, 0.07240628688445977, 0.06715505293780757, 0.2140970753445741, 0.2910463325679302, 0.1728000792284166, 0.27895096869718644, 0.1801349727376815, 0.17738194385122869, 0.16845208592712882, 0.16774305623144875, 0.15648122666583908, 0.11725930992754237, 0.14006869687188056, 0.2135683214592357, 0.1927886461658824, 1.1097737209450815, 68.97633075714111, 90.92392167737408, 79.35798168182373, 75.07596938840805, 52.32397879323652, 29.79226850694226, 53.08725241691836, 69.51967316289102, 60.38026825074227, 95.40233489005797, 11.395873869619063, 0.20957039969582714, 0.49440277860529963, 2.8600660783629266, 6.48860929473754, 17.931642801530902, 9.105883356063597, 5.0006660146097985, 92.11952286381876, 70.25974596700361, 81.21108978025376, 63.32330103843444, 79.11290414871709, 73.25580919942549, 77.51860972373717, 64.13330578034925, 69.48483467102051, 69.01549954568186, 73.5864963839131, 66.96132290747859, 60.13331190232308, 53.43952048209406, 54.26079811588411, 50.22058033174085, 54.20570058207358, 54.95065673705071, 54.83176969712781, 50.36067562718546, 51.123404041413345, 48.84253794147123, 50.23172770777057, 51.82843439040646, 50.5729543009112, 49.64167379563855, 50.3048602996334, 48.42036931745468, 49.909861933800485, 50.253018333065896, 63.22488092607068, 62.5550538493741, 68.74539729087584, 60.63538705149005, 56.50744545844294, 47.740410758603005, 46.85783040138983, 49.183329151522734, 48.21104418846869, 49.76893117350917, 56.33102509283251, 58.952772617340095, 63.16722992927798, 60.310579499890736, 65.70642332876882, 60.578877464417495, 52.611661111154866, 49.598919960760306, 48.380121877116544, 46.917536720152825, 52.14232206344605, 51.621737249435924, 58.98583035315237, 57.87453659119145, 68.94149226527061, 51.14898966204736, 48.96462955782491, 65.77645332582536, 60.198678201244725, 58.21810091695478, 50.128722344675374, 55.09325842703543, 56.10022498715309, 55.86729111209993, 55.60025222839848, 50.12835756424935, 47.34855813364829, 50.342142428121264, 46.77135390620078, 48.21780243227559, 49.657786892306426, 49.24864053726197, 53.9870245225968, 60.415396998005534, 61.23307781834757, 59.702592511330884, 61.888301910892615, 56.37932515913441, 53.12662909107824, 49.71209995208248, 47.428703923379224, 46.55206987934728, 50.13113852470152, 50.050290630709746, 50.36102079576062, 48.674389854554214, 53.13605454660232, 47.966806042578916, 50.69424183137956, 49.13206769574074, 50.27943157380628, 50.49267122822423, 61.238039616615545, 65.364941781567, 62.00989538623441, 68.24563241774037, 66.38828815952425, 63.90461590982253, 63.743465331292924, 55.191462809039706, 56.90504827807027, 54.782288997404045, 55.84524739173151, 57.47700437422722, 59.31421510634884, 57.59487944264566, 60.876236269550944, 61.92951425429314, 62.10330270951795, 70.39990794274115, 72.56942579823156, 72.73287880805232, 56.45448561637633, 0.5201602174389748, 8.580446570150315, 3.9254357497538295, 0.4495720487208136, 0.272868720874671, 7.734604112563595, 72.6142349550801, 64.37484925793063, 54.08405611591955, 47.507359212444676, 33.00661556182369, 35.25491422222507, 44.671866047766905, 67.01487110507104, 67.76814660718365, 66.71042457703622, 8.114816613735693, 0.6538215387732752, 0.26955447129664883, 0.10870071353330728, 0.12647832007778267, 0.12914210738193604, 0.1776688744223887, 0.16628952696919444, 0.11751132987199292, 0.22184800056199874, 0.17479348597266983, 0.11827551789822117, 0.13068298598931682, 0.1899008470917902, 0.19675716547475708], [0.0608244355798008, 0.035852769299620585, 0.12238269146051138, 0.04142683269756456, 0.02470438011861857, 0.028496003980117462, 0.10313909906413286, 0.031128812603832736, 0.05260755653463064, 0.023182128939116677, 0.019921235469800812, 0.07884800614368531, 0.12041204518848851, 4.039754699314795, 58.651742473725356, 63.505581425082305, 66.94775935142272, 43.62081204691241, 17.667951660771525, 35.31852722167969, 58.07649158662366, 37.56575507502402, 61.336518564531886, 60.57170344937233, 0.6467284838999472, 0.09884951230619224, 0.1606850115762603, 0.3279777460040585, 5.039620053383612, 25.730934642976333, 0.9311688402968069, 23.957695807180098, 86.85767112239715, 63.776640738210375, 66.56426921967538, 53.733478592288115, 65.64247692784956, 63.279197908216915, 70.84141777407739, 67.22365886934342, 65.47874935211675, 62.91662185422836, 67.18502352314611, 62.9725391634049, 62.728540282095636, 52.50923625884518, 53.4314247100584, 46.39895231493058, 47.068022374183904, 45.66877565076275, 49.55401666702763, 44.94019146888487, 47.33229598691387, 41.905759611437404, 46.0449387950282, 43.10162359668363, 47.382667064666755, 41.446308858932994, 44.057862143362726, 46.18231196557322, 46.79386831098988, 42.08631415520945, 50.155857301527455, 56.33009941347184, 58.50069199838946, 52.039756005810155, 48.29970152147355, 42.32513943026143, 43.79463972583894, 42.05345646027596, 44.78529707078011, 41.75050043290661, 50.50132397682437, 52.658353005686116, 59.33434471007317, 58.1840665109696, 59.759639463117054, 48.49932270665323, 43.82763862609864, 41.324205475468794, 44.64736300130045, 46.35223296380813, 53.1787456235578, 51.40524595014511, 55.322069891037486, 51.7469040040047, 63.68900714382049, 44.93180936382663, 39.342949621139034, 63.96343577292658, 52.62179259330996, 52.22838670976701, 40.7131080473623, 44.77750332124772, 45.515085420300885, 46.6753891975649, 44.171073513646284, 44.30404578485797, 43.984396150035245, 44.50243534580354, 42.36013089456866, 43.6641267807253, 43.271195503973196, 43.675415362081225, 45.388557603282315, 48.12153570113644, 51.50609008727535, 53.933088010357274, 51.39018797105359, 48.67966152006581, 45.555964362236764, 42.95128307034893, 41.68648735169442, 43.128766398276056, 45.532249712174945, 43.38747809010167, 44.62162833059988, 43.73985990401238, 43.90459945124965, 44.036740179984804, 44.49282946125154, 43.91334241436374, 46.72929433084304, 42.55562574632707, 54.894162839458836, 60.96412089563186, 58.796222979022616, 58.99794655461466, 55.96564062180058, 55.02237335328133, 49.62001838991719, 48.077663990759085, 48.54169607162476, 46.916199191924065, 49.86773567814981, 49.41471369035783, 52.31569474743259, 51.297055213682114, 53.520560572224284, 53.88501544152537, 57.2707857624177, 59.875455287195024, 63.99163369209536, 66.57382411341514, 68.9236141020252, 13.809089564508009, 0.4670122548216774, 2.7001765418437222, 0.7501669011769757, 0.1533589587216416, 0.07905660422458764, 35.906698396128995, 61.97877137891708, 37.50276965479697, 45.26927832634219, 49.868194595459975, 19.122329258149673, 20.255802062249955, 46.910260723483184, 49.86091075404998, 55.507805885807166, 17.63422712202995, 0.2978015733101676, 0.012207268249063243, 0.03124141029172367, 0.08071619581671492, 0.1170455867184266, 0.052130597853852864, 0.0035456263257430927, 0.06956036983718795, 0.03171309637236259, 0.05437384502241208, 0.05019876542651365, 0.0754117647246007, 0.05519358208402992, 0.02986538805998862, 0.014682574941205883, 0.022233313723136822, 0.009945995989255607, 0.07613632302250593, 0.05864561640567357, 0.05564443631878784, 0.10504288118212454, 0.07985372637068072, 0.026860480955351266, 0.024392603400854335, 0.09655330930986712, 0.03368033163790261, 0.12343832231577366, 7.353433082180639, 72.62056566053822, 69.36375894854146, 74.9348032859064, 50.59553930836339, 28.665979523812574, 27.240158742473973, 37.51389349660566, 45.40915396905715, 68.62566301899572, 62.50527112714706, 0.915094844756588, 0.0391667201033523, 0.6786046669848504, 2.1572602035537845, 5.475967064980538, 34.787089209402765, 0.4931953627495997, 26.758042573928837, 88.55686541526549, 67.00351976579236, 69.9166327138101, 57.76607913355674, 68.41371382436445, 65.98256603364023, 71.25848339449975, 69.30023224123063, 67.32987665360974, 65.62840738604146, 69.15632047960835, 65.30328604482835, 64.84601613013976, 55.3094437814528, 56.15586773041756, 48.15153398821431, 47.88744864925262, 48.46855171265141, 49.62890255835749, 47.138013147538715, 48.20683156290362, 45.69547130215553, 48.332476846633426, 46.381172210939475, 48.278034348641675, 45.12780627896709, 47.74800054488644, 47.85790535711473, 48.22901648859824, 44.37512697712068, 50.72309478636711, 58.33648589349563, 60.36027592997397, 53.481070149329405, 50.84518640272079, 43.80038599814139, 46.15575751950664, 45.58149899205854, 47.51758875385408, 45.251545290793146, 52.344277058878255, 55.04689208922848, 60.646448135375984, 58.043375015258796, 61.20187144125662, 52.21128517581571, 45.98686025988671, 44.480587743943744, 48.40624878483434, 47.28589434777537, 55.78531357549853, 54.06372254894626, 57.30163520382297, 54.82906718407908, 64.40813841358309, 45.98591496867519, 40.687455746435354, 64.74047299354308, 54.617525915945734, 54.333059941568685, 42.42911754115936, 48.20602355464813, 48.38885699549029, 48.45224249747492, 45.70743453118109, 46.75657833776167, 47.75393116858698, 45.953920195179606, 44.08920188103953, 45.056007292962846, 45.95495177853493, 45.93009179638278, 48.44195019814276, 50.77792167663575, 53.662381710544715, 56.26071660749374, 53.499611193133944, 52.07680279208768, 48.67239729050667, 45.18562986004738, 43.28597107241231, 44.56990011276738, 45.79166743063158, 45.95813674311484, 46.924240050777314, 45.89482968853366, 47.22840809052991, 46.48528760479343, 45.90929146735899, 46.034787701022246, 48.01828322872039, 46.53716095032231, 56.6233201180735, 62.513327675481, 60.31831049150037, 62.1960275403915, 59.12065006071522, 58.02624210234612, 52.05805386266401, 49.95472992620161, 50.75312837477654, 49.08519929455173, 52.126377628695586, 52.65406977745795, 54.90368635423722, 55.04110659322431, 55.21223960384246, 56.27555493385562, 59.950133292905754, 61.665966280045055, 65.41714068382018, 69.39027417090632, 72.78131223494007, 16.39587994544737, 0.33945260929965204, 2.9922918735011934, 1.845013552135037, 0.14591402434293302, 0.09264914904751125, 35.71357265595467, 69.00061022850775, 41.620705281534505, 38.67771563991424, 39.84604850892098, 24.391941408957205, 26.172952421249885, 53.370980985703014, 55.81371153554609, 65.03645504674604, 25.843453714924475, 0.15524569538331803, 0.04188407227517136, 0.08023772028184707, 0.09509916717727339, 0.13504106100768815, 0.025006052136661547, 0.13394253688954538, 0.045311013386855205, 0.003289960520980399, 0.05865785466026395, 0.05396362409115799, 0.14194449379799828, 0.01907616388052702, 0.05158035137179879, 0.07415608532967106, 0.18400820603053417, 0.18063083080755127, 0.1584938468952333, 0.1494833811997406, 0.160280762300376, 0.17767449750775294, 0.22925630061616822, 0.11339202913786135, 0.08523933980013094, 0.23897306873433052, 0.16009412796026276, 0.35211757486385686, 11.630723822501398, 84.64247334387996, 77.42894434159803, 83.73034184978854, 57.90740997560563, 29.2593615670358, 47.298073307160415, 81.46351783506333, 51.54698864106209, 76.28818573490267, 69.94237130688083, 1.5285934988529453, 0.1155698485672474, 1.304254640013941, 3.5477168954187825, 15.75357908202756, 42.672724185451386, 3.171927356912244, 30.00709083772475, 90.24171952278384, 69.99711190500568, 71.8812616409794, 58.39181876951649, 71.02311764993976, 68.53766856654998, 74.17424002001363, 71.80447732248615, 68.2866447202621, 67.21280174870645, 71.34856454787716, 68.35309751572149, 68.73397534893405, 56.55601616828673, 58.56694083059988, 50.791140064116455, 51.90494806535783, 52.55104088014173, 54.03989415014944, 49.500135067970525, 51.91378908772623, 46.988257054359686, 50.80584502989247, 49.14327782969321, 51.416467851208104, 46.96932769590809, 48.889786812566946, 52.022101417664565, 52.19716464319537, 46.798783040815785, 52.56838952341388, 62.14043186556909, 62.86051627128356, 56.07597689474783, 54.165492365437174, 45.469782044810636, 49.40258572178502, 47.563445183538626, 49.57673503506569, 45.14430769028203, 55.406577356400035, 58.52560297135384, 62.829553081143295, 61.916150739116055, 63.432182112047755, 53.4201047497411, 47.96259341701385, 45.88504729732391, 50.98150837805964, 50.72087472484958, 58.30991575794836, 57.421212580896196, 59.86182505084623, 56.92935520602811, 68.4968053140948, 50.879852310303725, 45.20217833980438, 67.05618150772588, 58.15798274932369, 56.65626802752095, 44.41953997458182, 49.54077866769607, 51.60855808565694, 51.23952973273493, 48.80261213548722, 49.4345961847613, 50.27337543426022, 48.783110110990464, 47.65432257806101, 47.98559027333414, 49.560002203910585, 48.09209831299321, 52.02464311353622, 52.68650385641283, 57.486445519231985, 60.923422382723906, 57.128529241008145, 54.952068790312744, 52.71921250127977, 48.9349332932503, 45.57678822548159, 47.66867845289169, 48.91828675423899, 48.942166143848056, 48.65856701327909, 47.517467160378736, 49.428712629502826, 47.618982022808446, 48.01523946946668, 47.33064074670115, 52.20673522641582, 49.208342106111594, 59.1678753975899, 65.24650581421392, 64.4525553334144, 65.89025697400494, 62.47063267615534, 61.65875696366834, 55.125394405857215, 53.831839869099284, 55.35549632964596, 52.71353683164043, 56.767757477298865, 55.92321626601681, 59.621077814409816, 57.95864789716659, 59.08706672729985, 58.252821737720126, 62.96251358524446, 64.9133671483686, 69.98974569382207, 72.7510315372098, 76.12456014079433, 16.984321763438565, 1.016496939043845, 11.752567348941682, 1.6258707306077405, 0.3392661741423992, 0.25123813640206094, 43.45575871006135, 74.97233252371512, 53.11753703701881, 58.78675045505647, 61.78257834526801, 28.142751032306304, 30.705384515946914, 65.35112719382009, 63.48405937994681, 74.0027226171186, 29.77607696287094, 0.5072485102761177, 0.13185585127963176, 0.2416348871925185, 0.23574854337400009, 0.2205253804042455, 0.11843702455441799, 0.35269943396410636, 0.18882159774582233, 0.13079924749270563, 0.19174731817216645, 0.18333938062912036, 0.2907002446872573, 0.17349257674669066, 0.12552939760949344], [0.0627564633595607, 0.0762779037317922, 0.050077918886898026, 0.014216767627775911, 0.04765603533615509, 0.04000033101727886, 0.03614529231262784, 0.04856589498118528, 0.025413591760180654, 0.06078662147985832, 0.03550733259368328, 0.05805169908149589, 0.14966773259783947, 27.114380098158314, 77.63967760147588, 64.20882317327684, 61.752234889614975, 29.274394050721202, 27.711874746507217, 56.75826534148186, 40.25332781576341, 38.67387956188571, 79.78420995896863, 31.823671863925075, 0.0654327647099572, 0.21128708016007178, 0.5185311467897508, 2.5880575516531548, 1.9363819783733738, 1.4694197644149105, 0.08738827771477162, 52.800001559718964, 78.23203394489904, 64.58285254816856, 66.82157670297931, 50.637959741776996, 54.32092412825554, 60.75629803442187, 67.47412573906684, 66.75769698235297, 67.25610471540882, 61.877138845382206, 66.30310212412189, 63.695698707334465, 61.22164018692509, 59.31977310488301, 57.67738649922033, 52.847281809776064, 52.796718535884736, 45.42887564628355, 46.52382881410661, 45.644978630927305, 46.669525254157286, 45.54098090817852, 45.40523944362518, 47.75466857417938, 45.69513397832071, 43.63527382573774, 46.23836655770579, 43.077638303079915, 45.198369718367054, 44.92482362254974, 42.78892440180625, 46.78577646132439, 49.71896409988404, 46.22650923267488, 45.416065185300766, 42.97634701575003, 42.927097735866425, 42.78482160260601, 45.63702798658802, 44.37504852971723, 50.3293711908402, 52.88532880044753, 56.42239670599661, 55.318225968268614, 51.666664077389626, 41.39761263324369, 43.958222173875384, 42.6138533315351, 47.723760297221524, 49.14141078149119, 57.15269496363979, 52.018877229382916, 60.55828109864266, 52.5873149594953, 65.75428408961143, 38.02768476547734, 34.25883223933558, 65.05057165699621, 51.72320896579374, 53.01552795594739, 42.403320112536036, 45.244704677212624, 41.5655489121714, 44.28772872494113, 41.43713051272977, 42.955083847045906, 42.23869039166359, 42.74756300833918, 41.42271580234651, 43.46043417530675, 42.72973191353583, 44.24339809725362, 42.334600187117054, 43.16997874167658, 44.09731334255588, 45.04389501387074, 42.30539814118416, 43.44622735054263, 42.51581761144823, 42.45888440839706, 43.36468127466018, 43.528181352923, 42.93621332414689, 44.13270096625052, 45.01402616500855, 46.43602655779931, 42.81210953189481, 45.588068962097175, 44.66835944883285, 46.82090128621748, 45.56597817328669, 44.620059382530954, 47.06981489735265, 54.34886317099295, 57.591278706827474, 55.820054008114724, 51.89986859598468, 46.5380121046497, 47.45875712363951, 48.204207497258345, 46.01321074270433, 47.84227078960788, 47.444911156931234, 52.39252613436792, 49.204117713436005, 49.99093732526226, 53.081109985228515, 54.53796848174065, 59.37823995467156, 63.07674869414299, 63.905929903830256, 66.8403648561047, 69.74564090851815, 40.63231898892311, 1.8485429498457142, 5.091226187444502, 2.2057036815151094, 0.296979193245211, 0.13343192396625397, 9.513691202286752, 62.51373952434909, 48.53354146403652, 48.16854530765165, 97.80699099263838, 40.463198154203354, 21.659314363233506, 53.40142250061036, 49.71032311839443, 57.4068880850269, 31.67367650616554, 0.18167589731033773, 0.08122133121134774, 0.15988448033890418, 0.06978858742983111, 0.07180314586167375, 0.06011346385123269, 0.06558179179386747, 0.04348231937676188, 0.07358557199158015, 0.033665235875354665, 0.0701863709236345, 0.035306759283787785, 0.09704785736938638, 0.05564767304026792, 0.04470114228165439, 0.06171027070752556, 0.03753724342752849, 0.08292107347158656, 0.021980987343516563, 0.0317720698207737, 0.04164665779699722, 0.04321590847065372, 0.01690520859894253, 0.025299243561382738, 0.10491666819659934, 0.03527384431612107, 0.08586887255190842, 38.71787678810858, 88.74532745730492, 70.49476654298844, 71.381316338816, 39.45862816226098, 35.24719499772595, 47.70068107112762, 42.461567309594926, 47.599511377273075, 85.50241378045853, 34.07378265934606, 0.1486478091007279, 0.20948039968648266, 0.7339100251274725, 8.457378283623727, 8.922040885494603, 0.8698505499670584, 0.38886999951735624, 54.51872533367526, 82.77872777754261, 67.20373322886806, 70.20942980243315, 53.57876070084111, 57.5530630542386, 62.81294968820388, 69.37077214640956, 68.31280692931145, 69.49406008566581, 63.04043539108769, 69.07942633475028, 67.6127815246582, 64.68244544921383, 61.90807457893126, 59.80363668933992, 55.48760960178991, 55.402517703271684, 47.81963086897328, 48.5198994605772, 47.679186482583326, 49.36406020195254, 47.33994068637971, 47.67844907699093, 47.811295832357104, 47.92932779558244, 44.24070342894524, 47.637825089116255, 47.02185999962592, 46.246411338929214, 47.59658136675435, 45.90612219225976, 49.04410462225638, 52.1912810879369, 50.269919826138405, 47.07856178283692, 45.908138290528335, 45.35861815175703, 43.70904968630883, 46.089555755738296, 46.17554979939615, 52.035904238300944, 56.94002405289681, 56.27795934677125, 56.080911236424605, 55.18022914086619, 43.38843907079389, 46.542538519828554, 43.679071011081824, 50.10380352697065, 51.550499162366314, 57.79328077070175, 55.20137463846515, 63.810922253516416, 54.08458171352264, 67.31113556892642, 39.06741488364435, 36.94735811602685, 66.20708250230359, 55.16103698361305, 56.08898347423923, 44.27180390204153, 47.647615325066354, 44.71471401952928, 47.46242453975063, 44.98104687659971, 46.859093404585316, 45.18956399733021, 46.073678001280754, 44.00609862419867, 46.43434386099539, 48.10908217583933, 47.99399983498358, 46.18494779832902, 45.80408173222696, 46.74157919422273, 47.12947414767358, 45.961462913020966, 45.50582078195388, 43.398719603015536, 44.54956262342392, 44.416802160201534, 45.659793423068145, 44.95528474930794, 46.46909213835194, 46.08008323177215, 48.681293226057484, 44.900850096056544, 47.85562646004462, 46.91379477900844, 47.47609792217132, 46.57756136309716, 48.27597510430121, 50.086733371980735, 57.80891141583843, 58.830543718030384, 57.55125876395934, 53.388431610599646, 48.67616668824227, 48.85545822881883, 49.64205034317509, 47.71590378976638, 50.51633488747382, 50.02600331460276, 54.758668484226355, 52.607774042314105, 52.31785989576771, 56.01429370141799, 58.24476911175636, 61.596344209486446, 65.88398902646958, 66.0259945161881, 68.89110549803704, 71.70974423808437, 46.30878094703921, 3.4412105717966637, 2.1075691667295273, 3.8028810485716793, 0.6926026868243372, 0.21121707504555104, 9.188736561805971, 68.82860645171135, 53.82286156377485, 42.00461902926045, 78.21364587353122, 39.436972756539625, 29.824859480704035, 58.236583125206735, 55.908315181732185, 63.562683290050884, 42.91877838873094, 0.552380343358363, 0.14062337517257661, 0.12306957355430051, 0.029794611111884157, 0.013947459951704069, 0.044222230076669686, 0.08998677134513856, 0.08114355030439555, 0.03570514415661174, 0.02294333741789864, 0.020069115337044485, 0.07218249728001895, 0.08500053487237423, 0.11660680985979496, 0.1859017761964952, 0.24976524043708082, 0.17106746413534688, 0.15471855028262063, 0.12175808465408704, 0.1596471309782036, 0.10958497818078726, 0.15820904604850278, 0.07070443788242918, 0.278872674511325, 0.137807848833261, 0.2335568117879091, 0.25315148695822687, 47.446119246944306, 95.72648740583851, 80.81747993346184, 79.2485632434968, 44.63283846455236, 36.571136136208814, 72.01488110326952, 60.58539252127371, 55.45275149806854, 94.27085661119031, 37.01759992107269, 0.3035639947460544, 0.36551580914566595, 1.4606079146746667, 6.657321712663097, 14.264326710854808, 1.6937801962898624, 0.5281434664803167, 58.33681929496027, 83.62225701732021, 70.1519670794087, 73.10348003141343, 55.88139987760975, 59.487207320428666, 64.99698423570203, 71.26894043337914, 73.13132101489653, 70.81582038633286, 64.01038262151903, 70.94917312745126, 69.8860852949081, 69.01382861598846, 64.77110278221869, 63.645798314002256, 57.44233062190395, 59.16599265990719, 50.59543732673892, 51.96850615163004, 50.503897051657404, 51.01419741107572, 48.715378622854914, 49.56735664798368, 51.114668923039595, 50.38944229002922, 47.38144720754316, 50.708385898220925, 49.5594334602356, 48.60230061315721, 51.13751672929334, 47.40822915107974, 51.89354965763708, 55.492210542002034, 52.30880314303983, 49.81316374194238, 48.53111351689985, 48.025888704484515, 46.43863101159373, 50.61869698186075, 49.92399031116117, 56.17247896809732, 59.174041363500784, 59.69956444155786, 59.274677615011896, 56.95169310415945, 45.61860069151848, 48.49132107150171, 46.788918279832416, 51.88457527468282, 54.57474462447628, 59.166694764168035, 56.65356159210206, 66.32274535394484, 57.875383823148674, 69.32243285640594, 41.94439888000488, 38.820780169579294, 68.80886908500426, 56.59877784790532, 59.52576029685236, 46.98664103784869, 48.84196919779624, 46.96146726608277, 49.988693729523696, 46.92481271682247, 48.22580798979729, 47.776190619314875, 48.36179656367148, 46.6350515427128, 48.69110699622862, 50.164255096066384, 51.81532582929058, 48.82158464001071, 48.52351588587607, 49.427037777439246, 48.921648225476666, 48.373646043962054, 46.94203584424911, 45.78124961545391, 46.950300278202185, 47.7963633691111, 48.18598024306759, 48.03120743843817, 50.93133341881537, 49.79284194207961, 51.005760392835064, 46.65634609037831, 50.87745574212844, 49.2008464567123, 50.1745395506582, 49.93844816761632, 50.77077511818179, 52.17854907435756, 62.224896184859745, 63.77640147362987, 59.77434050652289, 56.49512137136152, 52.1136809164478, 53.50656555544946, 53.736530196282175, 50.86372352415516, 53.492480324160674, 51.72307560520788, 59.426288989282426, 54.67383938450968, 56.23904158992153, 59.500272735472656, 61.22781791994649, 65.82245488320628, 69.8530746275379, 68.09618226943478, 72.93324132119456, 72.29913526965727, 47.83520660092754, 3.840154842022927, 10.930258131796315, 6.56791961962177, 0.6326921596642464, 0.3576706704353133, 11.953544693608439, 74.25433481893232, 63.61186196727138, 63.4138136525308, 103.39298740510019, 51.3857517703887, 33.08780862439063, 66.5322156106272, 64.85764988007085, 72.66972080353769, 52.36202186153781, 1.2865322684088063, 0.288738293513175, 0.41122361777290223, 0.21252423554899233, 0.16215683501814643, 0.21766923608318453, 0.23804326782063132, 0.1178571189783754, 0.19086596465879874, 0.07733959434253555, 0.12216505354210255, 0.14425003540612039, 0.17333034996784505, 0.21182184017473654], [0.04636157274005875, 0.02497462529478775, 0.07268629968166351, 0.014514878294580888, 0.027601935322426503, 0.03629760208329366, 0.07082469070390349, 0.029276967416667653, 0.0285707320266914, 0.033338430427735856, 0.09019091079432158, 0.10257522770834547, 0.17972002887437422, 52.121957117511386, 74.25424068204819, 56.43157897457, 55.012810614801225, 22.087586195238178, 24.84458684921265, 69.96698810208228, 39.823985176701704, 54.441348737285985, 74.87717582333472, 9.952104322371945, 0.16337560429688425, 0.07197659582861009, 0.37702217397670595, 2.990756020430596, 2.082707468540438, 0.9668209788299377, 3.6740059381531136, 78.83269786834717, 69.09761828760948, 75.26380385121992, 64.9795767568773, 66.60010399356966, 48.742956807536466, 52.159717775160274, 59.885186687592544, 66.54696372247511, 64.96318517192718, 65.04556279028616, 62.6250877688008, 68.3177883394303, 60.81511005278557, 63.55840006182271, 59.62455303438249, 57.08967424208119, 56.63631885282455, 51.72081239761845, 46.27710780789776, 45.828125861383256, 44.73685579915201, 47.869876430880645, 45.425941713394664, 45.347643360014885, 44.703260698626124, 43.06729109056535, 44.98427498725153, 45.75736238110451, 44.57835282048872, 46.56272303673529, 44.19054415918166, 44.66806134869976, 42.985215494709635, 44.63577239744125, 42.15288069940383, 42.72500937984836, 45.3019908935793, 43.10949971598964, 43.20296195245559, 43.08804435114707, 47.174400975627286, 47.10112325606808, 51.501665653720984, 50.13704169181086, 45.38563151513377, 41.84675147456508, 42.76251116106587, 44.82812543069163, 50.572966068021714, 50.29761568192513, 57.25180541315387, 56.03158743150773, 60.29106570828346, 52.89566816822175, 61.549228698976584, 33.5632195011262, 35.352189002498505, 63.42318811724263, 50.79047718355733, 52.51079343980359, 41.41346685348019, 46.884981047722604, 41.37379992392756, 43.842641692007746, 40.081939851084066, 42.641164795044936, 39.885758584545506, 43.18819815112699, 42.865465533348825, 48.10295935600035, 42.93529548952657, 45.406369086234804, 42.242797113234, 46.02776273604363, 41.60685931482623, 44.53773275498421, 40.56505818520823, 42.867230599926366, 41.146027888021166, 43.247327881474654, 41.123333054204146, 44.209081280616026, 41.73448931786322, 43.73222304928688, 43.02461962546072, 43.76153884395477, 45.16551594580374, 44.373565873792096, 43.44261092524375, 44.40649024901852, 43.73817328483828, 45.48953902336859, 42.96175187633884, 45.71818967019358, 46.52364838507868, 46.28168521388885, 43.39708789702385, 44.980776233057824, 45.899171752314416, 46.860909461975105, 46.41994091772264, 51.02227357126052, 54.86257991483135, 54.332377449158706, 58.516001009172015, 58.58193997413882, 57.56406530257195, 61.4681415404043, 61.13932924885904, 66.11072555665048, 63.41122881058724, 65.89421856787898, 63.92219597293485, 62.39877877696868, 18.91803456890968, 2.4288308956930718, 2.1060453259175826, 0.29891656831868235, 0.04649648848440378, 0.43133716429433516, 44.80702307916457, 61.051985909861905, 39.091227592960486, 76.77950966742732, 46.893394531742224, 14.578465415585427, 33.27912222954535, 47.890806198120124, 52.00292887226228, 47.21707244073191, 4.696207229168185, 0.17570413468826204, 0.07615647113491451, 0.1083460990940371, 0.08572730716438064, 0.0613637155132188, 0.019634854566726475, 0.05123226400164347, 0.04582574403273963, 0.01805941773308141, 0.020806925040819955, 0.07868126710696567, 0.08607919433064039, 0.036618278827518225, 0.021362082146468665, 0.0165469897159886, 0.05611975174096804, 0.08215326951035569, 0.05020957875756487, 0.0566103621085565, 0.031835858131788915, 0.012107388578325272, 0.023940672812562798, 0.04213121223954424, 0.059720001093322234, 0.013007053508303099, 0.7959287649681492, 63.557760715484626, 82.42509472754695, 63.5480450045678, 60.44602678668115, 32.8199028968811, 24.007609928807906, 58.331712368995916, 43.105753852475075, 59.3383494500191, 80.33785250879104, 11.066302599445468, 0.22451623883699218, 0.12353869515561289, 1.5546846149429199, 3.128897975529394, 0.6796295700534698, 1.331496358879151, 4.900551928627876, 78.92664647871449, 71.67992638003442, 77.51044334903841, 68.2580820206673, 68.50239076922017, 52.34770521040886, 56.177040684607725, 63.55231646568545, 68.65760680167907, 65.58439054796773, 68.36397032583913, 64.2419122880505, 70.64074147132136, 63.3811128524042, 65.47259515331638, 62.07795635346444, 61.56442788339431, 57.87876882860738, 55.263599118878766, 47.27471559278427, 49.593824801906464, 46.28095957540697, 49.68285083770753, 47.86509506164059, 47.52615913268059, 47.25891628573018, 46.20320643148115, 48.45268964767457, 48.27843835276943, 47.23604494525541, 48.41014762078562, 45.780363159794966, 46.20201403094877, 45.915073040992986, 46.806302224436116, 44.802402527101584, 46.443039755667414, 47.28238382647115, 45.8207518054593, 45.705967564736646, 47.101593940488755, 48.22024999126312, 51.05377804848456, 53.23289394378663, 50.48824679466986, 46.42047828243625, 43.13421849281558, 43.84271229467085, 47.03774952119397, 52.37549520307972, 53.783845747670824, 57.99541619516189, 58.297783867005386, 62.849572858502796, 56.04852814828196, 64.48913143527123, 34.05433162566155, 37.82558856471893, 66.6545464915614, 54.06202808503182, 53.458143895672215, 44.972362749038204, 49.811987030890684, 43.931287257902085, 46.69505988397906, 43.75956196938792, 45.189968001457956, 43.5882132284103, 44.79418516159058, 45.62468036528557, 49.703859052350445, 46.68446948451381, 48.321286324531805, 44.96667923465852, 47.7853258194462, 43.57495953959804, 45.983875336185584, 43.15007663542225, 45.820904777896025, 43.82079409014794, 46.71509142844908, 44.74755994735226, 46.55834567162299, 44.86752563907255, 45.84783969386932, 45.20418267096243, 46.33071091867263, 46.0965532641257, 48.16264214054231, 46.33226417726087, 46.561864037667554, 47.40200827198644, 47.28615322420674, 44.49521426231631, 47.339419011146795, 47.73303278030888, 48.75940330566899, 45.155741399334325, 46.547633678682395, 46.79170708502493, 47.05532958430629, 48.548364100917695, 54.28569732173797, 55.78992628282117, 57.80194920878257, 59.8438213717553, 62.589782514879786, 60.35516508163945, 63.4935672052445, 63.12829648294757, 68.7794356192312, 65.39200613575598, 68.53060830023982, 63.6456649534164, 63.89255069917249, 22.508695779308198, 2.292556479092567, 1.9356424890218245, 0.4223120050324548, 0.0566230868289788, 0.4232643136093694, 46.87324139379686, 70.2295280271961, 38.98147183079874, 72.62906151433145, 42.42592473183909, 22.869175326439645, 40.500813684155865, 53.48268224347023, 56.455160264045965, 61.25730237653179, 11.488444747463351, 0.30132315692401707, 0.06993732340033017, 0.020715210909744906, 0.13635053509666076, 0.04813603538599226, 0.03252455010829914, 0.0693363044410944, 0.07049863602245046, 0.02765369222259089, 0.04770154861973659, 0.01242209558239988, 0.05177165501781049, 0.0731325995237116, 0.20064647129226118, 0.11483071161614311, 0.23569355358279523, 0.1229764708888627, 0.17374771466899305, 0.14142419752334395, 0.2371324352439373, 0.10425078457281475, 0.14837005626290076, 0.25953594114511247, 0.20199708430276764, 0.19087776241283264, 1.3135886552833742, 69.7788163154356, 93.69684911543324, 71.53868183012932, 69.69049238389539, 33.35785596601425, 33.788198809469904, 83.04067934713056, 54.321610543035696, 67.66868314435406, 87.91056863723263, 12.683507588601882, 0.4002223193885819, 0.21337045627015255, 2.252590959110568, 5.359452568715619, 4.726121675583625, 6.060584081757454, 6.318775078942699, 85.19718277838923, 72.6447823739821, 84.02691225851737, 68.71293575532975, 74.70873355865479, 54.325124986710094, 58.84063989885392, 65.87016659398233, 71.5539869185417, 67.08178674021076, 69.10527475418584, 64.4658443235582, 74.70168113708496, 66.28339613637617, 69.39317672483384, 63.77800180066017, 63.679087469654704, 61.18623687374977, 58.113354021503085, 49.60046145223802, 52.75751052364227, 49.58076330923265, 52.60311034417922, 50.04575244842037, 51.66541284130466, 49.760596136893, 47.12939962264031, 48.68536072392618, 50.865676864500976, 49.481252777961, 51.85522417868338, 46.852943128155125, 49.707510778980875, 48.44763763489262, 49.83215193594656, 47.66507771707351, 47.21184784366239, 49.489011226161836, 48.543633722489886, 48.764580834296446, 49.16236016058153, 50.39890696925502, 52.808144400196696, 54.50302800824566, 53.23830289225425, 50.275944586723085, 46.68694057772237, 46.53198734406502, 50.3218755414409, 56.01757672525222, 54.52748006389987, 62.98171358723795, 58.67917945308071, 64.9565955900377, 57.98908548970377, 66.98273120387908, 37.36314112140287, 41.181082110251154, 69.3345529802384, 57.88440135217483, 58.002625511538604, 47.55831864572341, 53.524996772889175, 47.08976407204905, 50.18570653853878, 46.17273353761243, 48.22392132974441, 46.198558422826956, 47.55396873720231, 48.27834421588529, 55.719586418521025, 48.5058024621779, 50.935067515219416, 47.38538526719617, 50.836161028954294, 45.79706068961851, 49.91006197467927, 46.69961375574912, 49.305934598368985, 45.85336239107194, 48.756724326841294, 47.57764808593258, 50.87929533373926, 45.8215598137148, 48.086457944685414, 48.657256941641535, 47.98828494164252, 48.139849247470984, 51.39532235360915, 47.67522488870929, 50.15728504427018, 49.01922502825337, 50.23288088460123, 47.36910743098105, 51.492248042937256, 50.90261774678385, 51.88213163806547, 47.39439495148198, 50.38202901040354, 49.03438891133955, 50.854109794862815, 50.69520281207178, 55.863302061634684, 59.088266972572576, 61.45851212163126, 62.956167190305656, 64.62670072432488, 62.658051367728945, 67.5212412495767, 65.07851854447397, 71.93816738743936, 66.75051904493763, 71.03382572051018, 65.28750634962513, 65.90415785389563, 27.109343774857063, 4.030943585018958, 7.253410681601494, 0.5610582809294424, 0.18050583590182567, 1.1865978760104026, 53.50385127529022, 75.18636057453772, 52.748422391953014, 84.89868256353563, 56.97250127792359, 23.63296081942897, 45.045150172325876, 62.77103916291268, 64.50404820903655, 72.65328607251568, 14.263453983491468, 0.44777817723731844, 0.22494572304910232, 0.28136540204286575, 0.25476062399966104, 0.15624015411782652, 0.1549851029149948, 0.20483297325911062, 0.17326336323974595, 0.10316030437787695, 0.11429372228561871, 0.17256717317767684, 0.12624969645853967, 0.1901840238321212], [0.01327343472850419, 0.02498852596017382, 0.035206355800431584, 0.03969695636882417, 0.0047329098695979245, 0.06230350238301101, 0.12250853672383294, 0.02963777759202546, 0.04212073981761933, 0.09854916753547807, 0.11829473138336213, 0.2139832500007845, 5.373398555863289, 72.13816904252576, 63.38292890979398, 66.56300621647989, 42.61902301542221, 21.544373227703957, 40.58021422355406, 68.36259749627882, 39.83236335938977, 65.68451689135644, 56.88509125863352, 1.3458597107279686, 0.11572105900174189, 0.31600976723336405, 0.5173112896661605, 7.042245961004689, 3.0916741922978432, 1.0816644228273824, 36.34490166940997, 76.31079427657589, 70.85211015516713, 70.90336768857895, 67.18282699584961, 67.7537436639109, 62.24189965955673, 49.027709114936094, 52.450126140348374, 60.33543948204287, 63.187257551377826, 65.79026006883191, 62.258181418142016, 59.64563969642886, 63.54471883466167, 63.74701507629887, 60.322079889235965, 59.38529237624138, 58.44237419866747, 55.77871614886869, 48.63246363978232, 46.63294915230044, 44.309493957027314, 44.859025862909135, 47.457796142947295, 46.38829915754257, 44.41771215008151, 46.41122148882958, 44.402124651016734, 45.76097880640338, 45.746921031705796, 44.618239402771, 44.46108964181716, 43.670814421869096, 43.8260853675104, 44.00155259716896, 46.005177728591434, 43.93146768693001, 43.90727450770717, 43.33397696095128, 43.08269031586186, 43.52330976916898, 46.000506185716205, 43.508098817640736, 45.07701942997594, 42.92068858300486, 42.54793790078933, 41.87788724899292, 45.70125287578952, 46.93701128805838, 51.825351407451016, 49.20049344339679, 54.28730157113845, 54.57028488959036, 62.85072995770363, 51.31494122166788, 54.703904351880475, 30.269924940601474, 39.23102871064217, 64.16840314865112, 51.761455997343994, 50.65739116361065, 43.65533674916914, 46.19945664559641, 41.85977374353717, 46.007354644037065, 40.615397883999734, 43.05380598191292, 40.99531473652009, 41.92608141130017, 40.99236511415051, 44.88299938940233, 40.841169511118245, 43.44721971019622, 43.39948446519914, 45.03099826074416, 43.283394075209095, 42.83340015719014, 43.32604200609269, 40.83672154334284, 42.37920930308681, 42.13685389487974, 41.25509723540276, 43.80725799068328, 42.3455043761961, 45.47049983855217, 41.79102636152699, 43.82551270146524, 44.049950722725164, 43.70362897073069, 43.50063846957299, 44.502764824898016, 45.431617383034, 44.71343532685311, 46.41391223476779, 46.066739328445934, 43.26035015044674, 45.21531043514129, 43.662208741711034, 45.64548069430936, 44.894821413101695, 46.896838372753514, 53.1010748494056, 55.288129621936434, 60.099567751730646, 61.07750092783282, 59.72937837723763, 59.06775297657136, 61.71407415020851, 62.52351407081851, 63.69565948363274, 65.60073898684594, 62.39785701997819, 65.81190370744275, 64.20268858632734, 63.08866093235632, 28.061777622469013, 0.7778932166195686, 2.595849830296732, 0.6515084435382198, 0.09953802616726007, 0.02437492400678175, 17.090706248437208, 69.15173130650675, 44.55842325764318, 55.169768179616625, 39.67960665302892, 18.160181660805982, 24.995751073283536, 40.88455876996441, 52.29119562333631, 57.73184468669277, 24.979326148186964, 0.5571878821619096, 0.04664897062485257, 0.06937598013469289, 0.057445666076795715, 0.054336605488412806, 0.016707050381228328, 0.11305218487377129, 0.028489760363534577, 0.03435803982879847, 0.0645332319301463, 0.07467704810081952, 0.04258201667858709, 0.011418012868342622, 0.08945233308740201, 0.06477739181249373, 0.05012992859607743, 0.05342340953047237, 0.03102642686797246, 0.03522566121612345, 0.05293846821352359, 0.004087114507602829, 0.032531774317425106, 0.08778339522259851, 0.22920880316486283, 0.31377655964705253, 8.734483930372424, 82.25997078803279, 71.57949016940209, 71.63189303490424, 47.28572960822813, 28.253973760912498, 33.43458144895492, 61.80241377122941, 45.20963868787212, 72.4610036419284, 62.92334479670372, 1.4174226190774672, 0.07850360365644579, 0.35695661520284994, 1.4600396612959525, 4.741403229774968, 2.2897826279363325, 0.7042160894601577, 39.35177887639692, 79.5859419914984, 71.43535091030982, 75.43392489033361, 68.99208299575314, 72.90706342266452, 63.71746001705047, 52.1553914008602, 54.72339853163689, 64.6520745369696, 65.83185288213915, 68.76909625145697, 64.71715842523884, 62.52090177228374, 65.04877913382747, 67.32476188290504, 63.11079878960887, 61.67085747564993, 60.08745547263854, 58.466673281884965, 53.279091619676166, 48.26405109897737, 44.30484594837312, 47.30685549397623, 47.65683681734147, 49.171597342337336, 45.68402974836288, 49.41729460993121, 46.490080741144, 48.235606070487734, 48.55796214072935, 46.31718266394831, 45.85757501663701, 44.66433509703606, 45.97502646907684, 45.56374242228847, 48.84776253854075, 45.21662835151919, 46.11343514534735, 45.51895287729079, 45.16029919347456, 47.19615444060295, 48.792323758525235, 46.1685719028596, 47.262705295316636, 45.257605352709376, 46.84158002176593, 44.40498798124252, 48.59891953006868, 49.52444591829854, 54.750537410859145, 53.21667886549427, 58.01935442032353, 56.84480459459367, 62.09692101324759, 53.0198621749878, 56.92709592080886, 32.44154518650424, 41.21242577029813, 64.86687529471614, 52.29694581800892, 53.05939574395457, 46.4686292986716, 50.71766230367845, 43.42399143403576, 49.09597796778525, 42.43387537617838, 45.42295286732335, 43.70077348524525, 43.6674843295928, 43.766355514526374, 46.92718182840655, 43.31974660196612, 47.213554074687345, 47.420627763194425, 46.65432214736939, 45.72666198976579, 46.011990885580744, 45.63032073359336, 43.87739781410464, 43.970059887055434, 44.16821802816084, 43.85440488015452, 44.510040821567664, 43.215611596261304, 47.6637048875132, 43.48328590393067, 45.76115923543131, 45.49352415146367, 46.13344315559634, 45.30093577600295, 45.87042077895134, 46.50455428707985, 47.75208373223582, 47.93440334258541, 48.4056604293085, 44.55264168400919, 46.755401626709975, 45.4807960602545, 46.86374141323952, 47.70276777205929, 49.3700025927636, 54.484863511977665, 58.608062959486446, 61.24613931102138, 63.21475336628576, 60.953157871000236, 62.785861799793864, 63.42407849527175, 65.75646100505706, 65.47296385611257, 67.22103872606831, 66.6830542779738, 66.0005775574715, 66.46824175311674, 64.24847049097862, 32.364199969076346, 0.9691568728416198, 0.8029632907240623, 1.9940133633152133, 0.21063478693606394, 0.042811892851586306, 17.410506894511563, 76.0899648358745, 47.42307532218195, 58.06657975719821, 38.361686352760564, 25.11312407831992, 31.506291320247037, 47.035933463804184, 58.32416180641421, 63.19499246535763, 33.66485203466108, 0.6418993107734189, 0.07656969130039215, 0.07163308966424196, 0.05402067082843954, 0.06675813512335863, 0.019991570002129002, 0.03747697529052535, 0.019699391728687673, 0.06511164363473654, 0.11365819872627336, 0.05363207272884827, 0.027908922075444174, 0.04214340452885917, 0.13846597964725188, 0.18951853857405726, 0.16127673788897454, 0.1256106259121049, 0.07917520229614551, 0.12182278077929251, 0.15401877492906588, 0.14631379966533956, 0.16437704975326217, 0.37520516663789755, 0.33454676609366174, 0.5593375861644745, 10.302225870470847, 97.24456233362999, 78.82515122813564, 84.8047810216104, 56.2602694572941, 31.2425099649737, 57.72893428802491, 83.13759326934814, 52.82402215465423, 80.50960525389641, 66.36648762610652, 2.011798492843105, 0.3006791527713499, 0.8840297955659129, 2.631708138412045, 16.713638997847035, 14.879378868687539, 1.2234871546106956, 45.15523933595227, 79.9748214598625, 75.30837766585812, 75.87619566148328, 70.58994677758986, 74.38968012409826, 68.69754437477359, 54.54060823686662, 56.79388438501666, 65.49241096742692, 69.61260195701354, 70.56343939996535, 66.31457897924608, 62.841433940395234, 68.4359379737608, 71.2066218160814, 65.23796289197861, 64.44749939826228, 64.54591951062604, 61.796306640871116, 55.150034735279704, 51.63705802732899, 48.438984886292495, 48.0873953911566, 50.2761838513036, 51.304146858953665, 48.12844299500989, 51.66908417978595, 48.25744582760719, 49.45856971125449, 52.02205827159267, 48.98526906967164, 47.89452460504348, 46.879650546658425, 49.17314275618523, 48.39759995860439, 50.23888995570522, 49.06050405194683, 49.2731043600267, 48.224513607640425, 47.161672884418124, 48.355548227986986, 52.058097008735906, 48.02846177931755, 50.12512553122736, 47.89851757787889, 48.86188307116109, 46.399175890030406, 51.67959613184775, 51.03256587059268, 58.183097685537035, 56.50805342581965, 59.905010346443426, 59.3829232646573, 65.67779787125127, 55.109528418510195, 56.71352678729642, 35.05921148484753, 43.347622886780776, 69.29656874748969, 57.16507788627379, 55.0870140137211, 49.588384474477465, 53.27285112873201, 45.1906701057188, 51.60107028099799, 45.60693948499618, 48.28147034491263, 45.76143772371354, 46.749718112330285, 46.954042219346576, 50.393058715328095, 45.47354752017606, 49.54506974066458, 50.45590685259912, 50.55187548360517, 48.57394972155171, 48.659614286115094, 48.618264659758545, 45.500980577161236, 46.91362219472086, 47.06982666446317, 44.598466734732355, 47.45907875799364, 46.05095571087253, 51.38232754122827, 45.68398267992082, 47.55410994252851, 48.50829316723732, 48.225976651714696, 47.659770750230365, 49.349594500757036, 49.94395909770843, 50.18057215598322, 50.4262262775052, 51.64224340069679, 46.6625669694716, 49.28216111275458, 48.53015253620763, 51.77535295486451, 51.52108530844412, 51.53034602442096, 58.725800744948856, 61.39828020526517, 63.57716860309724, 64.30064193664059, 65.18342625710272, 65.6300743933647, 66.66840030301002, 67.85745113126694, 67.66453327671175, 71.9785285765125, 67.11173011410621, 67.44397840192242, 67.87856917227468, 65.9861824589391, 34.62582488213816, 1.8842660587641502, 8.957507937185227, 4.305904430727805, 0.31797184098151426, 0.15240445913326356, 21.66416241276649, 83.57879715581095, 56.0339722325725, 66.01575713003835, 46.00182017972393, 29.55292940139771, 36.24260233294579, 58.03604410540674, 66.33827793982722, 74.21803720535772, 39.795512691620864, 0.8836727985931981, 0.28344634199334734, 0.1558832797191797, 0.12180774247333889, 0.2223100588326493, 0.119906319906154, 0.24479152184099923, 0.18812695518136027, 0.1184340751159095, 0.2724320814013481, 0.14957609316033704, 0.0989432508246072, 0.16766128400641103], [0.036070506809459585, 0.0694790342822671, 0.025578451966266, 0.011091303181714349, 0.06451584939514438, 0.027890269749707756, 0.03562807571142912, 0.014378248428505276, 0.026388028786788066, 0.022564587378573996, 0.09939391736782367, 0.2745022654773728, 16.320568476953817, 74.86518121534779, 60.556880812491144, 58.64091673204976, 45.746744525048044, 24.827852056872462, 43.95080104950936, 59.58828679976925, 39.308738708496094, 78.49376586175735, 30.46332916905803, 0.059159328154618704, 0.06821641413074347, 0.17834744446219938, 1.3137584203673949, 1.3619983028019629, 0.32346052388029717, 21.693036940789995, 78.44308099439068, 73.22708176028344, 73.86626335882372, 70.02211309248402, 72.26289256926506, 69.18682867480864, 67.2296993194088, 55.754405298540675, 47.55769498886601, 52.606883664284986, 62.748077607923946, 61.53180160830098, 63.905506287851644, 63.95780717172931, 60.00483466732887, 62.316891454881244, 64.09326230326008, 60.26937107886038, 57.979087368134536, 57.357881992093986, 50.32366021986931, 47.421016077841486, 45.393652762136156, 44.21411760391728, 45.23062336829401, 45.75659359655073, 45.54432276756533, 44.71837751327023, 45.71443203956851, 43.5841457305416, 46.54793570118566, 43.95928121382191, 44.73061138583768, 42.87534598381289, 43.38283008144748, 44.28330821375693, 43.799609368847264, 42.912941901914536, 45.51878421537338, 42.122835343883885, 43.261428802244126, 42.42787022744456, 43.97710838625508, 42.04933797159503, 44.8466194060541, 42.534927398927756, 41.78811596285912, 41.36126402885684, 47.692632367534024, 50.83235632988715, 54.1704894650367, 52.274553006695164, 57.781105733686886, 53.39231083470007, 57.60338314117924, 53.55288482481434, 56.785392453593595, 33.810768127441406, 43.81817002450266, 61.87449124551589, 51.57607301588982, 47.443710911658506, 43.12299659175258, 46.813150682756984, 45.68262161747102, 43.83183556218302, 42.27630984398627, 42.82932089221093, 40.15295436305385, 41.38262525681527, 39.790578349944084, 43.373604666802194, 41.8620369511266, 44.878265088604344, 43.218643588404504, 43.599344914959325, 44.61377182314473, 41.41301970328055, 42.506443146736395, 41.384802172260905, 43.66000044730402, 42.42710928763113, 42.02773355668591, 42.0691067172635, 43.15457167163972, 42.77378013057094, 41.771265460598855, 44.26781485157628, 44.54079612608879, 42.36673616593884, 44.19374481324227, 43.451746125375074, 48.31389657912716, 43.22320922728508, 44.03400236560453, 43.97571594484391, 43.455915604868245, 42.74461338596959, 46.05599987891413, 45.23485168333977, 52.85598162681826, 55.05548207990585, 55.853527515165275, 59.91382783459079, 61.596265762083, 60.83309412002564, 67.55355373505624, 61.870812062294256, 63.427137944006155, 59.48855661576795, 62.27518489283901, 60.008698201948604, 64.90011345955634, 63.237573715948294, 64.53055950903124, 61.599380123999815, 64.39361779920517, 9.293128482757076, 0.6202662135324171, 1.4924242203274083, 0.034617080969075044, 0.023257475601689472, 2.868363117018054, 56.93072803558842, 55.50079268793906, 42.34959540828582, 33.80799893409976, 22.80207337871675, 22.034459652439242, 44.724657227916104, 50.07304822244952, 54.586484278402025, 29.363765255097423, 0.6651041752869084, 0.04163346576294111, 0.047480593540615616, 0.0367811567810995, 0.14788492342397092, 0.057642826464988535, 0.0455305397119974, 0.026959562937038082, 0.0537940850030751, 0.07075533676411837, 0.01903278032137502, 0.04010079961810862, 0.05651561618452111, 0.04484046303156403, 0.07418407052154503, 0.0658648612818891, 0.10420344799997346, 0.02317602896401959, 0.06066077238609714, 0.06064865670557465, 0.019828705455086405, 0.037724647686005607, 0.11575128117035474, 0.07107730053605572, 0.2946831970926254, 21.6489867625698, 86.49940967559816, 67.73942701278195, 68.19848552826913, 49.61433879790768, 31.790894577580115, 48.607301635126916, 58.59158116002237, 44.0999177963503, 86.16436081547891, 31.21117807203724, 0.10235129254719905, 0.07221645029682307, 1.1450575244042183, 2.759584760473621, 0.8742607649295562, 0.7136528217984784, 24.604969255385864, 82.14177408526021, 74.24486621733635, 76.67759080086985, 71.1300963740195, 73.7747230837422, 69.34180152031684, 70.13099024372717, 58.48152729772753, 50.11013815479894, 53.83598581437142, 64.51898067228257, 62.34577971120035, 67.07245149920064, 65.58597518551734, 60.29452916114562, 63.26066863152289, 65.70295203116633, 61.98997366812922, 60.15436718540808, 58.61864943658152, 54.16401363188221, 49.6251880738043, 46.34445490375642, 44.955739744247936, 45.990468840445246, 48.23789281229819, 47.813715934753425, 46.585268820485766, 47.46746086305188, 47.525202074358546, 49.23318639878304, 46.50029459307271, 46.136553595142985, 45.177043791740175, 45.82862008002497, 45.70435547059583, 46.41050761745822, 45.05899221666398, 46.49066517429967, 44.101404374645604, 45.154046935419885, 44.61905133339667, 45.19801670505155, 44.92116405117897, 46.9280957406567, 43.97608072526994, 45.49869383535078, 44.425250945552705, 50.723843959070024, 53.273066859091486, 55.78912219693584, 53.68945390947404, 59.15295862382459, 55.9326966347233, 59.19050747348417, 54.120239980759166, 57.205941138728974, 33.44656428983135, 45.2750716670867, 65.51078727168422, 53.8633482686935, 51.056904177511896, 45.205445674157914, 50.25917645423643, 47.365196827919256, 46.48077687909527, 45.17849899107411, 44.43467247870661, 44.42537646139822, 43.25760449132612, 43.143459596941554, 46.72125739435996, 43.299244373075425, 48.21707287142354, 44.60987298719345, 44.902509258639434, 47.5472967855392, 43.773490305869814, 43.91936325257824, 44.73841298011042, 44.86566251324069, 44.47148784514397, 43.87395789546352, 45.78961603103146, 44.7045668478935, 45.90769114032869, 45.064495302015736, 46.015524941106, 46.51461124420167, 45.57407002295218, 45.60840252907046, 47.311464278928696, 49.48730891750705, 45.31046321315151, 47.09318045646914, 45.50339283481721, 46.32726707766133, 45.25924098107123, 48.401106557538434, 47.99089331780711, 54.84548230325022, 58.84402490431263, 59.36532751206429, 62.32764659389373, 65.466189922825, 62.23970313226024, 66.18252846502489, 64.11831448155066, 65.72917699813843, 61.425128829094675, 64.20722284624654, 60.65178255881033, 65.52530004132178, 64.65252953190958, 67.91767520289268, 63.139941999989176, 65.676927105073, 12.458827360983818, 0.33769158766635005, 1.1706350551497553, 0.14922217586107794, 0.03686120530830757, 2.300462261323006, 61.072076289884514, 61.301307447495006, 49.68964438284598, 34.68252274297899, 24.767916279454386, 31.926410505848548, 51.8396209901379, 55.36653387931086, 59.269511853494954, 40.54597585431991, 1.4928494297689008, 0.07882991880779305, 0.08124849668914273, 0.05148626045293866, 0.06766707546287967, 0.06385450101187153, 0.023744872230435574, 0.05519222227796432, 0.04807111709528873, 0.03280005447806851, 0.009488668311537515, 0.0431063195930854, 0.014068629205857795, 0.12368932336328492, 0.19517802843643775, 0.1121572332997476, 0.18449176072834, 0.2510603733601109, 0.13394204659327386, 0.1867358620849348, 0.09893680036428476, 0.13176450295554054, 0.17022583994173235, 0.18215117825856134, 0.5147515754065206, 27.239089896602017, 96.29642348135673, 75.98097001352619, 77.37909101670789, 58.551070920882694, 37.3140997271384, 57.29840709317116, 71.81395376882246, 53.99597537133002, 92.45164563578945, 36.70314742672828, 0.3199358759147506, 0.2532388669468703, 1.9019558256672275, 5.794613553631691, 13.081435964953515, 2.3708952819147417, 29.419433493768018, 83.19479711594121, 76.88852017925632, 78.89553423850768, 73.73822935165899, 74.75393495252057, 73.65560070160898, 71.7268849957374, 62.25581622892811, 51.546823901514855, 55.93773688039472, 67.69202124687934, 67.23828931008616, 69.44168859912504, 67.82386779785156, 62.84616039645288, 64.35454706991872, 68.60864777718821, 65.91722719130978, 62.451264012244444, 61.99001681420111, 55.89706582407798, 52.055547468123905, 48.4430641512717, 47.75651208816036, 49.496801053324056, 50.10225811312276, 49.9500701504369, 47.92552701888546, 48.662407013677786, 48.55421627721479, 52.20180480710922, 48.14607404893445, 48.74654969861431, 46.88232952548612, 47.388464327781435, 48.44018905393539, 48.52954456883092, 46.99224218245476, 50.84182493148312, 46.5906620794727, 48.046477225519, 49.47731864067816, 47.450418164653165, 47.92244403593002, 48.924774354504, 47.16498336484356, 46.029265003819624, 45.63571007021012, 53.274243570143184, 55.448884041078635, 58.679418717661214, 55.857916647388095, 62.68682979768323, 57.96583760169245, 61.62624443731001, 58.03671875307637, 58.89651013958839, 37.53776896384455, 48.37570136593234, 66.72637293415686, 56.33319024116763, 54.095446678899954, 47.82995454726681, 53.27033296708138, 50.813250464777795, 47.365643978118904, 47.95336015762822, 46.55165018573884, 45.428561856669766, 46.395328044891365, 45.36672569090321, 49.02707761333835, 44.73966029382522, 50.76162815093995, 48.47631016085225, 48.638660984654585, 50.66754617998677, 47.44197330167217, 47.938549287857555, 48.61594261661653, 48.70926757012644, 48.07640490993377, 47.04732794915476, 48.79492036757931, 47.340168183849705, 47.515702093801195, 46.23939421869094, 49.7395565432887, 49.77576786471952, 46.04613511793075, 47.80829129680511, 49.23584576575987, 52.87390293613557, 47.37919576706425, 49.32045129037673, 47.636205150235085, 48.513078458847545, 47.55663202654931, 51.15231190958331, 50.52371678813812, 59.32618225774458, 61.68696272757746, 62.756495014313735, 66.40437772197109, 68.72151005652644, 64.46983337402344, 67.43108164879584, 64.12946970232072, 68.72522061870944, 63.07084944940383, 66.31796006233462, 61.617317122797814, 68.17651241056382, 65.4776079423966, 72.48442019185713, 64.14877953067904, 68.56786297213647, 12.922955539918716, 3.505019199463629, 5.707015750869628, 0.13958629130596115, 0.18028619849393446, 3.6386744533815696, 68.71033914627569, 66.9260843338505, 56.63418116108064, 43.29292543472783, 34.15375194241924, 33.34996023485738, 60.61015836654171, 65.0134934917573, 70.16443237181633, 50.63575929211032, 1.9445243285548304, 0.20291882597150343, 0.18055013110560758, 0.12376289078665358, 0.32621948228728387, 0.1882260409934867, 0.12867713797717326, 0.1425874407493299, 0.11764714193920936, 0.13553734808679552, 0.10930398479104043, 0.21806700425522946, 0.16343954199504468], [0.04175699744073134, 0.03549651926263206, 0.010463510407134892, 0.061251456819234364, 0.08922527994840376, 0.0393604752307217, 0.06490089284676699, 0.07647874134202158, 0.044368039591297995, 0.08849086975979228, 0.094291718165961, 0.42281468128485067, 30.311251032736998, 81.10826092381632, 64.01235165134554, 54.8685654517143, 23.35554530543666, 25.467733798488496, 30.446772844560687, 39.116334684433475, 52.81332585119432, 73.67325921212473, 13.731691395082782, 0.16906740774791088, 0.4393580742180348, 0.5383971549810902, 2.512013090233649, 3.178206090965579, 15.310916073860662, 69.26864931660315, 70.84111967394429, 69.791822894927, 69.74619788508262, 67.74975069107549, 69.21133564364526, 67.7885429320797, 67.71257446658227, 58.88055786009758, 48.309087753295906, 47.84893489653065, 51.877322812234205, 61.285496373330396, 61.53948553146855, 64.55228159504553, 63.128673030484116, 58.58577605216735, 57.57620503825527, 60.4542088508606, 59.612287782853656, 55.534105377812544, 49.725981220122314, 46.395096625051195, 47.357477603420136, 43.10988018589635, 43.936437329938336, 43.093163044221946, 47.027049295363895, 44.85384441191151, 44.33676227446526, 44.693490074526885, 45.52498940498599, 42.89602471936134, 45.483580943076845, 45.19386291503907, 46.076031423384144, 45.850985434747514, 44.419775316792155, 43.512484027493386, 45.54765285984163, 43.66944943704913, 43.598682034400206, 42.34485718511766, 43.12867226139192, 43.226394191865005, 44.58129067574778, 42.24329133187571, 44.42198753356934, 42.80780669181578, 51.67188082971881, 53.63003392373362, 56.76823600645989, 54.315907416805146, 56.24534876115861, 55.667795442765765, 58.86348378273749, 50.812116899798, 54.013680950287856, 27.647563565161924, 45.15036382982808, 61.67212832358576, 50.078570919652144, 49.089447221448346, 43.31428274031609, 47.544013761704974, 45.19760485618345, 45.681205641838815, 41.66066246647989, 44.463439141550374, 40.76913518290366, 40.00011920928955, 39.72376861879903, 42.106628110331876, 41.45287882897162, 41.9913221943763, 41.74300478350732, 41.477244592482045, 41.86472377469463, 41.303985657230506, 40.877431823361306, 40.941291932136785, 43.33418092420025, 41.35220335375878, 41.98711741355158, 44.145487893012266, 42.99145206328362, 43.363818353222264, 41.52383842775899, 43.11768570253926, 42.363641415872884, 43.25047754472302, 43.060309271658625, 46.52401708787488, 44.29787197420674, 43.97579831461753, 43.400006140432055, 43.026506285513605, 43.474150703799346, 45.87551593780518, 45.1644019926748, 52.00398791220881, 58.29694447978851, 62.19548625330772, 60.77278375625611, 61.146436583611276, 59.26698976947416, 56.00435441540134, 52.76558668382707, 60.24469544810634, 62.644393674788944, 59.229644883063536, 62.30992532545521, 63.13695315391787, 63.88207012607206, 60.44330073941139, 65.209655146445, 65.47155180285054, 65.05230926698255, 40.1827722211038, 0.5820034312144403, 0.9060094096968252, 0.3841734821757963, 0.06611531074609488, 0.06957477995104368, 25.875077824438772, 70.96643155620944, 40.92081323746712, 38.0763731464263, 34.33706391242243, 14.69469799149421, 27.464730124319754, 43.87222420784735, 51.1184226312945, 47.71935939788819, 3.8174479959472536, 0.4037108386476194, 0.13927213396997223, 0.035207937771995226, 0.01758744436947088, 0.029682377315757257, 0.07740993653574298, 0.03700324183990879, 0.026560247267386126, 0.05947358125159818, 0.032741433430102565, 0.02914298821481005, 0.0639618797257783, 0.04536539413816026, 0.032889889778509256, 0.006671180308330805, 0.026831856080060525, 0.024732711965278275, 0.03259812136210742, 0.05067870418931689, 0.08028547820304671, 0.15407054715098875, 0.14102524957589566, 0.13699029512222738, 0.2693963813925943, 42.07686908783452, 87.61101722717287, 69.79399588800246, 63.55443846794867, 36.08308738277805, 21.556075619113063, 32.576215844000544, 48.53017999279884, 57.61987670775383, 82.85650837805964, 13.143131905986419, 0.143139943360321, 0.4013038823200811, 1.7924916672129787, 3.6219754526692056, 3.9366142595967943, 19.602860789145193, 71.55441837926065, 73.21177667187106, 73.3235328428207, 70.80649299006309, 70.71376815918954, 70.1142809467931, 70.03832817077637, 69.4536361386699, 59.75595635752524, 51.67597970654888, 50.46969006138463, 55.2274505553707, 64.32123045767507, 64.56912033019528, 68.71204145493047, 64.34263875407558, 61.87561696575534, 59.871725113161155, 62.59701536547754, 62.12920604213592, 58.53296526016728, 52.76249977850145, 48.72554932871173, 46.66809358904439, 46.052995343362134, 48.316061727462284, 46.12292728116436, 47.57047799325759, 46.850962331218106, 47.02800243131576, 47.56483370257963, 47.99057952819332, 45.420685737363755, 45.77609169867731, 46.65451042113766, 47.19665650398501, 48.761748883032034, 46.09835755440497, 45.66390014463856, 47.679386523462114, 46.69676219263385, 45.59749049525107, 44.848913992604906, 44.118427461193455, 45.094607337828606, 45.32639980316163, 44.371463483379735, 47.23267562927739, 45.43088389981178, 55.38587116426038, 56.38875453702865, 57.49597295638054, 55.76001821025726, 60.122729347598174, 58.50428096709713, 61.42793332376788, 52.98861657419513, 56.00317378197947, 29.87050214121419, 46.96570734823904, 62.3652817356971, 52.5096441853431, 51.77938515140165, 46.1887760316172, 49.835321211045795, 47.298143909823516, 48.04203710248394, 43.91437399771906, 46.20760733081449, 43.33292968811528, 43.873612726888354, 42.76101673803022, 43.434915234965665, 43.772525402807425, 44.29838972706949, 44.15667449274371, 43.876107354317945, 42.563909792131, 44.08740151313044, 43.20071443434685, 43.213862219164454, 44.323787073935236, 44.70125244509789, 44.146166463052076, 46.91733275690387, 45.31962979224421, 46.02506806773525, 45.55765098141086, 43.776914535030244, 45.0892533025434, 43.837079771103404, 44.38716080880935, 48.47244662623252, 44.98627539603941, 45.611814991120376, 45.38969116826212, 46.5208125114441, 45.541702624290224, 46.59862056855233, 46.44557360679873, 53.10434610612931, 59.88579465496925, 62.39842968602335, 61.62010592799033, 63.248677945906124, 60.42228468002812, 58.11941016104914, 53.64341705076156, 60.49883757868121, 62.55930962101106, 59.83432531356812, 64.29655874929121, 65.97145788131222, 65.1760325893279, 63.720233132762296, 66.74575728754844, 68.3464216416882, 66.97901279695573, 43.458586738955596, 1.2438791894143628, 0.621663251471135, 1.1860644336669677, 0.050786251442567, 0.012082954203980345, 26.951533094529186, 77.05500910359045, 47.778273397876376, 38.392767214006, 25.894883832623883, 19.2773413273596, 32.10015581500146, 50.82571967955559, 56.033344653344926, 62.52595770743586, 7.291106129846266, 0.4247313413408495, 0.0633672614311499, 0.03541163289018216, 0.05467394081455085, 0.038804701424293944, 0.03639454284923212, 0.004263695380124714, 0.04209304190871697, 0.014583300479928092, 0.04321556756152742, 0.11901103125344362, 0.0558377203020838, 0.11342521606674118, 0.07879254903884665, 0.15704404082029097, 0.1446079670061027, 0.1255195993449419, 0.1866534616677992, 0.15250564402630254, 0.21161963892800195, 0.2787269033010929, 0.17570254122537954, 0.2356159488760656, 0.31892273995664816, 50.92758755530081, 98.505886754682, 78.94177113809894, 73.30120671179988, 36.09052027425459, 35.620428131472686, 41.99159676028837, 54.67704396094046, 69.61986618657266, 85.39986733467349, 17.113714871868012, 0.3459971452191953, 0.9459230808481094, 1.62896535809963, 11.400470887461017, 11.104986975269934, 20.723972243647424, 73.46104329632175, 73.35607282577023, 75.98565332351193, 73.10544121649959, 74.06093843521612, 72.50694244138657, 72.63050494655486, 72.34046136179279, 62.234380475936405, 53.375275981041696, 53.62259318751674, 56.79233897116877, 67.3489942858296, 67.98060570993732, 70.24014196088238, 66.41353253395327, 64.35851258616295, 64.04934744681081, 66.05425127090948, 65.27466058731079, 59.751794722772416, 53.74581052410988, 51.56557283093853, 51.02280309123378, 47.05567867525163, 49.29531281994235, 47.993211438578946, 49.725196746087846, 48.61243601768248, 48.985524023732836, 49.936887064287745, 50.57555483233545, 47.659162782853656, 49.019342699358546, 49.163144634615996, 50.53724504286244, 51.01590756447085, 48.65017314111033, 47.26893794152045, 49.359612234177135, 49.194574586806766, 48.50626137948806, 45.20846197682042, 46.732620500749164, 46.99552128391881, 48.377493889101096, 47.25025569238971, 49.7833929523345, 47.48697465465915, 56.81876790138983, 58.685816103412265, 60.65009201726606, 58.37351699029246, 61.57131164304672, 61.30209192152947, 63.81740200904108, 56.025731332840465, 57.271491789048724, 32.10959107645097, 48.73100142325125, 66.7372771232359, 56.91109265050581, 53.260111270412324, 48.684674309146025, 53.10763305233371, 51.97759036094912, 51.15486145019532, 46.71734286892799, 48.98572798698179, 44.90840458100842, 46.31979496248307, 45.436818445882494, 47.91356771223007, 46.41193143783077, 48.56437521596109, 47.53918924639302, 48.14624663322203, 46.79916743309268, 46.00378920955043, 46.71070621859643, 46.813880243609034, 48.61611127853394, 47.55804015744118, 47.44777448715703, 48.56297885217975, 47.659770750230365, 49.40448022657826, 46.70040215215376, 47.24181867414906, 48.170439812444876, 47.446229073309134, 47.36254530568277, 51.28903396667973, 48.671412775593424, 47.98974014097645, 48.39259501426451, 48.8027572631836, 47.40662097930909, 50.17921893827377, 49.89549036948912, 55.40096052231328, 61.5352415269421, 66.0337451196486, 64.79078523574337, 65.2568216477671, 63.26432428052349, 61.04232903449767, 58.31517173397926, 61.31068191220684, 64.62125255215552, 61.05596711558681, 66.4603420995897, 67.20639259584489, 67.82883351848972, 65.63495774422923, 69.44772120445006, 70.21618412386987, 68.8085788296115, 45.31079269224598, 1.3748476197642665, 4.0628197068168275, 1.852360028893717, 0.20168019969376827, 0.20140518945071006, 32.394261014076974, 85.71105249466436, 53.14737450691962, 50.65853257333079, 44.317279861819365, 24.792342839702485, 40.18556102629631, 60.309634208679206, 65.53310948033487, 71.644224966726, 9.048482410369381, 0.7055887351593664, 0.34766847327832257, 0.1981269919704045, 0.15638595597157556, 0.07605136387170323, 0.12421513547099407, 0.14123436093570726, 0.15709483244967076, 0.09992871568688463, 0.14944481633363232, 0.23918555088100896, 0.16037972553843455], [0.024475095748540857, 0.012749957273744289, 0.010467618553628846, 0.035677024899351026, 0.0620020582761255, 0.021147579442889943, 0.07036203488467202, 0.03989184147588188, 0.018250483891836578, 0.13036279188048455, 0.04396336130617608, 0.622539533482444, 50.56922412687733, 72.10454648540866, 57.01052865674419, 46.369660054483724, 15.822260764337356, 37.23375781889885, 51.1158299446106, 35.699322685118645, 61.69638818310153, 63.275189245900805, 3.39284063827607, 0.035998471561939485, 0.1966512308365876, 0.9457086375163448, 2.089254149506169, 1.2105389203756087, 55.99008875508463, 78.14855021815147, 73.06333849506994, 68.08255595545616, 65.74334852157101, 65.46247151590163, 64.78060276277604, 65.39202182523667, 63.49996851336572, 56.81560647103095, 50.96897248298892, 48.710954189300544, 48.39725871239939, 51.46787051231631, 64.18797577581098, 62.22409994371476, 62.94529045781782, 57.874599349114206, 60.432278879227184, 61.030997307069846, 58.46999945179109, 52.06765582484584, 49.04346527591829, 45.87787328227874, 45.551237906179125, 45.117800312657515, 44.472978345809445, 44.06134128570557, 44.48756956285046, 43.6053422189528, 44.39693143290859, 44.20779082082933, 45.14204056032243, 44.20662979925833, 45.278201718484205, 43.669778916143606, 45.38950681686402, 42.77193269421978, 43.71644727645382, 42.34968954516996, 44.52829160997945, 41.607067200445364, 43.99911288292178, 42.24000438567131, 42.961591059161776, 42.38058605501729, 43.334027951763524, 43.20571153394638, 44.6206202814656, 47.07957767671155, 57.14704675059165, 57.64653313544489, 57.366444526180146, 56.90186723586052, 60.71635653895717, 56.3647613986846, 57.77488485459359, 52.85829190284976, 55.64353950562016, 29.62642481250148, 47.21224008067962, 60.17265327515141, 49.92872853432932, 51.36449252405475, 48.329307571534194, 49.38048316586403, 48.838874447730284, 47.60653241988152, 45.231305860704, 41.779051365390906, 41.80334652623823, 40.106133030306914, 39.890967492134344, 41.69728955914898, 42.07905384802049, 41.57102846330212, 42.2878102333315, 41.75703117924352, 41.320498835655954, 42.01171851927235, 41.69072743385069, 41.86203302875642, 42.169099700066354, 45.35044000994775, 41.16716554087978, 43.3036688066298, 42.81375300499701, 40.57787256856119, 44.49245683608517, 43.97974814138105, 42.71309714163504, 43.22426434486143, 41.1423251705785, 45.43741072377851, 43.73926762611636, 44.89161683667091, 44.86693336117653, 44.061823737236764, 44.15274820020122, 43.60527553865987, 45.40667503110824, 57.1960057750825, 59.29677232619255, 62.625691813807336, 54.93230788938461, 60.098496944673606, 58.45032876537692, 62.239016717480084, 56.30771052452826, 54.543875571220156, 61.65167316313713, 61.42798039220995, 64.1478773855394, 62.92175623678393, 60.492914799721014, 64.21888797513901, 60.14221960498441, 64.07237568209248, 66.42048297389861, 67.78708381037559, 13.075724013390081, 0.5909504188645271, 0.6558451753470206, 0.10828810623816906, 0.04781225598567436, 3.2421392538855156, 62.93521388884514, 54.412303586159986, 46.66322985003072, 40.535844372164824, 25.585640245868316, 34.44230110414567, 46.35131905155797, 53.92822034897343, 53.41790037770426, 13.07634178669222, 0.44306639942430687, 0.12306896068396107, 0.12535037818334757, 0.028816521761097738, 0.01706757135839472, 0.020838227393406055, 0.049916802935542605, 0.013304378934985688, 0.056193480042800795, 0.020731597530445265, 0.009299566210698216, 0.011931614492148643, 0.01512973375933906, 0.04493277662643983, 0.05843113476951277, 0.04799580299145272, 0.03638413171434114, 0.08434847147474367, 0.04644693025658208, 0.06562915134934649, 0.029660141613755017, 0.0620857993471286, 0.0854933822167016, 1.5252490654107065, 65.4743209961922, 78.10933436116865, 66.88377764917189, 53.44695729594077, 22.530937579370317, 37.8258474411503, 43.219086816233975, 40.77280652138495, 69.86143712074526, 69.44029223534369, 3.3944046833822807, 0.1587085966621676, 0.059841602229543274, 2.2314140825502338, 3.306217789649964, 1.6845638521255988, 55.00402450561524, 80.22047950375466, 72.71736191165063, 69.72346382756388, 68.89458856275006, 68.3250133452877, 69.22211431687879, 67.36655865946125, 66.10830153188398, 60.404037813986506, 52.83129030658353, 50.80460948328818, 51.28879077972905, 52.930608641716745, 64.61449430834863, 62.66546072498445, 65.8471893495129, 60.929109819473766, 63.285760033515196, 63.70697552157987, 59.89694987573932, 55.01697617192423, 50.27032383026616, 47.10081338882447, 46.85672429300124, 47.60563419711205, 46.94467559937508, 45.57437596782562, 47.10543786325763, 47.69718623930409, 46.72522683297434, 45.9584544550988, 47.82602825472432, 46.02367562632407, 46.541518703583755, 45.20750099612821, 46.76999284375099, 45.349318212078465, 46.232400632673695, 44.737812857474054, 46.139962134822724, 44.38298348457583, 45.15943627203665, 45.42016406213084, 45.08477395580661, 44.49241761238345, 46.070983332972375, 44.74961134695238, 46.41947415567214, 49.25153132407896, 60.85269028140653, 56.39970187217959, 59.4103955453442, 58.89973040549987, 62.35488745474047, 58.3294334719258, 59.5457330057698, 56.385220481503396, 57.36242017438335, 31.888414505989324, 48.03132118717317, 61.49299367781609, 52.154402963576786, 53.855887920625754, 49.7121548652649, 52.0812350703824, 52.57180198546379, 50.534346411305094, 48.29157044810634, 45.489429197003766, 43.73976576712824, 42.848438524430804, 42.641780607161984, 43.271517138327326, 43.20675488441221, 42.71834135055543, 45.73692683250674, 44.77598536399103, 44.01762254776494, 43.69774149310204, 43.257828066425944, 43.53551618514523, 43.6057383783402, 46.28080660297025, 45.361014719932314, 45.07510531333185, 44.523714203988355, 44.58046697801159, 43.74301741200109, 45.006122589111335, 44.39392297498642, 45.060608233174975, 43.21310127935102, 46.669419350162634, 45.925004482269294, 45.61233666635329, 46.530838089604536, 45.60346034265334, 45.85284856057937, 46.38137225181826, 48.6083096842612, 58.43951479081185, 60.799785352522335, 64.09732980112877, 57.829154768297755, 60.769728229891875, 61.42694880885463, 64.40505543062764, 60.007721531775694, 57.45312890698833, 63.610818616805545, 62.84222233679987, 65.00964564661827, 64.65434166692918, 62.491923301450676, 64.27695474316998, 63.17381166642713, 67.17529604511877, 68.98204172811201, 71.7513370513916, 16.431530367943548, 0.39063871267341804, 1.5900995726546936, 0.2609223764269583, 0.13738938096550204, 3.6183097525950405, 70.73455672110282, 59.33152844828945, 47.86147471397154, 30.21813004247604, 27.02720738226368, 43.12105109614711, 54.88835773160381, 58.87407025983257, 62.94987570854926, 20.93486632070234, 0.5979794900744193, 0.07375665474683046, 0.053209896995535785, 0.038498204967547814, 0.03427389656163512, 0.021834067001398054, 0.06177623087780611, 0.06377274793903194, 0.03718587337061763, 0.028138848044158473, 0.03295108488190078, 0.04842688449688497, 0.1124111608031296, 0.10397368290972325, 0.1410522465143473, 0.16773694284981297, 0.11464834438576815, 0.16655468532154638, 0.15130677771183754, 0.18270213337194535, 0.09410643980147378, 0.23244840513554313, 0.18125418122977982, 2.6446642173874766, 77.4914590774044, 86.5730639426939, 72.97237873077393, 62.15295207115912, 26.32745065996724, 53.36090441673033, 69.81448634978264, 50.43691081385459, 76.67691615320022, 76.11791564572242, 4.7021108865737915, 0.14473452473119383, 0.9775021443924597, 3.299139382377748, 11.423649153401776, 2.5860245381632163, 59.01774667924451, 80.26165654582363, 79.09188808933382, 71.90720419729911, 72.79205168447187, 70.8550048643543, 72.71730699846822, 69.59478655169087, 70.36647365939233, 61.488737906179125, 56.97506650801628, 52.77820494867141, 54.1087160571929, 56.29699460921749, 68.64591813856556, 67.5924793366463, 69.24870014190674, 64.06702556917745, 66.32309052252, 65.38297291724913, 62.15507407342235, 56.7141386770433, 54.45219016844227, 49.492329551327614, 50.34760236740113, 49.92532391701975, 49.181685678420536, 47.58367676888743, 49.3027731680101, 49.561963388996745, 48.72692215827204, 49.91619656162877, 50.8391067289537, 48.65815908678117, 49.392116915795114, 46.08088731765748, 50.07551147091774, 47.98590798531809, 48.17519372509372, 46.24188884612053, 48.35499517379269, 45.20031521397252, 47.53926769379647, 46.890433142262125, 48.17999862855481, 46.296582375803304, 47.869860741399954, 47.8957405397969, 48.17057317303073, 52.13744655732186, 63.4054825382848, 61.74636702383719, 62.48774989958733, 60.750473314715975, 66.1076896421371, 62.115771924295736, 62.58560126827609, 57.10314366125292, 61.79614974606422, 34.57719141437162, 51.86973302595077, 63.6670457932257, 55.03299513170796, 57.13195739253875, 51.21358717641523, 53.45030700006793, 55.610105222271336, 54.32925132013137, 51.70113778883412, 47.92694299451767, 49.30460491488057, 45.46087434214931, 45.56763733586958, 47.42140047011837, 47.377265960939475, 44.91266035264538, 47.24556846003379, 46.840285639609064, 47.28797712633687, 46.371083874856275, 44.92695739192348, 45.43258620846657, 45.17070916391189, 49.383703431775494, 48.02609266773347, 47.67425214090655, 47.090375961795935, 45.50608750312559, 48.05746770674183, 47.08806960813461, 46.48451097549931, 47.08402564448696, 45.26432437281455, 49.945979118347175, 49.44810090526458, 48.59365570929743, 49.63331914717152, 48.836838737610854, 48.26704778978902, 48.80106672163933, 50.13620230459398, 61.322970697956706, 62.50456902288622, 70.12534987541937, 61.44620372403053, 61.820021290932935, 64.86793825703283, 65.56984639936879, 62.39926122849988, 60.81316063480993, 64.68484201738912, 63.69002303769512, 68.34326021132931, 67.16956153992685, 66.12322222801947, 68.25776038631317, 65.05838894074964, 71.63078692651564, 71.68970092650383, 74.24248141627159, 16.266367204727665, 2.0619289577007294, 3.4236028069450013, 0.3238776434333094, 0.20011736500647762, 4.719445311254071, 78.72158496610581, 64.6962914159221, 63.277899603689875, 52.174301147460945, 38.160135361456106, 45.5300453401381, 64.53272465736636, 67.12675279186618, 75.08503790824645, 24.592707926227202, 0.8450300979518122, 0.2728008454845798, 0.27251745423963, 0.1439051273008508, 0.1302101565224509, 0.06723874038265598, 0.24378747168567874, 0.12828096326801086, 0.1822105194291761, 0.18585245545593002, 0.21977625366660858, 0.10026637660039049], [0.03974494794684072, 0.0442482540834575, 0.014926240696842152, 0.04800216535166387, 0.011886968803141388, 0.03334359386034551, 0.028141628943323612, 0.08474843065825202, 0.08144322857861558, 0.08717596410743653, 0.07676024801067768, 5.541992322091134, 66.00766920274305, 66.88199689311367, 55.191713840730735, 38.77634363789713, 32.16324910040825, 23.753508983119843, 35.18325644154703, 47.829048479757006, 71.07854074047458, 47.47154405040126, 0.2882817357538208, 0.13305336927935002, 0.2736240835680116, 2.554564677899884, 1.9936712590917467, 11.868513591827886, 76.44238195111676, 68.7328770852858, 70.76607688780754, 61.54476111935031, 60.643949585576216, 58.11805302096952, 62.63171265202185, 58.36995155580583, 59.17984254898564, 56.05264271459272, 49.94820310223488, 46.16654795985068, 47.44668406824912, 47.647984027862556, 49.076397495885054, 58.419263593612186, 63.24726197027392, 63.88315270023962, 61.52146616289693, 60.75907115013369, 56.067273155335464, 49.005869357816636, 46.41411227564658, 45.39983441752773, 46.25338923546576, 44.729666094626154, 43.7990092462109, 43.02451764383624, 44.48931109520697, 43.933299433800485, 45.190987817702755, 44.17843188008955, 44.767567957601244, 44.55676409506029, 46.40483979255923, 47.13235708975023, 44.002207632987734, 43.735298187501975, 44.88928694878855, 43.130460862190496, 44.02699701247677, 43.937880762161754, 45.70731686007592, 45.09938086232832, 42.638015131796564, 43.008945834252145, 42.793756761858546, 43.46220316425447, 45.19714201650312, 49.57482484079177, 60.44376357909172, 55.489480572362105, 57.93137565735848, 54.989433288574226, 58.97531840109057, 54.60364464790591, 59.254300901966715, 54.43001700985817, 56.30675346620622, 36.14531186319167, 47.905158150580625, 59.670272181111, 53.18896339785669, 53.74661068762503, 55.803470227026175, 55.386377150012606, 54.236502955036784, 53.773769178698146, 50.466814964048325, 44.66201697626422, 39.86039261664114, 42.04669821646906, 38.69715098411807, 40.154856712587424, 40.13407599541449, 40.828064872372536, 42.62186673379714, 43.085110418258175, 43.427996173981704, 42.46300289707799, 42.229731698190015, 42.45054544941072, 43.50372929726878, 43.21429760225358, 43.09660296286307, 44.429510639559844, 41.5934173522457, 44.81577780938918, 45.828286678560325, 43.36874092778852, 42.149130913519095, 44.339103929458126, 43.142584908393125, 42.6283190327306, 41.221890449523926, 46.72557200154951, 43.764821867788996, 42.67852929330642, 44.77340444441765, 43.77251363569691, 51.096198481898156, 57.23443715803085, 55.312483618336344, 42.688609784649266, 52.958010319740545, 62.98187048204484, 58.59571141581382, 58.097539024968306, 63.25703259437316, 59.71245727231426, 57.46595505745181, 61.90912969650761, 58.53915868266937, 59.001857157676454, 60.21239080736714, 59.85224270051526, 61.81704028960198, 64.13214868114841, 62.55422622926774, 69.91682098757836, 45.28929810370169, 1.0329390245099221, 1.4393610483215702, 0.3533028967438206, 0.05290857929315779, 0.07245082723637743, 27.770737755683164, 69.88460263898297, 44.47469242157475, 39.65793948019705, 19.401692228932536, 23.666846175347608, 39.23702209226547, 48.46517062956288, 54.524957979879076, 31.934353305447488, 0.6787906731328657, 0.09059550480977183, 0.1487661850067877, 0.048508227712685065, 0.0633717353846277, 0.10422908130191988, 0.018894101170101957, 0.045905750425111864, 0.022637582151219252, 0.09260597999297804, 0.040911642398925564, 0.06234941403231314, 0.04873944453955178, 0.0062586721258177875, 0.06562312989826165, 0.021752626109387607, 0.03059500062297429, 0.08157052940899327, 0.06495467221905148, 0.025311686744492863, 0.02664012150959142, 0.11677053051009295, 0.18624876806091878, 8.155599947898619, 79.3028723809027, 73.2863252393661, 62.98545552838234, 45.07027687564973, 40.44237429095853, 35.45314688836375, 35.50493001937866, 52.76319796039213, 77.66442775726318, 49.87494107215635, 0.10157631800299692, 0.06400909755499133, 0.9820032480262941, 4.744631340426784, 1.5798865787444578, 11.768493152433827, 76.26312178950157, 70.95753562065863, 73.6061631479571, 63.777727234748106, 62.26098983518539, 58.97772281400619, 64.86978961575416, 58.820561285941835, 63.17723589558756, 57.47365859247024, 52.41337353183378, 48.459381211188536, 49.53954704346196, 48.43393679588072, 51.49844931017969, 60.298318170732074, 64.58488041354765, 66.94822219110304, 64.8448198072372, 63.044173409861905, 58.32609553490916, 50.31536832932503, 47.94757073925388, 48.5079558434025, 48.43489385420277, 46.22435585145028, 46.39363358097692, 45.151422869774606, 46.338567426127774, 44.081576793424546, 45.495383354925345, 45.647685066346206, 46.5593497983871, 45.42660067158361, 49.39441150234592, 47.447939226704264, 45.44284712883734, 45.75567968430058, 47.04151107418922, 45.95916832647016, 46.05271293270973, 46.04575072565387, 49.02800329269902, 46.7358603785115, 45.23940947748, 44.01173507013629, 43.92103025990148, 44.82204183455437, 47.67712723824286, 53.37637816706012, 61.86415580011184, 55.75862969121626, 60.489223849388864, 55.95823126454508, 61.49877917382025, 57.03622802611321, 60.568765594113266, 55.926518901701904, 59.93732675429314, 36.881501520833666, 49.649765645304036, 62.385419184161776, 54.529398102914136, 56.35923870148198, 58.069690196744865, 58.056193320981926, 58.016283204478604, 56.93297555369716, 52.05327249342396, 46.30918887353713, 42.52674141237813, 43.87891184899115, 40.872815193668494, 43.460371417383996, 43.14642098642165, 44.5217098728303, 44.02684796241022, 44.94548274624733, 45.21108604246571, 45.07015528217439, 44.06354173537224, 44.40889466193415, 44.1077390024739, 45.04755066287133, 45.0007293301244, 45.94793465829665, 43.75506693317045, 47.243309174814534, 45.88254874752414, 46.17696185265818, 45.15510597536641, 44.16418190925352, 46.637773667612386, 44.994677112948516, 44.887478736139116, 48.63196942114061, 45.877688930880645, 42.81876187170706, 45.80340708455732, 45.52978254133656, 52.97564921840545, 58.97746001520465, 58.03711491246378, 46.98584087433354, 56.54320570730395, 63.80791771796442, 60.86051933227047, 60.13308048248292, 63.6738746396957, 59.69332787298388, 61.003132789365715, 62.67727490394347, 59.810214504118896, 61.586079366745494, 62.20521765370523, 61.38719950952838, 63.41029528648623, 65.85166085150935, 65.63316914343065, 71.91779459676435, 48.8047262930101, 1.777976200945916, 0.9269495344450398, 0.4770087216409945, 0.1031165377747628, 0.1610021872986709, 30.747944193501628, 77.30582898662936, 48.02845001220704, 35.665806031996205, 27.74565615961629, 33.222600875362275, 42.9449680543715, 55.430044897141, 60.78575111204579, 44.72681453151088, 0.9398752763386696, 0.07048083979996943, 0.08958998376563673, 0.06542049964228946, 0.016081901567597544, 0.058902933848120516, 0.05620283397635626, 0.04602856581069289, 0.035910329315811396, 0.02650287111229714, 0.058927915975331306, 0.08699334406804654, 0.10162625927478076, 0.10225181603023123, 0.1590556651353836, 0.12326127939647245, 0.22195203530211605, 0.1794570615334857, 0.1533890659770658, 0.19324672077932667, 0.17937032505869868, 0.17258039585524992, 0.29656345265046247, 11.054791423582262, 93.44371503399265, 81.86590594630088, 74.48178522048458, 52.736725884099165, 47.09094078310075, 33.40725037359422, 50.61074633752146, 61.69489768243606, 83.71948472915157, 55.3738530220524, 0.5243064691462825, 0.30614129838443577, 1.2520947163143468, 8.877837734837687, 7.574046792522554, 13.407211361392854, 79.51508829670568, 74.5955967134045, 74.83646946568643, 66.43036734673285, 64.07721196451496, 62.607648911014685, 68.1104047836796, 61.61000190242645, 65.29777903710642, 61.19472096043249, 54.603350470142985, 51.02111254968951, 51.65817214596657, 51.27963989011703, 52.74320563962383, 63.26901543524958, 67.95909543191233, 69.20633854404574, 66.37919610546481, 66.16839224292387, 61.13604230265464, 52.638599949498335, 49.8311125078509, 50.915134030003706, 49.789182370708836, 49.48624203282018, 47.579209189261164, 45.692811935178696, 49.127545202932055, 48.58196704618393, 48.404079714129054, 48.19394265451739, 48.79678349341116, 48.67973604509908, 52.02223870062059, 51.81585927163401, 49.303757682923354, 48.90921431203043, 49.555989619224306, 47.591152806435865, 48.494611940076275, 49.61201283239549, 49.499440808450025, 50.78241279048305, 47.288714531929266, 47.189874725957075, 47.60868187873594, 47.40899401326334, 50.47195719134424, 54.515779633675855, 63.258946711017245, 58.68498456093573, 64.10594724839734, 59.939064364279474, 65.38161969953968, 59.72754270799699, 63.57588206568072, 59.389940384895574, 61.29753804975941, 41.253281178012976, 54.10053791538362, 64.93668563904302, 58.06450874574723, 59.4286306442753, 60.9566487804536, 62.87184015397103, 60.15883476503434, 59.01138459482501, 55.709086233569735, 50.07739813097062, 45.575980217226096, 47.760697257134225, 43.20101253447994, 46.01994937466037, 45.89502580704228, 47.01845538231635, 47.10275103968959, 48.629800350435325, 49.87954593473866, 47.477815920306796, 46.660417510617165, 46.54125982715238, 47.79243707656861, 46.70194756600165, 46.90841328713202, 49.1972614103748, 46.11121116145965, 49.112342096144154, 48.22977742841167, 47.483189567442864, 47.840372362444484, 48.45467044461159, 49.828476675095104, 48.36313409190024, 46.88657745238274, 51.99045573511432, 47.752927041822865, 46.80596097823113, 48.5332315967929, 48.713044812602384, 56.120150627628455, 61.59032729364211, 60.59314704710438, 51.50188138408046, 60.42644631478095, 65.91977673192179, 64.62850501460414, 63.94194118438229, 68.0932326470652, 63.98145121912803, 63.59262666394634, 63.979360595826186, 64.07327390486195, 63.99424599063013, 66.5507919557633, 64.08808085226244, 66.62938840927617, 68.78256567062871, 69.97276967571628, 73.93237098570793, 50.285397498838364, 2.032840660502834, 3.567671218226033, 0.8139921989171737, 0.2840273737186386, 0.40757081861938205, 36.595219489066835, 83.02019673009073, 57.691809054343935, 51.58428645903065, 28.033297292647827, 35.605632951182706, 52.88944728912846, 66.36419696192588, 70.06355685572471, 54.848612354647734, 1.717482343796761, 0.24113388101179756, 0.24698192043410194, 0.24515411125556116, 0.11445277746045783, 0.19413700687789148, 0.11385406442587415, 0.11660859484465853, 0.10823217415881735, 0.21138664094671128, 0.17069175929552124, 0.18784753227185821], [0.07008037499843106, 0.028447562325445395, 0.07102689961151731, 0.09267740237015872, 0.06216867856921689, 0.07403027070986648, 0.04562917353224851, 0.10165904017706072, 0.15895331578869976, 0.189263814339234, 0.41211001214481174, 10.884846891126326, 68.66655765041229, 57.88279318040418, 52.1242360145815, 29.350817511158606, 19.25863358282274, 34.68003988265991, 40.66314881847751, 49.36584488038094, 77.18054063858526, 20.48025969536074, 0.13905928410109014, 0.15402966869934914, 0.7694149522050735, 1.8949939863335703, 1.141756114459807, 30.419612392302486, 67.21000117640342, 67.08348120412519, 68.58138730449062, 61.05571608389578, 57.15955518907117, 54.03055890913933, 55.615992699899984, 54.52368320957307, 55.37412758796446, 53.48179186544111, 51.50933780977803, 47.673161721998646, 49.21179379186323, 44.26202543320195, 46.57941664418867, 44.559886301717455, 52.865944447055945, 56.080338570379446, 60.244852342913234, 54.90445906116117, 48.033768746160696, 45.00413394743397, 47.34290599822999, 44.09551689701696, 45.9440593565664, 46.98562122160389, 46.1170554930164, 43.16875103981265, 44.26727748686268, 42.3687248076162, 45.9120959620322, 43.54029755438528, 45.85954404646351, 42.59579081689158, 44.572402584937315, 43.482979959057225, 45.473116059457105, 43.72186799203196, 44.690995447097286, 42.07770063031105, 46.08878697118452, 46.22575221523162, 46.07801222032117, 43.816557930361846, 44.41195803303873, 42.83653805332799, 43.30304907214257, 43.03672798218266, 46.01782345002698, 55.125147296536355, 57.62519544170749, 57.15237332928566, 57.206670699581025, 54.53881571369787, 58.71827763895835, 54.181821192464525, 59.75194769520914, 55.13041896204795, 60.117096824030725, 32.40467686806956, 39.776379369920306, 63.46669112482379, 52.34645789669406, 59.73758789800829, 53.508503206314586, 55.871535116626376, 54.20371978513656, 55.59731045076924, 52.62102773112636, 47.82734617110222, 40.39939688098046, 41.10054800587316, 41.69958022332961, 40.914780632142104, 40.48629699214813, 42.22072593627438, 40.97130590869535, 42.45755080253848, 42.039614415937855, 43.431079156937145, 44.50653030026344, 43.26001282661192, 42.23894142335461, 42.47753527856643, 46.03888265548214, 44.56148662874776, 45.18682226057976, 43.789623014388546, 43.57506936596286, 42.169185992210146, 41.985646524736964, 43.243707533805605, 44.20651212815316, 41.674226022535755, 43.071397812135764, 43.515978859316924, 42.48829826231926, 43.21648236243956, 44.055759752950365, 44.49673614194317, 50.89077611123362, 57.69115401852516, 56.72281888223464, 52.171951647727724, 60.17881531869212, 59.25053542660129, 57.3950856731784, 57.333155370527706, 56.032505266128055, 58.55550319917741, 55.16484952742054, 60.068051507396085, 62.0436316920865, 58.677771322188846, 57.53835416609242, 57.061244903072236, 61.620933548096694, 58.633421082650464, 67.19858707920199, 64.54680988865515, 69.46334792721656, 17.345993711102395, 0.7243186656025149, 0.3703291089304032, 0.05827623179122325, 0.07990853230078375, 6.711479348521079, 62.79364378221574, 52.920390867417865, 42.08923239861765, 21.561892494078606, 14.853233329711424, 32.82716908762532, 46.731639908206084, 53.18930856643185, 44.78919982910157, 2.293721668181881, 0.1983913535913152, 0.048729102352573994, 0.05997976618668726, 0.01590358885756183, 0.06322988271412831, 0.0794067906756555, 0.06337044069603567, 0.1776836905628443, 0.020050365335097717, 0.06058073151976832, 0.07535828412660668, 0.04533935097917434, 0.02547785504570892, 0.041649814079245256, 0.01635633915993235, 0.022384999132144357, 0.12267458628142074, 0.09670034456517428, 0.01853259385473305, 0.14842990305154555, 0.2297653507200941, 0.441589473836845, 17.18994809735206, 82.79556259032219, 65.15469489559051, 59.119716536614206, 34.953181974349484, 25.900130002729355, 32.773569899220625, 45.76158285140992, 55.7616695280998, 83.36341196490874, 22.20302547177961, 0.17472898136944542, 0.09695437932086569, 2.206552384361144, 3.577474201879194, 0.7963861501024616, 34.3309332478431, 71.02214490213703, 69.36773623189619, 71.14802160570699, 61.42690566278274, 59.99510326693135, 56.55314107095042, 58.12522311364451, 58.00069178304365, 59.02745454542099, 54.222056865692146, 53.74479855260542, 49.52495974879111, 51.977872771601525, 45.92128607534593, 47.94241282247728, 47.81958772290138, 56.59500452779955, 59.40092302137806, 62.40095961478449, 57.16611339199928, 50.85243102042906, 47.34940536560551, 49.75714052877119, 45.651948682723514, 46.372954845428474, 47.299826606627434, 47.13158438282628, 45.99154356987246, 46.33171112306657, 44.72089959729103, 46.33167189936484, 46.940517886992424, 46.92647187940536, 45.67014848032306, 45.74455976486207, 47.41824688449983, 48.73652804282404, 45.78775682756978, 46.62685378905266, 44.73530254056377, 47.45900031059019, 50.4289327129241, 47.797155687885905, 45.898869729811146, 45.749521563130045, 44.42789462304885, 45.35145590382238, 46.35961486447243, 48.996577262878425, 55.38027394202448, 59.6614743048145, 58.24853066475161, 58.719940723911414, 56.22434839125603, 60.25500343691919, 56.223356031602435, 60.33248201493294, 57.9607149862474, 61.01212286180066, 33.66249469018752, 40.05905674349877, 64.57576090289702, 54.0441224651952, 62.81242016823062, 55.8151981138414, 56.902106500441036, 57.27421391394831, 57.53174104998189, 54.37014595154793, 50.02493250754572, 42.8524903328188, 45.1234838270372, 44.26521824252221, 44.46302337031211, 43.885607334875296, 45.01369668591408, 45.01321031201271, 43.766092715724824, 44.93732029391874, 46.80495685146701, 46.36516894063642, 46.11283894508116, 45.84004594433693, 44.475951502400065, 48.26565927074802, 45.61366634984171, 48.278889425339244, 45.05034339043402, 44.292980778601866, 44.54562064140074, 44.38439161546769, 44.91055403986285, 46.375500463670306, 44.06404772112447, 45.511712181952696, 45.046381796559984, 45.123632877103745, 44.60901398812571, 46.18942714506581, 45.65431779430759, 53.221224892523985, 59.89480433925506, 59.03631125727008, 57.2310443078318, 62.314000668064246, 61.34573613443683, 60.5766377910491, 60.364743509600245, 59.33259533297632, 61.67686654675392, 58.60960837333434, 61.648476431446696, 64.40133310133412, 60.20778986715502, 61.15496773873607, 58.74496544561079, 64.23771535196613, 62.113132169169766, 71.42959287089687, 66.61972368917158, 75.19999473325669, 20.250926556125766, 0.30824849982896163, 1.1414719877704498, 0.15136850907677604, 0.09578312281519176, 6.781911878816544, 69.079693055922, 57.970179665473204, 43.88898841796383, 24.27408399120454, 19.726642947043143, 35.97765015017602, 55.9554228475017, 57.07349054275021, 59.063520739155436, 4.736471339579552, 0.4372016286417362, 0.02924415778609053, 0.11084958250003477, 0.06643981026906161, 0.060441885744371725, 0.06292574963862858, 0.07141202733281159, 0.0906796365856163, 0.07453258690093795, 0.03547180526619477, 0.07377474208272274, 0.18623015212435878, 0.1531437646237112, 0.16814404197277563, 0.15805838719731377, 0.12573280161426914, 0.2874467305598721, 0.17649254641465603, 0.16541790277246507, 0.27031593204986665, 0.37486977334464755, 0.7027007675459308, 23.389063919744185, 92.26235989601382, 72.95205300854099, 69.16488693606469, 42.262008882338, 29.738579104023596, 44.0099347022272, 58.726836250674346, 60.659121313402736, 89.19405444975823, 26.859537824507687, 0.23890163869627062, 0.23014893094378136, 2.497760913064403, 11.034660839265394, 4.817876210135799, 35.94683208773213, 77.73298294313493, 70.95741794955346, 74.59270984895768, 64.8864596889865, 63.89679078132876, 58.9780052246586, 61.625781597629675, 59.40906978422596, 62.48929923580539, 58.26055272932976, 56.569171797844675, 51.86981147335422, 55.12968547882573, 48.74362361046576, 52.00474492965206, 48.88537806849326, 59.10095191770985, 59.5331931883289, 65.26588624523532, 59.2544734862543, 52.565216325944476, 50.00729753125099, 52.729253768920906, 48.05383166959209, 50.05231457371866, 50.88687335291217, 49.59395816249233, 48.08970174481792, 48.28060742347471, 46.12833230726181, 49.60912989031885, 48.980354339845725, 50.37462749788838, 45.281712239788426, 48.25504141469156, 49.25976437907065, 52.093484632430545, 48.9292380117601, 49.37911425867389, 46.58273496935445, 51.247241112493704, 52.418272572179, 49.881389448719645, 48.13882943122618, 47.125571389352125, 46.61355303179833, 48.301976496173495, 48.66295222313174, 52.802045114578746, 58.28597753278671, 63.13902808773903, 61.9612148500258, 59.67778351999099, 59.708048528240575, 62.66790043923163, 58.35942391426333, 64.22246125436598, 58.56104943060107, 63.97698756187194, 38.092392106210035, 43.96294470756285, 67.09880198201826, 58.01400430740849, 65.02091069375315, 58.82212238927042, 58.384931087493904, 59.43682447556527, 61.07836384927074, 57.502005561705566, 53.37896300900368, 45.285246295313684, 44.69472562113116, 46.620770192915394, 47.86773873913673, 45.28978055523288, 47.8945206826733, 47.34174497665898, 45.96480477240778, 47.05538841985887, 49.60874942041213, 50.00981177053144, 47.406366025247884, 46.73380897891137, 45.51008047596101, 51.50090863627773, 48.88238530005179, 51.66024707978772, 48.99447095009589, 46.40107823956398, 47.00086355209351, 47.34616548784318, 47.12863083808653, 50.140309026164395, 47.93140665177376, 47.71983792704921, 48.14707817569856, 48.569219343123905, 46.61318432900214, 48.63877081101941, 49.046999331443544, 57.706604234633915, 63.196694774012414, 63.67856187205162, 59.11098534061063, 64.76028488528344, 64.98949643104308, 64.25638191161617, 61.54681251895044, 62.288509184314364, 63.37782982856997, 61.857727035399414, 63.03685426712037, 67.87300725137034, 64.01077878090643, 64.80203851576775, 63.11377979093983, 68.66673807944022, 66.05619676651494, 73.44981747288858, 69.15078209292504, 76.52208451301821, 21.752268652762137, 3.0421138194299515, 2.527161038690998, 0.20552421439318888, 0.20846531786505254, 9.490762006851936, 76.77524997342017, 65.45418354772752, 56.988806570729906, 29.77309596153998, 24.71817474211416, 42.677085861083, 66.97134848563903, 67.60905527299451, 70.40423039467105, 7.030649963886508, 0.4596896800062349, 0.14518092416467207, 0.3202124642989328, 0.1430038708232103, 0.25381556261451016, 0.21782453742719468, 0.27161389949821657, 0.25971174300197636, 0.24584492338040184, 0.2825956473187093, 0.21405987411497102], [0.12518740063833614, 0.04920479315783709, 0.05844648717151535, 0.10594062131619263, 0.039120842928006765, 0.032529276870791955, 0.06458042294628198, 0.041778915216245, 0.04949121811096707, 0.02959216280179399, 0.2448707659758868, 25.969808947655466, 74.12572814572242, 55.01570140161822, 55.39729310620216, 22.251798183687274, 33.3701329846536, 53.81678189000776, 41.633005834394886, 59.19041725897021, 69.53348775063792, 7.55601957921059, 0.06979227997362614, 0.09756156528789191, 0.6157077452348125, 2.8082679933117283, 3.6945643059669004, 64.8033211308141, 69.88861130129906, 69.0584965675108, 60.730881075705256, 59.049168786694935, 51.84118993820683, 53.7074105201229, 52.72142079568679, 52.79788347982591, 51.342244840437374, 50.82459395931613, 48.73576318064044, 48.32521261707429, 47.73645700946931, 46.478333242477916, 45.02021174277029, 45.091665560199374, 42.50256784500615, 47.12114303342758, 45.8753433535176, 45.48050188249158, 47.506861071432795, 46.88857001643027, 46.00707615575483, 46.35989335275466, 44.217710494995124, 44.95583780350224, 46.40636167218609, 44.99790522360033, 43.99575533405427, 46.20843887329102, 44.18115400498913, 43.664577853295114, 44.81255754347771, 43.01919890988258, 45.41206044535483, 44.059144758409076, 43.584561501779866, 44.065640203414425, 43.32993299730363, 44.7641162718496, 43.513750953059045, 45.36700810155561, 45.727897536370065, 45.601973764358036, 44.28814057380923, 43.52801661337576, 42.79934613935409, 41.78778256139448, 46.05441131899434, 55.43475174134778, 56.80846383494716, 56.4200746628546, 57.101857123836396, 55.5408832334703, 55.99563106413811, 56.499247704782796, 58.326860397092766, 56.38265917378088, 55.98442877492597, 37.94319691196565, 27.06640951095089, 57.62834510495586, 52.17357550897906, 56.589795620210715, 55.17058011024229, 57.05048584168958, 52.44437202330559, 55.96642901820522, 56.07465113362959, 47.674962089907744, 43.666350764613, 42.66734661594514, 41.777109792155606, 44.23450216170281, 42.2366193802126, 42.749692855342744, 42.254764264629735, 44.819786471705285, 44.05641478876914, 44.30238662227508, 43.67164596434563, 43.23080685830886, 42.61924266815186, 42.67899213298675, 43.5335510776889, 44.53921541090935, 42.78422932470999, 45.10231479521721, 41.80145594381517, 42.89202390178558, 40.661336683457904, 44.112881229769805, 42.6397527417829, 44.048295482512444, 41.453533864790394, 43.48461166504891, 43.605420666356245, 41.925191033271055, 43.70837111626902, 45.28302231142598, 46.740818254409305, 54.8313460811492, 58.03343965161232, 60.252751996440274, 56.56382952966998, 58.512561090530895, 51.7599811861592, 51.23917279704925, 51.35676153244511, 54.60921049118043, 54.65869119090419, 53.840108225422526, 60.83665170977193, 57.62210853638188, 60.752273682625066, 57.76713425113309, 57.03108972118747, 59.25828995243196, 59.21979581156085, 64.76936909460252, 71.36910992283975, 53.4677380131137, 1.8080558772048645, 0.7422169309950645, 0.03672715141287735, 0.043126544314286405, 1.1630776284202453, 40.331567333590606, 60.242318491781916, 42.696611419800796, 39.669220216812626, 16.439197621037884, 35.85400919760428, 58.35749803050872, 53.60874329843829, 50.05893161219936, 7.3615322862902, 0.477068936151843, 0.039854437232978886, 0.02778785337033051, 0.03461857101008777, 0.04956274391001752, 0.042797486568170215, 0.0025364761794691966, 0.11582439660184807, 0.07074065851948916, 0.028393346283044067, 0.06651021374930298, 0.08300787123340754, 0.025982224352417455, 0.06375532326919418, 0.03377452214819289, 0.021935592803563324, 0.02727618516092339, 0.02388596838910974, 0.028036236312360536, 0.0461172673010057, 0.037689740889735764, 0.12077298751401326, 37.977686312890825, 83.016446944206, 61.155763979881044, 62.260122991377315, 29.79042695414636, 32.865926027297974, 37.06888883344589, 46.882733529613866, 66.0431666528025, 77.48752886249174, 8.252890417652747, 0.0869992046406673, 0.23537786407095773, 3.510775522839639, 2.992656653927219, 3.9085771576050794, 68.68270997078189, 71.87573894377678, 74.26974188896918, 64.98902182425222, 60.599509131523874, 53.732839245950025, 54.81839833721038, 53.788270181225194, 56.473363984015684, 54.21547120617282, 52.950648030927105, 51.1974544678965, 51.00789023983864, 49.88499802927817, 49.2461851335341, 46.70287716773249, 47.36127053537677, 45.81786886338265, 49.47074082589919, 49.15820637056905, 47.83504578375047, 49.3134145582876, 48.82855469180692, 47.257751341789, 48.467100435687655, 45.59886332481138, 46.37459831853067, 47.36600483617475, 48.964080426000784, 46.049033749488096, 48.30689514836958, 46.2099293739565, 44.878990727086226, 46.648418980260054, 44.59645848120413, 45.20863848347818, 46.58622195643764, 44.78490091139271, 46.19203159886022, 45.298437226203184, 46.78818087424002, 46.79551178409208, 46.78940465373378, 46.45231616112494, 46.61070146868306, 47.007743389375754, 45.38790648983371, 45.51631704453499, 43.413197071321555, 48.325345977660156, 57.663783719462735, 58.56394021741806, 58.93451006181779, 59.67521044515795, 57.14860000917989, 59.540245609898726, 57.43788265412854, 61.97308001979705, 57.464735200328214, 57.585803078066924, 39.0692780094762, 27.35963806029289, 57.84429903953307, 51.94012388106316, 57.189694681475245, 58.08681134254702, 57.715480558333866, 54.936022373937796, 56.47853759027297, 56.68169283097791, 49.368119855080884, 44.206268941202474, 45.38277210727815, 43.88847066510109, 46.248215629208474, 44.44419207111482, 43.7314268081419, 45.471492198205766, 46.55453705018567, 46.32443512639692, 45.77204773502965, 45.58830822667768, 45.196745857115715, 44.04680105947679, 46.401850946487926, 45.8511854756263, 46.55246211636452, 44.758883830039736, 45.756260195086085, 45.16416272809429, 44.77237286106233, 43.49621795838879, 45.846525699861594, 46.08564123030632, 46.417669865392874, 43.65530144783759, 45.209815194529874, 45.13533722969794, 45.18078181051439, 46.060463536170225, 46.27173808313186, 48.191742204850726, 57.04810104062481, 59.832772054979884, 61.52832246595814, 57.49294488660751, 58.85408186143445, 54.01679923457485, 53.54908797048754, 53.97732842353083, 57.6413320725964, 56.60683047386908, 57.332535636040475, 62.17470945850496, 59.715446118385564, 62.02189391659152, 61.36091962937386, 60.09298209221133, 60.667221007808564, 62.29616172852055, 67.57341661760884, 72.48189418546616, 58.52836039758498, 2.2122949794415505, 0.37196786293099005, 0.25583340756354794, 0.08060526628527911, 0.6535837450815786, 43.48842813122658, 68.99128283223799, 42.57156625870736, 28.710818098437404, 22.501276616127264, 39.409637758808756, 63.98012545800979, 58.52196693420411, 61.09029962170509, 14.575745251870925, 0.6856211130657505, 0.06532230249215519, 0.048609259388139175, 0.02156170933777767, 0.012765776031770775, 0.01093545216961854, 0.08637044563769333, 0.03049432517840497, 0.09749086303336006, 0.027987976603570486, 0.09137735882353398, 0.169413848029029, 0.2093470544223824, 0.14291875845482274, 0.2302534406584117, 0.1479525230224094, 0.10242328949032292, 0.1239027631198687, 0.15259029674193553, 0.18002833329862167, 0.12679439263358233, 0.3512246840663495, 46.58479813606509, 93.0693091115644, 69.32965001752301, 72.3771982808267, 33.17378305619763, 47.28667097706949, 68.64335290847286, 57.04710868097121, 71.97400216133364, 85.43784372268185, 9.599400874107115, 0.23289851243457488, 0.3579705172488767, 5.512548560096372, 12.951081875831852, 5.3691976974087385, 72.36722761584868, 72.77048649326449, 75.27118575188422, 65.75638255765362, 64.52906508599558, 55.587516292448974, 59.130805077091345, 57.133914655254735, 59.575848963952836, 56.650592357881614, 56.26684727207307, 54.752714326304776, 53.46933049540366, 54.2140434634301, 52.30264109949912, 50.114511597541075, 49.07417351199735, 47.59272567687496, 53.35097297545403, 50.59117763273178, 48.440804866052446, 51.172896508247625, 50.68462810208721, 50.44699130519744, 50.18887973600819, 46.388895357808764, 49.682874371928555, 51.12128596152029, 51.658995843702755, 48.01998945974535, 50.45446734274588, 48.391971357407115, 46.94984528326219, 49.422832996614524, 46.7769903521384, 49.07556595340852, 49.60350128912157, 47.169105775894664, 49.218524579078924, 46.385663324786776, 48.333124037711855, 46.976078094974646, 50.81596866730721, 49.11046328083162, 50.72891558370283, 48.88369537168934, 48.57163944552022, 47.09890319455055, 45.828769130091516, 51.24674297148182, 60.50949858080957, 61.65263806619952, 61.57520263425766, 61.55093493000154, 59.82109908134707, 61.78312355472196, 61.9318009961036, 61.87596997907085, 60.37185084435248, 58.81221055984498, 44.12857463282924, 30.848760874040668, 59.03645246259628, 54.607684689183394, 59.44220596744169, 59.81079893727457, 60.04884366066226, 57.48719076956473, 59.53624086995279, 61.609923455023, 52.85955098367507, 47.571274234402566, 46.678652609548266, 47.43883932790449, 49.21886974765409, 47.740387224381976, 47.00495850655341, 47.802505800800944, 49.6034267640883, 48.124712820976015, 46.789600772242395, 49.91018749052479, 48.70116003098027, 46.46933140293245, 49.174362613308816, 48.09080785320651, 49.663580233050936, 46.768721995815156, 49.0869604387591, 47.421271031902684, 46.19497337648946, 47.11475741478705, 49.37302674016645, 47.89365383886522, 50.16838142948766, 45.13733763848582, 48.64314425376154, 47.50484105079405, 47.50384084640011, 48.85197124173565, 50.11643355892551, 51.93222422753611, 62.15149294945502, 63.599945806687884, 64.30649411293768, 61.204966191322576, 63.40820858555456, 58.60541535962013, 56.5429429085024, 55.779779111185384, 60.57228396015783, 59.43248241178451, 60.24855113798573, 63.0012156117347, 63.67835006406231, 66.72249763242661, 64.56338582500335, 61.55860316368842, 65.46791184333064, 65.08823425539079, 71.29167449089789, 76.51565182593562, 63.23146266321983, 2.8789243438551506, 3.5554444549545168, 0.5104887251171374, 0.15317165022415502, 1.5685228594849188, 49.188502757780014, 70.10394942375922, 58.02424561592841, 52.99736738204957, 27.58246594859708, 45.999278483852265, 72.74226896224484, 67.7724455248925, 75.0758203383415, 21.10693873897676, 1.1041720860427426, 0.20393539400350666, 0.22112507403137224, 0.15779909707846182, 0.0992187437030577, 0.1131802058267978, 0.15684073640694543, 0.1274589509252579, 0.2292031187924647, 0.07090602625882433, 0.18488300183127004], [0.07410177735671883, 0.04429177936887549, 0.051128432274826115, 0.05658346093109539, 0.08695828022375222, 0.023987107316873247, 0.07438552866299307, 0.043908034436284535, 0.10778500863741483, 0.04602910590267951, 0.2397093558383565, 48.70146205348354, 73.24405777838923, 47.65878231294694, 30.986357619685513, 18.491980837237453, 55.86456114246, 58.93332158365558, 44.95319020363593, 69.69934909574448, 52.13626592389999, 1.7860108085217017, 0.05490091351431705, 0.16212954696628357, 2.225736696873942, 2.3997771643823196, 15.090992700669075, 87.32579815772273, 64.2161972292008, 70.51561786282447, 55.067311948345555, 55.590920909758545, 49.85920060065485, 52.254670512291696, 49.571216260233236, 51.05627267591415, 47.476427401265795, 51.73033983476701, 47.98186009930026, 47.366891291833696, 45.77846865500174, 47.45674102537094, 46.107049526706824, 46.0335325425671, 44.10729577464443, 43.65998868019351, 44.41558230307795, 45.042671234376975, 45.78549754235053, 47.01713354356828, 45.53835684253324, 45.96922136122181, 44.140071099804295, 44.62345615510018, 45.834456566841375, 45.03366155009116, 44.30946650043611, 43.237310148054554, 44.30442233239451, 43.688304270467455, 44.44974222490865, 42.32517473159298, 43.13912145553097, 42.26667650284306, 43.29222725283715, 43.18122809933078, 42.9072230862033, 43.64426389817269, 45.21079970944313, 44.99179417087186, 43.012597560882575, 44.62170677800333, 44.22756348886798, 43.73043837085847, 44.448906760061945, 42.34691250708796, 45.26738382154896, 54.71911530340872, 54.650042364674235, 56.63282009863085, 56.52719459226055, 54.85730824931976, 53.82266152289606, 53.36318723617062, 57.52648115158082, 52.383567440894346, 59.65221358883766, 37.85673610625729, 26.109178604618197, 61.467396290071555, 53.02985245181669, 60.52987921622492, 53.891738384000725, 57.66138715128745, 53.57376752361175, 54.84477627661921, 52.89679781083138, 46.12771649514475, 41.71793691573605, 45.089135631438225, 41.597225973683024, 42.06074422405612, 42.66366743272351, 42.407799459272816, 42.63241006482033, 44.57642301436394, 43.92040268067391, 44.097050543754335, 44.39781788856753, 43.82726207856209, 43.22257380331717, 43.914060208105276, 42.700608315006384, 42.996304035186775, 44.09955301592427, 43.2853631050356, 41.873651089206824, 41.487066207393525, 41.110714789359804, 42.799452043348744, 41.4034765766513, 42.72984173990066, 42.585886832206484, 44.12148298755769, 42.5306284812189, 42.609060195184526, 43.26285262261668, 42.96820025290213, 43.728810587236964, 45.01387319257183, 47.94709613246303, 49.018848480716834, 49.772794708128906, 46.91119816995437, 47.38797795388007, 49.08273996845369, 51.572354608966464, 52.58636182354343, 56.45151638215589, 53.74450437484249, 57.42773940486293, 62.3699297443513, 55.99240295348629, 58.27779154623709, 54.32572903171663, 57.0325880665933, 57.136193552324855, 66.40023569906911, 64.55250124777517, 73.13089739891791, 15.472852107017273, 1.0030064371324356, 0.4719791399134744, 0.0566019504631479, 0.02232480568871383, 26.864842830165742, 69.69284580599877, 49.1449369922761, 60.65326913710564, 20.94720413607936, 21.62679791450501, 44.93331947634297, 52.545184781474454, 48.83797230259065, 22.7239554543649, 1.0139630266254949, 0.09272016539809205, 0.034598664215375344, 0.06316447412715324, 0.0948828086256981, 0.0236397841194224, 0.024838786414493958, 0.09725568936236444, 0.03986040122746941, 0.11931558184686208, 0.016766207690741268, 0.10682741405382272, 0.027700760664658684, 0.031839929889106465, 0.013399964682908069, 0.04327419243993298, 0.0070926699141461045, 0.02963659973184188, 0.027420410788768244, 0.06360841441839453, 0.13931285920402697, 0.7480623044313923, 60.09176615745791, 78.23368134037142, 55.39876007264661, 43.08220394196049, 29.29150539059793, 48.88685680204823, 51.437836923906886, 50.72411068024174, 76.62765902857628, 57.60241039337651, 1.8257152457391064, 0.1206526351011088, 0.45416802468319095, 3.930234524511522, 1.3867233309053606, 17.55297718509551, 87.70036881969821, 66.8979452502343, 72.20454339058169, 59.08289332543651, 59.64405505887924, 52.29812645143079, 55.678668252883426, 52.42471310400194, 54.04303596865747, 51.24300103033743, 54.168524357580374, 51.008521741436375, 49.4477871156508, 47.629697938119214, 49.12303839960406, 48.20496059233143, 46.788906512721894, 46.164363199664706, 46.565288266827984, 46.64456329038067, 46.72819214482462, 48.00154647519512, 50.33512923025316, 47.093709976442405, 47.951069493447584, 46.36656530441777, 48.2362061931241, 47.23468388280561, 46.60433153952322, 46.60615151928317, 45.5263190884744, 44.48173699840423, 44.13981222337292, 45.19354520305511, 44.53074309133714, 45.082055753277196, 44.65233656667894, 45.33320119304042, 44.422148350746404, 45.54842948913575, 44.62304038386191, 47.63395370975618, 46.46936278189383, 45.51185730964907, 47.04706515035322, 45.88782041303573, 45.96323974670903, 45.7155381479571, 45.114807544216035, 46.173388573431204, 55.027323384438795, 57.33524991619972, 57.11706807536464, 59.561536235194055, 55.626132026795425, 56.266608007492565, 54.72908989075692, 59.33819255521221, 56.47226572036744, 61.93623719676849, 39.20136774739912, 27.397845868141424, 63.3956923023347, 55.16766971157443, 61.704491799877545, 54.886141592456454, 58.93891096115113, 53.88287382741129, 56.969873289908136, 55.74266956698511, 48.35401458124961, 44.446176790422015, 45.584024998449514, 43.818256316646455, 43.792937417184156, 44.41482920800486, 44.70147994256789, 41.85458837016937, 46.888456267695275, 47.176915214907744, 45.997584019937825, 44.74698335893693, 45.48238069780412, 44.30438310869279, 44.84981613774454, 44.60696258852559, 44.97017014411188, 46.563236867227864, 46.11341945586666, 44.97620667180708, 43.87059250185567, 44.30458707194175, 46.385008288967995, 43.027577092570645, 43.61060211735387, 44.606970433265936, 47.099503317186915, 44.2748398165549, 45.59388975943289, 44.72020533777053, 44.70535916666831, 46.69771532858572, 47.55894622495098, 48.68644722046391, 52.02701614749048, 51.468894250931285, 49.67526889616444, 48.143967736151914, 51.37450633510467, 53.18717871942828, 56.542303562164314, 58.40852806645056, 58.67822631712883, 58.37930248629663, 64.92005871188256, 59.32852783510762, 60.54355259864562, 55.87698328879572, 60.908482074737556, 58.680591506342736, 69.6978429055983, 65.69598197937012, 76.89237979150589, 17.871607003673432, 0.5161933528800164, 0.3050758539428634, 0.12875583052875536, 0.13546774133799538, 28.23595831471105, 75.83410862953433, 51.35070931526923, 49.006900941171956, 24.368964164487778, 30.862206758991366, 50.72846058876284, 59.699540907336825, 59.78432293861144, 34.71924789490239, 1.171642613987769, 0.0817428149222847, 0.04386404949811198, 0.041686241560044794, 0.031901216923048904, 0.02588300255968446, 0.009350606818653403, 0.05480461626223499, 0.06322133700333296, 0.04411648696048125, 0.07580404770710776, 0.18984259376602788, 0.15314411702415637, 0.1381332370182199, 0.12559783990464865, 0.15798495000889226, 0.1024499876544841, 0.11530378623114479, 0.149982318943066, 0.25944407188123275, 0.275440018383726, 1.6172090341006558, 73.01347732543945, 89.70848114259782, 67.41630215798655, 45.77120834781278, 27.38258392580094, 69.08425869480257, 74.4864449962493, 59.21833668985675, 81.58838256712883, 64.53656858013522, 2.551409866540663, 0.18552219495177272, 0.5000335861357951, 9.932838620678071, 6.698276650521064, 18.290641653922297, 92.21121218896683, 71.26410022858651, 73.8907781724007, 61.66047103943364, 62.44280345978276, 55.1354552853492, 57.51942088527065, 54.75636213056503, 56.51116778773647, 54.7664543890184, 59.1172807447372, 55.02540534542453, 53.43135802976547, 50.69932130075271, 51.377973710336995, 52.05273512871035, 50.394125600014966, 50.10325439514653, 49.530196112971154, 48.03650656054097, 48.223140778080115, 49.31381856241534, 51.53376633121122, 48.683321091436575, 50.15252328688099, 47.283548770412324, 50.18977795877765, 48.85319894359958, 49.13385237416914, 47.64555608072589, 46.7950410996714, 47.770856195880526, 47.167878074030725, 48.140974967710434, 45.673254997499534, 46.18016642908896, 47.01905942732289, 47.160813885350386, 45.88160737868279, 47.91042981609222, 47.24554492581276, 50.474530266177275, 49.187573156049176, 47.43318719248618, 48.706655271591686, 47.34905627466018, 48.26506307048183, 49.47520448315529, 46.88307869818903, 47.669043233317716, 58.51742482954457, 58.871607011364354, 59.70878985620315, 60.44546196537634, 59.13434697735695, 57.59176900309902, 58.562406570680686, 62.04204705453689, 57.38344800087714, 63.38338390473397, 42.20970407609017, 30.618074517096247, 65.12681076603552, 59.345311657074966, 65.30691815960792, 57.10286125060051, 62.91587268152545, 56.6028884918459, 59.19449652394941, 58.17224840964041, 51.96251277000674, 47.48817097756171, 50.28282442400533, 45.45441812084567, 45.92554576935307, 48.23686515131305, 47.7388810342358, 43.83516173208914, 49.386158835503366, 47.850621515704745, 47.83022911317887, 48.660626257619555, 49.472341152929495, 46.011735931519546, 48.07303951632593, 46.86416502921812, 48.50921884659798, 49.44794008808751, 48.05668715507754, 46.058733770924235, 46.51068887402935, 45.977850575600904, 47.750036255005874, 46.973693293909875, 47.04448030840966, 46.70998450248472, 49.7666169751075, 47.251687357502604, 46.78445462257632, 47.173310556719386, 47.79555928322577, 49.77887045952582, 50.93821325609761, 51.443885218712595, 55.564072285929036, 55.91469687800254, 52.8724830381332, 51.88866238440237, 53.68621010934153, 56.28290937792871, 60.23192028845511, 61.36302986452657, 62.0294915476153, 62.39628807190926, 65.41532462643039, 62.42652562356765, 63.83504090770599, 57.9145839906508, 63.65354499509258, 62.631736186242875, 73.33226403882428, 71.40065362376552, 80.65655293003206, 18.704406599844656, 2.8276521015551785, 1.6763743109280065, 0.31675422083466287, 0.2419152447292882, 34.18531525519587, 81.13427408279912, 64.47477948281073, 75.83245338932161, 31.272971091731904, 34.78399838170698, 58.20452951615857, 68.96343400401454, 71.17133617401123, 45.25846827414728, 1.8693626455722319, 0.1312372046372583, 0.15723602245411566, 0.15718823388939904, 0.250769566384054, 0.14267385546718875, 0.15876295826127454, 0.3187497573033456, 0.171575763473107, 0.2105954100167559, 0.2364546312920509], [0.02302391071533484, 0.024098969560356873, 0.018475485830417564, 0.04928294944787218, 0.0761453015729785, 0.005818140447034591, 0.032718787871060834, 0.05878595605252251, 0.08895740198392062, 0.19170259395914693, 2.229334490914499, 59.09993602383522, 60.09666127543296, 55.96705659743279, 30.40323453564798, 14.88624890004435, 57.20462322235108, 48.7609604866274, 46.8103854117855, 74.91276741027832, 37.55062257089923, 0.1788007999740301, 0.07375457098767643, 0.15682909187049637, 1.95578949826379, 0.9179553557788173, 41.70871542346093, 76.31032359215521, 63.82761978333997, 66.60390084789645, 57.41587423509168, 60.456448524228996, 55.56926942640736, 54.123130767576164, 51.5564376308072, 49.90527276069888, 48.79194328861852, 51.102258543814386, 46.06804155534314, 46.27460925809799, 44.43411942451231, 44.58408732568064, 45.85187189040646, 46.945526753702474, 45.11279536831764, 45.76803515034337, 45.264630317687995, 44.730026952682, 45.76928246405817, 44.79922148489183, 43.457555155600275, 42.563956860573064, 43.31053687680153, 44.19246219819592, 44.44656510506907, 45.60760236555531, 43.741879924651116, 43.8820928912009, 43.564451509906405, 44.049076034176736, 41.72065511826546, 44.42851435753607, 42.26557431682464, 43.61088845037645, 42.77234454308787, 45.03040598284814, 42.0535780537513, 43.64358925050305, 43.15728595179897, 43.14414208935153, 44.53674824007096, 43.030518870199884, 43.118485866054414, 42.376871570464104, 41.849010759784335, 44.199475396064024, 45.69296882998559, 51.507533519498764, 55.39113106266145, 55.22810559118948, 55.885408539925855, 53.91319374884329, 53.05181772478166, 51.736348905871, 54.81002407689249, 53.96573389730146, 61.36901540140952, 49.03059205701275, 33.9507104504493, 61.7993700119757, 51.779977429297666, 56.58413564005206, 54.024914618461366, 55.635686920535186, 53.587236942783484, 56.097440104330744, 49.43300762484151, 43.57344550471152, 42.90632094106367, 43.38099048983666, 43.68902990894933, 43.50915785758726, 40.633597681599284, 43.37281627039756, 41.68489879177463, 43.907576530210434, 43.878111685476, 45.60407223240022, 42.936460433467744, 43.14387536817982, 42.815102300336285, 42.255729167692124, 43.68715893837714, 42.46592898522654, 42.60607919385357, 43.04592986260691, 42.51138141078334, 43.84299078295308, 42.38677555514921, 42.036904058148785, 39.19856325272591, 44.48587509893602, 41.53547610006025, 41.41770301326629, 42.02116750901745, 42.58139571835918, 44.260731051045084, 46.26039458859352, 46.183653416172156, 43.55182540032172, 42.50204616977323, 41.81205811039094, 43.11018220839962, 44.285457672611365, 46.02442087665681, 47.834076958317915, 49.688734392966, 49.373289538967995, 53.41198152111423, 55.70369689695297, 49.86610397215813, 59.12517647589407, 60.27668629923175, 57.95348213564966, 57.086559880164366, 56.044468495153616, 55.9261501989057, 60.54892232341152, 65.56082887034263, 71.26279015694895, 44.172501256389005, 0.30846554785966873, 0.4106721876850052, 0.045169877008565014, 0.06368911795077786, 10.585142508629831, 59.75596420226559, 51.98712956520819, 43.43832769701558, 31.660983716287923, 18.827184630978493, 42.55260159892421, 58.67667698091077, 51.61383367353871, 35.15087727577456, 3.2418847901205865, 0.23283495778037658, 0.035002921152138905, 0.07295474455121063, 0.029497047240335136, 0.04831164955131469, 0.06487652358989562, 0.03162040164874446, 0.061507207611876155, 0.04277405959944572, 0.03908525814392394, 0.032934100712619485, 0.02762159122334373, 0.007807157986286668, 0.06127177347098628, 0.0682771265987427, 0.041064886796859004, 0.15401368810524865, 0.029474033959089752, 0.030855200471236344, 0.13639607136287998, 3.214180109000975, 72.78749389033165, 66.46393499066754, 64.16780694838494, 33.46491313749744, 21.489052118793612, 56.903518553703066, 49.935251435925885, 54.65037576613888, 81.17792221807665, 39.60033947421659, 0.09457511707179009, 0.052037104483573675, 1.506045386195183, 3.745859347043499, 0.5286509231213601, 44.09918431312808, 78.7480531200286, 65.65174156619658, 68.66023478969451, 59.07014954474665, 63.17919315830354, 56.81664589912661, 57.06900335127308, 53.56405181269492, 53.15089679533436, 51.29838097480036, 54.08680961978052, 48.76625176398985, 49.06813698430216, 46.56445672435146, 47.811095791478316, 47.5004558409414, 47.882890855112386, 47.15504407882691, 47.413955811531316, 47.11926814048521, 47.858627073226444, 47.604630070347945, 48.068199311533284, 45.35385639436784, 45.11902801452145, 46.911935575546764, 45.65390202306932, 46.9836639588879, 47.6663250307883, 46.097580925110854, 46.4561757733745, 44.0993215960841, 45.34767866134644, 43.04771454103532, 45.9415804186175, 42.84988980139456, 45.90631438839821, 45.1345213767021, 46.33558250242665, 45.037234829318145, 44.81284387650029, 45.37650023737262, 44.69594547825475, 45.7449088558074, 44.76510470913303, 44.924702029074396, 44.424960690159956, 44.704331505683164, 46.099040046814956, 47.501581561180856, 53.06716595926593, 58.864774242524184, 57.91929083485758, 56.281924863015455, 55.285866414347005, 54.7738362896827, 54.72404180034515, 58.68706733949723, 56.59101155496413, 62.55756416628438, 50.10251698955413, 35.77404775927144, 62.85634286942021, 53.63307768298734, 58.39886726871614, 55.67723266540035, 58.89860468526041, 56.21208706209737, 56.90396962627288, 52.15798800991428, 45.48458506984096, 44.21540806370397, 46.23956680297852, 45.78141435500115, 45.733302562467514, 43.701518735577984, 44.43391938363352, 44.952268446645434, 45.36024985774871, 46.9562622808641, 47.8486720977291, 44.91317810550813, 46.51544278667819, 44.02296481593963, 45.242865085601814, 44.687771258815644, 44.35531900775048, 44.786289430433705, 44.705845540569676, 44.69727516174317, 46.579032251911784, 45.67831485502182, 43.60678957354638, 42.743271935370664, 45.60251112907164, 43.538905112974106, 44.339570691508634, 43.3639124901064, 44.89114222988006, 46.339493105488444, 45.96074511927944, 48.35661511267386, 44.65294453405565, 44.09791738756242, 44.9803683065599, 45.18744983980733, 46.87626554119972, 48.31897604850031, 49.04986266166934, 51.79865183368806, 52.54854233034196, 57.33750135667863, 58.34962583357289, 52.11586959900395, 58.796458321232954, 62.44415667749221, 60.5645098224763, 59.10725908894693, 59.23750139051869, 57.65518588404502, 62.81484419299711, 67.1229402480587, 73.25625634962513, 49.82953571504163, 0.510369950845357, 0.8530696697773472, 0.2490148266717311, 0.040708184767995155, 11.109315310755084, 64.6837398313707, 60.99250708856891, 44.513194407186205, 34.021458241247366, 29.262105264971336, 50.67301004163681, 66.22695322959655, 59.45573814453618, 52.51174265338529, 5.459198932493887, 0.32063742859228966, 0.04176445913711383, 0.0316574554064221, 0.0578698834344264, 0.01729252541648044, 0.07407245151097737, 0.01952626351867953, 0.013884636911473448, 0.05588402648666694, 0.07323455050467484, 0.10004518403401298, 0.15102344775392165, 0.24403623575645111, 0.12140334764074896, 0.26273999663610614, 0.10263532730600528, 0.21191018543416457, 0.21924587567487072, 0.32514619310536697, 0.42277129006481945, 5.58087722909066, 85.61682147364463, 73.10258573101413, 75.84622875336679, 42.31701227926439, 22.54104356611929, 69.31247003616826, 59.956891536712654, 61.4158171223056, 86.24470664608864, 46.30092051721389, 0.3687896399248031, 0.2619158086036482, 2.3944579401323876, 10.980656666140403, 2.772330257200426, 46.90102746409755, 83.16918403871598, 69.97447198437106, 73.24590129237022, 61.67227737365231, 66.41073196165024, 60.53251897135089, 59.84484511037027, 57.1985278591033, 56.14880746410739, 54.42432565073813, 58.116013388479914, 50.7264405681241, 51.14149009027789, 50.7146381562756, 50.9345026939146, 51.72435037551388, 51.266613698774776, 49.76287503396311, 49.51835055505076, 48.980071929193315, 50.05177328663488, 50.9944208206669, 49.92020914631505, 47.844828174960234, 46.35030315768334, 47.54596317968061, 47.26105397747409, 49.061629772186286, 50.32087925941714, 47.47218339673935, 48.36532669682657, 46.773605346679695, 48.07998995627127, 44.681420941506666, 48.96905791374945, 45.06631920414586, 49.60416809205086, 47.87799573713734, 49.15873196817214, 46.95893733732162, 47.58531631961946, 47.17025503035515, 47.7344605230516, 47.66198688937772, 46.93586595596806, 46.11017957810433, 47.43783520114037, 46.111987790753766, 49.36612729103335, 49.64307800416024, 53.89442128519858, 61.98577280967467, 62.1004472240325, 59.977017218066806, 57.2537273745383, 56.65405973311394, 56.68898059475807, 59.24954698931787, 61.46279534985943, 67.18711806881812, 52.09522224241688, 39.331268802765884, 65.16564223074144, 56.829409291667325, 60.9108276521006, 58.69301365267847, 60.33027764289611, 58.79507372456213, 61.88009631249213, 55.066507862460234, 46.95430109577794, 47.322874453759965, 48.53578505977508, 48.10099032617385, 49.63757884117865, 46.17561255731891, 48.2073728499874, 46.490496512382265, 48.79013899833926, 49.66703584117275, 50.70450667412051, 47.67473851480792, 48.03957385401572, 47.868432998657234, 46.75040844948062, 47.20762737335698, 47.0837785351661, 47.17337331464214, 49.06894107018748, 47.35075858331496, 49.017848276322894, 47.83892108548073, 47.0537841704584, 44.62534281515306, 48.88314623986521, 46.03958083737282, 47.39046865893949, 47.045378531179125, 46.42973899841309, 48.81346925612419, 50.58928312793855, 50.77008870340163, 47.56689294692009, 46.15884442483225, 47.98304073272213, 49.08588570933188, 49.77705440213604, 52.25455284118653, 51.55098553626768, 55.24476781968148, 54.36532535860616, 59.91334930542977, 62.073802563451956, 56.7946296353494, 64.23105124504336, 64.98406787072459, 63.96478506826586, 62.574061655229144, 62.20012249485139, 62.015877000747196, 66.65837472484958, 71.64519771452873, 76.06648552802302, 51.670570758081254, 0.48187607658966897, 3.5898431510694566, 0.584833727728936, 0.1871648406790149, 15.329289436340334, 72.68443753642421, 66.90586059324204, 58.78524034254013, 43.824371291745095, 31.134438860800962, 58.80935507435953, 76.73945442322763, 71.43650408714049, 65.00830811838951, 7.655432541524211, 0.631869565094671, 0.20731552714301696, 0.19051727207918323, 0.2145974839767141, 0.18826765488953362, 0.24183719569156248, 0.07843457913446812, 0.1329420260604351, 0.18380807322119513, 0.15892544551001442], [0.05748480167840758, 0.02952707022608769, 0.08370360164272209, 0.01360364830977614, 0.028177261607901707, 0.07259747944772243, 0.09537805382522846, 0.022436143161969322, 0.1805189206835724, 0.16901269374835878, 4.786807606297155, 61.578038507892245, 62.08089028635333, 51.96945144284157, 37.49818440406553, 30.881389110319077, 48.5248730259557, 57.915905829398866, 51.80337436737553, 77.51120428885184, 18.24521472377162, 0.07421428502927865, 0.1027712083211349, 0.7084301246270057, 2.296765427435598, 1.0244292585599808, 64.77768451936784, 68.98070812225342, 70.6862880337623, 63.10085165885187, 64.22192781202256, 62.80697591843144, 60.429246887083984, 56.740038087291104, 54.491425637275945, 52.72984996918709, 50.86302141989432, 47.99112081527711, 49.541731803647934, 46.478392078030495, 44.660812808621316, 44.53403395991172, 46.01089654430267, 44.628610149506606, 43.523160719102435, 43.687594321466264, 44.40377596885928, 43.019626448231364, 44.943317597912205, 45.00936246687367, 45.105032997746626, 44.45946578056582, 45.55796869339482, 45.259535158834154, 43.49825366850823, 43.067832377649125, 44.235878913633286, 43.188672757917836, 43.924834958968624, 41.24298495631064, 43.33790325349377, 42.141180269179806, 43.25143068067489, 42.89909593520626, 44.44724367510888, 44.215251168897076, 42.860809679954286, 43.22904963647166, 43.57704624052971, 43.64391872959752, 43.220655764302904, 42.608063913160755, 42.19517169460174, 43.08798943796466, 42.38419071320565, 43.23983615444553, 43.839594010383856, 49.13822581691127, 52.12137268435571, 52.94394470030262, 55.23517370224, 51.41246311126217, 51.04612550427837, 48.96348030336442, 53.9681932233995, 54.56361293792725, 55.874210173083895, 52.81309050898398, 44.03910536919871, 56.77372340233096, 53.728422657136, 50.84011477808799, 48.98797550509053, 49.415200064259196, 49.94716759650938, 47.83669317922285, 43.36728180608442, 45.57823558007517, 44.210387429883404, 44.45185638243153, 43.51340578448388, 43.167868506523874, 41.51287148075719, 42.31766731508317, 41.98751357293899, 42.685883737379505, 44.25320010031424, 43.990562115946126, 44.00814610142862, 42.25481917781215, 42.35509457126741, 42.721698899422925, 42.38226482945104, 40.755842270389685, 42.596226199980705, 42.33821269004576, 42.77056378702964, 41.65634001455, 43.86483446244271, 40.65621014564268, 40.73102543430944, 41.59175818966281, 39.64249710882864, 41.46241803323069, 41.55164803228071, 45.23146667788106, 43.84173562449794, 44.29628733665713, 43.302970624739125, 42.485654584823116, 43.2756866178205, 43.258020262564386, 44.98432597806377, 45.223006125419374, 45.56903762202109, 46.29909661508376, 46.30385837247295, 48.28542409404632, 49.27525381888113, 54.864941181675086, 57.26054053152762, 52.477527818372174, 54.57677248985537, 57.37947071752241, 55.910268522078, 54.40418035753312, 55.70153174861785, 55.883910194520034, 65.68604269335347, 64.97780776792958, 63.247497312484256, 4.990964031988575, 0.7194638132087646, 0.16492924592908353, 0.06957945308738178, 1.9832039239906498, 48.11047461725051, 61.134900892934496, 45.18122896071404, 29.2616286969954, 16.6615891456604, 43.74459420481036, 47.377732722989975, 47.66061405981741, 46.65741689743535, 7.290758509789744, 0.6916249134848196, 0.08254382879503312, 0.07137972140504469, 0.06838650863257147, 0.08753244780124196, 0.02333908311782345, 0.08582134445708606, 0.03875446137821963, 0.06839790802088476, 0.05148870044297749, 0.05134494787442589, 0.03022098883746132, 0.16377496593181165, 0.038516633212566376, 0.08161076434677647, 0.056224161864168225, 0.09364129419648841, 0.05398846832254241, 0.16478177400365954, 0.21356711104031534, 8.626934501432604, 75.01864787070983, 68.74948440059539, 60.4788766368743, 38.04176999676613, 31.54897455246218, 49.92188007600846, 60.86730895503875, 58.536330653775124, 82.951414046749, 19.12330004476732, 0.19615944835447496, 0.07771024300206093, 1.7955677860206174, 3.1470127067258282, 1.5089882669910308, 67.22350197453653, 72.2023468632852, 72.22233526168331, 65.78948343953779, 66.29054269483014, 65.80981700651108, 62.63982019116802, 59.57825729923864, 57.05380416685536, 56.40972745034003, 53.63974571228028, 51.81336072183425, 51.17306517016504, 47.73513124835107, 46.625830050437685, 47.47356407104, 47.69543293983706, 45.863156549392215, 45.74357132757864, 46.85986218913909, 47.162794682287405, 44.64549203072825, 46.91292401283018, 46.413374870054184, 46.87661070977488, 45.766493658865656, 45.09931810440556, 46.91733275690387, 46.01115934310421, 45.36615302485805, 46.6169301925167, 44.37642528164772, 46.26720382321266, 42.88721115358415, 44.84091627982355, 44.7567069145941, 45.72336719882104, 44.30743079031668, 46.151258560919, 45.96734254590927, 45.03260643251481, 45.132673940350934, 44.53052736097767, 44.884482045327466, 44.57820377042217, 44.94532585144044, 44.34442266341179, 45.85644929639755, 44.37065155275407, 45.504902947333555, 45.04790759855702, 51.38092333270658, 56.388891819984686, 54.77499338888354, 55.89426525177495, 51.75463499561433, 54.69353752751505, 49.844432876956084, 56.873712462763635, 57.35637972431799, 57.199606510900686, 55.013430349288456, 44.47834807057535, 59.128777211712254, 56.60021343538838, 52.25559226928219, 51.14848367629513, 52.62172591301703, 52.224009344654704, 49.530105898457194, 46.62521031595046, 46.89030370404644, 46.380050413070194, 47.63796629444246, 45.52787234706264, 45.9360263424535, 43.70946153517693, 44.74203332777947, 46.16691274027671, 45.13713367523686, 45.73006660707536, 44.95033471815048, 44.89306419126449, 43.8176405045294, 44.378610041833696, 45.66898745875205, 44.159753553328976, 43.64456199830578, 44.75896227744318, 44.56733096030451, 44.960450510824884, 42.84317470365956, 45.877406520228234, 41.572369913901056, 43.9662669550988, 43.79727948096491, 42.20416176703669, 44.29074502760365, 43.6046048133604, 46.184586940273164, 45.58691578526651, 45.79509950453236, 45.54942969352969, 43.77870313582882, 45.89256255857406, 45.18794798081921, 48.27738323519307, 46.48622897363479, 47.31246840569281, 48.087167893686605, 49.11615856232182, 51.43191414494669, 52.93489971468526, 55.72398339548419, 59.565454682996204, 55.56546472734021, 57.020546390164284, 58.86683348686465, 59.459311423763154, 55.873872849249075, 57.963703832318714, 59.90628511674943, 69.35224286971554, 66.8679234289354, 66.87360302094491, 6.559100170289317, 0.8574684240644979, 0.1298505395290352, 0.07687810297694898, 1.6242553269670856, 52.05884618143882, 68.17769696635585, 50.13914015985305, 27.30427968886591, 25.151326002613192, 53.88830631009994, 55.636793028923776, 56.16204154106879, 61.392675138288936, 13.78908351544411, 1.0142043136781262, 0.08141819282525009, 0.03845602799687655, 0.03814855094758734, 0.02789662444903966, 0.02308708232557101, 0.11596960856789544, 0.048506346966830954, 0.06428282843121598, 0.010013215416561692, 0.10473587144646915, 0.09680487726244236, 0.23022940081934776, 0.1631547105047972, 0.18273305268056933, 0.1407637224803048, 0.18717510625720027, 0.1956521908962919, 0.38820377881488494, 0.7275473278376364, 11.606767946673978, 86.46077432940083, 77.87010115961876, 70.63718780394524, 49.722576602812744, 46.974960219475534, 59.716869938758116, 74.01833365040441, 61.82390051503336, 89.3889727131013, 22.058684210623465, 0.3201828626615386, 0.1855477363231682, 4.730479919141339, 12.179316320726949, 1.6826901849239104, 72.48757377747567, 72.86095988365912, 78.35467861544701, 66.80847598660377, 70.42888641357422, 67.95020734110187, 64.57924004523986, 62.252439068209746, 59.426559632824315, 59.11059702596357, 57.34216505481351, 54.53085330224807, 55.14814807522682, 50.08738056305916, 48.53967212861585, 49.273822153768236, 50.63214286681145, 48.03260772458969, 47.51287798727713, 48.61482474111742, 49.30434211607903, 47.0822762673901, 49.10973764234974, 47.715503708008804, 48.94440581721645, 48.49573766031573, 48.308770041311945, 50.332411027723744, 49.52183754213395, 47.1919535821484, 49.329323691706506, 47.62166884637649, 48.334496867272165, 43.745888586967226, 47.48199716691048, 46.15815408768193, 48.11971572137649, 45.90425514405774, 49.57435807874126, 47.76443527590844, 49.028572036374, 47.94760211821526, 48.13940601964151, 48.18187744386735, 47.62790149258029, 46.786298136557306, 47.33519461847121, 48.349703896430235, 46.94367539498114, 49.08195157204905, 48.414760328108265, 54.263653601369555, 57.88751571409164, 58.32614260335123, 60.01928075667351, 55.74249306032735, 56.90154560150639, 52.53069162368775, 59.49969222468715, 60.924442198968705, 58.3452602355711, 56.11321979953397, 47.975505859621116, 61.4433600056556, 59.78021229467085, 56.155416657847745, 53.89346030450637, 55.24292430570049, 55.177860029282115, 53.348019430714274, 49.526465938937285, 49.689185465535815, 50.31084583651636, 49.523543773158906, 48.779042613121774, 47.59601262307937, 47.60260220496885, 46.759202403406945, 47.665442497499534, 46.94883723412791, 49.71247257724885, 49.02313563131517, 47.01871425874772, 46.824415729891875, 46.77012620433685, 48.169827922698, 46.57569039252497, 45.43659879315285, 47.53538846969605, 47.008904410946755, 47.63881352639968, 46.223234053580995, 48.2840669539667, 44.8651094590464, 45.68163710255777, 46.87926223201137, 44.09561887864144, 45.900434755509906, 46.377485182977495, 49.158300507453184, 47.69269120308661, 48.95667499111545, 47.752836827308904, 46.44060788616058, 48.72467071779313, 47.420929785697695, 51.07466859202231, 49.5706553612986, 50.42212740067513, 52.634124525131725, 52.081078175575506, 54.39193864022532, 55.828749902786754, 58.292335694836034, 61.56531826142342, 58.45904034952964, 60.6102446586855, 61.76049932356804, 61.964999937242084, 59.66617330428093, 61.26833600382651, 60.13775202535815, 72.19875397220736, 67.8243306375319, 69.59768126087805, 6.4228836086488545, 2.5971623534156434, 1.108677541055987, 0.21268892913095414, 3.0503397651257056, 62.12909229340092, 72.45804617481848, 62.143742345994525, 39.918510375484345, 25.42761971873622, 55.98872769263483, 65.71851599601008, 65.38789549181539, 74.4841072636266, 19.240810332759736, 1.325691496172259, 0.34954508225764, 0.16164712607860565, 0.16905272950328168, 0.3144056404069547, 0.10974937298845862, 0.3134100938275937, 0.18483694462526232, 0.1923751272261143, 0.15359840716325468], [0.017027815225564184, 0.02687611680988583, 0.038446206749687274, 0.04077726674656715, 0.015251970748537251, 0.06652028780550727, 0.036165758351524996, 0.06970741275337435, 0.06628064018103384, 0.22536506425709496, 10.386392089628405, 66.09978214386972, 50.72921368383592, 46.66019393551735, 22.047801594580374, 25.94956167282597, 44.769725261196015, 53.78135896498158, 61.26004803565241, 67.47918559658912, 6.477292766494136, 0.10130699979321611, 0.15764690605142426, 1.499510104617765, 3.5183081896074357, 6.605836681781277, 77.7523123833441, 67.48112324745425, 71.10422442036291, 64.86937776688607, 66.81748959325975, 64.0633346188453, 64.15729499632313, 57.863028357105875, 56.89801546835131, 52.31160371534286, 53.06699729734852, 50.11085987091065, 46.942439848376864, 45.357068815538966, 44.80441078062981, 45.72202967059228, 46.18024487649241, 44.9545826450471, 46.49756462343278, 44.78281813283121, 45.02558931227654, 44.77504399514968, 44.253745309768185, 44.841449722166985, 42.767300375046275, 43.77409042850618, 43.15516787190592, 43.46134808755691, 43.75279980321085, 42.95868066049392, 42.93117307847546, 41.91222367748138, 43.736051282575055, 42.25231670564221, 42.6931675787895, 42.48947497337095, 42.54383510158908, 43.30914051302018, 43.03567678697648, 44.75496538223759, 43.14926470479658, 43.628119422543435, 42.87996653587588, 43.17924730239376, 42.952361722146314, 42.679266698898815, 43.651881141047326, 41.59586491123323, 42.164341865047334, 41.88846980371783, 42.31236034824003, 46.0983967781067, 53.51405728247858, 52.05064842777868, 52.026204216864805, 51.751544167918546, 48.92662571322534, 49.349629802088586, 50.05300883323916, 51.56305859165808, 55.57720045889578, 54.886996669154016, 46.25078870404152, 56.78585137090376, 53.09960788296115, 47.77181717657274, 43.67135570895287, 44.88222276010821, 45.90957780038157, 44.85556241004698, 44.56501283953267, 45.35036548491448, 45.06466004156297, 45.72617561586442, 44.78370066611998, 42.071617034173784, 40.52568543341852, 42.12983677464147, 42.27433296941942, 43.652649925601104, 43.5931711043081, 42.29203462600708, 43.1076209006771, 41.152162474970666, 41.8465082876144, 41.3141445959768, 42.07335072178995, 40.2997176877914, 42.96183816848263, 42.4781197117221, 41.01487167419926, 41.13660243249709, 42.31083846861317, 42.293701633330315, 39.53294530991585, 38.64974521821545, 41.58368987421836, 40.299568637724846, 41.99296174510833, 42.65759560369676, 42.28369566702074, 43.110327336096, 43.265437464560236, 42.716976365735455, 43.5373047859438, 42.804245179699315, 41.048152985111365, 43.06506318430747, 43.34570877013668, 44.33887643198813, 44.82526994520619, 45.80196365233391, 50.584462534996774, 51.101744713321814, 53.28252369357694, 55.48183979526643, 55.28774522965955, 53.87107533793296, 54.68500637239026, 52.8040062996649, 53.875535072818884, 56.81115850325554, 66.15102398780085, 68.10350925691667, 69.6062869410361, 19.64042336710038, 0.5009685811256209, 0.13221102496308665, 0.04611854666783925, 0.2536286524827442, 30.115295302483347, 68.23113533758348, 44.461795668448175, 50.91736978100192, 18.258344857923447, 32.23162385725206, 47.57295693120649, 45.72734840454594, 52.279616786587624, 17.037915068288005, 1.0758761076196548, 0.03995795103330766, 0.1389138806130617, 0.060040528450401566, 0.019732582488007123, 0.03820351009527522, 0.034372595499359795, 0.03683585162845351, 0.03933148646366693, 0.04707370126139253, 0.08901591577957715, 0.04409128649821205, 0.0387663395714856, 0.05128371829707777, 0.03168675252386639, 0.04952598318097092, 0.019694396835421363, 0.08313589984731329, 0.1250756437319421, 0.2052061806523031, 15.9460792041594, 77.30554657597696, 58.446649582155295, 55.44668359141196, 29.754935387642156, 28.17250221006332, 40.41893420680877, 60.989337813469675, 65.25362491607666, 77.83758471089025, 6.476931418142011, 0.10127540632721879, 0.16316670744169146, 2.8491356584333607, 2.5985302800132386, 7.315916592074979, 78.80062856981831, 67.6940373451479, 73.82935385550223, 66.78305902788716, 69.25523481061383, 65.54772030922675, 66.05419635772705, 59.298407954554406, 59.902425504499874, 55.68910960228213, 55.97147318624682, 51.77592562090967, 49.347421507681574, 47.639146927864324, 47.621617855564246, 46.866067378751694, 48.7888014701105, 47.58917593186902, 48.84159657262987, 47.67721745275682, 47.09501612570978, 46.71508358370873, 46.40783648337088, 44.66220525003249, 44.72691651313536, 45.15341151145197, 45.33160871075046, 46.71337343031361, 44.670850153892275, 45.790133783894206, 45.72770926260179, 45.502553447600334, 45.11058315154045, 43.667339201896425, 44.18891245318998, 44.78581482364286, 45.74181802811162, 45.25264355444139, 45.42897762790803, 45.06411090973885, 44.47268024567635, 45.56933179978402, 45.41919523669828, 45.35866914256927, 47.07163487711261, 44.549472408909956, 47.47664313162527, 45.41955217238396, 44.474347252999586, 44.62658620649769, 45.65272138964745, 48.73137797078779, 55.358481253347094, 54.93805023931689, 53.71046996885731, 53.64594697952271, 53.241887938591745, 49.876878723021484, 53.11356367603425, 51.97496237293367, 57.31581849436606, 56.2430267180166, 48.50201345259144, 58.21004044625067, 56.166575800987985, 51.41105498037031, 45.25499697654478, 47.27049120010869, 47.59368273519701, 46.26278331202846, 47.37637166054019, 46.80206606465001, 48.23691221975511, 47.50277003934307, 47.414473564394065, 44.24497489006289, 44.05012330701275, 43.24602173220727, 46.240884719356416, 46.28048496861612, 46.538259213970555, 44.07391640447801, 44.661722798501295, 42.87575391031081, 42.826885100333925, 44.91187195624075, 45.761363198680264, 43.535928034013324, 44.015790800894464, 45.05416770135203, 43.56055267395512, 43.51639855292536, 43.74697508350496, 43.66693912013885, 41.52277154307212, 42.2589494336036, 43.42738036186465, 43.64852751455, 44.78983133069931, 45.56248334146316, 44.989687858089326, 45.62625323572467, 44.66970089943179, 44.7659872424218, 44.97006424011723, 44.91351542934295, 44.91059718593475, 45.898418657241336, 46.34447451560728, 47.64679947207051, 47.24458002275037, 48.07700895494031, 52.42525831345589, 52.996018086710286, 56.57185469904254, 57.86555828586702, 58.40148741199125, 57.79402602103449, 58.0140317639997, 54.78463065239691, 55.94918235655754, 57.61244773864747, 69.14756574938374, 70.34850135926278, 73.12844199519004, 22.1732448762463, 0.08850297394899592, 0.6778227057187789, 0.036366166952516765, 0.24861407075678152, 33.64315348286783, 73.92903697106146, 52.09708536824873, 45.52648775039181, 22.049048908295173, 42.06875370394799, 53.94785965642622, 53.278346369343424, 66.96393520601335, 27.746438672465665, 1.4437555738033787, 0.051655780388823444, 0.10225190796078214, 0.037217060810015086, 0.042732300146693186, 0.04524553585196695, 0.02230484143740708, 0.06345396726241996, 0.09004554561068935, 0.07461671867678243, 0.18326934487108262, 0.12215215262145766, 0.13000835364143695, 0.11321049694332386, 0.16831351594338495, 0.1802533639654998, 0.12258066390190395, 0.14767705312659665, 0.3077497153032211, 0.4269020974395737, 21.94568072595904, 92.19198473038213, 65.47634493920111, 68.03771541964623, 33.636442307502996, 41.30119292966781, 57.16570546550136, 68.97843314755347, 70.34560665007561, 82.76487396609399, 8.332161518835253, 0.34938607304807634, 0.21509400088219874, 5.5385769182635896, 11.609325332026328, 7.101950318582597, 85.48113099990353, 71.1714538451164, 77.3016163610643, 70.31375700427641, 70.9118478528915, 69.6717591439524, 69.5927155402399, 62.89718651002454, 62.81918625677786, 58.54444603766165, 58.651248255083644, 55.75240096738262, 51.927399712224165, 51.603694346643266, 50.16369027476157, 49.969748681591405, 51.54942051056893, 49.97603231860746, 50.98447761228008, 49.37883577039165, 49.46735189807031, 49.530298094595636, 47.62070002094392, 48.059730914331254, 47.14039402623331, 47.24987130011282, 47.899364809836115, 48.62869031967656, 47.55593384465864, 47.65251828778175, 47.56450422348515, 47.1885254306178, 46.456748439419655, 45.85666502675703, 47.266431546980336, 46.95550918579102, 46.745631002610736, 47.32661247253419, 47.70543498377646, 48.519946529019265, 47.58345711615778, 49.20491003221082, 47.15491856298139, 47.69364041666831, 47.823294362714215, 46.86988384492936, 49.82864925938268, 47.391515931775494, 47.7971988339578, 46.428593666322776, 47.205976055514434, 51.736588170451505, 58.76673067769697, 57.84958247215518, 54.88103858886227, 56.277806374334524, 55.53532131256596, 53.226378886930405, 57.25866171621508, 54.72342991059827, 60.68575028450259, 59.12446652689288, 51.58105050363849, 62.583420430460286, 59.13684552715671, 53.174478084810325, 47.23366406656081, 49.598221778869636, 50.58969889917682, 50.1227407301626, 51.406085337361986, 49.612824763021166, 50.48693672303231, 50.17956018447877, 51.2564508376583, 46.17614207729217, 44.991896152496345, 46.077384641093595, 47.64238288325649, 48.92852414038874, 47.68527007872059, 46.30122646208733, 48.03210566120763, 45.46458882670249, 46.01567791354272, 47.15292992130403, 48.31501837699644, 45.427530273314446, 47.24341115643902, 49.52373204692718, 45.888906909573464, 46.862976551055915, 47.6553306271953, 46.392335276449884, 44.88818476277013, 44.99978796128304, 46.61345105017386, 46.231310213765795, 46.95151229058543, 48.31419860163043, 48.312107978328584, 49.13825327350248, 47.18754876044489, 46.97767449963478, 48.309217191511586, 48.24408623480028, 47.56894434652021, 48.61474629371397, 50.21135883946573, 50.76553483163157, 49.789484393212106, 50.626176941779356, 55.93331636921052, 56.56414724165394, 58.94645760136267, 59.16918154685729, 60.38420631039528, 59.36883803336852, 62.16300510591077, 58.092530158258256, 60.06503128236341, 60.96142622732348, 72.09885120391846, 76.14901219644855, 75.19025156574865, 23.249462842941288, 0.9709631855930052, 2.3794617383710803, 0.16279363794432533, 0.5595750121339675, 40.70867969143776, 78.57189947558989, 61.57547327779955, 66.00719851832237, 28.677746634329523, 43.47123246039114, 64.35179748842793, 63.797178268432624, 83.82312159384452, 37.872103952592425, 1.729827636191922, 0.21325888322486033, 0.2140941948539788, 0.16683069147890614, 0.2068939642800439, 0.1382346823811531, 0.12514214016376965, 0.11182795338813337, 0.19185751225919495, 0.26474503259504995], [0.027718518582743504, 0.10571263354992676, 0.03455253806145441, 0.03758667142040307, 0.027636721459848267, 0.06259228688694778, 0.028695276855761488, 0.10753262863163987, 0.015441966299418242, 0.13760477424629275, 19.512144211799868, 64.30892206007435, 54.65552191580496, 45.12033416378883, 26.61580566437014, 33.01864154877202, 37.39495154350035, 49.20184666110624, 70.8994923868487, 46.51813745498658, 1.700730145938935, 0.05703115888360528, 0.12431728563481763, 0.8849897343785533, 1.267965974346284, 26.912717319303944, 77.17807739011704, 66.92146378178751, 70.12797786343482, 61.89425214644402, 66.92485270961639, 62.95352351280951, 63.409185255727465, 57.094137899337284, 59.27139459117767, 51.963646334986535, 51.71510534901773, 45.5765607280116, 45.9252437468498, 43.38103363590856, 44.67561583365164, 43.077116627847, 44.98088998179282, 44.59380303659747, 44.684845170667096, 44.10526398689517, 44.40113229136313, 44.71580051606701, 46.021224144966375, 44.80270454960485, 43.836314908919796, 44.36645461666969, 44.03502218184933, 43.75668687205161, 44.29216884797619, 42.3898232367731, 43.455417463856364, 42.33825583611765, 42.113959020183934, 40.72379258371169, 42.45467962757234, 43.36182578917473, 43.863128231417754, 42.376279292568086, 43.71523526407058, 41.70776620987923, 42.72691565175211, 43.941053959631155, 43.51311160672096, 43.023454681519546, 43.292772462291104, 43.00299167633057, 42.67570910915252, 39.882495172562145, 41.382217330317346, 42.55628470451602, 42.774823481036776, 42.43105911439465, 51.143372827960604, 52.3635398187945, 52.40459918975831, 48.98962290056291, 49.79023748828519, 46.86486713347897, 46.18885447902065, 51.245315228739095, 57.896725439256244, 54.05091993270382, 44.375868305083245, 55.53331305903774, 53.63017905143, 51.006842967002626, 44.25131344026135, 45.82957713834701, 45.09590171998547, 45.53584652562296, 46.40841307178621, 46.91242979418847, 46.405989047019716, 47.6677841524924, 44.901991505776685, 45.605350925076394, 41.97855487946541, 43.07208814928609, 43.148252733292125, 43.30111534364762, 43.556018414035925, 43.15049240666051, 43.15485408229213, 40.92108780337919, 40.05334969489805, 42.903049684339955, 44.14099285679479, 42.254050393258375, 42.53739456976614, 42.783189896614324, 40.98722680922478, 41.02485802865798, 40.620257700643236, 40.85542340432444, 39.86282448614798, 41.1935866263605, 40.13686480060701, 42.285143021614324, 40.81901988675518, 41.75797647045505, 41.71502651706819, 42.54781238494381, 43.75411379721857, 43.25291333660003, 42.661423836984945, 40.37350923784318, 42.74493502032372, 41.36941471407491, 43.83843298881285, 42.46588976152482, 44.32319871840939, 45.287097654035016, 47.760234417453894, 49.60380723399501, 52.98758499083981, 52.98543945435555, 54.711603964528734, 54.83326412016346, 52.34721099176715, 50.3545057389044, 51.62953884370866, 56.40562857350996, 64.84830287195021, 65.55536108632242, 69.647644412133, 38.568811032079886, 0.4532529786229134, 0.35132482707981144, 0.20164733452181663, 0.04458662362829332, 19.55087173369623, 73.52686066781321, 48.63612713352327, 41.50258702616538, 24.68135545330663, 27.29991409086412, 46.799351784490774, 42.42075112558181, 44.55643853833599, 26.569268703460697, 3.02562564611435, 0.1859235943805787, 0.048789688416065714, 0.06362114296925646, 0.0686852369577654, 0.032273476282435085, 0.08339580283650468, 0.11449793834359416, 0.04330736404705433, 0.019945250411007195, 0.01929682976145658, 0.03780851516151621, 0.03679893768182205, 0.07671530163216014, 0.014035609858711402, 0.0879412093350003, 0.08521487095182942, 0.01957772547499307, 0.14500026531036825, 0.11527287458340008, 28.10984823011583, 74.69082401644799, 60.83704394678916, 58.34493075647662, 34.052503801161244, 30.2738884956606, 38.80895422350976, 54.41608867337627, 75.43951819019934, 54.497144452987186, 1.4935674686585705, 0.057347338691714315, 0.2957563637004745, 1.203962944207653, 0.8990541280757998, 28.048353310554262, 78.99303651625111, 66.75024447902557, 74.43001777895036, 65.56393146514893, 69.8123525804089, 65.79165643261325, 65.54756733679002, 60.288261213610255, 62.0836006441424, 54.45779523541851, 52.32065654570057, 46.94573071695144, 47.47939271311606, 45.77677811345747, 47.121594105997396, 45.77429917550857, 48.00335076547439, 46.64452014430877, 45.96669927720101, 45.66870112572947, 45.50444795239357, 47.33897970568749, 47.35993300714801, 48.05463967784759, 46.69492652339321, 46.33574331960371, 47.17079239506876, 45.94513800836379, 46.60009537973712, 44.83260869979859, 45.869914793199115, 44.2623156885947, 43.47724153149513, 42.83650667436662, 44.02278830928188, 45.50565996477681, 44.94279592267929, 44.38784330121933, 45.43914833376485, 44.15239126451554, 43.984372615814216, 45.70515563411098, 45.66579857180196, 44.63375629917268, 43.779687650742076, 44.96436895862703, 43.78694403556086, 43.81030959467734, 43.842857422367224, 45.8407009801557, 43.16302045699089, 46.88056838127875, 53.92534132926695, 52.912314707233065, 55.27059270489601, 52.663844323927364, 51.81056407190139, 48.50821471983387, 49.06253583969609, 53.74723042211225, 59.417447966914025, 57.02670058896465, 45.36212475069108, 57.39634867637389, 56.06715156186012, 53.40279925254084, 46.58556299824869, 47.86237685911117, 47.300893491314305, 48.012289847097094, 49.75293574794647, 48.23131107514905, 48.744133518588164, 49.62747481561477, 46.023416749892704, 45.82707074380691, 43.21913388467605, 44.25289807781097, 45.521357290206424, 44.92629843373453, 45.81519380692513, 46.35253890868157, 44.20047952282814, 44.39185980827578, 42.55658672701928, 44.337280027328, 44.25977791509321, 43.39476977625201, 45.3314478935734, 43.839507718240064, 43.32455150542721, 42.473228516117224, 42.25137925917103, 42.940931935464185, 42.93668793093774, 42.670194256690245, 42.822750922172304, 43.056653622658025, 43.903563945524155, 43.778318743551935, 45.17839308707945, 44.99065668352189, 44.6650097447057, 43.95149138665969, 45.26499902048419, 43.44728246811898, 45.177094782552416, 45.41003257997575, 46.11520413429507, 45.47087246371854, 47.802270458590606, 47.54051108514109, 49.05139238603654, 51.23251653486683, 55.49922373987014, 53.646566714009936, 56.3173399433013, 57.577781831064534, 54.57287365390409, 53.54663648912984, 53.58094938339726, 56.88405575290803, 68.03421666545253, 68.02262213922316, 71.22500204270887, 40.514969518107755, 0.8639232970533833, 0.7032609923231987, 0.13381075444481066, 0.020251250825822353, 20.511248380907123, 78.24086712252709, 54.70208044975035, 44.417700382971, 26.232227279293923, 35.49562223495976, 51.304162548434356, 50.53150269293016, 56.29278982839277, 40.18789875891901, 5.021199132165601, 0.19638575072730743, 0.02172595284308397, 0.055330114273895184, 0.07082683575009147, 0.0136687514191914, 0.031883081706661376, 0.0574884022916517, 0.01532719100660254, 0.021318520471874266, 0.23528513678860283, 0.25776897466951804, 0.10972417635662902, 0.1700030462515931, 0.11815847498514961, 0.10633287365518271, 0.222219874962203, 0.16139791767683723, 0.29026737436652184, 0.4142007273772071, 37.01174774477559, 85.02401798002182, 70.22962216408023, 61.051825092684844, 38.00630784803821, 46.45570116658365, 51.1049767463438, 62.77935458767799, 83.199048965208, 59.48819575771209, 2.5181655729970625, 0.19089587273136263, 0.8624981896531198, 6.030218072475926, 3.771226540688546, 31.62663552068895, 82.35670428122245, 70.78364126143917, 77.3014908452188, 68.49522852128553, 72.74753278301608, 67.12142621317219, 67.40713165652367, 61.71999300679853, 63.17514134991554, 55.896300961894376, 54.33965344582835, 50.78800609034877, 50.77514463855375, 48.08485369528494, 48.61761354630994, 47.04212688630628, 49.893497805441584, 50.61991291661417, 48.934054682331706, 47.44272639674526, 49.97461634297525, 50.02033941207394, 49.68329798790717, 52.676093885975504, 47.74481558030652, 48.44830051545174, 47.87391254978795, 47.86766029173329, 49.243306113827614, 47.72103817232194, 50.13710837210379, 45.74095118430353, 45.05541109269665, 44.47843828508931, 46.72620742551742, 48.89548601642732, 47.20421883367723, 46.426526577241965, 47.89241436989077, 46.30461538991621, 46.31164035489483, 48.929010514290106, 48.143234252929695, 47.255790156702844, 46.9998162792575, 48.96116610496275, 47.28479608412712, 45.926412613161155, 46.35356656966671, 48.09705618889102, 47.12515169574369, 48.70467055228449, 57.681932526250044, 55.55507829112392, 56.45596827230146, 55.637808922798406, 55.37143291965608, 52.41942967137983, 49.96592829304357, 56.451414400531405, 64.1820098507789, 59.62491389243834, 49.07050609588624, 58.87518813533168, 58.55508742793914, 55.28896900915331, 47.698457087239916, 50.634162887450195, 49.81805493754726, 50.8276024172383, 50.86661823334233, 52.143600756122225, 51.25590955057452, 52.633112553627264, 48.484088220903956, 50.74169074335406, 45.870020697193766, 47.057020125850556, 47.27804176269039, 46.953030247842115, 48.12143764188213, 49.291990572406405, 46.52230693447975, 45.679566091106786, 44.643499466680716, 48.16893362229871, 46.769329963191865, 46.69296533830705, 47.08455516446022, 48.60334004125288, 46.6758285030242, 45.37446844962336, 45.095266296017556, 45.419203081438624, 45.34863179729831, 45.81324438894949, 45.58186377248457, 46.90659330737206, 46.56622571329917, 47.917266507302564, 46.70214368451027, 46.866793017233576, 47.543445018029985, 46.086884621650945, 48.334940095101636, 44.715867196359945, 47.56066030071628, 46.74605461858934, 49.13905343701763, 48.029312933644945, 49.95638124404415, 51.52180702455583, 54.137753363578554, 54.366145133972175, 59.2374425549661, 57.96642203484812, 59.67482605288106, 62.11288898221908, 59.1798621608365, 55.71674662251627, 56.5706426866593, 60.09359398195821, 71.28082521500127, 71.11230450291788, 74.49376413899084, 44.62076540916197, 1.1363546430103242, 1.7910085209915716, 0.5296204227112955, 0.13586482003090844, 24.80194087951414, 85.80387930716239, 61.07963077483639, 57.95590223804597, 35.16042824714415, 37.852139088415335, 61.03149544808173, 59.79196763807728, 71.51259022374308, 54.47107638082197, 5.830844977209646, 0.3655965548128851, 0.15674891310834116, 0.07995339440962962, 0.15850866303568886, 0.09789616951057989, 0.09097632711693164, 0.16018095636560073, 0.1215250407075209, 0.05869573387768], [0.07208451463450348, 0.14035630160041396, 0.0184552323809194, 0.04278722482042448, 0.024991128743896564, 0.048190132684765324, 0.04382851834018384, 0.061153278821298195, 0.06401357916934837, 0.14246984625295286, 35.17666685965754, 63.68011513063985, 50.41565548989081, 37.381760612610854, 43.354024194901996, 43.34292780968451, 33.84635579201483, 56.729106441620864, 66.85454030190745, 47.44490331219089, 1.3404654711484911, 0.014810078784883505, 0.1714046653960982, 2.1580427164031617, 0.47173518687486654, 47.54559447688442, 73.1138978465911, 64.9762741211922, 63.23912697453653, 58.97760122053085, 60.99433491306921, 58.27008801121866, 59.058264763124534, 56.99846736846432, 54.664339403952326, 48.15138886051793, 46.87206468274517, 44.05258263311079, 44.735498659072384, 44.517987543536776, 45.18384910398915, 44.92622390870125, 44.89675121922647, 44.31971957606655, 45.14505294061477, 42.986925648104766, 41.53945338341498, 43.36813688278199, 41.731524006012954, 43.148276267513154, 44.955386730932425, 42.74386421326668, 41.972612488654356, 43.39523261593234, 43.787077396146714, 43.48146592417071, 41.99594666880947, 41.04778820468534, 41.70451848737655, 41.19753253075385, 41.190280068305235, 42.58716552488266, 41.72871951133975, 42.806025935757546, 42.771316882102724, 42.23328928793631, 43.41413451779274, 44.30322993186213, 44.34888632066789, 45.089080718255815, 42.90237895904049, 42.79697310539984, 42.57726546256773, 41.13571989920832, 40.30134939378308, 41.29266961928337, 41.38637896507017, 44.20673570325298, 49.35561141660137, 49.39561174761865, 50.06585067318332, 47.724187835570305, 45.46504774401265, 45.540310182879054, 43.827403283888295, 51.474585610051314, 55.5457587395945, 57.261403452965524, 37.720265080851895, 52.534806189998505, 58.65254655961068, 50.36873609788957, 47.14798773488691, 45.33073009983186, 46.45141401598531, 47.215174013568515, 46.622550948973625, 47.03388598657424, 48.440518533029866, 48.914160420817716, 45.08496615194505, 43.74796744315855, 40.973843682196836, 39.70936175315611, 43.77465132744082, 43.33146272167083, 42.720271156680205, 43.41978665321104, 44.10402451792071, 41.702623982583326, 42.38388869070238, 42.63878783872051, 41.84003637683007, 41.73881176979312, 40.09398152751308, 40.19012666517689, 39.766134139030214, 42.04231692898659, 42.6990472116778, 39.26806372980918, 41.27492089425364, 42.53802214899371, 41.32082439238026, 42.00155565815587, 41.8051508165175, 42.09305278716549, 42.415157825716086, 42.82774802177183, 42.631041157630186, 42.2578590146957, 43.36426550342191, 42.270289005771765, 42.890619693263886, 42.26475454145863, 42.258847451979115, 40.66738105589344, 44.696718185178696, 44.75322777225126, 46.47552874780471, 48.071886339495265, 50.190707560508486, 51.644592900430005, 52.01439396027596, 49.093436271913596, 48.379525676850356, 49.785954260057025, 48.72849502871114, 54.24826614318356, 61.94485856640724, 65.89778007999544, 70.88751346834245, 54.500286271495206, 4.304871866779943, 0.8518598637273236, 0.24639931056768666, 0.15613179864181628, 8.390950002977926, 67.46655556463426, 57.400172987291896, 47.59993499325168, 35.91120127708682, 20.609990127625007, 48.578813460565385, 45.5070641732985, 44.29716202520555, 41.09876332744476, 7.125763027898728, 0.30715363761109693, 0.038773567611051184, 0.05354609085066665, 0.053502626852282596, 0.12531722955886396, 0.07340963989976915, 0.033402264704026526, 0.011545707276391407, 0.04943545840139832, 0.08148154063570885, 0.05643026632887702, 0.011891815266872366, 0.043010784598488006, 0.03388426424334607, 0.04439054725451335, 0.053431254270817005, 0.07257215258094572, 0.04928469229789992, 0.7543209363375941, 46.060659654678844, 72.76247701337262, 57.799756603856245, 40.79560333682645, 43.31951910449613, 40.55355387349283, 41.73083366886262, 61.12851135192379, 74.03130885093444, 51.05631974435622, 1.2259295654873694, 0.0714272954651425, 1.176742553230255, 2.3813579592012593, 0.7524633876258328, 50.702890657609515, 77.08874148707237, 68.24837023212065, 67.36647236731746, 60.76826126344743, 63.29364791993172, 60.595512236318285, 61.13317897242885, 60.049396714856556, 57.20851813593219, 50.28973171787877, 49.751280507733746, 46.77766892217821, 46.41819154062579, 45.31062403032857, 47.463542415249734, 47.61944878485895, 46.58595915763609, 46.302744419344016, 47.641194405094275, 46.51771776137814, 43.28895207374327, 46.095941374378825, 44.673438918206, 45.26390860157628, 46.524425014372795, 44.469126578300234, 44.28846613053353, 46.73747639502249, 46.130454309525035, 44.82435211058586, 44.79877825706236, 44.882203148257354, 45.11738454141925, 43.95699839438162, 42.723679696359945, 43.27828322687457, 44.65568234843593, 43.117481739290305, 45.54918258420883, 44.24264500218053, 46.45342226951353, 45.84310147070116, 46.133133288352724, 45.28619943126556, 45.80560753422399, 45.73001169389295, 45.86723189200125, 42.662471109820956, 43.77363543356619, 44.795714885957786, 43.97405678226102, 46.92153361535842, 51.645573492973085, 51.84968971437024, 51.16661679360175, 49.107305772842906, 47.734582116526944, 46.27910037194529, 47.48606466477918, 55.17438873167961, 56.814398381017874, 60.08345857743294, 40.48147639920635, 55.617749921737186, 60.1080753726344, 52.89307155916768, 50.06335212338356, 46.363309737174745, 48.668922070534, 49.71133508989888, 48.72169756120252, 48.62670167799919, 50.726193458803245, 50.225757860368304, 47.02155405475248, 45.85958327016523, 42.74414270154892, 44.12518962737053, 45.50486372363183, 44.188688878090154, 45.20548489785964, 45.600910802041334, 45.7441439936238, 42.81348236145512, 43.98999729464131, 44.31209841082173, 44.153854308589814, 44.280554709895966, 42.90255546569825, 42.48347374700731, 42.188872368105, 43.21212068680794, 43.48104623056228, 43.089829029575476, 42.790030510194846, 43.5782935542445, 43.92583908573274, 44.051339241766165, 43.786128182565015, 43.91485252688008, 45.148983155527425, 45.134968526901744, 44.63589006854642, 44.40209719442552, 45.543322563171394, 45.248430928876324, 43.681530337179865, 44.826254460119436, 45.65467472999327, 43.75558076366302, 46.534125035808934, 46.984299382855816, 48.463052549669825, 49.71756381373252, 51.22931195843605, 54.63474904337237, 54.01416340181905, 51.78444108655376, 51.523199465967, 51.805868994805124, 50.88430027807913, 55.26470130489719, 64.52721372727426, 68.60834183231478, 71.59432457339379, 59.404880692881925, 5.495207271268291, 1.519313783895585, 0.6714699982154755, 0.11390319364445825, 8.523652611240264, 73.32301508995795, 63.484655580213, 46.982459791245006, 31.734830179522117, 29.63872732654695, 55.77512718016102, 54.015344035240915, 56.12473587835989, 58.18356836995771, 11.350075294894557, 0.32083241329077755, 0.03298682288356847, 0.052457552688616904, 0.019467667368571126, 0.13642976390978984, 0.07697394823715573, 0.024394229422473622, 0.03660142872362368, 0.02203501186393682, 0.18534884457626652, 0.2544486883186525, 0.13066391040000225, 0.08630300691771893, 0.12143975213891077, 0.21738791327563026, 0.1592789491217944, 0.22207390456911058, 0.23103569303789448, 1.496447836679797, 58.92223304317844, 81.46510247261294, 69.84734796708631, 49.84003589999292, 51.802923294805716, 51.80056595033216, 50.52171245698006, 69.30835154748732, 78.82902652986589, 55.78202662929412, 2.180148704398063, 0.16120556832080887, 1.4747030744629523, 9.326797127723694, 1.7333991993819515, 53.43602565027053, 77.54972980868432, 72.34910626565257, 70.78788526596563, 65.17743287547943, 65.49796896596109, 62.876852943051254, 62.371796792553326, 61.79553001157699, 60.72268724441529, 52.34950165594778, 50.892384283004276, 49.91228988093715, 46.88620874958654, 48.87344621842908, 50.183490399391424, 49.052431814132206, 50.254497066620864, 47.914575761364354, 51.123353050601104, 47.25196584578484, 44.82907072190316, 47.35810518264771, 46.485879882689446, 48.494788446734034, 50.46756413675124, 45.90114078214092, 44.69068557985368, 49.02024876686835, 47.8589722418016, 47.93374830676664, 46.85596335318781, 48.50588875432169, 47.87409297881588, 46.11320764787736, 46.262191034132435, 45.86753783687469, 46.44933515979398, 46.74501911286385, 47.16735639879781, 47.7346448744497, 47.10107226525584, 47.8783409057125, 48.105708937491144, 48.60905101222377, 48.193366066102065, 47.45978478462466, 47.370276297292406, 45.37575890941005, 44.357523379787324, 47.86254159865841, 45.349278988376746, 48.555793070024066, 56.00391510994204, 54.548174488929014, 53.6282806242666, 51.27243449611049, 50.39257234142673, 48.583288884931996, 47.8264283364819, 58.42791634221231, 59.508619539199344, 61.72742589827507, 42.21328127768732, 57.773888572569824, 63.407114244276485, 54.992520193899836, 52.03404111246909, 49.82149877855855, 51.84871696656751, 52.69383476626489, 51.047364973252826, 51.34595540262038, 54.75083943336241, 56.335724092298946, 49.792375180029104, 48.338776173130164, 46.92173365623721, 45.0931207595333, 48.719442198353434, 46.240084555841264, 47.388554542295395, 46.9632911682129, 49.7346967266452, 46.34425878524781, 46.462741821042954, 48.37265760667863, 47.38719347984561, 46.86746766490322, 45.48616186265023, 44.231689822289255, 45.41561411273095, 45.61809078339608, 46.774393743084325, 45.81676667736423, 46.00572293804538, 48.68284648464572, 48.81954500752111, 46.71856272605158, 46.36510226034349, 47.22329331982521, 48.12214366851315, 48.40230288044099, 48.45829079228063, 46.55423895005257, 49.54324976090462, 47.927856906767815, 48.10822709914177, 48.55125488773469, 48.38832355314686, 47.03102657871862, 48.93517255783082, 51.74964181838497, 51.36012300368279, 54.2690311708758, 56.73468012963572, 57.717175022248306, 58.284204621468824, 54.659561957082445, 54.555250444719874, 56.648309538441325, 52.744409807266734, 58.88189538832634, 67.5379034780687, 71.98678124335505, 76.49198424431586, 61.636619106415786, 6.139503150216996, 2.666439255399089, 0.7853780795008906, 0.3202478882045515, 10.716960622418313, 80.35883718921293, 68.91016037233415, 63.864191962826645, 50.52876880092006, 28.95783328240918, 62.25599665795604, 66.46351137468892, 65.89211617746662, 71.28786979183074, 15.768593915047186, 0.48890140929049064, 0.1990164660157696, 0.1294449879036796, 0.12819870840758085, 0.16482645225140358, 0.16927920041545746, 0.11605809172314983, 0.1537282897099372, 0.18981732818628513], [0.05420596068424564, 0.023790159518079414, 0.03861912428551624, 0.044607147123784795, 0.04579691997458858, 0.06363729976357953, 0.04924675562388955, 0.06779000193120972, 0.04285084459209635, 1.5807553837376258, 50.031274980114354, 58.26309442520142, 58.70014059928156, 51.98844748158609, 26.955316220560384, 30.563832059983287, 39.46573549701322, 57.87186153473393, 72.06354987236762, 34.95679447727819, 0.3397820883941266, 0.017688029798709096, 0.3954238510660587, 0.2918406738148582, 11.578298403370766, 64.39626539907148, 68.23563821854131, 66.81385747848019, 65.04196597683814, 56.24585474691084, 52.86143764372795, 52.63583075615668, 50.49128270918324, 49.30260450609269, 47.98682581993842, 45.17800085006222, 45.11896133422852, 44.796444446809836, 45.78635261904809, 45.38420377239105, 43.560407546258745, 43.777875515722464, 43.57952910084879, 41.76219694076046, 40.3050442664854, 40.81236754694293, 43.29944833632439, 43.52068178115353, 43.620612006033625, 43.223166081213186, 43.22667268014724, 43.61203770483694, 44.14275007863199, 42.95995935317009, 41.036656518136304, 42.88463415638093, 43.35690713697865, 41.38210358158235, 42.47587611598354, 41.184933877760365, 41.51580933601626, 41.39376086573447, 43.200722279087195, 43.37587179676179, 41.323546517279844, 43.82115887057397, 42.00416011195029, 44.11909818649293, 44.744979027778875, 44.47518271784629, 43.05491209030152, 43.22968506043957, 43.255847269488925, 42.29925963186449, 40.9037587719579, 42.11881099208709, 41.83880083022579, 42.55848907655285, 46.210984491532855, 48.36563656407018, 47.6458384913783, 45.88323908467447, 43.592265036798295, 44.33460497087048, 44.17803572070214, 51.94984351435016, 54.83866914626091, 56.48402890851421, 39.22552562529041, 53.29693055921986, 55.44242389740483, 52.67843554096838, 46.54850052249047, 44.97197443439115, 46.1962010783534, 45.266615036995184, 47.55469045331402, 46.437638651940134, 45.613568290587395, 47.31004830329649, 46.102130874510735, 42.69011989716561, 42.405606854346495, 41.042124302156516, 43.396264199287664, 42.790567874908454, 43.026545509215325, 42.43288693889495, 42.43155333303636, 42.67071985429333, 42.60513390264204, 41.278851109166304, 40.817780417780725, 40.7873506699839, 41.97415398013207, 40.41656509522469, 39.41412495028588, 41.63151533372941, 39.91758077375351, 39.43248556506249, 40.72592635308543, 42.18013724973125, 41.202027566971324, 40.488619035290135, 42.61200981755411, 43.12092950267177, 42.289010478604226, 42.83136444707071, 41.82244062423706, 41.18693428654825, 41.86056998468215, 42.38737567778557, 43.981756394909276, 45.159753984020604, 42.944673876608576, 44.29093722374209, 46.288168891783684, 44.54289067176081, 48.4900188446045, 44.59414820517264, 44.91313888180641, 43.70202472133022, 45.41467666625977, 45.497379841343054, 46.081875754940896, 48.3381054478307, 50.6076947335274, 52.69612150807535, 58.11902969114242, 65.42964519992952, 65.78755755578318, 64.35912055353965, 10.966653804625235, 0.7807593047618867, 2.9321889050545233, 0.05279561196784339, 2.5109099236226853, 55.99283049183508, 63.444286546399525, 47.130454740216656, 42.819126652133086, 14.378327458135544, 32.48320271891932, 48.50171535245834, 44.45213879308393, 48.71618270874024, 14.55080976409297, 0.671647179030603, 0.03150340278572854, 0.04704986060518892, 0.042980439855807254, 0.05573170522468225, 0.020258132210602204, 0.09076499410213963, 0.018712593873421994, 0.0559263298618457, 0.049599826395992315, 0.06114294812563927, 0.03508031518468934, 0.044487009215499126, 0.04077254381451396, 0.07538128208609358, 0.02003160192661228, 0.03369528567418456, 0.11903294136807804, 2.8123769212153653, 64.5705206163468, 62.9499266993615, 70.51628466575377, 53.05664616246378, 40.17902243521906, 41.3940118974255, 43.115167540888635, 64.3011086986911, 76.06379478208481, 39.423758291429095, 0.18857425859858915, 0.08767760614113462, 0.7457112112352926, 1.0883057309735207, 13.219947603441055, 67.1028341785554, 69.93483251140964, 67.81475220957111, 66.19791984558105, 58.53671504605202, 54.60044007147513, 54.1405813924728, 52.30623399057696, 50.55169897694742, 49.42635528502926, 47.83672455818423, 47.47575667596633, 48.49228205219392, 48.452520985757154, 46.860250503786155, 45.78559952397501, 45.65774986820836, 46.074674283304525, 43.54169391816662, 43.35754648331673, 42.582231183205884, 45.20659885098858, 45.079470911333644, 47.05351352691651, 44.2232959501205, 45.30503465283302, 46.481455449135076, 46.70825473723873, 44.86658819260136, 43.914275938464755, 45.59492918752855, 46.82197209327452, 44.04451824003651, 42.96996924184984, 43.027024038376354, 42.18786824134089, 42.94966313146776, 44.37320109336607, 45.66997981840565, 44.78752889940816, 47.01377991707095, 45.829377097468225, 46.652961084919596, 45.63658868112872, 45.37879090155325, 44.5204782485962, 46.61004251049411, 46.156518459320075, 45.3587358228622, 41.85716536737258, 44.075799142160726, 44.444501938358435, 45.74091980534215, 48.96457072227232, 50.53202044579291, 48.29876407500237, 48.300627200834214, 46.22271237834808, 46.03995346253919, 46.168748409517356, 54.368306359937115, 57.648839489106216, 58.86164419112667, 40.226989100056315, 54.20188803826609, 58.099892447071696, 53.83271848001788, 49.375693951883626, 46.92045104119086, 49.153895685749674, 48.1907537675673, 48.721795620456824, 49.66721627020067, 47.80040341038858, 47.6579233138792, 47.38626780048494, 46.35161715169107, 43.70234243331417, 44.64058906801286, 44.20727699033676, 44.238197034405125, 44.70093473311394, 43.548781641068004, 43.7406208438258, 44.46101903915406, 45.24930561742475, 43.55679504333004, 43.38327723164713, 43.840205900130734, 42.49949270679105, 43.7872774370255, 42.27252475676998, 43.70981062612226, 42.66366351035334, 42.62809545763078, 44.04025854602937, 44.65416046880907, 44.22579449992026, 44.31838989257813, 44.658494687849476, 45.84850257442844, 44.567268202381754, 45.21871505245086, 44.91307220151348, 44.86443481137676, 45.059945352615856, 45.591583405771566, 45.83352304274037, 47.57522406116609, 47.36498894230012, 48.21972439366002, 48.078001314593905, 47.01869464689686, 50.41963669561571, 48.185540937608295, 49.21400993101059, 48.24225448792981, 47.52500595584993, 48.530266284942634, 48.34717004529892, 51.68842538710564, 52.93955949044997, 55.14896392822266, 60.41670706964309, 66.61766836720129, 68.17919531176167, 69.08369387349775, 11.566265552274643, 0.6372228649354751, 6.088469682201263, 0.025100415016734795, 2.9379790588732693, 59.04464629388625, 70.80639885317895, 54.128304373833444, 40.37618037193052, 16.982278208578787, 40.555687642866566, 55.83851268214565, 52.337895362607895, 60.97889646407097, 20.76772039936435, 0.9023248945032397, 0.050316681679818905, 0.12528125406993976, 0.061433544427516966, 0.056474324045402396, 0.024572921346031854, 0.05863145143995362, 0.10179182619697626, 0.027534910289931203, 0.12575082000224821, 0.25711522587845403, 0.12452538575856917, 0.18498663820566671, 0.1538403990167764, 0.24413680777915064, 0.16075490943847165, 0.2917440854493649, 0.309622616416985, 5.479128495339425, 76.9201187933645, 71.96509838104248, 76.1878828848562, 65.44910800072455, 38.26940082734631, 41.39631432871665, 54.096227230564246, 70.28479422292402, 85.78320841635428, 44.99558318045832, 1.0112845993811086, 0.1747928577805719, 1.7974627811101176, 5.067726287149615, 14.409239657463567, 69.73203812876056, 72.72591267862629, 71.74278628441596, 69.26566831527218, 61.49482150231639, 57.604897176065755, 57.40367958622595, 54.341147868864006, 53.28126461275163, 52.42489745540004, 49.2410272167575, 49.94379828053136, 50.53524855644473, 51.264887855898955, 49.95609491102157, 48.311833412416526, 48.93460381415583, 47.14360644740444, 46.74991815320907, 46.8658830273536, 45.29795085230182, 47.289036166283395, 47.80101922250564, 49.31413235202913, 46.991018402961, 48.18045754586497, 48.16445035319175, 47.85344562222881, 46.54296998054751, 46.269200309630364, 47.48785326557775, 48.72004624335997, 45.919320967889604, 46.20350845398442, 45.704543744364095, 45.8000377685793, 45.00971940255935, 47.85759156750095, 48.668129751759196, 46.539149591999674, 47.51198760924801, 48.37049638071368, 48.84093369207075, 48.804408581026145, 48.281972408294685, 47.86264358028289, 48.700508917531664, 48.159296358785326, 48.776132214453916, 45.940772410362, 47.248372954706994, 46.57570215963548, 47.652639881257095, 51.971075304092906, 53.99252760794855, 50.71173952471826, 50.34981066180814, 48.253696041722456, 49.47044664813627, 49.69512001160653, 54.40733786552183, 60.97291877192836, 60.166067615632095, 44.8906833125699, 57.58245729630994, 62.44454891450944, 55.88519673193655, 51.912176993585405, 50.0518125103366, 51.70498955634333, 49.70748724475984, 51.6454009086855, 51.89579717574581, 52.4644898599194, 51.71298726912468, 49.981602084252145, 49.079876638227894, 45.63603170456425, 46.66832108651438, 46.85986218913909, 46.31377020189839, 47.16374781823928, 45.35713157346172, 47.979769475998424, 48.407907947417236, 47.6708592907075, 45.96524800023725, 45.56227937821419, 45.00098036181542, 46.134827752267164, 46.72383439156317, 44.704060862141276, 45.79417382517169, 46.744171880906634, 45.0388273116081, 47.16840759400399, 47.874457759241906, 47.225513381342736, 45.87954813434232, 46.73796276892386, 48.20133632229221, 47.54889319019933, 47.97974594177739, 46.30985175409625, 47.405275606339984, 46.582527083735314, 47.8657304856085, 48.11636209487916, 50.42813647177912, 49.29078248239333, 49.8702734516513, 51.10762042383994, 50.67143324882754, 53.170932262174546, 51.358271644961455, 51.065356885233236, 49.72135282331898, 50.879730716828384, 51.10274884008592, 51.32390775988179, 54.55377171116491, 56.23463676821802, 58.17886937049128, 63.06832736538303, 70.82215893653132, 71.63491325993692, 72.12731976662913, 13.26218270486401, 1.9785917069642776, 5.1644558579691, 0.2256367496785618, 3.7541178974413105, 68.52484241608651, 74.3507388330275, 63.665198356874534, 56.22350900403915, 21.006384857239265, 46.57763588813044, 65.53490984824397, 62.412609054196274, 75.27308417904761, 28.659289921483687, 1.1382123755831872, 0.1495443924420303, 0.14409205275437525, 0.14520991293172683, 0.11313693718083444, 0.10284711231267261, 0.15510874950597364, 0.15674888246482419, 0.14079280317791049], [0.12240480841888536, 0.04879688198167471, 0.10252443607896568, 0.03398706941234489, 0.05799955913736936, 0.04183670888925272, 0.06516596692944727, 0.05407504391886535, 0.09342699642142943, 6.1180551398185, 63.785485682948945, 56.217597992189475, 50.16479638315017, 20.98494714306247, 11.83361626440479, 29.538220513251524, 45.81275409267795, 57.89226962674049, 68.7785726977933, 27.351393238190685, 0.00970550183762586, 0.2653208855659731, 2.4106867467203448, 1.2715675681829453, 23.61295477036507, 66.80005858021399, 68.24393795382592, 70.25223070575346, 62.666998294092, 61.40441871458485, 47.79256651478429, 47.21764510677707, 46.505472121700166, 47.02240520907987, 47.19548371530349, 46.260088643720074, 44.81371464267854, 44.66669244150962, 45.18801858348232, 45.82441529920025, 47.50050683175364, 47.896026872819476, 47.074470750747196, 50.290457356360655, 48.502703789741766, 47.41140234854914, 40.405555002151, 42.827206734688055, 44.006788961348995, 41.993185320208156, 42.87955860937796, 44.18238170685307, 42.675328639245805, 46.00341658438406, 44.2663674969827, 42.48963579054802, 41.860652354455766, 42.62616172913582, 42.34862266048309, 40.58237937188918, 42.034170166138686, 43.06827952784877, 42.73393277199038, 42.61506142154817, 43.869223594665534, 44.16186378848168, 43.2126933528531, 42.71427385268673, 43.12784464128556, 44.46032085726338, 41.53264022642567, 43.67232061201527, 43.16634662689702, 42.418868387899096, 41.072848227716264, 41.4373109417577, 40.70820116227673, 42.62181966535507, 44.30055487540461, 43.52237624506797, 43.43050256852181, 45.24513613793158, 41.84008344527214, 41.75324609202724, 42.04484293537755, 50.8130935699709, 56.68312057372063, 59.06340306805026, 44.784881299541844, 55.48398533175069, 58.758411330561486, 51.60196850376745, 46.86951121976299, 41.89868757801671, 43.871706454984604, 44.8587473746269, 46.12262133629092, 45.315052386253114, 45.89205265045167, 46.04788449502761, 43.85764475791685, 42.127753996079974, 41.865731823828916, 41.22509110358454, 44.8559703365449, 43.078505146888, 43.80138228016515, 43.3865681002217, 43.52315287436209, 42.688770601826334, 40.28538534718175, 40.4450571921564, 42.39431042825022, 40.06486969609415, 39.97201542700491, 40.787633080636304, 39.38456204629714, 40.3192550136197, 40.40954405261625, 40.05962940954393, 41.938707520884854, 42.19586987649241, 40.05529126813335, 40.13525270646618, 41.810379335957194, 42.048098502620576, 42.08260751539662, 42.32420590616042, 42.53002443621236, 43.55069968008226, 43.86365382902084, 45.4031958887654, 48.9826097026948, 48.384138384173, 47.10244901718632, 49.48636362629552, 46.47278701105426, 47.863906583478375, 46.578137951512495, 47.939051351239605, 45.90522004712013, 48.23515499791792, 45.858167294533025, 48.87706264372795, 51.19866648027974, 58.52440664845129, 57.39960032124674, 57.17012989905573, 58.55338904165453, 65.25764926787346, 65.27715521474039, 71.22782614923292, 17.452337011214226, 0.1422884979195172, 4.790973653716426, 0.06475951132034102, 0.43606475416210394, 37.54732385758431, 74.46721753766461, 46.19545190565048, 49.19799097122685, 40.73571266666536, 29.62251813180985, 55.91598341541906, 51.91027072168166, 52.88779204891574, 32.08492329043727, 3.045068099614113, 0.06887067620071673, 0.04917354826184531, 0.053580017054393414, 0.043988745629547105, 0.07191577610830147, 0.022790447335630175, 0.0653677085234273, 0.02625226460006689, 0.04472851077274931, 0.02774104539815697, 0.10535145373714548, 0.08179893852361748, 0.018551855220369274, 0.01884658839703808, 0.04015358307609155, 0.08566799663728283, 0.20830987862521605, 10.111326075369313, 74.01750210792788, 64.07050471152029, 61.38847035746421, 28.230967098666778, 16.993039231146536, 23.412923697502386, 50.59851246495401, 63.333310927114184, 75.40372264000678, 29.349860452836563, 0.0741065347627286, 0.20684046069941214, 0.8060736689836749, 0.3879829309880734, 27.480109737765407, 70.52338415576567, 69.5046740193521, 72.048307541878, 65.54617881774902, 62.44591782169958, 50.23273967927503, 48.95645141601563, 48.755029862926854, 49.635146971671816, 48.40335799801735, 50.083489571848226, 47.33673610994893, 48.32240027766074, 47.119166158860736, 46.504295410648474, 48.959871722805886, 50.040559230312226, 49.251754899178785, 52.391859331438624, 50.45920556591403, 49.471415473568825, 43.224433006778845, 44.26538690443962, 45.46906032869893, 44.041607841368645, 45.060361123854115, 46.312444440780155, 45.052728191498794, 47.57288632854339, 45.688014876457956, 44.47765773342502, 43.562455023488695, 44.04940551327121, 42.90075509778915, 43.47937922323904, 41.70897822226248, 44.422254254741055, 45.8857141002532, 44.31087463132797, 46.57225439625402, 45.22941920065111, 44.64384855762605, 45.79800598083004, 44.615015214489354, 45.22615578866775, 44.0229687383098, 46.177911066239886, 45.47723847050821, 45.34526248132029, 44.28490854078724, 44.290631278868645, 43.39825284096503, 44.524275102923, 44.850628068370206, 47.840941106119466, 45.668603066475164, 46.5642096150306, 41.32884563938264, 45.113360189622455, 45.57911811336395, 53.09643468549175, 57.39625061711958, 59.80985364606304, 46.94282424065375, 55.840030639402336, 60.19090798593337, 53.381657677312056, 49.13072232277163, 44.042051069198116, 46.88412597102504, 45.64850091934205, 48.098323114456676, 47.27716707414197, 48.91335241256222, 48.31043704863518, 46.639468131526826, 45.4129586681243, 43.225021362304695, 42.505231134353146, 46.12138971205681, 44.530472447795255, 45.275201105302386, 45.62577078419347, 44.354899314142045, 46.26179095237486, 43.522058533084014, 42.42206511958953, 43.782170511061146, 43.52318817569364, 41.105529415992, 42.193414472764545, 41.95384394737982, 41.90648132754911, 43.14097673662248, 42.99355445369598, 41.9445949985135, 44.7721649754432, 43.53361383561165, 44.75181571898922, 43.654501284322436, 45.532677250523726, 43.22221294526131, 46.5478023405998, 44.47105246205484, 44.42076375407558, 46.490884827029326, 49.95882880303168, 51.63770129603725, 51.429643092616914, 49.13546839068013, 52.159843291005785, 48.47789479840187, 48.53591449799077, 47.527575108312796, 50.676575476123446, 47.373006266932336, 50.442033429299634, 48.675425360279704, 51.92852935483379, 54.4355240175801, 62.55775636242282, 59.464673303788715, 60.16107051603256, 59.588647657825106, 67.63722573557209, 66.89300306381719, 74.49585868466285, 19.143400230715354, 0.5630097213772036, 6.676937976191121, 0.1516130136986894, 0.5289292275424927, 40.79457175347113, 80.06953101004325, 53.11397552490235, 47.678068607084214, 37.26805110131541, 38.73817113138015, 64.37164860387003, 63.8022538154356, 63.550257221344985, 43.1899671400747, 3.752273648015915, 0.07583620807816906, 0.08164282512640761, 0.0466617911062654, 0.02589830133553234, 0.06995971615035688, 0.030346068012858593, 0.0452384035733919, 0.0886991077793702, 0.18384201091624078, 0.1408818838817458, 0.22234560531233588, 0.19010651105594253, 0.1188980945716462, 0.10701501366472053, 0.1809229707765964, 0.12762024307683592, 0.49761011295260926, 16.0856302707426, 86.71702277275824, 71.80676014192643, 71.75634199573149, 35.04698153465025, 18.846335603344826, 39.98710478505781, 61.03400184262184, 68.02031578556185, 83.6731929163779, 34.28852065916985, 0.2516237084543513, 0.71487347565351, 7.896059655374097, 2.9741526274911823, 31.406710186312278, 72.37639811731154, 71.6825072996078, 74.99492537590766, 68.71786225226619, 66.16088482641405, 52.367540636370265, 51.498312027223655, 51.791477818642896, 51.370929133507516, 51.622753143310554, 53.091935726904104, 49.47137232749693, 48.78434957996492, 49.32726836973622, 51.626769650367, 52.43133798722298, 51.419209587958555, 51.83275291996618, 55.16585365418465, 52.35083918417654, 51.33762036600421, 44.43887725953133, 46.63545554684055, 48.835944437211566, 45.72213165221676, 47.606018589388945, 49.286036414484826, 46.13930709900395, 51.74187552544379, 48.95818510363179, 46.78124220140519, 45.90802061942316, 46.663323986914854, 46.23694273733324, 45.255487272816325, 45.90590253953011, 47.96221294710713, 48.69126781340569, 46.914469426678075, 49.92865793166622, 49.761157035827644, 48.22441554838612, 47.33993284163937, 48.24916178180326, 49.315363976263235, 48.3345204014932, 49.43369796199184, 48.25871667554302, 47.347891330719, 47.14094315805743, 46.6662932211353, 46.66723851234683, 46.839803188077866, 48.696159009010564, 49.86559014166556, 46.94990019644461, 50.60085411994688, 46.48143583728422, 46.44132175753194, 47.1859602005251, 54.9188070912515, 62.148198158510276, 62.39464852117724, 51.63855637273481, 60.78269950805172, 65.47562714545958, 55.296366599298295, 52.47067543768114, 47.02782592465801, 50.108412311923125, 48.188447413905976, 50.92774837247787, 50.83131297942131, 52.10831511405207, 51.29731016774332, 49.606960819613555, 48.30549486221806, 46.93622681402391, 45.68029172958867, 49.88297016389909, 48.76215288715978, 48.398517793224705, 47.23866116616034, 46.86985246596798, 49.03469877858316, 45.4777209220394, 44.86729421923238, 46.9280251379936, 45.18895995232367, 44.59891780730217, 46.47374799174648, 44.8120201787641, 45.996195500896825, 45.139036024770434, 44.747634472385535, 44.81578173175935, 48.674605584913685, 46.10661806598787, 46.67864476480792, 46.46889994221349, 47.77723004741054, 46.50925328654628, 48.55214918813398, 47.84536553967384, 47.88025894472676, 49.01473783677625, 50.87454926583075, 53.52194124652494, 54.86745542095554, 52.569566234465576, 55.87557515790386, 51.320695338710664, 53.087974133030066, 50.113550616848855, 54.00231784389865, 51.73407785354122, 53.66661394796064, 52.31368649390436, 55.53475256889097, 56.636918975460915, 66.0984956064532, 63.04398513609364, 64.12632788381269, 63.30162209849205, 72.1683712928526, 69.89024300729075, 77.2306057714647, 22.19826763676059, 0.45275578756005536, 7.854028517200102, 0.19408351861901824, 0.6630601914178941, 46.508088342605106, 86.0106509731662, 61.731697359392726, 65.7638938965336, 53.10544044740739, 44.02066238464848, 74.37653233928066, 73.83767712500789, 74.23115361121394, 52.61445776108773, 4.7519774494632605, 0.1434025123354889, 0.3072763342530497, 0.15250650204477773, 0.17845868042880492, 0.12986662737544508, 0.23191902305810685, 0.17598228589180978, 0.11933191484140775], [0.057662507263763305, 0.037011461963336316, 0.029012714963286158, 0.0479766316411476, 0.03212336326889213, 0.02668874319492569, 0.013083292663307681, 0.05681321836046635, 0.10966078258089482, 10.065572607901789, 63.543891214555316, 54.95642654357418, 54.56863357174782, 26.966004679279944, 31.063855809550134, 44.10756249581614, 46.51692544260333, 63.9795135682629, 68.32525653223838, 28.362513588320827, 0.09654813821637824, 0.0887699785732454, 0.8626574746543362, 0.31671950172993446, 25.730209004494455, 70.02838104001938, 65.45614865518385, 72.241790217738, 63.98476169955347, 60.470749485877256, 48.94017750217069, 51.41531859674762, 47.27259751289122, 49.82377767562867, 45.62981867021131, 48.51130162515948, 47.772605572977376, 51.41371434734714, 49.4546865647839, 54.83272283307968, 52.06869917531168, 54.023204465066236, 57.62454825062906, 59.40351570806196, 58.239309172476496, 57.31299831021217, 51.062344504940896, 43.536284969699004, 43.642698872473936, 41.262483058437226, 44.57227314672163, 42.841146838280466, 41.14072876591837, 42.342174283919796, 42.49550757869598, 43.31602427267259, 42.087839957206484, 40.37878874809512, 40.985685317747055, 42.128985620314076, 40.8939528465271, 42.393788753017304, 43.22058908400997, 42.006270347103, 42.39838969322943, 43.59166491416193, 42.924920820420795, 41.526003576094105, 42.47076134527884, 44.33245943438622, 43.91339340517598, 43.52937767582555, 43.751615247418805, 42.07149544069844, 41.60700836489278, 42.4289841805735, 42.06203860621299, 41.92849759132632, 40.78771545040993, 42.71069272871941, 41.25219075910507, 43.49211908155873, 40.754845988365915, 43.12646788935508, 45.07340300467707, 50.76706847836895, 52.9993599460971, 58.41905963036322, 43.967565259625836, 52.312203837979226, 55.06733548256659, 49.11924546764743, 45.20450430531656, 43.81566755233273, 42.05793188464257, 41.47795061911307, 42.25532516356438, 40.91520032575054, 43.2699481902584, 43.43058493829543, 43.43370322258242, 41.67227268218994, 41.4604058573323, 41.54616063640964, 41.36987363138507, 43.545910466101866, 44.58539347494803, 44.66112267586493, 41.863594132085005, 43.37528736360612, 41.71940780455067, 42.485709498005534, 42.514554608252745, 40.160297040016424, 40.690236706887525, 43.05851674848988, 38.824004357860936, 38.41297918750394, 39.54926629220286, 40.78222020979851, 40.0047319166122, 42.4685138271701, 41.38633189662811, 41.67560669683641, 42.98687073492235, 41.64194883838777, 41.5742330397329, 43.46193252071258, 43.0261807287893, 45.29999048479142, 49.33798036267681, 51.920606167085715, 51.881335396920484, 52.55228819385652, 52.144224412979625, 51.8046687495324, 50.436738229567005, 51.313278136714814, 48.73055819542178, 51.477397949464866, 50.31847092413133, 51.427324971845074, 53.528581819226666, 58.93068182852961, 59.12906746710501, 63.050539416651574, 62.01636337464856, 66.68933791498985, 60.16127840165169, 65.88947249997047, 63.90538077200613, 75.25884597532212, 22.08050435589206, 2.044225830224253, 7.811684570004863, 0.07342866186292903, 0.10882732488455311, 22.516977863927043, 78.44829774671986, 51.59866586808236, 55.744924929834184, 27.00189240517155, 29.474385899882165, 52.216286197785415, 44.84445033534881, 53.5020116836794, 45.34750607705886, 5.492494461997863, 0.2228479138425281, 0.02692022049168666, 0.03662007913414029, 0.05981727510750775, 0.06054633417196813, 0.0798039306556025, 0.04899106228784208, 0.034805331754708485, 0.011197860266322331, 0.013064937196641922, 0.028148799526294874, 0.01982164403964435, 0.040970420494915984, 0.0652960486589901, 0.07601388685044742, 0.09593355184000346, 0.13298667366466216, 14.656856925256792, 72.56993570635396, 60.83349812415339, 64.39686944407802, 30.556481538280366, 32.31589598040427, 43.6888220233302, 51.016507687107215, 67.38656274734005, 76.22447075382357, 29.428213719398748, 0.08004148686004263, 0.05086845267684229, 1.470416904457154, 0.7389382585402459, 30.114673606811035, 72.76868220298522, 67.6993090106595, 72.54466779770391, 66.00557465707102, 63.00944866672639, 50.55074976336572, 53.138768826761556, 48.671095063609464, 51.32316250954905, 49.58561528113581, 50.93340050789618, 50.200407581944624, 53.10360870053692, 51.92646226575298, 57.3692843221849, 55.085480366983724, 58.424225391880164, 59.8087122363429, 61.19385019425423, 61.78232731357698, 59.61798306434386, 53.19429389892086, 46.491461415444654, 46.80046573761971, 43.77043085713541, 45.900619106908, 43.64851966980965, 42.909717713632894, 44.06274157185709, 43.62243590816375, 45.5322418674346, 44.78734454801006, 42.41240432185512, 43.09015850866995, 43.713944804283884, 42.60916217680901, 44.28065669152045, 45.01747785076019, 43.53302940245598, 44.27710302414433, 47.30719281781105, 44.92305071123185, 43.07140565687611, 45.3900049578759, 46.9234634214832, 45.332240212348204, 45.24586569878363, 44.752470754808, 44.715149402618415, 42.63746992234261, 44.91123653227284, 43.303751176403416, 43.91090270011656, 42.28668843546222, 44.93352343959194, 43.48323491311843, 44.64291503352504, 42.375212407881214, 44.49199399640484, 45.54903353414228, 52.55414347494803, 56.93575259177916, 60.077127871974824, 47.65567971814064, 55.881595996118364, 58.079300003667036, 51.97229516121649, 47.56692824825164, 46.833668601128366, 44.17928303441694, 43.56117633081252, 44.252352868357015, 44.852695157451016, 47.35952115827992, 45.47936047277143, 44.222115316698634, 42.81096027743432, 43.55130764745897, 42.323135099103375, 44.235400384472264, 44.45289188815702, 46.350440440639375, 44.90709843174104, 43.54745587994976, 45.422270374913374, 46.012736135913485, 44.87064784572971, 44.02506720635199, 42.46972976192352, 43.347320864277506, 42.54156797162948, 41.693998690574404, 42.16291019993444, 42.33856962573144, 43.06544757658436, 42.774560682235226, 44.66948516907231, 42.46563088509345, 44.4997642117162, 45.694663293900035, 43.6921521156065, 43.17803921238069, 45.731462970856704, 43.647978382725874, 48.79858386132025, 49.66727902812343, 54.8961946272081, 53.837362566301906, 55.51719603999969, 53.86279129212903, 52.973946909750666, 53.08866447018039, 54.9019330547702, 51.94698802886471, 54.1867123880694, 53.42786319794194, 55.95127297985939, 55.713063516924464, 60.788273196066584, 60.20524032654301, 66.86918643213087, 65.01453684222314, 69.33605917038457, 61.981360143230816, 68.29102208537441, 66.92986549869661, 76.17942625476469, 24.12083894975724, 1.3953969170970302, 2.5973342022588177, 0.13866055065826063, 0.08074413504331343, 24.604045537210283, 82.29272257897162, 57.484323516968765, 60.99555084782263, 34.9117656677, 37.843796207058816, 56.327545950489665, 51.80445301917292, 62.76299045931909, 58.659465620594645, 8.34598885428521, 0.1791760758046181, 0.0722143282332728, 0.02110326700212975, 0.04309020110315854, 0.07587091186113896, 0.022648912591619358, 0.07159841652478903, 0.04654276019503032, 0.10374454601157097, 0.14106594416643345, 0.13157967658292863, 0.1489870175118408, 0.14250614349880528, 0.11342949849823791, 0.178682699859623, 0.1788046304136515, 0.18762199598695004, 20.41189866681253, 86.44506131449054, 70.01728073243173, 74.12791682827857, 40.07415394629202, 44.440775686694735, 59.412490091016224, 60.23621136142362, 73.53476032134026, 82.52438560608896, 33.49100866625386, 0.19508166989732176, 0.25701388776783024, 3.534377895055279, 2.200407256041804, 33.11616736073648, 72.998807660995, 68.65632026426255, 76.01172139567714, 69.70795477590254, 64.82343504505774, 54.61892620209725, 55.82200342609037, 52.69028109888877, 55.339563662006015, 52.03719469808763, 54.60010274764031, 53.38093988357052, 56.82191364226803, 55.613400013216086, 62.23050125183598, 58.304169485645915, 59.56499576568604, 63.94230596480831, 63.80856098667268, 63.871970022878344, 60.34892066832512, 56.13989976144607, 47.313001848036244, 49.42493146465671, 44.740935064131214, 48.39623889615459, 47.7189750056113, 44.68014224883049, 46.82507076571065, 47.2184060465905, 47.32614571048368, 48.15701746171521, 44.028573805286044, 44.29338870509979, 46.98979462346723, 45.23536943620251, 47.36096066813315, 47.830727254190755, 45.07567797937701, 46.96216937034361, 49.54725057848039, 46.71160444136589, 44.9609015833947, 46.50083588015649, 49.269742888789025, 48.2807368616904, 48.93359968739171, 48.28230580975933, 47.115765463921335, 46.610426902771, 46.56290346576322, 46.604861059496486, 46.69095708477882, 44.08122770247921, 47.58308449099141, 46.12748899767476, 47.210769191865005, 44.00800489610241, 47.045825681378766, 49.51931153574298, 55.545303744654504, 59.55125962534259, 63.102985428225615, 50.86236246170537, 57.368064465061316, 59.73202989947412, 54.82214027835477, 49.27890946788173, 50.520598503851126, 47.64579142293623, 47.23912792821085, 46.17562040205925, 45.086009502410896, 48.09968809927664, 48.306793166745095, 48.28207438991916, 47.39483425694127, 46.82531395266133, 45.265022554705226, 45.60385650204074, 48.25658290616928, 49.45402760659495, 50.22702086356379, 46.43579513795915, 46.86464748074932, 46.77534295666603, 48.05462006599673, 47.196989905449655, 43.82490081171836, 45.07768231053507, 47.33453958265243, 44.681381717804946, 43.497861431490996, 46.589854071217204, 46.03709797705374, 45.59120293586485, 47.93740787813741, 45.41426873976185, 47.68550542093093, 50.03764098690402, 47.085331793754335, 45.92104288839525, 49.540319750385905, 48.477871264180834, 51.724695544089045, 54.984647996964, 58.62203836441041, 58.352304812400575, 57.41510937290808, 56.29096592626264, 55.45252792296871, 57.448775076097064, 58.28317696048368, 54.094834789153076, 55.7259092792388, 56.20443451789118, 58.343750123054754, 59.29197526747181, 63.02016850440734, 65.05126591651671, 69.29696882924726, 67.2406348874492, 71.91460963218444, 66.37525804581182, 70.93790023557602, 70.64743303483533, 79.19232429996615, 25.05526519590809, 3.5650731382831453, 11.27137685975721, 0.36725029349327093, 0.459814123328655, 28.20334576791333, 91.53381886020784, 63.766764210116484, 73.98638202298072, 39.387464600224654, 40.482237339019775, 67.58112015262728, 62.65453300168438, 72.54069051434918, 71.25881287359422, 10.340032615969259, 0.32203342465143053, 0.13293474822515441, 0.06583294605896359, 0.2604487502286511, 0.08488577490131702, 0.19683948928310027, 0.21625503777496277, 0.22142728039574242], [0.03359956681848534, 0.02924685633080381, 0.04369750964425264, 0.04749390431829999, 0.04801593195166319, 0.028696088908961224, 0.030475291723926223, 0.06573837250471115, 0.016883725578325893, 15.630640233716658, 65.08553566471224, 48.51740875551778, 46.832244780755815, 23.385496524072465, 27.13388212265507, 27.64525328913043, 51.32675932299707, 62.50411402794623, 71.32904683389972, 19.190484362263835, 0.10354704854469146, 0.13806756796135058, 0.36359829107119196, 0.7313576653119057, 43.002799480192124, 75.8340850953133, 67.43836941257601, 68.4552203455279, 60.211068968619074, 52.568142414093025, 47.52619051164197, 47.37963115015338, 49.2967091837237, 52.58316116948282, 53.96301961714222, 56.88375373040476, 55.19203155271469, 56.33650856633341, 56.410268737423806, 56.5398677702873, 56.562444932999156, 56.97902810189032, 57.385358195151056, 58.915870958758944, 59.33278752911476, 61.14352618494342, 57.93055980436264, 51.61654403132778, 41.36948531673801, 42.91693879712013, 41.01662105129611, 42.38179414503036, 41.514361981422674, 43.56378470697711, 41.42055849875174, 41.74478553956555, 42.26515070084603, 42.324825640647646, 41.9362364276763, 40.279835193387925, 40.8306771709073, 43.08085072425104, 43.84615221331197, 43.06431008923439, 41.56293661363664, 43.381555311141476, 42.00210871235017, 45.11688247803719, 43.6635031238679, 42.74918294722035, 42.7719013152584, 43.37204748584379, 43.934385930338216, 41.77827473609678, 42.00919251288138, 43.256188515693914, 41.559092690867764, 41.40353541220389, 43.29160359597976, 43.57130389059744, 41.8910821022526, 42.75541951579433, 42.05843002565446, 43.06581235701039, 46.349757948229396, 51.38451230141425, 53.057791494554095, 56.656507292101466, 48.40617033743089, 53.11379901824459, 55.06202851572345, 50.81309749234108, 47.78892263289421, 43.45647650380289, 42.332595855959006, 42.894149826418975, 41.2167796011894, 40.104207146552305, 42.62607935936221, 40.89490990484915, 42.136261616983724, 41.476868044945505, 41.56776112894858, 42.15308466265279, 42.439747164326334, 42.60509075657014, 42.426768041426136, 42.51539007309945, 44.04276886293965, 41.576617840797674, 43.691677508815644, 41.75893745114727, 41.868622610645915, 41.706099202556, 40.08919231353268, 39.82408323595601, 40.901750518429665, 40.83968293282294, 40.274434089660645, 41.479578402734575, 40.4464457111974, 40.408853715465916, 40.8880026109757, 39.76744028829759, 40.96467318073396, 42.67321448172293, 43.051503550621774, 42.70620161487211, 42.357330322265625, 47.49290920072987, 49.34947682965187, 52.22191479898269, 55.07958896698491, 53.83874324060256, 52.53890898919875, 55.459423449731645, 53.94669471248504, 55.04308739016133, 54.00181970288677, 57.02391962851248, 57.17532311716388, 58.6822545912958, 58.808276422562145, 62.33093354009814, 66.0022641766456, 66.16257144558814, 64.03854523935627, 68.28719385208623, 66.25366457047002, 68.86952461734896, 64.63890321793096, 73.82521183260026, 22.522380928839407, 0.41508733625373534, 0.9850827376207999, 0.047645513118515094, 0.07569693329353487, 12.558260425444573, 73.84939716708276, 57.49565132202641, 47.56237045411141, 30.238853885281472, 23.565717666379868, 37.886118581218106, 41.302648129001746, 51.82917179599885, 59.727581931698715, 17.17064807491918, 0.3034677128157308, 0.04821447129811972, 0.007369714120643274, 0.05238044976947769, 0.032206566163128426, 0.03808722560924869, 0.07249915206264104, 0.03195697471739785, 0.030854131778581973, 0.07811304437176836, 0.02215636785202209, 0.12614325620234013, 0.039110615654217626, 0.029086314945391593, 0.06021201723225175, 0.031523298089122104, 0.09537591643991972, 22.974561568229433, 74.75828093867149, 56.01268552964734, 55.446585532157656, 30.85087307037846, 30.116607335305986, 27.839418457400416, 59.52408936715896, 67.00927780520531, 76.39689030185824, 21.378474620080766, 0.20672081308739804, 0.1355728332794482, 0.9246106986557284, 1.0833732279077655, 44.9518056069651, 76.22526307259837, 69.14376889505695, 71.04606351544781, 62.396903884026315, 55.357139802748165, 49.4249040080655, 49.78416565925845, 51.357365577451645, 55.11874991078531, 54.63519619357202, 59.604874503227975, 58.51984885431106, 57.595412884989095, 57.73979533103205, 60.29392119376891, 58.165533311905406, 60.215544392985684, 59.596978772071104, 61.48448997928251, 61.88665451542024, 63.06989239108179, 60.40252770147016, 51.44403819114932, 43.695133116937455, 44.68661808198498, 43.058293173390055, 44.267579509365945, 43.64587599231351, 45.35648830475346, 44.38703529296383, 42.710931993299916, 45.119247667251095, 44.47169965313327, 43.419382649083296, 44.075622635502974, 42.99393100123252, 45.10241677684169, 46.47510905419627, 43.89866882754911, 43.905878143925825, 45.40094444828649, 43.90013187162338, 46.75598605986565, 44.806681832959576, 45.16527275885306, 44.87742570138747, 44.18732781564036, 47.01716884489983, 45.15756530146445, 43.015009818538545, 43.96256816002631, 42.169201681690836, 43.34881920968333, 44.4045800547446, 45.278699859496086, 43.28517090889716, 44.77909188116751, 43.86978449360017, 44.97821100296513, 47.271867952039166, 53.99079392033239, 55.62018179124402, 59.87346272314749, 50.74059247970582, 55.20173941889117, 58.2619216365199, 54.95961543052427, 48.6631561863807, 46.1902782993932, 45.29714676641649, 46.02788825188914, 43.857919323828916, 44.41162070920391, 44.05528906852969, 44.32921563425372, 43.22432318041402, 44.575501257373446, 44.310792261554354, 44.2985583889869, 44.50719710319273, 44.79071778635825, 44.05973311393492, 44.00927182166807, 44.38308938857048, 44.66326821234919, 45.123597575772195, 45.01657570562055, 43.32454758305704, 43.50407054347377, 42.7082137907705, 44.101773077441806, 42.39687565834292, 42.00193612806259, 41.61160538273473, 44.160118333755, 43.29260772274387, 42.94413651189497, 44.708379391700994, 42.75550973030829, 42.6301468572309, 44.91676315184563, 46.204261549057506, 44.89035383347542, 46.243093013763435, 50.88570840897099, 53.09543840346798, 54.610477416746086, 57.649804392168605, 56.5899956610895, 55.86687534086166, 58.18955782921084, 56.48100476111136, 56.661771112872714, 57.177790288002264, 59.77477196724185, 59.56748254837529, 60.28539788338446, 60.35371772704586, 64.72468153122934, 67.49024668047505, 69.69314390613188, 67.30580114549207, 70.07326079953101, 68.55763343072707, 71.91616289077267, 66.66301096639326, 75.65120850839924, 24.585988906122026, 0.47427087661720096, 1.6329257262329904, 0.1403361075227299, 0.06084165723633863, 13.18793615987224, 78.08156398034866, 63.128304327687914, 53.39423671845467, 27.810534123451482, 27.5922816799533, 44.75772280846873, 55.52152241429975, 58.65693176946333, 70.26623356726863, 21.866142903604818, 0.3849681605014109, 0.06836086000886656, 0.040733515465211485, 0.03245809198086781, 0.05991479810026865, 0.033755212902061404, 0.02499828017466972, 0.07707886397838593, 0.07100159572737832, 0.23529630635053883, 0.1013547117491403, 0.23529765466528557, 0.1651792817058102, 0.21359090573124348, 0.12991017181306116, 0.16208221805432152, 0.19173838558696932, 31.498701533963605, 86.63299775892689, 65.80272536123952, 65.54329587567237, 37.990645823940156, 37.848106891878196, 40.11899840447211, 66.86071411255868, 70.82735215463947, 82.36356058428365, 24.227650973104662, 0.37564370600927266, 0.31546838821903356, 2.3306132756894637, 1.9094644679177193, 48.96850878192533, 80.27984065394249, 73.67833475912772, 74.11964847195533, 64.08022042243712, 58.6734567149993, 52.14090216544367, 50.75265769035586, 54.98184742466096, 58.69238999582107, 57.59793104663972, 62.454719620366255, 61.99497469009892, 60.882527751307336, 60.53682573380009, 62.57019027586907, 60.78309566743913, 61.36482238769532, 62.13446201816682, 63.28397143271662, 63.56560153345909, 63.84514493326988, 64.8930061248041, 55.14567698201826, 45.75960205447289, 45.171948632886334, 45.919654369354255, 46.221468987003455, 44.76199034721621, 47.405989477711344, 47.22204992848058, 46.19616577702184, 48.79596764041532, 47.5203618695659, 47.859376245929354, 44.991649043175485, 45.19853053554412, 48.28927586155553, 48.471160088816, 46.1825551525239, 45.70762280494937, 48.207023759042066, 46.33064031600953, 49.89007749865132, 48.2550218028407, 46.322054247702326, 46.39957989415815, 46.73049457611577, 50.578720185064505, 48.130474782759144, 46.40507513476957, 48.15171833961241, 44.35001988564768, 46.661374568939216, 48.539550535140506, 47.70725888590659, 46.47029238362467, 46.27694306835052, 46.81179354267736, 47.690294634911325, 48.64088496854229, 56.602582546972464, 59.21428488146875, 61.350588106339984, 54.4078242394232, 59.500527689533854, 60.488239334475615, 55.95343028345416, 53.04798164675313, 48.29458282839868, 47.50244840498894, 48.44492727710355, 44.97684601814517, 45.58269923733127, 47.373559321126635, 46.13736944813883, 46.04236964256533, 46.68508137426069, 48.32871529363817, 46.02241262312859, 47.75442538722869, 45.7771703504747, 45.666677182720555, 45.19554561184299, 49.21007579372775, 44.843748231087964, 48.36222410202027, 45.72915269482521, 45.92818552447904, 46.91696797647784, 44.740111366395034, 46.0261231853116, 45.171411268172726, 45.6214600993741, 45.3724641184653, 46.496968423166585, 45.81303258096018, 45.28815669398154, 47.44290682577318, 44.990848879660334, 45.30370496934461, 46.30974977247177, 48.348793906550256, 47.98791231647615, 48.2125582233552, 54.44371000412972, 55.13205066803963, 57.6277018362476, 61.53668495916552, 59.74506001318655, 58.645325476123446, 60.47304015005789, 58.673354733374815, 59.46061757303054, 58.900397208429155, 62.571512114617136, 63.409502967711425, 63.85409185963293, 62.77032529154132, 69.00261063729563, 70.23520761920561, 71.81087078586702, 70.31560836299774, 75.47827120750182, 71.59106116141044, 72.41497855032645, 68.67509272790724, 79.83284734910535, 27.4005268081542, 2.074119439048152, 4.514895667952876, 0.1814841608246488, 0.16274528247454476, 16.33103237998101, 86.98856061504733, 68.61347229250016, 65.05585508961832, 38.974705742251494, 34.6983338171436, 52.229284932536466, 65.75362905379265, 71.87949657440186, 80.3237319761707, 26.545716831761023, 0.5868351171093603, 0.1900828082955653, 0.13632603560484227, 0.15034627199413317, 0.2708339913477821, 0.1526955265792147, 0.15748889275616215, 0.21312501702097156], [0.05536762576910758, 0.04345494705522734, 0.0480370338435375, 0.07433779372443115, 0.05524733847367668, 0.021428863946048003, 0.1221745300497259, 0.11591453450701891, 0.474222919513141, 28.801220886168945, 62.30300626447124, 47.72640005234749, 41.09724537018807, 13.694952514863784, 47.53527079859088, 51.60368257953275, 51.875291024484945, 67.94723418451125, 66.75484934160787, 16.72643965290439, 0.24970790641682766, 0.24411361063680342, 1.686879153693876, 1.7034140277293421, 50.77378749847413, 72.06763698208717, 62.02512594961352, 65.90334200089978, 52.54495728400446, 49.54368514399375, 53.39272268356816, 58.61953981461064, 58.613448373733036, 61.44728237582792, 57.379298133234826, 60.12798140125891, 57.360611961733916, 59.113993798532796, 59.32787672165902, 59.6917236235834, 55.895190931135616, 59.40364514627765, 55.77299733315745, 51.970310441909305, 54.66950908783944, 57.43046937450286, 56.95732955009707, 55.09939301398493, 46.8824746531825, 43.16838625938662, 40.91422365557763, 42.68212610675443, 42.813392146941155, 41.689311458218484, 41.33971060475996, 43.85730351171186, 42.340013057954856, 39.54734040844826, 42.04634128078338, 42.86391619713076, 40.943374710698286, 42.25035159818588, 42.25507805424352, 43.53294311031219, 42.563635226218935, 44.277707069150864, 42.74015365108367, 43.89720186110466, 42.12726762217861, 44.86866312642252, 42.63352009557909, 42.43875872704291, 41.90424949892106, 42.07690046679589, 41.12812226818454, 40.50645405246366, 40.32066706688174, 43.31084282167497, 40.050439296230195, 41.978696084791615, 41.22609130797848, 42.533848747130364, 40.40898707605178, 43.5403799241589, 46.89303367368637, 54.135501923099646, 54.209222870488325, 56.14939974200342, 48.95087772800077, 53.66412324290122, 55.36042674895256, 53.602122337587424, 48.2953163116209, 45.00877803371799, 43.828752579227576, 41.57517833094443, 39.45363106266145, 41.30045160170525, 41.26055325231245, 41.86883441863522, 41.72556200335103, 41.051953761808335, 40.852720891275716, 41.06046530508226, 43.91315414059547, 44.23051703360773, 44.64609215336461, 43.96214062167753, 43.1612200890818, 42.10198794641803, 43.95807312380883, 42.200921889274355, 42.76477044628513, 42.1569795762339, 40.99576188671974, 41.27204579691733, 40.04207288065265, 41.48310853588966, 40.325864207360056, 40.553906886808335, 41.12958138988864, 41.99313040702574, 42.177834818440104, 41.656414539583274, 41.42471621113439, 41.79723547350976, 44.51589692023493, 42.23084565131895, 43.30835996135589, 46.535513554849935, 48.39050046859249, 54.39349189881356, 55.809479298130164, 57.590615826268355, 54.164543151855476, 56.588407101169715, 58.97884853424565, 60.05047536665394, 58.29014701227988, 60.50679214539067, 60.834643456243704, 61.95058522685882, 61.889925772143954, 66.07613025173065, 63.153383962569706, 57.65850028684063, 51.8497799288842, 58.9776365218624, 61.20054175776821, 69.10168970784834, 65.17359287508073, 70.87045900283321, 17.526738489827803, 0.5810105812645728, 0.03961256029264581, 0.09242612553099472, 0.044125649372055646, 6.67666046850143, 67.14154797215616, 59.16506305817635, 63.10353063767957, 61.273835166808105, 46.81667297117172, 17.117698038778, 34.57709727748748, 51.12709106937532, 59.746483833559104, 22.360995008099465, 0.4038489796221257, 0.03349389648064971, 0.05855201195264536, 0.03785235837342278, 0.04725420306767187, 0.056516941516630115, 0.10877594336747162, 0.023818267284021265, 0.010241176369750212, 0.04397378010194629, 0.048372476932502566, 0.07731431344103429, 0.11437090564398997, 0.049443617237791906, 0.06523076264608292, 0.02817643231772367, 0.6574473409883438, 39.306185245513916, 72.81841785677018, 54.97039018138763, 49.34674686001193, 24.924638502059448, 44.54282399146788, 47.00190690255935, 58.71884246026316, 70.92337962119811, 73.96388330767232, 17.20940697577692, 0.28910004023102026, 0.14400326316395115, 1.9962065811118774, 1.8003416782425297, 52.322331397764145, 75.65299710919781, 63.87921464058661, 67.08045313435217, 56.28965585462509, 52.786128136419485, 55.39218618023781, 61.19781178812827, 61.637709525323686, 63.17923238200527, 60.44125326218144, 61.76766941624304, 60.12104272842408, 62.29727175927932, 61.65099067072715, 62.981490012138124, 60.06962830020536, 62.58937066601169, 58.46546911424207, 52.31161940482355, 55.19349067441879, 59.434310236284816, 58.99785241773052, 58.1079254611846, 48.41242651785574, 44.65012434990176, 42.12787166718514, 43.87212222622287, 44.255074993256606, 44.394158317196755, 43.91890825763826, 44.71696153763802, 44.3604455455657, 42.1047689068702, 44.35494638258412, 44.9004304024481, 42.69637607759045, 42.5690245628357, 45.20302557176159, 46.11053259141984, 42.6224393998423, 44.91155424425679, 44.483815854595555, 43.63960804477815, 43.47890461644819, 46.650486069340865, 43.932636553241366, 45.90613788174045, 43.06211748430806, 43.603961544652144, 42.39438887565367, 42.41519312704764, 43.23229343660417, 47.088061763394265, 42.831595866910874, 44.81919419380927, 43.854412724894864, 45.72548135634392, 43.24726904592207, 46.401529312133796, 49.46361780166627, 55.09299170586371, 56.53291340797179, 58.06491274987498, 52.4966101492605, 55.47459909992834, 59.11369962076987, 54.102930561188735, 51.19640719506049, 47.30738893631966, 45.81962608521985, 42.609683852041925, 41.09788471652616, 43.90392480358001, 44.7710314104634, 43.60731517114947, 43.306053607694565, 43.18198119440387, 42.393451429182484, 43.32704221048663, 46.002647799830285, 46.48355391717727, 46.588269433667584, 46.21580508447463, 44.55548932475429, 45.39860671566379, 46.6221155658845, 44.523306277490434, 44.082894709802446, 44.27727168606174, 43.57007226636333, 43.23476452981272, 41.33231301461497, 42.335600391511, 42.80503749847413, 42.891443391000074, 43.5227253360133, 43.92471728786346, 43.958206484394694, 43.95781032500729, 45.615811886325965, 44.61987503113286, 45.26170422953945, 45.69019571427376, 44.682260328723544, 49.32692712353122, 50.22312594998268, 55.854798363101104, 58.96653229190458, 59.76399329400832, 57.968877438575994, 58.19486871842415, 60.60044657799506, 61.37443611698767, 59.61741432066887, 63.02428699308827, 63.29262025894658, 63.85768475071077, 63.675463199615486, 66.57910362366708, 63.30417163910405, 56.9813266108113, 53.037665813199936, 60.85495741136613, 63.255542093707675, 69.57696330162787, 68.18023081748717, 70.79224694159724, 19.38666758998748, 0.7315551321352682, 0.7471265127101253, 0.310956712571844, 0.10987948536151841, 7.464823001815428, 73.08513118374732, 65.10471605485486, 64.94542860215711, 50.22045089352516, 45.807764837818766, 26.751535361812962, 42.97506440070368, 60.516268591726984, 67.11330690691548, 30.27131542082756, 0.4850842689554538, 0.11840660320294481, 0.03042469544696712, 0.0014432547064760941, 0.08378936518584529, 0.035958615837678794, 0.057229184951152534, 0.04853886356877704, 0.10912472787763804, 0.17568052385843572, 0.14962970399327818, 0.2213939555710362, 0.2114547614849383, 0.20630419915241582, 0.16083626797603023, 0.2094319982514266, 1.3666727874548206, 50.7626126658532, 84.76439629831623, 63.448071633615804, 57.959016599962794, 22.97565002595225, 58.88709252880466, 68.31712938124134, 63.081894843809074, 78.53907708198794, 80.34321046644642, 19.71151044291835, 0.32062011500520093, 0.3805425931369105, 6.077941550362495, 2.3783235155767013, 56.27863399444088, 76.65686499687934, 65.54626118752265, 71.3658308213757, 58.093028299270145, 56.24156367394232, 59.70574217457926, 63.455896762109575, 63.470531125222486, 66.0021935739825, 61.84083338706725, 63.87497455843034, 63.43607310325869, 64.78174025012602, 65.55597689843947, 66.39763909001505, 58.86023998260499, 62.77733064466908, 57.04033867005379, 52.278526367679724, 56.58173122713643, 62.66916344242712, 62.120192435479936, 60.07545301991125, 51.7208202423588, 47.61508318685716, 44.040427207946784, 45.3895656524166, 46.313550549168745, 46.457980063653764, 45.80667049654069, 48.26513367314493, 47.16159835938485, 44.02467496933476, 47.151619849666474, 46.86686754226685, 45.29764490742838, 45.251796322484175, 47.679563030119866, 48.74105445800289, 46.04750010275072, 48.45793385659495, 45.800669270177046, 46.44331432157948, 46.11711432856899, 49.46031908835135, 45.66912081933791, 48.751993948413485, 46.50269508361817, 45.59125392667709, 45.85751225871425, 45.56930826556298, 45.55219496450117, 49.79802731544741, 44.03765016986478, 47.033521206148215, 46.97656839124618, 49.28854673139511, 46.214997076219134, 49.33201836001489, 51.509561384877856, 59.327253064801624, 59.04953748949113, 61.561462571544034, 55.42370242457236, 59.09103616591423, 60.642631669198316, 58.63013413644607, 54.928871893113666, 49.88968133926392, 49.72094881919123, 46.55568630464616, 42.47852763822002, 47.4532893396193, 48.46393508295859, 46.640342820075254, 45.957324812489176, 44.40843182225382, 45.182695927158484, 44.64000071248701, 49.49525563947616, 48.67306801580614, 49.94230385749571, 48.72285466040335, 47.021028457149384, 47.35486530488538, 50.08808266732001, 46.02729597399312, 46.621154585192286, 46.9230515726151, 44.63662747413882, 46.04854345321656, 44.61925137427546, 45.7270856057444, 45.72691302145682, 44.178310286614206, 47.75608454981158, 46.245913197917325, 47.593145370483406, 47.20104563620783, 47.09043871971869, 47.37614808544036, 49.74982923076999, 47.7262863036125, 48.232342658504365, 52.82764642469345, 52.13202584174372, 58.61389944630285, 59.98088467505671, 62.66921835560953, 59.15788119839084, 61.45638619699786, 63.588037490844734, 63.99222204762121, 62.564330254831624, 65.04275437324279, 65.90589154151179, 67.8840918694773, 67.05152957670151, 70.54745966388334, 66.90333458685106, 61.86338701555806, 55.43352403948384, 61.86442644365373, 64.71615429847472, 72.4224938115766, 69.82757922141784, 73.46740538074125, 20.98394693866853, 1.496556437303943, 2.025766911045198, 0.5418553984453601, 0.16466972598385426, 8.656338549429371, 78.1875228881836, 70.75094438368275, 79.44922385677215, 75.26934223790323, 57.91897704524379, 28.07895956500884, 53.74079381265948, 71.69711420612951, 78.28475060001497, 40.37620390615156, 0.5552942966741901, 0.2493936724720463, 0.2224992365846711, 0.10958493987639105, 0.09260450144328418, 0.17351405785208748, 0.16071914845416624, 0.1507213179983439], [0.049919422956243645, 0.06939825031065172, 0.06256209153141226, 0.05636601453466762, 0.013350711932646172, 0.10069726275340204, 0.04592629690324107, 0.07221085019409657, 1.0318087690299558, 30.435299911806663, 58.25677156448365, 46.36954630574873, 36.262174960105654, 16.168827664467596, 48.18274428767543, 44.912809402711936, 55.83955995498165, 64.0523402152523, 64.05564285093739, 12.909249797944101, 0.20348237557036264, 0.26770691237142014, 0.6139412690554896, 1.788265435926376, 60.833572649186664, 69.8103129479193, 64.1572989186933, 58.88133056702153, 49.298537008224, 54.99507365688201, 60.98441916127359, 60.54873797201342, 59.18105063899871, 64.81353106037264, 59.036048458468535, 59.785083878424864, 58.89510985343688, 61.16864112115676, 58.52484987628076, 58.05353395400509, 57.90197749291697, 55.9099704219449, 49.51897028953799, 56.78932659087643, 48.07968401139783, 54.65025417266354, 58.53772701755647, 54.10144398289343, 50.56790621049943, 42.342746949964955, 43.50889505878572, 41.979300129798155, 41.63878348565871, 42.87576175505116, 43.55297857715238, 43.01624536514283, 44.1969846910046, 40.305397279800914, 39.79212376379198, 40.95615379271969, 39.989430750569994, 42.69587793657857, 41.62089747767295, 42.90951375038394, 43.13843896312099, 44.28066845863096, 43.26773205111104, 42.52971849133892, 43.3586133680036, 43.99141327027352, 42.8303171742347, 42.141160657328946, 43.29458459731072, 42.994331082990094, 42.88284947795253, 41.456346204203946, 41.39372164203275, 40.06850965561406, 39.20558821770453, 40.68700859623571, 41.606427854107274, 41.99236946721231, 41.85923245645339, 44.25334130564044, 45.88845975937382, 53.91729654804353, 51.58183105530278, 58.06410474161948, 46.57494514219223, 44.68197007333079, 55.4689508868802, 51.907113213692945, 49.8705284057125, 44.73038388836769, 45.058615669127434, 39.620425931869015, 40.670860198236284, 38.828766115250126, 41.798074860726636, 42.02587435322423, 40.11759811832059, 40.88054226290795, 41.170648605592795, 42.113492258133434, 41.032859663809504, 41.07098117951424, 42.36219013890913, 41.614394187927246, 43.658957096838186, 41.613237088726414, 43.84787021144744, 43.8454814880125, 40.13664907024753, 42.752807217259566, 42.16588335652506, 42.03726883857481, 40.81921992763397, 40.56205757202641, 40.73272382059405, 40.65857533485659, 41.737376182310044, 42.63587744005265, 41.15015422144244, 42.999139908821356, 42.82433163735175, 41.54334437462592, 41.88315891450451, 42.905469786736276, 42.910533566628736, 43.763045034100934, 45.23274144818706, 51.374655385171216, 55.32795344629596, 57.69191103596842, 59.04937667231406, 57.7965755616465, 56.17469118487451, 61.66207528883412, 58.02481043723322, 59.178532477348085, 58.65288780581567, 61.683205096952385, 60.71554068596133, 60.351583957672126, 51.93756649571081, 53.0839733154543, 53.58435007833666, 59.2577172863868, 60.94792935156054, 64.83558654785156, 58.22258026369157, 62.0976270398786, 14.614338432588886, 0.20178231921407486, 0.45670426600883085, 0.16883767330117766, 0.009494174568493281, 3.4655319634945165, 59.67656758523757, 66.61012172698975, 55.121366131690245, 51.16389859107233, 39.11769966925345, 13.691497887334517, 37.45179845440773, 52.487792661113126, 58.736018519247736, 34.83075695653116, 1.2280648057499242, 0.05933390044036412, 0.04302350165803106, 0.08830363787109814, 0.03505864255731145, 0.06385376556746422, 0.007109523369675323, 0.009998475884898536, 0.07442177994357002, 0.02617491078713248, 0.04140362023345886, 0.014615103662494692, 0.016657704742805615, 0.08674284097768607, 0.09784969095621379, 0.06681371480226517, 1.8279670539402195, 41.850077644471206, 69.40966636903825, 57.1947310047765, 44.98680491601267, 18.071647882461548, 44.08220437265212, 47.455442720843905, 61.99211920461347, 71.09157085418701, 70.98520401985415, 14.079100624207529, 0.27207254101672484, 0.16773138105148272, 3.061986262759855, 1.6180824969084033, 63.173121329276796, 71.6724346530053, 66.59939796693864, 62.60273418118877, 50.41294905447191, 57.536381213895744, 63.49796025983749, 61.002936670857096, 62.47020121543639, 65.64752109589116, 61.5105894304091, 61.63809391760058, 61.455311467570645, 62.086589490213704, 60.02956128889515, 59.22665211462206, 58.690342518591116, 56.12620284480434, 49.513953578087595, 57.09602063701999, 52.049114781041304, 57.75165265606296, 60.33579641772855, 56.72184221206173, 52.97893224223968, 43.71944396726547, 44.26154298167075, 44.60612712367889, 42.310528601369555, 45.57895337381671, 45.042675156747144, 44.42004988270421, 46.532732594397764, 45.20624976004324, 43.17761559640208, 43.57956832455051, 41.88182530864593, 44.35226348138625, 44.34542286780573, 45.120243949274865, 43.53009154719692, 45.81525264247772, 44.76411234947943, 44.38422295355028, 45.085228950746604, 46.78468996478666, 44.574701093858295, 43.286618263490745, 45.66707334210796, 44.741503807806204, 45.23180400171588, 44.204911801122854, 44.04846806680003, 42.701985066936864, 41.63827749990648, 43.87532680265365, 43.158027279761534, 44.319437165414136, 44.00833045282672, 47.40782906932216, 47.9470294521701, 57.21358976056499, 56.402063139023326, 61.63121015794816, 47.6697257257277, 47.326816435783144, 58.605995870405636, 53.05120975740495, 52.26459803119783, 47.231487151115175, 46.245540572750954, 42.623231718617106, 43.33088221088533, 43.3198917296625, 42.769783235365345, 44.627974725538685, 43.26518643286921, 42.93547199618432, 43.03147200615176, 45.1196163700473, 42.64414187400572, 43.40521504802089, 44.5217804754934, 44.482831339682306, 45.93542229744696, 44.60267543792725, 46.395724204278764, 45.50338891244704, 44.088174220054384, 44.53469684047084, 43.96225044804235, 44.68246036960233, 43.165636677895826, 42.35685963784495, 43.923065970020915, 43.2446567473873, 43.589786098849395, 43.78793247284428, 44.51781888161936, 44.72515536892799, 45.13358000786074, 45.318794327397505, 43.793988612390336, 44.75358470793694, 44.86408179806125, 45.89327642994542, 47.620425455031864, 54.68444939582579, 56.72052429568384, 59.96529325362175, 60.76729636038504, 60.07955974148166, 59.52990231975433, 61.931997114612216, 59.67557522558398, 62.252815615746286, 59.54511327128257, 61.99505705987254, 62.735278914051676, 60.536162853240974, 54.14098931897072, 53.92132089984033, 55.22637582594349, 58.17750830804148, 60.67428519648891, 63.74186500426262, 59.917130470275886, 62.291321523727916, 17.64860260871149, 0.5246896356824906, 1.4421483826252723, 1.0825532073936155, 0.09064171523336442, 3.698982365669743, 65.59434552346507, 71.19562349011822, 62.170394851315415, 51.43764865013861, 46.27686462094707, 23.829959900148456, 43.91413081076838, 63.35655489275533, 66.29379041733281, 45.27040404658164, 2.090207285458042, 0.0846862702840759, 0.04309036964250188, 0.17520666783375127, 0.05058210816294436, 0.04293947713449598, 0.08814605358507364, 0.014265967709493014, 0.09011223356449798, 0.1298087877371619, 0.1009164251867802, 0.18043144876437803, 0.15433173716789292, 0.16560219288352998, 0.23352224590076556, 0.2295171841979027, 2.596092281803008, 56.7576926754367, 78.72870799033873, 66.98276258284046, 53.42412910153789, 25.200792974041356, 61.63164946340746, 57.226706166421216, 70.23618821174868, 76.70806761710875, 77.26101982978084, 16.591433632758356, 0.45873341841563103, 0.33190158706518913, 3.883052333708733, 1.9697315630412873, 67.09575822276454, 74.72265797276651, 69.0600968945411, 65.6736558483493, 52.75779293429468, 61.35924477731029, 65.58634388831355, 63.39168364001859, 63.8332405397969, 69.21431664497622, 62.37200860054263, 63.88396855323546, 62.99000155541205, 64.70278686092746, 62.10810369060886, 60.482602888538, 58.55632297454342, 55.85393151929302, 51.021320435308645, 56.953493472068544, 52.600964807694965, 58.81218310325377, 61.68633514834989, 59.52528176769134, 54.5649230095648, 46.335021603492, 46.90383195877076, 47.27868110902848, 44.38381502705236, 47.378532886505134, 47.87344578773745, 47.82765211597566, 50.231872835466945, 46.28539577607186, 43.98416865256525, 44.935417944385165, 43.91809632701259, 47.039349848224276, 45.918387443788596, 48.02716347479051, 46.46163571265436, 49.73526547032018, 47.360062445363695, 45.974194926600305, 47.072548789362756, 48.41977311718849, 47.323231389445645, 45.02238081347558, 47.42985317783971, 48.56969002754458, 47.92834720303936, 46.403282611600815, 46.64353955176569, 44.38809041054019, 43.77895416751985, 46.1021936324335, 46.436120694683446, 47.06762229242633, 47.66712519430345, 48.892069632007235, 51.317428004357126, 58.60993785242881, 55.86942095910349, 63.65059929509317, 52.25976174877536, 51.8612136379365, 61.540368064757324, 56.36251388057586, 54.147394549462106, 50.050922132307484, 49.70572610055247, 45.15726720133136, 44.01474352805845, 45.457771747343, 45.72628936459942, 46.95544642786826, 44.703260698626124, 46.28510944304928, 47.0657983902962, 48.28923663785381, 44.872522738672075, 45.49629726717549, 46.009119710614605, 47.52189943867345, 50.10166975759691, 47.15717784820065, 48.244145070352864, 48.754061037494296, 45.21955443966774, 47.96799059837095, 47.295402173073064, 46.611387883463216, 45.339688793305434, 45.06261256433303, 45.034846105883204, 46.24945117581276, 46.65130976707705, 48.4414206781695, 46.3840865319775, 46.34874989909511, 48.25169955530475, 48.07941729022611, 46.0143913761262, 47.271848340188306, 47.11933482077814, 48.864134511639996, 49.822593119836625, 58.054753811128684, 59.20128614671769, 63.4959049378672, 63.56367957207465, 61.143228084810325, 62.01231548863073, 64.01243009874898, 61.44960049659976, 65.2218968637528, 61.199745516623224, 63.90845591022123, 64.18140972814253, 63.47568119725874, 57.40799419341549, 55.07977724075318, 55.23294187361195, 60.70097692551152, 63.31108285534767, 67.24615758465183, 59.879589465356645, 65.64955288364042, 18.706501145516675, 1.172640121752216, 4.123562266749721, 1.9899394915949915, 0.14526013765604268, 4.7316154453062245, 71.78699139625796, 78.16781690043788, 69.8962442336544, 66.72379985932382, 51.03875929309476, 23.902625729960782, 54.32623893983903, 72.93731274143343, 77.33840819328063, 56.80853835998043, 2.8447247080264555, 0.3347806067716691, 0.2573025190541821, 0.3361703821968648, 0.12044820453851454, 0.16719367925918874, 0.22388652988499214, 0.09772673384436677], [0.033177674537704836, 0.05345853466180064, 0.07802879002185599, 0.08545087199778327, 0.0247555356397624, 0.029734915625604413, 0.11116897221654655, 0.031349068627722805, 1.5654741972684862, 42.92788220990089, 53.447945733224195, 48.700348100354596, 33.35472199224657, 27.68406906435567, 48.85197908647599, 36.840822619776574, 62.89222863412673, 60.22584453705819, 67.49670290177869, 11.224841860032852, 0.19227478502979203, 0.31766543645531903, 1.5134032623421763, 2.108842711294851, 60.86422989445349, 69.09568063674435, 62.58822533392138, 54.646959381718794, 57.42649993588848, 63.89489235416536, 60.779620447466456, 66.31084488284203, 62.25637320549258, 56.47083405525454, 58.24649887700235, 58.00393950554633, 56.29562962439753, 56.170674677818056, 57.18460344499158, 56.859462491927616, 53.48010132389685, 56.90215749125327, 65.50456639259093, 50.100673475573146, 51.22317344911637, 56.129936941208385, 55.89161765190863, 55.61610644863498, 52.99824207059799, 47.282579944979766, 41.856071026094504, 42.097485065460205, 41.281632069618475, 41.74853924782046, 41.73366954249721, 40.77804680793516, 42.15131959607525, 40.8992951147018, 39.59689171083512, 41.313807272141986, 41.20565968175089, 42.249661261035556, 43.12567949295045, 42.918256713498025, 42.94548580723424, 41.02049635302636, 42.36449257020028, 43.9310440709514, 42.817526325102776, 41.69646193904262, 42.19841549473424, 41.11150710813461, 42.613782728871996, 41.38855195814564, 41.4907257787643, 42.146204825370546, 39.66351316821191, 42.17469299993208, 39.37494047226445, 42.66107474603961, 43.38655241074101, 43.79050554767732, 42.22450317875032, 43.57221780284759, 45.263739939658876, 53.525440000718646, 53.66149917725594, 60.04734139288626, 38.492222832095244, 48.0987310409546, 58.76042350645989, 52.66888456959879, 46.83731248301845, 44.47821863235966, 43.1062323816361, 41.31744330929172, 43.959685217949655, 39.908618157909764, 40.80279304135231, 39.66553711122082, 40.74918993057744, 40.76869195507419, 42.626197030467374, 39.1806144868174, 42.51577446537633, 42.28390355263987, 42.60502407627721, 42.001532123934844, 41.62219578219999, 43.267112316623816, 46.42169421718967, 43.160984746871456, 43.743088014664195, 41.58402327568301, 41.059794579782796, 40.66612197506813, 41.08473300933838, 40.90480996716408, 39.64952599617743, 40.48051149614396, 42.20784879499867, 41.970133550705455, 42.652618115948094, 42.62290223952263, 41.310088865218624, 40.92446888646772, 41.656198809223795, 41.843358624366026, 42.257152988064675, 43.73180727804861, 42.42468526286464, 45.35014190981465, 49.62045377300632, 54.89413538286763, 56.51947536776143, 59.04916094195459, 54.10643323775261, 52.82437909033991, 57.34276125507971, 57.72463537031605, 56.392241524111846, 59.59727294983403, 57.30343164936189, 61.75158377616637, 65.9895400078066, 68.37889102197462, 67.47859724106328, 68.7861664064469, 64.20060188539567, 69.54843982573479, 62.58202798904912, 63.42351367396694, 18.988862768296276, 0.48152361485746603, 0.5572310282338051, 0.24606912667232178, 0.16393938372212072, 0.7422359299755866, 48.40189887631325, 69.894118309021, 57.84086304326212, 60.7073272428205, 28.160362474380005, 13.413150810426282, 29.001187239923787, 50.88888552881057, 61.34899170167985, 46.08953222151726, 5.787799906346106, 0.06956423858120557, 0.06634789503990643, 0.036889531409307834, 0.019257424113851403, 0.06442711343087497, 0.09095309167018822, 0.03890865572517918, 0.03721856234234668, 0.05243113031610847, 0.0413773012828202, 0.07731868780308193, 0.0981406128454593, 0.05258137931025798, 0.022584630153892983, 0.10215442327241744, 2.2654965375700304, 53.24416291329169, 61.36051170287594, 58.12378752616144, 39.91616087575113, 29.475268433170935, 56.03652961792485, 39.82231424700829, 67.70846382264169, 65.89625035562824, 74.81487289551767, 12.782740612183849, 0.18700330337930113, 0.07456065636248359, 3.8529179894155074, 2.1321361968594212, 62.311608022259136, 70.03697103069675, 64.38801273222893, 56.06411956971692, 59.028811685500614, 65.80922080624488, 61.506961237999704, 69.01407180293914, 64.2661839146768, 57.45161487210182, 58.73622640486687, 58.442229070971095, 57.329464420195556, 57.404597420846265, 57.91740025243452, 57.572125773276056, 55.54946145703716, 56.66269286986321, 62.12254193521316, 52.78148405013546, 53.30363388984434, 59.848512526481386, 57.846609315564564, 57.79832101637318, 56.2095179096345, 48.18296394040508, 42.22431882735222, 42.90169646663051, 44.06037246027301, 44.47421389241373, 43.533507931617, 42.67141411381383, 42.72768443630588, 45.17212121717392, 42.371195900824766, 43.82259445805704, 43.645589659290934, 45.12661780080488, 44.32285354983422, 44.63748255083638, 45.12741404194986, 42.16989594121134, 44.18727290245795, 44.397790431976325, 45.54368734359742, 44.24267638114191, 44.378131512672674, 42.52591379227177, 45.9822436301939, 42.95588008819088, 43.68250700735277, 43.68772768205212, 42.30468819218297, 44.54685226563485, 41.38490023151521, 44.788956642150886, 44.97455143159436, 45.618184920280214, 44.34574450215986, 46.04052220621417, 49.39609419914984, 57.46762206477504, 55.262332193313114, 61.83967236549624, 41.34231505855438, 50.06271669941564, 61.29449036813552, 55.15766766763503, 51.44259475892591, 45.636671050902336, 44.45640633183141, 44.863717017635224, 46.063440615131015, 42.516892340875444, 41.672496257289765, 42.58956209305794, 42.81875010459654, 42.32761444584016, 44.13096335626418, 41.41492205281412, 44.605593681335456, 43.420755478643606, 44.493300145672215, 45.46954278023013, 45.18048763275147, 45.65461589444069, 46.18375932016681, 45.8690518717612, 46.19263956623693, 43.120215631300404, 42.48087321558307, 42.98434080616121, 44.025361384114916, 43.08722065341088, 42.59100552528135, 43.584863524283136, 43.6969687861781, 44.76788174721503, 44.66563732393327, 45.00754248711371, 43.255811968157374, 43.72500981053999, 42.96811788312851, 43.98344301408337, 44.31569130189958, 46.831264188212735, 45.1257509569968, 47.26472531595538, 50.54581149931877, 57.55612642534318, 57.59743290562784, 60.07291916877993, 56.54259381755706, 56.33729304036787, 58.93536906088553, 60.04031250553747, 57.24190535083894, 60.391776484827844, 59.97109836147678, 63.20085248639507, 66.87154769897461, 70.4555114623039, 68.80562920724192, 68.84675133612849, 66.89234410562824, 71.00441578895816, 64.08300922762963, 64.50012191649407, 21.616313419034405, 0.49368746698864047, 0.9163950491816768, 1.0232507088972678, 0.21275282086383915, 0.8307545704226341, 49.692284137971946, 75.8030277682889, 64.22264168339392, 64.05754127810079, 27.000256776809696, 18.30206947941934, 39.26524354565529, 57.13833908880911, 69.68831939081993, 56.37968601719026, 7.873819816497065, 0.07250367964227354, 0.009514665505247972, 0.021707848270213412, 0.11015841031386969, 0.09279552546720352, 0.0327692692348313, 0.03357173484419623, 0.1639986329621846, 0.15354683412419212, 0.16295888310959264, 0.18418584649841632, 0.1528327482482118, 0.12582811827380813, 0.27467990594525493, 0.2090326519382577, 4.570398186483692, 70.70581359248008, 72.06237316131592, 68.36530393169772, 48.44173839015346, 38.92607619685512, 62.15476420617873, 50.20513796037244, 72.38996167336741, 72.17468630883002, 79.76455888440533, 15.06067866279233, 0.5755680475023486, 0.7397541115360876, 4.469905101483868, 2.335058056539105, 64.53807084791123, 73.32158734721523, 67.71236265859297, 59.82009887695313, 62.27024270642189, 69.56183079750308, 64.81377816969349, 71.55894479443951, 65.7989912648355, 58.86012623386999, 60.405998999072665, 59.12354476990239, 58.898549772078, 58.877270913893184, 58.62985172579366, 59.50219861922726, 56.383023954206905, 57.86266357667985, 57.96875976747083, 53.66260528564454, 55.54526059858261, 60.31053635381884, 60.204989294851984, 60.562729066418065, 57.35804280927105, 51.24135363486506, 44.11563865600094, 45.22613225444671, 46.42837401359312, 47.66311260961717, 46.82396857969223, 44.29821714278191, 46.695271691968365, 45.81830032410161, 43.71048919616207, 46.54418199293075, 46.58287225231048, 45.5577019722231, 46.363580380716634, 47.11861310466644, 48.118382115517896, 42.099085392490515, 46.16903082016976, 45.514477452924176, 47.56299411096881, 45.2261910899993, 46.35275071667087, 46.78044203789004, 47.441945845080966, 45.89711250797395, 45.844635117438536, 46.6743262352482, 43.89853154459308, 46.75813944109025, 44.060768619660415, 47.450096530299035, 47.144347775367, 48.549109351250436, 47.775119812257834, 47.3640711076798, 52.78423363162626, 59.86412748213738, 58.87913403972503, 64.41716770971975, 45.72682280694285, 53.304214400629846, 65.08198984207647, 57.94672389184275, 53.0786467367603, 49.10523083902175, 47.844149604920425, 46.77039292550857, 50.45349067257297, 44.95355106169178, 44.338994103093306, 43.970828671609205, 46.27958282347649, 44.41959096539406, 46.61652618838895, 43.46521162217663, 47.31764593432027, 47.34260005335654, 47.77368030240459, 46.57135617348456, 46.872519677685155, 47.93970246468821, 49.5735736047068, 47.98530394031156, 47.44857465067218, 46.85404923654372, 46.32716901840703, 44.632607044712195, 46.938803811227125, 48.5159888575154, 43.715705948491255, 45.27401262714017, 46.22005301137125, 46.867789299257346, 46.98396990376134, 48.32578136074928, 45.407541874916326, 44.64596271514893, 46.18133137303014, 46.913202501112416, 47.96180894297939, 50.389293239962676, 48.203517160108014, 50.20768357861427, 53.415068426439845, 60.9266387262652, 60.27354055835355, 62.617184192903586, 58.20498843346873, 58.20253302974086, 60.390438956599084, 61.11727768375028, 58.69053079235939, 63.227195124472345, 60.048153323511926, 66.68878093842538, 67.64143836113715, 73.39720279939714, 71.80861150064777, 71.7460104726976, 68.77132415771484, 75.00079324168544, 67.78600908094838, 67.93996211021178, 24.076151386384044, 1.415463640324531, 2.9107006903617614, 2.187072423196608, 0.5090338015748609, 0.8681150237398764, 57.70339965820313, 82.30382288655927, 74.595243700089, 74.38273752889326, 36.63519628586308, 22.759294048432384, 42.64636585789342, 67.07912737323393, 80.79389864398588, 69.17301408706173, 10.072747603539499, 0.1642362581145379, 0.16770107461319816, 0.12122764537531523, 0.25496227366309016, 0.2038166044099677, 0.2574754710639677, 0.12355431568838897], [0.063039617117254, 0.12151756368937994, 0.10548653802083385, 0.09130373011313139, 0.09857133812000675, 0.03863679027305015, 0.08445663542877282, 0.2611695470348481, 10.656955222929678, 52.59126086388865, 58.18225829832016, 48.78885246092274, 33.97668830810055, 16.230705995713514, 26.408447604025564, 41.03003555728544, 62.78603438408145, 64.43587349307153, 63.10853950438961, 8.705223048886946, 0.3456999031045745, 0.2711166165048077, 3.115849230558642, 0.4645407632473977, 54.254894948774776, 72.43991697988203, 62.171057731874534, 62.56282798705563, 59.26888035189722, 63.44677332908877, 65.4874413244186, 55.17670293008128, 50.11701406971101, 53.14867673381683, 51.503520934812485, 55.86110161196802, 58.844915282341745, 59.60161893598495, 57.424385778365604, 58.14119108261601, 52.96408214876729, 47.28583551222279, 48.604861920879735, 65.92491503684752, 55.29562527133573, 54.64850479556669, 55.03362271093554, 54.4506839782961, 51.10373335499918, 49.95880526881064, 41.7493982468882, 42.5428270524548, 40.82780991831134, 42.04304256746846, 40.990643193644864, 42.734466214333814, 40.90953642322172, 41.079049494958696, 42.13371599874189, 42.57598284752139, 41.41278043870003, 42.268865185399214, 42.334219717210345, 42.9242540174915, 41.118661511328916, 42.70434241141043, 41.92865448613321, 42.8967817368046, 44.262904044120546, 42.6575485352547, 41.719596078318936, 41.7043419807188, 40.03059994789862, 42.97681377780053, 41.46757595000729, 41.455189105003114, 41.58438413373886, 43.06807556459981, 39.747110643694484, 42.635038052835775, 43.84372034380513, 44.159020070106756, 43.72473132225775, 44.21589835997551, 43.65969450243058, 52.111139220576135, 51.47901396597586, 58.640159714606504, 40.74438894948652, 48.98917182799309, 57.018938218393636, 50.06271277704547, 45.031814113740005, 41.51891585319273, 42.78270352271296, 41.31155975403325, 41.74743706180204, 39.623865850510136, 41.5769120185606, 42.290489212159194, 44.219832497258345, 41.452157112859915, 42.88545785411712, 45.570473209504165, 40.770798267856726, 42.78236227650797, 44.376919500289425, 43.570978333873136, 43.3068851501711, 42.29534510643252, 43.307602943912634, 43.51926188315115, 44.616866573210686, 43.02892638790993, 41.875074909579375, 41.231641461772305, 40.79497967996905, 39.6202729594323, 42.05203263990341, 40.65933627467002, 41.307570703568004, 40.992388648371545, 41.95422049491636, 42.75860840274442, 42.26919858686386, 41.180921293074086, 41.91050960171608, 40.87047353867562, 43.11398690746677, 41.59859488087316, 42.27566265290783, 41.756701700149044, 41.85694179227276, 47.34736181074574, 55.96006301141555, 56.63236510369086, 61.03204850227603, 57.344745974386896, 58.036961940027055, 58.19311541895713, 59.74187504860663, 59.802926740338734, 62.777820940940614, 64.50389523659983, 63.29038843031853, 59.01928424835206, 60.07970094680787, 60.78342906890377, 63.859198785597286, 63.56670764184768, 69.04899658695345, 66.93787497858848, 26.6280238474569, 0.3798739822401155, 0.7041812171378444, 0.959129210922026, 0.02838564709940505, 0.005659150389669043, 35.07846247765326, 71.12269093913417, 61.62044717419533, 49.892603505042295, 56.09086621192194, 41.19454368468254, 20.93367195898487, 48.65485645109608, 50.504716827023415, 55.66633239869149, 9.29525342679793, 0.18783734330246527, 0.03581077619005115, 0.06516021360913593, 0.00628866829849299, 0.03801341303774426, 0.014784990362973224, 0.014941102802573193, 0.06970190458119878, 0.049329044958276135, 0.08291242433892143, 0.040371466142636155, 0.06592352063425126, 0.05051329431514587, 0.04530599168051155, 0.2765884761127734, 13.209213056871969, 64.51046128426829, 65.85199817534416, 56.935595696972264, 39.19481738921135, 19.417342485920077, 33.70216161974015, 44.60708810437111, 69.51901420470207, 69.32064425560736, 67.80424025750929, 9.458658387584071, 0.3834111634041033, 0.2976239634858024, 3.7002671870493122, 0.9357730287217325, 56.831084143730905, 73.09449780371882, 64.92024306328067, 64.19886035303917, 61.299530613806944, 67.07782514633672, 66.71456659993818, 56.198613720555464, 51.442135841615745, 54.86026179405951, 51.03605285767586, 56.80162322136664, 57.08592053382628, 62.38190081811721, 58.549784383466175, 59.07643710413287, 55.632015582053896, 49.78920590492987, 54.13740427263322, 62.59730562087029, 57.284219880257886, 58.70531028316867, 56.68951795947168, 57.542590325878514, 53.72818731492566, 52.58920554191836, 43.25161503207299, 45.0926539974828, 44.192124874361106, 42.70053378997311, 43.649833663817375, 43.737761435970185, 41.95034127081595, 42.821448695275095, 42.6285739867918, 44.949679682331706, 42.06737695201751, 44.62910829051849, 44.15068895586076, 43.64753907726657, 43.35685222379623, 45.22156269319596, 44.67309767200101, 45.36602358664236, 45.23146275551089, 44.21669852349066, 44.197882913774066, 42.990063544242616, 41.42059380008329, 47.33022889783306, 44.455429661658506, 42.29860067367554, 43.642753785656346, 44.60269897214828, 42.56797728999969, 46.026287924858835, 46.30559598245929, 45.19057989120484, 47.672589055953495, 48.06259424455705, 46.58208385590584, 54.946934407757176, 54.69793450447821, 60.64873095481627, 44.408298461667954, 53.956418268142215, 57.48588854266752, 51.337216361876465, 49.23186456003497, 42.67875679077641, 45.37819077891689, 42.633539707429954, 43.261271907437234, 43.544616083945, 46.029249314338934, 44.24035826037007, 44.901293323886016, 42.409031083506925, 44.42237977058657, 47.586426350378225, 43.07815213357249, 44.15521144866944, 44.94220756715344, 45.36257190089072, 45.92827966136318, 43.78699894874327, 46.60933256149293, 43.62569932014712, 46.43096277790685, 44.19154828594577, 43.6360582997722, 42.498637630093484, 44.52245120079287, 42.36085653305054, 44.01387668425038, 43.84478330612183, 42.922159471819484, 42.7592908951544, 44.80326937090966, 43.951216820747625, 43.80559882810039, 42.776145319784845, 45.56257747834729, 44.11576024947628, 43.36309663711056, 43.21993012582102, 45.13621976298671, 44.57057868280719, 43.62833907527309, 49.960778221007324, 59.27451287546466, 59.31461126573625, 63.170214852979115, 59.562206960493526, 58.991156931846376, 60.616795016873276, 62.38079863209879, 63.037630896414484, 63.95799544549758, 65.17533832980742, 66.42127529267343, 62.36280672011837, 61.817738471492646, 64.72545423815328, 66.19453876249253, 66.40563288042623, 69.47911585530927, 69.46160639486006, 27.778800187572358, 0.2663163402147832, 0.8221071537944579, 2.054187056999053, 0.18030847633077254, 0.011899018408580413, 38.865793289676795, 77.19581434803625, 68.68731483336418, 55.498537325089984, 49.369759405812914, 30.368764746573667, 24.161233478976836, 56.05775748529742, 57.56639911282448, 67.11834323021674, 12.373041202945094, 0.18471810906644792, 0.054675097607316515, 0.02724788587300047, 0.0657255481928587, 0.017753593518488833, 0.025367892700277513, 0.08131212029125422, 0.1879212146084155, 0.15360845823682126, 0.169583659078325, 0.19760992858679066, 0.2224841293308043, 0.19598249736572468, 0.21411245839009363, 0.4695334808240014, 17.858027758136874, 77.08262258960356, 75.2959280629312, 69.39162346624559, 49.84441718747539, 24.016839265823368, 36.533591208919404, 55.3156489710654, 74.28497637471845, 76.80374991509223, 71.71003449347712, 10.627628641743815, 0.5771306830067788, 0.5152284498176267, 7.058418383521419, 0.8256712399663464, 59.215971500642844, 78.0840664525186, 67.8127831797446, 67.35305001658779, 63.82112041596444, 68.11717479459702, 68.70309060619724, 57.89472503046836, 53.36859226226807, 53.91638655816355, 51.63184911974015, 57.081456876570186, 61.027867255672334, 64.35459806073096, 62.16570369658932, 63.41032666544761, 58.19712408127324, 53.90762006082843, 57.1797122493867, 60.85911120137861, 58.481182129152366, 61.84614035391039, 58.30348307086576, 59.6111620626142, 54.911331053703066, 56.73316609474921, 47.034627314536806, 47.43808231046123, 46.93995306568761, 46.348063484314956, 47.24299538520075, 46.52120082609115, 44.53670117162889, 45.70595579762613, 44.534567402255156, 48.10107661831764, 43.72486076047344, 47.05250547778222, 48.65777469450428, 45.80663519520914, 44.40571754209457, 48.200783268097915, 47.452948093414314, 46.902200252779075, 47.63731125862368, 47.031956180449455, 44.831588883553785, 43.70517830694876, 45.79542113888649, 49.98080976547734, 45.93146854831327, 44.35282045795072, 46.658060166143606, 47.76245055660125, 45.11015953556184, 47.764372517985684, 49.11637821505147, 48.47397635059972, 49.628914325468, 49.294045894376694, 48.55376912701515, 56.67801757012644, 55.693165333040305, 61.79569867349441, 48.707569183841834, 57.35333596506427, 59.357384712465354, 54.138251504590436, 49.61027522240916, 45.21561245764456, 47.75857133250083, 45.600604857167895, 45.859116508114724, 44.89053818487352, 49.28697386095601, 44.97804234104772, 48.411979367656095, 44.6443231644169, 48.10733672111265, 49.52257887009652, 43.99010712100614, 45.95917617121051, 49.135691965779955, 47.24688245404152, 47.90787243073987, 45.77466395593459, 47.84787193421395, 45.59214822707638, 49.16822410398915, 47.42946094082248, 47.287004378534135, 44.98840524304298, 46.72255962125717, 45.49679933055755, 47.0109244315855, 45.76065717204925, 43.60281229019166, 45.94592248239825, 47.17112971890358, 47.412547680639456, 46.838308765042214, 44.92148960790327, 47.8947050340714, 44.55703081623201, 47.30500021288472, 45.663056835051506, 48.74142708316926, 46.743155987032004, 47.03402719190044, 52.609856820875606, 61.906003567480276, 62.34794485953547, 66.69497828329763, 63.14155409413, 62.59666235216203, 62.785002800726126, 64.83532374905002, 64.09027345718877, 68.4975976328696, 69.50658813599618, 70.4314124199652, 64.37530425287062, 65.88351049730855, 66.78136456397273, 69.02270886205858, 70.43433850811374, 75.2424269337808, 73.06380133475028, 32.58934597815237, 0.6761571079973252, 5.2982003458084606, 6.499501716706061, 0.3328442429342578, 0.2578734384188729, 42.540944314772084, 84.74958542854556, 76.03425933468726, 65.78672209093648, 67.26074880169284, 53.13610161504438, 31.524198901268747, 67.23497882966073, 67.61192644796064, 80.61118679661905, 17.53901158609698, 0.2923414501692018, 0.1888318633240077, 0.21467228480164083, 0.24159449903715044, 0.10657981443669527, 0.1608421821748057, 0.18345274632015537], [0.09915479068313876, 0.07776567712426186, 0.05275070389372207, 0.06822737684893994, 0.13916955479691107, 0.1157418046627314, 0.11261768278575714, 0.2357594984313173, 10.316698435814152, 56.87492839751705, 54.8431484929977, 46.9786629369182, 24.544162711789532, 25.381265148039788, 47.22663125684185, 38.584414220625355, 65.93275977719215, 58.643332912075905, 66.28367854702857, 5.809249877929688, 0.07098426681853111, 0.03557414312155978, 2.187368562144618, 0.03036299664076538, 33.951914618092204, 77.08671754406345, 58.30191412279683, 67.15264043500348, 59.205828251377234, 68.55456613725232, 43.3168597375193, 49.36669995707851, 59.577421834391934, 61.825975448854514, 59.64987977858513, 63.67593388403616, 58.61035754603725, 60.40546163435906, 56.917227237455315, 59.07825316152265, 54.52667597801455, 58.17635120884065, 42.90537564985214, 47.12359843715545, 60.40087638362762, 52.58699724751135, 57.84635436150336, 56.609748717277284, 51.96682737719629, 47.991277710084, 45.938611184397054, 43.08241182757963, 43.88153199226626, 41.332156119808076, 41.19870531943537, 41.65907782893027, 42.366351773661954, 41.54863565198837, 41.808402461390344, 41.331104924601895, 41.250484528080115, 41.46759163948798, 41.40352756746354, 41.99720574963478, 43.042854724391816, 42.29208561681932, 43.89454249412783, 40.7593959377658, 43.88406584339757, 42.481822429164765, 43.20831206537063, 42.833015764913256, 41.17579475525887, 41.37347436720326, 41.92452423034176, 41.370916981850904, 40.641583627270116, 43.326289115413545, 41.10501558549943, 43.50891467063658, 43.786469428770005, 44.73820901686146, 42.575010099718654, 43.831125613181825, 44.64308369544245, 50.975950379525464, 51.31613754457044, 57.16595649719239, 44.87768065544867, 47.25626084112352, 56.43869807643276, 50.45321610666091, 44.979187673138036, 41.91765616017003, 44.709662006747344, 43.3652304064843, 44.493264844340665, 40.80848047810216, 40.53755060318978, 42.19320658714541, 42.31173669138263, 41.183631650863155, 43.40987090141543, 45.20190769626249, 42.696866373861994, 43.02519621387605, 45.36809852046352, 42.457040894416075, 41.85241145472373, 42.65308880036877, 42.84799137423116, 42.4454189115955, 40.630797109296246, 41.83038734620617, 43.126377674841116, 41.496942735487416, 41.362852588776626, 42.356220291506865, 41.47143948462702, 41.474565613654356, 41.94839577521048, 41.99633106108635, 42.33581612187047, 42.51650794859856, 40.74734641659645, 41.08865145714053, 42.43320072850874, 43.13819185380013, 40.97474582733647, 42.18044319460469, 41.791838292152654, 42.124098347079375, 43.301005517282796, 42.06270933151245, 46.64578706987443, 51.29914191461379, 53.46541204760152, 56.936572367145175, 57.310731180252574, 58.54046875430692, 59.11360548388574, 58.78074138395248, 60.218678366753366, 58.29523824876355, 59.26363614297683, 57.634636586712254, 59.64273322013117, 58.1188492621145, 60.77419188714797, 63.87643368013444, 65.18232014871413, 70.62218866040631, 37.491457539220015, 0.6718467296131196, 0.16696848005296724, 0.997880450900524, 0.23512013677147128, 0.04498648705081113, 24.986741388997725, 73.67852303289598, 61.62092570335635, 59.99371082552018, 60.99061258377568, 38.673142156293316, 24.294266546926192, 36.59499983633719, 51.604408218014626, 58.127533389676, 15.985038145895928, 0.3249546404807799, 0.1322241863536258, 0.041352031872637814, 0.02158473411034192, 0.001822289515046343, 0.072682055554563, 0.051773788572679606, 0.08811049944450779, 0.08333400252365297, 0.010276511217647744, 0.06189483661024321, 0.08712489668640398, 0.08657488386116682, 0.1194585491752913, 0.27077212208701723, 13.91330497880136, 67.69526112464168, 63.77680547775761, 56.46912390185941, 38.53161127336564, 31.772553574654367, 42.071150272123276, 45.286332791851414, 70.74337420925018, 63.795201393865774, 72.29561298124253, 6.67878786402364, 0.058609441733889045, 0.18302721512173453, 6.445196991966617, 0.5823220625039071, 35.28671287721203, 79.52292519230997, 60.25229700150029, 69.27929462925081, 63.13762780158751, 72.06609156823927, 46.793111293546616, 50.79110084041473, 59.08541148708713, 59.58328185542938, 60.182412132140136, 66.95620813677388, 60.79519225705055, 62.11042965612104, 60.318086916400546, 60.0289729333693, 57.04736363503241, 59.633900042503114, 44.77843684534873, 50.13577084387503, 58.41622767909881, 57.41389343815466, 60.050094896747225, 57.5726160695476, 55.538168953311065, 51.212226113965436, 45.15287414673836, 45.75982562957272, 44.222523243196555, 43.97848513818557, 40.38733167033042, 43.127609299075225, 43.59889384238951, 41.59559819006151, 42.47001217257592, 44.79460877756919, 43.40370493550455, 43.57724235903832, 43.96950291049096, 43.601784629206506, 45.83763760905112, 43.67711767073601, 45.442647087958555, 44.44320755620157, 45.29932368186213, 43.06144283663842, 42.721895017931544, 44.572402584937315, 43.94505477720692, 43.10274539455291, 44.07150022445187, 44.79894691897977, 42.600168182003884, 45.80892978175994, 41.3863750427, 45.82547433914677, 47.593878853705625, 46.892343336536044, 46.95692516142323, 45.60418205876505, 46.12893635226835, 55.11287027789701, 54.57860031435567, 59.2849777590844, 47.99259170409172, 50.195363413903024, 58.06719949168544, 51.017311772992535, 46.37087206686697, 44.382261768464126, 48.042703905413234, 47.49054008914579, 46.52589590318742, 43.20119296350787, 41.29312461422336, 44.44761237790508, 44.21502759379726, 43.92670985191099, 43.297510685459265, 45.778009737691576, 45.263367314492505, 44.451264104535504, 45.44784422843687, 45.623923347842315, 44.88807885877548, 44.40500759309338, 44.37509167578913, 43.78634783529466, 42.813643178632184, 43.948490773477864, 45.170838602127574, 43.5488247871399, 44.131210465585035, 44.76814846838675, 45.34465059157341, 44.145115267845895, 44.11391281312512, 45.27366353619484, 43.56060758713753, 44.96454154291461, 43.374675473859234, 44.001595743240856, 44.31041571401781, 44.999811495504076, 43.7114344873736, 45.26435575177593, 44.79687198515862, 45.62894398166288, 44.87980658008207, 43.648280405229144, 48.55454967867944, 52.67642336506998, 56.105975181825706, 61.17909423766598, 60.20611501509144, 60.363354990559245, 62.09208473082512, 60.473993286009765, 60.95122806487545, 60.924814824135076, 62.5976154881139, 59.26001971767795, 60.41261603755336, 60.38002898616176, 61.72327603063276, 65.48075760564497, 68.28473060361802, 71.39272259127709, 41.49299683109407, 0.5965277228143908, 0.4234454167946693, 2.6912281445918547, 0.42056443590310316, 0.12532429288952582, 27.387606520806592, 79.64514624687934, 67.42208373162055, 64.95369695848035, 60.187746555574485, 43.80325717310752, 30.811176723049535, 45.51233191643992, 58.819470867033935, 69.76087539426743, 22.662811586933753, 0.4940410625309714, 0.07861765882661266, 0.00835908698894444, 0.15089842220467908, 0.09533635565950986, 0.04834577876834139, 0.07130256102931115, 0.23923474904750627, 0.2425121191528536, 0.18149615776154304, 0.17595116740032551, 0.22338127957717066, 0.30396778436918415, 0.18383009058813896, 0.39828246219023583, 19.463587230251683, 80.67537246211883, 70.44884343301096, 64.56141679517685, 38.87043737596081, 35.0927948182629, 62.1982515242792, 52.01594329649403, 75.17474251408731, 67.96349633124568, 77.43934646729501, 8.00538738889079, 0.21099930689219507, 0.7840594276785852, 9.204727084405961, 0.5188625870693115, 35.54487151484336, 84.18442679989724, 61.31123888877131, 73.39184484174176, 63.90167805456347, 74.03920850446148, 50.02578758424329, 50.48440287190099, 58.83814527142433, 63.57280692746563, 61.60031364810083, 69.01848839175317, 62.873236517752375, 64.47908232288977, 61.87316940676782, 62.906325632526034, 59.63797538511215, 60.975911540369836, 49.86594315498106, 54.61361139051376, 60.10894221644248, 58.76725235292989, 62.212364212159194, 59.60567466674313, 57.28246265842069, 52.251210981799716, 49.07974327764204, 48.00419015269126, 47.58350026222968, 47.55660849232828, 43.72313099522745, 45.91692047734415, 44.96443956129013, 45.83400549427156, 45.509260700595, 47.55930316063666, 45.304265868279245, 45.756636742622625, 45.501996471035866, 46.45966668282786, 49.243604213960715, 47.03121877485707, 47.180072722896455, 44.09712506878761, 48.13589549833729, 45.39233876812843, 45.59619219072404, 48.27613592147828, 44.98505946128599, 46.37396681693293, 46.14034652709962, 46.13003461591659, 46.19701693134923, 48.10223763988864, 45.04899409509475, 47.71490750774261, 49.06419892464915, 49.77341052024595, 51.24266370650261, 48.76830316358998, 49.188196812906575, 56.6339458188703, 58.91683586182133, 61.69218732464699, 52.85140814319734, 54.22654405716927, 59.57237766635034, 55.030939809737674, 48.702701522457986, 47.22905528160834, 49.70291768350909, 50.279419806695756, 50.41422774714809, 48.07011735054755, 43.23172469292918, 47.16858017829157, 46.7724560922192, 45.553822748122684, 47.57602030231107, 50.56272083713163, 48.0047510516259, 46.854119839206824, 48.90447608886227, 46.8331390811551, 47.71877888710269, 47.131360807726466, 46.46942946218675, 46.06429176945841, 45.54904137888263, 46.735487753345126, 47.6831716106784, 46.360595457015506, 44.997034457422075, 46.6817787385756, 46.33268779323947, 45.71493018058039, 45.97089229091522, 47.25317785816808, 45.44260394188666, 48.0841084449522, 45.1915055705655, 46.87869741070656, 47.87116296829716, 46.79941454241353, 44.99755613265499, 46.53875343261227, 47.14447329121251, 48.33621878777781, 47.745294109467544, 46.02130259236982, 51.10469433569139, 55.41552036039291, 60.15075468247937, 63.60140100602181, 63.00029385474421, 63.61334854556669, 64.68160606199696, 63.83771204179334, 64.73028659820557, 63.66315872438493, 67.54115120057138, 61.39618565959316, 64.12662206157562, 63.66030323889948, 65.1598253557759, 69.42886244866156, 72.24266098391625, 74.37730112383443, 46.005303244436945, 1.5602060864048621, 3.387223068744906, 6.734651730906579, 0.5902475791592753, 0.1357986453560091, 30.352481026803297, 85.37210479859384, 74.27578233903455, 73.79507234019619, 68.82124808526808, 53.07269257883872, 36.382940815341094, 55.76510160200058, 68.72856247809626, 83.45702325144123, 30.05327674650377, 0.6943833203085008, 0.20868389807160825, 0.16041792268233915, 0.13140050393919792, 0.22000030374094365, 0.16654523179656075, 0.12221836560075322], [0.10273911689798679, 0.03203653103311456, 0.11996893227220544, 0.015462083768309846, 0.09197572711855174, 0.02999307767998788, 0.03774668037470791, 0.05168783350757534, 13.59478400599572, 58.73548115453413, 51.64732287006994, 44.27168230856619, 19.949688526891894, 16.648111881748324, 48.77413965040638, 41.57619814718924, 69.20511476455196, 58.80779397103095, 64.42168235778809, 3.9101983222269245, 0.10106061825588827, 0.16594316329686873, 2.978005865889211, 1.669864157034505, 10.575557216521233, 74.12541435610864, 62.295036008281095, 65.31491979475945, 62.41180104594078, 50.05824911978937, 49.87551373820151, 68.5580256677443, 59.44910149420462, 64.36969918589439, 58.61542524829988, 60.72028675386983, 56.604645713683105, 60.0069135235202, 54.91363740736439, 57.49695354892362, 55.70257509908369, 56.50189138227894, 52.63812534270748, 39.97644378292946, 39.99980934204594, 57.64152034636467, 51.82322548281763, 56.730208627639286, 52.830772553720784, 51.11845401025588, 43.05914040534727, 40.596727401979514, 39.396089892233576, 41.416412553479596, 40.45887177990329, 41.553813180615826, 38.8998394627725, 39.55788766184161, 41.10031266366282, 43.31150962460426, 40.26363972694644, 43.397723320991766, 42.537551464573035, 42.26088316209855, 41.92465366855745, 40.9435002265438, 40.320427802301225, 42.5824273017145, 41.360487399562714, 41.93054899092644, 41.59794376742455, 40.79777240753174, 41.05999854303176, 42.38773653584142, 40.0896002400306, 40.39446253930369, 39.80185124181932, 39.48019335346837, 38.7778341385626, 45.43186841472503, 45.42631433856103, 44.042408004883804, 42.863520037743356, 45.820893010785504, 43.28143289012294, 49.14488207909369, 51.59587706288984, 57.43583909926876, 50.834125318834865, 51.83656938614384, 56.43536798415646, 50.87565145184917, 45.443055014456476, 43.121835570181574, 43.809160340216856, 44.81108665466309, 45.54300485118743, 40.92652813080819, 40.37971050508561, 41.15363336378529, 41.85374506058232, 39.71494720828149, 39.90517823926864, 40.00617927120578, 41.39542395068754, 42.40939586393295, 41.215344013706336, 41.47236516398769, 41.336027499168154, 42.292650438124134, 42.188425217905355, 41.08938101799258, 41.36239759383663, 41.9409393495129, 41.27921196722215, 41.956479780135616, 41.673151293108546, 40.217630324825166, 42.60916609917918, 41.514377670903365, 42.41943713157408, 40.47670287470664, 41.29974165270406, 41.86959143607847, 42.44143378350043, 41.251523956175774, 42.2030556586481, 41.556131301387666, 41.613499887527965, 42.81865204534223, 42.52772200492121, 41.01186321627709, 40.827586343211514, 41.949207705836145, 41.9946522866526, 40.51309854753556, 43.50916962469778, 44.749701561466345, 45.79167135300175, 46.79004792244204, 50.09260516012869, 47.08686151812154, 49.3453779528218, 45.53422266437162, 44.36710180774812, 43.408513761335804, 46.18464185345558, 48.149121730558335, 54.76352045612951, 60.38270796498945, 65.71548008149671, 69.67744658070227, 54.74057851299163, 1.5667331555197317, 0.16471840321056305, 0.7365076147740888, 0.2603380658453511, 0.20377070042154483, 15.26684138082689, 73.43140586729973, 61.2703364126144, 59.38001286598944, 45.542447874622965, 17.89398608669158, 19.1581287307124, 37.40512617172734, 47.231506762966035, 63.94836602672454, 26.789390156345984, 0.5227783382419617, 0.03190659102983773, 0.022560410284166856, 0.03831437833967709, 0.06173794180335057, 0.0801443188421188, 0.025927301593905976, 0.06696703963943067, 0.02108406692352747, 0.10504972234728838, 0.04937847295115071, 0.0610496003120657, 0.08915133714195221, 0.08937780039324876, 0.08794112506532863, 18.46857605441924, 68.85725544344994, 59.41980531138759, 50.96854102226996, 23.073695551964548, 19.832680302281535, 49.37494085681055, 48.65018883059102, 75.226360905555, 62.93029131427888, 70.20254212041056, 4.50287115189337, 0.02040678391142959, 0.31371141152997173, 7.055849721354823, 2.7797849668610484, 10.38533599145951, 78.85765983212379, 64.15114079752277, 68.53654676868071, 62.29761300548431, 53.435837376502256, 53.432024832694765, 68.73701910818778, 60.91521678432342, 65.469672987538, 61.56740888472527, 63.06960605805921, 59.1806270230201, 61.592315935319476, 55.913096550972234, 58.8072056155051, 57.51911494039721, 58.247475547175256, 53.40079884375296, 40.504167310653195, 43.95229155017484, 59.56459568392847, 53.15513295512046, 58.34627220707556, 55.168822888405096, 53.67845166114069, 44.68121305588753, 44.73838944588938, 41.332085517144975, 43.558285543995524, 41.940166642588956, 42.85956628860966, 42.24610367128926, 42.51829262702696, 43.382571205016106, 45.57757662188622, 41.956569994649584, 44.51009965712025, 46.21372230591313, 44.23676144692206, 45.22119791276994, 41.85194077030305, 44.767693473446755, 43.39724086946057, 44.056026474122085, 43.62047472307759, 42.2106493673017, 41.98710172407089, 42.383002235043435, 43.55076636037519, 41.8861791395372, 43.11858000293855, 42.23120650937481, 42.67406563605032, 39.56518327036212, 46.80370953775222, 46.74810209581929, 46.765552720715924, 46.14157030659337, 46.44238864221881, 47.057945805211226, 50.91722465330555, 53.412036434296645, 59.59580598338958, 53.946882986253314, 52.361978715465916, 57.82464012022942, 54.272031784057624, 47.55980522401872, 44.79179251578547, 45.76366955234159, 47.26777691994944, 47.549509002316384, 43.36761912991924, 43.119658654735936, 44.04382790288618, 43.09046837591356, 42.657783877465036, 41.9911809890501, 42.32178972613427, 43.06329027298958, 44.643730886520885, 43.33143526507963, 43.7588284861657, 43.28244878399757, 45.16965796870571, 44.434664633966264, 43.747904685235795, 43.551280190867764, 42.81088967477122, 43.17655263408538, 44.63102632953275, 43.28585732367731, 42.32915201494771, 44.40836121959072, 43.6411730704769, 44.82465021071896, 43.413608920189645, 42.8628336229632, 43.55075851563485, 44.23937766782699, 43.22347987082697, 43.575202726548724, 42.18111784227433, 44.177133575562515, 44.111276980369325, 44.848133440940614, 44.8358368104504, 44.90997352907735, 43.968243829665646, 43.453185635228316, 43.36854873165008, 45.69591060761483, 46.14877570059992, 48.406570419188476, 48.570399976545765, 52.26867337380686, 50.70013715374855, 50.21153534612348, 49.36959074389551, 46.75894352697557, 46.543966262571274, 48.09336131618869, 49.75172373556322, 57.122355430356926, 63.458159969699004, 67.87059891608455, 70.42376379812919, 57.122716288412775, 2.1708419005717, 0.48287269569212393, 2.3715400215118163, 0.6388676863524222, 0.2776735630487242, 17.064077277337354, 80.18076158338978, 66.64823932032432, 65.85614804298648, 54.05339102591238, 31.39270340242694, 27.750023718803163, 45.70945062944966, 54.18573179552632, 70.70295810699463, 35.227641982416955, 0.6770727362844252, 0.09035228721557126, 0.048724306642167994, 0.04964835423555586, 0.11500787710951221, 0.10936350216187778, 0.0037206122989676175, 0.1752957638593451, 0.09993347309289441, 0.23394082102083394, 0.09774388655299142, 0.16250797907911962, 0.2743956260383129, 0.17795293982471191, 0.20616895399026333, 25.808960391629128, 80.82322228339412, 70.58372589849657, 60.8923101425171, 30.929287133678315, 24.03165013559403, 60.92004522200554, 56.99332121879824, 79.9860865069974, 69.19923905403384, 76.96380615234375, 5.501415402658525, 0.33065883923442135, 0.3720175360720004, 10.685300230979921, 2.831663460500779, 11.074149300975185, 79.96626284814651, 64.77680198607906, 71.51040154118692, 67.03542432477398, 56.719763355870406, 51.226648669089045, 65.89852533032818, 61.19195961183118, 67.2346415058259, 64.23287906954366, 64.98557013850059, 61.58953105249713, 64.49839999598842, 58.23773237966723, 61.92509374310894, 61.16849991583056, 62.2389147358556, 53.61243817114062, 47.03856537418981, 47.98650026321412, 62.5501940327306, 55.693381063399784, 62.086636558655776, 59.41917380978985, 54.90460418885755, 47.18187309080555, 45.3565824416376, 43.411683036435036, 46.20548925092144, 44.23109362202306, 45.06692717152257, 43.037296725857644, 43.866246515704745, 47.250738143920906, 46.00245952606202, 43.69328568058629, 47.528536089005016, 48.66296791261243, 46.557847530611106, 46.70205739236648, 44.76242573030534, 45.289749176271506, 45.380446141765965, 45.65025421880907, 47.183740139007575, 46.64457897986136, 44.496645927429206, 44.69373326147757, 44.943937332399436, 44.029679913674634, 44.85411897782357, 44.099776591024096, 45.78342260852937, 42.73657644948652, 50.95003527979697, 49.92155059691399, 48.085720539093025, 49.47148607623193, 50.337541487909135, 48.107328876372314, 54.6685088834455, 55.47542279766452, 62.45886164326822, 56.537400599448915, 57.8225455745574, 61.79785205471901, 57.59165917673419, 48.7035644438959, 46.457050461922925, 47.38759748397335, 49.43592979061989, 49.730778278843054, 45.982663323802335, 46.99627045662173, 46.07722382391653, 44.681973995700965, 44.73015246852752, 44.5583644220906, 45.09777661292784, 45.33365226561024, 47.69297753610919, 45.564201339598625, 46.290216369013635, 45.085742781239176, 45.53549743467762, 46.744387611266106, 45.21930340797671, 45.05545816113872, 45.613105450907064, 44.260534932536466, 47.577906962363954, 47.01895352332823, 45.02325157965384, 47.278532058961936, 45.53528954905849, 46.58270751276324, 45.89737922914567, 45.92904452354678, 47.291550405563854, 47.8582779822811, 44.680922800494784, 45.38273288357643, 46.03920821220645, 46.091038411663426, 48.037157673989576, 46.61699295043946, 46.43965867257888, 47.91094756895497, 47.93567419052125, 47.09807165207402, 45.940085995581846, 49.68953455648115, 50.01546390594975, 51.6104761246712, 51.845551613838445, 55.58331543399442, 52.595030261624245, 53.86232060770835, 51.24757059158818, 49.78886465872488, 48.116632738421046, 50.847924217101074, 52.84290052229359, 60.67127673856674, 67.92115826760569, 70.70203242763397, 74.69450319966963, 60.51842981769193, 2.833104196094698, 1.3981120552747481, 7.837643796397795, 1.4076528529967032, 0.28497818076322157, 19.11990523338318, 86.85133257219869, 72.07503457223216, 71.73573386284613, 60.19944306342833, 28.785058759873916, 30.956045542993856, 54.63292121887208, 65.92928455721948, 82.26572882744574, 46.052728622190415, 1.38372149198286, 0.18547624499807436, 0.1561058895482171, 0.11078625767221374, 0.159331027778887, 0.3538438773924305, 0.1444829567786186], [0.11694634002783608, 0.05522089311853052, 0.08885273139082617, 0.1456183756911947, 0.04342921033141114, 0.04138778519606398, 0.05174625537268097, 0.08837640856302555, 13.29914810196046, 54.08516614667831, 50.57200900969967, 47.34843654017295, 27.99492866762223, 37.76914173556913, 43.98325081794493, 51.81281159001013, 66.74846372296734, 59.46019003468176, 60.10871864134266, 3.540366128567727, 0.20530160456415147, 0.12494307987752462, 4.728378999617792, 1.5276587490112552, 0.2219322855554281, 40.92842655797159, 69.32637876079929, 60.85017996449625, 61.38860764042024, 63.023761395485174, 71.42210898860809, 62.88088906195856, 61.031573895485174, 61.62650723611156, 58.18345854359289, 59.102995472569624, 57.7647102263666, 53.63346992000457, 54.73812703163394, 53.84273621343798, 55.29769236041654, 54.09488185759514, 51.05784554635325, 56.30786741933515, 51.075982586030044, 56.04708471605855, 54.475771457918235, 54.23818565184071, 50.35904784356394, 46.49929438867877, 45.209136624490064, 41.276230965891195, 41.32672363711942, 40.64822419997185, 40.39545489895729, 40.82717841671359, 40.501029414515344, 40.22548683228032, 40.73920749848889, 42.33407851188414, 42.04425457985171, 41.80049104075278, 42.13270402723744, 41.80382897776943, 41.73045712132608, 40.715500693167414, 42.17646591124996, 44.685398224861395, 40.626286383598085, 39.03489059017551, 40.08371276240195, 40.861405018837225, 39.35345765083067, 41.53480145239061, 39.0101678909794, 41.25040608067667, 39.362365353492, 40.703517852290986, 40.34238523052585, 41.94664639811362, 46.999027882852864, 48.24392149525304, 45.460654689419655, 46.242814525481194, 44.55369287921537, 47.92564076762046, 49.80782147376768, 56.43230069068171, 49.80746846045218, 50.54542710704189, 53.41671974428239, 51.34331956986458, 46.81338602496732, 43.46713358356107, 45.441650805934785, 44.35883345142488, 45.43542208210115, 38.91619966876122, 40.24170975531302, 40.49915059920281, 41.62003455623504, 40.00101350968884, 41.69799950815017, 39.60959234545308, 40.93840114531979, 42.173928137748476, 42.36854437858828, 41.83222693781699, 42.46119860679873, 39.924927373086255, 41.850544406521706, 42.942198861029844, 41.49491487010833, 41.24687986989176, 41.99813142899544, 40.10277548143941, 41.908952420757664, 43.50237607955933, 42.12361589554818, 40.00398666627946, 42.31804386261971, 40.873972292869325, 41.28825303046934, 39.04939159270256, 40.173523272237475, 39.96718698932279, 41.14149755047214, 40.82620566891086, 39.83534436072073, 41.70323587233021, 43.710395059277936, 43.64361670709426, 42.88418700618129, 41.19493592169977, 42.885771643730905, 43.786857743417066, 42.33242327167142, 43.58243557714647, 43.373726260277536, 41.68266304077641, 42.233454027483546, 41.92582645723897, 44.42461159921462, 45.40434514322589, 50.43446717723724, 53.794698945937625, 60.43256128987959, 60.8630649505123, 59.172825428747366, 58.81236745465187, 65.36902889128655, 65.20365784245153, 63.14835156163862, 4.553023067212874, 0.2662893126328146, 0.9986322589458959, 0.284432603587066, 0.08535606095627432, 6.3104601444736605, 67.88664141008931, 63.21909543006652, 66.24059523305586, 45.571814660103094, 24.38401626002404, 11.900960418485827, 28.11324500268506, 52.5267731758856, 64.78303855465305, 35.936739829278764, 1.3390108846849011, 0.030364427309963974, 0.11955561251529764, 0.02868200629769314, 0.08486624732012711, 0.028233850607648495, 0.055534322670991385, 0.1138002390883142, 0.1294998091555411, 0.033963650104499636, 0.057645829529651714, 0.06655281589877221, 0.07747146105694194, 0.07328194836455007, 0.09930914207812279, 17.895541306464903, 64.22358305223527, 59.691076432504964, 53.808909693071925, 26.664321461031516, 27.67771286349143, 44.52493798348212, 58.30773099776238, 71.30266497212072, 64.47781539732411, 62.61009647000221, 4.202460252469586, 0.32956039172507107, 0.8901014407315563, 12.696667140530003, 3.485775806250111, 0.05801324529813663, 46.46325565153553, 70.52419216402116, 62.70997570407007, 62.277506935981016, 64.8430076722176, 72.49135494232178, 63.60710805462253, 64.13441581110801, 63.935241776127974, 60.69990611845448, 61.44077516371205, 59.88322942487655, 56.82518489899174, 55.03159092318628, 55.54100874931582, 57.54635580124394, 56.571309489588586, 53.15608609107233, 59.85341156682661, 53.68335462385609, 56.63280833152033, 57.03346275514173, 57.89044180224019, 53.324124351624526, 49.527250412971746, 46.91281418646536, 43.57607349272698, 44.194462606983805, 42.71586241260652, 41.80273463649135, 41.95041579584922, 42.951985174609774, 43.38967461739817, 43.01889688737931, 42.84127627649615, 42.97199318485875, 42.48350904833886, 42.84543791124898, 43.5062906049913, 43.9449724074333, 42.77282307224889, 42.5609484026509, 47.8137041676429, 40.75398698929818, 40.372203088575795, 43.31232155522993, 42.17597169260825, 42.022316763477946, 42.8771149727606, 41.37659265149025, 43.715831464336766, 41.66513396847633, 45.0457267607412, 41.86990914806243, 43.30814030862624, 48.42569589614869, 51.729422000146684, 47.65092580549179, 48.59651119478288, 48.09585594361829, 49.42221718449747, 53.63639600815312, 57.95009320782077, 53.08118843263196, 53.926274853367964, 56.604700626865515, 54.11696872403545, 48.41046533276958, 44.966561563553356, 48.463409485355506, 47.645669829460886, 47.70908671040689, 44.09807428236931, 41.36071097466254, 43.35615404190556, 43.00499208511845, 43.00567457752843, 43.14205146604969, 41.83971474247594, 42.50996151278096, 43.93888881129604, 45.17921286244547, 45.23343963007773, 44.27953097128099, 43.913365948584776, 43.33372592926026, 43.68953981707173, 43.909620085070216, 41.24414990025182, 42.82400608062745, 42.87867999845936, 44.126448708195845, 44.083286946819676, 44.49635567203645, 42.66904500222976, 43.26780657614432, 42.89617376942789, 42.975393879798155, 41.67935648272115, 41.882958873625725, 41.32118525043611, 43.50243099274174, 42.79674953030002, 42.74262082192206, 44.3056147329269, 45.32061822952763, 45.94628726282428, 45.54206348234608, 44.59374812341506, 44.88643538567328, 45.493618288347804, 44.19765933867424, 44.63456038505801, 45.80437198761971, 44.68215834709906, 44.48314512929609, 43.6993065188008, 45.99243787027175, 48.05594582711497, 55.14053475472235, 55.800755946866936, 64.12233491097727, 61.71797298615979, 60.98223047871744, 61.097877640878, 66.82355357754615, 67.63315431533321, 66.38396570759436, 5.307141388616254, 0.3902701937383221, 2.339739895636036, 1.3094018928466307, 0.1338722559833719, 6.911185845252007, 74.5142702902517, 69.84586531116118, 71.30303367491692, 57.17875519106465, 33.07645336274178, 14.845939682376, 35.687088812551195, 60.065411752270116, 72.80119865171372, 44.150853695407996, 1.5530317036374923, 0.028962162736382698, 0.04277200648380865, 0.0738768922465463, 0.08705899014227814, 0.051602659852153836, 0.010404066772260254, 0.27966352239731823, 0.32623158647648753, 0.14974510747819178, 0.23841843639890994, 0.15328991887790544, 0.16505462387877126, 0.2576983720064163, 0.39266483137203806, 24.27505870019236, 77.26659744016587, 68.46292388054633, 65.34829916492586, 40.26673839938256, 47.57124677781136, 56.22470140457154, 64.98721361160278, 77.90857176626884, 71.3925656964702, 69.79457639878797, 4.34615481284357, 0.44110806418522713, 0.9674304170954613, 13.349265206244684, 5.515668315272178, 0.4225239968828617, 47.330632901960804, 73.9265815673336, 64.79338184479745, 65.17697395816927, 63.034187055403194, 69.79348597988006, 69.2589218385758, 64.45767010411909, 67.01095657963907, 62.88308558925506, 63.50581676729264, 62.25029745409566, 60.3481871851029, 57.03235272438296, 60.18624428779849, 59.68266294848535, 57.65051041879962, 55.49195166557066, 60.944030515609256, 55.407059807931226, 61.01016952145485, 58.29941557299707, 59.929901707556944, 57.40580158848917, 52.14644055212698, 50.86651232934768, 45.67081528325235, 47.20360694393035, 44.57900001156715, 44.03230397931991, 44.700283619665335, 45.38837325188422, 45.70358668604205, 45.998815644171934, 44.75162352285078, 45.38637676546651, 46.842352728689875, 44.717930363070586, 45.910491712631725, 44.958563850772, 45.62876747500512, 44.98659703039354, 48.89807478074105, 42.08405879236037, 41.817941665649414, 45.83042044793406, 45.467142289684666, 42.54637287509057, 46.73519749795237, 42.620129123810806, 46.177095213244044, 43.99446095189741, 46.89160200857347, 46.28159892174506, 47.0925489548714, 52.39308703330256, 53.54527150430987, 51.278882872673776, 52.583439657765055, 51.10913053635628, 53.529189786603375, 56.37513999016055, 61.80117822462513, 57.06920339215187, 56.121935306056855, 57.68376427312052, 58.23869336035944, 51.30528042393347, 48.44249540759672, 51.3285400790553, 50.43435735087241, 50.34347211160968, 45.028605614939046, 45.894355081742816, 45.745422686299975, 45.24231987614786, 44.43934402158184, 47.482918923900975, 45.2201545623041, 43.961736617549775, 45.87617097362396, 46.8383676005948, 46.46665634647493, 46.286811751704064, 44.84736465638684, 43.973519417547415, 46.25499348486624, 46.477336960454146, 45.476912913783906, 45.06521309575727, 44.89908895184917, 46.605398424210094, 48.68059896653699, 46.289129872475904, 44.287669889388546, 46.89220213120984, 46.62575552540441, 45.060035567129816, 43.37049814962572, 42.414236068725586, 43.86875291024485, 46.204159567433024, 44.70451193471109, 44.4821096235706, 46.79626095679499, 47.06179365035027, 48.961868209223596, 48.178500283148985, 46.95794105529786, 46.9937248383799, 48.640606480260054, 45.37486853138093, 48.90027523040772, 47.90803324791693, 46.60486890423683, 46.94675837793658, 46.595718014624815, 50.25512072347826, 50.23321820843605, 56.81800303920623, 58.93967582333473, 66.41753335152903, 64.75226756065123, 62.80239851244035, 64.74569366824242, 70.64398919382404, 70.33343945780109, 67.4518309870074, 5.310231235719496, 0.8318520373394414, 6.260411681667452, 2.3997335280141523, 0.19454939200753169, 7.753782051224863, 82.10481751349666, 75.11194536762854, 76.03281590246385, 62.76659119513727, 33.14176082611084, 22.034896996713456, 45.44720880446896, 71.88934172353437, 82.68479485665598, 53.25393353739093, 2.326767146587372, 0.16592482315196147, 0.18118134158993923, 0.23130731717232736, 0.1866645239774258, 0.1258139762907259, 0.3209574694835371], [0.08325079771419687, 0.07716016122891058, 0.020075207651262323, 0.11204788957031504, 0.140904575406063, 0.08136625206398387, 0.04523804351206749, 0.1777446864833755, 10.464826745371665, 57.52626934359151, 48.10714060260404, 42.01626454630206, 21.725614186256163, 34.23018324759699, 32.8227093527394, 46.850503413907944, 66.75168006650864, 57.541641112296816, 56.33306080295194, 2.848607119052641, 0.07689173168112194, 1.2360441324210938, 6.927521046130889, 2.184095589383956, 0.38156804778883535, 8.75548626146009, 65.08707715618995, 56.33579469496205, 61.983662574521965, 65.91859217612975, 59.854521597585375, 59.59249942533432, 58.440538529426824, 57.48534725558374, 58.208361671816924, 56.936984216013265, 50.152068291941, 51.52874961976082, 49.002782452491026, 51.607993264352125, 56.97538814237041, 57.32312586999709, 56.09880116678054, 55.68361436167071, 55.12550815459221, 51.81994638135357, 51.53334663760278, 49.42439802231328, 49.435137471845074, 47.87952938387471, 44.34559937446348, 40.215190610577984, 39.762050951680834, 41.6987173018917, 41.13902253489341, 40.40727300028647, 40.66596900263141, 40.79214772870464, 41.454812557466575, 38.525633581223026, 39.8996869210274, 40.53706815165859, 39.37464237213135, 39.64633710922734, 40.885311865037494, 41.331422636585856, 42.59194297175254, 40.41267802638393, 40.221980233346265, 38.98259362866802, 37.59561607914586, 41.0813009354376, 40.4346432993489, 41.19389257123394, 39.49908741058842, 40.439126568455855, 39.98526911581717, 40.69914048717868, 38.480883259927076, 41.82596683502197, 49.03616966739778, 48.152757767708074, 46.553662361637244, 45.05860390201692, 43.66369924237652, 47.97730230516004, 49.89177196256576, 53.86419942302089, 56.57611831541985, 53.83930021716703, 53.91514316681893, 53.51745013267764, 47.56086426396524, 45.575183976081114, 45.55490532229024, 46.02006312339537, 44.31124333412417, 40.149259490351525, 40.510525472702525, 40.57300490717734, 40.91201143880045, 39.874799482284054, 41.867037973096295, 39.485319891283595, 39.47231331179219, 42.08611803670084, 41.53273044093963, 42.355863355821185, 41.70816629163681, 40.94990545703519, 42.09506496306389, 41.17091532676451, 40.38782196660196, 39.6805166429089, 41.17534760505923, 39.630655473278416, 41.41804033710111, 41.27335979092506, 40.93127027634652, 39.587529013233805, 40.70616152978713, 41.21325731277466, 40.79863925133982, 39.365585619403475, 40.25295126822687, 38.50963423329015, 40.72159213404502, 40.07898630634431, 41.34926549849972, 43.778836496414684, 47.5601621597044, 49.48337870259439, 50.13127188528738, 50.13650040472708, 48.303565056093284, 43.90565064645583, 44.93526104957827, 42.31621996048958, 45.51073943414996, 42.096465249215406, 47.01712569882793, 51.22474631955547, 55.95452070236207, 56.803788369701756, 60.90346536328716, 57.78997813501666, 58.22983272614018, 58.44339793728244, 64.84456877554616, 60.291202991239494, 68.96475192039244, 70.18853141415504, 70.39053347802931, 5.692499058861887, 0.44938867791525783, 0.8759706731765502, 0.5055679585183821, 0.14954777855065562, 4.38957299916975, 62.38827074727705, 67.17171884352162, 64.66324152485018, 61.993472422322924, 44.07191991806031, 25.43363859576564, 42.334647255559126, 47.96323668572211, 66.35019410041072, 36.88744391164472, 1.2715584977019219, 0.11415185812380045, 0.06237218216542275, 0.08588226376882485, 0.037331525837221456, 0.026507894733860612, 0.034300793908656604, 0.051497552588942556, 0.02974996350765709, 0.07023467276726039, 0.0323747416147061, 0.09683037266856241, 0.12198355965196125, 0.07692962238985686, 0.13445694960894125, 17.043014149512015, 69.26738631340766, 57.67739434396067, 54.70235893803259, 29.221814678561305, 37.9366583208884, 41.14625146312099, 51.961469419540904, 73.05803545059698, 65.86693456096035, 61.37939399288547, 3.269363689807154, 0.27852836395463637, 2.1501202640994905, 14.150800570364922, 6.162321538694444, 0.7616119483305562, 10.117656780827431, 65.67009433623284, 55.052940384034194, 63.15888312555129, 68.84162872068345, 62.11288898221908, 60.155728247857866, 60.008164759605165, 59.33888289236254, 59.979656973192775, 58.86634711296328, 52.39450693130494, 53.478163673031716, 52.81493402296498, 54.06525619568364, 57.13918632076633, 58.42575903861754, 58.89719655436855, 56.82989958793887, 58.14896129792737, 53.153442413576194, 53.78509306138562, 50.705208778381355, 51.80045220159715, 49.272751346711196, 47.39745832258656, 41.978288158293694, 42.96203036462107, 43.5941634639617, 42.17144135505923, 42.869619323361306, 42.54180723621, 43.22451537655246, 43.65247734131352, 40.71307666840092, 41.32675109371063, 42.35825992399647, 42.486137036354314, 41.98298323538996, 43.816867797605454, 43.939681130070845, 44.74583802684661, 42.33537681641118, 41.39082693284558, 41.853717603991115, 40.7549048239185, 42.484991704264, 43.160733715180434, 43.47222089767457, 41.03517386221117, 41.67293948511924, 42.00767455562469, 43.02805562173167, 41.01112188831453, 44.56992756935858, 49.915937685197406, 51.00649387605729, 47.65946480535692, 46.283422823875185, 47.46356594947077, 50.197038265966604, 53.89276604498587, 57.220767697980335, 58.921236761154674, 54.41131122650639, 57.1431714488614, 55.95587392007151, 50.94220230656286, 47.43338723336497, 48.93631396755096, 49.32737035136069, 47.6431595125506, 42.67663871088336, 41.80623339068505, 42.35042302839218, 43.667605923068145, 43.523964804987756, 43.25103844365766, 42.02048501660747, 41.29615268399639, 43.157078066179835, 44.078744842160134, 43.092527620254025, 43.455880303536695, 43.06909145847444, 44.0291896174031, 42.592982399848204, 44.17499196144843, 43.179404197200654, 42.93768029059134, 41.854792333418324, 44.78539120766425, 42.61924659052203, 43.727527972190614, 43.253085920887614, 41.75166145447762, 42.81862458875103, 43.543133428019864, 41.98357551328598, 42.50756102223551, 41.952894733798125, 42.16434578741751, 41.87683605378674, 43.27814594391854, 46.63620079717329, 49.930815235261, 51.75575679348361, 51.66289860202421, 51.66160814223751, 50.33384661520682, 47.687615656083636, 47.61806026581795, 46.182978768502515, 46.55137169745661, 45.606488412426366, 48.61615834697601, 54.26448906621626, 58.59850022100634, 59.66421996393512, 62.46806352369247, 60.491985197990175, 59.880872080402995, 61.63546985195529, 69.07598249373898, 63.90228209957, 70.49167571529266, 71.35425198462703, 71.62246365700999, 7.639949965861536, 0.9317760722291086, 1.175631051582675, 1.5920283981869299, 0.24762854460747014, 4.718347537902094, 67.5974529020248, 72.21802849923411, 71.39327172310122, 63.341383164928814, 37.90466746976299, 26.6078628647712, 41.88635172382478, 56.19413437381868, 72.31359312611242, 46.93435976582189, 1.6994168873756164, 0.13712293558543728, 0.03364352877402017, 0.11044773107935345, 0.02985880927993886, 0.0374566356561357, 0.02219268425007261, 0.1012169384968377, 0.16235733554968912, 0.1496665221789191, 0.1694308705027065, 0.253022002777265, 0.17479618260216329, 0.1822366123838771, 0.2372045394393706, 25.893265854927805, 83.91612099063012, 67.4847867411952, 61.033048706669966, 34.3517884900493, 46.31145600349673, 46.012826350427446, 62.08070593495523, 77.35660799088018, 71.91092260422246, 67.17855161236179, 3.7442425950880978, 0.35483396942577056, 3.004845664385827, 22.831420552346017, 11.04838619309087, 0.8858943309995436, 12.381406637930102, 67.74799346923828, 57.19945353846396, 62.733305961855, 70.32120950760381, 65.171231608237, 63.216691017150886, 63.66584947032314, 62.138215726421734, 64.50795096735801, 60.908485997107725, 55.006264178983635, 56.48469571144351, 55.028409880976525, 56.89336353732694, 61.24303671621508, 61.528867675412094, 60.186103082472286, 61.343347411001886, 60.782475932951904, 55.26843932367141, 56.92155753412555, 55.041118360334835, 53.89492727095082, 51.2487865263416, 49.52066083108225, 44.654250683323035, 46.65453003298852, 46.937823218684045, 46.12599065226894, 45.75790759055845, 44.61569770689934, 45.945883258696526, 47.14784652956071, 43.173661847268384, 44.47469242157475, 44.19101876597251, 44.55373210291709, 42.49386410559378, 46.271208563158595, 44.46809891731509, 46.2451522581039, 43.804955559392134, 45.8357705608491, 44.494849481890284, 41.98638393032936, 44.910977655841464, 45.98786046428066, 46.16371993095645, 42.998375046637754, 44.24305685104863, 43.55719120271745, 45.967793618479085, 42.9968531670109, 46.925287323613325, 53.96172523498536, 54.33812764383132, 51.29253272087344, 48.59709170556838, 49.52244550951066, 52.8958878209514, 54.04516189329086, 60.0694949396195, 62.79390658101728, 57.06994864248461, 59.239148785991055, 61.13305737895351, 53.646299992838216, 50.60559234311504, 50.80144020818895, 52.52617305324924, 49.945426064152876, 45.58383280231107, 44.69359205615136, 43.788230572977376, 45.86916954286637, 46.53052429999075, 46.284156307097405, 44.7305525502851, 42.51748461877146, 44.803779279032064, 44.87172257515692, 45.703935776987386, 46.683430056418146, 44.43664543090328, 47.899682521820075, 44.402838522388095, 46.89111955704228, 45.89735961729481, 45.11174417311146, 46.154063055592204, 46.75315018623106, 45.40114841153545, 46.11372932311028, 43.77647915194112, 44.6754942401763, 45.03062955794796, 45.11272868802471, 43.73315265101772, 46.31401338884908, 44.348768649562714, 45.9936341931743, 44.79948820606355, 45.217267697857274, 47.45962396744759, 52.62181612753099, 55.38862074575117, 55.72517971838675, 54.72466937957272, 52.933495506163574, 49.463162806726274, 51.047600315463164, 48.47754570745653, 51.525058669428674, 46.35798315848074, 52.40125340800132, 57.54701868180306, 62.22663379484608, 61.37605605586883, 67.26573805655202, 62.564698957627826, 63.36402308556342, 64.04980636412098, 72.55460708372055, 66.03845196385538, 75.65284805913126, 74.89192393518265, 72.97767393050655, 7.122667297240227, 1.357967332005501, 4.926563616721861, 2.267428795176168, 0.28321774135674205, 5.048612577299918, 73.52667239404494, 79.14059608213364, 77.04779978721373, 76.5669564277895, 57.99828737012802, 38.4173918539478, 57.09134517177459, 66.39118286871141, 83.17760928984612, 57.083088582561864, 2.9127427743327234, 0.2982914712159865, 0.13554667903771325, 0.19093983085645785, 0.10329737282928922, 0.22616636158237535, 0.12616372607167692], [0.006817087977974406, 0.0612782201008691, 0.10449433924570199, 0.02036188349818751, 0.05503055091286379, 0.11046116826154533, 0.19297600062864442, 0.03764996943514674, 17.96509277436041, 55.18028013167843, 47.37170404003513, 32.78024381206882, 13.49565786700095, 44.16504090832126, 54.595007588786466, 48.410371195885446, 68.97994718244, 59.33983602831441, 56.75440180686213, 2.0127528545356568, 0.20629161998869913, 1.1138743138121021, 13.370315586366962, 1.5254254494943928, 0.5345551933973066, 5.879753010888254, 63.31116130275112, 56.642261243635616, 68.84786528925743, 57.65135765075684, 58.77155519300892, 57.14815285898025, 56.42547184421171, 51.39640492777671, 52.057904812597464, 49.296054147904925, 49.29299862154069, 46.55257194272934, 47.96482132327172, 49.330574927791474, 51.02108117072813, 52.02646309329618, 54.35071845208445, 51.72145566632671, 51.37614196346652, 49.15392706471105, 49.198657774156146, 50.35402720974338, 47.65091403838127, 47.357065754552046, 44.28313562946935, 39.14548573955413, 39.65373469937233, 38.45767067324731, 39.993866951234885, 36.079235615268836, 39.63512305290469, 39.85583874487108, 40.92170361549624, 40.36413869550152, 38.75099335947345, 41.188695430755615, 41.40491608650454, 42.73808263963269, 41.42402195161389, 39.93197979465608, 39.59375773706744, 40.60903579958024, 39.652138294712195, 39.054541664738814, 40.31972569804038, 42.05942630767822, 42.73933779808783, 40.377784621331, 40.441942830239576, 41.04195956260928, 40.139579080766254, 40.52317511650824, 39.12509333702826, 41.86226444859659, 47.116153778568396, 48.672303153622536, 49.40255042045347, 47.75687294621622, 44.52712666603827, 50.46726995898832, 52.7207814493487, 53.50272163268059, 59.19490052807716, 55.70931373103973, 51.5861770414537, 52.2078295676939, 48.17703331670454, 45.54362850804483, 49.17637871157739, 46.99088896474531, 44.58318518054101, 38.73643744376398, 38.67990824484056, 40.22452192921793, 40.510847107056655, 39.17102429174608, 39.65782180909188, 39.86322849027572, 39.79958411185972, 40.335438712950676, 42.50381123635077, 42.89756228846889, 43.33617741061796, 42.03329155522008, 42.854624102192545, 43.335698881456935, 40.52692490239298, 40.8282688356215, 41.760157308270855, 40.72071352312642, 42.08844792458319, 41.62758904118692, 41.50231638262349, 40.564403149389456, 40.269582117757494, 40.062704547759026, 39.06506930628131, 40.1404929930164, 40.088572579045454, 39.06704225847798, 38.625650098246915, 40.60181863846318, 42.940841720950225, 47.35948585694837, 51.941928171342425, 50.47717786604359, 53.16255407948648, 53.766269606928674, 49.915616050843276, 54.10985746691304, 50.968337059021, 49.97941732406617, 49.93630655350224, 50.84766926303987, 55.76484272556921, 57.797438483084406, 59.874345256436264, 59.13366448494696, 64.05802765200215, 62.52311398906093, 74.48694705963135, 72.43208008427774, 65.79298611610167, 66.56611273365637, 71.61388935581331, 78.226683831984, 63.895410107028106, 5.456007103766165, 0.5156605846939549, 0.31543780598909626, 0.7779250245901846, 0.08190207694086336, 2.284096662075289, 58.4755103818832, 69.18150994085497, 65.45221059553086, 67.45143090524982, 50.82014206917056, 14.78101759187637, 32.14950315413937, 43.668268803627264, 58.310661008281095, 48.117613330964126, 1.9159035288518476, 0.2283682361725838, 0.11407309662430518, 0.03145126475682182, 0.07332112610099778, 0.05872212560667146, 0.059349754629957105, 0.04411127756259615, 0.07504506141788538, 0.0673715953504847, 0.03473266448465086, 0.04670434346001956, 0.03244173600368443, 0.09405329628216644, 0.03629087583131848, 25.652255819689845, 68.23905068059122, 53.59310480856127, 41.496887822305005, 20.601992414843654, 38.97873009404829, 49.86772391103929, 58.30542464410105, 70.86073152480587, 66.18175183573078, 62.03359826918572, 2.399482986619396, 0.2787931239412677, 5.259205122147837, 20.85796040873374, 9.288879575267915, 0.7118666111942261, 7.66869064300291, 65.07936577643117, 56.43509734061457, 70.9127970664732, 58.81530530991093, 61.90643502819923, 57.422797218445815, 56.658386107414, 53.9625410879812, 54.086421305133456, 51.2051187792132, 50.67924661021079, 49.16624330705213, 49.072388833568944, 50.18646747835221, 52.610966851634366, 53.15093209666591, 56.19911578393752, 54.64113858438308, 53.875464470155784, 51.61751677913051, 50.68150981780022, 53.29798175442604, 49.994369399163034, 49.45591818901801, 46.751981319919715, 42.571550569226666, 41.657038196440666, 41.01522468751477, 40.88811635971069, 39.25517089905278, 42.79091696585379, 41.505054197003766, 43.61220244438418, 42.42413613104051, 40.59872388839722, 42.06598843297651, 42.62770322061355, 44.640381182393725, 44.12051023975496, 40.81917678156207, 42.18520102962371, 41.931502126878314, 40.906453440266276, 41.86786167083248, 44.457002532097604, 43.32790513192454, 42.64664826854583, 42.706652687441924, 41.33434087999406, 41.88639486989668, 42.39076852798462, 42.727405948023645, 41.30700980463336, 44.18648842842349, 48.67135001767067, 50.064736720054384, 51.74318951945151, 49.91029339451944, 45.509021436014486, 52.70815141739384, 55.64259813677881, 56.020773456942656, 59.57523707420596, 56.75521765985797, 53.32525399423415, 54.373672162332845, 51.64438893718105, 47.98642573818084, 50.86077782415575, 48.69628844722625, 48.04129577452137, 43.21208930784657, 40.68723609370571, 43.80559098336005, 42.28704144877773, 42.42983141253072, 41.91797387215399, 42.52923211743755, 42.39550282878261, 41.92989003273749, 45.539741439204064, 43.37518538198164, 44.92103461296328, 43.10312194208945, 44.36637224689607, 46.13851870259931, 42.751650118058734, 43.63415202786846, 44.3015903811301, 42.7426012100712, 43.05721844396284, 43.99400203458725, 44.08911558889574, 43.84846248934346, 44.97550456754623, 42.01216959184216, 41.4634653060667, 43.77265876339328, 42.03335039077267, 41.37446672685685, 41.36235052539457, 42.07504518570439, 44.98990751081898, 48.93503135250461, 53.99135089689686, 54.448440382557536, 54.48469485006025, 56.54433927228374, 50.814015326961396, 55.937019086653194, 54.384082132770175, 52.79038390805645, 53.675309842632664, 53.1584708921371, 58.932525342510594, 59.85984033153903, 61.8245045600399, 62.79407132056452, 67.68584743622812, 65.30525899702504, 75.95809475068124, 72.12924172801357, 67.79682697788363, 66.84653082201558, 72.92220377152967, 75.78469461010349, 67.61508787831953, 5.946150893165219, 0.5208167241465661, 1.262005810295382, 0.9043385412904524, 0.06999364618452326, 2.5411646356505733, 64.24344593478789, 73.94552661526588, 73.52245192373954, 70.79349425531203, 54.27675431774509, 27.504051885297223, 43.205895885344475, 53.69833023317399, 65.16468125004923, 57.77466912423411, 2.9060252251163607, 0.15715657913636777, 0.09744521951483143, 0.01999112567113292, 0.06487122992233885, 0.08266760562095912, 0.04111901856958866, 0.14642494370139417, 0.17992071326701872, 0.24286039804499, 0.19782673146936203, 0.164519909829382, 0.203332927138094, 0.3522832030730863, 0.1834594112850966, 35.8399788794979, 80.08013709898918, 61.95181292872276, 49.83800803461383, 22.056046416682584, 51.90514810623662, 63.48630297568537, 64.56302888931768, 76.30592269282188, 72.78937662801435, 67.93243115948093, 3.249472370070796, 0.7131821373778006, 7.56105786369693, 29.461400893426713, 9.170810349525945, 3.7812670728852673, 8.81981901584133, 66.61928438371228, 58.31856066180814, 72.70671659900297, 62.29964479323357, 64.63931114442887, 62.43035385685583, 60.68942162298388, 54.985036311611054, 57.013819525318766, 53.53417119672222, 53.37203610327936, 50.77239505706295, 52.6086957993046, 52.80918775066253, 57.526991059703214, 57.32449085481706, 60.83076423214328, 55.3189084606786, 56.803984488210375, 53.20401353220786, 53.29684426707607, 56.41002162810295, 53.016983155281316, 51.51003599166871, 50.31267758338682, 43.09137444342337, 43.035351230252175, 42.72902196453464, 45.00034493784751, 41.31628621009089, 44.166401970771055, 43.68274627193328, 47.50022442110124, 44.71432570488223, 43.09326502584642, 44.90867130218014, 45.22627345977291, 46.80635321524836, 46.91716801735663, 41.64868354797363, 43.89693906230312, 43.599305691257605, 41.30552714870822, 43.13806241558444, 46.540200787205855, 46.859324824425485, 48.10988233935449, 45.09704312970562, 43.74761050747287, 44.989613333056056, 45.97584232207268, 44.30456746009089, 43.217604160308845, 46.73181249249367, 51.53944592322073, 52.49464111943399, 53.18021259000225, 55.478925474228404, 49.09346765087497, 55.79970082929058, 58.06563446598669, 60.00282641380065, 61.96003029423376, 57.16114767136113, 55.80725923661263, 57.59351053545552, 53.11557977430282, 49.58047697621007, 54.05301840074601, 52.56991532541091, 49.81022588668331, 44.28575577274446, 43.31077221901187, 46.29110282467258, 44.73560848543721, 44.36009253225019, 43.386132717132575, 44.95020920230497, 45.42434530873453, 44.822014377963164, 48.33204146354429, 47.5156589477293, 46.31440562586631, 46.046735240567116, 46.089900924313454, 50.073005076377626, 43.57576362548336, 46.40906810760499, 48.090521520183934, 45.41850097717778, 45.159412737815614, 47.375038054681596, 48.0688347355012, 45.17784003288516, 47.66027673598259, 44.63287376588391, 44.1239187794347, 45.386914130180116, 45.27734664178664, 44.646480468011674, 43.52183495798419, 43.82963119014617, 47.39537162165488, 53.34425395534885, 55.5174784506521, 57.96461774456886, 57.01298013810189, 59.1405874683011, 54.308345087112926, 58.7326805822311, 56.21995925903321, 54.6446491056873, 55.56326427767354, 56.77679069580571, 61.95175409317017, 62.878190471280014, 64.80012439912366, 64.19562047527683, 70.23509779284078, 68.04066504201582, 77.97581688050302, 72.15581970830118, 71.108915575089, 70.27342719416465, 78.45137288493495, 75.93355640288323, 68.19826587553948, 6.79351621097134, 1.2768507556569193, 3.2233577197597874, 5.149116939113987, 0.19306333465201242, 2.769832687993204, 69.61835999642649, 81.67639270905526, 77.28713497038811, 84.29444143849035, 69.38320605985581, 24.880543216582268, 50.963736118808875, 64.1726863768793, 76.10283805478004, 70.23745121494417, 5.311992379926867, 0.4483524367453591, 0.281805963886361, 0.15653707447551912, 0.23030533545440246, 0.2179380256922976, 0.16266364814533343], [0.02702183439396322, 0.04528847124968325, 0.02733797015201661, 0.06467279782819171, 0.022557043327739643, 0.047574910455413406, 0.032001967061190836, 0.16986502785115473, 22.784546267601755, 64.9035337663466, 50.83275641164472, 39.04639882426108, 16.13180637359619, 37.369369845236506, 66.52688118719286, 49.01471822492538, 67.9559967594762, 56.94107132573282, 56.73057340806531, 0.9523077188960968, 0.08677912290178, 2.221663315449992, 11.68489077398854, 4.067220606150166, 0.8351608630149596, 17.360771240726596, 65.50663740404191, 55.46590320525631, 63.18326850091258, 58.026740243358, 59.59085595223212, 53.611249692978404, 50.97274188072451, 47.902820417957926, 48.597801654569565, 43.39432654842254, 46.29175001575101, 43.89608398560555, 47.44584860340242, 43.640545491249334, 45.022882876857636, 47.04918323024627, 47.65563264969857, 45.68005638737833, 47.98863403258785, 47.870821722092174, 49.05946854622134, 48.97733803718321, 48.56949783140614, 46.78925560366723, 42.530883435280096, 40.500154725966915, 39.99747160942324, 39.64183030589935, 39.52711666783979, 39.848178355924546, 39.79679530666721, 40.830241787818174, 39.175362433156664, 38.564853360576016, 38.78058764242357, 40.72470649596184, 42.019555414876635, 40.6029208244816, 39.82793500346523, 41.225828509176935, 40.24791494492562, 39.917957321290054, 42.02414851034842, 40.649106733260616, 41.536095834547474, 43.10340435274186, 42.15133920792611, 40.304471600440245, 41.02525418804538, 39.52622628981067, 39.35350471927274, 41.911231317827784, 41.076284223987216, 39.70285454104024, 44.37362470934468, 47.35285312898698, 49.41201902204945, 48.29488877327212, 44.69284288344845, 49.18463530079011, 52.33685201214206, 51.799487298534764, 40.689275726195305, 44.50976233328543, 53.79239651464648, 53.123561797603486, 49.153699567241055, 48.947280914552756, 49.330786735780784, 49.43431769647906, 46.02542108105075, 39.36591509849795, 39.224125339138894, 42.23832168886739, 42.261196951712336, 39.348456628860966, 40.75619528370519, 38.75459017292146, 40.50228849534066, 42.84110369220857, 45.62353503319525, 43.82554015805645, 41.17441800332839, 40.150506804066325, 43.04595339682795, 41.80939089867377, 40.06356746919694, 40.57703318134431, 41.189032754590436, 38.12054687930692, 41.507066372902166, 40.1018851034103, 40.978448544779134, 40.30235352054719, 43.34601471501012, 39.17134200373004, 41.12997362690587, 38.53723202982257, 39.83700744567379, 38.519624510119044, 41.24088256589828, 39.68436056567777, 40.873956603388635, 49.21911685697494, 54.1428053763605, 51.44085714893957, 53.812027977358916, 56.45908655658845, 55.3247880935669, 56.345173082044056, 54.86604336769351, 55.74076329508136, 58.31518742345995, 54.24254732747232, 56.672663534841234, 58.648683024990945, 61.800550645397564, 59.05898255686606, 57.05123501439249, 60.054193773577296, 46.88141561323597, 55.30436038970948, 64.6582797265822, 61.035739452608176, 70.5218073629564, 84.12416350456976, 54.06589161965155, 5.02339614975837, 0.38833220579451133, 0.5466493315273716, 1.3920929330971934, 0.04938534475983151, 1.6670273028073774, 54.5179408596408, 70.62447147984659, 66.53722055496709, 62.606601638178674, 40.182042660251746, 12.823465601090463, 11.929638828000716, 42.47199296951294, 58.74271400513188, 55.23274575510333, 3.6334650554964623, 0.09256968274712564, 0.07493346538995543, 0.01929136755455646, 0.023957900214760054, 0.0463066557272067, 0.04796901672718026, 0.0645366869866848, 0.05821815083524393, 0.019295969827761574, 0.03253485782132034, 0.01207892266627882, 0.015738382954300655, 0.06313018403166244, 0.11219310153636242, 30.456961201083278, 75.37493244294198, 59.18787164072837, 45.86623168760731, 18.614276416840095, 46.43529699694726, 64.47380281263783, 54.480337096798806, 73.1766636140885, 63.15543143979965, 62.06035275613109, 1.172350601803872, 0.16707617669336258, 4.157553526663011, 12.312200338609758, 5.617461665984123, 0.713743833043883, 18.894467007729318, 67.27412408398044, 55.41421421112553, 66.42486033901092, 60.36267249814926, 62.23929128339214, 55.883588560165904, 54.06214967850716, 48.58853701622256, 50.63852456308181, 46.47638382450227, 48.54963494885353, 46.712938047224476, 50.26935108246342, 45.70705013890421, 47.67532687033377, 49.676720173128196, 49.590027947579664, 47.63909593705208, 51.38368468130789, 49.54307717661704, 51.96200678425451, 51.49067909486833, 49.97911137919272, 47.27333884085379, 44.3161266849887, 43.1050282139932, 41.74879027951149, 42.35455328418363, 41.71983534289945, 40.67889713471936, 41.60855377874067, 43.1725125928079, 41.52724304506856, 40.712484390504905, 40.10228518516787, 41.002104359288374, 43.262479997450306, 43.39134946946175, 41.81176001025785, 42.654289045641505, 42.366136043302475, 42.13241377184468, 44.25858159219065, 43.78447686472247, 42.684809007952296, 43.82603437669816, 44.74175091712706, 43.95073044684626, 41.36309969809748, 42.118038285163145, 43.05725374529439, 43.08592234888385, 42.275658730537664, 41.4081088958248, 45.39681811486521, 49.99675027785763, 51.47448755079701, 50.5301651647014, 47.43337938862462, 51.66366346420781, 54.75607579754245, 55.3340684213946, 42.110303371183335, 47.69800209229993, 54.62026373032601, 54.9633809058897, 50.58565101315899, 50.42943869867633, 52.43170669001918, 50.42623804461572, 47.656119023599935, 41.29449744378367, 43.33331800276234, 43.83084712489959, 45.14002053968368, 42.435718890159364, 42.00616444310835, 40.950705620550345, 40.703784573462706, 43.21507815391787, 45.86708676430487, 47.705909590567316, 44.010475989310976, 42.28249149937784, 44.61637627693915, 44.08975101286366, 42.1062280285743, 41.95810756375713, 43.254917667758086, 42.3937612964261, 42.943371649711366, 43.11831720413701, 42.65445378518874, 41.5473844159034, 44.68415875588694, 42.759439945220954, 42.81347451671478, 41.5473138132403, 41.58655320444415, 41.52612124719928, 44.27554976555609, 42.24441705211517, 41.662031373670025, 49.49279239100795, 57.39533278249926, 54.69472992804743, 55.609179542910674, 58.626537322998054, 59.849367603178955, 59.56300712400868, 58.26179612067438, 57.768165834488414, 60.136995007914884, 57.6952999637973, 59.11774750678771, 62.257718578461684, 63.901505470275886, 62.64539387918288, 58.794865838943, 61.71432125952936, 46.03931803857127, 54.0292606046123, 67.64356428577055, 63.55893742653632, 73.81584521262877, 81.31818617543867, 57.19676671489593, 5.93162194375069, 0.35513988365569427, 1.9913399003205763, 0.6917188665078533, 0.147591496427213, 1.8255958585969865, 58.67936772684897, 77.81459962168049, 72.05742313015845, 69.21030013791977, 40.72748353404384, 12.71162509918213, 18.602887815044774, 50.31930638897804, 64.58513144523867, 64.81180521749681, 5.17351653306715, 0.19468857486161495, 0.19248833969956447, 0.056180981318316156, 0.022529228590428833, 0.025504013117883476, 0.06940799494904858, 0.1530326052658981, 0.1756937312142503, 0.11953573253366256, 0.1438933142250584, 0.10006926983835236, 0.12099030367549389, 0.10425837650414436, 0.3242839764683478, 40.14284641511979, 88.71583123360911, 68.31923961639404, 54.972912265408425, 23.1837337247787, 47.14506949147871, 77.93683636573054, 62.38898069627824, 78.38022893474948, 67.67783795633625, 68.28405595594838, 1.3269168691289042, 0.27928841510607355, 10.29622660529229, 20.790793741903, 11.234082964158828, 3.8546935973628877, 23.728509756826586, 70.68766870806294, 57.34950380940592, 69.18289845989597, 61.74789674820439, 64.87140170989498, 58.60272853605209, 56.18399504692324, 52.348626967399355, 53.40442311379218, 47.71719817192324, 51.222263459236395, 48.63287941102059, 53.686108127717056, 47.60930945796352, 50.19021334186677, 52.37594235327936, 52.94277583399127, 48.99566335062827, 54.216263524947635, 50.60587867613762, 54.479179997597974, 54.915414241052446, 53.774573264583466, 49.845821395997085, 45.782394947544226, 43.91708827787831, 43.83153353967975, 46.376736010274584, 44.60665664365215, 42.79655733416158, 44.72561428623815, 46.50280490998299, 42.46121821864959, 42.62258452753867, 42.01009465802101, 43.533092160378736, 45.41350387757825, 45.70521054729339, 44.924400006571126, 43.921230300780266, 45.173231247932684, 43.94696889385101, 47.54767333307574, 44.178612309117476, 44.488554077763716, 47.964719341647246, 46.84246647742487, 46.067645395955736, 44.15685492177164, 42.786625892885276, 43.55150768833776, 46.337316190042806, 45.28494819518059, 43.785430000674346, 48.003907742038855, 53.62320115489345, 54.164154837208415, 53.22485700730355, 48.59504030596826, 55.29355818225492, 59.59293873079362, 57.60848614477343, 45.43339813909223, 51.67860377219416, 58.56507378239786, 59.33275615015338, 54.04143171925699, 52.530577874952755, 55.30159904110817, 55.01190846966159, 53.0478443637971, 42.965913511091664, 43.524557082883774, 47.35179801141062, 46.753354149480025, 43.71906349735875, 46.09037553110431, 43.10984096219463, 43.54634584919099, 46.88376903533936, 50.2477192109631, 49.497962074895064, 45.99938831021709, 42.602913841124504, 46.04874349409535, 45.659365884719364, 42.325653260754, 44.98734228072628, 46.266913567819905, 42.68767233817808, 45.3887301875699, 44.93529242853965, 45.74053541306527, 44.043267003951534, 47.479867319906916, 44.27267074584962, 44.78574029860958, 43.67563501481087, 43.90422682608328, 44.96014064358127, 47.37677174229776, 44.537960252454205, 44.13625071125646, 52.28134655183362, 59.306162480385076, 56.40384389508156, 58.26476535489483, 60.886108875274665, 61.1474956235578, 63.00096850241385, 61.863842010498054, 61.21284231062859, 61.96244255188973, 60.82469632548671, 61.053711752737726, 64.39785788136145, 66.97247812824865, 62.76919957130187, 59.74454618269398, 62.69076001259589, 49.34907282552412, 57.24340761861494, 67.7535161664409, 64.3923822526009, 74.1712119502406, 80.22532755328764, 59.26161612233808, 6.878097711070892, 1.2730591720150364, 5.353353773393939, 4.442315149691797, 0.4366974815005257, 2.099877889117887, 63.227406932461655, 84.93642360933366, 79.27450579981651, 77.28086702285275, 49.48397882523076, 20.55766570952631, 25.235192160452566, 60.735548696210316, 76.6886361952751, 78.77815338873094, 8.279598816748589, 0.47567238850939664, 0.2459873391255256, 0.18215064199701433, 0.10953635458023318, 0.14123635276431037, 0.17727597856954222], [0.09926680805942706, 0.04178983579960562, 0.04005033357609664, 0.027467948459689657, 0.20402471985547774, 0.09257823228836061, 0.127139997878863, 0.4078727491920994, 22.485304724785593, 65.11987993794104, 49.100304342085316, 39.599778575281945, 18.49290063304286, 18.361889546917332, 40.989517473405414, 55.19072148107714, 63.25255717000654, 64.05385817250898, 54.42456491531865, 1.129041383824041, 0.0579673144966364, 4.947474752703021, 24.337393006970807, 15.088249002733539, 0.2580582188262094, 30.051960791310957, 60.55526087360998, 59.21655593379852, 61.21442694817821, 60.01287944855229, 60.78713570871661, 56.83934073294363, 46.73928068530175, 46.260049420018355, 44.636117566016416, 43.891902739001864, 43.94801616668702, 44.39721384356099, 44.188790859714636, 44.08359681406329, 43.755247362198375, 44.539223255649695, 44.638114052434126, 48.288781642913825, 46.8570694615764, 48.07522819888208, 47.933485507965095, 47.13306311638125, 44.10076895067769, 40.164701861719934, 39.091941464331846, 40.10372469502111, 42.34646535688832, 39.82185532969814, 38.99895383465675, 40.879428309779016, 39.636503727205344, 39.77372392531365, 39.7629334849696, 38.176060184355705, 39.2206540415364, 39.670106672471576, 40.51172571797525, 39.430128220588934, 39.23766536097373, 39.601100414030014, 40.61668049904608, 40.23310015278478, 39.12680349042339, 41.26479333446872, 42.015507528858805, 44.65381922260408, 42.83825605146347, 43.246449270556056, 40.069745202218336, 41.517833279025176, 39.48424516185638, 40.925833871287686, 41.065552619195756, 39.571055058510076, 43.77418064302014, 47.075651384169056, 48.5816454118298, 50.767609765452725, 45.14466070359753, 48.975863225998424, 50.89287457927581, 53.711121082305915, 51.15427309466947, 42.73844742005871, 54.09695286904612, 50.66649498478059, 51.29841627613191, 47.92515439371909, 49.93495725816297, 49.555636605908795, 43.951789486792784, 40.19393136424404, 40.90195055930845, 40.23256671044135, 40.9679405150875, 39.45855363722771, 38.89776845132151, 39.54479086783625, 38.47885931691816, 42.40985870361328, 44.60482489678168, 45.06106322811496, 45.065013054878484, 43.03859110801451, 40.88093057755501, 40.01171373551892, 40.24743249339443, 40.9621314848623, 41.68793078391783, 41.25939223074144, 42.28235029405163, 41.11922241026356, 39.69839480615432, 39.91260328600484, 40.93848743746358, 38.798583476774155, 41.09631969082741, 39.47442746931507, 39.92317015124906, 38.16903521937709, 40.21308037542528, 40.079766858008604, 41.214277129019464, 48.1697847766261, 57.260544453897786, 55.87592817121937, 53.263868901037405, 52.47401729706795, 56.04882624841506, 55.691651298153786, 56.19686042108844, 57.96508450661936, 59.65027593797254, 57.88240094338694, 59.21364553513066, 60.58134855762605, 55.70404991026848, 57.083065048340835, 59.39175251991519, 62.6960865912899, 43.56745996782857, 43.83265141517886, 65.56794797220539, 56.75586092856623, 61.86894501409223, 50.25379888473019, 62.28443384170533, 6.7019092555969, 0.3579101801639603, 0.7034278769166239, 0.7302772361905344, 0.08140422704239046, 0.779146965472929, 53.89229928293536, 70.47757871689336, 70.31698119255805, 62.15395227555306, 55.1567223764235, 31.937393142331032, 14.663829918830627, 31.18876761005771, 52.563259063228486, 55.31600590675108, 7.198507305114501, 0.2336211325300317, 0.07124594713170683, 0.06579493277616079, 0.0606286924542679, 0.02702434524713505, 0.015457924868490909, 0.00869634283346034, 0.027481017919677882, 0.09003186328036171, 0.08086994966311802, 0.220973618448742, 0.056356331183304714, 0.056940251060070536, 0.4354104231442175, 31.162366136427853, 76.77502247595018, 55.15409046603788, 46.09959310100925, 22.024714523746123, 24.001785209102017, 48.96217807646721, 59.30889245002501, 68.73220243761617, 68.05733511524816, 57.98241746041083, 1.1013944350904035, 0.17247919564045247, 7.459892582508826, 19.986094005646247, 5.556064315380589, 0.3211299618405681, 31.71579295589078, 61.16088267295592, 59.57063613399383, 63.73202377750028, 62.09916460898615, 63.573540410687855, 59.385480650009654, 47.545351289933734, 47.17952751344251, 45.79770395832677, 45.34356409503568, 46.328314350497344, 46.85605356770177, 46.42158439082485, 45.61683954731111, 46.09149340660342, 47.70701177658574, 48.42838271971672, 49.701752739567915, 49.21601818453882, 49.833038391605506, 49.70964847072479, 51.10177609228319, 46.369707122925796, 41.66559288578649, 40.52222198055637, 42.43564436512609, 43.91966527508151, 41.343260349765906, 41.10737292997299, 42.654594990514944, 41.66517319217805, 42.86044097715809, 41.57899087475192, 42.73821992258872, 41.63334708059988, 40.95182349604946, 41.59960293000744, 39.97262339438162, 42.28482923200054, 41.679199587914255, 40.959013200575306, 44.18318971510857, 41.63040922534081, 44.25571041722452, 43.31570263831846, 44.742872714996345, 43.724978431578606, 45.72120205048592, 41.61368816129623, 44.259554339993386, 43.72224061719833, 41.45769549954323, 43.348874122865745, 41.87483172262869, 43.45118130407026, 48.617664537122174, 49.80735863408735, 52.968047665011504, 47.56931697168658, 52.125397036152506, 52.8316354751587, 55.21694252567907, 51.18167477269327, 44.153222806992076, 56.949622092708466, 52.55515152408231, 53.43267594614337, 50.52752148720526, 52.64893147253221, 52.93884169670844, 44.93881863932456, 42.17619919007824, 42.867191376224646, 42.93789602095082, 42.39823279842254, 42.903045761969786, 42.57089553340789, 41.17394339653754, 42.49360130679223, 45.1513248105203, 44.903862476348884, 47.011257833050145, 46.71585236826251, 44.529080006384085, 44.327054408288774, 40.689844469870295, 41.2587607291437, 42.527055201991914, 44.43216216179633, 43.474829273839156, 43.6272604234757, 43.24276616496425, 41.49587977317072, 42.208464607115715, 42.302362226670795, 41.89587131623299, 43.08627143982918, 42.13486525320238, 42.0433485123419, 41.19074683035574, 43.368501663208015, 43.16335778082571, 43.19783933701054, 49.9601153404482, 57.943527160152314, 59.78672342915689, 56.215264181936945, 54.5755643998423, 59.44223734640307, 58.84011037888066, 58.5578134752089, 60.70628781472484, 62.925666839845725, 60.83693412042434, 62.590159062416326, 61.65109265235163, 55.89946239225326, 59.08195195659515, 61.113418071500725, 65.88509513485816, 46.297311936655355, 46.30530572706654, 67.34211444854736, 58.805726881950136, 65.83573602860974, 51.581481964357444, 63.91183307093959, 6.87432292007631, 0.26077139581884107, 2.0963095128536224, 1.011374384885834, 0.14038017290013452, 0.8545977393946341, 58.67244866586501, 75.02047569521012, 76.30376538922711, 68.24320054823353, 59.65009158657443, 32.3986638745954, 18.91486921618062, 39.601794673550515, 61.187550867757494, 65.79210750518307, 10.002267514505695, 0.2574345926123281, 0.07607429288327694, 0.05000904375206559, 0.049052709383108926, 0.033184573159462986, 0.06288326240234798, 0.26438987423335353, 0.09563183577190484, 0.2652803135495032, 0.15647636966839915, 0.32064037036991894, 0.2049102715306705, 0.23894588793477706, 0.6385625382104229, 43.8403667173078, 86.53300085375386, 62.49122119718983, 56.94533101973995, 28.05629218778303, 25.539458259459465, 55.82307031077724, 68.2862917069466, 73.27543673976776, 73.17858557547294, 63.595219350630245, 1.5069349062058235, 0.5399676965128991, 12.958029373999565, 37.6186482367977, 27.544381695408976, 0.6499257058866563, 36.09299528983332, 64.39096627696868, 60.27048110961915, 64.26055531347951, 63.48452221962714, 65.98899872072282, 62.60578578518283, 50.55184802701397, 49.77019809907483, 48.06439069009597, 48.47270158029372, 48.573020119820875, 48.98118588232225, 48.748342221783055, 48.96973256141909, 49.61046349617743, 48.40649197178502, 50.868767692196755, 52.11257480805921, 51.58204286329208, 53.22190738493397, 53.51426909046789, 54.47059785166095, 48.55787192621539, 44.05470463537401, 42.98524687367101, 42.34141726647654, 47.836826539808705, 43.757298761798495, 43.23074802275627, 46.6110074135565, 44.86018688448014, 45.160514923834036, 45.008570148098855, 44.63248545123685, 42.86410054852886, 45.357982727789114, 43.857205452457556, 41.846284712514574, 44.66431156281502, 42.58925222581433, 43.9314127737476, 45.29546406961257, 43.62727219058622, 45.79158506085796, 46.14274701764507, 47.87660721809634, 47.1112076697811, 49.052365133839274, 43.35045483804519, 47.332237151361284, 45.742500520521595, 44.70900697092856, 47.393524185303725, 44.44925192863711, 47.38410657451999, 51.10430602104434, 51.27761986947829, 55.82564338561028, 51.432757454533736, 54.392181827176, 55.65889558484478, 57.32014094629596, 55.612670452364036, 47.4695554087239, 61.866054227275235, 56.25163239817466, 56.40230632597401, 52.604369425004535, 54.062071231103715, 55.18264532089234, 47.81658318734939, 45.0397059225267, 46.08364082151844, 44.97850125835788, 45.749772594821074, 44.50760895206083, 43.6437383005696, 45.13724742397186, 43.37782121473744, 47.00256193837812, 48.53976626549998, 47.580060343588556, 49.09447962237943, 46.90638542175294, 46.84298030791744, 43.1736030117158, 43.96481175576487, 44.75455745573967, 46.02757838464553, 46.608214685993815, 46.62858747666883, 45.20172726723456, 45.37413897052888, 46.02389135668355, 45.960717662688225, 43.54374139539657, 46.38534953517299, 45.01879184476791, 45.73149042744791, 42.51781409786594, 45.66271951121669, 45.837166924630445, 46.20571282602126, 52.939398673272905, 61.9287258578885, 61.82956049519201, 57.842027987203295, 59.105368506523874, 60.58114851674726, 62.126432926424094, 60.92692898165796, 63.19190948240219, 64.342124923583, 62.82099054705713, 65.7609050504623, 62.1878101748805, 57.65507213531002, 59.33719627318844, 60.879389855169485, 64.68270824801537, 50.71468522471767, 47.507127792604514, 66.47529417468657, 59.460409687411406, 66.07476526691069, 56.7752766609192, 65.39554019128123, 8.643193706389397, 0.674301581757684, 3.3339825320628385, 2.0777253229771895, 0.4396446523887496, 1.002581105116875, 62.87303255450342, 82.63306663882348, 82.49178286521666, 78.06954583814068, 71.92368599676317, 43.746049404144294, 29.81961331059856, 50.244977474212654, 71.67312499015563, 79.26250334708922, 13.882002503641191, 0.4128169580813377, 0.15066844260981008, 0.19868488784038252, 0.12025178725560827, 0.14301007613539696, 0.17880001856434732], [0.04076716970772513, 0.14330673602319535, 0.029148762602539315, 0.01455245586487675, 0.030714481610864885, 0.025153432131534623, 0.043739878136904976, 0.07858718384898479, 29.820417396483887, 59.200121202776515, 47.58834438939249, 37.155792866983724, 16.231095290953114, 39.85945124779978, 37.15769913888747, 56.14608533920781, 62.93954810788555, 62.09757604906636, 54.96402025222779, 1.6769781107864075, 0.38338566799798324, 5.93687693918905, 20.754017599167366, 0.9532381786454109, 0.2581546233306008, 47.80225084673974, 61.432149871703125, 55.837414418497396, 60.18798974252517, 59.81980077682003, 59.015044166195786, 57.52677532934374, 50.274250122808645, 43.146201333692, 43.86572091810165, 43.88710175791095, 46.694487217933904, 44.044796728318744, 44.57971780530868, 45.48740133162468, 45.4425843300358, 44.68997170848232, 45.3218694656126, 44.707469401821015, 46.6359301536314, 45.2575308276761, 41.365280535913286, 40.59165185497653, 40.046305118068574, 39.28103500796903, 40.22620462602185, 39.48002076918079, 39.4010595352419, 38.98445675449987, 39.27427676416213, 37.69263198298793, 37.8440393940095, 39.66574891921013, 39.495467062919374, 40.56682717415595, 40.60263841382919, 39.21034997509372, 39.98053873738935, 42.19571298168552, 41.418142318725586, 38.53068559400497, 40.20637312243062, 41.71221417765464, 39.09177280241443, 41.8420877764302, 44.210736520828746, 42.70024353458036, 41.53179299446845, 43.62160436568722, 37.947840998249674, 39.07396131946195, 37.03603506088257, 38.21323640884892, 39.322765104232296, 39.20197179240566, 44.399473128780244, 46.01175162100023, 49.552545778213016, 51.9896791058202, 48.7127310229886, 49.83124586843675, 51.44204170473161, 55.271279119676166, 51.75374853995539, 46.86998190418367, 51.42990196904829, 51.96064179943454, 49.64665128338722, 50.71448910620905, 49.241894060565585, 49.23199007588048, 42.608632656835745, 38.730318546295166, 40.49069004674112, 38.02684930063064, 38.383078959680375, 39.242736985606534, 39.32889576881163, 38.789397285830596, 43.319260228064756, 43.95928513619208, 44.075783452680035, 44.677639776660556, 46.24234384106052, 41.27459533752934, 40.87528628687705, 38.75772806905931, 40.09501311086839, 40.77936472431306, 39.63699010110671, 42.494177895207564, 40.64405472047868, 42.27480757621027, 41.63925417007939, 41.3532349371141, 39.56242192176081, 38.832417841880556, 40.415788465930575, 38.094459195290845, 39.90580974086639, 40.967352159561656, 40.20913447103193, 39.110855133302756, 41.04636830668296, 42.71377571167485, 53.54354958380423, 57.51457283573767, 55.583311511624245, 53.66186788005214, 54.53710556030274, 55.686693422255985, 56.883102616956165, 55.92539318146245, 60.50452893780124, 59.493538025886785, 60.15211966729934, 55.69675822411814, 59.61240545395882, 61.908678623937796, 64.78330135345459, 61.813941617165845, 70.60170604336646, 67.4239743140436, 65.89377141767933, 64.26447376128166, 57.780380095205004, 37.22849007575743, 57.503041067431056, 9.908987668252761, 0.3624383420232804, 0.8809330843148694, 0.536570372360368, 0.10277532987416753, 0.7189651206135751, 48.02298222818683, 68.62053255881034, 65.89679164271202, 67.93873833071801, 43.72812417245681, 18.33088124952009, 16.03911880523928, 35.25809918680499, 48.81490484360726, 57.95282709983088, 11.41899428059978, 0.28686796645483664, 0.11197845136085827, 0.06629968512683146, 0.02290414244447264, 0.018622519170504906, 0.14226064296259036, 0.06679488436108635, 0.17906813401608698, 0.04757559227366601, 0.05175757815220183, 0.07672325362481418, 0.10279365469731631, 0.08854072676190446, 0.14216290546521065, 38.61750725776919, 68.77819615025675, 54.81193034879623, 46.47421083142681, 18.690154667823546, 39.160222084291526, 45.2204526624372, 60.38728537098054, 71.10853902755245, 66.34373003436674, 60.956189863143436, 1.5287946428983443, 0.23837800227826644, 4.3819792905161465, 25.3668543600267, 4.5628162449406044, 0.19466055136534477, 52.88556414265787, 60.66056866799632, 60.91906855183264, 60.80271928541122, 63.248128814081994, 60.48604672954929, 60.11391185945081, 52.44688234021587, 45.80045746218774, 46.82154847729591, 45.07321865327897, 47.60412408459572, 47.203034277885195, 47.089948423447154, 47.27722983206473, 48.09150995746736, 47.64796049364152, 45.76739580400529, 49.43239573509463, 47.50029502376434, 46.661715815144206, 43.26928530969928, 43.15905101837651, 43.15625436844365, 42.94011608246834, 41.1688050916118, 40.742047294493645, 40.88963823933756, 40.660108981593964, 41.37088560288952, 41.07073799256356, 39.831900519709436, 41.812497415850245, 41.0966883936236, 42.64019989198254, 42.23374820524647, 43.73153271213655, 41.688307331454375, 44.12530337610553, 42.72210682592085, 41.256885836201334, 40.51605209227532, 43.79307862251036, 40.1934959811549, 45.43917971272623, 45.12346813755651, 46.36549449736073, 43.08485154182681, 43.881080919696444, 40.84798659047773, 40.00295900529431, 38.74000680062079, 41.38089549156928, 40.12206569794686, 42.52151681530861, 46.8941907728872, 50.03927269289571, 49.68842060335221, 54.323230481916866, 51.03637056965982, 52.992205542902795, 54.15698474453342, 55.38840893776187, 52.3390563841789, 50.32518994423651, 53.64736295515492, 54.037199481841064, 52.7672262345591, 52.862626121890166, 51.43582082563832, 51.68280463064871, 46.643088479195875, 41.62895010363671, 42.70728026666949, 40.38243655235537, 40.28909983173494, 40.37452513171781, 39.49642019887125, 41.192362846866736, 43.93063614445348, 46.56971662275253, 47.157660299731845, 47.725399847953554, 47.51813396330803, 44.45390778203165, 41.66286291614656, 41.6021603153598, 42.90146112442017, 43.686276405088364, 41.46722293669178, 43.96459994777557, 43.05470812705256, 44.471919305862926, 42.76887324548537, 42.06156399942214, 41.62779300443588, 42.4403472869627, 42.04132064696282, 40.96941532627229, 42.040626387442316, 42.41541670214745, 42.682730151760964, 41.83126595712478, 43.204856457248816, 44.41899084275769, 56.16799177662019, 58.94987790815292, 57.34862912085749, 54.830071310843195, 54.829749676489065, 57.02996792331819, 59.43606745812201, 58.83951810098464, 62.20160122840636, 59.4534396356152, 61.792796119566894, 56.87274363733108, 60.74118121977776, 61.754392193209746, 66.01524722191596, 61.458574879554014, 72.32813727471137, 70.24988512839042, 68.9700863438268, 64.31655499242967, 62.70494722550916, 39.17424848002773, 59.499174471824404, 10.406058853672398, 0.42071691804355194, 3.3522404297705624, 2.0492099369725874, 0.028407723838163, 0.7358257352344452, 53.1310692141133, 73.55224624756845, 69.6016977679345, 75.14647006988525, 47.400533460801654, 22.065138470742014, 23.71367927520506, 43.26788502354776, 58.587474438451956, 68.53346378572526, 15.03432131582691, 0.2842485279806199, 0.12651240332953392, 0.0825874575023209, 0.07022820698517947, 0.003964572759052258, 0.153870644168027, 0.1323140484671439, 0.29559839637048785, 0.16526195791459855, 0.10337241114147248, 0.1472633503257267, 0.12558570507192804, 0.15287603221593365, 0.3621476576212914, 48.34698177153065, 80.68003223788354, 63.12836708561067, 53.53499489445841, 24.937511720964988, 52.6484803999624, 51.942249805696555, 68.64396479821974, 76.32731529974168, 74.43212016936272, 64.95975309802641, 2.2938658152857134, 0.6189237823409419, 10.58137801385695, 38.3403015905811, 6.582519661995673, 0.415327305635137, 58.06659936904908, 58.733170878502634, 63.20809710410334, 62.60181242419828, 66.26114845275879, 64.10555108900994, 63.077921482824514, 53.762845377768244, 46.524366178820216, 47.497396392206994, 47.84084696923533, 49.26746399171891, 50.24387528819423, 48.7208777858365, 49.46109964001564, 50.621650526600504, 50.1993053959262, 48.38234193863408, 52.00832605361939, 50.96798012333532, 50.261412205234656, 46.25000423000705, 45.93245306322652, 45.234537893725985, 45.12148734061949, 45.00964487752607, 43.120176407598684, 44.412358114796305, 43.567075575551684, 44.53587747389271, 43.716827746360536, 42.6210077347294, 44.995339993507635, 43.713689850222686, 45.95942720290154, 44.370698621196134, 45.48924484560567, 43.33951927000477, 49.033824090034734, 46.179519238010535, 42.170472529626664, 43.45073807624079, 46.686038432582734, 43.97701032700078, 48.11544033788866, 47.388193684239546, 47.65295367087088, 44.440508965523016, 47.67691543025356, 43.69505074716384, 43.00434489404002, 39.98728521408574, 43.47451940659554, 41.99700963112616, 42.825865284089126, 49.95144297999721, 50.97893138085642, 53.324842145366055, 58.08920006598196, 55.44050978076074, 55.42841319114932, 56.65671910009077, 60.65262194602721, 56.64752114203669, 52.08966424388271, 56.08819900020477, 57.60362632812993, 56.37510861119917, 55.04299717564737, 53.01524554529498, 54.49215127575783, 48.12769382230697, 45.14610021345077, 44.63046543059811, 41.8081396625888, 42.532115059514204, 43.80895637696789, 41.91072533207555, 42.158046460920765, 46.41917997790922, 48.35076293637676, 49.34500532765543, 49.440193406997196, 51.70569950534452, 45.76316748895953, 44.370141644631666, 42.98270125542918, 44.76885449501776, 45.02065104822959, 42.6182306966474, 47.575251517757295, 44.93303706569057, 47.25314255683653, 45.814703510653594, 45.83433889573621, 44.12647616478705, 44.87375828527635, 44.58904912394863, 43.87144757855324, 44.0249809142082, 46.13738121524934, 46.32727100003151, 43.6907204504936, 45.395951271057136, 46.34912644663165, 57.77951325139692, 64.50327550211261, 58.54262213553152, 56.92409922999721, 58.86581759299002, 60.117430225495376, 61.61288092213293, 60.664867585705174, 65.03152462743944, 62.465490448859434, 63.20925420330417, 57.92625304191344, 62.459979518767334, 64.19924474531605, 68.15678288859706, 67.52639524398312, 74.35056624873992, 73.28987106200188, 73.7698358105075, 68.29927475221696, 63.97587753111317, 46.79741805599582, 64.12288012043123, 13.261316841648473, 0.8502446439477706, 4.101848270623915, 3.0425389062973762, 0.2762083126412284, 1.1551187716184126, 57.88180866549092, 81.06585225751324, 73.96338908903061, 81.28308880713679, 53.35764884948731, 27.22418881231739, 30.232864426028346, 53.69634943623697, 68.0342794233753, 79.87214949823196, 19.394816314020467, 0.459089128360633, 0.26521921037666263, 0.25478636455391684, 0.1997548522007081, 0.12658715818918523, 0.28199999863582276], [0.03841406553082409, 0.11386507310934606, 0.02535374114109624, 0.014398304610362938, 0.11329307356068205, 0.06275905273674477, 0.08231562652414845, 0.29839189002110117, 25.301511595326087, 63.23143520662862, 49.40117759089316, 50.35245433930428, 26.98037232122114, 25.96758104139759, 34.67460347760108, 59.61543744610202, 63.193517654172844, 63.704578953404585, 52.518744084142874, 1.0339761236982963, 0.09809471651791565, 6.502317978489784, 16.14212809070464, 2.7807358964796993, 1.146289761508665, 58.77476369180987, 52.34599505701373, 57.44449969260924, 59.455228236413774, 60.820075773423724, 61.03647685820057, 60.81966392455563, 50.77467395413307, 47.46670384560862, 44.780511779169885, 44.53569312249461, 42.788394881832986, 44.1251935497407, 45.97792510063418, 47.121809836356874, 45.23018014046454, 47.29429998705464, 44.03184506200975, 43.693277835845954, 42.23121043174498, 39.71511979256907, 38.73676300048828, 39.44292299209103, 38.57839338241085, 39.642995249840524, 38.35985068351992, 38.58444167721657, 39.69591586820541, 39.21178164020662, 37.740998729582756, 38.122198197149466, 39.25854413740097, 40.49995076271796, 38.90218896250571, 38.977165068349535, 37.79393895979851, 39.50036218089443, 38.756931827914336, 38.50651594900316, 39.56033522082914, 39.844663912250155, 39.66781600829094, 39.62219099844656, 40.57879040318151, 40.147800368647424, 42.63456344604493, 45.291306357229914, 39.76230982811221, 39.68763182240148, 39.2524762307444, 41.83256033928164, 37.37747346201251, 39.44883400394071, 38.356246025331565, 41.09055772904427, 41.13935985872823, 47.78156034408077, 48.100609856267134, 51.37809530381234, 50.24092174345448, 51.04563128563666, 50.323620996167584, 53.69708684182937, 52.86980013693533, 48.31241392320203, 50.79082627450266, 52.37387918656873, 51.54427043853268, 51.98834549996161, 48.93800058672505, 48.19221681164157, 43.76825786405995, 38.58040555830925, 39.92375458440473, 39.813249649540076, 39.48957566292056, 38.701704855888124, 38.04013829077444, 40.741615833774695, 40.597496186533284, 42.7433660722548, 44.937469343985285, 45.25358492328275, 44.71233314083469, 42.81009343362624, 39.94675144072502, 39.54988602669009, 40.013090487449404, 41.838279154992875, 38.48993216791461, 40.279831271017756, 39.89252859546293, 41.13705350506691, 39.43059498263944, 39.16038682383876, 40.89548257089431, 39.38268715335477, 38.80840116931547, 38.30926387540756, 39.101535581773334, 37.36982091780632, 41.18738143674789, 40.36156562066848, 39.68620407965876, 40.56084163727299, 45.42308622790922, 53.9003283746781, 56.519094897854714, 55.42743652097641, 58.5154361878672, 57.548309141589755, 56.79653982962332, 55.413441504201586, 54.46897399040961, 55.24123376415622, 57.70713375460718, 59.8179062720268, 62.2552514076233, 59.336576538701216, 60.80588856051045, 58.17129919605871, 57.67206776526667, 59.08961626791186, 67.37015155053908, 60.85558106822353, 67.04745815646264, 39.9286614694903, 47.163543854990316, 9.66780799050485, 0.24011990235697842, 1.7322973810857343, 1.4470237661753933, 0.1728931129459412, 0.2720503857539546, 50.56345432035385, 67.33030026958835, 72.8031127683578, 59.86239771689139, 67.9350434580157, 35.80972563835883, 16.213108281935416, 35.41301319676061, 49.64534905649001, 65.53410183998847, 15.142374769333871, 0.18981846199641306, 0.18139031505392444, 0.12621339155180802, 0.052663224313648484, 0.07843231151421225, 0.06426006412854599, 0.0681313170841144, 0.054541652751786095, 0.030465104669753103, 0.025743059363336335, 0.06386575101303958, 0.05635016034507463, 0.08662401307975093, 0.3133361510211422, 36.10588812058972, 72.24382985022761, 55.62703809430523, 56.166626791800226, 27.4575972941614, 29.414050040706513, 39.80028621612057, 65.86632267121347, 68.82629225330969, 67.34407563363352, 57.33779945681172, 1.0911813186061, 0.20030700241125401, 2.011503702209842, 15.250085015450756, 2.4021430890406332, 1.5955129337887612, 62.222221128402225, 55.44260040406258, 61.0549904454139, 60.982254012938476, 65.68712134515086, 63.92529856774115, 62.01915610221125, 52.14419695638841, 49.975879346170736, 46.79984600313249, 47.73610007378363, 45.24843877361667, 46.771593170781294, 48.98734400349279, 48.944558789653165, 47.200017975222686, 47.78285080386747, 47.80408259361021, 45.91962691276304, 43.63494826901344, 42.85675787156628, 39.597852691527336, 41.32234627200712, 41.663313988716375, 42.3298619639489, 40.93743231988723, 42.35314515329177, 41.67507717686315, 41.52700378048805, 40.374089748628684, 40.71388467665642, 41.217309121162664, 43.4040657935604, 41.203773021698, 43.052429229982444, 39.61567594159035, 42.04486646959859, 40.87489012748965, 40.84588812243554, 41.34864184164232, 40.1280669243105, 41.079586859672304, 42.89299664958831, 41.412686301815896, 42.29320349231843, 45.00089014730146, 44.97031919417843, 41.17741469414004, 41.55178923760691, 40.5070424079895, 42.58161537108883, 40.10448955720471, 41.36535506094656, 40.65416266841274, 42.10642414708292, 42.708860981848936, 49.724537787898896, 48.93235237367692, 52.89083188579929, 50.494961892404866, 53.43018524108395, 53.02353743583926, 55.472151540940814, 55.29772373937792, 48.890018232407115, 52.57059781782089, 53.57178672667473, 52.73129732378068, 56.240885103902514, 50.25916076475575, 50.29362663145989, 45.26723869385258, 40.80398544188469, 41.497460488350164, 42.67797623911212, 41.223031859244074, 40.81663116332024, 41.61626123612927, 42.39119606633341, 42.01890430142803, 45.475218449869466, 45.971359052965724, 47.29818705589541, 46.05029283031341, 44.40814941160141, 42.48942006018854, 40.55007865352016, 41.639301238521455, 43.10450261639011, 41.06637239456177, 42.38089199989073, 41.84604544793406, 41.53804525252312, 41.60802033639724, 41.28021609398627, 42.234030615898874, 41.142305558727635, 41.459927328171275, 41.07195784968715, 42.5640509974572, 39.36720163591447, 42.977072654231904, 41.664882936785304, 41.14541207590411, 42.43047860360915, 47.962228636587824, 57.2320641240766, 57.12115518508419, 58.51362405284759, 60.20894304398568, 59.97711135495094, 58.246745986323205, 57.714452897348714, 57.73804987630537, 55.16694015072238, 57.480048133480935, 60.61152335136168, 62.896213762221805, 61.37889192950342, 62.83599753533641, 60.62985650954708, 61.735356930763494, 61.337071618726185, 69.86661464937272, 63.63906752678656, 70.11796013001474, 43.8834814102419, 50.29604281148603, 10.790472703595317, 0.3278755498749595, 3.8224193549925283, 3.5717647017971164, 0.19221864610670075, 0.4441462156753387, 53.709073605075965, 73.68896438229469, 75.84378119437926, 69.64442022385137, 53.37467193603516, 26.357674483330022, 25.736471068474557, 44.69173285268968, 58.915282603233095, 75.81568917920514, 19.72944744171635, 0.3004975286462615, 0.21808391947659755, 0.1112110227827103, 0.07973312114876124, 0.06927645765244961, 0.09704251773655416, 0.1970013943050177, 0.17777061089873317, 0.1437677983795443, 0.2113633059085377, 0.16005681947835032, 0.3026539435790431, 0.19207298214877808, 0.48582645493649673, 46.51912196989983, 82.52710773098855, 63.85899482234832, 67.15348766696069, 39.602418330407914, 35.769615480976725, 45.89957575644217, 72.24386122918898, 74.54858318451913, 72.58206367492676, 62.737153806994044, 1.1531465548661448, 0.3555174117847797, 15.132664941972303, 33.721985278591035, 7.981655088163192, 1.5996371834508836, 65.34235285174462, 53.646798133850105, 62.480713167498195, 61.57516733292611, 67.69665748842301, 65.34039951139881, 65.88496961901265, 54.84887515344928, 52.041607364531494, 49.08538756832, 51.311579750430205, 48.84381271177723, 49.394933177578835, 51.29528230236423, 51.71657623783235, 48.5756088841346, 51.038955411603375, 49.008093341704345, 49.07527569801577, 47.09049755527128, 45.60919092547509, 42.43163962518015, 43.678533646368216, 43.745817984304125, 44.073657528046645, 42.49972804900139, 44.685217795833466, 43.807022648472945, 44.02172926933535, 42.17921549274076, 43.76226840480682, 44.39484080960674, 45.778048961393296, 44.60570350770028, 44.93515906795379, 40.54914905178932, 44.46731052091045, 42.531456101325254, 42.883473134809925, 44.31607177180629, 42.09664175587316, 43.349246748032115, 45.62957156089045, 44.883077836805775, 43.82056659267795, 47.43220267757293, 49.246942150977354, 41.58772599312567, 43.563349323887984, 42.7923603980772, 46.074921392625384, 42.433436070719075, 45.15904795738959, 41.281079015424176, 45.72179432838194, 44.79426360899403, 53.654054518668886, 52.205840926016535, 55.928962538319254, 52.453209123303814, 56.44908451264905, 55.78811414780156, 60.852305889129646, 57.268530399568625, 50.428536553536695, 56.361384237966234, 56.58242156428676, 55.82884796204106, 59.17746951503139, 53.814114678290586, 54.483906453655614, 47.9323087969134, 43.13202196551908, 45.283885232863895, 44.7515921438894, 43.25179153873075, 44.12313822777041, 43.63761548073062, 45.95663839770902, 44.60515045350598, 47.03166984742688, 47.86434588893768, 49.050474551416215, 46.82376461644327, 48.07642452178463, 44.92911861788842, 44.268163942521625, 43.11473215779951, 47.71647645581154, 41.96233587880289, 45.169787406921394, 43.95082066136022, 44.86869450538389, 43.36496760768276, 42.93748417208272, 44.799978502335094, 44.13617226385301, 45.04910392145957, 43.480642226434526, 44.74304137691375, 41.45352209767988, 45.369479194764175, 44.74554384908369, 44.687339798096694, 43.22434279226488, 49.458346136154674, 60.05472329355056, 60.74489570433094, 59.80035366550569, 62.41325232290453, 62.92649838232226, 62.408655305062574, 58.76931159727035, 58.12238724000993, 57.018781323586744, 60.167456134673095, 63.140165575089, 66.77330801563879, 63.296868185843195, 65.04141292264386, 63.642338783510276, 64.49452861662834, 65.31208392112487, 73.18793650596373, 67.25907787199944, 73.62569655141523, 50.75127309368503, 55.45848992563064, 12.962798976129102, 0.40868127838738505, 7.12799632741559, 3.767833200193221, 0.2838956065956624, 0.5669700282235299, 59.618383146101436, 79.8559344199396, 82.75416589552357, 74.43856070118566, 82.81646097860029, 50.726872028843054, 28.517715892484112, 56.414140116783884, 69.18802892008136, 87.30050671485164, 25.23968327429987, 0.3860915824770928, 0.37343090700526393, 0.1771937007264745, 0.14201935590995898, 0.24735811557019913, 0.1968861900029644], [0.017726862795590874, 0.03443207839624055, 0.0166582390891328, 0.06358170859335412, 0.016894906631580765, 0.022421102940795884, 0.02961346579174842, 0.05810094704370826, 30.625891800849672, 57.903981824075025, 52.907235237859915, 39.26803627321797, 21.503792385901175, 37.92643270184917, 44.34399904743318, 54.88659658739644, 66.953046706415, 59.23090004151868, 55.28606645522579, 0.5835975069672831, 0.27407947687372086, 3.1125880249084967, 7.0347257967918155, 1.8635123078861546, 3.549794771017567, 49.77004512663811, 37.80425087098153, 55.43263366145473, 52.09253149647867, 67.43006967729139, 54.46187450039772, 61.35808767810945, 45.95159815203759, 48.999036588976466, 44.32123753332323, 46.71351463563981, 44.828113663581114, 45.94988407627229, 43.1638833784288, 44.76475954055787, 44.71130547984954, 44.05443006946195, 40.45653012491042, 41.050757438905784, 38.475642973376864, 40.66145435456307, 39.756755751948205, 39.9091947463251, 37.43912527638097, 36.99324984704295, 39.068568060475016, 39.35438333019134, 37.355433664014264, 38.78994249528454, 38.396163986575225, 39.78296502943962, 37.44667583896268, 40.02245710742089, 38.78343528316867, 40.03806814070671, 39.56752100298482, 41.78345226472424, 38.5048528640501, 39.64115958059988, 38.533670517706106, 38.512046490946126, 37.259323827682, 39.499279606726866, 38.937266718956735, 43.396350491431456, 45.825293910118845, 44.108178307933194, 39.118331170851185, 41.52465035838466, 40.22112907901887, 38.84582058075936, 38.91016314106603, 36.565130987475, 38.320983917482444, 38.27361737528155, 39.60039046502883, 44.795452087156235, 45.905879005309075, 48.471199312517726, 48.952921282860544, 54.25155308938796, 50.16415703681208, 53.136254587481105, 52.778036286753995, 49.49240015399072, 51.661690512011134, 52.648456865741366, 52.42441892623902, 50.028921558010964, 48.543461138202304, 43.98650246281778, 42.134045477836366, 38.86368697689426, 39.373383291306034, 41.39319212205949, 38.86534221710698, 37.926342487335205, 38.72054792219593, 40.03437326800439, 40.45038769322057, 44.72562605334867, 43.32272760329708, 44.14239314294631, 43.83901349959835, 44.29117256595243, 39.78388286405995, 40.002641293310354, 38.53783215245893, 40.14128531179121, 39.48395490646362, 40.27384965650497, 40.40550401133876, 40.61515077467888, 39.31777977174328, 40.00693236627887, 40.74623246346751, 39.740830929048606, 39.73463750654651, 39.05822084796044, 40.28271421309441, 38.96794357607442, 39.48546894135014, 40.355297673133116, 40.771676878775324, 41.82731220799108, 41.30165969171832, 46.0635700533467, 51.328100773596, 52.71993421739148, 53.24939535510156, 55.0246169490199, 58.841596957175966, 57.33153935401671, 59.401523144014426, 57.939510653095866, 59.745487551535334, 57.80024690012778, 59.41768723149454, 58.1571315949963, 55.92749557187481, 54.10433084734025, 60.4993357196931, 56.43913738189205, 59.628389112411014, 62.02797359035861, 66.59167874243953, 53.60241259298017, 57.90296985257057, 9.060401512730508, 0.08639647730536039, 4.432336149677154, 1.9380042461618303, 0.11075940629046772, 0.29905795750598757, 48.96906968085997, 65.30212110088718, 70.52621610703008, 65.5492853349255, 79.24518216040828, 81.7022881969329, 12.712772392457532, 30.369380558690718, 49.769037077503825, 60.18214148859824, 13.105179052199087, 0.22533046772643445, 0.03137415034636375, 0.08981944242071721, 0.07650229088481396, 0.03335195954047865, 0.05542026367038489, 0.0026756456270137985, 0.03286701439309024, 0.030724316264592835, 0.04839596901870063, 0.0480920159738631, 0.029205740391907674, 0.03853270573721778, 0.15562045027411756, 37.95503070277553, 68.22302387606713, 61.192755852976155, 49.9067005034416, 24.58607912063599, 35.11389324741979, 48.43252474261869, 61.0808623990705, 72.09729010058989, 64.84025416835662, 59.06972985113821, 0.9062443228979266, 0.04799141713808622, 0.6396001276950682, 8.423180118683847, 1.381685781863428, 4.497404348465705, 52.52480806842927, 40.749440962268466, 55.64892491986675, 52.977175020402484, 67.6121304112096, 56.93857277593305, 63.18995614205638, 48.56983515524095, 49.91026201555806, 48.04169585627895, 48.472933000133885, 46.38687533717002, 49.216633996655865, 46.30824750469577, 47.13049396391838, 46.364933598426084, 47.61385940736341, 43.35817014017413, 43.78064470906412, 40.572534222756666, 42.3275242313262, 41.415894800616854, 41.26322046402962, 39.711079751291585, 40.38809261014385, 41.372893856417754, 43.00374869377383, 41.76428364169213, 40.882758402055316, 41.01246726128363, 41.7868019688514, 41.14418829641035, 42.30737893812118, 40.89958144772438, 40.95598120843211, 41.76855902517996, 40.984669423872425, 39.37627015575286, 41.32084792660129, 41.453278910729196, 38.51972649174352, 39.051921521463704, 41.10470964062599, 40.6764260415108, 45.58617837967412, 48.142967531757975, 46.5909170335339, 40.409697025052964, 43.55877584026706, 41.27759595071116, 41.081689250084665, 39.43983608676542, 37.67023524930401, 40.744028091430664, 39.917886718626946, 40.31650935449908, 47.07956198723086, 48.514953351789906, 50.65718720036168, 50.38206431173509, 53.90556081648796, 51.39593032098586, 55.54539395916847, 54.55796472487911, 50.91274138419859, 52.57752080117503, 53.935919961621686, 54.67064265281924, 50.933890804167724, 50.365139284441554, 46.89704625837265, 44.33959422572967, 41.43020360700546, 41.67030757473361, 42.95036915809878, 40.96462218992172, 39.6425598667514, 40.63995584364861, 42.89961368806901, 42.030412535513605, 45.88595728720389, 45.834723288013095, 46.22698383946573, 46.259406151310095, 45.33114587107013, 41.664380873403246, 40.984151671009684, 41.33634913352228, 43.16233404221074, 43.336106807954856, 42.46138295819683, 41.92821125830374, 43.50434118701566, 41.587545564097745, 42.08380383829917, 41.71076682306106, 42.83289024906774, 41.48741529833886, 39.412991385306086, 41.51387560752131, 42.74476243603615, 42.09424911006805, 42.67225350103071, 43.42037893110707, 45.00009390615648, 42.55063256909771, 48.02290378078338, 52.65589760195825, 54.63671807319888, 55.98448761047856, 55.92646006614932, 61.75858912929412, 58.39735323382963, 61.780013115175315, 60.99311897831579, 61.96238763870732, 59.72531087936894, 60.523073903975956, 60.10588669007825, 58.67114251659763, 57.13344397083406, 62.56347517813406, 57.52195081403179, 63.904608065082186, 63.991559167062086, 69.19282205643194, 57.09532245512932, 60.33255261759604, 9.942730838252652, 0.29502854952889107, 3.273703547254686, 7.300033934654729, 0.06992431522737588, 0.03110768198366127, 54.70207652738018, 71.17654508160007, 74.36991137842979, 68.75688199074038, 77.29501108969413, 66.87376776049214, 14.61847359134305, 39.11384397937406, 57.7589443422133, 70.12849561629757, 18.60418611957181, 0.27666343015528494, 0.03537199933141951, 0.024293580790981654, 0.06500647508449132, 0.07638242876818103, 0.04175680974918989, 0.10154285528246434, 0.17751677532590207, 0.1329816021626034, 0.10559054977831342, 0.14043880926985897, 0.1293282820692947, 0.15826345361288519, 0.351194316341031, 47.96184424431094, 78.81610624251827, 70.2220755238687, 56.791519195802756, 31.693415834057717, 49.31042963458646, 62.336640588698856, 66.37765069161692, 77.78422478706607, 71.10682887415733, 63.59576848245437, 1.0530488938093185, 0.3895805920324018, 5.102943778038025, 25.493519460001302, 5.377211589967051, 4.342473668436851, 60.50178327868062, 43.75905598363569, 60.89636587327527, 55.764230835822325, 73.03464243488928, 59.458852506453, 65.12708925431775, 48.92811621389082, 53.50197638234785, 49.340984898228804, 52.07247249541744, 49.14057923901466, 52.34157846819971, 48.18859646397252, 50.23646593093873, 50.28460518006356, 50.27776456648304, 44.64349162194037, 46.108900885428156, 42.99848487300258, 46.24907855064639, 44.20461370098976, 44.92117189591931, 40.78108272244854, 41.226452166034335, 44.02738532712383, 47.10100558496291, 42.763166196884654, 43.23441936123756, 42.5788854014489, 46.33698278857816, 41.57821816782798, 45.390769820059504, 42.343456898966146, 44.99899172013806, 44.77162368835942, 44.337480068206794, 41.559747726686545, 43.47604520859257, 44.31678956554782, 41.68877801587505, 40.74474980754238, 43.73547469415973, 43.05646927125993, 48.509818969234345, 50.544615176416215, 49.05734262158794, 41.39152903710642, 47.49642364440426, 44.12772347850185, 42.89242790591332, 43.112543475243356, 39.57383994133242, 43.794008224241196, 42.363696329055294, 40.638888958961736, 49.78749575153474, 49.23842276296308, 53.1841584943956, 52.25624730510097, 56.5639550455155, 54.17005800431775, 57.40093000473515, 59.46760331430743, 50.14914220379245, 54.53611712301932, 57.06199799814532, 58.83622723241007, 54.29527182732859, 53.423254412989465, 48.8652680766198, 47.47539974028065, 42.50814153302101, 43.85454216311055, 45.75128270733742, 43.05682228457543, 42.608652268686605, 43.53082110804897, 43.69317977659164, 43.73933430640928, 49.1836743200979, 47.62181397407286, 48.28423169351394, 49.87437232848137, 49.23771673633207, 43.526996797130955, 43.33228641940702, 43.01827715289208, 44.39315026806247, 44.43470385766799, 46.37082107605473, 44.393475824786776, 45.45517121591876, 43.54022695172218, 45.23203542155605, 45.55097902974775, 45.0170934584833, 44.41679039309102, 42.85058798328523, 44.505098635150546, 44.993555315079234, 45.3776220352419, 45.22468489985312, 47.11349048922139, 48.990858447167184, 44.60184781782089, 51.11205270213466, 56.37038999988187, 58.635362655885764, 56.44427176444762, 58.845962555177756, 64.34547855008033, 59.25078645829232, 65.45824712322604, 61.93215400941911, 63.21279610356977, 63.832495289464156, 63.58424063651793, 62.82631712575113, 60.84935234438989, 60.22772335237073, 66.4588672884049, 60.44747021890456, 66.29391593317833, 68.39122295379639, 71.12135733327558, 63.18229967548002, 65.15268664206228, 12.372133174250203, 0.37568752623854146, 9.161104444534548, 7.722543804876267, 0.2230163612553189, 0.6491106496222558, 59.20590277641051, 78.49849624018516, 82.0235538482666, 76.92670053051364, 93.12635606335056, 88.59521050607005, 21.40891221261794, 50.07850031698904, 67.7503155123803, 85.08189647428452, 25.671785300777806, 0.4253718827760989, 0.11711771389649761, 0.2713544408400213, 0.23851966725722437, 0.24972070008516314, 0.27758497264116044], [0.08649053758070355, 0.056685657060194405, 0.08315384928737918, 0.06464433000092545, 0.014590602255456392, 0.07084074024591716, 0.15450706405024375, 0.1289942983778254, 26.189434220713956, 58.86679426316292, 45.963604527135054, 37.10470791785948, 21.194331107601045, 27.21798754507496, 35.75420056619952, 59.777772580423665, 65.85178636735486, 62.289007325326246, 55.91427326202393, 1.2322196989290177, 0.04114391259668816, 1.46097281767476, 7.994332188560118, 0.5916444332368913, 9.326793205353523, 48.96298608472271, 40.12490157158145, 58.10719590033255, 53.395480109799294, 63.46237651763424, 58.140559581018266, 60.51169903047624, 45.97912142353673, 47.20859227641937, 42.042481668533824, 44.783610451606016, 42.343704008287006, 43.97703386122181, 42.83324326238325, 43.003113269805915, 40.4880855929467, 41.70183166380852, 37.80700437484249, 40.88171897395965, 38.75052659742294, 40.41094433876776, 39.4364236247155, 41.13389991944836, 40.33161832440285, 39.64811786528557, 38.27663760031424, 41.28321670716809, 38.481773637956195, 41.30721376788232, 38.49963218935075, 37.39747362752115, 37.31067942034814, 40.44035427031979, 37.563252602854085, 38.813045255599484, 37.795001922115205, 39.20892615472117, 39.40664106799711, 37.114000012797696, 36.59849074579055, 37.18554012237057, 37.749337688569106, 40.183403722701534, 37.982067600373306, 44.237122304977916, 48.45612956631569, 47.04324476180538, 44.44760061079457, 43.86529730212304, 39.20236010705271, 38.956894259299006, 40.113032479440015, 39.17278935832363, 35.97290408226752, 39.05392193025158, 37.126963446217204, 42.166812958255896, 43.9074117906632, 47.7522563165234, 45.743069264196585, 51.54241515744118, 50.25946670962919, 49.67923049003848, 48.02162116573703, 48.44912421318793, 47.255433221017164, 50.95267503492294, 47.96755521528183, 48.94092275250343, 44.94097594291934, 42.36532803504698, 39.242682072424124, 39.39931015814505, 39.231660212239916, 39.664850696440666, 37.57727899859029, 39.50373149687244, 38.275755067025464, 40.1020537653277, 40.873740873029156, 42.52005769360451, 42.05857123098066, 42.154269218444824, 40.7374777332429, 42.96849050829488, 40.03409477972215, 39.80123935207244, 39.75130757977886, 41.42032707891157, 40.57141634725755, 40.34166743678432, 40.810990795012444, 39.679920442642704, 40.6791756230016, 40.36388766381049, 40.368084599894864, 38.75799479023103, 38.85166098994594, 38.59567926776025, 39.735629866200114, 39.81511277537192, 39.514129700199256, 40.571890954048406, 41.500257138283025, 41.960813999176025, 41.73189663117932, 40.85137944067679, 44.40077535567745, 46.948162586458274, 50.29896889963458, 52.38803894289079, 54.095536893413914, 55.1065238829582, 57.85266937748079, 56.98483713211552, 58.52002143859864, 57.22343883206768, 55.37325682178621, 49.52135509060275, 46.91088438034058, 46.12668883415961, 46.09242300833426, 49.258477841654134, 54.519647090665764, 57.366232718190844, 67.96654793523973, 63.13521554393154, 72.5814204062185, 10.15144996104702, 0.27887362446035113, 2.6019554897662136, 5.47507276458125, 0.058648680757370696, 0.3937100817359263, 44.39569980867448, 68.93483208071801, 59.709986179105705, 68.8822566309283, 49.551906431874926, 58.28934684876473, 35.73696174929219, 25.456711938304288, 46.92979412694132, 57.723078189357636, 16.1960587193889, 0.3286013415744228, 0.13949270600513106, 0.052939383688593106, 0.13025439043919887, 0.008355333158115466, 0.009838923710518548, 0.01620586608506499, 0.08412910985850519, 0.05060677236366657, 0.031063526590925553, 0.031201525839165817, 0.04695424900179909, 0.09719316126598466, 0.10537534801950378, 38.53434124300557, 69.03120471585181, 55.570438292718705, 44.06760923324093, 33.17750146312098, 33.88433218002319, 39.544688886211766, 65.55888729710733, 69.38567715306436, 66.09226688261955, 61.1441812207622, 1.2675462807378461, 0.07448376411752355, 1.1420482084635766, 5.985177005490949, 1.0050828418424054, 10.348577499389648, 52.43991621078984, 40.227134227752686, 59.87809504232099, 55.54477422468124, 66.41871006258073, 58.858800472751746, 62.10811938008955, 48.113585056797156, 48.9385889422509, 44.33440885236187, 48.173844429754446, 44.239448270490094, 45.95430066508632, 42.93369908486643, 46.06325234136274, 42.43813114781534, 44.63914171341927, 40.16247395546206, 43.511236713778594, 41.42244515880462, 40.744039858541186, 40.99068633971676, 44.402320769525346, 41.43731878649804, 42.154481026434134, 39.63676652600689, 43.29815003179735, 39.85090048082414, 43.35902521687169, 40.40257400082004, 40.37301109683129, 40.88526479659542, 40.23968188993393, 41.44919180100964, 41.22820938787153, 40.466563547811205, 40.434207916259766, 40.36611164769819, 40.78066695121027, 39.48971294587658, 38.274452840128255, 40.267746448516846, 41.21143341064453, 38.7697305217866, 45.33174599370649, 50.59978331288984, 49.4262650705153, 44.915413856506355, 44.98536932852961, 41.88199004819317, 40.40994805674399, 42.666554297170336, 40.19790472522859, 37.45865083509876, 40.875258830285844, 39.116958341290875, 44.72691259076519, 47.53065024652789, 49.81167716364707, 48.82084331204815, 53.40911819088844, 53.53322982788087, 52.22014581003497, 52.04104646559685, 51.293379952830655, 49.172652459913685, 51.92324984458185, 52.459661422237275, 50.080673310064505, 46.96907666421706, 44.189736150926166, 40.75568537558279, 42.184624441208385, 39.512815706191525, 41.28347558359946, 41.618351859431115, 39.283113864160356, 41.56132844186599, 42.675360018207186, 43.091150868323545, 42.611982360962905, 45.285689523143155, 43.61798401801817, 43.343186686115885, 44.21665929978894, 40.94620273959252, 42.182400457320675, 40.845464506456935, 43.43131842151765, 41.99875900822301, 40.86595496823711, 42.64331033152919, 41.795564543816354, 41.90715597521874, 40.62627853885774, 42.45811562384329, 42.07568845441265, 39.817281846077215, 41.23144142089352, 43.41391878743326, 41.34814762300061, 41.59509220430928, 42.57423347042453, 43.36565794483308, 43.32535166894236, 44.500803639811856, 43.61748195463612, 44.86297961204283, 48.60484623139905, 52.02223477825042, 53.57397933160105, 54.86343106915874, 58.92126814011605, 60.39138817018079, 57.8949603726787, 60.27379943478493, 58.43507466777679, 57.48213875678278, 50.61882249770626, 49.42097379315285, 47.685521110411614, 49.774850030099195, 51.8391542280874, 57.4541251890121, 62.30843482478973, 70.4680944258167, 64.71851556531846, 72.8897108570222, 12.11062385189918, 0.3218238229953474, 2.6903380117108746, 8.06239756845659, 0.028784554827237324, 0.4048437907570793, 49.22139575404506, 75.06195868215254, 66.73328415040048, 73.83496284484863, 63.39703375293363, 70.08407869646626, 31.8392534794346, 32.21738761471164, 54.397257374178984, 70.43506022422545, 19.521093099348008, 0.3228397781570112, 0.06438474876866226, 0.09273196315212597, 0.041244932780823404, 0.08355498824629091, 0.02417065815309123, 0.11445640871721892, 0.2189371575631442, 0.21388767287135127, 0.16192440394191973, 0.16342798938914654, 0.0861462959719281, 0.22660130034050635, 0.2509326818248918, 47.895069814497425, 79.70638229000954, 61.728920321310724, 52.2527720851283, 33.037829783654985, 36.11277972498248, 47.84071753101964, 70.98831838177097, 75.6806968873547, 70.52665541248938, 66.59278485082811, 1.4263679519776375, 0.2323081344366074, 3.994811936732262, 16.33846134908738, 1.5138734564665826, 12.091567016416981, 59.30901012113018, 45.229583940198346, 63.62486070202243, 58.67965405987155, 68.90553197553082, 61.08288634207941, 64.99753728989633, 49.47984072469896, 52.08991527557374, 44.340704256488436, 49.33404230302381, 47.42678588436496, 48.54246485617853, 45.85284856057937, 46.74215186026789, 44.22098175171883, 47.2742723649548, 40.93550643613262, 45.56099676316785, 44.002917581988925, 43.928431772416644, 43.451157769849225, 46.59392156908589, 44.98164699923608, 44.98627539603941, 40.71614788424584, 45.84843589413551, 43.51594748035554, 46.63645967360466, 42.14116457969912, 41.21313964166949, 42.553456675621774, 44.88419571230489, 42.85588710538803, 43.177172368572606, 42.85751096663937, 43.37764470807968, 44.305587276335686, 42.44027276192942, 42.561281804115545, 42.08821650474302, 42.40830936739522, 44.79529911471952, 43.136505234626036, 45.93918385044221, 52.0651964987478, 51.01587618550947, 46.2700593086981, 46.583931292257006, 44.0227137842486, 43.564557413901056, 45.47217469061575, 43.2151016881389, 38.47964379095262, 43.63085723692372, 41.264710964695105, 47.79114269441175, 50.32449960708619, 52.585169423011045, 49.40029113523422, 56.486841247927764, 54.795840786349395, 53.05572048310311, 53.91955975563296, 49.66466280721849, 52.52158388014763, 56.37581071546001, 55.70983148390248, 53.34221432285925, 49.70609480334867, 45.968009348838564, 43.510362025230165, 45.25278868213777, 42.16960568581858, 44.215698319096724, 43.362833838309015, 42.229374762504335, 45.128300497608805, 45.72478317445325, 45.960611758693574, 44.87297381124189, 46.83095432096913, 46.58185635843585, 45.540023849856475, 47.37015078144689, 42.2783455541057, 44.18492340272473, 44.55670918187788, 47.18696824965939, 44.22402943334272, 44.735224093160326, 44.33920591108261, 42.424900993224114, 44.30618347660188, 43.73123068963328, 45.50834678834485, 44.75253351273076, 43.439853499012614, 43.593351533336026, 46.88556548087828, 45.239762490795506, 44.98039576315111, 45.72837606553109, 47.21198512661842, 46.40721282651348, 47.825267314910896, 46.2503376314717, 48.83752907476118, 51.906952396515884, 55.609697295773415, 58.454674751527854, 59.34983414988364, 61.6227456831163, 62.81198870751166, 62.086781686352154, 62.808270300588305, 61.254725379328576, 60.65084903470932, 53.51433184839065, 50.999037450359715, 49.63638644064627, 53.16528404912641, 55.75618213222873, 59.473553549858835, 64.05326981698313, 73.87115847679877, 68.74787622882475, 76.60426601286858, 13.886697580737453, 0.3579055223493807, 9.30783050675546, 10.668132997328236, 0.08243263113282381, 0.665115206953018, 52.195034796191806, 82.0446954234954, 72.9474167669973, 83.28672962803995, 64.14970913240987, 72.23958584570116, 50.34720620801372, 44.87053409699471, 66.58127661674254, 83.4372466610324, 28.874245612852036, 0.5538528256358639, 0.23286743990836606, 0.15973011362216166, 0.1973398519499648, 0.21912150896124302, 0.08648499876501099], [0.07861002093000759, 0.050508598196170026, 0.027762903801856503, 0.013304990847715208, 0.013911881870890578, 0.029386989133913192, 0.01741762757451544, 0.045701243253725196, 32.230586390341486, 58.68511399915142, 46.949645242383404, 31.153966380703835, 12.99970651826551, 38.404687296959665, 45.31780196774391, 54.96243561467817, 65.96297771699967, 58.40130306059315, 60.29550583131852, 2.4795623412055354, 0.025739707728667606, 0.1161262046004976, 2.4331229492541286, 1.1287470834870492, 14.419531956795725, 48.7816313774355, 40.20963653441399, 61.78724596577307, 59.152519318365286, 61.452479516306234, 55.267093950702304, 51.96692151408042, 40.781694612195416, 43.74479816805932, 40.83547422962804, 43.608770370483406, 41.0913186688577, 42.86021347968809, 40.72463981566891, 39.04373945728425, 41.63629670296946, 41.06406996327062, 40.54196719200381, 40.814446403134255, 39.914407576284106, 40.575491689866595, 38.81277853442777, 41.02636029643398, 39.416380313134965, 39.53355327729256, 39.69079717513054, 40.17608065758982, 39.023962866875436, 39.7835063165234, 40.005990997437515, 39.144360019314675, 37.86363163302022, 39.72070524769445, 38.68197925629155, 37.81831256804928, 37.74337176353701, 38.508233947138635, 39.8530303278277, 37.20757599799864, 36.5626363600454, 38.39277113637617, 37.93600720743979, 40.508603511318086, 38.93383464505596, 44.77088236039685, 51.10900502051077, 48.426829461128484, 45.0549090293146, 42.90159056263585, 40.83928285106536, 37.8656320418081, 38.52300559320758, 38.42466392824727, 37.405185007279925, 38.56184490265385, 39.59017661310012, 41.35763191407727, 42.88600698594124, 49.04645804435977, 47.3995489458884, 49.22923264964935, 47.95465846215525, 48.00876363631218, 47.236248908504365, 43.95889289917485, 43.892777427550286, 48.609886477070475, 44.56075706789571, 43.31459652992987, 42.65728965882332, 41.985395493045935, 38.3101934771384, 37.82627890186925, 41.65704211881084, 39.65740211548344, 38.55783624033774, 39.74202725195116, 39.37812935921454, 40.75810155560894, 41.02516789590159, 40.37718842106481, 41.196857883084206, 42.13994472257553, 43.213277786008774, 39.75682243224114, 38.82516930180211, 39.718442040105025, 40.39408991413732, 38.586053771357385, 40.48582630772745, 40.96446529511483, 39.309660465486594, 42.15002913628855, 37.67447925383045, 39.00986194610596, 39.60163777874362, 38.47105380027525, 37.75942210228213, 38.65138084657731, 37.81608466179141, 38.793515774511526, 40.30509133492747, 38.9331913763477, 39.77828171945388, 41.15906976884411, 41.06874935088619, 40.79041796345865, 39.11644843316848, 41.01141606607745, 43.34169226308023, 44.78077457797143, 46.60231151888448, 51.36272353510703, 51.709135501615464, 52.16176525239022, 53.2529451001075, 48.03153691753265, 46.490265092542096, 45.59731006622315, 47.89930205191336, 49.40736709102508, 55.89295518013739, 55.27697832353654, 58.176519870758064, 56.67556216639858, 67.60022209536645, 63.71880931238975, 78.37902084473642, 11.126311921304273, 0.3819669038057328, 3.114385941336232, 11.192143021091338, 0.285646332007262, 0.08886222322020801, 45.23476931356615, 67.82094170970302, 61.175101264830566, 62.274278825329205, 40.25970166729343, 18.213837723578177, 27.54741760992235, 34.210136013646284, 49.10891002224338, 68.36390756791639, 18.541863579903882, 0.1484942544371851, 0.10676172201431568, 0.0856351467870897, 0.050690800717641274, 0.005650653995783819, 0.011301625918056215, 0.07636318463952312, 0.06610404925360795, 0.048848171568205284, 0.043667877363341476, 0.015371242977468478, 0.04921829545750253, 0.06583453186096684, 0.1747935166161868, 40.972525765818936, 68.46978018360754, 52.45841018615231, 42.47863746458485, 18.18837565760459, 20.490000901683686, 44.63454469557732, 57.917549302501065, 70.5532020138156, 63.78557981983308, 64.31178539030014, 2.5347594051591815, 0.08521831068660944, 1.563340673042882, 3.7643508709246114, 1.1583439404925993, 15.581236020211252, 51.42750932324318, 43.01724949190694, 66.12359877555602, 61.875769938192065, 64.04260881485479, 57.44922614866688, 54.52631904232887, 42.51909279054211, 46.50988086577385, 42.659411661086544, 45.62080506355532, 43.46005370540004, 45.129622336356874, 43.13266523422734, 41.72476183983588, 42.51349164593605, 42.540101005185036, 41.982132081062566, 43.55082519592778, 42.1532533245702, 41.83376450692454, 40.19829696224582, 41.916773626881266, 40.62875355443647, 42.06339574629261, 41.838334068175286, 41.360201066540135, 41.70913511706937, 41.500916096471975, 40.80500525812949, 40.223584482746745, 40.65455098305979, 40.766060044688565, 41.16679683808358, 40.881479709379136, 37.902914170295965, 40.60741978306925, 40.261188245588734, 39.799470363124726, 39.05147044889389, 38.81184893269693, 39.1811087054591, 42.35703222213253, 42.24943376356556, 46.04740204349641, 52.89649578832811, 50.434616227303785, 47.820619306256695, 44.503368869904556, 43.216733394130586, 40.84121265719014, 39.28147039105816, 39.09623253730036, 40.03396926387664, 40.64461954178349, 40.02630495255993, 42.81377261684787, 45.73308290973787, 50.04823138636928, 49.50816415971326, 52.40937271425801, 50.18923667169387, 50.33695705475346, 47.599672194450136, 47.60586169458205, 47.59121164198845, 49.78086302357335, 47.64151211707823, 46.28430927953413, 45.0742776932255, 42.93511113812847, 39.194315325829294, 40.4439510837678, 41.72915881679904, 41.38709283644154, 40.9198522567749, 40.696300691173924, 43.7588990888288, 41.53788051297588, 42.02241482273225, 41.35636106614144, 43.66841785369381, 44.1225028038025, 45.528954921230195, 42.99665312613211, 40.30414212134577, 41.7605338558074, 42.87135693334764, 40.72189023417812, 41.51000030579106, 41.75354026979016, 41.16247438615368, 45.044224492965206, 41.769249362330285, 40.19778313175325, 41.87499646217593, 41.78115375580327, 40.58114774765507, 41.47362032244283, 41.21372799719534, 40.05469114549699, 41.49527965053436, 43.16065134540681, 41.642333230664654, 42.70437771274198, 43.47600206252068, 42.17117463388751, 42.23769803200999, 44.27942506728634, 44.84814520805113, 46.451884700405984, 48.65700983232068, 51.422971140953806, 54.193654983274406, 53.37340108809933, 57.41261082310831, 49.68897757991668, 47.975490170140425, 48.168066778490626, 48.20643932588639, 51.55360960191297, 57.1519418685667, 58.179320443061094, 59.282969505556174, 59.61873615941694, 69.1333746141003, 66.79126462628766, 80.18061253332323, 13.356883429711866, 0.5306376036136381, 2.652453309105289, 4.775225827770849, 0.4215339354930386, 0.21411608964685472, 48.232303434802645, 76.62124987571471, 65.13553411729875, 71.04684798948227, 50.2581331037706, 31.058591988778886, 34.654983781999164, 43.51657113721294, 56.908954958761896, 78.29588228656401, 23.503642236032796, 0.09500825552329903, 0.035125100684742776, 0.032810408156365156, 0.056230382498113386, 0.06495028253524535, 0.014854869072986467, 0.15793330036103725, 0.24720076111055192, 0.1532737697444616, 0.15366329481044125, 0.18516162800933086, 0.17001709630412443, 0.16045601257393438, 0.44286963740183466, 52.10254922989876, 77.18264302899762, 62.15416016117219, 45.33223236760786, 18.666251743993453, 51.016025235576016, 61.00766704928491, 63.284014578788515, 76.42528041716545, 67.27509683178317, 71.63591738670104, 3.0323731034032764, 0.17996358354726147, 2.9958095041013535, 11.51313606769808, 2.0971922912905296, 18.005628508906213, 56.14768958860829, 48.61380884724279, 67.74617348947834, 62.96309801840014, 64.91693258285522, 59.95651498917611, 57.51058770764259, 45.20661454046927, 48.5382757648345, 43.59931353599795, 49.21719097322034, 45.369247774924006, 48.586870008899325, 45.0061696575534, 43.95452730117306, 45.506224786081624, 45.253420183735514, 44.5346889957305, 45.53570139792658, 44.36111627086517, 44.209759850655836, 42.193967526958836, 46.30119116075578, 42.75933796359647, 45.07243810161468, 43.148915613851244, 43.861508292536584, 44.18852413854292, 45.35474285002678, 43.96750642407326, 44.92942064039169, 44.074034075583185, 44.52035273275068, 45.26391252394646, 42.495284003596154, 40.62481549478347, 42.91932752055507, 44.29727185157038, 41.97953939437866, 41.43430248383553, 42.374424011476584, 42.10339607730989, 45.642680122006325, 44.18693557862313, 48.13188291365101, 54.807341175694624, 53.36917277305357, 48.12564634507703, 46.74910622258341, 44.78880759208433, 41.997590141911665, 42.61286489425167, 40.65221717280727, 40.9958952473056, 42.810944587953635, 44.3946054673964, 45.20903464286558, 47.33514362765897, 53.26310011648363, 52.71283472737959, 55.33889685907672, 52.4781200962682, 52.988228259548066, 49.45048962869952, 47.24936139199042, 50.0590963517466, 52.88841962814332, 49.910218869486165, 48.79966251311764, 47.39839576905774, 44.96667923465852, 43.11512047244657, 42.38150781200778, 44.11858435600035, 43.54126637981784, 43.32627734830303, 44.33564832133632, 45.09773738922612, 44.70904619463029, 44.28258257527506, 43.2968831062317, 45.497501434818396, 45.779347265920336, 48.054627910737075, 43.26626900703677, 43.74460204955071, 44.88389761217179, 45.274530380002915, 41.6653222422446, 44.0001013202052, 43.54625563467703, 42.9638817233424, 47.23281291223342, 43.05164083357781, 43.01098546674175, 43.70839072811989, 44.40279145394602, 43.203452248727125, 43.668696341976045, 42.68582097945675, 43.98895002180531, 44.65257190888928, 44.916288545054776, 44.279719245049264, 46.494524786549235, 48.03618492618684, 44.88530182069348, 44.55527359439481, 45.61608645223802, 48.701293391566125, 49.67418239962671, 50.409587583234234, 56.387020849412494, 57.94735147107033, 55.68953714063091, 59.904778926603264, 52.13642281870688, 51.0277884237228, 51.25189304351807, 51.64868001014956, 55.74736856645154, 61.152159321692686, 61.995523821923044, 63.399340106594956, 61.948773091839215, 74.2148208618164, 67.34420114947905, 82.92606769069549, 14.920614746309097, 0.6902855466450415, 6.187231040770008, 22.4878679936932, 1.2228545498463417, 0.2410428084793591, 52.88395597088722, 83.55817333344491, 72.92712242372575, 76.25616350481587, 55.915767685059585, 29.129544842627745, 42.145169319645056, 54.75190631804928, 68.22868777859595, 89.6874023252918, 31.98653259584981, 0.2746283941932263, 0.2863153106262607, 0.15120050599498136, 0.16775247911291738, 0.14224214960009823, 0.0715277525746534], [0.10793460262638908, 0.023176281773034605, 0.04353437888165636, 0.06463861498501032, 0.061532182078207695, 0.0688881200227526, 0.11912170031498517, 0.239302103497809, 46.45390079867455, 54.442717644476126, 50.29093196315151, 17.605478109851962, 49.79143381118775, 94.0296543798139, 51.06709841758975, 57.2266237966476, 62.507134252978915, 59.83004600771012, 65.38365540965911, 5.139133036136627, 0.25548756483101076, 0.49521449472635026, 2.1578850861518615, 0.32542287342010007, 15.022771896854525, 61.76918737349972, 47.318665750565074, 65.92154179849933, 55.918485887589, 60.853247257971, 46.46653867536976, 48.68050090728268, 46.142719561053866, 51.740847864458644, 48.267494939988666, 44.94677712840419, 40.72770318677349, 44.1584748606528, 39.21646495019236, 41.294858301839525, 40.82158903921805, 41.80833970346759, 37.94838228533345, 40.77825861592447, 38.025343110484464, 42.033071902490434, 40.03975475988081, 43.64935513465635, 39.557420899791104, 41.800589100007095, 40.70153705535397, 38.24183440977527, 37.788227988827614, 38.64541884391539, 36.840285255062966, 37.85497888442009, 36.74642685920962, 37.03869050548923, 38.86134532190139, 37.97724308506135, 37.15195286658503, 38.22142631776872, 37.900576437673266, 36.939729106041696, 37.87250403435, 40.23284912109375, 37.05582341840191, 39.68003811374788, 38.77878335214431, 38.807659841352894, 48.16575650245913, 49.91221927827405, 43.67239513704854, 42.74240509156258, 40.103512887031805, 39.02181733039118, 37.20406547669442, 37.70808219909668, 39.30328661395658, 38.530818954590835, 37.059824235977665, 43.13860370266823, 42.29861636315623, 45.37806918544155, 44.12021606199203, 46.98254216101862, 47.26551763473019, 46.663021964411584, 49.72499670520906, 45.5132693629111, 44.97242550696097, 45.10523696099558, 46.020514195965184, 45.51672889340309, 39.547987599526685, 39.690542221069336, 38.72900847465762, 38.63344384777931, 38.183653893009314, 40.46837568283081, 40.52077070359261, 40.40276619695848, 38.895014947460545, 39.09794269069549, 40.376352956218106, 40.377302169799805, 40.74418890860773, 43.73192102678361, 45.2025431202304, 43.619223486992624, 38.15654639274844, 40.568043108909364, 40.200069873563706, 41.86001693048785, 39.4531564558706, 39.1791828217045, 39.55534596596995, 41.63488464970743, 39.43095584069529, 39.26770287175333, 39.91057149825558, 37.9851858846603, 37.8920139035871, 38.83724627956268, 38.10803844082741, 38.361384330257295, 37.66050384890649, 39.03580842479583, 39.727891029850134, 42.953801231999556, 41.02459130748626, 40.375282149161066, 41.76642133343605, 39.899110332612075, 40.10050442910964, 43.88973759066674, 41.880585839671475, 42.41634238150812, 44.82577200858824, 45.56870029818627, 45.04068651506978, 44.79862136225547, 44.18349565998201, 48.438412220247336, 55.451311988215295, 61.09157046964092, 60.20444800776821, 61.698772984166304, 64.01029632937524, 59.98274780088856, 68.2936030049478, 63.245057598237075, 74.74751795491865, 12.883299396884057, 0.48450532098931653, 0.8315129361806378, 5.013763298911433, 0.31097488417740793, 0.0956282658021777, 40.29660724824475, 69.19036665270406, 65.4757526613051, 62.18786116569274, 56.970414576991914, 44.2199658578442, 15.462212677924866, 32.466464004208966, 51.394090729375044, 64.37591614261751, 13.537960629309378, 0.14223789015123922, 0.019720378707373337, 0.01958485583834831, 0.07735217350625223, 0.037464656596702915, 0.10868166858750967, 0.06351102166058076, 0.09985222180764522, 0.014068984479132681, 0.027094698931661346, 0.053395811213000174, 0.01679989257677188, 0.09980804917793121, 0.3658562586192162, 53.80948628148725, 65.02234235886606, 56.15013322522564, 27.705795072740127, 33.77239165767547, 73.07783557522681, 54.278809639715384, 61.711446162193056, 68.03241237517327, 61.939163284917036, 71.35269088129844, 5.1537727925085255, 0.14664694066009215, 0.7333150506019593, 2.8543114710238675, 1.0359767776343132, 15.795789668636939, 61.85764466562579, 51.88811717494842, 70.12140397102603, 55.06315031359273, 63.24160983485561, 49.61948886994393, 49.97988408611667, 48.425809644883685, 53.15110075858332, 49.92370397813859, 46.50482493062174, 44.56959809026411, 45.23931141822569, 41.885916340735655, 44.804779483426, 42.29096381895004, 42.876463859312, 39.67624910416142, 42.56849504286244, 40.39378396926388, 44.32154347819667, 42.055747124456595, 45.484204599934245, 42.41297698790028, 43.62793114877517, 41.798259212124734, 41.78265210120909, 39.45049708889377, 39.97940125003938, 39.233574328884, 40.70564377692438, 38.631459128472116, 40.28333002521146, 41.492059384622884, 39.31068812647174, 38.92709209072975, 41.209640887475786, 39.28610271023166, 38.15862917130993, 37.689902013348, 41.69485768964214, 37.97027303326515, 41.14685550812752, 41.056068328119096, 41.53369926637219, 50.36705340108564, 52.31146251001666, 47.265701986128285, 44.06231403350831, 40.91375297115695, 41.0929621419599, 39.48256638742263, 39.516628249999016, 41.30594291994649, 40.36447601933634, 40.540696344067975, 44.50420825712143, 44.97936025742562, 48.559197687333636, 47.12413580186906, 50.32990071081346, 49.12216763342581, 47.108383563257036, 50.94526175529727, 49.34895515441895, 45.61639631948164, 47.356587225391024, 46.500392652327015, 49.089337395083525, 42.86430451177782, 42.258506205774125, 41.77512899521859, 41.6150100000443, 40.67688103645079, 42.26278158926195, 41.5846194759492, 43.53414727795509, 39.93445481023481, 40.75696014588879, 41.60113657674482, 41.69085294969621, 42.67783111141574, 47.2389788781443, 45.65666729404081, 45.218711130080685, 40.090231741628344, 42.335714140246, 42.36863459310224, 42.225260196193574, 40.5097919894803, 41.513699100863555, 40.82159688395839, 42.614033760563025, 41.23228865285074, 40.7508804721217, 41.910266414765395, 42.39940166473389, 42.38176276606899, 41.44060965507261, 41.08053999562418, 40.22616540232013, 40.33984353465419, 42.74606074056318, 42.72291483417634, 44.555983543396, 42.24850416183472, 43.52232133188556, 43.249340057373054, 41.88029558427873, 41.5954020715529, 45.874696162439164, 43.463830947875984, 44.86600768181586, 46.95315576368763, 47.47558409167875, 46.835347375562115, 46.038196240701986, 47.190961222494806, 49.69964250441521, 55.98262840701688, 62.531503938859515, 63.61992243797549, 63.49900361030333, 68.23424185475996, 61.48730231869606, 70.44323444366455, 66.1620693822061, 77.52160641454881, 14.076996272610081, 0.5388481049768387, 4.0916023042894185, 6.976562930691627, 0.35992683001583625, 0.13088166323159972, 45.50658956650765, 75.57878586553758, 70.35264338216474, 69.63888183716806, 60.870890079006074, 40.38320533690914, 20.281207253856046, 41.8877794665675, 59.84386451782719, 73.25277328491211, 18.752151650767175, 0.22291888422783346, 0.013563787797465922, 0.037156907586200584, 0.029669317431868087, 0.029425561660900715, 0.03955069103188092, 0.17367510485552973, 0.23313688835309399, 0.16052687570693033, 0.1515545611900668, 0.19069623021829515, 0.22441692319848847, 0.29339004067644, 0.5048614722346106, 67.07490690292852, 73.24231624603271, 68.31294813463765, 29.714052523336104, 63.71305911771713, 100.97477559120425, 58.84098898979926, 71.10179255085608, 71.81456565856934, 67.99332987877631, 77.37309763508459, 6.098152543267896, 0.5044237908817107, 2.712984061048877, 7.627359157608402, 1.1327248571380493, 18.044614907233946, 68.1027404723629, 55.69342813184185, 73.1908312151509, 58.544116558567175, 64.95994921653502, 49.53745249778994, 53.304163409817605, 49.306875967210345, 55.55526264252202, 50.92492818832398, 49.260152693717714, 45.80178322330598, 47.4503710962111, 44.49170766338226, 46.49027293728244, 44.15342677024103, 46.2166876177634, 42.05317012725338, 45.324485686517534, 43.11141383263373, 47.4118612658593, 44.40660792012369, 50.80461732802853, 43.918696449648955, 47.14235521131947, 44.73977012019004, 43.96728284897343, 42.154904642412745, 42.551150321960456, 40.68122310023154, 42.876628598859234, 40.3259151981723, 41.9894669132848, 44.988562137849875, 40.22922877342471, 41.26654271156558, 42.9891025635504, 40.14583133882092, 40.350912463280466, 41.3789656854445, 45.418297013928814, 40.945747744652536, 42.99615106275005, 41.95360076042914, 43.05211151799848, 51.65513623145319, 53.93365283166209, 48.44865745113742, 45.60146385623563, 41.76893165034633, 43.792439276172274, 39.711687718668294, 41.57093824878816, 44.80218287437193, 44.69464717372772, 41.52179095052904, 48.67477032446092, 47.078522559135195, 51.035919497090006, 49.85467810784617, 53.58485998645906, 50.85037177608859, 51.761255956465206, 49.09122405513641, 51.29181100476173, 49.92664575576783, 49.749319322647594, 49.43915397890153, 51.24926113313245, 44.23283515437957, 44.443878281501036, 43.980207058691214, 45.50834678834485, 43.638917707627826, 45.55264211470082, 45.46726388316001, 46.71698985561248, 41.92261011369767, 43.93151083300191, 43.633661731596916, 43.02986383438111, 44.71773816693214, 48.991854729190955, 49.96627738398891, 47.53381167688678, 42.773474185697495, 44.69216039103847, 44.737530446821644, 44.59617214818155, 43.46933403322774, 42.5238976940032, 43.07013873131045, 45.58700992215065, 44.48258030799128, 43.904273894525346, 44.56229855937343, 43.47090298129667, 44.93397058979158, 44.6807933622791, 43.331796123135476, 42.90371256489908, 41.38366076254076, 45.0100371145433, 45.63871460576212, 47.52913621164138, 45.22816796456614, 45.954543852037006, 46.606147596913004, 43.51012276064965, 44.38867484369586, 50.23037056769095, 45.25194929492089, 46.39002107804822, 50.344174215870524, 51.06715333077216, 49.8605969644362, 48.69605310501591, 49.07025898656538, 54.77766844534106, 59.18178019985076, 67.7678406623102, 67.16700415457449, 66.91017520043158, 69.40269239487188, 64.37613579534715, 73.19822880529588, 67.89982841860864, 79.29434514814808, 17.38829843459591, 0.6240405755177622, 6.590536986627887, 15.639375352090406, 0.749365940930382, 0.2406070270245114, 48.54024087229083, 84.59229053989534, 77.72231409626623, 75.7236703749626, 71.00439225473713, 58.09895892297068, 28.987031405971898, 52.66680179103729, 70.27172488550987, 82.94345948003954, 25.208267050404704, 0.3870981300790464, 0.10846779216080905, 0.13457344093870732, 0.13873228713149025, 0.11704959335827059, 0.20826098689388847], [0.042806959245353944, 0.014975809458372815, 0.05957293519449811, 0.02891628173059754, 0.08905292548719915, 0.032230766880656445, 0.04415675254178144, 0.27582309298938323, 44.51495555139358, 60.72110652923585, 44.48303530293126, 25.50976199488486, 67.87350147001206, 97.54251341665946, 68.84628849644815, 48.04057013603949, 67.2955088461599, 58.394129045547984, 68.69087634548065, 5.828618051544313, 0.04134889857302751, 0.5511778304653784, 0.6172228832879375, 0.6307510154381876, 14.83760464575983, 70.00799255986368, 51.97016139184275, 66.49180735311201, 53.88875346029959, 54.744547951606016, 47.31687322739632, 56.80907180232387, 53.6781104149357, 57.33853686240412, 56.47488978601272, 54.20895222694644, 43.00188949031215, 41.9906985375189, 40.80631925213722, 39.55494588421237, 38.02665710449219, 39.850049326496745, 38.879521585279896, 42.35432970908381, 41.182274510783536, 43.70270329137003, 42.72067516080795, 45.48372214840305, 42.69281456547399, 41.5196571811553, 40.33307352373677, 39.31336318292926, 38.04460587040071, 39.01924817792831, 38.9856569997726, 37.917070004247854, 38.937729558637066, 39.061425424391224, 36.8034424320344, 37.441666972252634, 36.675447648571385, 38.79692823656144, 38.3516215508984, 37.695232514412176, 37.04397786048151, 38.23640584945679, 37.68502650722381, 38.75576688397316, 38.91114373360911, 38.000471361221805, 48.72654168836532, 53.321402226724935, 45.31919440915508, 41.46115110766503, 39.95068557800786, 40.32198106088946, 41.013247812947924, 38.92718622761388, 35.88623539094002, 36.77651928317162, 36.903345200323294, 38.31113876834993, 41.85629460119432, 43.49758294320876, 44.47842259560862, 45.47931732669954, 45.593952517355646, 53.26544569384668, 48.63891593871578, 42.74631569462438, 42.20613471923336, 43.05080144636093, 41.98392460423131, 41.975648403167725, 39.98192725643035, 40.349916181256695, 39.390990811009566, 38.86688763095487, 37.69686814277403, 37.946232826479026, 39.14522294075259, 39.63099671948341, 38.829405461588216, 39.859996457253736, 40.357866825595984, 39.68708661294753, 40.68143490822085, 44.03327280475248, 44.44547076379099, 40.95984474305184, 38.12003697118452, 40.71881901833319, 40.771445458935155, 39.15031809960642, 38.81320607277655, 37.480137578902706, 38.730855911008774, 40.173205560253514, 38.39817616247362, 39.45404291152954, 38.320054315751605, 38.969269337192664, 38.26847122561547, 41.13836357670446, 37.63615377487675, 37.33100122021091, 39.478549880366174, 38.867115128424864, 41.34610406814083, 40.82031819128221, 41.71989417845204, 41.91016051077074, 42.55524919879052, 41.95269469291934, 41.75521512185374, 41.99009449251237, 42.146471546542266, 44.41867313077373, 42.79467459647886, 44.95783821229012, 42.33558470203031, 44.95735183838875, 45.848365291472405, 55.69798592598208, 60.30891641493767, 62.102522157853656, 62.399575018113666, 63.93250788411787, 64.965024763538, 64.15128200284897, 68.5728757612167, 67.90532758159023, 76.3796240283597, 11.198116790863777, 0.8290928337843189, 1.4295263179848272, 1.839410936640155, 0.20454256464877438, 0.09831301327193938, 39.44527249182425, 70.64311058290544, 64.9720654179973, 71.45497060591175, 54.09623899767476, 43.08497705767232, 20.117232568802375, 37.44012155840474, 53.92647097187658, 68.06259893601941, 15.018033673686368, 0.11138051973595736, 0.04852489012503817, 0.03683551838020644, 0.06004133667316168, 0.021955968827129375, 0.03739378197238811, 0.03634303492764312, 0.009360765144529362, 0.04906414324537881, 0.04325230913837591, 0.09034907730716853, 0.0200849752722969, 0.049938134653794194, 0.3731352277100087, 55.12579840998496, 68.61763784962316, 53.614316986453154, 28.41153144836426, 72.10249116343837, 96.99531924340033, 69.77685513034945, 54.01341422911614, 69.39086252643217, 62.703154702340406, 72.50965672154581, 6.105398141568707, 0.23414726639466904, 0.42212287324570846, 1.7112608518331283, 0.7376208324586192, 15.958555283084994, 70.63711720128214, 53.63421124796714, 69.38181754081481, 57.38150250527167, 57.676849134506725, 47.81650866231611, 58.63844171647103, 56.445726963781546, 59.92530468971499, 58.104638514980195, 55.99336785654868, 44.38129294303156, 46.28448186382171, 42.97893970243393, 42.37771488005116, 39.32789164204752, 41.3234955264676, 41.22717780451621, 42.07865376626292, 41.95248288493003, 45.561381155444735, 44.32771728884789, 47.47013984187957, 44.762916026576875, 44.85231076517413, 41.62180354518276, 42.42750152464836, 39.53920541271087, 41.13591601771694, 39.360612054024976, 39.796669790821696, 39.58710539725519, 41.089479077246885, 39.609564888861875, 40.530494259249785, 39.063382687107215, 42.104827742422785, 40.168820350400864, 38.214891649061634, 38.11776591885475, 40.134228967851215, 38.66778419863793, 41.62672611974901, 41.316415648306574, 40.51722488095684, 49.90439807215045, 55.116604374301055, 46.61354126468782, 42.53634337455996, 41.30512314458048, 43.37560899796025, 40.47985646032518, 40.32606424823884, 38.82265506252166, 38.88439316903391, 39.80397324408255, 40.5832972065095, 44.311827767279844, 46.79363689114971, 48.117295618980165, 47.29637099850563, 46.01476400129257, 54.15068149566651, 52.77775387610159, 45.79105161851453, 43.59692481256301, 44.92283498087237, 45.46590282071022, 44.025628105286636, 43.2983422279358, 40.51591873168945, 39.59653085277927, 40.85757286317887, 39.577173955978886, 39.98425322194254, 40.27766220031246, 40.95742464065552, 41.874062938074914, 41.526038877425655, 41.487705553731615, 40.73001738517515, 41.631813433862504, 45.69519673624347, 47.44487585559968, 42.262106941592315, 40.25402992002426, 42.51885744833177, 41.92983511955508, 42.6152418505761, 41.470572640818936, 39.951976037794545, 39.86102019586871, 41.81812601704752, 41.25863913566836, 40.42302131652832, 40.42143667897871, 41.73748600867487, 40.90715946689729, 43.26750063127087, 41.04010428151777, 40.159685150269546, 42.70942580315375, 41.55405244519634, 43.363245687177105, 41.62457273852441, 44.05629711766397, 43.75623972185197, 44.36962781413909, 43.26481773007301, 43.74975212158696, 43.25239558373728, 44.520631221032914, 45.79123596991263, 44.65580394191127, 45.12146380639846, 45.93780317614156, 45.357716006617395, 48.44930071984568, 57.47049716211135, 63.93073105042981, 65.37801111898115, 64.80166589060138, 65.66603860547467, 67.25658324456984, 67.28850349303215, 70.96097161692958, 70.5601602985013, 79.57109189802601, 13.384651849346778, 0.8262698304268622, 3.1799824343573664, 1.8629941873012053, 0.14112309432558476, 0.11006310897608919, 43.89041616070656, 74.87197476048624, 71.12800967308783, 75.65393063329881, 59.37664355001142, 47.622943616682484, 23.45418114815989, 45.906839986001295, 63.283583118069565, 77.80648816016414, 20.92020450099822, 0.1620267532886036, 0.09616910089408198, 0.022366611106741815, 0.08887615069867143, 0.10300163990787922, 0.07673446915202564, 0.18217221503296208, 0.10895709251804699, 0.10606550896960883, 0.24386115402223604, 0.24370024491462017, 0.12600857028437237, 0.13144639260586233, 0.5848150351835836, 64.04216558702531, 79.10204702808012, 60.691320050147276, 36.3599871050927, 78.70598962230068, 98.63257146650746, 76.83886297287481, 58.862205090061316, 75.5705802671371, 68.80208338460615, 81.18154648811587, 7.6343625495510725, 0.5333712504756066, 2.220750874088657, 5.770631201805608, 1.4871219112988443, 17.97448096736785, 73.36314093682074, 58.01090563497236, 71.82419899971255, 60.785774646266816, 60.41920169707268, 51.3764008398979, 60.33883233224193, 58.38242077058362, 61.61609726567423, 61.75824788308913, 58.53106683300388, 46.44078047044816, 47.52828505731399, 46.288361087922134, 44.30770535622874, 43.19104579187209, 44.65658057120539, 42.35306278351815, 45.359814474659586, 44.92806742268224, 46.98136152759675, 48.30348268631966, 49.59413074677991, 48.06623028170679, 48.15473071990475, 45.84689048028762, 46.70551300048829, 42.327359491778964, 44.73434155987155, 44.67861252446329, 41.57689632907991, 43.43016132231682, 44.592030125279585, 41.50687025439355, 42.044890003819624, 39.02195853571738, 43.64418545076924, 43.6468134387847, 40.182352527495354, 41.164694447671216, 40.58213226256832, 41.39924433923537, 43.777271470715924, 42.76343684042654, 42.301773871144945, 52.99362544090518, 56.87758776449389, 48.33052742865778, 44.35060039643319, 43.25063836190009, 44.21659654186618, 41.74029050334808, 42.14124302710257, 40.523422225829094, 40.36379744929653, 40.84734724413964, 42.655948208224395, 47.704077843696844, 49.28119620969219, 50.09104405680011, 49.217489073353434, 51.96584678465321, 53.60809218498969, 55.26779997733332, 49.701376192031375, 46.49788233541673, 48.66068509317214, 46.60395891435685, 46.5658099420609, 45.265630522081935, 44.51277471357777, 43.17541514673541, 43.60630319964501, 42.005277987449404, 42.21901578287925, 42.86258651364235, 44.30563434477776, 43.37391061167563, 43.75099159056141, 44.7934595231087, 42.15236294654108, 41.94957248626217, 46.866761638272195, 49.451481988353116, 44.307226827067716, 42.66645623791603, 46.4017685767143, 44.98133320962229, 44.72524950581212, 44.11495616359096, 41.53421701923494, 42.411133473919286, 45.087417633302756, 42.96779232640421, 43.68749233984178, 42.57209577868062, 44.52085087376256, 44.34694474743259, 47.411731827643614, 43.339785991176484, 41.75064948297317, 44.93984630030971, 44.32911365262924, 47.660770954624304, 45.93776787481001, 47.13626377044186, 48.53164695924329, 47.96819456161992, 48.383844206410075, 46.76272076945151, 46.55483122794859, 48.195794013238725, 49.65071878125591, 48.73525327251804, 49.06649351119996, 46.9678528847233, 49.055126482440585, 51.52486647329023, 60.0270745062059, 66.0637669409475, 67.15417800411102, 67.60963578378, 69.0810109722999, 70.70070666651573, 69.20248677653652, 72.79591914146178, 71.87530748305782, 80.81647580669772, 17.19920292977364, 1.348019588378168, 9.396093641558002, 4.084086552742989, 0.261264450006908, 0.2847332777755876, 47.77389995513424, 83.96200487690588, 77.1562062540362, 84.67167931218302, 68.09285609952866, 57.355622706874726, 34.10433400061823, 58.946873372600926, 73.19358471901187, 90.81885706993842, 27.557607927630027, 0.31195130920217884, 0.19231976971270578, 0.13117280728634328, 0.20503309074669115, 0.1565250622168664, 0.1778821379787499], [0.08824662560777319, 0.03709879981714391, 0.1066556494803198, 0.025884076997998263, 0.03433525637393037, 0.016518627225811926, 0.040902786422520876, 0.09309233857258674, 37.198119163513184, 64.2804927210654, 48.735967143889404, 41.712308314538774, 46.27945730763097, 78.51446813152683, 51.30124430502615, 53.26314326255552, 68.53256948532598, 56.97293666101272, 68.9018371028285, 7.195849899322757, 0.15143892787877591, 0.8740155555067525, 0.8961892043871265, 0.3636221930144295, 11.146882791672985, 76.74162741630309, 59.01895084688741, 63.47570865384994, 52.85804871589907, 57.202622813563195, 55.91939587746897, 60.40714825353315, 58.9119525109568, 60.63857986081032, 53.65345439603252, 59.87290966895319, 46.48818623635077, 43.475119529231904, 39.387519513407064, 42.168452508987926, 38.57374537375666, 41.04611727499193, 41.87642812728882, 43.92603520424136, 45.41710853576661, 44.01925425375662, 41.15257040146859, 43.14860574660763, 42.07294279529203, 41.778306115058164, 38.307898890587595, 38.91441106796265, 36.20356298262073, 39.33883505482828, 36.96152179471908, 38.88774287316107, 38.44374233676542, 39.948622411297215, 38.708141465340894, 36.8204302172507, 37.112183955407914, 38.07500423923616, 35.64414670390468, 36.127390553874356, 36.415155241566325, 36.080663358011556, 37.79880662118235, 37.88585970478673, 39.668792678463845, 39.81779959893996, 42.88180220511652, 54.69777368730115, 44.52323567482733, 39.212711241937455, 38.99523150536322, 40.409622500019694, 40.44509249348795, 39.12019037431286, 36.726199196230986, 37.206634629157286, 38.98994415037094, 39.224545032747336, 39.26542005231304, 41.23054319812406, 41.645914354631984, 48.10497937663909, 51.864469205179525, 45.522447709114324, 39.77277863410212, 43.57606172561646, 42.69025325775147, 43.589735108037154, 40.225369161175145, 42.68409513658093, 39.8814243655051, 39.00072674597464, 37.73880220228626, 40.08355586759506, 37.665783359158425, 39.08259445621122, 39.693056460349794, 38.460510469252064, 38.98081679497996, 38.54315480878277, 38.056074880784564, 39.59111013720113, 41.65262160762664, 49.25165683992448, 45.21860914845621, 39.276857683735514, 38.9332619790108, 39.483770555065526, 38.667992084257065, 38.72639225375268, 39.16591736578172, 38.866260051727295, 37.520035928295506, 39.516506656523674, 37.9878060279354, 36.417277243829545, 39.23883422728508, 40.052467161609286, 37.24426584859049, 36.93682262974401, 38.63077271369196, 40.35433277007073, 38.195672035217285, 40.7980901195157, 39.39952196613435, 39.61929628925939, 41.39792642285747, 41.08037917844711, 41.857836092672045, 40.33137905982233, 42.724715202085434, 41.73570133024647, 42.3471047032264, 41.88302555391866, 43.95474303153254, 42.18844875212639, 45.06156136912685, 42.51402901064965, 50.18201166583646, 57.788597460716005, 62.4960849362035, 62.17200302308606, 59.77146148681641, 55.06631566632179, 64.58287608238959, 60.555256951239805, 72.18066400097263, 61.35720906719085, 64.97081025954216, 11.954068330026443, 0.81687085090145, 3.0482177628624827, 4.111499507581034, 0.7419347042037595, 0.2203221066344169, 39.05269422838765, 72.51417529198432, 67.75090386790615, 70.9052739604827, 60.2704026622157, 34.705543133520315, 23.733777499968006, 31.84789053855404, 50.91526739058956, 68.04577981272053, 13.529283365895672, 0.13948651601470288, 0.09181114844977857, 0.003229655994800851, 0.059671097870675795, 0.007115604192574299, 0.0608729902324417, 0.06638510393038874, 0.08000236274974962, 0.020814346517586423, 0.02163302637786875, 0.03602996543650666, 0.03429458859646994, 0.05707757998137705, 0.09374846989709525, 47.14376334221133, 71.61221842611991, 56.95346601547734, 35.620141798450106, 49.80839021744267, 93.04252716802782, 59.34660603923183, 58.41396447150939, 73.74869423527872, 62.12290671563918, 73.49738797833844, 8.157361092105988, 0.23853414631899328, 0.32604509003220067, 1.0448322637427239, 0.6392355924171786, 12.289960499732727, 77.97373802431169, 59.76526414194415, 66.85591313146776, 55.55653741282802, 59.96552859583209, 59.028329233969416, 61.95553918038646, 60.391113604268725, 63.39344086185579, 58.023676872253425, 60.662494551750925, 47.73575882757864, 44.631269516483435, 42.64573043392551, 43.35118047652706, 41.80783764008553, 43.83973913808023, 43.16875496218282, 45.01852904596637, 47.52762217675486, 46.91618742481355, 44.34310474703389, 45.78719592863514, 43.61286140257313, 43.10391033849409, 41.915137998519405, 40.94350414891397, 39.20648251810382, 41.06331294582736, 39.15345991811445, 41.56323079139956, 40.09389523536929, 41.35719260861797, 40.345334852895434, 39.615252325611735, 38.35763062200239, 39.557883739471436, 38.072388018331225, 38.639499987325365, 38.575318244195756, 38.734472336307654, 39.562555282346665, 39.63940628113286, 42.527831831286036, 41.05708029962356, 44.95116233825684, 55.18013892635223, 45.71649128390897, 39.82579731172131, 40.58707444898544, 39.80705230466781, 41.87777350025792, 39.92198167308685, 40.11953576918572, 40.50182173329015, 40.00550462353615, 41.66743639976748, 41.620972002706225, 44.60683707268008, 43.99636722380116, 50.321636276860396, 53.9514329356532, 50.42866206938221, 41.540477122029955, 45.29974729784074, 45.264045884532315, 45.31308335642661, 43.73358411173667, 44.09488539541922, 42.59932487241684, 39.57399291376914, 40.10329323430216, 41.77364241692328, 39.3755562843815, 40.50659525778986, 40.68290579703547, 41.460288186227125, 40.46821094328358, 39.12391270360639, 39.255802400650516, 39.80564417377595, 41.57963806583036, 51.723785554209066, 47.79071515606296, 38.98596686701621, 40.98841920975716, 42.38103320521694, 42.38839549403037, 41.34820645855319, 41.35994219010876, 40.25003694718884, 40.36530363944269, 41.608938171017556, 40.79985126372307, 39.07512626340313, 41.527517610980624, 41.57170703334194, 40.01999385895268, 39.713519465538766, 40.702325451758604, 41.1849574119814, 41.20287479892854, 43.56075663720408, 41.312434442581676, 42.7968946579964, 43.992134986385224, 43.11608145313878, 43.488416364116055, 43.00366240163004, 44.57895686549526, 44.204641157580966, 44.57010799838651, 44.398865161403535, 45.949217273342995, 45.037305431981245, 45.654753177396714, 45.580283057305124, 52.7586244767712, 59.02599934608706, 63.26411247253419, 64.46939014619397, 60.297604299360714, 56.27143252280451, 66.26407454090734, 63.4669735354762, 73.40278040978217, 63.86956560996271, 71.71559641438147, 13.855763808373483, 0.8888222577591097, 3.0687317588636955, 4.078646960758394, 0.25772040469511864, 0.10498936994061356, 41.168687420506636, 79.44041421336513, 73.82329771595617, 77.98006088502946, 59.792869783216915, 41.52001019447081, 32.69625998312427, 41.14683981864683, 59.77372861677601, 78.06526260991251, 20.122825868668098, 0.31133249402046204, 0.08729557341505444, 0.05793049248055585, 0.04529363851273253, 0.038188287928219766, 0.04329952696758894, 0.19611578134279098, 0.1591039286746133, 0.29871735481485245, 0.09152462390521843, 0.09806516850667615, 0.12317891728373305, 0.19171842133566258, 0.25552589987074176, 55.21408311782345, 85.17972823112243, 62.717310536292295, 56.01308168903474, 56.63489895482218, 83.92853921459567, 61.0049488467555, 64.74375601737731, 80.25915407365369, 66.89617233891641, 80.69512551830661, 9.322870835181206, 0.3284426081565119, 2.3142829777732974, 8.262366863989062, 0.7388790552654575, 13.293981359850976, 80.8954958761892, 60.68419702591435, 69.57738691760649, 57.94665328917965, 61.98277611886302, 60.5843452484377, 63.6751494100017, 63.04216515633368, 66.50178586283039, 58.783369371967936, 65.15511458919894, 50.46008809920281, 47.47006923921647, 43.77094468762798, 46.761038072647594, 42.915777775549124, 46.456748439419655, 46.272440187392704, 47.818477692142615, 50.93709538059851, 50.4026920564713, 44.85537413627871, 49.11742941025765, 46.969896439583074, 45.75152981665827, 43.82111964687225, 44.211634743598204, 41.11640222610966, 44.44228972158125, 41.09475858749882, 43.21062626377229, 42.02061837719333, 44.467251685357866, 43.05884622758435, 40.70560847559283, 40.13090279794509, 41.26404023939564, 41.296462551240005, 41.93720133073869, 41.39169769902384, 41.02881570016184, 41.99362070329728, 41.134802064587994, 45.13392125406573, 43.7759574767082, 45.14098544274607, 57.13106701450964, 46.3979011197244, 40.378686766470636, 40.889536257713075, 41.83224654966786, 42.068902754014545, 42.60935437294745, 40.987842621341834, 42.815957377033854, 44.23735372481808, 45.2853012084961, 43.41217333270658, 46.91777206236317, 45.73444789455783, 51.21551306016984, 54.316868397497366, 51.38004864415815, 45.99793311088316, 46.76696477397796, 48.66778458318403, 46.53356021450412, 45.944369223810014, 48.89861606782483, 44.570100153646166, 42.6605805273979, 42.645750045776374, 45.23986055004982, 42.55575126217258, 43.66404833332185, 43.91906515244515, 43.56187451270319, 42.729704456944624, 40.3371645558265, 42.07326835201633, 41.18829142662787, 43.10453791772166, 53.72071127737723, 51.543348681542184, 41.525179878357925, 43.09934077724334, 44.229210884340354, 44.13931015999087, 43.011903301362075, 43.38523057199294, 42.71764709103493, 42.20323608767602, 44.441222836894376, 43.46609023309524, 40.92930124652001, 43.55924652468774, 45.052657588835686, 42.35731855515511, 43.12242392570742, 43.48450968342443, 46.562577909038914, 43.9742725126205, 46.137106649337284, 43.5869227686236, 44.819037299002375, 46.22371650511219, 45.31787257040701, 47.72859657964399, 46.12397063163019, 49.21853242381927, 46.683359453755045, 46.313821192710634, 47.166717052459724, 48.36349887232627, 46.77973208888885, 49.532545612704375, 47.6736363287895, 55.76691765939036, 61.70596661106233, 66.84773891202866, 66.8903515415807, 61.78860310585269, 57.41184203855453, 68.37823206378569, 64.48819398880005, 76.13338547368204, 65.85908982061571, 76.13481321642476, 16.666770596658033, 0.9908646789769974, 9.112687687720022, 10.15115382209901, 1.3334212620412151, 0.2329608719916113, 48.41334043010589, 84.86256537898895, 79.94932605374245, 82.57405065721082, 72.65254866692328, 47.03552553730626, 36.57308555418445, 51.96638414936682, 69.06204239014657, 89.70388412475587, 25.923291598596883, 0.5891709498340084, 0.35043754404590977, 0.11317455975879585, 0.19145182273801298, 0.12314415221372921, 0.14682379971829154], [0.03167382287492435, 0.019999952919240442, 0.03368167612220972, 0.07874584831898251, 0.04954433864763668, 0.01952624436648142, 0.07131137104044039, 0.07629173927970472, 33.98182269065611, 64.46256914446431, 49.709542566730136, 40.98294358099661, 27.021992591119584, 20.90144184327895, 35.075924704151774, 57.866056426878906, 67.02956430373654, 58.3142303651379, 69.24093384896555, 8.104251219380288, 0.16784934327006343, 0.48742154192539955, 0.4634333678310918, 0.4472287389780245, 5.040286856312906, 72.54688001448109, 55.20172765178066, 67.10857652848767, 55.04513878976145, 64.71398130539926, 59.392219281965694, 62.38142228895619, 52.19974948513893, 58.32305177565544, 57.38543272018433, 57.500652343996116, 45.782147838223366, 42.77929498303322, 39.84998264620381, 41.318835750702895, 38.55316861983269, 42.6080717579011, 42.83798540792158, 43.675395750230365, 44.76295917264877, 44.21293304812524, 42.67517958917926, 44.71337649130052, 41.14462760186965, 39.43068911952358, 38.080946630047215, 39.989517042713786, 38.25471155105099, 37.66046462520477, 37.31077747960245, 38.15802904867357, 36.877281050528254, 38.342078424269154, 37.28405437161846, 36.800634014991026, 37.70697609070809, 37.33980694124776, 36.32408565090549, 36.19823248155656, 35.66426846288866, 38.30592593839092, 37.74233233544135, 38.28569435304211, 36.64925013819049, 40.209232530286236, 42.24489558127619, 51.37202347478559, 44.315302987252515, 40.11042410327543, 38.912163549853915, 37.42234145441363, 38.99353704144878, 41.945230422481416, 39.915784328214585, 38.10474364988266, 37.63549873905797, 37.91023331303751, 38.60780723633305, 41.08445844342632, 45.76010804022513, 44.64601370596117, 41.6622902501014, 39.89312871809929, 45.064816936369866, 43.51145244413807, 43.965764891716745, 43.098462166324744, 40.061916151354396, 39.58155132109119, 40.77018245573967, 38.80484750193935, 38.341768557025546, 37.56146400205551, 36.37126784170828, 39.90024389759187, 39.69022843145555, 40.82537020406416, 39.41525459289551, 38.22508196676932, 40.302545716685636, 40.65968536561535, 41.032679234781575, 49.31531690782117, 43.649692458491174, 39.144893461658114, 37.23178486670218, 37.82083072969991, 38.21054566291071, 40.42141706712785, 38.93315607501615, 38.36651086807251, 38.26729843693395, 38.498694742879565, 37.08150709829023, 37.80858901239211, 39.25613972448534, 38.12099010713639, 37.13900120027604, 38.17171027583461, 38.183065537483465, 37.274362194922666, 40.10894144735029, 39.35087280888712, 38.20343832815848, 39.06398673211375, 39.866307550860995, 40.140665577303984, 38.88295365918068, 39.76801295434275, 41.13016582304432, 42.397189447956706, 45.34331306334465, 41.30897491208969, 45.28482267933507, 43.624781485526796, 45.94389853938934, 44.950036618017386, 48.70795357611872, 54.922027357162975, 63.57445040056783, 59.50372834359447, 63.49566175091652, 63.03223763742755, 66.46966949585946, 63.01340241586009, 69.15282172541465, 52.41174182584209, 62.800441249724365, 14.680340155478447, 0.5544376878007766, 2.663875251047073, 1.469268017718869, 0.2884719094201442, 0.08068072594582074, 44.81917065958823, 68.25550894583425, 67.71063681571715, 69.70716245712774, 61.888552942583644, 45.62749662706929, 17.49916618870151, 37.84697724926857, 50.7128103317753, 69.08347422076811, 10.623255199001683, 0.14071316067730227, 0.09762718071860653, 0.050017221740657286, 0.10386970945663991, 0.07983213035209526, 0.020673338459023548, 0.008047997835092247, 0.006366193044795505, 0.05332434287054404, 0.0513412093653554, 0.04864633038279511, 0.05780432929074573, 0.1032087594390877, 0.06769327566989007, 39.75427289162913, 71.76585766576952, 57.925821581194484, 47.92779022647489, 34.265994487270234, 42.7301751413653, 42.61822677427723, 61.59409669137771, 71.52349441282212, 63.3840742418843, 73.61319203530589, 9.429092541817697, 0.2196460340412394, 0.3612840926695255, 2.1635705617166336, 0.9701407748845317, 6.000435025461259, 75.16277144032141, 58.22492584105461, 69.44168859912504, 55.70184553823164, 68.12660417249127, 60.12666348488101, 63.74251219534106, 53.55901941176384, 60.21133568979079, 59.71889388176703, 58.351324219857496, 48.48279776111726, 45.872715365502145, 41.65876011694632, 42.352125337046964, 40.801145645879934, 45.40227020940473, 46.07505475321124, 46.10135424521662, 46.9481861206793, 47.04193469016783, 46.19966453121555, 46.4447420643222, 43.3033001038336, 41.36477455016106, 40.237132349321925, 40.616198047514885, 40.72337289010325, 41.37379600155739, 39.188376857388405, 42.50706288122362, 39.35910978624898, 40.72945256387034, 39.52641064120878, 38.632996697579664, 40.920660265030406, 39.40551534775765, 36.95733270337505, 38.159370499272505, 38.79501019754718, 38.464628957933, 40.8141286911503, 41.293897321147305, 38.67690763165874, 41.29909053925545, 44.530723479486284, 53.87817090557468, 45.95941151342085, 40.73919965374855, 38.78922470154301, 39.38926889050392, 40.60763159105855, 43.75341169295773, 41.465418646412516, 39.30078414178664, 38.710208554421705, 40.42548456499654, 40.713586576523326, 42.321079777133086, 45.554054167962846, 48.04336678597235, 46.71360485015377, 41.59282507434968, 44.88557638660554, 44.56216519878757, 44.45579051971436, 45.60481748273296, 42.30816341215565, 41.40032691340293, 42.05722978038173, 39.82832331811228, 40.8850412214956, 39.5782486854061, 39.545273319367446, 43.92834940264302, 41.305609518481845, 42.67890584084296, 40.11109090620472, 39.77111947151923, 40.73362596573369, 42.00587811008577, 40.52977646550825, 51.885861812099336, 47.287467218214466, 39.49672222137451, 41.669711374467425, 39.77624993170462, 41.17474356005269, 41.66324730842344, 40.10511321406211, 40.093365715396025, 40.42098560640889, 38.90885306942848, 38.6974726184722, 40.367115774462306, 40.7274325432316, 40.575228891065045, 39.809205685892415, 39.73720665900938, 39.393348155483125, 39.43443106066796, 40.85950659167382, 42.137599145212484, 41.873917810378536, 40.266605038796705, 42.4457444683198, 42.344453180989916, 42.77431357291437, 43.1487940203759, 45.37599425162039, 45.24208453393752, 48.33627370096023, 44.48238418948266, 47.31795972393405, 47.748518297749186, 47.51249751737041, 45.836151030755815, 52.3961268701861, 57.42712359274588, 65.38016450020575, 63.4834514125701, 64.63420029609435, 63.261370735783736, 68.43391403075188, 65.48508005757486, 71.17358761449015, 56.26736894730599, 67.51306703013759, 16.381027890789895, 0.6700209275849405, 2.711964244804075, 1.7336026723346405, 0.12688606271460173, 0.09394640403409159, 46.5627779499177, 76.1916091365199, 72.30585821213262, 75.82746413446243, 68.003998725645, 42.827512679561494, 21.678294712497344, 46.380870188436205, 57.37549343416768, 77.96012739981376, 13.023979125484345, 0.14308699136299474, 0.026926661375910047, 0.038621047166206186, 0.06561278771128386, 0.06493380398399408, 0.014402157075012164, 0.15626735023913846, 0.09197048707714967, 0.16387941435940806, 0.2109128002437853, 0.2575034792384794, 0.20659505209374815, 0.21604353622082742, 0.26811321476294153, 46.05629797904722, 79.62246710254301, 65.6416924538151, 57.405966328036406, 39.7710802478175, 33.5110519778344, 49.09444824341805, 68.83961262241488, 78.87719323558193, 66.8198194811421, 80.9287654199908, 10.32590521920112, 0.30861674297240477, 1.4709422569121084, 5.43713903234851, 0.9711385277971145, 6.110269725322724, 79.43159672521776, 57.65043589376635, 72.48493009997954, 59.250543271341634, 71.2978639910298, 63.622962274859034, 66.48032265324747, 56.14710515545261, 63.466342033878455, 61.752580058190134, 61.009177161801254, 49.58632915250717, 49.08481490227484, 45.28556792966781, 44.889887071424916, 42.04550973830685, 47.79242530945809, 47.224411195324315, 48.26841277460898, 51.522399302451845, 50.386833913864635, 49.410442229240175, 50.589969542718705, 47.00961043757778, 43.22966544858871, 43.47576672031034, 43.193646323296335, 43.93084795244279, 43.790533004268525, 41.002904522803526, 44.712458656680205, 41.391540804216945, 43.190920276026574, 41.41700875374579, 40.752829890097345, 42.07728485907278, 41.24885282208843, 38.905640648257354, 40.95921716382427, 40.31581509497858, 42.48026524820636, 43.80275118735529, 42.469894501470755, 39.647804075671786, 44.35082789390318, 46.206622815901234, 56.19496983866538, 47.457403905930065, 41.11784958070324, 39.71355868924049, 39.56723074759207, 40.41268587112427, 44.897284661569905, 42.99840250322896, 43.14086298788748, 40.87225037236368, 42.89136494359663, 42.62057235164028, 43.4813404083252, 47.53502368927003, 50.15158584040981, 49.30924115642425, 46.26996517181397, 46.76962414095479, 47.21560939665764, 44.974425915748846, 47.69135367485785, 42.8118977239055, 42.800428713521654, 45.44421211365731, 42.11550443403183, 44.14355024214714, 41.66249029098019, 40.728103268531065, 47.11721281851492, 43.27616514698152, 44.43736714701499, 41.287550926208496, 40.76425183203913, 41.545913527088786, 43.00066178844821, 40.932360695254424, 54.39065602517898, 48.77009568675872, 41.68068224383939, 43.18778237988872, 42.18001957862608, 43.18271467762609, 45.70140192585607, 44.00864816481068, 43.01104430229434, 42.16062345812398, 41.47598943402691, 40.84545273934641, 41.8118659142525, 42.494566209854625, 42.34525726687524, 42.916860349716686, 42.54069720545123, 43.737353509472264, 41.53547610006025, 45.81661370492751, 45.64578271681263, 43.12162768456244, 43.4178803813073, 45.453735628435695, 45.19354912542528, 45.12048321385538, 45.60134618513046, 46.26219495650261, 49.93669094577913, 51.55526876449586, 46.82293307396674, 50.89518093293714, 49.59164396409066, 50.187177427353404, 48.57282400131226, 54.61726311714419, 60.77949100925077, 68.82564113986108, 64.49031991343345, 66.22354076754662, 66.87375207101145, 69.49460921748992, 68.26297713864234, 73.15995431715443, 58.540817845252256, 69.37252152350642, 18.76086323491989, 0.8728699782683004, 7.938588934559976, 4.123970193247642, 0.6036881934250555, 0.1884679409164575, 52.73319182857391, 80.20065584490376, 77.5615204534223, 81.11797271236297, 79.62093737817581, 61.491397273155954, 29.29691630025064, 56.82914257049561, 66.75497485745338, 92.12982300789126, 19.53465665540388, 0.25208668603051093, 0.19333210893936698, 0.10637278683603772, 0.24895023013795578, 0.23120433963354559, 0.10981439087059229], [0.08670713361953536, 0.03467732229300084, 0.03781467833886704, 0.06397753473251097, 0.062161201551075906, 0.05717236804024828, 0.06392721041676498, 0.1419108165728469, 22.071992812618134, 65.40667972257062, 52.623820458689046, 43.702122780584524, 22.59176373481751, 21.225009925903816, 34.30388458313481, 57.46524510845062, 68.09816698874197, 56.849680100717855, 69.9188998437697, 8.966818663381762, 0.2847670469312899, 0.1346079761823339, 0.5881309701550392, 0.37675263360142713, 2.030632488669888, 65.23297363711943, 59.69479483942832, 63.322881344825994, 58.5865330696106, 55.76567034567557, 48.54514383500623, 58.658504639902425, 53.37699397917717, 56.49687859319872, 56.76600417783184, 51.68048650987687, 44.253066739728375, 42.58965622994208, 41.50812933521886, 43.51730462043516, 40.32457374757336, 45.29960217014436, 41.942108215824256, 44.69268598864156, 42.20171028567899, 44.744975105408706, 40.39779655395016, 43.46950661751532, 39.14192814980784, 37.647418822011645, 37.72852951480497, 37.74420330601354, 35.95351188413559, 37.057466891504106, 36.99584253372685, 38.194891483553, 37.70485801081504, 40.403774246092766, 37.83956396964289, 37.84387857683244, 38.534690333950905, 36.70323764124225, 36.926895110837876, 39.591365091262325, 35.69907949816796, 37.72959247712166, 37.20474012436406, 39.47981680593183, 38.19869618262015, 37.99305808159613, 38.06721048970377, 49.563673542391875, 45.267948642853774, 40.776795571850194, 38.04645330675187, 38.059177475590865, 38.57846398507395, 41.06630179189867, 40.66448634670627, 40.15814365879182, 38.02236995389385, 38.62002149704964, 39.95939716216057, 43.81926436578074, 38.90773519392937, 40.9371812881962, 43.47355450353315, 45.53346172455819, 43.46004193828952, 42.41000383130966, 43.0023209510311, 43.41231453803278, 40.185400209119244, 38.774923739894746, 37.06883392026348, 38.32736953612297, 37.29819843845983, 38.49030871545115, 40.58097516336749, 41.224259561108006, 41.07638228324152, 37.72487778817454, 38.94110279698526, 39.33870561661259, 40.63802211515365, 40.100833908204116, 42.26411127275036, 49.501366692204634, 40.86431541750508, 37.60807352681314, 40.70384340901529, 39.266765425282145, 38.79341771525722, 39.27071132967549, 38.798120637093824, 38.97395264717841, 39.240293348989184, 39.68135603012578, 37.592027110438195, 39.49662808449038, 38.03394486827236, 40.0709689817121, 39.133094972179784, 38.647058394647416, 38.477674761126124, 37.17811507563437, 38.20727048381683, 38.88828416024485, 39.14260671984765, 39.92953615803873, 40.23507702735163, 39.958463638059555, 41.8647276970648, 43.19956910225653, 45.1394517960087, 44.48374917430263, 44.101345539093025, 46.37675954449562, 44.12244789062008, 44.723943356544744, 44.093912647616484, 42.34897959616877, 43.723264355813306, 46.135984851467995, 53.524141696191606, 58.43738886617846, 61.767641959651826, 59.98010804576259, 64.71813509541174, 61.598113198434156, 67.44563364213514, 64.32933015208091, 76.13179299139208, 22.26796619353756, 0.5394857352779758, 1.2601321430936938, 0.8591182710182282, 0.18851367636553704, 0.21138261132422956, 43.98316844817131, 71.16034569278841, 67.22090536548247, 72.222350951164, 61.29365490328882, 42.070456012602776, 24.24888864640267, 39.5359420007275, 53.34693293417654, 65.28221507226267, 8.705839841596543, 0.17291339895417615, 0.04059480375520164, 0.03843840414417848, 0.11129720001331261, 0.07420165223940726, 0.09005097717407251, 0.022793586380899917, 0.05898985418400938, 0.05575221339841524, 0.06038451725016199, 0.039169026028004386, 0.05618955384218886, 0.20067277875158096, 0.12413074322525533, 25.90792767463192, 74.18746625223469, 58.096774162784705, 51.34895209343203, 24.602486395066787, 23.065907685987412, 47.76392144541587, 61.69558801958638, 74.1206604434598, 61.57384157180787, 76.1646624534361, 9.27478846042387, 0.3399975429619512, 0.10733487069486611, 1.8093855606932796, 0.8283763270704978, 2.547284023415658, 68.88933258671915, 60.63515563164989, 66.45077936110958, 61.11214722356489, 56.795943629357126, 50.66883663977347, 57.86629569145941, 54.520184455379365, 59.774595460584095, 57.67759046246929, 54.459442630890884, 48.32232575262747, 46.23016880404565, 42.46711746338875, 44.63723151914535, 43.504549072634795, 46.75288346505935, 44.83693115172848, 47.071729013996745, 45.77914722504155, 47.38823683031144, 42.87779746517059, 43.83322408122402, 38.65751935589699, 39.71381364330169, 41.030592533849905, 40.39253665554909, 37.73921012878418, 40.36291883837792, 38.91874920937323, 40.29619147700649, 40.415757086969194, 41.225863810508486, 38.54261352169899, 40.60567040597239, 39.26117212541642, 40.19938738115373, 38.97985189191757, 40.04309661926762, 37.8036036799031, 39.608478392324145, 37.63378858566284, 40.69448071141397, 41.07849251839423, 40.44863831612372, 41.388920660941835, 52.418386320913996, 49.26206288799163, 41.460307798077984, 39.685423527994466, 39.21486070079189, 40.227012634277344, 42.55515898427656, 42.11767742710729, 42.696991889707505, 40.88350365238805, 39.794371281900716, 41.67439860682334, 45.66714786714124, 42.44487370214155, 42.02259525176018, 43.55013878114762, 47.746098195352864, 46.782897441617905, 45.71491056872953, 45.54018074466337, 44.70179373218168, 42.692622369335545, 42.28501750576881, 39.841282829161614, 38.942581530540224, 39.66295226927727, 41.150648440084154, 40.63130309504848, 43.75566705580681, 41.099924349015765, 39.87542706151163, 39.42915939515637, 39.586619023353826, 40.9056415096406, 40.39918899536133, 41.07583707378757, 52.114151600868475, 43.634128493647424, 39.59175732827956, 42.186107097133515, 40.76143164788523, 41.0913186688577, 41.08198735021776, 39.474482382497484, 40.6245840749433, 40.053541891036495, 42.06575701313634, 40.11481323549825, 41.53927687675723, 38.62816825989754, 41.9196448018474, 40.67200945269677, 40.537770255919426, 40.383036674991736, 39.67161286261774, 39.93722400357647, 41.15701836924399, 41.14727127936579, 41.81477239055019, 41.93464786775651, 42.78486082630773, 43.679267129590436, 45.071218244491085, 47.37450853470833, 47.14571276018697, 45.76222612011818, 49.386696200216974, 48.31436726354784, 46.36460019696144, 46.4465267427506, 44.37369923437796, 47.53979329139956, 48.092161070915964, 55.51359138181133, 58.892909403770204, 64.01781551299557, 61.0340920571358, 66.83785453919442, 64.75779025785386, 70.19414040350145, 65.17895867747646, 78.93077281213577, 25.423767951227006, 0.5912021859999627, 0.6548860945528554, 2.2231986782243176, 0.32775622401987353, 0.21633641163427986, 49.06131990494267, 75.31982314202094, 73.06305608441754, 78.63621850167551, 66.83214356822353, 46.99557227473105, 28.705626841514345, 48.69059708810622, 58.24947595596314, 75.33189619741133, 11.25966662360776, 0.24787724739120853, 0.13329957461645528, 0.038769442227578936, 0.1138279255058977, 0.04823640056495224, 0.027663888852863062, 0.22690071814483215, 0.11475191181225163, 0.10639347887087254, 0.20661579775473765, 0.16660285693022514, 0.153990414354109, 0.32421168841181264, 0.22494716329439995, 30.618870758241226, 84.56437110900879, 69.71545434767201, 58.117029282354544, 36.1274690012778, 32.05610367559618, 48.507371410246826, 67.81240663220807, 78.00204184747513, 65.86626775803106, 81.1274334692186, 11.363587860138187, 0.46706637127264855, 0.21120834164321425, 2.6918351313760205, 1.4034350793207846, 3.0767711468281287, 69.99258548982682, 62.095324608587454, 67.78479314619496, 62.158682653980875, 59.35049703044277, 53.15129687709194, 59.51051404399257, 54.8696715601029, 61.299240358414195, 61.31430618224606, 57.291958716607866, 50.011008093434, 47.51592174653084, 46.04460931593373, 47.97380355096633, 45.733353553279755, 49.31290072779502, 46.719233451351045, 51.4127141429532, 47.91463851928712, 50.703231903814505, 44.113347991820305, 47.31582203219014, 41.60732215450656, 43.467521898208126, 42.47493082477201, 42.116010419784054, 41.18437297882573, 41.37935400009155, 41.18684407203428, 42.9157385518474, 42.47941017150879, 46.4321747902901, 42.18575800618818, 41.89910334925498, 42.39377698590679, 42.07356645214943, 38.94649213360202, 42.79654556705106, 39.595056041594475, 41.83704753075877, 39.47190930766445, 44.1045501155238, 43.807073639285186, 43.369019416070756, 43.232599381477606, 57.091929604930264, 49.343354009812884, 43.043388166735255, 39.94670437228295, 40.60108123287078, 42.023050246700166, 43.121584538490545, 42.24899445810626, 46.27530351761849, 42.5329662138416, 40.908449926683986, 44.51320225192655, 47.003056157019834, 44.30074314917288, 47.19573474699452, 47.68210080362136, 48.357438810410045, 47.98528825083087, 46.700708097027196, 46.92697394278742, 46.88156858567269, 45.454826047343595, 45.26073540410688, 42.72830809316328, 44.559231265898674, 41.89255691343739, 42.42573645807082, 42.159525194475734, 46.40216473610171, 43.86549342063166, 41.03154566980178, 40.27182963586623, 40.7441653743867, 41.22054115418465, 41.019896230389996, 40.69175074177404, 54.856425716030984, 46.36205850108978, 42.33027381281699, 46.532854187873106, 43.049201119330625, 43.60528730577038, 43.38387735428349, 43.10561656951905, 43.408564752148045, 43.388219418064246, 44.923615532536665, 41.68980959923037, 45.22668530864101, 42.48266573875181, 46.085229381438225, 44.484690543143984, 43.95340158093361, 44.214090147326075, 41.52544267715947, 43.90001027814804, 43.08915830427601, 43.6061070811364, 43.26370377694407, 44.20129537582398, 44.43785744328653, 47.568826675415046, 48.9852455354506, 50.16363536157916, 49.99971166733773, 49.80821763315509, 54.1401695436047, 50.45301998815229, 49.428645949209894, 49.286589468679125, 46.72513269609021, 48.513917846064416, 50.98723111614105, 56.90047479444935, 63.315750475852724, 67.06470089574015, 64.27933169949439, 71.10494613647461, 66.7765635828818, 71.99543399195518, 67.79850575231737, 79.81924456934776, 28.781461946425903, 0.7850304594443691, 6.041473803981659, 6.377984727582624, 0.694723831069085, 0.3871962812639052, 52.51622200012208, 83.05898897109493, 77.85860861501386, 85.02238627403014, 75.18796090156802, 60.32471179962159, 37.540804878357925, 58.148239581815666, 68.25728185715215, 90.33086715206024, 16.43241584300995, 0.5248616070997331, 0.20482856059266677, 0.18309332850959995, 0.23836310952901843, 0.16926729540911414, 0.19375684340634655], [0.1341125624434602, 0.04292192222971109, 0.054827698491393566, 0.03411868331773627, 0.021111312840554505, 0.06192469105665242, 0.09463141687334546, 0.2763880981552986, 11.149644140274296, 61.075661336222005, 55.190356700651115, 40.35277951148249, 28.222182950665875, 38.200088624031316, 38.193569644804924, 58.61197356254824, 67.42653169939595, 58.91924811947731, 69.50140276262837, 11.449124947670969, 0.36890314351166453, 0.27127237750157235, 1.7237057969454797, 0.6316025987748177, 0.7059153950502796, 49.56869417621244, 52.724605760266705, 67.09178878415015, 56.39963519188666, 61.254890118875814, 50.25310854757986, 59.54954162720711, 61.9581122552195, 60.35020328337147, 52.575045785596295, 51.5495107250829, 45.375703996227635, 43.63258700216971, 40.78309097597676, 44.53925463461107, 42.39461637312367, 44.37163214529715, 42.88080984546293, 43.21038307682161, 41.556751035874896, 42.872529722029164, 40.482202037688225, 40.83832187037314, 37.87999576137912, 38.83089988462387, 37.913755601452245, 38.8592743104504, 37.01912572306972, 38.071101480914706, 36.503957702267556, 37.94746445071313, 37.055717514407256, 39.35390872340049, 37.93619155883789, 39.10236320187969, 38.97683951162523, 38.0603620313829, 37.40234128890499, 37.92180822741601, 37.10419800973708, 37.66946646475023, 35.83524850107009, 38.52439411224858, 38.95225409538516, 37.495007284225956, 38.84120002869637, 49.616139165816776, 46.36602793970416, 41.57148345824211, 38.351594094307195, 36.900689755716634, 38.87444996064709, 39.403134469063055, 39.12890588083575, 40.89004616583548, 36.71631874576692, 38.032862294104795, 37.931045409171816, 35.93661039106308, 39.40633904549384, 46.75488387384723, 44.577305547652706, 45.74426558709914, 42.105200367589156, 43.64486794317923, 42.01938675295922, 42.306943555032056, 40.35174792812717, 38.94788065264302, 39.086148123587336, 37.71090238325058, 37.223842067103234, 40.14782390286846, 38.77177799901655, 39.64693330949353, 39.605466012031805, 39.06611657911731, 37.17622841558149, 38.49367803142917, 39.30974283526021, 39.19553910532306, 43.276937853905466, 51.659733249295144, 40.003355164681714, 39.13202024275257, 38.59581262834611, 38.32423556235529, 37.038015857819595, 36.48480869108631, 37.52555470312796, 39.57591487515358, 37.98204014378209, 39.39083391620267, 40.27613639831543, 38.62637181435862, 38.886864262242476, 38.42513853503812, 38.10413176013578, 37.34121114976945, 37.78737291213005, 38.49449780679519, 37.459007770784446, 37.886710859114125, 39.51683613561815, 39.433834860401774, 40.12275995746736, 41.89309035578082, 40.82988877450266, 41.95474609251946, 43.39813124748969, 41.152021269644464, 43.093006149415054, 42.515958816774436, 43.515994548797615, 41.10375258230394, 44.97336295343215, 46.03431701660157, 44.03417494989211, 41.65071925809307, 43.792478499873994, 47.27237786016157, 55.75528783182944, 57.25417452473795, 61.439782804058446, 62.262833349166385, 68.47529503606981, 62.785642147064216, 75.29901889062698, 37.98320901009345, 0.6406350205502203, 0.9540740725013518, 0.7769758110084842, 0.06281794957636345, 0.21875321985252444, 45.50473820778632, 71.9355707783853, 65.36553013709285, 73.38443156211608, 60.63009185175742, 40.75403405774025, 13.636807299429371, 38.800274018318426, 55.6459007724639, 60.71019057304629, 6.812731902445517, 0.23085261334574994, 0.16615864850821035, 0.00198494745775186, 0.11918916201759731, 0.04362553951420611, 0.06663311723499529, 0.07088675914752869, 0.1116134257866971, 0.10801282020345812, 0.026491557908875328, 0.06546690158786313, 0.16572308155798143, 0.061142760434097825, 0.29347820207476616, 14.09843300619433, 68.38166021531629, 61.343312109670336, 49.17487252143122, 33.01487215103642, 40.58622329465805, 45.4951637021957, 62.16162050923994, 73.14277433579969, 63.50178064838533, 75.09164317961663, 13.458407117474465, 0.5504276158828889, 0.15299883611019582, 3.4784174398068464, 0.630459902026961, 0.571063818229783, 54.58241285816316, 55.87122132701259, 65.66830573543426, 59.13222497509372, 63.132010967500754, 54.02795445534491, 60.31887531280518, 62.787250318834865, 61.81569883900305, 53.555963885399606, 53.60128687274072, 47.97163055789086, 44.298491708693966, 42.74497424402545, 46.72970617971113, 44.33474225382651, 46.67958613364927, 46.18588916717037, 46.44086676259195, 43.26899113193635, 45.57237948140791, 42.09968943749705, 42.41101580281412, 40.06208873564198, 40.41752607591691, 39.55654228887251, 39.54493207316245, 38.485962729300226, 38.874402892205026, 40.3565175302567, 40.19458640006281, 39.24938148067844, 41.40740286919379, 39.139241326239805, 40.96672850270426, 40.87345061763641, 40.52327709813272, 39.179496611318285, 38.52621409200853, 37.76984776220014, 39.63138895650064, 38.73704933351086, 40.755097020056944, 39.48719086185579, 41.06304622465565, 41.556503926554036, 51.723463919854936, 48.48622199027769, 42.67474420609013, 38.739371376652876, 38.74993431952692, 41.23215529226488, 41.54187740818147, 39.330088169344016, 42.190739416307025, 39.46910873536141, 40.5593668260882, 40.72171372752036, 38.85071962110458, 41.907650193860455, 45.99960796294674, 47.45336386465257, 45.33912789437079, 45.28478345563335, 45.73211408430531, 44.91494709445585, 43.368058435378536, 41.16261951385006, 41.060649656480365, 40.322514503232895, 40.495071334223596, 39.995902661354314, 41.801377496411725, 40.879730332282286, 40.64162677334201, 39.82260450240105, 38.0832019928963, 37.840532795075454, 39.78400053516511, 39.69670818698022, 40.16816923695226, 41.646428185124556, 53.05607349641862, 41.792563930634536, 41.514040347068544, 41.713751746762185, 40.39061077179448, 38.92453862774757, 38.83205306145453, 40.20616131444132, 40.313092970079, 40.08209282352079, 41.07922600161645, 40.60434856722432, 40.916973237068426, 40.44819116592407, 40.093189208738266, 41.84531196471184, 40.38804554170178, 40.065979726852916, 38.563143207180886, 40.25992132002308, 40.305848352370724, 41.58294070151545, 42.53939105618385, 42.958778719748224, 43.47406048928538, 43.26507268413421, 45.22901127415319, 45.77711543729229, 46.01369319423553, 44.85539767049974, 44.76014291086505, 45.82847102995842, 46.2971354299976, 46.10191906652143, 47.09863647337883, 45.655388601364635, 45.60175018925821, 45.59235611269551, 49.941523305831424, 57.726839742352894, 60.520367468557055, 61.40193977663594, 66.0792838373492, 70.0274004474763, 67.5305215774044, 78.06993023041757, 44.78544219847649, 0.6813707959748084, 0.848722703033878, 1.5615988955382378, 0.3626880866865958, 0.3163648949515435, 47.583025655438824, 76.5255440435102, 70.21207347992929, 79.34615181338403, 65.4887866973877, 48.40005928470243, 18.33162061629757, 45.75744082850795, 62.188386763295824, 71.16229118839388, 9.275729829265225, 0.25869060908594443, 0.19112206785188568, 0.0526811431101974, 0.10767064703207825, 0.027979919273826866, 0.09801379465047391, 0.21086594630633632, 0.16844595722373457, 0.23538339522577104, 0.11216110970464446, 0.1917928237948687, 0.31847503817369865, 0.21514102335899107, 0.5370300251149362, 16.36332133123952, 80.65156367517288, 71.33226317744102, 55.53003395757368, 41.46537550034062, 50.435965522643066, 50.1413994450723, 68.19186456741826, 78.65168048489478, 69.14519663779967, 82.25864502691454, 15.140625392237018, 0.7613975662858256, 0.4577167584530769, 7.1961499606409385, 1.3004330257254264, 0.6804995395002827, 60.458499923829116, 57.09443599947038, 68.88779501761161, 60.75492128249138, 64.4579093686996, 54.00636572991648, 62.51092326256537, 64.16572416982343, 63.44668311457481, 57.13679759733139, 53.90465867134833, 49.67227220535279, 46.447440655000754, 43.58085093959686, 49.580076894452496, 46.01225760675246, 49.750888270716516, 48.18634894586379, 48.29468088765299, 46.297202110290534, 49.82832370265838, 44.41688452997516, 45.691564621463904, 43.52634960605253, 43.449388780901515, 43.035621873794064, 42.66054130369618, 41.022586976328206, 42.99291510735789, 41.03694677352905, 43.518226377425655, 40.9454692563703, 44.864442656117106, 40.39815348963584, 42.32395879683956, 42.141286173174464, 41.54303842975248, 41.346684578926336, 41.72300461799868, 40.310566963688025, 42.6066832388601, 41.248468429811545, 42.39241984582717, 41.85605925898398, 42.6561874728049, 44.15289725026777, 54.91923070723011, 50.210943068227465, 43.29014055190548, 39.57447536530034, 39.48543756238876, 42.73964766533145, 43.53661837116365, 41.68755423638129, 44.34796064130722, 40.134746720713956, 42.86272771896855, 42.58532201090167, 42.91831947142079, 44.517579617038855, 49.64709058884652, 48.77564976292272, 50.158155810448434, 46.29107929045155, 48.01422749796222, 46.312283623603086, 44.13541132403959, 43.945490160296046, 44.23105832069151, 44.194537132017075, 42.42652485447545, 42.353568769270375, 45.14318197004257, 43.290524944182366, 42.137057858128706, 41.923606395721436, 39.0336158198695, 37.90646783767208, 40.44134270760321, 41.07825717618389, 39.51811482829433, 43.3933694901005, 56.794586489277506, 44.083522289030014, 43.10553419974543, 42.9457329165551, 42.88702287981587, 41.093221018391276, 40.370543925992905, 41.24785261769449, 44.93052282641011, 42.57040523713635, 42.636108859892815, 43.12538531518752, 43.73461569509199, 43.58580489312449, 42.141643108860144, 45.49290049460627, 42.21674865291965, 42.86490463441418, 42.65270048572172, 42.49204412583382, 43.036688758480935, 44.663130929393155, 44.36761563824069, 43.75815776086623, 46.557117969759055, 46.87410823760494, 47.16381842090238, 48.70789081819596, 47.91890213566442, 48.006312154954486, 48.60206919331705, 49.539307778881444, 48.420459531968646, 48.818282004325624, 49.797831196938795, 48.80158839687225, 46.729980745623195, 48.674703644168, 51.27755318918536, 61.340907696754705, 63.44356875265799, 64.46786826656711, 70.21703135582709, 72.6806563715781, 71.47786940297773, 80.69503138142248, 47.0536704217234, 1.207307255075824, 8.480795814144997, 3.9182384456357653, 0.499213872056815, 0.32791173986850247, 54.6541843875762, 83.59992304155904, 74.95973387072164, 84.07046625691076, 74.32638875899777, 57.20398779838317, 24.64128451962625, 57.741960479367165, 71.26187232232863, 84.95222291638775, 13.194152136002819, 0.3995942498647398, 0.4176020351869445, 0.12125992065956517, 0.17493535013448808, 0.11001023358755535, 0.17218489530346087], [0.06211291502920851, 0.035008023297714616, 0.1383480940374636, 0.039233488496392965, 0.07635080465866674, 0.056225709361775275, 0.040914794850733974, 0.04388752243211193, 3.9375159144401555, 57.59933133279124, 54.111689213783514, 40.210071917503114, 17.86155593010687, 21.71610636095847, 48.22809865397792, 53.78836824047951, 68.20668328192927, 55.264061958559104, 69.19100992141232, 13.265550059656944, 0.429697674849341, 0.23608356894504642, 2.394524375277181, 0.6050168350338936, 0.2215657124836599, 37.36784404323947, 59.86977177281534, 67.97811892724806, 58.75001745839273, 64.45270046111077, 62.15671754652455, 58.083849953066924, 57.3774036284416, 57.00850079136511, 51.51879856663366, 50.73726630979969, 44.94964045862998, 42.125365272645034, 40.443225445285925, 41.42249614961686, 42.11640657917146, 43.81637357896374, 40.2504252618359, 41.93179630464123, 39.273880604774725, 38.252793512036725, 38.3381050632846, 39.170228050601104, 38.571113463371034, 38.67633888798375, 38.465229080569365, 39.174558347271336, 36.283496964362364, 38.52617486830681, 38.50239746032223, 38.35883871201546, 37.51195976811071, 38.403298777918664, 37.73564469429755, 36.80922008329822, 38.989716652900945, 38.322568555032056, 36.75142788117932, 36.75218882099275, 37.02957099483859, 36.45697162997338, 38.59972323140791, 38.02509600116361, 38.4335716309086, 38.35096259270945, 38.41967467338809, 48.56051168134136, 47.944523057629986, 44.3049910760695, 38.82140774880686, 38.39086094210225, 38.757312297821045, 39.10467740028135, 37.96345203153549, 40.00177444950227, 36.2488075225584, 37.31042054391677, 36.83963021924419, 38.574678897857666, 38.607658186266505, 41.13732022623862, 40.31181035503265, 42.87013315385388, 41.16864819680491, 41.29312069185319, 41.459660606999556, 39.96628092181298, 39.059778028918856, 36.21681667143299, 38.277182809768185, 39.68223856341454, 39.950618897714925, 40.30455004784369, 39.3585684991652, 42.02359153378395, 37.9070601155681, 37.68148068458804, 38.33930530855733, 40.120398690623624, 39.743203963002856, 39.67314650935512, 45.6873990643409, 49.44500615519863, 38.59989581569549, 39.38287542712304, 38.78414915454003, 37.08839085794265, 37.746207637171594, 37.19019205339494, 38.66985128771874, 37.62564574518512, 36.59581176696285, 38.880788510845555, 39.26288227881155, 39.214119372829316, 38.99461961561634, 39.36432653857816, 39.55838972522367, 38.10654401779175, 37.23513064845916, 37.00640155423072, 37.89347694766137, 37.46428335866621, 39.45740046039705, 39.34980200183007, 39.70354487819057, 39.83688192982828, 40.58891011822609, 42.87343971190914, 43.07311581027123, 40.620744074544604, 41.86772438787645, 40.46523386432279, 41.26187116869035, 42.18651110126127, 43.94161093619562, 42.77798883376583, 43.57795623040969, 45.03394788311374, 45.61936163133191, 45.38220728597334, 47.81156647589899, 48.204889989668324, 54.139483128824544, 54.61030875482867, 64.26348924636841, 63.22831299997146, 70.74667684493527, 48.73386083110687, 1.207984231652752, 0.6033386121834479, 2.028418555855751, 0.1817853865964759, 0.4262339155520163, 48.255606235996375, 69.96833739742156, 66.0356278573313, 70.52857737387382, 63.660189490164484, 45.83486057096913, 26.34837454365146, 41.48218285652899, 57.38351468117007, 57.6383706831163, 5.7726889752572585, 0.25371557281863305, 0.032082691660992084, 0.04539261707254956, 0.012680068987631991, 0.029605343344531236, 0.024095970326133316, 0.09269198102335777, 0.030781081464562206, 0.03531677588339775, 0.006908907924943994, 0.09160712391378419, 0.04667261975907511, 0.05738696458959772, 0.14068840071558952, 5.045661484041522, 66.18958088659471, 62.60757046361124, 47.453799247741706, 22.373925101372507, 26.28165306583528, 53.24136234098866, 60.70234583270166, 73.28672532112368, 60.773846718572806, 77.09176955684539, 13.97933219709704, 0.4044692044056231, 0.07048346748154971, 4.072126755791326, 0.7858271295985868, 0.17499766372624906, 44.69538457932011, 61.44119093495031, 70.48010472328433, 61.44719216131396, 66.00399786426176, 64.03954936612037, 60.28754341986872, 58.80819405278852, 59.130024525427054, 53.97131935242684, 52.8460580302823, 45.73430668923163, 45.568213924284905, 42.12159979727961, 43.13279075007285, 44.550633430480964, 46.395810496422556, 42.48270888482371, 44.600769166023504, 41.78703338869157, 41.83931858308854, 40.10406986359627, 41.84990113781345, 40.359580901361284, 41.43782477225027, 40.91579260364656, 40.869959708183046, 38.8213606803648, 41.507403696736986, 41.0409358239943, 40.64139927587202, 39.157409744877974, 39.27727345497378, 40.02086854750111, 38.12269241579118, 40.89166218234647, 39.17169501704555, 37.050034000027566, 39.05487506620346, 39.05253341121059, 38.413724437836684, 38.432175267127256, 39.567191523890344, 39.77111947151923, 40.97402018885459, 39.38977487625615, 52.04165051060339, 51.18256515072238, 45.06260079722251, 39.56104516983032, 37.40866807199294, 38.09662434362596, 39.94786147148379, 38.00332684670725, 41.28790393952401, 39.05918575102283, 39.41694513443978, 39.39687436626804, 40.4990956860204, 41.23090405617991, 43.161788832756784, 42.176728710051506, 44.28862302534042, 43.18238127616144, 43.22531161769744, 42.15366517343829, 41.89693427854969, 41.353654630722545, 40.526179652060236, 39.95723593619562, 40.27449292521323, 41.459327205534905, 42.13522218888806, 41.024246138911096, 43.024470575394176, 39.26200366789295, 39.3586822479002, 38.7310794861086, 40.06383026799848, 39.41039477625201, 39.59037273160873, 45.517368239741174, 53.48276853561402, 40.78578172191497, 40.21241357249599, 41.048584445830315, 40.887343652786754, 41.08390538923202, 40.001625399435724, 39.76169793836532, 40.281686552109264, 39.343232031791445, 40.28415764531782, 40.6499029744056, 41.447073721116595, 41.21678352355957, 41.94022940051171, 41.93791520211005, 41.794262316919145, 39.799682171114036, 40.23988977555306, 39.84766844780215, 40.66079539637412, 40.38693551094302, 42.07649254029797, 42.14229814467892, 42.44722320187477, 41.93078825550695, 43.63395590935984, 44.493923802529615, 42.950329934397054, 43.11664235207343, 43.4922210631832, 43.801798051403416, 44.46569842676963, 44.91004020937028, 44.42914193676364, 45.559353290065644, 46.01117895495507, 48.60092386122673, 47.77445300932854, 50.161509436945764, 51.099567797876176, 56.750887363187736, 58.24161944850799, 66.16357557235226, 65.79238207109513, 73.62040919642295, 56.146838434280895, 1.8390175964563125, 1.1185978280921136, 2.5048819761122427, 0.24891609326004985, 0.4440923750160202, 52.897841161297215, 77.08757262076102, 71.5093974144228, 75.96116988889634, 71.09343790238904, 45.88971099545879, 25.493894046352757, 47.64988245502595, 62.4489890375445, 68.1872675495763, 8.2949911778973, 0.32600179074272034, 0.04234037339507092, 0.02043743700449986, 0.0850253178167247, 0.04834037784847522, 0.026311655566396735, 0.2321599117450176, 0.174274783160898, 0.19796683362895445, 0.11567792825160489, 0.21675995100409756, 0.2852996006127327, 0.23404591296228672, 0.42638051413720657, 6.211671819609981, 77.1587557946482, 70.73440767103627, 54.78037488075995, 29.028951737188525, 28.51837092830289, 59.578092559691406, 65.41645034666985, 79.20602121660787, 63.98113742951424, 82.22831726074219, 16.86087496819035, 0.6397445812340706, 0.6082399201489265, 9.315562478957638, 3.614440089271915, 0.38412031567385124, 51.19139440598027, 62.699640258666015, 74.36965250199842, 62.88285024704472, 69.52736885316911, 63.976579635374016, 62.64794734216506, 61.97394294123497, 61.56944851721487, 56.095549521907685, 55.45162185545891, 48.81436747889365, 47.26838096495598, 42.95562121175951, 45.27150231022989, 47.485896002861764, 47.89751737348495, 44.23005811629757, 48.164646471700365, 44.335020742108746, 44.08040400474302, 43.09059389175908, 44.96270587367397, 42.238808062768754, 43.45688835267098, 43.29973466934697, 43.35130599237258, 40.23029565811157, 43.39262031739758, 45.23923297082224, 43.74566108949723, 42.34954441747358, 42.40038617964714, 41.044567938773866, 39.71581405208957, 42.925336591659054, 41.985803419543856, 39.81575212171001, 41.018503788978826, 40.89884796450215, 40.1560922591917, 41.071812721990774, 42.39802491280341, 41.78986926232615, 44.38341102292461, 41.771214469786614, 53.75828758362801, 53.887659119021514, 47.12183729294808, 38.9681593064339, 37.63782078219999, 40.967289401638894, 41.319659448439076, 41.04370501733596, 43.692069745832875, 40.28630710417225, 42.36141350961501, 40.81164190846105, 44.84297552416402, 43.39517770274993, 46.746670430706395, 44.36366581147717, 46.865675141734464, 45.07662327058854, 46.40323554315875, 43.69569793824227, 43.55904648380895, 44.23315286636353, 42.31506678365892, 41.70451064263621, 43.81069006458406, 44.12335788050006, 44.570064852314616, 42.86862304133754, 45.504867646002005, 40.8246131866209, 40.84985756104992, 38.29159752015145, 41.30182050889538, 40.353607131588845, 38.39547364942489, 46.833915710449226, 56.5479439304721, 42.97285610629667, 42.44893727764007, 43.03955993344707, 42.28872414558165, 41.06292855355048, 42.63777586721605, 40.75947830753942, 42.58682035630749, 41.93061567121937, 42.714156181581565, 43.51493550885109, 43.28999934657928, 43.050664163404896, 43.18406397296537, 45.00777782932405, 44.984930023070305, 42.51362108415173, 43.35633447093349, 42.51810827562886, 42.54408221090994, 44.57532475071569, 44.955833881132065, 43.67776093944427, 45.72964691346692, 43.98749090010121, 47.24032425111341, 48.48587682170253, 45.441913604736335, 45.81727266311646, 43.279416791854366, 45.11885935260404, 47.57646353014054, 48.24897743040516, 47.50026756717313, 47.75815556126256, 49.735857748216205, 51.97687648957776, 50.8790482244184, 54.139840064510224, 55.00155341240668, 58.63727285015968, 61.76459820039811, 67.25319431674096, 69.27385822419198, 73.19800915256624, 63.01553618523383, 3.321755523643186, 2.5144285348153885, 6.240454171934436, 1.314387593057848, 0.9856789378869919, 56.93055545130084, 82.74639175784203, 77.03880971477878, 83.87513222232943, 78.91980586513397, 61.93307968877978, 38.76101109289354, 62.27942889736545, 70.61225721913, 79.51136988978233, 12.021145762935763, 0.49229226766094086, 0.2345281499888628, 0.14141235380403458, 0.13224269503787642, 0.16401029282039212, 0.3276730575148137], [0.077860557113684, 0.0770584553960831, 0.05929069691187432, 0.020786554762913335, 0.06765589824006443, 0.020738339104178934, 0.1020787644290155, 0.054812166058728774, 0.7024583160396546, 42.40270822278915, 58.594836727265395, 46.72239488170993, 33.72549187752509, 33.60684017981253, 38.605700923550515, 46.90354562574818, 62.46354887562414, 60.28529197938981, 67.6092121678014, 23.709831430066018, 0.27909281753724624, 0.3177358246138019, 2.417842620803464, 0.0825461500414437, 0.06112608269998624, 45.24620302261845, 67.86196970170545, 64.20616380630001, 58.674300024586344, 60.85625963826334, 61.03611992251489, 58.3886298825664, 54.24775623506116, 51.026792141699026, 46.48365589880174, 45.061890848221324, 41.75046513157506, 42.13774427290886, 40.7189170775875, 41.22700522022863, 42.01596644616897, 41.824123321040986, 38.92906112055625, 39.37219089077365, 38.301874130002915, 40.658469430861935, 39.37468944057342, 38.605355754975356, 39.3486213684082, 36.8233210040677, 38.62346533806094, 37.01046905209942, 36.238958451055716, 38.632184766954, 37.65266303093203, 36.22727763268256, 37.05847886300857, 39.060621338505904, 37.2493923864057, 38.4369997824392, 37.63562817727366, 36.147022016586796, 37.25074560411515, 36.703167038579146, 35.860967482289965, 36.79916312617641, 37.857508813181234, 38.08007978623913, 37.815676735293486, 39.494251128165956, 40.05440089010423, 47.969088862019206, 49.58084960137644, 47.24677655004686, 39.512458770505845, 38.7896365504111, 36.66170758585776, 37.968198099443995, 39.85827453674809, 40.145105700339045, 39.8752897785556, 38.4406554314398, 34.9926253288023, 38.69889251647457, 38.52573556284751, 39.01218398924797, 39.62961996755293, 39.53571058088733, 38.3639338708693, 40.01676182593069, 39.08812499815418, 38.805996756399836, 36.94576955610706, 37.693075210817405, 39.048156046098285, 37.273530652446134, 41.843252720371375, 39.82304773023052, 38.55233707735616, 37.8922257115764, 37.35883043658349, 38.21025932988813, 40.16556870552802, 39.74810300334808, 41.000233388716175, 39.95015998040476, 44.70537093377883, 48.278995329333895, 36.57308163181428, 40.50322986418202, 39.1557192033337, 39.351751419805716, 38.102484364663404, 38.63453426668721, 38.035447136048354, 38.25198550378123, 38.66550530156782, 37.50255000206732, 39.54844259446667, 39.67889278165756, 38.03070891288019, 40.24500846862793, 38.87523835705173, 39.497192905795195, 38.17558557756486, 38.40779773650631, 37.86867187869164, 37.89517141157581, 39.48443343562465, 40.06102577332528, 38.552552807715635, 39.59827238513578, 39.694484203092514, 40.38357011733517, 40.75175516067013, 41.26076113793158, 41.66731872866231, 40.23883858034688, 41.626322115621264, 44.48283918442265, 43.65198312267181, 43.54709894426408, 44.07619530154813, 44.91906950550695, 45.534230509111964, 46.966527123605054, 49.44550037384034, 49.50490859247024, 50.60302319065217, 53.631928428526855, 62.86659986742082, 62.678051533237586, 70.81363954851705, 46.22996091842652, 2.683935477848976, 2.032166257981331, 1.9974091552918958, 0.2351858364718576, 0.539387614736634, 51.29313676587997, 67.62396027964931, 68.29125742758474, 69.76650791783487, 58.077197613254675, 47.77191915819722, 21.384391515485703, 38.238990691400346, 60.335600299219934, 60.399170152602665, 2.669322442623877, 0.11664764234615911, 0.09202176134192175, 0.05938166985288263, 0.06992971614724205, 0.04338120726207572, 0.019246771661264282, 0.040495327238233826, 0.01837987039658812, 0.017625808137499036, 0.022475209815668005, 0.0342655883380963, 0.056378275771895726, 0.045406988882009065, 0.03385914422030892, 0.882394351065159, 50.74611517690843, 66.4255428314209, 52.06663993097121, 34.20533111018519, 25.624812956779238, 47.53951088074715, 55.6433355423712, 67.8615931541689, 63.36203836625623, 73.22050786787464, 24.981442266894927, 0.30735018512895035, 0.3000142803836254, 3.395035939831888, 0.6655330619504375, 0.1622267175585993, 49.1744645949333, 68.01836244521603, 64.64973680434689, 61.20065942887337, 63.795981945530066, 63.0558346163842, 59.03279681359569, 55.16983485990956, 53.423073983961544, 48.40052212438276, 48.985739754092315, 44.26304524944675, 44.12933557264267, 43.95591582021406, 44.69058752059937, 45.46296496545115, 43.76226056006647, 40.378137634646514, 41.23544223846928, 40.57060833900206, 42.5816624395309, 41.76750782997378, 40.77849788050498, 40.51002733169064, 39.67062050296415, 41.57407614492601, 38.49752587656821, 39.054898600424494, 41.42118215560913, 39.63671161282448, 39.32074900596373, 39.92469987561626, 40.7479190826416, 38.80737743070049, 39.03198019150765, 39.353375281057055, 37.55624332735616, 39.13264389960997, 37.6578248700788, 39.93988729292347, 38.54077785245834, 38.331997932926306, 39.152455791350334, 39.70038344783168, 40.705106412210775, 40.968320984994214, 51.04929870174777, 52.62420485096594, 48.79935264587403, 40.417467240364324, 39.27556330157865, 37.986817590651974, 39.98561428439233, 40.59742950624035, 42.85283550139397, 41.83781239294237, 38.96215023532991, 38.115302670386534, 40.400883459275775, 40.49505956711308, 41.04406195302164, 42.798804852270315, 42.41229057312012, 41.35603550941714, 42.414216456874726, 41.3082218170166, 40.61122448213639, 39.484088267049486, 39.096954253412065, 40.886770986741595, 39.28901310889952, 42.61930150370444, 42.521791381220666, 39.98271957520516, 38.836536330561486, 38.94255015157884, 39.5876153053776, 40.052431860277736, 39.14417566791658, 40.59559775936989, 39.08786612172281, 46.512940314508256, 50.59950482460761, 38.07438058237876, 41.33355640595959, 39.26341964352516, 41.12236422877158, 39.224125339138894, 40.14318766132478, 38.811150750806256, 40.64662387294155, 40.123391459065104, 40.14179914228378, 40.843875946537146, 41.95495397813859, 39.25815190038374, 41.359895121666696, 39.939047905706595, 42.11587313682803, 39.57896255677746, 41.087125655143495, 39.5758128935291, 42.47876298043036, 41.11859875340616, 40.63367612900273, 41.060457460341915, 42.56353324459445, 42.797004484361224, 43.1382389222422, 42.80240166571833, 43.63671333559098, 44.334950139445645, 44.032758974259906, 46.209576360640995, 46.38190961653187, 46.368726530382716, 45.489287991677564, 47.15858597909251, 49.11383651917981, 48.002107374129764, 49.229107133803836, 50.14723985425888, 51.15921920345676, 52.447141216647246, 56.778865629626864, 63.76018639533751, 67.38632740512972, 70.82685009125741, 56.57599279957434, 4.149477856774484, 2.4618403373226045, 2.2486820720857192, 0.29112766046197186, 0.4364285539955862, 55.22000197441348, 73.3697069844892, 73.0784631544544, 74.98626478256719, 65.91233991807508, 51.124580752465036, 28.873229718977406, 49.47148607623193, 68.21990166940998, 71.24222909250568, 4.634295557775806, 0.1565364769269382, 0.06605101298661002, 0.023978310712282697, 0.1015574339356634, 0.0772910473507739, 0.03540471511622591, 0.19741197146715658, 0.10796664042338248, 0.11081705440676982, 0.08838934778806665, 0.21339670244243839, 0.11830236161908797, 0.16727562002356977, 0.20660113483186693, 0.7694060655851519, 57.14209671943419, 76.12756467634632, 60.96517209083804, 46.53220699679467, 45.223841590266076, 51.39558123004053, 60.44353608162173, 73.41393563055223, 68.03995117064446, 81.26329652724728, 28.105388495229906, 0.42579087158364637, 0.550157094915067, 8.002121525426066, 2.498996214520547, 0.6413143873214722, 53.49049168248331, 71.07213158761301, 67.74995465432444, 61.96016365481962, 67.66134046739148, 62.54765233685894, 61.40060617077736, 56.443251948202814, 55.32939687851937, 50.36238578058059, 51.94212428985104, 46.147802952797186, 48.961173949703095, 46.6968249505566, 47.78964042663575, 48.16401104773245, 45.51411267249815, 43.26800269465293, 45.23760126483056, 43.079917200150035, 46.64328067533432, 43.6470958494371, 42.01847284070907, 43.739754000017726, 41.058547266068004, 45.383030983709524, 40.34902580322758, 40.87507055651757, 43.98686332087363, 42.84557519420501, 41.945501066023304, 41.79237565686626, 44.97837182014219, 41.77814137551093, 41.17517502077165, 40.307840916418264, 40.476781322110085, 41.49702510526104, 38.99288985037035, 41.607726158634314, 40.48610087363951, 39.82859788402435, 42.13972506984588, 41.51508369753438, 44.52391424486714, 44.58374607947565, 53.44605515080114, 53.509491643598004, 50.282702830529985, 39.61772734119047, 40.392544500289425, 38.27188761003556, 41.438303301411295, 42.24948083200763, 43.8056537412828, 45.39481770607733, 41.65551631681381, 39.32886046748008, 43.05997587019398, 42.683710744304044, 42.419456743424945, 43.9330287902586, 44.84180665785267, 43.5555830309468, 45.47697174933649, 43.12636983010077, 43.662883389380674, 40.398533959542554, 41.33022239131313, 43.34501843298636, 40.98059015889322, 46.96621333399127, 43.853447821832475, 42.50754141038464, 40.54683877575783, 39.64648223692371, 38.94998696542556, 40.18478439700219, 40.422636924251435, 41.814262482427786, 40.62769843686012, 47.12600285007108, 53.360924028581195, 40.94873266835367, 42.82428456890968, 42.60937398479831, 43.171912470171534, 40.82771185905703, 43.274870764824655, 41.74396968656971, 43.51873628554806, 42.77059516599102, 42.26352291722452, 43.42876888090565, 43.64126328499087, 41.201031284947554, 44.23869909778718, 41.922339470155784, 46.70825865960891, 42.35775393824424, 45.006212803625296, 41.47553836145709, 45.551241828549294, 44.740946831241736, 45.48089411950881, 43.29662422980032, 46.7353347809084, 43.69590974623158, 45.97400665283204, 45.95289645656463, 46.60038563512987, 45.904949403578236, 46.17293357849122, 47.75631596965175, 50.00074717306322, 49.71848949309319, 49.556221039064475, 49.804142290546054, 52.91262849684685, 49.44097788103166, 54.31586427073325, 53.17539984180082, 55.75595071238857, 55.58206812027962, 61.05926582890173, 65.1348751591098, 72.14409182148596, 71.06432607097011, 65.75869675605529, 5.764844234912626, 3.6259774959856466, 6.118735180747125, 1.3857404094549919, 0.7924355878945321, 58.488724846993726, 81.14802591262325, 77.7734382690922, 82.29127914674821, 71.48765963892784, 64.85327643732872, 31.740517616271976, 56.977470920931914, 75.9559609813075, 83.64387712171002, 7.218506490030597, 0.4201836595612188, 0.23036444679863993, 0.21119737126413854, 0.2048012725408039, 0.22224055933615855, 0.1803856213847476], [0.01975660892053237, 0.0616955848020171, 0.018119463704586513, 0.04200093898802035, 0.027113944975539084, 0.09991665746295646, 0.05089860589754197, 0.08329932938420004, 0.09870636877754042, 28.94996108547334, 67.65841437924293, 44.89840645943919, 30.278303123289543, 30.617858786736768, 37.17141566738006, 41.23049612968199, 66.68107740340695, 57.13853520731772, 66.36521677817068, 30.986794963959728, 0.08809539219064098, 0.08570132912286828, 2.4029525681849453, 0.11453975908338063, 0.8236671539564288, 57.86164768280522, 64.71629158143075, 58.795422815507465, 57.295292731254335, 55.52486819605674, 56.65669556586974, 54.38043825088009, 51.327198628456365, 49.77638367683657, 44.84699203122047, 45.428848189692346, 40.93371783533404, 42.35383941281227, 39.48928932989798, 40.88681805518366, 40.40817122305594, 41.640634844380045, 37.95148488013975, 40.978495613221206, 39.575357898589104, 40.114652418321185, 37.79178950094408, 38.91066128207792, 38.283438990193034, 39.08585394582441, 37.49263032790154, 39.29834834990963, 38.205772138411, 37.04351502080118, 37.18346518854941, 36.138926244551136, 36.84264259953653, 38.67890411807645, 36.30938460749965, 38.21049467209847, 37.35289981288295, 37.83599853515625, 36.09972215467884, 37.26993383899812, 35.08294966913039, 38.250471468894716, 37.77031844662082, 37.41412408890263, 39.02754006847259, 39.44956356479276, 36.83463311964466, 49.458561866514145, 50.28258123705464, 47.01744733318206, 40.139402574108495, 38.578691482543945, 37.06435849589687, 35.26899553114368, 37.87171171557519, 40.69796769849716, 38.494238930363814, 40.039511572930124, 36.72426154536586, 37.15431805579893, 35.89679833381407, 37.76364649495771, 37.10396266752674, 39.91041852581886, 37.98129097107918, 40.37783953451341, 38.72410551194222, 37.97414049025505, 37.49180663016535, 37.35893241820797, 37.66817600496354, 38.632780967220185, 39.81878019148304, 40.02839165349161, 37.534211374098255, 38.72273660475208, 37.39320608877367, 37.71018066713887, 38.25091861909436, 39.34406357426798, 38.31776365157097, 39.63282062161354, 46.973889412418494, 47.568171639596265, 36.91379047209217, 37.98142433166504, 39.95223491422592, 38.52745748335315, 38.437576370854536, 39.13276157071514, 38.93606255131383, 38.249706606711115, 37.409625130314986, 37.704983526660556, 39.13005121292607, 39.391061413672666, 38.93266185637444, 40.35195973611648, 39.27178213673253, 37.63088603173533, 36.610355915561804, 37.56819871164138, 38.07882070541382, 39.140225841153054, 39.367068275328606, 37.96527985603579, 39.478243935492735, 40.15556666158861, 40.87205033148489, 39.7070397100141, 41.411866526449884, 39.96933252580705, 42.46232432703818, 43.37478137785389, 41.54132827635735, 41.59096194851784, 43.174924850463874, 43.687574709615404, 46.875104519628714, 45.78417570360246, 47.18190054739676, 48.096236413525, 48.34878606180991, 47.48775520632344, 52.43862967337332, 53.16803363061721, 63.27909592659243, 61.569942735856586, 67.97469862045781, 48.452893610923525, 2.2050922820644994, 1.5355807110186548, 0.6592763912293219, 0.17805577946766732, 0.9082083271876459, 55.43723067929668, 68.05479341937651, 68.32950838150518, 72.76377139552947, 57.02767725913756, 41.03560924530029, 21.07026653905069, 33.47291869501914, 61.45414652362947, 48.71488832658338, 4.6595865103506275, 0.14550289559748866, 0.03136481364978658, 0.053361758604765906, 0.15769235038709256, 0.0474393550276516, 0.044117762496875185, 0.019367007245760293, 0.05299779406237987, 0.1177361000689768, 0.05357921266207292, 0.007899113913862816, 0.08861962615722611, 0.05939968057998246, 0.049740139229763905, 0.049841691845006524, 35.81382059281872, 74.80502774638515, 51.74487221625544, 36.35233456088651, 33.491110647878344, 41.95703675670009, 49.29830558838383, 72.0594862968691, 60.95737441893547, 72.38174823022658, 32.93208660617952, 0.07334261486727385, 0.18066452335446112, 2.608110178862849, 0.6090682144126585, 1.2763450150528264, 60.81221142122823, 68.34910454288607, 61.70166769335347, 59.93016450635849, 57.61250657420005, 58.68869120074857, 58.158994720828154, 51.78741032077421, 52.27971484584194, 47.39344966027045, 47.775849373109885, 44.11580731791835, 44.403889717594275, 43.49169154320994, 44.90782799259309, 41.94162184192289, 43.72336633743779, 41.23810160544611, 42.39859365647839, 42.40453996965962, 41.733073342231016, 40.60174803580008, 41.66469466301703, 39.39093589782715, 41.25437944166122, 41.03489929629911, 41.288817851774155, 38.64961577999977, 38.58177054312922, 40.63299755896292, 39.48982277224141, 39.08129615168418, 40.69448071141397, 39.54275515771682, 40.211354532549464, 38.91083778873567, 39.62139475730158, 37.90937431396977, 38.42305575647662, 36.911240931480165, 40.13043995826475, 39.06954080827775, 39.745023942762806, 39.069854597891535, 41.24675435404624, 39.63507206209245, 49.5020374175041, 51.0258468504875, 47.97931840342861, 40.615750897315245, 39.652122605231504, 37.032418635583696, 37.15072124235092, 40.61213839438654, 40.634648876805464, 39.5583701133728, 39.97993469238281, 41.275320976011216, 37.97119086788547, 38.253377945192405, 41.24664845005159, 40.19334693108836, 41.41405520900604, 41.05138501813335, 41.83783984953358, 41.715410909345074, 40.63196989797777, 39.182567827163204, 40.278176030805035, 40.87857715545162, 39.99453767653435, 40.989446870742306, 41.46842318196451, 39.698241833717596, 40.676151475598736, 38.83827394054782, 39.13440112144717, 40.09815492937642, 39.02827355169481, 40.525826638744725, 38.959898794851, 48.26746748339746, 48.983974687514774, 37.8632237065223, 37.6740477931115, 41.139591278568396, 41.5324088065855, 40.44484146179692, 40.532851603723344, 39.28303933912708, 40.13397401379001, 39.65090274810791, 41.31301887573735, 40.806942908994614, 41.22571868281211, 41.82874779547415, 42.128095242284964, 39.486461301003736, 41.13261730440202, 39.28424742914016, 41.367257410480136, 38.99587477407148, 40.98646586941135, 41.992294942179036, 42.29472144957512, 41.63965032946679, 43.91813555071431, 42.79956579208375, 42.660070619275494, 43.363084870000044, 43.599894046783454, 43.40690951193533, 44.74920342045446, 44.40561163809992, 46.12454722004552, 45.0801573261138, 45.919744583868216, 48.96806163172568, 48.644352343774614, 48.90593521056637, 50.47539318761518, 52.016700313937285, 52.560368276411495, 54.28960792479977, 57.791488247533, 63.45708131790162, 65.46511911576795, 68.84605315423781, 57.70960484781573, 2.58767070789491, 0.45695983294037085, 2.064663830303377, 0.4894450252815601, 1.3189320266246796, 58.9463242407768, 72.9892292330342, 73.7131340272965, 77.72005481104698, 64.33812802837741, 51.119728780561886, 21.59995517423076, 40.76269857345089, 70.53321361541748, 58.874560556104115, 5.984991183204036, 0.2932073440282576, 0.030354948887120814, 0.0213530327328631, 0.04607426295537622, 0.022876595837935325, 0.09495777798996818, 0.15704122161672962, 0.1434663734248569, 0.18009363463328731, 0.1512580545198533, 0.05300697562615237, 0.2568971359681699, 0.16159323945401177, 0.3235609733289288, 0.2641988731920719, 41.60229367594565, 85.42436645876977, 59.204169088794345, 45.93741093912433, 39.165893831560695, 49.65151502240089, 56.1403626011264, 78.00414423788749, 64.67019588716569, 77.61919498443604, 37.41323371087351, 0.22170141729856693, 0.4975303172344162, 8.817939219936248, 1.7940364681905316, 1.8324389236588634, 66.61433435255482, 70.37410659174766, 64.60338615602063, 61.60652276008361, 60.40460263529132, 61.4165819844892, 59.596013869008715, 55.640684020134714, 53.99861512645599, 49.19667305484895, 49.568807924947436, 46.88522423467329, 46.970500484589614, 45.95915655935965, 47.1200212355583, 44.318182006959, 46.615023920612956, 41.82016172716695, 45.72766219415973, 44.005737766142815, 45.10199708323325, 41.84126800106418, 43.37688769063642, 43.83287891264885, 42.78066781259353, 42.86193147782357, 44.19570207595826, 41.55304047369188, 41.13699466951432, 43.78791678336359, 40.48134696099066, 40.78564443895894, 43.616564120015795, 40.82427978515625, 42.27051258087158, 42.15625786012219, 42.5399362656378, 40.03948411633892, 41.21825441237419, 39.8026906290362, 42.6362382981085, 42.007062665877804, 42.228268654115745, 42.11154284015779, 45.44984463722476, 41.6701546022969, 53.23656920463809, 53.98478092685823, 50.59876741901521, 40.71608512632309, 39.76786782664638, 38.0441391083502, 38.350990049300655, 41.43671081912133, 43.45473497144638, 40.58356785005139, 41.967815429933616, 43.66356980416083, 40.14191681338895, 39.53629893641318, 43.512017265442886, 41.82233079787224, 44.77169821339269, 43.012723076728086, 45.05794494382797, 44.70729289516326, 43.782095986027876, 41.49782919114636, 43.280824922746234, 42.945725071814756, 44.11403048423029, 43.23234834978658, 42.919233383670935, 40.49180007749989, 42.12140367877099, 39.848029305858, 38.601492220355624, 38.78006596719065, 40.10159092564737, 39.73511603570754, 39.97721256748323, 50.92195503173336, 52.11478702483639, 40.21013467542587, 41.361871996233546, 42.934193303508145, 42.28515478872484, 43.38045704749323, 41.50682318595148, 42.19238681177939, 41.43699322977374, 41.67065274330878, 42.423861565128455, 43.89879434339462, 44.28308071628694, 43.587840603243926, 45.683861086445475, 43.90874147415162, 44.81215353934996, 41.86788520505352, 42.76354666679136, 43.49691614027947, 44.85352669992755, 43.82815637896138, 44.750148711665986, 45.016626696432795, 45.961462913020966, 46.506009486413774, 44.85635865119196, 45.41815973097279, 46.445942309594926, 48.08587743389992, 48.44489982051235, 47.57747942401517, 46.95917267953196, 46.984189556490996, 48.69806135854414, 52.95607659124559, 52.651881094901796, 51.98344253724622, 54.40936965327109, 54.25544015822872, 54.34744719536074, 58.67036980967368, 61.683616945820475, 65.13884459772419, 67.64625503170875, 70.82149997834237, 66.0415506362915, 5.11700939747595, 2.4477882010321466, 4.733019653827914, 0.8441824982723883, 1.670038702507173, 63.743284902265, 79.30488847917127, 79.43212232282086, 83.98954776025589, 72.46861304006269, 56.33438264170001, 30.004627589256536, 51.663792902423495, 79.6433105776387, 72.96083911772698, 9.031161223688434, 0.5267373580605753, 0.16702906228601935, 0.1442571447020577, 0.16631693759512517, 0.1121499861079839, 0.13074701561802818], [0.05016472430959825, 0.03483304498536933, 0.10119859835193043, 0.1255108123164504, 0.05548500576086583, 0.04129365214236802, 0.013437374671470496, 0.18063668371929278, 0.04519136194440146, 20.098834691509126, 63.52811544172226, 49.77321440173734, 37.413108195028, 29.91668804999321, 41.81978910200058, 41.0541699009557, 65.06128757230698, 56.71808065906648, 68.08093993894516, 39.645670306298044, 0.05216345536492525, 0.2705171373822997, 1.3732243713832673, 0.5098733113658044, 5.347046111860584, 67.01010150294151, 60.86947410337387, 60.69690550527265, 55.1135096242351, 54.133474057720555, 50.59486466069376, 49.439126522310325, 48.35595223211473, 46.30228942440402, 43.89456602834886, 42.526306029289, 42.047008083712676, 41.73632890947404, 41.696136382318315, 39.9599737505759, 40.73378286054058, 40.11816293962541, 38.40249469203334, 38.68664295442643, 39.24014429892264, 38.64673676029329, 37.3384262669471, 37.53607842230028, 39.927476913698264, 37.95483458426691, 35.2903881380635, 37.99494866401919, 36.83528815546344, 38.287165241856734, 36.597286578147646, 35.69404709723688, 36.822952301271506, 40.67084450875559, 37.57645137848393, 38.69443278158865, 37.15834240759573, 38.5428802428707, 36.74354783950314, 36.817249175040956, 35.589645370360344, 38.45000243956043, 37.985864454700106, 37.90625995205295, 38.732189516867365, 37.17506739401048, 36.32248140150501, 44.78164926651986, 50.89998191402805, 49.80470318948069, 41.349932301429014, 39.39765099556216, 37.346573029795, 38.07432174682617, 36.81904562057988, 38.26941259445683, 39.870677071232954, 38.193157795936834, 36.26576000644315, 37.71559746034684, 38.176577937218454, 37.142723529569565, 36.69241189956665, 39.60328125184582, 38.329169904032064, 39.69624926967006, 36.43447291466498, 38.4255386167957, 37.38308637372909, 36.04081207706083, 35.694666831724106, 38.12186871805499, 40.621312818219586, 41.77451318310153, 38.78252137091852, 37.15807176405384, 37.196883616908906, 39.93786334991455, 37.604147234270656, 38.9319872087048, 38.689243485850675, 45.34370530036188, 48.161885123099054, 47.24381516056676, 41.4097249123358, 37.95505423699656, 38.2710599899292, 38.94562136742377, 39.49294497889858, 37.59822053294028, 38.75643368690245, 36.752604592231016, 36.9861582017714, 37.0784084258541, 38.058569508214156, 38.496035375902736, 39.8748779296875, 38.48104799947431, 38.473913208130874, 36.623852791324744, 37.51337574374291, 37.569795116301506, 37.065558741169596, 38.60075481476323, 39.11210244701755, 39.24015606603315, 38.879254864108184, 40.164839144675966, 40.24481627248949, 40.99481659550821, 40.65468042127548, 41.46475184348322, 42.72552321034093, 41.02072777286653, 43.781633146347545, 42.61724618173415, 44.14804527836461, 46.39204109868696, 47.30479232726559, 47.66992576660649, 49.25725798453055, 46.06097344429263, 49.2941164970398, 48.32919774516937, 51.15940355485486, 55.44503227356942, 63.293459646163456, 65.55718891082272, 69.67736028855848, 51.37197640634353, 0.933444060144886, 0.0749217902099894, 0.8516826216251621, 0.7838473745411443, 1.8753296737709355, 59.59247589111329, 67.58075929457142, 69.4408021434661, 70.16274575264224, 58.253770951301824, 28.98539773879513, 29.358505356696348, 45.70766595102126, 58.37036340467392, 54.42684773475894, 3.866255518890197, 0.06469079323353306, 0.1384005710602768, 0.013829639459389352, 0.07214196356794528, 0.056484352136331226, 0.02012851396425357, 0.05303472716120943, 0.07505971667987686, 0.07675147630394467, 0.051758401696720434, 0.09189869697776534, 0.12417029634478594, 0.02470270813172383, 0.1045890506957808, 0.025525827471527363, 25.78881313723903, 74.38062729374056, 56.74898501365416, 42.75164619568856, 29.382859353096258, 44.46474921318793, 47.68129279536586, 71.45644541709655, 60.6224589194021, 72.65991487810689, 40.06235937918387, 0.049928554724301064, 0.2304319851100445, 1.3191307191887212, 0.2907936154834686, 5.864577360691563, 69.76284442409393, 61.500897253713305, 64.38984447909941, 55.34579238583965, 58.08789391671458, 52.478575091208185, 53.338586130449855, 50.557806107305716, 49.46484158116002, 45.681578267005186, 46.29136170110395, 43.951307035261586, 44.0710138505505, 43.02600814450172, 42.55337038347798, 41.47133358063237, 41.91891524099535, 40.7484721368359, 41.41108205241542, 40.87066573481406, 40.415537434239546, 39.54980757928664, 40.78997865799935, 42.06372522538708, 40.35229313758112, 39.33389286841116, 40.11921413483159, 39.32231010929231, 39.625046483932, 39.75086435194939, 38.77617889834989, 37.94600140663886, 42.54728286497055, 39.72002667765464, 39.666690288051484, 39.74402373836887, 39.35430096041772, 39.08659135141681, 38.8923438133732, 38.0899602367032, 37.70301057446388, 40.95731089192052, 40.567560657378166, 40.49385539947018, 38.03858110981603, 37.41791309848909, 49.18069724113711, 52.90884340963056, 50.78396997144146, 41.17346486737652, 41.23620317828271, 37.96036512620988, 39.186219553793634, 37.610336734402566, 39.959440308232466, 41.03028266660629, 39.80502443928873, 37.97580749757829, 40.30338118153234, 39.454517518320394, 39.88069088228288, 40.37597248631139, 41.49563266384987, 39.44750039808212, 41.34416249490554, 39.10334379442277, 38.850299927496145, 39.47901664241668, 37.49041418875418, 37.50189104387837, 39.41871020101732, 41.28867664644795, 43.45933198928834, 40.071172944961056, 37.72004935049242, 38.70934955535397, 40.18567869740148, 38.461612655270486, 40.929771930940696, 38.43121820880521, 44.58786456815658, 50.43825618682369, 49.91024632607737, 42.87541658647599, 40.465818297478464, 39.45954991925148, 40.302349598177024, 40.580947706776286, 39.611384868621826, 40.33346968312418, 38.86243574080929, 39.33732494231194, 40.13236191964919, 40.58343841183571, 40.13072236891716, 41.36706913671186, 41.84895584660192, 39.10049223130749, 39.95998551768642, 38.68251269863498, 39.89061447881883, 39.52996823095506, 41.57852019033125, 41.238615435938684, 43.05350395940965, 41.62792244265157, 42.183451652526855, 42.43253000320927, 42.8200170301622, 42.20290660858154, 43.073464901216575, 45.394527450684585, 44.20012650951263, 44.368502093899636, 46.26462290363927, 46.088437880239184, 48.770966452936975, 49.815568154858006, 51.386740207672126, 51.431780784360825, 49.34319711500599, 52.01310350048927, 51.11589270253336, 52.167582127355764, 58.522743563498224, 66.31132341200306, 67.83400320237683, 70.65104161539386, 54.58809637254285, 1.4250964911714679, 0.2748424085157533, 1.7005314533748936, 0.5101180917793705, 2.305555213843623, 64.60111902606103, 72.20579070429649, 74.90310269017374, 75.60257111826252, 68.39221923582016, 41.20954282822148, 28.396349914612312, 48.803071052797385, 64.81772799645701, 63.984749932442945, 5.723131299018861, 0.1945926146882196, 0.17263454294973807, 0.03517997173231936, 0.03192328983136723, 0.021252137038015553, 0.019028212522126494, 0.12383809763818018, 0.14809461701060497, 0.22328228569559513, 0.26686363342788916, 0.1603157571967571, 0.13595829807942914, 0.16614107445122736, 0.2064868038700473, 0.17332956855816228, 28.685626676005704, 84.25390766512963, 66.08581850605627, 51.64823678232009, 41.29276767853768, 58.269582025466434, 51.99216588850945, 76.59479741127261, 66.54242161781558, 78.17617154890492, 45.96065490476547, 0.14564911113871684, 0.5372368075674581, 6.266436932548401, 1.3790351176454176, 7.716527869624477, 74.80644764438753, 64.7829326506584, 66.51622018506451, 58.34276168577133, 60.103258702062796, 55.46893127502934, 56.554215800377634, 54.551598718089444, 51.86062136004048, 48.38203207139046, 47.82646363781345, 46.43754843742617, 47.522852574625325, 45.78446203662504, 45.01943903584635, 45.079651340361565, 44.60958665417087, 43.03370383477981, 43.10477718230217, 43.838931129824736, 43.574010326016335, 41.91537334072975, 43.49755156424738, 44.00077204550467, 44.514229912911695, 41.281314357634514, 42.48930238908337, 43.215395865901826, 43.96504709797521, 42.79801645586568, 41.08380340760754, 40.11254610553865, 45.30769401980985, 43.129645009194654, 41.7666409861657, 42.633665223275464, 42.26335033293694, 40.74573040008545, 39.96779887906967, 40.53772318747736, 42.187444625362275, 43.10230216672344, 43.43167927957351, 43.6607692318578, 39.517769659719164, 40.84930450685563, 49.583289315623624, 56.212200810832364, 52.6750740697307, 42.63210804231706, 42.30530008192986, 38.42173391772855, 41.712500510677216, 39.414297534573464, 41.8078847085276, 42.596845934467936, 43.04769885155463, 40.49527921984273, 40.85378385359242, 43.33077630689068, 42.220243484743186, 42.34410409004458, 43.68653528151974, 40.5296980181048, 44.97624981787897, 41.253516520223315, 42.33077195382888, 41.50461881391464, 40.534279346466064, 39.43989884468817, 41.69692870109312, 45.67267056434385, 46.15507502709666, 42.332952791644686, 37.96358539212135, 39.97165064657889, 39.72324302119594, 38.80552214960898, 40.154605680896395, 38.94246778180523, 44.82462275412775, 55.0448916804406, 52.37660523383848, 45.076246723051995, 43.085800755408506, 41.517829356655, 42.06639635947443, 43.43045157770957, 41.753042128778276, 42.80624951085737, 40.730103677318944, 42.79297228782408, 41.35724359943021, 42.567381089733495, 43.34883489916402, 45.16681425033077, 45.03310457352669, 42.80767333122992, 42.1564696681115, 41.28638598226732, 44.02748338637814, 42.37232554343439, 44.71771071034093, 45.78164185247114, 46.946628939720895, 44.63114792300809, 45.11507818775792, 42.966321437589585, 45.56395423027777, 44.32339091454783, 45.4795212899485, 47.272989749908454, 46.18111956504084, 48.18148912922029, 48.24971875836773, 48.0818844610645, 51.56083853014054, 52.95127953252485, 55.56829275623445, 55.62788924863262, 51.93391084671021, 53.932103495444025, 54.305313094969726, 56.7185317316363, 60.776164839344645, 68.22415351867676, 73.62578284355902, 73.55541552266767, 62.157058792729536, 3.220956248621787, 0.8691646867702085, 4.529264780782885, 1.763477895048357, 2.71041490858601, 70.63947062338553, 78.5785282811811, 79.94644703403597, 80.13774102733981, 72.82997315929782, 43.099195649546964, 42.656144326733006, 62.4579438086479, 73.52675868618873, 78.31285830466979, 8.311541618839387, 0.3984954039896689, 0.3329304431474978, 0.19163481049960662, 0.1994704650414567, 0.12441513804538597, 0.09698072508458169], [0.036643655490010016, 0.06953516554447912, 0.021509054199522062, 0.0603989809901724, 0.021983304759487513, 0.03210693451335594, 0.04428156741684483, 0.1373528079279969, 0.16774645766183255, 14.255966178832518, 67.19952060330299, 52.01309173337875, 34.87794699207429, 18.166357432642293, 38.48040080839588, 42.226358459841826, 60.38858759787775, 62.13920024133498, 61.90539560010357, 47.342878541638775, 0.7129086133453154, 0.35683119128788676, 0.3163445782997916, 0.652238555973576, 23.345511882535874, 71.61028861999512, 55.714401045153224, 61.37361241925148, 53.20073835311398, 53.131296711583296, 49.334548288776034, 48.79559501524895, 44.35990425848192, 48.07182358157251, 42.752128647219756, 42.948011813625214, 40.57409532608525, 41.48823507370488, 39.62817261295934, 40.14907121658325, 39.968147970015, 38.74720434988699, 39.449736149080344, 39.16163805992373, 39.27029163606706, 38.54833625978039, 37.41221781699888, 37.90913112701909, 37.41494386426864, 37.08759069442749, 36.939407471687566, 38.446119293089836, 37.206316917173325, 37.241900659376576, 35.273514101582194, 38.74523924243066, 35.9767323155557, 37.61369428327007, 38.19110247396654, 37.747168617863814, 38.11390238423502, 37.99572137094314, 37.138373621048466, 36.912170533211004, 36.98993152187717, 37.22121407908779, 37.48474636385518, 36.73376937066355, 39.2206108954645, 40.015549813547445, 36.74089239489648, 46.74167333110687, 48.67536260235695, 51.34280573937201, 40.401687545161096, 39.433497536566954, 38.57305503660633, 36.95700322428058, 35.927612473887784, 39.80672282557334, 38.74983233790244, 38.478400399608, 36.65511015922793, 37.733781568465695, 38.61324364139188, 38.962546394717315, 36.84575696145335, 38.37808970482119, 40.31334400177002, 38.76956578223936, 37.84295289747177, 38.57445140038767, 36.93166471296741, 36.64803812580724, 37.00959044118082, 37.97273628173336, 36.92879746037145, 39.97567892074585, 39.43776899768461, 37.28827876429404, 36.41860692731796, 37.04810419390279, 39.129133378305745, 39.22135614579724, 40.80982977344144, 43.76095048842892, 46.05014378024686, 50.82655514440229, 41.20915451357442, 40.161042290349165, 38.83736787303802, 38.88203974693052, 37.974603329935384, 38.56534757921773, 39.260991696388494, 37.21055307695943, 39.15530735446561, 37.50381692763298, 39.16070453582272, 38.252150243328465, 39.05478092931932, 39.499232538284794, 39.80446746272426, 37.5498184850139, 36.45705792211717, 37.18694825326243, 37.435979535502774, 37.25748815844136, 37.32580800210276, 38.35558314477244, 41.9298037405937, 40.71368463577763, 40.8275039734379, 42.433094824514086, 41.3782282798521, 42.131519471445394, 40.4150196813768, 41.40062501353603, 41.54752954359978, 42.07457450128371, 43.7812840554022, 46.69656215175506, 46.96064356834658, 47.244944803176395, 48.09706795600153, 47.15482834846743, 48.74944440780148, 46.35215843877485, 52.53370792635026, 58.705604460931596, 64.99084572638235, 61.29703990874752, 69.43101975225633, 48.12326154401226, 0.3648807222564375, 0.12991335873882617, 0.23972014235633038, 0.5071222283426793, 3.3506653529982415, 64.90258847513508, 61.80931714273269, 68.72242004640641, 72.19185060070407, 59.69077833237187, 33.96856115710351, 28.826794739692446, 43.143906747141195, 62.362622368720274, 51.378597367194395, 1.4365767783695653, 0.04877669173443029, 0.09267113577093809, 0.055987540286995714, 0.08099594814402443, 0.09502540823192367, 0.08127131078752779, 0.07431126409961332, 0.051039818884624596, 0.016431609213712717, 0.03724470892320237, 0.02735096874887184, 0.15087308001614388, 0.03814354073256254, 0.07901911954245261, 0.22735523811030775, 18.01197882621519, 75.04457473754883, 59.749076520243, 44.242495952113984, 23.72512279018279, 44.06275726133778, 45.26949013433149, 63.76329683488416, 65.66850577631305, 67.52566568313107, 50.896471392723825, 0.7622438789375368, 0.19043965205069513, 0.38422346175197636, 0.6677111418497178, 24.722885508691114, 73.30681570114629, 56.76158366664764, 64.49949825963667, 55.02190659123083, 56.70669794082642, 51.05448799748575, 50.341569762076105, 46.867044048924605, 50.558857302511896, 46.5360430748232, 45.728128956210234, 44.33879013984434, 43.837883856988725, 42.76096182484781, 42.16744838222381, 41.6542846925797, 41.12269763023623, 42.138897449739524, 41.387763561741004, 40.47448281318911, 39.97998960556523, 40.660552209423436, 39.38700568291449, 39.60976492974066, 38.21960241563859, 39.46365664082189, 41.598740008569536, 39.929171377612704, 39.85699976644209, 38.505166653663885, 40.70537705575266, 39.11645627790882, 40.35254416927215, 40.17222889008061, 39.408857207144464, 38.05401955881427, 38.90436587795135, 37.91388503966793, 38.22748637968494, 37.87009962143437, 40.92178598526986, 39.033753102825536, 38.18232028715072, 40.92919926489554, 40.72636565854473, 39.28674205656975, 48.25625734944498, 53.53805042082264, 52.205515369292236, 41.46432430513444, 39.73073082585489, 39.09685227178758, 38.432175267127256, 37.55354081430743, 38.71389166001351, 39.96496300543509, 40.696332070135306, 38.09495733630273, 41.54938874706146, 40.4859322117221, 40.61831612740794, 38.01329358931511, 41.72708388297789, 41.28518573699459, 40.772355448815134, 41.939468460698286, 40.37379557086576, 40.03657371767106, 38.80217244548183, 38.55646341077743, 38.9539054132277, 41.06536826779766, 42.10493756878761, 41.75235571399812, 37.488092145612164, 37.734883754484116, 38.20263424227315, 39.9452099492473, 39.70531386713828, 39.844789428095666, 45.661829133187574, 48.74665560260896, 52.06020724388861, 42.33492574384136, 40.44201343290268, 41.884935748192575, 40.076821158009196, 40.333352012019006, 40.49887603329074, 39.766334179909, 39.53620872189922, 42.616477397180375, 39.30489478572723, 40.43019140920332, 40.488262099604455, 41.24836644818706, 41.074589760072776, 41.289723919283965, 39.97785191382132, 39.69362912639495, 40.546430849259906, 40.17308788914835, 39.582837858507716, 40.28028626595774, 40.668553844574966, 44.40283460001792, 43.04847940321892, 43.09619111399497, 43.0360572568832, 42.530816754987164, 43.78142918309858, 41.942539676543205, 43.05304896446967, 43.61017065663492, 43.78805014394945, 46.64363368864983, 47.26428208812591, 49.443335225505216, 50.40137021772323, 51.92984727121169, 49.72414947325184, 51.644486996435354, 49.21142116669686, 55.334625397959066, 59.76336963715092, 66.56237079251197, 65.5023463310734, 71.86890617493661, 50.878910941462365, 0.6829067716194738, 0.6451792089689163, 1.7451536847699074, 0.9408166451800255, 3.535632072917877, 70.42544257256293, 68.02470884015484, 75.34727973322715, 78.1781013550297, 65.57466699231055, 35.886498189741566, 30.669704675674442, 52.31526328671364, 69.61402969975626, 62.42387017896099, 2.101373537894218, 0.06237749881561726, 0.05867029209771465, 0.04516997276955555, 0.12236625887453557, 0.012847354819607592, 0.0764205799468102, 0.22295629996205532, 0.1961447241445703, 0.08836385238194659, 0.16701177934244757, 0.13575055035612277, 0.15985731486110918, 0.12792681614237447, 0.2464699591960638, 0.2964151686718387, 21.63969466763158, 83.33863043016004, 66.90274623132521, 50.03970023124449, 29.22548797822768, 49.83137138428227, 52.12232582030758, 70.93291882545718, 73.00970400533369, 72.06612294720065, 57.61483646208241, 0.9004672232174105, 0.7712143395216234, 4.037765567341159, 1.1970100527809513, 29.394604890577256, 75.38655834813272, 59.62482760029455, 67.18456852820613, 57.87209687694427, 57.59081586714714, 54.01135498477567, 52.024580355613466, 48.717798725251235, 53.03348456659625, 48.80161585346345, 48.51708712116365, 46.08464887065273, 46.096972957734145, 44.48022296351772, 44.70514343630883, 44.22469231390184, 42.47295002783499, 45.104785888425766, 44.191469838542325, 44.880665579149806, 41.55665297662058, 43.28807346282467, 42.86736396051223, 42.57336662661645, 40.61652360423919, 41.60023050923502, 43.84078641091624, 42.87772294013731, 42.27391719818115, 41.05809619349819, 45.52387937422722, 41.00569725036621, 42.80682217690253, 42.20570718088458, 40.99120017020933, 41.131683780301, 41.54373268927298, 40.45087406712194, 40.64052458732359, 39.87563886950093, 42.97907306301979, 42.05507639915713, 40.06472849076794, 43.95486854737805, 44.56358901916012, 40.61024388959331, 53.0521942723182, 55.70971773516748, 54.78897271617767, 41.17291965792256, 40.24152932628509, 38.19513074813351, 39.53046637196695, 38.63421655470325, 41.60022658686484, 43.9124128126329, 42.80734777450562, 38.475839091885476, 44.081168866926625, 42.90315951070478, 44.080882533904045, 40.32705660789244, 44.26672051029821, 44.29003900097263, 42.29477244038736, 45.622601509094245, 42.69983560808244, 42.55240940278576, 40.61726885457193, 40.4046057885693, 42.023924935248594, 41.7578705664604, 44.174587957320675, 41.555205622027, 39.407825623789144, 38.70615282366353, 37.449558781039336, 38.90755084253127, 39.79837602184665, 40.42725747631442, 47.72628238124233, 52.07439837917205, 54.73413405879852, 43.79270991971416, 43.9236347136959, 43.34663444949735, 41.41106636293473, 42.351552671001805, 40.805601458395685, 44.026949944034705, 40.72960945867723, 43.90265003327401, 41.36400968797746, 43.30140559904037, 42.507902268440496, 45.427847985298406, 43.50172496611073, 44.579086303710945, 43.8474936639109, 41.960170730467766, 42.23392863427439, 42.251394948651715, 42.91970406809161, 42.315537468079604, 43.217427653651086, 49.746930599212654, 45.546856618696644, 47.02719834543044, 47.37689725814327, 45.55547406596523, 46.39216661453248, 44.57257909159507, 45.56423664093018, 46.91137859898229, 46.99346203957835, 48.92550783772623, 50.84734762868574, 51.45631913215884, 51.88706205737207, 54.60015373845255, 53.123777527962964, 55.47543848714521, 53.604224727999785, 57.3871938643917, 64.13210161270635, 68.54476805656188, 67.95489849582796, 73.62485716419836, 55.332185683711884, 1.3346934582917922, 1.3400997101299226, 6.0363055909833605, 1.3147680629645626, 4.713147455646146, 76.21129943478492, 73.08600979466593, 80.07107642389114, 82.31122047670426, 72.00083901805263, 47.62556768232777, 40.81697240952523, 62.57296731395107, 79.01082838735273, 74.47940826416016, 3.213112734017834, 0.3795056778096384, 0.18028434456115772, 0.21193522118753005, 0.24812533730460754, 0.1879803106308945, 0.19530352896019337], [0.04031228968092511, 0.031532512211631385, 0.0611943717775566, 0.04437540935712957, 0.059295247474144545, 0.057854377814838966, 0.05039064746890819, 0.08310374713713124, 0.23532494271714843, 8.548433165396414, 59.81228943794005, 50.923786778603834, 32.06628418737842, 23.251851566376228, 39.77622639748358, 43.38569341167327, 62.56543636322022, 61.92858073019213, 59.043948111995576, 57.322674797427275, 4.133283861221806, 0.3363253158186713, 0.325371851964343, 0.045142922204949205, 43.092060858203524, 68.38956771358367, 59.238360389586425, 58.869940004041126, 53.08338103755828, 54.50999413767169, 50.23472832095239, 47.97157172233828, 45.443933625375074, 44.69118372086556, 46.12261741392074, 43.74533161040276, 39.65696673239432, 40.07913535641086, 39.75147624169627, 38.901400566101074, 40.17853606131769, 39.72397258204799, 40.08881576599614, 38.83888583029471, 39.355516895171135, 37.730980996162664, 37.3522840007659, 37.40742468064831, 36.361152049033876, 36.312683320814564, 37.69227112493208, 37.808106560860914, 36.20682247223393, 35.82001009295064, 36.911954802851525, 37.57890285984163, 35.50800515759376, 37.95994151023127, 39.76135276979016, 38.16239072430519, 37.52171470272926, 36.65598877014653, 36.70288070555657, 35.59086914985411, 38.02538233418619, 37.6029783679593, 37.62790503040437, 36.26028830005277, 39.97370989091935, 37.72745478537775, 38.91964350977252, 43.02971478431456, 48.45449001558366, 49.0656933476848, 43.39389901007376, 39.58359487595097, 37.94340871995495, 37.840069955395116, 37.54734346943517, 40.44132309575235, 40.05794671274001, 39.37098280076058, 38.90636236436906, 37.98094580250402, 36.62043640690465, 36.980878691519464, 37.8332999444777, 39.815693286157426, 38.56897184925695, 39.8307159639174, 38.95724335024434, 36.1720859619879, 38.587210870558216, 38.04175430728544, 38.41416374329598, 39.50028765586115, 39.17955936924104, 39.30008988226614, 39.88544087256155, 36.09976137838056, 37.40606361819852, 39.0964953361019, 38.758842022188254, 38.707784529655214, 40.47750303822179, 43.18608007123394, 51.85904064486104, 48.13616614187918, 40.624948855369325, 38.26843592428392, 37.934720670023275, 38.248408302184075, 38.38516958298222, 39.379106029387444, 38.653746035791215, 38.594216223685976, 36.47506552357828, 39.39598006586875, 40.946708725344756, 38.65113765962663, 38.60239436549526, 39.475976805533136, 38.26012834425896, 35.984000467485004, 37.55083045651836, 37.12526505993259, 37.62463377368066, 37.3522840007659, 38.386483576989946, 39.420891038833126, 40.26795433413598, 38.644316657896965, 39.95223099185575, 38.21259314014066, 41.227526895461544, 40.375250770199685, 40.54634063474594, 38.498424099337676, 40.04258278877505, 42.223244097925004, 43.48853403522123, 47.03914980734549, 47.33693222845755, 46.49916495046308, 47.048496815466116, 46.946040584195046, 47.89095917055684, 53.43984211644819, 57.14547780252273, 60.30213855927991, 65.77799873967325, 66.14232417075866, 68.42468077136625, 49.53255737981489, 0.31141887809480395, 0.3398603212929541, 0.5470107411665301, 0.48489614840476747, 3.7896293209445093, 65.02248748656243, 63.43142117223432, 69.2304297416441, 65.95369738917198, 57.66965158524052, 36.2726673003166, 22.477630607543453, 40.176716081557736, 60.89316521921466, 50.51394616403888, 1.4040474593639376, 0.037613258501815225, 0.07335678749387303, 0.041791540345237146, 0.10678072865571707, 0.05020200214799374, 0.0454960695858444, 0.009975851393274723, 0.014756748531644624, 0.025781938325493567, 0.12142556419055309, 0.03936108810106113, 0.03636136741167115, 0.08223464336967276, 0.12800882585466872, 0.3030683358590449, 10.983540588809598, 69.97437000274658, 56.30095228072136, 39.21466850465344, 23.05092619311425, 38.608285765494074, 49.10232044035389, 65.490159526948, 67.87553325776132, 63.26690912246705, 60.28272674929712, 4.280720362740179, 0.5416430388727497, 0.2767991196484335, 0.11476462121091544, 45.1301283221091, 68.86524923386114, 63.18724970663748, 61.36794459435248, 57.18662346563032, 56.43627012929609, 53.295212561084384, 51.51770422535559, 47.84336120851579, 46.49782742223432, 49.71270791945919, 46.13912666997602, 43.05198992452314, 42.548443886541556, 42.46319901558661, 40.62885945843112, 41.45241991166146, 41.12275646578881, 43.470871602335286, 41.46421840113979, 41.07448385607812, 41.79188536059472, 38.77255855068084, 39.50703021018736, 38.3696722984314, 38.95309348260203, 39.93301530038157, 39.84558174687047, 39.94818702820809, 37.863870897600734, 38.70260700102776, 39.450681440291866, 38.07844023550711, 38.360474340377316, 39.926515933006044, 41.36671220102618, 39.507677401265795, 40.73664619076637, 37.61154482441564, 37.31100497707244, 39.77279824595298, 38.503134865914625, 37.29983406682169, 38.30571413040161, 41.27004931049962, 39.513349148534964, 41.68263166181503, 45.7725654878924, 51.02423867871685, 50.38805377098822, 43.72995591932728, 40.015918516343646, 39.553333790071555, 37.71027088165283, 40.028368119270574, 40.74482433257565, 41.37393328451341, 40.76975883976106, 41.24233384286204, 40.01899365455874, 38.15869977397304, 38.142382714056204, 40.81398748582409, 41.51302837556408, 40.07749580567883, 42.41014895900604, 40.79060623722692, 39.81903906791441, 40.240234944128225, 39.22002646230882, 41.22129424925774, 40.70899740342171, 40.33823536288354, 41.77918472597676, 40.97315726741668, 37.2433284021193, 38.37695613984139, 38.39382625395252, 40.04836044003887, 42.027972821266424, 40.598276738197576, 47.493666218173125, 53.05136665221184, 50.536393888535045, 42.260075153843054, 39.01692221241613, 39.761337080309474, 40.41935390041721, 39.267498908504365, 41.91011736469884, 39.57012937914941, 40.67714383525234, 39.33493229650682, 40.87913805438627, 41.076943182176166, 40.42716333943029, 40.953733690323375, 39.67018904224519, 39.740885842231016, 40.456651718385764, 41.428465997019124, 40.37643532599173, 40.06839982924923, 40.84771986930601, 40.035565668536776, 40.94852478273454, 43.23379962675033, 41.766841027044485, 43.364222357350016, 42.09142892591415, 42.23815302694998, 41.209676188807336, 42.306374811357074, 42.63440262886786, 42.17710917995822, 44.332757534519324, 47.91668207414689, 49.045344091230824, 49.87050487149147, 49.96565372713151, 50.87144667102445, 49.752378771382, 50.283004853033255, 55.535564499516646, 60.27390926114975, 62.47131124619515, 66.98095044782086, 69.4528595093758, 69.77142657003095, 52.38034717498287, 0.4623959928510651, 0.44415026061957885, 1.981146518261202, 0.6187879089866916, 3.90813147829425, 72.24455941107966, 68.47964886696109, 73.91492428318148, 72.54476193458804, 65.05518828668903, 38.72100291713592, 26.69021891009423, 47.5376202983241, 67.62818859469506, 59.512702726548724, 2.762795955904069, 0.10895285605182571, 0.05063730479788877, 0.07392415221059516, 0.06905147295084692, 0.030311728121652722, 0.09062104618116733, 0.1398989471096185, 0.1449345196447065, 0.09290061740865631, 0.18480907434657698, 0.18318594853964545, 0.195059054981797, 0.23474409485295897, 0.30676532296403763, 0.3926556076734297, 13.362054094191521, 79.24007523444392, 65.3513821478813, 47.65105916607765, 37.11435302611321, 51.2678570901194, 54.91012688606016, 74.27763369775589, 73.9229102288523, 68.89726361920758, 66.3778389653852, 5.589436331102926, 0.9086443844341463, 1.4203960208162185, 0.21276152362265896, 50.542140160837484, 70.67991810460245, 66.78731087715396, 62.572900633658136, 58.286891445036865, 59.78669597256569, 56.42995511331866, 52.77920515306535, 50.86381373866912, 49.25289238652876, 52.7217306629304, 48.95790661534956, 45.41402555281117, 45.25890365723641, 44.67687099210678, 42.71231658997075, 44.51298652156707, 43.53143299779585, 45.754569653541814, 42.66297709557318, 45.10175389628257, 44.3403551655431, 41.962720271079775, 41.421511634703606, 40.76947250673848, 40.98610108898532, 42.17887816890594, 43.66450725063201, 42.890247068097516, 40.308837198442035, 42.00853355469243, 41.334791952563876, 40.85362303641535, 41.81745136937788, 44.19809472176337, 42.92514831789079, 42.466940956731, 41.73215158524052, 41.149699226502456, 38.305529779003514, 42.92819992188485, 41.94133158653013, 40.604019088129846, 38.81345710446758, 45.27095317840577, 42.27168929192328, 46.24602694665232, 47.62108833559098, 54.24303762374386, 53.1967963710908, 43.508969583818995, 39.99918568518854, 39.94813211502568, 39.23542960997551, 40.68560438771402, 43.57104109179589, 44.31481269098098, 43.751042581373646, 41.98066511461812, 42.7103397154039, 40.28060790031187, 40.38422907552412, 42.32693979817052, 44.344791366207986, 43.938896656036384, 46.27442490669989, 42.80952861232143, 40.524414585482695, 42.32522572240522, 43.448820037226525, 42.95609581855036, 44.423587860599646, 43.20185192169682, 42.375561498826556, 42.75650601233206, 38.471469571513516, 39.76360421026907, 38.827252080363614, 39.51202338741672, 40.38522535754789, 41.37659657386042, 48.811147212982185, 55.44769948528659, 52.022462275720414, 45.094513200944476, 41.84148373142366, 41.125278549809615, 42.898566415233, 39.905158627417784, 43.91782176110053, 41.37798117053124, 42.73770216972598, 40.97187073000016, 43.96970687373992, 43.342496348965554, 42.965948812423214, 42.84666561311291, 42.605298642189275, 41.69304163225236, 42.03118524243755, 42.813266631095644, 43.38172789542906, 42.37956623877249, 44.262602021617276, 43.18801379972889, 43.112543475243356, 46.9825460833888, 44.9366456462491, 46.72795680261428, 43.462936647476695, 45.91072313247189, 45.36336029729536, 45.824701632222826, 45.337229467207386, 44.447227985628196, 47.43030425040953, 50.49477754100677, 53.0999412844258, 53.43957539527647, 51.28888099424301, 51.99535085308937, 52.29311758472074, 52.27366262866605, 59.34969294455744, 61.29314107279624, 65.86113729784566, 70.67099079009026, 73.00375769215246, 69.03106351052561, 55.81571194433398, 1.1483916616247547, 1.5021027913016658, 4.0513114727312525, 1.4076789612731626, 4.536255425022495, 77.63140140041229, 74.97015168589931, 79.5722842985584, 78.48378735203897, 72.31917073649745, 48.484680498799975, 33.743970163406864, 57.8323358105075, 76.41780437961702, 74.21092202586513, 4.3324304396106355, 0.30694890827421223, 0.24459388647829336, 0.15627576188454706, 0.2385381606197165, 0.19467244104992962, 0.15625573634620638], [0.08312261588270627, 0.021107346420326543, 0.024688882159910375, 0.04021707261281629, 0.05316051496793667, 0.06679135269575542, 0.061399614393350586, 0.058358693495392806, 0.13856287444791487, 3.7122022240392627, 53.72664582344794, 58.249777978466405, 42.05270336520287, 43.10957031865274, 38.77818322950794, 47.14729347536641, 62.11265756237892, 64.46597768414405, 56.11045452856249, 62.82525024106426, 7.967946894707219, 0.273691775097001, 0.13572839509335258, 0.27774303190169797, 53.52707170671033, 67.28148245042371, 59.438001186616965, 54.88438437061926, 54.14236999327137, 53.377809832173014, 51.57634758180188, 48.05993487758022, 46.99405431747437, 44.51471628681306, 44.61377182314473, 43.31152923645512, 41.154092281095444, 41.21943504579606, 39.28246667308193, 40.33586232892929, 39.28630275111045, 37.70932559044131, 38.069763952685946, 38.227278494065814, 36.58437021317021, 36.98281242001441, 37.432163069325114, 36.41388439363049, 38.35971732293406, 37.238280311707534, 35.92129353554019, 37.37838737426266, 35.73861698950491, 37.24242625697967, 37.00260469990392, 36.407439939437374, 37.06858288857245, 37.98626453645768, 38.67873153378887, 37.173153277366396, 36.49667386085757, 37.022879431324625, 38.30414518233269, 37.13332160826653, 37.74470144702543, 37.39337475069108, 37.19600500599031, 36.02290253485403, 37.12030326166461, 36.64608086309126, 35.28402213127383, 45.120797003469164, 48.12140626292075, 49.57400506542575, 44.39009866406841, 39.02610840335969, 40.91035619858773, 37.60837947168658, 37.52624896264846, 38.90031406956334, 41.17691263075798, 40.47464755273635, 38.43031606366558, 37.368334339511016, 39.37577201474098, 39.412563846957305, 38.263556495789565, 39.93876941742436, 40.00872488944761, 38.81060161898213, 38.364200592041016, 38.560130826888546, 38.34005448126024, 37.74193225368377, 37.34224273312477, 39.45514509754796, 39.77715599921442, 39.60028456103417, 38.59508698986423, 37.7666667199904, 37.32440379358108, 38.76717313643425, 38.711208758815644, 39.13276157071514, 40.529482287745324, 47.552235049586145, 51.64118043838009, 48.16788242709253, 38.7834039042073, 36.204088580223825, 40.34131834583898, 37.726003508413996, 38.63200041555589, 37.74425037445561, 37.8439256452745, 36.64920306974842, 36.730533415271395, 36.76024536932669, 38.52224857576432, 37.79350749907955, 38.86722887715986, 38.01478016761042, 39.227545645929155, 37.38944061340825, 37.94915891462757, 36.65170554191836, 37.534780117773245, 36.21266680379068, 37.07455273597471, 39.392328339238325, 39.639622011492335, 38.394598960876465, 39.68984796154884, 39.296983365089666, 39.642104871811405, 39.80860556325605, 39.00803412160566, 40.17551191391484, 40.75099029848653, 41.604462746650945, 44.838037260117076, 45.375754987039876, 45.348635719668486, 45.29160053499284, 45.816594093076645, 45.48693849194435, 50.12395274254584, 54.071716339357444, 60.19970586222988, 61.83981357082244, 63.57577616168607, 62.804610729217536, 50.853658722293, 53.30835250116164, 1.1993444759038188, 0.47525913003952275, 0.9066415854519414, 0.7923082334379997, 4.985155492059646, 66.73126805213191, 62.385226988023334, 69.6062320278537, 65.7676632942692, 60.51595087974303, 33.54827527076968, 21.50823643130641, 41.88979556483608, 62.87987709045411, 47.176130740873276, 0.7710320718826786, 0.02016708649124109, 0.10212538854008722, 0.04450190962562638, 0.02073120299516426, 0.03487401153712023, 0.07531001292649778, 0.041294471856447, 0.025626510576975924, 0.06816960615856994, 0.039243363369736946, 0.02323851492556353, 0.09128902122498521, 0.12372175186511972, 0.04257737801620557, 0.21648708580722734, 4.862942772526895, 63.07095143102831, 64.3717937315664, 47.92693514977732, 45.0611142189272, 43.528993283548665, 52.79570656438028, 67.38849255346483, 69.99983402990526, 61.79238034832863, 68.99997480453985, 8.502842476291042, 0.2549869570160105, 0.12764927780916616, 0.193746256071233, 55.6640064331793, 67.96683034589215, 63.185782740193034, 57.11478133355418, 59.18642036376461, 55.66881918138074, 53.729732728773556, 49.7654990996084, 49.35561141660137, 47.616432482196444, 46.61040336854997, 45.40272520434472, 44.35871970268988, 43.5130488487982, 42.622251126074026, 41.64210573319466, 42.82397470166607, 39.71691623810799, 40.94371987927345, 40.51651493195565, 40.12808653616136, 40.6675850191424, 38.862121951195505, 39.048230571131555, 39.726573113472234, 37.57097967209355, 38.61730329452023, 40.664541259888686, 38.41350086273686, 39.43472131606072, 38.340772275001775, 39.48852446771438, 40.320341510157434, 40.40644145780995, 39.20648251810382, 40.503739772304414, 38.90387950404998, 38.39986670401789, 39.954345149378625, 39.02739886314639, 39.18441918588454, 40.068089962005615, 38.89751349726031, 38.51345069946782, 37.92243188427341, 38.822294204465805, 36.99093172627111, 47.66131616407826, 49.972435505159446, 50.81878100672076, 46.11829103962068, 38.99467060642858, 39.88442497868692, 37.14809717670564, 38.26758476995653, 40.952827622813565, 43.21480358800581, 41.32881033805109, 40.51862908947853, 38.87658765239101, 40.71205685215612, 39.738791296559, 38.67769995043355, 41.822107222772416, 42.721969542964814, 40.847551207388605, 40.090620056275405, 41.00749761827531, 40.111251723381784, 39.671765835054465, 40.29489317247945, 41.24749568200881, 42.079583367993756, 40.3745839672704, 41.390705339370236, 37.50648021697998, 37.62419839059153, 37.90201986989668, 39.49396479514338, 38.938925881539625, 41.03880597699074, 48.947963406962735, 53.61892184903545, 50.7299118657266, 41.17215087336879, 38.589976141529704, 41.58001069099673, 39.089517439565356, 41.46450081179219, 40.976844295378655, 39.979856244979366, 38.30774984052105, 37.92207102621756, 38.73582163164693, 40.234049366366484, 39.285969349645804, 40.67420597999327, 40.66639261861002, 41.183058984818004, 39.609866911365145, 40.48349641984509, 39.38204780701668, 39.992996185056626, 40.05121592552432, 40.33487781401604, 41.32503701794533, 42.615120257100756, 42.233371657709924, 42.61743053313225, 42.261432293922674, 41.63663402680428, 43.65833343998079, 41.38943449143441, 42.87383979366672, 41.192402070568455, 43.893703106910955, 47.855649994265654, 47.790044430763494, 47.1824889029226, 49.256085195849025, 47.392833848153394, 47.344000339508064, 53.048201299482784, 57.62498363371819, 62.864889714025686, 65.86731110849689, 65.9936349622665, 64.40610662583383, 51.307998626462876, 56.65015697479249, 1.6305753684812978, 0.6476904451847076, 0.5689430417072389, 0.8113839453266514, 5.201609038537549, 72.63947932950913, 66.80472620071905, 75.2875812592045, 70.2179805694088, 62.75575368635116, 28.087018074527865, 21.94073069480158, 49.346688024459354, 70.01884968050065, 57.637970601358724, 1.4024658861660189, 0.040912933257077976, 0.10663804477981983, 0.014800021965657512, 0.07409528093112093, 0.10407209456447633, 0.05344561841939727, 0.1897294272578532, 0.11571067084948863, 0.15693533294383558, 0.13665225116475938, 0.12785513329529954, 0.17175202498272543, 0.19627915725352305, 0.1529654193549387, 0.32894448767746653, 5.496570294903171, 71.12979827388641, 73.05227741118401, 59.803428803720784, 56.905675857297844, 52.14182392243416, 61.71387018695955, 70.82820723133703, 75.53870708711686, 65.00093014009538, 74.58607319862612, 10.101793735258042, 0.5751552793287462, 0.3159604618145574, 0.47013029396053285, 60.08131696331886, 70.56889933924522, 65.352331361463, 59.444798654125584, 61.65620350068616, 57.48591599925872, 56.72893385733328, 52.81607543268512, 52.17118678554412, 49.824573916773645, 48.47281140665854, 49.69944638590659, 46.8902527132342, 44.7046805966285, 45.16759872436524, 43.7541098748484, 43.190951654987956, 42.13125667264385, 42.605208427675315, 43.58621674199259, 41.87606726923297, 42.478162857794, 41.49034923122775, 42.17595208075739, 43.74502174315914, 41.354494017939416, 40.39547058843797, 43.246504183738466, 39.2971912507088, 42.64105496868011, 40.79694870979556, 43.20775901117633, 43.21531349612821, 43.090405617990804, 43.150021722239835, 43.28201340090844, 38.94141266422887, 40.41757706672915, 42.43260060587237, 40.742043372123476, 41.49225942550167, 41.34968911447833, 42.63678742993263, 39.48561799141669, 40.31036692280924, 40.99564813798474, 39.29577527507659, 51.163039592004594, 52.636262216875636, 52.55460239225819, 47.60886230776387, 41.2918576886577, 41.481982815650206, 39.109062610134, 39.21929690145677, 41.88676749506305, 44.611587062958755, 43.74033451080323, 41.447803281968646, 41.871030945931714, 44.274388743985085, 44.11792147544123, 43.80851314913842, 45.09049277151785, 45.72403792412051, 43.53265677728961, 44.04612248943698, 43.36235530914799, 42.668193847902366, 41.532083249861195, 40.89301932242609, 44.70748901367188, 44.9667537596918, 41.754305131973766, 41.663419892711026, 37.87776393275107, 39.33541082566784, 38.44711557511361, 38.72651384722802, 39.35259472939276, 42.50517229880057, 50.44013107976606, 57.077020675905295, 51.97222455855339, 43.788552207331506, 40.709275891703946, 43.515684681554, 41.471251210858746, 43.11609714261947, 41.366261128456365, 42.033817152823175, 40.46643410959552, 40.22928368660712, 41.32413095043552, 42.92755273080642, 41.622968489123934, 42.50835726338048, 42.06527456160515, 44.611320341787035, 42.8672541341474, 44.00150552872689, 42.061913090367476, 43.91706474365727, 43.08980549535444, 42.5107773657768, 45.32164196814261, 44.90793389658774, 46.20140998594223, 46.41585773037326, 46.15893856171639, 44.33305171228225, 46.40911517604705, 43.942089465356645, 45.79227147563812, 45.58399361948813, 47.69422877219416, 50.1225406892838, 50.153448966241655, 50.345225411076704, 51.804990383886526, 49.09579753875733, 50.651923379590436, 55.392064586762466, 60.20225540284188, 64.85211933812788, 66.94222880947974, 67.96182540155226, 66.43512910412204, 52.24569220696726, 59.49274962948215, 2.2074866439065626, 1.5143263676474172, 2.5386180368161972, 1.6611278129200784, 6.557046319207838, 78.38008772942328, 72.6326387159286, 79.60523220800584, 76.6640821579964, 74.49722366948282, 45.82845141810756, 32.80013807358281, 61.160863061105054, 78.33314480320101, 67.36760200992708, 2.172582942631937, 0.14404409565031528, 0.2895912864515859, 0.1310984661141711, 0.10125194871497732, 0.3402295756724573, 0.25504478133253516], [0.09839797242274208, 0.003227640944157517, 0.033022959250956774, 0.013899639785860576, 0.03327058568116158, 0.09742373840943461, 0.03423180003019591, 0.024114051916366144, 0.027515185441100792, 0.9454083310500269, 48.00245254270492, 55.07921634181854, 50.50686628587785, 21.220736503601074, 15.222179312859813, 46.23447556649485, 57.411653764786266, 69.3186987600019, 51.5461374867347, 67.5045084184216, 15.002529524987745, 0.30390827465922604, 0.21712468546484748, 0.5584428567559488, 53.02597715008644, 64.94435387272989, 58.96409650002757, 54.07974543110017, 49.58436796742101, 50.50595629599787, 49.87776517868043, 46.041369438171394, 46.38581237485332, 42.71637232072892, 42.252799157173406, 40.90442949725736, 40.03271018305133, 40.39440762612128, 39.950246272548554, 40.29280647154778, 37.01208899098058, 37.44013724788543, 37.761108721456225, 38.93164596249981, 37.26078687175628, 37.0222165507655, 38.82445935280093, 36.88600440179148, 37.252169424487704, 36.92224710218368, 35.81418537324475, 37.26219892501831, 36.244932220828154, 34.59369282568655, 37.03543886061638, 37.358995176130726, 36.713726059083015, 37.90520091210642, 39.49300773682133, 37.57041485078874, 36.79741767144973, 37.15631846458682, 35.981184205701275, 37.259923950318374, 36.9843303772711, 38.16933331951019, 38.741426698623165, 36.849981354128936, 37.719868921464496, 38.381062861411806, 35.92812238201019, 44.042196196894494, 45.39967360035066, 49.955824267479684, 47.96480955616121, 39.46266820353847, 37.7563940325091, 38.865616783019036, 36.86506286744149, 37.163849415317664, 38.453034431703635, 38.24455261230469, 39.45450575120988, 37.003302881794596, 39.131839813724646, 38.11463194508707, 37.12349607098488, 40.41060701493294, 39.76465148310508, 38.72139515415315, 37.26014752541819, 35.89398207203035, 37.775648947685, 37.00300870403167, 37.15678522663732, 39.35295558744861, 40.38486449949203, 37.31082847041469, 38.47786303489439, 38.68655666228264, 37.40808756120744, 40.932874525746996, 39.266730123950595, 40.561335855914706, 40.6689029355203, 49.05036080268122, 52.129782246005156, 48.65491528664866, 40.3519558137463, 37.37937973391625, 40.522755422899806, 37.6503723667514, 41.05579376220703, 39.633899273410925, 39.636578252238614, 38.35436721001902, 37.60910903253863, 38.69046726534444, 38.08773233044533, 38.99773005516299, 37.975866333130874, 37.35098569623886, 37.95996112208213, 36.31247543519543, 37.59723209565686, 36.62277806189753, 38.734311519130586, 38.570505495994325, 37.56201705624981, 38.06897163391113, 36.967711294851, 40.64872234098373, 39.50403351937571, 38.412100576585345, 39.75691656912527, 39.18778065712222, 38.7888442316363, 39.74260776273666, 40.5970411915933, 40.06369298504245, 42.69928255388814, 43.517747848264634, 44.5325630710971, 44.606931209564216, 45.72170019149781, 48.385220958340554, 54.224429899646395, 61.605777509750865, 62.130833825757435, 67.61756681626844, 65.19270266256025, 64.02293028370028, 54.912578367417865, 52.00207379556472, 3.105824878138881, 0.9976766715126654, 0.29774742621567946, 0.523801280125495, 6.014012309812731, 64.47284967668595, 62.11391272083406, 68.00712093230217, 63.42910697383266, 60.47717825058968, 62.58779779557259, 31.520702108260128, 44.044816340169604, 59.19895625883534, 41.2328613188959, 0.3029859047983923, 0.05795668119624738, 0.006811446219217033, 0.04655765677471796, 0.02243310945378917, 0.012131388197773168, 0.014642378307818888, 0.1116158236419001, 0.061723692567958954, 0.02776898270953567, 0.025927895312047294, 0.020068510127584302, 0.015793860168947328, 0.023570832375797535, 0.02885391834312149, 0.05214269821261687, 1.56551280809987, 57.61831168205508, 60.68550317518173, 54.74215138343073, 31.351187075338057, 28.49465039468581, 54.781755555060606, 61.65488950667843, 73.49302630270682, 57.013356685638435, 72.46194501076975, 14.83344203041446, 0.3636962583949489, 0.10841662514834635, 0.6954876513731095, 57.7655182346221, 66.69900263509443, 61.66962585141582, 55.27953963125906, 52.549315037265906, 51.562564373016365, 52.06545537517917, 48.09687575986309, 48.09154133642874, 44.83471501258112, 44.96131343226279, 41.93564807215045, 42.41798585461032, 42.4128750062758, 42.950400537060155, 42.76013028237128, 39.63330307314473, 40.342177344906716, 39.74340792625181, 39.90924965950751, 40.74586768304148, 39.02542983331988, 40.25308462881273, 38.876046365307225, 38.232416798991544, 39.024857167274725, 38.43640750454318, 40.33850208405526, 39.18450155565816, 37.09815755967171, 39.731134829982636, 39.830084462319654, 39.00548458099365, 40.233319805514434, 39.41004960767685, 39.19160889041039, 37.967182205569365, 40.16538043175974, 37.10560221825877, 38.54480220425514, 38.07503954056771, 40.10008081313103, 39.675299890579716, 38.124214295418035, 39.55424377995153, 39.817211243414114, 36.648332303570164, 45.6916077675358, 46.90414182601437, 51.81632211131435, 47.4996478326859, 39.71591603371405, 39.14405015207107, 38.08626928637105, 38.56597123607513, 40.4270339012146, 40.30974718832201, 39.911626615831935, 41.76263232384959, 38.27684548593337, 40.92550831456339, 39.494717890216464, 39.360615976395145, 41.684137851961204, 42.10158786466045, 41.04978076873287, 41.20665204140448, 40.16094815346503, 39.80673851505403, 39.52304132523076, 39.94880284032514, 41.882139098259714, 42.22692328114664, 38.3796468857796, 39.729671785908366, 40.1308165058013, 37.286094004108065, 39.19127156657558, 39.21810057855422, 40.73027233923636, 43.38320662898403, 48.59871948918989, 54.48198841464136, 51.16554598654471, 42.66259662566647, 39.813465379899554, 41.79216777124713, 40.06105715228666, 42.6283621788025, 39.82449116245393, 40.12836110207343, 39.147623431298044, 39.21854380638369, 40.39133248790618, 39.65546838698849, 40.2133039505251, 40.126529355202955, 39.7807292784414, 40.53110614899666, 38.33959948632025, 40.64924401621665, 38.606144151379986, 41.25068849132907, 39.67853192360171, 39.65477020509782, 40.7580074187248, 39.23584930358395, 42.51846128894437, 41.82897529294414, 40.147812135757945, 42.782887874111054, 41.841632781490205, 40.72367491260652, 42.16248658395583, 44.493531565512384, 44.222487941865005, 44.239891498319565, 46.79961066092215, 47.11382389068604, 47.75735932011759, 48.37874120281589, 49.3631306002217, 56.28323101228284, 63.81508388826924, 64.10807317303073, 69.20374193499165, 66.94019702173048, 67.02761096339073, 56.272695526, 55.200237151115175, 3.1558284788362445, 0.6337076858166726, 1.7265512313573592, 0.6806875068333842, 6.15315446930547, 70.31079953716647, 67.93009342685824, 73.03039843036284, 69.30097749156337, 66.82454201482958, 60.281538271134906, 34.055853505288404, 52.25477641628635, 66.67937509475216, 49.22388253673431, 0.5078761507907222, 0.06945564561793882, 0.006761021833235939, 0.057722530252630674, 0.008109375841975694, 0.009819751402603523, 0.011051420644376309, 0.18593277211391157, 0.1203039271997348, 0.15450251348797353, 0.20035901978131265, 0.18801717478181088, 0.10977611711789524, 0.2470919613035456, 0.19386354413244034, 0.14463672594678018, 1.9393430001312688, 63.38392519181775, 68.85335660749867, 66.83541482494724, 33.133994533169655, 25.524941567451727, 58.89379193705898, 67.14160288533857, 80.95395488123741, 60.94802348844467, 80.58322814203079, 17.717516691453998, 0.60765266778969, 0.49788801900802127, 0.9741860255599023, 60.54585110756659, 68.3519757178522, 64.65241970554476, 56.703967971186486, 54.33287559017059, 54.28683480908794, 53.94074447693364, 50.421335081900324, 51.903135930338216, 47.2284512366018, 47.870821722092174, 43.977190756028705, 44.765375352674916, 43.79581643689064, 45.93552035670127, 45.52254184599846, 42.74458200700822, 43.48712590432937, 41.074840791763805, 43.69482717206402, 42.586581091726984, 43.187833370700965, 42.750422416194795, 41.79875735313662, 39.48019335346837, 40.975522456630586, 40.25901525251327, 40.68813823884533, 41.07538600121775, 40.232762828949966, 42.007341154160045, 43.96138360423427, 42.35888750322404, 43.1806593556558, 41.547235365836855, 41.714085148226836, 40.28196111802132, 42.22234195278537, 38.68783927732898, 40.17567665346208, 41.305750723808046, 41.739455038501376, 41.51093382989207, 41.45087842018374, 41.177869689080026, 42.36563005755025, 39.37203399596676, 48.497981256054295, 47.98252297985939, 54.11697264640562, 48.46321728921706, 40.17577863508656, 39.75178610893988, 39.93728676149922, 39.46392336199361, 41.602399579940304, 42.64561276282034, 41.92079797867806, 43.93449575670304, 41.527376405654415, 43.192948141405665, 42.710112217933904, 41.02467759963005, 45.003455377394154, 45.698409157414595, 43.01922636647379, 42.71581142179428, 42.58276070317915, 44.04448293870495, 40.19144850392496, 42.1440435994056, 44.85899448394776, 43.52618878887546, 40.12170876226118, 41.56266204772457, 41.31180294098393, 38.29018938925959, 40.714143553087794, 38.88819786810106, 41.30291092780329, 43.76650848696309, 51.367991278248454, 57.73119357324416, 53.09832919028498, 44.80604640899166, 42.270896973148474, 44.40643533583611, 41.045493618134536, 45.08216165727185, 42.89095701709871, 42.743217022188254, 42.69473652685843, 41.87325885218959, 41.527894158517164, 41.85957762502855, 42.19454803774434, 42.37458875102382, 43.35817798491448, 43.50853420072987, 40.77411267065233, 43.2748080069019, 42.03382499756352, 44.237553765696866, 44.01627717479583, 42.89131003041422, 43.461908986491544, 42.63724242487262, 46.366110309477776, 45.46451430166922, 43.13192782863494, 45.205512354450846, 45.005546000696, 43.73071293677054, 44.622550087590376, 44.639812438718735, 45.8261646762971, 47.19096906723515, 49.708546284706365, 50.929254562624045, 49.9431275552319, 50.104776274773386, 53.62973582360053, 58.38076160800073, 69.14351786336591, 66.80586368806901, 73.77225199053365, 69.3840846707744, 68.88297834704, 55.08690810972645, 59.335580256677446, 4.671525714858886, 1.7788670692713031, 5.092014583849139, 1.0656861576341814, 7.520566255815568, 77.88535917958906, 73.44922911736273, 78.3884031541886, 73.63219199642059, 74.77247207395493, 75.7983523030435, 41.81480376951156, 61.52906771629088, 74.18483826421922, 59.76515431557933, 1.1578862489231172, 0.2258219744168943, 0.11196030273793206, 0.18353856348943326, 0.16146711073815823, 0.11125583126540146, 0.17506184657254528], [0.07198273219288358, 0.015883095047977424, 0.0540596800255439, 0.04141855128710309, 0.02935516201109896, 0.05658763994072234, 0.03200778358375594, 0.06044877670525063, 0.08605070352073639, 0.12438886122958315, 34.46819266965313, 64.03985138862365, 50.747538997280984, 26.969972156709243, 18.912451074969386, 37.86354141850626, 57.46220527156707, 63.44702828314997, 55.20035482222035, 66.17449545091199, 25.402432218674694, 0.12583631541459792, 0.012794707342231227, 0.2720217953526205, 47.29379007893224, 64.29536634875883, 60.076461069045536, 55.22959609185496, 49.54972951642929, 47.90153780291158, 48.343251597496774, 47.03229742665445, 43.82752879973381, 43.735870853547134, 42.345457307754025, 40.88739072122882, 42.29825942747055, 39.47307032923545, 38.16058643402592, 39.956627968818914, 39.621763460097775, 37.48301659860919, 38.96039301349271, 37.77542929495535, 39.181544088548236, 39.0479560052195, 38.06415496333953, 36.39697897818781, 39.738395137171594, 36.829981188620295, 38.000412525669226, 37.265811427947014, 36.7889061281758, 35.97676761688725, 36.24820739992204, 37.50261275999008, 37.638075736261186, 39.63368354305145, 37.95428545244279, 38.69984565242645, 37.28494474964757, 36.87447263348487, 36.13166201499201, 38.35512814983245, 38.4297747765818, 37.4090838432312, 39.784494753806825, 39.07621275994086, 38.35454371667678, 37.493505016449966, 38.18643093109131, 43.451691212192664, 47.71636662944671, 47.919074719952, 47.63531869457614, 39.98979160862584, 39.35742708944505, 37.77775133809736, 37.075956944496404, 38.10323745973649, 39.72233303131596, 38.64557181635211, 38.99824780802573, 38.2908248132275, 36.36707875036424, 37.07965966193907, 38.207882373563706, 38.492222832095244, 40.14501940819525, 39.387142965870524, 38.55167811916721, 38.88380873587824, 37.40844057452294, 37.809581372045706, 37.83810092556862, 39.8611064880125, 39.35359101141653, 38.721120588241085, 36.66249990463257, 38.664528631394916, 39.83978448375579, 39.8427733298271, 39.13062387897123, 40.6064627247472, 42.715976161341516, 48.21522543507238, 49.27440658692391, 47.73294648816509, 40.169812710054465, 39.26534552727976, 38.77797534388881, 36.74090808437717, 39.176095916378884, 38.789452199013006, 36.0867351870383, 38.63995498226535, 38.89887455971011, 37.26645861902545, 39.16530155366467, 37.43051567385274, 38.04309968025454, 39.04656356380832, 37.922879034473056, 37.901662934211, 36.77716255187988, 36.81686870513424, 36.09711377851425, 38.771911359602406, 38.38430666154431, 37.96927675124138, 37.94638187654557, 39.711295481651064, 37.33100122021091, 41.60936178699617, 38.684768061484064, 40.984594898839156, 40.083136173986624, 42.525803965906945, 39.93850661862282, 39.218167258847146, 40.66097190303188, 41.541171381550456, 42.662424041378884, 44.184338969569055, 43.73821643091018, 50.62250952566824, 57.95462746773997, 60.73916512150919, 62.67137958157448, 63.66961102331839, 64.20613634970881, 68.36582952930083, 66.94462145528486, 61.345579239629934, 5.185998495548002, 0.6982763952785923, 0.8566063606450636, 0.4249387673072277, 5.093938996714931, 66.05192922776746, 58.56961980942757, 69.04130089667537, 64.43256693501627, 53.444239093411355, 39.450183299279985, 29.394887301229662, 47.75877921811996, 66.72246625346523, 35.23241550691667, 0.33308222048705627, 0.12340132792991017, 0.031011342596743378, 0.025902518649555506, 0.022753324630039356, 0.04706758404931715, 0.11956708851240336, 0.009707165206031454, 0.0671034032899526, 0.02144630010720463, 0.023738153639339635, 0.024255435358011918, 0.047894878568308014, 0.03213270379590892, 0.03794221665650126, 0.0395787681543058, 0.2470083811110066, 43.31273340409802, 69.1536218889298, 59.27119062792871, 30.715576794839677, 21.693076164491718, 50.89398853240475, 60.31067755914504, 71.6351721363683, 59.11579024407172, 71.45469603999969, 26.982980697385727, 0.09915852153133001, 0.028189821619420286, 0.2928441570651147, 51.52501160098661, 67.10608190105808, 62.180004658237586, 56.383726058467744, 50.349649844631074, 48.745239626976755, 50.69697964575983, 48.153024488879794, 45.251458998649355, 45.5013257457364, 45.3931075526822, 42.832054784221036, 43.18719794673305, 42.65158653259278, 40.19708887223275, 41.343868317142615, 39.95470600743448, 41.977680190916985, 40.836015516711825, 41.35420376254667, 41.40098194922171, 40.19282133348527, 41.00430873132522, 39.11309480667114, 42.08308604455764, 40.424221561801055, 40.104477790094194, 38.94396220484088, 37.828824520111084, 37.931669066029215, 38.71941043484596, 38.770860164396225, 38.72576075215494, 41.11803000973117, 40.705035809547674, 40.10918855667114, 39.68313286381383, 38.87033539433634, 38.39533244409869, 39.32851137653474, 41.20366711770335, 39.15814715047037, 39.7140529078822, 38.419039249420166, 39.9561768962491, 39.22183075258809, 38.94066349152596, 45.15895382050545, 51.48286965585525, 50.16871875332248, 49.977569887715006, 41.17430033222322, 38.08548481233659, 38.755759039232814, 38.41694078137798, 37.0791026853746, 40.668934314481675, 40.49072927044284, 40.63489598612632, 40.026512838179066, 39.42656670847247, 40.05383606879942, 40.212354736943404, 41.38430795361919, 42.263801405506754, 40.506928659254505, 39.53085860898418, 40.9553300949835, 38.773476385301166, 40.74720128890007, 41.00597573864845, 40.959189707233065, 40.87526275265602, 39.78973504035704, 38.08332358637164, 39.23903819053404, 38.689117970005164, 39.35360277852705, 40.049027242968165, 39.692715214144805, 43.382088753484915, 52.42941602583855, 52.37072167858001, 51.881849227413056, 43.10383581346081, 41.44357104455271, 40.63837120609899, 38.9059034470589, 40.982829832261615, 39.50958367316954, 38.79359814428514, 39.73670459562732, 40.024029977859996, 39.25880301383234, 40.62031653619582, 39.93183074458953, 40.347562759153305, 41.93619720397457, 41.047282218933105, 39.51081137503348, 38.813092324041556, 38.234836901387865, 38.22584682895292, 39.98710870742798, 40.12910635240617, 40.056393454151774, 39.67240518139255, 42.48215583062942, 39.93818890663886, 42.29611389098629, 40.65281729544363, 44.32707794250981, 41.75191248616865, 44.13053974028557, 41.494232377698346, 41.127455465255245, 42.55573557269189, 43.928910301577666, 44.11405009608115, 46.895551835336995, 45.49617567370015, 53.06569507045131, 61.04345083236695, 62.94610238844349, 64.99224993490404, 65.851653006769, 66.01967950021067, 70.35178046072684, 67.46224880218506, 65.07402350825649, 5.194655166518304, 1.1275250200302371, 0.45675792280704747, 0.41311818385316484, 5.307944493909036, 72.79269495318013, 64.14919922428747, 75.4190512626402, 68.94859175528251, 64.83187990803873, 49.3369330898408, 32.300500677477935, 56.69795497771233, 73.12943827721381, 44.065922614066835, 0.4854384467246071, 0.027592001077268394, 0.07030559718729028, 0.020916209398438374, 0.02918324996567061, 0.029220541210604772, 0.05546430606515177, 0.11051801964640619, 0.10090673417453805, 0.1340149475201484, 0.108648044988513, 0.1189017105066488, 0.1516413436301293, 0.2135682295286848, 0.1325749014053614, 0.19680360572472697, 0.5192108812832064, 49.95566345030262, 79.59497913237541, 65.86438502034834, 38.51833797270252, 26.886147183756677, 52.531754586004446, 66.0883366677069, 74.50977525403424, 63.218530608761704, 79.84251991395028, 31.395884444636685, 0.22521177006344642, 0.13879673044768073, 0.46746142749344155, 56.535670834202925, 67.14357191516508, 65.8745361143543, 58.55738985923029, 53.11455603568785, 50.656665525128766, 54.70472020487632, 50.19351205518169, 48.348974335578184, 47.080503356072214, 48.65837089477047, 44.097760492755526, 46.82601605692218, 45.207724571228034, 42.57163686137046, 44.1695830129808, 42.92617990124611, 42.72826886946156, 44.13193218169674, 43.48002641431747, 44.00074066654329, 43.39216532245759, 42.3455749788592, 42.10967971432594, 46.23662894771945, 42.159434979961766, 43.3659952686679, 41.85606318135416, 42.20853520977882, 40.93727150271016, 42.15213544907109, 41.08187752385294, 42.927839063829, 44.79525596864762, 42.95631154890984, 41.561850117098906, 42.28876729165354, 40.63602955110612, 39.11033345806984, 41.22962928587391, 45.92747165310768, 40.68225468358686, 43.40194771366735, 41.35906357919016, 40.98258664531093, 41.915134076149236, 44.41270328337147, 48.74729494894705, 54.80314031724007, 52.818966219502116, 51.54863995890464, 42.040112556949744, 39.182956141810266, 41.22465179812524, 40.40112272385628, 40.06640334283152, 42.91809197395079, 42.4153107981528, 43.47546862017724, 42.15539101631411, 40.51124718881423, 42.628970146179206, 41.67838373491841, 43.200490859247026, 45.82814939560429, 44.19990685678298, 42.990192982458304, 44.792988838688025, 41.89435728134648, 42.40249249242967, 41.062434334908765, 44.42630998549923, 43.42618403896209, 41.3471709528277, 39.70959317299628, 40.17443718448762, 40.97987628752186, 40.142465945213075, 40.141575567183956, 39.46363702897103, 43.88048079706008, 52.91188324651411, 55.39671651778683, 53.864752477215184, 46.509755349928334, 42.76562160061252, 42.485458466314505, 40.86601772615987, 44.5011801873484, 42.5566690967929, 39.956839776808216, 43.96015982474051, 41.70559321680377, 40.89952261217179, 44.21442354879072, 41.168942374567834, 43.18226360505627, 44.224860975819254, 43.521148543204035, 42.65679151781144, 42.08973446199971, 41.560759698191, 41.267170290793146, 42.85912306078019, 44.72593199822211, 42.48742357377083, 43.22827300717754, 45.2478111943891, 42.89642480111892, 47.379764510739236, 43.57043312441918, 45.44049762910413, 45.09055552944061, 49.50189228980772, 44.89708462069112, 42.820876029229936, 44.66353493352091, 46.93000593493062, 46.76422303722751, 49.32942959570116, 48.06390823856477, 56.398301586028076, 63.54842547447451, 65.33183305494248, 67.96686956959387, 68.33117931119858, 68.85341152068108, 75.84929604684153, 69.48553285291119, 69.18813090170585, 6.908601983900994, 1.6691646268290858, 2.5750705840126162, 0.9600972396231467, 6.3309996358809935, 79.51812421121906, 68.63221337718349, 80.91098923836985, 75.10432028001355, 69.07833591584237, 54.12889272935929, 43.00081083851476, 66.31291589429303, 85.6225638235769, 52.57495949345251, 0.8035506043703327, 0.19544347790220093, 0.18225424772789403, 0.09455130705910345, 0.3028864052987868, 0.20581407142021965, 0.2722084143709752], [0.04893231100492901, 0.037585319275216716, 0.03847315389242384, 0.04190805848808058, 0.04060550600350384, 0.037253622356201374, 0.022939382488989545, 0.015031066422741261, 0.01709409523755312, 0.06257350241104442, 26.635486156709735, 63.265116599298295, 47.93654887906967, 34.27523951376639, 36.31278138006888, 42.483838527433335, 58.5766996875886, 68.38511190106793, 57.558895618684836, 63.89217022926577, 35.806862308133034, 0.030010657482630307, 0.10072110340960565, 0.208531369965884, 26.273165056782386, 70.48420752248457, 57.77466127949377, 61.37018426772087, 51.17867808188162, 49.89391357667985, 48.431285273644235, 48.65368758478473, 43.90988288387176, 43.90502698959843, 43.12453416086013, 42.35977788125315, 40.376906010412405, 39.09750338523619, 37.988206109692975, 39.554067273293775, 40.24754231975925, 41.893957199588904, 41.063752251286665, 43.40292438384026, 42.25257558207358, 41.238646814900065, 39.639072879668205, 38.26242685317993, 38.22892196716801, 37.893429879219305, 35.72718720282278, 36.41553571147304, 37.85846194913311, 36.26750938354, 36.62430386389456, 36.609128213697865, 36.31506027713899, 37.9050910857416, 38.54326463514759, 38.81892881085796, 36.579102470028786, 40.89099537941718, 36.311039847712365, 37.68009216554704, 37.91604234326271, 38.456442971383375, 37.18191585233135, 37.88427114486694, 37.65575385862781, 38.38596974649737, 34.46233657098586, 39.3662053538907, 46.20744651363742, 49.72250992251981, 45.37761811287173, 40.654970676668235, 37.8797290402074, 37.84828339853595, 36.55275198721117, 38.735201897159705, 37.75923382851386, 39.98100942181003, 38.38403601800242, 37.16710498256069, 38.48308763196392, 39.470454108330514, 38.76181517877887, 37.85977986551101, 40.62691788519583, 39.34374193991385, 38.53490998668056, 39.192299227560724, 35.46471395800191, 37.216028705719985, 36.88242327782416, 40.256528469824026, 38.451057557136785, 38.48560187124437, 37.395453606882405, 38.28489026715679, 37.97079863086824, 39.008704846905125, 39.90163241663287, 40.47094483529368, 43.176654615709865, 47.87814478720389, 47.93046528293241, 47.24349744858281, 38.24784348087926, 38.090070063068026, 37.10257414848574, 39.219740129286244, 37.549630211245635, 37.06724536034369, 37.83238995459772, 37.15290992490707, 37.75711967099098, 37.9772077837298, 37.282014739128854, 39.33807411501485, 38.827644317380845, 37.892912126356556, 36.54787648108698, 37.90232973714029, 36.62892049358737, 35.996724636324, 36.353966266878196, 38.85800738488474, 37.53397995425809, 37.652357086058586, 37.921576807575846, 38.146407065853, 38.80820505080685, 38.70942800275741, 40.40620219322943, 39.543241531618186, 39.909096687070786, 40.32839021375103, 40.41159937458654, 40.88721029220089, 40.78171422404628, 43.473209334957986, 42.79822434148481, 43.1991768652393, 42.99843780456051, 47.69345606527021, 55.77579006072014, 64.30878869948849, 60.82106813307732, 62.49279014525875, 60.71217529235348, 61.966086433779815, 62.06067831285539, 68.0126985426872, 5.870944838370047, 0.5519393218621131, 0.7247432008866341, 0.7710340943547987, 8.412835847946907, 68.74342826104933, 60.11175455585603, 67.51752284265334, 62.451919048063225, 55.72150053516511, 41.878910987607895, 45.03733681094262, 48.42710794941072, 64.87116636768465, 27.014302784396758, 0.15893781016911232, 0.11316161287287552, 0.04377472747658049, 0.09487500985062892, 0.06965266044942603, 0.06856166697557896, 0.046012366881533984, 0.022641661569416043, 0.052476321842761776, 0.033743553043853854, 0.06434983048107355, 0.10073735979535889, 0.05933745125789316, 0.030897944346971573, 0.047780229679999814, 0.01750740733358168, 0.05796678206552902, 33.95160867321876, 71.78142947535362, 54.79536617955854, 37.187203207323634, 32.849085330963135, 47.5620605868678, 64.42663631131573, 71.49144080377394, 63.24830532073975, 68.79467010498047, 39.63052603506273, 0.07538731885893692, 0.0941782299008581, 0.2030978300758908, 30.281372377949378, 70.828411194586, 60.12945229007352, 63.595646888979026, 50.840350120298325, 52.42570546365554, 50.47160025565855, 50.657587282119266, 45.207140138072354, 47.720689081376605, 44.912742722419004, 45.69782472425892, 42.31389007260723, 39.984366970677534, 40.302204470480646, 40.420958149817686, 41.87340790225614, 44.164334881690245, 43.98208979637393, 43.96393314484627, 44.253015748916134, 43.10119213596467, 41.16087405912338, 40.99681700429609, 40.54053160452074, 39.182814936484064, 37.514015090081, 38.41260656233757, 39.00526885063418, 41.19024868934385, 38.4197570431617, 38.846326566511586, 39.86042399560252, 40.93499652801022, 39.45745537357946, 39.76228629389117, 39.599154918424546, 40.836639173569225, 37.72008465182397, 40.00159402047434, 40.204455083416356, 39.49196830872567, 38.15977450340025, 39.804232120513916, 39.64954953039847, 39.038369732518355, 37.095047120125066, 43.62240452920237, 48.10423020393618, 49.63613540895524, 48.25077779831425, 41.44799547810709, 38.578562044328265, 39.71901862852035, 37.06735910907869, 40.31774097873319, 39.58464999352732, 40.19307628754647, 39.95515315763412, 39.11038444888207, 40.12161070300687, 42.54720833993728, 39.85118289147654, 41.46347315080705, 41.02303804889802, 41.58939692281908, 40.31615634118357, 39.80657769787697, 38.20554071857084, 39.31134316229051, 38.75495103097732, 41.19633620785129, 39.89919270238569, 39.247781153648134, 38.51780060798892, 39.67198156541394, 40.73655989862258, 38.731475645496005, 39.16015932636876, 40.97419669551235, 45.20421012755364, 50.426540067118985, 50.67369253404679, 51.17993324033676, 40.45530242304648, 38.56386100092242, 39.32376923099641, 40.77363414149131, 41.13131899987498, 40.03818581181188, 38.64139056974842, 39.59416958593553, 39.28184301622453, 39.94318992860856, 38.60734831902289, 40.86790046384258, 42.084003879177956, 40.33587409603981, 38.8352458707748, 39.666721667012865, 39.56523426117436, 38.872947692871094, 38.078557906612275, 42.25052418247346, 39.24637694512644, 40.443245057136785, 40.99578542094077, 41.10656492171749, 41.3508266018283, 42.29265828286448, 42.69225366653935, 42.8581581577178, 42.03857106547202, 42.20128666970038, 43.20591549719534, 44.024188595433394, 44.066381531377, 46.58708095550538, 44.302504293380245, 43.93997923020394, 44.05944285854217, 49.992620022066184, 59.12790252316383, 65.48608810670915, 63.54900598526002, 65.72275607816636, 63.458285485544515, 65.50175797554755, 63.61105788138605, 70.44482692595452, 7.001593535946262, 0.5663273723856096, 0.5241574803667685, 0.7772512349390215, 8.752559192719, 75.24988728184854, 65.36301589781239, 73.09900068467664, 67.63849658350792, 62.044349485828036, 44.35249882359659, 46.031387006082845, 55.833009596793886, 74.21760574463876, 33.76551182039323, 0.20011992374014473, 0.06047588089601167, 0.049849540415790775, 0.03080889620187302, 0.006774116191081704, 0.05846421061564357, 0.05999480066220126, 0.09417267576340707, 0.147936481141275, 0.14162541817753546, 0.28970668993649945, 0.19933863663144652, 0.22898829241673793, 0.19229251230435987, 0.1469222420165616, 0.0976620223974028, 0.14025736900587238, 38.206027092472205, 79.097104841663, 61.390164821378654, 46.878226726285874, 49.22185074898505, 55.53511342694683, 70.24534302373087, 77.53906096181562, 67.81050036030432, 73.17681266415504, 45.78705864567911, 0.19144981558765137, 0.1816434611476237, 0.30931679411761226, 32.046221263947025, 71.72606914274155, 62.983788521059104, 63.96665603883805, 52.969581311748875, 55.0447779317056, 54.45684994420698, 54.29557384983186, 47.539628551852324, 48.89573704811835, 47.18812534886022, 47.67041214050786, 45.64444911095404, 43.09583025593912, 42.92312829725204, 43.48533730353079, 44.482815650201616, 45.672423455023, 45.09325412011916, 47.97766316321589, 46.45821932823428, 45.78179482490786, 45.031818036110174, 43.140835531296275, 42.91396564052951, 42.571119108507716, 40.413042806809955, 41.038045037177305, 42.79653772231072, 44.27312966315977, 40.61220899704964, 41.406139865998306, 41.758678574715894, 42.188099661181056, 41.35787117865778, 42.41723275953724, 41.66157245635986, 45.378630084376184, 38.441267321186686, 41.75919632757864, 42.761922805540024, 42.738474876649924, 39.76375326033562, 41.40806574975291, 41.95446760423722, 41.87941697336013, 40.436792758203325, 45.02018428617909, 51.20587971902663, 54.61206597666587, 48.55832692115538, 42.78214262377831, 39.841318130493164, 40.51398108082433, 38.291385712162146, 40.43273702744515, 41.55790421270555, 43.79698138083182, 43.69037920428861, 41.270484693588756, 41.99664092832997, 44.71526707372358, 43.19881208481328, 42.03479382299608, 43.740091323852546, 44.84224988568214, 41.77414840267551, 43.73105026060536, 39.05219608737577, 40.566399635807166, 38.963299489790394, 43.12422821598668, 42.569016718095355, 41.14265464967297, 39.663246447040194, 40.64805946042461, 40.61084008985951, 39.57864092242333, 40.26208254598802, 40.43033261452952, 46.44901744781002, 51.501163590338926, 52.887391967158166, 52.69530957744968, 41.81290141997799, 40.893635134543146, 41.18778151850547, 42.912800696588334, 42.50696874433949, 42.500649805991884, 41.748656918925626, 41.635943689653956, 41.46215131205898, 43.028220361278905, 41.18492603302002, 43.43232647065194, 44.085177529242735, 43.09604990866877, 41.9946954327245, 43.18844918281802, 41.39080732099472, 41.84652397709508, 40.70966028398083, 45.557658826151204, 41.88799519692698, 42.50191673155754, 43.79516140107186, 42.75727479688583, 43.44471331565611, 43.82124516271776, 45.62921462520477, 45.64593176687918, 44.212666326953524, 44.587911636598655, 45.9334611123608, 45.31165169131371, 46.296331344112275, 48.90937512920749, 47.51972252322782, 47.302427138051684, 46.86491420192104, 53.3986258506775, 61.165569905311834, 69.42197476663898, 65.79369214273268, 70.72607655679026, 66.48732016163488, 67.13619785924112, 68.52062979052144, 73.11902830677649, 8.549355902979451, 0.9063589296513989, 3.267247080802918, 1.3163562551621468, 9.859883516065537, 81.4416310095018, 71.94382344522785, 78.90199830455165, 74.48668033845964, 70.91227931361045, 56.805019993935865, 58.40269550200432, 63.852770020884854, 82.36004614060926, 43.69893389363443, 0.25010360615147703, 0.24520323281326603, 0.1555261601723971, 0.18271270538530043, 0.1679077038481351, 0.17434025303490702, 0.17537234200825616], [0.09148123268518718, 0.03653181048350469, 0.11004364268193323, 0.05079071007428631, 0.1232012257640881, 0.08129853755235672, 0.07100685109053889, 0.101207293449871, 0.12407479582414513, 0.16765745356678965, 11.706615801780455, 61.94990273444884, 50.679289756282685, 35.92463931729717, 25.818911444756296, 40.59855522647981, 54.95221784037929, 58.88973228393063, 60.66334570607832, 60.11991700818462, 46.78510181365475, 0.8270737937381192, 0.05351789881505313, 0.07451923398841774, 3.7982168601405237, 63.10529962662728, 59.79755309320266, 63.3746801653216, 56.11825612283523, 54.479925247930716, 50.533134398921845, 51.1252514777645, 45.4552928093941, 45.189152148462114, 41.478774316849254, 39.91897713753485, 36.505259929164765, 41.15490028935094, 44.17133631244783, 46.88762864758892, 46.52781786457185, 46.83439031724007, 45.320649608489006, 45.125201825172674, 43.059705226652085, 43.47907720073577, 38.17961385173183, 37.123649043421594, 36.79167924388763, 37.82556110812772, 37.85703812876056, 36.54124767549577, 37.69903329110915, 36.99538361641669, 37.33648861608198, 37.97595262527466, 38.072317415668124, 39.82110223462505, 38.14202185600035, 38.51658075086532, 37.70923929829752, 38.306490759695734, 36.71269839809787, 37.93912941409696, 37.09997753943167, 37.74851399083292, 37.31606483459473, 38.57460045045422, 37.04400139470255, 38.52744179387247, 34.69981255069856, 40.11215386852142, 45.66534357686197, 48.55629513340612, 47.32555343258766, 40.31364210190312, 39.444072246551514, 37.44394194695258, 38.335386860755186, 38.34451029377599, 39.940812972284135, 41.12569432104788, 37.927177952181914, 37.240527829816266, 37.94343225417599, 37.936077810102894, 36.78658016266362, 41.03160058298419, 39.62041808712868, 40.33232827340403, 39.42033013989849, 37.56094232682259, 37.74925924116565, 38.90600542868338, 38.597212914497625, 38.888221402322095, 39.11518542997299, 37.883392533948346, 37.035093692041215, 37.80811832797143, 38.20887081084713, 38.86403214546942, 39.79917226299163, 40.99621688165973, 46.84265082882297, 48.271472223343395, 46.75040060474027, 47.94660191382132, 40.3963178203952, 37.66734446248701, 37.52883380459201, 39.265416129942864, 38.04245641154628, 39.315269454833, 37.96958269611482, 38.474125016120176, 38.327616645443825, 36.93388869685512, 40.560057163238525, 38.9569374053709, 39.39824719582835, 39.257622380410474, 38.79607708223405, 38.048516473462506, 37.773554402012984, 36.18311566691245, 37.435999147353634, 38.28681222854122, 36.8079766919536, 39.11786048643051, 38.22246182349421, 38.96539011309224, 38.11150581605973, 38.33786972107426, 39.72443149935815, 40.74521656959288, 39.21722589000579, 40.2129783938008, 39.01785573651714, 40.3868099950975, 40.7674446413594, 40.5126396302254, 44.41282487684681, 44.125166093149495, 43.4487533569336, 45.672411687912486, 45.735295126515055, 53.84352853221279, 54.430538685091086, 55.1238803709707, 52.25323492480863, 64.01721931272938, 63.26073531181582, 70.39533445912024, 6.99687296344388, 0.6495945107552313, 0.4788883949720091, 0.5920080492092717, 8.543200723586544, 70.11998407302364, 59.268186092376716, 70.31363148843089, 63.001062639297984, 52.95837510016657, 30.24809891177762, 42.01395427027057, 51.848532615169404, 63.912794051631806, 16.628407855187696, 0.1694600584526216, 0.1737840885236379, 0.04732089102148049, 0.19778514821683207, 0.0496191356421238, 0.028618110734368526, 0.04136103340574811, 0.07961116761209504, 0.05715867038816214, 0.028753476555369077, 0.022391277222683834, 0.07214607746009866, 0.04811924273869203, 0.0924009059165274, 0.06313130635047151, 0.08615747319474336, 0.023247104686414524, 15.512739669892097, 70.01291905680011, 55.983138315139286, 41.81980871385144, 30.824710861329113, 45.43428067238101, 61.15919605378182, 65.80355298134589, 64.05425825426656, 64.3845453569966, 51.58838925823089, 0.8187137520120991, 0.13810354345027478, 0.1746003705287172, 4.351885885961594, 66.68801999861195, 60.566486697043146, 65.2990734192633, 57.801447145400516, 56.43780769840364, 51.95965728452129, 52.89966114105717, 48.34582467232981, 48.05898566399851, 44.32012750256447, 41.488031110455914, 38.39410866460493, 42.78494319608135, 46.407306963397616, 47.27790055736419, 47.72417214608962, 49.72427891146753, 47.39617570754021, 47.1829282083819, 45.82181084540583, 45.530398353453606, 42.058402569063254, 40.89538058926983, 38.20221062629454, 38.6248028662897, 39.20881632835635, 38.950226230006066, 39.17451127882927, 40.18740061790713, 39.21840652342766, 40.00615573698475, 40.18779285492436, 43.123632015720496, 42.21597202362553, 39.95290563952538, 39.56707777515535, 40.52735636311193, 39.261117212234005, 40.23623412655246, 38.408519452618016, 40.28183560217581, 39.45263085826751, 41.07036928976736, 38.316045653435495, 40.1207987723812, 37.83109557244086, 43.76308818017283, 47.27577855510097, 48.633954140447806, 50.11331135226835, 41.46542649115286, 38.15251027384112, 38.93436416502922, 37.77588821226551, 39.63160468686012, 41.040469061943796, 42.785825729370124, 40.91444723067745, 38.85243369686989, 38.169192114183986, 38.739179180514434, 39.30958201808315, 42.7185570809149, 41.32074202260664, 42.066639546425115, 40.159081105263006, 40.47947599041847, 39.45580013336674, 39.86313435339159, 39.82135718868625, 40.99947244890275, 41.3863475861088, 41.19469273474909, 38.69310702047041, 39.09510289469073, 38.66719584311209, 39.509477769174886, 40.30576206022694, 39.4862965614565, 47.20490917082756, 51.59029553013464, 47.94982217973279, 50.533703142596835, 42.0389280011577, 40.563049931680005, 40.93021515877017, 40.10763529808291, 40.605642949381185, 41.620775884197606, 39.14849027510613, 40.195951384882775, 38.004158389183786, 39.1653682339576, 39.24256832368913, 39.83035510586154, 42.93549945277553, 41.31702753805345, 39.73910116380261, 38.93288935384443, 40.038868304221864, 39.01739681920698, 39.151082961790024, 40.49893486884333, 39.03146636101508, 42.12633802044777, 40.00441028225807, 41.20707565738309, 40.795297391953014, 39.16150469933787, 41.08155588949881, 42.2097707563831, 41.542222576756636, 42.08261928250713, 41.2804239796054, 43.132100412922526, 42.20645635358749, 42.98426628112794, 46.30696488964943, 46.45010002197758, 45.313106890647646, 46.69595418437835, 48.675586177456765, 57.40212632763771, 57.390119952540246, 56.670737651086625, 55.66709726087509, 66.32970363863053, 67.00809324941328, 74.15030571722215, 7.947865830313775, 1.4561480572146754, 0.1666992614346166, 0.7149582356214524, 9.690332201219375, 75.48792023812571, 64.12054238780853, 76.99426727910196, 70.26829673397926, 59.306060498760594, 38.92123599206248, 48.70415279942174, 56.801576152924575, 73.71530702037197, 23.331705139529323, 0.2912175991842824, 0.16485948596269856, 0.016945386080131415, 0.1550937035391408, 0.03151411077969017, 0.06474684788695266, 0.07476974473965746, 0.22107063582347286, 0.12185690233543997, 0.219016662167926, 0.2270240583006413, 0.20645308067962048, 0.20686568031387947, 0.19499911626260127, 0.24215495364079553, 0.2240107893463104, 0.34009578607736096, 18.170326871256677, 79.56321577872001, 64.48973548027777, 47.92755488426455, 36.449079821186686, 54.3583631515503, 67.63087934063327, 68.42747349892893, 71.58180436780377, 68.56483490236344, 58.811986984745154, 1.0075458451624841, 0.37069195881485945, 0.23029375220498732, 5.705062410523815, 67.60827079896005, 61.52883237408054, 70.26055397525911, 60.93493846154983, 57.95589439330563, 53.883305288130245, 56.10779123921549, 49.37201084629182, 49.31463833778135, 45.26019019465293, 44.01569666401033, 39.56819565065446, 45.575662505242136, 49.15444873994397, 49.54439117062477, 51.328147842038064, 52.364151708541385, 50.23958813759589, 49.71518293503792, 48.22614139126193, 49.476706750931285, 43.700549910145426, 43.57439079592305, 40.30472655450144, 42.38256685195431, 42.08596114189395, 40.737893504481164, 42.18550697449715, 41.75978860547466, 44.40807096419796, 43.291666353902514, 42.87535382855324, 46.743014781705796, 44.514190689209975, 42.55861851476854, 41.150879859924316, 43.32654014710457, 40.58048094472578, 42.501767681490996, 40.31723107061079, 42.58056417588265, 40.98592458232757, 44.18713954187209, 40.58627036310012, 42.2246757630379, 39.369990441106985, 45.80486620626142, 50.791461698470584, 52.23823970363986, 51.85272562888361, 41.52854919433594, 40.51346725033176, 38.47750609920871, 39.622026258899325, 40.56947477402226, 44.077348478378795, 46.101024766122144, 42.81254491498394, 41.07766489828787, 41.91782089971727, 41.96920394897461, 40.64246616055889, 45.73163555514428, 43.25011276429699, 45.468334690217056, 44.669136078126975, 42.13715983975319, 41.88539074313256, 41.825747182292325, 43.93439769744874, 44.48744404700495, 43.02620818538051, 41.593515411500015, 40.62663155217325, 40.927995097252634, 37.86732258335237, 40.71200978371405, 40.32126326714793, 40.557664517433416, 47.891610284005445, 53.472919464111335, 48.58998437081614, 54.53163385391236, 45.48662470233056, 42.65588152793146, 42.89463620032034, 43.37359289969168, 42.20583661910027, 43.28516306415681, 40.76618948290425, 41.78507612597558, 41.771869505605395, 41.885559405049975, 42.49022414607387, 43.1470799446106, 45.632552562221406, 43.805186979232296, 42.385316433445105, 40.507838649134484, 43.26334291888822, 41.616280847980136, 41.70403603584536, 43.654218873670025, 41.93292202488069, 45.310220026200824, 45.05423830401513, 43.633214581397276, 42.99853194144465, 41.92102939851823, 45.482616040014456, 45.229489803314216, 45.23325135630947, 44.73665183590305, 43.36573246986636, 44.977477519742905, 45.04038057019634, 44.57009623127599, 48.82198472176829, 49.26702076388944, 46.81298202083957, 50.064540601545765, 49.91259974818076, 59.942394456555775, 57.87875313912669, 59.93633047226937, 56.98947729602937, 70.52719669957315, 69.93607982512444, 78.86515155915292, 9.242456363093469, 1.6142384515654657, 1.2987994811227246, 1.2178080528974533, 10.851661678283445, 82.6084812225834, 69.22973940449377, 82.40734208014705, 74.47126542368244, 68.05338136611446, 43.77491020387219, 57.69579418243901, 67.57283610682335, 83.04992829599689, 29.257755356450236, 0.4946501943613253, 0.3006998065017885, 0.23696555065051203, 0.2805344724366742, 0.16947914936369465, 0.26328211109484395, 0.12489188222154496], [0.01698502155411388, 0.04277973248052501, 0.03676422240753328, 0.03708561161352742, 0.06062658954291575, 0.029669238907855847, 0.0148280291825593, 0.021375653394047293, 0.07580446139458688, 0.14124459587037563, 4.353988276373956, 53.33041583338092, 51.548534054909986, 42.50969479160924, 25.52748718569356, 34.25096004239975, 54.60187958132837, 60.60269017373363, 62.11850189393567, 54.88493742481355, 57.37427357704409, 4.280369800906028, 0.42332621351365124, 0.2825509690709653, 0.18730045356337102, 24.518704568186116, 66.82803292428294, 56.38260818296864, 60.56958536947928, 53.32960390275525, 53.080168616387155, 52.28127987154069, 47.9932035938386, 41.58704350071569, 41.40862664868755, 41.71885867272654, 48.126670083692, 52.7946553691741, 55.63603993385069, 52.9322442700786, 50.676830430184644, 48.64616055642405, 45.56698622242097, 46.64632051221786, 44.76202564854776, 42.89341634319675, 40.14689430113762, 38.41555618470715, 36.87491978368452, 37.5918702156313, 37.30202667174801, 36.605060715829175, 37.62239802268244, 38.52717507270075, 35.62558997061945, 37.34454516441592, 36.760433643094956, 39.638323706965295, 36.16556698276151, 38.50975582676549, 36.6516427839956, 36.96476559485159, 37.79704547697498, 39.47180340366979, 37.04179310029553, 37.88446334100539, 39.36897062486218, 37.80905185207244, 39.47640042151175, 38.028818330457135, 34.79133713629938, 38.62676405137585, 45.827219793873454, 46.681398268668886, 48.31938005262806, 41.82042844833867, 38.37995283065304, 36.899136497128396, 36.04070617306617, 36.86205048714915, 38.8906571941991, 40.510278363381666, 38.22506235491845, 36.49120215446719, 37.72041020854827, 38.110717419655096, 37.37293135735297, 38.2941980515757, 40.61562145909956, 39.02473557379938, 38.98418218858781, 37.55484304120464, 37.71114557020126, 38.252436576351045, 37.98006719158542, 39.49068177130915, 38.881408245332786, 38.66885892806515, 37.31377024804392, 37.09351347338769, 39.1919344471347, 39.08875649975192, 38.52655533821353, 41.08832590041622, 47.7411913102673, 49.02595581546907, 47.96591958691997, 48.33220620309153, 40.987607279131495, 36.93080963626985, 39.3044594026381, 38.69140863418579, 40.44067590467392, 39.21418997549242, 37.87761096031436, 38.4005452740577, 37.99764725469774, 38.68304614097842, 38.57841299426171, 37.612211627344934, 39.57900570284936, 37.75730402238908, 37.985582044047696, 36.99945111428538, 36.48630311412197, 36.048837246433386, 36.23437712269445, 37.487091941218225, 36.15035995360344, 37.046401885248, 36.57671766896402, 38.35472022333453, 38.66406186934441, 38.491046121043546, 39.84547192050565, 39.65303651748165, 39.981087869213475, 40.961954978204545, 40.17588846145138, 40.73344945907593, 40.73639515907534, 41.488293909257465, 40.24040360604563, 41.2439694712239, 41.2470720660302, 44.50305900266094, 43.043749024791104, 46.57498044352378, 44.51081352849161, 44.80871754307901, 49.87891051077074, 60.729386652669604, 60.61248825442407, 70.21377578858407, 5.936017940121313, 0.5201507792357476, 0.45617168168387107, 0.7301484108451874, 11.061987011663376, 67.77658754779448, 58.6165980369814, 67.23397470289662, 56.78099547663043, 54.40598072544221, 33.169150737024125, 46.27187536608788, 52.37903318097515, 60.01425620048278, 7.935728546111815, 0.3275748450429209, 0.0778489049163557, 0.07992309563222431, 0.1228155387986091, 0.03194899016600703, 0.01202806400420565, 0.025289311231444442, 0.023828205359618992, 0.07331652191257285, 0.09793633550044992, 0.03524305524244424, 0.018669026453168164, 0.027651863187671672, 0.046442322237717534, 0.051753678764667244, 0.04518336015603235, 0.1228913891639921, 6.483874993939554, 64.96587591786539, 56.46945338095389, 44.32638760535948, 25.604320533813972, 42.8131450376203, 60.5176688778785, 61.591288274334325, 64.60400981287803, 60.39103123449511, 61.89312250383439, 4.290240445444661, 0.5176432202419927, 0.3849261175961264, 0.09319337024804085, 27.886108390746582, 68.68125084907778, 59.86851269199003, 60.57099742274131, 56.17624052109257, 53.86985548080937, 53.21986383007419, 50.9939815152076, 43.12173751092727, 42.37101154942667, 41.87048965884794, 50.27016301308909, 54.02667576266874, 55.71516198496665, 55.18524977468676, 52.60369869970506, 52.66429931886735, 48.307020664215095, 47.9766551140816, 46.91182182681176, 44.05415942592006, 40.3964158796495, 40.04745437252907, 39.127776238226126, 39.57536574332945, 39.13805677044777, 39.463640951341205, 38.79628496785318, 40.5729539163651, 38.890790554784964, 39.95772623246716, 39.93852623047368, 41.21108824206937, 38.88260456823534, 41.02301451467699, 39.65462115503127, 39.66136763172765, 39.60388137448219, 41.255940544989805, 39.147266495612364, 38.627395552973596, 40.622167894917155, 39.667168817212506, 41.54601943108344, 41.585368648652114, 36.73441263937181, 42.567738025419175, 47.81655573075818, 47.8996785994499, 49.280192082928075, 42.01995941900438, 38.148619282630186, 38.20852956464214, 36.973857648911014, 38.294099992321385, 41.60554139844833, 41.360106929656, 39.569541023623565, 39.69460187419769, 39.11427151772284, 38.83244529847176, 40.192633059717, 40.045791287576, 42.011494944172526, 42.42972158616589, 41.62462372933665, 39.384664027921616, 38.825588995410556, 40.42916767058834, 39.75495930640928, 40.90661033507317, 40.79976889394945, 37.93847045590801, 37.229886439538774, 37.75826108071112, 38.91539950524607, 38.68160663112518, 38.439502254609145, 42.31716132933094, 50.47541672183622, 51.721024205607755, 48.033682454016905, 51.14877785405805, 42.50210500532582, 38.81539867770287, 40.54255946989983, 41.4315725141956, 41.88304908813969, 39.645093717882716, 39.900910700521166, 39.61787639125701, 39.43112058024253, 40.31349305183657, 40.38925755408503, 40.65306048239432, 40.236528304315385, 39.85331273848011, 39.981048645511756, 39.18398380279541, 39.520872254525464, 37.55136782123197, 38.17678190046741, 38.71647650195707, 38.70494473365046, 41.2550776235519, 37.89021745804818, 41.588079006441184, 41.74950022851267, 40.32391871175459, 40.921715382606756, 42.86400641164472, 41.34599816414618, 43.36439886400777, 41.94652088226811, 43.18648799773186, 41.88542212209394, 43.28728898879021, 42.829575846272135, 43.590233249049035, 44.52949577762235, 46.916124666890795, 46.059875180644376, 50.144247085817405, 47.68238321427376, 46.31008709630659, 51.957868683722715, 63.57397579377698, 63.93471225615471, 72.17161117061492, 7.434470230533232, 0.694767406150218, 0.8741481806482039, 0.5332008112342127, 11.970357933352071, 74.20777628498693, 64.69081970953172, 73.04735875898793, 62.68289173803022, 61.256290405027336, 36.884286403656006, 51.74563315606887, 58.57351080063851, 69.60119570455244, 12.067984746348474, 0.33061425291722824, 0.16806746382386456, 0.042160936451006326, 0.06998194036104026, 0.08829243000476591, 0.05212100643304087, 0.03257147682410094, 0.08236054225914902, 0.1506428399513806, 0.24197138365237947, 0.2812376492206128, 0.20331360640064364, 0.1420205969723963, 0.15298401996974023, 0.1619327389785359, 0.18516449317816766, 0.3276023016341271, 7.61625345676176, 73.77648030557941, 64.16471612068915, 56.305921923729684, 38.86177678262034, 48.42392690720097, 66.09234533002301, 70.85276126861572, 72.15034407954063, 65.32412951992404, 67.10946298414662, 5.3055915621019185, 0.7598124997269723, 0.4012622071370002, 0.29502769151041586, 29.86465192610218, 68.0852702356154, 62.51887390690466, 62.95739489216959, 58.38859850360502, 58.02424169355824, 56.170976700321326, 52.99964627911968, 45.20791676736648, 44.86044183854134, 45.334946647767104, 53.36459144469231, 56.184473576084265, 57.86213405670659, 57.23885374684488, 55.09873405579598, 55.3211324445663, 49.78077673142957, 52.05684577265094, 48.40022010187949, 47.55545531549762, 42.592139090261156, 43.170343522102606, 41.13258592544064, 41.50758020339474, 42.243024610704, 41.56791017901513, 42.03484089143815, 43.73438035288165, 40.58988286602882, 43.49347229926817, 42.517406171368016, 43.81831907456921, 39.35561103205527, 43.481501225502264, 39.61629567607757, 41.79920450333626, 42.785935555734945, 43.10384365820116, 40.3025221824646, 40.68193304923273, 44.30862319084906, 41.453298522580056, 42.16165111910912, 43.64560142640145, 38.170215852798954, 44.161644135752034, 51.154496669769294, 53.192717106111594, 52.18235377342471, 42.09444522857666, 39.2548845660302, 38.24442317408901, 37.766294094824026, 39.27993674432078, 43.80961533515684, 43.6634325212048, 42.25657247727917, 40.893172294862815, 42.42130025740593, 42.05798287545481, 42.078885186103086, 42.081207229245095, 43.83215327416697, 44.884697775686945, 42.475009272175456, 42.80577490406652, 40.34393456674392, 42.9924601124179, 41.231923872424716, 42.8707685778218, 41.52690179886357, 40.2872210164224, 39.321302060158025, 38.71757868797549, 39.09680520334552, 39.656382299238636, 38.54124069213867, 42.45295378469652, 53.557642659833355, 54.61205813192553, 52.518116504915305, 54.46838171251359, 43.91399745018252, 41.12469411665394, 42.722965824988584, 42.775913899944676, 44.148539497006325, 44.24686939485612, 42.358361905620946, 42.446379892287716, 43.56769138766874, 42.86333568634526, 41.99462090769122, 42.69888247213056, 43.50010502722956, 43.33864458145634, 43.38252805894421, 41.999731756025746, 40.876294336011334, 39.47396855200491, 41.17306870798911, 41.439303505805235, 40.232107793131185, 43.92195201689198, 41.59081682082146, 45.0646992652647, 45.096372404406154, 42.280914706568566, 45.34894950928227, 46.31308378711824, 44.45574345127229, 46.511155636079856, 44.72626539968675, 46.6899686474954, 45.20123304859285, 46.00760959809827, 46.180288022564305, 46.27076533532912, 46.59999339811264, 49.95260400156821, 47.59156465530396, 51.41229444934476, 50.60729072939966, 50.1613486197687, 53.34461089103453, 66.2485811787267, 65.51205419724988, 75.27313909223004, 8.570554352575734, 0.682542420202686, 2.807900271108074, 1.2439532241513653, 14.027669525915577, 80.2147763775241, 69.46821951097058, 78.81663184012137, 68.32333457085394, 69.21037074058287, 44.1421107322939, 60.262271588848485, 68.2947483370381, 79.30546898995676, 17.784032244836133, 0.5631522137311198, 0.3483129370837443, 0.20836566514786214, 0.19551749731744492, 0.17290261243620228, 0.12254812814775976, 0.19331229790564508], [0.04946691014112965, 0.033939974157199744, 0.013417704406404688, 0.10329783248204379, 0.18540398758505622, 0.08273247794638719, 0.10510307271033527, 0.07516485458660511, 0.052860871167673226, 0.2072871512463016, 3.236054922303846, 47.96815533791819, 56.214581689526966, 42.55258590944352, 36.19537699607111, 35.513869101001376, 50.359577363537205, 65.17571487734395, 61.34208833017657, 56.74469394068564, 62.246057371939386, 10.095639536457679, 0.455422171902272, 0.3666080666645881, 0.07626983682594954, 1.9205440604879012, 55.10838308641988, 61.52064638753092, 56.18131606809555, 57.32025861740113, 53.50866794586182, 51.12184686045493, 43.63265760483281, 43.2995738521699, 45.64859113385601, 51.275368428999386, 59.46822697116483, 58.358439399350075, 53.09382238695699, 49.499829123097086, 48.323871166475364, 49.36851993683846, 49.37725113284204, 47.92084370889972, 44.85317368661204, 41.317211889451556, 37.43200617451822, 38.04262899583386, 38.13174132377871, 38.28071686529344, 37.511230207258656, 36.30639183905817, 36.39416663877426, 37.55549023228307, 35.85169499920261, 38.8792940878099, 36.077548996094734, 37.848146115579915, 36.783967864128854, 39.02113876035137, 38.225176103653446, 38.057286893167806, 36.059596307816044, 38.62568932194864, 36.897944096596014, 40.82394246132144, 40.13242075520177, 38.80181158742597, 38.5087634671119, 37.85541034513904, 36.225626314840014, 40.133303288490545, 44.08806831605973, 45.0624046787139, 46.980078912550404, 42.16592258022678, 40.551227907980646, 38.62890566548994, 36.43746568310645, 37.86006619853359, 38.64494423712454, 39.7272438387717, 38.91334810564595, 37.266843011302335, 36.534316847401286, 38.94757470776958, 35.77252587964458, 42.33709089217648, 39.85639179906538, 40.127486413525, 40.10257151819045, 38.44645661692466, 36.609143903178555, 39.37741548784318, 37.12614759322136, 37.93155531729422, 40.24596552694998, 39.32011358199581, 36.47184525766681, 38.48903786751532, 37.5619621430674, 39.36114157399824, 42.43150234222412, 42.60466714059153, 47.94775901302215, 50.37004616952712, 46.5544193790805, 45.8863809031825, 40.27272393626552, 37.442325930441584, 40.100198484236195, 40.02963504483623, 39.964025558963904, 40.99909982373638, 39.614059925079346, 38.6338988427193, 37.77335043876402, 37.992253995710804, 37.068324012141076, 37.655353776870236, 39.326793378399266, 38.404993241833104, 35.96109774804885, 35.89961067322762, 36.06295777905372, 38.02415070995208, 36.40662800881171, 36.704877191974276, 36.544805265242054, 37.338634152566236, 36.924843711237756, 38.44878650480701, 37.0997461195915, 37.91383404885569, 38.05272125428723, 39.42022423590384, 40.24457700790898, 42.01320117519748, 41.46021366119385, 44.21440393693986, 45.10575471385833, 46.546284383343114, 46.501188893472, 49.09542491359096, 48.75448073110273, 46.83032674174155, 45.60250720670147, 44.151140028430575, 46.658381800497736, 46.841834975827126, 53.2346119419221, 61.79679693714265, 63.04835857883577, 63.132422816368845, 3.8677420971855043, 0.5592234084202398, 0.4017583256767642, 0.5712012237598819, 13.272019028663637, 69.07061669134325, 57.14785868121732, 68.97654256513043, 57.389747327373875, 48.90338174758419, 24.464397391965313, 44.23523564492503, 50.305146632655976, 50.57235025590467, 3.1041090863366283, 0.14687425426898465, 0.15059092983363137, 0.04826710536895741, 0.03614566386527112, 0.0075800593608179164, 0.014684511228434503, 0.08673079807551638, 0.054854492416545275, 0.06966087291197431, 0.060175562938374866, 0.023173824546017477, 0.044061313308174574, 0.06363818459513207, 0.08602261873743228, 0.024529660360947735, 0.10607598905241299, 0.09259067355625092, 3.714858649238464, 56.69655861393098, 62.4404461153092, 49.79168876524895, 34.81616181711997, 42.328822535853234, 59.25065702007663, 69.30242876852714, 67.38211477956465, 59.44386120765441, 66.65210677731422, 10.264823129100185, 0.69532738577935, 0.5836296826601028, 0.0871400039402708, 2.3785416974175364, 58.638786885046194, 63.062122175770426, 59.749190268978, 59.2202704183517, 55.35875974162933, 53.13196743688276, 47.869605787338756, 43.77008568856024, 47.213016709973736, 53.167166786809126, 60.09903038701704, 58.83587029672439, 55.661539262340916, 51.19743877841581, 50.37680833570419, 52.17891385478359, 52.46283069733651, 51.32390383751162, 48.070301701945645, 44.0405095777204, 39.99603602194017, 39.59424803333898, 40.57076131143878, 40.63864969438122, 40.151648213786466, 37.45947845520512, 38.50797114833709, 40.333567742378484, 38.89780375265306, 41.63255476182507, 40.899467698989376, 38.87090021564115, 37.9716537075658, 40.50984298029254, 39.743560898688536, 39.70558451068017, 38.159088088620095, 39.70770259057322, 39.04848552519275, 40.855737193938225, 40.48013887097759, 39.841314208122995, 39.978981556430945, 39.910218484940074, 37.84847951704456, 41.367010301159276, 47.8072008778972, 46.93394399458363, 49.88898707974342, 43.74008740148237, 39.368621533916844, 38.86235729340584, 38.14190810726535, 39.33199051887759, 41.894471030081476, 41.15257040146859, 41.25220252621559, 38.4421576992158, 39.03035633025631, 40.792057514190674, 39.051333165937855, 43.98378426028837, 42.36466515448786, 41.173680597735995, 40.570875060173776, 39.8261817039982, 40.66893823685185, 40.87596093454669, 39.12090424568423, 41.54959663268059, 41.96358319251768, 40.914517833340554, 37.99677256614932, 38.24276008913594, 40.54000992928782, 39.929849947652514, 42.30392725236955, 43.095500776844645, 50.624380496240434, 50.91396908606253, 49.72324340574203, 49.30038444457516, 40.97833479604414, 40.32854710855792, 41.13875973609186, 42.44358716472503, 42.2632561960528, 42.40863100174935, 40.93938173786287, 40.465653557931226, 40.005865481592, 40.522045473898615, 40.181281720438314, 39.36302823405112, 40.82526037769933, 39.92529607588246, 40.317274216682684, 39.39489356933102, 39.19568031064926, 39.4972203623864, 39.55031356503887, 38.91946700311477, 38.30758510097381, 39.47139547717187, 39.78259240427325, 40.473659115452925, 39.26552595630769, 40.862295396866344, 40.63964205403482, 40.83518397423529, 41.91958988866499, 44.332757534519324, 43.656211437717566, 46.30011250895839, 48.861314327486106, 47.62865851002355, 47.7121030130694, 49.565740631472686, 51.32025603325137, 49.33118681753836, 47.31153880396197, 46.706395533777055, 49.773386986024924, 48.519911227687714, 57.772907980026744, 65.58686164117628, 65.41578746611073, 65.75163648974511, 4.528415587640578, 1.0302595553859588, 0.9599330516592149, 0.7203261217763348, 14.44137171391518, 75.03690258149179, 62.90927525489562, 73.578549661944, 60.640188032580966, 59.65463761360415, 30.79967437251922, 50.834643071697606, 54.42668691758187, 62.285481114541334, 5.090770702208243, 0.20021153253413018, 0.13719358421381445, 0.0877179253485895, 0.029862404147523548, 0.0011853957356276713, 0.028161809614468968, 0.03084292582746956, 0.13446542254138377, 0.14142222101649932, 0.07268847537136848, 0.15290020995082396, 0.2855606527338105, 0.28310527964945764, 0.20632229414918732, 0.1475214453474168, 0.1646092203595946, 0.2728946146465117, 3.8984564619679607, 64.53816106242519, 69.9539109199278, 55.80407034966254, 49.114315048340835, 48.96695160096692, 65.1171068222292, 73.94622479715656, 71.01561023342994, 66.36508341758483, 73.6258848251835, 12.383611009966943, 1.1331537438015784, 1.3629179760333032, 0.1401510819672577, 2.8481710005191068, 58.70456503283594, 64.98846484768775, 61.57139793519051, 61.2284258873232, 60.31581978644095, 56.52778687015657, 50.07207939701696, 46.09144633816135, 50.33949482825495, 55.358316513799856, 61.86470493193596, 60.247272445309555, 57.35659545467746, 54.788050959187174, 52.95825350669123, 53.33399303497807, 55.686140368061686, 54.91541031868228, 49.99439293338407, 46.66514396667481, 41.48543057903167, 43.147221149936804, 42.54630227242747, 41.98982777134065, 42.54862039319931, 39.64445044917446, 42.327928235453946, 42.126777325907064, 42.12002692684051, 44.77945273922336, 42.45799795273812, 40.2260555759553, 40.811057475305375, 42.60014072541268, 41.26559349798387, 40.220501499791304, 39.48149165799541, 44.06696988690285, 40.56073573327834, 45.31158893339096, 44.31335356927688, 42.43579733756281, 43.20704906217514, 41.39784797545403, 40.98859963878509, 45.04738592332409, 50.807457124033284, 50.64293330715549, 52.080207409397254, 45.089367051278394, 40.26454971682641, 40.296807289123535, 38.52482165059736, 41.00726227606497, 42.49618222636562, 41.655826184057425, 42.80067582284251, 39.99419643032936, 39.75189593530471, 44.34437559496972, 40.54661912302817, 46.17776593854351, 46.20876443001532, 43.147809505462654, 44.34314397073562, 41.261396561899495, 42.141643108860144, 43.301487968813994, 41.423523810602006, 42.55323702289213, 44.29437714238321, 43.37075310368692, 38.880764976624526, 39.686066796702725, 39.85141038894653, 39.87472103488061, 43.36545005921395, 43.01785353691348, 52.533398059106645, 53.36441493803456, 52.03022464629143, 52.00834566547025, 43.660816300299864, 41.55655099499611, 44.71913060834331, 43.36327706613849, 44.6373805692119, 44.99941533611667, 43.82290040293048, 42.658336931659335, 41.75993765554121, 41.4851717026003, 41.41885226772678, 41.56760815651187, 43.788834617983916, 41.44967033017067, 41.732433995892926, 42.15746595013527, 42.651241364017615, 44.36079463651104, 42.12504756066107, 42.306570929865686, 41.62662021575436, 42.89362030644571, 42.13588114707701, 42.85470254959599, 42.18270640219412, 43.61620326195994, 43.73495694129698, 45.07951405740554, 44.136697861456106, 47.55481204678936, 46.205477483810924, 48.87794517701673, 51.835977108247825, 51.41394184481714, 51.230998577610144, 54.669650293165645, 53.98005839317076, 52.229904667023696, 51.740992992155014, 50.83069324493409, 52.16102784679782, 52.37546774648851, 58.92325678179341, 68.8539057393228, 66.03591026798372, 68.03099247717088, 5.305895055494001, 0.9169276335066365, 1.992131238502841, 1.1846749340334248, 16.42395038758555, 80.69655326104935, 67.11463266803374, 80.87780598671206, 68.15857933413598, 63.7747815347487, 36.00223164404593, 58.623042491174516, 65.64321041107178, 70.9606578273158, 7.908112118321081, 0.36129028265995367, 0.24118698622670867, 0.1864711940288544, 0.18478342572287207, 0.08651384197536015, 0.08523210026924649, 0.14577251258155993], [0.053602517056729526, 0.01851628192760531, 0.021920064201338157, 0.015308912148729209, 0.04276953585025284, 0.03169002371930307, 0.061956192592098835, 0.021696565710308573, 0.042960238117243976, 0.01866315055878893, 1.203766948273105, 44.92533745304231, 57.72690250027565, 42.16630305013349, 36.321147795646425, 31.709828992043775, 55.316970809813476, 62.888463158761304, 63.221990139253684, 52.06081521126532, 66.62572491553523, 21.235429702266572, 0.13175835893038781, 0.7219095335852715, 0.3978714100535839, 0.08059399713191294, 27.025795329001646, 67.80785668280818, 53.77475761598157, 58.7453890615894, 46.89522235624252, 50.38306059375886, 41.37352535801549, 47.49827892549577, 48.216100123620805, 59.329394678915705, 52.01343297958375, 50.08610187038299, 46.61469444151848, 51.17222970531833, 53.10957854793918, 52.98513743185228, 47.559671863432854, 46.1451945766326, 41.71865470947758, 38.314672823875185, 36.51988644753733, 38.22507412202897, 37.72955717579011, 38.34190583998157, 37.03694112839238, 36.11238748796525, 38.073760847891535, 39.00552380469538, 36.40726343277962, 38.38290245302262, 37.758112030644575, 39.43641185760498, 37.995478183992454, 39.70988342838903, 36.799633810597086, 39.68075982985958, 37.926730801982266, 39.041899865673436, 39.56888991017496, 38.136624674643244, 37.858928711183616, 39.948496895451704, 39.49134465186827, 38.41883920854138, 34.54503582369897, 38.56973278907038, 43.358130916472405, 44.35938650561918, 47.30202705629411, 46.54402509812386, 38.37889771307669, 39.41638815787531, 37.72754499989171, 39.581080636670514, 40.21311175438666, 39.069227018663966, 38.7244624476279, 38.97152470004174, 38.42965318310646, 38.90130250684677, 39.231962234743186, 40.693621712346236, 38.727431681848344, 38.22414452029813, 39.397854958811116, 39.90408782036074, 36.55724310105847, 38.19965324094219, 38.677939215014064, 39.997954060954434, 39.97428255696451, 38.91476408127816, 36.100969468393636, 37.21433424180554, 39.00231138352425, 40.154036937221406, 47.299053899703495, 47.54896771523261, 47.59462410403837, 48.20301509672596, 45.99802332539713, 44.411236316927024, 38.67078088944958, 37.614937674614694, 38.8200702205781, 41.92087250371134, 38.961993340523016, 39.807013080966094, 38.03368599184098, 38.73449587052868, 37.73382863690777, 37.736507615735455, 39.181869645272535, 36.87576701564174, 37.45473630966679, 38.643944032730595, 36.374025267939416, 37.446209076912176, 35.84013577430479, 35.28835242794406, 36.28352442095357, 37.38832666027931, 36.240029258112756, 38.21773928980674, 37.967562675476074, 39.50597901498118, 38.28740058406707, 40.72506735401769, 38.09193318889987, 39.735378834509085, 40.875203917103434, 43.01333888884514, 46.79051860686272, 48.52318248441143, 50.234995042124105, 55.31267973684496, 57.20733358014015, 57.53536924239128, 59.5571941714133, 60.35167024981592, 55.39658315720097, 46.09649835094329, 41.65399051481678, 49.11935529401226, 56.94247553425451, 61.0976658328887, 60.98976927418863, 57.251326883992846, 2.6398450953345147, 0.9564685569174829, 1.1257780944147417, 0.3280054170998835, 16.585387299137732, 71.10529914979013, 54.93573996328539, 68.84410765863234, 55.756527300803896, 51.130585901198856, 35.35706843099287, 54.223931758634514, 58.486285132746545, 41.353709543904955, 1.429942702093432, 0.07718079197671145, 0.07685282207544773, 0.020325793096074657, 0.06573485616113871, 0.04042662064274473, 0.017949365372318896, 0.017434253597692136, 0.07687620307889677, 0.0023467707843895283, 0.055925429708534674, 0.0393426483647237, 0.04672008656686352, 0.1356996055091581, 0.049968188283063715, 0.03348672206723883, 0.019875618764349533, 0.07414957358231468, 1.5886623917087432, 53.833604935676824, 65.32589066413142, 47.260281270550145, 42.26395830031365, 38.175985659322436, 61.490502972756666, 67.9166240076865, 67.39101071511546, 57.6687612072114, 71.03309615965813, 22.563173578631496, 0.21949277049110782, 0.07492396589969436, 0.8890771505332763, 0.07923822834967606, 30.573063358183834, 69.94910993883687, 55.775119335420676, 60.972432398026996, 49.38948108303932, 53.98842480874831, 44.52725610425396, 48.63608398745137, 50.828096635880016, 60.26343261041949, 54.40253296206075, 52.05511992977512, 48.773355176371915, 51.62702852679838, 53.16470353834091, 54.75151015866188, 49.59312269764562, 49.33131625575405, 44.52416919892834, 39.76755403703259, 39.88076540731615, 40.34024361641177, 39.83844695552703, 40.571498717031176, 39.907923898389264, 40.23770893773725, 38.99401164823963, 41.488599854130904, 37.83603383648781, 40.4772755407518, 39.116315072582616, 40.214563031350416, 37.934791272686375, 40.2139982100456, 38.34424749497445, 40.15618639607584, 37.943914705707186, 39.512792171970496, 40.44439823396745, 41.07968099655644, 40.259403567160334, 41.3258764051622, 40.84007516984017, 40.8379178662454, 36.76446976200227, 41.93253371023363, 46.62500243033133, 46.33407631228047, 50.16916590352213, 48.11302415786251, 38.83402993602138, 39.322514072541274, 37.719053068468654, 40.926794851979906, 39.192620861914854, 42.605655577874955, 41.19721089639972, 40.20152507289764, 39.152024330631384, 40.200356206586285, 40.455349491488555, 41.65494365076865, 40.93989164598527, 40.05911165668119, 40.86813972842309, 41.412097946290054, 39.21901449080437, 40.08189670501217, 39.77124106499457, 41.968548913155836, 41.59746916063371, 40.944606334932395, 38.15014508462722, 39.052419662475586, 39.32962140729351, 40.53911562888853, 47.153683016377116, 49.44865395945888, 49.26664813872307, 49.738991721983886, 49.05960975154754, 47.664638411614206, 40.54347730452015, 38.91458365225023, 40.21094268368137, 43.119933220648, 40.49888387803109, 40.98801520562942, 41.5763589643663, 39.869751391872285, 40.82602916225311, 39.803145623976185, 40.636072697178015, 39.768271830774125, 39.81474015020555, 40.686918381721746, 39.40023975987589, 40.28220822734218, 38.878843015240086, 38.97183848965553, 38.45048489109163, 40.545862105584916, 38.81317469381517, 40.918279386335804, 40.24516536343483, 43.299256140185946, 40.85514099367204, 41.694673338244044, 40.33861975516043, 42.97660196981123, 43.02177590708579, 45.988315459220644, 48.2122758127028, 50.95675822227232, 53.102059364318855, 58.48869739040252, 61.279326485049346, 58.89183075197282, 62.342135829310266, 62.72064847330894, 57.49016392615534, 48.7274516782453, 42.98699232839769, 52.74648866345806, 58.54614442394626, 65.56482184317805, 63.84220315564064, 61.6604200486214, 2.872996661932238, 0.8992807062402849, 0.5779153409023439, 0.5113253237739687, 18.219629103137603, 77.75673681689848, 61.29531014350153, 72.1927527458437, 63.32604669755506, 53.95990133285523, 29.27815168134628, 55.94607976175124, 64.38602801292174, 52.28454720589423, 1.9365427955504388, 0.125110094705897, 0.08336778700111375, 0.03810171616233645, 0.06586690673664694, 0.029809272119535074, 0.04141672033696406, 0.014963596101639973, 0.18411309878912666, 0.13193207702809764, 0.2396323640019663, 0.1275891858723856, 0.2543989845341252, 0.26383047683104394, 0.2023318647256782, 0.20496930626611556, 0.1188861052956312, 0.16230426097829498, 2.021159719555609, 61.482622931080485, 72.83369941096153, 55.72290866605697, 49.752386616122344, 44.41824951479512, 70.11832883281093, 73.47696027448102, 72.981690437563, 62.77196876464352, 78.6087069972869, 26.41360159843199, 0.42239753108832145, 2.6374590685290675, 1.302784364069662, 0.1741635165507755, 33.369646610752234, 71.1990830206102, 57.70408607298329, 63.83943788466915, 51.28571956388412, 56.20286949219243, 45.19354128068493, 51.110177809192294, 52.779691526966715, 62.730038627501465, 57.81174728947302, 53.64801799097369, 50.99621334383565, 55.18152352302305, 54.5085467830781, 54.71251003203854, 52.949969460887296, 51.04254830268122, 47.48206384720341, 41.86337055698518, 42.06175227319041, 41.24363606975925, 41.29701952780447, 43.54855806596818, 43.59217089991416, 41.95587181275891, 42.63461443685716, 45.02537750428723, 41.36674357998756, 42.63323376255651, 42.602568672549346, 43.54453371417138, 40.948740513094016, 43.14801346871161, 42.06807121153801, 43.2455785043778, 41.18947990479008, 41.63502585503363, 44.18886146237774, 44.51873671623969, 43.352208137512214, 42.56200352022725, 43.299256140185946, 44.145487893012266, 39.519479813114295, 43.33025070928758, 49.02812880854453, 50.56772970384168, 51.30101288518598, 48.99833840708579, 38.47513306525446, 41.827033719708844, 38.663281317680116, 43.04664765634845, 42.1225215542701, 45.066370194958104, 44.13872180446502, 43.308281513952444, 41.17874045525828, 42.25318354945029, 43.39311061366912, 45.45395135879517, 43.15892158016082, 43.43575462218254, 44.32937252906061, 43.78380221705283, 40.54353221770256, 42.60849537387971, 40.469085631832, 46.699064623925, 43.73930684981808, 40.42609253237325, 39.57234944066694, 39.17778253555298, 39.441718824448124, 41.4920711517334, 48.576993480805434, 50.17246461683705, 52.34061356513731, 53.630967447834635, 53.80400280798636, 49.5436066965903, 42.917503618424945, 42.2099825643724, 41.2316140051811, 45.53916485078874, 41.8839826122407, 43.72429593916863, 43.376350325922814, 42.783974370648785, 42.527031667770885, 41.98510523765318, 41.98526213246007, 42.168472120838786, 42.055103855748335, 43.65591725995464, 41.46246510167276, 42.850591905655406, 40.88698671710107, 41.0601201365071, 40.91950316582957, 44.11758022923624, 42.24746081136888, 43.721891526252996, 43.12407524354997, 45.28074733672604, 42.95898660536736, 45.95626969491282, 42.45954336658601, 45.20858749266594, 45.82614114207607, 47.74006559002785, 53.221491613695704, 53.30463409423829, 56.47349342223137, 62.39120860253612, 63.958077815271196, 59.29978470648489, 65.9342973462997, 65.02848086818572, 61.14548344765941, 52.02077957891649, 46.44365949015464, 54.39092274635069, 61.47193447236092, 67.8246836508474, 65.64073539549305, 62.778727008450424, 4.154530359852699, 1.53032828963572, 2.770907662568554, 0.5708012032893397, 21.66969099352437, 82.99048085366526, 65.09752242795884, 77.50765846621606, 66.88053777140956, 66.16779604265767, 47.92639778506371, 66.11402034759521, 72.5334184400497, 63.33910819022887, 3.2379653617259, 0.307616691796049, 0.18592901828308261, 0.11531927652897374, 0.18210417110352747, 0.154348177414748, 0.09740660102256844, 0.09526858752172801], [0.01571289520905984, 0.031097481522949475, 0.06974549498409033, 0.05991999217639527, 0.05230180701361068, 0.051495449677590406, 0.06139103420859864, 0.09048862022257621, 0.01590288692950121, 0.006336273959717684, 0.36491124319934076, 36.353507349568034, 60.037170687029445, 40.861832557186005, 28.885785225898992, 30.67781025363553, 51.598556041717536, 58.547379970550544, 59.88389622780585, 52.48328978015531, 62.53465752447806, 38.76482363670103, 0.06431701127439737, 0.30035586366730355, 0.5445251842179607, 0.12940479893117182, 14.259260969777262, 63.57893759204496, 52.1159049003355, 58.133640520034305, 46.930045158632346, 49.28124720050443, 43.36107661647182, 49.69806963397611, 52.806402867840184, 51.67000201440627, 48.17163221297726, 52.347595384044034, 46.898226891794515, 54.932225519610995, 52.0215718976913, 53.128409847136474, 47.28783199864049, 44.043298382912916, 37.145575092684844, 39.499354131760136, 36.49221020360147, 38.24290521683232, 36.849769546139626, 37.92021966749622, 36.300092512561434, 37.99316398559078, 37.07660413557483, 36.95949392934, 35.3462113103559, 37.03312073984454, 37.2011354661757, 39.23170728068198, 37.910013660307854, 37.5478926012593, 39.037083195101836, 39.57144729552731, 36.71387510914957, 37.52093415106497, 37.69125130868728, 38.758057548153786, 37.90839372142669, 38.3709470687374, 39.555440102854085, 37.66857608672112, 34.7624449576101, 37.90507931863108, 42.54232106670257, 44.465133605464814, 45.5587649345398, 47.725199807074766, 38.38076868364888, 38.904816950521166, 37.30135202407837, 39.26413351489652, 40.584281721422755, 39.71356261161066, 39.30614209944202, 38.60392801223263, 36.573791580815474, 37.28990262554538, 38.37572451560728, 38.949426066490915, 38.8650127380125, 40.97769152733588, 39.96700656029486, 40.38846523531022, 37.268266831674886, 38.04342523697884, 40.34944157446585, 38.04708480834961, 39.671824670607045, 39.55231397382675, 38.7828077039411, 36.60799072634789, 40.03132166401033, 39.70185041427612, 38.8880645075152, 50.696120646692094, 47.83688145299112, 48.63543679637294, 45.15823994913409, 45.335464400629846, 37.53126959646902, 36.599318365896906, 40.70638510488695, 38.24825925211753, 38.82941722869873, 38.93960837394961, 39.39563489729358, 39.050689897229596, 38.65393430955949, 37.99557232087658, 39.82955494234639, 39.09498522358556, 36.6849946975708, 39.165999735555346, 36.597361103180916, 36.800190787161554, 35.89287596364176, 38.309612966352894, 36.91745788820329, 36.845549075834214, 38.1108586249813, 37.53447025052963, 37.40059583417831, 38.261277598719445, 39.79475959654778, 40.932501900580625, 39.6596182546308, 40.73945068543957, 41.89942498360911, 44.678585067872085, 47.392904450816495, 50.548592459770944, 55.10671607909664, 59.54334035996468, 57.26127009237967, 56.26392118392452, 54.40336058216711, 52.38199064808508, 57.367193698883064, 55.112128949934444, 45.03281824050411, 44.676588581454375, 56.54790470677038, 61.48085394213277, 65.12102527003135, 51.0641291833693, 1.0418836219656853, 0.26724428719570564, 1.0101998188803274, 0.2278184301910862, 23.154884692161318, 70.98365860600626, 55.91997246588431, 71.86763532700078, 55.85596330704228, 47.72905157458398, 27.33679613759441, 51.94962778399068, 63.458477681682965, 32.07211282945449, 0.49144096011596344, 0.03797312830424598, 0.1362694523507549, 0.018848760256303415, 0.0610589427543023, 0.09407013489474213, 0.08569186027612417, 0.015832234470684443, 0.008606492211261104, 0.05897929366197317, 0.04870592053198526, 0.03338861684765547, 0.03327373430253037, 0.04855883931140265, 0.024214943780774073, 0.027466762938626835, 0.02708290692328686, 0.0030654613275997223, 0.5406968283557123, 43.29128196162563, 66.67774338876048, 46.12592397197601, 32.88316288302022, 36.357716052762925, 59.778627657121234, 64.92119619923254, 66.53715779704433, 57.84419313553841, 69.78422134153305, 39.71707705528506, 0.07861219661971254, 0.29233771166013134, 0.6079283368683631, 0.1559575749260764, 15.202038922617513, 66.73246829740464, 53.420242032697125, 59.53697043080484, 48.330041054756414, 50.8705759048462, 46.3059489957748, 51.74818269668087, 54.58637052966703, 55.37808525946833, 50.4949579700347, 51.64738170562252, 49.21462966549782, 57.0925767960087, 54.8514796072437, 55.8314916395372, 49.827817716906154, 44.72189980168497, 39.814253776304184, 40.60820033473354, 39.23116207122803, 39.928226086401175, 38.39984316979685, 41.515754422833844, 38.26178750684185, 39.28926806296072, 38.689580809685495, 40.13106753749233, 38.34523985462804, 40.165443189682506, 39.02561810708816, 40.21951306250788, 40.320035565283995, 39.746808621191214, 40.081904549752515, 40.13337781352382, 39.66749829630698, 39.43345046812488, 40.278995806171054, 41.050647612540956, 38.83765028369042, 41.45468704162106, 43.258667453642815, 40.05906458823912, 37.12690068829445, 41.15318621358564, 46.23389113333918, 45.97879586681243, 48.03201544669367, 49.62651383492255, 39.64685093971991, 39.91409770904049, 37.197848519971295, 39.99979365256525, 40.968783824674546, 42.25366207861131, 41.108094646084695, 38.45737257311421, 38.67200859131352, 39.79342206831902, 39.280783976278, 41.81239151185559, 40.63142468852382, 41.6755949297259, 41.64659684704196, 42.56452952661822, 39.00716727779758, 40.10200669688564, 42.017237294104795, 41.09333868949644, 39.95867152367869, 39.42496638144217, 38.355194830125384, 38.12707762564383, 40.12519574934437, 39.31533221275576, 42.05295047452373, 52.62136897733135, 49.761980733563824, 51.03190299003355, 48.140308164781146, 48.10254750713226, 38.35493595369401, 37.88878187056511, 41.59041673906388, 40.06672105481548, 39.187753200531006, 41.56097542855048, 40.68491012819352, 41.29286966016216, 40.19125630778652, 39.547595362509455, 39.5632730760882, 40.03162760888377, 39.23583361410326, 40.18612192523095, 38.47326993942261, 38.57420429106682, 37.11449423143941, 40.00404157946187, 38.26323486143543, 41.425822319522986, 40.114781856536865, 40.14680408662365, 39.04444548391527, 41.51005521897347, 42.04617654123614, 43.31169789837253, 42.1893391301555, 43.62663284424813, 44.85512310458768, 46.863604130283484, 49.30016871421568, 51.24007886455905, 57.02262132398544, 60.10852252283404, 58.00934845401395, 57.78950352822581, 55.18767379945325, 54.27864882253832, 60.584302102365804, 56.930527994709635, 46.32181890549199, 46.35759092146351, 59.18342759532314, 65.84418481396091, 68.15442162175333, 55.51867085118448, 1.4203304436899002, 1.2228167970334332, 0.19196494842969603, 0.17496217853359639, 24.226686070042273, 80.27575354422294, 59.88202525723366, 77.46186871682444, 59.681427401881066, 61.08953868189166, 37.313425079468765, 55.5978831168144, 70.11711289805751, 40.391862007879446, 0.7492388316219853, 0.03306093422936336, 0.05074433111135037, 0.035224374188410665, 0.049529499524543365, 0.021349064397415327, 0.10337262564609129, 0.07096077090189343, 0.17473244408686317, 0.1709669380779228, 0.21402682508191756, 0.14342915687349536, 0.1382902543991804, 0.09228148813089056, 0.1204410722599395, 0.14406966766522777, 0.19580833493701874, 0.1854746055699164, 0.5675149925293461, 47.32976605815273, 75.2329347979638, 55.96039641288019, 39.24217216430172, 42.72422882818407, 66.59837815069383, 68.41916591890397, 72.59170486081031, 63.79445614353303, 72.06473442815965, 48.37983946646414, 0.21172997091085682, 0.9857255160327881, 2.272442319700795, 0.32146072796275543, 17.587323419509396, 70.32652824155747, 57.07484376045966, 63.51937640097834, 50.12769076132005, 53.04545171799199, 48.122786937221406, 54.344881965268044, 56.3880249761766, 58.286267788179465, 52.53094265537878, 54.32791771427278, 50.27603087886688, 58.96667349723078, 56.727306073711766, 58.57345196508593, 52.34675599682716, 45.8880243762847, 42.11879922497658, 42.86073123255084, 41.56035961643342, 42.25336005610805, 42.4065835245194, 42.31784382174092, 40.55461291343936, 42.70915515961186, 41.83405868468746, 41.088051334504165, 40.64090897960048, 42.388136617598995, 41.722059326787154, 43.84701905712005, 42.95317365277199, 40.60379159065985, 41.673884776330766, 42.669821631523874, 40.726569621793686, 39.99713820795859, 41.74335779682283, 42.976907914684666, 41.4963073115195, 42.93995918766145, 45.039196014404304, 42.74834748237364, 40.55320086017732, 42.51748854114164, 47.591917668619466, 48.51986023687547, 49.42930098502867, 51.85056832528884, 41.642545038653964, 42.016739153092914, 37.9573292116965, 42.920268889396425, 44.613461955901116, 42.6532260833248, 43.81071752117526, 41.1681539781632, 40.4977346235706, 41.0663959287828, 42.41814667178739, 44.373224627587106, 42.77201898636357, 44.291251013355875, 43.75094059974917, 45.486593323369185, 42.554217615435206, 43.717023864869155, 43.947208158431515, 42.72689603990124, 43.86104937522642, 42.41692289229363, 39.34820167479977, 39.299591741254254, 41.438181707935954, 39.92473517694781, 43.539062007781, 54.31972780535298, 52.51327237775249, 51.60518092493857, 51.14514573927849, 50.743577403406945, 41.318980878399266, 39.867896110780784, 44.96393749790807, 41.21036652595767, 41.889517076553844, 44.414676235568145, 44.093006580106675, 45.09873759362006, 42.66836643218995, 41.17235091424758, 42.71608598770634, 42.57465316403297, 41.15005223981796, 43.87804500518307, 41.70840555621732, 40.998840947305005, 39.445123441757694, 44.07239844722133, 40.923998202047045, 42.56898926150414, 43.47647666931153, 42.51548813235375, 41.11905374834615, 44.15648621897544, 45.075423025315814, 48.011344555885564, 44.38676072705177, 45.70223739070278, 47.67051412213234, 49.94087219238282, 52.60612272447156, 53.163338553520944, 59.627196711878625, 64.24000993851693, 59.34853584535661, 59.80812780318722, 58.5689647736088, 56.11421608155774, 62.16165581057149, 60.306143299225845, 49.204113791065836, 48.36242022052888, 60.90751717167517, 67.86029877201204, 70.82361021349507, 57.84519333993235, 2.063969325634741, 1.5789051281829036, 2.0734192959723936, 0.42059955337355215, 29.471302916926724, 84.06227634799096, 65.91944725282731, 81.7601666911956, 67.1353506272839, 62.213505621879335, 40.89271337755265, 62.35262032478087, 76.64593727357926, 52.42567016232399, 1.2959365186191376, 0.13905502465223113, 0.18760589281878165, 0.19050970313049134, 0.08911517779192618, 0.17019387875353137, 0.18568068322154785, 0.1093090256495822], [0.046869201750885096, 0.03346265924553717, 0.036505656241769754, 0.03253762722916661, 0.10361140759121026, 0.06752450650017108, 0.011077751086333828, 0.01601529596824079, 0.02433060965080175, 0.07395322524732159, 0.012779769585317662, 22.96699335498195, 58.620351745236306, 48.05957009715419, 38.840176290081395, 26.208545969378566, 47.56683803373768, 58.40688067097818, 58.107646972902366, 58.170561790466316, 55.31274249476772, 46.89514783120925, 0.8937988874893036, 0.3541770030654246, 0.416544220981098, 0.08363792492497353, 12.204743085368989, 66.59633067346388, 54.65027770688457, 55.90611473206551, 44.05774839462773, 45.05029239962178, 47.090128852475075, 55.36822442085513, 49.73069590906943, 52.897162591257405, 50.42827375473515, 47.15451848122382, 51.65902330029396, 53.94839309876966, 52.72801429994645, 49.2633141240766, 42.7370471339072, 38.88840967609037, 35.894644952589466, 37.69324779510498, 38.15211019208355, 37.297272759099165, 38.41333220081945, 36.8139700735769, 36.92615378287531, 36.32461124850858, 36.614847029409106, 36.52686042170371, 37.6288503216159, 37.99965943059614, 36.07099079316662, 38.292974272081935, 38.6130710571043, 37.99989477280648, 37.60902274039484, 38.724183959345666, 37.64608913852323, 37.75385625900761, 38.695801688778786, 38.49959296564902, 38.53633772942328, 37.9545521736145, 38.254680172089614, 36.735620729384884, 36.19514949860112, 37.32252105589836, 42.81302736651513, 43.57396325757427, 44.04090181473763, 51.85653032795076, 44.290631278868645, 38.48233061452066, 38.965809806700676, 41.38809304083548, 40.835050613649436, 39.48766939101681, 38.99214460003761, 37.8029368769738, 38.24866325624528, 37.912147429681596, 37.84057986351752, 41.6291501445155, 40.982316001769036, 40.58427779905258, 40.65920683645433, 38.763121328046246, 38.09261175893968, 35.77827215194702, 38.450614329307314, 37.03262652120283, 39.95132100197577, 40.617174717687796, 39.76261185061547, 37.831495654198434, 38.071317211274184, 39.95121509798112, 39.70887537925474, 45.17232518042288, 50.05458170367826, 45.44005440127465, 46.100471711927845, 40.75811332271945, 35.13686656951904, 38.038941967871885, 38.18967473122382, 39.27240187121976, 37.727627369665335, 38.021699228594386, 39.36906083937615, 37.76969478976342, 37.50687245399722, 36.793212890625, 39.18819642836048, 37.27016918120846, 38.90056510125437, 36.63652204698132, 39.62821968140141, 37.37449638305172, 35.014543533325195, 35.852503007458104, 37.74342667671942, 35.47055828955866, 37.513226693676366, 37.2703339207557, 37.62326878886069, 37.04061246687366, 38.34627928272371, 37.214640186678984, 38.809083661725445, 39.11839785114412, 39.743505985506125, 41.0136478947055, 42.694230541106194, 48.193279773958274, 53.840720115169404, 57.92813185722598, 57.66423086966238, 55.28443474923411, 59.84053050318072, 47.84588721490676, 53.950052261352546, 56.72124208942537, 47.40314575933641, 44.3906242616715, 55.5917916759368, 59.791245921965576, 68.90405716434603, 40.87986761523832, 0.08818935287455398, 1.070713165306276, 0.2838485687971115, 0.1355576034515135, 26.754826230387536, 67.81231249532392, 55.78794548588415, 68.7814909412015, 55.642088228656405, 34.840127498872825, 17.649555744663363, 39.843043973368985, 61.331333191164084, 28.79962055913864, 0.21072484823244236, 0.04186716854512211, 0.12081755850944789, 0.027014830435115485, 0.02422100162103532, 0.038220249116420746, 0.030029340451883695, 0.05345667306814463, 0.031245600792669484, 0.02586238138798264, 0.007870708331240402, 0.04394224026210366, 0.07400967826646182, 0.06740272150284822, 0.041520203493775866, 0.051782705836118235, 0.02913511857660788, 0.06611676631315101, 0.04505948756911582, 29.980556003509033, 67.71175076884609, 53.67314077192738, 38.239277024422925, 33.54217598515172, 55.919564539386386, 62.045902744416274, 64.09812996464392, 62.19694929738199, 62.49844228067706, 51.50814148687547, 0.926370065539114, 0.28662738420309564, 0.9754617151714141, 0.11776289782456814, 13.509495008376337, 68.41657715459024, 54.85104814652474, 58.908508669945505, 46.7974925810291, 48.645615346970104, 48.44817499960623, 57.102963232224994, 51.86426916430074, 54.96737780109529, 52.82937618993944, 50.41072114821404, 54.49767397296045, 55.71624063676404, 54.21321192095357, 50.844162664105816, 45.88208590784381, 39.84547584287582, 38.83360632004277, 39.99377673672092, 40.46475533516177, 39.77361017657865, 38.07935022538708, 39.32179235642956, 40.66563560116676, 38.78234486426077, 39.757128377114576, 38.9550664347987, 40.07670348690402, 39.947853626743445, 39.105383426912375, 40.903782306178925, 41.60735745583811, 39.05041925368771, 41.28907672820553, 39.94935589451944, 39.081943342762614, 40.13798659847629, 38.90679382508801, 39.21650417389409, 39.40773148690501, 40.50793670838879, 41.1725038866843, 38.83515565626083, 37.6436141229445, 40.853983894471206, 45.494543967708466, 45.3273803957047, 46.33535108258648, 51.44794094947077, 44.42845944435366, 38.83517134574152, 39.67792787859517, 43.08275699615479, 42.62928393579299, 41.390226810209214, 39.17029080852386, 39.28185478333504, 38.86454989833217, 39.88828066856631, 39.51425913841494, 42.30237399378131, 42.24179298646989, 42.78462156172722, 40.660446305428785, 39.015035552363244, 40.35039078804755, 37.944153970287694, 40.030144952958636, 40.63931649731052, 41.507011459719756, 41.797435514388546, 41.73604257645146, 38.781732974513886, 38.7096986462993, 40.24869549658991, 40.78987667637487, 50.58663945044241, 53.92323109411425, 46.945271799641276, 48.84755857529179, 45.01723858617967, 36.18880702603248, 39.93260737388365, 40.53684065418859, 41.48682694281302, 39.45275637411302, 39.720222796163256, 39.587297593393636, 40.2641692469197, 41.17188807456724, 40.73201779396304, 40.932360695254424, 39.67294646847633, 39.61429526728969, 38.949406454640055, 39.47860871591876, 39.25517482142295, 38.094867121788766, 38.03868701381069, 40.280902078074796, 39.80034112930298, 40.154978306062766, 39.079715436504735, 42.01310703831334, 40.14860837690292, 39.93216022368401, 38.932524573418405, 40.45820889934417, 40.65755551861179, 40.91095632122409, 43.554967218829745, 46.54076953088084, 49.90869306748914, 54.908514791919345, 58.457365497466064, 58.98492428564257, 59.237368029932824, 58.83463867249028, 48.59953141981556, 56.77753594613845, 58.73908973509266, 50.346955176322695, 46.97395609271142, 57.86166337228591, 62.11999239460115, 69.53347990589758, 43.897041043927594, 0.19028363058403616, 4.2304615628334785, 0.5660859627589103, 0.20350574125205317, 30.674654706831905, 74.61408676639681, 58.615036933652824, 72.87846934410834, 62.37371483156758, 44.26711666968561, 18.047970494916363, 43.80872103475755, 67.9519724076794, 37.23988848347818, 0.39054604667809706, 0.05434456131150646, 0.0691351374130576, 0.004595109804217974, 0.11816775997079189, 0.07068877138437764, 0.03206010164332486, 0.01952730348303674, 0.12640191046821495, 0.15380764109713418, 0.08106227603650863, 0.1752559272872825, 0.251213621588484, 0.2357038038392221, 0.1861670724446735, 0.09711271437305598, 0.15626126750101968, 0.16040868366197233, 0.11146825212504595, 32.98050434358659, 78.49958665909307, 59.798686658182454, 49.81927479467085, 38.612439555506555, 62.02667136346141, 70.30402952624907, 69.26809234003868, 67.0304193804341, 65.31989336013794, 58.759976356260246, 1.1478865338910011, 1.104669001313948, 2.5541489066616183, 0.3478303016914476, 15.843370960604762, 70.78904628753662, 60.10565527023808, 59.488740967166045, 48.21906935784125, 49.44779888276131, 52.7242958930231, 58.44005607789563, 55.981443851224846, 56.85266502441899, 51.63999196021788, 51.54797707834552, 55.75201265273556, 58.32820969243204, 57.72185833223405, 54.817213781418346, 46.57012454925045, 43.68387983691308, 40.013804358820764, 41.28260481742121, 42.55680245737876, 41.85394902383128, 41.44083323017244, 41.35564719477008, 41.743236203347486, 40.30661321455433, 41.61720260497063, 41.243514476283906, 42.65099817706693, 42.71518384256671, 41.13735944994035, 42.43191419109222, 44.14776679008238, 40.668969615813225, 41.918130766960886, 42.860362529754646, 39.71431962905392, 41.85933836044804, 42.059704795960464, 41.03277729403588, 42.354459147299494, 44.33249865808795, 42.663561528728856, 40.38876725781349, 40.24424360644433, 43.064392459008005, 48.9006753121653, 48.360647309211, 48.37243795394898, 55.02533082039126, 45.839787067905554, 41.27801956668977, 42.08946381845782, 45.35495858038626, 44.290223352370724, 43.529562027223655, 42.341797736383256, 40.67229578571935, 42.74795132298624, 41.654814212552964, 42.52187767336446, 46.53694521996283, 44.566593554712114, 44.3584059130761, 43.87743311543619, 43.303253035391535, 42.319408847439675, 40.51182769959973, 41.84287225046466, 41.55664513188024, 43.879421757113555, 43.97668869264665, 44.17357206344605, 39.460714863192656, 40.92206839592227, 42.2085234426683, 43.63061012760286, 54.51165330025458, 54.59796113352622, 49.46944252137215, 52.82280229753064, 46.26572116728752, 39.134856116387155, 42.230320053715865, 42.9105100324077, 44.81575035279797, 39.95184267720869, 42.715674138838246, 41.683616176728286, 42.24885717515023, 42.72731965587985, 41.61732812081614, 42.68698592339793, 42.77515296013125, 41.63665363865514, 42.166193223768666, 44.194501830685525, 43.11497534475019, 40.03637759916244, 40.98739154877202, 43.02125423185287, 42.2752429592994, 42.57935216349941, 41.86267629746468, 43.965639375871234, 42.4174367227862, 42.95298930137388, 41.900460489334606, 43.42957296679097, 43.0766773223877, 43.328269912350564, 44.18798285145914, 47.154059563913655, 53.39271876119798, 57.269907151499105, 64.24061790589364, 62.082839704328975, 63.027875961795935, 61.54155262054936, 49.86061265391689, 59.125635393204234, 62.79715038114979, 53.28861905682472, 50.31565073997744, 59.816600122759425, 64.73152606718003, 72.67350981312414, 44.86053989779565, 0.5430210165439114, 6.994145445285305, 2.0603210310782156, 0.35065321311835324, 34.3000602722168, 79.32919148475894, 64.17063889964935, 79.92019853284283, 66.14396372149068, 47.846342209846746, 27.634060805843724, 52.39378129282306, 75.46841036888861, 50.543222735005045, 0.6999229940195238, 0.09458165946266345, 0.18968461111428278, 0.19958945381785595, 0.24668568955554118, 0.20580380584203428, 0.14819457616296508, 0.14431167484050797], [0.032701190831440116, 0.04965301205013549, 0.05759013493755653, 0.043725464192609635, 0.019873259213542747, 0.019405991545007117, 0.030375755835144274, 0.0648195189874499, 0.032852799631655216, 0.06896135036743457, 0.04189702299153132, 11.884837515892523, 53.77391038402435, 47.83772868494834, 39.646274351304584, 31.839537851272095, 41.78399747417819, 53.18960666656495, 59.78760204007549, 60.08265449154762, 54.98265151054629, 55.39589674242082, 4.1323253320109465, 0.6450320588004205, 1.2536833988082026, 0.2840433389909806, 11.20740790520945, 65.41126105093187, 53.804575474031516, 51.918625370148696, 42.81602405732678, 47.57714602255052, 52.94514886794552, 53.64062824556905, 50.7693983662513, 55.911845314887266, 48.050352527249245, 55.784591859386815, 53.06473801212927, 52.44113214554326, 49.11286769374725, 42.405069489632886, 36.67121148878528, 39.23051880251977, 36.73445186307354, 36.36462334663638, 35.10508752638294, 37.38527897865542, 36.5639542764233, 39.23950495258455, 38.65780568891956, 39.07854264782321, 37.95881578999181, 38.65211825216971, 37.6466461150877, 37.112470288430494, 37.417077633642386, 37.707693884449625, 37.634741721614716, 38.652055494246945, 37.98094580250402, 38.099491596221924, 36.59199137841502, 36.839516470509196, 38.16283787450483, 38.25570783307476, 39.8377566183767, 37.85734015126383, 39.96064447587536, 36.6371770828001, 35.2527137725584, 37.93941966948971, 44.207320136408654, 41.583411385936124, 45.95389666095857, 48.75109572564402, 38.68021811208418, 37.220861065772276, 38.50572363022835, 41.55182061656829, 42.45082393769295, 40.93741270803636, 37.74001421466951, 36.92956232255505, 39.03340793425037, 39.54101754773048, 37.822423211989864, 39.160582942347375, 40.411156146757065, 40.03142364563481, 38.491689389751805, 36.944667370088645, 39.07382795887609, 36.85388019008022, 37.77110292065529, 37.20612472103488, 39.564634138538, 38.830903806994044, 39.034466974196896, 39.37867849103866, 39.679971433454945, 38.744690110606534, 42.98336021361813, 40.81234793509207, 47.40016475800545, 44.554787220493445, 46.672431730454974, 42.07804579888621, 35.339688408759336, 39.07065083903652, 38.37514008245161, 39.52130763761459, 39.216755205585116, 38.86562070538921, 38.90149470298521, 39.06218244183449, 38.11161956479473, 38.37137852945636, 37.19871144140921, 38.37335148165303, 38.54590831264373, 38.63301630943052, 38.678704077197665, 37.7974534034729, 38.34125472653297, 36.77922964096069, 35.796060100678474, 38.03096386694139, 38.17548359594038, 36.3511029366524, 38.49640407869893, 37.13441202717443, 39.84015710892216, 37.404459368798044, 38.25813578021142, 36.10304832458496, 38.85248468768212, 39.10535597032116, 41.087055052480395, 46.45071975646481, 50.979566804824344, 52.3941146942877, 55.36278017105595, 54.450315275499904, 60.31478820308563, 56.885581554905066, 55.96805287945656, 55.56734746502292, 55.93521479637393, 41.35217197479741, 53.24942281169277, 58.166764936139515, 74.93472483850296, 28.559969625165387, 0.10524761817988851, 0.03907053393401927, 0.2105517736485889, 0.008102143971970486, 36.53616036138227, 66.80899373946652, 56.803968798729684, 68.90433957499843, 55.76137535033688, 40.43676922398229, 48.57960577934019, 43.36056278597924, 55.628128513213134, 25.549611314650505, 0.10992391846112667, 0.056388081697326516, 0.05842653441152746, 0.09109536951948559, 0.0360675037447964, 0.035906330336846655, 0.03789667272940278, 0.016106621309694265, 0.019650040344605525, 0.11996779080119827, 0.05355843252712681, 0.027793710112511635, 0.014818485642242578, 0.027261388172665914, 0.07113251249275862, 0.01735885522418445, 0.06517695263028145, 0.07376297497220578, 0.13653218986526613, 15.120716421834885, 61.85661308227047, 56.22461903479792, 44.177349305921986, 35.564597114439934, 53.90611387068226, 61.1535596078442, 66.22340740696077, 63.92149779104418, 59.08473291704732, 60.54867129172049, 4.259227245084701, 0.5587240416676768, 0.5586091284790348, 0.5717456364823926, 13.000753791101518, 65.62239831493747, 55.988810062408454, 54.771310283291726, 46.18674816623811, 48.962738975401855, 53.69318408350791, 54.017909265333614, 53.47810091510896, 57.696994427711736, 49.92347255829842, 55.880772298382176, 54.977670100427446, 54.19561616836056, 49.65715539070868, 45.604829249843476, 39.49755768622122, 39.77990950307539, 37.42452229222944, 39.96583377161334, 37.488535373441636, 38.48754736684984, 38.07599659888975, 40.90942267448672, 39.106626818257, 41.279666962162146, 39.755292707873934, 40.572781332077525, 40.67432365109844, 37.73242835075625, 40.25289635504446, 40.17970492762905, 39.54212757848924, 40.73531258490778, 39.69944992373067, 39.5538789995255, 38.535043347266416, 39.200712711580344, 41.524897467705514, 40.33771368765062, 40.701431151359316, 38.54465315418859, 41.877393030351215, 39.07488699882261, 37.34417253924955, 39.59892742095455, 46.60815192807106, 44.02704800328901, 46.48326366178451, 51.36478670181767, 41.15468848136164, 38.789789522847826, 38.84679332856209, 42.02512518052132, 42.532703415040054, 42.211724096728915, 39.63952395223802, 39.1765901350206, 41.33054794803743, 41.26006295604091, 39.7759832105329, 41.30003190809681, 42.029557458816036, 41.94718376282723, 41.07275016846196, 39.87874146430723, 41.69309654543477, 38.28449410776938, 38.43627414395733, 39.93663172568045, 40.59504862754576, 40.599402458437034, 40.1619012894169, 39.96171920530258, 39.52558694347259, 40.33046906994235, 42.36521036394181, 47.03577264662712, 49.73636373396843, 48.605391440853, 47.47396415279758, 43.876001450323294, 36.627080901976555, 40.225726096860825, 40.870014621365456, 41.46819960686469, 40.37404268018661, 42.465846615452925, 39.96430012487596, 39.78194521319482, 40.47092522344282, 40.68557300875264, 39.0643201335784, 40.73020173657326, 40.6808190961038, 40.06620330195273, 41.083666124651515, 40.75593640727382, 40.37341902332921, 39.76277266779254, 39.01814206953972, 38.94356604545347, 41.170134775100216, 38.41642302851523, 39.77694811359529, 39.192922884418124, 40.848582790743926, 40.614911510098366, 41.38254680941182, 39.47867931858186, 42.61152736602291, 41.584603786468506, 44.09271240234376, 49.12441515153455, 54.71318075733801, 55.675263635573856, 57.0669597964133, 57.24782812979914, 62.3983512386199, 57.18936912475094, 57.30657346786992, 58.56306160649946, 58.13702552549301, 43.91631557095436, 56.0644490488114, 60.81421967475646, 76.29337110827046, 28.53434281964456, 0.17073086042317653, 1.8265465430675016, 0.10766140801171142, 0.07180372042761696, 39.73959146007415, 72.2462538749941, 62.52468293712985, 78.21130814090853, 61.29944432166315, 44.54023130478398, 42.41191402558358, 46.962765570609804, 62.67254060314548, 30.946086645126346, 0.1560590509325266, 0.06214002305040918, 0.02711248749326314, 0.033636231786541404, 0.022556754129548228, 0.05271023146868233, 0.06810387581466668, 0.08493419165813154, 0.08629286391360146, 0.14423949403628228, 0.18595731757100553, 0.08434742959516664, 0.13682307345011543, 0.12290070479315136, 0.09857828653747998, 0.0824466428809589, 0.19036799218625794, 0.376068118719324, 0.2105741280942194, 16.983927565236247, 72.03254745852563, 63.16944214605517, 52.823939784880615, 43.43919061845349, 56.16111193933795, 62.77307095066194, 70.29824795261507, 70.33258438110352, 65.40878603535315, 65.86139617427703, 5.277560833961734, 1.1859369566363673, 2.9234155435715956, 0.5073712988486213, 14.38491213706232, 69.40717174160865, 58.36809627471432, 57.13930791424167, 47.87663075231737, 52.10966048702117, 56.11099973801644, 57.527359762499415, 57.69667279335761, 59.00885074369369, 52.480928513311575, 58.82744896796442, 57.11871154846684, 57.243184043515114, 52.00814170222129, 47.93912587627288, 40.97947228339411, 42.659870578396706, 40.98140208951889, 41.972243785858154, 39.214723417835856, 40.602614879608154, 39.83134746551514, 43.67597233864569, 41.762726460733724, 42.235026897922644, 41.13880680453393, 43.23001453953405, 43.48277207343809, 41.55482515212029, 42.150809687952844, 42.00499557679699, 41.11114625007876, 42.94093978020453, 40.95955448765909, 42.02808657000142, 39.552031563174346, 41.38511596187469, 41.775348647948235, 42.55065218094857, 42.64045092367357, 40.9448887455848, 44.43934009921166, 42.694136404222064, 39.11179650214411, 41.88985832275883, 49.43566699181834, 47.34908373125138, 51.683443976986794, 54.184700212171, 41.903492481477805, 39.23932060118645, 40.46379827683972, 45.22270802528628, 44.86329732402679, 44.651293216213105, 40.507854338615175, 40.33505824304397, 44.47314308535668, 44.61324230317147, 41.68206684051022, 43.644981691914225, 45.06148684409357, 45.5685551704899, 42.798718560126524, 42.89651501563288, 45.12499001718337, 40.51750336923907, 41.05379335341915, 42.48621548375776, 43.27307431928573, 42.94387763546359, 41.08321897445187, 42.67889015136227, 42.32060517034223, 42.39162360468219, 43.53401391736923, 50.18615368873843, 53.338370400090376, 50.29037890895721, 50.38937168736612, 47.25155007454657, 40.358721902293546, 43.36967445188954, 42.543631138340125, 43.862571254853286, 43.496139510985344, 43.23391337548533, 42.929309952643614, 42.435538461131436, 42.44236338523127, 42.00455234896752, 41.423637559337, 44.10127101405975, 43.18395414660054, 43.45770028329665, 43.812529656194876, 44.21606309952275, 43.484529295275294, 41.97034143632458, 41.265283630740264, 41.75834909562142, 43.864230417436175, 39.74271758910149, 43.08331397271926, 40.26563229099397, 44.66864185948526, 41.89749909985451, 43.25724363327027, 41.348398654691636, 44.88213646796442, 42.95731567567395, 45.895425888799856, 51.988710280387636, 56.25098128472605, 58.791092518837225, 59.04400302517799, 59.77952587989069, 65.14856815338135, 59.91007804870606, 58.152593412706935, 61.43462096491168, 61.79162725325554, 47.58588114092427, 59.47944494985766, 65.17771136376166, 78.51424847879719, 33.7167763710022, 0.26421811732072986, 0.571697342299646, 0.2299510504329397, 0.24566490803995442, 44.55171600464852, 77.32278147051412, 67.66857331798923, 81.39591970751363, 68.77951406663465, 55.91643448798887, 61.39759379048502, 55.682147395226266, 70.50388997600925, 39.437612102877715, 0.22420263308430874, 0.24977751316562777, 0.14549281388040514, 0.1375000347052851, 0.22035665719980196, 0.09695289311029258, 0.17071837319001076, 0.2438798159240715], [0.03526160223109107, 0.07019168757382901, 0.05557535050977623, 0.08869076508187479, 0.03580599197096402, 0.11360380648364944, 0.05477723244938159, 0.06808482320798982, 0.013035526123618888, 0.12144773477508176, 0.07926956134577913, 6.397146486466931, 54.105731133491766, 50.544309231542776, 31.677287047909154, 20.41726839157843, 40.38027140402025, 52.16534245398737, 60.05593138356363, 60.60012102127076, 51.02215197778518, 60.10179173561835, 9.065460389660252, 0.7231290842736922, 0.9304778902761398, 0.3404312406576449, 8.42361746295806, 65.01023007977393, 54.740433385295255, 49.28200421794769, 43.74693193743306, 51.211806420357, 53.14321679453696, 51.70475029176282, 56.71087526505994, 50.07544086825464, 55.98402084842805, 54.96966846527592, 51.48552117809173, 47.86380852422407, 43.56867982495216, 37.74653711626607, 38.16424992776687, 36.57907109106741, 37.71736252692438, 37.88205892808976, 37.24609759546096, 38.65514239957256, 38.15235337903423, 39.70299182399627, 38.026676716343054, 39.65257760017149, 37.731604653020064, 38.34923282746346, 38.68838448678294, 38.18077487330283, 36.48234152024792, 37.857132265644694, 37.66939586208713, 38.74426649462792, 39.28143116735643, 37.685736456225, 39.3197605686803, 37.72795684875981, 37.79025193183653, 37.695926773932676, 37.6987430357164, 39.15491903981855, 40.17906165892079, 37.800830564191266, 35.85373463169221, 38.41871369269587, 42.28682179604807, 44.7677013181871, 42.84300604174214, 39.80782108922159, 40.12399550407164, 35.90208176643618, 39.202995531020626, 42.608362013293856, 41.01863322719451, 39.00099346714635, 37.953387229673325, 38.6668114508352, 38.38320839789606, 39.29390822687457, 35.921799521292414, 38.26782403453704, 38.039938249895656, 38.799493466654134, 40.126082205003314, 38.42390298843384, 36.818912259994015, 36.42205076832926, 36.87340182642783, 37.763532746222715, 39.16738825459635, 39.28768734778128, 40.58844727854575, 39.61691933293497, 39.95518061422533, 39.57744459952078, 49.18387043860651, 43.77761663929109, 40.08650941233481, 43.22865347708426, 48.04790104589155, 40.51784069307389, 33.46471701898883, 37.413229788503344, 40.08890205813993, 39.95987961369176, 38.96306022520989, 38.275429510301166, 39.62376386888566, 37.71585633677822, 38.925483918959095, 37.061475553820216, 38.34290212200534, 37.017784272470784, 38.41414805381529, 37.32863995336717, 35.14207155473771, 37.242026175222094, 37.27479365564162, 37.646116595114435, 38.97876147300967, 38.10615962551486, 38.51146205779045, 36.51095521065497, 39.646101767017, 36.11983999129265, 39.34310259357576, 37.78159526086623, 37.274366117292836, 36.70736789703369, 37.86116446218183, 37.72785486713533, 40.15135795839372, 39.6080312421245, 45.78441889055314, 46.17249035066175, 51.41895071152718, 51.45094940739294, 57.294206234716604, 55.472630070101836, 58.21351958859352, 56.83296688141362, 58.56453641768425, 48.44951252783499, 56.33280977126091, 54.186422132676654, 70.4262113571167, 12.909250778536643, 0.18006634658142445, 12.10770364730589, 0.2813878330972887, 0.08922692703744096, 40.62994987733903, 63.46476524106918, 55.91634819584509, 51.27394068625666, 54.885859181804044, 37.87648131770473, 22.08586427473253, 45.04945693477508, 55.701025762865626, 13.935032948370903, 0.2639468609085006, 0.10016407321898207, 0.1277039994695975, 0.057647166353079586, 0.04722443289093433, 0.03193157124182871, 0.06591659519941577, 0.08166462798873264, 0.04227470050776198, 0.044330508943887494, 0.039249403973019896, 0.031900406785068974, 0.04183734474222987, 0.08581513148402015, 0.04944918669700142, 0.0112470900339465, 0.056347149619532216, 0.08434781263912879, 0.21971409329243247, 8.718079597719255, 64.80055978221279, 55.16323743327972, 39.01558468418737, 27.833793778573316, 51.0389671787139, 57.32964484922348, 65.29735934349799, 65.47041823787075, 57.968340073862386, 65.02330726192844, 9.779387654796723, 0.8674815609570473, 0.9883322987344958, 0.8345857454884438, 10.173908472061157, 68.0621753200408, 57.93247392100673, 52.120250886486424, 47.74189733689832, 53.60470325716081, 57.337811223922245, 53.90890267587478, 58.06750543655888, 51.262605036458666, 55.68432823304207, 57.27326470036661, 54.232666877008256, 51.42167283642677, 45.14602961078767, 39.79799947431011, 40.200979863443685, 38.91200273267685, 39.026939945836226, 40.03055287945656, 40.0475053633413, 39.95135238093715, 40.26315727541524, 39.28668714338733, 39.956839776808216, 41.95478531622118, 39.41385822911417, 40.37505465169107, 37.82102292583835, 39.76196858190721, 39.30843668599283, 40.69982297958867, 40.21160948661066, 40.781945643886445, 40.648090839385986, 39.720885676722375, 38.395430503353, 38.715680260812086, 40.10769805600567, 39.814516575105735, 39.39823542871783, 40.676100484786495, 41.92664231023481, 37.908636908377375, 36.619518572284335, 40.7313000002215, 44.98876217872866, 47.87067267202562, 47.67340098657916, 42.98876916208575, 40.28029018832792, 37.20130805046328, 40.55757038054928, 43.25671411329701, 43.51762625478929, 41.362123027924575, 38.515988472969305, 38.85660317636306, 40.977177696843306, 40.127294217386556, 38.1352283108619, 41.033977539308616, 41.357184763877626, 40.39172864729359, 41.340228357622706, 40.9511370812693, 39.5313802842171, 37.99003785656345, 38.996580800702496, 39.453568304738695, 40.7284523594764, 39.63213028446321, 41.68346712666173, 40.675739626730646, 41.19134303062193, 39.79463015833209, 49.46438658622004, 46.08715918756301, 44.17257578142228, 46.162888388479914, 51.721361529442575, 42.32212704996909, 37.445832529375636, 40.389171261941236, 41.08693345900505, 40.15915955266645, 40.23284127635341, 39.978075488921135, 39.371755507684526, 39.7290010606089, 39.29433576522335, 38.32896201841293, 40.08794107744771, 39.59854302867767, 41.070992946624756, 40.023410243372766, 38.556279059379335, 40.1064468199207, 39.77200592717817, 40.39918115062099, 41.63836771442045, 40.37612938111828, 40.534134218769694, 38.26613741536295, 40.92511215517598, 39.18221873621787, 40.89743983361029, 40.641407120612364, 40.03606380954866, 39.992568646707845, 40.19338223241991, 39.71914414436587, 41.93265530370897, 41.409834738700624, 47.3941360750506, 50.58653746881793, 53.794310631290564, 55.11565123834918, 60.703212676509736, 56.533066380408506, 58.96452011600618, 58.22715766968266, 60.82936786836194, 50.01161606081071, 58.350524056342344, 57.59425970815844, 73.40414539460214, 13.348749414567026, 0.1965594381815003, 6.5884488148074, 1.1011132501786756, 0.1275257614531344, 44.10209078942576, 70.43417376856651, 62.975406416000865, 60.5064195202243, 61.99175050181728, 42.11613593562957, 31.48332388170304, 52.68708044482816, 63.796915469631074, 19.435448146635487, 0.3175265293928885, 0.17707653523933503, 0.057329071325159846, 0.048555047176177465, 0.03649312687376815, 0.029731784241213918, 0.02770509672231011, 0.12738137686204526, 0.13538230721267963, 0.122019772628142, 0.18442878830096415, 0.1289948959264063, 0.11467148790196066, 0.21131085952924145, 0.18321712831816367, 0.23524125527230003, 0.14200547439677103, 0.23327216415876345, 0.2953747906271489, 9.737046649379115, 74.33053078189974, 62.417351199734604, 44.01735190422305, 29.62791923553713, 52.54178408653506, 64.28132426354193, 70.56562023778116, 69.79105411037322, 60.83223904332807, 71.30947420673986, 11.807367763211651, 1.4232059087484115, 3.5042467376878186, 0.7135186031941445, 11.606939550369017, 69.01563290626773, 59.95533435575424, 53.56724462201519, 49.14005364141157, 56.34553786247008, 58.08152006518457, 57.866130951912176, 60.50339145045127, 53.07421838083575, 59.54980442600866, 60.25021814530896, 56.028159279977125, 52.45540172823014, 48.374556033842026, 41.40708123483966, 43.06532598310902, 40.63289165496826, 41.90530069412724, 42.36976423571187, 41.5132244940727, 42.156724622172696, 41.51518567915886, 43.57008403347385, 42.14220793016496, 45.76737619215443, 41.66378859550723, 42.98730611801148, 43.13364582677042, 42.94997692108155, 40.37916921800183, 43.847921202259684, 43.710285232913115, 45.34441917173324, 42.472322448607414, 41.5952177201548, 42.930788686198575, 41.090141957806004, 43.086785270321755, 41.46311621512137, 41.96030409105363, 42.34784995355914, 45.72502243903376, 41.09707670827066, 39.43961643403576, 43.61543839977634, 48.423279716122536, 48.66860828092022, 50.52510922954929, 46.48470709400792, 41.52234400472334, 38.71731588917394, 41.24720934898623, 45.97817613232521, 44.96110162427349, 42.51737479240664, 42.4551110882913, 40.986183458758944, 42.79722805946104, 43.74937949642059, 38.13328281525643, 43.247465164430686, 43.19344628241755, 42.4384057137274, 43.37263191899946, 44.32354388698455, 42.291971868084325, 38.98425279125091, 41.01316936554448, 43.00398403598417, 44.32955688045871, 41.82755539494176, 45.07219099229382, 44.09436764255647, 41.99927283871559, 41.4222921863679, 54.45918767682968, 49.077825238627774, 49.2876838099572, 50.86146423893591, 53.31297305322463, 46.35625731560492, 39.193354345137074, 44.12483269168485, 44.81653874920261, 44.302092444512155, 44.42598442877493, 43.34116274310697, 42.58431003939721, 41.46851339647847, 41.61207998952558, 41.788488588025494, 42.90162978633758, 41.560104662372225, 44.73753436919182, 41.9888864024993, 40.489846737154075, 42.5117971820216, 42.264460363695704, 42.913545946921076, 43.81355339480985, 43.7838924315668, 42.163753509521484, 40.13692755852976, 44.34260268365183, 40.8684221390755, 45.127198311590384, 44.057077669328265, 41.765629014661236, 41.972490895179014, 40.71209215348767, 41.929219307438025, 43.238290740597634, 42.741024417261926, 49.3721559739882, 53.5237886828761, 55.19287878467191, 58.14878871363979, 63.090414231823345, 60.948380424130356, 60.95224788112026, 60.32606109496086, 63.00341998377154, 53.612748038384225, 60.80498249300065, 60.343747062067834, 76.36452290319627, 15.659191166200946, 0.3806415104096936, 27.56236380146396, 2.482527162759535, 0.24109637334702477, 49.748001406269694, 75.62066893423759, 66.4441897792201, 64.56965769490888, 69.37040344361337, 51.62734231641216, 34.38595233425018, 60.027525578775716, 72.78621519765547, 26.388133648903143, 0.43738294633165486, 0.3383240085696021, 0.2857527569417031, 0.23413022859923302, 0.1426995653779276, 0.16950228521900793, 0.10342679572321715, 0.23136613740315362], [0.06687318620782706, 0.02415880677290261, 0.0356148453729768, 0.13051892059945291, 0.028172368221285365, 0.1490648367231892, 0.053911729295167236, 0.06126270682040242, 0.05468409530998719, 0.01647826779874102, 0.09148258099993391, 1.2591584146984163, 39.59314584732056, 54.1813152067123, 34.4591712182568, 26.077995761748284, 38.846930611518125, 47.75640226179554, 59.757023242212114, 61.96323879303471, 52.582835612758515, 63.706112600141964, 20.496296305810255, 0.29612500520963825, 0.8887035447743632, 0.8092675201835171, 3.031470222819236, 52.643804934717, 58.40928508389381, 51.850258458045225, 53.170092874957675, 53.86526630770776, 54.42116029800908, 57.446296138148156, 52.62185927360289, 56.671020061739036, 53.89622165310768, 53.264618073740316, 49.74936246871949, 42.60103894818214, 38.34964859870173, 37.70121412892496, 38.57882092075963, 36.84248570472964, 36.79037309462024, 36.40694572079566, 38.73012635015672, 38.23655489952334, 38.53883627922305, 38.580758571624756, 37.34005012819844, 39.982707808094645, 38.72330927079724, 36.2518395147016, 37.70717220921671, 36.652415490919545, 37.41153140221873, 37.42797790035125, 38.165183451867875, 37.79857127897201, 38.60966251742455, 37.58768896902762, 38.36088618924541, 37.494866078899754, 38.34831107047297, 37.783470153808594, 39.92206012049029, 38.383671237576394, 39.92989701609458, 37.86503976391208, 36.233808379019464, 38.393971381648896, 44.013166735249186, 42.53031469160511, 39.87756475325554, 43.920818451912176, 39.90327981210525, 37.47607792577436, 40.59228727894445, 39.41820029289492, 40.910611152648926, 38.047782990240286, 39.25195847788165, 37.651145073675345, 39.720187494831706, 38.99662394677439, 39.73232723051502, 39.17808063568608, 38.51343108761696, 38.03297212046962, 39.71923828125, 39.35218680289484, 38.26072062215498, 37.161641120910645, 36.50901755978985, 36.65445120103898, 38.977078776205744, 38.93809041669292, 38.97589029804353, 40.897114276885986, 40.1351664143224, 45.792757849539484, 49.245514408234634, 43.81882898269161, 42.58554950837166, 42.53604135205669, 44.04440056893134, 41.53479753002044, 33.01683333612258, 36.49615610799482, 37.98738633432696, 40.30570322467435, 38.81834045533211, 37.798386927573915, 36.97306533013621, 38.336371375668435, 36.77818236812469, 37.73828052705334, 38.095796723519605, 38.53467856684039, 37.15641260147095, 35.762916072722405, 37.22113955405451, 36.96123938406668, 36.9621140726151, 36.23662856317336, 38.27215825357745, 37.91306918667209, 36.86689853668213, 38.23440544066891, 39.168368847139426, 37.34445494990195, 38.76276831473074, 36.60921058347149, 38.723450476123446, 38.51852624647079, 38.4031379607416, 36.69553410622382, 39.275590758169855, 36.897689142534816, 40.84700207556448, 41.68764052852508, 44.829517872102805, 50.506783916104226, 56.076612318715746, 55.13988364127375, 61.989032299287864, 57.39452869661393, 60.641580473992136, 55.19907612954417, 58.9473166004304, 58.29870562399588, 64.0779846714389, 1.4639840948004879, 0.23339513659236893, 2.0984148450436133, 0.2823338291097072, 0.09436415944008097, 44.21756536729875, 61.11369263741278, 58.82883748700542, 50.19849346530054, 47.08006797298309, 32.72588956740595, 27.915514399928433, 43.49044422949515, 59.63759491520544, 10.915739478603488, 0.6044867634773254, 0.21902705032017925, 0.03400811384762487, 0.12213632524494203, 0.0806417397313541, 0.05126014194120804, 0.04238101818989362, 0.0579823489721504, 0.057990312456123294, 0.01863353168441644, 0.022314775682565187, 0.057346442368842905, 0.04536380067527775, 0.0746530465661518, 0.05694280596329801, 0.09006829842204049, 0.09878576613001286, 0.031344234612920595, 0.04839595369694214, 2.2766301853041497, 49.869818456711315, 63.28781535548549, 39.306471578536495, 20.91197732956179, 41.1750259707051, 53.617419581259455, 64.25228695715627, 66.43654900212442, 55.69768782584898, 68.73737996624362, 20.291983965904485, 0.39048463707008674, 0.68983998990828, 0.9099652425896738, 3.4386595602958434, 56.402298481233665, 61.197427395851385, 55.00285171693372, 53.9836238276574, 58.393399484695934, 56.67596617052632, 57.85335971463112, 55.290859591576364, 57.08839947177518, 57.516522253713305, 54.5165523405998, 53.62755498578472, 44.28352394411641, 40.82217739474389, 39.380474936577585, 39.71900293903966, 39.75362177818052, 40.6374769056997, 38.62343395909956, 39.06337484236687, 41.00679159164429, 40.10118692151962, 40.42070711812666, 39.87107715299053, 40.27645411029939, 41.02161815089565, 38.80373747118058, 40.23819138926845, 38.20247734746626, 39.23044035511632, 40.521441428892075, 39.87362277123236, 39.104387144888605, 40.82744121551514, 39.470897336159986, 40.85581956371185, 40.01944472712856, 40.12647051965037, 39.10171993317143, 40.30487560456799, 40.01538507400021, 42.35603986247894, 39.97439630569951, 38.76741240101476, 40.405237290167044, 46.07890259835028, 43.49121301404892, 42.933338226810584, 46.588014479606386, 42.05138937119515, 37.94833521689139, 40.599527974282545, 40.27165705157865, 41.860515071499734, 39.92835944698703, 39.54770518887428, 41.221035372826364, 40.36573510016165, 39.995581027000185, 40.80468362377536, 42.956409608164144, 40.433780377910985, 40.2761560101663, 42.10815391232891, 40.516373726629446, 39.68720036168253, 38.230059454517985, 38.82008591005879, 39.36191035855202, 40.305899343182965, 41.51206739487187, 39.73578283863683, 42.33891871667678, 42.61118219744775, 47.60038998819167, 52.474456602527255, 47.469994714183194, 45.58347978899556, 45.62220534970684, 47.6708161446356, 43.712995590702185, 37.366392766275716, 39.669165303630216, 40.59814337761172, 42.41021563929897, 38.3788388775241, 39.602081006573094, 38.07737335082024, 41.1342490103937, 38.904816950521166, 38.649733451104936, 39.97952284351472, 39.782196244885846, 40.249452514033166, 37.548994787277714, 40.94574382228237, 39.97724394644461, 38.031171752560525, 38.08990532352079, 41.01592286940544, 40.7676133032768, 40.45762054381832, 39.67104411894275, 41.51606821244763, 40.255422361435436, 40.180599228028335, 39.40788445934173, 41.2680685135626, 39.74349814076578, 38.84063520739156, 37.75082818923458, 41.18131745246149, 39.014407973135675, 43.73007359043245, 43.027934028256325, 47.36132544855918, 51.96610173871441, 56.60187259797127, 59.09205598215903, 62.8584138808712, 58.37327772571195, 64.41137044660508, 56.385648019852184, 62.63938873044906, 61.37828396212671, 67.0506509657829, 1.5661042279774144, 0.3331869293845469, 4.306931111120409, 0.21782128921439572, 0.03180092452244172, 48.08157851619106, 66.09591468687981, 61.679286649150235, 54.34670978976835, 55.695267723452666, 36.56111840278872, 25.01111891961867, 47.32159576108379, 66.99508666992188, 14.289554415210603, 0.6953833408413396, 0.18192844585545603, 0.0726089094795527, 0.11578747116389776, 0.09552082197079736, 0.06785976955847395, 0.06083147975826456, 0.09509567381633867, 0.15196578186606208, 0.10857354293787673, 0.18275730702425205, 0.25049259495590964, 0.18267050926243106, 0.21292019575353593, 0.14803300821973434, 0.23800030560983768, 0.24839628728166704, 0.22494855757442214, 0.22506397638109424, 2.8951443251102202, 58.02680692365093, 70.05424514893564, 45.86368999173565, 36.08619389995452, 51.16192563887566, 59.976962304884395, 69.00765480533724, 71.52005057181083, 62.01610449821719, 74.32644367218018, 25.403359859220444, 0.751758341587359, 3.0362998862420363, 1.3535104163231388, 5.380250446258053, 59.651421270062855, 63.592583517874445, 58.111232019239864, 57.42793944574172, 61.712744466720096, 59.196041937797304, 61.331709738700624, 56.16530103068198, 58.365119195753536, 58.266910891379084, 56.9779259158719, 55.2524164415175, 45.99348906547793, 43.345932345236506, 43.021924957152336, 41.970239454700106, 41.584207627081106, 42.163306359321844, 41.44458301605717, 41.93819369039228, 44.21413721576814, 43.170272919439505, 43.43873954588368, 42.80921482270764, 44.61926314138597, 45.02463617632466, 40.01470258159023, 41.49012173375776, 40.195343417506066, 41.596119865294426, 42.32749285236482, 42.91633867448376, 42.49322475925569, 42.327233975933446, 40.404699925453436, 41.1542687877532, 41.279274725144916, 43.607742709498254, 41.71386157312701, 43.24482540930472, 43.385783626187234, 42.183004502327215, 42.837616705125384, 41.47100802390806, 44.35060039643319, 50.13380965878887, 47.590725268087084, 46.08629234375493, 49.8326422322181, 43.58632264598724, 39.951901512761275, 42.89376543414208, 44.674949030722345, 43.08924851878997, 41.58782405237998, 41.93119618200487, 41.946924886395855, 43.286300551506784, 43.67656853891189, 44.787160196611964, 45.284348072544226, 42.490145698670425, 42.529443925426854, 43.492464250133885, 43.886568315567516, 41.24499713220904, 40.39601187552176, 40.642509306630785, 40.7092680469636, 41.945124518486764, 43.46316414494669, 41.141556386024725, 45.34803559703212, 44.854636730686316, 48.268067606033824, 53.10463636152206, 50.37194067432035, 50.03345974030034, 50.20080374133203, 49.37719621965962, 45.79948079201483, 38.4068642124053, 42.171829669706284, 42.35744014863045, 45.08213027831047, 41.97003941382132, 41.912925781742224, 41.02227710908459, 43.59388105330929, 41.36301340595369, 41.67841903624996, 42.38878380867743, 41.31317577054424, 42.43110618283672, 39.61048664585237, 42.376797045430834, 41.82575894940285, 41.702859324793664, 41.73665446619834, 43.01401353651478, 42.69956496454055, 41.45370644907798, 43.51069542669481, 42.76422523683117, 43.4635877609253, 43.29526316735053, 40.93128596582721, 44.03844641100976, 43.07740296086958, 42.216552534411036, 40.50228065060031, 43.881775179216945, 41.383445032181285, 48.289197414152085, 44.998709309485655, 49.26729140743133, 55.289184739512784, 60.256278207225186, 61.35997826053251, 65.71400134794175, 60.58382749557496, 66.77806977302798, 58.85294437408448, 64.65243147265527, 63.14256998800463, 70.89512286647674, 2.6389998245623807, 0.4667778625603645, 10.680502191666635, 1.5040888589236046, 0.19251835502443776, 52.00638448038409, 71.85812750170308, 68.09873965478712, 63.903094030195675, 63.998795940030014, 48.73726544841644, 39.931630703710745, 56.187556559039706, 78.01120450419765, 19.983607222956998, 0.8037831886641441, 0.29115845719652794, 0.16897618199788755, 0.36176562489521125, 0.21003572150103508, 0.1611769013106823, 0.1568290459052209, 0.1930852754101638], [0.04208502096814975, 0.009125721708480871, 0.06737477461537046, 0.05473636548906084, 0.04487181517986521, 0.07279216537191983, 0.046576249728640245, 0.03747624750699728, 0.04301249297455915, 0.05233065405439946, 0.026508699126181104, 0.6993749653620105, 31.543185134087842, 56.823984653719016, 37.03171260895268, 30.248808860778812, 33.32513947640696, 52.67452886027675, 61.420724007391165, 61.75423922077302, 53.77868390852406, 59.82912425071963, 30.55385158907983, 0.02487727467180981, 0.4890857606885895, 0.13644623480016185, 0.05120727804399306, 32.97480513972621, 67.42882236357659, 50.10993811392015, 57.61524046621015, 51.760671523309526, 60.41435756990987, 56.46444843661401, 60.17949388873193, 52.17135152509136, 52.81815428887644, 49.1307262451418, 43.86668974353422, 37.800489317986276, 38.277802544255415, 36.86670241817352, 39.66450945023568, 34.73802035854709, 37.16340618748819, 37.18372406498079, 39.62707827168126, 36.957132662496264, 39.50877958728422, 36.3243955181491, 40.406967055413034, 41.19994086603965, 38.88964130032448, 40.277136602709376, 37.38914643564532, 38.85648158288772, 37.167395237953436, 38.83529293921686, 39.14205366565336, 38.51136007616597, 38.303584283398045, 38.10383366000268, 38.297061381801484, 38.57844045085292, 40.94634394491873, 35.63006539498606, 38.08767349489274, 38.659111838186945, 41.164588543676565, 37.390570256017874, 34.451781472852154, 38.962330664357836, 41.59214650430987, 41.607549651976555, 40.733841696093165, 46.820403145205596, 48.645132895438906, 38.4477549214517, 41.91512230903872, 40.023982909417924, 40.94966619245468, 38.74849088730351, 38.783305844952984, 37.66810540230044, 38.54414716843636, 37.25344811716388, 39.53796594373642, 38.33844238711942, 38.627752488659276, 37.69349882679601, 39.973549073742284, 39.55232574093727, 35.59740381856119, 35.958756093055975, 37.82791453023111, 37.46464813909223, 38.9347642467868, 39.372740022597775, 39.04633606633833, 39.4019381461605, 38.83246491032262, 41.07966530707575, 48.092478782899924, 45.38265051380281, 42.220674945462136, 44.02582422379525, 44.23389027195592, 42.98002619897166, 38.07210953004899, 36.20553593481741, 39.65337776368664, 40.208769690605905, 38.50902234354327, 38.86141984693466, 39.08915265913933, 38.188125395005756, 37.59808324998425, 37.00012968432519, 38.3655067413084, 37.05487028245003, 37.44769957757766, 34.86479528488652, 36.61108155404368, 36.824615386224565, 36.561075256716826, 37.11236438443584, 38.06354307359265, 38.02433506135018, 37.999702576668035, 37.51101839926935, 38.65002762886786, 37.541605041873076, 40.06854103457543, 38.48680996125744, 36.89375500525198, 39.20330932063442, 38.265980520556056, 37.177197241014056, 37.238350914370635, 38.352590376330966, 38.31852066901423, 39.429610467726185, 40.17231910459457, 45.294153997975016, 50.45416532024261, 54.57938086601996, 55.0325362143978, 61.38659546452185, 57.81406933261503, 60.672296554811545, 55.7803713890814, 68.4112427311559, 28.505095666454686, 0.03155379030372828, 0.22682207155852552, 1.628083805403402, 0.2655341644440928, 0.21679848522668888, 47.30140339943671, 58.09695066944246, 58.74941733575637, 60.74055364055019, 38.96556661974999, 24.981781551914832, 34.02485893618676, 46.10697107930338, 56.14752877143122, 4.974710220290769, 0.21496433284013503, 0.11484585717440614, 0.04138196292783945, 0.06478093879958315, 0.024550480715509866, 0.05766860149320095, 0.04304757597105157, 0.019154753010239334, 0.031471652271706736, 0.01472976595734156, 0.023992016025248076, 0.034280653457127275, 0.0906521263682554, 0.0363853766072181, 0.021947564842600017, 0.031862565872049144, 0.04048987652265257, 0.02053724868493455, 0.021348355766085368, 0.7646164838825503, 40.024461438578946, 62.47652799852433, 41.391219169862815, 36.094477945758456, 40.400295103749926, 57.998130475321126, 64.36447458882486, 65.81742640464537, 57.305953733382694, 66.69521362550798, 32.205783282556844, 0.0741189913523774, 0.6927965377126971, 1.423920638138248, 0.10607929855224588, 37.59023458726945, 68.0598375874181, 53.73158800986506, 61.68662148137247, 54.86450972095613, 60.092597699934444, 57.77553596804219, 60.921374905493956, 54.898548049311486, 55.17271387961603, 51.28460953312536, 47.06713984089513, 39.95725947041666, 39.672750349967714, 38.02531957626343, 41.196430344735425, 37.8396188828253, 38.94628032561272, 40.05680922539004, 40.45927970640121, 38.59007812315418, 40.82689992843136, 39.21784954686319, 41.89982898773686, 41.847320218240064, 41.89702841543382, 41.28183995523761, 40.08636428463844, 40.955377163425574, 38.69513880821967, 40.32161235809326, 39.34297315536007, 39.66496444517566, 39.9501835146258, 40.039189938575994, 40.15873201431767, 40.78076108809441, 41.97192999624437, 38.354896729992284, 39.978357899573545, 39.12377542065036, 42.61188822407877, 40.9860618652836, 37.53304250778691, 42.13579877730339, 43.89999458866735, 43.621255274741884, 43.62834299764326, 46.155930103794226, 50.12221905492967, 39.71221723864156, 42.48876110199959, 40.86290728661322, 40.62372507587556, 40.61415057028494, 39.19635103594872, 40.67792046454645, 39.69466463212044, 39.14247335926179, 40.74834269862021, 41.67501049657022, 40.12118708702826, 40.37313661267681, 40.52633262449696, 40.2207289972613, 39.54858772216305, 38.7905583074016, 39.94815172687654, 40.33849423931491, 41.11565305340675, 39.77721875713718, 41.12071683329921, 39.949548090657885, 38.548096995199884, 41.905951807575846, 49.191813238205455, 45.754569653541814, 46.086974836164906, 48.247510463960715, 46.55073235111852, 45.046719120394805, 38.602241393058534, 39.44927723177018, 41.46373987197876, 40.90913634146414, 40.23696760977469, 39.206615878689675, 39.89386612369169, 39.815924705997595, 38.95137548446655, 38.425118923187256, 39.98268035150344, 38.19370300539079, 38.16453626078945, 38.123249392355646, 38.35045660695722, 39.92160512555031, 38.26914979565529, 39.21648456204323, 38.882459440538966, 40.457491105602635, 40.29415968925723, 41.08654906672817, 40.01774634084394, 39.89130089359899, 40.236422400320734, 41.234277294528106, 39.00171910562823, 40.22796577022922, 40.41025007924726, 38.958231787527765, 39.63708031562067, 40.768695877444365, 41.85746738987584, 41.81723171664823, 42.01150278891287, 48.1950330734253, 53.40137543216829, 56.22796873892508, 57.5266537358684, 63.27956268864294, 59.843001596389286, 62.9151431206734, 59.110769610251154, 70.14648360590782, 32.667658059827744, 0.08930456238768755, 1.1979671111029964, 3.097397175527388, 0.32007285243561195, 0.08408629320441716, 51.37805215774044, 62.651202909408084, 63.421058270239065, 64.4786665516515, 50.23998037461312, 31.676690847642963, 38.72039887212938, 53.27097231341947, 63.254667405159246, 7.548096881758783, 0.2252335116387375, 0.18998477968477434, 0.09616394512235157, 0.05230336983297622, 0.026260339166788806, 0.03023683153573544, 0.0239572279726065, 0.03033701859925303, 0.162151993342465, 0.18346884948832376, 0.282202061986731, 0.16173361740525694, 0.1996870074541338, 0.18076673480531863, 0.17071832722473532, 0.17726189787349395, 0.10780505715839325, 0.21179202403272354, 0.14821876921961386, 1.3296030798266012, 46.99515650349279, 73.83431173140004, 50.41274509122295, 43.72767309988699, 47.577318606838105, 66.98625349229383, 69.11758315178656, 72.15658064811461, 62.13665462309315, 70.51506088626, 37.66800734304613, 0.2354542123934915, 2.843955188028274, 1.2918684078801064, 0.4066391331293891, 35.97323748373216, 72.38200710665795, 56.22150859525127, 63.18218592674502, 57.75672820306594, 64.32917325727402, 60.56293302966703, 63.60972427552747, 57.459012462246804, 56.590168245377086, 54.841034335474816, 48.69642965255245, 42.32956386381581, 43.08352578070856, 39.537542327757805, 43.51046008448447, 38.54095043674592, 41.180011303194114, 43.41961406892346, 43.944387974277625, 40.32023560616278, 43.72489213943482, 40.96378280270485, 45.08831977844239, 46.34891463864235, 43.860311969634026, 44.984180850367395, 40.81450523868684, 42.865787167702955, 41.24404399625717, 43.02947159736387, 42.53192678574593, 43.37386746560374, 41.50319499354209, 41.667985531591604, 43.33532233392039, 42.784829447346354, 45.784320831298835, 40.672244794907115, 42.09110729156002, 42.08027370514409, 44.27691082800589, 42.49335027510121, 40.189138227893466, 44.81587194627331, 47.64832135169737, 44.68133857173305, 46.355751329852694, 50.33088130335654, 53.99183334842805, 40.366335222798014, 44.417441506539625, 42.583925647120324, 42.48496424767279, 41.914228008639434, 42.95470729950936, 42.95354627793835, 41.74543665301415, 40.97787980110415, 44.416743324648955, 42.63110391555294, 42.79066985653293, 42.58234885431106, 42.87879766956453, 43.629758973275464, 41.25593270024946, 39.97574167866861, 43.26425683113837, 42.70785685508482, 44.220958217497795, 41.83509811278313, 42.34690858471779, 41.77252454142417, 38.45823157218195, 42.64369472380608, 52.02429794496106, 48.61749587520477, 51.21071992381927, 51.34209579037082, 49.78298502583658, 49.39366625201318, 41.98900407360446, 41.33152461821034, 42.934550239193825, 41.89445141823062, 42.01845322885821, 41.05277353717435, 43.0871618178583, 42.180902111914854, 41.250927755909586, 40.78068656306113, 40.715622286642756, 40.428736209869385, 40.806742868115826, 39.68254058591781, 40.45115255540417, 41.69926251134565, 40.59607628853091, 41.17884243688276, 41.59639050883632, 43.465078261590776, 43.44110865746775, 43.53174678740963, 42.66931564577165, 41.9638930597613, 43.37036478903986, 44.72281371393512, 40.54269675285586, 43.35070586973622, 43.63268506142401, 42.12241565027545, 41.476295378900346, 43.4806892948766, 42.41434981746059, 43.4983281935415, 44.27129007154896, 51.46810585452665, 54.70641074642059, 60.78683760858352, 60.62408278065344, 66.2150292242727, 60.474475737540956, 66.04464146398729, 61.22326404817643, 71.50748329777872, 34.045066987314534, 0.17211272982099365, 0.6426031923582477, 5.893851480176372, 1.0348399031546809, 0.3108765491314473, 57.785192843406435, 69.61802267259168, 70.66469146359351, 70.18831960616573, 54.51310849958851, 37.32959308931905, 47.071109279509514, 60.36453954635128, 75.4108456642397, 10.445307070209134, 0.3949629725708116, 0.35483314205081234, 0.19423073007454797, 0.12126330676819048, 0.10837622167121981, 0.1865927721824377, 0.12482114932349614, 0.11051824181190423], [0.04525662114423129, 0.057739897465874115, 0.03131577636175339, 0.04551132239641682, 0.0563034059990558, 0.07012278562591923, 0.048210280797173904, 0.0658550170520621, 0.03804622075310157, 0.1553136627039602, 0.05814196339117424, 0.12455868760063765, 25.60648960451926, 61.05019730906333, 38.32123887154364, 20.540585748610958, 25.18360907031644, 47.60783464677873, 58.636092216737815, 58.91570229684153, 54.8884165671564, 56.90916284438103, 41.542583434812485, 0.38674677151345443, 0.852967810726935, 0.6081568149309005, 0.13451241437465916, 3.8009120187451764, 54.80494460751934, 57.42953192803168, 55.64426906647221, 57.965362994901604, 60.57874410383163, 56.79990914560134, 54.696039999684984, 50.17791278900639, 48.00892445348924, 42.99018906008813, 39.80973128349551, 38.92362079312725, 38.46271484128891, 36.806803903272076, 36.70492426041634, 35.95696356988723, 37.098063422787575, 37.64159802467593, 36.779668946419996, 37.587857630945024, 39.071172514269435, 41.98260276548324, 40.537660429554606, 41.53329133987427, 39.33736024364349, 39.22406650358631, 41.31117928412653, 41.308249273607814, 40.44042487298289, 37.82107391665059, 37.64680693226476, 36.75783703404088, 37.10197402584938, 38.51518438708398, 38.88838614186933, 39.00987371321648, 37.33946177267259, 37.24423054725894, 38.56799125671387, 39.71574344942647, 41.60611014212332, 37.26117518640334, 37.482847936691776, 37.321254130332704, 43.39723302472023, 41.89503585138629, 40.54384208494618, 46.92241222627702, 45.20297850331953, 40.46015439494964, 40.29503045543548, 40.192793876894065, 37.972194994649584, 38.41674858523954, 38.18019044014716, 38.50895958562052, 37.97986322833646, 36.57505066164079, 38.70728638864333, 40.4533451603305, 38.98598647886707, 38.16451272656841, 37.495983954398866, 40.9662970419853, 38.317634213355284, 36.89799116503808, 37.068520130649695, 36.58139705657959, 38.20448167862431, 38.20530929873067, 40.652228939917784, 39.09425174036334, 39.687439626263036, 41.000409895373934, 44.79238871605166, 47.62218267686906, 40.692876462013494, 40.30839789298273, 41.62533760070801, 41.593731141859486, 35.442576100749356, 36.181876197937996, 37.98388365776309, 40.262470860635084, 38.593863210370465, 39.299234805568574, 38.16878026531589, 37.65170597260998, 36.68741087759695, 38.306290718816946, 38.28687498646398, 37.868718947133715, 38.26392127621559, 37.01659579430857, 37.16483785260109, 38.022075776130926, 36.61899689705142, 37.80315260733328, 37.43976070034889, 37.96807258359848, 39.101657175248675, 38.10503390527541, 39.26767149279195, 37.34392542992869, 38.165967925902336, 40.723070867599986, 42.44528162863947, 45.80310506205405, 46.59820087494389, 44.96168605742916, 41.24555803114369, 38.719673233647505, 37.76705503463745, 37.507131330428585, 40.932717630940104, 38.53273699360509, 43.77296078589655, 51.92628183672505, 53.16789634766118, 58.46774801131218, 57.44133041751001, 59.78501327576176, 58.30957843411354, 61.79482398494598, 5.542421331328731, 0.30171236023306847, 0.5050065692874693, 2.1341040009452454, 0.19101070931121228, 0.27304590168979864, 46.12953647490471, 60.74467605160129, 57.676633404147246, 58.739568264253684, 31.66462563699292, 28.220090366178944, 27.99917071096359, 48.74633396825483, 45.1239231324965, 1.316599932409102, 0.10242069245225961, 0.10632349673898951, 0.02137799379265597, 0.06364294200114186, 0.030716121039022843, 0.025008377213511738, 0.038269788192044345, 0.04278638595414739, 0.03459949542077319, 0.0832283589988947, 0.02433542259818604, 0.032949656127922, 0.03201694216489071, 0.028231843457286878, 0.04132842487325111, 0.048643200913624424, 0.02086569164549151, 0.08637355595466592, 0.07008016815469151, 0.15138753870081517, 32.08157162512503, 67.15428783047584, 43.17743124500398, 24.00267362594605, 35.51852103202574, 55.890127151243156, 62.49873253606982, 62.93468044650171, 59.23654825456681, 63.14149133620724, 44.47810096125449, 0.1796486907668652, 1.0406783511561732, 2.7841549775292798, 0.192881174265377, 5.563845317209921, 58.89705142667217, 58.26959771494712, 59.02437156246555, 58.62780817093388, 62.18092249285791, 56.59945249557496, 56.384506610132036, 53.23959727441111, 50.98890204583445, 46.247262493256606, 40.33259499457575, 41.47053341711722, 38.64577577960107, 39.05228237951956, 38.59473005417855, 38.752868252415816, 39.28785993206886, 38.78329800021264, 39.16648610945671, 39.64180284930814, 41.58358397022371, 42.68132594323928, 43.76016601439446, 43.42080646945585, 41.85154853328582, 41.41911506652832, 42.7522502406951, 42.01100464790098, 42.32664169803743, 40.000083907958, 40.61318958959272, 40.67657116920718, 39.78145883929345, 40.550780757781, 40.93545152295021, 41.003994941711426, 39.563300532679406, 38.872214209648874, 39.443978109667384, 40.644505793048495, 44.67488627279959, 40.29403025104154, 38.052187811943796, 39.96233893978981, 45.82706289906656, 44.13343052710257, 44.06516951899375, 48.05246668477213, 45.6588363647461, 41.2276327994562, 42.78524521858462, 42.489133727165964, 40.02779937559559, 38.20282643841159, 39.5453360772902, 40.60426227508053, 40.147812135757945, 39.412030404613866, 41.41756573031026, 42.17324564533849, 42.310155976203184, 40.1058231630633, 38.74825946746334, 41.633272555566606, 40.88928914839222, 39.59882543933007, 39.86122415911767, 39.3952779616079, 39.40667244695848, 40.457977479504, 42.79544338103264, 41.297282326606016, 41.35379583604875, 40.79607402124713, 46.44492249335013, 48.504770878822576, 43.98548656894315, 45.01463805475543, 43.95098932327763, 44.39762961479926, 37.47703890646658, 38.06175839516425, 40.78949620646816, 40.391132447027395, 40.91976988700129, 40.85440358807964, 39.82828017204039, 39.34302022380214, 39.90924573713734, 39.95714572168166, 40.6421249143539, 39.62790196941745, 40.47345515220396, 39.793500515722464, 38.59731097375193, 38.861121746801565, 38.739626330714074, 39.99171749238045, 40.778909729373076, 40.15884576305267, 40.10587807624571, 39.026159394171934, 41.5266703790234, 40.15340151325349, 39.94808112421344, 43.62516195543351, 44.5610983141007, 49.12439161731351, 48.213727089666556, 44.62047515376922, 43.44758449062225, 42.47236167230914, 39.77558705114549, 41.18360027190178, 42.734748624986224, 40.89455689153364, 45.125998066317656, 54.4578109248992, 56.28947150322699, 60.323813576852125, 59.28260080275997, 61.19556819238971, 61.030628604273645, 63.03961953809185, 7.286653259108144, 0.7652914992743923, 4.166583313095955, 5.6811516419533765, 0.14152814033291033, 0.2765864229971363, 51.638030775131725, 64.69967249901065, 64.61368630009314, 63.1320894149042, 38.292103505903675, 29.496523757134717, 31.27982543360803, 53.76677951505108, 53.27373758439095, 2.5339957687162586, 0.18857948331823274, 0.0856392989836393, 0.02805889719316075, 0.017377438602007685, 0.014557820395566525, 0.03327929227042102, 0.03411286487995136, 0.04319360765117792, 0.1641457678089219, 0.19548913674248805, 0.0784850643286782, 0.15465677295240665, 0.11578169486094868, 0.12713483444625331, 0.15613113980620139, 0.18452716931220026, 0.18877609212312008, 0.3635676781977377, 0.1259480646601127, 0.32723215859263177, 38.669984648304606, 74.92609562412386, 53.183821170560776, 31.099986722392423, 38.03974213138704, 60.788716423896055, 67.16352893460181, 68.4143021798903, 63.93618314496933, 67.94222139543103, 50.134958913249356, 0.6290358365062745, 2.4261651548647114, 4.458985222924141, 0.13832875797825475, 6.594967303737518, 60.07321334654286, 61.358428924314445, 59.39097981299124, 63.242778701166955, 63.64650826300345, 58.98887803477626, 59.7645345810921, 56.230577115089666, 52.59674433738955, 48.27389232573971, 44.622503019148304, 42.845787002194314, 42.663561528728856, 40.907096708974535, 40.89712212162633, 40.60643526815599, 42.29219152081398, 42.37108215208977, 41.23043729412941, 41.18918572702716, 45.18302540625296, 44.97208818312615, 44.474260960855794, 45.35049100075999, 43.978230184124364, 43.90107324046474, 46.373864835308446, 45.19884824752808, 44.6854256814526, 42.414004648885424, 41.27630941329464, 42.2180587245572, 41.37187011780278, 42.29216798659294, 44.04550275494976, 42.9322870316044, 39.2856437929215, 41.85622399853122, 40.16250141205327, 43.62140824717861, 46.29065567447294, 41.90845820211595, 41.70816629163681, 41.67535958751556, 46.67742490768433, 47.44475033975417, 46.64535953152565, 49.45919729048207, 46.830942553858605, 43.45772773988786, 45.504546011647875, 44.23194869872063, 40.531176751659764, 41.09631969082741, 42.492499120773815, 43.01444891960391, 42.23471310830886, 41.42786587438276, 43.60826830710135, 44.80000203655612, 44.08256915307815, 43.039712905883796, 40.59870819891653, 45.169308877760365, 43.579909570755504, 41.03300479150588, 42.737282476117535, 41.094860569123306, 42.78470000913067, 42.80802634454543, 45.22081744286322, 40.90841070298226, 42.62759339424872, 43.627652660492934, 46.94298113546064, 51.41802895453669, 46.508005972831484, 47.16747799227315, 46.3365944739311, 46.04560167558732, 40.16807117769795, 39.175185926498905, 42.789728487691576, 43.55353163134667, 42.36663810668453, 43.431808717789195, 42.828348144408196, 42.046760974391816, 41.20178830239081, 42.8262653658467, 41.40535539196384, 41.449482056402395, 42.865449843868134, 43.46526261298887, 41.43433778516708, 42.84983881058232, 40.83179504640641, 43.0963009403598, 43.35679731061382, 43.03436279296876, 42.99105982626639, 41.89651066257108, 44.16061647476689, 40.10499554295694, 41.278705981469926, 45.556070266231416, 48.01392155308878, 51.66036475089289, 52.13121783348822, 47.19489535977764, 45.775821055135424, 44.44907149960918, 41.91403973487116, 43.438280628573516, 46.77500955520138, 42.42021768323837, 48.77387292923466, 56.76707498488888, 57.82465580971011, 64.29313844250095, 60.504128856043664, 62.79427136144331, 59.78160081371185, 66.24193668365479, 9.098456348142317, 0.4925096527703347, 4.737372994422913, 13.100422197772613, 1.0825232993210516, 0.5338864292829267, 55.913881025006695, 70.0993053374752, 70.2927723238545, 68.2218942334575, 42.639423262688425, 38.97598443492767, 40.71263344057145, 62.271945015076675, 63.82945937495079, 4.4541361927986145, 0.34102023969734874, 0.17082018627514764, 0.08505209258967832, 0.16434798437741496, 0.08555495270317601, 0.22099463990138424, 0.14378881983218655, 0.18257611190840123], [0.049292456599012505, 0.055324920197768565, 0.05839317511286467, 0.0763976509352365, 0.0802260221192433, 0.01577986853062025, 0.08145940835557638, 0.07831335338132997, 0.0707901171558807, 0.08026763601529022, 0.012784045313545054, 0.04048502335565225, 23.62935616124061, 53.95327644963419, 49.71823061666181, 33.882739697733236, 23.83974817491347, 42.80723010340045, 61.67775692478303, 58.52725821156656, 58.24383558765535, 49.76116095819781, 56.39884679548202, 2.944345310811074, 1.3180525576876057, 2.0076369806643455, 0.32873353770663666, 0.04624679361680343, 11.212531501247037, 57.995992783577215, 55.242026082931034, 59.81997728347779, 54.28534038605229, 53.06290234288862, 47.82947601810579, 44.90877328380462, 39.78389855354063, 38.77677117624591, 37.228513609978464, 38.12869756452499, 36.37441750495665, 37.0538269319842, 37.622496081936745, 36.5030869360893, 35.48081136518909, 37.95694481941962, 37.65418098818871, 43.56991929392661, 42.15342590885778, 41.717368172061065, 41.468776195280014, 42.55230349879111, 42.5080003276948, 41.53429546663838, 42.445273783899125, 41.59355855757191, 41.20318074380198, 40.31951389005108, 39.910716625951956, 38.09600068676857, 39.74221160334926, 39.102716215195194, 38.614718452576675, 38.92455039485809, 38.191071095005164, 37.292546303041526, 38.61107849305676, 39.03066227512975, 42.442920361795736, 38.41970997471964, 37.23494237469089, 41.2466327605709, 42.212386977288034, 42.41173359655565, 43.56141167302286, 46.418007189227694, 44.086279715261156, 41.3458530364498, 40.01332582965974, 38.3915905029543, 38.78947573323404, 38.39475977805353, 38.34302371548068, 37.600797530143495, 38.49872612184094, 36.553250128223056, 37.76532526939146, 38.89428930897867, 39.24117588227795, 39.164697508658136, 37.16816794487738, 39.55892708993728, 35.91587281996204, 36.84848300872311, 36.781845861865634, 38.293958786995184, 37.67373792586788, 37.7257054082809, 38.439843500814135, 41.9378092981154, 39.71948539057086, 40.23604193041402, 44.12902962776923, 46.44325940839706, 39.92247981409873, 41.42109194109517, 42.50492518947971, 41.9431358768094, 36.71320046147993, 35.71297645568848, 39.37008457799112, 40.523457527160645, 36.94429866729244, 37.66876828285956, 36.60108343247445, 37.749647555812714, 38.600939166161325, 37.8380460123862, 39.93240733300486, 36.471707974710775, 37.48747241112494, 36.764748250284505, 34.75917370088639, 37.016752689115464, 36.295436659166896, 38.626038412893976, 38.32321966848066, 37.86484364540347, 38.75685730288106, 37.90103143261325, 38.73009889356552, 38.161869049072266, 43.91686862514865, 48.75018573576405, 51.98468985096101, 49.452674388885505, 48.8780903047131, 48.72690646879135, 48.37193196819675, 43.30024457746937, 40.94487305610411, 39.1616419822939, 39.67484489563973, 39.02850104916481, 39.72513360361899, 43.54771475638113, 51.38688925773867, 52.92681963213029, 57.26485513871717, 58.768040749334524, 61.68036530094763, 41.73961585567844, 0.458236288639807, 0.04729362595225534, 3.8199171279707267, 1.127700791243584, 0.05973473296410615, 0.7008290002422949, 50.130055950533965, 58.65600216773249, 56.676731032709924, 59.32071839609454, 32.54309927263568, 31.05398712619659, 41.00696417593187, 48.78008596358761, 45.973783077732215, 0.8157417598751284, 0.047121191051818674, 0.044640471948490995, 0.04893855462151189, 0.07224647328257561, 0.0473239362209795, 0.005434167603286164, 0.04027731393674209, 0.016190283856685125, 0.058717781888140794, 0.012812150206657187, 0.015153328309796993, 0.035241404322967414, 0.06398008580529882, 0.03732137134178512, 0.05403274820456582, 0.019119995601114728, 0.0632466523787908, 0.049830422691640355, 0.06820003517092237, 0.026954058595302127, 29.20582513655386, 61.33762075055031, 54.961270670736994, 32.63404726982117, 33.43331844575944, 53.24785386362384, 67.9484893429664, 64.0817540691745, 62.21624343625961, 55.13623975938367, 59.673515981243504, 2.4212298325953947, 1.0279577369651487, 1.6318210887332119, 1.2597444413169738, 0.04320630172808324, 12.642269749795238, 60.51189122661468, 55.61791073891425, 63.7242574845591, 54.27844093691919, 57.41921217210832, 50.6209994131519, 48.50478656830327, 43.5281107502599, 42.659015501699145, 38.522797707588445, 41.47311041432042, 36.58005168361049, 38.92226365304763, 39.57842519206386, 38.487621891883116, 37.98098894857591, 39.72167407312701, 40.58403853447207, 45.26915673286685, 41.45339658183437, 43.90905134139523, 43.46860055000552, 46.1102972492095, 43.5461889543841, 44.21559241510207, 43.75741251053349, 42.546321884278335, 41.540853669566495, 41.55726878873764, 41.36176609223889, 41.05648802172753, 41.39021112072853, 41.79745904860958, 38.28237210550616, 40.74355348463982, 38.669294311154275, 39.81498725952641, 40.3180076999049, 40.85818083055558, 44.22269974985431, 42.00998875402635, 40.18274476451259, 44.42600796299596, 46.14046812057496, 46.54824556842927, 43.31765597866428, 46.699994225655836, 46.167732515642726, 42.000069079860566, 39.837301623436716, 41.52945133947557, 41.18538102796001, 39.244945280013546, 39.22087369426605, 39.04810113291587, 38.984421453168316, 38.490724486689416, 38.80637722630655, 42.046349125523726, 41.403382439767164, 40.99464008885045, 39.75583399495771, 41.21334360491845, 37.86374930412539, 40.167749543343824, 38.02856337639594, 40.33618004091325, 39.531713685681744, 41.118504616522024, 41.08756103823262, 43.26600620823522, 41.494495176499896, 42.649888146308164, 45.76557190187516, 46.66938012646091, 42.8691957073827, 43.03457460095806, 44.53099804539835, 43.12859381398847, 38.242614961439564, 36.87236632070234, 41.53583695811611, 42.412541604811146, 39.91965570757466, 38.4938859170483, 38.08176248304306, 38.69778640808598, 40.93563587434831, 40.019629078526656, 40.660018767080004, 38.115785121917725, 40.48598320253434, 39.181457796404445, 37.63481624664799, 37.34580424524123, 37.53015172096991, 39.76754619229225, 39.90200504179924, 40.48614794208158, 41.36614345735119, 39.433387710202126, 41.17225285499327, 41.261035703843646, 45.22833270411338, 50.61141314045076, 51.94470128705425, 51.16040768161897, 51.42885861858245, 52.41879032504175, 50.61910490835867, 46.746686120187086, 42.8258966630505, 41.32977524111348, 40.91400008047781, 42.73203042245681, 43.10933105407223, 45.4216859417577, 53.14068686577582, 57.12366942436465, 59.44114300512499, 62.313361321726155, 60.84091924851941, 46.318971264746885, 0.7685132973617124, 0.618021943636479, 7.560171898334258, 6.459761242712698, 0.3507073295693244, 0.7745432060572409, 56.464126802259884, 62.64611559529459, 63.115552702257716, 63.42687514520461, 45.110955776706824, 36.31018084864463, 43.04992675781251, 56.55024636176325, 53.88490561516055, 1.1901495822014347, 0.06152398110697828, 0.03642667257677644, 0.007378618935153129, 0.026454839314664566, 0.026877867320792812, 0.05287793194574695, 0.0660787683521067, 0.012830069960816013, 0.12747964296009273, 0.09696266073132716, 0.1447638352551768, 0.2006046888568709, 0.18240584120635064, 0.1677382145557673, 0.25867810653102014, 0.14710273233152207, 0.17643510514209348, 0.22565830739275103, 0.17032196865447108, 0.13969924330951708, 33.45223995947069, 69.72700180545931, 62.17433291096842, 45.15784771211686, 35.27321992381927, 53.576772059163744, 75.11029012741582, 66.88340110163536, 66.71251912270823, 59.77183803435295, 67.02921913516137, 3.551212952982995, 2.764066558691763, 5.243433271684955, 1.0443503025078005, 0.09950165231261524, 13.937141222338523, 60.93467174037811, 56.13975463374969, 65.50542931402883, 56.99657286367109, 58.37055167844219, 51.938437261889064, 50.51621721636865, 44.131924336956395, 44.03788551207512, 42.918205722685784, 42.58298820064914, 38.09262744842037, 40.515875585617565, 43.2606678624307, 40.854650697400494, 39.287765795184725, 41.75055534608903, 43.55349633001512, 48.016977079453014, 44.80024130113664, 45.953492656830825, 44.39855529415993, 48.70794965374855, 46.7354485296434, 47.327240051761756, 46.40101548164122, 44.657333666278475, 44.26375912081811, 43.39340086906187, 45.016630618802964, 43.709539982580374, 43.69943987938666, 44.00868346614223, 40.598472856706195, 44.1929054260254, 41.00651702573223, 41.98602699464367, 43.55031921017555, 42.741954018992764, 46.86013283268098, 44.680601166140654, 42.16928012909428, 47.66661136381088, 48.946806307761904, 49.752582734630955, 45.992041710884344, 48.34717396766909, 46.65656182073778, 44.85928866171068, 41.33630206508022, 41.98177122300671, 41.852466367906146, 41.92171973566855, 42.96714513532577, 41.418287446421964, 41.845927776828894, 39.574016447990175, 40.93798537408152, 44.30317109630954, 44.56096495351484, 42.357487217072524, 41.58743181536275, 44.242954869424146, 39.49474534680767, 42.0152525747976, 39.97970719491282, 41.28896690184071, 40.31792533013129, 42.4786727659164, 43.641953622141195, 46.74149290207894, 42.63754052500571, 43.888317692664366, 47.24282672328334, 49.719615213332645, 45.216926451652284, 45.51244174280475, 48.12765852097542, 47.579903448781664, 40.151608990084746, 40.25656377115558, 43.89033771330311, 44.64301309277935, 41.614323585264145, 40.69277448038901, 41.022496761814246, 41.28113392860659, 42.32175050243255, 42.48836886498236, 42.46371284607918, 40.365460534249586, 42.7435778802441, 43.94461154937745, 38.587085354712706, 40.86397809367026, 39.60983945477394, 42.477331315317464, 42.57988952821301, 42.944873917487364, 44.55112764912267, 41.407838252282914, 43.33150194537255, 44.60331870663551, 46.800136258525235, 52.83553823348015, 55.650909639173946, 55.14482975006104, 55.40675386305779, 56.14938405252273, 52.32099779190556, 49.51754254679526, 45.00391037233415, 43.08861701719223, 42.884685147193174, 44.4443371988112, 44.120082701406176, 48.350915908813484, 54.78741945758943, 60.51263647694742, 62.32632475514566, 65.63480869416269, 61.13048822649064, 49.09967284048758, 1.6166361229073618, 0.4226000234484673, 10.618574830793566, 9.765476968980606, 0.8456965331589023, 0.9668815304194728, 60.91971966528124, 67.75040964926443, 68.10923591736825, 69.3151137136644, 44.93478252041725, 42.930894590193226, 54.83794350777903, 62.88389359751056, 62.524961425412094, 1.8251422119717446, 0.1445604848765558, 0.13952239957307616, 0.14615315102761792, 0.10378889484150756, 0.12977984493538258, 0.2264278120691738, 0.10293906584622399, 0.09759425425962096], [0.02816022764290533, 0.0554462876771727, 0.06016831191617155, 0.05128962866541359, 0.03919196653089697, 0.04298108720010327, 0.09877521709929551, 0.02206098224456993, 0.05728743827691483, 0.041887803123362606, 0.06247228304404886, 0.059136786017446756, 17.31061589333319, 56.43496398002871, 48.24590229219007, 27.047925341513853, 26.033880864420247, 28.981759740460305, 54.8492399338753, 61.58523213478827, 58.96456326207807, 50.518849126754276, 60.84337465224728, 7.769554882280289, 1.2415170645521534, 1.059625360273546, 1.525187778376764, 0.27370587111480776, 0.4361396469175816, 41.88886596310524, 59.575672457295084, 54.39699457537744, 51.175218551389634, 48.83124543774513, 43.47294261378627, 42.58726358413697, 38.16333993788689, 37.98220880569951, 38.54099358281782, 38.159048864918375, 36.73501668437835, 37.248815797990375, 38.45858458549746, 39.26934634485553, 39.47308994108631, 40.766632710733724, 41.849046061115885, 42.63748953419347, 41.211962930617794, 43.37560899796025, 41.98103773978449, 43.622930126805464, 43.46037533975417, 42.10931493389992, 41.91121955071726, 41.20787189852807, 41.32543317733273, 39.22812223434448, 39.09639335447742, 38.3210466754052, 38.82061150766189, 37.4273620882342, 39.7879974303707, 39.489477603666245, 38.425813182707756, 39.45742399461808, 38.2861218913909, 38.27180916263212, 39.466747468517674, 37.1974798171751, 37.5308616699711, 41.37182697173088, 42.15245316105504, 42.790320765587595, 41.96369301888251, 47.098205012659875, 46.036470397826164, 42.34189971800774, 39.81098644195065, 39.09396540734076, 37.77131472864459, 38.10266479369133, 37.95427368533227, 37.68916068538543, 36.8529898120511, 37.36923648465065, 38.25536266449959, 40.89992269392937, 38.54563766910184, 42.55592776883034, 38.737841652285674, 38.87170822389665, 39.12286935314056, 37.98901804031865, 37.89358285165603, 37.57659258381013, 37.2778570267462, 36.73809966733379, 38.53002271344585, 40.448218622515284, 40.635790286525605, 41.65055451854583, 45.282622229668405, 44.95827359537925, 43.058720711738836, 40.1890480133795, 41.76537798297021, 43.15935304087978, 36.5087547609883, 35.23576521104382, 38.27433516902309, 38.17460890739195, 38.08168795800979, 38.0389537349824, 37.17737374767181, 37.36100342965896, 39.207580781752064, 36.89060926437378, 39.519177790611025, 39.9285908668272, 39.28974266975157, 38.13417319328555, 37.699154884584495, 36.47488901692052, 38.91501119059902, 39.2155392708317, 39.23120521729992, 39.93390567841069, 40.43758115460796, 40.28206702201597, 38.188949092741936, 43.69655301493984, 49.281470775604255, 52.558944456038944, 48.65619397932484, 48.52576340398481, 51.33410984469999, 50.731669087563795, 50.439428975505216, 49.625431260754986, 47.67149863704559, 41.68561266314599, 39.5649165491904, 39.14946694527903, 39.24718103101177, 40.71927401327318, 46.00071799370551, 53.13163011304794, 53.72699883676345, 53.30406142819313, 65.05281917510494, 33.05423313571561, 0.046866788573923616, 0.6235074396094968, 5.659100076844616, 6.1744509781560595, 0.4724207129930297, 2.3000187883453984, 56.2138246720837, 58.309037147029755, 57.588011372473936, 58.82309905944332, 30.703999919276086, 25.206245068580877, 39.19159712329988, 48.795940183824115, 22.606466739408432, 0.14573232360905217, 0.09659748960046038, 0.08278120113837142, 0.06687056618712603, 0.02237542494831066, 0.022154077249128493, 0.026842060371211944, 0.06317333393399754, 0.0643476547913686, 0.032414256429840485, 0.0585338709905984, 0.02823695326374183, 0.028613527613361518, 0.02244001382120675, 0.04262389487496788, 0.11701695801269625, 0.09381282894361405, 0.07836286564387622, 0.04614876117557288, 0.018192261209591262, 0.08310583089628527, 23.216465903866677, 65.16307700064876, 56.68197524163031, 30.42996156600214, 24.467853000087125, 39.47489815373575, 62.294965405617994, 65.07667503049298, 64.07630981937533, 56.307718369268606, 65.20791753645867, 8.559590347351568, 1.1552192823540781, 2.455686873966648, 1.8747804193727433, 0.7097797264014521, 0.643934837031749, 45.90678899518905, 59.36688077065253, 58.19178573546871, 53.3122827160743, 52.92079094917544, 45.85395466896796, 43.36931751620385, 39.39874141447006, 40.48930937244047, 40.858533843871086, 40.09400506173411, 39.03578096820463, 39.01966394916658, 40.66265852220597, 41.136904455000355, 40.473412006132065, 43.08649109255883, 43.77587118456441, 44.83723709660192, 43.58783668087375, 44.72027594043363, 44.07654439249347, 46.33423712945754, 45.2055045097105, 45.95884669211603, 44.26039764958043, 44.54458121330508, 44.28913685583299, 41.853894110648866, 41.21373191956551, 41.130801247012236, 40.28139237434634, 40.876058993800996, 41.269241302244126, 41.22435762036232, 40.8561372756958, 40.864754722964385, 40.72452214456374, 41.11429199095696, 42.322472218544256, 40.00009567506852, 40.60720405270977, 43.803421912654755, 43.68988106327672, 44.44121499215403, 43.34888981234643, 47.87759957774993, 48.09206301166166, 44.30037052400651, 41.95869591928298, 41.232641666166245, 40.54364204406738, 41.02941582279821, 38.70417202672651, 39.4563727994119, 38.738610436839444, 40.073404773589104, 41.63067202414236, 43.09236680307696, 41.78897103955669, 42.45728015899658, 41.50973358461934, 40.483606246209916, 39.1815911569903, 40.5743149788149, 40.40330356167209, 39.56344958274595, 40.032486607951505, 40.019330978393555, 40.37643532599173, 41.691017689243445, 41.9878508967738, 42.23299118780321, 47.69424446167485, 47.088701109732355, 44.98704418059319, 43.680569356487645, 42.7962278550671, 45.027554419732866, 38.25686885464577, 37.489566956796956, 40.02184914004418, 40.713323777721776, 39.980766234859345, 38.806675326439645, 38.347514829327984, 38.60794844165925, 38.77930502737723, 38.88151414932744, 40.30563654438142, 40.784189239625015, 40.69085251900458, 39.90161280478201, 39.84938644593762, 38.69427980915193, 40.26233750004923, 41.31567432034401, 39.66015169697423, 43.46428594281597, 41.589526361034764, 43.11956059548163, 38.46058499428534, 45.31471898478847, 51.602376430265366, 54.683327597956506, 49.63895559310914, 52.38671710414272, 53.8406495125063, 52.898476585265136, 53.002976371395974, 51.77312112623646, 48.62666245429747, 43.145330567513746, 40.56537981956236, 41.78447992570939, 40.5151185681743, 42.74730805427798, 47.033913443165446, 55.21935478333504, 56.55251349172285, 58.562994926206535, 65.63957045155188, 38.04149150848389, 0.010795138378237045, 2.4673296943787606, 8.927914634827646, 2.3010417915159658, 0.370997995618851, 2.212830137821936, 61.51571596822431, 62.88859651934717, 63.765477672699966, 64.4627691853431, 37.151529250606416, 28.378742394908784, 44.62917497081142, 56.18715647728213, 31.851869783093854, 0.13952266004297043, 0.1097309179303627, 0.036344896521299117, 0.05471426002200573, 0.036840789065125494, 0.03187391163420773, 0.03332625729061904, 0.012847214050951504, 0.06111619250488378, 0.1283844694074604, 0.12993035056898672, 0.14775030645391635, 0.11536835212140314, 0.15184271750190567, 0.17992123420680725, 0.246480377991834, 0.16956131995445298, 0.1404152137617911, 0.20066375423583294, 0.21492118676823957, 0.2123684898739861, 26.445972919464115, 73.4492212726224, 62.33499711559665, 37.81925393689064, 37.17667556578113, 40.13581360540083, 65.63063921466951, 72.83776298646005, 69.30111869688957, 60.65697969928865, 70.74018924467026, 10.238382431768603, 2.4289787200189408, 4.680981568751797, 6.00647694641544, 0.650907708031516, 0.9309648157608126, 49.08028848709599, 61.573492480862534, 61.88119849851055, 54.56547214138893, 55.108598816779356, 47.73387216752576, 46.90762881309756, 43.04063466287429, 42.089726617259366, 41.718384065935695, 42.26181668619956, 41.1576694826926, 42.98539200136739, 43.75008160068143, 44.42574124182425, 42.398562277517016, 44.59022191263015, 45.35378186933456, 46.226693584072976, 45.33950444190733, 47.740959890427135, 45.805521242080204, 50.228895756506155, 48.686635494232185, 48.86933557448849, 47.76521582757273, 44.34885101933634, 45.59843186409243, 44.11815681765157, 42.9214769794095, 42.56649463407455, 43.34814848438386, 41.94324570317423, 43.337248217675, 43.509663843339496, 43.679408334916644, 43.84778391930365, 43.21233249479725, 41.94865857401202, 43.02965987113215, 41.54116745918028, 42.968353225338845, 45.16611999081027, 46.61222334830992, 47.65953540802003, 45.17931484406994, 51.19832915644492, 51.02382682984876, 46.42398880374047, 42.65437141541512, 42.337557654226984, 41.05868062665386, 42.79455300300352, 41.85631813541536, 41.57204827954693, 40.18738885079661, 41.449199645749985, 44.502462802394746, 45.19632224113711, 43.45385636052778, 45.40809100674045, 43.350246952426055, 43.33559689983245, 42.947901987260394, 42.67419899663618, 42.996700194574174, 42.75636480700585, 41.690288128391394, 41.92962331156577, 42.0534368484251, 43.40976891979095, 43.84523437869164, 43.970577639918176, 50.14358028288811, 49.32397357879147, 45.91550450171194, 46.9295980084327, 46.95253995157058, 48.097664156267726, 40.15734349527667, 41.55729624532884, 40.68216839144307, 42.18826832309846, 41.701266842503706, 42.320565946640514, 40.52156694473759, 40.390026338638805, 40.96345724598054, 41.078782773786976, 43.24278969918528, 43.677125515476355, 44.44268195859848, 42.936844825744636, 42.510561635417325, 42.51666876577562, 43.72263285421556, 43.78081337098153, 42.53106778667819, 46.40937013010825, 45.65573376993979, 45.622425002436486, 41.58469792335264, 47.20661147948235, 53.49444935398718, 56.14570094693092, 54.19893057115617, 54.69967211446455, 55.59677700842581, 55.60841468072707, 54.1955965565097, 54.30613679270591, 51.096465203069876, 46.72101028503911, 42.71399144203433, 43.80456724474507, 42.64763670582926, 46.070979410602206, 49.75006457298033, 57.256390663885306, 58.381683364991225, 61.27794973311886, 67.83787850410708, 39.93978923366916, 0.26969276548873994, 2.0339464011692234, 12.045633119921531, 14.653268937141666, 1.2434027440124944, 3.2146507934216535, 67.9063787767964, 67.81619564179452, 68.6455023673273, 69.38989762336978, 41.64734994211505, 34.95912436516055, 52.50575319413216, 64.26312838831257, 39.82110223462505, 0.24765877443696224, 0.16380508850899436, 0.18700558632131548, 0.2777590584610739, 0.1088886732055295, 0.10893962571337339, 0.09358017570188931, 0.1836084766734031, 0.19485840123266945], [0.05143641111170573, 0.019916926225226735, 0.06183852148692935, 0.078037561728589, 0.0470605590230515, 0.047191602192939296, 0.049743475542674144, 0.11658083181828262, 0.049260652458836, 0.1228703753722291, 0.09506837044271732, 0.03905821907063646, 12.717767530871978, 55.276397812751036, 49.489564280356134, 34.22933993800994, 74.71263239460608, 49.14723942356725, 45.4503623900875, 61.7812055157077, 60.072648525238044, 50.92467715663295, 61.92695686894079, 19.590181727563184, 1.4934268762027065, 0.5131263351969181, 1.0804671193322828, 2.9363238186605516, 0.022496076135505593, 32.836555319447676, 60.80810862202799, 53.70010314449188, 51.00019062719038, 44.19673365931357, 39.76548302558161, 40.62359956003005, 39.782462966057565, 39.31807394950621, 42.41949988949684, 38.23731976170694, 37.46946873203401, 38.25464879312823, 36.288239109900694, 43.22767680691135, 43.92130874818371, 44.917802579941295, 43.3436809047576, 44.46016396245649, 44.4270944595337, 44.16959478009132, 43.818307307458696, 43.63907852480489, 44.3971275514172, 43.63605437740203, 42.91141609991751, 43.964266546310924, 42.452961629436864, 41.46016659275178, 41.305060386657715, 40.443496088827814, 38.31539061761672, 37.47151620926396, 37.99931818439115, 39.27945037041941, 37.70542675449003, 37.360599425531205, 38.80588300766484, 40.34226363705051, 40.07674663297592, 36.22628919539913, 36.64912462234497, 41.70122761880198, 43.22640988134569, 40.327484146241225, 41.21474389106997, 44.29003507860246, 44.49440625406081, 40.831077252664876, 41.07895535807456, 39.472234864388746, 37.2125260291561, 37.86803253235356, 37.25520926137125, 38.25903400298088, 35.27176864685551, 40.709813256417554, 38.84611475852228, 41.65979954504198, 39.135495462725245, 44.14359731058921, 44.76224530127741, 37.61865215916788, 38.11797380447388, 36.99332437207622, 39.62628595290646, 37.5264843048588, 38.47595284062047, 36.27566006875808, 40.39695716673329, 40.35008876554428, 40.15030676318754, 42.000637823535556, 43.014637193372174, 44.56844883580362, 44.10165932870681, 38.940545820420795, 40.47871112823486, 42.47862177510416, 36.604437058971776, 35.863269913581114, 38.725395971728915, 39.83233982516874, 36.66313140623031, 36.84737690033452, 37.24299500065465, 37.91067654086698, 37.538510291807114, 38.55534161290815, 40.29625815729941, 39.62356382800687, 38.0344194750632, 37.94156912834414, 37.75011431786322, 38.16649352350543, 37.554980324160674, 40.96813663359612, 42.12746374068722, 40.53678574100618, 41.352356326195505, 38.431484929976925, 43.616493517352694, 50.15623777143417, 53.76988210985738, 49.011556794566495, 47.625650052101385, 53.39351892471314, 51.2323792519108, 51.369058162935325, 54.83109504945817, 53.26218228186331, 51.06096775301042, 49.15285233528384, 40.711829354686124, 39.76227844915083, 40.51763280745476, 39.592898737999704, 42.31490204411168, 47.38936255055089, 54.830643976888354, 55.97545046960154, 63.88597288439351, 29.798532532107448, 0.14099872761195706, 2.6290200891033297, 8.165138171565149, 3.3559029429189624, 0.5097997362815565, 6.888752829643988, 64.24868622133809, 53.05206483410251, 58.668989135373025, 51.16965270811512, 38.04014613551479, 28.260835947528964, 36.85893612523233, 51.43083157077913, 13.122387470737582, 0.09301546931026444, 0.12440236735968821, 0.07222906776493596, 0.05733426923172609, 0.07707768420298254, 0.03988209683748503, 0.06935542599568445, 0.04002713643374943, 0.037530678054017406, 0.05663372012936781, 0.02262149047436974, 0.03122624941170216, 0.013434563128788386, 0.03313583847615988, 0.07017392965574419, 0.09432397046757322, 0.03930599871842612, 0.04455060600453327, 0.04801975856084497, 0.061102077334878914, 0.05139734445800705, 16.398216697477526, 63.264006568539536, 53.26868557160901, 35.98423580969534, 55.59620826475082, 40.079190269593276, 52.895605410299, 69.12480031290363, 64.26552887885802, 56.62756412259994, 66.16406979099398, 20.056498589054232, 1.065798435480364, 1.2588671787131218, 4.227638436901954, 3.11102373465415, 0.020015167425416654, 35.685037412951075, 62.33201611426569, 56.25635493186213, 53.446608204995435, 46.75575071765531, 42.24585656196841, 43.19130074593329, 41.134747151405584, 42.593300111832164, 42.0661884738553, 41.34856731660905, 40.083151863467315, 39.50779507237096, 39.928869355109434, 44.911409116560414, 46.44088637444281, 46.89283363280758, 44.96129382041193, 46.2840151017712, 44.74404158130769, 46.14692434187859, 46.30345044597503, 44.82672906691029, 46.18366518328267, 46.98160863691761, 44.27647936728693, 46.359155947162265, 44.867443269298924, 45.55348934665803, 43.3344986361842, 41.30715885469991, 40.93769511868877, 39.93902437148556, 38.55651440158967, 40.406912142230624, 40.17240539673836, 40.20972674892795, 41.80084797643846, 40.830634024835405, 42.74755516359883, 39.479028409527196, 39.33056669850504, 43.420633885168264, 44.10076895067769, 43.99049935802337, 42.47152620746244, 47.11172542264385, 45.04965697565387, 43.95282499251827, 43.15550519574074, 40.77359491778959, 41.38538660541658, 38.77220945973551, 38.20572114759876, 38.78611426199637, 38.104139604876124, 41.43804050260975, 42.10818921366046, 42.03612350648449, 40.546521063773866, 46.979804346638346, 43.67838067393149, 39.86684099320443, 40.58204204805436, 39.683281913880386, 41.97830777014456, 40.07572681673112, 40.93316870350992, 39.05574583238171, 40.28131000457272, 41.16454931997484, 42.154959555595156, 41.10662375727008, 45.181444691073516, 46.29432701295423, 45.53825093853859, 40.615037025943884, 43.236415847655266, 44.37827664036905, 40.376156837709495, 37.218829278023016, 39.315524408894206, 41.348222148033884, 38.65828029571041, 39.3786588791878, 38.486162770179014, 39.668094496573175, 40.55222419000442, 42.03628824603173, 42.823107857857984, 41.518154913379306, 40.37161865542012, 39.037000825328214, 40.533863575227805, 40.539982472696614, 39.447441562529534, 44.11196339514948, 44.14112621738065, 44.21555711377052, 42.45486790134061, 38.96688845849807, 45.835899999064786, 51.13696367509904, 54.302288947566865, 52.31463178511589, 50.892478419888405, 55.31005174882951, 53.037061768193404, 54.270050987120605, 55.67024300175329, 56.80578877848964, 52.883861834003085, 49.80209873568628, 42.70180856027911, 42.27819650403915, 42.57051898587135, 41.719152850489465, 44.94205067234655, 51.426018822577696, 56.74339171378844, 59.17941108826668, 64.6579384803772, 34.28349610297911, 0.08949747864877985, 4.188747156050898, 9.88772253836355, 3.2450690192561, 0.6131781229088383, 7.450819650003988, 69.9487098570793, 59.047207601608775, 64.09565887143536, 57.60596013838246, 40.417141683640025, 26.70306467240857, 41.45917423309819, 57.58269656089045, 18.431935233454553, 0.09164661574628084, 0.09653159837809303, 0.03172318383510555, 0.03412403061144775, 0.013828981581384377, 0.0775136725015698, 0.08774791769082509, 0.07192072503629231, 0.05170914607362882, 0.10498410691657376, 0.1259619538341799, 0.181060744028899, 0.14668875373899937, 0.20404342772258868, 0.18737056593020118, 0.1362450907547628, 0.2638727648844642, 0.19008411064503655, 0.2498105928421982, 0.19126869708059296, 0.13410078001118478, 20.91174787090671, 72.30412452451645, 63.2066575942501, 49.842577595864576, 79.92473279276203, 58.22625552454303, 59.07196167976626, 71.85273032034598, 70.14026272681453, 59.22468308479556, 72.13180695810627, 23.600354156186505, 2.8793026074286434, 3.390752221307447, 6.941501844313837, 6.658193949730166, 0.14891449962892842, 39.550662655984205, 63.414888381958015, 59.11291122436524, 56.381353024513494, 49.55075717741444, 43.473797690483835, 47.736912004409305, 42.04967529542985, 45.72637173437303, 45.511037534283055, 44.04275317345896, 40.242341256910755, 41.532028336678785, 42.518100430888516, 49.20359211583292, 49.50998021710304, 49.8098022707047, 47.182053519833474, 49.195096262039684, 49.38555479049683, 49.34766077226209, 51.35553383058118, 48.77323358289657, 49.2143629443261, 48.76107423536239, 46.78357601165772, 48.70349776360297, 47.00907699523434, 45.74947449468797, 46.074313425248675, 44.6866023925043, 42.05215423337875, 41.60591010124453, 40.51753867057062, 43.98696922486828, 40.410834512402936, 42.71714110528269, 43.73036776819537, 44.752733553609545, 44.909373406440984, 41.471141384493926, 41.95518147560858, 46.41618328709757, 47.399729374916326, 46.20070395931121, 43.900335834872344, 48.495557231287805, 47.47053600126698, 45.50631892296576, 45.566460624817886, 43.26688089678365, 42.79574932590608, 39.98763822740124, 41.41759710927164, 41.41387085760794, 39.523296279291955, 45.76964332211403, 44.66276222659696, 45.57505061549526, 43.35303575761857, 49.228397184802645, 47.57520444931523, 41.58455671802644, 41.87459638041835, 42.20210644506639, 43.954264502371515, 41.974252039386386, 43.26604150956677, 39.42300127398583, 43.368470284246634, 42.741255837102095, 42.222385098857266, 43.32742268039335, 47.27198170077416, 50.83955780152352, 48.739195254541215, 43.40272434296147, 47.377587595293605, 47.47027320246543, 41.587153327080514, 40.59411510344475, 42.0543154593437, 43.28050721076227, 40.299960874742084, 40.882460301922215, 41.35428613232028, 42.08974230674006, 42.147420760123964, 43.54805992495629, 43.97965792686709, 43.405124833506925, 42.42348109522174, 41.827331819841945, 43.17775287935811, 42.916491646920484, 41.633111738389545, 45.76395196299399, 47.176236644867934, 46.05615285135085, 46.04876702831638, 41.82287208495602, 48.842718370499156, 55.22750939092329, 56.89146903253371, 56.43327736085462, 52.38274374315816, 55.42768363029727, 54.854676338934134, 54.7997356999305, 60.25313638871717, 58.445939633154104, 54.76397152869932, 53.62200483199089, 44.04236485881191, 44.082184760801255, 45.48135695918914, 43.59635214651785, 46.649893791444846, 52.841127610975704, 60.339004916529504, 61.52616516236336, 67.7899863643031, 37.10949713183988, 0.19589638908303555, 8.402727900012847, 17.662862385472945, 9.224521325480554, 1.2940150475309742, 8.658358570068113, 77.03232211451378, 64.29880234502977, 68.15271931309854, 62.83526797448436, 51.174587049791896, 37.54070289673344, 48.78088220473259, 68.30193411919379, 25.564165269174886, 0.1791081544492514, 0.31380073738194286, 0.2174788172687254, 0.241228171113518, 0.18967019333954782, 0.19849489803516096, 0.15375081269491106, 0.19875446394566568, 0.16435319377530008], [0.06213934889303581, 0.06523347459733486, 0.0339901682379986, 0.13476765954927092, 0.04919189989807145, 0.057101945407808795, 0.011445521170483723, 0.026574318387335347, 0.05585969553419179, 0.019801488266356533, 0.09908365175849008, 0.16008563970606174, 9.896004622982396, 61.98058743630687, 45.819590783888295, 49.25550860743369, 84.83131193345594, 74.00460535480131, 36.29958260443903, 46.787588596344, 57.42005940406554, 52.54460034831878, 57.585336316016416, 32.973255803508145, 0.2268296251854589, 2.0110199023639006, 1.563090499370329, 1.8081251315532194, 0.3756951258307503, 35.595011172756074, 62.50546332328551, 52.098215010858354, 49.6603835013605, 42.157689525235085, 41.08767086459745, 39.015820026397705, 42.39641674103276, 44.668512421269575, 44.28198637500886, 41.219250694397964, 38.37668941866967, 37.53225803375244, 46.21805652495354, 47.77598273369574, 47.11458483049947, 44.836672275297104, 45.34858080648607, 45.09292464102469, 44.91860274345645, 44.97106836688134, 45.78831380413425, 44.62022412207819, 46.55122264739006, 47.003071846500525, 44.733729670124674, 44.38425041014149, 44.53062542023198, 42.98155200096869, 41.781479312527566, 38.40505207738569, 39.56942335251839, 39.80397716645272, 38.33715977207307, 38.79135062617641, 36.2651010482542, 37.07104221467049, 38.07221543404364, 39.747644086037916, 41.56879663467407, 37.71241249576692, 36.468389649544996, 42.171735532822154, 41.6310917177508, 41.18571835179483, 43.24426843274025, 44.221879974488296, 43.83406346844089, 40.66751833884947, 38.35981930455854, 39.30789147653888, 37.931025797320956, 37.59421187062418, 35.9700172178207, 38.01164227147257, 36.569351457780414, 39.384577735777825, 41.91897799891811, 42.66030988385601, 42.421221810002486, 40.63349962234497, 47.01943597485943, 39.20378392742526, 38.37375940815095, 36.984906965686434, 38.877383893535985, 37.01755677500079, 38.72364267226189, 39.637394105234456, 38.97410561961513, 40.79621914894351, 40.483249310524236, 42.28607262334516, 42.97364058033113, 45.05430890667824, 42.56350578800325, 40.91527485078381, 37.34429805509506, 42.235081811105054, 39.316595215951246, 34.38623474490258, 35.57410493973763, 40.03741310488793, 39.9566162017084, 38.56891301370437, 38.4525990486145, 38.72452912792083, 39.14918453462663, 38.69697447746031, 37.89470464952531, 37.90602068747244, 37.097329939565356, 34.826399203269716, 35.05284940042804, 36.73513435548352, 38.19745671364569, 41.845213905457534, 41.95085117893834, 42.508047396136874, 42.14537328289401, 47.17222013781148, 49.36516631034113, 50.72679750380978, 51.191790565367675, 47.24271297454835, 51.25286971369098, 53.15994178095172, 51.0449880169284, 51.646573697367025, 52.24956358632734, 54.86640030337919, 51.36727740687709, 52.219710426945845, 46.74386201366302, 41.787790406134825, 38.63152188639487, 41.56355634812386, 40.144140797276656, 49.67422946806877, 53.964498350697184, 58.77701513228878, 60.20804874358639, 37.392421614739206, 0.030284208328192754, 4.23541110369467, 7.120340351135501, 1.8153290546709493, 0.4796389159896682, 18.15072678750561, 65.82672242195376, 53.85404048427459, 61.00257189043107, 46.85335497702322, 33.303809627409905, 25.62716441769754, 45.03582277605611, 50.84971674026982, 9.012008290137015, 0.26431758617681844, 0.0592118204991904, 0.05218389076030543, 0.11225183749751699, 0.07676810041190156, 0.03003675809821054, 0.02867700182832778, 0.01874855595580753, 0.01496911480752451, 0.031156922284994396, 0.017685377219271277, 0.022816019350542657, 0.07541156554174039, 0.04078663983232072, 0.06546432753243754, 0.03282209865808968, 0.04508338951235337, 0.04238510909940928, 0.028856364078819755, 0.016397001191733346, 0.07329531659882876, 12.342651659442533, 70.71215214267855, 52.51550420638054, 54.374260517858694, 78.89438890641736, 69.05793959094633, 41.831838623169936, 53.77476153835174, 63.39305254720873, 56.89508153546242, 63.58663720469322, 33.665522759960545, 0.2919628801605394, 0.9938905424168034, 2.7609821048475083, 4.479048146355537, 0.25617940351366997, 37.73205572558988, 62.2974443435669, 54.29377740429294, 52.16165934839557, 44.0462480052825, 43.48945579221172, 41.858318544203236, 45.038913603751894, 46.86955044346471, 45.84372512755856, 44.36742344210225, 40.61436630064442, 39.36041201314619, 47.34846791913433, 48.57256904725106, 48.45308972943214, 47.59861315450361, 47.36209031074278, 46.38610263024607, 46.241724106573294, 47.528665527220696, 46.526743135144635, 48.1021866490764, 46.86731861483666, 47.29504915975755, 46.067594405143495, 45.500513815110736, 46.643692524202415, 47.0347410632718, 42.82142516105406, 41.17066429507348, 41.68437711654171, 41.91051744645642, 39.74003861027379, 42.77191308236892, 38.82979377623528, 38.052368240971724, 39.39818051553542, 40.97515375383439, 42.20374207342825, 39.92980287921044, 39.74618888670398, 44.74038593230709, 44.481799756326986, 42.800126691018384, 45.02451458284932, 45.85938715165662, 45.074744455276, 42.40447721173687, 40.59897884245842, 39.85646240172848, 39.87261472209808, 39.51148210033294, 39.36466386241298, 39.77539877737723, 39.69635517366471, 40.0047319166122, 42.949792569683446, 44.787517132297644, 42.72791585614605, 44.570064852314616, 45.44483969288488, 39.86456601850448, 40.20334113028742, 38.456117414659076, 40.17508045319588, 41.38366076254076, 41.708958610411614, 40.35113996075046, 40.40177775967506, 40.79612893442954, 41.44948990114274, 43.29338827440816, 45.24976061236474, 47.560683834937315, 43.50888721404537, 42.26004769725185, 41.01313406421293, 44.086264025780466, 41.53834727502639, 37.27523296110092, 39.39499162858532, 41.734606988968395, 40.97340829910771, 39.02126819856706, 40.04658360635081, 39.90807687082599, 41.48767809714041, 40.10649388836276, 40.822844197673184, 40.42218192931145, 39.055734065271196, 37.427632731776086, 38.230467381015906, 39.48267229141728, 39.19455851277998, 43.82652859533987, 44.28067238100114, 44.82727819873441, 44.235769087268466, 49.30576593645158, 51.04317195953862, 53.714972849815126, 54.8264431184338, 50.979672708818995, 54.125197856656975, 54.196690897787775, 53.155246703855454, 54.194604196856105, 54.673556973857266, 57.679473200152, 56.74295240832914, 52.77263910539689, 50.41853843196746, 44.47934827496929, 41.20534196976693, 43.211669614238126, 40.676386817809075, 51.8031664817564, 56.6059204839891, 61.32748534602504, 62.689571534433675, 38.875650205919825, 0.142484585784616, 4.269351863091992, 8.18789674389747, 2.2905742112667333, 0.5338983802545456, 19.250249516579416, 70.23976541334584, 59.235081288122366, 65.74593728588474, 55.15715383714246, 34.863897062117054, 26.766073626856652, 48.57480872061945, 57.59210240456366, 11.7899691097198, 0.2763070460529097, 0.11632370206737712, 0.02611609821718547, 0.08806942947088711, 0.03821461837017729, 0.022501593883780223, 0.07203729297485083, 0.02464931180340148, 0.017984492418866967, 0.15435513349310045, 0.22314671877651449, 0.14155481551443377, 0.221485227286335, 0.1489368693963174, 0.25547869353284763, 0.1857515463545438, 0.12984931378835632, 0.22912660193058754, 0.20710089995015055, 0.26325201916117824, 0.34154237458302134, 13.764291194177444, 79.07927374685966, 59.8916115299348, 62.27988781467561, 86.10663921602311, 74.95073595354634, 49.44395103762227, 58.35195179908507, 66.74604754294118, 62.19431346462619, 66.92296997193368, 39.747522492562574, 0.5602806710427808, 5.856653192350942, 6.113591482562404, 5.637480462751081, 0.7087753544892035, 41.91111756909279, 64.39661449001682, 57.012399627316384, 54.91456308672505, 45.20930528640748, 45.49277105639058, 43.00088144117787, 46.18781505092498, 48.79992923428936, 49.44293122137747, 46.9205020320031, 41.810520541283395, 40.75737199475689, 51.096661321578495, 52.2597852829964, 50.91622837128178, 49.98239832539713, 49.72807184342415, 48.99266665981662, 49.84870826044391, 49.08475606672226, 49.41427046252836, 50.21380247608308, 50.56310915177869, 50.910250679139175, 48.19197362469089, 48.1716832037895, 48.87099473707138, 49.58373646582327, 45.04478931427003, 42.471000609859345, 45.00935462213332, 44.38168518004879, 41.14247029827487, 44.627649168814386, 40.5556405744245, 39.92476263353902, 40.44102891798943, 43.04518461227418, 45.47681877689977, 41.57409967914705, 40.195555225495376, 46.254075650245916, 47.00211871054865, 46.08846533683039, 47.95519190449869, 48.03424335295155, 46.76130087144914, 45.09681170986545, 42.54015199599728, 41.95010592860561, 41.20076848614601, 41.710025495098485, 40.629620398244555, 41.85293705232682, 41.90541052049206, 43.601674802841686, 45.90285485790622, 47.17924902516027, 46.47149655126756, 46.91935669991278, 47.75129141346101, 42.17976854693505, 43.73053643011278, 40.91403538180936, 44.524479066171956, 44.340261028658965, 43.921136163896136, 45.121275532630186, 42.534127235412605, 44.80597188395839, 44.13790595146918, 44.8403004677065, 47.45021812377438, 48.781572541882916, 45.43670077477732, 45.716632489235174, 43.44798849474999, 47.10585755686606, 43.67353262439851, 39.71695153943954, 41.60345861988683, 44.54354178520941, 43.02399204623315, 42.7551684841033, 41.410513308740434, 42.05433114882439, 43.65507002799742, 42.55371162968297, 41.79547825167256, 42.802656619779526, 41.23113939839025, 39.74320004063268, 40.15712776491719, 42.5137387552569, 41.64856195449829, 45.90530633926392, 46.968649125868275, 46.081856143090036, 45.37872029889015, 52.718863410334436, 55.96809994789862, 55.981463463075706, 57.11760544007825, 53.234360910231075, 53.820857232616795, 56.80942873800955, 55.540934224282545, 55.9693354945029, 57.631851703889915, 60.58835391075381, 56.87124529192525, 56.168019233211396, 51.505784142401914, 46.6567853958376, 42.57972871103595, 45.643943125201815, 44.414680157938314, 55.13242721557618, 57.507104642929576, 63.143899671493045, 62.08156885639314, 44.29720517127745, 0.2445869303999409, 8.47880325009746, 18.593801644540605, 8.028603897940728, 0.785220142814421, 22.210617219248128, 77.78245972048852, 63.55858049085064, 68.98830967564737, 60.51992424072758, 46.9247813378611, 34.68466435709308, 56.917035041316865, 67.13014171969506, 15.048342808600395, 0.5414539070860033, 0.2539410631382658, 0.1827125368459571, 0.2324333285251933, 0.13029840985132804, 0.16109727413183259, 0.11588671785448829, 0.1181206762069656, 0.13384709765593852], [0.03547041864705182, 0.11869559455062113, 0.044657069243370526, 0.0477553854486154, 0.03114914840778276, 0.04766121409052322, 0.013796165247537918, 0.027285975764595696, 0.05786715233097634, 0.09549300531826674, 0.20168372369821996, 0.15865254966962725, 2.244547893924098, 45.886173017563365, 46.880807645859264, 36.172929271574944, 70.1249497936618, 75.10479096443423, 46.091979780504786, 50.44560278615644, 59.4287718496015, 54.38441161186465, 55.77050662809803, 42.92249287328413, 0.28559990707905064, 0.8087715242178211, 2.437010753539301, 3.682914621406986, 0.03722240810372657, 35.68299778046147, 62.15667440045265, 53.75028594847649, 49.32917071926979, 40.35951422106835, 44.62237750330279, 47.235927274150235, 50.35987154130013, 50.27395202267555, 46.52088703647737, 42.058441792764974, 36.223504312576786, 42.8123095727736, 51.63110386940741, 51.30686506148308, 49.31407351647654, 48.03044649862474, 49.94379435816119, 50.06500736359627, 49.50208448594617, 48.329809634916245, 47.73855939988167, 47.759395030237016, 48.71125621180381, 48.62103777547037, 47.6197390402517, 48.72970311872421, 47.51083835478752, 45.20533192542292, 43.40406187119023, 40.56239489586123, 37.45937255121047, 36.8495459710398, 39.36420494510282, 37.155059383761504, 39.63914740470148, 37.6936282650117, 37.746897974321925, 39.68525094370688, 40.47006622437508, 37.494171819379254, 38.98302901175715, 40.48906618548978, 42.58529063194029, 40.49162357084213, 42.27720022201538, 43.09136267631285, 41.488846963451756, 40.54639162555818, 40.58163804392661, 37.620032833468535, 40.11851595294091, 38.25975964146276, 37.062785625457764, 37.61699299658499, 37.35513556388117, 40.32555434011644, 42.7373452340403, 43.15383034367716, 46.454610747675744, 40.16445867476925, 49.04454392771567, 46.61716161235687, 39.03898946700558, 38.17115329927014, 39.80179632863691, 38.543676484015684, 37.95187711715698, 38.475509612791, 39.09501268017677, 38.28900875583772, 41.09441341892366, 43.582443421886815, 42.658799771339666, 45.39235053523895, 43.486972931892645, 41.57261702322191, 40.15189140073715, 44.93290370510471, 41.6060552289409, 34.95176207634711, 38.07738511793075, 38.81792076172368, 39.4855591558641, 38.52974422516362, 34.74897946080854, 37.74649789256435, 38.23762570658038, 37.670827527200025, 37.81804192450739, 38.26116384998445, 37.84547890386274, 35.3329772333945, 34.60382430784164, 36.92800514159664, 38.20927481497488, 42.942038043852776, 43.844900977227, 47.97561960835611, 48.132522259989095, 49.70215282132549, 50.89156058526809, 52.38319873809815, 48.236331708969615, 48.85956495038925, 50.754077588358236, 53.00247823038409, 51.41090593030376, 52.96185424250942, 52.417586157398844, 53.390773265592514, 52.91478187807145, 56.8657265170928, 53.23321165577058, 48.04688515201692, 38.01946739996634, 39.23486871104087, 42.05411149609474, 50.29407378165953, 54.80428564933039, 61.12651486550609, 57.57427915450066, 32.81861047590933, 0.14366431522273249, 1.4668613984700174, 5.323791849997736, 2.0034922611328865, 0.14323552048975421, 27.646802625348492, 64.28750199656334, 50.243353612961315, 60.02439552737821, 39.61429526728969, 31.90482178042012, 27.767340983113936, 43.70673548790717, 43.66217736274966, 2.6548155565415663, 0.11886119977721285, 0.03802289720624685, 0.052558461790003126, 0.01243368074703481, 0.05732968036505965, 0.024457699807000258, 0.09516823766452652, 0.061089444545007525, 0.026968284848056016, 0.051775462474794164, 0.05451988436341767, 0.06460889077354824, 0.0087746542563001, 0.03520457081556801, 0.05218655291584231, 0.041409798732568184, 0.015931642039739076, 0.029711214780446984, 0.09468199399810645, 0.12647879505229573, 0.12600453300101142, 3.9496281935322672, 58.49092921903057, 50.726228760134795, 47.41628569941367, 80.4171157652332, 76.17919091255435, 50.05807261313162, 52.695807718461566, 63.65352538324172, 58.633346557617195, 61.14330653221377, 45.85158555738388, 0.41725438448690605, 0.5248482465263337, 4.81504523946393, 4.856980279568703, 0.13131514642267458, 37.96839029558244, 63.696773436761674, 55.623755070471, 52.17688991177467, 42.21902362761959, 46.398481630509906, 48.62182224950483, 53.06096861439367, 51.75281501585438, 48.51783629386656, 45.479988051999, 38.63764470623386, 44.054994890766764, 53.43416644680885, 53.350161044828354, 52.245331348911414, 49.6189122815286, 52.070095539093025, 51.55484122614707, 50.21260615318052, 51.017609873125636, 49.406253137896144, 50.64525927266767, 51.57020122774186, 49.96585769038047, 49.48607337090277, 49.66297226567423, 48.87683906862813, 46.9719752957744, 44.26987017354658, 42.44963153716057, 40.52146496311311, 39.40310309010167, 40.45431006339289, 39.44854767091813, 41.37559636946648, 38.03777702393071, 40.40167577805058, 41.07240499988679, 42.04771018797352, 39.212585726091945, 39.79795240586804, 43.74431179415795, 44.74146458410448, 42.69428937665878, 45.05002567845006, 44.93462562561036, 43.7984993380885, 43.63137106741629, 42.17288478728264, 39.27891692807598, 40.10709401099913, 40.105870231505364, 38.18147305519351, 39.18897698002477, 40.20202321390952, 41.873133336344075, 44.4213834885628, 44.46353327843451, 46.64703046121905, 42.487243144742905, 49.0728202942879, 47.145928490546446, 41.97160836189024, 39.337454380527625, 41.22387124646095, 39.79111571465769, 41.5098669452052, 40.41415675993889, 40.72558902925061, 40.8365568037956, 43.77578097005045, 43.6535716825916, 43.9505696296692, 46.38006218018071, 45.720033184174575, 43.74417058883175, 43.15554049707229, 47.55214875744235, 41.287037095715924, 37.54215025132702, 40.846751043873454, 39.379353138708304, 40.1753197177764, 39.3239692718752, 38.77894809169155, 38.25566076463269, 39.756092871389086, 39.20536856497488, 40.30671519617881, 40.232194085274976, 38.80586339581398, 36.33522518219487, 37.77730026552754, 39.77587338416807, 41.05919053477626, 44.29345146302254, 47.3068594163464, 50.153464655722345, 51.019218044896284, 53.25722048359533, 52.29746749324184, 55.91930174058484, 52.21721972188642, 52.178086234677224, 53.79219255139751, 55.318273036710686, 52.19448174199751, 55.83726536843085, 54.58084391009424, 56.08274298329508, 57.25301350316694, 57.281372239512784, 54.8612266971219, 49.93657327467396, 41.28650365337249, 42.4027435241207, 44.67223082819293, 53.075100914124526, 57.27406486388176, 63.57492892972885, 58.648643801289225, 35.150104568850615, 0.37395365476127596, 4.144780818493136, 8.981723670036562, 3.1274133584191723, 0.37856247035726426, 32.4989333844954, 70.03728482031053, 57.565242013623646, 65.45686252655523, 46.89119800444573, 40.581645888666955, 29.050193332856704, 49.3097863658782, 51.43360860886113, 3.4243137365387333, 0.12155282671653456, 0.025618257894811612, 0.04587102748994385, 0.04556523966452768, 0.017584244037167202, 0.019938242621719837, 0.14017504519752919, 0.02376892164559855, 0.03340129943324193, 0.194533059012986, 0.1925076604370148, 0.24467519905057647, 0.10477321823277783, 0.16716052297382586, 0.24886487262143245, 0.12254736205983548, 0.1802643343445755, 0.13651741969008602, 0.31579694800799896, 0.27272733168736585, 0.2613872079358947, 4.470887164915762, 64.03901592377694, 59.27082192513251, 52.01578640168714, 75.48567664238715, 79.19846673165598, 58.13456619939497, 63.0378270149231, 68.04065719727548, 64.03052399235388, 64.91195509510656, 51.88304947268579, 0.6508414567478242, 2.0376336742793364, 10.232418467921596, 9.166626161144627, 0.4653064528059575, 41.50274784334245, 64.06786495639433, 59.50221430870795, 54.11522719167895, 44.73734609542355, 49.98325340209469, 52.69325817784956, 55.0047383769866, 54.83206387489073, 50.48222595645536, 47.45557215905959, 41.54918086144232, 46.40191370441068, 56.67677417878182, 56.41030403875536, 53.40203439035724, 53.2834219163464, 54.27722500216577, 54.3555155108052, 52.27145825662921, 53.42221106252363, 51.460017927231334, 52.83411049073743, 52.43084376858127, 53.51215101057484, 51.47995533481721, 53.13046516910676, 51.60497303931944, 50.12241909580846, 47.9516617713436, 45.40694567465013, 41.95574237454323, 40.814360110990464, 43.528883457183845, 41.199356432883974, 44.29261207580567, 41.534738694467855, 42.9658664426496, 43.82746211944088, 44.78097854122039, 40.04176301340903, 43.01817124889743, 44.47959930666032, 47.39512451233403, 44.37091042918544, 46.02164383857481, 46.9375604198825, 44.96811874451176, 43.89890416975945, 43.872220285477184, 41.70076870149182, 42.929164824947236, 41.928513280807, 40.99234157992948, 40.69862273431594, 41.732696794694476, 45.51663867888912, 47.89354793487057, 47.57911505237703, 48.4959690801559, 46.251047580472886, 51.65720724290418, 47.56746953533542, 45.25331035737069, 41.148938286689024, 42.959539659561656, 40.69534363285188, 44.21267417169387, 41.612201583000925, 42.45014929002331, 42.838667900331565, 45.53762335931101, 45.20732448947045, 47.2430306865323, 47.2905933472418, 49.57176146968719, 45.047876219595636, 47.01578817059917, 49.04164137378816, 43.5672285479884, 38.797187112992816, 41.74786852252099, 42.685828824197095, 43.09434367764381, 40.95930737833823, 38.92191456210229, 41.2273346993231, 43.29829123712356, 41.9655639894547, 41.46822706345589, 43.30877181022398, 41.05369529416485, 38.80591830899639, 39.140990703336655, 42.990989223603286, 44.979277887652, 48.17423666677168, 49.098127426639685, 53.171626521695046, 52.51208389959028, 54.869346003378595, 55.39790499594904, 58.568164610093646, 53.715988743689756, 52.10206677836757, 54.93774821681362, 57.973599972263465, 54.618200563615375, 58.72182346159413, 56.30548654064056, 57.532815779409106, 58.79855286690497, 61.7175179912198, 59.15801063660653, 51.224989506506155, 43.504800104325824, 44.803559626302416, 46.12966199075022, 56.055235401276626, 59.06476413050006, 66.41813739653557, 58.1965200362667, 39.687102302428215, 0.49617189012708207, 5.031885139403805, 19.862145147015973, 7.306168031307959, 0.4740200900743085, 35.67829485862486, 76.07592275065761, 61.94292091554212, 71.1251384981217, 51.1666795515245, 45.41686142644575, 38.7407559733237, 57.01698095567765, 59.83005385245047, 5.274738688622752, 0.4074834845960141, 0.21180137030539975, 0.16027838742781073, 0.2160415290704658, 0.14920293173242002, 0.12669413470693175, 0.22755589185943528, 0.17851587655323167, 0.07820899688428448], [0.09353656997723926, 0.01821385914339654, 0.03513266197255543, 0.04629565853505366, 0.13936558137497596, 0.06510650318476462, 0.07201279348303234, 0.015098711986455227, 0.0352587791970901, 0.09628340121238463, 0.019627404361662847, 0.09656823270263211, 0.24247416715708472, 30.198941807593073, 56.36361214422411, 33.63244933466758, 27.036742664152577, 39.531729375162435, 41.15673203622141, 56.55785575989754, 54.53858037148753, 59.805084043933505, 50.724946145088445, 55.337512262405895, 2.678245099321489, 0.03702664965643518, 1.6757537184223052, 3.289282220986582, 0.3929714504028521, 18.024712800979614, 71.1222751678959, 48.0618921402962, 55.014234435173776, 41.39213308211296, 46.94426375050699, 49.524489064370435, 55.92319273179578, 52.76360980926022, 48.04499456959386, 38.83550866957634, 40.59935931236514, 47.919741522881296, 53.024600398155954, 51.13758340958626, 50.52095936190698, 48.506018192537375, 52.04433341180125, 50.59449595789756, 51.01173808497768, 50.66318450435516, 51.26090665017405, 51.15242565831831, 50.85651028540827, 50.917008922946074, 51.89029409039406, 50.72313793243901, 51.54715730297951, 48.28255291908018, 46.98018873891523, 39.14385011119228, 37.824027461390344, 38.23457410258632, 38.1217392798393, 38.64533647414177, 36.591548150585545, 39.305149739788426, 39.4091631520179, 40.783581272248306, 40.0570837913021, 38.39103352638983, 39.09377321120232, 42.551369974690104, 42.62811114711147, 40.93163113440237, 42.13279031938122, 44.358221561678, 43.63706634890649, 39.75879930680798, 39.95720455723424, 38.71024777812343, 37.53905550126107, 37.43650121073569, 38.13990769847747, 41.14682020679597, 40.38036946327456, 43.45167552271197, 46.11580033456126, 45.5115278305546, 49.366139058143865, 40.98360646155573, 44.41633147578086, 48.25697122081634, 40.78813514401836, 41.90601064312843, 39.697853519070534, 39.26117604778659, 38.4921443846918, 39.84130244101248, 39.751244821856105, 39.993831649903335, 36.70646182952389, 40.905637587270434, 41.54128513028545, 42.436715172183135, 42.06803983257663, 41.38893242805235, 38.143127964388945, 43.889651298522956, 41.79270121359056, 36.680150570407996, 37.58957955145067, 39.30590675723168, 39.31461049664406, 38.232930629484116, 34.836420859059984, 36.938979933338786, 37.61205081016787, 36.61530986908944, 37.134839565523215, 37.76291301173549, 35.89549610691686, 35.91928920438213, 36.08693130554692, 35.65609032107938, 39.35646610875284, 41.63269596715128, 46.58805370330811, 45.35180891713789, 51.27810624337966, 51.60415326395343, 52.7275396931556, 48.22986764292563, 49.30387143165835, 50.99966502958729, 53.99029970169068, 52.33782868231497, 53.57969814731229, 53.20856348160775, 51.923304757764264, 51.37324333190919, 50.781714608592374, 54.05553264002646, 56.595541892513154, 53.13904731504379, 46.037250949490456, 38.27799866276403, 41.45077643855926, 50.13953239687028, 58.98690508257959, 54.133685865709865, 61.93042816654329, 22.519360703806726, 0.03419488225312483, 3.948594648991862, 4.368128911141427, 0.7048366819658588, 0.14855017885565758, 37.600852443325905, 59.849081270156375, 52.873628370223514, 59.38721825999599, 36.38168565688595, 20.905966297272716, 27.272700686608594, 47.672753795500725, 29.18617798436073, 0.15371800880999337, 0.02155111434178487, 0.08662156925927247, 0.058020645707485184, 0.028901932903775768, 0.09493369984650805, 0.049211745405749935, 0.0728033808991313, 0.04632881865085614, 0.029820123754982508, 0.023047284057904637, 0.03833515081374395, 0.039044077087554245, 0.013359017283355278, 0.04425499182675154, 0.05638700534379291, 0.007028300812723296, 0.06679788742574953, 0.036925878450875325, 0.10769271036429752, 0.005164226468261933, 0.047557420668102084, 0.6688546966160498, 40.119057240024695, 61.79403558854134, 34.7232408677378, 41.75887861559468, 64.3284397740518, 50.67701478158274, 63.03062554328673, 58.248083514551965, 64.91484195955339, 56.29904600881762, 61.116489287345644, 2.3886962234973907, 0.2510989229044607, 4.043478499497137, 6.921221229337878, 0.29736946907735645, 20.33977020171381, 71.3644423023347, 50.05307159116192, 56.12206866664272, 43.243546716628536, 49.664811857285045, 51.86925841915993, 56.335959434509284, 52.6488059566867, 50.654131673997455, 39.3353323782644, 41.07184017858198, 50.23868991482643, 53.43771619181479, 54.99647394303353, 52.26131108499343, 49.94552020103701, 53.20486076416508, 51.509557462507686, 53.20910476869153, 53.59997287873299, 54.80247743668095, 52.140533462647475, 52.99026789203767, 51.249594534597094, 52.21467802601477, 52.89296565517303, 53.33968047172793, 47.82665191158172, 49.05458127298663, 41.015012879525464, 39.76988784728512, 40.907790968495036, 40.78074932098389, 40.681411373999815, 39.377548848429036, 40.89401952682003, 40.58547412195514, 43.234670392928585, 42.3284028422448, 40.53375767123315, 41.704942103355165, 44.341904501761164, 45.739754861400975, 42.804296170511556, 45.774091289889434, 46.94000797887003, 43.95859087667158, 41.059669063937285, 41.39924826160554, 39.9038956242223, 39.66548219803841, 38.31847752294233, 40.25631666183472, 42.09246050926947, 44.239158015097345, 45.44527507597401, 47.817536323301255, 46.883694510306086, 50.119085081162, 42.07795950674242, 46.14572409660586, 50.54915728107576, 41.54759622389271, 43.15241829041512, 41.41439253284086, 40.171150238283225, 41.34105205535889, 41.09839854701873, 43.047773376587905, 41.51966502589565, 39.758720859404534, 41.957982047911614, 43.005509837981194, 43.97092280849334, 43.56232166290284, 42.98654910056822, 41.903264984007805, 44.568335087068625, 42.99463702786354, 38.11388277238415, 40.09227137411795, 41.38786162099531, 41.20262768960769, 40.36226380255915, 38.40513836952948, 36.71611478251796, 39.701489556220274, 38.87207300432267, 39.479742280898556, 39.747608784706365, 38.687223465211936, 38.71544491860175, 38.509924488682906, 37.17817783355713, 41.854200055522305, 43.63715264105028, 47.725839153412856, 48.90404070577314, 52.83857022562335, 53.9499738139491, 54.290737567409394, 54.09359924254879, 50.51242428441202, 54.47895250012798, 55.784180010518725, 54.15883218088458, 56.982887714139885, 55.15960139612998, 52.98816550162531, 53.98776585055936, 52.468145508919996, 55.87073887548139, 58.49286294752552, 54.83747674572853, 48.92205615197459, 40.548894097728116, 44.10186721432594, 52.52211732249106, 61.98427446426884, 56.36042717964419, 60.063183846012244, 25.523288288424094, 0.4867423283717325, 5.420925915241242, 7.162250386130426, 2.5750119936081672, 0.11507579846487892, 41.161572241014056, 64.71254964028635, 58.74706391365298, 63.78753708254907, 45.48337697982789, 26.64902617854457, 29.768208688305272, 54.550610280806026, 34.842182820843114, 0.30946740700352576, 0.026580433684190916, 0.12439180300721239, 0.024187998553257317, 0.03771235580526052, 0.03643907937071016, 0.010940361835603273, 0.039092731331625295, 0.010642460885367567, 0.12381152970896614, 0.20898722292434788, 0.137573073527986, 0.2043610171324784, 0.15959237101337603, 0.17305763798855966, 0.12847102968202484, 0.1180682528103071, 0.09207237677107896, 0.0966404288286163, 0.2558691379043364, 0.1602257878309296, 0.16527138079606718, 0.574806310957478, 48.11127478076566, 70.85713863372803, 46.645547805293916, 39.238398844195956, 49.913195948446955, 53.18044400984242, 66.7686168609127, 62.13911787156136, 69.21242606255316, 59.73531292330835, 66.39627410519508, 3.7475143421080808, 1.0943831984073886, 7.466095320640072, 8.976462791042945, 0.5963045767238063, 20.650051255379957, 75.57077638564571, 52.07808540713403, 61.172430130743216, 45.83631577030305, 51.703714786037324, 53.359923824187256, 60.97557029416485, 55.47909413614581, 53.91105605709938, 42.53639828774237, 45.133615309192294, 52.858244834407685, 53.99987028491113, 54.35450746167091, 54.60077739530995, 51.57492376142933, 56.753797761855594, 54.73990778769217, 56.42453832011069, 55.11106990998792, 58.3570195013477, 54.100792869444824, 52.94023413811961, 53.15084580452212, 54.74257499940934, 55.09767893821963, 56.57063876428912, 51.92843914031983, 51.376102739764804, 42.15519882017567, 41.764024765260764, 43.3395428042258, 40.66700058598673, 43.33699718598397, 39.0132430291945, 44.752768854941095, 41.796325483629786, 46.02348343018563, 44.3392922032264, 43.495080471038825, 44.86388175718246, 47.14937233155774, 47.0804209862986, 44.52775424526584, 46.934806916021536, 48.89021042854556, 45.948126854435095, 42.527015978290194, 42.85704028221869, 42.53548829786239, 40.344781798701135, 41.63518667221069, 42.658944899036044, 45.12441342876804, 44.943615698045306, 50.19594000231836, 49.796085742212114, 47.62225720190233, 51.34961497399115, 44.144707341347974, 48.25949722720731, 52.76296261818179, 44.58404025723858, 45.01953317273048, 44.756479417124105, 41.693037709882184, 43.381104238571666, 42.97586064184866, 45.35588425974692, 44.17906730405746, 40.21429238780853, 44.780437254136615, 46.08051469249111, 47.58996825064383, 45.65573376993979, 44.70587299716088, 43.602890737595104, 48.3248439142781, 46.0469078248547, 40.763384988231046, 43.256686656705796, 44.14278930233371, 43.35798186640586, 41.7369721781823, 38.85137465692336, 38.24590583001414, 41.4117645448254, 39.41660781060496, 41.894380815567516, 41.81854963302612, 41.33050480196553, 41.251143486269065, 40.20401970032723, 39.569203699788744, 44.58895890943466, 45.45524181858186, 51.616744072206565, 51.420029363324566, 55.59727907180787, 57.99328634815832, 56.06057374708114, 56.21270287421442, 51.605659454099595, 55.39213126705539, 59.250256938319055, 57.54762664917977, 59.69665404289, 57.589941178598714, 55.24852152793638, 55.67105885474913, 53.24437079891082, 56.30046982919016, 62.0928535153789, 56.74348585067257, 50.78463677437075, 42.75696885201239, 45.61903215223744, 54.8559981776822, 62.3378526010821, 56.376304934101725, 61.96634531021119, 28.438515393964707, 0.5983972224977709, 9.334546750591649, 10.185617727618064, 4.847576397080576, 0.3823299069077738, 47.67595052719117, 68.97069038883333, 63.100934028625495, 68.61545701180735, 48.4997384778915, 29.68689795463316, 38.966990440122544, 61.00917323943108, 43.33433389663697, 0.6628474641230799, 0.17575576901435855, 0.1751107842691483, 0.11964655481278898, 0.13603029502255304, 0.1574107058226101, 0.17758576920436275, 0.1088205756499402, 0.1274764483734485, 0.19269458589053926], [0.10101073061025913, 0.022019044676375006, 0.016301372351365227, 0.05536653409381548, 0.05243478838594691, 0.07579772748173245, 0.031151665006614024, 0.031068578940786185, 0.051488405499126644, 0.15735326455004756, 0.08459131368586133, 0.1415635489167706, 0.13587994260653374, 15.27923999294158, 58.69211150753883, 42.28058130510392, 25.495594393822458, 20.195838828240674, 29.39268881274808, 54.69342770115022, 54.13146580419233, 58.80748018141716, 46.929762747979936, 61.53254685863372, 8.36346987755068, 0.16688424102481336, 3.188696469991438, 7.752195942786432, 1.4251705259084704, 10.990728332150368, 71.7749418750886, 49.220230810103885, 56.123021802594586, 44.0439808753229, 54.036042382640225, 52.395550281770774, 58.45452177909113, 49.350555481449256, 45.24715615857033, 37.384223861079064, 46.41193536020095, 48.990768232653224, 55.73630748256561, 50.379863862068426, 51.75539201305759, 49.83824729919434, 54.394672532235425, 52.82248458554668, 53.18160503141342, 52.93726098152899, 54.715004659468136, 50.29565841920915, 51.64754644516976, 54.18422168300998, 55.02653498803416, 52.32501429896201, 54.46881317323255, 50.388171442093395, 49.917902792653734, 42.24379339525777, 39.93934208346952, 37.928233069758264, 39.2026738966665, 39.243058619960664, 39.47613370034003, 36.9550028154927, 38.785015998348115, 39.11848806565808, 40.84977519127631, 37.30090487387873, 41.01208286900675, 43.30467293339391, 43.13867430533133, 40.237897211505526, 42.34189579563756, 41.75836478510211, 42.19543449340328, 39.86414240252587, 40.145548928168516, 36.606021696521395, 38.91944346889373, 39.15839425979122, 37.02207142306913, 38.9614716652901, 42.069777442562966, 44.50971526484336, 47.09313338802707, 47.402761367059526, 48.74471402937367, 45.50813105798537, 41.103885942889804, 50.33216784077306, 44.98281194317726, 42.40810932651643, 42.71368549716088, 40.49102737057594, 39.222572080550655, 36.447248074316214, 39.443425055473085, 36.7804338086036, 39.53311004946309, 39.02196638045773, 40.53475787562709, 40.20547489966116, 40.7977645627914, 40.727942451354, 41.16234887030817, 40.52840363594794, 42.20768405545143, 37.522675683421475, 36.064746379852295, 38.09629486453149, 38.84474192896197, 36.69938587373303, 37.88920548654372, 36.94687174212548, 40.47689507084508, 37.60353926689395, 37.229333385344475, 38.947731602576475, 37.40179607945104, 37.13180365100984, 34.656803761759114, 36.19584768049179, 38.77375879595357, 42.84682643028998, 48.14417562177105, 46.84244686557401, 49.91551014684862, 51.90674843326692, 49.71717942145563, 48.53250203594085, 46.69991185588222, 51.44360280806019, 55.6131999723373, 54.547119371352665, 50.82236605305826, 51.78948917696553, 53.37998674761865, 52.84913709086757, 52.64509931687386, 53.33594245295371, 57.01798508244177, 54.99889404542985, 51.73850620946577, 38.21161646996775, 40.37120680655203, 48.54703049505911, 58.34972781519736, 56.08382163509246, 59.1675929869375, 16.5440906247785, 0.04906912664732626, 5.5651078301091355, 5.360270382896547, 2.143380406402773, 0.4348747131805267, 46.37580248617357, 55.933026113817775, 56.445742653262236, 54.7031081107355, 39.61612309178999, 37.317567102370724, 28.720618140312936, 50.2035140991211, 17.180465767460486, 0.15437445423055082, 0.07362984421272432, 0.07810721444266458, 0.07448769414857512, 0.04731033049944428, 0.05491390636551285, 0.09013043581357888, 0.04978091042909411, 0.03821652975954837, 0.04755453634706717, 0.058778674386802225, 0.03192369777318691, 0.04672622676157663, 0.03003060641217857, 0.07500779124036913, 0.1075520719431581, 0.10138268161925579, 0.09828825331022663, 0.13072086137629327, 0.1752493082876167, 0.07755072051358801, 0.0623612922255791, 0.17168238759040835, 22.3544583782073, 64.20683845396965, 45.647386966213105, 24.88218668968447, 30.05471233398684, 39.811484582962535, 58.34215371839462, 60.15475157768496, 63.57439548738542, 52.24560591482347, 66.55192159837293, 9.249718631467513, 0.08873057101042041, 2.165355485293173, 7.724877615128794, 2.149548088350604, 10.84018188138162, 75.55481233904439, 51.593782517217825, 61.22260508998748, 45.108602354603434, 57.238347761092655, 53.95183301741078, 58.172491596591094, 52.164534445731874, 48.06820715627363, 38.230381088872115, 48.93880859498055, 51.89981368280227, 57.866986028609745, 52.02924405374835, 54.155258901657604, 52.27722021841234, 55.96675065255935, 53.3934679339009, 54.301535852493785, 53.687022039967204, 56.26299942693403, 52.39055318217124, 53.05116661133305, 54.19482777195593, 56.65580911021079, 54.84876532708445, 56.45309709733533, 52.03812822218865, 52.08878955533428, 43.23986361103673, 41.23765445524647, 39.93834580144575, 41.51470322762766, 40.70527507412819, 40.7979057681176, 37.72437964716266, 41.7229457824461, 40.36112631520918, 43.059026656612275, 40.05705633471089, 43.10731103343349, 43.619882445181574, 43.64498953665457, 41.598794921751946, 43.7930864672507, 44.512837471500525, 44.62376209997362, 41.16381191438244, 42.66740545149773, 40.061704343365086, 40.31588962001186, 40.36269134090793, 40.845609634153305, 40.920271950383345, 44.09964715280841, 45.75510701825542, 48.756045756801484, 48.363000731314386, 49.46724991644583, 44.82740371457992, 43.87927662941718, 53.0636005247793, 46.99006526700912, 44.98079976727886, 43.414750329909786, 41.492004471440474, 40.981602130397675, 37.954599242056574, 40.30130232534101, 38.59303951263428, 40.9469715241463, 41.220050857913115, 41.02344989776611, 42.341997777262044, 43.74227216166835, 41.480256972774384, 43.49697497583205, 42.77147769927979, 44.94165451295915, 39.4433230738486, 39.58921171003772, 41.2933874130249, 41.62173294251965, 39.19003994234147, 39.8746935782894, 37.962067434864665, 40.61012621848814, 39.724537403352805, 38.99536094357891, 39.50177423415646, 39.23773596363683, 38.19689189234088, 38.27399392281809, 38.75631993816745, 40.404950957144464, 44.39023986939461, 49.594770093117994, 49.00054670149281, 52.250053882598884, 52.48470183341734, 52.74273103283298, 49.90850087135069, 49.792069235155665, 51.78712398775163, 56.19764097275273, 54.61017147187264, 53.60729986621488, 52.83803678327992, 55.030127879112, 55.54707665597239, 55.42956636797998, 52.030483522722804, 59.65060541706701, 55.88431419864778, 54.11245799833729, 41.41515347265428, 43.759656106272054, 51.33951487079744, 61.726923834893014, 57.03385891452913, 59.82550782542075, 19.40806019690729, 0.11933182291085682, 5.0496676948762715, 6.3420567973967525, 2.2204723858064224, 0.3627069324495331, 51.7215145018793, 60.752006961453354, 58.90733195889381, 60.449392180288996, 45.93567725150816, 31.856296177833315, 29.87502855639304, 58.886060945449344, 22.793240201088693, 0.2555610020194323, 0.02152128862367282, 0.07423874621670093, 0.0435463949707487, 0.010543839514045226, 0.03833097180411701, 0.08261567252057214, 0.030523003679850412, 0.04394846089604882, 0.07499374884871707, 0.17786151489182828, 0.1984335190706676, 0.08828119149491673, 0.13710050453101436, 0.14312479014117874, 0.17803305729983315, 0.16573233590010675, 0.27765787356803495, 0.3178078368786843, 0.29682024532268125, 0.2717184551781224, 0.30732864273651955, 0.38076699561169075, 24.979551684471872, 72.53115915483045, 56.275398039048724, 39.06590084875784, 30.56936260192625, 41.95117281329247, 66.04482973775556, 62.97011513863841, 70.11064098727319, 55.49911391350531, 74.55378424736762, 11.90653802887086, 0.4287424244947972, 8.210785244741748, 13.964142818604747, 3.4801643654223415, 11.690389936970128, 77.55417777645972, 54.0622006693194, 63.45567710937993, 48.45437626684866, 60.21729769245271, 56.952152021469615, 60.993777936504735, 55.554411488194624, 50.83133651364235, 41.23366148241105, 52.06357655986663, 53.16719032103016, 61.207660859630955, 56.40018432371078, 57.202195275214414, 53.7046766281128, 57.59717795156664, 56.185112922422356, 57.83695636257049, 56.878415384600245, 58.863472015626975, 53.86350516350039, 56.171066914835286, 59.131342441804954, 60.04889072910432, 56.30238002346408, 57.522652918292636, 53.70186428869925, 54.732694548945275, 45.42125840340891, 43.71221503903789, 40.62238362527663, 43.05832062998126, 42.60973484285417, 43.59988227967293, 40.20734979260353, 44.29035279058641, 42.26457803480087, 44.62617827999977, 41.074323038901056, 45.951194147909845, 47.68507396021197, 47.04938327112506, 42.92824699032692, 45.607790639323575, 47.643214425733014, 46.66803867586198, 44.11301459035566, 44.25569080537365, 41.07133811519992, 42.92095530417658, 42.702714627788914, 42.3136390409162, 43.487361246539706, 45.11991447018039, 49.76079225540162, 51.478080441874845, 50.128451701133486, 53.35198494695848, 48.126850512719926, 44.333149771536554, 53.28613227413547, 48.40573887671194, 47.221649846723004, 46.925699172481416, 45.464380941083355, 44.368145158213956, 39.74544363637125, 42.118430522180375, 40.828260990881155, 42.72070653976933, 41.67729331601051, 43.34184523551695, 43.388776394628714, 45.93136264431862, 44.25395319538732, 48.057251976382354, 44.10707612191477, 46.77903782936835, 42.660298116745494, 40.90119746423537, 42.464881712390536, 44.014292455488636, 41.225777518364694, 42.00857277839415, 40.783530281436065, 45.884070627151004, 42.242518624951764, 40.92584956076838, 43.088781756739465, 39.52931711750646, 41.63298230017386, 38.99101103505781, 39.647098049040764, 42.491165514915224, 48.31298658924718, 52.40809794395201, 52.324237669667895, 54.684665126185266, 56.799210963710664, 55.19458893806704, 50.16374518794399, 50.34799852678853, 52.4924720487287, 58.82826874333044, 56.987755375523726, 54.71334157451507, 54.59023798665693, 58.106313367043775, 58.55050609957788, 56.49197955285349, 54.94727957633234, 59.99334212272399, 58.282918084052305, 58.83119875384916, 42.83937784933275, 45.72170411386798, 53.490464225892104, 64.56551567200692, 60.11016599593624, 62.51164890104725, 22.747022913348292, 0.4186545787078719, 12.03570265923777, 14.749842593746802, 5.797580826667048, 0.6367323235157998, 60.494322930612874, 65.3553202075343, 66.82138842921104, 66.31282960214924, 52.95027540576074, 48.289570039318455, 39.88173423274871, 66.03796558995401, 30.262501855050367, 0.32365131041696, 0.16528438896902148, 0.1757999722875895, 0.23461827257227516, 0.11878915686881351, 0.22936382871722022, 0.29439334006559464, 0.11557353345016319, 0.11376005011580645, 0.1615934386368721], [0.018046378916610154, 0.027123894542455677, 0.03758597044995235, 0.089720647722002, 0.04586328234102938, 0.062029376971505346, 0.05289476289744339, 0.08603774131305757, 0.053407735371541594, 0.08240754175330363, 0.035740529757834254, 0.08337445962693422, 0.03823667404151732, 1.112361627240335, 39.1665449450093, 53.311078548431404, 37.08096973357662, 37.573038916434015, 27.90280003701487, 49.80678596804219, 55.9035808809342, 58.78341251803983, 49.493949490208784, 59.71281813037012, 21.227184880164362, 0.049886025353184635, 1.3003272443048417, 5.151369360185439, 0.1621380505422431, 10.214189252545758, 70.95698648883452, 51.49151063734486, 55.17537324659286, 49.023927950089984, 57.36060803936374, 55.76160284780688, 57.21207572567848, 50.77355607863396, 42.56749091609832, 37.90505970678022, 50.63712035456012, 51.53268375704366, 54.36497234529065, 48.49652605672037, 54.04014518184047, 49.61313463026478, 53.888812295852176, 49.91978553033645, 51.80704962822699, 51.42139827051471, 53.291309802762925, 51.922284941519464, 51.89276910597279, 50.149632500063994, 54.50806433154691, 53.0839733154543, 54.686657690232806, 50.53598203966695, 51.115986839417495, 41.784401478305945, 39.05264323757541, 37.99957313845235, 38.121484325778106, 38.7919036803707, 38.2285689538525, 37.15298052757017, 39.12407352078346, 40.72754236959642, 40.975895081796956, 38.26649042867845, 41.25924318067489, 42.970636044779134, 43.311666519411155, 40.08739979036393, 42.576257413433446, 41.968815634327555, 40.84396223868094, 38.50743378362348, 39.73772441187213, 38.959373197247906, 39.475921892350726, 37.25043573687154, 36.92545560098464, 39.5056220792955, 45.577784507505356, 45.61035979178644, 49.68552197179487, 48.5853991200847, 50.52703119093373, 47.033834995762, 40.862883752392186, 44.33998254037673, 47.57012105757191, 45.44014461578862, 45.33863367572908, 39.844809039946526, 37.20197485339257, 36.949233008969216, 38.24890252082579, 39.71169164103847, 38.41984725767566, 38.32653407127627, 40.554777652986594, 41.66114884038126, 40.83112432110695, 40.894403919096916, 40.27052740896902, 40.69030338718046, 41.61675545477098, 39.38700568291449, 38.51342716524678, 39.85502289187524, 39.41073994482718, 39.56191593600858, 36.8806032980642, 35.26753640943958, 38.88940988048431, 36.61441556869015, 38.00862989118023, 38.66483065389818, 37.752785451950565, 35.31727598559472, 35.89378203115156, 38.11451035161173, 37.13202330373949, 40.52932147056826, 46.01860792406144, 48.802431706459295, 50.17573979593093, 49.43572582737092, 53.517367762904016, 51.188099615035526, 52.624283298369384, 53.25767155616514, 51.91075317321285, 51.82977584100539, 52.27194463053058, 50.550996872686575, 51.5869144470461, 51.20414603141047, 53.7402956716476, 48.08319845507222, 54.01487335082024, 56.57209004125288, 52.95268766341671, 44.697985110744355, 40.53660531197825, 47.39612471672797, 58.881071690590154, 55.20583829572124, 59.85754182261806, 12.0046414098432, 1.1956701956449018, 4.148547764747374, 7.044268433124789, 1.7148136611907714, 0.9893482538961595, 54.55744697201637, 53.07627762517622, 56.6176522931745, 50.519888554849935, 34.97887349897815, 27.66696164684911, 34.84709362829886, 50.05795101965628, 8.213443631126035, 0.3380607807588193, 0.1498665783794657, 0.01567071249272915, 0.06843760669712098, 0.11896384789818719, 0.07661669845542601, 0.029603485581314856, 0.018762249777454044, 0.048326580604958924, 0.04405172188736258, 0.041681690997774565, 0.08244272817166583, 0.06415935037958045, 0.008021610894150311, 0.015756946222315875, 0.09362427938369014, 0.01909981109952975, 0.05504607185420971, 0.02249234720253416, 0.09684361066789397, 0.06798946824405463, 0.03674635340669944, 0.12542995939692184, 2.5810548951548915, 51.05030675088206, 58.33622701706425, 39.63175373692667, 32.82711417444291, 35.53263764227591, 55.616471229061005, 63.293498869865175, 63.28810953324842, 54.79002391138385, 64.25648389324066, 21.20791623669286, 0.11350242240775017, 0.5902025944763615, 8.839875075124926, 1.3039558044364377, 10.592444000705596, 72.55217521421372, 53.6954237568763, 60.058225970114435, 50.244208689658876, 57.90916327507266, 58.19230348833146, 61.169617791329664, 52.1752699728935, 45.17711831677345, 39.39872572498937, 51.46892170752249, 53.90251705723425, 56.28551383172312, 51.998833917802386, 54.78272830286334, 52.538175505976525, 54.54871969838297, 51.39117640833701, 53.783343684288766, 52.19907091509912, 56.32538472452472, 53.835923056448664, 52.88539155837029, 51.44624256318616, 56.059871642820305, 52.41372654514929, 54.746277716852006, 54.450130924101806, 53.58790374571278, 43.70125593677644, 42.445207103606194, 38.976866968216434, 41.82948127869637, 40.20979342922088, 40.28526375370641, 38.52790855592297, 41.303683634727236, 40.93275685464182, 42.06083836094026, 40.30933141708374, 42.52591379227177, 43.868760754985196, 44.39800223996563, 42.5295223728303, 45.42104267304944, 44.49579085073164, 43.282982226341005, 40.89697699392996, 41.9098545658973, 41.63674777553928, 40.51381634127709, 39.58539524386006, 39.04668515728366, 41.68079991494456, 46.83184469899824, 46.62965828372587, 50.393058715328095, 50.67749723311394, 52.190025929481756, 46.41533997751052, 41.71151207339379, 47.285541334459865, 49.84717069133636, 47.60888584198491, 46.86012106557047, 41.42920732498169, 40.22180372668851, 39.942934974547356, 39.26909139079433, 40.10643897518035, 41.995574043643096, 40.065309001553445, 42.3868187012211, 42.25922399951566, 42.80244873416039, 41.16371777749831, 44.136929281296275, 42.64433799251434, 43.60764465024395, 41.419013084903845, 40.97228257886825, 40.145819571710405, 42.2356427100397, 41.21619516803373, 38.257245402182306, 38.63908813845727, 39.49373337530321, 38.03679643138763, 40.90183288820329, 40.98413598152899, 40.85228943055676, 37.73694692119476, 39.230718843398556, 41.11432336991833, 39.47786346558602, 42.400437170459384, 48.92356234212076, 50.76735088902136, 52.151465108317716, 52.123620202464444, 52.98543945435555, 52.12528720978768, 55.3664711213881, 55.207258193723625, 53.916857242584236, 52.914350417352495, 54.33455044223417, 51.67520699962493, 54.58947312447333, 52.9268745453127, 56.53494911809122, 50.48418321917134, 56.153918312441924, 56.31944233371366, 55.89457511901856, 45.979917664681714, 44.38899255567982, 49.512949451323486, 60.69901574042536, 57.233982163090865, 58.76726412004041, 13.69664893996331, 1.0121860703633678, 4.246663893422773, 9.045222920756187, 2.791824927253108, 1.607371852282555, 59.33139901007376, 58.83355217595255, 62.331239484971576, 56.77275457689839, 44.49478280159735, 31.110500635639315, 36.73745639862553, 57.99172524482974, 12.042106909136619, 0.27561462514342805, 0.07166662133268772, 0.006632338692959879, 0.10083360342128624, 0.061184140673327836, 0.07352422367060378, 0.04315030836169759, 0.0338814948354998, 0.016653587020212607, 0.07516690770224219, 0.08009485254484801, 0.11496088527623685, 0.14113726695218395, 0.16794292857089352, 0.17893198487018386, 0.19976600644088563, 0.12726788093606312, 0.21593806123541248, 0.11071249872686402, 0.11638185580170925, 0.14137979506725265, 0.12922599400964477, 0.22652346580739946, 2.662250409203191, 58.7774230587867, 68.17473165450558, 49.47491815013271, 48.483715595737586, 40.27757590816867, 61.21386212687339, 65.54419409844184, 68.8235701284101, 58.22153299085556, 71.03063291118991, 25.37820177693521, 0.10526999560815674, 6.669860059215177, 11.515201195593804, 1.0980514725369792, 12.58366463645812, 77.47423987234794, 56.10685771511447, 63.53728986555531, 55.15873847469207, 61.60797011467719, 60.32106007299116, 64.45841535445183, 55.65369844436646, 46.18513999446746, 41.56396819699196, 54.8787675365325, 56.40733872690509, 59.53897083959272, 52.28391962666666, 56.695068113265506, 54.51517951103949, 56.43936487936205, 52.93917902054326, 54.59638826308712, 53.2244961492477, 57.77188031904159, 55.96848041780534, 54.58442503406156, 53.00439234702818, 58.23631248166485, 55.76907496298514, 56.77455886717766, 56.35028393037858, 55.02918258790047, 45.75422448496665, 45.75786052211639, 40.33254008139334, 42.9114317893982, 42.58410215377808, 42.299636179401034, 40.00207647200554, 42.889799917897875, 44.26662637341408, 45.184872842604115, 43.167848894673014, 44.278734730136016, 45.84456059240526, 47.2050739103748, 43.17710961064985, 46.64126065469558, 47.822525578160445, 45.408491088498025, 42.692336036312966, 42.3344942831224, 43.713046581514426, 42.20594252309492, 42.069973561071585, 40.68784013871224, 44.64304447174073, 50.04735277545068, 47.926856702373875, 53.945063006493356, 51.94277540329964, 54.15012451910204, 49.121434150203584, 43.69626275954708, 47.076078922517844, 51.82304897615987, 49.01207846979941, 48.850849443866366, 43.05407270308464, 42.092240856539824, 42.68952369689942, 39.48372740899363, 43.056814439835094, 44.05632849662535, 42.29077554518177, 43.68639015382336, 45.15716129733671, 44.14422096744661, 44.97858755050167, 44.881916815234774, 45.50829971990278, 45.557101849586736, 44.2479911927254, 43.18466409560173, 43.02102673438288, 43.86852541277486, 45.115054653536895, 39.539162266638975, 39.950171747515284, 43.49728484307566, 41.22168648627497, 42.74757869781987, 43.71995387538787, 42.78652783363096, 38.33668124291205, 41.070600709607525, 42.03612350648449, 40.9109406317434, 43.526373140273556, 51.55573160417619, 53.612924545041984, 53.53994884798604, 52.457343301465436, 55.195118458040305, 53.37467585840533, 57.2417837573636, 55.55370546156361, 56.62088040382632, 54.96239639097645, 56.0661905811679, 54.51616402595274, 55.00773899016842, 55.397202891688195, 57.57216891934795, 51.76101276951452, 60.96936118218207, 58.82142420737975, 57.74339214448006, 48.859910118964414, 47.588995502841094, 50.92076263120098, 64.38138000426754, 58.0256498244501, 63.300539524324485, 17.620110511779785, 2.048559926690594, 10.230252338993935, 18.378842030802083, 5.997358416357349, 1.5123523122841314, 66.23218567140641, 64.04968869301581, 64.94989618178337, 61.96272888491231, 47.49697669859856, 36.37496663678077, 45.16947753967778, 65.84396516123127, 14.99073495787959, 0.44213048512897185, 0.3156929132678817, 0.11536287459274454, 0.2624944194910988, 0.21414509373566798, 0.2928866596231538, 0.18629896214171765, 0.11578972346239513, 0.12500679541018703, 0.2368610409358817], [0.04686890297659463, 0.029847610989705693, 0.0368721641960644, 0.07046828361889047, 0.04627454515186049, 0.10838020532842606, 0.08563516210884818, 0.01073021338426418, 0.08839053522434928, 0.08280813678978913, 0.08635841805728213, 0.022222222685213053, 0.020581750732456005, 0.13307109655391786, 15.394103661660226, 59.13600613993984, 35.594312990865404, 24.427460432052616, 35.17787887204078, 47.328632493172925, 58.5080974332748, 58.292241557951904, 48.443177900006695, 58.812751846928755, 36.037893833652625, 0.1318051362590444, 0.48994227763145204, 8.556611307205694, 0.12239175428065563, 4.936755405318353, 61.743931231960175, 55.10880278002832, 58.23008375783121, 54.030943301416215, 60.04312092258085, 54.883913686198575, 54.484561489474395, 45.87422940038866, 40.803553981165734, 44.51209614353795, 53.9044076396573, 52.61866254191245, 52.980720843038256, 48.631510503830455, 52.304108065943566, 52.89113783067273, 53.3126514188705, 50.06790207278345, 51.90263386695616, 50.15904226610738, 52.76838333375993, 51.55302516875729, 51.55814778420233, 54.37075784129482, 54.07848635027486, 50.99722531534011, 53.05047627418272, 50.92850146755096, 51.34766947838568, 40.05569919463127, 37.693824383520315, 37.294150552442, 39.63335406395697, 37.86649888561618, 38.91427378500662, 37.18823479067895, 38.697084303825136, 39.36397744763283, 39.82643273568923, 38.47836117590628, 40.48040951451948, 42.88287301217356, 41.35039906347952, 41.24243974685669, 41.669676073135875, 40.478083549007295, 39.71349985368791, 39.47021484375, 39.40460535787767, 39.94841452567808, 38.75037754735639, 35.61898469924927, 36.70399073631533, 42.81729882763278, 46.96497778738699, 50.1910174277521, 49.79415201371717, 51.81806756604103, 52.58331021954937, 50.65822662845735, 42.77128942551152, 44.75983696599161, 49.13515460106635, 47.68707044662968, 44.93625340923187, 39.89083805391866, 37.67673461667953, 36.68736380915488, 38.5473439001268, 37.6929614620824, 38.99254075942501, 41.557735550788145, 40.48495161917902, 40.49606369387719, 40.871497277290594, 40.44806172770839, 39.43855347171907, 40.06550512006206, 39.90102837162633, 39.752758856742616, 38.06759095961048, 38.83595974214616, 38.74804765947404, 36.816484312857355, 36.13476460979831, 38.244215288469874, 38.3115819961794, 36.709784077059844, 38.20261463042229, 37.54932034400202, 37.17524390066824, 35.344595293844904, 35.27346703314012, 36.09292468717022, 37.94070228453606, 37.11163874595396, 40.36495847086753, 43.944140864956765, 47.98890075375957, 48.37592886340234, 50.05360111113518, 51.05071467737998, 54.8136208903405, 51.0215675446295, 50.41103493782782, 49.49170589447022, 49.405982494354255, 47.559628717360965, 50.44394754594373, 52.67111247585666, 53.13238320812103, 53.54680907341742, 51.52971844519339, 55.718896081370694, 55.35779091619677, 52.39582877005301, 40.443264668987645, 46.64634796880907, 53.39327573776246, 60.311956251821215, 50.42141352930377, 17.74954088272587, 2.344231744927745, 1.3810037797497166, 2.724840895783517, 1.2634319595752226, 2.1728486832111114, 52.62320464657199, 55.084601756065126, 45.62660624904018, 43.58129416742633, 29.032423034791027, 22.035238242918446, 38.50679835965557, 46.207293541200706, 2.1485326847722455, 0.26030616594418404, 0.057712908188301715, 0.005811984451758045, 0.07774320776544272, 0.05861135312326013, 0.061734184142081976, 0.06162919562249895, 0.0232956018824611, 0.054778680355558475, 0.056993137939923236, 0.03249016425181781, 0.08201502128354005, 0.013404735495456526, 0.01195254114141027, 0.030974817439733498, 0.07243138392485919, 0.12157446870039548, 0.05464671404972192, 0.04208980135679726, 0.1161899354549185, 0.009480370621707652, 0.07545514828375272, 0.04985803250043143, 0.021542829100883776, 22.10524666693903, 63.45506521963305, 36.53041408907983, 28.609760192132768, 41.31804343192808, 53.225559111564394, 63.98033726599909, 63.43879522815828, 52.8622103506519, 65.36253344628119, 37.25201252968081, 0.18104606578426977, 1.0780888146931127, 8.323049852924964, 0.8101146908537035, 5.939078859744534, 65.90247123472153, 56.457580366442286, 59.95676209849697, 56.61282385549238, 62.327623059672696, 55.57254460550124, 56.882498571949625, 47.462965826834406, 42.314258775403424, 44.36083386021276, 56.60384162779778, 54.070892641621256, 55.620232782056256, 47.86851929080102, 53.6463588283908, 52.775322006594756, 54.361191180444536, 51.51480951616841, 52.38083747125442, 52.50844394007037, 51.84345314579626, 54.57182638106808, 54.99965498524328, 55.17400041703255, 55.814343037143836, 53.00900505435083, 55.47110819047498, 53.144044414643325, 53.3804182083376, 43.51035025811965, 39.677202240113296, 39.57106290325042, 42.249751475549516, 39.29038593845983, 40.812053757329146, 39.81477152916693, 40.60354840370917, 41.18742066044962, 40.967301168749415, 40.0967271866337, 42.27455654451924, 43.81968798175935, 43.413844262399984, 41.85060324207429, 43.52281555052727, 42.05167178184756, 41.91581656855922, 40.83543892829649, 40.93885614025978, 40.319608026935214, 41.40211943657168, 37.93514036363171, 40.92517883546891, 44.24986216329759, 49.292829959623276, 51.23649381822156, 50.52169676749937, 51.37108602831441, 54.22486528273552, 52.27884407966368, 44.827631212049916, 47.71672748750257, 51.030432101218935, 50.16866776251024, 46.35927361826743, 40.61887702634258, 39.9428722166246, 39.78559301745507, 39.92736708733344, 40.196488749596384, 40.6203047690853, 41.72946476167248, 40.82503288022934, 42.544756858579575, 42.44262618403281, 41.194967300661155, 42.38985461573447, 42.20804491350728, 42.14293356864683, 41.2612396670926, 39.56735234106741, 40.26813084079374, 41.71636404529695, 38.04501379689863, 39.662034434656945, 40.67122497866231, 40.172295570373535, 40.10580355121244, 39.803090710793775, 39.479648144014426, 38.894591331481934, 37.54807303028722, 36.92823656143681, 38.19320094200873, 41.00946664810181, 39.38188698983962, 43.510467929224816, 47.26431738945746, 49.915514069218794, 49.9287324566995, 54.23818957421088, 54.0352108401637, 55.95501884337395, 53.8284940873423, 53.45000497756466, 52.19566629778955, 51.60432977061118, 49.745071395750976, 52.9286317671499, 55.248996134727236, 56.0791265579962, 53.84399529426329, 52.75794590673139, 58.92424521907684, 56.697386234037346, 54.70956040966896, 43.623640075806655, 49.34708418384675, 56.709922129108065, 61.84657181462934, 49.13655488721786, 21.316254062037316, 1.6868342915850303, 3.075914844389885, 5.007877782467873, 1.7511269642460732, 2.706310638496953, 57.943519315411976, 60.892204238522446, 51.6647970291876, 49.16369376644012, 35.25241175005513, 24.414902963945945, 42.156191179829264, 54.446000668310354, 3.6116446650797323, 0.21181598726299503, 0.026230835205604954, 0.08580637509904562, 0.09377688409820681, 0.04614198512788262, 0.05302957138947902, 0.03863333521651165, 0.04084228462870083, 0.018231021428120234, 0.11299194738028512, 0.1100743321641799, 0.18971629651083102, 0.10514537608551403, 0.08964140358711443, 0.18160166339047495, 0.2729285676633158, 0.14347837036175115, 0.1955874564666902, 0.16510510907298134, 0.23910961624595428, 0.22260984435917872, 0.14843892756729357, 0.18416824179791635, 0.20240738567325378, 26.096332842303863, 73.8762418685421, 47.077471363929014, 35.48893459381596, 47.7036306934972, 60.29449778218424, 66.65233427478422, 69.76067143101847, 57.098970259389574, 71.60976302239203, 43.03157791014641, 0.29818945894798926, 2.782165845555644, 21.03293930330584, 1.1011454871585293, 6.710619368860799, 67.36251861818376, 59.551318460895175, 63.41343318262408, 60.11015422882573, 65.14593232062556, 58.21368432814076, 58.69122505187989, 49.66656907912224, 46.13527490246681, 47.73011453690068, 58.44811654859974, 56.023044509272424, 56.7945590326863, 49.05487152837938, 55.067362939157796, 54.29748012173561, 56.284062554759366, 53.115732746739546, 54.29864114330661, 54.531233772154785, 55.7718010102549, 57.04269993689753, 54.62447243352091, 58.56883533539311, 58.33540724169824, 56.04014604322372, 57.693946746087846, 56.70146157664638, 55.774766322105165, 44.78871737757037, 41.6034350856658, 41.928183801712535, 44.825171885951875, 43.04300377445836, 44.18108732469621, 40.40251516526745, 43.60619337328019, 44.48132514953614, 43.44647445986348, 42.04100685734903, 43.330741005559126, 46.34386654823057, 45.77787637710572, 45.464879082095244, 45.83016941624303, 45.49851340632285, 42.73575667412051, 41.94245730676959, 43.4033715340399, 43.148040925302816, 44.07248081699495, 39.017867503627656, 42.11070737531109, 46.51159101916898, 52.59266115004017, 53.18206787109376, 52.2510148632911, 55.762912919444425, 56.956274432520715, 54.78570145945395, 45.64548069430936, 48.0403426385695, 53.82778806071128, 52.51268794459682, 49.77294375819545, 44.6179413026379, 41.47674645147016, 41.340538224866314, 43.190618253523304, 41.764773937963675, 42.150790076101984, 45.699389749957675, 42.542991792002034, 44.788015273309526, 46.234412808572095, 44.18170313681326, 45.30193598039689, 44.48298038974885, 43.124683210926676, 43.599678316423976, 40.792963581700484, 42.67455593232186, 44.27756978619484, 40.58591342741444, 41.104031070586174, 42.233391269560784, 42.18023530898556, 40.06569339383034, 43.35314558398339, 41.24418912395355, 41.71294373850669, 38.86165126677483, 39.61638589059153, 41.773191344353464, 43.884501226486705, 40.83366993934878, 45.05943936686362, 46.952069267149895, 52.46412507949337, 50.5802930555036, 56.391194251275834, 57.34612664868755, 57.7186498334331, 55.847165430745775, 54.82967515145579, 53.50399248061642, 54.565872223146506, 52.33884849855977, 55.765266341547814, 58.41425080453196, 58.29535199749855, 55.73758225287161, 53.93149945043749, 59.21863871236002, 60.430302004660334, 56.887064210830204, 46.83194668062272, 51.0783124739124, 59.45562831817135, 64.78678441816761, 53.054849716924856, 26.215912180562174, 3.7476298068800284, 6.430535662558771, 13.816041965638439, 3.83904432096789, 3.227911836677982, 63.913594215146965, 64.9310923391773, 59.369096909799886, 55.37946985613916, 39.340576587184785, 32.01469325250195, 51.18766030957622, 64.33484108217301, 5.4771182806261125, 0.40466988879826765, 0.173128608373865, 0.17525005905378252, 0.19904038328076565, 0.117200076009237, 0.19606290595425716, 0.1632508698610529, 0.11404724115686071, 0.16755585498627157, 0.15015131793916225], [0.030415778183528495, 0.025498083597349546, 0.04505752255359004, 0.03800042784742771, 0.03656388275445469, 0.059918398713512774, 0.013056213370404177, 0.05845365775448661, 0.10656222505795379, 0.05383392157513769, 0.005999830647206475, 0.03820951622460158, 0.11312939887565952, 0.08284514649741112, 3.4525562726682235, 49.47898957037157, 51.715944736234604, 33.053444739310976, 25.023570483730687, 33.65626596635388, 52.01755146826468, 57.755845669777166, 57.24125815976051, 52.6410984992981, 46.76202650993101, 1.9064430171443572, 0.5580482295443935, 5.642651127230737, 5.860273049723718, 0.2859507753483711, 40.943649276610344, 59.11845353341872, 57.81512837256155, 52.4948803840145, 52.328975892836056, 60.16639317235639, 51.94104171568348, 50.78529965492987, 43.02521582572691, 51.874404568826, 53.36789015800723, 56.11728337503249, 51.85514573127993, 53.10163967071041, 52.0932492902202, 52.2618680615579, 50.52123000544887, 48.95313701322002, 53.207139661235196, 52.636572084119244, 52.47315045325987, 51.39809939169115, 52.830380316703554, 53.1655978387402, 51.93986892700196, 51.29126971767795, 51.197246582277366, 51.469592432821955, 46.02358933418028, 38.6840267335215, 38.98606492627052, 40.3229106626203, 39.64075165410196, 38.765635567326704, 39.667757172738355, 37.73513870854532, 37.433551588366115, 39.50820299886888, 38.01773371235017, 39.723611723992136, 41.56054004546135, 43.01147184064312, 38.904075622558594, 38.456246852874756, 41.14788316911267, 40.59388760597476, 38.847875902729655, 38.9400633688896, 39.5542477023217, 38.687262688913655, 38.80403949368385, 36.402854688705936, 36.405368927986395, 42.69880010235695, 48.945002017482636, 48.861530057845584, 51.37026233057822, 50.310767389112904, 53.527832646523755, 51.41598932204708, 47.190235584012925, 44.22032279352988, 50.6352807629493, 48.70404297305692, 44.63356410303424, 39.443832981971006, 38.39326535501788, 39.40025937172675, 37.90216891996322, 38.41423826832926, 39.10427339615361, 37.25451500185075, 39.5698195119058, 39.454623422315045, 40.77432447864164, 39.8692257942692, 40.03854274749756, 39.37694088105233, 39.72949920162078, 39.24053653593987, 39.451195270784446, 39.745984923455026, 39.261827161235196, 39.991854775336485, 38.13638148769256, 37.403584680249615, 36.74120618451026, 36.73159245521792, 36.28666231709142, 37.231596592933904, 36.6061903584388, 37.85124478801605, 35.24093489493094, 36.9735909277393, 38.57562811143937, 35.361284978928104, 37.54739053787724, 40.123214952407345, 42.93138096409459, 44.439728413858724, 43.379111674524125, 45.781547715587, 45.74630914195892, 45.59337592894032, 47.55755770590998, 47.104782827438854, 46.870785990068995, 48.413905251410704, 49.23327661329701, 49.47882483082433, 50.649126729657574, 53.977426482785134, 51.63182950788929, 53.702350662600615, 56.01723547904722, 53.21358019305814, 47.76136798243369, 44.83867660645516, 53.88016346962222, 56.455779998533195, 50.79785516185146, 12.822081004419635, 0.4397421294162351, 3.751439899206162, 4.101172887509869, 2.4278017638191103, 4.863165367034174, 57.00472354888917, 52.91481325703283, 49.34377370342132, 33.343154922608406, 28.788300598821333, 24.70477004205027, 44.933103745983495, 28.605543644197528, 0.21223410273030882, 0.019267842909621618, 0.10942266713226996, 0.03700724081887353, 0.011471483890237588, 0.07203647326077185, 0.060238366826407375, 0.038821088044994304, 0.05638489094112189, 0.014132578395337108, 0.08040545523286828, 0.02193896933608959, 0.005007219142205413, 0.08328508780968767, 0.04873095628535075, 0.03437693155701122, 0.020227944515945933, 0.02209512295291549, 0.059768034806174625, 0.07912372118763386, 0.015871074170835556, 0.0735305822003753, 0.039039331172863324, 0.09873927225388827, 0.12290872573371857, 5.075421487131427, 59.43650676358131, 56.79815976850448, 29.073878565142234, 37.99298747893303, 46.9720890445094, 54.86733774985037, 67.97178037704961, 61.64721735062138, 60.709829714990434, 49.25057426575692, 1.7015748038407297, 0.707585466725211, 5.79539998885124, 3.666923853658861, 1.2751985797958991, 42.651672824736565, 62.54916637174545, 59.58252483798612, 54.86442735118251, 55.375735759735115, 59.406861489818944, 53.32133554643201, 52.359892014534246, 44.358221561678, 53.62471911215014, 53.36498368170954, 58.55976681555472, 51.98744727719215, 53.06630303782802, 54.08809223482686, 54.662931273060465, 53.40605089741369, 51.745413503339215, 55.0701399772398, 55.11971089147753, 55.0270252843057, 54.60539010263259, 55.37018952831146, 54.365949015463556, 54.1928469750189, 55.117047602130526, 53.14089867376512, 54.4635493524613, 48.52495931809949, 39.89595674699353, 39.86115355645457, 39.81311236658404, 41.72847240201889, 40.76827618383592, 40.56952968720467, 40.385464622128396, 38.89136322083012, 41.567572855180316, 39.202854325694425, 40.88870471523654, 42.045246939505304, 42.80818716172249, 41.931843373083304, 41.873129413973906, 42.01422883618263, 40.99029410269953, 40.927171399516446, 40.618155310230875, 41.67196281494633, 39.67945760296237, 41.67294340748941, 38.1050064486842, 39.280623159100934, 44.33742123265421, 50.45211784301266, 52.472907266309186, 53.65289349709788, 51.05934389175908, 55.63720487779187, 51.739012195217995, 48.0538591261833, 49.917953783465975, 51.78417828775222, 49.91712224098944, 47.30904417653238, 43.33308658292217, 38.78514935893398, 39.55491842762117, 39.88700197589013, 41.58504309192781, 39.56457530298541, 40.60973005910074, 41.83044225938859, 41.75688605154715, 43.52203499886298, 42.09879513709776, 41.49448733175955, 41.23852914379489, 42.92543072854319, 41.82363694713962, 40.5583901559153, 41.09742187684582, 40.13591950939548, 40.93372568007439, 37.69741335222798, 38.8301311000701, 38.47015949987596, 39.65138912200928, 38.79507687784011, 39.76824437418292, 38.44773530960083, 39.333567311686856, 38.64992564724338, 39.84458154247653, 39.6730915961727, 38.34742069244385, 40.64887139105028, 42.609934883732954, 46.09037160873414, 47.70691371733143, 46.095192201675914, 47.31404127613191, 49.00343356593963, 48.37246541054019, 50.29122614091443, 50.277870470477694, 50.628691181059814, 49.75531270427089, 49.20958157508604, 51.41654237624138, 53.42949098156345, 56.279163514414144, 52.801103745737386, 54.30156723145516, 57.902875715686434, 55.33017743018366, 49.14933396923927, 46.4547872543335, 56.605787123403246, 59.24444790809386, 53.16251485578476, 15.488071883878401, 0.7231157237002928, 5.6165526566966895, 2.9326519898829924, 1.7636448409288161, 5.273634051122974, 61.539461997247514, 57.3407216225901, 52.76405303708969, 43.56873866050474, 33.361962687584665, 23.11292121487279, 50.907505020018554, 35.85476229267736, 0.3889284060607034, 0.07743785277970376, 0.014326281811771615, 0.041914734944340684, 0.031122779661429026, 0.08080274076952089, 0.06575997618417587, 0.06184856873005629, 0.05474145231287807, 0.02465106422952827, 0.05569255047087228, 0.10893245513040213, 0.12508698949410071, 0.1835070313104699, 0.19372429999132312, 0.20151239579483388, 0.129828889884295, 0.13333320587633118, 0.1920474101338656, 0.2932906943944193, 0.11863230802719632, 0.13669029509107913, 0.2031519312051035, 0.26518032375362616, 0.38272263422127695, 5.580241805122745, 68.45950357375607, 63.505263713098344, 43.88372851956276, 35.903666403985795, 46.27582519285141, 60.905736415616936, 68.42160563315115, 66.56216682926302, 62.975747662205855, 60.70165157318116, 2.4575262204293282, 1.8952817902449641, 14.649268119565903, 8.614083836155555, 2.474986651251393, 45.620267698841715, 62.34745456326393, 61.584278998836396, 58.228063737192464, 58.22378835370464, 62.74166845506238, 56.6333653080848, 54.18477473720428, 47.35426518224901, 56.538718515826815, 58.37721970773513, 61.01482537484939, 53.25758918639153, 53.16969671557027, 56.65931963151502, 57.086116652334894, 55.47967072456114, 53.173164090802594, 57.62715662679365, 57.59547956528203, 57.826589538205056, 56.37417508709816, 57.23211119251867, 56.80287053508144, 54.780363113649436, 56.426974111987704, 54.572308832599276, 57.48659456929853, 50.33345045581941, 41.72493834649363, 42.083152724850564, 43.737737901749156, 44.55092368587371, 42.86960363388062, 43.078815014131614, 42.84328060765421, 41.50129656637869, 42.96958484957295, 40.41210928270894, 44.39031439442789, 45.587429615759085, 44.96900127780053, 42.9844977009681, 42.99076564850346, 45.209615153651086, 41.85969529613372, 42.40978810095018, 42.22202031843124, 43.525318022697206, 41.75809414156022, 43.95183263286468, 40.2442906748864, 40.19239379513649, 45.854409663907944, 53.30458310342605, 53.155631096132346, 56.32945222239341, 53.76574400932559, 56.17664452522032, 55.269890600635165, 47.80230183755198, 49.03918204769012, 54.942105970075055, 51.0263567586099, 50.36682198124547, 45.24198647468321, 41.93336525271016, 41.79291302157987, 40.566937000520774, 43.42753725667154, 42.155442007126354, 43.46112059008691, 45.110634142352694, 43.856103266439135, 46.345337437045195, 43.55203328594085, 44.90595309965072, 42.771599292755134, 45.482298328030495, 43.95651594285042, 43.842323980023785, 43.244954847520404, 42.304535219746256, 43.700926457681966, 40.39163451040945, 41.638654047443026, 40.758446724184104, 41.55926135278518, 39.61323230497299, 42.11054263576385, 41.42526534295852, 42.61392001182803, 40.2643104522459, 43.32038987067438, 43.02360373158609, 41.00397925223074, 43.897711769227065, 44.00001502806141, 48.85868241710048, 48.60689763099917, 47.42415789634951, 50.567470827410304, 51.868838725551484, 50.80302484573857, 53.054410411465554, 51.46645845905427, 50.7314415900938, 53.270627144844305, 51.793654734088534, 54.29808416674214, 54.479482020101244, 59.13155817216443, 54.12044394400812, 53.853656091997706, 61.91892777719806, 56.922149812021566, 53.039913331308675, 49.184360734878055, 59.93755817413331, 60.6597920387022, 56.04342514468778, 19.247911783956713, 0.8688455038974363, 8.570863239226803, 11.844436122525124, 4.43262493418109, 6.298895036020587, 66.57689925163024, 62.56282798705563, 58.93945617060508, 45.75471870360836, 39.89396810531616, 34.80761497251449, 59.306091877721975, 43.15944717776391, 0.6637510801515272, 0.11987217536736881, 0.21568857704199132, 0.21165307100501754, 0.09815345247907024, 0.30774141091012186, 0.18075599425262023, 0.11645504018111576, 0.1460430795146573, 0.13341333867321092, 0.144759897563246], [0.053074395193928675, 0.07785634363010045, 0.031733644765711604, 0.037314292689364766, 0.05447826280649151, 0.05606209213334707, 0.03768578787604648, 0.020281377233444683, 0.025182227461388516, 0.032197970656617995, 0.03892873488967458, 0.030694320091917634, 0.027581425233473702, 0.06377238787770753, 0.08859016241565829, 22.969144775021462, 49.506571677423295, 27.78438368151265, 27.427149895698797, 33.185911024770434, 51.66433418950727, 50.11044017730221, 51.24229500370642, 51.22247918959587, 58.458098980688284, 8.25874553572747, 1.3821027788423723, 2.3663004704060095, 18.395445423741496, 0.2143220294026598, 29.24602354726484, 55.912402291451734, 55.984052227389434, 44.753765136964866, 46.620801571876775, 58.8230323791504, 52.30277053771481, 56.542464379341375, 47.237406007705204, 52.88981599192466, 53.450314844808275, 53.734765129704634, 51.22107498107418, 55.19502824352634, 50.715818789697465, 51.220604296653505, 50.30691562160369, 53.30031948704874, 50.805425336284024, 53.29596957852764, 50.81443502056984, 54.090484880631976, 51.14414553488455, 50.26369110230477, 49.616174467148326, 51.16726790705035, 48.244835407503196, 47.90127108173986, 39.79128045420493, 37.295350797714725, 38.799473854803274, 39.067634536374, 39.27923856243011, 38.802717654935776, 38.21842178221672, 40.121445963459635, 40.068945038703184, 40.32738608698691, 38.09938961459745, 39.33066868012951, 40.7106565660046, 41.23501862249067, 38.313249003502634, 38.10617531499555, 39.6710088176112, 40.985257779398275, 37.927323079878285, 40.1825878697057, 39.76788743849724, 38.94017711762459, 37.65550282693679, 38.04943430808283, 36.76699184602307, 42.2744780971158, 46.72748219582343, 50.47269459693663, 51.87514981915874, 51.94954541421706, 54.42669868469239, 55.69117669136294, 45.316515430327385, 45.531394635477376, 51.807539924498535, 48.94898714557771, 45.78636438615861, 39.72239971160889, 37.06153831174297, 38.65685255296769, 37.45236327571254, 38.533352805722146, 37.71535427339616, 38.2216695047194, 39.2745356405935, 41.27473262048537, 38.947747292057166, 38.96922226875059, 39.73062492186023, 39.02488070149576, 39.90769640091927, 40.017832632987734, 38.500710841148134, 38.21233034133911, 38.193161718307, 37.85988969187583, 37.50067903149513, 37.36376477826027, 37.844153142744496, 37.22239471250965, 36.52803713275541, 36.767764552947014, 36.05755275295627, 36.360759812016646, 35.01160960043631, 36.4674404359633, 37.44066284548852, 36.86474123308736, 37.905997153251406, 36.973037873545, 38.96042439245409, 38.516541527163604, 40.79349310167375, 38.486857029699514, 40.784299065989835, 41.4512235887589, 41.21205314513176, 43.3166753861212, 43.88968659985451, 45.02680132465978, 45.673702147699174, 47.05709465088383, 49.98310435202814, 51.76436639601185, 53.73891107497677, 51.14116845592376, 56.238582672611365, 54.81287956237794, 52.844230205782004, 48.67751598358155, 57.67575087085847, 57.165521114103264, 47.40192982458299, 1.470860745156965, 2.690292904453893, 9.507472284378546, 2.6281784955532324, 0.4333036813524462, 4.486442304426625, 63.644213676452644, 49.388512257606756, 58.9373851591541, 29.648978440992295, 25.19401119601342, 31.388859479658066, 49.03773861546671, 14.115833620871268, 0.036727354426177285, 0.05661353754300264, 0.02750668761080071, 0.011325886007398369, 0.052747980451151255, 0.00982662512650413, 0.023583101273904887, 0.03531376898829495, 0.04642974690444047, 0.0206836212741872, 0.02338057060936286, 0.03360502902538546, 0.03948528244490585, 0.02165534251910304, 0.011820937769727842, 0.016005278411020916, 0.05602983983173486, 0.0691588861387103, 0.054661641272926526, 0.04515470463722464, 0.015216945208639148, 0.07879911441235773, 0.020311392558317994, 0.0783525541004154, 0.07723420362679229, 0.25397857080303854, 30.75984662578952, 59.189974031140736, 27.575797919304144, 27.924741775758807, 41.62933841828377, 52.109770313386, 55.766937271241225, 59.791857811712454, 56.11557322163736, 61.39573850939351, 7.228279565611194, 1.3304238357851583, 2.174781921409792, 15.597005909489049, 0.7823316849047138, 32.540094737083685, 57.88496617347964, 55.129206949664706, 47.11126258296352, 47.84844852262928, 61.86952944724791, 55.81160522276356, 57.5516039325345, 50.46784262503348, 54.354680045958496, 53.98436123324979, 55.11961283222322, 52.578109156700876, 58.75175899074924, 51.87697372128887, 54.74413218036775, 52.63241829410676, 55.51159097302345, 53.128123514113895, 54.84723560271725, 53.56282411083099, 55.936485644309755, 52.10172945453275, 54.19095639259585, 52.08989566372287, 53.51539088833717, 51.694316787104455, 51.88800342621342, 42.84339043401903, 38.43862364369054, 39.88722555098995, 42.188052592738984, 40.06512857252552, 40.01034090595861, 39.72602398164811, 39.66390932759931, 42.31619642626855, 42.33820092293524, 39.91064210091868, 41.14525518109722, 41.21567741517098, 42.65237100662724, 41.341730625398704, 40.47454949348204, 42.0920878841031, 41.84036977829472, 37.897050226888354, 41.0219790089515, 40.94192343373453, 40.64046575177101, 40.108984593422186, 39.40841005694482, 38.93693723986226, 44.77536955187398, 50.625855307425226, 51.1307780973373, 53.846203588670306, 53.53777193254041, 54.702523677579826, 56.188874475417606, 50.35767893637381, 48.66798462406282, 55.437348350401855, 50.95305942719983, 46.84013266717234, 42.21813717196065, 39.05275306394024, 40.64459992993263, 41.42393173709993, 40.55585630478398, 41.779765236762266, 40.142822880898755, 41.676544143307595, 42.99449582253733, 41.360734508883574, 39.63087512600807, 41.56662364159861, 40.658077193844704, 41.91465162461804, 41.440907755205714, 40.11045155986663, 40.56248511037519, 38.81508488808909, 38.859729305390395, 38.913199055579405, 36.68963093911448, 39.91108532874815, 38.90964146583311, 38.77095822365054, 38.62027252874067, 39.5503802453318, 39.01358819776966, 35.93692810304704, 39.071941298823205, 38.94066349152596, 38.131258872247514, 39.965559205701275, 38.40400088217951, 40.96516739937567, 41.749249196821644, 42.767225850013, 40.40159340827696, 41.891352745794485, 44.20543739872594, 44.65518812979422, 46.69193375495173, 45.04691916127359, 47.488676963313935, 48.978648108820764, 50.23583050697081, 50.5612224917258, 54.93439851268646, 55.65706776034448, 51.663400665406265, 59.01999419735324, 56.000400666267645, 56.688243189165675, 49.572946025479226, 60.39249035619921, 57.44295820113152, 50.81235616437851, 1.8583349018327653, 2.771335446065472, 5.631596417196336, 5.207622522307981, 0.5374279005392906, 4.6357885099226435, 70.05866173774966, 54.34164208750571, 62.967722492833296, 36.36907915915213, 29.631006140862745, 31.002013760228312, 55.65971536021079, 18.151250423923617, 0.043853783919926614, 0.05916898469290426, 0.016093996180702123, 0.07984062626717553, 0.02695393219079462, 0.0472285621048462, 0.013498098630788586, 0.031101714158731125, 0.03415924001244768, 0.041607288538568446, 0.032081900675210266, 0.16285395970748318, 0.17264529882419496, 0.14934597566964167, 0.15534297322794316, 0.1608103129171556, 0.2250313563572784, 0.24176953480609004, 0.15648623688086388, 0.11570821936813094, 0.06583002726397207, 0.17583444624418215, 0.15827134431850526, 0.1932361640877301, 0.158335511843043, 0.2944117261757774, 34.368540933055264, 66.30962894808862, 38.57169005178636, 38.047127954421505, 46.06306406759447, 61.8033786742918, 64.8298441979193, 61.95482923138527, 60.70227523003856, 66.17695869938021, 11.401216137793757, 3.1848324450754353, 10.242099858099415, 27.707177708225867, 1.3705315416859043, 36.19186647476689, 56.674318775053955, 56.83724226490144, 48.06872490913638, 50.084666282899924, 63.465451655849336, 55.50502100298482, 61.42891783868114, 53.00203108018445, 58.31852536047659, 56.4042478992093, 57.37340281086584, 54.51158269759148, 59.15901084100047, 55.92795448918497, 56.06612782324515, 54.17176815771288, 58.05566380100866, 55.173176719296364, 58.607156891976636, 54.5685080559023, 57.63723319576633, 54.50926065444947, 55.17534971237183, 54.085495625772786, 56.031418769590324, 53.97874832153321, 53.69050118231005, 44.12319314095282, 39.8018551641895, 42.31006576168922, 44.67429791727374, 42.83823643961261, 42.82759112696494, 42.06034414229855, 42.231712495127034, 44.45574345127229, 44.68777518118582, 41.58532158021004, 42.206287691670084, 42.13089973695817, 43.86452851756927, 42.57681831236809, 41.29059468546222, 43.5036979183074, 44.480352401733406, 39.63712346169257, 43.165299354061005, 42.49917499480709, 42.1286992872915, 42.84466520432503, 43.37455780275407, 41.5816149403972, 46.34620428085328, 52.34130390228764, 53.46713789047734, 57.781109656057055, 54.900473933066095, 56.920671078466604, 60.24500139297978, 46.41004870014806, 49.86608436030727, 56.940102500300256, 53.57634844318513, 49.746036298813365, 44.427514153142134, 43.12240039148639, 42.69222228757797, 43.8206724966726, 42.798094903269124, 41.757713671653505, 41.33601573205764, 43.18347169506935, 45.52502470631754, 41.62693792773832, 41.520139632686494, 43.05996018071329, 43.15612493022796, 43.45308757597401, 43.19965147203015, 42.96514472653789, 42.300883493115826, 41.384751181448664, 40.873227042536584, 40.03861335016067, 39.21270339719711, 43.420206346819484, 40.165376509389574, 40.149588969446, 42.131892096611764, 40.58545451010428, 41.86754395884853, 38.56062504553026, 41.03842550708402, 41.63159378113286, 40.95645189285278, 41.87271364273564, 41.165216122904134, 42.81476889887164, 45.085605498283144, 45.34934566866967, 42.89508335051998, 45.11227761545489, 46.40960547231859, 45.7107489339767, 48.561056890795314, 47.54606123893492, 49.43431769647906, 51.821821274295935, 52.07563000340616, 53.24415899092152, 56.06248001898489, 56.78461582429948, 52.03645729249524, 60.36798338736258, 59.25352035030242, 59.47201990312146, 52.175728890203665, 63.303053763604936, 58.564673700640284, 53.32913321833457, 2.8200064214967915, 4.654536458753771, 18.53614672537773, 11.18967192788278, 1.3847474369310564, 6.208399582293726, 75.50469229298254, 58.079998185557706, 69.34032670913204, 38.33611249923706, 36.6235037003794, 41.99813927373579, 65.09423940412461, 23.553691679431548, 0.20296446949003205, 0.1388717151337093, 0.14095604119281616, 0.12614163209594068, 0.10581238585854731, 0.09697301824006344, 0.16576567604657144, 0.11308280540810478, 0.09821834778713603, 0.11394290764245296, 0.18953291038351675], [0.03134754794319311, 0.015826605639660794, 0.0627075486455954, 0.03419839476625766, 0.08998597461369731, 0.03988520715445761, 0.0628024937524911, 0.07364341162986333, 0.03892178647220135, 0.026476523433361324, 0.013422268375213589, 0.11123110960808494, 0.029731313097140485, 0.10107197933980536, 0.0071342670520196765, 7.6049751716275376, 48.59102772128198, 39.5752166932629, 36.80279916332614, 35.72971320921375, 48.979091336650235, 54.70159407584898, 55.5651823166878, 47.523444852521344, 58.35244601772678, 14.78037432316811, 1.2526401709164343, 2.016260801784454, 23.337123893922378, 1.8563140231755473, 20.173693126247777, 44.058740754281324, 51.952573483990086, 52.965407909885535, 47.49816517676077, 53.097176013454316, 53.12031407510081, 53.69035997698384, 53.87235795297931, 55.646869597896455, 50.27426188991916, 54.662240935910134, 51.913490987593136, 51.26338166575278, 49.237795183735514, 49.03928795168477, 53.00902466620169, 53.41727279847669, 51.75790232996787, 53.80599929440407, 51.79694168029293, 52.510969946461344, 52.65830593724405, 52.01107563511018, 51.285821545508604, 50.47507547563123, 46.904322255042295, 44.51401810492239, 38.4773805833632, 38.935642857705396, 37.40362390395134, 39.467351513524214, 39.66749437393681, 39.99978580782491, 40.1685183278976, 40.65193083978469, 38.027229770537346, 40.308586166751006, 39.258763790130615, 37.97078294138755, 40.97114116914811, 40.55821364925754, 39.373732382251376, 39.33229254138085, 39.21879876044489, 39.06532818271268, 40.19676723787862, 39.03698513584752, 39.88107919692993, 38.61075293633246, 38.995600208159416, 39.49128581631569, 36.581679467232, 41.93242388386881, 47.922412656968646, 49.00463381121236, 51.417530813524806, 52.15071985798498, 56.14907026290894, 46.38880122092463, 35.789870600546564, 51.915969925542036, 52.645005179989724, 50.43343167151175, 46.2741268065668, 41.22534998001591, 36.98156510629962, 37.35400984364171, 36.72152765335576, 38.201014303391986, 38.271299254509714, 40.23272360524824, 39.25556313607001, 39.20601967842349, 38.197342964910696, 37.742140139302904, 38.99221520270071, 39.38784899250154, 40.0986962164602, 38.391370850224654, 37.55841632043162, 38.11922896292902, 39.55236888700916, 37.833970669777166, 36.15241135320356, 36.76179078317458, 37.22879994300104, 38.641963235793575, 38.52924216178156, 37.38140759929534, 36.8471101791628, 35.881720742871686, 35.46597303882722, 36.839481169177645, 39.00267616395028, 37.412908154149214, 37.35738700436008, 37.69114148232245, 37.52022420206378, 35.433236937369074, 36.31128303466305, 35.67305849444482, 35.736475375390825, 37.041263580322266, 37.23304786989766, 38.333927739051084, 39.44656687398111, 39.85873737642842, 43.36612862925376, 44.89829271070419, 49.74947229508431, 51.203349790265484, 53.02591439216368, 50.17752839672951, 53.8628383605711, 55.995285895562944, 56.624916522733635, 55.51569769459387, 55.48088273694439, 59.13118554699806, 32.415522221596014, 0.6120857428158484, 2.275995251632506, 3.9329517464483943, 3.0239640320501024, 0.35148135416450044, 16.600706115845714, 58.85899266889019, 51.774203700404016, 49.22946406948952, 33.56390983827653, 35.96205872874106, 35.44916176026867, 49.06119438909715, 2.295241831771789, 0.058663627132773406, 0.07498689236179476, 0.03780101133029788, 0.05753049116221167, 0.038471805577677105, 0.017567673555365013, 0.0222600482764744, 0.02359162783250213, 0.03540218702607578, 0.02129365325785212, 0.054963215614759156, 0.04186131563338061, 0.021894183836036155, 0.07364043920871712, 0.01936364220455289, 0.09743395036146527, 0.005818728419516477, 0.03274801795581176, 0.049751285809062185, 0.016282913462829687, 0.021716675518320936, 0.04975412033438202, 0.026891381111777118, 0.031157548561872497, 0.056466712961874665, 0.1326756266456458, 11.414411971645972, 59.94638742939119, 42.076249353347286, 35.500623256929465, 46.94707216755037, 56.99986765461584, 56.02826910634195, 56.99763974835796, 54.451119361385224, 63.64231132691907, 15.155896159910387, 1.505519298295821, 4.820550776297047, 35.06361630655105, 2.3348553190308237, 23.901613758456325, 45.905502457772535, 53.57370868805916, 53.977097003690666, 48.25653976009738, 54.81265206490794, 55.927695612753595, 55.73293424421742, 54.41857545606552, 58.02201378730036, 53.078509453804266, 54.95425355049872, 55.45037454174411, 53.04266291279947, 50.61739867733371, 50.502273190406065, 55.17446717908306, 54.320116120000044, 54.18660648407475, 54.62576681567777, 54.05293210860222, 54.041372883704405, 55.08868102104434, 52.76459432417347, 54.6783697220587, 53.67844773877052, 48.72205841925837, 45.912954961099935, 39.5820455397329, 39.726890825456195, 39.35030406521213, 39.307005020879934, 41.53558984879525, 40.28536965770107, 41.17587712503249, 41.31637642460485, 39.99114874870547, 43.367152367868734, 39.47640434388192, 40.674943385585664, 41.32231881541591, 42.73700791020548, 41.936067765758885, 41.440746938028646, 40.82188321698097, 42.43725645926691, 41.384500149757635, 41.18983291810559, 42.548396818099484, 39.679186959420484, 41.293701202638694, 40.80726846571892, 37.758865125717655, 44.783469246279815, 51.07513535407282, 50.47985684487128, 52.79811489966608, 53.12296167496712, 57.935678497437515, 50.76764898915445, 40.32400108152821, 51.06587856046615, 55.862054747919885, 52.69834549196305, 47.67555436780376, 43.38819588384321, 39.546544167303274, 39.68513327260172, 40.558574507313395, 40.91377650537799, 41.369712814208, 41.41884050061626, 41.92004488360497, 40.1075372388286, 40.936922411764826, 39.126776033832186, 40.92076616902506, 41.25433237321916, 41.54295213760869, 39.85994938881167, 41.524681737346036, 41.239647019294004, 40.37423879869523, 38.44231459402269, 38.344855462351155, 39.70202692093388, 39.40807665548017, 40.503112193076845, 39.467798663723855, 38.01576468252367, 38.34232945596018, 37.74516036433559, 37.690796313747285, 40.064555906480365, 40.58552903513755, 39.04193908937516, 39.46931269861037, 39.40123211952948, 38.853688855325025, 37.971747844449936, 39.52074281630978, 37.86933868162094, 38.725168474258915, 38.8534652802252, 39.689487103492986, 40.0520396232605, 42.49644502516716, 42.56932658533896, 44.768623075177594, 47.181100383881606, 53.10793115246681, 53.38277555281117, 55.489978713373986, 50.68924080940985, 53.49935231670257, 58.432423145540305, 59.035495404274236, 56.958482726927734, 55.930339290249734, 62.871824464490345, 34.32160192920316, 0.8423641732623501, 4.476638830477192, 6.077358588095635, 1.4836067321800417, 0.6693979448849156, 17.26591067929422, 64.84237224824967, 56.00874746999433, 53.981807770267615, 39.06168037845243, 30.857186125170802, 39.34452249157814, 57.17629586496661, 4.733161349450389, 0.1943718894354759, 0.030284945687819875, 0.014548607230667147, 0.1432796318324343, 0.056388097019085, 0.012829589240643527, 0.04373196827908678, 0.01678893368901505, 0.03682239529406352, 0.0036904028186859985, 0.07686961472274796, 0.11871142192713677, 0.17749553936864101, 0.17513111624265873, 0.1529787492848212, 0.15429611407941388, 0.13571722553141657, 0.13020906867759843, 0.1365611939540794, 0.10409383613976742, 0.15509109884019823, 0.11595758864836347, 0.19579168018554488, 0.24267210895496033, 0.14410449402226558, 0.2492321351723325, 13.397198530935473, 70.38481466231808, 50.343283837841405, 50.00612474256947, 47.74023817431542, 60.86430834185693, 64.85713997194844, 66.62715265827795, 57.41802761631628, 70.02197973189816, 18.317351033610684, 2.344735279198616, 7.870876077682742, 31.897169236213934, 6.5052107264918675, 28.766594202287738, 46.17671082096715, 55.25787638079736, 53.01602609695927, 49.29375171661378, 55.874818140460604, 58.82588786463584, 57.33271998743857, 57.5129528968565, 61.29673004150391, 53.87331108893118, 56.506256980280725, 57.24780851794828, 55.41983496758246, 51.60013675689698, 52.22438981456142, 59.228927089322006, 57.43623918102634, 56.28640813212241, 56.51524705271567, 55.412052985160585, 55.69544030774025, 58.54687398479831, 54.9445652961731, 56.9662372527584, 56.09525534414477, 50.94804271574944, 48.192730642134144, 42.516837427693034, 41.07171074036629, 40.446594761263945, 42.269633969952984, 43.374675473859234, 42.9807714493044, 43.952942663623446, 43.76451200054538, 42.37778548271426, 44.55853700637818, 41.71555211467128, 42.406265812535445, 44.45790859960741, 43.67792567899151, 43.47843785439768, 42.214771778352805, 44.17792589433732, 44.234396257708156, 44.81704473495484, 42.84971721710698, 44.07290443297356, 42.19774084706461, 42.25041827847881, 43.884842472691695, 40.114330783967056, 47.43396774415047, 52.46130881770965, 52.10114502137708, 55.33710433590797, 53.94949528478808, 61.09766975525887, 48.367636972858065, 38.89774883947065, 54.54772733872937, 57.46914786677207, 56.80625946291032, 49.61699816488451, 46.009939485980624, 42.964626973675145, 41.883864941135535, 42.62975069784349, 42.371231202156316, 43.50399209607033, 42.44874508150163, 43.73420776859407, 42.916205313897905, 42.25778448966242, 40.38406041360671, 43.502627111250355, 42.23653701043899, 43.77839326858521, 41.601183645186886, 44.653666250167355, 43.21675300598145, 43.91339732754616, 40.537558447930124, 41.33125005229827, 41.15501403808594, 40.54179460771623, 44.01166446747319, 42.75023022005635, 41.35840854337139, 40.54822337242865, 40.03338090835079, 38.8392270764997, 42.65295936215309, 43.086624453144694, 41.82413901052168, 41.76050247684602, 41.83805950226323, 42.7180903188644, 40.233213901519775, 42.61671666176089, 39.90508018001434, 40.80031018103323, 41.61590430044359, 41.770622191890595, 42.1786428266956, 43.428435479441, 43.71146586633498, 47.42154167544457, 48.87873357342136, 55.30627450635357, 57.47132478221771, 58.771410065312544, 50.63606131461359, 55.01841175940729, 62.295996988973315, 62.717471353469364, 57.03394520667292, 57.896831343250895, 62.117015315640366, 36.79582911152994, 2.0828825043093775, 3.6278987219256744, 11.347740504049487, 6.8722636757358435, 1.9156567872531953, 20.44051431840466, 70.20276961788055, 59.831057979214584, 58.0402998770437, 44.93972862920454, 48.91385447594428, 45.836166720236506, 65.30010108024844, 6.323292668788664, 0.3161676732763168, 0.17416941542779246, 0.1419210668292738, 0.18729093875135147, 0.16183305561782854, 0.10934688571480014, 0.1607062934987968, 0.08069309826579787, 0.13375407926017238, 0.08429617065215304, 0.21701945562756833], [0.010451275025374226, 0.08094242158075494, 0.030575310248100472, 0.04828351880273512, 0.01542050721904924, 0.024424269645204468, 0.030022725282657533, 0.023762789111764684, 0.0813482873021595, 0.007125160660624745, 0.05908713585907414, 0.07404960676907532, 0.05970519644418552, 0.028851591351051486, 0.035617561154668374, 1.4944507373917488, 33.563992208050145, 43.65641540096652, 27.912360814309892, 19.93397355079651, 38.149121346012244, 53.31559711886991, 58.09576611365042, 52.36099420055267, 55.81089919613254, 29.236837356321274, 0.25483069040121575, 0.8751560459213873, 3.58704797202541, 26.155621428643506, 26.683943117818526, 40.37440353824247, 50.43555367377497, 54.776566259322635, 51.22858631995417, 48.75127615467195, 56.87417530244397, 52.54511417881135, 54.43315098362585, 50.38727321932393, 55.71087483436831, 53.461105285152314, 51.38244521233344, 51.009165010144635, 47.74181104475453, 47.08296660454043, 51.17923113607591, 52.43204793622417, 51.1746851090462, 52.03410779276202, 52.043407732440585, 51.99793569503292, 52.74320563962383, 52.10327094601047, 51.99795138451361, 48.04701066786244, 43.48523924427648, 38.79311961512412, 38.47900052224436, 36.62923428320116, 38.404812812805176, 40.60923584045903, 41.558178778617616, 40.71057027386081, 39.393881597826564, 39.304988922611365, 40.34569963332146, 39.707122079787716, 39.87266179054014, 39.735167026519775, 42.95369140563473, 41.31498398319368, 39.72189372585666, 39.62312844491775, 39.906315726618615, 41.36622190475464, 40.66307037107406, 40.299729454901914, 40.14028510739727, 39.812865257263184, 37.11068168763192, 35.177137544078214, 37.827447768180605, 43.11769354727961, 48.099146812192856, 46.843062677691066, 48.02188788690875, 50.34835546247421, 56.551148506902884, 44.37648019483013, 46.17489476357737, 55.41017416984805, 51.35035630195372, 50.59643360876268, 45.7645599303707, 40.95221181069651, 36.65094067973476, 38.581343004780436, 36.29525623013897, 39.793947665922104, 39.420781212468306, 39.76745597777828, 37.97699989811067, 38.740034257211995, 39.21592366310858, 38.61765630783574, 38.4096412504873, 38.19189479274135, 39.202462088677194, 39.28208620317521, 37.21623266896894, 37.17387891584827, 38.287220155039144, 38.112980627244525, 36.177718485555346, 36.36549411281463, 37.31438606016098, 37.23711144539618, 38.1523573014044, 38.29729280164165, 36.777833277179354, 35.512963033491566, 36.19374136770926, 35.52178052163894, 35.25076827695293, 36.54402863594794, 36.439705356474846, 37.69278103305448, 38.42615442891275, 37.643300333330714, 38.309593354502034, 38.01650208811606, 38.17172988768547, 40.0274149833187, 36.83325636771418, 37.58985019499256, 35.963800261097575, 37.11383135088029, 38.749106699420565, 42.54522362063008, 45.85633947003273, 50.317533477660156, 53.2247511033089, 54.46656957749398, 51.2707753335276, 54.91504946062642, 54.8153349661058, 58.41478032450522, 58.91949915116834, 56.06312721006332, 12.49889535288657, 0.5195383991925947, 2.0069063166456838, 7.0448175649489135, 0.9882306848322192, 0.052966261883416486, 27.78453665394937, 58.61672355282692, 52.40358329588368, 45.18247627442883, 28.301053970090805, 33.0352488640816, 44.94426681149391, 37.01351281135313, 0.27339220407509035, 0.03474808966500625, 0.08598105080666081, 0.032528024317035754, 0.040504152571121534, 0.026059775432992368, 0.14350814053848868, 0.0638731284397504, 0.05384869941119706, 0.11363220536300253, 0.058279728982597596, 0.06459202151745558, 0.011649734355629453, 0.04428962283136864, 0.04650835135591127, 0.05191477173338494, 0.051175929726131504, 0.04755303098429595, 0.04862917384373085, 0.06281123481570713, 0.023368602400765787, 0.04805075064782174, 0.0525488282343553, 0.04108388194694154, 0.04329281220693262, 0.03658478546346869, 0.06110531788679862, 2.3405025514864155, 43.76488854808193, 51.07737894981138, 28.953824620093073, 30.052474621803533, 44.44483533982308, 56.67299301393571, 63.7073677585971, 55.62687335475799, 62.29280417965305, 30.307520858703125, 0.18122611176823417, 2.6754386434631967, 5.912247396284535, 29.140329399416526, 28.40763065122789, 43.65918067193801, 51.065266670719275, 54.689991704879276, 52.89835106941962, 48.73458646958875, 58.21941883333268, 55.255738689053445, 55.74200276405581, 51.66032944956134, 55.61109365955476, 55.61652221987325, 54.0774037761073, 52.326893114274554, 50.55232655617499, 49.69355890827794, 53.530115465964045, 54.29621319616995, 54.71095285108013, 54.22715202454598, 54.02986464961883, 53.812530040740974, 55.91483416095857, 52.64833134989585, 52.805167321235906, 50.161952664775235, 45.39569631699593, 41.8601228344825, 40.57919440730926, 37.948645084134995, 40.01782086587722, 42.388242521593654, 42.065215726052564, 42.48269319534302, 41.30318941608552, 40.531192441140455, 41.76089079149308, 41.01934709856587, 41.93701697934059, 41.566953120693086, 42.88213952895134, 43.91952406975531, 40.25400246343305, 42.74507622564993, 42.56136417388917, 41.69868984530049, 43.00943220815351, 42.04917323204779, 42.4099136167957, 40.55965315911078, 38.98514316928002, 37.67447533146028, 39.36235750875166, 44.18544507795765, 49.49853866331039, 48.16174784014302, 50.636912468940984, 53.53635987927837, 57.87127317920808, 45.69950742106284, 45.79221656245571, 58.66719661220428, 52.671190923260106, 51.155030112112726, 48.036318286772705, 42.3692504052193, 39.25976399452456, 39.4227227857036, 38.334300364217455, 39.470952249342396, 39.54229624040666, 40.37297579549974, 40.00836795376193, 42.35202335542248, 39.96533955297163, 40.719921204351614, 40.172185744008715, 41.46828982137865, 39.27699104432137, 40.581963600650916, 38.54659472742389, 39.52353946624264, 40.82898270699286, 39.88640969799411, 37.87164503528226, 38.486515783494525, 38.90040820644748, 38.845573471438506, 40.33850600642543, 39.62607022254698, 37.246980128749726, 37.302250246847834, 37.896261830483716, 36.87762229673324, 38.63675040583457, 40.219677802055116, 38.61038031116609, 39.76427493556854, 39.43926342072026, 37.99452897041075, 39.15724108296056, 40.282435724812174, 38.90291852335776, 39.808809526505016, 38.58912498720231, 38.699778972133515, 38.03947541021532, 39.300658625941125, 42.49761389147851, 44.455951336891424, 48.99392966301211, 52.62960987706339, 53.900657853772564, 54.51419499612624, 50.78742165719309, 56.51642768613754, 56.38198060374106, 59.50168871110486, 60.44213187310004, 58.659842168131185, 14.584094997375244, 1.4774251993625396, 5.5463084001694964, 6.310031625532336, 2.1036668987043443, 0.28007147953875605, 29.43426593657463, 64.01308905693793, 56.36016830321282, 51.48051231138168, 34.61899603566816, 36.37499409337198, 48.73118577464935, 44.297369910824685, 0.6668962694464192, 0.07234210403816355, 0.053347551504210125, 0.0161396837492864, 0.03655675047587964, 0.03507050542881893, 0.026558927680936553, 0.06579877087666143, 0.031199556993200418, 0.08335588199477043, 0.02387630035950532, 0.08525332090474906, 0.13735912049249296, 0.22767370086043115, 0.22549704588469, 0.12400349602103235, 0.13983588275169173, 0.11750970576559344, 0.11078336952073921, 0.13796082126998133, 0.1904017613419602, 0.09948950215813615, 0.16781470077412744, 0.09023665390428036, 0.1887654281792141, 0.18217897192845423, 0.16576088033616543, 2.4578669763380483, 50.3105987271955, 58.88398601162819, 37.14469648176624, 28.616259559508297, 48.36746438857048, 62.81819389712427, 68.19313541535409, 61.43908069979761, 64.88447104730915, 36.253761476086034, 0.4635401298442195, 5.019590470098681, 4.638593004595849, 36.37481366434405, 34.507922357128514, 41.266032803443174, 52.16797828674317, 53.87706479718609, 51.985219370934274, 51.979782965875444, 58.71269218383297, 55.72533661319364, 56.643284982250584, 52.035994452814904, 58.20562385743665, 56.92255381614932, 55.92694251768051, 54.8193318613114, 53.15081442556074, 51.37916218849921, 55.63807172159995, 56.3105816994944, 55.86289413513676, 58.22512980430358, 55.606520175933845, 55.41621069754324, 59.52250472960934, 55.92633062793363, 56.00805321047383, 52.92070073466147, 47.69493872119535, 43.40384221846058, 41.64411790909306, 40.682231149365826, 42.98908295169954, 44.52727179373465, 44.474225659524244, 44.73627136599633, 40.698316789442494, 43.32064874710576, 43.41242828676778, 42.3083124622222, 42.7710933070029, 45.020960915473204, 46.101366012327134, 46.696322887174546, 40.94640278047131, 45.11228153782506, 43.944176166288315, 44.860026067303075, 44.896896346922844, 44.57094346323321, 44.26397092880742, 43.940069444717906, 40.417804564199145, 40.558951054849935, 41.00159445116597, 48.94839094531152, 52.29657711521272, 51.46715664094495, 52.92189705756403, 54.68156645374914, 60.44846650092833, 49.14298757430046, 52.68642148663921, 59.07062807390767, 56.10457489567419, 53.926341533660896, 50.48700732569541, 45.646041593244, 42.64422424377934, 42.95009851455689, 40.33551716035412, 43.04814600175427, 42.15230018861833, 42.81318033895185, 42.037543404486875, 43.345595021401685, 42.894510684474824, 43.313219777999386, 42.9370762455848, 43.059740527983635, 40.714127863607104, 43.81672266990908, 40.953647398179584, 40.33756855995425, 42.46654871971377, 42.51144809107627, 40.52897237962292, 41.38413929170178, 39.99457690023607, 39.385232771596606, 41.3806797612098, 43.20377780545143, 39.301266593317834, 39.294202404637495, 40.51589911983859, 38.97856535450105, 39.9350941565729, 40.38365248710879, 40.10335599222491, 42.097696873449514, 41.642956887522054, 40.24673431150375, 42.98517627100791, 42.43494618323542, 42.44485801266086, 43.37311044816048, 43.0858439014804, 42.08180735188146, 39.89202260971069, 41.27361866735643, 44.14145177410495, 47.19001593128328, 51.09629654115247, 54.11948296331591, 55.85758324592344, 56.38280037910708, 50.7612516034034, 57.13381659600043, 58.73746195147115, 62.010134650814926, 61.7996524226281, 58.4445511141131, 18.27270269393921, 1.8867962326734298, 5.7299630872664915, 15.987886767233572, 7.561838905657492, 0.6937803784685751, 33.26655887788342, 70.43020432995212, 60.05734735919584, 56.379015291890795, 40.18654161883939, 43.64744886275261, 57.88419346655569, 52.372945662467714, 1.8692647088919918, 0.22533463524474254, 0.2082170900558272, 0.12636589667489453, 0.12201879203559891, 0.15949097161571826, 0.20270747763495292, 0.1461203931079757, 0.07244399373209284, 0.2882972107298913, 0.12262447647029355, 0.16157879103575984], [0.04035940025782874, 0.023897206898958936, 0.04617723283327876, 0.06018516968094534, 0.022466987777020664, 0.011259461396313723, 0.025829924157850688, 0.06820971852228527, 0.01670863426801178, 0.01019765682999165, 0.0334168471876652, 0.017488550079325517, 0.056830547269313574, 0.05080856758380129, 0.10034127701674739, 0.14975915753072308, 15.529407781939353, 51.87517335337978, 29.067561587979718, 30.872097015380863, 37.75821008989888, 52.76216245466664, 56.25673540176884, 54.98418515728366, 52.694815358807965, 41.0642856936301, 0.1690930410498573, 5.247696888062262, 1.908441709895288, 4.425465137727799, 15.106333090413003, 38.5984484611019, 60.71919633496193, 49.92274299744637, 61.40100233016476, 44.90469401882541, 54.036058072120916, 51.96286970569242, 54.84277586783133, 53.7539259079964, 56.616612865078835, 50.377545741296586, 51.431972980499275, 45.62170720869496, 45.74361055128036, 45.81888083488711, 50.34974398151521, 49.68259588364632, 50.668820950292776, 51.76510772397442, 52.67132428384597, 50.385978837167066, 52.468341627428615, 51.42399487956878, 50.79745508009388, 44.63081844391362, 39.02566517553022, 39.93292116349743, 39.351751419805716, 39.3148026927825, 42.12417679448282, 42.308316384592366, 43.48755736504832, 40.687114500230365, 40.27008810350972, 38.29482563080327, 41.10387417577928, 40.410477576717255, 38.747698568528705, 41.9176757720209, 40.68083086321431, 38.02577457120342, 40.953592484997166, 41.966893672943115, 39.24857347242294, 39.390563272660785, 38.51975394833473, 40.474055274840325, 39.90341709506127, 39.93871842661212, 38.13798965946321, 35.73424746913295, 36.38756528977425, 40.16141099314536, 44.82533270312894, 44.90428609232749, 49.712201933706964, 52.343296466335175, 56.96653927526167, 54.506185516234375, 52.98284284530148, 54.94038012719924, 55.025683833706765, 47.1281954549974, 46.02986120408582, 41.70072555541992, 39.80018031212592, 40.179669626297496, 39.64239512720416, 39.14911000959335, 39.126407331035985, 39.63649980483517, 37.43156294668875, 39.565885374622965, 39.00837144544048, 37.57424308407692, 39.644725015086514, 36.80578408702728, 38.23550762668733, 39.22336439932547, 37.91018624459544, 37.101009122786984, 37.82221924874091, 39.804816553669596, 37.50187535439768, 38.84673841537968, 37.64507716701877, 37.934077401315015, 37.92527560264834, 35.92272912302325, 39.368260675860995, 36.43538682691513, 35.719503279655214, 36.71323184044131, 37.21837428308303, 36.70601860169442, 36.63068948253509, 39.74307452478717, 40.29271233466364, 42.5709935926622, 46.51538787349578, 47.66752135369086, 48.37097883224488, 46.26924345570226, 46.55462726469963, 43.25015198799872, 43.229461485339755, 40.39891442944927, 37.495591717381636, 40.12972216452322, 42.723087418463926, 48.662446237379505, 53.33362433218187, 52.33459664929298, 50.171327129487075, 51.104419769779334, 57.168070654715265, 55.5339837843372, 59.26723295642484, 31.284808804911954, 2.1783507879703277, 1.6578446665117819, 7.180747303270525, 4.979872549733808, 1.4120302181090079, 0.1491683352017595, 39.96310380197341, 53.832534128619784, 51.442688895810036, 36.01449297320458, 24.63870752242304, 23.424663351428126, 42.6655815493676, 16.294727902258597, 0.17429085568554942, 0.05204574595535955, 0.053695638874365445, 0.047076401721325614, 0.037018069471683235, 0.06340611358022978, 0.03110738512459061, 0.038126273110749266, 0.03177258501490278, 0.03708061672026112, 0.008680175505428305, 0.05283692708959984, 0.039525184134442004, 0.0339289578128486, 0.016944077985000708, 0.029117868191772894, 0.02839141382625507, 0.02431370975119212, 0.033342283849994984, 0.0667634287909154, 0.04095209567176719, 0.027593230648386865, 0.055646845665309703, 0.09431533665666658, 0.030560055522308237, 0.022958226336707032, 0.15063864178955555, 0.11613499928986835, 21.93777518887674, 59.50526199033184, 27.760321901690578, 24.07870092699605, 50.436236166184955, 56.13292186490951, 62.2829786423714, 57.48973638780656, 58.720811490089666, 43.5271458471975, 0.10675813672283005, 4.2772985850611045, 5.049664753098642, 7.451850743063035, 17.971072427688107, 40.89494912855087, 60.438170279226, 48.61594261661653, 62.15436020205098, 46.77438589834398, 53.94532188292473, 52.28886965782412, 54.43031510999126, 54.1718073814146, 59.38207211032991, 52.19987892335462, 51.89783680823542, 48.233323251047445, 47.956572578799346, 48.78184318542481, 52.3663168568765, 51.36334326959426, 52.05329602764499, 52.95290339377619, 54.5233811870698, 53.266967573473536, 53.79113351145099, 54.18268411390243, 53.045953781374045, 46.82815374866609, 42.23259502841581, 41.52782747822423, 40.607372714627175, 39.95877350530317, 43.505031524165986, 45.771110288558475, 44.50731869666807, 42.76329955747051, 41.79951437057988, 39.62100644265452, 41.4478660398914, 42.448054744351296, 41.79757279734458, 41.53114972576019, 42.22072593627438, 42.03442119782971, 42.62210599837765, 42.134971157197036, 43.16839410412697, 42.079818710204094, 40.01874654523788, 40.87714549033873, 41.19010356164748, 42.20453046983288, 39.81290055859474, 38.60317099478937, 39.45494897903935, 41.561548094595636, 47.82608316790673, 46.364239338905584, 50.52456402009534, 53.050805753277196, 57.099966541413345, 54.51886653900147, 53.960838779326416, 54.7347459485454, 54.67265482871763, 50.207538450917895, 47.71485651693037, 44.70988558184716, 41.343515303827104, 41.70983722133022, 41.58533334732056, 40.54195542489329, 40.490042855662686, 41.48778400113506, 39.313582835658906, 41.20840534087151, 40.86713952402915, 39.42489185640889, 41.70878994849421, 40.14534888728973, 40.01090572726342, 39.6509890402517, 40.131165596746634, 39.391708604751095, 38.08127610914169, 40.44576321878741, 38.56108396284042, 39.52556340925155, 39.47228193283081, 38.968053402439246, 39.86520928721274, 38.20826284347042, 39.50269991351713, 38.644508854035415, 37.745152519595244, 39.72541993664157, 38.27811241149902, 38.71542530675089, 38.13184330540319, 39.99778147666685, 41.56474874865624, 45.291714283727835, 47.135769551800145, 47.86029408054967, 49.919220709031634, 48.8371289930036, 48.411853851810584, 46.09923616532357, 45.43475527917185, 42.157050178897, 38.885526734013716, 42.033856376524895, 44.6838528110135, 52.59132362181141, 55.756833245677335, 55.90486349598054, 50.36444894729122, 51.20658182328748, 58.3112689756578, 57.10426938149237, 59.80233054007254, 35.50436519807385, 3.6488542297194084, 4.631406732143895, 5.609871389404421, 4.046938275137256, 0.46806351131489204, 0.13228490648250427, 41.78149107963809, 60.55675137427546, 54.353644540233, 48.38125151972617, 33.719898577659364, 26.144558383572488, 52.11770526824459, 22.22857382989699, 0.13388020797602593, 0.02372719092114318, 0.10641586396002001, 0.05424009373171195, 0.028752543843321265, 0.036918094997564634, 0.008290657142717994, 0.023859580490557898, 0.013354024305308779, 0.075169772871079, 0.07976564158114695, 0.045934314013368664, 0.16434441440768782, 0.09303956277548306, 0.13554845636169757, 0.18764197556001527, 0.07562445371501869, 0.03381717026293759, 0.13520694968681182, 0.16877445572566602, 0.17715478345992106, 0.1426917972463754, 0.12922345059773616, 0.13865094391569016, 0.14186736406578174, 0.13945761917819902, 0.1449959598962338, 0.18304633667632458, 26.60173220019187, 67.4118463454708, 38.12399856505856, 44.79657780739569, 51.623321886985536, 64.24939224796911, 67.52852901335686, 63.3732485002087, 62.37149084767988, 50.54144590131698, 0.16904191234179083, 12.83638490784553, 6.178080641454266, 5.698715034992465, 20.3541241153594, 41.21341420758156, 59.57078126169021, 51.67981578457741, 60.02874935826948, 47.56231161855882, 56.674001063069994, 54.089421918315274, 55.030457358206476, 55.12180543714955, 62.64179706573487, 55.382584218055975, 56.27491166514736, 48.79275521924419, 50.454247690016224, 50.71218275254773, 54.08051813802412, 54.86691021150159, 53.85435819625855, 54.95455949537216, 55.84540820890858, 55.12489234247516, 56.611086245506044, 56.01618428384104, 55.70656807191911, 49.355940895695845, 43.43842967864006, 45.092434344753144, 42.500312482157064, 42.56135632914882, 44.881956038936494, 46.02708416600382, 44.743857229909594, 45.450762471845074, 44.2789779170867, 42.22957872575329, 44.7892508199138, 43.35837018105292, 43.02668279217136, 44.04778165201987, 44.13583101764802, 43.32883081128521, 43.686664719735425, 45.86468627375942, 45.461137140950854, 43.30439836748185, 41.91220798800069, 43.082329457806004, 44.51405340625394, 43.54946805584816, 41.800341990686235, 40.136652992617705, 41.18432983275383, 45.40523552125501, 51.82976407389487, 48.96333909803822, 54.054669718588556, 55.63774616487565, 60.68457357345089, 56.27578243132561, 53.67083834063623, 56.974423239308024, 57.451661940543886, 50.939742980464814, 51.498472844400716, 45.73960581133443, 45.33595861927156, 41.991228057492165, 43.18661743594755, 44.431989577508745, 43.21672554939024, 43.89691552808208, 41.51906098088911, 43.08654992811142, 42.80046009248303, 41.156783027033654, 43.861845616371404, 41.59173857781195, 42.62606759225169, 42.38583026393768, 42.64894677746681, 41.123015342220185, 39.495890678897986, 44.57816846909062, 41.00909402293544, 42.398491674853915, 41.70684445288874, 39.895509596793886, 41.37805569556452, 40.17526480459398, 42.68422065242645, 40.715269273327245, 39.37009242273147, 41.12426657830515, 41.27536804445329, 40.55395395525041, 41.24973143300703, 43.451491171313876, 45.48631483508695, 47.077561578442975, 50.12854976038779, 51.32563752512778, 53.87420931170064, 51.64565586274671, 51.586718328537486, 48.02026794802759, 48.417023535697695, 44.39594691799533, 41.14840876671576, 43.977959540582475, 47.43784304588072, 53.94011297533589, 58.370885079906834, 57.387017357733946, 52.10886816824637, 50.68434176906463, 58.42692790492889, 57.73656722038024, 61.325696745226466, 37.030869299365634, 5.799460622572131, 3.513873214683225, 15.461709633950266, 15.954108295902131, 6.518295753386713, 0.357571967667149, 48.39550541293237, 64.33279752731323, 59.700882357935754, 48.58821538186843, 38.37111180828464, 35.699656086583296, 57.653903268998675, 26.96364341243621, 0.33724189405479743, 0.15201076654897583, 0.19542346768561872, 0.2678325507910021, 0.13524177604384963, 0.17638808266530115, 0.12344524008972992, 0.13724992231976602, 0.15019651712669482, 0.12304334270377314, 0.1960577425216475, 0.170988020817599], [0.03349753156785042, 0.029077334479699214, 0.05311745316571286, 0.1034328708004567, 0.04831526165587768, 0.06510597458409687, 0.04656704518223002, 0.045915556350542654, 0.024203228381192012, 0.025850677479719444, 0.058056605874650904, 0.01652118595947902, 0.05491861397580755, 0.059451697950041106, 0.01632335141391283, 0.130374038051213, 3.838433166665416, 41.08155588949881, 45.71594215208485, 31.302643822085475, 25.964013645725867, 49.63676298818281, 53.68110710574735, 55.37290773084087, 49.426041495415475, 47.864596920628706, 1.3593298653441093, 3.7217656979637765, 4.045196497632611, 0.26682254047163073, 1.7011899212675712, 45.648010623070505, 62.22992858579082, 54.68756375774261, 55.01019831626646, 59.95778975948211, 53.26497108705583, 55.591313146775775, 56.55207418626355, 54.533234180942664, 51.66467151334209, 49.80888051371421, 46.744654332437825, 44.83872367489723, 45.63955399297899, 46.10169549142161, 49.1128598490069, 48.70518046040689, 49.09925706924931, 50.572334566423976, 54.07485815786547, 50.24797808739447, 51.60798149724161, 51.87676583566974, 47.765757114656516, 40.35825514024304, 38.667921481593964, 40.029399702625895, 41.43980949155746, 44.76768170633624, 43.076551806542184, 40.671409330060406, 38.95774149125622, 38.604720331007435, 39.26679680424352, 38.06743798717376, 40.11316584002587, 41.13870874527962, 40.4121288945598, 40.26603629512172, 40.29556782014909, 38.937694257305516, 39.54422212416126, 39.33319076415032, 39.3523201634807, 38.53275660545596, 38.09138797944592, 39.47059139128655, 39.50765386704476, 40.687675399165, 38.98909691841372, 37.09593749815418, 36.755605205412834, 36.492320029966294, 41.38406476666851, 43.344312406355336, 45.44180377837151, 51.07365662051786, 54.86641599285988, 55.57967155210434, 53.327658407149784, 57.28153697906002, 50.265067854235255, 45.882132976285874, 44.46907166511782, 42.34737534676829, 39.45281520966561, 41.27880404072423, 39.569219389269435, 41.32045176721389, 40.04443414749638, 39.009344193243216, 39.4819466529354, 38.876666099794456, 37.62806976995161, 39.67890454876808, 39.71625335754887, 39.64123410563315, 39.024319802561116, 38.11263153629918, 38.707588411146595, 38.63026280556956, 39.21899487895351, 36.84753379514141, 37.49509357636975, 36.86811447143555, 37.287360929673724, 36.851962151065955, 37.0146502987031, 37.16222163169615, 37.00966104384392, 36.66073091568486, 36.15950692084528, 36.9915279265373, 38.160013767980764, 38.965060633997766, 38.854065402861565, 36.973441877672755, 44.20161701017811, 49.22752641862439, 50.8072570831545, 49.613558246243386, 49.25590084445093, 50.264067649841316, 50.63621036468014, 52.30685764743436, 49.689538478851325, 50.68544395508305, 46.64252365789106, 44.20713578501056, 40.94369242268224, 48.776700958128906, 51.28317002327212, 53.62714313691663, 50.97750756048387, 53.28988598239038, 52.399005889892585, 52.14803695678712, 47.28959314284786, 8.449876750669173, 0.4411227117863394, 0.8514759004596741, 4.037701093381451, 1.7765543417584513, 1.574370132819299, 0.4206010549058838, 43.58463602681314, 54.47156667709351, 49.075471816524384, 27.927044207049956, 18.217346283697314, 28.896297177960797, 42.76549216239683, 1.8881943124917246, 0.2703450433909893, 0.04742591784545972, 0.03894175455394772, 0.014047779165388597, 0.018376108904879902, 0.10540336385489472, 0.04124666413953228, 0.034959411188479395, 0.04922091547820357, 0.021406291165359078, 0.01708466852564485, 0.03524371790849874, 0.06050324172622735, 0.04912061924715677, 0.014757036772226135, 0.03316045671160663, 0.06825921546307302, 0.055454480987522876, 0.14838520948204303, 0.01467573569126187, 0.048784781622910695, 0.016780985526800636, 0.03354375348276189, 0.029308961163605415, 0.06740194009316545, 0.04209520227666344, 0.10499248791846538, 0.12483176730212667, 5.603382808546867, 53.61933762027372, 45.32601933325491, 34.08962119010187, 40.359616202692834, 57.563480869416274, 58.864201576479026, 59.84829287375174, 55.26881587120795, 52.14646016397784, 1.2206256629959231, 2.4283352061625454, 6.918398593702625, 0.762112602110832, 2.9092807923593833, 45.43340598383258, 63.12709231530467, 55.65880929270099, 55.24849014897501, 60.064019310858946, 53.51166855904364, 57.169835721292806, 57.7821373170422, 56.84745219445998, 53.47508461244645, 51.49883762482674, 49.339772885845555, 46.94204368898946, 48.74714197651033, 48.90149116516114, 50.45327101984332, 51.78543344620736, 51.89044706283077, 51.80603765672254, 55.63619682865759, 53.41482523948916, 55.043028554608746, 55.08538623009959, 50.735430640559045, 44.702582128586315, 41.759106113064675, 41.1532489715084, 40.32562102040937, 45.66269597699566, 45.78426591811642, 43.67872584250666, 40.80240080433507, 39.75972498616865, 40.85080285226145, 40.14767485280191, 40.75838396626134, 43.322868808623284, 40.846896171569824, 41.580053837068625, 41.51184381977205, 40.9136196105711, 41.108145636896936, 42.17672478768134, 40.19102488794635, 41.32651182913011, 39.74466308470696, 41.07411515328192, 42.00811778345416, 43.274137281602435, 40.186718125497144, 39.44737488223661, 38.84261208195841, 39.87488969679802, 43.283394075209095, 45.12032631904849, 46.571917072419204, 50.916420567420225, 56.36669904954972, 56.76801635373024, 53.61013966221964, 57.787193252194314, 53.20625712794643, 46.79934393975043, 46.721229937768754, 43.51022866464431, 41.93432623340238, 42.52333287269839, 43.34228454097625, 42.791085627771196, 40.952184354105306, 41.10054408350299, 40.476765632629395, 39.774312280839496, 38.94804146982009, 40.85382699966431, 41.44961149461808, 42.00707051061815, 41.6028820314715, 39.49168197570309, 41.153021474038404, 39.99234114923785, 40.06185731580181, 39.818937086289935, 40.268009247318396, 36.738056521261896, 38.615483314760276, 38.99725152600197, 39.03112119243991, 39.16667438322498, 39.15529166498492, 39.09887229242633, 40.074769758409076, 39.12690547204787, 40.86344465132683, 41.39315289835776, 40.32190261348602, 39.38533867559126, 45.551700745859456, 51.497994315239694, 53.29265517573203, 52.84976859246531, 52.15671323960828, 51.28429966588175, 53.828933392801595, 54.40415290094192, 50.517868534211196, 51.624337780860166, 48.56386138546852, 47.21380902874855, 43.527318431485085, 49.78475793715447, 54.067421344018754, 55.53459175171391, 52.483407451260476, 51.77768284274686, 51.908784143386356, 50.73648968050557, 51.272732596243586, 10.738157110829508, 0.6591182093947165, 4.1733494016432, 2.1178440605440447, 0.675468425596914, 1.09148150249835, 0.43010247570853083, 48.15156536717569, 60.364798422782656, 52.310277954224624, 36.732243568666526, 23.993577649516446, 30.59144162362622, 49.208094996790734, 3.699263795729607, 0.36410792340194026, 0.07945744440920892, 0.048759439434375496, 0.04336233851650069, 0.07079668252939178, 0.03454959628382518, 0.06354457631166424, 0.020234128760714686, 0.055431996306945244, 0.07266632776947753, 0.08715754735373682, 0.02460486721247435, 0.17323929275716507, 0.14278535190368855, 0.20568732983402668, 0.1942609292605231, 0.11364925081931776, 0.13086821072764937, 0.26353167189705756, 0.16644527264420064, 0.1503087336858434, 0.11796884524125247, 0.20325538371839832, 0.06876543104167908, 0.1716383375347622, 0.14741201734831258, 0.20841228925893385, 0.4051721973284599, 7.008894537725757, 60.193539896318995, 56.061103267054406, 42.62129406775198, 39.28640081036476, 62.807787849057114, 61.42901982030561, 65.64977253637007, 59.16439625524706, 58.69378635960241, 1.663728099196188, 7.559843399832326, 10.169291842368342, 0.7493820594203088, 4.672337645484555, 49.485606608852265, 60.3656142757785, 56.115212363581506, 56.227458830802675, 60.07036178342758, 54.10274228742046, 60.05939483642579, 60.898840888854004, 59.73696816352106, 56.43360683994909, 53.20682587162141, 51.04732182718093, 47.81638706884077, 51.26342481182468, 51.25147334990963, 53.637298153292754, 53.29937811820738, 53.891832520884854, 55.70832921612648, 57.94342910089801, 55.84644371463407, 56.91140251774942, 56.97876530308878, 53.54998227088682, 45.32242644217707, 43.11892124914354, 43.619329390987275, 44.563043809706166, 47.823270828493186, 46.9636873276003, 46.132580234158425, 44.17912613961005, 42.967302030132664, 43.461638342949655, 41.586137433205884, 43.52646727715769, 44.378323708811116, 44.17305038821313, 44.07375558730095, 42.66187098718459, 43.25279566549486, 43.85824880292339, 44.13211261072467, 42.584976842326505, 42.41456554782006, 41.51756263548329, 43.73911857604981, 43.868031194133145, 45.06329113437284, 43.67496428951141, 42.877271867567494, 42.54707890172159, 41.738745089500185, 45.47445751005604, 48.12671715213407, 47.86745632848432, 54.30538369763283, 60.47042785152313, 58.10203406118578, 54.93287271068942, 61.99106800940729, 56.07834600633191, 49.12797666365101, 49.432070178370324, 47.39046865893949, 42.98844360536145, 46.26940035050916, 44.800923793546616, 45.943600439256244, 44.146448873704486, 43.60933126941804, 43.19132035778415, 42.20753892775505, 39.86954350625315, 42.37190584982596, 43.24550005697435, 44.30716406914496, 44.538348567101266, 41.15426486538303, 43.47004005985875, 42.15445356984293, 43.09932901013283, 41.608098783800685, 43.305249521809245, 38.604347705841064, 40.410387362203295, 41.25438728640157, 40.63625704857611, 41.70101973318285, 40.24124691563268, 42.67829395109608, 40.68678502113589, 40.37869853358115, 42.35808341733871, 43.47841039780648, 42.81521997144146, 41.94379483499835, 48.60144553645965, 53.4287182746395, 55.51469749019992, 53.8033869958693, 53.24952871568742, 53.92305458745649, 54.25309065849551, 58.10216742177164, 54.34688237405593, 54.89737918300014, 50.845409977820616, 49.353214848426084, 44.74233535028274, 54.05981586825464, 57.65025938710859, 58.70779314348775, 51.96606251501268, 53.69937750601, 51.29855355908794, 50.43098411252422, 50.08852981751966, 15.030736269489413, 1.1662660250740668, 2.820778147828195, 13.110549757557532, 7.789426099869513, 4.331130664194784, 0.49586983698029674, 54.388243767523, 64.34296431079989, 58.232590152371316, 36.72665419117097, 28.62191757848186, 39.41172053737026, 59.82016947961623, 5.322704863163733, 0.5685094972291301, 0.21703676921465706, 0.11776515012306553, 0.1162919324011572, 0.16570202946182222, 0.20192308020928215, 0.15555521022648583, 0.12082386341306472, 0.18555000394342408, 0.17707734729253477, 0.1835073530673981, 0.09547176170012645], [0.04019540764631764, 0.013409535036302142, 0.06500003228504812, 0.07243785736781937, 0.025867056439540563, 0.05006841556619733, 0.028158549910351157, 0.06913038000704781, 0.05254192195171791, 0.03849905532514376, 0.009818736336103851, 0.0478359587460516, 0.033639809417147795, 0.0355969304068675, 0.07053596748700065, 0.06767900345186073, 0.5189063460115464, 27.867657561456006, 49.00685387272989, 27.819088812797304, 29.28898330657713, 39.810970752469956, 50.89982894159133, 57.2105420789411, 50.03886084402762, 55.28163809930125, 2.2509634206371922, 2.5549824103232357, 8.376967733906161, 0.5621403648007302, 1.1448109053796338, 38.874316600061235, 59.70566764954598, 53.79943716910578, 55.49052392282794, 55.5089198389361, 59.2417924634872, 54.394849038893184, 51.68898236367011, 50.66927202286259, 49.89050895937028, 43.73690635927262, 42.56315669705791, 43.56199610617853, 48.21100496476697, 46.64737170742404, 48.23967356835642, 49.7030431993546, 50.421084050209295, 51.46995721324798, 50.82485675811768, 51.15338271664035, 52.567856081070445, 50.30921805289484, 43.96378017240956, 37.122382117855935, 42.24824136303317, 45.018697707883774, 45.16064436204972, 42.030428224994296, 40.14064596545312, 38.19640944080968, 40.998060395640714, 41.27413249784901, 38.71633137426069, 38.341666575401064, 41.42836793776482, 39.52665775052963, 40.3093941750065, 39.798156369117, 39.609925746917725, 39.661661809490575, 40.50730912916122, 38.71827686986616, 40.77658376386089, 38.84467132629887, 39.82492654554306, 39.17186367896296, 39.47103461911602, 39.63169490137408, 36.94906826942198, 36.95835251961985, 34.97118957581059, 37.31717878772367, 40.512561182821955, 42.350485786314934, 45.72073921080559, 50.1763673751585, 55.33128353857226, 55.61520822586552, 56.87845853067214, 55.14128392742526, 52.73138361592447, 47.98778680063064, 44.61789815656601, 44.932425175943685, 42.824527755860366, 42.4921892535302, 42.853180669969134, 43.12451454900926, 41.02730951001568, 39.24228199066655, 37.9127279404671, 40.07259676533361, 37.150227023709206, 39.505327901532574, 38.3026978277391, 39.37764298531317, 36.972516198312086, 38.273523238397416, 39.22536873048352, 40.03315733325097, 38.9756824124244, 38.39028827605709, 37.41463007465486, 37.72785094476516, 38.37000962226622, 38.280159888728974, 36.561808739939046, 36.9282953969894, 37.03368163877918, 37.07716111213931, 36.03294380249516, 37.484130551738126, 37.431982640297186, 36.329047449173466, 36.124221278775124, 37.08462930494739, 42.17737982350011, 49.86765723074637, 51.370807540032175, 51.45289882536858, 48.30613813092632, 50.94630902813327, 44.51155877882435, 48.158264775430005, 49.43008153669296, 51.034495676717455, 50.42054276312552, 51.54995787528254, 47.358493497294766, 49.903801871884255, 49.413329093687, 55.3380496271195, 48.36541298897036, 55.89947023699361, 39.743972747556626, 51.91466377627466, 24.624673281946492, 0.11137501156378178, 0.08613119637894054, 6.3419675634753325, 2.2240760634022374, 0.6526285253705517, 0.5468607105074391, 2.2267805376360497, 51.510310557580766, 55.202163034869784, 42.36100558311709, 28.561214977695098, 26.643893757174094, 38.285627672749186, 32.61405494905288, 0.2851772410494666, 0.012179252413672306, 0.04966979320611685, 0.012212905698576042, 0.03202540743645401, 0.05903784959246555, 0.07506804405561379, 0.01645349634570941, 0.04318172562747233, 0.0202074823074884, 0.02473314288973568, 0.05954968059555658, 0.05358957017080919, 0.030455243202947804, 0.023464581726359266, 0.06510697815927767, 0.04967660755820332, 0.06418281565270116, 0.05543396898335027, 0.10701297587084194, 0.07341769148385333, 0.050175338457789154, 0.06110857376047681, 0.039285869758215644, 0.04723895791797869, 0.013070341946947719, 0.0755943694422322, 0.05372992130897699, 0.1272511648975553, 1.0733113678232318, 34.75017970608127, 57.6084469210717, 26.83685671898627, 31.48934668110263, 52.609841131394916, 55.05859644182267, 64.92468318631573, 51.55131893773233, 62.42445068974649, 2.3314708038683865, 1.5620581805706026, 6.414728020468067, 1.917212865044994, 1.5016164174002986, 41.26599357974145, 59.1769439174283, 55.85186050784204, 56.737614062524614, 57.92005177467101, 59.97154158930625, 55.469515708185014, 53.53540282095633, 53.97915624803113, 54.838841730548495, 46.64375528212517, 46.03210872219455, 46.53642746710008, 49.28878207360545, 50.028882334309245, 50.534824940466116, 53.62192246221728, 51.75479973516157, 54.009817415668124, 53.170077185476984, 53.845878031946, 53.68590024209792, 52.810874369836625, 46.25047491442773, 39.52963875186059, 42.45066704288606, 45.83582155166134, 45.717071794694476, 44.42594912744338, 40.69490040502241, 39.87091633581346, 42.64633447893205, 42.38179806740054, 39.885519319965, 40.610722418754335, 42.369254327589466, 41.6378774181489, 41.93451450717065, 42.66562077306932, 41.76432286539386, 41.381091610077895, 42.45075725740002, 41.28526026202787, 42.050130290369836, 41.68206291814005, 41.33189332100653, 40.45276857191517, 41.39256846520209, 42.022654087312766, 39.54353963175128, 40.14905552710257, 37.84654971091978, 41.00774472759616, 42.24934747142177, 45.06022384089809, 48.83623861497449, 52.56984864511798, 56.59485155536283, 57.84984134858655, 61.010604904543975, 56.466711644203436, 52.831160868367846, 48.02941491526943, 45.87060120797927, 46.84982876623831, 44.49176257656467, 44.40953793064241, 44.680208929123424, 43.964623481996604, 42.61279429158857, 40.23129194013534, 39.67314650935512, 41.16682821704496, 38.336081120275686, 41.2249695101092, 38.55721650585052, 42.423755661133804, 38.867864301127774, 40.56016698960335, 39.46877141152659, 40.968230770480254, 41.0320948016259, 40.39589812678676, 40.35141060429235, 38.35863082639633, 40.17284077982749, 39.142720468582645, 38.644975616085915, 38.66774497493621, 36.87311157103508, 38.50316232250583, 38.658523482661096, 39.32151386814733, 39.84857451531195, 39.91169329612486, 37.76514876273371, 40.29079821801955, 44.68020108438308, 53.3586568986216, 53.50045450272099, 54.08724500286964, 49.13666863595286, 52.24865751881754, 46.365612168465894, 51.63443788405388, 51.38959569315757, 53.49592808754214, 52.400092386430316, 53.830537642202074, 49.65783396074849, 50.83611396051223, 53.37150266093593, 55.77595087789721, 50.80753164906656, 55.231651413825254, 42.2250013197622, 51.02714515501454, 28.766364743632657, 0.39274689471048696, 0.4982803173122868, 1.4281257866851746, 1.5103608514032059, 0.08923732285057345, 0.317096907284952, 1.8638785592009945, 56.53754572714529, 58.37497218962639, 52.005878494631865, 38.2953159270748, 22.765966000095492, 42.42923521226452, 41.07534677751603, 0.49106937682917046, 0.11551223875534151, 0.07893715579543384, 0.044922365491548856, 0.03186008566239428, 0.03650034342201487, 0.010262957207047412, 0.019483318544864174, 0.024472083107778625, 0.05676837157337897, 0.027031577117140257, 0.019667486081861203, 0.05640344176020834, 0.24992694627613793, 0.07547100630378531, 0.1550468496016918, 0.15998914327111938, 0.20100231913308944, 0.16475022650293766, 0.18723930442525497, 0.152293790071722, 0.24448205296310688, 0.18314056549101107, 0.11073335164016294, 0.11903318651621381, 0.14494575049367645, 0.13575174545328464, 0.291912226426986, 0.21157053269205556, 0.9350321297684024, 44.99867008578393, 64.27083976807134, 37.57875380977508, 39.763121758737874, 52.40319105886644, 60.21754872414374, 68.59379768371582, 58.74937811205464, 69.19532452860187, 3.030462173684951, 6.4675280259501555, 21.92388411491148, 1.9954675820565995, 2.6868885322924587, 45.77078473183417, 60.80653182921871, 56.01684716440017, 56.640143163742565, 58.13449951910204, 62.24439428698633, 57.60107286514775, 55.76454462543611, 56.27275436155258, 56.777331982889486, 47.572607840261156, 47.2911464014361, 47.787043817581676, 51.767892606796764, 51.32701427705827, 52.466698154326416, 56.05601595294092, 55.59460401535035, 56.78824401670887, 55.14915220199093, 55.84920506323538, 57.335206770127826, 55.71911181173017, 48.8328928332175, 41.67871321401289, 46.429664473379816, 48.771958812590576, 48.24693387554538, 46.751161544553696, 43.7166630068133, 41.824695987086145, 46.41523799588604, 45.203178544198316, 41.68094112027077, 42.27109701402726, 44.151551877298665, 41.66841699231056, 44.35738609683129, 45.733886995623195, 45.27572670290547, 43.58517339152675, 44.67068149197487, 41.698113256885165, 43.38696818197928, 43.03156222066572, 44.643393562686065, 43.520524886346635, 45.0594432892338, 43.94492533899123, 41.832128878562685, 44.00380011527769, 40.0615043024863, 41.76123596006825, 46.32717686314737, 49.26700507440875, 49.30468728465419, 53.16102827748945, 57.74989935659594, 59.90509271621705, 60.10619263495169, 59.195896810100926, 54.901485904570556, 50.94580696475122, 47.16937249706638, 50.714179238965436, 47.021707027189194, 45.892629238866995, 46.13585149088214, 47.37930951579925, 44.569676537667554, 43.65572898618637, 41.427497171586566, 44.59229292408113, 39.73685364569388, 44.11691734867711, 40.81996910033688, 44.44989911971554, 40.38255030109037, 43.04398436700144, 41.23072362715199, 41.4188208887654, 44.02712252832229, 42.14566353828677, 42.318408643045736, 40.90950896663051, 42.81470221857871, 41.34424878704933, 40.49460457217309, 41.40697533084501, 39.92434293993058, 41.48400283628895, 42.0313342925041, 41.38369214150214, 41.81507833542363, 42.020555619270574, 39.390280862008375, 40.61274243939308, 47.430323862260394, 55.0166819941613, 56.423408677501065, 57.69559021919005, 51.40575193589734, 54.15974609313473, 48.17100855611986, 51.388026745088645, 52.08531433536161, 56.130027155722345, 54.27309082400415, 56.46353452436386, 51.863559215299546, 55.0664411821673, 54.87666122374996, 59.323154187971554, 49.78271830466486, 55.035093599750155, 42.72648026866298, 51.572013362761474, 33.694305112285, 0.9583554621185026, 0.33728470304800623, 15.059731410395715, 11.532699869525048, 1.0488352876517082, 1.104798929825906, 2.226668259789867, 61.58158040815785, 63.015328299614694, 54.767795839617335, 39.62360305170859, 35.65042641855056, 49.601343985526796, 49.54719566529798, 1.1099420151402875, 0.18301995260821236, 0.16533665148721588, 0.12708490849622797, 0.106349068753902, 0.11424961860381788, 0.19208333965751434, 0.0936216057368344, 0.11715420266433109, 0.13464241949540956, 0.10979094091923007, 0.15730205923318863, 0.1669989856741121], [0.030653757651546792, 0.06922148318300325, 0.013010331407009114, 0.04530414540861403, 0.039012192508145686, 0.03589698406417043, 0.006460247095674277, 0.08840751173275133, 0.025252090849643274, 0.06747271129561049, 0.029092012724328428, 0.0367051302154939, 0.03700138024625279, 0.02224799771342547, 0.04796743858605624, 0.10642182412407092, 0.06473088261461066, 11.392492786530527, 55.1182125460717, 42.08638868024273, 33.616653949983665, 34.9700403213501, 37.49053578222952, 60.977449109477384, 48.57500876149824, 57.11746423475204, 6.593862666237739, 0.9844143412286236, 3.38896484624955, 1.737775706475781, 0.3387141005406457, 33.99515874924199, 61.925615418341856, 57.632620488443685, 59.965465837909335, 54.271070803365404, 54.610606854961766, 51.659458683383086, 48.58483429877989, 44.77423206452401, 42.98698840602752, 42.72807275095294, 44.58947273992723, 47.459490606861735, 51.76672766285559, 51.214273591195386, 52.151057181819795, 52.62029817027431, 54.27331832147414, 51.2515204183517, 50.383911748086255, 51.769422331163966, 51.229057004374845, 45.96814270942442, 41.123313442353286, 42.31783205463041, 43.28111125576881, 41.176496859519716, 38.62616000636932, 39.124959976442405, 39.83246534101425, 40.44092301399478, 39.38051808264948, 37.63381211988388, 39.27408064565351, 38.66812544484293, 39.433638741893155, 39.94805366762223, 41.32031056188768, 40.379286889107, 41.121873932500044, 40.20310971044725, 39.17886510972054, 41.307731520745065, 41.967854653635335, 38.27532360630651, 40.197959638411, 38.92171059885333, 40.0914712106028, 40.71905043817336, 38.263540806308875, 36.69629112366707, 37.23283606190836, 37.307725875608384, 38.321070209626235, 42.07985793390582, 45.17429028787921, 50.558484677345525, 54.57157142700688, 53.114308926366995, 55.400548673445186, 57.56887020603303, 52.108322958792414, 48.06870137491534, 44.48878549760388, 47.70425042798443, 46.013359792770885, 45.57938091216549, 44.090684536964666, 44.91870472508092, 41.383166543899044, 40.399298821726155, 38.85845845745456, 39.36452657945695, 39.11507952597834, 40.63867322860226, 39.68609817566411, 38.46493882517661, 36.8722015811551, 37.791240369119954, 38.80581632737191, 40.70851887426069, 39.828244870708836, 39.13549154035507, 36.54129474393783, 36.54524064833118, 37.550614726158884, 38.61491064871512, 37.5777026145689, 37.15036038429507, 37.032438247434555, 36.83200905399938, 36.638153752973004, 37.30667860277238, 35.7484660610076, 37.382549009015484, 38.47012419854441, 36.310953555568574, 38.95751007141606, 44.3882433829769, 48.494804136214725, 50.385621901481386, 49.59433471002887, 48.99301575076196, 47.4769373093882, 46.6125096813325, 47.62348882613644, 49.593875792718705, 50.91458882054975, 52.95762592746366, 49.37919270607733, 54.565432917687204, 49.05715434781967, 51.01937101733301, 50.26875095982706, 52.14642878501646, 52.91681758819088, 53.07322994355233, 5.789118313020276, 0.38146042775723243, 0.8034385103852519, 3.7734127717633403, 0.7926764459379259, 0.026628831288807338, 0.42907104557079656, 6.634566082108406, 58.78088258927869, 45.42637709648379, 33.19897251744425, 20.54535338955541, 29.865848249004735, 46.3981560737856, 12.240936756134035, 0.14853619009016023, 0.041460973405910116, 0.008976977119492668, 0.0542046123694989, 0.02540462278580714, 0.04050433643222336, 0.04292984357884815, 0.024887938615715793, 0.025667425417791934, 0.03525815483543181, 0.05942309222694847, 0.03283333333749925, 0.07210968062281609, 0.007818372555888228, 0.050559933747976064, 0.058315493797342625, 0.023163170178210544, 0.004448295756798959, 0.06368991468221911, 0.022472924958433838, 0.016803918368813973, 0.07183041859177813, 0.055238183722981525, 0.05318293836148036, 0.051505883795119105, 0.041854014815462214, 0.06279729584592485, 0.05853664805932392, 0.0696756737306714, 0.07659915504195998, 17.188165380108742, 62.10009028834682, 40.209754205519154, 34.280593549051595, 43.52456492762412, 42.79050119461552, 64.40912685086651, 54.55404627707697, 61.22932803246283, 5.881440610654893, 0.9042408497583483, 3.9161897426651375, 2.906080138298773, 0.5607907630262837, 34.49612386765019, 64.20466938326436, 57.27300974630541, 61.45016924027474, 56.61146279304259, 56.29148760149556, 55.2915067826548, 52.30213903611707, 47.12627741598314, 46.451986682030466, 44.621502814754365, 46.093034898081136, 50.2086994724889, 53.25646346615207, 51.553134995122115, 52.62931962167063, 53.88015954725204, 55.84534545098582, 53.47718700285881, 52.614320478131695, 52.14844096091486, 53.25936209770941, 48.08323767877395, 43.20062029746271, 43.60403999205559, 44.645821509822724, 42.69276749703192, 41.87432181450629, 41.94427728652954, 40.778862660931004, 41.58468615624213, 42.3209071928455, 40.99615412373697, 42.49079288974885, 40.0664347217929, 40.923037221354825, 43.11389277058263, 41.883617831814675, 41.52738425039476, 42.87342010005828, 41.557166807113155, 40.905013930413034, 42.770654001543605, 43.1208824342297, 40.72192553550967, 41.93421640703755, 40.59231473553566, 40.74175311673073, 42.031785365073915, 39.5167302316235, 38.90664085265129, 39.61526409272225, 38.951206822549146, 41.00368507446782, 43.957492613023334, 47.336030083317915, 53.84559169892342, 55.95142987466628, 55.4613571782266, 60.875255677007864, 60.01088688450476, 54.43028373102988, 48.535898808510076, 46.88889557315458, 46.94405978725803, 46.67946846254411, 48.17527609486734, 47.2868396389869, 46.383545244893725, 43.75541210174561, 41.69190022253221, 41.28893552287933, 40.27726604092506, 38.89070426264117, 41.79384262331071, 40.72860533191312, 40.193543049596975, 38.62891743260045, 40.055467774791104, 40.02031549330681, 42.54920482635499, 41.286782141654726, 40.79461489954303, 38.03798883192001, 37.947911600912775, 39.39653312006305, 38.865844280489036, 39.53602044813095, 40.032110060414965, 37.90788381330429, 38.21614680751678, 38.41864309003277, 38.98403706089143, 36.40871078737321, 39.390084743499756, 40.839420134021395, 39.012380107756584, 40.405072550619806, 46.569614641128055, 50.99881779763007, 53.960219044839185, 49.919722772413685, 50.51333819666217, 49.8752470170298, 49.05918221319876, 49.37568218477311, 52.64996305588753, 52.1982236831419, 55.59227412746799, 52.977320148098855, 55.8143195029228, 51.61700294863794, 52.90810600403817, 52.31462786274572, 52.6592904521573, 50.496621054987756, 54.426118173906886, 8.392746448516846, 0.3934547905960391, 0.7990979787803466, 1.3783349745696591, 0.21144679417052578, 0.053346482811555754, 0.9528770141543882, 6.478870049599679, 64.68351625627088, 50.41224695021107, 43.77125063250142, 30.60681143114644, 27.876412291680616, 52.1921871554467, 17.581569302466608, 0.2571187192393888, 0.0903037402238096, 0.051232873041543274, 0.0498418833669876, 0.07949604757971342, 0.013394961171152612, 0.08446717679861092, 0.053342855385234283, 0.022165135728315483, 0.03855604843627061, 0.057948338498751965, 0.07619628472433937, 0.018282192271022547, 0.18243467675582056, 0.0950240905606939, 0.12263290343746064, 0.11884459099101445, 0.15295150719823378, 0.17736482944700027, 0.13236496267059158, 0.16873697870441023, 0.12294070224367804, 0.27737282757316867, 0.14022169995211786, 0.17133024761513357, 0.18732804805040362, 0.1336764439099258, 0.23408369641871224, 0.19618707348502454, 0.16344030808296897, 19.696460308567172, 73.0065425749748, 54.41177406618672, 45.02479699350173, 46.1974601591787, 46.02254990608462, 71.38042203841671, 58.75677570219963, 68.9867171933574, 8.69577503973438, 2.09536446679023, 13.419063783461048, 5.158965030024129, 0.9614456769439482, 36.9894451479758, 65.80332156150573, 59.018805719191036, 63.325995706742816, 59.164647286938084, 58.66786733750374, 56.00293451739896, 53.996461745231386, 48.80380845838978, 48.810523556124785, 47.33850117652647, 48.90514681416173, 51.66827617153045, 54.8435015063132, 55.057859036230276, 57.24535703659058, 56.54839500304192, 59.318925872925796, 57.47714557955342, 54.98351835435437, 54.26812118099582, 57.480099124293176, 50.91193729831327, 44.88596077888243, 46.55112458813576, 47.27970484764346, 45.33655874190792, 42.81327447583599, 44.323096736784905, 43.89054559892224, 44.498716938880186, 44.21097578540925, 41.69433209203905, 45.03714853717435, 42.250681077280355, 43.75420793410271, 45.32428172326858, 45.46927998142858, 44.152516780361054, 46.10608070127426, 44.463066516384, 42.68527184763263, 45.16129547549833, 46.2253168321425, 42.40261800827519, 44.5072441716348, 43.31367869530955, 45.414617830707186, 44.97187245276667, 42.87915852762038, 41.1901859314211, 41.72973540521438, 41.42891706958894, 43.71078729629517, 47.54015414945541, 49.223121596920876, 55.86117613700129, 57.03614957870976, 57.982692026322894, 59.32355426972913, 58.12714899739912, 57.44304841564548, 52.423042174308534, 48.76949164175218, 48.91402706023186, 50.37651808031144, 50.68270614070278, 51.413824173711966, 49.40767303589852, 48.02983460887786, 43.50015994041197, 43.451600997678696, 42.559838371892134, 41.80669230799521, 43.65655660629273, 43.57642650604249, 43.20363660012522, 39.73080535088816, 41.325382186520486, 41.10738469708351, 45.66456302519768, 43.779958294283965, 43.719130177651685, 39.864958255521714, 40.05500493511077, 40.87184244586576, 42.87334949739518, 41.85580038255261, 41.30847284870763, 41.09119707538236, 40.78850384681456, 40.74192962338848, 42.75579998570104, 38.502189574703095, 42.253689535202525, 43.053641242365686, 40.21079363361482, 42.256780362898304, 49.1204967037324, 54.65564743165047, 54.888279284200365, 52.9932959618107, 53.41254634241904, 50.91507519445112, 51.27971833752048, 49.99482439410303, 52.390894428376235, 54.71405152351626, 57.78729131144863, 54.304407027459916, 59.081618555130504, 52.75727518143193, 54.36619220241424, 51.9981514253924, 51.81900893488238, 52.20480149792087, 56.037286635368105, 10.783665430161262, 0.9140030162469034, 4.230659152230909, 16.050245588825597, 2.1315478413335742, 0.14172128642037993, 1.2392617017030716, 8.284334098139118, 68.46971742568478, 52.45072234061457, 43.63770177287441, 30.272027331013835, 38.423330322388686, 60.99392306420111, 25.755633807951405, 0.4205298700159596, 0.3385265009297479, 0.21529183542776495, 0.16872619218643636, 0.10810242184708196, 0.11742960361223068, 0.17141546723583054, 0.11367221813528769, 0.10837636722792542, 0.13524571373578043, 0.2097609257625957, 0.16815666710176777, 0.13814863538549793], [0.020083197948312568, 0.05793767838528561, 0.016315395590819178, 0.04370859493651698, 0.07536966053228225, 0.06538096184451735, 0.04550036733909961, 0.02839872996593195, 0.014747249998993453, 0.09025893940199768, 0.04070563752564692, 0.05719289153573975, 0.03952641753600009, 0.015333912470528196, 0.03239165683607421, 0.0836324780398319, 0.06435630392403373, 1.4254068487113523, 39.3072364407201, 45.8956180849383, 32.66818561861592, 44.17172462709489, 37.00329895942442, 60.4319650896134, 44.861430275824766, 63.52425190710253, 14.231666115022476, 0.9113145379289505, 2.6728638525932067, 1.3353374624444594, 0.05800836531805897, 18.027366284401186, 60.93502867606379, 55.38743618995913, 61.05772825979418, 52.90882772014987, 54.65363525575208, 47.950336010225364, 46.65073317866172, 43.858119364707704, 48.75103689009144, 49.332908738044004, 50.15403339939733, 49.19446083807176, 52.89583683013917, 51.60849532773418, 54.11123421884353, 52.96504312945951, 52.57566159771335, 50.94160218392649, 54.02710330101752, 51.91195734085576, 47.84549105551935, 43.074912255810155, 40.68626334590297, 40.187059371702134, 39.96171920530258, 36.682182358157256, 39.51403948568529, 39.07535768324329, 38.70399944243893, 39.54001734333654, 39.27985437454716, 38.640147178403794, 38.15885666877993, 39.00238590855753, 40.52964310492239, 41.15511209734025, 40.613432776543405, 41.331124536452755, 40.17993634746921, 40.59292662528254, 40.94044077780939, 39.95831066562284, 41.65031917633549, 40.330017997372536, 39.150027844213675, 39.366946681853264, 39.45552164508451, 39.20912619559996, 38.667329203697946, 36.90384726370535, 36.45606948483375, 36.97681903839111, 37.13353341625583, 41.88438661636845, 46.537274699057306, 51.89002344685217, 53.79425179573798, 54.2327178678205, 49.06815659615302, 57.9043113031695, 54.52602094219577, 50.59251516096054, 48.02060134949223, 52.27840477420438, 50.129663713516734, 47.589513255703835, 48.34262009589903, 48.43377205633348, 44.99370828751595, 40.698673725128174, 39.658900460889264, 39.89603911676715, 39.567524925354995, 41.308680734326764, 42.171484501131125, 40.09676641033542, 39.542213870633034, 38.362419835982784, 39.231181683078894, 39.734751255281516, 40.13616269634616, 39.239614778949374, 38.19750378208776, 37.529716337880785, 37.458403725777906, 38.407021107212195, 37.7840506645941, 37.66498711801345, 36.521553454860566, 36.31195768233269, 36.324677928801506, 35.64909281269197, 35.37733531767322, 36.765211089964836, 34.47774364102271, 38.213514897131155, 37.0491083206669, 38.855991286616174, 44.819355010986335, 48.12429312736758, 48.249310831869806, 49.91541600996449, 49.18979321756671, 50.27098671082528, 45.73132961027084, 47.889115656575854, 48.49319596444407, 48.3670368502217, 48.157209657853656, 49.228487399316606, 47.95157155682964, 50.01189454909294, 48.036055487971154, 52.89681350031207, 49.04959986286779, 41.78239714714789, 1.7058962751780788, 0.8439545105061225, 3.0976433042557012, 0.24632745152038915, 0.3229832204599535, 0.14314018850845678, 0.15541720714780594, 7.254917362043935, 63.13795728068199, 39.03977001866987, 29.076279055687692, 23.878856166716545, 31.21207041125144, 37.04492315169304, 1.2044471117757982, 0.2050429579591559, 0.08393891320954408, 0.029196645013026656, 0.02210069432734482, 0.04623251373789484, 0.08234455400416929, 0.03177373031634958, 0.08809468738975064, 0.03791600112773238, 0.06312789342876884, 0.041310103880541946, 0.01851106103840134, 0.03109743938811364, 0.03575022843095564, 0.02560615370560798, 0.07039286992362431, 0.021729379171325315, 0.09686014284529994, 0.08050929845100449, 0.04122162838616679, 0.029796219896525148, 0.06071482755003437, 0.06617518817825664, 0.012424720391150446, 0.019418800535101085, 0.07011353894467316, 0.017180366313926155, 0.012198932254837166, 0.13180752645336813, 0.08001912475353287, 2.8920324146747594, 49.599151380600475, 51.062305281239176, 31.864335075501476, 50.64731067226779, 43.0553121720591, 67.41121092150289, 50.08658824428436, 66.78841698554255, 14.321593315370622, 0.6927492241224935, 4.144433688732886, 2.6132050925685517, 0.20299142046320826, 20.24810048841661, 62.009212893824426, 56.78331751977244, 62.73546326544977, 53.78955671864172, 57.55291400417205, 48.83101794027513, 49.290347099304206, 45.36866334176833, 50.78393074773973, 51.008772773127404, 52.30222925063103, 53.09459901625111, 56.639523429255334, 53.82956489439934, 56.40659739894252, 54.68137033524052, 56.3480560241207, 53.63204609963202, 55.589320582728234, 53.48421196783743, 51.39675794109222, 44.74077816932432, 42.780852163991625, 42.44521494834654, 41.19022123275265, 39.53523597409649, 40.40526082438808, 40.14376424974011, 40.258509266761045, 42.41667970534294, 40.84636665159657, 40.62498023433071, 40.22778926357147, 40.46106830719979, 42.36822666660432, 43.71421544782577, 41.654578870342625, 41.65792465209961, 43.024509799095895, 41.39853439023418, 43.182522481487645, 41.80293075499996, 43.1556660129178, 41.81293672130954, 40.48068015806137, 40.71791295082339, 42.35118789057578, 41.54704709206858, 40.84782969567084, 38.11333364056003, 39.75103693623697, 38.7806543227165, 40.35312075768748, 43.692281553822184, 48.54562236416725, 52.6626911470967, 56.71947310047766, 56.443020528362645, 52.89332259085871, 61.99271148250949, 56.62445760542347, 52.41908842517484, 49.51695419126942, 52.90496026315997, 51.05304848763251, 47.94383272047966, 49.65327224423809, 48.76225486878426, 46.442412176439845, 41.38855588051581, 39.98471998399304, 42.44643480547013, 40.30466771894886, 41.91358866230134, 43.0112051194714, 40.33129669004872, 39.8835777467297, 41.57644525651009, 39.710687514274355, 41.681517708686094, 41.949454815157004, 41.03488752918859, 39.65729621148879, 38.020581353095274, 39.58488141336749, 41.69122949723275, 39.487767450271114, 40.31608966089065, 38.53475309187366, 37.88748356603807, 36.46547925087714, 38.357999324798584, 35.681974041846495, 38.594114242061494, 37.564896075956284, 39.760478081241736, 38.957804249178984, 41.146208317049094, 46.26485432347944, 50.582230706368726, 50.713002527913744, 52.07695184215423, 49.68240368750788, 51.79544333488711, 48.46908515499484, 48.845307134812884, 49.545473744792325, 50.452443399736964, 49.56225756675967, 52.27813805303266, 49.19688878520843, 49.284910694245376, 49.19233883580854, 53.67754559363089, 49.30979421061855, 43.87814698680755, 2.8209058700069307, 1.6918859366447696, 8.207607144309629, 0.4506125186960544, 0.2301177818087801, 0.11592116116756394, 0.2500193824450816, 8.334469833681661, 68.61288393697431, 41.78126750453826, 37.000792564884314, 24.14451829848751, 28.588198923295547, 49.507928817502915, 2.6386911830594464, 0.14812437186558403, 0.15138625167310238, 0.08413575950168795, 0.024578527194417776, 0.05404708937050835, 0.05742877766850495, 0.06506455987091027, 0.03215243439039877, 0.026886583486151312, 0.07812156326948635, 0.039078646805137396, 0.06509100522605643, 0.0344821996986866, 0.13019917082161675, 0.14044142929056, 0.13446612734227412, 0.2244914175882455, 0.22182555418581734, 0.22365011515155916, 0.18213222524331463, 0.07960827179974125, 0.1233319816510043, 0.2475577734050251, 0.13463527955595525, 0.1734258964537613, 0.12262030895198546, 0.14597570974259608, 0.10270625172603516, 0.17627080992585228, 0.11939762986355251, 2.724732295159371, 57.129580436214326, 58.661870033510276, 41.680160568606475, 55.05166953609836, 48.45783579734064, 71.46729469299316, 56.33475918923655, 72.43136621290638, 19.26327374673659, 2.189679328472384, 11.91000638469573, 5.447222955765263, 0.4486604347344368, 22.73935271847633, 61.54885999618038, 59.487458352119695, 65.24541539530601, 56.64389687199747, 58.62842006068076, 51.06474107311618, 50.59374678519465, 47.38924095707555, 52.967051382987734, 54.660930864272586, 54.25815443838797, 54.59435255296769, 57.88841001449093, 55.09762402503721, 58.42434306298533, 56.51789857495216, 60.01102024509061, 55.729517859797326, 57.74412562770229, 55.202892595721835, 50.771441921111084, 48.86783722908267, 46.2229359534479, 43.21401519160117, 42.02163427106796, 41.833180073768865, 44.170540071302845, 42.51133826471145, 42.356043784849106, 44.14075751458445, 42.85517323401667, 42.99464487260388, 41.45132557038338, 40.790676839890025, 44.65109709770449, 46.68048043404856, 43.896841003048806, 45.007162017206994, 46.41966242944041, 43.514394221767304, 45.72137855714368, 43.995606283987726, 45.69347873810799, 43.71145409922446, 42.852223611647084, 43.13803495899324, 43.63568175223566, 44.84406202070175, 43.217411964170395, 40.69650857679306, 42.22656634546096, 41.9570210672194, 42.46644281571911, 46.71427165308307, 50.5343738678963, 55.511512525620006, 57.22476067081575, 56.973850573262865, 52.71492142831126, 60.24553483532321, 57.60133174157912, 54.59239529025171, 53.26134289464643, 52.50583948627595, 52.517210437405495, 51.4398608669158, 52.79421214134463, 52.8046299565223, 48.580684431137584, 43.51693591763897, 41.83443523222401, 44.314855837052875, 42.974001438386985, 45.54759794665922, 45.520521825359715, 44.14355808688749, 41.816725730895996, 42.71828251500284, 41.942178818487356, 42.997771001631214, 42.95910427647252, 43.56034086596581, 42.18249459420481, 40.51820547349992, 42.63599511115782, 44.17598432110202, 41.69141777100102, 42.681086678658765, 40.48211966791461, 40.30092577780447, 40.552816467900435, 40.40417432785034, 38.41308116912842, 40.47869543875418, 39.20060288521552, 43.857515319701164, 41.39600838384321, 43.53656738035141, 48.60699176788331, 53.10286737257435, 52.612516187852435, 54.293494993640536, 52.3103799358491, 54.94395340642622, 49.75549705566899, 51.99415845255698, 50.669374004487075, 51.24615461595597, 51.28171482393819, 54.6076415431115, 49.92531607227941, 52.704013316862046, 49.70035637578657, 56.00215788810484, 47.43580733576129, 47.86581677775229, 4.573024213314056, 1.7996367547781238, 10.10010515489886, 3.7952709149929786, 1.0519046648856134, 0.27819566729087986, 0.6540866051950763, 9.408319669385111, 73.6179381032144, 47.4719205979378, 40.0800218120698, 34.45647654994842, 38.84172954866963, 58.41603940533054, 4.821512247285535, 0.4093651803991487, 0.3108110639356798, 0.18680153114180412, 0.21188020075280822, 0.1923972824888845, 0.18921582659165706, 0.19339537248015407, 0.2376292432628332, 0.16836475190376082, 0.17317512523262732, 0.1642870497439177, 0.09310709342600838, 0.12694607804258987], [0.03670716034849325, 0.06641672803990303, 0.05657982201345506, 0.015723943154537873, 0.07189046456328324, 0.0714868741230138, 0.08413075694754239, 0.06357630384304831, 0.035277123172436996, 0.06604722851226408, 0.09252309694045013, 0.04588272565254762, 0.08474853791056142, 0.01893194016790198, 0.07791211483098807, 0.032110305300222776, 0.05603537481698779, 0.025363646657957185, 18.54892776858422, 51.84406503554314, 28.412474778390703, 24.63798776749642, 34.35414583452287, 47.89883136749268, 48.400831991626376, 64.53269327840498, 25.31121357794731, 0.17013286751124168, 2.599941597830865, 2.1685536878724254, 0.3832231041404509, 8.624208454162844, 57.835269743396395, 54.70153916266657, 59.322691348291215, 54.98777020362116, 53.44544326105426, 49.50033903121949, 52.73108551579138, 50.48712499680058, 51.41354568542973, 51.8752831797446, 55.30077926574215, 51.70498171160298, 54.473347433151744, 54.80415228874453, 54.286081714014855, 52.406795717054806, 52.61836051940919, 53.37704104761924, 53.75287471279022, 52.83731506716821, 44.481438898271136, 38.50910079094672, 39.6952372981656, 38.65746444271457, 39.75283338177589, 39.5405468633098, 38.995459002833215, 38.229188688339725, 39.894638830615634, 39.465264812592544, 41.72928825501473, 39.69930087366412, 37.998361126069106, 39.02079751414638, 39.49605934081539, 39.435223379442775, 42.58294897694742, 41.65165278219408, 41.68163145742109, 38.60854071955527, 42.6542615890503, 39.863153965242454, 40.74496161553168, 41.38147600235478, 39.742403799487704, 38.115016337363954, 38.00223250542918, 39.43711003949566, 39.30733057760423, 40.58957692115538, 36.45324537830968, 36.583613195726954, 37.97176353393063, 40.04386932619157, 44.30261804211525, 52.86654849206248, 55.757523582827666, 54.38570991639168, 50.09674718303066, 52.90986714824554, 54.58231872127902, 48.91514493573097, 48.992337180722146, 51.59062108685894, 59.38046001618909, 48.4371413723115, 47.50309559606737, 48.49091706737396, 48.36674267245878, 40.87162671550628, 39.43040670887117, 39.34960196095128, 40.81714499381281, 40.67815580675679, 40.4437392757785, 40.76421653070758, 40.270315600979714, 38.03613355082851, 41.755999595888206, 39.34957450436008, 39.90378579785747, 38.55760874286775, 39.319219281596524, 37.74876894489412, 37.942204552312056, 37.23493452995054, 37.34507468438918, 36.895410245464696, 37.12951690919938, 35.81320478070167, 35.049660513477946, 35.99102151009345, 36.83240129101661, 35.727469613475186, 36.30719200257332, 35.25494560118645, 38.913395174088016, 36.73043535601708, 40.70023482845676, 44.188386855586884, 46.37790095421576, 48.11710734521189, 46.96247139284688, 48.25129947354717, 46.80690234707248, 46.62704990756127, 46.23682506622807, 46.7376450569399, 44.82839215186335, 46.902753306973366, 48.60198682354343, 47.56587705304546, 51.843790469631074, 49.5972490310669, 52.18740970857682, 26.52511066006076, 0.6260667861469331, 0.1717892262123285, 1.0149563055846, 0.10173194110393526, 0.253601165248021, 0.18152192895931585, 0.2768248908462063, 13.781709459520156, 61.89180458745649, 41.468109392350726, 33.193787144076445, 29.788869773187947, 43.487773095407796, 19.643039588005312, 0.22114585033587872, 0.06698665149029225, 0.052957222045909975, 0.029541183480872747, 0.03310745874900491, 0.01695555206688662, 0.027246560540891467, 0.03555212575461596, 0.04723021302432303, 0.02079410838984674, 0.022208048143394055, 0.005775059492612679, 0.05290667556466595, 0.05604003646200704, 0.016717478753097596, 0.010799113416954154, 0.059817390020696394, 0.06762793603082819, 0.05141442438827888, 0.06692524188228192, 0.022023907419474378, 0.02895047223465818, 0.05684985268500544, 0.05516887957891149, 0.0200743802763041, 0.01984251035948194, 0.06764456779966432, 0.0398571415233516, 0.049749339945734515, 0.046711866443435994, 0.03226424109250788, 0.02328538993043044, 25.535853601271107, 57.58797999351256, 31.399030185514885, 36.09677645467943, 41.36571199663224, 53.63994575315907, 51.303472211284024, 66.83898418180405, 25.48067565887205, 0.21565329103219896, 1.2182408619311549, 2.2762087756587617, 0.3771600391595595, 9.999565001456968, 59.3959729902206, 56.80339221031436, 61.730630474705855, 54.689281755878085, 56.03026951512983, 52.70815141739384, 55.66249632066297, 50.34958316433815, 52.97693575582197, 55.23440099531605, 55.58030305370208, 56.404757807331706, 56.3625374147969, 57.0635747909546, 55.80235235152706, 53.45037760273103, 53.537140430942664, 55.81080113687823, 54.799284627360684, 53.78032738162626, 47.87976472608505, 41.32683346348424, 40.44130740627166, 41.10408598376859, 42.409741032508116, 40.42460595407794, 40.54482267748925, 38.84099606544741, 40.991031508291925, 41.400417127916896, 42.6410000554977, 42.26930056848834, 39.598319453577844, 40.660442383058616, 42.851545041607274, 41.6956421636766, 42.917115303777884, 41.675171313747285, 41.6047098559718, 42.254976072619044, 43.58160795704011, 41.954663722745835, 41.29205380716632, 42.42092763223956, 42.671547474399695, 39.71835182559106, 40.025245912613414, 41.86957574659779, 40.035518600094704, 41.91890347388483, 39.71809294915969, 38.938157096985854, 39.430269425915135, 41.448093537361395, 47.58969368473176, 55.049676972050825, 57.528254062898704, 57.065484985228515, 50.49983739852906, 58.935941726930686, 56.798602996333955, 49.67509631187686, 50.10886338449294, 54.000705749757834, 59.212284472680864, 50.37175632292225, 49.678183217202466, 50.743789211396255, 49.14518410159696, 42.44277523409936, 40.34675475089781, 40.98579514411188, 41.348936019405244, 41.933408398782056, 42.158438697938, 42.13209605986073, 40.77499912631127, 40.18627882003784, 42.5184848231654, 40.69653603338426, 41.190315369636785, 40.12636461565572, 40.72759336040866, 40.199944357718195, 39.675260666877996, 40.030745075595, 39.122233929172644, 38.16114733296056, 39.45814178835961, 37.379446414209184, 38.3409252474385, 37.45820368489912, 38.22015939220306, 37.30887513006888, 37.639377963158395, 38.203355958384854, 39.41823559422647, 37.57891070458197, 43.38826648650631, 47.07096807418331, 48.944378360625244, 49.159673337013494, 51.67564238271406, 50.73868620780207, 50.38745364835186, 50.26186720017464, 47.973050455893244, 46.820081510851466, 46.11424315360285, 48.27768918006651, 49.262596330335064, 47.722634576982074, 52.1007449396195, 51.458554883157056, 53.33510698810701, 29.412283012943885, 0.9779740545538165, 0.9426607107443195, 3.624599273166349, 0.3102807165874589, 0.22742228612544077, 0.13985227703327133, 0.3832290796262603, 14.717766431070144, 67.64200318244197, 45.68086047326365, 43.36253573817592, 23.12202307485765, 45.542463564103656, 29.453507123454926, 0.24302643994169854, 0.07387324566802672, 0.039086100840640646, 0.023501488012111476, 0.02210621207561945, 0.04869777701735016, 0.08313453621080807, 0.0191212787983879, 0.033766581646857724, 0.015873016203723608, 0.059267086082048, 0.019926222702187878, 0.018587579815498283, 0.018280028072636456, 0.21349119172701914, 0.16206433756216881, 0.15610330017103305, 0.1581463340910212, 0.19159442234423854, 0.1411085692985404, 0.16598479251467413, 0.16819742297933948, 0.1553972428964992, 0.25366991397834593, 0.17366018146276477, 0.11049016468947935, 0.18041298604540287, 0.13568782307688268, 0.1387476548552513, 0.19452550538605262, 0.10398930344249933, 0.13112472760821545, 28.635510552314024, 66.99282738470262, 39.227792755250015, 35.862681558055264, 44.1258172065981, 59.53259306569254, 58.86560186263054, 70.28164848204582, 31.540323765047138, 0.28268334906428094, 7.494368255138398, 8.116275735439794, 0.8167112594650638, 11.088109997011001, 61.596865884719364, 57.65682543477705, 64.23455392160724, 58.37439560121106, 57.42255403149513, 55.14425316164571, 58.66391358837005, 52.85022750977547, 54.85248765637798, 57.377172208601436, 59.94124912446546, 56.64798398171702, 56.80984058687764, 58.46790882848925, 57.16416005165347, 55.46989225572156, 56.124626051995065, 58.350288714132006, 57.89380719584804, 57.53131351163311, 49.69532397485549, 42.670257014613, 41.4781585047322, 43.25800849545387, 44.60993966748638, 42.69201047958867, 42.25827870830413, 40.35558008378552, 43.839597932754025, 44.646390253497714, 44.591375089460804, 45.3358684047576, 41.39007776014267, 42.35412966820502, 44.456967230766054, 43.649064879263605, 46.55076765245008, 45.34911424882951, 45.12464092623803, 42.10583579155707, 46.94710746888192, 42.50598815179641, 44.36621535208918, 44.68616700941517, 46.26410122840635, 42.78460587224653, 41.82390366831134, 43.6793573441044, 42.71156349489766, 45.3923858365705, 40.84510364840108, 41.51504447383266, 42.04835737905195, 43.84912536990258, 49.644454756090724, 56.38729541532455, 59.867465419154016, 58.190459974350475, 54.22488097221621, 56.278233912683305, 56.408362465520064, 52.87731147581532, 51.54020294066399, 56.74125402204452, 59.45259240365798, 53.79087855738979, 51.10021891132478, 54.3117065583506, 52.318224676193736, 45.116090159262384, 41.54847875718148, 42.03573126946726, 45.726081478980284, 44.06101572898127, 45.089041494554095, 44.733192305411066, 42.90768984825381, 41.51483658821353, 43.150323744743105, 43.549726932279526, 43.59455177860875, 43.08274522904427, 43.41837852231918, 42.932267419753536, 41.52639581311134, 41.347261167341664, 41.15612799121488, 40.996613041047134, 41.90681472901375, 39.93927148080642, 40.15322892896591, 40.739709561870946, 40.864205591140255, 39.77881908416748, 39.65291100163614, 40.455047468985285, 41.43321206492763, 40.241627385539395, 45.125935308394894, 50.20528701043899, 51.44295169461159, 51.96983975748862, 52.486133498530236, 52.11858387916319, 51.38817971752536, 52.14508733441753, 50.594033118217226, 52.42239106085993, 48.39262639322589, 49.08556407497775, 48.79141769101543, 48.43774541731804, 52.89332259085871, 51.10087786951373, 52.89451106902092, 34.0466163235326, 1.568984718572709, 0.5247827306870492, 2.910236870088885, 0.8244478894818215, 0.661237515028446, 0.6141898492651602, 0.578052623858375, 17.752617982126054, 73.43104500924387, 50.98349309736683, 44.50194112716183, 38.454517087628766, 54.956544214679354, 39.30655787068029, 0.5829912556275245, 0.18111296058181794, 0.12434794447354733, 0.09074452423280285, 0.04690425027342093, 0.18273303735881083, 0.16594651876197708, 0.1290615762193357, 0.1497124108455835, 0.11024406660468349, 0.18377747566949937, 0.20928054266879637, 0.13484278213112585, 0.13198766436788345], [0.02191190344972476, 0.054245341433993274, 0.06363139322568333, 0.023878416677396146, 0.03529472787293696, 0.07791142535185622, 0.08176693137014106, 0.04359630176857595, 0.025822088993605108, 0.06840061997213671, 0.014410407841956664, 0.09390870484733775, 0.012810729113557648, 0.010665400430650241, 0.039992379024624825, 0.039502768401777556, 0.05715593928471208, 0.031788190225920374, 6.0865119291890055, 46.2140243284164, 38.353127741044574, 26.882258153730824, 28.710633747039306, 40.770413875579834, 55.673306372857866, 59.15817929852394, 35.527738601930686, 0.19687623085994876, 1.9305369113722157, 0.9845716650447539, 0.18983206771794828, 2.059472328232181, 45.64790079670568, 60.353568676979314, 59.09442117137294, 56.18203778420725, 53.63136360722204, 52.629739315279075, 54.64455496880316, 54.86007352029124, 55.70239074768559, 54.54062000397713, 54.526189604113185, 52.3404174466287, 55.681241327716464, 54.90147805983021, 53.86068890171667, 53.51077425864435, 53.797358312914454, 51.806684847800966, 52.37922145474342, 47.349154333914484, 39.63145563679357, 39.047195065406065, 40.33048868179321, 38.27495490351031, 38.828016942547215, 38.87945490498697, 39.477635968116026, 38.89589748074932, 39.44110301233108, 40.14264245187083, 41.58185028260754, 39.10591294688564, 38.90515035198581, 39.309660465486594, 40.462751004003714, 40.98633643119566, 41.77441512384723, 40.585046583606356, 39.66475263718636, 39.61993171322731, 41.29930234724476, 39.80160021012829, 41.02505022479642, 41.558720065701394, 40.74392218743601, 37.63050948419879, 41.49322825093424, 40.3210122354569, 39.4681752112604, 39.5876859080407, 38.66307343206098, 37.94691924125918, 37.86541238907845, 39.74028964196482, 46.07860842058736, 55.06951239801223, 54.097227434958185, 55.75589187683598, 53.52065863147859, 46.15488675332839, 56.7564453617219, 50.86311163440828, 53.434695966782115, 49.61837883918516, 58.192460383138354, 55.41006434348322, 49.42353902324554, 53.4551432824904, 48.86686448127993, 42.29438804811047, 38.085292616198146, 37.9849152411184, 40.03149424829791, 42.00921212473224, 40.27010379299041, 39.09718175088206, 41.298659078536495, 38.95737278846003, 41.17804227336761, 38.71735119050549, 39.39019849223476, 38.79173109608312, 37.899293822626916, 38.27328397381691, 36.39647691480575, 38.77504533337009, 38.60337495803833, 36.61307411809122, 36.366125614412375, 34.95715925770421, 36.67099575842581, 35.083753755015714, 34.76276266959406, 35.80717217537665, 36.60577066483037, 36.22919567169682, 36.68373169437532, 38.16668571964387, 39.05509864130328, 43.290489642850815, 46.55742783700266, 44.048734787971746, 47.350915478121856, 47.85791712422525, 48.47218774980115, 45.69303158790835, 45.63975795622795, 42.87413789379982, 44.56034129665744, 49.443649015119, 51.180435303718816, 47.10195872091478, 50.48418321917134, 50.20922114772182, 46.75407194322156, 11.847096470094497, 0.18987755801889206, 1.6402604358811534, 2.236414614223665, 0.017036443290811394, 0.18583198558659325, 0.12695583034186594, 0.2737358711179226, 19.18533625141267, 61.61254752066828, 31.533942068776778, 22.7490762741335, 31.32909432534249, 46.274060126273866, 12.341785796226995, 0.1901097286252245, 0.04864588988223865, 0.05521230144245971, 0.034003069158643484, 0.030307999188681285, 0.035432581564471606, 0.026639866785356597, 0.006300259687592306, 0.10099610599178462, 0.05754874703744727, 0.053862940985709436, 0.05758147431357254, 0.009609163408317875, 0.05557530454450077, 0.0328069071345512, 0.026511985643376267, 0.03182200917733773, 0.11547814018183178, 0.07643968617964177, 0.07746812091359208, 0.07808129002730693, 0.09400419004622007, 0.04788596513530901, 0.08932683256364639, 0.0771096760347005, 0.09275376601445098, 0.08808972314000131, 0.028901570927231546, 0.02739881668540259, 0.06538869933255258, 0.06434485857044497, 0.04264471714474982, 9.52915612728365, 55.58343310509959, 38.868931185814645, 25.549495604730424, 42.18626006957024, 45.14253477896414, 56.97356031787012, 63.78349311890141, 37.55562359286893, 0.17066099320448216, 1.4269541011702631, 1.4434469323004446, 0.16536524188855004, 2.7535749539252254, 49.24727163007183, 59.43927595692297, 60.65374374389649, 57.78363174007785, 57.92804164271201, 53.34401861313851, 57.98842653151482, 54.24721102560721, 58.122889303391986, 57.48285262815414, 58.154005465968964, 54.82817680604997, 57.11604433674967, 56.661163145496005, 55.51130464000087, 54.15194842123217, 56.33145655355146, 54.05284581645843, 54.81186366850331, 49.55401666702763, 41.90309239972023, 40.92156241017003, 41.62333719192013, 41.13992468003304, 40.903017443995324, 40.87040685838269, 41.82525296365061, 40.601595063363355, 41.04786272971861, 42.10480028583158, 43.73573749296127, 41.999637619141616, 41.31667452473795, 40.51005871065202, 42.66489121221727, 43.15752129400931, 44.64635102979599, 41.66352579670568, 39.95750657973751, 41.87259989400064, 44.021674356152936, 41.31323068372665, 43.128483987623646, 43.78586538376347, 41.581763990463756, 40.41064231626449, 41.76700184422155, 42.297353359960745, 42.464403183229514, 42.26643723826255, 42.05152665415118, 39.372732177857436, 39.884279850990545, 41.772834408667784, 46.14673999048049, 54.02057255468061, 56.303654793770086, 58.61129107013826, 52.440226078033454, 51.43400084587836, 59.67171953570459, 51.17983518108245, 53.99690497306086, 51.54576093919816, 59.326680398756466, 55.10458230972291, 51.94311664950464, 53.58715457300986, 51.03938687232233, 43.770560295351096, 41.307962940585234, 39.77300220920194, 41.86232328414917, 43.216980503451445, 42.6116568042386, 40.82026720046997, 42.63858387547155, 40.679505102096066, 42.991044136785696, 41.50328128568588, 40.81478764933925, 39.70866357126544, 39.21598249866117, 39.22527459359939, 39.828084053531775, 40.45218806112967, 40.40032256034113, 37.6408370848625, 39.2890444878609, 37.581864249321725, 38.62747007800687, 37.96932774205362, 37.9370270236846, 38.13745621711978, 38.66987089956961, 37.70517180042882, 38.70528597985545, 39.15967687483757, 40.461825324643044, 44.731446850684385, 49.126258665515536, 47.31699482087166, 50.375317835038715, 49.8812403986531, 50.15001689234088, 48.11136107290945, 48.39317552505001, 48.84334202735655, 48.80450271791028, 50.97863328072333, 50.61362143485777, 49.435400270646625, 49.21201736696305, 50.22158053613479, 48.23661019725185, 14.292971780223233, 0.2469021247159089, 2.479839603747091, 3.8628013816572007, 0.09635651664387795, 0.4075595724486536, 0.376258752038402, 0.1643987300415193, 21.784159483448153, 66.13506778593987, 40.03117653631395, 31.024081014817764, 29.16312425367294, 53.715776935700454, 16.898457157996393, 0.17393324584249528, 0.017355474861218564, 0.013674317047961298, 0.019614141464473742, 0.017884110002928687, 0.08583567030127011, 0.06057735307202224, 0.0471455181738542, 0.06287008569005036, 0.07339742079737686, 0.023337016595647703, 0.053676942498573375, 0.006392212742338739, 0.050677095404675895, 0.10251567969399114, 0.1447764144188935, 0.205168504448187, 0.14093860503165953, 0.16206711080045472, 0.1876835741343037, 0.2424062917669935, 0.14811367727816105, 0.12121452995005155, 0.2168608294619668, 0.1983139633892044, 0.23928849777627378, 0.1914019810576593, 0.047038917039190574, 0.17943772547427686, 0.13357078506340905, 0.196711475990953, 0.1523142599410588, 10.92768603755582, 62.63443869929161, 48.56855254019461, 36.80593705946399, 40.93970729458717, 50.45747187829787, 62.796142332015506, 70.0150606709142, 44.21315270085489, 0.263946493186297, 4.8816657162481745, 4.302030599886372, 0.9001449147059072, 3.4201408249716607, 49.924680648311494, 62.154991703648726, 63.21618503139865, 59.043430359132834, 59.017899651681226, 55.60490808179302, 60.2645230293274, 57.72866364448302, 59.20001922115203, 59.52198305437642, 59.66537706313595, 55.541648095653905, 59.857267256705995, 58.70675371539209, 57.395646572113044, 57.549360336795935, 58.17915570351386, 56.524597983206476, 57.411991088621086, 51.120179853131695, 43.39063952046056, 44.35942180695073, 43.58530282974244, 43.749916861134196, 44.06913895760813, 44.9726333925801, 43.340174305823545, 43.67221863039079, 44.7514783951544, 44.93849700497043, 46.73665661965647, 43.19035153235159, 43.08381211373114, 42.28003609564997, 43.967157333127915, 45.00203547939178, 46.857685273693455, 44.07486954042989, 41.844307837947724, 44.31778976994176, 47.56284506090226, 45.04824100002166, 45.07869428203952, 45.6707799819208, 44.79091782723704, 42.430906141957934, 43.991515251898, 45.36397610941241, 46.21798592229044, 45.29680159784133, 44.00491014603646, 40.53278884580059, 42.38641469709335, 43.417637194356615, 49.15515084420481, 57.93601189890216, 57.70531377484722, 59.58812598259219, 56.382102197216405, 50.4614923077245, 57.26472962287165, 52.66152228078535, 55.48295767076554, 53.958952119273526, 59.686079332905436, 56.425707186422045, 55.684308621191214, 56.51929101636333, 53.2660654283339, 46.95629758219565, 42.10130153163787, 41.86235074074038, 45.13217579933905, 46.7554683070029, 44.876013648125436, 43.97687696641491, 45.36938505788004, 42.548020270562944, 46.25426392401419, 42.948776675808816, 43.08472602598129, 40.9322077228177, 41.43416127850933, 43.789623014388546, 41.38783808677427, 43.628848983395486, 43.017433843305035, 39.37211636574038, 41.062485325721006, 39.53963295105965, 40.65817525309902, 39.183489584153705, 40.62563134777931, 41.45200414042319, 41.315576261089696, 40.462496049942516, 40.38146772692281, 42.61719911329208, 42.96812180549868, 48.53073696936331, 51.933836321676935, 48.583873318087676, 51.65269259483584, 50.719384224184104, 51.256313554702274, 50.214971342394435, 50.69092350621378, 50.65370805801884, 51.2525833806684, 51.18444004366475, 55.03523088270619, 48.361290577919256, 52.36741119815458, 52.429851408927675, 50.2949563149483, 16.10754063052516, 0.45103307032296736, 3.665322300887877, 7.141629505542017, 0.3060961911274541, 0.7013912474916828, 0.9034449763355717, 0.3860310921745916, 26.203897960724372, 70.70385240739392, 40.22414538168138, 34.05090739650111, 38.604312404509514, 62.18255027647942, 23.25978063767956, 0.230246699084678, 0.1625989443592487, 0.08781097438787261, 0.07790534261373744, 0.07153974951154764, 0.17195421090770155, 0.24445442783255733, 0.16745178960263732, 0.21445633993754465, 0.18480262388625454, 0.1146893224288379, 0.19106548459779835, 0.10981576216797675, 0.19451130211593645], [0.05397794993534204, 0.03876571137938769, 0.09505831936915075, 0.03944926865158543, 0.02592285062306591, 0.020597103134458585, 0.03754193571606471, 0.03725587082425914, 0.020898683221950647, 0.029178609388069283, 0.07619513559245294, 0.01159119374689556, 0.018756216835050334, 0.03045249486251945, 0.052300964316893975, 0.0284598580366301, 0.022901286851734887, 0.06243829172284854, 0.06977813032966468, 27.1518720734504, 49.573750111364554, 29.323527620684718, 21.860196590423588, 34.73886759050431, 48.499726710780976, 59.05807256698609, 43.459912500073834, 0.5804990796792893, 0.9758703158267084, 1.2150643549619184, 0.18253915582693395, 0.3367831299622213, 20.60898207849072, 58.324863910675056, 59.273697022468816, 57.234962755633944, 54.65836171180972, 56.3055375314528, 55.74360701345629, 55.47545809899607, 51.488290371433386, 48.88823355397871, 49.824589606254335, 52.339162288173554, 53.52213736503355, 51.4973275123104, 51.06246217604607, 50.31765899350567, 50.11810448861892, 46.76275999315324, 44.260782041857325, 40.46332367004887, 38.007064865481475, 39.02242529776789, 40.72686379955661, 40.28826044451806, 37.7355662468941, 38.873908673563314, 39.8100999862917, 39.87753337429416, 40.54249671197707, 40.589827952846406, 39.63480534092073, 40.32844512693344, 38.346855871139034, 38.855257803393954, 39.888025714505105, 39.52298248967817, 40.68264299823392, 40.38777489815989, 41.95795066895024, 39.497906777166556, 40.37336803251698, 40.4543649765753, 39.58867826769429, 39.80369083343014, 40.729884024589296, 40.34697832599763, 41.95580513246598, 41.1757908328887, 41.62212517953689, 41.3770947148723, 40.50495570705783, 40.12467015174128, 38.785514139360004, 40.67999147599743, 44.55236711809712, 51.70085930055188, 58.151471614837654, 54.13603536544308, 55.51980833853445, 45.64031101042225, 52.76066018689064, 54.05694077091833, 54.480140978290194, 51.96215583432106, 52.31654590175998, 54.03909790900446, 49.71036626446632, 52.32180187779089, 52.68989670661188, 44.21661615371705, 36.57938095831102, 39.379529645366055, 39.51626346957299, 41.66313748205862, 39.612577269154215, 40.08811366173529, 39.716586759013516, 39.680112638781154, 39.24676918214367, 37.80616890999579, 38.7280474939654, 37.364608087847316, 37.36961695455736, 36.93289241483135, 35.71603590442289, 37.07273667858493, 38.94695889565253, 36.4206700940286, 35.25423957455543, 37.01681152466805, 34.55145282130088, 35.77513817817935, 35.34354409863872, 36.80797276958343, 36.25707195651147, 35.47210762577672, 40.25579106423163, 42.197874207650464, 43.212203056581565, 45.554968080212994, 48.77078994627922, 48.69938711966238, 49.71713235301357, 48.14560336451377, 49.211142678414625, 46.948625426138605, 48.35997658391153, 41.95278882980347, 44.58849214738415, 48.54376316070557, 51.35801276853008, 50.32642156847062, 50.987160513477946, 49.031525581113755, 36.612493607305716, 3.20791706442833, 0.3629363911046136, 5.819219562315173, 2.3968064592730616, 0.03664185135294834, 0.034142581430534204, 1.9163092490165465, 0.3978858125065604, 30.38241655595841, 55.09985977603544, 28.679490127871116, 29.208055003996822, 27.20070754328082, 44.85357769073979, 3.3281793853928967, 0.050643858680080985, 0.09210560966523425, 0.0622420774532422, 0.010540753137320282, 0.08377726099664166, 0.06104695730872693, 0.036770814594121716, 0.04808165846512683, 0.04273770872743861, 0.04418263865274288, 0.032962863483736594, 0.03735156286688101, 0.021126588633764657, 0.011042621166956042, 0.0016962898371275517, 0.0479765052366401, 0.06065171722683215, 0.032303457133351796, 0.03774321382685054, 0.05300796004913507, 0.08177170409790932, 0.018058665051695802, 0.02342971514970545, 0.02788340177146658, 0.07696377458952128, 0.05986332848307587, 0.013505526810824392, 0.03921192695176409, 0.08793833650528424, 0.03913153751542972, 0.052943367345799366, 0.024718248225267858, 0.8247442735779671, 36.44220782864478, 54.56418952634258, 28.00526019065611, 30.238389084416053, 43.3036688066298, 52.73065797744259, 63.98560108677034, 47.12759140999087, 0.36396037486772387, 0.38995686377729144, 0.39129751764478227, 0.059063988512442, 0.40573692670272243, 23.72919617160674, 59.2554501564272, 59.55608414065454, 58.64069707932011, 54.891079856503396, 57.43634116265082, 56.996957255947976, 57.340666709407685, 53.1210946267651, 52.1282603663783, 52.921457752104736, 54.39398611745527, 53.83884129985687, 54.862266125217566, 53.60469933479063, 52.38872535767094, 51.60549079218219, 50.09824552843648, 46.65700112619708, 44.033135521796446, 40.520009763779186, 41.19901910904915, 43.29292543472783, 40.58653708427183, 40.24423576170399, 42.41769952158774, 41.41722056173509, 42.129177816452525, 42.12879734654581, 41.9176757720209, 39.35252412672966, 42.51664523155459, 40.58378750278104, 41.34589226015153, 41.0041400694078, 41.78453876126198, 43.6804909090842, 41.228805588137725, 42.43354981945407, 40.892513336673865, 43.50504329127651, 41.77096343809559, 41.445543996749386, 42.57456687188918, 41.774258229040335, 42.29199540230536, 42.91305172827936, 43.55256672828428, 43.47028324680944, 42.43698973809519, 42.17313974134384, 42.12734606958205, 41.292453888923895, 43.44985946532219, 46.544570307577814, 53.177172753118704, 58.160277335874504, 56.402369083896765, 57.46842615066036, 49.40224839795021, 59.61375082692793, 54.982643665805945, 56.02854367225401, 51.9886161435035, 57.14559939599807, 57.838658671225275, 53.12430312556606, 54.818249287143836, 54.98486764969365, 47.264752772546586, 38.94508008033999, 42.28782592281219, 40.15459783615605, 41.65781482573479, 41.322012870542466, 41.64584375196888, 41.25133960477768, 41.1440392463438, 41.37516098637735, 41.09759838350358, 40.69462976148052, 39.32719738252702, 39.97636533552601, 38.78137211645804, 37.99068897001205, 38.27283682361726, 39.89286591929775, 37.69351059390653, 37.6225588398595, 38.059573634978264, 36.50406752863238, 36.787050847084295, 36.79712741605697, 37.3832981817184, 38.141508025507775, 38.43837653436969, 42.473958076969275, 43.24644534818588, 45.34188532060193, 47.46516627650107, 49.844397575624534, 49.776062042482444, 52.17479536610266, 49.332853824861594, 49.30334975642543, 49.72809145527501, 48.600472788656916, 47.120476230498284, 48.17208720791725, 50.36028339016823, 52.94800435343097, 49.89234462861092, 51.47023962390039, 50.054950406474454, 37.93683482754616, 3.8312608676572, 1.3404508848344128, 3.9713622918052063, 3.3027893929712238, 0.11799713686829615, 0.23101185238169086, 2.836648057545385, 1.0470356551870224, 34.51354703595562, 61.18395405430948, 39.29506924844558, 31.44504547119141, 26.785536427651685, 54.40727902996925, 5.772060905733417, 0.08127388484295338, 0.07870508478053155, 0.01095030852969015, 0.044236471651182066, 0.03733090530600279, 0.11142925824970008, 0.020003450110614784, 0.01773935768963589, 0.025712720366315018, 0.010951386798443574, 0.08100216111709034, 0.033775177153368155, 0.020586716897425153, 0.016111545339827577, 0.20267605270829894, 0.1333914285585765, 0.16481529801122605, 0.1851666075808387, 0.10545489092868184, 0.08456753431669167, 0.1534621354432837, 0.08128207432286394, 0.17280896584833824, 0.1092065460679512, 0.171375033115187, 0.1289687110411544, 0.20568247283658675, 0.1827481905779531, 0.19325758390609296, 0.12250387890925332, 0.16232200357462132, 0.13570188845117248, 0.9064595016740984, 39.54134310445478, 63.10932790079425, 40.46427288363057, 31.937234286339056, 45.482278716179636, 55.78458401464648, 67.52717971801758, 52.35791906233757, 0.5954474775541214, 4.061895008048704, 2.7931119549658994, 0.368413919763219, 0.7783469858188784, 24.97998510637591, 61.405909215250325, 63.00158823690107, 61.69732955194289, 58.495628218497004, 59.02203775221302, 57.60434019950129, 58.40351919974051, 53.63632540549002, 54.96889183598181, 55.286399856690444, 55.287400061084384, 57.302439289708296, 56.28155616021926, 56.16208860951086, 54.93443773638818, 53.831498622894294, 51.701965408940474, 48.77009568675872, 47.18462267229634, 42.15457908568844, 43.603710512961115, 47.305117883989894, 43.81071752117526, 41.56628239539362, 43.78182926485616, 43.995359174666866, 43.93348770756876, 44.86796886690202, 45.025181385778616, 42.109820919652144, 44.26949754838021, 42.31449019524359, 43.25711811742475, 43.26087182567966, 42.91392641682779, 45.06610739615656, 42.18904495239258, 45.326548853228175, 43.38848221686579, 44.75505559675155, 43.596705159833355, 43.55008779033538, 43.806348000803304, 45.29649957533806, 44.2505132767462, 45.5081977382783, 46.816735729094475, 46.43434386099539, 45.26501863233505, 45.47402997170725, 45.83116962063698, 45.085028909867816, 45.663252953560125, 48.60722318772347, 56.07859703802294, 61.307944097826564, 57.63620945715136, 58.23336285929526, 48.08743853722849, 55.751518434093846, 57.00784183317616, 58.045320510864265, 55.311589317937056, 56.070532644948656, 57.44266794573877, 53.75381608163157, 56.614792885318884, 56.33803436833044, 48.604536364155436, 40.922272359171224, 43.165868097735995, 41.868030332749896, 43.67333258351972, 42.66258485855595, 44.06043914056594, 44.4716682741719, 42.86928984426683, 43.779636659929835, 40.910517015764796, 42.247684386468705, 40.471713619847456, 42.152484540016424, 40.06465788810484, 38.63134145736694, 39.69262499963084, 42.44283799202212, 39.799544888158, 39.29246479465116, 41.849155887480705, 38.325298524671986, 39.0235863193389, 39.314990966550766, 41.1132368733806, 41.70578933531239, 40.07170246493432, 45.41220949542138, 44.63259919997185, 48.18408966064454, 50.75676441192628, 53.437445548272905, 52.84921946064119, 54.32981221906601, 51.09376661239132, 52.431098722642474, 50.788182597006525, 50.90404548952657, 47.32001504590435, 52.6881943979571, 51.57046794891358, 53.74541828709265, 53.307568027127175, 54.57895725004135, 52.20206760591077, 41.1261022475458, 5.430771554670026, 1.3684027978489477, 10.925307120046309, 9.087803190754308, 0.7141923315582738, 0.47507496250252573, 4.546116263635697, 2.280363055967516, 37.28801204312233, 68.21162546834638, 40.40482936366912, 40.006010609288374, 35.46586713483257, 61.53119364092427, 8.149371714361253, 0.3362316998743242, 0.22225938977733736, 0.18404074944555762, 0.12230543915422694, 0.1709007021159895, 0.3731759529440634, 0.06619126070290804, 0.1672844147129405, 0.1153681835820598, 0.18295572379664068, 0.1603087398313707, 0.18444570352233228, 0.08958676619635475, 0.056233500475965204], [0.030977381919060024, 0.033312709025678136, 0.013116960312359998, 0.019424779851350094, 0.02810338583414353, 0.04395666569771786, 0.008050730853762117, 0.052771932190103885, 0.011401791914155888, 0.14041216473185247, 0.03182759970396517, 0.07228664693332489, 0.046023130416870124, 0.011342164418179423, 0.0412030354322445, 0.009557935108821239, 0.11245771596628813, 0.04337142814972228, 0.12408503075881351, 10.747869879968706, 48.10849382031349, 33.79390978044079, 31.726332364543794, 32.88544962483068, 40.131910847079375, 52.42412082610592, 48.093926137493504, 1.460643828876557, 0.6799108775392656, 0.3514367372037903, 0.3477710371296252, 0.09715559231417795, 5.767661967585164, 42.27656479804747, 56.8660246172259, 58.553102708631954, 57.53476911975492, 54.93224905383203, 55.78320334034582, 51.585188604170284, 53.11441875273182, 55.27118498279203, 49.17169932396182, 52.8328670993928, 51.397244314993586, 49.23234701156617, 46.47570133209229, 44.10763702084942, 42.97518207180885, 41.86512777882238, 38.97683951162523, 38.16439505546324, 38.25092254146453, 38.933881713498025, 38.38898997153006, 39.087128716130415, 37.30373290277297, 39.464821584763065, 39.442122828575876, 38.076953657211796, 41.028913759416156, 41.08022228364022, 39.81461463436004, 41.25227705124886, 39.67702181108537, 40.92477875371134, 39.591325867560606, 39.43226983470302, 38.84749543282294, 42.198584156651656, 40.612040335132235, 40.658088960955226, 42.6725516011638, 40.89005008820565, 42.235881974620206, 40.9729846831291, 40.06583067678636, 45.98788007613152, 45.30869422420379, 45.894786542461766, 42.43772714368759, 43.435166266656694, 39.69827321267898, 40.13167550486904, 40.254057376615464, 39.94470788586525, 46.10760650327129, 51.48993776690576, 56.027763120589725, 56.553964768686605, 55.260888761089696, 43.58802103227185, 49.07891957990585, 55.73311467324534, 54.06567981166225, 54.46515752423195, 49.075134492689564, 53.95044449836978, 53.1624952439339, 52.29755378538563, 54.157184785412205, 44.487683311585464, 36.5747800180989, 39.62055929245488, 39.35942357586276, 41.43107437318371, 38.62041373406687, 39.31168833086568, 39.14636042810256, 40.48850528655514, 39.261740869091405, 38.996384682193884, 39.76301977711339, 38.20385409939674, 37.34668677853, 38.21831980059224, 37.86277655632266, 37.58837538380777, 38.36242375835296, 37.72468951440627, 34.91184019273327, 35.38348951647359, 34.165315089687226, 34.71856148012223, 34.87762535772016, 35.61051630204724, 36.5107669368867, 34.750238541633856, 37.698158602560724, 42.13244122843589, 44.667374933919604, 48.361808330782004, 48.35645037312662, 49.03407904409593, 47.53674953214584, 47.89438339971727, 49.766095299874586, 48.03689487518803, 47.98527256135018, 46.531340152986594, 43.336808912215695, 47.8209880090529, 49.69279012372417, 50.59939107587261, 49.35422289756037, 47.862157206381525, 18.39091508619247, 0.48213516752566066, 0.8524949812600691, 2.6927105553688544, 2.048482337305623, 0.1461067567429235, 0.04134255153457484, 2.1390824692864574, 0.2284911166756384, 38.85430466744208, 41.18383953648229, 26.627170731944425, 22.361418624078077, 40.219214962374785, 27.289819871225667, 0.2814781088982859, 0.04425833197010141, 0.04866578135519259, 0.09329460876723451, 0.008414068161660146, 0.03896974740670093, 0.045694712354170705, 0.023180769133051077, 0.02415750442343133, 0.04195180976943624, 0.035395824665864634, 0.05488415917141303, 0.01637597973909109, 0.05433803424239159, 0.03004390569854408, 0.04166760647128667, 0.02050498106156386, 0.1447646013431011, 0.01830819904083206, 0.03925541393278588, 0.024136504038206996, 0.03101647730105587, 0.014580871981208124, 0.04947051841525301, 0.0699273259529183, 0.06930770637888102, 0.027860986038802132, 0.04875773488874397, 0.040103668617385055, 0.0100738886225548, 0.108917148693675, 0.053792974175584894, 0.006495985576146913, 0.08438700569733497, 16.623344075295233, 55.60418244331114, 31.167733900008667, 28.49759021112996, 41.75719591879076, 45.091143884966456, 58.977428636243275, 52.209265155176965, 1.2424049910999115, 0.3456516395653448, 0.39821155309196443, 0.1915501577839736, 0.09840397855206844, 7.524899003967163, 47.24354843939505, 58.498013019561775, 59.81381523993708, 57.636256525593424, 56.556651592254646, 55.90975469158542, 52.68990062898206, 53.0917239189148, 55.749933796544234, 52.15337922496181, 54.83747674572853, 52.10814645213466, 52.43737059254801, 48.216813994992165, 47.877917289733894, 44.04110970035676, 44.12292249741093, 41.48817623815229, 39.901110741399954, 39.77340229095952, 40.54710549692954, 40.17681021844187, 42.18116883308657, 40.514753787748276, 42.27583915956559, 40.42035018244098, 40.86164428341774, 41.31031244031845, 43.320935080128336, 40.23923081736411, 43.01829284237277, 40.409336166997115, 40.175931607523275, 41.4055318986216, 41.46002930979575, 41.52201844799904, 43.453581794615715, 42.382268751821215, 42.06421159928845, 43.66309911974015, 41.52340696704003, 44.87808073720625, 41.446806999944876, 42.28497828206709, 46.788275011124156, 46.30767876102079, 45.51465003721176, 45.239997833005845, 45.60626483732655, 42.35381195622106, 42.68890788478237, 44.18822211603965, 43.42856099528652, 48.092215984098374, 53.31885268611293, 57.78931525445754, 57.61294587965935, 55.854814052581794, 45.858485006516986, 55.09823199241392, 58.258795507492565, 53.278028657359464, 54.742998615387954, 54.44728720572687, 55.5826956995072, 54.75719367304156, 55.47497564746488, 54.41817145193777, 46.437795546747026, 39.377156611411806, 41.378420475990545, 42.49845720106556, 43.73213675714309, 40.7694411277771, 40.89365082402384, 41.01243980469243, 41.54173620285527, 41.47988826997819, 40.58383457122311, 41.24826838893276, 39.84957471970589, 39.74174091892858, 39.84947273808141, 39.05303939696282, 38.060624830184445, 39.01556899470668, 39.29733637840518, 37.77318177684661, 39.23618662741877, 37.830569974837765, 36.74473631766535, 36.04116901274651, 36.93382593893236, 37.62785011722196, 37.38643607785625, 40.547078040338334, 44.91009120018252, 46.97952585835611, 49.79525419973558, 50.370936547556234, 51.098677419847064, 49.51854275118921, 50.200423271425315, 50.45813083648682, 51.24800989704748, 50.11257394667595, 48.3642598121397, 47.837003046466464, 49.65385275502359, 51.06543141026651, 50.701266796358176, 49.9827278044916, 49.72216083157448, 21.306740353184363, 0.8496986990494113, 2.5549941774337523, 5.034012534926015, 2.19853334369198, 0.21086295856343162, 0.08863152350269018, 2.9980467259883885, 0.3994113080684216, 42.16834660499327, 45.988719463348396, 38.710224243902395, 26.500050637029833, 40.01928390995149, 36.608057406640825, 0.18726630136370662, 0.04870696624200191, 0.14303820688397656, 0.11062049156715793, 0.04891695860292643, 0.01921196062598498, 0.027708446441759026, 0.026253452036349524, 0.03421198133559477, 0.04317003895618743, 0.018630245167221275, 0.05451082920415267, 0.04405660186744025, 0.04302932775669521, 0.03381432807673851, 0.165304062106917, 0.17118502798820698, 0.1401708776792211, 0.1148885359326678, 0.12145692783017313, 0.11725737172509394, 0.10980473816274636, 0.1689238735144177, 0.22536483443071767, 0.36076554307533854, 0.11923410839611485, 0.20447971479546642, 0.17068333232835417, 0.15055691552979333, 0.10988798127659868, 0.20095453056837284, 0.18108008008810783, 0.06383468614771001, 0.2747083431290042, 17.96273150751668, 62.74446902736541, 42.51201291238108, 42.44335182251469, 42.59286472874303, 50.179152257980846, 61.811603884543146, 59.589114419875614, 2.4240823763032116, 3.2067258896366244, 1.645514205578835, 0.7145704725576986, 0.24662886115331806, 8.74565484062318, 48.419110236629365, 61.64358131347164, 61.43217340592415, 58.866233364228286, 57.85661920424431, 58.249864270610196, 55.247391885326756, 53.51947799805672, 57.07936625326834, 55.586253289253484, 57.862298796253825, 55.84991893460674, 54.117764965180434, 51.598579575938565, 48.6890124505566, 46.59984434804609, 47.355892965870524, 42.910788520689934, 41.56710609312981, 42.27913787288051, 42.81484734627509, 42.54858901423793, 44.2969855185478, 41.215344013706336, 43.35804462432862, 42.568396983608125, 41.99242438039472, 44.9629843619562, 47.12535173662248, 44.23868340830649, 46.20090400019, 42.50238741597822, 44.45928535153789, 42.607063708766816, 42.019021972533196, 42.64038032101047, 46.71676628051266, 45.250050867757494, 43.30331579331429, 45.79358939201602, 44.094606907136985, 48.46543735073459, 42.94064952481178, 44.24330003799931, 50.91857002627466, 48.59179258346558, 49.16660024273781, 46.6115604677508, 48.3829616731213, 42.18233377702775, 43.30906991035708, 44.978081564749445, 44.710038554283884, 50.62800868864983, 54.13634523268669, 59.3922467385569, 59.70962532104985, 57.91324254005187, 46.131560417913626, 50.19826989020071, 58.08858817623508, 57.21695123180267, 56.41161411039291, 53.0511038534103, 55.536478411766794, 55.99005345375308, 56.414653947276456, 57.16592119586084, 47.444695426571755, 41.45846036172683, 42.0778496803776, 43.75397259189237, 45.420038546285326, 42.283825105236424, 42.38041739309988, 42.4956605511327, 43.672434360750266, 43.37882141913138, 40.95938974811185, 42.415479460070216, 42.70122804949361, 41.58741612588206, 42.7732898342994, 40.95850721482308, 39.60027671629383, 41.871081936743956, 41.5000767092551, 38.944687843322754, 41.477240670111875, 39.82933136724657, 38.31763813572545, 37.81504915606591, 39.563567253851126, 40.84797090099704, 39.09431057591593, 43.26573164232316, 47.543119461305686, 49.976185291044175, 53.444662709389966, 52.14165526051676, 53.53019391336749, 52.43250293116416, 51.87241200477847, 54.26242982187579, 52.458323894008515, 51.22995914951448, 50.9507687630192, 50.87492189099712, 50.77552118609029, 52.19896501110446, 53.473707860515965, 51.007768646363296, 50.82514701351043, 23.118712594432218, 1.1779794481492813, 1.877533065215234, 7.214996459022646, 6.4536928457598535, 0.745948208195548, 0.2651585055695426, 4.311484002297925, 0.8404439279148657, 49.026069564204064, 51.60168609311504, 39.66456436341809, 32.85474138875162, 49.54350471496583, 42.06034021992838, 0.5898750765669731, 0.21603947595482875, 0.22414077914530234, 0.29914860102918844, 0.12822830238409583, 0.1376921389131777, 0.12009942768922738, 0.06395701889789875, 0.10933828254741047, 0.13661339518523988, 0.1489823443755027, 0.1771977609924732, 0.11193401060037075, 0.20398902015820627, 0.09468852106722132], [0.19866175198506927, 0.040412758281754876, 0.04274808921881261, 0.04485244081626016, 0.10705090488397306, 0.06703014996263289, 0.03422585518790349, 0.018815594394841505, 0.049339858289327354, 0.027861554859085914, 0.022840664399066762, 0.021987077742514592, 0.050715081874401345, 0.020571513882567807, 0.030940649918310588, 0.021659988842363802, 0.04038424065877353, 0.14690780892006813, 0.09318754031893708, 1.1490637352389674, 32.63597707594595, 45.962710226735766, 31.734887053889615, 30.51244901072595, 40.358023720402876, 46.97721950469479, 56.217350882868615, 3.9185446356573417, 0.20791099196480167, 0.09862009961638721, 0.23384175053046596, 0.10015360079705717, 0.474530611067049, 19.446016973064793, 51.38657939049506, 58.93618099151119, 55.91879183246244, 56.78560818395307, 55.835308105714866, 54.16621800391905, 52.845654026154556, 53.9066041669538, 55.54947714651785, 53.27081541861258, 50.95967646568052, 46.51264613674533, 42.027690410614014, 40.35601546687465, 38.60913691982147, 38.76829493430353, 40.289390087127686, 38.5640767312819, 38.95594504571731, 40.66991882939493, 40.34785301454606, 39.275037703975556, 39.288303159898334, 38.07291753830449, 40.880836440670876, 40.79221440899757, 40.15614717237411, 39.3040200971788, 41.20243157109907, 42.49129887550108, 40.62905557693974, 39.592573181275405, 38.60168441649407, 39.75621446486443, 41.36002455988238, 38.85664240006478, 39.83369696524836, 40.202850834015884, 42.30732402493877, 38.04895185655163, 40.96943101575298, 40.652370145243985, 41.032698846632435, 48.563520139263524, 48.55898195697416, 50.11550395719467, 46.927609366755334, 44.499772056456536, 44.00289797013806, 41.817474903598914, 40.40540595208445, 41.69015084543536, 44.559545055512466, 50.67752861207532, 54.19512587208902, 54.48658543248331, 54.91963078898769, 48.43169712251233, 45.01479102719215, 55.82331349772792, 54.641609268803755, 53.87320518493653, 46.193533866636216, 50.33119117060016, 53.39785706612372, 53.46167010645713, 54.962372856755415, 44.82975713668331, 37.26119872062437, 37.690368775398504, 40.85370932855914, 41.600128527610536, 38.02433113898001, 38.92691166170182, 39.49620839088194, 39.629337556900516, 37.85250779121153, 39.01596907646426, 40.369120105620354, 39.13761354261829, 38.31134273159889, 37.5051034650495, 39.38267538624425, 37.759822184039706, 38.864887222166985, 37.163025717581476, 36.760645451084265, 35.70876383012341, 35.69284292959398, 34.77337660328035, 36.91790111603276, 36.457924765925256, 34.54389049160865, 34.68472319264566, 35.25125857322447, 38.91982393880045, 43.158419516778764, 43.72407628643898, 45.35624904017295, 46.00918246853737, 47.009547679655014, 48.156480097001605, 48.60972958226358, 51.51953597222605, 49.73854457178424, 47.38579711606426, 44.35515426820324, 47.23452698799872, 51.860527223156346, 49.4082574690542, 51.887485673350675, 38.518647839946134, 7.251731416871471, 0.09656893750352245, 1.9754818802879703, 1.604054139987115, 1.6761529421614063, 0.30588576209641277, 0.05797042098316935, 1.2453395368591433, 2.100476295717301, 54.08992005932716, 36.95799950630435, 25.067640273801743, 22.480403723255282, 45.97229649943691, 11.160370842103037, 0.12501157579883454, 0.037612128522126906, 0.11787726709078397, 0.026314225791382696, 0.041377029321607084, 0.033482864814540075, 0.03812208260980345, 0.04362296162834091, 0.05663974541089228, 0.043653903919602596, 0.0569159584119916, 0.11898749703240973, 0.06820511433386034, 0.0648999275759824, 0.05516504530885047, 0.02775168827464504, 0.037197169337061145, 0.0053646642763558175, 0.06177527709834038, 0.05311856782364269, 0.07070865136601272, 0.05019588493591836, 0.01962748671611471, 0.023742279022811882, 0.059720319019810814, 0.0067883635112535095, 0.07357453266459127, 0.03516074675585955, 0.022033523738143906, 0.045586226643213344, 0.017112144269049168, 0.1217693538074532, 0.06057733008938451, 0.05263186067402844, 2.15760120461064, 45.696271465670684, 47.840207622897246, 29.77418245807771, 38.397932975522934, 47.18526986337478, 53.48230961830386, 60.88143341002926, 3.5301611019719035, 0.20940756004664207, 0.04711220101002724, 0.12772829211767645, 0.05801252900592743, 0.4825242482606442, 21.649498631877286, 53.56615028073711, 59.62016390215967, 56.82223527662216, 59.01314966140255, 55.710427684168664, 54.343968053017896, 52.910286841853974, 54.81606844932803, 56.95204219510479, 55.326439411409446, 52.552401942591516, 48.20721595518051, 44.1837937601151, 42.26185198753111, 40.723733748159106, 40.98462235543036, 41.85593374313847, 42.18570701537594, 42.24134975864042, 43.48705137929609, 42.201651450126406, 43.23624326336769, 42.00125363565261, 40.54491681437339, 43.25715734112648, 42.027808081719186, 40.493914235022764, 41.907720796523556, 41.54031630485289, 42.44405784914571, 42.12558492537468, 42.13108408835627, 42.067980997024044, 42.45284788070187, 42.79547868236419, 40.03211790515531, 41.71181017352689, 42.39221196020804, 42.28344071295954, 41.3326621055603, 42.743311159072384, 42.320314914949485, 43.76075044755013, 48.97996994756883, 49.27898007054483, 51.86376710091868, 49.2126488685608, 47.58722651389338, 44.91024809498941, 44.0866837193889, 42.74670008690127, 44.538297576289025, 47.18637597176337, 53.25553386442123, 55.77386417696553, 56.1856306752851, 55.33427630701373, 49.45721257117487, 50.64720869064332, 57.44230708768291, 53.798087873766505, 55.24199470396965, 52.135563819639145, 51.7447074767082, 56.055560958000925, 55.02175754116428, 54.7009821861021, 46.280339840919744, 38.93039472641484, 40.94757164678266, 40.89376065038866, 43.79175286139212, 40.02308076427829, 42.143408175437685, 40.48093903449274, 41.406838047888975, 40.58618014858615, 39.288248246715916, 40.6202341664222, 39.61849220337407, 39.771892178443174, 40.82575067397087, 41.34733177000477, 40.2296406222928, 40.084952231376406, 39.601076879808986, 38.89891378341183, 38.362768926928126, 37.489104117116625, 37.02236952320222, 39.089270330244496, 37.67595014264507, 37.128830494419226, 38.11525560194446, 37.60423352641445, 43.07168806752851, 45.06750375993791, 47.21811579119775, 46.28941620549848, 49.685153268998675, 48.42512323010353, 51.28969292486868, 50.0015434142082, 52.85911167821577, 50.89530644878265, 49.325864161214525, 47.18999239706224, 48.67903394083823, 51.35366678237916, 51.52940857794977, 52.446042952998994, 40.578025540997906, 8.78690444654034, 0.678500785462318, 4.343678816672295, 3.9258848611385595, 3.5565037400491777, 0.7987830247129164, 0.10648321074944352, 1.4161477261973967, 1.9365988118994621, 58.03431826253092, 43.97890875416417, 35.2511134455281, 19.98164996024101, 52.77342357943135, 14.848803012601792, 0.048770363848175735, 0.08099936489616671, 0.10401764869569771, 0.02773074343079521, 0.028320382153915784, 0.026418559305790453, 0.006091777477488523, 0.028144149372594494, 0.015936603416658698, 0.05455862159930891, 0.028822635142733494, 0.08435578761442054, 0.1254156182309793, 0.035111498793647174, 0.006665901004922607, 0.20544089467054416, 0.25390508764934155, 0.16243506283048662, 0.172685181361533, 0.25302788633252343, 0.2856565669419304, 0.15589599677872273, 0.13160201570680066, 0.1526980853128818, 0.175268184694071, 0.19066822204378345, 0.2211207379737208, 0.15312920895314988, 0.16994902173117285, 0.12051951200250657, 0.07855951275315978, 0.15238919866181191, 0.20069694116471276, 0.28186936532297446, 2.369762207231214, 51.32355866893646, 57.348989978913345, 41.41631449422529, 41.48536389873874, 50.102995518715154, 57.07245503702472, 66.6921777109946, 5.3657994539506975, 0.7817621444982867, 0.21300077288141175, 0.4772721639563961, 0.28026119355232487, 0.8288060717525021, 24.080060028260757, 54.46164308055755, 61.95580982392835, 57.858980471088046, 59.99919429902108, 57.42574684081539, 56.15108636117751, 53.833946181881814, 54.75104339661137, 58.2900881767273, 57.699238023450306, 54.95906629870015, 50.73382639115857, 45.551645832677046, 45.058607824387096, 41.64707929857316, 42.401202032642985, 44.94134072334536, 44.70273510102303, 43.32740306854249, 47.80707143968152, 46.10646901592132, 44.5477230318131, 43.17224587163618, 41.277552804639264, 45.126272632229714, 44.78025290273851, 43.4865689277649, 44.67551385202716, 45.730109753147254, 47.38081962831559, 45.057682145026426, 44.36376387073148, 43.82056659267795, 43.7009225353118, 45.896084846988806, 42.08720453323857, 43.62495406981438, 44.79941760340045, 46.14783040938839, 42.333548991910874, 43.81086264887164, 43.40904720367924, 45.37722195348432, 50.644772898766306, 52.643985363744925, 54.498874218233176, 51.289543874802135, 50.40947383449924, 48.15204781870688, 46.943220400041156, 43.48346633295859, 46.73365208410448, 48.17158514453519, 55.55935367461174, 56.77455886717766, 58.31109246900005, 56.57309809038716, 49.82114184287287, 46.24675650750437, 57.64457587272891, 56.9732935966984, 56.496270625822014, 51.43552664787539, 53.50065062122961, 57.75398646631549, 57.672589440499586, 56.382635639559844, 48.419467172315045, 40.38519397858651, 42.58581230717321, 42.96919261255572, 46.19921345864573, 41.72173377006285, 42.221969327619, 42.25256381496307, 42.89735440284976, 41.62392554744598, 42.0690361146004, 44.183676089009936, 43.46583920140421, 42.024026916873076, 41.82886938894949, 43.408635354811146, 42.07313891380064, 42.22383637582102, 39.93843601595971, 40.96279044305125, 40.49353376511605, 39.599829566094186, 38.055737556949744, 42.144781004997995, 40.76102372138731, 40.03864472912204, 40.253037560370664, 39.25723798813359, 44.60716262940438, 48.397839223184896, 49.41692590713502, 48.10999216571931, 51.09591999361592, 51.44934908036263, 53.418508345080966, 53.08353008762483, 53.399488772115404, 55.21761717334871, 50.09877112603957, 50.48454015485702, 52.04295273750059, 52.741126783432506, 51.50853372389271, 53.67503527672061, 42.9821599683454, 9.82253666846983, 0.34422469355406304, 4.878130680130375, 5.962322825385678, 4.541391768763143, 1.3382423452792631, 0.3618871570835191, 2.6143188005493534, 3.338003206637598, 64.54899464884113, 45.915700620220555, 37.91625415125201, 29.055951372269664, 59.416000612320445, 19.677146557838686, 0.2776145129915207, 0.24773965800000777, 0.30935534366196205, 0.05273013826339476, 0.11625182769832113, 0.14395639390474366, 0.10813413788714718, 0.08655843595343252, 0.13884278765368846, 0.16341579326939198, 0.08430291988676594, 0.19721144029209692, 0.20471995996852077, 0.13043842008036952, 0.10466941331903781], [0.058239172287886186, 0.08944652614093597, 0.028804277760847926, 0.032447018179922335, 0.024883592981965314, 0.05353646112545844, 0.019643480716753873, 0.066878579466814, 0.023169509555783965, 0.00948439928657946, 0.07073519631258904, 0.04248393444164146, 0.12467429026841156, 0.04052650701675204, 0.013514147215192358, 0.0724645325493428, 0.010848388192243876, 0.11006317792400239, 0.07666186699944158, 0.14101751208786042, 5.262063059114642, 46.5512030355392, 38.937874686333444, 32.816333540024296, 44.335161947434955, 31.989188040456465, 61.16719376656317, 9.024513786838902, 0.3744229295801732, 0.08827203674422157, 0.04750374088724775, 0.06356316926558653, 0.17277254602841793, 3.2791978072735573, 30.77759535081925, 53.106197464850645, 59.50072380804247, 56.221983202042125, 55.47743105119275, 54.25264350829586, 54.87690441070065, 52.3301173025562, 53.72593587444675, 54.06407948463194, 51.61020940349948, 47.016874667136904, 44.87210696743381, 42.09056992684641, 39.30220011741885, 40.11644494148993, 40.588957186668154, 41.44127645800191, 40.205325849594615, 43.54276080285349, 46.47710161824381, 46.50791575831752, 43.73912642079015, 41.04928655009116, 40.42540611759309, 42.40405751812843, 40.184705949598744, 40.09927280487553, 38.70399552006876, 40.060562933644945, 39.718728373127604, 41.39023073257939, 39.341541490247174, 40.069996233909364, 39.25238601623043, 40.55237324007096, 40.60631367468065, 40.54366165591825, 40.747766110204886, 39.05118411587131, 42.79186225706532, 39.37417561008085, 41.990423971606845, 51.75795724315029, 51.11093090426538, 52.82696000991329, 52.16542090139082, 50.449497699737556, 46.7134597224574, 45.32803935389365, 44.03089192605788, 45.5726069788779, 46.3574928622092, 52.49810849466632, 52.24382908113542, 54.64849695082634, 52.72372714934811, 49.87991855990503, 46.98003576647851, 55.02212624396048, 53.36526609236195, 54.922207786190896, 43.86811748627694, 51.80658678854666, 54.84005766530191, 52.35984886846235, 55.10119338189402, 44.392267734773704, 37.34687897466844, 38.91821184465962, 40.03641682286417, 37.70848228085426, 38.59558120850594, 39.257641992261334, 38.34766387939453, 39.1144048783087, 38.977490625073834, 38.89788220005651, 38.52628077230146, 39.61684480790169, 36.462576696949625, 36.608324127812544, 37.30150107414492, 38.09012105388027, 38.01034004457536, 37.517859012849875, 37.17718939627371, 36.93019774652297, 37.92878612395256, 35.528119071837395, 35.35919043325609, 34.86162208741711, 35.20644157163559, 33.25762371863089, 35.32723096109206, 37.29541747800766, 36.07707438930389, 40.69702240728563, 43.210367387340916, 44.62739813712336, 45.95495962327527, 46.23590723160775, 46.50853549280475, 47.819195485884144, 50.37882051160259, 48.53099192342451, 45.333397311549035, 47.80371389081402, 51.427929016851614, 50.93017239724436, 46.65837395575739, 23.220217650936497, 1.2020788582101947, 0.40206249322622056, 4.1184347483419605, 2.8737144556737717, 2.0556204381488987, 0.27061173391918986, 0.3262821176359731, 0.8407102200773455, 11.917097049374735, 52.480002833950905, 30.769123031247048, 26.459699253882132, 27.42108395022731, 37.24467377508841, 2.054909998851438, 0.0906629741732632, 0.027897206675862114, 0.027558208938928384, 0.06037639288772499, 0.03947488663177337, 0.07776484974930364, 0.029107100825997132, 0.046496239505828395, 0.05922802708922856, 0.05435623266103287, 0.061021178450074896, 0.0682612685787101, 0.08644876280619253, 0.06489644953680616, 0.02071336080740777, 0.0516340273222135, 0.011731495089348287, 0.015094374971193893, 0.018857966717933456, 0.03131342638704566, 0.036935611597953305, 0.0038090317731633064, 0.0664995881097932, 0.05155632302405373, 0.04136114448849713, 0.021580941975116733, 0.013442913487163043, 0.05749546945275319, 0.07179394514570314, 0.0252466899297771, 0.028209916105674162, 0.05105669580159649, 0.0461513428918777, 0.01872526305246978, 0.15860984792872784, 13.381152114560528, 57.09514987084174, 36.52905694900021, 36.75916279515913, 55.75348354155018, 38.00229134098176, 66.05868354920419, 9.083371893052133, 0.41305076811582814, 0.02297998897941603, 0.4053668143047441, 0.05005115560526329, 0.3162005844135439, 3.5704713002327955, 34.836209051070675, 55.55473704491892, 61.71462328203263, 58.208342059966064, 55.98967690621653, 54.0618476560039, 56.06143274614888, 53.10228686178885, 55.55938505357312, 56.89807038153372, 53.695647331976126, 50.36471959083311, 46.698480190769324, 43.93205604245586, 40.963574917085715, 41.8878226126394, 43.102262943021714, 42.518296549397135, 43.24200914752099, 45.19593784886022, 48.27784999724358, 49.47520840552546, 45.995089392508234, 42.35676550096081, 41.23576387282341, 44.26506134771532, 41.755987828777684, 41.376137656550256, 41.00942742440009, 42.643773171209524, 40.99322019084808, 42.31851454704039, 41.137512422377064, 44.02719705335556, 40.79113183483001, 41.415377047754106, 43.0990779784418, 42.94156343706193, 41.3155331150178, 42.130860513256444, 43.611112025476274, 41.44774836878623, 44.01064072885821, 54.92307462999898, 51.011820454751295, 55.93210435682728, 53.198439844193004, 52.26181314837549, 49.72379253756616, 47.981946391444055, 45.80998489933629, 47.13205114487679, 47.219221899586344, 53.53638341349941, 55.23449120983001, 58.179336132541785, 54.40969128762522, 49.721968635436035, 51.17036657948648, 57.63175364463561, 52.52976202195691, 56.329899372593054, 49.59955538472822, 51.770763781762895, 57.753437334491366, 53.17199914686142, 56.30036392519551, 45.56371496569726, 39.13371078429684, 40.32687225649434, 40.42904215474283, 40.53147092942269, 42.35361191534227, 40.65862240329866, 39.327005186388575, 41.97103961821526, 40.61267183672997, 39.807746564188314, 40.61053414498606, 40.72436524975685, 39.56596774439658, 38.4121633345081, 39.28449061609084, 39.31034295789657, 39.370025742438536, 39.804749873376664, 38.3084794013731, 38.31137803293044, 39.64361106195758, 37.243379392931544, 36.798782656269694, 36.478587811993016, 36.84743965825727, 36.380352051027366, 36.908922810708326, 39.157547027834006, 39.55048614932645, 43.47166784348027, 45.51849395998063, 46.633368845908876, 48.56069603273946, 48.68483904869326, 50.54403466563071, 50.505968063108384, 52.23099116356143, 48.71191516999276, 48.93860855410176, 50.23379871922155, 52.782652916446814, 51.95233814177975, 47.35025259756273, 25.73216038365518, 1.8288081571940453, 2.570190420073848, 6.137052159155569, 7.0502951548945525, 5.81707206464583, 1.1441360125618598, 0.4639076375432553, 1.3874275189253593, 13.38561773300171, 58.54814091036397, 39.8436087946738, 29.298536239131806, 28.01224397074792, 48.47361549254387, 2.931484594460457, 0.023308608140195572, 0.012039037256111062, 0.03682064861359616, 0.06137414580030788, 0.03349914801337066, 0.022394119408882918, 0.12071497933638674, 0.03747724342129884, 0.020377982835916263, 0.05783701443203515, 0.05137218613057368, 0.020900550561266083, 0.02410003250735181, 0.04356674992689683, 0.05770185353955435, 0.20674420941260555, 0.16932522697794825, 0.1198059164227978, 0.1022046173532163, 0.13553710293865975, 0.1181896164592716, 0.1335746614683059, 0.19688076610046049, 0.12042855438325675, 0.1403469859712547, 0.1220958911242985, 0.11949838574735389, 0.17630145344282352, 0.14682919297727848, 0.10292526094182845, 0.16232612512765393, 0.16646359746734943, 0.17691341979849726, 0.19362699150318102, 0.2167199612144501, 20.412775316546043, 64.39290392783381, 49.353265839238325, 43.58262777328492, 57.36167492405061, 41.262694866426536, 72.93870910521477, 13.784546313747285, 0.7333148054538235, 0.3729106107306096, 0.7714467399543332, 0.0805144005965802, 0.4313994625643377, 4.932160348661484, 35.401269620464696, 57.83909013194423, 62.9282634488998, 59.70668354342061, 57.736771183629195, 56.40826440626576, 57.68161873663626, 54.60874765150009, 56.055772765990234, 59.85469025950278, 56.453461877761356, 50.85783212415634, 48.44117356884865, 46.74643508849606, 42.33118380269697, 44.707398799157914, 46.31393886381581, 45.50757015905073, 44.510825295602125, 48.06564584855111, 50.156551561047955, 51.46628195239652, 47.48544493029195, 45.42300778050577, 44.47513564940422, 46.22366943667012, 43.57586952947801, 43.9998032200721, 43.33456923884731, 43.32501042273737, 44.28462220776466, 45.27016478200113, 42.67345374630344, 44.596540850977746, 43.66173021255001, 44.59341079958024, 44.79900183216218, 44.95583780350224, 42.99561762040661, 44.666425720337905, 45.24354757801179, 43.82131184301069, 45.52093759659798, 56.842615912037516, 53.431063852002545, 56.66663092951621, 56.39229251492409, 54.92825608099661, 51.65419094024166, 50.29219888871717, 47.572470557305124, 50.25830568805818, 49.560253235601614, 55.9025453752087, 56.6398685978305, 59.20829542221562, 56.14757976224346, 49.82872770678613, 49.5785746266765, 58.001162467464326, 56.037874990893954, 59.70007434968026, 49.478707159719164, 54.483525983748905, 58.693284296220355, 57.52377471616192, 58.74002325919367, 48.07141565507459, 39.95734968493062, 42.838083467175885, 42.64154918732182, 42.05864967838411, 44.516316613843365, 42.905760042129025, 41.59066777075491, 43.16705657589821, 41.59751622907577, 40.82104382976409, 43.00659633451893, 43.643699076867875, 40.50073523675242, 40.61460556522493, 42.420492249150435, 42.729096489567915, 42.04753368131576, 41.75659579615439, 40.54294386217671, 40.85494095279325, 43.19816881610502, 39.598692078744214, 40.310998424406975, 38.26586284945088, 39.1949938958691, 37.482742032697125, 40.061916151354396, 42.87617360391925, 40.44229584355509, 45.73488327764696, 47.67082006700578, 48.441091199075025, 50.747711581568566, 49.8637701619056, 51.78157775632797, 51.560140348249874, 53.45028738821707, 51.19440286390243, 52.33249425888062, 51.83206258281585, 53.65199527432842, 51.79558846258348, 50.14247417449952, 27.72535397160438, 2.0842595013879963, 1.9131247747328974, 9.140514942907519, 7.631375174368582, 4.420199355771465, 1.8294221307000809, 1.0923707773608546, 2.8302565553495964, 15.505615665066628, 62.969060021062056, 42.283750580203154, 37.51166951271796, 36.77075339901832, 55.702975180841264, 3.955548275862971, 0.14120086757165773, 0.1234029443754304, 0.12754389475430214, 0.4041455475793731, 0.12921457929957297, 0.14447909569548023, 0.22184211700674028, 0.15241694636642933, 0.2150620090504808, 0.18728680187656035, 0.18315579531894577, 0.15420488832939058, 0.10969607625156642, 0.29718962227625234, 0.10585733989794409], [0.07607095273992709, 0.046337831675285296, 0.0925488451555852, 0.05148238021760218, 0.08376423750192889, 0.05754684330895544, 0.02061757491901517, 0.018576789467084794, 0.057153376720605366, 0.06918265784700071, 0.059346717091337334, 0.03318587167849464, 0.02130522501594838, 0.015288567726290034, 0.05399948466689356, 0.06754809434735967, 0.011619115736515773, 0.06240654120882673, 0.08975863802216708, 0.11194939364589031, 2.4501283851362046, 34.7123602128798, 40.34687242200298, 28.608689385075724, 37.54886142669186, 32.00066293439558, 52.67906704256612, 24.554070618844804, 0.1716922241593561, 0.38425134735242017, 0.2680660543903228, 0.12643987012486305, 0.0907602826614053, 0.12082163409720506, 8.265286087989807, 39.40269124123358, 53.27690685949018, 58.20170148726433, 53.373405010469504, 56.12640288568313, 51.27272475150324, 54.84411339606009, 54.23172158579673, 53.26428467227567, 51.2654056087617, 49.832022497730875, 45.602711169950425, 43.933495552309104, 41.08019874941918, 41.9224924425925, 41.842680054326216, 43.5077928727673, 43.92671769665134, 46.56827319052912, 45.820571376431374, 48.17435041550667, 48.35262606220861, 46.891500026949, 40.228059907113355, 40.31051205050561, 40.552086907048384, 40.42402152092227, 39.28034074844853, 41.17770494953279, 40.82886503588769, 41.1413759569968, 40.18194460099743, 40.07362442631876, 40.82449159314556, 41.283914889058764, 40.03682474936209, 41.45229439581595, 39.49144663349275, 40.49649907696632, 41.26089057614727, 40.5555699717614, 45.4556615121903, 55.23931964751213, 53.31182379876414, 54.704830031241144, 51.91005891369235, 51.98617642925632, 48.0280577751898, 47.803164758989894, 48.12233586465159, 47.82333750878611, 47.814857344473566, 52.769579656662486, 54.27161601281936, 56.54668092727662, 55.86605556549565, 57.463534955055486, 43.060662284974136, 52.522521326618815, 55.76114000812654, 53.787642601997625, 42.203596945731874, 53.01910515754454, 55.092215076569595, 52.69036739103256, 53.786803214780754, 44.57192405577629, 38.265968753445534, 38.54436682116601, 39.49752238488967, 38.60484976922312, 38.00385244431035, 37.80010492570939, 38.58219023673765, 39.32514206055672, 37.659236923340835, 38.37861530242428, 39.52355123335315, 37.131650678573116, 37.27941813007478, 38.853939887016054, 38.073192104216545, 37.93988250917004, 35.58745668780419, 38.08453559875488, 37.686642523734804, 37.333680199038604, 36.98998251268941, 34.8022727043398, 35.70563770109607, 36.4976897547322, 34.65462292394331, 35.58334996623378, 36.820622413389145, 36.85213865772371, 36.37069909803329, 38.311554539588194, 41.14295274980607, 41.857051618637584, 44.019058135248, 45.819822203728464, 47.88778989545761, 49.33760381514027, 48.05975837092246, 48.79883097064111, 45.79810796245452, 47.07971103729741, 50.00946267958611, 51.383017878378595, 40.32944140895721, 8.982752311614252, 0.24882943339405522, 3.9927904452047045, 5.343711116621572, 5.796643870492136, 2.861370266445222, 0.6575121826702549, 0.14301470330645963, 0.304367222612904, 29.48447619715045, 43.62880583732359, 26.605466296595914, 20.964158581149196, 31.17131502397599, 12.293354330524323, 0.08213058564691775, 0.15085063363996246, 0.07351740548807768, 0.021146135367152673, 0.022420419207323464, 0.03619000886476809, 0.03437976608233106, 0.07423431822849859, 0.028096356977438255, 0.12042156000050808, 0.05439734859992901, 0.02598632675325198, 0.03193994841328071, 0.012653614056386776, 0.009091929570140858, 0.04463967521704974, 0.009220101825532415, 0.027762379031628374, 0.03445262104393013, 0.045015686492045084, 0.07550589394785705, 0.05229358689018315, 0.025612962312035026, 0.07104154721262955, 0.08854729213541554, 0.07879789633255813, 0.07408021198165032, 0.026209315795811917, 0.056738406044220736, 0.029212135310855605, 0.05295470544707872, 0.048450173569783095, 0.07321291618169316, 0.03988518800225951, 0.07367105208217137, 0.1752547321901206, 3.6952541528209566, 49.546705369026434, 45.7848072052002, 30.463084020922263, 49.973149376530806, 36.53657221025036, 58.80070624812957, 24.162649454609042, 0.17913289908920565, 0.3728561265574348, 0.13482638784954626, 0.13112120360376375, 0.12616267653122065, 0.09232932266088263, 10.016156627285866, 42.128095242284964, 56.049159649879705, 59.66760496939383, 53.76226486698274, 57.47381548727713, 52.46029292383502, 55.71295369055964, 55.95175150902041, 55.93660331541493, 52.8694785025812, 51.61087620642878, 47.829013178425456, 45.25726410650438, 43.60217294385357, 44.296710952635735, 44.0422942561488, 44.33907647286692, 46.40508297950991, 48.0098658223306, 48.89368564851823, 50.68745613098145, 49.488830797133915, 47.29674754604217, 41.48653668742026, 43.1900808888097, 42.23881198513893, 42.0377669795867, 41.269147165359996, 43.183573676693825, 42.12977401671871, 43.537697022961034, 43.17393249081027, 42.89487154253068, 41.154053057393725, 42.60062317694388, 41.8682695973304, 42.93241646982009, 40.33882764077956, 41.06617235368298, 42.68319691381147, 42.73867883989888, 46.304030956760535, 56.994478317999075, 54.81799041071246, 55.47285364520166, 52.97062466221472, 53.93564147333945, 49.82469158787882, 49.48638716051656, 48.550642997987815, 50.83566288794241, 49.14132056697723, 57.5116624370698, 55.559169323213645, 59.08173622623567, 53.42261506665138, 55.78580779414023, 50.67159798837478, 52.87738207847842, 56.59784432380431, 58.566454456698516, 49.12798450839136, 52.849344976486705, 57.04192330760341, 53.01559855861049, 53.801351285749874, 45.91212734099358, 40.328892277133086, 39.806118780566806, 41.410976148420765, 40.43378822265133, 39.499903263584265, 38.83324938435709, 40.30569930230418, 41.418393350416615, 40.44262532264956, 39.987151853499874, 40.79092787158105, 39.48484528449274, 38.95482324784802, 38.10753637744535, 38.06872060222011, 38.0270375743989, 38.34331789324361, 39.20343483647993, 38.54478651477445, 40.12198725054341, 38.87181805026147, 37.776080408403956, 37.95440704591813, 37.36167415495842, 38.39902731680101, 36.747148575321326, 37.568657628951534, 38.69107131035098, 38.130293969185125, 39.74372956060594, 43.26359002820907, 42.69416778318344, 46.86853062721991, 47.69556630042292, 50.986842801493985, 51.94439534218081, 50.33004191613967, 50.43193332610592, 48.87401496210406, 49.793834301733206, 51.81082294833276, 52.06842853176979, 43.25118357135404, 10.045451829510352, 1.2002381634327675, 5.081436932086945, 6.788027344211456, 8.107212118564114, 5.8317147627953565, 0.928535704170504, 0.2985445253791348, 0.5389131918068856, 32.2259795665741, 50.35053237791985, 36.21703632416264, 22.30149265258543, 34.46217575380879, 23.854623763791977, 0.06746001721870515, 0.11493195779621602, 0.054096023236671766, 0.060992197343899365, 0.05173803141881382, 0.06291870546016483, 0.025948545212046276, 0.024885023651163907, 0.02391216476568051, 0.07398332484186658, 0.043622670514929685, 0.028481038452516642, 0.033009265429310264, 0.045921309670854005, 0.014080357054368624, 0.059169609054562554, 0.1996521964188545, 0.16992371018615463, 0.14628442785432264, 0.1229602757901434, 0.20786950064282264, 0.14008601045896932, 0.09580497930367148, 0.13016953854070556, 0.14935461714142753, 0.15433766668842686, 0.13116801157593727, 0.18366432448308315, 0.13876305322252935, 0.08102842261113467, 0.21175158991208, 0.13176776649009797, 0.25717390821345393, 0.16537212135811008, 0.34124096495009243, 0.3481584018276584, 6.30957123733336, 56.79878734773206, 51.9980102200662, 38.85579909047773, 49.96943489197762, 43.348576022732644, 61.586185270740145, 31.238669964575003, 0.4759620923188425, 0.6137203292981271, 0.8231623326578449, 0.3402669914066792, 0.2368901982422798, 0.38509811965688584, 10.283947625467855, 43.509632464378114, 56.637950558816236, 61.66274601413358, 55.89629703952421, 58.838800307243105, 53.59858043732182, 58.314720661409446, 58.160850001919655, 58.89176407167989, 54.720444986897135, 55.89115873459847, 49.554350068492276, 48.13418926731233, 45.52897845545123, 46.42685997870661, 45.895065030744, 47.928464874144524, 49.363699343896684, 50.43783257084508, 51.146063573898815, 52.752270237092056, 51.01135369270079, 51.08344685646796, 43.03588075022544, 45.77633096325783, 45.65725564956666, 44.913385991127264, 43.90132819452594, 46.78514888209682, 45.4230313147268, 46.585449249513694, 44.80376358955137, 44.65654919224401, 45.007569943704915, 44.45378226618613, 45.60161290630218, 45.72107653464041, 42.61926620237289, 43.87520913154849, 45.36983220807968, 44.6647391011638, 49.698261830114554, 59.97032565455283, 56.05756136678881, 58.38491147564304, 55.45447341857418, 57.732350672444994, 52.77443947330598, 49.72285509109498, 51.53770439086422, 53.89087938493299, 53.48809903667819, 59.30149878225019, 59.7887630616465, 60.29045381853658, 57.05937785487021, 52.46244238268945, 49.05524807591593, 56.37927416832217, 59.81511746683429, 56.89777228140063, 46.61123883339667, 56.899525580867646, 58.33772928484025, 55.76107725020378, 57.1147931006647, 49.07622491159747, 42.86131566570651, 42.462406696811804, 43.28582594471593, 41.722169153151974, 42.736851015398585, 40.98483416341966, 41.430764505940104, 44.47553965353197, 41.41871890714092, 40.79216341818533, 43.271987822748, 42.356294816540135, 41.393984440834295, 42.746978575183505, 41.30194994711107, 40.7521983884996, 38.86707590472314, 42.062179811539195, 40.341090848368985, 42.75872215147942, 41.04512883770851, 39.027959762081025, 40.62609418745964, 40.24806791736234, 40.79790969048777, 39.09159629575668, 41.02368523997646, 41.24543251529817, 41.497189844808275, 41.49431474747197, 46.76589396692092, 45.45706572071199, 48.05616940221479, 49.84849253008443, 53.390647749747004, 55.59936969510971, 52.9763081765944, 51.07800260666878, 51.49135374253797, 53.239605119151456, 53.64753946181267, 51.78906556098692, 46.08533528543288, 11.173401936408013, 0.7273422001350311, 7.435495930333292, 10.636116650796707, 12.030784007041687, 10.045882309636763, 1.531120363262392, 0.4510988925974216, 0.8177036804056937, 37.94491098773095, 54.6988994075406, 38.57543199293075, 30.88708439180928, 45.2654657825347, 32.35536090789303, 0.20947958763328292, 0.3278530575335026, 0.18500963616515362, 0.07411429523340157, 0.15686031761429003, 0.10033452012125524, 0.09792140444680568, 0.08864217978571692, 0.09373081157044058, 0.20942098190707548, 0.1140690363583065, 0.06760699118697835, 0.16859704508416115, 0.1689844251039528, 0.07082515801753729, 0.24503273228483818], [0.05809585638945142, 0.06799055608890711, 0.07556785513917286, 0.027678396642929124, 0.08660332104491611, 0.06169057841743193, 0.03427631739947585, 0.017795563645420537, 0.061500764812432954, 0.05895810366998758, 0.06927152404621725, 0.03405594454717732, 0.020188174976576722, 0.017323873734341997, 0.07411511494748055, 0.033304703406869404, 0.020731869491658384, 0.04421732328351467, 0.013040971093540712, 0.027655036706898003, 0.026987597924627127, 9.749660991853284, 43.914311239796305, 34.42530155181885, 30.858196135490175, 35.13651355620354, 36.003592706495716, 44.04167452166158, 0.2516681109104426, 0.13152176033585303, 0.7972132186255148, 0.28257643383356834, 0.06807910053119545, 0.07143962948072342, 0.21458956262757703, 12.721034865225516, 41.810610755797356, 54.932296122274096, 52.68381703284479, 54.535034548851755, 54.0129945355077, 52.56394547800864, 53.54907228100685, 53.58450305077338, 53.62624883651734, 51.308818401828894, 49.99471849010837, 46.15736961364747, 45.260939367355846, 43.99538663125808, 42.66086686042048, 45.1116382691168, 46.17648332349716, 46.11499232630576, 50.13970498115786, 48.86114566556869, 52.02563939555999, 50.2565876899227, 48.60344594524753, 40.754489052680235, 40.9676855610263, 38.750554054014145, 40.3035145421182, 40.38388782931913, 40.48135872810118, 40.95505945144161, 40.50420653435492, 40.70221954776395, 40.52262990705429, 38.8127314659857, 40.88641012868574, 40.186392568772845, 40.86843390618601, 41.09820242851011, 40.399957779915106, 39.99683618545532, 45.529272633214156, 53.73432582424533, 53.1792986777521, 54.3796576992158, 56.33166836154077, 53.22312331968739, 52.09202158835627, 48.5120351083817, 49.79303021584788, 47.486590262382265, 52.08935829900926, 53.32015883538031, 54.76069242723527, 53.177670894130586, 60.954515011079856, 58.640477426590465, 43.29149376961493, 53.60740969257971, 56.10957591764389, 50.42805802437567, 38.646619089188114, 57.22423899558283, 49.254320129271484, 54.472382530089355, 50.90330808393417, 45.87908529466199, 38.19489932829334, 40.62050480996409, 40.76485195467549, 39.39931408051522, 39.078358296425115, 40.84347586477957, 37.628536532002116, 39.30685597081339, 38.11452604109241, 39.44029500407558, 37.28839251302904, 38.12433588889338, 37.434316450549716, 37.96699393180109, 37.47087686292587, 39.62590940536992, 43.168849099066954, 39.84388336058586, 36.05246936121295, 38.09626348557011, 35.492872653468964, 36.24647763467605, 34.63548960224275, 37.587535996590894, 35.642644436128684, 38.435513204143895, 38.12403778876028, 40.47088992211127, 40.32766457526915, 43.372247526722575, 42.025595864942, 43.2489360532453, 44.13383845360049, 46.47382251677975, 47.0073119286568, 48.87317949725736, 46.69342425561721, 49.9437080660174, 44.410365550748764, 45.66004445475917, 50.921001895781494, 52.87085133214151, 27.030496289653165, 2.1929184707903095, 0.7959953839740446, 3.230515555027993, 4.701172459510065, 6.297845311703221, 6.895070787399047, 0.1519132741997319, 0.2187413301679396, 2.7239524789394873, 42.91866856236612, 30.12532872538413, 26.280007631547992, 24.356138014024307, 35.202487822501894, 3.5925517928215767, 0.05678874185128559, 0.03661323413853684, 0.05657494969425663, 0.03810234435443436, 0.02354145098868157, 0.07105554363900615, 0.08970946283830751, 0.09227945799789122, 0.019009196304626042, 0.0294369418970159, 0.05060809003489633, 0.06571703695601995, 0.02380110308407776, 0.0331666428715952, 0.06666405952625698, 0.03297087676342457, 0.00892958021722734, 0.04499781749121124, 0.04791238750781744, 0.04263856928915747, 0.0032162410770392707, 0.03550945082679391, 0.05933307689584552, 0.03612795191246175, 0.045584024140431036, 0.03057988953866786, 0.060053088461920145, 0.04005764205489428, 0.009243835229426622, 0.04691065476846792, 0.031195297544341416, 0.018699951507451556, 0.051117358473880645, 0.07608281178099495, 0.03455868974748639, 0.016245333019704107, 0.02233865081272539, 16.85904126013479, 52.43358550533172, 31.472988436298987, 36.700107589844734, 44.56281631223617, 42.20848421896658, 48.46194644128123, 0.060703217487541906, 0.38446015227706204, 0.5405669611307883, 0.22886849158713896, 0.019598082346361012, 0.08040848894104843, 0.5541911300632262, 15.241665647875879, 45.15576101118519, 55.91133932913504, 54.890628783933586, 55.55965961948518, 55.20577946016866, 54.40326644528297, 55.88272956109817, 55.68973325913953, 53.21544331888999, 54.1940942887337, 50.72145915800526, 47.82551442423175, 45.71512237671883, 46.87124882974933, 44.70061702112998, 47.30484331807783, 48.3183680811236, 48.5828495794727, 51.57006394478583, 52.63279876401348, 52.99973257126347, 50.82456258035476, 47.567493069556456, 42.89485193067982, 42.80111512830181, 40.87410957582536, 41.563599494195756, 42.9622813963121, 42.59673218573294, 41.36976772739042, 41.8330192565918, 41.41226268583729, 41.90530853886759, 41.62121126728673, 42.249731863698656, 42.43112579468758, 42.965195717350134, 40.64207000117148, 42.27138334704984, 41.57054208940075, 48.176699915239894, 55.45965879194198, 55.84085041476835, 58.28845254836544, 58.65986177998205, 55.189003482941665, 54.801206588745124, 51.92839207187776, 51.860154597989975, 50.006862148161865, 52.520097301852324, 56.82066240618306, 55.35004031273627, 56.10812464068013, 52.54178800890523, 56.016980524986025, 48.746945858001716, 54.835166469697036, 54.94913485742385, 58.18947153706705, 43.610911984597486, 58.57366377307523, 51.3883719136638, 54.30858435169343, 50.36730835514684, 47.211820387071185, 40.01701677999189, 41.86027188454905, 42.896558161704775, 41.52730972536149, 40.52274757815946, 40.24310611909436, 40.146388315385394, 40.572267501584946, 40.77767418276879, 41.026211246367424, 38.962314974877145, 40.67238600023332, 40.87301523454728, 40.25022914332729, 40.834309285686864, 42.06490193643878, 44.302053220810436, 40.568807971092966, 38.74479993697136, 39.94682596575829, 39.30606757440875, 37.583805822557025, 36.813452320714156, 38.90669968820388, 39.06340622132824, 39.41206962831559, 39.96095042074881, 43.007553392840975, 40.813642317248934, 43.471393277568204, 44.075049969457815, 44.26706960124355, 45.7261638487539, 47.77537476631903, 48.47082276498118, 51.07166405647032, 49.91847938106906, 49.94026422500611, 47.44554658089915, 49.295685445108724, 49.803553935020204, 53.2629628335276, 29.906833094935266, 3.8189098142808486, 2.873715436266315, 6.275235789437448, 8.691193711373115, 8.151222092490043, 10.149776089575983, 0.27056221399576436, 0.10857933456258428, 4.217678068145629, 47.54539443600563, 38.040279496100645, 36.31815894957512, 21.328719354444935, 46.41003301066738, 6.348184520198453, 0.08785903108336272, 0.060707476936400905, 0.050263882900077494, 0.02770080471471433, 0.025978700347965764, 0.10747084364054665, 0.056701564875942086, 0.029977761667161703, 0.02723597703621753, 0.001828375125994846, 0.0711282836874166, 0.03597584132465624, 0.038099938838352124, 0.08728765972679661, 0.027591891909739184, 0.013073548024910833, 0.1053506876492212, 0.18796500419416737, 0.1592583107131143, 0.1413015928119421, 0.1583227488182245, 0.35600596137585183, 0.17150318430316064, 0.1444360262323772, 0.34436746169963195, 0.13653982010099197, 0.27131003838393, 0.1637510946320911, 0.066575936432327, 0.12251432834854051, 0.10174447430237647, 0.10277136153871975, 0.1720035469700252, 0.16549415916444796, 0.09660390175638661, 0.08149679344628127, 0.1038050976011061, 23.044315038188813, 62.03097420354044, 44.326838677929295, 42.69292831420899, 46.72098675081807, 47.85962727762038, 56.027908248286096, 0.4018102664380305, 0.593821961552866, 2.097511229015166, 0.4460829472349536, 0.3152339346706867, 0.30164898943997204, 0.9385741526080716, 14.879958398880499, 46.99487801521055, 57.3075109143411, 57.0716078050675, 54.2419981956482, 56.294774547699966, 54.90326273825861, 56.784105916177076, 57.39963954494846, 56.662779162007, 54.86643560471074, 57.2626115429786, 50.518586327952725, 49.866307935407086, 48.535761525554044, 47.521762155717425, 47.28492944471298, 50.87048176796206, 50.60764766508534, 54.310416098563906, 52.94651777513566, 56.56374323752619, 53.762221720910844, 52.37012155594365, 46.66846621421076, 44.49856396644346, 43.203381646064024, 44.54569124406384, 43.74527277485017, 44.28835630416871, 44.377182299090975, 44.03280996507214, 44.00196836840722, 43.804563322374904, 43.27020706668977, 44.1293591068637, 43.06254110028667, 46.12087980393441, 43.0620272697941, 43.56677747541859, 43.85607188747775, 49.95771877227291, 56.88883319977791, 56.83351993560792, 59.52062199192663, 60.15766589872299, 56.63234156946982, 57.258426374004735, 52.43342468815466, 53.50480833361226, 52.442705015982355, 55.19622064405873, 56.76375273735293, 55.42469478422596, 58.86813963613203, 54.305477834516964, 53.30656390036307, 49.59382872427664, 55.54945753466699, 56.486892238740005, 51.74076157231485, 45.07680762198664, 58.77128062709686, 52.25338005250501, 57.585677562221406, 54.29913536194832, 49.621277470742505, 43.12172574381675, 44.3561387831165, 45.991771067342455, 44.82077098661854, 44.72910127332134, 43.19108893794399, 42.827940217910275, 43.140513896942146, 42.5758534093057, 42.15090382483698, 41.528996344535585, 40.843577846404045, 42.086941734437026, 41.51454633282077, 44.06382414602464, 44.89949295597692, 48.14491694973361, 43.392561481845, 40.848461197268584, 41.52785101244527, 39.445507834034586, 39.33164535030242, 37.89401431237498, 43.37933524962395, 42.06758091526647, 42.819381606194284, 42.55544531729914, 45.48407516171856, 43.92302674631919, 47.221218386004054, 46.40338067085513, 46.763105161728404, 49.32224381354548, 50.36217005022111, 51.73475642358103, 52.176121127220895, 52.38306537751229, 53.63660781614242, 49.44127598116475, 53.22892058280207, 51.643216148499526, 54.59303463658979, 32.90185101570622, 3.79816145666184, 2.443087975825033, 9.04897564841855, 13.705564487364985, 16.667796296458093, 19.984297560107326, 0.8794116949842823, 0.39491115438361324, 6.20578924494405, 53.59660748512515, 39.9339174455212, 38.7947944671877, 32.884874997600434, 58.71231563629643, 11.49975980481794, 0.20838587454730467, 0.18368012121608182, 0.14244309446263698, 0.15527940325198636, 0.11197754737710762, 0.1295889205028934, 0.17673093765493364, 0.15194454590880102, 0.058486534417757106, 0.08263070316564652, 0.18077353766608625, 0.13099728122113213, 0.08050457934939093, 0.24389222654844486, 0.1776542881083104, 0.11161265203789358], [0.03970517266181208, 0.03194029698328626, 0.011491534326435819, 0.05626453086733819, 0.010673364872233042, 0.02537441210851314, 0.10378633610784047, 0.04293872636833018, 0.026923765563556266, 0.03089242276825732, 0.02477801265946079, 0.03156777523878602, 0.0061868035024212256, 0.10549575405856294, 0.015070771802246813, 0.13243155103297005, 0.024421967550992005, 0.1949121346396785, 0.05530189159476469, 0.08522584899178437, 0.10524355025301058, 1.3488777294274301, 17.631738378155617, 43.209104384145434, 27.19659297697006, 35.069609688174346, 34.256612177818056, 55.44005086345058, 8.503160188275, 0.08761642635950158, 1.3827950771777862, 0.13570680673564636, 0.13470493227003083, 0.11622539766493345, 0.29458234927827315, 1.0430597201470406, 17.732621738987586, 43.90270886882659, 57.51200760564497, 52.85040401643323, 54.311557508284054, 52.27122291441887, 57.90980654378092, 53.36129273137739, 56.274366455693404, 51.85178426004226, 51.23250869012649, 46.514724992936664, 46.66665407919115, 42.37814634077011, 44.66139331940682, 44.29664427234281, 46.179268206319506, 49.6565866470337, 50.65483770062847, 49.46262936438284, 52.68909262072656, 52.615528568144775, 52.04942464828492, 44.641754011954035, 38.576836201452444, 42.05436645015594, 41.03072589443576, 41.05471118803948, 42.607934474945075, 40.83121453562091, 43.16808815925352, 40.5707299324774, 41.110463757668775, 39.53683237875662, 41.02262620002993, 38.45074768989317, 41.38660646254017, 40.02119018185524, 43.60153751988565, 38.27786530217817, 42.449003957933, 51.87633045258061, 57.50269589885589, 51.65319073584772, 54.54503659279116, 52.12708757769678, 53.014453226520175, 51.57560233146914, 51.16058418827673, 47.61736600629745, 54.50311822275962, 52.43306775246897, 56.36588711892405, 54.08766469647808, 71.77410248787173, 51.653045608151345, 43.85616994673207, 58.6291378544223, 58.059174322312884, 38.520322692009714, 49.544132294193396, 53.80104534087643, 50.888002995521795, 50.22575393799813, 46.44702880613266, 40.74018024629162, 38.40012165807909, 42.30334674158404, 39.852492963114095, 39.10938816685831, 38.64774480942757, 39.69366835009667, 38.05672207186299, 38.90559357981528, 38.207450912844756, 38.97010087966919, 38.07074062285885, 36.944792885934156, 37.69336938858032, 37.72386973904025, 41.55661767528903, 45.47901530419627, 46.96377361974409, 47.31798325815509, 42.6938186922381, 37.960482797315045, 37.514191596738755, 36.4544613130631, 37.25301665644492, 36.41883442478795, 36.34717272173974, 42.50916527163598, 45.582169717358006, 44.64470755669379, 49.744577177109264, 47.92369527201499, 47.19892363394461, 47.8938970258159, 45.41142109901675, 48.49135245046308, 46.68406548038606, 50.89633803213797, 47.98008718798238, 49.009144536910526, 42.952502927472516, 45.97061772500315, 49.368527781578806, 44.84910618874335, 13.570278998344177, 0.569109006995155, 3.018488648437685, 4.505878629222993, 7.032028677002077, 6.369817862587591, 8.436285738022097, 0.2678831432375216, 0.10081644305178236, 17.536605211996264, 50.942378813220614, 27.961109991996523, 22.549023628234867, 34.338856435591175, 30.01804013406077, 0.21874951198697093, 0.03439311133397203, 0.02427497251530088, 0.033587899299398545, 0.08748163318922443, 0.00614923790224918, 0.048085427617714296, 0.05312206118457741, 0.03774223323430746, 0.092629452926978, 0.06475140611010213, 0.06193869897434789, 0.0732936924924293, 0.013835176359862091, 0.06161257917542131, 0.0313205931395773, 0.07571491337711773, 0.02536367730147416, 0.04973923524601325, 0.03266377892765788, 0.05654825536053508, 0.023275402059117635, 0.009497858493799164, 0.048502815301500024, 0.0551068839136391, 0.02796894697953136, 0.10345098877986593, 0.04701894129656496, 0.02718187016134541, 0.03091214570186792, 0.13085673473054363, 0.02601241970795297, 0.05221950618790523, 0.09019890875225106, 0.027935451700262008, 0.008663026627243288, 0.0342511820546802, 0.1481285547056506, 2.0957547426223755, 32.43817390934114, 46.43470471905124, 26.831498761330884, 47.02491160361998, 38.13318083363195, 58.27332396661082, 6.948165951236603, 0.04120264472740312, 2.0412322037643005, 0.19705770176745233, 0.07613352680158231, 0.28185015183783346, 0.13080091756438056, 1.8002773268568901, 21.348601848848407, 46.96694681721349, 57.164666037405695, 54.026463954679436, 55.98254211487309, 51.74044778270107, 58.911909364884906, 56.0915800832933, 58.790162917106386, 53.71529840653943, 52.81473398208619, 47.7760023455466, 48.75568097637546, 43.09475944888207, 46.760465406602435, 48.18968688288043, 48.573710456971206, 50.748974584764056, 53.421293227903305, 50.23820746329523, 54.84084998407672, 52.196442927083666, 53.48449830086001, 46.18842301830169, 41.67507325449298, 42.25761975011518, 43.08017999895158, 41.37062280408798, 44.25950727155132, 43.52130151564076, 45.01450861653974, 42.74675892245385, 43.00916548698179, 42.66406751448109, 43.24326430597613, 39.90825337748374, 44.03967019050352, 41.5230853326859, 44.82133973029352, 40.240862523355794, 45.24896829358993, 54.61050487333729, 56.7920369486655, 55.33463324269941, 56.67746843830232, 55.97147710861699, 56.103821800601104, 51.6253105286629, 52.25680035929526, 49.12765502929688, 55.185995025019494, 54.68515934482698, 60.219556977671964, 53.92669062460623, 60.79166604626564, 58.03718551512688, 45.764120624911406, 51.09628085167178, 65.06626898242583, 46.86454549912484, 49.385037037634085, 58.008830701151204, 52.47238559107627, 52.109393765849454, 49.55486389898485, 43.241554152581, 40.10319909741802, 43.09438682371571, 42.32850874623945, 39.0138666860519, 40.397996594828946, 39.15884140999087, 40.25875245371173, 40.95189017634238, 40.61711195976504, 40.6260863427193, 39.10687392757785, 38.270918784603, 38.94322872161865, 39.9370200403275, 40.84908877649615, 47.149815559387214, 47.159017439811464, 48.636664498236875, 43.01974411933653, 39.132471315322384, 39.526394951728086, 38.92098103800128, 38.335355481793805, 40.23943870298324, 38.13420457224692, 42.47330696352067, 47.265431342586396, 49.982970991442286, 48.83720744040705, 50.47200818215647, 48.47359588069301, 49.42118167877198, 46.73660562884423, 50.686706958278535, 48.73467668410271, 51.60951906634916, 51.04183050893968, 52.088777788223766, 45.45188819208453, 51.343488231782, 48.225192177680235, 49.85863185697987, 14.114580423601213, 0.6455263387291663, 3.651117192160699, 5.789299722640745, 8.147646852077978, 6.578838517588954, 8.893025152144894, 0.14321655215274903, 0.13035309320736316, 18.105307702095278, 54.75786047597086, 38.08446891846196, 28.146185067392167, 33.88330059666788, 40.23215486157326, 1.057400028071096, 0.04652623950894322, 0.0605342491349626, 0.011818926788926607, 0.10741098919102263, 0.04906421602373162, 0.0074112945003435024, 0.10726943912525332, 0.051705058994552786, 0.05095313603599226, 0.042230171647163174, 0.05009973324054191, 0.07582741338879832, 0.041322483861398314, 0.06246258820136709, 0.051162385291630225, 0.023926597862173955, 0.1648200630781151, 0.10610133890182742, 0.12853211753310698, 0.2085457724188605, 0.10871536113441953, 0.13342596380220306, 0.2392482168732151, 0.20340691590982102, 0.098958358078474, 0.12424328920221138, 0.1340298402693964, 0.18754158739841756, 0.13430838983866478, 0.23576571906526245, 0.18483031030383804, 0.25829791241595823, 0.16491908760320756, 0.3083828716508804, 0.10948792250166017, 0.1790810042932149, 0.2798487931009262, 2.748502593848013, 39.11994326499201, 55.289890766143806, 36.902415598592455, 48.619390379997995, 44.809784427765884, 67.02443384355115, 10.004474828320166, 0.19299432545179324, 3.6197367598933563, 0.3707272907899272, 0.28152045823874017, 0.6888739223922453, 0.5570870649910743, 1.3915869473449647, 21.34760948919481, 48.721348470257176, 60.58066606521607, 54.087382285825676, 57.753974699204974, 53.84724693913614, 60.83623201616349, 57.98924238451066, 62.2475008041628, 56.95255210322719, 55.381976250679266, 50.10445856278943, 50.96510502599901, 46.898564215629335, 49.74763270347349, 51.07084428110431, 51.46755280033235, 56.11899745079779, 54.58110670889578, 51.63999588258805, 57.63789999869562, 54.50805648680657, 56.25254631042481, 48.06769332578106, 43.071876341296786, 44.74721477877709, 46.60508855696648, 45.08926899202409, 46.36834998284617, 45.923721867222945, 47.16679942223334, 44.98828757193781, 45.769164792953006, 43.660616259421076, 44.4177709856341, 43.388203728583555, 46.75631553896012, 43.55515941496819, 47.51620807955342, 42.5963124921245, 49.04581477565151, 55.993371778918856, 59.128486956319506, 55.173800376153764, 58.41903217377202, 58.46393938987487, 57.18443870544434, 53.06272583623087, 54.616937560419885, 51.62620875143236, 57.445174340278875, 53.471511333219475, 62.41395442716537, 55.12157401730938, 64.7761744068515, 64.34919695700368, 47.57227836116668, 54.709356446419996, 56.30505115755143, 46.872821700188425, 54.87915977354973, 58.59404440849059, 57.83374001902919, 53.11278704674014, 51.68101210747996, 43.560995901784594, 41.85137987136841, 44.4884285619182, 45.18019345498855, 41.22908015404978, 42.660996298636164, 42.031499032051336, 43.19089281943537, 42.60923670184228, 42.034170166138686, 42.79390581192509, 41.546148869299124, 40.435863156472486, 41.48514424600909, 42.10673009195636, 44.66062453485305, 49.28465966255435, 51.354247293164654, 50.731378832171046, 46.44121585353729, 41.22532644579488, 41.54737264879289, 40.27381043280325, 40.47738144474645, 42.28051854718117, 39.461346364790394, 46.140370061320645, 50.30925727659657, 50.44213148855394, 52.768226438953036, 52.068938439892186, 51.30324471381403, 51.66720928684358, 50.39885990081295, 53.145436856054495, 50.87173300404703, 54.76317528755435, 52.781103580228745, 54.22399843892744, 50.824625338277514, 52.681797012206054, 48.86865700444868, 48.407715751278786, 17.879543919717115, 1.1674820824015526, 7.277644555414877, 9.055250460101712, 12.594258958293546, 10.521954105746362, 14.255414105230763, 2.434144726684017, 0.1613738778377733, 22.924013983818796, 63.57405424118043, 37.09960099189512, 33.67829791961178, 44.64895156122024, 47.07861669601933, 1.7736334017207547, 0.2845884871578986, 0.1653762582329012, 0.09879832231109181, 0.2651122338589161, 0.0885516511757047, 0.11152784610467573, 0.25700676315013443, 0.16192581354370042, 0.1621525142822535, 0.1878159234841024, 0.19534117452079253, 0.20022098605911579, 0.14437647055714362, 0.10314519712401014, 0.0866659946980015, 0.20812057829912634], [0.006472195194463336, 0.0421855585168927, 0.024726929916669766, 0.025201640129389784, 0.04772588340265136, 0.017421523131610408, 0.06962002510385168, 0.07967574116323264, 0.007097048106633368, 0.047349864466776775, 0.03758636498523336, 0.014393113407066033, 0.04940520175882886, 0.024923992628652244, 0.05309101164100632, 0.024769909364441713, 0.05571159541666989, 0.046614251520124175, 0.0769220611020442, 0.05919525384782784, 0.1403688041553382, 0.08955063748984568, 3.580288502477831, 43.474864575170706, 32.002139706765455, 31.722884601162328, 32.96625829512073, 50.822448422831876, 28.446244424389256, 0.07264606474388031, 1.253908689944975, 0.048476128628657716, 0.06154212589946486, 0.04459585115734128, 0.13092016681067406, 0.08140871631762675, 2.969102085598054, 27.863603791882916, 54.189183481277965, 55.47956089819632, 53.282857095041585, 53.953339207556944, 53.514920203916496, 53.37077702245405, 54.39144834395378, 52.67599974909137, 50.6338490978364, 46.673306419003396, 43.85535017136605, 42.09457466679235, 43.42739997371551, 46.544087856046616, 45.872574160175944, 49.31107290329472, 51.75200308522871, 51.50088510205669, 52.959402761151715, 55.89967812261274, 55.316566805685724, 49.629192813750244, 42.09935995840257, 42.512503208652625, 39.46237010340537, 43.31303542660129, 41.641329103900546, 40.369739840107584, 40.8334267523981, 41.56175598021477, 40.168067255327784, 39.216457105452015, 41.51263613854685, 41.147263434625444, 39.07688348524032, 41.785723317054014, 40.84020068568569, 39.154126721043745, 44.124075674241595, 52.838954617900235, 57.62678400162728, 53.15913377269622, 53.93355477240778, 54.75714268222932, 54.40466673143449, 54.31518962306362, 50.327323713610255, 52.437676537421446, 54.19876190923876, 52.940767580463046, 53.83014932755501, 49.45294895479756, 28.8686542741714, 29.683467841917473, 73.44912713573825, 74.6191466239191, 39.34273781314973, 44.82928252989247, 54.1624133048519, 55.15600850505214, 53.3593511581421, 47.402263226047644, 43.564435820425714, 40.72594988730646, 41.37064241593884, 37.58899119592483, 37.82606317150978, 39.498816767046534, 38.09585948144236, 38.14478320460166, 37.70175541600874, 38.3109151932501, 38.110948839495265, 37.579526516699026, 38.13040379554995, 39.42634705574282, 38.92850806636196, 38.07050135827834, 44.027467696897446, 49.791108254463445, 50.458628977498705, 49.46164092709942, 46.46056490559732, 43.30363742766842, 39.794638003072436, 37.807730013324374, 36.552912804388235, 35.34462275043611, 37.44795453163886, 42.18898219446982, 45.209191537672474, 43.70666096287389, 42.54624343687489, 48.59568357467652, 52.0838003004751, 49.88157772248792, 47.747737746084894, 49.14594896378056, 47.79978367590135, 49.529478319229625, 50.62621616548108, 49.9614607134173, 44.501391995337706, 47.27933222247709, 51.0765983981471, 37.03606643984395, 1.9774889080755174, 0.7979609817266465, 2.2257469930956444, 4.88658485874053, 10.17515480518341, 6.547402681842928, 6.610274843631252, 0.8363110980679913, 0.7461624063791767, 48.06549287611439, 32.07124794683149, 17.319045066833496, 20.00044988047692, 33.65888610962899, 20.11629512233119, 0.06541516767033646, 0.04812699171804613, 0.0317942614727203, 0.06746125062026324, 0.09031008343182265, 0.05168622855337397, 0.021494450648465467, 0.05197720406877418, 0.12400973197673598, 0.08365575945185078, 0.002299229522430969, 0.06325125656721574, 0.014147567863185561, 0.06758078331908873, 0.018074919522229223, 0.06208589893855876, 0.030207180102626165, 0.0711370707159081, 0.03348817763429496, 0.03012225351056024, 0.038812764499697, 0.022428476537067085, 0.005274374590014979, 0.08180974802422909, 0.0553800325630413, 0.050779222585861726, 0.10472231935108862, 0.031594622790092425, 0.05467732692317617, 0.038398192189032995, 0.0521191869742207, 0.02285866555006754, 0.12035218307808523, 0.038390071657035625, 0.04832487988976702, 0.059642411708351106, 0.03600093836505567, 0.06549586737228018, 0.11125209275633098, 7.722511445322345, 53.28197456175282, 28.038963156361735, 36.036164068406634, 40.6241016234121, 56.69544073843188, 28.791365931111, 0.1051677611746615, 1.6995468158875744, 0.05494362674653531, 0.06849291058437479, 0.7450572172960928, 0.39801947952758887, 0.17966995736764324, 3.738556629227054, 29.870798280162198, 55.04479754355646, 56.03294849395753, 55.26446596268685, 54.946742211618734, 54.93139005476429, 55.013665691498794, 56.6521809178014, 54.24615590803085, 54.413801931565814, 49.49271394360451, 46.083068155473285, 44.74481428823164, 46.153082463049124, 48.24427450856855, 49.353356053752286, 50.22433796236592, 53.36747830913913, 52.45313067590037, 54.613136783722915, 56.5226681770817, 56.61886430555775, 50.758411807398645, 43.46917321605068, 42.84735202789307, 42.636622690385394, 44.17758464813233, 43.44132438782723, 43.06991123384045, 42.84843067969046, 43.83258473488593, 43.782672574443204, 41.81693361651513, 43.45469574774466, 41.95209849265314, 40.760278471054576, 42.64082354883994, 41.541477326423895, 40.41112476779569, 45.34525855895012, 55.24758015909503, 57.88083199531802, 55.17602828241164, 56.34607130481351, 56.127909075829294, 56.444836585752434, 54.70574002112112, 54.96351818884573, 54.9944382329141, 56.34693422625142, 56.50135009519516, 53.609217905229144, 51.23180658586564, 39.78300425314134, 32.89168227103449, 59.981135706747736, 76.99906041545253, 50.09009876558858, 42.86867403214978, 57.42880236717963, 55.229294069351695, 56.783909797668464, 49.51795831803353, 44.73196068117696, 41.44286109555153, 43.20482900065761, 41.38948940461682, 40.51642471744169, 39.48019335346837, 39.69099329363915, 40.549376549259314, 38.77570036918887, 37.920870780944824, 40.65002849025112, 40.24850722282164, 39.97603193406136, 39.99267062833233, 40.68976602246685, 38.938980794722035, 46.88787967927995, 50.217007052513864, 52.96997747113628, 51.35173697625437, 49.660909098963586, 43.60942932867235, 41.317537446175855, 40.08219872751544, 38.63800556428971, 37.3850828601468, 37.72634867698916, 44.15207747490176, 46.883392487802816, 47.04078935807752, 44.380888938903816, 50.323722977792066, 52.019445973057906, 51.33412945655085, 49.915639585064305, 51.2470724505763, 50.39709875660558, 51.70186734968617, 50.95643266554802, 50.398122495220555, 49.23826194578602, 50.400703414793945, 51.946191787719734, 37.28989870317521, 3.315888148161673, 1.7881689701349506, 4.575737512880757, 10.799527495138108, 8.956805832924383, 8.479196467707235, 3.635073227267112, 0.4370797900182586, 0.3152068458016842, 48.21591184985254, 44.05417903777092, 26.418622232252552, 19.347930262165686, 41.96186519438221, 26.22880893368875, 0.055395040225477955, 0.04081562476893587, 0.02756631031872765, 0.04554675779335442, 0.060641493783482624, 0.13838645972071156, 0.005894284319853591, 0.07025895009358084, 0.06990240511274146, 0.09769964497536422, 0.03347595470146306, 0.08259674248796317, 0.036968702765842604, 0.011373109582270826, 0.020596411740106922, 0.029511026429733443, 0.021552236660593943, 0.13548245022614158, 0.12755374664500838, 0.08638107893808235, 0.09199543856084348, 0.13962038221859163, 0.1711185468781379, 0.22482492630520176, 0.17743736265167115, 0.09424559967291933, 0.16829459357165522, 0.11732442740110621, 0.11260538707457243, 0.16151827008974168, 0.1687848132344023, 0.16960647317671007, 0.18923009114880718, 0.25926894418174223, 0.14082883995386863, 0.15382893834142916, 0.15430734492838383, 0.2663975455347569, 0.22732309306100493, 12.396974525144024, 59.3227933299157, 39.6786182157455, 41.31394455509801, 44.76707373895953, 61.369929313659675, 36.25456948434153, 0.16472417951351212, 2.1965138133495086, 0.15905391845491626, 0.2762820102995442, 0.36095617639441646, 0.3263347938416466, 0.19281918243054422, 4.523762185727397, 32.00425582547342, 56.681500634839466, 58.81044157089726, 55.19873096096901, 56.38242775394071, 56.575533882264175, 57.15233018321376, 59.31442691433815, 55.37759888556696, 56.87100602734474, 50.47968818295387, 48.35735644063642, 47.067504621321156, 48.80929977663102, 51.61905827060823, 49.77822326844739, 51.761255956465206, 56.790487612447436, 55.00030217632171, 58.25247656914496, 59.843362454445135, 59.50925104079708, 51.00270094410066, 45.7933501274355, 47.058267439565356, 44.80832530606178, 46.696448403020064, 47.461949932959776, 45.37850456853067, 44.18611580325712, 44.64556263339135, 44.10091800074424, 43.47348782324022, 46.72833727252099, 45.5103511195029, 42.08198385853922, 45.291749585059385, 44.04237270355225, 42.08760069262597, 48.818976263846125, 56.1352478304217, 61.17171233700168, 58.09371863642047, 58.288283886448035, 57.82174541104225, 59.11068331810736, 57.54211964145784, 56.10856002376926, 55.155251487608886, 56.88366743826098, 57.32833477758593, 58.97089004516602, 50.596727786525605, 46.56697096363191, 39.30906034285022, 62.00564353696762, 71.43774355611494, 48.862745992599, 50.87268221762873, 57.29846592872374, 59.777274439411784, 57.23430771981516, 51.181596325289824, 46.72552101073727, 45.11904370400214, 46.73873155347763, 43.89886494605772, 41.613943115357436, 42.09246835400982, 42.26218931136593, 42.562329076951556, 41.92391626296505, 40.75990192351803, 43.19026916257797, 43.97515504590927, 41.08880835194742, 43.26225249998031, 42.95529957740538, 40.6987129488299, 48.89494472934354, 52.00364274363364, 54.51088843807098, 54.58658233765633, 52.00383493977209, 45.97958818558724, 44.14634296970983, 41.7995535942816, 39.85641925565658, 39.57928811350177, 39.118025225977746, 45.14690822170627, 49.16190124327137, 49.86502139799057, 46.937462360628196, 53.133865864046165, 55.9027728726787, 54.107743309390166, 52.821994289275146, 52.84349672255978, 49.595766375141764, 53.32079033697806, 53.926114036190896, 53.3456346296495, 49.32029439556984, 53.5194819204269, 51.742001041289306, 40.28180422321443, 3.166658388030145, 2.698486000299454, 7.638315318092224, 15.052835883632785, 18.757915573735392, 15.204665930040422, 19.152502090700214, 1.9857613093429998, 1.3674557906004692, 58.82538972362396, 42.00892186933949, 26.919524592738, 29.598217087407267, 47.476341109122004, 33.67544243412633, 0.20934624236918267, 0.1287622656673193, 0.22801010538974117, 0.18050552946665596, 0.2016834785500842, 0.26874211166174183, 0.10722338191924558, 0.1996041933495191, 0.24525915723173852, 0.23743335458059467, 0.1406322311489813, 0.16694336769080934, 0.16826891430443333, 0.1690643280744553, 0.09225038496116478, 0.10033149407395434, 0.13927728208082338], [0.023366941905189908, 0.04055881294451895, 0.019435016701238293, 0.0029052912554283056, 0.06624574487608287, 0.07401002300602776, 0.0724528803520145, 0.037460167321466634, 0.04110086994666246, 0.025997385232438965, 0.08404219718349558, 0.0916032245262496, 0.030231248669987245, 0.07965565433785801, 0.03631407680410532, 0.08951325239914079, 0.011648919429599999, 0.05979548373650159, 0.03167797507147395, 0.007119692708065193, 0.03750516349569925, 0.03544590766391447, 1.4756160061205588, 24.403688907623295, 40.69132712579543, 29.607003196593258, 36.99503060310118, 34.70015379690355, 47.345157438708895, 1.8215670941337463, 0.2753786087757157, 0.12249675429155751, 0.04034862906161336, 0.05084440517689913, 0.10000799812616841, 0.626849421570378, 0.09440065586879369, 8.84019180651634, 40.72299634256671, 54.20841093986265, 55.28694114377422, 53.14493087030227, 54.20325302308606, 57.33833682152533, 53.93972073831866, 54.3030498873803, 50.07112626106509, 44.91148756396386, 41.1950888941365, 40.28323196595715, 45.446891092485004, 45.60801029205323, 47.45805501937867, 52.39165536818966, 51.777733833559104, 51.45174957090809, 50.62893829038067, 55.13654962662728, 54.73215718423167, 53.35014927771784, 43.10959385287377, 40.23282950924289, 43.24944203899753, 42.49229515752485, 41.180227033553585, 40.337364596705285, 39.62700766901816, 41.91432606789374, 41.563846603516616, 40.03387904936268, 40.10982005826889, 39.65881416874547, 38.851617843874045, 38.8619807458693, 39.48178583575834, 38.3360222847231, 46.70753302112703, 57.60740357060587, 54.92357669338104, 53.653893701491825, 54.74842325333626, 54.192694002582186, 52.11285329634144, 51.69539543890184, 54.27666410323113, 50.16686739460115, 53.036614617993756, 54.42411384274883, 55.23764479544855, 39.767416754076564, 24.53504712350907, 61.38661115400253, 64.65431813270816, 34.465380330239576, 45.47720316917666, 53.94794594857001, 53.31638159290437, 52.231995290325536, 47.51519610804897, 44.73315308170934, 40.32488753718715, 40.070494374921246, 36.77204778117519, 38.152984880631976, 39.740564207876886, 40.92312743586879, 39.61003165091238, 38.40011773570892, 37.05563906700381, 38.66328916242046, 38.03871447040189, 35.598737424419774, 38.276767038529925, 37.04809634916244, 37.08377030587966, 38.74872230714367, 45.85368794779624, 50.72298888237246, 51.81638094686693, 50.58940864378407, 50.15482964054231, 46.23830772215321, 43.58487136902348, 39.50251556211902, 38.69280107559697, 36.23144711217573, 37.0915993567436, 38.05155238797588, 46.42577740453905, 49.061527790561804, 45.834848803858605, 46.87788940245106, 50.67334736547163, 49.96215889530797, 52.80589688208796, 48.93692977966801, 48.33606973771126, 48.60039826362364, 51.01434646114227, 47.39908610620807, 49.630636245973655, 48.71131504735639, 51.41725624761274, 18.26321251930729, 0.3305770210441082, 0.47721853780169643, 2.925746902342766, 5.556021169308694, 6.281316443797081, 5.746289953108757, 3.4109178618077314, 1.1722705609375432, 12.657915103820063, 46.77660988223168, 32.07916132865414, 33.24191854846093, 22.572430372238163, 30.57561093761075, 3.099360566946768, 0.026503755943849686, 0.08510019525044388, 0.04844366948330595, 0.023063036740847656, 0.0062014405698245095, 0.07720961220442288, 0.04843993480467508, 0.042234626448442864, 0.017446126045298674, 0.025076380923330307, 0.05123407196914477, 0.037118472955039436, 0.03160625392000281, 0.04773967298528841, 0.033554720031397964, 0.04270839054257639, 0.039952814413775364, 0.07080448896534021, 0.028629653764167623, 0.04657798491778874, 0.01604868686803046, 0.007286964654697166, 0.06905866651645592, 0.05138576886947117, 0.01268024231502486, 0.05471815174866108, 0.01453786955079845, 0.04258958562727898, 0.055145234275128574, 0.011417134740059415, 0.01493728098144094, 0.043618587266293266, 0.041097054828799544, 0.08158952838951543, 0.014478725647824186, 0.04391474153606161, 0.03971995432831107, 0.0663962122052908, 0.06730424090018196, 2.25885768090525, 35.587393929881436, 43.13823107750186, 28.88414763635205, 46.68995295801471, 42.19104143881029, 50.40242925766976, 1.2985252829328662, 1.1907039847104781, 0.05579145625233651, 0.17142576345753285, 0.2528435962214585, 1.2851819924769865, 1.332022446778513, 0.3098198993792457, 12.16960943514301, 42.18284368515015, 55.5734428282707, 56.64783885402065, 53.82040616004698, 55.01388534422844, 57.102606296539314, 55.80769069733159, 56.491332361775065, 52.10832688116258, 47.213887476151996, 44.11460315027545, 42.804849224705855, 46.55386240251603, 48.7126172742536, 49.894031247785016, 53.46069735865439, 53.044906508538034, 54.396990653007265, 55.80395660092754, 58.812485125757036, 57.18246967561784, 55.35960697358655, 44.968244260357274, 40.61369165297478, 44.682064210214925, 42.71928271939678, 42.869529108847345, 42.3767029085467, 42.85143129287228, 44.875303699124245, 42.882759263438565, 41.45817010633407, 41.85800867695963, 43.50876169819986, 41.609259805371686, 41.149809052867276, 42.40711696686284, 40.07354990128548, 45.990417849633005, 57.64718817126367, 57.55221974465155, 56.71891612391318, 56.029543876647956, 54.493441735544515, 54.97693269483505, 55.00957073703889, 53.02624387125815, 49.91151325164303, 56.21566034132435, 55.381599703142726, 56.917678310025124, 40.39999700361683, 29.54025426218587, 53.474115787013886, 70.29852251852714, 47.201343736340924, 43.632755664087114, 55.814397950326246, 54.58162446175852, 54.415174761126124, 50.85803216503513, 48.11140814135152, 42.65616393858387, 42.06771427585233, 38.959875260629964, 41.94082167840774, 40.338039244374926, 41.64182724491243, 40.0918948265814, 40.73463401486797, 39.27618303606587, 39.70275255941576, 40.68300777865995, 38.46376603649509, 38.74932635215021, 38.776331870786606, 39.87368552915512, 39.220469690138295, 47.74398796020016, 51.62823661681145, 52.859900074620406, 52.32716768018661, 51.65019796740625, 48.81734848022462, 44.57075518946494, 41.26828816629226, 40.06451668277864, 37.78663158416748, 38.7882205747789, 41.52028868275304, 48.41399938829484, 51.808041987880586, 46.73251851912468, 45.63765556581559, 51.42829379727764, 50.925461630667414, 53.42716501605127, 50.5305064109064, 51.565294342656294, 50.16061905891665, 52.73165425946636, 46.70173183564217, 50.98082196327948, 50.64697334843297, 51.67173962439261, 20.36792693599578, 0.9943974474745413, 3.201794734885616, 8.022052559160418, 6.68217335977862, 6.031378113454388, 7.341867483431294, 1.1591601612106448, 0.7506239798761184, 12.566618015689235, 57.527410753311656, 30.865985962652395, 27.38528643884967, 22.617092440205237, 43.51258600911787, 6.548604888300742, 0.06110454030755547, 0.10825623698051899, 0.01827018192758964, 0.014315863016001401, 0.03946718744813435, 0.04411521142408733, 0.023933211116180308, 0.0538080622772536, 0.048578615871167956, 0.06343447798562628, 0.033823153409626217, 0.056180835761610544, 0.02546193573864237, 0.043186391102931196, 0.07222380474089615, 0.0101040274791059, 0.09456329633511844, 0.12793157354838428, 0.0778632767258152, 0.15006073570299536, 0.21655768847032902, 0.1161751499579799, 0.15481762077298858, 0.15584178839720067, 0.18765017270080506, 0.288096281189111, 0.1502214609495094, 0.14742321755376556, 0.15601544520787655, 0.19203133760921418, 0.24700494903710582, 0.1667681480607679, 0.15769363741480535, 0.2994539636758066, 0.1442275430646635, 0.09664319440602295, 0.1017955570451675, 0.25503286100443334, 0.2848415719645639, 3.3783597378961505, 41.08485460281372, 54.29006684210993, 37.71392653065343, 47.307290877065356, 46.10697892404372, 56.90841759404829, 3.2606996643927793, 1.7846101546479811, 0.23579054031400914, 0.18630591822007012, 0.20698416347224868, 1.2446322844874476, 2.0692074058517336, 0.268771713299136, 10.713184360534916, 44.5673466497852, 57.95738881634128, 58.95428272985644, 55.11640041105209, 57.49643971843105, 60.20339289019185, 56.56051904924455, 58.63698259476693, 54.656478974127005, 49.480754636949115, 46.771322527239406, 44.33761735116282, 50.49530706098003, 50.77907877583658, 52.548208928877315, 57.148764748727125, 54.63876555042883, 55.52582917674896, 56.58936023712159, 59.79815713820919, 59.736336661923325, 58.16342699912287, 46.538914249789336, 43.95618646375595, 47.34659694856214, 45.865011830483716, 44.923670445719075, 45.51837236650529, 44.145311386354514, 46.96564851268646, 46.88536151762932, 43.3852933299157, 42.709735670397365, 45.471456896874216, 43.21569004366475, 43.37822521886518, 44.4038426491522, 42.77792607584308, 49.74041161998626, 63.386917960259225, 58.899738250240205, 55.56872029458323, 58.4462377332872, 57.804357544068374, 56.101182045475134, 55.198597600383145, 55.854547331410075, 53.106283756994436, 58.70940915999874, 57.8694571218183, 56.42865680879163, 41.7980513265056, 33.31831455230713, 54.755816921111084, 70.71190111098751, 51.39354944229127, 49.344420894499756, 58.293277063677394, 55.63538882040209, 55.999063138038885, 50.96816447473342, 50.30614291467975, 43.27371758799399, 43.650755420807876, 41.40022100940828, 42.89580506663169, 42.91371068646831, 43.71004989070278, 43.301452667482444, 43.496814158654985, 41.53180868394914, 42.08978153044178, 42.0424699014233, 39.583449748254594, 40.697936319535785, 42.13170774521367, 40.70768733178416, 41.599006729741255, 48.910951922016764, 54.54546805351011, 55.133199922500125, 53.98693430808283, 53.28606951621271, 50.794258348403446, 48.39916498430314, 43.218965222758634, 42.511134301462484, 39.40507996466852, 40.799023643616714, 42.46421883183141, 49.125925264050885, 52.17620741936469, 48.251252405105106, 48.23136991070163, 54.68809720008604, 53.78392419507427, 55.7625481390184, 51.072417151543405, 52.547216569223714, 52.17375986037716, 54.60257776321904, 47.578546308702045, 51.73591744515204, 51.92989041728359, 53.0781642852291, 21.65402896942631, 1.3832939536340776, 3.510193786313457, 9.792646246571696, 11.438053077267064, 14.12076404017787, 12.888276884632727, 9.255562963024262, 1.9864549559931604, 17.123556098630353, 62.045118270381806, 42.955319189256244, 45.46187846891342, 31.23479074047458, 53.71500815114668, 8.868718224187052, 0.13387738877246458, 0.2031212570446153, 0.17808715842904585, 0.11242429921103102, 0.10602407893466373, 0.16582887830032458, 0.15328460222771093, 0.24891164995008902, 0.16627141665066444, 0.1941910773635872, 0.21550134515329716, 0.08062867027136587, 0.10505898435029293, 0.1680375863948176, 0.24043130177643993, 0.1666615545869835, 0.1515571199237339], [0.054498644575716994, 0.09124600538803686, 0.03628280126459656, 0.01737684871430599, 0.07212679502704451, 0.013005421741024382, 0.028495929286544843, 0.020161471066756115, 0.1392557396883926, 0.046177876347135154, 0.052381108605092576, 0.02419499485122581, 0.01832669048810438, 0.08408067777993218, 0.03899488658193619, 0.07098290318202588, 0.06237355729324683, 0.022175797757001656, 0.09057698846464196, 0.009047687992513662, 0.15645104280162245, 0.03162338939164916, 0.04308095059147285, 5.693561040586041, 46.18744242575861, 25.580029295336818, 30.59975116483627, 36.55937687043221, 46.86546725611533, 16.011113082208944, 0.40770439370985956, 0.2495202608406544, 0.09953211962936387, 2.0732190099454697, 1.465496658798187, 1.1012072644887434, 0.04791983388244145, 1.1544312536716461, 18.42351390469459, 48.2761319991081, 55.988951267734656, 58.35817267817836, 53.735082841688595, 58.30153757526029, 53.94571411994196, 54.44588691957536, 47.39170420554377, 45.36401925548431, 39.337760325401064, 41.6072750860645, 42.9606379232099, 48.81361830619074, 50.27243014304869, 54.5854252384555, 54.655204203821, 53.26818743059712, 53.069648819585005, 54.616612003695586, 51.273928919146144, 54.17306253986975, 40.70257648344963, 42.07575905707575, 40.67830485682334, 40.53703285032704, 40.820129917513945, 43.064784696025235, 41.4611707195159, 42.10490618982623, 40.837796272770056, 41.546878430151175, 42.11681058329921, 39.29586941196073, 40.51704052955874, 39.236296453783595, 40.90718300111833, 42.83819721591088, 49.13097727683283, 55.63407482639436, 53.31920177705827, 53.909087027272875, 51.50126557196341, 51.66158068564631, 51.47158107449932, 50.042253694226666, 53.98611061034664, 54.057187880239184, 53.358288195825395, 56.00948487558673, 53.04946038030809, 50.328731844502116, 54.11709816225114, 41.75736850307834, 30.51381007317574, 46.32080693398753, 56.23172636955016, 56.58788150356662, 55.08258565779656, 49.72906028070758, 44.83427570712182, 41.72737413837064, 37.472132021381015, 40.26289055424352, 38.98266423133112, 40.848288612981, 38.851496250398704, 38.630796247913, 37.74157531799809, 37.97766277866979, 37.96118490157589, 37.60160946076916, 37.31710426269039, 36.512481012652, 37.53094403974472, 36.96922140736734, 38.39581881800006, 37.0053425142842, 46.184920341737815, 53.41528415679932, 51.321032662545484, 50.78219706012357, 50.33754541027931, 50.218732895389685, 50.67659116560414, 44.08648760088029, 37.13174873782743, 36.69524385083106, 35.385603673996464, 34.409133541968565, 39.57480484439481, 46.64029967400336, 50.58085395443825, 50.61080125070388, 53.239173658432506, 49.978860347501694, 49.72432990227976, 50.19490841896304, 49.57628396249587, 49.987038489310976, 51.009502333979455, 52.382716286566954, 49.448379393546816, 47.719320174186464, 44.46088960093837, 4.460896397790601, 0.4105529231169532, 2.236045911427467, 6.152470996302943, 15.245786097741897, 6.4136008293397975, 4.379841598772234, 0.5087853439392582, 0.08017358340082631, 26.86579400493253, 33.07687697872039, 42.373211999093336, 35.65108929910968, 22.962008022492935, 16.589403806194184, 0.16939582964104993, 0.10046778111568383, 0.020506626235381253, 0.030308305623851, 0.10838700052831443, 0.06135030514410427, 0.023766073713740034, 0.03532491173715361, 0.029979740089226155, 0.03464272193190071, 0.07642727555526842, 0.0714761182485569, 0.04458091627325743, 0.011464677199030356, 0.06429746071056974, 0.014825495346749743, 0.02480306373458476, 0.0728664146135411, 0.08744548916095689, 0.051084884006770394, 0.028812457664659428, 0.006112834361697277, 0.041285600558283835, 0.08028995215652451, 0.08396240912618176, 0.032300936704080914, 0.02609532382789879, 0.057206129535071315, 0.03229191984921213, 0.036777483389502576, 0.059954960259699056, 0.03158655779946956, 0.023773782473478108, 0.02939539694888217, 0.07678523013788847, 0.055244971261990655, 0.024152950030721487, 0.04171782736516288, 0.09479675396916368, 0.04786357238528229, 0.04494159046800868, 10.36087412987986, 52.88241055703933, 25.519591454536688, 37.96363246056342, 42.7203849054152, 52.31543587100122, 15.207243907836178, 0.32984307816913055, 0.33440439631381347, 0.4225839968890913, 2.187634793020064, 3.5331903974856105, 2.708103897110109, 0.466592070916968, 1.7065166225356443, 22.68699888260134, 50.00999219955937, 55.70727409855012, 58.47423953394736, 54.588229733128706, 61.649810037305286, 56.79096221923829, 56.64527362392795, 50.83454109007313, 49.31439515083067, 41.162184130760934, 43.65884727047336, 45.04211033544233, 48.95356847393898, 53.66228365129041, 56.20942769512054, 55.8736845754808, 55.69887630401119, 54.171572039204264, 55.961730018738784, 55.12563367043772, 57.20510567388227, 43.75070133516866, 42.18208666770689, 43.18547210385723, 42.977888507227746, 43.55497506357009, 43.39671527185748, 42.09927366625878, 43.424768063329886, 41.72078455648115, 42.80995615067021, 42.77561579981158, 43.1179916474127, 42.93064748087237, 39.543908334547474, 42.41744064515637, 44.586240706905244, 52.003046543367454, 55.36738503363825, 57.34730728210942, 55.7199158976155, 55.04933180347566, 55.09178361585064, 54.53634069811914, 54.014539949355594, 58.97806406021119, 54.865462856908, 53.24552789811165, 56.621708023932676, 55.761524400403424, 51.21834893380442, 54.50512647628785, 48.221469848386704, 36.37505685129474, 42.43797425300845, 57.739140295213275, 57.512168422822036, 56.242305001904896, 52.78554762563398, 47.69443665781329, 43.26515113153766, 41.110302940491714, 40.37510172013314, 41.16540047430223, 42.993366179927705, 41.088784817726385, 39.56384966450353, 41.59556288872996, 39.34093744524064, 39.358191951628655, 38.48287190160444, 38.10649694934968, 38.50599035140007, 39.63910033625942, 37.622029319886245, 40.48095080160326, 40.265997071419996, 49.13713932037354, 54.47958007935555, 52.14933133894398, 50.771834158128314, 52.54596925550892, 52.0009716095463, 50.19829734679192, 43.70163248431298, 38.92709209072975, 37.38674986747004, 36.07282646240727, 36.19984849806755, 41.64633797061059, 47.08774797378048, 53.248857990387954, 52.47621382436445, 54.070912253472116, 51.69448152665169, 51.459786507391165, 49.89240738653368, 51.959276814614576, 50.74928837437784, 53.123204861917806, 53.04957020667292, 50.685953863205455, 49.16150508388397, 46.14718321830996, 5.690062286392336, 1.7331715793378892, 3.6626359676161124, 5.50462095968185, 12.314473352124615, 9.266355364553391, 8.413555602873526, 0.8209434968809929, 0.06858794379138178, 30.09741713923793, 39.90040863713911, 51.06489796792307, 35.54362027875839, 28.421676658814956, 30.67521756695163, 0.7269478180716116, 0.049087968579823935, 0.03076416049753466, 0.024540550300791383, 0.07978025087786299, 0.0207941371181439, 0.041590212438736236, 0.08557372951820012, 0.03179665932792329, 0.02314302972668121, 0.031480684448334004, 0.08137499312719992, 0.046794764817722385, 0.02680673605702337, 0.02078978382351418, 0.05371144326824335, 0.0434420729476598, 0.00725561106998113, 0.3297224959298488, 0.14090443751023662, 0.16218206995437223, 0.14509115398170488, 0.14374274730442033, 0.1451875891296133, 0.18173151529364048, 0.10509215595741427, 0.2812679863024143, 0.16501124798049852, 0.14852178763718377, 0.0907542305668035, 0.13559448292418835, 0.15202467870568076, 0.10976831068194683, 0.1486747600739041, 0.20656431664622601, 0.17424738785672575, 0.22572558523426134, 0.11463715950207365, 0.25846810650921637, 0.14845703788582357, 0.15262742136274615, 12.59162018376012, 63.34008878277194, 34.695399884254705, 40.08919231353268, 44.00335688744822, 57.33530875175231, 21.52557526865313, 0.47609162246507986, 0.3306440997027582, 0.7207779297905584, 3.941838121221912, 3.7723821690005646, 2.9908124045018227, 0.7591770144720232, 2.1572116642229022, 21.135556351753976, 52.89544067075176, 58.49314143580776, 60.58283121355119, 54.92594580496512, 62.91740632826283, 57.39253221019622, 58.37130477351528, 51.059226220653905, 50.68061551740093, 43.46364659647788, 47.181708351258315, 48.101982685827444, 51.668876294166814, 55.5844372318637, 58.876149116023896, 59.0985788837556, 59.009682286170225, 55.74053187524119, 60.401186250871234, 55.67742093916863, 58.468328522097686, 44.71228999476279, 43.91757857414984, 45.342865913145005, 45.5956587483806, 45.40597684921757, 46.726862461336204, 45.113395490954005, 46.706093511273785, 43.838954664045765, 45.26014704858103, 45.56695876582977, 45.41470412285098, 45.05000998896938, 42.95568004731209, 45.80904353049494, 48.54257468254336, 53.630277110684304, 58.82740189952236, 58.37944369162283, 56.96578618018859, 56.11441612243653, 56.69511910407775, 55.72243013689595, 55.05464661505915, 59.50214370604485, 55.85894038600307, 55.655318383247625, 60.508192431542184, 55.22559919664937, 59.09353863808417, 53.47619464320522, 47.11951524980607, 44.39033792864892, 48.04501418144473, 59.42230386118735, 58.88948909697994, 59.04039444461946, 53.92066586402155, 49.4139527505444, 45.246077506772934, 41.14571409840738, 43.07934453410488, 42.972381499505815, 44.729415062935125, 43.063035318928385, 42.028698459748306, 42.79426274761077, 42.08556106013637, 42.04349756240845, 40.55057679453204, 41.324633013817575, 40.19699865771879, 41.720831624923214, 39.966892811559866, 42.6632438167449, 41.64697339457851, 51.462865567976436, 56.70071240394347, 55.44764064973401, 52.01392719822546, 55.10443718202653, 54.45957599147674, 54.152368114840606, 47.21602124552573, 40.88827717688776, 39.4895835076609, 37.140319116653934, 37.696283709618356, 44.733815962268466, 49.871191286271625, 56.619888044172725, 53.10494622876568, 56.496984497193374, 53.54208653972995, 51.97551542712797, 51.28173443578905, 53.461850535485056, 53.586005318549375, 54.58595475842876, 54.164327421496, 52.12466355293028, 51.24598595403856, 50.15479433921076, 7.234040546801783, 1.9710612465297024, 6.667097730021323, 11.773795216314255, 24.83873075054538, 15.798906972331388, 17.227342013389833, 2.7365638796360265, 0.24641143007864877, 34.473809503739886, 46.521981377755445, 49.954859364417295, 48.366640690834295, 36.23518905332012, 42.5934648513794, 2.3754719524614276, 0.21944761726885073, 0.18842851803187402, 0.10682827207229792, 0.27524757709714676, 0.1322254427378216, 0.10901336933696464, 0.18616488143321008, 0.20993694212407837, 0.10667818012617289, 0.11580378117580568, 0.1407010105228232, 0.1552916300152579, 0.0886074376983508, 0.13207476856487413, 0.1504065018267401, 0.1227504289859245, 0.169130104383634], [0.018546094239178686, 0.057835137516620665, 0.04240384377959756, 0.018944963662614746, 0.05455590198717771, 0.03450366548232494, 0.061589443320108045, 0.10154446406710534, 0.01824583948379563, 0.06141157685628822, 0.036546435101979205, 0.01668637558337181, 0.06732825775660815, 0.01517670739802622, 0.02637938348456256, 0.05119060797076072, 0.012422777400652488, 0.06682602583520836, 0.0776141296110807, 0.02730796823368198, 0.043767560724048846, 0.04740947759860466, 0.012330836316029872, 0.47608727108566995, 22.944810390472416, 42.057159177718624, 33.17977251545076, 36.681437107824514, 39.91895752568399, 38.40906466207197, 0.2392803925660349, 0.02085206485653837, 0.122100418703931, 0.8471822534357348, 2.129670987206121, 1.7334734792670898, 0.4477720485339242, 0.4430847548909726, 5.11679268652393, 30.053029637182917, 55.1721804372726, 56.87040982707855, 58.335281725852724, 57.20928299811579, 56.8336925198955, 54.930817388719134, 51.04226196965864, 42.63085680623209, 41.17121734926778, 42.03833964563186, 46.93266137953728, 54.14159728634743, 55.19945659945088, 55.013681380979484, 54.86673762721401, 50.25573261322514, 55.753499231030865, 55.90725614178566, 54.20562997941048, 49.110714312522646, 40.660069757892245, 40.31962763878607, 40.24116846822923, 39.885848799059474, 41.64760489617625, 40.75766617251981, 38.483864261258034, 42.41971954222649, 41.998217721139234, 40.493667125701904, 41.01292225622362, 38.694036622201246, 39.822773164318455, 39.25419422887987, 41.22925666070754, 43.2465708640314, 50.38100919415874, 54.9526414563579, 54.51304574166575, 52.051966344156575, 53.237232085197206, 54.603793697972456, 53.9722607212682, 50.88228810218073, 49.1657216318192, 51.41711896465671, 52.056779092358006, 55.690882513600016, 53.69461967099098, 57.615664082188765, 50.97785272905904, 35.945172925149244, 50.79579199514082, 53.25223907347649, 55.24807045536657, 53.98227845468829, 51.03091455275013, 46.71759782298919, 42.14580866598314, 39.46782219794489, 39.186058736616566, 37.863996413446245, 39.76995452757805, 38.37813677326326, 39.349935362415934, 38.317775418681485, 37.80689847084784, 38.84554993721747, 39.05911514835973, 38.749130233641594, 36.894021726423695, 37.924969657774895, 37.59012083853445, 36.426012362203295, 36.96509115157589, 37.54109905612084, 44.68879499743062, 49.49744824440249, 50.67159798837478, 51.37475344442552, 49.30701717253655, 49.4485794344256, 50.309476929326216, 49.39385452578145, 41.99165167347078, 37.89573231051045, 36.3583436319905, 37.696962279658166, 35.901669917568086, 39.45424295240833, 41.81178354447888, 47.716413697888775, 49.661905380987356, 50.03119653271091, 49.31743891008439, 51.2260877701544, 49.395552912066066, 49.75813681079496, 50.843939089006, 55.252063428201986, 50.85847147049443, 52.86522273094424, 30.446247246957597, 0.5623881482789593, 0.8868276099524192, 4.2325703270973705, 10.559539237330037, 6.359023990169649, 4.024647200299848, 3.3226814481519886, 1.7084692274370503, 2.039140722443981, 47.13252575166764, 31.172982031299224, 24.93863940238953, 35.376131150030325, 20.06491207307385, 6.209386058392064, 0.1795666274284163, 0.02448900599002598, 0.06825497133597251, 0.03458823775872588, 0.1113496923578843, 0.05051849988259135, 0.05146474104314562, 0.041058378879942244, 0.021062675833461747, 0.04124951781705022, 0.020944378451414166, 0.03765451233653772, 0.004148282797917003, 0.03618366565675505, 0.026739530993865866, 0.005751721581609379, 0.031013033735836228, 0.029711603570068558, 0.046011076023381565, 0.06822683292651369, 0.034507825339753787, 0.10557625457764634, 0.014065754460921932, 0.04445892060175539, 0.05233806212462726, 0.027109206721727407, 0.019362837812232397, 0.03340725576685321, 0.1108879405224035, 0.01668148602719509, 0.018495511368758256, 0.020986160886804425, 0.08420151282822894, 0.05543927031178629, 0.06344016618846406, 0.03204544829655319, 0.09024751703104666, 0.03327084232061621, 0.06599940930403049, 0.0700151809160748, 0.03699270813094993, 1.2095650694062634, 35.45408433483493, 41.271222099181145, 29.256102077422607, 46.29054584810811, 46.35303704969345, 39.73438647485549, 0.15312418341636658, 0.018272574037133206, 0.09674271688826623, 1.5217346217363112, 5.16067567371553, 5.625100972190981, 3.3057412216740274, 0.68840685390657, 5.8805879854386855, 35.707755780989125, 56.45552896684217, 57.66793750947522, 60.082474062519694, 57.95052466853973, 56.365910653145086, 55.356751488101104, 52.81976638301727, 44.6922545279226, 43.275157097847234, 43.612429941854174, 49.7596469233113, 56.14996456330823, 56.53352529771867, 57.943844872136275, 55.766294002532966, 53.901885555636504, 55.3858672418902, 57.13409900665284, 56.21982197607718, 50.524379668697236, 42.8733181184338, 43.022799645700765, 41.959762803969845, 42.002332287449995, 42.65539123165993, 43.0898251072053, 41.54435634613037, 43.80488103435886, 43.16752333794871, 42.589036495454856, 41.250790472953554, 42.804602115384995, 41.57833191656297, 41.813230899072465, 42.648962466947495, 44.31026274158109, 52.71102259235998, 57.09098431371874, 55.048715991358605, 55.59324687527072, 54.89174665943269, 55.89904269864483, 55.10984220812398, 51.6852286554152, 52.77738125093522, 55.88200784498646, 55.272973583590606, 55.10994418974846, 53.354185396625155, 59.10599216338127, 53.074743978438846, 35.22898735538606, 48.73293907411637, 55.27043188771894, 55.45098250912082, 55.9495432146134, 52.752772300474106, 48.761121303804465, 43.187903973364065, 41.22319659879131, 40.78615434708134, 40.845644935484856, 39.931971949915734, 41.5546251112415, 40.754775385702814, 39.380208215405865, 40.08267725667646, 40.79204182470999, 40.59384838227303, 40.28005484611758, 39.326330538718935, 41.00906264397406, 40.10225380620649, 38.37826228910877, 38.2427797009868, 40.19510807529573, 47.13190993955059, 51.898307492656095, 51.84580656789964, 50.665063319667695, 50.952094524137436, 52.14968827462966, 52.01548045681369, 49.92454336535547, 44.86489372868692, 40.131875545747825, 36.78522302258399, 39.623450079271876, 37.656369670744866, 41.36870868744389, 44.399610411736276, 50.115311761056226, 50.541516503980084, 50.59075793912334, 51.5973283398536, 52.334753544099875, 51.28942620369696, 51.66876646780199, 54.31100053171958, 54.02982934828728, 51.415875573312086, 53.06504787937288, 33.50388580752958, 0.5434999747141716, 1.8057862957639081, 3.869595907388195, 5.9330982258242955, 9.199298524087476, 7.089388437809483, 1.8964458761676666, 0.514370063620229, 1.9243382181852096, 48.515471104652654, 38.785604353873964, 33.97848867600964, 36.33394256714852, 28.808232122851958, 16.273751066577052, 0.46684975225117903, 0.0395057293316049, 0.041878272989584554, 0.017503050208512335, 0.04345156477704164, 0.03384235923388793, 0.0533751804651993, 0.04057501187367786, 0.05152772113140072, 0.045125623939618956, 0.05806460383258039, 0.017260592956576618, 0.04476910960229655, 0.012019064386315163, 0.06198426205364447, 0.04311784921634582, 0.022827447467153112, 0.021441879779881528, 0.18894760388760798, 0.17019125873283034, 0.11808345965560406, 0.15697633396954308, 0.14387728766568247, 0.1847471897640536, 0.21068763168108082, 0.1440251273133101, 0.14512377400552073, 0.12420897612408285, 0.19039066838881663, 0.09442877895649403, 0.1932345399813306, 0.08254569038868913, 0.23391388536941624, 0.1668124432645498, 0.13420086173761275, 0.16939356202079406, 0.1101262882472046, 0.14001795120777624, 0.13223316490409837, 0.1525635755951366, 0.08766164852967186, 1.3995244762589856, 36.936948145589525, 53.65360344609907, 43.13940778855355, 48.4238092360958, 50.193668949988584, 47.28474117094471, 0.809100513016024, 0.37321603466426173, 0.5526422841414329, 3.3877847031239545, 9.15450309553454, 8.18212644707772, 2.701737400024168, 1.103060094098891, 7.316363742274623, 35.06098831853559, 57.42612731072211, 55.30605877599409, 62.13767051696778, 58.075150136024725, 59.88069949611541, 57.39725474388369, 55.9919911046182, 46.27359336422336, 45.542243911374, 45.88164268001434, 52.922069641851614, 58.44912067536385, 58.92280963159377, 60.646859984244074, 58.541445424479825, 53.01023667858493, 57.50026795171923, 58.61970847652805, 57.81985090624902, 54.20856783466955, 43.56407496236986, 44.74644991659349, 45.12826127390708, 44.185688264908336, 46.94558166688489, 44.68390380182574, 42.29518821162563, 46.130403318712794, 46.01907468611195, 44.456982920246745, 43.39167110381588, 43.45103617637388, 44.42609033276958, 44.255651581671934, 45.09409742970621, 46.775088002604825, 52.87199274186165, 57.49360776716664, 58.40128737111246, 56.82745595132151, 55.64100957685902, 58.78178473441832, 56.789095171036266, 54.59816509677518, 55.299951645635794, 59.037460511730565, 56.0743098874246, 56.824553397394, 57.307412855086795, 59.8275553026507, 51.37459262724846, 39.48563368089738, 52.27148963559059, 56.64318300062611, 59.37694165014452, 57.957541788778, 54.60603729371102, 48.66092043538248, 45.01069607273225, 42.87665605545045, 43.694403556085405, 43.5549593740894, 43.14956280492967, 41.8957850240892, 42.85037225292575, 40.683407860417525, 41.0841917222546, 41.900158466831336, 42.85135284546883, 43.83304365219609, 40.71703826227496, 42.14527130126953, 41.49138473695324, 40.41486670894008, 42.259400506173414, 41.914969336602, 48.4688223561933, 54.16332329473188, 54.77376176464943, 53.35471099422824, 52.77238807370586, 53.59365786275556, 55.51739215850831, 53.01658307352374, 47.63052948059575, 42.96520748446065, 40.33110449391027, 41.86608091477425, 39.17313844926896, 42.880068517500355, 47.51073637316304, 52.152426089009936, 54.045456071053785, 52.937935629198634, 53.06261208749587, 54.10611160339848, 53.95140547906199, 53.50128996756769, 56.31123673531317, 57.413614949872425, 55.38385898836198, 53.59382652467298, 34.63777242168304, 1.4302425182634786, 2.892891168594361, 9.705710834072484, 20.235721488152784, 13.937618770907003, 12.087864298974315, 11.078082457665476, 3.409695798350919, 3.006645541998648, 58.36303249482186, 42.028349368802964, 36.31257741681991, 47.017870949160674, 36.682507914881555, 29.484937075645696, 0.7086399714312246, 0.18087158159863564, 0.18079728639173895, 0.20616556788163803, 0.25436941354024795, 0.14922899404360404, 0.1618790821803193, 0.12195317660488429, 0.09756829153986708, 0.14254450918205325, 0.151557027993183, 0.07036932804171117, 0.10284007196464848, 0.1470939836074268, 0.1766163002579443, 0.07925998524672563, 0.16048648755156225, 0.09757342432895977], [0.08342329007122787, 0.05578188398372262, 0.052984582876125653, 0.029297860549582593, 0.023800109084996007, 0.03625725223232181, 0.11551945530358823, 0.10322812614181351, 0.10405707924116044, 0.011558617773135344, 0.04492510425587816, 0.013980349063903335, 0.06605340318093378, 0.07592581738267215, 0.006534885126917113, 0.015263509947896726, 0.046944561819996566, 0.07130753293993973, 0.05981228021424144, 0.044456488272595795, 0.021683295152240226, 0.0004885216109077221, 0.08733629864910919, 0.03714489532754787, 2.808548442779049, 41.966430833262784, 38.10350810327838, 41.97129064990629, 34.568777930352, 44.52287089440131, 10.601774338752994, 0.17047576846614962, 0.07042010434933248, 0.8680797836953594, 3.885764897831025, 2.7769245784128866, 2.551599366049613, 0.6115039450026328, 0.7889797346245858, 11.624445088448065, 45.715063541166245, 52.79100364254367, 58.90969322573755, 57.22969501249252, 58.47614972822128, 52.03044429902108, 49.56327738300447, 44.03315905601748, 43.082670704011, 46.473575407458895, 52.5294521547133, 52.94772586514873, 56.37797586379513, 52.64897461860411, 53.80009220492456, 54.07874522670623, 57.642708824526885, 52.63838421913886, 52.89251850497339, 44.66739454577046, 40.67229186334918, 39.96783025803105, 40.60655686163133, 42.221996784210205, 40.122818793019945, 40.28196896276167, 40.135817527770996, 38.55630259360037, 39.66660399590769, 40.448579480571134, 43.29982096149076, 39.984366970677534, 40.890556073957875, 39.44245623004052, 40.498460262052475, 42.97562137726815, 48.423440533299605, 52.44510158415764, 53.040536988166075, 52.31497303132088, 54.8827487422574, 51.53196204093195, 53.48435317316363, 52.907607863026286, 52.092970801937966, 49.647933898433564, 50.9742598379812, 54.61191692659932, 56.36122342078917, 58.251809766215665, 55.623135335983775, 51.77468222956504, 51.40723459182247, 53.9241724629556, 53.26309227174329, 52.51605726057484, 48.791343165982155, 42.968992571676935, 41.025297334117276, 38.456478272714925, 38.43939635061449, 41.59486470683929, 41.352658348698775, 40.171495406858384, 40.556970257912916, 39.1643484177128, 37.269996596920876, 38.88704076890023, 39.25127990784184, 37.85922681131671, 37.70101408804617, 36.91508485424903, 36.755260036837676, 36.387396627856845, 36.69323559730284, 37.328098666283395, 40.287322998046875, 47.04123650827716, 50.44874068229429, 52.94632557899722, 51.43707990646363, 52.56719320051132, 51.254795597445586, 49.12337964580905, 49.415541310464185, 45.09834535660283, 39.161594913851836, 35.894413532749304, 34.903560069299516, 35.95266857454854, 34.14689563935803, 39.97284696948144, 41.156814405995036, 44.9232703639615, 45.41503360194545, 48.93181500896331, 47.7098084265186, 46.71779786386798, 48.79209233868507, 50.70662475401356, 50.5526795694905, 52.46076753062587, 17.636321667701967, 0.2713708964086348, 1.7463432660987301, 2.0115989422605884, 1.1914091533230198, 5.821619072268087, 4.86454604133483, 1.952173563261186, 0.2382417612018124, 12.34879409113238, 44.81938638994771, 29.68092614604581, 45.38530988077964, 44.11639959581437, 17.96807965924663, 2.504350494953894, 0.0471902079129171, 0.034100408290302565, 0.05191058123243913, 0.025756680406630043, 0.03287853635547142, 0.03270850314067737, 0.07173078119634621, 0.08053587404109779, 0.005428887821073014, 0.027071149388868964, 0.08814932478051032, 0.04553042862924837, 0.023895521505525517, 0.057331545789155273, 0.013009425508038653, 0.035270025367818536, 0.07101881738391615, 0.00857905860269262, 0.032431899434736663, 0.03876434391244285, 0.02660403876835781, 0.054480633848617156, 0.01171020167549291, 0.03248239995070523, 0.07513627950702945, 0.02641264702223482, 0.06779085994968492, 0.04525492042903939, 0.07568964013649572, 0.01527419878966025, 0.02544955767300581, 0.055693431471985196, 0.029704984570402774, 0.04790635073497411, 0.05055300065226132, 0.04797698021115315, 0.005650737307845585, 0.033110607370373704, 0.029434411891645966, 0.03928787690857726, 0.022118569073838093, 0.06898764250499588, 6.146545765861389, 51.41488713602866, 36.21770312709194, 45.63735354331232, 42.002567629660334, 48.52555159599551, 9.310892897267497, 0.5764206114315218, 0.17584121846143277, 1.6090497686978311, 4.1030825914875155, 7.312836550897168, 4.863331087173955, 1.2069055798553652, 1.6480400893957385, 14.476189613342287, 46.08059706226472, 52.32319824157223, 57.62394028325235, 58.17162475278301, 61.02070893010786, 53.56955489804668, 50.836941580618586, 46.40096449082898, 43.92368178213797, 46.99190485861994, 53.955351383455344, 55.9979138835784, 57.08940752090947, 55.07221098869078, 54.54059254738593, 56.21376191416095, 58.64514504709552, 53.7480737316993, 54.68723820101831, 47.90807247161866, 43.4083019533465, 41.644361096043745, 43.057885246892134, 44.28624999138617, 42.46703509361514, 42.24111441643008, 42.38149212252709, 39.058158090037686, 42.379523092700595, 43.101831482302764, 45.50678568501627, 40.752488643892356, 41.29491713739211, 39.81713279601067, 41.91773460757348, 44.74274327678066, 50.48115122702814, 55.52402488646969, 55.187826771889966, 54.62847717346684, 56.3001678066869, 54.24087247540874, 54.29326749617054, 55.77967320719073, 53.77695806564824, 51.299867553095666, 52.92137930470129, 56.192263403246486, 58.11824129473779, 59.41893454520934, 57.34312603550573, 52.05903053283692, 54.73512249608194, 53.51274328847086, 56.215907450645204, 54.789725811250754, 51.36212733484084, 44.713152916200706, 42.52457234167284, 40.17136989101287, 41.60398421748992, 43.78752454634636, 40.95736972747311, 41.740078695358775, 41.13979916418753, 40.526003145402484, 39.762160778045654, 40.21455910898025, 40.93191746742495, 38.67595449570687, 37.64200595117385, 38.89402258780695, 38.16108849740798, 38.028104459085775, 38.41286543876895, 39.30184710410334, 42.839491598067745, 50.61584934111565, 51.43048640220396, 54.28449707646524, 51.309155725663715, 53.45383321085284, 51.32219368411649, 51.50321106756888, 50.47803294274115, 46.2572096240136, 39.700952191506666, 37.969002185329316, 36.03275160635672, 37.40847195348432, 36.55853356084516, 41.07449170081846, 44.42276808523363, 47.167889841141246, 48.033164701154156, 51.68005897152809, 48.945786491517104, 48.619782617015225, 50.247452489791385, 52.80084486930601, 52.21643524785196, 53.65970273171702, 19.31495685731211, 0.538068411331023, 2.528956503637376, 7.730097799531876, 7.338330976424679, 8.104089421610679, 5.716829521040763, 0.41402605933047115, 0.7446657770103025, 13.464242623698327, 50.622701721806685, 32.64502794511857, 46.73383643550258, 52.478680995202836, 28.2008844806302, 8.102084109860083, 0.07014051290048708, 0.03298540945134817, 0.03035365419852878, 0.03721614150450595, 0.03168565701813467, 0.03458671707419619, 0.06381277220263597, 0.022055652187836748, 0.04355107576796605, 0.09974214263380536, 0.06007223682958753, 0.02924415778609053, 0.07586464526191836, 0.06894566854762454, 0.020982832234773426, 0.03512627662970655, 0.02838889722742381, 0.04820460025521536, 0.22799665288579082, 0.1344879761698746, 0.15842103789890968, 0.15659952596310647, 0.11563803039250836, 0.11756088809981463, 0.18325429890424977, 0.17192876146685693, 0.12491138682009713, 0.0959558220159623, 0.12093947374171789, 0.15155135894254332, 0.15698859137633156, 0.13165008006317, 0.1186566619623092, 0.19329106194838402, 0.13980911563961737, 0.3359427315092856, 0.1676843279311734, 0.0943625353336815, 0.12320542392591316, 0.10485816206182204, 0.14226971344361383, 0.2996043314135844, 8.058453625248324, 58.030007577711544, 46.92321631216234, 52.93781795809346, 44.34174760695427, 56.77311543495425, 13.331108554717034, 0.5644288226481408, 0.2705366266590934, 5.067035459703015, 10.49740202965275, 13.047915389460902, 6.844865920082216, 0.940417850450162, 1.3355634890256392, 14.046841090725316, 47.17244763528147, 52.9553823317251, 61.346936379709554, 61.27468239876532, 64.31790036539878, 55.29398179823353, 54.53189273034373, 48.63733130116617, 47.335245609283454, 50.59521767400926, 56.13655005731891, 59.244016447374904, 61.57524578032955, 54.86935384811894, 54.61327406667895, 57.18335220890661, 61.70938691785259, 56.2838742809911, 56.68668600820727, 50.46679927456764, 45.75459318776285, 42.727013711006414, 46.04436612898304, 46.187273763841205, 43.467447373174856, 44.484470890414336, 45.177596845934474, 40.73051944855721, 44.16508797676333, 46.009492335780976, 46.73761760034869, 44.00958953365203, 43.63406965809484, 43.18719794673305, 44.53964294925813, 48.00830471900202, 52.561082147782855, 57.03533372571392, 59.2632713625508, 56.74765925253592, 58.527854411832756, 55.99359927638885, 58.152648325889345, 57.880859451909224, 55.95217512499902, 54.07110052724039, 55.84762827042611, 59.61477064317273, 58.851649991927616, 58.870963742656095, 59.226989438456876, 52.14195728302003, 56.299253894436745, 55.68921158390661, 57.00852040321597, 57.10765046458091, 52.871365162634085, 46.69620913843955, 43.842873111847915, 41.73667015567903, 43.30718325030419, 45.768062606934585, 42.63417513139787, 43.88475225817773, 44.273298325077185, 42.826975314847886, 41.98849416548207, 42.37203921041181, 43.31033683592274, 39.96284100317186, 39.59349101589572, 40.42620628110824, 40.72718543391074, 40.424919743691724, 39.39599575534944, 41.35896944230603, 43.678572870069935, 51.682428083112164, 52.80328458355319, 57.061441021580855, 55.33370364096857, 54.674627780914314, 53.044227938498224, 53.76655986232143, 52.46077537536622, 50.208271934140114, 42.013546343772646, 41.329728172671416, 38.23343661523635, 39.23277808773903, 37.90467139213316, 42.63135494724397, 44.7743889593309, 47.84954286390736, 49.87214834459367, 53.85302066802979, 52.224805585799686, 50.59365264831051, 52.469094722501694, 54.952198228528424, 53.31742886574038, 53.59460315396709, 21.0361046560349, 0.5805462706954249, 3.6363256890927595, 7.60208732658817, 8.751096148644725, 12.550047962896286, 13.630173590875442, 9.811107862380243, 1.2636939003582925, 15.929793523203944, 56.957588426528446, 39.30291791116038, 53.23629463872602, 52.367524946889574, 41.94068831782187, 16.254478500735377, 0.194831726051146, 0.12747699995675396, 0.20541893859063426, 0.12939533008442772, 0.1367622154254106, 0.2013295612508251, 0.23207645412654648, 0.212293014891686, 0.12402024270305712, 0.13204438551779718, 0.15781046582325814, 0.14050778782656118, 0.09523087301321569, 0.12315337591233755, 0.13345198014811163, 0.12902613699195847, 0.26409995591928886, 0.13466527955907007], [0.03853632933309963, 0.0716134624916219, 0.05144217975377556, 0.03480874467641115, 0.06718056366568612, 0.07590946140548877, 0.014405090234152254, 0.04205513970866319, 0.0286043249821711, 0.028022521423296105, 0.025380933431968577, 0.022482529785784505, 0.12939943631570186, 0.0358821411106375, 0.032823558055585435, 0.0108050812418843, 0.07283046976813386, 0.03532139156314154, 0.027686693375149084, 0.018134827597907955, 0.02604929151974859, 0.074983176835362, 0.043168518271657734, 0.021828302189767845, 0.21632076811886605, 23.02674281981684, 41.564599698589696, 29.098722857813684, 38.48178932743688, 33.0832939763223, 31.227653987946052, 0.12380597557151511, 0.12841743417084217, 0.6631587409684736, 3.9090478420257573, 3.889721343594213, 5.7882191096582725, 1.7963457636294828, 0.4920212870403644, 3.0560659352810156, 26.297197418828166, 55.140687727159076, 58.51354952781432, 58.82235380911059, 55.213718337397424, 54.80460336131435, 47.23938680464222, 43.17334413528443, 45.549174739468484, 53.657761158481726, 53.028734576317575, 55.9093467650875, 57.34898605654317, 54.484063348462506, 53.88104992528116, 57.46723767249816, 54.414319684428555, 53.18789259079964, 45.65040326887562, 41.858173416506865, 42.2657782800736, 41.76736662464757, 40.3232362193446, 41.57842605344711, 40.67803029091128, 40.62922031648698, 40.565097408909956, 41.73670153464041, 39.97026997227823, 41.578681007508315, 41.3355528923773, 40.231323319096724, 39.402918738703576, 40.687506737247595, 40.40913612611833, 41.74533859375985, 48.592930070815555, 51.91815468572801, 50.65180570848527, 50.089212309929636, 50.45611473821825, 49.26954284791024, 49.172256300526286, 49.928206859096406, 51.03488399136452, 51.846190960176536, 51.92719182660503, 52.338162083779615, 53.415907813656716, 53.7880858298271, 51.10230953462663, 48.22503136050317, 56.33273916859781, 54.9986743927002, 53.87198140544277, 47.35887004483131, 42.71303438371228, 40.50666193808279, 39.574302781012754, 44.22039731856316, 44.72084468410861, 49.78009816138975, 52.114685043211914, 47.43020226878505, 39.98289215949274, 38.167230929097826, 35.929589348454634, 39.91794555417953, 36.52257719347554, 39.212672018235736, 36.36470571640999, 36.736099258545906, 37.92533051583075, 35.96431409159015, 38.045347198363274, 37.420380269327474, 39.525594788212935, 45.48011356784452, 47.797406719576934, 51.44453240979103, 51.26508789677774, 52.13829771164925, 48.918510329338815, 49.708546284706365, 49.81661150532384, 49.32070624443793, 47.83796794952885, 44.95621042866861, 41.263322445654104, 39.54447315585229, 37.71256546820364, 36.93475946303337, 35.94851086216588, 37.25576623793572, 39.118366472182736, 41.67526152826125, 41.61880685437111, 45.72668552398682, 48.0190324014233, 49.52774463161346, 53.264924018613755, 45.8615993684338, 7.018484242500798, 0.8821127371441935, 1.495012616918933, 4.907088558520041, 3.8378247089924353, 4.3425388778409655, 2.8647947407537893, 0.35846115059910283, 0.04238297554454015, 18.34903790104774, 36.30096327873969, 32.07009477000083, 26.47220769236165, 27.278801933411632, 11.252748543216336, 2.656272962208717, 0.11463558136094963, 0.0782745586888444, 0.03495288411936453, 0.10285742385613342, 0.05911296834388088, 0.03541603789574677, 0.05505186347891727, 0.10979576727315304, 0.027121803122422388, 0.022100024000411073, 0.018213265425255223, 0.023074809597024036, 0.02970568171041387, 0.03593706578436879, 0.09065522136346948, 0.05573763857565581, 0.07304210921809559, 0.07326108012949267, 0.04638725583772025, 0.05151192822884168, 0.03758310145067592, 0.034392854694517395, 0.07157619231410565, 0.04432037743108888, 0.034334298764025016, 0.0618302439069075, 0.021832839345499393, 0.034842804945524664, 0.038534923561758576, 0.020643851734817992, 0.07552428005803978, 0.049121783700801676, 0.004014665093798672, 0.02396222669631243, 0.0162743428541768, 0.05368035542027605, 0.03299814949352895, 0.030792570868206602, 0.060967215216688575, 0.05905986312896975, 0.06161707228109722, 0.05417337130394675, 0.47708312410020065, 30.639926041326216, 44.46509045939292, 32.690796121474236, 47.999863778391195, 40.618818190789995, 34.09733256986065, 0.12937859872416144, 0.2700132966762589, 0.5366962559280858, 1.9409926019368635, 7.76022062186272, 7.423921506251059, 5.7526633143425, 1.5034426484377155, 4.896987965030055, 31.546017085352254, 55.24677999557988, 58.765361770506836, 58.12789424773186, 56.562644973877944, 57.371292575713134, 47.97641584950109, 45.17237617123512, 47.230757590263124, 54.564417023812574, 56.493093505982436, 56.185277661969586, 58.15438201350551, 56.389189920117786, 55.35659851566438, 58.695017983836514, 56.95800419776671, 53.78979598322223, 49.518283874757834, 43.73348997485253, 43.9275453167577, 43.47767691458426, 41.77439158962619, 43.96160717933409, 42.14034872670328, 41.97948055882608, 42.93548376329484, 43.235913784273215, 42.4113021358367, 42.27396818899339, 43.059434583110196, 41.96799193659137, 43.41632320034889, 41.62494144132061, 41.762173406539425, 42.73632541779549, 51.60406304943947, 54.54289890104725, 53.356040677716656, 51.23424630011282, 52.20829240737423, 50.94928218472389, 51.501932374892704, 51.84100166443856, 52.42561524914157, 53.73732251505698, 53.162071627955285, 53.44450973695325, 54.86544324505714, 57.36385183949625, 53.61383061255179, 49.94246859704295, 56.20006107514905, 56.446044675765506, 56.24797282680389, 49.96040951821112, 45.116870710926676, 41.65688522400395, 42.001532123934844, 44.353275452890706, 46.25349906183059, 50.02794881020823, 52.172269359711684, 49.35848651393768, 41.564870342131584, 40.654095988119806, 39.141990907730595, 40.368743558083814, 39.8418515728366, 41.07565272238947, 39.64938479085123, 38.25075387954712, 40.31825088685559, 38.01065775655931, 38.13257286625524, 39.645862502436486, 41.18774229480375, 46.81828898768271, 50.485995354190955, 52.858342893662, 52.40719579881238, 53.3996025208504, 50.90561051522532, 52.17060627475862, 53.01164088710662, 50.85427453441005, 49.384170193826, 45.23594210224767, 40.77472063802904, 40.167996652664684, 38.53654953741258, 37.70540714263916, 37.676279621739546, 39.01365095569242, 40.82251471857871, 43.38606211446947, 44.63153623765515, 47.32376875415925, 50.62720068039433, 50.948332971142186, 54.200330857307684, 47.664587420801965, 8.699920004413976, 1.4886854661087838, 5.24651478375158, 8.077185884598764, 6.644426430425336, 7.888116855775157, 2.718864674529722, 0.8383340604843632, 0.16440832146233128, 22.032374912692656, 40.62552544378465, 40.71399450302124, 33.38735611208024, 37.885745956051736, 24.247462864845033, 4.799359190848566, 0.1469268232223488, 0.21335407731033143, 0.04501906493979116, 0.03226399977481173, 0.0411966998851107, 0.051204175387899724, 0.1005197142160708, 0.0875278206301793, 0.02070894239530448, 0.038709633743330356, 0.05334896493643042, 0.03178228560324398, 0.022631886287502224, 0.05360571930425302, 0.033889190188699195, 0.05869423234534841, 0.046460087816681594, 0.018174878674589338, 0.16836950164889136, 0.1596945211771996, 0.11250875274380369, 0.09706304889292487, 0.162290915726654, 0.17503803655985864, 0.18219910471910433, 0.1004833480223052, 0.17092276544820878, 0.06444573702831423, 0.19459554114409033, 0.18710906947812728, 0.19277556138413568, 0.09793398361052237, 0.0963069124507808, 0.07321908318948361, 0.13035313917263863, 0.06992071461413177, 0.15149191051961916, 0.11875403939836449, 0.17174062559441214, 0.20063179304763196, 0.141395928878938, 0.15508169128048807, 0.5345370524352597, 33.94534464805357, 54.67069364363148, 35.3469330264676, 48.05708331446494, 43.02434113717849, 42.22357357701948, 0.8129971426340842, 0.9717138904717662, 2.6642956800999182, 11.25393113782329, 12.529065243659481, 11.271637697373668, 6.953595001851359, 0.6559282192780126, 4.3084765249683015, 30.263829577353697, 55.94847632992653, 59.83926749998524, 62.6764198272459, 58.04294747691001, 61.05271939308413, 50.44380634061752, 46.913488834134995, 49.41799279182188, 57.740568037955995, 57.42705691245295, 59.30464452312839, 58.794748167837824, 57.97553370075842, 57.44365246065202, 61.52840875810193, 58.73907404561197, 56.73722182550738, 49.68909132865168, 45.88058364006781, 45.93446131675474, 45.74721128709855, 42.87881335904522, 47.55878540777391, 44.099403965857725, 45.80392483742007, 43.72712004569269, 45.76323416925246, 44.72570057838194, 44.92831060963292, 44.706010280116914, 45.65486300376154, 44.36381093917355, 44.55267306297056, 43.867156505584724, 44.97395130895799, 52.83059604706303, 56.32760870841242, 56.24121458299699, 54.462243203193914, 54.8817995286757, 53.1544896864122, 54.48892708747618, 53.8595514143667, 54.64651223151915, 56.19214573214131, 54.63591398731355, 55.09757695659515, 56.948461071137466, 59.80462904899352, 52.58428688972227, 53.22566893792922, 60.751398994076645, 59.294301232984, 58.55420489465037, 51.94754108305901, 46.398701283239554, 44.45568853808988, 44.22507278380856, 48.363341977519376, 48.80918210552585, 52.42088094834359, 55.341344418064246, 53.060325345685406, 43.1473780447437, 42.19706619939497, 40.146372625904704, 44.188814393935665, 41.35794570369106, 44.620075072011645, 40.43962863183791, 39.991874387187345, 42.56814202954693, 39.725274808945194, 40.67334305855536, 42.272983674080145, 41.643753128667036, 49.46362956877678, 52.703122938832934, 55.7375979423523, 54.27740543119369, 56.369836945687574, 51.527804328549294, 53.56250247647686, 55.274938691046934, 52.40353230507144, 53.21574534139326, 49.338113723262666, 44.678298734849506, 41.34719448704874, 42.401935515865205, 39.463946896214644, 39.363926456820586, 41.350701085982784, 42.09218202098724, 45.54006699592837, 46.25093383173789, 49.78313015353296, 53.162303047795454, 52.97980693078811, 56.78421182017173, 49.58099080670265, 8.948797333625055, 1.5183285335379264, 6.323862883352465, 15.735732297743521, 9.247526026541188, 11.588026861990652, 14.72977182557506, 2.336971192590652, 0.3399938963834317, 25.39668986874242, 47.837716917837824, 42.92779984012727, 37.193761410251746, 42.4665016512717, 36.815809665187714, 6.947022090035101, 0.33846221083114225, 0.3736592624937335, 0.09464292351396815, 0.2022023192576824, 0.08014375959793407, 0.28990663888473667, 0.11801934575722103, 0.16900939957028435, 0.13285011083127993, 0.15838926057181052, 0.15412121620630065, 0.13988088275636398, 0.09933189488947393, 0.13494491697319094, 0.2176720246432289, 0.14598055141827754, 0.16775531363823723, 0.19421421321890048], [0.016379084310404236, 0.030893935791907773, 0.021332834824739445, 0.025219478486706654, 0.09208602845788964, 0.04374623283623688, 0.058428606679362644, 0.04037126312933622, 0.10998491438165789, 0.025515280356029832, 0.03630441643538014, 0.063571450676048, 0.06767646003995212, 0.0421185334843974, 0.06553670751952356, 0.0860020952419408, 0.04122316439245497, 0.0275142737964709, 0.07262777822512774, 0.04773708360810434, 0.10562105539945826, 0.03853753592158037, 0.026064184268996603, 0.027675550626290422, 0.048663180486689654, 1.9344167483429757, 37.870162379357126, 27.855482524441136, 36.01770539437571, 34.838272217781316, 33.614249537068034, 8.564202074081667, 0.7021762118224175, 0.26206605376735814, 1.72534289619615, 5.757578534464683, 5.990391306338772, 3.652669715304529, 3.030972326955488, 0.5189761519432068, 4.209078271542826, 39.746718406677246, 57.21822992447884, 59.13778297362789, 55.21901745950022, 56.489743801855276, 44.5395056663021, 47.57885617594565, 51.62323951721192, 56.02189133244177, 54.89994833546301, 56.85812104132868, 53.0971642463438, 55.76081445140224, 56.01135192378875, 55.77565277776411, 53.74419058522871, 47.464950546141594, 40.47083893129903, 42.143121842415106, 39.74438459642472, 41.688040610282656, 40.579971036603375, 42.11398255440497, 40.892956564503336, 40.52762700665382, 41.07331891213694, 41.13694760107225, 40.06914900195214, 40.11266377664382, 41.443225875977554, 39.80082358083418, 40.058852780249815, 41.357486786380896, 38.767632053744414, 42.44854504062284, 51.626177372470984, 54.39957941732099, 53.223931327942886, 50.17584962229575, 51.25676854964226, 52.09501827916792, 50.292457765148534, 49.93160363166563, 48.854473713905584, 51.621917678463845, 50.68516938917099, 52.94583920509585, 53.60651539218042, 57.80938994499945, 53.30947822140109, 54.89692418806015, 55.062228556602236, 53.12182810998733, 53.43907333189442, 43.43684504109044, 41.22926450544789, 43.02867143384872, 47.917921543121345, 50.41269017804054, 50.59853992154522, 53.12385989773659, 54.51038245231875, 53.33959810195431, 43.1335634569968, 37.860874206789084, 38.34707160149851, 37.85002493089245, 39.429449650549124, 39.61356570643764, 37.99395238199542, 38.188541166244015, 38.003111116347775, 37.48845692603819, 36.966295319218794, 37.04179310029553, 39.97273322074644, 43.80655588642244, 49.054769546754905, 47.63686803079421, 50.49053353648032, 49.77830171585084, 50.02912552125993, 50.85184266490322, 48.881177210038715, 49.72865235420966, 48.53498097388975, 49.2505624986464, 48.84984139473208, 47.98284461421352, 46.21487940511396, 44.002933271469615, 45.455873320179606, 44.27749526116156, 42.877071826688706, 42.09546112245129, 42.220996579816266, 45.12553130426715, 50.03717422485352, 51.79232505060012, 54.24493997327743, 33.64135311495873, 1.8425999461643159, 1.6817131470288, 3.4520375392129345, 10.59510434827497, 11.501168916302344, 6.054844183306541, 2.743433665844702, 0.6478110580675064, 0.7331788708125392, 27.406431936448623, 32.77873566073756, 27.063081379859682, 27.548094218777074, 31.110669297556726, 8.909850158999044, 0.09109698596500582, 0.03319129941143817, 0.011303627322758398, 0.03765907822056644, 0.03989924188523043, 0.049818479380900824, 0.03531956061300251, 0.05446495968968638, 0.05076502314618519, 0.052889806308573296, 0.03152979259950019, 0.029037944153852524, 0.03577930146768209, 0.02983851178038505, 0.01762709899565145, 0.09454025241035609, 0.05708075541582319, 0.04804012883875159, 0.027722808675119476, 0.023780550860289126, 0.017289840278305837, 0.02427095246891822, 0.04692830926468296, 0.10759351729986169, 0.06527711862638112, 0.02335149374219679, 0.05422282227945905, 0.04692875742611866, 0.025881284607514262, 0.05486808664676163, 0.04482497273373508, 0.02336558209912431, 0.05342349763058367, 0.12168876135781889, 0.05741156750328599, 0.03821440386555849, 0.045475523107715195, 0.030948705332834395, 0.04662569687371293, 0.08457917119226149, 0.039298464243690816, 0.07588361359892354, 0.007016698411110068, 0.018130307679154703, 4.4547274901020915, 48.10970583269673, 26.84000049867938, 39.23073061050908, 39.01090921894197, 39.95986784658125, 7.040305858658207, 0.7563076781169061, 0.42639329248378355, 2.2064734466614264, 6.600839091885475, 6.685504922943731, 8.647372011215456, 3.6265854633623555, 2.089701544853949, 6.717113833273611, 41.67567729949951, 57.246925984659505, 62.22939906581756, 57.14041010026009, 57.38610736785397, 47.881396432076734, 48.91037533360143, 54.173321416301114, 58.52456746562835, 55.93236323325865, 58.51957428839899, 55.164029752054525, 56.453053951263435, 56.02281701180243, 57.48554729646253, 54.60875941861061, 51.35757346307078, 43.359040906352384, 43.88041019439698, 42.293968354502034, 42.88923901896323, 42.84641850379206, 43.568303277415616, 43.66804130615727, 41.5264585710341, 41.31457997906593, 42.962610875406575, 42.369434756617395, 44.857064677822976, 44.20062072815434, 42.522011033950314, 41.13611213622555, 42.66661705509309, 40.24236086876162, 42.334631566078436, 51.33506690302203, 55.61598485515964, 53.57105324345251, 54.189269773421756, 54.94123128152663, 54.594529059625444, 51.23156732128513, 52.205178045457416, 50.69726990115259, 54.198385361702215, 51.67886264862553, 54.24884665396906, 55.66932516713297, 59.060061208663456, 53.65821615342171, 55.26083777027746, 58.0529102971477, 55.78419177762924, 52.70368383776758, 46.2067561764871, 43.92827487760975, 43.87527581184141, 48.25142891176286, 53.245543587592344, 52.59109220197124, 55.274366025001775, 56.323537288173554, 54.000439028586115, 44.68527663138605, 39.26186638493692, 39.45316430061094, 39.24320767002721, 40.00211177333709, 40.546615200658, 39.98307651089084, 38.5455866782896, 39.890057502254365, 39.01008552120578, 38.35753648511825, 39.04112323637932, 41.83005394474153, 46.15191751910795, 49.16331721890358, 49.155982386681345, 52.49155029173821, 52.6658643445661, 51.5806386547704, 51.98162255748626, 49.90156612088604, 49.35074375521753, 52.08179596931704, 51.28406040130123, 48.41640380121047, 48.54418677668418, 47.86988819799116, 44.87541744785924, 45.75450297324888, 45.18213502822384, 45.28411665270406, 43.33872302885979, 43.783649244616115, 46.63995450542819, 51.40008018862817, 52.913632623610965, 53.76260219081756, 36.23837794027021, 2.2081598206873867, 2.3970641099637557, 5.788218129065729, 12.00586126696679, 17.890779549075713, 9.02026487934974, 3.3478608583250358, 1.1706842073509771, 0.6281330784963024, 26.376815649770922, 40.334650316546046, 33.4238027757214, 26.102538031916467, 39.975898573475504, 14.476227856451466, 0.1013746300351716, 0.038667809173104264, 0.02381244310057692, 0.10989948791722137, 0.07644464276851186, 0.04636199025797748, 0.09755668530781424, 0.02243654918856919, 0.0366135482345858, 0.0285543913712665, 0.05564375833097485, 0.01700628432445228, 0.05862559086733288, 0.024249285587199756, 0.025972058365662253, 0.03130683228523741, 0.06911786979124432, 0.08464753687862428, 0.03106739150450355, 0.13236932937176, 0.10431986272094712, 0.1216890677929886, 0.12768362153081164, 0.21694799494599143, 0.1865634923019717, 0.12032879441375695, 0.1925742028341178, 0.27717526881925525, 0.17758727073669436, 0.13376650520630423, 0.1724265347565374, 0.15283216602138935, 0.22141882278505834, 0.1855431704391395, 0.20172432635820683, 0.18748877329691765, 0.1763806822559526, 0.13888346692246778, 0.17045007387716926, 0.14375356446591117, 0.08082707938287528, 0.11759033651962397, 0.12591256414570157, 0.13896523914750547, 4.649090738065781, 52.99254678910779, 39.12297133476504, 46.30687467513546, 45.650434647836995, 46.89097835171608, 11.482249363776177, 1.3802063128640576, 1.2870801744922515, 6.223507081308673, 20.092094098368, 15.890370761194538, 8.069612278092293, 5.5692699551582345, 1.1666775062199564, 5.781556963920594, 43.29132903006769, 58.240379979533536, 64.98027493876796, 60.343758829178356, 62.08049412696593, 49.059868627978915, 51.931482899573545, 57.27225272886215, 60.81099548647481, 57.595675683790645, 59.262824212351155, 57.160633840868556, 57.89892588892291, 59.53549561962005, 60.34070330281412, 58.38340528549687, 52.234489917755134, 44.85753928461383, 46.76703145427089, 44.23065039419359, 46.699511774124645, 45.913253061233036, 46.21026277542115, 46.34377633371661, 43.526031894068566, 44.500984068839784, 46.12659469727547, 45.02314567565919, 44.98757370056645, 47.78707127417288, 43.00407425049813, 43.725123559274984, 45.737648548618445, 41.562050157977694, 45.07300292291949, 54.62057751993979, 58.296842498164025, 57.76575749920261, 54.8529387289478, 56.31098962599232, 57.10050390612695, 53.843783486273985, 54.5663821312689, 52.06356087038594, 57.11107077137117, 53.79785253155617, 57.07184314727784, 56.0837039639873, 60.90520689564367, 55.44630312150525, 59.92366906135314, 59.486724868897475, 57.81802308174872, 54.15994221164335, 46.904647811766594, 44.41217768576838, 46.531140112107806, 52.463328838348396, 54.71457712111935, 55.679009499088416, 56.82987213134766, 57.87124180024671, 55.55364662601102, 47.186736829819225, 40.1616031892838, 42.59296671036751, 42.260753723882864, 43.04664373397828, 42.183683072367025, 42.02831406747141, 41.84990506018362, 40.76790355866955, 41.08414465381254, 40.43400395301081, 41.532918714707904, 45.638455729330744, 47.15035684647099, 51.817761621167584, 50.7494217349637, 53.5766230090972, 54.99103361560453, 54.3999755767084, 52.99124456221058, 51.176226600523925, 51.73652149015858, 54.451186041678156, 53.33351450581705, 50.92728945516771, 51.63739927353398, 49.793124352732015, 47.742815171518636, 49.887135721022084, 49.21721450744137, 46.90117259179392, 47.364039728718424, 45.48635798115885, 49.01346698884041, 53.97960339823077, 56.74785144867436, 54.851424694061286, 36.02435381181779, 3.191258022862096, 3.2509861598091745, 8.465112217010992, 18.194510244554092, 18.53543089282128, 12.785683370405629, 10.645406784549838, 2.6334582509533053, 0.9407253887864852, 36.60833589492306, 42.80163680353473, 37.520020238814816, 37.89379465964533, 50.5363860437947, 20.333725829278272, 0.21665573240287844, 0.16813654963287616, 0.10426432134643679, 0.22948241912789885, 0.14222189423538026, 0.25640903070809384, 0.1386045955962712, 0.1492841983394277, 0.1363693195725641, 0.16090886246773506, 0.29435574047027097, 0.10789249077319138, 0.17725129521662192, 0.20425103755006868, 0.11422526466870501, 0.14724159342867715, 0.261511467397213, 0.1403409185548944, 0.11765217513687189], [0.087232961049003, 0.05965864128102699, 0.1219913890705474, 0.03717130620873744, 0.04605553976650681, 0.031018988154227697, 0.032376051625056614, 0.03274911346154348, 0.020226274444271, 0.03058902322194509, 0.036242646766045404, 0.030527933455643155, 0.09248206527122567, 0.07086562278169779, 0.045348298886129935, 0.019294200164656487, 0.014564275643938493, 0.013451124992101424, 0.0020362075977778484, 0.03326337296335447, 0.037548171671768354, 0.03784361731020674, 0.02895580612183098, 0.00566327337911653, 0.12909922177993483, 0.06702059684621711, 13.146261957383926, 40.97943305969238, 35.025616384321644, 42.0333033223306, 33.75756117605394, 22.36530177054867, 0.020699396939767946, 0.3623507015647427, 0.4235487773774132, 4.5343550366740075, 4.207185237638412, 10.696307382275982, 4.714173155446207, 2.326726451996834, 0.37648395124462347, 12.634851567206844, 54.986424830652055, 59.06457193436162, 56.826624408844985, 53.95426096454744, 47.7039562502215, 51.539332174485736, 54.50450674180062, 58.3741916379621, 55.975352410347234, 55.627575459018836, 55.26331278585619, 58.80819013041835, 56.007547224721606, 56.22645078166839, 46.49699587975779, 41.82982252490136, 41.95015691941784, 41.025246343305035, 42.62169414950956, 46.261437939059356, 45.22181764725716, 45.379108613537205, 42.50442312609765, 42.46167321358958, 42.60778150250835, 41.48359490979103, 40.18547865652269, 40.25983895024946, 40.45782058469711, 42.35835013851043, 39.48185251605126, 41.751959554610714, 40.988391753165956, 43.15193583888393, 53.06243558083811, 56.52970098680066, 53.81255749733218, 53.0488641800419, 55.72759589841289, 52.08686759394985, 51.88818385524135, 52.459983056591405, 52.62957065336166, 52.086036051473315, 52.824351633748705, 52.34901135967624, 54.82020654985982, 57.16441892808484, 50.30424056514617, 53.9088987535046, 56.141864868902395, 52.62995112326838, 45.509715695534986, 42.481445881628225, 46.648203249900575, 48.707639786504934, 52.113488720309356, 52.36569712238928, 55.66870151027557, 54.34474860468219, 52.94792590602752, 53.6610520270563, 44.25603597394882, 36.595666639266476, 40.60121459345664, 39.430893082772535, 38.07967578211139, 38.27903024611935, 38.14315934335032, 37.15982506352086, 38.03600803498299, 36.95794067075176, 36.67553786308535, 38.025143069605676, 43.09943883649765, 45.95393196229012, 49.931454581599084, 49.31335964510518, 49.64173263119113, 49.72696181266539, 49.91258405870008, 49.774457793081964, 50.49240842942269, 50.597351443383005, 52.40352838270126, 49.30382436321628, 50.60805166921308, 49.66013246966947, 49.707032249819854, 49.91186626495854, 49.85712958920387, 49.24039963752993, 49.480578130291356, 45.29320086202314, 43.818307307458696, 46.06892016626174, 53.52520465850831, 49.3397807305859, 55.73225959654778, 20.262881940410985, 0.4177864172285603, 1.7396926423234327, 7.140638616777236, 9.695977472489881, 8.633183817709646, 5.300683206127537, 0.5910759347100413, 0.8058613706980983, 2.524675236594293, 40.80361281671832, 36.08313837359029, 31.278789927882535, 27.16745565014501, 22.93074477103449, 1.1328378704286393, 0.029022568769212213, 0.07058295932027601, 0.04645580155474525, 0.12558707636931252, 0.03833527338781184, 0.010244560563155721, 0.019899120426646644, 0.06142672624499087, 0.09668194313323307, 0.05473238183185459, 0.03202607584816795, 0.025435312268053813, 0.022765618426004247, 0.02814408617034074, 0.020608607859861468, 0.04235942217130815, 0.029843027868698684, 0.034625377701295, 0.01195112196353054, 0.06558818862803521, 0.06010051696531235, 0.04428121884683928, 0.022062993225371166, 0.036472281621348475, 0.042715450042798635, 0.034384588605814406, 0.06827967767153056, 0.04791486197181287, 0.03147385860492866, 0.08544083624597519, 0.030555273218440916, 0.1111846080710811, 0.013199960193296355, 0.04340033264710538, 0.02339926698515492, 0.03409442514361393, 0.019101086635923675, 0.040721300193258834, 0.03523106979686887, 0.010513106939352809, 0.027734849662069353, 0.008074469045705853, 0.041927712473777995, 0.0359681919367323, 0.05877275635758716, 19.364266933933383, 45.47558323029549, 33.979069186795144, 45.954155537389944, 37.57519229765862, 25.590286293337424, 0.027492582016894897, 0.46228242797716973, 1.0408104860013532, 3.2315760658633326, 6.45987646233651, 6.281097771659975, 5.501157016523424, 4.1419253330076895, 0.9582278012268005, 15.21935030337303, 57.44152261364845, 61.196478182269686, 59.557758992718114, 57.00735938164496, 48.83608956490794, 53.64801014623335, 56.13252962789228, 58.65571191233974, 59.264408849900775, 54.97177477805845, 55.97944344243696, 60.26237749284314, 57.227012111294655, 56.47851797842211, 50.69819165814308, 42.8735024698319, 42.116681145083525, 42.65267695150068, 44.288328847577496, 49.15442520572294, 46.493348075497536, 46.72188105121736, 44.2229272473243, 45.133379966981956, 43.7727411331669, 42.75955761632612, 42.75534499076105, 42.67828218398556, 43.643734378199426, 44.39969670388007, 41.28256559371948, 44.18783380139259, 43.371623869865175, 44.84022594267323, 55.77279336990849, 57.76265882676648, 54.73924882950322, 54.88540810923423, 56.20359513067431, 54.476399037145804, 53.65792982039913, 51.93086708745649, 52.36979992158952, 53.27981725815804, 53.011189814536806, 54.738130954004106, 56.124539759851274, 58.58115157773418, 52.299228637449204, 56.62613245748705, 57.37428534415461, 55.38263128649805, 48.88004364505891, 44.89573140298167, 47.309342276665475, 51.79079532623292, 53.86800019971786, 55.27008279677361, 56.73444478742538, 57.026692744224306, 54.907997039056596, 55.568583011627204, 45.472115855063166, 38.4201688920298, 41.863645122897246, 41.632154680067494, 40.08128481526529, 39.80440078243133, 39.53097235771918, 39.694554805755615, 41.48149251937866, 39.26013661969093, 39.5099288417447, 39.40769226320329, 43.46503119314871, 50.282220378998794, 51.59360601056007, 50.33741989443379, 52.44047710972448, 50.70075688823577, 50.538147188002064, 52.95985775609171, 52.27090128006474, 51.22755081422868, 53.70425693450436, 50.987803782186205, 51.00608987192954, 52.41044744368523, 52.961630667409594, 51.507549208979455, 52.46922808308756, 48.92448802148142, 51.60981324411208, 46.502063582020426, 48.292064666748054, 46.98978677872689, 56.468566925294944, 49.2355868893285, 56.124198513646284, 21.50185081266588, 0.038929612060347875, 2.472777376251836, 5.555231792311515, 12.206633667792044, 13.838623050720463, 9.584948901207218, 0.751134378294791, 0.5902262512714632, 3.048170449272279, 42.38222168337914, 42.965336922676336, 32.408873804153934, 31.548837269506148, 34.45263262717955, 2.4779960897661026, 0.07084309979672394, 0.06417177249527266, 0.03795329811832598, 0.04615301679399225, 0.0388130862566252, 0.04112700886663891, 0.034414875891900835, 0.041463620239688505, 0.09235046668759278, 0.004095949416589593, 0.054810258499797315, 0.07128656511345217, 0.023879282356750582, 0.05500788620162395, 0.029941947056701588, 0.05818229408994798, 0.06331060156827012, 0.04892251274037746, 0.027750640649408586, 0.46536672860383993, 0.1510553170115717, 0.2200549717752203, 0.09642631491465915, 0.14809771200581906, 0.17620448203336808, 0.11143693445070137, 0.11931892965109119, 0.16175944989006366, 0.14408382497006847, 0.2156973257660866, 0.09976822792762712, 0.20978654374278363, 0.1366413573944761, 0.18883500428449726, 0.10878468443068767, 0.12864306238630127, 0.13784177120654814, 0.15111211477027786, 0.14176967253367748, 0.09712825063616039, 0.15016493898245598, 0.10466346081586615, 0.1448439220867811, 0.24272978005390017, 0.16421790264787214, 20.338744501913748, 56.11743634746921, 45.35983800888062, 52.58617354977516, 45.988405673734604, 31.159451815389822, 0.11909124065911579, 1.1735210615781047, 2.3583405104375657, 13.517220116430714, 13.24034785070727, 17.82763723404177, 10.91963243099951, 6.381130958757093, 1.160013767019395, 15.371218592889848, 58.36040842917658, 63.46449459752729, 61.78131141970235, 59.36753972884148, 51.14621262396536, 56.13892701364333, 57.776755825165786, 62.55786618878765, 60.357883284168864, 57.99491020940966, 59.17453165977233, 63.25319651634463, 60.04548611179475, 61.53879127194805, 51.46975717236919, 45.50206707369897, 45.7538636269108, 44.52185892289685, 47.35229615242251, 53.422148304600874, 49.23916409092565, 51.37493779582363, 47.489955655990116, 47.34570657053302, 47.69258529909196, 45.33042807732859, 45.524891345731675, 44.45311546325684, 44.95498272680467, 48.479757924233716, 41.66266287526777, 45.634482368346184, 45.181162280421105, 46.6533140982351, 57.89993786042737, 61.57579491215368, 57.597123038384225, 57.6887103819078, 59.241109971077215, 56.77711233015984, 55.27524855829055, 54.88037570830315, 56.04648851579236, 56.39555200453728, 56.82650281536964, 56.11403173015964, 60.01444839662122, 61.241036307427194, 52.221083256506155, 58.52110793513637, 59.68158429668796, 57.22071278479792, 50.272179111357666, 48.04199395641204, 51.6043415377217, 53.38227348942911, 57.31368080262215, 55.089685147808446, 58.69768127318352, 58.47998188387964, 57.67805330214962, 59.15341754113475, 47.49201490033058, 39.36202410728701, 44.25552998819659, 44.04037621713454, 42.30120904984013, 42.804915904998786, 40.95469467101559, 42.221353515501946, 43.01378211667461, 39.983637409825484, 41.51564067409885, 41.792442337159194, 46.928052594584805, 51.77503916525072, 55.204692963630926, 52.85633856250394, 52.960042107489805, 52.44641950053554, 53.106142551668235, 53.156344967503706, 53.55191599938178, 54.276773929595954, 57.32714629942372, 52.21994576915618, 53.26437880915981, 52.38967457125264, 53.106962327034246, 54.45932888215589, 54.34744327299057, 52.30096624743555, 52.228520070352864, 48.89810223733225, 50.81234831963816, 49.1403321296938, 59.22833873379616, 51.966211565079234, 56.75409586198869, 24.227082229429676, 0.7621942977270773, 4.023513880468184, 17.418994903564453, 16.757314589715776, 17.12584872399607, 14.626093775995317, 3.280392904435435, 2.899229963940959, 4.046486712271168, 53.6480729041561, 47.43563082910354, 41.56553322269071, 38.45160668896091, 41.623717661826845, 2.3962168780065354, 0.2367243248849146, 0.14128814030799175, 0.13676627569140928, 0.2849278028213209, 0.13807133711393804, 0.10042826630054943, 0.16186323948204517, 0.19498361064301384, 0.30399346363640606, 0.15095944876872724, 0.14317300771513294, 0.17870652519406813, 0.1049679194787337, 0.18902615854336371, 0.11593891142476952, 0.13372839999295053, 0.15886543018202628, 0.1475234678195369, 0.17490516627027144], [0.013543257598705111, 0.019789219368249178, 0.03473088716066653, 0.030034863945817756, 0.06098378186805114, 0.011668591609885617, 0.03302601211133503, 0.03145558549271476, 0.014876973582431676, 0.060546678911534056, 0.03041470182999488, 0.0070786983856270394, 0.03563119751972056, 0.07155818158700582, 0.0411943020299077, 0.053012441663492116, 0.008099379352173738, 0.04954204804474308, 0.04505743062303913, 0.0758791856107212, 0.04998213108328562, 0.015500255056747026, 0.1142646186053753, 0.02610404765413654, 0.04118632322417633, 0.06025391841127027, 0.20022369801036774, 28.866948043146444, 33.913836248459354, 28.527996424705755, 40.247063790598226, 30.52023687670308, 2.395018593918893, 0.7613634906949536, 0.7493226109973846, 1.9992194517004875, 2.814635225842076, 5.358617103868916, 2.7089685345849683, 3.6726125161493983, 0.24177200160920623, 1.839952836594274, 39.84615833528581, 61.35403586972145, 57.95470591514342, 57.13091011970275, 52.39297720693773, 53.670422569397964, 54.948362150499904, 54.56906895483694, 56.239241630800315, 57.746259397076024, 57.450897078360285, 55.053756237030036, 53.4967557076485, 49.89645527255151, 41.80477426898095, 40.82808840659357, 41.60091692401517, 44.0656441257846, 50.20229816436768, 51.39711095440773, 47.923773719418435, 44.5813024428583, 45.18482577416205, 43.58717380031463, 42.182004297933275, 40.394435082712484, 40.36164014570175, 40.5250656989313, 41.38399808637558, 41.37186227306243, 40.85208938967797, 41.00299081494732, 40.5419397354126, 40.56274398680657, 52.90663903759372, 55.63254117965699, 54.714259409135394, 53.47950512363065, 53.89522537108391, 55.25795875057098, 56.02244046426589, 55.70726625380978, 56.94404840469361, 56.033901629909394, 53.47100142509707, 53.767924847141394, 54.840677399789136, 55.299112258418916, 49.98872510848507, 57.20831417268323, 52.17894915611514, 47.89985902847783, 46.56659441609537, 48.25708889192151, 51.714638586967226, 55.46335366464431, 53.23283510823404, 53.764265275770626, 51.62595379737116, 54.21885228926136, 52.703868189165675, 51.75702764141945, 44.55326534086659, 36.956238362096975, 40.714959406083636, 38.5205227328885, 38.18481883695049, 37.43807015880462, 39.99279222180767, 37.461702439092825, 37.51375621364963, 36.87555913002261, 38.32537697207543, 35.66194641974665, 42.07205241726291, 47.609301613223174, 51.00175173051896, 51.17823093168197, 51.594053160759714, 49.929061935793975, 49.74642461346042, 50.01785262938469, 51.68553067791847, 48.047532343095355, 49.67402550481981, 50.37767910188245, 51.73098702584544, 49.892607427412464, 50.948258446108916, 50.543222735005045, 51.10346663382746, 49.63621385635869, 50.92552438859017, 47.08959148776147, 48.74279206798923, 48.14521112749654, 52.05770084934851, 52.569483864691954, 48.35223774756155, 5.109656914587944, 0.15847215128521766, 1.5459280461072924, 6.926469850924708, 9.708361375716425, 20.864344066189183, 10.970891925596423, 1.5343526414325162, 0.25363545534351184, 7.6634876189693335, 42.15837594001524, 25.013633158899125, 20.48016359729152, 36.468766197081536, 3.9626857638359074, 0.11239917152711462, 0.09441296690173688, 0.11079998596781686, 0.05262562854876442, 0.011375612774563414, 0.02028338055336668, 0.024703516354483944, 0.01138729370018888, 0.03604527187323378, 0.04966272987545498, 0.057662434485410495, 0.01668411179355556, 0.06975976720211968, 0.04705436903262331, 0.07345831712647792, 0.03896509342256092, 0.05562020495774285, 0.05659495608039922, 0.02095705720656101, 0.03174678508883282, 0.05759494980016063, 0.012238044873811306, 0.032560115740183866, 0.05715362186874113, 0.015311972669986709, 0.06307788320907182, 0.019598695216700435, 0.020337763219891537, 0.06437254498802847, 0.08476016712525199, 0.008644725744342132, 0.03520309609631377, 0.09855919562640691, 0.02353930211205396, 0.055597601533536954, 0.02904907732661213, 0.045939048436740716, 0.036293292838719585, 0.03264433178570002, 0.023687892525847402, 0.05266239693869026, 0.031092957773756598, 0.08674192933305618, 0.059709038375125784, 0.024690948682086124, 0.04894301325323121, 0.9023077954207698, 37.731961588705744, 36.53565045325987, 37.1496465129237, 46.766866714723655, 34.66361691874843, 2.413955061666427, 0.7018815437632223, 0.2738442572374498, 2.9573479679323014, 4.914318467340162, 6.32210026825628, 4.82048164452276, 4.085908983984302, 0.9555605282225917, 2.6808120454511335, 42.47774708655573, 62.64978693377588, 59.72396158402967, 58.51681686216786, 55.02779799122965, 57.795889146866344, 58.56676432394213, 57.46663754986179, 56.34324719828945, 58.38233447843983, 58.508297474153586, 55.9372308946425, 55.65600479802778, 51.6791646711288, 45.014987145700765, 42.724801494229226, 44.16450746597783, 46.42804845686882, 51.86048015471428, 53.12657025552566, 50.55389942661409, 47.07749882052022, 47.66553663438367, 44.968883606695364, 43.43317762497933, 41.478009454665646, 42.45988853516118, 43.184624871900006, 42.78587672018236, 42.56950701436689, 40.78099250793457, 42.489129804795795, 44.5206900565855, 43.51850094333772, 55.212957397584, 56.95202258325393, 56.165253962239916, 55.46039227516421, 58.35356389322589, 56.64444208145142, 57.93927531088553, 54.958913326263435, 57.40892379514633, 55.743371671245946, 54.38735731186406, 56.544405952576675, 55.95861565682196, 55.30594894962927, 52.10390636997839, 59.28558572646111, 54.381352163130245, 49.706851820791925, 48.07196870926888, 50.12724361112041, 54.6081945973058, 56.113109973169145, 54.75369099647769, 54.93336300696097, 55.441078524435724, 55.41447308755691, 53.57152000550301, 54.89975613932456, 46.02042398145122, 39.20361526550786, 43.32110374204574, 40.72212557638846, 39.45915768223424, 39.215347074693256, 39.595252160103094, 39.41298746293591, 39.265875047253026, 38.380584332250784, 39.86537010438981, 37.269192511035556, 44.74371994695356, 50.42328057750579, 52.27703194464407, 51.94070831421883, 53.880041876146876, 52.09034673629269, 51.209456920623786, 50.59055005350421, 51.86617151383431, 50.300404487117646, 52.369948971656065, 51.81176431717412, 52.1972313234883, 51.23764307268205, 52.68419750275151, 53.01667721040788, 52.89549950630435, 52.07207241365987, 52.17792933987033, 49.92661829917662, 50.11056177077755, 50.46551273715112, 53.11897262450188, 52.46450947177026, 50.27987872400592, 7.328158309382777, 0.48964469843814457, 3.8653072859010393, 7.208982975252214, 10.328732267502817, 9.100577369812997, 7.1944711862071875, 0.8893082026512393, 0.39266314597860463, 8.640113665211587, 47.260030238859116, 36.14693572444301, 22.038021164555705, 41.04028863291587, 8.451096607792763, 0.0724140779986497, 0.05219351665507402, 0.019301029838501446, 0.09900430037129311, 0.051941508201942335, 0.024347595735302856, 0.056699806704155864, 0.10327099642205624, 0.04503102357228918, 0.04531724551211923, 0.02890145026838347, 0.018975678042718963, 0.020797241689457048, 0.01135079918669597, 0.05450396505635112, 0.04499836141363748, 0.028707532347330166, 0.045888107420215686, 0.039303482119594856, 0.017860501088322173, 0.09250677926766296, 0.057745804003770315, 0.17001374083901608, 0.12160962447524072, 0.12310569459993033, 0.12631900443304933, 0.08604133426542245, 0.11887351847103528, 0.1646773715413386, 0.13951104615003834, 0.1767897578857599, 0.19779792656340908, 0.17069178993903822, 0.257679587530513, 0.1656326218958824, 0.11449960841526909, 0.2605052262304291, 0.1045656237270563, 0.12046732609310459, 0.1068139309063554, 0.18173859394606084, 0.11214857650620323, 0.2271039153058683, 0.12672829456747542, 0.15568388235424796, 0.1819733998948528, 0.9752598969686417, 41.58803978273946, 45.81153423555436, 39.51898951684275, 50.861601521891934, 43.18103198082217, 3.157467539272001, 2.059636087186875, 4.148620818891834, 7.273690315984911, 12.421223598141825, 18.037729186396447, 10.030290888201806, 9.058452094754866, 1.316717113218, 2.513418769644153, 42.548157553518976, 64.01886670820176, 62.13573286610266, 62.00348623337285, 57.18855719412527, 60.0800931838251, 59.70060386965352, 57.59101590802593, 58.269025048901966, 60.8962482021701, 60.94453257899131, 58.79796058900895, 57.54515555597121, 55.29251090941891, 46.35027570109214, 44.18456254466888, 46.633651256561286, 49.769091990686235, 56.23259713572841, 56.70688229222452, 53.94107787839828, 48.829209727625695, 50.2124963268157, 47.141704097870864, 44.382979562205655, 42.74619410114904, 43.025651208816036, 45.332306892641135, 45.51068844333772, 45.903133346188454, 43.99866573272213, 43.596187406970614, 45.542451796993134, 46.23987274785196, 58.034412399415054, 59.527925445187485, 57.37871762244933, 57.505061088069795, 58.87257583679692, 57.91185009864069, 60.94856477552845, 58.89990298978744, 59.03523260547269, 59.08656466391779, 56.67898247318884, 56.63333000675325, 57.28179977786157, 56.99563933957008, 53.62358162480017, 60.59906198132423, 56.29695538551577, 50.851042501388065, 49.488815107653224, 52.02468625960812, 57.06752854008829, 58.9489326169414, 56.084602186756754, 57.975792577189786, 55.35754380687591, 57.484429420963416, 55.8971481938516, 57.320219393699404, 48.2578694435858, 42.22948458886916, 44.900599064365515, 42.72205975747878, 42.839169963713616, 40.7666366331039, 42.73020652032668, 40.82815116451633, 39.88951229280041, 39.970693588256836, 42.31965203439036, 40.05927639622843, 47.831335221567464, 53.49855607555759, 55.32870261899887, 52.702209026582786, 55.49565438301333, 52.60079222340738, 52.80517516597625, 54.12406821404734, 53.28388475602674, 51.681137623325476, 54.85353492921399, 53.60850795622795, 55.16084478747461, 53.868616011834916, 53.588037106298636, 54.95817592067104, 53.49124085518622, 53.29252181514617, 55.43350835000315, 51.66112961307649, 53.17129704260057, 51.84691659865841, 56.880129460365545, 54.59968305403187, 50.42187244661393, 7.316536816858477, 1.0771398462595478, 5.300049253048436, 17.25075464094839, 20.05209965090598, 33.911427913173554, 23.903702420573083, 2.540603981864068, 0.8559831327969029, 11.980100120267561, 54.66701838278002, 33.32748897614018, 27.96724065657585, 52.4169115097292, 10.627349172869037, 0.29148242045794764, 0.16486898545295964, 0.21743637599772025, 0.14756973953016345, 0.13395661758559366, 0.09175002995517947, 0.1741177351364205, 0.2771475670799133, 0.12880669876692757, 0.18893401348783126, 0.16726095710069905, 0.09585005591713613, 0.12748913478947457, 0.12743724765436304, 0.1492118796393756, 0.1645746238289341, 0.15077437724797957, 0.21133206484298553, 0.13743764450473173, 0.14143826289763375], [0.01309705351764757, 0.015419684632140544, 0.032297799574030985, 0.07789528387929164, 0.08805912558830555, 0.0392095290965611, 0.010891208676771532, 0.04313559564311178, 0.05126176221716789, 0.026351105264057557, 0.02624426089647797, 0.04786511222201009, 0.03182346474439387, 0.0685949075306135, 0.0881169269221925, 0.05076292789571228, 0.046856718348158945, 0.05225312595646228, 0.04463320177408957, 0.04789720747559782, 0.02310576337960459, 0.09031389088880631, 0.04635642462920758, 0.1456593613951437, 0.03570350472845378, 0.034326063318839, 0.08922372478991748, 4.995658128492294, 40.97549892240956, 26.426947462943296, 35.237785231682565, 37.83237818748721, 8.24628024331985, 0.09275191974255348, 0.24303748692956664, 1.4701810719505435, 5.031284036174898, 2.8832516987477583, 2.998917001870371, 2.71465229411279, 0.42140443599031824, 0.45612452131125236, 20.761907446768976, 59.78960244886337, 58.973043426390625, 57.817905410643554, 55.85778720917241, 55.827231945530066, 59.858906807438025, 56.96550376953618, 58.41589035526399, 57.426633296474336, 56.19478156489711, 53.939148072273504, 47.74253276086623, 42.60645181901994, 41.526588009249785, 43.718686949822214, 46.179891863176906, 50.99320096354331, 51.03264431799612, 50.370948314666755, 49.15785335725354, 44.5817417483176, 41.954036143518266, 43.5852518389302, 41.910646884672104, 42.18213373614896, 43.25221515470936, 41.078551353946814, 41.46690522470782, 40.47010937044698, 40.28998236502371, 41.156422168977805, 41.48832136584867, 39.460059827373875, 45.89815978080996, 54.277432887784904, 54.86514906729422, 55.04123995381018, 52.05422170700566, 53.53419080857308, 52.13439887569797, 53.89782590250815, 53.65723948324881, 56.42576602197463, 54.91590845969416, 55.08856727230934, 55.982267548961026, 51.58480421189339, 49.777097548207934, 54.52677011489869, 53.894185942988244, 48.86638595211891, 51.044246688965835, 52.44520748815229, 53.13449344327373, 55.34982458237679, 58.58934148665398, 54.861395359039314, 55.714793282170454, 53.412463972645426, 52.854495048522956, 51.05832407551428, 40.72491830395114, 37.72899627685547, 40.17521381378174, 37.97248132767216, 38.16750941738006, 38.93786291922293, 37.461361192887836, 38.613906521951, 37.61043871602705, 38.33140565503029, 37.64223737101401, 36.36621190655616, 41.84176614207607, 47.85110004486577, 50.13130326424876, 52.26004415942777, 50.71253184349307, 49.890536415961485, 51.06710626233009, 49.08781159308649, 48.032807765468476, 46.864282700323294, 47.574627860899895, 48.33443410934941, 51.3048646526952, 49.295685445108724, 50.00011959383565, 49.418126152407744, 49.889575435269265, 49.46741465599307, 46.11265067131289, 48.39854132744574, 47.72308957192206, 50.90699511189615, 51.96098304563954, 56.24086941442182, 26.065836414214104, 0.49158130742369166, 0.2679738480477564, 2.259327384733385, 4.463532230546398, 5.784767914202906, 6.745510812728637, 3.3681934447057786, 0.19064669497311118, 0.06686944003787733, 14.785373383952727, 42.2485629973873, 21.48509248610466, 30.16445044548281, 29.341554833996682, 0.4651829900760805, 0.05797697103492195, 0.044257190499094226, 0.052304507473543774, 0.0571806954159852, 0.06334674176609804, 0.027285751683877844, 0.04221273548600655, 0.03169027652831809, 0.017497561188534867, 0.012033046448543187, 0.013204039611493149, 0.012143911820115342, 0.032456352961279696, 0.0498153958770056, 0.0908229946188869, 0.000324039152004726, 0.053242593628144076, 0.045686990187893954, 0.032970083862422936, 0.045204565469776435, 0.030079743291641918, 0.02226654278685249, 0.10567271270819249, 0.029459621930014224, 0.06722195539623499, 0.049658175482745134, 0.019344587682656223, 0.04550366151717402, 0.05899634677916766, 0.05762579633043178, 0.07614208400369653, 0.03876914345328847, 0.07372247190364907, 0.043164017505102584, 0.03710037795826793, 0.0445903966113204, 0.0464911756646489, 0.009746228986900422, 0.03624043660238385, 0.04246165277436376, 0.043091668161533536, 0.10333259755204763, 0.041713315107288866, 0.11348154651181352, 0.01861936480347668, 0.05615696063145034, 0.11052254722603869, 9.433999426903265, 45.92214899678385, 27.071853760750066, 45.23980171449723, 45.255181327942886, 9.658347233649224, 0.14281740502244042, 0.09150449111456833, 1.9574278232551392, 1.9688858019728817, 4.805900723703446, 5.533904394795818, 4.60995283819014, 1.70934894152226, 0.5904560776487474, 24.888711552466116, 59.43483975625808, 61.98709464842274, 59.191974439928615, 58.468689380153535, 56.97382703904183, 60.38905435992826, 56.31830484636369, 59.23147270756384, 59.008219242095954, 59.37562373376662, 57.45630602682791, 49.72795024994881, 45.62999517686906, 44.327089709620324, 44.44858120333764, 48.26336860656739, 52.31757356274513, 52.22122053946219, 51.98428192446309, 51.7258212643285, 46.400733070988814, 46.17302379300518, 44.3519300799216, 43.53081326330862, 44.644570273737756, 44.49686950252902, 41.84652789946526, 41.98000615642917, 42.39735026513377, 43.69425450601886, 42.206734841869725, 43.94925955803164, 42.30374682334162, 49.95709511541551, 55.74047696205878, 55.87566537241782, 56.36205104089553, 53.294694808221635, 52.87437362055625, 55.05570957737585, 55.186097006643976, 55.908087684262185, 55.94922550262944, 57.45512539340604, 58.10523079287622, 57.13369108015492, 53.03091933650356, 51.554884372218964, 54.88033648460142, 55.194871348719445, 50.97955503771382, 52.17638392602244, 54.01279449462891, 55.962459579590835, 56.47753738587903, 57.319984051489065, 57.9643000325849, 55.257076217282204, 54.83098914546352, 53.228606793188284, 53.208653696121715, 42.958578678869436, 40.17948135252922, 40.782996839092625, 39.948014443920506, 39.11469905607162, 40.47925633768882, 39.52554771977086, 40.68882465362549, 39.22562368454472, 40.21095837316206, 38.03502744243991, 39.06363371879824, 43.368717393567486, 50.4854932908089, 50.92733652360978, 53.02061134769071, 52.38867044448853, 50.953275157559304, 51.76943017590431, 52.03247216440017, 49.5177072863425, 49.83360713528049, 50.60874592873358, 49.15265621677522, 53.36933751260081, 51.66455384223692, 51.52357209113337, 51.42788587077972, 51.49007112749162, 51.89471852394843, 49.55081601296702, 50.035001231778054, 48.44611183289559, 53.1027183225078, 54.32576825541835, 55.83564150717951, 28.07464691900438, 0.4899112051052432, 1.94429254099246, 6.646902426596611, 9.154370715541225, 7.481301369205599, 6.310593014763248, 1.4018946910096755, 0.19012543342767224, 0.04431478115880201, 16.301822489307774, 51.810983765509825, 21.62242251057779, 27.351020613024314, 39.83616805845692, 0.8336190651020696, 0.03691300434330779, 0.08670822912526709, 0.017833222612558354, 0.061147801292639595, 0.02738666270048388, 0.050571471032115727, 0.05846919401759102, 0.026124335577591296, 0.06550030302136176, 0.022480595413775697, 0.02722509858769275, 0.02966094792129532, 0.027938267073383736, 0.04389465471068698, 0.047025667548540144, 0.029417416231045802, 0.016107408465036464, 0.034859409901283445, 0.011759631583587298, 0.043069539711840694, 0.06115532810649565, 0.14317498422197758, 0.2057866607942889, 0.17791377741002268, 0.16467380157161146, 0.1473592798556051, 0.19075475933571018, 0.1823500087184291, 0.11098246045050122, 0.30346363722797365, 0.1980975282288367, 0.09208140894770624, 0.14133678689118356, 0.15054389203508056, 0.20553045034889253, 0.29376229812060634, 0.1199930333983033, 0.2116447972554353, 0.10987269782250929, 0.11321952911995112, 0.16473850535769619, 0.20745877026309892, 0.11092264430537341, 0.30558422988941597, 0.22247931829863982, 0.15758825435994134, 0.3265167244019047, 10.06764263876023, 56.28101095076531, 37.351526983322636, 44.88255616157286, 51.71550543077531, 13.488413249292682, 0.41866708126279617, 0.7125494100393788, 3.2025971047339903, 13.261662990816179, 9.30921216164866, 9.037277179379618, 9.13007261291627, 2.429037065275254, 0.7281181552717764, 24.744370291309973, 60.71646636532199, 63.63933424795828, 61.99839499688918, 60.187695564762244, 59.45790329287129, 61.48742783454157, 57.6520715221282, 62.70361361965057, 62.35036103956161, 61.04135236432476, 59.75330483528876, 53.24191147281278, 46.525993962441724, 45.962388592381636, 47.65689173052388, 50.760996649342204, 55.62502591840683, 55.57197978419643, 54.66743807638846, 54.90501996009581, 49.0497685247852, 48.05324723643642, 47.81521035778908, 45.931174370550345, 47.29600229570943, 47.920439704771965, 45.2156634484568, 45.24891338040752, 43.91730400823778, 44.630469352968284, 44.62403666588568, 46.29566454118299, 43.08252165394445, 50.20371021762971, 57.25335474937194, 58.24397287061138, 57.89772956602035, 56.78463151378017, 57.03532980334375, 55.978078457616995, 57.486108195397165, 57.52770885344475, 58.984845838239124, 59.36104036146595, 59.06292453888924, 59.91352188971735, 53.25799711288945, 53.21055996802546, 57.245427639253684, 58.19804583826373, 53.401897107401204, 56.11433375266291, 55.706713199615486, 58.14008497422742, 57.95715739650112, 60.38335123369771, 59.45240020751954, 57.11671113967896, 57.45304653721472, 55.77257763954901, 56.26700808925014, 44.01702634749874, 41.384209894364886, 43.19185380012759, 42.64185120982509, 41.04971016606977, 42.84643027090257, 40.81673314494472, 41.80182464661137, 41.71858410681448, 43.50076790778868, 40.95460053413145, 39.65611165569675, 45.51977657502698, 52.080187797546394, 54.370142029177764, 54.707822799682624, 52.92643131748323, 53.26524957533806, 53.60377365542997, 53.46936579673521, 52.31894639230544, 49.93007390729843, 52.0292793550799, 51.43653469700968, 55.77595087789721, 52.68702945401592, 53.965588769605084, 52.4184843801683, 54.63973437586139, 53.24009933779317, 50.12471760472944, 52.6068248287324, 51.78251912516933, 54.85697092548494, 56.09183111498433, 57.326012734443914, 28.374867093178537, 0.7074980101277752, 1.5636353411020771, 7.813927675447157, 14.914532130764378, 14.545391009699914, 17.221077988224646, 8.686386846726942, 0.9514989751961924, 0.2364692022843707, 23.420589970004176, 54.20044068367251, 30.276845962770526, 39.296987287459835, 42.99294648631927, 1.1242551116212722, 0.19515916735174196, 0.11375879373161063, 0.17973011059145774, 0.14447043890193587, 0.15811421968523534, 0.09658042116150742, 0.33677773670323435, 0.09870970126001105, 0.1082483462748989, 0.08612790986174539, 0.07308446621942906, 0.08650619641787584, 0.17219378192338253, 0.11401603073482552, 0.12049253804669266, 0.05810938933263383, 0.15837162522779358, 0.11950914162181078, 0.2651574330464486, 0.1384472258148655], [0.03958401968702674, 0.04029439386701392, 0.03448986440836903, 0.027608058280161316, 0.05849992563467353, 0.052280528921513796, 0.026613860015547084, 0.06451653887427623, 0.08502216153447667, 0.032329756931792346, 0.1458936004388717, 0.03475670049327516, 0.032263452021945874, 0.03380410846382861, 0.018521433868896098, 0.020992356622892044, 0.02516333764839557, 0.02384826728713609, 0.039818270222073605, 0.014280195877466713, 0.024542999866929267, 0.03664969992373259, 0.06992374066143267, 0.04837001395982601, 0.015897280123505383, 0.04499265405860159, 0.02795536807107349, 0.05349592741338476, 22.564522873970773, 35.65716505050659, 23.104854860613425, 41.69774455408896, 17.918218489616148, 0.681112532413775, 0.28978090853460375, 1.0083605337046808, 1.9396118050621403, 3.3638915852192914, 4.353697040388662, 3.1075289028306163, 2.394701127083071, 0.05245816938939595, 10.420785392484358, 54.301002410150346, 60.45760562342983, 60.476491835809526, 56.01246195454752, 60.202314238394464, 58.567129104368156, 61.067785216916, 55.92071771621705, 58.353748244623986, 52.82053124520087, 45.0530380587424, 43.10050572118452, 43.059379669927786, 44.48192134980233, 51.39735021898824, 53.35597399742373, 54.879367659168864, 53.41398585227228, 47.707160826652284, 46.064758531508915, 42.92330872627997, 42.74597052604922, 44.73534568663567, 44.56369884552495, 43.23564314073132, 42.65380659411031, 41.46724254854264, 40.259540850116366, 40.01878576893961, 40.37422703158471, 41.372697737909135, 39.73890112292382, 40.92634377941009, 40.727354095828154, 46.9323750465147, 54.10749227769914, 54.32720384290142, 53.038862136102495, 52.413197025176025, 52.334063206949544, 53.87273057814568, 51.937723390517704, 55.105249112652196, 54.14340942136703, 55.585625710025916, 52.94983610030144, 52.04672213523619, 52.25223864278486, 56.85561856915874, 53.06840935061055, 53.99335522805491, 52.29479243678432, 57.291480187446844, 51.52360347009475, 70.06230954200991, 58.610067290644494, 49.807672423701135, 56.88879789844636, 52.728634034433675, 53.47724976078157, 45.399697134571696, 40.55600143248036, 37.03047313997823, 38.65268699584469, 38.86339672150151, 38.10710099435622, 38.65793512713525, 38.252044339333814, 39.021542764479115, 38.102586346287886, 38.44195765833701, 39.29487312993696, 37.8915314520559, 38.563947293066214, 47.61271407527309, 50.63004439876926, 51.20230251742948, 50.36271133730489, 51.956158530327585, 52.36875264875351, 51.18631493660712, 48.39845111293178, 45.688160004154334, 42.366241947297134, 43.06322751506683, 42.875055728420136, 45.35425255375524, 44.29089015530002, 47.0332819415677, 45.63010500323388, 44.94603580044162, 43.62808804358206, 46.31828484996673, 50.29198315835769, 50.060065177179155, 53.01770487139302, 47.46554282403762, 2.864713106424578, 0.38806116388690093, 0.308190614225403, 6.850201814405381, 2.24451823099967, 4.078881812672462, 3.7398328704218713, 1.4148348353562819, 0.1455632173606465, 0.22316954819665802, 24.95945542089401, 39.92478224538988, 24.17354383776265, 39.070337049422726, 13.208588419422028, 0.05589167587459088, 0.07102323771123925, 0.02406118227349174, 0.014498366226982928, 0.04220995075640179, 0.044882938776525765, 0.01294229801128348, 0.01484018316747801, 0.044360351898977836, 0.055423063721748135, 0.10604374441168002, 0.038258419447248025, 0.03431279084555084, 0.03218546427125412, 0.039980110126517476, 0.03347185996150778, 0.04514228635197205, 0.050774798428099004, 0.015582227422254942, 0.036310882217461066, 0.10818268487890882, 0.007946600352654294, 0.03456438178076379, 0.052135493155689015, 0.04443575793336477, 0.03976868135073493, 0.07145778576452887, 0.03372971366550173, 0.03306631216659181, 0.07770017660673588, 0.030461500226069364, 0.08190789154820866, 0.05511863953283718, 0.031240014096481666, 0.023752573329294403, 0.06493713646646469, 0.022405208531586875, 0.06435844897022171, 0.044070977507339376, 0.005665495512901896, 0.029008344431678136, 0.04136983575599809, 0.06438872476498927, 0.03042644978831372, 0.035732799930678266, 0.04168705744368415, 0.014586361001185594, 0.011795603242071887, 0.15134399426319908, 31.190879806395504, 35.50165091791461, 27.041578946575044, 53.0380815844382, 21.170787080641716, 1.0134842523163365, 0.15219815165525483, 0.7689942167170587, 1.9091484719707121, 5.154546480025015, 4.926233157034844, 6.120595364801346, 2.781912117235122, 0.6317078898991308, 12.643144438343665, 55.88720106309461, 61.76912853794714, 61.80189601836666, 59.422421532292525, 61.48611384053385, 58.68077978011101, 62.65392503430767, 58.731009652537686, 59.53333831602528, 55.784893881890085, 48.695766771993334, 43.734996164998705, 45.4735710543971, 46.52742170518445, 52.073166754937944, 54.8881184670233, 56.99058732678814, 54.90700075703283, 51.2452289365953, 48.287789283260224, 47.196189741934504, 45.84052839586812, 45.071786988166075, 46.70994920115317, 44.209728471694454, 44.76445359568442, 41.79355629028813, 42.66147090542702, 42.30859879524478, 42.9307573072372, 42.120889848278416, 41.77145373436713, 42.924940432271654, 42.95700973080051, 50.19305313787153, 57.52569667754635, 55.78525473994594, 55.0003884684655, 54.32801969589726, 53.349051014069595, 55.35593563510526, 53.62074575116558, 55.66008406300699, 54.77997872137255, 56.51347021902762, 53.22358615936772, 53.7678817010695, 52.78264899407664, 58.66192886906286, 56.351966627182506, 54.959654654226, 56.124214203126975, 57.394462016321, 52.955268582990094, 62.091719950399096, 59.019150887766195, 53.64085966540922, 57.10807408055952, 54.300076730789684, 54.60018119504375, 48.09508323669434, 42.21720364785964, 39.915035155511674, 40.55038852076377, 39.89724328441005, 40.718513073459754, 39.43291310341128, 40.876376705784956, 40.92047199126213, 38.985566785258634, 41.79426623928932, 40.70397676960115, 38.97717683546005, 40.93170565943564, 49.13514283395583, 51.75434474022158, 52.8128041759614, 51.22916683073967, 51.71982396033503, 53.98390623830981, 51.8908118432568, 48.82239264826621, 48.63076917586788, 45.4220821011451, 45.683111913742565, 46.05195591526647, 46.790581364785474, 46.47437164860387, 48.0605036212552, 47.555282731210035, 47.22580363673549, 46.29602147686867, 48.35555607272733, 51.24822954977713, 51.07803006325999, 53.245363158564416, 48.75252739075692, 4.6878746440333705, 1.6681799893417668, 4.345264434814453, 10.660629503188595, 7.411776377308754, 5.90895309563606, 3.52352763856611, 0.22231427231623282, 0.19055159281819098, 0.5617867386148823, 25.86819406478636, 50.1295970332238, 23.198723062392204, 42.35840112932267, 18.197255903674712, 0.05665744587238278, 0.08571486589649031, 0.023975660048064687, 0.039806476298479304, 0.015345329095819786, 0.04081174453359939, 0.0045534786711927625, 0.019357078746261618, 0.011670561413460923, 0.05778590487616678, 0.04676859525422897, 0.07035097257504541, 0.006862698937766255, 0.023327593714179053, 0.03432024871149371, 0.027633854375791647, 0.04273124294535768, 0.03236182154186311, 0.047562476848402334, 0.028027573773156733, 0.041846530136441996, 0.0988581690997366, 0.1477669458836317, 0.1549977433657454, 0.12007959367286776, 0.12376675953067119, 0.16295385757280936, 0.13235200046291276, 0.22066853159377653, 0.15770561902994112, 0.07588460951322511, 0.35827949583049745, 0.15255321808640035, 0.11669194521082026, 0.1293860910640609, 0.10579887972844225, 0.06575172541723137, 0.11715888346154844, 0.15568775875914484, 0.08986759870763748, 0.14501399360597134, 0.11913089337007654, 0.11483427392499101, 0.11673707545043961, 0.15353998529814905, 0.14801149647082054, 0.14031454980854066, 0.1151179945877483, 0.19744359557667088, 35.08499714636034, 49.30673476188414, 32.21444975945258, 52.44158714048324, 29.828093474911107, 1.5656822054616868, 0.7499583414004696, 5.020505362941373, 5.877901161870649, 13.29066695705537, 12.22464813340095, 9.627933175333085, 6.38242926328413, 0.6713723679704051, 13.071788895514704, 56.50166780717912, 62.1415497410682, 64.72179466678251, 61.04748302890409, 64.25446779497209, 61.55504557394213, 65.94894347652313, 60.98309340015535, 61.40989042097523, 55.652537422795454, 49.84395827016523, 45.521141559846946, 47.888613593193796, 48.9358550502408, 55.82103852302798, 58.913537148506414, 60.38385721944994, 58.346531083506925, 52.252583811360026, 49.38598625121578, 48.42158132983793, 47.68745483890657, 47.12049976471932, 48.433673997079175, 46.967558706960375, 47.2276432283463, 44.54030190744708, 43.986424015414336, 42.125114240954005, 44.918539985533684, 45.34612932512837, 43.912283374417214, 45.68214701068017, 45.06389517937937, 53.11530128602059, 61.3911218797007, 58.152879745729514, 56.60182945189938, 56.08857554774131, 54.627739767874445, 56.868130930008434, 54.776515268510394, 57.482632975424494, 56.35593214342671, 58.3805105763097, 54.992469203087595, 54.53188096323321, 54.14128741910381, 62.15539963014665, 59.078637553799545, 56.265788232126546, 57.571321687390736, 59.10764348122382, 56.18104542455366, 65.25252273005825, 60.096057230426425, 53.825811186144435, 60.26635477619787, 56.530983601847005, 58.023394461601015, 49.41725538622949, 44.44833017164662, 41.85996986204579, 42.20562088874079, 42.72416214789114, 42.69477182818998, 44.25246661709201, 41.784452469118186, 41.83406652942781, 41.26620538773076, 42.443167471116595, 43.09659511812272, 42.192924176493, 42.080548271056145, 50.503606796264656, 54.423678459659705, 54.20908950990247, 52.5358848417959, 51.96281087013983, 56.117169626297496, 54.478462203856445, 51.044607547021684, 49.63558627713112, 46.40747562531502, 45.424945431370894, 47.3312997048901, 49.4445707721095, 48.04155857332292, 50.39188592664657, 50.83230141670474, 48.40846100161153, 47.027692564072154, 50.82593933228524, 54.279629415081395, 54.30992187992219, 53.86732555204823, 50.04752535973826, 4.123146985807727, 1.5701035746643621, 4.874729985190976, 16.44353380126338, 11.937684589816678, 12.661123602621018, 11.52767433274177, 2.7846494413191274, 0.28795437106201727, 0.9056182145591706, 36.013167212086344, 51.43491868049868, 34.6651937115577, 51.26251089957453, 21.502092038431478, 0.16240638049860157, 0.12834801128314388, 0.12963994195865047, 0.19016557643490453, 0.1743610293394135, 0.20453513359590886, 0.0471589400342876, 0.11103870662590189, 0.1563739896781983, 0.14488742055912174, 0.17537672403118304, 0.2914792948192166, 0.18984285423592215, 0.11018105587291141, 0.16093209025359925, 0.12212979051494792, 0.14669358009292235, 0.1041971737398736, 0.12090275514750712, 0.09626663920860137, 0.1662791081734242], [0.037915277174643935, 0.04817519397024186, 0.024157648064917134, 0.08329734521647615, 0.10959152057166062, 0.02855285919541794, 0.012872502613332004, 0.04835522080200815, 0.05296498634702256, 0.03740227788746838, 0.07225839361067742, 0.03669208373814341, 0.025066354747621283, 0.044563541399134744, 0.03498456185503352, 0.14029502988823, 0.0036199349391784885, 0.01278604576063733, 0.02729958531657054, 0.023180257769361622, 0.018428403981811097, 0.07625152732455924, 0.03748842830499334, 0.04766732364171936, 0.056431909587474606, 0.07469256904216544, 0.07335449689097943, 0.10667038135110371, 4.800846749736417, 43.87049444260136, 25.280972103918753, 38.71741394842825, 38.23638231523576, 6.161198269936347, 0.06616615600162937, 0.6022156498605206, 0.5437351330634087, 2.9018393206980924, 2.3441898245965285, 3.9996815593011923, 1.0549577397684897, 0.21492391404125, 5.841846735246721, 40.256159767027825, 59.43806002216955, 59.63348427126485, 58.67577091340096, 57.7826472251646, 59.783887555522305, 57.945876659885535, 54.56284023100331, 52.728618344952984, 47.02815148138231, 41.9905573321927, 41.350646172800374, 48.10901549554641, 54.713996610333844, 54.14424880858391, 53.618521767277876, 51.06338393303656, 51.11864228402415, 45.94960558799006, 42.56351363274359, 43.7887797048015, 48.845840577156316, 55.72622306885258, 55.48139656743696, 52.135528518307595, 43.12844476392193, 42.28099315397201, 40.07156518197829, 41.09014588017618, 41.47083543962048, 40.45891884834536, 40.66572973805089, 40.06373613111435, 42.49129495313091, 42.17661103894634, 46.81040894600653, 54.91210376062701, 57.898168871479655, 52.9733193305231, 53.69440786300167, 56.11574188355477, 57.49001487608879, 56.06328410487021, 55.47469715918265, 53.62406015396119, 56.63100404124106, 52.04860879528908, 49.68443155288697, 49.998554568136896, 52.08226273136755, 53.63921619230702, 54.2553734779358, 52.07062898143646, 54.68790108157743, 56.48091454659739, 49.90290757148497, 53.7370087254432, 56.094388500336684, 52.31048191747358, 46.63094089877221, 43.12981759348224, 39.63875909005442, 38.480616538755356, 38.702842343238096, 39.169926028097834, 38.941848047318, 39.308126818749216, 41.159509074303415, 40.33280288019488, 38.6648424210087, 38.9698733821992, 37.75626459429341, 38.73382514522922, 38.75528835481213, 45.58094986023442, 49.03476153650592, 51.34078964110344, 50.32673143571424, 49.89441956243208, 53.01977980521418, 49.3984946896953, 50.047246871456025, 44.288615180600075, 41.60880873280187, 38.75166800714309, 42.00553686388078, 40.857000197133715, 44.13148110912692, 43.97372338079637, 44.67780059383762, 46.89213937328708, 47.73314260667371, 47.56938757434968, 53.01263324676022, 48.47488241810953, 57.53744025384226, 12.42061366958003, 0.03806090665861003, 1.1455398533613452, 5.03025588489348, 6.76023833213314, 4.945186540003746, 4.178434264275336, 1.9044904122429511, 0.1978633811156596, 0.0402761341613387, 2.3444366887692483, 42.57323326603059, 27.2025804750381, 22.640508990133963, 36.79016520900112, 1.6277062772743165, 0.03909331355844775, 0.04444352989535659, 0.0853117274480962, 0.05221900823075445, 0.04059941560450581, 0.028718332271842707, 0.032547360376244595, 0.006957674688178927, 0.030157656348761053, 0.027514352320483135, 0.036864813582430926, 0.015862657737377432, 0.057736542000765764, 0.050639231509018334, 0.09249012451618911, 0.0718638813123107, 0.0233480233638998, 0.021784912884956407, 0.038917419771032954, 0.04265676004691951, 0.02238014213470442, 0.03271905217139471, 0.03451504571844013, 0.03343477364509337, 0.08152374441945746, 0.05113897747510383, 0.011283129682734368, 0.03750532820460297, 0.05079788065725758, 0.03694545199734069, 0.025835572141072443, 0.05974125237234178, 0.03956621580366646, 0.014401622728684978, 0.03102685970764968, 0.0238282245118171, 0.014699646252988568, 0.01574400987010449, 0.09310559955455604, 0.03185639311859925, 0.021507259638559435, 0.04284907109855164, 0.03897457759106352, 0.020392109497239994, 0.008337879759980547, 0.040426796842967315, 0.05511005551764562, 0.12864165278452058, 0.07964721204893244, 7.07091260340906, 49.4107364070031, 23.131879991100682, 43.31135272979737, 39.96428835776545, 6.336788563959061, 0.08943870438322907, 0.18237326714781024, 0.7585345424952046, 2.059496843045758, 6.971351571621434, 6.534989360840091, 5.044890738302662, 0.8632617035219747, 6.5315798405678045, 43.3159811266007, 59.84935975843861, 61.629276429453206, 59.29172031341061, 59.85725548959548, 60.49434646483391, 61.178882429676676, 57.856536834470695, 54.58344444151848, 50.32892796301073, 44.874534914570475, 43.07135858843404, 50.312865857155096, 55.87381009132632, 57.11186701251615, 56.76016376864526, 53.24890113645985, 53.02480043903474, 48.50338628215175, 45.51334388794438, 43.8634616328824, 49.19233883580854, 58.70529459368799, 57.79512820705291, 53.19066962888164, 45.43096234721523, 44.04093711606918, 41.77394836179672, 41.93278474192466, 43.33574202752883, 42.53112662223078, 41.36592772699172, 43.17479148987801, 43.920712547917525, 43.57961539299258, 50.46682280878867, 55.22015886922037, 58.577601832728234, 55.656922632648104, 53.98300409317017, 57.483072280883796, 57.9803111476283, 57.30622437692458, 57.031132867259366, 55.74510143649194, 58.22995824198569, 53.18356621649958, 49.95923280715943, 53.07318679748043, 54.6245155795928, 56.978502504287235, 56.209537521485366, 53.00396088630923, 53.916590521412516, 59.51538170537641, 52.32278639270414, 54.55099467308291, 57.48237409899312, 54.7906397235009, 50.77212441352106, 43.98074442340482, 40.83435243175876, 39.30735411182527, 39.828107587752804, 40.127811970249304, 39.77819150493991, 40.7795294638603, 42.28460173453055, 41.788378761660674, 40.349167008553785, 40.32193791481757, 40.129580959197014, 38.41849011759604, 40.86116183188654, 47.38334171233639, 50.9346164426496, 52.98053649164016, 51.11701057803247, 50.34726504356631, 53.13200273821431, 50.881978234937115, 51.9116396288718, 46.10882636039488, 43.470087128300825, 40.76167875720609, 43.04252916766752, 42.941304560630556, 45.97061380263298, 45.38006174948908, 46.24979634438792, 48.27072305064048, 48.49232127589565, 48.712789858541186, 54.9892803161375, 48.889680908572295, 58.88712783013621, 16.616160254324637, 0.3173544660450951, 2.5043884929149383, 6.6230284302465385, 8.518014204117561, 6.15086478571738, 4.581059678908318, 2.110551884097438, 0.24216178714508013, 0.06473505779379798, 2.8434376803136643, 46.120919027636134, 36.38932251161145, 24.305439418362035, 45.854852891737416, 3.35770478171687, 0.011656184815951895, 0.013592334148744422, 0.044708845295733025, 0.017590981780461246, 0.07929200772196054, 0.031030067700832605, 0.02448307455427224, 0.0028059049931940653, 0.03463466268693728, 0.01902702891628348, 0.03699172370796723, 0.06203607641040318, 0.013886392210429956, 0.04427292977549857, 0.06887648314718278, 0.04246348755494241, 0.021246222839240107, 0.05311572180700399, 0.01682851553684281, 0.052455534046936425, 0.02504809695716587, 0.10622755954823188, 0.1315366071198256, 0.14284110778281767, 0.14343790559759065, 0.2012187236499402, 0.1383431910747482, 0.1947498465737989, 0.16741487948644548, 0.18452819587001879, 0.09975531934610299, 0.19805309512922842, 0.09377616397555798, 0.12411296998541202, 0.17615802646163972, 0.12944063652426968, 0.2587244088851637, 0.1290994669280706, 0.22758834334390782, 0.12047966776956474, 0.14123947840304146, 0.11315787436380503, 0.1504696274717008, 0.08457488109988552, 0.1260041882614455, 0.21202261649793197, 0.18751946277916434, 0.18725497858418574, 0.32639255687113733, 8.666863249194238, 58.155609715369444, 36.92164305717715, 48.04843448823499, 49.7069263458252, 11.194667066297225, 0.25643892345889924, 2.6049769405395757, 3.6539336990925575, 9.566082300678376, 11.539794456574226, 10.806062163845187, 4.684200363774454, 1.088567181460319, 7.487233463794955, 42.2474451218882, 61.27221915029711, 62.128805960378344, 59.375745327241965, 59.553012924809615, 62.82514041469943, 62.06587937570388, 59.64069751001174, 57.15611134805987, 53.11569352303782, 46.22909407461844, 46.279696572211485, 52.57598323206748, 58.93079949963478, 60.133570778754454, 59.17908160917221, 55.36248599329303, 55.777511981225786, 51.28032630489719, 47.90992775271016, 48.672056044301684, 52.25607864318356, 61.60695029843239, 61.29069351380872, 56.59646757187382, 47.784066738620886, 46.921168834932395, 43.25881650370937, 43.3948992144677, 45.4503898466787, 45.11422311106036, 42.8967385907327, 45.26296331036476, 46.4714494828255, 44.97082125756049, 51.47451892975838, 59.007222960072184, 62.891867776070875, 58.36577030920214, 54.68854042791552, 59.305593736710094, 60.30408797725555, 60.592127230859575, 59.68221972065588, 56.76978142030778, 60.160843018562566, 54.70198239049604, 50.626890813150716, 53.670583386575025, 57.71665334701539, 59.40634765932637, 57.98134273098361, 55.92319665416595, 54.27428322453653, 64.36139160586943, 54.73918999395063, 55.15243130345499, 60.59346868145851, 56.66605434110088, 52.42175171452185, 45.859967662442116, 44.32791732972668, 41.24302810238254, 41.37627493950629, 43.22397801183885, 42.43451080014629, 43.269038200378425, 44.696129829652854, 44.47417859108218, 42.622788490787634, 41.72464809110088, 40.74655017545147, 42.03433098331575, 43.0323584618107, 48.978628496969904, 52.40904715753371, 53.95788523458666, 51.90899595137566, 50.1001557227104, 54.87803797568045, 51.98317973844467, 54.768258679297666, 48.93206996302451, 44.8733268245574, 43.69122251387566, 46.81533544294296, 44.3460504470333, 47.66135146540981, 48.352410331849136, 49.357584368798044, 51.78246813435709, 52.264390145578695, 52.06568287264917, 55.948268444307395, 51.061579642757295, 60.064019310858946, 15.041359028508587, 0.23042930380230953, 4.471966797305692, 10.363726673587676, 17.53417922604469, 11.803518937480066, 13.492588612341113, 7.255175748179036, 0.8919999904690251, 0.327852659167782, 5.057246204345457, 55.29678237053656, 35.97253145710115, 31.378257313082297, 51.75217959188646, 3.598633427773753, 0.19480736445515387, 0.16841105425790434, 0.25616762108139457, 0.18645728187214944, 0.2158829029048643, 0.12686348610347317, 0.1802229196313889, 0.060516812973805977, 0.12197165464561795, 0.08094120350095534, 0.19571828896239882, 0.14713915215144235, 0.08277072105556726, 0.17326540103362453, 0.15254036313103092, 0.15057965301938597, 0.1561373144748711, 0.10455552668821429, 0.08866633453796949, 0.10736599684722962, 0.13699221034203807], [0.1147974021131954, 0.014582563120300972, 0.04211822321878807, 0.0381068795949461, 0.06743877360056486, 0.0347390957927752, 0.037909876254777757, 0.022150340655277816, 0.026120870944953738, 0.03415434471061153, 0.03516493725680536, 0.0536177775281812, 0.05682577837198492, 0.013607243177360825, 0.03717074696455271, 0.03466020022789317, 0.024258177952780843, 0.028448048791277315, 0.043362759864859046, 0.05336219527488274, 0.1702203853957115, 0.06466937341517018, 0.05617779439255115, 0.05950646940618754, 0.11440033874204082, 0.03485641449749951, 0.02030124955420052, 0.060816357182639266, 0.10405225288723746, 26.17470964308708, 34.410757403219904, 29.651290678208877, 56.212251801644605, 19.14034470435112, 0.393531583249569, 0.30705343331060103, 0.4298973173624085, 1.3109723118043717, 5.009694330153927, 5.401397905042095, 5.066270597519414, 0.6416324670276334, 0.5139816263991018, 17.891928803536203, 52.300879955291755, 57.91428981288787, 56.86766024558776, 60.373890476842085, 59.07233430493263, 58.95050156501032, 53.963804091176684, 47.60449278739191, 44.375115210010165, 44.44295652451054, 50.29707831721152, 52.24801425010928, 55.161386074558386, 54.86198763693533, 54.341755836240715, 50.531902774687744, 45.6629587757972, 43.659208128529215, 44.666586537514966, 48.67368382792319, 55.41022908303046, 57.52465724945069, 55.77886912130541, 57.07358860200452, 47.299179415549006, 40.986289362753595, 41.468403570113644, 41.74920212837958, 42.07258978197652, 40.60326599305676, 42.58586329798545, 39.10437930014826, 41.23608942954771, 40.88883415345223, 40.252056967827585, 43.91481722554853, 52.73512947943903, 53.662150290704545, 54.04520111699259, 54.30301066367857, 53.99824642365979, 54.309329602026175, 53.57924315237231, 53.47843823894378, 55.6519922133415, 53.309438997699374, 45.42675364402033, 54.08912381818218, 51.27491343405939, 54.47728157043458, 54.31215370855024, 55.381301603009625, 47.875418739934126, 30.90124022576117, 52.486655173763154, 55.06384065074306, 54.496112869631865, 49.810990748866914, 45.600726450643236, 37.72905903477823, 38.94692359432098, 38.40658180175289, 39.53502416610718, 39.01862452107091, 40.64634538465931, 37.91479502954791, 39.90422510331677, 40.05118062419277, 40.001358678264005, 40.69668116108064, 36.11732575201219, 37.74931807671824, 37.459564747348914, 45.06817448523737, 48.67056162126603, 52.407474287094615, 52.52708696549939, 50.95614241015527, 51.61019763638897, 51.840256414105816, 47.658488135184015, 45.139036024770434, 40.73282187984836, 43.097497263262355, 46.59043850437288, 47.567175357572495, 48.984437527195105, 47.87102176297096, 49.99262786680653, 48.37734876140472, 47.338454108084406, 49.84864550252115, 51.65297892785842, 54.91882278073219, 27.236436413180446, 0.11185175573994076, 0.7106626886994608, 3.0523615018013985, 6.60957028788905, 7.621353518578315, 4.80838260342998, 2.9585700313891135, 1.8319171258518774, 0.09548585005705396, 0.06353937457465837, 11.204781878379084, 49.005743841971125, 24.172904491424564, 32.79636671466212, 18.979152940934707, 0.06381245427614739, 0.061228527807660645, 0.056002019348764615, 0.06010889413676435, 0.08762232523651854, 0.029239794915361755, 0.06129864400493042, 0.02306252920759782, 0.06913958072301842, 0.035984704961940166, 0.020041202923523325, 0.05719019107580666, 0.030438695703783346, 0.04019544212027423, 0.016350116610767382, 0.025471948507812717, 0.025864340657848987, 0.05199529906554569, 0.041624992830498565, 0.03251566348837749, 0.008194659622536312, 0.02600157764860459, 0.047721991675996014, 0.020769384817310402, 0.013893770594750682, 0.025821288431724234, 0.04595011457680695, 0.04265803941375306, 0.040885982283901785, 0.03498168136443823, 0.059920405863874385, 0.0400181808659146, 0.021282845672460336, 0.009481871196429336, 0.06331860718707885, 0.08376962310003658, 0.03925568972443862, 0.05535612678936413, 0.04583106068293414, 0.01640267215759283, 0.04757404094561935, 0.030816911396780805, 0.024608682330337264, 0.044547399926570155, 0.10086299821494088, 0.029193258904401335, 0.052680851996786175, 0.03591009948943411, 0.03844633315419478, 0.019080157113832333, 0.1359815565088103, 35.658420208961736, 34.696184358289166, 29.56888952562886, 64.02522094788091, 20.606487451061128, 0.5256503099395383, 0.0453648119113378, 0.6353608422702359, 1.6456786999779365, 9.596796420312698, 5.682712254985686, 3.399084806442261, 2.8019502807048062, 0.90773549772078, 21.59608575605577, 53.334165619265654, 57.38038855214273, 57.43407011032105, 60.68191420647406, 60.72041226971535, 60.050165499410326, 57.80509494966077, 51.4052616396258, 46.97741170083323, 46.149462115380075, 52.2891991369186, 55.40232942950342, 58.325138476587114, 57.48087967595747, 56.73877900646579, 53.8578216491207, 48.03049748943698, 45.614921508296845, 45.680813404821585, 50.69152362885014, 57.332927873057706, 59.26602486641177, 60.21863914305165, 59.706354064326135, 50.12259952483639, 43.50232901111726, 42.662173009687855, 43.85183965006183, 42.87649131590321, 42.648460403565444, 42.985678334389966, 41.94195524338753, 43.96423516734954, 43.08427495341147, 43.55078204985588, 48.04177038131222, 57.427951212852236, 56.43818032357001, 55.61347846061953, 56.87419491429483, 56.39204540560323, 55.89327289212135, 56.37886624182425, 56.847714993261526, 56.81263331444033, 55.67739740494759, 47.648650830791844, 52.28903439737136, 54.636616091574396, 54.71341217717817, 55.35439022125737, 57.60966285582512, 50.79392886930897, 34.160521953336655, 53.78143349001485, 57.03963656579295, 56.457474462447635, 54.51903520091888, 47.69627624942411, 39.75249605794107, 40.82985347317111, 39.77261781692505, 41.88445721903155, 41.041073106950336, 42.131162535759714, 39.45254848849389, 40.947426519086285, 41.0779159299789, 41.3277473757344, 41.983489221142186, 39.47001480287121, 40.37786306873445, 39.32141188652285, 45.7619397870956, 50.24305943519839, 55.19537733447168, 52.5674089308708, 50.3119441001646, 52.825336148661954, 54.66322545082339, 49.63870848378828, 46.69262016973188, 42.7895833599952, 44.93965802654144, 48.29906609750564, 49.278834942848455, 51.683118420262495, 49.80974735752229, 51.76047148243074, 51.452957660921165, 49.866076515566924, 52.51389603460989, 52.46676483461934, 55.58324483133132, 30.569121376160656, 0.20619895399337818, 2.47303331090558, 3.3849064188618816, 10.341860440469558, 7.442484123091544, 6.158420741558076, 2.9115493932077965, 0.8134218617793053, 0.0818336806109836, 0.07856296014881904, 11.429424843480511, 57.39013564202094, 25.02554931948262, 33.65053538353213, 28.227170244339977, 0.1008820967868932, 0.04726977380473287, 0.03451748187803934, 0.1138239341878122, 0.0218556419525656, 0.027898076185656172, 0.039218653203739275, 0.025718889289325284, 0.024841890985807105, 0.04423360265190563, 0.03105059311154389, 0.040178400494398615, 0.049926693130645065, 0.010606349415836797, 0.07475184892574627, 0.14844193063195676, 0.02716283287642704, 0.053757504304690715, 0.032730263868166555, 0.058727055382464206, 0.01852526813895712, 0.029921534643959136, 0.12981638732937076, 0.11552084192273118, 0.21380283629461644, 0.08841730233642364, 0.11081211313965822, 0.1439107657079735, 0.13210034057978662, 0.07435272477807538, 0.19089501471288745, 0.11804271143891158, 0.07183364382193935, 0.14408489749316247, 0.1719642466595096, 0.12417235712130224, 0.256677192125109, 0.126723958509824, 0.1322594417199012, 0.11261619657518403, 0.16276432742034236, 0.17449906306161037, 0.24468008669153338, 0.1988203475071538, 0.19072943246893345, 0.1465605565857503, 0.22097910363827983, 0.1506283762113702, 0.11179802233293173, 0.07048041079073183, 0.2755523575169425, 38.753299713134766, 47.010885207883774, 37.73123595022386, 64.08982238461896, 29.471863815861365, 0.8794723691478853, 0.5112593789254466, 1.50104436422548, 6.825277113145398, 17.136233199027277, 13.223383599712005, 11.391791662862225, 2.1530328691005707, 0.8976018705194997, 21.914852857589725, 52.503552744465495, 58.89720047673872, 57.83938430970716, 63.2730790107481, 64.38344709334835, 62.97861883717199, 60.420190134356105, 52.19457587888164, 47.56549266076858, 49.40242490460796, 55.84382749372914, 57.49008940112207, 60.521991329808394, 60.0251054763794, 60.134261115904785, 57.065861532765055, 50.10403886918099, 47.77446869880923, 51.57373528326712, 53.883842652843846, 61.22016929811048, 62.24902660615983, 60.76633145732265, 62.780852933083814, 52.47710812476374, 45.52467169300203, 44.41836326353012, 45.636435708692, 45.15948726284889, 44.63557627893264, 47.06476680694088, 44.03193527652372, 45.340543870002996, 45.85439397442726, 44.261711643588164, 48.4926821339515, 58.62073221514302, 60.72863355759652, 58.00634391846196, 58.40966555380053, 58.11015336744247, 58.39998906658542, 56.93006123265913, 58.40895952716951, 57.837729069494436, 57.66594886779786, 47.629658714417495, 53.70662212371827, 54.27926463465537, 54.792491082222234, 58.30037655368928, 57.105457859654585, 51.24483669957807, 38.53721241797171, 54.94954278392177, 59.43518100246307, 59.62806355568671, 54.71584796905518, 50.16922866144488, 41.21956448401175, 42.382574696694654, 42.16767980206398, 43.913722884270456, 42.55359003620763, 44.67925971554172, 41.75517982052219, 43.98827537413567, 43.30741074777419, 44.9490285688831, 46.281673446778335, 39.646403789520264, 42.10675754854756, 42.027737479056086, 48.1516202803581, 51.88977633753131, 56.04946951712332, 54.792436169039824, 52.472781750463675, 53.00020325568415, 57.46389973548151, 52.90890616755332, 49.27427714870822, 44.01365703152072, 46.67600893205213, 51.47276170792119, 51.676701422660585, 53.259393476670795, 53.54215322002288, 54.84601966796383, 53.7114348719197, 51.384641739629934, 54.83414273108206, 55.44156882070727, 57.3235926320476, 29.227384444205995, 0.20444973011411008, 3.2401256070983027, 7.304939348851481, 13.25845939497794, 18.40145645603057, 9.542096026482122, 10.671479759677764, 3.7114613863729664, 0.4825749019941976, 0.14323055624000489, 17.646304099790513, 60.51280121649466, 32.810449984765825, 45.8670828419347, 30.596599540402813, 0.29362357491927765, 0.19602575068992956, 0.10718656373360466, 0.22633939020095334, 0.1723542773435193, 0.10398004910037403, 0.12718536560573887, 0.1668420295801855, 0.14164703717875865, 0.129140023622782, 0.15708061385779612, 0.16928425659575772, 0.14734231866896152, 0.11695304329717353, 0.19105944782495501, 0.18334033057814647, 0.11716050756794792, 0.1471462614473797, 0.2754759938726502, 0.14491749717102897, 0.08674841809777484, 0.11552048186140677], [0.04215766142513003, 0.004514512566534142, 0.019736736599776535, 0.09685566889182215, 0.05153812843585207, 0.04009069491838736, 0.025262653286899292, 0.08202518727029524, 0.05646220453444028, 0.10659480677737344, 0.022512472332305005, 0.02383046723421543, 0.01994565069194763, 0.05931660600547349, 0.036469600313613494, 0.04645356457800635, 0.03546836936185437, 0.05826939062605943, 0.06533158747779746, 0.036377570171269684, 0.021832877649895607, 0.013073260741939229, 0.12443809770047666, 0.03875612761945494, 0.0649785511796513, 0.07931784020676728, 0.07768656322432142, 0.054285185666935104, 0.06002471639564442, 6.061630374000919, 45.85592369879446, 23.19882896638686, 36.18333139727193, 46.42593037697577, 3.996656676453929, 0.213500400103869, 0.4023301030599302, 0.42233311841564797, 5.286198383377445, 4.01191518672051, 2.983829850150693, 1.800972689544001, 0.20656554238690486, 1.7693191622534108, 25.61956874785885, 53.72224100174443, 59.83463125844156, 58.44076210452665, 59.103120988415135, 57.7388108161188, 52.13940774240802, 50.18088986796718, 49.36286780142015, 53.76337489774151, 57.16824716137302, 54.62819868518461, 57.657755036507886, 56.64453621833556, 51.039292735438195, 47.51308979526643, 43.17770188854587, 43.22959484592561, 50.034334428848766, 53.87249523593534, 58.71547314428515, 57.54034280776978, 57.3734930253798, 56.83292765771189, 51.02921224409535, 42.31503148232737, 40.24848368860061, 41.74688008523757, 41.49415000792473, 40.82007108196136, 41.43600871486049, 41.21450462648946, 40.16423117729926, 40.68493758478473, 40.783141966789, 39.73119758790539, 41.27735668613065, 44.693278266537575, 44.73154490993869, 48.42954374128773, 49.823569790009536, 47.247639471484774, 53.73684006352579, 54.141816939077074, 58.729515229502034, 45.294730586390344, 44.95451988712434, 54.57847087613998, 49.98160992899249, 51.51136567515712, 53.830482729019664, 49.62947522440265, 44.052480651486306, 51.68461284329815, 57.5971701068263, 54.81799825545281, 53.37696652258597, 48.71303304549187, 40.07638185254989, 36.81189513975574, 37.71986107672415, 38.191302514845326, 38.109772128443566, 40.32979049990254, 39.1013982988173, 40.07743697012625, 45.30876090449672, 46.82461969314083, 44.03743836187547, 40.4215935737856, 38.03385073138822, 39.32211006841352, 38.66534056202058, 42.589789590527936, 50.2381839290742, 50.63619467519945, 52.23339557647706, 50.19745795957504, 51.02234809629379, 51.75784741678546, 50.86360193067982, 47.12685792676864, 40.88118553161621, 45.75195735500705, 50.22296905517579, 48.68862805827972, 49.95967995735907, 51.36231168623894, 49.69751657978181, 51.13649691304853, 51.64780924397131, 51.98714917705905, 54.097141142814394, 37.42837013736848, 2.381568051153614, 0.33193128063313426, 1.652864849855823, 1.109241994638597, 10.278161148871146, 0.9664899062725806, 4.301667780645432, 2.413691282272339, 0.8050349763324185, 0.1588859766601555, 0.09144962389743136, 25.837709403807118, 44.24176639126193, 21.492037042494744, 36.35308765595959, 6.696122288703919, 0.19734929015319194, 0.056325959627546614, 0.10094824081827557, 0.06623066826573303, 0.048207990194280306, 0.02502933163346062, 0.07849621856885572, 0.06568857678963293, 0.055432930934212865, 0.048919383271206776, 0.023877081769188086, 0.03929901199655668, 0.04728373575715288, 0.029343651540036646, 0.1126331041356729, 0.023447948042303327, 0.0356998926238908, 0.11185157187883893, 0.03950108683878376, 0.07434995153978949, 0.01910817486444308, 0.040870702660252015, 0.04331223253581313, 0.036130480002611876, 0.025990551728154385, 0.015239789950541191, 0.02621412874319621, 0.017498175974094102, 0.03857955967466678, 0.008303589664489753, 0.046819145565912615, 0.048230551483650366, 0.06680315811066859, 0.017319417017842495, 0.018058904454172138, 0.10430048069646282, 0.05110206352847238, 0.03982543697460525, 0.008973003995995368, 0.036222360757810455, 0.036068848229103515, 0.03995508203403123, 0.03723966806466061, 0.07101049766905847, 0.06049829662867612, 0.052245729377553354, 0.03902469506306995, 0.005006355378070786, 0.06508576518465435, 0.06264241201983345, 0.20350312123135214, 9.591018769048876, 50.711696378646366, 23.760977175927934, 47.17316935139318, 49.818580535150346, 4.097044347755371, 0.11181223326392713, 0.13887678663576805, 0.8216782058438947, 2.955286517258614, 4.321833666293852, 5.510719264707258, 6.090529907134272, 1.3183034668045661, 1.9828434336570002, 30.948781313434726, 53.632355966875636, 60.87110973173573, 60.094986423369384, 61.41838235239829, 60.02366988889633, 56.7199202506773, 50.870356252116544, 50.25401853745984, 54.53290862421836, 60.23141430270288, 55.67602457538728, 58.92973261494791, 58.78349881018362, 53.44880865466211, 49.190534545529275, 46.55129717242333, 44.42960869881415, 52.118913358257664, 55.912010054434504, 61.10319245246149, 58.62146962073542, 59.886414389456476, 58.52549314498902, 52.43237741531865, 43.00922432253438, 42.90613658966557, 43.837311190943566, 43.8827871507214, 42.69272435096003, 44.88887509992046, 43.81332197496968, 42.04541167905254, 42.22011012415732, 41.9699138979758, 41.39492188730548, 45.60456645104193, 49.844844725824174, 49.88758287122173, 52.13659932536464, 53.020105361938484, 51.39674225161153, 53.91870467893539, 54.85417819792225, 60.53639035071097, 47.8001602234379, 48.274896452503825, 52.50297615605017, 49.61606071841333, 53.2859440003672, 52.84431257555562, 51.36421795814268, 42.721341963737245, 49.5679763824709, 57.72014425646875, 55.55230517541209, 54.08979846585182, 50.511604509046, 42.6285739867918, 37.796676774178785, 39.7680207990831, 40.29111593000351, 39.48071110633112, 41.512134075164795, 41.368936184913885, 41.02706240069482, 46.1529294906124, 48.8630715493233, 44.900563763033965, 41.73983550840809, 38.758826332707564, 40.903013521625155, 39.705674725194136, 44.22513161936114, 51.684746203884, 52.18163990205335, 54.22086054278959, 50.17945035811394, 51.464563954261045, 52.30449638059063, 51.22510717761133, 48.52939944113455, 43.39287919382895, 49.22746758307181, 53.34736831726567, 53.516206741333015, 51.68041982958394, 53.52147840684461, 51.593354978869044, 51.56447848966045, 52.14148659859934, 54.59542336002473, 53.73060741732198, 41.814941052467596, 2.789640412215264, 0.6846927983626243, 3.1629532191061207, 4.544316386022876, 7.078643104722423, 5.292244226701799, 7.411017888976683, 3.3213017544438763, 0.2156727190219587, 0.07008369215914319, 0.1669792818926996, 27.7574566102797, 55.197522870955936, 23.902364892344323, 43.080274135835715, 9.428380631631422, 0.1258171938600079, 0.022947794134398142, 0.1902163987078013, 0.07049937146685778, 0.10665382619106001, 0.053255452413953124, 0.0727167210331367, 0.05310647895619754, 0.031399605532867775, 0.06683170254672728, 0.02812750228199988, 0.030289046173434586, 0.012557301482546234, 0.041175034918612054, 0.02042615444459502, 0.07859600152099326, 0.07320831965414748, 0.01265680960064093, 0.03982754754683664, 0.05547233083615861, 0.003157692328621183, 0.045435935514228004, 0.31914334263532396, 0.10545086130620011, 0.09488245622525293, 0.3743800286564135, 0.15047897374437702, 0.12359331722461409, 0.13708850759412014, 0.25011466846110364, 0.13997334956882462, 0.24065274715183244, 0.18508632156637408, 0.2227179393652947, 0.15032016371767368, 0.18419104057454294, 0.15259311594549688, 0.3211298392665002, 0.12257839628164807, 0.21628753522471075, 0.15132966841901505, 0.10494345829131142, 0.08999191179511049, 0.26145474624729925, 0.2633121110979588, 0.1437028494453238, 0.16896703490807166, 0.18051127512608806, 0.14263714453385723, 0.24620740554265438, 0.3716465962990638, 11.45798852366786, 60.59901099051199, 34.12513432964202, 47.577702999115, 59.78623313288535, 7.7381391486813955, 0.6708578633204584, 1.7057933129610556, 2.8686923509643925, 13.834308443530915, 12.110650327897842, 10.696359353680766, 5.590618925709879, 0.6007765690165182, 2.6391118572604273, 30.32473025783416, 54.00675796693372, 61.245241088251916, 62.03417877997122, 66.74169371204992, 62.72317055732974, 58.04607752830752, 55.52263244505852, 53.09341838282924, 59.536417376610544, 62.20326431335942, 58.34464442345404, 62.05253155000749, 61.377809355335856, 54.9956855466289, 49.97776208385345, 46.822011316976244, 49.0091053132088, 54.619181156158454, 56.50153444659326, 63.96387507838588, 61.53727723706154, 62.71680847291024, 61.63063356953283, 55.31782196414087, 46.608002878004505, 45.88296451876241, 46.54218550651304, 46.76052816452519, 45.43302943629604, 46.612493991851814, 46.10662591072821, 44.34790180575463, 44.202311269698605, 44.84339521777245, 44.416766858869984, 46.72830197118944, 50.06294419688564, 50.01813896240727, 55.49312053188201, 55.005981768331225, 52.61909008026124, 57.8080798733619, 59.40708506491877, 63.086868409187566, 54.0986983237728, 51.88216693939702, 52.830144974493216, 51.90667390823365, 54.02422820368121, 56.063637118185724, 51.416820864523615, 45.072073321188654, 51.7995108327558, 60.528835865759085, 58.54830564991121, 57.91277970037153, 53.55003326169906, 45.13856534034976, 39.02170358165618, 40.73717178836946, 41.307480489054036, 41.29538389944261, 44.547691652851725, 43.07988189881848, 43.55023684040193, 49.610385048773985, 50.64385114177581, 48.4269981230459, 43.27705160264046, 41.080351721855905, 43.21004967535696, 41.530886926958644, 46.623209907162575, 54.57282266309185, 55.25529546122397, 56.63421646241219, 50.3142112301242, 51.944995464817175, 52.46453692836147, 54.06780181392547, 50.40908944222235, 45.47126470073577, 50.41300004528415, 54.31450320828346, 53.65887511161066, 54.9308644571612, 54.76764286718061, 54.55867859625048, 53.577858555701475, 54.75074921884845, 55.09204249228201, 55.78814160439276, 39.48954428395918, 3.363906539255573, 0.9121333939894554, 6.72964874775179, 5.6449864083720795, 19.635734173559374, 7.439771804117388, 15.49738359066748, 8.9523402144832, 1.3495436743382485, 0.516615497969812, 0.3884729208244432, 36.20375517875918, 56.40635421199184, 30.78627947838076, 51.139054298400886, 11.516814270327169, 0.37824635183618915, 0.17671563121820652, 0.41161928686403465, 0.16480657993064773, 0.25436527666545683, 0.13092998805786335, 0.16079036398760735, 0.11185152591356348, 0.10352517673445326, 0.22921623421772835, 0.14818152202473533, 0.153216895376963, 0.13043949260346352, 0.18399600991077963, 0.24893607283311509, 0.20265549090841126, 0.12824570024085621, 0.1976519561703167, 0.15961618102606268, 0.20372459725026162, 0.09942174168123354, 0.21844382758342454], [0.03289169008513132, 0.029932001320224617, 0.0226885269981839, 0.055577055055407755, 0.013141556522778928, 0.041435730808805075, 0.039603535776897784, 0.017534021228071184, 0.06655898290656267, 0.033827964441790696, 0.06855563020273563, 0.11213287936463473, 0.03233520381693398, 0.02795083857622118, 0.037447779679731015, 0.047973387258788275, 0.011584128501013884, 0.029514577247262485, 0.0975606153388658, 0.01226454098228245, 0.06568873000721778, 0.1271251817384074, 0.04234639484615576, 0.04229477201137812, 0.011080173839394365, 0.025592898469298117, 0.04001280675912577, 0.03530217424756096, 0.016186524280196717, 0.21585703977654058, 27.62300756669814, 37.56344479899253, 26.33353033373433, 57.379474639892585, 19.307486703318936, 0.04602612582065406, 0.1078887905685171, 0.4679019893369367, 2.50728884050923, 2.962725292290411, 0.7731657799693846, 8.20787190429626, 1.5889131782516357, 0.24334899360133758, 2.9433482933428983, 30.61507586509951, 58.21507676955193, 63.75126300319549, 59.71632080693399, 56.68124175840809, 57.197111883471095, 54.54505620464202, 56.7337622950154, 57.72798899681338, 57.61049832067182, 58.89719655436855, 57.81913311250749, 56.69652723496961, 48.24420782827562, 45.91768926189792, 43.0889464962867, 51.57095432281495, 57.91115583912019, 58.527124850980705, 60.3376595435604, 56.912006562755955, 57.84145139878797, 54.39134243995913, 50.52208115977626, 43.12478911492133, 43.845940405322665, 41.89940929412842, 41.2642442026446, 39.12517178443171, 40.1172137260437, 42.49673920293009, 41.15499050386491, 42.21599163547639, 42.90794087994484, 42.423504629442775, 40.64880863312752, 39.73836375821022, 39.97488660197104, 42.42877629495437, 43.67900825315907, 44.5826909618993, 50.48596789759975, 52.467078624233125, 56.68818043124292, 55.4581408346853, 49.35721174363167, 54.56735880144181, 52.8401352513221, 55.2815596518978, 54.725171442954775, 55.48854704826109, 60.50397980597712, 57.12256331597605, 54.6474967464324, 53.67426649216683, 48.40569180826987, 41.145011994146536, 39.54102147010065, 38.78376083989298, 39.92681011076897, 39.05655384063721, 39.849657089479514, 37.42291412045879, 39.518157974366225, 49.400224454941295, 53.745304538357644, 54.00624021407097, 48.88879837528352, 42.9391590241463, 38.93527807727937, 39.576789563702, 40.095550475582, 42.32781448671895, 47.06861465207992, 50.27602695649671, 51.353906046959665, 50.794368174768266, 51.269684914619695, 54.209513125881074, 51.66508728458036, 48.6467489119499, 41.80507629148422, 46.60920312327724, 50.87370987861387, 50.45555383928361, 51.9803281753294, 51.66165128830941, 51.414753775442804, 51.00498768591112, 52.816079355055294, 52.52698498387491, 44.03901907705492, 6.171266994168682, 0.08545496290729893, 0.5156217287144353, 2.619312713223119, 3.041643625305545, 23.28097320372059, 12.727826449178881, 6.487221756289083, 0.16201589016183732, 0.06646779546093556, 0.09371278552158226, 1.4250773696168777, 45.36481941899946, 23.263404907718783, 22.16752802172015, 30.961079905110022, 0.5317419346782469, 0.04868152829247618, 0.09773205049456128, 0.030042950003858537, 0.04434459730081501, 0.09912436167078634, 0.10363737031096414, 0.07337205562620394, 0.10718577466304265, 0.05026669061231998, 0.05009797889919532, 0.015999926329259912, 0.0023431945901979966, 0.004241776168196192, 0.04200037974383562, 0.03791889694008616, 0.06438734580672557, 0.03985603069586139, 0.030116820031957283, 0.006677293689966563, 0.11042133935036198, 0.03327856448689296, 0.043421921004811605, 0.033532660529618306, 0.05284353459794676, 0.011961338703610725, 0.045895795112535845, 0.03184251926629053, 0.03883066414404781, 0.07903573598953025, 0.0327962585124037, 0.029403866050885092, 0.0922422644291674, 0.03912040625788993, 0.0648631859991339, 0.03848636890911768, 0.03254536471720184, 0.05005934508517385, 0.08654325209077328, 0.02307812675773617, 0.016701272163059444, 0.07033727492295927, 0.021352691823736798, 0.03689468718103824, 0.02123784183734848, 0.043406729481273124, 0.024897118264268485, 0.034307347790848826, 0.02008366334672657, 0.06125722929174381, 0.03972601791423175, 0.02420753188010666, 0.4224229958509246, 36.491606158594934, 38.44692730134533, 32.57058724280327, 66.75591622629474, 19.30432331177496, 0.10763058829451762, 0.1259901382089142, 0.34660569482272674, 0.8600535111561899, 3.1410757091737564, 6.646542549133302, 6.416489164675436, 3.7486552615319533, 0.6306495853970129, 5.098435013524948, 33.236062449793664, 59.62897354556669, 64.47949417175786, 61.04905197697302, 57.63146338924285, 58.08556402883222, 55.151819413708104, 58.03607940673829, 60.656446256945216, 61.323327633642386, 61.410525844943145, 59.277921415144405, 58.50455161063903, 51.13427292916083, 48.26329408153411, 44.96523580243511, 54.101224330163774, 58.16454879699215, 60.18562063094109, 61.48765925438174, 58.789005817905554, 59.572891496842914, 57.70648656352874, 52.93523703852008, 44.42267787071967, 44.63101456242223, 43.32561446774391, 43.7743571496779, 40.44852456738872, 42.95591538952243, 44.25454547328334, 43.17552105073006, 43.50065415905368, 44.555446178682395, 44.02714214017315, 42.58756560664023, 41.839934395205596, 41.55264431430448, 44.34505024263936, 46.11459616691836, 46.94597390390212, 51.87820926789315, 55.711529870187086, 58.715677107534106, 55.57076384944301, 50.238717371417636, 54.36205017951227, 53.279021017013065, 55.36688297025619, 54.68974851792859, 55.20464589518886, 57.52575159072877, 59.36059713363648, 55.57628262427546, 55.363525421388694, 51.748370970449145, 42.40077057192403, 40.15349172776745, 39.76771877657983, 42.27215605397379, 40.9416724020435, 41.598151653043686, 39.98963471381895, 39.49226248648859, 49.83245395844983, 54.94740509217786, 53.05343766366282, 50.639834634719364, 44.2600760152263, 40.10875709595219, 41.31019869158345, 41.273787329273844, 44.167613983154304, 49.84760999679566, 52.16461289313532, 53.71574947910925, 51.81778123301845, 50.9274188933834, 53.82814107402679, 52.187872548257154, 49.207914567762806, 44.5362893227608, 48.03721650954216, 51.375188827514656, 51.36222539409515, 52.766108359059984, 52.13535201164984, 52.93240508725567, 53.33380083883963, 54.26781915849256, 51.83458466683665, 45.82717272543138, 9.416336013424782, 0.16183461843719407, 1.8332520800252117, 4.250389654790202, 6.891434750249309, 14.894754559763017, 14.559327190922154, 4.9394422288863895, 0.34290389668556953, 0.11012880101559624, 0.04852572133043601, 1.3920850883568487, 51.54145025437879, 35.13977696818691, 21.49206057671578, 39.932968231939505, 1.1699025525200752, 0.05736467143100116, 0.09266227213365417, 0.03276342398396904, 0.11825785191068727, 0.010611496569078055, 0.043282638559298175, 0.029323518749386556, 0.003700953525220675, 0.03092653857874534, 0.02522077317529869, 0.03457476993301704, 0.005526689478316375, 0.06966363082850172, 0.03256856568998868, 0.021940532155455123, 0.022933541068566904, 0.04189636415591644, 0.03616859670728445, 0.024887371710651827, 0.022857345963617968, 0.027312001686603315, 0.032931208730705326, 0.15035946402818928, 0.0959807888214146, 0.12405132289014517, 0.14911472436881837, 0.1773353044183985, 0.1297020716893096, 0.16373480760282086, 0.1237750639237704, 0.14325539281051006, 0.20393658910066853, 0.1879439827415251, 0.19955971428463537, 0.12877721970360126, 0.17217663687563714, 0.30102162471702026, 0.19765008691578143, 0.11762307911750772, 0.13326893109948407, 0.19328646542083835, 0.14491786489323263, 0.19203316089847397, 0.24580062817661996, 0.14926089394477107, 0.12489173666483934, 0.10040145322319963, 0.12558227299802727, 0.10085676225923723, 0.08686410503522043, 0.26020807604635915, 0.7623861261433171, 41.599308752244525, 51.06513723250359, 39.64726671095818, 68.4003620762979, 27.622168179481264, 0.2643193022137688, 0.6322888296938712, 0.9141824646822868, 9.576920790057029, 13.725207717187944, 10.157505120000533, 14.801378615440862, 4.043601318713158, 0.30594625239891393, 4.5508559576926695, 33.118716901348485, 60.94443844210718, 67.93408639969365, 65.13671082835045, 60.371976360198, 62.36410502464541, 56.30373716354371, 60.77095200938564, 62.114685427758005, 62.53841123273296, 64.34241910134593, 63.1249624683011, 62.14911991550077, 53.33123560874693, 51.23015134565292, 47.62931354584233, 56.45440324660271, 62.09324183002595, 63.27824477226504, 63.05701917217624, 58.99382414356355, 62.654109385705766, 58.55841359784527, 55.498392197393606, 46.63013289051671, 47.5030210710341, 46.15128209514003, 44.69301546773603, 43.42917680740357, 44.671489500230365, 48.36789977165961, 47.02429186913275, 47.85295532595727, 49.01317281107749, 47.467103927366196, 44.679730399962395, 43.11970964554818, 44.45692800706433, 46.31628836354902, 47.41118661818966, 48.12177496571695, 54.36288956672915, 56.45099470692297, 61.2084335665549, 58.10882760632423, 51.25188519877773, 55.52409941150297, 55.30114796853835, 57.51909140617617, 56.158056412973714, 57.234998056965495, 57.627160549163825, 60.38005644275297, 58.05438118596231, 58.17257004399454, 52.763574507928666, 44.390094741698235, 41.36899502046647, 42.54656507122902, 44.49673614194317, 42.66485198851555, 43.55487700431578, 40.74479295361427, 43.44576451086229, 53.66536271187567, 58.05793093096826, 55.67215711839738, 53.7973661576548, 45.51969420525336, 42.145012424838164, 43.114520349810206, 44.899406663833126, 45.64787334011447, 51.60586341734856, 54.781665340546645, 54.712388438563195, 53.3963587207179, 52.019143950554636, 55.54350729911558, 55.00155341240668, 51.897362201444565, 46.593686226875555, 50.96222600629253, 53.973123642706106, 53.420795086891424, 54.342293200954316, 53.398437576909224, 55.13347841078236, 54.2323217084331, 55.18259825245027, 52.55213914378997, 46.753656171983295, 7.664305923446533, 0.16158251422307185, 1.7853675398134419, 8.114544499304987, 11.457563927096706, 35.181303101201216, 22.621534524425385, 13.355785166063617, 3.855704097978531, 0.314800328905544, 0.41027559928836366, 3.1269468415168027, 58.17819864519181, 33.16918996072585, 31.67011695523416, 45.327227423267985, 1.8303899755400999, 0.27190200984477997, 0.1911342792933987, 0.10201607545417163, 0.298389928836015, 0.2311944111340469, 0.2979700820099923, 0.211716472441631, 0.21586483855160976, 0.11621856416064887, 0.12036624079149578, 0.18701110215437028, 0.10481114724590894, 0.15811369874544684, 0.1465718333999957, 0.1813355244455799, 0.1372120469327896, 0.23674631160834145, 0.14926524532418098, 0.3108728106223768, 0.31046699852712695, 0.10793168383139758, 0.10808274870918644], [0.06185603808731802, 0.05038951748921987, 0.06261811937175452, 0.015264457024093118, 0.060652107931673534, 0.0516380722664537, 0.033830680223482276, 0.006955313700957285, 0.030263499056379643, 0.05741113849404839, 0.11610046404624179, 0.04885940624761486, 0.03411110670816514, 0.07481250010671155, 0.04570351470442069, 0.10146663719487768, 0.01917539141891945, 0.03863039726932203, 0.041679637882137494, 0.012965023051947357, 0.03773526566463613, 0.018535608410715096, 0.08804401833443873, 0.025924363646716363, 0.0704450405112678, 0.025079113942000176, 0.059993980948122284, 0.07541093734964248, 0.06562844654845615, 0.023644842214942462, 8.529061559707888, 45.89009146536551, 24.829036612664503, 44.49379436431393, 43.175089590011105, 2.41174407062992, 0.22854100432126756, 0.3410744787223878, 0.4064879380166531, 1.4888821974877389, 5.636007122455105, 8.332078168469092, 7.5139899119254085, 0.6009605526924133, 0.06564939139230598, 2.662791451138835, 39.9596481938516, 63.570869276600504, 62.09037457742999, 60.324076375653675, 60.40579111345353, 58.897004358230106, 60.503195331942656, 61.06959342956544, 62.22821451002552, 57.69750433583414, 58.66842431406821, 50.76431889687815, 45.531363256516, 45.01648549110659, 49.4959734332177, 58.06623066625288, 59.05532690786547, 59.83700429239581, 55.61753026900753, 59.34645306679511, 56.90457759364959, 54.978666382451216, 52.396017043821274, 46.36574945142193, 43.15216725872409, 41.42168029662102, 41.57420166077153, 40.32027875223468, 40.97940560310118, 41.28420906682169, 42.552511384410245, 41.64312947180964, 39.77507322065292, 42.809877703266764, 40.93851881642496, 41.845884630757, 43.264441182536466, 44.136270323107325, 46.37808530561386, 47.03474890801215, 52.257525997777144, 53.150249604255926, 55.16313937402541, 56.48225207482615, 51.68820573437599, 61.03744176126296, 58.26789148392216, 57.1851957228876, 53.27605570516279, 56.584088571609996, 54.37169921013617, 55.56803780217325, 52.50268197828724, 51.86222953181113, 42.079104838832734, 39.903283734475416, 39.214641048062234, 39.11564826965332, 39.87381888974098, 39.96229971608808, 38.405687501353604, 39.71782622798797, 48.79954876438264, 55.25470710569813, 54.47059392929078, 55.00948836726528, 50.46968613901446, 47.65824102586316, 40.87918904519851, 36.97195137700727, 38.56289217548986, 43.550244685142275, 50.24887238779376, 51.995091976657996, 51.58123877740676, 50.17700279912641, 51.51957911829795, 52.7495716464135, 52.324845637044604, 51.23244593220373, 44.775785323112245, 44.49628899174352, 49.87958123607021, 50.969800103095274, 53.92604735589797, 50.30451120868806, 52.639011798366425, 53.4796541736972, 51.972506969205796, 47.89589743460379, 18.45110385648666, 0.5577647157253758, 0.28721653646038425, 0.8244166330945107, 1.8308243780366837, 3.0114234791648005, 13.964867476494083, 13.27548542330342, 3.219582928765205, 0.603995364039175, 0.10363832792086948, 0.03319955400882229, 10.015823225821219, 47.615542104167325, 15.796705542072175, 37.34475697240522, 16.160018021060576, 0.13239275634048447, 0.016121071643166004, 0.061542340404083656, 0.042037037051012444, 0.05443950258796254, 0.05596969043835998, 0.046924118763737144, 0.07923422937071131, 0.04951100233161161, 0.05784252643465035, 0.017860922436680526, 0.06806956273653815, 0.04681493208232907, 0.07757731908631903, 0.030426348281663754, 0.03866850631311536, 0.03347179867447384, 0.06957134787714289, 0.08643211571559792, 0.04356573486039716, 0.06813348511294012, 0.036592013503034274, 0.05370322314481582, 0.0496152860503043, 0.07299814343212113, 0.029890314645824895, 0.04743167882665031, 0.051035184052682696, 0.024384030876981638, 0.039343192287149935, 0.02844115208473898, 0.04897602015144883, 0.12423791126498293, 0.08798823181179263, 0.06010439720064883, 0.03155972748514145, 0.036725780115492886, 0.029302729038341396, 0.06549094142692705, 0.07264208108667405, 0.0317042212437598, 0.031056367499273152, 0.01314989347461491, 0.07367645300203755, 0.014692701665954966, 0.0568506149424901, 0.024037265008495703, 0.0334432274253378, 0.03214091242801759, 0.04946668414519199, 0.09762474455900731, 0.015108763060021787, 0.02735888818278909, 12.55603644155687, 51.96371301527947, 28.32763783393368, 56.715146726177586, 48.257406603905466, 1.8866221774970333, 0.12028768613574006, 0.10253179818391801, 0.2539719364816143, 0.8274641308572985, 6.382418476766156, 11.960326471636373, 10.615298671107139, 2.73366843500445, 0.5990041479949029, 5.619585629432432, 41.30142827187815, 65.42451081737396, 62.35877844595141, 60.79033244040705, 60.349148165795114, 61.77216445246051, 62.248253899235884, 61.5919158535619, 62.204680288991625, 62.30908593823833, 61.250159740448005, 53.50024661710186, 47.395916831108835, 46.51658419639834, 50.71395174149544, 60.037955161063906, 60.265515388980994, 61.60936647845853, 56.9319635821927, 59.76027096471479, 59.22339262500886, 57.11557757469916, 53.079403754203554, 48.320321421469416, 45.33406411447833, 44.6418010803961, 42.99330734437512, 41.97048264165079, 41.15942278215962, 43.81311016698038, 44.95407665929487, 43.21187357748709, 42.12394145227248, 41.39926395108623, 41.92707377095377, 43.64619762666764, 43.98777331075361, 44.628151232196444, 47.32452577160251, 47.75511180200885, 51.952683310354914, 54.97475185701924, 57.8356659027838, 57.92037733139531, 52.07857962577574, 60.951220220135106, 59.345331268925825, 59.407606740151685, 55.955077678926536, 59.34622949169528, 57.77735594780215, 57.726361213191865, 55.10574333129391, 55.06538214222078, 46.04659795761109, 40.490133070176654, 41.55154212828606, 40.95369446662165, 41.658552231327185, 40.77065706253052, 42.313631196175855, 40.99278480775895, 49.390406762399984, 56.449488516776796, 55.68317505621142, 55.33575504056869, 52.289450168609626, 48.67425257159818, 41.68054888325353, 39.072584567531464, 40.160599062519694, 44.53506162089687, 51.298443732723115, 52.4064701603305, 54.3079097040238, 51.855337927418375, 52.29538471468034, 54.226089062229285, 55.040051475647964, 52.37675036153486, 45.91358646269768, 46.40152538976362, 50.8530350654356, 53.69007756633144, 55.2644581179465, 52.55062903127363, 53.035433984571895, 53.70608475900466, 54.34578411040768, 48.639927910220244, 23.03270874484893, 0.5996205729822959, 1.1653071281410035, 1.636996288453379, 4.212823644761117, 7.281834137055182, 28.27419750152096, 20.78031316880257, 2.459877436199496, 0.4079500934289348, 0.08522360435416622, 0.03634586179208371, 10.267038287655001, 61.56515744424636, 18.471280528653054, 37.5256762966033, 23.23171215672647, 0.14666600092764825, 0.06616991749333759, 0.01607986568893877, 0.026232375042332758, 0.04873164193404298, 0.06663287974773877, 0.04651059982396903, 0.04758602639119472, 0.05259862394943353, 0.029872033872731754, 0.02001292661823813, 0.015919068621681826, 0.1087622457153855, 0.034898036054425666, 0.06298542788793003, 0.013989183015280194, 0.02751720216756146, 0.04570259156847193, 0.05679878143353328, 0.03001350732970863, 0.04140963019322484, 0.057129405829454624, 0.013302106526680292, 0.08667214638403348, 0.15978127297374511, 0.2918848004792967, 0.09029163603460597, 0.24459073019604533, 0.13468869120603608, 0.2685540217545725, 0.07795560564244948, 0.09106764479750588, 0.20478889255994753, 0.32128161660605864, 0.1927623693500796, 0.14348270641940256, 0.18845925347939615, 0.14187454997051147, 0.21194363283293866, 0.1234791164977416, 0.10920281521975995, 0.22293756145142743, 0.178162066506282, 0.1276209555386055, 0.1142472590530111, 0.20863264678947388, 0.09540734902745295, 0.1364268221321606, 0.1761423063374335, 0.267238587501549, 0.1834343142446972, 0.15984962333834943, 0.23114115270155094, 14.313305347196518, 61.89909235123665, 37.2642973930605, 56.02183249688918, 56.61405547972649, 4.602069854736328, 0.6978742297618621, 1.7292014052790983, 1.0500088117776378, 7.477798202345449, 13.04194652265118, 18.04076510090982, 14.096163915049646, 1.4758795403665113, 0.3593249913425215, 4.249109491225212, 42.226597724422334, 67.5837952090848, 66.17247935264342, 64.98920225328015, 64.43599900891705, 64.92469887579641, 64.73304010206654, 64.72042968196254, 67.70649479281518, 63.013735817324736, 62.93086398032404, 54.46654604327295, 50.05554268437047, 50.462680785886704, 53.47820681910361, 61.963340774659194, 63.02409087457965, 63.47972123853622, 59.52537198220531, 60.46877261131041, 62.65086950794343, 60.113276435482895, 57.58825455942462, 50.698372087171, 47.87851349000008, 47.23687648773194, 45.113842641153646, 44.64839458465577, 44.6790361404419, 44.62471915829567, 48.50855988840903, 45.29577393685618, 44.44402733156758, 45.24037438054239, 44.97162142107564, 47.837732607318515, 47.29211522686867, 48.53081149439658, 49.02247667312623, 49.833952303855654, 56.413641975772, 58.66021871566773, 60.43253383328838, 60.88326907926991, 54.10620574028262, 61.5112405438577, 61.64808027205929, 61.86075902754261, 58.33860397338868, 61.47193447236092, 59.371364039759484, 59.242729909958385, 56.33584960814446, 58.01520455268122, 45.47153534427766, 43.05345296859742, 44.33846066074987, 43.35018419450329, 42.95773929165256, 43.02305852213214, 42.412431778446326, 43.60010585477276, 52.81948004999469, 59.13396258508006, 58.160720563703975, 57.78395337443198, 56.66455599569506, 52.5414663745511, 44.60010236309421, 40.50700710665795, 42.46936498149749, 46.743909082105084, 54.2570444076292, 55.85790880264775, 57.24396067280924, 52.36202186153781, 52.82544989739695, 53.95504151621173, 57.82920183673982, 54.81430338275049, 48.46949700386294, 49.22705181183354, 53.66704148630942, 55.84319991450156, 57.257661511821134, 53.40106948729485, 55.04763341719105, 56.5026758563134, 53.81447553634644, 49.6763357808513, 22.02552253200162, 0.8030108494624015, 1.2543522854966502, 3.4577541485909498, 5.495230315193053, 12.73278138329906, 24.10519457632496, 20.03423913832634, 10.894149772582516, 1.3047277759159766, 0.4607718558080735, 0.23347986591679437, 14.890042812593522, 61.296494699293575, 23.601303369768207, 49.76391053968861, 26.304904876216767, 0.18918709829449656, 0.17718754137956327, 0.16806214717367005, 0.10862464100242623, 0.16770107461319816, 0.12057054878002214, 0.14354351847883196, 0.17283728045801963, 0.25702108899431847, 0.1368609028718164, 0.22683769975218082, 0.12169916483183062, 0.23212122430484142, 0.16547390379972998, 0.18562566278682602, 0.15859518500585712, 0.22298706605309443, 0.19520491812257998, 0.19791434128438273, 0.14223884010026533, 0.15793717676593413, 0.14057140376779342, 0.21918132510637084], [0.031569625341123154, 0.0517374377006725, 0.03986275694783657, 0.05507075137669041, 0.026297921525134195, 0.007895805850444783, 0.013982113938958896, 0.06258538443475001, 0.04739323653460992, 0.11613264739994081, 0.06150246935806448, 0.058874872047454126, 0.06784224146676641, 0.0318899764979799, 0.018338078385098808, 0.01588112428679221, 0.0641145074229327, 0.028103613745301004, 0.02062347762647175, 0.01812118357197652, 0.05051470774736616, 0.016555556494201866, 0.028981929720048944, 0.05961545307429568, 0.015210965892390139, 0.028728588273929014, 0.02256596059117827, 0.0699243918361683, 0.016112937704629956, 0.022217417398708004, 0.3580395570926128, 28.917948661311982, 40.173201637883345, 27.62655338933391, 54.79244009140999, 19.417921035520493, 0.044910345572016896, 0.04407359369760079, 0.06394547778331945, 0.4963577430575125, 6.717454589182331, 5.037090124622469, 9.552772718091166, 6.673070519201218, 1.3924634745044093, 0.04173215703978654, 5.374613019727892, 51.63730905902002, 58.95253335275958, 62.69381553896012, 62.3370445928266, 61.7649394466031, 61.32248824642551, 59.70972730267433, 61.49339768194384, 60.10338814027848, 55.181017537270826, 48.370064919994725, 45.225355625152595, 47.50766515731812, 58.282576837847316, 60.79062661816997, 59.600061755026545, 55.99245786666871, 57.26944823418894, 56.53642785164618, 57.2785363658782, 54.49692480025753, 49.89994618200487, 49.90218977774344, 45.5568939639676, 42.474405227168916, 40.438451920786214, 40.362930605488444, 39.731083839170395, 40.68671049610261, 42.01753147186772, 41.49169068182669, 41.41778930541008, 42.800146302869244, 42.490486944875414, 43.48987940819033, 44.060450907676454, 46.36426287312662, 46.552395436071585, 48.2128563234883, 51.62534190762428, 54.50451850891114, 55.72009240427325, 54.9276206570287, 53.06689139335386, 55.97485426933535, 53.996708854552246, 52.68844150727796, 50.762243963057, 54.365827421988214, 55.194796823686175, 54.12414273908062, 53.105181570976015, 45.216553826485914, 38.831719659989886, 40.823538457193685, 38.783894200478834, 39.746824310671904, 39.21004403022028, 39.70478434716502, 39.889649575756444, 50.217007052513864, 53.716043656872166, 54.106323411387784, 54.508276139536214, 56.67762141073904, 51.32397444017472, 46.6220724198126, 40.504516401598536, 39.721136708413404, 37.147085205201186, 46.47719967749811, 51.640921561948716, 53.12615448428739, 51.02636068098007, 53.571688667420425, 53.5334377135, 53.852695111305486, 52.362845559274, 49.949795584524836, 46.86175669393232, 42.14997814547631, 47.53760460884341, 46.31783377739691, 44.853142307650664, 50.76233025520079, 51.71955331679314, 54.20406495371173, 50.93546367460682, 33.02957711681243, 5.314019264713411, 0.12502945629098725, 1.1168515153469578, 2.215179147258882, 4.490120997351985, 6.307948846970835, 3.5629499102792437, 2.6978635691827346, 1.5485573824374907, 0.004595725068582162, 0.027971641693805015, 0.19757225238267453, 26.724496503030103, 36.34464671534877, 22.90817545306298, 39.05638910108997, 4.39872928204075, 0.09333994585059344, 0.06290580836995956, 0.014586404093631334, 0.026429211758377574, 0.04518209611095729, 0.008602821692493896, 0.03466353654080341, 0.010875802648614251, 0.0028637489407218153, 0.02182159317477096, 0.038307552496271755, 0.034578562068242225, 0.021390791291431076, 0.034138605434207187, 0.028702340186423356, 0.017038195716938185, 0.04664959881695048, 0.018508912161773732, 0.07290185384091831, 0.0245078019572482, 0.04650253674856598, 0.045097960504673185, 0.029385569956033464, 0.023838212383129907, 0.05186455850038798, 0.015983604826033115, 0.04846794297918678, 0.034115871775054166, 0.05997507772859066, 0.05459877226742045, 0.022449065150032123, 0.03875126679157538, 0.06254378203002196, 0.03179891354164049, 0.06478967986279918, 0.04707987976050185, 0.014072369630148095, 0.007320115194400593, 0.023937794237187313, 0.031213974767935374, 0.049219410115432356, 0.004476487792412481, 0.059585862928220344, 0.017392294962079297, 0.0579139105074348, 0.05296246591775168, 0.0453365164538545, 0.05488357311415096, 0.03208504929657906, 0.003773350988687467, 0.06761616892031125, 0.02349010586077648, 0.06832067869723805, 0.6595185975874625, 39.127991968585604, 40.98000572573754, 34.09761105814288, 66.8226122087048, 17.117966721134803, 0.09823003062798132, 0.14067019846650863, 0.10550680104643108, 0.14328640404968493, 1.0355356335639954, 12.233455815622884, 15.988055429150982, 6.249318238227598, 3.985861578295308, 0.0852805859739742, 8.757954412891019, 56.87156300390921, 59.81183444300006, 64.4880174821423, 62.74449256158645, 64.29945738084855, 63.66295476113597, 62.34196324502269, 62.905682363817775, 59.881652632067286, 58.49998989412862, 49.39312104255923, 46.79724939407841, 47.62079808019823, 59.49136895518149, 61.658294123988, 62.15065356223815, 57.13483248987506, 57.81638745338687, 58.08610139354583, 57.699277247152025, 55.47982369699786, 51.759177100273874, 51.65515584330405, 47.984888169073294, 43.754929650214414, 43.837577912115286, 42.77760051911877, 42.162604255061, 41.72930394449542, 43.323147296905525, 44.77984497624059, 43.339389831789084, 44.996030330657966, 42.24678224132907, 45.244292828344534, 47.50651590285763, 48.70012452525478, 46.39922688084264, 48.56619519572104, 53.08252596086072, 56.33678313224547, 56.79593186224661, 55.588587099506015, 55.509182637737645, 57.63255380815076, 56.334159066600186, 53.6561922104128, 53.2538237110261, 55.63910722732545, 55.59710256515011, 57.87663505923364, 55.65850334782755, 49.30860181008616, 42.00155958052605, 41.84152687749555, 41.736838817596436, 41.85422358974334, 40.899397096326275, 41.991424176000784, 41.56833771736392, 50.92747772893598, 55.53925152747862, 55.516242904047814, 55.730714182699884, 57.689345805875725, 52.76078962510633, 49.2123782250189, 43.226523630080685, 41.700607884314756, 39.68727096434563, 49.197218264302904, 53.33561689622941, 54.800586854257894, 52.81293753654727, 53.93624551834599, 53.36478364083075, 53.308140693172334, 53.22510803899458, 52.167566437875074, 49.534345980613466, 44.310223517879365, 49.12095169867239, 49.86166777149324, 48.55295327401931, 51.99695902486002, 53.14357373022264, 55.77860240013369, 51.36588888783609, 37.193459387748476, 7.087875873811784, 0.5431554190093472, 1.3633756676027853, 2.7757633116937455, 5.19694681129148, 7.516630157347649, 7.43467664526355, 2.6256059110164642, 0.6278173889844649, 0.05024724347036212, 0.15663104282031137, 0.07753359844848033, 29.14300641705913, 44.09011187091951, 19.643871130481845, 46.68208076107887, 7.090879428771235, 0.14779201228051417, 0.04471008635817036, 0.007466561998420906, 0.09077206509368074, 0.07288732881387396, 0.03937075613066554, 0.06130690243275416, 0.07336650148875291, 0.03539482109068382, 0.01715423122438933, 0.03538732492034474, 0.04549643730804805, 0.01477061089263448, 0.015383599018077216, 0.02150680956190392, 0.03539105576853599, 0.004120389536593951, 0.04252120078871808, 0.032399620320047104, 0.046463113863982504, 0.06895601839548157, 0.060213369377438104, 0.03917289094158238, 0.12685096822679043, 0.10961025908228852, 0.09627185626736573, 0.1965376046756583, 0.10289946676141794, 0.11333060420809254, 0.12886015638228387, 0.11714784413455956, 0.09627094462273583, 0.19751940763765768, 0.18371392101530107, 0.2726272806044548, 0.09846505874227132, 0.11416918703264768, 0.1003453219609876, 0.09828469100137872, 0.1585562217740282, 0.1300905089104368, 0.15510015399946323, 0.16170364804565907, 0.15195755408175532, 0.16235398008458077, 0.11782456790247273, 0.16044816783358976, 0.11916301543674163, 0.09615774747104415, 0.1392370318212817, 0.14456969325340566, 0.11326587743937008, 0.213834720874025, 1.0366863589132986, 44.30208459977181, 52.62604444257675, 38.35634408458587, 67.43793795185705, 27.63707906969132, 0.2839486811670565, 0.7755863726619752, 0.37301213270233524, 2.3595262919702837, 16.822649509676044, 12.786005985352302, 15.152333667201383, 14.188978960437161, 3.7605150380442223, 0.19937928525670884, 7.574654759899263, 55.01413637591947, 63.33064371539701, 67.46356671856296, 65.46127911536925, 66.18332862854004, 66.40662131770965, 62.50673809359151, 66.15573083200763, 62.416472588816, 60.87227075330673, 53.827701768567486, 48.23457840950259, 50.55132635178105, 62.337409373252626, 63.72382210146997, 64.50003562435028, 57.783408164978034, 59.447132464378114, 60.413879040748846, 58.69673990434217, 58.5190212342047, 54.081412438423406, 54.591104830465014, 51.68713884968912, 46.746046773849, 45.940890081467174, 45.60464097607521, 45.89900701276718, 43.52041113761164, 45.96314953219506, 47.05631409921954, 45.59025764465333, 47.95576457054385, 44.69679271021197, 48.72161911379907, 49.27900752713604, 51.22211048679968, 48.90811997075235, 51.46913743788197, 53.65002232213175, 58.94631639603646, 61.107126589744325, 57.51398055784164, 56.67416188024706, 58.16757294439501, 58.85796108553487, 56.03500773829799, 53.540329317892756, 58.74661676345333, 58.1812894728876, 59.22964880543371, 57.37901572258242, 51.5613837395945, 44.14260887330578, 44.55328495271745, 44.71748321287094, 44.34969040655321, 43.65540342946207, 42.87308277622346, 44.809572619776574, 54.52607585537819, 56.76049717010991, 57.44215019287602, 56.318952037442116, 60.33936577458536, 54.5144695620383, 50.506980034612845, 44.82580730991979, 44.93499825077672, 40.79370098729288, 51.88430463114093, 57.088183741415705, 56.25568420656266, 54.874837321619836, 58.356297785235995, 55.370083624316806, 54.166539638273186, 53.75903283396075, 54.17523553294521, 51.23952581036476, 46.84252531297746, 52.641380909950506, 50.53061231490105, 49.86957526976063, 55.04067513250536, 54.407082911460634, 56.654730458413404, 52.33661274756155, 36.66446893445907, 6.563915860268378, 0.589156547381032, 2.9061779524049456, 8.262607109162117, 11.811234239609012, 17.947587236281365, 6.6960364868564, 8.330378801591936, 5.003443052691798, 0.28984982580427204, 0.4628284648060799, 0.590439468862549, 36.68064871141988, 46.673553528324256, 29.885262020172615, 53.76896819760723, 7.760671694432536, 0.3401693611616089, 0.25272391796592747, 0.13086451818385433, 0.15442077190645281, 0.15757428091620246, 0.13098609633743763, 0.17332845006979283, 0.20062932624451577, 0.11368989944458009, 0.11130046354787004, 0.1342610915702197, 0.1453182530859786, 0.12740853467896102, 0.1156498128247838, 0.1413489983326966, 0.14035919741276773, 0.08838121193431078, 0.07882169102348628, 0.19808102669494768, 0.11317144178094403, 0.12797185445144293, 0.2310783641352769, 0.11404576260716685], [0.03278095207567657, 0.08406223038271551, 0.014361471102963534, 0.0564113631093454, 0.04408901121707694, 0.02507832870187779, 0.04883895553047619, 0.051031445543612206, 0.015436895754969409, 0.01480093073745769, 0.08346393103561095, 0.03689278728298603, 0.01455768728778968, 0.03561895926513019, 0.022337593611389883, 0.041322123800073905, 0.08762926599311252, 0.06884112818947724, 0.050395573414261305, 0.05490733716156214, 0.03869947924789402, 0.014211798589977046, 0.020312355913882776, 0.05499321178743436, 0.028010934343441363, 0.0381570813366242, 0.16642290287681166, 0.00942295041656302, 0.03472116167446779, 0.03512414690527705, 0.17429707631949456, 5.739481208785888, 42.41561282065607, 28.581073937877534, 40.22210182682161, 43.99639075802219, 3.760417469086186, 0.28328368620526406, 0.3156949357400018, 0.06112493356809982, 0.8911469362435803, 13.761718119344405, 15.760512851899671, 5.643280177347122, 4.334686292755989, 1.0263394528338987, 0.033653035925160495, 12.760841038919265, 49.07217702557964, 57.84200445298226, 60.72751568209741, 61.47095780218802, 62.851522276478434, 64.0307044213818, 59.127631879621944, 58.42056189813922, 53.28071155855733, 46.23438535198089, 45.290321842316665, 52.49755544047202, 60.10879316637593, 59.476012875956876, 56.609995826598144, 59.89756568785637, 57.887723599710775, 60.439499962714414, 57.59387923825172, 55.60937958378946, 55.35336648264239, 51.79616112862864, 48.405966374181936, 43.320385948304214, 43.25608261169926, 42.80468448515862, 40.23766186929519, 41.06235588750532, 40.63345647627308, 41.79306599401659, 42.6234160700152, 43.200671288274954, 43.66578202093802, 49.807295876164595, 49.562371315494666, 49.98401434190812, 51.5598108691554, 51.05008709815241, 50.15618285825176, 55.47137491164669, 57.53844045823621, 57.243913604367165, 57.195844957905436, 56.857399325216974, 54.70189217598208, 50.1925196955281, 45.41877946546001, 46.6529179388477, 47.473003172105365, 46.930068692853375, 43.5907902256135, 40.391724724923414, 39.49760867703346, 39.314155501704064, 39.18511736777521, 39.086575661936116, 41.48886657530262, 40.52024902835969, 49.16044996630762, 52.95160116687898, 55.676691378316576, 55.86377666842554, 55.90131767334477, 54.4993802039854, 49.991800246700166, 48.03789507958197, 42.941253569818315, 40.39761612492223, 38.007445335388184, 46.28680390696372, 53.81247904992873, 50.90987413160263, 51.835753533148, 53.04599692744594, 53.11354014181322, 51.97832384417134, 53.8980180986466, 51.816314266574004, 47.94446422207741, 45.47090776505009, 43.85453039600004, 47.06087973810012, 50.23991761669036, 48.151788942275516, 49.477401010451786, 51.44497955999067, 44.4063804226537, 18.34592746150109, 1.4471088325785053, 0.806566478023606, 1.5362591584843974, 1.0139763259118604, 2.9400505606205236, 8.584117908631603, 10.393439608235514, 2.4126346938071714, 0.07857255923051028, 0.08912533611780213, 0.0885446721147145, 6.373059211238739, 45.3365195182062, 22.44678116613819, 32.09357996140757, 24.017509991122832, 0.1339755552790819, 0.04934979061926565, 0.031127232547488906, 0.07687361370171271, 0.05424107815469465, 0.012430711198718318, 0.03870803645000823, 0.12588064892277603, 0.04835683724752838, 0.03142048717446385, 0.04358492153246076, 0.060151186020624255, 0.08588120656748933, 0.006499632633471441, 0.049518487010631836, 0.03797012140914317, 0.01356052139007877, 0.03348373432433413, 0.040449124475520466, 0.00947896197753688, 0.05353018686535859, 0.04396664016249199, 0.009608660663117566, 0.02753058380837883, 0.033328268271420276, 0.03543291481271867, 0.04420081025830681, 0.06031213343263634, 0.029242688812495723, 0.01949470069619917, 0.03149399139557875, 0.024240521541345986, 0.06613507581454131, 0.054687316709708785, 0.04448319409763621, 0.03720137899020507, 0.03419480947477203, 0.03139196572104289, 0.056248963960716804, 0.05070930557145227, 0.019080543988234094, 0.062463181919508406, 0.015349175814809579, 0.06373423286863873, 0.0385231870947586, 0.030339154069341963, 0.004698214705117168, 0.05642659676771972, 0.06415135242165097, 0.0237831230004949, 0.09970714007654499, 0.0835076823169666, 0.03834059003800635, 0.03633992078023092, 0.21356317334838454, 11.213197323583788, 52.016311999290224, 26.44075812832002, 53.35847254722349, 49.19169948947046, 1.8311934485550851, 0.15552137978374958, 0.255037518819013, 0.09580139401218585, 0.4998146382070357, 6.158858085832288, 8.062698610367315, 4.463612148838659, 4.318449151131415, 2.105430494393072, 0.11617684301229254, 16.716890642719886, 54.412091778170684, 59.87239191609045, 62.648257209408676, 63.257679785451586, 65.48669215171569, 66.53377671395579, 61.73074030107068, 60.32572769349622, 54.42731057443927, 48.72341948170816, 47.82888374020977, 54.59731394244779, 62.31733076034054, 61.95151482858966, 57.76984460892216, 59.99982580061882, 58.38586853396509, 60.945426879390595, 60.16508310071884, 57.5061515069777, 54.651470107416955, 52.328658180852095, 49.94723427680231, 45.672933363145404, 44.00480031967164, 44.65991458585186, 41.73561503810268, 43.59337506755706, 42.55362533753918, 44.29372602893461, 43.02024618271859, 44.06635799715596, 45.0694453331732, 50.82882619673207, 52.16223985918107, 51.24261271569037, 52.292450781791445, 52.07000140220889, 53.48098777955579, 57.39194777704055, 61.12244736763739, 57.75890904088175, 57.28322752060429, 59.74372640732796, 56.68470913364042, 51.705436706542976, 49.70017986912882, 50.32811995475523, 51.19824286430113, 50.116488472107925, 47.172973232884566, 42.31544333119547, 40.94982308726157, 40.19917557316442, 40.83921224840226, 40.45945621305897, 40.93098002095377, 40.25290812215498, 49.94260587999898, 55.614058971405036, 56.64004510448825, 57.501758452384706, 56.9688730855142, 55.943314490779755, 52.371894467261534, 50.25324190816572, 45.345842992105794, 42.27700018113659, 40.582285235005045, 48.84638578661027, 55.369640396487334, 54.60437813112813, 53.490946677423295, 54.07335589008947, 53.254278705966094, 53.10649556498374, 53.81957853994062, 53.99599498318088, 48.65272268172234, 45.84520386111352, 44.83948069234049, 49.2358418433897, 51.26338166575278, 51.26967706987935, 51.372447090764204, 53.41438201165969, 45.698801394431825, 21.10926470448894, 1.827013427692075, 1.7325154403525016, 2.836113879757543, 2.6783784599073472, 5.451729759093254, 5.797517578448019, 4.605039088956771, 1.6801117168318842, 0.08520310384131248, 0.012125216401933182, 0.05793421183742824, 5.650408594839035, 52.97191904437158, 24.17631499228939, 29.944232894528298, 32.98529747993716, 0.22562622363048218, 0.05214349494405812, 0.07553861356310307, 0.05897039172029304, 0.052777593579864314, 0.04995258307204612, 0.022838469557163697, 0.02454147535195995, 0.10432613698104698, 0.0373442773707211, 0.04552631473709499, 0.08165685219630119, 0.02449173709347604, 0.026346811341241966, 0.03408881354956858, 0.03115988704526136, 0.058734302574227897, 0.043742720323104056, 0.010706645646883596, 0.03650389806998353, 0.05201990197923395, 0.013206124328257096, 0.029455906403581464, 0.1056887852328439, 0.14448926934311468, 0.19892628214532332, 0.11594856413261545, 0.21042777465716486, 0.15008361108841436, 0.14204403926287928, 0.1355498199982028, 0.17757397145032885, 0.11096651816079695, 0.13527614274813285, 0.2009527532443885, 0.1337889822260026, 0.1722993181958314, 0.15553216630172345, 0.14185596467746844, 0.15054090429217587, 0.12839046787590752, 0.22805997771361183, 0.10439243423001421, 0.1262427940063419, 0.13472469733847728, 0.09156475925157148, 0.1384154944530418, 0.10902374982833864, 0.15346699244072362, 0.10931905374051103, 0.2752990582056584, 0.17662946164848345, 0.14523776788865367, 0.14874194598486348, 0.47293917065666574, 14.90258361062696, 60.59859129690356, 39.65599790696175, 52.687256951485914, 56.80865995345577, 6.244140709600141, 0.8135289302276028, 1.0215758568336888, 0.2972396018524324, 5.346317531601076, 28.73841589496982, 25.78463189063534, 15.142690520132742, 10.271455857061571, 2.978133588067947, 0.17807434943895187, 15.792592936946502, 53.230477763760476, 59.666934244094364, 64.1252492320153, 66.99691449442219, 66.8654994041689, 69.53545678046443, 64.71508349141767, 62.282786446232954, 57.95114048065678, 50.81848290658767, 51.99546460182437, 57.56652462866999, 65.93002980755222, 63.99852529648812, 58.1028106904799, 60.718364792485396, 60.090334492345015, 62.448283010913485, 61.665468139033166, 60.389670172045314, 59.83754557947959, 55.12791256750784, 53.76119013755552, 48.104422400074625, 47.99522361447735, 46.9220749024422, 44.03529674776139, 46.39977601266677, 44.8608026965972, 46.099989260396654, 45.92801294019146, 46.38819325354792, 47.97494496068647, 55.21505978799636, 54.44047404873756, 55.087115995345584, 55.48638974466632, 55.12700649999804, 54.74486566358998, 60.86532031336139, 63.41908924041256, 61.64758997578775, 59.820808825954316, 61.74541781025549, 58.69454337704567, 53.22788899944675, 51.58706741948282, 51.572515426143525, 52.4198728992093, 51.95335011328421, 46.582311353375836, 44.70750862552274, 42.150221332426995, 42.236795886870354, 44.29052929724417, 42.433651801078554, 45.00210608205488, 42.8758833485265, 52.66247541673722, 56.51985191529798, 59.9562757245956, 58.136335188342684, 57.94333496401387, 57.98726550994381, 55.05248931146438, 53.131924290810865, 47.34368654989427, 45.524832510179095, 41.54302274027179, 50.38588470028293, 57.737053594281605, 55.65586359270158, 54.72231595746933, 54.88932655703638, 54.28228878205823, 54.51865473101216, 57.6267251660747, 57.5142982698256, 51.228288219821074, 50.844092061442716, 47.140597989482266, 50.86487277861565, 54.6395343349826, 51.842860867900235, 53.27920929078133, 54.08435029368247, 47.689941621595814, 22.032288620548865, 1.959568089054477, 2.8668740872413885, 5.301615749636005, 4.321869457921674, 10.03852492378604, 18.253434050467707, 20.283835241871497, 8.260412543050705, 0.18996719030603287, 0.23770222079850015, 0.23328063709120597, 10.715760377145584, 58.54624640557074, 30.631498829010997, 43.46614122390748, 37.42945663390621, 0.3137513706761022, 0.10594753909014887, 0.17858978871616626, 0.13174617813239176, 0.1104771641774043, 0.1452831049720126, 0.17427539603123743, 0.14873120543216506, 0.15564236038875195, 0.10581988585932602, 0.2501057358759065, 0.16166099227003514, 0.19625116440076984, 0.1753074696828281, 0.13785986620331966, 0.11049227909215036, 0.12704592228176134, 0.1935628086568848, 0.11186772867316201, 0.12099793391121973, 0.14980403496132744, 0.16616980274838788, 0.06720419747815018, 0.182053578657008], [0.047176337891048005, 0.029308719845909267, 0.06771845697996116, 0.02496937950772624, 0.042555291701348565, 0.03519833102942475, 0.030501547472311125, 0.035973742243743716, 0.04930994638632383, 0.07897902250049577, 0.0987328677588413, 0.10345465068014399, 0.01242704067995111, 0.012523509344206223, 0.08278257243575589, 0.023775004383717335, 0.02969500052952959, 0.08863826507642385, 0.056260535718813065, 0.020821858009683992, 0.07627959678610487, 0.01720094726601195, 0.05102460054800876, 0.02750144565417882, 0.017134199940389203, 0.07181583227769983, 0.02086555183444533, 0.058260013709866235, 0.08862375537113798, 0.03139531927093143, 0.057123660170022524, 0.6238166326957365, 24.66485208080661, 41.244655886004054, 27.292010514966904, 51.25698820237191, 28.004685563425866, 0.89423488344877, 0.017105770417519154, 0.05945187415026369, 0.11570608964370144, 4.903359365078711, 6.622998031877703, 1.5333844288702936, 3.2577323913574223, 1.3320424263515782, 0.3935840143071067, 0.16268417930170415, 15.500488146658867, 46.87780703267744, 58.488960189204064, 56.75883408515685, 62.94435693371681, 58.8224361788842, 60.109499193006954, 54.980541275393584, 51.675140319332, 48.90786109432098, 50.84544920152234, 57.640072991771085, 61.346234275448715, 59.684318188698064, 55.4656639406758, 56.76569431058822, 54.83422902322585, 61.791242860978656, 55.503761922159505, 55.828895030483125, 54.1430877870129, 55.67747977472121, 51.52954193853563, 45.96366336268764, 42.22278518061484, 43.50072868408696, 41.09878686166579, 41.78500160094231, 40.44411190094487, 42.4206805229187, 41.584352754777484, 43.64003950549711, 46.879242620160504, 51.03773555447979, 50.39852649934831, 52.2747883489055, 51.8375382115764, 50.15175842469739, 54.31161634383663, 56.06828512683992, 54.94933489830264, 56.52064815644295, 57.34142372685095, 56.39014697843983, 53.663503508413996, 52.161926069567286, 45.50025886104953, 41.91609113447128, 41.608600847182736, 40.537358407051336, 40.229487649856075, 39.587960473952755, 38.09121931752851, 41.07469174169725, 39.36716241221274, 38.80273334441647, 39.27888162674443, 50.44282967044462, 54.64363713418284, 56.08923058356009, 56.182496701517415, 55.8682873941237, 57.90786497054562, 54.28556788352228, 50.421711629436864, 47.936290002638295, 43.26947358346755, 40.153232851336085, 40.079904140964636, 50.78193426132203, 52.736117916722456, 49.356725369730306, 53.32203372832268, 52.49052655312323, 53.57543845330515, 54.639883425927934, 52.02869099955405, 51.58706741948282, 48.461805235955026, 44.21108953414425, 45.99666226294733, 47.76416463236655, 46.45659154461276, 50.80122840019965, 51.44294777224141, 49.369418159607925, 30.149363048614997, 7.406693475861704, 0.19549399373992798, 1.332461997385948, 1.400718715402388, 1.312634906461162, 2.3716258233593357, 2.4469610712220593, 3.422775677134914, 1.2440479739058403, 0.2883645038931601, 0.05069631655069609, 1.2101910551709514, 29.02711214557771, 37.663355412021765, 19.821440750552764, 42.43695835913382, 7.563681929342209, 0.07105292361830512, 0.011568559679172693, 0.030314886319120566, 0.03201314236878628, 0.04937845379895261, 0.04307246999815107, 0.0224602289663087, 0.05735511065370614, 0.1163649865456166, 0.04533537881328695, 0.02816830795528668, 0.020626180001624653, 0.06924789023375319, 0.01609852376033462, 0.04083000423927461, 0.07499889695956823, 0.035540787653336604, 0.050950719028591156, 0.016285550720509023, 0.007603767388049634, 0.03994139204282434, 0.020170650715308807, 0.0609602936122927, 0.06389006281331663, 0.04781648479101639, 0.0702399740956964, 0.031464372521206256, 0.02957916228971895, 0.052319269987844655, 0.0547608228460435, 0.061477464248215964, 0.06572258343259174, 0.020599481837463476, 0.1087600470430428, 0.05769401646008896, 0.038704650341382915, 0.11445533619412493, 0.030665294935686455, 0.052815748588933106, 0.03721645943099453, 0.03605577876911529, 0.06032121540497869, 0.056255134798946886, 0.04466286469851771, 0.008545271252402136, 0.03981020331623093, 0.038644581387240085, 0.03659642616947813, 0.01656936522903702, 0.014425451893569722, 0.0025287116389541378, 0.02831791152035998, 0.02118663077483014, 0.008529737862127443, 0.10362623139254509, 0.8261280122303194, 36.373542816408225, 41.090510660602206, 29.594381009378743, 65.8159202144992, 26.387007928663685, 0.5939776919061138, 0.13664250652636253, 0.05652446450004655, 0.08201824651370127, 1.0696622152482311, 5.37012827973212, 4.698322857579877, 4.931347927739544, 3.264781871149617, 0.7096854669432486, 0.50024438288904, 19.990039910039595, 51.165765639274355, 58.56341461981497, 59.926634373203406, 65.85681484591576, 61.971809171861224, 64.22393998792096, 57.613914705091915, 52.824084912576986, 50.4573973532646, 52.15614841830347, 60.64177267013058, 63.63058736247402, 59.5214339225523, 55.88576939798171, 58.48928966829854, 57.164736640068796, 63.73824857896375, 58.999233092031176, 57.811951252721975, 55.55436049738238, 55.879132747650154, 53.830376825025006, 47.514992144800004, 43.491413054927705, 44.54929197988203, 41.68986451241278, 43.23116771636471, 42.80209572084489, 43.211328368033136, 44.74912889542119, 44.05888980434787, 50.116190371974824, 52.496119852988954, 51.80087973994594, 53.45116992150584, 54.33400915515039, 53.092524082429954, 55.086582553002145, 57.93848691448089, 56.90112198552778, 56.29730447646111, 58.20000702334989, 56.879184169154016, 56.54508844498665, 52.26078940976051, 46.02829225601689, 43.460316504201586, 43.502889910051906, 42.39616570934173, 41.7861077093309, 40.61675502407936, 40.67418636814241, 41.24613069718884, 41.88203319426506, 40.73158241087391, 41.096911968723425, 50.16274890592022, 56.166183563970755, 57.1756878975899, 56.53667888333721, 57.090160615982555, 58.18458818620252, 54.584075943116225, 53.10906471744661, 49.480146669572406, 46.16791686704082, 42.33576513105824, 42.10312151139782, 51.483442321900405, 55.310855834714836, 52.25145024638022, 53.4005517344321, 52.392161353941894, 53.59940021268783, 53.75213730719782, 54.27638169257872, 53.082827983363984, 50.66068203218522, 46.58136213979414, 47.56926205850417, 48.32382017566312, 51.048616209337794, 51.94748224750642, 54.8927939322687, 51.11792449028262, 34.35852712200534, 8.711474326349075, 0.797206538338815, 3.022598066637593, 2.7263277192269606, 3.4493141885726684, 4.600822541021532, 3.4947016498734875, 1.761942654848099, 0.0667757245021001, 0.07478338876558889, 0.04374504539995425, 0.8041407372201643, 31.02004881828062, 47.48568811724263, 21.085199002296697, 45.31286370369696, 11.8894100189209, 0.10099638944431659, 0.0722014043299902, 0.046300362314908736, 0.08525352774848861, 0.029393611964018598, 0.037413665784462806, 0.05923794409740837, 0.06058042891503823, 0.022075528339032206, 0.03847542534311933, 0.06648446553416791, 0.08573903597050136, 0.055029003415256746, 0.02351116561781495, 0.040362250104907064, 0.0096304118145077, 0.057646993983296625, 0.014445965812962144, 0.0511036952957511, 0.03575313956506791, 0.046003855644695224, 0.04115916157682096, 0.03987184275061854, 0.09641516067448164, 0.10787530742104977, 0.1566810683617669, 0.1299614537387125, 0.08384139021678318, 0.12956371621018456, 0.1242395353713824, 0.12585211980847583, 0.12719947694530412, 0.08517610690286083, 0.26662620745839616, 0.1324824805581762, 0.16703359752653107, 0.1576230194299452, 0.10915076720618433, 0.11038796089950109, 0.1276332512497902, 0.10100142264197912, 0.15883245775776525, 0.2244139048120668, 0.14547140938380074, 0.11127333637447127, 0.14320873805592138, 0.18366605584179202, 0.13330807819241478, 0.14186881963283787, 0.11028641594513772, 0.11022892104642046, 0.19050892172080858, 0.1180276271676825, 0.13985405435725567, 0.37586875199790926, 1.4569858509686686, 44.274365209764056, 54.2111252200219, 40.048976252155924, 62.41714723648564, 38.50348395685996, 1.305840013007964, 0.2700617440765904, 0.17864601956980844, 0.25331746756790147, 10.434849050737197, 16.8442480410299, 8.842467761808827, 11.212366761699801, 5.1643274003459565, 0.9349077783765333, 0.6348292998248531, 17.83638019715586, 49.85636864939044, 59.5251876308072, 60.56428624737648, 68.2221217309275, 63.7676114420737, 65.97611765707693, 60.87050176435902, 54.9090168553014, 52.46859265911964, 56.116051750798384, 62.67305051126788, 66.77224897569226, 61.9130559890501, 56.162461234677224, 56.95587435076314, 59.17626926975866, 65.52131883559689, 59.714441991621456, 60.13894050352035, 58.900714920413115, 59.48921949632707, 56.72583518489715, 50.6519429914413, 46.039941695428666, 47.60865442214474, 43.69279146194459, 46.774158400873986, 44.688285089308216, 47.075721986832164, 47.25237769465293, 46.89603036449802, 52.91857088765791, 55.27646057067379, 55.494579653586115, 57.45361135851953, 55.968147016340694, 54.77879416558051, 59.15233888933736, 60.72573492603918, 59.56960062826834, 58.03441632178522, 57.53496523826354, 58.311637678454005, 58.261148929595954, 56.60653629610616, 48.94548054664366, 46.42032138762936, 44.316695428663685, 44.093665538295625, 43.302468561357074, 44.30425759284727, 42.37230200921336, 43.623910719348544, 43.028930310280096, 43.135650157928474, 43.585114555974165, 56.230737932266734, 58.43400386071975, 59.33489384189729, 57.77279423129175, 58.76248275080035, 61.32214700022052, 56.604739850567235, 53.90828294138755, 52.12352606558031, 48.38851967165547, 44.25958571895477, 44.234733581542976, 54.91346874544698, 58.12777265425652, 54.83519392628824, 54.50542065405077, 55.01910994129797, 53.82434029732981, 57.245694360425404, 56.105677081692605, 55.96939825242566, 52.05994052271689, 48.45166983142976, 49.989074199430405, 52.60295344937233, 51.845798723159305, 54.66433548158216, 55.78403488282235, 52.857872209241314, 32.88601836850567, 10.133966976596463, 0.6529982087592925, 4.351071994150839, 4.940562555866857, 7.583675720999318, 6.994598479040208, 8.705963396256971, 12.876027322584584, 1.9189671451045622, 0.5736064334069529, 0.1945146422592863, 2.0683802760416463, 39.76918966539445, 49.632636654761534, 29.71047728292404, 55.96839412566155, 12.76179809724131, 0.20916622702873525, 0.2786442577358215, 0.12721605508798553, 0.14157488701804993, 0.22444952790054584, 0.1869046465764123, 0.1482721655479362, 0.21456513974455096, 0.17906131583356089, 0.14907352416025055, 0.1415208318541127, 0.18088103512362128, 0.18691802247157022, 0.08190331800330071, 0.26067474616631386, 0.2585893629058715, 0.18185928343765198, 0.10449484486373202, 0.11826023444413178, 0.09206614081537531, 0.1573329632200541, 0.13395641840273334, 0.10490210486515876, 0.21539010918669163], [0.07100266825047231, 0.014808093659549713, 0.015034174824494028, 0.05229869669663811, 0.0028419951559044425, 0.015116517785035316, 0.046124200396720445, 0.018463278219344157, 0.010852290452608179, 0.01257701100961816, 0.026222048177113457, 0.02913938760156593, 0.025110843388604063, 0.02964196043209203, 0.05446308660471151, 0.043148316533094457, 0.016379894448384162, 0.030805935272045677, 0.05756780347456375, 0.08301377777130374, 0.06022944956296875, 0.0298125337388727, 0.023889295125920928, 0.03196255183748661, 0.030681442153910478, 0.02530372709095959, 0.04991021840983341, 0.09398847758289307, 0.07174833993157072, 0.044690003363235344, 0.014244646524950383, 0.06453074214439239, 7.710294242828124, 43.931585358035186, 37.435010710070216, 33.925011081080285, 51.410333264258604, 18.389367711159494, 0.8125024336961009, 0.09463698633255498, 0.04734447120778984, 0.23041189828466987, 2.7502083345766994, 2.1717732183394896, 1.9892131176687058, 2.85948924479946, 0.34353365160284505, 0.1036358074915986, 1.3443014266029483, 22.084860147968417, 47.207772501053356, 62.47171917269307, 61.99834400607694, 64.6417155573445, 60.950133723597375, 55.49567791723437, 53.40818466678743, 49.74218845367432, 52.3494702769864, 59.98770959915654, 60.27251681973858, 60.00597999941919, 57.360576660402366, 56.41385770613148, 57.45408596531038, 58.57062393619169, 60.501802890531486, 58.41431748482489, 55.82067766497212, 57.37831361832158, 54.69624396293394, 51.31584336680751, 44.33886466487762, 43.976123871341834, 41.58095205983808, 41.290155380002915, 41.64929543772052, 43.25641209079374, 41.45534599981001, 42.119340512060354, 48.96607299004832, 50.93046265263712, 53.56984515343943, 54.51011965351721, 57.278638347502685, 58.67083264935402, 55.5956865895179, 53.95413152633175, 58.16201494586084, 58.797062366239494, 55.19559306483115, 58.11773138661539, 55.7983946800232, 57.20097149572065, 50.24807614664878, 46.06393483377273, 42.54526676670198, 42.66709558425411, 40.94844633533109, 41.100959854741255, 42.32419021667973, 39.43268952831146, 40.30947262240995, 40.4637159070661, 46.606343715421616, 53.42947529208276, 57.32258458291331, 57.45099905998477, 55.59997766248642, 57.206345142856726, 56.45297158148981, 51.97824931913807, 48.62258318931826, 47.28035596109206, 43.29837752926735, 41.407885320724986, 37.81768498882171, 50.513361730883204, 54.14608840019473, 52.373957633972175, 51.779212567114065, 54.06361664495161, 53.990703705818426, 53.062557174313454, 51.63679130615727, 52.09037811525407, 47.99193274590277, 45.73372225607596, 46.63072124604256, 50.69978806280321, 53.25298432380923, 51.5682831887276, 54.411876047811205, 40.78056496958579, 16.177034243460625, 1.0506738986699813, 0.270205952467457, 2.9510456996579326, 2.7119615481745813, 2.2475744928083112, 4.589730078174222, 1.97363615997376, 0.5977033306994747, 0.02534158715617753, 0.09734033441711819, 0.41281043101222287, 12.109775639349415, 46.111987790753766, 28.686923019347656, 28.59559847462562, 23.969761017830145, 0.35031408131603275, 0.05304081372976784, 0.017338705196556066, 0.012935986404397316, 0.04221622884694127, 0.04110812096886578, 0.02409655638339539, 0.018886832910920345, 0.025138514484429074, 0.06323876550361034, 0.056715289341105576, 0.03059224462166669, 0.01235109551118747, 0.014813391157546112, 0.07912827174990408, 0.03891260873886847, 0.009766979435939464, 0.030541221250689803, 0.01843021003409259, 0.06302781170234084, 0.06656985369420822, 0.04808399886373551, 0.04600551039461167, 0.026457156730635513, 0.014518315156531191, 0.07347429005969917, 0.03130312825012351, 0.031664126117022774, 0.05318203820816932, 0.03127091808334714, 0.02576978051013524, 0.024610664582841342, 0.04007131289390307, 0.05632980155848688, 0.04412593665502725, 0.03210427427303887, 0.045529302479999686, 0.04891677091138498, 0.04591365645249044, 0.02220716331184151, 0.02169131034714801, 0.012758527882397177, 0.07288745138794184, 0.07006526774456424, 0.027215332881877982, 0.03604621033094103, 0.02684990128111695, 0.061430886102419716, 0.0465476057011514, 0.05891390039675659, 0.046951414476479256, 0.03756745027438287, 0.032980341779729055, 0.048075514439974106, 0.060845859228603305, 0.010811097904919617, 0.19921105234853684, 11.830769604252232, 52.127930887283824, 33.069742187376946, 41.228809510507894, 63.5811145074906, 16.992417535474225, 0.9766435743339601, 0.06654039761351963, 0.11477395216183317, 0.011889985274343241, 0.45330427587032324, 1.5963421473580024, 5.608561317766867, 5.010465075892787, 2.4192963492485786, 0.3210091957401845, 2.439124911062179, 27.110487145762292, 51.323205655620946, 63.847616026478434, 64.87172334424912, 63.6847552945537, 62.751450846272135, 58.231409518949455, 55.45294369420698, 51.11045237510435, 54.963679006022794, 62.162569722821644, 62.58956286215014, 59.02811350360994, 58.141873575026, 57.907527646710804, 58.85942020723897, 61.638584213872115, 61.99930890913933, 59.58511360229985, 57.67180104409495, 57.46076183934366, 56.18375185997256, 51.986356858284246, 46.887742396323915, 46.95319498738935, 45.62289568685716, 44.572645771888, 43.952264093583636, 42.9102276217553, 41.45332597917126, 44.19127764240388, 49.41683569262105, 53.2826139080909, 55.302371748032115, 56.104335631093676, 59.25199454830539, 58.58566622580252, 58.046410929772165, 57.936643400499904, 60.36189586885514, 61.161447494260734, 56.189145118959495, 59.54760005397182, 58.200265899781265, 59.33428979689076, 53.04241972584879, 46.651588255359286, 45.74089627112112, 44.34182213198754, 42.70313432139736, 42.27654518619661, 42.6469502910491, 41.21627753780734, 42.20489132788874, 40.72867593457622, 47.1628378283593, 55.26442281661495, 58.99520089549404, 59.51645643480363, 56.100326968777566, 58.370328103342366, 59.02235154182681, 54.99702699722783, 50.77736862244145, 48.75620657397855, 45.01785047592656, 43.36364576893468, 40.30287911815029, 51.280471432593565, 56.67290279942175, 54.32784318923951, 53.00397657578992, 56.76081095972369, 55.507821575287856, 54.59359161315426, 54.65555721713651, 53.73398065567017, 50.250233450243556, 47.42285174708213, 48.976263307756, 53.3804182083376, 53.59554844517862, 53.88162259132632, 54.61100301434917, 43.243170169092, 17.880585308997862, 1.7061393395546944, 1.4024658861660189, 2.6017073998528146, 3.589390607610826, 3.454170818290403, 4.10698534980897, 0.9695133795180629, 0.23270602518272018, 0.0551329960205382, 0.05756309203382942, 0.17863071313308132, 12.582863492350425, 53.50648710804602, 30.343598819548088, 28.304019281941077, 33.36180971514794, 0.9009986430887253, 0.02448660238916355, 0.038025907931789275, 0.05861281252075588, 0.01400404607862114, 0.051578022464508974, 0.0354812779433785, 0.01792507080902015, 0.024557658959360375, 0.035091331529040495, 0.03316809460821171, 0.029684282959468906, 0.02712270902139285, 0.07210286244028999, 0.1691729286986013, 0.017640716208505536, 0.00901866762433201, 0.09748601369679936, 0.04624339601685924, 0.004936631322057257, 0.023213090382576473, 0.032702780463882995, 0.05272285659767447, 0.0003390703058093711, 0.051139417975660295, 0.13942126064531266, 0.08534692918821689, 0.20975859685530587, 0.24138941729982055, 0.12591156823139998, 0.10631109377549541, 0.1233771731776576, 0.1330523427215315, 0.15308503632343587, 0.13628452896110474, 0.14281665425627463, 0.10141220664785755, 0.18177657658534666, 0.12280837587651708, 0.14724367718783118, 0.08428795052872551, 0.09661581442360917, 0.14412153181770157, 0.15743589479356043, 0.16856742812500847, 0.13430158697789715, 0.12151351108426049, 0.09473276264484852, 0.18615578030866964, 0.14724615931270585, 0.16262656948979826, 0.20845630867106302, 0.17522586599713372, 0.2580651442610449, 0.14077061727162332, 0.16912867946009483, 0.29932216590931343, 13.713669084733533, 59.79934953874158, 47.637095528264204, 44.6584358522969, 63.50685619538831, 26.151646106473862, 2.04011494113553, 0.3199075613050692, 0.3253849673896067, 0.465305962509686, 7.699956345942713, 7.907699288860445, 8.62848776002084, 9.734448079139957, 2.5009549481253472, 0.20708747808971714, 2.4494110816909425, 25.779517119930638, 51.58141920643469, 67.65715922078779, 67.35091624721404, 67.8862177941107, 66.31475156353366, 59.55324042227961, 58.35045345367924, 54.46578118108935, 58.709150283567375, 65.54672010483281, 64.4081933267655, 60.3519840394297, 58.401401119847456, 59.041076937029445, 60.19016273560063, 64.82068938593711, 64.91567350202992, 63.558282390717544, 58.54535210517145, 62.746602796739154, 60.47613882249402, 55.891896140190866, 48.88509565784086, 48.990183799497544, 46.968841322006725, 47.66830582772532, 45.443631602871804, 45.2180443271514, 44.280699837592344, 46.457391708127915, 52.78251171112061, 54.863356544125466, 56.988096621728715, 59.71484991811938, 62.315628451685754, 62.17463101110151, 60.68629941632671, 58.44848525139594, 62.32465774782243, 64.31885742372083, 58.85509775530908, 61.71810242437548, 60.15475942242531, 62.59514047253517, 55.52413471283452, 50.68087047146213, 47.65289483531829, 47.883447831676854, 45.03353211187547, 44.901740474085656, 47.29154648319368, 43.37049030488537, 45.030833521196925, 43.51843034067462, 50.92567736102689, 56.67060036813059, 60.356279034768384, 60.28981839456866, 58.00668124229678, 59.75218303741948, 61.01213070654101, 57.37973351632395, 53.001689833979455, 51.55728094039425, 47.15166299573837, 44.467855730364406, 40.97081169005364, 54.64950107759046, 59.21400247081634, 56.16558736370456, 55.460278526429214, 56.453822735817205, 56.36666767058834, 56.12402200698853, 56.10012692789878, 56.04095405147922, 53.094308760858354, 49.93449049611246, 51.1018035488744, 55.253310741916785, 56.136981518037864, 54.48924087708997, 57.58862718459099, 42.98075183745354, 19.814562874455607, 1.6153967765069779, 2.7868628838369927, 8.274639960258238, 6.613872637671809, 10.341155394431084, 13.186657467196065, 7.49957275006079, 2.4503872615675775, 0.22594502345929224, 0.30265752887052877, 0.712252167924758, 18.196453778974472, 58.7333316956797, 37.34238786082114, 39.47741631538638, 36.294016761164514, 0.8507114672853101, 0.12740252854963466, 0.1537912314937961, 0.12884091225362596, 0.09986790362745525, 0.17851423712507372, 0.22297776574569367, 0.12984300122386025, 0.11464315030964152, 0.1969942696873219, 0.17517942574716386, 0.11137520308576285, 0.14312479014117874, 0.13093490634233723, 0.3102644142364302, 0.1107774783046015, 0.07487948683481063, 0.17290305676719836, 0.12675071030013985, 0.16071841300975892, 0.09850229827627059, 0.23585542796119568, 0.10991603541638582, 0.09401962671789432, 0.11224185537186362], [0.027778152781989307, 0.0695594275490411, 0.06065383545994278, 0.03754634072162932, 0.0403742125678447, 0.04427880950031742, 0.019544908183536703, 0.014811060335036489, 0.023907449494506565, 0.0158528087195009, 0.04277176133567288, 0.035028152257925084, 0.05217272502880904, 0.07994040921931306, 0.020679325436151797, 0.023053037378215985, 0.03838175194217794, 0.015607151135261503, 0.05178679674563389, 0.059196069731467196, 0.09284755815902064, 0.04465074135711597, 0.0440989205643775, 0.011245816412772383, 0.07834104745979271, 0.0134293575613429, 0.04600774737135057, 0.024013179204156323, 0.10490031988029519, 0.05222643928361997, 0.0413558776340177, 0.03320872025083631, 0.06115101120104233, 20.470777365469164, 42.01176166534424, 34.27186235304802, 38.49387022756761, 46.05622345401395, 17.332700798588416, 1.9359929282819073, 0.04061679047862849, 0.054954654582205324, 0.67525134692269, 2.0454480162551327, 4.7348960176590955, 2.3695477026124157, 1.777480021119118, 0.8584791698282765, 0.10700771284680213, 2.2706326361625426, 25.0003186733492, 48.42214615114274, 65.15959001356556, 61.59874862240207, 64.30181864769229, 58.80136912868869, 54.63889106627434, 50.918503345981726, 53.58243596169257, 58.86842204678444, 62.53785817853866, 60.33439613157704, 58.32462464609454, 58.435486516644886, 60.05150695000926, 58.57066708226358, 59.97891956760038, 59.08805908695344, 59.28567594097507, 57.67977914502544, 57.61358914836761, 54.24980763466128, 44.9896643238683, 43.42385022870956, 44.00691055482434, 43.354275226593025, 43.38955302392283, 42.69523074550014, 44.58982575324274, 44.258181510433076, 48.4151957111974, 52.55757947121897, 52.410867137293664, 55.9766036464322, 57.73467663795718, 56.986386468333585, 58.32176131586875, 57.43867889527352, 57.48340960471862, 54.72235125880088, 54.8638625298777, 57.39884722617365, 54.427455702135646, 56.82451809606245, 55.12435497776155, 51.030875329048406, 43.92634507148497, 41.29285397068147, 44.40239921692879, 43.06466310254989, 41.146008276170306, 39.53257660711966, 39.84176528069281, 43.85157292889011, 54.24216685756561, 57.59376156714655, 57.5179970648981, 55.37036211259904, 57.459753790209376, 54.04891560154577, 52.47804164886475, 47.89593665830551, 47.9721640002343, 46.209525369828754, 43.68879456673899, 39.42888482924431, 39.43398391046832, 51.996645235246234, 53.39297763762936, 50.84848119366554, 54.52944517135621, 54.682629416065836, 53.87283255977016, 53.39123610527285, 50.49217700958253, 47.728553433572095, 49.988360328059045, 48.55282383580362, 49.270335166685044, 54.407153514123735, 51.36177824389551, 54.49308872222901, 43.836562018240656, 21.066952136255082, 2.7916555298912913, 0.018263331186326764, 1.94893907875784, 1.6759343925983676, 2.1705862110660923, 1.5077991759584797, 2.5322201607688783, 0.8213997175616603, 0.034529049805695974, 0.008023134451509725, 0.556895665584072, 12.270790896108075, 39.35315170595723, 38.272954494722434, 25.332835643522202, 39.46073055267334, 7.319470749747369, 0.10911340509811718, 0.13393282289466552, 0.032794615253806114, 0.07699644823949184, 0.02469752363169626, 0.013784489109961977, 0.07823950250542934, 0.07688168826843463, 0.05125978187988362, 0.0273158646849615, 0.0470993077502616, 0.058940736456744136, 0.03829338753055181, 0.020308535050360427, 0.01840412857071046, 0.07604948695628874, 0.03677400535032634, 0.015276037400678523, 0.040473604815140854, 0.07130348799569954, 0.05291807112253962, 0.02405959838670829, 0.051103668482673746, 0.04181507073583142, 0.10829914556515795, 0.06322373485853595, 0.05215067701834825, 0.06559082397049473, 0.016096568320907893, 0.019215586137086637, 0.0886095137966256, 0.01573719743323783, 0.03015359991320199, 0.07184812288370825, 0.0277376324764543, 0.07740514082533699, 0.024869535268554767, 0.07782000807985183, 0.05703716884337126, 0.0409978426121656, 0.024251332957177393, 0.027972961280254588, 0.01792883038550856, 0.06670795636431825, 0.025783401553428946, 0.06519021361225075, 0.14053507587842404, 0.05822121518694105, 0.021092174048986168, 0.09518026524493772, 0.058592369464496454, 0.07424990045687846, 0.039778119553962064, 0.031612076188227346, 0.016675975939799702, 0.027586151995966514, 0.0290384593479816, 0.3031511959289351, 30.994759336594615, 46.71266348131242, 32.162572491553526, 47.29826158092868, 55.06429956805322, 16.80361620841488, 1.4738437076730113, 0.024429747173863075, 0.059883055247126095, 0.14164896772032784, 0.33655737917269435, 2.2976455092430115, 5.6419235275637725, 6.488290111864767, 2.0437020712321807, 0.16827026261918007, 3.759056651784528, 28.51911225626546, 52.324559304022024, 66.62413243324526, 64.15043477089175, 65.38822104853969, 59.03563660960044, 56.748361356796764, 53.474025572499926, 55.052406941690755, 59.86132690983435, 64.74339123695128, 60.72314616172545, 60.69246930460776, 59.92392009304416, 60.9093253843246, 59.99114951779766, 62.41716292596633, 62.718612763189505, 60.000037608608125, 59.97948046653502, 59.95544418211907, 56.60208832833075, 48.252021189658876, 45.632019119877974, 44.45963444248323, 44.47494737563595, 44.23095241669686, 45.972339645508804, 45.79018085233627, 45.62539423665693, 51.446615188352524, 55.0301710251839, 54.31768425049321, 57.03809507431523, 60.92343022746425, 58.98681094569545, 59.245032341249534, 60.17581862788047, 56.82262359126922, 53.13667035871937, 55.17568311383648, 59.763616746471776, 57.00197396739837, 58.41695723995086, 55.62913656234742, 51.73550559628395, 43.983042932325795, 43.20992808188162, 45.59817691003123, 45.21809531796364, 42.58049749558972, 41.97142793286232, 42.17134329580492, 45.776460401473514, 54.37654333729898, 59.9819201807822, 58.00221758504068, 57.08360633542461, 57.843012502116544, 55.79946940945041, 53.358978532975726, 50.73244571685792, 49.4130035369627, 46.83663391297864, 45.18835982968731, 42.52752588641259, 40.183525316176876, 53.39707651445943, 54.418975537823094, 52.47311515192832, 55.35460202924667, 56.63086675828504, 56.36003494262696, 56.404369492684644, 52.03705349276143, 49.52690524439658, 51.797839903062396, 50.63825784191009, 50.784723066514545, 53.92688282074467, 54.029978398353826, 55.21800156562559, 47.30897749623945, 25.140341404945623, 5.063515622769633, 0.6401086262156886, 3.401476471654831, 4.94900643825531, 3.33244324691834, 4.78778378617379, 0.7867991419569139, 0.49839192100109597, 0.05302348865136024, 0.060369735583662994, 0.3236206056129548, 11.630581636582653, 38.950783206570534, 45.24531264458933, 26.64845351249941, 43.81771895193285, 10.221133808935843, 0.15539612440812975, 0.08187368572238954, 0.015545882295907266, 0.07507811811181807, 0.05220141885201297, 0.03902599741254122, 0.08535242203863398, 0.006142653855344942, 0.06699525465768191, 0.05924118464932807, 0.0631113114556478, 0.038445911805836425, 0.05388697316389411, 0.04672360674087559, 0.025362124058207678, 0.03321284180386894, 0.06864871754641495, 0.04468544514008588, 0.054007647333726774, 0.07983547815632436, 0.04160651862020454, 0.05219486880026037, 0.026587146529627424, 0.029723989296584364, 0.13168587169099238, 0.16570783640828826, 0.15685647185291016, 0.1302421330324104, 0.11112369642022157, 0.14201728747256342, 0.17859918095411795, 0.06833810719751543, 0.1548873194523396, 0.12306825588307074, 0.11521790777483296, 0.1199016850742121, 0.11058829289170043, 0.17096113113145675, 0.10304627985122705, 0.07710781444104449, 0.10143489051129549, 0.12654299322035045, 0.07849726810931199, 0.13507895171642303, 0.12191095749937719, 0.21799649352267866, 0.2719806411093281, 0.13077917598908947, 0.10469209718247575, 0.1503717827220117, 0.11379267780050156, 0.12970628517289318, 0.16709891418295522, 0.18531231750403682, 0.12929976827675296, 0.15578290687934046, 0.10514172950699445, 0.3922462102866942, 34.75506697931598, 57.334139885440955, 47.92148697760798, 48.70787512871527, 60.623110032850704, 23.659244621953658, 3.2422561895462776, 0.13813582639540398, 0.21550733596086505, 1.5870281116616343, 7.710772771989146, 11.269293100603166, 8.564327589927181, 6.7894340042145025, 2.550073809200718, 0.27881310351433297, 2.4537323078801556, 29.001138210296634, 51.29209733778431, 71.82959618106966, 66.2876558303833, 69.85116051089379, 63.346678364661436, 58.95101931787307, 55.85976408373926, 58.445080634086366, 63.61101473531416, 68.28349897938391, 62.50988775683988, 62.82466580790859, 60.82912468141126, 64.23200438099524, 61.6090173875132, 64.62919927412464, 63.92525934403943, 63.99637583763369, 62.08832317782987, 61.9961396340401, 60.20868416755431, 49.85012423607611, 47.67117308032128, 47.609478119880926, 47.36434567359186, 47.64892147433373, 48.803094587018414, 49.04219442798246, 48.1207473047318, 53.424411512190304, 56.87803491469353, 55.41895635666386, 59.50110427794918, 63.12111462316206, 59.96126105708461, 61.49752009299494, 63.79328727722169, 58.072314262390144, 52.70574700447821, 55.63201165968373, 61.36260624854796, 59.64523176993094, 61.5317859188203, 57.96298996094735, 55.915838287722686, 46.55254056376796, 45.974426346440474, 49.315367898633404, 49.28734256375221, 46.759508348280384, 43.99159369930145, 45.32894542140346, 49.28326722114317, 57.30588705308976, 62.657906240032574, 62.73341971059, 57.13589937456193, 58.93781269750288, 56.89483442614156, 54.779617863316695, 51.703000914665964, 51.577520370483406, 48.98880312519689, 47.85191982023178, 42.94915322334536, 43.48848304440899, 55.143990362844164, 55.868401142858694, 53.900673543253255, 56.77646513908141, 59.144352943666526, 56.698798287299375, 59.03976686539189, 53.65350146447459, 50.8306775554534, 54.849326226019095, 51.973840575064386, 52.97478237459737, 57.69486458070817, 55.9362816810608, 58.422048476434526, 46.0355172618743, 25.395677897237963, 3.3421219404666656, 0.8462130602809691, 4.96072942210782, 6.994377845718015, 5.752263722881194, 5.377601375502925, 9.3446272419345, 3.7696370001762145, 0.17250508941229314, 0.16568356674284707, 1.0233403718279255, 17.97418482841984, 50.38131121666201, 49.91943251702094, 35.84445430386451, 52.161306335080056, 11.333139481083041, 0.28355782310808864, 0.22447943597310976, 0.13936407984264437, 0.17596670366342992, 0.1540252560329053, 0.10605880570027137, 0.22099062560066102, 0.30162714061237156, 0.1300219440412137, 0.14489549512584365, 0.1904912404115162, 0.1981267008569933, 0.17639062607720976, 0.11987255841133096, 0.20385136947997157, 0.1789672095929423, 0.1482484168222835, 0.1663508752901708, 0.1461756433690748, 0.15538333073979424, 0.10550169123997612, 0.12422075855635828, 0.20756527180633239, 0.18620824200972436, 0.21269792300318519], [0.04607754564213176, 0.07468707619174834, 0.03329469446813868, 0.026559764631993832, 0.017953349029525154, 0.022151788561454704, 0.0213965407813028, 0.03437948262979908, 0.0274980231563771, 0.027267265982264956, 0.13081043237640014, 0.016066853685544866, 0.03423849946909374, 0.023236509690421726, 0.033506609709753145, 0.05159365831904354, 0.07511580963769267, 0.027112234684248126, 0.07449183868424547, 0.04004864052178399, 0.015754351099472375, 0.018986156210303307, 0.05847331940106327, 0.08667914076678215, 0.018738035653387348, 0.021132150432094935, 0.023424626410668416, 0.017398929283503565, 0.027041587971090793, 0.07697302127076734, 0.014214935720026975, 0.03645747697221176, 0.05237575365050186, 1.190106681277675, 34.148664628305745, 40.52189642383207, 31.607062893529093, 36.28841169418828, 48.93692585729784, 18.49919407598434, 1.0364452557217692, 0.01533628447026375, 0.035270875725414486, 0.25156775339236187, 1.886532085557138, 4.680865368535442, 6.744182109832765, 2.248525422426962, 0.303264147932491, 0.10805905360968844, 5.076361385083968, 38.100342750549316, 60.771332479292354, 71.95333127052554, 62.42900063914638, 63.153332971757465, 57.46386835652014, 52.655819154554806, 53.50593405385172, 59.28913154909688, 60.358008800014375, 61.97705730315178, 60.8241315041819, 61.832157104246086, 58.16822013547344, 60.546698339523815, 59.15008744885845, 61.54003858566285, 57.891359636860514, 60.45269873834426, 59.095935206259455, 56.270334259156265, 48.755775113259595, 44.29481644784251, 46.77329940180625, 44.02435333498063, 42.640188124872026, 42.94033181282782, 43.23748273234214, 42.41727590560913, 48.00822627159857, 50.06112813949586, 54.52199659039898, 58.47035638747677, 61.042109381768014, 60.75496050619311, 57.78151366018481, 54.78071220459477, 55.52446419192899, 58.70906006905341, 52.89188700337564, 59.79883178587883, 59.25918425283125, 58.827268538936494, 59.90125271581835, 58.63891632326188, 50.70079218956732, 45.199362078020656, 43.355773571998846, 41.2733676356654, 39.984688605031664, 41.626392718284364, 41.38443739183488, 51.724373909734915, 58.28130598991149, 56.849354543993556, 57.483895978619984, 58.295967809615604, 55.30736884763164, 53.41079304295202, 49.11168313795521, 46.53259531144173, 47.80304708788472, 48.0942673836985, 45.83469583142189, 40.04958421953263, 39.036463460614605, 48.40541331998764, 53.68777513504029, 51.38376312871134, 54.55576035284228, 53.87305221249981, 53.87402888267271, 52.21775708660003, 51.980226193704915, 50.8397303858111, 49.44984243762109, 50.406787010931204, 52.765088542815185, 52.55492010424214, 57.95317226840604, 46.30050474597562, 20.724166400970955, 2.1747789796321624, 0.3421854900736963, 0.7172308814141058, 0.2253501255425715, 2.1387596091916485, 1.0991127188167265, 4.358153833496956, 1.2808347805853815, 0.06842725684926396, 0.017607502466548356, 0.5845970372038504, 13.589515282261758, 36.435547644092196, 37.56987356370495, 25.260210998596687, 32.36043057134075, 21.471230829915694, 0.020919440374259027, 0.04937677606639843, 0.06928859248517022, 0.10271719146159389, 0.05165000025543475, 0.020687532153040655, 0.04987611600588407, 0.016499974900075508, 0.06472776463675885, 0.04788221130448003, 0.03097502428347305, 0.01275928918227193, 0.024466207213399392, 0.022512359334336176, 0.03703981487741394, 0.06527393170061611, 0.06057400909823276, 0.023673365583583236, 0.039035144502357136, 0.051270564567417874, 0.012815176253958095, 0.09195688901649368, 0.06758452182815922, 0.028108938056374752, 0.021615699384241335, 0.06446080597778482, 0.027332982919629545, 0.016021190057208222, 0.0540987849836388, 0.08032938270198722, 0.010618867292519539, 0.021473358332690214, 0.014734253317358033, 0.10402477331339352, 0.01927459788989396, 0.08874279777369193, 0.14952753850769612, 0.11218655914548906, 0.04932389301698535, 0.036476598526801796, 0.01865899453179971, 0.05210133712558497, 0.025127844794863657, 0.023156702480909806, 0.06893319663621726, 0.020859534213800105, 0.04452963817804571, 0.013815953298622083, 0.07944484992373375, 0.03979045356954298, 0.046634315362861084, 0.01650844400207843, 0.010962905887995037, 0.051140747138208924, 0.032935801427811384, 0.041378553836576404, 0.028705113424709248, 0.01043579813408395, 0.05182586722977219, 2.8626386628996943, 42.68138085642169, 42.905736507907996, 32.102970115600094, 45.23439276602961, 58.2722649266643, 17.06319670523367, 0.8700447072905879, 0.04714138512950271, 0.052564257245150306, 0.10459093527207453, 1.0713580274774184, 3.462091554557124, 10.777810312086537, 2.7962858878797103, 0.7873022472185474, 0.24485420315496384, 7.074943819353658, 40.05424399529734, 61.7010401141259, 70.87767616395028, 63.92315695362707, 64.22855661761376, 59.018456628245694, 54.932923701501664, 56.69929250594109, 61.36657176479217, 61.545184735328924, 64.48690352901336, 60.57246831155593, 61.98927156386837, 59.01744465674124, 61.81778553993472, 61.21073992021623, 62.94006978311847, 60.59850108238959, 61.912942240315104, 60.94690953531573, 59.06460723569317, 49.42305264934417, 46.83712420925018, 46.95368136129072, 47.36732667492282, 43.84759564553538, 43.58053714998307, 45.75569537378127, 44.85581344173801, 50.08722759062245, 53.73007005260837, 55.00342830534905, 60.068639862921934, 62.27921708937615, 61.7529958294284, 58.94979161600913, 55.66152357286023, 59.16178787908247, 60.736694028300626, 53.36995724708804, 59.098912285220244, 60.113884402859604, 60.31349382092876, 61.072182193879165, 61.02209352677869, 51.02648227445541, 46.79989307157455, 46.19682081284062, 43.95864186748382, 42.53417430385467, 43.424003201146284, 42.47249895526517, 53.221009162164506, 58.06259070673297, 58.79353615545458, 58.24649887700235, 58.40116185526694, 56.107904987950484, 53.52598128780242, 52.146664127226806, 48.423922984830796, 49.674657006417554, 48.90517819312311, 47.4965883839515, 40.844130900598344, 40.8950589549157, 49.70899343490601, 55.329165458679206, 54.371314817859286, 55.99403858184815, 54.02640511912685, 56.03807895414291, 54.38458419615223, 53.68293885261782, 52.376632690429695, 51.14622831344605, 51.997268892103634, 55.13653393714659, 54.63394887985722, 58.13067520818403, 48.075636125379994, 25.26711437009996, 3.4283373528911225, 1.0831827478062723, 2.921423960116602, 3.1249569740987595, 2.9631621462683526, 2.965345435565518, 2.1244115791013165, 0.19551988751176866, 0.0528882856240436, 0.01387410990578393, 0.4236957130412902, 11.096140069346275, 37.97387376908333, 46.62338249145016, 32.66217654751193, 34.535249510119044, 28.846616437358243, 0.5131432197747693, 0.035750343344144286, 0.08959714668772875, 0.0488707251966961, 0.03677896960007568, 0.037563524073770935, 0.019525378687126983, 0.05590699763307649, 0.06273474859734697, 0.07735513060563996, 0.029057420024107543, 0.04642610032592089, 0.010475813779198836, 0.0962563889521745, 0.06032771566101621, 0.029364797481966597, 0.02217567709815358, 0.037290888703278, 0.058561021146634896, 0.04751042883482672, 0.04019340432639565, 0.06635022394719624, 0.03871972312129313, 0.047911127293182, 0.041060765243826375, 0.004731627151129707, 0.1538388208756524, 0.13877330347895622, 0.10792104287012931, 0.13001748540949437, 0.055520356888131756, 0.07957195923213037, 0.14163545392934354, 0.16729333197637913, 0.14106931495330027, 0.1349376238161518, 0.31660529334218274, 0.13498334394347283, 0.11890857465445034, 0.21034975626295616, 0.08828446269035341, 0.15157636405239183, 0.22774569780355503, 0.15780274365698138, 0.15027677249764243, 0.09962518399040546, 0.15862143117814295, 0.0999185803436464, 0.13120895131461083, 0.2368811584047733, 0.18377624992882052, 0.1360347842977893, 0.16369247358412514, 0.1727232865748867, 0.13903890616230427, 0.20123475020931614, 0.0614446641937379, 0.18792869162655648, 0.1746179445857002, 2.9925558980434173, 47.12873281971101, 53.20469210224768, 44.112312486094815, 47.40653076479512, 62.65495661766299, 25.380155117281024, 1.6414834799305087, 0.21444710091717784, 0.2044590763867863, 1.0099454164024324, 7.32087544856533, 12.786805168274912, 12.136859605389258, 3.7259746463068075, 1.1316174004347095, 0.5922049644493288, 6.274621448209209, 42.86163730006064, 64.1099206093819, 77.49248673838954, 66.95081880015712, 68.8574750961796, 60.9929620835089, 56.436760425567634, 57.54166856888802, 65.81952095031738, 62.24883833239156, 67.76493026364234, 62.41460946298415, 63.64662593410861, 60.35928357032038, 63.947683534314564, 61.89093774364841, 64.5275745853301, 64.07850242430165, 65.89626604510893, 63.82266190744216, 60.70568769208847, 54.429703220244384, 49.14723550119708, 48.91873390443864, 48.818925273033884, 46.898187668092795, 46.55679241303475, 48.06367681872461, 45.60313870829921, 51.86420248400781, 54.65239186440745, 59.062026316119784, 65.65225147431897, 64.6094972087491, 65.90119254204535, 60.87951144864483, 55.03087705181491, 58.908100743447584, 62.17916134865054, 54.77334991578133, 61.334824100617446, 64.5572159367223, 62.006965375715694, 65.39906247969597, 62.28837582372851, 55.263759936055834, 50.562995403043686, 48.2112128503861, 46.21377329672537, 44.31586388618716, 45.741731735967825, 44.93899906835249, 56.21760975929999, 61.03142484541863, 59.32750017412248, 58.670232526717655, 61.05790084408176, 57.42118512430499, 56.59773841980965, 53.909051725941325, 51.2404554120956, 52.712748435235795, 52.79271771830898, 50.830183336811686, 42.98859657779817, 42.22319310711276, 53.65081856327673, 56.886762188326934, 56.29864200468987, 56.93170078339116, 55.27935135749079, 57.0859323009368, 56.36201573956398, 56.17241228780439, 55.03619578576858, 52.06023077810965, 54.403403728239006, 56.80789509127217, 55.61989545822144, 61.500250062634876, 48.08356323549825, 24.988467231873546, 2.7601132998543405, 0.8966789490753605, 4.056457132101059, 4.527093258596236, 6.456314950220047, 6.2183148437930695, 11.381644491226444, 3.7007971973188467, 0.3023552305756077, 0.15284065427559038, 0.9418492091278877, 19.56241919148353, 47.014482021331794, 48.003444902358524, 36.300841685264345, 45.4891271745005, 30.917210155917754, 0.4809718170473653, 0.16929979285886212, 0.17412631532117245, 0.18113810358749283, 0.19122325274492466, 0.17213692287764243, 0.15754466395704977, 0.11113838232573002, 0.12679522000854054, 0.22677845051211698, 0.1107073582768921, 0.16260260625952677, 0.0904464164388276, 0.21251551746841402, 0.1270881184046307, 0.16138198304801218, 0.0815980089828372, 0.10128987772810845, 0.10455515896601063, 0.14100194518123904, 0.09722737475268303, 0.17643835335489244, 0.16736057917437247, 0.08010711761251574, 0.1370250601922312, 0.1887612453391475], [0.0658476243035928, 0.04972935654222966, 0.08101630310017256, 0.05193755901869267, 0.030160737937436472, 0.01962086005556968, 0.036630723925848166, 0.05382277499583941, 0.04470158278221085, 0.027988936128695647, 0.012169159205269911, 0.011527476299013342, 0.03250362441664742, 0.032348062602743026, 0.0133986814856349, 0.020322590848551165, 0.02700645326366348, 0.06015023224115853, 0.04715665326183362, 0.07211647582270446, 0.014580527241642197, 0.045179165824646914, 0.02491816652998809, 0.06037543527781964, 0.03352853897658568, 0.024643920459634355, 0.011116507474423177, 0.11706291562727383, 0.03879510234260271, 0.017982826177631656, 0.03792392247686944, 0.041047898797138084, 0.11855687134929242, 0.03141060655546044, 4.676881711329184, 33.8130078008098, 37.5631506212296, 32.34480188738915, 38.61628347827543, 53.41401330886349, 23.642501984873128, 1.5049101051784333, 0.10253562096266017, 0.09217870977496909, 0.18066430884984233, 2.3637600002750276, 8.75401537264547, 1.077726363174377, 0.9407323142213206, 0.05194008710884279, 0.07728974500130262, 10.359768021491266, 44.131865501403816, 65.14050768267724, 66.634824814335, 64.60613181514125, 59.43188228914815, 57.327381641634055, 54.79229496371362, 55.408970002205145, 60.24349912520378, 60.04598425280664, 62.94258010002875, 61.90123396535074, 61.657482193362334, 60.023587519122714, 61.40458345413209, 58.69282537891019, 59.326578417131984, 60.98299534090104, 58.80540132522584, 59.249774486787864, 51.93655060183618, 44.343010610149754, 46.59458444964501, 45.126896289087114, 44.36862368737498, 44.84665470738565, 43.87137305351996, 43.59157862201814, 46.37322548897036, 48.816909174765314, 51.058798682305124, 57.898184560960345, 59.184541548452074, 58.451411339544485, 60.74628814574211, 58.86499389525383, 42.63436732753631, 45.8705815961284, 51.859028877750525, 57.372845834301366, 59.66858556193691, 58.210146350245324, 59.29526221367621, 56.16543046889767, 54.64038156693982, 44.1414870754365, 41.821181543411754, 41.59729265397595, 43.73696519482521, 42.61142146202826, 45.1775929235643, 54.34262268004879, 56.70188911499516, 59.1100400493991, 57.054647476442405, 55.17139596323813, 53.602232163952245, 49.85519586070892, 45.373099542433216, 47.45386200566446, 48.56879572714529, 49.837066665772475, 48.327456212812855, 43.27963644458402, 39.92498620863884, 46.14986219713765, 54.45173125113211, 52.6782629566808, 53.936135691981164, 54.94762474490751, 56.94520550389444, 56.134428055055686, 54.96865257140129, 51.938558855364406, 54.910687784994806, 53.36929436652891, 54.18206437941521, 55.02737045288087, 44.919571568889005, 19.70693107574217, 2.6239170855091465, 0.09933857517617364, 2.5433395899111226, 1.5675382219975995, 3.9411445971458194, 3.7484525240236715, 2.754291031629809, 3.804720149886224, 0.18669234829083567, 0.1279303631294639, 0.48436399308904526, 14.495966203751104, 38.44625657604587, 40.96328073932279, 30.73827555102687, 27.08676661214521, 31.701529256759155, 3.066183198844233, 0.033570512933957006, 0.03391472006877584, 0.04338972999023334, 0.02293093253918473, 0.04290720951112528, 0.04766882517405095, 0.012112677457832522, 0.01585567771877733, 0.010885523346763466, 0.03862166769742485, 0.0952411845566765, 0.027393132313004425, 0.038980955273033156, 0.055059355818816734, 0.030896837349920988, 0.015549808496519204, 0.03689025153195666, 0.03991529142724411, 0.05820041589979684, 0.06717752229662673, 0.042955499863432306, 0.0427476219051788, 0.027781623160286296, 0.01949947342396744, 0.043301327274210995, 0.007449028161053937, 0.07171169028527315, 0.06400648902560915, 0.015813193355326452, 0.08276187274004183, 0.07053884797759595, 0.03059488570978565, 0.05299510892420527, 0.015993427030832296, 0.059964053723360264, 0.04026856904308643, 0.010904424651075276, 0.021370135645772663, 0.07493446896513624, 0.05394465958459243, 0.03485189074830663, 0.029420327365158067, 0.07308104946728676, 0.06758132724151497, 0.08626585165339132, 0.006141184402945182, 0.020047381422632647, 0.05232642141861781, 0.06580974125573713, 0.05171129878069605, 0.047921622697744644, 0.040736403616686026, 0.007780807913326088, 0.07086153953306137, 0.019957304804495746, 0.06794108213075707, 0.02110362323301454, 0.09248339060333469, 0.051405836542647694, 0.06084351882999463, 9.878193140029907, 46.24393632335048, 39.45809471991755, 31.99996279131982, 48.45719252863238, 61.22552725576586, 20.70033015743379, 1.9719792037240922, 0.08915234837801227, 0.02605442622406108, 0.19715383048019103, 1.6493155951461487, 9.178612924391224, 3.440645995639986, 1.8797755577871877, 0.6838231353509812, 0.19143331405376235, 15.31539345941236, 48.747232191024295, 66.63216544735816, 67.20323901022634, 66.55423579677459, 61.3811747489437, 59.104348690279075, 55.368142051081506, 57.977824364939046, 61.71910655113959, 62.68765349541942, 63.30309690967683, 63.36339158396568, 61.73378798269457, 61.0408503009427, 62.52424755404073, 61.655587688569106, 62.356130846085094, 62.62675085375386, 61.10920544593566, 60.29439972292993, 54.10231867144185, 46.71969629103138, 48.15570346770748, 47.69298145847936, 46.93381455636794, 47.25533908413303, 45.14369580053514, 45.012920056619954, 49.36256577891689, 51.96351297440068, 54.75246721698392, 60.05769645014117, 61.56374539098432, 62.74557121338383, 59.87930705470424, 57.932697496106556, 43.76945026459233, 47.671592773929724, 55.014516845826186, 58.084901148273104, 59.80118128561205, 60.14631063707414, 59.72096489321802, 58.67689271127024, 55.51758827701692, 46.368675539570475, 45.37787306693293, 43.97991680329846, 44.35551120388893, 43.927486481205115, 45.97306136162051, 56.88038441442675, 58.96765408977386, 59.32549192059425, 57.19999090317757, 58.36865717364896, 56.20465417062083, 52.902759813493304, 45.7287290788466, 49.744651702142534, 50.57766506748815, 52.108213132427586, 49.68620054183468, 44.90186991230134, 41.508670622302645, 48.815944271702925, 57.50756748260991, 54.11550567996118, 54.224480890458636, 54.64485699130643, 57.553106200310495, 56.97476840788319, 55.18677949905396, 52.961799329327, 56.30912650016047, 54.46702849480414, 53.82341854033932, 55.63542804410381, 48.50933259533298, 23.76753341767096, 3.708676503550622, 0.6275386555540947, 3.167752484160085, 3.7369847393804982, 2.181243045676139, 4.278702793582793, 2.2736227079745266, 0.42937597920817716, 0.11417037446893032, 0.06361900558394772, 0.37797331809997564, 11.41161826349074, 45.34564687359718, 43.91313845111478, 34.1988552770307, 29.679457218416278, 39.709777524394376, 5.6146610936810895, 0.22514296004608755, 0.02342135713045155, 0.038820938657849066, 0.08446848680896145, 0.04214567597955466, 0.07893806744006374, 0.046442961921134306, 0.04736178479487858, 0.008140297065819464, 0.0353276658232414, 0.039504369525539304, 0.02413741568283689, 0.0218720170819471, 0.025423893727542415, 0.009184133039877541, 0.01780736331467427, 0.05128918816485713, 0.0634124338056051, 0.0811596304899262, 0.015260617008372663, 0.03219234757125378, 0.02185232670707328, 0.045325798883793816, 0.06388846935043413, 0.010273283114656806, 0.04173216853110541, 0.14754096526772748, 0.12634800086098333, 0.1416985029655118, 0.13190235281663557, 0.12370527331386844, 0.1614775601774454, 0.14240105155735247, 0.1194803290549786, 0.16323534891970698, 0.07812552394405489, 0.1421960617505735, 0.0590650801877341, 0.20733242704262658, 0.21397304570963308, 0.11689277516017038, 0.14030943234120646, 0.17770535552934294, 0.128518772281466, 0.23433946253311252, 0.14105638338913842, 0.13289362462537904, 0.1855989569617856, 0.11343813997002379, 0.15180098103179088, 0.16079828533674442, 0.1207230462422294, 0.09387148063509695, 0.17166567155190054, 0.08662214382521569, 0.12780693104310384, 0.15505518463830795, 0.2619227646820007, 0.3935296527079998, 0.16900285717941102, 8.488559165308553, 53.98452597279703, 52.10341999607702, 43.536743887009166, 49.71757558084304, 66.26670252892279, 33.42800363417595, 3.2034274214698426, 0.1858227465662264, 0.2945445964653646, 1.5793413692905058, 7.700894282710168, 20.339711366161225, 7.04816040492827, 1.7793845769859131, 0.9280576040187191, 0.3470210983387886, 12.717368429706944, 48.33810152546052, 68.37927541425152, 70.8137179959205, 69.3870186036633, 64.53057519851193, 62.79898605039043, 58.25982709084788, 60.63728940102362, 65.74651779667025, 64.26829022745933, 66.73073460978847, 65.35085655027821, 64.13028947768673, 64.05907884720834, 63.98664443723617, 64.55779252513763, 63.52247507341447, 64.58402533685008, 63.294746183579974, 63.9505821658719, 56.988681054884395, 48.042382271059104, 50.81701594014322, 49.751013786562034, 48.40373062318372, 49.454870916181996, 48.46739853582075, 47.77259380586686, 52.91425235809819, 54.79255384014499, 56.18134744705693, 62.21002255716632, 64.00583267211914, 62.88048505783082, 62.33321243716825, 61.05782631904849, 42.670233480391964, 48.285471162488385, 55.18145684273013, 58.25133123705464, 61.63398719603016, 60.15240992269209, 62.91035782906317, 61.204754383333274, 58.60326197839553, 49.16193262223275, 46.17245504933019, 46.18410841111214, 47.84959385471959, 45.639275504696755, 50.46393986671202, 59.14359984859344, 61.93764532766035, 62.285120256485484, 58.11181253002536, 59.264734406625074, 57.31901522605651, 54.00048217465801, 47.981966003294914, 50.18315699792678, 52.649335476659964, 55.03254798150832, 53.49635562589092, 46.24836467927503, 44.01114279224027, 51.21930599212647, 58.50978797481906, 56.007123608742994, 55.953061580657966, 57.22437627853886, 59.35539214841781, 59.93479290316182, 58.2861069710024, 55.34918523603871, 59.12088148055538, 55.153600169766335, 56.420612027568204, 58.635433258548865, 48.74037981033326, 22.409948149035056, 3.7136451659664034, 0.3360460308049956, 4.959540453649336, 5.753176654538801, 12.371828209969307, 7.51545197540714, 10.150562524795532, 7.2715938091278085, 0.44132603152144345, 0.19436606716725136, 0.9939417783771792, 20.473695608877367, 50.56852594498665, 51.225205236865634, 41.558143477286066, 38.304102036260794, 45.98413029024678, 5.097204369883384, 0.4928748928491147, 0.16049399521322022, 0.16175992486457672, 0.18002652533112035, 0.1819175061198973, 0.11207987374115376, 0.13739115828948636, 0.05812261967108615, 0.08922105114306174, 0.14195592382982855, 0.1898480176685318, 0.1351519445738485, 0.1429944939070171, 0.2225629138129373, 0.13570610193475602, 0.1318309993873681, 0.17086101876151177, 0.17390750528823945, 0.1979086109467091, 0.09095642415265884, 0.08444152817490601, 0.13828944234598067, 0.1277492216397678, 0.1691299971313246, 0.1047570537775755, 0.1544091733352792], [0.03125379027258004, 0.0260705734422851, 0.06542856654813213, 0.0699092309561468, 0.05429423699576048, 0.019120664012828664, 0.014560909645121186, 0.05742799625882218, 0.024535451985655293, 0.05501236015510175, 0.03409993714622913, 0.06892568131368007, 0.06271787934125432, 0.014593544033085628, 0.008661104704163248, 0.03882568457253999, 0.027488071674240694, 0.007197876768787542, 0.045025637974181486, 0.06064421339561382, 0.01177702082185856, 0.037145515858766534, 0.07909618798763522, 0.02422946880781843, 0.03493487339226469, 0.008952979415264583, 0.045390246030423916, 0.03422356841544952, 0.02541323935973548, 0.006276517665208948, 0.11516869428657717, 0.03181030143863492, 0.01707677973524457, 0.07441007412008702, 0.03466480058587847, 8.968001257988716, 37.340665940315496, 37.95386183646418, 34.78965051712529, 34.71537259317214, 50.90737165943269, 29.198225544344997, 4.1082596298187015, 0.3135015034387189, 0.12697820010925495, 0.8518882396240389, 12.290848916576756, 3.041963298474589, 0.696537007968272, 0.41561057430601894, 0.1774697834926267, 0.1251873929774569, 9.02237021153973, 50.94330449258128, 66.15021597954535, 69.65422614928215, 64.85285674372028, 64.18702656222929, 57.50837941323557, 57.24669064244917, 57.359384259869984, 58.27066067726382, 60.56754573698967, 65.25809641807311, 62.15000244878954, 60.0615325281697, 58.93311369803644, 61.51902644864975, 64.62531220528388, 63.59682752240089, 58.90841453306137, 59.38333903589557, 56.45801182716124, 46.93990207487538, 43.22559010597968, 43.47619425865912, 44.4332996491463, 43.18400905978295, 44.106817245483406, 44.96952687540362, 44.816738790081395, 46.73200861100228, 48.79888980619369, 51.261926466418856, 58.599190558156664, 60.56617682979953, 64.72487372736778, 61.284284360947154, 62.9152843259996, 51.21263404046336, 39.63692342081378, 60.52536456815658, 57.17542509878836, 60.50614495431224, 60.41407123688729, 58.56958450809602, 55.794821400796216, 47.285058882928666, 42.63280622420773, 44.36112019323534, 44.48589078841671, 41.85399216990317, 47.718649448887, 56.74365059021981, 56.88389885810114, 61.23503115869338, 59.20365525830177, 57.52229206023678, 52.641341686248786, 47.17487950478831, 47.43183397477674, 53.17516842196065, 52.925862573808246, 50.90823065850043, 49.99344371980237, 46.915818722017356, 41.3556864184718, 42.103403922050234, 53.60921398285897, 55.38121531086584, 54.96528717779345, 54.321830195765344, 52.9607089104191, 55.18592834472657, 55.14657520478772, 58.309374470864576, 54.38895763889436, 55.593093902834006, 51.51324056809949, 44.620428085327156, 22.00392007827759, 1.8262974725615595, 0.10600090477495425, 0.9205351108985563, 1.8510776589955054, 2.3774789802489744, 1.4055139355121122, 0.7597350329160691, 2.1679126254973875, 0.04159587765893629, 0.027902429480285897, 0.7971521767397082, 15.501387350020872, 45.11691385699857, 33.21777243768015, 46.57743192488148, 30.386617414412964, 35.00084661668347, 10.649335038277412, 0.043184843605324146, 0.08508364775127943, 0.02833072625611338, 0.08100602220022872, 0.07096745884947239, 0.05161119407163032, 0.02794575749806339, 0.06699680215528897, 0.02619406298523949, 0.07081766567763782, 0.16476355643282015, 0.025247421543744784, 0.012268159790114771, 0.02522511689382936, 0.0399158813149458, 0.0345763748872184, 0.03695302094603258, 0.028972612175669883, 0.029144009026969155, 0.04570620750347453, 0.04861656020605757, 0.020887337459792054, 0.02797075494703266, 0.028183497563605348, 0.05045537806807026, 0.07564178262386592, 0.05062142379521843, 0.04729825695375762, 0.01311761914797488, 0.054136112617749366, 0.1027096761390567, 0.042114293187736504, 0.04993561039408369, 0.037142240832890236, 0.044570957130241784, 0.039546550326650186, 0.050508314743638046, 0.03956382560934271, 0.049286205321550376, 0.03287232721284513, 0.011119910820026793, 0.027805425512093692, 0.01953126607282508, 0.03784469749417998, 0.028025631740268682, 0.033695733835620266, 0.0166000911004601, 0.034349360052616365, 0.05581890135222385, 0.03364220727235079, 0.06453653376909994, 0.05036458898816378, 0.03876171623086257, 0.042130970921848095, 0.06372508960926244, 0.08415247554019575, 0.03527248451005548, 0.08710078789942688, 0.011322275818055196, 0.004832175233581614, 0.14850903993412373, 0.09266010410482846, 15.201912426179456, 48.62206935882569, 40.2894450003101, 34.451173505475445, 46.56769660211379, 61.39905291218912, 26.16863193050508, 3.0746768463042478, 0.14558892727138537, 0.03498635450077634, 0.3215826585167839, 3.4850604639899347, 2.670444730789431, 2.7427124400292677, 3.3369703975416, 0.48152560668606914, 0.13191908417690185, 13.119637889246787, 54.487989641005, 67.94072305002521, 71.89177359304121, 65.99896938570085, 64.27480920668572, 60.34385296606249, 58.6379788767907, 59.833074077483154, 60.33373325101791, 64.48825674672281, 64.67174130101358, 65.48384843334075, 61.49870857115715, 60.20068253240278, 61.96268573884041, 66.41679594593664, 65.38973900579637, 62.14714304093392, 60.97369147885231, 58.800898444268014, 49.144823243541104, 47.4527088288338, 46.640087866014056, 46.35903043131675, 44.51103318122126, 46.5458333107733, 47.17305952502836, 47.20133589160058, 50.195022167698035, 51.49545261936804, 55.38234495347547, 60.40108426924675, 64.23037267500355, 65.85761500943092, 61.67908268590128, 63.44281173521473, 51.0652196022772, 42.86417115119196, 61.31298042112782, 58.62745907998855, 61.576147925469186, 62.293035599493216, 60.32845374076598, 57.621049496435354, 48.48893627043694, 45.504263600995465, 43.93687663539764, 45.3057602913149, 43.58933502627958, 49.404790093821866, 57.81288477682299, 61.10280021544426, 60.7334110044664, 59.718513411860314, 58.3327910207933, 53.15506627482753, 49.65257406234742, 49.118398235690215, 53.877033418224705, 53.94681238359021, 52.124883205659934, 50.462319927830855, 47.49890650472334, 43.300648581597116, 44.12594664481379, 54.32507007352768, 58.28342406980453, 57.96613570182555, 54.02950771393315, 55.47569344120642, 56.96751986780475, 56.92607610456405, 59.84474705111597, 56.28545107380037, 57.47130517036685, 55.550061579673525, 48.74449437664401, 26.610014284810713, 3.403692610802189, 0.14596097021093293, 1.3509504569153632, 3.777869074575363, 3.673429594885919, 5.439488041785456, 1.7861588779957065, 0.3458827836138587, 0.061733222701737, 0.12633875417973728, 0.3725936648345763, 11.557074458368364, 51.95472686521469, 40.951760738126694, 48.10393602617326, 34.14422058290051, 38.601315713697865, 16.519409110469205, 0.14017521373687253, 0.04354185589979734, 0.015058664740213465, 0.018364108137546048, 0.04476831670129492, 0.01576618045463317, 0.02712832636109764, 0.04892211054421721, 0.03516019134211444, 0.11566151098738756, 0.1490804036298106, 0.03405661104367145, 0.015155005084741262, 0.001898486056410137, 0.01131846261541209, 0.17740667316942446, 0.021650705771941333, 0.03160725749518362, 0.07550888935164099, 0.023577024281445532, 0.01880545139072403, 0.06014672738890495, 0.02734061507057519, 0.03345414800869842, 0.039302045704736825, 0.05012104197615578, 0.023028664290905002, 0.21825844962750712, 0.15141128742646787, 0.20384933168609298, 0.1974689224434476, 0.15053122094081295, 0.15698074663598693, 0.15771326458742543, 0.23040082065328477, 0.09568566110946479, 0.19805441280045818, 0.11576624286751594, 0.15826167628890084, 0.13580141859429498, 0.13493181686968575, 0.09234670519588456, 0.112133109191012, 0.10402435196503516, 0.14345958588584778, 0.15435133369699602, 0.0949359827885224, 0.11412074729319542, 0.13513790984307567, 0.25298763607298175, 0.10495220701540671, 0.2550623400677597, 0.14373186885589553, 0.21250079325850935, 0.17052910350743802, 0.1628704459196137, 0.10212774043001475, 0.30031023547053337, 0.14879244650083204, 0.08139298087166202, 0.22109182581545847, 0.1399615518147907, 14.927380834856342, 55.765266341547814, 50.44695992623606, 46.90215710670718, 43.43280107744279, 63.075517069908884, 37.73235774809314, 6.5569007012151905, 0.6436589840919741, 0.46776338870967593, 2.3044258163821314, 20.107216796567364, 9.156395639142684, 4.775949505067641, 2.999159698524783, 0.7998080503556037, 0.7125294917533476, 10.0444035760818, 54.42304303569179, 69.69740360013901, 76.670514845079, 69.07863401597547, 69.0251721105268, 62.26696360495783, 63.242743399835405, 62.91473519417548, 62.420383191877804, 65.81814027601673, 68.36844967257592, 67.14161857481926, 62.899924324404815, 62.54252187667355, 64.87658708326279, 68.75317142855737, 70.04946770206575, 63.28503831740349, 65.05842031971102, 60.11619075652092, 52.62798993818222, 47.44345595759731, 49.046964030111994, 50.02821553137995, 46.90108237727996, 49.09221641479, 49.037617021991366, 48.25353522454539, 52.022446586239724, 52.98780464356946, 56.986739481649096, 62.93091497113628, 67.24630663471838, 67.4656298852736, 65.43341459766512, 67.41253668262114, 53.639059297500125, 46.643802350567235, 61.35329061938871, 59.81938892795194, 64.42044681118381, 65.84222362887475, 62.28484176820325, 59.988035155880844, 51.51207170178814, 48.98696745595625, 47.34188225961501, 48.17693525745023, 45.97309274058188, 51.90705045577019, 60.285158618803955, 62.1396513139048, 63.54574649564682, 62.68459404668501, 60.012173421921275, 55.75225976205642, 51.21888237614786, 52.68741776866298, 58.15880252468971, 58.055487294350904, 55.209717519821666, 51.9033791172889, 52.1791099732922, 44.837723470503285, 46.3584852218628, 56.44928847589801, 59.25379491621449, 59.33858479222944, 58.80634661643737, 54.843980035474225, 59.14365476177585, 56.59793846068844, 61.32824628583847, 58.03370245041386, 60.28755910934941, 56.35514374702208, 47.34447494629891, 25.709528307760916, 2.8244811104189966, 0.22545354741234935, 2.1758647407254865, 3.9430001233854606, 8.93279798569218, 5.2384935367491945, 6.592357456684113, 6.82230003418461, 0.33883701168721725, 0.18183912000348493, 1.1700340744949158, 21.010764183536654, 56.54150339864916, 43.30249994031845, 57.57941353705622, 39.825534512919766, 49.23229602075393, 16.384928687926262, 0.1863583339558494, 0.28885814030804946, 0.10741576957967013, 0.16037629346453375, 0.12823792444842477, 0.08565762380678808, 0.17179612100364702, 0.20916144664008773, 0.1281688616220509, 0.21242905678527974, 0.23583491212658345, 0.20291127234457002, 0.08732001928071823, 0.08664960807730114, 0.134894278561396, 0.23437882413066205, 0.11093793542034204, 0.11135320870145676, 0.1447356278978048, 0.0634461340133942, 0.09557181278303747, 0.16365369421339807, 0.17436214782778295, 0.09300684316023704, 0.1518204243433091, 0.17027234147873618, 0.2355554892170814], [0.03793454045549997, 0.04776801440804716, 0.05451745969513732, 0.0274737190169793, 0.048946560240320625, 0.011722212976535723, 0.0612705783738244, 0.024991942712316112, 0.01744467047824254, 0.03677240039612498, 0.023035177953481194, 0.04505604400389618, 0.023398079548872287, 0.028795176636307474, 0.05570834720387094, 0.05593009901443317, 0.015204001195548524, 0.023941622761588906, 0.051732025289487456, 0.05084827009047713, 0.04203108837828041, 0.06337843482352554, 0.051756566916141784, 0.03234178068176393, 0.024839596552473885, 0.03956820763226959, 0.047547587929593946, 0.018216687923056946, 0.007405887834817893, 0.03864710947739021, 0.030448727625151797, 0.0065444138242803035, 0.0690183243263633, 0.037606432658409884, 0.044000723414243235, 0.045344054759029424, 5.604082461326353, 35.825795588954804, 38.75093452392086, 27.39230748145811, 36.4574933052063, 51.59364915663197, 34.243813483945786, 8.076375424861908, 0.051873740064160484, 0.09651966272823273, 0.855723214485953, 0.8564166772750117, 1.5498065347633057, 1.8914748848445955, 0.05920483760776059, 0.09062568867398847, 0.05377358832066098, 5.7811848290504955, 49.40861440473988, 67.28452620967742, 66.2814506407707, 64.7166249828954, 62.94005409363778, 61.67633310441048, 60.17960763746693, 58.736053820579286, 63.42500417463241, 62.19538819405341, 63.06047478029805, 57.154165852454405, 57.195793967093195, 62.60988858438308, 63.51354383653211, 62.67108148144138, 61.71006156552223, 62.35660153050577, 54.6628842046184, 46.571046306240945, 47.105869323976584, 49.874262502116544, 51.754482023177616, 50.86623776343561, 49.04785048577094, 45.48434188289028, 45.581032230008034, 45.904110016361365, 46.134274698072865, 48.21728075704267, 52.30156637007191, 56.598197337119814, 59.92428879584036, 57.99545149649344, 59.21983503526258, 55.61537296541276, 38.3991136089448, 58.94824620216124, 55.12623379307409, 61.371000120716715, 59.596833644374726, 59.05941009521485, 56.378854474713734, 48.042864722590295, 42.758871201545965, 44.01940330382317, 41.79829843582646, 45.74424989761845, 53.6306889595524, 58.78248291630899, 56.68061025681035, 61.93904953618204, 60.06360353962068, 59.66366298737065, 50.42461810573455, 49.66474909936228, 53.892915095052416, 56.063260570649184, 55.796864955656, 56.596926489183986, 52.92700398352839, 50.21309252708189, 46.47766643954862, 44.272372645716516, 49.740031150079545, 55.41988203602453, 54.5441383700217, 57.56217472014889, 55.71053751053349, 54.09972990712812, 52.44982804021528, 55.13629467256608, 57.08936829720774, 53.68900283690422, 45.54254985624745, 20.117848380919426, 1.4637991305320495, 0.05293448072587771, 0.8578034802790612, 2.267782053639812, 3.563840533456495, 2.1195632844201984, 3.589165806770325, 3.153749867793053, 0.2940843614839739, 0.02830223353098958, 0.5593705585887355, 15.77217503901451, 44.414068268191436, 29.22033202263617, 32.38442174849972, 46.23320864092919, 28.469105958938602, 18.258901834487915, 0.12127832975238563, 0.04871799790811154, 0.06042140821415571, 0.10098119025989886, 0.04443897933308636, 0.09147943237856512, 0.074427931629602, 0.002034093195106834, 0.03327076188138416, 0.01781433854522484, 0.06810785947187294, 0.036795103411761024, 0.04913810520402847, 0.01425859698605153, 0.03080810138565158, 0.039654633841447295, 0.004648523848323573, 0.09153891910588549, 0.03192828280941373, 0.06327168430171667, 0.022391748366757266, 0.023560729591296087, 0.019797090921671163, 0.05475019720653373, 0.031849661120964635, 0.033773296407514045, 0.059772144867888385, 0.015544375017916244, 0.03998048934004, 0.023780223357701497, 0.12448824581600006, 0.0014062050186405561, 0.024308937023423856, 0.034658894047982274, 0.024485278972274354, 0.07377356996819859, 0.07705443343448062, 0.07745188751047657, 0.06298782574313302, 0.016411857551804954, 0.03034423323227994, 0.025909855856650302, 0.04768133538985445, 0.07466248476937895, 0.05558753130777229, 0.018990965327247977, 0.01628971823881711, 0.050304094855222976, 0.041748440238617124, 0.05987133793232422, 0.08811165623727345, 0.01960642695907624, 0.10187195133297675, 0.03239012466022565, 0.010097635432987685, 0.01846583312257163, 0.029761508452676, 0.04846558342837999, 0.07477545209469334, 0.04305570416392819, 0.0635414008772181, 0.05126191160431312, 0.05925276406830358, 0.282494830147874, 11.624603944440043, 44.91477058779809, 41.06700389615951, 27.801461681242916, 43.56024280671151, 67.71627718402495, 37.7673609795109, 4.853296193384356, 0.06436410269910289, 0.11378512417356815, 0.5742788134563355, 0.8983016458730545, 2.574944823018966, 4.01133859830518, 1.0554890983527707, 0.3783677920939461, 0.05496635657524871, 10.34199478164796, 56.43163781012259, 68.70415749088411, 68.12120699113416, 66.55957806494929, 63.960599899292, 63.32458365348078, 61.73987550120201, 62.06474188835391, 64.15615750897315, 64.9067501098879, 64.71978249088411, 56.45194392050467, 57.4942784924661, 64.26356769377186, 66.83635619378859, 65.19788411355788, 65.32739685427758, 63.83075375710765, 57.21642563419958, 48.537181423556426, 49.18091297149659, 51.15739137895646, 52.13947050033077, 51.16360441330941, 49.37422698543918, 48.285078925471154, 47.13235708975023, 47.65382443704913, 48.92710424238636, 50.41943273236675, 55.272922592778365, 59.17452381503198, 61.29810287106422, 59.9098309393852, 63.75031771198396, 56.962993452625895, 39.92256218387235, 59.23478318798927, 55.253220527402824, 62.98376498683807, 61.53724585810016, 61.105804750996256, 58.47146249586537, 49.6556648900432, 44.57868622195336, 47.44388741831626, 44.06546761912685, 46.954975743447584, 56.037890680374645, 59.87419620636971, 59.27077093432027, 61.8567229086353, 61.28782233884258, 59.4299485606532, 52.59139030210434, 50.40729299668343, 53.7626963277017, 57.751711491615545, 58.80607989526565, 57.445829376097656, 54.46653035379226, 52.76464923735588, 47.3142413170107, 45.212647145794286, 50.998676592303866, 56.923844275936005, 56.88402045157648, 59.412258671176055, 55.445534336951475, 54.93482605103524, 55.27196553445632, 55.66449280708067, 57.161794862439564, 56.11936223122382, 45.58164804212509, 23.540100666784472, 3.8230984153286105, 0.14677447897772636, 1.2935192354263798, 4.498123613096053, 7.018549451904913, 4.643827407590805, 2.519401364749478, 0.1636446084106161, 0.11158369391435578, 0.10414254400999316, 0.5215448141098022, 13.092693167348063, 50.469611613981186, 40.91440408460556, 34.19039080219884, 50.37505895860734, 33.6928459905809, 26.14198530873945, 0.5695588538242925, 0.052729774371630726, 0.11461986889762264, 0.11121641604169724, 0.05402653523149991, 0.053402502991018765, 0.034503462469025005, 0.026741543889886914, 0.026769573131816524, 0.00913481708736189, 0.04127619682901329, 0.01877510473282347, 0.04336380940531531, 0.08360168896615507, 0.02860501637652276, 0.01581743269437744, 0.017695144840305852, 0.025932216047940236, 0.04502259277468247, 0.009169599394344035, 0.0029488850099545333, 0.03558657672857085, 0.04195134628624205, 0.01338619137963941, 0.03326077592529116, 0.041666189208626754, 0.031665012863795125, 0.015701708410145537, 0.11605925617679475, 0.11950865898641849, 0.13895054558111777, 0.12410026824762746, 0.1463800662707898, 0.09405171048016318, 0.10300380793670494, 0.1014587464892576, 0.10294887177165478, 0.15522052173412618, 0.158397289173257, 0.09918839896037694, 0.08323419658887772, 0.09084192465149588, 0.12837395102026003, 0.11291923031451241, 0.1995443465608743, 0.14437051039309273, 0.23919748653086925, 0.1860770111482951, 0.1255285855562937, 0.2063499039579784, 0.1363975575734531, 0.2053107516539674, 0.17763266910708722, 0.1461855412250565, 0.1778226282687918, 0.18915144456250055, 0.11101885728778378, 0.13988753239954674, 0.17674373132326912, 0.12336310780336782, 0.18015744975737988, 0.11074896451205977, 0.15382590463324902, 0.29620636374719683, 10.258417898608792, 52.66855116813414, 53.319225311279304, 40.13507227743826, 48.339968573662546, 62.26981124570293, 46.053387580379365, 10.937073249970714, 0.28600645461870783, 0.36948135603339444, 2.363684739797346, 5.626923893728565, 9.134524503061849, 6.131043578347852, 0.5453322731679486, 0.45720651325198913, 0.41475206553455324, 7.172722624194238, 53.43098148222893, 72.8609912626205, 73.02911973768666, 70.61487736240511, 69.12051708467546, 67.64700812678184, 65.96387201739897, 63.11832974033972, 68.96770938750237, 66.74487867662984, 66.13858222961426, 58.04998420899915, 59.2136965259429, 67.4487558487923, 70.04053254281321, 65.99266221446376, 66.922726784983, 67.32158476306547, 59.25495201541532, 51.061952267923665, 52.13304173561835, 54.0801376681174, 55.235463957632746, 54.06697811618928, 53.521341123888575, 50.78636653961674, 51.10327051531885, 50.22191393759943, 52.58830339677873, 53.236149511029645, 57.3255616618741, 61.61370069749894, 63.76654455738684, 62.79127074826149, 65.31205254216349, 62.33677787165489, 43.11251601865215, 58.26550276048722, 55.40838556904947, 63.69584775740101, 63.12136957722326, 63.00656180227957, 60.43254167802873, 52.354188888303696, 47.566594846787, 48.75042892271473, 46.369385488571666, 49.09282045979654, 58.67354692951326, 63.05205737390826, 62.078529019509595, 63.39416650033767, 64.70027262164702, 63.32042201872795, 55.68117856979371, 52.897821549446356, 56.532497636733524, 59.14946771437123, 61.09816397390058, 58.31266533943915, 55.68177084768973, 54.52249473141086, 49.91858920743389, 50.14784389926542, 52.86855282322053, 58.42391160226638, 60.119948387146, 60.70350685427266, 58.98134708404542, 56.47538008228425, 55.8831492547066, 55.89634410796627, 58.68979730913716, 56.10442976797781, 47.54127202495452, 22.527354494217906, 3.1173792000739806, 0.17533408357731758, 2.022420516417873, 5.888699937251307, 10.725926180039684, 9.390253232371423, 9.129751959154683, 10.07955389638101, 0.5505710888293482, 0.19491811012548788, 1.1070919229138283, 21.656245108573668, 56.58060550689698, 40.22854628101472, 43.689265251159675, 53.626280215478715, 42.88192379859186, 27.568568991076564, 0.43478069887045895, 0.1327411118414133, 0.29368139923580233, 0.23633631667302502, 0.1362459334514795, 0.16401936330141562, 0.21148540500190952, 0.15257376456452956, 0.14152749681905394, 0.06098565878346563, 0.13114516683403524, 0.07758174707452137, 0.10292349893960262, 0.14000004007210656, 0.11855022936698892, 0.15593454632307255, 0.10440702820497175, 0.15161439265695312, 0.1118484539009871, 0.2983336060518219, 0.10832512360667029, 0.14923193582123326, 0.16606187628161523, 0.08577495783327088, 0.11664699117142348, 0.18306617835356345, 0.07335854183521963, 0.089566801945048], [0.05254893165622508, 0.05359407093736434, 0.02810936515039254, 0.05002556826859232, 0.034342564852728, 0.07806466591935005, 0.10574215857852852, 0.04921901174971173, 0.023779972463906295, 0.037951011345872, 0.01853832610762648, 0.03390650760622756, 0.040381647451149846, 0.015842131369056243, 0.03801622074998675, 0.01967335814580081, 0.03087622575431822, 0.008575513530823012, 0.03535829401845413, 0.04582520777119264, 0.02344752094828554, 0.06818432270759536, 0.05377220936239727, 0.09406572222829827, 0.09376191474016636, 0.01955892950777085, 0.04576565209595908, 0.03083036390073117, 0.04417508885624909, 0.0253682661681406, 0.018099020648327087, 0.07123713712057761, 0.051637045708635164, 0.02276469912049511, 0.053134376047960216, 0.015755535662925292, 0.031285052405550115, 7.679828703403474, 36.24817994333083, 40.78825281512353, 30.83581901365711, 28.427681807548772, 44.49373552876134, 44.496653772169545, 6.740897615109721, 0.3458553576661695, 0.023170817650914676, 0.9170118418912735, 1.3540303755191065, 1.9795205732507093, 1.4310446429637171, 0.11154051719894333, 0.32600295519636524, 0.3171149256729311, 6.303611195856526, 41.966858371611565, 68.4797037801435, 62.331863141828975, 65.41151992736324, 61.52510612241684, 63.09773729693506, 62.170218344657656, 62.15570165264992, 65.19958249984249, 63.17393718227264, 60.768445614845525, 61.78688903008739, 65.48229125238234, 63.855672574812374, 61.57130379830638, 60.58494929344424, 60.87410642254738, 55.04929257977394, 48.83501091311055, 52.42975727204354, 56.882533873281176, 60.07397036398611, 58.05607564987675, 56.77844593601843, 54.76572090579618, 49.14215210945376, 45.975975682658536, 44.45211133649273, 47.5269789080466, 48.57183556402884, 53.06523615314115, 58.33869026553247, 59.50061005930747, 61.42559951351535, 52.60411447094333, 38.89097098381289, 62.55683460543233, 58.99515774942214, 60.70363629248835, 60.64067440648233, 61.534127573813166, 54.51463430158554, 44.66857910156251, 44.885160615367276, 46.07905164841683, 51.4030651123293, 54.958881947302054, 55.84765572701731, 56.4657388964007, 58.465798593336544, 59.20287470663748, 59.86017765537385, 56.502138491599794, 50.55415438067529, 53.734925946881695, 58.549666712361, 57.49365875797888, 58.126474349729484, 57.718583153140166, 57.04274308296942, 51.800852283354736, 51.317749638711255, 45.90236848400485, 46.13175261405207, 54.702460919657064, 56.689902351748565, 59.569879116550574, 57.34127859915457, 57.6297571582179, 55.10718284114715, 54.8826349935224, 50.555668415561804, 45.01701108870968, 16.39116035353753, 1.5621731550462785, 0.37541743427995716, 0.27031700457296065, 0.7803429206532817, 2.0854994606587196, 5.657108983685894, 3.445133922561523, 3.287485775447661, 0.10757290953469854, 0.018005159555844242, 0.3274742117331874, 17.753700556293612, 43.60655815370622, 31.121549952414732, 22.801506596226847, 32.350601111688924, 32.24423035498589, 17.076679852701005, 0.6788895291186149, 0.124878253517372, 0.11963520905063038, 0.020305932266637683, 0.05379077167280259, 0.08116844816193466, 0.030059470689945647, 0.04091543453415075, 0.03177057594932135, 0.10158182617517249, 0.0495364670942147, 0.012105771175195134, 0.03769708767292961, 0.061908672158155716, 0.03871720652246187, 0.022192546354246237, 0.02380814917776133, 0.03373758138848409, 0.015848732174133823, 0.03689925689550658, 0.0673492409048542, 0.017492832510822245, 0.029953103212098924, 0.025607473292057554, 0.0483753995579337, 0.053030548151582486, 0.010792635185944458, 0.05667032381038993, 0.03531126771122217, 0.00581225210372659, 0.08518849454459645, 0.019614752419593356, 0.04698449798348931, 0.06072015569154775, 0.030500917364993406, 0.09426690457809357, 0.04187407865819912, 0.03203319280498451, 0.008312649611804274, 0.02267994106777253, 0.062488141064081466, 0.07726558258817082, 0.0181129653637688, 0.07766879764535735, 0.03231273445811483, 0.013978812100005247, 0.03179624372522437, 0.04557938930848914, 0.07057139139261938, 0.04135901093362801, 0.05332413985724411, 0.07352076095318602, 0.035158563405275345, 0.02953477132494652, 0.029656998738045656, 0.05505135403044763, 0.047621672462311485, 0.019476615275526722, 0.035499392092348106, 0.018049221102809234, 0.013365692782005476, 0.05331737147043309, 0.05152548798510144, 0.04780335787443384, 0.044499530922621496, 0.09744865924961145, 13.508825263669415, 46.55188552794918, 40.656629839251124, 34.05890510928246, 35.13711760121007, 58.55391463925762, 46.99235200881959, 4.592079577907439, 0.16310244798660278, 0.10015068200206566, 0.07271318170692652, 0.84415516425525, 3.5102251652748357, 3.705347391866869, 1.0892005216690803, 0.88664993884102, 0.30864156422115147, 10.168847633946328, 51.10075235366822, 70.98453721692486, 64.27555053464829, 68.16048560603973, 65.30994230701079, 64.67719731792327, 64.2671880414409, 65.54646515077161, 65.26436044323829, 62.83553469565607, 59.70342405380742, 62.48396481237104, 67.0292583588631, 65.84139208639822, 64.04115361552086, 61.93792773831276, 62.319546899487904, 56.846573583541385, 49.81490527429889, 53.884058383203325, 58.7262478951485, 62.02775785999914, 57.585269635723485, 56.54450793420115, 54.71354161539386, 50.24500885317403, 47.78863237750146, 45.852656364440925, 49.85729432875111, 51.989047604222456, 54.905557324809415, 60.611366456554784, 60.42171985872331, 64.21888797513901, 55.424490820977, 42.25630967847763, 61.72133053502729, 58.888555572878936, 62.100207959451986, 61.46091653454689, 64.50316567574778, 56.55574944711501, 46.76906324202015, 46.252204679673724, 46.9449854666187, 50.813505418839, 56.75207191897977, 57.60253590922202, 58.351943954344726, 61.30142904097035, 59.96976475561819, 59.27943152766074, 59.66379242558634, 52.52607499399493, 55.91278668372862, 60.049063313391905, 59.34307198370657, 60.56627881142401, 58.07692696971279, 57.77849735752229, 52.98264280442269, 52.78465724760487, 47.025448968333585, 48.588246760829804, 57.20373284432196, 58.94817167712797, 59.98091997638826, 58.39025766618791, 57.90271882087954, 55.05371701332831, 55.73355397870464, 53.28353958745157, 49.4918784787578, 21.018467718555083, 3.60250358139315, 0.6986697967494688, 0.906991289267617, 2.248311653252571, 6.3099634743505915, 10.892117984833257, 2.596188625020366, 0.9025117586697302, 0.054177745665994384, 0.0576044301382236, 0.10962533569263835, 12.499924975056803, 50.66074086773781, 42.526749257118475, 22.90052094767171, 34.788713070654104, 40.144748764653365, 26.26326499446746, 1.9817400218979007, 0.12094545688840652, 0.0596557263164751, 0.031353877744667476, 0.042989433728038304, 0.05565253769858711, 0.02978382459391029, 0.025964610075818437, 0.1079544366427487, 0.03447587947331129, 0.09823173134317321, 0.03359940594002124, 0.08035031222407857, 0.06088502164329253, 0.01643183520965038, 0.04668169790097783, 0.03990673422512989, 0.023093053980940775, 0.01211242656403732, 0.020161957532588034, 0.068456222633681, 0.07373040091366538, 0.04163963660117119, 0.0641491575797479, 0.06580686842602107, 0.025392669898968552, 0.01614356206940307, 0.010949483069951737, 0.06736032619711853, 0.1787478632984623, 0.19683150664692928, 0.1095300037113409, 0.19541283438522972, 0.22933431901037696, 0.11578299721041996, 0.2659027753097396, 0.10210008465594823, 0.0751606640856593, 0.11955122283149151, 0.0928515418162269, 0.12290098824568334, 0.16215907199488533, 0.09271977469325067, 0.19431377400553998, 0.09579095989465715, 0.16275446020787762, 0.06416022755025376, 0.14749187435353958, 0.11776716493430639, 0.15201199228965467, 0.12700296773184694, 0.1528604499875538, 0.23943874293998366, 0.18006653044252627, 0.15842339744971645, 0.14623722151642846, 0.11933945314658266, 0.12914121871994388, 0.15739844841582162, 0.11631280829709385, 0.1965792185717052, 0.10163043445396809, 0.13612498348999408, 0.13237752651254978, 0.11151617858558895, 0.16907678466410409, 12.869146504709798, 52.56736186242873, 54.79173406477898, 44.56484809998543, 38.49617658122894, 54.21651847900883, 56.95739623039, 10.255878163922219, 0.7703870871374685, 0.14748721653895994, 2.8052801278329667, 6.7266873582716915, 6.2044522070115615, 4.350119838791509, 0.7879423290010422, 1.225050464272499, 0.78419474944953, 8.002138195499297, 46.72007676093809, 72.94492998430806, 65.72209319760724, 70.8708433951101, 66.46281319279825, 68.50917646961828, 67.65615509402367, 68.55852773112636, 68.18711849950975, 64.41470446125155, 59.85680049465549, 65.76397234393706, 71.70578264421033, 68.54982006934382, 66.94778288564375, 64.10373895399033, 65.33121724282542, 59.752508594143784, 52.7554512793018, 57.4107986880887, 63.07625447550128, 65.79626521756573, 62.559890131796564, 59.91387882540303, 58.697634204741455, 53.641287203758, 50.14696921071699, 48.03820494682559, 53.520340919494636, 53.12087105166528, 58.01223924083095, 64.35415091053133, 63.77398921597389, 67.694107947811, 57.47530991031278, 45.82333664740286, 62.6402908755887, 60.41904480226579, 64.81306429832213, 65.09103875006399, 67.61607631560295, 59.945163649897424, 49.176570907715835, 49.12402291451731, 49.39933799928235, 56.85535969272737, 60.17927031363211, 59.76131039281046, 59.353050493424945, 63.757099490011896, 59.884331610894975, 63.23866805722637, 60.77785145851874, 54.438563854463645, 58.52109616802585, 62.7461281899483, 62.74881501351634, 60.86487316316175, 59.762565551265595, 62.40366605020339, 53.443344793012066, 56.55325874205559, 51.76128733542658, 49.62137552999681, 59.10597647390058, 62.92390961800853, 62.91128743079401, 58.2522020032329, 58.87825542880643, 57.01707117019161, 58.90038544131864, 53.63012806061776, 49.68937766167426, 18.860634603808005, 2.761061287695362, 0.7867782430783395, 0.8874320839681934, 3.22050346001502, 6.287434360673351, 10.465868134652416, 10.020448680846922, 8.71772462321866, 0.32215339402037285, 0.19248578096589736, 0.9036569068989447, 23.567721997537923, 54.895033605637096, 42.31786343359178, 32.984038399111846, 42.50487812103764, 45.85152279946112, 27.882250739682107, 1.4195728133763037, 0.22172841423701858, 0.22324033472086155, 0.1124070775544932, 0.1460212613305738, 0.21260888826462532, 0.15335639998797448, 0.15207812099927856, 0.15786297348958833, 0.21250330602690098, 0.24624920329980313, 0.09925630499398518, 0.14141549476452414, 0.21248150316457595, 0.09835218334750784, 0.1422417359126191, 0.13573293033386433, 0.0642108851142468, 0.14151197587770803, 0.13854903890000236, 0.1904397899465215, 0.15604428075734647, 0.11225927621126176, 0.16430601808092288, 0.1769271021288249, 0.143832532809146, 0.08872847959038713, 0.13843682234085378, 0.1855360304996852], [0.06076001141580844, 0.026836527301178827, 0.01645247744877012, 0.047038729347649126, 0.03225769870163452, 0.05631045017751956, 0.02415440559777762, 0.05732582694280052, 0.01516580596686371, 0.07574682860004325, 0.06822989727821081, 0.08346216137250585, 0.04195999541890718, 0.10153698704896436, 0.008790914472492953, 0.0625285790151646, 0.05076432983661371, 0.058765624079012105, 0.03369768352938756, 0.05938157409189209, 0.02304158053330837, 0.025046493918184313, 0.03684657302895381, 0.015746553282013104, 0.016347716840344573, 0.05501921664202406, 0.10529300122852288, 0.04541709358173032, 0.03604070981964469, 0.025903834405565457, 0.0259775971813548, 0.025386974035251527, 0.023517005123017777, 0.02463918220582268, 0.10261322566938978, 0.044824873142304926, 0.009438031814962385, 0.03646059111962396, 7.360750754033366, 36.42700079948672, 35.73799333264751, 37.96259303246775, 36.800618325510335, 42.96166166182488, 40.256034251182314, 7.035181772324347, 0.5321331298159016, 0.017413293432083823, 0.5086660487276893, 2.1476136244112447, 3.955831176811649, 0.9227594012214292, 0.21105425071812448, 0.57372453352136, 0.07534891487129274, 3.6251822354332095, 35.260735019560784, 66.70567066438737, 66.91039485316124, 65.90436181714459, 63.212199903303585, 66.8499589735462, 68.88230369937035, 64.44546368814284, 60.86558311216293, 59.106384400398504, 61.820966582144464, 64.44974691637101, 63.03161005819998, 62.124632558515, 62.93908134583504, 58.14634115465226, 54.472084429956254, 52.79963285692277, 59.31467010128883, 61.284103931919226, 61.62964120987923, 64.21655808725666, 62.84632905837029, 63.809212100121286, 63.59135581601051, 55.76700002916398, 49.48925441311252, 45.327031304759366, 48.1879061268222, 50.81973414267264, 59.23774849983954, 58.475247583081654, 61.40179857130974, 57.32276893431141, 39.28288244432019, 60.286927607751664, 58.06513240260463, 63.29398132139637, 61.14455384592856, 59.773991415577555, 49.61658239364625, 43.498775343741144, 46.626438017814394, 56.0804719309653, 59.13001275831654, 59.32302474975587, 59.81284641450452, 60.394447618915194, 61.422383169974054, 60.43626008495208, 61.66779410454535, 56.01030465095274, 55.02554655075074, 58.77088446770945, 59.13140127735754, 58.53543635337584, 56.869221348916334, 58.7050945528092, 55.04606446912212, 55.486236772229596, 52.6297353929089, 50.64729890515728, 47.12099398336103, 52.87078465184858, 56.53957751489455, 60.24253814451156, 59.639297223860225, 59.34881825600902, 57.6358211425043, 51.30439004590435, 36.90968375052176, 12.84780292741714, 1.0496023561685317, 0.05905881358851349, 0.3819137373037877, 0.5387766442952618, 1.7782267423406726, 4.20981812861658, 14.355995443559463, 2.3050207909076446, 0.2979988869159453, 0.07329914703845017, 0.8725141457492306, 19.51609011619322, 43.52393734839655, 25.224544886619817, 24.42874893065422, 29.858578135890347, 25.8164030890311, 9.080449727273757, 0.7251141100160537, 0.03928361362927864, 0.033032182949565114, 0.03279343547840272, 0.0671521188210576, 0.018124060232132193, 0.05708727865449845, 0.06064749991280898, 0.11249785897352042, 0.04458478884771467, 0.07617239044198106, 0.017243650922131155, 0.029451997439947822, 0.02691328931119173, 0.02920263965103415, 0.019428164044755603, 0.10240713269599985, 0.01919407630339265, 0.02388703325132449, 0.06611418459684619, 0.05088701498724761, 0.015990733274168546, 0.058686525500830145, 0.04543488214333211, 0.028690486891014923, 0.07588405026904038, 0.05129489551989302, 0.029240459496636066, 0.01601883625206087, 0.004031359586083601, 0.006214271584946302, 0.055332684498881145, 0.025978593095656366, 0.04477129295288075, 0.02944720747520126, 0.04150486258309215, 0.0075180071965611035, 0.033338924554447015, 0.024243819549860015, 0.05821175017063657, 0.09472037500311291, 0.07572144044623261, 0.041812297497545524, 0.03669560008171586, 0.06970490764586196, 0.004713125170148429, 0.06548991486910852, 0.02327553037884495, 0.03735179652369792, 0.05447109222352024, 0.07348824818167957, 0.13155655604937386, 0.03196091623976827, 0.03321931141638949, 0.032351310815541975, 0.07163272960291756, 0.04626987201552238, 0.01450853604417775, 0.059628338673182076, 0.02044887852764899, 0.017910804336650238, 0.031482982712106845, 0.00796504822867592, 0.028017957454487204, 0.03390278441891555, 0.07913649187333162, 0.0843737293936072, 0.06383122726073188, 12.874966321452973, 43.681228314676595, 39.94561787574522, 31.905151259514597, 38.370472461946555, 61.029926500012806, 46.06036547691592, 6.473985227846331, 0.24420204782678237, 0.06872676658414065, 0.6253461119148039, 1.3461969119887198, 1.9374924994284108, 4.315261735070137, 1.2111992268793046, 0.41089459833118225, 0.2877614088356495, 7.332791609148826, 43.937221803972804, 69.17531259598272, 66.579284052695, 67.6777595089328, 66.06335901444959, 68.0550209168465, 70.61188067159345, 67.05251801398494, 61.300868142035704, 61.24900656361734, 63.641220908011164, 65.09514154926424, 66.27916782133042, 64.367118266321, 64.39502200772687, 61.85836245936733, 56.84709133640413, 53.93186423086352, 59.91354150156821, 62.99395530454574, 64.76841203628048, 64.80308186623358, 64.1137723768911, 66.25571204769996, 63.77909221956807, 55.40179206478981, 50.34862218364593, 46.03511718011672, 49.44113477583855, 53.7357339551372, 59.423241307658536, 61.4932329423966, 63.93449652579523, 60.47999843474358, 41.79044192837131, 59.91136850849275, 58.343604995358376, 63.97592852192541, 61.74322128295899, 62.22682991335469, 52.857193639201505, 46.161550860251154, 48.2817723674159, 56.781952534952474, 60.409136895210516, 61.53807740057669, 61.3697841859633, 62.01894037185177, 61.69699222810807, 62.042607953471524, 63.0519397028031, 58.44609260559083, 56.73091857664047, 57.911697126203975, 59.803036566703554, 59.61360177686138, 59.94950179130801, 59.20898968173612, 56.92240868845294, 58.71863065227386, 54.3242032297196, 52.64510323924404, 49.268711305433705, 54.28102577886274, 58.02720308303834, 61.27928726134762, 58.72423179687993, 58.48475148600917, 57.67130682545324, 53.73516128909204, 41.798451408263176, 17.309629417234852, 1.6136903003338845, 0.2712937360329013, 1.501916356144413, 1.9881580000923527, 3.7484613493565595, 6.773926913738252, 4.721585454479341, 0.6612839706001744, 0.04317564288935354, 0.05606308038676939, 0.41112276995854996, 17.716079142785844, 55.41411222950105, 34.629045148049634, 25.077605055224513, 34.116218782240345, 33.95389149265905, 18.056483999375377, 1.914628758545845, 0.07634714275838868, 0.04842616437423614, 0.0927813834841213, 0.07555237250222314, 0.02692227935298316, 0.053844045427057056, 0.08781341054747183, 0.11785361795656144, 0.04083636276904614, 0.052304813908713485, 0.0727236311462137, 0.015046157397239681, 0.01126707056462164, 0.012581695637275136, 0.022121981995540763, 0.07207996407223326, 0.011098346402568203, 0.07910370331017241, 0.0722962613367746, 0.05346193226174482, 0.08585519788246002, 0.0584892348776902, 0.020878900916525917, 0.05675013868078109, 0.05271698836417449, 0.01301705287093477, 0.09474184844763049, 0.005582826486187837, 0.012968674418516459, 0.17072618728683842, 0.12116617448027096, 0.12227648103068914, 0.13543948801534791, 0.060328140839814186, 0.08692448042453298, 0.10810363226600232, 0.10679140792138155, 0.13780463126397904, 0.2757887109633415, 0.1574050520937289, 0.15565241146231854, 0.10281675224823338, 0.17658714295154618, 0.12749836614896215, 0.18074045798951582, 0.18300593319919803, 0.18717778756493525, 0.092491572422366, 0.12325936417666175, 0.1442134010815813, 0.19972138948017554, 0.10096826635661627, 0.1272753426324456, 0.12015041084058824, 0.25670389795014936, 0.20148590447441225, 0.12380754605175988, 0.09002565796817504, 0.08604729442947334, 0.1788233382807624, 0.16307160528677125, 0.08302483242005111, 0.16839093678901274, 0.21841989499667, 0.09660104424842904, 0.15607356063781247, 0.17702192849209233, 11.025499163135406, 52.212418740795506, 51.195501127550685, 52.22837102028632, 47.224497487468106, 52.69969478730233, 50.800749871038626, 10.000878995464696, 0.8543668711377729, 0.13723847696617728, 2.3690240661944113, 10.185156849122817, 13.756872030996508, 2.6254747567638277, 0.2909103979266459, 0.7144847319972131, 0.34191935112880123, 5.782848894596101, 40.92644576103457, 70.84346525130734, 70.64690743723224, 70.7261000910113, 67.94934441966396, 70.1489076306743, 71.53617935795938, 68.27898825368574, 60.89432231841549, 63.817554981477805, 65.44837059513216, 68.57232662939256, 68.92950550202401, 67.63553127165764, 67.4672302123039, 64.4302801932058, 57.64740390162314, 56.73421336758522, 63.63454111160771, 65.3116681498866, 67.21581412899879, 68.5342953282018, 65.09008169174194, 69.25844330941477, 68.99318910414173, 59.37478826891992, 55.48858234959265, 49.77537955007246, 52.78563784014795, 55.28695683325491, 61.276274881055286, 63.965028255216545, 65.21626434018536, 62.24252331641413, 43.5587562284162, 60.465211099193944, 59.92272377014161, 65.1467481736214, 64.28106146474039, 63.488707388601, 53.85172628587293, 46.209882305514434, 51.13988191850724, 61.47064009020406, 63.69945633795954, 63.81873953726984, 64.80401146796443, 64.00391855547505, 64.04693518915485, 63.43397071284633, 66.46312698241204, 60.64884470355127, 59.45809941137991, 61.65107696287094, 62.5294093931875, 61.38231223629367, 61.08538489187918, 61.8363775745515, 59.37991480673514, 61.14455384592856, 58.58852171128797, 54.7222492771764, 51.81339994553597, 56.82675776943084, 60.159470189002256, 64.26889819483604, 60.706476088493105, 60.781283532419515, 57.607140771804325, 54.56416991449172, 41.47473819794194, 15.324942469596865, 1.7700959141215973, 0.36791400142735053, 1.1191418118053869, 2.046718128746556, 4.482967084453953, 18.434624018207675, 31.175253083628995, 7.6961080105074, 0.4602980763921815, 0.4002969057088898, 1.2574438486368427, 24.850862641488355, 53.93911669331213, 34.76089169902187, 33.76304464955484, 43.46110490060622, 41.01542865076373, 17.336699654979093, 1.404953036577471, 0.2232157892637676, 0.07999985764223723, 0.1872389367030513, 0.17432234189923734, 0.09597971629832061, 0.15863128306884922, 0.14418174632855002, 0.27178384844333897, 0.17171716798217068, 0.15393832037525793, 0.11388848475631207, 0.112631403420481, 0.10683810864124568, 0.1743877351644539, 0.17326158591576163, 0.32940429364961965, 0.10573273569705988, 0.13140571333708304, 0.20126096573808502, 0.1813115918588254, 0.18849895215563237, 0.24035751218757323, 0.15981776940245784, 0.17059789820303842, 0.21770487449342207, 0.15202146113639878, 0.19808957623618265, 0.15737356588004098, 0.08245185227884401], [0.016438946420807513, 0.026733624455969662, 0.05758256598886463, 0.05006985581149498, 0.02482201100417203, 0.006867920305775179, 0.05275679812315972, 0.1144984286398657, 0.0861699374452714, 0.09179271637432038, 0.018753405292368224, 0.055424515458364645, 0.044359911398421374, 0.019840633444067453, 0.1767064994501491, 0.012650075687786505, 0.08374048111539695, 0.02526152522243079, 0.020783434869841706, 0.07337502804735015, 0.06429160779882824, 0.03436587307782423, 0.02121974492535716, 0.08217835122899664, 0.03782873222183797, 0.06299891103539737, 0.05615703724024277, 0.04333777773764826, 0.06952850057953788, 0.05186617111546859, 0.071213832725921, 0.0413854256452572, 0.009528808445940095, 0.02336418781910212, 0.011320577975693009, 0.019471681669294354, 0.0037979333137627695, 0.029509136107780283, 0.07883083811330219, 5.275744286275679, 35.87871228494952, 43.295016058029674, 36.87610826184673, 37.06320139669603, 47.336390941373764, 47.41024524934831, 12.674297863437284, 0.6938838922689039, 0.04477737569099954, 0.6066264776933579, 1.4407802108795413, 6.857992131863871, 14.393911034830156, 7.69182478227923, 0.47223004903043475, 0.21707781620564, 1.1815749132825484, 24.107661747163345, 54.197279253313624, 65.50294253133958, 65.92507977639475, 68.9567110615392, 66.83594826729068, 70.48215220051428, 61.84931747374996, 63.12340136497252, 67.15635884192683, 66.14019040138491, 63.82323849585749, 63.920030824599735, 61.811784313571074, 62.255149425998816, 58.21086414398686, 58.51169816909298, 62.79439295491865, 64.60850877146568, 65.01811404382029, 64.16168020617577, 62.739326800069506, 64.26678403731316, 62.9429841041565, 60.84117812495078, 55.256025022076024, 53.45750454933413, 48.20388194053404, 52.395087442090436, 60.79291335998043, 64.67724830873551, 64.60895199929514, 59.61650825315907, 37.850856473368985, 65.05751032983103, 63.48536945158436, 63.33836293989613, 63.03189639122256, 60.053789769449544, 48.172295093536384, 47.48438589034542, 51.65986660988101, 58.244286660225164, 61.29340387159779, 60.741342036954826, 59.216081327007664, 59.439052381823146, 58.78350665492397, 60.7670610181747, 61.051981987491736, 58.22758913040162, 57.216100077475275, 59.50370480937343, 60.92729768445415, 58.78033345745456, 60.953801139708496, 61.52183486569313, 61.27831843591506, 57.491540678085826, 57.61137300922025, 54.714910522584, 55.53439955557547, 57.889720086128484, 57.031721222785215, 59.86492764565253, 61.17835290970341, 56.871088397118356, 49.741031354473485, 27.273226284211685, 6.541313692446678, 0.76188265315948, 0.10874559862479087, 0.3546516404997918, 4.777991098742332, 2.809114980120813, 2.2011539772633584, 3.2755026894231, 3.492107492300772, 0.05493560580596809, 0.16201460313412452, 1.3203799940886036, 21.991246900250836, 42.90391260577787, 22.946651943268318, 24.783648906215547, 31.5439421515311, 25.75312152985604, 5.714855588251545, 0.04380132604931151, 0.03855409491206369, 0.022800655457221215, 0.03410801554339067, 0.03686959780151806, 0.029264497420480175, 0.07712901975478857, 0.0411393198995821, 0.02800814003773755, 0.05334457142218467, 0.0624241459093267, 0.008484135520824743, 0.06996389132954421, 0.014045082535895129, 0.10433606548054565, 0.008660639305749248, 0.09707880732152732, 0.04545745875446066, 0.021767898072158138, 0.04315431117110195, 0.026337669997085488, 0.013793583531233092, 0.06390947931175751, 0.01860251086914251, 0.021512139618637103, 0.07660220407189862, 0.021555662988835288, 0.021293467481530482, 0.017457801225264708, 0.03620622311568549, 0.0508568196317121, 0.02145695255979175, 0.05011517757309541, 0.0710929210688318, 0.030691841797482584, 0.10101288331732636, 0.020360770755477493, 0.015304962965479542, 0.0554461459509067, 0.09008672283661943, 0.02468172881391741, 0.01779290148988366, 0.038218536909909985, 0.0600955335633649, 0.01375876579268445, 0.05232501947771638, 0.031079254376011032, 0.03117659733810973, 0.09668169032421806, 0.020251038236423366, 0.06598339040553378, 0.09592300280928613, 0.015480458387173714, 0.006669440809937735, 0.032854462042450905, 0.028363510988832965, 0.07164340886858202, 0.09241844166911418, 0.05508804581158104, 0.015610068972643106, 0.04987558357477669, 0.04895320988350338, 0.03085712718236591, 0.02479549861633249, 0.04715394131058166, 0.03520812929397629, 0.038824937636813814, 0.008652101255833142, 0.017734923955774116, 0.056986986253891266, 10.715375984868697, 43.283033217153246, 48.69067161313949, 32.70726811501288, 34.71979702672651, 60.29506652585922, 45.34292082632742, 10.540328448818578, 0.5197634451812314, 0.09430016811576583, 0.25915256010428556, 0.5385481662327244, 4.560539799351846, 9.419165022911566, 5.161183130356574, 0.9363862667833606, 0.4250802484250838, 3.308485409905834, 34.685503744309955, 59.48329671736687, 69.94241053058256, 66.64499159782164, 70.18213010603382, 67.97452603617023, 68.85209360430318, 62.90316420216715, 62.590390482256495, 67.51301211695518, 68.24314563505112, 63.749133156191924, 64.52120465617027, 63.197738124478256, 62.340351150881865, 60.92279088112616, 60.22776649844263, 64.42949964154151, 65.6605080635317, 66.67433092671057, 67.141202803581, 63.94964079703055, 64.31884173424014, 64.80916546237084, 63.3494318685224, 57.18266579412646, 54.60974393352386, 50.23646200856855, 54.44762845193186, 63.58036141241751, 64.23691518845098, 66.74239189394059, 61.979548008211204, 41.19749330705212, 66.19047518699401, 63.94940937719038, 66.19567624984249, 62.75260794547297, 62.2355140409162, 51.493977808183246, 50.124372436154275, 54.510052973224276, 60.94105343664847, 62.87324044012255, 64.34005391213202, 61.42890999394079, 59.81308175671486, 58.999535114534446, 59.53462093107162, 61.50786338313934, 59.555793885261785, 59.5688828345268, 62.014096244688965, 62.84325392015519, 60.92148080948861, 61.99373522112447, 63.573218776333725, 62.33573059881888, 60.02318743736514, 58.96802279257006, 56.953901398566465, 56.48748451663602, 56.993372209610484, 58.447559572035274, 62.562349457894605, 63.423803929359686, 58.669322536837676, 50.58245820383872, 31.526446419377482, 9.863302842263254, 1.2393076669785286, 0.7006290819375747, 1.529732947388003, 3.827454207404968, 5.573700762564137, 6.412532473764112, 5.015925015172651, 0.5940330953847978, 0.09796651936466656, 0.16444562994424375, 1.1244942536277156, 19.342886094124086, 46.18772875878119, 28.654920401111728, 20.851659121051913, 32.75689198124793, 33.65679156395697, 12.001174034610873, 0.37192882309036873, 0.11982199660832844, 0.02914036819410901, 0.03160042782133866, 0.020892918410320437, 0.0269328992468335, 0.0387352517235183, 0.033518847964343526, 0.09214891661559382, 0.014864300572944265, 0.020121012048255053, 0.048735905213341604, 0.06617321167141199, 0.046842840665410605, 0.06523383465865928, 0.002373773229098128, 0.07516749758994387, 0.05589668608961567, 0.06304484949777685, 0.04483082564547659, 0.05002552230331687, 0.032409893559111703, 0.05291269318531117, 0.008760326496896245, 0.03654395680754416, 0.05503520872744341, 0.07273424912484423, 0.048380608955818805, 0.008078791696818606, 0.017323996308409882, 0.039020791845095736, 0.14369825291777813, 0.17566843499099055, 0.11569161824281178, 0.12423126162180018, 0.16960192261443985, 0.1624920444502946, 0.10533585618700712, 0.24914956621585355, 0.1648335615473409, 0.2073292094733446, 0.09389900617421636, 0.11188369394550401, 0.1480335598030398, 0.07225178993277012, 0.32432988045677064, 0.10417815177671372, 0.1843165410982986, 0.2072753381705092, 0.16305810681754546, 0.22806003900064578, 0.23342810901662997, 0.14787136366771114, 0.10807907148714989, 0.3099020240047286, 0.18598944729854985, 0.21502249423534642, 0.20077520470705726, 0.16907721367334166, 0.15858311146017046, 0.23788291029632094, 0.12112953249485263, 0.12283119763578139, 0.07200468061191422, 0.14096033128519214, 0.16890931784385638, 0.11345160779573264, 0.13177197997368154, 0.1173937583582536, 0.22289665235627085, 9.317287341240915, 51.06481167577928, 57.93649042806318, 48.918494639858125, 46.51969071357481, 56.198880441727184, 58.01408275481194, 17.16230127119249, 1.1768993254630797, 0.19201868183670506, 2.308530331619324, 4.9755961856534405, 19.705054221614716, 26.900669759319676, 12.804295997465811, 0.7373912512294708, 0.3668531535133239, 1.957707046981781, 29.22875923495139, 56.79662612176711, 68.84830459471672, 68.36281714900848, 73.93816824882262, 68.94818382878458, 69.85134093992173, 63.79709197628883, 65.40739751631214, 72.23200782652825, 70.54820491421607, 68.45512620864376, 70.62530302232312, 68.5032380011774, 66.05726365120181, 64.59871069077523, 63.912578321272335, 67.51900549857848, 66.56964286681145, 68.75448934493527, 70.54250963272588, 66.73331552936186, 65.24421907240345, 67.34115739022532, 65.6095015618109, 60.32048348457583, 58.355674128378595, 52.76564944174982, 57.10612466258388, 66.54609295629686, 67.9795466699908, 69.38925435466152, 66.06913274334323, 43.9160684616335, 66.73233493681877, 64.87779909564604, 68.8339408751457, 67.2723747068836, 64.05744714121666, 52.36820743929956, 52.4441719824268, 56.63922140675207, 62.957065413075114, 63.58016137153872, 65.29929699436312, 63.00767967777868, 61.73080698136361, 60.37223915899954, 63.21397281462147, 62.52065466296289, 62.13094757449243, 61.432153794073294, 64.61274885362195, 67.70858149374685, 62.616780188775834, 65.1579269286125, 66.09134120325889, 66.67688046732258, 61.52500414079236, 62.60467575442407, 59.73657984887401, 60.331564180312625, 62.32623846300187, 60.82002870498165, 65.05186603915307, 62.827289873553866, 60.28228744383782, 53.79599332809449, 31.58893369859265, 8.759696925840071, 1.4091856417156037, 0.3243580418488672, 1.0536785567960432, 8.83350024300237, 7.772062747709214, 8.338009772762176, 17.77023530775501, 9.144219621535271, 0.49605146110538517, 0.30018879521277647, 2.1970813312838158, 29.239459460781468, 53.72076226818947, 30.14561326273026, 33.8772758360832, 43.87789595511652, 40.22587906929755, 11.684059231512009, 0.43742125072786886, 0.25668358129839747, 0.10887828505327625, 0.16308026208031565, 0.12504239551602833, 0.13504714374580692, 0.14996062333305038, 0.11619657743722202, 0.1845607699285592, 0.21584878134871685, 0.17680298056333296, 0.2479731309558115, 0.14876336580322636, 0.19265686372114768, 0.16249046630917058, 0.11279464909626592, 0.17728337897889077, 0.1199975609779358, 0.14131147534616534, 0.16316223348821365, 0.11896874320002333, 0.11806239223768634, 0.19073694013059142, 0.08789682986154672, 0.10240881042855401, 0.21025606370981664, 0.17925345068497045, 0.11692040029071993, 0.10881463080764779, 0.1276196685108927, 0.2353220928700701], [0.06979138365075474, 0.04745000748023872, 0.02723472065202171, 0.0343491149044806, 0.060726629134507916, 0.004467081190312221, 0.05025341047815258, 0.03605694705319982, 0.06865419507507356, 0.048663804848347945, 0.015230391009320176, 0.029963973999744462, 0.018270609021607428, 0.026433758490208178, 0.035980349752090635, 0.020655710775885853, 0.006991838857967167, 0.019080919371316993, 0.028780532865634853, 0.02646069222640607, 0.06790327569169384, 0.02924607492112104, 0.031580967272842125, 0.0038781913181376317, 0.05168789479460928, 0.025510038399407943, 0.01129475219415561, 0.06828409799885365, 0.022501375548721805, 0.03716948674991727, 0.06804732320409629, 0.03335638752868099, 0.00852489427122618, 0.04025503609990401, 0.005370137974574802, 0.07818966848595489, 0.07291781145238108, 0.1040871405313092, 0.03181186617322026, 0.03695453780012266, 4.996445054008115, 33.49618227251115, 45.812153970041585, 34.01484512513684, 32.94951761922529, 48.60506196175852, 53.31659732326385, 16.964205888009843, 1.1927479072924585, 0.06516489440635329, 0.1732348954124797, 5.430840196148043, 19.6164616077177, 12.927513334058947, 13.028307460969495, 1.0550423158753304, 0.054027711176463676, 1.2826003374591952, 17.80900009216801, 42.381292081648304, 56.72015951525781, 65.68203403103736, 67.32553066745882, 67.96926221539898, 66.42103210572274, 64.38403152650403, 65.20249289851036, 65.77044425472137, 64.04155369727843, 63.67517294422273, 62.938877382586085, 63.85490771262877, 61.68083990773847, 62.306069635575824, 65.61913882532428, 63.24038213299167, 64.97867853410783, 63.81806881197038, 62.546322653370524, 65.47436806463426, 67.19014613859116, 63.941125331386445, 62.65245022312288, 53.174215286008774, 51.12777748415547, 51.58949144424931, 59.43070557809646, 60.193594809501406, 66.46307991396996, 62.19019889831544, 35.16135000413464, 59.62610237060055, 65.17511083233741, 63.916057463615175, 61.56713824118338, 58.65998337345739, 46.105802212992025, 48.39352461599535, 53.66843000535042, 57.65437787578952, 61.93887302952429, 63.259731185051706, 64.0813265308257, 62.24537095715923, 61.506494475949204, 62.738954174903135, 62.62525643071821, 61.25945968012656, 59.052698919850016, 58.683211649617846, 60.89142760922832, 60.65196298783826, 56.71551150660361, 57.640782940772276, 58.11133007849417, 61.825026235272816, 59.175323978547134, 61.15202203873665, 57.48152294466573, 60.08768297010853, 59.75535231251871, 62.496649757508315, 59.67951720760715, 47.71853177778183, 19.053160221345966, 3.276768879544351, 0.24185642449846192, 0.12647733182436036, 1.1063971730970568, 1.5845716047671534, 1.2886238723031938, 4.989722111532766, 6.9697027052602465, 4.923118304821753, 0.2502708431453474, 0.07065631223902588, 3.0157834387594655, 29.711995240180727, 44.77096865254064, 52.066871350811375, 52.585385153370524, 40.71048398171702, 26.16071266512717, 8.249892746248554, 0.17712849132235975, 0.021071024276616595, 0.0818943854181036, 0.04333415031132679, 0.06801261942112638, 0.06366376810136341, 0.016664047950818654, 0.04211599390292841, 0.055967771388109655, 0.004024466709984888, 0.03549426313369505, 0.0977433119870482, 0.03595857370284296, 0.03393216772125133, 0.027566507586368152, 0.013606026055171125, 0.061023017061093164, 0.04828472539121586, 0.049350978055548285, 0.009142146633577444, 0.03870061305802196, 0.05577938653708947, 0.04701336800691582, 0.025645109276557644, 0.0983051072445608, 0.04308215334951397, 0.03483383405593134, 0.017586666790227738, 0.07858135391988101, 0.09906417780345488, 0.04628056277250571, 0.045771301994400646, 0.011040693498216571, 0.08788442689805262, 0.05570011558912455, 0.057614174776620446, 0.030622700447096463, 0.020366512584469972, 0.012900766469688426, 0.07159843184654752, 0.030441390418057, 0.012343375260130534, 0.005453147910415165, 0.05666571196108576, 0.020115940546196316, 0.08872913076512276, 0.05113857527894359, 0.03222627377498054, 0.027643568370671525, 0.05040095518192938, 0.07428005367757813, 0.010204875293458182, 0.06176916371670462, 0.03677620019222941, 0.06106765700444099, 0.011423723096208227, 0.027417744802791747, 0.010497664522019126, 0.020893782174455065, 0.09165678939391529, 0.05168431333356327, 0.049226197654441486, 0.015252060763868354, 0.0679435029685978, 0.032694280718363104, 0.09038810948691062, 0.020193464813693877, 0.04441585496909196, 0.062309803456188216, 0.01581911713020095, 0.013597234238630101, 0.04828094474730953, 9.64371188994377, 43.1943170485958, 50.158116586746715, 32.61061699159684, 32.768474740366784, 64.0273037264424, 54.12019683468727, 12.429880269112127, 0.4368647338161546, 0.07383183095484011, 0.2808224908526867, 0.9062516160549656, 18.144884417133948, 22.119190692901615, 8.076240103090964, 0.7117289605159914, 0.3315852233959783, 2.535445329643065, 24.398844780460482, 49.41387430314095, 60.52811022727721, 69.70338129228162, 66.53037209664622, 67.40421341311547, 64.92374573984455, 65.42476184906499, 67.64020673690304, 70.37366728628837, 65.44532683587843, 66.96353512425577, 64.62683800728091, 65.171117859502, 63.47137443480953, 64.57383501914241, 67.15162846349901, 65.60178233731177, 67.83957296802153, 65.43550522096696, 64.46791141263901, 69.57732415968373, 67.41131290312737, 64.79148734000422, 63.48137647874894, 55.59547870389877, 52.73419987770819, 52.917468701639486, 61.30587308637558, 62.5101544780116, 66.42917494620046, 61.635603212541156, 38.72384271314068, 61.58498502546742, 66.37526589055216, 66.05134087224161, 63.49540679685531, 59.69024489002844, 48.910057621617476, 50.06701953949467, 54.81157341311055, 60.51850434272521, 63.915398505426225, 64.3405245965527, 64.57545495802357, 63.27525200382356, 61.806151790003625, 62.95829703730922, 64.14447276822983, 63.028166217188684, 61.129142853521536, 61.03578259868007, 61.68374638403616, 61.17213203061012, 59.15269582502304, 59.71191206286031, 60.04418780726772, 61.26860272499823, 60.09592386984057, 62.49899925724153, 58.85419168779927, 61.07531616764685, 59.84494316962458, 62.260177904559725, 59.440334996869495, 51.69321852345621, 24.599776037277717, 5.1009281700657265, 0.6819010513924784, 0.406982064727814, 4.535662656830204, 3.6889406077323423, 4.023611204278085, 7.249527535130901, 1.8714837898169796, 1.0585840935668638, 0.13522884447968778, 0.13589057590692274, 1.4821129220147289, 26.715122038318267, 55.486252461710286, 52.22760615810272, 41.50133186771024, 40.02356713817966, 32.327841558764064, 14.122354561282744, 0.4990727586611625, 0.14031672549824561, 0.08090938020858073, 0.042376502101579984, 0.0746120072360481, 0.08726374246180059, 0.025472032777484388, 0.06374396984615634, 0.037342906073336644, 0.02504317675747218, 0.06885343156154118, 0.08564578774835795, 0.03511777305374703, 0.04058474502075584, 0.07183388130919588, 0.04476387339133409, 0.03159614155940231, 0.01795121164421641, 0.04426516547438599, 0.06597916160019175, 0.043807615631169854, 0.03344059974375752, 0.009598182495533219, 0.015436054973472512, 0.03909957632722874, 0.06045548380502771, 0.018130026141842528, 0.1078920464421953, 0.042178996973821235, 0.04303994573532574, 0.028017038148978067, 0.06415208786605828, 0.14185412606645015, 0.14257144483347095, 0.1965939274598514, 0.1074060632456695, 0.1333211629741615, 0.06721146765255159, 0.22686143315607504, 0.15288165530129788, 0.10631242676848367, 0.1847762857834178, 0.05117237890860246, 0.13673242992691456, 0.1267232460480544, 0.14690534211695194, 0.20517005194579402, 0.12456742100297444, 0.10491440823722271, 0.13647744522219704, 0.1303031136311831, 0.07301947898081235, 0.149370628379045, 0.17317512523262732, 0.21665254547711343, 0.1623849453584802, 0.15042963768205336, 0.1321516531489549, 0.1283240097484762, 0.16028241705029242, 0.13616860453640262, 0.17251570739092367, 0.11138681697869494, 0.11570169995989531, 0.21348178416730898, 0.2570379735721696, 0.08638764431159343, 0.26162478712297255, 0.12840625694802693, 0.13745880385320033, 0.2153852521892517, 0.07573382042708897, 8.65978729340338, 49.40902625360797, 64.09100301804082, 46.71234184695829, 46.469260800269346, 57.40952784015287, 63.85969692660917, 21.682215121484575, 1.969684984895491, 0.3630761868290363, 0.8800883038390068, 12.338442956247638, 31.264247740468672, 20.516541619454664, 18.968299742667906, 2.817318372188076, 0.23941822710537145, 2.357696015988627, 21.534683012193252, 46.31493514583957, 59.40638296065792, 69.39947605133057, 67.74569496031731, 67.30643656945998, 65.92121231940486, 66.18217545170938, 68.00933314907935, 72.06452262017035, 68.28573473038213, 70.21737652440225, 66.61718983804026, 68.66673023469987, 66.68065378742834, 68.0397472073955, 69.16811896908668, 67.6024107779226, 67.5264972256076, 66.21608826421922, 65.14183344379549, 71.15116734658518, 70.79036420391452, 68.36522548429429, 67.93246253844231, 59.62671033797726, 56.293739041974476, 55.7051952423588, 62.48802054312922, 67.02966628536102, 69.82499830184445, 61.90202236175538, 44.241938975549516, 60.20404792601063, 66.62088471074259, 66.79415933547482, 64.53396804871099, 62.85916305357411, 50.66620865175801, 52.363598654347086, 59.045513137694336, 61.42700372203704, 65.74950664274155, 66.42091443461757, 65.26310920715332, 62.824885460638235, 62.68931658037248, 66.0862813457366, 65.87925864804176, 64.7244030429471, 62.978418796293205, 60.73375617304156, 62.71289786984844, 61.542062528671764, 59.12078734367125, 60.294682133582334, 60.27530954730127, 64.05297563922021, 62.62252253870811, 66.33117844981533, 61.180596505441976, 64.57634141368251, 62.46853028574298, 64.96714676580122, 61.82706979013259, 51.438036964785674, 21.54042536212552, 4.779483560592898, 0.5444403016759504, 0.24564998464718943, 3.364061227729244, 5.168371363993614, 3.2278814383091468, 12.041031199116862, 15.254428059824052, 9.212674786967616, 0.3839410204560526, 0.32326366992727407, 4.754892751093834, 37.668030877267164, 55.92163947320754, 58.55484424098846, 57.59717795156664, 51.44501486132222, 39.17135769321073, 13.212615712996453, 0.6222281340629824, 0.24685680295430848, 0.16610479252713342, 0.11496542051674859, 0.20490299369538986, 0.12245423641175994, 0.15567925518318532, 0.22465928277421385, 0.15339137956259713, 0.1055684787852149, 0.18147008012860052, 0.10315760008750424, 0.18225568797319167, 0.1140407600530213, 0.1403893659552259, 0.14417638371308006, 0.15448492410923206, 0.09365802555675469, 0.12976159672102622, 0.11899883513368907, 0.11795643461687912, 0.115996161175351, 0.21058399530668415, 0.19790386120157857, 0.20011805448560946, 0.13955774686990247, 0.16273546122735547, 0.14585244619557935, 0.15400844806384656, 0.23046293506218543, 0.09079766009123096, 0.14611288544631776], [0.017656476552327795, 0.06713663618410788, 0.03305481318684836, 0.007431380846913183, 0.04679467288717147, 0.05003445105807436, 0.013133093166435439, 0.09849214761127388, 0.0591317643111031, 0.0230368614316948, 0.0069334797163103385, 0.07390434117687326, 0.05650368436510044, 0.02928537140119701, 0.05303908237105897, 0.07373861337621367, 0.05051882930039879, 0.06262889822884914, 0.02786964091712669, 0.04458330263714156, 0.02235111697847324, 0.017252363257050034, 0.05363117257553724, 0.058570137592933835, 0.07401714762372356, 0.013966306672251273, 0.05362978595639429, 0.06727610249072313, 0.06861959088353381, 0.03097394792993944, 0.012535459358215094, 0.02201075943547391, 0.0441669644938121, 0.04038528253835055, 0.05702081286618787, 0.03631122312658737, 0.021852257759160092, 0.040800092336271084, 0.03449824924070028, 0.02365967559237634, 0.03344478641426371, 3.367118224982293, 28.778402497691495, 47.853637818367254, 36.47350049787952, 34.24560600711454, 55.190180193993356, 57.5565343518411, 26.556746536685576, 2.9906851726193584, 0.05725741146072265, 0.12433706602502255, 2.913577748883155, 2.910067717875204, 1.3844737290374696, 1.2486248896006615, 0.6962188669750768, 0.19343294143196077, 0.5626896191989222, 8.014039156898376, 23.299367158643662, 43.58629126702586, 56.971167672065, 64.13442757821852, 68.29619176926153, 68.88421781601446, 67.0640968507336, 68.78635468021517, 66.24080704104516, 66.51596130863314, 66.09970369646626, 66.54704216987857, 67.22686736814438, 67.47055638221003, 65.86147462168049, 66.74982086304696, 63.76530901078255, 62.30809750095491, 62.447212203856445, 62.35607985527285, 67.02550857297837, 63.24389657666607, 60.51994385257844, 55.19964487321916, 55.29521734483781, 57.39285384455035, 65.15534993140929, 62.625817329652854, 70.15026477075392, 55.013802974454826, 21.093432057288386, 68.33384652291575, 66.55326304897186, 64.77438188368275, 62.22960695143669, 61.74535505233273, 49.16558434886318, 55.239099994782485, 55.297664903825336, 57.826126698524725, 61.49336630298246, 63.33198516599594, 63.23335716801306, 64.02184770953271, 60.63019775575208, 59.00336334782263, 58.510258659239746, 60.61509663058866, 59.48921165158672, 61.396032687156435, 61.62819777765582, 61.280165872266224, 61.45044772855697, 60.15918777834985, 62.2612722458378, 61.5558575045678, 62.87875529258483, 60.82065628420923, 59.4374442100525, 61.35744440940119, 63.103303140209576, 60.28690015116046, 40.72249035681448, 14.033770772718615, 1.4413815592565846, 0.07049054613397007, 0.22217256137199942, 2.7980519350497954, 5.934796612108908, 9.541112492161414, 7.474568620804818, 6.203846200819939, 1.809950504572161, 0.18797176108965952, 0.2616231323730561, 5.2493712498295695, 32.55782973381781, 44.37495831520327, 28.449733372657533, 29.65068074964708, 38.89887455971011, 30.558111283086962, 6.596679908614005, 0.09157121737277316, 0.04948286009171317, 0.054579746473820946, 0.014713450199774197, 0.04310563394439317, 0.03131269668829778, 0.05569815057359877, 0.01993322091537618, 0.11103856106919628, 0.03808747458782408, 0.07333463223110284, 0.061014168745567726, 0.012732655177974414, 0.04274236654201823, 0.03367430635637814, 0.018138453109009613, 0.010269327228137804, 0.03793383565460963, 0.03627009186593275, 0.04310835738696399, 0.0377161096360895, 0.024568648490634178, 0.02441056241701928, 0.048046606112151384, 0.04376731557591308, 0.0181255464427053, 0.043476573717329776, 0.01774012186234036, 0.03152013223077501, 0.011046353930367098, 0.0510727338522913, 0.033109511864641984, 0.034743021993387135, 0.007175778005001767, 0.03975317956158712, 0.013109773450020342, 0.015117560622222243, 0.016075230856996872, 0.12976607067450402, 0.05387062867802959, 0.04021766633095761, 0.05302053538241214, 0.08463003176955447, 0.027524753879275055, 0.0590781802912393, 0.015389210612122572, 0.047860875755788825, 0.034024067628648014, 0.02733816167399768, 0.0782391194614672, 0.06052581450691628, 0.025172028915896535, 0.04405153802626076, 0.03661179772367881, 0.08498280759780638, 0.025832712717895067, 0.07802387173738211, 0.07213217296427296, 0.056305179492600506, 0.00597467327738301, 0.04579022436613037, 0.022312358675164082, 0.03323137347075728, 0.04756061142430671, 0.032097955962883375, 0.019233757742650567, 0.032388535027782765, 0.04472919642144153, 0.019703771836394747, 0.048363437094996055, 0.011776914527159066, 0.02842178346679336, 0.0324411767594997, 0.09157715455418633, 7.673108212409481, 40.6178258311364, 49.55790765823857, 33.899982437010735, 34.37764475422521, 63.844725239661436, 65.71895922383955, 26.850483032964892, 3.0096559611059006, 0.05993231853109695, 0.17194014553341175, 2.7092582996814483, 2.10116074931237, 3.6345454233307994, 1.2875285504325744, 1.128091557372001, 0.6807344527013841, 1.768746005911981, 12.688846914998948, 30.224964772501302, 49.026191157679406, 59.01081192877985, 66.57665606467955, 67.34091420327464, 68.31711369176065, 67.42534714360391, 68.85437642374347, 66.7701622747606, 66.96971677964734, 68.62929513377529, 66.76789514480099, 67.44265264080417, 69.10228590811454, 67.00719110427364, 66.54428082127725, 64.25852352573027, 62.48525527215774, 62.08040391245196, 63.152458283209036, 69.76384070611769, 65.91289689463954, 62.39533493595739, 58.622473747499534, 57.016780914798865, 60.07229943429271, 67.93169375388854, 64.12867346117574, 73.14585731875512, 54.75919408182944, 26.25462205179276, 66.50726933633128, 67.59295002106698, 66.7717626017909, 63.85975968453192, 64.51492886389455, 49.13138912570093, 55.80601976763818, 57.1232654202369, 60.509208325416814, 61.350140956140336, 64.87057408978863, 64.3316129715212, 63.32504649316112, 61.73920869827271, 62.51744224179176, 60.76927323495189, 61.88720756961454, 61.63950204849244, 62.76859160392516, 62.86559966302688, 61.3906394281695, 61.56442788339431, 61.19599573073849, 64.29056929003808, 62.18140102201893, 63.29871169982418, 62.742319568510986, 60.434753894805915, 62.4206812920109, 62.98203129922191, 61.89693504764188, 46.50154582915768, 19.62107627622543, 3.813922275458613, 0.7301732320939341, 1.126166654209937, 5.20428115321744, 6.268896748942714, 16.937331768774218, 6.11909358732162, 2.4555076706794003, 1.0944024425360466, 0.1432055358083979, 0.1595983924644609, 3.353879245058183, 32.52117322337243, 55.76136750559653, 34.16092595746441, 37.974548416752974, 47.486605951862956, 39.47868324095203, 11.90841096062814, 0.5593087812585216, 0.16612673328528482, 0.01498427377232621, 0.05665545021334002, 0.05333536687577444, 0.022247635736881245, 0.048995888641765045, 0.01926659801674466, 0.04748644645235712, 0.02716159564442933, 0.0289600866381079, 0.056525847288749875, 0.05272571793607166, 0.030662588730093934, 0.0772710754385879, 0.04336029689218249, 0.03478563180373561, 0.00788145367198834, 0.005638327641082147, 0.057036058015881054, 0.06353008192813685, 0.031097349372782537, 0.13458856351433263, 0.017079679378037973, 0.029220663784672658, 0.017884715212388866, 0.05555307650337777, 0.011990723921166313, 0.022623903651331222, 0.03656369889335286, 0.12235486714710152, 0.18748028504271663, 0.013788063867738651, 0.14088462647651473, 0.09830147598779972, 0.17151436918685514, 0.11309184524561129, 0.07584334801762335, 0.14266729775455692, 0.2033368648300248, 0.1658040723733364, 0.13627709790823922, 0.09363743311335003, 0.11417572176264179, 0.1728636338826149, 0.13574704167342957, 0.16824709612034983, 0.18415128061127278, 0.15755713586845707, 0.24361306410883707, 0.17535683638866872, 0.17332696385921972, 0.16003382151886342, 0.09344155975287, 0.1846143041527079, 0.1619648840278387, 0.21240152358528108, 0.1538153939069279, 0.1816824397012111, 0.11749387838907781, 0.12757649179548025, 0.1176786128311388, 0.11653426899424485, 0.1835666635944959, 0.16614459845567905, 0.13761520836382143, 0.1224337895250609, 0.08098467899065825, 0.24319199154213553, 0.1218229569795151, 0.2135885308586782, 0.11726196059176039, 0.16957271934276627, 0.1926303264354506, 6.549915940530839, 45.08432680560697, 64.04387966279062, 47.7730409560665, 46.59053656362718, 65.00258538030809, 71.11237510558098, 33.07867734662948, 5.110352154700987, 0.21662764761957432, 0.32969770532461906, 5.297184942230102, 9.24636402437764, 6.039989186871437, 7.631470782141532, 2.2663226867875745, 0.39887094029015113, 1.2275620069234603, 10.264778021843204, 28.089045939906953, 47.83598323022166, 60.89867222693659, 65.7363941592555, 69.30198946306783, 70.59890547106343, 70.61546571793096, 72.54454228185838, 68.91755011773878, 69.94217518837222, 73.42558506996401, 71.76431225192162, 71.17059876841884, 70.12804846609794, 69.41395744200676, 69.64638925367787, 65.38713062963178, 66.15882950444376, 63.6146782290551, 66.31817971506428, 71.62202435155069, 66.05092510100334, 65.15065093194285, 62.83615835251347, 59.213653379871005, 63.730301856994636, 71.80750539225917, 66.79281004013555, 74.55153280688872, 57.74640844714258, 29.441436029249623, 69.64042725101595, 69.96807852099019, 68.68038008289953, 68.12762398873606, 69.8081870232859, 52.33065074489963, 59.23315540436776, 61.479183012439364, 63.43167612629553, 65.37326505107265, 65.67204767657866, 65.94718625468593, 63.88571400796214, 62.64405635095412, 62.7709803273601, 61.13163748095113, 63.822779578547326, 63.807964786406494, 64.9607886037519, 63.83490754712013, 63.104338645935066, 63.51129631842337, 60.87023896555747, 66.18331293905935, 64.36589056445708, 66.3418786756454, 64.16732841922392, 63.71205891332319, 64.61946787372713, 65.45676446730091, 62.94250557499548, 43.66436604530581, 17.433813618075465, 2.5715046592297095, 0.8452255423030547, 0.9852339327335359, 6.967090897021755, 11.236480512926656, 15.988337839803389, 19.71576229218514, 16.333213217796818, 6.6335825477876975, 0.7907026357227757, 0.518316948606122, 8.014772149824328, 41.069388697224284, 56.65360081580378, 39.8612908394106, 39.85221447483186, 50.01537369143579, 44.20222889992499, 12.39156263489877, 0.4096892049476024, 0.14550556158346517, 0.10459872638626445, 0.08148122653965989, 0.21603458831387184, 0.15367746743704044, 0.15314583306110677, 0.12830825898075296, 0.15874988880128632, 0.12561621835395215, 0.1581094852618633, 0.0944765598603314, 0.19565280376663133, 0.13894075497744546, 0.21849561512710589, 0.15431829998570104, 0.1261379701956626, 0.18952239965719564, 0.10889374470758824, 0.08788139318987247, 0.1380865822636312, 0.10073758196085693, 0.15110799321724525, 0.1388740593627576, 0.10227358824903927, 0.10430868549813187, 0.11722305098608618, 0.09053817845039791, 0.11508957272575748, 0.10976240414405063, 0.2085174271656621, 0.2248255085320242, 0.127207834964558], [0.06323044578875266, 0.037035930811637835, 0.06689849775284529, 0.04355199124303557, 0.06837431251281692, 0.05826705788833, 0.01253094518512127, 0.06254857007954871, 0.06192275285420399, 0.007685553019626007, 0.03742623345686063, 0.05204933507728481, 0.07268583236802971, 0.0504513216325112, 0.024178742295912197, 0.011201396719702791, 0.038064051449539206, 0.028908797051577322, 0.06720120973524547, 0.015180430585338224, 0.018806094904580427, 0.10119872092599831, 0.02113492941604026, 0.01757773995069006, 0.043117527459417625, 0.13497744506645587, 0.06749330373901515, 0.0573160516608867, 0.035089071569663864, 0.050020236296639334, 0.029662330709998647, 0.05014767502284339, 0.04479068646868391, 0.017468792671758323, 0.020515162370077545, 0.029373015690174316, 0.05009337854121001, 0.023510820878249024, 0.0649658800853837, 0.02115290375396369, 0.12570483174415367, 0.009078588148939514, 2.3871645379451016, 22.762508430788596, 44.50912298694734, 43.87284786470475, 33.06643170695151, 32.50692325253641, 42.421939603744015, 37.57640038767169, 8.52594131423581, 0.2299227205014998, 0.6870491009566092, 3.717063266423441, 0.9539416925080362, 1.5535718875546611, 1.928403754868815, 1.4497351045570066, 0.11633951412213427, 0.30430167613010256, 2.024120618739436, 8.304262680392112, 23.351628818819602, 40.37812586753599, 58.22551811895063, 62.59630149410617, 66.55032127134263, 64.4178698139806, 66.1235595518543, 68.64109362325361, 67.42738677609351, 65.7771554300862, 67.08266535112935, 64.55363873512515, 66.68299936479139, 66.13216523201235, 68.72465579740464, 65.94811977878695, 66.05256465173537, 67.2467145612163, 69.61009164010325, 67.03323564221783, 63.208175551506784, 56.891163087660274, 61.47873193986955, 61.56191756648403, 66.14833324186264, 61.80546537522347, 70.39915484766807, 44.53346129386656, 24.91936879773294, 58.342177252615656, 65.62359463784003, 62.14471901616743, 63.625994267002234, 61.1817692941235, 56.20040624372421, 54.6200676118174, 54.13359172882573, 56.53590617641326, 58.41455282703523, 62.806254202319735, 62.5701863534989, 64.63720483164634, 64.29718240614861, 62.376260449809415, 63.68443366019957, 64.6682386244497, 60.53186001316194, 60.2381411675484, 63.10726081171344, 61.582796342911266, 59.896439967616914, 59.68813465487573, 61.62480492745677, 64.51010827095278, 64.48015705231698, 63.72294349055137, 65.96822584829023, 58.77890963708201, 53.5287897048458, 29.140121513797393, 8.17693175808076, 0.666292714736154, 0.9677347072189855, 1.103876927687276, 1.4203621903734824, 4.964750341830715, 6.573510468006135, 13.931957810155808, 9.47010386374689, 2.193174650592189, 0.04997489155240117, 0.15685996521384488, 7.425038401157626, 39.1803438432755, 40.46422189281833, 31.59651956250591, 27.066566405757783, 38.107383405008626, 29.411273002624515, 6.619238930363809, 0.11815929469922859, 0.055791092360572475, 0.055474927874221924, 0.019719712210879214, 0.045130140027932586, 0.045410838473828576, 0.03506529603093382, 0.0747353014265818, 0.03597632779048816, 0.047603416587075884, 0.030497006486139955, 0.028107990022568453, 0.02217529405419144, 0.07135359780682672, 0.093434366187261, 0.01611026980343365, 0.017507292420393037, 0.015555109824955225, 0.033236598190400875, 0.028811450259039, 0.06005099321144724, 0.054772750835024545, 0.02632611739118734, 0.04722959632354398, 0.04719334121252741, 0.016230656690294706, 0.039774266131702936, 0.05600831276106258, 0.05251230116212561, 0.0765084885361214, 0.031845122050013275, 0.026288446932730657, 0.018007766170006607, 0.04792876646763856, 0.06508974118098136, 0.03362166845510083, 0.022843215471854614, 0.004823068842186683, 0.02045609124545609, 0.05792354023264301, 0.024884165632688714, 0.04954390963839908, 0.051115110005822875, 0.06281281678727077, 0.02164916976565315, 0.03983209427866725, 0.04284429454034375, 0.04467884146217858, 0.05436736774901229, 0.05197341576398862, 0.0443152982681509, 0.06489240459256596, 0.038037751651098656, 0.04906751403224565, 0.0519702633121802, 0.08457618344935679, 0.036959314358330546, 0.032585653281139756, 0.03976719130972221, 0.10335779418387722, 0.02593687194730005, 0.034061870237271634, 0.027759502371472698, 0.032578065180249756, 0.017713565424445177, 0.05045315258265023, 0.06031047102184065, 0.053723578100963953, 0.020936639048159126, 0.012507678137250967, 0.12989495730688497, 0.08888270841130326, 0.02833481716562904, 0.07412577889138654, 0.022452508715251764, 0.05360723232790347, 5.346678389656929, 36.42256459882183, 51.28022432327271, 44.10727616279356, 38.26455277781333, 46.67974695082634, 63.22464950623051, 41.349732260550226, 5.586725483017584, 0.17034337315107548, 0.05856032783706343, 0.8343689732493893, 0.2740805800403318, 1.518101158642, 2.2677685704923447, 2.035977085751872, 0.25598503168552156, 0.5305928027918262, 4.117538486757587, 13.119658481690193, 29.441700789236254, 48.414544597748794, 60.95231063904301, 65.42184752802696, 69.50778053652856, 65.64777604995236, 66.11942537369268, 67.93644766653738, 66.32112933743385, 67.50679908260223, 65.91419912153675, 65.90962563791584, 67.36608013030022, 67.75767387882357, 69.64990369735226, 68.56800417746268, 67.55913919018161, 70.97450379402407, 70.41182410332465, 67.23315884990078, 65.28978524669525, 58.71060156053113, 61.10791106377879, 62.713317563456876, 67.28221201127576, 62.756247904992875, 71.08920958734328, 48.36722512398997, 22.74296129903486, 60.919962852231926, 64.9317983658083, 63.98452635734313, 64.13759685331776, 64.02702131579, 57.188023751781834, 56.64656800608481, 55.350738494626945, 58.33152409522765, 59.79646267429475, 64.68968614455193, 64.60632008890953, 66.75840300898399, 65.34865610061154, 63.6140545721977, 63.66862650840514, 65.56725371268489, 62.83168685051703, 63.46691077755344, 64.28112422266315, 63.132077647793686, 59.97477362232824, 60.670904113400375, 62.85793142934, 65.69919440054124, 62.88555668246362, 62.312969084708925, 65.96622543950235, 61.684648529175796, 57.19512324179373, 35.42743182951404, 11.805055525995071, 1.08063418778681, 1.5546719898139278, 1.4135106677009215, 4.696070436508426, 4.671543365524662, 6.406413576295299, 14.704176399015612, 8.778034006395648, 0.9871201637771823, 0.03550422993758994, 0.13773617364706534, 6.033740360890666, 44.27516145090903, 50.58045387268067, 34.996520242383404, 28.452410390300138, 36.96433021176246, 36.65392952580606, 12.485947608947756, 0.22638472728431228, 0.018116933699216575, 0.002348646023986681, 0.03341593554303531, 0.04790792504565851, 0.036711511727903164, 0.022714614207225464, 0.06973856954925484, 0.030184672439410806, 0.016416306607425213, 0.039895491884841074, 0.017082092554999456, 0.027257540496066216, 0.05008411653820546, 0.07242038290226653, 0.07574970909063855, 0.03778999115550711, 0.028862789641284657, 0.043306406437148975, 0.04150235747557975, 0.0016897424188021932, 0.04388260031719843, 0.07373996935183964, 0.04699187541020013, 0.023125405873983138, 0.03219635421109777, 0.01661735106139414, 0.03435093819374039, 0.060777302020259445, 0.067363559088159, 0.06977899600901911, 0.015207990598414215, 0.007989499839999142, 0.02288120002636025, 0.1694871013563487, 0.14695389676959286, 0.09956865436247281, 0.09715761478629806, 0.14525281385548655, 0.21954887877068213, 0.12738309289899566, 0.14056538231670856, 0.10982606605055834, 0.18861792561027313, 0.12490461460284649, 0.12434943834499967, 0.16741599797481493, 0.13824804295455256, 0.13107723015691006, 0.10330539376985642, 0.11811666956712162, 0.14879598582704223, 0.21294538472448626, 0.1952844533708788, 0.14782034221195406, 0.15875641587040118, 0.1558540917692646, 0.09943894801601287, 0.11135575977424461, 0.26738610539224844, 0.1070390458429052, 0.1486033147140857, 0.1416941669078604, 0.11201186811611538, 0.1321472098389941, 0.14937943839017423, 0.12207377416592453, 0.1695237203591293, 0.09541135566729693, 0.10093491854927233, 0.1947585952978942, 0.18306915077470964, 0.17907233217791205, 0.12814053169061101, 0.22456559022107433, 0.16955359778817625, 4.479783100466575, 37.12665357897359, 65.31582978463942, 56.73721005839687, 45.95785433246244, 43.97506090902513, 52.38753295713856, 47.05825567245484, 12.810281534348766, 0.3583181066618812, 1.3978528111211717, 9.914508404270295, 4.87523106798049, 2.0953247527922354, 4.2947977492886205, 2.9749613711910867, 0.37469332797392724, 0.5589826729509139, 3.0317033586963533, 10.55257801086672, 26.327468310633016, 45.79378551052463, 60.81116807076239, 64.23976282919607, 66.8861153817946, 66.1326986743558, 68.68947998169931, 69.68259273036834, 70.203075562754, 68.44398667735439, 66.34390261865431, 67.24807170129591, 69.48332848087435, 70.00090875933248, 70.33663226712135, 70.53022476934618, 68.82932816782306, 71.49507291855352, 73.61011689709079, 70.79256073121103, 69.23195162127095, 60.82305677475468, 65.38885255013743, 65.59378070216026, 68.03460105772942, 66.63815098424112, 72.91105639549994, 50.267119253835375, 30.971738946053293, 59.5548564387906, 65.88143948585757, 65.11779323700937, 67.92005215921711, 66.67869260234218, 61.06740082463911, 60.02623511898903, 57.96474718278455, 60.218466558764064, 63.176706375614295, 67.20349788665771, 66.35686212970366, 68.36735140892768, 68.22529885076708, 67.17930470743488, 65.85967817614156, 64.73222032670053, 62.32224941253663, 61.89522881661693, 66.01889502617621, 61.26424889410696, 59.63955610029159, 60.242604824804495, 62.850761336665, 64.50862169265747, 62.92492551188316, 64.11239562496063, 67.25783840302499, 60.32968928737026, 56.88857040097637, 31.849428107661588, 10.311039436248041, 1.0236781246719822, 2.3210711296527617, 1.658057577667698, 5.209517517397481, 10.384196542924451, 19.139932855483025, 24.079581499099735, 15.099471884389079, 7.25627891479, 0.15633041459706523, 0.2643282807642414, 11.268399780796422, 50.034012794494636, 50.18662045078893, 42.5352608003924, 37.35115828052644, 49.31091208611765, 41.34671203551754, 12.7191315350994, 0.3215587565735463, 0.11259679922894125, 0.12894896129446645, 0.10469650218804037, 0.1284104397880935, 0.15889955173817374, 0.15319003633433773, 0.2621777800302352, 0.23076958473651643, 0.17018293901797266, 0.24648480598003636, 0.11658160556708613, 0.11211587987359493, 0.20255697200134878, 0.36362053826451307, 0.16667028798932032, 0.2504626562398288, 0.15595081803058425, 0.12975304717979125, 0.06575473614277379, 0.17235557969299056, 0.19536409587148698, 0.14193569910862755, 0.14256663380130646, 0.13111999318484338, 0.14195987684351785, 0.07640765604352759, 0.177815503651096, 0.15925421980359863, 0.2437640906822297, 0.14849952512210415, 0.1332973069961994, 0.08670138029922402, 0.11963186124640128], [0.038706163365033366, 0.04312032751078087, 0.049670957659761754, 0.01744280888458654, 0.046101148811078844, 0.04770402691417164, 0.023286935512817675, 0.022007813827405055, 0.02378323791368354, 0.029405124350300724, 0.004370202669017618, 0.04066852056571553, 0.01898520817649701, 0.020477953479595242, 0.07792994935786532, 0.027249981123473377, 0.01732213088431426, 0.026544808680492065, 0.06106920067160841, 0.04721645025476333, 0.039752114699372364, 0.009764157359548395, 0.02760482347390104, 0.06607168969968635, 0.03958655543805611, 0.03638593968184244, 0.07996254149944552, 0.06199008815230862, 0.008945714028912687, 0.05065395188848338, 0.02701144815692979, 0.026861517089268854, 0.07741578944748448, 0.02899827612113328, 0.03470488613651645, 0.02477609552443028, 0.06499715945533206, 0.017720634500766476, 0.0243258579904514, 0.032774808050523845, 0.04264370590868977, 0.019747362239286304, 0.006412689314944851, 0.6916686111400205, 18.16964045647652, 38.924734746256185, 42.33257624410814, 28.8445964167195, 32.004200912291004, 41.69255918072116, 44.19678857249599, 16.720212890255837, 1.2868262010235942, 0.2049280754140308, 0.5916892340587032, 0.3508169720730474, 1.0208966126365047, 3.445325383255559, 0.5185745992968159, 0.08045397158111296, 0.08629720763213213, 0.23282892100753325, 1.0810086515641983, 7.856323103750906, 25.121661116999967, 41.367598656685125, 57.49673781856414, 66.83040988060736, 67.95012104895808, 65.1564521174277, 65.09698506324523, 67.9994095525434, 67.76545586124544, 63.63573351214009, 66.33469289348972, 68.37244264541134, 70.0597050882155, 66.69624913123347, 64.95871759230091, 65.14924672342116, 67.66238381785732, 66.17043972015381, 63.22611647267496, 62.13105347848708, 66.0480696155179, 67.07864099933256, 67.65566087538197, 71.59099055874732, 69.33234076346122, 35.727057764607096, 40.39626290721279, 49.781890684558505, 72.5387607082244, 68.33008889229068, 67.42451560112738, 65.84738546802153, 66.88405221508395, 60.54338785909838, 56.434885532625266, 56.46010245046308, 59.62798510828326, 61.41328327117428, 63.24512427853, 65.18859594098984, 62.602173282254135, 61.18748810983474, 64.24883527140464, 64.26389325049617, 63.36981642630793, 64.06553899088215, 66.08226483868015, 63.49890162867885, 63.92771867013747, 63.53452459458382, 65.74559211730957, 63.2804883680036, 62.382591155267534, 55.74841976165772, 45.971515947772616, 28.33100126635644, 11.67117718727358, 1.4867959868523384, 0.08278619603163774, 0.3230703706222196, 1.4902757420655222, 0.9195988901680516, 4.631410654514067, 2.8245784342288975, 3.338912215925032, 10.172486612873694, 0.5471203223832193, 0.025971267379880435, 0.27854635169909847, 13.634462702658869, 41.90238245071904, 37.27040844578897, 31.70358850109962, 29.555453446603593, 37.80971081026139, 22.246769705126365, 1.7943398390085468, 0.0544760411515111, 0.013434933723821757, 0.03359675144536361, 0.020247447199278304, 0.07586316671222448, 0.1324900495068681, 0.026978408699975382, 0.05280151084486035, 0.044666381042090156, 0.038901121250443885, 0.013654296297670133, 0.01621704139266043, 0.07703836090982923, 0.02883491170172009, 0.023649988410573815, 0.027525943230777502, 0.033891270117413615, 0.06128120401333417, 0.01623107612343325, 0.05224543826414212, 0.06019688316530759, 0.04202147014439107, 0.06937886828616743, 0.04118677521605165, 0.049605288602892435, 0.017894599661831895, 0.05076042278819988, 0.07998195416744679, 0.05260353074258855, 0.10412304707232023, 0.024303222007508722, 0.014475848987668514, 0.029803754371260444, 0.05057734692649496, 0.05066520188965144, 0.016928748565635855, 0.04553350830270399, 0.03099899517462379, 0.0475475802687147, 0.0293459881082057, 0.029090505446337407, 0.030083071943672917, 0.03007264548702346, 0.08357856077172103, 0.019330242686274073, 0.04006379374092625, 0.015371254468787343, 0.07774725270968291, 0.08309171189584079, 0.008924947300505255, 0.02873412325918194, 0.02294429502780399, 0.019040098376271707, 0.07217850596193345, 0.04735958612253589, 0.08887042802187706, 0.038126499106686924, 0.021137394303936633, 0.1001490272521492, 0.03313717146914813, 0.06218468980683435, 0.061976624157039396, 0.008770153489744952, 0.04483311241793056, 0.0135058504829724, 0.021734073375081344, 0.05300491101919644, 0.011766959214583041, 0.025163027382786238, 0.013773437334044326, 0.00926353039234997, 0.06914429216375274, 0.011982988348350892, 0.006362953450485704, 0.048027415609648155, 0.04801447255416744, 0.04837877800567977, 0.06077875758731558, 2.3707374065153064, 27.883325469109323, 49.074381397616484, 39.90659421490085, 24.93943368234942, 29.13325344362567, 61.773953053259085, 58.62666676121374, 14.467364280454575, 0.5277560711387665, 0.03302557161077857, 0.581133829489831, 0.5002931673680583, 2.309063038518352, 2.0010092782397426, 0.9757063117238783, 0.27649623912668997, 0.11202766484911404, 0.42503869581607084, 2.702300995588303, 12.303941788211947, 32.27580543487303, 46.826353380757, 60.05496648050124, 68.1781441165555, 68.20719319005167, 63.82159894512546, 68.35276803662701, 68.29108484329717, 68.3828055474066, 64.52248727121662, 66.71250343322754, 70.71681191844326, 69.49984950404014, 68.09295023641279, 64.66317876692742, 66.04475913509246, 69.06754155312815, 68.18359621109502, 65.90615041794317, 63.734840039284, 67.90109142180413, 69.63571256206882, 69.48026903213994, 73.22061769423946, 72.25623238471248, 40.625039069883286, 38.02557060795446, 54.40827923436319, 72.05077863508656, 69.9191822544221, 70.44940825431578, 67.2056551902525, 66.92652363930979, 62.854891592456454, 58.18245049445861, 57.911681436723285, 60.75675302936185, 64.55761994085005, 65.580754510818, 66.82828395597397, 65.65908424315914, 62.72165260007305, 65.53046188046856, 65.45634085132231, 62.76685791630899, 65.96809248770437, 66.20589794651156, 63.882270166950846, 63.95272377998599, 63.91548087519985, 65.40622080526045, 63.51339870883573, 61.77840102103449, 59.71492444315265, 52.162890972629675, 37.34135235509565, 18.057056665420532, 3.99173655336903, 0.40354254445241344, 1.6126324861280381, 2.8866318012437517, 2.5249130302859895, 6.194885546161283, 2.685734865165526, 2.601524764491666, 2.2535943504302733, 0.7328397696537357, 0.052421458456064426, 0.1626533672453896, 9.555518377211786, 47.03392128790579, 44.75733841619184, 32.78125578357328, 30.805526548816314, 40.43279194062756, 35.365634887449204, 6.360349751287892, 0.054640887951057766, 0.03973136903838285, 0.05071362247690559, 0.06858232070601757, 0.030897356374489687, 0.07761504891658984, 0.029815425720786857, 0.040733588243564295, 0.04487814689655939, 0.03579313701559459, 0.003296803122559082, 0.00371004531306455, 0.047940686795740366, 0.03186504416648419, 0.0012650012485532752, 0.06655100027039167, 0.0032905460994375212, 0.03723690631769357, 0.051402450434022376, 0.026428012830776074, 0.12878192348345635, 0.030218560338741353, 0.03229850820536095, 0.0749328678413745, 0.03606795956711135, 0.01846795518612189, 0.0692803570399842, 0.03125311228476706, 0.035205762082290266, 0.044013815856869185, 0.03780188467053156, 0.0064782774537771705, 0.05822517586150958, 0.085360121222273, 0.06444160781440235, 0.17921983474685302, 0.1204659854392371, 0.12012936640530826, 0.15724719201605167, 0.24455233386928038, 0.12039012741297485, 0.12125642729863045, 0.12119749215461555, 0.22473598349719281, 0.12604197937875025, 0.11451504508694334, 0.12302651941295593, 0.1254455952514564, 0.21654947600778074, 0.16205515982883592, 0.16067678379195352, 0.06934078605545145, 0.1234173161848899, 0.1595751646785967, 0.16393209056508157, 0.14713070986251678, 0.18170560620004134, 0.08125123928391165, 0.14906993886876493, 0.22165581974531376, 0.2011926153734807, 0.1445279108180154, 0.12902245976992194, 0.12009479285728548, 0.1734099005379023, 0.16715853114522275, 0.11399549191757558, 0.1463274819956672, 0.10450699501821112, 0.11723669501201761, 0.11747650351495513, 0.11584726432638785, 0.1651966259364159, 0.1058941044574303, 0.12113362340436828, 0.15353472993498848, 0.12008193790191606, 0.13988907989715377, 1.885291513416075, 31.28177485158367, 59.49578946636569, 55.97052789503529, 40.245530143860854, 40.07289878783688, 52.78330402989542, 55.27042012060843, 22.45808739815989, 2.380070686340332, 0.24126567877829078, 3.022602479304037, 7.444971886373336, 7.755312756184609, 7.2600051664537, 1.1996847415162673, 0.2585784844573467, 0.21251017017470253, 0.7043173356402306, 1.900587408773361, 10.874956634736831, 29.048681259155277, 43.998873618341264, 59.984787433378166, 70.7600913509246, 67.27224134629773, 66.68172851685556, 69.25123399303806, 70.20440916861259, 69.74671563794537, 66.69083626039567, 70.16160826529227, 73.16587709611463, 72.33089862331268, 71.04743634500812, 67.7912493674986, 68.89028180030085, 71.08543626723751, 70.12146672894879, 68.23406142573204, 66.92311117725988, 69.90867814710064, 72.46637728906447, 74.68604656957811, 75.62738403197258, 71.40510159154093, 45.12429575766287, 42.39037629096739, 58.59703325456189, 72.09889827236053, 74.92321660441738, 74.1704745446482, 69.77798477295907, 70.64727614002844, 65.82395322861211, 61.13270044326783, 60.899664586590184, 62.94436085608698, 65.77854787149738, 68.66495732338198, 68.47208653726886, 66.5483836204775, 62.43218168135613, 60.72801382310929, 64.53292862061532, 65.69265188709383, 66.96826550268358, 68.50719959505143, 64.98867665567707, 64.25072977619787, 66.42660187136742, 65.74843191331433, 64.50835889385593, 64.66827784815143, 58.21269589085733, 49.68336074582992, 32.236016911845056, 14.425072304664122, 3.070956478195806, 0.2561975291539585, 1.0807168027085643, 3.857173025608063, 5.269279239639159, 10.473699146701444, 8.561163217790666, 14.34550408394106, 20.420408248901367, 1.7629312147055904, 0.11158030014485122, 0.7843010824534201, 18.176867423519013, 51.89206307934177, 46.843494138410016, 43.36362615708382, 39.87324230132565, 50.83465483880813, 37.860376065777196, 5.307475280377173, 0.2056430193084863, 0.15547746762392983, 0.2138909210841502, 0.18184976862563243, 0.1657660437687751, 0.21367431738443915, 0.1298174138871893, 0.2243092572016101, 0.147289673106805, 0.12452068963959334, 0.12484622338125784, 0.11731809185397242, 0.19893902984838333, 0.18183832327204366, 0.15307639485164998, 0.22986134153700646, 0.13646233796833024, 0.13226737839079675, 0.11412709050120846, 0.2741466474629218, 0.2068040102359749, 0.13841227688375982, 0.18770012163346816, 0.20820293275098647, 0.1817433130476744, 0.07876350664563718, 0.2444424308956631, 0.11662289770620486, 0.19744554143999854, 0.32947636720153595, 0.19184078089892867, 0.11042423516271577, 0.14156420775238546, 0.16052874496146557, 0.14180290542783278], [0.017785966478949113, 0.11020117334180302, 0.04014313746724398, 0.05584659160024697, 0.05825584619155815, 0.026240696672410257, 0.014288482075977712, 0.01750287783872937, 0.01936314807784173, 0.007024599650439116, 0.030291901766172344, 0.019032849269288204, 0.004207888268865645, 0.06610300737403094, 0.0177930508770289, 0.023447185784818667, 0.02893299776910534, 0.03235189687280405, 0.11099788946129623, 0.048769475186183575, 0.048746178452406204, 0.03905389067386428, 0.06060134694581071, 0.03332837169329005, 0.08458583615720273, 0.03581629968398521, 0.10747041463130906, 0.05096471545496776, 0.04409798210667026, 0.010727501433012227, 0.03594802467212562, 0.076208388913543, 0.05716147810040463, 0.0441329961552495, 0.028852485758703084, 0.06338724866509438, 0.024484706321550954, 0.09600329648462996, 0.04052225139833266, 0.0756553653627634, 0.03981078171261376, 0.0394220955129112, 0.012649246397608472, 0.05042980605315778, 0.27884917093380807, 13.888597969085941, 39.20462331464214, 43.685899857551824, 36.87154262296615, 21.841498651812156, 26.600718267502327, 49.972686536850475, 30.661148025143532, 5.354843293466876, 0.12534090933660347, 0.20301962782058025, 1.7206142338052874, 0.40909855115798216, 0.6376185953136414, 0.4033091940706776, 0.08965941431421427, 0.035454970484058705, 0.14563021941050408, 0.061720176224386504, 1.4646745545248834, 8.053387393874507, 23.643965028947402, 44.75126266479493, 61.99879507864676, 66.94706116953205, 62.58339297386908, 61.18779405470818, 63.81037704406246, 66.2029012556999, 67.80360483354139, 67.49043495424333, 69.38759126970845, 67.34558966852003, 66.50719873366818, 68.43342765685051, 72.84748261974704, 70.61759164256435, 68.34733163156818, 64.7253522565288, 65.51203850776919, 64.25687220788771, 72.35687255859375, 58.639908682915475, 46.39049568483907, 26.322280976080126, 33.78477850267964, 39.51642036437988, 66.36768787137925, 66.02288799901163, 66.24905186314737, 71.31232184748497, 67.25054279450448, 65.18788991435882, 61.98054821260514, 60.9874354639361, 62.37683311585457, 63.8938803826609, 66.97972666832709, 66.49419215417677, 67.29503816173923, 63.6709838528787, 64.23479710855793, 65.87934494018555, 66.49486680184641, 64.73316561791205, 65.18276729891377, 63.28159839876237, 60.02668226918867, 59.230248928070075, 52.46733357829433, 48.51585157455937, 38.847005136551395, 22.329692532939298, 8.62222961841091, 0.9077456713684144, 0.02175698323445695, 0.13996199614578678, 0.7352269609128276, 1.6522150847219652, 2.8820747425479274, 2.2186364714176428, 4.540901472491603, 1.2195630684014291, 1.8052329964214757, 0.809340084031705, 0.19900068460452944, 1.4999598288728346, 23.67065675797001, 37.53703155825215, 31.84429176392094, 38.363200387647076, 30.65875537933842, 36.12349956266342, 19.115353322798207, 0.5926280288446335, 0.06634892925860421, 0.02060361296659516, 0.10626137466920961, 0.05813899480046765, 0.043943707320478656, 0.047359153282858675, 0.08316823641859716, 0.029512830566795125, 0.057569519511514136, 0.05329237402146382, 0.06092149891980714, 0.032133274531412515, 0.04469409044231138, 0.019082018707488334, 0.04528005577383503, 0.026321296782923803, 0.0372865756282643, 0.06935689688449906, 0.06428543313015854, 0.07566180050132737, 0.017105582725977706, 0.03675585672740014, 0.10062322035552033, 0.00540092273900706, 0.03956626559938154, 0.046318051285080375, 0.03182329428983072, 0.05363601808165831, 0.025861896837370533, 0.13377324678003788, 0.06673538997288674, 0.009779429322318926, 0.02358689915478951, 0.007059186605000569, 0.04562762603464146, 0.07069001244681497, 0.04889111079636121, 0.12409895057639769, 0.08662439612371307, 0.14737426453540403, 0.039964646641765876, 0.07053442765027285, 0.055983909030234626, 0.01466849807559723, 0.07248714746486756, 0.04863528339492698, 0.08889569360161982, 0.07709837623781736, 0.022506102311214613, 0.037002445108467535, 0.020743347403983918, 0.0628249746026291, 0.03171484879848938, 0.07042681527954918, 0.003951679499286618, 0.02476930223976172, 0.049734588922752496, 0.02237908493336891, 0.034980053427599134, 0.06265543168410659, 0.10088975000525675, 0.0777998140021678, 0.11295465422013115, 0.029275504188732277, 0.04811058211470804, 0.029842204324180083, 0.05153056714803942, 0.05202960831323459, 0.09181946050375701, 0.01168774763843225, 0.017810749423299587, 0.05695980545433779, 0.008736391037312007, 0.0051698835487777916, 0.039755891512839064, 0.01211271480461883, 0.03759310655896703, 0.1235137819763153, 0.062308757746171575, 0.06470233817855198, 0.9383953783300616, 22.8613325472801, 50.882884302446925, 43.16678593235631, 27.738866536848008, 20.820960690898282, 43.208123791602354, 72.02084310593145, 31.467720693157567, 3.226441683307771, 0.0357060672925605, 0.11593309681742422, 0.8738780886896196, 0.8659922860322461, 0.8892054242953178, 1.0169710555384237, 0.3531818242082673, 0.21292929687807638, 0.10194432365918353, 0.6212220461137834, 3.4135250122316423, 11.81310619077375, 30.67807109125199, 51.260628161891816, 65.29050304043677, 68.81634512255269, 62.8633011541059, 62.83814307182067, 65.22197138878607, 67.86219719917544, 68.73035107889484, 69.6077617522209, 71.7606330687, 72.22754416927215, 67.18303880383893, 71.42957718141618, 73.10004403514247, 69.62363950667843, 69.172041339259, 65.1811199034414, 67.5816692844514, 66.4285473669729, 73.13643578560122, 62.9822587966919, 54.561083009166104, 31.144548769920107, 35.81715852983537, 46.773464141353486, 66.09996257289764, 66.74381963668331, 68.23887809630364, 72.88190534037929, 69.02659985326952, 65.972454163336, 63.211254612092056, 61.06400797444006, 62.4800463645689, 64.65288646759527, 68.25277113145398, 69.04845529986967, 68.06617613761657, 65.55632206701463, 67.17537449252221, 68.10928298581031, 67.7147945280998, 65.24840816374748, 65.6780332134616, 63.786658471630474, 62.74163315373083, 61.6942544137278, 57.17877480291552, 52.99769686114404, 45.6208638991079, 29.896174053992, 14.317362058547236, 2.479855783524052, 0.5776530323970703, 0.8053266413269505, 2.211637737289552, 3.0786305954379425, 3.317881202505481, 3.224666810804798, 3.7269606321088733, 1.991089971796159, 0.3454415169694732, 0.4441523443787329, 0.2269559071188973, 0.32179756150130306, 21.89366617510396, 54.026110941363925, 42.439570657668575, 34.68462121102118, 33.2455506632405, 42.27881623852638, 29.13631093117499, 2.1613142182750087, 0.237233359667082, 0.03496261343600289, 0.1167611076286243, 0.025120346709304762, 0.04682537003029739, 0.03731648753126783, 0.008903526524532466, 0.025150185833955487, 0.04663528063364568, 0.043299668693854924, 0.07166546453992206, 0.042771025891265566, 0.02810978266831127, 0.046123526239347075, 0.10640925262123348, 0.030001316955613515, 0.028460838629173178, 0.06655637820762011, 0.03213408658461225, 0.04145597468220419, 0.04707088205783118, 0.10310890753903698, 0.017507062594015754, 0.008024491863550559, 0.04217160805579155, 0.023120472267750772, 0.017063739003553506, 0.028523292031980334, 0.038282493760268536, 0.0451475915108477, 0.044750646883321386, 0.019485092038408886, 0.03863641872040687, 0.03570063955961697, 0.035196082561366984, 0.04312617659208275, 0.11945947614167968, 0.22701003889162696, 0.17313378712823316, 0.25247117023794885, 0.10657373935945573, 0.15404022539094572, 0.21629939426577863, 0.14470476987621478, 0.19255871253628887, 0.20966847427189353, 0.17710232175886634, 0.20064181347768154, 0.09187878635261329, 0.1566503022707278, 0.11724966488057569, 0.11644324242708184, 0.1293361574531563, 0.2432446524260506, 0.2139851345770782, 0.0879794218006634, 0.15900844347573098, 0.13180296056933943, 0.13952155687635945, 0.11736778797762049, 0.29723561819522615, 0.14611654734659582, 0.26187597203158564, 0.1903869911667801, 0.15862932188376305, 0.10104625410730801, 0.12026322494831779, 0.12342971914838399, 0.1592870543320333, 0.13050816472499602, 0.1935790803643965, 0.19385969837106046, 0.1385901165345023, 0.1760215402370499, 0.0845681854914273, 0.21926967036579886, 0.19058669496688152, 0.15916342306281292, 0.1829315307399919, 0.12852468648024146, 0.5655290474814754, 22.566040831227458, 56.73765328622634, 57.641994953155525, 48.59045505523682, 30.54796999500644, 35.369392518074285, 62.36414032597696, 38.711546082650464, 7.255995033248779, 0.2971262208396389, 0.5439248777204945, 4.045227386297719, 2.6405991710001424, 1.760956546471965, 0.8307341618403312, 0.42210136149679467, 0.241734447979158, 0.3028207975289514, 0.2891026755734798, 2.255325586565079, 9.097044294880284, 26.853063952538278, 47.47918090512676, 62.14602124306464, 66.7031446579964, 65.10639875165879, 64.63833839662614, 66.56013504151376, 68.7613848716982, 69.29578427345523, 70.69727851498511, 72.63211311832552, 71.59477956833379, 69.7100414768342, 71.66974390706709, 77.11826124498921, 73.34752205879458, 72.65441571512531, 68.08007701750725, 72.03998427237235, 68.69474380247055, 74.26705114303097, 66.28597705594956, 60.90551676288728, 33.29354870703913, 37.23495806417158, 49.47148607623193, 64.66420250554239, 67.5473093217419, 72.67220758622693, 74.7001749469388, 70.90547792373165, 69.2032241821289, 66.20223445277061, 65.7769710786881, 67.02236283210017, 66.85902749338459, 71.49038176382743, 70.93856703850531, 71.61574855927499, 68.17881091948479, 69.46245362681728, 67.91197207666212, 67.542508340651, 64.63982889729162, 65.33544948024135, 60.60729111394575, 62.65334844589234, 60.53056955337525, 55.091320776170306, 50.632597861751435, 43.132994713321814, 26.30479112748177, 11.986200386478055, 1.7336431217770425, 0.3665482811629773, 0.3880355765502299, 1.94762300099096, 7.049267493909405, 6.543967666164522, 5.912785251294413, 11.202492194790995, 8.354783788804086, 5.501013359715862, 2.5913474396351845, 0.3330471643036412, 2.1579939319241435, 29.024097804100286, 48.64453669517271, 42.919609931207475, 48.5932634722802, 41.93949983965966, 50.281635945843114, 31.003804322211977, 2.2546470165252686, 0.20403729901919443, 0.11707181756895398, 0.36411870991991413, 0.14439755329681983, 0.10429398427086492, 0.26668636068221063, 0.16285759096424426, 0.15046622604131699, 0.19370873308470174, 0.19892285007142252, 0.13058920150562642, 0.14292732331781619, 0.1154549123959676, 0.16483616624628344, 0.1830078943842842, 0.10906258282522041, 0.10770752650475311, 0.165239128494455, 0.20128555716045443, 0.1534519924391662, 0.11289760365240997, 0.16012984297929272, 0.21385762690296098, 0.1647943838108932, 0.19256661856366744, 0.21963500237512976, 0.07011176162068883, 0.1442130486811361, 0.10549729389529075, 0.17306336832623329, 0.1688610543046267, 0.12208475986675871, 0.13258738863852718, 0.15605016431260496, 0.09269502239241716, 0.19689277835911323], [0.049655701018749714, 0.02461221208044839, 0.081170478294934, 0.07946719670848501, 0.1039246149781731, 0.05911439326742004, 0.021911233122791016, 0.05581653031009821, 0.05824887096100758, 0.01645770216841371, 0.005249442737324224, 0.0224294456382913, 0.0814539001834008, 0.07402896069951596, 0.04917462844581855, 0.008898080597000738, 0.06379694865655995, 0.04686665067809725, 0.01537070097026205, 0.06686299723843414, 0.045471202371822256, 0.034279473681723883, 0.12144981853423581, 0.05133860849685246, 0.1362015156736297, 0.10688107085203934, 0.03250949265014741, 0.05791165054805818, 0.056725489801817366, 0.07493010226396785, 0.0860776391721541, 0.04242993673429855, 0.06224395053821707, 0.03363436636244578, 0.019361744221720486, 0.036459867166535515, 0.04857277828118494, 0.06926126612891113, 0.04435012079474907, 0.037469184176335414, 0.042763020272456834, 0.018167026273365465, 0.03273251999710356, 0.0035491046043218026, 0.11117867088966793, 0.04744877790912025, 7.426581363524161, 39.17854347536641, 44.36393253264889, 38.19982974759994, 31.938781661372033, 30.12944329169489, 46.83170741604221, 41.95647585776545, 11.862704561602685, 0.40511789701638684, 0.08402329013352433, 0.432095438121788, 0.7471866965774567, 1.1419893729109918, 0.0814102101890791, 0.287332889894324, 0.06982656240823769, 0.28074600463432653, 0.18512940635123562, 0.27980865009369393, 2.9791095227964464, 12.640267379822271, 28.03902199191432, 49.736857952610144, 61.612876999762754, 66.15318129139563, 64.87890912640479, 64.08501748115786, 64.8616663871273, 67.09622890718522, 63.160750173753314, 60.89739353426042, 61.916378236586056, 63.95687756999847, 67.68776939761254, 70.56420818451913, 67.48550845730689, 68.85501969245173, 71.84614073845648, 74.87129226807626, 68.50804682700866, 59.10752973248882, 43.10954286206154, 32.307600167489824, 42.41199247298702, 40.305526718016594, 60.40044884527884, 75.51232522533786, 72.85609614464545, 72.03491657010971, 73.35799478715467, 70.29096803357525, 69.68216911438974, 69.28464474216585, 66.61030215601768, 65.33353536359726, 65.95647442725398, 69.36364127743629, 62.75949954986573, 64.75466805119669, 63.25006254257695, 57.14114750585249, 51.14416906910559, 46.97692924930204, 42.68376957985663, 38.561609560443515, 34.1616633630568, 29.034919623405706, 26.062735780592888, 16.056003628238557, 7.018266550956234, 0.9491805479891839, 0.18177533552290934, 0.0793422018027594, 0.7134983171859096, 1.5717659241730169, 1.6598638291320496, 2.261490817031553, 2.255942624422812, 2.286244159744632, 3.558330583956934, 0.856467361652082, 0.16305841325271517, 0.007709719263197435, 4.740394690344411, 32.16884632264414, 35.86896519507132, 23.205171438955492, 27.266191513307636, 32.81637864728128, 37.82155636818179, 11.997086924891319, 0.334855254379011, 0.17601463012397292, 0.047687705410944844, 0.06814345957771425, 0.08936170488595964, 0.02644920090754186, 0.051652505362947146, 0.04017010759261828, 0.04718670306066352, 0.014296718478773632, 0.03630208369765071, 0.10846997551139324, 0.05985708103605336, 0.064956518490949, 0.027953094705158187, 0.06298203411842547, 0.1016987694968139, 0.01469985788477765, 0.041680568678965496, 0.014680672170323952, 0.08003450779905243, 0.032258752072530414, 0.08851333911861144, 0.03863497081422999, 0.0532035461266435, 0.08783990186789344, 0.07379414708984476, 0.04853095754139847, 0.017758986777475765, 0.019582187937152003, 0.03584685510084514, 0.10459606040028796, 0.05995042884962694, 0.05275400573267572, 0.02616212477967624, 0.05906546706213586, 0.026420936093575535, 0.030786296608106747, 0.06276102924358941, 0.03243527405204312, 0.043348146737703395, 0.018427415728388775, 0.08337344072999493, 0.03648113376731354, 0.024300418125705856, 0.03823511505259141, 0.043995954516914584, 0.03386965111619042, 0.07049664419384734, 0.011492219017518145, 0.06081497439393594, 0.02864559796909171, 0.0509470226543565, 0.03425897316887014, 0.04435601967176603, 0.06156173391988682, 0.051916437974620255, 0.041368786215541825, 0.06541448585208386, 0.03485770918609154, 0.09128976433027176, 0.008102063532738436, 0.09388173855240307, 0.10884967933018362, 0.09727908568757196, 0.048586947077344504, 0.034026932797484824, 0.08090628521336664, 0.08378970992541121, 0.010275220359495331, 0.08510552722239688, 0.08845459549657761, 0.024856414097631653, 0.01431800518935967, 0.05967098295748715, 0.06461167933359262, 0.04815568937168968, 0.048590846464879094, 0.023570361231724103, 0.0021297306539641036, 0.012803819958090544, 0.01615014467989245, 0.06086038042520804, 0.20367815700029174, 13.585209500405098, 50.06677243017381, 45.80929456218597, 26.191199287291496, 16.599958904327885, 36.4736730821671, 66.80393388194423, 48.83221034080752, 9.240426536529295, 0.16106016483278046, 0.2521282539612824, 0.16688326043227028, 0.9443921307402273, 0.8920184378662418, 1.0127915249716852, 1.4295225181887228, 0.912519257155157, 0.8832615013084105, 0.8468122636118244, 0.5719830011648517, 4.87897300912488, 15.910245410857664, 34.47495875820037, 52.386226807871175, 67.25642634976295, 67.92679863591349, 65.85777974897816, 64.4889823852047, 66.32286302505001, 70.16640924638318, 65.39217872004356, 63.03812903742637, 62.84216742361746, 66.94903804409888, 72.21507887686454, 74.1823201025686, 70.14476560777234, 71.530366405364, 73.48726826329386, 75.38850384373819, 70.04312915186729, 62.91139725715884, 49.92991309012137, 30.656415685530636, 42.30624145077121, 44.99507719470609, 63.669720849683216, 73.59263881560295, 71.91287594456827, 76.59025530661307, 74.3280439992105, 70.1112764112411, 70.049177446673, 69.3398089562693, 69.49189493733068, 68.60881251673545, 66.75477873894476, 70.3131764934909, 65.4907988732861, 65.51656492294805, 67.23389625549316, 59.64836182132844, 56.05690633097003, 52.43670771198889, 47.97916935336205, 43.98456088958248, 39.21171888228386, 36.23274541670276, 29.2153545348875, 21.609151171099757, 10.95733719487344, 2.7867648245826846, 0.5543653078136906, 0.11101233021866892, 2.064854065256734, 5.089203715324402, 3.2078658284679538, 4.095288596806988, 5.115917997975504, 1.9744208791563589, 1.1738988348553259, 0.2379900400316523, 0.1834225011689048, 0.011788973708697146, 2.6404488951929155, 33.03569209191107, 54.40791053156699, 28.729363064612116, 25.887272473304506, 38.73541762751918, 42.55606112941619, 20.515774796085974, 1.5283794845304184, 0.12047343947474035, 0.08921001181607285, 0.038631454470657536, 0.0709015446444673, 0.0375593833685402, 0.03994014714994738, 0.028954425248347467, 0.01788764741391905, 0.07068060488710481, 0.08860771349000354, 0.014167671925538491, 0.05131025175233522, 0.04807897715739185, 0.07843853214815741, 0.047236640502007744, 0.11875668240170326, 0.0334607133822095, 0.01951622202121202, 0.04669863610498367, 0.0829459406856087, 0.04387358346232965, 0.11211899785144676, 0.042548956154214765, 0.01319537419945963, 0.031240638458139958, 0.019180870862797867, 0.048011818059509805, 0.055641601793468005, 0.0522467942397681, 0.011181488967380457, 0.044899781219541066, 0.034178878676386616, 0.03875689370737922, 0.05711622145627776, 0.1623008135826357, 0.02063841634099522, 0.04148217105877496, 0.20628339220439235, 0.22174848574063472, 0.14660715005330502, 0.13724043815126344, 0.22962423732444165, 0.14491601096045587, 0.15628084870836428, 0.20395926530322722, 0.2120119372322675, 0.1437144480164974, 0.09259270368925027, 0.1641036942601204, 0.17058686653692878, 0.12382746433779118, 0.27278104977261636, 0.13732820118386901, 0.0784508968072553, 0.13994325763515889, 0.14122918218133912, 0.19048112805091566, 0.18878972848817227, 0.15095001056550011, 0.2651093533683208, 0.09230228741803477, 0.18378384952102939, 0.26794645274358414, 0.2186130410841396, 0.13872102563900335, 0.19632994888290284, 0.1736565042407282, 0.2352475831585546, 0.17044644262040817, 0.17836218399386253, 0.20925829547547528, 0.1674692717290694, 0.08705992476954576, 0.1749006463515182, 0.12246657042734085, 0.2689047061627911, 0.14346793624422244, 0.127988547507313, 0.1790127765026785, 0.13863304810177896, 0.181466402906564, 0.22829697467386725, 0.2877200094442214, 14.104185162052033, 58.33384221599948, 59.56609402933429, 50.60798891129033, 43.21299929772654, 39.10293194555467, 57.41895721804712, 54.72485373097082, 15.226316432799063, 1.009980901595085, 1.116750391740953, 1.7765751793499918, 4.760258553489562, 1.9631188146529661, 1.1998877241726846, 2.5455554839103454, 0.9543673309587664, 0.9791367308747385, 0.6228327919398585, 0.41753366950058174, 3.7082320499804715, 14.354582409704886, 29.817197130572413, 50.759423778903106, 63.641679825321326, 69.91307904643398, 68.74259671857281, 69.77211690718129, 70.55444148279005, 73.7265799122472, 69.1482247075727, 65.90311450342979, 67.52477138273179, 70.41547975232525, 75.10776412102484, 76.65096575214018, 71.2603739769228, 74.12926612361785, 76.17964590749433, 76.57773510102304, 70.20179687007781, 68.0142988697175, 55.45753286730859, 38.55261948800857, 47.606712848909446, 54.75588360140401, 63.89180544883975, 74.69997098368984, 76.40295428614463, 76.61386013031006, 78.40844646576913, 73.09283471876576, 74.69213408808555, 72.49303371675553, 70.6141556462934, 70.06115636517926, 69.86361011382073, 71.4193005715647, 66.44444865565147, 65.2951196701296, 63.692031291223344, 59.43614982789563, 52.84714060444986, 50.729366656272646, 47.47278351937571, 41.84004814394059, 36.24692478487569, 31.782063361137148, 27.561440083288378, 18.399381522209413, 9.185885979283242, 1.8727241168099067, 0.3254567957933872, 0.16363023660115658, 1.904308389752142, 5.47675448079263, 4.995706177526905, 6.501505067271571, 11.001870805217374, 8.080263474295217, 10.720607446086023, 3.5577253132097186, 0.7348196472852462, 0.21600241262105205, 6.278052051221171, 38.597263905309866, 46.743548224049235, 31.584228815570956, 37.04211473464966, 46.96833925862467, 52.51149554406443, 20.769556068604995, 1.2976691030686902, 0.34437460163908623, 0.24089280846378497, 0.14356499958422878, 0.19966836087405684, 0.13298357866944807, 0.10868374468578447, 0.12311193055563396, 0.19852069987645074, 0.08151395381578515, 0.28399259332687626, 0.1840953868363173, 0.20380696702388026, 0.14291806897569087, 0.17759480904186928, 0.2036611804918897, 0.18702129112376323, 0.12279970376121423, 0.09543031634342286, 0.15470650738045094, 0.24367550027466592, 0.1312088593840599, 0.20679052708850754, 0.1414056275520594, 0.09885236215327056, 0.12122530880714617, 0.16448987918275018, 0.174680442038563, 0.114195731979224, 0.09478158542826291, 0.19167795657150208, 0.341544887351413, 0.14884667020411263, 0.20992059380777423, 0.17509167803631676, 0.23306956454630823, 0.09960337346720119, 0.08427131875988939], [0.0674421826918279, 0.04640011845396892, 0.05768621002414054, 0.05227905037181993, 0.05230581748389429, 0.06832391924915776, 0.013680902531280393, 0.03331393476635699, 0.05672237948484479, 0.01176475958463045, 0.022022214365161715, 0.11204233543286402, 0.0067930404780312415, 0.033035281775218826, 0.05225148652830432, 0.08209599677713648, 0.057929010100422375, 0.03611030124668633, 0.01193350960215133, 0.04712483763033825, 0.0993639633299843, 0.11978825809614313, 0.13964091337496234, 0.06704298959624383, 0.030086649574279308, 0.0935319045017804, 0.021656223520215963, 0.11917700420223898, 0.007746353587736526, 0.03727052991669025, 0.0336661551808638, 0.03349033800224143, 0.042494560081151225, 0.16930756099041433, 0.06695762441884126, 0.06798760665039863, 0.022852004415565924, 0.06459389077199083, 0.058067886519335934, 0.05594452445004737, 0.027099253324371193, 0.04964983661568934, 0.1137105914794149, 0.07207285477629594, 0.042938933212069735, 0.05845478773417492, 0.05416153524551661, 3.329371050480874, 35.05285332279821, 53.66101672572475, 45.57210099312567, 40.28376148593041, 24.5353687578632, 39.39691751233993, 48.86751559472854, 24.753752600762155, 3.550935200145168, 0.47604179610648467, 0.2381690288142812, 1.3954890927960797, 1.4935538629370353, 1.2349181670335032, 0.3940400817701894, 0.46184088554113145, 0.627941862950402, 0.1469842951384283, 0.26096202913791905, 0.2621004664369168, 3.614522949341805, 10.75729827727041, 23.679368342122725, 35.90450579120267, 46.595451293453095, 55.70004517032255, 54.68211166320309, 52.52771846709713, 50.66324726227791, 54.00761696600146, 56.472450071765536, 62.16307570857387, 67.33794104668402, 67.91628668385168, 74.14114306049963, 69.43634633095034, 74.49234424098846, 64.0437816035363, 66.90932012373402, 67.40564900059854, 51.15211579107469, 51.545302021888, 58.37384646938693, 35.191418893875614, 55.04128309988207, 68.77053968368038, 63.48257672402167, 69.50593702254757, 70.28937555128529, 70.3802490234375, 72.24342192372968, 71.20267591168805, 71.65650983010569, 70.70899071231966, 76.0809826081799, 64.24007661880987, 65.05996573355891, 64.37626131119268, 46.376681097092174, 33.87731113741475, 21.75985843904557, 15.64891847871965, 11.722764199779881, 8.70942194615641, 5.076479546485409, 4.074652762182297, 2.4362498137258717, 1.9266390560134765, 0.18418776171822704, 0.2079752973851658, 0.34016660324508147, 0.42565070813702005, 2.20132950332857, 7.4418599759378745, 2.060686056652377, 2.182925497331927, 2.4606168029769777, 1.5420011406944645, 0.8019545674324037, 0.10978936277810605, 0.8888959247739086, 15.817553920130576, 43.5239726497281, 28.51237754667959, 22.004310354109734, 34.32298260350382, 36.54189094420403, 32.1852594806302, 9.542651041861504, 0.2960712871243877, 0.06088251270534051, 0.021846443151814804, 0.1196934164111172, 0.05146119788649583, 0.04866759698357313, 0.06509725650351855, 0.06880512205703605, 0.03206697536722547, 0.02826249080469772, 0.03390699407205947, 0.011529952678228579, 0.13172647435097926, 0.04166258093450339, 0.012636869289581815, 0.046214384267166744, 0.0637999287385854, 0.027921181397452473, 0.007177157920875377, 0.018136022695069833, 0.004638817035517986, 0.017329255502010067, 0.0930899866826592, 0.06304975246049224, 0.06885599795608752, 0.02692959740787985, 0.061766260243471593, 0.13125629554833138, 0.10361124671274617, 0.035519222278268106, 0.1014543644663307, 0.03973464023381953, 0.0385579981300379, 0.03734210934189539, 0.01550859200858301, 0.026663759152495095, 0.08324899740757481, 0.0606320747324536, 0.08934597710087415, 0.019899108935327783, 0.03835621440122205, 0.03200186555454087, 0.02229752338251039, 0.05197613154568019, 0.05231512162173468, 0.04267264104958984, 0.06781148303660654, 0.027673043603558215, 0.022322547644557014, 0.03616242203861475, 0.04753819952208189, 0.03218511953168819, 0.07740309537057916, 0.017873649072322636, 0.10640981952629744, 0.009733549274143674, 0.0009797812080866988, 0.019136820807151737, 0.12335539329797031, 0.04978894669141981, 0.019825748355698683, 0.05499224268621015, 0.0885735919338561, 0.07928179576992989, 0.019460644257525285, 0.04312366765413073, 0.12004325812261914, 0.011361410462057159, 0.017759823728533044, 0.030088934431513472, 0.00657256899191247, 0.08181812136524147, 0.03114516283535669, 0.07558423409899397, 0.04032746971314473, 0.03364493837580085, 0.04135275199528664, 0.06266388546435103, 0.07508284487431088, 0.04509844314006548, 0.043829966246360735, 0.10632055496136028, 0.07025581679397053, 0.03000564152194608, 0.05666394229798068, 0.15289912210597148, 8.949068957759488, 46.687677983314764, 54.40100716006372, 39.901844224622174, 26.509079933166507, 26.605505520297637, 59.07511918775497, 59.19130371462915, 22.981302161370557, 2.5924559995051357, 0.09925615177640032, 0.12339719105511905, 0.7791729511753206, 1.2661632775299012, 2.0538733899593353, 1.3735044531283842, 2.3054507807377846, 3.081616254583482, 0.5013783155910431, 0.2775516631382127, 0.8448075034445333, 6.011993760062802, 15.79187906557514, 29.943883803582963, 44.56779772235502, 53.28266489890314, 60.14333355811335, 58.1444937183011, 58.747911145610196, 58.390406716254454, 59.860616960833156, 62.888157213887865, 66.66363854562083, 68.79842773560556, 69.50832966835269, 69.69735653169694, 66.85712122148084, 69.45587188966813, 62.28999576260967, 63.21381984218475, 64.60789295934862, 53.931797550570586, 54.301127925995864, 59.114240907853656, 41.832113189081994, 54.4687347258291, 69.84728520916354, 65.49615683094149, 70.83193348300073, 72.14368389498803, 72.10133798660772, 71.58705249909433, 72.21839720203032, 71.01168786325763, 72.51805059371456, 75.69309942183956, 70.38649343675183, 62.73600847490373, 69.38552810299781, 52.98325861653974, 39.6805440995001, 28.374602333191906, 20.717845501438266, 16.08289735932504, 12.881741235333106, 7.940747218747293, 6.634978911569042, 5.749930402924938, 4.060217214207496, 0.6267830477126184, 0.7146960496902467, 1.482505526754164, 1.257786320582513, 3.163091237506559, 5.747879003324817, 3.736944535086232, 2.2312348792629857, 1.5040187465567745, 0.6742008258738826, 0.7519841843074369, 0.022113924665797143, 0.07197180777908334, 14.072439459062393, 51.31536876001666, 41.4068341255188, 20.634047985076904, 25.059854369009695, 38.00726882873043, 39.560841206581365, 17.03936830643685, 0.48901046956739125, 0.0689974560913059, 0.016989778960123658, 0.015433259710158794, 0.05357533625717606, 0.01615782088089374, 0.0897692176964014, 0.04330041179914148, 0.05031276697052583, 0.04494873423790259, 0.00529177627721501, 0.01117237443630133, 0.16794447606850058, 0.002208321220091274, 0.0643511787958203, 0.06704917192579278, 0.06061439725360083, 0.06654200639816062, 0.019279338058925444, 0.018857250425724253, 0.007127008368937119, 0.08822551988545926, 0.0737304775224578, 0.05262751695549777, 0.17607770980365817, 0.05693077072200756, 0.09577193793149726, 0.050978658255189664, 0.02547541888610971, 0.06031174272779496, 0.04357113578026334, 0.023243745390866554, 0.013735826247401777, 0.07283096772528465, 0.029955803672032013, 0.033067806038044156, 0.04094430072713764, 0.08997258339678088, 0.0750872498798755, 0.17988553450953576, 0.1675960439587793, 0.1572210837395922, 0.0938733498896322, 0.1460387128134889, 0.1631897513664538, 0.12144460147547147, 0.20070547538418926, 0.15488759524399234, 0.07215804375347591, 0.1002893745598774, 0.26085701380525866, 0.11807493309700683, 0.2350696515772612, 0.10924154862521157, 0.1909844937824434, 0.1402745753406517, 0.10616592777472351, 0.21296642149888703, 0.1589605016934295, 0.24719414211088614, 0.1422609187542431, 0.3106683877206618, 0.18908517795705027, 0.11473801497730518, 0.1290163157447692, 0.17708761287072014, 0.24804345782726045, 0.09353827069243116, 0.1015118670259272, 0.1459479160727032, 0.0998373290583972, 0.15087556214101855, 0.21143021602784434, 0.2506981210242356, 0.08775961585342885, 0.09723287526397936, 0.17494017648841106, 0.13047620353679504, 0.16356469011835514, 0.22421453809065206, 0.14354276771266616, 0.2786891198446674, 0.277013685554266, 0.14094510145725744, 0.2023443366370855, 0.10506464574005335, 7.351403255616465, 51.60866006728142, 70.36266896032518, 59.54372475224157, 52.887642998849195, 34.11534801606209, 50.567949356571326, 62.12212224160472, 30.906343229355354, 5.154575897801307, 0.6261188188387502, 1.065397005408041, 6.360902805482188, 4.868438503434581, 4.948777960192773, 3.2624027084919716, 3.0295514483605666, 2.7071779726013063, 0.2837807240505373, 0.664849037364606, 0.5113099100849321, 4.784049199473474, 12.071745318751182, 26.529150701338246, 38.8918339052508, 49.396961042957926, 57.30261579636605, 56.59070168772052, 55.11705936924104, 55.46123166238108, 58.60308547173777, 65.14404566057267, 67.72463183249197, 73.15317646149667, 72.18817141748244, 75.3478131755706, 71.70175044767319, 74.8846047924411, 64.26061414903211, 67.79936867375528, 69.25703910089308, 61.495421624952755, 61.25004599171301, 65.08764982223511, 45.15929898908062, 56.82444357102918, 67.44373521497174, 66.03474140167236, 68.29343826540055, 70.99897153915899, 71.87020055709347, 74.13109394811815, 73.70447343395603, 73.61319203530589, 75.79541837015461, 77.80563308346656, 72.21367466834285, 67.17876342035109, 69.60682822811988, 54.87185632028888, 37.4429613544095, 25.27348037688963, 16.494947248889556, 12.888840725344997, 10.109775758558705, 5.669587023796574, 5.3562744682835, 4.223268426233723, 3.0576660171631844, 0.6376260110447485, 0.8268288907504852, 1.4035439250930664, 0.8750560254819932, 4.687966329436149, 12.560114725943535, 8.405011700045678, 7.392482238431131, 10.45257914450861, 7.61024340506523, 2.4479593144309137, 0.3709927249339319, 1.643981907156206, 21.56324963415823, 54.36733753450456, 38.28300752947408, 31.196835925502164, 44.210014804717034, 49.68210166500461, 47.2779986166185, 15.398940924675236, 0.4273515765465075, 0.14648203257351153, 0.06447734581607004, 0.24256125603231693, 0.12214538806508626, 0.12953570803567288, 0.16646978745777763, 0.2581563087240342, 0.10164878992063385, 0.1194174562190329, 0.09895740046856866, 0.16800210120216494, 0.26379722861513016, 0.11338888051649255, 0.20174877988474987, 0.15279170125722885, 0.31850889925995185, 0.16114233542353879, 0.13851709303355988, 0.12065247422264469, 0.12827344028459442, 0.34230499978988405, 0.20855698794607194, 0.12636983436682533, 0.2852754228778424, 0.23622100511866234, 0.23178964612945435, 0.14415882497785554, 0.28366339002405444, 0.1457727730514542, 0.15395099146952554, 0.09054572441645208, 0.20788491433185918, 0.11678862550686445, 0.100850350103311, 0.1806032363205187, 0.16515387823024105, 0.1724402936956575, 0.16574148298992267], [0.08536932959912286, 0.021123415114538326, 0.040974220291020415, 0.03214469690236353, 0.03889916772623697, 0.025454435737863667, 0.057177615742529594, 0.09229972102348843, 0.007214406552168751, 0.06439857665569552, 0.039957954863747286, 0.07700656060009234, 0.13571716424438263, 0.015464712407500034, 0.021435862159236305, 0.061282445075771505, 0.03997590047337356, 0.046726908579829245, 0.055719041791293895, 0.028550449848896074, 0.021188676229587967, 0.06180494385320814, 0.027600437620534535, 0.020078789112308336, 0.04584701446395728, 0.06887103626204115, 0.0252919887087398, 0.07018306908468086, 0.07796637683866486, 0.02635261254204858, 0.07338841160338733, 0.04751630472920595, 0.050668905924765334, 0.028367280141420426, 0.052200606798813234, 0.031489678320565054, 0.05719045154570092, 0.028487050327502435, 0.036130414885138316, 0.013495247826100358, 0.04714622297474454, 0.06327936050271796, 0.03573986709177975, 0.012727936076360845, 0.06134696500075441, 0.04957698931496951, 0.04531080654311565, 0.016044566272607735, 1.5684722363948824, 24.00287562800992, 49.81650560132919, 45.83859858974334, 35.489809282364384, 28.35251154438142, 34.92371320724487, 47.38068626772973, 37.74274418430944, 9.377931106475092, 0.534998788948982, 0.05514365613400456, 0.7699998756570201, 1.000998919048617, 0.7043293478988832, 1.6316071969847528, 2.920551968197669, 0.7498680043124384, 0.19636281405485448, 0.11329282075166704, 0.31629481322823033, 0.542419790740936, 1.3098589715457734, 4.951049502818815, 8.792835070240884, 10.653548644435022, 12.115568980093926, 10.71673018317069, 12.759984001036614, 13.88310076728944, 17.781647443771362, 23.34707690823463, 35.25917391623221, 50.65597518797844, 54.875833603643606, 60.26281287593227, 60.13544174932665, 71.73459637549617, 69.90266907599666, 59.27025318145753, 45.8206106001331, 53.50163513614286, 57.35199843683551, 39.22208570664929, 55.07243064142043, 73.48131410537228, 64.88746381575062, 68.98445790813815, 79.65175151824951, 75.7976148974511, 78.98425040706512, 74.65690335919781, 74.80804012667748, 71.95229576480004, 65.31937168490502, 65.55152108592372, 60.39090179627942, 35.84199497776647, 21.76038403664866, 8.967359950465541, 3.845938376842007, 1.8691862614885455, 1.0675779657979165, 0.3295809841684757, 0.5336590543870003, 0.2112530198909583, 0.4021513287819201, 0.699435087942308, 0.355809873510753, 1.1116445689432084, 2.206415346553249, 1.4670848509957715, 3.843550143703338, 6.806243811884235, 2.121749515494993, 2.7245413247616064, 1.496149981694837, 0.03534365790866075, 0.12475420856067251, 7.37639561776192, 32.6974465001014, 33.70977886261479, 22.608190621099165, 19.556088486025413, 35.51907408622004, 41.74872359921856, 29.04286438418973, 4.303344103597826, 0.04833073280150852, 0.08534199558198453, 0.032142708904200026, 0.05902866036781381, 0.035770656165456584, 0.050626047135841463, 0.04915792389862961, 0.05065847946811588, 0.052467772301526806, 0.01608631614926121, 0.02799812535334739, 0.04174757072882306, 0.02993310065639596, 0.07095565343455923, 0.076323646841751, 0.055487058876502904, 0.06430185805525511, 0.02797381163785054, 0.0734547165132338, 0.048382911050031265, 0.021306738039598833, 0.03994633714037557, 0.08417238616534779, 0.027518171268785675, 0.03973038844583977, 0.0782966603254599, 0.11723301012910183, 0.04665539044165804, 0.08150345841122252, 0.03585879458114505, 0.013853962750985258, 0.04467111929590183, 0.030701837329674634, 0.06165100614570322, 0.052324582807599544, 0.02216709499818183, 0.06892003524567812, 0.044851893063394294, 0.050769876313185504, 0.041325004290669196, 0.11530149562825119, 0.019832846160317143, 0.053864725970573006, 0.05920362718884022, 0.021588537736885974, 0.04755744748117943, 0.0862045492976904, 0.044326559760637825, 0.0470634241918883, 0.06069505865114832, 0.1335893703564521, 0.06195502047757469, 0.10114530161503824, 0.08921705982497624, 0.02030024023336028, 0.02547091237389513, 0.020159643947056705, 0.046006586748145284, 0.0299570006844137, 0.031002919460015915, 0.019465775131398154, 0.012935690502936562, 0.06985047967323373, 0.024510517738939776, 0.061172687658859845, 0.054098853931551984, 0.013298424516594218, 0.005252879599274527, 0.013325568926971287, 0.09443096230707823, 0.025842271579970277, 0.05205095152280504, 0.036488886577107256, 0.026718750858919758, 0.05050680171998759, 0.018035420028853322, 0.07219971893655677, 0.0292495931799133, 0.037695888745328116, 0.11417612012836242, 0.0513284846449331, 0.02771045167690083, 0.02818893104220831, 0.026205902874109246, 0.05576412223519818, 0.03396406379197875, 0.09843876660471002, 0.03781327639796561, 5.04100465005444, 35.97648520623484, 57.70239945380919, 47.21110259332965, 26.261435208782075, 23.899203461985437, 43.626832885126916, 64.03061028449767, 43.16385984420777, 9.615712050468693, 0.20255991377897803, 0.26296108961105347, 0.504707764353483, 0.7659323165012945, 1.175543656272273, 1.5048229550161671, 4.7615720572010165, 1.7641366080891703, 0.7057789088256898, 0.8152458251964662, 1.089296497164234, 1.3035960495471954, 2.9726045170137962, 7.710032914915393, 14.10768097446811, 18.984232410307854, 19.542879904470137, 17.38898681056115, 18.732218165551465, 20.3209134071104, 24.240604600598736, 31.60423094226468, 46.68727397918702, 59.72143165526852, 65.6769427945537, 68.61673570448353, 70.00526259022375, 75.39903933002104, 77.08065355977705, 69.58307435435634, 58.86462127008746, 61.898676579998394, 61.72653944261613, 43.90165375125024, 63.23671079451039, 74.30103455820392, 66.1754995776761, 70.49766909691596, 77.6130368632655, 74.13282763573432, 79.1861818682763, 75.51209772786787, 76.78877430577433, 74.17067066315683, 71.16262066748835, 63.42298807636384, 65.3858950830275, 42.79795369794292, 27.935626352986983, 13.332474520129542, 6.134204518410468, 4.006071835756302, 2.853424034772381, 1.7331661860789023, 1.1866899291353843, 0.9018951498212353, 1.8500132257899933, 1.7721579776656244, 1.3728233090331479, 1.369107231017082, 2.899369208082076, 6.580398640324993, 3.683585837002724, 3.0764666728435026, 1.1057873671093295, 0.8746660560850175, 0.35632125252196867, 0.2079618602029739, 0.07834993407971437, 4.302526289416898, 38.073866751886186, 47.795951520243, 31.04560305995326, 15.537790867590136, 29.146726785167573, 47.024444841569476, 39.397003804483724, 10.142904097034085, 0.14381967785377658, 0.007149064040277154, 0.02354612029458006, 0.08252354278679817, 0.028692269960658687, 0.022884586134985573, 0.04970192293366117, 0.053419640377884915, 0.03944438101062852, 0.059122578916890975, 0.04435328473787635, 0.049893812636934945, 0.027625735759014086, 0.06870749947284499, 0.0596660340294963, 0.1500222474456795, 0.06537507828925887, 0.018096450423341126, 0.09768457602589362, 0.03479547603356262, 0.021971453379298893, 0.05218770970860797, 0.08723323684065573, 0.0187390832786238, 0.005685541639855553, 0.11985666208690214, 0.06424080467812958, 0.09690901159398979, 0.024832050586419723, 0.09447007109561274, 0.031227457915402712, 0.0034228712695861057, 0.04203932382346642, 0.05504468140462714, 0.09557764271214124, 0.017861307395862478, 0.03798204939812422, 0.1382964443896086, 0.05064410765865638, 0.056629882028867165, 0.17220098314987076, 0.2392856938944709, 0.1366008926303156, 0.24331836540612484, 0.140717726561331, 0.12879290918429054, 0.1516304958251215, 0.11575808403112235, 0.11995707323113758, 0.171320763446631, 0.24979838140068517, 0.274128322639773, 0.18981328324204494, 0.16271800974444037, 0.09711940998151418, 0.181913583749725, 0.22438179040628098, 0.20079003616927132, 0.1877787682197748, 0.14854509203184038, 0.17602406832720005, 0.165390292963674, 0.12024804874653779, 0.09149480776320543, 0.1801134456670092, 0.21856344455192167, 0.12064141191301808, 0.16855333210720172, 0.16554769338859668, 0.34654961718666943, 0.17121420061636358, 0.17936491647795325, 0.10327204596251251, 0.11959380965920226, 0.20725828505331473, 0.08702586450043225, 0.17757705112378444, 0.09112048954252275, 0.15820945973598188, 0.17674005410123259, 0.15019827912892067, 0.10322814146357198, 0.13266969712511187, 0.13190796058024132, 0.13527413559777124, 0.10703064185837585, 0.13751478955870675, 0.10199235737203591, 3.596997799411897, 37.42065091286936, 68.15653970164638, 62.15614095810921, 48.04475922738352, 38.594416264564764, 45.71925263251028, 61.04574934128792, 48.59628761968305, 13.781953627063384, 0.6523931218731789, 0.5225845486406357, 2.855265097272012, 5.3495275012908445, 5.865163755032325, 7.192466364752862, 7.277590622825008, 1.8887076526880267, 0.609668214474955, 0.8681353097481113, 1.180295362587898, 1.2503134699598437, 2.2524720622647196, 6.627616622755605, 10.535613759871453, 14.147931356583873, 15.45934444473636, 11.9939725629745, 15.068870532897213, 15.648715496063234, 19.821342691298454, 25.388982411353822, 39.0716588881708, 52.927525658761304, 58.56617596841628, 62.504906346721036, 62.02525146545903, 76.01559669740739, 76.42728082595333, 66.71862233069636, 60.17440265224826, 68.28050228857225, 66.6281646297824, 54.714349623649355, 67.88743372886412, 75.1215002613683, 71.98521229528612, 71.56673462160173, 78.39245888494676, 74.83844634025328, 79.95022035414173, 76.7661657641011, 75.07748342329457, 75.15256543313303, 72.23392194317233, 69.60835010774674, 60.53338973752914, 40.183348809519124, 23.156690943625666, 11.236341268785539, 4.719877752565569, 3.337082185091511, 1.982672320258233, 1.1315443462902501, 0.8255657649809315, 0.6279267863400522, 0.9821447597876672, 1.222997716357631, 1.2532420095897492, 2.785743537449068, 4.9331747716473, 6.463542897855082, 10.170053762774314, 17.19743001845575, 9.872324293659581, 10.04098032751391, 4.012157147930515, 0.41148871483822025, 0.438348492907901, 9.937428774372224, 41.20231782236407, 41.66134888126005, 31.45882867997693, 28.789322376251224, 44.758758314194225, 56.2854746080214, 44.17368188981087, 8.952236271673634, 0.22712574881171027, 0.14076724648475647, 0.12120568929540536, 0.20270242145465267, 0.17186295451416125, 0.11059446756037013, 0.1961283298629907, 0.15588373937193425, 0.16330265740473426, 0.12297107762987576, 0.18486509069560036, 0.11306764452808327, 0.0867887679487467, 0.2083967989611049, 0.22788691845151687, 0.18032525365631427, 0.20950140581736643, 0.12280327373094137, 0.2749047374292728, 0.08735143654649297, 0.05809969065951244, 0.22628122880574197, 0.1918121138888021, 0.15755388765565811, 0.13353159200520287, 0.21560674352991968, 0.18419857887971788, 0.2543642960729138, 0.252997487963688, 0.2702650025246605, 0.15373970442000898, 0.14157145494414916, 0.17242233659471237, 0.14975705844981058, 0.1376578641394454, 0.12966522286015172, 0.24284732858500174, 0.23549908982409587, 0.1303518827884428, 0.09214992019077463], [0.051289582700138135, 0.06499571921003443, 0.035123009264709494, 0.08344441111530028, 0.015038094321836629, 0.005582652201185064, 0.01611606334336102, 0.01665306033476466, 0.021392511158821084, 0.0360903408258192, 0.0702701656207923, 0.02263624341257157, 0.07510744395755953, 0.025666278201125325, 0.01448605327881993, 0.04568219447748796, 0.03238441730518976, 0.013178810420926782, 0.009582107098052099, 0.04893351376297013, 0.03226569665956401, 0.06873824258124636, 0.022030823278210817, 0.05275155808175764, 0.03424294660949419, 0.029535474210617044, 0.06080025401447089, 0.0483711937352294, 0.028373588875476873, 0.019147965471230207, 0.07499117479329148, 0.016892558572092847, 0.02317512306504913, 0.06494535658989223, 0.0459019084941716, 0.08651472297647307, 0.03675551198783421, 0.05641900100595048, 0.07111059471724496, 0.014669784145700115, 0.015419729639806095, 0.10762119605656593, 0.03430194304054303, 0.03942511772977249, 0.032530678811693386, 0.04417570938746776, 0.014167289839186257, 0.11501319375970673, 0.0496702490284318, 0.30716374997169743, 16.1022924992346, 44.90643947355209, 49.48832873375186, 44.96823249324676, 25.83640129335465, 23.524607304603826, 32.30136752128601, 46.384565061138524, 28.365247480330932, 4.693036483180139, 0.5046980197150861, 0.8113148135523643, 0.9756340543108603, 0.8384550410893656, 4.788342723923345, 2.14755478885866, 0.24480327362975768, 0.3360533852490687, 0.7488961758152132, 0.34217001509762585, 0.05967430777907853, 0.07274057701109879, 0.23915787978518396, 0.01381188824457387, 0.16820215740271155, 0.1616744754175025, 0.31628310740474735, 0.4911309090112487, 0.4907522777155523, 0.9532900274761262, 1.9189303728841969, 2.922425635399357, 3.9630836392602617, 3.0081725697363577, 4.4627609945112665, 4.640537029312504, 4.332693728708453, 2.198052117901464, 7.9496804168147435, 26.504261301409816, 27.957979940599014, 21.908977147071592, 5.810662421487994, 24.57540439021203, 51.67234759176932, 61.45883767835556, 69.76694722329417, 72.86884384770548, 68.99028655021422, 70.01582945546797, 64.06868865413051, 60.25148899324479, 55.597537948239236, 42.11889728423088, 18.51823914435602, 8.635632357289715, 2.6786231177468456, 0.7992674987162314, 0.6308873790887095, 0.22256030911399474, 0.393806241092182, 1.2617846866769176, 1.039304173281116, 0.7289290440178687, 2.6150000672186575, 2.093535171401116, 1.541546145754476, 0.9651140736476068, 1.9833032089856364, 8.050629967643369, 1.822225439452356, 0.8720237881906572, 0.48672599537718686, 0.06401687334742277, 0.30152448483051797, 4.849602301274577, 27.18763428349649, 36.21365131870393, 21.202583774443596, 19.303887928685835, 26.031294061291604, 38.35797186820738, 39.38303624430011, 15.791827094170356, 1.8959761723395319, 0.04848994885481173, 0.057952038703426245, 0.02016825477532562, 0.03201355031060596, 0.10898372939517421, 0.024786573692014622, 0.031867191127891985, 0.033882410310569315, 0.12442856756669861, 0.13120519748378184, 0.019743979961100607, 0.02105500346290008, 0.009926981686974966, 0.04821364392316149, 0.028125558333892017, 0.07849249538154372, 0.0510864774696529, 0.10540566211866756, 0.047300486269617276, 0.0866834615026751, 0.03203114160456725, 0.019485337186544653, 0.019258217014853033, 0.08807015725441518, 0.0014827555165656152, 0.0514631629020216, 0.011102491895848466, 0.012735393942303717, 0.04427856435218165, 0.04286923836315832, 0.06891170786994119, 0.08072395628738789, 0.034077529074443925, 0.10514226576854145, 0.028995397545757796, 0.03867969502724948, 0.08222431650445347, 0.07320727011369121, 0.05962384556750617, 0.010389270741612682, 0.065056853026392, 0.024288118584081534, 0.06482674319657587, 0.06704687366201993, 0.020942087848520568, 0.0839512855295212, 0.06586104616402619, 0.006316439943358062, 0.02338480707558413, 0.008665545141294358, 0.051447967548043504, 0.07599196141405452, 0.06021172611884052, 0.04995691912969755, 0.034176147572936556, 0.07386599081538378, 0.03389829897411889, 0.030958972826239564, 0.06246519290030964, 0.026529421804532893, 0.048023454935079625, 0.04678057303892509, 0.03541926695634762, 0.034433610572089116, 0.030236243563253554, 0.029512384320579232, 0.0053038493440967175, 0.14757985189076395, 0.06251608029067998, 0.04373790546049995, 0.0393385689465269, 0.0494663815404619, 0.02064319481442292, 0.012067348992962752, 0.0454722480818389, 0.029027056129228686, 0.05682867418433871, 0.03441665321588516, 0.016161139956825686, 0.0341269915412751, 0.022064092561542507, 0.06197579295164155, 0.0959100406016073, 0.046187521394101844, 0.07640447677864183, 0.028038620761024858, 0.08490915590476605, 0.04588311252694938, 0.08156048599630594, 0.12933776623779727, 1.384088846464311, 27.665918296383275, 54.33558202558949, 49.952451029131495, 35.521219622704294, 24.595588907118767, 29.301356423285704, 48.15244397809429, 53.92717307613742, 25.213719144944225, 2.2459829911108944, 0.20305554202247053, 0.7726658003464822, 0.6909780288415571, 0.82212615277498, 1.7248967265890491, 1.5823390406946984, 0.7170014227590253, 1.615021822433318, 1.8039377562461363, 1.4501843385158049, 0.35955524672904327, 0.4248868265459615, 0.553881446680715, 0.25909173272309766, 0.3645388631811065, 0.406726528439791, 1.3111171943526114, 1.4776502453511762, 1.6025803093948674, 2.175002064435713, 3.3076619573177832, 6.12047573251109, 9.202524673554207, 9.062339163595631, 9.277213465782905, 12.198801675150472, 11.529655129678789, 6.293335076301329, 14.296497010415601, 40.52820359506915, 42.36858752466018, 32.39037786760638, 12.842449872724472, 34.20340914880076, 60.2017141157581, 66.06193127170687, 73.14257037255072, 73.01514041039252, 71.11332431916269, 71.29377688131025, 70.64860974588703, 65.32540821260022, 60.21806647700649, 49.593142309496486, 26.115515193631573, 11.909520991386907, 7.08263558726157, 2.134235400346018, 1.231175735592842, 1.3578133789762374, 1.583147661820535, 2.4743718197268825, 2.919141140676314, 1.9003933740238992, 7.059872602262805, 9.164683607316787, 4.302490007492804, 3.027018087525522, 3.9933748783603793, 2.300128859858359, 1.2581448497310763, 0.24295983625756157, 0.06696984352123353, 0.3052325955321712, 0.13159075421431374, 1.7934450483129871, 23.283346237674838, 54.835421423758234, 36.67215285762664, 19.814886469994825, 19.909225356194284, 35.54380855252666, 47.122845342082364, 26.461223094694077, 4.096688147514097, 0.02356000755342745, 0.01970749119326713, 0.06619430207196744, 0.06992044648335827, 0.0880487374360523, 0.10728435485713905, 0.019579027824464346, 0.07509635100441595, 0.07215105703160649, 0.09118861008074977, 0.012348643072219867, 0.03996869924688532, 0.022709653787915746, 0.032090948173596014, 0.07449121049214756, 0.049499963004622734, 0.04142692845855509, 0.05626400992754967, 0.05932655365717027, 0.03492925030690047, 0.034185340628027916, 0.05216577661133582, 0.0376902120338092, 0.06616671524581409, 0.13244345603931335, 0.02127922973745773, 0.05787764773553899, 0.019049331650979096, 0.10473451547084317, 0.09656333740079596, 0.060007659448010314, 0.032314109585938916, 0.10540895629674198, 0.024285803083330396, 0.023003189952202865, 0.04555174119530186, 0.055366633685245636, 0.04288368295097063, 0.011150200978942938, 0.06887860521073304, 0.07053474174632181, 0.1390018275067691, 0.16711627373531943, 0.11485970038319789, 0.14852086833167463, 0.1051367959007621, 0.1318925162476878, 0.08944428150331782, 0.12341845765589707, 0.101972829790846, 0.13753818588391428, 0.21926536495166443, 0.13291319051096517, 0.15505228882595418, 0.22382760240185648, 0.10468219932649406, 0.11655925878233488, 0.14255874309568636, 0.14698423385139436, 0.11942990514780245, 0.15949751400659162, 0.18212595864409403, 0.10602980161145811, 0.12683668834788184, 0.164777024258529, 0.1429932068793043, 0.1824436706280516, 0.4064293476122041, 0.08983661811197959, 0.26483258112303676, 0.12192414187255407, 0.10585085879410468, 0.19091724658445006, 0.08668156926550212, 0.14247094941956384, 0.24544412150017678, 0.15725986311031928, 0.09783134315042727, 0.13610054528520954, 0.16333224372036997, 0.10408097352351874, 0.12766236259091285, 0.164247305102406, 0.2823282826331354, 0.14429125093644665, 0.11810761440785662, 0.19809774273345548, 0.1988123495492243, 0.2068011297453796, 0.27316584041522396, 0.6394896884599041, 24.512322871915757, 63.1440761781508, 65.7042738699144, 58.00978383710308, 37.63931520523564, 32.945465810837284, 39.218755614372995, 56.45341873168946, 34.93986552761447, 6.3502011087632955, 0.6681005596633881, 2.034259823060805, 3.343730357385451, 4.9793057672439085, 9.835602083513814, 5.213780153182245, 2.156794422095822, 1.269649284020547, 1.900935396552086, 0.6695298958689936, 0.18130884926405647, 0.16220375024262937, 0.44587328429183654, 0.23320090266004687, 0.6033564467103251, 0.4098541589994585, 0.6665805799345816, 0.9056673054733585, 0.7915921557334162, 1.3227823232450795, 2.861940726157158, 3.5363013273285286, 5.378203459324376, 5.358929422593886, 5.612996047542942, 6.867161652734203, 6.6669756462497105, 3.3747609632630504, 10.619325964681565, 37.55736120285527, 40.105831007803644, 29.87022561411704, 9.526481070826131, 27.274757969763975, 56.892590830402995, 67.17572750583773, 72.77576600351642, 72.51364184964088, 69.22034925030124, 72.65308995400706, 72.51919592580488, 67.32606410980225, 61.188637364295225, 44.88272874586044, 21.809774521858465, 10.692990037702746, 4.868948901853254, 1.417582700810125, 0.9716622867891866, 1.1835390401463355, 1.8644004795820484, 2.714224510615872, 2.745226924457858, 3.110507207532083, 5.048104140066332, 6.1012948520721935, 5.505593707484584, 5.1401445173448135, 10.427979019380386, 14.701836705207826, 10.04553419928397, 7.284246885007428, 3.572515100240708, 0.7620013661442265, 0.6319322617303941, 6.727937123467846, 34.20546054840088, 45.66625356674195, 31.248146410911318, 28.44609341313762, 36.43838351772678, 50.21011544812111, 57.08034292344124, 26.091161197231663, 3.372723291958532, 0.2060471000450273, 0.1727242365239128, 0.15411311099606176, 0.16430338273846334, 0.25633217676753, 0.3167953750779552, 0.10383263846198398, 0.15915590007939648, 0.2231096247992208, 0.27756079490627017, 0.08131989608368567, 0.1351209486564321, 0.1893030840062326, 0.12833495714491414, 0.21290050729388194, 0.12962060589944163, 0.1541666145766935, 0.18836471822953996, 0.12484590928520888, 0.17222557457224016, 0.09529842664637873, 0.12168499986611067, 0.09403507871132705, 0.2073881829217557, 0.2726137668134705, 0.17320553892322127, 0.10834881870616829, 0.15552461267479006, 0.2043499548228518, 0.17465013560027848, 0.26272847467372495, 0.21618733092421488, 0.1973324362188578, 0.13165343552827835, 0.1090185021260573, 0.2237433633737026, 0.171470349774726, 0.19420178727276866, 0.2280802330783298, 0.14915653744772558, 0.15931060387482568], [0.05046101264475335, 0.07991219420106181, 0.14127257340137037, 0.059235262789673386, 0.05496280575771967, 0.07725779913486013, 0.009862682969880202, 0.050900134242950916, 0.0561252216087474, 0.08044169885256598, 0.10380692855124513, 0.06851058423278794, 0.1310992168803369, 0.04214931489719499, 0.04927885087747728, 0.014606801184615301, 0.015627829763557644, 0.07416342445198568, 0.0863097867958488, 0.056644790099873665, 0.04360272541582104, 0.09658724700491275, 0.13893940666269872, 0.041984950733040614, 0.01617852440704742, 0.08144021019219391, 0.05959467293934957, 0.07124969330165656, 0.046006720813532034, 0.05398191827078981, 0.07686638949258674, 0.08947141633759584, 0.09280154691828836, 0.025275152011383927, 0.061020937132378744, 0.07548402213761884, 0.043352130394909656, 0.08849501429546265, 0.04571211787181036, 0.06300220521347177, 0.026549474155950933, 0.04066343374189831, 0.013501073924764512, 0.012487236996211354, 0.017650351679373174, 0.04508857209716113, 0.0508792277034973, 0.05731791708498232, 0.050093455150002436, 0.1311772812398211, 0.06417736876755953, 5.940776755732875, 39.715213929453206, 48.10754852910196, 40.245816476883434, 29.986406218621042, 37.112984118923066, 30.361853530330045, 33.49956727796985, 39.73895603610624, 18.4983076203254, 5.299657506327476, 0.42257229106560834, 0.21324471059826114, 1.6643501625907038, 1.258057822142878, 1.2273837842287556, 2.5110609348743194, 0.9100232814108172, 2.084318336940581, 1.1011631378243047, 1.871189489479988, 1.3766499488584458, 1.213784804267268, 0.15426917842799617, 0.826147562794147, 1.306804425774082, 0.3684994151755687, 0.37339692334494284, 0.6316356937731467, 0.10566445428036875, 0.1801372097144204, 0.10703477107228772, 0.011705127300604457, 0.042831148471563094, 0.1963536056780046, 0.1757843440939342, 0.04460375718471985, 0.30409820317741365, 1.1554417542872892, 2.304511127933379, 0.15089351924196368, 0.11050275917495452, 0.8507155735165843, 7.8320083310527195, 16.39934535949461, 26.39051844996791, 42.24783735890543, 42.429780421718476, 39.6310830116272, 25.244152815111224, 19.375308405968454, 11.218836711299035, 2.5464701316049023, 0.5267882262987476, 0.26317629903074236, 0.49772334074781793, 0.6331996775923238, 0.727526612820164, 1.5084224650936744, 1.6248517723814135, 1.8592234412508628, 3.753025027052049, 4.072523650623137, 10.580921057731876, 13.42123285416634, 4.540430788070926, 1.0317923441048593, 1.9839591028228885, 4.195140619431773, 1.3080361725822574, 0.11921339337864231, 0.24340620504752283, 3.3503831874939705, 22.272323946799002, 46.53557631277269, 27.617582928749826, 18.607712330356723, 28.64186675317826, 34.749524670262495, 42.96113998659196, 33.91180838308027, 7.487507539410745, 0.13588910501810814, 0.04907354697464936, 0.07398697908126539, 0.1005147193228045, 0.041615504831556356, 0.03662516212751789, 0.06664106156677008, 0.03187881076648351, 0.07565898129776602, 0.04821574683451364, 0.00973487460625268, 0.01001644351955263, 0.03542714234020922, 0.05563459591940046, 0.01386401957021125, 0.006187977532165186, 0.04922687947269409, 0.025958054278406407, 0.033377271085496873, 0.07245587575579844, 0.0647196670873992, 0.0473877934799079, 0.01920751157036472, 0.05152613532939746, 0.08293458726257086, 0.05336178924828287, 0.07189543647391182, 0.0361065014505819, 0.0218301733595229, 0.023220942783800345, 0.021653938662981796, 0.05893564963292691, 0.01836495657992219, 0.034239246404819915, 0.021824601985093568, 0.04123952803051761, 0.046006291804294434, 0.0817157720185576, 0.07675608815324884, 0.05992539309626145, 0.06364705589329524, 0.032758310347074465, 0.046335311246014414, 0.04244535042333507, 0.019163723899832657, 0.0506406755847556, 0.088663668551993, 0.057960871697193196, 0.11967435614356112, 0.050441542520157756, 0.08539278721136433, 0.035258671944780696, 0.02303672162064862, 0.02659945373213099, 0.024169206416474718, 0.07531023509199582, 0.01996077518279274, 0.013283250230034033, 0.08244113470878332, 0.05185790119632598, 0.049415708654710365, 0.060434810922390995, 0.01533672497082021, 0.025183466608606042, 0.0500460917640838, 0.04964461955692499, 0.0063217436658188466, 0.02050943969328317, 0.03823470519555192, 0.03376426423088678, 0.06692854372123558, 0.055315351759594296, 0.0024971943029442863, 0.03575459513212404, 0.08567342053978674, 0.0457067207823838, 0.03929106766478189, 0.013454214241656085, 0.0712810722630351, 0.029640679150038672, 0.03185396078943966, 0.07707076642902629, 0.02991432767181147, 0.016590786962619713, 0.04916208758649807, 0.005611030013120223, 0.029052813920462807, 0.06756002999721997, 0.0964923440328529, 0.022887181257829074, 0.05219142523504073, 0.018868121213369796, 0.08800095653221493, 0.287218957298225, 13.841191222590785, 53.86594487774757, 54.952104091644294, 36.636761311561834, 23.666744193723126, 26.340996565357333, 44.73910331726075, 57.96104446534188, 51.565274730805434, 15.89742220217182, 1.4647392736327265, 0.2934298159614686, 0.200127063679599, 0.7194010552860076, 0.9438645106650169, 0.7575575658871282, 1.9517314385983253, 1.7618102748547833, 4.603566238957067, 2.564998918002652, 2.290044446145335, 2.4456027054017593, 4.370767685674853, 1.8334515080336602, 2.4072301580059916, 5.072727309119317, 3.3109680250767743, 1.777382942457353, 2.2164360217509733, 0.3233334452154175, 0.8294919962363859, 0.06332988400132426, 0.06802780328378563, 0.014092767678741968, 0.17838481423114577, 0.15511509271398669, 0.07942277126975598, 0.4391080231195496, 3.3270919082626222, 5.252332639309668, 0.8475662167033843, 0.11130389562177082, 2.3580321140827674, 13.356754972088723, 26.875656804730816, 36.315797682731386, 52.1989453992536, 52.0289537983556, 50.1482988942054, 34.44335229935185, 28.982689342191144, 20.071613442513254, 5.8708757065957595, 1.28068940774087, 0.685821705527844, 1.7399966260117872, 1.4230916697171427, 3.0900314546400502, 3.9288158522498224, 6.084424737961062, 4.456019420777598, 5.107135320863416, 6.037322465450534, 9.635414115844235, 14.898244488623837, 5.088727147348466, 1.3095571941906408, 0.5620714168875449, 0.055966541816991185, 0.6660855645614286, 0.15428316719349355, 0.1721420709884936, 0.8105797368672587, 16.901553869247437, 53.400367383034, 46.126108323374105, 23.509849386830485, 14.841458374454131, 26.119804305415002, 45.16643378042406, 44.279060286860314, 16.043079418520776, 0.5972968138033344, 0.038285190389762004, 0.03030612801892623, 0.10965818554283151, 0.011758068764221766, 0.05777383133048012, 0.05725599419806273, 0.05559683161517305, 0.04247727713757946, 0.0883789596358134, 0.024126516166894187, 0.012749327166426568, 0.035915619152928555, 0.05139123490681091, 0.023147907791539066, 0.052425212286893404, 0.013243353328547411, 0.1256571810752634, 0.07788217611490719, 0.06740084458743373, 0.05556748278679387, 0.03073626340577199, 0.04490383382466051, 0.08564305281446827, 0.08509782037787861, 0.04517712803076833, 0.027578772654035882, 0.018805390103690086, 0.029731619532310197, 0.021570741514404936, 0.02057006980683054, 0.0798365047141429, 0.0762137591898922, 0.029313333610433246, 0.04404840089621083, 0.08072085363129455, 0.03193735329043721, 0.04920282048143206, 0.10397257208223305, 0.022057128822310798, 0.027905679608304656, 0.06325834671095495, 0.016705322852959077, 0.11186703153315092, 0.24478476494550708, 0.19945477556076743, 0.1917122160234759, 0.1387624709957069, 0.2790608869925622, 0.19150359495993585, 0.1666847823728477, 0.23332951350077508, 0.27823878271925834, 0.18859223102129277, 0.19701080186472786, 0.26107700361359504, 0.16298822427709259, 0.09421747658521899, 0.19189005567421838, 0.11139148245415381, 0.19032378891302695, 0.23089128546416762, 0.15319087903105444, 0.20069007701691122, 0.22587929311538898, 0.1977483913182251, 0.09148321685291107, 0.16806294390511128, 0.11983806913297985, 0.26033607401674796, 0.1616772180122714, 0.1116598507149085, 0.180160008491047, 0.2938643716756375, 0.13649149527472837, 0.17512069744688852, 0.11490529027557182, 0.1413196111999212, 0.18174558066793028, 0.11265309136961738, 0.14612171077920547, 0.1546610017577487, 0.2272030470832702, 0.1671849765003689, 0.13755131663093645, 0.19297963188540554, 0.16382967993136377, 0.205049776141682, 0.26739106964199777, 0.10680667605371245, 0.15473918869130074, 0.14320230291735742, 0.24802530154345498, 0.17906401246305437, 10.580606287525548, 57.262219305961366, 70.99493934262183, 52.357130665932935, 43.15499136524816, 46.13780090885778, 37.33151112833331, 43.591555087797104, 49.669357884314756, 23.058812118345692, 6.458092764500649, 0.7956017986420663, 0.7258763981442298, 5.199021745112635, 5.794163461654417, 6.626662015914918, 6.666398567538108, 5.121275955630887, 6.964879170540841, 2.66163214560478, 3.25944033841933, 2.2170072169073167, 2.2602670375377905, 0.5523267172036633, 1.4182837019043586, 4.363024926954701, 1.3917156501162438, 0.7559243890066302, 1.0490660946215353, 0.23513680684470364, 0.36357567615566716, 0.19461709885827957, 0.10930590001085114, 0.12796416292868315, 0.4007006340449856, 0.3558739491047398, 0.1635642304656006, 0.5670121937028824, 2.493158256815326, 3.7356006330059426, 0.45715178393067857, 0.2983852097344014, 1.773000674382333, 9.15231147120076, 20.075573075202204, 31.84159513442747, 49.77597967270882, 50.58629428186725, 46.61529848652501, 29.96483906622856, 22.319249222355506, 14.780145845105572, 4.1906980449153535, 0.7919349954012902, 0.400487293879832, 1.8809343730249715, 1.7013569897220981, 2.4297999662737695, 3.35368410714211, 8.505290035278566, 8.020730720412347, 8.029001037920676, 13.545095420652821, 23.05938478439085, 22.788760854351906, 10.22247035657206, 8.375173249552327, 7.643807126629738, 9.885242619822103, 4.223326281193764, 0.7466739692514943, 0.4396727524938122, 4.155664905425041, 28.197448484359253, 58.546595496516076, 36.67291379744007, 25.522001751007576, 40.563426479216545, 46.07324261819163, 57.626929129323656, 53.50014855784755, 15.485202670097353, 0.4581863397071439, 0.15467169634517164, 0.13526273620945795, 0.2512333406916549, 0.14617833999856827, 0.2222840731302577, 0.21991666226137072, 0.13300830798764385, 0.15138214544182824, 0.130224451723118, 0.10372668084117675, 0.08769698816561892, 0.11280928137561969, 0.13598906417046824, 0.1457939323999228, 0.12281661132170309, 0.18941094918597132, 0.16378601291967979, 0.17000091652716362, 0.2163239244011141, 0.25970196772006254, 0.16521798446774483, 0.07963341480541615, 0.1972596885095681, 0.13890022892625103, 0.22867919126104927, 0.11711871747167842, 0.18720325232753832, 0.25795911769232444, 0.11283132172520123, 0.0939921318222919, 0.25096416803857974, 0.2242627250210893, 0.1805840688006532, 0.20340677801399462, 0.2620546850225618, 0.12826700514603045, 0.19586160869127323, 0.14748655770334507, 0.16935109010627195, 0.23574115828641, 0.12770171652758314, 0.18736960065941657], [0.0443817142607464, 0.0612589798026508, 0.07015427183960715, 0.031260828705384366, 0.09216687371653896, 0.007123796545314573, 0.044420520444550825, 0.06075169170095075, 0.1181842615046809, 0.026229760767291152, 0.051938148906394366, 0.012430269740551952, 0.011726004154151006, 0.04989467065541014, 0.058482558421430096, 0.08647944462755996, 0.021366789756763368, 0.03998865583731283, 0.046401160333545945, 0.01895357449088366, 0.03928428395621238, 0.04930096783585126, 0.0701616722489557, 0.027058700460099408, 0.025761152444888028, 0.009972035317801902, 0.04623031889599177, 0.05591308037119527, 0.007355006668911947, 0.04198037718813266, 0.0999771247828199, 0.034617804922163486, 0.11143731749466351, 0.026294535416508877, 0.05977388771791613, 0.05081302238508098, 0.07576303135964178, 0.005445144206826245, 0.018259678862147757, 0.03472030748643222, 0.023277970368883783, 0.020049773532176213, 0.057934671490182804, 0.023847118155249668, 0.0546413399429331, 0.043143911527529846, 0.05307322690984415, 0.041208505300023866, 0.06224831723938547, 0.05891414554489236, 0.103164249730687, 0.06807523944805707, 1.6613353308170073, 21.70339592041508, 51.38411221965667, 49.06474805647328, 42.05483321220645, 43.95268378719207, 22.507654390027447, 25.085959703691547, 42.01041629237514, 38.08855210581134, 19.903051545543057, 6.395199029676377, 1.147957994572578, 0.12770134114450024, 0.49842164521255805, 1.8683110826438474, 4.095565369052272, 11.368980138532578, 5.229674577713013, 7.162109180804222, 4.03073373821474, 8.990869656685861, 5.999567201060634, 3.817989283031033, 8.843652317600867, 10.279720291014641, 7.277503840384945, 2.7825906872749333, 1.0795931662282636, 0.7885031666486495, 0.7795018173994557, 1.1335831207613791, 0.10319461745600547, 0.07747935176256203, 0.1265971249930801, 0.23075003417268877, 0.19648114399563885, 0.0639507293160404, 0.07636742876662363, 0.03171769481512808, 0.021328701780387954, 0.04402092132236689, 0.2578223556760819, 0.12475567178860789, 0.5929898674930296, 1.6591630731859517, 3.5782701978760385, 3.0917028746297284, 1.133448166712638, 0.5612803238534159, 0.6972815841436387, 0.17290760732946858, 0.18686655668481705, 1.523616133678344, 2.662221726871306, 1.7304169723103124, 4.134510582493198, 3.8169949621923513, 4.015276412810049, 3.060544791721529, 2.3723320951384883, 4.466744651717525, 10.619227905427257, 21.770105631120746, 5.849995949575979, 1.2265162049762666, 0.6196423115268831, 0.026704398201658364, 0.6202728325320829, 4.432554821814261, 19.97435239053542, 45.485985355992476, 34.08054090315296, 24.841772548614014, 25.70600013579092, 38.53910692276494, 42.023371881054295, 42.9668431128225, 26.79177495741075, 2.652585198802333, 0.11757950403637464, 0.06026801442907703, 0.0335001400972326, 0.043806493312360785, 0.10127788079121422, 0.05752288007868394, 0.027875126106664542, 0.018546391098249345, 0.0334899932626755, 0.04212268951138662, 0.011902881406938598, 0.03501940736426942, 0.026478174352838148, 0.027243971163707397, 0.023676027739120108, 0.031203755155025475, 0.03001571749337018, 0.025952322025512977, 0.08236192887829197, 0.01927806826819095, 0.02207845862534258, 0.06559148280610962, 0.08211481955743606, 0.0343699295133833, 0.028614422021013115, 0.07054187402489685, 0.06122539450805034, 0.02545179656496452, 0.06702859480414661, 0.07034584744683198, 0.0861345901484451, 0.023109310366694006, 0.23476991201600722, 0.05359167308216134, 0.06007989770883034, 0.13849430957869177, 0.0948763658262549, 0.06944010169395516, 0.030142771260392283, 0.0902773408339389, 0.04981742601000494, 0.15577619594912376, 0.07033768094955914, 0.07997301392137043, 0.17212414453106542, 0.010420043535921122, 0.07613717338010188, 0.05511172558932055, 0.037848983756116325, 0.02659619402801318, 0.014263208835355699, 0.01012100494511786, 0.03355499199261108, 0.036491395515059276, 0.03427690345673792, 0.003073464073578737, 0.015424412352243259, 0.1286565455337686, 0.032870193657976006, 0.028686229357375737, 0.011090234489059977, 0.024238744217361656, 0.019946945380539666, 0.021024133949991197, 0.09935431062213837, 0.029713608805210363, 0.07933398167933188, 0.05206614304634352, 0.017852420775940823, 0.06616516008732781, 0.05191881667762514, 0.05644848006927679, 0.02755918378581203, 0.008478094917541791, 0.046467982352741306, 0.05381841595555025, 0.11080796860398785, 0.02443738315524834, 0.05337051498974043, 0.0785869003964528, 0.08228820823733846, 0.08164957436102052, 0.05863341262503978, 0.053199267525586395, 0.04007129757214458, 0.052127119814676624, 0.025484479791034135, 0.031725179494148305, 0.08420846890658142, 0.0782743595059841, 0.031634440209956906, 0.03429807046608579, 0.07733611630335932, 0.014604429184879749, 0.018262791094340144, 0.022508500166417613, 5.396331183372006, 33.10644380507931, 60.420884393876605, 47.708263012670706, 38.83519095759238, 27.430821234180083, 21.394707349038896, 38.16845470859159, 59.5356721262778, 50.03575432685114, 21.594752150197184, 4.263200606069257, 0.7483792809709426, 0.1780779347304375, 0.09329654696968295, 0.8867571911504193, 3.035280805441641, 4.108258404078023, 4.765521883964539, 4.4188858520600105, 4.030925934353183, 7.403613434683892, 5.895486618241956, 4.8824693118372275, 5.402569222834803, 5.576417984501009, 4.456733782445231, 7.377967017312204, 3.182084579621592, 2.7827284605272355, 3.0185567996194287, 1.95722030535821, 0.8286783495737661, 0.23951391148711407, 0.5270419546192693, 0.6966174165568044, 0.8293797183902034, 0.3424426504681188, 0.08245418884701307, 0.17589890488213109, 0.16464625304985434, 0.30891242226766, 0.3317089006304741, 0.7208416683058585, 2.0419703448011033, 4.327318120387293, 7.45171542129209, 5.879336259057445, 2.6253565953623865, 1.7956267441472702, 1.1547633068215464, 0.5217523320067314, 0.42570703092121315, 2.3374041241984216, 3.071886815371052, 3.5521391226399333, 4.286007717732461, 5.05903676632912, 7.010138909662924, 4.540205742082288, 4.501466453075409, 3.267269389283273, 2.011561312021748, 7.753643297380018, 0.5615457579974206, 0.5302507598553935, 0.2446843461403924, 0.08189810094453635, 0.14521231844780907, 2.682944343936059, 11.453725887883095, 47.22040253300821, 56.30564343544745, 36.92084289366199, 17.725961554434992, 20.028908637262163, 41.69434778151974, 51.5456707246842, 39.457027835230676, 6.58132775175956, 0.07033502262446188, 0.035042014618914936, 0.02432230525770255, 0.07467533206386913, 0.018606666896131732, 0.002708858411361073, 0.05755184969354061, 0.04895252806525077, 0.03292449013960939, 0.044347336065144315, 0.094560569062108, 0.09680021178698349, 0.018420044047337387, 0.07742158107219205, 0.09503018862057118, 0.09255698100934107, 0.006131632244139309, 0.04073712756977447, 0.06614447571337223, 0.02572701173654247, 0.04139057375610836, 0.03386902292409251, 0.09335233349232905, 0.12814573342761687, 0.07830791415706759, 0.022250770951711366, 0.03401006737183179, 0.04487309837713838, 0.07214562546822333, 0.04945079165120279, 0.08173644873163394, 0.04309303179803876, 0.14417845215047562, 0.17563693345554415, 0.07883413229137659, 0.062297592014675184, 0.08630005747921045, 0.06883187384735193, 0.008074534163179417, 0.06717713925266458, 0.04675282533430765, 0.03761109430342913, 0.025007358316572446, 0.015777336610030505, 0.20711698779656043, 0.2137775247495982, 0.17414231123703142, 0.17271260730922225, 0.1349973480307287, 0.1035657410900439, 0.14475197621410893, 0.2021371558188431, 0.29823429041331817, 0.08736089773235783, 0.12801752861348853, 0.10661882363379964, 0.15218327422776531, 0.15714354031989652, 0.08233672458558314, 0.2079116201568996, 0.2583351442890783, 0.08922645972380716, 0.0848933438500089, 0.08984748889962513, 0.18132672975620917, 0.17972108607570972, 0.1487302095178635, 0.12189226495402476, 0.24210285966194448, 0.12072549006270787, 0.18582835432983216, 0.12173355451875156, 0.19574594473646534, 0.12514154261518873, 0.22224769927561286, 0.15688774356197926, 0.23516648509089025, 0.08376342544872915, 0.15249603728373207, 0.21953639153751636, 0.15466556764177739, 0.1785367294665306, 0.14852572532911457, 0.10843287387322034, 0.12195146822881316, 0.1657286586780702, 0.18166969199815106, 0.13815905418126814, 0.2614463499236492, 0.17353164723082898, 0.1603794344250233, 0.11240998102772622, 0.16560629911480412, 0.18484658201134976, 0.1379369959355362, 0.20647777935429928, 3.311650272338621, 32.6426431440538, 70.13908601576283, 64.47120228121358, 55.580099090453125, 53.66335445834745, 31.326870341454786, 33.67380288339431, 55.763783685622684, 48.61745665150304, 24.803700062536425, 8.302410341078236, 1.754764349710557, 0.8443745718367639, 0.9894471098819088, 4.419695331204323, 8.766552248308736, 22.400026513684182, 14.67512732551944, 18.20614399448518, 9.552982564895384, 14.276341911285156, 14.174191624887529, 8.150938210948821, 18.70570098200152, 18.043487225809407, 13.902619461859427, 7.683597120546526, 3.0603069980298323, 2.41867097635423, 2.699711495830167, 2.996339514370888, 0.9101589709039658, 0.42961211814995737, 0.5056038114332384, 0.7536549914267756, 0.47815785352741524, 0.22165778093039992, 0.13112319543236686, 0.2152899661732297, 0.3139181020519426, 0.21432924595090652, 0.27203362375017137, 0.4772394673237878, 0.9653243494610634, 2.4608060573377917, 4.678617850426705, 3.793505358119165, 1.6943158449665194, 1.4411067481963866, 1.2036126275216381, 0.5304291664112, 0.2816293652980559, 2.5378480265217447, 5.470733642578126, 4.584478514809763, 9.777025407360448, 11.417915628802392, 15.103037318875714, 12.444443048969394, 11.472129648731602, 8.441492684425848, 20.787122403421712, 32.14804207125018, 12.599675751501515, 5.089016912444945, 1.6963000739774399, 0.3078570288996543, 0.9959678051452484, 5.842044324644151, 26.5468111730391, 57.03790287817679, 46.979702365013864, 36.3669571568889, 34.62148281835741, 49.855999946594245, 54.75831939328102, 62.615744683050345, 43.16214969081264, 6.16062266211356, 0.2689253905367467, 0.2341968169616115, 0.11370301486984377, 0.13032448748427053, 0.12951070292582437, 0.2475240195710813, 0.10977519781238611, 0.13534289964985463, 0.11081274899263537, 0.24444206317345946, 0.18037618318152043, 0.14296489226962292, 0.13446644909920233, 0.2598703232023024, 0.25478924504451217, 0.15208711487150964, 0.131315223031467, 0.17665172416356303, 0.12862348117895667, 0.13462122950342395, 0.10081466572779803, 0.23248163802969843, 0.14273572472795365, 0.2317423172174923, 0.20819576216801522, 0.08956129377287242, 0.13956572950607346, 0.1975613279688743, 0.21015150802991084, 0.13880926364612195, 0.20644977117978758, 0.20022734458888733, 0.3880358216983657, 0.2641004462155604, 0.21596173335227276, 0.2559366608939825, 0.3442136618879534, 0.25163303940526904, 0.14521720608876598, 0.19416234906642668, 0.13967650581992444, 0.2571286170953705, 0.17218547753028332, 0.1496831309651175], [0.05364486639718375, 0.01682023987204077, 0.10963416868640531, 0.047317550878130624, 0.03157696063299814, 0.04968036521947192, 0.06805406477782996, 0.03322659691254939, 0.03581480964297249, 0.039961635916223454, 0.017826563393276547, 0.07940185706942313, 0.07039742814677377, 0.01925729962456371, 0.059299836340810985, 0.01450483296667376, 0.0160073698310542, 0.05061547129204677, 0.032966540705773144, 0.044395706856683384, 0.03204372842916318, 0.07521032190491116, 0.0795246992680815, 0.05515767554301889, 0.037734323376489264, 0.015396024964209047, 0.112317843633073, 0.03832614928063366, 0.06025513649106987, 0.025457172586973158, 0.016766968033006115, 0.011778140267837914, 0.016613758109029264, 0.07041042865884882, 0.03710736084969775, 0.027731524840477976, 0.04547263495624066, 0.055342490424311934, 0.1356171131614716, 0.007744294726440022, 0.05661115500955813, 0.15484106306347156, 0.021307963780277682, 0.07417079421781725, 0.026722768990082607, 0.03540963340069979, 0.048132794834072554, 0.08401988104226128, 0.09969056193386355, 0.006613984183904025, 0.07724075367854488, 0.037980007773806015, 0.04548030349636271, 0.08871649797525137, 9.50218394879372, 45.06539744715537, 55.41931721471972, 47.93178319931031, 39.99102323285995, 39.46852037983556, 26.087470246899514, 23.384731661888864, 36.12761412897418, 39.6206691188197, 26.880663710255778, 14.510976133808015, 4.620479989436365, 0.6141772854232019, 0.3273131187644697, 0.3156101451285424, 0.5524960532784462, 0.9247083901878327, 2.3022452237144595, 8.53661310288214, 9.023436115634057, 5.757525092171085, 4.10288818901585, 6.42157647878893, 3.100653723362954, 8.296499329228556, 7.1646930421552355, 3.817744380043399, 3.662815906347767, 0.6854455870005393, 0.5873711335082209, 0.8005792251037014, 0.8134450895651695, 0.7823501935889645, 1.211030442387827, 0.24838681843492294, 0.21893605439653321, 0.2561873401845655, 0.15650237069254921, 1.3600176284390113, 1.6713638507550763, 0.08182614230580869, 0.4844551881955516, 0.3043564667384471, 0.1494364353317407, 0.11819310215932709, 0.019013471075243527, 0.08068822594659944, 0.15464492923309728, 0.32710891036737355, 1.176110193614037, 2.6511250965056883, 3.3983782895149726, 2.7051753574802033, 2.357278773861547, 4.323564412132386, 5.718100859272865, 1.7705746884307556, 3.224270651417394, 1.8758122478761983, 0.6698899571934055, 1.7518177916926725, 0.26334471580001617, 0.41439813291353567, 2.708174009476939, 13.635353080687986, 27.973385049450783, 49.02970167898363, 65.047880911058, 25.717590739650113, 21.140092572858258, 28.758035590571744, 39.26799312714608, 44.77451055280624, 39.42706484948435, 12.11510515982105, 0.3875816234898183, 0.11239883444842794, 0.11502234084952263, 0.04903289834938703, 0.057252726833065676, 0.0034356012568628838, 0.056333053601725455, 0.03873222567621739, 0.04077063242514287, 0.0443615623178982, 0.08143851713788125, 0.06625142924848103, 0.06307486865308977, 0.03914849104119405, 0.021245336092467752, 0.03871843609358034, 0.06591209826330025, 0.002957232016694522, 0.055616225130976214, 0.0630482585890399, 0.037702323883892074, 0.061483355464353684, 0.05150649283501891, 0.034738881288156394, 0.0312059614882474, 0.04136411690964334, 0.04036568983968708, 0.04327314672991634, 0.05150150560263184, 0.008991998188467997, 0.05986016453994859, 0.04562055121266073, 0.07686486497761742, 0.026260364064646345, 0.040330982226277554, 0.14100222097289178, 0.11851550260138129, 0.04873862865591242, 0.050637841059435765, 0.08667754730389965, 0.01726739773256404, 0.07620848084409391, 0.08351678344150705, 0.15398613958349153, 0.12590798293991437, 0.03919076760329547, 0.05792413395078433, 0.05321172028479557, 0.019319871770999125, 0.02610752760853258, 0.08670675823645246, 0.09914398118252717, 0.08651834657235492, 0.03825106883361455, 0.04280504785598286, 0.029995140371724006, 0.023526728693996708, 0.030109913749319893, 0.060885274452307535, 0.026964653591294924, 0.033820437627934644, 0.037366428803051674, 0.09798209393216718, 0.0482847866782498, 0.010694777987326586, 0.08505137246702948, 0.03747114153098195, 0.019529475342302073, 0.03910458271181391, 0.09699007135725791, 0.009157606287889425, 0.041336736927229556, 0.07463729579842861, 0.03506917243583068, 0.05667617672213143, 0.014092008294087025, 0.05330180839425134, 0.06981524728959607, 0.020669596119513436, 0.002925101092137817, 0.0610996948014344, 0.028092796583810163, 0.01093645095674982, 0.049651728852862315, 0.08594467695201598, 0.03760738643787561, 0.05061955454068319, 0.08644849467541903, 0.01681221127059431, 0.04206909783064358, 0.03236146531097832, 0.05019801849078748, 0.01069992418295794, 0.04973347809526229, 0.08532437555972608, 0.08442508026717171, 0.039939614718840014, 0.0747725256388226, 0.05366251706295917, 0.668599987702985, 20.575536028031383, 58.02393574868479, 58.038475974913574, 46.60942277600689, 25.440130118400823, 21.969869982811716, 29.092296054286344, 41.629793413223766, 54.31398545542071, 48.55662069013042, 28.90327899686752, 11.697621806975334, 1.7873478464541899, 0.2073624270457414, 0.11629581646693331, 0.23627887540046247, 0.7971562829709823, 0.8863433810972399, 0.34476478554068074, 2.0949668365140117, 2.3543960769330305, 2.6006115876859237, 3.2253892623609115, 3.1416721545880844, 3.4254490175554833, 4.1053864936674795, 1.1162474703404213, 3.690416154361541, 4.765061495765563, 3.1968380847284874, 2.416236900514172, 0.830653446816629, 2.5185874729387225, 2.33888138686457, 3.2253605800290264, 1.001833587163879, 0.8121587972967856, 0.7529435715367718, 1.6654058930373963, 2.985465233364413, 2.2930938438061745, 1.7261886572645557, 1.4690142893983473, 1.0298716084611033, 0.4535225802852262, 0.5267703917718703, 0.2016153273683402, 0.7637213254647871, 0.32569462012860084, 1.2724125938069437, 2.769569153747251, 2.4655528606907016, 2.6693474477337253, 1.1000936790820093, 1.326395316470054, 0.20689537388182458, 1.0999089599617067, 0.9588468002696192, 1.9883747110443732, 0.6647640935355618, 0.5616318662801097, 0.7592739705597201, 0.14047617903880535, 0.057854718723965276, 0.9832839631745893, 7.94770158106281, 28.313040733337406, 48.94271527567218, 73.04709988255655, 45.260621655371885, 21.44527650648548, 21.5110997615322, 35.08870770854335, 50.06948278796289, 49.79349305552822, 19.42859576594445, 1.6566913671070531, 0.13574514177537736, 0.014631612857262936, 0.04220724646602908, 0.013085015403527408, 0.04215873777866364, 0.037278286556923584, 0.0694420935225583, 0.013823054933680162, 0.0451076630082342, 0.1607473864550552, 0.06971813798431428, 0.03840533212848729, 0.012586983559172482, 0.0352305565179596, 0.05921882637325795, 0.047203794482254216, 0.042116108816117055, 0.06611665139996237, 0.0675113527705112, 0.1349499731534912, 0.017457791649165656, 0.07661741857807483, 0.0438323947450807, 0.07902049083983706, 0.014415563613687073, 0.11231984312255537, 0.02579873671845323, 0.024822658348468044, 0.048044001413208824, 0.03962735345046367, 0.1632208545361796, 0.06008687293938091, 0.05432047550716708, 0.1160920370790747, 0.021438120203393123, 0.18632598972368627, 0.2666737355532185, 0.0820471203675674, 0.0703263275265213, 0.033845569142290664, 0.09987423917458904, 0.06201169183177333, 0.10225203053485002, 0.05103210820966671, 0.059142692555342956, 0.190992905427852, 0.13818637287664798, 0.287946189242986, 0.09081711872450768, 0.16489907738662538, 0.19163491775191602, 0.18293278712418773, 0.13522159728792407, 0.10238550603389741, 0.21049958773918692, 0.15216992897612436, 0.15181696162589137, 0.21838085515604866, 0.12038379186584104, 0.1169033548344047, 0.18496267497539523, 0.18658707248828105, 0.22014550804611177, 0.16588032876531925, 0.18405643892624687, 0.20351473512428425, 0.16490929699953527, 0.17931044762653692, 0.2084624986614912, 0.1347699118477683, 0.13815577532495224, 0.24810943331929947, 0.19735151180817237, 0.16286728963736566, 0.0802070844257551, 0.19077496873515268, 0.16791927177579175, 0.10700464849510502, 0.18131100963200295, 0.14096938644445714, 0.19586260460557478, 0.13033617798599506, 0.15892072640840085, 0.3263677049788737, 0.10612120356170401, 0.1773520204569063, 0.391879100953379, 0.16093492477891908, 0.18256535603394433, 0.08055437506446916, 0.20090764598740687, 0.10117926995360083, 0.1658890008806221, 0.4108571825969604, 0.1723897165708965, 0.17982043235773043, 0.12985824637355345, 0.21713420027686706, 0.2525421099797372, 16.648586488539173, 64.17341593773135, 77.31840410540181, 63.02591085433961, 51.639262399365826, 53.20532752621559, 35.7607352349066, 32.42964667658652, 44.95264891655215, 51.74691577111521, 34.848988133092085, 18.26980210119678, 5.989974064211692, 0.5730844517388652, 0.5201282256072568, 0.8620852376184157, 2.465432247807903, 4.279706920346906, 6.378600049403406, 23.79143241913088, 20.989865795258556, 17.91068950007039, 14.435111611120163, 19.653820222423924, 11.860233468394126, 17.19868713809598, 18.427650044041297, 11.265916920477345, 5.387429364265935, 6.417166754122704, 4.338180143986979, 2.4143200872405886, 3.6115211104193046, 3.790353488537573, 3.2545015840761127, 1.9398704363453774, 1.1315192186063336, 0.707968817122521, 1.6988551304225, 4.2576455493127146, 4.89488753580278, 0.695196537961883, 0.8163095229575712, 0.5807330735748815, 0.5931027582095516, 0.5724223066241511, 0.15697659443943732, 0.6769637066510417, 0.4530019162883682, 1.162912888873008, 3.807575880519806, 7.815435336482141, 14.597897818011624, 11.200999732940428, 11.529852228779948, 15.071906447410585, 18.25719952583313, 9.931814882063097, 10.479006113544589, 8.652893727825536, 3.6711533944452968, 3.770867398669643, 0.7202106570043872, 0.6980118804400968, 4.2024298541007505, 17.28915660612045, 36.87017371577602, 58.05934690660047, 75.79123712355091, 35.090582601485714, 30.97275091755775, 40.28407135317403, 51.89238079132573, 61.22191475283716, 59.24271029810752, 21.221171886690204, 1.2489695678795538, 0.2128722999365099, 0.28025457455265906, 0.17393840927510493, 0.14628769138888006, 0.13288625485954747, 0.17274585552513602, 0.11619003504634866, 0.21567405201494697, 0.11185710303365223, 0.21051192175476782, 0.1623009361567036, 0.19918898901631757, 0.2183168408490958, 0.15444095066237837, 0.1764348906374747, 0.1925072314277772, 0.14188168990996577, 0.1359748455785936, 0.17413025301310325, 0.22841109113106806, 0.2304377307694766, 0.2146409058402623, 0.14178989725487848, 0.19060903409075355, 0.12131563057341885, 0.24548470883840517, 0.09178765253314088, 0.11566894970113233, 0.14248135289357555, 0.16592048709431004, 0.23887168465843125, 0.23169160219690493, 0.2815080476143668, 0.11238563475349259, 0.2873310512833057, 0.32792467143266435, 0.3317620671324192, 0.2626207933550881, 0.16305151846139662, 0.08706960046002943, 0.17530773015272233, 0.16981477248332194, 0.33520112775506516, 0.22312030406488528, 0.21013257033642263], [0.05850592793356027, 0.09989154510079853, 0.006689914509714131, 0.06317023893878346, 0.051186578348279006, 0.033444434013818546, 0.02635083713328406, 0.07603293945712429, 0.013794522946550241, 0.02729696912630912, 0.027949070828335903, 0.10097375154615411, 0.02762456364448994, 0.02031739868764435, 0.019200867672841397, 0.06759754532287199, 0.040896351283956925, 0.04751975978574446, 0.024540048513200977, 0.04878425302224294, 0.059230390470474965, 0.039017861558785366, 0.03282430499131161, 0.015746956435783256, 0.018310527948121873, 0.015543855035737639, 0.041690102643183166, 0.034208775257631656, 0.04129081378660856, 0.0028677608474202815, 0.02404556174071566, 0.015135649873334316, 0.053645636315547654, 0.01768740926749043, 0.04709540070184777, 0.06645224387607267, 0.013198395458711012, 0.03730217317840265, 0.03304024985540779, 0.12450489290659467, 0.01178346745174138, 0.0039342356772507515, 0.02517117281264115, 0.11689901877675327, 0.01814593012715059, 0.03211019038703413, 0.03820965412042795, 0.06708859481037625, 0.06000584381962976, 0.04429085240248711, 0.059718928570228244, 0.06712702178065816, 0.034022539283239076, 0.02406645678885041, 0.06217080063276714, 2.448903625049899, 26.05777398232491, 48.53097623394382, 51.18591093247937, 39.27437090104626, 34.49149154847668, 32.30283252654537, 35.05546562133297, 26.553412522039107, 33.263232707977295, 36.776389844955936, 35.10730758790047, 27.71812700456189, 13.50239355717936, 7.816217359035247, 2.452625954343427, 0.32968486569100813, 0.06714034404966139, 1.8411959827907625, 0.9011196236937278, 1.2352434786096698, 1.7263795050882524, 0.5735786090935431, 1.4994991955257233, 4.145783474368434, 1.5798113182667763, 1.8078276442904628, 5.852393498343806, 3.554009112619585, 1.3635967912212497, 0.42266694888953243, 2.1426074543306908, 1.4843081009964791, 2.99321926889881, 0.9995233724194189, 1.6305106493734545, 0.8855718999139724, 2.0676909194838617, 2.450600540445697, 1.2336009861000123, 4.490155318090993, 2.2624782737224334, 1.631367196959834, 0.2865676906320357, 0.7866640653341048, 1.651519231738583, 1.2877203788488143, 0.24958879506636053, 2.7072299440060896, 2.8798774798070235, 1.6922265699794217, 1.0818057507276535, 0.8785065467799864, 0.8479969419779316, 0.6368378597882487, 1.3409933976588713, 0.6369198618396636, 0.01556830664706086, 0.28486314500051163, 0.8241294420534565, 5.676937545499494, 10.78899004767018, 25.972646782475135, 35.47298231432515, 45.081573301746005, 27.84822810080744, 51.206362170557824, 25.846813224977065, 31.863472154063565, 45.487538614580714, 41.487956585422644, 49.358741467998875, 26.90259760425937, 3.581033507662435, 0.18171220987794862, 0.17210601889077695, 0.014871150356597237, 0.06414602811057722, 0.03888396854181925, 0.03384018354418297, 0.05210614049687021, 0.06140884575283816, 0.05315631680611161, 0.06392206230591382, 0.0464712382264195, 0.036323580124806014, 0.010308843000882096, 0.03873823946642299, 0.052262805477385564, 0.015179738233376656, 0.0637596938008022, 0.027621698475653128, 0.13693289981494028, 0.032112498226906025, 0.1084731700980375, 0.039846427783730536, 0.08960944239891346, 0.04462483226351681, 0.019802426724063776, 0.08141593286587347, 0.010947240347553407, 0.059951846112286857, 0.015746401022038153, 0.04307036708679892, 0.06281562066907365, 0.037883024873031725, 0.039157189969574256, 0.020713270792076667, 0.03330545800347482, 0.05527671411513321, 0.018415886105128357, 0.0026255188183107927, 0.0037511646035953516, 0.04631638504384507, 0.09928494136059478, 0.022028754840815262, 0.02903755536423095, 0.014553241104999138, 0.024000615362198125, 0.04374776884252506, 0.012015859265961956, 0.03428970861639227, 0.014721944199634657, 0.02970281654157706, 0.03744410245769447, 0.07305057448965889, 0.06545969270049565, 0.08141641550126576, 0.06647275204980566, 0.029671933622129505, 0.02407400083968476, 0.037222806469447194, 0.0888181425210449, 0.02941267797723413, 0.008044229640114692, 0.07910886674278206, 0.06459690149753325, 0.007971114208621365, 0.0701896651017089, 0.019399066110171618, 0.05270656956840427, 0.0370651149311133, 0.0394927364804091, 0.025183727078500296, 0.021507071947017987, 0.03230924492761974, 0.0289449104363279, 0.01698179823917247, 0.03700722932755467, 0.05278165001542338, 0.009305015011059662, 0.04096602315023061, 0.05507238697440875, 0.09537548743068211, 0.015675219962553635, 0.05301603844629661, 0.029306479038730748, 0.009235962718394736, 0.05819182039328641, 0.12334449186680779, 0.0362868347175179, 0.06204854832181047, 0.03675130233469029, 0.04319645749825624, 0.048636964957920775, 0.03527897327477413, 0.0408629690026564, 0.030020139735913085, 0.07259347280787845, 0.038990765028903564, 0.046107679710633336, 0.053050811177179705, 0.028906600294454448, 0.02000589967675267, 0.11511335975580639, 0.05904288279012807, 8.266663820512834, 42.99309945875599, 57.84743693567092, 51.378915079178356, 43.50470596744169, 25.02989530563355, 15.168443822091627, 23.212035586757047, 37.59492181962536, 49.355670252153956, 54.11934568035988, 49.967642368808875, 26.826482049880493, 12.683123196324996, 3.7675515249852216, 1.1112344361120656, 0.22699298577443247, 0.13046907891909923, 0.42664512090625306, 0.18272183715335785, 0.7151734756846583, 0.5754155040748659, 1.2761328393413176, 0.860086422293417, 0.8923116963236564, 0.9662692116633539, 0.4717923676775348, 1.9919945684171494, 2.253015310533585, 1.2047218002619282, 0.8169968570432355, 0.8683061167117089, 0.7157936391811217, 2.485180401032971, 1.0646627867414107, 0.6397705669364622, 2.342919957253241, 2.752236690252058, 2.445380601190752, 1.4179587580503956, 3.549865128532533, 2.503385101595233, 2.2875235878652145, 1.6319014973217443, 1.016288256693271, 1.7750325847056605, 2.7739796138578847, 1.1055060596235338, 2.3237395671106156, 1.5855083157939296, 0.5208564381445608, 1.6151765109069887, 1.40456656054143, 1.4187958163599816, 1.0405609251991397, 0.348905184336247, 0.17780448730674484, 0.26141371457807483, 0.034337903207708756, 0.21146852042405836, 2.205899064579318, 5.676364879454336, 15.425143338018849, 33.990706859096406, 66.91686676394555, 53.72674780507242, 60.64245908491073, 40.87325057675762, 20.765264995636482, 31.77537375880826, 44.089637264128655, 54.255346021344586, 38.234840823758034, 9.017703571627218, 0.32135031937110814, 0.14151841101627197, 0.024777189114942186, 0.06106705562542043, 0.08097835876528295, 0.026417754913469958, 0.05112958140671254, 0.06601812483202066, 0.026386937111495968, 0.09277373792663698, 0.028631731777662234, 0.032886752648459326, 0.009160401551203142, 0.025991541896796515, 0.02198864822275937, 0.01762103732495058, 0.02243903131344386, 0.06309676727640533, 0.0626955593695804, 0.048165970271633524, 0.03973464023381953, 0.04552733363403429, 0.14981878981474908, 0.11028885210473692, 0.09856730083664579, 0.014914146083737574, 0.01727040462766684, 0.025377646914773414, 0.027514210594217145, 0.06341573181411912, 0.03730403094161903, 0.07519682343568533, 0.01776967561923929, 0.05182521605503656, 0.0280591921370116, 0.045858264465125344, 0.08174221737370377, 0.06868486923556175, 0.06401976915977656, 0.020921776942428083, 0.04866846266292757, 0.03598804127485041, 0.07265049273208266, 0.014365374320937742, 0.011657473758884497, 0.041546518613974896, 0.06249597048266761, 0.15789890301323709, 0.2839189875991114, 0.18706607662381666, 0.2260902124427019, 0.22099205052420018, 0.114678313745366, 0.231690468386777, 0.19098064802106351, 0.0829255550859436, 0.11704901879232739, 0.13219325172324337, 0.2948046679938993, 0.1205293945367298, 0.12478932603112153, 0.18370000885859614, 0.19963711980850468, 0.17787220947925123, 0.13963411051419475, 0.07955915790291564, 0.25932238647534006, 0.17470469638224573, 0.10313808016719357, 0.08631573929902046, 0.09564181789755823, 0.09081580871415716, 0.11698344166600898, 0.22560651984906968, 0.19223292598560934, 0.11191963879091125, 0.06403304546350433, 0.10924043013684212, 0.22036368988694685, 0.1964075842331494, 0.18485231234902338, 0.16058437826652683, 0.17279488515228997, 0.17233897090679215, 0.11826843158492159, 0.2064351695439508, 0.19747961703087055, 0.16866596235382944, 0.0954095783433126, 0.15434555739404696, 0.23411312951676308, 0.08995779023896303, 0.13617897736689738, 0.1338143244145378, 0.15589587420465487, 0.13187147947328706, 0.09778056684280596, 0.2444677730841983, 0.2587300472922864, 0.1480474106727108, 0.24731360586179843, 0.12196893503348674, 4.94489481372218, 41.06372871706563, 71.6793066455472, 70.07238218861242, 57.24335270543253, 47.88325955790859, 46.65073710103189, 46.86377279220089, 35.44676126972322, 43.336357839645885, 51.007419555417954, 47.14677572250367, 36.77036900674143, 19.669645024884133, 10.523417149820636, 3.553075098222302, 0.7278476955909884, 0.6116863352156455, 3.4702135574433113, 1.4873522279723999, 2.873195477070347, 4.4792658379001, 3.5672365705813136, 7.347217106050061, 13.133588779357172, 7.229440587182199, 10.681199392964764, 17.930589645139634, 10.703749099085409, 7.837637422546265, 2.7079232229340464, 5.716549561869714, 4.707729681845635, 10.343981462140238, 3.787026338038906, 3.566091483639133, 5.674431150959385, 5.7110244131857355, 5.978907587066774, 6.1907346979264295, 11.221929500179908, 8.266677548808437, 5.8405626493115586, 3.283316295954489, 3.3949628856874283, 6.290530581628123, 5.951302926386557, 2.653650857748524, 10.515290979416141, 15.766510155893142, 9.318346381187439, 6.600040399259137, 5.517384842518838, 6.521994058162936, 4.599817433664876, 2.7971662148352596, 1.2747005613580829, 0.6156584091724888, 0.46701547239095936, 1.214551505061888, 7.443637299922205, 15.701967554707682, 34.297369526278594, 46.025589742968165, 56.764372471840154, 36.523122402929495, 57.008740055945616, 35.015343696840354, 44.460693482429754, 60.074217473306966, 55.31540970648489, 68.80459370151644, 43.25441560437603, 6.853313724840842, 0.28122241939267806, 0.29532545456482523, 0.20741544033010162, 0.15374316713742672, 0.14023853856469357, 0.12262183346695478, 0.15486426020581878, 0.27798318514420145, 0.1688312534843722, 0.3053802053534216, 0.15433225810768145, 0.08598417644539187, 0.19677098570091112, 0.11206570111455456, 0.12927438012294232, 0.09327308169656223, 0.1310918624362638, 0.13508707224842043, 0.17971350180525936, 0.14923990313564578, 0.2520582948120371, 0.09046071930037392, 0.21067053259861088, 0.17681727576400005, 0.25969853564616174, 0.22172767879261127, 0.1505956795787619, 0.1508099237276662, 0.14852606240780125, 0.1423175479736059, 0.10333432124987726, 0.13780184270393464, 0.10238473994597312, 0.13705227163530168, 0.16201061947691828, 0.17655607042533739, 0.20603753926773227, 0.15441776884178962, 0.220682397785206, 0.1195924919879725, 0.19011414129166834, 0.10994189854470954, 0.11202078537955401, 0.11984825810237278, 0.11527320400120751, 0.13655668935708462, 0.17133859797350823], [0.11498811204106578, 0.06644232303745325, 0.08974915385366448, 0.05125422391199297, 0.02137316552351319, 0.09412688668817283, 0.03222253909634967, 0.05018351261594123, 0.03620764420878503, 0.01675418777120931, 0.08706012395240607, 0.062686538684272, 0.016884637222955787, 0.04064995442487059, 0.046495783683513446, 0.049675236260818864, 0.1054407106412034, 0.05264990587508487, 0.03333274222489807, 0.05193259476894333, 0.015311234352749684, 0.015677817000616944, 0.018152447620166406, 0.01637606017832314, 0.06991837038508347, 0.02720407138939106, 0.06146635980375352, 0.05184482407545851, 0.02242254510131334, 0.031837826977754315, 0.06819025988900854, 0.050660486618477496, 0.05285049833717847, 0.03620424660884085, 0.013265036489634265, 0.006890724828061198, 0.03939715935097587, 0.05721326564408599, 0.09137182000784144, 0.022541292560016437, 0.04924145812589315, 0.0031617322454093807, 0.008010150218803075, 0.08572942156705164, 0.04614470474001381, 0.056521415470107916, 0.008582110505460972, 0.025678288544558232, 0.021060427365403984, 0.06490358947626045, 0.11875312009285535, 0.014085232246396764, 0.03889739040225264, 0.029177764776132764, 0.04686964225144156, 0.08200798093551591, 0.01991098521337394, 9.162329204620855, 32.40480434510016, 53.2075358206226, 46.52104000891409, 38.66684675216675, 38.27266031695951, 38.56644584286598, 32.683324006295976, 20.223093417383012, 21.52214123356727, 34.4983753081291, 45.53419913015058, 37.10450787698069, 36.89151140951341, 31.206349634355117, 22.269505723830193, 15.108806144806648, 8.686618266567107, 5.047119134856809, 1.9490750133991244, 0.970469334673497, 0.20488247786077762, 0.31400929715844894, 0.573347618262614, 1.839759169567016, 2.1919589609869066, 1.497753250502771, 1.1907113391545512, 0.6543059514895563, 0.6492567579111745, 0.7923963641928089, 1.8375904665839289, 0.6305449684300731, 0.21131144175606392, 0.7755097025825132, 2.240721131524732, 2.208715326363041, 0.6639042977363833, 4.524608437092074, 3.0875963982074492, 2.5212652260257356, 0.9574656969597264, 1.5119562754707954, 1.1217496976737054, 2.2803672234858237, 0.41930566151295945, 1.3497983832513134, 1.3902593476157035, 0.7392046119897597, 0.32784116784891776, 0.12057347523589289, 0.202877763658762, 1.2571787209280076, 5.246253946135122, 8.68988952329082, 12.942005511253113, 25.611265090204057, 34.56604796071207, 37.817002496411725, 42.138756244413315, 84.89261857924923, 60.930145325199256, 25.47570601586373, 27.461541237369662, 34.32973692494054, 37.72441494849421, 46.847859736411806, 53.465255152794626, 40.10810990487376, 13.764905045109412, 0.4281926491568166, 0.1787474189674662, 0.11549196806886505, 0.12896060583091554, 0.04660532659580631, 0.02789383397377547, 0.031815844084767085, 0.02572359498440018, 0.03958970022898528, 0.054700344034861174, 0.03200910700064513, 0.06726903916006127, 0.0688189652658278, 0.06347474356692645, 0.034082033671438694, 0.03178179913741206, 0.0522215401513442, 0.01758426510458512, 0.0307987091476999, 0.014161207101067469, 0.04399915676443808, 0.05646020887539752, 0.06459047401984853, 0.06615704721620967, 0.08619353295333924, 0.03655819455161691, 0.04807738369450935, 0.07306974967040362, 0.06757787218497646, 0.03896792411744114, 0.0536087223689162, 0.025119400590718276, 0.027901025624164653, 0.03388028824701905, 0.02105683824347873, 0.023394036519851898, 0.06957769874603519, 0.045626821642320965, 0.017799304069710836, 0.10088144561215755, 0.029843142781887325, 0.01534960195121746, 0.03694665858582143, 0.030558322248379552, 0.03239407767391494, 0.06737465204130258, 0.01725043080026104, 0.04314956908685066, 0.03212316408603182, 0.06729524702795091, 0.04090340695373955, 0.11859385041339744, 0.04698290452060681, 0.07418919564975847, 0.015250840768848938, 0.008841977105475962, 0.043930101598943436, 0.010176690918723903, 0.05540420263705235, 0.02142397055943166, 0.04002612902812901, 0.00601387016602882, 0.00595760100799042, 0.06823011178282962, 0.042917567019861554, 0.023527490951481368, 0.04191922421957697, 0.013090928644692947, 0.023889419615208626, 0.02407249930735317, 0.012434820302822178, 0.03271933179348707, 0.07670244667679071, 0.025279076296776056, 0.02898201973538005, 0.0506838254870907, 0.06841982579639844, 0.04798889287837571, 0.04208912336898427, 0.045299276919855226, 0.040359496018819274, 0.04872673131044834, 0.05400930974452246, 0.04039335710507247, 0.03786271588215905, 0.08646972297180085, 0.02810270210067111, 0.014891050448040328, 0.031794317014094804, 0.07538344245404005, 0.024218643985448346, 0.024660289843356418, 0.045327484277227235, 0.018097620622645465, 0.04430946833904713, 0.008132053959754207, 0.006782274069865385, 0.0334659572540512, 0.027877767194783496, 0.10313217362929737, 0.04455121504443307, 0.03932515857741237, 0.030214687764284112, 0.07332327880806501, 0.026230237657024015, 0.5263199320723934, 20.955464647662257, 49.369437771458784, 56.943385524134484, 50.58407814271989, 35.689175513482866, 34.2481751595774, 26.028122825007287, 25.03331365123872, 25.852106463524606, 32.488599900276434, 51.95970435296336, 59.639352137042636, 52.56305117760935, 41.729884455280924, 30.609160930879657, 17.000075963235673, 8.583082402906111, 4.653293067409146, 1.7990032919952947, 0.9549695986413187, 0.4800248710859207, 0.27801456410557995, 0.19034165408342116, 0.2473843157772095, 0.6100312175769961, 1.0331581869433004, 0.7741382213369493, 0.8444730601003094, 0.6114321778858862, 0.5421862258545814, 0.3973299084651855, 0.7865902757452381, 0.17305360836607797, 0.25095177273596486, 0.8762045444980745, 0.5740038798220697, 0.2661497007694937, 0.6920083864561973, 0.856555798842061, 0.7693858408639509, 0.913673292004293, 1.3785379572260765, 0.9024398076918818, 0.8073005128291346, 1.408671933797098, 0.9189100851935725, 0.7159901254119412, 0.4102751396356091, 0.17205642235855903, 0.6536677083180797, 0.18518197530459973, 0.4929210726291903, 0.09903631518564879, 1.8177889936393308, 5.922468112361047, 11.121810020938998, 17.30381254226931, 33.14559690413937, 47.020632297761985, 58.80472275518603, 81.4613526867282, 62.34492855687296, 32.849101020443825, 20.05135832294341, 34.628315587197584, 29.65416773673027, 42.1135667831667, 59.141164056716434, 50.05242440008348, 24.588077568238784, 1.7828383464967053, 0.22479345541327234, 0.07654717597629755, 0.11359321914853589, 0.1074406750980885, 0.04804728026952475, 0.03819741203539795, 0.057046070785051396, 0.07656386137128839, 0.019104386559657512, 0.061172097771158146, 0.028840138336583495, 0.03786748094904808, 0.03505537136187477, 0.073755030640431, 0.060582133460669756, 0.05568167968322674, 0.11500888068469302, 0.041181163622006293, 0.023173690480630726, 0.06235532440064896, 0.05802669397164738, 0.06692506568205935, 0.041067859218005216, 0.03211308045372848, 0.10786541722594731, 0.04437886058322845, 0.06633132455810424, 0.11879520896341532, 0.04113164369858081, 0.032201598082939466, 0.08781098204875186, 0.013574291820517712, 0.05911351992718636, 0.040800314501769123, 0.044504479850612344, 0.08344682429226176, 0.1148267892459708, 0.02109319103070565, 0.028216263144126827, 0.049780427793701815, 0.03377593174997357, 0.062082987804446495, 0.036227217755250396, 0.014223572403763332, 0.05476734608471875, 0.0787069004089121, 0.024509757396674926, 0.010022144171319181, 0.22647160165492566, 0.100739635076494, 0.14220015266008917, 0.1345618730110507, 0.15110445389103505, 0.12361335042383402, 0.1140326701645409, 0.1274259478574799, 0.10575309831408725, 0.13376613748410057, 0.15571529195914346, 0.12213083239452494, 0.1588507366156386, 0.10014452265515443, 0.15261733964566263, 0.12960759772648736, 0.2052893318356045, 0.2134432346229592, 0.21123864808149878, 0.13088357845141044, 0.08865411543557722, 0.13624268523868055, 0.23479427361199934, 0.13227811894349514, 0.14263768079540423, 0.11391563491234857, 0.07851203828449212, 0.2258527405079334, 0.09129564788553024, 0.15972625253902328, 0.09853655772824442, 0.16825483360838506, 0.12030546703646261, 0.2018824469057783, 0.14682113373231503, 0.08054777138656186, 0.1684736896065935, 0.11090568311872984, 0.1526340710059289, 0.20770414822524597, 0.15958901554826768, 0.11572292059539788, 0.1503450768969713, 0.12456781170781582, 0.11537631943581567, 0.15584434713086776, 0.0796864204288971, 0.09610304879325052, 0.13688426855350697, 0.10308092234716301, 0.35779027208205194, 0.17780546789928792, 0.13180855301118669, 0.209794664274781, 0.1636790057584163, 0.10865814202735502, 0.18463897218386974, 16.53995644661688, 53.3847681168587, 74.30467451772383, 66.66050849422332, 53.555873670885646, 54.564436635663434, 55.12258991118401, 48.073616104741255, 31.673507844248128, 31.241923570632938, 46.262120431469334, 54.97450474769839, 49.48618711963777, 48.67029490009431, 40.51570692370015, 30.27782851649869, 19.346590772751842, 11.212644269389491, 6.340552078139398, 2.7607087646761252, 1.376578365602801, 0.5644092720843131, 0.7399710676362439, 1.7020549264646347, 3.8147746555266844, 5.5620228859686085, 4.457759482245292, 5.101562613441098, 5.088513378174075, 5.208855617430903, 3.8061045014089157, 9.83806533198203, 4.9683054800956485, 7.060041754476487, 5.827771800179636, 9.849295077785369, 10.342345833778381, 7.0621495381478345, 16.288721772932238, 13.711285264261308, 10.458465641544713, 5.4361334346955825, 6.824971168271958, 3.559101819992066, 5.5990696722461335, 3.341658365341925, 2.6761221164657227, 2.619281089113605, 0.8677006621033916, 1.0668308768541583, 0.21681043619830764, 0.455210363912967, 2.2458474241918136, 6.943256124373406, 11.939351597139913, 18.237903425770423, 31.14814558336812, 46.994305349165394, 49.25585769837903, 55.882039223947835, 93.51815377512287, 70.8729144065611, 33.03621376714399, 35.8396533227736, 44.487879430094075, 49.242588320086085, 59.64028958351382, 70.36375153449275, 57.84674659852059, 21.444250806685417, 1.0975559055805206, 0.305074199192947, 0.17421640726106782, 0.2706607941898608, 0.26370493034201287, 0.09060071420765693, 0.12388471408837265, 0.14266889121743942, 0.18290212828545802, 0.17121827620412075, 0.17457712742109455, 0.11261562200924082, 0.14325536216699308, 0.18416686283965267, 0.194933952823762, 0.18026670921714077, 0.2126051803990718, 0.1534951231893032, 0.15916282551423197, 0.12788753881449663, 0.19846862121935815, 0.14006829850615996, 0.2502627992221425, 0.17938852730777957, 0.19332038779412547, 0.18713733812253322, 0.16825889387438375, 0.2351259896832128, 0.22964924243429016, 0.11162666378602867, 0.21219981263481805, 0.19933377963400659, 0.15956871421827426, 0.20366711001242363, 0.12048470862810651, 0.25293955639485394, 0.09760459644659873, 0.18634200096130374, 0.13099748040399245, 0.13835505011581606, 0.23515903871626626, 0.07231523733465903, 0.1378832318850102, 0.13585067804782622, 0.0752540885080253, 0.22496781702483856, 0.21761659052102797, 0.13851986627184576, 0.09506653183169904], [0.041026662839877034, 0.0868628639727831, 0.04203836621356107, 0.057005908625620993, 0.038522363550239996, 0.03338469064704353, 0.02607829943900147, 0.014084896125319987, 0.029023966879674026, 0.026733162887995283, 0.03586211557229681, 0.025644063566541, 0.10169929809748166, 0.06906290298267719, 0.06792608979007891, 0.10078602170030918, 0.03821919957596449, 0.05673066472574588, 0.06985101593478073, 0.03486232869627495, 0.009411005190603677, 0.059686254920257684, 0.013820974047355836, 0.03771288440592828, 0.049014688439426884, 0.018166101222196897, 0.008800132425441858, 0.04588159184241968, 0.058903067913507266, 0.025108585344447244, 0.004177923218512367, 0.027076554139174765, 0.04811119881548709, 0.03814259844441568, 0.02231721567260402, 0.01520905641823887, 0.053886436902347117, 0.04676289556007232, 0.04278693753745287, 0.021893909959603223, 0.043938934592710394, 0.036719176437585585, 0.012171402885278147, 0.02052967590580304, 0.010107931654690015, 0.0315811587948232, 0.06057125118170535, 0.05813909439189781, 0.05024719750508667, 0.020351922439952052, 0.036482911091297865, 0.13305661749214898, 0.013241635376377212, 0.03994004755851723, 0.03522951080794296, 0.10319411183797544, 0.08233953612826525, 0.08350872419654362, 0.8526975961942828, 16.28928267186688, 44.78668558982111, 49.40175025693832, 53.92799285150344, 52.29414916807606, 46.6730514649422, 35.33869997147591, 31.125831219457815, 22.01174912914153, 30.576197331951512, 38.18323419940087, 29.279675522158225, 31.34440725849521, 36.12846920567174, 44.80261433509089, 42.361036962078465, 39.514702366244414, 35.18532745299801, 31.991894475875366, 27.26983931756789, 24.76952445122504, 13.336862671759821, 8.46637325902139, 4.5848457467171455, 1.11899790984969, 0.47598731193330984, 0.19629662405819664, 0.06976948119699955, 0.22313259211519074, 1.1086111059111934, 0.6694345332441792, 0.9061333320794568, 0.4868878850773458, 0.6679383941715764, 0.09355584474941415, 0.24216921819794565, 0.9068179082485938, 0.29210669018568536, 0.2768250134202742, 0.08829158730804922, 0.11075051967054607, 0.3720118976648777, 0.7624303140947897, 2.159265515304381, 4.206777801436763, 8.990924569868273, 14.732541018916717, 19.046866778404482, 24.935525040472708, 32.89616161777128, 39.59029820657546, 31.57054758840992, 35.039772218273534, 41.310053563887074, 36.78379920221145, 20.73608256155445, 38.823808239352324, 21.90072644141413, 53.40621563696092, 63.47233541550175, 40.13735509687855, 52.638905894371774, 41.400330835773104, 57.90969671741609, 44.97806979763893, 24.091642787379605, 2.318234275425634, 0.1375830939580356, 0.049743927534549474, 0.06664552785936864, 0.054524193607991746, 0.04501666325414854, 0.03904805691432088, 0.1098292299936856, 0.07512309513385258, 0.08470294035730824, 0.04542296181523031, 0.012971443826362733, 0.016516579855834285, 0.059159006397690506, 0.013672254356225173, 0.029025391803213188, 0.05216632053376206, 0.001994520564274412, 0.022069905253667987, 0.07552392765759461, 0.061954005411075014, 0.04353498792155616, 0.01176430663514522, 0.025905334022677234, 0.07356720886403516, 0.04444027019123878, 0.0648511584187227, 0.06521367888537145, 0.06480847966046104, 0.04250287213512967, 0.056767195628415194, 0.05862641058141186, 0.034690227044085344, 0.029976290778347084, 0.03896565649718527, 0.015522230288855013, 0.061573144799518975, 0.024267777034472075, 0.055007763627556064, 0.04788750497203681, 0.007232163033838715, 0.008572256699534915, 0.03545367196502705, 0.05192682995731312, 0.08984473098309771, 0.03412540190883222, 0.03261617039360347, 0.04568842277231236, 0.03194549872029213, 0.00903136361645715, 0.06625690677713963, 0.05617525864152178, 0.035522309612602956, 0.05715533024481228, 0.055162957719256805, 0.04736339357951957, 0.022532562988119263, 0.031065437980296633, 0.03077049029900903, 0.030911931197249123, 0.07592098336786994, 0.05528056753739234, 0.08504531271154843, 0.01571774550323044, 0.047440492668219154, 0.0884208033582376, 0.09558066875944216, 0.04932730593868802, 0.0361305566114043, 0.015378229699337916, 0.030320222121513182, 0.02344648098392833, 0.21737439948464596, 0.04054782341324514, 0.04260016530151329, 0.014867839899154441, 0.03096261365909971, 0.052220180345278595, 0.01775279487182777, 0.030407711277685823, 0.0424889178435889, 0.03899844506034448, 0.024442558079176856, 0.019890071013041084, 0.058339307640468886, 0.03550663545367218, 0.020752728150616732, 0.05344229742824551, 0.033021591784011935, 0.10150530931329536, 0.14102068369186696, 0.05804496133820184, 0.09564347264747466, 0.02265913220452926, 0.017106140054942622, 0.01706822636356998, 0.04038229862588548, 0.09469864108870107, 0.03887256532306633, 0.0493794190697372, 0.06463140609764284, 0.06341042282480387, 0.09458526007590756, 0.014555083546457032, 0.048196552501570795, 0.04536039541445432, 0.023026174505151088, 0.08156305239085229, 0.20700176817274865, 3.6094054820076114, 29.75706131227555, 57.27763422073857, 57.233664451106904, 53.504831867833296, 52.35225908217892, 38.7205243879749, 24.697413636792092, 20.97002644692698, 23.43693840888239, 36.875763093271566, 44.00280383325393, 44.82530916890791, 53.51596355438233, 62.619812180919034, 64.58896360089703, 60.897220949972834, 54.159432303520944, 42.145490953999186, 35.79345564688406, 24.589675934084003, 15.527115156573636, 6.755647688142716, 3.1312016325612224, 0.6056959566570098, 0.6398628039225456, 0.5171672651363958, 0.4161167745628665, 0.14848866199533786, 0.36016753484164515, 0.36051671771753224, 0.21655413382236036, 0.10315857301916807, 0.334199360541759, 0.14999017900516912, 0.052504544521892266, 0.11649463160504257, 0.14017703702613232, 0.2412879872586458, 0.35564979177809536, 0.10307368281627856, 0.07230093447311271, 0.186945938715531, 0.5435382791103855, 0.2831922765941389, 0.347214458930877, 2.7148577282505655, 6.536337185290552, 15.389790035063221, 22.33957494458845, 33.513856472507605, 43.30875219837312, 44.060133195692494, 53.31900173617948, 57.73487275646579, 57.47420380192419, 44.09038643683157, 46.2725539361277, 33.31494131395894, 75.05831872263263, 67.48626155237999, 23.79687470774497, 31.349504378534135, 41.64893457966466, 58.55556987947034, 58.56282626428912, 38.04419402153262, 6.549904173420322, 0.12579068721782777, 0.044839785043751045, 0.14705805408377803, 0.02964283951798514, 0.05948581950618856, 0.019773294315523198, 0.09065196548979129, 0.15333222225308418, 0.049622337889647296, 0.03467380594942839, 0.020036727054825714, 0.05304356781585563, 0.013599338107592156, 0.09956550574110401, 0.051323918760904384, 0.07250326595479444, 0.013008846154045916, 0.0886764315768115, 0.08116922957161743, 0.03677903088710962, 0.08735320620959805, 0.007169063244345448, 0.046881271466132135, 0.09401544387782775, 0.03595903718603715, 0.0071374180674132325, 0.06904735905869354, 0.004906058668219034, 0.050055506984673204, 0.0043413120569781435, 0.022255007417932637, 0.066290331193276, 0.01856713867445867, 0.026955253692464005, 0.04509904834952566, 0.033781612291932106, 0.10004807218548753, 0.07477323043971293, 0.042826666857206055, 0.05782882112168497, 0.07915351434700912, 0.05009594493575635, 0.04220427787532249, 0.02125052250771513, 0.05428154674929477, 0.05638702449599101, 0.03282735402125024, 0.03800990435505106, 0.056559700714123834, 0.019795269547631184, 0.1792659532398947, 0.30501481205705677, 0.14811018391722633, 0.14413285459722244, 0.07840921396329519, 0.16260796887499673, 0.11885399088984537, 0.16964108502912909, 0.08346118077996277, 0.16470085979709703, 0.15278169614893777, 0.12123884558076821, 0.17630745957214988, 0.14397969829940027, 0.30453612967844934, 0.18574616841731534, 0.16945362331405764, 0.16831086527916694, 0.15706847902507554, 0.07935740864805638, 0.15085490841057994, 0.26998715775628246, 0.10462784538826636, 0.11802751991537311, 0.2507286572888974, 0.10837973801479225, 0.1519407614344551, 0.13655223072536532, 0.07749784512505417, 0.11829618695041827, 0.16148198816564777, 0.10421709968678414, 0.15942177855439726, 0.2348378793366494, 0.17565577921848144, 0.10002338117168796, 0.12901495210826397, 0.09416980293369102, 0.28272333885392836, 0.2313160199311472, 0.10587768719321299, 0.2023836522693596, 0.14157805862205644, 0.07641990578943685, 0.12090064840571535, 0.07586218611968142, 0.185088527899596, 0.14891065386754854, 0.18626442689809108, 0.1279063309512792, 0.1362183542862054, 0.2936101224153273, 0.11782907249946749, 0.19531505092257456, 0.193722844424267, 0.18128759798503694, 0.139486929702182, 0.25733693172374084, 2.1636237588620957, 24.838891567722445, 65.48916716729441, 74.1932164469073, 73.5958786933653, 69.95587994975429, 60.41877023635372, 48.78391419687579, 45.224073010106245, 32.4894687052696, 43.07513190853981, 49.40406837771016, 38.84761702629828, 42.393784830647135, 48.294547527067124, 58.45291360732048, 54.78115935479441, 51.14152931397962, 46.321359988181825, 45.042137792033536, 38.208078492072325, 32.57842609959264, 18.465712724193452, 12.350769985106684, 6.545731261853249, 1.9173579927413695, 0.7217011576698673, 0.49621555713876603, 0.298504903311691, 0.5263293089885865, 2.0733445257909837, 1.5327521918281433, 1.4253597802692846, 1.0221152440194161, 1.3841343214434962, 0.6990906548115515, 0.4689669741257545, 0.9580407531992082, 0.6414101176684903, 0.6211986344668173, 0.19104696059178924, 0.16950213200142308, 0.6236632925368125, 1.1392439589385064, 2.8768246500722827, 6.094463063824562, 11.603592788019489, 20.027029821949622, 25.58973323914313, 32.48876463982367, 44.052515952817856, 48.56029595098188, 42.59518677188505, 47.29687698425786, 55.79928113568214, 52.53738318720172, 31.304365742591123, 49.03611475421537, 32.91095287569108, 65.39648940486293, 71.47120137368479, 51.89178851342971, 64.49128481649583, 55.29242853964529, 76.67441368103027, 67.43620426424089, 38.012881740447014, 4.449486713255606, 0.2588919982794793, 0.2589897204551005, 0.33056007517922315, 0.3412668893654501, 0.21145670734826597, 0.1501843822939742, 0.1388434005240279, 0.35199641039775265, 0.09497391946253278, 0.17520521226669514, 0.10527348130821221, 0.17738880799903026, 0.12333991832189983, 0.17752348625611875, 0.16361922025680542, 0.1719623314396989, 0.09556040573384493, 0.17811587140444787, 0.1776873218196054, 0.18133822107507339, 0.2101346387738182, 0.2532036575458704, 0.11273077268513942, 0.16576798963210276, 0.10946986580928487, 0.15312039894202065, 0.1597630860464227, 0.1202613480329033, 0.14123445286625816, 0.14934891744727088, 0.1845161529678491, 0.12557306462117743, 0.1497008122744099, 0.10689798607340745, 0.1202749154500423, 0.174623460418755, 0.13493258295761001, 0.17047111065157, 0.1399449277068338, 0.12187241561590664, 0.1186073029173478, 0.16459745324907765, 0.2114309361504932, 0.23743473353885838, 0.09382711648340188, 0.23284853285839482, 0.1456306177762247, 0.14843241581993719, 0.15175838654320087, 0.14329829373426978], [0.04578993325271914, 0.032647078210908564, 0.04540659051628844, 0.022384886134175525, 0.014083088157818684, 0.1311666019741566, 0.04439470328150257, 0.038497810432266806, 0.07422078911575579, 0.04706242827758674, 0.05465694515395069, 0.03271300773767214, 0.08305883906300991, 0.030445714984389565, 0.039283356989824006, 0.06257545593525134, 0.029495245018493266, 0.032261927506976554, 0.05487473628994438, 0.07480363646942763, 0.0690518636556883, 0.041777781406117064, 0.0738296092998597, 0.008806914218791552, 0.01661669797143869, 0.030898909617756164, 0.07642647882382717, 0.019472173880785704, 0.028024183834091793, 0.07277790847564898, 0.07347491825179708, 0.04695018107492117, 0.025395006467137608, 0.011803903804731466, 0.052934204934224974, 0.03477648088348008, 0.011095002428778719, 0.12217507397215213, 0.01722145352452513, 0.01881277327606034, 0.038773257345441854, 0.06780844166754715, 0.01348461165288163, 0.03564003817436676, 0.07211488235982196, 0.018962171912613898, 0.0014048896217343189, 0.02305531840501053, 0.04249075262416755, 0.0031227326244040727, 0.0316051239403145, 0.04198622243899492, 0.03596455301909197, 0.06943051027314318, 0.03105778476193307, 0.024667238260829644, 0.08602857890148317, 0.04627315853271754, 0.011162723643675206, 0.09928530908279842, 2.1598474969786983, 11.86087183413967, 38.24145786223873, 57.94514317666331, 60.55604534764444, 55.02516215847385, 50.418334468718506, 51.21568956682759, 42.96321099804294, 44.21488246610088, 33.35382376947711, 43.234042813701016, 21.738636455228253, 27.29557594945354, 24.318598970290154, 30.547920965379287, 36.05804304922781, 37.41861128037976, 39.77596752105221, 29.272799607246156, 47.75978334488408, 46.83923836677305, 40.81327361445273, 43.07743041746078, 31.28578155271469, 24.48282860940503, 22.232047088684578, 16.305686023927507, 15.652140705816208, 14.262224320442447, 12.444557778296932, 10.082877124509505, 9.682965009443222, 10.732940358500327, 10.742649205269354, 14.657096189837302, 16.22033917134808, 17.211099478506274, 21.104944213744133, 23.00452063160558, 26.762406210745535, 39.38315391540527, 40.70933080488636, 45.00791511228008, 38.20980041257797, 38.593612178679436, 31.500856876373295, 37.209952954323064, 23.015942573547367, 30.488116587361983, 53.78291222356982, 40.10423068077334, 30.954084357907696, 16.289039484916195, 25.000820736731253, 32.621978136800955, 41.682957218539336, 34.28689679791851, 45.62218573785598, 46.43211203236734, 54.33833945182062, 44.63249721834737, 25.394573750034457, 3.2596720034076325, 0.05389856024374885, 0.059000104440436255, 0.06930350055617672, 0.066447647348527, 0.009264299353103965, 0.06065095496934749, 0.007973243454245911, 0.07678509224206209, 0.1285999163144058, 0.031738243208477096, 0.08163694157114915, 0.02613382740697313, 0.033419968995956645, 0.13566877813108508, 0.032140605992847876, 0.03864234058006156, 0.018833534258808342, 0.054118239786475904, 0.07729175215166423, 0.03261516298798304, 0.06173281667513713, 0.019391562278953292, 0.058378799472965544, 0.044170944320578734, 0.026008851653445634, 0.11294722316726563, 0.018891287712200035, 0.050127097901197216, 0.047703797087794354, 0.02503386304353274, 0.06751672304686039, 0.024231941356594046, 0.07412975488771355, 0.00649101845356786, 0.054913787621884584, 0.02156558957311415, 0.02866613678634167, 0.04193921145352145, 0.030610607749211694, 0.06101763146298547, 0.0414818914366826, 0.043578409785104376, 0.07990565181018845, 0.02367709834699429, 0.04266676515521061, 0.036238241760480794, 0.01221199979960558, 0.08131909169136517, 0.08432778710078809, 0.06569155687165838, 0.056871069490068385, 0.03431333093753746, 0.08151790682947443, 0.01464509025907084, 0.029210244988902446, 0.04019306724770896, 0.049397425966397415, 0.0275182114884017, 0.04837195599271406, 0.060866834715970104, 0.05659417467071645, 0.026357333558881958, 0.1351315972785796, 0.0529027646858125, 0.04525989617010759, 0.043645342887048764, 0.044601956878097794, 0.07105964987028031, 0.06416958914468847, 0.1192506558952793, 0.02225144319386492, 0.042933677848909176, 0.038020897716764486, 0.022930176027359504, 0.03861950349903876, 0.07007911095335599, 0.072823942699019, 0.060657558647254785, 0.026535039144237677, 0.10063855743576443, 0.039066320450435725, 0.0340171383633729, 0.043300147498807603, 0.02787523527419375, 0.023355237996926712, 0.014341490572288394, 0.006793094582990894, 0.010019832501007665, 0.03122440313980464, 0.08117922701902928, 0.012167999539674531, 0.030822643649674235, 0.024433071995454452, 0.10056356508885661, 0.029886782980493964, 0.0802335757461767, 0.029237195962078633, 0.04316449631005526, 0.06327902342403127, 0.021911734910381418, 0.038484204710731586, 0.017590861121613174, 0.022064161509455695, 0.026134557105721008, 0.036342349278950886, 0.0423663935714191, 0.018224055773668715, 0.04431324132207421, 0.06859214961408608, 0.05398859855748954, 0.03583726368003315, 0.08177345843925592, 6.28708674061683, 24.421041473265618, 54.84327008647304, 66.37399504261633, 65.33291170673986, 53.820017845399924, 43.59617956223027, 34.65976907360938, 30.92190327182893, 35.086499414136334, 23.92537939933039, 27.00936059797964, 21.3424535336033, 32.611191618827085, 30.960742581275206, 41.21282977442588, 49.15848878122146, 59.25206907333867, 57.66210102265882, 62.036508667853575, 63.89486489757415, 46.90343579938335, 49.28005479997205, 43.52055234293784, 33.27141084978658, 23.328037723418205, 16.37381955500572, 14.036172243856615, 7.147456186432993, 5.215864892928831, 3.8745841816548383, 3.8802270014439864, 3.974000330894224, 5.134294792529076, 4.751192485132526, 7.1365632741682, 9.940597068878914, 13.49853688670743, 17.875274419784546, 19.047674786659982, 22.81152040727677, 39.354057773467034, 50.166855627490634, 58.85594106489613, 59.95078440635436, 65.14711295404743, 57.70889097644437, 62.78787005332209, 47.1573975009303, 48.012395751091745, 48.7151393582744, 35.404242777055316, 30.353436123940256, 21.222085798940352, 18.939703702926636, 33.11104474529144, 26.219820822438887, 39.230863971094934, 52.207586380743216, 42.01455047053676, 58.03980958077216, 55.63826784010857, 41.274587492788996, 9.98077194536886, 0.5280093091630167, 0.1316761883396295, 0.06937863845979014, 0.07383931563386033, 0.07157885830008215, 0.016025906285992073, 0.03469566626834773, 0.06885988968274287, 0.016191680051927126, 0.05277797662382645, 0.04791056804899727, 0.004027234202611351, 0.004595755712099133, 0.03086931181080159, 0.04913679519367795, 0.055113824670233076, 0.19254873807151474, 0.05920751891549557, 0.047062730882316835, 0.02502883942196927, 0.04284309944318187, 0.010060897686578816, 0.06804933801533715, 0.10114083532243968, 0.049379108804127866, 0.06575429947265694, 0.039530029640563076, 0.03679727527102636, 0.054799272798963135, 0.033338813471697995, 0.04406358092843045, 0.03023136932883532, 0.06574744298573464, 0.019606313961107406, 0.010194928599371305, 0.027745126731573578, 0.04999882413915569, 0.0030817363867461085, 0.03701937948203376, 0.011587129650457252, 0.05329813117221479, 0.0563489192826373, 0.03988345281311101, 0.06485662828650206, 0.03463095099094414, 0.06511611758821434, 0.010707737322175696, 0.030156294627475645, 0.0201023175876828, 0.058461203720540776, 0.04643109138874758, 0.06020742453514569, 0.25299811615578593, 0.17140238245408382, 0.10654895641510526, 0.11374537187117724, 0.14332467780238198, 0.18061242937561006, 0.17300080958633654, 0.21422542571540804, 0.3011308994985396, 0.1445803725190701, 0.12208261482057073, 0.16376371976108323, 0.186253349266706, 0.11363083406561807, 0.07409192546601258, 0.13811653630147058, 0.14867267631475004, 0.20733806544974928, 0.14278924363034387, 0.20061181347456672, 0.1368443094073765, 0.09796772212270768, 0.12480264063924552, 0.10628167599920305, 0.11571849260719554, 0.11706532880423531, 0.10963586174071797, 0.1343576339704375, 0.1085571639780556, 0.18543322150024677, 0.20960815250873568, 0.18447544305555283, 0.19000768571371035, 0.18613823689520362, 0.128159714532235, 0.11554996858561233, 0.14278925895210237, 0.23080116288075525, 0.11213432727081162, 0.10085146859168045, 0.1423320423571333, 0.2657842461860949, 0.2485995916950126, 0.18847011660616245, 0.20559518477849423, 0.10932240154474013, 0.10877374469512895, 0.09724125626587099, 0.10082871578032933, 0.12095541603142217, 0.15102023018463967, 0.08473660226070112, 0.11409656955830513, 0.09368144486459995, 0.08698661015519212, 0.12143409841002957, 0.2136912019622903, 0.13260358373724646, 0.1016276458939237, 0.14159175627414258, 3.3528322173703105, 22.153825221523164, 57.47475685611848, 77.202113674533, 80.80257492680704, 71.3760603627851, 64.87447684811008, 62.64339739276517, 55.26425023232737, 58.79574837223176, 46.070657776248076, 56.29054623265421, 31.986214883865852, 37.168395442347375, 34.25583554852393, 39.42668045720747, 46.52248736350767, 47.63876645795761, 49.89236424046178, 40.1815955100521, 60.96469356167702, 64.29567621600243, 55.6423157261264, 58.875882394852184, 45.20055055618287, 38.19651142243416, 32.05405423718114, 25.01501383319978, 22.027826924477857, 21.22680244907256, 15.781407317807599, 14.489667857846907, 13.608133792877199, 15.748080899638516, 15.480400708413894, 19.262034277762137, 23.692712245448945, 24.82646353783146, 28.125655381910263, 32.64046230623799, 36.96212191735545, 53.411502991953206, 54.363901538233605, 60.79293689420147, 51.440798313386985, 51.97429557000437, 42.62509484444895, 50.43612633982013, 33.10794215048514, 41.03445214609946, 66.29282551427042, 47.69958672984954, 40.809331632429554, 25.295902605979677, 36.15546295719762, 47.64490888964745, 51.74253840600291, 49.0709218671245, 59.03052576126591, 63.878810636458866, 74.77844192135719, 64.88760502107682, 38.38973914423297, 7.390936824583239, 0.3212689608335495, 0.19578562809094308, 0.17650981403646931, 0.19209417214076366, 0.18055837421167284, 0.2446376913858037, 0.1562060785269545, 0.21155508835950207, 0.1912912507090838, 0.09932227282514496, 0.13707208266902354, 0.1389495496668162, 0.17217456843824158, 0.17381488525819394, 0.20051842735659695, 0.17768306237074638, 0.21830403185900182, 0.21398962385231451, 0.15440230918747766, 0.18182162255529435, 0.12988201042096462, 0.1644644297419056, 0.20913152324576534, 0.13798904394911182, 0.18381171979971472, 0.21905674388812435, 0.06712078582495451, 0.14720440752083255, 0.13197963576643698, 0.11907766558109753, 0.1766934912771948, 0.10799593562560697, 0.2502604549930942, 0.18906533627981142, 0.09556623566294871, 0.19342474429117096, 0.1778838386939418, 0.11039440369894428, 0.06999507876894168, 0.12927658645616424, 0.09533126883569265, 0.13466975351254787, 0.22773045265386183, 0.13576967191071282, 0.11822485650378851, 0.14625586809650545, 0.07292852136156253, 0.24332355948225146, 0.11481431733456351, 0.15699119607527412, 0.14527306922020453, 0.22705756698644933], [0.049136017614434806, 0.07463721918963617, 0.03914001044787226, 0.03378430126054633, 0.06455560935841453, 0.036704793136807225, 0.03249058176973655, 0.012874668726937906, 0.05250947429768501, 0.04228881950820646, 0.007019130261464706, 0.044721665777145855, 0.010960434296829327, 0.05019069852067098, 0.014790161456462118, 0.0308371705919384, 0.06971725698320136, 0.051014036195532936, 0.11206852031811593, 0.016288664867921222, 0.08779088756249798, 0.008869087999506343, 0.009442690587151916, 0.08081080001448432, 0.06249953662195514, 0.04028891250791569, 0.04632928596448995, 0.07244002539664507, 0.06397746195415817, 0.03299401261873784, 0.017764450899595698, 0.04765303610193153, 0.10213714798972492, 0.014130975356355551, 0.04583119091788127, 0.06478165126135273, 0.11315319356658768, 0.028283950842676625, 0.05194485983661106, 0.029745977935231024, 0.05180634730946153, 0.027883903559056983, 0.09512596493286472, 0.028142264796300765, 0.011259710374889115, 0.02112796376158874, 0.03713065758347511, 0.055388176077676404, 0.02134298165929654, 0.04839762759905669, 0.07835310568372089, 0.04781296844744394, 0.004855834422708159, 0.005028464675565521, 0.027310092212452043, 0.05187341447679266, 0.05139394685806287, 0.041852214508840156, 0.013331956185039975, 0.07904758736971887, 0.08422841017525043, 0.060231341800141724, 0.8010695826622748, 9.0161758084451, 21.935362931220762, 37.10755555860458, 50.244785278074204, 58.10266164041335, 55.905283189588985, 61.91561729677262, 59.032039796152425, 59.07516625619704, 48.605124719681285, 46.23344006076936, 41.97875099797403, 39.52004855678928, 45.3606617066168, 31.693209909623672, 29.890545452794722, 30.195786260789443, 15.529405820754269, 78.99112239960702, 56.43033950559555, 21.348648917290475, 31.72279242546328, 25.464442929913922, 30.332686785728704, 28.47244389595524, 26.696498624740112, 28.94712913420893, 31.052108310884048, 32.31840825849964, 32.64606933439932, 34.48167385593538, 40.809970978767645, 37.612960800047844, 28.88828181451367, 32.409577869599865, 23.37957766748244, 44.078815444823235, 84.44353857348042, 36.20572028621551, 30.044551434055453, 26.707408697374408, 35.32875676308909, 27.69869754391332, 33.71126151853992, 31.37058319584016, 40.63483322820356, 52.246770858764656, 54.927377470078014, 33.737243298561346, 32.757733329649895, 45.38780058583906, 49.40259356652537, 51.353231399290024, 59.40449237823487, 64.45139431184339, 59.06841585713049, 47.35129594802857, 21.516885257536366, 4.536624127818692, 0.12917927796802214, 0.0381025128937777, 0.014193619323533871, 0.021270276084842703, 0.14094479502208773, 0.02591812769101272, 0.044998181382975275, 0.04700109527836885, 0.013806512222565232, 0.030070031211981853, 0.006191603522071796, 0.054348219381344896, 0.0725314120251325, 0.019697380747886437, 0.0343120668924624, 0.11362241475933021, 0.0211761181332892, 0.01600116260364772, 0.12330021198478439, 0.024557339117651986, 0.03611434236048691, 0.03900914347820705, 0.009830716993629692, 0.05415543718563934, 0.0492004111349102, 0.05357538605289114, 0.01664542818381902, 0.05015882926302091, 0.032759612696545745, 0.028439397743392377, 0.05278171896333656, 0.021748173223327727, 0.029377355578265367, 0.09508353898361807, 0.03443569816168278, 0.01557667520002372, 0.026841430263894222, 0.048158355357666174, 0.022500984843880422, 0.08376078244539038, 0.11084528474677956, 0.03614467178140918, 0.05960906007056756, 0.059199796749218825, 0.042689257496667486, 0.03255513233823642, 0.025795095885593085, 0.028841469414351933, 0.06016356600148063, 0.07273024248500025, 0.02878325630820567, 0.06032469344415492, 0.00942786678581709, 0.06759556881602734, 0.014685927533484517, 0.04908668538255077, 0.05550226189136025, 0.009546689895702707, 0.018685211975788398, 0.009305333895158143, 0.007687493137294247, 0.03808863904146898, 0.02776384225956375, 0.02688513366475461, 0.018091855811015255, 0.06760445543594899, 0.07114879952202882, 0.01880299799414652, 0.07408993363740944, 0.01222226920823056, 0.0884786123530038, 0.013938810819038942, 0.0829625494718071, 0.035233061625472004, 0.04398363582309216, 0.012702588142166215, 0.04100165006914928, 0.03806091048904965, 0.018583804917251392, 0.04107013066870071, 0.04165531459054159, 0.08927866861584688, 0.03416036233125675, 0.011540996793266988, 0.013045898954113646, 0.042213800348221295, 0.014066679512090502, 0.03884906557598903, 0.030112447585129452, 0.07736494419194999, 0.09525724942044866, 0.02619244270927964, 0.038742368680334864, 0.012511317054891299, 0.0859080809318731, 0.08871402351125594, 0.025082959703380064, 0.04798823787320045, 0.017045002408145417, 0.042919593322421276, 0.03575898481593017, 0.033029179884901935, 0.0464251350551363, 0.05651731306927339, 0.07214342679588065, 0.06001156266598452, 0.009547094007082766, 0.04357223128599506, 0.026129564127674507, 0.04098922029257782, 0.022175361086884816, 0.049627099126096696, 0.03425863992062307, 0.05710571839083588, 0.10814836413990106, 0.18927161311430318, 3.422824951910204, 18.702076711962302, 37.96543282847251, 52.477327777493386, 63.65931872398623, 67.07921366537771, 58.89024219205303, 59.24778192274032, 53.53512041030392, 57.43524682137274, 35.30871345150855, 32.05234408378601, 25.64035338740195, 29.83999786838409, 35.764606614266675, 24.05470190509673, 26.215855306194676, 25.166382020519627, 27.576578470968432, 78.25949053610526, 59.661674345693285, 43.430157399946644, 50.140571824965946, 48.87571334838868, 53.18844956736411, 47.372770924722, 56.45999262409826, 53.325124556018466, 56.499196713970555, 53.40199516665552, 58.01621652418568, 62.16787668966479, 63.58538596860824, 64.70852921085974, 57.77050356711111, 56.6674114811805, 43.02424700029435, 53.31363201141358, 75.34760136758128, 51.61451224357852, 43.38530117465604, 38.56017789533062, 35.148645447146514, 26.346305493385564, 21.30555775857741, 23.454787154351514, 18.877820468718006, 29.899378630422778, 52.34317879523001, 31.965079192192327, 32.88661849114203, 35.72926213664394, 43.71176396646808, 45.46152153322774, 58.39280328442974, 58.990674480315185, 65.00144789295813, 58.04542249248874, 37.483416680366766, 11.877316371087106, 1.1052538021918268, 0.07222083998062918, 0.11324643412785185, 0.053254996591638175, 0.05624509521669919, 0.07248474194878533, 0.020126508729111765, 0.07906355264206087, 0.04272460479349379, 0.02809205539374342, 0.07181013258354318, 0.07239488749614648, 0.04002676871154578, 0.06420860600267207, 0.013627405653917983, 0.013849847901221967, 0.04490971354947937, 0.05175238024563559, 0.07967457670958773, 0.051496951209921996, 0.022585474765829505, 0.07286954791315141, 0.058411285431394656, 0.05308713140566984, 0.03367115007413011, 0.03867352801945902, 0.024759471416473392, 0.0923037429850909, 0.030464842284639037, 0.054313542411452344, 0.006223171611406631, 0.04069350652336594, 0.03133592447416196, 0.02971428870824316, 0.045711922519389665, 0.045545578017951026, 0.02654703991157153, 0.06950477483652293, 0.05718800389478284, 0.040545731993211855, 0.040323229416483836, 0.09928774524239764, 0.046432087303049145, 0.06009206701550753, 0.02280894644378174, 0.03173741008785944, 0.03594512119889259, 0.044564621583107984, 0.033144495269704255, 0.06997896793989405, 0.06803548714566617, 0.03202453218100052, 0.08162894361321965, 0.057986669708043344, 0.1492207202940218, 0.18344517737146349, 0.1287368315482332, 0.11421793320726965, 0.1653185258469274, 0.21222150824483366, 0.19052386043533204, 0.13334561650070453, 0.12817189533023104, 0.1258353807873303, 0.1553270692426351, 0.09752151421121052, 0.17009690734407595, 0.1463935953835326, 0.14259632736925157, 0.12882905321255808, 0.15415388219539197, 0.18219961033713433, 0.18098548355121769, 0.07198926692287769, 0.11950690464507188, 0.13941009108337665, 0.1015771913432306, 0.185194477859524, 0.1560924830095422, 0.09873566397976491, 0.0863013751504402, 0.16989622295143145, 0.14998310035274875, 0.09543259162455799, 0.10278340444088944, 0.15490474029173776, 0.18943218514323237, 0.12109535731255047, 0.14867727284229573, 0.25182198733091354, 0.2264347221822508, 0.05909470097732641, 0.10982064214805443, 0.08689327766337702, 0.20874662535084834, 0.3830868324204799, 0.11054638022136305, 0.10687887217969665, 0.10201333285940271, 0.10604349926354424, 0.10377641526922103, 0.16384861762485198, 0.1469339478400446, 0.18871115851065806, 0.17238006386305058, 0.259055175007351, 0.07404433608415627, 0.12410838877962482, 0.2124301446301322, 0.16033734555446333, 0.13797965171116014, 0.21368962382116627, 0.2893982016511502, 0.31181197313051073, 0.25466944421491317, 0.18779214411493272, 1.9471008354617705, 13.695223158405675, 33.890050995734434, 55.87202933526809, 71.7642024255568, 79.08234888507475, 75.66714117603918, 80.30000948136853, 78.57105224363266, 79.19039449384137, 61.309493434044626, 60.589075626865515, 53.5810003742095, 52.78656744187879, 60.75977325439454, 40.9522275001772, 38.91579958700365, 39.80071375446935, 20.922740313314623, 89.27108979994252, 68.77359128767445, 33.54860082749398, 44.94876184771138, 41.57256603240967, 45.33568797572967, 43.90673714299356, 43.667680448101414, 45.302979330862726, 48.27098192707185, 49.74579311186268, 47.515023523761386, 50.658301153490626, 57.24990698599047, 55.1515801491276, 42.873165145997085, 47.21883358493928, 36.9629220808706, 58.66934607105871, 104.26284359347437, 49.224051198651715, 41.34581773511825, 36.03658768438524, 46.34217600668631, 36.827823885025516, 42.88151587209394, 40.51771909959855, 52.69184220221735, 65.81582607761507, 67.60941613105037, 43.250214745921475, 49.25263351009738, 60.76751601311469, 67.94702237652194, 65.47407780924152, 79.04955002569383, 79.61533623356974, 79.97150313469672, 64.5316420831988, 34.78990939355666, 8.095359696495919, 0.5162600944599798, 0.2032028147650342, 0.14331329373582719, 0.19843672131819112, 0.2647651040986661, 0.16542004781865305, 0.20404696704879885, 0.20267108845854961, 0.10800586412510566, 0.10496349149053136, 0.21662554853866178, 0.13407890054006733, 0.19310949911032954, 0.18080484001867234, 0.11393527740672713, 0.1546976207605293, 0.1413947644252931, 0.17432840931559765, 0.3159355179917428, 0.22955928839022116, 0.12778885136809082, 0.208144357668296, 0.19358617433857536, 0.15252553166881685, 0.141791996335791, 0.14869454046410902, 0.1311953609148341, 0.19704890707808156, 0.13651872203955728, 0.09539093942411485, 0.15089756418620387, 0.18328730197202775, 0.13167824145526658, 0.18317932953997967, 0.14281742034419892, 0.1804928277288714, 0.1482532125326895, 0.13107128531461762, 0.15895150782119843, 0.12224239011805867, 0.20314111404361265, 0.1358535891819385, 0.1901716898165403, 0.1927597186858616, 0.16527251460619513, 0.13275218947279838, 0.14413195061347178, 0.13984363556148546, 0.0949674077151764, 0.1705984497863439, 0.1660426321529573, 0.10601880824974469, 0.2545490918020087, 0.12046164172070643], [0.06600177651571651, 0.03462905875377117, 0.0749181742749868, 0.016090937574664434, 0.07729559025216488, 0.04247389868983338, 0.017865863703792135, 0.08205984508798969, 0.018676005514158357, 0.02570461707129594, 0.013372736960469235, 0.004712775163728023, 0.04997245922324158, 0.07781092993794911, 0.03516126386520844, 0.036562932805428584, 0.05703402405244209, 0.07250836810037013, 0.019275699141285112, 0.023192315993289796, 0.011046532045809493, 0.009452066545735204, 0.07669372093533317, 0.06907939685568695, 0.10187502334555311, 0.04190670634289423, 0.029821393545717004, 0.03618614012075048, 0.024524577367570133, 0.020993394672029445, 0.05591807909490121, 0.028777924336252675, 0.08515002926991833, 0.048833619728083574, 0.038469369418077895, 0.03429468052702085, 0.044257090907664075, 0.021325897898585088, 0.041426759919211756, 0.010803629505267788, 0.0321311065025868, 0.050430556819323576, 0.03681196500697444, 0.046685045705206936, 0.024153882742769296, 0.05291761530022468, 0.07664177251318771, 0.06133563839079392, 0.014286999695844228, 0.08206336143156213, 0.06755241508325262, 0.015211755920562054, 0.06890223136231785, 0.013182555633266608, 0.04082183391156216, 0.03818675958281083, 0.044690493659506884, 0.06190294948136134, 0.030088696944256945, 0.04863485438568939, 0.028901515385857033, 0.041510018354822556, 0.05653584473616174, 0.10504587658590848, 0.023129115654756466, 1.0904121663301223, 4.427882298346489, 11.381493479974809, 25.50129359768283, 34.246986681415194, 43.08955838603359, 53.159396571497766, 59.731688653269124, 61.41243211684689, 58.869335959034586, 62.63365422525714, 63.66845000174738, 65.31577487145701, 59.4812100164352, 58.80719777076476, 48.89703143027521, 46.654157407822154, 64.03313629088863, 34.46436051399478, 60.435789400531405, 43.22925359972062, 32.317396286995184, 34.576967839271795, 25.22637074993503, 26.971513648186964, 34.09889367318923, 35.23218800944667, 28.903139752726403, 30.36152993479083, 24.545533580164758, 35.46241152671076, 30.493390214058664, 35.43129928650395, 31.061084655023393, 58.4379066190412, 94.83285380947976, 36.5663351551179, 47.965754847372736, 48.785816546409364, 55.53066545917142, 61.840288177613296, 62.19460372001895, 55.6365341524924, 72.01789348356186, 63.485345917363325, 49.05702490960398, 48.04063681633242, 62.39496231079102, 56.130223274230964, 46.81364097902852, 43.35747195828346, 33.021893193644864, 21.231215115516417, 11.345472393497346, 2.124903101113535, 0.05878256994389719, 0.017340099476578257, 0.0054489847013516534, 0.041176521129185156, 0.0833602640176973, 0.012372342959767389, 0.015778092164245826, 0.057639689334938606, 0.07404156284587038, 0.05532040410945493, 0.06391551608460085, 0.026088210701521848, 0.024108156869788806, 0.01656523409990534, 0.035145041953411796, 0.054942255449150844, 0.08757489673312634, 0.020391063787223353, 0.018776732669662566, 0.04016974753129386, 0.029840647250473983, 0.03340118068961367, 0.07124226224879104, 0.06351048539903376, 0.030361286349474426, 0.04304368424439623, 0.057177083311422225, 0.04744498960433468, 0.004640596274722127, 0.04468195177915116, 0.07904283762458833, 0.016272452532223636, 0.06335521086810098, 0.05670852095429456, 0.015676008075505735, 0.029328078887755835, 0.0232408897981288, 0.05067200475041905, 0.04602796443167233, 0.0018650272860184253, 0.07015390411740349, 0.02318170759075832, 0.02133560806302534, 0.023221377538697376, 0.09479414927022112, 0.03003626205627957, 0.07146629700136763, 0.06561170752731062, 0.017439934139650677, 0.058297555848595604, 0.026974597412552086, 0.04350474277030557, 0.02948358516028572, 0.016403936202667894, 0.00879309207741772, 0.09458921308959685, 0.06239682338350724, 0.07044510179830175, 0.08054196444009581, 0.026620846737416524, 0.07047747667398184, 0.006395505962803239, 0.03621850350511171, 0.06185176331670054, 0.06949220333368548, 0.029691825095083446, 0.08924075492447422, 0.06613234088065163, 0.018419080691772605, 0.02725823380563769, 0.01638594462776617, 0.030140947971132495, 0.04071980632180649, 0.08531373459845783, 0.0341914042139486, 0.008114700153049442, 0.05482939537614585, 0.07424125898509257, 0.09873378706435043, 0.02759720281427426, 0.04978127049041852, 0.037769234003198725, 0.057469407141569166, 0.05177246707101023, 0.06163810522505834, 0.030901100629219608, 0.04678377528644858, 0.04326493426736805, 0.01586471372584422, 0.05314287579348011, 0.07016950932842109, 0.04306930222458417, 0.06088214498313685, 0.017127004459560398, 0.030393896797191233, 0.010352925615265005, 0.027030106228325638, 0.055215913547022696, 0.027570112030051892, 0.03698002937580309, 0.02689741596940064, 0.035868454949870225, 0.03678656919228454, 0.04986211574906784, 0.03720044819337707, 0.04176279289587852, 0.020052818731675227, 0.05060306066767343, 0.0530071058610995, 0.03202884525601422, 0.06342210183520952, 0.025215270748782544, 0.055307392106061025, 0.03940758580762533, 0.004292086598598549, 0.023237762244177923, 0.022267429533624844, 0.1169586050955038, 0.04841535487362454, 0.23721543320965385, 0.4775122865553825, 4.347768868169477, 12.326381667967766, 25.328017011765514, 39.616342744519635, 53.59054742320892, 62.04571839301818, 65.01813365567115, 68.13557071070518, 66.96045214130034, 64.77431128101965, 58.11534658555062, 58.05202384148875, 46.026001591836255, 45.70041348857265, 32.138136125379994, 20.397811474338656, 61.15317129319715, 57.10220621478174, 20.634957974956883, 40.43494139948199, 28.08365660329019, 26.33708792348062, 27.556246865180235, 21.187684651344053, 28.01553483932249, 32.362760459223104, 35.68501780110021, 27.161256344087665, 26.281307897260113, 27.436579273593043, 30.249057931284753, 21.373624609362697, 27.94852702848373, 19.82635744156376, 56.7726408281634, 98.64439349020682, 30.623379522754302, 29.491144226443385, 28.286880485473144, 38.268051532007036, 36.11092444389097, 42.915205109503965, 44.64196189757317, 62.18967722308252, 67.45638093640729, 59.02493638377036, 51.764970441018384, 63.818551263501575, 63.275526569735625, 59.3495282050102, 58.23142128605997, 47.57798933213758, 37.70376759190714, 22.056013076536118, 7.05361936361559, 0.5183332509571507, 0.025677539693612247, 0.03671685902161464, 0.06422057612648895, 0.08843161285884919, 0.06167873852856218, 0.11367554295687907, 0.01977231946863955, 0.0792864306018718, 0.07177603401003346, 0.06924189176530608, 0.10003173153006262, 0.08457763135553369, 0.01850903856628124, 0.052178034018124306, 0.1350259997190968, 0.04140751962099345, 0.04975222426676943, 0.045383780248342984, 0.02334498774049984, 0.026258312864229087, 0.04570416970959595, 0.02600490247019597, 0.026892242960691936, 0.030986356639092973, 0.02105033415700159, 0.029243968179329272, 0.010818848799493526, 0.01642528324267797, 0.06050788038860887, 0.05400974258419968, 0.021282464543718006, 0.09544397569111279, 0.04684836798978429, 0.04067477567361728, 0.061326805397026965, 0.012775672930142572, 0.06834170014988031, 0.08106839707902364, 0.030371094190125025, 0.036997105475635304, 0.07554152469721533, 0.04179642032531481, 0.06081242715158771, 0.04020434789239399, 0.013765903816918933, 0.012507506725077909, 0.012597936701269881, 0.01934213811651834, 0.045364976620241526, 0.08327103009627712, 0.028798218005366867, 0.017094945595149073, 0.022710377741004192, 0.06888682533416056, 0.05635227857818527, 0.3307533438407606, 0.12566186187248077, 0.12944515644302293, 0.08119557533533343, 0.24330866673300344, 0.22406996197758183, 0.18247843569805547, 0.17929304210889727, 0.14997413712403468, 0.1391280021878981, 0.1382397998484873, 0.13576291501522064, 0.13509448797952744, 0.2198472393736724, 0.09152814024879087, 0.13666916638612747, 0.1424653416559581, 0.156918371757192, 0.08640708762311167, 0.32019113641112085, 0.14618060761882415, 0.09462989235837614, 0.09515958087098214, 0.15813818291550683, 0.16975962947453224, 0.09260798714333966, 0.19253569925504346, 0.13654112245046324, 0.16075866326930063, 0.13209076448073312, 0.08549348946901099, 0.1052086013219049, 0.10217179814654012, 0.129467970541408, 0.11586954982410516, 0.20831675809477607, 0.18962796657316147, 0.1563787700668458, 0.14385980553925037, 0.1081024831341159, 0.19760047506180503, 0.17877622387341915, 0.09788304642443696, 0.13509352270874286, 0.10092365705678541, 0.31445892948296766, 0.1814828891186945, 0.14102046918724814, 0.12314897856765217, 0.233486638134045, 0.1289624444419338, 0.15358077181923777, 0.11876754552846956, 0.14614400393780203, 0.20310201291595736, 0.15237484217411087, 0.14958638938203936, 0.13507449308470373, 0.11964747411829811, 0.2514499597131245, 0.11592619436522646, 0.23549731250011155, 0.24195960122010401, 0.25999344885349274, 0.1950177475209198, 1.9582461277323386, 7.689463025139225, 18.678615054776593, 35.649598798444195, 51.62438484930223, 65.6902043281063, 72.73277682642784, 81.18305267826204, 78.90937236047561, 81.69822462143438, 79.73703953527635, 80.08679728354178, 78.75370133307673, 72.34119876738518, 71.458845907642, 61.19892574125721, 60.65501851420249, 76.40721398015177, 50.55682159239247, 77.21417888518303, 57.07384747843589, 47.67506407153222, 51.276800094112275, 35.77382810654179, 40.3242991816613, 46.86981716463643, 46.905573491127264, 40.50741503315587, 42.009196435251546, 33.97770812434535, 45.40548655294603, 39.9535842095652, 48.11437737557196, 44.13814129367952, 71.07599119986259, 101.3016894555861, 51.24340503446518, 60.65885066986085, 61.30542201380576, 70.06180747862786, 74.58337460794758, 77.64408634554955, 72.99104921279415, 92.70470911456694, 83.19121206960371, 71.29644409302743, 71.46281534625639, 86.18539256434288, 77.47038810483872, 70.01034598196708, 61.37969601538874, 44.39355427219022, 31.04346536820935, 15.780230606755904, 3.673380320110629, 0.238460969600466, 0.1538750108691954, 0.18747014203859916, 0.1951953113800095, 0.2053994186703236, 0.19100876344788462, 0.3451308836379359, 0.07871740347435398, 0.2300033282728926, 0.21639828089504473, 0.12711254894853602, 0.18957915145062632, 0.21251237650792446, 0.13003878265378938, 0.1266365708603013, 0.19069656729698184, 0.14425057166766736, 0.10236600909622447, 0.2016501384036195, 0.14438069936248565, 0.1647392101585865, 0.12131284967425371, 0.22471998758133382, 0.1539182488716418, 0.10907096382711204, 0.0990976328631082, 0.14956795730658118, 0.13533854827044473, 0.08979396233635564, 0.16886981835048046, 0.09879557205544365, 0.10266849891312661, 0.190191179093334, 0.11857210117722712, 0.1800515151192104, 0.1148060282632228, 0.1541018188600579, 0.25123557766839383, 0.27172464516855055, 0.16021385218106932, 0.238840566166947, 0.16825567630510177, 0.13908759871077153, 0.11458907216306656, 0.20521261579086705, 0.10813064452621246, 0.1324716327531684, 0.11028546599611161, 0.10042828928318717, 0.14689058726353033, 0.18157051425547371, 0.16204964399578112, 0.12866200007978948, 0.07362402960537903, 0.13126315969613292, 0.29664291128996884], [0.049139917001969395, 0.04605129563940629, 0.030566988618022976, 0.00705375504161742, 0.03186328407947815, 0.12950924735876823, 0.0378199681759842, 0.058383323222158424, 0.02044704757750996, 0.02759835386138049, 0.02666593101176043, 0.06846518586239508, 0.0364761695175642, 0.017843932521739797, 0.06569633726030588, 0.029218105051005562, 0.09380616397867281, 0.014210650415700531, 0.09285295141800758, 0.08283586917264808, 0.05179974363155423, 0.03542760965384303, 0.053604451428738334, 0.06676432511378681, 0.02815328880153116, 0.06294759080534981, 0.07608396091288136, 0.021622140268464724, 0.10963861199636614, 0.05933388128816601, 0.01044333260881925, 0.08389769767921779, 0.016945956815635006, 0.00714641816410867, 0.05517848632148197, 0.005301235547860063, 0.022759244574474233, 0.0426932334929945, 0.032107723583917946, 0.02307676503645076, 0.04169912715893119, 0.02068788263826601, 0.07487787805016964, 0.04237476691243149, 0.0010964135459113507, 0.005572736150615158, 0.029683319603904124, 0.06296053386083053, 0.04986281671951856, 0.03717968338018945, 0.01782919682051626, 0.01532456715546188, 0.0496980618505228, 0.053941342423880295, 0.04861200964378734, 0.04728783049710816, 0.04164582659159938, 0.06042116306601994, 0.07288745904882109, 0.03545207467170493, 0.08280341002729633, 0.03195538891539459, 0.03925250279867361, 0.03515064588657791, 0.056834412182891564, 0.09547251246629224, 0.07562388680995473, 0.14765096017189566, 0.05142988021215124, 0.3368523230235423, 1.065157618253462, 4.2599048345319686, 12.843409872824147, 15.565184700873592, 13.806094834881446, 34.31229806715442, 50.40437083090506, 53.24756360823109, 51.557841839328894, 60.0691968394864, 69.50709804411858, 59.38275068036972, 52.991844684846946, 66.47720829133065, 54.592850285191695, 59.69910944661787, 58.20093662508073, 53.696251376982666, 65.98818286772698, 63.31479341753068, 65.19581702447707, 64.14193107235816, 66.83932150563886, 63.63944407432311, 63.09918072915847, 69.38201365932342, 75.04954045818698, 66.5824141040925, 65.15381236230174, 60.807308458512836, 52.64201633391842, 62.583800900367, 69.31698076186642, 65.10664978334981, 65.09694191717333, 59.0835169822939, 53.4016146967488, 43.78406893822455, 39.1149147864311, 29.515045189088394, 20.872261370382002, 20.99996001489701, 13.655041417767926, 7.792084976550072, 4.775198371179642, 0.9418351743971148, 0.15811611958328756, 0.03453500996974688, 0.03752215149542017, 0.06169882918437643, 0.02274363361779721, 0.023657036419477195, 0.007292474742092553, 0.025596824669910055, 0.11161616072058679, 0.09447988468192278, 0.030076129271859126, 0.04601818148887927, 0.040357159450650215, 0.026128079832321214, 0.03707668285876994, 0.028874365229820533, 0.08045109109051767, 0.03009200644408984, 0.026226133340969685, 0.029069629550400763, 0.00789131130835402, 0.02988540019179064, 0.03083482061723067, 0.05353762940954297, 0.03454231078766527, 0.015177551052352835, 0.06039739518816914, 0.011788735263830712, 0.044629773530628414, 0.04668147573547979, 0.026713246517183802, 0.024371101228039593, 0.04926455567681021, 0.04067528895252655, 0.03747247835440982, 0.03285983997967935, 0.04449854649963879, 0.00830620202431155, 0.03312091125295528, 0.09284204998684507, 0.042238070013662504, 0.05297301494846902, 0.024384268364238165, 0.043679429969239625, 0.035063997511902166, 0.02014012594196585, 0.05765696461763113, 0.05825443275933785, 0.11002179385433275, 0.05674793617799879, 0.01822402513015174, 0.07275785995467056, 0.08252677567783864, 0.0256845647198779, 0.06054001011615319, 0.04232336241271227, 0.0693463095493855, 0.02690296627641205, 0.06115740420477045, 0.038936683051888986, 0.017333233413556894, 0.05764092656693632, 0.038583616110225843, 0.048235324211418636, 0.08219493703255731, 0.009538436255928491, 0.06360479465295231, 0.017806539770155665, 0.007458239889538457, 0.03545477896207764, 0.024637090785789396, 0.03813640462354787, 0.06066973944525085, 0.0481930629710757, 0.017979160446913976, 0.012463206733246485, 0.07627612640780788, 0.029654936046309532, 0.07206812035292387, 0.052055789368046876, 0.008596424858326153, 0.03197591049566625, 0.03992099495184037, 0.0950211181395477, 0.1657396443789044, 0.024344092798269084, 0.0509028883290387, 0.048986082716334256, 0.07048250987164437, 0.09454836528147421, 0.024207512727908553, 0.03447366930964974, 0.09237066076527681, 0.015245827680994428, 0.04937932713918629, 0.045028836391265356, 0.025398407897521413, 0.01489906851577783, 0.02260460972695822, 0.014509238929848277, 0.017366893401729967, 0.060372688852611094, 0.04452910957737796, 0.021695975822606878, 0.04755432184244837, 0.03584898482527464, 0.0536963475056954, 0.03341154585922918, 0.04662575816074687, 0.09617681539947949, 0.030522193541870486, 0.017050047097126805, 0.033808049986199025, 0.06836610771114789, 0.051625895298897266, 0.037448664511283564, 0.03436957711293813, 0.03155658460943209, 0.024767831350947102, 0.08391880340153172, 0.012345772157723625, 0.026802685367123737, 0.13074396658808957, 0.058602749955870455, 0.015800962761615314, 0.10106917545800248, 0.15838737599551678, 0.2679734190385188, 0.6505747355761067, 2.296591127111066, 7.87554762055797, 14.41507810546506, 25.24275645132988, 30.03820896148682, 28.56248386444584, 51.57860294465096, 66.09040767915788, 73.19887207400414, 69.29594116826212, 64.40440431717904, 67.61101645808067, 55.50997495651246, 56.73486055866365, 59.089624112652196, 55.04753535793674, 54.617941687184, 48.351786674991736, 45.65830292240266, 40.25213541523103, 40.8955688630381, 43.47642175612911, 44.632646268413914, 40.80518176478725, 40.4089831536816, 36.74772908610683, 49.25326108932496, 51.80715945459182, 52.9926017022902, 62.55369670929448, 68.13928127288818, 67.7096248442127, 60.531899236863666, 71.26161344589727, 71.68894783143075, 73.22730925775343, 74.97281889761649, 68.19109578286448, 58.65668858251264, 56.211820340925655, 45.78343829801006, 35.57122984240132, 34.49020108868999, 27.975320739130822, 18.484981367664954, 11.539800340129483, 4.097917320266847, 1.2897460378946797, 0.30916262658373006, 0.04968813718146375, 0.05796762093180611, 0.09977097818327528, 0.06356344122679965, 0.05574995343903861, 0.1269815938787595, 0.0787022655769702, 0.14810860577610233, 0.017504329575345885, 0.05580960487526271, 0.12509645834084482, 0.025085809550458388, 0.018759273525868213, 0.0541742216615427, 0.056658211960307056, 0.0377511351759876, 0.044995806510410005, 0.05406464810573286, 0.023826359087721478, 0.05293767914296158, 0.06251920975985066, 0.027148371051636436, 0.005140208175420882, 0.0339667757432307, 0.1319331955164671, 0.08850861235611862, 0.02909265432296501, 0.03230919513190466, 0.0201380766567684, 0.07494112626919824, 0.03847707626259616, 0.026920710787958196, 0.027161936553555633, 0.027677881448800047, 0.059118951490569505, 0.004543160903267562, 0.050121907655510216, 0.10820631869137289, 0.11126760603679765, 0.028913675116435177, 0.014825345959604509, 0.09659601105076653, 0.010536316530628791, 0.036573340109879934, 0.017041668010454987, 0.07073262225716345, 0.08028359362675298, 0.047902704156454534, 0.033150669938373956, 0.04538691737839291, 0.0704387739120472, 0.005461701282089757, 0.029990522776760405, 0.08108426275993548, 0.03110787159042253, 0.01974212602832385, 0.032508010270013925, 0.03819090028804156, 0.14665000501178926, 0.12041592925426461, 0.11195947536297383, 0.12362419822884184, 0.17378905277338721, 0.14463548488434286, 0.0916045498583586, 0.1999882332259609, 0.12199109029625693, 0.09533932041977683, 0.12138415713824573, 0.1902221750107504, 0.20232786574671346, 0.08675768776165863, 0.17169741823548273, 0.16563749421508084, 0.22084911383928793, 0.08044774328628856, 0.21405518565687442, 0.19847983674656963, 0.20618185491090824, 0.1302378582617929, 0.13037334857208113, 0.1451471396872113, 0.21130738149006523, 0.3021243929622635, 0.18531291505261777, 0.11696789008114608, 0.18155727625614215, 0.18262144899176014, 0.18664987637631356, 0.17702831766538082, 0.20830348945192753, 0.14163629662606025, 0.13113758256358485, 0.08587055794534185, 0.0779943390479011, 0.06726867143785761, 0.09364743056076189, 0.08025674224500695, 0.11363764458726491, 0.17747385908038388, 0.17760325133079485, 0.13975066313099477, 0.10502325400950448, 0.11956282906354436, 0.12421286785073819, 0.11519982809981993, 0.11959806144718202, 0.14412729279889216, 0.10493195931156797, 0.1328039310512043, 0.1362981193608815, 0.20104940289691572, 0.1874784157881814, 0.15062629245221615, 0.19487456568787176, 0.1527076767336938, 0.11614369438780893, 0.18541396204983035, 0.14271280337725917, 0.2594242148822354, 0.19647011232952918, 0.17312246434871228, 0.10515987046904142, 0.17624482422346072, 0.33120496799388244, 0.2324356574324831, 0.21879166214456483, 0.818824497682433, 4.195379393716013, 8.73115481868867, 17.345275917360862, 23.41424749743554, 25.054312059956214, 47.73016552771292, 69.01675470413701, 78.56987553258097, 78.67529315333213, 83.17304365096554, 88.65202211564588, 78.06675311057799, 72.65287814601776, 83.33458254414221, 70.44123403487667, 75.45765522987612, 73.34496467344223, 69.87118813299364, 80.95222119362124, 78.93819393650179, 77.44035059405913, 75.66362673236479, 80.78484581362817, 76.25137821320565, 75.76651050198463, 84.82301219817131, 93.83740332818802, 82.85894809230682, 86.85217980415591, 82.1821117401123, 72.39660616843932, 85.12712140237132, 92.38108219638949, 88.90161821919104, 86.23018603171073, 83.68232419413906, 75.42371888314524, 62.14704890404979, 54.90292933679397, 45.42531413416709, 33.792705612797896, 29.58840527842122, 19.191174699414162, 12.269134675302814, 7.3110562851352086, 1.732192457683625, 0.4381058268970059, 0.25345174745926935, 0.15344713544172628, 0.16052428632974625, 0.28619316556761343, 0.1376143043800708, 0.15212837636711138, 0.23249133670281982, 0.16960765295211347, 0.2677723056366367, 0.18336567276668164, 0.18417455436241242, 0.30219101196815895, 0.2267881185417214, 0.07455167015113177, 0.1496419460783082, 0.11527201656492488, 0.11124734301120044, 0.1896828797555739, 0.20590669145026516, 0.14231524970983306, 0.13925201650108063, 0.13756734319031239, 0.10389292192074562, 0.12244652190636243, 0.10245414751191294, 0.3680761975626792, 0.20793219727854576, 0.11958238728825124, 0.16094451619973107, 0.09481913139743191, 0.1589323862666084, 0.14819673653091156, 0.1012965273712912, 0.18205866548082522, 0.2209179238566468, 0.20553849427209747, 0.14386578102505979, 0.1458223849054306, 0.24631625131493617, 0.21783333211656541, 0.20884804007026458, 0.11576939914976397, 0.15009007687049528, 0.11242902597352383, 0.11201815769797373, 0.15445575148107546, 0.18325302719829545, 0.22441427253427046, 0.13934383979968487, 0.41092750946840934, 0.20951724851564055, 0.27440730121827894, 0.13886195517355396, 0.08687400289120213, 0.1861933952257518, 0.14544022960528252, 0.30956080844325407, 0.23421209275482163, 0.1931033857286938], [0.04958739661942086, 0.07999202822365108, 0.013709844375449805, 0.03377604666316221, 0.021991697252698002, 0.02287920053687788, 0.01811503380116436, 0.05551401751055833, 0.05373472851070185, 0.02453142810883301, 0.04686110420152546, 0.011742332360647138, 0.04470248293552188, 0.02924098235164439, 0.06560940926353778, 0.014728277831548646, 0.06160522856178784, 0.06913739737243423, 0.02599881398641775, 0.07568313605001858, 0.0186214083430147, 0.07749014594141515, 0.02295019007438133, 0.06902092902530586, 0.010707819676627556, 0.045290332843339255, 0.04015495437347601, 0.010376458878688996, 0.05878279977027447, 0.059196146340259624, 0.02333386988949872, 0.07355670579859326, 0.03681431689690198, 0.013886451582244087, 0.05871548362436795, 0.04486783918353819, 0.04313633108751909, 0.02863896173244763, 0.10430725291371347, 0.019927053907585722, 0.03276028685391911, 0.026103005774559516, 0.011103018581296408, 0.03369732346806315, 0.04364517817814504, 0.04290439030756393, 0.09789888912271108, 0.022192157564624664, 0.04684030874482086, 0.05775942887750365, 0.02324460915500118, 0.0333461525940126, 0.029743938226132628, 0.07420816398676365, 0.022937335119011904, 0.0823149906711713, 0.023001778435202378, 0.05302232802815495, 0.06050924019467446, 0.029241378802145203, 0.041028114576493545, 0.06114858653276198, 0.018843483825724934, 0.023538798409243746, 0.08903320638402816, 0.0589981624075482, 0.11272417666811137, 0.10507399967360882, 0.10992528209763189, 0.033866985130213925, 0.04756981214027732, 0.08176280215622918, 0.005858106775239351, 0.045491009575104525, 0.09038309161100658, 0.25105252861976624, 2.0952431184630242, 3.748759939785927, 7.853724533511747, 19.0131716574392, 31.58437982682259, 51.65622272799092, 60.202333850245324, 58.63998713031892, 66.8479585647583, 61.2814720215336, 60.42277889866983, 68.67717158409857, 66.52231554831228, 63.75470292183661, 62.35571115247665, 62.068703482227946, 62.60054157626245, 63.56274997034381, 56.62217086361301, 54.69030941686323, 55.78586270732265, 54.95712080309468, 47.97953413378808, 48.36533061919674, 47.40467548370362, 37.41758754176479, 26.72942888352179, 13.809730872031182, 13.120271352029617, 5.267839239489648, 4.834340358934095, 2.4579510621486174, 0.8761824198788213, 0.40684049167940695, 0.0867118297385112, 0.05060000014641593, 0.08058561613002131, 0.397534882950206, 0.17969393591967323, 0.002443745066674667, 0.042344085091064056, 0.012630799000391798, 0.031530210117418925, 0.03037165151908994, 0.052780408952986045, 0.09421365380647684, 0.039109451200572715, 0.04571468426635669, 0.05152755259205738, 0.060736385264223626, 0.017046741427733533, 0.044993213302786314, 0.08707035122619522, 0.01454170477846938, 0.019219675131382483, 0.04735094465075001, 0.037509518705548785, 0.034432269918221625, 0.03836629611830558, 0.08838533348734341, 0.011551171398511337, 0.06602161819295538, 0.07305287275343172, 0.02881138514156544, 0.0020574741985558745, 0.0686239575847022, 0.030444535208986174, 0.023059242690402656, 0.07467594493420855, 0.0489957737285764, 0.07680986752553333, 0.010913400328718128, 0.023965762192082983, 0.04797204277448116, 0.10022745933383705, 0.06025201468277843, 0.055903626846209656, 0.034107310742500334, 0.011435058324657863, 0.05102141362224376, 0.04197027631885102, 0.01702594405580913, 0.03501473805837093, 0.015155775003105163, 0.06521934793601114, 0.08344972010461554, 0.042345563640757915, 0.022909338435819073, 0.03503362212570445, 0.060054406133149905, 0.05356977445884578, 0.11001842306746591, 0.013625961578180714, 0.08183797070335957, 0.06282510866801586, 0.10779221752478231, 0.05814806145105151, 0.04188417952748076, 0.06788391664984726, 0.047024388181706595, 0.10400464818362268, 0.0695798667748609, 0.019371107731375004, 0.020739074548586242, 0.03520435248050959, 0.03627188834211519, 0.11327322422256393, 0.029937842740647258, 0.07551105738046669, 0.08726262397343114, 0.0711215727571999, 0.032431899434736663, 0.01941753074436659, 0.006192201549457687, 0.07762862399460808, 0.07509769931916269, 0.04064535406688529, 0.09429041581648974, 0.06566876575591103, 0.023314710030512466, 0.035329542738655885, 0.0745778933407799, 0.049866513093753215, 0.048110145444591204, 0.015350320158646473, 0.06469428659446778, 0.07715450750002939, 0.06223584149753856, 0.08444800927874543, 0.043638662600349036, 0.031698720732463465, 0.10542645374493254, 0.029978500942008632, 0.01705155629033764, 0.07619205591899735, 0.013321071033245854, 0.04134148284192047, 0.023633837361910173, 0.05303172792698588, 0.051767062320704424, 0.029978975916521686, 0.12329872577421128, 0.056153229783259095, 0.02592810215578685, 0.05067599606850455, 0.034181123314004754, 0.05828484261949217, 0.02907715636425682, 0.06771497894078493, 0.09658456569717777, 0.03972991730176634, 0.062331602488073616, 0.03391534826087375, 0.01123464972366609, 0.042620148705018145, 0.07654651714068267, 0.022561794988089995, 0.07444027330606215, 0.034576436174252344, 0.06722645233235053, 0.02338581639642437, 0.05019249882729304, 0.00425180186510026, 0.04769713595329274, 0.047725952350564545, 0.029717988912917437, 0.01645855252600966, 0.05859557171201995, 0.08560216670194942, 0.05281129378765341, 0.017605625551133867, 0.07219768880355744, 0.14400358492087934, 0.1800422454553266, 0.3222454165018374, 1.425424131654924, 6.589893717919627, 11.405440530469342, 17.849286756207867, 34.32280609684606, 48.13648385386313, 67.95709502312445, 72.16964214078843, 71.48605931189753, 75.23869283737676, 71.79627956882601, 71.7297326364825, 77.60953026433145, 80.14401681961553, 76.29915268190446, 77.70943303262034, 78.41926436270438, 77.26555408970003, 78.75618027102563, 75.1269131322061, 72.4520920168969, 72.1582123541063, 71.03215479081678, 64.67856230274325, 62.644554491966005, 61.60509501734088, 55.23831944311819, 43.92824742101854, 28.51436422717187, 25.77917587372565, 15.361607805375131, 12.68940487215596, 7.620980403115673, 4.2456965388790255, 2.4262534081935883, 0.46962816929144247, 0.1443859853691632, 0.11941905734279465, 0.11552806613185715, 0.1277886138808343, 0.056772864679054874, 0.036209318110899585, 0.022242792145979982, 0.018306580680092017, 0.06956979271865661, 0.03214897550342064, 0.06574808649959103, 0.06053557063663199, 0.02352720366850976, 0.042788668896161744, 0.020608703620852004, 0.010637848078453494, 0.07239316379831684, 0.10010790365237383, 0.05046801851882089, 0.046175930483807484, 0.01660422222959178, 0.05366422926946994, 0.04126108957514648, 0.07264075575456505, 0.05414277758269061, 0.02754200617932985, 0.04232446940976285, 0.06657542315341773, 0.04414660570722434, 0.00693334229928892, 0.0789089254554241, 0.032078031931192644, 0.016874911736757044, 0.0188325958011011, 0.027067439608095635, 0.03874629871138642, 0.09246532625008015, 0.033367928643260276, 0.02273044541418072, 0.034552629992005326, 0.05356201781861244, 0.02524123729897603, 0.07563527853738877, 0.05522147151491335, 0.050803802516912265, 0.060236999359462536, 0.04180808018352236, 0.04200277759903862, 0.06986603125809662, 0.017256783584373134, 0.07926011548167275, 0.03731661393577534, 0.03301853892363368, 0.014347220909962011, 0.020557354662507292, 0.08908963642053067, 0.012872551451437177, 0.06120326988879712, 0.021832728262750373, 0.05435357433593562, 0.05201828936415334, 0.006420556080317306, 0.07247709639130101, 0.05835665953195384, 0.03524305141200462, 0.17547490585955883, 0.3012163949108893, 0.18512471789313903, 0.20667713075395555, 0.12424524272641829, 0.09772423639773362, 0.1477103319860274, 0.1666775505028425, 0.18361598433506104, 0.20115647134521317, 0.13933769577453214, 0.19010467244492424, 0.13356896177414926, 0.1977578908084862, 0.16875125858331883, 0.1333893907646979, 0.20763271818718604, 0.21678236673676202, 0.14984554160506497, 0.12379017883851645, 0.1773141144264129, 0.18873869171065671, 0.1329871333174167, 0.19366198639956214, 0.0735214734149556, 0.15301411190340597, 0.09412008382740522, 0.10041964015052204, 0.19167417209715615, 0.20286579736538474, 0.1589210175218121, 0.17854734744516113, 0.082813338526795, 0.14459368712719411, 0.15396833570013124, 0.15416799353495722, 0.09723212449781357, 0.13305238868680694, 0.14885301341212567, 0.12480108548075923, 0.16715784166609088, 0.21282774426283377, 0.16164603823375318, 0.09042402368880088, 0.2434567208852499, 0.1701493384016137, 0.21835456301848735, 0.2298594876042297, 0.1389828591697639, 0.20363111920174093, 0.07504878460519737, 0.1777511829089734, 0.13862414616009883, 0.1395409848661192, 0.08189498296668453, 0.1988163025629136, 0.0846997993968187, 0.2175353239140203, 0.178290891851629, 0.20597559339817495, 0.1083049908160202, 0.11451406449440027, 0.06306675195153202, 0.12045677706238725, 0.2837850754299472, 0.16689418484607052, 0.2315655654116023, 0.21491059943312601, 0.1587543780765226, 0.15568164537750906, 0.13659467199637046, 0.31227401607940275, 0.13439765440360193, 0.10248588653461588, 0.24683830959181635, 0.4806934819827157, 2.9137616099849826, 7.407646611813576, 13.68054662981341, 30.083816320665424, 46.996992172733435, 68.35203063103461, 80.19003406647714, 77.94162165734076, 88.589154366524, 84.13431459857573, 84.39167699506207, 92.47131239983344, 90.09696052920434, 87.78182860343688, 87.45417733346262, 88.64340859074747, 86.65258607556744, 86.95679726139193, 81.2345455538842, 75.99214092377694, 77.90117417612385, 75.18362276015743, 69.39823658235612, 69.3889170308267, 68.29918061533283, 55.63824822825771, 39.87812565219018, 23.076821680991884, 18.755728852364328, 10.226121102609943, 7.037534704131465, 4.029673717675671, 1.627467380416009, 0.8583123465218853, 0.18875260386736165, 0.09617738230454345, 0.22692321048628902, 0.3568001800487119, 0.44101579655562684, 0.1800726897894375, 0.17869955379395716, 0.08358905617628368, 0.11731228490750636, 0.14243316596313832, 0.20578589470636463, 0.19742260476754558, 0.10402498781801232, 0.15345841225597168, 0.177345953040546, 0.1328566532221533, 0.12223717305929431, 0.2024686114201623, 0.2565713340957319, 0.1171977854063434, 0.10503310590021073, 0.15065937212878658, 0.15925296341940282, 0.21867438940511597, 0.1367467557710986, 0.1964316700374888, 0.09286675632240311, 0.15026811570409807, 0.1380333544746522, 0.19487470358369813, 0.10262737531335124, 0.12291437180172052, 0.0992416344102352, 0.08987163599099844, 0.12877417067366262, 0.13422793528485683, 0.2189963301944156, 0.16554747888397786, 0.12397860582437246, 0.22947219951498896, 0.1649074430667585, 0.15844268754364985, 0.11682856933123643, 0.16809162623699636, 0.13171646924268815, 0.08351892082681579, 0.25749238628533583, 0.19165189426031806, 0.11500567077629029, 0.20600073640384983, 0.24728164467359745, 0.21001224856703513, 0.1371744626592244, 0.08494585917721834, 0.13539652580455427, 0.17398831224249256, 0.18550400802445027, 0.1655758854242102, 0.18681633196050124, 0.1503032025310301, 0.15763474057518667, 0.12760959445468842, 0.0822039385656676, 0.11812189428676521, 0.18542470260252877, 0.19812941280824525], [0.01948346410156979, 0.03608799276633128, 0.062082198733884486, 0.008374772639194084, 0.0169887658088438, 0.05946181031064161, 0.04657592797171205, 0.0781054447795595, 0.08005942863922927, 0.05176168055303636, 0.020315293861072392, 0.026308489708049644, 0.021856476988403067, 0.006610969149117028, 0.017994585627269362, 0.019212770763964906, 0.017739853731566863, 0.001006700340733533, 0.09648703504353763, 0.03778573936752735, 0.043801008122822935, 0.04793595237236831, 0.021471753378488848, 0.07080926935398771, 0.08674927611625002, 0.021985298503310453, 0.07581333269275005, 0.05514754019978066, 0.018220677325922637, 0.030820594364476782, 0.048530850289089066, 0.05712306262144158, 0.04280218268714605, 0.031995865170873945, 0.12040630718993565, 0.10650420921944803, 0.0501879635867813, 0.029943272388810595, 0.10178850903626412, 0.03524320462958948, 0.004588801070161525, 0.008931659188331857, 0.0430797056985959, 0.059607401490211494, 0.04206207280437793, 0.02661625595553027, 0.02039793751112396, 0.00564093760687918, 0.014930469502184181, 0.03682483145366273, 0.003990015257225042, 0.057165867784210754, 0.029055317112755392, 0.051708540864168644, 0.01538840143175255, 0.025796892361775525, 0.03471961034642112, 0.023478149143498273, 0.01996665490761159, 0.03541664693564658, 0.024876958660541043, 0.024978396362595023, 0.03694958121125256, 0.02637441348915379, 0.028170537271146334, 0.03749958254517086, 0.09258341104272874, 0.023543783726411003, 0.0665569297909256, 0.05728441222961392, 0.03818348455693453, 0.0707658474904395, 0.037181843748135913, 0.10468687246283216, 0.0023989605242311354, 0.03446192518177052, 0.10902984022733667, 0.032656290418198036, 0.11324235087921543, 0.1516952302547232, 0.17538412444053159, 0.6652096502723233, 1.9489526844793752, 5.331093342073503, 5.831577479839326, 8.678649971562049, 8.541594513000982, 7.787684567513005, 8.675066886409637, 10.696939864466268, 8.831715564573965, 7.563395106023358, 6.409185711414584, 6.90109750916881, 3.6068936942085146, 3.3477865784398975, 4.276398401106558, 2.6156658895554084, 1.8589866281517091, 2.3246392607688904, 1.2639731240849341, 0.7170759477922994, 0.19251029577947434, 0.06154420582817928, 0.12392658845431383, 0.1288464893737147, 0.12492307732182166, 0.0419916233588611, 0.052045780429316145, 0.03199218028795815, 0.015995614211856118, 0.050213543262573025, 0.14226651119609035, 0.03929903880963403, 0.08925874266893634, 0.044190640441111984, 0.05593571826935776, 0.028110633025907224, 0.027137812444820043, 0.039050523717437065, 0.04109909262267813, 0.03955179802893151, 0.030125093781539512, 0.044785373648929025, 0.06319802494779711, 0.11119268263780302, 0.024460633923750252, 0.035634009062402675, 0.02510982449166477, 0.0863810176510484, 0.010659411538302178, 0.017178451094115456, 0.06148624744626784, 0.06008815613665408, 0.015789456120992622, 0.031642583724592006, 0.03942207636071309, 0.006049993605683408, 0.0864636478945613, 0.04615005586416491, 0.024030617280532757, 0.05998053610505116, 0.03205767697504452, 0.03406951579475596, 0.10019011254752837, 0.009779267486244922, 0.024233383517111504, 0.008022295585232637, 0.017970712412328973, 0.03771015713291784, 0.04510410069938629, 0.09337565320874415, 0.04552022050765734, 0.03951418311184934, 0.04297593142837287, 0.04026892144353159, 0.016398523791482853, 0.05399290780206362, 0.033322097433190194, 0.03556423760469883, 0.06350202778834971, 0.0326259303537588, 0.05200546888274051, 0.03486214483517312, 0.04611950810818423, 0.03833724223377724, 0.05748224294474048, 0.052260698735593795, 0.02658918049306639, 0.06125159471506073, 0.09233301520467767, 0.016943907530437556, 0.0772894002617367, 0.015678878990001976, 0.03392473666838581, 0.08500411250298062, 0.054570622366642764, 0.015629561122266517, 0.023751133083996755, 0.03787301210386138, 0.024413822121137095, 0.12198361327811597, 0.04607959109688959, 0.06505873760268574, 0.02901923245630197, 0.061181325300206105, 0.02205674769356847, 0.006282633919674423, 0.029255319687147296, 0.03552597151288102, 0.015384423520205723, 0.044650362143593456, 0.011689563266812794, 0.028942382346177777, 0.018466957356600512, 0.01759309809835207, 0.008547119439519461, 0.019053428306154186, 0.05692895509362702, 0.0637872921182744, 0.054550248258296526, 0.030729322649178006, 0.036697116935805935, 0.03127598767018607, 0.028934160307530436, 0.017442092592377337, 0.031035801868945844, 0.01880674224887644, 0.022170176586857247, 0.04947259451352781, 0.04464493441064993, 0.0395127811709479, 0.01628715375949058, 0.017152835029147325, 0.04087054944266716, 0.0456076771050932, 0.03506340379376085, 0.026458547180218082, 0.031939856482729796, 0.15342019979030858, 0.027298978191890547, 0.05827812785883585, 0.027219795344036915, 0.020294373915080103, 0.04607749967685631, 0.06467134992201483, 0.02087451506315941, 0.010125211725432065, 0.061722903497396946, 0.0459257836243318, 0.00992965246100099, 0.040832187589858814, 0.029004107965456865, 0.07700949471684233, 0.014753398812195707, 0.0034361042414656692, 0.047882291743712085, 0.01603180133256941, 0.015027877581756444, 0.07589942565368069, 0.0789772758200284, 0.05882273593376722, 0.10217870825961714, 0.03788544188043283, 0.09095827808543559, 0.05445957792201831, 0.021248067195917812, 0.12562975512757418, 0.07858523032477788, 0.018079652030381466, 0.05503956393729295, 0.06080129206360829, 0.0675060054767997, 0.22074667256205316, 0.3685673212091769, 0.5629420604917311, 0.9372467367399124, 3.244112941526598, 7.35550360333535, 12.3137741896414, 16.247513351901887, 19.856075279174313, 19.79046187093181, 21.403948453164872, 20.26414494360647, 21.85131830553855, 19.8097187472928, 17.909679489751017, 16.612567363246797, 16.09186585872404, 10.84517603920352, 9.954339092777623, 11.150156009581782, 8.999644979353874, 7.6819041275209, 8.16297253293376, 4.819991838547492, 3.1406052699012146, 0.9760544833637054, 0.31718108502607195, 0.21125764706202094, 0.15041615453458604, 0.10995444706490926, 0.00965954518065818, 0.07819555204121337, 0.21531265769754687, 0.10218623124303357, 0.018841005531289888, 0.03519155115129487, 0.0405370407257109, 0.03538866557421223, 0.010742928528587424, 0.04928136747630854, 0.09605495379336419, 0.07646830722449288, 0.034485118493678114, 0.03721574696922495, 0.04867643380777971, 0.01882689993738407, 0.01548905197846433, 0.05962007258447909, 0.06718218011120636, 0.0264429438844203, 0.02570267312318808, 0.03829404253572707, 0.03844559770978747, 0.029540603169270103, 0.0405372207563731, 0.059859770004667585, 0.05727554859232999, 0.07989497254452399, 0.023382139174387823, 0.058406708056047085, 0.06641607686516739, 0.056498497949853066, 0.02690528943804243, 0.07776959949443418, 0.06703869950386786, 0.02816454837879827, 0.0438539064939945, 0.10426145617759998, 0.035026884382410396, 0.07965097354064066, 0.02279700887870164, 0.09479305376448939, 0.009921174740508921, 0.010372773995773207, 0.04832870266850918, 0.03914245809879034, 0.06220715533521387, 0.020655634167093425, 0.012309755491573485, 0.03997416528422506, 0.06693497119892029, 0.04906369891438273, 0.018676378982021444, 0.07919796276837587, 0.046823623349830035, 0.067192139254222, 0.02378675808769561, 0.04065867633588853, 0.009330420401848612, 0.03453067008165583, 0.038542404410339175, 0.04404650482859823, 0.027713108086778272, 0.022376411286513173, 0.05167207124853327, 0.0763675130362953, 0.009155557002691973, 0.06471048169318708, 0.04754965253654988, 0.15538291705231513, 0.1203158092234404, 0.13460842051332997, 0.17105601878175813, 0.0739434729480455, 0.263353449202353, 0.23179490149261492, 0.20067702287868147, 0.11362066807886285, 0.17761293468215775, 0.1645511815384511, 0.13322975336303636, 0.14500909064325596, 0.17018730571914106, 0.12074215247506097, 0.16232519050038632, 0.1847635993673917, 0.08380539174522124, 0.23823420757487898, 0.08990808645443571, 0.06340353952480421, 0.1978345149226727, 0.09573278317768728, 0.15628090999539823, 0.22268800064921382, 0.10291125685457261, 0.159500838828183, 0.22305826626477704, 0.13037342518087358, 0.14020109218695473, 0.09935395056081396, 0.15251094535473855, 0.15056106772634292, 0.22934795537542915, 0.2548961909187417, 0.2128330149477528, 0.06596078315088827, 0.13516873722114872, 0.19564656781092768, 0.2159988426513249, 0.061142549759918646, 0.08038998025679782, 0.14665225731028667, 0.2672938071191311, 0.15002710444311942, 0.10620993186509418, 0.09891641476461965, 0.10692049373662281, 0.15901371416065002, 0.11491093634357376, 0.07405607255115625, 0.17281630497065284, 0.13027898186156828, 0.1377277926451737, 0.13432682191412296, 0.10646462545640047, 0.17857650475155923, 0.15680758012158258, 0.13025301148093518, 0.10450966866506685, 0.16044168672975034, 0.14316762977790448, 0.16700574256960424, 0.2486672985457605, 0.11094440886330222, 0.16322799447563388, 0.2172477498290039, 0.18492008048680522, 0.15093197685576257, 0.17920215343756063, 0.2194940881623376, 0.22705096330854202, 0.10892335400586167, 0.25310785059005986, 0.13910569370754305, 0.11391702919237076, 0.22341120297149306, 0.3757771585256823, 0.29936439267569975, 0.32134112631601675, 0.3212754572591474, 1.2917436274789995, 3.3393740750128225, 7.317078103942256, 9.807029577993578, 12.795335342807155, 13.454826974099683, 14.364145148184992, 13.856624768626306, 15.36233050207938, 14.677387591331238, 12.524635907142395, 11.299225687980654, 10.382993355874094, 6.94764280511487, 5.309492359238287, 6.393465832356484, 4.813872450782407, 4.251539889843234, 4.1064271475038225, 2.0754572124250474, 1.330221833721284, 0.38649687363255414, 0.20215613947760677, 0.23900959580656023, 0.2935098261842805, 0.23476765971750985, 0.19996908102785388, 0.21022572662801514, 0.2712582814837656, 0.21947423116334025, 0.13428030505536065, 0.22750890002615992, 0.1312293292533967, 0.22803293480988474, 0.13187966129231837, 0.17603768937049374, 0.22891143847617412, 0.22709150468149494, 0.09324713429856686, 0.10299792438144646, 0.14204996878341322, 0.13043607585132122, 0.19832533213400072, 0.15052579703830904, 0.15923564983231409, 0.2514688820848542, 0.09343667977279232, 0.16873048227881232, 0.16449769327957786, 0.11153906929276644, 0.13608125519127617, 0.14536522959749545, 0.2228379240559955, 0.13288152043617543, 0.11256238655938257, 0.13564452378740235, 0.10036504872503782, 0.20357934697981805, 0.15562374445219196, 0.10022179794407661, 0.1421548462202472, 0.14850645055693967, 0.10213504890881239, 0.1660011101874613, 0.18101033544348133, 0.12603441043005836, 0.1254569563353735, 0.1975596272536824, 0.06179098573122775, 0.10228976802600008, 0.18801787958270122, 0.13582415608388765, 0.09351226966828109, 0.14984548031803102, 0.13697797642840495, 0.1126901776860318, 0.2115396133834316, 0.12461514061977788, 0.12679800090770568, 0.14512918258626617, 0.09749329153208003, 0.15802743724517285, 0.12276327628041468, 0.11778283909323717, 0.16366000677789413, 0.12549080209986818, 0.1073886653889091, 0.159826104439074, 0.24254104663287443, 0.20611879055298146, 0.17480329189810062, 0.19182571961033731, 0.15863496029088575, 0.15038164993447645, 0.19554708363308063], [0.09842703779858929, 0.023893813129454374, 0.07668188487690303, 0.025888997197691953, 0.03867592970510164, 0.03641307068568084, 0.029890203563075875, 0.12552403499402348, 0.011709341741797906, 0.05767523581462522, 0.0612652272496733, 0.07978221206294914, 0.011601457409861108, 0.058733463707950816, 0.02688297521202795, 0.028525873748285156, 0.03583989136161343, 0.015090225647474009, 0.012959394220923705, 0.03887476399540901, 0.03556907544994066, 0.011064085992984475, 0.03007335603357323, 0.017426962355872797, 0.007245015595183378, 0.010128496327407418, 0.08545054257997582, 0.06418208020829386, 0.055895916171251774, 0.04531747150805689, 0.06174355339739592, 0.011024384443918544, 0.01369875621035575, 0.07917656593265072, 0.015428450593214123, 0.02545706533466376, 0.03292583845435612, 0.034226808967369224, 0.05360219146936171, 0.09297751731449559, 0.023480556574800325, 0.048864370497364196, 0.04800184742517529, 0.009894381772967116, 0.03440927195873472, 0.016282116731388435, 0.05044041637090906, 0.03672992082072362, 0.08863984321754786, 0.0567258536935814, 0.03199578856208152, 0.04487509786662075, 0.049833398943226186, 0.065830372003538, 0.033321040231854684, 0.05508105142883236, 0.09866836315561688, 0.059741600942347324, 0.021439462772480423, 0.03188411017969972, 0.041610624851478685, 0.01105007520245929, 0.03770408971655754, 0.04883588734833945, 0.0626021004732578, 0.017010470994958476, 0.07005443526131493, 0.03359872029132901, 0.022674191577900803, 0.0645184847376039, 0.039407160628827355, 0.08343722521057052, 0.058008614296634356, 0.02297829592510337, 0.04964425566516096, 0.049284906802518715, 0.046361829379513386, 0.04609966260050574, 0.11103614023135555, 0.13351101488355668, 0.12573518414771365, 0.07582832503342822, 0.02249700118667416, 0.2619012222895699, 0.0914951601636506, 0.296068866286547, 0.21917055391015547, 0.3314390231765086, 0.26850103911372925, 0.3713172704221741, 0.3342084923098165, 0.19621687430527904, 0.18594122972459565, 0.367185237306741, 0.11588708557669194, 0.12357211191087, 0.17988208711387652, 0.1871440796962669, 0.04974376282564575, 0.08669502943033174, 0.05831820574859458, 0.022418511648392005, 0.023038947106068654, 0.065872146778049, 0.0542982857704403, 0.05904418897003897, 0.007116984108447909, 0.03546103023953977, 0.03784239156952789, 0.05029623862355948, 0.12361367218076222, 0.04500218419237964, 0.03764978940448454, 0.04930994638632383, 0.048379597719758756, 0.022022559104727644, 0.0437289115882689, 0.034203569690186175, 0.05215273396442494, 0.043944802826210376, 0.06823547439829958, 0.04214502480481902, 0.0901131145656109, 0.04498091759160162, 0.04400514374156633, 0.03872243124210546, 0.08306331301648771, 0.002736247012264005, 0.10096938484498572, 0.031500574006068136, 0.04987082999920653, 0.08170343034209744, 0.03011244183947002, 0.07549044195442431, 0.07034511966330391, 0.0037139468552214246, 0.017590351673143528, 0.007561950957507737, 0.08050169119791639, 0.006745793441716101, 0.03740438079882053, 0.014838558103468631, 0.012950727851280283, 0.04418744968490736, 0.02072939502766296, 0.02363558212715772, 0.03435194942980044, 0.06477945258901005, 0.08557155382849517, 0.01817611590658705, 0.021749058054880272, 0.013352749726524758, 0.009844503703437025, 0.025853492852841175, 0.02550506457355955, 0.01936446191863187, 0.07071075044692525, 0.03240396403857777, 0.09325157760852769, 0.011389876374103611, 0.061825107287375204, 0.092820024959022, 0.020195471964055495, 0.0371556397106859, 0.030795575848089594, 0.013710074201827089, 0.05380202933484989, 0.01607735100532732, 0.12822902250674464, 0.04405033526821964, 0.01604107195406311, 0.03437160724593747, 0.06013207212691346, 0.019384859009615837, 0.07649886647179242, 0.0233347432297324, 0.02185828495590437, 0.027469118658993995, 0.038758276496082544, 0.075963233116894, 0.06789847232040859, 0.04705210907324668, 0.006041057668851629, 0.10419726567042452, 0.01920612112078215, 0.0299426288749542, 0.04621503161146276, 0.13668982011656608, 0.026044059139225754, 0.02577044317618974, 0.021424650462464463, 0.05553362553098029, 0.04194466599954232, 0.07898972474879797, 0.03085685522115279, 0.03145080701928706, 0.034695930568681616, 0.030068273040195628, 0.05743915049899971, 0.0777705341217018, 0.011014946240691409, 0.07711390484004252, 0.0548756517650139, 0.01634647386268743, 0.06396610087024109, 0.04867939473760705, 0.015757663472134982, 0.0035538117358115537, 0.030854704429305373, 0.04125702164826855, 0.014619886923971918, 0.04955431311241081, 0.03356756732588814, 0.06804890900609956, 0.05089559134155993, 0.13980021369793724, 0.04293832034173031, 0.07761363931480916, 0.04571967149874376, 0.032120689622036395, 0.045709440394514994, 0.037523112935765136, 0.08784679665921197, 0.056076057916206706, 0.06009052334834011, 0.02029603632587579, 0.013729923539945196, 0.0707152167395238, 0.06431108941474269, 0.10840878040800173, 0.020520976977422833, 0.07111290830277628, 0.010506982066398187, 0.01952777079667055, 0.0260216242543632, 0.05794758007170693, 0.10307171397031316, 0.04341463167821208, 0.014092154808402544, 0.04390894991135405, 0.06699903147114862, 0.02303259432195656, 0.07202460655882474, 0.06840346981921504, 0.01635686009972086, 0.03930379621564381, 0.06952360527770174, 0.06068297744458241, 0.05127061436313295, 0.114186140558412, 0.02392082155922488, 0.038716398299701756, 0.037311301116020455, 0.036808387376368046, 0.06103546982030235, 0.18031955396215762, 0.05723297708637773, 0.10955548379570247, 0.08217708718392157, 0.18371058087195122, 0.17491950743621396, 0.1543724317584307, 0.09889344744864972, 0.1679869326612642, 0.1229862078663803, 0.12413359307233365, 0.13738135236405558, 0.27211850629218165, 0.08534165850329785, 0.0739704085994632, 0.09479562015903574, 0.07834410415061059, 0.04398209215592473, 0.2897098155752305, 0.1514101076510645, 0.055284290724704345, 0.10758597133380753, 0.05557292201105626, 0.09343255055888046, 0.07312680789900404, 0.10758204130275596, 0.10251938755954466, 0.02177986053509578, 0.04750032796554508, 0.030760642238742406, 0.02923047737098269, 0.0922045192771381, 0.04633122416693838, 0.05213232921256174, 0.03715820610523224, 0.11988050274310574, 0.034300767095579256, 0.049121917766188426, 0.05601395499862491, 0.05246111116702518, 0.02812523849218363, 0.008175704692069801, 0.01665364639202674, 0.03250651256812196, 0.05262493140875332, 0.019288919903638384, 0.01734322320008951, 0.06845376349144405, 0.08244688802909467, 0.046251957049413074, 0.03879571521294214, 0.02451588418484936, 0.07448157310606011, 0.023045359261994882, 0.04123996470063444, 0.03333429355294474, 0.06954591375805678, 0.057966249634421645, 0.02824408171187726, 0.057463209490261735, 0.038912585756230744, 0.0813624446070002, 0.025524923487776713, 0.0365115704405452, 0.030662069705525236, 0.128090774279929, 0.025949004864800843, 0.008403835142211569, 0.1315364845457577, 0.010927026160061361, 0.06544344397562166, 0.05519670389232136, 0.03717121427818652, 0.026166204197873032, 0.04386668101013188, 0.04675005209602175, 0.01911554079983504, 0.051853726017138654, 0.0176338731281219, 0.06513125548559813, 0.05248521229312305, 0.05180182739070827, 0.054692702307816476, 0.030490460264826977, 0.015333038172684612, 0.04255397019967918, 0.009694126389560201, 0.027639914131272706, 0.030053633099962628, 0.06373184650475461, 0.13903869165768548, 0.027150745924201705, 0.058290864070577014, 0.04830428744636236, 0.02169516185418733, 0.04470249059640112, 0.031186627344258373, 0.13087674494712584, 0.13626335429087763, 0.12944345572783103, 0.14058945279928947, 0.12383957618787406, 0.1483539377729739, 0.16301903633340714, 0.26807227502426795, 0.1077311679780964, 0.12034119737725105, 0.1611833211274878, 0.278022010480204, 0.1478306384336564, 0.16051181441833898, 0.1561099498142158, 0.08245140794784793, 0.10833570328090461, 0.2249185882148243, 0.1845363930108086, 0.07814199483442692, 0.11812459091625868, 0.1101484971361295, 0.19756411652891867, 0.1472659090593938, 0.15994147728047065, 0.21518611529421425, 0.15090186960033833, 0.15760665579188257, 0.1807257797448866, 0.16889188168269975, 0.08786520575203242, 0.10116682102483127, 0.18601233800572736, 0.1006051560022658, 0.07321973436421926, 0.12020994353318408, 0.11871145257065374, 0.2283666580314598, 0.13752030539176158, 0.20954139560701388, 0.10694241917301571, 0.2540667628448817, 0.17702028906393438, 0.08836751428222464, 0.13306843056794138, 0.11320211594143223, 0.13621858411258267, 0.17455750024847447, 0.13685117355517804, 0.11291456483905354, 0.14295323241141536, 0.22676452303365355, 0.08104282506411115, 0.29047758889294445, 0.13066823113589518, 0.22399310803701802, 0.19737945869565013, 0.13614761372727735, 0.14371313034526764, 0.18720562720010359, 0.2390701167525784, 0.15159591461621946, 0.1820741251351372, 0.12787070020192093, 0.14890254865730965, 0.1191433959250008, 0.10876570843280324, 0.1646182755188596, 0.14441148077528324, 0.15214927524568575, 0.18532966173464255, 0.1518407563168195, 0.27154452257579376, 0.1870929663099589, 0.16512076791015365, 0.18684527476228055, 0.10350021758988019, 0.14779694588674655, 0.29397248200351195, 0.2850019907759082, 0.15472759012012713, 0.2176325711151285, 0.1296811421672183, 0.27771346090782073, 0.28733613810712294, 0.36344127369023144, 0.43261453929928045, 0.47566944673176736, 0.40646480216133984, 0.46890418555948044, 0.5096922081805045, 0.3734492624719297, 0.4435483606592302, 0.5054868757724762, 0.2703955439069579, 0.22104135594300686, 0.2764432871293637, 0.3543069622208995, 0.2217469075995107, 0.21932412389545672, 0.2076760940854588, 0.09119118413617534, 0.17691536566182492, 0.27634639232870073, 0.23736774681075928, 0.20242347351966367, 0.16619034922651707, 0.13798962617593427, 0.14068328324825535, 0.14906103692708478, 0.37923255214287394, 0.13547011621056065, 0.15682706939837626, 0.23968203714297664, 0.21463597223402994, 0.07236265051629275, 0.133634738083328, 0.10841086416715577, 0.2109571260910842, 0.08557579029471644, 0.12410884077150015, 0.18871092868428077, 0.18436488124632067, 0.1728004929158957, 0.19845788066665973, 0.09528459875934547, 0.18072063163403543, 0.20206831515796725, 0.18587868630645737, 0.10941193424045079, 0.16205165114614273, 0.23767196032549107, 0.15941678366113096, 0.17962175511544753, 0.1388653259604208, 0.24836723722757834, 0.10795359394603199, 0.09234045391842242, 0.12452803642278719, 0.19005354373685776, 0.21227521100832572, 0.11895964207548289, 0.10548807785756166, 0.1028728452060492, 0.3347192584506927, 0.156053826212883, 0.12111005087893818, 0.18482605085497905, 0.13145437524203332, 0.12848118800790082, 0.20415176787684042, 0.2028095205464671, 0.11023131124074421, 0.09127363817946565, 0.1318119237980535, 0.1621764621907665, 0.10934916865681449, 0.15250354494539, 0.21027533848199154, 0.1214071321150949, 0.17463308248308398, 0.14450866668935747, 0.1294053505144773, 0.1381721083194979, 0.1440243765471443, 0.08109470453834342, 0.14119840076854154, 0.1071163441144651, 0.16472401097416878, 0.17547173425555232, 0.14801335040359728, 0.2132984133617532, 0.10651611422579135, 0.1548615635763253, 0.11984152418951835, 0.0838309790818922], [0.02964182062104585, 0.06800402391461596, 0.04310025983760434, 0.01273681407779335, 0.0019344200090047033, 0.043487831379377076, 0.013140505067102853, 0.040893769567652095, 0.04025043574191871, 0.03167578022957089, 0.0801615558204151, 0.026839825309692856, 0.0364357392273603, 0.04301012959331275, 0.025148711114701246, 0.06602069888744624, 0.0336771791860942, 0.0267411302024078, 0.010271564204876703, 0.04604094962198888, 0.10275836102664472, 0.022870970837351297, 0.018268197759865754, 0.039119954266014605, 0.0327056264805217, 0.03633048257700378, 0.02834762998616263, 0.05739542220028178, 0.04321185203509466, 0.02400404169043947, 0.0688685234936495, 0.012617335005122568, 0.008041935206781472, 0.04203516013559796, 0.04891706585523583, 0.031816985555774266, 0.02386016080216054, 0.01510100163173892, 0.08624649261154475, 0.03808387397457996, 0.037547125961751714, 0.06275506524909889, 0.010847086800382504, 0.06143528344710508, 0.055479957241444826, 0.023585560416141828, 0.015090706367646495, 0.007874584257332309, 0.04491982591007987, 0.04459265274025741, 0.03924171245026012, 0.03292027665602584, 0.04655379186113996, 0.0237047158166646, 0.02901076335429905, 0.00903804294554697, 0.020610354540328828, 0.07413710933178663, 0.07978857059272067, 0.07402975743095722, 0.08748494268905732, 0.03339405607191786, 0.045708321906145544, 0.028578774034676534, 0.030973631918670672, 0.01607580542294008, 0.048431450380913676, 0.014292042469605805, 0.029522067671942136, 0.007949837552939333, 0.03108479127648377, 0.06362841697409749, 0.01862098124899691, 0.08230043500060998, 0.027312798418044567, 0.03321733873998446, 0.12079469844578736, 0.08353028957161211, 0.02827557941688405, 0.03212237310025, 0.027550216726658326, 0.10371685959398748, 0.03899572161777366, 0.11300275688089671, 0.040144351716603965, 0.10760407399145827, 0.07771850142988466, 0.11177669444511976, 0.1083002640535274, 0.16978886338972277, 0.08494213598990634, 0.07991905068798412, 0.05420598366688337, 0.09055119428423145, 0.040159508766185854, 0.02784232222174685, 0.07786073331390658, 0.06746416175437552, 0.057592092292203065, 0.12651602692541578, 0.08895322680473329, 0.04984014434739948, 0.05588709083836406, 0.10657906367052948, 0.10093210700659022, 0.049450374133284056, 0.02992738564048083, 0.03305988085846747, 0.01581008399596378, 0.044008326836891716, 0.02398538744948324, 0.03794566405216052, 0.05276846947268613, 0.023593179160548795, 0.05205324978657788, 0.029848526464775208, 0.06475100774438151, 0.02667054669150422, 0.006763308605689917, 0.046459827346787344, 0.025726511864171877, 0.0517227441342848, 0.04008926233396896, 0.02306941825325691, 0.07250103663893477, 0.032985041729144515, 0.016833498938790253, 0.0740272140190486, 0.07183315352566781, 0.022975199014669465, 0.058002611997747616, 0.06742323733746045, 0.0362013201529701, 0.04782131114493936, 0.005961034518306054, 0.021699053580842672, 0.052865831586982936, 0.051838752828658595, 0.04679469970024882, 0.06295217584157664, 0.046560334252013315, 0.03123758751298151, 0.028232919810820493, 0.033210420966028206, 0.030157369065789447, 0.06618612791381537, 0.027590823217084812, 0.0709162918370097, 0.0255892442298993, 0.026638790431822983, 0.018950877861390193, 0.037646265400032845, 0.01738501521157882, 0.08342489885586886, 0.018944222472548004, 0.011911167605449597, 0.05658834474161268, 0.020166192083589492, 0.04652108756765243, 0.07530318708309243, 0.00492698340226085, 0.044482336079161015, 0.05877306662319649, 0.023888733966516393, 0.03412498439091348, 0.03050432071059702, 0.010312875496193526, 0.05751274473544571, 0.03169699320419422, 0.05677262336135872, 0.03724714508280158, 0.016943796447688536, 0.021262063622294415, 0.06764825268258011, 0.023575804286426114, 0.03707571758798534, 0.033579495314869194, 0.04957616577045091, 0.01396411374556802, 0.0060566111689343335, 0.06748981037808043, 0.022514688241625988, 0.04518756214829703, 0.04766785990326636, 0.055872987159678054, 0.07764875678525818, 0.029363209764743527, 0.027269922392142397, 0.024930161551662514, 0.021259690664948958, 0.045799080342535055, 0.018087129048522443, 0.06263952003791928, 0.027207687324393662, 0.03222626994454092, 0.019745037162436113, 0.05086305941785536, 0.010025190328428102, 0.042641775367120584, 0.03388454769587806, 0.01929890777495119, 0.01932159929926838, 0.06147894662834945, 0.04886774894511027, 0.03546505220114224, 0.03401256864890456, 0.0349887638472982, 0.0644046593938143, 0.06279145825594183, 0.06288643017591489, 0.03749011369842676, 0.05082738653366124, 0.03665155385650935, 0.02458554072936456, 0.05572288755267378, 0.05424154163788884, 0.04519878150594812, 0.028060159323016004, 0.05384110364942782, 0.06035839365194402, 0.06560126574890268, 0.053050022106617696, 0.07798121596175818, 0.0381889199507573, 0.05097911024706499, 0.011938990003639653, 0.013241679426432859, 0.0022257739000187647, 0.03255281875270509, 0.06398121578498714, 0.07310545702855434, 0.024363204776760072, 0.020294573097940416, 0.0269344563205396, 0.030051961113067887, 0.02065163518812868, 0.08687213363666689, 0.016337776849527034, 0.020742305524406895, 0.07811080739502946, 0.06061217176818079, 0.022953183562945456, 0.01090433080530455, 0.07178949417486306, 0.04105272132062143, 0.009921404566886205, 0.021359249536368637, 0.040900894185347904, 0.06040215642461854, 0.02693970976848035, 0.04296629787272504, 0.06219795461924327, 0.06802896773743053, 0.10371772527334192, 0.04128988682022018, 0.061101548734211156, 0.04578167865533502, 0.10738153311033403, 0.031223868793477456, 0.12488033727652605, 0.034378402445825844, 0.06315552622019764, 0.1034763616119181, 0.09448010684742082, 0.02267128427422816, 0.05252318727152963, 0.1019950233580124, 0.062288843290579904, 0.01681988364115598, 0.12705426497925676, 0.06722319645867234, 0.024132639124629, 0.019031700137401783, 0.0532143556272551, 0.07960005933719297, 0.02439897533716454, 0.09881729830897625, 0.05758961399776801, 0.007521127568437688, 0.06442850771089716, 0.1144337478364187, 0.06998399347667733, 0.07855783502060561, 0.030962902857291124, 0.014444186573758002, 0.05139987254815717, 0.036550556655011834, 0.038410001434385777, 0.018662415114381624, 0.007864349801468874, 0.01661202675032039, 0.02774308319203556, 0.04160628496338764, 0.029754088891129342, 0.029755816419398593, 0.07560690264067343, 0.04657000994249698, 0.04658771806486672, 0.041806812308007674, 0.05542362679637248, 0.013861674383553046, 0.034133510949510726, 0.16934836283326152, 0.04978333509737446, 0.026892409584815466, 0.03154047378038447, 0.023382656283736713, 0.007697826226977933, 0.04752839742709072, 0.020675946988405722, 0.03706826738292172, 0.019092535179468895, 0.0025197378765310975, 0.02458285559118996, 0.04788301569680053, 0.08524177595973016, 0.021713258766178644, 0.08008965080784214, 0.016624222870074933, 0.0762121657270097, 0.013129472443383309, 0.058783018105332895, 0.04201395482185387, 0.05447326408278558, 0.03853853949676118, 0.05442119691701186, 0.00672736806952725, 0.06264333898622183, 0.0760943643868931, 0.03386607731602365, 0.012128777753171182, 0.02685628279352621, 0.054850447472305074, 0.052697284582761995, 0.019887510364154176, 0.04766974830999971, 0.011189190066239287, 0.0673894911643959, 0.02785196343827392, 0.0036802423381877523, 0.06157304903852844, 0.02108852364002697, 0.002053163038761986, 0.039560255639615564, 0.02296730830904938, 0.009129798253847948, 0.054948184969684774, 0.0842606548159834, 0.03840391486582737, 0.009544579323471315, 0.05809578361109861, 0.044867203330561045, 0.13631190894351852, 0.15754728397775083, 0.14589833486224377, 0.1102657775364576, 0.11104342572751547, 0.19680417262979094, 0.17740097347526781, 0.12993926783242535, 0.2232312335963211, 0.1759528681155174, 0.14277370736723946, 0.1133134668212264, 0.07596691033893055, 0.14545818670622765, 0.0923741311435738, 0.22307859823828746, 0.17675001324424822, 0.09026421008691674, 0.1121973763069799, 0.13679517252791312, 0.1788852228632858, 0.08923045104189266, 0.14272573494142102, 0.14906235459831454, 0.14469428979341062, 0.12383171612577093, 0.11479118914012948, 0.2474307560271794, 0.13152995747664284, 0.14335421815274224, 0.1337658923359648, 0.2276203964626597, 0.12544832252446683, 0.12547633069897854, 0.1433232835223598, 0.17281929271355753, 0.07531612630813353, 0.15949366824521174, 0.17409553390837487, 0.11987593685907703, 0.13888047917956306, 0.1647348741009351, 0.15497063917498435, 0.21461902636914484, 0.14726030129578807, 0.09718016075390963, 0.13319160218440718, 0.13441437044210974, 0.22032779100681507, 0.14649568426032222, 0.1428883600859873, 0.14152692991398996, 0.17825880808936012, 0.17398190774744557, 0.15371333567365525, 0.17085265308137865, 0.09380512209909578, 0.16882693274847924, 0.12625414742937974, 0.11471985103262049, 0.1746061161881493, 0.1225436082290065, 0.14225350302313605, 0.11163654632025188, 0.2646894146117472, 0.1704511770437802, 0.18125658674586206, 0.09377732842920289, 0.09607700180382499, 0.12168314593333392, 0.1518038308788692, 0.14186269092944362, 0.1157016080293444, 0.15971811668526742, 0.11579464174686901, 0.12460513551148678, 0.20115472466474582, 0.20134060823869324, 0.19903548031805024, 0.14731378955466135, 0.15651980685370584, 0.2711600077248389, 0.1805006877909745, 0.26933365411335425, 0.20695935754526049, 0.1424704744450508, 0.24406217549356723, 0.36674075309307347, 0.2159706352939529, 0.3086975192831409, 0.3652823668333792, 0.17065624345935163, 0.14141235380403458, 0.26674047713318183, 0.26101121198265786, 0.13486927345154748, 0.20607857093695672, 0.14267106690714437, 0.21018224347743297, 0.2127695828676224, 0.23694298170026273, 0.11137241452571847, 0.11313083912095717, 0.2724952683333428, 0.30185007219833715, 0.2870202340906666, 0.17721674465123685, 0.18093824656980653, 0.11776088301332728, 0.2336270773723241, 0.19994179297599102, 0.12679257700520177, 0.18836185306070313, 0.14724513275488732, 0.20561956169624485, 0.07108491545002307, 0.1681073616829611, 0.1495148061263946, 0.06588697824026309, 0.2605449402284238, 0.15005143539559457, 0.12264339118114403, 0.14320513744267727, 0.12842812109738588, 0.13221670933548482, 0.16307983307107804, 0.19367531632944462, 0.19168874308947595, 0.13895184793058904, 0.14616559229550824, 0.21700186624882684, 0.16604975677065312, 0.10157634098563464, 0.12187635330783746, 0.23084121395743665, 0.07205979297718695, 0.1745677045396259, 0.1869818069521458, 0.11957056655157959, 0.160789659186717, 0.1424799432917949, 0.14536374338692234, 0.21084123230989904, 0.18866055074238008, 0.20789635968544792, 0.098360518384124, 0.08832309650437487, 0.1997736826418869, 0.06824244579841053, 0.11421827028595632, 0.08174322860976381, 0.18194814963686853, 0.1444857300169045, 0.2882331351359045, 0.12369036524286195, 0.08938219007705489, 0.14470153698517432, 0.1336427053977405, 0.13988175609659764, 0.17791849651163627, 0.07595702780470734, 0.15973025151798803, 0.21265911298894116, 0.2240108046680689, 0.12286188711802806, 0.11664490741226943, 0.0897189470068101, 0.08804044070383234, 0.08023767431657161, 0.09729921847822205, 0.16935332708301085, 0.21133489936830538, 0.17581869547645892, 0.08134090987544867, 0.11012385208760539, 0.15643199785582482], [0.052495845593512065, 0.056604516857694236, 0.17947990627538774, 0.10715949784723983, 0.03863130125307268, 0.06116947008957786, 0.06147418539190005, 0.08525355839200559, 0.03570360431988393, 0.02220831244372793, 0.06134702628778835, 0.022770234105748036, 0.025521759544649435, 0.01881836954834721, 0.09120143439260223, 0.06361976401099274, 0.024795941032108762, 0.010468312820810224, 0.04914756638989334, 0.04133671011415221, 0.04750969722085903, 0.03925654774291381, 0.04946297244919885, 0.04263796791013691, 0.01723123646731819, 0.04824227262889186, 0.017312014693274133, 0.02893938502717403, 0.013011906675303416, 0.04168608451202031, 0.0724532557350974, 0.006937283821659344, 0.008381355249683463, 0.02584072216714342, 0.058519935851255735, 0.039954599398638935, 0.06288541893985483, 0.06240068446664561, 0.01348225114446494, 0.02833006359005888, 0.050699905672621344, 0.021567179205557032, 0.08283840492367744, 0.020288478868502765, 0.11259917410150652, 0.0230705616394839, 0.02984277122924405, 0.033597862272853815, 0.045386178103545984, 0.08623821886196252, 0.023504178895945513, 0.027899579633207574, 0.06193337083283452, 0.10021112633929138, 0.023339424026949752, 0.050142906125514745, 0.034273850596359665, 0.020060650065481182, 0.05156106127786541, 0.09322480283557408, 0.023140122423008568, 0.05495504528704671, 0.03994636395345292, 0.02150992179409631, 0.01856451482331801, 0.04250294108304285, 0.007935120046304, 0.09181688644833143, 0.059090732641878634, 0.07995953843478235, 0.034261374854512756, 0.08241508005847854, 0.029916727442234278, 0.040392709760776455, 0.03615277316120844, 0.03443763253369159, 0.03469590375560426, 0.03085335611455864, 0.0719083756989529, 0.05759497661323798, 0.0234587709494536, 0.1364664288778459, 0.0383138612303282, 0.08788533854268252, 0.02068053777029197, 0.10261560820283429, 0.006847672601936446, 0.035821053259555376, 0.12052701200328528, 0.011350527225482849, 0.09413552049907947, 0.11202201878111209, 0.013359930843204982, 0.12139045438098332, 0.07420958124942358, 0.06199077763144047, 0.09260090083004006, 0.03972972961022489, 0.1926467053952717, 0.0955574639562157, 0.0157636983297585, 0.09836843973326106, 0.04628724305920544, 0.022281381909945802, 0.048484593900221015, 0.05265381675393832, 0.04540071845234883, 0.07329872569009181, 0.16473787716559826, 0.023063879437564362, 0.08233739874295651, 0.02514039523028318, 0.03528945718801791, 0.0340159394357714, 0.05032986222255615, 0.035206486035378716, 0.028594097708381956, 0.02274495320424678, 0.05832436892594542, 0.05535946310227437, 0.053905409069791924, 0.041689957086477554, 0.057875755498366016, 0.042961678362541625, 0.03882379999624626, 0.03714069333528319, 0.03456484143351836, 0.018951971451902104, 0.04239602585233027, 0.06534122486388491, 0.03370786866834087, 0.017772525466317614, 0.013632732837821447, 0.01947841558214878, 0.11711832676683703, 0.015142339736133095, 0.03764976642184681, 0.02194803790189326, 0.035485230957067786, 0.0419745855634251, 0.07973964821787612, 0.01870663179415128, 0.02130417164505249, 0.011087854828445182, 0.025586310113149307, 0.024610055542941538, 0.08297019502929143, 0.07636847830707989, 0.03862942050721857, 0.03805367861904445, 0.06274421744409107, 0.03822222179282577, 0.021573629665879474, 0.0967575483504803, 0.02579667019627748, 0.03294974039759367, 0.01320086130421729, 0.057974033087732336, 0.06812399328355828, 0.03461652172489032, 0.06973769620902116, 0.04721172732271014, 0.06499582646234382, 0.04727944183433729, 0.05577265645467466, 0.06239106623275627, 0.04935457483835278, 0.04167655820868189, 0.06201250388497307, 0.0194391708130077, 0.033066243218678626, 0.02032716822389874, 0.053244144956190745, 0.02142317765843003, 0.026624179219887145, 0.04108589292774278, 0.01257598349418972, 0.05578020242072883, 0.0835271179676056, 0.06333299814873646, 0.014148022727890602, 0.024689420336677183, 0.03153923271794713, 0.06508162830986323, 0.01541015928641202, 0.03858404128902382, 0.018783324856250998, 0.05189075104651913, 0.0591989157481059, 0.008772498676403156, 0.019133319785337777, 0.032328749526171915, 0.062216670147233435, 0.042327821044431585, 0.044682851932462186, 0.09403198371611296, 0.03482637618998847, 0.028323806566937317, 0.01323056923631098, 0.05138272750041178, 0.018138667613628413, 0.020426581538612806, 0.021271183899032976, 0.07413100361103013, 0.003399996123569567, 0.02142705406332689, 0.014281808492547322, 0.05077784362759802, 0.036639254314885024, 0.050120482731971054, 0.03345005326874314, 0.03224815324609799, 0.05763587038663607, 0.02436445541529646, 0.05008338875467739, 0.06282750652321885, 0.01428698054364612, 0.04555803460759982, 0.08928233051612493, 0.038529672029037634, 0.04608686127129101, 0.06515344905276453, 0.041476938678252126, 0.034973177788478714, 0.05228786038294916, 0.06060626523028459, 0.02015320497805313, 0.03399629311095323, 0.0378117710351944, 0.08127619842848471, 0.005586879091307281, 0.07801579717066019, 0.023603163201421983, 0.026795848032399535, 0.02554587024684635, 0.06538004253900821, 0.029197951192937555, 0.030777051842080492, 0.054688891020393184, 0.05527200650483851, 0.02165815214656534, 0.04280472226861504, 0.04375747900696532, 0.002967238561400483, 0.03344080275705746, 0.03275134277740314, 0.03855177366565313, 0.005399982366080006, 0.012394089323107996, 0.01484964339573297, 0.06020684613876286, 0.054463634357577374, 0.03476127403818312, 0.07275472665506025, 0.1368053308537891, 0.02398156467074108, 0.005520557423287462, 0.09360299746115362, 0.031412274711915565, 0.08013013855464036, 0.017330774271319953, 0.06694754270175773, 0.030289387082560893, 0.053403242265865694, 0.12699647130624903, 0.05154911796712587, 0.020089284516870975, 0.017711755541724064, 0.031055224113046166, 0.14704720627877021, 0.008921048870580572, 0.025725339749647726, 0.05281330093801503, 0.061902635385312384, 0.1512275948639839, 0.06894160062074661, 0.04489339970713181, 0.03969191167984278, 0.03232453221214875, 0.02332218513343363, 0.08291919655617207, 0.029085935731869073, 0.058907928741386825, 0.10660620616568674, 0.03208841433778646, 0.06716197837264308, 0.042885582849022844, 0.07545463500484344, 0.02702254302529318, 0.00864397210534662, 0.08081876732889684, 0.044807310576640794, 0.03216064302250743, 0.03212955134410051, 0.031241695659475464, 0.045609056063356905, 0.045156294269667524, 0.030456865394127466, 0.015862255541217184, 0.031932316262335066, 0.0816218649607993, 0.11143675058959954, 0.06218721406654485, 0.006769457897697125, 0.03563511222901364, 0.03854550706643251, 0.04507991913405638, 0.052243553687848394, 0.05907799259969785, 0.01612668515243117, 0.036732475723951094, 0.09021186329905065, 0.04254368163885609, 0.020090533240187555, 0.034312220110047253, 0.041652192782250144, 0.059543038613253066, 0.014700039830659668, 0.020186949235897873, 0.023419757921909614, 0.03263338438926205, 0.054726888981437495, 0.07442364153722603, 0.018641688605590213, 0.012172001391468991, 0.050027705653901064, 0.04392940445893234, 0.08103544763740032, 0.012723954334374399, 0.04273506189366022, 0.0355822368404798, 0.04692703372828903, 0.019572713344748464, 0.022530940796939597, 0.02404381889068792, 0.03205175703060964, 0.019601774890156045, 0.05919783556413266, 0.03990601793292069, 0.0340594302472328, 0.023480822790354013, 0.056290688939512744, 0.03954990196131891, 0.058528964197443384, 0.04011603710692256, 0.027604256568837072, 0.050536142887487534, 0.037757202592347903, 0.030807293162891464, 0.034068673098039244, 0.0433174534250171, 0.04959205443400049, 0.10952752924734548, 0.15805616554233337, 0.32836682673904205, 0.24963882060781603, 0.20384265139939325, 0.15927271316609076, 0.24776688476483671, 0.16446513454279593, 0.0688874765088962, 0.0823149906711713, 0.17473532457745847, 0.13789332892385223, 0.14150983083152002, 0.08518421211309972, 0.14426592406966995, 0.11539744047988808, 0.15647810102710802, 0.21888956818128788, 0.14945053134954747, 0.15007555184345092, 0.13244763887937994, 0.14256108732473466, 0.12292050816599401, 0.11586619435899681, 0.1373422665581588, 0.17420805690269317, 0.08519866819223089, 0.1483991063169895, 0.1378387221766095, 0.1513768900786677, 0.16082272354152896, 0.16053049164193292, 0.09370501739003005, 0.13623036654485812, 0.18102449274832205, 0.10623444667867116, 0.181582449905334, 0.14104003507283427, 0.18695090296528033, 0.13677638805200978, 0.13249705155049601, 0.14665807957851118, 0.22131561541989928, 0.1068388287638945, 0.1419643814405126, 0.18817682750523093, 0.12827298063183987, 0.09427907771521038, 0.1263649237432307, 0.13026657123719493, 0.15711435236998145, 0.11726651115403061, 0.13552262387689085, 0.1467755055355449, 0.08668503964379912, 0.18238590759856088, 0.15425132857936044, 0.1291277968595105, 0.15058375925066012, 0.2185895987936566, 0.12700332779317133, 0.13245709240436554, 0.1321989514174, 0.10184032722346245, 0.14167709846890744, 0.14071529040173178, 0.20338905073942679, 0.20437842265011805, 0.18692117875381825, 0.16261114047900324, 0.16776337288320067, 0.23084631610301234, 0.08895068339282468, 0.1595565180985197, 0.18029962035436786, 0.14991398390022018, 0.14498005591092572, 0.17533979859323273, 0.270105840097512, 0.13297558071151858, 0.12804036569451133, 0.21917303603503013, 0.12975248027472727, 0.19658675687688013, 0.10496552928440994, 0.19348434593167999, 0.09174524956653196, 0.12543831741617573, 0.3158924025633643, 0.2168602932004198, 0.19090641410120074, 0.24529177725555437, 0.3146201756692702, 0.281999692200653, 0.14610306419912847, 0.158624051198844, 0.21739545158080517, 0.1554996688519755, 0.43698075017140764, 0.15947255486201856, 0.11659701159524342, 0.1407363578196495, 0.1690322289904279, 0.23594827781761848, 0.25951829047933705, 0.13347199036469384, 0.18304393116024234, 0.18459657687814007, 0.249629796092068, 0.13959450376850946, 0.19405606202781203, 0.1445338556603078, 0.11619280062375531, 0.2249108047615136, 0.2040365788965456, 0.14440607219453783, 0.22334798539598144, 0.15362169623615282, 0.1305153199862088, 0.14716749740464075, 0.08862988407453222, 0.21855039041369193, 0.1190571497464853, 0.20106464804660892, 0.11765728494332683, 0.19289261961896575, 0.15418700783723785, 0.15812997045295854, 0.17468050332559695, 0.18046327205675264, 0.27918419650485443, 0.10159717857717507, 0.09814202244723998, 0.05875222903165606, 0.1756963052696759, 0.13196903310956495, 0.09843302094527791, 0.11023678876940282, 0.09013644960378447, 0.1790247121525388, 0.1778620051880998, 0.10891026922411497, 0.07358017107171398, 0.0841693984224431, 0.14502364631381728, 0.18714875283260501, 0.23505118885828605, 0.15640362195910948, 0.1313496357010257, 0.13329948268590436, 0.2213215755839502, 0.23351757276442744, 0.1561059968005265, 0.19020240994230395, 0.19683374362366815, 0.14205507092898892, 0.14881619522648473, 0.11890171816752804, 0.14160091868571698, 0.13066092265709756, 0.14339646024088706, 0.14286632739728497, 0.21836692767758525, 0.16222705463728598, 0.12699136916067333, 0.1312336806328066, 0.1943222469379825, 0.12331560269118318, 0.11770528035178301, 0.06741995848114453, 0.092735119434374, 0.1832564899157132, 0.18672588762016068, 0.14395309972666925, 0.1416260157261164, 0.1316922608642809], [0.019372616924585837, 0.057574721248520006, 0.07216211168035384, 0.05932214099072641, 0.08977729226312331, 0.07454377944551169, 0.020914139045823007, 0.030909010487037803, 0.03220235267954488, 0.037897109399519624, 0.01867614532520454, 0.05464548064816383, 0.02859760064541573, 0.026654688671471614, 0.028910254533853263, 0.031499049491098816, 0.07148394766714304, 0.052667874467348864, 0.03770068062529449, 0.020059096822214705, 0.030788841935235168, 0.03638624611701216, 0.06712337520213858, 0.028099411753036325, 0.047411040417970195, 0.05060223329271521, 0.07316563323500656, 0.04936010216272647, 0.05122306328567286, 0.03985979601800923, 0.06003537267867116, 0.0934459264540384, 0.023262162144566258, 0.01763974136162189, 0.026438665283363194, 0.029434921340115612, 0.044771338918156205, 0.017497388818751902, 0.004040480341627113, 0.04097980890242804, 0.03037241569179441, 0.012494383638934984, 0.07653869538297577, 0.05147470401660089, 0.06265871820130176, 0.044658949989224636, 0.009621164175651727, 0.021567209849074002, 0.07609313864621424, 0.018976762057131818, 0.030198661204908165, 0.03794422763730249, 0.05231431339897456, 0.018217936646373525, 0.06784317609403404, 0.022004540716748566, 0.11184026442107656, 0.011639928430198662, 0.025699829021769188, 0.0621530388842427, 0.04806103154776558, 0.05306098865525377, 0.01673029540407081, 0.03922660519639331, 0.04404720962948857, 0.07577607783699229, 0.027645393575151122, 0.057792006766483675, 0.029762178779609745, 0.03312664925150814, 0.0052292275922222724, 0.03472354037747268, 0.025859608149696744, 0.019496347785236377, 0.052222493930809924, 0.05213308763960677, 0.015798904857928717, 0.05604707297959155, 0.06717258869039436, 0.07002725446176145, 0.038527986635604215, 0.008250079380588667, 0.0177958432675129, 0.03839811558024057, 0.044975374945469444, 0.08105237051964768, 0.08481786120682956, 0.0889153054524814, 0.09969014824638445, 0.1294592371390712, 0.008027914361352282, 0.04093266768200744, 0.08653902328543125, 0.02434301069907604, 0.026245959696450064, 0.05651675382508867, 0.020626402167122693, 0.04007742627553883, 0.023998332420183767, 0.03362236176467231, 0.05416313636927836, 0.07757136658314737, 0.0319162150093865, 0.07395357764776676, 0.041983315135322274, 0.03146541057034366, 0.06839754795956035, 0.03997888821627825, 0.023547966566477573, 0.029446981479263598, 0.02856204650484987, 0.044644926749770684, 0.02370758481594103, 0.052140465066317594, 0.04624817257506713, 0.06569159517605459, 0.030495127655505657, 0.04780891201188488, 0.05238974241599922, 0.015886725347128608, 0.0195087009530154, 0.03041185581335618, 0.07044173867231415, 0.012156472789243826, 0.06317800707033565, 0.05727777024731041, 0.049000339612605116, 0.04413526377550537, 0.03953179164278892, 0.06711673321983508, 0.07674599111440682, 0.03910653240558121, 0.08265885689686384, 0.0375191867351532, 0.030652725348068826, 0.032223584806366314, 0.012357614919423096, 0.009969797383453096, 0.08187283536479359, 0.03176867413604933, 0.02406981799961819, 0.02604751611098407, 0.041107519589845216, 0.09113933530546005, 0.055916274957839525, 0.14124723121283517, 0.03496765429454465, 0.03563809997191833, 0.08104107072276455, 0.053193586983627854, 0.058985882018121986, 0.01510206840917348, 0.006982794232411131, 0.12928774069634177, 0.07460462214845805, 0.042577454624998, 0.023386812310725934, 0.014719328009373239, 0.04289025981580058, 0.03817872715092475, 0.08021626981996721, 0.013400669483798406, 0.01584352373385862, 0.024635091296307022, 0.01784823985109406, 0.04362686867675474, 0.08733697280648255, 0.01445352135511536, 0.03340039161905166, 0.01476660042235087, 0.009063455039605258, 0.021722716121603886, 0.015578849932118772, 0.04540642963782434, 0.07147833990353732, 0.056766456353568265, 0.03685919049706671, 0.08227300905292073, 0.040388940608189, 0.0462667080723951, 0.027172317044929634, 0.05912716395311779, 0.05898917236575677, 0.048211966190607324, 0.014048126777784239, 0.06244486858767848, 0.030168548203824513, 0.025126825897924365, 0.02894255088552112, 0.08379019256080351, 0.0610239708405589, 0.05871446855786828, 0.10663465101031527, 0.021428189788674636, 0.02892223231854939, 0.09486808441579343, 0.03878019810203583, 0.026123910398793318, 0.09814953010889793, 0.11064455438885959, 0.036572428465250044, 0.03190385992638767, 0.03873449712691288, 0.04966463360394682, 0.013414827746249015, 0.02902646624152699, 0.045973775202348355, 0.0662391105546586, 0.03435651148338953, 0.04580926931192798, 0.04611005075275899, 0.01964044126291429, 0.03216771401404854, 0.12446920853108169, 0.01006188115195161, 0.014330448372469795, 0.03061802348031873, 0.04590453617575188, 0.036203354116409056, 0.07731383846652123, 0.01688457210548222, 0.049269033460727626, 0.04774967426313989, 0.07585002830432308, 0.05819144884064313, 0.037986209255553065, 0.04392216109760827, 0.016169559263113528, 0.05789938164995082, 0.054660101436198726, 0.0452784929544695, 0.015449614729732277, 0.04562702082518128, 0.05623843025175795, 0.044419045725296584, 0.0747488841654793, 0.0784704780145999, 0.057306180617982344, 0.0009558420976146966, 0.0427695818155283, 0.015181326908209633, 0.04230639739562908, 0.012501544645807196, 0.08373249847922595, 0.03436659703091268, 0.04178750306187619, 0.09459824526622411, 0.04785543653152643, 0.023839296397542762, 0.02276634620953231, 0.0752657024009574, 0.004207510012953032, 0.013990863620664084, 0.07932367013587106, 0.0708234036761907, 0.007542245739680385, 0.02491401050299887, 0.01470582283687808, 0.07777699990378273, 0.037243165256034945, 0.04342800374293039, 0.047893832858291366, 0.10312642030898603, 0.07152926176786423, 0.056888302637925076, 0.06492019060157961, 0.043286491981557304, 0.06998743321145735, 0.17842353231483893, 0.02794644123153581, 0.03778831725339255, 0.06952550517575395, 0.042987755995484135, 0.09447829887991953, 0.022218403736910513, 0.017702279034100713, 0.030831800315589197, 0.021685367420075402, 0.02167683320059892, 0.11980356453287026, 0.016808781111913345, 0.020840814855370312, 0.02421291939343416, 0.007372359518006805, 0.010036266044593387, 0.015465967834085948, 0.038023280250209, 0.03183008565927946, 0.062241702070159305, 0.019318282138556242, 0.04890704159474662, 0.016387388703503435, 0.009094511286445684, 0.03884130510531607, 0.04171380540356041, 0.009727081576842937, 0.0525329702143227, 0.06483570642528996, 0.05998103406220194, 0.054851148442755786, 0.13825064765349512, 0.079811108899453, 0.05891899488145306, 0.013074758443831196, 0.06249459918528315, 0.028022082837959452, 0.06833865878082092, 0.04816806935254605, 0.04583682932500397, 0.06168100231837842, 0.059305233430237546, 0.04479063667296883, 0.021688161725779215, 0.014591048501672284, 0.01961381779232573, 0.0036455277821064117, 0.01552281538850718, 0.02408969989647308, 0.04337323611722358, 0.07511027848287936, 0.07126467032057625, 0.07762195902966684, 0.044716364448709835, 0.011015094670226738, 0.04998657056280682, 0.03827304406572254, 0.03251935603217252, 0.06103491440655724, 0.0182394809540241, 0.033573937346978534, 0.06979834738998644, 0.023340820222191756, 0.04979829296409603, 0.008991001316556528, 0.012444609948884577, 0.029534242724278764, 0.020539870620855404, 0.024043776755852085, 0.02506732767928512, 0.04555946336157861, 0.04313624298740779, 0.06621181484191649, 0.021707097504047618, 0.047274431619312496, 0.05072124505175218, 0.04685776022773597, 0.04079229739164153, 0.03769746688645213, 0.02851023789375059, 0.04493103377641209, 0.02232850014772867, 0.04388109495442721, 0.08095074895649187, 0.23183636217107698, 0.17248196887873835, 0.19437945838416779, 0.1766630469430839, 0.15466688531300715, 0.27548874157571024, 0.17101632010552192, 0.14082242013706317, 0.11060347675435966, 0.09020841590339139, 0.21526833185024802, 0.11813911594330304, 0.14647722154134704, 0.16890796952910964, 0.17892573359272174, 0.27500270475302974, 0.09569615651402744, 0.15257036313414574, 0.1144851676578964, 0.13727558626522943, 0.12690300091860757, 0.1591684485995962, 0.14592248195361707, 0.1494045967176076, 0.13694952392289717, 0.1871315005325502, 0.20621591518002175, 0.17279551334438786, 0.09805850354173491, 0.17922032504312455, 0.18590297129365707, 0.06826072465628386, 0.10317866750542196, 0.1551240406209423, 0.15902425553048813, 0.12657683898484515, 0.20679287131755583, 0.10240507958036277, 0.18631900300181684, 0.08264777926547874, 0.15685392844100154, 0.2263608406628332, 0.14818705317954864, 0.16706935851083649, 0.15352673197705902, 0.11534753751250044, 0.28237464627431286, 0.12517474486582703, 0.1317659432008382, 0.15190110872349433, 0.11624956007806525, 0.09117710344012707, 0.11225539214548566, 0.15221966340416862, 0.21619427168080885, 0.14409130198820946, 0.10421513850169797, 0.09573771678391965, 0.11943359003071824, 0.13005012075506872, 0.24683902971446517, 0.14314809453583535, 0.09038810948691062, 0.10231385383033946, 0.21416847473911702, 0.10982409720459294, 0.13806441167910255, 0.1658734646175177, 0.17636618787242522, 0.10854027173932522, 0.1512229217276458, 0.15625202848065287, 0.17161527828824136, 0.2046682949989073, 0.14828384072790224, 0.07658710447891105, 0.20646452603320922, 0.275194104160032, 0.1961747547912021, 0.14547977506393386, 0.1257558455390315, 0.1704772699984812, 0.18310388520119653, 0.15446025607807023, 0.23314292512593732, 0.22831977345049384, 0.1979972319977899, 0.24514649634159383, 0.375546474129923, 0.20318380046275356, 0.1961666649027217, 0.32714344561100006, 0.15934555280593135, 0.2203375356452119, 0.1393111278453181, 0.14203714447156077, 0.1843706269057528, 0.07279696874320507, 0.20068304432976633, 0.12634924192342067, 0.12763880538724123, 0.17771004398743953, 0.21664474670204426, 0.19665757404460063, 0.12091361827427342, 0.11309805055779797, 0.17421541134676627, 0.057302388482757156, 0.10490656349687807, 0.1753268210637954, 0.20301503129303458, 0.1276117931270311, 0.19397021421501714, 0.1425698973358639, 0.12722774558971006, 0.10691876237791394, 0.11274987125709174, 0.1542141273497574, 0.09532886331961041, 0.16186184520202299, 0.16461577807222644, 0.1660359212227406, 0.2198126275212534, 0.18406092820148315, 0.1673538529223973, 0.14324213948942002, 0.14875035763027208, 0.15114030680589138, 0.2021696226250741, 0.283642583076031, 0.12773855003498255, 0.11917205527424814, 0.1608760432610589, 0.12120132259423695, 0.10159115712609022, 0.15942671216062962, 0.11311659754644479, 0.1499025538683899, 0.08946020081038437, 0.10063774538256469, 0.20813338728922032, 0.24707389695029108, 0.24825085315012166, 0.214027943570287, 0.2307046664458129, 0.18599039724757596, 0.11223193453324419, 0.1573600214455397, 0.09931220642981992, 0.12672551366831028, 0.1719999310350226, 0.17366943580489005, 0.19503299267061297, 0.18046681138296283, 0.17259538053504883, 0.0938875071944729, 0.10118779651219807, 0.08201453864814774, 0.1314189360146561, 0.22640836875765558, 0.10738430634861994, 0.08029359873504409, 0.17304744901916674, 0.1364524707558655, 0.1723704417987216, 0.12138252537096701, 0.10622362185630108, 0.16490566574277418, 0.2566336323657344, 0.13391819061531177, 0.08884392904057618, 0.10152912698686124, 0.16190215674859865, 0.1603677132797818, 0.19057388597678757], [0.05458523166335879, 0.01659133088504595, 0.0404991883213722, 0.04958747322821329, 0.07994754149788812, 0.012368866835810967, 0.03409260951523339, 0.04151340829388749, 0.012890649321038398, 0.04370276117697359, 0.0015384182681314528, 0.004676120729380918, 0.06620596193017499, 0.17158261229915006, 0.020292529558402397, 0.02483051649535135, 0.0060706832464934605, 0.048469230006899566, 0.01590502718763967, 0.0539487160201515, 0.02510332998128668, 0.03495326333288704, 0.07311761484391267, 0.07473733922046039, 0.01949217835170848, 0.08929981264255701, 0.04605703746839877, 0.060874265768835624, 0.01958227029160386, 0.006892426500863006, 0.02301389220050506, 0.034124088068042076, 0.05976833741090471, 0.018834227568379814, 0.03495225592726662, 0.03183071385137737, 0.044807126715538964, 0.04510190202704361, 0.017366966180082773, 0.02830922791373826, 0.026505182782608657, 0.03387228262821033, 0.04748303353065445, 0.028060611314891327, 0.012741147262615063, 0.06657281845447517, 0.03863163067088012, 0.015194221125585178, 0.01931112304690384, 0.041923391737885056, 0.06823568890291838, 0.020536130196565104, 0.040613706974733266, 0.03644461818640271, 0.03795915103006748, 0.0401338524816017, 0.05711853504180909, 0.10011077648208988, 0.05191134348992379, 0.02690618767613365, 0.06898454750978178, 0.041564697880418076, 0.04171925611914166, 0.06097473820010501, 0.06153169178193616, 0.013051361161013766, 0.038391033097380595, 0.061831366225716576, 0.012133154030438634, 0.05524407876955886, 0.02101141689044814, 0.025259244195636243, 0.025214148429973472, 0.02385685321754746, 0.114459503712433, 0.08347918384618337, 0.02150871903605519, 0.01954344878604095, 0.09213608464286213, 0.0973178037712651, 0.05021748478494344, 0.04019257695143742, 0.027978212812975533, 0.004764735077192346, 0.01322454491239642, 0.07494455834309902, 0.05430032356431889, 0.0646676420564613, 0.06422908353288809, 0.027093710678239024, 0.021631072853661833, 0.010415266977713234, 0.023930665789051883, 0.03059754020444328, 0.02760214408138587, 0.056103296172354496, 0.0436121138233331, 0.011219841244089748, 0.007989149354773784, 0.018900103468988693, 0.046258315579184604, 0.04130225147931807, 0.04974260986331971, 0.023248497051216906, 0.06317652469020217, 0.08506751393959408, 0.011027854822215535, 0.023743485611292626, 0.02667222250883858, 0.013114679285565452, 0.08657745791659241, 0.10039854974996659, 0.08412380853006918, 0.045272927325699604, 0.009978277976774882, 0.04486233867224186, 0.03982575490109382, 0.025587913152130864, 0.022171025029233387, 0.06638007073272621, 0.04854770422342324, 0.017771159914592584, 0.04902201223998301, 0.06164204291698914, 0.025141628631841273, 0.019836178642787763, 0.049140139167467435, 0.019784862243179834, 0.02550058295920251, 0.00862728096469636, 0.04141097084709233, 0.05686349288049725, 0.07348929772213583, 0.06614017796011702, 0.023002287883672024, 0.01301845576944611, 0.0351848095775612, 0.04353977597108291, 0.036992888161612135, 0.004598249328292666, 0.05174074337006577, 0.02776605625366492, 0.04469841883908357, 0.0354187460165591, 0.02559566213148496, 0.01674687546197205, 0.06038547869050696, 0.05499394340140205, 0.05018262012350944, 0.04199072703598969, 0.05900270530893918, 0.05190961596165454, 0.0385650844433375, 0.07496674424938618, 0.025031861638830557, 0.05668680619208082, 0.04589331681810079, 0.03549494112150804, 0.05688574390425798, 0.1052468674137227, 0.04149270859817344, 0.030633521439026923, 0.030577227383130984, 0.017018876894707644, 0.030385084870842197, 0.029830419976684838, 0.026746029334683574, 0.047460073875563766, 0.06060075322766939, 0.019665936669034344, 0.012533107468287551, 0.00677792221165052, 0.11052439349793619, 0.02046911665538867, 0.06298884847051194, 0.0735270735176821, 0.03938168054446578, 0.06332060667656123, 0.03467029343629557, 0.025529462558728074, 0.059058660370928634, 0.00938295009320662, 0.021848955920206446, 0.027155878713294387, 0.02814534255453656, 0.037955615534296924, 0.004426907539562953, 0.08692883946482213, 0.06005881496915414, 0.12298660623210093, 0.033496114305190505, 0.020783632137482206, 0.03601241436216139, 0.06843455766718234, 0.027657989975846106, 0.03460213842411195, 0.03703665093428666, 0.03156718726630413, 0.05028165997036042, 0.0431676717445014, 0.012134995514286623, 0.05309337119181311, 0.024450933335409052, 0.05516841226527768, 0.046152940185199824, 0.03687310265377164, 0.0548148014011883, 0.0645355225330399, 0.06362120808673001, 0.11817600307685715, 0.05952950950051027, 0.03296291710989129, 0.015289208367316714, 0.03018269784778597, 0.08633925819829588, 0.04655579901150158, 0.04298485252225111, 0.03899591313975473, 0.028277584652025855, 0.04658689835078774, 0.013649546552539594, 0.05637729517935265, 0.03539655627983232, 0.01596206243360235, 0.03787551721137378, 0.053414335219009276, 0.012080460587786812, 0.020623895144390485, 0.06170603424130429, 0.03471232101982159, 0.0449736129432436, 0.1331190689797363, 0.021142622854019848, 0.0389656258536683, 0.10809829263317008, 0.028022498440658374, 0.042954519270889224, 0.0134630759637202, 0.01793244057485173, 0.08313160975493732, 0.06446685807238664, 0.019057517300450036, 0.03861979844288961, 0.06194804524702411, 0.017068507900882154, 0.026010973716995893, 0.01449778495777038, 0.024374161749297095, 0.1274108406036131, 0.05613657120134562, 0.06931838564454548, 0.06124700201795467, 0.03025463541909572, 0.031894067407495556, 0.020764345873988444, 0.05017850623135606, 0.0672162097368029, 0.07038494857448725, 0.035414409958907676, 0.06241642374304995, 0.12290301837868269, 0.026910588851258643, 0.07174274748972348, 0.040274035080426165, 0.0978452553071322, 0.08474318295597069, 0.0424630738674633, 0.051781158338511185, 0.06982172839343548, 0.04885146191584007, 0.01901967830265001, 0.09055541542869422, 0.03558297228488711, 0.06544357421056879, 0.047678259546838464, 0.0348463366108556, 0.06980167221157782, 0.057057696169302355, 0.044156859794090834, 0.0579321472304723, 0.08481282800916704, 0.03690694458782673, 0.04681313560614663, 0.004107492925193642, 0.023262629458200068, 0.050514198298896515, 0.1604592914302503, 0.059873697483131004, 0.02925054887459884, 0.035627650532631144, 0.0572135720792557, 0.040162546304805626, 0.04932550563206596, 0.05587484875333406, 0.03242825285621709, 0.09930600877851249, 0.02719760752252994, 0.025251652264306625, 0.03615602137400739, 0.026412039897554827, 0.06331362761557102, 0.042520549613982446, 0.01921060273513919, 0.02650792346215777, 0.033271669695574435, 0.03597739265270291, 0.022036879203252254, 0.022112258424561833, 0.05563414392752513, 0.04444506207120515, 0.022966980806461746, 0.030884018783727964, 0.036322706784572334, 0.064248752840344, 0.02585823110665285, 0.019420844074639104, 0.009531905356374, 0.018789738927397038, 0.005795869792270805, 0.05312547410628008, 0.03852545854545409, 0.013066997973158235, 0.044316068186514804, 0.035980755778690504, 0.02972977134519287, 0.013795629943600826, 0.04311091229019146, 0.046911558752218564, 0.033245323931858424, 0.040435802206517234, 0.011937305567816142, 0.051449652941476916, 0.0616153868876638, 0.0728542797808205, 0.02723576061637892, 0.12326217571934386, 0.06286240565860945, 0.008358531575199337, 0.04710877276656609, 0.04221093517938449, 0.03405835772413881, 0.0040762547324712005, 0.05029710430291392, 0.10957914059080424, 0.03460681156045006, 0.02395633548017471, 0.03505444822592601, 0.009439410773226091, 0.023176231977319526, 0.07967644596412297, 0.024031415927193822, 0.02476302031878262, 0.2432972213794147, 0.15430570550022588, 0.10258969910923513, 0.10840797601568122, 0.2518687033725362, 0.10621290428624039, 0.11016966414547737, 0.14862651185643289, 0.07607535774549169, 0.15604279454677336, 0.08542007526322719, 0.16677202446566475, 0.1077730653266753, 0.34957155825630315, 0.1022753808947821, 0.0702224153604719, 0.11966503285352262, 0.2466628907789146, 0.07570624126181488, 0.157813805966608, 0.1042512212429316, 0.13451386994171527, 0.1901913016674019, 0.1742108148192206, 0.16441730001280386, 0.1281204678478741, 0.15122776340332725, 0.14530106207295773, 0.17545636653179125, 0.12064525001351872, 0.15947502166513475, 0.15916959773148262, 0.18598753207873914, 0.1621448687247692, 0.13756715932921057, 0.1520504192599366, 0.07489021206575056, 0.24645863641654295, 0.11724236406265728, 0.14066486649455565, 0.11704203973133719, 0.13014666315528656, 0.08876588000285049, 0.21707626870803295, 0.1339460302504801, 0.1055868802171561, 0.17101589109628432, 0.10000065900385381, 0.1269920279962882, 0.13903283874594397, 0.1751912847882317, 0.13374294034175335, 0.09507207830827083, 0.08314502395449147, 0.11371319617835746, 0.14303394743511755, 0.15321473500901653, 0.2584511300008143, 0.22045506885455501, 0.12939100934853479, 0.13787880389680787, 0.11628639358546465, 0.20521232467745582, 0.12343897349050931, 0.17551071280913969, 0.10278977063154021, 0.15627861173162538, 0.10851319819208115, 0.053337871983286836, 0.12037652935231886, 0.08151776127276883, 0.09079721576023488, 0.31048584429006426, 0.16223307608837084, 0.18795283871792978, 0.21895994101801228, 0.08244625983699676, 0.15335115994657242, 0.26263121215085833, 0.15729856587225394, 0.11589593389221739, 0.1558098884960336, 0.16858190718677737, 0.11020528723395641, 0.16789900108931527, 0.4101614828311628, 0.21267399041643067, 0.14050654676412383, 0.21607542080023598, 0.26031085440228063, 0.15436103237011742, 0.1271915096308916, 0.2555523758694049, 0.19718562312904866, 0.1142386865291384, 0.2523918648160273, 0.12644738544740025, 0.10858116551272332, 0.1356834410539558, 0.17589948710895356, 0.1623903692609841, 0.10413759508200231, 0.11736035692475497, 0.1894993404106748, 0.15741894892867536, 0.09768272209311686, 0.1463530540105797, 0.09115776738091823, 0.20228275848973185, 0.1453156637087945, 0.21571534415406568, 0.21671617674010418, 0.11770773949401996, 0.1268488155197232, 0.13116623425195295, 0.12081418772258105, 0.20219608330197875, 0.2199098747223616, 0.09412285706569111, 0.2401747389305984, 0.2017669668120723, 0.14604373835027218, 0.09141445280082765, 0.1650637556468287, 0.23822745067938683, 0.12854195410205474, 0.18851811967549786, 0.14731026555020965, 0.10560124436573637, 0.09810053112526095, 0.1410506377297063, 0.16485184040521422, 0.08552211817474135, 0.15609574654409963, 0.09668929757730615, 0.12739436971324106, 0.12474640212472408, 0.13953995830830068, 0.11026388529928462, 0.30368779455461814, 0.1362668016865369, 0.13599074956390167, 0.11104927097837772, 0.1798356621856651, 0.11674438392923725, 0.14505980566384333, 0.1178147389944042, 0.13322325693743844, 0.18909237918353852, 0.10602958710683931, 0.14302532128509016, 0.10159583792330758, 0.10580478626633845, 0.10485062375664712, 0.14716896829345535, 0.1691453342115687, 0.2054889590269135, 0.2283771840795394, 0.0998302044407014, 0.1765920305925031, 0.08974127846980288, 0.10560849155750006, 0.2315236450803857, 0.11693061990362984, 0.15480720197721837, 0.10891075952038651, 0.12797032993647361, 0.12211639163715225, 0.13032594305132666, 0.11958233366209654, 0.1184016083096785, 0.2128030915534304, 0.14944401960219109, 0.15137266127332566, 0.1408367306594887, 0.13065482459722028], [0.021615459981765, 0.04349808929668319, 0.09963470646330427, 0.015250561146756575, 0.04889931942846987, 0.013621025099118632, 0.02598857330608993, 0.05610783141286624, 0.012087484656442559, 0.05202829064200482, 0.06424311060278166, 0.028993666187048923, 0.09908056442415523, 0.06332297388824724, 0.029480852141615846, 0.057099313895788886, 0.03599999224646919, 0.02890210335833892, 0.04354467127291907, 0.07378598059257192, 0.052624425790723295, 0.04291896129988375, 0.030560436651050567, 0.08993446286166869, 0.04986991452413702, 0.010060572099210996, 0.019415826198735067, 0.036951971405576316, 0.010303893115281338, 0.04378329617001357, 0.09200693754058692, 0.09050639346241952, 0.0769347321963118, 0.035765416124054504, 0.02450195287594632, 0.024308933192984234, 0.04120662072373014, 0.04904859549095554, 0.023233261477622776, 0.02908291926066722, 0.08430184736367195, 0.0239142389487355, 0.04157173439800259, 0.03132423971809688, 0.0428715251356123, 0.03564787142339253, 0.020028587370630235, 0.04348072591387937, 0.04234506185316751, 0.05300060177462236, 0.06450032079291922, 0.002460157064037518, 0.034110597259695494, 0.05240719772935395, 0.024188540560463746, 0.024561129337657365, 0.04034093753885358, 0.011594170956091296, 0.057968107397638025, 0.019009835988042817, 0.019372469452660412, 0.05180612897440311, 0.07128961414339081, 0.04499198756210747, 0.028138216021620942, 0.0072993115980118034, 0.08590091800978107, 0.03186362690382427, 0.05161012537897595, 0.024733045213525335, 0.025006207269466212, 0.013488340585853064, 0.0471544124546551, 0.0283930475087536, 0.03401930639219861, 0.045637462603589224, 0.02739870943309319, 0.0802951768761681, 0.05210756158996975, 0.05613695807574738, 0.07338054388040498, 0.03413428469831425, 0.0757476253314845, 0.03551168397309319, 0.015595653113127958, 0.07005720849960081, 0.09295416695456352, 0.05307294728775179, 0.07070776270402056, 0.009019512236268531, 0.09081204722244894, 0.06746691967090292, 0.05441601816264372, 0.051885572292150996, 0.036801423637136337, 0.06803780839207672, 0.029742597572265134, 0.02160393801938382, 0.04329610638500702, 0.03941857533889913, 0.027281136004134055, 0.05100198946292362, 0.05804752773274818, 0.030570784583687786, 0.10574676276695345, 0.044840742653656396, 0.06629475918147834, 0.01455395739720834, 0.04422256715535637, 0.03155334022707276, 0.020042945773551063, 0.04693793898989116, 0.057490198767834136, 0.09229892429204718, 0.10915228406027441, 0.025095468003963752, 0.0957988276176395, 0.05360155178594494, 0.02212301812945835, 0.007969550431645926, 0.15022116983609815, 0.04934518643084073, 0.030979459932554635, 0.010579595710301112, 0.034517313338695996, 0.038650928425692746, 0.027217908852523374, 0.06842846726818431, 0.05386823082282659, 0.055391263412011255, 0.039038630202412605, 0.006081672298962311, 0.029089197351206696, 0.03974565657817068, 0.027391383717317256, 0.020040844777418722, 0.0394730671729532, 0.0317449560539136, 0.05014464897554248, 0.05556645622897533, 0.03403463964200309, 0.024243545673427083, 0.0679460617022649, 0.01844530962708016, 0.050187894638868115, 0.05195222960244264, 0.05282737780362368, 0.05258058640925635, 0.009504083915793849, 0.09233290029148902, 0.021163579189188538, 0.015462415101337097, 0.04127226679796173, 0.04827729433835034, 0.04114516132000474, 0.03612891335280673, 0.030495125740285844, 0.016801302178552555, 0.01709739707650677, 0.05433356028891379, 0.09639701971243467, 0.02090161159304121, 0.05420386926421235, 0.0029777263050838826, 0.046326757874339826, 0.05967115149683049, 0.09000872742504844, 0.0412686815064761, 0.027059736594016996, 0.02130922207969331, 0.04228600413508473, 0.049089037272478306, 0.0743519586901511, 0.030369203868171865, 0.03866233164444566, 0.017516408866691976, 0.024811785645602692, 0.05353876705011053, 0.019739664970867096, 0.03706843975270468, 0.07338618228752768, 0.03734203656354258, 0.024710012780081843, 0.06441291782163805, 0.011824038510601367, 0.042478912735297795, 0.07288975731259392, 0.06644829086238338, 0.018462841549227317, 0.022526775193851323, 0.01384293108487562, 0.06182788435610072, 0.04730300286844854, 0.02572351454516813, 0.04844767612314994, 0.05091961968930499, 0.03950364940289048, 0.04205847985201305, 0.016758077582644842, 0.03462224057124507, 0.011417875930126156, 0.03478785728915565, 0.011495315927952048, 0.031530225439177405, 0.023256711428985003, 0.037604306764420004, 0.08913929423978252, 0.017699088277896086, 0.031191218126144622, 0.04364991643195672, 0.02560530143279222, 0.06382381152962485, 0.04204717622469029, 0.08194783537258064, 0.049851984236269235, 0.03540286884432839, 0.06430633966961215, 0.05508432262426904, 0.05969701079471458, 0.06467346432468583, 0.04451592520420109, 0.025041772901350935, 0.14035288484827166, 0.05533291049481881, 0.028848557642871336, 0.015566688286320818, 0.025563338966739756, 0.0468925406194983, 0.0798202176848727, 0.03656983525762635, 0.028709635258682316, 0.03431777041705866, 0.029705306327330972, 0.03502045307428606, 0.12162125368993129, 0.030486982225650744, 0.05967192907607364, 0.053960866174630584, 0.034884564398277196, 0.05670044638757264, 0.05732165176361319, 0.07331830689743643, 0.0990787334740162, 0.06277895570101757, 0.1100559690366349, 0.021919416857042143, 0.009109577363086565, 0.042305064402640834, 0.042795138508682294, 0.03735790607489405, 0.021118303392863563, 0.045852334944591414, 0.09924385606521562, 0.045117296563882026, 0.07898470687289393, 0.018846967610560598, 0.03180357327143992, 0.039444829172064225, 0.015012319293624211, 0.04535896283003592, 0.05220164484795063, 0.08824171498417856, 0.07686769184205802, 0.01268286616616552, 0.030899765721011548, 0.06286005759912153, 0.03282307542019314, 0.06803675885162047, 0.05263520847825755, 0.007878741720736387, 0.021217737774995547, 0.034188956563030524, 0.010977482625974283, 0.041547935876634814, 0.01036759715662488, 0.01910906927209468, 0.004920328492223616, 0.02676877831559508, 0.01883631132753386, 0.00616956029966053, 0.05399729365543012, 0.067298878284712, 0.027231669706863262, 0.08670357131068746, 0.033049722532591516, 0.020276370848859512, 0.02642849163572875, 0.06749905705932649, 0.04024924064475683, 0.08466832084401, 0.026611912236999602, 0.06150019407692937, 0.08720892887081831, 0.030389129815082398, 0.01012572787717105, 0.009827147023902546, 0.08606624744472005, 0.014931316986950416, 0.04676957584677204, 0.038153289201399015, 0.013563292713144855, 0.04691034067241896, 0.020672342544721983, 0.05625842514658167, 0.018787994162149487, 0.04668936261066026, 0.1069272582929942, 0.025148178683593873, 0.035637885467299533, 0.0654558162955988, 0.00937816970455911, 0.14776932075619698, 0.015401871172681212, 0.042942005224646106, 0.07976463800596614, 0.013775731767377546, 0.0331012113019824, 0.01419040845752123, 0.08034574634004986, 0.03342770265355226, 0.022349127065089923, 0.040358216651985725, 0.07577028621228472, 0.0572364972603898, 0.008119461389498846, 0.021740460633150032, 0.015590861233161583, 0.0230689509396231, 0.03864673026386769, 0.07046341129969205, 0.03021634825985999, 0.04433016803476118, 0.051739862368952845, 0.026970027698083755, 0.023383977785406095, 0.07074700938838144, 0.022300191283706697, 0.017440552755649534, 0.04858318558563629, 0.03236272935605338, 0.038270512145132794, 0.06572454461767789, 0.019808486479544835, 0.05711553963802515, 0.03484986061530729, 0.1244532815631359, 0.04714031643684834, 0.09876756388093196, 0.05167169586545037, 0.06825068124359654, 0.07721468370648162, 0.05531273173889326, 0.15343521511362446, 0.13812957511794183, 0.15691181404456017, 0.1391210920748211, 0.24713640972491235, 0.09453254556583782, 0.13639620925870635, 0.14839576617363961, 0.1130319448308118, 0.1533944132707773, 0.15478896908462048, 0.20004973476452215, 0.2727105696835826, 0.2009097450683194, 0.07624709933635689, 0.12319587847037662, 0.12257700966250513, 0.0832567808608855, 0.13629792017802117, 0.14874838112342745, 0.18370831325169534, 0.19730619004657193, 0.09017320650239145, 0.16636818887725954, 0.09206151364431267, 0.09809074052158864, 0.07479036782657908, 0.0874882675106487, 0.10841858633343252, 0.10438492656835627, 0.2120115235447884, 0.21734032389377395, 0.11342009093852774, 0.2371438193104921, 0.10617715096281422, 0.14829117985021684, 0.11536305845384637, 0.18787523401120018, 0.14464879949246684, 0.11102359937203508, 0.15511089455216162, 0.21207051231495797, 0.10683578739483511, 0.21020965410336373, 0.15494001097977161, 0.2186581789846382, 0.1360379865453128, 0.11757557400532308, 0.09908345257562977, 0.16425593125243343, 0.28074980443043096, 0.20531421437138514, 0.19660816137348452, 0.18927909013244415, 0.14282114353151093, 0.1462367618636739, 0.19446403449100835, 0.13314966653143206, 0.18315116814788313, 0.14383867683429874, 0.14964465802956015, 0.13529356358753097, 0.14695441770938136, 0.23409002430496678, 0.2397361842374648, 0.1682078570968682, 0.1854908772774281, 0.1707361157863371, 0.27937164289816735, 0.0892018070144038, 0.11669361528249518, 0.0907403796971325, 0.11007949559678955, 0.17049977766169658, 0.13380001389211224, 0.08293883138967138, 0.18652774663942476, 0.2699919994319639, 0.1869901266670035, 0.15783185499810404, 0.1500524925969301, 0.21670405722914204, 0.19785170593569357, 0.1293275159813704, 0.3174144047642908, 0.2105795826402403, 0.2501105009427955, 0.15972478165020867, 0.23356922241228245, 0.07878795251130097, 0.20073785025986934, 0.24562263530829262, 0.11749087532441463, 0.1657055841097909, 0.21999815869475567, 0.15851316763268364, 0.1555284124708945, 0.09231149579488462, 0.11084323163114249, 0.19198247652140357, 0.1203724920689579, 0.09347202706961863, 0.11862727482953381, 0.07484507416525195, 0.1766545280453659, 0.2342472868340631, 0.15287646122517126, 0.16040954168044752, 0.11374691936878428, 0.075877002260137, 0.18916158756661802, 0.15805717677839343, 0.16500012438383796, 0.303892370673918, 0.17771151487625417, 0.09648488999734964, 0.2978507255113894, 0.13415938573739222, 0.15594911731539235, 0.07406346529962556, 0.2520960169814287, 0.1231367058391052, 0.16829920542095939, 0.09425716760057597, 0.10345856538943707, 0.11636789001884962, 0.1366975576046013, 0.18227294027324648, 0.08167549877637818, 0.11258491720523565, 0.2278487979164047, 0.11138750645782679, 0.12895570286820013, 0.1645729997225346, 0.11987623563336751, 0.2958869357262888, 0.17873228107008243, 0.21263708030023884, 0.22224166250276953, 0.09136267291802554, 0.16153221288996358, 0.11895279324943982, 0.2044315891520631, 0.17521005394237657, 0.15686561894272605, 0.15002722701718732, 0.18932637307913075, 0.18162990139136392, 0.10617785576370456, 0.17008008405325875, 0.1506298777437018, 0.14725552090714056, 0.10959222537255096, 0.15571443394066828, 0.09282783139497043, 0.14404637859232966, 0.10692710507540934, 0.14785147602519683, 0.08408877532929183, 0.18194681664388027, 0.14013825765540525, 0.10732412248128846, 0.09864571759657514, 0.11710128897140104, 0.22869071322343043, 0.1461604135411401, 0.17018379703644784, 0.18926107174446508, 0.10210818986618712, 0.2692458604372317, 0.16990153960162596, 0.18326359921165053, 0.14929841693130233, 0.15797197247945494, 0.18464251151007993, 0.11478567330707466], [0.008247136645349524, 0.0293324034540884, 0.0298490263371458, 0.049183243104527076, 0.023961276747286323, 0.022499513955065803, 0.043646189414205096, 0.05602204105666569, 0.004300955023932001, 0.016087932594781442, 0.005975221987858776, 0.010536865241104558, 0.026272077549008593, 0.01357357552830851, 0.021787358620654673, 0.05104586714878679, 0.07480387395668416, 0.022679632717383005, 0.05054801725031388, 0.04913864529601509, 0.07410417521192182, 0.06250751159724689, 0.019152684572843776, 0.0503957151405273, 0.02401409659444565, 0.02011103183782149, 0.049050407288896467, 0.031178713656000556, 0.09542801041877079, 0.015007831933607739, 0.05335378745991377, 0.013871137484637721, 0.047905454412102706, 0.01218349845599263, 0.011728619386802518, 0.04307088802658743, 0.06923310473681459, 0.037603640267925884, 0.034590041895787564, 0.04251384251420537, 0.04388939934752641, 0.09378055365936411, 0.07099173617579284, 0.092411715417139, 0.04223710474287791, 0.03624168915614005, 0.04483357973156437, 0.015611042861916847, 0.041078354622567856, 0.03797892375939316, 0.05437798572764282, 0.036221475926257914, 0.0913997515735607, 0.03423003036709082, 0.03370425656377789, 0.03615387249737978, 0.05170603958709587, 0.022665733967216748, 0.023385077121577436, 0.03298414923671273, 0.03800080323051061, 0.04772460403581781, 0.02803931215537652, 0.021710855165316213, 0.06057511609528334, 0.036776315105418046, 0.04129910285794928, 0.02395014932018615, 0.060712816569233136, 0.01900110258570602, 0.07159201202974205, 0.013069698433091324, 0.008334097200854412, 0.025485184591924472, 0.04310710483320779, 0.05080445752208752, 0.046019564277582595, 0.023872019843228405, 0.08838933246630816, 0.02098907202091669, 0.03056356420500144, 0.04764518753114728, 0.022475207900448192, 0.02148643162311806, 0.03381319426661057, 0.04319058160387701, 0.05311728845680914, 0.03263902279638475, 0.08365120888958055, 0.08423372682544493, 0.09188863058244029, 0.08890141627841419, 0.03928316929828256, 0.09639479039657502, 0.08758635740847358, 0.04218729753648082, 0.06751776492643742, 0.021957908944797613, 0.01807262317367619, 0.018085054865467454, 0.022404712489655903, 0.023373685394143386, 0.07779248254073244, 0.034064045926976594, 0.02894672797992826, 0.03492188054106889, 0.05224351155301256, 0.059760090474399834, 0.019835971799048207, 0.029565447400654518, 0.10053546498379401, 0.020077385256187092, 0.05653827706532133, 0.014896375716723984, 0.002746115661143596, 0.044183431553744504, 0.03987649673475854, 0.03155327319437939, 0.06533804559899915, 0.04407539783466247, 0.011888321905937648, 0.01912986472879927, 0.06862589578715063, 0.036031486121036356, 0.07732864694609758, 0.06150020173780861, 0.04025948707074408, 0.03626281786109171, 0.04090672411445168, 0.033671793587986505, 0.0115477460278799, 0.03682808732734092, 0.0641790273479156, 0.02723548099428656, 0.08216147431202474, 0.0725385366428283, 0.04244255420241145, 0.04338779178778491, 0.021465609353336117, 0.038486441687470486, 0.044594219390062556, 0.08553685770640451, 0.0555593277808399, 0.08702177359091659, 0.03658257529980714, 0.014258891929902378, 0.017561805321865024, 0.0359758872899317, 0.017940691341796232, 0.037493553433206775, 0.020834262888397903, 0.06994103892676293, 0.04093907217705443, 0.041924253586799874, 0.04042067580045231, 0.013750510237690423, 0.01110720333658279, 0.040060491901972604, 0.03756384200025951, 0.09154251205825037, 0.03129318825930598, 0.05604188273390455, 0.034763001566452366, 0.04144073719339025, 0.027118830701276183, 0.027472830354987134, 0.04147923694202497, 0.04174760520277966, 0.007443428058327446, 0.031588620491205685, 0.026371261037345377, 0.02885900899737833, 0.05501178941959816, 0.022164185779289376, 0.032531885400174126, 0.1383642738144244, 0.03924825101069385, 0.004864306876345748, 0.07244217044283306, 0.09162480522307659, 0.025324873032889543, 0.03948547779732654, 0.03896839143107495, 0.04725174392543493, 0.06476343369051334, 0.04201033505641165, 0.03328781882901827, 0.020288827438508312, 0.0493571910286142, 0.030232141162419034, 0.03602459132971783, 0.06899616906359311, 0.010342662909909362, 0.009848281474513634, 0.029180647181947867, 0.09445481828504032, 0.025411410324816263, 0.07016944804138715, 0.027316479470520735, 0.03845035511579725, 0.06837083447364069, 0.05407076148736862, 0.04856195728925448, 0.003014690526235368, 0.07494059000765124, 0.019660644916697376, 0.009848865616555897, 0.049731233457644144, 0.0247911874565386, 0.07496829940787247, 0.01733054444494267, 0.009312570553212877, 0.04275969162042584, 0.01724240411403439, 0.023082399613133842, 0.06699274955016953, 0.034607520191780025, 0.010453673838187131, 0.11906200674392524, 0.06043373456885738, 0.03022724203014326, 0.12483373614809207, 0.06421093490996188, 0.024327985799661087, 0.030320051666950027, 0.046070861524992415, 0.06278780401654302, 0.029863846308041005, 0.020031753228977323, 0.01532135820466905, 0.059247198439533674, 0.04099972718845933, 0.030888113523683244, 0.04080696414495188, 0.042457159668687856, 0.03523443292285647, 0.06244618625890824, 0.04371785310908191, 0.028286683861346498, 0.06502571921314924, 0.08747189621170683, 0.0386551074353197, 0.029942780177319245, 0.060357259841816085, 0.051717925441241076, 0.038296260360267856, 0.01985236991106743, 0.037174952787257014, 0.008507495456855864, 0.024490457726642493, 0.04495973526049526, 0.027058775153672023, 0.013063168491146738, 0.05854268866260687, 0.04868830050972681, 0.02167984201092153, 0.03460812923167983, 0.04377769223684746, 0.032914186257027814, 0.0678657373834041, 0.05248222455021836, 0.045357170184293104, 0.05231615200999284, 0.07640891242772341, 0.047567195950015906, 0.0033052841946858195, 0.028415513037133123, 0.019284309969554027, 0.06330505892213795, 0.0537726077281179, 0.04170108451357773, 0.05247310810391942, 0.06429243517378647, 0.03272169134429386, 0.022055309363490632, 0.037959882644035166, 0.027932080913395173, 0.011703556820359683, 0.03822431704329868, 0.04288736017300718, 0.05202025821011874, 0.10936879582943455, 0.034472397603695436, 0.09487102619342266, 0.021879819687455896, 0.05208880392714374, 0.0723725407113952, 0.04277409790384193, 0.026161190152408618, 0.07705279400632267, 0.01583129792819701, 0.04075717992119251, 0.024421913924837307, 0.056938102183442925, 0.050762629121421814, 0.04506164027618305, 0.05828484644993179, 0.013113179668453673, 0.08545346903584658, 0.013648064172406112, 0.06186919947785716, 0.02772995052979358, 0.08338439578731215, 0.07251899373987991, 0.03851791640983955, 0.03864536662736247, 0.007806295179761947, 0.034291221640042724, 0.029133892835929032, 0.011400778762876027, 0.057122932386494456, 0.03552679122696, 0.04592402545254558, 0.06315210946805536, 0.03337891434409446, 0.046570726234706185, 0.055263093071839506, 0.037427907358975186, 0.03357756860373962, 0.04910603293307847, 0.024789904259265434, 0.04060951264334783, 0.029066850566455436, 0.03840309515174839, 0.011702958314168838, 0.010061085378120263, 0.05238117372256614, 0.02415482120047654, 0.07276156015934483, 0.03937022369955817, 0.03685801838254256, 0.013243383972064383, 0.06301792533767801, 0.03579003818994088, 0.020032176492555488, 0.05301701137796045, 0.012854737034367939, 0.06815430738272206, 0.05552645877844865, 0.049713234221863176, 0.009307246242139128, 0.10843848163682608, 0.06596891134376488, 0.004021732254900158, 0.04125850785884165, 0.054275333776228854, 0.031256412208500894, 0.0988980056717992, 0.07532546491993052, 0.03074833503623884, 0.0847216175809022, 0.10252721697813082, 0.1603083261438916, 0.08826036156425554, 0.14173829357229895, 0.13761539222492328, 0.10784873183095649, 0.15503920404420746, 0.1280668493540537, 0.0989693820837044, 0.13604949318593548, 0.1079947941545998, 0.1393130583868873, 0.07440125644807855, 0.09323732837313607, 0.08514895674682434, 0.05915064837843661, 0.16063490942601236, 0.16731056895467544, 0.13486193432923288, 0.16511045636669283, 0.24059558167092263, 0.10911067782510674, 0.15868820340162323, 0.14282987693384772, 0.1368708313713151, 0.13619261373194957, 0.07914333303849544, 0.16547254016322477, 0.14588149624966806, 0.17965794510899052, 0.1304801718722428, 0.14629683847869598, 0.2045440202158305, 0.10918652819048975, 0.12186770417517233, 0.08194088695510741, 0.12737206123288602, 0.19243396277869904, 0.15902442406983147, 0.10654678838627954, 0.1387281962219746, 0.13418045315530994, 0.12380164717474293, 0.2437800712763302, 0.1704782199475073, 0.19711007153795612, 0.2051996842267052, 0.1415676704698032, 0.10846078245630188, 0.1527043365903439, 0.09014178157573746, 0.20147781458593186, 0.090138832137229, 0.0888267839928308, 0.13878689387873297, 0.16861345468749925, 0.17460934907918976, 0.1381057651052552, 0.1740762131709245, 0.0899046313978972, 0.12844674469482514, 0.1443033704474088, 0.15967975100201948, 0.1032907844731404, 0.22222370540182437, 0.14672753310972644, 0.15149235485061524, 0.07876808785142438, 0.15132622102335577, 0.14988258961708317, 0.17132611074034246, 0.1502877888419936, 0.09358196068675288, 0.08384011084994963, 0.05504866123139378, 0.12489241082221271, 0.20193008225291006, 0.16864599810252268, 0.2313865919507319, 0.14991649666861182, 0.06375687842768046, 0.11478372744374699, 0.18014297069561097, 0.09634312542696154, 0.13227287890209308, 0.23646226152777675, 0.08862205465594608, 0.2028469975677229, 0.11273746063271839, 0.14389890666690566, 0.17342070237763468, 0.1064792730575127, 0.21576915416986714, 0.16004840783294172, 0.3112436891082795, 0.10228894831192109, 0.14192100554223985, 0.18323715385650435, 0.11185596922352431, 0.151888667455604, 0.07718966327487461, 0.12026542362066046, 0.09212435583674139, 0.1835620670669502, 0.1550153174227284, 0.11967101600021125, 0.17678030436077427, 0.19646605206353052, 0.16210302500234497, 0.11099056566074011, 0.19175215984784788, 0.19315145008506315, 0.09354285189821836, 0.18364161763700748, 0.07988417836567087, 0.1475104596465826, 0.09713057188257095, 0.14007609728122913, 0.19855132807166348, 0.21759628919103455, 0.18116899225259983, 0.11198829559068527, 0.1089774244915574, 0.20956028733522664, 0.10410946433342273, 0.12760830742697563, 0.15195013835064827, 0.15165278898371806, 0.12850750312809983, 0.11895273196240587, 0.09272748919864816, 0.1480894688997538, 0.16341597713049383, 0.10698220211892359, 0.13005721472924756, 0.12948943632504634, 0.17940199513348842, 0.11687920774303137, 0.17194973695422375, 0.10024870295197734, 0.14725245655544345, 0.23501369651527176, 0.2161348232578847, 0.20028480118320835, 0.11176498096075752, 0.12745882069031078, 0.1011828629059657, 0.1047092498911004, 0.16759782128276365, 0.1667892154786856, 0.08749297895138303, 0.16640759644008454, 0.14895117991874296, 0.13153216380986477, 0.11004416362172174, 0.16740780083402512, 0.14248424870592935, 0.28014119353986555, 0.07305003822811189, 0.13829186318382142, 0.1797913976254002, 0.20201231413070234, 0.25211903026267407, 0.10683720465749504, 0.11978679486820776, 0.09412076564565783, 0.12323544691166571, 0.15820368343303282, 0.0889941588825276, 0.08641145432428007, 0.1934921293849907, 0.1508280034026792, 0.18517273628423292, 0.15266168081471998, 0.09995332243101251, 0.17453157583311682, 0.18202219969562947], [0.06393681332889585, 0.02522006262874892, 0.01874337145577996, 0.033804112294268225, 0.06446954704100086, 0.04032319494252724, 0.023673070639732386, 0.02808882250270296, 0.02311745962698854, 0.03735018007817768, 0.028021969839990623, 0.04990360707104687, 0.02791560044692409, 0.03619461305319302, 0.019478178094892253, 0.02270368021732617, 0.03637593840399096, 0.027601201793239005, 0.04859788298246361, 0.1014901407723946, 0.0745984934450638, 0.039047731326953064, 0.11308302757360282, 0.002050779308305092, 0.05813390031577118, 0.014454766247992315, 0.04200280824255559, 0.03728587082737396, 0.05492784150485551, 0.1100275854790403, 0.024287446341927976, 0.06381686694259125, 0.04732422350395111, 0.034705751815870885, 0.05970749470795836, 0.028439468606525374, 0.02252805073024525, 0.05156547011386964, 0.057697306807723746, 0.012765101874397408, 0.015139042685228973, 0.0627282215282321, 0.05557639621979287, 0.04251338669189042, 0.00873847862690567, 0.10817548365242059, 0.018108116027208108, 0.009753562363555596, 0.03597829663645356, 0.02952980132953775, 0.029819386395355387, 0.060528633710477626, 0.03929144687830441, 0.027710403796405565, 0.027863968036047397, 0.029575711063620065, 0.041089485880107655, 0.0456536921762651, 0.049609065416359135, 0.0221181764537769, 0.02092133069621219, 0.00777938538381169, 0.05362531966379574, 0.08321248565710361, 0.05727768214719911, 0.01796029936221819, 0.06545844397717906, 0.013150115640112951, 0.040168437520943345, 0.032273625669580315, 0.02922921715634725, 0.037692885680664936, 0.04219017419663649, 0.041184346717331684, 0.04064625422019632, 0.043562256821220925, 0.05355609212851813, 0.03756461191862341, 0.0159086124791253, 0.03280087036170787, 0.0533959414479473, 0.03401772442063497, 0.03455965118783136, 0.023809164244261, 0.010619935027564005, 0.023289120778621688, 0.058234771112761194, 0.0286439853540111, 0.03861531299809295, 0.019347042994453542, 0.04573803462628876, 0.05319381681000514, 0.02179338390217914, 0.041787200457146095, 0.04042573198075256, 0.03213400997581982, 0.03992548805751628, 0.07331898105480979, 0.04124204845978849, 0.044930493684425477, 0.02237074606631312, 0.025357473904507297, 0.07737361630725284, 0.04742048628207657, 0.05659236670321515, 0.0660189368852204, 0.012707455673315113, 0.043750691467956196, 0.022606804568861282, 0.03553294291299197, 0.0715804594238439, 0.038254041254760764, 0.044487181585282094, 0.03878579054388308, 0.11577339046784949, 0.013268527935349174, 0.017836223762001724, 0.04943593720635099, 0.06297946772387912, 0.0344561412179422, 0.02315776925834437, 0.0377861415636876, 0.025713053614562078, 0.031842354557386814, 0.08361662768067853, 0.048684424104829954, 0.036852108014206734, 0.0738805618077036, 0.010265389536207002, 0.04890313071589317, 0.054384570253352006, 0.042000854718348676, 0.031089483565019987, 0.061039533916740656, 0.011266826374095776, 0.027011616696273128, 0.022975716124018355, 0.024726265335395455, 0.02141568531853057, 0.04744265303616563, 0.06342096419464197, 0.04415537741395735, 0.03063152386476436, 0.022219018522469748, 0.03639870653710058, 0.024520545829868606, 0.04704021555822223, 0.04027360224074895, 0.044706470423167756, 0.03186413060663448, 0.0284857556389104, 0.024415245129456444, 0.03532010453542875, 0.07318018124468866, 0.011638027574536542, 0.009642280431674614, 0.08264373432123855, 0.09187205243975886, 0.029357360683441646, 0.020611875224858522, 0.030102907875252348, 0.03356744858225988, 0.03963216831306777, 0.017196624614899198, 0.02875258980859672, 0.0061180983433469895, 0.08310150249951309, 0.017514051231105002, 0.025508324277677366, 0.04818768120340763, 0.021481595693096038, 0.00983826200207395, 0.04078682369342254, 0.053144783352411566, 0.07152092673124806, 0.05756674627322824, 0.038438603327038794, 0.07632553141804473, 0.03190002948676627, 0.02403026871052721, 0.05373443739729063, 0.022927891170125336, 0.01915074828561516, 0.0288190919860837, 0.024579896576582425, 0.05100636765541089, 0.030369502642462333, 0.0665804640119595, 0.03784400801504812, 0.03166103686746811, 0.06066370650284714, 0.04140528647469417, 0.03497052329382108, 0.023895230392114292, 0.09620363613770855, 0.08297268481504533, 0.02086413648700522, 0.007156138383452931, 0.034894347341070255, 0.019171658655508392, 0.04642638377845288, 0.023771499531463753, 0.0333947800250063, 0.07396953525922953, 0.08142991397049158, 0.06839086001198139, 0.01744723112712945, 0.0652630455912121, 0.06994416456549399, 0.03874100504382964, 0.04786621921906068, 0.05763274091746538, 0.03950723086393649, 0.07684450236059005, 0.022919774468567584, 0.11632811473382097, 0.037364237791588234, 0.05216137160577121, 0.04842096263723028, 0.047377949250080896, 0.02111779585961373, 0.05058038446511473, 0.04691797090814479, 0.047282402764164636, 0.030670021698179267, 0.06967384278053237, 0.022706625825395028, 0.11860390148696401, 0.04358462658860991, 0.036954947657162146, 0.06429869411212784, 0.03494215505798498, 0.04713947757057125, 0.009440111743676807, 0.014252733540601067, 0.020383332044847553, 0.0425427355202696, 0.06958987954403124, 0.05280477054897816, 0.03374020140918513, 0.011723696314279112, 0.014300098841739519, 0.04806539441849436, 0.03882258191644665, 0.022206186549738053, 0.01915411332682256, 0.03086112233089103, 0.023485800446642023, 0.04061250038625252, 0.023122395148440715, 0.05235059915350811, 0.024450282160673412, 0.0418479090947057, 0.005937719111135531, 0.025546845093729998, 0.0615253983696382, 0.05731289920907828, 0.01520315754122191, 0.02866897322688132, 0.0359538201272728, 0.0329223987195761, 0.04857814472709452, 0.04828444193868388, 0.019259059711569743, 0.05083294833199151, 0.03602043147228899, 0.02911135835963632, 0.025208533005488497, 0.032731593030715184, 0.043837554347250736, 0.025737821237154068, 0.06173650538849254, 0.05599277266751855, 0.014541174262581814, 0.053784447616987655, 0.05911734653636814, 0.058937515057022535, 0.06567601294767472, 0.06866197852838425, 0.02706618513911963, 0.0016687354500097556, 0.029066496250790455, 0.06320662428474715, 0.060794205750308694, 0.03600000373778805, 0.011062453268095853, 0.02841752210271455, 0.014066040786283632, 0.057942569856682134, 0.052161095814118465, 0.0929391822747646, 0.01443374862578968, 0.015247222918626523, 0.05267637038242914, 0.045168176293373115, 0.0321834379686944, 0.031683885439809774, 0.10861513385128592, 0.07543391232649166, 0.02658314372022306, 0.04026031061526268, 0.06843146267196826, 0.03471501764931506, 0.016025684120494033, 0.057909930680668166, 0.01800337265576086, 0.05072703667645974, 0.0772316295713667, 0.039596066419636054, 0.014742512702791682, 0.03633482629553445, 0.02342463407154766, 0.06882407507228275, 0.01615591906762171, 0.03161403928853331, 0.049467388946082325, 0.028866166173810923, 0.03950248494924557, 0.023596515473459038, 0.042092835064977414, 0.017425763428271297, 0.021028985201771704, 0.017439405538982922, 0.009132455621335295, 0.023162199161766518, 0.020963873473867294, 0.02574837601353084, 0.012588294527132907, 0.026359405826717138, 0.03810289593773984, 0.029058785575832573, 0.030650925041446765, 0.04306084461390011, 0.025417443267219973, 0.04318206653659863, 0.1098961094694753, 0.04477940199355926, 0.04685904725544876, 0.03248692753033773, 0.0071005855176237325, 0.06319599481479776, 0.03313071334794645, 0.011585535229964843, 0.020860945730800592, 0.05014306317353922, 0.018378654232008323, 0.020285366636310375, 0.058176238164906545, 0.03085858083420223, 0.0654750757460152, 0.030887778360216372, 0.02343679188690599, 0.1522424775025537, 0.2095599962218154, 0.14193349277540562, 0.16761718798548947, 0.14131901365134025, 0.09183396254816363, 0.18178817515652027, 0.08381686008144772, 0.11759789780743661, 0.11445845417197674, 0.11999854157047889, 0.12544642262641462, 0.13267294533791082, 0.14634660355025722, 0.14208687889960506, 0.17277613131990358, 0.12875622889447597, 0.1219274054071115, 0.1109339747457735, 0.1276082844443379, 0.18739895714867502, 0.069272841717447, 0.20997924549925714, 0.16534199878092737, 0.12239870269812884, 0.12453185154065011, 0.10041030153872506, 0.09381794641094823, 0.1646099864475189, 0.23182744490763835, 0.08956196793024579, 0.27166102922731833, 0.2029635961497984, 0.1341656983018883, 0.16874591128960734, 0.14161345188415822, 0.13223103517966886, 0.153196670655762, 0.14405117430273565, 0.15698054745312662, 0.10294737790020243, 0.14553488742920662, 0.248842456888768, 0.13833448831592837, 0.15242165014628442, 0.1875497385739319, 0.11844290044879723, 0.17578719394101253, 0.15181762046150624, 0.1296804986533619, 0.11744073486977047, 0.29996316699731734, 0.12750642539392557, 0.12324175947616178, 0.17111540591764837, 0.08562390827724049, 0.15049276332701408, 0.1829994827388756, 0.1133736583494371, 0.0895121262498921, 0.14085914639215316, 0.11734469808758267, 0.11057920708891847, 0.16409296902918047, 0.13843910528286812, 0.18431231229295655, 0.1145527825780934, 0.09632945075751313, 0.1411657654229672, 0.10006728567062848, 0.09425099293190627, 0.18679098977196604, 0.15101123631240862, 0.12335584528984563, 0.16372209054327783, 0.16092197789299875, 0.17497098854472562, 0.12168111580033457, 0.15831233002245426, 0.10106888434459126, 0.18645642385367425, 0.13487601502528115, 0.11875521151288865, 0.14959596548109286, 0.1166817868849443, 0.2728415400751176, 0.11586239456289238, 0.1485077682281694, 0.19977458662563757, 0.07553588629009263, 0.15388762067642905, 0.14787888665112758, 0.13603450850613658, 0.1310046509869637, 0.09359622524390299, 0.16098796870679627, 0.12950106553973692, 0.1187814040590198, 0.1543842601559816, 0.21507163111480976, 0.14030382457760074, 0.27412795491756936, 0.1547098475238008, 0.11137042269711533, 0.17509624392034548, 0.29602857006172983, 0.127902033198024, 0.11721555098530748, 0.10645943138027385, 0.10236587886127735, 0.15921779998367833, 0.13598350237213797, 0.13444568811645433, 0.14168494320925207, 0.2718873316001508, 0.11488852827178855, 0.1002377249120224, 0.18108985537002165, 0.17875601447397665, 0.09627105187504523, 0.15762580798998957, 0.19121939166178628, 0.1826355603313254, 0.13430478922542066, 0.18270728148279652, 0.21070316794418523, 0.07635302631364715, 0.20649910724211126, 0.22204730599637956, 0.12347663437286693, 0.18818332393082882, 0.16645396008126198, 0.07941299598784217, 0.12159491558709454, 0.08739965412044719, 0.07081656251102686, 0.13869395209175928, 0.11880106953603607, 0.15954219225433566, 0.16158156427404574, 0.15191960208598645, 0.12228020421800115, 0.24118841115024783, 0.11254913323829252, 0.12288562052192227, 0.13779637283615528, 0.08550320346389087, 0.07791036048964148, 0.14198935590684414, 0.10855984528579059, 0.0960848082397734, 0.1664250938882751, 0.10686256982866796, 0.18797278764747805, 0.09828043921339898, 0.24008997896265602, 0.1346389720997503, 0.22247896589819463, 0.09800142233049679, 0.1822699065650663, 0.146997379920175, 0.10081583784232218, 0.20892346908728923, 0.1156151090418139, 0.13464623461327246, 0.08299790442951265, 0.17460522752615715, 0.160283412964594, 0.22269638165110545, 0.17202148874921186, 0.12123781902294968, 0.09491539800599699, 0.1548866912602417, 0.22279583518543553, 0.11999266567609965, 0.1553875442233778], [0.03191091368095048, 0.04907466163257918, 0.03924040627034922, 0.04003842856975333, 0.04601906632043181, 0.06399127068899332, 0.033143510846721555, 0.018382538297784426, 0.033750807896496794, 0.06545450628524827, 0.012147432951737317, 0.05001578532579926, 0.024816213633805036, 0.06053121159634283, 0.07446982131730165, 0.02870926945169847, 0.06176504599411161, 0.032873058826812816, 0.03603827366004548, 0.04358851448482564, 0.053056200605727015, 0.059210341949496544, 0.020644432046420632, 0.030316102483700362, 0.03860555686837724, 0.0747032636295884, 0.06865901376811728, 0.0499902707674811, 0.043653547688717806, 0.011960552505878432, 0.04436402146013514, 0.025084874923190763, 0.002689318141839918, 0.02728316805235321, 0.0345774665625105, 0.02674290369595251, 0.022423378221931, 0.04220238946858914, 0.039685277358418515, 0.0459586066614476, 0.04332797564265709, 0.06447778248618688, 0.04501816095604051, 0.03023188835340402, 0.054370765348956476, 0.03902738020124455, 0.017436276069812236, 0.030712880487103137, 0.017218630490524155, 0.056308695836172956, 0.06943261701493494, 0.04427376864177566, 0.031607897178600394, 0.07752004635309981, 0.05048553894964918, 0.018819256295119564, 0.008895932677983037, 0.08447419416399733, 0.048918425661301425, 0.03244208074325035, 0.05568040031639319, 0.05819234899395417, 0.028889418857532646, 0.03523630983827095, 0.005462378791097793, 0.02451615614606248, 0.06235899396180626, 0.05077361865269561, 0.015539289151708928, 0.01255043541952487, 0.029211886332280217, 0.03274241402264565, 0.023524269551759767, 0.07283645291482249, 0.03570391075505364, 0.07326453518603118, 0.04021463645321708, 0.04934429776884856, 0.10596702070606333, 0.060206650786342165, 0.03107034477345165, 0.06650868157345442, 0.07805065417121496, 0.030745412410807707, 0.025425784049495578, 0.020920066651137128, 0.0978637793131413, 0.031848100216818914, 0.07669727558330183, 0.05596351193925066, 0.037314771494317445, 0.04578057931916368, 0.01996310217486274, 0.061624959156277685, 0.020890966801333333, 0.025238760919760794, 0.03022552599319287, 0.05929422857720525, 0.02574651633509465, 0.055235870137450196, 0.042005899407330065, 0.04453788128411097, 0.013173377899933728, 0.08207689054430493, 0.016259459681027842, 0.06689113564789295, 0.05262896486167466, 0.029640598710806623, 0.0787106772223788, 0.05177882177034213, 0.04678891956686013, 0.038122500127722184, 0.02036289856468718, 0.03482837567947084, 0.0500682317050955, 0.0525531949355237, 0.030629432444731076, 0.018813608311897805, 0.07501450983146507, 0.013335316438197851, 0.018579570366249933, 0.013960946929611027, 0.024062808295111024, 0.02774101092420038, 0.03135975172382689, 0.04019919978154283, 0.004317400537641539, 0.04062931601619048, 0.015560961779086821, 0.03720209911285389, 0.026949303104512157, 0.03495973294540759, 0.020166745582114787, 0.06658751968174212, 0.024139510933309797, 0.02617228693599182, 0.013662143910844481, 0.03173704236565578, 0.07566575351501666, 0.05362172288099124, 0.016851915692489956, 0.029931470804337054, 0.04097533877938986, 0.04259870973445716, 0.058654786478127205, 0.03716135472660104, 0.023616196272233804, 0.021047673916684526, 0.02951929251843643, 0.017037646048852516, 0.05081818198725101, 0.05250325749417948, 0.019835479587556857, 0.0058011668114622515, 0.016598062882680568, 0.050854620959369407, 0.00984438304458895, 0.009144149953499436, 0.015058434913836181, 0.06931706031243648, 0.06783111020922661, 0.025012720932042407, 0.011077887066940387, 0.03958956616359853, 0.07611383068104906, 0.05850549892432267, 0.030516539812989296, 0.013386424078846411, 0.04580806272344724, 0.12297516853939142, 0.022568272261489785, 0.013693131209771722, 0.03619507270594759, 0.019968935934406136, 0.08258922716542598, 0.045557957998807394, 0.011397684725271839, 0.06382765346056511, 0.005393371984903371, 0.03665805794298649, 0.0870911811568564, 0.07199397836361202, 0.05802179866981122, 0.026476107830662402, 0.08441650774329902, 0.06512213903929918, 0.0566674356589154, 0.03636274253949523, 0.032590824374628645, 0.030922455330108924, 0.0262339934030728, 0.04512576566588494, 0.10086967084076136, 0.02662815904665378, 0.010627490569717221, 0.035020338161097425, 0.018231511724391775, 0.07855158374314347, 0.06832745091448869, 0.02111308250365959, 0.03247885679405543, 0.0439874739235928, 0.038694377102318316, 0.023115596118112727, 0.016690972110917492, 0.04258191708715693, 0.003209431513002323, 0.005434646408238839, 0.005569561194973968, 0.03206817237960716, 0.05769205144456318, 0.048464491753087896, 0.019388967156109792, 0.00640431693154237, 0.020443002633269758, 0.05338618914867121, 0.02740693913261977, 0.08252413267449987, 0.06516352310896882, 0.03317871258684224, 0.029927728464826945, 0.03243395638081335, 0.011695299350145844, 0.03415503802018301, 0.08021281476342872, 0.06080337582276233, 0.051191550258907585, 0.028242145424648642, 0.0074098327088229846, 0.03312312141661683, 0.11314593105306549, 0.08260682420504671, 0.058980630485401045, 0.07869936976461642, 0.031026152991539532, 0.07482965281533618, 0.025398166579825264, 0.028284979315714973, 0.04321521899152187, 0.023390972168154778, 0.046472326071271976, 0.0433651309069847, 0.015318984289713686, 0.025101813127196608, 0.019668229187147755, 0.023116032788229567, 0.007675457417198848, 0.011849864292138768, 0.032278298805918426, 0.013176708467184536, 0.014282737374155512, 0.0666908189774521, 0.032039649010966384, 0.07463374115045994, 0.0202160012052064, 0.06454368903031273, 0.023888132587495833, 0.016266921377410332, 0.03195512653028052, 0.0732362435589875, 0.03795846155093562, 0.021303049326243422, 0.040520600478855834, 0.05898655617549535, 0.05713501742349998, 0.04105398919613611, 0.014154475103432854, 0.055993875834129514, 0.021817195830085588, 0.06531483313489346, 0.04348042330914929, 0.014034558403035326, 0.03888109571210319, 0.030747724081119223, 0.026648211398071824, 0.03949750154729813, 0.035036226824647, 0.03968871326275891, 0.03417682556074954, 0.06132122827693821, 0.1020735550311304, 0.0492205630777584, 0.02199280041930897, 0.03244014637124154, 0.02784950621125679, 0.0320802784840306, 0.03609729307373205, 0.02152289357787419, 0.020280149577546026, 0.08056153798656118, 0.05466640633981555, 0.05917231717537488, 0.04737404986254631, 0.03925127705799476, 0.0312790003109483, 0.00811615093205605, 0.020114921649257024, 0.01409891936477394, 0.05517444520768139, 0.05197854472264167, 0.05036772228777409, 0.06579680203069603, 0.0038689831806902565, 0.061331256367867036, 0.03721391984952554, 0.06636500944413486, 0.046950012535577824, 0.026702249325030757, 0.0442862865184584, 0.005571799129322773, 0.07204780370117196, 0.009844744063523269, 0.021967316504507776, 0.014505702476467819, 0.03602872820450895, 0.011804134588718656, 0.02346685892271419, 0.011162191212567832, 0.029560632538050417, 0.05416985879081392, 0.09496092661133698, 0.07008835763460206, 0.05344854104482839, 0.0032760615314116645, 0.03405923872525173, 0.06865807914084966, 0.0425000146271721, 0.03793289719690238, 0.04041142528876662, 0.06804196824950558, 0.052834253442744096, 0.02454201927438619, 0.03452688177687026, 0.05175081742627006, 0.019637995527216026, 0.03425830667237601, 0.023511552492216713, 0.041929803893811284, 0.03929999641953938, 0.018201800919468367, 0.036682760448104916, 0.03903506406312508, 0.04516344570044068, 0.03165564360848117, 0.0171116309901399, 0.05293930324936106, 0.02116988600802518, 0.030786528349703843, 0.019005346712806535, 0.00498329900437966, 0.1163718966586936, 0.011585326471005478, 0.19340435103062661, 0.2223967033768854, 0.08907429934028657, 0.09815841672881957, 0.2040014461043381, 0.10797182683862987, 0.1503723189835587, 0.17906701552771753, 0.1475777681316099, 0.18797309408264776, 0.12252090904381006, 0.1457523031821174, 0.057997356634587056, 0.11709162860267586, 0.13984791033210295, 0.10159675722881671, 0.20261884126211369, 0.07583480613726763, 0.19247543877891957, 0.09399202456998249, 0.09557588837079464, 0.1983662565509158, 0.24047089320036674, 0.14160272665321827, 0.12872275085218493, 0.19465085269222338, 0.09279556377159973, 0.13005343025490163, 0.10976746032435088, 0.2009264611068272, 0.14693590902513073, 0.19582448407046257, 0.14486240012751472, 0.14447581683916433, 0.11958666205886873, 0.13327081567577778, 0.1378029611923041, 0.10445691585060089, 0.26197881167454107, 0.21082675324813013, 0.08438970232682844, 0.17410736230592574, 0.15317350415693176, 0.14859208386511574, 0.1579933310107839, 0.07924559811550765, 0.11149641351714251, 0.15491857583965027, 0.16715223390248515, 0.13927858443029467, 0.1535755011343187, 0.11993818150292482, 0.12246799535088002, 0.14591177204443564, 0.3009336165362789, 0.161414128097315, 0.14517401405159505, 0.18890687865355324, 0.14023018820631888, 0.14306218543600652, 0.1400205405849603, 0.12108017344989123, 0.20366335618159465, 0.1579102564362749, 0.14305979524168277, 0.07323528594908214, 0.14481438173642083, 0.1308652842717786, 0.2243666218653802, 0.1192336334216018, 0.1521095152824156, 0.07396422626991427, 0.12640690536148128, 0.12271590140317717, 0.1314388696224459, 0.14131932008650996, 0.15002151200127217, 0.1336801977407548, 0.2351022256358016, 0.2069039847100935, 0.29234794659479973, 0.07193408560969176, 0.1870204790705635, 0.1480369612334236, 0.12216348306185777, 0.2135303234981914, 0.18137523844357462, 0.11302225381856966, 0.18927645478998462, 0.3408248872766572, 0.13318303732141373, 0.18198697497287106, 0.13590261880909243, 0.3072943832845457, 0.10459934691748313, 0.1386254638313286, 0.1491030645106108, 0.1807149012963618, 0.0673535386581094, 0.19848106248724848, 0.13584300184682493, 0.12077230569576064, 0.11749481301634543, 0.13456774124455068, 0.23432168929326921, 0.23227781267656436, 0.10034374381986358, 0.09272668480632767, 0.12329535498734444, 0.16506352582045142, 0.15122989312775675, 0.12657187473509582, 0.06368496192378864, 0.24511036763508476, 0.11962074531061996, 0.23212087190439626, 0.23538907959816918, 0.1277163334851784, 0.23290309364036207, 0.09311525992328122, 0.0591908258596255, 0.10627733994155161, 0.12046631485704454, 0.09453960123562044, 0.1285616732052257, 0.21596225429206126, 0.10028280152548706, 0.23943829860898758, 0.11342736111292917, 0.15687295806504067, 0.14662146057573058, 0.11731237683805729, 0.15641047078515255, 0.10778107094548403, 0.1871757038057812, 0.09365852351390547, 0.1281928631567186, 0.04273133487590859, 0.25412785069596383, 0.11300193716681774, 0.1548766708301921, 0.11884184073536627, 0.14164535178532525, 0.17265899647628108, 0.2220914633043351, 0.14210377879921468, 0.12075156003477112, 0.33679737919761293, 0.14298030595865943, 0.10613969692419614, 0.09597452222219399, 0.16574771894562632, 0.13974827293667103, 0.1290208969505564, 0.10972705684722432, 0.1542955624961084, 0.09436369978732641, 0.09357171809120525, 0.12309391216765489, 0.13043541701570635, 0.16560378634641248, 0.18444288431877093, 0.16137887273103962, 0.13390320593551283, 0.2483161544847873, 0.10006715543568136, 0.17803949243839712, 0.1556378557917572, 0.15335957159198102, 0.1839080017300383, 0.09792157298614902, 0.11985578874666845, 0.11961848535124334, 0.11113287415355445, 0.16456219788280227, 0.13828844643167912], [0.029715148641938166, 0.018289173247232553, 0.035875751937349, 0.037299296518246976, 0.0174675535245408, 0.06400056716595447, 0.07608936183274755, 0.04608073639833639, 0.05198342470271934, 0.036210329346959634, 0.02631066348253479, 0.0330036346830668, 0.01778679959956677, 0.01938682977080105, 0.04990576360855372, 0.04605744732543827, 0.021560826421444936, 0.05984193547779034, 0.055665725902203596, 0.030903431451729232, 0.06694538233381125, 0.054808634393397844, 0.04457089967364746, 0.030064025082655495, 0.01329340281025056, 0.03349095087258085, 0.03577088599183387, 0.059614093268230084, 0.052793731221989285, 0.021483980141760364, 0.018755399036191164, 0.05831417995655249, 0.018220677325922637, 0.010417357440136615, 0.02494501025085488, 0.02906681034683941, 0.06199736215714967, 0.016440737151330518, 0.013788572358598393, 0.01395503273083558, 0.026302991111973123, 0.05898387486776037, 0.014798513730056586, 0.07245459638896488, 0.00730268286368359, 0.06730201158432231, 0.03656299026202291, 0.019172037869030913, 0.06585281071884018, 0.004087620125632853, 0.06197344489215363, 0.060340651055617686, 0.023359577885017763, 0.026723567636743672, 0.04054827157468085, 0.04678700817748905, 0.027186526060705225, 0.03708868362610379, 0.030123063648540168, 0.029773131921707146, 0.03365482857090331, 0.035772981242306774, 0.03768472684427135, 0.019281019621919242, 0.024314822493902138, 0.03281516556237494, 0.04423532634973527, 0.0213805946611589, 0.08363194943916413, 0.03180070810260312, 0.023088591518781842, 0.032457398671296336, 0.04576415056362749, 0.03150684635094818, 0.05843644375882803, 0.055351641344567465, 0.04051681600450989, 0.06983318906878272, 0.02875782410433937, 0.08144099926275593, 0.06333400938479651, 0.06208685271802449, 0.03698402069388859, 0.013384814336595517, 0.019556828511638508, 0.003805232455863828, 0.013782176482040557, 0.0698408116436293, 0.07248638903782254, 0.028314318567995104, 0.0637583339947366, 0.004208137247441036, 0.04175612027005803, 0.034376743865469774, 0.0602971104484412, 0.014603766518825246, 0.0298790397467993, 0.040433733769121676, 0.0703603494912386, 0.04077193860505377, 0.061926326654370756, 0.027604702815052964, 0.044153351111397635, 0.026382436344940818, 0.14240711897371278, 0.018723995176955097, 0.060723162586650545, 0.029760181205347184, 0.08311737584130419, 0.05028741712111139, 0.051062445291468216, 0.026805577349037896, 0.0995414122758854, 0.020045165513311664, 0.02728222001854691, 0.04283543090305982, 0.09487219830794681, 0.03418881483676453, 0.12040637613784884, 0.027235821903412862, 0.029619456599316293, 0.05460671659919524, 0.01698516519559968, 0.027789310852606452, 0.04538199909391903, 0.0625164058780478, 0.05318880659498034, 0.08360597905853102, 0.03889184392568085, 0.01666279922750208, 0.09233630938275207, 0.042231378235643914, 0.062477427324460405, 0.02220333861787954, 0.1424701220446056, 0.032717259525651896, 0.05258118778827691, 0.020801267481499144, 0.03986837237232155, 0.0037003803956923227, 0.029456532680459564, 0.05183245175548139, 0.08376552452964169, 0.012784573914212807, 0.09575621780729103, 0.13596552994943437, 0.07323221393650578, 0.019068803690794497, 0.050426324183541926, 0.040898737647841056, 0.007487048147126071, 0.10212823838716555, 0.034235664943773905, 0.02709116152067098, 0.011320953358775906, 0.05406149565392444, 0.06794167201845877, 0.04399461769348672, 0.05846362072794188, 0.044794505416986444, 0.01674747109533318, 0.018790072175644098, 0.07615934396463056, 0.026635021279235522, 0.03447714351838635, 0.06810493301600218, 0.027784459600825945, 0.030795769285290476, 0.04797624476674584, 0.03847383188023683, 0.03493418391313284, 0.018047878533721935, 0.04102591590415086, 0.02285885324160899, 0.03172901184898952, 0.05063517507345927, 0.02256541858397184, 0.012750110491329144, 0.03299705015735761, 0.041171625827349005, 0.016138831476470637, 0.023114253549025427, 0.04500935860579053, 0.02320279033043452, 0.03154197531271606, 0.02050883448382299, 0.04471391296735214, 0.046483878677170125, 0.03609257397211848, 0.06229797505863732, 0.029400962577652068, 0.023310906403968414, 0.05870184342887613, 0.014265598072069547, 0.05949223549255441, 0.05442389354650533, 0.09514453490414927, 0.08876937336378521, 0.022644201150885033, 0.031321514360306245, 0.02017273255924304, 0.06793588805463045, 0.0045292027812871725, 0.008643200271762908, 0.0422698550016409, 0.06530793068269569, 0.019210321197827018, 0.03453183070486111, 0.0711806687796789, 0.03505086676488, 0.0410179409288591, 0.042355281466077414, 0.023990866893361655, 0.04206807893370429, 0.03630815494445063, 0.015238630284945813, 0.06949653173045767, 0.04819054637224444, 0.04804960151593532, 0.03415482734600383, 0.03534239003314607, 0.029219641057293744, 0.03600547360556741, 0.01206652544844415, 0.03463236059272482, 0.07654763562905212, 0.06742551261859556, 0.04049903127334772, 0.009711235048129194, 0.042269180844267534, 0.03577499222310801, 0.041767619249801484, 0.05909394638072099, 0.005755116308723847, 0.05093388424645509, 0.023082451324068734, 0.003442895850316892, 0.038107699309025085, 0.06941608483752898, 0.040232359897345304, 0.01174281020798991, 0.007572840418546431, 0.04379264627312941, 0.06551197054044855, 0.03663964501972641, 0.043049621425809405, 0.005806987164466973, 0.011053513022019498, 0.029083880701012192, 0.026364241756739158, 0.06489485607392366, 0.09341339069989421, 0.005469772975981957, 0.022575542435891206, 0.05121913708506092, 0.026045815395792166, 0.01456750757736905, 0.023031328361661687, 0.024276299762629697, 0.022061953261013956, 0.05585956146880504, 0.03598720623901294, 0.020508087548096816, 0.03300085761434129, 0.005408062199656402, 0.016870225193880258, 0.06006285991339434, 0.014154432968597018, 0.04002818214376608, 0.06774894727934754, 0.034758401208467064, 0.03344401649589981, 0.0507020622101282, 0.022139843335495363, 0.03200060725512524, 0.056935715819558794, 0.0851429736001357, 0.024223301800027974, 0.06446282844990492, 0.03604388142365121, 0.03873959161160934, 0.03812886248793333, 0.07871587895938466, 0.02250994424215488, 0.02738560166870875, 0.029696712736040357, 0.03938637666344162, 0.021497430730490916, 0.0627540463521596, 0.01903813719118555, 0.03469673879144173, 0.02906543904945495, 0.10830122166343274, 0.025353900104340528, 0.12250431557937015, 0.05555459718790747, 0.061927567716808095, 0.02198679812042223, 0.030316161855514494, 0.011297931459041373, 0.010222886020558016, 0.0241419815668656, 0.039913031467867476, 0.03432985162362456, 0.05278250803389857, 0.010711991982985168, 0.09017201140522958, 0.006645290366929746, 0.03417645017766664, 0.061310686907100106, 0.03298419903242781, 0.010655635682445382, 0.03316191610910239, 0.022128434371083014, 0.04224671148544839, 0.029007461515345404, 0.021023118883491527, 0.037281128743122664, 0.0751278755225001, 0.029760543181891405, 0.01870796287191972, 0.062401366284898216, 0.019071745468423735, 0.025762644401120565, 0.04435060343014137, 0.046006782100565975, 0.011631218010499593, 0.06733552793100958, 0.05198563869682051, 0.05306164749086865, 0.039458457876237175, 0.02046076246657439, 0.020472518085772475, 0.005595285948666354, 0.05022897610380765, 0.06959083715393659, 0.04403583705425263, 0.0639917877983422, 0.11058274641512864, 0.01330076012715337, 0.01662934225262894, 0.02451877425154371, 0.058596870231051604, 0.019154821958152518, 0.05306689902358959, 0.023135414812713865, 0.04163841086049234, 0.026338549082978602, 0.0748591318786625, 0.054766882601524555, 0.018404168790326487, 0.0366475893515012, 0.15915041488985862, 0.16342618142164525, 0.0864903690413602, 0.14692231862535401, 0.1427397083851599, 0.08386264149580272, 0.24500685383475598, 0.17614546261968153, 0.12433335815946903, 0.14152090846290513, 0.14973759981653384, 0.1353967249874146, 0.11080292008456685, 0.14988905539916408, 0.18722657204395343, 0.08496312679903162, 0.15181003619105587, 0.15036991346747647, 0.17009969590412033, 0.13397269011024507, 0.15572630830349463, 0.11112630111916412, 0.11805966496467592, 0.18756349751305199, 0.10418670131794869, 0.09912507413255592, 0.10120899416506292, 0.11018512379978934, 0.16419112021403928, 0.11982840876425467, 0.10764718941983678, 0.20529208975213192, 0.18217918643307301, 0.14660456067612096, 0.10729910204968146, 0.20996030780576894, 0.13851168445281445, 0.10712233492203298, 0.18645597952267817, 0.11008346393223732, 0.12898446180887763, 0.22050677978944397, 0.16603320927148865, 0.20345969936780392, 0.11436037193503111, 0.10277502343899782, 0.12295188712737254, 0.09087659013006957, 0.1387952748806246, 0.30696187048189105, 0.14915466819319034, 0.11941374069260013, 0.17022024749988512, 0.09070980512807447, 0.18625005508863157, 0.05627342131769946, 0.09861958633747794, 0.11104629089635228, 0.1882764955441798, 0.13374067272149748, 0.08836114043069464, 0.09290945040242327, 0.17719454342319121, 0.12670956371772674, 0.07250452233899025, 0.15169794220597516, 0.12556672907404362, 0.19221634784292793, 0.13460301193258456, 0.14508507124358608, 0.16557669747740994, 0.17637489063124503, 0.18897791032589253, 0.12500525557345923, 0.22828526885038425, 0.1409400299551987, 0.2428168229638569, 0.09152346711245277, 0.11863578606637255, 0.20373919888609843, 0.1431731302892008, 0.10572503651342086, 0.11797315065538692, 0.0705101503239524, 0.08755041256306634, 0.11854538769130746, 0.126075794499728, 0.1002438459545374, 0.11629885017511346, 0.1610415795397374, 0.1432926093618716, 0.062210346091418504, 0.1487879265820788, 0.14322027534006104, 0.25719195724495, 0.24400523983903472, 0.221308475480445, 0.19181432022202402, 0.21888311772096544, 0.17927503904267666, 0.2010664866576272, 0.18240130596583892, 0.1823637370140322, 0.10688942887129323, 0.22142873596279855, 0.13637501926672074, 0.2385137683802074, 0.14387440717508718, 0.151418074965477, 0.18220016192043983, 0.1502444589089963, 0.09157694771044678, 0.1788713566718563, 0.18811852821419317, 0.15106190536772052, 0.1828931957002609, 0.21917236187765676, 0.1809658717003561, 0.1963559499070529, 0.1912512915629533, 0.11175276185836523, 0.15583464845774636, 0.08498740412535206, 0.1530579474544333, 0.14077728223656455, 0.2622421620593917, 0.14861339643116922, 0.13011336897409734, 0.14540034706794447, 0.07278402185728473, 0.2133771978438862, 0.10833525128902928, 0.20048511785364923, 0.15503846859980017, 0.2134255379919083, 0.13859650570779078, 0.13656891612035615, 0.16422747874692564, 0.12424029379842744, 0.09232134768559087, 0.09225389364385798, 0.12506301860294997, 0.20878269277032346, 0.14068593391247336, 0.14698389677270768, 0.2879340850537823, 0.1595886937913395, 0.15878499094997683, 0.08998031322393688, 0.09789573284046305, 0.11742369707433448, 0.23458589769659505, 0.18459657687814007, 0.08275000603809472, 0.15728995504398502, 0.13163085125627058, 0.2064061041681036, 0.1040382104955854, 0.10282475020616286, 0.19392656252509166, 0.1752640171757629, 0.12764314144489267, 0.22597044225661989, 0.07903752863527307, 0.18302139285351002, 0.12417946641723956, 0.11814521400318032, 0.09963481371561367, 0.22982130578208357, 0.15034711469084988, 0.12207047232697088, 0.09529291847420317, 0.170488148447006, 0.15644198764235745, 0.13982296650928838, 0.24310563811131064], [0.031082372353862853, 0.016717574514088132, 0.03536225469302266, 0.024335953114073605, 0.016343813622370362, 0.007775221217138273, 0.0567417998137253, 0.07430874367034243, 0.011487981593686969, 0.005020309669611555, 0.01620578564583294, 0.014984704696783617, 0.02653329629420994, 0.02416205881614118, 0.01939567808632649, 0.02450383936745986, 0.0453739206967575, 0.031188404668242704, 0.06483146995906869, 0.025160566325329488, 0.03312010686063478, 0.04868149381851958, 0.033771545896607066, 0.038413410525648825, 0.010250140556074198, 0.04531359127272041, 0.05311424708774975, 0.014742416941801147, 0.058612540559542764, 0.01940469685641508, 0.0768974696796748, 0.08124185470683921, 0.04937839251191867, 0.0535819475959626, 0.014274768144523185, 0.02858390107810978, 0.012238310131755088, 0.0205236372177399, 0.03137078913559597, 0.06094338222136421, 0.03514297351601624, 0.07485206854800064, 0.012888336693116976, 0.012774622432076404, 0.03512531518936157, 0.015099440727593198, 0.044493578419449835, 0.02151289996090195, 0.06002391583376354, 0.0674016259971165, 0.05442076790777426, 0.0501726801326919, 0.03506536880928663, 0.02859028450573885, 0.0398087477491748, 0.04571125219245592, 0.040776584928314534, 0.04528108999253281, 0.03804025675861105, 0.031851405886212186, 0.05116812329018309, 0.062136449250242407, 0.008376358441197345, 0.06596453698171724, 0.06411515476722872, 0.031857228154436715, 0.06371130385706503, 0.08085258244987457, 0.023962245848510536, 0.030690847798400832, 0.03125993621295258, 0.01730960534675227, 0.04879110567872563, 0.07964352716601665, 0.06233006265134581, 0.026546511310903777, 0.018958757075691418, 0.03486009171953605, 0.051099041311611096, 0.015435228556124194, 0.014888909232291966, 0.056743071519679604, 0.051704162671681375, 0.0389257509772095, 0.05443438895106797, 0.06737115868036786, 0.06433149799704552, 0.0232637268791516, 0.10518960234138275, 0.0422199213907363, 0.0252188426337295, 0.06302124249839014, 0.02823400191001354, 0.02842875103646469, 0.018600800577851555, 0.07227925418485558, 0.043706530329561046, 0.053398963664808584, 0.017724041676809712, 0.04625526654924597, 0.04411919508129359, 0.031176087889640085, 0.03846732396332007, 0.02565703535031888, 0.003322658111198595, 0.027184968986999125, 0.02866439010587431, 0.09899097810228986, 0.05717594950129429, 0.006505932749038743, 0.006946344726583771, 0.03890376042334303, 0.02152819107587059, 0.048534761167942524, 0.03040969544540971, 0.04150465956979221, 0.04495295155192575, 0.03548623070180897, 0.0534569182162804, 0.0426868251675079, 0.04384761308169654, 0.07197966018030721, 0.008733960623372226, 0.023244536376648375, 0.08349119610483609, 0.013728849101631392, 0.03552033693619794, 0.04143166288192715, 0.028147311400501963, 0.025363091244212082, 0.056111160064897234, 0.06904730543253884, 0.03240001485532811, 0.019574770290825157, 0.03924498747613642, 0.06675288742107731, 0.0820416275171503, 0.053139508837052894, 0.05223565915178868, 0.037387917569327744, 0.07093936640528903, 0.04401267438586201, 0.049072773225845835, 0.03409074792157739, 0.08579982504729303, 0.06635379391692339, 0.029800195892852162, 0.02420037853411369, 0.013162107788957657, 0.05113043176430849, 0.056697370544556654, 0.011740382666879845, 0.05439627224639539, 0.03777027205233613, 0.04854828645024569, 0.042920960789366115, 0.02928935888884289, 0.03898884214821362, 0.033683652629054366, 0.02312278202284248, 0.021411611645993207, 0.03632490928735464, 0.11333222065361277, 0.11314274412730049, 0.024270538781439106, 0.05942965760045956, 0.002302680987932329, 0.02430460862665167, 0.004347748153152004, 0.01436620073828606, 0.024896434530796065, 0.043780526762167295, 0.05882474691456845, 0.06554001701935645, 0.02629718991116651, 0.058243699867518685, 0.05326197565262837, 0.056601046479397246, 0.028665554559519215, 0.0539982206218185, 0.031385065184064934, 0.048360705991545995, 0.013809329510906772, 0.04331226700976972, 0.03623233905302421, 0.033248480214106466, 0.06039267991699519, 0.03713853296733672, 0.053924599572295145, 0.04627004055486572, 0.012416888099734583, 0.061183600581341216, 0.05547148047856266, 0.08663424035354007, 0.08487236836264211, 0.09675780115949531, 0.019385751502047625, 0.024351353396571452, 0.01954973453745967, 0.015804515494364166, 0.014194314548325156, 0.008640644410925527, 0.02001158021871121, 0.040034647925847, 0.09376340095073947, 0.027278809012064052, 0.01733656015036808, 0.023511533340018605, 0.12069454777144617, 0.06781594932920511, 0.008123574324042327, 0.015218022519782668, 0.08203554477903151, 0.027512732044523282, 0.01599903287921822, 0.05996793012825712, 0.03726585294991251, 0.041118532103756746, 0.0507367123669434, 0.03696152452199209, 0.03464492443468302, 0.008628982637498167, 0.03256219183845866, 0.08831859190738009, 0.03940342595019648, 0.020128586742606376, 0.032007689737985213, 0.019402584368963877, 0.038851225943935495, 0.03420267719775438, 0.08779580584697186, 0.03297307926620687, 0.02987827557409483, 0.08646429140841769, 0.043165553511390765, 0.049453055441019036, 0.017216125383011757, 0.10773030995962121, 0.027903155348594152, 0.008255520520070869, 0.025500127136887565, 0.026975633546469674, 0.06291387527580224, 0.004767259815707803, 0.009927311104782408, 0.01828078075402206, 0.033892043866217136, 0.03781772736880568, 0.054350238023025375, 0.049121994374980854, 0.013557217635905311, 0.0643017124985495, 0.017978041958544525, 0.04110463909924992, 0.011856041833638184, 0.031098431471975583, 0.04721328248119643, 0.03011023550624809, 0.029319002661072922, 0.06111836053370949, 0.010853951905793961, 0.06675563767672547, 0.06590021623959465, 0.06508487652266218, 0.0476208335960344, 0.0693196420287413, 0.04946304905799128, 0.04894484037293061, 0.03680991572177699, 0.05890985545251639, 0.012338429204969397, 0.06723453455995168, 0.046251302044237816, 0.038660439407272686, 0.051167732585341706, 0.032149806708818486, 0.02937894712592806, 0.028905341995038816, 0.04571780990508776, 0.03344683186902154, 0.06756817351185507, 0.03803888929166621, 0.016417624278654976, 0.07094433831591761, 0.055059106840241345, 0.08598070606709489, 0.09225662857774766, 0.05095475248151249, 0.05434477964656488, 0.03947957892030959, 0.008075295463054171, 0.05013379734009505, 0.060896934310515086, 0.045629847689621875, 0.04618513503021771, 0.04185315679698702, 0.009471757878218929, 0.09603904980805614, 0.05092047004690094, 0.022111766213070483, 0.04956863512615523, 0.016685329873355168, 0.006239701873592792, 0.07220444569904959, 0.011721019794593656, 0.015530037682413336, 0.06997527539609902, 0.02747500412947228, 0.010796951133787874, 0.04320998278055941, 0.025784548770095554, 0.09975571005094437, 0.0439480816825263, 0.07352038557010313, 0.056795843486343665, 0.054841802170079564, 0.052899527964332414, 0.0368621782399714, 0.021210793187961947, 0.04017454707213948, 0.04398534036872368, 0.033290270310375965, 0.0202363504156951, 0.020630623311585477, 0.09683239514068251, 0.10111781438031506, 0.06502689898855264, 0.02710579954568417, 0.05103597695368433, 0.03797010991782431, 0.013228875224388415, 0.05915749720447968, 0.04142233193100941, 0.0561092563364054, 0.052337771011216026, 0.0404801280538161, 0.02940470491716218, 0.037015805681866985, 0.05383058909266707, 0.03821212092354413, 0.04125169350675518, 0.06364785645517611, 0.011526122238607177, 0.04617437149488157, 0.06201159990122242, 0.04323393451951204, 0.05633259394897088, 0.02243849122145724, 0.03448529852434032, 0.0979638227351731, 0.023587711207989245, 0.06141679774549219, 0.1273641322228697, 0.14499078114186564, 0.08600015703949236, 0.09706949169236807, 0.12069385063143508, 0.11628417193048424, 0.1283329423336733, 0.12025045426262003, 0.1668043227325524, 0.187972848934512, 0.10978874990776663, 0.11402860223766297, 0.1425293406411525, 0.18090872154120477, 0.0615165040888373, 0.13781639837449597, 0.06901596477555652, 0.20570505710859455, 0.11958146032186286, 0.14667767610761429, 0.14692037276202632, 0.1481657865787706, 0.1383516333636738, 0.09726592429703283, 0.09908473194246331, 0.13383611195510434, 0.20151319252627514, 0.10331898416963317, 0.14432114368725207, 0.13907212373470107, 0.16087084918493227, 0.1283313335490323, 0.2294444824538885, 0.30633211556461554, 0.17354004355447908, 0.11326458275077805, 0.23046132627754445, 0.0743675485794102, 0.15850769776490428, 0.1691229491224212, 0.14147745595583994, 0.11069469484350375, 0.11835613333049322, 0.07208296713689644, 0.10698816994385374, 0.09877746173691365, 0.12182957597918088, 0.13047387462950524, 0.1493109041644681, 0.2063206087557539, 0.10684972253417778, 0.11416497354906414, 0.11771375328422555, 0.07793827673360225, 0.1753869742876099, 0.168216559855688, 0.07930707667143115, 0.28390945746533336, 0.07042416461533116, 0.07854881050485758, 0.13522083119999978, 0.17366594244395533, 0.0590036744101634, 0.1361278333370724, 0.15704541977855468, 0.09451127130418055, 0.12729373640350758, 0.053054787173506715, 0.12842712518308433, 0.1299985323942477, 0.15279588409729544, 0.13082607589181394, 0.16011510344762958, 0.11770437636803235, 0.13595990686407014, 0.1771931644649275, 0.07935485757526853, 0.16826727487627538, 0.13554735319508662, 0.1621663345084075, 0.15559290175236043, 0.2174908295273781, 0.10468554713072316, 0.13570464636769988, 0.10297896370532052, 0.17724216344856447, 0.2126143428106462, 0.17888410437491634, 0.19324249197398463, 0.0857537525195268, 0.1292564996307896, 0.2665239500422632, 0.09073353087108943, 0.15918363246225542, 0.1536410016518447, 0.27546235750759807, 0.39886637440612244, 0.13671825730031537, 0.12798044229707412, 0.18142960004268155, 0.18529779247699246, 0.16464174845285956, 0.15507372396607555, 0.1699021065066899, 0.14884791126654995, 0.1646446749087303, 0.11699045903139538, 0.16877859260045713, 0.15791512875547334, 0.14897108288301578, 0.13444026421395042, 0.22179904754363725, 0.19517353916120148, 0.14136510150086495, 0.0910948868840933, 0.18572154635142896, 0.14620126134926273, 0.16790969567673822, 0.1064303047173927, 0.13614303252149013, 0.16225086464997263, 0.20010713007180922, 0.10009742356956967, 0.13944744553056457, 0.23331782299905057, 0.16437228468637313, 0.11284654389225668, 0.19812513803762777, 0.12169949424963807, 0.07417813334013186, 0.17223505874074277, 0.118504103213068, 0.13723987124619946, 0.1689737764818053, 0.14888198685742196, 0.2217012334374651, 0.20856222798747404, 0.13776554545808223, 0.15230517413827682, 0.12637438492909556, 0.15480904058823663, 0.11468465695337904, 0.16333979734730336, 0.11265349739621724, 0.12462316156034509, 0.1597980043340114, 0.11500801500533858, 0.06666732306081442, 0.12300227273015246, 0.22454919593949474, 0.31145911303258716, 0.06646861517501455, 0.15257459193948777, 0.09279892689758733, 0.10090449719779915, 0.15015378474227845, 0.16167930177142545, 0.1347809741573949, 0.14082687876878247, 0.1337981599593355, 0.10293224000281866, 0.0783462338750401, 0.15969565498732752, 0.27269239807801865, 0.11740040034055711, 0.1892344272064586, 0.10040723718702795, 0.10969852773292411, 0.12363624113101153, 0.2082899909827017, 0.11889273195617622, 0.13406261351079712, 0.17654226552094185, 0.26044130385402714, 0.08487517990532421, 0.1854257291603473], [0.00404485566128466, 0.036332351831539024, 0.08023149964790191, 0.097025916611235, 0.04572234131515988, 0.07212339359666071, 0.02295931609677932, 0.04792657545617512, 0.03434980055317283, 0.009940345133204135, 0.04251057897964793, 0.019990240839580377, 0.07797376192625492, 0.040470260841351365, 0.02832452285914652, 0.04912690499857549, 0.13891098480070793, 0.05763839081590695, 0.04605877648798689, 0.07799180329687173, 0.06063424276127931, 0.04932778091320107, 0.047042372095729076, 0.03968418951356604, 0.030164704357664433, 0.08644397475666578, 0.005486375537715973, 0.03702922754230038, 0.08503191383375276, 0.019903766749907407, 0.01978012398936816, 0.01154915467205067, 0.08565943177428939, 0.05747224549732863, 0.04528867809342281, 0.05672393464333108, 0.08658168672193443, 0.04006536039073141, 0.01845651366297276, 0.07095219071714148, 0.03363142841525617, 0.01796464116552905, 0.009569417809196299, 0.05778652540738544, 0.022242353560643333, 0.03380630713617129, 0.03589815234825496, 0.04019154656317927, 0.026608152660511197, 0.03673342950341683, 0.035045373914462906, 0.060057849698369546, 0.03904123873179478, 0.028045145914919918, 0.04327989596452925, 0.022892754547478213, 0.017030442907144467, 0.02063259981843012, 0.020446520892062017, 0.05460666680348016, 0.017683144072971998, 0.04204822576514656, 0.05630629032009071, 0.07032789800676607, 0.03921864171242041, 0.029287127657763423, 0.0242163265694774, 0.06014479684733576, 0.025760244630697756, 0.012965210743488805, 0.02041812009748913, 0.024255724556203333, 0.041213032879656365, 0.06809730278027636, 0.03467155748137063, 0.005042315066431559, 0.028125334253174164, 0.06800226191239012, 0.038793210105429736, 0.03207549234972366, 0.07992929328353175, 0.08404477123892115, 0.02341075830401913, 0.02270293902725943, 0.03080242658935247, 0.003901203881175588, 0.027251607145092664, 0.03620672107283627, 0.011613741629726945, 0.06960841121091958, 0.02752375221931406, 0.027092312567777214, 0.03016949815285062, 0.013744252256958956, 0.015420327188387034, 0.03815606243968491, 0.056888168572538325, 0.05577578209340573, 0.07108754313160336, 0.02276866554072307, 0.014425404013074456, 0.05008975494532816, 0.04856270805542027, 0.037351700762707385, 0.057540538405338605, 0.02966994945440562, 0.01088294163045864, 0.0470940102522652, 0.030130450651350043, 0.12835439279555313, 0.025837274771484158, 0.030646474070606694, 0.07485212983503457, 0.02895262685694522, 0.027658043602000804, 0.009773983394787198, 0.04371168227085183, 0.07791592228797176, 0.02751605495089485, 0.027462539878944238, 0.0196550294922124, 0.01961069406881448, 0.022123788047822255, 0.03424986821389006, 0.04306580503320983, 0.02555720451768608, 0.004303175721302508, 0.046968525050268065, 0.017360352926076423, 0.03362677826155578, 0.015982940244758805, 0.0653749940195872, 0.03534967552930598, 0.05010834406881083, 0.01693788033369328, 0.02325411439092169, 0.0569527191410382, 0.05361375556657872, 0.06386496194247758, 0.03944096808892585, 0.04659191239625216, 0.025921726389037027, 0.028704575247942444, 0.023123994356982654, 0.02321040907484149, 0.03928198569243954, 0.054072638402783105, 0.03953433888513715, 0.027740281225452502, 0.051979939002663865, 0.02268029729865732, 0.059896369855250084, 0.06175453909823011, 0.03516677586782364, 0.08361864249191939, 0.00542140793010232, 0.02641797899418781, 0.018605916129965937, 0.09173090073971019, 0.03281662879031032, 0.07222452486354498, 0.03162741135325163, 0.02503760538304285, 0.03139727279513834, 0.019226012593736092, 0.01928194467308781, 0.014602761028424628, 0.03214969179562984, 0.030671693685074008, 0.07016187909269525, 0.030289199391019442, 0.025602589481540268, 0.025777910618231665, 0.021400041803116762, 0.04060503868987003, 0.10848477633009035, 0.048952673621956384, 0.07938043725106024, 0.018420473056574984, 0.10375302660489276, 0.040921976925024105, 0.05644457302086296, 0.04344608724838303, 0.022987182545025023, 0.0794340480840014, 0.015627244663905474, 0.09642010960247248, 0.042539893334070523, 0.054244257419580416, 0.04083144448457226, 0.01001877913011178, 0.026677121641114358, 0.011752698487872559, 0.0927590290384908, 0.04467544003179477, 0.07151757126613971, 0.057792562180228775, 0.0009042110034516232, 0.01605190156448272, 0.01157139228927272, 0.03627411765797484, 0.04536213443404244, 0.03810486861414487, 0.012775652820334561, 0.016570857185269558, 0.09421852612567526, 0.05869518995525376, 0.06598333677937908, 0.020956808227985617, 0.08904430699805099, 0.026668738724002918, 0.01795308281397147, 0.03162865050046915, 0.053365723109774055, 0.027185675703109275, 0.010635876359658377, 0.026924064337846734, 0.043620678686326554, 0.03241968416278401, 0.02308757453706236, 0.0677594273621517, 0.047819886221400196, 0.01407926825190624, 0.04138992258137272, 0.041041207019119494, 0.036994190511083415, 0.043121798399595485, 0.07614828165500395, 0.04033507313579321, 0.03936161670172888, 0.0404639674290534, 0.056084339326668176, 0.06493615587392161, 0.019788129608176892, 0.021983231981134704, 0.028505491979059674, 0.035062227848797076, 0.029107441735123436, 0.038752553819288174, 0.06522307112332314, 0.04599643991358819, 0.023323184878174818, 0.028908917710425395, 0.05708064433307417, 0.017872965338850216, 0.022229546485769174, 0.019575120776050517, 0.01865019409676954, 0.0681547440528389, 0.08128201303582999, 0.004905020140276681, 0.051814360589149504, 0.035660236082490415, 0.0966232301547162, 0.038416482538225195, 0.02314999346591292, 0.038722867912222306, 0.06559262427711679, 0.029561885091806614, 0.08590070350516228, 0.04178423952731875, 0.035647959523503824, 0.05255625928722082, 0.04950347934819518, 0.011532339999722618, 0.0296154135702959, 0.03645009188462169, 0.060011007252239415, 0.054892961521663015, 0.13910780811021406, 0.028185119754785014, 0.05137773260714547, 0.03442338712873959, 0.025360319921146, 0.07311909339360653, 0.02969350474285743, 0.03573419038026083, 0.05431312106309399, 0.025540570833630143, 0.051557158059891195, 0.03878872466063307, 0.06494022380079954, 0.04579343810497273, 0.06628781076400511, 0.03533844468033603, 0.06845365623913466, 0.008018831910204985, 0.04258270998815856, 0.030148049606190577, 0.029556447782764034, 0.039678428532375444, 0.03203146144627564, 0.10099398392823436, 0.07696507693899256, 0.05255062088009812, 0.04144388198431942, 0.030720596907720454, 0.006117910173000588, 0.013448253119995278, 0.03176379990163109, 0.03238621761181182, 0.018334554380647117, 0.04675453754081842, 0.04593298102038042, 0.021687734631761428, 0.040700818832603194, 0.02223155172091098, 0.05141533603290877, 0.02034001551838892, 0.03449759806596464, 0.03351975960897342, 0.025363422577239336, 0.048278792040242303, 0.042394520489559065, 0.057392671944633614, 0.008990495698526502, 0.03496790710355967, 0.04441684322251428, 0.04627975071930597, 0.051457317651159344, 0.03811983797218531, 0.01873808927954205, 0.007651815943855553, 0.04282303177000534, 0.06920411596975981, 0.06781197333287808, 0.0630760369371743, 0.06952677688170826, 0.03231323241526562, 0.03002115480241276, 0.031971532303178986, 0.039994604510044864, 0.02376113436184824, 0.002290280897267944, 0.01429980198266886, 0.016214314119649992, 0.04654664426080642, 0.028725839933500658, 0.09570882760829504, 0.046000163100900195, 0.0782066909596324, 0.02403539958440008, 0.04185315679698702, 0.043362258077268644, 0.02783688682792408, 0.09931864156838387, 0.002294529333613032, 0.059233899153168165, 0.03885333651616689, 0.02523487110832526, 0.07310714242198775, 0.06417425078970772, 0.1756392163975585, 0.12570620304153812, 0.14693088348834746, 0.21286097715698907, 0.15092047021513985, 0.13006852218700996, 0.13612830831158546, 0.14925634338250085, 0.16697912867511475, 0.14319585245703498, 0.15390969933040682, 0.14508419790335242, 0.16116246821418886, 0.14643668016839415, 0.12013791594654323, 0.12258397340173684, 0.20116477573831237, 0.16380778513848782, 0.1501293465374939, 0.19138103621380945, 0.30092715075419796, 0.19023837010946967, 0.15927505739513906, 0.22400939506628822, 0.10285785286537102, 0.17407086587721304, 0.1343306983190198, 0.1130988626109977, 0.11941128921124244, 0.2150515749329521, 0.06687960602463254, 0.15593488340175923, 0.12939511557980893, 0.14004309421345112, 0.16031712083326233, 0.10600422193566639, 0.15632442378949735, 0.12243719861632395, 0.15487912231154982, 0.15024303398545713, 0.12089017598379044, 0.1284158790123559, 0.13495265446122617, 0.15824964870848965, 0.11311645965061842, 0.2589692812292807, 0.09360681257901654, 0.15973333119144364, 0.10345285037352193, 0.12642765102247078, 0.11316371961466729, 0.16230105873077147, 0.19352597514948539, 0.07665032971530192, 0.11399652613627334, 0.14717908065405585, 0.13256261335505595, 0.12168781140879278, 0.10076676224989277, 0.16212594635303945, 0.12221115671338574, 0.09068224128455886, 0.15090551617885792, 0.20159197700840814, 0.187721035833801, 0.15441983727918518, 0.12135233384587112, 0.14190995855437172, 0.11453857164709799, 0.10323007966602042, 0.19603466795336819, 0.10374741118040778, 0.21666656488612776, 0.25982110971404665, 0.11631674598902465, 0.11065407686175839, 0.14436824277283686, 0.25080970939128633, 0.13876207262998627, 0.12243631761521102, 0.2178010951367117, 0.15853903076100737, 0.1267950897735934, 0.09565173873617765, 0.09405623039891643, 0.1525927788668102, 0.11489170753667433, 0.11295247086954695, 0.12729161433995734, 0.18916780820056317, 0.18795743524547548, 0.16247621707377896, 0.14731529108699293, 0.2041957413236941, 0.1731069127638494, 0.20809840771459764, 0.1736276840130168, 0.20352786587130642, 0.2260876383872763, 0.16171380637153504, 0.1334091251896274, 0.14011397266820555, 0.11202131398022176, 0.0911932525735709, 0.2726716217735122, 0.2290266734217444, 0.12200579152352388, 0.17439046243746437, 0.1137378488877608, 0.16326207006650587, 0.10518979386336381, 0.10144167805030462, 0.14128322202351787, 0.1493825640289053, 0.11555298697203399, 0.13487238376852007, 0.16453567591886367, 0.22872956920294996, 0.21009935276402583, 0.09193760658343954, 0.20970978173277072, 0.1273807563308266, 0.132797327373297, 0.08435963337580044, 0.10775707707169557, 0.09184972097676608, 0.08289561636986272, 0.10037488529398557, 0.14366169520203145, 0.10546285824309434, 0.07109337306070714, 0.1768568365444099, 0.19790424424554073, 0.16764338819249985, 0.11448392659545907, 0.13385200061865393, 0.11587406974285842, 0.1804563006566417, 0.19146901375103384, 0.1678424331569864, 0.09662622555850015, 0.09872240299779562, 0.1254761621596352, 0.12775928037421358, 0.1384648918023994, 0.1057497811533751, 0.09205795133546477, 0.11958194295725516, 0.21395798442104172, 0.1679155026232043, 0.1747948036438996, 0.23396720508894614, 0.17118642226822917, 0.12216219603414498, 0.204160746427313, 0.1808123476803303, 0.17639951269713142, 0.14229494837983964, 0.2175021063416235, 0.10324852706323709, 0.1395798561673972, 0.15791543519064305, 0.17794258231597562, 0.1266904421631367, 0.1832060200432616, 0.10374085346777594, 0.1282389663280018, 0.13339228657705168, 0.18167998821985337, 0.21422341856504643, 0.12778515116341654, 0.13749560671708277, 0.20043201263873808, 0.10865154601032696, 0.15638030224269436, 0.2442033961415291], [0.02843860675761056, 0.06289500269978758, 0.07979361911214168, 0.016096711962393696, 0.03544039566129927, 0.03492905112404016, 0.020798896439373497, 0.039219771692108725, 0.019979603708751743, 0.01817493804640347, 0.02870511533992906, 0.03242307410184895, 0.0712354900315404, 0.062088093780461824, 0.007489773983721652, 0.0844972763931559, 0.010966621414427797, 0.00894881955783574, 0.01410464491439803, 0.04351655967653759, 0.041228557651441906, 0.02052438032302645, 0.052670777940581885, 0.05658176787678273, 0.07337762508541346, 0.03633673002402629, 0.01605845353145513, 0.07462635606286988, 0.04229864458583536, 0.03499387365375315, 0.0078761485131127, 0.049708488307172255, 0.002075166999167132, 0.08241427566615805, 0.026572828346322623, 0.08181532514431784, 0.00648111054268215, 0.05705940837581312, 0.017903264116255507, 0.010755748052390353, 0.05238341836018428, 0.007136205733273059, 0.04323786072012398, 0.06136091163141593, 0.008900005392910493, 0.09960456090348382, 0.006439339119805805, 0.0166841903175678, 0.05559984234071547, 0.02651461332495655, 0.042469072335910414, 0.029732182606934544, 0.07241721129826001, 0.06963141683128572, 0.03968560677622596, 0.05725945308504086, 0.01229583950442893, 0.028560207893831596, 0.05642607582793121, 0.03684936158899819, 0.01817327372038797, 0.04725701077991436, 0.06953511957920368, 0.0371684525312195, 0.016315217475376783, 0.014748029493456407, 0.05540114594623447, 0.02795788850034437, 0.07535341180740826, 0.06993919265486541, 0.06998312013644366, 0.03782996179295644, 0.0529545943643297, 0.0339437777837438, 0.07394299797353245, 0.016117308236237977, 0.02615177684703902, 0.0634240668507353, 0.033350120929460374, 0.10131125924207511, 0.029660327390076655, 0.0061021426471040375, 0.04747741044529023, 0.09419182796151408, 0.05606803314519986, 0.06458935553147908, 0.025180203074048606, 0.027641737420532494, 0.03706122703489758, 0.0142009804708763, 0.018532369774015203, 0.0423620613442073, 0.07686147120811286, 0.011020470692235376, 0.021973427970923727, 0.025054532095729828, 0.03825321387980254, 0.06680115862118621, 0.04756143496882531, 0.025883536906011646, 0.043976752523092494, 0.040649851003000816, 0.05946380213924474, 0.014310994527242599, 0.009669799267524674, 0.004667797662888564, 0.0161977781118044, 0.05722049368365158, 0.0263132241314217, 0.04574194550514222, 0.04029592604286248, 0.016817583462163326, 0.02901903710388128, 0.009258255876991297, 0.05187748240367059, 0.04635748183054309, 0.011418497418954728, 0.14987973977000485, 0.04543478255190196, 0.046466178215679624, 0.06973885300178682, 0.03455472524247823, 0.03509811523761, 0.04670963329713672, 0.016994116932994897, 0.04855556811596598, 0.041539853649033655, 0.06626766265159653, 0.08479159205190598, 0.008932213644467054, 0.04040806982365828, 0.038998697869359486, 0.05230955599296478, 0.03325294650670502, 0.0878009692795815, 0.12217200962045502, 0.005928330703623474, 0.032276540634132204, 0.012691406131301437, 0.06424697168592004, 0.013780831040123539, 0.017045915967995123, 0.009870096785767425, 0.04924320480636051, 0.013515092376168939, 0.026622375082825462, 0.0854849552495345, 0.024995238805610328, 0.02218695774283861, 0.019731320358151873, 0.03491027047857642, 0.010470507662713287, 0.06406559270896739, 0.05257415127069239, 0.029031403678198977, 0.0377593859429321, 0.056690023761362805, 0.04932131896155977, 0.02415626527621381, 0.017960092518478632, 0.04642154976365067, 0.03308794265913387, 0.11530370962235237, 0.05817731451844016, 0.009968274783703589, 0.020676724567648866, 0.03677747189818371, 0.022232001797566493, 0.023144958353030588, 0.021755362958497098, 0.026220286174887614, 0.017233197652404348, 0.024710702259213697, 0.02635269872694006, 0.07111327602497994, 0.048259241476414666, 0.029589205702406265, 0.029800126944938977, 0.0338829618938748, 0.004047696411068882, 0.05422484858201877, 0.025000141768325723, 0.047386165543068806, 0.11977256095457463, 0.08908753733961813, 0.04859763400388822, 0.04311208057427599, 0.019885007171861587, 0.04000251819830268, 0.028888648939168746, 0.05808544525456044, 0.061914122873736974, 0.04812339876568125, 0.006417087138435173, 0.03844215414456783, 0.007122022094159958, 0.005507048899157634, 0.023078145909934275, 0.0634377568419422, 0.03990193851472389, 0.0068663565287997415, 0.02850578500769071, 0.03212054981099021, 0.0191620844716747, 0.013998477577021527, 0.007811248895802325, 0.03739524136988386, 0.046121396514917576, 0.061637814111647114, 0.027062337462519927, 0.06572026218618117, 0.10806705156761794, 0.027817424364207734, 0.02454019023946697, 0.05340121979374559, 0.03813191534831159, 0.0502439990880028, 0.04360600427213696, 0.10466750576010636, 0.05740482975999194, 0.03368011713328381, 0.03172648950449882, 0.03919070631626152, 0.024527530636518233, 0.04669399744260215, 0.015502789850166489, 0.04900857888823075, 0.026598342904640783, 0.04143567718265038, 0.03704572141531014, 0.06400802120145771, 0.010397854756804244, 0.03270451948347111, 0.0070860298470624035, 0.02350261224614036, 0.04549837168005686, 0.06714442729829781, 0.04525355296209455, 0.06524981525275977, 0.05317882063888735, 0.0354403113916276, 0.024017072846031478, 0.013574622195935058, 0.018652988402473352, 0.05438544742402531, 0.04166817720679026, 0.06282180299862258, 0.0283908641581694, 0.029950898794096806, 0.027496971700701024, 0.07583342717900392, 0.07001612320422165, 0.043564754267854076, 0.023432076615732045, 0.04812443298437903, 0.0057168013788008645, 0.06254901058010517, 0.030215677932926246, 0.1299501769244671, 0.05450320279886646, 0.0599309855381087, 0.06582626577226386, 0.02496446122325236, 0.004504901993524043, 0.024015592381117806, 0.036078987402781364, 0.022340711589241703, 0.07560456607250438, 0.061759258199843674, 0.01715145032522419, 0.019117452189206116, 0.02237301751700861, 0.08541858139177484, 0.012820199875521564, 0.051601652446533405, 0.05887700560232324, 0.0333528290502727, 0.029921429306869547, 0.04369035821347948, 0.056635171865984324, 0.03814516866940164, 0.011507947760213529, 0.012516637535525427, 0.034865255152145704, 0.02885436075889776, 0.024644299673156875, 0.04403656866822032, 0.02762517843004917, 0.013049007355866414, 0.04717033176172165, 0.06205659607545503, 0.01626601164800025, 0.06489620438867039, 0.029408830300634427, 0.026407719161661885, 0.031467224283504396, 0.0529906579533652, 0.03177283782391779, 0.04221629779485445, 0.06099795449465033, 0.06540448074379275, 0.03030910044007244, 0.045514398239432804, 0.0591226555256834, 0.02633302558904454, 0.018496323421957995, 0.058994914194749254, 0.04912034345550403, 0.06383780029512222, 0.05221251180515655, 0.05629026376071477, 0.04094086482279724, 0.031309000314063126, 0.03949996451997469, 0.01222847068997761, 0.07092766824268526, 0.02025486484560515, 0.010503536585958735, 0.01295237589792739, 0.03613138398636253, 0.07133489760059504, 0.03666234037448322, 0.03383208216438371, 0.04573974300235991, 0.03005268315093652, 0.07641081998665487, 0.02937165588410872, 0.029159284820179307, 0.06368420732718322, 0.016234017901062485, 0.011854920472439018, 0.02824884103310685, 0.038323261129159125, 0.041863215531432824, 0.0018799375116472104, 0.055096614505014116, 0.046822960683775526, 0.049890909163701924, 0.03795093090663995, 0.07149658045701443, 0.019817187323144848, 0.029569699188634276, 0.05065569473851112, 0.0130069998821484, 0.016507833046958815, 0.0446358562687472, 0.04341476957403845, 0.012673800473191566, 0.07793755661095343, 0.0028377565350608844, 0.04790269266513567, 0.06901110011723734, 0.1359797332195505, 0.15747901022193894, 0.1241931793910842, 0.07307365671881745, 0.13203611176821495, 0.17923587662798746, 0.23934440687298777, 0.2363893606009022, 0.20226242651622142, 0.09654633024887693, 0.10152972453544218, 0.12137117960880842, 0.1853319446766569, 0.12247468329845898, 0.177359803910217, 0.1526415327023114, 0.10957049145813912, 0.07778511277490086, 0.08703035377566853, 0.1083599346419496, 0.2046956596595626, 0.18153030996120748, 0.11523217233198306, 0.12895836885417664, 0.1540184378503792, 0.13089428836059186, 0.10265882322264296, 0.11913768856996491, 0.09456082187112301, 0.11493564267913181, 0.08651639304814801, 0.16415186586879915, 0.09772644273095554, 0.19309331933336873, 0.12057848545091769, 0.14912483672941887, 0.06377869661176397, 0.1859066638374521, 0.11200580836063433, 0.16600723889085556, 0.10403559047488437, 0.10201038342089423, 0.2705459116447357, 0.1344105553242468, 0.09646411369284315, 0.1708775202954008, 0.11913540562795055, 0.10059875916809806, 0.17315186680324618, 0.1910203773408167, 0.1226853727993946, 0.11121903606239827, 0.23085970731992878, 0.12496889704057287, 0.16664010412510366, 0.10401658383348297, 0.1437579924541135, 0.1096975931056565, 0.18781072940797577, 0.13492650021949124, 0.1458414298512282, 0.1971893309946022, 0.09982001547130848, 0.09357700409788279, 0.14983472444357412, 0.08770604332488391, 0.20189190043076394, 0.09035663093410193, 0.10770318278622244, 0.1914015673701802, 0.18247184734190666, 0.1504707919253457, 0.10809345095748864, 0.08382912514911545, 0.14493902424170127, 0.10744969961383652, 0.23793658241629603, 0.18189936515785035, 0.10753268225779457, 0.19719956592927057, 0.12266193050891162, 0.06974523451419608, 0.21083879615029982, 0.2172163402241084, 0.2247494819664186, 0.14366947865534213, 0.06131373593703874, 0.10051359317355579, 0.18268269006042712, 0.1525856389273559, 0.12579204319345375, 0.16371842864299976, 0.22533578437662896, 0.13103619848768558, 0.17137065109226013, 0.07301330431214265, 0.13532630618541472, 0.13482948284476035, 0.22973915051308372, 0.14408236940301236, 0.10608226331251283, 0.1038447043467914, 0.19235398319940414, 0.13261319047981693, 0.23232921717628358, 0.1254617750284172, 0.14812135347916236, 0.15254178805457008, 0.10863622425184136, 0.08552080050351159, 0.125759836857117, 0.14962624127586044, 0.0821262649110248, 0.10225840438638004, 0.18170228137844996, 0.09997587605950334, 0.15240565423042546, 0.16791519618803458, 0.1517614355731395, 0.08732951111010007, 0.18287454912018392, 0.1357659487234008, 0.126710360449168, 0.13463546341705707, 0.14692215008601067, 0.10523088681962221, 0.18811226161497255, 0.15242557251645675, 0.24297108242829002, 0.1070561525862544, 0.1634727595674415, 0.09020327545341947, 0.13070820560378413, 0.08880456744302666, 0.14846492859144367, 0.2276306313973281, 0.08194789665961459, 0.11584511161932062, 0.12147161373568159, 0.1522340658571451, 0.11290432990438516, 0.13401438061508442, 0.11231048152812066, 0.11549135519852562, 0.15359777897115678, 0.16029718722547256, 0.16234624259654554, 0.12739640750711964, 0.1467954238215762, 0.17782696432644324, 0.15568835630772576, 0.1272669999349502, 0.11136459276801157, 0.14837986218833155, 0.10096682611131862, 0.19335417227158624, 0.12102138386258196, 0.09866411902851636, 0.11222931451254314, 0.13231150505523528, 0.13738247085242503, 0.17954218922363174, 0.17495998752213296, 0.19125783395382667, 0.14192508112999702, 0.07990558286227527, 0.17924169889621197, 0.08262683442162891, 0.105654870520436, 0.10945413036332016, 0.12781669866413842, 0.07212839615080627, 0.07353864144533873, 0.1543898832413458, 0.14558652175530312, 0.16200197800513239], [0.08563376016794674, 0.029494475100129366, 0.06482358691432784, 0.10644450032662962, 0.00864339370896379, 0.0705184700388101, 0.006147221175788512, 0.06562951907155014, 0.05884950304584158, 0.11689950141214556, 0.0398577505632514, 0.05152381025254727, 0.0034104295228908382, 0.04423291317277378, 0.032049267244855725, 0.030545710525926084, 0.050472028989104495, 0.02590125843492006, 0.041990275044114365, 0.07710107286731083, 0.009542364371760238, 0.02133735091305308, 0.036163092365548495, 0.0011499154507257647, 0.025353668362743435, 0.017838709717316013, 0.04237480904726733, 0.048599062757867004, 0.048515926896324085, 0.02581242479444031, 0.03835353309348707, 0.018563149271592982, 0.007959508934178421, 0.03166989092865298, 0.07935335604293693, 0.02917510262059589, 0.006840950659205837, 0.05283937474051791, 0.031152195522501588, 0.08425101742989595, 0.06436306081952588, 0.023104997291680307, 0.03893317436919578, 0.0788333278990561, 0.03663701733814613, 0.04061139338920194, 0.03680628829545552, 0.015881057254098836, 0.042314636671254714, 0.012045770211355581, 0.031367569651094176, 0.027856655726810137, 0.025083264223329967, 0.024751875654704148, 0.04346264623886636, 0.02725626879011191, 0.020319647155702114, 0.01218804614543314, 0.03039677345734691, 0.03792256650124346, 0.027209801727064678, 0.0342240855247984, 0.06969391428414853, 0.08993361250407274, 0.06861066595921594, 0.030061022017992316, 0.093530471917362, 0.05792745494193608, 0.043620184559615395, 0.05117726271911975, 0.017470545097885114, 0.05556574376720575, 0.04024228073596474, 0.04599906376472885, 0.02931500942776761, 0.03636676450109771, 0.051614706584763144, 0.02195938174883204, 0.06186481362449066, 0.016438879388114138, 0.10228357803557189, 0.04917948544325848, 0.06829654692762321, 0.03266345717072968, 0.04479349035048678, 0.021508923964574937, 0.016974872804336974, 0.0140848808035615, 0.010008643786873548, 0.04835673765609822, 0.06587528007765932, 0.022553362275263476, 0.0277515561244781, 0.07434963744374053, 0.030631996924057606, 0.02604180492550856, 0.030279734374714956, 0.11520554311573507, 0.021337636280804876, 0.05981647454562688, 0.01390455328228493, 0.07982899705248495, 0.10382296277150031, 0.03751554015663363, 0.027304082252686063, 0.06048669039662327, 0.015349702500257523, 0.006332382711867292, 0.05078226395492112, 0.029232767973876292, 0.05810709872974023, 0.06684330111790089, 0.030589827614265586, 0.0991302069216486, 0.025185274576107343, 0.05801124580865426, 0.061791349622991786, 0.009575941047871546, 0.03687962972288651, 0.03216321324749339, 0.021296652492075678, 0.10088132303808967, 0.05189802122092055, 0.06189295969482872, 0.013900167428918425, 0.01108581416173688, 0.03052532109582136, 0.020609314575971618, 0.0387680939128322, 0.0035553070436787583, 0.054656631057901736, 0.04631322493115741, 0.060494278497513265, 0.062375679356797095, 0.031188406583462513, 0.0447633562819852, 0.030879161786288026, 0.04102892279925366, 0.027662816329769073, 0.06207524265553202, 0.015348095630836344, 0.003883197223917852, 0.04007997351788706, 0.04812398482294333, 0.03553732110547923, 0.024372581692953265, 0.04175196041262919, 0.022698221840865673, 0.020627915190773147, 0.05404847982009092, 0.026279144710110083, 0.042708252646750024, 0.046234057405062264, 0.041915026057751915, 0.02920534968706629, 0.015782926179048036, 0.054630898164525155, 0.0370464300466401, 0.05826480558983261, 0.04858321622915326, 0.022789290542864514, 0.05525597611502294, 0.027526414374850934, 0.03577908696306329, 0.030496100587169492, 0.037838063172755704, 0.050058506218896764, 0.02469072268614846, 0.003743239184616194, 0.012519229785539212, 0.04069078691123475, 0.0960798133465071, 0.01775678427469346, 0.021749151900650996, 0.020586421953574307, 0.04454371504365437, 0.03940772753389132, 0.038950376873535496, 0.012098583355245572, 0.033531787189384626, 0.0028523311184178437, 0.04446290042852202, 0.050812846184858394, 0.09728748201122207, 0.035993672021093874, 0.01415162142591491, 0.004195739550801415, 0.06765893194824457, 0.013849613286795156, 0.029261760571370685, 0.06538286174256956, 0.003403999172376409, 0.0492060840159895, 0.020941067036361467, 0.051213031364304405, 0.05480438260541809, 0.032606877747081944, 0.09230009640657133, 0.02874067522615435, 0.07415917266400592, 0.04154982811380779, 0.022088490546711033, 0.0736382865016499, 0.07296204536912904, 0.028054059347918922, 0.04634497161473959, 0.07727338902411923, 0.007247895128168767, 0.007013782967753228, 0.04112193353414055, 0.050776380399662646, 0.07816773538868274, 0.06555979740956137, 0.034304850344215675, 0.04513654069253995, 0.06711495589585074, 0.054853657380707806, 0.01775159211378665, 0.008313137035246098, 0.04315299733031181, 0.03653205180120084, 0.027576901484280828, 0.04355484109011389, 0.02251134043739688, 0.010216098481548891, 0.022873349540356188, 0.059554752097615314, 0.045344311398484057, 0.0389294550123234, 0.07710000034421682, 0.03994834429073719, 0.04861539575241266, 0.04679659576786142, 0.013090916195764177, 0.05384122239305608, 0.0668227929441679, 0.06536058390573149, 0.01754849262896084, 0.08442986065581923, 0.027574603220507986, 0.04798172612584407, 0.04644752014428378, 0.09591239249153484, 0.0650316334119247, 0.0222361195201595, 0.06933777532990902, 0.012953341168711984, 0.034223216015004346, 0.02479655773288781, 0.08785934517941169, 0.060157651802705187, 0.060044810881898295, 0.048503232819418755, 0.03320353766602855, 0.08307906378421091, 0.027264724485576156, 0.061655775043031866, 0.08293556785511394, 0.0876278640522111, 0.06548925603349363, 0.05440011800777528, 0.029545942802102338, 0.008734245991124021, 0.04343870599123259, 0.047037967090164466, 0.023478622202791517, 0.055230446234946294, 0.06002098554745317, 0.06985578100166975, 0.04653870758991088, 0.032306816428899765, 0.05110154641912349, 0.08470778969386894, 0.0562752714200366, 0.0406185103460185, 0.038555776475057486, 0.04053481524029086, 0.055604867877498756, 0.055021193148868705, 0.027220542279763088, 0.05358201271343616, 0.0589773477986455, 0.023537859951536504, 0.022795687377032255, 0.02015607397732956, 0.11669074245277913, 0.04011767653508052, 0.021656091370049025, 0.02801562088631815, 0.013235664678617351, 0.06183676331514313, 0.04996792781316946, 0.11399383716765912, 0.029425737861123298, 0.029590239921104045, 0.028925585868437926, 0.04897873593314041, 0.026683474425226453, 0.025151989971017166, 0.009063329592707657, 0.006107929962567024, 0.018323890436741135, 0.036078466462992856, 0.016589212651935317, 0.017595298685914567, 0.005948895376340877, 0.07511639186451513, 0.017386635487538674, 0.0732111158750711, 0.09139285678224218, 0.062079188008342064, 0.07064095217614405, 0.08395840248633778, 0.09425194288093237, 0.04582406246974584, 0.02996483776387909, 0.049722994182018504, 0.0232856867895011, 0.10833696732597967, 0.012153167119850556, 0.04036386655042729, 0.03359774352922555, 0.03975660014416903, 0.044621319750383984, 0.017074740026146173, 0.03623844860422035, 0.031561590994017265, 0.06801918479463748, 0.05325128489564504, 0.08126242416760615, 0.039644904524808934, 0.041776525021921244, 0.04465077583107256, 0.04368463170624549, 0.07519012782722712, 0.04408785442431127, 0.014340633511423104, 0.02132845471703237, 0.01702992771301539, 0.11393367628296537, 0.03779903865389286, 0.04438162999107473, 0.0696468918073562, 0.03598568555448325, 0.04290454352514879, 0.033195145172818054, 0.0702810823737133, 0.043639279301128084, 0.046084589820595524, 0.07955523553274332, 0.05424005925775536, 0.010650093036313212, 0.1703134191132361, 0.09799139423956794, 0.18575980478236753, 0.17584137167901764, 0.13277523339756075, 0.14261408528733638, 0.11705375321569944, 0.25854664584321363, 0.17293226003887194, 0.18365202111101922, 0.1449367566214454, 0.17441634088754657, 0.08547909467691377, 0.09641548243140984, 0.10558458961426251, 0.07846108577664822, 0.1901084569192702, 0.11515547926988333, 0.11750877113832582, 0.14691450452852636, 0.17791242909527596, 0.2026750108287219, 0.08183853760842355, 0.16253750410772141, 0.1163960054456707, 0.10247009746249645, 0.18133079002220787, 0.12416363904072393, 0.1557927740918052, 0.097102303238165, 0.1785388438692016, 0.08515487860647902, 0.06278848966523524, 0.17034470614406372, 0.2319209995649515, 0.16178922006680121, 0.10192127973442117, 0.14546213971991695, 0.14861194086411308, 0.12459436431527139, 0.21568479256764536, 0.13021355795283474, 0.13560268006497814, 0.14639336555715532, 0.11445465437587231, 0.07474935913999235, 0.10873994489590968, 0.05754849039799264, 0.1657908496957633, 0.11848910321151057, 0.13026539146179153, 0.13885283872725504, 0.09948441533431893, 0.2386154895347934, 0.12234378185483719, 0.10713909692581623, 0.13598244517080246, 0.09716030375491227, 0.14236731304516717, 0.17470250537078227, 0.18119467151982172, 0.09358814301630182, 0.23860879392633516, 0.10914527435576725, 0.14983907582298403, 0.14448631224372696, 0.22401702530201406, 0.23965162345238272, 0.14636030120234336, 0.16275338768478365, 0.1140230940654874, 0.095463449646148, 0.12585321531420754, 0.16364387296620878, 0.07993177540840642, 0.11880796432735459, 0.159499766305089, 0.12428444344550373, 0.22667957920460935, 0.20139624154375446, 0.19942279905080798, 0.1352049425364502, 0.12206914699486188, 0.13480271573268598, 0.2365568580646669, 0.1344291099737729, 0.09129197066349369, 0.15761082331019063, 0.14861030143595513, 0.12447923662201052, 0.13497422749717392, 0.16862987961259582, 0.25164836116375466, 0.1910830892982983, 0.11638443751801407, 0.10006275043011674, 0.18354058596155337, 0.25893921993913194, 0.23785277239737973, 0.14748398364791948, 0.1736596911664932, 0.2081058387674632, 0.24921886652948397, 0.11397444748229558, 0.07431447400801605, 0.16335357160818192, 0.1514234988679809, 0.13213908930699672, 0.11339493261109437, 0.21847540572766336, 0.19721346276421703, 0.10777580026056498, 0.07655610856149467, 0.19066362551623778, 0.15913388271245266, 0.13178593809566191, 0.20301316203849934, 0.051568105456329165, 0.15480156357009567, 0.09576583987161999, 0.12940809310924622, 0.17740667316942446, 0.21450861777749755, 0.07838671396095907, 0.1453374972146365, 0.16752881208254447, 0.25707079277884576, 0.1317291096934388, 0.2114991639410296, 0.13164859385259692, 0.15484268716987104, 0.09421042091543637, 0.16834163137020605, 0.16985649363167826, 0.1683908908237373, 0.2162501348122474, 0.12397572533377718, 0.2495958583970224, 0.09765975477714693, 0.2175410695734524, 0.16023502685129642, 0.11904404198210086, 0.19665329927398315, 0.17425014577325315, 0.09771643762266445, 0.07898427020277708, 0.14215118431996915, 0.14850292655248798, 0.11286003470060327, 0.10890974062344722, 0.10614495228735671, 0.22961691352388552, 0.18186761847426816, 0.15100458666922587, 0.10025136893795383, 0.12407846538530243, 0.10461381065749353, 0.1576933922666696, 0.14453031633409763, 0.12709202545304454, 0.1292999521378548, 0.15671094579081382, 0.06838231047074642, 0.20059541919298712, 0.10373526102592869, 0.17806797558742185, 0.15428672184146222, 0.12574418568082396, 0.11736879155280129, 0.12523171116387652, 0.11194689619925716, 0.15659367305136498, 0.13187167865614738, 0.12307934117533507, 0.09719352898818832, 0.13879366609598362], [0.03554337703052067, 0.03682288559033506, 0.09373045150911617, 0.007965038652576866, 0.06259891737793243, 0.040424533053151065, 0.045359223299930175, 0.041799959651524984, 0.0315084072550939, 0.08655813717914206, 0.04602293506444943, 0.03431737205133804, 0.04736264281335378, 0.029304690223427552, 0.14667162401301248, 0.012273803942896908, 0.021862335645804004, 0.054934766939691, 0.040264930125446095, 0.018486709018508275, 0.03700391599728215, 0.10192292682345837, 0.04447652530225535, 0.004819386353295658, 0.05582944655250158, 0.039594698952691215, 0.012455973905631372, 0.028376017374196844, 0.032863329510174455, 0.012608631288692837, 0.02260472080970724, 0.03167478623048913, 0.03701357636600733, 0.025760652572517435, 0.0598918614278157, 0.06094120270121963, 0.0355690103324671, 0.017430034368449164, 0.014746689797198821, 0.04353272413173991, 0.018628136510209694, 0.0060017616675806145, 0.04212494947076325, 0.018530077255901792, 0.02207398275664497, 0.020654760826859745, 0.0405713691255979, 0.03400909060972833, 0.05049090539555877, 0.03567046718671918, 0.0830517680714688, 0.05134379874253946, 0.05391703062360326, 0.07239477258295783, 0.038970084485387614, 0.02288845870944281, 0.04513733359354158, 0.022168046862427748, 0.018208571221499194, 0.058984897595139286, 0.03436878804237612, 0.026789972138020302, 0.07990925242343257, 0.05534075140472382, 0.03211774784440716, 0.04703275769227936, 0.020331768581884044, 0.03524234278067466, 0.02354637693403469, 0.021966433588175044, 0.04760950698607391, 0.05859544530751244, 0.06159016344275686, 0.07873155311831544, 0.040593214122758764, 0.022328096036348614, 0.022504740589929205, 0.04818676572833811, 0.03477091908514981, 0.048644330893312736, 0.05685297449329688, 0.0211938185947797, 0.0431807182218519, 0.03228753016540601, 0.03484059095142349, 0.03266845972487523, 0.11018913043963333, 0.007494860328733922, 0.07862957149383523, 0.038088547110918074, 0.07476781419808827, 0.07542133316277497, 0.024567675558970343, 0.043808967776356206, 0.041465585255214286, 0.03658904491232769, 0.04729820332760292, 0.0846553433145727, 0.026875800798617067, 0.024726548787927436, 0.01968288253391943, 0.08313771547569383, 0.01759133992656585, 0.01577926140594026, 0.05387971448081155, 0.03802576620552329, 0.036338882731093515, 0.07465686168401472, 0.05135089654715792, 0.037528536838269046, 0.023057164676908045, 0.010938515563705757, 0.15250667058412107, 0.0820614768552684, 0.05283138061302805, 0.012475528299898632, 0.017720695787800417, 0.03697742850730016, 0.02244117061397241, 0.0027504433397083517, 0.028357968342700796, 0.10441875701109249, 0.03588061659566818, 0.005923522065483755, 0.03944459934568694, 0.02536515776638783, 0.04258224267452475, 0.05978663925141577, 0.060447447542702, 0.05524771002631995, 0.06409195379444188, 0.04251505293312573, 0.0562519517036215, 0.06341810668668439, 0.03681272343401948, 0.07115195580427686, 0.01943837408156645, 0.03261378402971933, 0.010278446547266458, 0.11033805793211346, 0.046188061486088464, 0.04936840655582567, 0.057748807068433494, 0.019401285849932223, 0.034821289366171244, 0.06637368155943771, 0.051918789864547794, 0.030331613848947232, 0.02810032531288603, 0.04147917565499102, 0.027385477179421053, 0.0426654742970582, 0.0974943793769325, 0.040964785918232896, 0.10480613703088415, 0.00502462561745497, 0.07191537774258083, 0.03382762353266439, 0.02062893217249263, 0.020656241291773417, 0.0330806456716551, 0.0720929492625498, 0.025262360258268255, 0.041378446584267, 0.04530153304879223, 0.03267305242198129, 0.020079363678251545, 0.023463158718039914, 0.04338983341210312, 0.025513863093369914, 0.03158157439752212, 0.06086423001702755, 0.012002915252871331, 0.022338455460304697, 0.03240520127057549, 0.05061452517346029, 0.05322195138902434, 0.039262569193998655, 0.028372464641447992, 0.01791192665545931, 0.054996195699899435, 0.010696973786839556, 0.07593866467716233, 0.04094757958345356, 0.01739809233244629, 0.07284762247675851, 0.049511132566558744, 0.013869905040689535, 0.06317734440428115, 0.01731956640498773, 0.07417379728248043, 0.04270537598659435, 0.028753172035419175, 0.06111165726437204, 0.06392889581019841, 0.06793663882079624, 0.06061352391336715, 0.03997601155612258, 0.0067389230694501635, 0.008328522953595366, 0.011673499360650538, 0.005589021743470503, 0.033537915892778866, 0.05565541052830316, 0.04345317739212225, 0.0158157789020709, 0.03055932582356036, 0.01452369500897945, 0.04614328364691427, 0.09032457781535003, 0.03386797721407587, 0.05750292731869606, 0.10823248059398706, 0.013161620365515833, 0.06512607673122998, 0.01592781734577711, 0.0195191886966988, 0.049339973202516, 0.03987515225045143, 0.06221771585725008, 0.028973910694701538, 0.02586101583625761, 0.034777603202289155, 0.027432509232312444, 0.03034414704738846, 0.013835209876208777, 0.03715602275464804, 0.03202341752307069, 0.04940191141119407, 0.027317295354160092, 0.09190662598778164, 0.041888588363484996, 0.04494646661764672, 0.08413295561988508, 0.020900770811544313, 0.02463393450354136, 0.04814904738938616, 0.030177193506050016, 0.04680301175422726, 0.038831495349445654, 0.045560995537427165, 0.03169737433293655, 0.022403741473211877, 0.04780166482012119, 0.021608235772639033, 0.04716450949349711, 0.03897593356668949, 0.08579515957183416, 0.03790127691782771, 0.04400338940021973, 0.04237376333725068, 0.039578783476064285, 0.059358794467463616, 0.042074950742385084, 0.028214566259374543, 0.05483511805294022, 0.014647881691944937, 0.046198380690428524, 0.018340058722383073, 0.03823804533890179, 0.004788662875897342, 0.046108392172402916, 0.060659412580031546, 0.026896104043830308, 0.03638269912992274, 0.05174401456550245, 0.051579186918153885, 0.05037788827452929, 0.017883692485009952, 0.03851313985163166, 0.03473568670151215, 0.042869291989313024, 0.05536771769965849, 0.011642518764992636, 0.020653506357883735, 0.07660948190717928, 0.06969826566355844, 0.04879448412647171, 0.02798284764491743, 0.07747732929044193, 0.018280167883682637, 0.02072729786197024, 0.04592070446139382, 0.008527177213240535, 0.01684435823511693, 0.047331574117584575, 0.059093536523681496, 0.01758696747973802, 0.033685966214585694, 0.05783170927315951, 0.04616924636666814, 0.018951155568262743, 0.05614248156968144, 0.025118950514062762, 0.12426808746832034, 0.03149608856127147, 0.07342893765458176, 0.050423891854382334, 0.033970728756919984, 0.0323640393664039, 0.037004459919708396, 0.010548687892996017, 0.03268798730606514, 0.06036615412261698, 0.011099298266814122, 0.04540782391784653, 0.14233559700510195, 0.006698495173271025, 0.01059637399345276, 0.01570337177855113, 0.043946560997996605, 0.02612782510808639, 0.0449613708582136, 0.054592283502701795, 0.05309660791329319, 0.026765893994560166, 0.028420224477867448, 0.07809859595351643, 0.03199699515056226, 0.08442004706950919, 0.05173664096923125, 0.0458376758521603, 0.01308768809277324, 0.046684271956403414, 0.014979800776458316, 0.07464222174378173, 0.07695055957282744, 0.08192289154976606, 0.0374184959688254, 0.04939184501586903, 0.06534040514980594, 0.028739432248497204, 0.04810936403490844, 0.01256459176675567, 0.05836329002293849, 0.03153127497963367, 0.043316568593464555, 0.10534544760781912, 0.01978870034368048, 0.021059628718742923, 0.05283013188971147, 0.01729850856316907, 0.036588910846940936, 0.0216422519916969, 0.06984710122548765, 0.024231565973511147, 0.017735531080454107, 0.03204449260186765, 0.01496156596864063, 0.008434522709238433, 0.04998797633414788, 0.011689056691172863, 0.09017083929070542, 0.0894894500473334, 0.1323290637904598, 0.08843766495345101, 0.1147051421444743, 0.13850040763856905, 0.14792031668607267, 0.1693975609997588, 0.08019575398535499, 0.16296560936156781, 0.12072115400505644, 0.09543795424002795, 0.20080313627277652, 0.0930906301965156, 0.24618005620375757, 0.1165051959575184, 0.1118747077341522, 0.15240643564010822, 0.149478723385161, 0.16165190646725316, 0.18602467202130826, 0.3092941792020875, 0.13476355331799678, 0.14776279368708212, 0.09445228253401096, 0.11989682807677216, 0.1040575925200697, 0.18393018763632546, 0.13245209751109924, 0.09813818434673933, 0.13566241960131353, 0.14791052608240038, 0.1192311283140894, 0.13534533580945385, 0.16357929175419195, 0.26000322413540655, 0.21435570662781117, 0.11682436350853213, 0.16825615127961482, 0.09381760167138231, 0.076240855719774, 0.13486017232700703, 0.10385760526743629, 0.17798076413812178, 0.0747080440182359, 0.14290038766639848, 0.14666227774033624, 0.12390737496917287, 0.10426379274576904, 0.11511659264684686, 0.18810705221708746, 0.07338239781318173, 0.28675050985428596, 0.12009350582957269, 0.2495074824940774, 0.17665158626773667, 0.1688693433759674, 0.22446069746248185, 0.11199423277209844, 0.2671561257973794, 0.17952099923164616, 0.0979101123108018, 0.10042541645347111, 0.16974044663290824, 0.09847287283909899, 0.22057004333023103, 0.1548347504989755, 0.22745280706834411, 0.16288253478705883, 0.16211934267513214, 0.18587638804268453, 0.14865703279933623, 0.16484117646130825, 0.17577769445075145, 0.10485315950767649, 0.1500932484745018, 0.16796778046315716, 0.14926515339363008, 0.1431866594019436, 0.12969903798112947, 0.09395376613904392, 0.09150475924534184, 0.1776931440878299, 0.10930756242164683, 0.09260418734723523, 0.11872748679090893, 0.19272225698636425, 0.15206560312259584, 0.14297716499816987, 0.16959556408466833, 0.13896375293693236, 0.18301834382357138, 0.07098785211001674, 0.1803620718419552, 0.18471276177273643, 0.15513769230775296, 0.15724464860414306, 0.21781600320771818, 0.08789527470306044, 0.21035847434353447, 0.1683817284121629, 0.17036077866871513, 0.1825436757456872, 0.1709232863879973, 0.09578981076277072, 0.16953412383314104, 0.09426973144253416, 0.14729286003257, 0.1304005600151516, 0.10302520477243009, 0.10411534788868121, 0.1322785939180082, 0.27340501306518433, 0.20707371915059708, 0.15841984280174778, 0.15793886215936753, 0.17828828715268644, 0.11831577581864212, 0.21375426632021705, 0.11096415860999016, 0.16356072178290737, 0.16532667702244175, 0.11397840049598487, 0.13719491720680269, 0.11958587298830671, 0.08853845148076935, 0.142442021939543, 0.2259753298975768, 0.14087652126627584, 0.12457394041121007, 0.24718488776876082, 0.12846421149949874, 0.1965179008942458, 0.17486914481607177, 0.1392444935176642, 0.20607340750434708, 0.1607964926910016, 0.14966126681575853, 0.15756571605320902, 0.2384171187276802, 0.16382045623275543, 0.18992839561354732, 0.24743155275862067, 0.1465096577040611, 0.18022282770083797, 0.164448035460326, 0.10334516905488507, 0.12660192836436535, 0.11616297682086307, 0.21115794837955507, 0.19126138860179534, 0.1747928577805719, 0.13053775104063173, 0.12329633557988752, 0.21425514992687011, 0.11012310898231883, 0.14939123614420816, 0.1507792342454195, 0.12439318962635533, 0.11880869977176191, 0.17058787777298884, 0.23022625985885822, 0.10311704339279283, 0.200374081069904, 0.09806696881329822, 0.16851700421783233, 0.08943959304522123, 0.14815251793592207, 0.14364913136007326, 0.1081863314574284, 0.1325158053828824, 0.19268332439805233, 0.17595417046498868, 0.05923641575199943, 0.15772201331152072, 0.1809602179714749], [0.09476977235247051, 0.07640782458287093, 0.03568787270435884, 0.006046222059071185, 0.025169246101511583, 0.0492805554231088, 0.04710199288843621, 0.04052770211391392, 0.03020650977569242, 0.08147699007343862, 0.009263353234517479, 0.04849048128591911, 0.03472777684369395, 0.040201578484547716, 0.029615744903323152, 0.05209281822786697, 0.011834378782359344, 0.05293847970484246, 0.045844608947875044, 0.08131837922959559, 0.01591702220931409, 0.016152866207243457, 0.05631126606115892, 0.06485771613135453, 0.07276791868911636, 0.03770661397626804, 0.028993648950070627, 0.07327950454407162, 0.04124866362901465, 0.018566815002310662, 0.04155684930963382, 0.008338640102245396, 0.02320104556518697, 0.014990732851137799, 0.05459825132763194, 0.05858104285453597, 0.037987929122943076, 0.04332110000353667, 0.07410876407858825, 0.03089401048548039, 0.05201164738184983, 0.043896225190931754, 0.0993428269641534, 0.01606714479895609, 0.015502651954340118, 0.03864556197978316, 0.07988810073584318, 0.017620035664989583, 0.06100201859108864, 0.04274346204774995, 0.04327094422713403, 0.025500339726286552, 0.07537110843845914, 0.03125432844934685, 0.04458452071694117, 0.04449734757203729, 0.04899598440275558, 0.10822945454668616, 0.0033781901490123525, 0.042711891564390356, 0.0421870447274658, 0.0157850492002082, 0.05979152306193306, 0.0041107258162341054, 0.07725297278093715, 0.06725791556340072, 0.05360833166407482, 0.04758199293827338, 0.007464760734188942, 0.02391060003109517, 0.03219079624320711, 0.03322200038500371, 0.01265389559369895, 0.059281442569749015, 0.07026595213720876, 0.06420328169159832, 0.018234792495927504, 0.1324569238650222, 0.05849574279460696, 0.07484007927198565, 0.11620570920527944, 0.037238771741789196, 0.013923851037097555, 0.03432907404438142, 0.02189807747791131, 0.03778642501621958, 0.03707641855843606, 0.07007702719420195, 0.03607964623839625, 0.029678546876135855, 0.03590384055109274, 0.01657990659887512, 0.09109556104146666, 0.058478773947084145, 0.01206486112242865, 0.07095713198425309, 0.019593771186567122, 0.01972617799296014, 0.10201747739507307, 0.023576539730833426, 0.02864758788247503, 0.013197641819715502, 0.028273566520863005, 0.05056770570996789, 0.05990342552503271, 0.011364920102360268, 0.030237080514310833, 0.032247804676092444, 0.11738927674389656, 0.02045866147044205, 0.02449703267625263, 0.07531211966828955, 0.05110248487683074, 0.06803568632852647, 0.04647949282380362, 0.05826647183106792, 0.09040955994879046, 0.053099821652135545, 0.02118362196450753, 0.03814945110089837, 0.0380569268318434, 0.039054216261232094, 0.041048595937149185, 0.029945756428905075, 0.04819495903868829, 0.03353471364525538, 0.004519247468711148, 0.028936782243451285, 0.05198394564250785, 0.03627110693243243, 0.008032632984160896, 0.06451388054917898, 0.03418195068896298, 0.012489798602708166, 0.04090876190833027, 0.03286211909125409, 0.029787201126436555, 0.05150597572567002, 0.09812769660305593, 0.0482014746164843, 0.05492435963523965, 0.059374997227062146, 0.05793691229736132, 0.04405621116259887, 0.012430773443362166, 0.0969761975049492, 0.012213916934636092, 0.0867010202378996, 0.06810098766319214, 0.0901022897432408, 0.055933128892173695, 0.009144308916743725, 0.010121096875668775, 0.02538652012815639, 0.06889183554918536, 0.021640578089582346, 0.01320006840321566, 0.019456710396034103, 0.037925722783491496, 0.03613920957450906, 0.12020946089779178, 0.05704765658705466, 0.17573243397618496, 0.05697706158483221, 0.0693332247676388, 0.02042012533263093, 0.03987755776653367, 0.01752104178341406, 0.01541417167191544, 0.051020214694642255, 0.06085043660395088, 0.04806391203836088, 0.02494690057280804, 0.04942197142349136, 0.023587134726826223, 0.032351161428396745, 0.02402834966027689, 0.024380933966547735, 0.05672871886241821, 0.057422966891599286, 0.03408537764522818, 0.01765621608243354, 0.03737665607684082, 0.049112877928681915, 0.05340901856881477, 0.012167044802598897, 0.027525054568785335, 0.02270826525355299, 0.10408981417816493, 0.016499779547654813, 0.04916398365411067, 0.04435800766992954, 0.019188945429519783, 0.07184377150429834, 0.08223899474908268, 0.08074749816930102, 0.03812666764603027, 0.05782089977254791, 0.08003634641007071, 0.054868481182042635, 0.05354103850080602, 0.024186736423402064, 0.012055468884476972, 0.11404166403677195, 0.03715886877128675, 0.04162383986817252, 0.04593307295093133, 0.025481984259620793, 0.06219611217778537, 0.035823677110696034, 0.07198999470640575, 0.014601437611535434, 0.08521682447603635, 0.0263038816891851, 0.03752593596976611, 0.06250167017682426, 0.008689481558488503, 0.03295240255313055, 0.034919195402894294, 0.016532531721637617, 0.01938981176804631, 0.07576381276932455, 0.04860525274829519, 0.017839885662279783, 0.05214766629280583, 0.029044921299622908, 0.051791688217030424, 0.044093603914182995, 0.036820146826005755, 0.04707317266072478, 0.017644694120052363, 0.06092817154562762, 0.08382575436224861, 0.029383773479851025, 0.05047957495515866, 0.06578062225373522, 0.04740371661741407, 0.008522855519737688, 0.07248042121289239, 0.027502876323377414, 0.03686772088610357, 0.025577406256249356, 0.027623500697494998, 0.028566399799479593, 0.019044710225575877, 0.024301594070669626, 0.05867363607150413, 0.04675085265790263, 0.008359692198404623, 0.03649055664878219, 0.08442997556900786, 0.02165671190126769, 0.03879000785790625, 0.013861409125609264, 0.038135366574410474, 0.02404077560640872, 0.03365785461820422, 0.029251652041209802, 0.12103419285267593, 0.03738220638385223, 0.06964670794625437, 0.043330001945216814, 0.03830552619371203, 0.018245559861703266, 0.04070496719871317, 0.07195080930907881, 0.0736212333844554, 0.018552199959935203, 0.03212794638989914, 0.021508845440562696, 0.04038961859600198, 0.04047358566294274, 0.027615512315664562, 0.029929681989033858, 0.0686400990572668, 0.03724266729888417, 0.06226146713860574, 0.02249505915378611, 0.07178558712644924, 0.016105190640495672, 0.03376529078870531, 0.037154371835171215, 0.07631246961893574, 0.015621466445736589, 0.041780757657702894, 0.026007549303974357, 0.044019389146518324, 0.023641599747802944, 0.021791453360609954, 0.05747252894986061, 0.044802089687436826, 0.03094863830014102, 0.013266704646089386, 0.040011048587339546, 0.03586242200746652, 0.03162120412584515, 0.05537950779281317, 0.02986992330050036, 0.020489130702410496, 0.03323521923213717, 0.05262429938621579, 0.03175890651501475, 0.1263905876886941, 0.06802293862546645, 0.04459928323124205, 0.03490929754691259, 0.05871029337868095, 0.023592279007237767, 0.035719148243867585, 0.04348940185962185, 0.02913097404093752, 0.17588692326699534, 0.020763635327438676, 0.05196508838825169, 0.0507734194698353, 0.04098642024121458, 0.02325867069885135, 0.039979240616723415, 0.02409104055034057, 0.046788253070366, 0.022374450101427013, 0.07205667499933513, 0.05663243693209464, 0.03990956492001011, 0.02450206395869534, 0.03883033472624037, 0.053214531827477686, 0.025132540913839495, 0.07526647614976091, 0.04503176284713611, 0.08522185001281962, 0.02070054990209399, 0.01761332856521251, 0.055651135757685675, 0.002722525419930237, 0.03485662134123906, 0.04012688491193037, 0.03884839141861566, 0.12695399173084768, 0.040311037127168915, 0.04553207571828558, 0.03843048662548104, 0.016460278139059103, 0.02137231325069743, 0.008619629661552608, 0.046216598261267915, 0.0666192127391696, 0.008010533741570168, 0.010374605903522143, 0.03647283320465396, 0.021880643231974497, 0.03862984951645617, 0.11066450331840785, 0.10213598353608001, 0.12695319499940644, 0.14039970814220368, 0.15145611889179678, 0.2149232858491521, 0.1527953938010239, 0.14663474454033762, 0.10093979086847076, 0.12499015598047165, 0.08201347378593299, 0.11924010686456196, 0.08128608862358717, 0.2346430172122294, 0.11193083899636423, 0.09301828851382579, 0.11032165598965461, 0.12889827691739605, 0.15648220725838216, 0.264675747603178, 0.10356907357251453, 0.11071836696036401, 0.15972043027079877, 0.15460003648073445, 0.21951691758248115, 0.18269234276827306, 0.07295911891325828, 0.207897876539538, 0.16220022623817767, 0.13137448759328935, 0.18410491697009534, 0.14855616966322546, 0.14170705250674678, 0.1024100591518706, 0.1843982060710269, 0.18274267474489828, 0.1290927406760954, 0.1636480098409999, 0.22854075917313177, 0.0832446996543196, 0.09018614572743255, 0.11505231786999973, 0.22273649401482076, 0.09210654429250187, 0.11227497335283027, 0.15316860119421638, 0.16739011952473273, 0.09693389412977042, 0.18346480454408354, 0.21437806107344168, 0.16972736185116155, 0.15373686989468915, 0.20104494426519642, 0.09806892999838437, 0.14660946363883634, 0.17524321022773945, 0.22018784206480752, 0.2111828309153357, 0.07145935624477363, 0.19499373832537284, 0.10670542987363954, 0.0651408622281686, 0.19559197638544346, 0.237956837781014, 0.19621045448847357, 0.11404615331200824, 0.12287926965302999, 0.14114236909775965, 0.05848393354925418, 0.09833421092480422, 0.1661572082629127, 0.1024014866279979, 0.09595840373226712, 0.16310546637302445, 0.19082995852635753, 0.12689125679072835, 0.10261828184969003, 0.19436530107932706, 0.16263102812151756, 0.16596455247171465, 0.1827392426709975, 0.12951413499972514, 0.2196601607025631, 0.2397074406185458, 0.12641559279854261, 0.12768505411523004, 0.20199087899058096, 0.12475754870402238, 0.08683179910745352, 0.18393703646236853, 0.18620750656531704, 0.1154304818520623, 0.23055097388644374, 0.13892799195262695, 0.1455658986683815, 0.1039889740246919, 0.1613352210411141, 0.11333681718115846, 0.14834793164364754, 0.18898923310541338, 0.13823212364748602, 0.0916527444496751, 0.14218267053365707, 0.1296068163168046, 0.1972306537772379, 0.09499953744272072, 0.17376366461957657, 0.11268967972888101, 0.2195518971571038, 0.10210487270547498, 0.1367310203251339, 0.2226969485561694, 0.14136407494304642, 0.1712684856066781, 0.2135566156357527, 0.1329516174812471, 0.20230276870631403, 0.2200995887359304, 0.06150182967464771, 0.1444113122359399, 0.10291126451545185, 0.17175968586196824, 0.1729240935415991, 0.10824776404807646, 0.14555434606248333, 0.09318773184091815, 0.15401364213997318, 0.11390145462487014, 0.14276370225894836, 0.1916999739384459, 0.20299085355814428, 0.12243067920808831, 0.10921579274919727, 0.10875967932083916, 0.13469406914326454, 0.2798654018871246, 0.11538345171439073, 0.19722139943511258, 0.1159464803734614, 0.15044210959346066, 0.17769268443507535, 0.14030017799908115, 0.19936960190534594, 0.13327990147855975, 0.13172878793651058, 0.2554336628846584, 0.11836779318870076, 0.2240011366384645, 0.1576611246432989, 0.2676244200237336, 0.19913759983835683, 0.13692240441037765, 0.0847304582355484, 0.10657737827709607, 0.17913539653583882, 0.1425367870157765, 0.16927638121189612, 0.24345316623728125, 0.10804947751063494, 0.1004731284093953, 0.17696942082576214, 0.18073296564961636, 0.36667431794827987, 0.1203059496718549, 0.23718934025495286, 0.18027164282337313, 0.14331315584000082, 0.08150636188445554, 0.13426840004901733, 0.23234591789303288, 0.11701965464218972, 0.1686417999406976, 0.09443644749661607, 0.18558850752249842, 0.11534015242491039, 0.1990870533571128], [0.07639734450006679, 0.04133388324971161, 0.012005095730625815, 0.06246965153202896, 0.05453370075913207, 0.05601065699011088, 0.04274181495871275, 0.028431332752769514, 0.04106355380387076, 0.031890342304963744, 0.01186879815518736, 0.03213381462339913, 0.03755490558462278, 0.037213958153921756, 0.048644997389806856, 0.01965024910356489, 0.03132541566306064, 0.02323204531304298, 0.04958579932609874, 0.023338027831707752, 0.02005747654625485, 0.028465779896284786, 0.01937126286417967, 0.020616824152849374, 0.02408716031500409, 0.038020468707526886, 0.06288990055421187, 0.02773976028566399, 0.02763602048939755, 0.0334935364193253, 0.020442338051995444, 0.025891021585031867, 0.015943963606391224, 0.04366829105082058, 0.03612756120762037, 0.029442369629959428, 0.041140484353227, 0.05006438211327599, 0.06281197409055407, 0.04173307251485606, 0.03238448242266332, 0.03277267449565473, 0.026800557557914047, 0.08153150489013042, 0.026926958234980706, 0.05069887911480281, 0.019947571657417763, 0.017293421739351847, 0.029026529443780744, 0.0386295507421657, 0.01796835860718162, 0.06089578900906829, 0.021419435318919922, 0.02098331295494591, 0.03685233784058402, 0.015026420099480499, 0.01775951729336333, 0.014182986980754764, 0.09877423650675243, 0.05511953968614821, 0.05013611092562637, 0.05708142574275694, 0.04861292894929648, 0.04164368154541139, 0.06657405185603327, 0.03274873807846058, 0.009079195273619507, 0.013810734324637922, 0.045153658927208, 0.03176581471287195, 0.033409768535244855, 0.08118160189159455, 0.06428756285458803, 0.007826185695105984, 0.03818772485359542, 0.032199387919277914, 0.02414850863598047, 0.023188138898882656, 0.040980214929027904, 0.06773796157851335, 0.049464458659771955, 0.017082144265934344, 0.05136582760080215, 0.020980828914851434, 0.055001313167233626, 0.06855569915064881, 0.014139620658581056, 0.02727060804083463, 0.020568497411365953, 0.05096640084840117, 0.06816881708800793, 0.027066257917472435, 0.02023173856639093, 0.018282726617349733, 0.021469476182133924, 0.004370920397641679, 0.02064620362474553, 0.017372962733310078, 0.027060983402113763, 0.04776077104672309, 0.052279900729415886, 0.021422344537812377, 0.05365820015750585, 0.013644491329849249, 0.0411331643831105, 0.031210272648041288, 0.05328685052752976, 0.059456248512311335, 0.0627302976265069, 0.05203211725118661, 0.10630766936247388, 0.0321972735166069, 0.037175431592209686, 0.05639586132019759, 0.041672635838509574, 0.036007856139011925, 0.04994808996637022, 0.006579693130803325, 0.05679069154505288, 0.03265344440155933, 0.02368067023194125, 0.028718257578270092, 0.04449894869579904, 0.072944249146648, 0.022581703698022232, 0.022757342761202205, 0.0277081017021931, 0.04714048497619168, 0.013689940453567093, 0.035791861479200666, 0.05115505383019486, 0.02638391680985449, 0.05031631012717563, 0.0169825911401741, 0.07207424139543887, 0.0070557349000967325, 0.07389691778488698, 0.12029517847563952, 0.03200347242396205, 0.07912532997227485, 0.02072881663128013, 0.004537391303587826, 0.03302698887343849, 0.024654517370846965, 0.01588705476493605, 0.028098074929608453, 0.03230559834910016, 0.045387108900373986, 0.032935357096815304, 0.06333929156103442, 0.024886906312237826, 0.045348754708444884, 0.13638972815486694, 0.03644086818601336, 0.02106737961331683, 0.011139773564683575, 0.04266321816812119, 0.02541885669944027, 0.08698592067606027, 0.01718715385293528, 0.02356344537298766, 0.03601160613940128, 0.03278197480305549, 0.0668005304290883, 0.05845742307663445, 0.027459464035928253, 0.056092781615593744, 0.10788518229439374, 0.0860219982062136, 0.021167802248871135, 0.05681161340626498, 0.03293675520727712, 0.013457992012732694, 0.015664816488541903, 0.03605973944368382, 0.0334561666503789, 0.08229429097545725, 0.04111961994860922, 0.02474720826402547, 0.07691083025307426, 0.03986355750971744, 0.048074323173251846, 0.010797109139422256, 0.07859250816005854, 0.02550074766810623, 0.06715909022116853, 0.02316320656738695, 0.07056039803090595, 0.04377991389182787, 0.04900456841794714, 0.015683557871999522, 0.10400374419987203, 0.03937102426143904, 0.06096172619671111, 0.01747438511360557, 0.0209371714792665, 0.001792439497582945, 0.02464829865212162, 0.01771261930585869, 0.02845598163173324, 0.019603954410300623, 0.08516916614626685, 0.042646793243024624, 0.026724816360060247, 0.036015926875294216, 0.018236188691169507, 0.0093911434035568, 0.04979194592564337, 0.051569335027447635, 0.03727975361529858, 0.03536998068973903, 0.04424171935346338, 0.1027865837057752, 0.010721666715858925, 0.02543738070544937, 0.011215333774265264, 0.026595041065687136, 0.02759789229340611, 0.04294085609275968, 0.02915604618347941, 0.020472127380931092, 0.10556408144052952, 0.09869323803051826, 0.045419920446170915, 0.02431422303010139, 0.06642273416922939, 0.06410191293745753, 0.05432583429219742, 0.03210216178558767, 0.019686603806011622, 0.062169528926812836, 0.012348399839303907, 0.040816440652575225, 0.05037930553718921, 0.11276435031886063, 0.030681285105886, 0.04752063312597814, 0.05654359371551583, 0.05453160933909878, 0.052426752123621204, 0.045107766430103974, 0.03150071381711431, 0.01857710356313375, 0.031866379074692246, 0.05093478439976612, 0.08770072667468941, 0.03254061114163168, 0.03385449406660853, 0.014171638345766454, 0.030415835640122815, 0.017737057510643237, 0.04305403409225326, 0.03764993879162977, 0.05816412631482367, 0.059416454075084585, 0.05440663358557129, 0.029871352054479144, 0.01023554562350675, 0.048074162294787746, 0.03554020159607453, 0.014950366720797555, 0.0058637221997243265, 0.05233833408584038, 0.11401187853827593, 0.022177605724502957, 0.043460845932244294, 0.028742379771785873, 0.005696571390745381, 0.03880622210882364, 0.04467994462878955, 0.06262720134409686, 0.07537342202399047, 0.03740316271902092, 0.06481269314404457, 0.09132796147417638, 0.01166969286127677, 0.048542992782688914, 0.03291543114990477, 0.05246052127932349, 0.022745947203328534, 0.06034176188310789, 0.04890208500587652, 0.05622901120072892, 0.04022192961025623, 0.04651788915056856, 0.030390815208515817, 0.06177197525938673, 0.0391403934918344, 0.07090108499171273, 0.022243351390164708, 0.06449796124211242, 0.03326431525150134, 0.0628581538706297, 0.0406446569268742, 0.1060202791385593, 0.07165340631599389, 0.02679515472282806, 0.05315709055491513, 0.12021051809912729, 0.093087014261513, 0.058264464680706306, 0.01699029798469236, 0.01515730813656363, 0.03113740236468373, 0.030340649856014118, 0.04236638208010024, 0.012707690287741923, 0.005426330523820775, 0.06167097422744959, 0.02092226149304019, 0.03622703006370895, 0.05364302012528624, 0.08749983543830533, 0.0943974689430287, 0.055990849786828605, 0.039146204268740076, 0.07839294225578347, 0.06626068359060634, 0.01739930466658646, 0.017303737113252282, 0.07044923867309286, 0.009293593597718546, 0.027102729448327617, 0.06833134264114403, 0.03241651255877749, 0.019551858516229738, 0.03969008072970375, 0.012954055545701375, 0.05840473537964206, 0.022284722053295663, 0.024810008321618362, 0.02863123765095107, 0.08490359410643579, 0.03520421458468322, 0.050305412526452736, 0.006479693280022231, 0.005467685386388293, 0.01118780727753596, 0.055191770286088994, 0.06065496927007072, 0.04104830865417758, 0.023164750234554374, 0.01071532829589541, 0.052450588949385195, 0.03077174476798504, 0.023180022197324904, 0.03335556398416239, 0.06605721063791745, 0.04828272207129387, 0.01741749159390888, 0.01537784569776587, 0.04707406132271694, 0.13934603081114832, 0.18972815555189887, 0.22052236201782383, 0.17367060025853498, 0.2045918547458226, 0.18180349691500589, 0.1535018187977614, 0.1567281214820762, 0.08978689900569378, 0.16037195740688234, 0.09630854421805951, 0.1839151110259756, 0.11952135306332382, 0.1852851979915173, 0.10380435449581954, 0.19786800828672227, 0.1175462251769439, 0.12167481089671775, 0.11571508351593249, 0.11142962597190373, 0.08707827257533228, 0.13112872658718017, 0.11619299980661563, 0.18083392071627802, 0.09219015512855784, 0.11808908274096828, 0.16853581933725267, 0.14241094941333418, 0.1201264399494375, 0.14961580715833173, 0.11781398056735916, 0.21504573734296908, 0.13452422745045156, 0.1316109942572732, 0.10337832534024793, 0.13221235795607492, 0.20215984734316028, 0.1269527430075311, 0.12387766607946928, 0.09389249442685997, 0.0989777401029583, 0.08459638518792006, 0.10700836402153778, 0.16408717740447293, 0.13529135725430905, 0.23631687336150678, 0.15353125189581227, 0.1555095513861987, 0.1869893759008377, 0.14959112380541142, 0.14256223645662108, 0.18567533592783636, 0.09765240799395308, 0.0996690042196743, 0.165227392027455, 0.1525286879510649, 0.10104121324876625, 0.12255067155966837, 0.2711836338764237, 0.16854200932768085, 0.08046387709797391, 0.2529130650744323, 0.13787543310994102, 0.1992558225268318, 0.16332222329032037, 0.11238434006490054, 0.12137607491064457, 0.14479784955901487, 0.1526676409787709, 0.1152848332158981, 0.12481830713729705, 0.16359000166337337, 0.08502652057476583, 0.16260154905819124, 0.11004943430664078, 0.2175868816313244, 0.08078940317875917, 0.1878162299192721, 0.20617189576789258, 0.16804808179938024, 0.1803768573388938, 0.07753251060362785, 0.16353772382342047, 0.103699270215246, 0.21767265283532683, 0.19179628651228645, 0.16736612565094428, 0.23190656646845803, 0.12708270982388528, 0.24706839643899473, 0.13989297162380912, 0.13454794553258728, 0.09688708615759689, 0.19867909621567498, 0.13372127537525472, 0.13838446789210843, 0.11205203410598541, 0.1083645694738915, 0.159871916496946, 0.08733324961917055, 0.1371220928887206, 0.1154656146442698, 0.12385220897774543, 0.10784751375115688, 0.11474038984987045, 0.15701094582196207, 0.15985843334947863, 0.13395684741197095, 0.18889555587403237, 0.12938546287196298, 0.14641919804196205, 0.17702404289476334, 0.17023353146449213, 0.14449703747466688, 0.19602807959721935, 0.18349655122766573, 0.21992413927951168, 0.08916304296543522, 0.1687585057750825, 0.12827645101013685, 0.1075341914510054, 0.11185673531144859, 0.16459593639498757, 0.2145824533316397, 0.27675683159501324, 0.10687420670423778, 0.13102507489102502, 0.14397885560268356, 0.2410329106233774, 0.19386058703305262, 0.0914596519883602, 0.11534646498940646, 0.1517781669334058, 0.06898763484411663, 0.22403904266895788, 0.13034408401337363, 0.2057871817340774, 0.26757529846602873, 0.1630329331683536, 0.17317841941070172, 0.1356358516720995, 0.12785464299902802, 0.18642481506591846, 0.16731223902635037, 0.24690229325525223, 0.12421552617583545, 0.11072824183370798, 0.2191458399137182, 0.13755235851051348, 0.11215840541427174, 0.12896077437025885, 0.24881875412839077, 0.19629135337327758, 0.14170509132166065, 0.1271506694836482, 0.10480822845091743, 0.1714475356763409, 0.11924409818264747, 0.1525737339210126, 0.07710760759730494, 0.10470771771525184, 0.20076241103872178, 0.1291601564134321, 0.14453091388267858, 0.12364625390018187, 0.15919748333192643, 0.23128019765980784, 0.20546663522479996, 0.20548932674911716, 0.18156122926983143, 0.17842627490960783, 0.15247326915062245, 0.1297859123517429, 0.07606853190208636, 0.21979375111479915, 0.11705404432911067], [0.004515443842167095, 0.06609268816969087, 0.0388505824300791, 0.020671482611026977, 0.07541397871870188, 0.014374631535892766, 0.018229343695566058, 0.05003910121177474, 0.11076323673008912, 0.06274714006952221, 0.017008500233773264, 0.03151645117829884, 0.04768431164144028, 0.08024232447027199, 0.08707051210465931, 0.09416815584465381, 0.02960776035193234, 0.03865539854873092, 0.03138268265062042, 0.11013886741092128, 0.03209251482340117, 0.030353070056486516, 0.026088206871082226, 0.011214290937078337, 0.08506139289707908, 0.05375820910558105, 0.03131636816467489, 0.06002166736570578, 0.04296263214200736, 0.022065860309427785, 0.20877060390287833, 0.021922827863525, 0.0452915930579747, 0.01615481973145037, 0.053338438888350805, 0.038578571421244455, 0.0049357780916315895, 0.03919128854308398, 0.038760069141825365, 0.10040619530745092, 0.07873070276071949, 0.043762343665284496, 0.16130278487840008, 0.021759139771963802, 0.022236925827699806, 0.012555165054847398, 0.025520409314682888, 0.02512499303256552, 0.023143740273230982, 0.05105398768078416, 0.031120257316938335, 0.05158989682733532, 0.031588940332914074, 0.04018621842166589, 0.08827584420120524, 0.019025445029500033, 0.05205395458746822, 0.029357330039924676, 0.039113250996677146, 0.03570766841632224, 0.045763407458340934, 0.05949057308175872, 0.03848788576320775, 0.035442433455177856, 0.035453737082500617, 0.09064270348678674, 0.00909794527556627, 0.011485622042880185, 0.05591714063719396, 0.04827612605426581, 0.017700384881707932, 0.06522215947869324, 0.053470225163525155, 0.033938679468607715, 0.03132775606166932, 0.017363214264473608, 0.05185674823399994, 0.06125808347977939, 0.01004644831071698, 0.0190941650315278, 0.03325108874348864, 0.04205257714455647, 0.013502390638384367, 0.033003025643167, 0.057215192355215556, 0.023927193495535085, 0.016325467731803656, 0.0273360530169861, 0.03741882538663284, 0.008834433054641612, 0.09430046689005629, 0.01177484992020313, 0.03848364546654686, 0.014810273179694291, 0.03329121259852283, 0.04027383206712623, 0.03004183726114852, 0.004801280822815193, 0.05556069141734512, 0.06961850058888236, 0.059371032722054, 0.07290260460708411, 0.030880925703733682, 0.02656708268689052, 0.07485559255245232, 0.05530469547656756, 0.045328062673610066, 0.06463424828384193, 0.06428972322253451, 0.026034145961485566, 0.035620847671863534, 0.06258679020609106, 0.09830253318913522, 0.049923533017957405, 0.08948705985300964, 0.0518454292849187, 0.02674055180602497, 0.026091681079818838, 0.004608488093400675, 0.05685518848739805, 0.06598921267375832, 0.06299237630540325, 0.01805903851955889, 0.0600646602200164, 0.06907015783532013, 0.034575930556222316, 0.051753602155874816, 0.013076484056880638, 0.07729979607486918, 0.02404646955490593, 0.09125067852437498, 0.026108349237831372, 0.07389026048082499, 0.043404193730243755, 0.02570983413006029, 0.07297386610580069, 0.015152680965500976, 0.04101828183798541, 0.07388848315684066, 0.0500046962030953, 0.02098389901220799, 0.029595152459918495, 0.12112780113614376, 0.02611008825741949, 0.07285503054698629, 0.04289864081769221, 0.023913706517628124, 0.029507805030011845, 0.07257348557393398, 0.06345150812018303, 0.009032846954200537, 0.017454453421035604, 0.026270662201568488, 0.04191628627238735, 0.042183991867087545, 0.046890092968580224, 0.017079957084910526, 0.06310366206772386, 0.03016668277972889, 0.009368931641802192, 0.08401494743602891, 0.010954842812591984, 0.01979137399053622, 0.07076560234230372, 0.030201070551430027, 0.03321165053714668, 0.061045846481236725, 0.02057788198843839, 0.07957307005962057, 0.048009577252331286, 0.04834519654151894, 0.021187320253961993, 0.040913067322464726, 0.01971958963681133, 0.1060446024301552, 0.01653087505650136, 0.0473300917374511, 0.081792265897797, 0.044020017338616234, 0.027830453604579936, 0.034661659625388926, 0.03610082473906298, 0.04169804314451833, 0.02579546552301655, 0.03556593448945111, 0.045428726626860524, 0.01511781630406697, 0.02841102184667703, 0.02306187420242256, 0.023479824960832636, 0.05675445558623441, 0.04464887976345997, 0.04861921853115482, 0.04221826664081985, 0.02720437016368153, 0.06381631918972538, 0.11633154680772174, 0.07412727276283888, 0.014573899623487267, 0.05207823957466791, 0.04690529215299795, 0.019375449534685864, 0.005189488696370034, 0.026968890057516196, 0.033763122759879596, 0.03927448569166084, 0.11734545651462772, 0.03340526010781046, 0.026529136436781096, 0.014472046318734366, 0.020441001228567575, 0.01585767146260027, 0.040354527938630314, 0.06968619211787178, 0.02093053907306204, 0.04459853629551588, 0.07193363361781643, 0.02433076861404604, 0.049768492143841526, 0.04950634068659237, 0.02315583105589594, 0.016002244702840767, 0.0186710738231458, 0.06949453224097529, 0.02508256708331887, 0.08825715931673205, 0.043100160246174184, 0.09189358717131038, 0.015377865807573884, 0.09267798459698116, 0.03915092720079326, 0.05892528829375102, 0.03266350696644476, 0.017346080708047076, 0.01488012986467971, 0.05593300631810581, 0.011833146338411158, 0.07942044236246618, 0.04924110572544798, 0.06014832468222707, 0.02609569729576188, 0.012077716077798078, 0.04376507859917418, 0.031334405704852075, 0.05860921573795139, 0.07461095769559184, 0.057375277918312824, 0.021643223008140925, 0.025441762728376255, 0.06133294559174007, 0.022413037950173024, 0.04740945844640655, 0.04287243294980257, 0.1008564328414298, 0.024905909123199604, 0.1450869864633968, 0.09668755855771805, 0.03275942117456467, 0.08284946723330407, 0.07949464563881198, 0.07998818246227118, 0.037826104540257685, 0.06361902473614582, 0.023601989171678023, 0.05425219792091558, 0.05713060475705613, 0.07449108791807968, 0.023029296313442534, 0.04618677062793605, 0.02413228289374421, 0.03753066273225892, 0.02151432105400149, 0.023321074305943424, 0.05692988589045502, 0.11101016985072244, 0.02569497968520849, 0.07683034505574934, 0.019575178232644836, 0.002371907805002505, 0.058700633009955774, 0.019621191388596932, 0.031219908118908925, 0.03793203534798757, 0.0806694797750923, 0.07435798014123594, 0.018028404578686725, 0.03634263273148287, 0.042584238333567496, 0.08719882417109706, 0.01217397694070373, 0.038578709317070824, 0.02170048808048089, 0.0019608909802158333, 0.025951688087755637, 0.013099275172627984, 0.07504463240864777, 0.023321922748319568, 0.04987377943771501, 0.11310735852607798, 0.051662740297615535, 0.037483341481176116, 0.047605381602601665, 0.02418784150523284, 0.035121090214459166, 0.034401308474761826, 0.008511881310222371, 0.06050266716028414, 0.028094474316364335, 0.07501008950414197, 0.011960885754125494, 0.026162770208752444, 0.033878449636000785, 0.04069339927105654, 0.03385811000161114, 0.041491027035179644, 0.07793911943031896, 0.037462442602601745, 0.028619591199282198, 0.11281717974211901, 0.010030229271750056, 0.05584083827993563, 0.021461614204810995, 0.12729732935587246, 0.030612304633963975, 0.009179582477607315, 0.05853729540361993, 0.06086438706505203, 0.03484745892966467, 0.05945184350674672, 0.06509095159990173, 0.04503767704591156, 0.03945889454635401, 0.08641747577536492, 0.060609716456383474, 0.08488498583075502, 0.02287712252338327, 0.08085294251119898, 0.016460647776482568, 0.0502575128789871, 0.0314547868460537, 0.00870554546465076, 0.06890158784846145, 0.010669245234420224, 0.029603638798899712, 0.05254831112500641, 0.08038499302441075, 0.015944307388347245, 0.03074808988810307, 0.05835573256556546, 0.011444995442645685, 0.030206854515258345, 0.015315890252109499, 0.09036990723782971, 0.15821198782613202, 0.1247483020227763, 0.10042601400205206, 0.142575612351779, 0.14419674633010743, 0.1493137846550634, 0.11799600305816821, 0.16750639634988002, 0.15774047603049587, 0.15766474057830152, 0.11329543311148883, 0.11891622787281392, 0.1603346182814529, 0.1443121957802965, 0.18497948294445393, 0.07856143563384972, 0.11353108941787675, 0.13091201563515972, 0.23112059090166326, 0.15946182963107863, 0.14061110244402963, 0.09466250472131277, 0.1279856516949592, 0.16674000199042982, 0.10364958175247717, 0.1976941063279106, 0.19662881510392313, 0.12156149883183742, 0.14723750251916148, 0.25191828458299564, 0.06078072643328098, 0.16902700427078432, 0.08172764638138395, 0.1736068770649933, 0.08939300723854574, 0.14440211918084853, 0.2571895976941432, 0.1151921442379394, 0.15078209941425633, 0.20820294807274498, 0.13509018256539299, 0.23892681234546248, 0.10958880862040866, 0.18555794061431963, 0.17822505425541632, 0.086949470212623, 0.16615213676085397, 0.1579869265157369, 0.14562323268863464, 0.0997726482549502, 0.23641465682416196, 0.09848961952112376, 0.15260751839847336, 0.16124531296232056, 0.17777848628259477, 0.170006892012973, 0.09853039072045396, 0.14967937713428853, 0.23963316073340757, 0.08427567013929929, 0.17892224023178702, 0.15775231974980525, 0.2526847861947552, 0.1438599127915598, 0.10090204571644146, 0.14336592397622525, 0.14917149148400755, 0.11348045100608181, 0.15456533269776454, 0.13709848205889427, 0.1935509955810924, 0.17796683665965835, 0.13218202087427341, 0.09747312043703373, 0.09727605964027106, 0.20714358636929145, 0.15495629800904184, 0.09283984365362315, 0.2476219868948383, 0.2909618483916406, 0.12254891721832177, 0.12297628702776087, 0.06418827019872204, 0.14584170564288093, 0.14842884585021004, 0.24000633748308306, 0.13815566807264282, 0.13347079526753197, 0.18485370662904557, 0.2784110299281536, 0.13732208780223323, 0.1254477096541274, 0.15520762081348127, 0.15622901519940746, 0.14038366626106924, 0.13550183225062587, 0.20911186542962829, 0.14414007114546915, 0.1811827511917199, 0.14081797682710234, 0.20883058858734949, 0.08899805827006217, 0.09051042308490123, 0.14652349325197359, 0.13329867063270462, 0.13961684289238147, 0.2935527271080402, 0.2881352597426984, 0.19590253310818828, 0.12169542632276013, 0.12867372122503098, 0.18398594351545458, 0.11649463926592182, 0.12793779418232942, 0.12173748454980313, 0.12392552359209907, 0.20476224802194104, 0.16567855652782226, 0.12045301557067903, 0.12615607285331334, 0.15290045509895972, 0.0999048520480433, 0.19454971376445987, 0.12588131541927017, 0.09379487950354816, 0.32365134106047694, 0.09057519581889914, 0.12499520449989265, 0.09061593637471238, 0.21976830167395456, 0.12074876381384751, 0.21955229552282443, 0.16287441425506147, 0.0776483124542621, 0.11978325554199758, 0.070592297932073, 0.15124690027967577, 0.14962786538225992, 0.21123775941950662, 0.08507059361304968, 0.08460358641440831, 0.3514504042123595, 0.08812307094734523, 0.20516085889070265, 0.16076134457703561, 0.20008073068193852, 0.1315642935374091, 0.1296480931341648, 0.15291946940124035, 0.1341472662264301, 0.11873092652568895, 0.12636298554078226, 0.19321410075551082, 0.12020840369645627, 0.13357556545205657, 0.15908715134907156, 0.12810748265755753, 0.19016641913162124, 0.07179325566657128, 0.2117607523236544, 0.08384604037048356, 0.0922087787259971, 0.240848068929007, 0.0876210994958397, 0.21252634995166333, 0.2708504775599126, 0.1626377850170097, 0.15718553725990558, 0.22019896566146807, 0.22006131498323334, 0.127747934612055, 0.10138316425464808, 0.09200639361816068, 0.19303868194260906, 0.11752840597182514], [0.07933713796157991, 0.02637203287092909, 0.10853105570159613, 0.01311665291958038, 0.04722881874430084, 0.015098473541588794, 0.05536989338936345, 0.061066772172888445, 0.06925594181783738, 0.007039914705655388, 0.02449266789030404, 0.01052360042869564, 0.03649452115379034, 0.005040008662974523, 0.013434511417853496, 0.05184259092915924, 0.05087062070566801, 0.0580733755393134, 0.0388466447381483, 0.04573139264398525, 0.06697964178578508, 0.04806067148644117, 0.05217527993203652, 0.01018021971122512, 0.027088681311016122, 0.03307976084010255, 0.016684561870211077, 0.0060712654733159135, 0.05170520072081878, 0.05898010954561253, 0.03057355590675387, 0.012840090390865602, 0.07315684620651507, 0.03181241967174555, 0.0350327372941519, 0.02693494470159133, 0.028566403629919215, 0.04036668575398865, 0.12006136844114912, 0.007726479830565833, 0.04274463033183448, 0.015270713089604773, 0.07048368198616851, 0.006754165346313629, 0.04317671924288716, 0.028192169678908204, 0.017330915997585943, 0.012747395667247476, 0.04047054046344373, 0.060536217980928, 0.030081317602326314, 0.04021731776095206, 0.03393189192959859, 0.020710258151314432, 0.049818992659810095, 0.024343933835024797, 0.037980390817768155, 0.003267594823433507, 0.010836269638891663, 0.010344983198710028, 0.07853028649884848, 0.037562627750899524, 0.03728123216499244, 0.09370969052636817, 0.04629285082281117, 0.02110059718571363, 0.02814176109349055, 0.024371436391506466, 0.07183630214703661, 0.03127983917722539, 0.08530771314737298, 0.011691190246041986, 0.04146231789021723, 0.0791204729748349, 0.01004588810892235, 0.10443255425460878, 0.027619484481551958, 0.03910208526518076, 0.04765802716475822, 0.04994772224416656, 0.1034135424021271, 0.05754283666911145, 0.057201035050374854, 0.0382796592349487, 0.004758074900300633, 0.08714332876186218, 0.05010197787816006, 0.06180669819455474, 0.1038638718666569, 0.04728698780039146, 0.013957626896069176, 0.05593297950502846, 0.019842575476955504, 0.03785230474726808, 0.008526827685625083, 0.018014641809127024, 0.06205412927233885, 0.021201529269737583, 0.009010471441152116, 0.010934205361521773, 0.012905841802186784, 0.03083254150565594, 0.06529893681046463, 0.03783599090492053, 0.033908319404168476, 0.013130532517548532, 0.05355988809418294, 0.017008117189811125, 0.0489425459395974, 0.042265086104312254, 0.04054377846900494, 0.084325228367121, 0.05623956789232551, 0.07781772513783748, 0.10465862680106394, 0.009558116097093351, 0.10171226030516048, 0.04236990991499155, 0.08758142380224121, 0.025412184073619788, 0.03359241155727256, 0.03452041599478933, 0.026116004371414744, 0.03952812974251086, 0.050957180980232455, 0.05723987953857549, 0.07222553609960503, 0.03452431921276354, 0.07686209940021077, 0.02687501747371449, 0.07993374425437182, 0.004993368751339374, 0.008161732205940832, 0.05003421740125745, 0.0621377362779552, 0.058241374790668494, 0.05916900001466275, 0.008384320967560335, 0.02425296472445611, 0.07700214027276925, 0.06700913617086988, 0.0421663909970272, 0.029054361418069854, 0.040176768727119894, 0.037886763382102215, 0.022932639000036066, 0.050687525691764976, 0.021196024928001628, 0.034957158889982014, 0.05219613667577506, 0.015890997244916376, 0.008711167592405072, 0.02641660769680335, 0.02298217999087947, 0.010906196229400174, 0.0940558473549543, 0.048428573720758004, 0.03581457598615558, 0.03842367227339456, 0.04773962702001295, 0.027381518420072335, 0.03929282583656811, 0.062083186987306804, 0.02671739296807397, 0.008575132402080682, 0.0434785119197782, 0.07881929316828329, 0.03259520639755553, 0.042755650506625255, 0.06638716470690505, 0.04159962765932564, 0.03602023995030792, 0.03027700901692433, 0.03957399159609791, 0.0958193894175272, 0.026098116218382796, 0.047790008792353254, 0.017370354203927903, 0.07529587094341555, 0.04143688760157074, 0.05330531707694454, 0.029808034887537364, 0.0531349276312657, 0.040671500647740985, 0.03321838828044073, 0.04261595820407233, 0.05416602835119252, 0.03926614299416542, 0.06180358021670292, 0.02559686488952608, 0.037833604541036396, 0.016156330839881015, 0.012886793983559455, 0.06694712901427861, 0.03531469595468333, 0.04675641828667253, 0.0692790317078752, 0.05497252358303917, 0.08084943382850579, 0.03406946599904088, 0.03569397459467573, 0.030804179015479265, 0.012718050669307911, 0.048843310740325725, 0.033771656979356086, 0.036755439209481405, 0.08619246809112449, 0.06771946055514198, 0.03715371682999596, 0.008665331594285466, 0.01571245279328357, 0.04414539145786436, 0.009355480095461733, 0.03712160242421012, 0.04982320614339364, 0.016420818865299225, 0.032603472486258514, 0.06478858435706747, 0.027710744705531868, 0.028094206185590838, 0.09014848484507493, 0.057803582355019555, 0.05658871629425595, 0.044016320964381586, 0.04643360415713922, 0.038398954446517655, 0.03914912306373158, 0.04128329846407137, 0.04176322190511612, 0.03052827053432984, 0.014719010082884662, 0.06070552724263361, 0.04085045495641328, 0.05017388672117264, 0.042741776654316534, 0.04511456162999234, 0.061633286532014615, 0.04747368725797823, 0.02153390417656591, 0.02650990954510147, 0.06862054083255992, 0.028464851014676596, 0.03469200436806968, 0.036562687657292814, 0.014164644920627677, 0.04753800033922157, 0.06839796164703947, 0.04572489238794773, 0.07044054357515228, 0.03982076766870676, 0.017717189020327023, 0.026879152433285793, 0.026050584293120814, 0.053402702173879074, 0.04812000116573707, 0.021489089948215315, 0.03354530098036893, 0.007928586752724745, 0.06454709046069654, 0.03622883803121025, 0.012598391565974924, 0.04685791727576045, 0.06839878136111845, 0.033038736831757336, 0.07245664184372272, 0.03206212028500534, 0.037917123446541454, 0.029617005117958593, 0.038353096423370224, 0.02259231976143295, 0.03632972031951912, 0.04434730542162734, 0.08335484777607265, 0.03554625369067635, 0.047325717375403455, 0.015062144694609508, 0.03618729308307652, 0.02880063309754816, 0.031673524100633885, 0.040521175044799046, 0.05697963564025779, 0.01228314159708398, 0.014409289353587216, 0.02206898594815885, 0.011078874362752804, 0.019837029000383713, 0.0305333458668282, 0.07956173961922046, 0.016997522193818324, 0.019559362347448067, 0.025615783430816188, 0.03851484056682356, 0.012522465549409391, 0.0958085109690024, 0.039630659119856936, 0.053140604342784614, 0.005995037809630195, 0.04790204149040003, 0.013702945753691659, 0.03563954021721598, 0.020746944186788414, 0.04862998206649096, 0.05865800021696956, 0.018846004254995816, 0.05831684211208936, 0.05576225298066294, 0.03014884633763183, 0.006063783188320456, 0.019044520618814616, 0.07374749233525607, 0.009456212996625373, 0.08061721725689788, 0.07643207126567442, 0.02050645961125772, 0.062234186747622114, 0.041997031939606515, 0.011025538363854491, 0.02887850593505127, 0.03501493341079162, 0.03169089705953675, 0.021996217171451258, 0.06992574015091504, 0.03271676156850111, 0.012124737596980507, 0.014084737162075698, 0.05118632553926399, 0.06286020698626676, 0.12619925722960504, 0.03839248866443673, 0.09074273158706005, 0.05666303065335078, 0.06534556092153634, 0.10109130773813495, 0.013598904310305034, 0.02016530342159733, 0.04234370970798116, 0.04146034904425183, 0.019763859942735686, 0.041563181026328, 0.007717019602310874, 0.06575234594845003, 0.04811085024548154, 0.06149696884676815, 0.03907616851070235, 0.041705910867500695, 0.04519119340505812, 0.02254619552273183, 0.05005568701533541, 0.03993947299257402, 0.03480911239861481, 0.01463337102904916, 0.07446712468780818, 0.20175622625937387, 0.15674112965503048, 0.1899365008237862, 0.15521008761659746, 0.11180356114862428, 0.12412807723927884, 0.21994886859770746, 0.1707163047526152, 0.12262662917736078, 0.12535939503821636, 0.15056164995316537, 0.09690656777351134, 0.1803802740910361, 0.08355242951262383, 0.127519280349295, 0.1909899330067058, 0.17177767360643034, 0.17791445156739605, 0.15963134956696343, 0.11979033419441794, 0.11894964462807102, 0.18313701084304243, 0.16737781615266878, 0.13727682732766675, 0.14044286953585763, 0.09267193250237934, 0.16932784699864928, 0.131813011642906, 0.145317793433224, 0.13509393639622197, 0.1357658261493329, 0.14312547962031058, 0.11916688418075924, 0.09206772661737858, 0.08243789415686362, 0.08678014945959853, 0.1356001672965865, 0.13015156611800194, 0.2265037467042285, 0.08946512675573749, 0.17660750556857358, 0.17439564119183248, 0.09408649087192551, 0.23005649477483767, 0.24681710427807224, 0.1596410635618433, 0.174307816872193, 0.15913348434673202, 0.11941842915069674, 0.16100371947451947, 0.14284568898860486, 0.16301900568989017, 0.17524009991076686, 0.10656891300553277, 0.11042924537774056, 0.14835019926390342, 0.25759050682667767, 0.20143165012761471, 0.178892990994838, 0.1572453687267919, 0.20488376488849042, 0.08101405080167517, 0.11651850290476315, 0.13927452416429598, 0.22967319034280317, 0.1695477755199517, 0.10372527123939607, 0.12741929821429715, 0.1299354833580794, 0.18394828263309695, 0.21117222825846366, 0.1829983182852307, 0.15187582782199308, 0.20209408635574005, 0.06394168564809427, 0.2166039295374386, 0.06857649077691379, 0.15051410653658454, 0.20073113932965264, 0.1222147649875091, 0.2515156287699938, 0.09532928466796876, 0.19233458585316138, 0.07842887177943222, 0.10455712781197603, 0.17540724497408638, 0.21636633502860225, 0.12289109805058088, 0.24647627176055986, 0.10367129268425126, 0.11901831674960353, 0.11953200934635055, 0.19698417264847987, 0.16518429192083497, 0.2187245375206394, 0.12208499735401523, 0.21237821919062447, 0.13327694437917204, 0.09641034964231715, 0.05939931668821843, 0.09496496389469794, 0.15385492404382076, 0.20424938280015223, 0.2804138289103585, 0.2230403091638319, 0.10258168582954716, 0.10087041394604791, 0.1016691831811782, 0.19519348809074974, 0.10286094786058511, 0.1933994633896697, 0.16932464475112577, 0.16962173364816174, 0.24551018892276674, 0.19135275224764503, 0.16068082873619374, 0.2065942247187899, 0.14297230800072994, 0.1408402699856989, 0.15467862178000713, 0.09377046428140133, 0.15530535831086098, 0.19161070937350874, 0.08752904637085815, 0.16599936350699396, 0.18924671525676406, 0.1624978973620361, 0.152879387681042, 0.13634092835409028, 0.1474508426843151, 0.19015578583123224, 0.08175955394343024, 0.17959083580682356, 0.1323482313103253, 0.11099790478305471, 0.16711962920042778, 0.1930634265825633, 0.09882121301826932, 0.16161032321472324, 0.17367136634645924, 0.13465677598311057, 0.15968860697842416, 0.17003267853250428, 0.11307988661311327, 0.1913232885060772, 0.15420971468331354, 0.15669084364368072, 0.16365547153738239, 0.1113364466976735, 0.14522842161597746, 0.15046789611299194, 0.16549469542599496, 0.15210136410690125, 0.17521641247214811, 0.1623840720182465, 0.13900941177721948, 0.26581403168459095, 0.09090013201198271, 0.11758790036002476, 0.12599771481848535, 0.08326690088236526, 0.07899977582236452, 0.14402570954013255, 0.11568440169456506, 0.11557870454365209, 0.18365324685169807, 0.18108187273385065, 0.10773906634459574, 0.14046735370591765, 0.1992293158846517, 0.13903872230120246, 0.12465526830525168, 0.11568545889590057, 0.148699336174515, 0.18373793021084803, 0.09737694575901955], [0.041703869243182486, 0.01567466071836891, 0.007428648307048266, 0.02653247849535077, 0.021171592468876513, 0.027002969478827812, 0.04914698033263126, 0.054131818694933775, 0.02676636705385341, 0.032220765602804964, 0.03883837481900569, 0.014004819827424663, 0.0694153034278462, 0.039987839953673464, 0.050180218437866825, 0.09486654457906563, 0.03727123088714096, 0.01758402378688897, 0.02853322627713844, 0.021190629753794883, 0.06033347281176717, 0.03421803726063621, 0.03788274525093936, 0.02332592364250412, 0.029917181349329414, 0.009871394347189175, 0.030164432396451314, 0.05005186806703287, 0.031790318035130063, 0.01933613390241179, 0.007982781248903203, 0.053893339354544885, 0.026126710450156566, 0.027919467275721893, 0.03430415320420458, 0.10927176313294519, 0.08370314198996752, 0.014290644359143992, 0.030691816899625045, 0.015444560464651836, 0.04655343179981555, 0.06155519152901346, 0.07471477027021109, 0.030795349852151932, 0.04404160569632246, 0.04926729061069989, 0.043735599535847866, 0.02691858680918813, 0.0538959555448063, 0.12177496923193817, 0.014392838573023198, 0.05020746052445424, 0.03259296175993739, 0.023784455993483146, 0.021202216833649624, 0.0652821441631644, 0.03454162513897304, 0.04452473521533032, 0.019413891826726256, 0.04201618796815315, 0.07347232121373377, 0.048791940714563095, 0.024450146180066853, 0.10833644638619117, 0.07748241611425916, 0.03999617115985002, 0.011464920431946315, 0.020983789844678778, 0.09204619188582705, 0.04454681386930808, 0.03336597511905336, 0.04348790032729026, 0.058602845716860995, 0.042459205123445684, 0.015015560803153824, 0.04806165973986349, 0.06622816315822064, 0.020278061987952362, 0.016106567683539564, 0.06727850034592614, 0.017514250413965315, 0.04834673254780712, 0.0623864735356502, 0.022476138697276195, 0.08382972269769638, 0.013987444953301982, 0.04215055979007194, 0.051231149343713644, 0.019252404322727554, 0.057136281468575044, 0.0264710784634395, 0.049092936660012895, 0.08062169121037568, 0.05422490986905271, 0.1106858465279783, 0.013660040999492331, 0.05423608709186797, 0.016027430800961393, 0.024277448894516118, 0.03457667366150887, 0.0520399734828501, 0.03993453172546241, 0.0076095068230173524, 0.026101088639529004, 0.01833646960045782, 0.028982862432096756, 0.009439031559703572, 0.06523365845843669, 0.0599130169458447, 0.055715081116725365, 0.02586549936583446, 0.010819302706588662, 0.06098296981485141, 0.021031967199016965, 0.015880779547226286, 0.04335462784154281, 0.019862350121500994, 0.040199720721331336, 0.02784124969865286, 0.05535641024189611, 0.03165450405269381, 0.046899354971584775, 0.04477826052255208, 0.03659608909079144, 0.06011709127755416, 0.07124266061451166, 0.015460628201253714, 0.0663977520420186, 0.047960493999022635, 0.055301512381242174, 0.04581934719857189, 0.08006623149999688, 0.03511272070388641, 0.0084655684223699, 0.08134759782302765, 0.03451875741443327, 0.018317501263452635, 0.0847156574168513, 0.04776264413169796, 0.06647144970033439, 0.06345082630193041, 0.037126555182640596, 0.029483960543368614, 0.009868517687033502, 0.033009211803155566, 0.04411398185296886, 0.04745551565241429, 0.023183931160958546, 0.036638844457845536, 0.019679268514136636, 0.07184973932922849, 0.01940709662683789, 0.039643230622694384, 0.08667831339182393, 0.044784565426168904, 0.02123377965612998, 0.0404528170193155, 0.017809962267957388, 0.06774987424573592, 0.08623673265138943, 0.05805121261566397, 0.028300481104862787, 0.07755272766394962, 0.017972650614777402, 0.03615201090372378, 0.048472439915302305, 0.034493066655892524, 0.04549866662390771, 0.03535853533615028, 0.014681424851709557, 0.05810567380620107, 0.04152343638481633, 0.06267587857080564, 0.02475160369349103, 0.03883593865940648, 0.04847849200990412, 0.0804775670891808, 0.03164661143185391, 0.023842381816657803, 0.07775151215854191, 0.058005304796801466, 0.028783710215300806, 0.06665839813649654, 0.053432211880722356, 0.028528819356354016, 0.01625661557960895, 0.0849744878829487, 0.006686811374815842, 0.03293274473699351, 0.013605768458106586, 0.017496618900388, 0.026280023796003193, 0.019312496259508115, 0.017392976780331904, 0.04866621036443019, 0.04835938448987661, 0.02944802527406043, 0.02738874645963792, 0.022934364613085505, 0.01266031732572423, 0.034485942038196715, 0.010801663532132104, 0.04188167058952874, 0.022781430480761394, 0.04811074299317214, 0.039131790324444735, 0.02091232533266227, 0.03455202478254515, 0.03177894354467431, 0.013588089064034003, 0.03175072278076362, 0.09793530128175214, 0.035643615804973154, 0.015184304117405368, 0.025511281377065088, 0.026566703473368, 0.06409509475493143, 0.0439186409235962, 0.0613608158704254, 0.0478170593569596, 0.06080892229933412, 0.00944801202539595, 0.0309816911636341, 0.013902797983328422, 0.03719938716160194, 0.1040301895550182, 0.059897534308894995, 0.03315072356452865, 0.03524834891000102, 0.07165998701126346, 0.03781802997353577, 0.06314682346137782, 0.01979963433357977, 0.02527013030504027, 0.046379104662205906, 0.043574238436356674, 0.0927078083998734, 0.0713265855466166, 0.039257413422268246, 0.053072989422587626, 0.08613593846319184, 0.01508917323418803, 0.01658638387227491, 0.05178676610211692, 0.07015977235090348, 0.019154182274735743, 0.05351951143013374, 0.034286939208545995, 0.04893443689891889, 0.0500860202666973, 0.057813867085403016, 0.07889250819120677, 0.041104596964414084, 0.05627325660879574, 0.012701772258526856, 0.04662586924349589, 0.05649250331184557, 0.06402696272538555, 0.037396478601881576, 0.027695221848966136, 0.009143257461067651, 0.04351057269940934, 0.06346807477154559, 0.018037182031079166, 0.03675208757481268, 0.014604188824793505, 0.014511765104778593, 0.06983324269493742, 0.07481552615401245, 0.051240782899361466, 0.08332384419777701, 0.029558385985212463, 0.037876356077650865, 0.03734593978151679, 0.024204293243406762, 0.01717540206417682, 0.03197769931096944, 0.013088546111248435, 0.019673114912884853, 0.039067756865293755, 0.017902132221347383, 0.0315192167557055, 0.06083308088202631, 0.02914022646784302, 0.053773435103076125, 0.019555539568705906, 0.008871293375118366, 0.04036573963540216, 0.032135147616387374, 0.04617145653032968, 0.020334348382969058, 0.022861136183623346, 0.07331361077846059, 0.06490809407325522, 0.009661113745683144, 0.09154012952480586, 0.050088330021789, 0.05772775497227427, 0.05370969275733637, 0.027167111477484147, 0.02670788773215346, 0.03955988408697229, 0.05873403827389402, 0.019753785886531396, 0.06377273644771307, 0.06927535448583864, 0.050872064781405275, 0.048181100508138064, 0.04047672279299267, 0.023197511984636227, 0.04506300774312789, 0.05065430811936817, 0.03764297122195844, 0.008702337471467834, 0.016912465366805275, 0.03993907845729301, 0.08018035561807695, 0.033149455689013965, 0.006413204030268976, 0.031215286693505706, 0.05838605049516886, 0.0589496958550186, 0.07575722441317574, 0.03500667498296788, 0.01616563306250159, 0.048247405417984536, 0.023068927956985372, 0.015866216215785715, 0.03557456830035775, 0.008705616327783754, 0.03032955690287054, 0.0942128417532771, 0.037768138497467005, 0.020391640268386375, 0.06262707493958936, 0.07987364465671201, 0.01728799783684794, 0.021349485745773684, 0.14467414168100204, 0.04433089198784963, 0.012679582521800074, 0.019698579675487934, 0.030265326176079053, 0.026813954520489902, 0.07884609858475386, 0.026554348390369166, 0.08232805247028029, 0.01719064529865019, 0.01923278098054711, 0.05062240821820113, 0.08496623711600419, 0.03252612441898354, 0.19426705796391736, 0.2340536044850465, 0.1171834672230386, 0.1850494574154577, 0.11194947025468273, 0.12259032427062913, 0.14882534231630065, 0.18060187268401348, 0.10403843266108345, 0.10383522783916804, 0.22797454358829608, 0.08612640066853455, 0.1197639654480642, 0.15105364693989679, 0.1272386700035103, 0.17435286284214066, 0.20114096572562573, 0.09458666967768824, 0.09442826567758476, 0.2093345059021827, 0.1558604962643116, 0.11178260098301596, 0.22380385367620378, 0.09008041027212337, 0.10359868287078797, 0.22755052924396532, 0.2879480891410382, 0.15166092483747393, 0.124451580847944, 0.09459174884062621, 0.044486323566806894, 0.1542191222430237, 0.20594131862444265, 0.26873696355089066, 0.09945502820154352, 0.29483013275650244, 0.15020446911934884, 0.05858019632737964, 0.09149347477021719, 0.10165299574333815, 0.17526711217097699, 0.13713865570964354, 0.13672081603398248, 0.18742757819352612, 0.104379081317494, 0.3004017063686925, 0.16354520084156146, 0.11706181246066287, 0.11962872794679097, 0.21173697295448474, 0.14772591421440726, 0.1304110094544388, 0.12160791609916957, 0.12194360816671003, 0.15584935734589256, 0.17134153975113747, 0.0947519071820763, 0.21411958300778944, 0.09335233349232905, 0.14682750758384505, 0.19663126658528082, 0.1389196415942523, 0.11085947269513724, 0.1592622484050451, 0.23525593351692925, 0.24801011768079576, 0.09607419792202213, 0.21329344911200387, 0.14368737446925334, 0.09920107005464454, 0.13023897675016236, 0.09414155727192279, 0.16125096669120176, 0.136910300221174, 0.12275826606538989, 0.1932106073945761, 0.14059455494486517, 0.10219452797525352, 0.0948849383501276, 0.07306329154920194, 0.20416453090165892, 0.10250328439137629, 0.1586537600885476, 0.11306126301567401, 0.21600924612533665, 0.13706872720391522, 0.14540224696599668, 0.1636389546817349, 0.1289075159377629, 0.1768656465555391, 0.12151423886778856, 0.15335630805742356, 0.23444228685430943, 0.1528157257745343, 0.19032711373461833, 0.11141513924925558, 0.1269143543416454, 0.1580696640115592, 0.1553406749641703, 0.08821051988390186, 0.16648123281136637, 0.1618978053691887, 0.061003995097933285, 0.13329044284839786, 0.08720465410020083, 0.16407159517609304, 0.1383567048657325, 0.15906832090789275, 0.19812268655627005, 0.08337441366165878, 0.10955196745213001, 0.10822206179821685, 0.15546893340445336, 0.12319384067649804, 0.07879836364619194, 0.1524398677171238, 0.21698593162000182, 0.08320907656584056, 0.15024491856175085, 0.18037204630672934, 0.13534561160110659, 0.14264534167464704, 0.11132194465326686, 0.22174655519906553, 0.1264686214046613, 0.11110318058560933, 0.17006535984335408, 0.1390227876723774, 0.1332230883980951, 0.18668275687002367, 0.1949586514984408, 0.13460437556908977, 0.1151360359583651, 0.08894593364769414, 0.18488056567167083, 0.14550205290077195, 0.15875807062031763, 0.0894071415607487, 0.19142715470685115, 0.1326130066187151, 0.17466859831925363, 0.2549136577234153, 0.10605201816126224, 0.20599241668899215, 0.10451252617302442, 0.13127993702167465, 0.16246069613243305, 0.0980021960793003, 0.06397014581448128, 0.13180125985414753, 0.11394471560995426, 0.09958718602936115, 0.2216366215819313, 0.22087722926610903, 0.13272871653879845, 0.21253371971749493, 0.15085153762371312, 0.09381580902563949, 0.2677135313710859, 0.15503284551443594, 0.14006603088590408, 0.15233282991234334, 0.25857771836942245, 0.1551490304090323, 0.11799386567285947, 0.15073126181960106, 0.17133594730929022, 0.1600730145770696, 0.16144987375986192, 0.09045623002513763, 0.13585153606630143, 0.13491936028003693, 0.14696125121366593, 0.12576847066802363, 0.17769898167781292, 0.2270939101975772], [0.029046790554158153, 0.03781507670458767, 0.021943600337591865, 0.020522727488329815, 0.03394020015313741, 0.059266890729627306, 0.020195247883337642, 0.03973277864016352, 0.03680030514876689, 0.039272348306352095, 0.048968960651226585, 0.026896557950925444, 0.03229348649901729, 0.004929339122628012, 0.038739905707658305, 0.0494763138704002, 0.03569034716835426, 0.05736633001135723, 0.02249297347941226, 0.03423616290092468, 0.027563238306151285, 0.058544178703619595, 0.04381581660239928, 0.019922353958170262, 0.035674971783713955, 0.05634252627890918, 0.024613412923269698, 0.030226159930950215, 0.031021081489480795, 0.042188776086174676, 0.037641393080834425, 0.03679661643541148, 0.042343617777430245, 0.025679610046227614, 0.07579556711378597, 0.03229927046284561, 0.05799540694081976, 0.031144998126452973, 0.04200345941729123, 0.018957010395224058, 0.06337407195279676, 0.036803821492339336, 0.012994706086183508, 0.053305983573438666, 0.049190390704860615, 0.00899679677170371, 0.02958959257680803, 0.024552936027307185, 0.02371836750347528, 0.03251932155821593, 0.015458840343560425, 0.021560610001606327, 0.0055989602978731845, 0.015364951480390325, 0.0027270805308475133, 0.03955356769203659, 0.05416782099693533, 0.06850230282232647, 0.07714310045083685, 0.013771783541737786, 0.10383108330349769, 0.071520735209267, 0.04938779241074959, 0.00893691263627261, 0.06443186317600551, 0.021217559659553152, 0.05342936586408366, 0.07840690037776386, 0.04523761067239027, 0.027604706645492586, 0.09248007344262255, 0.04346308673942282, 0.11484602571374948, 0.013977898540155543, 0.06320411917723476, 0.020956917395514828, 0.03216303704727081, 0.03021844925599233, 0.0726857940636335, 0.050379592820160815, 0.04122990213574902, 0.05958499341842629, 0.008349903509952128, 0.04652317515724609, 0.02299946868011067, 0.06196618620907107, 0.03364523715009132, 0.10220984973373914, 0.057570936774174054, 0.08010439800038453, 0.019431716777504455, 0.001994111545143589, 0.004646833188035676, 0.07503313342890433, 0.03147302739953082, 0.05601796929934814, 0.08093363455226345, 0.05494057771659667, 0.10552415293791603, 0.06140936286218705, 0.056291305640291785, 0.04536113468930126, 0.034238802073823835, 0.021979489641624595, 0.04942288689856087, 0.028817873906284094, 0.026539775482829542, 0.04069973098775072, 0.09287121495412243, 0.051788957113580364, 0.06791917201612266, 0.11239863526556762, 0.021424548955814495, 0.09931919315168936, 0.02045373935552855, 0.038259859692545674, 0.02254681796917031, 0.04306061478752283, 0.016582130169075344, 0.04004212494398798, 0.0188025823914476, 0.08329018229438413, 0.0547430687583983, 0.05085784235909101, 0.02853773278935302, 0.029279273341319738, 0.04472671429656687, 0.019420303982652484, 0.046192389882860646, 0.015628084487792467, 0.0457574587856089, 0.049272124625502095, 0.030850291762861515, 0.029627309000540166, 0.10518099151311383, 0.035597830560178526, 0.004724061554072485, 0.03979632563348259, 0.015441341937759952, 0.07182120255404903, 0.03655690752390412, 0.040580642619921316, 0.027115597810235717, 0.00405500345345166, 0.015495796425027714, 0.061873489570233135, 0.08835839783592571, 0.0297143672322554, 0.05307934795235915, 0.02202277360934644, 0.01551176552780934, 0.0847532799948127, 0.01102467364210996, 0.0421318672447195, 0.012273992592048262, 0.0012167670361269568, 0.038332710823705124, 0.058516492286036094, 0.04054535277968934, 0.04409774078897411, 0.04547915819491591, 0.042224904792683746, 0.04367614728248408, 0.03115643198872286, 0.015914934619720426, 0.08748275933847313, 0.024001871746393944, 0.040277639524109905, 0.06420040886188227, 0.07396613382884572, 0.023637453296912775, 0.020749349702870654, 0.03687436286840708, 0.03611895037935146, 0.037752969956566254, 0.05827920804280908, 0.049818092506499066, 0.11379013438859295, 0.03301096997494179, 0.0108692430207626, 0.016545118546233546, 0.06672169232080061, 0.029914076778016267, 0.04504148067245561, 0.06885213687294914, 0.019324985407893697, 0.018374540339854938, 0.04904776045511808, 0.03062422496206578, 0.02872945395328345, 0.009541447939080818, 0.044379335557741505, 0.03702443183189438, 0.05836779461993326, 0.030395323635950208, 0.058789215756640326, 0.03872712353064168, 0.04735450695959791, 0.07380378447593221, 0.027799233606445695, 0.035991630396775665, 0.032361434667461345, 0.039943073605818134, 0.03007029551231573, 0.02890593379796032, 0.010725064315803109, 0.040626393390759345, 0.0411959299667468, 0.025651226488633022, 0.05050272613223042, 0.05343090187037184, 0.022273219243112593, 0.03534325188206088, 0.03333522434977274, 0.028149180655037204, 0.05091741718652268, 0.03786325597414567, 0.039799006941217574, 0.0419982461889665, 0.028574805699228763, 0.03593475602927708, 0.036318780583960396, 0.025033424458196087, 0.038586714935879556, 0.04968250260478066, 0.048241724876025995, 0.011486943544549568, 0.02866831630648625, 0.05776490257572263, 0.08971536171532447, 0.009458733425896254, 0.03500509301140424, 0.025102743924024607, 0.05498772276745689, 0.06334041771028312, 0.028350477918021144, 0.07805715059681285, 0.03948331359894045, 0.024057043483480815, 0.009572112523469954, 0.08185222759963044, 0.07184587824609011, 0.02277234850841905, 0.04669933707543439, 0.061965504390818466, 0.033434628088387756, 0.035815479969906236, 0.03811469369177376, 0.041656459891988386, 0.03427156765434531, 0.02324363239289772, 0.08202643599361181, 0.05153771091793334, 0.022407054803484393, 0.01965713048834474, 0.042597943646532875, 0.020866576477044055, 0.029002903292195934, 0.0740382916504337, 0.01822377040591692, 0.010199213903697749, 0.018172461667188236, 0.024582217822992997, 0.025313061872316946, 0.03219305620258374, 0.056622830189524166, 0.04749281264300789, 0.03057842439551267, 0.03230025488582831, 0.0349567452025029, 0.057391254681973695, 0.04104303413881891, 0.07274675167976849, 0.04330992278072142, 0.08701219749186309, 0.08232796053972938, 0.022875107712142413, 0.03706143387863713, 0.026155193599181312, 0.032682276120589625, 0.017386807857321638, 0.019311146029541572, 0.015898091219095214, 0.02608657701902332, 0.023303908190780112, 0.0533570509944712, 0.09750518121666486, 0.02280062098326462, 0.08926656442664324, 0.022978179096694917, 0.020615360924914, 0.033156488376158866, 0.08974733056440469, 0.01962730093979307, 0.0682919810435945, 0.07722628227765523, 0.03511622938657961, 0.014606556994089437, 0.012782037205573533, 0.05939180519612086, 0.03591472666049677, 0.08257935995296126, 0.043088814484015595, 0.05174317186878574, 0.08147234758061749, 0.04213058021700671, 0.03184682851086461, 0.0597297840361153, 0.02247303795640267, 0.03768709788639699, 0.018562867734280807, 0.08422009046039275, 0.02113126943098201, 0.06606934547063804, 0.04164859216900603, 0.04516099038864336, 0.06199227916377206, 0.03963544333894407, 0.02997573153416236, 0.07648122346689624, 0.024092494202176892, 0.05377175354008233, 0.05930710268477279, 0.04953405774769284, 0.03487707205837773, 0.04692907152216762, 0.039730894063869794, 0.05190773904624005, 0.024740564366502148, 0.051980651464433446, 0.0329870067446703, 0.07982534281308613, 0.026699705913122145, 0.0840386042311307, 0.01675520283770898, 0.07682727304317298, 0.04141337253273495, 0.06009424270521249, 0.04843042382309514, 0.055250471773286985, 0.05467611650425581, 0.04816479049623013, 0.06432819615809188, 0.021600456149767966, 0.04489967779767129, 0.05522934689877495, 0.06728852077597572, 0.028435477288439873, 0.0451554860469074, 0.0428016540864783, 0.05725005701664956, 0.09301298718538978, 0.12841885909438133, 0.2124641129686948, 0.1120438369651956, 0.19257366657257083, 0.06425185932687695, 0.16814879171790617, 0.21419956258708434, 0.1830570619072645, 0.0725652577896272, 0.1272157256701781, 0.2831753000857369, 0.09081184803958862, 0.12636346817617455, 0.24099232328514902, 0.1546435349530751, 0.12504934393350156, 0.09561672085715879, 0.13987469276593578, 0.08167901511995063, 0.12097364892402004, 0.08554878569538556, 0.17922942616766502, 0.18736920229369597, 0.1437826911287923, 0.22365846550993382, 0.14114760913916174, 0.09899220384296872, 0.14272771144826568, 0.11089924031928663, 0.16221231510562284, 0.13205270523265486, 0.1139954612740586, 0.12765344532747425, 0.22781179586966194, 0.1397356171641619, 0.16162123230676498, 0.13658822153604802, 0.09054228468167205, 0.11814585751703671, 0.1688684087486998, 0.23752926878871458, 0.12727607041597366, 0.13354034072929813, 0.1691903801815164, 0.16652502239711825, 0.0915801193144533, 0.10386795511529331, 0.10664960504659723, 0.08524003694014204, 0.1704494916503468, 0.17407811306897672, 0.0906616488411542, 0.09744715771727985, 0.18301180143269802, 0.1775012850280731, 0.1780349265543684, 0.12700782472928687, 0.15729861183752938, 0.17094947127324922, 0.1196881533870774, 0.2723241242910585, 0.1833616891094754, 0.14792045458189904, 0.10909766965215245, 0.24708734945424143, 0.11667474653692016, 0.12527576121952266, 0.15757150767791658, 0.1541007156934469, 0.13461667894115373, 0.14121652640883, 0.13188908417378703, 0.17571489056271894, 0.20941185013901806, 0.1479665117879068, 0.1751455186956352, 0.10509699763309573, 0.08353759038953051, 0.12046307430512483, 0.13535992212353215, 0.14698083242101057, 0.19271189947762798, 0.23602421245267316, 0.10838841779097434, 0.15575552689692668, 0.14446259416159124, 0.12504211206349636, 0.20936899518053378, 0.15170388704826757, 0.18694417671330515, 0.18081577975423108, 0.21885688687043808, 0.09963284486964827, 0.16037287671239148, 0.14340916197867165, 0.17028302074440066, 0.2532356953428638, 0.12597437978031176, 0.17875822080719858, 0.1609531117062415, 0.14600514284064695, 0.11779284420152826, 0.1681323667928096, 0.1381202441670241, 0.10092825358433109, 0.11517812482892506, 0.10828553984362273, 0.17657911435009974, 0.20702102762316504, 0.2353482930770805, 0.18894489193635602, 0.13188989622698677, 0.41943243374266936, 0.22526735740323223, 0.11170836706315318, 0.2187912791006027, 0.18915578062015195, 0.18605539214707192, 0.16450288735570448, 0.17582945135091582, 0.1285846864864711, 0.19655125636246898, 0.144252042556482, 0.1188017743369264, 0.0812945768777882, 0.19885065394543833, 0.13551225104639608, 0.1012628807896568, 0.08321577983517801, 0.11020249867391203, 0.22830344045594816, 0.1589992810641566, 0.18547855858360568, 0.21767020135396914, 0.13780830848601558, 0.1780576180786856, 0.11837654957367529, 0.17744240351021293, 0.08946819110743462, 0.2522601283365681, 0.24366863612686437, 0.11025513657518934, 0.232185545046964, 0.11267727676538691, 0.06658249414495884, 0.16472002731696253, 0.18043261321802295, 0.15413902008966093, 0.1468526046242445, 0.23208616812142635, 0.11795135545394114, 0.1544881876437895, 0.13818441169156184, 0.12207392738350939, 0.10333934678666054, 0.17531762800870404, 0.16021667138463067, 0.14988497981140692, 0.10464951035476501, 0.15768236060055996, 0.07608507940125081, 0.17028562544334322, 0.07150132254126572, 0.12036331433562503, 0.17693882327406638, 0.12461141743246587, 0.15856205936401122, 0.16966193794242798, 0.17074602896407728, 0.12358613898076358, 0.09629077097821621, 0.13718204692967478, 0.12922602465316174, 0.15261540910409344, 0.1126802262038954, 0.24132840605753086], [0.05995230959548105, 0.038483021104888576, 0.01880373535377364, 0.05419299081568757, 0.07543603439004191, 0.050219158687058, 0.061211830921350956, 0.08144063154055227, 0.04028258079122152, 0.05183389966165827, 0.01749506565712152, 0.022541639214802175, 0.048041783588668036, 0.0688657119509674, 0.024062783397253484, 0.006401170225393388, 0.033230829548331044, 0.06589273922145367, 0.022420693083756396, 0.057281723260999694, 0.11079229444505707, 0.019258849037390564, 0.05250325749417948, 0.02778523526484928, 0.03574512245494031, 0.03283052562525676, 0.015321587073436428, 0.034361992842487754, 0.03310700675712959, 0.01951459983003236, 0.0543233253542454, 0.015123637614681598, 0.015153131999766395, 0.008989998698985625, 0.06801524710270666, 0.035899906689601566, 0.023018161225463116, 0.035113563400603114, 0.03219663383319013, 0.018534294569924958, 0.037342277881238735, 0.0855503868191473, 0.023335610824306647, 0.017675843255053607, 0.013179189634449301, 0.03585611710384969, 0.011560071424971665, 0.07802070013337559, 0.04026907849155607, 0.03167666314590362, 0.0427248920764654, 0.04401339833895045, 0.040782660005554076, 0.008407482678341049, 0.06922971096731002, 0.06513549961269864, 0.0806635732371961, 0.04074890617161028, 0.06476396229118109, 0.0056096137080702095, 0.048751763233374205, 0.0524846836924553, 0.03390127522570472, 0.0180771699055068, 0.05840799125332025, 0.07442439996427105, 0.15056607794136773, 0.020064652874885548, 0.04152086232939074, 0.051597982885376106, 0.03901422647158465, 0.005568423554406412, 0.05404313252637944, 0.003988174970389434, 0.03204616841920201, 0.04380289269911666, 0.020645937409191843, 0.04074616740728098, 0.06905030849720202, 0.0156939881590886, 0.011714180544649642, 0.031069615074703773, 0.12863475799320206, 0.07407839635326978, 0.04088839163042365, 0.028300345124256228, 0.05283775063411844, 0.02756568787228917, 0.012689766703143477, 0.03073613125560505, 0.009120225985234064, 0.029203189319119822, 0.06985804862192563, 0.079305904556907, 0.01365554502098671, 0.01902066272563271, 0.01910486344939038, 0.008451476235002761, 0.030683280764928753, 0.04605278184997939, 0.048248968237350066, 0.10296294480682382, 0.06899036211712707, 0.03910419200697253, 0.07067036995243642, 0.05554443886203151, 0.0333874409026917, 0.0408251702244724, 0.024897206364379778, 0.0724332991446699, 0.030004344918134234, 0.04809391587191532, 0.032217379494179646, 0.0998619358025251, 0.05779670288545951, 0.012260302600841369, 0.030978450611714396, 0.09512598025462321, 0.06279946770519018, 0.019159131202726595, 0.03069548837600216, 0.028630335582420233, 0.020497887087385022, 0.025434647686779503, 0.017479291906760588, 0.0660559848972386, 0.040518187301894354, 0.05105803645546398, 0.013211700490735953, 0.027671540156006817, 0.07521478819750971, 0.07065985156523605, 0.035135519480512994, 0.13927228718755708, 0.022440197682308576, 0.0250568724943385, 0.0276091652772119, 0.025432828227959337, 0.031154430584020676, 0.06208917013399544, 0.07081480050880103, 0.017956738968590097, 0.038962285710318435, 0.03477109145493277, 0.16266553272162715, 0.038720826287904096, 0.023575781303788387, 0.05182339276577677, 0.03373109645420506, 0.018521209788178245, 0.06625606408042294, 0.09887667012310798, 0.021995104428741242, 0.12628188747311794, 0.04323191587783156, 0.041052843894689314, 0.024550467308971192, 0.04441204751210828, 0.05469299342122771, 0.01990776764409196, 0.025005964036550254, 0.030166309311865803, 0.01104266042896216, 0.013137362191393493, 0.04025994289305903, 0.05158444611175407, 0.03776314743464032, 0.08468876773070905, 0.04065236760183208, 0.059411803921384204, 0.053881357739409136, 0.03319025370142153, 0.019992910655996492, 0.04094859081951361, 0.03559521436991711, 0.017193753700402957, 0.04889408704794703, 0.10082923672011784, 0.061233227757076104, 0.017214168028365222, 0.030622780886328513, 0.05657193130783497, 0.0175666508279861, 0.025003370828926567, 0.04274704733923559, 0.04654224308568143, 0.030341806648779782, 0.03797935276863076, 0.03163897162002902, 0.10730579765813966, 0.050127013631525545, 0.04577972513112811, 0.08896268032971891, 0.056430549781409, 0.023403729447313858, 0.04082709693560197, 0.06472146739402125, 0.045355090255578684, 0.033133425299198396, 0.0470938838477577, 0.036234943751966765, 0.027895467656273997, 0.07195835527513297, 0.05440554191027919, 0.05388380155988759, 0.051849627446743755, 0.04618351858469748, 0.024586394917400136, 0.035961726154651374, 0.05449622756831589, 0.00945784476390409, 0.045558092064194144, 0.04527226849008472, 0.025426295413185033, 0.02524683548648271, 0.04311327567143787, 0.05281010252093116, 0.08722525420448474, 0.015916321238863374, 0.024731375141850403, 0.023622698443491134, 0.0271817073676615, 0.035449347398694486, 0.03581366434152569, 0.05113042027298963, 0.09042585463893991, 0.05768922074968296, 0.03644024382435507, 0.06859430998203254, 0.037378751327313726, 0.06168244256367607, 0.02108828232233082, 0.02774780803930856, 0.05221261905746595, 0.027812347116489566, 0.014674273420936398, 0.0240343653657023, 0.07747299323279051, 0.09911654757395869, 0.02538998476079395, 0.008018472806490477, 0.04592007243885629, 0.023532179409577966, 0.05132343995595171, 0.04720970485059004, 0.019647682709018552, 0.09143300745035372, 0.015405721722110627, 0.05286135763350514, 0.1177610285700329, 0.029444817280877503, 0.046558120257912144, 0.05607490112344104, 0.030265230415088516, 0.0371843105512521, 0.022764411837523504, 0.019296783796181122, 0.01390331126223769, 0.13892393168662825, 0.03636122951584478, 0.03728592062308904, 0.034426317415049965, 0.06784293094589826, 0.059704127751531146, 0.016644185206161875, 0.014901675129940194, 0.07666129243349837, 0.04694399874537222, 0.08989113292867139, 0.03817551341208239, 0.02008681196809536, 0.026106589150825338, 0.006029586938600387, 0.036656449158345504, 0.0408701089421107, 0.08412872681454306, 0.10738144117978313, 0.05980756494306749, 0.030308221354179328, 0.050368373462509726, 0.046582071996864774, 0.014375348785711874, 0.037856794022504366, 0.019446825946591074, 0.035213154830759576, 0.019456170304047487, 0.08189889001509837, 0.035999528763274995, 0.05115257553575982, 0.07686605241390006, 0.05989597531996908, 0.02968022460869003, 0.04379607068615095, 0.05372456252394665, 0.023084368459099246, 0.036205234862263166, 0.03522444696676347, 0.03331109641059753, 0.027373690916706, 0.10190680067265227, 0.024568328648925792, 0.08191938286707287, 0.04393077192587718, 0.05044664466573347, 0.055199752922259995, 0.04354694655405418, 0.03277034941880453, 0.0521029535711052, 0.02221726801156277, 0.027907897432845448, 0.010167021931509578, 0.034145151655520165, 0.03352227620780468, 0.054672699752113516, 0.012769389093943663, 0.013733706099071331, 0.03814484308203382, 0.06720163874448308, 0.0275144883010897, 0.049261912673471436, 0.06387512409879316, 0.0372900651587594, 0.033396829310203754, 0.0022793519348206543, 0.018956420507522363, 0.011271168177406634, 0.01448535518119893, 0.06546065797128024, 0.03906414859117039, 0.10209493654509706, 0.021116713760420684, 0.030682194835296085, 0.016787631339543772, 0.07013207827244075, 0.06650547166505168, 0.055307418919138374, 0.019202325155117342, 0.021910191243213993, 0.01049924936641248, 0.006406882847283757, 0.07125243589642548, 0.06848387840774751, 0.06542709565931751, 0.06751946564162932, 0.04725823652059321, 0.09843197906570089, 0.00793451340042896, 0.057606935245736, 0.05968679884268392, 0.07722006164371006, 0.0377459449303006, 0.04016214027820576, 0.15057841195694863, 0.17430636130513685, 0.12745659903533038, 0.14193661841413668, 0.25291075148890096, 0.10606589967445021, 0.20758149754856864, 0.12934688268409622, 0.20702266705132302, 0.09814546984289924, 0.11426660277309919, 0.16735198366786205, 0.1682298897855705, 0.11855532385168538, 0.12282156024969394, 0.06807511687398919, 0.13621073937223804, 0.16662571699388568, 0.14729658321988198, 0.0846558795761197, 0.24157550005662828, 0.11404334176932612, 0.09639051562595753, 0.11756034417738838, 0.1517223804107597, 0.11296032327077082, 0.1282407742955031, 0.08508062936485776, 0.2622818760573864, 0.08693992475708646, 0.11998742563469757, 0.11362753222666441, 0.10763908420959789, 0.28000323642646113, 0.11847965734740419, 0.1580252768772264, 0.16892978771319314, 0.17222146834096602, 0.15594968422045632, 0.21295192711535962, 0.1890048766208272, 0.15527603246511953, 0.12380359303807059, 0.16958019636090726, 0.13906829329507966, 0.09455793371964848, 0.13485088734136474, 0.11448561198889248, 0.13068868568347347, 0.18414666876196864, 0.20736245768925837, 0.12387078660990923, 0.14403819677329835, 0.16494485880098037, 0.1967314862075352, 0.15635033288309652, 0.12372092449016149, 0.16874155991019743, 0.20452872910086187, 0.15608944930136204, 0.17213393513473774, 0.16753893976490344, 0.19332415694671293, 0.14996566419159213, 0.12167048249994555, 0.13559849722491157, 0.1966478294062038, 0.1298835119532962, 0.13037252119712292, 0.21191796888747524, 0.113318944349885, 0.10752184977454525, 0.21630379161046398, 0.16738212156680324, 0.09807522724112196, 0.20813067533796836, 0.16288446532862802, 0.19121242026167531, 0.153457002654191, 0.08573931942303335, 0.1286723116232503, 0.11587151867007056, 0.16470272905163227, 0.1678842922011691, 0.3000649647606958, 0.10297391518589952, 0.19132282885332264, 0.14804319718912726, 0.1142135741669805, 0.1070181393034516, 0.15255950000737944, 0.09733599069858752, 0.22923868059390978, 0.14956389704058248, 0.08692913057823336, 0.17828744445596972, 0.12686445903513702, 0.09692224193244212, 0.1380869346640764, 0.20035092989283226, 0.19244611293317812, 0.24467599578201774, 0.24920788082864978, 0.12337222424966675, 0.22823550377882298, 0.09863792648238522, 0.1321450647928061, 0.11635606928217797, 0.13276502910640933, 0.14097522403444016, 0.1546859915458387, 0.08810630894356197, 0.1383687477679022, 0.36048592098297616, 0.14505995888142817, 0.11079889046208513, 0.12237663936590958, 0.30456085899664515, 0.16151385742329782, 0.11217620163675278, 0.1442122979149703, 0.09276788501489548, 0.13931158749807265, 0.2079664260870026, 0.20827684491392107, 0.1532522426737893, 0.12854917065030144, 0.11154258563633888, 0.09046119427488697, 0.14116473886514866, 0.12486457118704436, 0.19759684380504394, 0.09094590576545847, 0.1957303318645685, 0.07254603664360701, 0.11090738383392174, 0.16543536957713867, 0.1586362013533231, 0.19178808937149663, 0.1250655313713416, 0.09996155021531929, 0.12207283953865691, 0.1665857578477552, 0.13074027404429453, 0.22550801626376568, 0.14034366114966332, 0.10416186474744352, 0.18569747586884808, 0.13436250628963595, 0.13263295554826338, 0.1288102993801717, 0.22619983962466642, 0.10213651979762702, 0.16621942992412275, 0.12096935117076482, 0.09166836498245116, 0.1271875719389608, 0.18745385500932896, 0.10042416773015454, 0.15999890323127472, 0.0862095058865605, 0.14864368754769527, 0.10015198435153692, 0.10838256487923284, 0.17173003825929858, 0.2289500033422824, 0.1615974529375953, 0.19440843182946407, 0.16346543576688538, 0.19563671592022144, 0.12942678565459867, 0.1762219335162832, 0.20561625219641194, 0.17611710204472467, 0.11602678170968449, 0.1307510605622684], [0.05839517460234704, 0.04072262169492822, 0.01637928349326455, 0.0372398634170813, 0.05761664541017625, 0.024068716748227036, 0.0543075209603675, 0.012011839219579294, 0.023252522843259, 0.03622311535441587, 0.05036383056111875, 0.03964168695552696, 0.04171387435147359, 0.02118633008531986, 0.014392072485098916, 0.0698316109276587, 0.05293633082821485, 0.07847613174348109, 0.06597966721822178, 0.07213621790851317, 0.00949481520951996, 0.04406054338981067, 0.07984637958748687, 0.03439014657370506, 0.009934837918638462, 0.04416387715947725, 0.054326925967489524, 0.12680878742567955, 0.02092004558371921, 0.04528414285291107, 0.0387591268536785, 0.020843293149805358, 0.03716877045770807, 0.05471732437370285, 0.02931192400865257, 0.043793577069957415, 0.05073220010906939, 0.04058807367278684, 0.10996280508416315, 0.009967622651358046, 0.01225745179615314, 0.015513816728226602, 0.025122646888297413, 0.06368009343502984, 0.026590151509510416, 0.04477137722255242, 0.096460290914101, 0.028311455314378106, 0.028604127714530598, 0.039592818206837105, 0.04659527552223975, 0.015976547241030682, 0.09369968541807706, 0.002335086507129393, 0.04048868908636993, 0.02651800134880168, 0.03123715467330429, 0.00854351978388525, 0.051409303090505065, 0.11711084208781682, 0.08450627792626621, 0.051233635299027934, 0.02424476375322669, 0.06525153128971016, 0.024317036488003308, 0.030566624726258942, 0.08521502416941427, 0.01410617325980697, 0.025181162599173766, 0.019271952971335382, 0.07036185868444943, 0.041399514002184716, 0.04180290525959384, 0.013745699205525942, 0.01647726422356021, 0.02253370254390663, 0.01961512780267625, 0.027465468250034798, 0.04432516548061564, 0.056466441000661546, 0.03485498957396035, 0.016176245295472683, 0.035445463332918384, 0.03542564080787763, 0.039311614142911094, 0.04013144313507984, 0.046880038064574046, 0.0665271672750673, 0.07887391523728449, 0.0157826695395934, 0.05695388742512273, 0.04769704402274182, 0.028450235972301136, 0.06262659613463668, 0.05002299421316674, 0.10505954359447765, 0.02275636408387894, 0.05173164607596494, 0.049193244382378556, 0.027332082766318516, 0.010716527223496908, 0.020886249614939578, 0.024097174999394247, 0.09198278278833436, 0.012055479418185931, 0.04233015761260064, 0.031535465480579485, 0.07184608508982966, 0.004885245974536144, 0.08175161727253469, 0.013906255912696643, 0.19541298760281456, 0.024344832073116017, 0.022003065997494325, 0.031676381608591445, 0.008035111278595944, 0.04227580750481256, 0.015263590387128776, 0.08821114041512051, 0.11508086230605842, 0.057128421406471924, 0.040300829005577875, 0.06030888138939777, 0.05059602415008892, 0.04683421834582283, 0.04621990393066118, 0.0056919518805619695, 0.02965927018874115, 0.019129696189455928, 0.05966221508119376, 0.12787798569808084, 0.04444544894560691, 0.030547434223755717, 0.05080092202631697, 0.020423708708896753, 0.055551065522576534, 0.04743266708007263, 0.02253471952562611, 0.07886793209059585, 0.03258731186149582, 0.02146037314237366, 0.0325930345382902, 0.023734055068944732, 0.013107227165282015, 0.01573265165901713, 0.05491638849038751, 0.037640247779387626, 0.04332914775718124, 0.047583237831150337, 0.14888472945219086, 0.05840380075237444, 0.08787666642737967, 0.021945327865861116, 0.028903625958088427, 0.09919339385364326, 0.04238968264431723, 0.0182838125469824, 0.046583814846892516, 0.004134143208859548, 0.017932913634144974, 0.044962841747028214, 0.05486555089573226, 0.03838395444496024, 0.02423944135737275, 0.05923793643652912, 0.02754976090434338, 0.04010939895505867, 0.006372020101069563, 0.04795117836986338, 0.027584242521815246, 0.025354472755063927, 0.02094192505483666, 0.0949612177247482, 0.03254441476817573, 0.029692311560915365, 0.025160788490827528, 0.036583031122122085, 0.02938723619726877, 0.058559730288482485, 0.012470184836626775, 0.030671643889358932, 0.00897994858302897, 0.07294064853340387, 0.02832915960630823, 0.0523028297409896, 0.07801582015329793, 0.03903459291905165, 0.03197990755941118, 0.029105501617455197, 0.03338687782806735, 0.05740706290629122, 0.05691346479579807, 0.022823553825277957, 0.0118874006852087, 0.020795924018227288, 0.044494068715721376, 0.06586301500999159, 0.0453696612478985, 0.03711791754129433, 0.02014989547822024, 0.08423345103379219, 0.02044819862461619, 0.057356872655931986, 0.08130171681724249, 0.03658337203124839, 0.07111778828285395, 0.032212610596850995, 0.050808835714574785, 0.068013301239379, 0.017527469261098775, 0.022888753653293657, 0.03305812268668125, 0.04850320983678103, 0.04704881106473265, 0.02893263962300074, 0.05330990211317136, 0.05882411489203092, 0.061044295153190056, 0.019594587070206483, 0.03823554789226863, 0.007224779382663509, 0.03590547231837146, 0.06330174559186544, 0.05513247891118931, 0.029235451196831082, 0.007972690434525571, 0.006305265114567573, 0.0394863817810772, 0.004849256600268306, 0.05300541280678684, 0.05142943205071553, 0.040013055737701156, 0.008669392817894058, 0.01942332619951377, 0.024201617681331212, 0.06164422626757334, 0.03950774797328538, 0.05372319505700181, 0.011752839256528647, 0.0363827450951982, 0.03947702401708211, 0.027949111047951926, 0.055924958564461245, 0.10884794031059551, 0.04294158387628775, 0.049529767655316866, 0.028976463682709203, 0.022201741324557413, 0.05971915839660553, 0.03483757639544145, 0.05385937867686153, 0.018851481783654422, 0.034442209909039165, 0.012006031315503343, 0.010892916095232772, 0.026012777854057572, 0.020972367473727754, 0.02456426455248748, 0.04266810580907811, 0.03795665741387395, 0.09784338605259696, 0.013947473358242743, 0.026131322299460732, 0.02575828919127103, 0.030687352522246303, 0.02191236118725952, 0.04652287638295562, 0.04765458359953858, 0.017811745337601152, 0.03249553452816702, 0.045106437267555345, 0.08535482755471623, 0.02273402496000692, 0.10945879583877903, 0.02122153565588017, 0.0694510797339101, 0.030906989930137515, 0.03634924790070903, 0.03464781258615755, 0.0043786688981908226, 0.02263933266212623, 0.03523738236136494, 0.0075583738057063, 0.034056381217294165, 0.016521467496791196, 0.05010591557009086, 0.05522499168892542, 0.04937836952928094, 0.04132837890797565, 0.0412408878365832, 0.02143893608703248, 0.05086142765057664, 0.0008910053234543622, 0.028594511395861066, 0.09700071997940542, 0.06276754865182504, 0.08767451114592054, 0.0159557355049577, 0.02874792050269823, 0.05320411686214709, 0.05753363978358046, 0.0392262106611123, 0.019099985384532524, 0.02295255920128717, 0.004995972971476976, 0.050721482539008704, 0.15268596580191968, 0.04336976956936621, 0.04544902029597471, 0.08964521870497735, 0.044394933107879855, 0.001548217131189191, 0.019930566420718547, 0.024377116933465007, 0.053343077550732323, 0.028253429899773294, 0.05032071513274024, 0.05149321653129113, 0.015971375189931886, 0.019482064075888168, 0.06288132803033918, 0.024685113007322918, 0.02959664824659065, 0.0725187945570196, 0.04661075049831022, 0.020419213688001037, 0.05516114209087626, 0.027393942450984355, 0.015941866440698504, 0.05449526612797091, 0.051346836281159235, 0.0505335956451393, 0.02527939805370425, 0.06633671015621194, 0.008309467474088795, 0.028047386722098437, 0.022213044951880173, 0.05131318586908522, 0.0320961901302179, 0.03775536398132963, 0.02325925101045399, 0.005709650426832659, 0.04771652180821665, 0.03202054469335464, 0.049674596577402086, 0.036441749187126275, 0.05424343770550144, 0.02830747740283128, 0.01885647476170092, 0.004737012749237399, 0.052167722474663496, 0.013307210587475811, 0.13606789461787672, 0.0672007117780947, 0.23926108715034303, 0.13343713336413907, 0.21666552300655076, 0.10541293229306899, 0.14556592931189846, 0.12435988778428686, 0.1769163309326095, 0.29172775245481924, 0.10131852941647654, 0.1391015721545104, 0.15976037409517074, 0.07977285046851443, 0.1119054891469498, 0.20419925000638733, 0.11095835166352411, 0.13056110140056382, 0.15042456617999464, 0.1986819460627533, 0.14029826277927046, 0.12821661954325053, 0.1653980764169847, 0.17844303691339108, 0.1889328949994618, 0.15439359110689935, 0.175072280690074, 0.2597410688477178, 0.19432048493575668, 0.1104608771481341, 0.09425032643541213, 0.12347802099200988, 0.21302660536621848, 0.22056415977497257, 0.1755385064790326, 0.12138538287892459, 0.14087722606716618, 0.16392829076897714, 0.20122433141354593, 0.11211153615506426, 0.2795083742708929, 0.1905306173308242, 0.16521351051426705, 0.16316733563378935, 0.10043316160238559, 0.08111987818753527, 0.27110083509356747, 0.1536451232048773, 0.1183689806249834, 0.13411366561007115, 0.09866280901816585, 0.11525700890248823, 0.13252055512801295, 0.1115196259812482, 0.19020807899294362, 0.13693751166424445, 0.15840018498561076, 0.0957109879762415, 0.12071582969398269, 0.20608218687195934, 0.14923077136758836, 0.14450897312452718, 0.09030786177684223, 0.1841028485326998, 0.10641044005751611, 0.10162710197149746, 0.18510535119041321, 0.14731864655210128, 0.14074073984257637, 0.1123376010406402, 0.1447160160469432, 0.2255046914421743, 0.12496092972616035, 0.11114693952784424, 0.11116000898783246, 0.11157395693683818, 0.1396232933527039, 0.09625351612245846, 0.10417661960086516, 0.12188995136849343, 0.08159387976892533, 0.09251199632642731, 0.10413443879975427, 0.14352055116286203, 0.1469428804252417, 0.13623277206094037, 0.10008467586650964, 0.15951825966758115, 0.1390499378284139, 0.1313894416295713, 0.19678837589679227, 0.11639631188084042, 0.07508767122823386, 0.14764296221396617, 0.14116311475874918, 0.23276643887642892, 0.08368925281590031, 0.21347927139891734, 0.13290723034691426, 0.12919590207597903, 0.14419256349004086, 0.17826047816103507, 0.11696373788459648, 0.19007919236056267, 0.11658080117476564, 0.1249771554683966, 0.13340809863180886, 0.07475199448245187, 0.11312179928345066, 0.152778769693067, 0.1813839871676699, 0.2583095263088903, 0.08178092779651766, 0.1499098010601536, 0.15704158933893328, 0.11598766526027073, 0.21117444991344408, 0.10728285332480747, 0.31354425114489376, 0.17958640781862123, 0.13369161245082656, 0.09500634030348833, 0.0997931564286832, 0.14118767553760161, 0.18504262391117313, 0.2127699965551015, 0.13580736343658742, 0.0993859577142904, 0.12159256369716699, 0.21729602868999207, 0.23998795137290033, 0.16043770307254407, 0.11667457799757681, 0.1554553583264351, 0.14563404985012549, 0.12966018200160997, 0.1001127146845383, 0.19202775231772856, 0.2426083704396602, 0.09894460680023318, 0.13137692375288856, 0.14642662909482757, 0.17701541674473595, 0.12000653186752913, 0.10573777655560164, 0.12272622826839648, 0.11115271583079331, 0.23421728683094825, 0.10076452527315387, 0.15612119598494423, 0.1031337900748176, 0.20860011869620895, 0.0657370548334814, 0.11966537759308854, 0.14744293665693653, 0.1416724406543278, 0.14147426903007493, 0.23492150549446386, 0.1697990676808742, 0.07415987746489626, 0.09202911578599485, 0.18289696485284837, 0.11513211358819278, 0.14327065328196173, 0.24036483598812936, 0.09599487717834213, 0.1525155725258012, 0.08654766475721713, 0.18674942184119456, 0.08613599975022578, 0.18594643912248074, 0.1074215612043777, 0.25627173243030427, 0.1076817553069803, 0.1567001133075645, 0.10625172196136368], [0.042147223477161704, 0.07681299316426439, 0.05270165894480963, 0.02424617718544699, 0.020003275825612007, 0.04494165941592186, 0.0380144395955628, 0.014936237186644108, 0.036514588826966864, 0.04567411608032642, 0.027480451014613914, 0.05677703602780258, 0.01957243563787591, 0.02407033510896708, 0.04406078470750682, 0.08603317542902886, 0.019849330457227848, 0.06803685078217138, 0.030311873678358334, 0.04905722930186218, 0.051887357277014566, 0.038453473093649077, 0.024257070955730254, 0.021175637413116715, 0.019026793344246767, 0.015057091387138974, 0.020339601830909812, 0.005549056851680601, 0.016700835492942604, 0.023283440236663146, 0.03713701994368627, 0.06289840413017139, 0.05471263591560626, 0.007544411374481336, 0.04053792172682382, 0.03330465744159395, 0.021460978351833842, 0.03173892694194952, 0.09644928223062908, 0.08371284832396815, 0.05811217789267821, 0.02324550547787259, 0.00855246864845075, 0.031032996071923166, 0.05504997507218392, 0.033606683775301904, 0.029533919052130757, 0.06929821454949918, 0.017037942907923175, 0.05126935414849751, 0.03757332233832248, 0.047838153587954665, 0.09759812300363857, 0.019280073503332756, 0.05335046263832239, 0.033053648733203454, 0.01603355663152592, 0.062171164524531176, 0.04899093971377419, 0.04718767216188773, 0.07957981163335424, 0.04504454119371311, 0.0031222212607146154, 0.06638619943612045, 0.08004443629855111, 0.0404943389848115, 0.06009533821094421, 0.02740847130846833, 0.05913565220731882, 0.03646013146686939, 0.1133913932848842, 0.061234062792913574, 0.06714788235483632, 0.0549195371117563, 0.020560200679145997, 0.049390232400788416, 0.021902963203648408, 0.03604982243550401, 0.02727456871540316, 0.08372450052129646, 0.02724474491251092, 0.05429167826209338, 0.0432291311482268, 0.060844292578798156, 0.0844264745471939, 0.06318697029904974, 0.032540863950646697, 0.060916925374899185, 0.014343445054105213, 0.09580397572849067, 0.03673781535678333, 0.041397261703687335, 0.051301242558345686, 0.025955384461990288, 0.042952906655808615, 0.029487457734742956, 0.01426933179309051, 0.02201012549771657, 0.03710276049171244, 0.04653430641478589, 0.020127880026496226, 0.03425284446547589, 0.013199823255079889, 0.08247184717366773, 0.01679937163698337, 0.014754049986931346, 0.015002885878446602, 0.015177337505343943, 0.04573923738432988, 0.07217080677829443, 0.02661597633343791, 0.048824415181673346, 0.052518134921669006, 0.03257078734496909, 0.01743576087568316, 0.03478385064931166, 0.006637537557136028, 0.04591078745321401, 0.028876487293370792, 0.032867646415627776, 0.02339360368017468, 0.05985965126103932, 0.029104867679697853, 0.033502181721550804, 0.015163790198012948, 0.02491731617239214, 0.031078116735443476, 0.022247438469240745, 0.036531078869537, 0.06945850312589638, 0.028365715406835083, 0.005300587724759094, 0.03194560980304115, 0.05002468343703978, 0.056023592384712356, 0.009167024381308547, 0.06924398318533936, 0.03718879599604876, 0.05279638188620729, 0.02276778070917053, 0.017795098247006536, 0.009833464376448144, 0.039422084021592335, 0.004683756231961231, 0.03796650930458019, 0.017140755737801234, 0.0589584828835101, 0.029616193064758857, 0.02350345685807688, 0.05239159634877598, 0.004386626157699334, 0.04609738731937063, 0.06337520576292469, 0.009088709128029164, 0.11127940379083158, 0.032393123894449205, 0.03451356716874627, 0.028332245025423267, 0.04018053404926773, 0.0479597891981323, 0.040901024420295036, 0.07250017862045958, 0.01348395664770637, 0.014627553548874154, 0.026463061353311907, 0.02745972642104232, 0.029914685817916068, 0.045014334346858725, 0.05730017065821637, 0.026840313690744584, 0.032096335686923515, 0.042833603783360416, 0.03173297826921748, 0.015864115219653373, 0.03299544520315624, 0.07486782697660309, 0.07751174196000062, 0.03422607352296191, 0.02192288532011932, 0.04315897664656082, 0.049844078208890655, 0.021345699356207927, 0.00482783965473514, 0.03581947128799173, 0.040937291022630475, 0.03543926951205058, 0.01976121885461673, 0.026204041280453245, 0.03352456298025866, 0.02625479843587645, 0.010830394702122338, 0.0899409439655081, 0.049876847619851755, 0.05878839987300097, 0.04559426290553905, 0.02384597285380287, 0.10226460203768746, 0.016188230741048054, 0.03854868250087865, 0.08049706402685373, 0.0416729269519208, 0.032587917070956, 0.020098483317621776, 0.03351677952694797, 0.08520745522072239, 0.050401142873470826, 0.09768379461621085, 0.039897801639932784, 0.026232878745142973, 0.03964722194077988, 0.009496867367547126, 0.03961965426682465, 0.008053829679415833, 0.04461720202779097, 0.0337100213754081, 0.04059684154908023, 0.029781269690682812, 0.03632176066598585, 0.09533028824314957, 0.05708003146273475, 0.07017409819508753, 0.10641653811739338, 0.025019431862259106, 0.05381834317719745, 0.050343376013540456, 0.050601034365113706, 0.0897798509967904, 0.06335841694606409, 0.035398517464918476, 0.05224858688551092, 0.04245885272300051, 0.042018876936767376, 0.03376105049204442, 0.0574589079065669, 0.008961623759880182, 0.03737863258368546, 0.04168385136572104, 0.009592006869253614, 0.04651683577967267, 0.06736555857764137, 0.021496471205365755, 0.03562823658989322, 0.06917506591567109, 0.05755356956093062, 0.023877342239082344, 0.010692084230662835, 0.07226419289626422, 0.03905759087853855, 0.022865864861335967, 0.004196308849890146, 0.020461191475811987, 0.016509694640614813, 0.03577507266234006, 0.032838504430988145, 0.1364056168184165, 0.035349717664141814, 0.013407926251661154, 0.025571503548792777, 0.061813776846975095, 0.033464865578759107, 0.06920122781828528, 0.03109055417289417, 0.022091422748241215, 0.030416297208097194, 0.057739112225751725, 0.05378393433807839, 0.057919070109604835, 0.022447098219286532, 0.047369755939730716, 0.08672214894285125, 0.035141326426979036, 0.032516360628388585, 0.04203271248467988, 0.017424503213635856, 0.04048447177234677, 0.04230126077609678, 0.015523342073955124, 0.038043110436129, 0.05311313626025954, 0.12944405327641195, 0.05188654522381483, 0.02497085422698048, 0.06331769937288857, 0.017890072082199397, 0.057114589688999046, 0.02480910050742809, 0.07370388661060603, 0.06379490320180213, 0.029119530602568583, 0.024806269812547875, 0.02920253431394456, 0.059383179046093464, 0.05948647451136382, 0.06722950136228915, 0.07799898154072224, 0.034026745105943376, 0.041502418762613694, 0.010642119976241263, 0.005087315549908747, 0.0058289810699681125, 0.02518660565387578, 0.008372595034269317, 0.01694438250495061, 0.04971109300611481, 0.02785485733540789, 0.09955243628111579, 0.033351346670139226, 0.013976869109507292, 0.044011598032328396, 0.016125549427083424, 0.014258754034076008, 0.017627631426758824, 0.02491106106449039, 0.017147317280872695, 0.046168759900836215, 0.03900063607180792, 0.02904509558462568, 0.028647626186871243, 0.012987221407163288, 0.007447343246425472, 0.07036392712184499, 0.03321036350943389, 0.07828539883297297, 0.01433587035975389, 0.0393196159312802, 0.009424337993315872, 0.003957626735603798, 0.05109375147449394, 0.016571245974891128, 0.17054353660393148, 0.05798195060642977, 0.01887210104013643, 0.015605898581505304, 0.0244412059339905, 0.06006903841250366, 0.035420144127020915, 0.03508616426599122, 0.045067562135837735, 0.008134931577519785, 0.06990838059855085, 0.028276500637613, 0.04130935311437615, 0.01902099022822034, 0.04672296705745882, 0.06615122494798514, 0.014020956511939726, 0.04416508374795799, 0.03612106095158285, 0.058532162614527254, 0.06581763962223645, 0.04380233728537156, 0.05886863226131086, 0.18921139860345473, 0.11471325501559243, 0.15112575113533006, 0.1567760326208607, 0.1822809995182099, 0.18378856862264295, 0.11369120179405136, 0.1852730784805552, 0.09508229792118074, 0.11328807866741573, 0.10422995464215357, 0.09225251468559427, 0.11453762169807188, 0.11964124582347371, 0.0646979408338666, 0.1913380740030158, 0.1372651981129762, 0.17774097861782198, 0.14053912082266423, 0.13863807363856223, 0.19641726758451233, 0.14416322232254092, 0.06667650845502654, 0.2073971461504698, 0.10225956884002495, 0.20147982173629347, 0.13197451829910278, 0.1379746108526184, 0.11026776170418148, 0.23082747034007506, 0.1910904284206129, 0.12230759186129417, 0.08767370675360003, 0.1144031426238437, 0.09010872488180477, 0.13474345117086364, 0.06634594151569952, 0.08688029247306048, 0.17295332745678965, 0.11570297166584961, 0.1406588450434708, 0.1394905149936676, 0.1351008311875405, 0.11037652320679157, 0.21826640162016117, 0.1984290604389483, 0.10770047849584972, 0.12237534467731753, 0.2216311823576689, 0.11114923779161708, 0.23912326793276498, 0.11744035182580834, 0.4737273832001994, 0.17041785221907402, 0.0830750877878839, 0.15973300943451543, 0.10601621121168138, 0.1983806436821338, 0.15803940353855012, 0.13896713904555769, 0.16666527777429552, 0.14934781428065994, 0.22314705585520114, 0.1551794900649017, 0.12901294495790236, 0.10109217341748938, 0.14493361566095583, 0.1654329947045734, 0.14678756375947308, 0.15349178304595334, 0.2059262420140928, 0.12999716875774245, 0.10349659399399835, 0.18425094865022168, 0.08933515993938332, 0.12317914711011034, 0.15200566440340013, 0.11947523457028213, 0.3137981939700342, 0.23336368102219798, 0.14425919781769478, 0.15955146191821945, 0.18423648491021127, 0.12000630204115184, 0.1486580133918793, 0.13085590735558542, 0.13134503917348, 0.11802224923045405, 0.10991341539568479, 0.219280717353667, 0.1485282227757477, 0.11558201404348498, 0.1573897303352433, 0.230229691932759, 0.1679385618697251, 0.12378498476238982, 0.1000227606404693, 0.09506986431416967, 0.13036299106334487, 0.13946269068025774, 0.14132068372301518, 0.08954797150386919, 0.1226825612567125, 0.26173289745084705, 0.18763452918539125, 0.08625521069212307, 0.06521419216428073, 0.09872720636908086, 0.2713656870107497, 0.13870077027428535, 0.1175084263987599, 0.161176702127822, 0.12593311062383075, 0.12753118535563832, 0.1126816051621591, 0.12156118473578846, 0.130780738808455, 0.19168736413121226, 0.18158566747461596, 0.13361679630414133, 0.11931669267435228, 0.2621361967777052, 0.09636394769674349, 0.08156554983748544, 0.17634153516302187, 0.16756397551826893, 0.07592360338857097, 0.1414178543153309, 0.15372128766630927, 0.1992776407109153, 0.1135816588817585, 0.1416324048994049, 0.15109444878274395, 0.11506209315191354, 0.21585262711009673, 0.17247872066593942, 0.24296529080358245, 0.12266054388976867, 0.07806165519380763, 0.16244197294356363, 0.18259639791663618, 0.11284041518886244, 0.11475210333423269, 0.09990426982122083, 0.1549995666550052, 0.1429871547847025, 0.14644719089471525, 0.0935384392317745, 0.0715769507411507, 0.1674715087058083, 0.15032639967337733, 0.11904726721226208, 0.11769690701077062, 0.26684797459071685, 0.21243774422234107, 0.06162413178131946, 0.09693867451841794, 0.0659360921370887, 0.23491839517749127, 0.09879022476173217, 0.1220456893826204, 0.13531219484584947, 0.08038686993982523, 0.10492277391735585, 0.05624947340918645, 0.14899311557171807, 0.10246984465348144, 0.16433146752176747, 0.13211310360460513, 0.08115943130706588, 0.09243187119042681, 0.14616246665677718, 0.1334272048646404, 0.1351027464073512, 0.10434848376579824, 0.18544023886563318], [0.04861853671290221, 0.10128333533723509, 0.032410211485600283, 0.059208863399802684, 0.08502295060503869, 0.028013494992328268, 0.021279712372850028, 0.02542270629125978, 0.052861315498669306, 0.040242150501017614, 0.020915069842651006, 0.0485846373222528, 0.04886183474633483, 0.0683113094419241, 0.024441167629594286, 0.021976159074373787, 0.030937388298972964, 0.05441628629341722, 0.014472054937223514, 0.04302455885936657, 0.05698706286268369, 0.038712020107214494, 0.03824104074268572, 0.03256100057173641, 0.011929797906158193, 0.041303833450881705, 0.06957490252511156, 0.010813547471057504, 0.038542155431763786, 0.0255388452205807, 0.031585577206926486, 0.05556125832240909, 0.027917958082511064, 0.05658922957316522, 0.014558712887998312, 0.0646251165157845, 0.01173435547013557, 0.029546570994200248, 0.08193062137692206, 0.011177565639598236, 0.06532635509727464, 0.04808280376657363, 0.05543557010711201, 0.008641961124545385, 0.08427281263134173, 0.010951782291334484, 0.038728935328582605, 0.025278833063860095, 0.07485264311394385, 0.010171615586225546, 0.08438769517646683, 0.05593838425533426, 0.041757568176234924, 0.05812034438995104, 0.04606793889956129, 0.07533504867986326, 0.011982340046444969, 0.057823266984233936, 0.03669127934582291, 0.0041421833016248725, 0.033949320429875966, 0.055514588246061924, 0.04780479045885225, 0.03782381393736409, 0.04717619233434239, 0.042825276407623486, 0.011474372999322031, 0.04053034511725268, 0.03183647866300758, 0.0066528645824761165, 0.038239194470788204, 0.029220728902146224, 0.07018079380354575, 0.00604758856840612, 0.03325269752812963, 0.04479094310813854, 0.039920853225574385, 0.03591631629293965, 0.04306669369520199, 0.05150663839172452, 0.07910228604751249, 0.028446005251739296, 0.011830479394824756, 0.013807364495380992, 0.07996529941597293, 0.022051724072005, 0.031266903782623916, 0.03643668151550716, 0.013209776652436103, 0.06026499604265537, 0.01611384360360042, 0.028704199864859545, 0.06852756074119, 0.0445476220920682, 0.02456781345479671, 0.01790274509168681, 0.05388511157023811, 0.034548056447097374, 0.01663254258493262, 0.08135382611785205, 0.04965187440956793, 0.022208377561201493, 0.029801197552813158, 0.010317583106488231, 0.036149597726762295, 0.0822191147674476, 0.022311730483066172, 0.016478313764016476, 0.04782526798906827, 0.058604925645575415, 0.01202162311998226, 0.06744003764563991, 0.06977041582426718, 0.050528750139018225, 0.04253721585677516, 0.06426002965458939, 0.011775298081638833, 0.031468739222374656, 0.07150695328750918, 0.062335318014506376, 0.07319449942799346, 0.05120666134321401, 0.050130039678826455, 0.03713512770651329, 0.10794376503796348, 0.05411293079716064, 0.02222481397761693, 0.03207102031146567, 0.01541924030114446, 0.03873334799502646, 0.045629280784557906, 0.004324720507758039, 0.04325337017015104, 0.06350589653236732, 0.058026479467028574, 0.024033168353320613, 0.033283111218723564, 0.02483064098463905, 0.04287707161218409, 0.03997808765439738, 0.018377777061335022, 0.03930689887173715, 0.014642207853255734, 0.09678377920100767, 0.03912228700374404, 0.049707124670667034, 0.09716373582881305, 0.0428182628726767, 0.07311377674341202, 0.020118612277832244, 0.05221645715796659, 0.011522839551851636, 0.07004446845742003, 0.049673060571113904, 0.028755167694461924, 0.008050104576884019, 0.03341670546139921, 0.06926292853970682, 0.0256033115194089, 0.04634214091985937, 0.018810672279928, 0.08194421177669879, 0.03193806192176717, 0.055844029036140254, 0.027774349155445254, 0.03604324940111368, 0.031821147328422915, 0.01970255184137533, 0.023133673877905936, 0.06825893967142029, 0.017168620270827127, 0.050695646223762346, 0.06427770330300255, 0.07224766837973749, 0.02207537512144735, 0.06498091839133732, 0.0349977117542538, 0.04346016411399169, 0.01196628475877186, 0.03853073689125238, 0.08423941885872234, 0.021989462191178914, 0.03196548786945641, 0.033026659455631054, 0.0045234834561274665, 0.05137325099278843, 0.003802165470739466, 0.05628471728414298, 0.09698072508458169, 0.08322253673067016, 0.02493619257884641, 0.03782921102679065, 0.0502350511810472, 0.03804174296918415, 0.05619461768336835, 0.05645517950817462, 0.02020494272601941, 0.04901961055434039, 0.01594279244947698, 0.029128361681115725, 0.043532057635245786, 0.04576190975644896, 0.07789865466615847, 0.03722385600990346, 0.0659418531182793, 0.006412522212016367, 0.02352596835173186, 0.030580341530543183, 0.032941826709335854, 0.027260248616878546, 0.028674316690153176, 0.032016128196471164, 0.023850695785856055, 0.04729953249015155, 0.001661594552945556, 0.04150331125504548, 0.03267022172710107, 0.034364367715053024, 0.09222115870685348, 0.026819045174746748, 0.04128668074225707, 0.04428601455724528, 0.0324453481082474, 0.04316597869018874, 0.058886646818850315, 0.03419937152836112, 0.058390470822491956, 0.06458433765557504, 0.06801050501845537, 0.05377006814664891, 0.08127599158474515, 0.0356287153948459, 0.04874558090382526, 0.03916756663050863, 0.0010589298213862124, 0.051222454245773055, 0.04544956421840095, 0.07134652681528561, 0.02682940842914245, 0.08456055525570147, 0.04092913984711613, 0.02592534423925944, 0.07498010482278562, 0.06324535002931952, 0.029379592555004264, 0.05541960100433039, 0.1035515301590485, 0.05631193638809266, 0.03607649378658783, 0.02359966601004764, 0.03733529882024854, 0.018889351424971418, 0.0657188525844005, 0.025022511535714713, 0.038338678648635265, 0.09418330906379609, 0.07386673392067034, 0.016610052158695557, 0.04424261567633479, 0.02633966757134805, 0.04475294514709423, 0.029676108801316832, 0.02010266998812797, 0.045673641105813366, 0.045631322408876115, 0.0383710611851946, 0.014825241580124826, 0.08278077212913383, 0.014151684628168662, 0.09203455501025723, 0.04424547318429236, 0.02317274627726405, 0.05054496438993562, 0.028180186148552645, 0.04034889336194723, 0.07171025770085473, 0.04016932235249589, 0.03383532271630341, 0.01852909091769928, 0.0339400545964318, 0.08518951344153575, 0.03424524487326703, 0.037713309584726254, 0.07018588828824221, 0.04790231345161315, 0.014302097373611987, 0.002723531149733331, 0.08791698563483455, 0.007208204112811796, 0.04069508083405034, 0.055368024134828206, 0.022241192937438047, 0.01543083025382892, 0.01253944301542135, 0.04091205225596505, 0.031328167833928625, 0.04168170631953305, 0.05630924358903881, 0.04617275504936134, 0.07357447137755734, 0.0363004710825701, 0.04549096744026869, 0.0612069892456695, 0.016818537241629055, 0.015794750746159304, 0.018908427014286, 0.0067848122149195165, 0.025417232593040795, 0.02075572738484029, 0.05213033738395861, 0.09618646810732542, 0.015500117160920656, 0.06077757781191219, 0.023799197440366113, 0.051834497210239215, 0.03659558347276142, 0.026939541229137012, 0.028395002948180325, 0.016779252252871954, 0.02974943682220915, 0.04540705782992225, 0.02084965742523632, 0.02327725216145477, 0.07472169570504658, 0.05370219275655766, 0.0749173698826663, 0.0438088949980034, 0.010223153193721609, 0.015092467412262436, 0.04615890801012997, 0.031215051121468988, 0.013945185628178862, 0.07240503816114319, 0.025384671941039064, 0.09013736124841437, 0.025287633498890266, 0.014223344492605858, 0.08900829320473057, 0.029482202371582392, 0.049561813113189516, 0.04408006714056096, 0.05513415281330386, 0.023121209627377893, 0.023896933022526004, 0.016722550255156333, 0.0710244634519181, 0.017524366605005438, 0.025542794403830366, 0.09912536524596716, 0.0735169458353231, 0.004200264257604196, 0.040641508305505405, 0.15036704829863964, 0.17585848608324606, 0.10391840200510719, 0.12146573018042311, 0.21031565002856717, 0.13413617327328653, 0.08792594120266937, 0.1400390645909694, 0.11012001398710475, 0.16505774951750235, 0.12177250242882198, 0.2644878109135936, 0.21144749897141613, 0.20571516946919505, 0.12358177227959519, 0.09486020137105258, 0.13528734295358583, 0.1722429034810874, 0.10550328470285862, 0.1540235399959549, 0.07384372063942495, 0.1641679077499336, 0.06518879634959084, 0.09661969848938527, 0.16325200367118084, 0.1240011977572595, 0.1608142506090864, 0.12199072257405329, 0.17817893576237465, 0.10452632341654071, 0.14113240995474402, 0.2053985912953654, 0.11781876861688592, 0.16492870966753653, 0.06717769083597007, 0.1127393605307706, 0.10208012806552072, 0.10688395900351387, 0.23631629113468433, 0.12966773562854336, 0.0849685813450525, 0.16441990471174642, 0.19905420350691966, 0.14183708827101416, 0.17551120310541124, 0.08674422759682902, 0.11827669001274532, 0.11094002684037532, 0.17651255663123824, 0.18592033084602128, 0.16966146296791493, 0.15148276342980324, 0.2271564995809909, 0.15894645164089818, 0.09979330198538881, 0.22081275530640157, 0.23673121967623312, 0.1317290943716803, 0.12314929266370113, 0.10447153280819617, 0.10335926507269183, 0.1439103673422529, 0.18221689328070612, 0.21257769316434863, 0.23248217429124543, 0.15799961293176298, 0.13869661807773576, 0.26447365360875286, 0.13007161718222404, 0.12427215539519826, 0.18037992169059094, 0.10761217154081791, 0.17339205068926658, 0.09160524699836971, 0.1350389925702926, 0.10716245494662754, 0.20899980208806454, 0.10688351467251779, 0.11944285969460204, 0.23200686269950485, 0.19028015254485994, 0.16237284116927655, 0.15133624145340535, 0.11211509080303293, 0.21833766311887773, 0.11820159041352811, 0.1372532624631159, 0.1331222559055013, 0.13673849734327487, 0.13002396651333378, 0.11500529539320739, 0.20300795264061422, 0.1770388743569774, 0.2529188566991399, 0.13857663338703496, 0.19284852359804416, 0.16652738194792502, 0.10710120621708133, 0.14611481598788692, 0.1578407569397842, 0.1641831528996268, 0.12275555411413794, 0.14317591884924522, 0.0704592667640217, 0.17668279668977185, 0.10881924265695196, 0.13529739402715238, 0.1343844930130628, 0.10379994949025494, 0.13102101462502636, 0.06333218992597635, 0.15679406633059825, 0.20224348882273321, 0.17134754588046383, 0.1736512029122922, 0.21635856689705005, 0.09664604425310128, 0.14174909541203132, 0.20795844345083161, 0.24996099122349294, 0.18039504426621622, 0.1709785366490964, 0.14471276783414427, 0.11836116652815573, 0.2919886513583122, 0.11738394477194357, 0.12062266574151094, 0.11825147805915726, 0.17237569716188217, 0.11219628080124817, 0.16221706485075338, 0.08847255259752275, 0.07604918818199828, 0.11339917673819488, 0.1928681967359397, 0.14111014743966444, 0.16622637068071675, 0.15898667125692292, 0.20990832107922724, 0.16571762701196058, 0.20243295768816627, 0.180022127986435, 0.15572330523883143, 0.20133094020908882, 0.13815119411916504, 0.1403164343848344, 0.215481809911228, 0.1698070349952867, 0.19755830958245263, 0.19631885592975926, 0.1107508490883535, 0.09785897594185607, 0.12397417017529089, 0.12308543923521235, 0.21435055851696, 0.18442132660458166, 0.18018748040401167, 0.2624965338937698, 0.12762325380237835, 0.09107723621831787, 0.09455932799967066, 0.16667123793834643, 0.12483717588287209, 0.11971142713821704, 0.09622035983709559, 0.16836599296619817, 0.09577519380517545, 0.11016552727068625, 0.14031787463013204, 0.1584708489357464, 0.11689682010441058, 0.11095593848656263, 0.1642324276749165, 0.12295337333794563, 0.05068727288274996, 0.14659815618107397], [0.029961763836082914, 0.028762137179353067, 0.022523343119950547, 0.04899457863141452, 0.023505287808215907, 0.038058543277363625, 0.038703803814226584, 0.020476235527425043, 0.034231508916784684, 0.03593045061514263, 0.020288863827684717, 0.034729726537461245, 0.05885460902185691, 0.07222461679409589, 0.029395130733328483, 0.027433478333536657, 0.04901631637626598, 0.032788118828208215, 0.04558371004438208, 0.022932640915255875, 0.04340428566079467, 0.041914830705331224, 0.0013183429931110193, 0.016377870061044252, 0.03085989275977256, 0.0083069805611646, 0.05134659496346309, 0.024074102346334728, 0.054343274283793666, 0.07061846749556643, 0.02784598029158529, 0.022381881154292536, 0.03475088588592987, 0.04510528813566893, 0.024632969232756766, 0.05304361378113109, 0.038510619422360774, 0.0830697175115347, 0.03252313284563922, 0.02562414911094933, 0.006751882404299274, 0.04814135203618677, 0.021326625682113153, 0.039759296773662495, 0.05693795662673731, 0.028228993610208555, 0.051935015606784055, 0.06402066165220834, 0.04130611256245644, 0.07276169039429196, 0.0914386765009934, 0.029892731653226, 0.005937920688020607, 0.012389736028478272, 0.01669869427719424, 0.054936042476084926, 0.01405206446971504, 0.09700663417818085, 0.04381926782849816, 0.02029963119346048, 0.011870664536892887, 0.01807299281109966, 0.11968344194634307, 0.06433086980494761, 0.013320686074063904, 0.08583709522480927, 0.04906570989518397, 0.09127075002799112, 0.05115477803854212, 0.10356852965008828, 0.008808682924286734, 0.03237565708977561, 0.04261283639578089, 0.016685488836599455, 0.01776060513821581, 0.04711519258337156, 0.06590246087721278, 0.025288999050615296, 0.010411877038648293, 0.023584191033977176, 0.04163417439427107, 0.01896638348097763, 0.04686659705194254, 0.01591222266846847, 0.015348280449548076, 0.058853295181066766, 0.0005983070079838077, 0.01311490432389321, 0.03296312395363085, 0.02126155417382477, 0.06132917260871299, 0.040008577953783736, 0.04402640651190474, 0.04721204907963834, 0.03919303522355134, 0.04096207779742057, 0.014535923687470777, 0.07542947667741007, 0.08161755954666484, 0.03177763927998322, 0.04749986065191127, 0.013576511560278315, 0.016159778235540274, 0.027093699186920162, 0.07521157062822774, 0.049272503839024616, 0.03320389772735296, 0.04953916372370817, 0.03252141297824922, 0.015704227881806514, 0.05868829899437486, 0.02095626622077919, 0.10827965628836425, 0.03093781347777094, 0.046325593420694915, 0.05831041463440465, 0.044731578954886046, 0.024890639075648882, 0.018814236503995715, 0.030907290619647795, 0.006705603990403395, 0.060660826012251846, 0.0647726267456047, 0.07459989538596523, 0.01903942804933796, 0.034356591922621575, 0.03140794248470376, 0.01594647924761258, 0.06438925336565703, 0.05453085474249336, 0.03883989933397501, 0.036447479524799896, 0.07442325849326388, 0.005718306741572076, 0.04665568921594851, 0.04573024351209883, 0.014299220713456313, 0.02772509161713383, 0.07277028590080238, 0.05978104680956853, 0.039174672096006335, 0.023322326859699625, 0.013945465250271223, 0.012550219957296167, 0.05548314416720983, 0.05680082305785149, 0.022411603450534806, 0.020530296437021707, 0.051286322996020324, 0.07670961725976198, 0.04812940106456799, 0.03732401434512388, 0.059464641005521825, 0.03737474468746974, 0.01050282316657925, 0.032103000651864756, 0.03513059353515987, 0.039317310006628116, 0.08005501597278541, 0.011779922379871771, 0.06862595707418458, 0.05523647534691038, 0.04227052915901427, 0.09510206298962717, 0.026509771649275097, 0.08617182968244438, 0.017798806112560055, 0.07793181861240057, 0.0549990187339004, 0.0815437086707642, 0.0639040554092536, 0.04258625314480836, 0.0349378994395656, 0.02964269204605972, 0.010289166990156856, 0.07470664207733448, 0.037168234196161075, 0.04597105175977753, 0.042346004141314376, 0.0468968881684686, 0.08887002199527719, 0.06884609243922657, 0.01768585793944376, 0.04523410965057631, 0.015832745834373902, 0.0424839421025207, 0.05920825435990288, 0.023499461709551757, 0.06360852550114356, 0.005856357700747228, 0.02010638551456073, 0.046026723369234995, 0.012145220872855956, 0.07308864139861639, 0.021608166824725848, 0.015194836868754318, 0.05724382872182516, 0.016180039345917684, 0.07243180527321755, 0.01600848448898403, 0.028646021232669874, 0.01993983225416272, 0.052758154098785696, 0.05374273795995021, 0.031493185088038445, 0.07777954331569134, 0.08334987586544407, 0.037906260319775155, 0.008628241447431427, 0.037688384914109786, 0.0769766448666492, 0.048182100252879244, 0.0199020296455391, 0.11723160052732115, 0.03660036003096931, 0.04174748262871177, 0.017701509115736813, 0.004753057982006501, 0.06116085926130895, 0.03184237945524435, 0.054920601973971056, 0.0572373399571065, 0.11314061440287099, 0.05311283365552945, 0.04897829160214432, 0.012934485829675631, 0.04521601465380481, 0.02118758455429587, 0.04655658425162396, 0.048215781308470235, 0.051843096547189264, 0.0363254034140658, 0.0359893627765198, 0.10217819498070788, 0.03762942295701754, 0.047610345852351, 0.02978139801041013, 0.051196165938651374, 0.12265443050813292, 0.04983395435697129, 0.055196064208904584, 0.01721796016359041, 0.027716835104529897, 0.06688691450343018, 0.09322232071069941, 0.03139486536383629, 0.012283844482754509, 0.05668298341333867, 0.009381237886695853, 0.012745916159943709, 0.04144684291414676, 0.027170277335831237, 0.06963153174447437, 0.06864231305136796, 0.08643881132405612, 0.04882257274021545, 0.034589746951936715, 0.02470508683472872, 0.06867365370835028, 0.07206092678731488, 0.030602749602328387, 0.08251224298991504, 0.01753723113647392, 0.04132279412700765, 0.013196802953438414, 0.025705287398229686, 0.058712492051023635, 0.01866456207578942, 0.009386144679850869, 0.03185938660716338, 0.08840011898428203, 0.05915135700976657, 0.006482131833646206, 0.03285658410600117, 0.02930457722545872, 0.029638501545113903, 0.04134566568198704, 0.04197598750432653, 0.045512513663139076, 0.03349720215004298, 0.0463943153379425, 0.03548261859724599, 0.03479367572694056, 0.06354499382958298, 0.01471095945641038, 0.03901423030202428, 0.06451061701462155, 0.09030776984629132, 0.05488187239895906, 0.030175278286239317, 0.09290034927788282, 0.06765093399031509, 0.0320092085072951, 0.02726899925619364, 0.02673189884292022, 0.05296746464145761, 0.026172932365068027, 0.009540058447108155, 0.027310883198233864, 0.013834852687714082, 0.03797054275750153, 0.04642266059114088, 0.04610761459315977, 0.028879111144511454, 0.06761348761257625, 0.07632681078487828, 0.029342456442874768, 0.02987609796917006, 0.02260677009490469, 0.014033869881513379, 0.06553699097205555, 0.004267414736997096, 0.016411466846963572, 0.03143030650643332, 0.03985964280042437, 0.015435318571455298, 0.015675569490169086, 0.005502975705425225, 0.06919601842040016, 0.016869233110018315, 0.06546042048402372, 0.029457187685634822, 0.056123149340912226, 0.07780200501363124, 0.06254583897609865, 0.015050476217912811, 0.004697386372549039, 0.067361950303518, 0.033712220047750784, 0.022161822398042968, 0.01698415970519906, 0.13060217903506371, 0.03728977404534817, 0.09465443781547009, 0.08309746521615213, 0.056029188656999226, 0.054954076185822494, 0.05133081355222291, 0.022274052363730246, 0.05108886000309741, 0.014852815957349396, 0.06823356683936811, 0.03333863344103579, 0.07978324628164692, 0.04399124690661988, 0.051722552612303734, 0.03746900797611283, 0.06543837247356292, 0.006975387598598197, 0.038745578588737596, 0.025151434557272062, 0.06442958023399115, 0.13760307353110085, 0.21969932311725235, 0.06420775947551574, 0.11281356380711641, 0.17820012575436026, 0.16683344939543357, 0.10141308764897047, 0.15308433152254552, 0.10598039660122126, 0.1469949284388173, 0.162370236470334, 0.1367796669083257, 0.12021291595433028, 0.07747818730891713, 0.08471499858123642, 0.07915335346854503, 0.10571496245721657, 0.16101242223333928, 0.27689963038409915, 0.0895472207377034, 0.16572147277334046, 0.22569593763159168, 0.1464539631119659, 0.13907914110008748, 0.13423878308986464, 0.062036612671950174, 0.12303700715663934, 0.24600229316180755, 0.2050095258821403, 0.15797624725007242, 0.2251632460543225, 0.16736998673408263, 0.11534570656236141, 0.13328028452252189, 0.13287831818865192, 0.18603768019426256, 0.12255593458370817, 0.18064780731595334, 0.11114045076312558, 0.08902564509621552, 0.11212404637086777, 0.14478238990470288, 0.1993089583852599, 0.08923074215530388, 0.19821973457451791, 0.10119950233568108, 0.2721613459289074, 0.11170988391724326, 0.10073563609752925, 0.20085115466387043, 0.13986761411351545, 0.09911719874869432, 0.12345744387036371, 0.16767170280218127, 0.19571251265944975, 0.09366716498569136, 0.12142647583518298, 0.18814485099527145, 0.12913162729913188, 0.14815676206302258, 0.17953964581172313, 0.14116158258290062, 0.400058284642235, 0.12360889945299396, 0.18765921253831158, 0.11144544568754013, 0.17030709122698154, 0.23157774620959837, 0.11530724894856254, 0.24587126148323862, 0.08833390600498646, 0.17037665201050622, 0.1315465049758073, 0.13019128011599665, 0.14320283917890442, 0.1010216243805424, 0.1347162397277932, 0.1816629197809004, 0.2965003576490187, 0.1886297693295825, 0.11724620982403718, 0.08606811669925529, 0.14995461720372402, 0.1991003526434783, 0.1413443098746, 0.14717623080697753, 0.0966810927756371, 0.14322674112214198, 0.06612474894932201, 0.18247216909883485, 0.10328212767959603, 0.1688100328488696, 0.11471779025610417, 0.12181757904228666, 0.19746853939948544, 0.11165766736432431, 0.09891594745098584, 0.12994237814939794, 0.13898892658612422, 0.11672374552055714, 0.21080544068207666, 0.11792101071126039, 0.1127918528753423, 0.1358053409644673, 0.15033392265679377, 0.076810488056752, 0.13624895183790114, 0.14999371833137928, 0.16760899084469966, 0.1363407904582639, 0.15632240131737726, 0.15452163504256358, 0.1784611319101626, 0.15237072062107826, 0.21388850024630948, 0.1436965675243447, 0.09949458132107412, 0.15978707992021116, 0.11639225161484174, 0.20701944948204104, 0.051529831703632116, 0.10053232402330446, 0.11615585220316726, 0.12447647104460387, 0.12813411187380552, 0.14710902957425964, 0.21616923592744336, 0.0877511046165901, 0.20576724812628763, 0.2548197353438985, 0.19556565360436517, 0.11690312500802741, 0.15582786091873724, 0.11166830832559256, 0.19936871324335376, 0.1043661957186076, 0.08751896465377462, 0.2283714537418658, 0.18342136735877684, 0.1422606123190734, 0.15176575630903244, 0.10650163516402246, 0.10290872876442249, 0.11523882963604505, 0.09741231603848358, 0.13197992687984822, 0.17008063563656423, 0.17615883851483946, 0.16457738174546152, 0.15707272315217605, 0.10225237527441594, 0.09352540041530326, 0.14890464773822218, 0.11678060456629723, 0.10932423249487916, 0.25967852542957953, 0.18322075957492476, 0.14313202201118394, 0.1904965417399522, 0.23903596455291395, 0.17390008955713243, 0.08196078991938023, 0.15791247809125533, 0.17997774085210216, 0.13013457428784142, 0.18144767971769457, 0.12042089350401394, 0.12323378450087003, 0.10142451001992149, 0.16679972620500674, 0.18523213874188163, 0.1463719917040679, 0.17949797062864228, 0.10291490343309219, 0.10512269988295533, 0.18402479949497408], [0.006449614752895169, 0.03282625085463928, 0.04709030621715131, 0.04689807560475123, 0.05389160416539639, 0.052751600216593475, 0.04076017915541607, 0.024606330440409725, 0.033463551737968965, 0.03338934463118354, 0.00958590497893672, 0.09074733577548497, 0.005549262259005299, 0.05470035169574042, 0.041341586263790246, 0.05922097908032518, 0.045998588790215796, 0.020011921127837513, 0.04072852823282442, 0.011088919690659931, 0.08778602290417879, 0.04148448847474591, 0.021309643428051667, 0.0756501559648783, 0.04101719782357255, 0.05944668390457669, 0.02196633399674489, 0.001768320296598118, 0.09712916994166952, 0.07694603965407418, 0.09373487183643926, 0.034862692588038986, 0.029054449518181147, 0.030061809173334512, 0.034063000216959946, 0.054685504911767865, 0.030458857222730597, 0.04212593772418557, 0.02344247051364472, 0.031820593829897624, 0.025532065342450817, 0.01659110871954791, 0.013613243561027753, 0.018920847214758396, 0.06802665415189921, 0.057443946209405704, 0.03157987942798965, 0.05716111037820097, 0.09416488464921714, 0.05329559925162504, 0.03855087351234209, 0.04702364124598042, 0.020015441301849582, 0.07099840880161332, 0.01474626366079094, 0.03132254283334459, 0.004038100681012316, 0.04888752550487557, 0.025131062364145636, 0.04156528776811977, 0.07374197650220125, 0.07757057751258535, 0.031205141774168423, 0.010862758086483565, 0.043137089514564124, 0.07418824570073236, 0.04976840404373023, 0.05548287220599671, 0.048655094428648876, 0.01874424096557402, 0.011457981590572144, 0.0379125154276769, 0.013200269501295783, 0.025019079461813937, 0.05274574730485197, 0.007952895201367117, 0.01885611853081613, 0.043339819361966465, 0.018291002282151775, 0.05062403998547985, 0.02162985285864242, 0.04755040330271568, 0.02353908186177573, 0.05613628391837401, 0.012387665675862903, 0.01841674603882336, 0.053273286940830375, 0.04431253269074425, 0.14136540793603466, 0.027301128983737964, 0.026422121614638357, 0.041716046210738926, 0.007897283921333691, 0.08479939082697516, 0.029174828744162957, 0.0325549676293327, 0.05055330708743103, 0.007906102072147113, 0.03666209905678707, 0.0354000611320859, 0.04451608608266519, 0.0411789266452674, 0.04455894104114944, 0.04680426813842309, 0.03428863226285866, 0.04519434968730615, 0.030445935234667796, 0.011102531157854584, 0.0382624605610486, 0.07104428214651924, 0.027422892913642912, 0.014894074580121427, 0.04083286940811142, 0.05819426421376486, 0.03015223436147696, 0.04568442379334762, 0.017884207679139032, 0.0534143045754923, 0.007673463673375908, 0.03752799291584281, 0.032958581052239866, 0.023547039600089196, 0.041787533705393155, 0.09709837320711344, 0.046046932768677516, 0.04347070548382979, 0.039052515546040195, 0.035253876234374704, 0.06717390636162412, 0.030343808053481965, 0.009782944708281468, 0.025789685389627854, 0.07562550325547496, 0.05445263333498471, 0.05073663192771135, 0.029202463450811567, 0.033288366581884124, 0.04266743165170474, 0.1044915123812614, 0.04132145347314016, 0.06565233316993521, 0.04840133929504983, 0.08599696245284812, 0.06764846718719891, 0.0034436475740925922, 0.004814472378066351, 0.04458273956251722, 0.05833838450452013, 0.09358098775508905, 0.05433370967605903, 0.06756019853656331, 0.04534947483109371, 0.047596341765095154, 0.0428865059849716, 0.01618201776798214, 0.033106424530307134, 0.018425201734287605, 0.027805678321108706, 0.06908334986937624, 0.06194826741252215, 0.049787192350073214, 0.029325242447216186, 0.04220262312540605, 0.010316957787220037, 0.025080010264871583, 0.14333845206326054, 0.024293755075984427, 0.025352908020478584, 0.02695535136867435, 0.05226041528306181, 0.025371382230772607, 0.047906615035307985, 0.05584826933280115, 0.02921337254285332, 0.02268739510327578, 0.02959822255727505, 0.06374503853881071, 0.03589900270585091, 0.041377446839525815, 0.035323586405044606, 0.04259183409533674, 0.032465863942859635, 0.05849268227334946, 0.02905784903334514, 0.012959498600403388, 0.07080040571670379, 0.04926429520691595, 0.06845895756757067, 0.0513533978242307, 0.01041399718697874, 0.03134302610922004, 0.02627386636431179, 0.04436285317605061, 0.005023504735060758, 0.03591263141002386, 0.01639247361210085, 0.06561605890672054, 0.015878202618970987, 0.09448956037240644, 0.04034117502611011, 0.0014438748785910469, 0.06553498382169394, 0.033151386230583155, 0.046359852872668736, 0.09020497616861137, 0.0458573451596162, 0.06804004536881562, 0.02976276866731144, 0.023846658502495097, 0.024513568684098222, 0.04742051309515392, 0.07945367525662146, 0.04724797477284747, 0.07414723701414562, 0.021370627857264013, 0.028660513700977452, 0.0639018873804279, 0.01090303994715214, 0.04956217700495355, 0.019687934883780057, 0.033976160320303136, 0.03159457682481697, 0.020358811485611146, 0.05419718897751263, 0.007045004881107279, 0.10443965588966686, 0.028789534398745147, 0.04376406736311413, 0.037522289391246536, 0.016984826201693188, 0.043295324975324255, 0.05992706699837601, 0.06448679168017642, 0.012778889541814645, 0.003987677492043605, 0.05397782353083453, 0.08866475639684547, 0.010404584839219048, 0.02556111156609991, 0.06916005825323444, 0.10253366743845325, 0.04411101709270189, 0.03185039273493233, 0.016042238322927827, 0.04700298751554182, 0.019124038630135117, 0.02739734579658797, 0.06401278626834674, 0.011093441524632998, 0.06786864085663712, 0.014506686899450519, 0.008228686375303135, 0.016212467847752477, 0.02385780699701319, 0.02073166264791883, 0.037112409369118755, 0.020568307804604693, 0.02589071131942253, 0.02792772570354564, 0.04435168744455423, 0.053097140344400565, 0.0649439393272323, 0.03536894264060163, 0.03102544052976995, 0.10974541997476932, 0.057552738355532776, 0.06719415406546286, 0.05727827203490081, 0.021533281730127432, 0.042573164532622026, 0.07563894043766684, 0.05995912394756752, 0.01767988819929381, 0.04335818631995109, 0.02891469592859428, 0.042765100201171254, 0.06521301238887733, 0.023721441431271455, 0.03441248186713746, 0.048341588267395576, 0.020960054525564757, 0.0493383988918316, 0.007497028357559636, 0.027061366446075902, 0.04090829076425683, 0.03561629327915369, 0.055300612227931145, 0.06885160827228139, 0.059397091202798395, 0.031665907271446726, 0.026341950513362408, 0.10033209928341451, 0.015102921639599148, 0.019730485322314407, 0.01488803493444838, 0.020683355058633515, 0.0822750085424031, 0.035375178596305276, 0.023057905866974787, 0.04828737988587349, 0.020756097022263754, 0.0446739768038594, 0.01629748062470988, 0.01688484023625572, 0.065430834168388, 0.03039677345734691, 0.05256914488610722, 0.020474933177953767, 0.037302521748408195, 0.015246711554937066, 0.04874593713471005, 0.02264954269893708, 0.07125857226069897, 0.08925982285290958, 0.011664541877595889, 0.03680625765193855, 0.027395150954684904, 0.031227655183043213, 0.07126532915619112, 0.03985777737632875, 0.04757944952636477, 0.03465042111553973, 0.03448937794253711, 0.022399056845554904, 0.01900938016572787, 0.0246761612699277, 0.01541812851604435, 0.02931397903950945, 0.06022326723341981, 0.037605103495861256, 0.016322843880662997, 0.015823236768013768, 0.08115799106176823, 0.04899907939796967, 0.03830754866583213, 0.05912965756931132, 0.01860977721310431, 0.05895478267883582, 0.032956907150125316, 0.05612347492828004, 0.045695991721004255, 0.07155353143330544, 0.025585408044618466, 0.03246939943863019, 0.0009973989560216245, 0.03743543417283124, 0.03677100994654241, 0.01788499674970104, 0.09359325282275678, 0.042488458190834334, 0.0849564848167281, 0.034531336578149954, 0.233924227556394, 0.11851924111045177, 0.11085213357282263, 0.3016635757540503, 0.10068047010610182, 0.15159953055122208, 0.15036373879880677, 0.08970497356307122, 0.14887659359843503, 0.1173060106474065, 0.11808385802132469, 0.1966353574947965, 0.1396405456527587, 0.10500436994217097, 0.11480680967290556, 0.1415361536125983, 0.1531106389818653, 0.09030239190906288, 0.11089503449658233, 0.072034994711078, 0.19805591433278977, 0.14857328406745388, 0.22765601955113873, 0.19764198170554256, 0.20549084360320724, 0.22946452331398765, 0.16911479794690687, 0.15167410154977154, 0.1702414374918707, 0.14231236921923776, 0.16986671324458816, 0.1472599488953429, 0.1301128480343088, 0.09975636122568, 0.12250336563034404, 0.26907471639494746, 0.1039005981217469, 0.15426042970390091, 0.06250679913547731, 0.11142483026149774, 0.1939026605818541, 0.14807736471055016, 0.11815585496444857, 0.06432937593349526, 0.17398933880031112, 0.23128324668974648, 0.06725012444921079, 0.21329157985746863, 0.18721374773210098, 0.15652985792727242, 0.11219350756296229, 0.1090238494197688, 0.111380098387599, 0.2167949152569617, 0.17406213247487623, 0.11367004244558274, 0.11834609757868514, 0.10608590223015317, 0.13627234816310868, 0.09920846280311385, 0.3161286334356954, 0.114354373466584, 0.1252376483452897, 0.14167458570051578, 0.2334979455918074, 0.17318778100513643, 0.1537184991062649, 0.2110942558295304, 0.17381929792463782, 0.06645688636889381, 0.11996813554076419, 0.1421122670534157, 0.11997190469335164, 0.14836988772355741, 0.1517196071724738, 0.08734130120325474, 0.12152347022727614, 0.10568455642750187, 0.17867787350570002, 0.15440728875898546, 0.07798138450110152, 0.16680953213043753, 0.09081612281020611, 0.10181532211361394, 0.13286049898353317, 0.17613496721511887, 0.10075988278033272, 0.09822868231323459, 0.23997491255642908, 0.19633650659553467, 0.10057977550933439, 0.18386735310477598, 0.09502545419719913, 0.2098550166814558, 0.12305666497277638, 0.15765087438687203, 0.18655737892033594, 0.1282608534599985, 0.11287832888023508, 0.11222605863886495, 0.1900088042020798, 0.19061022918791543, 0.13873251695786754, 0.1864474453032017, 0.15746154341726534, 0.15730058834437402, 0.07289400143969445, 0.0718614834571077, 0.1337640843684635, 0.1403518736122116, 0.21412051763505707, 0.14891787041579524, 0.13184592278013307, 0.15075275824675638, 0.14387318143440833, 0.20149992388342658, 0.15140267659819898, 0.12904522790303155, 0.06855824256255742, 0.20002964793914751, 0.18717524415302664, 0.11142691402065177, 0.1524368952959776, 0.13341865532340544, 0.09349320940072499, 0.21361077805199932, 0.11821647550189689, 0.05986806290644792, 0.13260136208226606, 0.08122335368346784, 0.12491442818915653, 0.12121720359690728, 0.1413387633980282, 0.18040529452264312, 0.17326966048248355, 0.06814702188656216, 0.20576559337637118, 0.20909150281260092, 0.2213346450439384, 0.23275013652540025, 0.2763694056099461, 0.1314697429657944, 0.2149317894251116, 0.17308681061671627, 0.20189006181974567, 0.11598929702754944, 0.11915484127858955, 0.15165781452050134, 0.18334615284637099, 0.1052732821253519, 0.1673625710029756, 0.08425096380374125, 0.1851974656024287, 0.12889305219775246, 0.0835566506570866, 0.16093651824180158, 0.17979892060881664, 0.18565313469979072, 0.17919360389632566, 0.14381886580057684, 0.15654989878737158, 0.14880352413221715, 0.12479242102633561, 0.17306019672222678, 0.17723407356008408, 0.2795676388327153, 0.11402598221696193, 0.0892009260132909, 0.15479909676697948, 0.11008386229795795, 0.11845529575141207, 0.15708039935317733, 0.18176583603264826, 0.09342531868887526, 0.15030389201016198, 0.15489874948416987], [0.037616276888236884, 0.07603926734337885, 0.018959571044110966, 0.03763377050598783, 0.06836991516813155, 0.043547421528567234, 0.03627963349102967, 0.08823530282825233, 0.07337414704623722, 0.01639936457297975, 0.029558723063899145, 0.00281008567863835, 0.0582279529302351, 0.07635911671264518, 0.02613120355583247, 0.027241973589444836, 0.03926421245259624, 0.010223352376581922, 0.0619946119015015, 0.06474299446469353, 0.0330669901544048, 0.013492060900335352, 0.016058594300111216, 0.04907609038655797, 0.0315357010526162, 0.02067405475123275, 0.03256657769182517, 0.053205763951184294, 0.01172305184281281, 0.02595637271541261, 0.01622037579035086, 0.13540646962581143, 0.04494149087657852, 0.02146286101290776, 0.06909444282251982, 0.02205081625781473, 0.025182928431839235, 0.032395671136797435, 0.03381332833199732, 0.035109909161204295, 0.0009667554390504055, 0.06892121502108152, 0.01365234851912265, 0.04187470685029703, 0.03231891295722416, 0.054345683630315535, 0.07216066377417696, 0.04108626831082567, 0.03795039081465333, 0.02507721021350834, 0.027888220464510304, 0.060111659714171005, 0.09582757889743775, 0.035751071127672354, 0.030316828352008617, 0.026721579638580163, 0.01510515574350833, 0.049805827438831336, 0.030762166753711722, 0.0825367194990958, 0.05038143526161871, 0.016334963391625112, 0.07705333792874891, 0.02893481914314532, 0.026610675005001888, 0.11177353050199249, 0.01552723763105009, 0.058642927437059345, 0.09073161565127874, 0.10139670102827011, 0.07180567395182387, 0.07584517130688315, 0.061943965828827316, 0.0876376546558834, 0.07644248240056538, 0.052121136667988, 0.07532256144669748, 0.08265183953147742, 0.13229209238723402, 0.0396668414525207, 0.03594786379366152, 0.03052195988505358, 0.03254731824140876, 0.024952632825701468, 0.024647134198476712, 0.11485543327345965, 0.06494081368850124, 0.0031231800676323478, 0.08016886429921274, 0.028861745846487825, 0.029089927049954573, 0.11750504795101382, 0.04179480004935496, 0.045223867055028684, 0.05380436590301895, 0.024113555874435172, 0.0013413159350391419, 0.0624715207865642, 0.12592387160346394, 0.034113217280396534, 0.051566515823886286, 0.04289194903967362, 0.016456162331685904, 0.022601779032078002, 0.058582536725988316, 0.016634566972272533, 0.058937476752626325, 0.014614377794186435, 0.05821250093680236, 0.07432372835014137, 0.012376435784502857, 0.025918581598107854, 0.06450910016053146, 0.06810398306697607, 0.08351923492286475, 0.05861290445130679, 0.024598522089241494, 0.009122723431867218, 0.021558139368050525, 0.03160073042606875, 0.0591245707454941, 0.05316120444706852, 0.038271285893936316, 0.04035736246395015, 0.04027356010591311, 0.07046422335289179, 0.011694305351064091, 0.02560496818454516, 0.029163220596890298, 0.06513421258498585, 0.06658068617745753, 0.057134619057779355, 0.0824265254120673, 0.03976007818334526, 0.07218516326599544, 0.07284083493774937, 0.06683710346659345, 0.05818126370168983, 0.06825140136624537, 0.046304395767830075, 0.015834070208873, 0.08449836423800838, 0.06366819992000539, 0.013188915120648041, 0.05335428541706455, 0.020388692745097706, 0.04432829878022594, 0.05710472247653431, 0.009709168525953448, 0.01882167713296029, 0.0030884880153837827, 0.03516047862508605, 0.020097554436013586, 0.14204292077450983, 0.030290185729221954, 0.05582119961599669, 0.10052752065201921, 0.04450786595923766, 0.03390843431735712, 0.01088934516789572, 0.029045068771548332, 0.039916241376270215, 0.020059454968319308, 0.0811345564321645, 0.016531788616351063, 0.09371914405135379, 0.11016626271509355, 0.07684119286075716, 0.014660638013494112, 0.030418199021369222, 0.04387374051035412, 0.03553987983914633, 0.06207141987678986, 0.03778822149240202, 0.005271198197958931, 0.06231498604099597, 0.0020786658663588067, 0.02755593174257346, 0.02868843377537785, 0.043612313006193414, 0.0489261708102159, 0.06695759377532429, 0.03991193979257538, 0.06997814822581506, 0.0513046095147729, 0.013408461555598244, 0.08058532501661009, 0.04049142785069924, 0.01089891839411951, 0.07573906046849105, 0.01528191808310728, 0.03319718679713626, 0.069550747772859, 0.02012777660462645, 0.13013121882273307, 0.05851085770935301, 0.09839067926570293, 0.016518374416796912, 0.04084680837789371, 0.03131704232204826, 0.019881640215434378, 0.0838348248432721, 0.018336841153101097, 0.031686097518691135, 0.023540163960968776, 0.036105398283970934, 0.03352824403273483, 0.07994571820862832, 0.14561463718212422, 0.02502488257784036, 0.06515370186177954, 0.03902936053852882, 0.04031130525794241, 0.04266918982349096, 0.0314814179775215, 0.030823794696780465, 0.09064180716391533, 0.039130690988273396, 0.025324966878660267, 0.025480293120527943, 0.061435279616665464, 0.020428416319191456, 0.032556109100339875, 0.013459637186550086, 0.013780291905746827, 0.029717906558465575, 0.08529029230797484, 0.06832745857536793, 0.010130138628395095, 0.023913850159113927, 0.03862938603326198, 0.059392881549654476, 0.022202461447206237, 0.05590203338332715, 0.02711800907197739, 0.029140793372906988, 0.005179652127422272, 0.05237058255701296, 0.02116087681403564, 0.01175060994066899, 0.02533224662916074, 0.06724015764531589, 0.03311639133420202, 0.09688671843539323, 0.017566987906672785, 0.041137155701196006, 0.05873018102119527, 0.056286521421204654, 0.05374105256651679, 0.02974591090253765, 0.05633048720717911, 0.0870765948427781, 0.06673074748006559, 0.052067981657361796, 0.11004162020981313, 0.026902315101676413, 0.0471976887614977, 0.03218179854053644, 0.01589476352467412, 0.009135876203917209, 0.05210110729920769, 0.09902220384608354, 0.015593918881589367, 0.04154371090173241, 0.07284469602088775, 0.027306437973053228, 0.05765330271735307, 0.021822709747920596, 0.055812018052224195, 0.04043312855966149, 0.06185094360262156, 0.017887088169734326, 0.026254499661585978, 0.016639789776696313, 0.08987261658354152, 0.03489052839276772, 0.06793007344728516, 0.0839330296542856, 0.007941936792415238, 0.036738673375258525, 0.01875074505205116, 0.05747622915453488, 0.03584830300702203, 0.03172762139940695, 0.03621948409765478, 0.05219519821806781, 0.04554552439179632, 0.008245654265216042, 0.06785305862825725, 0.04900398619112469, 0.043075909732931086, 0.08913066808975513, 0.035087619833047354, 0.00810032642837013, 0.008980683069826375, 0.0961563072257465, 0.06952003530797458, 0.07652858302237527, 0.054276253081737995, 0.016984008402834018, 0.033184465907153585, 0.07177212696161962, 0.014455590750120822, 0.009795023042017655, 0.030128545007638396, 0.05781839849547513, 0.0671878261792083, 0.058046244535475015, 0.12451787043603198, 0.04141054183785473, 0.08643230723757898, 0.015046883265547937, 0.010706208019156851, 0.03055355909671034, 0.08926353071846309, 0.00965505111737237, 0.029813430061744108, 0.03741929270026665, 0.06505924322071575, 0.05012447405005655, 0.029807829959017616, 0.021196616730923136, 0.05040082111654263, 0.023166776537114096, 0.019023215713640376, 0.053708861551938526, 0.05116655664037793, 0.03822244012788419, 0.030903138423098192, 0.04098339419391367, 0.001075268441890066, 0.04567937910436623, 0.06457865328317688, 0.04596167867402396, 0.04629935107884869, 0.07825584316085424, 0.02272763770193823, 0.05780090487772419, 0.04127170372333738, 0.032780097887641, 0.06855466493195103, 0.03694634065933285, 0.03144561677360006, 0.026025274663322398, 0.03978628222079527, 0.02225750486456579, 0.028254619251275738, 0.06871005820651209, 0.0743637717659435, 0.0669537480139444, 0.06046384948516085, 0.04231209708978573, 0.1661180152047065, 0.26024506277134346, 0.09407369720359003, 0.13824252712149776, 0.17655024815711284, 0.2077321104344822, 0.08233122407428681, 0.2631581580686954, 0.1237726124424127, 0.07926842753565119, 0.1964260469521246, 0.10806515933044496, 0.10441530195455398, 0.2708149923672599, 0.21105999637755657, 0.09085548440775565, 0.1699360748452525, 0.06156908070308067, 0.2613500679933256, 0.27849775108118213, 0.21098614550165593, 0.06109863760009889, 0.17611278130883173, 0.2748495790987246, 0.09968012781633485, 0.17196858271716103, 0.12826293721915255, 0.12056635827907633, 0.10146864434523929, 0.12738828697512228, 0.15991641088358818, 0.31790313821646476, 0.21619129925966266, 0.07868875944686514, 0.17219110061564755, 0.09715332469392209, 0.2023114408216169, 0.12808562616907782, 0.10248704332738154, 0.1319735377065597, 0.2333855911368324, 0.19283983616098282, 0.10176283742992148, 0.1705478879833414, 0.15602134408489352, 0.16260688103014426, 0.10803485289216043, 0.09803662407061747, 0.1556931213746148, 0.18854634235462836, 0.16750052811638003, 0.15590440842413134, 0.1321425213808975, 0.12739240086727566, 0.1658624023078911, 0.15948706456730444, 0.17183850098761821, 0.16170761638110684, 0.19753921867137958, 0.20428155849297203, 0.1678716211069015, 0.17205266852773007, 0.2563354709456044, 0.15905312172347502, 0.0992596221546973, 0.17774965073312485, 0.14288468286395073, 0.15892406655175073, 0.1908924253357034, 0.13060037106756242, 0.14820006135250294, 0.20245797811977326, 0.34745243648367546, 0.18155087176109516, 0.17433231636401147, 0.18712676610917817, 0.17015649366282648, 0.13501049409950935, 0.2582144088322117, 0.11356200106562146, 0.1156505482691911, 0.1386098969247072, 0.1305656672845925, 0.1059460222360588, 0.1860375422984362, 0.21325197311178332, 0.09538361562355872, 0.16222706995904446, 0.19547447381961733, 0.13069224033144214, 0.09453754811998337, 0.1566957619281546, 0.13949505023417935, 0.17793363440902005, 0.1812633742848712, 0.11282672519765555, 0.09189286704866156, 0.14150865105611665, 0.3104875296834977, 0.20873802984433792, 0.17530515609729677, 0.19468270662811496, 0.1001065017114724, 0.10102825870196666, 0.09445023707925312, 0.1334339157948571, 0.08450627026538696, 0.1261238665169766, 0.14259551531605183, 0.20505405091229947, 0.07069840877046508, 0.11418371972057129, 0.17431644302222038, 0.13012303700370173, 0.16595773428918856, 0.1730689148028051, 0.0889262222054024, 0.1372393043411355, 0.10303770732735434, 0.2127624582499266, 0.1060269364426213, 0.15885259054841536, 0.13598632157569931, 0.16957060494009527, 0.18373780763678013, 0.19249256850490648, 0.0980964248939868, 0.06797608468801745, 0.08843740448355676, 0.12959874175008268, 0.08476209766682118, 0.093154881990725, 0.1764671276173284, 0.22060177469205475, 0.14249537230258988, 0.12502878213361387, 0.11992367179763895, 0.11203672766925828, 0.1595143679409258, 0.15721169150164052, 0.11667740486201741, 0.1506647960312905, 0.19849204818808264, 0.2492393823640962, 0.15111577667055592, 0.13004460492201392, 0.08497377542117912, 0.22910210243876905, 0.097752581650932, 0.21998701977633664, 0.13390221002121128, 0.15131070008200986, 0.05900897573859942, 0.27175832239370196, 0.1482543923080929, 0.1597344496798131, 0.14928763041332846, 0.1003509986725065, 0.185064579991083, 0.17154386357193993, 0.07684277866276042, 0.11171478687995866, 0.09177314282785501, 0.13811698063246666, 0.12608314128292183, 0.12359111855227141, 0.2554429019050252, 0.31549327075481415, 0.14893170596370775, 0.14089420257556823, 0.1919405102249115, 0.31688252524022137, 0.22736227079745264, 0.17849267941088448, 0.13367675034509552, 0.1691287101036118], [0.055550322417289986, 0.043089197527977734, 0.0319558562290284, 0.056158029324104713, 0.043034931689861326, 0.024749575475711497, 0.030514404342900363, 0.010390178555802954, 0.025199822585789428, 0.032085210175043156, 0.016292118009239916, 0.03888388044170795, 0.03293330015073861, 0.10382911445753229, 0.0580879963273483, 0.005182824689038699, 0.05012356240542666, 0.056787994915559414, 0.023033458086091186, 0.07019970851439623, 0.021627646525420492, 0.0818781366932296, 0.10262912965469784, 0.002464778728843216, 0.04527137982809255, 0.066381894021986, 0.041563066113139355, 0.029886897893682606, 0.04799323659690638, 0.03182777973462737, 0.007659202467860475, 0.05972475083845277, 0.05273121078648875, 0.009640817203739238, 0.05782951060081682, 0.02809871652824504, 0.022550389854117267, 0.047648301678559477, 0.03625263655257802, 0.07146631998400535, 0.03283771152998651, 0.09314749690313494, 0.050688130901225155, 0.05914763382245457, 0.029170236047056895, 0.018186417873948812, 0.05610036588604412, 0.06009747942669257, 0.029682097693664894, 0.053918608764727274, 0.062297538388520486, 0.08682118112882299, 0.058292047676420024, 0.02009789917557951, 0.04101798306369493, 0.003979237118337845, 0.019484205291636532, 0.027708115108731775, 0.031226075126699386, 0.045388614263145194, 0.024635830571153955, 0.04030847073262257, 0.04428199642608243, 0.05833100324736969, 0.04333889239557809, 0.04384670143706664, 0.034622761511033585, 0.034796104225660526, 0.015824653073063782, 0.03619986075547434, 0.03356294398526511, 0.08037872642519013, 0.02969235178053139, 0.13811497348210505, 0.06504449602817336, 0.04709736954781318, 0.03426320580465179, 0.02052708652861897, 0.023398424288438215, 0.037041013805015434, 0.02322442273819639, 0.0291253681925516, 0.03810465793996569, 0.04051322688258464, 0.06816382219474162, 0.02787414551412146, 0.029292162770645756, 0.00790610542378178, 0.058429886046196186, 0.005024788889943833, 0.04720718825175878, 0.028811848624759627, 0.12537021986058644, 0.09465082188046749, 0.07017641178061886, 0.049184388405973875, 0.022861356433901577, 0.023665143544935895, 0.04259494824274894, 0.03187146398328966, 0.034565377695065354, 0.03788203278916978, 0.03331199273346894, 0.05120888299819443, 0.061435869504367156, 0.026298578445529266, 0.07574259213382199, 0.08898285142476521, 0.026977326600782336, 0.0812123220173582, 0.014249126224087612, 0.04830560894803174, 0.03864217204071822, 0.009206946180652707, 0.054653202814440575, 0.05993743599843114, 0.08865459041009027, 0.04900981995066808, 0.02114568912093678, 0.03506294414100628, 0.06594556098383281, 0.05534889874979854, 0.04465867802801152, 0.04226554575706682, 0.038470158488639904, 0.017656256302049565, 0.06827590085806386, 0.07396942800692013, 0.012400321448372017, 0.04310457674305766, 0.10638765660264801, 0.010327074935870066, 0.030388020902812004, 0.02253332907604354, 0.04579896542934641, 0.0392437502441387, 0.023979637959611513, 0.0271673891843567, 0.036769968066965385, 0.04619986307056201, 0.08415333355867094, 0.05336127596937361, 0.016065724663466455, 0.024671375135620757, 0.03753887519480721, 0.053726075547597105, 0.024572400406243342, 0.03529390049797874, 0.007660854344947204, 0.04036627972738878, 0.04077565796192616, 0.04450541064744035, 0.048302418191827116, 0.009477991918702761, 0.04422468155802739, 0.040800582632542624, 0.019034000316394434, 0.037444554449569796, 0.026827916472909913, 0.04051695390033626, 0.008687709980163603, 0.009335975496909552, 0.03650322774304979, 0.06356302370888091, 0.01576375387113301, 0.013088750082158275, 0.020381219557396347, 0.031500037744521134, 0.020830424787897258, 0.019720696633861914, 0.013458848115988077, 0.048349291281474215, 0.046011347984594685, 0.030414025757401705, 0.04682351226708101, 0.05808210128077096, 0.08531649251498523, 0.0102228831477283, 0.03360504051670432, 0.07192065608837912, 0.040097210496183366, 0.041057172291461504, 0.047323882594824805, 0.034273555652508815, 0.012702211801473413, 0.05626858730289725, 0.041806356485692725, 0.07295906528710358, 0.01919978557364835, 0.0622011109014913, 0.06676080877021437, 0.045011135929774855, 0.05653345071139836, 0.026013875275009105, 0.014715796344042307, 0.045451188324800426, 0.05758590996265412, 0.08077447212511495, 0.026334220686206417, 0.019659800304760857, 0.04663236566909379, 0.013673518401300235, 0.02067851146773225, 0.0345046958705831, 0.03641242334138482, 0.06363783985556615, 0.09073306355745563, 0.05730939052638508, 0.02171299829628439, 0.006513090883081238, 0.05197480621357119, 0.05378290011938061, 0.038969628663072665, 0.01439583684963685, 0.07021703742324345, 0.03661719481310537, 0.021097381531651464, 0.031024205212992047, 0.019182977604589636, 0.06590610745573236, 0.026059162562652945, 0.00893375922685429, 0.017012824800105828, 0.052873618870733254, 0.07372504595907466, 0.044647163726509585, 0.08812364551328844, 0.04090709949753458, 0.02262149622002917, 0.030142989595450705, 0.03797677105232593, 0.02707681652428883, 0.008437773794867098, 0.08501659207526716, 0.03120374940936604, 0.026649959993758993, 0.09121025206461068, 0.029308794539481885, 0.06201283713322013, 0.020338439292484717, 0.05235536805083675, 0.03265378914112526, 0.07978719163445697, 0.06765103358174525, 0.029816419719868613, 0.02174490394311086, 0.043470498640090234, 0.044248395809723486, 0.022780310077172135, 0.04418352348429542, 0.08341843307378792, 0.03311854787170887, 0.024743793427102992, 0.052090784264428, 0.05274071410718945, 0.03041396063992814, 0.06493008845756132, 0.04383558167084571, 0.025418125085472584, 0.05531647407840337, 0.04701210396184076, 0.08938083410142891, 0.03862429154856551, 0.040575659217973875, 0.05437645738223388, 0.031622803334387085, 0.04215150590865843, 0.04048801492899656, 0.044949297312526934, 0.0359473045494768, 0.03962536545230016, 0.01722585853008974, 0.01793765954883589, 0.026679829761926687, 0.02146526269855038, 0.06431410014028512, 0.05254212113457823, 0.03453783300374785, 0.043559341856669036, 0.08318744224285887, 0.04027085198510078, 0.03423746525039596, 0.0467531202781585, 0.013874448899690424, 0.025991453796685226, 0.05479483714988155, 0.022409906565782525, 0.010499648689743011, 0.03764212469480211, 0.010864363040684933, 0.06311305430567553, 0.023210265433355685, 0.027831238844702323, 0.01870586379100719, 0.051706644796556046, 0.006176518772037761, 0.08458393625915052, 0.067618022853088, 0.04724628171853481, 0.050731552764773376, 0.041187361273313725, 0.026260036562058716, 0.00890566582506102, 0.043601832923389254, 0.009511016053898681, 0.01855776367348529, 0.05703404703507981, 0.0073314437195808905, 0.024665499241241527, 0.02091204571056991, 0.02641843481650276, 0.04899585033736883, 0.06552175348324162, 0.0323323080045802, 0.03658645936558324, 0.021375957913997195, 0.040612282051194104, 0.05455498268166858, 0.07569186945235537, 0.07204442525342589, 0.14685868736236327, 0.05943487848966353, 0.019583700960802457, 0.017283818827220992, 0.07536782192126398, 0.032699888481968836, 0.03895128085728615, 0.06630887052104359, 0.013111789218871104, 0.04568029074899612, 0.05583791948494412, 0.0083956437470812, 0.036359279822077484, 0.02079375215896195, 0.04127439269195161, 0.052588465623557575, 0.04185333299720961, 0.04781497559780556, 0.016343622100389293, 0.05472182130981838, 0.04458666959356877, 0.052898183480025306, 0.03725127429671345, 0.03142650479510908, 0.015821963146839653, 0.007068867562338711, 0.05744039539187666, 0.003713650714358195, 0.017867631451677413, 0.07582317692257705, 0.020922338101832617, 0.03297470720304597, 0.11931448634113036, 0.09309809955377733, 0.16729137079129297, 0.17274153478924306, 0.2260258917005793, 0.17611818988957714, 0.18339663804058107, 0.1226350638054071, 0.11272059137662573, 0.14830734430541917, 0.12162940486544564, 0.1481997702390917, 0.10123830468904588, 0.20465821328182376, 0.17042208102441606, 0.1164027316976459, 0.18497182206521112, 0.25504030737905736, 0.22089647339476695, 0.13520800688814733, 0.12992500327527523, 0.2427220425658649, 0.18164978903387824, 0.1298652943824568, 0.1101173020358528, 0.13148541712472517, 0.15400371364047452, 0.2068450725487163, 0.1680936180655995, 0.0718787893833172, 0.19453825308911263, 0.18040558563605433, 0.14949954565494292, 0.09680902945899195, 0.1125570239439126, 0.12727128236644691, 0.11599656720195087, 0.11889529835072257, 0.15449852983076728, 0.21876537000700352, 0.11327225895177935, 0.15308964817274004, 0.08867486875744597, 0.18511278224327873, 0.09257430225730905, 0.13840230241898568, 0.15708326452201413, 0.23365897727349114, 0.19147664398675968, 0.1536366043071593, 0.20792496540854055, 0.1641251140784833, 0.09580501760806769, 0.13106733230092835, 0.10989699047058822, 0.09084839809445605, 0.12745138963744526, 0.2365564137336708, 0.07159558966034843, 0.1905462761679965, 0.1402200605239599, 0.12318362106358814, 0.10339776865176617, 0.1729337922147205, 0.16654906223618215, 0.11402670233961075, 0.16922149867300065, 0.1428636614113085, 0.11754270883337145, 0.16184643151298647, 0.14157551521014783, 0.23900916679732262, 0.1476205464813017, 0.18057268473409838, 0.24168779322456932, 0.1281616527346834, 0.09803002039271017, 0.1852827311884011, 0.19116830891899525, 0.13933239444609613, 0.17023279602008481, 0.11880701437832848, 0.11546422802512685, 0.16505368925150365, 0.14523704776600485, 0.17682107556010448, 0.18595376292303686, 0.12868597863181946, 0.17108111582215757, 0.17505262287393694, 0.13095978887811785, 0.159677054372526, 0.2435671141551387, 0.31655099303010975, 0.13734649536350083, 0.11652494570420635, 0.11184378842552824, 0.10452014874787101, 0.288071797019051, 0.11511689142113733, 0.17297879221939272, 0.10165523272007705, 0.15551025618708905, 0.12083428220883494, 0.17633891514232083, 0.09792606992226455, 0.24011335996610506, 0.17137233648569355, 0.09029705227623064, 0.10182358820231692, 0.150276159627303, 0.15144956117916494, 0.16232410265553385, 0.10187154530637688, 0.12157299781158087, 0.2011123446807746, 0.18177184216197462, 0.13139236808544205, 0.20180992902286593, 0.0796654602632888, 0.23361264427583064, 0.11299744789158145, 0.1853023277175042, 0.16496368924215918, 0.1257402020236177, 0.13151659690324338, 0.1567657210773999, 0.11142782566528167, 0.08503443426302365, 0.2191900125434322, 0.2088943271026496, 0.10959664569987405, 0.10989185768149554, 0.08667159480072799, 0.21008933233397625, 0.15042868773302726, 0.19528845234984354, 0.12183141459019915, 0.14940124125249926, 0.11733335232542408, 0.18070221488033572, 0.19721482640072224, 0.214999511597618, 0.15956842310486302, 0.20276283514836144, 0.19618183344362244, 0.12063044153394238, 0.11716975424919399, 0.13333038667276984, 0.17301156546079344, 0.1283782794170322, 0.17078699934626781, 0.157291027567079, 0.11474359975827318, 0.11781548976056999, 0.13079694922893279, 0.11138909225983006, 0.09021705737517727, 0.09619946861940046, 0.09030491233833375, 0.1396093658742405, 0.10402492653097838, 0.236684518956369, 0.1579174116974877, 0.17556063109828582, 0.12598448448003302, 0.11362198575009262, 0.11296768537572316, 0.07964990101754665, 0.0836049908051087, 0.12887742400409716, 0.14046620457403122, 0.09966180299318607, 0.17826924220688883, 0.15528314176105684, 0.21448157487377045], [0.07057726728699862, 0.0225005692411815, 0.02657497339251061, 0.029602911015371644, 0.08759746568337565, 0.07618274795071733, 0.029343938823008252, 0.02873551370876451, 0.04841392995008538, 0.05103835565668922, 0.03968451127049424, 0.020131976681671316, 0.02506322719367041, 0.035344584875049136, 0.06414102172599205, 0.09596185112792639, 0.042948084132325266, 0.011065099144264335, 0.05441742010354515, 0.04051889210278469, 0.0206718445875712, 0.0327978328230881, 0.01249539200216532, 0.07153207331054634, 0.012421418552196795, 0.02317796716646802, 0.017668665011203098, 0.011051414898716876, 0.02346486134845163, 0.08140913000510586, 0.06329423793020748, 0.05899863738206126, 0.024731424937565482, 0.05956774494881111, 0.028657445518840707, 0.009644320140773011, 0.03199934129483037, 0.025637218570937554, 0.022249656293781537, 0.008888439380473668, 0.026503411204283758, 0.03835493120394888, 0.044550805187393586, 0.026308372879641193, 0.06290521848225786, 0.0436427535098647, 0.057007061587947036, 0.03378491413088576, 0.07008193015691734, 0.041422086782873645, 0.04513719952815483, 0.037062835819538564, 0.04514998170517145, 0.009576465818099678, 0.02434835990800733, 0.04709358124302761, 0.006072025815580762, 0.009887872898440448, 0.005408882871345287, 0.04632906762943153, 0.029239681917392922, 0.0548900772006281, 0.029426764418941834, 0.04106396749134987, 0.06743663621525611, 0.028688167559824167, 0.03260786600050426, 0.024912606646877625, 0.04548137218901708, 0.023746163088587985, 0.12728633599415903, 0.03196173403862744, 0.03536480576581052, 0.04592276906834976, 0.05541783900210454, 0.042765490906012636, 0.07743668832605885, 0.023654314892126188, 0.025883918034753976, 0.010423261105203101, 0.033161437304149714, 0.051710348831669944, 0.04488516043150618, 0.05544577822870305, 0.027447913345249913, 0.0147833930696511, 0.03927186950139942, 0.05418849004913242, 0.018523599982502, 0.0669916540444378, 0.03453423622094336, 0.03877118124716705, 0.04725119234212945, 0.023915912850850055, 0.0733839682934265, 0.05051630504068829, 0.0394665515951572, 0.12098480316419756, 0.045617705196022026, 0.0375206001673735, 0.014886236543046131, 0.033286926336586475, 0.02125674314166029, 0.04800606856963808, 0.05295529533478041, 0.07867405821959819, 0.010273488043176552, 0.013517167516833833, 0.039656985731374834, 0.013198059337634235, 0.03773695488850917, 0.05521879403761799, 0.010504150413908066, 0.015861901225552203, 0.08759683749127774, 0.002377153352661539, 0.05498006571865371, 0.027575292699639837, 0.014246259140030993, 0.04000526462351123, 0.034067439696481155, 0.03962091065102047, 0.02005277659683939, 0.028026570197975928, 0.018118837427708413, 0.007831380250037559, 0.023008880070260456, 0.05780351340710636, 0.01997470840691559, 0.00827677562953003, 0.03037509508430958, 0.06794510409235954, 0.06843047441854593, 0.03978959172062817, 0.06919775743998828, 0.008174634084195621, 0.03544442145334136, 0.022231875393058986, 0.021563021263348, 0.044625157850884625, 0.09149147528073481, 0.030600436016797062, 0.01714166546721132, 0.022035023355255687, 0.057368475057545214, 0.04415439299097465, 0.029141653306601994, 0.04026818216868466, 0.0218021287958348, 0.016533452942366564, 0.005698477513261981, 0.03321725447031279, 0.03019530957023944, 0.019692368617641832, 0.0491851621547774, 0.020117576143914656, 0.02661868445425024, 0.08807733549826569, 0.05237363541739122, 0.007718487139490824, 0.0975174309625741, 0.02465662794307836, 0.023848866750936837, 0.02212982099022596, 0.02950047356857648, 0.0045507624106962356, 0.011785140396246027, 0.025992880635444197, 0.07804962761339643, 0.02205007889818761, 0.09286433548456238, 0.01346440225343911, 0.10945284333560737, 0.04249696176679384, 0.012297118871262478, 0.04372218916673334, 0.03135514370496235, 0.022219447531707348, 0.037899897959564006, 0.0480004531451531, 0.07457738006187063, 0.0220364578548939, 0.024374387745234757, 0.01354225019308468, 0.020839840008486665, 0.058088318084276495, 0.05320469525852992, 0.026787951581120014, 0.026415314923431125, 0.07536009975498723, 0.02846309284289037, 0.018219145150074077, 0.0162952110892342, 0.016627995853102016, 0.07591719123264475, 0.05040875012655893, 0.12148078380813523, 0.04223042062573856, 0.023538604972042868, 0.014128041239605557, 0.048623110257810166, 0.04215195407009414, 0.0970672240721122, 0.026527127371199673, 0.03909093102500324, 0.04796062423396976, 0.08372284577138002, 0.031163058649267883, 0.03262282386722584, 0.0529474007987207, 0.046075316326272105, 0.026614844438529787, 0.018654177753975796, 0.06343509468640532, 0.06880355157679127, 0.05417173187578878, 0.0516662068454729, 0.05420665016337749, 0.08907649801262925, 0.04423287486837757, 0.046009179955768975, 0.03601783060378606, 0.05885792618256904, 0.07608512536652627, 0.055373578272279234, 0.022546017407289436, 0.01927158716435154, 0.05311927645497265, 0.030082606545258916, 0.027261721420912977, 0.044277614403155544, 0.03296436884650781, 0.028805292827347596, 0.021790340617899934, 0.05428400589153171, 0.03144192997546446, 0.02424091033096756, 0.05461865990993477, 0.03372627393072171, 0.030204770756104303, 0.10349837131798269, 0.06698146507504486, 0.044898019217315226, 0.03961040375513896, 0.023557416261023572, 0.04096434924811606, 0.03411207580938935, 0.034612281428229426, 0.04568074657131107, 0.04111239956992288, 0.02970608965223355, 0.02400134697616581, 0.08145458200165341, 0.013915005594401831, 0.009136523548213225, 0.06317979588563885, 0.006060557958159235, 0.01688866301499788, 0.04493970972215457, 0.10005683623134129, 0.018267355063149048, 0.05649613073816704, 0.020592926040051446, 0.04693475589456578, 0.022089168534524018, 0.029571231364482836, 0.03514774624378451, 0.07361342694850699, 0.06658695277667816, 0.031059320768221255, 0.06317005507768163, 0.013398295568843043, 0.01827214502789561, 0.07538197922610468, 0.03258290685593121, 0.02140521864226509, 0.027174393143204432, 0.0647183264335317, 0.02939085404749119, 0.05061490821742243, 0.06696513208049922, 0.06060588601676207, 0.03458994996523665, 0.04393513862704558, 0.029514588738581347, 0.03910910646100679, 0.029958544351581125, 0.03676778471638118, 0.030429711407651345, 0.011975218301578876, 0.034481954550550836, 0.12876543727132583, 0.035308211020404295, 0.050080171185395414, 0.04983520308028787, 0.038580069123136426, 0.038643439916232904, 0.02970937233898909, 0.0640641256505924, 0.05242881290013752, 0.04355551141704764, 0.04208944895635209, 0.007328707349276351, 0.054259705582573536, 0.017983770380998333, 0.028750906330383116, 0.00952223924198939, 0.026008547133495732, 0.036890515832290534, 0.039903926512887405, 0.019779319597047665, 0.0507013995440737, 0.054224821768941424, 0.05343357551722758, 0.028051333990128293, 0.04921309755093629, 0.07250610814099351, 0.01409383828661615, 0.04914267874893643, 0.020925978934692762, 0.029917160281911496, 0.023724850522534504, 0.006805333316386227, 0.005379522072842285, 0.008519957792164098, 0.01598020339564931, 0.05378531329634209, 0.02682656049728394, 0.03370840876032749, 0.03768820105300796, 0.048549228738392555, 0.020399942746265762, 0.08118896399654689, 0.029166087680946917, 0.03944102554552017, 0.027514767923182058, 0.10740030226447891, 0.027864847121940508, 0.042913418653751575, 0.07193384812243524, 0.00657938430160885, 0.002081117108314028, 0.07275614391772017, 0.03219654956351846, 0.03811698429466736, 0.019094199505484393, 0.024547337839800506, 0.03383929105175119, 0.01271823836084936, 0.08601829800153933, 0.03571136479055689, 0.03426248568200296, 0.18008742932110064, 0.15925726883353727, 0.16770810730034308, 0.0757889481141202, 0.22600969660186002, 0.15910736074851406, 0.10879442140820528, 0.1063781341297492, 0.14785616448329342, 0.15868546080685433, 0.17222338356077674, 0.14393325804943038, 0.18515609685451756, 0.1775190889114334, 0.10036307987907242, 0.12677727056847465, 0.149255117641822, 0.08908968238580613, 0.19373407527323694, 0.13159008005694037, 0.20317088422035018, 0.07892376457851741, 0.16299760119328577, 0.12602203811008122, 0.17206748466818564, 0.16227301991274282, 0.16981442008287678, 0.09828335034751123, 0.23704646485707453, 0.3173485824898366, 0.21764406243399267, 0.3161087457931811, 0.08591401811328628, 0.17457585571514023, 0.14267066854142374, 0.23710510122679898, 0.17621912963448033, 0.1355806014110004, 0.10317548824053618, 0.1742356207462088, 0.14688893251361387, 0.10924819826839433, 0.21328535922352346, 0.11060605080978525, 0.1255992648281878, 0.16539824495632804, 0.17505259223041997, 0.1213107199498242, 0.19593273229416341, 0.12733312098369484, 0.18211707202417238, 0.15961938327358616, 0.10697479404869581, 0.1245117876979132, 0.11649915152379584, 0.16699181509114083, 0.06448767268128934, 0.09261691206765753, 0.13051686748381586, 0.1153788322042073, 0.11487395727946875, 0.16020188588769207, 0.13504187306088788, 0.12815136417386033, 0.2738318772565934, 0.14031603601911377, 0.08952952410665252, 0.14893450984551063, 0.10830710521869122, 0.1176146827938576, 0.2474749286568934, 0.09696009433678082, 0.14761469356956022, 0.17687603470779237, 0.2832534410540135, 0.05896823518278618, 0.1561490356201126, 0.07477930551695247, 0.04464533660681017, 0.1916333549325505, 0.10665431648733155, 0.12144555908537681, 0.13855024931892274, 0.21124626299546612, 0.10106205850118592, 0.1571678406288547, 0.1302763005538333, 0.26154401081223644, 0.18342864519405752, 0.15313064919844752, 0.11462512426078321, 0.17428146344759773, 0.19614340647334055, 0.09010191436015791, 0.15169455609734983, 0.09643291093168721, 0.12096287772780466, 0.28736589296210197, 0.1671831532111091, 0.06908460625357206, 0.17256158073582958, 0.17320771461292622, 0.1286286292898078, 0.17262813845469108, 0.18769917168444206, 0.1253716830885218, 0.13917657216229748, 0.17907435465003216, 0.13610206213929962, 0.07072127649500486, 0.10884073908410727, 0.14447952470471784, 0.16548683536389183, 0.0886679126790935, 0.1396799685373422, 0.21619132990317963, 0.17925714322876546, 0.20724740660478994, 0.15413649199951082, 0.15842764157681696, 0.16332870439415978, 0.08739448302695829, 0.17549226541192303, 0.17057804120404108, 0.21083070626181943, 0.14115458053927268, 0.06530352567713107, 0.12479463502043679, 0.10847580544049702, 0.07080524739238524, 0.13954691438665315, 0.18456924286100174, 0.13063771019299186, 0.10528774586536231, 0.13328074417527647, 0.08701683998468422, 0.153278672707177, 0.17685262306082636, 0.09400415174182385, 0.2355506935066754, 0.23510861480909012, 0.1301514129004171, 0.11341585447230648, 0.14590930524131945, 0.14681027060554874, 0.15045199212768387, 0.13653183746482098, 0.17677800609700142, 0.09424168496362625, 0.08534097668504523, 0.13508172495470894, 0.15307729883540064, 0.09331048210902561, 0.15085254885977314, 0.0886223074649611, 0.11934838573177976, 0.2186087816352806, 0.2114481731287895, 0.11584663613428993, 0.11368134224246587, 0.25080489835912184, 0.10528234494549614, 0.0851311068981886, 0.1348347688514379, 0.1145211584685791, 0.07898754139821376, 0.12038885570702054, 0.19403525507978855, 0.20536898965797118, 0.09929094748992114, 0.25257929588758177, 0.12047638891324883, 0.20609101220484705, 0.17296982899067864, 0.24619603679785806, 0.20195815171445572]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03662361846035046, 0.045582572403814525, 0.0017687247670818904, 0.031181818227313703, 0.02730994282530681, 0.03322861938466949, 0.01387672992648497, 0.036795643503747644, 0.01892429844085728, 0.05610645245460253, 0.04049465691130008, 0.010413296216528022, 0.0608181881327783, 0.01962287869725016, 0.016133767635291143, 0.09241025218920362, 0.06721404170797718, 0.0015431416789895946, 0.009231532814972585, 0.017157151934600646, 0.004522636450166184, 0.038627309934987177, 0.04419856945112829, 0.029580370793419502, 0.06897200665046131, 0.013893300408287155, 0.07358367975440717, 0.06680798446459156, 0.027662324118277723, 0.04535867937750394, 0.025109711493695938, 0.07018594957527614, 0.04271172302504701, 0.05499036960123528, 0.0830933972892742, 0.03640908319803496, 0.13118089717482367, 0.061122508899819475, 0.004496284461985793, 0.05095793557683787, 0.00932266663444499, 0.03930335571508735, 0.04191546655830838, 0.06693366884944901, 0.02902075122561186, 0.01670196738785073, 0.039773136152014624, 0.025839032943270383, 0.03200879290459618, 0.036339533905829155, 0.011665458310275309, 0.030147858084209507, 0.03665925687058799, 0.05860027166143541, 0.028962624304357077, 0.061006247396430666, 0.04139021752522357, 0.017843683543164405, 0.015822706252126204, 0.06781104636648971, 0.03206293808386451, 0.04680141063046552, 0.0236202048272976, 0.04164168971680826, 0.04826847283590225, 0.050004650237819845, 0.053442937111662286, 0.0349680028645502, 0.0953435568859981, 0.0885956782487131, 0.027916655733039784, 0.027757583321222377, 0.052601370374642076, 0.03333546183702927, 0.0551073320750748, 0.0327382005390621, 0.04042082901803717, 0.021520066713433594, 0.07553207883310896, 0.03879206480398294, 0.05938618594119626, 0.024884190530546253, 0.023530605098893567, 0.021165904266038732, 0.06817505304371158, 0.015415002877313285, 0.01968535125225542, 0.011185383566865518, 0.09630787772156539, 0.03629467562742291, 0.04630831047712315, 0.028394250266794718, 0.09287517562869096, 0.02642867549683058, 0.011060106166217838, 0.027986861945640658, 0.05844485540423663, 0.07252957341411422, 0.06522852566934402, 0.02917857491411269, 0.04097075757360266, 0.038180021839516784, 0.07886362667646139, 0.05800796695233834, 0.05366031456017687, 0.07697639971851342, 0.03865738654689443, 0.1267078936460518, 0.02813878292668491, 0.039844520224799077, 0.0652481375202056, 0.0690904132000381, 0.03727578527985081, 0.036372770630424066, 0.0071464727478732755, 0.04454474926235215, 0.029182928208742413, 0.028237682962489706, 0.05037308873368367, 0.027874187648957296, 0.07138264786091543, 0.004154894136703544, 0.019365352495843847, 0.0401421032485462, 0.03220892571393521, 0.05416976686026301, 0.0950910083408798, 0.051021605144224824, 0.0803800977225746, 0.045016192110075105, 0.030427572107122793, 0.021397211108236544, 0.012278542196708582, 0.05598092894820918, 0.03304722125551874, 0.001117771837837814, 0.05942635193106629, 0.014701613183734159, 0.023598453675907467, 0.024855006411070787, 0.027059575715552897, 0.10512168864689528, 0.09447110531431052, 0.010579482712332281, 0.016753421683285027, 0.055594866599647276, 0.02513470894266521, 0.02213901979097676, 0.06184828910796393, 0.07567148385269028, 0.024573938327751333, 0.04952299926850585, 0.023642362005287604, 0.052029198456195094, 0.03786686807870865, 0.005374048853428254, 0.016232912819231712, 0.02372410167158852, 0.05019337216752672, 0.044988490370733124, 0.025607479037716988, 0.025242309822070024, 0.04919658452572842, 0.031615364620642315, 0.026717226343950438, 0.043877881215584856, 0.049158100098852194, 0.03362401268414913, 0.014883496821106923, 0.027170702514629212, 0.06037465003769725, 0.05188384476388174, 0.06035374732868326, 0.05075285383950799, 0.0644163805390558, 0.026460282369366577, 0.03641667512936458, 0.011274563862131009, 0.058398652641523274, 0.020648582327750423, 0.027796697855416327, 0.038994813803583384, 0.08118680362860042, 0.0386352772493997, 0.01931799677080445, 0.06265014184698944, 0.031100733566188046, 0.012842579219009609, 0.067403219459999, 0.019078092506876396, 0.05829138884080514, 0.015369929136678338, 0.02902612916284031, 0.011910503981785189, 0.049744322069830475, 0.03404746778429516, 0.0266014417302945, 0.038791467255402, 0.038737128638932784, 0.02141491731538648, 0.03814252183562325, 0.03996504117704688, 0.04724157027780049, 0.04456147679217881, 0.02562453215491147, 0.049012815354452025, 0.024993781323334383, 0.018053597380076686, 0.05713862186718372, 0.055748026727909045, 0.028719226679494305, 0.05603655076195156, 0.0048030729897530575, 0.03231049748137593, 0.02917346893809736, 0.029652697154350822, 0.05155327782455472, 0.009590647063188015, 0.09333228497135063, 0.038187510348976626, 0.08329709240746114, 0.13778249132296733, 0.061526547501524614, 0.042711470216032, 0.03619190493238069, 0.01209955820212922, 0.07066242562066163, 0.03205843923252917, 0.0516569716555457, 0.032028402840237946, 0.005497206105745488, 0.03324698634265411, 0.06408893540802021, 0.08450741173639413, 0.016605400089775364, 0.0445792462015825, 0.020075042942358602, 0.055918270616882274, 0.05297756551073925, 0.06901748929052584, 0.02880721953847716, 0.05192462362409119, 0.05001318445729633, 0.03528035606347746, 0.047708849437654986, 0.11130967958559913, 0.02904481787775313, 0.03553658566107193, 0.03944825358508576, 0.04051756294023606, 0.018302344213870746, 0.0328615483557505, 0.07906297041523842, 0.023294196111120047, 0.014349215611394857, 0.017948197088234367, 0.017735383608528686, 0.03050827946994574, 0.08639364278004055, 0.059124635862967664, 0.035915040756545724, 0.033828493042458455, 0.03729734299404006, 0.02270371277606295, 0.06399965935176419, 0.05688321198366823, 0.06651867135998703, 0.06361694863787101, 0.04927541497313688, 0.06846789781364702, 0.02746852302563287, 0.036027885507792234, 0.07313528083144658, 0.030870955069399172, 0.04378985771308503, 0.041386559455385136, 0.015156031642559797, 0.07408909860157198, 0.03244295791392365, 0.044981905845023935, 0.015768060242877375, 0.07414443313234276, 0.0313064185977583, 0.0467658105246242, 0.045798095919552355, 0.014718918152333749, 0.07618234192411746, 0.0073205652710561075, 0.006022704596210632, 0.032886580278676365, 0.043877781624154705, 0.0428338336097377, 0.006862061169569291, 0.06867477985759897, 0.05568657881550251, 0.0439381302003899, 0.060373083387892094, 0.031116867377873392, 0.02203115078079845, 0.04377029948837815, 0.006729044365666567, 0.045018601456596974, 0.01961061937524186, 0.04858306684200803, 0.05946464866640107, 0.04007495947242264, 0.07626706358766364, 0.05135471166502084, 0.01990953922241686, 0.04547337423108759, 0.0805160476856174, 0.010038797965183133, 0.06849843407830886, 0.057234976575860096, 0.024605079801873337, 0.028232822134610147, 0.05948209248843694, 0.08486492964889734, 0.10577392824474843, 0.1064093292300259, 0.05438595687249496, 0.0770278348617496, 0.07448861345408425, 0.030981857787757635, 0.08663343596121958, 0.06479241479668887, 0.020127223106101155, 0.02643382360768174, 0.04298430476938525, 0.026311856664476857, 0.0308890902857867, 0.01751141588864548, 0.059526257457271706, 0.04521867680934168, 0.06348444607048746, 0.05107392128857394, 0.05749541965703811, 0.08351126760845223, 0.030763810012309305, 0.026385245972403118, 0.07769755658603485, 0.08856143411849776, 0.07107835007651199, 0.02657598845901028, 0.03163250775316791, 0.1235483248808211, 0.014025960023695183, 0.035340440339378776, 0.003627215647288869, 0.11203173277599197, 0.015836639476249057, 0.038025352518044175, 0.09371528296821541, 0.1124755198496484, 0.10771848156207031, 0.15749379571887756, 0.08760238396784953, 0.16711138609436252, 0.2082106855607802, 0.14862540868982194, 0.15952778980135918, 0.16783262723155562, 0.12524589145135495, 0.13306761851474164, 0.17222965015999733, 0.16581518064823844, 0.16728560981010238, 0.21212157973599052, 0.1258692035691873, 0.09951188724728362, 0.09849227784622101, 0.11720765261880814, 0.1566304759152474, 0.2101435866807738, 0.09713416483493582, 0.1406914191020112, 0.19078122001261483, 0.237570331101456, 0.13458526933625822, 0.09370074261941257, 0.08038202060326453, 0.1725774081123452, 0.08629324695756359, 0.13463995269229337, 0.12049228523767765, 0.11709118427167978, 0.3093282241494425, 0.14975656815353902, 0.16675373028603294, 0.1276243186645931, 0.12933867022154794, 0.1259787924467556, 0.14064698600240294, 0.16745908275967644, 0.12616384098486555, 0.28244923259462085, 0.1276240888382158, 0.2296303660278359, 0.102253386510476, 0.18030119849549187, 0.12849658637517883, 0.09821281663232273, 0.17107276546378292, 0.14747973952081897, 0.12460665236557684, 0.14284453985671844, 0.10885428351860856, 0.18778371714776565, 0.1330965153512455, 0.18305028969001386, 0.08776235844819777, 0.2000192138216188, 0.1093358004225358, 0.1509085958523135, 0.22019559487460122, 0.09913114920979547, 0.14077732820184002, 0.15226788097812285, 0.1210719686482222, 0.13839517780128988, 0.23770560690712547, 0.2155035668082776, 0.06386477042049651, 0.3007665787252688, 0.23646030034269058, 0.1548534583660864, 0.18211432942940345, 0.10295823336608949, 0.1058415201823077, 0.082857258347494, 0.2618339597698181, 0.13890583668985676, 0.1494131002935671, 0.16516924595400212, 0.12568458404031493, 0.13885375803276417, 0.25284149714054605, 0.15125151212897994, 0.13628080577379273, 0.13550576994255667, 0.2202623670980815, 0.12643797022681083, 0.16698847494779095, 0.14726935645505307, 0.21548006323076066, 0.151421798152789, 0.10461967123011429, 0.13880888060215982, 0.20086655303114848, 0.09319093408844165, 0.19090927927003754, 0.1590120287672166, 0.14479199664727335, 0.1626546083078269, 0.13919589289974782, 0.2316572354926217, 0.0803915354152841, 0.202155863685954, 0.1335893703564521, 0.21826886842327736, 0.16980383274776323, 0.1423258830102221, 0.1952064043331531, 0.1135708647029054, 0.10758304487793677, 0.15167834567687205, 0.18079112704482772, 0.1452361437822542, 0.14158227210564, 0.11991447108166835, 0.16910358241969542, 0.14960377957792054, 0.23626197550085284, 0.13202849685424758, 0.21808604920102706, 0.11730793352809646, 0.11325725128934269, 0.14286344690668967, 0.1433628902680451, 0.1656860795112387, 0.15611456166351997, 0.18139416081530435, 0.14677596518829947, 0.12243808727831611, 0.14092199624546115, 0.17203927731081364, 0.1800830319764153, 0.10119851408225876, 0.17896036076689922, 0.1410123180117338, 0.11761646011784194, 0.176942439209069, 0.19006835987731335, 0.21357146241972524, 0.1540460936244457, 0.16820387343966192, 0.14128539771322282, 0.18988934045116748, 0.14487150125205517, 0.09672357235103847, 0.20835385207206975, 0.17514928784822265, 0.12152767604998044, 0.11962908800811538, 0.11019407170674494, 0.21219705471829062, 0.15178379001877002, 0.07835445399846762, 0.17302031418488872, 0.13313656642792687, 0.20619472518803614, 0.17572964541614058, 0.15738030745377465, 0.24168137340776383, 0.15276001586068064, 0.07373122062774436, 0.15277118542261664, 0.21732970591514342, 0.19227647042322546, 0.09422897556496244, 0.1678754668682814, 0.21652286211329125, 0.11478247872043042, 0.1595685763224479, 0.134126091556203, 0.15509607841170606, 0.17264569718991557, 0.09452447865999515], [0.01780564919294369, 0.03318399093264053, 0.006914731150778432, 0.00814660675748582, 0.008463516264342734, 0.10680077717669549, 0.06507951390719222, 0.0752774082244404, 0.03804063980257319, 0.03349238345699926, 0.08726033337053754, 0.05939796071259245, 0.03182553126656961, 0.04767324550137405, 0.029775694485813863, 0.05889640677900565, 0.03628581582057861, 0.010136455023330788, 0.041524608499340476, 0.0812670513386688, 0.03303308693331576, 0.05807063294454448, 0.01816925367400531, 0.015453087023249077, 0.02939601939532065, 0.05479130931499024, 0.03277692245319486, 0.02285458613187075, 0.0065157693179865046, 0.031793081697316906, 0.020519879556471304, 0.0885336634312426, 0.026221714928866397, 0.027983404973882343, 0.019389390419687957, 0.06848685082889373, 0.07228674652475504, 0.017844581781255624, 0.06328647362909491, 0.026867299137877363, 0.049164826350827376, 0.06402950996773378, 0.03922182863818542, 0.01938268331991088, 0.015250540079338657, 0.03509995767906789, 0.04630066108919921, 0.056978107294848854, 0.02413746739377178, 0.05184837872342718, 0.023136269000749436, 0.014262750140211035, 0.04520851082258648, 0.03126135539083231, 0.014413433889257572, 0.053758664927895994, 0.012132657030897756, 0.05378637432811722, 0.013468203964763352, 0.05298545621635933, 0.043522780310482755, 0.012799493476538169, 0.046229441725318475, 0.039668718367935195, 0.06644662079070845, 0.01682824166040988, 0.007981793474285834, 0.019205069665106076, 0.02857434221603457, 0.06722427664264556, 0.07020369983248173, 0.028367944722694736, 0.05087827009359195, 0.023166110040619973, 0.037396455619243846, 0.026522685976458654, 0.03036815624293541, 0.040400765175300266, 0.04148312100780107, 0.06444371455619413, 0.07974617528699099, 0.08156768722279419, 0.026040448949882583, 0.013815544399192498, 0.094959570635711, 0.06746729505398581, 0.07032527798606504, 0.06152350996290484, 0.019899331100825823, 0.054250370801216176, 0.06277921617091184, 0.027715789394513256, 0.04045131548698391, 0.03618225988541399, 0.08241599936398768, 0.02134426102613009, 0.07098045936154743, 0.04360736024776294, 0.024980566306640545, 0.016379745061238928, 0.07981232697925261, 0.0616967109512658, 0.039163969847704136, 0.027703757983662432, 0.05461910424093085, 0.014385963891512685, 0.032884879563484466, 0.03876451245178619, 0.05006418293041568, 0.03304028049892476, 0.029737535646305453, 0.07069103900463351, 0.055594797651734085, 0.0346520452219392, 0.05277347968771093, 0.03574779227135643, 0.050004159941548304, 0.030195311485459248, 0.006476436448734134, 0.022025656015161547, 0.052252681625466195, 0.04128984085494473, 0.027514369557461435, 0.023837308399379257, 0.09495990771439769, 0.024869669333941517, 0.055155063183197094, 0.03408579899358653, 0.03858990569208418, 0.0515717635261676, 0.08065438784298398, 0.04630602370466917, 0.05175822549649785, 0.030826939487709638, 0.02162731902283286, 0.014912982587702574, 0.0720867745938801, 0.08063549611477122, 0.040895895461641976, 0.06630485622032035, 0.03746521201044802, 0.04434703729085384, 0.008121052937161538, 0.059109245156568874, 0.003316219860402447, 0.04759072634061018, 0.022379908477887515, 0.03800941788921914, 0.13497128571954467, 0.07193243085977531, 0.12188101112241707, 0.03170985582044288, 0.015727565792809813, 0.06517183516294726, 0.02750043824855839, 0.009310084597898588, 0.0051280680758458, 0.07410587592711372, 0.04751503685369127, 0.05751159943399891, 0.11357794335532574, 0.016017022538900135, 0.04370350811269976, 0.05757417732609376, 0.0068811132974411935, 0.021577216872584917, 0.010537034738057805, 0.03734273370355368, 0.02431837331143118, 0.034146653187851754, 0.032891104027869246, 0.020184020864807313, 0.02349253818993607, 0.05105414472880864, 0.02151486689164754, 0.02983615989045751, 0.042334221709038944, 0.02081420862176005, 0.035527645414995576, 0.04109440416458153, 0.02132478898631469, 0.05666969561829202, 0.0175435456161898, 0.08606253957916653, 0.044365419570596955, 0.05020410505934589, 0.02414594798709356, 0.0017344987117535165, 0.0757219230816249, 0.022202553377757152, 0.05464031338511456, 0.0541069821244286, 0.028789718259846973, 0.039623657076229016, 0.020826870139928597, 0.06051904612010526, 0.0384223354499667, 0.12901579480498068, 0.04135156838944362, 0.011884797901485958, 0.012713939649984242, 0.06264300190753515, 0.01903196252251585, 0.02070530730810377, 0.03318518219936279, 0.04441097115857467, 0.03935747982693776, 0.08356318538708073, 0.040135568518552094, 0.03642150914416679, 0.04218687235768284, 0.03493601486327187, 0.05690457051499717, 0.037291830991424864, 0.07299288040808133, 0.028434879739858934, 0.049683578958314274, 0.03832979968959286, 0.032090923275738474, 0.007747166119741217, 0.010946912844965776, 0.03823865820924121, 0.03716269538046853, 0.021159788969183163, 0.023285725093897314, 0.03425765549764037, 0.022473625928884553, 0.06327104844873951, 0.0446371088225034, 0.057857488131811546, 0.04263291172983666, 0.04000916018060619, 0.06730647021604162, 0.09150172553716168, 0.03277475442436915, 0.022508260763941274, 0.015684185106487527, 0.036706061012321906, 0.04123490085945495, 0.12946060077557642, 0.060772379905345945, 0.06837209851871576, 0.025987717202834548, 0.03461511595354926, 0.04050239822977493, 0.06187191142910912, 0.018940390117706794, 0.09304289525795369, 0.019547892096001777, 0.07844770988149029, 0.03761097939024049, 0.04655551172852997, 0.055122535089932145, 0.06766311478831115, 0.05773297203103862, 0.0227227462305417, 0.015063246903610567, 0.024568207990077716, 0.01284579200024206, 0.0287570063054802, 0.07190266068303777, 0.046848904251331286, 0.013530338483472026, 0.029883883337700562, 0.06535601036082353, 0.03148194083252982, 0.05010233410904485, 0.02510228618648985, 0.04999677868439786, 0.012827709452399324, 0.06531357675069763, 0.020306688778462912, 0.025083965193780682, 0.07463709661556829, 0.01606611058025831, 0.019890572800631487, 0.05426980262141555, 0.04458568517058607, 0.037858801172865976, 0.05530158132915536, 0.019176605668279435, 0.03610310002019809, 0.07926205368412119, 0.028945735896066315, 0.06955281621025455, 0.016830469061049725, 0.018082103511739164, 0.02662562329562441, 0.0513157599245108, 0.039176591146256656, 0.03656798132484959, 0.027055197523065636, 0.041023146496304584, 0.0969573364202534, 0.05937823777898185, 0.01924262137993449, 0.07351342183087142, 0.03593646440534823, 0.10811969712977448, 0.023800396367967613, 0.03386131991001387, 0.026450746489929098, 0.034443711441370754, 0.03811676212916932, 0.020243371611521132, 0.04707713333529331, 0.08714994010064872, 0.00912882149174449, 0.04454109119251371, 0.018180789042925163, 0.030507229929489475, 0.027967104538073464, 0.032138441794461785, 0.045512525154457945, 0.04402635671618966, 0.04456021274710375, 0.03587621925098281, 0.01630460524240569, 0.027713791820250695, 0.05164339274708783, 0.003258957421489721, 0.041532066365283345, 0.025247796926827683, 0.061773714278974844, 0.1393100706439826, 0.0365315615049293, 0.11252474099878343, 0.02873939011366137, 0.04126827164943661, 0.048870989497029976, 0.06297279509805864, 0.03079534219127269, 0.014096495654103498, 0.02585413636669757, 0.01043832526662417, 0.08820413837149259, 0.0564983255800701, 0.006840424452562847, 0.043281585188402284, 0.09619723164266157, 0.050795498123813065, 0.04636962815458256, 0.02257917943831173, 0.025409751744460196, 0.07255416483648362, 0.020222681491906126, 0.018725402863515962, 0.032248038332909346, 0.05703854014075572, 0.03874744401283322, 0.035298159946837736, 0.059251787306200114, 0.16837771411143965, 0.08541200069650527, 0.1407688246258805, 0.14250960621622302, 0.17166084519797759, 0.18180674512780484, 0.1441326860578791, 0.16065901055211024, 0.26214330607364256, 0.10711943144879996, 0.13353925288444565, 0.1619764213119784, 0.14971567438014094, 0.08758638805199055, 0.18626723077989396, 0.218585477240624, 0.10295482427482644, 0.17351839390973892, 0.13018830769485043, 0.13173038139939308, 0.2119383621480196, 0.36173856666972565, 0.15830044033786944, 0.07988060073506448, 0.14695689983425603, 0.11687117148070567, 0.08726892887704796, 0.1065759686753154, 0.10416423962000879, 0.14339160324344713, 0.16502001202635228, 0.1694150124826739, 0.1551222173316825, 0.10667347634631781, 0.2028079117618261, 0.09187994314537895, 0.1415463732255082, 0.20091653260732853, 0.12553589403509133, 0.12529870555285486, 0.1194531252727874, 0.14587918266413674, 0.07697584047432869, 0.14236360517961366, 0.13180694422654568, 0.21495322456523297, 0.1414844273559509, 0.11271878340912443, 0.13058273572354548, 0.15810804501656564, 0.17448983936300203, 0.2125626012322403, 0.10261399175731406, 0.10264847337478593, 0.13230995755762825, 0.14526087310044997, 0.13368028967130569, 0.23577010108818933, 0.17284138668929377, 0.11519243535135062, 0.1973252656358865, 0.12401229837128233, 0.08718334919502659, 0.15107168064963433, 0.19783384076529936, 0.10497674481162142, 0.1255698240692577, 0.1052312238983089, 0.1061687010130094, 0.22441364434217254, 0.22707524829574172, 0.13360774114487634, 0.1437211589467141, 0.23674393673577618, 0.13714568839678842, 0.10234941563178455, 0.08137413510872472, 0.13185992686738893, 0.18554048913140453, 0.16391060945968475, 0.15768649747535107, 0.12829447705899516, 0.15569189563393593, 0.106819408435014, 0.21450149315980174, 0.23703183257772079, 0.12318333761105615, 0.2034745461517765, 0.08298130330419348, 0.12141350596662491, 0.11726320931507696, 0.1658654819813467, 0.1412798972019265, 0.16082862241854592, 0.18768178148856088, 0.10106404266890981, 0.15511201304053107, 0.14215892180800438, 0.09195203201905375, 0.11300002960788627, 0.13335894643058702, 0.12687882318371727, 0.16240232023260287, 0.1433070884236405, 0.13095716885741682, 0.17510099366547602, 0.13501930411063856, 0.10364164508158162, 0.17924339961140387, 0.09570167234708225, 0.13968598998842702, 0.14346160835796787, 0.23685685809581514, 0.1129545929330972, 0.16435737661536665, 0.11409775699458777, 0.1801819339274399, 0.18000323625822223, 0.1659400223363792, 0.16704283654689792, 0.10243394577334966, 0.11646357440059224, 0.19662152194688398, 0.1061351616836844, 0.1484481972311774, 0.049718095049742735, 0.11903455781359827, 0.11747811229959612, 0.1055885426279518, 0.12676882061866984, 0.23399533583752571, 0.1935502294931681, 0.10101169588104372, 0.1195061385571476, 0.1104202515055095, 0.13326447246776474, 0.10976580557443442, 0.19958520969075544, 0.19254043367841553, 0.13091111165140906, 0.11704518835270598, 0.13927538218277116, 0.12265493612616293, 0.1845672663541571, 0.164864863899927, 0.13927761915951006, 0.14285365630301738, 0.12983321062018796, 0.3048341991680284, 0.15439005178068915, 0.22735189796695787, 0.10274392026927202, 0.13528469228936782, 0.14596861576841724, 0.12214439215078471, 0.07396353679078241, 0.1436918790662481, 0.16891849557718924, 0.08235904838769667, 0.19963287568140417, 0.24780358037640973, 0.08550531020568264, 0.18062381344216485, 0.14862520950696162, 0.08974825753079307, 0.15941952625589986, 0.2581413546877523, 0.08323592028670734, 0.14868694087190015, 0.10195029148411366, 0.218575885819812, 0.07054672336145755, 0.16263508838751625, 0.1725521884978779, 0.0843857033478637, 0.13200969705658575], [0.03987037186180392, 0.017248262771435322, 0.08957271614382345, 0.05318142150739028, 0.010457013023927087, 0.057072619562067335, 0.012229724201343715, 0.031065642908816377, 0.00846719348637928, 0.09068538224504841, 0.061663301856887925, 0.0754180466455798, 0.06932874315328176, 0.04385783652504606, 0.019077671158518043, 0.041345864864847356, 0.07820747236931518, 0.04963920714573995, 0.03681954927742481, 0.03824842583027579, 0.07547424685570502, 0.09801702754151437, 0.06224419568635284, 0.0425980011031272, 0.16490588024739297, 0.05655178319542639, 0.0752095251734699, 0.058578265785810456, 0.07137600587861193, 0.00980940634279602, 0.04157490217156949, 0.030433177955508716, 0.05886704262886798, 0.03273902791402033, 0.039974364467085376, 0.04885623847404796, 0.058833736956359885, 0.03630310642502962, 0.022371054416702642, 0.04107563884087628, 0.02196087370506458, 0.03991247222368275, 0.04947740937613192, 0.04653968435201434, 0.011236400234573072, 0.013182475194034558, 0.03816026060150997, 0.04461167087297767, 0.029970357427373532, 0.014761372829877563, 0.007399115617567253, 0.03387176551886144, 0.06410721043545393, 0.055138542497109984, 0.047262672169674794, 0.06829532118694437, 0.01767153592569934, 0.06918658787805228, 0.020512151644535122, 0.04066777362998936, 0.0500161683697614, 0.028659739952173927, 0.0628143259804816, 0.019019059686651154, 0.11131796099606062, 0.03808981881687238, 0.055316998848631505, 0.041390926156553536, 0.03576953767708713, 0.05710846864648404, 0.06169068566974133, 0.0460293548812549, 0.05187729854256876, 0.04680288151928014, 0.04085083033949618, 0.03302202845412878, 0.04320187757032053, 0.11095714124460375, 0.0383175116392874, 0.020389625457145517, 0.02896407221053397, 0.0760649619323592, 0.024692840919259097, 0.009174333817716087, 0.04672412001978486, 0.03961258327528354, 0.06291330837073826, 0.02686917796851166, 0.03262536344869483, 0.029952589933189656, 0.0015916103861414858, 0.08997155683896235, 0.04136062354870862, 0.09419805625633848, 0.022108069838835828, 0.029658659233621536, 0.09288158012373794, 0.025113066958804286, 0.04116232935038786, 0.02901427586743188, 0.0834794213334399, 0.029440984926036293, 0.054735683670808236, 0.01758438193299357, 0.028523979595892375, 0.03207245289588408, 0.014394325741206207, 0.047870041997802835, 0.01126261767856176, 0.0174124660571256, 0.026659777410508647, 0.09407912876697318, 0.05909435623776048, 0.022631418973868413, 0.03192324003565215, 0.039371545201227556, 0.03471077352221455, 0.029114047328250545, 0.019375662124084852, 0.07832991620225292, 0.02103979087194368, 0.09226336249060209, 0.03456216012578338, 0.07148086033280819, 0.05873779976560224, 0.0232957627609252, 0.06737249167335611, 0.09219933286189072, 0.057564057304614016, 0.030964078802254894, 0.016273638053286462, 0.023377986977838223, 0.03289867680700075, 0.07925223243693191, 0.04341070547760014, 0.1451260416257766, 0.009788704731862151, 0.0629166063792523, 0.07310010207396361, 0.07164996658121386, 0.05069576113695099, 0.04636002907289132, 0.0646370368438863, 0.03638970883442991, 0.04866946240766876, 0.05206869411913138, 0.0856692606823579, 0.03280088951390597, 0.014128997891901002, 0.05882230692452962, 0.025254896646665952, 0.00981251857498841, 0.039839885392857176, 0.006907514123726757, 0.10737242432491434, 0.09781111076834703, 0.0455047685142246, 0.03317141559936347, 0.025671891710390488, 0.03933626302187482, 0.011570263267194313, 0.04252544108537897, 0.03306753407683104, 0.04749648220416519, 0.046863701239588766, 0.06289763038136786, 0.07248903970204054, 0.062495644895299796, 0.020992848834383394, 0.0266675187289835, 0.05805017839696619, 0.048873571213334806, 0.03632159978752175, 0.006893664690470624, 0.009865127747968562, 0.027173357009286844, 0.02337185444400436, 0.010721246325110477, 0.05724188668893711, 0.052379338941987486, 0.03519488363376549, 0.05541722996220474, 0.017258231490550023, 0.02286557183270493, 0.03257095971475205, 0.020808078003145998, 0.09897206339143938, 0.017362735459520932, 0.028506643026165908, 0.008033969807588767, 0.09740836302479429, 0.024686087854206566, 0.06975144748726199, 0.030379829507681633, 0.014684593582886362, 0.029127813928249865, 0.10828194689125785, 0.08608371424939364, 0.03969403374339304, 0.05412299336204606, 0.052310770242324764, 0.057877800953123844, 0.07512591433741393, 0.03280937393766738, 0.02763107347662651, 0.05920997422729289, 0.04000412698294367, 0.03600208366650247, 0.05858172084234896, 0.03770198297476576, 0.04972533458062718, 0.016904825554980386, 0.12218713219608031, 0.11025430920023112, 0.06455451385268281, 0.030029530058644956, 0.05163858937580259, 0.028791537718667142, 0.02820917491560742, 0.06803135793175429, 0.03880153365072705, 0.009574512293892763, 0.03383038527963143, 0.007337056750041103, 0.10240385383968392, 0.017303878839518276, 0.05669107713225869, 0.02865676561580791, 0.04615258778475466, 0.07308397592315752, 0.039826279671321956, 0.03831879100612095, 0.02423790343586476, 0.02837998954008424, 0.029550795969102654, 0.03426065856230355, 0.06232250519397278, 0.0311394727172991, 0.04485653172577581, 0.00700963651686306, 0.08182432667742814, 0.07496486733397169, 0.013913902427790868, 0.11454822435494393, 0.1023333507680124, 0.08723214899580325, 0.07378801072557127, 0.010351499734115938, 0.03356289035911041, 0.06340700607266157, 0.0942531456389735, 0.01471369055986044, 0.06742180475304205, 0.030256860904515754, 0.044132390945789315, 0.04266016913818256, 0.022145177222668164, 0.019228992675761544, 0.049223064354831175, 0.044562625924065236, 0.08762053259077572, 0.05257958283407554, 0.052997533592485616, 0.013835230943626695, 0.03191893845195732, 0.029244498695216836, 0.03965827275908763, 0.05140046626629849, 0.016654161586155816, 0.09423304349184038, 0.02357967111522392, 0.046786916246938134, 0.04545478893804454, 0.026000185283802213, 0.046224557914801186, 0.06372722316413157, 0.049829166307444536, 0.07385578652423236, 0.011307408924274629, 0.03742070996292657, 0.011369169975120214, 0.013291541216594559, 0.032869209234993306, 0.038260905402562315, 0.026428943627604076, 0.04645769379191822, 0.016747053577414444, 0.0267750276778374, 0.05819625604236799, 0.02262266641933351, 0.06808398817215236, 0.028478803390997554, 0.01705183974286962, 0.04956412286828122, 0.0194246553620624, 0.006625383093412365, 0.0033101567532867198, 0.00473720427121847, 0.10044176476977526, 0.0704407963841673, 0.05937886597107976, 0.020740419032893354, 0.02782606583599362, 0.03313806779201954, 0.011221460562439696, 0.06208772605825817, 0.05377274179350465, 0.047702724564700365, 0.042339607307146636, 0.020168091981641708, 0.04298931498441004, 0.05781157648250942, 0.07696414997260417, 0.02059842080568835, 0.03972458916025297, 0.061015252759980584, 0.016242927503621867, 0.055225558593989386, 0.019480102890802008, 0.13338713846620054, 0.0361533209140743, 0.0726285596348105, 0.0003046031123367063, 0.06304395317490544, 0.008918169337595183, 0.011536875240234359, 0.025691654863617113, 0.060513959296288035, 0.015346861271668347, 0.02138673868631163, 0.0740378626411961, 0.08144604012129769, 0.032025328912441774, 0.06083163297584942, 0.03603920445687348, 0.10318641265433642, 0.04836254843300389, 0.03722972807384307, 0.008817998553445984, 0.012481775746921138, 0.031543398321035414, 0.0662859491703491, 0.03387040188235622, 0.03031077242696718, 0.015300264931283893, 0.008116479392253585, 0.03773472174220989, 0.03136569082045988, 0.026926119368703618, 0.03351198764698159, 0.03259399597863517, 0.02455751340265476, 0.11908231573479792, 0.12022760952071798, 0.17258738257711934, 0.1328128636364014, 0.11667293856941885, 0.14663151164929714, 0.08396548113875812, 0.10400740610015008, 0.060211239653008605, 0.17958224030031314, 0.33659559163835745, 0.173253741175417, 0.13008772035039243, 0.19184534678295737, 0.13848355370423487, 0.20908382661159963, 0.17990385933268457, 0.12124782413124077, 0.10787015164931936, 0.09935432594389686, 0.25401338183831784, 0.25821719739225607, 0.20406956664256512, 0.09218480783484637, 0.23595708782874772, 0.12935900219505833, 0.2315351517210084, 0.1325165714708067, 0.09722978026876528, 0.09478530095469567, 0.10531888733948432, 0.13953770600980328, 0.1182923105455214, 0.1647231682774521, 0.11014483523585143, 0.21326398537043603, 0.261330425498947, 0.1775303657256788, 0.15388359105394733, 0.11105257281733137, 0.11446442199690689, 0.13556607638395604, 0.138233732432127, 0.26785541085466263, 0.0975435622216713, 0.07717672404983351, 0.18996749674120258, 0.20458857588950666, 0.17406957884950025, 0.12321436417198951, 0.13900414109230042, 0.10184514591650617, 0.16288553785172202, 0.10915293523501005, 0.14676266590193396, 0.1394715926219379, 0.08644319334698301, 0.1812660096273307, 0.09897020179778339, 0.1601833159164075, 0.17092419037174794, 0.12277581713973515, 0.16462458808335567, 0.09383244845535486, 0.19983144567137767, 0.12362034480658271, 0.10660549370391716, 0.2163368866087929, 0.16364817838034323, 0.25603009297722773, 0.1967875025565586, 0.14484094966563488, 0.24931064386281276, 0.14267630694854644, 0.18517256774488958, 0.13873763442520173, 0.21923746402946212, 0.16233433759020222, 0.12479206862589046, 0.17416350122901703, 0.08838527220030946, 0.18395389039670268, 0.17959940066981703, 0.13242480945923638, 0.23384110701660957, 0.17752547808472188, 0.15508518464142276, 0.05744293114290603, 0.16054055803725797, 0.09631425157309541, 0.10465645877223824, 0.19649404491628372, 0.1554159660853686, 0.20899266214861026, 0.17124928744329562, 0.2700783528627888, 0.3222236289612709, 0.10059456866715225, 0.1992650615471986, 0.20422698238924628, 0.12490506659472182, 0.16640963423396313, 0.16351942964378866, 0.10668270004492615, 0.07264967301800367, 0.08905419719315345, 0.15203557247596403, 0.2219003396889856, 0.08297491413090499, 0.17002054369978367, 0.15667630329487786, 0.20740753430272305, 0.13074968160400469, 0.16946925150771297, 0.17643110616312874, 0.09649883279757154, 0.10771976092890387, 0.12613054680367633, 0.09459565588904005, 0.17542779145221557, 0.07117405744089235, 0.1771593033786743, 0.20223003631878286, 0.22885775103444056, 0.15290264611042317, 0.11024823412299158, 0.14749912154530326, 0.13991812995124248, 0.15089250800590362, 0.14281930492049263, 0.09784037532705454, 0.10063541647527488, 0.13469011612957524, 0.11911109765811313, 0.21270585967408073, 0.23033611686720004, 0.15346277895714008, 0.0989292007720759, 0.19757968343554005, 0.20553564442501915, 0.1631052978336811, 0.10339131819144373, 0.07074920806072413, 0.22764463548458394, 0.11961151395113238, 0.1390241819523996, 0.31098659000089096, 0.22567237276704083, 0.11208758824655127, 0.07884544741001823, 0.107469403395249, 0.11842723395074568, 0.11221213116040153, 0.1420151730698924, 0.18165214858468504, 0.3677326224503979, 0.11603076536689075, 0.2252209631185378, 0.11254709544441394, 0.17529705088705788, 0.10215433134186654, 0.1183805408917608, 0.1510384937207545, 0.06487196536674615, 0.10591616012877035, 0.1943991315220633, 0.20260059304775732, 0.12762175227004674, 0.11264786664997378, 0.17808885914423775, 0.22039194320959432, 0.13682647488049923, 0.10997674788438505, 0.073655737984565, 0.07923370077004356, 0.13590520818627652], [0.02422482439977748, 0.0468782760623482, 0.02467430350671132, 0.04191159015341152, 0.03194444151895662, 0.009142037466048233, 0.0304046469259887, 0.07626756154481443, 0.017280294822769302, 0.06273991969083587, 0.05901021297059714, 0.05049284742844682, 0.0903850834396097, 0.051973090176620794, 0.025612751637855848, 0.014920732524666577, 0.01992382676220469, 0.06235153609586339, 0.0472473887155854, 0.049644677013519316, 0.06720630421994195, 0.04628717028085263, 0.07472793932162947, 0.08666251665882527, 0.022590854618277763, 0.038907874315496416, 0.028060063562025468, 0.0088113795537802, 0.018777309150825587, 0.07599121064788873, 0.01774196047335863, 0.054313810542225845, 0.03863596672853155, 0.022663349518552426, 0.03189754544667179, 0.04351816463073896, 0.08164883125573397, 0.07042606451338337, 0.05879677321401335, 0.05982924523132463, 0.037296553923478054, 0.034785528381865834, 0.058500929209854335, 0.13543545839286622, 0.035686918924893105, 0.020625149613366495, 0.038959604402583455, 0.008447927332693532, 0.04194355900249174, 0.030696926706079996, 0.029588027842222687, 0.026303341597198483, 0.02299760134079524, 0.08304541720257652, 0.07215664181257449, 0.017336734435370853, 0.010475519792957893, 0.04411427296638008, 0.014504281383368277, 0.0357660060117562, 0.059207361867471095, 0.03597703642181812, 0.07819087890487525, 0.04276271766772674, 0.031558099548302354, 0.011089912732131781, 0.021890230822346864, 0.02467406027379536, 0.022646612412626707, 0.06691701409797515, 0.04227180469540819, 0.05807890286368709, 0.07137633529641936, 0.030773981744723938, 0.01964311682498984, 0.024669322019983685, 0.09421501744298205, 0.021516029430072636, 0.016443052652081656, 0.04164217618264018, 0.07870938253378676, 0.01982629227812492, 0.02145034888188445, 0.018409272851122004, 0.03222310983185326, 0.06153358018866951, 0.0179344036751577, 0.018863924966764548, 0.017008555775147774, 0.04537975828674051, 0.00720868626939914, 0.004284349589368268, 0.030121169496147387, 0.09027268301935927, 0.008975843309364732, 0.05828073638821802, 0.03789743115644782, 0.03942761134596602, 0.014014707149697408, 0.06004551568278863, 0.07483584280576437, 0.01834605910605, 0.040398922733842366, 0.0799747606018378, 0.0354050904993088, 0.035119883625978426, 0.05142706100858989, 0.02871929371218768, 0.049524493139958194, 0.04438848264755742, 0.08017232701663049, 0.004804182380828406, 0.04531184076181343, 0.061822242118538394, 0.016657595575276404, 0.0746699388048822, 0.033488169973415714, 0.004947538977684153, 0.031501489481137644, 0.029452323027315642, 0.020008864437019633, 0.042934489902108915, 0.03082110381294643, 0.014003641009631177, 0.06680603094038463, 0.06324095268463416, 0.03310214592925003, 0.04904132531655412, 0.07010179481679393, 0.011627531212363994, 0.033973911852245374, 0.011863115698009009, 0.03832695750339377, 0.004067740143997775, 0.06157742340057608, 0.025103764736183712, 0.018435076607631582, 0.010434340651808007, 0.04897221269446516, 0.03504532411874783, 0.036786550040086435, 0.018691292798687375, 0.03859731376231198, 0.05067866588492067, 0.01429108773253017, 0.024943112268022476, 0.04633012866120666, 0.023125641446019855, 0.03042824051883673, 0.04012835580074499, 0.11882694032523902, 0.02022523447991379, 0.009798960733948456, 0.08717188085880011, 0.07232041608902716, 0.04287066328669748, 0.075476139092878, 0.04720173753617753, 0.01934190062926181, 0.038094844353655656, 0.046850122331130895, 0.04620996010940402, 0.06747179965098059, 0.06932919514515708, 0.0496253447847501, 0.06160826226996799, 0.038892460626459895, 0.030765616064590794, 0.057436909691821185, 0.037050321773295446, 0.030387009666751952, 0.007002791521259614, 0.013319328183218116, 0.03849486482419795, 0.039791369044612494, 0.021135143920659058, 0.01106093354117606, 0.04408298210511285, 0.1132083748797736, 0.09922298016927897, 0.060065096890133236, 0.06247212216558476, 0.03628988757789616, 0.07349735696709926, 0.04820593324820361, 0.04836828643155675, 0.039887260270094684, 0.037815792996796875, 0.057369899981084375, 0.08069445424142384, 0.020902885214215326, 0.011945398329126259, 0.03242621123189888, 0.03298583846058577, 0.06303208264251871, 0.027406967860916932, 0.04257834328699016, 0.035684923265850356, 0.12054205797011815, 0.04886121804555578, 0.02743646416122154, 0.017925384905069106, 0.00913748020050867, 0.04695801049350731, 0.06592419479162463, 0.028892885405390017, 0.023517686941270387, 0.06784322972018873, 0.02821832775108276, 0.03338651776674294, 0.014153999171309896, 0.0020054940555823005, 0.024577856867484028, 0.030093469672025214, 0.05246800978878333, 0.013581653925470047, 0.07401390707180386, 0.03357580277107416, 0.06822153159807767, 0.043495718254557544, 0.0509898507997634, 0.03722755621457773, 0.018115939700134823, 0.03374898077679738, 0.08750902083251746, 0.06149213483196594, 0.024452362089387836, 0.04740425670940069, 0.030690723309113137, 0.036997155271350377, 0.02348127669744915, 0.015481551977685623, 0.04445505568817739, 0.05040959282327564, 0.019878688861706087, 0.06042773226997065, 0.10064525304422264, 0.033525639333792275, 0.1223408324163287, 0.0315621885425982, 0.013180978449752495, 0.014808052482323782, 0.04928218719038752, 0.03361650119205156, 0.047566299627144495, 0.05369871088694181, 0.04657557174082726, 0.017734456642140305, 0.019872018151105415, 0.03235153681147964, 0.011853761764453545, 0.03628437940572058, 0.03274793368614009, 0.05806656118722693, 0.032532980905905846, 0.03142266669460843, 0.03200044829188095, 0.024918580217467203, 0.037489148427642165, 0.12891652513175242, 0.03355078233946716, 0.03331602235595065, 0.05248641888160379, 0.032760034044904095, 0.055809003496242154, 0.025845334016447587, 0.04474691220469052, 0.01845703077232165, 0.012722505470587602, 0.04203191192279901, 0.054818635671249324, 0.07581252830042955, 0.03452209755778313, 0.03223498036423999, 0.017967962156680804, 0.010338662973334713, 0.03535609917655107, 0.036938315888326016, 0.05084777596376596, 0.05366420245639259, 0.040169471739641124, 0.05524803178324815, 0.0672419656128172, 0.0887701930778642, 0.012996384776347588, 0.08887005263879415, 0.01676681673064107, 0.018881079590608998, 0.06434516500561469, 0.04153023541514431, 0.06910971095485073, 0.0834624907903133, 0.02167552127502859, 0.027426610355295485, 0.06047677338844346, 0.05219194234438962, 0.05141548158961439, 0.011443770659576741, 0.04940588357708147, 0.04981634199559208, 0.05186796759165103, 0.11587775462577421, 0.0059500718001096005, 0.05431933020572028, 0.03467073393685203, 0.02771460004301081, 0.01878551203727482, 0.051347219325121374, 0.030347353125351573, 0.019773110454421372, 0.0022491824347525835, 0.03749773244283373, 0.016593820670799866, 0.03710988510940825, 0.028699091973624406, 0.045376517734820807, 0.00928171061640305, 0.026436150599751743, 0.038088757785097245, 0.04917563585143897, 0.015857952999912443, 0.004877732567218763, 0.08133068260165953, 0.0901757039490246, 0.0018367159082704496, 0.09471735661669124, 0.06570205227622102, 0.036824735692672195, 0.05835976218804718, 0.056272728008127985, 0.060529702403132, 0.039196088083929596, 0.04097008724666892, 0.0399999977690318, 0.012897349717546136, 0.042753053468561945, 0.015990627937078956, 0.025759480457993287, 0.03323465998795244, 0.05836779461993326, 0.04224837389624408, 0.04010451514454138, 0.021719485145783233, 0.04277078840400904, 0.03822999758525722, 0.07351699180059856, 0.025850480212078943, 0.030037424594704664, 0.016554483971107873, 0.02587579175709717, 0.02151939064084042, 0.03276477612915539, 0.11454627083073701, 0.19735662927550657, 0.1710829850766928, 0.1718602272411508, 0.11736770370794881, 0.12281740805314434, 0.13820353324615187, 0.17478720405169074, 0.0839444826687536, 0.14868779889037534, 0.11604227200751344, 0.12007414678772611, 0.23091144889833468, 0.32503268951850556, 0.13150866023234783, 0.08188063413986275, 0.2366828182411771, 0.1118355299977045, 0.1513109758736626, 0.25159424471278347, 0.16042530776992922, 0.1235739352001298, 0.22358777091628124, 0.19969869795585835, 0.10982446492679658, 0.16773323498425946, 0.11524916416214359, 0.13379524882522323, 0.0945841032831419, 0.19616830433087964, 0.13529927860344612, 0.12621257949860828, 0.2458601072430611, 0.09659722913056613, 0.10364931362170367, 0.11480617381992841, 0.2254025106348338, 0.14040700129924283, 0.23907714943972327, 0.16672661077351342, 0.1905850095734481, 0.18339622435310196, 0.18775708793151766, 0.23768441691513986, 0.06379596423357725, 0.10235614954463898, 0.08602295581611895, 0.06603189143201997, 0.1659472542063844, 0.20308629279175114, 0.18180253164422128, 0.13613610708665463, 0.09177073731177277, 0.19357883521626074, 0.09507006349702997, 0.10525152522830233, 0.1462950917982286, 0.13926271108850358, 0.09849415476163549, 0.1513370535066051, 0.20455411725467254, 0.09027053031229204, 0.20524647687712025, 0.11783956024315088, 0.09783164192471774, 0.0889425092346726, 0.19581165975861012, 0.1753642214762588, 0.2004781004882628, 0.16301509864147634, 0.08328127269182475, 0.17416563095344653, 0.14391789032566932, 0.11959049249849013, 0.0904786304360436, 0.2853341052128423, 0.168786728454213, 0.18069643857738665, 0.11129507794976236, 0.18891244045188352, 0.1517010984882232, 0.1379239111537895, 0.11039932198341816, 0.2691701403067958, 0.16489844919452745, 0.18180864502585706, 0.11043008807445727, 0.10198478076246478, 0.14930967842378925, 0.11271745807701543, 0.16653778542193676, 0.19109583700135832, 0.1854667301860548, 0.1804999370248087, 0.1089361170306802, 0.1807159584976973, 0.1121317302327483, 0.19292338571000486, 0.08043531734015673, 0.11678635022572934, 0.15385120085650875, 0.15023878985835662, 0.11408359968974707, 0.16381003743698522, 0.10524132859803016, 0.1833267708218867, 0.15213177779749518, 0.15634428078849472, 0.06534799708113556, 0.21912575308834353, 0.2174561257444082, 0.0946735363874224, 0.1049084480731718, 0.08670602279204516, 0.12721580993984977, 0.17600519192074576, 0.11357771352894845, 0.11398200110922899, 0.1986898214466149, 0.18021626998820614, 0.11065777706643266, 0.19034827308308697, 0.13023453344020153, 0.1083197916347173, 0.16732619714833077, 0.22175971658960467, 0.15740116036707358, 0.12676592480631607, 0.15157323841366077, 0.19573601623696668, 0.1563928201193771, 0.1522221302072848, 0.11421857672112604, 0.11223268529940998, 0.14660240030817448, 0.09759742586362748, 0.11995268354733145, 0.09512471620954814, 0.21396932252232106, 0.1117415156876368, 0.10657475059551579, 0.07627486236273281, 0.16240497089682088, 0.16302380140029615, 0.059434108571299625, 0.08144070048846545, 0.17256439993939093, 0.22640930338492318, 0.2094030707714058, 0.1859026035714534, 0.159046747871945, 0.12849172171685966, 0.18166802192647613, 0.19922556205382272, 0.2839011837157511, 0.17817296027656526, 0.22279643273401648, 0.13778639837138115, 0.1372703768673443, 0.18379219987940404, 0.14803703784221603, 0.1189389730232858, 0.0992397191904245, 0.19588695087980842, 0.15730248824242624, 0.11118582615088071, 0.12311920073003539, 0.17402687710860085, 0.14851441787135217, 0.17447019686862347, 0.15018591446982277, 0.09294678186697346, 0.15928058854995236, 0.14660457599787943, 0.11705468784296706, 0.18611959031512662], [0.036396871756521926, 0.01668632387243692, 0.0929648845246242, 0.04007459558065861, 0.017348771591881113, 0.05631356049449213, 0.040590211058095585, 0.04568225959496153, 0.009714723621014386, 0.03680599335160467, 0.023264613625923955, 0.018666004236306877, 0.007497962506022305, 0.04855736459214841, 0.03498137875970814, 0.06281356372299694, 0.05745937522020071, 0.06399861747218717, 0.05813951190981654, 0.036832496163345156, 0.02653632808717028, 0.018354026420462518, 0.05640545274100958, 0.018215799261064782, 0.03144558038442366, 0.03161275226082052, 0.03638669427844786, 0.043819941985871524, 0.03595984923923689, 0.034170455539659146, 0.037079651449476524, 0.044377818703651435, 0.06111310517054893, 0.03825364288904014, 0.07736309792005247, 0.060099532542329644, 0.02525914843464571, 0.035117807527703625, 0.048446546143461625, 0.055356969486080834, 0.012431061683943676, 0.0254414122431509, 0.04368489983701899, 0.05692695943458427, 0.04285858208013158, 0.007377315149266994, 0.03085871681480879, 0.05458913105089338, 0.05109614549925731, 0.033903263223868225, 0.057163875955607624, 0.03299353764422479, 0.028299429649186712, 0.05617779439255115, 0.009631456566914436, 0.011750178058601677, 0.04884313070966352, 0.026068583528901783, 0.018180107224672552, 0.06802557396792597, 0.06400100000563168, 0.014828961894607112, 0.08636321376768813, 0.006898191312493216, 0.05321645087772801, 0.025009472719243458, 0.06234494773971458, 0.05535194011885793, 0.03058126658171175, 0.04984389051734921, 0.06647000179415749, 0.07204949675548462, 0.07646958659132642, 0.013080316411721851, 0.019461737848037196, 0.023710291021533554, 0.06806199378784626, 0.0716981688334096, 0.07276788804559939, 0.03113067994314817, 0.009829843653396014, 0.011654172877540753, 0.08640426841955032, 0.04034612778454058, 0.036214757335161975, 0.009678483831756299, 0.03471594461570344, 0.1236308478720246, 0.03547860812696238, 0.054012692022708156, 0.022059001907285665, 0.014724519212670146, 0.061134996132985245, 0.04629905613499784, 0.06566389343671261, 0.028620016378080173, 0.02834672791763179, 0.08279512861683484, 0.04707051433562752, 0.015353104888251232, 0.060799729244242755, 0.027782063660842758, 0.029133006089156675, 0.006339989486150444, 0.0376317786773847, 0.05967893111970156, 0.02334359154525784, 0.06039691638321646, 0.018514002816030578, 0.029291073010573467, 0.052926191654537, 0.032642439548527045, 0.046891701753221215, 0.04697015298710716, 0.0783858942468801, 0.017115668273500858, 0.06320427239481961, 0.040769839524141246, 0.07431913182259568, 0.04304139747194225, 0.03576139416245203, 0.051466552841086546, 0.03780101133029788, 0.021527191331129403, 0.021442693748301076, 0.06233527587967054, 0.04153209317836069, 0.041316906741309556, 0.0507468055753458, 0.060049227378781767, 0.03735938462458792, 0.04481027916734738, 0.032614638217754906, 0.045040745228048296, 0.013541012003477062, 0.038976209358342236, 0.039710374398817944, 0.08452889284179096, 0.061660023000572, 0.05341136662830269, 0.04856269656410141, 0.019694029113217708, 0.012767730513587596, 0.04083652364751024, 0.0064543568371464655, 0.01748391907782324, 0.00285666334562965, 0.054067494122371565, 0.008058833191171288, 0.11653125826870242, 0.02205720734632304, 0.014567565033963371, 0.008051051653080411, 0.05905625485484639, 0.021762744215647542, 0.02029576244944286, 0.03165409419565432, 0.04955656924134782, 0.023154930902584907, 0.007568475153792891, 0.04750159967149939, 0.030091479758641897, 0.004774725342529916, 0.011537497686672837, 0.05187591958430506, 0.050496608920155034, 0.05436878884211183, 0.023482990819179726, 0.07097400124034575, 0.1112456193133708, 0.014218126476231604, 0.06657957534996733, 0.07614727807982315, 0.07660267904641167, 0.021140753599484603, 0.05764297202169415, 0.023328733269966418, 0.04664023722251577, 0.12110670307470907, 0.04115055840943129, 0.02666301030154911, 0.016816639258796652, 0.03556504199701933, 0.09136986648363453, 0.005452118958571866, 0.0478897036443795, 0.04537308183048041, 0.01625440733116721, 0.08335863991129784, 0.009864384642682009, 0.0310715705141305, 0.06110641339253034, 0.021854538785954638, 0.041689734920979514, 0.07716664999362922, 0.032654865494658875, 0.03491933712916028, 0.026578449516467033, 0.11333441932595546, 0.02230757637129676, 0.06900126354828959, 0.08456331317222888, 0.051336134032857035, 0.03286640152275082, 0.05654258247945578, 0.04153677780601767, 0.06869303573283457, 0.006436487836312624, 0.06748032620957783, 0.031347555604072354, 0.060583860988939, 0.02694800075504088, 0.029092300007300034, 0.04273018957446179, 0.04749768496220631, 0.019913467338248607, 0.01351007066982528, 0.0064730608738177734, 0.028017093690352577, 0.029838421765053948, 0.028032396296640078, 0.07305797489900744, 0.0295328886638726, 0.020923123341955004, 0.0377850690405936, 0.013196799122998792, 0.029961298437668916, 0.027117587723619035, 0.013754928649793711, 0.05125220527031249, 0.050270440612709334, 0.029634814746978305, 0.016708276121907176, 0.05308016000555889, 0.05326811584734148, 0.04422549744166675, 0.1213249998287328, 0.009315154184737514, 0.02696974041511215, 0.026875802713836876, 0.01530226729359598, 0.04672207839546665, 0.022230839259141398, 0.01662552138910659, 0.044280295710890524, 0.050497551208301905, 0.01693452678380474, 0.05366881047525714, 0.07265331959652324, 0.03550173249095678, 0.037141934397720525, 0.022992422586427103, 0.07158805135517352, 0.032918503162481134, 0.07961767169857219, 0.03164554465441935, 0.012568259412693161, 0.04674385444471433, 0.029117646026274854, 0.03173429019478781, 0.052573580535188805, 0.021219877075524102, 0.019893271345344764, 0.055916313262235735, 0.05766405476137035, 0.059227969632634235, 0.11574163612338806, 0.04124939524298234, 0.07618898390642098, 0.013270593499915015, 0.004917262225306683, 0.029023346348455357, 0.014986632365523087, 0.04739422861847186, 0.026685912500045476, 0.04316027899603209, 0.10040575097645484, 0.08916660527428312, 0.04415343155062968, 0.020610722262532483, 0.0018904345920271873, 0.02842415833935863, 0.008296753287375455, 0.08144746504483685, 0.02083267134073521, 0.040069485774203654, 0.12270090140161977, 0.0402075884443137, 0.05902098799725214, 0.062215819789637486, 0.04199799337995149, 0.052298872896860686, 0.055712449604705463, 0.04439294894015597, 0.043774593411193746, 0.041426246640302485, 0.035248069287908655, 0.056964340694849534, 0.03203968156970317, 0.02716263943922616, 0.03890797773736619, 0.07726451006507681, 0.00035126831085841747, 0.02168112137775508, 0.05481679706023105, 0.05376838658365512, 0.07945706902612602, 0.032660477088704225, 0.05601129667352765, 0.0421063105515655, 0.04194970685808409, 0.0179927853206473, 0.04417846730399517, 0.044253306433318124, 0.06104731353961172, 0.022072935131408518, 0.050803484590423685, 0.016691014245753328, 0.040117446708703236, 0.06514221054291533, 0.031002787309848977, 0.011492665263734037, 0.044882877489491824, 0.08256357088084183, 0.04857597669826881, 0.08112334856583227, 0.013449612926060875, 0.020671038280030894, 0.03712918286422088, 0.01925408205528173, 0.05492564283251282, 0.033371866335191076, 0.022717002486329407, 0.02522481045865965, 0.011234659299765144, 0.011080496553932468, 0.038274338754314574, 0.06948987442639566, 0.09548626374453308, 0.1307485937591522, 0.04345749812801519, 0.057128662724168076, 0.026321735368260456, 0.03304238341027691, 0.010446179583067856, 0.0798306518024014, 0.009485383709562163, 0.05831170166211744, 0.03179604454236406, 0.01987225755358175, 0.06103881762453145, 0.055939993039975246, 0.22536388448169156, 0.1065285784763194, 0.21686842905417567, 0.1255064302935235, 0.1264658481663754, 0.1053724675289085, 0.12982057016943732, 0.21377234599523007, 0.08956378355862633, 0.1251488051287109, 0.08596261107032338, 0.08192721228565901, 0.1187618611560714, 0.09184647276396714, 0.13571385474454972, 0.17460608554463233, 0.16169200350921, 0.1475094177670056, 0.20861620654261884, 0.1069277409283865, 0.0895123560762694, 0.08456439335620211, 0.18821332393394363, 0.11827822218859389, 0.1795633332503419, 0.15703700813314608, 0.12692905556891235, 0.08800978186510264, 0.23798720550633248, 0.13503156151742707, 0.2347973992507304, 0.10949041994829332, 0.21082920472948782, 0.0795516885456539, 0.16919718304228398, 0.15396724785527877, 0.11810332431548065, 0.12652882059375126, 0.08567894403372081, 0.10788020272288593, 0.09593876123788858, 0.18543700597459273, 0.12592561062305205, 0.1148570190754629, 0.1097606651244625, 0.15014336594650823, 0.14570088336063972, 0.1178382195892834, 0.13676927875607245, 0.1400142586639812, 0.17548722455338125, 0.08675905905904309, 0.15578207950438225, 0.17601789365853035, 0.1699369635072447, 0.20387003138180704, 0.1276570536015976, 0.2642476883146071, 0.12391994647201031, 0.12135383537820271, 0.19474843697201824, 0.08797682476260009, 0.11280873745319345, 0.11485298945298118, 0.2021294642960833, 0.2036009046940073, 0.19981520460738292, 0.24756359567324965, 0.11459103334815272, 0.0836530781441158, 0.13534597932331024, 0.182948476604877, 0.15300671149405742, 0.12557196911544571, 0.15569826948546595, 0.1456463991874649, 0.15749541982527704, 0.12752490343465922, 0.13420836939927072, 0.21148902093691213, 0.10382608074935214, 0.15483116520748985, 0.12326317929452467, 0.0989692365269988, 0.13418354815052402, 0.05611273437558163, 0.1556197454732272, 0.22833149459573532, 0.13170238854663988, 0.2005802200085694, 0.19171695044684797, 0.1640826115204442, 0.1519224366113063, 0.2093281167288942, 0.24571501019020237, 0.23348050943065077, 0.06120881253492929, 0.2535091580883149, 0.1707870299897848, 0.11788808425227482, 0.25384835117766935, 0.14002005028868877, 0.13127725571393967, 0.081304099350687, 0.14968642514319191, 0.1497845916498092, 0.2445341009766825, 0.28466668941320916, 0.1398512657972113, 0.08651316015710754, 0.17415561052339693, 0.11006334646334572, 0.15653895905181286, 0.10574646399266298, 0.1078272200820427, 0.1615808594731554, 0.20595762097547132, 0.1547529629521793, 0.17406496700019608, 0.21391224897196218, 0.08406804499006079, 0.11019020296272733, 0.10139722962893787, 0.09509450170181452, 0.09328442745872083, 0.12042139146116473, 0.14466831941277752, 0.14511085776311738, 0.08716962856030272, 0.14791768134361313, 0.16189916900569395, 0.1284502227340014, 0.16931799510794301, 0.1210368358560147, 0.13895118909497417, 0.1879304689505408, 0.10688069546895643, 0.16396892407248098, 0.20659218692491133, 0.21007352027921908, 0.11257239932855291, 0.10289437227672148, 0.11814611032605173, 0.16413056862450418, 0.09251094678597105, 0.10033994402375915, 0.18979767037014808, 0.21801134030665123, 0.13395899245815893, 0.21334203440816174, 0.09184269595050043, 0.17553770974759134, 0.1108992173366489, 0.20829516973706985, 0.17995422195282676, 0.12964257730111, 0.13101482463459815, 0.2246698701093274, 0.0820227281280583, 0.09254657753532933, 0.13192600961173737, 0.15438343278102337, 0.1430838197589882, 0.16036907691628705, 0.1505067674142699, 0.105414510434193, 0.09454088826333323, 0.07412158072956147, 0.15790936777428274, 0.22399585063178695, 0.0793965710627456, 0.15346239591317792, 0.1342066993275958, 0.126797663829019, 0.14056913614753755, 0.13463837455116934], [0.02107577210652732, 0.025273575785479722, 0.00530733073490762, 0.04557738981900677, 0.028399105349014846, 0.02832781895244074, 0.07351983398679765, 0.01047649463984154, 0.05119340036124472, 0.023775197820918217, 0.01265791180964199, 0.005980568323960348, 0.054288361101381244, 0.02965537080120656, 0.027140673783217228, 0.08748484309762718, 0.0433837085391485, 0.0476648606690428, 0.0629607598567682, 0.06791182523292881, 0.07600012025044811, 0.016722636440047817, 0.06689821430031331, 0.023251145800215103, 0.04169978216410645, 0.012971522350374971, 0.02327287588418732, 0.07516531423935968, 0.008703706853632486, 0.03503256875480856, 0.0062587750688826126, 0.029913812477682388, 0.031516839967920415, 0.022762278282654383, 0.05577577443252649, 0.002665691272047679, 0.04661487588178247, 0.03112622705708829, 0.03604999480528697, 0.0558518584547264, 0.04302602208730194, 0.05465298830982178, 0.02574794317385362, 0.019198351074010134, 0.043557729241588426, 0.051076162095752456, 0.06491166404298236, 0.07509350115733762, 0.09388354651990438, 0.030817292525523135, 0.043228119912166754, 0.024558499740857272, 0.050793345416745836, 0.0385938816884112, 0.016401042305533926, 0.036232840840614615, 0.02162213260758548, 0.032633449506735614, 0.1132487706960209, 0.04158080487902607, 0.013655851456156422, 0.05370214296084258, 0.014345720335240326, 0.06007926568629281, 0.0312658274290903, 0.0318387903333191, 0.046467924896146984, 0.05921711033630756, 0.018602137401279424, 0.023931797683960008, 0.026366806236065687, 0.029122951185150497, 0.034056515282680916, 0.08800255765597667, 0.03153675059307247, 0.02382385398020908, 0.029256780999862862, 0.0323858575504874, 0.03072889747038003, 0.02594804150923606, 0.04990781672419079, 0.03217959986819375, 0.047014731643421036, 0.0368637525506558, 0.025663175545031988, 0.02657489869893799, 0.08488928358401023, 0.04066580095358434, 0.05456168212056641, 0.016516258098906087, 0.04703323649723203, 0.052463344313324466, 0.058903918271103216, 0.09251996364083984, 0.0611317670723844, 0.03945988279977634, 0.029351798885111368, 0.05735762342209778, 0.008194470015775052, 0.025762778466507315, 0.017690431484351718, 0.03403109648535329, 0.006697920607327814, 0.04532401006849063, 0.0386741332289192, 0.05134666008093665, 0.03149054399991949, 0.004006828732540711, 0.03063406536145316, 0.02162841261334477, 0.03407282529458885, 0.02972984986920511, 0.014100084776028752, 0.019024816837402123, 0.06767596208280133, 0.07556014829465459, 0.0557385693724838, 0.038654460091023676, 0.024764282448637872, 0.03984648524032485, 0.09269224915413127, 0.04993814231467344, 0.027196358799213366, 0.009569785531399953, 0.02367168402058944, 0.015689218304150047, 0.04349065824381767, 0.019970757308446115, 0.030464909317332412, 0.04227977584026033, 0.08257107854249977, 0.03564984026935793, 0.023032940976742296, 0.0244327942885819, 0.08682802229398683, 0.05195276969442925, 0.0422458726191713, 0.05413071552832281, 0.027735711510984168, 0.04176284652203322, 0.048712581666486884, 0.029533677734434608, 0.051490037266405365, 0.02814099309034646, 0.05588602214570969, 0.07399408837720271, 0.015162179498152148, 0.049154752294623086, 0.043683417456885504, 0.04297092504378769, 0.030171290798593434, 0.036598961920507496, 0.035058964314239646, 0.03791309765449936, 0.018283988747204986, 0.045091000595881094, 0.10598207433377543, 0.007794801945677929, 0.0397252748089452, 0.03562483515950941, 0.03734551843315844, 0.0330417015920243, 0.03476174135181693, 0.016768398702204708, 0.05608937635477032, 0.005195313837424282, 0.02485343018516658, 0.04572805250063539, 0.02876004192888016, 0.011411473350298983, 0.006016575892816388, 0.031228459575363708, 0.035570691895460894, 0.030787307844166795, 0.0470490868563854, 0.07385151175361487, 0.041395798475751956, 0.058422884002568266, 0.038352851275234454, 0.06209540225925946, 0.03190365882830755, 0.08380296324650127, 0.03416624588651523, 0.03547894903608868, 0.023885899441196554, 0.004550939568528725, 0.02018021915348307, 0.05372877217709057, 0.029662370929614674, 0.019629558983949885, 0.05242987010147303, 0.06390907328515764, 0.08706694213493217, 0.036860458372581395, 0.019742742729102893, 0.018489823165920474, 0.07658470662370806, 0.022509494165499366, 0.054319448949348544, 0.02784559341718353, 0.05025800317525864, 0.06824314293842162, 0.10595739864173437, 0.07072136076467653, 0.02103479406345756, 0.014470213453375525, 0.061623373354274424, 0.02936041162860009, 0.022789976191556743, 0.07025428461812197, 0.022564884237644654, 0.03418720222168392, 0.015230340255995192, 0.02047590036395817, 0.052031508211286805, 0.06100689091028706, 0.025523613477426193, 0.059621413238346584, 0.01320458927957882, 0.08110105540723571, 0.024282935999273777, 0.05486309941437456, 0.029481348183546818, 0.05842081556517271, 0.0532572910249714, 0.0439139524654996, 0.039912430088846915, 0.013652871374130971, 0.01678719083898731, 0.006727798036374753, 0.03345458084837564, 0.1010463230552212, 0.02642057411703131, 0.030751091037546436, 0.04513829120344693, 0.07135228013559695, 0.033242677098080035, 0.056822633581055756, 0.052660799645368135, 0.011270368573135667, 0.006377983137950182, 0.034352753822120934, 0.01707563443379777, 0.06714481034225996, 0.02927182888191554, 0.04076679049420261, 0.02178423872758304, 0.04740954271607822, 0.041366039790333285, 0.03709046478052774, 0.0357532276651792, 0.03619499992759478, 0.027531958936202913, 0.04461553195611604, 0.027809183173362288, 0.021243215944137306, 0.05065404764947392, 0.05721777407152038, 0.03171950086740957, 0.03682133809272801, 0.023468458131256125, 0.03745947401189516, 0.021553385792480364, 0.04230498396340878, 0.09568719328531335, 0.026874933204042818, 0.026356923701842467, 0.027002538554370407, 0.025655018623858213, 0.04635025379097751, 0.049719508481963035, 0.06751893704096157, 0.04088184157867105, 0.06058883289956759, 0.007579034718219192, 0.012466653171295842, 0.04604828491386387, 0.10274503875764147, 0.03971657588056499, 0.050293913546709285, 0.0973050790508428, 0.05991394008179346, 0.06803366385640637, 0.06031856474076068, 0.025120371607162302, 0.05082840926104015, 0.025445064567329905, 0.054061553110518766, 0.023503146592467546, 0.057576962055698525, 0.06768894727311789, 0.01995862630616513, 0.07981582800106657, 0.05508412344140872, 0.06718487674069983, 0.06705632718700556, 0.08397942393898003, 0.0733877987330479, 0.05643321193694588, 0.1137228335644449, 0.0028954589957251187, 0.0278313422665721, 0.019345248433490916, 0.0014551191340996736, 0.03162985134329046, 0.0478474309127177, 0.03105737298967377, 0.021470249930937445, 0.021875294023043206, 0.031732633529651555, 0.04069080989387247, 0.02607966882116612, 0.05639000457801646, 0.04821330301403519, 0.02969098431358655, 0.03389104029103633, 0.03148516223225142, 0.01852480274054312, 0.05842559978425984, 0.039026188934522296, 0.10824237078908952, 0.06691641654939422, 0.01914340341764112, 0.04875508039408634, 0.012483461140354556, 0.019588010205376535, 0.020892935647298733, 0.012153943741483795, 0.035418002911272554, 0.002493530966251368, 0.029467704157615383, 0.0053750462041446765, 0.03693887513251074, 0.011871099291789916, 0.01376678386042195, 0.04120492000853823, 0.010251324161917213, 0.007549540333134393, 0.011440984972362078, 0.09698408821056928, 0.026471850297023213, 0.02255888576919754, 0.019936857917796702, 0.009554390994561537, 0.007214771880347643, 0.0327957222508567, 0.05700415045383477, 0.005390065357900195, 0.051820044961547664, 0.027577575641654195, 0.015121428408629954, 0.032288717601688645, 0.10435747763802929, 0.22981131599555094, 0.1131694499523409, 0.14780102147450372, 0.11869770895329215, 0.12246528339962806, 0.1723642671300519, 0.12745387176231993, 0.10178631036392144, 0.11804428191915636, 0.09570158041653135, 0.1600486223375605, 0.13619393140317934, 0.09707084766799405, 0.182704140522307, 0.20927524134036035, 0.20814451088588085, 0.16792160068308154, 0.1876826241852776, 0.16672169248903954, 0.2082072688086379, 0.07665140223839591, 0.11560013202289421, 0.13233370628328095, 0.15234409140483027, 0.16169054794215387, 0.174792229588474, 0.17228022728475834, 0.190997701138258, 0.12601977048982538, 0.08128821068713743, 0.11651338543742897, 0.09862791371321487, 0.12388294442526757, 0.13611738389778522, 0.1726133989230279, 0.08822745042702845, 0.1201463046093141, 0.14020067849947562, 0.17496767904489272, 0.12350285756251506, 0.1950475330194158, 0.10503022540961543, 0.17388079946319904, 0.09303230792284013, 0.12424189492218918, 0.16628096210620097, 0.10134164228915207, 0.21757241789131396, 0.11073920455190445, 0.15664035844947063, 0.1114835432400146, 0.09906939486221922, 0.11975333980855443, 0.13135299116613405, 0.23835252219390488, 0.12081698394350468, 0.1311425468133342, 0.11498619682125508, 0.09387754805145726, 0.11348225131270387, 0.21288354610723836, 0.1501134731957028, 0.22326768405975836, 0.10137616221102015, 0.19091292584855712, 0.16298730497158345, 0.19102587785211303, 0.09824770427639447, 0.09749286252284244, 0.06216074955920058, 0.14115703202063037, 0.11909535455126917, 0.16072513926173412, 0.19569025014437016, 0.12293766087461865, 0.08294586407681627, 0.16659914906467163, 0.12246260209189308, 0.1747425258039467, 0.23917488693710298, 0.13014238838466907, 0.13361915585494813, 0.0958682505053378, 0.09785349841319746, 0.12394491327746261, 0.1741826993923995, 0.08032357575552118, 0.21150287180658311, 0.1698962842384654, 0.148261746752166, 0.15570171688112522, 0.14862816660634934, 0.21303397513205008, 0.18413212841316579, 0.20537732469458736, 0.15942868866747426, 0.13262195452567072, 0.11137059123645868, 0.09688189208147027, 0.10752839216541861, 0.20892567542051116, 0.06571763450460089, 0.1800820513838722, 0.2153039242952101, 0.15438150223945418, 0.13268250611520585, 0.15953345885199888, 0.1661611459548435, 0.13981362023661215, 0.11584253756389504, 0.1372932982180388, 0.10923680654096027, 0.20915021579111778, 0.17695388456265773, 0.2498394743569436, 0.1808654682169999, 0.14036771631048572, 0.14132851314160133, 0.16260049185685574, 0.22264208133903243, 0.12792457916563557, 0.16158249890131338, 0.2246358864490063, 0.08143824134622851, 0.10256076396833505, 0.15336994442247576, 0.09779703007229874, 0.12109177202106484, 0.16650168735894466, 0.22091813836126561, 0.22002022202697494, 0.11904666200280191, 0.13611136244670038, 0.2382400604866205, 0.12543970403531868, 0.13578433483358354, 0.12843672426477556, 0.17104578384708974, 0.1546418342378832, 0.15506319791799592, 0.08464778202676004, 0.14355159304555387, 0.15021769179692193, 0.16048627304694346, 0.2149411510195463, 0.14272351328644062, 0.1337922917258355, 0.11443035406691414, 0.11106321377859962, 0.08291909696474191, 0.16440740215682215, 0.12610386396127363, 0.16295479220007697, 0.08412428350458223, 0.09744144270136472, 0.19289424372536523, 0.10569700535627143, 0.09033832909359087, 0.14536291601196413, 0.11859031108718728, 0.13548810395502275, 0.11501636536371325, 0.17833466611562238, 0.10844252658106628, 0.15780013895803885, 0.07183202737641912, 0.11709175883762299, 0.06435860218780656, 0.11983780866308559, 0.10615868058295981, 0.14604260454014426, 0.06815344170336762, 0.11404194748930394, 0.1626079841967552, 0.10990573153380426], [0.011989849623322729, 0.057236504921269034, 0.08048637710031002, 0.02675342208315288, 0.036418303066203674, 0.013747575163330524, 0.008530910934261497, 0.04834378310929864, 0.04193807764339351, 0.07203370002248595, 0.09659983382950868, 0.07285211941287403, 0.038796347235479665, 0.010038816159771336, 0.050113679871203444, 0.03557216278427551, 0.025066879517849416, 0.03956834169765634, 0.10055454823398784, 0.03792805169078131, 0.04713376638509574, 0.0268869569540144, 0.011790619840124443, 0.06740809177919742, 0.01291746718643774, 0.03260983484646967, 0.0562679514499201, 0.08389037387866168, 0.041587557944078604, 0.09089501454464852, 0.023125536108930266, 0.022202281416544033, 0.026583925129905827, 0.009818255615931366, 0.02608068005722617, 0.03835433748580756, 0.05745865126711227, 0.028523650178084933, 0.021561753387833317, 0.10580032763461913, 0.024576596652848587, 0.022354234956325065, 0.04158113429683351, 0.06106098820906013, 0.047200894839460814, 0.023100379696716706, 0.01793080497713339, 0.04090421900693928, 0.027113127176679915, 0.010954406142475144, 0.038239956728272864, 0.04049552259065452, 0.06956440712054891, 0.04436425894739167, 0.016693710875246796, 0.025089661057497707, 0.08745766995895295, 0.03321878281572173, 0.08710101006492492, 0.058931007140105775, 0.023444460427028038, 0.030807676206853603, 0.04038411808470565, 0.014083151360072437, 0.001899698510251549, 0.058609774982136105, 0.06076193429649838, 0.030313078351619265, 0.034783019443913814, 0.055580613533816034, 0.028596643035510377, 0.013486989398276614, 0.03125083508841213, 0.0773828246841027, 0.03425441111528105, 0.08469524883454846, 0.02559817681509641, 0.020876035747689106, 0.01793170321522461, 0.045611051722399654, 0.0956006866369036, 0.007650713734854494, 0.026178427130704927, 0.06493722839701561, 0.029965465955977, 0.03532201209436021, 0.041697606474401495, 0.020017170745338646, 0.03720931566110061, 0.03178593601220318, 0.05840947363345374, 0.0483115422990053, 0.007764565412916484, 0.054053953518309904, 0.06655876074106463, 0.03902761385806146, 0.039228256115870136, 0.009773635782391555, 0.04409006458797282, 0.09559815854675348, 0.09399243059658235, 0.06185848956867572, 0.05030621691877323, 0.018437876658994826, 0.037390732942449476, 0.02687977487972427, 0.06639607430946443, 0.03913376300084976, 0.0414445408199343, 0.13171069293973908, 0.05581274583575226, 0.016072313977225174, 0.016359282852781397, 0.08455499345737119, 0.07194684863451027, 0.011075588803167545, 0.07263302592740906, 0.023873272396984602, 0.04844484542826972, 0.06567406708434706, 0.025210030707380465, 0.04809202746518197, 0.05155069227781027, 0.08133608352152571, 0.025036768431985573, 0.075681351065155, 0.03437478268038362, 0.030326710886231838, 0.05702789151860822, 0.009385233035220975, 0.0351045044108985, 0.013810406822050291, 0.022253101774220987, 0.022333841695780718, 0.10080577144699712, 0.04765882772663909, 0.045911679945645795, 0.03075669880115217, 0.05092651065018389, 0.08191709226417927, 0.09679713211352788, 0.028241172492984804, 0.03177454236954932, 0.06436107665180199, 0.060585764717430844, 0.004998244422172467, 0.04297837524885132, 0.0017411561355167521, 0.03763585426514188, 0.03135838425688205, 0.056470861327984644, 0.028660333670315244, 0.052513683950828935, 0.039616904011176485, 0.09029247873132268, 0.023679185936587955, 0.06667669231612837, 0.06385083528115384, 0.014995670287809787, 0.030270305747586875, 0.05202436827183251, 0.0318409028207703, 0.04772466149241213, 0.013710838374531558, 0.07714748247376374, 0.051440107485940384, 0.03162927294690763, 0.07851006177764747, 0.03323711146931014, 0.024018262197533925, 0.050123520270590825, 0.05409139223516949, 0.08253216893682558, 0.015237710979436676, 0.009935317681201044, 0.017679533883628827, 0.09772916234308675, 0.06433615581162515, 0.06328000784701397, 0.017341815513528643, 0.016644005175499667, 0.014722804133329662, 0.007103163403488937, 0.01871785306702218, 0.02349860369107656, 0.07470781419185862, 0.08369449285730239, 0.01918735196663728, 0.035756843600181804, 0.06711109481271237, 0.035389450814334616, 0.04346208699468163, 0.0007532839017878888, 0.018053108999024958, 0.05503399447808343, 0.04981134710232577, 0.0054742517175092814, 0.05501755806166799, 0.039221158311251676, 0.0637426560053662, 0.04063396616989086, 0.03239272552872858, 0.0348171831348971, 0.15531789150930222, 0.04170873390150167, 0.049187992849657615, 0.038571201655412876, 0.02184351286550443, 0.02541706022325783, 0.020122603595917745, 0.044620239566410744, 0.03812432724742159, 0.017367623100477843, 0.0804239102909642, 0.08395523854321049, 0.06908403168762885, 0.03106228552848822, 0.09251724402870863, 0.0404592789709568, 0.06450168442942443, 0.030743347803851774, 0.0070103508938524515, 0.03318868322117675, 0.04659057940326391, 0.06728609227725575, 0.09991366205917251, 0.02113449083070361, 0.03543843064577349, 0.0075667840147000415, 0.041986302878226966, 0.014665550552308561, 0.024487759181929213, 0.02998598370580904, 0.037442608586242127, 0.04723786241224697, 0.05286674706205245, 0.0335287228376875, 0.033225945737813754, 0.05117851527287595, 0.010593051087081192, 0.014275944089486957, 0.04753247301484789, 0.009752057000784384, 0.025797631636622454, 0.04519758640878624, 0.026244126831091223, 0.01098479110477192, 0.021515918347323616, 0.02229780108938294, 0.01927503072957118, 0.05874120885686529, 0.03935939887718808, 0.014416054867568516, 0.03126376282213436, 0.029212330663276297, 0.012432235713687637, 0.06000063059130504, 0.027094260346324697, 0.04944777326478113, 0.07687232667399992, 0.023279558086106857, 0.03265788771152016, 0.10262839421029053, 0.029072010168625467, 0.07832725787715566, 0.09481703231651938, 0.0668960998976423, 0.05966441375353645, 0.0026157660402297495, 0.04213167189229881, 0.03978164355841376, 0.09904754603461874, 0.04834700833945986, 0.0736365704646995, 0.038722515511777134, 0.02879300669226195, 0.05880365651401301, 0.08028844296331368, 0.027075525666136416, 0.015247012244447347, 0.04162525330039282, 0.06940444030107991, 0.030775866321017666, 0.032174003595906886, 0.0518620572233152, 0.10779779464487108, 0.04111130789463078, 0.051965900441451426, 0.04931809756183817, 0.042727293762108015, 0.09685911628748141, 0.040017227086448864, 0.058064193975540905, 0.02141671953722835, 0.010680233808084121, 0.14121189923776736, 0.03567900140619567, 0.03168613199264773, 0.02740065146598124, 0.10125903502827692, 0.02521795780217696, 0.03575140820635903, 0.08840383451071479, 0.005230730082163768, 0.010622169131473189, 0.10466401239917164, 0.022227476133153807, 0.009619669346589475, 0.03775351770943211, 0.030229002117149295, 0.020328033903253176, 0.03706176712688419, 0.030567938567049084, 0.0316887941481846, 0.04732078759961071, 0.021578000197487495, 0.02528960234485567, 0.031904438322770505, 0.019240213948632442, 0.03146478620868537, 0.018827639212231004, 0.03811268654141215, 0.04193300614133478, 0.03899182223023907, 0.044120838339891166, 0.03729376536343367, 0.01580016028451463, 0.052126131561254306, 0.04651077602419161, 0.027006326859155973, 0.05727326565031564, 0.008729648505968433, 0.09256916946821636, 0.004833864936259606, 0.011990463451272058, 0.06978762215904652, 0.014966883576445043, 0.02138201192381882, 0.014604915650711666, 0.058831990275892525, 0.06744631956661902, 0.04062289236894539, 0.10441538622422565, 0.0089145036068775, 0.030227071575580106, 0.05876093179047589, 0.03422228521817634, 0.061451899894182725, 0.03398920679765363, 0.09185607950653761, 0.04686372039178687, 0.053835327346478744, 0.17982412490152544, 0.1309180983732785, 0.13131730679062106, 0.09673845743940723, 0.12280150406783628, 0.08942459304366382, 0.08924794082920398, 0.13513219482716055, 0.1146095343715241, 0.14014144458117025, 0.2831885074415515, 0.0759380135024267, 0.10622462543148188, 0.14288808429433456, 0.41076454724515643, 0.10022040366405442, 0.08291372668839271, 0.10253785793939907, 0.15276871861950045, 0.14789203271990822, 0.15385699248121631, 0.15416626217624835, 0.14658956067456355, 0.11221639060926054, 0.12546668565201183, 0.10321669610998324, 0.1541375645226048, 0.16118186556043165, 0.16167073690843198, 0.2775856467985338, 0.16213667158397937, 0.07619107532645426, 0.09325632735365823, 0.09136353859737997, 0.10152608561780184, 0.1171948129851972, 0.1094027182027217, 0.14066509632093294, 0.19997983690231078, 0.13066731183038605, 0.13643350241886032, 0.17523213259635434, 0.1304458051679596, 0.19220053578817076, 0.18283052970805477, 0.19885641492662892, 0.1813968574447978, 0.18402731226336572, 0.11704029305086983, 0.16631886813669436, 0.09965329941722656, 0.13180228641196606, 0.16150530788206285, 0.11381417422765687, 0.188991270899292, 0.07870818743662489, 0.1470855259967427, 0.08267840746069148, 0.1780324750730107, 0.09985858033741675, 0.13594691401287434, 0.07647479598921153, 0.09833233400938973, 0.1391722820699215, 0.10741903311422757, 0.15430945933105486, 0.10378695663905914, 0.12875495718852167, 0.1134137477305147, 0.152877809539918, 0.1398783087009384, 0.1427292589458727, 0.14485404976914007, 0.22414525309878014, 0.13092197477817535, 0.26421633999674554, 0.12244882783101452, 0.10183530934755841, 0.11464702671453839, 0.08266589724488797, 0.19826379995192253, 0.08031753132179861, 0.10641463055846193, 0.15037792674716444, 0.07086335516144192, 0.11177315511890959, 0.20690691116596424, 0.09132554063633566, 0.19210097500153128, 0.16067943445617155, 0.23566134724645849, 0.12824083558253704, 0.11847231056421034, 0.15400719167965074, 0.14030166420965426, 0.23533670982766539, 0.11575816063991479, 0.15220257964345718, 0.1058400722761308, 0.10311756433258135, 0.1883895854435621, 0.15183738552995268, 0.14024672038372488, 0.10492874940316524, 0.1026599570327709, 0.11997321470370216, 0.11731505814579227, 0.12059410598369376, 0.116580686261577, 0.3854330226538643, 0.13305361442748578, 0.13492912024019227, 0.11301404901690061, 0.13237628545011246, 0.2582633158852977, 0.20885349461628547, 0.14638106218509137, 0.10675061373941361, 0.1390447590740458, 0.2419102038707464, 0.09808775277868395, 0.0979058528619428, 0.10244441819527458, 0.11141675569477583, 0.11458969269428523, 0.16704705003048145, 0.21633575279866496, 0.12237430279774052, 0.13875226670455548, 0.19366051551074753, 0.08513164315973559, 0.07543093990534544, 0.14520936134842136, 0.1863564034142802, 0.17749943109529634, 0.11776010160364452, 0.1875713422533966, 0.057935851265586195, 0.15262915272145502, 0.1768668263309425, 0.09835596782185378, 0.20633982224089487, 0.05295920621363386, 0.0948497519317654, 0.17627384363403245, 0.11317721808389311, 0.15229166034729252, 0.11536144966920538, 0.15376731422880005, 0.08356859396782615, 0.08227805757234175, 0.11386325748096551, 0.20352975044760013, 0.14665386609492764, 0.1663901909224449, 0.08330348924162888, 0.18341222026896092, 0.15540718671775636, 0.10763816490408876, 0.1600798327595957, 0.10989397208416656, 0.13095194413777322, 0.14564217038212285, 0.13181141818002348, 0.150317681592799, 0.12815068235560773, 0.22291036533011546, 0.14755250255186714, 0.09059014219430186, 0.06850435593796354, 0.14317882998335746, 0.15740344330908793, 0.1459592082087071, 0.16162883189897384, 0.13876786425469384, 0.17282712213214368], [0.02054125340955873, 0.08091267438665514, 0.05538198608724822, 0.06639539249121182, 0.05872816237951479, 0.0332691224532262, 0.04248276998799655, 0.0035859967653279106, 0.035190842519964904, 0.018113168377068736, 0.020356432782606255, 0.012714214484027077, 0.05705894872305855, 0.036544121516447876, 0.013325787262029707, 0.009521063297025619, 0.042752747033392234, 0.026600855673032425, 0.013765570568671871, 0.07260275779352074, 0.01122482751886691, 0.02235783365434937, 0.07480625649012866, 0.01473122439722741, 0.056371005597494306, 0.037174876178464586, 0.04565994345372723, 0.046803475237421455, 0.05039793296506809, 0.02925843766499912, 0.04744752152492443, 0.008665028031945469, 0.029669304025329413, 0.051600005357496204, 0.06236642118423216, 0.036373889118793516, 0.013441918530471384, 0.052202636931812575, 0.0036721390431686757, 0.03580665846745815, 0.03656473694249027, 0.0051859182478379345, 0.02110931335107213, 0.0253427094749866, 0.048317709306795756, 0.1007950462160572, 0.05202524927294543, 0.0295099270935621, 0.04642605053020581, 0.02111944294865093, 0.046916611102079196, 0.047503242930096966, 0.00471797019746455, 0.028037412257324305, 0.012170573595100114, 0.014859522099516567, 0.054406675720407124, 0.04600768991475625, 0.09515807933865056, 0.02464242850340182, 0.0260162367410357, 0.0881730888279215, 0.034631667283153346, 0.04405333067200357, 0.010457870084792377, 0.040515578772512176, 0.05545820417483488, 0.023036882499112718, 0.05592199380419428, 0.04087282472380227, 0.023035264138372678, 0.021578410054526983, 0.0011665674490711443, 0.008773134529380309, 0.06362767003837132, 0.01350680426243813, 0.031053257182300575, 0.04046782851219177, 0.055894541043427684, 0.09506166717337985, 0.028150435124013214, 0.06532591842715779, 0.04333079484621844, 0.02130776842785699, 0.02127368709132556, 0.011316247663701014, 0.03661066008311126, 0.05450668083804269, 0.038195925824824846, 0.047714732992913456, 0.08150974033220161, 0.04807041612483802, 0.02737628986998912, 0.04233628248555526, 0.03573601366952062, 0.028895672050214587, 0.026949661250616756, 0.04083528258507291, 0.04058220926972647, 0.028308555671584704, 0.05603979131387127, 0.025419638109123035, 0.060391484819833315, 0.07333597288497033, 0.04546633771350307, 0.027507735236037164, 0.07054765032784593, 0.01516204926320502, 0.02901990852889515, 0.07791714036777135, 0.01970069982381838, 0.020155154671820424, 0.029492511999823397, 0.05260047022133105, 0.048057902078594894, 0.053798286995339784, 0.04668196986219095, 0.014974158538895992, 0.029620088621853825, 0.05363581506835838, 0.05767146666203776, 0.06391620939417232, 0.04078506552163632, 0.043973944810850006, 0.029324317396047617, 0.007923723530820421, 0.045676111739369175, 0.04747367576665936, 0.06770794625364004, 0.02370604689443304, 0.09214652642127007, 0.031326679708135706, 0.011408662765226778, 0.03185836004934484, 0.03895750532167093, 0.03662153470119642, 0.0026211480473002963, 0.09591586286983184, 0.045903609209363504, 0.03727317292002901, 0.03216828474955213, 0.06113164449831652, 0.034587552110033656, 0.04816610050658065, 0.07682963259397976, 0.06630811975487778, 0.05344554564104446, 0.017897934059522325, 0.011455436263443723, 0.04841772591575019, 0.02511474277613865, 0.015263817340676344, 0.011055463673396698, 0.060974692234829556, 0.01959252629369017, 0.010894966338040128, 0.026405440050087152, 0.026114723089361386, 0.03955902223805747, 0.04782261349441064, 0.07735860098393695, 0.0200111492942538, 0.025358674747328606, 0.08284373689563045, 0.0456355435533389, 0.04557611045217322, 0.04659172853515033, 0.07542153234563528, 0.033911307147073175, 0.02322792376001035, 0.049517613670398156, 0.03796443320630539, 0.04143554311726363, 0.037910692138417114, 0.04788576595244869, 0.03250211522343659, 0.05083448816871932, 0.0493735316840391, 0.02410155702232113, 0.03781539846151587, 0.020364020883496252, 0.03321252387738036, 0.013810037184626827, 0.023391989149874257, 0.06556745062792493, 0.06774421285597548, 0.01711787843716241, 0.056156995105406934, 0.09214261937285624, 0.013550088230159976, 0.02481999236249155, 0.03585003436573091, 0.048674779057863264, 0.06100713222798321, 0.04802118348438413, 0.02596891165951327, 0.06342343099775814, 0.03820985713372788, 0.06150352272896036, 0.017580133975453435, 0.022330744785346815, 0.02200703624816191, 0.053752658798569636, 0.03369025630696166, 0.028985453724500634, 0.05759610276248667, 0.0618920250675611, 0.0310758127260112, 0.08144826943715734, 0.044673011533074805, 0.046759126407484856, 0.049399383321043946, 0.03315991661962002, 0.038456208027538755, 0.0804148015055445, 0.07831493152245399, 0.04752704145146474, 0.06291835305971966, 0.028921443247987382, 0.07408232638432134, 0.04848925171480064, 0.0465823094841213, 0.014677950642972946, 0.035568883927959594, 0.06709301513769934, 0.0776104064237687, 0.03825073941580711, 0.0326026106373437, 0.025420153303252115, 0.09697313315325207, 0.05778577464121965, 0.02617394551634789, 0.0621978895017697, 0.07662949978464073, 0.021577733981933807, 0.05978969594223365, 0.04475120995794574, 0.034102721875833894, 0.029936017536167658, 0.009291558676669675, 0.014091616631635736, 0.014424389904184688, 0.07445751794523771, 0.04376708957997542, 0.03143052867193136, 0.10494620088608035, 0.020171234857351072, 0.03956931462932018, 0.05437300232569537, 0.044559653502919024, 0.033947523953693534, 0.06045194447881753, 0.06139405642545993, 0.062397233240546725, 0.029497610314959483, 0.05839821214096681, 0.07380098825500858, 0.07070562531871181, 0.02180360543030885, 0.02325611196518425, 0.020019582007080317, 0.03231265018844316, 0.07769108314307467, 0.00399167120415387, 0.01896939229130024, 0.04197604879136047, 0.05088767382286249, 0.027051981869003466, 0.0361649539592045, 0.013641826301482658, 0.08400094334877307, 0.14944054156301484, 0.10450866508988604, 0.04393725686015622, 0.05069811685731815, 0.026950770162887154, 0.06378572546846925, 0.02073693141761807, 0.05104923793565362, 0.0601745861762714, 0.09858068439268297, 0.030610916099601218, 0.02730306527096658, 0.017275361216536934, 0.006408739174085279, 0.019572613753318306, 0.03102816780278039, 0.04388457682404307, 0.07731484204170204, 0.110701865426475, 0.02631516233387013, 0.042904340511848854, 0.024593000510527242, 0.03642758422140633, 0.07933689281344414, 0.05346105509107152, 0.07585617232947581, 0.083472924907842, 0.008780298409082236, 0.04088640746269976, 0.05431187233977741, 0.08080962023908093, 0.0703148208858986, 0.03325057546457937, 0.04366910310402032, 0.04340170011405022, 0.18274524880032386, 0.06482976158299754, 0.02751526013467341, 0.004312543540201601, 0.06817123792584866, 0.06248515715161639, 0.014492319878040543, 0.016352602566081672, 0.05122077268277926, 0.022552969655202284, 0.07601829951689129, 0.05173001430868622, 0.04282516149443485, 0.037348368280236764, 0.07653967597551885, 0.03961700743304626, 0.03156755115806816, 0.017606198201857267, 0.051904211211348736, 0.0546096622072641, 0.016835900624432874, 0.0676223895542564, 0.0062347539032118465, 0.03846531298251883, 0.02596527848753237, 0.056170907262111866, 0.03058849653649715, 0.02845625550816617, 0.018331419165817, 0.03184914592683556, 0.053396650079277255, 0.02269633726457194, 0.0319469083220728, 0.04552686248996085, 0.012381462278896043, 0.007919318046450855, 0.06186609299132421, 0.04664359268762412, 0.04430267313915876, 0.04562916204092964, 0.04638190088312953, 0.04670947241867262, 0.010264552585149725, 0.02405588860593496, 0.11485104358965352, 0.08259024606236527, 0.17035559991434698, 0.19974700746036347, 0.1024803247362856, 0.10753004691533505, 0.0921095550180443, 0.15418596595766085, 0.14227938147321825, 0.08286231452779425, 0.11509308906932993, 0.14165607701626518, 0.0442010247629256, 0.10757516949407517, 0.2883175580251602, 0.11977145778796366, 0.09358782125937362, 0.09722802592741867, 0.16731282125317282, 0.13191847130656242, 0.13522982507223083, 0.14360120489953027, 0.07511760994431473, 0.10371810065642481, 0.16933049766286729, 0.12715459951469976, 0.11194751673047582, 0.1304385426544374, 0.1525388156334239, 0.11512346445552765, 0.13057872142282226, 0.20900753957609977, 0.15952526171120907, 0.15337794238040525, 0.2336250702219625, 0.17910046292649162, 0.18206292492968423, 0.09730614391305754, 0.1707226019953528, 0.16982269383245902, 0.1714257174922574, 0.13478305791654896, 0.11941857470740234, 0.12613277611953597, 0.1455166851801257, 0.09704292376315403, 0.2401860157448438, 0.14975066927652206, 0.09658456569717777, 0.10550088684765563, 0.24035898307638787, 0.10015118762009567, 0.1908815468871786, 0.10775620373146189, 0.12204825577716674, 0.26679290819071955, 0.16012939864829664, 0.06924241270509458, 0.21098285132358152, 0.21447038999007595, 0.15348069009280976, 0.19411448389291766, 0.09466518602904775, 0.1381629459079235, 0.18981653145484387, 0.12525394303543916, 0.09605299260827804, 0.08768910512087807, 0.14910519423504032, 0.12888867017482558, 0.13044033530018023, 0.15135049068879697, 0.1038134019942053, 0.17156379717972972, 0.19156546422070075, 0.22226472174929035, 0.2040705625568667, 0.16764017062321787, 0.20795390821031987, 0.09575696091257757, 0.12944204612605034, 0.1605808849055921, 0.21845314321258377, 0.16701522673810684, 0.19421563814243964, 0.0981705362397817, 0.15081542423896252, 0.07467707874433649, 0.2303319033836165, 0.11740166438563217, 0.0983260291057729, 0.19763280397220967, 0.17260071250700182, 0.14344970335162457, 0.08720374245557093, 0.12798022779245533, 0.20599212557558091, 0.30562333101707123, 0.1713022241188634, 0.12438628717415756, 0.10913872430401464, 0.10976971262284826, 0.18864077035217516, 0.08661645179193828, 0.16010799415169225, 0.13404549910656868, 0.33418529516746925, 0.07559840672559316, 0.25852629854794473, 0.13804463128889763, 0.18725911545897686, 0.1717437665549017, 0.16327351542009463, 0.1074712266845088, 0.15360229888991003, 0.21220407208367703, 0.22369442567709955, 0.16562535938236023, 0.11681739210842118, 0.08524660231365312, 0.25023322822826527, 0.17357278615236285, 0.23245033567711232, 0.21635631459855267, 0.15654772309766662, 0.16727172829691442, 0.21109730485946904, 0.08455867067940774, 0.11951059718886692, 0.16894498689761087, 0.10180856521812179, 0.1618327645044173, 0.2405340801323614, 0.12971077444812945, 0.10610228118997429, 0.1135857574521534, 0.22695200007048347, 0.07769060050768238, 0.12577756413168487, 0.14388199144553754, 0.11037004976383141, 0.1277842854840621, 0.1165148410044851, 0.10440214056401484, 0.19998549063119198, 0.1436975174733708, 0.14810345766525115, 0.15174925477514345, 0.11630474139125117, 0.15301547553991118, 0.13547242979609198, 0.16402699353714145, 0.08962842605767712, 0.16316958793228672, 0.08935658741862544, 0.12451734949624348, 0.11612894719526654, 0.05933714865316307, 0.12935629024380638, 0.1124649401754141, 0.10316062613480514, 0.09865515579980227, 0.25215252362672363, 0.08675362749565994, 0.2651489447922476, 0.15687479667605894, 0.10591941600244854, 0.11186420466871032, 0.1668414013880876, 0.09631284963219397, 0.2021722886110506, 0.13818850260107748, 0.1639510129368113, 0.1278974673139953, 0.0884624862021977, 0.2560268754079457, 0.14865179275793416, 0.21079116080316807], [0.028200993096576105, 0.019138174867557905, 0.0865912551601087, 0.02739543440721689, 0.03325056780370013, 0.064380765111456, 0.0180770090270427, 0.03553258668210718, 0.0573351655545975, 0.018930725918541995, 0.05661367543882901, 0.05296168067762929, 0.01102715959742425, 0.05304576265775869, 0.07099411870923734, 0.030384508389679175, 0.04864250377361332, 0.051461006364514755, 0.01965912231694787, 0.024637728553986358, 0.017340733414335598, 0.04694970226996849, 0.06832761179295278, 0.023105453113995256, 0.03277795284145302, 0.10247190542999776, 0.013426739455861671, 0.01621370891018981, 0.05758518217912605, 0.043183196516286944, 0.05262364438104053, 0.049725633354917656, 0.028147928101281007, 0.0654016079140767, 0.03710597806099442, 0.055972004023891304, 0.06421579573784145, 0.010653018534574057, 0.01615957905267996, 0.07747552898381987, 0.05959785220423534, 0.050792299706729195, 0.06179197398465007, 0.06683930213893614, 0.041935116713566166, 0.008401216079120435, 0.01935910696404115, 0.049846070037493785, 0.022741542197763923, 0.04321348380237337, 0.06900932279325302, 0.013944176307338622, 0.019317119600131147, 0.0643047538676089, 0.044407025805764624, 0.03751514562135262, 0.07432169055626278, 0.019350321850769462, 0.057880076234258955, 0.05966398091385922, 0.06346234443387197, 0.03827225116472091, 0.09528964727876649, 0.024423497811620756, 0.10377435449270472, 0.056140731058774464, 0.028193941257233103, 0.03350971236584648, 0.06816130176547074, 0.012495601718734591, 0.02017743633909812, 0.016735031742662672, 0.07500407571393637, 0.028963964958224567, 0.04254101565287959, 0.03797125904971073, 0.03914944482065978, 0.0346978074840961, 0.011775842004065073, 0.016656779691637043, 0.024221267836589008, 0.03561797484214749, 0.1130670776230193, 0.03134773371951475, 0.023464353815201792, 0.056044506585045215, 0.03666167004754947, 0.10326791674860063, 0.03991235348005449, 0.052080974508557594, 0.010031102611983736, 0.02646970908127485, 0.034247880215726556, 0.03740508943015049, 0.06446236113627112, 0.05421551380066141, 0.01571014399580177, 0.014364062395367413, 0.045226092540448716, 0.041664752793768724, 0.01402515563137469, 0.04209456259324666, 0.014297444347081887, 0.03850408852280628, 0.05048522868403985, 0.05107689754015977, 0.026758809596480384, 0.014520965820749202, 0.07925528912774979, 0.03823130376516812, 0.03407215879809472, 0.019300805757783594, 0.03363647310423755, 0.08169851971850281, 0.06524684283161356, 0.0468237612456564, 0.04426483605657855, 0.0857934128913668, 0.008987102886631845, 0.08927260119948657, 0.023042879052340023, 0.05170254239572152, 0.0463970196283152, 0.05011624626574978, 0.04117123895294724, 0.005032658528146004, 0.06776288241869019, 0.03501805904952269, 0.03314705783381097, 0.01206677059657992, 0.010206757954532101, 0.02596770124059291, 0.04848424533021547, 0.06859935084057432, 0.07996317735242267, 0.02357360178364381, 0.010807170746697774, 0.007864065391326985, 0.022525988038509123, 0.04653627909119091, 0.12258328392260498, 0.043248934521069454, 0.03443416981627384, 0.0172811892304209, 0.026987423639624353, 0.05077636124746454, 0.026613042216687918, 0.012729802458066375, 0.019871305689335834, 0.03074287474455853, 0.05392638455715872, 0.02476427670297844, 0.052064859849070354, 0.034032839335381024, 0.004105841048106912, 0.07299281146016813, 0.029033851329117056, 0.017687880411563862, 0.02155983050714337, 0.044095645538501205, 0.0340567451090582, 0.03602374097212188, 0.05089719246532168, 0.020330414521477876, 0.061912364701950745, 0.027108455955561613, 0.014217369964406376, 0.028004962688071594, 0.03635174151690256, 0.036148057890034495, 0.0628666382943911, 0.08580389297417096, 0.06890896527517228, 0.029541160498235016, 0.019144048846717325, 0.13908471822017623, 0.02991408826933513, 0.022803980278812593, 0.03718914456605431, 0.09167399572869463, 0.09027040007734492, 0.06349213759324725, 0.0434209710557855, 0.026654749958505555, 0.06545311966610533, 0.0284428738673488, 0.076332165739469, 0.006102111524782114, 0.0513470622770969, 0.08500602006191209, 0.029561810398233995, 0.08077949766189822, 0.015565864741802217, 0.03308205910387539, 0.018436700714031057, 0.013235682873205553, 0.038029853284599326, 0.029066908023049755, 0.04183867007433888, 0.002610034026738797, 0.05016210811933683, 0.11882210631043681, 0.042180977311105504, 0.019958946147873517, 0.0555393903426105, 0.10355101688013923, 0.03944877452487427, 0.01310976961958072, 0.04308905197127212, 0.012484470461194795, 0.0082233649370591, 0.08276128285234013, 0.01640398216794335, 0.0464869698419446, 0.03350033161921367, 0.06720385273858424, 0.04953804523533872, 0.048607980021305626, 0.034291505092574705, 0.01836405642661116, 0.04983469363181822, 0.05936514916679552, 0.01777131504739725, 0.0327985682674954, 0.06816513220509214, 0.04056401468152481, 0.01603816848083009, 0.03634183600004162, 0.06527834436705997, 0.011107980915825936, 0.04745113362948741, 0.018382026934094967, 0.023880406590779463, 0.03837304535291849, 0.03983136649513918, 0.06843543100741602, 0.07252199680454309, 0.059962192129704266, 0.05329586355195892, 0.046628090898476304, 0.05852408804780534, 0.04199527376782029, 0.06365740191071265, 0.10498412989921148, 0.022869235648202802, 0.015420717893228417, 0.04154263837863842, 0.016147446135179173, 0.03541462446352647, 0.022897289787989952, 0.028610924829638777, 0.07492031932117478, 0.03631619503721595, 0.017922988965085918, 0.02911019007555179, 0.01907818635264712, 0.02865179370517933, 0.10772665572022239, 0.05090980993343457, 0.01821778342878867, 0.02509955508303979, 0.047339384383972616, 0.014763923902665416, 0.041173950904199196, 0.03181715409511761, 0.025801102014919444, 0.036291458058140935, 0.0575595258945419, 0.026615217906392874, 0.03973072552452645, 0.06344582757822449, 0.018311621538633784, 0.044193356222803556, 0.03833908850567476, 0.0688956353452898, 0.04512071331602432, 0.1639143939340307, 0.022493571027993195, 0.03376165187106498, 0.037835822365577185, 0.026896446868176424, 0.09446813289316432, 0.02526185080979861, 0.020341034415328217, 0.10917275392961119, 0.020537886453131517, 0.04957787414652206, 0.0706892846632869, 0.039417567933278705, 0.07097759419271062, 0.02154455662915303, 0.06174513919939918, 0.025754286381866665, 0.09251350551963815, 0.026998522338427366, 0.02774412698683239, 0.04402619583772556, 0.0031906022688358905, 0.023756177772978143, 0.02779271419821007, 0.05352287455612133, 0.035118531480792074, 0.011996628543842706, 0.08592825202691941, 0.03329798098533385, 0.04529683309937677, 0.03556997177281207, 0.05961347273701142, 0.044412867226187265, 0.06360279516346994, 0.0999682458237775, 0.050252724829460346, 0.03338580530497336, 0.04691790196023161, 0.10304905308951294, 0.021769144880254904, 0.06609691697503291, 0.03057910812898509, 0.04214737286430694, 0.03399749969943397, 0.04536655476136554, 0.016300460706735333, 0.046457429491584344, 0.04289367273750325, 0.06339435413059208, 0.12347123345300076, 0.008233821079615624, 0.03777696766079434, 0.06536660535681633, 0.017726232688273155, 0.021901319945050825, 0.02226824158682458, 0.0460975979935498, 0.006682449461696971, 0.00853806140742475, 0.048654493049628315, 0.06449687339725994, 0.03848010614033669, 0.03781145693914544, 0.06830740239351027, 0.007411759898757503, 0.02639027917006564, 0.0398121491795586, 0.06060463729344549, 0.009539639971579516, 0.06633639606016298, 0.027997931916146513, 0.10057504874684157, 0.004083398981170068, 0.08981795621014411, 0.06987913902248107, 0.06315928388146624, 0.14321451435887045, 0.10641649215211792, 0.12450633315189231, 0.12658270721834514, 0.19200234884215941, 0.25989915875177233, 0.16995038536767806, 0.10669132619495354, 0.16818884279458754, 0.11133171227430144, 0.19743231876242548, 0.07848461999768212, 0.15689653825135003, 0.14998803395898114, 0.171206800207015, 0.2024205777073099, 0.14931847311316, 0.20766539949803584, 0.1698565395969537, 0.09525168762211839, 0.13163472766116743, 0.09545164423123484, 0.17988458456050965, 0.167227448414891, 0.19536993346147, 0.22025317404299016, 0.13945031069940136, 0.1275373217199118, 0.16175192690664725, 0.17404371572117652, 0.11736827827389203, 0.15255133351010663, 0.11925942760201232, 0.11780012969768817, 0.1828706573935286, 0.21753258131925138, 0.08446199038336355, 0.1747805084432325, 0.123293700237428, 0.19295075037066015, 0.18335298635065558, 0.1877749377801534, 0.13668240438545906, 0.1412847848428834, 0.08428336166205906, 0.17899308804302447, 0.12594771225966755, 0.09573304364758153, 0.15317658383038738, 0.12875143318406998, 0.23399378833991868, 0.09070887050080685, 0.18433072904665626, 0.1602025906885824, 0.12537646347716933, 0.16301721304414735, 0.10271965826471006, 0.10404790916870679, 0.15618746259039448, 0.16078921485572092, 0.15792798371084277, 0.14316787492604027, 0.1591001901655428, 0.27331308251427067, 0.33073020798544733, 0.20405452067573226, 0.11164188595308412, 0.1216782736141355, 0.13757494278252125, 0.06332434135519209, 0.12714323843078268, 0.11365077533428708, 0.15835497047631972, 0.1085494494726581, 0.1486611083870934, 0.17113621286567182, 0.17810949755291786, 0.11327748367142294, 0.19883574587443184, 0.10573118053857358, 0.18234225590863537, 0.16871644754803952, 0.19823640464775025, 0.10360543210540088, 0.14086377356321583, 0.16472338278207088, 0.07492592708478052, 0.19402911105463583, 0.15283389738009823, 0.28091111190376744, 0.2094748225663939, 0.1784334761360961, 0.15025853960504457, 0.09649991298154478, 0.25471216127757107, 0.13824315531359566, 0.11701698865621321, 0.061318121790405244, 0.11898838569440189, 0.23670783867278408, 0.27097118237326223, 0.13548554522135567, 0.1420498921746208, 0.10066734701995889, 0.10247449480718183, 0.22430429295186075, 0.12299112615085418, 0.0811843674690012, 0.21528903154596207, 0.11783480283714111, 0.1562138466585067, 0.24761095522872864, 0.215384915110565, 0.142401036235594, 0.15157218121232527, 0.14896329942970507, 0.07180650898766133, 0.3046267732016502, 0.18933712895358765, 0.3333629457460296, 0.11826937387306845, 0.14286920788788027, 0.1501724772876309, 0.10435027641154106, 0.2154071929474031, 0.15165516385628333, 0.21020347943469403, 0.16008288178953434, 0.15444458191913946, 0.10156280421201261, 0.18743862518139426, 0.13114086141990078, 0.192725719703782, 0.25324891802043686, 0.15220313122676266, 0.22100394020878503, 0.14382513239979744, 0.12993801144822953, 0.1909908676339734, 0.1216496219257674, 0.1687159419300095, 0.10171763824238893, 0.107032603043462, 0.08782548409315848, 0.1737379393870792, 0.21401951660311994, 0.1197178086506263, 0.15643708467964204, 0.16098807595910566, 0.2221334908878611, 0.24520029103563679, 0.12560795226524915, 0.13681711328606452, 0.06830596214821262, 0.10739819552268713, 0.14876544956238041, 0.1597199859398027, 0.06225478685190601, 0.18744671506987465, 0.20908318309774324, 0.14163090336707332, 0.16806452204623532, 0.1297409429905876, 0.12942235766639634, 0.16981074286084022, 0.2300705907926444, 0.09555918765404532, 0.14057892675120987, 0.11545810698261184, 0.11385483817467767, 0.12258044939728514, 0.2555245055907196, 0.17676040139650145, 0.20091521493609876, 0.11325251686597064, 0.1878702084744169], [0.024524803363507795, 0.04978391732419691, 0.048169390854215434, 0.014263685725088564, 0.02843839033777195, 0.018136551295737588, 0.027336256030286034, 0.01061548309911403, 0.011997485604707994, 0.032547138210746555, 0.01507574850092492, 0.08620320098294366, 0.04501070309009764, 0.05568750578189089, 0.018240614764152036, 0.05913628806029597, 0.03705881768837571, 0.029971290139421344, 0.005664334410891658, 0.05814574403508056, 0.04570571337676337, 0.03308630706141553, 0.0364356319750509, 0.02551696766468306, 0.06382770708671982, 0.04688160854481882, 0.01921859877784887, 0.020849996419142813, 0.04915600101793966, 0.053424478223126744, 0.052143996731648525, 0.04906533451210107, 0.025505213960704785, 0.016742347882339553, 0.024358347779320135, 0.005931520023413244, 0.010783250608872022, 0.04218900208211234, 0.005336537837020813, 0.09845132278578897, 0.0030741284154505743, 0.04176995964841016, 0.03094625768191632, 0.024756341947302706, 0.06823947337726433, 0.010766161102501136, 0.024812222315719532, 0.0734221424546934, 0.025260636560438622, 0.05731675263133742, 0.03375909696783751, 0.023525799812388518, 0.015267162272075733, 0.05983843062553675, 0.02652938350013668, 0.053229616098706765, 0.07286949428699671, 0.05998271945563536, 0.004954233628532459, 0.05641997393761432, 0.019237567114854054, 0.029833070640902848, 0.08817796880799918, 0.03328572357854536, 0.004990066433580773, 0.03617805406270969, 0.02222555325246386, 0.026627590226370002, 0.004958485895317169, 0.03355076701770868, 0.05043621054820476, 0.043426823967527, 0.09509201957693986, 0.011734195549281375, 0.02215811453248945, 0.021980108257623452, 0.053706356444426125, 0.03742004346643244, 0.03842500526638281, 0.061942835849139004, 0.021197811828085014, 0.005587317197838979, 0.016652895625860944, 0.06097921215358281, 0.023016910586926728, 0.02010226970718753, 0.05441405314711794, 0.02270124214250715, 0.07727312855422497, 0.026091661927620732, 0.01895423332649854, 0.032284078939307126, 0.04352063909473439, 0.010280910477552925, 0.0445616721445995, 0.06484808640614634, 0.05884347776431711, 0.013446422169856248, 0.011072112679211123, 0.043135806317290956, 0.028598215430974964, 0.04181071552598188, 0.04844751907512546, 0.03742818698106754, 0.021251924448616562, 0.06822896265094319, 0.04306706524784527, 0.018161596625202128, 0.05231850389992038, 0.033855455506953507, 0.031168386790781256, 0.04734488106482933, 0.06866441468798345, 0.054321230103772496, 0.024588170326164654, 0.022985610149560437, 0.03551654480097275, 0.03754493495028827, 0.0654016615402314, 0.035546065999134895, 0.028954974916433136, 0.027841021787495385, 0.08409997553474481, 0.03934570505554157, 0.047880694450389956, 0.018337526801793326, 0.026086580849462943, 0.02148746775703565, 0.022886315578474634, 0.0819688031990682, 0.04543117044733898, 0.04628214474406935, 0.08289215365244497, 0.09712076595714016, 0.030295040811442082, 0.04401896396772035, 0.044397453537150744, 0.03525791351773566, 0.05637110135848484, 0.009522594515264276, 0.01074763996932175, 0.07924843264082748, 0.02363811787818709, 0.024018899965730887, 0.030503433963824666, 0.06205564612642892, 0.0200934233068819, 0.04727746915793227, 0.05084814751640924, 0.03701078780596295, 0.04784555016686359, 0.017070674014488058, 0.030412907269032254, 0.03760680804149278, 0.05326384490716362, 0.08007557011179386, 0.06533752465921064, 0.026282760645112684, 0.016916150249721065, 0.08358036107834309, 0.059592573858437047, 0.03945790246249207, 0.10371589432320288, 0.05300485739304174, 0.06884259907829185, 0.014643426890665246, 0.036579832705038215, 0.03389698130288913, 0.06479003226324435, 0.028531006537377838, 0.08155706158328442, 0.02734474811492668, 0.012049665768450547, 0.023308995014597333, 0.06073027571302749, 0.017746744692445766, 0.040484789698835344, 0.08900830852648906, 0.04370358472149219, 0.052461674241649534, 0.023343949691362442, 0.05042063598070414, 0.0763870406174852, 0.03809807724469612, 0.01784819963147804, 0.015834446549565805, 0.0031560009501258573, 0.03505052202531407, 0.04798361453257742, 0.05097478568073242, 0.03132981300774602, 0.04995434124383235, 0.05430396631239884, 0.026764191364148454, 0.01882071952305494, 0.036063140874067624, 0.07999169114496439, 0.0731042695922717, 0.04194592238373814, 0.031012484067750555, 0.062451790192074357, 0.07983514873851692, 0.02454371615913847, 0.052143380030869484, 0.03723561928998079, 0.038047423511142694, 0.05414385776666384, 0.05438973368596166, 0.022633744050718607, 0.027412495185290615, 0.025778238120819294, 0.018232793006445133, 0.06679639355429719, 0.048593301776676416, 0.02396885910251689, 0.05121411537871726, 0.08396217163892523, 0.0853904583040745, 0.02933459829599146, 0.021832573129945708, 0.08389670176491623, 0.032462604238741824, 0.011696675435579833, 0.04464826689312055, 0.021724570054380644, 0.05817294398683214, 0.019452868465093837, 0.03004658700627906, 0.024337755335915475, 0.04840123587318006, 0.029439519782881104, 0.11056147981435062, 0.010773789423007158, 0.08168918876758507, 0.05066706348330744, 0.04374997517574699, 0.03133023435610437, 0.057316721987820445, 0.020275330884502302, 0.025386364995351723, 0.0185720837720099, 0.012314480338846485, 0.028565884605350516, 0.038139771579975085, 0.007637194677015707, 0.05274627590551973, 0.04489109761291935, 0.03640488120577028, 0.06826327572907172, 0.03699245915237454, 0.06953092141737861, 0.03266621508725709, 0.07207723679922282, 0.024455978024390437, 0.05299147383700456, 0.08700101260816859, 0.025665205678031332, 0.02834069114478846, 0.02412996547777326, 0.015608214082256442, 0.0440581685172454, 0.06469713644154611, 0.06761561733700576, 0.043320441167921796, 0.07387217314493272, 0.05046238011169819, 0.028356627688833305, 0.019394143995258118, 0.033076114261582974, 0.0589043626020993, 0.060976258884634704, 0.10951665079882068, 0.0525895802814874, 0.025617045560671438, 0.01897037288384332, 0.06686507333670894, 0.047074172405465964, 0.012073123380692016, 0.09042548691673626, 0.02992883163143791, 0.09537711153708159, 0.03598834771002012, 0.09533539804960452, 0.051359430766634406, 0.048799750980951136, 0.032963844076279676, 0.024430153200462944, 0.05210543952641949, 0.03837118375926249, 0.03042184943032842, 0.05420789888669407, 0.05752586782158864, 0.018062800011267106, 0.034077417991694905, 0.08201551924069082, 0.07471282440688341, 0.028463046877614917, 0.023771641257729743, 0.03617870906788496, 0.011060053497673044, 0.043846981059159004, 0.03836042405436597, 0.055927628380877364, 0.03687627042733854, 0.03679556306451559, 0.013399287652704987, 0.03175363008443627, 0.0718945937771951, 0.029441209006754142, 0.06876696321752764, 0.03126324762800529, 0.012554284053734474, 0.03707521963083456, 0.03628751653577051, 0.07559354972815321, 0.030402118835838574, 0.03915000023440488, 0.08470433463733043, 0.01771278018432279, 0.036864235186048096, 0.04444602351155012, 0.030505008274509065, 0.04062270850784356, 0.0282546479795729, 0.05449600923325747, 0.11033588990328774, 0.08908923805481003, 0.05829419655304763, 0.06475115330108712, 0.02735672973006243, 0.04628948003594433, 0.07774830225013918, 0.0570540725734205, 0.05726863464881336, 0.023057166592127854, 0.04570683569557244, 0.02201643231655321, 0.02867966206864484, 0.031029339917304537, 0.023394881131788416, 0.007331348437395308, 0.03786961067347758, 0.019912034753830205, 0.022937685604237264, 0.11040857632554348, 0.03448577732929299, 0.07427824571007684, 0.047403674482578234, 0.03533199422001358, 0.046015764481478164, 0.015998397026241066, 0.057406450035951795, 0.11289780283527029, 0.19197910573453675, 0.13862514207440038, 0.08302827215483112, 0.10763797338210768, 0.18646197033024606, 0.1584695465862751, 0.09738092941622581, 0.12079933327772926, 0.14865010736450074, 0.10565336898810442, 0.19476228784168922, 0.12926227593373868, 0.17140003822503552, 0.11384604348530693, 0.17441439502421888, 0.20732822888080152, 0.18013509531174937, 0.10695581038993214, 0.13764169968424306, 0.17965527912301404, 0.15954361717787482, 0.13822836981665704, 0.09903845257095753, 0.16529877610023946, 0.14293896785426524, 0.11787892950157966, 0.07393896069017149, 0.21298460842620945, 0.16490658504828332, 0.24492845239658512, 0.14940983675900968, 0.15608370364192994, 0.10506928057199526, 0.1754797475352403, 0.0933551526958904, 0.15402335613485307, 0.22443325619303414, 0.10666369340352475, 0.21153265730507914, 0.16121797894518222, 0.14959876936289573, 0.14983086336043575, 0.1471159090438197, 0.15132994421066778, 0.12958702060484117, 0.09120567085882349, 0.16726647293375385, 0.09702179505820237, 0.17629704077637967, 0.09361666446972279, 0.09120639098147232, 0.10626752635524159, 0.1450494175115901, 0.07887397652431842, 0.2133897770076029, 0.25062304440765615, 0.16785559454752555, 0.10951215386270516, 0.11561609729523621, 0.12665976034176926, 0.1455473746623724, 0.1454503726094, 0.1539915941295124, 0.09015504255770676, 0.12584950744865403, 0.0733246194619325, 0.10427664004025922, 0.0690313708037138, 0.12169575574056757, 0.11619784914317632, 0.08313611435193209, 0.19146578085999336, 0.10831214607723298, 0.2523972580750143, 0.09174600799357699, 0.26355535933567636, 0.08725224348205714, 0.1556538210640992, 0.2052074523582574, 0.08439439844580428, 0.13481589244498363, 0.07729254888310548, 0.16930252013187255, 0.0954658858057472, 0.10807696474535812, 0.1693898847987575, 0.14847868753056373, 0.2812749117372498, 0.1764400081048089, 0.06407342595799316, 0.07632281946679277, 0.19601865671575072, 0.10415516147810606, 0.1545958076753924, 0.17830716355914072, 0.11477304817808252, 0.07837369812712555, 0.06857274460696405, 0.15384959207186777, 0.12901176518249896, 0.11721828591919715, 0.24710383566637195, 0.1392651472481028, 0.14843436168326488, 0.12815240605343736, 0.21034240181888306, 0.13908883977320888, 0.10712389008051927, 0.12661937984728044, 0.12778837639357776, 0.1390025629511764, 0.11933695569994951, 0.11072187564305722, 0.15503304469729626, 0.12453021977337138, 0.11687720059266976, 0.12977763860216066, 0.188306097181574, 0.14058194513763153, 0.1354315360226939, 0.17916637713149672, 0.1353557086399486, 0.16418172797608763, 0.11445762679701853, 0.07761959947886006, 0.15499247268082636, 0.08906552763355356, 0.09993787043757978, 0.12887881828411935, 0.18426224078622558, 0.14390679737252576, 0.23180824674425587, 0.22109325073899763, 0.10888815226574099, 0.11154601771023967, 0.133503231430246, 0.1924847850515958, 0.17562784765276218, 0.11597161571825705, 0.06366658347448514, 0.2182425149986821, 0.17349847562370763, 0.15333599140567167, 0.13456253184666558, 0.07828695399145927, 0.08833775942724559, 0.12875785300087544, 0.15425290672048447, 0.15394403539117307, 0.11738919247422488, 0.16723627374777872, 0.1493608377753727, 0.10402573858417812, 0.21878323517739776, 0.12551475766926043, 0.11323931717103529, 0.143170295763881, 0.218103684545044, 0.22216775033983494, 0.1264267930039956, 0.1003940757964888, 0.1821140383159922, 0.11832249440973806, 0.15460641033226444, 0.1649331223339804, 0.12411153740099362, 0.08449982746594376, 0.2813799577134271, 0.13284621910462457, 0.2510221608944478, 0.10974777186469686, 0.12639323069203284, 0.17918634138280348, 0.10501829742063438, 0.17605489570527308], [0.02114359004002425, 0.023129632764105356, 0.036329394732151306, 0.03028859226633945, 0.011766815573097238, 0.05217054550866446, 0.05802595086636082, 0.024227873429716117, 0.10120073573723917, 0.06780144728479848, 0.0320724758785218, 0.03521701208345833, 0.045055752890484954, 0.04425091240855475, 0.04308349400338146, 0.10367313129526955, 0.04757541990388305, 0.04314146004617215, 0.03196749118937841, 0.00623702583271229, 0.06338894554984666, 0.05616761691447708, 0.04460216372183735, 0.0369103575095294, 0.03335141944849203, 0.016036677482207457, 0.060997820429263584, 0.02746265287691307, 0.023923554577894753, 0.032658259264163436, 0.0745816012063334, 0.018182681280098135, 0.0014952516076230115, 0.034324925678271445, 0.013028324897130652, 0.015063847325021222, 0.04686809858427413, 0.07247868219330426, 0.07461453532619823, 0.06233589258044959, 0.06436287695842405, 0.02337202489856751, 0.014554189138805435, 0.022950739742467002, 0.07347051324623247, 0.05006429018272508, 0.1260790886778024, 0.0661000502746432, 0.041620836803509344, 0.05739632618403243, 0.03581933722260498, 0.03140398181013523, 0.03439456307058854, 0.05439228092830989, 0.06553312988891717, 0.04435126226575625, 0.060540504242864356, 0.04152784139038094, 0.03391101603366194, 0.02557809765060102, 0.061929781710909265, 0.038296160768837705, 0.01744717558575494, 0.07291120011359453, 0.05899525510387556, 0.08665836446227566, 0.0749661773443222, 0.02686644494984179, 0.03672752296552062, 0.027699241895348798, 0.031061889077987404, 0.011741784607781278, 0.03452765169523416, 0.06954534685299282, 0.013919668197030983, 0.04341704485517356, 0.022430554550561695, 0.01950881395098423, 0.039008216511818676, 0.027695216103306705, 0.09879973191287249, 0.04724362722387718, 0.03849474225013006, 0.037649264634256406, 0.08938196791155685, 0.025548884802828395, 0.028602176105543494, 0.04046281063628774, 0.04256396764709104, 0.062313679861085075, 0.05977405625725946, 0.054669635400416396, 0.022708447199435006, 0.07127134294639673, 0.011677227336012069, 0.09433754554559147, 0.07297085538025826, 0.015070681786915709, 0.05576999812957741, 0.03802425318187283, 0.07835070782851788, 0.03963391499353513, 0.03382942383928645, 0.05405208809421428, 0.010894868661829782, 0.04487465736606429, 0.03831461965737324, 0.05033437064999054, 0.05028860455739403, 0.06299405786839705, 0.0369658567492039, 0.025105664634235927, 0.11195816535262332, 0.08404847910447467, 0.05986661500027103, 0.02553497264612346, 0.031116055324673656, 0.0344573746195003, 0.060328045078823646, 0.0242745109473265, 0.012310678627522243, 0.09668586550340538, 0.02903804374528268, 0.004401350367604005, 0.03255969056138589, 0.09716778843393249, 0.03228879038004145, 0.033409695756892045, 0.02051124383034485, 0.06641299719171179, 0.03490848549371285, 0.046060515507575006, 0.02168369543318066, 0.026022669964379845, 0.03166434445208119, 0.04529849551017246, 0.030950281558738604, 0.027219552111120957, 0.053216967987076896, 0.05543220698112442, 0.020173874030250217, 0.07676684402770574, 0.034148805894918983, 0.030474450942429326, 0.07722412190970875, 0.01708221129862772, 0.06113947008646304, 0.06565717484561667, 0.010539413441062696, 0.026966787146164045, 0.09100556869300143, 0.026395754783504435, 0.04057135763427904, 0.028076877276743614, 0.015869104367260252, 0.05534094292670489, 0.09067492514488198, 0.04864503569420307, 0.052852459522264625, 0.024383318415212057, 0.03768796356575143, 0.03369182678720644, 0.01838680732274248, 0.018540919315250173, 0.07651886902749538, 0.03105447526210018, 0.05359521240837151, 0.03479680136567162, 0.09338290806138709, 0.08226108106393969, 0.037212176999497804, 0.03679372828393694, 0.006686175521838689, 0.011977222579110776, 0.03721216933861856, 0.046750653475042314, 0.046071267551592285, 0.021491116250775034, 0.0773161214085356, 0.05489075135800147, 0.017790593650011767, 0.016140871185569033, 0.08039370344410982, 0.059849240126148354, 0.037260264338504885, 0.17718786313649149, 0.042682190335566, 0.09642351869373553, 0.06264192938444114, 0.023722757187281406, 0.02643986229574488, 0.03462498699645362, 0.007653822136607262, 0.039938729887287465, 0.032252010498796745, 0.009351995353016162, 0.03268126105408996, 0.0676804130536414, 0.022230590280566006, 0.030993575102559505, 0.054682356290399074, 0.08617017493252793, 0.07008673352820259, 0.012295924731710506, 0.007276999766022088, 0.06654115604056467, 0.08970116610608755, 0.040434967170679764, 0.03184842580418674, 0.04277872124446496, 0.015390635535661733, 0.036280560457418044, 0.03060550943407561, 0.05389214425738301, 0.03386891950222273, 0.04742532795775802, 0.029052176152265845, 0.04783242708072067, 0.0019760414462296236, 0.0368783924908888, 0.023182301308899637, 0.06677377863877243, 0.05493826030062572, 0.030761107637156403, 0.03477900131275097, 0.025463741790923863, 0.018931350280200283, 0.03223080901549228, 0.013863079197284196, 0.05952539560835689, 0.007391452823104638, 0.06756918474791512, 0.10713698252314523, 0.006197486119720364, 0.04831017866250008, 0.029738422393077807, 0.10773368840736729, 0.02445456076173052, 0.04896391213180558, 0.04518651260784076, 0.08631606105594866, 0.05605536205093226, 0.0395473585494103, 0.038072371164396886, 0.014467570450036757, 0.01606724439038625, 0.02930558654629896, 0.005759398740220575, 0.022688718520164974, 0.03449490909735042, 0.028440592840554255, 0.028558298419680328, 0.01403843385032228, 0.021802176676330068, 0.04675984653013368, 0.09922705575703614, 0.04288250317556724, 0.07584736231834659, 0.05372916671237158, 0.03127765391142138, 0.06096834902681651, 0.012123329910419643, 0.016932734138061924, 0.09689565102059035, 0.05137862893001688, 0.1268175974368088, 0.053677053581322395, 0.02234999082922455, 0.053721624576757034, 0.0577287815300928, 0.03407753290488355, 0.07674845791752301, 0.07240641711940689, 0.009069853788992811, 0.04225581644042846, 0.00912943531969382, 0.03459822371481888, 0.018747807104861545, 0.023600020325712623, 0.0049720968837068695, 0.011786368052144686, 0.03474517087001474, 0.1117947051722196, 0.061409592688564336, 0.07730185685138549, 0.010172976349901048, 0.06083791489682852, 0.060067716910834276, 0.07615520708983944, 0.03198689619650043, 0.08294783292278167, 0.05633197724819184, 0.022507795365527276, 0.07254638904405218, 0.036229175109896934, 0.06942631211131811, 0.027567361774403724, 0.005194191518615211, 0.05731335503139323, 0.04500327203723212, 0.04941380492621853, 0.04847628184624257, 0.051129083449561755, 0.0724394201871849, 0.025518070831294024, 0.018858566181734204, 0.04846227009810748, 0.022434350516226505, 0.018073402668139147, 0.006919633155883922, 0.06257446385138939, 0.048791339335542534, 0.021070424812815843, 0.06026561657387403, 0.06239670080943935, 0.029632941662003438, 0.031174212889445406, 0.025460583593456015, 0.04600605431703791, 0.054581029671094114, 0.009914940700025089, 0.06162230849205967, 0.06009622304249675, 0.06151507916529814, 0.016398414623953642, 0.014226089002594594, 0.05344065416964793, 0.04077988676726818, 0.030456754311378446, 0.051775255631054604, 0.006841119677354132, 0.09750891206485611, 0.018454253703596133, 0.10762812915228068, 0.048529666683246056, 0.027441872741966963, 0.050607086459715525, 0.018688130770779906, 0.016244373494578947, 0.10505736790477269, 0.027273930947206197, 0.09150076026637709, 0.018939143309610027, 0.04014145590425019, 0.07826980128283463, 0.05357084698193977, 0.027815101202577356, 0.04179764989643328, 0.01079769711190414, 0.048169969250598264, 0.011524524945285053, 0.03707652964118508, 0.09250989724551478, 0.1618729075116496, 0.2259231286664163, 0.2377881911853629, 0.21569865875907485, 0.10989037147092243, 0.25679814208659435, 0.1742720252443706, 0.20437209476386348, 0.27815203092271285, 0.10397010527911688, 0.1646262581550306, 0.11422246078690214, 0.27479104998130954, 0.16270812721021716, 0.20053267659198856, 0.15478985774661266, 0.234968711832358, 0.14422354408569876, 0.13625195490256434, 0.22165655518972108, 0.09546923360997632, 0.18854787453047692, 0.09019751447222887, 0.13352535604949922, 0.1479033554994291, 0.18768395717826583, 0.11006713859857091, 0.08399689840453287, 0.12502732656655774, 0.17465220403767404, 0.24823980616225352, 0.1055710911450367, 0.14403959105332054, 0.06678680979436444, 0.11670265512000169, 0.12212669551973382, 0.1492932075334172, 0.2640350529503438, 0.18118757754564288, 0.15463144608562993, 0.1290574087010276, 0.09303870475700787, 0.1303907540897208, 0.17811921154779775, 0.22769815438697416, 0.19642100609358282, 0.19247939179260887, 0.11011307323051077, 0.15149518937593506, 0.0720073619196492, 0.1179095576967924, 0.1582176568767717, 0.21667019614288885, 0.1615383569151163, 0.20353486791493433, 0.15379075651928303, 0.13793209297282083, 0.11048084139944085, 0.1354547484867996, 0.16115243246238078, 0.07853534267914873, 0.10717537884991016, 0.10151747478953294, 0.1404651780162127, 0.2519878606882788, 0.143074979104342, 0.15435968405537068, 0.11759537737816574, 0.12977059059325727, 0.10876148728834045, 0.06801717764427585, 0.0829293318994103, 0.19031986654285463, 0.14164300755627696, 0.08136767698752304, 0.08005627235698123, 0.1590566457279267, 0.24744707369996657, 0.2377573025202559, 0.19187229775613357, 0.19251944286929024, 0.11020835924653277, 0.11711496364084945, 0.2423052141262639, 0.10838438050761338, 0.12257247442199339, 0.12826007205031573, 0.17205538047898203, 0.27749169377550004, 0.19126022414815044, 0.11329629879084327, 0.13195679102453495, 0.16994814839093916, 0.10989521314660389, 0.18846961098813242, 0.17108157547491212, 0.0763846580840407, 0.11247323690763406, 0.1229288815070064, 0.14795290606637157, 0.2184420502594402, 0.14182861533857163, 0.15629371898549219, 0.12415797765096351, 0.1271719667279432, 0.15859705426039236, 0.22285615694859337, 0.09568932300974285, 0.10970370648729225, 0.10818674514490752, 0.08833256535111897, 0.30086690559983253, 0.07853784012578188, 0.17709099897934547, 0.1030834274546754, 0.15274233455138822, 0.1673556762116571, 0.141645627576978, 0.12883216352953067, 0.0645808749381573, 0.18266156135547548, 0.21698344949512713, 0.1216254978170318, 0.11403582644678893, 0.18978990223859588, 0.11255643405621091, 0.13714501423941505, 0.1314444773860516, 0.12856145870060692, 0.09631975208439174, 0.091516564660255, 0.10440833055444303, 0.12435497716069223, 0.11779731049412683, 0.17627934414532878, 0.13188171440795546, 0.18552748095845023, 0.26334762693412844, 0.1242530644841252, 0.13299969715937493, 0.18319118858104755, 0.22262749502495413, 0.19546030119301813, 0.13258577985388617, 0.1009885523648512, 0.11799494585683269, 0.17649628492372652, 0.1855698915859384, 0.14319527023021253, 0.23777138321630417, 0.18533750647498717, 0.12293870275419568, 0.10679605807508193, 0.15313676258008327, 0.19572328385566512, 0.24105577068703793, 0.23654317573433925, 0.1960724360880352, 0.16116545595709356, 0.15940688580514925, 0.157621625149923, 0.12399777334423796, 0.20184256436844028, 0.27615002867194915, 0.16783365378937415, 0.13077009018630753, 0.1006880007503975, 0.22629829724469494, 0.22316386382425987, 0.17007864380796112, 0.19238923856567955, 0.044055406770278374, 0.18382983011824472, 0.1236135955719698, 0.1415638400301818], [0.06980469059799949, 0.05618113453590101, 0.01912029629062501, 0.044054977761040774, 0.10155502075870192, 0.0710409113596524, 0.016063084532957406, 0.06497235352834387, 0.039587650943787835, 0.014448006479670445, 0.04072724120511163, 0.006284094274780083, 0.05672623673754354, 0.0749797600832197, 0.08207610147374292, 0.05741418369354741, 0.04500991401953563, 0.027125457361821207, 0.04489184837908514, 0.04399709981836138, 0.025981134592345165, 0.007072170837707217, 0.01859365489273783, 0.025267874176103263, 0.05611509009594879, 0.04615936383244492, 0.02509968914842654, 0.06960260426445354, 0.04389284674318568, 0.028369304528760336, 0.039469332494322336, 0.0705419889380855, 0.04539878791077964, 0.07551271213038314, 0.03456624337441979, 0.03987166271995633, 0.059003992336651975, 0.03257538770295439, 0.02626979460699424, 0.013582979257579052, 0.05786776520131577, 0.019720983916833516, 0.009982185025188712, 0.024410357488499537, 0.0414511444978416, 0.06304503335887868, 0.019905727934993563, 0.04149698336879092, 0.09105210087352222, 0.05388287076305959, 0.04168566699410158, 0.05205048037873161, 0.015605922521752937, 0.046445409572052385, 0.029920148024816188, 0.08382227632307238, 0.06187798650634866, 0.032362338651212, 0.015392137067993323, 0.037145220914915685, 0.04427268079692318, 0.011670742401733034, 0.027866988337688872, 0.029590986856830218, 0.021982119238424688, 0.06475499906246701, 0.05287409384524631, 0.030686132527226885, 0.057816107892581535, 0.07406391729150089, 0.011473039048723878, 0.00785436959103531, 0.0187624566211936, 0.021855896676800424, 0.018402341670627077, 0.0105432802698605, 0.032124849479465235, 0.058749371523698496, 0.06230850876759618, 0.02456404430220925, 0.08405699800219267, 0.04528530730655597, 0.060867252233888836, 0.06938141935895528, 0.002983186596764192, 0.01395205073359032, 0.03704978934218807, 0.03348345470224177, 0.08108482966499944, 0.036728354170918465, 0.0168407020804983, 0.0864838726157623, 0.06531583671007427, 0.051332985411488244, 0.01982286211944396, 0.03305524602652558, 0.052887730210298495, 0.03396868713260178, 0.026915116430891138, 0.06946166706902367, 0.03638159596331177, 0.09336164146060906, 0.05322586992875703, 0.006568217612502556, 0.05255923553880665, 0.032066910249751904, 0.042737701066559365, 0.07051847769968933, 0.019292614362653226, 0.00538848769558113, 0.01867488319534929, 0.04981494005469065, 0.004288820670016351, 0.058846335272274675, 0.05424763203688687, 0.040631905393374544, 0.0954501886641787, 0.06572521111417202, 0.008018466582026092, 0.011432322433158275, 0.013380469660454941, 0.06578885769892125, 0.06637878370501342, 0.03996163208578383, 0.030510830542733593, 0.042982209518912344, 0.03412484266464749, 0.018366971391163046, 0.05344382960409407, 0.04509696459037162, 0.06388590678632741, 0.022683947707616517, 0.053526651369588035, 0.06747844929416334, 0.05602232067875805, 0.04756196356949307, 0.041510244350760214, 0.004254533926160225, 0.03280353634768436, 0.038366686823146964, 0.09797522978436563, 0.05895253038033844, 0.0606769253499806, 0.02436573478213001, 0.01979779189212188, 0.025438298095738696, 0.06960104144508801, 0.04304838802425131, 0.04582671313396385, 0.04668296194605289, 0.0896590082876144, 0.04958640836599854, 0.07966770490090694, 0.10969033825301355, 0.028095726870120536, 0.05259511909717995, 0.06597699357136604, 0.018663782581326463, 0.019916479979010842, 0.054346422905162464, 0.03893924944643532, 0.02723157777631235, 0.03751070614183142, 0.021056602671442014, 0.06155291624787835, 0.08131483990338542, 0.03522963721245047, 0.03245262977396769, 0.03548936400141928, 0.10990037657921353, 0.01299901437314768, 0.027247759468492963, 0.021701248422745737, 0.010331084448543769, 0.06886781869275917, 0.018810103459644224, 0.005342317970409509, 0.05921263255239014, 0.010638835374265911, 0.07267205810715115, 0.013967585081474916, 0.046476765550793185, 0.030618852770496762, 0.0833246102857013, 0.08340481969137346, 0.02645908918742451, 0.029111969314755935, 0.09459020134301917, 0.06232620539864706, 0.054138625386141004, 0.0509712731675996, 0.04113813629373908, 0.03909345528471374, 0.027199905786302783, 0.04627159571335201, 0.03195310788860004, 0.01809350673049208, 0.011920835635054016, 0.03369624711452954, 0.027149328661541787, 0.055395890583073905, 0.02215619931267875, 0.01581344041868203, 0.08634581591092771, 0.08750345137330794, 0.02082051352537688, 0.03475165580429378, 0.004098464579005996, 0.044485741339984446, 0.08444132133116646, 0.04256233587981232, 0.042326545508037654, 0.023691619543599027, 0.05822426038644007, 0.048626530840392077, 0.005416851622172662, 0.014230558168022864, 0.020286563648692062, 0.05309579586009345, 0.0259280217165548, 0.023492821642468055, 0.02802458411503223, 0.022971594570985725, 0.011033469289090606, 0.05098912301623533, 0.029593779247314222, 0.03226788767102746, 0.02733681910491038, 0.042051133068819205, 0.009198582415739376, 0.011535675355022954, 0.03858979460933516, 0.025256292841907953, 0.06725747123240464, 0.05684475053942973, 0.05595211255093736, 0.02423162343010547, 0.02012237376954046, 0.02695390729293708, 0.03209675512006206, 0.03272767832142211, 0.036938970893501274, 0.011736065761426525, 0.04828931042744268, 0.0758673035870156, 0.040296424000013265, 0.033236096402810465, 0.046811285503809495, 0.05109054539653082, 0.015139902618923977, 0.03419372546035917, 0.03278612316916547, 0.09724969089391733, 0.016909538910934524, 0.06695073728840198, 0.045914778771299514, 0.023799285540477406, 0.02229295941370149, 0.061348922355400945, 0.02097734704523558, 0.01464136228370931, 0.010647977676032292, 0.11984009926597919, 0.046101960864278584, 0.027846930240611398, 0.0034749295774682038, 0.04552723787304375, 0.07497514823391553, 0.017958749949391332, 0.01929997455238575, 0.002817702747227985, 0.06906020635318372, 0.038916002508373036, 0.04785171717465405, 0.03649007784382951, 0.045862240461452354, 0.08026917585201802, 0.061309434353343906, 0.07942562111683431, 0.09206389617775718, 0.03455220864364698, 0.01572515836150776, 0.01571383079393737, 0.029355968318639264, 0.05151888047675452, 0.004575345214576491, 0.07950679579329106, 0.06456894694917625, 0.00975884453979351, 0.04151565676194526, 0.07537373612003942, 0.04651043128462569, 0.10055453291222935, 0.03571425677247105, 0.03343529075444226, 0.02144466450948629, 0.02578345134914402, 0.03447722012717878, 0.039339208629943674, 0.03168375712008246, 0.05642203854457025, 0.009824979952686738, 0.0316735087788754, 0.02774816427019335, 0.052662906387159904, 0.10450720952282991, 0.02433271830781333, 0.016001116638372264, 0.09318007096167534, 0.06896852861128508, 0.08817115062547308, 0.014068921276878928, 0.03258165047173539, 0.022594859342901938, 0.026939472281223825, 0.020740941887901678, 0.03375418634424287, 0.06277907444464584, 0.010134301358653654, 0.040563788685587146, 0.023864098494091344, 0.05308869039459575, 0.05253647123613665, 0.0502553295284029, 0.015400971019370182, 0.05323033622135559, 0.04534191737372068, 0.006255319054734203, 0.04955753068169279, 0.04316397920070637, 0.028023151530613823, 0.025280884264277357, 0.0336561155986161, 0.02674101528921916, 0.03391055255046776, 0.10330263585332902, 0.06129228930559851, 0.022600390497715245, 0.02147793379281798, 0.03771213363976248, 0.13528715909248398, 0.021175309910529086, 0.04740283944674077, 0.01830279237530645, 0.03129637518507098, 0.023797512046932697, 0.05348720167192721, 0.09217242785398999, 0.0184576666252988, 0.024053666950954546, 0.02472316650974174, 0.031507246631888614, 0.19798685916729514, 0.14576783944522181, 0.11399246587027466, 0.12259587840808016, 0.21925911367420228, 0.10068919584755937, 0.12305042135619348, 0.16862336786523943, 0.13353617321099007, 0.08830035135390298, 0.099257277925649, 0.18776474881076044, 0.15238985749742678, 0.14254735902913157, 0.15447076680439134, 0.16287577789156668, 0.10862689330092362, 0.21379217235071046, 0.12595646098376284, 0.12710553924402884, 0.1568757925903605, 0.07097982350857028, 0.15083702791842724, 0.13005773566903608, 0.12899808285217132, 0.09649829653602454, 0.13285836925910366, 0.21280656959260666, 0.14481392208366625, 0.08096928062338023, 0.09583795172793251, 0.17764520230552844, 0.1464917772119084, 0.2256889202662053, 0.12754523540816962, 0.12664345032986135, 0.19561822255772932, 0.15514944409651144, 0.10121090172399437, 0.14446498435591498, 0.14354563288150296, 0.10059973976064114, 0.15418804971681488, 0.20824247820963784, 0.09079255794565524, 0.1348452029689666, 0.07891860114590776, 0.13071438027245383, 0.3428219559211885, 0.19530696103409415, 0.17716958427861815, 0.11473004000201342, 0.09694646563260786, 0.12341671863630896, 0.04574575679256551, 0.19144748668036154, 0.097954606697444, 0.26628781110048294, 0.11266442947089673, 0.11695049988526492, 0.11577896758793824, 0.07505160380875872, 0.13416160739237262, 0.0872827337814435, 0.11147779758058249, 0.1438918280144853, 0.21874920555180122, 0.1433483958845177, 0.1588133668466922, 0.17995233737653304, 0.10665423987853913, 0.13857002970912766, 0.09275308419619838, 0.11439715947715506, 0.25200377999534535, 0.15279044487303303, 0.19095060205267322, 0.1538037800139958, 0.16749367929033696, 0.13302896171808243, 0.14231482070059548, 0.131838537692543, 0.13468737353480634, 0.18781180193106975, 0.08921613285858786, 0.15195485745226184, 0.1909949125782136, 0.14000630667132719, 0.23091722520128374, 0.16530868927797965, 0.08909378095620102, 0.1547253837869052, 0.15923575708462348, 0.12664961733765182, 0.110699214762257, 0.2208309575554825, 0.18061950802803042, 0.11958808698240789, 0.11059649003249024, 0.14888721157706555, 0.18628054538801794, 0.20487667091431158, 0.15056548039278678, 0.17610159642513723, 0.18362788934140437, 0.1250518720236517, 0.09261965466242644, 0.12352690506245821, 0.12906255681187878, 0.1624920444502946, 0.10901136984748226, 0.15758086927235126, 0.13166101979872874, 0.18815864057790851, 0.17184121293887017, 0.17882513092650523, 0.20353025606563016, 0.21408612028725688, 0.11640487674383387, 0.2037015226819823, 0.1680655026387784, 0.1316709636199859, 0.27328084553441695, 0.1353225217110688, 0.12726339166082684, 0.08301389268449239, 0.09699306676104184, 0.11070328268913493, 0.16470893436381895, 0.22442302125836575, 0.1806863875038201, 0.21143136515973077, 0.17722730134283343, 0.13016819022595882, 0.24368015808924554, 0.10432269724626696, 0.1417185591473695, 0.1352763725745101, 0.11824842902921862, 0.12339829422173001, 0.20967415864429167, 0.14695861587120643, 0.1269475182878875, 0.11909471869829202, 0.10790941365543874, 0.19790219112990365, 0.18140654079616073, 0.10540598387559576, 0.18003536598576655, 0.1564314922377948, 0.1659114779003205, 0.17573719904307397, 0.21193790249526503, 0.2408197543193256, 0.11411895464745261, 0.10221552644525805, 0.13599516223034552, 0.10787730691053214, 0.14158334462873398, 0.28187904867433733, 0.09618548751478234, 0.12010847518761313, 0.10780548616763085, 0.143658462310991, 0.2250611724992914, 0.1860445290203056, 0.15435707935642812, 0.08038125451534026, 0.13110407387777684, 0.13319949289002728, 0.16275856643915176, 0.22442228581395843, 0.13870334432971093, 0.09629601868049753, 0.13307794537996093, 0.13677035127916645], [0.04504387086677936, 0.055260178107287616, 0.044037763765382196, 0.0586467310636034, 0.06885882482052812, 0.04560573890264477, 0.02370694513252426, 0.01608233057683514, 0.02282262877410939, 0.03134463297864122, 0.028430658595396147, 0.04631652293967144, 0.06288413574258167, 0.016966909320364078, 0.023024713192435525, 0.04885733014934006, 0.016020585805357947, 0.023379277835990635, 0.020240542831860726, 0.035999946281193726, 0.04224317215923821, 0.014793217189670091, 0.026681570696734616, 0.018617348077016014, 0.02067607530813304, 0.05692316346891946, 0.044823904041080706, 0.036902665986769626, 0.06159969740697454, 0.036162376073339296, 0.07925678299920214, 0.032882347642894716, 0.03695882789249863, 0.024060760925133384, 0.05246977179100918, 0.01234613796470747, 0.04744235809231478, 0.0014155849273647034, 0.025907007924791788, 0.04541816610482432, 0.07885166804396337, 0.067453260323213, 0.029846256929299528, 0.02529823807098212, 0.019354380201548338, 0.010941790589582055, 0.04790328255283737, 0.036874385851044814, 0.038030619372523604, 0.031114940666743827, 0.03475973803189493, 0.048987534452950766, 0.055477781551739866, 0.049344914469627604, 0.0340137560851872, 0.017993041960101937, 0.06466142142251616, 0.032599829738178564, 0.055766428159850265, 0.059198004103476004, 0.06421576509432447, 0.009594207456816108, 0.06416269818380957, 0.038425859454418385, 0.013845838388548264, 0.036106918968500636, 0.045259922983184944, 0.02040845206788471, 0.0053425272081738286, 0.019653120018061132, 0.005461336911520771, 0.036323369450626836, 0.07432163693010807, 0.07887150206032299, 0.010971737924152085, 0.05982615406655016, 0.032558556751257954, 0.039677367500600316, 0.04077984846287197, 0.10005950221731778, 0.07567480867428165, 0.03669658067425893, 0.028641681344578826, 0.012656139273707186, 0.06766220314368125, 0.032333805706472166, 0.018434126658605474, 0.09942015587923028, 0.1043998959263967, 0.06051749862249821, 0.07453474726888441, 0.09794329157880238, 0.03668795835467116, 0.013362718445639457, 0.047367503641233336, 0.01815144212976579, 0.05494859865716389, 0.03799805297486244, 0.008602894470846702, 0.05225048678356314, 0.06776066842458903, 0.015124214095844617, 0.09176942730142225, 0.031726286491198886, 0.04336085613636721, 0.03850246824684643, 0.07686602177038308, 0.020865540343126463, 0.09724028333420716, 0.0566823092559653, 0.05818370369172866, 0.027797427554164204, 0.06618271116167307, 0.021713157259528677, 0.012583788972528232, 0.04404645886332278, 0.08069419377152959, 0.10976013652379475, 0.06815348766864308, 0.06029041100954337, 0.0027274312554753477, 0.038242120926658955, 0.04952624365086517, 0.005286050727590919, 0.06815262965016788, 0.019681453779940645, 0.04661088839413659, 0.027636541429186062, 0.0190552381888753, 0.010865115722070539, 0.0540011202646119, 0.016809361423515988, 0.036103758855812976, 0.00596184992314046, 0.0634518260466716, 0.04865551194656761, 0.05939534069189142, 0.030238997649341345, 0.0341100609981485, 0.026363023676939552, 0.03580924018376297, 0.0335556393369071, 0.013523220569045554, 0.007312706645367848, 0.02749343428971066, 0.041625421839736165, 0.04213491627465814, 0.04428531741723419, 0.063459521399871, 0.01975942620887391, 0.04006591197403689, 0.04601206810724351, 0.03659847545467558, 0.06597900072172766, 0.020454907639613076, 0.049413923669846795, 0.08985272128014796, 0.017048277434021715, 0.0511503002546247, 0.07037372538639654, 0.049428490831726984, 0.045389656142722216, 0.12303097804467525, 0.02997477583947682, 0.09228674349405112, 0.02341810125677336, 0.08249150498980477, 0.03330342787047548, 0.022296489163812612, 0.03058019405861776, 0.029358787522200617, 0.048218742238297585, 0.013236034316040817, 0.12641153253254392, 0.03133922631311561, 0.010524900862947108, 0.03328408031994778, 0.031036246199941928, 0.09300020883881277, 0.00950998470803062, 0.03010921469408899, 0.0445416810802154, 0.02722677057458749, 0.04582220087608984, 0.011856954435877984, 0.0706882810881061, 0.033782006827213114, 0.010645526194674595, 0.044843155830617876, 0.023751935561097438, 0.02168899101595725, 0.01113212704958935, 0.04566902542606958, 0.008076157311968988, 0.013451247566169309, 0.05842001500329184, 0.04704544410830544, 0.03751516477355073, 0.010115274607444243, 0.059203707628072276, 0.03793400419395297, 0.014029785675267059, 0.018165559214990468, 0.03253135296906675, 0.04188198085513808, 0.021947382896718, 0.02907567972978277, 0.12365377688359831, 0.050902103088916316, 0.05667564812146368, 0.020592648333178896, 0.05407381051730725, 0.010862443032824706, 0.018362131630701405, 0.023992860637184595, 0.048065578279596184, 0.020307837910349333, 0.029509745147680084, 0.04085186072775433, 0.03621851882687019, 0.02444999679292162, 0.035452262363246376, 0.04485024980479672, 0.008862346425772676, 0.02105086084244953, 0.07188074290752411, 0.07439443826555245, 0.02807762804290941, 0.07560787557233727, 0.04595047463813136, 0.018908679823301012, 0.0618104137209875, 0.041423982850486235, 0.059723111410294814, 0.037027875397114024, 0.03947097575291991, 0.05406224258965062, 0.03315493321767257, 0.03441891700570141, 0.03803179531748738, 0.015114042363429983, 0.07494281932351089, 0.029251789937036175, 0.05801092022128644, 0.04428535189119078, 0.065762757083341, 0.062453881612107645, 0.009773788042366505, 0.06879071194318033, 0.0421710794551238, 0.01630859081483176, 0.08570387253477689, 0.0030938049049807656, 0.0352053024295357, 0.03165077320450256, 0.06424388818202481, 0.055224784845185865, 0.05418676252086317, 0.049713950514072375, 0.023829800737721306, 0.05175491216622534, 0.038651116117234194, 0.026998192920619925, 0.016129048533677574, 0.042530175508751024, 0.01542198193830348, 0.0729781102329012, 0.03166450916098491, 0.02211055770936993, 0.03194930809249561, 0.013234634290359194, 0.0513088689636319, 0.006834163120196712, 0.06369004108672661, 0.03327314058438905, 0.03149024714084883, 0.05233317448367035, 0.05677363076697915, 0.053868625358107596, 0.03359325808442889, 0.008098391098751417, 0.03455330031893907, 0.04526930756025738, 0.014756296539769299, 0.03248341118676528, 0.011755029310382182, 0.07802304436242388, 0.03585266587775081, 0.04242850798031977, 0.05067137272788152, 0.01766014228304548, 0.04973050184367646, 0.045733836464463704, 0.012799722345305548, 0.05068759463967816, 0.04239362799712727, 0.05370345680163272, 0.004344796320618761, 0.08811978443015007, 0.01941995732786675, 0.09017764981235228, 0.09913577638085812, 0.06354962483108526, 0.058249457018269654, 0.018355847794502493, 0.020703593186373194, 0.06988658539710507, 0.04520905474501272, 0.058978094734371676, 0.04027889973874535, 0.0340945975133969, 0.05436773930165557, 0.018549704428521857, 0.036842746419772025, 0.005373482905974191, 0.04331588677521195, 0.0433960578764879, 0.01938582044996081, 0.05697327711048627, 0.0151084432183134, 0.02664899280775459, 0.02209788469988252, 0.029742905922654658, 0.05943806541542854, 0.012520931458341019, 0.032271350388445204, 0.010200496143361014, 0.01834187626598343, 0.053570237942039974, 0.00967373791706538, 0.07358125891656646, 0.022321729845697844, 0.09210227718276363, 0.04255814154842689, 0.013568699378670465, 0.0799955215845858, 0.045221396421472874, 0.03767978557715974, 0.05994086807233192, 0.030343363722485882, 0.06289774529455651, 0.04447212412713036, 0.04587790312906427, 0.01813630997804144, 0.011509040393115533, 0.012609071789249297, 0.03196763674608402, 0.07534558238882212, 0.031937985312974745, 0.04383176655298279, 0.02508376409570056, 0.036405693258970015, 0.1507928859322302, 0.11670067861315706, 0.21702463438193645, 0.15383601699384952, 0.15971742720613558, 0.19234269106340027, 0.1563751694536017, 0.115700428253941, 0.07062913910035165, 0.14725841671949433, 0.13546768005096144, 0.16394099250676172, 0.1283160500949429, 0.1864927057777682, 0.059797548343457525, 0.1677581175200401, 0.13047373673367885, 0.12273893000618105, 0.07235495133265372, 0.20632759547762333, 0.1334131548121091, 0.10504264369486802, 0.10557628522116332, 0.10425211756580299, 0.16736467008388814, 0.15611290691360352, 0.12106076844276921, 0.14715713989590445, 0.16830154965000768, 0.12185180785074351, 0.11346394947219281, 0.21416469026477108, 0.11567029035499982, 0.07456673910060237, 0.13549430926720943, 0.08892699595420592, 0.22301910385008783, 0.16346920491947284, 0.13961224636483577, 0.2062020030233168, 0.15537779958498094, 0.14576972402151556, 0.08500048124621953, 0.13450947259702992, 0.09798093713940152, 0.09588534958780774, 0.20910569076095858, 0.10227478334620115, 0.15327331009170703, 0.19303027029720046, 0.10454738317357917, 0.11026743994725328, 0.2148781173051365, 0.1024733073708992, 0.09663152688693616, 0.11091178883948635, 0.17702727578580382, 0.16284058381232525, 0.10758303721705753, 0.16303106391381833, 0.16488655950994263, 0.09049042819007751, 0.10771093559601616, 0.20192669614428477, 0.18809310941686555, 0.12384809508559205, 0.1224942108796489, 0.2089297816517853, 0.11585226688053339, 0.16592033387672517, 0.15289075642583833, 0.08578502422859592, 0.18321055528377334, 0.14076496354274212, 0.09306211640397388, 0.17167920066464334, 0.20920083888115423, 0.2363076803064154, 0.15497119075828983, 0.17521872605767944, 0.143786215133244, 0.10753878797855108, 0.16852062015283495, 0.12220136610971344, 0.15254440807527112, 0.19780361093580726, 0.10691169904725206, 0.16937532912819617, 0.1636964725630899, 0.11127247835599607, 0.19944785012593194, 0.20916072651743892, 0.21045135484347421, 0.08346394635736944, 0.1458066341377074, 0.12366206595493902, 0.08190798347875958, 0.15395088421721614, 0.09848660879558134, 0.14567422350087475, 0.14755449438047025, 0.10245992381486202, 0.17985158149273167, 0.07539207626494669, 0.13785526967577397, 0.10942396948174124, 0.09274428950682764, 0.12415053893721874, 0.18975552021255418, 0.13595244516768765, 0.20989715151729124, 0.14855892757975286, 0.20049729865164528, 0.16408161560614265, 0.09832189223098178, 0.207310164527547, 0.17220014045315404, 0.1360477005401927, 0.14678456069480988, 0.1739781539166166, 0.08420515940674851, 0.08535350988348646, 0.18963884502168626, 0.08580344098229563, 0.29176829382777214, 0.21019405655322537, 0.24430447378225867, 0.13227609647137503, 0.12520388685046666, 0.09749061022434505, 0.19193088816058254, 0.12832326664318963, 0.14095020360283314, 0.19363390161625801, 0.14925579179919538, 0.0966084982839323, 0.14024943233497683, 0.10301186718166837, 0.061735861874636144, 0.11004503696195542, 0.15552026129538016, 0.10718353002542451, 0.11663272661427337, 0.13807806336591322, 0.12312062565357455, 0.17613329714344395, 0.15383060841310411, 0.1437849281055312, 0.10910051183835154, 0.10478310076700104, 0.15855833617669923, 0.1349470926628959, 0.17854465081566767, 0.14003744048456992, 0.12040723415632403, 0.15166290134431856, 0.18834728206838333, 0.15916484798635208, 0.11318472574555105, 0.24867958659606598, 0.10643007489101541, 0.15588715612407655, 0.23688080600432812, 0.07773255148241598, 0.12133582465110287, 0.14135935584143286, 0.1969099387286171, 0.1666433676596611, 0.09201115868504971, 0.09442974422727862, 0.10663672710859007, 0.1860901112518003, 0.09782385847140705, 0.10349641779377576, 0.1624328718190232, 0.09170632463909927], [0.028822884121308887, 0.04614383139978013, 0.038972677693011305, 0.048173351528783964, 0.06259597560030318, 0.037177917547523975, 0.04355170012962434, 0.017984948241181912, 0.018278852127672687, 0.01905485706013297, 0.029730307606739864, 0.03331768476674634, 0.031141885894260583, 0.08919524164089272, 0.07332995909476474, 0.020500727358364293, 0.035794780274192174, 0.06095927854579303, 0.05636060212348258, 0.027947607600400527, 0.040286572109307014, 0.0399581004204529, 0.022277438472355568, 0.04663677833553764, 0.05424199746020379, 0.0165628285838231, 0.02145040442325896, 0.15391975040397338, 0.041487813296337286, 0.03956707382214166, 0.06583286945017115, 0.08279292228361292, 0.006241175156432174, 0.06705931492991025, 0.017154821112091025, 0.05300026086549606, 0.051988909892257185, 0.05559626471010908, 0.022570189396520297, 0.06107161001813027, 0.023649406183751363, 0.03139923014978488, 0.05237358945211577, 0.08258679866670601, 0.05028233795817341, 0.02981908570584511, 0.0049985992166424, 0.05031701875850559, 0.05118771981928618, 0.0388822065395934, 0.06039290208249323, 0.058721830662820614, 0.016001605977033897, 0.09018341079354288, 0.05570886814365945, 0.1276806567705447, 0.05369805588176655, 0.08452013645681643, 0.007417285307911375, 0.05883403573065035, 0.07150067136653009, 0.06290234948298143, 0.03215037744432207, 0.020712523856350494, 0.002918610651601827, 0.1176567410209006, 0.02196349755620524, 0.054644726051558415, 0.0509500295494593, 0.03375512097151049, 0.04734609148374969, 0.01845591802961163, 0.05012657313096908, 0.04808259309239445, 0.03597263141625351, 0.07277609284726844, 0.0521084119475657, 0.04491832437774828, 0.04098122616508796, 0.018914724257023587, 0.06913027275473842, 0.028004594965867942, 0.03340153692049846, 0.03034807707844002, 0.012962881836198993, 0.05014601644248732, 0.037558307015006585, 0.005212871136233932, 0.03778184381043238, 0.05758586016693904, 0.03548100598216538, 0.039636688231821024, 0.023107337690288984, 0.07483427998639884, 0.045414492713227395, 0.014914096288022496, 0.02250751191299529, 0.07211656009237613, 0.03284567884439903, 0.021015004097153584, 0.005198092821369609, 0.02761146545620455, 0.008391205225169899, 0.04674826711115818, 0.04789705425801297, 0.025380826179659175, 0.03843383826014977, 0.06597649561421526, 0.04776844341728476, 0.11794563277714676, 0.09086793333652521, 0.031149927902245717, 0.031184283115210074, 0.016687827319988323, 0.027181096412541888, 0.0461791557139687, 0.07345041109909935, 0.03542771690615243, 0.07108737459226001, 0.02355068809382858, 0.041031079336760506, 0.015474771141945837, 0.03077046540115149, 0.015216132197829505, 0.033399594887610407, 0.021582483727064346, 0.022500050216612798, 0.044662910663793166, 0.023245894267494162, 0.004001524531274974, 0.07816731404032438, 0.05334916794973035, 0.12116977509351508, 0.06604189654031108, 0.037914541730236624, 0.011240998677338564, 0.04969647604851954, 0.03240385678626838, 0.031551741018530824, 0.059733836641234744, 0.023810188886859728, 0.013987905563666456, 0.03946781947067188, 0.019335875347737345, 0.03433806025573323, 0.046105825777856574, 0.03615895166031776, 0.05522816329293194, 0.055316236591146845, 0.030002847216242266, 0.04132066823301777, 0.06647040015987812, 0.03582930019606025, 0.020368282247575063, 0.032049207873041594, 0.027398874141996907, 0.046569040841272766, 0.05516114209087626, 0.03396182298480022, 0.014297063218339557, 0.040771268278120026, 0.051012438902210806, 0.02625507231230938, 0.031319963032259576, 0.02537210235342143, 0.06906638868273267, 0.0027556661441321337, 0.03662657172929856, 0.07000851595113355, 0.05915216140208706, 0.039194479299288605, 0.04699819180513582, 0.02891193609684706, 0.020377846855309703, 0.04560029584794276, 0.00479475662653004, 0.057837462593470855, 0.013045916191091942, 0.0428858433189171, 0.07819211230643335, 0.10587792468046951, 0.054293034237719355, 0.09858635344332266, 0.016495083428678975, 0.0263503793957493, 0.07114771167717635, 0.0035212702360079297, 0.029231597774571953, 0.003733097856316055, 0.05729772300729829, 0.0636241230512819, 0.03568858516612842, 0.05897786873843401, 0.033050274115897, 0.03869999252680329, 0.033062248070153503, 0.041135680981941765, 0.029483987356445966, 0.033820717250027006, 0.0008852331501980042, 0.02636525490801902, 0.02592350945868079, 0.025382348779408682, 0.05153533604536807, 0.027409281446448257, 0.03976780418006163, 0.0410597846512833, 0.048361284387928825, 0.07124514273938633, 0.04540004812541508, 0.03038661896191057, 0.08174907386062608, 0.03781470515194439, 0.09073700891026566, 0.05893012613899285, 0.06585013707198444, 0.019944220022749037, 0.016702155079392177, 0.03581824554731289, 0.036203821430042867, 0.020263824243879607, 0.024625812056324175, 0.020304020877266606, 0.02168847007616874, 0.018894317589940566, 0.04660936387916727, 0.01219871104694903, 0.0662755303745789, 0.03305484766080495, 0.04276263339805507, 0.019739910119002866, 0.04817284974119356, 0.036851023999793876, 0.014624936401002831, 0.005869090082048769, 0.06722585478376958, 0.05513673836004831, 0.017756696174582167, 0.043358822172928246, 0.010017463374101828, 0.060102527946113586, 0.10513495728974381, 0.03352390031420416, 0.022136895812206694, 0.06113976886075351, 0.024077812127108057, 0.043254519302037456, 0.019697794435365547, 0.06721197327058162, 0.059449732934515324, 0.03645298386653585, 0.051984750034828345, 0.028506152729894367, 0.05030357008499484, 0.05846167103417459, 0.025190447584816048, 0.04970807845013277, 0.011552423952267537, 0.03541300418756662, 0.029849991607930393, 0.02347343961798376, 0.051206374060242414, 0.041502993328556906, 0.027333153374192697, 0.013022947917512108, 0.057425012346357114, 0.04159673184697186, 0.05083793556437858, 0.03536198656224916, 0.03609802468769974, 0.0502528052686924, 0.045860516763622725, 0.04023965688482408, 0.02051324140460741, 0.008545775912822256, 0.06884801531991652, 0.0412342841586759, 0.044970085108352285, 0.06248573937843885, 0.025347817366221742, 0.016140306195724877, 0.05629724282170496, 0.09881034989150302, 0.06370243638934148, 0.09624431540648784, 0.08215899984802931, 0.0628945392165934, 0.038163340274965575, 0.04389850430250649, 0.0647726267456047, 0.020771593065752138, 0.01945374755098695, 0.017331021334675532, 0.021127848848400098, 0.049259932336187175, 0.042247787838982004, 0.026941849069008907, 0.04898720886558295, 0.010537148693636542, 0.05129858423324843, 0.044433302621567444, 0.026915897840573907, 0.11966643479442406, 0.013493919621161638, 0.035480757003589984, 0.01448937331236178, 0.04654555641595395, 0.03360539674758911, 0.08408473804593088, 0.05176078423016495, 0.07220820719075781, 0.05440227071484251, 0.03210246822075739, 0.010002422195318486, 0.022871045530923916, 0.03557806166129247, 0.015082273654819978, 0.01824837906526462, 0.04654215881600977, 0.062432798872431444, 0.032921012100433154, 0.041290323490337025, 0.07894564404963486, 0.04078655173220942, 0.03791289847163904, 0.03488231209977981, 0.05416153141507699, 0.0499010521678194, 0.02954829086159026, 0.03029006698559369, 0.050344793276200374, 0.0328983627109518, 0.013697733482976836, 0.060276460548442226, 0.039230665462392, 0.06440212364278494, 0.10036018406671864, 0.0775486444153132, 0.002020621299555886, 0.012126243917361624, 0.05365153519256462, 0.037480882338939175, 0.03519276923109447, 0.06754181242638058, 0.03843807855681066, 0.042451563396400986, 0.0425141527798147, 0.09150146506726743, 0.014622754965638442, 0.0383197141420697, 0.13427730199069748, 0.0765551126471931, 0.09038538987477941, 0.11667227207292473, 0.11906929990096439, 0.18369254716221364, 0.21545464443343304, 0.15464321319614688, 0.13191883902876608, 0.11010383421014394, 0.10125790887902822, 0.16975990526618498, 0.14608691506568464, 0.13079622910628397, 0.08128717646843965, 0.19240906492115992, 0.1717726174261301, 0.1315194467503217, 0.12919702056434848, 0.22227622838991307, 0.12563833531232613, 0.13900283874282915, 0.11767752498628632, 0.14714025531805333, 0.21591219810708878, 0.08395186775634367, 0.09975193323747766, 0.11521186334111037, 0.22480084050086238, 0.24367674133710324, 0.19182942747589082, 0.12207174403292519, 0.16771838820028692, 0.19638850864383484, 0.2436196218214689, 0.12018312279495502, 0.1754525820574453, 0.12635009994189586, 0.1363554993464101, 0.16193932733468472, 0.20739461806031967, 0.16058198807220306, 0.11104861214276283, 0.10496073357400396, 0.207991584414436, 0.20213413743242142, 0.13450813960404168, 0.11344718746840955, 0.13412889543800585, 0.12457421620286281, 0.1350673991105249, 0.10120112644208056, 0.1319418216664945, 0.22956183180212977, 0.1789464332884358, 0.18144121393561366, 0.1364039161032246, 0.20732370896204827, 0.13006597877510134, 0.12060680772147833, 0.10899537393162329, 0.21364799460336087, 0.14962202779227687, 0.200457661262443, 0.07691315149948483, 0.11843362312403419, 0.17485083531468146, 0.25544098668521453, 0.05929652301053848, 0.11406645464200167, 0.14529640425837811, 0.127771882520568, 0.1466962767224158, 0.1738162029294237, 0.1474066700546011, 0.1694687918549584, 0.12190570213621664, 0.16473671271195336, 0.10577205899021319, 0.22900051918000947, 0.11798266546740649, 0.13494332351030844, 0.1160487607722321, 0.13147818525471996, 0.18340812935944528, 0.14703297236513707, 0.21926611571783022, 0.181009630642591, 0.11285654133966855, 0.06366305947003346, 0.13254675533502333, 0.16418943482060588, 0.15204006175120033, 0.1355292735200736, 0.09865504854749288, 0.12598529653323273, 0.16394209567337267, 0.13963931991207984, 0.12697648407230455, 0.19672001021042948, 0.24579393256816173, 0.09305468535110836, 0.18615674557945422, 0.17352101393043998, 0.11409588007917328, 0.11830144231357884, 0.1251944792907565, 0.1265635703419966, 0.24157189944338417, 0.15896447002887726, 0.20129488811137217, 0.287263635545969, 0.1919579770295851, 0.1700072137699012, 0.15162819756134865, 0.13604848194987545, 0.13312885958340862, 0.12582072552533882, 0.27549005924694003, 0.19893469379073192, 0.156282227666628, 0.11964135307578311, 0.11843018338925416, 0.12176173889348585, 0.09628589099813854, 0.08412834377058091, 0.14280908530758274, 0.11932681269583204, 0.17837537602791864, 0.15559971993488653, 0.17582027361758296, 0.11602449876767014, 0.17219502298581987, 0.1310548144242456, 0.2578756753956118, 0.1334497738148897, 0.15310889230139796, 0.15162519449668546, 0.17904332808909879, 0.09950992606219747, 0.07392481104621003, 0.17011054370912815, 0.1331735837964281, 0.17182400660409083, 0.08327469199655518, 0.12208054638317517, 0.1191004413750864, 0.15942884188505912, 0.14723203265138213, 0.1282700005498144, 0.1465230489209775, 0.10172311577104753, 0.13750642387857362, 0.1973820480728342, 0.1322544161831179, 0.1345652744414345, 0.12141891454737033, 0.15502382099868792, 0.2959954750634009, 0.1387323637402827, 0.16273890862301474, 0.1142549735584086, 0.14117442221651155, 0.14913323305306897, 0.11767589321900761, 0.1361727873764692, 0.19796203791854844, 0.14786082229787303, 0.10981352519123785, 0.13487737866178637, 0.16052237110993556, 0.1268132154138819, 0.15566975569292424, 0.1743955492612816, 0.0989981410243819, 0.11889346740058354, 0.22993249578341363, 0.15688182936320383], [0.054619517928409966, 0.04223470688767491, 0.05178095149477163, 0.12479812072049226, 0.02328044674809902, 0.048711275486575986, 0.03566465640981351, 0.0774618619752507, 0.045215907401495406, 0.036477322479890245, 0.03753273883053372, 0.017939701173154098, 0.01654390429687356, 0.06848399332093616, 0.009327163570560515, 0.04694720099289571, 0.030769048138491573, 0.01137814469515316, 0.03129756645179324, 0.006960302369759208, 0.024061617028388767, 0.10609852735914531, 0.03667313455333633, 0.08966011145422537, 0.03368885819649985, 0.079389484749446, 0.014016021948097455, 0.03602247692704682, 0.05133550201031951, 0.01950048849046711, 0.03821747587813485, 0.031154692969134742, 0.05077940261652393, 0.07976983974297201, 0.0781971684867336, 0.04052592862036921, 0.022659191576343392, 0.01962648888659333, 0.059009676709050135, 0.08289753925055265, 0.050754336219641476, 0.02934841852214548, 0.04231791169713101, 0.09254838550283064, 0.07037560230181103, 0.039259838090548595, 0.0828890816398686, 0.03585745392727756, 0.09466084231051708, 0.03920947930084602, 0.027811301406472925, 0.06863659037457359, 0.04776407671611636, 0.01636819820100021, 0.02211476161685442, 0.011169276568257521, 0.04892671473264214, 0.060165538677885655, 0.02633726588570543, 0.011204554917170637, 0.05752578355191697, 0.02605612502403317, 0.07742040129678865, 0.019185576557872758, 0.02276824993802415, 0.004388104228588242, 0.05116642257499118, 0.03098353743553162, 0.025574073773778738, 0.02030136446738916, 0.021549892431545644, 0.040530820091765736, 0.02222710458051053, 0.02709563547414878, 0.025029318226921945, 0.09517413654154348, 0.06810625068723195, 0.012182017991078958, 0.025158156978807626, 0.042955430915519115, 0.024515935895784248, 0.020385741391369415, 0.04635603009392658, 0.043261130640824, 0.002423551467795586, 0.03434746015456415, 0.035660017747431993, 0.029494478930568988, 0.01897182079002021, 0.10184520720354012, 0.037718672200196215, 0.056778916773656686, 0.047745782536484545, 0.03595444065849147, 0.03322774221399619, 0.03496884939170653, 0.023592855488400788, 0.03167339578090656, 0.044415537042603384, 0.01434840547341493, 0.004907959523881155, 0.02304931610612379, 0.02620568836949045, 0.05234743521038083, 0.0629695277330616, 0.029391765692121083, 0.013718047261899038, 0.040449197253873276, 0.049469208404902494, 0.010092045863970153, 0.04780333872223574, 0.031406529052483464, 0.08176087927553924, 0.07125304110588566, 0.04457062771243434, 0.06695664382629818, 0.06880569662297926, 0.0507197281976621, 0.07029072742067999, 0.04239361650580841, 0.0760291856262953, 0.051652509193386764, 0.026395013593437693, 0.06069024761898383, 0.05852155612721559, 0.06102767870611241, 0.017173653468489647, 0.038128280261110876, 0.013953548435482287, 0.024220607085754315, 0.06159193310586195, 0.042756608116530606, 0.03705568438876541, 0.061159193020073645, 0.015724774359935717, 0.043535980005418105, 0.021941357615193533, 0.010219643553418499, 0.015982496871372626, 0.05077865185035814, 0.033222980977546786, 0.10378545510672754, 0.02702702847008984, 0.06487956495895501, 0.001925337079052453, 0.09198816838644205, 0.022692541298907132, 0.03896170348349599, 0.0229889502929103, 0.09880564611164794, 0.026192325880871187, 0.03951394945503243, 0.02917797928075156, 0.023022458978718328, 0.05931240401320881, 0.09584275509921775, 0.041558684090212475, 0.02320743090803585, 0.03833318579821818, 0.06312029383655998, 0.03546529734927801, 0.06447788207761704, 0.003283072193528736, 0.039676789104217486, 0.03459085011854768, 0.045843896486105463, 0.04108035411205023, 0.019533007007633007, 0.05993880346537598, 0.017217069586378433, 0.02730710063910773, 0.03431678599407596, 0.05481781978760997, 0.013144203356557317, 0.032024875005346634, 0.05310455990594722, 0.05631656355915531, 0.06177423904920298, 0.034050566609948874, 0.0442890789089424, 0.02297751068498098, 0.08598581587354984, 0.027683502618944453, 0.034454896325065244, 0.028640643295441425, 0.03356137350502034, 0.023284372948710958, 0.05617645756912328, 0.034543957876702475, 0.048638646520914576, 0.04454841882350945, 0.0132293913761274, 0.03658211564705257, 0.1164139012595819, 0.032185866467414365, 0.04256553046645657, 0.020944319079600034, 0.04097500936158242, 0.024775980611241637, 0.06184303757524299, 0.06328688731657402, 0.04361348512071756, 0.016001415412662732, 0.027495971955959837, 0.0137461751376489, 0.024913811320138556, 0.019873467972502112, 0.027009508039261547, 0.012117438694281925, 0.042641599166898, 0.04637491799169972, 0.04964472297879477, 0.04088954459274969, 0.013997181930819587, 0.022080435132187222, 0.06016972534839184, 0.03135581977755553, 0.014203948103972982, 0.043175543297923384, 0.05640822214885585, 0.03430044150821144, 0.06039494370681144, 0.06461051487994772, 0.012478171303237398, 0.05976010962659794, 0.030656084643616795, 0.024658401436623067, 0.04443511441950837, 0.009956855285582284, 0.031149845547793858, 0.051986251567159934, 0.06667556616687967, 0.026216381041693593, 0.02593440131374425, 0.04715755724558427, 0.015772032408764767, 0.03886192053135845, 0.015343391850981263, 0.055860718261570706, 0.009301152970311383, 0.04217157358183496, 0.040523526934726585, 0.03431498185701428, 0.03517418776849105, 0.022377242491911017, 0.032884550145677025, 0.046911114421222484, 0.02873144195144696, 0.07252889925674086, 0.023136353270421108, 0.03003132653482739, 0.09852855977031494, 0.09295315571850346, 0.04431923596008171, 0.028106136089791695, 0.08552270806244305, 0.057723487862536026, 0.0501226392694779, 0.06303471798497824, 0.04348661713001709, 0.028687646620035655, 0.022442811957350182, 0.03947842978842316, 0.051455115148377036, 0.026253725912782456, 0.03541614897849579, 0.04415196449225468, 0.06386173671231636, 0.03320638368266725, 0.031043376563297167, 0.013390890371444966, 0.034039872022525924, 0.03759355855084235, 0.005374389283749606, 0.02164813363173556, 0.0222856949849595, 0.01481834487358649, 0.04655013762174114, 0.038851137843824206, 0.024611145303013827, 0.02458138278715553, 0.09359815578547218, 0.040349996528558196, 0.03801789465210131, 0.07703240840665757, 0.027113075465745023, 0.016794803837734847, 0.02886219017748391, 0.006240084917554933, 0.016863000984754295, 0.05226126947109738, 0.11286849997216657, 0.03219952581510429, 0.02261190096877756, 0.03137142498857312, 0.035605625504808086, 0.05568391665996564, 0.09273609236603783, 0.029483248081599033, 0.09384613078568252, 0.05690421428411238, 0.002602636011415011, 0.022432948575325073, 0.032198537561681964, 0.0716663302192765, 0.019613277700339115, 0.023111104927656632, 0.00901062274351716, 0.031113900702386618, 0.030230871371684537, 0.01693938952690411, 0.04069392021084505, 0.05648684958296438, 0.031717809728316726, 0.004599443467844639, 0.0422276895222885, 0.030828686168176994, 0.059029480081892786, 0.05614703596239129, 0.06817446315600988, 0.02380615543393839, 0.06204330828040839, 0.0637224504363633, 0.03627298767828653, 0.02779215303880553, 0.05390570018320315, 0.04965966935419748, 0.041880755114459225, 0.06540032088636391, 0.06864113327596458, 0.05339074737182068, 0.049665897649021885, 0.037135414989484895, 0.05187504624407138, 0.07118883527695172, 0.022182029882265676, 0.01115501201110742, 0.01790832412699538, 0.058518323236175125, 0.044997480412524556, 0.0488827336249092, 0.027622403276543465, 0.03029394913614998, 0.0644273509181315, 0.1052854705842272, 0.05350641132662854, 0.029944247235694242, 0.015155789367253742, 0.10139325363261086, 0.06403108427841818, 0.04081440285869664, 0.09175757592123363, 0.15044443850075045, 0.1565472174796366, 0.09392305367415953, 0.2749867701242047, 0.15498329494749347, 0.15043595024654943, 0.09879417777542146, 0.16459360748769777, 0.12840801895025278, 0.13613889564669904, 0.0827902333149987, 0.15115576646020337, 0.06678076536064187, 0.18033191862125553, 0.20584051677536583, 0.09301581404983036, 0.12207526803737688, 0.16495932254099077, 0.10810724054012569, 0.10691285584001772, 0.1081124499380108, 0.20738462827378706, 0.14564213973860587, 0.21078576754418113, 0.11108807333174253, 0.18894260899434168, 0.17338466560167654, 0.09260765772553221, 0.172278986222321, 0.1437540547621827, 0.16024972041768415, 0.12153512242460444, 0.10890915073574552, 0.1341369393612108, 0.12460412427542672, 0.09086168971994231, 0.09288581658995922, 0.12368510987970138, 0.2598633977674669, 0.23308277190212282, 0.09898592958286886, 0.08239176034206346, 0.1173343405788464, 0.13461070345534434, 0.18145256735865148, 0.15588611424449952, 0.1650564931333065, 0.08756589520001605, 0.11240907704397557, 0.10413423195601472, 0.22480142272768483, 0.20198099645635775, 0.12603008969416543, 0.12083513256643089, 0.09816773235797883, 0.15277182893647304, 0.10670385173251552, 0.2650886996378822, 0.16490227963414886, 0.14050725156501417, 0.1797258971078742, 0.10839548878251545, 0.17603916025930838, 0.1568637496881908, 0.16822089591333944, 0.18592068324646643, 0.1402990595107117, 0.11690977465121016, 0.0953886564821005, 0.10606463562937514, 0.19062659282597805, 0.20069707906053913, 0.13962453441514125, 0.09111987667218333, 0.14878383567256315, 0.18130995243066744, 0.23688486627032682, 0.10962769524344515, 0.16002513408180208, 0.1365290335830181, 0.2315718626543399, 0.1566285453736782, 0.17004726484658259, 0.16299514971192808, 0.07731049832317137, 0.136414151037893, 0.11128269030802673, 0.10424850163080039, 0.08783346672932948, 0.196139729251304, 0.13201898204222803, 0.14192880431730903, 0.17039539052113412, 0.1001715042718476, 0.1626144959441116, 0.1544452560765128, 0.17200457352784373, 0.08323432682382484, 0.08422814204447693, 0.11968643735012702, 0.14478320195790262, 0.11403339794806897, 0.2016335296174211, 0.08173752891560716, 0.09499291078217569, 0.21445782614811776, 0.2542144799184415, 0.1361046208729667, 0.1717994305034799, 0.13903734334293874, 0.0716749027431492, 0.11910021920958835, 0.11558562231760834, 0.17269952252747553, 0.20032419342427485, 0.1614465795817875, 0.14131401875807395, 0.18520019287543912, 0.11934831678386658, 0.20589903057102235, 0.21855592156850526, 0.22655936468753124, 0.14277338561031128, 0.21044226904069224, 0.1277816884459988, 0.08084851452299664, 0.06557086738006723, 0.1228919254255391, 0.11358279269188644, 0.08337701836060132, 0.11047891851875091, 0.16019466933944534, 0.11517034137561438, 0.11360356133551368, 0.12293536261084581, 0.1371372001425874, 0.1480256844191782, 0.06555050476303985, 0.11313938866219214, 0.12473589139840296, 0.10690137218203276, 0.16327331623723432, 0.11575285165059952, 0.18656894684799258, 0.12009520654476459, 0.16891532397318273, 0.15371705886096726, 0.1242512411948654, 0.12902135660331096, 0.2804502027650034, 0.16768365377380004, 0.16722965474811294, 0.09982024529768575, 0.10207112653241043, 0.14139962142273305, 0.26563703473056516, 0.23720434025651027, 0.1924721292790867, 0.2732992622881167, 0.08014007471501827, 0.1307811678176926, 0.15564248296281985, 0.13763226148101593, 0.1389136967519599, 0.07657152225053118, 0.18885227190631051, 0.14753469866850685, 0.22369310800586978, 0.25562091009511106, 0.1519866194576025, 0.11977963194611574, 0.1357187730290236, 0.15594426031795242, 0.09459837550117124, 0.10961088727438643, 0.1536334173813943], [0.016285581364025994, 0.01978722945486586, 0.0018789761910034766, 0.038590859471549915, 0.09410939690086151, 0.0908321034043066, 0.02854413536918019, 0.05593605917848407, 0.011622636868137748, 0.021043877951019717, 0.036290090591196096, 0.0572472722870448, 0.03306324781489468, 0.025380196072341456, 0.02836418131576671, 0.025554582581765233, 0.023574854337400006, 0.03651424408740094, 0.008390987847721385, 0.026334145992633798, 0.05594090085416552, 0.009230061926157966, 0.04882348438484534, 0.02456965972669423, 0.034506756647099415, 0.029378066124815135, 0.023139927070587877, 0.047357050371506525, 0.028413628460839394, 0.01696839170049756, 0.03505456696955427, 0.005599737877116329, 0.044390060788681435, 0.0234957825722954, 0.043185950602374734, 0.06815518838383498, 0.014254026313973291, 0.05811416972128134, 0.08759715924820594, 0.025740297616369305, 0.043080831847844586, 0.06838353621142526, 0.06081181428124828, 0.04859381122514606, 0.02976769078222494, 0.01946857901320102, 0.06476700366024049, 0.014502911043593721, 0.021088747720744823, 0.044841543215537266, 0.07377105719980694, 0.08673218469465933, 0.022654150717801625, 0.036338733343948285, 0.026081802376035242, 0.07296611329600697, 0.018886013196841366, 0.0402994194037972, 0.039565978316409935, 0.09985350883535801, 0.06299694601987159, 0.020959851512264822, 0.041331952708142425, 0.024941308130960793, 0.04178598237734649, 0.03269285196438432, 0.08784870421814342, 0.03844489673933676, 0.08790941668614265, 0.03237921556818389, 0.09231777005498448, 0.014600411053716898, 0.10571539146645416, 0.040686339770834294, 0.0777679753880347, 0.0669630559822244, 0.04810647971387352, 0.028993290803966024, 0.025884728172733903, 0.04465668619940839, 0.061242918769318255, 0.08998580607435397, 0.057523956432217555, 0.016742608352233807, 0.013273095734597696, 0.02253222782465239, 0.00953605946814341, 0.0789352865408986, 0.03127441910516111, 0.08249961020004365, 0.08538825963173183, 0.007834278456416101, 0.037388201021859725, 0.11495023665408935, 0.031965171858187647, 0.048325584690657356, 0.010301311398976514, 0.05604014371431643, 0.02567531420819221, 0.01934222430140982, 0.04802346642639849, 0.014194196762306797, 0.029616179658220183, 0.054330541902492126, 0.09751473433308064, 0.019841998995792483, 0.08954615587548864, 0.04002594516702718, 0.06327442689648559, 0.018164262611178622, 0.04795535737949033, 0.011186909039444741, 0.08743119396028981, 0.05094209287856376, 0.11388404144635124, 0.026167251823109486, 0.05132990573803264, 0.040055830256953355, 0.032730336646519365, 0.032693786591651945, 0.026272096701206702, 0.014321408534963286, 0.044833005165621165, 0.07678986496983037, 0.045876964671357025, 0.040978246083062504, 0.020288611018669703, 0.02229692200348983, 0.05474741247692897, 0.08080898438610377, 0.040863627838271285, 0.04119268175394785, 0.03460305772962109, 0.04581824403196093, 0.06484686832634673, 0.04308404558668694, 0.05134230487108712, 0.09505337810203915, 0.04250594414770604, 0.032397674456719434, 0.048996072502866875, 0.009318112241735142, 0.03418913276325311, 0.07009888368268168, 0.021071192815959938, 0.08920101028296257, 0.022616120198020534, 0.012728650453350237, 0.022727495975672238, 0.0765758200037864, 0.02801114693284035, 0.02853554369310939, 0.06926069922384716, 0.02762484135136249, 0.034949566958652395, 0.09289058931772748, 0.018422765574688395, 0.01902825848740195, 0.024037358854266427, 0.030628243093228633, 0.03744134837160668, 0.038305794324485526, 0.01671183651553527, 0.07319924151224476, 0.032266121838361986, 0.024187310989345276, 0.03848468734612388, 0.09197532875283111, 0.03566606984203381, 0.017375760869453513, 0.043791746119818384, 0.029000302423693003, 0.06088083497278633, 0.036763042632129886, 0.022206167397539944, 0.019612894656376976, 0.07343963990288396, 0.054092763532553954, 0.04128196547108312, 0.023839319380180492, 0.042626595334900964, 0.025920502563577988, 0.041672574551475626, 0.057366678581362775, 0.024841588381077015, 0.02277075887597617, 0.06001406777349692, 0.0052785823279390895, 0.05020913825700841, 0.044910617533230016, 0.02677515982800434, 0.057118090710813, 0.014526660726856322, 0.06743166430462753, 0.013092691604528698, 0.027180125396097862, 0.012663739823525953, 0.025987885742177887, 0.02806555258200294, 0.025505539548072605, 0.010826339224173177, 0.028823755546322757, 0.056416894264158704, 0.03386700045197241, 0.03364949659895032, 0.02151544528803037, 0.08227801926794552, 0.03999978709485262, 0.025742559490965742, 0.06264833387948814, 0.03586535995465613, 0.04147953188587581, 0.05488583690396721, 0.05464079219006723, 0.10062585569797985, 0.044842623399510506, 0.047927084904644764, 0.00823227549722839, 0.06213484812648066, 0.06400982916895902, 0.0829297609086479, 0.03549161246947704, 0.04615795040022462, 0.02034334225520011, 0.07275173891215556, 0.019645072264416565, 0.038435933510622675, 0.03778914462835078, 0.03451258274576357, 0.015334940943566543, 0.02320666673533138, 0.08192166580908722, 0.03148245028099947, 0.030721430028338107, 0.058912138394530744, 0.07856553420424461, 0.0256097006926974, 0.017508711598272768, 0.05898854034321924, 0.04807876648321267, 0.016607543220743537, 0.03777366582184069, 0.022458526335896987, 0.015332739398394142, 0.03922882685137372, 0.026195156575751402, 0.05355025070809549, 0.024222985788759206, 0.04006167550781562, 0.008021833538453305, 0.02009953094285823, 0.08229694930055449, 0.04914165985199714, 0.09822245401841018, 0.05993060632458618, 0.014445020651985562, 0.06706796406257538, 0.12285418793438904, 0.006054757714962528, 0.10463251086372523, 0.042356572324229826, 0.027962098153488293, 0.04787194189585505, 0.04727507513316889, 0.055576920990021005, 0.10093895583263329, 0.03736903733243385, 0.0290161585285058, 0.014340076182458191, 0.03996507182056385, 0.037602617540546966, 0.03150248539543921, 0.017042085528373718, 0.07282251777547984, 0.04211760651800902, 0.06521430707746936, 0.023439262520461798, 0.06151883682656673, 0.024872752837836746, 0.036513734638931296, 0.031476070683810024, 0.00758522327223252, 0.042466563397958394, 0.07081047211202883, 0.0238854780928382, 0.02329249348070833, 0.023020591639402895, 0.05297571540840211, 0.025505641054722573, 0.07531367482677584, 0.029273663662494193, 0.035502736066137595, 0.060276085165359324, 0.041541684599172686, 0.01599420077963582, 0.03901018152734445, 0.02541541313422063, 0.005974219849092827, 0.011501108510269514, 0.01326172986263109, 0.06524324987924869, 0.12953638219304625, 0.011954370176329488, 0.03316051033776134, 0.04689748954748915, 0.09379787490733209, 0.052015320773446755, 0.025622360295646136, 0.010913392667838884, 0.027695995597769658, 0.08332746013277963, 0.028727203570005876, 0.010886192716087305, 0.0421967625527853, 0.03737466424823769, 0.03671347291298932, 0.061843742376133326, 0.043364560171481104, 0.022214711193115484, 0.08402764917381349, 0.037973538161285465, 0.01825586374428484, 0.04074096183983549, 0.027322680952267784, 0.07928294490181631, 0.049942646911668206, 0.024539353288409692, 0.02230380338826968, 0.0712416110740554, 0.03731420075881385, 0.02864620317855189, 0.07220696612832046, 0.012737501641705394, 0.010981536188703633, 0.01203776076210723, 0.038645343644724744, 0.052189375949843284, 0.004434642633573423, 0.02696218487295893, 0.02470825843873524, 0.020624927447868452, 0.03476516193439884, 0.05036402208309981, 0.018273388005552754, 0.022830628647258686, 0.030013084066130465, 0.03338737578521813, 0.039543957119026495, 0.019255290558982282, 0.04228202813875772, 0.06208093851924904, 0.052583214090836626, 0.17209658068754982, 0.1297072964089532, 0.06808263985740562, 0.0965865038996262, 0.1920118483324205, 0.19747451488529483, 0.15839667630291757, 0.15983097675827243, 0.1239975818222569, 0.12415278357483688, 0.18398370653871568, 0.22369989554487893, 0.15623344318760982, 0.18396957987739196, 0.11613683790088662, 0.1005806718322058, 0.10004159108164812, 0.11271743509437769, 0.22138741318016286, 0.14288595456990505, 0.09063783116758832, 0.1240370813156328, 0.17765309301114854, 0.23924696048901928, 0.08430941631236384, 0.13849763440028315, 0.10420039130915558, 0.17897364473150623, 0.11647865101094208, 0.0907157346486084, 0.16628830122851557, 0.1577598274114632, 0.2697155029783326, 0.10483686481752705, 0.15525053705899947, 0.213745808709533, 0.10256337632815685, 0.13494355333668573, 0.2129172539759067, 0.19442686390492225, 0.13101850185663472, 0.11838252505948467, 0.15072429041949012, 0.13477138273658293, 0.1375245648406206, 0.08586603802658858, 0.16318412828108958, 0.11075747574889853, 0.11578610752739253, 0.19278913646215395, 0.24977469396206642, 0.156815639366546, 0.16857680504120168, 0.11834219819115055, 0.1175299764520699, 0.2272904270719136, 0.10451580502934034, 0.18244776153756728, 0.11403919723365577, 0.20768608387199142, 0.12214090645072923, 0.0871947868877361, 0.18668727678877695, 0.1267005008975825, 0.13895518807393892, 0.14492138889768433, 0.14802444335674086, 0.0769192342376036, 0.09330837536723384, 0.14644461683928967, 0.21430013460978387, 0.08840227169134925, 0.24183520386295937, 0.0864660457497643, 0.19607911637473494, 0.17864583570870662, 0.1250656539454095, 0.1532504500280465, 0.11904804096106561, 0.14968083270134466, 0.10226102440708107, 0.23158683201238034, 0.1843578332374173, 0.18941995837996084, 0.15483802935529142, 0.1680247161176897, 0.11675742274570851, 0.19442355440508938, 0.11193388802630287, 0.3257723014441229, 0.2336987525585198, 0.13272197496506477, 0.11853081669898764, 0.1765509223144862, 0.18270864511930174, 0.16923746394534267, 0.1110314594341382, 0.17392953797694177, 0.1588364720584885, 0.1973429469451789, 0.16159872464354963, 0.1617162884964097, 0.21609624307001793, 0.13910696541349735, 0.20263387190718807, 0.18748279781110827, 0.20104747235534653, 0.20171807508074469, 0.14282108224447698, 0.1361348966677343, 0.10948104303210013, 0.10299181099981071, 0.16916630969893548, 0.16876071210830443, 0.19389686895714653, 0.12077978271390162, 0.16036320868278706, 0.1778502074340659, 0.1300447121743233, 0.0933748564773029, 0.10783397697753484, 0.14326872274039254, 0.15686506735942057, 0.16372302517054543, 0.12324283966013502, 0.15638011838159255, 0.13054596350318, 0.15639948508431836, 0.19954080723466414, 0.15058072554247995, 0.10559134650975467, 0.17148809237105234, 0.14378797713546984, 0.11159230474262469, 0.21293954713450325, 0.15200289116511423, 0.15527656872666654, 0.1833569853296203, 0.06948828862439241, 0.11531888582413236, 0.19357391693178685, 0.2130373459189169, 0.10158376437762093, 0.14645836045665128, 0.12466451498649775, 0.14344728251378383, 0.2534058434708465, 0.1693921370972549, 0.19776063340325511, 0.15587057798139511, 0.07827508728951216, 0.07099962688141292, 0.2438422316505063, 0.09129242265536901, 0.11438773659568642, 0.20037987269461158, 0.1389851114682613, 0.08270937273459089, 0.1123256653907799, 0.12018935875065866, 0.152423151678616, 0.1046317907410764, 0.06987682543694973, 0.10148372861646837, 0.11932109001903765, 0.1432994275443977, 0.17532306723296645, 0.16197476656206194, 0.18297312931428034, 0.13836032080073513, 0.18451272089394832, 0.12802954853302048, 0.0853497943570537, 0.12007825301900027, 0.15217824869098204, 0.17712381818602163], [0.03801668806362056, 0.00602457097791616, 0.01602501953921972, 0.05630384649961226, 0.06798101063337057, 0.011243744144937205, 0.02624885359358403, 0.05430186340104669, 0.053337132708439906, 0.02046866083307372, 0.043588878376589674, 0.04736446610261356, 0.024377773853860075, 0.039930881316503214, 0.012821329855209878, 0.006253864924092928, 0.006920677908290659, 0.02107666651417892, 0.02612647870855947, 0.08507027185612148, 0.020217060321761716, 0.08670005496711501, 0.11318841828934609, 0.026898218446501324, 0.010870291603608959, 0.028150406395716053, 0.04523008768897384, 0.04187302145686361, 0.11054337715669987, 0.014172265580254457, 0.03819260483367309, 0.04734589230088938, 0.03139423142607895, 0.05830812020107143, 0.05255224115605797, 0.09023413347500948, 0.0490947637797123, 0.030727056944141948, 0.06225518138718702, 0.025195815945945443, 0.07826888963820473, 0.04176398033216115, 0.047367036327599525, 0.06150078013419144, 0.013240601157679433, 0.03410509291795954, 0.0748505593547898, 0.012757068484901421, 0.07215723170027619, 0.045167218683467764, 0.0262529464183195, 0.04917617211298597, 0.012185889607926291, 0.08212414284747455, 0.07566281939826666, 0.07687451768546336, 0.0402445292040225, 0.09340235903378456, 0.02680665370257151, 0.04683167876435384, 0.020725947632003697, 0.045596017246885646, 0.06474018292201143, 0.048491841091984705, 0.043419791280382106, 0.057621299394316254, 0.04806834768744246, 0.07416066653545826, 0.030708331840052724, 0.02213912895850597, 0.018190110417743845, 0.060816089051865765, 0.016736504546697104, 0.05437635779080372, 0.08921543571857676, 0.029230161359713926, 0.03642781787822324, 0.03332017455250025, 0.06762948352843523, 0.008550173257507624, 0.032412030944420446, 0.03140109748910031, 0.028869831904528603, 0.020044815028086305, 0.019983654398651376, 0.06425829063500128, 0.05490465202338754, 0.051466296201631914, 0.034128014268654014, 0.1277836802746019, 0.04897305156074224, 0.17559881292043195, 0.01102286950504828, 0.02735967916857091, 0.09785903722889001, 0.06550461609637545, 0.0868021208612669, 0.040174600698294184, 0.04716655111781532, 0.02526634008503489, 0.03579586811904465, 0.016855872536618865, 0.04829972922321289, 0.06009729939603037, 0.03927514835771534, 0.019771256521644614, 0.035464902813997, 0.04964018007740379, 0.021405774056010192, 0.1006117596801731, 0.018685152603974266, 0.03701209398587385, 0.06331893660488629, 0.05880972776081293, 0.05372470425021264, 0.037304019450300166, 0.03428392082212433, 0.02954231346056106, 0.03391473922097395, 0.02335233069325407, 0.03321621642117539, 0.030263455006324, 0.007405464092434775, 0.06228866325991769, 0.05677219435212113, 0.04630361818858693, 0.031349943883176294, 0.04548232213804319, 0.056614345765762755, 0.0678296929465667, 0.08448396178503191, 0.06363541901772542, 0.02454836439761904, 0.06746289004842121, 0.051497518114985964, 0.051825790620979764, 0.028660799068729245, 0.012891040983489685, 0.002640061321735923, 0.05277596564302522, 0.032914454387801315, 0.037784004178378856, 0.04188654290872716, 0.009181298514557703, 0.019920812206222646, 0.07237842426665368, 0.0281484279736516, 0.04712968313645932, 0.043000492207225294, 0.03430115396998102, 0.023922604628868645, 0.01955142950699214, 0.03700685777491139, 0.029178247411525058, 0.03682913303735756, 0.024573932582091902, 0.017574093372170484, 0.016119761632815484, 0.07092034444212914, 0.022869517185514974, 0.01854601763038626, 0.1031252175509449, 0.06974495106166409, 0.033622748639074065, 0.01735278589260434, 0.04158762306155216, 0.07305490288643107, 0.14182077059822698, 0.046939114934854934, 0.016690202192553592, 0.03694024259945558, 0.018702081231881055, 0.051173087539932424, 0.05682565962835666, 0.02519094362674702, 0.06822100299740992, 0.03932088380679488, 0.00606181146952534, 0.026442273557486556, 0.020462606823252096, 0.028756157863104058, 0.062432243458686344, 0.0231642005664687, 0.03212766293736716, 0.027675964313769535, 0.019374857731764356, 0.04651753291968377, 0.06531808900857164, 0.04237284403174155, 0.042910687550301516, 0.006602194569554301, 0.034211356973936485, 0.025733904612641183, 0.1054887137105388, 0.020619503545364546, 0.08271147181550342, 0.01573804587561397, 0.022536337886366154, 0.09922865688079789, 0.06572922541489525, 0.051486248961619796, 0.05648812128891868, 0.10151310042748529, 0.03794466047697971, 0.032446217618041465, 0.02946736516370889, 0.010244847846127326, 0.01031558744744548, 0.04518429478329997, 0.03716487107017348, 0.05374768688794106, 0.060301128579604055, 0.05375936972878633, 0.042749230689819784, 0.044407849350283225, 0.026093860599963416, 0.03571935508760714, 0.028090350848111897, 0.06242145694071247, 0.08210051669588975, 0.005831817989312714, 0.04376923079572378, 0.022373228191187786, 0.014143776685570278, 0.05103339140693988, 0.00968717701447707, 0.04263416428359286, 0.05095442306370505, 0.019280703610650474, 0.09485195826498732, 0.0053685904769677556, 0.08905693978792237, 0.04534147687316422, 0.04985375389937432, 0.07892437744885683, 0.026916918652733008, 0.010677447163259551, 0.02492714891090028, 0.027401545873632836, 0.01947947278348429, 0.02765966770840028, 0.01866484361310159, 0.030701107630926757, 0.057630366044900114, 0.037957706954330206, 0.029568117217070637, 0.015698880588095036, 0.04987887392241148, 0.03619943557667636, 0.0098347092693251, 0.019140423335615667, 0.044992006714305574, 0.015650543312902655, 0.05264854606901927, 0.0073143748018229685, 0.04086945776737506, 0.02475716932226093, 0.034198578627359484, 0.009012459439315624, 0.031729398723391276, 0.03618939599442867, 0.028325026561956734, 0.10698240896266316, 0.07475276057037615, 0.010588122268898353, 0.03540173120376083, 0.06308015465976731, 0.057925627822236675, 0.013568915798509074, 0.043170349221796765, 0.048977621275210576, 0.030575241300187288, 0.04990508562074073, 0.03147839959109983, 0.01666861766528699, 0.031546079628770395, 0.0452227064318234, 0.03919924436617763, 0.06194313462342947, 0.023815181864906224, 0.010931774947581994, 0.046567516326303446, 0.004424530272972921, 0.043278704697806994, 0.023031274735506986, 0.025904378327991695, 0.050014318267424265, 0.03387478773572272, 0.022538766385086124, 0.04705731847113179, 0.044775655823609525, 0.04634577600706009, 0.027996792360359145, 0.02344600026375584, 0.0448540227878238, 0.09529278823925603, 0.07303028848142394, 0.03976561699903781, 0.04752924395424705, 0.08457043012904544, 0.10325726046557389, 0.03285238594417611, 0.030706770935907002, 0.023015983620538347, 0.029793176612245943, 0.05258533998482651, 0.03291850699292075, 0.02681280155816386, 0.03255207564741854, 0.1092868857085705, 0.10736345343532101, 0.06549271875091138, 0.00867113087987227, 0.04159590830245326, 0.051001365101265336, 0.005528793826083383, 0.05145989553702455, 0.02788153826259077, 0.07197651155893842, 0.050060536351896105, 0.010058245107140994, 0.07170379957965306, 0.029069556772047957, 0.056949256423620455, 0.0952593485013612, 0.05315239060549967, 0.04054984588536524, 0.030746768386433684, 0.03568526034453704, 0.019324504687721213, 0.06269127310764405, 0.03582638906194799, 0.04497735911319333, 0.05075653872242378, 0.03325272434120698, 0.024146641296665036, 0.02969363306258475, 0.020152618920791055, 0.095605053338072, 0.026573793617107218, 0.03576591791164491, 0.07544194092793811, 0.047491766932991245, 0.12846578964062277, 0.10646655599796966, 0.03135683675927501, 0.019140067104730877, 0.03378273461074118, 0.07586531941929171, 0.06922316091555743, 0.053572045909541274, 0.030186964957524213, 0.18672922776351053, 0.12370684379411322, 0.10648622147498593, 0.11269365572520804, 0.09257673841690825, 0.14766107253249616, 0.1140004025411702, 0.17921048847417678, 0.1804391556088963, 0.13190379306193323, 0.11654706266258033, 0.11544804824816605, 0.1515414764083201, 0.15682857093070784, 0.1457599947048772, 0.13793148010248138, 0.22078669299521755, 0.27852873167684006, 0.08477805527828394, 0.12129963465755987, 0.12840466348514443, 0.2002895662500974, 0.1764548855322984, 0.14861187957707914, 0.16861299503474467, 0.08360643105040635, 0.22801015135501662, 0.12761969915440968, 0.1893898664462951, 0.12934962527886515, 0.1662107884523369, 0.13446707729130022, 0.20423275869219534, 0.15022215042864123, 0.12643922661100665, 0.1808138032473864, 0.0995384245329807, 0.10833592544640265, 0.12804324618510662, 0.11572187871582086, 0.18753604092184575, 0.1358874196246747, 0.08542137761269847, 0.13797359961655833, 0.13428819576098075, 0.10034149918224543, 0.12841920383394728, 0.07892947959443254, 0.1394040849540503, 0.11608191705759495, 0.10390316451629324, 0.1769819540242034, 0.11361474621920817, 0.2393287173922985, 0.1424745959980834, 0.19083317609563952, 0.1433441211139002, 0.15680857603588413, 0.19684017876223212, 0.1992989226334518, 0.1335198402164444, 0.21057164596934475, 0.12124610043341115, 0.10119938742249243, 0.12546706103509472, 0.09319267310802976, 0.07470183104516999, 0.20609974560718383, 0.11043826223260934, 0.11536492004750237, 0.15078770717786205, 0.14635237985320632, 0.2083022790330072, 0.11158995285269716, 0.2788342475410431, 0.15310832539633398, 0.11171609689030917, 0.15721877015406088, 0.10777858115973012, 0.19632538299887412, 0.17326158591576163, 0.1345350446119424, 0.1967856792672988, 0.11006709263329545, 0.17732087132190505, 0.14710264040097115, 0.27922651520179165, 0.24380709885829882, 0.17030450184979748, 0.2021179882989776, 0.17660355255488427, 0.2431804389362374, 0.09879449953234966, 0.09004114060512475, 0.14081937110712453, 0.18614887019559262, 0.17726372116275374, 0.20446759528450428, 0.13491700072923016, 0.12115574036274226, 0.09548860031270212, 0.15963772341849344, 0.10378683406499126, 0.13229598411388938, 0.17975350691666528, 0.12547237768528924, 0.13179306271335772, 0.1724470046258742, 0.1363629303992756, 0.1482326813763188, 0.12916988573007046, 0.14321587799537566, 0.1136511890217662, 0.13798052505139383, 0.11644904937354789, 0.13067595330217194, 0.14695752802635395, 0.09418214461015118, 0.09253065822826279, 0.1705540473302526, 0.1312611525457713, 0.14837623093157046, 0.11240172259990247, 0.1540235553177134, 0.2500527225915463, 0.15210517922476416, 0.15251715066692523, 0.09456922585565238, 0.2967518796363185, 0.16259082382725132, 0.14366790051421813, 0.16221386260322987, 0.1292097989109255, 0.20024881037252568, 0.17372883826253877, 0.1472034269282895, 0.10341346579333467, 0.10751545294037751, 0.1315259584976781, 0.1354285482797892, 0.12366570487257936, 0.18667184777798193, 0.17660169862210753, 0.15866413291904236, 0.19037893192181665, 0.12814236264075005, 0.12858543725263688, 0.14724444327575548, 0.2248282051615177, 0.16106016483278046, 0.1130320520831212, 0.23875776738409074, 0.1636634235300364, 0.10938239389009054, 0.15968112996028316, 0.08258930377421841, 0.15764255467201435, 0.12341795969874629, 0.13771631664806797, 0.10574939044853372, 0.11165513161329493, 0.2032339026130015, 0.26692314313784726, 0.16293369413864228, 0.16978595225561052, 0.2029211855223102, 0.14256133247287045, 0.2215587717270659, 0.1393422310150439, 0.0964519175730886, 0.11846956030856218, 0.10768291976062522, 0.1867794065225509, 0.2641726116980276, 0.12342775796329784, 0.1841104021596332], [0.05603902522594698, 0.028006975584092642, 0.02312508028661532, 0.03201808938155732, 0.018601649020227696, 0.025369658532942978, 0.04707600718604461, 0.09837545709864748, 0.02102900818440943, 0.04649125227344133, 0.037780832574372335, 0.026700257496427626, 0.020834184364385663, 0.04051360226566753, 0.014935187646187844, 0.015093091773920724, 0.034963777889647794, 0.018671456867107944, 0.05366420628683222, 0.030766294052403782, 0.06382625151966369, 0.021975226362325975, 0.06321231248758494, 0.04503080906767038, 0.091407427774562, 0.03144637711586491, 0.016326094008681756, 0.0730709447675655, 0.015133626443604309, 0.027619178046382246, 0.0446956685834354, 0.02726091511337267, 0.03319604915656871, 0.04300602719247822, 0.02140055699724584, 0.05764964464751463, 0.06885874055085645, 0.05761442375519584, 0.04704833225977998, 0.0571357720201054, 0.07381503830753988, 0.015462563530872426, 0.05595266030380323, 0.027668399195517265, 0.15253641011734165, 0.020276763468920704, 0.047304925749138485, 0.030041775974114577, 0.0065473915122809916, 0.03664736718600316, 0.02905446292471982, 0.03467498955527141, 0.05608434698754742, 0.1039799188654269, 0.025424943267998677, 0.10279217614762245, 0.044962654055486766, 0.022528562093934706, 0.04876734546175407, 0.042489641796677344, 0.09023586483371836, 0.007508629801562958, 0.02704295735325544, 0.04876777064055205, 0.029728564756712126, 0.019580037145304586, 0.07798876192781233, 0.024885615454085415, 0.05614608601336518, 0.04011894441059521, 0.033477563486104055, 0.031148388065517913, 0.04963182588858951, 0.05778942888061847, 0.06017769649324398, 0.018781453686495943, 0.015510255376988602, 0.06812665926953478, 0.053673142702468944, 0.0381488305696797, 0.05620738453862648, 0.008785623677765891, 0.037727443906929226, 0.0531046097016623, 0.09725427976058376, 0.012089400833863164, 0.042429166815934644, 0.06510739950763603, 0.008449472915080768, 0.03260987315086588, 0.03783307594036864, 0.035051426009064725, 0.0894812529065436, 0.03455687028866622, 0.0204606571294848, 0.024468670186075955, 0.030039121479456945, 0.13695634210542326, 0.027561978091515844, 0.12610257693356083, 0.0435915673452039, 0.04766248579647753, 0.02331330425917141, 0.020218582921511224, 0.025588018489220453, 0.04204423827750068, 0.04812662016540285, 0.024939228202246373, 0.03959190656220721, 0.015080360350229088, 0.04267865867023507, 0.017962116905818545, 0.0337995081058433, 0.08042872898400792, 0.0024045333350753233, 0.02730227620040457, 0.03595699173127932, 0.04371842767502512, 0.010006706542035025, 0.03377138501814297, 0.044234705818516594, 0.06029491177609852, 0.10495825911000853, 0.006274573238296134, 0.022205106365764817, 0.045882656704634435, 0.05286365206683836, 0.0271828162799319, 0.03439517211048834, 0.013520056625918276, 0.03276045539326245, 0.05535883491017646, 0.07399965017553299, 0.030210596854768457, 0.015480089707360154, 0.02988829791936423, 0.09463551544374037, 0.055802127857121735, 0.06314613398224597, 0.031651947234246525, 0.04902879977899213, 0.07078236434608698, 0.04035374269850793, 0.024418150517909278, 0.022567094401306203, 0.04479480419127692, 0.018575956346467137, 0.06681055852001713, 0.008711751734447336, 0.029472773744454308, 0.07793566437378045, 0.08581165344484391, 0.027495994938597567, 0.07004230808947357, 0.050049194420177134, 0.043231291516173276, 0.024794389704062093, 0.01586486215537955, 0.008423070652380345, 0.036905446885934765, 0.04218988691366488, 0.00610571165922128, 0.024906650313266346, 0.013940212759940375, 0.021889577732391415, 0.009885701039175113, 0.05480286192088839, 0.012353938654996456, 0.02906564014753507, 0.024302591900191, 0.023378258939051343, 0.02835702796977374, 0.03682497701036834, 0.05169176736906652, 0.08168243953297216, 0.008075641160230003, 0.06506845159756561, 0.07617214529384529, 0.056270536996664546, 0.035128509776005824, 0.0030038750405618625, 0.03073077438579452, 0.039567069991702036, 0.03329856704259592, 0.02111063676796133, 0.03401640674940521, 0.06991034944451625, 0.04153023924558394, 0.08053950529785887, 0.003467045335714976, 0.06156851762845632, 0.017895559186957056, 0.028976821828813806, 0.051647008682090434, 0.01100119783528029, 0.035608038681769566, 0.04176175867718074, 0.04568781756285218, 0.02868440798333576, 0.09829711694751056, 0.06659930211401756, 0.02528785566438831, 0.018993470434760375, 0.03352710256172765, 0.011983866476634098, 0.03906373107325166, 0.029863208539844043, 0.0372124451302713, 0.02058392642216096, 0.047296709456150575, 0.0599134459550823, 0.07973905066929518, 0.06249995797031349, 0.0427382258367875, 0.01857865872162004, 0.10862975080888118, 0.05061026572460129, 0.03377222005398043, 0.029082009531257134, 0.07962887190402516, 0.026193388827866124, 0.045626576494185195, 0.02193885250768114, 0.03556543270186071, 0.08082338683908025, 0.025472335382214478, 0.082200858892212, 0.034387859801251086, 0.032958102247287194, 0.04587177442567003, 0.014669391525638922, 0.026306053548450434, 0.03290991148641033, 0.04008609839084168, 0.01336903484057515, 0.04376615112226817, 0.06770642173867072, 0.039344804902230544, 0.043692962912422036, 0.03999818597109087, 0.015616649667912675, 0.0229214770989793, 0.04773145286186088, 0.05321411430955895, 0.04843277188258306, 0.013725874765265374, 0.03668643000926222, 0.06823930483792098, 0.015668877712150496, 0.04034861757029449, 0.03481794922282139, 0.059883093551522305, 0.015924483905696583, 0.13738207248670442, 0.035491233255954525, 0.03694362104720166, 0.017558928661709352, 0.06821982322200652, 0.02175280039439038, 0.011943657394318331, 0.021068695369326783, 0.029603431955160155, 0.05857679872743546, 0.06810444271973065, 0.005454875917489371, 0.059079180035980484, 0.03110523050230357, 0.028698379511854825, 0.05191806208101973, 0.057758138019351236, 0.06131025023698326, 0.03800741073885753, 0.009371597627778689, 0.05216686062574868, 0.029867743780355782, 0.020117101169401602, 0.04714947884842273, 0.07848927781226174, 0.02249975718798176, 0.05507691455404124, 0.009121595367398715, 0.02289692972666554, 0.041601657792324984, 0.01051574323942224, 0.03321474553236077, 0.023565747467200124, 0.060878421795824846, 0.08082403035293664, 0.02460937947034836, 0.10276382323354484, 0.03171465919172812, 0.01910850428225052, 0.02480510918934259, 0.012989977408470887, 0.05067177492404177, 0.056530754081904895, 0.060888656730493235, 0.022516643681052714, 0.05667816088985532, 0.0607379021183137, 0.015349613442536325, 0.06320363654184245, 0.038612731281788125, 0.01937147736879847, 0.03242557154848211, 0.06306462988798177, 0.05752760301073713, 0.005640096346577329, 0.020074876318235072, 0.013369950315644665, 0.06734181751286791, 0.05951796455549137, 0.08214541710913181, 0.04607344324129724, 0.03058978164899013, 0.007282729624890753, 0.012478688412586288, 0.015338408449033817, 0.06583992511995378, 0.03885239805845965, 0.0130592959166895, 0.04010808894470815, 0.020758435505652623, 0.01325699065120951, 0.041806785494930325, 0.03733724851401583, 0.0012451711823345134, 0.002366728093024464, 0.01965937704118269, 0.037934839229790435, 0.07669098600144349, 0.046174762199722955, 0.0318399892609206, 0.03652474332240321, 0.03990387288673271, 0.031638736047992305, 0.019464897960724852, 0.009607489506203321, 0.0731307226082971, 0.06164341038393398, 0.05828613347764458, 0.02950729941198182, 0.01133027473359459, 0.012649340243379196, 0.09815375891423996, 0.03196133184246719, 0.0013228963085097232, 0.016515310065099792, 0.06588011409246153, 0.0478405591040369, 0.017810626849231702, 0.17233746937446057, 0.11206871950097623, 0.2583952668693758, 0.1438587176943979, 0.17024031900350126, 0.04260715202338273, 0.11368798422476939, 0.19640298770560374, 0.20987979196492704, 0.11543802015723721, 0.13577576997059007, 0.17868101446618959, 0.23119183707862134, 0.15501422957787592, 0.13881923811089608, 0.1212023491520555, 0.15367426518951693, 0.12693971185193909, 0.18239402813055824, 0.10307073337777008, 0.12120177458611228, 0.13361069824426405, 0.1779350593325592, 0.11825922320807174, 0.1953915677844517, 0.14205954488246672, 0.08932881673137028, 0.15279723241204216, 0.17154086050727677, 0.18288967169580922, 0.1375205045746219, 0.1407575324898766, 0.11239877316139399, 0.09723064594811971, 0.14996661414061824, 0.08878560676690071, 0.1185592309000992, 0.13327591782135348, 0.2216466266902224, 0.19205710880698698, 0.1991584067863803, 0.18893484086278947, 0.1183487942081786, 0.13872035148162998, 0.1113762679479776, 0.19297961656364704, 0.1645435206592083, 0.16892827085910306, 0.10833885190227341, 0.20566129816635964, 0.09692314591619278, 0.11472047156383915, 0.10828632125330549, 0.12709229358381804, 0.19021995335576997, 0.09363181768886505, 0.13935664878977885, 0.10869535857871657, 0.11481168965298323, 0.12229945600753832, 0.12326875641461342, 0.23866548443273192, 0.12492056455343001, 0.20164544994552291, 0.1264458762541894, 0.1121668247205596, 0.10261619809053599, 0.18238468185788204, 0.13118446714455081, 0.22199291375375566, 0.16740521145684106, 0.12589019437831256, 0.16586083948852556, 0.12385079171508552, 0.17351721413433555, 0.14944011255377723, 0.22895686749008395, 0.16409276984632015, 0.19886948438661717, 0.12656896360098355, 0.15146644575701607, 0.15443523564646322, 0.09786705816945723, 0.1186381915824548, 0.09832848824800984, 0.17771644848248652, 0.14943619018360493, 0.14613024499868194, 0.17487732663510308, 0.0778778630398935, 0.13637861987996486, 0.1203322954355709, 0.12417222688635512, 0.23154342547059062, 0.14084770103856442, 0.06890715730767097, 0.08468507518691402, 0.09698330680088652, 0.13512169942259789, 0.1470832124112114, 0.23460442170260415, 0.1202923822547159, 0.1621260995706243, 0.12716799839249543, 0.146583202144792, 0.1352357392710063, 0.12883960990415466, 0.1580504964916937, 0.0618615998856483, 0.07402666243574313, 0.11007764932489204, 0.07164765299568254, 0.19299119981306215, 0.10942779992136265, 0.23819306865334514, 0.15662117560784664, 0.12098870255173215, 0.06367072801015551, 0.1379719142231249, 0.16473913354979408, 0.156039439081665, 0.21388376582293742, 0.2421826860236545, 0.17605644320288014, 0.2818809179288726, 0.14922225246987036, 0.12741303161507653, 0.1144956554015798, 0.1315426745361859, 0.1425805306362529, 0.1595095722305198, 0.24784767639733132, 0.09385741526080717, 0.18861352826558775, 0.10139276333633931, 0.24899477048987345, 0.12678182113074488, 0.18457016216651087, 0.1771213820264224, 0.0977784601010142, 0.15649000603345134, 0.11259578033200196, 0.09844563075251157, 0.18784065280229817, 0.06485088262706995, 0.13442751651089038, 0.20864864270533287, 0.1141348816153984, 0.17431085058037313, 0.133891316250928, 0.1759113614717799, 0.1492650154978037, 0.2506093927208455, 0.14382979021437708, 0.1142192662002579, 0.18033159686432731, 0.11457245571598892, 0.09620229548384106, 0.07071232092717002, 0.07668567701212822, 0.1269563206381375, 0.1016076356773415, 0.08577723311440599, 0.18333352771737885, 0.08026787350254674, 0.17059742322852536, 0.08433632898114382, 0.10528612175896283, 0.06674722603131687, 0.09122643950245074, 0.07986432136667353, 0.08508779228694978, 0.14996554161752426, 0.28194143887489076, 0.33166627549836714, 0.18950940680599984, 0.16383289750064575], [0.01129725251361848, 0.05528954991830453, 0.04530197737978832, 0.022628795122727755, 0.05831252520663604, 0.01544458248967966, 0.0496858197654928, 0.01784290787914107, 0.013279342224010298, 0.0606044419410248, 0.013361804885789754, 0.05575811993631144, 0.01038577355023834, 0.10266998512369972, 0.034182609524577856, 0.047198385901508794, 0.10381707921624185, 0.050779728203891754, 0.041266004029180736, 0.053587888607815395, 0.043956845728380066, 0.0334466097035235, 0.016178286919790893, 0.0926247644688814, 0.022028705045100183, 0.1313459125137137, 0.04630064576744072, 0.09106146246795693, 0.016215721806210857, 0.08683418930177728, 0.020423837028624072, 0.06058182319506042, 0.023359445734850826, 0.033108921976940285, 0.012804507522002585, 0.10361051126833885, 0.07785652749120228, 0.0537603120169332, 0.075057701868636, 0.013643760673491465, 0.05441229880577134, 0.036975095769570726, 0.0506068681246571, 0.006151647727575995, 0.042237725274096576, 0.01204086437581047, 0.03166610453908723, 0.025545586794314366, 0.04659972649307982, 0.03421131866954027, 0.07913941066832313, 0.03562159077715009, 0.017900791567479892, 0.037760083082943194, 0.006639594982017673, 0.0671340085025276, 0.015393001789737855, 0.04379739984869958, 0.03963067827205505, 0.037760155861296, 0.020203255417366183, 0.018614565262631066, 0.004783233227734004, 0.03398971241568366, 0.02965048507546946, 0.007763264021055112, 0.013309205288908655, 0.005670111192645686, 0.07307849839449891, 0.047383078208733956, 0.007535746920057723, 0.024123965094106335, 0.039355262002396973, 0.023182483254781654, 0.023695712368334496, 0.062153697719857584, 0.006198696538640728, 0.03381334365375581, 0.07710405294933627, 0.020699915964336648, 0.05758216379270439, 0.055175628813524405, 0.028178713344518217, 0.022165476637441787, 0.03787525674147952, 0.050179188049608664, 0.049254297759504094, 0.051738211449476025, 0.03729288819276037, 0.0772877914770957, 0.011188796488568188, 0.05806997793936922, 0.026811740526388732, 0.0371597382810808, 0.01575239949048527, 0.10649362954521373, 0.06975762215593169, 0.04848703772069947, 0.03402835006014474, 0.0731439299641117, 0.028579038335010413, 0.09566184343589891, 0.07012417990594141, 0.025472195571168296, 0.05007312317649203, 0.05407378753466953, 0.04133377599740221, 0.024740497333808772, 0.024214256216862032, 0.046113927157655846, 0.013841486051528445, 0.06760200395459129, 0.005736042634629074, 0.0731757685782448, 0.006744919143872517, 0.09816259190800691, 0.008117778868895144, 0.05109389703119955, 0.04735431160717722, 0.020233305216196085, 0.05013071383619982, 0.021705308688744422, 0.05309647767834606, 0.03464130849968042, 0.030310121252231544, 0.05101813093548821, 0.006308264827596085, 0.05121944352023063, 0.013304530237350735, 0.004165906171810123, 0.03464829139111023, 0.06099944070522344, 0.04041270465560017, 0.027169656804612568, 0.10777015419256304, 0.006966668081605026, 0.03686558350079483, 0.05888802960755364, 0.011041253700011201, 0.043136706470601985, 0.030862499373934926, 0.03471490656656604, 0.06754187371341452, 0.013085825541507334, 0.032653869580357306, 0.06100109545513988, 0.015070900121974129, 0.01994717903735657, 0.029422591154974316, 0.0769012081887453, 0.0278143580972908, 0.02644974099952848, 0.04019747991415282, 0.08792354334746638, 0.044694182372862296, 0.03879271214827895, 0.022383737002289104, 0.04148910032405008, 0.029505920453718113, 0.008548668852346319, 0.02258716015926292, 0.03491132384947231, 0.0279137943946426, 0.040268511586492105, 0.04927145046812873, 0.03576083491826731, 0.05048638547680551, 0.03566229685900673, 0.02488050373241065, 0.055631906950786236, 0.03346755454737333, 0.04859771827355989, 0.0881776700337087, 0.025814271066337827, 0.03912428266278679, 0.05328947820911004, 0.016604580375696384, 0.04899265575072458, 0.03666524001727662, 0.039675360350238706, 0.027357396226556554, 0.06965631468882484, 0.051962705854807174, 0.008852445696961255, 0.02853208480613126, 0.06084875887139671, 0.04579331936134447, 0.024580490294723742, 0.04081169856832393, 0.08972794087904115, 0.041868195102940646, 0.031613087424287395, 0.012320642558587416, 0.03319303077014704, 0.014704998334749572, 0.041999786025694305, 0.08216889770401102, 0.031096579454418634, 0.049643581507787596, 0.054863302427674496, 0.006038356251308635, 0.10002067688131526, 0.0457625417789865, 0.06744235889205048, 0.01629863167181611, 0.09873069973001558, 0.026010196137752746, 0.07307235436934618, 0.02377370394946587, 0.029810882819395874, 0.11568895991771452, 0.054446558257745165, 0.051667072524827336, 0.01299962437065739, 0.038665273422074896, 0.029786980876158324, 0.04313494829881576, 0.018652748999997013, 0.08907491987150523, 0.07788465057890262, 0.05825380839767957, 0.035894126556212866, 0.042428845059006445, 0.0234173753884651, 0.04952079293528392, 0.01795622568968083, 0.03178234114461849, 0.03652397723447892, 0.039290477777080196, 0.05949306286751263, 0.0762502326359672, 0.12271290599939325, 0.0210682874275071, 0.015759749146508836, 0.03726789457423072, 0.03276656111401897, 0.030221052039715073, 0.0065746297684287835, 0.04014854987842902, 0.02152492371087353, 0.03893811563630739, 0.024087376734842698, 0.06452855113292895, 0.03569679379823708, 0.011480746850852045, 0.052461601463296724, 0.05396859217134695, 0.019908374768771955, 0.04314936607355072, 0.023139442519975767, 0.04182960342375502, 0.08355924003427068, 0.022836979516150973, 0.03839213626399156, 0.024400453886858398, 0.015456739347428085, 0.06229096535413016, 0.031205534394229614, 0.07126298492714282, 0.05750160581702667, 0.02797728010092772, 0.009649510386460012, 0.033110040465309735, 0.042887796843124014, 0.06079518251241215, 0.039453489796048215, 0.014181530456088725, 0.05814370241076235, 0.040594459015635714, 0.01566690790857519, 0.032051965789569, 0.05482351565132699, 0.02274724955279981, 0.04907349334849466, 0.05198939635808911, 0.053416196812665274, 0.044690443863791805, 0.047419850429099415, 0.029929134236167998, 0.02613320113009503, 0.011467518427619531, 0.022757281474168264, 0.025883647988760666, 0.013337949865437565, 0.047850824682222265, 0.020317929203531915, 0.03214478500247483, 0.0431611561667054, 0.02608379228941856, 0.11408306342820007, 0.011978821787652711, 0.06172479190413029, 0.03296902283064781, 0.033909510670890736, 0.046255856436947664, 0.030361138877549, 0.05582692229279107, 0.05670872013715487, 0.02916309036194317, 0.06001833105279554, 0.10216556219083649, 0.01673373896929045, 0.07547793173862082, 0.043115692678838975, 0.04073526980655809, 0.0472255896837, 0.04675507763280504, 0.03893563351143272, 0.024808675328630115, 0.04053791023550495, 0.06300950603139016, 0.005940080098357173, 0.027046925688703215, 0.06810785947187294, 0.029191477749977383, 0.0735993079480625, 0.02191448899646921, 0.07260318680275833, 0.051142995606266686, 0.019941297397317908, 0.040455743475186254, 0.07111407275642119, 0.0038237952450740965, 0.027542735878077727, 0.042670974808354536, 0.05252457006023296, 0.028099995895078587, 0.03155135222890925, 0.05040656294553511, 0.09609495124389088, 0.014731798005560714, 0.07404540860725027, 0.04318786582218544, 0.042444749044314514, 0.03059256063293546, 0.02875583419095605, 0.01397932633652442, 0.011647141148005764, 0.03443910725294583, 0.09087364835244033, 0.039436635861714045, 0.04825519653217447, 0.05557254662797336, 0.012770494175774437, 0.034037206036549424, 0.0837613033851789, 0.06974073757808055, 0.03329887347776563, 0.008492686977279524, 0.002757832497140513, 0.035568734540814356, 0.02913413032318556, 0.0799095971629985, 0.1906477215309297, 0.10050273770766874, 0.08368850971061377, 0.09330199385482459, 0.19696131258481936, 0.2278839153868537, 0.10286056481662298, 0.10843011595669294, 0.18841247615073958, 0.1356328792509533, 0.10201987525027606, 0.14841468854536935, 0.20262130806522988, 0.13420931934829683, 0.140544697942753, 0.2037473194180958, 0.16638872003363026, 0.18560686298916418, 0.18522827765874325, 0.1652229180739772, 0.13350991171694573, 0.23700748630348714, 0.11227841308761029, 0.09349691726627851, 0.16835994087159636, 0.14214778288958535, 0.12515756917456466, 0.09772699431426103, 0.15765041473411745, 0.07701303404305251, 0.10747851984154795, 0.11532628623348092, 0.09812555921774718, 0.19002501462255755, 0.15935027190754492, 0.32229757176772245, 0.08437674011914961, 0.07176523983118034, 0.17615508468401048, 0.1794917653164556, 0.12909848633552753, 0.17264957359481245, 0.12502993892637954, 0.1809536142935676, 0.08348391060867617, 0.10344659143518056, 0.07530488779828434, 0.154354015004731, 0.12450965797348369, 0.2186396549786291, 0.17822001339687457, 0.08077733729395174, 0.20761684484539494, 0.17101915463084177, 0.19165308935747993, 0.14878981115837253, 0.14593188951332725, 0.12937247002076718, 0.08400116551427111, 0.07465097812875625, 0.23085400762577213, 0.11475679945320853, 0.20240380038176814, 0.11942408287957793, 0.12570071019112103, 0.16828783667616307, 0.12301456078045792, 0.13514399258119447, 0.1521254652329991, 0.11370165123333854, 0.19621290596983126, 0.16204494021592603, 0.07094702728453182, 0.13099994720710864, 0.211365113876039, 0.10527336639502358, 0.2051458129238698, 0.17178222416870056, 0.10780180128471506, 0.1648287658369349, 0.18662654133813997, 0.20422160445201784, 0.12603893800969088, 0.13744507555759725, 0.13745771600834786, 0.126545314466761, 0.09463357724129193, 0.1526805265776573, 0.15545649213656304, 0.11616306875141398, 0.23479606625774216, 0.14089916682531758, 0.11089461314822398, 0.15022656309508509, 0.2094824987673952, 0.2074167120360559, 0.25388901512469014, 0.12545518667226838, 0.2654797722014689, 0.12269385339271639, 0.18328932444414786, 0.17613369550916458, 0.1325279555373615, 0.15767897449193463, 0.1271409861322853, 0.11882495615751514, 0.12915991126529633, 0.19193572983626397, 0.2004754345022863, 0.1293847121057972, 0.15765429113901433, 0.10684792222755571, 0.1791090277894851, 0.09560953495242903, 0.20744668139565378, 0.11825340860072645, 0.13162807801798468, 0.12670593246096565, 0.18745229218996343, 0.21093287174740147, 0.18810886018458875, 0.2025235399243332, 0.17352466050895954, 0.18311045823558686, 0.0979480030195367, 0.1493596579999693, 0.18219073903897118, 0.10318163226568892, 0.14582379450721128, 0.166686054078802, 0.12515330206482642, 0.10644866018405846, 0.10003270446172646, 0.10625960500610453, 0.12212239776647861, 0.12804660165021498, 0.14221219556225886, 0.12096074800337515, 0.161228351775677, 0.12047328625715549, 0.16303766759172564, 0.20023499014637164, 0.10258915518680889, 0.12906684690425474, 0.20989794824873248, 0.10710344319382023, 0.1645677137158571, 0.13744752703895494, 0.24680495412359316, 0.08257406628540448, 0.14406884029026956, 0.12844597094602164, 0.2951839428034521, 0.10481090209777318, 0.16006944460734246, 0.14344440202318853, 0.08078014883663386, 0.09505490261700847, 0.1172415060441821, 0.16632061481716173, 0.18837205735185455, 0.10853579012496818, 0.1296974291964885, 0.09260785690839253, 0.26723552314985183, 0.19408606203092685, 0.15394023559506864, 0.15719034829207007, 0.17933776632191675, 0.1144736227128775, 0.13655552490343972, 0.11622588796120499, 0.1472475076274526, 0.14488438685094157, 0.12023720094152998], [0.05007529886619699, 0.05606963426896161, 0.03301711783053414, 0.028814702302277572, 0.08772547131464367, 0.0037405078417636576, 0.0119465867230188, 0.009944686936514993, 0.061476453012155916, 0.061940924459767926, 0.07297949685204415, 0.024513735308221752, 0.05993142220822554, 0.01896928503899084, 0.06642923059482729, 0.03908690523296114, 0.08540391846890412, 0.03681606740780896, 0.053649482076927546, 0.04967936164429111, 0.028609589921430718, 0.025378018467416687, 0.03113647348307554, 0.0448488325421368, 0.026719486303327065, 0.02547285440678318, 0.019451432050235813, 0.03181563341058791, 0.010608251229108823, 0.02197568026942111, 0.025469669396237984, 0.021458480905200687, 0.023333119123332927, 0.040758869145065546, 0.03203041190581937, 0.07956907108065583, 0.0279103048641475, 0.051714198423489455, 0.07860232174636857, 0.08708784101350654, 0.06946526002138853, 0.066548518145517, 0.022476357032334613, 0.05950155112171366, 0.03659418536229961, 0.015616453357882079, 0.027419813240187305, 0.011162518715155462, 0.04630189066031768, 0.10083979341171442, 0.021000798911817616, 0.032580083821930235, 0.029400847664463426, 0.08629985829635013, 0.02247041793570163, 0.02762031377172999, 0.09634263513069, 0.039268272718594927, 0.03419949027198938, 0.016345874398886677, 0.059488209700512315, 0.03872733037438124, 0.133169952539667, 0.0823781852640452, 0.03852917024144723, 0.06583785668255822, 0.024508525910336646, 0.04804854431459981, 0.03507292626665966, 0.03937193973650856, 0.029475684878566576, 0.0718689451534902, 0.03977967088200873, 0.06967130702950301, 0.02918441824975514, 0.034328947639873916, 0.02597769677278496, 0.033695588278914654, 0.022229960173248284, 0.04130223615755958, 0.011805729009211065, 0.04853224456911126, 0.036291530836493745, 0.07823019453714933, 0.019409345094895652, 0.0782405520458856, 0.03357502136139139, 0.07079382502143422, 0.034644843995450966, 0.1375366690298242, 0.025451289031714685, 0.04651220094773077, 0.012069029598346642, 0.02340439402858817, 0.03248732589605836, 0.027730488706560388, 0.007800987148056588, 0.05465485756435702, 0.05054937322593985, 0.06289200729600365, 0.0630185152253797, 0.034007987443117366, 0.01391330296399012, 0.01637458737428871, 0.012575134094203673, 0.018501352789180896, 0.037169797015526605, 0.041260691209425854, 0.08554441899421715, 0.04001161166196389, 0.019537293269569357, 0.018828267404328913, 0.038275135485755826, 0.09556304107630446, 0.016501395993175048, 0.04571132497080872, 0.032449121091274485, 0.032164496444766565, 0.06716194006824686, 0.04185375817600758, 0.0610172062841875, 0.00605894438546872, 0.05223504245100964, 0.10755800912457128, 0.034066516560532396, 0.03807391100112469, 0.06723291811443145, 0.04189580491173171, 0.04570603896413119, 0.003620038839853219, 0.026591737311513677, 0.0362970888043844, 0.02325132583087731, 0.05369753111153842, 0.02943410162603663, 0.025623641577699495, 0.05354675734716077, 0.03824215540061555, 0.03812415487763863, 0.06844512968053741, 0.03975150182903294, 0.03230033532506035, 0.033198194202756694, 0.006915788830918892, 0.0612864172416589, 0.04363640647141203, 0.08713022865835698, 0.06729779810073876, 0.05236516248494868, 0.03304701441177919, 0.057044806739976334, 0.06772573481524183, 0.020953860704696948, 0.03166910377331078, 0.025176207925523483, 0.1268672858995776, 0.04930773239222266, 0.057995721036868716, 0.005794294523976503, 0.026550240243875214, 0.06516891636795576, 0.017376063474183603, 0.06482247608683764, 0.018516479195245815, 0.03867820498623675, 0.0680244171751603, 0.006001733418088407, 0.07880036313567432, 0.022081894529682976, 0.033299781291955904, 0.01731156844705824, 0.0763437106844879, 0.053264243272884246, 0.05060166638765124, 0.04655771423131228, 0.052240799601760604, 0.05090226013694079, 0.027571642290680643, 0.02415995398956922, 0.033190395427687515, 0.06943129168282594, 0.015288571556729656, 0.015390807905444696, 0.047439841493483514, 0.031113737908702706, 0.0537324455686875, 0.004673942645651199, 0.023254777056976192, 0.05284711222855314, 0.08611074183136226, 0.07325731863778445, 0.03695096783039551, 0.014938152406454809, 0.051991369034494125, 0.03390554616588258, 0.05101342715563313, 0.020114163222211986, 0.04093170241122285, 0.04344958060931775, 0.043402251697355704, 0.03010743928532447, 0.04654103649720069, 0.07370494381194154, 0.025944994394517234, 0.032205470657396706, 0.04622707451363245, 0.020337562121811415, 0.01973972051224161, 0.045841720796400504, 0.03221399338555432, 0.09766979818983425, 0.036840800556444356, 0.05339356657538203, 0.042043184906604796, 0.06358984444710998, 0.032217540372643745, 0.08377091778862862, 0.041534931534120155, 0.03165362688202051, 0.03691398876629049, 0.0432768622563491, 0.057487701321200985, 0.055177624472567154, 0.054372377964037086, 0.013886591393290269, 0.03186053765426961, 0.03151755817534943, 0.024305878417386163, 0.02049572097377912, 0.049451431334619565, 0.05468702559629756, 0.03825815514691415, 0.029428288933911154, 0.02662932924595812, 0.039949727079440514, 0.07351564348585184, 0.0203008167145233, 0.04233757334370767, 0.023860423187274608, 0.036466348270374926, 0.07201712187980452, 0.042016000276611704, 0.017617379255112142, 0.04855151168040691, 0.02494277327411598, 0.05357778773853376, 0.03027263848531631, 0.03435381868433568, 0.059679635920591896, 0.07855966597074464, 0.031260987668628656, 0.024173795283141158, 0.12456006655890135, 0.012394683041249313, 0.03357726216856991, 0.010991361266332529, 0.0675065034339505, 0.02802382185754757, 0.04897666749574485, 0.017266262007216295, 0.034576899657446536, 0.04198551380766496, 0.035761562701795375, 0.0225129185785209, 0.04489402023835048, 0.04963903477595699, 0.03298461655034654, 0.011845244781955356, 0.012079354548346133, 0.026474384132832773, 0.012372186869352817, 0.04664700177888717, 0.05513098120929734, 0.04014408741627009, 0.05787394370042509, 0.026120840301436764, 0.019318559845428795, 0.03476935626578427, 0.028457582755494985, 0.02879109721811068, 0.0557441694752103, 0.04293617912598195, 0.020881383041400584, 0.034781069750146526, 0.02875217037545818, 0.048342595673016006, 0.02013616335217751, 0.023116276021145528, 0.04208556489057599, 0.04543145389987096, 0.05018179274855122, 0.07003840104105973, 0.10005455328932694, 0.06513161554692254, 0.023946041173692194, 0.013139632684479078, 0.019853157066409628, 0.04380102727502104, 0.05401044355465039, 0.0700979413945348, 0.01755813001504829, 0.023987040284179875, 0.012320908774141104, 0.021365418459378907, 0.03684021449918228, 0.030670439216098, 0.035150871882515575, 0.0739941036989612, 0.06929675132156381, 0.031098569367801955, 0.04864371419253369, 0.03233184452138601, 0.0721779773612657, 0.002494705953605233, 0.05575649199947234, 0.01981301214395752, 0.04116313374270836, 0.044670169346875725, 0.04515618701735812, 0.01630728655014067, 0.016559566964485472, 0.06638336491080062, 0.04969032436248757, 0.029862649295659318, 0.04068891382625988, 0.04860498461752169, 0.061696890981928, 0.02421436346917143, 0.059349520973140196, 0.01889173778885555, 0.0515697219018494, 0.013665712922961723, 0.018001882614748135, 0.05697169130848301, 0.04292320542698426, 0.06407778882872193, 0.062035812110069304, 0.03803895057870015, 0.038681966477944967, 0.03887463759090151, 0.07817544989408025, 0.07202380982738349, 0.029732762918537183, 0.10827350460233227, 0.08632679394776784, 0.054099723441346045, 0.1173538834817948, 0.09067420502223315, 0.07133279085880326, 0.028671372997304125, 0.017402123870147813, 0.05000237878712435, 0.16542377100596506, 0.11846546173816729, 0.08801905152898643, 0.11027710031597845, 0.1740809016290211, 0.07192771175816175, 0.11781688404059219, 0.10138371583795357, 0.11336755262868059, 0.20408985265080007, 0.14744060774964673, 0.17563006930774258, 0.17075249474615822, 0.16210285646300163, 0.21757859255998366, 0.15845396435789524, 0.16355204966760453, 0.10691907647396288, 0.11315916139151781, 0.17356265847000385, 0.21405654929337964, 0.1391186099499464, 0.15496501608962013, 0.19788466303819613, 0.09490911608501788, 0.1921542027905103, 0.351712865935218, 0.1741402121561189, 0.14182486150774265, 0.14592510197431813, 0.10646185221811456, 0.1065255524290185, 0.16473919483682803, 0.11843451178602635, 0.16508209579173597, 0.19244859505805278, 0.17170438963559367, 0.13308200564595962, 0.24080619456306582, 0.22073521188670592, 0.13183179611880935, 0.15172680839896202, 0.18987758866240903, 0.0967060212766932, 0.1735888127117388, 0.1852156678515096, 0.1637514929978117, 0.21119953163208502, 0.13981925864373485, 0.13060525870851933, 0.20011230882617737, 0.11131039204736871, 0.11960703233677535, 0.20612937788809502, 0.2054657465628078, 0.18854511661394951, 0.17410616720876387, 0.17473855746849892, 0.1318548400435717, 0.1599275957672827, 0.17941310340839048, 0.1420404080061182, 0.19740803377522578, 0.17398406811539205, 0.20846214626104603, 0.13413346132203458, 0.0807932566010183, 0.07323843457045094, 0.1566196127884811, 0.2150318711515396, 0.1787296457276229, 0.12858678556738362, 0.20225632845634417, 0.16683689679109281, 0.19951446913182738, 0.1301275416006965, 0.2966588459187939, 0.06756932264374149, 0.14070286445559996, 0.09590257124434556, 0.13810507562612334, 0.12668440539029338, 0.20485276897107402, 0.22015744369597207, 0.09743143759307363, 0.21681595203136245, 0.07560754615452982, 0.09505652672340793, 0.14639243092988768, 0.18396470755819352, 0.18102239366740952, 0.09561948643456544, 0.08067140265578225, 0.10785817003418362, 0.09410344439768985, 0.12861274062625824, 0.14731997954508952, 0.11969470343883, 0.18830105632303223, 0.1220713150236876, 0.1521787083437366, 0.15710281508584178, 0.07376564861906153, 0.0938400786910807, 0.13914831883965, 0.12823976305944304, 0.1343010047510747, 0.14458777292841865, 0.12632765356571446, 0.17149731606966065, 0.10782687534247676, 0.11397480754362, 0.11807918488498657, 0.15760340757908362, 0.16284780036057198, 0.17708326149131023, 0.20009684917186538, 0.24893527610167382, 0.13226449790020145, 0.1457663532346487, 0.1345613367495037, 0.08865105108388009, 0.2694557685284846, 0.16947329645195316, 0.1496518132907729, 0.08464060378290954, 0.09661158561826715, 0.10110810804631441, 0.0714531739152247, 0.13518873211597243, 0.10257356529754978, 0.14830069466223642, 0.15272966345712063, 0.1497705415972779, 0.1292490685779241, 0.12314519409330622, 0.12726755151825567, 0.10978730200158973, 0.18587595903344695, 0.1407904589488622, 0.19638349842881003, 0.10078608298734312, 0.11272602294000889, 0.08404333099362352, 0.19880050582991493, 0.15198668074463645, 0.16704348006075428, 0.17603197435457862, 0.18509241962625136, 0.09976497205394892, 0.190061281224893, 0.20694610422417042, 0.2035838822203298, 0.09233938905620769, 0.13701641872044534, 0.13313595355758745, 0.20298130810260775, 0.11660707799056846, 0.12248928493429577, 0.12918948225917357, 0.16822397558679505, 0.1621416511554872, 0.14477855946508147, 0.10643792729223929, 0.21497515000162587, 0.22570090188134104, 0.08213071588186488, 0.1541492703460878, 0.16785315838792633, 0.20749768752965236, 0.26176090562535875, 0.26930472663333344, 0.1434070935412761, 0.12716874915866122, 0.12412128970026971, 0.22268947153802843], [0.025102521758526567, 0.01573629344948718, 0.04663370249252166, 0.05363320653897621, 0.00986954999051147, 0.0326391032356168, 0.017310246945388855, 0.07321754335275582, 0.06256990945867955, 0.038757020111886725, 0.036840505612593506, 0.02170887291281214, 0.01207982856524928, 0.045802661803581064, 0.022820477982261972, 0.02889669094715388, 0.06059992968315079, 0.0464774665212439, 0.017267227278000886, 0.02137868135656801, 0.0875579049029658, 0.0910264139454211, 0.024333940218052557, 0.024989822563985666, 0.049240397094118024, 0.020393421422810327, 0.030140534283653386, 0.02137857027381899, 0.0461603635771861, 0.009388936112724967, 0.03293282900666518, 0.019313748813264312, 0.060831709584641847, 0.02055776068910716, 0.06477528507070196, 0.003017697181935693, 0.0590591200236832, 0.040316403573078495, 0.07079336536867965, 0.0650018555743079, 0.01328105538813097, 0.09646806670653243, 0.03458115144542629, 0.050436869383819645, 0.02254179051716722, 0.026561532379879106, 0.060735538737067295, 0.06221638286426183, 0.030073695027479724, 0.03362885052939096, 0.07727575623580525, 0.07086708600963317, 0.04973266604206255, 0.020768302718117353, 0.023405368875471816, 0.07756775064814476, 0.028926367278120695, 0.030657557447651224, 0.05252399932472937, 0.06162711569378453, 0.007884581225939215, 0.03115173778496683, 0.05708884913474322, 0.05906599949324324, 0.0330042973491213, 0.040788551221691796, 0.038103114272798264, 0.010998488756858054, 0.08363497548646505, 0.033004553988575935, 0.03723426714479443, 0.0993428805903081, 0.025636726359446204, 0.023574863913499063, 0.0389786187048641, 0.02941097151638279, 0.07931302151372356, 0.018929475280005607, 0.03984708661934541, 0.029410527185386712, 0.02192345988606253, 0.04518028814345599, 0.07454895053900058, 0.026448747000446724, 0.04413548211056379, 0.021509408515187043, 0.09192785428416345, 0.11069218207511211, 0.07374969100759876, 0.009528910910199967, 0.03180479326645934, 0.014304124633781614, 0.018584450346327597, 0.04662876888628929, 0.05628671294318573, 0.031871113498064305, 0.01773132525774981, 0.030730594355132312, 0.043523630668078704, 0.007420868684177197, 0.061210160849676024, 0.03314034307315465, 0.016608458695813053, 0.019539202743720625, 0.01507700871556036, 0.032707993692207726, 0.025584550026143273, 0.02344962002919807, 0.019714552608709184, 0.02952420314203107, 0.06113444454967976, 0.04435934832379703, 0.0356304697361925, 0.0400968044695835, 0.04271791684591482, 0.052291763600923365, 0.13699967203842056, 0.050611441669565056, 0.0718091519910001, 0.03681072777497672, 0.019210729139646696, 0.016413826397770358, 0.01898919566414289, 0.015774183200612184, 0.025031175990138325, 0.02600502312904404, 0.07758245953629095, 0.037871794024061774, 0.037149905542572664, 0.009584921513563924, 0.04686844715427968, 0.045187776652915825, 0.043882136834004236, 0.005972202165022252, 0.01276120057164301, 0.05663205005769288, 0.039429120539176854, 0.01581708412437189, 0.024213235404702927, 0.03749090276898877, 0.017076323912929625, 0.041550310749200084, 0.022963159942939397, 0.04582784694409178, 0.06836162609679085, 0.015757359909794984, 0.06036202873914473, 0.1035026690712379, 0.03617082219270449, 0.04557692633581258, 0.015649401841895477, 0.06122181687744395, 0.029240082198333357, 0.036833323538303375, 0.0356228816353025, 0.0390565796424785, 0.03656539960854477, 0.018585199197273583, 0.06109130613866353, 0.01987777338663657, 0.03573572255610939, 0.04050019955743225, 0.02151194426621641, 0.007980561987947552, 0.02272968315669606, 0.07529255378270343, 0.0652563346609954, 0.009177390508533967, 0.05576284286836463, 0.01536866604921318, 0.04823026037023914, 0.07153483888795299, 0.04988963745774762, 0.013306327671143077, 0.05951812160351585, 0.03727706081624474, 0.040658366070279194, 0.014291054216183484, 0.05063158595153401, 0.023538275554235426, 0.01681609533637041, 0.028812997756646048, 0.010833524171293024, 0.06218847045074068, 0.008076089321665706, 0.006204454647001601, 0.029655525934011228, 0.04142715445449276, 0.03827089518909493, 0.022141871553274895, 0.08186905089044764, 0.07273786505984683, 0.02917912841263798, 0.0609722484143511, 0.0572591198367938, 0.11345291014520392, 0.019789313214019905, 0.03541737088873502, 0.038805364090348446, 0.06676115350978029, 0.07491867223213758, 0.04630852498174195, 0.03851785895324523, 0.011989398589057308, 0.06885553064245371, 0.011209690579093032, 0.04296703331713234, 0.023924508357360482, 0.05754316608691889, 0.027581055596050237, 0.0047169843380669915, 0.06628732812861282, 0.01532318915480808, 0.07732153765016025, 0.007229774275929818, 0.06192831465253427, 0.03375054359616291, 0.011377838259983447, 0.02377015696237645, 0.02980253629146084, 0.05856262610083627, 0.034695539863840226, 0.0605673939290066, 0.0337761692372301, 0.006451826352971576, 0.05224056977538332, 0.087918356932219, 0.04041985608637333, 0.053468968779329336, 0.008818307861445412, 0.05135853061332338, 0.015233598044893194, 0.019081551393854524, 0.03999557361126908, 0.04741522708847638, 0.01565906029540084, 0.021849766058186372, 0.09325257352282924, 0.013300487208330344, 0.023256043017271067, 0.012537361171487118, 0.0875755325861035, 0.009159156658326187, 0.08267928080092515, 0.0052818683663293006, 0.05188453424301359, 0.01710149373168186, 0.009848969996035581, 0.012262211117382732, 0.0564108076956003, 0.016415241745210463, 0.03621089242158398, 0.02258920369880094, 0.018325985687214042, 0.02931626389674362, 0.018672180820196387, 0.1403315416387012, 0.026908374857157472, 0.014627684741431187, 0.0526097322243356, 0.0724100866805642, 0.054025508673681374, 0.06640840832504534, 0.07550865186438446, 0.06324379104039361, 0.014365410710114145, 0.07033686123548016, 0.02406247313164415, 0.041471231323216236, 0.061794904270960446, 0.015207040649388107, 0.0426529640812547, 0.019757145182079366, 0.03132956594439044, 0.0043617776170703434, 0.04680250613619724, 0.06043927338454993, 0.08815498617027076, 0.04962979958602979, 0.08258186506047364, 0.042616099930338325, 0.028067117316588282, 0.009300047888480609, 0.06150534601822015, 0.008117315385700955, 0.017506036036197218, 0.043366391121620135, 0.05767829633588272, 0.026061891750883193, 0.030850155782254956, 0.03501622809938366, 0.018945430976248557, 0.037271924196712436, 0.05989359278652457, 0.04201247244172039, 0.029331081952419014, 0.011671467312431384, 0.037324994937666965, 0.06952589588059534, 0.05181173673800884, 0.025593432815625303, 0.04379960235148188, 0.05699924366067975, 0.03817343731380759, 0.052330600428244764, 0.04414705003822043, 0.04209014992680281, 0.03123805482661532, 0.033218196758459655, 0.05165710189049283, 0.06566947055680138, 0.043458271876818715, 0.04188005797444813, 0.09001628105198184, 0.05205067956159192, 0.03033298131589207, 0.019880694096847888, 0.03282680243794476, 0.01105523863506894, 0.04413684957750863, 0.06288706219845241, 0.038091511871185035, 0.05935270023802596, 0.03310426033192104, 0.04393838300940491, 0.04219888078589593, 0.014664435894378733, 0.038348036412630356, 0.05082749378597064, 0.059548772781366305, 0.013828786228963686, 0.028839707412126086, 0.007919617299546279, 0.019359997541253126, 0.030819182847476298, 0.028437620419408047, 0.019447176431816433, 0.018234380723668203, 0.052154584066762086, 0.02848433454581086, 0.009903656224900437, 0.03533067654878382, 0.02339758925260075, 0.07285855455143798, 0.06080545192103713, 0.11029762381146993, 0.05738548603990386, 0.04845285104707845, 0.06573507832663675, 0.012135122876404034, 0.042845612211573514, 0.05243666913180102, 0.15528563920769, 0.13861847710945915, 0.23657631669794363, 0.12667491356091154, 0.059642151238456856, 0.17065749984354744, 0.18536617348511375, 0.2335104787902486, 0.16326795362176436, 0.1295976385834717, 0.17369436430594615, 0.11233367867046788, 0.16632548713636014, 0.17309333768583116, 0.20768779990894182, 0.1750170151072164, 0.21468619695834576, 0.1381305710322434, 0.09325563787452637, 0.16901942000033396, 0.16418044094837483, 0.13179241919950133, 0.08702156674717704, 0.13616429912226816, 0.13515847164296335, 0.22742764874091073, 0.2034826053967399, 0.06806076804716742, 0.18206450307080824, 0.1348598812135958, 0.10135448192276302, 0.12872889487733766, 0.1627674837025904, 0.1232046425162304, 0.18353646440852076, 0.09145877864812652, 0.21407803039877646, 0.15950304516140493, 0.1420209493728415, 0.24390949417025815, 0.17979593286591192, 0.1495185139919481, 0.12253042385582963, 0.11158796102409402, 0.1782453249418928, 0.1533134837424563, 0.2099327592840118, 0.12837401230729398, 0.17309356751220842, 0.2120813294764488, 0.17591819497606448, 0.26537138608194166, 0.17739754140136704, 0.09379117929887387, 0.12252838606195104, 0.23767358443189054, 0.11495350018864679, 0.130896280189195, 0.17814809306254312, 0.16544846968064386, 0.09588795428675029, 0.1314438645157122, 0.18210898213569196, 0.18528800187332017, 0.1283253350805852, 0.16006521580200042, 0.10105108046123099, 0.13172135688364506, 0.1780576334004441, 0.09956001289068692, 0.15479045529519359, 0.2304065203474414, 0.10649294006608187, 0.1276834683132268, 0.1464589580052322, 0.11492469528269385, 0.12824614457185232, 0.139722210625487, 0.12389373094324144, 0.14372238468739296, 0.3759832361773137, 0.12042036490334619, 0.08081579490775063, 0.26214214161999766, 0.16630463422306124, 0.15510269741137184, 0.20802049657269833, 0.18739442190816327, 0.16357089543054182, 0.10988656401393876, 0.17317800572322262, 0.12339182843964909, 0.207093499540802, 0.2289898552361035, 0.1294464741142527, 0.08960446282740563, 0.1886649174435485, 0.09292479514354661, 0.16191118126434667, 0.13796773138305835, 0.14924537300342514, 0.19395366671585268, 0.2543333614425313, 0.18444135214292234, 0.143885760598125, 0.17070908820436848, 0.07730052385839724, 0.12966119323767003, 0.1122641332087017, 0.07476740051060915, 0.15754982738965945, 0.13869790510544855, 0.14470146037638187, 0.14436485666421153, 0.11382001947851912, 0.11882485656608498, 0.17071874091221442, 0.1647536892203554, 0.11342977428989065, 0.08960768039668761, 0.10120134094669934, 0.2435287944371662, 0.15131333542446937, 0.08965465690820448, 0.09516786228144362, 0.18692473340178692, 0.22628084576177984, 0.12118220103964691, 0.12019148081420891, 0.15004314632425386, 0.24401066374153862, 0.13632044316299502, 0.12477351397636438, 0.0910849200801984, 0.06473958537343048, 0.14635775779043475, 0.08536030508337483, 0.14984889707017332, 0.16200501171331252, 0.23936902893887413, 0.2676398337127701, 0.15544432666032545, 0.09955167785407075, 0.1609782393901579, 0.2132785257192389, 0.08744130632089031, 0.16021342317183174, 0.1591386324575832, 0.1375458314413986, 0.13792109195022814, 0.14662029612208569, 0.12361754858565908, 0.10199368270414491, 0.14345917219836868, 0.11626797683176496, 0.09453742554591549, 0.12494954565960555, 0.0908307244460429, 0.16437269837385224, 0.10833986313833345, 0.09322077321309237, 0.18544900291148694, 0.08613680414254628, 0.10819946220445056, 0.16472776480499776, 0.17157914958173232, 0.09521743583102381, 0.10642042218316948, 0.1218304723020523, 0.20070406578240857, 0.11212578539045588, 0.21180466448347415, 0.14531952479193289, 0.09108017033506786, 0.1309192781486819, 0.14258411592773854], [0.011273172454938534, 0.025047736895841458, 0.008707885863259435, 0.04688303729879761, 0.04757692143621464, 0.03606682575698342, 0.03893474867988018, 0.04863189728630166, 0.029157829253123175, 0.010548005117133502, 0.04782852003230684, 0.03155391287779616, 0.026631066350326426, 0.05275061196317116, 0.04383767692131862, 0.037483441072606274, 0.05337367510242809, 0.015919737033395758, 0.04811568809072337, 0.019738343469197714, 0.01826905769356076, 0.037268924962488875, 0.0977550331322897, 0.06891523953527212, 0.01097403523031502, 0.02194333986769761, 0.003095037588331428, 0.007217017954380642, 0.04659347904605731, 0.03682454417069112, 0.06448465429486767, 0.024736544320119486, 0.019599976498753797, 0.017349227414196058, 0.0229596876494226, 0.03960077019949113, 0.030045204217575734, 0.033810631702503854, 0.047346704354089116, 0.009823693882583851, 0.03436856587687808, 0.045794579575979905, 0.0052281962463542105, 0.03217009654749305, 0.01983415234022804, 0.037070895064501994, 0.02836371783257252, 0.04059771488931391, 0.04007959430436454, 0.04733051308580945, 0.025794272341074485, 0.016010300117364575, 0.042973633164600025, 0.01087378017649415, 0.023540998996806242, 0.019934735854246446, 0.06149075204326261, 0.042647183947866006, 0.020967039332214384, 0.043927799504730976, 0.1472809243827097, 0.030964277985115207, 0.024313910849272244, 0.0609393717510806, 0.05501693370000971, 0.028436034617404786, 0.07306594221341996, 0.012131551949066982, 0.03684735060819695, 0.04006364435378102, 0.057215303437964576, 0.033459740450545665, 0.030724159216568358, 0.07398570737531109, 0.03562072509779565, 0.01119104112618633, 0.07148610037421027, 0.04598830405983233, 0.028416993502046795, 0.03140328658534394, 0.014344564500084568, 0.0255514090625389, 0.038465853074505445, 0.032673872136060274, 0.023422755240913362, 0.041410932542696115, 0.05298732164045496, 0.04390491645843272, 0.041906541633990504, 0.01597706051993995, 0.028116095232807344, 0.03418520656264117, 0.02998931618827966, 0.06323613399159043, 0.00029696440774827236, 0.014626878433890883, 0.05379550992661426, 0.06305348330868349, 0.01572225488827474, 0.07384208121126698, 0.05006218344093331, 0.01751448981644165, 0.055924962394900864, 0.05207963768512972, 0.0591846703431539, 0.05192668057016788, 0.05632998541958871, 0.06501875547391754, 0.06851230026973833, 0.03295361680249053, 0.02321767158836367, 0.022316553006549517, 0.02577876672148705, 0.057580298368608764, 0.0985000612995317, 0.03872966694255029, 0.014403790757510693, 0.0769627403708235, 0.030111059050766692, 0.01765422616905022, 0.0412010665862791, 0.030792850490298965, 0.07601552627860539, 0.06184191525643391, 0.030397122027352456, 0.03310514899391321, 0.07621308503251883, 0.010850619423323342, 0.06380604978110041, 0.02873040390230956, 0.035924658990435065, 0.05339435564594404, 0.061739696144697175, 0.06261615435622873, 0.015165769577687307, 0.02088587997751611, 0.0526097513765337, 0.030235347240382147, 0.05855262482298478, 0.030707402958444534, 0.0403478859563268, 0.04014665381081643, 0.024413214996457103, 0.10651515661588601, 0.009519914165139198, 0.001395385822228667, 0.0607794240838097, 0.06451229474717571, 0.07766892021942524, 0.012609086153397878, 0.011325293246866956, 0.07453447147723168, 0.06894014505369049, 0.04231623013413722, 0.09500914418529119, 0.019328654969051, 0.03739090148179281, 0.02996563641054015, 0.03971494028284665, 0.012256362993690756, 0.039880836622849594, 0.0376712781707606, 0.03958862004501205, 0.007435691049097167, 0.005924157918460908, 0.04357634900858806, 0.02976970176302618, 0.08552594861436276, 0.04881285491489595, 0.024348084116354588, 0.03534993216876061, 0.034353998714997884, 0.032713792977794524, 0.038585496856079954, 0.019787085813380057, 0.02273725019016814, 0.06595486895211282, 0.05814220853931001, 0.02292218956074888, 0.06730368931687648, 0.012912805541418495, 0.035733972045202414, 0.056963612911321466, 0.012711892280006602, 0.010325113750783908, 0.017365177364779577, 0.035703883941976294, 0.05032844879033585, 0.015258799464772306, 0.012373363771926493, 0.0620272395861966, 0.044677133086107435, 0.11546624283636771, 0.01638903770776045, 0.06422798419671674, 0.010424936922537464, 0.048208043820435004, 0.031656783164268544, 0.051230486677659136, 0.10325284013825078, 0.046647492075158704, 0.017089406779456525, 0.07807994937343944, 0.0332568803681962, 0.07021604916982113, 0.02032410961786105, 0.04278319902838238, 0.03913203930302013, 0.03188455259547599, 0.0593771192906124, 0.05863697876432731, 0.006162263790986711, 0.014756425817106521, 0.03335468681348908, 0.08400078247030897, 0.04544910456564638, 0.03744685654378226, 0.03635587456125406, 0.0051254049626990195, 0.02168145654122195, 0.03779946000225121, 0.04677358248661603, 0.06651860241207384, 0.03674694712484076, 0.03626121290689034, 0.02399753568874252, 0.039315563326160756, 0.05809945317225591, 0.02521897478389644, 0.03304111553476222, 0.01163334007404985, 0.03509857105992494, 0.026701479406666853, 0.030882164850951205, 0.026760119606830904, 0.01402495166046485, 0.010872636790267162, 0.019333799249462543, 0.008336939387053491, 0.01760036061187425, 0.010840990655725042, 0.005896910565019015, 0.04865635464328432, 0.061992830747077544, 0.012020973860466433, 0.11802187384737116, 0.10684216890724436, 0.03053400278722327, 0.059686699251253764, 0.0650567994002373, 0.02105538459164241, 0.019653464757627057, 0.035571220496128646, 0.045272739634158156, 0.07008594445764058, 0.021268939261414835, 0.04136009494804087, 0.0674871597138624, 0.025340909168364543, 0.01745854816099088, 0.04770100852774997, 0.0321118662043685, 0.08814968484183473, 0.036198952941284064, 0.0678158420768957, 0.012574150628830879, 0.04925638534909776, 0.02034019746427094, 0.08489172740448868, 0.0724712971057142, 0.033122627289905664, 0.020751912266977375, 0.0033658963530474617, 0.017757941067459124, 0.028625319621736006, 0.02325348236838416, 0.06012745644716967, 0.09353768846560871, 0.05013324958722919, 0.03312500216247093, 0.019415697879007748, 0.015486704876586316, 0.018080605809847196, 0.09341651633862527, 0.04578273585667053, 0.030529425411875692, 0.02402447517059984, 0.030556826461707393, 0.022311661535152988, 0.05225261267755301, 0.02702713380717943, 0.02757453810303442, 0.022206554271941705, 0.11113482001688212, 0.013707626550909013, 0.03259554347624222, 0.027631104120143482, 0.020618482733205445, 0.01845053051628413, 0.10063619022407841, 0.06985984892854769, 0.05037034230847513, 0.004397857485474238, 0.0915937939839017, 0.026539873159039887, 0.015152400385798707, 0.05316008978913869, 0.020176225920177756, 0.017227995915398482, 0.029617805679839466, 0.03668859803808793, 0.03361958469594679, 0.053566817359458056, 0.02044814308324168, 0.014350171306080396, 0.043563536188054475, 0.05385007070858152, 0.0734102221265916, 0.03567354302973517, 0.024491049529563998, 0.04492967013990687, 0.015428275350601444, 0.025476035586888754, 0.021484196561598973, 0.030556228913126454, 0.08626276431905647, 0.04470715224142036, 0.024634455443329872, 0.04974511497083211, 0.0396210945121223, 0.027235869783908132, 0.032576195925714514, 0.03860155788941249, 0.0384592225835208, 0.024322983245515538, 0.05418412334796402, 0.03539232747449029, 0.04423173339737039, 0.012578193657851268, 0.08344748312787664, 0.042636125468679016, 0.0338522877333866, 0.032677511053700606, 0.015498143526905728, 0.06582646495512416, 0.09854166753469937, 0.024784934263856664, 0.037875172471807855, 0.02992681682019705, 0.06898525231067212, 0.010849569882867078, 0.06489147762617757, 0.16150244271322606, 0.13699728184409682, 0.09975523507643132, 0.15630974554486815, 0.08783533598386473, 0.24956630272490365, 0.14055163869934698, 0.09532771418772398, 0.08969859205066197, 0.1697833015913925, 0.0979643589967201, 0.14270111287553466, 0.08522432447681505, 0.1630285664671852, 0.12062363101229553, 0.1891060308703492, 0.27043672879376723, 0.07966718396111842, 0.1159185947730176, 0.06362873490058607, 0.06482803788516792, 0.20241061856429424, 0.1398493199338836, 0.20210373906358597, 0.11202013420481836, 0.12957931376032292, 0.19147722621358212, 0.22181030903612414, 0.16113245288931555, 0.11200131908539804, 0.2124368402385904, 0.10582241394947614, 0.11375901589710867, 0.1880175731475315, 0.16987644256122653, 0.18823823711324125, 0.08112953855626046, 0.1754902735833199, 0.11920534945543736, 0.1423695040566306, 0.10994402826913904, 0.10209161172350568, 0.1003636314623779, 0.10563499053880092, 0.2081551135427529, 0.20151909140329208, 0.1899803670183305, 0.18744122988033682, 0.10423229121032263, 0.15371142045384453, 0.13829436063045455, 0.14760784474351715, 0.09711233132909383, 0.1629244244747585, 0.2064939438095016, 0.1257438179586203, 0.15464856048985837, 0.11275627575213872, 0.12108804883375285, 0.09345272931480601, 0.20490831034558438, 0.12958398689666104, 0.10086959423196894, 0.17409835311193622, 0.17207577373952637, 0.13076581541569005, 0.16265361239352535, 0.1650864165276289, 0.14459926424728287, 0.17926909420038425, 0.3612043275948494, 0.21082920472948782, 0.09662194312700341, 0.13618925826684122, 0.11686530324720568, 0.11594296402988896, 0.12216152953765086, 0.14470648591316518, 0.11461691179823492, 0.13176770520306405, 0.12535901965513346, 0.23180400261715536, 0.21261495568098562, 0.092674698079786, 0.11893405473881191, 0.18571563215265352, 0.16606572204299513, 0.19360290569884164, 0.13012315957776963, 0.1490396017869634, 0.13519170453711865, 0.1363858364282116, 0.14777831462842805, 0.1695710033058159, 0.10958252669942957, 0.13220302700515718, 0.12475165748788465, 0.10584772549449437, 0.11654258870910253, 0.15776465376538618, 0.20151498517201794, 0.16958289299040072, 0.20498147174235315, 0.1799406775183255, 0.1980627018717989, 0.10504451294940327, 0.13282409448537136, 0.21595352088972447, 0.16872138115427188, 0.2820293551250812, 0.09252550245653238, 0.15406775859094438, 0.10515900478968698, 0.1432382171192477, 0.236202189999242, 0.09794195858581413, 0.09770843200385572, 0.21159230491086362, 0.08505929381616655, 0.10258360104935785, 0.17333514567825103, 0.13843567320896735, 0.2299271791332191, 0.2885595805221989, 0.13657867608051147, 0.1817912395082174, 0.12028346499127728, 0.16159418940303788, 0.1561141020107654, 0.17797593778419882, 0.14938785003558283, 0.13650205196632495, 0.1597880145474788, 0.16168535386602725, 0.10160061065107585, 0.13902468757042963, 0.11149978430400934, 0.10360682638542307, 0.17304649907014064, 0.1081600929460218, 0.12314308735151445, 0.09942796997605793, 0.12788944637342808, 0.23683085707166504, 0.12332610575662506, 0.10768301935205538, 0.23357095377099132, 0.18083919140119709, 0.17412881276780562, 0.1835834715635546, 0.11842166449153617, 0.14560892216620908, 0.1633909873424038, 0.17025717293783543, 0.17606470163070387, 0.174054931248388, 0.08742944727982245, 0.16876612068904986, 0.17271600873960605, 0.14331790558513136, 0.14459056148846305, 0.18374335411335194, 0.11034326732999857, 0.27881622915306403, 0.09182982567337253, 0.12220207857148302, 0.12026710901409389, 0.20529270262247135, 0.22527817456472307, 0.1551341376597843, 0.10298571293993343, 0.1061509124514076, 0.16876253539756422, 0.15231545503822067, 0.18872479487571026, 0.15137149681968076], [0.0058420854827178825, 0.024697376159770836, 0.03503406262626091, 0.042343556490396304, 0.04929429521003077, 0.061887206374517376, 0.04466024850825629, 0.10157663975992512, 0.028333005367688117, 0.021432177276320515, 0.07663627200189137, 0.023161356465049812, 0.04207513460348691, 0.0080461103859688, 0.06205663054941162, 0.10170246204060894, 0.04620613350022224, 0.04192969664150188, 0.009824171729926622, 0.07374116444900151, 0.04687125486652217, 0.03564046335316474, 0.063066782595049, 0.061328257133643475, 0.04581810230569494, 0.04330783902156738, 0.04581738218304612, 0.02311396626605382, 0.01923362750770344, 0.013153209677717138, 0.02644493379780362, 0.019616656148085193, 0.08659033585459956, 0.06938685092233843, 0.027338086980425065, 0.012855802854192595, 0.056003344680873625, 0.04585351855043442, 0.011929552758022422, 0.020736326208157886, 0.0023819358959313365, 0.05089050834818233, 0.05519987166588826, 0.03258304092131796, 0.03379582705336713, 0.07394934884242474, 0.01701256241499176, 0.03262474291747616, 0.09869712209629436, 0.04841849200367447, 0.00659864710365993, 0.05462760781689037, 0.04037362268014301, 0.023870518310896816, 0.028332557206252412, 0.11172709791290183, 0.026657841123280027, 0.08585280768813626, 0.012322259961717553, 0.09389300004489, 0.07156923623575319, 0.04258502740412951, 0.036513738469370914, 0.02810090562448867, 0.09090865090970071, 0.03684472292661667, 0.042459990363568074, 0.07123518359637068, 0.05388305845460104, 0.015786979741777386, 0.04322684820621245, 0.005720597823270627, 0.022762917966071158, 0.016094609051041545, 0.040491810894661376, 0.03806495926372948, 0.05251270718872548, 0.030016903014433, 0.08322338708826611, 0.0396200219890283, 0.010446689031537502, 0.014745814541745332, 0.04876116696264475, 0.006942334735105115, 0.0251367658887419, 0.0571859737617835, 0.08061902522439919, 0.04313630427444174, 0.041425702717876246, 0.07875822829983889, 0.02497696760861624, 0.019563983772851287, 0.01857737743956668, 0.02386532231955038, 0.05281363801670171, 0.07418125131798368, 0.08195272301353755, 0.037395827427145936, 0.05640470963572303, 0.025756418021515976, 0.01983256845344459, 0.007423744386722966, 0.05202117368518826, 0.03331661607409197, 0.028065056540071968, 0.018883933268126943, 0.024378894257449338, 0.04485199265482445, 0.03355414929589437, 0.04382831149644429, 0.06806033903792982, 0.05455757971973189, 0.02163342665880919, 0.025974799045211366, 0.04891212841856384, 0.07965967629946048, 0.019581540592855985, 0.0545163641894056, 0.03511320716971832, 0.03447084244520914, 0.01746245520940471, 0.08450363492292744, 0.035083816206503304, 0.047587187014400005, 0.017371129867951238, 0.02331663482642222, 0.07038536226196636, 0.09491408799564648, 0.13476347670920436, 0.07360328394438952, 0.04472156235527608, 0.0240316093643947, 0.06627316316289288, 0.01734600218403484, 0.111129357809982, 0.01636898535634241, 0.03836372589331962, 0.02498710295185447, 0.018993841987403653, 0.0834153840438493, 0.036691187415272, 0.040373691628056194, 0.0478675292294112, 0.017968530976964582, 0.11451643170608629, 0.05555917839369467, 0.034946851176960815, 0.04190537334990598, 0.04193716599876362, 0.030600748197626204, 0.03758877433175522, 0.037138134601616093, 0.04164201530417608, 0.11127275414764883, 0.02665725123557833, 0.021382465830913956, 0.032439598618375684, 0.018719737643315908, 0.030704489909112457, 0.03274876489153793, 0.017766385271604505, 0.031753314073167505, 0.04827175552265779, 0.015636381220012423, 0.09115872499082359, 0.028241448284637545, 0.022806816719352238, 0.031975703651926694, 0.04065438241307293, 0.05816287376106747, 0.02380811853424436, 0.05079124633583331, 0.03879676092295878, 0.08536836432833826, 0.06042097154403887, 0.028780810572507403, 0.02204158298310734, 0.017749146378088384, 0.09504807677360312, 0.06165878959901391, 0.01242319300335141, 0.09250134770427981, 0.043690871492388754, 0.08739413828739236, 0.04261433792811248, 0.04843712709243259, 0.043485678672309847, 0.029800046505706928, 0.0507555389776826, 0.013370136091966304, 0.08136679598641011, 0.07158464992478972, 0.00770145892015388, 0.035532372177488385, 0.02453306370655135, 0.027820841116350026, 0.033805502743850795, 0.020432507228707115, 0.06748351313534283, 0.010477560459666196, 0.043487364065743266, 0.029104683818596027, 0.021191097067428694, 0.06601188887631701, 0.006420022212795072, 0.03458592417319456, 0.08759406425299184, 0.02505158457244116, 0.1030829065148869, 0.050165444432247075, 0.01646947119415047, 0.02215813751512718, 0.06834283396000825, 0.013388627539238623, 0.05835535335204294, 0.05541454482403013, 0.04751180013221118, 0.019579523866395318, 0.05005205575857432, 0.02104271924303424, 0.04304053562302743, 0.01620240145242743, 0.05937382128209837, 0.015655284439544045, 0.030269591370597485, 0.028047327350284305, 0.01659927138638112, 0.019526234790382367, 0.07613733425856599, 0.04426506971339545, 0.03093186097459928, 0.03224586264320439, 0.019310960253219933, 0.02765232284042624, 0.038209424294050665, 0.045031333837898514, 0.027751789781295007, 0.041768825838282224, 0.01764037912981885, 0.021775840488713116, 0.0316783772676342, 0.04039565153840569, 0.012203759566370037, 0.03419470605290225, 0.06246096409496762, 0.03464292111476103, 0.01708106025152149, 0.013512271257387775, 0.019256790176094062, 0.026255200632036697, 0.02343495902154715, 0.04129909902750965, 0.06128352142930512, 0.060052893109499454, 0.047431242156533465, 0.06145473441950256, 0.020113592486708395, 0.08685405396165387, 0.03439716010865185, 0.015726441558780932, 0.020235379399251074, 0.07594974996942667, 0.021178837745420395, 0.005941979996409388, 0.004710293517658307, 0.06452670486103143, 0.06006392094516947, 0.032667440827935934, 0.02237918835523869, 0.016020752429481477, 0.04658101862596889, 0.03830486352765753, 0.03438062027036663, 0.0315874598680004, 0.047215553931891925, 0.02392341093640895, 0.04303368679698437, 0.03580942787530442, 0.07009657009715034, 0.04408763991969247, 0.05985088338474593, 0.015262729495823866, 0.01694668076872345, 0.01986146912038807, 0.047699541469374974, 0.020104351551121762, 0.05244576259546223, 0.029060160703656655, 0.050244324675370614, 0.030298246889405196, 0.04388512840734855, 0.039657437723250165, 0.03759991708061388, 0.054120358019586534, 0.03367279716316731, 0.05546792200015438, 0.039782363681062576, 0.03359845982143476, 0.008974055451671443, 0.026903144391854445, 0.032771042728376006, 0.05331452162335477, 0.013907314071642056, 0.034198662897031155, 0.05767108744851524, 0.038450634737889615, 0.04695690732689635, 0.026050653241034, 0.02703347126953304, 0.007907343134584447, 0.06484901337253471, 0.0369510023043521, 0.038463623758645794, 0.01645622361871985, 0.04273771255787823, 0.07122117950911484, 0.046704213225072434, 0.05044398251019659, 0.08498079278656552, 0.04374252114024374, 0.03183307340218416, 0.027390910658024015, 0.048002567547824115, 0.0947659036084529, 0.019606225860996113, 0.023535433368036346, 0.03633545448763236, 0.07215362342615282, 0.04650878419558849, 0.09719411121501077, 0.020983726642425024, 0.03096040924109759, 0.0734884703471776, 0.04524552819108771, 0.0019228429840539673, 0.06641410801920199, 0.024255866282469323, 0.04805294932016442, 0.012473073945711217, 0.04299408388173869, 0.030625870135883172, 0.04648022060733169, 0.006440666367134621, 0.06823568890291838, 0.04080733186715553, 0.014750248275607105, 0.07775067712270445, 0.010603947730194177, 0.06785114340844654, 0.0990099004740196, 0.028153748454285726, 0.07039588831004596, 0.12255950455343533, 0.06452295103020246, 0.15951262126045843, 0.10858421454266196, 0.11019833881648318, 0.22705128506547023, 0.06977321970607005, 0.23558000403065837, 0.1916020219364474, 0.193760076297387, 0.11446349503051852, 0.11945263497651586, 0.10112429548415447, 0.09097102578849563, 0.1847005503312234, 0.20156309549366275, 0.13264748057530773, 0.2220062743271551, 0.21039028231415058, 0.13669729713470707, 0.17816021257350523, 0.09306508116424085, 0.17302167782139394, 0.11170043039225763, 0.15697133907627675, 0.10407135912006903, 0.21236533359173806, 0.15125230886042118, 0.09751704025773272, 0.16086237625248972, 0.1288272452450568, 0.10571819534825702, 0.15895599709643474, 0.11708715464919807, 0.1093617171770142, 0.07807439523598841, 0.1710688430936106, 0.14504909575466188, 0.11151516734952889, 0.1556523501752846, 0.2357513932210784, 0.0955793357664539, 0.11826787234073687, 0.1588676824805237, 0.12999482452869415, 0.15662491411691712, 0.1056619951381318, 0.11762269607354557, 0.22914829754060317, 0.12477023512004845, 0.07462853941345408, 0.14149279303608403, 0.14897739544751185, 0.12713913986038777, 0.11775029567821373, 0.2115284284997371, 0.18183927322106977, 0.11555926123213385, 0.08413730699929499, 0.2178423719540719, 0.17588169854735175, 0.2090746029129913, 0.1702848746771774, 0.08667750133862419, 0.24340467287167428, 0.13044277145977945, 0.0896646466947371, 0.1354655962918074, 0.17069644775361786, 0.10807331816683854, 0.11510431225742064, 0.11442162066457734, 0.055967254278760765, 0.08090225559088492, 0.15249068999002058, 0.14491167490280446, 0.2150315800381284, 0.1796863210057059, 0.15269713536385568, 0.0924198589317741, 0.1251575385310477, 0.2233076738494058, 0.12323011493971273, 0.10796396677652675, 0.1082924422958205, 0.21247321409323525, 0.10899724318615853, 0.11310745811750812, 0.06603279541577063, 0.15003743130833874, 0.11279783602203093, 0.10445753638181957, 0.13675340541428135, 0.11194701877332504, 0.13802875794710653, 0.14561898856153413, 0.14341596483943925, 0.10231108825293281, 0.15546743187212175, 0.14329319158869405, 0.07073371010201593, 0.11335362515021717, 0.24628200718472082, 0.09490461148802312, 0.10803809344408014, 0.09891730342661181, 0.10988373714949816, 0.1193072468102459, 0.09191852333324571, 0.10129961470562605, 0.29158679227675166, 0.1733839608007862, 0.1960540193343355, 0.10526718406547463, 0.18218133147926102, 0.1533131619855281, 0.1506481719233336, 0.18669325227458633, 0.07367104442129213, 0.10576339453578958, 0.18220650512845288, 0.17782841989349935, 0.10635981696747965, 0.18760869670058453, 0.17757974775327792, 0.11587577811892956, 0.10340497753913365, 0.26310306102518116, 0.27267888428703435, 0.15823273348712152, 0.1037690531642687, 0.1437405562929569, 0.15156122615500806, 0.1936757759821992, 0.2015794591317254, 0.11301745810816366, 0.15873772332504874, 0.12092324799948162, 0.23877356411708942, 0.17096791867046587, 0.11146714129755575, 0.1574153942807067, 0.1569203176205197, 0.14206814038897717, 0.22524765362181973, 0.192999902571882, 0.15644333595710416, 0.14541015299337526, 0.14743253318292482, 0.17198923644759964, 0.08188083332272307, 0.21295304560372907, 0.14958554668532265, 0.250123325254648, 0.09919881775614717, 0.1149497080534216, 0.1374497027286599, 0.1110793705729227, 0.09778165468765844, 0.18347384438159006, 0.11420229735273509, 0.16606336249218834, 0.09825600866949367, 0.131798624511688, 0.08763693453323457, 0.11029911768292228, 0.09756998459417975, 0.1798931647452616, 0.1895665109998757, 0.08474107621417892, 0.14397390667469273, 0.14170444780780425, 0.23430961574758255, 0.1857911684219876, 0.15372697203870744, 0.2506258023241835], [0.02110335318702123, 0.006541236953419303, 0.04136359980029445, 0.08774098459511034, 0.021121674179730397, 0.0416703682182537, 0.01809603290542239, 0.0616818756586121, 0.017531230752806992, 0.040356309093054266, 0.08611297880810115, 0.03174103942940072, 0.007799595740864114, 0.052237635658633326, 0.06114586692063078, 0.05270569239773097, 0.038958704249272426, 0.039870762566645304, 0.05657069024539763, 0.036359682018237735, 0.013733459993325656, 0.03432449283859423, 0.030392550397664312, 0.06295079305287331, 0.03206387654157176, 0.017245039456493912, 0.0676776398153555, 0.06827266796702339, 0.039712048300932494, 0.11226643147247453, 0.022316156556048704, 0.030824834661137675, 0.04190420123538183, 0.09311621753318657, 0.11422455986781467, 0.07616823824543147, 0.00931525377616767, 0.04382075786951088, 0.02025023192888306, 0.013362118024228802, 0.017910084214001414, 0.04291837141218205, 0.027412901211890484, 0.043489934290729226, 0.05735625595515294, 0.05384894838977245, 0.05925456054448601, 0.036295261684684985, 0.027761013479903344, 0.0585987126725095, 0.1233144075940213, 0.09030413858953024, 0.007699725167420243, 0.055387770051076535, 0.108137508674014, 0.023919637953381867, 0.03736348319498282, 0.042148108308714245, 0.05383215957291184, 0.008600174858715505, 0.047639729154686776, 0.043531073212263086, 0.03335890412751225, 0.002500672581522996, 0.035997843369841576, 0.07626142518054094, 0.005029412709371818, 0.017081812932907094, 0.036968564870016235, 0.07654030416761676, 0.021931233763274167, 0.07058141182266897, 0.06771137832754082, 0.11393877076766185, 0.011390129183118623, 0.011885661665620583, 0.015524777531203245, 0.01594509262846963, 0.0058387079925817115, 0.07054326830491905, 0.046386459106279, 0.09181186857242739, 0.025785914321820584, 0.020699500361637726, 0.04028196409044247, 0.04123983446568732, 0.06515153383295383, 0.03255095332860947, 0.028176930274874456, 0.014020907673834553, 0.05380953316606822, 0.08146044257427416, 0.02279106212118941, 0.03766511882384939, 0.02869203247340216, 0.004604283228306281, 0.02825126378616739, 0.01935754989033505, 0.039486580963937506, 0.0455109240306962, 0.08143579752575006, 0.044916627492996, 0.018493406542186296, 0.1035068212677875, 0.09801442284257182, 0.035822102800011635, 0.06480549957843558, 0.023775013959816387, 0.03710485957262497, 0.027233755381237117, 0.06433145203177007, 0.025755893251287843, 0.058488736920539415, 0.10774842793903044, 0.04080250551323256, 0.04223667190320069, 0.05160488533757387, 0.04550903945440247, 0.029083871124913136, 0.04371075913490307, 0.04411201300700346, 0.05200033226320821, 0.020346584722339627, 0.03010116119478499, 0.029011353242000746, 0.08131182917784299, 0.03260747146522326, 0.023163214228266192, 0.07335366951602121, 0.032530533254987774, 0.03584600857368881, 0.0304658018097642, 0.022579690802001187, 0.079334648175826, 0.022709738057587418, 0.03454304623207258, 0.02519903160000761, 0.08221269495064214, 0.09720556422947876, 0.007392903602111244, 0.0172223077125607, 0.06767005554490513, 0.05932086928477211, 0.03809821897096211, 0.03504957973716721, 0.013015282250219777, 0.031924540469903624, 0.02206286682086366, 0.00913137543736206, 0.03977508967622154, 0.021615276120663173, 0.03700693438370382, 0.030241864733397964, 0.02718948316009295, 0.011772730729482588, 0.03802242989261304, 0.03185119138159339, 0.051672519409968976, 0.029003912613036174, 0.042264002089899395, 0.010424673579813493, 0.035247356826139074, 0.030157062630619735, 0.02707523072228557, 0.027668389619418213, 0.04140445526929633, 0.03983837619964634, 0.017839098506937587, 0.048757792345338294, 0.055166182949418024, 0.09370333199659664, 0.038107565243638335, 0.027688579866662625, 0.04826350475571329, 0.059299725258061965, 0.03366660717273912, 0.01916277778124617, 0.03469939328609936, 0.014063628566932055, 0.025870350617614966, 0.027988350071433573, 0.1346487473816641, 0.0207875142880385, 0.030054870331960342, 0.05004221152874732, 0.0547291451103745, 0.016884518479327523, 0.025798378572348627, 0.01820596269211702, 0.011458497742311129, 0.06420234323389108, 0.05424524567300274, 0.036827823027007045, 0.012477434901220184, 0.051272644496132294, 0.03076879341425675, 0.0218196319896848, 0.052156974261085835, 0.0481331434040781, 0.021289206117451675, 0.023547501168063572, 0.09459344955581812, 0.041826554393816384, 0.05178834807368056, 0.06522251954001766, 0.060834218522593866, 0.030133250702713287, 0.04558733364026393, 0.03707308990640506, 0.09354534934485152, 0.018566715410880504, 0.07382774770620369, 0.017159057578312296, 0.026651097634326548, 0.05859731839248731, 0.009488826317171897, 0.02175309150780161, 0.05300036811780545, 0.056473354944178177, 0.05209178017872957, 0.055488755761255185, 0.12501208141686457, 0.058871834508834354, 0.12732137685581563, 0.010103842660394168, 0.04931845762316258, 0.010950347791696268, 0.042876317015578674, 0.02855657855229032, 0.02409147722045741, 0.0422950899378667, 0.024601029111973705, 0.023869041676422762, 0.06407226533478787, 0.08620176073764602, 0.006957263873529531, 0.04129054182539544, 0.03753729322324357, 0.0030511826457035158, 0.025872769540235884, 0.025260339701367963, 0.12290040601886089, 0.052029573839278, 0.016545421150963635, 0.011648847608857099, 0.04715813947240672, 0.04182039504690517, 0.07996179839415897, 0.02258330482178398, 0.05125384852891007, 0.03715845891424725, 0.08486199553214735, 0.015899003821335012, 0.03304832825256932, 0.05768699909470255, 0.023518646466395548, 0.019127627752060374, 0.041917956344062285, 0.03558272713675134, 0.011122196634870865, 0.019353470472138257, 0.024693490178774924, 0.025069108833709074, 0.0502333159918987, 0.053492208056512384, 0.06549923049826777, 0.033119490159855734, 0.0640678488379044, 0.03646901808679104, 0.07743285788643746, 0.04937517877307631, 0.04446937770192181, 0.014614567400947695, 0.06359720655206232, 0.07527662681475764, 0.023844925228566415, 0.05082444858647162, 0.11073063968891099, 0.00864141815972905, 0.009296758498455729, 0.02409221841052415, 0.017672619940112197, 0.01173243546227534, 0.022871947599454753, 0.04088812349965015, 0.03259154066683785, 0.07406197142817321, 0.01116517799786262, 0.008648704613498863, 0.013894375804210863, 0.021869571346248833, 0.02854424070626978, 0.031463127628329306, 0.04943938460201026, 0.02944538610116128, 0.006155700332695438, 0.02916448272674555, 0.08496077490910407, 0.021218099751539772, 0.04871536639609164, 0.13985940165096714, 0.015751750230969443, 0.031052000798104756, 0.03563277183040496, 0.020070975015480674, 0.06595833166953056, 0.02374082345575575, 0.07092333984591308, 0.07312414191302753, 0.0543291591137888, 0.03599468325715392, 0.07811941056241913, 0.08385749338495155, 0.04576194806084518, 0.014753340397991482, 0.03380737965926528, 0.04051172151981343, 0.026582739608843, 0.017097730324753833, 0.010732739559194494, 0.03893754107036418, 0.03532215765106582, 0.03891359316185117, 0.05205479345374531, 0.0009036738441453407, 0.025537904847653645, 0.007258078351902265, 0.017463769050194852, 0.017928935722598148, 0.021916695329691135, 0.0076701723681312185, 0.03254773192888787, 0.06244397226480707, 0.04350125707025009, 0.08719186809274458, 0.008168916195450772, 0.0329494952494579, 0.008793556518221815, 0.07247336554310976, 0.003352159199552731, 0.10604290937584256, 0.04614550147145506, 0.06864925380796194, 0.009583677578296874, 0.09027986126320978, 0.06046758799423134, 0.05962488361664357, 0.0618859040250461, 0.0332898298098195, 0.025300580384810607, 0.02772992180149642, 0.05520290920450803, 0.11939087296806036, 0.16146819858301073, 0.19684160368577128, 0.18219908939734583, 0.26337465451609704, 0.1491123341744946, 0.10878417881265764, 0.09511622795534712, 0.16001676840166892, 0.11209401572423597, 0.24646214509923614, 0.09328080386283899, 0.12226388654521397, 0.12446102671205037, 0.1362295085263829, 0.15576517960477262, 0.1699739961975044, 0.08843955719062398, 0.20860575710333165, 0.1388236967426154, 0.0640844231501462, 0.1387300195112344, 0.1238118974311698, 0.20858432196321028, 0.18893620449929469, 0.15534692624163243, 0.14625648096684488, 0.13305693924907716, 0.2189190472446142, 0.1905578594174116, 0.08252132879269701, 0.17241179522487426, 0.1533690710822421, 0.21561924608484392, 0.1786919542017483, 0.12482988272583294, 0.04504386320590012, 0.1914300811627219, 0.10533166568606131, 0.11880344440860134, 0.18183927322106977, 0.18049987573777476, 0.23952872762756966, 0.10632364995657437, 0.16175784110542268, 0.20259636424241528, 0.17092514032077405, 0.2488986877424102, 0.07619001046423951, 0.17529456876218322, 0.20673101737854943, 0.20238679322984912, 0.19091620470487303, 0.13825798677580972, 0.24904137927918668, 0.10836483760466499, 0.10557391800947728, 0.19701398879049287, 0.18952554061768517, 0.12241433855266341, 0.11761246879975643, 0.1520910832069574, 0.12710468122555366, 0.10956121413337608, 0.09642128937787588, 0.20828737096200067, 0.14195186356382986, 0.07242383795880503, 0.08575608142681661, 0.10853530748957589, 0.13140192886273708, 0.20635189578658153, 0.16378071159124374, 0.1233367620396518, 0.14254424871215898, 0.15880561403689847, 0.07962665024904475, 0.11482485104352237, 0.18063073887700037, 0.1882166640772935, 0.18293378303848928, 0.15392261557281017, 0.10280205102096643, 0.14136652642440412, 0.07493207110993325, 0.1380467610133271, 0.2151400580882065, 0.1045482105485374, 0.08600836950204066, 0.1455510978496844, 0.1675693534554974, 0.1943806994466051, 0.12009316109000676, 0.2011756235433202, 0.09698709893611171, 0.17286188720214754, 0.11988247158907114, 0.1304473986308421, 0.17028430777211345, 0.15588429095523973, 0.1501230492947563, 0.12790785546624853, 0.19484986701319296, 0.1928065419797936, 0.20080762554801282, 0.09409127126057303, 0.1376514443226399, 0.16355598735953533, 0.06654714684813254, 0.08722153867805198, 0.19658790600876655, 0.11776270630258708, 0.25472526138107626, 0.2363347232101425, 0.09063187100353742, 0.0959143000504663, 0.16940238735368177, 0.11459143171387334, 0.11525526988290011, 0.09300207809334801, 0.14186647540378955, 0.2532448117891627, 0.13916768554237582, 0.12544405541472858, 0.2438960263445493, 0.1757421786145818, 0.09965518399352029, 0.1356316841537914, 0.08747167404620879, 0.15510418362194492, 0.10640925262123348, 0.16040663054633528, 0.20723930139455105, 0.18010713310251314, 0.10499365237211028, 0.17219505362933682, 0.17744654038500401, 0.16895333725598552, 0.22915185218857181, 0.17070211680425754, 0.12070397065291483, 0.15306255930373747, 0.19829090414268358, 0.1134890771561092, 0.14873523505464678, 0.10686395644781091, 0.16721329111005032, 0.09558533423490102, 0.06421367367429119, 0.14062576536690036, 0.1835337524572688, 0.16928653953777206, 0.13676287426102546, 0.09869932076863705, 0.07200899368692791, 0.1532980240881443, 0.22091490547022513, 0.08180527407075129, 0.1966192696483866, 0.15633923992995294, 0.0722323312994934, 0.13159571846406307, 0.15024084297399368, 0.09708784715903383, 0.12666335329413414, 0.13016495733491837, 0.16581326542842775, 0.09561895017301845, 0.15842241685717337, 0.11313356639396761, 0.16991888383223167, 0.19226254294476203, 0.15160723739574034, 0.16265805570348618, 0.13241904847804578, 0.15805777432697435], [0.021540829611401406, 0.056014751730066155, 0.028732142921897675, 0.020938307204614245, 0.05517572074407532, 0.05572061993241791, 0.02717760496682698, 0.05376726426484604, 0.02036675390216612, 0.031404646391409545, 0.05678542086013383, 0.007381194905798523, 0.10141655036638822, 0.07022030861868013, 0.040565853292543086, 0.014254190065267106, 0.05118937073876301, 0.012894419431235763, 0.0397251675566358, 0.009239752938400113, 0.05509580245181438, 0.0728432557755901, 0.029232681788984808, 0.05438722474800964, 0.00223118607180133, 0.03301270133365066, 0.04964047502125463, 0.04835663806466807, 0.008481554762129823, 0.09705654480644772, 0.022405181718509526, 0.046719075330803474, 0.031936422493609215, 0.059786807790759115, 0.020076862401178768, 0.015825051438784408, 0.0722842873825181, 0.03140892499246665, 0.007301572036193384, 0.004056156415777702, 0.05584342765711969, 0.06920824518367168, 0.05345490340503955, 0.028704226677936893, 0.010054644493896876, 0.022574481404116078, 0.03835921746588523, 0.00942585676262576, 0.018768570002829357, 0.04217663359257483, 0.06580987149068425, 0.021551807651356347, 0.04563353257253767, 0.05261116097831438, 0.01716439338070491, 0.021618374946316885, 0.05937908047569856, 0.018792521741781986, 0.01880370087981705, 0.07144639403709481, 0.002917179503598281, 0.09595127911457131, 0.046199487687479106, 0.061216664936153166, 0.01563365298939208, 0.04610460386761735, 0.041796623338614745, 0.06945334735416597, 0.061234480310832305, 0.04134987150469134, 0.04703253552678132, 0.043276908221624555, 0.10774215367893059, 0.021077093608196706, 0.005624998668809572, 0.07212725467979908, 0.013790639838384045, 0.033095978921459566, 0.02115159182839336, 0.0665321774900921, 0.01325542495901426, 0.020418501226231456, 0.09159721839692324, 0.01995403552427888, 0.006770315916172319, 0.03267883638580961, 0.047617573891916586, 0.04176939657378582, 0.03508646304028169, 0.01269694590460389, 0.04520595208891938, 0.015085627204708517, 0.010544871817523194, 0.015026716000941253, 0.008986292748651918, 0.04628792104701843, 0.027199501674922726, 0.019524049524578358, 0.02452858592263393, 0.027460216717313857, 0.029049852990635464, 0.00551318334821131, 0.061270808200201685, 0.05885814834806708, 0.08673338745270046, 0.03920218997424649, 0.0197151463268505, 0.04887345630014616, 0.06631581127763757, 0.045405958493750904, 0.016027334082360952, 0.08558668406499971, 0.01243112680141724, 0.04371963809394548, 0.07810929820181862, 0.04688485292717815, 0.04953721019950125, 0.045929050989328854, 0.07278596005973316, 0.03942583785242131, 0.0422081810932967, 0.01621051432354556, 0.042785581561826894, 0.019465721505243453, 0.04927436543268062, 0.02927906458236037, 0.03786614029518059, 0.019049760660216696, 0.030203389882620786, 0.03533758666186083, 0.09686792629861063, 0.0457600021975175, 0.0038841761406435966, 0.02021351716511192, 0.09059930460587626, 0.07691066171373091, 0.03568455171320708, 0.052173295764312635, 0.018528907056597453, 0.043104768265038736, 0.031283106542222446, 0.06463499905000772, 0.11245850503685013, 0.028440313218461893, 0.0092875721466337, 0.02462552668857238, 0.06751296921603142, 0.01744404037092482, 0.009675200187390851, 0.029662238779447736, 0.03279465738864195, 0.022112614655446623, 0.07958704350335945, 0.027216242611288067, 0.00393990975534243, 0.00910301007435567, 0.013764080527659147, 0.07447268648613846, 0.00977112588682963, 0.08028314163487765, 0.01503658225579608, 0.05864416466905706, 0.0594339247101978, 0.034444266855115854, 0.010590114097501482, 0.08731289466302242, 0.022669064534467556, 0.09090812230903296, 0.03250572732799957, 0.13147030987085837, 0.08340687280701053, 0.08868659756356671, 0.02364454344065199, 0.02035467652603984, 0.03354720470886077, 0.032860035332100045, 0.03929165372204396, 0.07775847589777363, 0.052971107389537565, 0.024017660818513364, 0.03490678860896057, 0.05638684446532881, 0.013752731892670837, 0.07826721190565056, 0.08190320309011206, 0.08616123468645158, 0.007800684543326498, 0.02225243144728724, 0.09187962138845075, 0.04082746848824524, 0.028638295235953508, 0.02473448354360317, 0.017448129365220666, 0.02692270453178114, 0.006649608708797924, 0.0053943109214155665, 0.022059337070752538, 0.024350064453638853, 0.03073902515273902, 0.018071290180687944, 0.06909952964633703, 0.03250568902360336, 0.0845170874268778, 0.05198092725608618, 0.030909037300115152, 0.06444022885613865, 0.0635859297378169, 0.02809257824875174, 0.02124363729249566, 0.09819327372937434, 0.028350548781154138, 0.016814214590516303, 0.02251966206747438, 0.03932162308164182, 0.05065587093873371, 0.009051323079714372, 0.04367955254330751, 0.043960193532609174, 0.046588959127304055, 0.03794207876067489, 0.029412699044652046, 0.08781220012855145, 0.0448447875978966, 0.07485278100977022, 0.017302666505378102, 0.04031578304185983, 0.056554855208002755, 0.03428305897320952, 0.05232192448250229, 0.01725033120883088, 0.025828160240405032, 0.03348622794052766, 0.04015137291243, 0.0342444519722654, 0.022325114039103353, 0.12975657118424294, 0.04183059167717734, 0.025164323986598083, 0.035792206218766595, 0.025037591976504174, 0.062419300403205626, 0.02154316617957046, 0.027083366576041427, 0.05196099364829641, 0.04537572483381918, 0.028744019199943835, 0.009511116602938742, 0.05939648216289859, 0.09921456086299113, 0.020950045586834033, 0.044591967091565175, 0.037035547767675696, 0.002172639478005529, 0.017040982361762755, 0.0200096994728571, 0.027622723118251855, 0.030600686910592263, 0.020905449693541855, 0.07444641733121488, 0.013312101101262436, 0.032814012600048896, 0.01643186968360697, 0.030987706869059516, 0.03136510093275818, 0.020496140406917662, 0.04856341668675023, 0.08071165291532394, 0.03400123820850446, 0.022770414136410243, 0.00925823480957338, 0.060592762930619146, 0.030376154200864897, 0.034546455323335626, 0.048336666152482076, 0.006317216564991302, 0.021195465683816903, 0.028595647121208812, 0.031138756425089897, 0.07951269467030803, 0.06104234928986239, 0.038362787435612375, 0.010418339947899504, 0.022799379920827288, 0.010883693354234341, 0.03006461497035719, 0.06906849542452444, 0.06416684271947992, 0.03146614984519059, 0.042861320844460885, 0.01947491839077444, 0.054367865706163074, 0.00488590193732131, 0.03190437895095637, 0.011744328977299795, 0.03652586181077265, 0.04039245695176144, 0.0331481724917408, 0.015577708461111592, 0.056898315407095425, 0.02058809777090867, 0.0545589050518409, 0.021065954689777667, 0.03313899858884754, 0.042334355774425694, 0.05047688215610482, 0.04584801803913809, 0.012530883898087328, 0.02464460993876621, 0.058585068646578066, 0.0621924655992658, 0.01899208190039762, 0.010121407141278108, 0.05672874567549556, 0.03370337939310459, 0.07276626393919991, 0.08364570071740497, 0.023269426573308247, 0.026360407486678134, 0.024484625882318905, 0.04689738229517976, 0.035258587675109025, 0.02931183590854128, 0.02069074972232263, 0.01102624316474483, 0.05397191699293833, 0.029798560295133825, 0.03748224214500478, 0.013000586768612267, 0.07162034962206118, 0.05556339570771783, 0.0542980176396668, 0.004236847828818305, 0.031542092141124516, 0.06685843135440542, 0.01055253652720562, 0.051523155247372006, 0.030220236156075716, 0.04952751535681948, 0.031884422360528866, 0.057217827697675076, 0.00933109647444179, 0.06838516797870398, 0.046271672322144436, 0.006657673699420787, 0.05138565395628253, 0.015989792901241494, 0.09512406503481251, 0.02767302445136011, 0.023565975378357598, 0.038408982537446484, 0.10373591220066433, 0.04386665802749415, 0.13481531021816118, 0.16741302555366872, 0.17856493682390262, 0.12444774274744334, 0.10963936276253193, 0.13068505442671238, 0.11773388607487564, 0.16484493029213723, 0.2244262541494062, 0.23298376269878882, 0.08783968736327465, 0.08381346631194315, 0.1720542313470956, 0.14887463241334886, 0.1069383206026208, 0.1020333047715887, 0.12529511260048998, 0.0817107081773781, 0.10856716142546748, 0.07057342152561873, 0.11301265473687842, 0.1691243434024434, 0.17533714792901473, 0.16585468014161434, 0.11882924624989111, 0.19886637406964458, 0.1618404407054186, 0.22684606543231398, 0.1538086982984697, 0.19439847268644841, 0.12404525547378487, 0.11224583136819064, 0.11941472894602245, 0.2082227131411914, 0.10709386709476672, 0.10096627452801313, 0.1326935071377985, 0.13021482965878903, 0.16810898578936057, 0.11282484062136182, 0.10249327928308519, 0.17696549845558984, 0.16436099255036923, 0.167961023567665, 0.21052402594397146, 0.22231914463543126, 0.21266154914854035, 0.13736497340423448, 0.11080878065718759, 0.1319243701835794, 0.16045998090938215, 0.1394335486956181, 0.1615182547679832, 0.13808941678895106, 0.0855138214425214, 0.10466516153105807, 0.22684545256197455, 0.1828925828299215, 0.1061676974378286, 0.2564784689175506, 0.08040026115674166, 0.22176604447585924, 0.14493687919551326, 0.18782808896033995, 0.10201796003046537, 0.09962085559363328, 0.1494839021395291, 0.14650896822492923, 0.0858702821536891, 0.17055292884188314, 0.11795483349311738, 0.18041077971218095, 0.2751070152847998, 0.09178543087816046, 0.1547922632626949, 0.13637979965536826, 0.1657701959653247, 0.13610265968788055, 0.11576393694286385, 0.16571096204701932, 0.09040491745596932, 0.09955416763982466, 0.24228422331713864, 0.09274956785262593, 0.14290250206906951, 0.09439755321270037, 0.11607322195965437, 0.09725316127221431, 0.1229605056165207, 0.1259996070556583, 0.15583814181868108, 0.18958803807054797, 0.1028290709420558, 0.08558132911040899, 0.18863508597977702, 0.1167725989474885, 0.09298662609991529, 0.1621616766938279, 0.13215182168829825, 0.10710027158981371, 0.09446276261681512, 0.1314394978145438, 0.1853003052453841, 0.17622637682624404, 0.14664819704428797, 0.13276443155782838, 0.07336699944590369, 0.1441075583739627, 0.1369242583431544, 0.2683524486999358, 0.1194674434560922, 0.18767407464404262, 0.10767326705277928, 0.14688781402524442, 0.17909945169043157, 0.15520029701292515, 0.10512695167093508, 0.10199870058004895, 0.20626079261062608, 0.10259641003945183, 0.14889068961624177, 0.15431486791180027, 0.13804743517070048, 0.13145279710090932, 0.10907924523757351, 0.10298796523843082, 0.1638923306018114, 0.1705394763379328, 0.08240128281496226, 0.15416569527118437, 0.1487687590622133, 0.15225162459236963, 0.1188029541123298, 0.21738984381719945, 0.12325234681127534, 0.15508311620402723, 0.22785108085841904, 0.18442328778966782, 0.20038561835404367, 0.15932028722618857, 0.11876594440470781, 0.12437193068645655, 0.1356972766018683, 0.18361164827740964, 0.10913770540707535, 0.050387249868964, 0.12639304683093103, 0.0766226739412354, 0.19831065388937152, 0.11958734387712133, 0.18627329819625427, 0.14085945282732287, 0.1884463219152343, 0.14278466242455667, 0.17405707629457598, 0.09770853159528586, 0.10718504687951458, 0.13115206162535376, 0.15486652782607466, 0.16244215680466545, 0.14777607765168915, 0.15303445919867487, 0.11163263161095882, 0.22717399702918148, 0.13232284315651463, 0.18060691354255523, 0.1908635591427165, 0.14258698109657536, 0.08137116268757852, 0.2989381413546301, 0.17441583526951654, 0.12158666482015003, 0.1538712876818834, 0.10994427341727481, 0.1896577520716575, 0.14656835536081947], [0.041574120761886726, 0.026469444780940973, 0.017520585961099115, 0.05876031125925722, 0.020680874848978657, 0.012612181148611972, 0.1215788737059601, 0.028247870016662825, 0.04015726029812809, 0.0744898391947631, 0.044477402472928654, 0.06845907248075932, 0.11189574450855294, 0.03403933959141855, 0.048573609486582785, 0.054666053939370386, 0.05727425390373796, 0.05809086915706435, 0.039651017906444694, 0.0312958772279202, 0.02207449986599386, 0.029856308002866087, 0.04602833215387599, 0.04835552723717786, 0.0047864943682666755, 0.021278549834424933, 0.031607849298105124, 0.06755599271385901, 0.07266102644104151, 0.030559095997183077, 0.04729986573839861, 0.02942035992389485, 0.01575984299227956, 0.07839465063185462, 0.09898444337229576, 0.06246346920248001, 0.0938071292494574, 0.0642922283300469, 0.030074192984630505, 0.07378646322796423, 0.032938088200265364, 0.04775992068912714, 0.02441793409807067, 0.045807200874532425, 0.007842489003744579, 0.040332073901569655, 0.0699954771346623, 0.023033599812357176, 0.01583221053043681, 0.04342198995272479, 0.004368240526321555, 0.041506712685429284, 0.04015001693680402, 0.044561212491844936, 0.0041955748418976944, 0.013317070139061301, 0.04176870709465396, 0.03180856816470623, 0.029248411489290096, 0.03125093084940266, 0.11055817797539697, 0.005226501755626692, 0.049003959378047336, 0.028916731807253057, 0.0040831619727184935, 0.0418197745156865, 0.041444084997619354, 0.05187200104457237, 0.025948206218139782, 0.09545624841965976, 0.04520870617500717, 0.04078428028151393, 0.038043593071521296, 0.05448573599419287, 0.059896932929874434, 0.008625271899114934, 0.02913334125262355, 0.009293773628380752, 0.05738894875732161, 0.046998996197456316, 0.04422255566403751, 0.04055849118759075, 0.017678514986689535, 0.02155007437742766, 0.10006198434219246, 0.04669305132401567, 0.05555660433826908, 0.041576093438291745, 0.06347872339369309, 0.019295701696988077, 0.04647740140377034, 0.05625295144836268, 0.012442163255576406, 0.012035617631139054, 0.023277884183992303, 0.022046606604670806, 0.02035349483541664, 0.039095401148041414, 0.015415180035145774, 0.08170116272184157, 0.06391243258070561, 0.0392999466238243, 0.011541193103297584, 0.014267171425144038, 0.06693529295584848, 0.032178546497297865, 0.010050510491935477, 0.07773414494529848, 0.035076990363097964, 0.048110785128007975, 0.045274635701770746, 0.017987606566279166, 0.12820402505777537, 0.03241231056651281, 0.06834150096701999, 0.024124055109437437, 0.00847553522626479, 0.03500913795564444, 0.033741538232613, 0.055792126579270254, 0.03985740965412509, 0.024562115675859877, 0.020643715754211433, 0.03998759863597732, 0.02812931216472099, 0.050494551974078344, 0.03241026128131536, 0.07591071012880533, 0.01357069791054293, 0.05154891112338632, 0.06174475615543704, 0.05693832817938059, 0.034709612899009264, 0.019768521587754932, 0.012533769176732148, 0.008743834539106297, 0.031640484643679474, 0.09728411122435525, 0.10531989857554437, 0.0376972830253503, 0.061967477067223484, 0.07234436399754017, 0.0166730399078299, 0.056357683328491066, 0.03232395381576592, 0.03594974070907601, 0.0034577936270169074, 0.06286285382004515, 0.05380224383946869, 0.016583057135463725, 0.018781572430124207, 0.04329930097165127, 0.03194810533445449, 0.04747172990333169, 0.03382561255186316, 0.007466145438112079, 0.06098502293048848, 0.022854737434235793, 0.02552471855925697, 0.029249300151282263, 0.0290107365412217, 0.02005599033568175, 0.020311260408151056, 0.05179025563261202, 0.04833742074908749, 0.057591330034718405, 0.031850065232344696, 0.00895438039855611, 0.0209251802880317, 0.0037622855668286645, 0.061274719079055136, 0.0490425931920688, 0.06869883501842138, 0.058985659852623946, 0.0775105775063557, 0.021180777863088637, 0.06778424861089838, 0.05863998948986973, 0.03353310103017477, 0.04197563127344174, 0.02831583733730499, 0.01449963027205799, 0.06005533309953828, 0.03716444972181513, 0.02965113433498529, 0.054792014115880576, 0.051011883488465706, 0.027710332933272568, 0.03386966260750929, 0.03777448170548005, 0.018997957794776848, 0.049633951782579386, 0.01672197377399331, 0.06059910613863219, 0.024323668894207767, 0.03303615128501289, 0.016524422680959105, 0.05455809299864116, 0.05705460500452788, 0.056022071700182655, 0.029812305827715227, 0.02401195920913691, 0.0417175094386743, 0.042607550389103355, 0.019437069816875364, 0.06066766717741567, 0.029386117708899324, 0.0116269595192505, 0.019396290956665913, 0.07449085043082315, 0.04514407133683563, 0.04372800377407863, 0.07439974725486771, 0.12209390695657461, 0.03103551267075443, 0.09701146053210383, 0.036394240244502024, 0.02216770403808163, 0.026464560970423684, 0.04571023329551663, 0.03765632030403903, 0.01946617924277821, 0.0067728090535609, 0.028261157811709472, 0.026426967120759433, 0.011578326342597364, 0.029037681768738458, 0.04439223647838639, 0.04638736692046927, 0.05770432417311015, 0.011281958525820125, 0.0450817654059539, 0.031007673035586075, 0.040676656419471394, 0.013111034622265687, 0.01382419640468734, 0.07492310788121916, 0.03608253055943116, 0.052873423518312555, 0.009191636871095867, 0.03238359759111078, 0.028293375639365088, 0.022365574972824227, 0.00652637628410312, 0.042614586906687874, 0.04415581025363457, 0.07714365969502157, 0.04711889661848546, 0.03926529263656947, 0.04576726471103969, 0.03985571276937281, 0.045042760039289156, 0.03244972630073467, 0.027287306842364134, 0.028427835561395175, 0.0429047427080091, 0.037791140287393526, 0.026167106266403874, 0.04006695385361391, 0.07464029886309179, 0.04551199272335057, 0.05013132670653924, 0.015409548331292407, 0.04335227978205489, 0.06802897539830978, 0.05881837689347806, 0.02912441058264625, 0.05136622596652277, 0.058257278775976556, 0.032807776644345255, 0.04810010969278313, 0.01803015125915408, 0.02187090433923708, 0.017129827493561373, 0.042007354974386193, 0.058790521936551224, 0.09968043425150457, 0.023552312200228055, 0.03803440767730917, 0.038956896281771125, 0.10446205630057281, 0.03395893483332569, 0.07243492325106937, 0.03597778335754429, 0.04654025891795755, 0.12822690810407364, 0.09962952004805689, 0.001925847485132005, 0.05737338951157947, 0.049665690805282325, 0.028783855772006418, 0.023346736336187012, 0.020785068552340233, 0.0660403413818248, 0.052104298055412314, 0.05451368288167062, 0.023556073691936272, 0.02657764895458616, 0.019716810652866, 0.02123828425312475, 0.03217445558778221, 0.035088688525701725, 0.03494349954229209, 0.06327791642698069, 0.04326857318500838, 0.05182156181563774, 0.015692594836676316, 0.08321174255181706, 0.04370667205582704, 0.015893006310497802, 0.03033898744521843, 0.023994825652710373, 0.036352143713062814, 0.006854302135311188, 0.07042920547387294, 0.0074301958046553125, 0.12167854174490898, 0.03059672240558411, 0.023505722563112938, 0.05658303192185779, 0.028868654044345025, 0.0458381584875526, 0.04846191769766231, 0.007870712161680024, 0.03562526416874701, 0.04096068351739838, 0.01645759874654393, 0.0037508260884938104, 0.019189548723760153, 0.04604958726333515, 0.03751355981934936, 0.02149858177759715, 0.01693496536914139, 0.011587182319002047, 0.015360613507519086, 0.026115724749322382, 0.06512065282872607, 0.054678395615830544, 0.04503345973188839, 0.058704693275954456, 0.03782432721627336, 0.02143310615792871, 0.014996446909443026, 0.02459195288529079, 0.01479283223048814, 0.014313464203188497, 0.030085339563928788, 0.011904873235541727, 0.04960042011413363, 0.0114169173626109, 0.04571859897564977, 0.03624162403866649, 0.31926076859235764, 0.13998094916103349, 0.10210913215433398, 0.16325301490724087, 0.1732557330040201, 0.13251916084799076, 0.20792240667487347, 0.10711440591201668, 0.17546750545021028, 0.1393162453126523, 0.08746851776396075, 0.13327276153910544, 0.21983429248775208, 0.09624534962518562, 0.12000189703558722, 0.14056781847630778, 0.14077728223656455, 0.13400704149276982, 0.14825278352345192, 0.10496540671034206, 0.11467444500134838, 0.19907047521443139, 0.09617211161962441, 0.1661330458497809, 0.09053144453754348, 0.15878551188976536, 0.184726536033615, 0.1683522033835611, 0.10322351429250934, 0.13781863535123487, 0.1268656005061442, 0.12547409372223964, 0.10443879787119166, 0.13118154068868007, 0.2650556046395533, 0.12635253610149508, 0.1342657800283163, 0.28742886538947787, 0.11416269826792902, 0.1737064378516328, 0.10352599644853223, 0.218537550780081, 0.1315482056909992, 0.10442422687887185, 0.1071820438148514, 0.08842474871104763, 0.14930535768789632, 0.13146795032005157, 0.10033692563733748, 0.08389712311327459, 0.15319576667201135, 0.14153025473558134, 0.19314516816408406, 0.18597300705169478, 0.09983826368566483, 0.12189178997951171, 0.07564761255296969, 0.19854084798885932, 0.21533792327728965, 0.07959514871359834, 0.14874839644518592, 0.06006751389753434, 0.1500470686944262, 0.11981191489124492, 0.09547150123023218, 0.17473167799893888, 0.11236153362739472, 0.11973699915312952, 0.11179649015708316, 0.2026308381990079, 0.13075064687478927, 0.15483674232757863, 0.13943572438532306, 0.14757262002075874, 0.13542926840243802, 0.07525461710869305, 0.10126140223996294, 0.13125428839796974, 0.1653916719219377, 0.10934762882008668, 0.11908823759445261, 0.20109087889713628, 0.10560226326267566, 0.19985956109819875, 0.28421331857961996, 0.20083417815546836, 0.09406998167715727, 0.15571156877183145, 0.14349998936297434, 0.12718194119271733, 0.13441308341439695, 0.20389506713517253, 0.17413016108255233, 0.07637157330229398, 0.1379274198364827, 0.09068424843492047, 0.12452482651438444, 0.0790728452885824, 0.16931424127711406, 0.2736948394486981, 0.20126966849690486, 0.0766463690407334, 0.10295048055629577, 0.08600727399630893, 0.17716627477878527, 0.1459306484508899, 0.1611678614731758, 0.16647328081871235, 0.13143143856958037, 0.20252835095649768, 0.200152084111206, 0.10958637246080946, 0.23967544878682784, 0.17666557503323402, 0.19387382503238418, 0.07733289107319809, 0.14962869275721813, 0.20700795816317683, 0.16191945501392888, 0.16110406167084174, 0.1258283634219439, 0.10735684209653448, 0.1690657989632699, 0.18244998319254768, 0.08712838238645947, 0.13098297069870657, 0.12357080956139874, 0.16373037961461853, 0.16295971048455085, 0.1670432655561355, 0.13596934506729727, 0.20978606876827058, 0.16124200346248765, 0.07418615428069908, 0.1322432619429404, 0.06641565551680904, 0.08017434182787135, 0.19375198640890662, 0.1943956228393701, 0.21655637079909926, 0.16709440958596047, 0.13101061115101462, 0.19599588858264108, 0.10709032776855654, 0.11447218246757986, 0.10020652215086645, 0.1642219782356293, 0.09419237188394032, 0.13816829320163498, 0.18445273620947716, 0.13875638825758813, 0.1501966397007627, 0.13613949319527996, 0.13129355806496837, 0.14149742020714667, 0.29250383016563236, 0.18360722028920728, 0.19139372262983553, 0.09274887071261484, 0.1839949833529611, 0.14202790545119395, 0.14860503075103607, 0.1398462555821865, 0.17993047322717406, 0.09217660303317732, 0.1202043817348538, 0.12143626643885529, 0.1522606797516346, 0.11522943739809337, 0.12853821559298423, 0.08175196201210061, 0.16177630382439784, 0.1133975143273992, 0.1519793875875973, 0.11320780031383039, 0.10005456861108543], [0.044242110058304765, 0.020666208095668305, 0.0543131938414468, 0.05229764715618184, 0.09041304564884595, 0.03914313608660333, 0.031724256358199546, 0.09148359223599396, 0.041575070710912834, 0.03978600642914253, 0.03078841484121738, 0.0196250869456919, 0.06114740675735859, 0.03670883042016818, 0.034080286990971334, 0.028878029045318405, 0.056502550554972504, 0.053153566550463445, 0.03860228567294056, 0.008626427734270692, 0.06520476928281208, 0.025300771906791676, 0.037389997498042164, 0.03256344822265449, 0.032218609065298116, 0.041692033184752356, 0.053265526470157414, 0.0412387389599556, 0.017642208164738073, 0.052016194113680435, 0.0664552929060113, 0.021643720965291706, 0.010256606338155127, 0.030576407669052005, 0.015757695073261857, 0.04032722839544858, 0.011859259402920163, 0.04617372032014593, 0.04341287350642585, 0.09738475985584721, 0.029087439179420475, 0.09873822271343201, 0.019929943974280072, 0.059473619555994395, 0.16463459319164678, 0.04429860521228083, 0.02399948346729, 0.025196947840853565, 0.013781452528952111, 0.02189368587888537, 0.04874017998395909, 0.04302389236287244, 0.06858379159483217, 0.0307481492599172, 0.04516666326972266, 0.058925667507273544, 0.009159804002622203, 0.04474200158109588, 0.036279342377618436, 0.07908026101968943, 0.01583196921274066, 0.03087480466121868, 0.034264316632141995, 0.0269174893882366, 0.07317963732226242, 0.016693933040744836, 0.04099230762691267, 0.04620755076288216, 0.08536798894525537, 0.07291623331125706, 0.04019670233490967, 0.037681336905206406, 0.04680939709707614, 0.016484622498072924, 0.06167831718020382, 0.019941450614902764, 0.0485948377829646, 0.020818879842878352, 0.084117871348656, 0.020198756566030845, 0.07735813367030314, 0.06095684238619382, 0.12131298757008008, 0.022544942968975634, 0.03134691017499614, 0.045751732278374896, 0.10622794259219401, 0.027979775632341063, 0.04477845204453315, 0.09809370528185561, 0.055080928854764476, 0.006725152639011222, 0.014281576750950228, 0.052726675545977014, 0.029686987249841614, 0.08033152008729597, 0.04507878915436807, 0.09305768841577154, 0.014947376105063146, 0.0370612308653372, 0.06593144198338832, 0.03233487822956616, 0.023918647784739736, 0.046691714500587796, 0.018897157860919833, 0.009126116243761875, 0.08436517219149298, 0.012623270271315932, 0.08603391853431541, 0.035578479179211205, 0.02773551807378329, 0.009477156882865295, 0.05575045522662902, 0.026957053999086062, 0.07153129190086358, 0.030715169174776926, 0.032267228835412574, 0.03420881739246749, 0.03962454190778156, 0.0356059510921759, 0.04137758473535219, 0.03312479531873138, 0.042671089721543175, 0.03320294777832685, 0.02885769898702781, 0.003030777415035353, 0.06705012953569812, 0.06902783913838287, 0.0285139438440843, 0.018347792379978686, 0.05132018408227352, 0.028797522780575582, 0.018583755121536313, 0.09481573762792735, 0.044228887380731684, 0.010265516898324414, 0.016068655907386736, 0.01043490659926207, 0.04526767579297866, 0.039366086824767055, 0.016415845039450837, 0.049477485984924345, 0.036650703498913396, 0.031995265707073194, 0.03353350705677464, 0.058903918271103216, 0.03049683028591737, 0.08981357418721722, 0.06326788450561224, 0.034320719855567144, 0.07748759486862729, 0.01233600262146924, 0.041203452950163234, 0.030285709860524347, 0.04255075646083682, 0.05058437961363985, 0.057148186474918365, 0.035671972549490394, 0.09655927713479727, 0.030009383861456188, 0.02695999386149549, 0.051034778026082826, 0.01745270099490881, 0.04533848913025953, 0.09239789519098499, 0.03514438694823654, 0.016935195195518674, 0.026421137191655657, 0.07215039053511235, 0.011001777189273027, 0.026546168486557664, 0.026924545058019222, 0.009959708005490323, 0.06394566930530053, 0.03691311159561719, 0.022992905221819397, 0.03179405845942036, 0.03511842422848267, 0.013061288702902536, 0.052083705612007654, 0.05506655321486535, 0.01262428150737598, 0.0540743544397335, 0.09600588586181404, 0.04547508260715873, 0.02095684461716202, 0.0328775481020491, 0.10425814667776709, 0.051144795912888744, 0.05000519416024608, 0.019028101439377474, 0.024276866667693662, 0.06815997643336173, 0.036454937390742764, 0.08072483728850081, 0.015596213314922587, 0.025051682248651504, 0.03575703129172325, 0.018925891903739785, 0.021428097858123725, 0.030912844757098826, 0.044463440520508636, 0.010197718117025592, 0.04041311451263967, 0.05028771972584148, 0.04292776748057335, 0.04366254539138848, 0.09876926459612385, 0.018950123264784777, 0.03751669694939929, 0.03397444811379237, 0.02323826403176833, 0.03005606542912222, 0.06705969031299315, 0.12228773486229683, 0.03443108631237861, 0.023870621732766592, 0.03020706327421771, 0.011582718899233208, 0.04867965520750131, 0.0641178897011184, 0.08026343019258592, 0.035322762860526005, 0.06104456328396356, 0.06062979945131849, 0.041695492071730476, 0.0990246323448035, 0.049197477018160206, 0.11626342626949472, 0.05917756487765621, 0.014955923731078305, 0.04151715063339761, 0.056300146294937986, 0.04957998088831383, 0.030305953733923457, 0.048773217525693684, 0.04668980311121672, 0.02068599423153266, 0.022903550641551133, 0.06356141875467955, 0.023727903382912762, 0.06525884742938703, 0.08194172199094489, 0.016604712525863322, 0.06043489902250229, 0.06136285749474361, 0.07379519663030103, 0.039959184434865756, 0.010071692823041833, 0.05482979757230609, 0.0689589218687146, 0.012819198215560568, 0.049276648374694976, 0.05963964996138408, 0.06511749654647804, 0.08997775449026978, 0.07714083283058099, 0.028878166941144777, 0.029635519547868642, 0.05079330328191, 0.014917237248512046, 0.034686078677975365, 0.03074924668086873, 0.06786254279675984, 0.04914080949440118, 0.015826673629964073, 0.06533955479220999, 0.06681035167627758, 0.040456467428274696, 0.0555226551519046, 0.015707473221775747, 0.024434129196789958, 0.06322109951607643, 0.10014075350256697, 0.042071813612335154, 0.028518220529921597, 0.04529083080049004, 0.05204780290143625, 0.007909658156530632, 0.0013526063952257017, 0.02401767614027185, 0.022536749658625455, 0.028215366821255417, 0.03569811529990646, 0.039543060796155084, 0.02635094247037365, 0.01622266256280484, 0.05699961521332303, 0.046515234655910925, 0.0639865056221043, 0.015609684013461154, 0.05839389523551349, 0.036629789298580545, 0.006772283804527815, 0.05635782122431744, 0.03240524340541132, 0.08177877508945043, 0.06843808933251327, 0.06641170250311976, 0.02241592227120794, 0.06047520290819868, 0.02508917267644598, 0.018570566917919827, 0.07842961488471878, 0.061959329722148765, 0.0419855214685442, 0.07228928993666364, 0.012754631367692304, 0.021945343187619603, 0.04675238483375119, 0.019477283687240655, 0.037593022289295355, 0.02663433180010367, 0.015873391586806507, 0.04863940494795961, 0.05409355260311596, 0.0759820788798313, 0.02007626676781764, 0.007436090851232651, 0.12383059763740148, 0.005332259235963707, 0.04999103302496576, 0.021763129174829494, 0.04831940619154804, 0.04820671082744676, 0.07165716014682286, 0.1144021773530591, 0.048754750976278904, 0.04633024740483492, 0.05604518074241858, 0.014628408694519632, 0.050311196490281054, 0.043332928401087566, 0.03764702382707789, 0.05498064794547616, 0.01314109687002436, 0.06379179671526918, 0.051706143008965644, 0.018706911416243643, 0.011128787863849392, 0.04967942676176468, 0.07090091645236939, 0.006699012282619914, 0.06277975243245883, 0.056984745446712746, 0.027719667714629925, 0.0342835760825584, 0.036030796641904506, 0.03192147037254707, 0.04457957944982956, 0.04094093760115005, 0.013227376564886543, 0.10029631531647137, 0.07755388445671528, 0.07043102876313272, 0.11471379127713943, 0.1254840222217383, 0.1302686090310735, 0.15319498526232858, 0.23013052951184013, 0.08556431429761072, 0.12327654752880336, 0.1088728151854969, 0.24009103616399152, 0.14682501013721191, 0.25283423462702387, 0.2562085148547926, 0.13020053445812196, 0.15384393834298657, 0.19854074073654993, 0.28830159275281814, 0.2641190161868449, 0.13098502381434365, 0.15313049598086267, 0.23167176051966606, 0.04202817724416814, 0.10283134622319091, 0.1409488706098449, 0.11169485327216888, 0.08638652582322398, 0.12743013835842573, 0.13738625532677098, 0.23045492178249746, 0.13213881351534398, 0.09458508387568498, 0.15987812180913266, 0.18045495234189496, 0.1168595422660151, 0.10965221005702212, 0.14054998394943055, 0.17195110059072896, 0.24605628703871082, 0.11153140841352363, 0.11522611257650199, 0.18155528442753902, 0.1692353955079471, 0.23156544283753444, 0.14159213931810471, 0.08889233047563223, 0.12153034203595693, 0.11951398329749224, 0.19315699656163493, 0.10375828962893256, 0.17679738812148574, 0.17559660658721002, 0.12116591401037671, 0.1828167554471762, 0.10670281751381774, 0.17370724990483255, 0.09968660892017427, 0.14842699191743328, 0.18715468235313895, 0.1046996737920469, 0.16038865812363165, 0.11959745623772183, 0.1665095167775308, 0.1982322064859252, 0.16899090620779222, 0.19272804861107182, 0.10079870045545603, 0.1996814762993205, 0.27435005912857674, 0.20090406069592123, 0.09960039338517575, 0.21673612566965245, 0.1724805286334407, 0.19125342128738282, 0.12300411134117073, 0.14683336049558657, 0.2639940212811193, 0.19960998497422666, 0.18527928379274186, 0.17718545762040924, 0.15522738588192772, 0.2805008871420738, 0.11761082937159847, 0.1961854953439005, 0.20114761536880849, 0.18331955427363997, 0.19249730292827855, 0.07543108546205106, 0.1606697051395332, 0.09613146299436208, 0.13084637722180736, 0.21852676426210713, 0.18707114812587539, 0.10376035806632812, 0.23072289933841075, 0.12566226789908064, 0.26677479787218955, 0.10989107627181277, 0.25781828008832475, 0.20847521572103425, 0.1378384157414398, 0.19589182319900683, 0.14298058175031217, 0.1539374163915073, 0.11589685319772652, 0.1962081868682177, 0.08196487316801664, 0.19334199147359019, 0.25490657907099495, 0.11907979530552704, 0.0775207434931109, 0.19089999428439527, 0.12548152477510516, 0.21034391867297314, 0.10446793985583129, 0.10921639795865744, 0.09002624785587673, 0.16520264738750073, 0.09167254782251774, 0.21744250470111448, 0.1421743661405579, 0.17857322589524333, 0.1341928331361663, 0.1550850620673549, 0.15267882586246537, 0.1834440129178186, 0.16550140635621163, 0.21475704476958324, 0.22436838386760605, 0.1748893542155143, 0.17857252109435298, 0.08464216660227507, 0.14178045905165135, 0.13030096858499512, 0.14428622539966338, 0.08960488417576398, 0.14753705821931362, 0.11932531882437969, 0.09720838343304011, 0.11286530538552231, 0.1324059330527821, 0.09397388360793553, 0.1636935767507361, 0.14668752799832052, 0.19686323800875297, 0.15802535348601882, 0.1991504088284508, 0.11551095172762872, 0.13709742485755874, 0.2347844063995346, 0.09683456316950823, 0.17145577878240617, 0.18093505964404155, 0.10527737303486756, 0.08398220483814517, 0.24552163427635548, 0.11892054860870685, 0.11201395187526943, 0.15349688519152904, 0.2609305888895066, 0.18782758334230995, 0.09139548446382247, 0.1170956275816406, 0.17969988076196564, 0.1251544435358336, 0.1358519803972975, 0.10766851730764875, 0.08943053788595623, 0.11759660311884458, 0.1223389708226727, 0.11189932980003858, 0.0682029233223969, 0.1853630478463827, 0.1725730720546938, 0.0832913390871498], [0.0555699764029874, 0.04427356945891534, 0.024698735965836435, 0.04749290457355881, 0.03247309198242522, 0.023378816268016255, 0.04247916171387319, 0.023762293069833712, 0.025244575527106083, 0.017288151054432797, 0.022306337224079237, 0.05104032833309424, 0.05259658998599457, 0.05105406812001621, 0.013099134403971896, 0.03798467324926488, 0.037652440068702546, 0.0565512660860775, 0.04824828641909746, 0.03619208113260327, 0.05815216768232565, 0.04218642419624714, 0.06675143951490041, 0.04961139815408857, 0.026050168690421892, 0.009756521378163128, 0.02942470555764533, 0.01689988237264897, 0.17387891488690532, 0.05472387825589507, 0.0789820179042797, 0.10306468894404751, 0.011191439491906955, 0.04424599412408087, 0.07167297986245925, 0.012422776443042583, 0.0478766035408743, 0.07811542690521286, 0.06847974919383565, 0.030724678241137057, 0.06597424331571787, 0.038669873780060204, 0.07554615186827798, 0.030446843048858068, 0.06495919979868398, 0.036146349513963345, 0.020971162800466823, 0.0426948078036789, 0.11049463864295714, 0.0411775668392018, 0.07386895557565075, 0.026442288879245043, 0.034172409063866066, 0.011820825729368916, 0.010046845718827701, 0.029098639384873455, 0.0050054059078496315, 0.013095011893329362, 0.047287420640068675, 0.014621677654494923, 0.09648326589095016, 0.04644293127761734, 0.007360967790572754, 0.03635440367243944, 0.06606372238527383, 0.052354525354120045, 0.03840975628625001, 0.02407684302588384, 0.03229251356735345, 0.012257392424339009, 0.003269713295946619, 0.03912244405176851, 0.030175310844976096, 0.01650323268897351, 0.006724278341167637, 0.038491436580736796, 0.050883261156418634, 0.011073877554266684, 0.012225645740756826, 0.022024612220364715, 0.07785871084178649, 0.018002428452394182, 0.027978856326831926, 0.005920094779632505, 0.05565451037499213, 0.014887422064108955, 0.07767927006728227, 0.04036512676506274, 0.018360856094307477, 0.06262558489857663, 0.04768805398095039, 0.01748834898124539, 0.04335292712635091, 0.04523268855747677, 0.031613447485611804, 0.10078373109741558, 0.012723452546783994, 0.04327913370704459, 0.04318604636336527, 0.03438049003541951, 0.04152672290201149, 0.04357121621949538, 0.09494369729391991, 0.0741582763411345, 0.07742103714976581, 0.0358009242993449, 0.010010193199700406, 0.03304632493264733, 0.02288331825947089, 0.053450222607822194, 0.06238059764127098, 0.003553561081418828, 0.048333394957045396, 0.03126944719453252, 0.04360745600875347, 0.03773009840158686, 0.06373049819000787, 0.0944065624066899, 0.01021992126029105, 0.021718931647257942, 0.024178100697275613, 0.009665684417761382, 0.08054886689229358, 0.05043069854558957, 0.020871397085307587, 0.03705477274413552, 0.053901486699619604, 0.016617232317765875, 0.022546582397133596, 0.02619353629979155, 0.026439760789094914, 0.02587786402493235, 0.04696581692945573, 0.0386130683604748, 0.05259924831109182, 0.050002570309105425, 0.08786548920456441, 0.01783577560056602, 0.019703088102922327, 0.0581679261109281, 0.02095468041877593, 0.03373828235893481, 0.007279725123812715, 0.03586395418331508, 0.12203258161823596, 0.003528077884825067, 0.03518333102786734, 0.029035412233262777, 0.02086323633369419, 0.017865497896808292, 0.035901212869512464, 0.016140903744305816, 0.013576573804922163, 0.05362307885661722, 0.04204295891066713, 0.06804279562446379, 0.05646821832464588, 0.051697520689377864, 0.021626305871553, 0.025049102447566488, 0.0868782010530272, 0.025479121006003795, 0.028446386380481626, 0.051563834516151305, 0.01221855176657799, 0.038959788263685284, 0.034221381234425696, 0.08541321877630488, 0.02999681618905837, 0.015325764167843568, 0.022536969908903685, 0.013513228867293127, 0.020368590597964583, 0.055783860490567265, 0.034638902983598174, 0.009402029512960826, 0.10205189006463175, 0.03351216001676456, 0.06590837507598823, 0.046500732611504295, 0.01879881132364033, 0.1506958685574993, 0.028165299144964066, 0.031789912008530194, 0.02276893750193619, 0.017274242728167487, 0.012501907579961323, 0.043898906498666734, 0.037225108563659653, 0.08129030210717071, 0.03029634316091336, 0.032543372888598716, 0.013939641066826882, 0.019862549304361307, 0.01861078653394455, 0.006136666399411738, 0.03525266581545434, 0.014470169403319879, 0.05225776844928342, 0.019233506848855365, 0.031296061089022026, 0.031881754459332556, 0.10623417854789766, 0.06852988964847981, 0.03347662119795719, 0.05897914044438832, 0.019012092116979823, 0.04903533450898625, 0.055494980225639964, 0.03955408480138548, 0.04266217245810455, 0.038950993574314544, 0.05638091494479487, 0.0800825185292671, 0.029146115768760927, 0.05575814291894917, 0.04567560612133915, 0.01436906973756249, 0.0973832353408779, 0.023850875816518263, 0.07425673396116303, 0.048279523654209996, 0.03914926478999757, 0.009283678504758546, 0.042867801948300296, 0.06518671259043679, 0.15412475553251084, 0.029415614009203932, 0.06381619278521788, 0.03842151956632733, 0.05838613476484053, 0.023890681745063876, 0.03003501141774318, 0.0683527241551107, 0.039541938477346016, 0.015630894115254763, 0.022504845927018794, 0.04327719933503578, 0.003240648159501894, 0.01933105473947381, 0.03289842016754612, 0.019146542462910858, 0.018250941629371336, 0.005729145928090739, 0.028158132392432422, 0.06548855123260329, 0.009703714937542476, 0.06122657811389335, 0.07705321535468102, 0.050307787399018006, 0.0587909471153492, 0.014359925520576298, 0.07492765078261014, 0.023488263419318586, 0.09538039805427675, 0.054974879303406325, 0.044764708427171555, 0.027702214316495007, 0.03042791493146891, 0.04138213529762241, 0.03668067668895087, 0.023359210162814108, 0.05860313683027222, 0.018314113239607504, 0.04884324179241254, 0.02883603402052916, 0.02267906198187942, 0.0434477994548938, 0.018679435672839324, 0.009089934868708013, 0.033057448529307885, 0.041620415455150994, 0.028919962783073707, 0.02626977353957632, 0.007102277135521535, 0.0304996456590391, 0.04781318678250236, 0.05205279779470256, 0.027810818771080627, 0.04817132522622424, 0.04974879602330828, 0.06150014428121429, 0.04655157020615955, 0.042379340457339446, 0.024911407719276128, 0.05741347123177783, 0.04225108967793565, 0.039473591943181334, 0.09330581663356674, 0.03382895269521302, 0.04497673475153504, 0.04305573480744516, 0.04957051587200934, 0.06944361803752762, 0.0682848564258987, 0.07077759927919797, 0.055776000428464145, 0.01505380486994381, 0.08086100175616243, 0.07822967359736081, 0.010096896158140755, 0.04941408837875051, 0.025573801812565616, 0.03128374814085903, 0.05859126246744587, 0.0311489588010215, 0.057042320784662044, 0.050162395402308435, 0.014799528796556256, 0.07542424429688724, 0.008360598097375084, 0.04104221825517955, 0.035673608147208734, 0.03949345277261831, 0.024842760495601163, 0.03986761011483689, 0.003809000890243859, 0.011150387712874481, 0.0982858477941444, 0.06021395543470018, 0.0505933007075181, 0.05834103899917776, 0.07903124671429396, 0.032347089671079195, 0.029984411310344457, 0.04694393362789866, 0.05066827007178819, 0.05097263680410482, 0.03563476365900809, 0.023677975517667593, 0.041441599042305065, 0.09685178482604605, 0.009418642129598847, 0.03727851255286125, 0.03537637752390677, 0.04690885829228548, 0.07087824024981068, 0.06453928402474811, 0.02707119535414442, 0.03647748718879396, 0.025005054307140173, 0.011295027028198444, 0.060132903332311305, 0.03373908292081568, 0.029692882296418952, 0.037069393532170404, 0.007741637837757627, 0.03037547812827172, 0.022781560715708523, 0.03643997186314195, 0.03518469849481218, 0.06574028006364262, 0.1969313432252215, 0.17642761280219402, 0.14255247649646577, 0.09671729809093861, 0.15374641535022568, 0.16864987450741953, 0.1196833576766714, 0.18442986082405816, 0.07094293637501617, 0.1514318185828386, 0.08901115837356738, 0.11805430234920596, 0.09333744074308103, 0.279762776748788, 0.09868693312690144, 0.06830263732662124, 0.1491215731948614, 0.08494190616352905, 0.1483171961961254, 0.11132179909656126, 0.1245972294841082, 0.0608203370094059, 0.11380607667829722, 0.15751003678287231, 0.061089712675781026, 0.08725017504466158, 0.20372870348153577, 0.23175151027258367, 0.22054376651442822, 0.18039482976159743, 0.22191052865837851, 0.2547622481060605, 0.10130439509427357, 0.10143112901958729, 0.12210847794889443, 0.0928774202663091, 0.19077121490432372, 0.2639966259800619, 0.15876655887451865, 0.25612544028028367, 0.11481197310551522, 0.13318115274512, 0.20787841790626127, 0.15465136437166124, 0.1849587372834644, 0.13151863469712197, 0.14499170044737478, 0.08278938295740275, 0.18170476350332462, 0.229956581587753, 0.2015124877253848, 0.06410238791197058, 0.21816529333591464, 0.106633348660844, 0.17192057964782562, 0.12503549306383058, 0.13145814439462078, 0.14439323256092687, 0.09929327639721094, 0.10181577410548927, 0.21221642142101643, 0.13766941674534353, 0.10792269762004576, 0.08068424228939318, 0.23475134204472267, 0.1465822521957659, 0.16658238706088838, 0.11877498424221432, 0.10931899245347708, 0.19217117929891234, 0.08616402324649595, 0.09618062285646316, 0.15463492412480617, 0.15205792692159453, 0.2464039530605078, 0.25367308558235246, 0.282370264251386, 0.11395321918591378, 0.11165135479982823, 0.14552685882776015, 0.12627955090494888, 0.22196130496599983, 0.13144584102255683, 0.0967727245522603, 0.18834807879982457, 0.15840537906173738, 0.16048244260732206, 0.06893757865914414, 0.18685891112733274, 0.1341955910526937, 0.24308883014225194, 0.1587550981991714, 0.11400919723054094, 0.1310269135020433, 0.0780442726588057, 0.15194548053606866, 0.07602817439023526, 0.13681152084421727, 0.21289453180807255, 0.12963292459326406, 0.16704533399353105, 0.14645028588992937, 0.17029386854940848, 0.13433963090421694, 0.21425256054968606, 0.1390217151492834, 0.18050019749470297, 0.10967269524811737, 0.0882076470541858, 0.12302113381484825, 0.09877265070474918, 0.1318233231863668, 0.14360198630921303, 0.12416860329047327, 0.10107826126078445, 0.11714514750506609, 0.23868023928615356, 0.1948633348389018, 0.21299608442331516, 0.16335300470311798, 0.12709088398203736, 0.14237371754021416, 0.29088435093722037, 0.14086265507484638, 0.09706071998563506, 0.1155784210911201, 0.12045248697001128, 0.16017977659019733, 0.12362137136440124, 0.07646677504864431, 0.11336737642845801, 0.18772506545628273, 0.16471437358808133, 0.17777054961169922, 0.1504686622009162, 0.1716575203763862, 0.1885048969979248, 0.1178598922166613, 0.11332181717960105, 0.23508622971994264, 0.14289844180307082, 0.1291887927800417, 0.16415059416284486, 0.11450877082684349, 0.22906752122986704, 0.1500834578708295, 0.14065855393005958, 0.194290331715057, 0.12869152510839124, 0.10603217648402338, 0.19548169036786403, 0.1434296624915254, 0.13165124451681492, 0.13667644422140815, 0.2345837373286486, 0.2180373566525598, 0.12526013302586733, 0.15656823893227886, 0.10835140808335236, 0.18504217958017705, 0.2567247661852068, 0.13483988631877208, 0.20737944951941892, 0.13830128606529007, 0.15097201261068546, 0.09322921550201793, 0.1658050223223625, 0.14670471901134138, 0.11710076803161253, 0.15111619035803503, 0.12300417262820468, 0.12232963987175496, 0.172040518373251, 0.2181182708591223, 0.18681340550463046, 0.17065599831121583], [0.06474048935718114, 0.10678840485671837, 0.09834568692190994, 0.02614051918499172, 0.05769784306927074, 0.020883823031439416, 0.02074783284878058, 0.0798521099251605, 0.03716951739343424, 0.040896661549566254, 0.058858822505440445, 0.04980962340449614, 0.012285154493105029, 0.02318478917943374, 0.03506963591902487, 0.025187488570208513, 0.041033036691407045, 0.017295727664003932, 0.031025103451083266, 0.05253860479100578, 0.021646708708196398, 0.017057234917076367, 0.07143878678400671, 0.07347564603532515, 0.0493132175817605, 0.044239294685183034, 0.04356994451354108, 0.03349554740012654, 0.028471473844782002, 0.04164103088119338, 0.030280527275716587, 0.033670341851369995, 0.0636128117630799, 0.03956763306632638, 0.015231664630494293, 0.031135435433938142, 0.08275176804032057, 0.032831123173837705, 0.024674531417868795, 0.06603936078928171, 0.07831821037876992, 0.09213387064876095, 0.02842156704695475, 0.027843750975725633, 0.04979825849013944, 0.01421089364861649, 0.052687275644031265, 0.09659822504486769, 0.019589973305682504, 0.034647130767904946, 0.037428516398874984, 0.07838743408360789, 0.041287630691283175, 0.033342613267802426, 0.05187654011552373, 0.06749518065442962, 0.05442145738690611, 0.019599840518147237, 0.039178682566289945, 0.0854984307361226, 0.0437472210896592, 0.08447417884223885, 0.09135433022053012, 0.0637390936965183, 0.017523403249440656, 0.029786517392964135, 0.04039829837218408, 0.048422054312522375, 0.0197992455439582, 0.029926891513769666, 0.07475024014110528, 0.04101216845634965, 0.0271448029971291, 0.03664425303859096, 0.019826334412960757, 0.08025619066170148, 0.028544539480560252, 0.09613701713181312, 0.02690181714452563, 0.010783103136946599, 0.044475671114219774, 0.012494097313573285, 0.0160673248296183, 0.005496984897857352, 0.034800091713306405, 0.06690733074661225, 0.03714337847345779, 0.06529974120278513, 0.04514686755775925, 0.049681656077624335, 0.03292747788251408, 0.0756104419668836, 0.04490442754280183, 0.0878154100369542, 0.010588476584563333, 0.06649034908942639, 0.015241800931342428, 0.08586903343037253, 0.06525297919588705, 0.02173613415159766, 0.021043332113373666, 0.05910722268444877, 0.026037085823894992, 0.007556319732459323, 0.07803416795908444, 0.04156109343673434, 0.06578778517582724, 0.029428103157589515, 0.02426863888338689, 0.027323854982011744, 0.038292249889984246, 0.02759589854958317, 0.09194994059902045, 0.02522784991249923, 0.04937995150084457, 0.049168541877260136, 0.027899539413591547, 0.030714424154270562, 0.036939150924163486, 0.018419402448700804, 0.04417069917244296, 0.04481342012783693, 0.03027122122265639, 0.05500848375020489, 0.02461902068687543, 0.10168635887244057, 0.05656813917260978, 0.04651783552441386, 0.050998538236824736, 0.021137940141582684, 0.08782966693322505, 0.1094174117691094, 0.05883146933610401, 0.05010233027860523, 0.013813245177809751, 0.052102237278896, 0.015710615139875202, 0.07002159307200102, 0.01746208748720106, 0.009740173061858984, 0.042527183935406714, 0.024767205074069, 0.06384565652678571, 0.04442812769763893, 0.08472075190154776, 0.07392365425344437, 0.015896725667370184, 0.04568027542723764, 0.07363137638857288, 0.024014544755881353, 0.04231353350464375, 0.03557150011822101, 0.04163604364880631, 0.04538929225095818, 0.043433826011154926, 0.015585738020167958, 0.050896939656306664, 0.03615257014790851, 0.008747212986852373, 0.04722144897846926, 0.054512579715059656, 0.024910616733494307, 0.07590554669619569, 0.03232309579729073, 0.02128192445173139, 0.062500478910102, 0.05244369798850629, 0.10836095353888889, 0.04809600346150899, 0.027164173530294534, 0.019230829371560006, 0.04072013957005355, 0.037671825923626466, 0.052967813211463155, 0.05908829648227942, 0.014097834392751177, 0.07961554963502192, 0.05641296040266753, 0.06385466572077525, 0.0507060726804118, 0.008830765408704118, 0.02354377415031195, 0.055501315772773764, 0.03758536907093179, 0.06600720807909966, 0.011778552040097215, 0.022048705685583335, 0.04616113732598963, 0.020225523678105206, 0.02132795101422216, 0.012898366699265617, 0.05779343935090208, 0.025334960495632504, 0.009648404347019331, 0.03565196999378743, 0.05284363035893729, 0.05909460904677549, 0.023427547120879737, 0.03840770700105256, 0.014379567057344944, 0.011572967557567022, 0.027419296130838416, 0.04685152810247195, 0.06904626355296181, 0.01575632090304768, 0.05081613270205356, 0.02622209988804835, 0.058359298704852985, 0.037322485999714945, 0.017481708914161693, 0.056731863653347384, 0.006958042889187534, 0.020798084386173758, 0.025139422298619346, 0.04300211631362477, 0.05841104794413813, 0.012390452320687475, 0.058653702463714354, 0.03797153867180309, 0.05646038124518049, 0.03652180920565321, 0.023499161020041476, 0.034598809772080956, 0.050861523411567175, 0.014747467376441966, 0.021387056612800208, 0.05010360964543877, 0.02087292926115615, 0.014100261933861241, 0.04914935137475691, 0.05581612811393796, 0.02643289472607355, 0.041154794875652566, 0.034680394305577206, 0.07559397873739082, 0.01875645432230686, 0.02708586019223496, 0.034883901732222694, 0.016517344028538754, 0.09180688134004032, 0.031730028830709, 0.013071340734079001, 0.05714990634230837, 0.0063665301234821885, 0.04609244988269864, 0.029577854194588242, 0.027886860658444708, 0.04613651909054287, 0.05046572025504805, 0.02233401023512406, 0.014253189362916014, 0.05201371964968501, 0.024795471803255142, 0.1690423719945454, 0.01612564135763434, 0.07004064567867788, 0.039243635330950065, 0.041447367684374896, 0.033851188397215265, 0.0335301362699078, 0.066753477308779, 0.050144151018391696, 0.02628416067079431, 0.02993176000252847, 0.04060952030422707, 0.016574710607528687, 0.010735591321492629, 0.05294065539454741, 0.03126544821556778, 0.031337408769515254, 0.013456405253119528, 0.05002784738016706, 0.041144759123844486, 0.03314140027449016, 0.01854372319705304, 0.07509786019762678, 0.044619561578597755, 0.04291720312809752, 0.02514037033242564, 0.06898359756075567, 0.039512857779740326, 0.04874040981033637, 0.05274831752983793, 0.026097673802606525, 0.006277747715132372, 0.08024112171223087, 0.027148338492899656, 0.04355337786217851, 0.01595958030872768, 0.017848410305657217, 0.038247828281694846, 0.05682096733982044, 0.03960326764612429, 0.012811849517146907, 0.017954406230860663, 0.0046993442060005285, 0.022990394368647568, 0.03496142216928063, 0.014377333911045665, 0.06252908463319463, 0.03253512595209383, 0.03750725108529291, 0.06477236627571045, 0.031415178185148586, 0.09864178756552358, 0.005400174366866029, 0.012133996727155342, 0.061214738225023595, 0.031006196401112025, 0.008234144751763633, 0.008967419215027363, 0.03858915492591839, 0.020125939908827988, 0.026216001828171076, 0.010393055215958628, 0.03798879480229751, 0.05962192651725585, 0.04900404364771901, 0.1026234146387827, 0.08450322123544832, 0.10368389483060568, 0.008443552013035984, 0.002634240968731202, 0.09970296489735765, 0.04569413778822749, 0.03614231223060239, 0.01823628445216004, 0.05364044990030028, 0.037170647373122555, 0.046586362089240746, 0.05558845061328142, 0.03762917014800253, 0.08160741654254737, 0.026812184857384815, 0.10130677762771807, 0.07365405259113159, 0.031345732314812566, 0.010230570840048454, 0.012989555102502628, 0.06360816927025877, 0.04037358820618641, 0.059430810562785596, 0.022098175813293746, 0.06045087195572354, 0.04898756892690736, 0.0763749594109193, 0.020904319713853543, 0.0249582578262855, 0.049681832277846914, 0.014950230740190995, 0.03829640974741309, 0.04538561502892164, 0.14743889171269633, 0.13937632192767438, 0.13255547341560164, 0.19059283899203425, 0.2424967820726095, 0.11362187849778323, 0.11067378064317089, 0.1817739872081626, 0.17419725506296083, 0.12290643513082497, 0.20146525074397365, 0.1879303616982314, 0.09952891738184037, 0.05363604106429604, 0.07371144023753944, 0.16866845980046258, 0.1956127833334669, 0.08999621720924493, 0.15086964794224308, 0.1169086714845992, 0.15401472998482568, 0.11507137047667658, 0.1182353595692304, 0.14364591379079128, 0.1145258852310719, 0.15897292763956133, 0.13959032092844287, 0.23469272099675673, 0.10107397882928772, 0.1521662517540878, 0.15627265156757447, 0.1396433188910446, 0.36247683028059624, 0.18526846663125102, 0.09184262700258725, 0.16251991472897992, 0.10851319053120191, 0.13872062727328272, 0.1618899759506026, 0.15512523571810416, 0.24708348837110305, 0.15922227393715613, 0.1391984669551734, 0.24780387148982097, 0.12963966616699774, 0.10329589427959535, 0.09864846019134407, 0.21217684531884812, 0.11882930753692506, 0.14803699187694058, 0.08608198289068476, 0.16036939867321523, 0.0983322037744426, 0.1701603087806894, 0.1919325275887405, 0.1455708935616478, 0.2120329893284267, 0.07931751078895985, 0.18003155086790362, 0.176261555583727, 0.15607061886018322, 0.1391991104690298, 0.17247366448563917, 0.13505448286812152, 0.1685638887987983, 0.13774473851005878, 0.2020290914562441, 0.15428083828620373, 0.21058774913751313, 0.08319358626801161, 0.1508946530520916, 0.12843850924963915, 0.10033170091769389, 0.13096127508869096, 0.10637644873631578, 0.22753068756672645, 0.10658229656156995, 0.2338488598264033, 0.11864062774205401, 0.2681214272254898, 0.10776423233290834, 0.09552796191025166, 0.11605240735075167, 0.1776878427593939, 0.1738537105941965, 0.15100660914134595, 0.12176549272431482, 0.10078409881961924, 0.09510895778094569, 0.12825271760624263, 0.10826528447890475, 0.24179703736257172, 0.10207874910725702, 0.20934383685310043, 0.10163475518986102, 0.16601099272168454, 0.11333346937692935, 0.24370122550716325, 0.1778916221472525, 0.10493995726949747, 0.08467603534940751, 0.14380893730107816, 0.13692258827147946, 0.12303078652269418, 0.16347931728007334, 0.20614946471346965, 0.1395444935488124, 0.11562358963513568, 0.0997091472269066, 0.24294710387626003, 0.13332664816369935, 0.1420739320136847, 0.20998486858462134, 0.14583861064766684, 0.14761953524524166, 0.1053536753921259, 0.12311847294650732, 0.12863379272241748, 0.1400461125998728, 0.10998289190953779, 0.14287587285282152, 0.13023240371577202, 0.12389169314936285, 0.10898456443101169, 0.1486834628327239, 0.24882293696845734, 0.2091191892301844, 0.0982959065285902, 0.19982602176887376, 0.10918352512582656, 0.13198328234495657, 0.1945579875140421, 0.22882356819125915, 0.1627829280351439, 0.07656427505876749, 0.1766296148660683, 0.11476762427557861, 0.15333688006766383, 0.0870520034204087, 0.13890018296097556, 0.16148070113793497, 0.09708631498318526, 0.2501705622360591, 0.1108491228472802, 0.22062339369327794, 0.1472120530783169, 0.10816859652198131, 0.20258979120802498, 0.12509366978080044, 0.15812454655045466, 0.14050688384281051, 0.09995667789612087, 0.13247042233424802, 0.17527814383708662, 0.21033026698616245, 0.12847348116338253, 0.14974205844825314, 0.11666209842529028, 0.13381672993062005, 0.18728454957806295, 0.12701000807987106, 0.13045646911186556, 0.1620516664679012, 0.14169824249561758, 0.21245844391805513, 0.158169960242606, 0.15922706964756214, 0.14029627095066732, 0.1312925468289083, 0.16368343374661862, 0.17163495142613688, 0.114541758572863, 0.09592402936710466, 0.16421583421047659, 0.14200987174145638, 0.11421170491244524], [0.04043539234947774, 0.03547256752367943, 0.049118523996683865, 0.05217993391617652, 0.03084106614903337, 0.04033264463707324, 0.035147627500156244, 0.03988895332440734, 0.03634825964728671, 0.03818268399505365, 0.047061156571632436, 0.018457729827552553, 0.024745384974765684, 0.04562141306157555, 0.013001302103211564, 0.014504049641771183, 0.012449593350832022, 0.020913367212239294, 0.025598272576086947, 0.021677568645006227, 0.013829131926139517, 0.03574613369100037, 0.043609152893505754, 0.06010181165390438, 0.01962386120501305, 0.011209896465222682, 0.03312304097738478, 0.037479541685071685, 0.035375316492131645, 0.044161360560645985, 0.05396601045504213, 0.043017342311119845, 0.019271790177651474, 0.009281748920799264, 0.09324497393062038, 0.03408288402903465, 0.03778444084849569, 0.05154253727185631, 0.04980828658106828, 0.0354313979586286, 0.02632757295824347, 0.04820482625115303, 0.038341838761322924, 0.0016757064910169932, 0.024469267734656894, 0.04125812481487951, 0.045150644371225956, 0.04057075625525848, 0.034676659626946334, 0.04750435375758717, 0.018228162004942858, 0.027932385433345076, 0.026508756582775427, 0.04131351680224461, 0.04266153277468778, 0.03713950589900056, 0.022036113115327976, 0.142971204834119, 0.047383683418194135, 0.042303650970420534, 0.05143962485054809, 0.03850775808396359, 0.04331464188233499, 0.03569647204130888, 0.01202199179979582, 0.014478017974104133, 0.008484961938173061, 0.05966883025041992, 0.007575858804968096, 0.022592779414187518, 0.019320988344148766, 0.026394444773153915, 0.04121016388037994, 0.03617586688168588, 0.06934793365578498, 0.16154503720181604, 0.031013709808429404, 0.019822030914046114, 0.03281983486827343, 0.03874396597365699, 0.05658191343348834, 0.022893928577222174, 0.043911857215026696, 0.09240968528413966, 0.05797528564148854, 0.04985463873092687, 0.0597204071199221, 0.07125058962452797, 0.0392762515243263, 0.024265042100582394, 0.12845782232621025, 0.04791906013363793, 0.06318110589598937, 0.0357190256697997, 0.08205892578248056, 0.0278589578210226, 0.024262717023732203, 0.01069801087836705, 0.07646441549783753, 0.04087899173159273, 0.029082926921546463, 0.04857851244929818, 0.021107629872858528, 0.04918742211415403, 0.07077972134274822, 0.08721174041350042, 0.07579151450866654, 0.05082520318307704, 0.01317977856454109, 0.05007107006085496, 0.04592068530919571, 0.07148639914850075, 0.019351066871275826, 0.037043361864503355, 0.040284603263341615, 0.05972938950083429, 0.09586690219059106, 0.016967583477737445, 0.08238020007528606, 0.08928220794205705, 0.052003101671054486, 0.034708911928558545, 0.07370097547649376, 0.08446408180339683, 0.06354043177599389, 0.022897739864645467, 0.02678835186206045, 0.020275798198136113, 0.024523370779089393, 0.021977151158235727, 0.01253530326780052, 0.04674473544582725, 0.0443205957661473, 0.039133242061061245, 0.0063238154548490725, 0.006768763630515746, 0.0353998811014237, 0.058678060229266846, 0.03318441228099889, 0.061470695861404946, 0.026433789133725148, 0.019418176173442797, 0.04056030298553167, 0.11093310140553983, 0.06095802216159721, 0.04274733079176757, 0.02611591627130345, 0.041001435564530474, 0.04903704288505739, 0.05203670611785305, 0.03245148064208127, 0.05168573059622319, 0.07301708878648859, 0.06485863543686367, 0.022877388738936955, 0.034360874354118304, 0.046818582491288264, 0.00706487815947302, 0.017200631254743186, 0.04127259621576917, 0.06300644551013267, 0.0644529612374402, 0.014415707255172876, 0.020097686586180524, 0.018868075248094338, 0.06630023671013695, 0.028954674226922855, 0.03719595508770116, 0.021203442574328473, 0.029624733029894774, 0.03598580429811151, 0.05339966846569892, 0.04333009770620735, 0.0227234625227509, 0.06635727961697886, 0.006287855287683347, 0.02701085443878847, 0.05535384767778939, 0.04525675520961804, 0.037984033565848105, 0.04052999271680752, 0.05470931109401488, 0.05084090798552479, 0.02255757958928664, 0.026482341871146235, 0.013927859592161352, 0.15348396894912567, 0.07686437468134588, 0.019335883008616588, 0.01725306231228094, 0.019720208252810185, 0.07357901427894831, 0.026632732591561736, 0.040227227108252626, 0.1126363063831964, 0.03406391569202946, 0.029756253089515433, 0.03574015054431173, 0.033808230016861236, 0.010307850917020153, 0.010222595864756694, 0.07695029144205394, 0.028653076902452498, 0.09029039497216863, 0.011709512196361058, 0.06504336221804542, 0.01001610165281642, 0.02185413275935477, 0.05192100768908859, 0.03762428633748524, 0.07503032188622222, 0.011345350386334524, 0.010992997821660773, 0.05611314806306074, 0.03168401375953709, 0.04548196207671877, 0.035541193679936474, 0.017116120265376185, 0.024823179288256555, 0.023782264982019703, 0.012078802007430745, 0.012769074997894708, 0.014881292403104806, 0.031152005915740327, 0.044605817961236166, 0.05932245508677537, 0.011043367145072308, 0.0783699672789343, 0.041093557637425206, 0.04818305020190535, 0.06926315070520486, 0.06362226145762591, 0.023200790840952147, 0.041123354627240094, 0.05166715679449901, 0.03143211447393462, 0.012452684515606494, 0.0718048542377449, 0.07563170856766163, 0.04631916211257058, 0.01632771811508123, 0.06642196042042586, 0.016333879377212257, 0.052301454613165516, 0.04384747518587016, 0.017288135732674313, 0.022955568011609778, 0.05850429233584193, 0.08033837657421827, 0.009896410948356554, 0.03634981097533338, 0.04976300312386406, 0.028472105867319533, 0.02366837835119617, 0.051391732863961696, 0.018664297775455543, 0.1033018621045255, 0.017322117477775584, 0.02106533224333919, 0.058044448059292576, 0.07342091671401456, 0.03481165964096304, 0.06775679201969216, 0.05430988051117428, 0.022285662426222718, 0.05722372657469204, 0.018670675457425175, 0.044743893818268855, 0.033510149035963326, 0.05765150624117064, 0.10138712492921662, 0.05386587893289905, 0.005787703294997976, 0.004792538323184295, 0.010533132477693502, 0.01580906414141458, 0.06404225767079381, 0.016844513367921594, 0.06416636008408762, 0.0773959784137626, 0.06947989996162153, 0.08836131663091722, 0.012851262825631328, 0.06864266545181313, 0.04203352453787962, 0.029648108287684383, 0.10099412948493997, 0.07502050063903294, 0.04698827479695601, 0.028297167774590275, 0.007339817060593276, 0.028836899699883598, 0.06228845641617814, 0.040758191157252564, 0.04459195943068593, 0.050618673539570266, 0.02155736944968662, 0.025425230550970283, 0.09588766317333906, 0.047362412986976486, 0.11199595646992808, 0.022887955006632595, 0.032063169825461604, 0.03755188336776149, 0.04692567392222343, 0.02776120117144479, 0.026526803699051662, 0.018348206067457795, 0.042646877512696295, 0.06417516626477723, 0.05369632069261805, 0.030881597945887237, 0.06932584734092798, 0.07026686378183865, 0.02902911307530538, 0.013312668006326403, 0.028521189120628183, 0.036581533420230114, 0.03180356369534087, 0.056593826100710905, 0.061902252341350245, 0.04715906260835548, 0.030381740897052714, 0.028177585280049714, 0.04545520645596328, 0.02572860519942497, 0.01969351391908863, 0.055018059849258394, 0.04295911196799528, 0.03668474078538918, 0.03539784713798473, 0.025671707849288662, 0.04560367046524921, 0.026046631279431527, 0.050597399277913, 0.009925624753739084, 0.04932514940118117, 0.09386953477176929, 0.04761114258379225, 0.038547433777562076, 0.021807271161026532, 0.0427015187338956, 0.024186814947414304, 0.05189386136349171, 0.03431714222496075, 0.006662857720643403, 0.020591608368821686, 0.05119252702101104, 0.08217239106494574, 0.007473940382741633, 0.021397846961213697, 0.04170054059115149, 0.11273487125553432, 0.17514364944109995, 0.1342002795107903, 0.18097062144548665, 0.11528577550404495, 0.12874925749436503, 0.1766477251845983, 0.15121809537372283, 0.10826729162926636, 0.18837210331713, 0.17960146910721259, 0.10280286307416617, 0.08575438071162471, 0.12059494868041047, 0.0903597948772292, 0.2405277062808314, 0.0941973437945689, 0.10529031225990866, 0.19922805950045588, 0.17528937468605657, 0.12080552326815745, 0.10304543715451034, 0.23806571419681274, 0.14947247210769884, 0.09130204471969798, 0.17145441514590096, 0.16474984345897553, 0.19800077132400007, 0.15105717094434848, 0.13444631630855222, 0.09246338038675248, 0.05778423863493147, 0.13093510552519752, 0.22014586044655693, 0.25334979647830613, 0.11691608721570623, 0.08308026654225203, 0.14081383995231123, 0.1322933947367053, 0.10035633064445951, 0.15134912705229175, 0.10571083324330469, 0.08935911550877557, 0.19101032626725015, 0.16674849024463087, 0.10984108903475347, 0.06199447400567513, 0.0905835614990323, 0.1778852482957225, 0.14977164476388885, 0.16553358204903143, 0.162493729843728, 0.11835048726249127, 0.15884670699315687, 0.14730641978882975, 0.17789946688759714, 0.14176375833490204, 0.23521756783368128, 0.19056849271780063, 0.1328698146126924, 0.18906518306222656, 0.22751611657440665, 0.16442290777640958, 0.1884479153781168, 0.14029178167543105, 0.14294397806929005, 0.08636259323646946, 0.18695824208759493, 0.12858772019465126, 0.07610701249852296, 0.10680405603301142, 0.12370995411108579, 0.23478806829981266, 0.13301684220712032, 0.17775156595293554, 0.24676049038046793, 0.17386011508924348, 0.07913865224127808, 0.14006054569636622, 0.1717788687035922, 0.25377263104723347, 0.18497592829648526, 0.09277316336069377, 0.17151838348757836, 0.19190044382647162, 0.0959020043392816, 0.16392586993113642, 0.17838176520120713, 0.11967919015836333, 0.1353965104827958, 0.2253183635372308, 0.15387024580230638, 0.14960762533930042, 0.2160767997584997, 0.27402643294584367, 0.14780249236331833, 0.20513367809114919, 0.1573064718996325, 0.12712163475131796, 0.12611527867134542, 0.10357253628993228, 0.08984475396573545, 0.2304432619242899, 0.20041243143139348, 0.31262145227482246, 0.20532922969470102, 0.13117032516146862, 0.16694439424862786, 0.07924660169068845, 0.12005699407910148, 0.17012607997223256, 0.24555563325843505, 0.1311598144351475, 0.15957134956073377, 0.18584813472003708, 0.21278007827218504, 0.15178233445171388, 0.11884633001060256, 0.1346258566744866, 0.24800541390094066, 0.11947387093377691, 0.1447824665134953, 0.15936393891611408, 0.20788837704927693, 0.23045116795166848, 0.1786242473510004, 0.19663733400164113, 0.14253586771026736, 0.09652780624286783, 0.16892457831530802, 0.12920287347608997, 0.12107981338856683, 0.15924547107950335, 0.16878815337775216, 0.10145181339354285, 0.2136553030821585, 0.21814096238343947, 0.20007245693235629, 0.15936406149018198, 0.15376264109246193, 0.11711147027991473, 0.16842605425946175, 0.1567016148398961, 0.13365104043435666, 0.15534027659844968, 0.11122675056779578, 0.13455070344911468, 0.10624400745596617, 0.21437781592530591, 0.23473058106197467, 0.14453005586420337, 0.1626249300616403, 0.10906473553228764, 0.08707589770276701, 0.2118676522326085, 0.08378517468489947, 0.09855365681071436, 0.12401001542926797, 0.11170284356921913, 0.09696469852520574, 0.15934800428728904, 0.19800236478688257, 0.09428761959556611, 0.14178631196339286, 0.0744666267306574, 0.17675159138537225, 0.08736024655762219, 0.17013611572404064, 0.101166307745922, 0.08332241927423785, 0.1327044928386327, 0.14548144513560882, 0.149175796898142, 0.09033570907288983, 0.17927353751034508, 0.09682969085030979], [0.0388908518418189, 0.04107893684939031, 0.0342838978394866, 0.05127569735651055, 0.027172387908062628, 0.02729732727241372, 0.024482400396898873, 0.07485385353286421, 0.03972818211261784, 0.0674792460256046, 0.07033985663926409, 0.024988407216545556, 0.04800914058221444, 0.022229546485769174, 0.02806592030420659, 0.06339421623476571, 0.008801105357105694, 0.02836021489553875, 0.036579380713162885, 0.02637034556227586, 0.018410234291466977, 0.0024823776836837494, 0.012471994719347887, 0.057610758024478154, 0.02997582154949346, 0.013373370898226577, 0.01080864642356192, 0.06767322714891165, 0.0525345100510505, 0.031463464707015984, 0.03950541140511632, 0.10025810285080826, 0.028974469938886263, 0.02781995053913805, 0.05260630015043482, 0.033287133180326035, 0.025411730166524652, 0.0026354437267723223, 0.07745143551860126, 0.03239567879767668, 0.07391441523307755, 0.01292390998588094, 0.03732891347739966, 0.005801157235363198, 0.05784777796737129, 0.027565295252227978, 0.045500543539322195, 0.05171248621697869, 0.05906608759335453, 0.04300654430182711, 0.0447728596026859, 0.05714242549372777, 0.036503331164919564, 0.042213853974376, 0.048053064233353066, 0.048494242777627324, 0.01069718063057911, 0.023477823556130453, 0.06459773653337071, 0.022135666241088224, 0.02043762852648093, 0.038918047963130864, 0.0425014816855471, 0.026803669790106437, 0.029498100611231023, 0.02979148164271347, 0.027099310780965516, 0.02801018357727557, 0.030321005446415757, 0.044724986768297614, 0.03651237866330532, 0.036622155232415084, 0.04601584492071022, 0.03263756722932862, 0.11900566097709442, 0.021830083344191797, 0.06357287176914754, 0.02003209988376306, 0.023348634319019415, 0.03975092726308973, 0.02272850721173229, 0.08975466202584007, 0.0792192293691539, 0.035919752197280046, 0.051833244656483014, 0.04370186485410218, 0.018707924567523505, 0.01448978508462108, 0.01046466624229065, 0.01103786376094626, 0.0345427819317387, 0.005015014565639919, 0.025827512896109014, 0.02256926434535173, 0.021801611686485912, 0.06473383971399839, 0.0336720080926053, 0.07919361138896597, 0.008444166798595219, 0.03971872858763222, 0.05642975304996776, 0.07659923931163165, 0.04594678592477595, 0.05063199197813388, 0.027598721583584146, 0.03305349168517897, 0.030526562158258694, 0.04541015282513634, 0.022020925422229116, 0.04938353296189059, 0.03429744227398788, 0.049797687754635854, 0.07924705368256377, 0.03283102358240755, 0.022621251071893403, 0.025200912345861717, 0.027653885659791773, 0.036280338291920004, 0.02258595548600199, 0.03249571455882923, 0.031009199465775204, 0.07098047468330591, 0.03743002559208582, 0.04329177415779522, 0.03077078715807969, 0.011864652661907097, 0.01942220771114432, 0.03832043043427891, 0.03624104181184404, 0.03353267968181641, 0.0551176589402941, 0.08916549444679292, 0.06890112053482764, 0.02954950128051062, 0.031937878060665344, 0.06136835417560032, 0.056607910627198804, 0.015251814658122679, 0.03174248733557761, 0.014020952681500106, 0.0404056221727402, 0.04278838927406938, 0.04257019977235506, 0.09049273411472959, 0.08030074633537762, 0.050646723848917795, 0.03842763677840272, 0.06882202961752493, 0.02873988232515272, 0.03342014136573961, 0.07031790822023345, 0.034042212421134595, 0.046085708308964975, 0.012218674340645873, 0.017123061021970167, 0.10038847569376232, 0.06575475912541151, 0.08154439048901682, 0.07907649952798121, 0.023367052987938928, 0.045866530553828326, 0.026207906194031242, 0.008336302576466434, 0.0444378761664754, 0.03398264525458217, 0.035518448529464584, 0.02365382076541503, 0.017213710290830464, 0.049361324072965694, 0.031136615209341533, 0.019964291526365186, 0.01797603097774329, 0.039866725283284346, 0.03219830007442544, 0.061516067418720455, 0.05946576332433089, 0.0321768879169418, 0.08413067267787072, 0.02730513179314233, 0.0789452763274312, 0.06675939916843368, 0.14402636837574745, 0.022247750650069887, 0.05338179180398584, 0.07396368234748803, 0.03189888801575909, 0.07985760277557759, 0.011446270979039613, 0.020311315949525566, 0.017803958053850842, 0.046293103631826184, 0.03515027816437426, 0.03073124744508776, 0.020880835288534724, 0.02254072182451285, 0.024350095097155824, 0.03970761265185091, 0.01048135163728148, 0.030267756590018832, 0.014728817923535264, 0.010916818996080229, 0.06799148305529548, 0.026916206190963427, 0.005013598739394858, 0.011006090264286726, 0.04472114100691773, 0.05475711498048998, 0.08421440608799459, 0.02070319865109219, 0.025154410808857892, 0.027027275533445423, 0.03934131537173544, 0.014422971683914864, 0.03624934620494324, 0.04870065750794546, 0.01419178837339484, 0.05147561183079116, 0.044532170098635464, 0.03338229662228016, 0.03206280401847776, 0.06883070173282778, 0.029455527190058946, 0.03549165077387326, 0.020328430353753993, 0.03409007376420402, 0.020126045245917577, 0.02250218377148192, 0.09387963947149054, 0.06074172872749548, 0.08833995043870904, 0.07824770730709837, 0.04756923374389449, 0.009496002645802595, 0.04633633397339333, 0.037276179815131816, 0.022178810397763888, 0.005341136279786307, 0.09366555620105037, 0.013674933748740344, 0.07196862851419757, 0.047954246552000125, 0.009791482758197573, 0.03424274742663388, 0.0786803248188188, 0.027588647527379856, 0.027692046414519993, 0.014979377512880152, 0.013703356568341055, 0.04243622631615689, 0.002534230105436197, 0.08572304771552164, 0.06891808172147121, 0.08695557593337952, 0.0691306634595798, 0.04990063081946104, 0.029862235608180205, 0.029262181919729038, 0.065460903119416, 0.08123286083460816, 0.06356023514883653, 0.03458916089467464, 0.09360603883021301, 0.055340828013516245, 0.024400348549768813, 0.01587557589500061, 0.044939464574018796, 0.016374880402919748, 0.010931348811174113, 0.0403266423381865, 0.05348429053781494, 0.04394909291858635, 0.04253420130079312, 0.03600461558709222, 0.052554956937749545, 0.04313828844216563, 0.010809073517579707, 0.04166785161942244, 0.08264217916275225, 0.049203613382433696, 0.037978755220049815, 0.025212376851648576, 0.03454026150246782, 0.02611388805352392, 0.02619421237238473, 0.07685193341345557, 0.08024867533916429, 0.08172961522734935, 0.0326259839799135, 0.0793610475656967, 0.028956118302660126, 0.012379087406330773, 0.014744907685164965, 0.018977078068400585, 0.034722678528557864, 0.03193909997090457, 0.03101271580934765, 0.05399383859889162, 0.020051504890885086, 0.05721706544019042, 0.03201351583664937, 0.06618084190713783, 0.05424001712291952, 0.037447902253798904, 0.040206807034630934, 0.0885126189959626, 0.039355223698000756, 0.03550308846658276, 0.02893818418435272, 0.027054519535252647, 0.042649880577359474, 0.11615036701362942, 0.013274174003351121, 0.07068432807441681, 0.02702863342429121, 0.051228858740820046, 0.028808782357842695, 0.04466507486217926, 0.0669176499509523, 0.040669681188920816, 0.02357876713147327, 0.08822152090649452, 0.04473649340892031, 0.03874873487098563, 0.04684433453686295, 0.033440615065516, 0.04409778292380995, 0.06688810193971281, 0.03810591049372189, 0.011753460745357219, 0.022470892910214684, 0.009358351009957975, 0.01917951488717189, 0.018920649947117896, 0.02302120259452251, 0.030366836656485836, 0.014688962199274572, 0.04508975187256452, 0.020469783151882793, 0.021130191162228588, 0.021513229378709392, 0.04908937052072537, 0.03760203531372451, 0.08164531491216152, 0.011934254622657695, 0.05202101663716378, 0.04894869379518975, 0.020138011539294835, 0.016759678706406586, 0.04857955815931482, 0.03550191635205861, 0.03666412918978641, 0.009627719973063758, 0.1370527619315732, 0.11809410827775156, 0.12093383533459519, 0.17760495204598675, 0.10741279715852392, 0.1984193924093439, 0.08818461845118193, 0.1512696530910269, 0.1999038103367052, 0.1844958056725802, 0.12919535049267356, 0.11817428703990676, 0.146342052987987, 0.09905719874246467, 0.17335241330006432, 0.12514698950033035, 0.06363324332802046, 0.09897836829505621, 0.1065421612152169, 0.07984005170123232, 0.13544616830204764, 0.15271005160625906, 0.09252766282447884, 0.1233910623517248, 0.04388043228837271, 0.2396488808576138, 0.07019633006665014, 0.23695788977126922, 0.12535358809175032, 0.23163304243597294, 0.06491467476852479, 0.19959460192870712, 0.12396221154279287, 0.0913541846638245, 0.15762372423083554, 0.11746740239041469, 0.16221651326744788, 0.15989077758164177, 0.17158130994967877, 0.11192507801517365, 0.1987857662982518, 0.13592612238660937, 0.09053646241344752, 0.11287258322080297, 0.13928069883296568, 0.10540168612234055, 0.1884494935192408, 0.11013207987191216, 0.2376840645146947, 0.1804012495784029, 0.21387795887647137, 0.1979355925634023, 0.14309996889243204, 0.11517387304094531, 0.10059688225268357, 0.14997522496888716, 0.18376314982531533, 0.12761346319870603, 0.16430911307613696, 0.08957016507103559, 0.09614267852157356, 0.1395656069320056, 0.1219894355463405, 0.18720642393154485, 0.23903587262236306, 0.09874747705555732, 0.12040365652571763, 0.17602618272987106, 0.1604243578209031, 0.17248498726516, 0.24472205298802546, 0.11017897977463662, 0.08907895715486619, 0.1227056128423541, 0.23812168458056068, 0.20165556230612341, 0.16627690184020227, 0.1583369061230652, 0.08704513927260715, 0.19988533229597155, 0.18081843041844908, 0.16205552755103958, 0.24262686380215231, 0.09469027540856793, 0.089452080278387, 0.17124141205943402, 0.18153692896087326, 0.10760945192868672, 0.11861768340872181, 0.11585757586984866, 0.1827584255126215, 0.07964522022032931, 0.1879884005193749, 0.2553487037338557, 0.10572023314213562, 0.13148089720597192, 0.12020836539206006, 0.21509392427340632, 0.11558877093897713, 0.10438200011248551, 0.19726434632414774, 0.12037214732939198, 0.14110696051389943, 0.22000730578457156, 0.17699850152336782, 0.11315969765306481, 0.13553174032318976, 0.30358994980492904, 0.12685787833986745, 0.2649649611163524, 0.2038702765299428, 0.1492584118198964, 0.1989708071754825, 0.09494106195146039, 0.10273072057433667, 0.1436170475978044, 0.1382759132332379, 0.1427009749797083, 0.11464737145410431, 0.11321240450225531, 0.19558230835583904, 0.1486026712002293, 0.12348867727503662, 0.08306501373167961, 0.10741791462585812, 0.13751967719966365, 0.160734853256614, 0.15443013350088752, 0.16392326523219386, 0.12792684678589145, 0.11091573419229639, 0.17970041702351264, 0.10805982735849197, 0.11024745271330881, 0.19173942746654635, 0.16904877648959238, 0.17018061011068283, 0.13227588196675624, 0.12171634818397223, 0.18592368631112963, 0.12334430034482673, 0.1342071130150749, 0.14725211947675676, 0.16785427687629578, 0.14663180276270837, 0.1438206890898366, 0.09849614659023863, 0.1262716448775703, 0.12866959967199834, 0.12010531890536509, 0.23045547336580294, 0.11248914855382136, 0.10705783031880857, 0.16727660061611285, 0.11160487624546213, 0.1858671643440762, 0.13779154648223232, 0.13466390060080638, 0.16452435313934283, 0.09596525255831019, 0.1114231601898228, 0.14094350799437494, 0.1564573860096355, 0.22818003901310507, 0.09564087560941135, 0.16435345424519432, 0.19022361525604803, 0.08774342075470956, 0.16928919020199007, 0.13805595406841847, 0.1300255293326993, 0.09887567420880641, 0.12667351162001012, 0.1171837889799668, 0.10048411411022949, 0.09344248671925838], [0.026341893056768085, 0.0355873734600121, 0.0725315575818381, 0.005370750844914226, 0.00830661188135104, 0.047179241364281026, 0.04275342502120522, 0.03841521466271051, 0.04297157238808371, 0.03740202124801375, 0.04031815408398548, 0.030788933865786083, 0.024871287694681558, 0.08188847121932814, 0.03698910368726619, 0.021857921064140338, 0.055232844090149294, 0.029546379472219178, 0.04558426162768756, 0.05299467608452805, 0.0038380791938247825, 0.0821023170025118, 0.034449028091565255, 0.05096621698729935, 0.022202909608641942, 0.06466948066747959, 0.029130001109273686, 0.03515233511045095, 0.015170305775808952, 0.040830253217850006, 0.045562359173932386, 0.06327430432241771, 0.051141076556016365, 0.047466007226537314, 0.02263304691070751, 0.0067373027934903105, 0.0401198560552251, 0.0005534144950234481, 0.025911776822120435, 0.03498558075197282, 0.04971002814390006, 0.10791073898754774, 0.02278724125766706, 0.04398343664023184, 0.04010822684053452, 0.0810912801253219, 0.0958107479457413, 0.047110155555269415, 0.032810262599659544, 0.11563879648043264, 0.04427888610910985, 0.021467626079796784, 0.045680516744933786, 0.05916348801204755, 0.06854160313284205, 0.05405144841079751, 0.01114145512767737, 0.03362498178537335, 0.061118820186464064, 0.020768658949002143, 0.004310741797164684, 0.02937939337214395, 0.0243819662700257, 0.029724862636818044, 0.09575541341497053, 0.048715803066208485, 0.03125698485922429, 0.041084739965416735, 0.06249666379223909, 0.09918999242325945, 0.08785678644574459, 0.0984423059309202, 0.016268216066002365, 0.044670035281488975, 0.02002130953534957, 0.02802864821147054, 0.09728962705741007, 0.028014079134370533, 0.03566735303930698, 0.038078951859666456, 0.018287351873192578, 0.013904484334371746, 0.06583293839808434, 0.2630234491680899, 0.102137592320721, 0.08973990717241842, 0.018610878464495464, 0.06885650357411754, 0.10746086151489329, 0.02114685932024112, 0.14547867189732291, 0.07779180072247982, 0.008330027358756672, 0.061623595519772464, 0.08020523049297833, 0.007608506599471214, 0.04449440962484768, 0.018473354190768256, 0.03050533003143726, 0.03922341444018868, 0.015937105204249104, 0.04388913887763216, 0.07420455571264029, 0.0478889528782137, 0.05951809862087812, 0.04762238109364145, 0.047351932904172334, 0.043206983546335856, 0.05408519075342244, 0.08147351203426238, 0.0874450984561155, 0.06861997392749594, 0.01597291406904978, 0.02916205231280577, 0.021606841492616845, 0.032904874458308184, 0.029795379115028248, 0.0148945888166406, 0.0850681804360882, 0.1066600698076429, 0.052707642091498266, 0.07488773760175513, 0.03599885460590163, 0.04603897311514424, 0.0212191071571602, 0.028384737369994965, 0.009665354042344037, 0.010052739807795133, 0.034973579984638965, 0.016470447956253926, 0.044605660913211685, 0.011094934438475439, 0.03246032129672747, 0.034044717528646996, 0.07310177980651779, 0.09421350824977122, 0.03156906609693843, 0.0609796220106223, 0.04418461899002714, 0.026181428280148297, 0.03513879067594967, 0.014029599898945422, 0.06647151864824757, 0.046103117657044244, 0.008162142062980321, 0.023964580501459783, 0.05816726727531322, 0.019791193959874012, 0.007617167702260157, 0.08761198304954075, 0.016286943085311402, 0.017530479986641197, 0.04063565922420352, 0.08602846398829453, 0.02625220139781314, 0.08395497807331624, 0.015147033939889122, 0.023610958146051537, 0.026694621004524733, 0.05334716462980836, 0.02010687581083227, 0.04834435767524185, 0.04817074682984141, 0.036992443830616055, 0.07161180008082621, 0.09982938472662242, 0.07476147099007523, 0.032199816928515514, 0.020139202806017092, 0.03778986092055998, 0.044106458869552424, 0.06888650357723236, 0.045618727923400944, 0.025263325529052846, 0.04665481970615445, 0.03495101486482928, 0.028294871426037246, 0.041833701994149916, 0.09014365083027272, 0.036637285468919624, 0.04252342244369849, 0.016559543981847745, 0.01733144842869332, 0.04340771773469545, 0.015109735991685622, 0.05283753612949964, 0.005901449157165424, 0.0336108704458081, 0.026265772645391768, 0.1244070175133886, 0.04692482356462748, 0.016560580115765333, 0.028440732651600437, 0.08011752108652746, 0.02574930872557865, 0.10047222442564466, 0.04406066979431818, 0.0026383591701291623, 0.03343817124503755, 0.03909471549934918, 0.051218244592629136, 0.035120423717965046, 0.00951657114895962, 0.039727435176891666, 0.029821929807264, 0.07736708923813797, 0.039470673148189826, 0.017800803686822617, 0.037017111861777884, 0.06744818116027503, 0.017113599836105303, 0.0490854749636304, 0.010838317966479208, 0.05037329174698361, 0.03707163433934893, 0.04845858138475207, 0.04147809164057817, 0.06901865374417075, 0.041447168501514586, 0.042795226608793584, 0.08929638056865624, 0.053159718236495415, 0.07276539059896624, 0.04814181934982058, 0.05839918507263065, 0.049477083788764094, 0.03715922500217154, 0.03255086522849818, 0.04455273189852315, 0.07689009225296398, 0.017073301696068337, 0.006431471396823444, 0.022585281328628623, 0.04484233994697852, 0.08257952083142535, 0.053954787266951416, 0.020404972113488663, 0.04055692070734598, 0.0738424948987461, 0.016832213826297272, 0.06822690953530612, 0.06066536508320321, 0.033930819406504595, 0.07392160879868655, 0.011035972481383192, 0.13959427394213217, 0.04446019996858893, 0.03424981841817498, 0.04542805629992678, 0.06949221099456472, 0.07277828385873188, 0.019767964258790016, 0.04685726610102481, 0.03937485087062082, 0.054460635123353814, 0.05052575856567391, 0.006343866369852256, 0.009393791194945093, 0.09453862830395661, 0.0364933145653096, 0.05697772042044709, 0.04649217540939008, 0.07085697364903266, 0.04583543887542141, 0.016267708532752532, 0.03200465602980506, 0.08778455201536418, 0.06471307107037114, 0.03411891697455318, 0.052839359418759425, 0.04618236179193182, 0.02836292110113127, 0.020617312533901106, 0.03546031011689094, 0.02733485217416479, 0.015005109448646827, 0.034889314143407735, 0.03917323568114831, 0.06537553794201344, 0.08996263191464449, 0.08800034366187551, 0.06558525451128522, 0.04401160952364726, 0.02260620318984072, 0.03916892260613461, 0.0380490169740252, 0.026955941256376046, 0.0642242725007236, 0.06573464931739915, 0.042723693148863894, 0.01803440879279327, 0.03942412947635016, 0.042524709471411286, 0.024580174283454978, 0.12365086574948604, 0.042739336664277705, 0.020003586091221343, 0.02392191323451698, 0.040542644658877004, 0.04638696089386941, 0.02084764261399546, 0.054763350936193625, 0.05387504134447344, 0.0452214002519125, 0.050670652605232694, 0.02452580310824898, 0.03451331052929163, 0.021144258451738188, 0.014870287550072518, 0.0668586228763865, 0.10253559798002244, 0.05783808312468952, 0.08162662236680908, 0.016951009165495634, 0.04894026682802266, 0.028183895929325974, 0.03454297728415939, 0.034099573254465096, 0.06464574726358538, 0.04409259267812295, 0.011794547955956192, 0.02706037819265358, 0.006593572728771477, 0.024410110425143957, 0.040241093299682104, 0.06007872559430619, 0.04357403925349636, 0.027635564667082606, 0.033960478500493115, 0.04103081503642663, 0.032974427580953605, 0.056371855955090255, 0.05301100907907371, 0.029661419065368753, 0.03888640087097883, 0.024027761687795003, 0.032289039358616836, 0.035216111930147294, 0.050151999589175954, 0.032582791942742564, 0.036400070173605796, 0.048095911530958074, 0.09812147596911078, 0.03635060770677463, 0.023117505592263998, 0.07026831168801555, 0.03737548013187705, 0.046098616890489094, 0.12028485927129946, 0.017192003189495975, 0.00848837485987573, 0.0329785069991504, 0.07200510196027256, 0.11434442964532684, 0.20792190105684344, 0.13387582595309905, 0.08223589975386858, 0.13356310886240777, 0.10513797567616548, 0.142331306912726, 0.10833479929715396, 0.13884594393593652, 0.20447547066836588, 0.09993702774086308, 0.09607142468373622, 0.18174124461027885, 0.10600059833978454, 0.1315773783191558, 0.101975763907596, 0.12052806920462078, 0.17711560572347335, 0.23155157664610496, 0.14559242063232009, 0.14412223661859191, 0.08404375234198186, 0.13348501385940661, 0.10871037390203246, 0.17536363924943632, 0.10464602465470953, 0.1684687100350857, 0.18821392148252458, 0.15940031277075892, 0.22139717314031818, 0.10844140809269683, 0.20494846867457514, 0.2193907888666276, 0.11579905441331288, 0.07076492052405112, 0.12194597537839606, 0.12992295015963817, 0.22468266377766288, 0.24159307411361128, 0.16590223887995367, 0.1626684744992564, 0.15620666075377695, 0.1933893510290692, 0.21457390379040472, 0.2005993722066764, 0.2509938462847664, 0.12449000015734665, 0.1432202140530271, 0.2577033362561657, 0.17313168804732063, 0.11074377043593316, 0.08741396464287274, 0.17362535510572696, 0.14826487239089706, 0.1592755476914106, 0.13162654584213612, 0.334918073588802, 0.17942151505379908, 0.15395957165427748, 0.07310606223801452, 0.14908202773621007, 0.17865637707854473, 0.14341453991590009, 0.18057296052575114, 0.10188454581845192, 0.13307129573677817, 0.11088589506764567, 0.21609346983173203, 0.263617473744577, 0.16410393940825618, 0.13002303188606618, 0.12680499529045436, 0.13151910967163502, 0.21110416900727058, 0.13651717454195023, 0.1287682258313702, 0.18493569335870205, 0.1282368366035723, 0.12268721907129213, 0.08174862952963, 0.1152371212599739, 0.3825613573914574, 0.36987040612486105, 0.2227031232248391, 0.16773429218559496, 0.19199367672685655, 0.13206048868596554, 0.23532053005070458, 0.11894052818177209, 0.31098147253355674, 0.19454314073006954, 0.12255071752494383, 0.15018435165045724, 0.19861557220499362, 0.07032312527899781, 0.0886674989916144, 0.2688816622380288, 0.12873441071039246, 0.09395528299313399, 0.11831393720762384, 0.08288499073035295, 0.18931468257740622, 0.19130936102761378, 0.24905579705392164, 0.1274960525634308, 0.13421036122787383, 0.12415737244150332, 0.1743334501741394, 0.15026952530587875, 0.1627974990274637, 0.21390123262761102, 0.2834817046119321, 0.11598647016310885, 0.12861496228123867, 0.33968500973236176, 0.16522593646039888, 0.13612959533929825, 0.24517317152311727, 0.21275504251881955, 0.15406817227842348, 0.13249766442083544, 0.0836013748701061, 0.11176312702798075, 0.1244751533733741, 0.08633189609334355, 0.1399115109515767, 0.112830494350243, 0.15964346907792554, 0.09393131210198326, 0.11505260898341095, 0.06230743624450219, 0.09591554877378287, 0.20539344318451422, 0.17156313834411485, 0.2512129167875936, 0.19714200208264013, 0.19066354890744533, 0.15893405633828334, 0.15983477655437686, 0.14590866172746306, 0.1581486476765525, 0.13302946733611246, 0.2128761763414068, 0.0945384674254925, 0.1650983521774892, 0.1686936794149299, 0.1320723324052749, 0.18713284884729695, 0.17570493141970328, 0.1269112746681898, 0.10677493703100951, 0.1294354118046261, 0.19415186898362255, 0.09667042883173113, 0.18608284873827813, 0.16460289247334003, 0.136802235858575, 0.15752492953212033, 0.1256903220388678, 0.11938210892220659, 0.09092246347497548, 0.1255503501142225, 0.154260874034897, 0.13023692363452527, 0.17478642264200797, 0.17117842431029967, 0.1541353275458659, 0.13799315018038597, 0.24108829878030286, 0.10104762540469248, 0.293533758771035, 0.19780764055828895, 0.13672743503364826, 0.07781911941785967, 0.11884002510698573], [0.052659225334683736, 0.06706386549218048, 0.08247566229153065, 0.07344065113894402, 0.03065044049083466, 0.14578827867104163, 0.04529810480533108, 0.039904209965419386, 0.023339270809364897, 0.04385910057012112, 0.025925920720422463, 0.010023650491700299, 0.010176702410042768, 0.054497231143496694, 0.006406042065786859, 0.05402094278965266, 0.06687608968106008, 0.01855283006725292, 0.029909449606953614, 0.0620867301439566, 0.022147012003246817, 0.04849557577061558, 0.043002445731432214, 0.0541541769710039, 0.05373391645750212, 0.052145226302766995, 0.023909366629537077, 0.030090192730929104, 0.056270429744355144, 0.05408897139732877, 0.032109004865971305, 0.04845964624696682, 0.0197986192670801, 0.06099449177723258, 0.057244449253043825, 0.0746774924318156, 0.04980528351640509, 0.015276707727612268, 0.07065105687586531, 0.05335763705173328, 0.030466311258233847, 0.07607964017698843, 0.009113131053445321, 0.06685360500048246, 0.03443037768104865, 0.004527637567896877, 0.07254251263915532, 0.011154691211789126, 0.0343119060139983, 0.07283046210725462, 0.04037187599967565, 0.053557566847772374, 0.028097730190042528, 0.0121994215934988, 0.013149708655903177, 0.034266775774378935, 0.03814864287813825, 0.024001791307161895, 0.031123042046543092, 0.011686523812973212, 0.02500600617138609, 0.0066569617164561595, 0.014107311857984433, 0.03424594967415737, 0.027154457620194843, 0.06607732044592982, 0.08891014968075099, 0.05118708779674865, 0.10954051443766202, 0.09534115903079511, 0.09475651903138047, 0.018134415825648655, 0.131251898203646, 0.02511473511525941, 0.0875181755832126, 0.018927075509582798, 0.12082660600783364, 0.8557675862985273, 3.0099116506115084, 10.15569200438838, 15.41074823948645, 17.215769060196415, 24.21609174820685, 23.272669546065792, 21.10658964803142, 15.844232901450127, 6.676852664639873, 5.880767924170341, 4.025247077788077, 1.9579892124860518, 2.1186888410199076, 0.8213549780268824, 1.4107355908040078, 2.6568625434752438, 2.563088723728734, 0.5982059456648365, 0.21343365852390567, 0.2558957058335504, 0.16739350563335806, 0.06804428949591614, 0.009123789251691872, 0.04858410872158505, 0.024002026879198612, 0.08561298386344025, 0.059538917060220437, 0.05460562492390314, 0.02238391320251169, 0.020671618591633537, 0.015707379376005023, 0.04693188306484972, 0.12923393068054032, 0.04626858115736996, 0.009789284085854888, 0.08693621689153296, 0.04207590452185081, 0.09906550313556388, 0.03273354272448248, 0.016743512335984458, 0.028970018968046195, 0.015595621512001081, 0.05491989334264109, 0.033727350284255324, 0.0701174306713285, 0.01770387632742284, 0.04048341074057164, 0.05308866741195802, 0.06801080379274584, 0.018963995201873685, 0.02660423220555869, 0.032659760796495026, 0.05724222759806341, 0.04318181372758362, 0.04622530102008774, 0.042815386212521025, 0.013087433368538418, 0.027759100175312454, 0.016324115586617303, 0.039569149920416456, 0.045032417852311366, 0.02765759352534529, 0.06881345709365222, 0.017530750032634507, 0.03275209737400855, 0.0828867527325788, 0.03373237199059898, 0.02356344154254804, 0.054021632268784515, 0.023270558468216372, 0.06041261352478497, 0.10835811135268981, 0.015695502140348958, 0.0939814295739897, 0.008144661851768053, 0.010591479649226512, 0.015166382448026731, 0.07721708922256386, 0.026278552907188574, 0.005123429892269234, 0.01470337997400953, 0.04324744064961711, 0.06213853683983607, 0.05724752892649943, 0.024196044391682072, 0.018424357122351086, 0.01444059074856341, 0.045916536943085735, 0.08337272826822535, 0.02891125427859445, 0.02600520507492606, 0.07535090669989586, 0.052158671145838116, 0.09472013751585638, 0.03833730352081118, 0.06743182518309163, 0.055755898281331026, 0.047018742113704645, 0.07670393288736382, 0.03519147454250244, 0.025723305786208763, 0.04531597763660454, 0.02585266164744333, 0.05865593561001363, 0.039637523267658493, 0.057755927855689684, 0.03308844444672427, 0.04133481021609999, 0.026663929607058247, 0.014728189731437354, 0.023038294016113205, 0.01478872504160409, 0.05802178717849236, 0.10088696910609161, 0.007952496835646491, 0.041707607752252976, 0.04441556385568073, 0.04866909085502548, 0.050387426069186586, 0.06077585794452218, 0.017902199254040758, 0.0326670769361719, 0.05256806470213398, 0.07123677705925319, 0.005418435987761064, 0.061033359248070955, 0.021315151600227244, 0.07398706335093706, 0.010583428065142324, 0.06897576814216953, 0.040219378537468375, 0.11434920237309511, 0.043841603121930556, 0.0435872734223883, 0.04382646522454677, 0.03882581480748711, 0.039561339654028416, 0.11100092316947638, 0.06118921217538657, 0.025044155434795448, 0.02425569582790617, 0.045048739355538166, 0.030064768187942046, 0.11682628638922207, 0.028983565317767284, 0.004203567054167751, 0.03085677669714055, 0.03344545291075784, 0.02680490319166453, 0.05057893272849822, 0.013545196758763445, 0.04874255485652436, 0.033477823955998305, 0.03861647745173785, 0.06823182781978, 0.025963106628267035, 0.020799082215695132, 0.0685414499152572, 0.03361892586033191, 0.057822221274217295, 0.005791932100340003, 0.011747416311634645, 0.03129956594127561, 0.07226351873889085, 0.030795526052374515, 0.030498751251387502, 0.07914669616448303, 0.0362987895195763, 0.06249498605968491, 0.05278616993417663, 0.13275385954447333, 0.030654395419743755, 0.03760915993142032, 0.025016449865013845, 0.26094321401849874, 0.844085848619861, 3.658135538139651, 10.476402640342712, 17.488411049689017, 17.393695615953018, 24.57605158129046, 23.909238846071307, 22.756756274930893, 14.751687088320333, 7.150476411465676, 5.620230859325779, 3.62508196984568, 1.7726302555491849, 2.066539948986423, 1.2541633988580396, 1.4607825827214027, 2.4778803798460194, 2.737483430293299, 0.6668723675031817, 0.29607150162900653, 0.15625915309834867, 0.14918368760376208, 0.013112650110176014, 0.03459672601292691, 0.01813140126966661, 0.009857999299833132, 0.018277561269520272, 0.028037337563751687, 0.030724452245199395, 0.03284780473838891, 0.06701148039991818, 0.03697442544263698, 0.029035385420185425, 0.03949415374306902, 0.017215489530034603, 0.03191069726111188, 0.07202280625220268, 0.011014398487825549, 0.022853188021408937, 0.023515578284258806, 0.01954000522082131, 0.02977459706486233, 0.10417522532084297, 0.06068820599466563, 0.03355996007280004, 0.03284899217467154, 0.04371763094358387, 0.08302093303251652, 0.06045747946407046, 0.053483597228243474, 0.030320455778330088, 0.04719010832148695, 0.004059768520340685, 0.06186274135665548, 0.04706774492778125, 0.02494924097141672, 0.04041512166300128, 0.03922831357246445, 0.02472966868099907, 0.019338363218271447, 0.006646858931954711, 0.025881100746412432, 0.01602101960264507, 0.020174873774991404, 0.03943606512621045, 0.0030346315555019126, 0.060419374250716744, 0.025324853880691434, 0.02627280150209704, 0.08315035592644446, 0.014203103492036464, 0.08434311652015294, 0.09064156201577957, 0.05352877726357791, 0.08082128009728848, 0.04480904193534967, 0.00666450193685089, 0.024232724681496624, 0.03507457718613648, 0.05239823833107949, 0.05158774412026809, 0.021951893239372203, 0.02387468774442471, 0.07501946642033516, 0.022768556373193864, 0.04412747649175506, 0.055267275911906076, 0.02752086215261971, 0.021550692993426518, 0.04013888567926423, 0.041537995885817275, 0.013978284456947399, 0.04801261096051143, 0.11027018254202221, 0.10493385154874095, 0.1340078841894865, 0.07848580743396476, 0.05873496140984278, 0.0306617766768942, 0.1347576544409798, 0.14386688419167074, 0.15747205414358648, 0.16794056902008672, 0.11706659284931038, 0.23124177068952592, 0.22955794007547442, 0.14143611785144578, 0.18034350187067064, 0.09365195047951515, 0.071034683064828, 0.08012974018891973, 0.12019804618772, 0.08694859687238933, 0.11193652336876239, 0.19903171116546278, 0.13828354346896374, 0.11002891081114931, 0.13236160720548323, 0.1402419859603528, 0.06570838782335482, 0.1347642734406456, 0.09504158800888447, 0.11741408267088475, 0.1788866937521004, 0.12000851603525302, 0.09047033370382364, 0.12633398911284824, 0.1167700555355799, 0.12566586085144552, 0.1430232375259361, 0.23226877283905786, 0.09877671097074786, 0.32545967628398254, 0.153047084327667, 0.2401349330020528, 0.1662327138887298, 0.07866399182427315, 0.13099498295735928, 0.1982104802323926, 0.17301222429640833, 0.19914651710179546, 0.15994264173411554, 0.18650350761750054, 0.0745121553359974, 0.14803679269408027, 0.1433121292821823, 0.0702877779821715, 0.1266409682049867, 0.13933182754103215, 0.21473055344916162, 0.13362395156535412, 0.1105282622419538, 0.09777011740351878, 0.08486624732012711, 0.13503134701280825, 0.1762268518007571, 0.0922127700440826, 0.18748569362346204, 0.11299852807555469, 0.13617865560996917, 0.13826244540752905, 0.1390093045249101, 0.17644062097514832, 0.09779073282956116, 0.1605171923555674, 0.2786821944098319, 0.23041127009257195, 0.17605674963804985, 0.2490147500629387, 0.18996837008143627, 0.2085817632295432, 0.22459897633281448, 0.1268929115406448, 0.28321008047749924, 0.09959114670392968, 0.4999345462889441, 2.045149670973901, 6.105423636974828, 15.511942448154574, 26.924209863908832, 27.214804541680124, 35.88964393061977, 37.09318399429321, 33.10965230388026, 24.790493442166238, 11.737802567020541, 9.808259241042599, 6.581718517887977, 3.8861642441441937, 4.01494717886371, 2.383681473232085, 3.2565755373047245, 4.313993338615664, 5.22117038888316, 1.4627213367531378, 0.6400847855594851, 0.27593282742365716, 0.4081871823197411, 0.29005060212746747, 0.13344479424338188, 0.18626016744923207, 0.19765676720248115, 0.25967291766597383, 0.14703553109880418, 0.12401494903550034, 0.12972767434773907, 0.17587242888346796, 0.3204488483888488, 0.13989504006120468, 0.13759479978151862, 0.10535301655651101, 0.14401654712855816, 0.2461295710095475, 0.17802626976082403, 0.16882328616995967, 0.1464731306318314, 0.10196007442690673, 0.1599180962770216, 0.15088046510373393, 0.14734987229589494, 0.18230073394313936, 0.18699807865965754, 0.0873744421668591, 0.24253862579503369, 0.14511899361687322, 0.1768209529860366, 0.1418302241232126, 0.12139770923362625, 0.10283703059558907, 0.2247430161843377, 0.17632123383302845, 0.11094631642223367, 0.1734062999246582, 0.15574360656882488, 0.1677913350924369, 0.13328440607555453, 0.1817292476733846, 0.25709022076860555, 0.10452312116901721, 0.21366760645422245, 0.2322846768243659, 0.12220531912340273, 0.18126288398859963, 0.1514266857937459, 0.09016904664496261, 0.19356075554124771, 0.1364215054819661, 0.2341971233967812, 0.2586751647533909, 0.17073225470319872, 0.2067849193249018, 0.17173771446029987, 0.11360809657602541, 0.1033468927527147, 0.20101165008400718, 0.21086674303777758, 0.06112483014623004, 0.11194096667872322, 0.07434865685119744, 0.19090511175172944, 0.08095980411575687, 0.10088896859557399, 0.1471382481676917, 0.09986509208477314, 0.11660417451733544, 0.201189122012546, 0.16670869963784374, 0.07507470902055502, 0.22117267873498703, 0.15493500076474684, 0.2092652975191032, 0.24661522478826586, 0.23148429880459465, 0.1295093852545946, 0.16475117645196377], [0.1309858205457849, 0.08376538663381532, 0.017231791881063295, 0.023889781591752847, 0.06175889813851926, 0.04624961282036478, 0.05255391888861215, 0.013639266610205656, 0.06069338091859414, 0.037060828669176954, 0.06568800222368971, 0.025444281242427327, 0.04832810128948862, 0.09163644209864641, 0.019025310964113282, 0.05889910340849912, 0.08725107902841223, 0.10781354541259427, 0.05007783461722636, 0.004978126953280862, 0.04384435337757872, 0.06653676635675854, 0.10067162179057637, 0.03011509058846822, 0.06580383471784092, 0.04200047167438654, 0.06046420954648526, 0.05180811697256662, 0.022523404406984488, 0.03069120211406581, 0.053527528540261334, 0.0999794690118682, 0.05947445842227148, 0.024948580220582026, 0.060354011629017136, 0.08515191384621205, 0.014408327913242243, 0.012875314156014114, 0.011310191738659577, 0.01202800846283114, 0.0635876113008107, 0.056700185917678385, 0.02271206696487723, 0.011418085646695428, 0.023097508782220465, 0.022801747132513314, 0.023740432750914368, 0.05915450946157498, 0.02011925579168864, 0.018253260960562095, 0.029591141989634886, 0.025739079536569696, 0.011461404088373867, 0.060077572631980145, 0.04265223629772664, 0.043796503525828166, 0.021902629955401345, 0.027635340586364753, 0.047974344868693626, 0.0666278925153517, 0.06111441135045983, 0.02689496448804294, 0.05627396907056532, 0.04443698367404361, 0.12454464520898559, 0.26735000732925635, 1.0931168857120699, 1.8919860187076756, 1.9567542787521117, 2.122232947618731, 2.559777507858892, 3.547913749371806, 4.925129500127608, 5.431902177872197, 13.002615936340826, 22.471943170793597, 46.63288639437768, 57.95784381128127, 78.82155049231746, 95.58677258030062, 93.4098728241459, 92.82749499044111, 94.03439260298207, 98.13652500029534, 95.03105117428689, 95.17077384456512, 77.62485888696487, 78.01898648661953, 56.69290296493038, 53.852942220626346, 57.87029650903518, 56.102484272372344, 62.53378283592963, 65.283246655618, 54.61196791741156, 32.93935475810882, 32.20498311904169, 12.23814598975643, 9.944434127499981, 6.336353180869934, 5.15954505051336, 2.2985037728663418, 1.2745763938273154, 0.6429252557216153, 0.24932405040148767, 0.06239117731550529, 0.03883345653453181, 0.012065874273708511, 0.006867274397894019, 0.04215865733943159, 0.09205706267347259, 0.034379754591012196, 0.022175267241114092, 0.02831397957408861, 0.08716686298289607, 0.008198154898690841, 0.11305117363771124, 0.04421398314016481, 0.017962218412468513, 0.09109379137836157, 0.03706393898614953, 0.05507551261313981, 0.03557824935283392, 0.02466062500682329, 0.03657762254137666, 0.01603744261252183, 0.07359651938801812, 0.03153613197707361, 0.04503892959966775, 0.026081867493508805, 0.03603505992120312, 0.04671957328795426, 0.018342722793139758, 0.0432931301334212, 0.010149589600792576, 0.020621196599677205, 0.052128583042612, 0.054516594015782883, 0.02212101480953636, 0.025673755219266303, 0.055939552539418784, 0.06887161082798435, 0.06169420201331378, 0.0235056268021224, 0.025942908720143383, 0.03293719570783358, 0.07298294424770341, 0.053262511914175366, 0.02190386718739906, 0.03401543381774137, 0.06603572187164138, 0.06957254297430478, 0.02784070769144643, 0.0361314682560342, 0.005094238111914526, 0.03229890274064195, 0.0725905463520077, 0.049477413206571536, 0.00802385122252388, 0.017197499870352687, 0.028692231656262474, 0.027419162065451665, 0.092817910556351, 0.042168995695969755, 0.025227779049366236, 0.03325809078711656, 0.05281139337908357, 0.040585683478463086, 0.0788877354634385, 0.0704986053789335, 0.15867585406428383, 0.09351287487774126, 0.06703838540781891, 0.04273791557117816, 0.02866154983489504, 0.03647226246915037, 0.1031905418682483, 0.056587980849848646, 0.050525770056992776, 0.023355299283960657, 0.04965478171324057, 0.0039409485226872595, 0.02409185643397993, 0.04342696186335337, 0.037365812102272626, 0.03269242678558634, 0.029609667910863797, 0.0305946980182442, 0.09103680975855359, 0.04771772456625777, 0.06457231007516384, 0.029957977446517157, 0.01007973195819725, 0.02298843318356141, 0.03956687080884173, 0.03325060610809634, 0.09579692005870805, 0.011650932325621047, 0.09285855152073408, 0.16574897532982213, 0.023011762476075562, 0.07589740318156059, 0.029938785028794122, 0.050661658733001644, 0.06987128662125719, 0.033029539946226344, 0.10751021289897543, 0.0743955031277672, 0.00192033332789452, 0.07046827595801124, 0.025896225237257542, 0.024977475141866073, 0.07148793898522854, 0.033678879901286096, 0.01757949237681685, 0.035567210025845036, 0.042130074598976684, 0.07936538362334813, 0.08353217414790585, 0.04429576302608175, 0.03535897200626712, 0.04428715219781284, 0.039680270973833344, 0.03328111555968081, 0.04524621000934032, 0.021086434135213498, 0.038474720542228995, 0.0552035833618814, 0.01998421747327572, 0.04271370336233128, 0.08668304015431674, 0.04016862521248479, 0.019051710353983987, 0.013920029215965302, 0.05503443114820027, 0.023280481222055616, 0.03795361221437493, 0.08506390566547072, 0.030735742465983477, 0.05821248178460425, 0.015892869372281338, 0.18795849244681098, 0.7396412821065995, 1.5461589756511873, 1.0189182671808428, 2.180801533883618, 2.214832017498632, 4.525715035776939, 5.161410627826568, 6.260712723578177, 13.296163178259327, 25.09705020535377, 50.35292502372496, 66.38551896618259, 87.676144261514, 109.62880288400959, 109.42948372133317, 108.8592024772398, 110.06086764797088, 112.82966090786843, 109.16500614535425, 106.21440318322952, 84.50421764004616, 84.41937677321896, 62.091649347735995, 59.51047874266102, 65.46215772628784, 63.678832515593506, 68.3846333719069, 73.01027667137885, 66.83477940097933, 39.39856098544213, 36.573148312107215, 15.446668324931977, 12.880547854208178, 7.585584934680694, 6.053753764398637, 2.5601496427289905, 1.0257923434818945, 0.493364331102179, 0.22255062576263185, 0.05027006906006606, 0.09727875626976452, 0.14053031081153503, 0.028176399758986892, 0.028445382805300817, 0.02231775959503026, 0.03474066627301997, 0.03277727868407965, 0.002658903733038554, 0.028925852083991614, 0.014602929567767969, 0.05305216332236606, 0.014260723837651314, 0.017653109595900583, 0.06869777781708587, 0.03182447598045392, 0.013143016877884587, 0.00797784285462131, 0.05231259736202417, 0.025006580737329302, 0.0590820107308607, 0.0732880923897028, 0.04109126703453161, 0.012494885426525389, 0.04309419625168366, 0.0631169307105724, 0.025355966626516274, 0.029931043710319266, 0.029869988417973923, 0.025235531859159954, 0.018293084126086007, 0.05218600899341607, 0.047399958956145474, 0.05413865219921835, 0.032473406078474175, 0.049639831507398244, 0.04939163051125023, 0.060473268536189874, 0.0774308430751966, 0.042055584039659276, 0.043703174864452694, 0.018822242122804447, 0.007216603788096579, 0.020348674227153103, 0.04040824985432048, 0.01776051895332433, 0.08995697052488405, 0.008501230772855061, 0.010291063057769452, 0.050867180970887986, 0.04157855641096831, 0.017804002103906487, 0.045927545626557646, 0.029234158423458858, 0.06139045198177619, 0.023633274287285826, 0.03750524776537092, 0.028744701018196442, 0.02034632042200575, 0.05954777686706474, 0.04863442154601217, 0.014095435579938274, 0.054561885133866346, 0.03820634079015544, 0.009947195874467012, 0.024829321398189472, 0.03745554781128322, 0.04554835508667654, 0.033569949859332655, 0.03831064366104622, 0.03358337171976605, 0.25671074677619243, 0.16193053264531398, 0.17696370580984702, 0.19101267049629844, 0.18136796060829394, 0.12516657070767495, 0.12742391772448056, 0.09402795409363124, 0.30969015472838957, 0.18637232272134674, 0.1619839596171533, 0.12527667286415256, 0.14605184356051107, 0.19097615874582724, 0.20553472511951001, 0.1997434528123948, 0.22293624378019766, 0.1367244013254681, 0.10881636216635666, 0.09565162382298902, 0.15821469977738398, 0.07705740585562683, 0.19633388657483364, 0.22451294465891777, 0.15314924981324904, 0.12835234734079531, 0.19511537776599008, 0.12319341166726044, 0.19272662368753266, 0.12070625359492919, 0.24952614439591286, 0.29263575050619345, 0.12222139164805414, 0.12478921111793288, 0.10198351671738971, 0.11614040787061376, 0.18926310953834366, 0.1634614521096791, 0.1164842204701516, 0.22360454824182296, 0.10935142861619111, 0.17801284790039065, 0.19370168507579835, 0.21310393428129537, 0.1418203262672309, 0.09115890119104617, 0.27161009970211214, 0.14458870755568629, 0.19457390682110864, 0.07248227514566914, 0.11128278223857765, 0.1960526097325548, 0.11124995537102224, 0.20889089502874883, 0.1815002486710587, 0.1191664475106424, 0.16606446565879932, 0.08029563652892267, 0.15434874431981196, 0.12616652229260053, 0.22721610122149993, 0.10459034538437283, 0.16141990440026407, 0.21191447552654052, 0.3690095071590716, 0.6884435648399015, 1.4668795394320644, 3.27264279127121, 3.2129725092841737, 3.632148119711107, 5.04534230116875, 7.2280148056245626, 8.74824752730708, 10.579694336460484, 19.832017421722412, 35.02420040868944, 63.866937621947265, 83.4043771989884, 108.34722334338774, 130.84391470878356, 129.27357027607582, 128.20211210558492, 129.9176783715525, 135.0559283841041, 132.33308176840507, 127.18624960991644, 108.41439001021847, 107.23234453508931, 83.16829758305704, 80.56737392179429, 84.75386865677373, 83.33620640539354, 87.99907299780077, 92.48930038944368, 87.11122097507601, 56.37223351386286, 47.05581988057783, 25.891957744475334, 19.51539585667272, 11.928250308959715, 9.628847087583235, 4.485079280791744, 2.090117806388486, 0.7899935447400617, 0.4048868142549069, 0.12022246140986682, 0.15602739617949532, 0.2270138386877314, 0.12552261007048432, 0.0963091494275197, 0.18232501893033906, 0.2624779332789683, 0.15620633899684877, 0.16811995616843625, 0.14303330392126115, 0.09050082400321, 0.1959977884806933, 0.158102881583956, 0.14044714430647512, 0.13221447235874592, 0.14772902453137984, 0.0721016826648866, 0.15043377455684448, 0.11925558950151167, 0.0980132200845307, 0.11958127646076104, 0.17629193863080395, 0.10543488837297886, 0.1409044834755121, 0.13435049403098323, 0.12174902183394279, 0.08415006236323426, 0.12153822508069778, 0.13680963626792356, 0.11569815297280589, 0.09314891416579486, 0.09126123521597156, 0.17161679514233144, 0.23415992216717815, 0.0977999029020148, 0.2046822377991292, 0.14553208354740374, 0.19925216062655374, 0.13227249585813092, 0.1849976239065009, 0.1670441082528522, 0.10403363695067745, 0.19345247667402993, 0.10252899430211514, 0.17410717844482393, 0.17397322031038423, 0.17624168326297115, 0.10339648928493263, 0.09250255812320018, 0.11719369449682775, 0.12068504828118509, 0.15661912249220958, 0.1555608792771255, 0.1230633452594761, 0.13535904878329846, 0.16269223854666756, 0.2578902617096901, 0.1882732166878639, 0.10803597904140912, 0.26109480749695535, 0.1797361320425426, 0.15696058320181985, 0.18054289923560235, 0.123024060270719, 0.11496099252854625, 0.21508523683634498, 0.22203569210344748, 0.2128030915534304, 0.18271629067678608, 0.10155045487467321, 0.06911430748239641], [0.021425307382859533, 0.07139815348050288, 0.010139720473108033, 0.05344663731633656, 0.06194357512398593, 0.0200245903068853, 0.053327916670710816, 0.016553750441920374, 0.060230897469145644, 0.04040670235671344, 0.009747760205139077, 0.021238563875217113, 0.037438119311005845, 0.0454824140685941, 0.004555489173189047, 0.04322947971823235, 0.07335020679860346, 0.029914542176430265, 0.032900798870551015, 0.04482298473557157, 0.05687855799952823, 0.019462067265844634, 0.05258436322272305, 0.06310724352876987, 0.07629632048549191, 0.09321682019940308, 0.01373336231711531, 0.034922949233723265, 0.045405537145392555, 0.056948260509318886, 0.013323251511000339, 0.056574195097651214, 0.020007439513480472, 0.05426710599192208, 0.02339971897703025, 0.032511097604348775, 0.04408355667105606, 0.0534301434433268, 0.03407297085129446, 0.023921568494951053, 0.022042283953558055, 0.09764430278371419, 0.04300361018507712, 0.03205704878294661, 0.03565845875850609, 0.028899841483742483, 0.07070003287686456, 0.0157394832480819, 0.05789759666508725, 0.03661366697821406, 0.07361412408851808, 0.02217725715449741, 0.013731374318951802, 0.03485467547791139, 0.04505751872315042, 0.03386034697835003, 0.07225725213967024, 0.07636509985933382, 0.030910670982613683, 0.046292241782911366, 0.0193901679989311, 0.12544551098178472, 0.6410095456146425, 2.878216846335319, 10.576956522080208, 22.74382814284294, 23.662810056440293, 24.092823420801473, 33.765449062470466, 44.53229634992538, 56.822509842534224, 61.23574503006474, 69.68732310879615, 72.555846552695, 84.08681469578897, 87.47948446581441, 96.05698631655787, 98.75882471761396, 82.02092586025115, 87.8201658495011, 81.37725707023375, 83.6617317507344, 76.50379842327487, 75.93749446253624, 88.7244761374689, 95.9805550113801, 103.46031881147816, 103.0173969268799, 115.44576414169805, 102.88100042650777, 113.0630183989002, 114.24288303621354, 100.3810856419225, 108.02648328965711, 99.84394058104485, 99.34750972255584, 98.28705772276848, 93.95449392257198, 96.08772200922813, 71.38114375452842, 67.0239160906884, 49.26239628945628, 33.68329501921131, 25.345161691788707, 9.815523470601729, 3.631643849995829, 1.186832850498538, 0.13339231722056866, 0.036932374876473224, 0.025846149900086948, 0.049490758458212505, 0.07418160371842884, 0.028115618343074477, 0.016944721498857104, 0.06437491986059374, 0.04368149457619556, 0.01956757097955673, 0.036547752773208965, 0.08151655085384846, 0.10538654822495677, 0.04140365087697583, 0.04940719358743199, 0.03602396313761992, 0.02793300404934393, 0.03310065971867692, 0.021043301469856696, 0.018818407852743423, 0.024563695732203704, 0.02896784710878086, 0.018024102994991888, 0.02137371136115924, 0.06899153423165122, 0.02375065427904408, 0.04058808899454532, 0.03817678128759708, 0.013665049299297315, 0.04389578852081492, 0.04116462378372108, 0.05382872366857144, 0.05898333094533413, 0.048950766063024925, 0.018181754313709757, 0.062273751358471574, 0.07093954260551161, 0.041565858503623355, 0.0262348341845697, 0.03988752457042856, 0.09007795879076566, 0.10704001877456905, 0.021564074634243886, 0.04401030334373636, 0.03415619098250905, 0.03090443885734966, 0.008710949257346652, 0.055082740652705395, 0.05837020779689474, 0.03581509309550447, 0.0519296721435122, 0.038739070671820836, 0.09304061997681858, 0.12033110033840903, 0.03919726785933299, 0.03440356077325921, 0.09594477502809418, 0.021204614688852624, 0.05928834119150716, 0.06358372340459498, 0.04495123551497537, 0.04483112058932743, 0.08223650496332877, 0.02865698969652576, 0.07399128449539985, 0.1015452991029428, 0.009683963275634715, 0.03541117323742759, 0.026210078053296577, 0.047734996018510674, 0.01676357234828174, 0.03215903040742682, 0.08041530712357453, 0.0525765146519388, 0.07228724448190582, 0.020907246169724295, 0.04412160825825507, 0.03710119767234691, 0.055420060657084956, 0.032135193581662835, 0.041509367180086916, 0.06970268599088154, 0.01662888068465456, 0.05348484595156005, 0.04574247793624959, 0.05105517894750641, 0.04442357713536871, 0.02635883892165317, 0.05665034806776432, 0.04087354867689071, 0.06521441432977877, 0.03423248567888814, 0.039859627478665886, 0.051512686655886715, 0.047778724317228606, 0.038455185300159844, 0.021650129290778312, 0.07514397102978922, 0.08686733792626089, 0.022609166034887877, 0.07983216099561223, 0.07386701737320231, 0.0487857124197387, 0.08311127012054767, 0.020191327428385135, 0.03006437173744123, 0.0322870283778156, 0.0094275823756752, 0.03244724800629962, 0.06439679933171119, 0.0803862187650896, 0.04856554641117973, 0.0325409903551542, 0.028197585920532866, 0.01404112377654641, 0.06507687090385346, 0.00856003185148321, 0.03627961816927118, 0.01266761239798319, 0.09207557135772321, 0.07953813645027338, 0.06157608274670859, 0.05216410653966089, 0.027709842637001027, 0.025076896117459384, 0.02720500793187849, 0.062446266698140296, 0.005529013118751708, 0.05447443619730973, 0.05318191946454106, 0.03649095884494243, 0.35424071093720777, 2.7862524649789258, 9.145501255989075, 21.078564313150224, 22.626955240003525, 25.23548829940058, 37.607238061966434, 47.13076460746027, 63.35409164428712, 68.53658599238243, 78.19339859870173, 83.57521210947345, 99.31906469406621, 104.31290088161346, 118.21375723808043, 117.66112665976249, 103.6058230553904, 108.76392026101391, 96.1874443484891, 98.36031190810665, 95.21810900780463, 91.93812893282984, 106.98064604113179, 110.10231925595193, 122.41509422179192, 121.91165801017516, 130.31809745296357, 122.48055857996788, 130.1036693203834, 132.4778799856863, 117.24763824093728, 125.37839781853461, 116.30626939958142, 110.54575889341294, 114.02445408605762, 109.46231395967546, 109.69796995962821, 86.49644436374788, 81.28218666199716, 61.86630918133644, 41.33223456721152, 28.88438690093256, 11.743016377572092, 4.599588465306067, 1.1802707252002533, 0.03686232379667702, 0.09852819970899052, 0.01621474121366778, 0.037992200063120936, 0.047671196216176596, 0.04402621115948405, 0.036095554054143934, 0.022139280260871017, 0.02455938840284944, 0.034796782213473515, 0.031382075525940425, 0.0497009614933162, 0.06926737951054689, 0.006858053093310446, 0.02953291356173014, 0.06036901546101417, 0.031136567328846267, 0.02897718763579765, 0.02231964800176361, 0.025919393651307594, 0.05106906046069438, 0.04955225999677374, 0.09905947402359978, 0.030695204923470176, 0.08853871961154285, 0.04455343669941349, 0.040075599155839414, 0.05061555556171844, 0.02811170937944084, 0.05402541674313046, 0.050999806112339424, 0.013323026472672582, 0.01914613643631099, 0.007485232518745527, 0.036526087806710315, 0.04204136161734501, 0.014445769502931546, 0.024841862257509947, 0.0012083571862369297, 0.01254694876185949, 0.010961874542126973, 0.01886691654010886, 0.04339625705934821, 0.0366700510494411, 0.02834992250427604, 0.06417529266928473, 0.006350376201988829, 0.07560616719626612, 0.03185031804135971, 0.017793859099789013, 0.03174890715238308, 0.05201269309186647, 0.05002269926931589, 0.040086324386779344, 0.05930201586095556, 0.0362160864977106, 0.05829097898376565, 0.06002062931656838, 0.020777091661828662, 0.04764320336342339, 0.049431601148699565, 0.10512190315151408, 0.047268218646246585, 0.009553420935727416, 0.03371473281614242, 0.03891173922907441, 0.0506075116385135, 0.0312666873627853, 0.014104522340330146, 0.12937072334029984, 0.0868687168845246, 0.09712992070783531, 0.0962086386918541, 0.21185629880957066, 0.16516555341020708, 0.12638311833143234, 0.19580680276117018, 0.08366237079063732, 0.15565959736704826, 0.1144089419094305, 0.11373457003144488, 0.16815606955318682, 0.12935141792460797, 0.190747496822188, 0.07796370319180912, 0.16943385824561122, 0.147444560763336, 0.19059165921663085, 0.14483659828622497, 0.09555056916489717, 0.18358524888753894, 0.14909549556191892, 0.12362600619634315, 0.1868008110191553, 0.16308927127430517, 0.12311902452981281, 0.07977089694430751, 0.17196052347219762, 0.20315625194099643, 0.08052871111900577, 0.11538228726074581, 0.13992200635613936, 0.121387068272358, 0.21687844948422527, 0.11298545861556647, 0.22977354786088391, 0.18215692391799343, 0.13482340010664157, 0.14553514789910088, 0.19443742059651883, 0.24248605684166957, 0.08006391791446556, 0.10154617244317647, 0.18955178678997103, 0.1063908052240168, 0.24302202727525468, 0.14134457034449424, 0.15680067000850556, 0.09668039563562601, 0.13956263451085937, 0.1453563429775738, 0.08806425071651898, 0.13835255266918292, 0.18256486573767278, 0.15113747228057156, 0.15013700741673672, 0.19928347830089832, 0.13838483561431209, 0.2022171966851719, 0.24433854937313065, 0.26970419552057023, 1.2487295678546353, 5.75628170082646, 15.47633517173029, 30.7977504499497, 37.13196446818691, 37.303940788392104, 50.28863345423053, 62.95761846726941, 79.24687662432271, 86.83858486913866, 97.11178225855674, 102.61834283028881, 115.50299936725249, 121.00289975443195, 129.84555382882397, 129.91815690071354, 113.66001882860738, 115.80071510807161, 109.36829474664505, 113.1773711789039, 105.52090460254301, 102.85958428536694, 119.19474986291702, 123.56660012275943, 138.0810171558011, 134.00716504743022, 146.35240154881632, 133.6704844813193, 144.68666507351784, 147.85515569871473, 133.250916388727, 141.61715938198952, 134.2235072966545, 132.39139956812707, 130.88498976922804, 128.3651964126095, 127.69988398398124, 106.93551524992913, 101.13945238051876, 81.47697940949472, 56.38562840800132, 43.146628872040786, 20.159598089033558, 9.026893684940955, 2.978341228538944, 0.2851958723077851, 0.1575145260581086, 0.18391789958602, 0.16069613517292086, 0.21336075759703116, 0.14012341087143268, 0.13767447292564378, 0.15211264092114665, 0.10870569310481511, 0.1620443273455866, 0.1260434349458064, 0.2125601344291241, 0.1512522169298703, 0.1698901095697957, 0.1347873786524419, 0.21373895988348993, 0.21780766817110203, 0.15237286566726624, 0.09690878176761251, 0.10505595064211277, 0.1738732918015411, 0.1217565754608762, 0.24661799802655177, 0.16408700886512959, 0.14176159796695556, 0.16098945491736935, 0.11458138830118603, 0.10478608084902649, 0.11166813978624922, 0.10894342550947782, 0.23456548911429223, 0.17270920587883842, 0.19162670528936773, 0.18504737365630367, 0.13235059086113207, 0.13577771583391776, 0.1935556687174305, 0.1489735803296489, 0.0816299701710382, 0.17318958897263775, 0.20400420402086553, 0.20167039376833748, 0.14367522431477425, 0.1203522290433607, 0.14370608233636425, 0.1412719145657555, 0.11417883207961438, 0.12957257218658924, 0.13106063669247012, 0.21046793298615565, 0.15721336157331545, 0.11639800493515308, 0.2540870182095997, 0.23512146976445955, 0.08677802739604827, 0.12503835823266737, 0.1841176187078799, 0.10950101494428613, 0.14722806431593435, 0.1955109089612961, 0.250695010707263, 0.18024423219744237, 0.19782630246012442, 0.1277159887456125, 0.22969099422616346, 0.18918345171597697, 0.10715932164701725, 0.16838940461316418, 0.12264093969978633], [0.014656258863396944, 0.002715309111085991, 0.060218513657849644, 0.06236395055067636, 0.08331845859966933, 0.0462812599125168, 0.01839008043339897, 0.011988773269789114, 0.026798278446339314, 0.05482853735767065, 0.05058186301480859, 0.02120039737482946, 0.11904473912211196, 0.044587305446545926, 0.06528286428581323, 0.013403208107657492, 0.04008719006613378, 0.005285717479343857, 0.040968612527414676, 0.006211202924004606, 0.07330190495497758, 0.004385352057720265, 0.04205749542903035, 0.034484099596738815, 0.021858702473823103, 0.072195750601109, 0.05994963977906493, 0.04785899884037433, 0.012112190034390699, 0.0344375635857784, 0.04802771438393862, 0.02698340742368131, 0.059332697682323, 0.04442449261043822, 0.049011378939593994, 0.03233918747414024, 0.07732310813040504, 0.009132327301607979, 0.027840987313538793, 0.04656658935991507, 0.009811908577478701, 0.034534240051382975, 0.03996300721360792, 0.05143238915010326, 0.05827141309817953, 0.015873017161333516, 0.015484438213940351, 0.05890350458362411, 0.06510289491064127, 0.02186175150376174, 0.039471661401612144, 0.04479935092310752, 0.07914642037283029, 0.028392894291168744, 0.04201648674244362, 0.02186125929227039, 0.061394891461297396, 0.1145693913642918, 0.038270527466891274, 0.2575867683176072, 3.580318165402259, 10.328426322629376, 22.000207554909494, 31.442321385106734, 41.088090558205884, 59.38854402111423, 81.6584360984064, 69.022991272711, 85.52801116820305, 73.25963743271367, 80.79090195317423, 77.31085746519028, 81.11856891262917, 83.85568511101508, 86.97326337137531, 74.71847672616282, 75.8035925895937, 72.07075918874433, 61.07424143821963, 56.17216910085371, 82.03006498275265, 66.34726801226216, 52.06692626399379, 41.71688964290004, 55.78683153275521, 61.215662494782485, 71.29307085467924, 68.34614707577613, 81.37160101244527, 60.625655651092536, 64.95803509989094, 68.99049835820352, 88.6552776828889, 83.94386783722909, 81.03816816883703, 82.6360554848948, 86.22471824769052, 95.3357958024548, 93.435164267017, 105.40652044357793, 97.5126406454271, 100.75473062453732, 98.95069137696298, 81.47850913386192, 66.97818909921955, 50.98759589656707, 31.720539023799283, 15.708202162096578, 5.093580590140435, 0.4792488546621415, 0.4775157186292833, 0.23859399310763807, 0.018023089843712026, 0.05441809426091852, 0.05098285641701472, 0.0698593509713969, 0.010181168702641323, 0.032227001558508606, 0.029829751564970905, 0.03315731958155671, 0.0538666220381856, 0.027504207401145852, 0.04882246165746643, 0.1205735824882023, 0.06844983346039249, 0.055149880598389336, 0.03276635427027941, 0.03883052624822144, 0.010487247641468722, 0.047097124399677406, 0.0937725710231931, 0.07200049777184764, 0.07073305126640105, 0.03050070860603404, 0.0413798600164873, 0.023345960672163678, 0.06861245094407951, 0.04391628903366866, 0.08616930159229426, 0.03666482249935789, 0.06268764951176221, 0.05164312461631433, 0.015184813565875014, 0.02576389120921733, 0.014816646073614399, 0.0951306150865651, 0.03437677450898675, 0.035757506266236305, 0.049999862188293095, 0.006794576963124376, 0.019741539971061775, 0.056739490058633595, 0.0847292248339903, 0.082911275207035, 0.03106602786799833, 0.03452547217508958, 0.07619436184364943, 0.02438206586145586, 0.014305240249321347, 0.04306288623821832, 0.004489115794234339, 0.04862912021757615, 0.05368806609523393, 0.06027940615651108, 0.020380687126288974, 0.006168460005879283, 0.03228281872467168, 0.06837749177770269, 0.00496845317801701, 0.023550433369593757, 0.016700381585847468, 0.045086189563716614, 0.06969775238464918, 0.040443133667952595, 0.027325622729897022, 0.04216114329474588, 0.03249147043172871, 0.04058908490884689, 0.024147369080193104, 0.03898102422094634, 0.0335046332029085, 0.018269071100099434, 0.023234759179514744, 0.04959159478124592, 0.08023541435719499, 0.05584425503207792, 0.019543686273297476, 0.02374410231207167, 0.07735831753140496, 0.029590249497203097, 0.02991004332509493, 0.06838274714086326, 0.04885147340715893, 0.04045049577290493, 0.01617238421233431, 0.0700734189200786, 0.049447237003234126, 0.08847203165773423, 0.05375644327291558, 0.04474519233730051, 0.012325413371135872, 0.04928381512722662, 0.017305949192133643, 0.053166976919577974, 0.04343179204771596, 0.048292083665728576, 0.07533533979327449, 0.01725371348701658, 0.07188337824998364, 0.021148766879172578, 0.03099621236023884, 0.01859101571983868, 0.09373923087672842, 0.05104969375796857, 0.010907691058462426, 0.056495081197710774, 0.046442149867934567, 0.02769679232921091, 0.04643911615975442, 0.05990322251173277, 0.050606301219593135, 0.07216196612364824, 0.02045368955981347, 0.02924470362373658, 0.07020550013910379, 0.026686680503189567, 0.03391003927155849, 0.03212405657846361, 0.0385523597229152, 0.023923244312285416, 0.053318493789242166, 0.028789354368082942, 0.05167663713256198, 0.08924774164634366, 0.09650444822205652, 0.36375950661397755, 2.796739411930884, 8.906565173979729, 21.044437731465987, 32.809137951943185, 45.92629101968581, 70.34432795739943, 88.77325473293182, 83.50573124424105, 97.12522814350744, 89.06212160664221, 96.03948470084899, 97.73000271089616, 98.6643034412015, 99.44586707699685, 103.40844938831945, 87.77509781622118, 91.53408558137956, 94.10060221149077, 74.31037764395438, 73.319579093687, 98.64817465505293, 87.50988283464986, 74.18545799870645, 65.27465274257045, 78.80080899884625, 87.88244524309712, 86.62569430566604, 84.83551671428066, 96.0137539525186, 75.06212342169978, 89.47282514264508, 90.2761265539354, 104.15008329576062, 102.92573113595287, 100.81580192812028, 97.67755277695196, 98.47806146067958, 112.95859706017279, 108.01448083692982, 117.8464194267027, 109.30108101137223, 114.05089870575937, 111.95536459645918, 96.73907864478328, 78.0491259790236, 58.99467922026112, 37.10133075714111, 18.15975804482737, 6.245209555472098, 0.6201126895123913, 0.765616626989457, 0.1392460869805467, 0.042208250041209885, 0.0385081526192446, 0.0424742587511578, 0.005342666540415057, 0.08734858669941464, 0.04379361920479325, 0.05115158728233749, 0.09677459380679554, 0.09945210940655201, 0.01629535281550019, 0.046751059501642184, 0.11218446006457652, 0.06681472603832522, 0.01720819062733602, 0.03724355979131595, 0.03941104086416383, 0.02914607363392509, 0.030494991674899097, 0.032766281491926605, 0.02142928720962617, 0.07862881306679019, 0.022726936731487516, 0.028043523723740253, 0.058370529553822936, 0.05215564126809759, 0.0809480676487569, 0.01146716219673474, 0.02309088978255468, 0.02766930509448773, 0.007498472912101857, 0.004905567893142542, 0.05533274961635471, 0.05593448103736005, 0.030009845429430568, 0.04724471506872966, 0.040031349917332974, 0.03315404838612003, 0.0153456537255777, 0.07359583756976551, 0.07115714221952424, 0.04013078046902534, 0.051605268381536014, 0.035630021574756796, 0.026630585630153938, 0.1170721086823652, 0.010491774263491314, 0.02775784379111663, 0.0484876161170823, 0.04515481571997366, 0.09139737670099543, 0.008465192081677097, 0.04507128915358936, 0.03539459892518578, 0.01029876607184809, 0.03427734012685476, 0.06191380877768802, 0.09026656963772352, 0.017807457160444993, 0.05199062209876795, 0.07174370509962882, 0.03844142636103976, 0.059379658872081395, 0.019120809569534276, 0.014374086655856622, 0.11177747585480252, 0.19422236439441481, 0.15378004661010158, 0.09670084252232507, 0.18313486579685442, 0.1917741925365502, 0.10556984242172011, 0.15148038855723797, 0.15679117051824448, 0.20329894347777291, 0.12375694594436115, 0.09222513470318049, 0.2870298561549956, 0.0971855080476211, 0.14581093955184185, 0.15393116511404514, 0.11101886494866303, 0.17173837329591476, 0.18129164292927713, 0.21715732081042183, 0.12674677260820905, 0.15368500574221536, 0.18996320664882663, 0.11867022171856896, 0.10438570797803903, 0.20064766638942305, 0.10878344336825033, 0.2576491278746436, 0.1841456268823916, 0.15836704402200638, 0.1172757271917597, 0.08706239157266195, 0.23171841527425477, 0.09633263768327814, 0.12161163928648158, 0.11118665352583894, 0.19916516368187245, 0.12678807240820703, 0.1396047846684533, 0.11638524957121381, 0.12970642306871955, 0.08453716659137318, 0.10983529741004591, 0.15036298803264095, 0.10252769195264387, 0.18656894684799258, 0.09749660869279216, 0.15551816221446763, 0.18525832362713354, 0.1138990491087879, 0.1481257661456062, 0.11694896770941636, 0.18751074469858603, 0.14893173660722472, 0.12381310785009016, 0.1276410576857386, 0.22201756646315898, 0.31322611015169854, 0.2520326615100907, 0.9040370703704896, 6.7465242551219085, 20.21439163915573, 35.3901614681367, 51.64073328818045, 62.59361467053814, 89.84986689782913, 106.49380145534393, 98.34455966949464, 114.92486553807413, 103.29168827302995, 110.88682466937651, 106.51115402098625, 109.3966377935102, 111.00840245523761, 111.89597991205032, 99.19920490634058, 97.85045085414764, 95.74693079917662, 82.49104545962426, 81.04052159094041, 112.15398557724492, 90.78261436954622, 74.19024329031669, 62.33471078257408, 80.3259128139865, 87.01913941291072, 98.55006833230296, 94.67906551976358, 109.53507392637192, 85.73329233354139, 91.3391359390751, 96.17813264170002, 114.99521716948479, 109.07846296987226, 108.47571234549247, 111.42149863704559, 110.32539229239188, 122.53047466278078, 120.16450097483974, 133.5572221202235, 123.51422863621866, 130.18066544686596, 128.6500781582248, 111.70496048465853, 96.13642215728761, 77.82684526135846, 52.40731739228772, 31.19101316698136, 11.962415133753131, 2.9382349935270127, 1.460779028073434, 0.40723870418244795, 0.1358943603812687, 0.1369524503787679, 0.14265107201232066, 0.25860158966914304, 0.16393659516207634, 0.12922346591949463, 0.1269523676244482, 0.15649423483879338, 0.27953638244540463, 0.21577062505868175, 0.13845502458993467, 0.25162239078312154, 0.19476576588086544, 0.12956629026561015, 0.1002875512706176, 0.17597413471629544, 0.08964232289262357, 0.06819608981811232, 0.22522431858364614, 0.16779024724758443, 0.21420665656126317, 0.15755666089394402, 0.17528955854715841, 0.14764126149877427, 0.12963505431769357, 0.1720829596442561, 0.15711220732379347, 0.11628499164456323, 0.16342826518079928, 0.10211338394231374, 0.07198853913934962, 0.11064328268290528, 0.14433600579298314, 0.14280448878003707, 0.12638291914857205, 0.14737127679249934, 0.1418798512989475, 0.13033619330775353, 0.1290199316797718, 0.13331108125707797, 0.14940907067108541, 0.2302505754895749, 0.1534492192008803, 0.1150232295115148, 0.1954123287671997, 0.0889871261953827, 0.28804152122428345, 0.1557593266930311, 0.15465021523977482, 0.1963919560394941, 0.10773382630319366, 0.25106474006127927, 0.19451589864348212, 0.17148164191072987, 0.149531414912593, 0.10913769008531686, 0.17686984471736417, 0.15968948031865782, 0.210595854347752, 0.16390736124688582, 0.19640756891139094, 0.12697368785138094, 0.10262680074740803, 0.17861012068967666], [0.05122307860743135, 0.06948449648916721, 0.03324864492301018, 0.06333914983476843, 0.013861329643987121, 0.017871371875967712, 0.05795667353536814, 0.07252018883704178, 0.0268026432322879, 0.04785696487693537, 0.04933682075070758, 0.014070622949680735, 0.04211281080760303, 0.04310708185057006, 0.017693195146538557, 0.03736784606571159, 0.04100114828155887, 0.01526243838241264, 0.10104394052177669, 0.04722715250306553, 0.05219590301895815, 0.049009517345937996, 0.11713612298931807, 0.0037440471679738335, 0.048228471554935946, 0.03510479552430972, 0.04811541612951025, 0.05006249370654264, 0.024319662254363782, 0.06895305363521462, 0.0406205672920952, 0.02167798424770515, 0.08706751670087538, 0.04137973744241942, 0.026613392701913274, 0.03043884317570877, 0.02352061531236095, 0.04350300375071745, 0.02367941959340486, 0.028159808209766785, 0.022096858142063986, 0.020356289141120452, 0.047107474247534434, 0.010155348666763354, 0.00900985474037307, 0.06715490738110197, 0.04851409977662468, 0.14877583771463365, 0.03508437928112765, 0.04395722494190259, 0.04940522857190621, 0.05548977465819448, 0.0034147562438456886, 0.03826772741552803, 0.04450143082067371, 0.0548269707078655, 0.041680679761714516, 1.66601300239563, 6.034520912554957, 16.01236726007154, 36.1010596829076, 63.82564290877312, 69.65568527098625, 70.86340658126339, 72.44562010611259, 81.53644254130703, 75.36661701817667, 64.89995264237928, 69.82823033486643, 62.66816716040335, 45.760645404938735, 40.73271597585371, 38.38822510934646, 50.834537167702955, 40.27799167940694, 35.451346520454656, 60.46202613461403, 43.035276705218905, 29.099466146961337, 35.414656669862815, 18.751433857025642, 14.189565354777923, 17.72612629398223, 23.941382669633438, 21.726371203699422, 16.346513975051142, 30.131249543159242, 34.07196267958611, 34.9786263896573, 28.920866904720185, 27.58367403861015, 34.48161502038279, 33.71465436873898, 37.703077254756806, 36.60701405617499, 44.53016258055165, 60.670947259472264, 44.741986259337395, 78.72618198394775, 80.02417272137058, 81.9254239912956, 82.5330069757277, 77.47116473413284, 93.26378806944817, 89.25338422098469, 88.96782782769974, 85.78298091888429, 81.61667070081158, 49.92006401861868, 42.74679814615558, 26.205513977235366, 7.228706613663705, 0.5642107020943397, 0.1809474549466564, 0.05469055343118887, 0.08066395628115824, 0.009643014918472017, 0.0727427986660792, 0.041187322968917514, 0.04684464097203267, 0.023313197006862012, 0.047694102245112585, 0.044677133086107435, 0.025531787635578264, 0.08933309150198776, 0.033351101522003455, 0.0013683526143018578, 0.028407124374362252, 0.03973598854856626, 0.05919795047732131, 0.0214294538337497, 0.028126437419785127, 0.1235595633906703, 0.08508321108116258, 0.04943600232382456, 0.009985847883076679, 0.0796661574032999, 0.03124865556826755, 0.006003325444556052, 0.03110098829042287, 0.05699809069835371, 0.033630585718539455, 0.018483328655542388, 0.05870699920060654, 0.045765548674089294, 0.09415000722172762, 0.08731939874949955, 0.05285282724446828, 0.005856344773013506, 0.07218970616738643, 0.024492842175306815, 0.04409583706048228, 0.0028105292914270036, 0.04650108118150984, 0.040673040484468785, 0.04528190970661179, 0.025540536359673547, 0.01796999612011977, 0.04842866565130892, 0.03381554232609849, 0.027119299930129803, 0.035358527675271034, 0.01904409352479683, 0.08415447502967813, 0.03518097913793979, 0.034639282197120695, 0.04734955037072782, 0.04556102618094414, 0.10185957901299962, 0.02900575888493369, 0.04714331184063227, 0.06987533156549738, 0.054362709934432665, 0.058213512172862414, 0.06430315274384714, 0.03743364918796766, 0.03110309311699483, 0.05150399155794613, 0.023602531178884452, 0.09069811462634995, 0.041930183107333804, 0.006959344281048905, 0.011264308817654608, 0.015419310206667551, 0.006331354717633898, 0.041339824261564406, 0.08737321642618026, 0.04884128826820562, 0.05316135766465337, 0.0277824467048049, 0.023936616377003735, 0.03779996562028124, 0.023744406832021572, 0.012891917196553082, 0.048939623314166264, 0.03357183826606601, 0.015292087900302103, 0.038919878913269895, 0.1021173139733653, 0.007693781282737732, 0.03999843111922664, 0.0555133663358227, 0.04937017238849113, 0.05870018484852007, 0.01841516406725972, 0.059476028902516256, 0.02481830505383832, 0.034554514568299055, 0.08007144089788198, 0.05627036462688158, 0.025562078752104315, 0.0528208124301126, 0.030980287307512858, 0.017945837537427584, 0.01834249871242191, 0.037860509548937125, 0.024525439216484948, 0.05177400307729841, 0.06636740729933785, 0.04142846446484327, 0.026218681220686244, 0.06410157202833122, 0.06616631688009347, 0.08020307012503186, 0.02886708739453987, 0.029386784205393448, 0.05658168360711106, 0.01908107258890185, 0.020673861314031868, 0.04000650568594856, 0.03521531519870605, 0.05011551848222172, 0.06208707488352253, 1.0568679340424076, 5.325398550879571, 16.513021530643588, 39.57444790870913, 69.21315562340521, 76.31649740280645, 82.69743273335119, 83.99179135599445, 93.88254196413102, 90.6231386430802, 77.89995039663008, 87.62654196831488, 77.86986581740841, 68.02201809421663, 60.989922246625355, 60.67972552391791, 69.370850593813, 65.3590190026068, 62.93309188658192, 79.23634113803988, 56.24194806621921, 51.5543273956545, 54.06252622604371, 41.42124883590206, 36.70979976654053, 34.32840331908196, 38.70834935096003, 43.72718280361545, 36.17473748422439, 62.573881226201216, 61.62960198617751, 60.91396162586828, 57.57841725503245, 46.00888436840427, 59.152181994530466, 65.54368026794927, 61.41420502816478, 61.1487429372726, 70.86717205662882, 79.46336792361352, 63.49364565264795, 94.66385456823534, 96.16944851413851, 101.49634884249781, 95.56198320081158, 89.99689302136822, 103.51495742797853, 101.26633321085285, 101.70181043686406, 96.42378284085183, 92.72199107754616, 59.93384761195029, 49.10437183995401, 29.98691220437327, 8.555637578810416, 1.1553000586648141, 0.10340973494514343, 0.06656243030222193, 0.06166563459461736, 0.02184676107830338, 0.049926041955909425, 0.09082947572272632, 0.021013929658839782, 0.01518923006275849, 0.019856870677622578, 0.0651310716244963, 0.07570006659314518, 0.10469575908275382, 0.054797537609814644, 0.01526275726651112, 0.050346513143590385, 0.03333510560614448, 0.030823287163530628, 0.07084538273873829, 0.03512114384061387, 0.03918574206651219, 0.042670066994164264, 0.030952983933891502, 0.004692209054595761, 0.01755717432036275, 0.06466204195373482, 0.09354530337957606, 0.028053823775882204, 0.026631650492368687, 0.033949554086692875, 0.031192208294786757, 0.025669474702989383, 0.007188839325305796, 0.07334906532759629, 0.04239121865060541, 0.05180678014913875, 0.023248882010398854, 0.052396572089844176, 0.0477470810555162, 0.09677947378687321, 0.014857075406208396, 0.04957137006004492, 0.05236180318940071, 0.03029167385501487, 0.04022296765939363, 0.06868852347496056, 0.059143753587118084, 0.052873963610299175, 0.006968117424196774, 0.018543692553536068, 0.012098021238231131, 0.07266400652306695, 0.01243511428906312, 0.016625324121466088, 0.030717461692890337, 0.01622285600000572, 0.09239625576282702, 0.02721005262085988, 0.009023720931802547, 0.039773124660695755, 0.011416197239962077, 0.07398505620057545, 0.04471256848304503, 0.01645955993163009, 0.18116289419272255, 0.14258305872640303, 0.15166161431660577, 0.14996482149487542, 0.17156015060121016, 0.1702763557794594, 0.12154889668548301, 0.11153440381730757, 0.05433806488590856, 0.1449032019703619, 0.15662785589454636, 0.156510062215309, 0.16707685085073595, 0.19228169514286905, 0.12050039810879577, 0.0820074983001236, 0.10575369586266818, 0.1109074834253519, 0.189065765289049, 0.1204109343609983, 0.181873639925353, 0.24850030670002585, 0.18968934553765482, 0.12253276042399869, 0.14943006148021068, 0.09893854704475212, 0.07622197165244049, 0.19728225745981742, 0.2183780512742458, 0.2431604133978967, 0.14733346269255684, 0.12219335283002547, 0.2580639798074, 0.09468277540778923, 0.1486025639479199, 0.09307969812183611, 0.1515098676205643, 0.08618523622111929, 0.12448411660208819, 0.10049981891267723, 0.16345999654262297, 0.18368379843811836, 0.13006331278912484, 0.12985369581128323, 0.15790182946910783, 0.12830848880713025, 0.17907119836778412, 0.38509101036094856, 0.13242739883642043, 0.10414194646141223, 0.08321378800657489, 0.12309355210633048, 0.09132940938035328, 0.1026287466107357, 0.11728879665174793, 0.0918978849245656, 0.19563092429551387, 3.28254432447495, 11.32764227928654, 27.37270543652196, 58.892921170880726, 85.12084561009561, 95.5450777853689, 97.12474961434641, 99.49004865461781, 108.34883151515838, 104.14576868857108, 90.61907506758168, 94.07026660057807, 87.65614801837553, 69.38535551871024, 60.71019449541646, 57.489261781015706, 73.11134046123874, 59.46622264000678, 53.8388648340779, 79.67719985592751, 60.027686395952784, 46.25053767235049, 54.88036001882246, 37.87492805911649, 28.47897856466232, 30.16777857657402, 38.42011005647721, 32.10177379269754, 27.4953559906252, 50.46324952956169, 56.46680970345774, 62.501764528213016, 50.01762120954452, 45.17973061530821, 54.55697236522552, 55.11148175885601, 56.07483940739786, 56.166752307645744, 68.32139691998883, 80.57379876413654, 67.18479602567612, 104.47327875321912, 101.81101706720169, 104.9595977414039, 107.15580340354674, 99.12887680915095, 118.79097323263846, 115.49448782397856, 115.43759776699929, 112.92590802715672, 112.69801047540481, 81.92454538037701, 69.28461336320447, 44.829541406323834, 15.822371571294724, 2.8983832222800103, 0.3494107410792382, 0.20755894392007784, 0.13779225128312267, 0.11391966453483028, 0.2248929395911194, 0.23072086154453217, 0.11284537177773253, 0.13021824641093133, 0.16680171803360985, 0.1773707589675342, 0.14403937654870172, 0.3109667330018936, 0.18780260887597838, 0.05041143526473353, 0.18162743458824773, 0.1180197517838209, 0.16667704488481247, 0.11248578542783377, 0.08496578512412888, 0.14731942796178404, 0.23969873785972598, 0.2093569676001226, 0.10610867036326278, 0.1767405597192626, 0.12145341914747992, 0.16280758074454724, 0.16584433795463654, 0.22799222489758847, 0.13709475887158226, 0.12318222678356594, 0.22889947218279685, 0.1585171359681314, 0.21969415968464268, 0.184316081445544, 0.157976706902827, 0.1898006427912943, 0.18335447256122867, 0.11670406472178237, 0.18070169394054722, 0.13036181128794147, 0.17656950760752926, 0.129422189127053, 0.1868861991791956, 0.11710800756249698, 0.17788391530273423, 0.1578486323236458, 0.1300792167744329, 0.08587599716960423, 0.08724940129585805, 0.08628308097080839, 0.20473894362728443, 0.08520091282984904, 0.11674397024175814, 0.1783785169884082, 0.0884929841624633, 0.1768372553370653, 0.16109951110857149, 0.10813327986867198, 0.19047559689610236, 0.13584427355277923, 0.188254983795266, 0.17025118213026755, 0.13937898791365086], [0.03666553496112747, 0.03695585930179204, 0.034360280635976986, 0.008135616268602111, 0.00587850242980846, 0.0750698367013566, 0.020802801572567513, 0.12186649375625196, 0.05250509993563737, 0.030889839136732683, 0.039057797722278104, 0.0800786727678872, 0.03277824395486424, 0.028436040363064217, 0.033990003529094884, 0.05717616783635271, 0.01729577745971901, 0.06864120222387776, 0.03447671067870913, 0.03461790834403327, 0.020585893352906552, 0.018002537619923393, 0.028268588864574992, 0.03539448018155752, 0.03333415948755799, 0.035774911783875964, 0.05876918638786001, 0.05450221837588376, 0.03599820343116599, 0.01660550351164514, 0.030861323428971153, 0.039627104471888275, 0.019424253165902152, 0.09280338552930663, 0.0498004878059991, 0.06082888655064087, 0.021900094204371976, 0.004995415642512061, 0.04689682305099503, 0.10522339447972276, 0.028668988548639803, 0.03428106331416676, 0.032014023369899204, 0.04248887187831345, 0.04559283798199989, 0.011361475579530723, 0.04339780455695526, 0.034097432038716735, 0.05468716349212393, 0.07878563892576965, 0.0731739606107435, 0.02209853395939835, 0.053590707811376745, 0.07232236961323409, 0.5065943018322991, 2.4397561675117863, 16.764872997037827, 28.862874661722493, 46.71493061127202, 69.03473484900691, 71.64835914488762, 69.51755508299797, 75.65881006179318, 64.5206045335339, 74.42926468387728, 62.473456782679406, 43.420618195687574, 56.29509225968392, 43.43196561259609, 27.927581571763564, 21.63221863008315, 25.71058342533727, 25.898680686950687, 28.28811799326251, 29.853765387688917, 35.615638917492284, 57.71788497124949, 65.40287894587364, 46.517200008515395, 49.48568505625571, 42.76907328636416, 40.927830357705396, 58.3428519002853, 58.77103744014617, 49.234747502111624, 57.0906352227734, 38.60928596988801, 45.48550290446128, 30.463584123119233, 32.40422971786992, 55.77586066338324, 40.89847533933578, 33.37776199463875, 32.39147220888446, 27.686665673409742, 21.445672665872884, 23.686787505303663, 30.34376552028041, 33.81821278602847, 34.163804977170884, 28.234811021435647, 48.37997674942017, 46.192231639739006, 52.062948980639064, 56.68215959302841, 67.45271744266634, 78.50851397360526, 81.4429646153604, 89.46167776661535, 89.40270885344475, 80.16022405316754, 63.366753055203354, 30.696455240249637, 5.789462991299168, 2.5730356093375915, 0.40908491479292997, 0.0454636947101643, 0.034100802825583566, 0.06698744056085426, 0.04046920364001586, 0.04262237035999856, 0.04461645892250442, 0.08247543246515336, 0.017962779571873047, 0.03738263539308983, 0.040107847627012, 0.04980406543660549, 0.08459147456432543, 0.07982079991169515, 0.058209294858839244, 0.04324444524583317, 0.029597808869795936, 0.06152752426362807, 0.02489417840185906, 0.061180279590189464, 0.03812716560318105, 0.06053677339467311, 0.0402808953977881, 0.03401424638145874, 0.008824591697644322, 0.01993319410229883, 0.018044517322954153, 0.051815061559600216, 0.04563265923230399, 0.018529050698083256, 0.05906717926864663, 0.08052841234471529, 0.0551499265636648, 0.010313735429888532, 0.0297072445297794, 0.03620187173627558, 0.006929994495059814, 0.021470355268027035, 0.01672559928509497, 0.04237782360324937, 0.054182112367162784, 0.029967724000133818, 0.028399902080456098, 0.036840666491057605, 0.020505785453884352, 0.005231686734459213, 0.08156503655857618, 0.01142036092783054, 0.04978665991896584, 0.05094026958930397, 0.0399723113514483, 0.022508885125599565, 0.041195726953446865, 0.0297752539852574, 0.05421207023544177, 0.016592435966876727, 0.044384682851452986, 0.06979471613322535, 0.010446512831314918, 0.030705284725333896, 0.014067666807902918, 0.0011590673285912002, 0.02534190891310573, 0.008489364070907958, 0.03275533792592826, 0.028927137196484595, 0.0728621551646821, 0.07048956554142699, 0.05705400362550732, 0.03571631754898737, 0.03642148233108944, 0.05257392910519435, 0.011945761263280386, 0.0485997062717234, 0.011863140595866548, 0.04082484846754421, 0.11127866068554502, 0.06118610185841399, 0.05947544284525418, 0.008508794933497425, 0.05024435148844796, 0.11544318358984687, 0.019242282386028, 0.031868384309834054, 0.07401616703118048, 0.006251886023223521, 0.05519271257423586, 0.0290760972477015, 0.12441974989469014, 0.03728548012253258, 0.05573164393764831, 0.04287823989626862, 0.03180683680599736, 0.05090612505051879, 0.057175842248984886, 0.029518650919799844, 0.049866195167264635, 0.026778612969323035, 0.05245320513964661, 0.04134032604915481, 0.030487591265550548, 0.0468075814686956, 0.030631588982237928, 0.0432435910577976, 0.01820412791153837, 0.05656748416743452, 0.06991936629938503, 0.056533745655249205, 0.037439375695201664, 0.051268928969699534, 0.05571264112668653, 0.027245907450936017, 0.053945241811414885, 0.025008235487245747, 0.03857771723320888, 0.2600105479359627, 2.0996609330177307, 16.054547448312086, 29.39459312346674, 50.3071980322561, 73.48147100017917, 82.06526433267902, 83.98519392936461, 86.08588203307121, 77.00955667803365, 87.78567252620574, 78.21887047060075, 56.59796591727965, 66.39650944740542, 54.2627122325282, 44.0155868376455, 34.49393910746421, 41.71230046979843, 40.562116407579, 43.67955738498319, 33.135904727443574, 37.9393647563073, 55.832585980815274, 57.35326536240117, 38.371296159682736, 47.28264662527269, 31.019395743646932, 31.078621572063817, 39.85631335166193, 44.194160584480535, 32.064772113676995, 45.14066773076212, 42.185448138944565, 42.631739339520855, 37.433324090896114, 40.396251140102265, 52.84798391403691, 44.24379817901119, 33.03429180575956, 37.55135605412145, 37.09896556792721, 40.021268629258685, 40.413027117329264, 42.7465392697242, 57.82387525804582, 53.079811680701475, 46.92783686422533, 62.740899670508604, 61.73150124088411, 64.71652692364108, 66.16471305970224, 80.04889934293686, 88.1347870057629, 91.3829331244192, 102.87148475646974, 100.5987693417457, 93.445817424405, 72.6437468682566, 35.303516311030236, 8.566345649380839, 3.1601641687654682, 0.6185992674962167, 0.08927551999447808, 0.03192460558737718, 0.050263143625230565, 0.0070009773292939274, 0.03560160737364523, 0.13108052433498446, 0.016942693281077573, 0.03865579691445155, 0.0315870480957411, 0.03823282444969781, 0.04297121998763854, 0.03825212603495006, 0.07969646384158442, 0.026465704356650674, 0.04152547800913454, 0.054884438793505394, 0.06902101329497753, 0.05398958681091186, 0.040430167629834146, 0.02910908882416064, 0.0882409182527373, 0.03518437673788398, 0.011881581289813885, 0.05000261627438088, 0.0404374071607186, 0.01149256567230388, 0.08461042757957213, 0.016852654967336886, 0.07521966817758738, 0.06581182501489116, 0.11214361991733314, 0.04341822463057695, 0.0515751458043533, 0.008785734760514911, 0.027895950291666295, 0.017041384557923003, 0.042477411202966206, 0.023216233258285833, 0.003604229897328262, 0.02651229207854598, 0.02250669411413612, 0.08430847402421698, 0.02176940918058878, 0.04000448321382846, 0.020570665440191666, 0.059170516868752826, 0.04529754556114635, 0.03560461426874803, 0.07001243832130587, 0.08085977601548357, 0.02445207672163604, 0.041717563064829, 0.01992865694656728, 0.07187295179333418, 0.03196735903921147, 0.053324534392525116, 0.06742066328203486, 0.07212676438352755, 0.012610467026881393, 0.08871269817914694, 0.2195537051246051, 0.11336729215878634, 0.2536045973219218, 0.20575102238405138, 0.15691020525991917, 0.17345416509816725, 0.28627271613767075, 0.36559505328055353, 0.13283339479277212, 0.190886955467924, 0.08843129876280025, 0.10166352179141776, 0.15756576201848446, 0.13869767527907126, 0.14195535692476458, 0.12304410879169742, 0.1646406299644901, 0.17706141266370976, 0.1394398459383557, 0.10540257478433271, 0.280041724683777, 0.10632112952730349, 0.11781421805461569, 0.12279977270912741, 0.08754167916072954, 0.13882705220772376, 0.16484765756514766, 0.29376664950001624, 0.1146765594040194, 0.1982911033255439, 0.15732462818343795, 0.24041444784210575, 0.10114186188025821, 0.22592001834944372, 0.11575590068053816, 0.19068483082998186, 0.12762107045179413, 0.0902285869984377, 0.2760481389780199, 0.3411065011976227, 0.15786812160043948, 0.21239131929412966, 0.11861237441940654, 0.1715598748095574, 0.1764869233292918, 0.2045284839527261, 0.10185528125974441, 0.13028045275038289, 0.18492155137561983, 0.20694556796262342, 0.19731135347918158, 0.14791599595017974, 0.2289061218259796, 0.17229588612193064, 0.990632952701661, 6.913610360314769, 28.162949277508645, 47.124284851935606, 68.8302303129627, 95.08948664511405, 97.82147238331457, 92.97888278961183, 100.12029509390555, 90.18062468497985, 101.12177818052231, 87.14028573805287, 65.61098421773603, 79.93107918770083, 64.82481179698821, 47.444766029234856, 32.936652245060095, 37.29102834578484, 39.241717169361735, 44.09579538529919, 44.795487388487786, 50.939864573940156, 78.36246844260924, 89.49646134530344, 63.94107826294438, 70.14860168580087, 61.1845463322055, 61.39560907117782, 85.15239715576173, 86.4699605203444, 68.78812759153305, 78.2328890215966, 54.44210967709942, 63.08538183089226, 49.57357752707697, 45.037430947826756, 73.93139039316486, 56.5990641809279, 48.43831416099302, 47.99969511647379, 40.84688440445931, 35.502784482894405, 39.32417715749433, 46.79561376571656, 52.77471403921805, 50.886002586733916, 43.7891484075977, 70.16646415956559, 67.48633999978343, 75.04656730159637, 79.96643543243408, 93.52300182465585, 102.63556203534527, 105.15742640341483, 114.86006798282747, 114.16881299787953, 107.31795418647029, 91.03234383367723, 53.14515836777226, 19.40940360869131, 8.352184237972383, 2.0097261330773755, 0.27148311296778344, 0.0906350349466647, 0.1824765970870372, 0.13395186784046312, 0.21619555870852164, 0.2658055127868729, 0.20300740105730875, 0.10653770258349758, 0.1442282938308293, 0.11394698323021013, 0.09736235944494125, 0.10485843019259554, 0.21536446056298672, 0.19028148553784818, 0.12886737293053058, 0.19371617945932573, 0.26526097749029437, 0.1847935074399556, 0.16233072165519963, 0.148018452549173, 0.26702518604936143, 0.1394127264258362, 0.16407905687247554, 0.10274849381417998, 0.17014118722609936, 0.0844196180602716, 0.18073662754989442, 0.10362997756249483, 0.1827392426709975, 0.17859361915578767, 0.19533302334527816, 0.14140791049407375, 0.2036907821292839, 0.19556868731254534, 0.1928905358598117, 0.07996626468675752, 0.11414461093203676, 0.08851415883269041, 0.1787040890344689, 0.09662857744842769, 0.08450559610801359, 0.17130701982926938, 0.1447662867365345, 0.1402385079211766, 0.10519553952279592, 0.16162034364477282, 0.1511355110954854, 0.16601172816609183, 0.13547963102258023, 0.22887693387606453, 0.1588225139365081, 0.14352082695451476, 0.0722180667423433, 0.11383007821296492, 0.1448777678512758, 0.1327105449332345, 0.15060524035605694, 0.18025756212732486, 0.1041720996821119, 0.13958855892621702], [0.04450509655139139, 0.033938361542119135, 0.07745095288320895, 0.00862836019105969, 0.03407054235257449, 0.008998485995576748, 0.019194499566970814, 0.05662551149725915, 0.07240991814122086, 0.03748787289124824, 0.053986698659437324, 0.03303730807777855, 0.04778710914955986, 0.02912274051097132, 0.02453035941617864, 0.012622265738525219, 0.03147095704691545, 0.050765532594654834, 0.012281455246040658, 0.08156945688589927, 0.050131491415442965, 0.03861668429547741, 0.021493682645321376, 0.0408530902988728, 0.10911313696734368, 0.05939055264236466, 0.06714286447893228, 0.039675306724084, 0.049963932664644335, 0.05647086515842427, 0.08527892356317851, 0.014242922827120752, 0.1259669640492047, 0.03541917119535708, 0.0025969590604936164, 0.04110154027359621, 0.06474353838711977, 0.021518670518191594, 0.04615161868353044, 0.02845822818457119, 0.07914291169013708, 0.008974601289317494, 0.06309954051469123, 0.06124608654288515, 0.01059686620494411, 0.041140875058068384, 0.03338038523290907, 0.05084863398224116, 0.013686454753511617, 0.06328455457884459, 0.09062713658016536, 0.010328428038666326, 0.19921463764002248, 2.2203488311459942, 24.919994415775424, 47.54001686649938, 61.23708648066367, 74.23227540908321, 71.620847640499, 84.99491399334323, 69.07136194167599, 55.93564233472271, 55.83273110851165, 37.87524969347062, 44.58689182035385, 44.58990027827602, 48.54842685884046, 35.5211058739693, 41.97825677933232, 33.10971506180302, 56.8003680629115, 69.22915889370826, 75.38338122829315, 68.65617905893635, 81.2806647823703, 106.3783190327306, 77.57734329469743, 73.3810426342872, 103.30348676250827, 94.39864743140437, 96.25003753169891, 117.85621750739314, 105.91758174280967, 96.02621924492621, 120.88602881277762, 107.97142105717813, 128.42805631699102, 99.71691070064422, 90.42803210596885, 127.32797268898257, 92.85510063171388, 100.36674545657252, 99.1236286778604, 86.2913828511392, 93.05986404418947, 89.98290584933373, 85.34908048568234, 59.808112113706535, 32.05509170409172, 43.5135313003294, 43.08281975407755, 33.14734235886605, 31.907667459980136, 46.9673704331921, 57.203905428609545, 44.97414742746661, 63.243708302897794, 69.31766325427641, 77.76080823713734, 78.92353996153801, 86.88505711094027, 87.54209333850493, 83.4973216825916, 69.31836928090742, 53.97612425588793, 26.970774281409483, 6.199226629349494, 0.5539407112425374, 0.10583134653467326, 0.09269159797939563, 0.04522590484890727, 0.048582542071779894, 0.056703077899592544, 0.04267194007913913, 0.052923207742071925, 0.017989027659378706, 0.08124108861891494, 0.030263805491549355, 0.016325521357958356, 0.0365581753994188, 0.014919355481622681, 0.03969575744122267, 0.022936383254765984, 0.03733623344751616, 0.04134600659111335, 0.04727154729827758, 0.024353787640950853, 0.045025932918032335, 0.04057900319176336, 0.06051662145182491, 0.031666820831296426, 0.056685794956020774, 0.030677908573359735, 0.07481082237415737, 0.03974907333031297, 0.03721957357840673, 0.006079239490997768, 0.03967765861401155, 0.013809061380133275, 0.04459396658104755, 0.04709463078348387, 0.02300309419121233, 0.01773285934881818, 0.05213488794622883, 0.0818172480250078, 0.02652777280027588, 0.015512521082024663, 0.008539450899397415, 0.05609293100273898, 0.07343608525491531, 0.02310683207225896, 0.04904288430548003, 0.027145006010429035, 0.08303800147146949, 0.0344943690053638, 0.03140010349001856, 0.09493129433042581, 0.013377327742355486, 0.025301311998778296, 0.042270471702419946, 0.04037269954419425, 0.035005273042066444, 0.03340592660430459, 0.03395853646760506, 0.02213221501498934, 0.02870694629006809, 0.005300242985193168, 0.05797049759196178, 0.027528136157460754, 0.024987754126590107, 0.015035924377791105, 0.03446799259813082, 0.017102269395705194, 0.016327783232554793, 0.003950372840570767, 0.010817947688572591, 0.09691020669115168, 0.055896444771919525, 0.0405912529376726, 0.04731254832398507, 0.03162607261460395, 0.01248968847756905, 0.05779246258879862, 0.06888240500683747, 0.028123260070119175, 0.018767033996541175, 0.0182174674175199, 0.01816545962356031, 0.03768206468873447, 0.1242345787825123, 0.06629919483055992, 0.03199670978281046, 0.10166958154689881, 0.1052311166459995, 0.0281947456495536, 0.0644049275245878, 0.018589948942404122, 0.04909029748711375, 0.05252141760842455, 0.04569085510147195, 0.062427447748280344, 0.02307517540400788, 0.04967411011157017, 0.10702822868141437, 0.017697389477923993, 0.05613804209016024, 0.08654637772950434, 0.1046727228188707, 0.06980102103684219, 0.06423683251224219, 0.040251707447873014, 0.044598486499800805, 0.02630918301762112, 0.0174289139648599, 0.022995845084228826, 0.019583898228442958, 0.06551732549503927, 0.041470434591774984, 0.24427589870268301, 2.507885531071694, 25.68397210490319, 49.97190598518618, 69.52529784171813, 83.05637667256018, 82.34832609853437, 97.45613498072471, 80.77169802881058, 68.78058879606186, 65.63730724396245, 53.887317872816524, 58.4215424906823, 49.154966492806714, 52.871435765297186, 43.53659875931279, 48.975635728528424, 26.213941189550585, 38.41161420268398, 46.35136219762987, 54.75067469381518, 52.24353490337249, 56.13863675825058, 73.47154740364321, 67.98273163457071, 65.62936052199333, 73.11246225910803, 69.7127636017338, 72.83264821575534, 74.11600851243543, 74.29685331160023, 64.33901448403635, 73.35382138529133, 75.91856510408464, 73.11587472115794, 72.84039881921584, 69.22345576747772, 76.05507927556192, 68.32829244675176, 64.72479527996433, 66.56285716641334, 64.49013948440552, 66.0994291305542, 60.833372608307876, 64.01786258143764, 57.33552055974161, 32.769545547423824, 45.75411465860183, 40.88773981217415, 53.08844089508057, 38.5368594046562, 54.87250743373748, 62.619898473062825, 55.516866560905214, 73.96787628050774, 77.80626850743448, 86.9782369367538, 89.3732753876717, 92.63099208954843, 99.43886956860943, 97.42091994131766, 79.32399042191045, 64.32712970241424, 31.903035140806633, 8.01383666453823, 0.5219217293685483, 0.09532019120430756, 0.04475400234842974, 0.05493965458064791, 0.07289871288042876, 0.04141121216478848, 0.013822074341137084, 0.04764021179007907, 0.07703468368779268, 0.030305865633812164, 0.003712042408522159, 0.011888785389131837, 0.022350475379836657, 0.04047123760345482, 0.0767546479079512, 0.09775806684046985, 0.020992140203053435, 0.046750220635365096, 0.046893697412263964, 0.0034333307637772975, 0.04460091882896039, 0.04051179046772661, 0.07521212221153321, 0.025943988904116616, 0.01400201977606142, 0.042171799577772624, 0.07578909367082581, 0.03347428079934851, 0.1077742451020787, 0.044922721722433646, 0.09958978306742446, 0.048354979484312, 0.06643638585604007, 0.02437033514011531, 0.057175079991500226, 0.013760486617684366, 0.019787072406841383, 0.07314053619460714, 0.05010981495762545, 0.010578377630501505, 0.04173863048274671, 0.011515212188955518, 0.040012255175820285, 0.0352585110663166, 0.0192116599364747, 0.06747202181647863, 0.0123439421651945, 0.0198318904656316, 0.05519201926466438, 0.05126730103286044, 0.09411107463341567, 0.06595593381432757, 0.039301111077469204, 0.03776187189824639, 0.09306270629167558, 0.05041467198621362, 0.0278116193329615, 0.052821704922544385, 0.011212230160562022, 0.14910603693175703, 0.22493527360981513, 0.14496828880040877, 0.08009305223822594, 0.12372464001659425, 0.1076468906455463, 0.11797051531292739, 0.13054383377875053, 0.1635609209657677, 0.11016641593267841, 0.1597178255718562, 0.11910681522661641, 0.17881339445950525, 0.14283300257257878, 0.0712435262938661, 0.1239958274809103, 0.1299173730395494, 0.1660401040628072, 0.1337601619982912, 0.26327466472022, 0.09976478053196784, 0.17369002824829471, 0.09990754101665751, 0.2345072970755639, 0.28533640347661515, 0.17721224005424208, 0.20036030680902545, 0.18648073948439092, 0.12811420890953273, 0.17150822516170242, 0.11824714200150584, 0.14499088839417504, 0.19132515776061243, 0.15955314731165288, 0.10434227079273233, 0.21263092095332764, 0.27429949732557424, 0.1750728016298625, 0.18557200598860943, 0.13251168382984976, 0.15423429078392445, 0.17398132552062312, 0.23489392632918976, 0.20580210512684238, 0.10241549071525374, 0.17139830686632665, 0.14970119531837203, 0.12160424653801227, 0.14846122072589013, 0.15452662993582988, 0.20911646195717398, 0.15439230407918655, 0.7126623620429348, 7.831720527141326, 40.127133400209495, 71.16529572394587, 85.91212103443762, 99.75568725216775, 94.73192338020571, 108.07810952586513, 90.0600588706232, 76.83758428019863, 77.2506804620066, 60.269645644772446, 68.55154591221964, 68.59670023764335, 71.65834549934634, 55.23597386575515, 67.92621812512799, 53.869741732074374, 83.96340124068722, 94.02715190764397, 100.3737586544406, 93.33555959886121, 109.43841103584536, 136.72450465540734, 104.92952100692257, 97.64456564380278, 137.1210249008671, 127.50671509773501, 129.96622946954542, 161.5408072933074, 142.99334649116764, 127.21691469992362, 161.64460889754758, 139.96687704516995, 166.57912315860872, 137.0418244023477, 118.34634119464506, 161.86870175023233, 117.93422560538016, 128.11688684648084, 131.70892284762476, 110.58942271817116, 118.7876941311744, 115.00341492314493, 113.82647637398013, 83.58270383650257, 50.702055192762806, 62.25244691295009, 62.38576435273694, 50.677042238173954, 46.82613765039752, 64.64892487372121, 75.58986263890421, 64.31956345035185, 83.43107285038118, 92.34659671783449, 101.2998773205665, 101.90330259261593, 107.71501571901383, 111.62897632968043, 111.07785194150864, 101.16685405854257, 83.12724605683358, 48.78687950872606, 16.17978970850668, 2.0046921386834113, 0.3650147263561526, 0.2133339904849568, 0.1468289325073842, 0.1218002807769564, 0.11062039197572779, 0.12055923366138052, 0.13511172495782375, 0.14098866121663203, 0.250220189411794, 0.15604005195200443, 0.1365224299051108, 0.0908037887946252, 0.10547123158410673, 0.33265498857344356, 0.20663976098500914, 0.1538958637824943, 0.20083292177127254, 0.1280880393460393, 0.12994331277666554, 0.1076074601000836, 0.10410836116681177, 0.19595632780223124, 0.09109177656712071, 0.14650211939888616, 0.11139519031970732, 0.3052027487466413, 0.1090549755721323, 0.22084686154079056, 0.10968279994783864, 0.2737759834816379, 0.218754215766826, 0.1254285421342619, 0.15543870357496126, 0.17393752061311277, 0.08013170903488513, 0.20775611963002913, 0.2511558892025102, 0.21701850567854222, 0.0895154740541212, 0.16308513439951405, 0.13426305275530587, 0.11979320702413399, 0.14401691485076182, 0.23154753170186476, 0.12412491329615155, 0.09104192722588779, 0.11093864788211162, 0.08480286886615139, 0.16355431728786038, 0.16012598189615435, 0.14664321747278014, 0.11269717972965972, 0.18896022901660015, 0.21831661102271852, 0.1281512492606717, 0.1003051636319968, 0.200543922762717, 0.08745183236896993], [0.11557154162156007, 0.1054286830607922, 0.01589739407908412, 0.06440541015998011, 0.032822194419080214, 0.04592353132583442, 0.02976071938211399, 0.03392778569832444, 0.08097720197251729, 0.06199037543528023, 0.0587744992076149, 0.04215050233347763, 0.0453739398489556, 0.08316465112711154, 0.07561412684979939, 0.0712194558112852, 0.06967332950162311, 0.06995636834612778, 0.010845039430404864, 0.025567897189889225, 0.034461438715938604, 0.015755324988746117, 0.0356510162143217, 0.06727334457419573, 0.015048581107910124, 0.03486678732799427, 0.019008495334175327, 0.056697542914339615, 0.010094609385686777, 0.057505110669280254, 0.005675648093118423, 0.03603948790940546, 0.013699206287011266, 0.042861814971172044, 0.02871689394176487, 0.026541363200052615, 0.025154533382925778, 0.07476269673075407, 0.0574695029025597, 0.04185508733855621, 0.08935222071745703, 0.03641739908245303, 0.039881196684174, 0.08349684983371727, 0.06595532860486739, 0.017430564884336728, 0.053922730317759904, 0.03077795008017171, 0.05969359404257229, 0.04526563799910007, 0.35749192680082015, 6.648344878227481, 22.973884959374708, 45.754122503342174, 76.48891695084112, 74.30668277125206, 80.45659834338774, 64.8235958622348, 50.05211453283987, 45.43789709767988, 43.71730627552156, 40.7014899869119, 38.95742770164244, 36.037325089977635, 39.675617602563676, 47.359026939638206, 43.38798799822408, 41.32547240103445, 42.604655373481016, 64.01246147771036, 70.65301064522036, 79.04037952423096, 81.76362622168757, 52.070891780238, 31.769754963536418, 21.85869432264759, 19.603708021102413, 17.269091721503965, 20.520191384900002, 21.926372858785815, 17.654444979083156, 21.402881568478, 23.884057229565038, 24.684305075676214, 16.15208600797961, 25.19123023556125, 22.406788679861254, 15.136069559281873, 19.728060883860437, 31.097066517799135, 29.39255741334731, 29.654644304706206, 24.10150166480772, 32.14907169342041, 56.3439061564784, 76.5828969401698, 66.1758682804723, 77.9700823753111, 104.47955454549482, 108.54783688822101, 91.9021607983497, 60.366779219719675, 44.95427277780349, 31.597298152985115, 26.636680518427205, 26.711799790782315, 29.799626873385524, 30.90126572116729, 45.21538496017457, 44.93693982401202, 63.02842509362006, 71.99287660660283, 76.25740297379033, 79.04175235379127, 83.87994889290103, 77.48876048672584, 68.21440250642839, 27.00893305963086, 5.836714804172517, 0.40148657896826345, 0.06784874555324355, 0.11257491209694456, 0.036273029813122366, 0.034940565425542094, 0.03279054732692819, 0.032183866977932, 0.06076086560384401, 0.0731090653026777, 0.05918185113959255, 0.017142636483655344, 0.011558473174039637, 0.06704218520392334, 0.11608119693494613, 0.0755941013114587, 0.04954505110940626, 0.041729506375568534, 0.010627444604441766, 0.12576632562183565, 0.046923931072195696, 0.018612188474845984, 0.012042243334074176, 0.08755494780357807, 0.011614385143583341, 0.010363349199084746, 0.010852867891381105, 0.028431219754800684, 0.06495431215772707, 0.03264222504390824, 0.015542656108136139, 0.017942031995663722, 0.03960914737094314, 0.06328909364979594, 0.046236983860933015, 0.05434780569386579, 0.04609933701313792, 0.04879671727277098, 0.03510879833371409, 0.022788288882903518, 0.024460185762314547, 0.08952062216497238, 0.036065979229827086, 0.038916389382774794, 0.01717548633384849, 0.10945816764668112, 0.04504547965142035, 0.08747589519067157, 0.07724414744804944, 0.08875308633451501, 0.011822493885824037, 0.09172073475295499, 0.04467772680424875, 0.039227474706187364, 0.02032001870834539, 0.02131088832092862, 0.09868263537364622, 0.04702303603652024, 0.10723430633304581, 0.03440999591182317, 0.029401996796349847, 0.018607737504005916, 0.06944315838477305, 0.08676549419760705, 0.03366389139104755, 0.036043552005843776, 0.07428805929638686, 0.031095104735164397, 0.032562222481975635, 0.04753020922503164, 0.03722720381413256, 0.03596466793228061, 0.12061843693616892, 0.028362880881515243, 0.08109499565175465, 0.05472000568143783, 0.08364606843960863, 0.019103603234754938, 0.030242152016369567, 0.03478255213028, 0.020428933428540345, 0.07974366251859935, 0.021167467085404262, 0.024882589406784505, 0.0454930818429397, 0.09378538001328708, 0.09060184801778487, 0.015767763383806716, 0.012497318713294884, 0.036794448406585765, 0.07078937405059416, 0.02385709453524361, 0.06404131155220733, 0.009419045283369, 0.0358630808430814, 0.10615622910160212, 0.09023003490461458, 0.07219405754679634, 0.07261739007287449, 0.017928579491713358, 0.040555691136227506, 0.008057283778344432, 0.025295928315890413, 0.025402018086864583, 0.03716485574841499, 0.02190545681984194, 0.0837605679407716, 0.03818684768292212, 0.24330572495537423, 7.118764048622501, 24.534001811858147, 51.93601323712257, 88.61508907810335, 86.02085698035457, 89.05392385298207, 76.41530190744709, 62.87653915343746, 58.33052781320388, 59.65683806327082, 47.9638760320602, 45.82777677043792, 38.987347541316865, 51.16227472982099, 57.173130512237556, 56.19820971642771, 43.23680023993216, 44.598325529406154, 61.746210129030295, 63.62241706540508, 63.46267854013751, 60.42294756058724, 47.56834422388385, 30.99078401442497, 24.086175003359397, 21.186454988295033, 21.051305801637714, 25.929912559447754, 26.736944144771947, 24.2637465846154, 26.366293891783684, 27.15117193037464, 25.953621325954316, 19.51092435467628, 19.12412178131842, 22.054826559558993, 17.61167545472422, 20.499602863865515, 24.013313055038456, 25.176425249345844, 25.612151545863, 23.56268567423667, 27.52816269474645, 39.92358592248733, 52.76157802151096, 58.10084950539374, 58.192515296320764, 76.00314709448045, 80.45907728133663, 83.08217017881333, 51.112641057660504, 40.5270347287578, 48.78983697583599, 43.886768356446304, 43.167350753661125, 44.72639483790244, 45.978258502098825, 62.10127484413886, 58.139100459314164, 76.60838450154951, 84.40845689465924, 86.00073522137058, 91.6293756423458, 96.24776255699896, 89.75855412021761, 78.4093015424667, 34.566361750325854, 8.26780621082552, 0.7954039640965, 0.06249361476230045, 0.05124760491232719, 0.06476813747036843, 0.07196076845209445, 0.09146250949631776, 0.02665743892711978, 0.07722854223703185, 0.10857630085440413, 0.02301899434608077, 0.058968932322797284, 0.00934913688744869, 0.03690767620179442, 0.05005366837365493, 0.044310640453571276, 0.005160187269681164, 0.022681869694121906, 0.08698667144222606, 0.06105258039409115, 0.0442551450443364, 0.038711924346223954, 0.042041572291524186, 0.02423102779674434, 0.03316460124727699, 0.04208225156030348, 0.02974695469733448, 0.06285166127547141, 0.03778426464827311, 0.04018798808477098, 0.019008192729445237, 0.006973897557585471, 0.018248252660757112, 0.055277461050859386, 0.08124549362447955, 0.032950893359919714, 0.08670154883856736, 0.04785969214994581, 0.049864138221187945, 0.0359503650707343, 0.0270537055668331, 0.05973335400584245, 0.01875844040525056, 0.06195814611630575, 0.00994587820323725, 0.05932608251309684, 0.015672153695636702, 0.12519203547027805, 0.0036356627242639665, 0.04422308426470526, 0.03836074964173379, 0.03862982653381844, 0.09791513784758507, 0.04163692081947962, 0.031670143737667994, 0.02025216438567206, 0.03302637983353869, 0.05726716375999874, 0.2307055091425296, 0.16254265221857256, 0.10613595841512566, 0.20408393845202463, 0.14584447888116683, 0.2282437928501637, 0.24338769636327223, 0.13005853240047732, 0.23734755273307526, 0.11465027492733733, 0.1417814549659529, 0.10690029965893877, 0.13332226614077247, 0.2565736783247802, 0.2091124936217262, 0.1621106705598293, 0.19902000534197978, 0.1804385274167984, 0.13498524384152505, 0.11842073752514778, 0.1434070935412761, 0.3227795330026458, 0.14349332439803308, 0.2586763598505528, 0.08045838424755682, 0.2499507256453076, 0.16525213666740926, 0.14237624563036427, 0.13866939131290684, 0.09740725219730409, 0.13313106591663054, 0.1297145436007169, 0.15105922405998554, 0.13607198552739236, 0.22890365502286344, 0.07703595539374698, 0.25332679851881923, 0.2912168330963581, 0.2060950111838118, 0.14515981078147888, 0.16519670254520832, 0.1054944210655747, 0.19883030665016946, 0.21376183526890896, 0.1619658799421403, 0.06745111527702502, 0.16607747383175359, 0.09675213976973489, 0.17323898632199536, 0.213228898543504, 0.8605949208140374, 12.57911959002095, 39.21719058867424, 71.56262397766113, 102.51818903030889, 95.07902960623466, 102.39405385909542, 83.51506648525115, 69.58358426247874, 64.69116880047706, 62.322469065266276, 57.16269700757919, 58.96623811414165, 56.44652320492653, 64.36341554887834, 72.69895815080213, 67.89673759091285, 63.1627074364693, 64.07615292456843, 87.31097159847137, 95.20094471593058, 105.52091244728335, 103.82236142312328, 68.489776426746, 45.008781956088164, 32.64611248047122, 28.115957321659213, 27.994889443920506, 31.752341601156424, 34.72830464763027, 29.897654748732048, 34.838527171842514, 36.28347343014133, 34.796522509667184, 25.00121493493357, 34.830447089287546, 32.63658504332266, 22.96559306883043, 29.76229375408542, 43.466023552802305, 39.075240012138124, 40.876663038807536, 31.940558495060092, 42.12425131951609, 69.62332571706465, 99.48782074835994, 86.5101569698703, 104.36306799611738, 132.67473589989447, 142.3207227645382, 123.52452093555083, 82.80792590110534, 61.61567757206579, 47.68780785222208, 43.93660206948557, 43.00843200375957, 47.89026491103634, 49.36422494149978, 67.35367759581536, 64.92013715928601, 84.76093676782425, 94.61576630992275, 99.56060424927743, 103.1907892227173, 104.22842087284212, 103.19680613856163, 96.68484795478084, 53.552539656239176, 17.68816363426947, 1.9615610208242171, 0.21051952134697668, 0.18505434505641463, 0.20704270791142218, 0.12723857041208014, 0.22972998810150932, 0.10018910131146831, 0.16471947573365706, 0.17405047261666867, 0.2141120753461315, 0.15061991860068616, 0.1630940363411942, 0.09364349286883109, 0.16035050694500247, 0.1402817306018645, 0.17965279699813935, 0.2737913358836405, 0.13757505003483067, 0.22462509993103244, 0.15320598628492127, 0.10457336121509153, 0.16411797413902898, 0.12491581480829947, 0.0820527970790863, 0.11999059723870409, 0.10366037593133028, 0.25272538885474205, 0.12426151443393, 0.11260566286622517, 0.12566416013625362, 0.13125451822434703, 0.121845418677455, 0.10919349192972146, 0.24000862042509744, 0.14972322800707433, 0.19727307972648453, 0.1241043744789016, 0.11831581412303833, 0.17042284711234032, 0.10190779658695383, 0.2545978916027854, 0.08830146984227243, 0.22486942069184399, 0.23481609179608284, 0.26923675931269125, 0.10125963257685786, 0.31305138081792866, 0.16779332692104001, 0.16833495108350632, 0.07598738786914656, 0.23091256738670413, 0.13280313431976304, 0.13838512672772332, 0.20626059342776576, 0.14779930543755332, 0.2401559084894196, 0.17841334334544598], [0.05075451241986406, 0.016426246598242752, 0.040837059909057234, 0.03667314604465519, 0.06744930730952371, 0.0578863658161173, 0.054687795514661464, 0.038483270083463965, 0.08082452831008742, 0.058810968823250265, 0.013929263448282598, 0.09530909825116397, 0.05178563229198899, 0.07891630288213491, 0.01999027531353697, 0.027695884515020638, 0.023583514961384, 0.015934398998656583, 0.009371658914812632, 0.11646771893626261, 0.07548946136188123, 0.006682827717609584, 0.032063104707988045, 0.015395331654637573, 0.049071160610765226, 0.04688057432612104, 0.047301275340179284, 0.019134143329856378, 0.01576582613896819, 0.04337888984610477, 0.06508597968927314, 0.012711073523537527, 0.05361033115355719, 0.02104741153157046, 0.02199452986279803, 0.045713753469528697, 0.026319040653986797, 0.011918928076122558, 0.017884435590296503, 0.06741104887858515, 0.018730056847655968, 0.04975771711718652, 0.07656779906321919, 0.042086376943775726, 0.026580878015187, 0.04290878382180968, 0.013921105569498915, 0.013641573492467645, 0.5287158873773391, 5.159081230240484, 29.154224395751957, 53.77727970000237, 73.29679012298584, 83.09628286669331, 66.46648453127953, 61.062894021311116, 47.3231529420422, 35.36727836055141, 24.416960247101326, 21.585450249333537, 25.060446646905717, 44.122671465719904, 26.902650556256695, 37.72417176154352, 22.765646326926447, 29.423742217402307, 30.021048591982936, 29.726845333653113, 32.710643314546154, 25.966067006511075, 22.439764045899917, 13.688518847188643, 10.55604930846922, 3.9897123652119793, 2.0112914039242655, 0.8269814954650018, 0.7846199588910227, 0.4030251593118714, 0.29677320752413044, 0.2141805176412867, 0.5150305539850266, 0.41345921555353754, 0.12992970705513032, 0.08890262669733456, 0.3315293296210228, 0.09921816913711448, 0.025369783022230672, 0.261519986294931, 0.37832890547090964, 0.18672533603685518, 0.09064792820643033, 0.07024751240087133, 0.5055764774161001, 1.416765989795808, 1.6873432191148883, 2.4912723322068495, 5.7138911754854265, 13.434467911720278, 22.85292886918591, 45.265132381070046, 62.80681902362455, 90.53035889902424, 78.22775071667087, 56.85673252228768, 59.32657057239164, 54.58742172487321, 40.02247671927176, 33.55018154267342, 20.46341311547064, 22.961445162373206, 27.657159643788493, 40.25846219831898, 52.87117688886581, 66.35863504102154, 69.14927590277888, 78.29709822131743, 78.57864595228627, 72.21506318738385, 64.10076971976989, 36.474237903471916, 9.321142050527758, 0.8782754333749895, 0.04946963741414009, 0.019626239908017942, 0.01258775826558591, 0.011162200788666886, 0.03237726970485622, 0.07799314395073922, 0.01683796140094919, 0.029885289109041615, 0.04358502878477016, 0.053849507633957176, 0.07578342462018614, 0.06254561681060061, 0.05223683126631284, 0.014319007806930573, 0.050532718474466, 0.013381759560997448, 0.030248612052791064, 0.05581495216897419, 0.0487723250332619, 0.026338731028860616, 0.09293101577749176, 0.001967157100631495, 0.03430293895484459, 0.028990209215290608, 0.04119500683079805, 0.019044166303149635, 0.06097998973282595, 0.018591343222426313, 0.06698194004955792, 0.03855612887550266, 0.0634933480121676, 0.04563167097888166, 0.04267022404218874, 0.046151990236173716, 0.02570783464057792, 0.061200626885458353, 0.12745374918825206, 0.02907815036333857, 0.09135700386738585, 0.044624924194067724, 0.06133304901360985, 0.01685809419159928, 0.031238501072831215, 0.038958888110374255, 0.04074538216715859, 0.014932064880286495, 0.023187617959094145, 0.023708061705673897, 0.024817939246854475, 0.05548664135858417, 0.040516574686813744, 0.03701537284218977, 0.030832999243190697, 0.0676574150941545, 0.022059088092177145, 0.020170733069760666, 0.045699634469084205, 0.05106375913225836, 0.016109854200734727, 0.044117689718522375, 0.09430587547080171, 0.06199179269794015, 0.024270284057204283, 0.018051823886531978, 0.02306137816049159, 0.0543104206031609, 0.014112217693529544, 0.08442033052204118, 0.0209248757680818, 0.03837273508730916, 0.02246673879844527, 0.06027089491967232, 0.06667064022152655, 0.06429238154763176, 0.03564473046290298, 0.03521535350310226, 0.053981450957156, 0.02636626805929888, 0.03135568188172916, 0.017620422539391348, 0.06448247094428347, 0.034319268118950634, 0.027078321887060042, 0.024603465271572915, 0.043467093379266804, 0.015088823706572576, 0.05399892925314846, 0.06453284122530492, 0.05188086085141667, 0.024006956654991356, 0.07706469135178674, 0.020103123895223105, 0.04498381723439501, 0.06837759136913285, 0.051017188647341345, 0.010157129821187307, 0.014884417084225965, 0.07051183571738583, 0.011879387405520726, 0.015108875100380711, 0.022704061346068498, 0.03427300789964295, 0.9467613036113401, 6.260870598977612, 33.838993503201394, 63.30755664456276, 84.72464699898997, 91.63043468229233, 76.19775941295009, 71.92486270781487, 62.340445287766, 46.99279915901923, 40.3787338349127, 34.90162634080456, 34.15614458822435, 46.012449802890906, 32.527980496806485, 44.757420785965465, 37.94624459358954, 40.518707536881976, 35.34698009490967, 38.413900944494436, 39.081676621590894, 31.782963545091693, 26.649600805774813, 17.131706783848426, 11.342672801786854, 5.863411436157842, 2.3349935825793975, 1.2105227405986478, 1.1897126056494252, 0.5145409931578945, 0.28196730200321446, 0.40745296365311073, 0.35279706420917667, 0.4090533213269326, 0.2778447070910085, 0.3389604744170943, 0.11564182252773356, 0.19680866190502722, 0.034469754600356665, 0.08887176867574455, 0.21657789786977155, 0.16671325020011396, 0.15302722732866966, 0.19852146596437503, 0.28237614780664444, 1.001480144839133, 1.7895987966368276, 3.0785271429246475, 5.66459825923366, 12.647152120067227, 21.8163150741208, 41.38108768770772, 55.50183996077507, 70.07752049353816, 61.929180852828495, 44.9298442563703, 51.85342773314446, 48.65123610342703, 40.381310832115915, 41.01514624011132, 35.0904570856402, 40.096127063997336, 43.40747041086997, 54.047327041625984, 66.64470918716924, 77.16969136268862, 80.61423055587277, 84.44076938013878, 93.17295382099768, 84.44141264884703, 77.27437157784739, 49.29018235975697, 13.247818004700447, 1.8111145904948636, 0.04127064652200188, 0.10900413031659781, 0.019581017737847664, 0.011432789746792087, 0.05654160188691271, 0.04802157801966514, 0.07978856293184143, 0.06730022659945874, 0.03389598921902719, 0.06411477172326657, 0.0531184988757295, 0.03773922633920466, 0.047053208409418026, 0.0011897842224214167, 0.04394794378669993, 0.02534230153316692, 0.039209743601179896, 0.07087927446850846, 0.047517955648682775, 0.02040637980004953, 0.04092856528117292, 0.04575141435188632, 0.05330733571862502, 0.021576607832685116, 0.01721044867149284, 0.010853250935343246, 0.05719799368131546, 0.046034154422100515, 0.008862315782255704, 0.02077315396989786, 0.04062410661830537, 0.03578415846512203, 0.11575602325460604, 0.0590154683337577, 0.0702729924852329, 0.03554139669323641, 0.009283742664622204, 0.05076625271730366, 0.022085828391174157, 0.05285719394563668, 0.06570189905863616, 0.019193248928434426, 0.09334985136745438, 0.05054563854730899, 0.024275518352946928, 0.029077047196727608, 0.04648751759481046, 0.022780848253938942, 0.041787177474508365, 0.05337496979102012, 0.07175577864531549, 0.036272007085743456, 0.0816125416707608, 0.05889479416392504, 0.12061254572003119, 0.10283942845079208, 0.12031258399327917, 0.0928675760364821, 0.11227619143262987, 0.1208119047805667, 0.18852774173982684, 0.16149769296809552, 0.20252217628782798, 0.25038868278986026, 0.11970666207132802, 0.18660806329740634, 0.1323301209917953, 0.16605752490220532, 0.07377953779312872, 0.13717490699022047, 0.15796302457249936, 0.11623911063877806, 0.13016613711032177, 0.2616674735421135, 0.24960914236162943, 0.19912287562845216, 0.08320237329650311, 0.20697100208170954, 0.20956131389304516, 0.22036626394237244, 0.13898587755618558, 0.14644126137418134, 0.14012200126965202, 0.19947806463366557, 0.12722453568130732, 0.1016649620367154, 0.18645122977754763, 0.15076745181314408, 0.16123751418725138, 0.12677029150748445, 0.17010161112393105, 0.07887307254056777, 0.15366767683336813, 0.24328468818097349, 0.11656085990609662, 0.1308768828429522, 0.25473250857283997, 0.21042648762945207, 0.20566270776814033, 0.18878899304376495, 0.14521084755899447, 0.10496341488173894, 1.8587189263874486, 12.717997970119601, 47.53814589592719, 81.02072146631058, 98.41222055496709, 103.93333312003844, 86.6910723716982, 79.70653134007608, 65.52511176755353, 53.22709668067194, 38.55584759866038, 34.093253304881436, 37.44321238610053, 62.94001094756588, 48.59040406442458, 62.20385266888527, 40.49355337696691, 49.8900814210215, 50.664631858948745, 48.61347544577814, 49.682764545563735, 38.3443533989691, 34.33385541362148, 20.811464632711104, 14.631567443570784, 6.877319120591687, 3.22987130572719, 1.6971104111402266, 1.3434055327407777, 0.9035250172019006, 0.6639625817056626, 0.5350097593280577, 0.8629306309646176, 0.7842687841865325, 0.5153184804704882, 0.39650878478442475, 0.5514447967852316, 0.38491186836073477, 0.1526101384191744, 0.5034829736236603, 0.9291540290559492, 0.39964772280185457, 0.298194024832018, 0.2868794577737009, 0.9713727668408425, 2.2952979706948806, 2.6787942311456128, 3.4218607842922215, 7.519072323076188, 18.38726532074713, 30.165603622313473, 59.103317106923754, 80.7009070919406, 116.95936756749308, 103.62948279226981, 82.12434307221444, 81.58397382305515, 74.24551733078496, 60.16950361190304, 53.554379247849994, 36.86442744347357, 41.99700570875599, 42.22342452695293, 61.5192461013794, 77.5041675567627, 85.74943680917063, 92.30180325046663, 99.67559245324905, 101.4359914102862, 97.31689868434783, 95.27179056598295, 71.42756892788795, 24.835082946285127, 4.172383027691995, 0.15144473482524196, 0.24828344253042053, 0.06695057640993787, 0.13330745000031688, 0.1938359190018908, 0.1669374228485169, 0.21149295862884293, 0.27592317471581124, 0.1269883584351309, 0.12035856459049449, 0.08923943725324447, 0.16601076289530725, 0.1577336425262113, 0.12496217078859768, 0.17935100432124831, 0.10326429315271879, 0.1197333602354892, 0.177838379036515, 0.16221527220501056, 0.14746823288019628, 0.15680114498301861, 0.12055810751213182, 0.1742269792744229, 0.10584813918197349, 0.11778396524248586, 0.1287784454442801, 0.20750000111518369, 0.0861425344802199, 0.1708213813723095, 0.10562355284609141, 0.11306819611138876, 0.286110611932893, 0.2024958381849912, 0.1047564255854776, 0.13987021881245798, 0.17956549361828836, 0.16445001196717063, 0.29954592487023723, 0.2617668198241342, 0.17638134109156747, 0.13883261400605404, 0.0827145285063213, 0.21901418004305134, 0.16754362822300004, 0.08281302443074604, 0.12447214264783169, 0.12168169036627778, 0.0780783482496777, 0.1361397843086912, 0.10272684416943982, 0.1474732124517041, 0.11626685068251626, 0.14253672572874254, 0.17252379727940406], [0.07785207652036222, 0.04907931178627957, 0.043176194472659024, 0.032670623923261324, 0.0034835028195483314, 0.042527183935406714, 0.04158227193740107, 0.037619030974324674, 0.1099304378693623, 0.08898018543878872, 0.05586991514710169, 0.023583670094188665, 0.08414281517147057, 0.04565595596608135, 0.014867008693756597, 0.027571814660463604, 0.024014010409554167, 0.016681719684011994, 0.018048014514328494, 0.02035956991265618, 0.041562254059939616, 0.05755029453505432, 0.05982997684529232, 0.01745111519290555, 0.0848854301617511, 0.03521802331951838, 0.045301364509448896, 0.0297467612601336, 0.016090803509277683, 0.022101581074117173, 0.04109281453213865, 0.023937279043058236, 0.027773941213625575, 0.02404365226656439, 0.06722741760313511, 0.023723569240481145, 0.16589545134094455, 0.06004152819514275, 0.024046751092218106, 0.0867278486370079, 0.024297937916050998, 0.0291436413047655, 0.05046823685387931, 0.051532271693670945, 0.020118618023491675, 0.03373507245053207, 0.9614580569248047, 7.229315071336686, 28.19832709527785, 64.01714478769611, 80.91873199709, 79.92772163883333, 74.07092478967483, 66.43145776564076, 49.65098550242763, 43.01574722413094, 24.587449989011212, 12.38376300181112, 20.36647762021711, 39.37514835788358, 53.75135675553353, 45.692278492835264, 56.52036966816072, 37.10157786646197, 47.9784123359188, 32.31971833013719, 20.952397354187507, 14.206906153309731, 6.158489873332362, 5.402960969555763, 2.718374623406318, 1.4077694209352618, 0.19712709401163364, 0.13361599957270007, 0.08136912489369993, 0.029738286412471247, 0.14573734914583547, 0.07480239540699028, 0.050706241219755144, 0.014726603929434093, 0.08163147936424903, 0.0922987480918246, 0.05943710397508356, 0.013589666247548116, 0.03497305138397121, 0.015080014653053257, 0.11569269076590577, 0.0517946721294955, 0.06737948605610479, 0.011371890544861315, 0.10129192318286627, 0.14590006622095264, 0.0869788573453984, 0.010842899172266406, 0.0887166818363532, 0.04451443516318837, 0.15244014350877655, 0.2009608431328689, 0.7941134430227742, 1.7902892563612232, 13.335652620561662, 19.60116240286058, 36.98873127660444, 73.21704833738266, 73.55725119190832, 103.09204747599941, 87.86761868384578, 67.54553641042402, 56.1654971491906, 26.375921349371634, 19.635024224558187, 17.363103089794038, 20.110027174795828, 34.287100761167466, 42.684048068138864, 71.99535554455173, 78.48855695416852, 87.22659357132451, 84.54327660222208, 86.56540747611754, 69.93252615774833, 53.947185008756584, 17.420026486919774, 0.6820136356738307, 0.1673294453611297, 0.04137158626690507, 0.035243503403879946, 0.013270973671047438, 0.0882986736213488, 0.017342891867062258, 0.10346347601303171, 0.05749763365113928, 0.024094087665059397, 0.03930716700251064, 0.0081808049224257, 0.01903674865682279, 0.031335326925581025, 0.04472820433757959, 0.07044310996969862, 0.02907508409642164, 0.04459658660174859, 0.08445157158759334, 0.03225993950881305, 0.05385249537686187, 0.12307180287016016, 0.038086589756271536, 0.04445307918133275, 0.0520349249634291, 0.024942441941088727, 0.038084781788770235, 0.057155923962953596, 0.07924881568478961, 0.029564844106414148, 0.047677175532425606, 0.030656488754996852, 0.02683804224004909, 0.049308115436184796, 0.05525644342865675, 0.05472414255622895, 0.030143981679312648, 0.04498080267841297, 0.014794414202051779, 0.018059517324511564, 0.019613478798419237, 0.03585163548949265, 0.024104722880668217, 0.043986627396436474, 0.032583355017366915, 0.028862645999798854, 0.03700401558871231, 0.020234234097804275, 0.04222168722340176, 0.01524433572476189, 0.13779453422513702, 0.028568263308355407, 0.034177725714060574, 0.036176349517078175, 0.021865239119037025, 0.05769901518379489, 0.014034045124126059, 0.05340190927287745, 0.02854300538949188, 0.02297097403976706, 0.005640861955696658, 0.07495205834387772, 0.021278971182783286, 0.030493597394876906, 0.039023756605362704, 0.02997439088029487, 0.04290817095147025, 0.038683590584344445, 0.031568999064245054, 0.08040244450732585, 0.036281518067323396, 0.04661668001884415, 0.01629272704913972, 0.02462486402251788, 0.026543885544543306, 0.04116843507114438, 0.030969046882443854, 0.03443262231866679, 0.03354790950975111, 0.05579722489440634, 0.023021744601728938, 0.05142248363324231, 0.02002100501539967, 0.05359754514610095, 0.02958318233610161, 0.042282686974372596, 0.07544191028442114, 0.03184815384297362, 0.05057956475103575, 0.11086957739485849, 0.048557088800495675, 0.047189181355098565, 0.047927414322452205, 0.018532141862857728, 0.07508063854108896, 0.04449020380214338, 0.06882970581852621, 0.014741545516787278, 0.04614905611942372, 0.534661342540095, 8.315245316874597, 33.102423375652684, 73.15534945457213, 91.90285113550003, 88.83770711960332, 88.33919740492298, 78.3912507949337, 62.57307321794572, 55.21684446642476, 34.19863170193088, 25.83397726858816, 27.97088453846593, 33.75738466939619, 40.38117354915988, 44.22181721656553, 51.265280092916186, 34.54285106351299, 32.22776228381742, 30.803886998084288, 24.019043637860207, 16.43849845855467, 8.7747254871553, 7.039473825885404, 4.11903977394104, 1.7574373224089224, 0.49109134823083883, 0.1764817445749237, 0.06451184275530039, 0.04922697906412425, 0.10897320334709461, 0.05670826431483992, 0.06552674837650792, 0.03643225735774444, 0.06335137276760032, 0.05165560801904048, 0.0416407474286614, 0.19030491250657267, 0.15034129242262534, 0.21450823473353542, 0.29264212435772347, 0.09754870267164323, 0.08152716883247899, 0.20215494438044487, 0.09330968537758436, 0.022579554821394628, 0.04377980280907885, 0.0034708130518875777, 0.022163096019217086, 0.10741981452391033, 0.08067705638466344, 0.2538665993920257, 0.5348800759642355, 2.112335091637027, 10.633087600431136, 19.601621320170743, 36.35202077127273, 54.13087744866648, 62.13157907609017, 73.55627844410559, 76.37810999347319, 67.13503683767011, 51.401947236830196, 30.407015700494092, 29.696152787054743, 29.278520384142478, 34.21419566677463, 52.48890269187189, 54.05339887065273, 84.89421890627953, 87.21582274283134, 95.34337382162772, 93.35000176583567, 97.41141211601996, 81.16052258399226, 67.25814434789842, 24.09339216447646, 1.0165291760236987, 0.0860569164938023, 0.019200915553336664, 0.04026592603974766, 0.00311632142608775, 0.04092057881456229, 0.07904752608268492, 0.13023399717865453, 0.08203044263345581, 0.0749381308654143, 0.03315662244154561, 0.014276288829052882, 0.09033515748958434, 0.04653824793715631, 0.06150646067614998, 0.049712138716131456, 0.09061340828456226, 0.02939862217904339, 0.06421878348074614, 0.03250406108676426, 0.05177625154535617, 0.04382310975943843, 0.014510318156211607, 0.0485072854245382, 0.05310292047778926, 0.04750144262347491, 0.009032894834695805, 0.006958861166851656, 0.022140776047543175, 0.006025683720626178, 0.04537468295424216, 0.05494910427519391, 0.018474717827273474, 0.024347398467662356, 0.0747166318638671, 0.051997122354805476, 0.025759807960580916, 0.05210915888329187, 0.025428708590146516, 0.07498198173820012, 0.008960947687287004, 0.021118653878088922, 0.0378739275789309, 0.023395773624220205, 0.1258127965153225, 0.004225322035997505, 0.1008596733933495, 0.017191729313063047, 0.060841036705119964, 0.06671310447516941, 0.09525319681532922, 0.03615831197690099, 0.03413151146002835, 0.16872223917274706, 0.19416124589981573, 0.12597851665510287, 0.20773937294800437, 0.13299609654613082, 0.1142538091047637, 0.10158665252909546, 0.09224425625777052, 0.17565665255871513, 0.2956425230349264, 0.15670774354329034, 0.15387439799885597, 0.16210676351141545, 0.14834388669940735, 0.13766440653031872, 0.09075350278327543, 0.12733918840005515, 0.08710955960615989, 0.057745164320353544, 0.05924447499696286, 0.15474632863075505, 0.17556662190585368, 0.16100117606261086, 0.10574061874180071, 0.18817163342910428, 0.10578406358798666, 0.12469187964715304, 0.10736299378256645, 0.15108540894523745, 0.18320785865427988, 0.1371464698064712, 0.13596006008165498, 0.16262667674210765, 0.21826514523596535, 0.10422829223135788, 0.07873593514124233, 0.313902810936974, 0.10978799914160084, 0.10363316448825984, 0.242876332673815, 0.17164771445095542, 0.15208189015186604, 0.1710744968224918, 0.13442619883966062, 0.08790191668536394, 0.14333016299191984, 1.856921500255985, 16.62273806910361, 47.96419766641433, 92.08677891762026, 101.04242078719601, 100.28852555059619, 92.62362587836482, 85.99380831564628, 68.09442504759758, 58.400330312790416, 38.83594405266547, 25.872224300138413, 33.65105705876505, 51.76131871438796, 77.38892832110005, 67.23829715482651, 78.03881799021076, 53.70061305261428, 62.64267567665347, 48.513776640738214, 30.077826861412298, 20.262809376562796, 10.168996684012875, 8.540082439299553, 5.986923931106444, 2.472442258750239, 0.8324753264746358, 0.5045325753669585, 0.30691906148868225, 0.1232127324047108, 0.19186391675424194, 0.2219748494005011, 0.199547870565326, 0.17183756636035058, 0.22629881818448344, 0.24647809504981966, 0.3436770326187534, 0.21995487472703382, 0.30420226856104793, 0.31014033863621376, 0.5325520266928981, 0.2815229403636148, 0.15922789702252035, 0.3016112979140974, 0.275003501484471, 0.257254745811224, 0.29281648596928966, 0.15550932155982142, 0.17680822060473506, 0.3522881366793187, 0.6424742444388328, 0.5187500027879592, 1.1961620853793238, 2.9305066985468713, 18.387722276872207, 26.0786880600837, 50.10127359820951, 93.67252257562454, 95.8748314457555, 130.1044459496775, 113.74158059397053, 86.63660633948543, 79.81225490570068, 42.50865536351358, 36.15576890207107, 34.85388325106713, 34.108268137901064, 51.74449959108907, 61.56573403266169, 93.25675133735903, 99.95324919300695, 108.60151844639933, 101.60482591198337, 108.65431354891871, 101.29817501191171, 87.0707421148977, 36.1919213879493, 3.136259283750288, 0.19091433545033779, 0.14446533675636017, 0.13537406410661437, 0.11444165386379727, 0.27120937443067955, 0.250991027081205, 0.20563721236202026, 0.21974954784156817, 0.13643391610633943, 0.11673224909651665, 0.12784529672635178, 0.20844935259271055, 0.2642181786077638, 0.13471608651020836, 0.3368065416091873, 0.21271221820385228, 0.1311203149417716, 0.16992029343401233, 0.1429875684721816, 0.11000100988894702, 0.13136118830692384, 0.11289596422425202, 0.16998568669922892, 0.11557732558538837, 0.20809448534442535, 0.14123532620649185, 0.09966187194109925, 0.18920421269872498, 0.15270527121761154, 0.1271035091110295, 0.14188141411831304, 0.07946511294933097, 0.17995805239244816, 0.10515459212324313, 0.15852544036123062, 0.08123792467578765, 0.17899737813540045, 0.09342253012883087, 0.16618964442562673, 0.16904021162659894, 0.19208603628700782, 0.22233426721105654, 0.13426887502353038, 0.26591720840623306, 0.13641781293817107, 0.25842931181673084, 0.1763574697918469, 0.13925520342684564, 0.10918585403311638, 0.15183176244458846, 0.15879533313695463, 0.1650307525790507], [0.02316440932542807, 0.03038672812943978, 0.12104291093325424, 0.04436289148044683, 0.07020722383693342, 0.05124423412546035, 0.03548782033425185, 0.005791241663598246, 0.011666239719958076, 0.06403949592382678, 0.03344158799717984, 0.03858406810210117, 0.09654201717386324, 0.023791320141284697, 0.0378883185405885, 0.043370753992348916, 0.05772792351161761, 0.05586638731221038, 0.012014447748961469, 0.05755566481140353, 0.042388996995625, 0.04716681158770958, 0.020997905014683644, 0.013468841732960316, 0.06321345778903173, 0.029567360705245408, 0.023745801112043764, 0.0320718840756003, 0.05642458578691848, 0.04072835203260183, 0.07155248955372842, 0.06425012413772845, 0.05069469627473624, 0.01579008622831034, 0.01393526670477924, 0.045374154353574406, 0.04544060482012649, 0.0545982436667527, 0.06713886549996753, 0.06909308684689384, 0.05698815836841541, 0.05481716478243471, 0.024796979081246163, 0.02292798118545644, 0.16517800999985588, 8.086067601557701, 36.2409157137717, 62.62816682938607, 80.22408023957284, 73.37558269500732, 69.25436404443556, 71.59391664689588, 58.36076144249209, 44.44838508482903, 20.114388850427446, 17.636549165171964, 28.153464986431985, 27.862662423041563, 69.0874985725649, 85.86191469623198, 60.852631445853945, 52.95944982959379, 32.17410033748996, 26.376492054231708, 17.141783352821104, 4.177512507284842, 1.4973862637435238, 0.8163934861940723, 0.4118922899567312, 0.12383330958865343, 0.06758762448425255, 0.031090387548770637, 0.07450622581546346, 0.04064743399559971, 0.04961986725609149, 0.18731376817149503, 0.012196656016092147, 0.0585955985250973, 0.009227962845245437, 0.040004310844045494, 0.030858739797446518, 0.025667241556690108, 0.021992160735892195, 0.06804144730971706, 0.014703964116051795, 0.13684040235896267, 0.15800065481134, 0.13779553013943857, 0.00918480240920138, 0.06873573747373397, 0.040567554007734985, 0.05996914437761711, 0.053104188353303945, 0.09332439426573054, 0.03238203094130562, 0.09304769862923892, 0.051162691726799936, 0.07243409587611115, 0.0070099721591348856, 0.03433469329930602, 0.15427783522154057, 0.43682161838777606, 1.7762421456075486, 4.1573745685239, 12.515776253515675, 22.176708329108454, 42.22784111576696, 67.54840758539015, 79.52596895156368, 85.09360867161905, 70.57457893125473, 38.91215962748374, 25.38470506668091, 12.456666135018873, 25.14321061872667, 34.80462612644319, 54.36661974076302, 66.20714526022634, 68.77520730418544, 78.30721009162166, 75.85843516934302, 86.8459197013609, 83.13407098093342, 48.885381990863436, 18.356151119355236, 2.1967935273724217, 0.22238527334505515, 0.03354712426962872, 0.0595173440242727, 0.06350093228261798, 0.011557047292890569, 0.12241842180129983, 0.07459681571250962, 0.044185886865541826, 0.047044547785434036, 0.016907978006788803, 0.03225443516707709, 0.015428617217337653, 0.05319135000688895, 0.028479054284792756, 0.04384088299928173, 0.038389447295377334, 0.0667146596336557, 0.08295727112600881, 0.009479706998043244, 0.007037372251356682, 0.01631077991107539, 0.032096061810490586, 0.018044224294323116, 0.034751586856380585, 0.026910106215866345, 0.020414891036888285, 0.04696056156629517, 0.04531898836214696, 0.045874911555719954, 0.02111537693699281, 0.058070774670810475, 0.09573456816255085, 0.03253945817930564, 0.07555632551591243, 0.06033540335333636, 0.03663301069830214, 0.05087491079804398, 0.05118292410888019, 0.03065380361682225, 0.00973833445084071, 0.06309020573333388, 0.022475476031221693, 0.06070712836639536, 0.10730246517566905, 0.010894454974350671, 0.011242899533000686, 0.011943423737501426, 0.021976614896688732, 0.036378493307218436, 0.04271545770367788, 0.03363066615777151, 0.01062319856212144, 0.017643412837999004, 0.11401701898824786, 0.025049753622302127, 0.026002615697741992, 0.05712093289701208, 0.02575113584527806, 0.036248331138443564, 0.028160181677629872, 0.08298528696139974, 0.037826372671031186, 0.03711706718369838, 0.050336377800352154, 0.09877675693602332, 0.04021178660613876, 0.03646522595156585, 0.029545552097260955, 0.027701408008954702, 0.05616439168431586, 0.027897559076307282, 0.04570156884109301, 0.031551639511880857, 0.02778982413151572, 0.05022460557219963, 0.03232750846373458, 0.032657546802393855, 0.0524984119880584, 0.09204735633947196, 0.02359630862971948, 0.023717948070336736, 0.08030764112669615, 0.02294975148904468, 0.0022498530010888053, 0.01160490289030056, 0.07187483636962791, 0.030608782544732097, 0.032859636966379425, 0.06713292831855436, 0.10862874723370038, 0.02560000393479582, 0.09913006136494298, 0.03377368711235543, 0.07346325839358954, 0.5961075389096814, 9.966388613946977, 41.87179188574515, 72.91094656913512, 92.09263109391736, 87.69214753181704, 81.37059688568115, 81.06921765112108, 63.92558882313391, 56.8576229003168, 33.5598619522587, 32.540708588015654, 35.0299859046936, 23.63527697901572, 43.36419882312898, 61.52622399791595, 55.520090749186856, 53.08705629840974, 39.913250477083274, 27.466418704678937, 17.789374513010827, 5.378990384840197, 1.6618386199397426, 0.9629738691353029, 0.5200530264166094, 0.137261658786766, 0.09411130445979296, 0.05867583857428643, 0.12710494935632716, 0.06506556344609107, 0.04821380480162559, 0.18779540764949015, 0.12003840112517919, 0.23322809878135883, 0.16016678373900153, 0.08241025370455558, 0.03441087691293609, 0.282553359265289, 0.15548780981090762, 0.3803671283587333, 0.8722650752432886, 0.8570047263656894, 1.0297839680025656, 0.8066976322762428, 0.49857345319563345, 0.06006579403014434, 0.07412915733913261, 0.04736547350823399, 0.10693384664914302, 0.17486341447839815, 0.03850413065764212, 0.01496152670663451, 0.08408365786195764, 0.11430152872156714, 0.039659582769438144, 0.02232115527975463, 0.1646244501875293, 0.685573676901479, 2.165686925572734, 4.722208621040468, 12.543210291093397, 21.730101377733295, 38.30163878779258, 42.66232990449475, 61.8923419521701, 52.74495501672068, 50.59509215816375, 35.95464544911539, 32.40414930928138, 25.553610171041182, 41.35014018704815, 51.4132240510756, 67.79699956217121, 79.8581309472361, 80.3271601277013, 90.3442189001268, 85.04209226177585, 101.07909494830717, 95.42890502560525, 61.91149488572152, 22.006357831339685, 3.1842818423624966, 0.13225478390532155, 0.015609491533870179, 0.04103176115501312, 0.0355872662077027, 0.060040310115343144, 0.030263265399562738, 0.0897634567152108, 0.03331919779039679, 0.03426681790921477, 0.040675978431658405, 0.08332483245119934, 0.037248830476235, 0.03737215147984605, 0.037826805510708404, 0.03608706963038252, 0.03663445860447903, 0.044931209976634676, 0.04555037755879664, 0.005852091548618891, 0.009412408089115015, 0.015471976836242024, 0.007284113850008937, 0.04818387374642396, 0.051164978499253916, 0.041417229785433704, 0.029826127969089056, 0.05700830648082399, 0.021491190944347652, 0.017434487254509044, 0.016144002569959532, 0.027059286517361482, 0.07161145534126029, 0.005081070975715956, 0.0840759203739224, 0.06721743547748174, 0.017129630225920872, 0.03283364360310859, 0.027265222442726937, 0.03358077468170274, 0.014842687317380502, 0.007021667448908932, 0.014807274903080639, 0.06211176589732209, 0.05138462356802437, 0.027083734298245083, 0.005598874112981702, 0.08963103841749892, 0.03514447504834783, 0.04769755730165109, 0.021064242483266903, 0.18174191876765222, 0.10959677593482119, 0.19776527589607626, 0.22490689771309977, 0.12638570004773717, 0.06100977523132198, 0.22360719890604097, 0.09597426175229973, 0.18473094870005885, 0.10766555254738178, 0.1178470602439296, 0.07893940043305198, 0.16638280583485482, 0.23606487639969398, 0.15068293699333746, 0.20405655846961085, 0.1801444262626671, 0.17403302113375357, 0.07544816922276251, 0.18861152111522614, 0.26906086552527647, 0.14776055671034322, 0.08627387259395854, 0.15171029154331456, 0.20061189008335914, 0.1337527003019087, 0.3115839240772109, 0.17644238297737416, 0.13158998812638945, 0.1531986011973312, 0.22339810286798786, 0.12097298242752591, 0.1097113750274143, 0.12343814611555108, 0.15188416285860926, 0.1320108155449552, 0.16099002182243333, 0.27590399187418724, 0.27163737243221653, 0.18496788437328032, 0.18266882386899766, 0.17010606975565035, 0.09310043612194639, 0.1842290078920703, 1.8718766397045505, 19.308406499124345, 56.2022929037771, 90.93968176072644, 103.91999706145256, 91.91599107557728, 87.4890079805928, 92.80505903305547, 75.24727498331379, 60.642863089038485, 31.42557482565603, 30.174821192218413, 44.33669167180216, 39.71293895475326, 91.88836974482383, 116.05308824969877, 86.48543819304436, 74.01558014654344, 47.96553519464309, 36.41652022638629, 24.421672974863363, 5.668819219835344, 2.2788553949325316, 1.3688374454936674, 0.8158164687695042, 0.5284589721310524, 0.2831004379737762, 0.16801973654618188, 0.18104545291393034, 0.11291179926164689, 0.2092333669744192, 0.24541159340691185, 0.16048786650982597, 0.39781600657489996, 0.25541402039027983, 0.19564843706546292, 0.18596985076944675, 0.23934681238907002, 0.09673552332265724, 0.6126254364367455, 0.8811974152922631, 0.8327344480541445, 0.6747800496316726, 0.5539724579261196, 0.500156190847197, 0.28804844665911894, 0.20027370823006477, 0.14250424360075306, 0.3072904915578904, 0.31216008348330376, 0.15789401537228018, 0.18780289998938962, 0.137312235911527, 0.1887553004968551, 0.2224585879594088, 0.2288973118148504, 0.3385376858134424, 1.5140672460679085, 3.2448415217861055, 6.012522299443522, 16.58730729933708, 30.845893621444706, 55.71929616312827, 90.6290457325597, 108.41236606720956, 113.242474679024, 90.09946300137429, 56.530944378145286, 39.99438078172746, 26.322159382604784, 43.69433687579247, 53.88450945577314, 74.12016622481808, 85.42986562175136, 91.09801999984249, 98.14811952652471, 91.80030468971499, 108.08942164144209, 111.56242939733691, 78.85820111920758, 34.206284246137066, 5.477424715795825, 0.32199591698665775, 0.10496893837567299, 0.13640911017935123, 0.22038604433257736, 0.11431593117454361, 0.15600360148856718, 0.19414174130126355, 0.09955677233876721, 0.09446734382260231, 0.09932857006788255, 0.3438650612388888, 0.18592943197056172, 0.08107284038898446, 0.2173409214423549, 0.21545822972491865, 0.12561344511566624, 0.15106328432598423, 0.18371977392704258, 0.10347293719889657, 0.0874529738399771, 0.13935214419278408, 0.09711310507789736, 0.1430719300744034, 0.1428007196274496, 0.18687643921904026, 0.09307674868332763, 0.159549807168303, 0.10916560632927765, 0.16543638081319872, 0.1451679006699593, 0.1048032105750134, 0.17760979372166819, 0.24861080722222406, 0.19542970364132237, 0.1429000505877118, 0.11209754738956691, 0.10870382385027987, 0.14929380508199816, 0.2041014359002152, 0.053045754996879455, 0.0980379187592095, 0.0722265320139066, 0.17321779633000975, 0.24094540806066608, 0.10290996216598058, 0.06773714952531361, 0.17040639154372678, 0.09729600090894008, 0.14826513286079132, 0.1292249827735847], [0.0663573562257713, 0.007785689329818613, 0.0373823787536352, 0.01746933276374494, 0.1108154915874043, 0.07910065428023377, 0.082927523931909, 0.05296593629604867, 0.048734334733096824, 0.04520446587834628, 0.03542553738600785, 0.04875755102764215, 0.0612353574815056, 0.017689657735548193, 0.02384826728713609, 0.06410798418425745, 0.08804947288045961, 0.09467869215915281, 0.03563301314810111, 0.03787377436134604, 0.040925554555630496, 0.039179889154770685, 0.06511307621915495, 0.004843148006682074, 0.08263578232858451, 0.012973466298482832, 0.019051346462219954, 0.07723530679340325, 0.06282051214047017, 0.06587922543046937, 0.018284155371328516, 0.032648480151809996, 0.02860538792916604, 0.028989705512480392, 0.05613802676840175, 0.04188661951751959, 0.028646925216420527, 0.10431741123958942, 0.02990859541891804, 0.0879348048399533, 0.033641042818705884, 0.04016895846073185, 2.7060127835119925, 16.653507101920344, 35.87811216231316, 66.7748926531884, 74.10209978780439, 73.29410722178798, 67.75000172276651, 53.799127301862164, 55.18545373793572, 66.22260724344562, 71.61714492305633, 20.141643439569783, 29.921514526490245, 39.70694949550014, 48.70646699782341, 80.955060989626, 81.3474392121838, 55.93640719690631, 35.082792774323494, 20.735604032393425, 6.018560788323803, 0.8950093064096667, 0.08338743715637154, 0.09766227520641782, 0.04247089945560983, 0.023325877677228664, 0.08073129540970249, 0.07414431821915411, 0.04029590306022475, 0.02603438153352228, 0.01903909671631071, 0.1106102642933688, 0.03300918115963859, 0.18632163834427634, 0.14306917215787596, 0.17834450268457014, 0.07777518427540218, 0.14704887635044514, 0.10234104995165141, 0.09364485650533631, 0.052228469416619315, 0.3388632731812616, 0.48434177653924115, 0.5930570380822305, 0.8591285059528967, 0.7309663476001832, 0.5853780178773789, 0.26423111017192563, 0.2069031113698598, 0.15070964281837787, 0.060873687372452794, 0.008318292806976506, 0.0267345973876335, 0.031331552027334134, 0.0454117194749415, 0.06502658489250368, 0.020818485307597348, 0.03503827227940483, 0.08795990188035273, 0.06729633487280338, 0.045253353779234236, 0.21091742741484798, 0.4856672925093482, 0.6283231908755919, 3.6109376578561725, 16.678947594857988, 29.263376112907167, 53.287548249767674, 86.81026535649454, 71.16109878786149, 66.58440666814005, 48.25528067927207, 25.233148605592792, 16.934460593808083, 19.51121068769886, 28.217717332224694, 62.39983389454504, 63.74301425872311, 67.8637896814654, 69.86790118678924, 75.05134474846625, 79.7066568559216, 78.50566633286016, 59.29469347000123, 15.2521756387526, 0.6848748821404673, 0.13653536146927264, 0.07747477055677483, 0.030786392369097283, 0.045849343371247096, 0.09723217812396827, 0.022818212277225913, 0.08028143325880652, 0.027542649693186247, 0.11375274929788806, 0.047406160437892524, 0.019309407009953455, 0.016836996130164594, 0.00837399889039056, 0.034836599633337996, 0.0590037280363181, 0.04736820078124443, 0.1083014285071723, 0.06752518831842369, 0.050121589729021636, 0.13516991699655212, 0.020769342682474566, 0.05948766194764645, 0.022148806564209443, 0.11175546614873795, 0.018999564664198026, 0.048699098519019546, 0.015707043254928246, 0.057418408668449814, 0.02103178908357457, 0.018829270979509722, 0.02241955735840865, 0.026864658049758405, 0.07725356266863885, 0.03357188423134146, 0.04027400060646957, 0.004689763797702449, 0.0711227908369995, 0.0563819031982172, 0.07027339851183277, 0.04312967378345709, 0.033424331866685426, 0.05381432121559497, 0.10281615469965244, 0.08655385474764532, 0.05845690596728556, 0.09818403470900752, 0.04687747550046733, 0.024213076441458637, 0.029924325119223327, 0.018635366464995088, 0.0043512549206253985, 0.031235687614929293, 0.015720760059212486, 0.038206494007740295, 0.04280007594535428, 0.034827019703844865, 0.0031259954407540785, 0.037369416545956366, 0.01386506815305761, 0.07409054650774888, 0.019799251289617632, 0.029065839330395384, 0.04283409024919233, 0.05475380931109671, 0.07226534968902988, 0.06995483617027921, 0.06293141868926826, 0.043009528214292186, 0.02565304403223338, 0.08570974076827688, 0.04644747417900832, 0.030167272667430585, 0.04635472391401568, 0.020928914966662566, 0.06441822681095331, 0.08909020332559463, 0.026101877710091013, 0.02520777649366327, 0.024189609253118118, 0.024805637790010344, 0.012563390923934359, 0.06426882434396014, 0.09174380166035506, 0.008802672006910848, 0.045146905862155466, 0.05041263802277465, 0.01037162390627688, 0.21357261155161167, 0.055864521888114756, 0.0246871680381798, 2.7821790835549756, 18.918622924435525, 40.67912070981918, 76.19312317140641, 84.68238738275345, 82.09989886130057, 77.92154696679886, 70.30686147751348, 62.607644988644516, 75.68470554967081, 76.13186359405518, 33.59170767568773, 32.240370742736324, 34.56911133181664, 43.36506174456689, 51.67115126886676, 71.29289827039166, 56.37881525101201, 37.706340666740175, 24.753727105356035, 7.937808382895685, 1.4953135362555905, 0.19678379469100507, 0.0654879077187469, 0.07320141720194971, 0.08482094854116441, 0.04246608459300572, 0.31636391435900046, 0.46750843464847536, 0.4695430722448134, 0.4592453796536692, 0.5393624257656836, 0.8083109521577436, 0.6820214191271413, 0.7675331951149049, 0.4708266985272208, 0.46248004801811715, 0.8143126075306247, 0.48272526973197544, 0.570104553574516, 0.9854157713632431, 1.6237581665477447, 1.2662695492467573, 2.151737996647435, 2.9274340118131335, 3.7296092125677296, 1.126611598076359, 2.292973230923376, 1.692878909168705, 0.26223443989311496, 0.2704629290007776, 0.03215765911004236, 0.12916689798716577, 0.15941900531611136, 0.2818262805381129, 0.26507233599981955, 0.07140566114216082, 0.26476951676510996, 0.10362748777674091, 0.0489658848082106, 0.03863417791322835, 0.10662739615767233, 0.6553481987887814, 0.6110165292216886, 3.8573451195993735, 15.134818323196905, 27.743679285049442, 52.211026299384336, 70.78004052562099, 58.04179430007935, 50.45875841571439, 37.23392255844609, 32.25237711783379, 25.566624595272927, 33.781617072320756, 44.906749340795706, 79.3508586575908, 78.22119251374276, 78.43583245431223, 78.87793848591467, 83.49979277580016, 90.04511464026668, 93.73546877214986, 69.93793118384578, 20.50624735893742, 1.3520489657117476, 0.1307559482032253, 0.050202557561738845, 0.014563452099419892, 0.04661052067193293, 0.06208037927506432, 0.048750790301710374, 0.06585404412039826, 0.06517568092432714, 0.09493464213465491, 0.06424461596555288, 0.037569920907938675, 0.0270799076890633, 0.03840348585658977, 0.09337385290212209, 0.06192058482537828, 0.046931519173085696, 0.003438229656650595, 0.1200932223770407, 0.055018056018818776, 0.025557058960980466, 0.05760857467389396, 0.070449621717055, 0.03365578235036904, 0.02001535703217791, 0.06764849016983664, 0.009417825288349583, 0.013644123607645593, 0.05157448696873842, 0.011542463851641985, 0.014571577419466792, 0.058098146992345015, 0.04710392726044502, 0.043807945048977295, 0.014894765016863184, 0.014209994452915365, 0.06366508577259318, 0.11985129181055293, 0.00986928856300731, 0.02284794989522667, 0.07736090690858903, 0.03142175696519835, 0.05692535064994328, 0.07795434925825366, 0.039759024812449376, 0.07909120841612739, 0.0013838958200780797, 0.036197857435552344, 0.06205193059999616, 0.19716365172738032, 0.1640964777118737, 0.12154588595994058, 0.1124058977790898, 0.26603098778474715, 0.20244234992611795, 0.19923486236122348, 0.18895212380636126, 0.1297228786373331, 0.137595473938892, 0.1476613483241489, 0.27586246990869123, 0.1386177876303273, 0.09720502796793178, 0.14112957542942417, 0.16671073743172232, 0.20707100719934513, 0.14957914219027565, 0.21397011925376233, 0.1832207136096493, 0.15063692575260518, 0.17041281136053224, 0.09632651664076314, 0.10106102428248814, 0.2213879034764344, 0.11873795921283385, 0.10412064921711722, 0.14436667995347133, 0.2240749109055727, 0.14523585266884298, 0.10593743439042762, 0.19658666494632923, 0.10068126683754307, 0.1770278120473508, 0.14108092884623236, 0.14833215023240737, 0.20750400009414843, 0.16175394937876733, 0.12241564090213469, 0.3142627803308349, 0.07582475506370107, 0.19432615398639635, 4.51365472808961, 30.239873701526275, 61.34180591952417, 92.77090303359493, 94.8711596765826, 90.54126308810328, 85.33818414134365, 73.19538116455078, 71.16255006482525, 82.86918547845657, 81.1813425248669, 31.088045066402806, 45.958987897442235, 55.32418797093054, 70.33193326765492, 108.389522183326, 106.05870862160961, 75.71697881144863, 49.721952945955344, 29.955878411569905, 9.922965034361809, 1.4652741868649761, 0.2653888528866153, 0.3541654811030434, 0.21247158998683577, 0.2165831685546906, 0.20539220212207687, 0.34363002546371957, 0.43356415124670156, 0.5171076328523698, 0.376748496726636, 0.3464572269830012, 0.3126643838420991, 0.3333879814993951, 0.42882044288900595, 0.4635806099301385, 0.3150907068723633, 0.4823686098379474, 0.43031774641525367, 0.26769269377954547, 1.092804812135235, 2.0393124487130874, 1.8931282864462946, 2.174468376944142, 3.2474180286930454, 3.5208788129591175, 1.8957730671090467, 1.2020664782293382, 0.5772675369535724, 0.43695461125143115, 0.32227400690317154, 0.12046203242554782, 0.20272143575693333, 0.16910909825275022, 0.3535625392631177, 0.2651392614408847, 0.3129030968393049, 0.25680281522293247, 0.3574234385403895, 0.3655128367245198, 0.4362255713391689, 0.5165557431117181, 1.0256434772764484, 1.5230004441353584, 5.761930404170867, 23.28443273421257, 42.02642348504836, 75.80800917840774, 110.32621599012806, 93.31974460232644, 88.26364471066384, 65.4935484547769, 38.746419875852524, 29.37547745243196, 35.714957252625496, 45.94758948972149, 82.65541630406534, 82.88334523477863, 91.41155073719641, 90.9999607455346, 93.25748089821109, 100.83996372838175, 105.06660784444502, 85.92693974894863, 28.623327670558808, 2.261394964110467, 0.3734257282508958, 0.19753975493292655, 0.16603388342886202, 0.20767926568946532, 0.19102437631978145, 0.21935775515533265, 0.16476747880299247, 0.25380325924244623, 0.281027618555292, 0.15824249344727687, 0.17146883292063592, 0.11864279577087973, 0.22361712740553966, 0.15993628320434403, 0.2604466664694971, 0.18169681151067058, 0.1297662085703304, 0.23413830316595494, 0.10234884106584134, 0.25554359650179265, 0.3308502079979066, 0.21611908781191996, 0.082055532012976, 0.2887737174187937, 0.16014806055013212, 0.1937149230751299, 0.09551417998849385, 0.1179556608680756, 0.0783883304064793, 0.13155681651926812, 0.11304964912274193, 0.1211779569125464, 0.1550371356068119, 0.16076716684526013, 0.17437962995421502, 0.19494938183455698, 0.313568459523301, 0.20595239625582773, 0.1136078437670104, 0.26832876126131705, 0.08488922229697628, 0.10767803211966831, 0.19514579145658403, 0.10301684675317618, 0.17920883372426036, 0.21199004243939154, 0.16488496604706013, 0.16890913398275453], [0.023207438568915092, 0.029496227526256157, 0.1174500121945335, 0.026285520476859905, 0.03904639067308557, 0.007038963799019375, 0.004290748817560774, 0.028224862481076873, 0.00304601370683691, 0.0070635949621998505, 0.07718105244660571, 0.01282582966415512, 0.05978066376560639, 0.09777143507474854, 0.046039578324604424, 0.1062691044963656, 0.047884570855286815, 0.009015940351321573, 0.07983891789110438, 0.01676919351842615, 0.018934663610472795, 0.05090280022892741, 0.023776871723032767, 0.05055586965153775, 0.014687810194558434, 0.024670078531808914, 0.04612259544251908, 0.014607416927784443, 0.04388933039961323, 0.032360500040193724, 0.02313259752437232, 0.07389085036852668, 0.07831615726313285, 0.08104940575938072, 0.07123585009286482, 0.031146185562735608, 0.1588003586737379, 0.026857728784483288, 0.01469136005447757, 0.1075658845084329, 0.03178078407091239, 1.805394549042948, 15.82772364539485, 43.677090214144805, 82.99313237590175, 74.43724278480776, 78.73983183214742, 73.9513474126016, 50.00484604989329, 60.880688159696525, 115.9932799493113, 56.34572613623835, 25.685042911960235, 29.63160037994385, 54.80785892855737, 90.9492523439469, 69.72551130479383, 61.82144118893532, 34.14041588383336, 20.774406079323064, 4.593268056069651, 0.8704593753622425, 0.09238759896928266, 0.08895770841909033, 0.13634385480996103, 0.05754129683238365, 0.14420790057028496, 0.09057992258139196, 0.06356616849981009, 0.12142824549828807, 0.2284539614113108, 0.2902632068482138, 0.3714538179337979, 0.34362938194986314, 0.5741369339727587, 0.15644525117691488, 0.26926072254296274, 0.45377186529578706, 0.6812735334519417, 0.5411960725342074, 0.4121922287008455, 0.56359059988491, 1.8030271534958195, 0.46843255118977645, 0.7033102670984884, 1.7199060008410485, 2.6789437715084325, 2.418707013130188, 0.9945539132721963, 0.4081304918133444, 0.14338444798223435, 0.041128000950500856, 0.12960836381441163, 0.15774931668514208, 0.08040513347594008, 0.0846498504641556, 0.037154038586924155, 0.07911489585474615, 0.06025616304888841, 0.12471596545149242, 0.024971522638694416, 0.014147807265661899, 0.053485060456178846, 0.45719128342405446, 0.039901023039654385, 0.09432087547235912, 0.12373885094758966, 0.0778336214622663, 0.9051399918333177, 5.4935637981660905, 20.312313610507598, 49.262945421280406, 63.803916900388664, 79.44096334518926, 68.62771049622567, 38.38329861241002, 28.1883172065981, 18.70299650776771, 12.426729625271214, 26.984783026479906, 52.2182434605014, 65.31249184762278, 71.0440238829582, 74.18361448472547, 69.30315832937919, 75.91199905641618, 75.98471979941093, 40.0605550889046, 1.2887370081678515, 0.04322249299636291, 0.06712628633625085, 0.09430854911765746, 0.08434138516144407, 0.01867854701084716, 0.03449807687091731, 0.06069073791525537, 0.07847736514503918, 0.049444961722099015, 0.01784606990704854, 0.08603325969870053, 0.0328170731213064, 0.032744321581577106, 0.011276593995130351, 0.019354119731654084, 0.005003811487357223, 0.03686421986428961, 0.037739758770312035, 0.04449649338400172, 0.02783917743081768, 0.013798517137465459, 0.05570006579340947, 0.08300105305088144, 0.027216893786023703, 0.03591817405615603, 0.01183886135432629, 0.01629575884210006, 0.06504681727458393, 0.013765696015569472, 0.05536811989581874, 0.03367137223962815, 0.11096817291071338, 0.033483002710366444, 0.058204863040197286, 0.02870397003848226, 0.06608290522689782, 0.013014934637824134, 0.026835184732091524, 0.05303934284095323, 0.07129822497165973, 0.028361239538137472, 0.11669223632423148, 0.024710943576909845, 0.024671499624908454, 0.04254925109806561, 0.06620834446361949, 0.04079660663621561, 0.03636318687049132, 0.010195895785375709, 0.1012909425903232, 0.07292667508966501, 0.03564366943112785, 0.036296797690973166, 0.031246280695702282, 0.042547102221438, 0.053761825040583654, 0.008096292017838888, 0.08550699559911605, 0.042298211746158144, 0.01979231436346327, 0.026555951429350723, 0.05741670412281829, 0.06572636024605844, 0.014211213490324877, 0.03801491457007585, 0.07737416789055833, 0.06145396450113866, 0.057490064702447385, 0.060367866329127745, 0.06621923823390277, 0.032653268201336745, 0.0257166006016515, 0.01997257868248609, 0.05178227299644102, 0.02617875463329256, 0.02894847466039562, 0.0326915955801885, 0.06430060933193853, 0.09127858710745651, 0.054363717340053096, 0.04586129434286587, 0.03134966809152356, 0.08589565498574127, 0.08292045294036789, 0.04425255183671271, 0.1070717961016682, 0.06597711614543392, 0.03447591394726788, 2.1236464717695793, 22.24691875519291, 59.64017975714899, 97.68706060224964, 84.78300402241369, 85.41908694851784, 82.60677106918828, 64.88824436741491, 61.7019187250445, 102.97007745312106, 72.9544456543461, 41.5923269333378, 33.55030705851893, 45.601605061561834, 66.71685726411881, 55.29420537333335, 57.43585478874945, 38.45258335913382, 24.33025429325719, 7.5706951272103105, 1.4016038227465846, 0.05484010911576691, 0.022940125594276096, 0.2697181689643091, 0.1598597510207084, 0.14535265043377876, 0.12218255865117236, 0.4505930907062946, 0.07094243841786539, 0.6098349152072784, 1.26074084591481, 1.0993611764523292, 1.2882376414152885, 2.4405918775066255, 2.334973970728536, 1.8734012159609028, 2.2768155172947915, 2.940230254204043, 2.47307155401476, 1.7431089041694519, 2.5546088045643223, 3.2963758274432156, 2.0119727931676374, 4.507744206536201, 5.844188390239593, 5.290275687171567, 4.93351552755602, 3.1296875976747085, 2.5720787961636824, 3.587311015975091, 0.2506638462505033, 1.1068837921465597, 0.8796740647765898, 0.6193451306992962, 0.47611279713530696, 0.5391847546542845, 0.4015421356645323, 0.13063366524875164, 0.4646197009471155, 0.18074254174866985, 0.056005424609588045, 0.02334042377169094, 0.6307939776489813, 0.3314028331829656, 0.02913405562961294, 0.04060710712726559, 0.057160811603910504, 1.4885536989858075, 5.911645312463084, 21.15100068430747, 46.436367804004306, 57.294559248032115, 62.94104645329138, 54.37522934329126, 28.30299750451119, 32.68665605975736, 30.88906714993139, 30.43437815481617, 42.113688376642045, 67.01543592637586, 75.29413946213262, 81.54667992745676, 83.61152541252875, 77.83308182993244, 86.82832394876789, 92.3061570813579, 54.75988834134994, 4.341843147431651, 0.0878580045255442, 0.12512248234763262, 0.0901411074183641, 0.14981655283801018, 0.08842478701544386, 0.03954809399381761, 0.020232577432668018, 0.05417526737155934, 0.02395981926501038, 0.04520392195592004, 0.11979628669758959, 0.056210644242744294, 0.07533705583022487, 0.06147122829251232, 0.0037004936330636306, 0.0053790854027254455, 0.05373942462967769, 0.01685495131588992, 0.10693089721063453, 0.012364782629564646, 0.02672315777970418, 0.026984372694465904, 0.05872915446337673, 0.03148440380520638, 0.03171131330271883, 0.04090893427811323, 0.012714721059667007, 0.03335668247253184, 0.06304858417640771, 0.03155000199894271, 0.017424118254453908, 0.0343478087245697, 0.00972811675315062, 0.021212131926609624, 0.023324016083572662, 0.032516632589601704, 0.05364855894097879, 0.07256159588934914, 0.0682554692931233, 0.10583299362371046, 0.055281609416969364, 0.1132549453646906, 0.05120145960620815, 0.04393718408180341, 0.014012364835868922, 0.060528576253883304, 0.10097414991187473, 0.11199375779758539, 0.14736991315599413, 0.2582057673604258, 0.09129554829410008, 0.15337291684362198, 0.16795195308664154, 0.09233428691063197, 0.17013321991168684, 0.22648134629332253, 0.14583930012679872, 0.1945323388903372, 0.1330395337314375, 0.11715585741424754, 0.19960218619915748, 0.14161072461114776, 0.2553935045556676, 0.13606339002088194, 0.10230322052995044, 0.22540594270873457, 0.13286446731898094, 0.1920334366901267, 0.15139215055011934, 0.13502979951520122, 0.09625962184321496, 0.13566837976536444, 0.08853477425873281, 0.10571938278453966, 0.1260577684508697, 0.13114715866263837, 0.12487818456945882, 0.18299484024605445, 0.201083708314165, 0.1640261048751493, 0.1935318280612269, 0.21114720782685667, 0.19628062814233765, 0.23568184775931222, 0.1439609444670139, 0.19073082674895564, 0.1499932893221417, 0.2823933081761483, 3.2657862430618656, 37.527402139479115, 71.89385244923254, 107.97927364226311, 92.39845829625284, 97.12115672326858, 93.91947500167355, 69.16295712993991, 75.05559659773304, 123.28907674358739, 69.91272603311847, 39.411226318728545, 45.131458005597516, 74.32646720640122, 114.21295535179877, 94.29468108761696, 83.3734610772902, 51.35128982605473, 32.12243095521004, 9.637005617541652, 1.9284151542571284, 0.16727159040108805, 0.26123405163807256, 0.4118594401065381, 0.21696065071850054, 0.26939540080005125, 0.2714075766984494, 0.6789940235114867, 0.3337704432347129, 0.5912192237953986, 0.6262359996476482, 1.0963763753252647, 0.9223147025031428, 1.4155781245039356, 1.625576307696681, 1.839481171581053, 1.822347890946173, 1.5969737715298131, 1.9196468183109838, 1.8937845480057502, 1.6941838326954073, 3.353532115297933, 2.506784815942088, 3.9936210070886924, 6.926053099093899, 6.8796941157310245, 6.251418667454874, 4.548818286388151, 1.7878643735762567, 1.542693806752082, 0.13619745540763104, 0.3156726579031637, 0.8450948170596554, 0.587081429698775, 0.542708330096737, 0.28156559613923876, 0.21347715699624634, 0.12036195835999905, 0.38413520842309923, 0.3191745683791176, 0.7748588342820445, 0.2076687243196272, 0.7978150572988295, 0.4537188826549438, 0.2637967996058926, 0.2828998148681656, 0.10956993221395439, 2.00020739868764, 8.852798304250165, 31.064177443904263, 65.32994639488959, 87.95874318768902, 107.54864446578488, 88.38592067841562, 55.30806702952231, 43.54897383720645, 31.54278897470044, 24.100723074328517, 39.06910150281845, 69.44575217462355, 83.33256644587364, 93.33043698341616, 93.84857423843877, 88.7892815374559, 96.87763244875016, 106.70439350989558, 74.80875399804886, 9.794747656391515, 0.2697484754025936, 0.2230202989472497, 0.19176927425207632, 0.2544865943491459, 0.11306930693887896, 0.15537744718453578, 0.15445827957122557, 0.18113248050212863, 0.15172493914442678, 0.10991034338310843, 0.17041258153415498, 0.14933693583213514, 0.16691995604384333, 0.22753251085598625, 0.18863101039201985, 0.16621941460236428, 0.14413826317796785, 0.1522260832209741, 0.21493440944581263, 0.1572848528984093, 0.1061304195994331, 0.26925465512660246, 0.18048965612486487, 0.11161593855508875, 0.1603894701768314, 0.09528526525583961, 0.08615352784193332, 0.13383396690891636, 0.1311393445658107, 0.14583562290476215, 0.07059920804515, 0.21268975650591238, 0.14188673076850755, 0.2787831341547351, 0.08744594881371145, 0.133615555241704, 0.18156034060783927, 0.1264836903541319, 0.12899707161611126, 0.23301299661397937, 0.21701573244025632, 0.1926550251101294, 0.16931774995980725, 0.10763632629307048, 0.11491901857117492, 0.14510969330947246, 0.16949463966152362], [0.05744305754741354, 0.019331288396290714, 0.04332376598951317, 0.0578568178048778, 0.034001552304553415, 0.024443971511397152, 0.032898067767100955, 0.04167332914808104, 0.03906034879506596, 0.05596779820118701, 0.02227383977433126, 0.011117160564378626, 0.013312637362809432, 0.03301320695168069, 0.026536249563158042, 0.0377185074912925, 0.06394084678181718, 0.0432673589356484, 0.04825324300796755, 0.03615517484685106, 0.03781085556012489, 0.01808993293032531, 0.006291767602951657, 0.028631141889960538, 0.03873869528873794, 0.09538895525639096, 0.05472161829651845, 0.054730355529294866, 0.027855707693003842, 0.08151853502157234, 0.02389167957458525, 0.019131142180413008, 0.032066207364081376, 0.05516968780167161, 0.035230391809055885, 0.0932234468599481, 0.08978594139578844, 0.07777826394885778, 0.08687448552659444, 0.17661987022767145, 0.9467683516202435, 45.71620102851622, 46.019153133515395, 36.59074014233005, 77.01816235819172, 82.6249316430861, 65.36506729741251, 41.62765964385002, 20.50097373224074, 82.50101612460229, 118.28130045244772, 41.97150245789559, 38.91465425491333, 43.9865142299283, 73.4601568406628, 65.95605081127536, 45.76787433316631, 23.425569418937933, 7.1669135939690385, 0.44064173114395916, 0.060456081353608644, 0.0349009242059002, 0.05187011646827863, 0.06155540220319264, 0.08340242183617047, 0.1485361134813678, 0.057505738861378164, 0.29602590407575335, 0.320773332590057, 0.5328529460295555, 1.9450609578240303, 1.8062173887606592, 2.6657861807653984, 2.974343352740811, 6.544161823488052, 4.413400907670298, 3.131334012554538, 1.3813268849926612, 1.7536763822840107, 2.765478857101933, 1.708767572718282, 4.197376860726265, 1.95477997824069, 1.996854262486581, 2.435532755428745, 3.6808634669550004, 4.853943384462788, 5.007206076575864, 1.0027742818478615, 7.750663766937872, 10.511337230282447, 0.4884491722670294, 4.224382869658932, 0.5572980762489381, 0.6024334026921181, 0.6681855034924323, 0.5631474946295062, 0.7966672737271556, 0.6882802348944449, 0.3970751382650868, 0.19579287528270678, 0.050444189353936145, 0.14127091865145391, 0.12393692298041237, 0.1791886549683348, 0.03824471413428265, 0.024446871154190555, 0.14336531110588582, 0.04780854812012084, 0.1743837208637307, 2.0309832956521743, 9.017699649257045, 31.462174461733913, 51.45562095026816, 66.16401487781157, 58.50906625870736, 42.39336513703869, 34.25450586503552, 36.61478427148635, 18.232329737755563, 17.574832631695656, 42.90411264665666, 62.75156459500713, 62.55591677081201, 75.5215584847235, 73.28569766013854, 64.81780644386046, 69.59903840095767, 50.677293269864975, 11.932430574970862, 0.7003057315464943, 0.0926154411788429, 0.2814515716125888, 0.048796709611891746, 0.07333162150556043, 0.044130694061037035, 0.055629068595026775, 0.03253123039499887, 0.004024439896907537, 0.04704773088075942, 0.02663353698388223, 0.035014803175844496, 0.042162303917951165, 0.03893551859824408, 0.007337556143606743, 0.014822216490433823, 0.026159294084796024, 0.06271379226217828, 0.04753315100266088, 0.02741524161049916, 0.05637670912209058, 0.014152468910681145, 0.00765913735038691, 0.024266133775874495, 0.014686496353768294, 0.0021231042328215535, 0.040538546088482105, 0.05724716120429578, 0.036188875054640156, 0.013576426332996739, 0.04948389814085057, 0.10170912700555018, 0.01905248027234789, 0.06855500967151697, 0.03757975364644681, 0.02126893160053559, 0.01654311905675117, 0.05023879352055731, 0.033316336451999606, 0.04997289589335842, 0.09239344422014491, 0.03694147217057405, 0.09828712716097794, 0.04215483456068943, 0.028468907450235663, 0.018049902921061844, 0.03844991078480117, 0.04473363590096274, 0.013280445390621261, 0.06581279028567576, 0.07666502328168961, 0.020509292221357747, 0.05019721792890661, 0.05596801270580581, 0.009519104027159272, 0.05286261784814058, 0.04049277999588559, 0.026185706881205403, 0.06285630759873218, 0.038787012454122305, 0.05878784062881624, 0.10299964041839685, 0.059236863913435134, 0.0844550726094073, 0.0646493861812257, 0.07728503356056829, 0.020378588045376445, 0.028974167334156174, 0.024504203259223895, 0.0068177678810072044, 0.04906877424688109, 0.10063465804822984, 0.11203951622930267, 0.04753832975702901, 0.06965813031720539, 0.032282964281377294, 0.020799440361799735, 0.06624241239361225, 0.018141417869276578, 0.06603210593663877, 0.029966567207368153, 0.09377954242330405, 0.024623385472824017, 0.09524928210603614, 0.02670204439651101, 0.22893319537322368, 1.8996434658765795, 52.15293991950251, 54.48322003887546, 43.36268871061264, 84.5131527992987, 91.32388576384514, 75.40001992256411, 54.706002819922666, 32.68130006328706, 78.77915751549506, 128.46657399208317, 45.87257808254611, 26.03107636974704, 36.83885358995007, 57.00595517312327, 61.57544582120834, 45.47040962403821, 28.48340888177195, 9.472929931456044, 0.7578556047331902, 0.040452690614807996, 0.09083839298616495, 0.09841542390565719, 0.011059264427111035, 0.0346343792344053, 0.18744450873665272, 0.10883691630536511, 0.15265850921071347, 0.1556047454716698, 0.22966791965788413, 0.9603086798902482, 1.8348217635385453, 1.49643435353233, 4.794776881894758, 8.87769554891894, 10.097104541717037, 8.910448320450323, 7.454854298022486, 7.338844316620981, 7.804042322020377, 8.031640793046645, 7.199721768979104, 6.316840369855204, 6.24714671604095, 5.867399996326816, 7.284921532677067, 7.378757374901926, 7.402871126128782, 3.111124980834223, 13.813109013342089, 7.632053744408393, 5.526356283695468, 10.519546751053104, 2.243026504593511, 2.6915573785381937, 2.521323326133913, 2.111677114040621, 2.892570269684638, 3.5157468818849136, 1.6418163910988839, 0.7352987893166081, 0.09399860526525206, 0.23999702185392383, 0.5243572148103868, 0.06831545397759446, 0.07219291607578916, 0.11869954756431042, 0.08827713122891803, 0.05864208090990301, 0.17737324109240887, 2.1555216129749053, 9.601060036690006, 26.863024811590872, 47.849319288807536, 53.70588471812587, 48.01656915295509, 32.849442266648815, 24.031736427737822, 25.896754803196078, 23.781424491636216, 31.015469451104444, 62.92876158991168, 76.39379947416245, 72.38657274553853, 83.52497439230643, 84.53980922698975, 74.51026947267594, 86.0951074477165, 70.84382610936319, 19.203420339092133, 0.9751227978737125, 0.10483211507239651, 0.14234980027521812, 0.015840229555784215, 0.1001483990600513, 0.02569049040997221, 0.040402462060052546, 0.03375448511853334, 0.09357853627373135, 0.03283856954846171, 0.024266440211044207, 0.010441651045825454, 0.06602850532339466, 0.07838610109061965, 0.02294829592198855, 0.03391666210166389, 0.05427198980243937, 0.039560144556866544, 0.04798597025294458, 0.040358484782759226, 0.0074044021030497415, 0.04735782028987043, 0.04192041165585961, 0.012499663899953087, 0.09276488961111154, 0.0675219324447455, 0.041580950435731685, 0.061933068228104425, 0.037106874383865826, 0.026983888143853798, 0.020354908267636935, 0.012950287350723821, 0.00898942700587213, 0.08661634453962888, 0.0354885098133837, 0.094985663590412, 0.030487721500497673, 0.07338936155241343, 0.08821420476681764, 0.0022428569425227904, 0.05580124685600881, 0.03314929098011025, 0.07612552118277358, 0.039863772014336246, 0.07274606220063663, 0.010865059223086124, 0.1278879678237342, 0.09785030382655321, 0.12357650925555538, 0.12004614627409367, 0.21176717214045987, 0.137009309424508, 0.11066396705686085, 0.22281498738354255, 0.18723509094167143, 0.17286259200303786, 0.1601116560519703, 0.11154069339916592, 0.12064031640728637, 0.07805879002497082, 0.09904863387947122, 0.13501944200646493, 0.09934594494200523, 0.12104228274115633, 0.19466643492060323, 0.1091742248184258, 0.13099208714500551, 0.10504741642263629, 0.08907908738981332, 0.10129222961803598, 0.19325568400804075, 0.19838784490862202, 0.2546229733214263, 0.2546491582066782, 0.11039283321869951, 0.23095693919927845, 0.12000666210247625, 0.07817521240682372, 0.1477866649868027, 0.14830394287503537, 0.06939910832912692, 0.18827105631991742, 0.1785366222142212, 0.1708447010887246, 0.20092600145407263, 0.32505674467932794, 5.465931190598396, 69.9926168687882, 69.31434492911063, 53.81861363687823, 95.87410188490345, 102.19504064129245, 81.98914681711506, 57.765561380693995, 34.83612668129706, 91.90376897012034, 121.5984881308771, 54.8627564214891, 59.770496583754024, 61.6934895515442, 95.4725923845845, 87.60737726765295, 62.14109474612821, 36.16253891298848, 11.492450468001827, 0.9860747908392261, 0.3473104344260308, 0.15001699208251892, 0.46757382791369195, 0.21621319405253858, 0.14696964753731606, 0.6262130170099197, 0.5231608919078304, 1.3300628551552374, 1.4977620758356587, 3.651651615096677, 6.800821625417279, 6.979124728710421, 10.878691711733419, 10.2398846995446, 16.594922581026633, 14.178539572223542, 7.7263068287603325, 6.084980243636716, 7.258154298028639, 10.92395096055923, 8.183589491151995, 9.306610649631871, 7.34583447056432, 10.410560754037673, 7.521636082280067, 11.75177699135196, 12.861496902281239, 13.937706043643336, 2.053910897624108, 19.25944943581858, 24.929543425959928, 6.829336766273745, 11.44144690805866, 1.5115788699157777, 4.099748331692911, 3.493341568016237, 2.0727985808926244, 2.8325413359749705, 3.96832368066234, 1.6454867489876288, 0.8751368017927293, 0.32557314922732694, 0.7979720133927561, 1.0084279494420176, 0.9163333331384967, 0.3885566695563255, 0.25106850921386675, 0.31557291325542236, 0.26828938434200905, 0.561737954135864, 3.048894371717207, 13.906141750274168, 42.695348416605306, 70.0422897646504, 91.58946160347232, 83.8103582013038, 64.71651515653058, 49.53767607288976, 51.84948575112128, 30.018144076870335, 32.40599086207728, 60.912424056760734, 80.53413575695407, 82.0016513332244, 96.80335060242685, 96.86634386739424, 86.65171530938919, 97.7737214488368, 93.74467065257411, 31.564966055654715, 1.6419889753864658, 0.23902487159977037, 0.3829352389420233, 0.07927244949725368, 0.2235642520170058, 0.23419632666533996, 0.1335002436873413, 0.15759942392187734, 0.1770172859992712, 0.17591609589515195, 0.2059588313943917, 0.10658805754276053, 0.20189884118735793, 0.10108123368193066, 0.1016663563167376, 0.1252719384407805, 0.18594792533305385, 0.17052110554950853, 0.09449745107802654, 0.09953604199953618, 0.14314093927462257, 0.0998047166954606, 0.12947731681408423, 0.0522214520512329, 0.11883182796619593, 0.1879845700797535, 0.1992451892264428, 0.114031505710896, 0.1349908362833723, 0.11643995590988668, 0.1521796736145212, 0.17742322066858893, 0.23532947795766018, 0.18263529986143115, 0.1812387522189848, 0.18769521867075276, 0.1299745385204592, 0.11575807637024312, 0.22837079490625092, 0.11844715989765622, 0.16065309635333477, 0.1210814374949663, 0.20492502638409216, 0.1280557717226686, 0.1580767733074965, 0.05296952924841354], [0.025401857208400488, 0.02245263511975927, 0.012768987855393321, 0.015316445665854602, 0.05799385178233347, 0.048640803058421424, 0.02659300327180855, 0.0073678970558478715, 0.02564332237647426, 0.05191386008875505, 0.012209745585888386, 0.05145915626217762, 0.03713861723700839, 0.04540339976008381, 0.051860015598997, 0.017459375535949104, 0.019488730956049218, 0.024044774585373463, 0.044397131780222546, 0.025927736348803007, 0.0030060751493194053, 0.043419201392680414, 0.05285333669293792, 0.03537152435690646, 0.02877913092473342, 0.06552655685452685, 0.057292142056769906, 0.02963352005838627, 0.059325335577370665, 0.0415093633496473, 0.13100386957728094, 0.0319301558943886, 0.02553253457130444, 0.013991370196304014, 0.09582485162442732, 0.06830772415043847, 0.10091846298065879, 0.11036220502348677, 0.36921255110252293, 13.877077967889848, 57.07025850972822, 80.6385806299025, 84.82043912333828, 70.41136910838466, 57.68831814489057, 47.49425849606914, 28.401739251229074, 23.905404729227868, 28.59726940431903, 21.272839307785038, 29.561562538146976, 52.44686665073518, 56.662500673724765, 71.45910478407338, 50.652386219270774, 33.30510400956677, 10.669807849391814, 1.5206657758643551, 0.12942876216144333, 0.06780226699887745, 0.19229375336679722, 0.4991440967686715, 0.07088656762554761, 0.05431685574172486, 0.316822218798822, 0.2527007514670972, 0.6483950622139439, 0.2866701931963044, 0.43226149534025504, 0.415365579387834, 0.846787074640874, 3.504513949155808, 1.965832972238141, 2.988482761767603, 3.3763333434058778, 5.378309363319028, 2.3727576723021846, 6.890512993258815, 10.528088692695865, 5.63730150461197, 4.744548480356894, 6.108501226671281, 6.2940146269336825, 2.3964360404399137, 6.971553573685308, 6.063230701031224, 4.541786457261732, 6.227674599616758, 4.058260932084053, 3.304726063243805, 9.557112820686834, 8.082716916838, 11.872812509536745, 2.251700581081452, 2.1863739961578004, 1.6194983499665416, 2.3631147703816815, 3.303903591248297, 1.768120020147293, 1.1712563830998637, 0.5624004056857479, 0.12450020444849808, 0.15462651247939757, 0.033488905417823026, 0.0650459898996257, 0.07027667736814869, 0.08029673969553364, 0.12115057693013262, 0.07649453807502024, 0.020150299589600296, 0.055521023384625875, 0.014741317605629805, 2.337874318322828, 11.2176021452873, 40.91541997848019, 46.46208286285401, 61.50680826556299, 63.857096395184925, 45.411499546420195, 58.731845117384395, 36.93166471296741, 18.620748327624415, 19.573411633891446, 39.45379972457886, 59.95717002499489, 66.83583844092585, 81.1552744527017, 68.73153563468688, 70.48715714485415, 75.76802453687115, 42.73594887025895, 2.7767139961642604, 0.3386305050263482, 0.03719005238024458, 0.03733565888157295, 0.16951155488289174, 0.038380135496657704, 0.02434308922308828, 0.04004780548594652, 0.06988033411964294, 0.025823743743521553, 0.016316841581776258, 0.06631120708921263, 0.060660630659831155, 0.033966273955640294, 0.08332288658787167, 0.053933850083980835, 0.09054315802190574, 0.029959944377262748, 0.04406045145925976, 0.022818037992223136, 0.046981429801352566, 0.07460695871662709, 0.10699963061920098, 0.025092413228365685, 0.05276974117864044, 0.03561458107264292, 0.03803042402010291, 0.03155944403260946, 0.04133808524197629, 0.030197862558247104, 0.008077623412734079, 0.01600539523942937, 0.04408735263672087, 0.08357486056704676, 0.07059983623724791, 0.07083138631236169, 0.044468910388288, 0.04396499307345479, 0.01902931951917708, 0.023836241621944695, 0.01769366246017237, 0.06705641145667723, 0.028689808903201938, 0.04248712519784609, 0.03414420170649406, 0.0511092800767191, 0.06455614561996152, 0.031923567538239786, 0.04581671951699161, 0.05713310986456852, 0.01899129474505542, 0.011843303706677211, 0.04765564080087408, 0.1016877454915835, 0.028912083568772482, 0.011750716235368483, 0.06454557360660645, 0.02585943003425435, 0.03167270821699452, 0.07986304966071922, 0.0062091723122003105, 0.03919924436617763, 0.04283969035191883, 0.06530199350128252, 0.04212208047148682, 0.0319585949933577, 0.040857181208388466, 0.03272742934284672, 0.04187580618646838, 0.045332919671050007, 0.07110016059971626, 0.02609206603900079, 0.02744946467329658, 0.08222441609588363, 0.019148856048442183, 0.017751494437576305, 0.092094968703966, 0.10137991604184914, 0.08046796034661033, 0.052656076713314945, 0.0506486390687285, 0.09400038258923639, 0.05354492639702174, 0.686132614651034, 19.421280545573083, 66.96666517565328, 93.63034140679144, 93.30733422310122, 80.39082804033833, 69.29701589768933, 61.095645812249955, 39.6717462232036, 34.841570931096236, 31.952964951915128, 35.58016892402403, 40.5055832862854, 47.09057992504489, 49.20316065511396, 49.07005894568659, 50.76757838649135, 35.5324964369497, 13.251719782429358, 2.14568528917528, 0.05195751943955979, 0.210413264951879, 0.16245027733666284, 0.7257397280585381, 0.10983528974916666, 0.12205468325485146, 0.2805478023665567, 0.7960661704982481, 0.14111483589776103, 0.2728108352711124, 0.31765664176594827, 0.652390792965889, 0.3012495511962522, 0.9132854676535054, 0.6436872374146216, 4.695700262823413, 9.604261671343158, 12.850852570226117, 15.964597694335447, 11.98190539113937, 13.153609537309217, 12.649997799627243, 10.993753460145767, 10.728172717555877, 10.72764123639753, 10.35760973730395, 8.845464452620476, 9.424719099075565, 10.333814678653594, 7.397231738413534, 8.807255664179403, 14.7276694351627, 15.525077485269117, 12.255939822043143, 20.950312614440918, 4.400966013631513, 2.7142953584271097, 0.5297894523509088, 0.8842427067218289, 2.3971089720726013, 3.872372210025788, 3.1985340195317424, 1.29457741735443, 0.2652844197807774, 0.2580531626459091, 0.02552448490244006, 0.05558431756892993, 0.1787665098785393, 0.3163343127216062, 0.3243558048721283, 0.05369042181560109, 0.10453498021008507, 0.004862738790125737, 0.053580729516162995, 2.6284481585025787, 11.176643775355432, 38.65980217533727, 47.555051311369866, 51.41027050633585, 46.10332719741329, 54.31487975582, 46.104052835895175, 33.04787105129611, 30.723209727195005, 42.087000569989605, 59.14111306590419, 73.86580051914339, 73.82328987121582, 87.3620016344132, 78.10740455504387, 83.26659217957528, 92.12371195516279, 57.52754019152734, 4.8027412545296455, 0.25178156853202854, 0.0605847190074142, 0.05312637425959111, 0.17323353177597448, 0.04887018510470948, 0.03854511636159113, 0.039211122559443604, 0.060397414340367245, 0.026953016715725104, 0.09202619699100334, 0.09720639926531623, 0.0302564395561574, 0.04517324396499223, 0.04824748585721658, 0.026240918837908297, 0.01530419304711564, 0.008593654492869973, 0.03701615425187253, 0.04463393338805726, 0.0820539768544897, 0.019195208198300773, 0.03984925464817113, 0.0440853531472385, 0.04390383627445948, 0.054461634868095, 0.07988410175687845, 0.035827059388881734, 0.013399289567924797, 0.06993071206154362, 0.07081388120329188, 0.06664227198569045, 0.03945461594529691, 0.027089748088450685, 0.03564634307798359, 0.0811677740045613, 0.03098482829368403, 0.01618711033745879, 0.03608692024323729, 0.05457861266369301, 0.06303815005887901, 0.03752337723609902, 0.034652148643808986, 0.008499246605131175, 0.04776319571500344, 0.12301344229208848, 0.11240893148726995, 0.1786622606338032, 0.12369696892076924, 0.11096066524905544, 0.1493579419630189, 0.15198304948787536, 0.20568144627876822, 0.2184573566961673, 0.1315066684037447, 0.08790454436694423, 0.2131679792317652, 0.2012108329443201, 0.1404138501252859, 0.2131210180420068, 0.06599284393051941, 0.08486008031233665, 0.12737897134596302, 0.1477073442431227, 0.12144319953457003, 0.18172413020605044, 0.1643843735538183, 0.1841903510954111, 0.12477744400741593, 0.17990225054804357, 0.18435479952923714, 0.20145398925148672, 0.17114468579811437, 0.19646303367710885, 0.26878387877537363, 0.23291879844280983, 0.19445387616513238, 0.19550508669307157, 0.2875694578453418, 0.21036794319027857, 0.15638647691136406, 0.23587303266169565, 0.1878998101118111, 1.8109731400205245, 30.579672551924187, 89.16829232246646, 102.86746040467294, 102.36480866709064, 93.41528569498371, 77.02066483036165, 65.22945919344502, 44.16102832363498, 36.981894585394095, 45.582169717358006, 32.901631362976566, 42.38029579962454, 73.8040937915925, 74.866255944775, 94.49128597013413, 70.5817804028911, 48.70392530195175, 17.08413431721349, 2.8873005653581316, 0.44772930082774937, 0.410034557383868, 0.4209221989637421, 1.5127979915949608, 0.2701360546052456, 0.4663941444408509, 1.2374498118315975, 2.4811607070507544, 1.8774641785890827, 0.9475859819400696, 1.5578672506155506, 1.6998338843545608, 6.378686341547198, 12.820924885811346, 8.97971639710088, 16.090342017912096, 19.882761124641668, 20.439678853557957, 19.23088869740886, 22.56245186251979, 26.802255530511182, 19.165987199352635, 15.940661430358888, 17.31686422901769, 17.05046469165433, 14.005152179348855, 22.45157822485893, 19.89616386352047, 17.080100159491263, 15.782413405756797, 17.53481072764243, 25.68122644578257, 16.82716808011455, 32.87960137090376, 31.5061971833629, 6.333758042704675, 9.042800857174782, 7.081302961995525, 10.769848881229278, 7.1567438687047655, 6.702423086089473, 3.733690929028296, 2.2649461800052277, 0.42508512074428223, 0.5036923301316077, 0.22038124862217137, 0.3704736237564395, 0.4057673250715579, 0.3445488406765846, 0.3419913940372006, 0.255784944841458, 0.20276294240067083, 0.24392170561177118, 0.22765767430105519, 4.628885138419367, 16.516112358339374, 55.82119541783487, 68.2930774073447, 86.5116866942375, 86.13348391748245, 68.46512040784283, 83.37405727755639, 50.01552666387251, 31.611304936870454, 34.42417190920922, 56.01050076946136, 78.21482258458292, 84.20464269576534, 103.91009699913764, 89.65523104513846, 92.72399148633404, 106.31228985324984, 76.34620543449157, 8.176761134978264, 0.46207785185786987, 0.1272074059553204, 0.19515740534951612, 0.3326710151328195, 0.15024258965446105, 0.10978865031633647, 0.1134835996274506, 0.18912525967724864, 0.2089979328335293, 0.27591686215131517, 0.25892671738420764, 0.16797338822676292, 0.1183830843036694, 0.15817340763826526, 0.1527849596834952, 0.15822079783726126, 0.29268756869339174, 0.13000325149586126, 0.19098933545812485, 0.13825976409979407, 0.15672208470923288, 0.17369585051651926, 0.14984707378091353, 0.1405070983474293, 0.26133422529505146, 0.12353428248916903, 0.14569394260404572, 0.07947426003914687, 0.13256901785010292, 0.1183746190321061, 0.1940686565132872, 0.0987374489646285, 0.08848945249713237, 0.22357876172229169, 0.21328002725157047, 0.11794446066262261, 0.10927285863867692, 0.12591710704709255, 0.08126073877417272, 0.15241317721384187, 0.17569504888548007, 0.14423895777473528, 0.181435514241457, 0.20462424494326117], [0.07503810533953291, 0.04379569147262843, 0.03048633679657454, 0.062388706681949485, 0.08961986119468367, 0.02563859752920126, 0.03115285244289666, 0.019768263033080487, 0.04243752483518855, 0.14077506058158415, 0.092348359945801, 0.09557557427474568, 0.04210405825306812, 0.03094109807974629, 0.024403661880041325, 0.020491884788498282, 0.04364448869901319, 0.02138878222584965, 0.05654972241891008, 0.005593822720730978, 0.040888146482287877, 0.05157793053395806, 0.042655204888433225, 0.04626905996232264, 0.006490332326070676, 0.015660649927843724, 0.009711378689614997, 0.06370497597081047, 0.013411303741797326, 0.04419391163654866, 0.01581161425659253, 0.021350033498639544, 0.04236353223302192, 0.01501633359434744, 0.10315833553191155, 0.025400403556564165, 0.2657123871387974, 3.613207974741536, 46.723724565198346, 82.8608778984316, 79.29456480087774, 77.74866457908385, 68.51522476442399, 75.73297423701133, 63.687693149812766, 37.75578214276222, 32.02061995383232, 20.332192182540894, 20.523890179972497, 38.08957192205614, 63.7000996066678, 59.0027436133354, 50.326700056752856, 40.14158733429448, 15.983824172327596, 2.6696399094596988, 0.23465700597772676, 0.20018162446156626, 0.06450075746303605, 0.018303071997398813, 0.033542972073079116, 0.09873258430630931, 0.030342578482363495, 0.13247177064899476, 0.14936644553897843, 0.23764611251892584, 0.11189508567293806, 0.30238786592118205, 0.1693406866322602, 3.1906042127839984, 3.212059577626567, 0.3020826564921487, 0.1261556898093512, 3.434237087926557, 9.784409269209831, 13.928354132559992, 23.663580802179155, 11.875200252379141, 8.396805121052651, 9.502060394133292, 11.434199348572763, 6.497455710364926, 6.362019700388755, 7.239537748598284, 4.3431022282569645, 5.70949419852226, 7.279641041832586, 5.307930765613433, 5.95340286531756, 16.395984868849478, 7.135429709188401, 5.588111550577226, 10.71497884488875, 5.477085921072192, 1.3875840460100484, 0.7211690023541452, 1.7574877003508231, 3.735599162117128, 4.220915494426604, 3.887940832684117, 1.5610832264346461, 0.2077676722359273, 0.3045552205895224, 0.07633291650563478, 0.10086432354704988, 0.06721636295438775, 0.24847006154877527, 0.04322869064767034, 0.022391321272739483, 0.08630292264804726, 0.07131256613760226, 0.0395265439405076, 0.06335789217583596, 0.02130992688058365, 1.6922713095141997, 17.892881939488074, 39.25663002075688, 48.51865606923258, 35.551010024163034, 78.32224061412197, 94.87020261826055, 39.451289407668575, 21.242185984888387, 21.431471724664014, 24.14132941153742, 52.409988526375066, 43.087001000681234, 57.13922162209788, 70.24877902000182, 71.47439418300506, 80.97569265673238, 52.19153211962793, 17.77943914936435, 0.7143799924562055, 0.2082343270341235, 0.03602792381218845, 0.020561049121522137, 0.04253507081058718, 0.01425019587435189, 0.029718910133646383, 0.04757054375424501, 0.08245778179937795, 0.049055356216887315, 0.008951398401310848, 0.004824223719732536, 0.025278737302869562, 0.006516065219447258, 0.018231109528231527, 0.03371175273411697, 0.024909760630238923, 0.020712255725576993, 0.046975255132682865, 0.037271839927040765, 0.06432815019281642, 0.1364808006873054, 0.03356033928632256, 0.07071189191793242, 0.09833752808551635, 0.08781164854524598, 0.035124683166824044, 0.0744233504238148, 0.039679186959420486, 0.04679020659457292, 0.018616587734751163, 0.027750610005891616, 0.07615363660959468, 0.05099395320059792, 0.056352811009292646, 0.04131123002979063, 0.0444750122786049, 0.029213820704289024, 0.0722422827816298, 0.05247556724615636, 0.03911385620613733, 0.01515134126924339, 0.008399025067656992, 0.023968025981899233, 0.03497953248781062, 0.004055104481296674, 0.04140621344108255, 0.008745789020923118, 0.010822475268205088, 0.022129200459007296, 0.0331523246882904, 0.04252355650908524, 0.0350959318870258, 0.04914511490853564, 0.042453850168854966, 0.05084794833354893, 0.0866620570060707, 0.014097209073482983, 0.03070496105318589, 0.053038806579406225, 0.04047665384507949, 0.022302445497423894, 0.04290469291229402, 0.03800056191281446, 0.027007230842906623, 0.015468061169339044, 0.031235578447400086, 0.06153581716540841, 0.07837218127303547, 0.026900758027970314, 0.08051400223085958, 0.050507445233843984, 0.055835318616441185, 0.025313716877492207, 0.018280755856164524, 0.1034689535416903, 0.05137028623252146, 0.0935930613007757, 0.021019535507225705, 0.21334900580827268, 7.589358254786461, 60.597795055758574, 98.0673736141574, 91.06765300996842, 87.3891915044477, 78.93995900307932, 84.47226601262247, 68.81344256862518, 43.48885174720518, 37.88314934699766, 24.36479860736478, 21.45568451573772, 34.40364614609749, 61.24781416308496, 65.59192542106875, 57.64335993797549, 45.04312230694679, 19.114164844635997, 4.063431351415573, 0.2120797360135663, 0.025017945651686, 0.053058759339394114, 0.040473041740516504, 0.06769789518007348, 0.09577779084323876, 0.08255666842864406, 0.06380833655355439, 0.14507269126272973, 0.159818121802903, 0.16709509906509232, 0.4737351666535101, 0.0626714850565599, 6.063765123967202, 3.691685776556692, 0.3912365064024926, 0.19236492293496288, 1.6838894496040961, 5.528297366634493, 10.225065004441047, 4.9619286867880055, 12.805888479755772, 11.234693873313166, 13.830378228618255, 11.807966905255473, 14.353711643526632, 11.878622520354487, 8.19435247490483, 7.450462714318307, 7.346047259146168, 5.757776123862113, 8.112252364235541, 8.077152054156027, 6.533675366832364, 5.327204312047651, 4.208692898673396, 6.041059503632208, 3.006162355023046, 1.0052870502395015, 0.1911467358830475, 0.7457643470937206, 0.3363728745570106, 0.3342320265308503, 0.7250040997901271, 1.2670201928384843, 0.31932328136697896, 0.2587414466805997, 0.1574999091005133, 0.11108929907242138, 0.26779397060313537, 0.16007177351463228, 0.1723521322973313, 0.2617767789671498, 0.11850146787060846, 0.03419968562441007, 0.05218284121984917, 0.03347524223969348, 0.04479691093306869, 1.9378819172420811, 17.98217273527576, 43.12098441585418, 50.13732802483344, 20.994578523020593, 63.88971090316773, 79.37134127463065, 26.984747725148356, 20.213448309129287, 27.407137963079638, 39.089450759272424, 68.458522981213, 58.19225249751922, 63.44154873201924, 81.07334398454236, 80.35463240838821, 96.44806231221845, 67.85835327640658, 27.488217276911584, 1.2218396365642548, 0.3103430148574614, 0.06210764051384984, 0.10499994195396863, 0.03497731466326983, 0.053860730822047884, 0.07178066118109612, 0.06972750723962823, 0.042262845297133735, 0.08253592276765455, 0.016419074100051678, 0.00840876970605384, 0.013374621536762965, 0.04531752513421159, 0.014684533253462325, 0.012394167847120234, 0.02819200113956486, 0.0184596527082425, 0.03891516364209595, 0.01009614730719477, 0.04177889223360727, 0.0353154965165642, 0.03529546714778389, 0.05418519204061839, 0.10045685670188359, 0.025516193915879535, 0.01331002021493811, 0.02350285930949594, 0.03226157510653138, 0.041201936096073165, 0.07011353128379391, 0.021136959549039606, 0.01650566310291329, 0.053227857926920544, 0.03598427595270257, 0.051284610789509556, 0.028684249020091472, 0.04172239324919159, 0.064179670861772, 0.022941360911053997, 0.06735053559344623, 0.07956171663658274, 0.0453841403096674, 0.26958885332269056, 0.1954079467442728, 0.10526922185935321, 0.1363155402002796, 0.21811223408627897, 0.06780587527300082, 0.1873817048486202, 0.10425526618717179, 0.17155204539097127, 0.22764993681301995, 0.22411410396377887, 0.21651759142837218, 0.21761824527094442, 0.13868457517556607, 0.06425284374985965, 0.15521698240791598, 0.24137683813610386, 0.11441680197153362, 0.12276354441118818, 0.12291837078068527, 0.13893704711189195, 0.0826700187979206, 0.1402644936235682, 0.09679854171530855, 0.08327483755326079, 0.1810261168547215, 0.1636829281285886, 0.22322979335102344, 0.11265739678375183, 0.17581720926588582, 0.21653367927478206, 0.13659856372302578, 0.15503633887537066, 0.09895202253134021, 0.3001636062418261, 0.21405854112198278, 0.2894781505869281, 14.616369239745604, 77.47789552134853, 112.72327838405486, 100.99727430651265, 95.62103056138562, 87.744181694523, 93.02520598134687, 83.97882400020477, 57.14422264406758, 46.523350284945586, 32.658134545049364, 37.26033187681629, 54.03654836839246, 85.71100542622229, 78.89303961107808, 69.86443381155692, 59.27479528611707, 25.239449893274617, 5.500275954123467, 0.41923459919710315, 0.3476728553012494, 0.1586284332217709, 0.1544251386076212, 0.3086698175437989, 0.43349658229178, 0.2612160026065765, 0.5248965407090803, 0.6210508714279821, 0.9621057382995083, 0.3688489657736594, 0.6263446615588281, 0.26318172293324626, 9.561222484034877, 5.446220790186237, 0.7564213042778354, 0.326007521080394, 7.306456815811896, 25.292105751652873, 32.605433579414125, 42.75519201832433, 31.63061672641385, 23.262500801394065, 23.2956781694966, 29.37551275376351, 20.654748293661303, 21.04893472886855, 22.09913561421056, 17.085787596241122, 18.779557251161147, 17.704725842322073, 20.442987372798306, 16.72336059231912, 36.72975678597727, 21.890655755996708, 18.179948445289366, 25.411806683386526, 12.577450621512629, 6.374234941697891, 5.602293370231505, 10.50407692309349, 8.224054623034693, 9.477766213878509, 9.363789000818807, 6.287487802966949, 0.9660797121544039, 0.763011315176564, 0.6700334301398647, 0.42647670413697925, 0.7720498656553607, 1.0496483214439885, 0.3994568749781578, 0.5131054056748268, 0.47054272505544853, 0.49132077624240234, 0.12369041886901665, 0.130474119777641, 0.19508079655708807, 3.4644386028089835, 27.089892741172548, 58.307899659679784, 68.76540137875465, 48.73781065787039, 92.08711624145509, 122.01447902187225, 58.46204488508163, 30.78096466679727, 33.57763813387963, 39.88764132222822, 70.673124559464, 61.13590501969861, 77.2962191797072, 95.02076671969508, 90.27767981252363, 104.03681308992448, 86.26671114275533, 34.23929883587745, 1.8244950208933124, 0.417711156750879, 0.23486787933976422, 0.1917657808911416, 0.2437121499209635, 0.12140199166512299, 0.22077923129883506, 0.17352015591196476, 0.1837489465551992, 0.1545680446490165, 0.11809102860429596, 0.11652501465211954, 0.27625479885647375, 0.20389342770701457, 0.25911434763862246, 0.2487117010018518, 0.13479329285121736, 0.3461427938553595, 0.07799160411401142, 0.08496712577799637, 0.09942380245774986, 0.2641056249699285, 0.1626186174971442, 0.17190049282245098, 0.23725677131404802, 0.14149909027882163, 0.1930618484414393, 0.16221603829293482, 0.1612510126564772, 0.1618670392781496, 0.1143244653940201, 0.21136696780881575, 0.18987385015333855, 0.06355513683370044, 0.20029171129628537, 0.2126883622258902, 0.12445048534221227, 0.12046903446917573, 0.20517500087378487, 0.13597328275922807, 0.21011781548300099, 0.11782912612562219, 0.16662246878108672], [0.03278722633577643, 0.042299318743208726, 0.05787814952312939, 0.04270596970473567, 0.01126932382072893, 0.03262318392855025, 0.016065471854451445, 0.029877890614912878, 0.004172902469778614, 0.04070145468558035, 0.05171106895431877, 0.01826951926153514, 0.0015217825491544643, 0.008192782707121826, 0.02914475979313495, 0.054069439985699234, 0.03306686374989729, 0.04820630863128651, 0.05472768571287875, 0.055017837683760354, 0.03324288011137997, 0.016061335937270237, 0.04738074930144414, 0.029554314227894913, 0.05673294383732062, 0.007631133485119791, 0.04472404831059037, 0.0067901935037826345, 0.02962862667176993, 0.01994378718307182, 0.028123932312272733, 0.0849889133185629, 0.026003523511932265, 0.019671565500057994, 0.05602209085238077, 4.576973549781307, 37.32932636814733, 72.55310089357438, 78.24482871640113, 71.13915704911756, 73.68492434101721, 64.38777346764842, 78.91043924516248, 68.4288541732296, 43.612410330003314, 42.577116412501184, 45.89209971889373, 56.79771654067501, 72.03067256558326, 64.63677729329756, 44.337676186715406, 45.41177411233225, 22.82217944822004, 6.724367276314767, 0.2533970641032342, 0.07169920305210738, 0.045682830330465114, 0.04186999924000233, 0.10194447687676839, 0.04971434121891376, 0.05757744469109082, 0.10104094511799275, 0.06470118904666555, 0.14631015308681997, 0.3042702052381731, 0.9275419349151274, 0.08826432223882406, 0.04565107215556406, 0.13529964632564975, 1.0645647274871026, 0.5773011835352068, 0.552969066606414, 0.8754822155160289, 0.9799259240108152, 2.970902208359011, 5.631417459057224, 10.022421633043598, 7.653623838578501, 10.280817574070348, 11.476696268204721, 6.828084549596233, 11.029308765165268, 9.623352827564362, 7.9183519559521836, 5.408524361348921, 5.0931290272743475, 6.732189463030908, 5.576452795536288, 7.891626396486837, 5.854135030700315, 16.060835007698305, 4.165627235366452, 12.332728062906574, 3.943013361384792, 0.44208430534889626, 0.2981872832582843, 0.10282786818401468, 0.8772477111028087, 1.6346873607366317, 5.5744180660093985, 0.9473547459610048, 0.1531630393958861, 0.04355908904765402, 0.041803709651914336, 0.18636803262897078, 0.28054951840350706, 0.3491826613824214, 0.4936119613628234, 0.1618212885073116, 0.09358392953271828, 0.04065735866465876, 0.1130788523944155, 0.11730332167879229, 0.08114445428814619, 0.10263888195397393, 0.060807918724153316, 3.7937551640695144, 25.285624034943122, 85.33365772616479, 77.75194368054791, 60.95942189616542, 49.99085103311847, 65.0236249739124, 31.17282709767742, 32.88829726557578, 25.13761143530569, 20.672130277079923, 55.202641564030806, 60.918362525201616, 66.67821407318115, 70.89845688112321, 84.62239865333804, 86.84826527872394, 52.74229172737368, 4.212993777567341, 0.23387541243385887, 0.026989436535645398, 0.01549914614447663, 0.027601307130328594, 0.01363866235835538, 0.03204476839352039, 0.07968007722088406, 0.06738526235905386, 0.015806069695240548, 0.09744957855512058, 0.045809575747097694, 0.032648595064998634, 0.05045190002889403, 0.09291066082134362, 0.07136000996275295, 0.031912420958941506, 0.06270677872723149, 0.048761235910557935, 0.044958900224657795, 0.056976958162962436, 0.04208330493119936, 0.039098266316878225, 0.03799822151420578, 0.030900437963165106, 0.006125505455964876, 0.03509690864912925, 0.03544497686708647, 0.03409410338668573, 0.07020597511361684, 0.020180617519203695, 0.043976687405618935, 0.0177526933651778, 0.055126740912636446, 0.0523612477756556, 0.019344514904303417, 0.021657748035185283, 0.08338820324429581, 0.016771554984452746, 0.04234226563224389, 0.07830008473848143, 0.021542396261206558, 0.04230606797782164, 0.04484726972277126, 0.014256796679429471, 0.09051002471918061, 0.05976253046443867, 0.017266920842831174, 0.050953293084016735, 0.037598461513557745, 0.10634517702724665, 0.01796888146218994, 0.02400003696581529, 0.07627505388471388, 0.022901011060082146, 0.021385968767947728, 0.039030670548879334, 0.016441461104418964, 0.046942554669634956, 0.02072239681447466, 0.019544115282535073, 0.04802860304593079, 0.03059212970847805, 0.037286453054196415, 0.035409958988067605, 0.05215853708045137, 0.04344112682907332, 0.017889489855376944, 0.03042105652932679, 0.016462743026955474, 0.027653529428906982, 0.08014930607450586, 0.0385697920536322, 0.09591105183766735, 0.03281548731930314, 0.07681465557506008, 0.08031694909497615, 6.319497775646949, 44.74375524828511, 86.26612278722948, 91.44438097553869, 80.52319234417331, 83.4102999779486, 73.81025975750339, 85.39183432056059, 84.89492493291056, 61.81657352755147, 45.05232810974122, 36.698358212747884, 36.239621331614835, 49.70304712172478, 64.13879317622032, 50.42179007684031, 48.99250192026938, 29.09034859749579, 8.241174297948039, 0.5854270475045328, 0.11129054270925061, 0.02472242915011462, 0.04070319753560809, 0.26040762662887573, 0.14167645495505105, 0.12822864712366175, 0.3292276031307636, 0.22323488017484067, 0.729306694721022, 0.8070548131100593, 1.1093492469479962, 0.8082215343752216, 1.1454902108638518, 0.22119045197483034, 2.05686689384522, 1.5404502110135172, 0.7326980127442269, 1.1765846778308193, 0.96861356328572, 1.8908056304339442, 2.9634369573285504, 5.499696914226779, 7.880770746738681, 4.937271196996012, 7.164560171865649, 8.51373391766702, 11.933200340117178, 8.868278918727752, 7.1119930571125405, 1.9093144372586284, 2.499046224740244, 2.0568450756611365, 1.8494658100028194, 2.3804540980246762, 1.5220720681451982, 1.878353943747859, 0.9861180594851895, 2.6945462246094984, 1.740844225691211, 0.8904895102304797, 0.34063909563326067, 0.17052470616275267, 0.9728836760886255, 1.1495133369199693, 2.577648561808371, 0.4694337361762601, 0.3436514759255994, 0.09244242022114416, 0.21618625840112088, 0.4648028878915695, 1.5891156706117815, 1.3989665191019736, 2.42847052793349, 0.5924523189183205, 0.4899010008140918, 0.25425209483552363, 0.11103211060887384, 0.039329762765837294, 0.07240852386119866, 0.04180766266560362, 0.0620176098609884, 3.8202279758068824, 25.236972916510798, 69.86535949091758, 74.9270683719266, 69.22519729983422, 45.751839683901885, 49.6479574326546, 31.27130408440867, 40.08048857412031, 37.1901685191739, 36.06562106840072, 70.01853589088687, 69.18002728492984, 78.00201046851375, 81.3568058321553, 96.19606571812784, 103.61879825592042, 70.0011754805042, 8.699942558042466, 0.191541240520535, 0.049941344562196927, 0.030319662877328457, 0.040199870108476574, 0.03680188328989091, 0.043938923101391525, 0.05364291670341646, 0.07009042607199761, 0.03886252191037901, 0.13378173503423893, 0.07644177759967505, 0.04301107188145961, 0.022394253474269665, 0.05517562498308479, 0.002892886855519347, 0.015191379896996003, 0.03123340275769513, 0.0565390240010475, 0.020484587801019513, 0.0336815650394607, 0.011666749168427722, 0.0033610190063970346, 0.04560054865695777, 0.037314932372781544, 0.040135200796348434, 0.025579422982710025, 0.04857669299047801, 0.0309456275745986, 0.018284534584851037, 0.018135612838030345, 0.061969013073511665, 0.013280130336962402, 0.012432867736225168, 0.039574623618635445, 0.047056238287158554, 0.07660842470584378, 0.06773259130216415, 0.0377754393153854, 0.10905996280451936, 0.1470247752243473, 0.10227747231481538, 0.12664394828701211, 0.24490756883976922, 0.07849434165344124, 0.22039479305667264, 0.19163179211318496, 0.0622051022195768, 0.10218893553340629, 0.10856177582735978, 0.1854382010717546, 0.12662059026620082, 0.14050121479217084, 0.18701076507568362, 0.12617946151764164, 0.19509804885714285, 0.1420254999351117, 0.12106813054772154, 0.17594249528502265, 0.1338417963275025, 0.13443263397822458, 0.157790899937672, 0.1712540984754601, 0.24909722708886672, 0.1558852868695413, 0.17270350618468178, 0.14180517304808865, 0.10681528688198137, 0.1560867220283516, 0.09371206539893344, 0.19387331941435415, 0.1735565450883681, 0.14720938709234038, 0.14676652698507234, 0.085673144748134, 0.18311618857326048, 0.1650530917029227, 12.256087891517147, 62.439085052859404, 109.19072120420395, 101.4428634028281, 89.19914568624189, 96.04045744865172, 85.90590015534433, 94.65268365798458, 87.87405137092837, 68.65206841499575, 63.24376713845038, 63.354256383834354, 76.30989213143626, 89.76360613299956, 82.93034307418331, 62.992558940764404, 65.63009008284538, 38.66618387160763, 11.225824413761016, 1.1445145212834882, 0.3358466947270978, 0.1591884588161784, 0.18185336923887654, 0.3399942947491523, 0.4702197117430549, 0.1395184312376284, 0.3584662067794031, 0.27580253118949555, 0.5575140517565512, 1.3923655378241695, 2.184226743636593, 0.39293621035833515, 1.2133024753101411, 0.9442536833305514, 2.863381216602941, 1.7612716844004972, 1.8011517702571809, 1.5227727015172283, 2.503674376395441, 13.527452599617744, 17.89573742497352, 28.785450996891147, 23.95381069952442, 24.83944658310183, 28.36507489604335, 21.231932909257953, 24.064046952032275, 23.022349765223844, 20.16309880441235, 16.647429389338342, 15.953088479657328, 21.04608904930853, 19.87616369801183, 23.704167527537194, 19.577224177698938, 32.61597494925223, 18.19728728263609, 26.428212427323867, 11.348029778849694, 2.6286771268613878, 0.8032213091369599, 0.845381640378506, 3.4276207848902676, 5.872183326751956, 10.44753791824464, 3.2479654444802195, 1.377566435164021, 1.0027510540619975, 0.3733164228258595, 0.59323005137905, 0.9431671867928199, 1.1857431670350413, 2.1429761571268884, 0.31271822450141756, 0.23014243451818345, 0.31645008392872354, 0.39441644544562987, 0.2507945102068686, 0.2209615755465723, 0.1818186807776651, 0.35698673778003265, 6.62912134201296, 37.03525058684811, 117.65355648532991, 89.8468231385754, 76.90100900588497, 73.38665946837395, 92.63378481711112, 51.06557653796289, 49.755308781900716, 40.42746928430373, 35.87948106950329, 72.83679023865731, 77.66961313063099, 90.52511076773368, 90.9635062371531, 104.85531760800271, 114.63633598819857, 82.49178286521666, 11.545035723716984, 0.351457329647195, 0.14620234919411523, 0.15538857078119633, 0.19636787023515473, 0.09981264570547689, 0.1680750940595904, 0.13531548902392387, 0.2186537050311604, 0.07484985455389946, 0.25369386188685894, 0.1374731143756259, 0.13129253150714984, 0.10698691355965792, 0.15732067516974865, 0.20036596053790665, 0.07320500249343534, 0.13478877293246408, 0.16001322907545876, 0.1297191248065041, 0.14011170504794968, 0.0928398896188986, 0.14605909075227477, 0.08936732797132385, 0.11759672569291246, 0.0923039191853135, 0.14789250769442128, 0.11645684814861706, 0.09298489474120641, 0.154957722932581, 0.10071329697365723, 0.13391819061531177, 0.08212582824090797, 0.24237334998624943, 0.16735972115589728, 0.15716843817743564, 0.1329136808072367, 0.16637422565010287, 0.17863068248956435, 0.2693579544223124, 0.22304260742760476, 0.23163285857487112], [0.014317442114735323, 0.07535949454552705, 0.04714293645754938, 0.039432809252532265, 0.1072689181854648, 0.07279637885550339, 0.015229658437742582, 0.009019331247996419, 0.08840384983247326, 0.09143067854306391, 0.033593817328613614, 0.050536253970236554, 0.031510579114359234, 0.040544081073735035, 0.01643708482715151, 0.05867811385542155, 0.033013509556410775, 0.08009949503766914, 0.022014946105980107, 0.01170401647311425, 0.044207996163036556, 0.0636035574209546, 0.2007763385171852, 0.066301500755212, 0.06321736100700594, 0.046770349595575564, 0.013394400969357982, 0.010817228523533671, 0.04865983651290017, 0.08900870689220967, 0.0723888277406654, 0.09497228769525405, 0.06318947923700176, 0.013769585827005007, 6.950117820693601, 66.10837213454708, 91.2977235547958, 75.73180537069999, 73.73042383501607, 69.8949263172765, 53.91429985723188, 51.28106371048958, 38.964919428671564, 23.227846660921653, 21.254417896270756, 34.68101263046265, 67.7365715272965, 73.03028075925766, 58.35156348443801, 43.32567722566667, 39.33157474763932, 19.101195527661233, 2.551345882877227, 0.18469751662304326, 0.062312163006995, 0.0542499992485729, 0.14024759372395856, 0.24016732319949136, 0.06320598460133038, 0.043948345982860175, 0.10029570244613195, 0.41250797949971696, 0.22845324128866198, 0.10002591692271734, 0.13015308297209202, 0.123369550602811, 0.14171154178198309, 1.0887427075255303, 1.309746571125523, 0.6355596574083452, 0.7893190809315251, 0.07184929499823241, 0.05908776022073242, 0.23967097483335004, 2.1344626526678763, 4.123274462838327, 2.471417294394586, 4.735327968674322, 4.731159960069965, 5.881566126500407, 6.567256248766377, 10.539611635669585, 7.784884975802514, 4.041647733219208, 3.628109794470572, 5.799617027082752, 7.06760996772397, 11.97065995585534, 20.88817834854126, 12.739066000907654, 3.4928292084124783, 0.44136114899189244, 2.161935913947321, 1.5976107889606108, 0.21094111485346673, 0.07582511512502547, 0.2817168525390087, 0.4513336219374211, 0.5131755793286908, 0.1332053151582518, 0.24624269155244677, 0.5200665708511106, 0.050300900268578724, 0.5119795935048211, 0.2960488254264478, 0.8625061569675323, 0.255525654722606, 0.22835567233062562, 0.5399650611704396, 0.40483861200271115, 0.18360896696967466, 0.014368511450987671, 0.04543022049831287, 0.03558849960926079, 0.08926487903320983, 0.14275219561832567, 0.033496792293003494, 0.2748252175027325, 6.448597196609744, 22.609926269900416, 38.281277764228086, 43.125773629834576, 44.7935301257718, 83.92328323856478, 78.29865147990566, 59.40998761884628, 15.408059454733326, 14.048356106204372, 46.34866360695132, 66.16770975051388, 69.13320987455307, 58.3602633014802, 69.07589620159519, 78.60090932538434, 69.30157369182956, 15.986771833512092, 0.46835894546201157, 0.012169389031647194, 0.025813799922264395, 0.007307557098101825, 0.058333064023886, 0.08167336905194868, 0.02477976700080739, 0.0320634915823898, 0.03047366570230694, 0.037313024813850085, 0.06129308986747938, 0.03506128173021059, 0.0714765472577945, 0.012358687442517089, 0.05355949355890194, 0.0461468153122452, 0.048267618647866675, 0.04520602486727219, 0.09322949129367068, 0.020927513025761135, 0.057186004405300465, 0.029409653845153032, 0.051464522708087206, 0.007196980445916134, 0.018679274794375225, 0.03927811311798231, 0.027711543352192933, 0.04131561205271752, 0.038338674818195646, 0.0157545885867289, 0.032888426550573883, 0.03133346533192502, 0.01933742093012458, 0.05772463699442245, 0.0568382656051507, 0.030088777383488995, 0.05247925595951177, 0.011767779886271926, 0.038350495554867296, 0.03679533706857793, 0.03680934115583378, 0.008509752543402777, 0.06755182519555092, 0.10971373457822109, 0.0013187109547171502, 0.016509698471054435, 0.01876038626857823, 0.03320598531694662, 0.09173834711433419, 0.035507646689732233, 0.01792400211636578, 0.006960356953523814, 0.02204530233997972, 0.05179746835041912, 0.05935251637692413, 0.09282124303882161, 0.10296266901517108, 0.04315905325535325, 0.037387266394592104, 0.026137661677034154, 0.040581481486198404, 0.06540519320556233, 0.045603597686896404, 0.07511236990291266, 0.01706489196587955, 0.04955217572710207, 0.08136895635435659, 0.04353539777859565, 0.021538268962514498, 0.030985703549137524, 0.018694954698965437, 0.05223044592346396, 0.023989959079171383, 0.1112200626202168, 10.91746630207185, 83.58260969961844, 106.5628351703767, 84.98630831318518, 82.62264097890547, 77.88906189703172, 66.58771714856549, 64.23432642413725, 55.604861013350956, 40.90362933374221, 32.2449089250257, 49.514306591403106, 59.53524458792902, 66.74900501005112, 55.73714294741231, 41.55934764492897, 39.13114163183397, 22.18329594981286, 2.5234828360619086, 0.1978314505709756, 0.09587202731880451, 0.019610791745024825, 0.1581226926176779, 0.24144105162591706, 0.07427599341157945, 0.24045757859224276, 1.1322721911053504, 1.5026677351805473, 1.3394037345724723, 1.268165034632529, 1.0079382660408174, 1.8070287065159891, 2.9550065580875646, 5.988911592191266, 2.2426779039444464, 0.871349998539494, 1.148892744414268, 0.4011141376629953, 0.2008810933799513, 0.2300250698481837, 0.41494646800621865, 0.1682063402427781, 0.40163734507176185, 0.7021637705545272, 2.103655867038235, 1.7383747259455344, 3.4008920384991557, 8.312783048998925, 3.50415799406267, 2.179803535822899, 1.9347383826971056, 4.4158842582856455, 7.5111613927348975, 12.80034028714703, 19.069928353832616, 14.135010088643721, 5.611672737906057, 1.7528596712696938, 1.001127805680998, 0.7208474292870491, 0.4048838418337607, 0.05853163784429912, 0.6475190253507707, 0.5063118911798924, 0.3359335690977112, 0.4319613420915219, 0.1592900267531795, 0.6669438894717925, 0.12337287542440238, 1.2897889388184394, 0.6529613752518931, 1.518172496749509, 3.352190909847137, 1.7774539128426583, 3.6115409674183017, 1.89915954345657, 0.3551957774306498, 0.33610529536681794, 0.061150953744448004, 0.1112457265656802, 0.11272522620856763, 0.24429382516011117, 0.010433615741109657, 0.22530065158442145, 8.709398411935377, 27.20910926018992, 41.35505883924423, 44.1300533663842, 50.29168898059476, 70.89276944437336, 74.40813879812919, 57.91181871967932, 18.63328422269514, 30.935270709376184, 59.8635155923905, 76.19732795223113, 75.29791278223838, 67.68927558775871, 76.8377725539669, 92.12932878924956, 87.24205555454378, 26.54748974307891, 0.4159294201001045, 0.0577584176414436, 0.08125836390160746, 0.007455806602768961, 0.021828775249061086, 0.059583855777858734, 0.04820058212405251, 0.03829556322025676, 0.04413614477661829, 0.038607912588744395, 0.030481269124955423, 0.043330465428411, 0.019592754204847643, 0.028161434231386073, 0.03353014393078704, 0.0758648138012617, 0.02480576419451785, 0.008924603518549233, 0.04841418658954002, 0.023412401562616713, 0.02936059548970192, 0.08451962317790716, 0.0014252518796579793, 0.01876407306671383, 0.007220247014981485, 0.07680756926176048, 0.09672125876550713, 0.023908244310728004, 0.06100781787667544, 0.04626251757144929, 0.052429061878712914, 0.016407969655589234, 0.045752506027178425, 0.025274979641600966, 0.0066888343257408955, 0.012384493114246477, 0.04059635508324831, 0.053145878858143286, 0.01622597780829716, 0.05827579129066679, 0.12547256920727032, 0.13524692415470077, 0.16155216181951185, 0.16762775999884452, 0.1957433247157643, 0.13845482540707435, 0.17200239783813878, 0.09931651950483361, 0.17412297517782258, 0.128389694127104, 0.1377990388221318, 0.16495798954800253, 0.05762541328646964, 0.21315071160995194, 0.145471133592148, 0.18328540207397553, 0.16362930197388897, 0.19657739528244544, 0.10495662734272981, 0.0732500254807453, 0.1231736619205725, 0.11138474088042014, 0.20166311593305683, 0.11553559677615283, 0.1142420879595222, 0.18774870692962603, 0.23762383468208775, 0.12812074363952683, 0.1818077410421064, 0.11433490717242803, 0.17006899110011517, 0.2128014214817555, 0.15882726368163863, 0.18534938083781352, 22.51655032557826, 104.72625593985282, 115.57461400185863, 93.7846709835914, 95.52064926393571, 93.50686519376694, 75.25094632179507, 68.82022042428294, 55.80578442542784, 37.91692095418131, 37.01306566115349, 51.20718979066419, 83.75885748094129, 95.10450932287401, 78.44975686842396, 61.360072397416644, 55.92315350809405, 30.44819666493324, 4.418559314743165, 0.5889511745302909, 0.31467233093515523, 0.19344591896139807, 0.4169131689254315, 0.5247037317002974, 0.22041725475461255, 0.488831848506966, 0.7683748499520364, 0.9609728474770823, 0.9625082102514083, 0.3752831850321062, 0.8499466663887425, 1.1843643313454044, 1.420567011640918, 5.3205470692726875, 4.356033792418819, 1.4333172887563708, 1.2618057694165938, 0.6263064184496481, 0.3822052490807349, 0.8841836873081423, 5.712575710588887, 6.491373094820208, 7.95023347100904, 15.434054963050352, 17.10383834377412, 25.791815711605935, 21.22677695366644, 23.997213686666182, 21.17041445547535, 14.131226962612523, 9.903240415357775, 10.80006976281443, 10.150114394003346, 17.632701320032922, 24.926742853656894, 16.212242418719878, 5.614864566633779, 3.438443829936366, 4.710798446209201, 4.450232944180889, 0.5117006149263151, 0.28981241007005015, 0.89788262642199, 0.9768408572962208, 0.7260637526069919, 0.7708886602232534, 0.4661765448268383, 1.0327909550359173, 0.41093081896824224, 1.3272535800933838, 2.1267118040592443, 4.812439314780697, 3.152243922795019, 0.5051930350882392, 1.538289107622639, 1.9123323333840219, 0.2543967782009033, 0.4769540229632009, 0.22639537590645978, 0.3267776845924316, 0.18559863520485742, 0.40322838711642456, 0.14700078135055883, 0.7534328259287343, 10.565625775244929, 37.72144571427376, 58.10439532802951, 60.48354033500918, 59.46238263960808, 93.57047034848122, 94.71008362308626, 71.59637205062374, 25.36857431934726, 26.022972752971036, 66.7556808840844, 83.35245286264728, 89.10876643273139, 78.63795218929168, 87.42936441975256, 100.82873790494858, 100.7019433667583, 32.505903436291604, 0.5315290848093649, 0.16519659529289893, 0.14216780842792603, 0.1186787635989247, 0.18386727649598353, 0.21319284644578734, 0.16365323456064348, 0.17782599905565863, 0.11064630873020619, 0.1585691073729146, 0.1659992102894091, 0.10118977301904272, 0.12896100419663614, 0.1472346220285662, 0.10471985254797245, 0.10239564903801489, 0.09371213434684662, 0.08398563691204594, 0.22985466125030674, 0.10847916090560537, 0.132413502001474, 0.23433187826266214, 0.08299977368404789, 0.2455772062943828, 0.09606274490755412, 0.17390977290849532, 0.139598717252093, 0.14495172597948583, 0.23681031059353586, 0.14020959576291425, 0.2444345555118015, 0.1509702659302181, 0.2113493784300743, 0.17414327650781602, 0.14787974466960277, 0.08061104258822818, 0.17993211265533202, 0.1421112251738387, 0.09751781400653625, 0.1524994846793913], [0.021201669080783764, 0.055411844364097046, 0.08833245809880957, 0.09345318130668133, 0.0736812410515643, 0.15949153852078224, 0.015566552305714259, 0.07774781195386764, 0.2609293937923447, 0.11359763947585899, 0.03826207751708646, 0.05567042202117944, 0.06651854112503991, 0.040047525863854155, 0.03207167148620131, 0.05455633482685494, 0.016488878116492304, 0.10001896850524411, 0.15373976570704292, 0.09333452960896878, 0.22998667352141874, 0.3441553779186741, 0.15218024051958515, 0.2261904933519902, 0.4237171022161361, 0.20600507246150127, 0.21517212652871687, 0.09550707835343578, 0.03814480860807723, 0.032991109145504814, 0.25457057290740553, 0.03891047518399935, 0.06053888779734412, 11.651364314940668, 86.93999382757372, 81.7057712616459, 81.17207004177956, 84.89792162372221, 79.28690048956102, 65.53809873519405, 40.64402726388747, 20.98111890977429, 13.468010060248838, 28.15271777491416, 41.01655437100319, 26.946102573025613, 45.24485372727918, 39.10013529562181, 39.35700739583662, 31.31701146402667, 6.849876257681078, 0.48092202133228706, 0.057288231177916454, 0.1378476700835651, 0.07281969091103924, 0.1678440112981104, 0.06760771130962719, 0.16012440375503034, 0.09909918036071524, 0.05910011338851145, 1.0347882994721014, 1.7467773008731105, 1.8640678135618087, 2.1451969540888265, 1.0396177177467654, 2.3229734791863352, 1.7201763992348027, 2.7892006164596927, 0.5671059628648143, 0.50437776431922, 1.8275110784076878, 1.2176556933310725, 0.26815859781157586, 1.4632381090233404, 2.0038072764873505, 0.9606224082169995, 1.0995583981275558, 3.6671984195709233, 0.9705840640010374, 3.5046654507037136, 4.548185313901594, 8.029816400620247, 4.3884605169296265, 10.818934402158185, 19.821634907876295, 49.360020160675056, 64.62304507532428, 75.88600943165441, 78.05943396783645, 76.22607892559421, 58.03385150048041, 34.58730720704602, 7.312164845005159, 1.89258614134404, 2.0262101388746694, 1.3215082883834839, 0.4076655377303401, 0.8155080111276719, 1.591453403234482, 2.4997463678160026, 0.6730808053285845, 0.20402896398257828, 0.07411454804241657, 0.5588441642542039, 0.8219256215999204, 2.1566098255495874, 3.1659398588442036, 6.84430355025876, 5.7704130199647725, 1.6322847864320202, 0.45135648200108164, 0.17532095283029542, 0.20317324377115697, 0.17369329178285214, 0.19970082768028785, 0.17678205104124162, 0.005584859970821849, 0.040155988592173786, 0.18005997272989444, 2.371056834536214, 15.961591197598366, 38.13458111978347, 72.0151242902202, 119.58982667615338, 72.1067508574455, 34.60368702488561, 39.04555943704421, 28.154282800612915, 16.780811548233032, 31.645353071151245, 44.56249467788204, 58.704568955206106, 69.48782351709181, 68.33460746272918, 73.21718954270887, 77.17286063778785, 15.555551359730384, 0.3085284590000107, 0.03224094435873051, 0.05031889184348045, 0.07871174974547279, 0.07900935192141803, 0.07537869270890951, 0.06338349100382579, 0.025704599834317644, 0.03651273489419011, 0.07129607992547174, 0.07217032414290213, 0.07286397079306264, 0.19832019934490805, 0.21855946089471542, 0.23647739942516052, 0.44462811562322807, 0.6548880557379415, 0.3379433548017856, 0.09087973875143836, 0.07490227028967873, 0.09506389648923952, 0.031492028295272784, 0.07238721129514518, 0.019135010924430627, 0.06652070149298638, 0.08077812636451376, 0.02234540387777792, 0.025451486299355185, 0.09683644774580195, 0.041472441742136594, 0.037047839648420774, 0.039834178037821286, 0.037536462017845725, 0.05082651702386718, 0.034213793133535696, 0.05642260928007384, 0.0876624069567169, 0.1226533733067974, 0.11999688682056243, 0.029079433560611743, 0.032255848599297386, 0.010060345145663428, 0.051088438654739055, 0.07260848047031511, 0.09912099854479875, 0.0014950946792997722, 0.08660156670356951, 0.18480334400890336, 0.039517101906840844, 0.06668377862942797, 0.09582630719148344, 0.036765796718217676, 0.01682264538812301, 0.050662689121259805, 0.02357316894396659, 0.055929719800910646, 0.05792427950748994, 0.029293149108848268, 0.023220073274006287, 0.18214146426368147, 0.1895730993560245, 0.15761227887724677, 0.17150822516170242, 0.18842957523320952, 0.11992161868200188, 0.09981347308043512, 0.026065329570443403, 0.0662606223035724, 0.0643821976958744, 0.14288094435488025, 0.07545557729299031, 0.08943537190075844, 16.119440121035424, 98.88285790720295, 94.46292723378828, 87.39078398673766, 92.23429141506072, 86.97415767177459, 77.5126398763349, 52.68906124176518, 33.892565235014885, 21.962815600056803, 30.553510342874837, 43.129676388156035, 31.227216643671838, 57.17002007269091, 45.945165464955, 40.35627042093585, 34.038685291044175, 9.074852505037862, 0.481283001962208, 0.10080564121205, 0.1505657868279565, 0.07598334292490637, 0.2395601678759821, 0.20101911178038967, 0.3394627829472865, 0.48184206228583093, 0.998325394766946, 2.2146971860239586, 3.392545479920603, 5.280136850572402, 5.907818550063718, 4.129032502251287, 4.697378546960892, 6.906410849863484, 6.063922509070366, 1.5643856169716006, 0.9733497639817577, 3.289325857354749, 2.4949995644630927, 1.088147610425949, 1.2105991042429403, 1.9847311968764954, 1.4132611068987078, 1.2975731275735365, 1.0502893838190264, 0.40611598700765644, 1.8200948570043811, 1.818233814931685, 2.6372901614635222, 4.372935285491328, 11.093164951570573, 21.473664660607618, 52.257933924275065, 69.620556523723, 82.03623879340388, 89.3640656625071, 86.49858597786196, 62.48592207508703, 36.36588634983186, 9.812381652093704, 3.036752674848803, 3.067590839439823, 3.656215047644031, 1.5846858437984221, 1.3768178753314482, 2.1045494319931155, 3.4414101223791804, 1.3010184394736446, 1.028000208879671, 0.49581388191830733, 1.4554464432501024, 1.0763512047067767, 4.971562518227485, 4.495667719071911, 2.768072769526513, 8.82499066091353, 5.422892983882658, 1.8955731488043264, 1.3290295557629679, 0.41713698917338926, 0.1784010859386575, 0.17247792393449815, 0.28665162322501986, 0.32759209734297573, 0.10604352990706122, 0.10597370099276306, 2.5193579735294467, 16.464829329521425, 39.40935142578618, 62.07222577064269, 109.44849937192856, 63.63863606606761, 33.22553873062134, 27.285395437671294, 23.172054867590628, 31.29953338253883, 54.54515034152616, 59.12832221677227, 67.8495357882592, 77.67074277324062, 76.05222379007648, 81.11474067934098, 94.7553320853941, 26.693319543715447, 0.09422561243897486, 0.022702824114070787, 0.02773541082147389, 0.10232606527185249, 0.1517908380276734, 0.08442760835732184, 0.033378056325619264, 0.029049559962004427, 0.014754875446669759, 0.008377324669591842, 0.009900914587741418, 0.0758282331028773, 0.03908562969656722, 0.1400838041257474, 0.15400614980007374, 0.28464128593764, 0.30061939791325604, 0.26802796449872757, 0.08406498829924292, 0.0036649126794204238, 0.0755616345052277, 0.039600578677510066, 0.03865022745524203, 0.10271523027650772, 0.04812498456768451, 0.0820707618409107, 0.005954822981654997, 0.03542625367821705, 0.08032183673593306, 0.06768287985675758, 0.03951231385731409, 0.027259068841475154, 0.025187387063558546, 0.03558185762695728, 0.08546790213234003, 0.08134433428847021, 0.059068305417895324, 0.17759696940981573, 0.05492396893039827, 0.09099222344136046, 0.08868299695032258, 0.1309783588494024, 0.16747978245539052, 0.20952959785297995, 0.212475098669529, 0.1506120891821, 0.2850055454238769, 0.2987845866910873, 0.26989473690909727, 0.14085864077412313, 0.11576743796467782, 0.13237233243642316, 0.24369855952118677, 0.2182603035602839, 0.16311079834497746, 0.11237007550775044, 0.1821970056381918, 0.170052673427328, 0.1599637704390672, 0.28738060185024816, 0.46386970086924495, 0.2686420605788308, 0.3947160164675405, 0.40942229991478307, 0.23586121958590325, 0.3694816624685642, 0.21964418010846262, 0.23021910459764544, 0.137929227803984, 0.2597743477071485, 0.2219864786151917, 0.3704185573564422, 24.213336283160796, 115.92163393574377, 103.22780855240362, 99.13585862805768, 108.60965344213672, 98.60988447743078, 83.54688475208899, 62.26885418738089, 35.99776798678983, 28.603600109777144, 44.298370115218624, 60.14965641883112, 39.869304241672644, 62.91515881015409, 55.64252361174553, 56.48364059386715, 45.691011567269605, 11.27222409171443, 0.8454932440673152, 0.19758544441673065, 0.22078093201402696, 0.47307841479778295, 0.37206794465741805, 0.3535478916620055, 0.7153772550725168, 0.49396852932630053, 0.7340397697783286, 2.59208484522758, 3.5346968327799155, 3.7126876173480867, 5.71697808081104, 7.428697972528397, 7.677126680651019, 11.697405096023314, 12.400319326308466, 2.3258931934833527, 1.8245846225369362, 5.368677983360906, 4.022639927364165, 1.5915909313386487, 4.7844943884880315, 5.169808422365497, 3.4138934698797043, 6.792186037186654, 6.498301471433332, 7.272745515069655, 9.686580454149555, 15.66938050331608, 20.901702680895408, 13.937533459355755, 18.56935155007147, 21.2021013229124, 48.69897919316446, 62.68640618170462, 73.29955147158715, 76.24115651653659, 78.01877467863022, 57.23649248000115, 37.20075891863915, 11.318690449960771, 3.10846806533875, 3.229737945141331, 4.040322217249101, 1.8516564537440579, 2.223536002059137, 3.0457934929478556, 4.687532907532108, 1.0995853644224907, 0.8098300125810408, 0.5097006351476716, 2.4596202758050736, 1.7596030836143803, 10.184459647824688, 12.09355369690926, 12.601302554530482, 16.12086296081543, 7.854640406946983, 1.2412561043616266, 1.007799267047836, 0.3071729430267888, 0.3125198690160629, 0.26135987391875637, 0.5903094790635571, 0.34780924959528836, 0.0950718408210143, 0.4680902937487249, 4.631362605479456, 24.141666735372237, 57.037659691226104, 88.9419480293028, 129.62486559344876, 82.42342379785354, 48.34174148498043, 56.43930604380947, 40.93036813120688, 31.402776049029445, 48.17845713707709, 60.221926089256044, 79.61193946100052, 89.08575780930059, 87.60955810546876, 91.64204489800238, 108.53141000193935, 36.35642559297624, 0.49404271728088783, 0.0912803414488031, 0.19769550060793278, 0.22579594274922726, 0.18941405950294388, 0.1637972590904082, 0.21675550769413673, 0.11504168456961071, 0.10699234512304107, 0.16244790246409757, 0.11768665675434375, 0.24751311047903954, 0.18666844634759813, 0.1807082056879036, 0.3120399302532596, 0.38705179708138593, 0.5933840656953474, 0.37675364483748713, 0.2748911623512545, 0.10695407137034402, 0.20157576658793036, 0.14329386574606742, 0.2562441992303056, 0.20190368286303936, 0.1383813116098604, 0.15368833056380674, 0.11465972079144371, 0.13479324688594188, 0.2878021340697043, 0.12839042191063205, 0.14536196606293803, 0.1692754159411115, 0.11875282897944413, 0.13696286917453812, 0.18061284306308917, 0.22944523322005428, 0.24301085771331865, 0.36724122301224743, 0.1575590051229923], [0.03864353184678382, 0.006380204792930595, 0.030562552968941392, 0.05257343114804357, 0.09905295461536416, 0.12684184411961225, 0.07400080696829865, 0.02330827680716832, 0.18624487633426345, 0.2015728554538181, 0.07761344013194885, 0.05064926343038679, 0.09636575566424478, 0.04720802328759625, 0.09252380174134048, 0.10530741900325784, 0.0386227861857943, 0.18431041239490434, 0.3362305354206793, 0.1445033960044384, 0.3653610900284783, 0.349086195590996, 0.5463372579505367, 0.3305682263547375, 0.8171067446950944, 0.3913357607539623, 0.5052282751327561, 0.17936490115619477, 0.040874196021186734, 0.2222064377800111, 0.05666820557727929, 0.30957380129444984, 9.668085498194541, 79.20631931674096, 88.27496467098113, 87.16137240009924, 77.1880558998354, 62.057814982629594, 45.236146065496634, 33.169099746211884, 25.096522646565592, 27.633466566762618, 43.34268070036366, 53.545353874083496, 37.92687200730847, 51.956801799035844, 42.29390559657928, 40.072883098356186, 15.691872354476684, 1.500165017862474, 0.02370001395202933, 0.060500686822999875, 0.08106318002025928, 0.06587984596168803, 0.10953732751189701, 0.04718198778948957, 0.06515122739778412, 0.07980256701909727, 0.27623353225569575, 1.2688329407284338, 5.526134669780732, 7.245514950444622, 6.017245323427263, 9.119013490215425, 2.694886245073811, 3.3824632725408, 6.647848698400683, 7.552011407190754, 2.5468023073288704, 2.4352152885929232, 4.522688436892725, 9.89058881036697, 13.52093165920627, 12.56726912913784, 14.216547339193284, 15.33372171463505, 10.932211472142129, 12.146280157950617, 12.629366132520861, 13.845338148455467, 14.139776748995628, 17.28908404227226, 17.358821822750954, 44.486145742477916, 91.35895175318565, 104.35858080464025, 84.44109885923325, 79.30249583336615, 78.87743642253261, 89.90713350234493, 90.7427630885955, 78.80323302361273, 52.59324166082567, 30.274884777684367, 29.421088733980735, 24.91110436377987, 26.433811610744847, 26.85810615939479, 28.102703632846957, 23.144608082309848, 15.841264647822227, 9.510357187640283, 4.714755627416796, 3.504714970627139, 1.3363984635760708, 0.12303281665569353, 3.461938336972268, 7.970164504743392, 7.670501797429978, 3.0936130689036463, 1.1212564596245367, 0.8029569781595661, 0.08039908904221751, 0.031672687149576606, 0.26832229547923614, 0.30251742671093634, 0.32325420108052993, 0.06697507590175637, 0.05913080287075812, 0.1108838266302501, 0.11498253492097701, 6.420316907667345, 28.01448952767157, 34.143883259065696, 49.0519925086729, 56.82695781030963, 46.32032056008616, 41.65455141375142, 25.392549807025542, 12.1669755635723, 14.393160881534701, 27.06950229983176, 43.70884964543004, 51.178905579351614, 67.95440427718624, 74.53719262153872, 63.399057695942545, 25.84435978243428, 0.19950473981518901, 0.20661877017588387, 0.03495551563138443, 0.16665513477017804, 0.11541804824505122, 0.055850965962294614, 0.04720118212243242, 0.031942907427888245, 0.09387651383275948, 0.1223645275158267, 0.0977370990139823, 0.15943421982228756, 0.41911475240222873, 0.750518995186975, 0.6758224195049656, 0.6260549577493822, 0.7484891073357675, 0.29547717061734974, 0.14396088317997996, 0.06487402614326247, 0.04104127213659306, 0.08587518511640449, 0.031012177632580844, 0.1371468834939503, 0.07944933153809079, 0.039910373142770225, 0.06600639602589993, 0.0533132920522363, 0.044525734960071506, 0.014881525102311806, 0.12450456348878723, 0.04584632881526505, 0.013598564358788633, 0.10507906351478831, 0.15165266640965017, 0.005224471143822396, 0.13393841533651277, 0.048264738157271385, 0.016149991462307594, 0.05908422089452225, 0.015858782290090478, 0.03880295857426621, 0.07545727034730297, 0.09191684560069154, 0.05711007360068541, 0.03543143626302481, 0.1166905202872811, 0.16505732050826474, 0.10902252408765978, 0.013014526696004456, 0.10475968912003503, 0.012728144835320213, 0.08226678075809633, 0.06014078254661253, 0.05284401340289943, 0.1066581545878322, 0.19257211907496377, 0.20937480212699985, 0.384533666074276, 0.39322199179760875, 0.5243174395253581, 0.26544581918466476, 0.6907710625279335, 0.3105025143632966, 0.1694759164726542, 0.1395435435997863, 0.09055379898317399, 0.2157291797019782, 0.12322990043509392, 0.2810844929227906, 14.417506052601723, 94.77785433492353, 100.87092691852202, 96.21942735487416, 85.96158212231052, 78.2229575803203, 65.9192511343187, 50.29060248405703, 34.7526978677319, 33.14439665886664, 40.07189466107277, 47.64116694850307, 43.46176385879517, 44.52653438814225, 46.059251523786976, 44.860469295132546, 20.604318380355835, 1.9644844123432714, 0.03232086648143107, 0.17935351708963995, 0.1870231297347815, 0.27063146834411933, 0.5517875751660717, 0.2423586717416202, 0.7085218713168175, 0.7028335765484841, 1.0550709982072155, 2.292097806930542, 5.900317507405435, 8.106814978584167, 5.961244173588292, 3.5173133784724824, 6.711813730578269, 5.356914795214131, 7.643076585185144, 5.231703913980915, 3.9270882933370532, 3.6599515955294337, 5.728931013614901, 12.258222641483432, 14.767346170640762, 14.522157830576743, 17.147088358479163, 18.576464768378965, 14.632796126027262, 15.730910724209203, 15.41055702394055, 16.263605856126357, 16.93572163581848, 18.87039542198181, 20.440155421533895, 53.79795059081047, 99.78358314883326, 116.71246220988613, 101.89130013988864, 96.83846366020941, 94.41189719784646, 105.42027227340206, 103.0295798086351, 92.16382211254489, 59.2464679287326, 36.59531362595097, 34.5971994246206, 27.91932890492101, 29.102529518065918, 31.48132347291516, 32.75938464749244, 26.812167359936623, 18.434957419672322, 11.301013308186686, 6.012649286177851, 4.344107825909892, 2.442527076890392, 1.7011418722329603, 1.3154782571138874, 5.956004377334349, 4.797628445010032, 2.5301511105029815, 2.133219506471388, 0.8218933846200667, 0.2828244011728995, 0.18811184792749344, 0.9137674901754627, 0.23365738381060863, 1.6241179214369867, 0.9849546477198602, 0.12271480589744546, 0.1171790085913193, 0.10933777692938045, 5.541126458875595, 27.960235303448094, 43.016951391773844, 45.96314168745472, 41.74841373197494, 41.5587043762207, 34.30836000750142, 28.148569868456935, 18.3690772902581, 33.397205183582926, 48.14517974853516, 59.49973929312922, 61.903861953366196, 76.774198778214, 81.41313106782975, 78.05048311910322, 40.578131444992565, 1.1019407477109664, 0.18268866554623653, 0.08270887477744011, 0.1145117432479897, 0.11140170972794296, 0.07467817425006822, 0.02500679907238772, 0.06403832763974225, 0.04284121103644852, 0.08026189801673736, 0.0713162969857935, 0.12237152955945461, 0.33379780789536817, 0.45752569612476135, 0.6038187348073529, 0.6771270978835322, 0.4762127869311841, 0.2916205614324539, 0.12862406340577912, 0.08014274070099478, 0.055000995240745046, 0.042847948779742566, 0.013568518390398354, 0.0831021843177657, 0.08487534844466756, 0.06263662039512588, 0.008182315073246437, 0.06331224099642808, 0.049204486722667376, 0.06371460569601867, 0.044432674429469535, 0.061719498236573515, 0.06198202507690557, 0.10685963571191796, 0.10795626759288773, 0.06386342593618939, 0.028856614972614957, 0.018783478073835857, 0.08988849758621185, 0.11800334984136206, 0.16933799000276675, 0.12358162672288957, 0.28007031508511115, 0.300411818729293, 0.19425334499007274, 0.17614040643938128, 0.29973493408291574, 0.40992218760713456, 0.2513410526538088, 0.1987230390190117, 0.15601952079563372, 0.15681380075552773, 0.25800348950489876, 0.20281410175225428, 0.1845212704351833, 0.3604564725631668, 0.45153841256133975, 0.5223959071501609, 0.5657858401536942, 0.9043293482353612, 0.8199941607252245, 0.8265750398558955, 1.0304120375264076, 0.6509647662601163, 0.6474750212604, 0.35999743267893797, 0.17336536018598467, 0.38078455434691527, 0.2032704143634727, 0.3564531728625298, 24.590015219103908, 114.66436524544994, 105.8983229052636, 109.80205397452079, 100.81329945595034, 82.66239812297206, 63.919371866410785, 51.40506159874701, 42.874271254385675, 45.213643427818056, 62.27323939723354, 76.29023321213262, 55.63012892200101, 72.89941480082851, 62.74384144813784, 57.33746605534708, 25.80780133124321, 2.856855618376886, 0.22142228550247608, 0.20044630783940517, 0.3745971379741546, 0.39469680298239956, 0.6740858513982065, 0.3054505322248705, 0.7471756649113471, 0.33941654188017695, 0.7351613837865092, 2.066168304412596, 11.650821066671803, 14.697190657738718, 17.972243255184544, 18.907373566781324, 9.144667752327459, 11.243022045781537, 20.800848737839733, 21.530495882034305, 3.7782181655206992, 6.304396650483532, 8.647470070469765, 17.291498261113322, 19.702661575809604, 16.67831805444533, 18.74364402986342, 21.065189030862626, 14.509349330779045, 14.803134856685517, 15.24758646565099, 16.459122280920706, 15.763167315913787, 23.396051622206166, 21.605736747864757, 55.83355480624784, 102.09406314357635, 114.09764551347303, 98.30230005325811, 98.07462215423585, 97.64396944353658, 107.87106329394926, 103.05178826855075, 91.45162167087679, 66.19334636196014, 39.72376469642886, 37.377555831786125, 29.038983198904223, 31.05596596194852, 33.24030645432011, 36.2215470498608, 30.26361188580913, 23.066262660488007, 14.761643044410215, 7.702084231761194, 7.608023343547699, 4.927639817037891, 3.6123300992673446, 13.176774074954372, 19.9984553552443, 18.33167749066507, 8.344102194232326, 2.12041272271064, 0.8260932011950401, 0.28023658680819696, 0.14401162884408428, 0.8304603313726764, 1.0761914906963226, 1.7772249444838495, 0.8332172060205091, 0.2084317019269351, 0.21582786714838398, 0.2640068609147303, 10.288299495174039, 42.605651655504786, 49.04789363184283, 64.81297408380817, 78.35834995392831, 67.15925355111399, 60.51319345351189, 37.01358341401623, 19.764697782454952, 27.68276683745846, 42.58911886522847, 61.857177903575284, 72.96400054808586, 90.89570414635443, 94.72438458473452, 95.11143622859832, 51.95838251421529, 1.7204737639234913, 0.34086711404304354, 0.15428859109599746, 0.2652973819884562, 0.23712678151505612, 0.2103089390983505, 0.15903171722687062, 0.1403297336711999, 0.15587522047421626, 0.21041588497258004, 0.2544750570650062, 0.4705339610095947, 0.5582621825798866, 0.9992852722925525, 1.3163143348309303, 1.129341445142223, 0.8068504821388953, 0.5306247946235442, 0.3274695232750908, 0.17152192281378856, 0.21089490442987413, 0.16244983300566673, 0.1170911000020081, 0.2185909930736788, 0.15380563394677255, 0.2000742495780991, 0.21429271887867682, 0.18417198030698687, 0.12677943859730037, 0.18176091774817438, 0.31216725406627505, 0.1874614699232963, 0.06426661801073821, 0.1946106943632326, 0.2632299864724759, 0.16683560976338002, 0.26871909838049646, 0.15897822896799735], [0.03302266813754555, 0.04226524698277635, 0.03935045480067211, 0.015325346649924835, 0.05568547947933117, 0.031100241354696696, 0.09762385589701515, 0.036617045425960136, 0.09863589634938587, 0.14060767037012886, 0.012428058619280497, 0.033560404403796124, 0.06915760677187674, 0.014727735824342218, 0.08990933517775229, 0.06326019681329209, 0.048623309440670476, 0.04489390915560146, 0.11636943751645666, 0.12055751762443012, 0.10519157884822739, 0.21012516992707408, 0.3748653606782037, 0.3747462186842196, 0.4194459168901367, 0.2494666959729887, 0.2631026013724266, 0.10681342528832537, 0.08879244793206455, 0.16350059920260984, 0.1320339207567515, 8.941934166416045, 73.29107915201496, 75.2696874064784, 81.78507374178979, 88.40331246775966, 70.54431392300513, 32.61098961676321, 18.411487917746268, 28.975583968623994, 34.94703169791929, 28.71585442173866, 62.807697634543146, 36.290145381804436, 42.44238299708213, 49.715300606143096, 27.307733335802634, 8.37560078790111, 0.6047269473633459, 0.01653355636423634, 0.0833259356178103, 0.025222205759717092, 0.026331215706323425, 0.08862503473797152, 0.15105131803260696, 0.2053903635110586, 1.1275019761054748, 1.1051148031988451, 1.604166172685162, 2.5044946420577268, 2.971260369785371, 6.0494264095060295, 7.5267533044661254, 5.643589554294463, 4.89979196940699, 7.0085179901892145, 9.429490662390187, 8.851047946560769, 12.22908139228821, 14.678392698687894, 20.218925899074925, 28.367316530596828, 37.474579580368534, 50.9688469671434, 53.93793998226043, 51.30238571474629, 55.967860683318115, 55.060589005870206, 60.05255422284527, 68.63230751406762, 66.08481437929215, 52.994821763807735, 51.5151939084453, 60.75838081298336, 75.62959624874976, 59.7809693121141, 54.252847471544825, 57.8158304768224, 54.10987315639373, 62.25892666847476, 53.229355965891195, 50.22963708446872, 47.13658540479599, 51.93236935523249, 51.46954928675006, 60.58622798612041, 64.82785163387176, 69.16082336056617, 67.58886291134742, 65.59545163185366, 56.78712614120976, 49.80976304700298, 36.70972131913708, 26.061017782457416, 21.510899720653413, 10.66276817552505, 6.0271345992242145, 0.8766463627257656, 4.985451140711385, 3.9517891743490776, 5.325733423233033, 2.0347468098325114, 1.5723249844966398, 0.9509875961849767, 0.47835691381366024, 0.18899978979701, 1.0827653831051243, 0.5395042439622264, 0.22845883373050924, 0.010122641500446105, 0.03573938062594783, 0.06308939368013414, 1.0520092205655192, 10.307461254058346, 32.82413709548212, 55.19784058293989, 50.78006329074983, 47.467762885555146, 43.6474645522333, 46.93558746768583, 17.76835060888721, 14.36868921402962, 14.927911335422149, 45.57174013506982, 72.59446620941162, 59.99952770048573, 75.10565388587214, 74.12237059685492, 39.60637992428195, 2.6955628539285352, 0.10660552434743413, 0.13445866564589162, 0.04752791479169842, 0.07669513053711384, 0.02530276565061462, 0.00798334623874736, 0.045460798897810524, 0.01356166860674538, 0.06956870487380414, 0.1009699211065327, 0.24383455544950502, 0.30164650731509735, 0.4001988464545819, 0.047804338466976924, 0.08467603534940751, 0.17534404272033324, 0.0564205791470745, 0.061293009428247336, 0.08831329057894408, 0.055746927391737706, 0.01807515317904613, 0.14465894249658431, 0.06836052293017988, 0.06988574270038836, 0.0908850247581159, 0.06172594103601672, 0.05141972954715452, 0.07537832498670587, 0.01473139102135094, 0.01581339349579667, 0.0933314039702377, 0.08071020500914705, 0.059314878477204236, 0.06400656180396196, 0.04821604177836449, 0.056530574051242684, 0.1312543190414867, 0.0790501537642652, 0.03600750756900638, 0.019489060373856656, 0.030715640318850358, 0.02066026133815608, 0.03882364294822178, 0.03563142351565823, 0.0635836736088799, 0.15291000055449624, 0.05292114696555561, 0.0386428308763331, 0.05887494099536731, 0.019095762324849927, 0.09006848994402156, 0.040489769270343166, 0.03387670678597304, 0.056412734406729864, 0.0910761866778616, 0.04578701828816726, 0.0586644315250939, 0.1310172454724389, 0.18198492185723397, 0.20116313631015442, 0.3542175750818945, 0.21478247888866933, 0.22382263815210712, 0.05752987829187224, 0.08982741739600898, 0.06160535879673497, 0.22753176008982046, 13.688810083173937, 89.27043868649392, 87.99469563268846, 91.64657915792158, 95.62265442263697, 85.09504425910212, 46.912061091392275, 32.81605112937189, 40.930630930008434, 39.72741642305928, 25.622363436606626, 54.860167657175374, 39.78079595873433, 42.260196747318396, 52.681565592365885, 30.03950530482877, 10.357143955845988, 0.5182197473702893, 0.1149039649434628, 0.08692756775886783, 0.10814865525331228, 0.13684607140960234, 0.280776403003162, 0.6145008809624181, 1.4689265263657418, 2.1226548475603906, 1.8485146352360327, 1.967468110303725, 3.554871543761223, 3.1378765260019614, 3.3137450631587737, 3.452196150056778, 2.318428432749164, 1.9215150922536852, 3.806920599552893, 3.8413587645176923, 8.399561566691245, 11.265754142115194, 15.8019370032895, 23.58791632037009, 30.645435010233236, 41.594088077545166, 55.19117255364695, 58.863793649981105, 57.71552370440576, 59.217273727540054, 59.277729219005955, 62.67647866279849, 74.12060553027739, 69.58298021747221, 58.616480365876235, 56.65086692379367, 68.73717600299467, 88.54540424962198, 71.80752108173986, 62.459532368567686, 63.44429831351004, 61.58056059191304, 67.23080542779738, 64.92824077606201, 58.39893787137924, 55.32216795029179, 57.253684228466405, 58.75648152443671, 63.64120521853047, 67.08296345126244, 71.42584308501213, 73.50579753998788, 69.49504852294922, 60.041344088892785, 49.24313352954004, 39.87680381344211, 29.427493964472127, 24.142500239033854, 13.556784083766322, 5.579329854057682, 2.693205019158702, 3.1709070503711705, 6.54081751261988, 6.358115471178486, 5.918502596116835, 4.143273157458152, 2.0764954147800325, 1.3850634328780638, 1.2638990893479318, 3.6918566448073236, 1.213506928855373, 1.1186620569036854, 0.20451732971254857, 0.04954828783088634, 0.06314745931435498, 0.7308428542267892, 11.311111450195314, 33.5601169063199, 53.36843928983135, 43.76864225633683, 44.153085524036044, 35.03325323904715, 34.57888980065623, 22.07818819630531, 24.290100989803193, 29.403734207153324, 51.69367744076637, 81.46582418872465, 68.58601570129395, 85.11287535390547, 88.70364050711356, 57.62057881201468, 4.67883897404517, 0.09442507109094052, 0.1898727316649691, 0.07150409577955162, 0.039085817388108665, 0.03354589469851025, 0.010497245088880582, 0.0765323828184797, 0.06214897095736477, 0.004642006355307756, 0.166779225692153, 0.21456739204304837, 0.26537377627626546, 0.3504773499744554, 0.14935481632428785, 0.028935663755081838, 0.12074857229186643, 0.04116816310993126, 0.0701710874695451, 0.018113400118665832, 0.08228427820628689, 0.08209451056656339, 0.1170395882499795, 0.11094756514555025, 0.02589931065637258, 0.01785736204305243, 0.018580374758570425, 0.024093731434174606, 0.02030457629101171, 0.07265087577604479, 0.041760850862990466, 0.01633233762526464, 0.008625405964501684, 0.0631166089536442, 0.07672443340021758, 0.0619405260940473, 0.021429463409848755, 0.18771780294276055, 0.13135682160575546, 0.14982746193005195, 0.11337342852305983, 0.12355340404375909, 0.19375776271185569, 0.2810103049682033, 0.07318580433005288, 0.29185783418436206, 0.31340519086487834, 0.15578561883059241, 0.10364562873878788, 0.21590501220235903, 0.3020146585279896, 0.19534592426592307, 0.2351613216582806, 0.1147584388813665, 0.14019779800888033, 0.3246221889651591, 0.23965724653774695, 0.25593937284523444, 0.5889875177414187, 0.5407722114074616, 0.7058373153690369, 0.7289971339125788, 0.4830158315598965, 0.3817825524076339, 0.19346444296740717, 0.1540190353989601, 0.2792530831310057, 0.29632155272749167, 20.92669406244832, 110.78242686487015, 94.77678745023667, 104.1973400115967, 105.17583800900368, 92.41602266988447, 48.93139531535488, 32.24280849579842, 46.48582889187721, 56.124249504458525, 45.8339152797576, 81.71303549120503, 50.54324626922608, 61.24859471474925, 68.77072795744866, 40.95668723506313, 15.654103852087452, 1.4999161925046676, 0.2439193154174474, 0.18207363483886566, 0.20894657429908553, 0.19496628173416664, 0.42043496704389977, 0.6153583478543067, 1.755131459043872, 3.471372372681095, 3.8447023399414557, 3.8634471018468184, 8.42519425576733, 13.051876983334942, 18.47128248983814, 22.72605980596235, 17.74219624457821, 17.661275786738244, 20.637631070229318, 19.501212566129624, 20.099921188046856, 22.600895012578658, 21.640883145793794, 29.066522159884055, 35.34224579411168, 47.47053992363715, 59.41642422829906, 66.31634404582363, 60.392039283629394, 64.42327484007805, 69.52057530803066, 71.00292528829267, 78.5188219624181, 74.12779915717341, 60.28363281680692, 62.609876817272564, 77.05133776510917, 95.56101045300885, 80.553755452556, 70.98041088350358, 71.09707786190894, 70.69649404095065, 76.57211042219593, 70.51101300024217, 61.372302347613925, 61.112049164310584, 65.18474025111045, 62.383924761126124, 62.7564714800927, 69.10912652169505, 76.30686406166323, 76.59442086373606, 74.54353901647752, 65.8660481053014, 59.256693547771825, 45.908958065894346, 35.6746195977734, 32.108129993561775, 19.073487904763994, 11.728713454738742, 8.867323821590794, 14.247614472143113, 14.987903987207721, 16.559776183097593, 5.004675657518449, 4.209372939602021, 1.504513087772554, 1.337407615876967, 1.2194429458149019, 5.273457054168948, 1.5751157508742426, 1.6283176767249263, 0.38031258289852454, 0.144795045677212, 0.16176084417008585, 1.6560713874716915, 18.284824778956754, 49.65225635036346, 75.18384241288709, 68.21874849257931, 65.17951565404093, 62.15101049792383, 64.56113830689462, 24.600134934148482, 21.807623101818947, 29.00789841528862, 65.38735812710178, 93.8653306038149, 80.98085449587914, 97.27896936478155, 101.23794309554562, 72.31642507737683, 6.391965035469302, 0.30558891834751256, 0.2774452994908056, 0.2127882141259409, 0.22813582041811561, 0.21935256107920603, 0.0837400597670386, 0.19725283968352503, 0.22701092755361912, 0.2781738491067963, 0.3891342079206821, 0.5118286128967039, 0.6156617799593557, 0.7650646759617714, 0.40310817259934645, 0.35775313213948284, 0.3214599618748311, 0.2840598252031111, 0.21997402692514084, 0.16585644214384018, 0.19770457108895625, 0.19754985197176858, 0.3259108101408328, 0.2952816343355564, 0.17424343484303645, 0.13917470290776224, 0.09745400654332292, 0.26214364315232924, 0.18977566832496276, 0.11066959014222508, 0.12677219140553667, 0.15803457718462716, 0.23349474334428388, 0.17911580000673571, 0.1844519394780359, 0.13878583667739747, 0.2194688685478703], [0.11201179150732295, 0.031972997446334174, 0.03433461286007397, 0.02906550416692851, 0.013803631731969936, 0.024050026118094404, 0.018366584516761285, 0.014368809267668235, 0.06314740568820028, 0.032966490910058065, 0.008779063092304334, 0.044363711194525805, 0.027681344166217793, 0.032724384143347704, 0.06314600374729884, 0.04954546096644575, 0.002110261726380897, 0.025134157359359727, 0.03979076000471269, 0.08979756294959977, 0.0666645268398908, 0.2122431885330908, 0.1850564747808441, 0.12589259223351557, 0.23289546340463624, 0.19269018854585387, 0.09550696344024713, 0.04897107122345798, 0.06549214418496817, 0.07997096846661261, 4.739243964995108, 72.81393066529306, 82.00242011777817, 93.08433963406472, 79.06895006856611, 73.04933563355478, 35.91761827468872, 28.032418681729226, 29.05898140322778, 25.334896849047755, 33.487509912060155, 55.92781328385877, 73.00232994940974, 53.94778513139295, 52.71865944708548, 14.973375528089463, 5.528627336025239, 0.712006161770513, 0.16905312786900228, 0.1730790118416471, 0.13221281760882947, 0.2092257980257273, 0.1683841492500036, 0.2807410097410602, 0.7141075103032974, 0.658272264465209, 1.27351968278808, 3.409266543965186, 3.6365637279325917, 4.633337518861217, 2.7279939911057873, 4.703518036873111, 4.4164819294406525, 1.2344735908892848, 10.23718414768096, 10.854312219927388, 13.94594890456046, 27.950598039934714, 41.072597196025235, 49.00336296327653, 54.97211602426345, 61.44290893308578, 61.880512083730395, 64.73774302390315, 62.77636181923651, 59.493836126019886, 63.89042477453909, 69.36921888782133, 72.99537166472405, 74.06600613747874, 69.22988060981997, 66.62428148331182, 56.36204711852535, 32.9787745783406, 56.73938305147233, 52.50338800491826, 55.85771268413913, 52.011726748558786, 60.54929887094806, 65.87495188559255, 53.436017805530184, 25.761046678789203, 32.70960977000575, 54.58216574884231, 64.38635749201622, 81.32227328515823, 84.00341726118519, 79.36077440938642, 77.68376504221271, 75.84111398266208, 77.41915410564792, 73.02046698908653, 68.6049529044859, 64.43764640438941, 50.09754342417563, 31.65917942600866, 18.392011388655632, 10.86419168979891, 3.102224142320695, 0.9862015324254191, 4.162578082853749, 3.5793530171917336, 1.3115540483305532, 1.2307179214492923, 2.9822790430438135, 0.09800051068586689, 1.8229967980615556, 1.6581866481611807, 0.40876655929511596, 0.4009595104763585, 0.09684348043294684, 0.05817203617264187, 0.07745302132060451, 0.08855843871471383, 4.280401179867407, 21.797071926055416, 40.70181946600638, 55.96084356307984, 59.0687531809653, 48.80294553695187, 56.06204071352559, 38.78472182058519, 23.33733177954151, 30.33936462094707, 44.01647721567462, 64.82404301243444, 63.82034770904049, 65.35545749049034, 70.64273403536889, 46.0828955711857, 2.3020324351326114, 0.07119124079303396, 0.03956207892887535, 0.07292213218827402, 0.002931307122531918, 0.09974584283847963, 0.08478966151033679, 0.01890561355638408, 0.058213278516045505, 0.07949656851950192, 0.09378090605980928, 0.086431234714485, 0.17730384884822756, 0.05376016646022758, 0.1359982572255596, 0.07332246675486527, 0.0879586608179154, 0.02223614441801704, 0.03666569583959157, 0.041768661129378507, 0.04479245230134937, 0.11930725447112515, 0.11015704667736446, 0.04878174408429092, 0.017697745708808783, 0.038950966761237195, 0.10102014583084853, 0.21749452207117312, 0.0723680667579174, 0.09856568439112556, 0.025544899230402325, 0.05348591847465404, 0.05433781973777279, 0.01354048531802912, 0.06549165388869663, 0.045819305063736056, 0.020638807045836604, 0.019823406041870197, 0.04102426115423441, 0.04807550677909486, 0.04994090789208009, 0.03501270792537159, 0.1070942041734534, 0.07037949402846637, 0.018758794720915538, 0.012620682809351674, 0.0735190372553564, 0.1325968268417543, 0.028837895614185163, 0.05293935304507614, 0.05464405572462467, 0.02863846569051666, 0.018134526908397675, 0.05023324704398552, 0.05556183671879192, 0.16389568606691976, 0.04595877903123056, 0.05038638035916994, 0.09704647841112268, 0.16732256589156969, 0.2437307658575235, 0.20333683418650783, 0.09708656013132104, 0.0289690173080852, 0.018185241928985043, 0.11924276518965922, 8.564434474514377, 90.56356568490305, 92.07891848779495, 99.6781498386014, 90.53211612086143, 81.5729284286499, 53.319794054954286, 36.95628150816887, 20.585865589880175, 29.087948106950332, 48.206274586339156, 41.475424612722094, 67.35446206984982, 43.68076939736643, 46.00207513378513, 16.036508467889604, 5.497371929307138, 0.8489386172544572, 0.07040027033297286, 0.23371457993503542, 0.5531218551820325, 0.47209141775965696, 0.7417796480078852, 1.7815211655632144, 2.1741648835520593, 1.4025590424576115, 1.0047684393582805, 1.4154230683080613, 1.5995472140850562, 1.621814632127362, 0.7914793875909621, 1.4933344553555212, 2.851382931393962, 2.153612644441666, 6.481098936450097, 8.944283666149262, 14.445760846138002, 28.007429261361402, 43.025455090307425, 53.0200465263859, 61.08866007097306, 66.45761212994977, 64.97431293610605, 67.5208568572998, 65.52610020483694, 63.984644028448294, 68.95311032572101, 74.0257312405494, 76.18188165849256, 74.9381451452932, 70.29142302851524, 68.93299641147738, 59.905630080930656, 41.28172620650261, 63.90369023046186, 61.841661007173606, 63.35445642471314, 60.749155398338075, 69.0099846932196, 74.77708478127757, 61.25095990396316, 33.3703879387148, 38.42096905554495, 59.43881311724263, 68.81220309965073, 82.09869861602783, 85.57452263370638, 83.13647147147887, 80.4194534978559, 79.41902160644531, 81.84839648585167, 79.24680602165961, 75.464048693257, 68.06798042789583, 54.65746348904025, 37.34021486774568, 21.48945612292136, 14.215989382036271, 5.5792048285084395, 2.8438730634027913, 3.034086443724171, 4.069420565520564, 6.6086750068972195, 6.087226290856639, 1.7058650187907682, 1.8505475261519033, 1.7343721923328217, 2.326724490811748, 1.889243791660955, 0.8562170041184273, 0.33448554034675326, 0.01908717256399893, 0.08844533349357306, 0.13061279701369424, 4.860390780433532, 24.43302627532713, 42.599222890792355, 51.170825496796645, 48.41480739655034, 42.16345540938839, 48.04914443723617, 35.13265002158381, 24.987518018291844, 44.86216768141716, 60.02351691645961, 77.87688686001685, 72.41930884699669, 74.6925812382852, 84.69764540272375, 68.72429493934878, 6.099040469815654, 0.10849878041734619, 0.03818426979705691, 0.07962963799194944, 0.10835144638774857, 0.03812941790167843, 0.035330553974715934, 0.0211341135324009, 0.09806525277634782, 0.077834211349968, 0.09398877635718354, 0.011807207558904926, 0.039951117529023084, 0.10398877484183158, 0.07130125867983989, 0.15290641526301063, 0.10763091005144582, 0.04939745660991438, 0.031152814138500445, 0.08723777208116748, 0.05186321401608087, 0.031290415021020083, 0.02370903463733773, 0.052025789364932046, 0.047069709943307024, 0.05340192076419631, 0.04587925527425063, 0.15684003160605509, 0.0480578484524402, 0.025107323214591994, 0.07360519916420022, 0.005913826265192081, 0.01451145675438907, 0.02018040876024433, 0.010810456306283033, 0.053100423031156106, 0.214900502394284, 0.12755290394829166, 0.07739604736167578, 0.11435050472256639, 0.08800841822859742, 0.15465248286003067, 0.19935319230200785, 0.23854481026289925, 0.1643851243199841, 0.07136636849252448, 0.16276469514254602, 0.3431941827218379, 0.1333590536828964, 0.14799148625423833, 0.3029793164422435, 0.11957340107689943, 0.05699185474265007, 0.18980743033030342, 0.17880611662422458, 0.31511629420903425, 0.18096365004537568, 0.300715220190825, 0.31175561970280063, 0.2567347559717394, 0.628861781329878, 0.35429160981889696, 0.27795401251604485, 0.1673527957210618, 0.14033253755300276, 0.20464391808115667, 14.831976044562557, 109.01673270810036, 101.85584975827126, 117.03896814777006, 99.51471251826133, 92.32132880918442, 51.898640894120746, 42.53879485591766, 44.79183173948719, 39.474905998476096, 48.78363570859356, 72.31148289095971, 88.15672874450685, 70.89364021055161, 71.82838809105658, 24.122017621994022, 9.354807753716747, 1.3308578705595386, 0.3437698518316592, 0.40617463869913933, 0.6687851971195591, 0.4130233421681389, 1.1021661614218066, 1.9248182182350468, 2.748539120920243, 3.07950405824569, 3.525924206741395, 7.9283932235933126, 11.410937732265843, 14.356767169890867, 9.473719308453223, 12.108156681060793, 11.330205548194147, 5.924517550776082, 17.332302678015925, 15.549471685963294, 19.170823481775102, 35.2321840870765, 49.559700181407315, 57.24998151102374, 63.57275593665339, 70.2270333997665, 69.21716428572132, 70.46251681543166, 66.86367942440894, 64.17571052428215, 65.80276850731143, 71.9255530449652, 83.39473601310485, 77.2796981565414, 72.18122882227745, 74.4111119547198, 65.18894110956501, 48.138778440413944, 72.05732899327433, 72.03669732616794, 71.96336469342633, 66.84181613306846, 77.36173060632522, 83.11619281768799, 70.08518480485486, 38.23203632908483, 43.66509952852803, 66.02127982724097, 70.46411714246197, 84.03736145265641, 88.33724406457718, 84.70146579127159, 85.84437385682138, 83.18936855562272, 84.08260991496425, 79.46375231589042, 77.08245785005631, 70.89025912746307, 56.15777400232131, 37.182174728762725, 20.05900694477943, 17.6302106149735, 7.178006547112619, 6.469970681974965, 14.801702210980078, 9.837848621030009, 11.014693033310676, 7.15859228564847, 5.248391637879034, 3.3672255998657596, 3.5242625926771476, 3.5537526876695695, 2.3793965289669656, 1.6744181513786318, 0.40899868393617295, 0.1585002513902803, 0.22982067758998564, 0.29175055123144583, 8.28909585552831, 34.494743193349535, 60.00790980554397, 77.85472546854328, 82.74785087954614, 69.47144369925223, 77.71737975458946, 55.10358210532896, 35.266136123288064, 46.72571320687571, 63.29450691899946, 84.6821520405431, 82.70980388887467, 86.72164332482123, 95.17389605122229, 84.25604143450337, 9.468373117908355, 0.3278947327165835, 0.16305298935021126, 0.16255307101434277, 0.1427962303522133, 0.13258155104854416, 0.15868432699672638, 0.08622583888110616, 0.26335976176684905, 0.24488080172769486, 0.33048150520170894, 0.34641352932780023, 0.42423304711138055, 0.35109282501282235, 0.35332765670553334, 0.4272601669353824, 0.29410268630712266, 0.19693765578971756, 0.07403284476529207, 0.1547227484444457, 0.14387517326301144, 0.20648260570822224, 0.1893079103601556, 0.15923721265167962, 0.09332081663512415, 0.11380191682086838, 0.11189984307894785, 0.36693681031465536, 0.10868752916013041, 0.24359466267689583, 0.12751881303566118, 0.17909441083188982, 0.2113173099895639, 0.07360968843943651, 0.08862402350191148, 0.10856703885139958], [0.08199544773707468, 0.06386050714119788, 0.04001399036496878, 0.01808162853722611, 0.061331735172819715, 0.08714999372680342, 0.0013161537771661496, 0.05698037874554435, 0.06364580333953904, 0.03562456702873592, 0.07807106275351779, 0.028221386357120452, 0.0280070751755228, 0.02599980223984007, 0.032849195187971476, 0.011177547445010034, 0.017708945914261767, 0.04888197136742454, 0.030591407670609416, 0.1405120013101447, 0.15543372400345343, 0.09310873285416635, 0.11248000912488469, 0.06327278363788802, 0.05097946647794978, 0.1122860050189399, 0.12952548842276299, 0.05051384972889097, 0.12494122594474785, 7.141349546370968, 68.78236170737975, 81.5892376438264, 85.92417055560698, 71.92206998025218, 59.36871643989318, 43.26346451236356, 24.953109025955204, 26.922635032284646, 45.21024665524883, 50.039151099420366, 38.84654621924124, 53.72629281013243, 56.562644973877944, 49.479774044406035, 17.773851733053885, 2.2046100756814404, 0.21414803551329722, 0.05092037045547078, 0.16039258049380395, 0.04143554694770325, 0.2024613335848816, 0.25990890339016914, 0.30746954162755324, 1.1483262070725042, 0.49695048060628677, 0.1425576246073169, 0.42262413989632364, 0.5332895548593614, 2.179707928049949, 8.422856523144631, 19.06220324577824, 21.904897882092385, 26.05895265456169, 35.57445795305314, 42.85325911737258, 49.87449784432688, 55.8900212472485, 63.84858877428117, 64.90546749484155, 68.74805665785267, 71.29678141686225, 67.5544951038976, 69.23013948625135, 69.74444850798577, 73.03622707243889, 75.72702007908975, 73.0876571901383, 75.97781642790764, 81.4178849804786, 81.2584327882336, 83.70436791450747, 78.46076303912749, 81.53397929283881, 62.59465802100397, 36.783218691425944, 55.49121425997827, 54.08370702497421, 55.92205524444581, 57.62854514583465, 59.19034273393693, 34.1519868758417, 30.25357257935309, 49.269405564954205, 64.80309755571427, 78.30706888629545, 80.53528108904439, 81.86145013378513, 73.87426499397525, 71.09150809626426, 74.41458717469247, 74.99922429361652, 76.41976556470318, 81.37887308674475, 83.60885820081158, 73.34823593016594, 64.7085331332299, 53.755447787623254, 36.51087284088135, 21.8628579185855, 15.10889635932061, 4.948058695562424, 10.410474461893882, 5.005990632118718, 3.0523075692115293, 1.4817735144207556, 1.0313599027933613, 1.9533418167021968, 1.0066204722369871, 1.0775616236271397, 0.44979369327906643, 0.1807231137589101, 0.10950408695686249, 0.04317975678150693, 0.10116329702037959, 0.06818968532306534, 3.254824689319057, 13.721379483899764, 38.484185895612164, 54.33411898151521, 56.655887557614236, 59.436577366244414, 56.61470659317509, 41.01863714956468, 17.29935476856847, 17.993257353382727, 30.342461332198116, 58.40718269348145, 68.45574594313099, 67.7337395760321, 73.73546800305768, 60.7517441626518, 4.089783550270142, 0.1174890980004303, 0.027124829169723298, 0.04619602113962174, 0.024889411419750224, 0.09853776814716478, 0.045341185759752996, 0.023435382285125317, 0.07740545492138594, 0.021047367481514815, 0.04544248939642022, 0.020299960611267917, 0.04432394357037641, 0.03997143035033538, 0.03250200031024795, 0.009852379087298628, 0.051953417038725275, 0.0280524448176185, 0.015447957106986114, 0.03794995797497611, 0.013147830782878785, 0.06091705560984631, 0.05178807994290706, 0.029722053009355744, 0.0659485487267375, 0.08552473819544239, 0.024921914615157633, 0.06579516260253807, 0.02806383846027236, 0.053669132232185335, 0.026209415387242075, 0.05392674461848313, 0.07138548238623528, 0.0295728535556625, 0.04119291541076476, 0.04114848231115649, 0.030291250591436704, 0.05760680501078887, 0.013106741657060002, 0.05131469506229605, 0.019580694065699657, 0.04396396268519663, 0.04683897192139299, 0.09395269361594993, 0.05148761259812502, 0.0203574076294899, 0.016564410555386738, 0.028566874773992647, 0.0701125430303716, 0.05317166920811419, 0.08506778973124682, 0.046650724966199174, 0.012501043815826698, 0.04714124723367634, 0.09252302799253695, 0.0236891987057583, 0.05020679402796011, 0.09892815123161963, 0.0697930077571542, 0.04496854144118486, 0.07038550015779273, 0.005082872718752873, 0.031341723759748766, 0.014370315588049352, 11.2890177196072, 84.9802835526005, 92.17866436127694, 97.28868899806854, 82.56551557971586, 74.07973443308185, 62.412448237019206, 31.91446884985893, 26.521784490154637, 47.044009623988984, 46.08843003549884, 40.79702323482883, 61.919520055094075, 58.86360929858301, 44.66457828398674, 17.691146596785515, 2.416386195728856, 0.17086008413424417, 0.028323902327927853, 0.3395061128802838, 0.6291262348813396, 0.5555112527743463, 1.5534285984693037, 1.5766382433714405, 1.7313071051912925, 1.0023802675066456, 0.1745694971853687, 0.5086785819261305, 0.8840845248872234, 3.1045167676864134, 9.701845338267665, 22.080390607157064, 27.560686988215295, 30.502272421313872, 39.47190930766445, 46.65674617213588, 53.558658553707986, 58.66463922685193, 66.02146810100925, 67.04197468296175, 70.844618428138, 74.80629074958064, 70.28449612279093, 72.35950054660921, 71.45528439552554, 74.50920258798908, 76.55901755056074, 74.47371298266997, 77.8674025689402, 85.78236118439706, 84.53882078970634, 85.82252625496157, 80.67658055213191, 83.25714711220034, 67.10727430159046, 47.88874303140948, 62.29325917459304, 59.971953438174346, 61.696399950212054, 64.73469534227925, 65.1775505465846, 41.04639576327416, 36.27748004851803, 51.907395624345355, 69.3555925738427, 81.59471327258696, 84.31060944834064, 84.13642483372843, 77.00608145806098, 74.85723449337867, 78.03792368981146, 79.75921661623063, 80.12169853333505, 85.77676003979099, 85.55354579802483, 78.7481237226917, 69.51155385663434, 56.688584435370664, 39.1862234761638, 24.535327572976392, 12.38379143899487, 4.658811351945324, 1.9771867629981812, 1.5714674563177171, 3.140550111570666, 0.8198731188331881, 2.631699803375429, 4.123556383194463, 2.9134147253728684, 3.3764921993978563, 1.7960882355128567, 1.0138494004645655, 0.2151057679927157, 0.09704565103616446, 0.0690094989934756, 0.08965593627503804, 3.35019025591112, 15.939528845971632, 37.925934560837284, 51.001567379120864, 52.04026591393256, 48.13843327183878, 42.34693996367916, 37.32053633659117, 22.75472644836672, 29.795212245756584, 52.98288599137337, 73.75513476710167, 76.8814520682058, 77.82475856042679, 86.19032690601965, 81.70218621530842, 9.090334100107993, 0.1010203909789843, 0.036251824499378284, 0.03989933381578134, 0.05508664770111923, 0.015128533874127655, 0.10821784065375406, 0.15750338713968956, 0.07498411912350886, 0.07393796477586993, 0.13676829816352937, 0.024000831782036734, 0.037393885394257885, 0.11301271602391236, 0.09532285719028405, 0.06204844873038031, 0.07360759701940321, 0.09535060489490148, 0.0027921046374455817, 0.02222070774634279, 0.0389791204924545, 0.07546492356566653, 0.038267735076407274, 0.02729631795157348, 0.08433838975766013, 0.06820241770436687, 0.0812730115027197, 0.017991184196885557, 0.023733264083162914, 0.0361898671385021, 0.0253769823334991, 0.0899923101608311, 0.014360767259683101, 0.031371298584065614, 0.06598646241811014, 0.17487360344779107, 0.1319163875474084, 0.11663882467415064, 0.11628039511701754, 0.18696784883016543, 0.17242317929142909, 0.14912806962045932, 0.1653590978633973, 0.13159915053796384, 0.15278019461660616, 0.11548301250103021, 0.15314319771864723, 0.0663974302850904, 0.15299643059411358, 0.16670381199688683, 0.1707993793271242, 0.1498237540644984, 0.08254814187004682, 0.10479922691780715, 0.167576692577812, 0.27754676017549734, 0.23165907410363998, 0.26202526724626946, 0.22046767866178868, 0.17521635118511417, 0.23918973372107555, 0.2563317477582924, 0.18626166898156368, 0.20973815762948608, 17.581092734490674, 101.76535283365558, 105.05899060157039, 108.3896633886522, 93.51646715594877, 77.96797214015838, 61.283766608084406, 39.60344599139306, 43.18568783421671, 65.54129546688449, 69.69374010639807, 54.42339997137747, 66.91691383238762, 76.24302356473862, 68.06369719966766, 26.325603223616078, 3.5948488308537394, 0.49679113431803645, 0.09331271908576451, 0.500249776148027, 0.5980307873218291, 1.3637120108450613, 2.7996743254123198, 1.962756853430502, 3.8925677585986356, 3.647733657590805, 2.592016939193972, 4.229175515713231, 3.620756821286294, 4.8410098591158475, 12.408436671380075, 26.875368510523153, 31.01172358758988, 33.4554131569401, 44.861575403521144, 51.374922106342936, 58.37356405873453, 62.030323090091834, 67.7249534668461, 68.77559169646233, 71.92300350435319, 76.0232453192434, 69.76257770292221, 72.91763028790875, 72.62956357771351, 74.00874737770327, 77.53384420948645, 76.95305885807161, 76.1483689277403, 83.60732063170403, 87.63636358322637, 88.58645577584544, 82.52325596347933, 89.01886570838191, 70.96083041160338, 55.561326626808416, 70.8780840904482, 67.03701680706394, 67.127545110641, 72.19651822120913, 75.15847252261254, 49.1283610559279, 42.86859950711651, 58.67394701127083, 72.43040915458434, 82.66471232137373, 85.37955730192124, 87.33251325545773, 81.95357876439249, 78.76309148726925, 82.01900389886673, 82.76940822601318, 86.24844074249269, 89.85476201580417, 88.84221000056114, 81.80599566428893, 70.60147070115613, 60.1406349674348, 40.06661515082083, 26.904492109052597, 20.706619678005097, 10.628851440645034, 20.51375085307706, 16.418379641348317, 12.526349002315152, 8.485109440742, 7.761185034628838, 8.00318301685395, 4.066646224068058, 4.9106010410093495, 3.0647108391408, 1.6206939374246907, 0.31737230057197235, 0.15789381618941986, 0.20500131341959202, 0.20645468946426146, 5.314163411817243, 24.443738268267726, 57.47263877622543, 74.15938992654124, 75.82446744365078, 76.51337685123568, 79.05117388694518, 58.846625435736875, 27.81691581972184, 32.143582336364254, 48.528034456314586, 78.89424770109116, 88.01534298927554, 88.62287106052523, 92.77500583279519, 94.66240329127159, 10.448870543510685, 0.42613600951529323, 0.11240544578721447, 0.11549076531082393, 0.12688434667765133, 0.22590650455845943, 0.17522278632367813, 0.366633715288293, 0.16126834156532444, 0.3956682331139042, 0.2833081703753241, 0.2719625001472812, 0.2921881100102779, 0.3085624733038487, 0.20941142112978045, 0.15675081300639337, 0.17091668271009, 0.1496407509811463, 0.0898209056486526, 0.05785784819313596, 0.10916062675776983, 0.2288804732022747, 0.11033009827858019, 0.09596292365102038, 0.2145144400457221, 0.2663525914953601, 0.18751802253386668, 0.14232142437850276, 0.07200766835481891, 0.14786051586270332, 0.10699035329443794, 0.23230859408936194, 0.22623376199795356, 0.13184871134017745, 0.3181192362981458], [0.00515795651740665, 0.06316381146109874, 0.019521749345585704, 0.013602932017566937, 0.03836651062292438, 0.03035070284480049, 0.09693993090261376, 0.04922836185282758, 0.00629209749956405, 0.042444182139250546, 0.037769590234083515, 0.07171725208360342, 0.028363342449489622, 0.0826182772195147, 0.10364807255926634, 0.024069536462306015, 0.07228588084540061, 0.034366259952225996, 0.07558475503878248, 0.005489217723915053, 0.07419947654970231, 0.06559843888446208, 0.19231256848621756, 0.09812140702119759, 0.08603699054689178, 0.03716921478870415, 0.01222163048242369, 0.18182635697866642, 6.386736516029605, 73.71857827709567, 78.37498080345893, 82.2636656607351, 74.18672100190194, 71.11992959053286, 36.0318612283276, 20.64325574905642, 26.392887561551987, 39.08114317924746, 30.219159664646273, 38.02497440768827, 60.40105681265555, 46.53541549559563, 31.950119272355114, 7.434283427653774, 0.3761203965592769, 0.06594667181132302, 0.021212265991996375, 0.08821779005830327, 0.1615188829600811, 0.5421330287091194, 0.4570446848388641, 1.015978328162624, 0.8977553945395255, 1.9661120733907147, 1.1140531493771462, 0.27747434954489436, 4.569771587848663, 19.532150260863766, 44.672830950829294, 62.54759742367653, 66.55363175176805, 68.14984813813241, 72.95454763597058, 72.76044522562336, 70.98751037351548, 73.92578140381845, 72.23789138178672, 70.3607548436811, 70.63543058210804, 73.44974687022548, 70.11592049752512, 70.57799139330464, 66.74315283375402, 74.50116172913583, 73.2520672582811, 76.23330393145162, 75.6893104122531, 79.06516890372001, 81.04371440026068, 84.21779048058295, 75.0686659351472, 75.28208994096326, 68.75213592283188, 82.83599438205843, 53.00189771959859, 38.65466387041154, 60.26710394890078, 56.86631487261865, 64.97793328377509, 44.07329274762062, 37.484059949075025, 49.539943202849365, 64.83422548540177, 79.5766616636707, 80.84343817926224, 79.30934429168701, 71.2835551846412, 64.85306462933941, 65.22163798732143, 65.90570326774352, 73.44702474532589, 69.59487284383466, 75.1065246520504, 77.02908223675144, 81.67529444540702, 75.25959122565486, 74.47265394272344, 61.63251630721554, 45.35006346241121, 29.789224747688543, 13.832716941833498, 7.644663183919846, 4.04794460823459, 6.437207123925609, 0.8557436230682558, 1.3113819543392429, 0.9100245071514961, 2.5625761189768395, 2.4054040495426428, 0.3841981808504751, 0.06830661332294827, 0.20610282528063945, 0.08980637296072899, 0.02928711999688418, 0.027911593807080103, 0.07663525310495208, 0.7381260214794068, 9.039738466662746, 26.14988692345158, 47.487590466776204, 68.5234695865262, 59.98683098823794, 37.25463659532609, 34.64067497561055, 23.179295562928726, 27.233063174832253, 21.97002491643352, 33.567000665972316, 58.205561099513886, 69.5713778465025, 74.05237197875977, 52.243711410030244, 5.400098619922515, 0.07880700511797782, 0.08512363754092686, 0.05309493018073901, 0.042603896149704536, 0.033457855874251936, 0.03913812970201816, 0.048968137106707985, 0.06932843671811205, 0.052570148461288026, 0.08192741146851933, 0.026276589806882605, 0.010525179527429564, 0.06074170574485775, 0.014289056641920922, 0.013796639264441066, 0.03522893241156013, 0.029021277911059802, 0.02972559042034611, 0.09762278337392116, 0.0448623808070777, 0.009185513913361056, 0.03305569035752166, 0.047894189089176156, 0.05469069132701524, 0.020066640873049057, 0.038409534120751966, 0.004173998454315288, 0.011018560260474201, 0.030286608098615563, 0.031054050083302205, 0.024942677513125445, 0.14728218076690552, 0.048763204756523335, 0.058570727480635534, 0.06749156471942702, 0.045793702405306606, 0.023705265484750274, 0.044889691841578296, 0.03385356710022015, 0.03599398994758245, 0.08869097192561434, 0.12573568210486444, 0.0744661440952651, 0.02031198244601969, 0.07782099633327416, 0.05402996730540068, 0.08522020292378242, 0.022423749774574273, 0.034285621537316235, 0.014311500145272623, 0.06481349753636508, 0.054067559239845124, 0.047747858634759346, 0.050876320399824655, 0.01004916696523827, 0.12881947711350458, 0.07372412665356552, 0.06954140150018277, 0.006708143093067432, 0.006117045451256057, 0.06081538425097543, 10.477678391241259, 90.25125088230257, 90.48916616747456, 92.95436797603485, 82.64323342231013, 84.97451766844719, 49.357564756947184, 31.04251615462765, 24.851286257466963, 27.673182525942405, 34.39052974024127, 49.017299144498764, 52.50568651383924, 42.77132864921324, 36.24928212934925, 8.180872759511395, 0.3390802292814178, 0.16369285662808727, 0.02548899587934777, 0.172720298831982, 1.0182574090938414, 1.3467266771101183, 0.9495574632479299, 2.6352669538990146, 1.703547265741133, 1.1568087002923413, 0.8774172310386935, 0.5857967308932736, 5.681542408081794, 23.790169415935395, 50.59650813379596, 69.13141342901415, 73.75458563527754, 74.31794781838694, 76.91702796566871, 76.93365881519934, 74.15931932387814, 75.68837688815209, 76.27145290374756, 71.62592318750197, 74.41756033128308, 74.67118863136538, 73.89754033857777, 71.84544255656581, 67.2059376009049, 76.23856775222286, 76.88171094463718, 80.50227826641452, 79.73735332489014, 80.97584170679893, 82.72208090751403, 86.9237865940217, 77.16110137201126, 77.08779227349066, 70.41373821996874, 84.90251079682382, 58.71689304228752, 47.477176573968705, 67.04587351891303, 63.48564009512625, 71.34975694840955, 52.12325149966825, 45.07426984848515, 53.882038362564586, 68.02144542817148, 83.66796047456803, 83.95231662258026, 81.35199700632404, 75.03874609547277, 68.2984902781825, 70.67251266971712, 71.05048794900218, 76.99811120187083, 73.38261942709647, 77.66933071997859, 79.90676833737282, 82.46847614165276, 76.63439766053231, 76.38165581610896, 66.29084863970357, 49.22237634658814, 33.92798031530073, 15.857135538131962, 9.354341972258783, 3.7856348772202773, 1.8020574700447822, 1.2845068545110765, 0.9819683757039809, 2.016610137877926, 3.9878276663441814, 4.200400027536577, 2.2372253191086555, 1.5615943602977262, 0.9210521896039287, 0.3604297207728509, 0.20036755400078915, 0.053511570928798574, 0.08048825401572451, 0.5587130100015671, 10.403255339591734, 27.238074002727387, 44.36996121560374, 46.053101247356786, 47.97666295882195, 29.201498762253795, 20.89892368162832, 16.231109019248716, 22.792436115203365, 32.92530875052176, 46.92873900936496, 69.33714174455213, 74.6843207267023, 82.84920492479878, 70.83608335064304, 10.829150215271982, 0.25373903043087453, 0.08124312641279352, 0.02299475915459616, 0.04224147144404631, 0.029161709488459656, 0.035587545829795064, 0.057065950766686475, 0.058820364891641566, 0.058831155240055055, 0.12325046989586085, 0.01220903599694852, 0.03244143722939395, 0.03965774032798025, 0.1146690977076369, 0.019585133545220863, 0.06431408481852663, 0.019656780003119382, 0.05100906428490436, 0.03574675039177941, 0.12971544758446757, 0.05687515656914442, 0.07245185379419597, 0.05105009978456844, 0.05389872112221295, 0.0520317227159056, 0.03819976392532549, 0.03683459141381806, 0.0305829577208046, 0.006530876093048363, 0.009686995068595055, 0.03974577149135932, 0.05592219681749421, 0.060166772079443744, 0.1628438167033657, 0.15827566505439822, 0.17749471199368277, 0.20155353471636775, 0.08360344330750166, 0.18236317010896821, 0.19613796724907814, 0.2089028613221261, 0.16906115647044875, 0.30158405582751, 0.08557342308303041, 0.15613864746785935, 0.175600360418039, 0.14463199152340814, 0.33715311978613177, 0.08568151042826715, 0.108504043441386, 0.21348063503542256, 0.17914707171580485, 0.11333893158382947, 0.14317643978903372, 0.14745387639249527, 0.23687976412475112, 0.17555644825821923, 0.14163033646200934, 0.1036028963543715, 0.16320928660852296, 0.47161910923257955, 19.131266378587295, 111.26902826370733, 99.1480964229953, 105.4060419144169, 92.28182269680886, 94.31262985352548, 53.61134382986254, 34.77682436666181, 40.505877464048325, 59.844676448452866, 44.266987231469926, 53.409361377839126, 82.12779475796609, 63.70025257910452, 48.02680653910483, 11.16970314133552, 0.7174656107541054, 0.5032653740096478, 0.20304604253220945, 0.4722302022480196, 1.6183389218584185, 1.7805842093883024, 2.5066968077613465, 4.222235862285861, 3.9856100563080084, 6.600756231815585, 5.1461251512650525, 2.5917056010615442, 7.815590760400219, 25.67391907015155, 54.39717892677554, 72.76701127329181, 75.89517993311729, 79.03540595885246, 79.93802962764617, 77.48568534851074, 74.948178568194, 76.42767306297057, 76.48002886003064, 73.45007634931996, 74.05892233694755, 75.9414089879682, 73.35613558369299, 71.31854272657826, 68.08693332056846, 75.2215285455027, 78.82770861348799, 81.85765327945833, 82.11944795423939, 85.02111542609431, 83.6686037432763, 86.9133609341037, 80.08234931576638, 82.39078967801987, 75.7288557483304, 88.37689138227894, 62.90898499950286, 54.424357029699514, 73.442474795926, 69.01993182397658, 78.03076928661716, 57.7979640806875, 53.26426506042481, 56.568810939788825, 70.75554140152471, 86.1708797947053, 85.08787416642713, 84.36455772769067, 77.33773354561099, 70.68049077064761, 72.54224377293741, 73.60346455727854, 80.68964204480572, 75.75850886683311, 79.53988552093506, 83.07030893141224, 85.54697975035637, 78.43945672435146, 78.66361233495897, 67.04071167976626, 52.250210777405776, 36.50735447483678, 18.576431428232503, 15.103155970573427, 11.656537921197954, 14.744053175372464, 6.563461845920933, 6.675371969899824, 6.58410478984156, 9.153693126093957, 8.290635385820943, 3.1047356849716556, 1.3784911339321446, 1.0857253016964084, 0.5427389123266744, 0.29054270636650825, 0.09869447143207635, 0.14566190480705232, 1.2366185145032023, 16.699483163895145, 41.50017869087958, 66.23202877659952, 91.00021177722563, 80.88473289243638, 55.14183305924939, 51.24641349238735, 36.540988799064394, 40.4613075717803, 36.4536533048076, 51.16627162502658, 76.36796674420758, 89.1514261307255, 92.66818400352233, 86.15358998698574, 11.56435045503801, 0.2866158928842314, 0.25383230929653494, 0.13417859922253317, 0.163657478687744, 0.23946886551716637, 0.17509258202006742, 0.22900551407327577, 0.20112328441633334, 0.15542378018219627, 0.25348539404090376, 0.16314826004447477, 0.1395698357373476, 0.24121016804729742, 0.24454435123310936, 0.10239825373695743, 0.07964577946451404, 0.07247086043559736, 0.18503085680065617, 0.20020024039812628, 0.24061537738288605, 0.13644199067306134, 0.15992080822827356, 0.16869466000747296, 0.1621085255136413, 0.1404016233620144, 0.1601818450275929, 0.09478572996393328, 0.17421849102022188, 0.12315889174539237, 0.11347185549957138, 0.1397610666050065, 0.2479610727318833, 0.17370800067099834], [0.03896981635461411, 0.02268693545052121, 0.008154160384419224, 0.11166731241129099, 0.0378697409084247, 0.0841837166057479, 0.07841822315728472, 0.017676716595287287, 0.023553786919482296, 0.02626542982104565, 0.07156712949396142, 0.04035451644731145, 0.06050059106200934, 0.0352462153551319, 0.07977808284903727, 0.028343433739557385, 0.025631622298650687, 0.021258999270597295, 0.010986574174415682, 0.029595259712227893, 0.055930420771361365, 0.04445816983558959, 0.03932387154969958, 0.02853079586319866, 0.003892276562832957, 0.03106991384899424, 0.047411507731604005, 6.298758733657099, 81.2392210191296, 89.37664862601989, 79.79389821329426, 75.10857997402069, 54.44037206711308, 27.50872538935754, 23.22302999035005, 36.43953277218726, 47.52052660911314, 37.57299577036212, 53.73866004328574, 64.41445735193068, 56.23671562440934, 34.80943887464462, 5.430663199194017, 0.6497846231345208, 0.015115637741532299, 0.0397029931416675, 0.0935846496553671, 0.21831267333078772, 0.32528120844114217, 0.3869446979895715, 0.4412883093520519, 1.5359225700939856, 1.1679678434325804, 1.1344618542540459, 0.9077630155990202, 11.66361681876644, 44.77208652803975, 74.28728272837978, 77.41430605611494, 78.36617900479224, 78.84766563292473, 76.14006919245567, 75.42599385784519, 87.81218774857061, 78.05045174014184, 73.9372347247216, 79.76408819998466, 78.1852714477047, 77.33659605826102, 73.08390740425357, 71.25976208717593, 71.14396587494882, 72.30115921266618, 74.22486997419789, 78.34657499867102, 73.77578212368873, 72.777099609375, 71.85921007587065, 74.63648350008073, 76.88017337552964, 75.08699909333261, 66.797987568763, 66.55195297733431, 72.62142073723578, 76.30185127258301, 35.33632693752166, 33.318906830203154, 64.28746277286162, 52.356487397224676, 38.10732064708587, 49.62845933052802, 68.70407119874032, 75.36833501631214, 75.5205386684787, 74.50844949291599, 71.8572332013038, 64.65982906280026, 64.03003761845251, 67.83344622581237, 74.0494066669095, 75.23706897612541, 78.21719169616699, 74.47558003087198, 75.22049303977721, 75.56643824423514, 74.50109112647273, 71.17325813539567, 67.74823665618896, 65.10708516643894, 54.44282354847078, 39.212801456451416, 21.413981876065655, 12.215434485866178, 13.363752480476135, 6.801531084122197, 5.415615026027926, 2.439260723129396, 2.6580095916025104, 1.7948973058692872, 1.8023694210475492, 0.148256414780213, 0.8458332645316279, 0.38316003978252416, 0.255300976456173, 0.0932971828226601, 0.046555841146337415, 0.022028362220754067, 0.19848515339676412, 4.863874825739092, 19.92314584793583, 40.54459125764909, 55.527005887800655, 59.66047017805038, 50.4775583359503, 62.953429375925374, 110.01630952281337, 81.88927542778754, 33.782923221588135, 42.51725712130147, 70.12009389938848, 66.44000068787606, 81.47418668193203, 46.45949802091045, 1.340467677481713, 0.017733100666514328, 0.027099837466413458, 0.0072862502777077745, 0.05328895343888191, 0.08661044566261192, 0.06558327800444057, 0.013105208523601536, 0.008253307483579603, 0.02672268472041094, 0.03942426737217654, 0.02767039868499964, 0.04046795108625966, 0.03479832971108056, 0.011207940068186052, 0.04716377021865018, 0.022133546092757778, 0.01912095321102008, 0.0736786286917425, 0.06682838538601514, 0.053721643728955146, 0.07503376928188148, 0.005101237761517686, 0.11636084200994623, 0.05486912852633865, 0.05049180171843018, 0.04698147576662803, 0.04744200952230923, 0.03646415342847186, 0.018859782346314, 0.05281153510534956, 0.03294239744483944, 0.03293134279609208, 0.06948566094281212, 0.07277342686129194, 0.09120290528141684, 0.045154696976345395, 0.014946932731676969, 0.031200886155749043, 0.043207615568873384, 0.09390628400949702, 0.02780668189628951, 0.030966292796356064, 0.026613716374061284, 0.01204221556338692, 0.05000674165785313, 0.03537630474555396, 0.019053543219342828, 0.03319940845211668, 0.011642303302763932, 0.025381172834444913, 0.04111909134794147, 0.010591316855542604, 0.04435523826208326, 0.051528862602407896, 0.03813989798448259, 0.023865190169383443, 0.019728819081079096, 0.09162406211779003, 0.05331459440170758, 8.065708048882025, 95.9113722462808, 101.43802319803547, 91.30672147197109, 90.37164411237164, 72.8359273172194, 49.48837187982375, 39.01261544996692, 41.95163565297281, 42.97502909937213, 52.88797247794367, 54.39048736326156, 46.752479460931596, 52.428870816384595, 40.128812174643244, 5.732947030375081, 0.15150828947944028, 0.02686772240145553, 0.02936356982606794, 0.046941252320163676, 0.33098424274113875, 1.0075272139041656, 1.3978319735296312, 2.445832899501247, 1.5861794088155994, 1.0056068459826133, 0.7278647333864243, 0.8155208201177659, 13.22635087274736, 48.94633170097105, 78.82999927766862, 81.46382377993676, 81.88340756200975, 81.26682666040237, 79.78184084738456, 77.57248740042411, 88.8043434389176, 80.49739883792016, 78.09570020244968, 83.22718020408385, 82.68978411151518, 80.91687279362833, 75.4460685483871, 73.76482302142729, 70.83631869285338, 73.58786921347343, 77.29529350034653, 80.29505945021107, 77.68058007763278, 76.14700394292032, 74.04191493988037, 77.73593256550451, 78.22903725408739, 78.36169181331512, 71.74754804180515, 69.92710544217017, 75.9712190012778, 80.01988949314241, 39.96158192234655, 40.31648974264822, 69.43971956929853, 57.31546548105056, 43.94414478732694, 52.45493888854981, 69.81431376549506, 77.60427428830054, 79.76167986469885, 78.09560606556555, 75.14442259265532, 66.8534577277399, 65.64111586539977, 70.30992092624788, 77.18560834084788, 76.83837659897344, 80.89926135155463, 78.94880787018808, 77.23279445402085, 77.46255905397477, 75.1027121082429, 71.25452180062571, 68.38664162543513, 66.89543493332403, 55.60543760176628, 41.946815060031035, 24.036278532397365, 16.557071708863784, 15.575174977702481, 8.74441635224127, 6.872349967879634, 4.4751228344055916, 2.791291484909673, 3.1465331969722627, 2.8834218315539824, 1.9058240181015385, 2.727232070699815, 1.3518380157409178, 0.6276603716035044, 0.4011575901700605, 0.04764403839926085, 0.04132749790686273, 0.04822231603846435, 4.815018763465266, 20.42475031268212, 41.88648900678081, 47.022416976190385, 45.84867515871602, 42.15235510180074, 52.97437837046962, 90.2132038916311, 69.52405837274367, 38.16485005040323, 50.31526634770055, 79.53950112865817, 78.0002297124555, 92.02069482495709, 65.70741568842243, 4.5371835558645195, 0.06405010624157806, 0.03221939047498088, 0.053645054088725205, 0.04488079373033778, 0.04547034052290744, 0.03779626541560696, 0.029819259990847884, 0.10022875402242908, 0.016060916504131693, 0.06837687124648402, 0.05842831939639104, 0.07560866464289927, 0.04044611758041767, 0.06190467700963059, 0.031167069119551492, 0.013714226398376689, 0.013593588617720432, 0.025896250135115078, 0.01637420049988695, 0.02704204187818593, 0.030392448891014345, 0.028323438844733664, 0.0459715458864887, 0.051440551816936464, 0.061765861877750974, 0.06996880195313884, 0.05023683233547115, 0.022009160226931977, 0.051457624086329055, 0.021172879496589306, 0.08991118911052905, 0.03225379931409994, 0.25507246775011866, 0.14594964743141206, 0.22505991611509557, 0.3584681986080062, 0.13670911021049947, 0.14571810501717752, 0.15873868859583334, 0.09791846266917645, 0.09326910570023522, 0.13872865587472916, 0.21523134512526376, 0.16513425105762097, 0.1575262318815916, 0.1782873831689358, 0.17224691778181062, 0.1804588440685503, 0.07137816624655839, 0.23513922768254436, 0.2263614688549311, 0.11629270614996073, 0.15581272302135346, 0.16086360199316857, 0.18236104038453874, 0.12482576117280031, 0.09284761944605459, 0.21363003750241574, 0.13007406866358173, 13.421108318913369, 115.7469629472302, 110.06253073292395, 102.58450062044206, 97.11750891900833, 75.67922992091026, 45.132132653267156, 36.54503668508222, 53.23153288133683, 71.84185751022832, 55.08778672064505, 75.54920334969798, 83.32642401418379, 74.43938439892185, 51.1636907054532, 8.890147113030958, 1.3242311487274787, 0.16585513979436892, 0.22799611662424382, 0.2755268008237885, 0.5258304938193291, 1.8013296252296818, 3.0767402581630217, 3.8977597509661033, 5.21668908096129, 5.3939934507493055, 4.541802146742421, 4.306856586087135, 15.366065579075968, 51.4034338151255, 83.31713584161575, 82.77324430404171, 83.17021954444148, 84.08939561536236, 79.80451214698054, 76.25250001107493, 90.6758160744944, 81.68080145312895, 80.43531556283274, 85.28166278716057, 85.2427528750512, 81.9663578464139, 77.07533482582339, 74.0981460386707, 71.36533660273399, 74.70205768462151, 78.80763392294608, 84.55682446879726, 82.18332767486572, 81.49216682680192, 77.68960152902912, 81.77347921556043, 83.89909790408227, 81.83157736255278, 76.05873492456253, 73.3266628942182, 79.22791588690974, 81.86771023658015, 43.60831145317324, 45.43259797557708, 78.4630693927888, 64.12312722975209, 50.77804719248126, 57.33977633137857, 70.80965442042198, 81.78978843073692, 81.98730330313407, 80.79859764345231, 78.5888127357729, 70.56033288278888, 70.29062286500009, 73.50910802041331, 81.46349430084229, 81.04503231663858, 84.96584138562604, 80.73289794306602, 79.2020360885128, 80.82246134358068, 80.05002898554649, 75.78134490597633, 73.13081895151447, 70.79341580790859, 58.04788181858679, 46.058984802615264, 25.83563643117105, 17.08455401082193, 18.866506391955962, 9.559151472583894, 9.93366918256206, 7.138125848385596, 7.515158778236759, 9.410207310030538, 7.885774710486013, 5.119629050454786, 3.6103581276632126, 1.499949777799268, 1.0625569642551485, 0.3194123620708143, 0.20911074694125883, 0.10972263651990122, 0.30741223825081704, 8.788938195474687, 32.84113468662385, 60.03506045187674, 75.92389952751898, 82.72199461537024, 67.8994518710721, 75.29457876759191, 120.01254835436423, 89.56773081133443, 45.47999589673935, 58.32061598377844, 90.02876620138846, 87.74036130597516, 99.45106813984533, 79.40159843813989, 4.635155537436086, 0.17164710158061597, 0.11629910298412847, 0.11212138038489128, 0.11518832912007648, 0.1877016691310752, 0.17859132089201482, 0.14950440265238285, 0.24872837107508416, 0.19634366185674745, 0.18899248131821234, 0.18822394191257416, 0.14297901893094664, 0.13639527463143872, 0.22283072282950725, 0.13361408435288938, 0.07445755624963392, 0.08170687007687746, 0.1258182893657396, 0.15438114983900902, 0.15576473527377652, 0.17350909360233815, 0.15852537907419667, 0.3298321690770888, 0.147010694528299, 0.1819110096942994, 0.1719199820992447, 0.08598452118495781, 0.11628589562831387, 0.11440306601505126, 0.12188692532119252, 0.2473017008554551, 0.17320446640012727], [0.05862595092865729, 0.04622812022364909, 0.0162048299511474, 0.03889278238338809, 0.04623396547451135, 0.010630360526603558, 0.026285972468735232, 0.012199103667010224, 0.04132301629250569, 0.05317745317194251, 0.02392393762185689, 0.03008889995755688, 0.0175847630617359, 0.04675248825562097, 0.07132102374828632, 0.05617607069472152, 0.07064485922455788, 0.007801295498446111, 0.04547736937961271, 0.04406975559710015, 0.03056508488953114, 0.04007560681671866, 0.02618348905666461, 0.032338689516989455, 0.02675773707338639, 0.054130604445573785, 3.5544469471900695, 59.385676768518266, 80.67719244187879, 81.51115894317627, 66.09508314440328, 31.15599032371275, 39.692060178326024, 41.75868249708607, 31.381948263414447, 16.033565709667823, 29.500204901541437, 25.840570772847823, 38.968092626140965, 58.245479060757546, 30.17505849561384, 4.8456456103632535, 0.39900325899643285, 0.05262349882433492, 0.09164221074071624, 0.026429332417225646, 0.1690419429853078, 0.19225908022734428, 0.428851300910596, 0.5712547273405137, 0.9389244692940867, 1.5514379956068531, 0.7782304178803199, 0.7903018798078261, 20.533525482300792, 64.29251870801373, 82.07856901230352, 77.87498058811312, 76.92771250201811, 76.09185541829756, 76.87959286474413, 77.12410557654597, 70.29591021999236, 72.62939883816627, 74.65647189847886, 76.4660652222172, 70.9444349042831, 69.86141358652424, 68.98378326046851, 70.73397621031731, 73.05707839227492, 72.94709513264318, 70.05361756970807, 74.58534363777407, 69.95441298330985, 63.135933337673066, 62.68799866399458, 65.69873548323109, 69.56037167579898, 69.94573670048868, 67.10512484273603, 61.89188695723011, 66.2970224503548, 72.73742875745221, 80.15453661641767, 67.87834167480469, 22.346772493854647, 42.20108662882159, 35.26541048480619, 43.62897057687083, 68.34440554341963, 68.9429827659361, 70.88978059830205, 68.14146995544434, 67.2299660405805, 59.620975832785334, 59.74875488588887, 64.3042269829781, 71.29944862857943, 74.25097727006482, 80.27257642438336, 75.73455887456095, 72.40510202223255, 70.77746745078795, 66.27826567619078, 63.77275759173978, 63.964741922193966, 66.30748733397454, 66.32869951186642, 68.45798953886955, 66.36948431691816, 57.042703859267704, 47.61331027553928, 42.059438074788744, 40.13185593389696, 27.711951232725575, 14.397724559230191, 11.213642512598346, 3.540183738354714, 1.0215610866585085, 1.8932286746078923, 1.502854415485936, 0.3917235851047501, 0.3223659374540852, 0.1977179776276312, 0.07260056678205729, 0.01991590349784782, 0.032616300628550594, 0.05917202989240328, 0.7026391740768188, 5.806514515030769, 28.206919047140307, 53.15366598867601, 54.14535099460233, 63.238409180794996, 95.02467340038669, 135.87207948007892, 88.44329710929625, 39.037463665008545, 49.62355244544245, 76.46543764298963, 67.21656722407188, 80.08109415731123, 41.35762406933693, 0.7248150292904146, 0.03948989812464964, 0.0880989928038851, 0.10382594285352577, 0.03359084107702778, 0.013872721371421171, 0.023870077810340354, 0.05522790665347731, 0.02278267728885816, 0.03446792748065726, 0.035219268212395335, 0.02696690780501212, 0.04056674578497487, 0.012272767808979318, 0.09151109479247563, 0.015723775572804435, 0.010184426491539325, 0.038038785869796435, 0.018755651845206178, 0.052812197771404064, 0.1073108155340437, 0.0606042619103626, 0.029661011123549075, 0.014610145158404786, 0.032422794479756586, 0.053915655495779174, 0.028099088080888315, 0.04877864525863721, 0.04039288596099904, 0.0020209109765522543, 0.04067929559237054, 0.029876729991707592, 0.022652934553221832, 0.05440682127711274, 0.02982718133998494, 0.03420507505295738, 0.08530900783596501, 0.0349175866182533, 0.013849619990064493, 0.060663017023715286, 0.012886244315473784, 0.012241412787848424, 0.05418256818947773, 0.031134014340838602, 0.028723080101753437, 0.026697520647318135, 0.004263814602557931, 0.032369604995173794, 0.029614275929728345, 0.042398741634021846, 0.028744452039621053, 0.06504171512900822, 0.06020512244093323, 0.024053011945779287, 0.07589116722585694, 0.10056541136075413, 0.04005566554804964, 0.028158027055342833, 3.7658543644412874, 70.27063446660196, 92.5119246205976, 91.68688543381231, 74.07470595452094, 44.54889189812445, 54.06731936239428, 39.1918206983997, 22.908838333622104, 25.799574159806777, 43.53461404000559, 35.33774291315387, 47.10484558536161, 58.15445261616861, 32.98241453786051, 4.698916606364712, 0.3851333903449197, 0.06456770588673892, 0.11102896198750505, 0.23888593389382287, 0.5964687646877381, 1.0245006579545237, 1.3463829794237692, 1.931128453823828, 2.2776247512909675, 1.7060969289272063, 0.5661595684866751, 1.6635803974443868, 22.603693623696607, 70.30042094569053, 85.54224937192856, 81.86428992978989, 79.53540617419829, 79.36180207037157, 81.78110430317541, 79.74795156909575, 74.62776799355784, 74.64179438929405, 77.95402419182562, 80.20393494636782, 75.54534373744842, 73.60933242305633, 73.29460144042969, 75.01019908535865, 76.19298196608021, 75.10089212848295, 72.11851012322211, 76.37774129067698, 72.4870324903919, 66.96275849496165, 66.65844532751268, 67.89352124737155, 72.1392829956547, 72.86605896488314, 71.65381908416748, 62.242205604430175, 69.30624131233462, 73.99032008263373, 82.27926884928058, 68.04040616558444, 27.785852609142182, 50.63615545149773, 41.4184521859692, 47.26205810423821, 69.06507830465995, 73.6235470925608, 73.64675967924057, 72.59549387039678, 71.61877662904801, 63.07315580306515, 62.81694658340947, 67.11118882702243, 74.44309496110486, 77.44706569179412, 82.87554756287606, 77.02604632223807, 74.27724930547899, 70.9038854414417, 69.22024726867676, 66.54273540742936, 66.84391852348082, 68.17931298286685, 67.32654263896328, 68.52411285523446, 67.40167956198415, 58.253021778598914, 50.96258294197821, 45.62243676954701, 44.34053559457102, 30.17417400113998, 19.062142449040568, 10.880027278777092, 4.189171752622051, 1.5669432474720864, 2.9514386721195716, 3.6536956602527253, 2.112340484896014, 0.8370375945683449, 0.5920389991614127, 0.44004396805840157, 0.0851246640987454, 0.0854903944737969, 0.04897276044733102, 0.6088665800709879, 6.504107069584632, 28.511593072645127, 49.43189367171257, 56.873783065426736, 70.90441888378513, 106.75613741720878, 137.75420527304374, 92.48391105282693, 51.054872389762636, 56.40149439534834, 83.29414290766563, 74.13654604265767, 91.17016023205173, 59.218446516221576, 1.6857224222152465, 0.03331911352072512, 0.07887774567690589, 0.023234360813794118, 0.02883439076193158, 0.021038003971860297, 0.03487832844257355, 0.012688836863925381, 0.007484768077941432, 0.026998305918588757, 0.032020665352202715, 0.05997051184456195, 0.05196631795937016, 0.036832002036634, 0.08148585371072255, 0.026221276343529745, 0.04709857613629392, 0.002025724402741499, 0.02475534220256152, 0.029248662383085298, 0.047791533307322574, 0.02629670344533459, 0.039639775566155874, 0.02418087776600113, 0.05695536980525621, 0.024753063090986783, 0.054804784801578334, 0.04447555237059151, 0.03907272494548271, 0.02440960289189412, 0.04013368394225836, 0.058912601877724936, 0.2829029711504137, 0.19356601090440828, 0.11695331908882627, 0.10469762833728906, 0.18399800173938277, 0.119438378080245, 0.11494885769582565, 0.21659151891306525, 0.16466200381757753, 0.13383441123991244, 0.13181445188820362, 0.18977879396369382, 0.11155617603611563, 0.10275752599080724, 0.10503433164088957, 0.1963895964886873, 0.17780198986011167, 0.10453355528654591, 0.10346248009873014, 0.09210619189205671, 0.13817569361098353, 0.1701530769106842, 0.16003546094702137, 0.15738157915972895, 0.1552913848671221, 0.18407955945980164, 5.713164066114734, 84.96283685007404, 101.14757168677546, 105.66918588453724, 87.56688271799396, 47.75303686818769, 53.563577205904075, 56.551944748047866, 46.76064975800053, 28.777498391366777, 40.983688831329346, 37.58981097129084, 56.63717785189229, 77.5134478845904, 45.299559024072465, 8.016044958945244, 1.071870509655245, 0.18418373209574532, 0.4704541346478847, 0.222552556304201, 0.8246494625364581, 0.6956253633383782, 1.687165609290523, 4.790965808976082, 6.234778011998823, 5.979618026364235, 4.8445909830831715, 4.286294541051311, 24.837326542023693, 71.62919444422569, 88.65115134946763, 85.36326377622544, 83.2097178120767, 83.26622347677909, 82.55620387292679, 82.59369388703378, 74.65547561645508, 73.55548612533077, 81.3130243362919, 84.14467750057098, 79.7748904074392, 76.90835952758789, 76.40566856630387, 77.64289394501718, 79.31976210686469, 77.17950513285976, 74.75297789419852, 79.20133006188178, 76.25252354529597, 69.46189665025281, 68.41975427442982, 71.8280586119621, 76.34702128748741, 75.53727149963379, 72.76507362242668, 67.94537498104957, 72.67314895506829, 78.9823833588631, 84.29445712797104, 75.3041571955527, 35.641805048911806, 55.277001857757575, 47.72642358656853, 54.21852673253706, 74.48729222820651, 74.24953383784141, 77.25147278078141, 75.109725306111, 73.69130211491739, 64.48052967748335, 63.6738314936238, 71.2393343833185, 78.93097677538472, 80.16848456475043, 85.63003201638499, 78.72043963401549, 77.2515590729252, 73.86006601395147, 72.90855392333, 65.70776085699758, 67.49632635424214, 68.3431346954838, 68.61232696040985, 70.79882083400604, 70.32279414515342, 59.82809266736431, 52.94166972560268, 46.214020406046224, 46.88947608394008, 30.251028922296342, 19.56343508535816, 18.233680994279926, 9.108166175503886, 6.938693917566731, 8.944847506861533, 6.838192497530292, 2.8219283828812265, 1.1050638123866052, 0.6614837663308267, 0.6331202495963343, 0.1626881782806689, 0.1889445088923939, 0.2459442083753886, 1.2350400056569808, 10.938528449304643, 44.20249954346688, 70.63153174615675, 69.36903061405306, 75.28053668237503, 100.96686809293686, 138.10127227537095, 97.0618034178211, 52.499434255784564, 66.4029029107863, 93.54507692398565, 83.50483694384175, 100.73651513745709, 67.53650711428735, 1.5359793218874163, 0.1834289822727442, 0.19605812556560964, 0.13408170442187017, 0.12825107817808468, 0.10076920607037122, 0.1449590038147665, 0.20774203893398085, 0.23577691927071542, 0.0862202081348627, 0.12453320751627608, 0.10640850951594692, 0.13091264382725762, 0.1184314244516915, 0.17337507418086454, 0.20429027657355034, 0.1295129092590463, 0.16245432228090304, 0.0950921881162832, 0.16974243846151138, 0.22698671917521188, 0.10967048891489545, 0.14998446398925397, 0.11280849230505767, 0.14031127095222473, 0.06928929728606055, 0.1289305138972498, 0.10713343553605581, 0.09814758424557025, 0.10695575676377743, 0.14030598494554722, 0.11274648514846641], [0.03826026188870592, 0.060885925627043175, 0.0823335146771804, 0.04247109480803052, 0.03914960569912388, 0.05439837132730792, 0.06518147254903471, 0.03560205170464131, 0.032115916894268126, 0.04065592608024036, 0.11233547897708994, 0.0571545296829314, 0.03500868596376912, 0.10082516113236066, 0.10095829189184213, 0.07780902237901766, 0.042463093019661405, 0.016565774191891956, 0.13485281788293393, 0.06824777777036352, 0.041927019164206526, 0.05388122750446201, 0.041538624077915184, 0.09309811487553582, 0.019567856347308527, 0.3473519257480099, 34.34811322919784, 87.06718060278124, 86.43634580796765, 80.66843771165418, 74.43314783034786, 44.776001053471724, 84.5184793779927, 171.51719893178634, 99.03607353087395, 43.6063188891257, 26.714398361021473, 72.0001486809023, 54.75547567490609, 23.10931459549935, 5.6518142742495385, 0.34139880970601116, 0.023417626282260306, 0.13158062653195474, 0.08602208247588528, 0.33753168979479425, 0.4512927128422645, 0.21217854603404002, 0.31579026772129926, 0.8305791669314908, 1.3670489672691593, 0.6799241768256311, 1.7415964627458205, 30.70819881654555, 74.92395401000977, 78.9977276709772, 73.61943644862022, 72.96669129402407, 69.81652598227225, 75.99252531605383, 72.53537962513586, 76.03455743482037, 72.79363632202148, 69.82626130503994, 71.60151035554948, 68.8634684778029, 67.39011641471618, 60.30503719083725, 64.18315518286921, 68.13363305984005, 68.7236830496019, 73.55125781028502, 75.44728448314052, 76.11980622814548, 72.92399237232824, 65.3802586370899, 61.79165863221692, 63.416547544540904, 59.72116101172663, 58.10936497103784, 59.58566665649415, 58.5817870017021, 65.23731177853, 68.37307806937926, 72.38236011997347, 57.49377642908404, 38.30542387500886, 28.823696067256314, 32.89308451837109, 48.79923105239869, 55.41816011551888, 71.87128313126104, 72.374633050734, 68.12898897355603, 59.81574112369169, 55.89426132940478, 55.0040441174661, 60.3245549048147, 70.75468632482713, 73.61958549868676, 64.55452911315426, 71.10430286776635, 62.933476278858805, 65.20648587134578, 68.55990056068667, 74.86283563798474, 74.0164509127217, 72.65925591991794, 74.3204346010762, 70.14502448420372, 65.7390143025306, 69.23585045722224, 67.42609239393666, 73.91558324137043, 72.17380769791143, 68.53645263179656, 53.49370018128426, 31.539960945806197, 10.59402765766267, 1.7521272912140817, 1.1327024260836265, 3.4068216816071546, 1.834741354950013, 0.5816250450668797, 0.773539140580162, 0.09415563796797106, 0.053963658565114585, 0.05045675319589434, 0.07049824531760908, 0.04367727343173277, 0.1184797645997136, 1.273927241563797, 11.172690026221737, 32.21874475479126, 38.70517223112045, 51.211371037267874, 66.49537670996882, 64.05518001125705, 26.323551824015958, 35.23012484273603, 51.618524828264796, 62.1470332145691, 66.3242829230524, 76.7386777939335, 25.7954478263855, 0.09022288730428105, 0.034145507886404955, 0.06796508366542478, 0.07943519721588782, 0.06589965699540992, 0.044808218390831066, 0.05673439174349751, 0.14590974957231553, 0.0454035414863498, 0.02714449656195939, 0.0642063575346143, 0.014714566772923836, 0.09731317660020244, 0.01711870198168101, 0.011622245205686459, 0.011154180805709575, 0.015516102543070674, 0.03391728263288256, 0.01176538969194817, 0.058647723147465344, 0.03639186920237638, 0.06984955270684536, 0.03640555153270403, 0.02681127129753511, 0.04249223117386142, 0.02080786924418663, 0.06561942969358737, 0.05827044782739493, 0.021393803932193308, 0.060826864078520775, 0.02848657535298938, 0.03672800943135254, 0.014374953292820965, 0.05542721208785811, 0.0512562157405961, 0.02668235402163719, 0.07416916245053853, 0.06156109806690967, 0.012452758251569204, 0.04753006749876565, 0.026522662993820927, 0.05485676003680114, 0.04507491274947121, 0.005173359193929261, 0.011389454068135352, 0.08789158982014464, 0.0513508390905636, 0.01821492783605091, 0.0596081905607735, 0.04389869965492718, 0.052621277169354504, 0.0621179060920352, 0.039456515843349124, 0.03861361611334067, 0.1036423575433512, 0.12458188474298486, 0.12078719078412942, 45.47373187157416, 106.36081741702174, 96.01348723134687, 91.53291671506821, 81.29453428329961, 47.77605333635884, 85.45503154877694, 136.57297565091042, 68.24431450136247, 20.63854694366455, 25.033596061891128, 52.54005039891889, 49.614021085923724, 26.505757685630556, 5.869278321343084, 0.1574714872385225, 0.06899043872591949, 0.275025840608343, 0.5957050669577815, 1.196940062988189, 1.6224711388349535, 2.1417665962250005, 1.9367565647248302, 2.0859637712278674, 0.5375376656170815, 0.1889899685498207, 2.801257982369392, 34.2066764831543, 79.97414681219286, 82.19740898378434, 75.82360452221286, 78.21935684450212, 74.1434572589013, 78.07347605305334, 75.61214170148297, 79.0921312762845, 74.45657222501694, 72.43503755138767, 74.72326986251339, 74.41089230199015, 70.17161815397202, 63.6341880982922, 65.91378335029849, 72.2908276896323, 74.20119454783779, 77.13277401462679, 77.23794060368692, 78.8170946798017, 75.84476963166269, 67.85553701462285, 62.947059446765536, 64.99709406206685, 62.70162890034338, 60.52154417960875, 61.41149859274588, 62.2917765186679, 67.53638159844184, 72.15004597940754, 73.43125681723319, 66.57279645243, 42.86865049792875, 33.33440803712414, 37.47567392164661, 52.66275390501946, 64.79518613507672, 75.75102498454433, 74.89546975781842, 68.51362443739369, 62.174623166361165, 58.58530929011684, 56.13545963841101, 63.099776929424664, 74.51548622500512, 74.55594939570274, 69.2681315637404, 73.77047123447542, 63.657157498021284, 67.4725881699593, 68.10627845025832, 74.86015273678687, 74.80025029951527, 73.01466972597184, 77.72952341264295, 73.8402815788023, 68.54921602433728, 67.11768427202779, 66.38875099920458, 76.3812400448707, 74.58018179862731, 71.16095758253529, 57.500938677018695, 35.627939470352665, 13.19324508790047, 1.8934442823933018, 0.6614026222978869, 2.1850332810032755, 3.635876087411758, 2.2823592972370887, 1.8933551710459495, 0.6448004550991521, 0.24004841103188454, 0.031817699932763656, 0.06638642160161849, 0.037322696673894123, 0.09941795720688759, 1.155890007653544, 12.306445240974428, 34.24656306543658, 44.98782865462765, 57.51569463360695, 79.72123238348192, 69.47483262708111, 33.57437079952609, 48.62374813325944, 61.2610835413779, 71.23541985788654, 73.42491826703473, 90.03559897022863, 40.48310026045769, 0.2086662780493498, 0.014621144265777644, 0.07427333508648219, 0.04860835923482815, 0.019769163186391516, 0.08634951611560199, 0.02800051937811077, 0.04313168093381871, 0.10999748588449533, 0.073592918774774, 0.02280752726590201, 0.1172851041079529, 0.06531307113266761, 0.04383141415253763, 0.022086615546516353, 0.03995592090030832, 0.04651244609586654, 0.06909965988128416, 0.00762704927887347, 0.06313832754629754, 0.06658755798613833, 0.05851256991586378, 0.035438978398639354, 0.014124799730075945, 0.04857902955864707, 0.03724609937278494, 0.03352589980368653, 0.05375346319089013, 0.08285520523185692, 0.0463889642137914, 0.009908964256605795, 0.13860695514707796, 0.10640702330537381, 0.19154553061291096, 0.20192024568396233, 0.11480149302271106, 0.18687581102694237, 0.18516699062480083, 0.08317993458120093, 0.3006257104777521, 0.12390168293589547, 0.18872361510030686, 0.19964638947238847, 0.12417945109548108, 0.18279273092987078, 0.22275396081949436, 0.20238006697787395, 0.1493921401279588, 0.13955561714547296, 0.19334467278132517, 0.16193276962205289, 0.2050154707244327, 0.14498298236679646, 0.14978264578648154, 0.2813656165474846, 0.30578313695807613, 0.6511621105094111, 60.563384102236846, 114.50487382950323, 107.59250440905171, 101.44953927686139, 94.73433956023186, 60.643059207547104, 92.3283733860139, 169.8722667078818, 110.83016995460757, 62.449957862977065, 40.04100207359561, 96.12981688591742, 74.73252665612006, 36.47450854701381, 8.523963459076422, 0.6843574357128913, 0.20289264108625152, 0.33684043333895747, 0.9076923516488845, 1.1791801837182816, 1.78082077733932, 1.9361926014384918, 2.9973757555407863, 3.8891937848060367, 4.7347508899627195, 3.000020413629471, 4.013163235879714, 36.43597518244098, 85.10345382075157, 84.17688800442605, 78.83410992160921, 81.3780729232296, 75.71926947562926, 81.47491624278408, 77.51023154104911, 81.0534889467301, 74.75617070351878, 73.38181141884097, 76.21653972133514, 78.23147696833458, 73.92746017825219, 66.91953397566273, 69.4684705426616, 76.75075869406425, 75.36234163468885, 78.46293603220295, 78.61585355574086, 83.79454320476901, 79.76315467588364, 72.3272272848314, 65.76656503062095, 67.21496689704158, 64.97622705275013, 64.48837834019815, 64.03521514707997, 65.7621092181052, 70.93884944915771, 76.12426204066124, 78.22371067539339, 69.70530325366606, 47.049838266065045, 41.14308218802176, 42.509149582155295, 53.17125781889885, 66.8428437940536, 77.70707961051696, 77.72426743661204, 73.3250625671879, 67.06767405233076, 61.1606590978561, 60.00902768104308, 65.66144943237305, 77.90679885495094, 78.89612259403353, 70.54185067453693, 77.48814859697896, 64.17969173000705, 68.66670670047884, 72.8631014977732, 78.64465944228634, 78.107953686868, 76.06895662123158, 82.36207008361816, 74.91323809469901, 68.1980069991081, 67.8760588553644, 68.21031539670884, 80.22016571414086, 78.8287833429152, 75.46890458753033, 59.29094760648666, 37.89823478268039, 15.451432043506255, 5.543527439717324, 4.617094493681385, 10.139909367407522, 7.141467707772409, 4.087989801360715, 2.1527970365939604, 0.7479071256614501, 0.32912157656204316, 0.22931375721048927, 0.24571479568558358, 0.14878798786911274, 0.28007981457537223, 2.693471495182284, 19.26985352270065, 46.879434816298954, 56.585786957894605, 65.03574117537468, 74.66336742524179, 70.77226638793945, 35.48537700406967, 51.57550427221483, 66.61797431207472, 83.56292724609375, 81.85204429011192, 102.96087557269682, 42.40477138949979, 0.37074889446939197, 0.1763606720393704, 0.13385221512327272, 0.18278626514778984, 0.10682388238849179, 0.21369126324932422, 0.23763843631792456, 0.2017386368806324, 0.20195398419614763, 0.12635417552965303, 0.17847980913375655, 0.18624435539447493, 0.1716376940209058, 0.18953407483716167, 0.1680531379796805, 0.14678011738484906, 0.15964697776061876, 0.1647699149625917, 0.11052528215992836, 0.19921114427908776, 0.2410820015375653, 0.12581670356373634, 0.22866166316934172, 0.17074296461238017, 0.19376122542927343, 0.1087142656286878, 0.17820702054567877, 0.12300976507005193, 0.1392619143570623, 0.24012964699537526, 0.1736920660421733], [0.043807404956990675, 0.018002466756790396, 0.009086460659971402, 0.04732061906026737, 0.04649515549141554, 0.03647986206135923, 0.07090850072281976, 0.09251342891084571, 0.06545205480389057, 0.03313792606575355, 0.06888967518123888, 0.052957160758876035, 0.04972584785953645, 0.04465679728215741, 0.021141117491248636, 0.05689129038082977, 0.04264818752304681, 0.029582921866207357, 0.025435701057675387, 0.03166764246059522, 0.03505808331312672, 0.04625857604907886, 0.04494876105097994, 0.01766855201323427, 0.0539409134146427, 21.748077600233017, 84.79865427940123, 76.59411491886263, 79.73117951423892, 59.48539518540906, 54.948773999367994, 34.24540988860592, 50.5994067653533, 73.75224790265484, 59.84175820504466, 64.47463043274419, 70.32983087724256, 57.3884411781065, 27.744526517006662, 7.479249969605477, 0.16367456244845546, 0.04606391693795881, 0.16524803043613512, 0.11250000401970842, 0.4623687201209607, 0.21923810754331852, 0.21169047141748093, 4.13842853999907, 1.0923832799157789, 1.2291321807330655, 0.7768814902632468, 5.06152109753701, 44.04271394975724, 78.7626600265503, 75.90015349849578, 77.11451930384483, 71.62547603730233, 65.15904872648179, 66.16268911669331, 67.24652628744802, 75.4272254820793, 77.77058278360676, 73.91400644856115, 70.25978519070533, 76.03607931444722, 69.20949997440462, 61.191736036731356, 52.20326000644315, 57.624006963545284, 58.92436289018201, 65.02118133729505, 66.84204363053846, 72.01420645559989, 69.82019732075354, 69.95605253404187, 64.92428310455816, 61.154850067630896, 55.670964717865, 55.5869593158845, 51.97383273032404, 54.614152677597545, 56.5170003521827, 56.58361396481914, 64.08055774627194, 70.58731878957441, 71.55346132093861, 66.63462869582638, 19.69277524179028, 30.052913927262832, 61.64425596114128, 63.640291306280325, 74.71311092376709, 63.347282409667976, 66.36939802477437, 56.213765836531124, 56.095031769044944, 53.496618424692464, 62.2359964924474, 66.28940520748016, 75.03993849600516, 63.309953212738044, 56.902392833463615, 68.12061079086797, 73.60142492478894, 71.99991333869197, 71.6823660942816, 70.002195296749, 68.24248667686217, 67.34922178329961, 72.72453200432562, 70.6881001687819, 64.80233269353067, 65.44729978807511, 70.07492388448408, 76.92899119469428, 75.05577702676096, 80.25428248989968, 69.52543904704433, 45.12276211092549, 15.91462964011777, 2.0621655256517473, 1.415882230766358, 1.2269922826559314, 2.4656656288331558, 0.9827353829337705, 0.26708871006004276, 0.07362691009597433, 0.055308805538281325, 0.025494691743064794, 0.0834254427782951, 0.03628692281762919, 0.09341080898358937, 0.1574098631258934, 3.543631011439908, 29.984433266424364, 42.344366888846125, 44.06737389103059, 47.109419068982525, 55.146308483616004, 26.259062174827825, 34.08846409090104, 49.80541313848188, 62.370753442087484, 76.6259410304408, 74.75226402282715, 5.37317596135601, 0.205472978432813, 0.08506789698355621, 0.02146586407757094, 0.034724497987378034, 0.06432975897745741, 0.057912688597195575, 0.009801630550364574, 0.03677209396095526, 0.03913577015121137, 0.03335176418805796, 0.0474456905747854, 0.09528432296769274, 0.0951519659570148, 0.03614495140350154, 0.046812147352724306, 0.03661706457815824, 0.08116416573043793, 0.07864826403918766, 0.04624033166516212, 0.03395649867372648, 0.05499279426951563, 0.05497133231631691, 0.007716442163537948, 0.05872492565803471, 0.07173589100280116, 0.03309662626575559, 0.06748149066322273, 0.026997045703953313, 0.0580444174157756, 0.018368664445475708, 0.0509482407341561, 0.020152481024964683, 0.043846954246081656, 0.014041498202019402, 0.02257708610305863, 0.042800933963829474, 0.062043817728878035, 0.08118888738775447, 0.06458725645056655, 0.013602024203376665, 0.052565253159451875, 0.03837505633371972, 0.0680467869425493, 0.010876395409145664, 0.01872563843555268, 0.0891930353076708, 0.044436095012051445, 0.10805967414090711, 0.016481537078957886, 0.019833051088836887, 0.03242512721748602, 0.00907827788333018, 0.021598152140335693, 0.023822340956558625, 0.01988102159943552, 27.255128468236617, 99.38547826582386, 83.80915011129072, 88.51304469570037, 69.25583885562035, 73.22903510062926, 45.923062909033995, 64.50792743313697, 102.68529768913024, 67.95989559542748, 62.967330255816066, 63.03342611558976, 58.520601949384144, 29.727927907820675, 9.083687643851004, 0.06230839385440754, 0.03594026420145266, 0.4536901390360248, 0.293752032542421, 1.6801222582017223, 2.1781436377956025, 2.2884857942981105, 4.004490385132452, 5.392226913282949, 0.687463523880128, 0.11428662065056064, 5.336476304838735, 47.70444262412287, 79.91858251633184, 79.50107759045017, 80.92044999522548, 75.91244620661583, 69.00381872730871, 70.07040531404557, 71.05920345552506, 79.05664167096539, 79.40319092042985, 76.74062328953897, 72.47520262195219, 79.25938898517241, 72.33623304674703, 64.50086324445664, 55.88750700796805, 60.84912876929007, 63.10368753248646, 68.26146310375583, 70.05088760006812, 74.28256803943266, 73.75929247948432, 74.03862799367597, 69.03319727989935, 63.144327209841826, 58.413529088420255, 57.400208288623446, 52.83663257475823, 58.185039258772335, 58.661426805680804, 61.21779626415622, 67.49170580217915, 74.36778545379639, 74.57194482126545, 73.7084585620511, 23.616633953586703, 33.4224142566804, 64.32154424728887, 67.0233355799029, 76.40832008854036, 68.18446697727327, 69.2789416159353, 58.711899865058164, 59.27937661447833, 55.312071769468254, 64.06090274933847, 71.84352843992173, 77.08624685964277, 64.22942346142185, 59.625447334781775, 69.19977249637728, 74.20930600935414, 75.07971132955244, 74.58890514989054, 74.56053856880435, 73.33584908516177, 70.25637272865542, 75.60421066899454, 74.25278156034409, 66.23540985968806, 65.88693864883916, 72.73386724533574, 79.92135170967349, 77.73572075751521, 84.01396059220838, 74.77519419885452, 49.96784240968766, 17.82578391413535, 2.4507924914360046, 0.37453903786597714, 1.231761394489196, 2.849907384764764, 2.8778425051319987, 1.9486799571783313, 0.6024932188372458, 0.050537437576079564, 0.04038900189522294, 0.048013503452943224, 0.030052001332683913, 0.0678382501486809, 0.136446081582577, 3.2037755318226355, 31.59889259646016, 38.897227164237734, 44.31324766528222, 37.87393569946289, 45.92052513553251, 31.770037374188824, 40.03486356427593, 57.55700503626178, 71.16589192421206, 84.98786941651376, 90.87598246912803, 11.276169015515237, 0.35235227356033944, 0.1975676252116119, 0.029840266121731653, 0.06361879490976853, 0.04048488162938626, 0.06626126581742879, 0.03993619030581848, 0.012304728039570395, 0.016664319912031773, 0.05752109509382037, 0.056024408268351714, 0.07263834257760356, 0.012139909968320883, 0.012499781685971446, 0.02658956353702853, 0.06380098210948129, 0.07038716256858842, 0.03240676408994102, 0.017285111600593213, 0.03911506279461807, 0.032249290886665546, 0.039401357512800925, 0.010843758148351505, 0.03380254564446307, 0.02787559533551816, 0.023390096912701285, 0.08294606325967659, 0.06439924315218964, 0.02332583362717302, 0.027634302537227352, 0.19780308999601873, 0.15337662470917549, 0.17529985476886073, 0.10730418121261943, 0.14281939685104356, 0.22642140757412682, 0.14001087255535588, 0.15156528642100675, 0.1408714650859756, 0.113933538387139, 0.16695703469937848, 0.15406094040841828, 0.16514203451093168, 0.11145954170534689, 0.13470635719357, 0.13926019832011194, 0.11108448804025689, 0.16547704476021952, 0.14634406013834864, 0.1313446408077594, 0.1811056674247788, 0.19846892765452787, 0.10997573664832501, 0.12005797467164456, 0.17001738741753564, 36.88133285891625, 113.989544991524, 97.34831686942809, 103.14997303870418, 82.74144957142492, 74.62745420394405, 47.95543901381954, 62.98131350548037, 83.6916123667071, 71.75512606097807, 83.96363658289756, 96.1834199966923, 75.87868244417253, 40.539590235679384, 12.440816817745088, 0.5921902555611827, 0.1087427564385918, 0.7441007105573532, 0.406171788852061, 3.0521276304798746, 3.0702286333807054, 1.844773919832322, 10.924776619480504, 4.553596223554304, 5.081369761497744, 3.2323928994517175, 7.1622719591663735, 50.71081776772776, 84.48575896601524, 82.03247331803846, 86.239866441296, 77.70617746537732, 71.50943663812453, 72.864348811488, 73.4554813754174, 81.60040070933681, 83.92358918343821, 76.62102237824472, 73.85252721848028, 82.0555760783534, 75.40787250764909, 66.45216788015058, 59.378012457201564, 63.459015046396566, 65.57199978059339, 71.87004366228658, 75.18837667280629, 79.30463744748023, 75.78300799092939, 76.3515006342242, 72.08728021191013, 64.86924440630021, 60.78929301231139, 60.604372870537546, 56.66906672139322, 62.7163613227106, 61.223687664155044, 64.94840568111789, 72.59167348184894, 78.2066483651438, 74.9388276377032, 75.32160389807918, 30.250707287942213, 37.602029154377604, 66.12626598727319, 69.79127376310288, 79.34946229380947, 70.4148207941363, 71.29338464429303, 61.86847432967156, 61.81061152488955, 57.72697310293875, 68.2240358475716, 75.10390450877529, 78.43586383327361, 66.90391509763657, 60.74385627623528, 69.50307369232178, 79.47957515716553, 79.43824122028967, 79.89007472991943, 78.39189406364196, 77.13635906096428, 73.01913338322794, 79.69674110412598, 76.80283992521225, 67.26218438917591, 66.95623167099492, 75.86502475123253, 83.33387651751119, 82.59797711526194, 88.64377729354366, 76.157194260628, 52.524925739534446, 20.158631224786085, 5.771417637025157, 5.926856754287597, 6.319110931888704, 6.5398530998537625, 4.372381250704489, 1.4333801692531956, 0.3329892480565656, 0.11485429180245246, 0.14327034684679202, 0.27340608558827834, 0.17471885368708642, 0.22760322077139733, 0.38403577021052765, 6.671536872463842, 45.94660497480824, 62.30610885927754, 60.227311503502634, 60.22207906169277, 70.88989826940721, 35.611967579010994, 48.046877307276574, 66.8695943586288, 84.20858075541835, 94.01839717741936, 101.75637060596098, 14.048241376876833, 0.5239060809535365, 0.20051674196316352, 0.14806542906068987, 0.19986245691055254, 0.13913452925701297, 0.15864104302900453, 0.1117996464393312, 0.259618402849282, 0.09352521655420143, 0.1790183995880427, 0.22686014612836225, 0.2447077577873584, 0.3208454061419733, 0.14378586273279884, 0.134871908794007, 0.17461936950923937, 0.21171291779366233, 0.16576541557667718, 0.10628036598885253, 0.16889505328670626, 0.12605063617229462, 0.19198978500020122, 0.07962751592839919, 0.17749454345433943, 0.165133178534527, 0.1364397230528055, 0.21196260116994384, 0.11707885025609886, 0.18002085628048067, 0.18834119933026452], [0.022469073451394518, 0.08043687249864302, 0.032076222048471534, 0.06188806439299257, 0.034170061004378145, 0.08614275664571794, 0.027350401843807874, 0.03127272796606825, 0.01885371109951408, 0.0454536704496751, 0.05697886189145427, 0.052180186725191535, 0.08032762836064063, 0.03444118335122063, 0.02544802932759687, 0.05217705725602085, 0.07810615724132908, 0.055351197013571385, 0.013138351402425719, 0.030233209855073405, 0.03252003018954589, 0.04219455238912375, 0.030565596253220594, 0.10153034506666084, 5.067688044040434, 68.38271141052246, 78.63457110620315, 87.53887699496362, 76.7819493816745, 68.36585306352185, 26.59936308860779, 27.11926344902285, 26.223835368310255, 14.193524987466875, 31.862248374569802, 38.27134240058161, 42.510224311582505, 18.113407396501113, 3.6776799732638947, 0.04518328737767954, 0.044792371862117326, 0.13192227110266685, 0.09831972420215608, 0.24589217568357147, 0.41474173866933395, 1.1577802223543967, 1.625957513047803, 1.72859049612476, 1.3998814119446663, 1.0925872431647394, 9.729814779373909, 58.24183125649729, 78.55225624576693, 74.00206365892964, 74.92957084409653, 66.35039021891933, 63.4773442822118, 67.156021518092, 61.47851620951007, 64.26709782692694, 70.82572044864779, 71.68668070147115, 70.5767362348495, 67.52705420217207, 72.8490201888546, 65.5633548767336, 57.4347722145819, 51.287315968544256, 53.45040898169241, 53.36244983057822, 56.58217053259573, 58.29358300855083, 64.99760789255943, 67.76287494167205, 68.00433604947983, 64.57906746095227, 63.048111469514915, 56.35854444196148, 50.794493690613784, 49.88522944911834, 56.678099939900065, 52.044498151348485, 59.953251577192745, 61.61020978804558, 73.57712191920128, 63.533234134797134, 76.83160658805602, 24.015109500577374, 24.04635117899987, 68.03072575599917, 64.50212232528195, 69.75086550558768, 61.14284369253344, 60.47731553354571, 52.46823964580413, 54.882858568622225, 49.75105301026375, 59.708672185097974, 65.144963495193, 74.45882366549584, 67.3409063585343, 60.67564233656853, 71.81080018320392, 67.96085265374953, 66.85786647181358, 64.56543722460347, 64.05558009301463, 63.56005530203543, 63.08515041105209, 66.19857095902967, 73.05627822875977, 67.45829505305137, 64.91814851760864, 76.08300655118882, 68.67248827411284, 72.59564292046332, 71.39035347969302, 75.2634822168658, 68.20331004358107, 62.708500892885276, 21.825209048486528, 1.2928831985881253, 1.2291026403827052, 0.5718110297476092, 2.529498035869291, 1.0233444780591996, 0.2542571663375824, 0.04755521433488016, 0.0010280056050114875, 0.08748775423173943, 0.13324558073955198, 0.0344967860127649, 0.06572388578206301, 0.03196952323759756, 2.0669000715978685, 34.71371343058925, 57.45277589367282, 56.39366142211422, 60.718580522844874, 40.67380589823569, 21.420147841976537, 46.058823985438195, 56.60159410968904, 67.21094254524478, 81.4169357668969, 29.800748671254805, 0.43723548972798937, 0.05419327043777993, 0.02189231841194053, 0.06731754018654747, 0.06257545593525134, 0.04321890004399804, 0.0539265416051832, 0.03951061697256181, 0.06456300210688384, 0.041284455256837035, 0.053034179408343575, 0.05102591055835928, 0.011572019523760725, 0.007803900197388665, 0.06950312008660647, 0.05256790765410951, 0.047120218120154836, 0.0292358840365083, 0.03213327070097289, 0.05083583265302643, 0.0592810825084246, 0.06527555580701559, 0.02361462770720884, 0.020347883241371285, 0.056983810819445126, 0.016867614749278274, 0.07759731398114274, 0.009927826298911487, 0.02604431577868039, 0.013998418205207395, 0.030881653487261747, 0.06747023683161506, 0.02402042831113983, 0.03635826092513819, 0.08036842254260856, 0.03017881569722968, 0.04640935747433574, 0.004858048895614283, 0.02515320613559696, 0.07043597769112357, 0.03086294562015082, 0.02560672061067195, 0.07742910405560847, 0.03316419522067712, 0.044347979579000704, 0.048872146289795644, 0.06696905445067153, 0.02618687325007012, 0.032978545303546616, 0.029976869174729914, 0.052305219935313355, 0.011308740002043065, 0.03378514778770266, 0.12043911107485333, 7.215188164864817, 84.30946411625033, 89.44190902094688, 96.96630939360588, 85.79117867254442, 80.07261399299868, 44.86538010258829, 41.123921409729995, 26.35794512687191, 26.880242055462254, 43.87091021383963, 41.88544957868515, 41.57401730937343, 19.611793987212643, 4.579276471368728, 0.10811668640423207, 0.05423561594779453, 0.02198786106741717, 0.5309309846451206, 0.7963688058718559, 2.2064766335871915, 3.0259257074325316, 3.4342890593313404, 1.4466350838061304, 2.0794925958879533, 0.9480915999700947, 12.620315263348242, 61.003650542228456, 82.8159510704779, 75.92375047745244, 78.38493577895626, 70.28346061706543, 66.46885364286362, 69.11669669612762, 63.862446508099964, 65.33718316785752, 74.1522119891259, 73.83848513326338, 72.50087845710017, 68.43068199772989, 75.4872299009754, 69.25037107160016, 58.787774193671446, 53.49024457316245, 56.92477780003702, 55.461788638945556, 59.62975801960115, 60.90324963292768, 67.83096728786346, 72.15524704225602, 71.85995532620338, 68.25889002892279, 66.80314156316942, 57.64731760947936, 54.750682538555516, 53.09083746325586, 58.29876053717829, 53.622071512283824, 63.04658958988806, 64.31018898564001, 76.07691118794104, 66.25568066873859, 79.94854942444833, 27.401264213746597, 24.92129272030246, 72.09278721963206, 66.89588992826401, 72.35954761505127, 66.44283263914048, 65.0951611611151, 55.406687182764855, 57.54744622015185, 52.62904897812874, 62.03688521539012, 69.03082816831528, 76.27582242411953, 68.89933463065856, 61.57168034584292, 72.8600263595581, 70.1508923499815, 70.78579856503394, 66.76631050725138, 68.706157899672, 66.43069682582733, 65.8323000323388, 69.38552810299781, 75.38906866504301, 70.63188475947227, 64.89633229471022, 77.5704477679345, 74.0041111361596, 74.47854534272226, 75.40014543840962, 78.45317717521422, 76.30183558310233, 69.20736620503088, 25.777601042101463, 2.026017575014022, 0.35804111991197834, 0.20568504689201234, 1.1313402604672218, 3.087124978342364, 2.4826406663463962, 0.6140847420019488, 0.12468896085216154, 0.23905085730216197, 0.05132226401098794, 0.08141997014923442, 0.04943571504085295, 0.01912704744045773, 1.997482577158559, 36.82929085146996, 47.65031391574491, 49.22295293500347, 53.98197250981485, 43.20437400571762, 33.02626271401682, 57.002252455680605, 64.46678961476972, 72.98454592304846, 90.09282635104272, 45.90296076190087, 0.7145663050393904, 0.03272965482826675, 0.027987214346085827, 0.154585036479177, 0.05816689189223032, 0.05596675249117036, 0.060489540243701595, 0.07298062300129284, 0.010031238592590296, 0.040153736293676405, 0.02958814850107076, 0.00858342721908083, 0.06483996587414896, 0.08337115778798058, 0.05574295522585031, 0.01826291558362784, 0.025875048651810617, 0.06001390689503282, 0.02480174797857481, 0.12529629237589338, 0.046571082465590975, 0.05964773601942486, 0.040705258312124404, 0.0599998185381053, 0.07878074362393349, 0.03640011613888126, 0.03323364492145277, 0.017310888544025443, 0.0926694350557462, 0.0026868434384420157, 0.14256580642634822, 0.22437131032347682, 0.10108769180313235, 0.18186058578712327, 0.17024010449888247, 0.1421851833020487, 0.12710203056133565, 0.10419617782557204, 0.14432425400422466, 0.174276897563569, 0.17772311344742778, 0.10196680067888192, 0.22246021206580827, 0.09653505343463152, 0.17632221442557153, 0.12426859308635035, 0.19084866639346848, 0.21108345398979805, 0.11190981754372198, 0.09722324553877117, 0.12196794678006442, 0.08888036418225496, 0.13732027983473194, 0.26212988421320915, 10.947367510487958, 100.58835937130837, 96.88344540134554, 109.9766072919292, 96.39729899744835, 90.07858814731722, 39.57117272961525, 40.20317639074018, 40.83568603761735, 23.110134370865364, 48.21918702894642, 56.005393843497004, 59.46863097529258, 29.106271459210305, 6.690340715069925, 0.2166842002301447, 0.1558144697018208, 0.4117961918875095, 0.9307601170674448, 1.5571153812831449, 3.5088827340833606, 2.8701235257810165, 7.269085943698884, 6.586701889191905, 6.139232016378834, 4.176134774761816, 13.204845497685096, 66.33077836805775, 85.26009759595318, 78.66472628808792, 81.76762703926333, 73.20392408678609, 68.04058659461238, 74.08713986796718, 66.53693029957434, 68.84356637154856, 76.68195247650146, 77.30131041619086, 74.99633742916969, 70.09468478541221, 78.99081645473358, 73.29438178770005, 61.91387184204594, 56.90769195556641, 58.77890179234167, 59.83587857215636, 61.966855218333585, 65.47877680870795, 71.71636519893524, 75.24862427865305, 73.19088612833332, 69.94202613830566, 67.48326486156833, 62.07047639354583, 56.25577442107662, 56.883126151177194, 61.19108492328275, 55.058757258999734, 66.4341720458, 67.36120854654621, 82.04445223654471, 70.58499674643241, 81.06888032728627, 31.887586885882964, 30.960128730343236, 73.57454099962789, 73.58573544409968, 74.43620727908227, 69.96631345441266, 67.73177839094593, 57.843024269227065, 60.242569523472945, 56.31409222079862, 64.73671536291799, 72.8922760871149, 79.98367817171159, 70.49202088386782, 62.71772238516039, 75.5205935816611, 73.99174782537645, 75.22863588025494, 70.25465473051995, 71.27371788024902, 70.51721818985479, 68.27166126620385, 72.21842073625135, 78.79000679139169, 71.30566166293237, 65.73060474088116, 80.57383798783826, 76.39236388667938, 78.3918156162385, 78.11506886636057, 82.89363753411078, 81.38474095252253, 72.73498904320502, 25.299844588002852, 3.4255201105148565, 4.297435052933232, 3.171306641832475, 7.898136550380339, 4.890133623153933, 1.8927858145006242, 0.448532436764048, 0.14469105690237016, 0.38539600528536305, 0.344637829449869, 0.1495588561820407, 0.1944897290799887, 0.16827571716520096, 3.763746580769939, 51.25414448399698, 75.29168405840474, 75.28567498730075, 76.55591887812461, 52.6004078311305, 35.55048442655994, 61.91522505975539, 74.73953985398816, 82.20289245728524, 102.23308763196393, 52.54059560837285, 0.7711847991712633, 0.22095745399353967, 0.22636865475966086, 0.24602475485974745, 0.12589840684086084, 0.130915968648849, 0.170528061627861, 0.11932275242983334, 0.15614664542578882, 0.1539290813548911, 0.14545735933126944, 0.1269638589433124, 0.17431081993685615, 0.11718227212587673, 0.24324593945376335, 0.13499524894981615, 0.0965591392389709, 0.1519537389638924, 0.1724731741893676, 0.2414658115876298, 0.19773260990698494, 0.23232540205842067, 0.1492926099848363, 0.09584447879704738, 0.2013027328517168, 0.1511721454200245, 0.12591823319634124, 0.13893232801027838, 0.21912126381310726, 0.20557685995534544], [0.015864757775899865, 0.07335394530767396, 0.05182001431803069, 0.0577795540072745, 0.047605002389079144, 0.015705753354385735, 0.06688742012146019, 0.047808065484728546, 0.05006458895701555, 0.07697685937126798, 0.02648283982829702, 0.017787284150178877, 0.008831348593136477, 0.04540677820782989, 0.04254374675632965, 0.051980406316297675, 0.04493281876127567, 0.038626942212783524, 0.09687434611541611, 0.046216506330717, 0.058735658549853874, 0.0648579766012488, 0.0850197330357567, 0.05683890528856747, 36.123005344021706, 83.64807405779439, 87.24822152045466, 72.95431229376024, 58.99507537964852, 41.51194187902635, 21.493664826116255, 22.76911174097369, 42.404465444626354, 55.231718094118186, 41.850720913179465, 48.47133267310358, 19.274221081887525, 2.346390764559469, 0.016586579224695603, 0.185403696471645, 0.10082529136730779, 0.1060422198967107, 0.2750325515385597, 0.7163507996066925, 0.9021828311585611, 1.717671843305711, 2.8450632576019537, 0.8099344456868788, 2.733117832291511, 19.203771391222556, 71.87207545003584, 76.95717734675254, 75.83898021328834, 70.88564642014043, 65.08413537856072, 65.86036066855154, 70.10103902509137, 67.05272197723389, 60.22814304597917, 60.07499410260109, 69.40051155705606, 71.53097045037055, 69.61015439802601, 65.81840699718845, 72.45545741050475, 64.1245000593124, 58.60119881168489, 51.70937476619598, 50.92725023146599, 49.16874185685189, 51.25002991768622, 49.09222033716018, 51.60793050642937, 53.06715026978524, 57.95965202393071, 55.569638129203554, 55.03800792078818, 51.57710459924514, 52.34921140055503, 50.752116403272076, 51.96269712140484, 50.38734382198703, 55.90678545736498, 56.2501811212109, 71.07175504007648, 61.74513539960308, 80.49240173832064, 29.054003915479107, 28.97373260990266, 71.14431888826432, 60.55631991355651, 69.52478793359572, 57.860659245521795, 57.33138638157999, 49.72601259908369, 53.75204709268386, 49.9369929682824, 57.296861679323264, 62.95151525928129, 71.88865138638404, 64.45710920518445, 71.54557735689225, 70.58541251767066, 64.5400281106272, 62.142479342799035, 56.42279678775419, 54.160448197395574, 54.67156440980973, 56.27715526088592, 65.14249632435461, 68.85410970257175, 70.96223462012507, 63.47235894972279, 72.7589939486596, 70.70266000686154, 67.84773934272029, 67.48466907009002, 74.12630865650793, 72.26316713517713, 71.430848029352, 68.56110865069975, 39.7048157261264, 3.22348102927208, 1.372264248709525, 0.665323889303592, 2.971876181902424, 2.5092723340757432, 0.3030465789619954, 0.1294631595092435, 0.0851654352980756, 0.11019977140090159, 0.14473427958305807, 0.12634782466076075, 0.11551350280041657, 0.07779370062053204, 2.0646025432694346, 39.66644317873063, 53.694631438101496, 54.978670304821385, 41.422029387566354, 20.048653848709602, 34.20739427689583, 57.81663456270772, 65.16128055510983, 64.77165583641299, 75.09004285258632, 13.427972466714921, 0.26038412305135883, 0.05597085106156527, 0.02583280656366579, 0.059873276134772654, 0.057852726895362146, 0.08300617051821563, 0.027256278366210963, 0.007092912668257111, 0.06003060761178213, 0.03381193788241475, 0.041144724649887894, 0.0462340459137434, 0.03813131779973065, 0.007326116056872473, 0.09338011184046346, 0.02600788063700161, 0.10503849149831843, 0.06334458905903083, 0.06905973137867066, 0.03278834482414588, 0.05565795777065139, 0.04098064776870512, 0.04980857003360026, 0.0151914689547172, 0.01504428910031434, 0.027243072925616178, 0.0265040451420411, 0.028018260059217294, 0.033505023907749884, 0.0676500606500814, 0.06187494896772889, 0.029593488133902994, 0.03319204251672472, 0.02107371324523082, 0.011734626473738782, 0.03664255615383868, 0.030081943879204414, 0.010644401003035807, 0.06362756661650154, 0.015015782011041959, 0.0047166994491201495, 0.014226279566965759, 0.022958255065004193, 0.05092962479759609, 0.051948176997323195, 0.016801034047779058, 0.04818408059016351, 0.06326735207450486, 0.04460651510124726, 0.09758665466741209, 0.06938530342473138, 0.06572858190103885, 0.04252105140157285, 43.2614327246143, 98.20939479335662, 94.82907264463364, 83.07583162861486, 67.20779680436658, 53.76108815593105, 28.09143662452698, 32.451494278446326, 40.08310479502524, 37.92606792142315, 47.450080840818345, 47.070085540894546, 20.95421733394746, 2.92600626907041, 0.21655349030850396, 0.1456534165528513, 0.051473371023612643, 0.5580339496654849, 1.4650100397486843, 2.0288632545740377, 1.988465415854608, 2.723090538094121, 1.546446902136649, 0.2857782829913401, 1.430763825774193, 21.103039903025476, 75.5455320112167, 79.98553737517327, 79.09634390184956, 74.23857473557996, 67.4209854679723, 70.55826971607824, 73.76685480917655, 69.83790289971137, 61.86245741382722, 64.26185754037672, 71.27305892206007, 74.06267212283227, 71.96487872831284, 66.31254719149682, 74.13581648180562, 67.20263496521981, 62.24271551255257, 53.94484335376371, 53.67179932132844, 52.41420899668048, 54.897120306568766, 53.48283913827712, 55.13864809466947, 57.3606001946234, 60.74228340579618, 58.50864264272875, 58.935478887250355, 53.74277853196668, 54.991021848494015, 50.86239776303692, 53.84550148440946, 54.026040338700824, 60.14468285345263, 58.728868038423606, 75.71836733048963, 64.14317054133262, 81.80286561289142, 32.729894307351884, 30.91836137156333, 74.32647505114156, 63.39540989168229, 71.76994477548908, 60.62447109530049, 61.12379666297667, 54.733388808465776, 55.389354228973396, 53.40720407424435, 60.87404366462462, 65.73169515978906, 74.4454405384679, 65.59293347020304, 71.52017608765634, 72.93492009562831, 66.83683472294962, 65.10138988494873, 58.61237364430582, 56.70398366066718, 56.528343846721036, 60.75800818781699, 67.30912731539819, 72.1560864294729, 74.09226248341223, 64.14208796716505, 76.04954088887861, 75.27830877611714, 71.9474712494881, 71.15919251595774, 76.24212141959899, 74.37800715046545, 77.19482591075283, 75.51733801441809, 43.879817916500954, 4.467068247256741, 0.22911625974360975, 1.0735003770359102, 0.8550423155388526, 2.4206615792166803, 1.6308067883214645, 0.3902344327540167, 0.07256740283581518, 0.22319116719788124, 0.1534194030588673, 0.3523640100273394, 0.11664620976174071, 0.08563267998397352, 2.0063489723590116, 41.008897904426824, 53.57250452041627, 47.91341866216352, 36.58884955990699, 22.386604162954516, 41.74561315967191, 63.153442798122285, 73.01710159547868, 71.97892081352973, 89.48912651308122, 22.189597237494684, 0.2047928455736368, 0.03431085264310241, 0.021297071925214222, 0.07765039621341614, 0.015750877848345668, 0.038156070100564154, 0.05704500975327627, 0.021807273076246345, 0.02937837447520466, 0.009380542661904568, 0.06937275490453167, 0.028975573105497227, 0.010125543058459318, 0.019244042473034035, 0.03370295038386699, 0.026143587367128462, 0.054634713282388066, 0.04226263845339418, 0.06157506001932968, 0.10204999782745877, 0.04768025903632084, 0.033803729250306086, 0.02059498490134795, 0.07403986213067848, 0.06707449113169024, 0.06655902887183814, 0.04146171651119667, 0.02043626488997571, 0.04356522158148789, 0.15451519990399962, 0.1987058020407154, 0.15524387209405824, 0.10283618023799312, 0.12269423643667852, 0.10924564719560648, 0.1566228303577631, 0.17353380759877546, 0.14671509184183615, 0.2164481532189154, 0.12667206371383322, 0.17852264877048232, 0.12407949194312097, 0.10894357106618344, 0.14204164906855554, 0.22354974231171995, 0.13515485570796076, 0.11315434269847409, 0.1546314920509054, 0.1555841989935406, 0.1185783064894138, 0.2096811760096781, 0.10213560815299712, 0.09463886324796947, 52.303613847301854, 109.5125359873618, 108.2649947750953, 95.77873337653376, 79.0585950113112, 60.60210181820778, 33.40577556240943, 33.74538613903907, 57.37607786732336, 78.72598586543914, 61.92183033112557, 68.50133172927364, 31.15252490966551, 4.167019676777625, 0.3907181713129244, 0.4636245833769922, 0.36360766798738514, 0.6885402144924287, 1.870293963340021, 3.5890226402590355, 2.962702983810056, 9.563791636497745, 7.429537850041544, 6.1269393082587955, 10.873944663232374, 23.159770004210934, 82.74688597648375, 83.54147188125118, 82.74831371922647, 76.59997493990006, 71.65595285354122, 72.40652976497528, 77.31753333922356, 73.4452675234887, 67.36932000806256, 67.58419529084237, 74.48016135923325, 77.07814324286677, 72.97331225487494, 68.02259076026179, 78.27336003703456, 68.9520905094762, 65.99615312391713, 57.63778624996063, 56.88666020670245, 54.53991397734612, 56.90125926848381, 55.12376269986553, 58.278568175531205, 59.5650153775369, 62.18086365730532, 59.0941583725714, 61.19988279957926, 57.362561379709554, 57.32761698384439, 53.86693723740117, 57.29313935002973, 56.01262277172458, 61.24188746175459, 62.49249204512566, 78.48168496162661, 66.39650160266508, 83.40247092708465, 36.090716392763206, 36.03075511993901, 76.70672616650982, 67.10465415831536, 75.94157372751545, 64.69653068050262, 64.57896547932779, 57.59611106687977, 57.69436643969629, 56.995513823724565, 63.37337401605422, 69.7959178493869, 77.70278853754844, 66.7168729535995, 73.27709197998047, 75.5540043307889, 69.05729632223807, 66.92262480335852, 62.317228778716064, 60.04363475307342, 61.31394924656038, 62.84870209232454, 70.70076157969814, 76.28823280334473, 76.5677095228626, 64.93936069550054, 76.35077891811248, 78.49896692460584, 75.7126328252977, 74.3181674711166, 80.15425420576527, 76.59964546080559, 81.2854814529419, 77.67474359081638, 43.42785889102567, 4.547442515050212, 5.242349226628581, 6.141254488498935, 10.501283214938256, 6.395675597652313, 1.3663146260284609, 0.48125998868096265, 0.2502971812481842, 0.37262280681921595, 0.5249004017922186, 0.507560154843715, 0.281403461290944, 0.19850680304150428, 4.465347307343637, 57.517020394725186, 71.10550311303908, 69.47618192242038, 57.01480796260219, 30.572082765640754, 48.43276792956937, 73.79135393327283, 85.41541561003655, 82.12159741309382, 98.3649952180924, 24.055339290249734, 0.387920479500486, 0.14361684841494407, 0.18382743992392095, 0.12554461211566964, 0.12545179290276381, 0.14585937163041485, 0.2041817065929213, 0.12197262757728178, 0.1423613375593578, 0.2055104860975858, 0.17065417502195607, 0.1521449545097928, 0.13487178621993912, 0.12550987002830352, 0.24878598088699005, 0.11847397297500603, 0.3024953020916831, 0.17014414432548708, 0.16840469572813282, 0.23295132653607478, 0.17184706585061166, 0.09446627129950831, 0.1166180024043687, 0.11700064800078831, 0.12025847520318725, 0.18992150082222878, 0.04552061504293834, 0.09840217058456714, 0.14835942296251176], [0.01788350287824869, 0.03943454061124114, 0.011895102741677436, 0.05018419826463346, 0.04179190423700117, 0.08606708248055751, 0.012152664374650247, 0.09661651922449951, 0.14861762523651123, 0.08099600943105836, 0.017270854704322356, 0.019564037399005987, 0.013307179943958839, 0.03293723401222979, 0.012151809229004768, 0.03583200831687258, 0.059012086055572, 0.029535941524250858, 0.016660627368236744, 0.04947328399265966, 0.05525719802526217, 0.058188993528845816, 0.10361735243350269, 1.7950418206953236, 64.52475832354638, 84.60858406559115, 74.74487427742251, 70.3121566772461, 73.24764282472673, 42.67188087586434, 44.0057259990323, 42.2183568246903, 42.912710482074374, 51.52342304106682, 47.64823113718341, 13.723280852840794, 0.3949022984072086, 0.03774845769869224, 0.12214828387744005, 0.08101499308982203, 0.2976408174201366, 0.08777681452732894, 0.8151314023040956, 0.6624485468191486, 1.1934858031811253, 2.332008904026401, 1.4683764139490745, 1.8596827262832274, 33.10551420334847, 76.20117971974035, 74.51374469264861, 72.07940409260412, 69.98172836918985, 64.33655515793832, 70.04418034707346, 73.52823349737352, 73.73704479586694, 70.13194730204921, 57.19156172967727, 57.2972107702686, 69.51779826994866, 70.3972250415433, 67.68973842743905, 63.899673723405414, 71.18981838226318, 65.20536407347649, 55.15763628867365, 49.046693386570105, 54.95257477606497, 55.20448900038197, 62.05361020180487, 54.55380309012629, 52.83679339193529, 48.22835753040929, 48.94834387686945, 47.82287466910578, 52.51796353247858, 49.28605210396552, 49.74153734022572, 50.88894044199298, 52.81746395172612, 51.478362852527255, 55.29158130768807, 53.285916543776, 64.61336858810918, 62.458069324493415, 75.73686522822227, 41.26125143420312, 36.91604583494125, 74.13912696223106, 59.46785434599846, 66.69381726172664, 54.39004021306192, 56.19133380151565, 50.997252771931315, 54.38669050893476, 49.73335135367609, 53.492299895132746, 61.96129721979942, 69.87140778572329, 66.49792625058082, 72.07934917942171, 67.46066416463545, 61.34326896359844, 53.21624348240515, 49.902444731804636, 50.03376176280361, 50.0004529953003, 50.343350518134336, 61.74646508309149, 68.85490202134656, 69.10751050518405, 60.14904845145441, 72.74747002509334, 70.24561758964293, 67.85855723965552, 61.231850116483635, 66.519805231402, 74.07166219526722, 75.21798272286692, 72.51888998093145, 79.53980707353162, 57.2496049634872, 8.581987081035491, 0.07634463765087628, 3.3831349784328095, 3.8944247557270915, 1.674452104395436, 0.3510956442163837, 0.23633046376128353, 0.06627795121241963, 0.06612511667152567, 0.09018908750506179, 0.035881911284260215, 0.07965902512472484, 0.06943516808772279, 4.400155063598387, 44.819355010986335, 45.00007429430562, 61.683687548483576, 37.778990807071814, 23.745309268274617, 47.13527141078826, 48.5270264071803, 68.55586051940918, 69.708511752467, 53.71982089934811, 2.6336423572032683, 0.04889176197109684, 0.035780741712979736, 0.07079373309088331, 0.03012314791821184, 0.07068985922923011, 0.07247082979208039, 0.030802380624077016, 0.030720058730953646, 0.022987623045581485, 0.01856831078898282, 0.0713561871840108, 0.029429003310900544, 0.01927576425875868, 0.019656735953063737, 0.03573812041131239, 0.09119925870289726, 0.028977607068936193, 0.019778706726708242, 0.05000656162719092, 0.07111776530021621, 0.020828829409794945, 0.04080060561518035, 0.07140092671878877, 0.040016043480605855, 0.03879291899201851, 0.03953072295013455, 0.05125988147131378, 0.0429610654922022, 0.07596212995028304, 0.07850351938677412, 0.018770960197153113, 0.03384363093984223, 0.019192592008039355, 0.0030517134009935567, 0.021853711410996415, 0.06885775229743413, 0.07243119240287813, 0.0715986080467701, 0.012637166148652474, 0.010202668002626349, 0.05408385009955495, 0.06348510490610235, 0.017010652940840493, 0.00574029250738902, 0.07852248006290005, 0.0813641989483468, 0.06375009854955059, 0.05380327422772685, 0.07362607506013687, 0.12163899628625763, 0.14293993312504985, 3.251394331455231, 79.56833839416504, 95.2921712013983, 85.58694870241227, 78.11399413693336, 82.70314370432209, 52.55364141156597, 28.81417255247793, 25.498893107137373, 37.01165753026163, 46.07934974854993, 47.26383493792626, 16.99069365378349, 0.665621008844145, 0.1155611687910653, 0.13521499361001676, 0.13769865066053408, 1.0594981283910814, 1.5681117460612328, 2.553242348855542, 2.064134310330114, 2.1933408610282408, 1.7659793866257516, 0.4028915229343599, 2.696892047120679, 35.760845061271425, 79.8739851674726, 78.80687298313265, 75.89462295655282, 72.50612658839073, 65.85744242514333, 72.42622006324031, 75.25308793590915, 76.86257762293663, 72.53073553885184, 60.15030360990956, 60.95609180388912, 72.04253381298435, 73.94105511326944, 69.5913113317182, 66.12590512921734, 73.58070696553877, 70.16675441495835, 58.85319932814568, 52.20904158007715, 57.3861740481469, 58.671107215266076, 63.902148738984145, 57.63025922159995, 55.38382368703043, 50.7751367938134, 52.72785348276938, 49.617213895243985, 53.10802921172112, 50.700235213002856, 53.96600454084335, 51.8453594177, 55.287400061084384, 54.620020543375325, 58.34152613916705, 56.5750906544347, 67.60926708098381, 65.34991125906667, 79.66537783222815, 44.31922143505466, 39.85387755978493, 74.33956007803641, 63.15553342142413, 71.25013659077307, 58.09629171125351, 59.03794296326176, 54.3453840286501, 56.8608667004493, 52.584435939788825, 56.558718681335456, 64.99178317285353, 72.63994216918945, 67.69241348389657, 73.6307014957551, 69.40099008621709, 63.78194378268335, 55.50567996117377, 52.95391928765082, 51.87326315910586, 51.52076367408999, 53.40126560580347, 63.346949008203325, 73.79784153353783, 72.21762841747653, 62.856264422016764, 75.71817905672135, 72.48287477800923, 69.67710925686744, 63.14884185791016, 68.02263782870385, 77.98418721845074, 77.70265517696258, 74.67191819221743, 85.81891767440304, 62.67275633350496, 11.162969412342196, 0.6377762868519753, 1.264707955621904, 0.6396076047132093, 2.2459881392217453, 1.7383779128712995, 1.2003146496511277, 0.2761037876048396, 0.4380189525263925, 0.037246202794654716, 0.3087781117327752, 0.04182747369932552, 0.0413353847820432, 5.2064394374047565, 45.445412358930035, 47.78041108962029, 48.85965124253304, 33.6601883365262, 35.41948510754493, 56.62932918917749, 56.37588916286346, 76.95836974728492, 75.7589481722924, 68.9139650714013, 5.845816664157375, 0.06451942702575077, 0.19692728295922282, 0.040022662480271635, 0.027305836594032667, 0.031476785060799414, 0.10444896385794687, 0.03628302726053423, 0.030745081077780456, 0.024583878318568873, 0.02504992216164547, 0.08558218712888419, 0.01140872213704091, 0.046468143231205405, 0.042199884361076745, 0.03809524271937628, 0.04888741825256617, 0.020306079738563108, 0.08036823102062748, 0.05202972322642323, 0.02323928484392743, 0.045886988931846236, 0.04182131818285392, 0.04648466008685289, 0.013259171128963992, 0.06857244583267359, 0.022280056577836795, 0.017281348193665187, 0.048402162839568434, 0.21609641160936127, 0.1456925789675405, 0.13669720520415615, 0.09517999711416422, 0.13515888533044246, 0.1838824297151258, 0.081308105990531, 0.17456816419238047, 0.2004797092729038, 0.25789096651058047, 0.1368220468922969, 0.12691446925483404, 0.12260389934864738, 0.25766365290168797, 0.1507907562078007, 0.18044952843939105, 0.18939337512898832, 0.10334919867736679, 0.11993578364772182, 0.26681049756946107, 0.35569419423418663, 0.12945972743534273, 0.4447336825391939, 5.135330298254567, 92.03689421376875, 106.0949513220018, 96.80690426980296, 89.11681513632499, 89.40639588140672, 56.43229676831154, 60.01540153257309, 59.51771943799911, 62.04635381698609, 75.78769130091514, 71.7835004868046, 21.675972669355332, 0.9691535633417868, 0.214054036524988, 0.3092781526427115, 0.1777875107983428, 1.280025914311409, 1.8367297514792413, 4.023755106233781, 3.4568076316387426, 6.322220390842808, 12.280676249534855, 8.143395493107459, 4.04191592527974, 36.6759418672131, 83.64532055393343, 81.13423485909739, 79.11706970584008, 75.21036547999229, 69.21506189530896, 76.1662470909857, 78.41108229852493, 80.14674678925546, 76.07501276077764, 63.08085149334323, 63.789866970431426, 76.59843737079252, 76.90688471640311, 71.11367733247819, 69.30252290541127, 77.45418087128671, 73.90500068664551, 62.67745141060122, 54.31691154356926, 60.80694367808681, 59.73192007310929, 68.14874987448415, 59.600430457822746, 58.63478606747043, 53.88372890410885, 54.83620982016287, 52.859723567962654, 56.89781150510235, 53.42761608862108, 56.39580303622831, 55.98182824350173, 57.35032358477193, 57.962405527791674, 61.311093761074936, 60.00936892724807, 70.34381804927703, 70.07727730658748, 82.3433211541945, 48.79554010206654, 42.9265917501142, 76.84463670176845, 66.5686858084894, 73.75616242808681, 61.713403424909046, 61.58844063358923, 56.79511208688059, 59.3451508398979, 55.163406095197125, 58.70554170300884, 68.50869794045725, 75.28669480354556, 68.93618922079764, 77.12881242075275, 74.38203934700259, 66.31088410654377, 57.8508258634998, 56.69413851153467, 55.06140093649588, 54.75886852510514, 56.10061722417032, 66.82316134052893, 76.57702907439202, 74.003232525241, 63.601283334916644, 76.99585976139193, 77.31070841512373, 72.67303128396311, 66.00641404428791, 72.31604852984029, 84.43978094285535, 80.3770762105142, 80.81851543918734, 87.95276549554642, 64.75953179021036, 10.430765863387816, 3.320278015828902, 7.897475140710031, 11.47103334626844, 8.20493502962974, 3.141151705095845, 1.7474354010435844, 0.23876404930506986, 0.7577500071737074, 0.5997500111979823, 0.4460184732752462, 0.24272147566080096, 0.16651322464308432, 7.7656854641052995, 63.4044195759681, 62.30522632598878, 80.38522689573227, 54.27521674863754, 36.68162145922261, 63.47901128953504, 66.19962999897619, 87.95798224787559, 86.08809424984841, 78.9888160459457, 7.132893896871998, 0.24260455532179726, 0.16472915908501995, 0.17701049846026207, 0.19404334496826897, 0.1605396846970243, 0.20196452556598574, 0.08688103557834703, 0.09083100023769564, 0.0914180763967095, 0.13564654625952244, 0.18821807367907417, 0.14546901918947697, 0.14714863631994496, 0.11479446033556616, 0.15475153802864014, 0.17731340962552256, 0.10064119277822395, 0.14128907493525936, 0.13334763897282462, 0.18265183203883711, 0.14688766080765955, 0.13112036090704704, 0.14053647015844623, 0.15158158877203542, 0.23895216985575615, 0.1572513135690843, 0.1237931052943872, 0.19947613409209639], [0.016569644851129384, 0.008923657399962747, 0.09228503511797997, 0.020503494850990754, 0.046656999226299026, 0.10594983735392172, 0.04814227134169591, 0.022151043540948344, 0.038889040043877984, 0.017834952056047418, 0.049448723213807236, 0.044041368209065936, 0.08768346671375536, 0.07472990050671563, 0.06213939485831126, 0.02226971630607882, 0.013847900122674483, 0.053264603334208654, 0.06631270862154423, 0.03139827253987953, 0.06873461898536452, 0.10158294466354194, 0.16354703945257973, 35.97648912860502, 86.31876099494197, 78.02172430099981, 81.87073046161284, 67.17849669917938, 39.451858151343565, 24.066268974734893, 49.54493245770855, 48.28168215290193, 56.890555120283565, 47.62248469937233, 23.02206539338635, 0.3358361840007767, 0.15217889220483843, 0.05028036528176839, 0.07678955853466066, 0.007751775575020621, 0.2985455979022288, 1.1991837813008217, 1.3086836088088252, 1.682239112354094, 1.5304270843344352, 1.9354201396626813, 8.002758420282795, 49.680485648493615, 84.27844601292765, 70.19494841175695, 74.41485389586418, 66.78611847662157, 65.15902519226074, 67.85629795443627, 78.03000050206339, 74.6443517746464, 74.56841468811035, 67.35882374548143, 56.253519058227546, 58.927453717877796, 71.66269148549726, 71.6603772870956, 69.6288013458252, 62.102467244671246, 70.56891502872591, 65.3439845577363, 55.80643946124662, 48.015317916870124, 56.714523069320194, 63.08076127882927, 68.32743737005418, 64.71765656625071, 61.28060517772552, 49.110749613854196, 49.552839955975934, 52.180486725222686, 51.81587888348488, 48.54599498933362, 51.22799404205815, 50.42437491878387, 54.255859851837165, 49.66771048884238, 53.06101568283574, 49.24064282448062, 59.970368800624726, 59.168459830745576, 76.70622410312777, 45.45967801924675, 42.75967528743129, 74.3932730151761, 59.75989441717825, 62.9707819415677, 52.83573827435894, 53.25719302700412, 50.02605822778518, 51.93638193991877, 48.40705679308984, 51.7977967569905, 55.700955160202525, 69.04505852730044, 66.81560685557704, 67.77841537229477, 65.03829071598669, 56.61356518345495, 50.89239605011479, 49.22439636722688, 48.98019744503883, 52.417743052205736, 52.012958372792895, 60.04251687757431, 67.72968384527391, 70.93619008218089, 62.48903251463368, 65.81064854898761, 70.16414996116393, 70.5096087917205, 64.32304259269469, 57.26336856042185, 60.51604109425699, 65.72806304500949, 70.85898999244937, 71.34029619155392, 74.51858489744126, 79.13784257827267, 30.266914521494222, 1.3631797942423052, 1.4122938749290284, 3.2827465716869604, 1.2919864467074795, 1.384835445111798, 0.7450988311921397, 0.040023374942041216, 0.6234501362327607, 0.12419127949303198, 0.041169990229630665, 0.05603748155877956, 0.11337296120942601, 13.766399468145064, 50.674367181716434, 39.0572637896384, 36.598376997055546, 24.877252348007698, 31.401469899762063, 54.220295721484774, 61.12081566164571, 64.61971890541815, 69.48671740870323, 37.807604497478856, 0.16640793351877123, 0.04131577293118162, 0.1378652594623066, 0.062032575388589216, 0.04120773921209959, 0.004459706636431117, 0.06315755635319699, 0.0404630902583801, 0.02176828877699952, 0.05515991635019741, 0.05171921629939349, 0.09045338783893855, 0.028378717834129933, 0.052495305501525445, 0.020816924403451627, 0.03102101445678742, 0.01562906412272564, 0.046973864683100296, 0.06688358202095955, 0.02366753565447946, 0.022485799066001372, 0.043359097964580984, 0.039018022437249465, 0.027409490205407627, 0.0773313895408665, 0.017493378348468293, 0.03210702069824742, 0.06239046102329608, 0.008148305557457911, 0.1043172810046423, 0.033061278968929284, 0.0243981632839648, 0.05641905080166556, 0.04996880115340314, 0.03923103318459565, 0.08159423983024974, 0.023102091903227474, 0.003460468231482552, 0.06054698151626414, 0.0175999392635159, 0.0418516322820177, 0.027493441950589902, 0.05274483566022208, 0.030649865924891447, 0.05901360290966207, 0.024974123507197347, 0.006937135870928967, 0.0490437384935156, 0.03920371831965543, 0.09524980304582466, 0.14280979010847308, 44.71056807425715, 98.3083091243621, 84.0049312960717, 89.9465847015381, 73.71318894047891, 55.589246057694965, 37.583237078882036, 57.61875490988455, 48.320643055823545, 50.152805697533395, 49.120198603599306, 25.54304526698205, 0.4014504502617544, 0.062234064173554225, 0.1975109500269736, 0.29102760937906086, 0.6142936695006587, 1.5068346406182938, 2.0295629073535246, 2.010432650004664, 2.1239122123487535, 0.665230304002762, 1.300019215672247, 9.58118538702688, 52.150409990741366, 86.86835565874654, 73.38177219513925, 75.56486145142587, 68.74228292895903, 68.26866457539221, 71.65812584661668, 79.22676271007907, 78.15484169990786, 75.81776803539645, 70.64877448543426, 60.05708848276446, 62.73101529767437, 74.27769645567864, 75.54877973371937, 69.64661675114786, 63.79105937096381, 72.79595052042316, 67.98995664042812, 59.19964659598566, 50.30482499830185, 59.96764275335497, 67.23697923844861, 71.71330575020083, 67.35003763629545, 64.22899984544324, 51.113190189484634, 49.933804081332305, 54.33355808258057, 54.608127917012865, 50.48211613009053, 54.71400053270402, 52.37746031053605, 56.50465665325042, 52.62536587253694, 55.73194972930416, 52.62129445229807, 64.0319948811685, 61.718843752338046, 79.1990315529608, 48.89137145011656, 44.148931734023556, 77.99698198995283, 63.578745395906516, 67.21873237240699, 55.892845353772564, 56.22667827913838, 52.255278479668405, 56.61904865695585, 50.306433170072495, 54.26619137487104, 59.117131694670654, 72.15474497887396, 69.27956135042253, 72.11884744705694, 68.46570091862833, 59.042398775777514, 52.67777266040925, 51.81760472636069, 51.82454339919552, 55.14994844313591, 55.12157793967955, 62.08472636438186, 71.45974805278163, 71.93484906227359, 63.245740090647054, 68.59103633511451, 73.39730478102162, 73.09580003061603, 66.68871818050262, 60.95135750309114, 63.587860984186975, 69.73923960039693, 75.52596722879719, 73.81107561049923, 78.70191820206182, 84.13598552826913, 36.34328957526915, 2.64887880413763, 0.8605550229549409, 0.3563514976732193, 1.7494920713286248, 2.6807335980476874, 1.8124224557991953, 0.15997032815169904, 1.2403832544242184, 0.32179636640414117, 0.10237543963857236, 0.09534326577258688, 0.09045670499965068, 15.12866706617417, 51.544399876748365, 42.51855934819868, 32.98151631509104, 27.98359105663915, 41.28423260104272, 60.445650239144605, 68.4212447750953, 73.60874406753048, 78.91779761160575, 50.25286928299935, 1.8684093870462912, 0.055300861206506534, 0.05341150069368943, 0.04236010398956076, 0.06673843900282538, 0.06207245792592726, 0.03128174673615685, 0.003085801201391845, 0.002257634060374732, 0.05192361238803114, 0.02243384106775686, 0.0533352519625858, 0.042412197968411836, 0.02138720216950582, 0.037132128472289735, 0.04080804432892511, 0.0075034879151761776, 0.061226421065868876, 0.04009778506212658, 0.04307207546287006, 0.02912679311609076, 0.05258100392717508, 0.053081293815686825, 0.011325009794334972, 0.03987201895084112, 0.11798298722433469, 0.05782052821990463, 0.05485929578783051, 0.12644280424161305, 0.1878331604623987, 0.1617680300748156, 0.1948890294278822, 0.14310494846393987, 0.15647649224246704, 0.2063289284706116, 0.17277603938935265, 0.17089958362762006, 0.10411413746976084, 0.2764092421820087, 0.13432073917600418, 0.1515419973481086, 0.15741223799845866, 0.20667745251088374, 0.11797921807174722, 0.16524539509367558, 0.15396075142968088, 0.1723394612030637, 0.1392009184365311, 0.1827478841427834, 0.3327017812238586, 0.37966395157479477, 55.40203525174049, 113.51987254235053, 97.08788717946699, 105.24178089634066, 88.30897946511546, 54.96801714743338, 37.180107639681914, 62.83090629885274, 70.8250379562378, 78.92072369975429, 65.85439866588962, 34.73994231993152, 0.7202560094095046, 0.3350039673668723, 0.49817517940555855, 0.5706172809004784, 1.1192770110022638, 2.3808240265615526, 2.4907766426763227, 4.279264673109978, 6.117715364502323, 7.035625980746362, 5.448525182662472, 11.814723187877286, 57.22275241728752, 92.95535641331827, 75.83207684178507, 80.05863466570455, 74.41269659226941, 71.24486492526147, 74.70252836904218, 81.07100625191966, 80.91227577578637, 79.08603591303672, 73.35995597224083, 63.250780336318485, 64.20269250869751, 77.5732091165358, 77.28253010780581, 70.66695859355312, 65.65508342558338, 75.68982032037552, 72.18030314291678, 62.689265589560236, 52.675058380250015, 63.39047947237569, 70.13323383946573, 75.41799222269367, 71.51548493293025, 66.98032286859328, 54.3472981452942, 53.11368919187977, 56.223179524944676, 57.385271903007265, 54.19747144945207, 56.871676752644206, 55.73897861665296, 59.07451514274844, 55.194459499851355, 57.70379973996071, 56.32349414210166, 64.99280298909834, 65.90727221581244, 82.03198694413709, 53.797464216909106, 46.62589673073062, 79.977245484629, 66.83965882947369, 70.6308178747854, 59.87869516495736, 59.518884381940296, 56.330397513604936, 57.7567478149168, 53.5813965335969, 55.52932008620232, 63.02983322451192, 76.70882071218183, 75.65698223729288, 74.13111748233919, 72.74063725625315, 62.74104872057515, 55.480459120965776, 54.42284691718317, 54.61123835655951, 58.803177341338134, 57.56562640590053, 64.78269338607788, 76.02929361404912, 74.2627836042835, 65.6825400167896, 68.72408313135948, 75.75690069506246, 76.2508761498236, 70.62792316559823, 63.91257047653199, 67.01720883769374, 74.24823945568454, 78.85350996448149, 78.08478032388996, 79.27973039688604, 86.19780294356808, 37.02973965675601, 3.0131142658572045, 4.909153196119494, 9.709363541295453, 5.288185063869723, 4.5306513386387985, 2.151156995565661, 0.14878241074902399, 1.4527791089588598, 0.41016347465976594, 0.32070058488076736, 0.14376625088193726, 0.37915021301277224, 23.403939508622695, 68.91153320189446, 55.60585729537472, 51.45371860073459, 37.03509761441139, 45.09482699055826, 70.72484493255615, 79.2336033236596, 83.3649024655742, 88.95671967537173, 57.993278503417976, 2.3802538119977523, 0.16532220306896395, 0.2649438783766762, 0.13862229222732206, 0.25178688518222303, 0.17064375622618586, 0.12228208879429488, 0.16349779532080697, 0.06221955446826835, 0.10663546306351501, 0.14250401377437577, 0.1874561532731018, 0.13901060687438135, 0.09616141703220145, 0.0922205918017895, 0.16706257097182736, 0.0700897978798997, 0.2040956749190246, 0.16892194297284852, 0.16903975197384435, 0.16415183522528218, 0.10949605069453679, 0.1650001856708719, 0.13392290971692533, 0.17080815869473642, 0.20511336143939726, 0.21129097188672713, 0.1806362240665382], [0.004944520591262488, 0.04654788149280414, 0.060400279509204055, 0.04795218194504419, 0.01920398948113284, 0.03155235963452968, 0.028135952231804692, 0.04373486026100094, 0.050272555015380346, 0.1055568112661281, 0.07229582466665777, 0.01137037177555143, 0.003599200530105361, 0.05490634890813982, 0.011530113556692678, 0.03405201068568615, 0.07158926943497312, 0.0734287461326007, 0.006137310870878038, 0.07875648928025077, 0.04129362915973029, 0.1034883508879331, 2.395342189458109, 67.23439047413488, 78.71628192163284, 76.88706890229257, 49.29664250343077, 44.165103666244015, 19.6096464895433, 24.136442138302712, 15.146257915804464, 37.09462742651663, 46.31999500336186, 27.267097580817442, 1.2313703832126435, 0.09088537715856107, 0.1673332758007511, 0.3712480773608531, 0.2614587911915395, 0.30675180917305334, 1.1248552342576366, 0.8889580085392922, 1.3891092351367398, 1.4437105891204651, 1.2903916355102294, 25.289375782012943, 61.54205468393142, 75.18085356681578, 68.92986636007987, 73.5425344590218, 66.13645630498087, 63.31631137478737, 69.11963062901651, 72.56522886214718, 74.40677381330921, 72.28670920095136, 74.38177262583088, 62.92510594091108, 54.34367779762515, 60.299118334247225, 71.54125490496236, 70.80506524732037, 65.42850379020938, 62.45466078481367, 71.93837135068833, 60.68951183749784, 52.31095260189426, 46.53296009186776, 58.973102261943204, 65.96551156813099, 67.6356803217242, 65.65589927857923, 66.30034862026092, 54.76843126358525, 50.42864637990152, 52.73580412710867, 52.52964435085174, 51.64957431054885, 55.539592773683616, 52.295192518541896, 57.20874171103201, 53.94955412034066, 57.8272641858747, 54.472668863111934, 63.410483560254505, 58.80005513468097, 73.47476374718451, 44.53381822955224, 43.9026225766828, 74.98411532371276, 57.99205472392421, 61.04643183369791, 48.818423209651826, 50.70443999382758, 46.278233528137214, 48.48495114234186, 47.55749494798722, 47.39406155001733, 47.82023099160964, 56.229843631867446, 58.64160706920009, 61.10862885752032, 54.48005076377623, 50.50830971810126, 47.331589960282855, 48.96078563505604, 47.726184321988015, 49.5947269470461, 48.375018873522365, 57.65844145128804, 65.01065761812272, 66.0947536653088, 64.96055718391173, 65.21218115283598, 69.32547661565965, 70.21546240775817, 67.9783542694584, 62.667229713932166, 54.95035079217727, 58.121449793538744, 62.205966826408144, 70.12280817954772, 70.72269547370173, 71.72011498481997, 82.7848780539728, 58.54612088972523, 9.03963158207555, 0.4442918336679859, 1.9092665107980853, 1.0612705494126966, 0.7024660382059313, 0.3428590652202407, 0.11941098277607273, 0.438140883080421, 0.07592033985401354, 0.12237801832417328, 0.04323726700198266, 0.31485934831923057, 24.411896467208866, 38.58993299545781, 45.837861184150945, 38.74475286852929, 31.679701266750214, 42.65809374470865, 47.88433036496563, 57.30953093497985, 64.0704458759677, 56.163045667832904, 16.774986828527144, 0.0894115772098303, 0.07094556405659645, 0.05390181228698743, 0.017035347785079674, 0.04533488468657579, 0.04400137458897887, 0.04347696442217116, 0.041264107961568146, 0.054185421866995674, 0.023844308527787367, 0.01515015479057066, 0.011605077175303333, 0.039081940983211806, 0.06562053286019834, 0.014428044143583507, 0.06660113306415659, 0.04268471076483688, 0.02831414045255271, 0.04983491962775589, 0.04761935504634054, 0.022165988001131245, 0.02609261379186665, 0.10794545809227614, 0.05937178348821979, 0.047920186282886613, 0.013296425027111846, 0.03555490282334147, 0.03259864996277517, 0.040591034602614186, 0.02546048974768529, 0.011369707194277117, 0.021374749410296642, 0.04712766449477884, 0.022927040812529387, 0.07903666295591863, 0.012110044988202713, 0.036284593910339384, 0.012477413833802267, 0.05045135610646779, 0.013195556145341647, 0.027294205464122277, 0.04991009583576553, 0.06959013235304626, 0.06507230501982474, 0.027581147526601152, 0.0413064458107035, 0.040597707228434664, 0.030679886995424187, 0.13642450854662927, 3.7202901513345785, 81.25007813976657, 88.4787396461733, 86.02454400831654, 58.93510233971381, 57.599119524801935, 31.754289057946977, 33.15171187923801, 23.577143530691824, 28.737372544503984, 50.91755413240003, 33.2821895230201, 1.1968605124181317, 0.10557645376050666, 0.061997147652530865, 0.8825406432151796, 0.7528173202468503, 1.3071745994590944, 3.921476117064876, 2.970488153157696, 1.3172770315600981, 0.7387194025420374, 2.3795257220345163, 26.199067561857163, 66.3910573528659, 79.36389661604359, 72.84123036169237, 76.26413376100602, 68.06766663828205, 65.58905032373244, 70.66732729634931, 74.09922076809791, 77.2067028476346, 73.53583505076747, 77.70433395139634, 66.64782354908606, 57.351539519525346, 63.455147589406664, 74.09836569140035, 74.37604596537929, 65.81700278866676, 65.49093615624213, 75.21513508212182, 63.66609657964399, 56.003589553217736, 49.34919441899946, 62.02572607224988, 68.6310915793142, 72.69201555559712, 69.13528088600405, 71.13943161502962, 56.75984997903147, 52.49463719706382, 52.88859221243089, 54.361975654479004, 53.6321912273284, 56.483024781750096, 54.29257323665004, 61.85911163207024, 56.41960397843392, 60.178674113365915, 59.15687707162673, 65.37910153788906, 61.519901137198175, 77.21834444230603, 46.6649321586855, 45.97607766428302, 76.5459325236659, 62.084573391945135, 63.5747092769992, 52.34303758990381, 53.81386364659956, 49.05274560374599, 52.96896157726165, 49.132197133956424, 50.27542291149017, 49.78127879481162, 58.02653628010904, 61.08975441225114, 63.670348428910785, 57.64119871201054, 52.892275318022705, 50.17293530125772, 51.532079712037124, 49.33853341687111, 50.844876535477184, 51.366779265865205, 59.6889740420926, 66.34218462051885, 70.70563316345215, 67.33407358969411, 66.70348982657156, 71.01842649521367, 74.77465291177073, 70.80213915917182, 67.21079349517822, 57.03040722877749, 61.48654137888263, 65.34798929768225, 74.93391683024745, 73.19168629184847, 75.29711261872323, 86.12341911562028, 65.01950256286129, 12.771763859256623, 0.7305821391843981, 0.6585319989150571, 1.1032112279245931, 2.6288472596676122, 1.6673922058074706, 0.750268821514422, 0.9965472740511742, 0.5209947629801689, 0.27344126434576127, 0.047534694669828306, 0.25556233501242054, 25.210744027168523, 42.84053102616341, 38.57886014446136, 35.42556085894185, 41.59009902707992, 52.96024999310894, 58.24404347327448, 64.10550402056786, 71.2575420256584, 71.30540278650099, 22.215571172775764, 0.3345118937713485, 0.029113011194332957, 0.01894473000579784, 0.013671350372474522, 0.022260144037464936, 0.045473983270987395, 0.03793766226379141, 0.014320702776463043, 0.006647120359458871, 0.007147952255177042, 0.06830859749067215, 0.04841895931730828, 0.037889628550939025, 0.05551537731662393, 0.06554638321000723, 0.09848480082808003, 0.045745113278709115, 0.053761012987383915, 0.06976013492432333, 0.07425707870072897, 0.005169231416432248, 0.07252275523158812, 0.09798469097023049, 0.05125433116430237, 0.05478068367548047, 0.0171360787710235, 0.02130304166536418, 0.14731847801275794, 0.21064543555821144, 0.08500172230865687, 0.14562467293393228, 0.08535026167068752, 0.12867482439164193, 0.16477570658729923, 0.16603906218323017, 0.17583041662170043, 0.2413689014652083, 0.11492891642715662, 0.12778417057087346, 0.0669490595558478, 0.12932992149745265, 0.10209168067141887, 0.20201953067894907, 0.22445366477533696, 0.16299039996679754, 0.061182803849899964, 0.15880144651859038, 0.11874030344188215, 0.24463073530745125, 5.859608207979511, 97.42796451814714, 98.70661797062044, 98.62977089420443, 69.0771278258293, 63.57899250522737, 30.74716364183734, 33.94173214512487, 23.236781820174187, 55.304995813677394, 67.20840869411346, 43.61406557021603, 2.330224470746133, 0.1911070372068113, 0.30772140069353965, 1.514715295164816, 1.4258299743936909, 2.0128586359562415, 4.228488120340532, 4.898706943758072, 5.909492421534754, 6.151107972668064, 4.547003699887184, 29.188523561723773, 70.30314307059012, 82.6554790619881, 73.77782960091868, 80.51417873751733, 71.37844516384986, 68.89338831747733, 75.18935726534936, 77.59734738257625, 78.90106478045064, 77.63948932770761, 80.08634228860178, 69.14152529931837, 58.85647058486939, 66.20647061255671, 77.88298222326463, 77.02315945779124, 67.1141698283534, 67.66563938510033, 78.0041285484068, 67.70133295366841, 57.95072863178869, 52.06374129941387, 64.64077811087331, 72.10329132695352, 75.19469168878372, 71.6348191230528, 73.10897134965467, 59.50830574958556, 55.63010146540981, 57.437047189281834, 58.341788937968595, 55.9448952059592, 59.3802599753103, 57.47098353601272, 63.4918099834073, 60.741506776502064, 62.85140460537326, 61.98303107292422, 68.46758365631104, 65.8212624826739, 79.19598779370709, 50.32275807472968, 49.782388825570386, 79.48058712867, 66.82819766383018, 66.80450654798939, 55.197868039531095, 56.95065367606379, 52.842586732679806, 52.9777398417073, 51.45308709913685, 51.53674733254218, 51.62636956860943, 61.42875702150407, 63.32943562538394, 66.04121331245669, 60.20371060217581, 56.00533893031459, 51.971647970138065, 54.708144434036754, 51.71803143716628, 54.96820542120165, 53.27894256960962, 62.83761747421757, 71.5551636295934, 70.87624057646721, 69.8222997111659, 68.06763525932067, 73.36767519673994, 75.79806989239108, 74.36285895685997, 70.48283469292426, 63.442313594202844, 63.06229868242818, 68.10004188168433, 77.59242088563981, 75.57508314809492, 77.4629669804727, 89.51835601560532, 66.99959739562004, 11.65123683791007, 2.9939897694895348, 5.668395603856733, 7.010813557332562, 4.200596146045193, 1.8978345177827345, 0.6428761035203934, 1.6299545308274608, 0.6621143486230605, 0.36046450116461326, 0.29177129689243536, 0.8124641905869208, 38.50502937070785, 58.59909642127253, 61.80936813354493, 54.1633782079143, 43.95475479864305, 58.03883683296942, 66.77646944599768, 76.03767179673719, 82.44329452514648, 83.1061750842679, 26.75092543325117, 0.3038235453348006, 0.13794476406708842, 0.16467669738396523, 0.08658056057268575, 0.19668311541599615, 0.12367141222761524, 0.16379830096998524, 0.14089426386260218, 0.11101600744070546, 0.08656188334909179, 0.24834223211772982, 0.09244395239699273, 0.10140268417495875, 0.18075253153520246, 0.13617218982788826, 0.23362807328662566, 0.21592992538165665, 0.1728715858752689, 0.10324508732845707, 0.19492335016688994, 0.10930286630267098, 0.10589388229193226, 0.37528980403177203, 0.17021273983822716, 0.12617629757451435, 0.09569220350033815, 0.17905722492404524], [0.02338166611509458, 0.06685529039391587, 0.006867372552909318, 0.03583069064564282, 0.09988067431315299, 0.043929695572343566, 0.04592843811898943, 0.0473505845894256, 0.025142963540049332, 0.08787458266822562, 0.06538905173299775, 0.06545950883939382, 0.12225554384771856, 0.034234201715838526, 0.056354852633610855, 0.018465867596528223, 0.04026278890969773, 0.07475876669970251, 0.022779599530622367, 0.11772853878116417, 0.17650371597659203, 0.30823143139000864, 26.218173426966516, 82.18714806341356, 82.5821856529482, 78.56428223271524, 59.04682713170206, 26.718577646440078, 30.684578303367864, 30.316963964892974, 42.30175033692391, 67.57234188818163, 35.59694490125103, 5.511793503838201, 0.15153141001299505, 0.16819215229442044, 0.09464174373856477, 0.08853221552506571, 0.18387486076643392, 0.11851322732024616, 0.7540068402886392, 1.277469754699738, 1.0282623335238428, 2.8086330188858897, 35.887247362444484, 73.93807411193848, 73.26152801513672, 71.09237101770216, 72.51099817214474, 64.58111101581206, 67.33933741046538, 69.38730885905605, 71.46452549965151, 75.87399913418677, 69.46428929605793, 73.86073281688076, 68.69386519155195, 57.804945899594216, 51.503199300458355, 63.41135432643276, 66.32517722345167, 68.14310950617637, 64.16672437421738, 64.65028201380085, 65.34822071752241, 58.99083529749225, 49.65282509403844, 47.33858746867026, 58.3968472480774, 66.69447621991559, 62.932479996835035, 65.33736359688544, 65.84236483420095, 58.728820969981534, 53.027310755945024, 49.757928925175825, 55.21873897121799, 55.21837419079196, 55.83273503088183, 56.34925234702326, 60.20387141935287, 59.16893051516626, 62.00793812351843, 59.16305088227796, 66.06841102723153, 60.300424483514604, 75.5959266231906, 39.83082186791205, 43.120800064456084, 72.34146548855689, 57.11568740106399, 57.75632027656802, 47.48935945572392, 51.14552228681503, 48.034412014868956, 50.876922299785, 46.794413520443825, 50.04240274429322, 46.065295896222516, 49.05003916832709, 45.009515439310384, 49.29983139038087, 46.527668814505304, 47.761642548345755, 48.48387641291465, 49.171169803988555, 47.61369859018634, 50.31983198658113, 47.922149858167096, 54.25926054677656, 61.263978250565074, 65.87393206934776, 65.23207933672013, 65.1555891959898, 62.18791215650497, 71.628951257275, 70.97133451892485, 69.29710218983313, 59.61037758857974, 54.432590084691206, 54.933261025336485, 60.013938488498816, 69.32748486918788, 72.83539387487596, 67.07021574820241, 76.42782211303711, 70.22170682107249, 24.787938017998975, 0.86400781187319, 2.0430465451171322, 2.0209017011427113, 0.4984186115043779, 0.9514164828485059, 0.5866649230161022, 0.043370424574541475, 0.09285472108111267, 0.06766087015069301, 0.07518900933885768, 2.617287789621661, 34.837275935757546, 33.6977058072244, 33.31538846415858, 19.354355104507942, 20.470467498225553, 30.388455044838693, 48.025339572660386, 61.59551658938008, 62.03939945467057, 43.65581527833016, 6.643433090179197, 0.2374123331279524, 0.04568358875751015, 0.04280719673261047, 0.0332057133557335, 0.020815359668866284, 0.041013034135704084, 0.021406486517779773, 0.0715349461402624, 0.07856062358064998, 0.05546597996726633, 0.023593083399558262, 0.05643515396983393, 0.04983110450989297, 0.04353059057687079, 0.026405156597555168, 0.03437913789023315, 0.06312647999654855, 0.08469802207283436, 0.039540348844903137, 0.021572871238834435, 0.07105886846059753, 0.024144881209659002, 0.015189974125654948, 0.030892976266782612, 0.05009932721394205, 0.03280662751245884, 0.022152311416463028, 0.054228759460872224, 0.041324582942310846, 0.0891902773911434, 0.0408436750782834, 0.07130147318445867, 0.071076741291871, 0.0690447926641472, 0.029302644768669724, 0.062381513116340485, 0.02365336302788027, 0.07414477021102944, 0.026290708807327097, 0.04345069526724758, 0.037810913016719204, 0.013183468235506406, 0.05590116004309347, 0.05420232559704492, 0.08546130611531197, 0.13141204122333758, 0.05345889855356467, 0.31473996117711067, 31.595913556314287, 95.87236819728729, 88.39478523500505, 87.74556236882364, 68.20144299537905, 38.386785599493216, 35.46468257904053, 35.32194752846995, 32.53121841338373, 61.013974220521995, 43.831517850199056, 6.056686716694986, 0.12294503064045023, 0.0507057317712855, 0.2472819204652502, 0.9908921355682035, 0.6316458061337471, 1.878095312464622, 3.620479803892874, 2.5649555267826205, 0.3462503832434455, 3.7528039034335845, 39.6398102852606, 77.23532046041181, 77.15390774511522, 74.34381977204355, 75.49424309884348, 67.60048881653817, 71.02299213409424, 72.06710353974374, 75.39935311963482, 78.30508416698825, 71.68650811718356, 76.6087688938264, 70.87704073998236, 60.1158534326861, 55.77766495366251, 64.46355365937757, 71.19006156921387, 70.10209022029754, 65.58251957739553, 64.15232927568498, 70.07366872602894, 62.3285448166632, 53.77417710519607, 49.73888581798923, 60.88528909990865, 69.62056436846333, 64.71865284827449, 69.9528048115392, 68.63530420487928, 59.79787472755679, 54.668371600489465, 51.996806052423295, 58.426257179629424, 58.61908089730048, 60.630335038708104, 58.616496055356926, 63.09367764380671, 61.129499789207216, 65.98633935374599, 63.119208351258315, 68.9250026210662, 63.76634451650805, 77.01848399254584, 41.939723414759484, 47.30620045815745, 74.35062900666269, 61.09670092982631, 61.46132838341498, 51.12306279520835, 52.46662755166331, 49.28302795656266, 53.176313754050966, 49.17845364539854, 50.507709595464895, 48.418984720783854, 50.885563281274614, 47.34466714243735, 49.81807847176829, 48.74428649102488, 50.07853169595042, 50.3601029611403, 53.2694229772014, 48.666046973197695, 53.06095292491298, 51.25292854924356, 58.090090444011075, 65.149129052316, 67.25350810635474, 68.83150116089853, 66.47118353074598, 64.77745702189785, 71.49167614598429, 74.21255373185681, 69.45136116396996, 62.76151957050447, 56.96860244197231, 59.80850042835359, 62.917198442643695, 73.52012988059752, 75.67582530360069, 70.9265253620763, 77.99295763815604, 76.22698107073384, 30.271180099056615, 1.7639428184878443, 1.039905766806295, 1.689763689233411, 2.3980493603214144, 2.9001757454487587, 1.5121891661997766, 0.7038350679701375, 0.5503783411075992, 0.288050499774756, 0.03293912624940276, 2.5124126816949537, 38.22675681883289, 40.80993175506592, 33.17527747923328, 22.213107924307547, 28.4562131281822, 39.900553764835486, 55.111968132757376, 68.64136818916568, 74.68199868356028, 66.36645624714514, 11.413671624275947, 0.23820638326146912, 0.04772896307610697, 0.03584540719466825, 0.0321357068605721, 0.06018379072268164, 0.027025285620062102, 0.012669779469198998, 0.020313005173398603, 0.02350535101046966, 0.04020499906712963, 0.042646042476858825, 0.01678621407688385, 0.03334831679239869, 0.04787081957704598, 0.060815338285699974, 0.022959249064085946, 0.03911099103730052, 0.013909371975328655, 0.03854610078457383, 0.04834102902321085, 0.01909404437267973, 0.04307485253159558, 0.039739489570380225, 0.05704572987592509, 0.01809979822757023, 0.033978094692311944, 0.19465684349979126, 0.17912799612649027, 0.12336182077565502, 0.17348840922838257, 0.2318935429737453, 0.16564651873082886, 0.24627963231215555, 0.16198213632789352, 0.1922208371181642, 0.23223606088469106, 0.13660593348885738, 0.21095586970688837, 0.20595590493852095, 0.16007465400522755, 0.1452883143698977, 0.08066481429963343, 0.1870656016493036, 0.15573894875424524, 0.15090703303294797, 0.2811971691346938, 0.2727223367940995, 0.4490225798180027, 40.62407808919107, 105.81876939342868, 103.14251269063642, 99.94052502416797, 81.52852719829929, 42.69745472938784, 43.17997294087564, 43.151731875634965, 63.08401292370212, 96.95986886178294, 53.5426042925927, 9.591187430966286, 0.32860826700925827, 0.42578207689427566, 0.7749853920071357, 1.6763330034671293, 0.7191688387143997, 2.0402384957959576, 3.8930033868358986, 6.75391351023028, 5.306393686802157, 4.282824714337626, 40.93811481229721, 83.68579941411173, 80.19536064517114, 75.10969392714962, 79.00216779401227, 70.36719537550404, 73.35844978209465, 75.90815513364731, 75.14724669917938, 78.92071585501395, 74.7020733741022, 80.03634775838545, 74.36396506524856, 62.954904187110166, 57.03830295993436, 67.52735230230516, 73.30787474109282, 72.29261629043087, 64.87082904384982, 66.17728817847468, 72.03928609048167, 65.51763573000508, 56.11509469247634, 52.961414937050115, 63.2082736107611, 74.6526122862293, 65.82021913220807, 73.02412263808712, 72.45421009678995, 63.25059206255021, 58.379788860198, 55.02518569269488, 60.85848754452121, 62.6385767998234, 62.72140156838202, 61.9856119924976, 67.21885004351216, 65.17158854392268, 68.1403560023154, 66.35369285460442, 71.57931758511451, 67.44568855531755, 77.7314296845467, 43.97915194111486, 50.60801244551136, 77.82453106295678, 64.89184902560326, 62.65825925334808, 54.29970410562331, 56.02745325334611, 52.374118451149236, 55.84085041476835, 51.16014488281743, 55.274279732857984, 50.68669519116802, 53.162589380818034, 50.33209723810996, 52.479304652060236, 50.748499977973204, 51.76155797896847, 53.74739516165949, 56.3601565361023, 51.27085770330122, 56.58810900103662, 53.492566616304465, 60.801464126956084, 69.2071936207433, 70.90094366381246, 71.12163189918765, 67.78185136856573, 65.2561273882466, 75.76975037974697, 78.80382922387894, 72.96832300001576, 65.74909087150328, 58.2873111386453, 60.86889751495854, 64.37021693875714, 74.44577786230272, 79.05255456124583, 74.84614203053137, 80.55821126507175, 80.6610950346916, 29.885699364446825, 2.303458461838384, 9.205895950717311, 8.799084386517926, 4.367545948874566, 4.436323238957313, 1.6699766800288232, 0.8311552037635158, 0.4166051709363538, 0.4615995678449831, 0.16501463408912384, 4.721968375867413, 53.99046444123792, 49.92697131249213, 47.925499562294256, 27.30784904572272, 31.605897949587916, 45.48216888981481, 66.67925742364699, 79.54106223198676, 85.30587950060445, 75.40748027063186, 12.384668088728382, 0.44080876895496923, 0.1526855214709236, 0.15611617044816095, 0.1582865281811645, 0.18153211792870877, 0.09876377174570676, 0.15188152751614972, 0.19981433126714923, 0.12228477010202986, 0.17159122312741895, 0.11469005787324522, 0.14961432094775862, 0.205689137801528, 0.15399908646941185, 0.17650104999061555, 0.08351032532030538, 0.1390231247510641, 0.18104707702032982, 0.14691850350749108, 0.11591618925693536, 0.11550900586430105, 0.11525556865719058, 0.10132598345197978, 0.0767639558762312, 0.07510922128154386, 0.21667456284405726], [0.01614283045543538, 0.03652219224961535, 0.0322222211698611, 0.023071117053229003, 0.05021238263936774, 0.031232512180483153, 0.06501765996818581, 0.10991703133068739, 0.08378970992541121, 0.018602191027434125, 0.006770150249658694, 0.0632933262855776, 0.06945612059245188, 0.13273449284174751, 0.01899783139026934, 0.06868041060384243, 0.03237260039895773, 0.002575173913951843, 0.02078530987003638, 0.04704730187152182, 0.02275527432380665, 0.590943125707488, 63.25569114377422, 81.03303770865165, 78.61827758050735, 71.73636928681405, 45.33881018238683, 28.640464505841656, 30.725165028725904, 51.13532020199684, 49.99405168717908, 38.102586346287886, 17.62937318894171, 0.08061946955539527, 0.02181119161597904, 0.04606030483339583, 0.25337041956522777, 0.24953732927960737, 0.2541317117791022, 1.2976814830495467, 4.226860336719021, 1.87595529181342, 3.6255006828615746, 36.82159516119188, 67.87718849797403, 71.1792044485769, 76.12251266356438, 69.50966327421128, 67.20691034870764, 69.14169788360596, 70.63684263537007, 72.78688200058477, 77.31350898742676, 66.26351756434288, 72.67493755586686, 71.84666633605957, 61.34978794282483, 51.95632326987482, 55.39909739648142, 62.843814819089836, 69.06669432117094, 68.52022970876386, 63.30773315122051, 64.20118631855135, 69.0334326221097, 57.58737987087619, 49.986665864144605, 46.67971164949479, 58.41627474754088, 65.56013068845196, 66.98934431998961, 64.394547400936, 68.05524056957614, 60.12261559886318, 58.47150564193726, 53.4317502667827, 61.45038104826405, 56.914269770345385, 60.52310136056716, 61.93769239610242, 67.27648535082417, 61.548730557964696, 66.2644353989632, 62.225233508694565, 69.12010131343719, 64.14774794732371, 71.42955364719515, 37.795676569784845, 41.21681882489113, 71.50154482933783, 52.89351478699715, 55.76327769987045, 47.744011494421194, 50.68296893950432, 48.247832098314845, 55.12675546830701, 51.697023222523356, 53.08365560347035, 49.24930734019126, 47.14464979787027, 45.00622457073581, 46.58903821822136, 47.108595371246345, 48.546344080278956, 46.07273271006923, 49.57072204159152, 47.76575319228634, 49.067681989362164, 48.126356294078214, 50.21885056649485, 53.78215912849673, 63.39473132164248, 63.86066575204173, 70.29160345754316, 60.49284419705791, 65.65576984036353, 66.52353932780605, 68.47374177748158, 64.34445088909519, 56.66052772152809, 54.10839834520894, 58.19941866782404, 60.27026537925967, 69.45317329898958, 72.6321444972869, 71.943235089702, 70.01247190660047, 66.75138981111589, 22.950744936543128, 0.6809832780591903, 1.6526100183686905, 1.9287615485729712, 1.5110609944789641, 0.2899693355204598, 0.6248331394407057, 0.5188635676618546, 0.16435639602282356, 0.14511193028621136, 0.030857040997474428, 11.22479675277587, 38.36085873265421, 48.07835432790941, 33.563956906718595, 19.735197636388964, 25.795281125653176, 43.845050027293546, 54.81783351590557, 61.14323592955067, 60.3072258733934, 47.93552906282487, 3.731837118825605, 0.1064850340387033, 0.10756690340537219, 0.13348144388967945, 0.03729135218647219, 0.034943541677127925, 0.025237858851229953, 0.0544666450831198, 0.03517464359080599, 0.03225047832294818, 0.10883634940030114, 0.046604211937876484, 0.049864716617570776, 0.06825807399206585, 0.08193944670980977, 0.047074701006133715, 0.021561014112986384, 0.022726381317742413, 0.09752131502835021, 0.028195044423844066, 0.07313130483511956, 0.03132414012666672, 0.0307901002346508, 0.051265558182832696, 0.024111945174574375, 0.036927835805521864, 0.12156499219277214, 0.03923764452338219, 0.06562085461712654, 0.01755589303830939, 0.0463457070591469, 0.025046315802741918, 0.05445850922936394, 0.019016142806879455, 0.07688038591896335, 0.05911640807866089, 0.0372800255765117, 0.04674334499624468, 0.04209211877276821, 0.07226133538830666, 0.062247915043225216, 0.07790168071345938, 0.024601632406214075, 0.06822668736980808, 0.0182013240297355, 0.014812640391380317, 0.01157458687591697, 1.2519564527657725, 76.7476757111088, 92.6731183451991, 89.17071634723295, 79.06287823953937, 58.441158263914055, 39.155589765118016, 37.67509898831768, 34.54501228947794, 50.21483798180857, 49.9065867547066, 20.813592518529585, 0.07579793432547201, 0.08083918357207891, 0.23179261855060057, 0.7085909418040707, 0.7373286158807817, 1.2194827823869645, 3.5641886438092882, 2.4965481652367503, 0.8502328155502197, 4.8190808680749715, 39.33874091794414, 72.6932942482733, 74.37333168522005, 77.81994973459553, 73.00855867324337, 69.31342709449031, 73.04682531664449, 73.78211282914685, 75.06461020438903, 78.35729875872212, 66.67385239754954, 72.95698735021776, 73.38191340046545, 63.77984139227099, 53.80914895765243, 57.65972406633439, 66.02404117584229, 70.60581668730705, 70.58764042392855, 63.63331733211395, 67.11106331117692, 72.18652402201008, 62.18707669165827, 51.08030111558976, 48.38204776087115, 62.58931575282928, 68.17868540363928, 68.47738173700148, 64.74822359700357, 70.6452129733178, 62.40693338455693, 61.31596926719912, 57.29517506014917, 64.17611845078008, 60.749798667046335, 63.70890532770465, 63.897390903965125, 69.64280420734038, 65.20898834351571, 68.99045128976145, 66.58950574936406, 72.14519792987456, 67.25783055828464, 73.03173203622141, 40.21145651417394, 44.40890642904466, 75.20540760409448, 58.38260904435189, 58.08339495812693, 49.45049355106969, 53.36170458024549, 52.64001984750071, 59.07165573489282, 54.45082126125213, 57.12455980239376, 50.93543229564544, 49.03775038257722, 46.82975407569639, 49.03137260867704, 49.55124355131581, 50.91090571495795, 49.03470662332351, 52.62407541275025, 49.482198069172526, 49.23457491782404, 50.68993506893035, 50.99118094290457, 55.71123177005399, 67.12625857322448, 66.15495420271351, 71.8188645762782, 63.46428278953799, 69.88453203631987, 72.13359555890484, 71.87329138478925, 66.75688112935713, 58.75642268888412, 56.120095714446045, 61.50541974652199, 62.240224807493156, 72.28553248989967, 77.75332435484856, 76.33290075486707, 71.83104745803341, 72.92745190282022, 28.65793082021898, 1.3040557023017638, 0.44353031162773415, 0.9159683688513695, 1.7478753193732233, 1.9350158903867969, 1.873282686837258, 0.6633145938957892, 0.5967427790164948, 0.19518748196142335, 0.08005036581908503, 12.269134675302814, 40.64867135017149, 44.35913939629832, 34.3001740209518, 25.497477131505168, 34.37571887047061, 50.907987471549745, 61.731305122375495, 68.97742902078937, 70.73368595492455, 71.71878137896138, 7.934441028102753, 0.17800952307879928, 0.09342618436822969, 0.09948454556926604, 0.06692210092179238, 0.04640848796454169, 0.01604793131381514, 0.11108540734576602, 0.08742186300937207, 0.018756630522529447, 0.07063027291047959, 0.024305146803418477, 0.019805115692678, 0.022974339080974463, 0.029206067894495306, 0.12240072517024896, 0.061135352363870035, 0.0611061912270323, 0.030163509260502555, 0.026272376323299065, 0.04891165727449041, 0.0509805619836815, 0.02021807538826139, 0.05419107942631649, 0.03273741912937934, 0.050174499591512066, 0.34759388695801463, 0.1840399067488409, 0.13728415112822287, 0.09654934097441936, 0.13317511597227666, 0.09142715453861222, 0.12081059477021619, 0.17295211703786928, 0.2355862553081205, 0.2100366867718197, 0.10095050077765219, 0.17362016102960035, 0.1890452341326783, 0.2516907411477258, 0.19202428960031082, 0.2812081395137695, 0.12680222971304772, 0.17423650940820096, 0.11715614086677952, 0.16478083937639193, 0.14553016832759305, 2.116648473085896, 90.80610152213805, 103.40327970443234, 97.99198565944549, 92.58931298409739, 63.12780618667603, 42.426411105740456, 45.583632761432284, 69.34069541192824, 71.19689433805405, 55.87337470823719, 29.077528330587572, 0.28884836502613565, 0.11905479785655776, 0.4680890067210121, 1.1406486577564672, 1.4257592491565214, 1.5320716606032465, 4.689045471529807, 11.484733204687796, 6.414575048031346, 5.248977541923523, 41.24864101409912, 76.10129264093216, 77.08222250784598, 82.2440851888349, 75.36186310552782, 72.34626646964782, 75.24296037612423, 75.87750573312083, 78.63264130007836, 77.89322745415473, 70.93221279882616, 77.73833305604997, 77.04019038907944, 67.02695984994212, 57.33932133643859, 61.2172745889233, 68.35946744488132, 74.08157010232249, 73.90787186161165, 63.84590979545348, 68.89538088152486, 75.94431154189571, 65.40356928302397, 53.395193776776715, 50.69619909409554, 64.87434348752423, 72.86883600296514, 70.23760026501071, 65.9793104663972, 72.20519450403029, 65.76191309959658, 64.5301398154228, 59.65333930907711, 68.41695370212679, 64.62195857878655, 66.04213899181735, 67.33474823736375, 73.33774751232517, 68.25343008964293, 72.44314116816368, 68.6102088805168, 75.16712527121268, 71.51870127647155, 72.10974754825716, 44.02831885122484, 49.35139486866613, 76.8532580714072, 59.04599558922553, 60.28095383797923, 52.79100756491385, 55.60740663159279, 54.98748779296876, 59.228899632730794, 57.11447146631057, 57.58700332333965, 52.67834532645441, 51.81678102862451, 49.88655128786641, 51.08233682570919, 53.156274364840606, 53.58885688166465, 52.21392493094168, 53.97734411301152, 53.65658052505986, 52.985376696432795, 54.756668075438476, 53.55723865570561, 59.17350007641701, 70.67621538715979, 68.86969720163654, 75.33545770952779, 62.74319033468924, 68.27554441267445, 74.1167772969892, 74.47596442314887, 70.82161764944755, 62.60753908464986, 60.78341730179326, 63.947844351491625, 65.88515004804059, 76.71341773002379, 79.35360431671143, 78.16753448978548, 72.89310762959143, 77.38043246730682, 29.144383168989613, 1.865257885186903, 6.307171727380445, 8.486524435781664, 5.290303634059045, 2.3613538713224473, 1.5587714795143375, 2.2189090761446186, 0.8079288275011125, 0.4483479015048473, 0.14945972440463884, 18.249192007126346, 55.54333079245783, 65.3646436814339, 48.27030727940221, 28.725972175598148, 38.86675427036901, 59.73637980799521, 72.01610488276329, 79.36656382776077, 83.19827233591388, 77.4274616856729, 6.727327685202322, 0.2275218162685633, 0.19278043370333411, 0.2073796640240377, 0.21262909766406785, 0.24773417281046992, 0.09622117955117457, 0.2408642487059678, 0.15993707993578526, 0.1288474546444993, 0.20199694640694127, 0.20546985279408195, 0.12282383553082905, 0.270333644002676, 0.124720937362121, 0.14530127657757652, 0.11880795666647535, 0.08158117803114076, 0.18002145382906162, 0.13748774665497965, 0.2006792292119034, 0.2355050040228713, 0.08451797608886996, 0.13631416124201592, 0.14383165946891233, 0.16027993492541776], [0.05351008471822547, 0.008813673029503515, 0.028832582794430277, 0.061028498420191396, 0.06633511669332944, 0.06867142439249062, 0.0060588500608930425, 0.055020886713698994, 0.04543027029402795, 0.0070305555052454435, 0.011353074467831082, 0.032247471427845384, 0.043299691676492655, 0.01987370545975864, 0.025594601099709832, 0.07859026352244039, 0.11414256547727894, 0.07936477841388795, 0.020095807755546227, 0.051257521920507, 0.2710144203757086, 8.503230790938101, 76.88601770708638, 71.62053385088521, 74.50906922740322, 55.65443977232903, 42.972079477002545, 22.441168254421605, 32.81425468383297, 55.885392850445164, 50.020539452952725, 39.32112947587044, 3.3683420044760553, 0.11065554775057301, 0.09548430255944691, 0.2732962285799365, 0.12061543387150574, 0.701008816399882, 0.9159452636395732, 2.4965829762720295, 3.1555526871835036, 3.4181139401851164, 25.008130073547367, 55.43516359021587, 69.10673387588994, 71.85404823672387, 73.79438200304585, 69.82384512501379, 74.59326682552215, 69.8743809423139, 71.77753848414268, 70.11475163121378, 66.525359307566, 68.58069696734029, 72.25449869709631, 61.09536340159755, 56.07057186865038, 47.927766692253854, 59.73522270879438, 62.35179270467451, 68.27310469842726, 67.50466531322849, 64.44294160412204, 66.16770975051388, 66.55953099650722, 55.62380998365341, 48.89148912122173, 45.76719968549667, 55.493242125357355, 63.45013087795627, 66.74363136291504, 60.943179361281864, 65.34227048197101, 61.61564227073424, 60.60381589397308, 58.400726472177816, 61.90746268918438, 59.64395699962493, 64.60610043617987, 61.28076207253241, 64.85427271935248, 62.80927834972259, 68.05698210193266, 63.71418091558642, 69.58607888990834, 53.90694541315879, 69.32817520633822, 36.147606449742476, 41.24661314872004, 69.64587934555547, 57.637715647297526, 57.44118528981363, 49.118080523706254, 48.48038942583146, 50.79532523309031, 59.60415278711627, 57.594730392579116, 61.35347889315698, 60.678752776115175, 53.0927437351596, 45.988084039380475, 44.73797759702129, 45.07123001160161, 50.35455280734647, 52.97246425382553, 55.106190481493556, 50.87396483267508, 46.87461814572735, 46.56631200544296, 48.910347877010224, 50.92301014930972, 56.703862067191835, 60.49260101010723, 63.1477318271514, 68.2206626092234, 62.010872056407315, 69.75393279906243, 66.90604102226996, 64.09919684933078, 59.4023625312313, 54.2005701218882, 52.600058740185155, 59.464390893136304, 63.759990276828894, 67.79004912222585, 70.86828600975775, 76.01704797437115, 71.17259133246638, 65.9249621052896, 25.110039134179395, 0.23444833894891126, 1.8666417464133234, 2.465934801486231, 1.4872731676986142, 1.1945943630510762, 0.8518002927303315, 0.5327200144529343, 0.10281005663977516, 0.05161979340858037, 0.4041246180572818, 30.81135322970729, 40.385390097095126, 45.45255499501383, 40.64605905163673, 20.78798532485962, 32.428240506879746, 40.83014765093404, 59.9986530119373, 68.21061349684193, 74.88280834690218, 35.98076843446301, 2.060219784898143, 0.07599104976942463, 0.0723019150656558, 0.036214401104277184, 0.02460596463342588, 0.05863648463761615, 0.0710956789853592, 0.03224341882272594, 0.04478403682550115, 0.05231820512562991, 0.046519145534764376, 0.05718205139161118, 0.035228622145950794, 0.023643246836840145, 0.04920840909283969, 0.03457043770580523, 0.014547805711176368, 0.02789801681384204, 0.042818278194435185, 0.020608050530896555, 0.03880177879886281, 0.036909790604465434, 0.055730705479941064, 0.05523010532581999, 0.040914928916120724, 0.04952169691903457, 0.021012142758756396, 0.04081622614795643, 0.04651644890527091, 0.016905151142348206, 0.032880045548682256, 0.022485036808516712, 0.03864280406325575, 0.050624453672958966, 0.05620095706094177, 0.021894593693075642, 0.007594598273205902, 0.014338870551587354, 0.037944308076534546, 0.0402243772611743, 0.05459851179752619, 0.14588377919168244, 0.04034790510852491, 0.12118211676997524, 0.13222361944856184, 0.25352297831446896, 13.279728447237323, 92.27149901851531, 81.62148737138318, 82.02859017156786, 68.21209615276706, 54.517489787070986, 29.103449313871323, 27.97548547867806, 42.3838298551498, 49.25204515457154, 43.5163083384114, 4.371771812438965, 0.2818071283400059, 0.12605345537585597, 0.9690970566964919, 0.7800758930463946, 1.936886615810856, 2.8199262580563946, 2.732308353147199, 3.0210656456408964, 3.4514320233175835, 27.185782924775157, 58.938028427862356, 74.18811736568328, 74.37364547483384, 76.09765268141224, 72.67384713695895, 76.72028972256568, 71.25437275055917, 75.81206490916591, 71.0346729524674, 67.3754467502717, 72.17975401109265, 73.88707545495802, 64.90766794450822, 58.48459851357245, 50.936958097642474, 62.19106966449369, 65.30572183670537, 71.87946519544049, 69.14912685271233, 63.97344173923616, 67.59159288098736, 69.0207084532707, 55.97825104190458, 50.98588182080177, 48.689098742700395, 57.43558806757773, 67.03432606112573, 68.98276344422372, 62.66608045947168, 69.99249919768303, 64.58682983152329, 62.944243184981815, 61.00654525141562, 64.23538546408376, 63.15522355418052, 66.56345336667954, 65.04449982796946, 68.814713416561, 65.77679457203035, 70.3260418676561, 64.9946935715214, 69.41444381590813, 55.22093157614432, 68.5399200070289, 37.474807077838534, 44.537744522094734, 72.59424655668198, 60.437821188280665, 58.832987354647734, 49.406982698748195, 51.69304201679846, 53.67006171134211, 61.401237672375096, 61.38410868183259, 63.62331136580437, 63.1462295593754, 56.795786734550234, 47.69575457419119, 47.13112546551613, 47.37351225268456, 52.39058456113262, 57.13490309253816, 57.271578081192516, 53.6338347004306, 49.546203305644376, 49.132597215714, 50.91286690004411, 54.41539441385577, 58.33514052052652, 63.424141253194506, 66.02165637477752, 69.06159523994693, 62.06840930446502, 71.19831423605643, 70.10928384719357, 68.46979587308823, 59.58306220269973, 55.91816817560504, 55.88163914219026, 62.58750754017984, 67.48847376915717, 72.22451609949913, 71.76643817655503, 79.43285972841325, 73.31790031925325, 69.75982419906124, 28.370946684191306, 0.6865442796580253, 0.7535488422839873, 1.1002419937041499, 1.7278893724564584, 2.991675816236004, 2.14341129506788, 0.9772750759317029, 0.35392260058752956, 0.09251831655180262, 0.6285879508622232, 31.274844023489187, 41.289135563758116, 35.31607181795182, 44.46083861012613, 29.338262004237023, 46.885585092729144, 50.96634057260329, 67.1799087524414, 75.40007483574652, 83.44928833746141, 53.08194152770504, 2.098924017721607, 0.017349489799310124, 0.1277686419686483, 0.034957193363938606, 0.06802699123058589, 0.06916660064410779, 0.012594968110563294, 0.015806865469071896, 0.04194252095335434, 0.05739174114780561, 0.029958211103334065, 0.057875855089796174, 0.032260671122780735, 0.05615779183684819, 0.05197433123905813, 0.014649456002629332, 0.05063222946539041, 0.07449721662147392, 0.05359957144866067, 0.041703980325931506, 0.04299390002063686, 0.03539633411433428, 0.03062676454353477, 0.0257605031853722, 0.054168617728376584, 0.18171800150265618, 0.07938583817092643, 0.10489485767339507, 0.14503886081999348, 0.166822325798773, 0.1359259691690245, 0.14969025558281332, 0.2815656574262727, 0.19117868174949001, 0.18675849232221806, 0.12651201262469255, 0.09305882988677872, 0.23275085664804906, 0.07874725025988395, 0.0896580583385883, 0.1334873580884549, 0.30225061360866795, 0.18584035126672638, 0.16717261184127102, 0.3083963854418647, 0.44369940255438134, 19.158156187303607, 108.42813399530228, 91.19403962166079, 94.98706571517452, 73.18638324737549, 58.73854060326853, 31.775593411537912, 44.6829035974318, 76.15425248299876, 68.10539983933973, 59.02779186925581, 5.610672043215844, 0.3640074126662747, 0.3920570172129139, 1.7016771531874135, 1.7051005243293702, 3.5658024539870605, 5.035294169379819, 8.774004751636136, 11.224388826277949, 5.160853651262099, 31.55889814899814, 63.27769564044092, 75.11055684858754, 76.88265231347854, 81.21043866680515, 74.61518503004505, 80.29839346485754, 73.5907482331799, 77.93890737718152, 72.74662279313611, 70.22203630016696, 73.70200234074747, 77.06366185219058, 68.464077057377, 61.00979689628848, 53.348835283710116, 66.17367959791615, 68.98398722371748, 74.24767463437973, 71.28623024109872, 64.26908646860431, 70.75061490458828, 72.89131902879285, 59.09098125273182, 53.72722241186327, 51.96825904230918, 60.433130033554576, 70.58708344736408, 70.67467781805223, 62.798715406848544, 71.53319051188808, 67.28001548397926, 65.50326416569372, 63.31768812671785, 66.74738899354013, 65.14986253553822, 69.79191703181114, 67.53088243546026, 72.07132401004915, 69.68216911438974, 72.11025745637956, 66.31357485248198, 70.98561194635207, 56.255574380197835, 67.75129610492338, 40.348935588713616, 48.76868755586686, 74.58708517013058, 63.485039972489886, 61.71661976845034, 54.57548203006868, 53.94907166880947, 58.071439573841715, 64.64675580301594, 63.07570142130699, 65.75180907403269, 66.18583894545033, 59.896757679600874, 51.3564791217927, 49.86043222488896, 50.28482875516338, 55.22050011542536, 58.89359189618019, 60.55503729851016, 56.5038525673651, 52.84607371976299, 51.90171603233584, 53.62138901987384, 57.72895782224594, 62.17251293120846, 66.60414403484714, 70.61344961966239, 71.9037054431054, 62.442897596666896, 73.57629822146508, 71.69397630999165, 70.26435082958591, 63.5988671548905, 59.567133457429954, 58.16387414932252, 64.4983882288779, 70.55626930729036, 74.26986740481469, 75.1609593053018, 82.17068979817053, 75.59540887032786, 72.76687791270595, 29.039793168344808, 1.7625051472456226, 7.2205725985188645, 10.341270123758624, 4.725041062601151, 4.3386508284076575, 2.8998190549112137, 1.8656996421275602, 0.5956076818608469, 0.28179974325241586, 1.2447023968542776, 45.879065682811124, 59.366904304873565, 58.456153485082815, 51.26758644657751, 29.907915669102824, 48.30592632293702, 53.67378404063564, 77.57960257991668, 82.91647357325401, 97.29472944813391, 57.695500004676084, 2.5554158322272764, 0.19093993810876725, 0.4421173697037082, 0.1804594875824067, 0.1516640045109295, 0.11470459822204807, 0.19952522500628428, 0.20303710994701232, 0.18308552973453077, 0.19767616454872394, 0.16275859708266874, 0.11079259321934755, 0.14210926398875254, 0.18980007588623032, 0.21980528839893881, 0.0836817145107254, 0.111454087159326, 0.15527664533545896, 0.1273180290515865, 0.09816236208162962, 0.07382888151633163, 0.1427211843791508, 0.0770157153507875, 0.11461151853924799, 0.12511006406238004], [0.06465141631422505, 0.004800130733318868, 0.07726588136246128, 0.04551259410237113, 0.04914750127241977, 0.03875626551528131, 0.022002928101667957, 0.06469987137543579, 0.0538741028867662, 0.04650172852580586, 0.016588239720271482, 0.09746097794343388, 0.07056533163713832, 0.049431516879027894, 0.03327404839857932, 0.03807253970374023, 0.026677701952716997, 0.06102347671384774, 0.037640136696638606, 0.03579899758821534, 0.08358065985263356, 37.32927537733509, 86.73827417435186, 72.96450261146792, 59.654896490035526, 36.81861023749075, 30.753606134845366, 31.663362633797433, 55.69483626273371, 43.97990895855812, 61.387242655600275, 17.57825097730083, 0.05464892804382309, 0.09049607425807946, 0.04073479100160542, 0.3524259712186552, 0.7202690022607005, 0.3884929003975084, 1.5770630850907297, 2.3589688251095438, 1.6153831707854427, 15.495860730448078, 53.69749476832729, 69.91632676893666, 75.36834286105248, 69.80766142568281, 75.25722995881112, 71.71875784474035, 69.39189803215766, 69.34551208249985, 71.0991096496582, 65.17018433540099, 64.33547650614094, 69.32171898503458, 68.33180689042615, 54.88832243027226, 49.38824945880521, 53.486788965040645, 64.41922695406022, 65.73685307656565, 69.27281487372615, 60.79024614826326, 65.56254686847811, 64.45678757083031, 63.04316143835745, 51.14793846684118, 46.13820099061536, 45.068115649684785, 51.94711354471023, 63.27503235109391, 65.14736398573845, 62.292659051956676, 63.251156883855025, 65.20273608546104, 66.66492508303735, 64.93444204330444, 64.77374253734466, 65.45991020817911, 65.31567681220271, 63.297617358546105, 68.19038191149312, 65.34940135094428, 66.41289710998535, 64.0125124685226, 59.20058012008668, 50.890642750647764, 64.5605460289986, 31.87032061238443, 38.992411321209325, 73.13079541729343, 54.94476533705189, 57.905872406498084, 48.15803335558984, 50.60934212899978, 48.542994376151796, 54.34372878843739, 58.67394701127083, 66.95681218178042, 63.281198317004794, 65.18011185430711, 54.91372369950818, 51.67989815435102, 49.758948741420625, 57.9718937412385, 62.27243923371839, 64.80023422548848, 59.40143292950046, 49.18030500411988, 45.455877242549775, 48.15873153748051, 46.54882607921478, 50.25769772068147, 56.31238598977366, 61.53819899405203, 65.46017300698065, 59.946799278259284, 63.859257621149865, 69.92457159103887, 64.60388821940269, 63.774538347798014, 55.702704537299375, 53.50417683201452, 55.09836143062961, 63.29263594842727, 66.05305102563673, 71.84468161675238, 65.42321251284692, 73.9594667188583, 68.97576593583631, 64.60774390928208, 19.343811773484756, 0.17313803125533367, 0.10443964822878761, 2.0529641355237653, 3.008349321542248, 0.39162086803586255, 0.5347514344799904, 0.07862399437374647, 0.09746154484849784, 0.10010205840151157, 5.073786349065843, 40.31899613718833, 43.27665544325306, 43.920057512098744, 25.089574167805335, 15.879770555803853, 29.662944039990826, 53.08878214128556, 57.647702001756244, 62.140733888072354, 66.68214428809382, 17.94606927902468, 0.6291219447889637, 0.17674918586929, 0.035656237103525674, 0.06705242013859172, 0.030463683576653564, 0.09046189907577731, 0.0706236002846591, 0.09198042323752757, 0.021042665616879543, 0.024626020815283544, 0.041841857000103885, 0.010983108584168217, 0.04452146401989364, 0.03858098076776632, 0.022848334854408618, 0.0836731956130074, 0.0432577483626383, 0.04536637473070333, 0.04009965431666182, 0.05166587359722584, 0.021025442045121905, 0.032760819285026485, 0.021975825826126724, 0.022920998294026624, 0.037736682927296046, 0.033140618864807396, 0.04123239192150293, 0.07256708107888699, 0.09938432594701167, 0.06403211849711596, 0.08768577263840745, 0.031011501559987668, 0.01846339887819223, 0.022476106138539412, 0.048780277025915926, 0.03732037925792318, 0.006418687304587014, 0.06779010152263988, 0.021628498798236254, 0.07752318731358937, 0.05484995334559391, 0.030623112219355764, 0.048993356721175295, 0.021832241796918457, 0.03838872334228889, 47.69586047818584, 96.85136825807633, 80.21012444649973, 69.96095549675726, 46.85329221910047, 49.0847639114626, 35.26058204712407, 43.0730216733871, 44.61885129251788, 59.12744360585367, 19.490012238102576, 0.02771926168803006, 0.055803652372091055, 0.41187019598099495, 1.374873850614794, 1.7330296385672785, 1.9084973585221077, 3.3254231849024376, 1.696200666408385, 1.9526615306254358, 18.435398686316706, 56.204156029608946, 74.54036189663795, 78.05808467249717, 73.21028617120558, 76.94320586419876, 75.16527391249134, 72.21065444331016, 71.6066094367735, 73.63731461186563, 68.3971300432759, 65.74756114713608, 71.32557161392705, 70.02023819954165, 58.501900088402536, 51.92989041728359, 56.34944846553188, 67.27235117266255, 67.01167045101043, 72.23538890961679, 62.33085901506486, 66.31597534302743, 68.0085329855642, 65.82054861130254, 54.10735891711328, 47.573788473683024, 47.80855801797683, 54.41810869401502, 67.21699868479084, 68.91798157845774, 62.69152095240932, 66.10706206290953, 67.43873027063185, 69.82180549252418, 67.40211102270311, 67.58872955076157, 68.55495837426955, 67.77708176643618, 65.95916517319219, 69.63789339988463, 67.15323663526966, 66.87539162174349, 62.341602386966834, 59.76208702210457, 51.22174962874382, 65.78017565511888, 36.24826623547462, 40.64303882660405, 74.72022610325968, 58.28306321174868, 61.16103564539264, 49.51791517196163, 50.71719946399812, 48.75059758463214, 57.89992217094668, 61.93837096614223, 67.82323237388366, 65.93730972659203, 67.0267637314335, 56.381082380971606, 52.82816025518602, 53.538352443325905, 60.76505276464648, 64.17381209711876, 67.01936614128851, 61.90596434377856, 50.80927710379324, 46.71973159236293, 48.93480777740479, 48.1286116569273, 51.688499912138916, 60.028874874115, 65.01850235846736, 68.90619093371977, 59.61560218564926, 66.0735022637152, 71.59074737179664, 68.0269681253741, 64.804411549722, 57.10108441691245, 55.68970580254832, 57.75139377963159, 65.05474113648938, 67.1945470379245, 74.11247053454, 68.43817372475901, 75.25667298224666, 72.49689332900509, 68.73730936358052, 23.997278405774026, 0.7511103537774856, 0.203398397012103, 1.5139995851824362, 2.12773603297049, 1.8087669293726645, 1.4185168377814756, 0.8652678120040125, 0.1091186911047947, 0.2318444367377989, 4.825305179242165, 41.09801023237167, 35.429596977849165, 37.38006222632624, 28.857857950272102, 26.162532644887126, 42.369148423594815, 58.23846978525962, 64.70687397064702, 69.16858180876702, 81.26292782445108, 29.40103953884494, 0.9203058361045776, 0.097690298702688, 0.07917432895591182, 0.046900630507978706, 0.026917652181920507, 0.016654368429895372, 0.11120801971804713, 0.04413880693215517, 0.052842324179026394, 0.013993965319147515, 0.017464046757067406, 0.056810479596137047, 0.03889922135239167, 0.043333778758683515, 0.039684319748513164, 0.02694699143420064, 0.015745392658807818, 0.026091485727398146, 0.04134886409907092, 0.02696316546550201, 0.06655861518435902, 0.05885288149358765, 0.0775257154037395, 0.05720295793106479, 0.1462256995540473, 0.14890965795324695, 0.15102591455703782, 0.22633022778937895, 0.1721568871289492, 0.12565508965523015, 0.17119443554791713, 0.2140117637933262, 0.1298173985654308, 0.13634465154140227, 0.13279245505409856, 0.13085598396437784, 0.14093506570544936, 0.2282103607731481, 0.1291387672385862, 0.09447487446689799, 0.12373858281681616, 0.09837747957076758, 0.07391264556997246, 0.1334833284659732, 0.14759494382287228, 58.203780343455655, 110.76557636260988, 93.02590416323756, 79.46709417527723, 55.70977264834989, 45.55176350378221, 44.104412832567775, 77.88082491966986, 58.64016755934685, 84.1859173005627, 27.572377612513883, 0.3105283162045864, 0.26381111012831815, 0.5310398304174023, 2.4004915260499526, 2.263714065474849, 3.7959950825860425, 7.095526947129158, 9.12187485925613, 5.805750143143439, 21.05957808033113, 62.491197662968794, 75.37067274893485, 82.30678819840955, 76.0825123325471, 80.16732354317942, 78.64738156718593, 74.51365055576449, 74.13650681895595, 76.5461443316552, 71.1480765188894, 69.3135133866341, 73.59601205395114, 73.86347847600138, 61.61923516181208, 54.468287575629454, 60.76770428688296, 71.81454996908866, 70.62529517758277, 75.15082390077653, 61.61306527353103, 67.31506578383907, 70.9472119423651, 68.33983205979871, 59.34945367997693, 50.77524662017823, 50.07943384109005, 57.88629193459788, 71.2166238600208, 70.65887851099815, 63.26918409716699, 66.82837024811776, 71.19040673778903, 71.76241382475823, 69.80380181343325, 68.42366879986179, 71.71001880399643, 71.36656038222775, 68.21623817566903, 71.07171581637475, 69.50384247687556, 68.98118665141445, 67.11359716230824, 62.5177481866652, 53.41391524960918, 67.44578269220167, 39.472199563057195, 46.52688041810067, 76.79821937314927, 60.271951998433764, 61.05335089468188, 53.72625750880088, 54.73786423283239, 52.77981312044206, 60.23282635596491, 63.98792312991235, 71.28694411247008, 68.99211437471452, 69.79311727708387, 60.40285718056464, 57.619531539178666, 56.358010999618045, 63.28517560035952, 70.64091405560895, 70.60260034376576, 65.87987838252899, 54.26259063905286, 50.19391213693927, 52.87495413134175, 51.52496845491471, 53.36630552045761, 63.97036267865089, 68.62172495934271, 70.30206049642256, 60.278208178858605, 67.09677803900935, 74.63196492964222, 72.08596229553223, 67.58551320722027, 60.923391003762525, 58.58010430489817, 62.76845432096913, 68.48639534365746, 72.00221184761294, 77.0885532133041, 71.1477784187563, 77.07722540824645, 76.24904048058295, 71.89833179596933, 23.02569162461066, 1.7351368093682875, 4.000461620669212, 9.480803108984425, 9.749154025508512, 2.8407714491890323, 2.1392690270177783, 1.929499567035706, 0.4261693496617579, 0.2874312555838016, 8.233726697583354, 60.161364693795484, 63.78499538667741, 55.651803939573234, 34.73174064390121, 24.711649879332512, 42.63825831874725, 68.63911674868676, 76.39170492849043, 77.82740223792293, 93.61626009787284, 30.11747417911407, 0.9245394831222873, 0.26680375599572737, 0.2101891382687515, 0.226044308454279, 0.1473122420570543, 0.11826639379104299, 0.26935397076510614, 0.2674006304192928, 0.13404962065960133, 0.14798837593726574, 0.2967274261097754, 0.1627196798161153, 0.1336094878253437, 0.1153970880794429, 0.19040470311958946, 0.1475320939695643, 0.10082214274593901, 0.2386449532763612, 0.12657723735056578, 0.1241999286256971, 0.10558638992088457, 0.17167308728300756, 0.14509860035632888, 0.17091991560113046], [0.06756017555392559, 0.023191877407953147, 0.06383948185811601, 0.034641388938912464, 0.010380353478174056, 0.042103008712611856, 0.07780066435976375, 0.031033239304839127, 0.006852250934893927, 0.016448047545347965, 0.045107678329992684, 0.050706421250417355, 0.05214552890749709, 0.018358230327947006, 0.03568094343908372, 0.014427836342234046, 0.02216914428337928, 0.05355773538711572, 0.03571178996935487, 0.1252571606047211, 3.184453936353807, 66.98888932504963, 73.62966599002962, 70.9835095559397, 51.968596366144, 39.647254943847656, 21.671960084669053, 40.24296883613833, 41.24662099346038, 36.13794565200806, 45.92058004871492, 3.579623660733623, 0.10105152479222707, 0.1270891219798115, 0.25673377537919634, 0.5333045701826773, 1.3770551787268732, 1.4436539599011022, 2.3510184259183946, 0.8278461942268956, 9.839101818300064, 53.7899842569905, 77.35345440526163, 72.6243782043457, 70.3929731922765, 73.51807455862723, 72.10691559699275, 71.08636979133853, 71.77369456137382, 66.2706405885758, 71.06536942143595, 63.15513726203673, 63.60362891227969, 70.80919942548199, 57.91118721808157, 49.19551595564812, 49.73110383556735, 60.73310505959296, 63.81178517495433, 67.98865441353091, 65.38319649234896, 63.04997851771694, 64.98273818723618, 62.162106883141306, 58.2492837598247, 47.79223311331965, 47.89726634179392, 44.58412262701219, 50.26902160336895, 61.68456615940217, 64.27801770548668, 64.90785621827649, 62.74786972230481, 62.1726345246838, 63.307474274789136, 62.32415960681055, 66.12947448607414, 62.78502633494716, 65.33049160434355, 61.901441850969874, 64.56779456907704, 57.23402530916276, 59.972632008214156, 53.15013193315076, 57.5418411531756, 48.67943010022564, 58.64310541460591, 32.81198167031811, 33.947117559371456, 71.28151555215159, 56.06715940660047, 61.00533716140255, 51.00940427472515, 51.220674899316606, 43.96972648559078, 53.091880813721694, 58.48595565365207, 64.6180401309844, 63.7086150723119, 64.53024964178762, 60.80198972455917, 60.497637333408484, 58.7009289956862, 62.931369966076275, 64.7442384689085, 62.644499578783595, 62.708132190089074, 54.74808592950144, 42.39430258350988, 47.32290191035117, 47.02548819203531, 48.840317879953695, 55.835382630748136, 60.92308113651892, 66.02962663096767, 62.49680272994503, 62.04305510367117, 68.56792573005923, 64.09549020951795, 63.19473358892626, 53.5219177123039, 52.783186358790246, 52.25118352520851, 62.34161023170718, 61.51604544731879, 66.85730949524911, 71.25516506933397, 72.05965103641634, 69.77212475192162, 69.77631384326567, 62.16452306316745, 25.722425060887492, 0.3001037900966983, 0.8477878306181201, 2.4583911030523242, 1.3873791021685447, 0.8283246008138504, 0.6186878272602635, 0.09548985669689794, 0.04971608789938112, 0.0681869044239002, 10.98532428664546, 38.78171336266303, 42.31763593612179, 35.00681646408574, 27.315691824882265, 19.536741395150464, 41.04985529376615, 55.9533400689402, 64.29406804423179, 60.05226396745252, 64.60541402139972, 7.69405072735202, 0.19789077641983188, 0.00806823500522202, 0.024878305060067968, 0.013867033168583388, 0.016414722720641765, 0.06664878373304683, 0.10939950829431896, 0.08766930174803542, 0.03285332057144373, 0.078994742624702, 0.011287066417055265, 0.06261284485639584, 0.04212398803041827, 0.05313610740666909, 0.015109381676020642, 0.03180841686234119, 0.02886878427929215, 0.07585306967338247, 0.07050179996557775, 0.018389647593721747, 0.03339616664414925, 0.034867319759101637, 0.030394423482639175, 0.09949672636726212, 0.03732528222063857, 0.004476158853409993, 0.05736747531280403, 0.0473599270316622, 0.021324449992408196, 0.05792377388945991, 0.036919519921103795, 0.02914550098320169, 0.053746212168686816, 0.06289950729678236, 0.032481622371462085, 0.019290120746459694, 0.05411540526115606, 0.12272609037257011, 0.05779971361100193, 0.06823285437759853, 0.09332126862699948, 0.029820516375043703, 0.11527842105997187, 4.876035153865814, 78.60458850860596, 83.19459315269225, 78.5702834590789, 63.1616444741526, 44.04542822991648, 28.019947505766346, 35.84340310865833, 36.37870465555499, 36.609485149383545, 48.63540149504139, 4.329729397450724, 0.125182758145515, 0.3198486644654505, 1.4651981909428875, 1.2611142065255874, 3.0833430780518443, 1.8145945908561831, 1.0752838297236351, 0.7830724612839761, 10.24989458822435, 57.959055823664514, 79.46725891482446, 73.24703877972019, 73.52480534584292, 75.21660989330661, 73.95563064082977, 74.55400390009727, 73.43400247635381, 68.39198389360982, 72.14140892028809, 63.83468397202031, 65.94451119822841, 73.66274726006293, 60.193508517357614, 52.10335723815426, 52.4701851414096, 62.73593002750028, 65.80510623993413, 69.13911696403258, 65.13262764100106, 65.16725824725243, 67.9638885682629, 65.27275039303687, 61.21752562061433, 49.5810261080342, 50.48513243275304, 46.776688329635135, 51.769175221843106, 64.12629258248114, 65.80306660744452, 67.35610162058185, 64.43262577056885, 62.57066880503009, 63.269737151361284, 65.08431580758864, 67.12620366004207, 63.4705860384049, 68.32051046432989, 63.273212371333955, 65.17509514285673, 58.09416578662012, 61.062701825172674, 57.63481701574018, 62.321649289900265, 52.287371312418294, 61.119497745267815, 34.93366426037204, 36.89183696623772, 73.149246246584, 58.526556107305716, 64.22072756674983, 54.06236148649647, 52.540383800383545, 46.80409785239927, 55.78542340186335, 61.19647425989951, 68.14304674825361, 65.75694737895843, 67.25876408238565, 63.43233900685465, 63.99543446879234, 59.61270355409192, 66.78971136769941, 66.39490912037512, 67.25802667679326, 66.35239062770721, 57.57939784757553, 43.81402015686036, 50.63258217227075, 47.33858354630009, 51.79683185392811, 56.75198562683598, 62.27516528098815, 69.3048135695919, 62.09011177862845, 63.00367493783275, 70.72476648515271, 66.77819528887349, 67.4920823497157, 57.85086508720153, 54.39445287950578, 55.1113836996017, 64.59322721727433, 64.89264918911842, 70.11031935291906, 73.87838348265618, 73.89565760089506, 73.0979024210284, 73.92025870661583, 67.7541123667071, 29.946068563768943, 0.7409510473089834, 0.3311444164043473, 1.1911792043716678, 2.073181257132561, 2.8952038961072124, 2.101787102799262, 0.5339150503277779, 0.050955863309002696, 0.0724843435830647, 12.19681989762091, 41.28271072141586, 36.1606091068637, 30.840967124508275, 34.615987577746, 27.041837823006418, 51.57877552893854, 65.61197657738963, 72.90513361653974, 66.41023774300852, 81.1265391688193, 12.809108745667244, 0.2825971182075239, 0.06340895193598925, 0.09965095518817825, 0.026523961512852582, 0.04644103904044436, 0.026207398660781405, 0.08171085373408372, 0.03310304991300068, 0.05371362278838793, 0.06090811536376996, 0.013504974269909004, 0.023568350250922868, 0.005393926441038569, 0.06622807888854897, 0.04398350558814503, 0.01590814133505187, 0.03258459607980425, 0.047801362215391094, 0.03772143777760287, 0.005641165518036654, 0.07592456099847633, 0.04773866174922836, 0.026617575541979847, 0.20345681887720862, 0.14190009134190698, 0.126966685807753, 0.14200028032064438, 0.09178671024499402, 0.11473387044163481, 0.20637667107005275, 0.10805179875704551, 0.14911360588044892, 0.13552236340699658, 0.15267724772134136, 0.15355696180655112, 0.07216794160945762, 0.12019272187664626, 0.14834269160224547, 0.19092214954716547, 0.30162190057096944, 0.1765283686859954, 0.09902653990373497, 0.25872879090809053, 6.10093399401634, 94.4579379789291, 92.70071614173152, 92.68711336197393, 71.9075022974322, 56.578193249241004, 32.70031963625262, 56.71724519421978, 58.39283466339112, 50.183164842667125, 68.2981215753863, 5.898158242625575, 0.3272327714629712, 0.42725921698635627, 1.9096190338173222, 1.7911237406153835, 5.040706549921344, 4.755893936080318, 8.953755209522864, 5.049065611054821, 12.758993602568104, 62.473327344463726, 83.53029312626009, 77.2994904364309, 76.81910207194667, 79.05607684966057, 76.48781868719286, 77.37562364147556, 77.01998233795166, 71.3305373345652, 74.74777683135002, 67.08007658681562, 68.47906051143524, 75.4880928224133, 62.677573004076564, 55.57246223572762, 55.6590485572815, 66.52538284178704, 69.39358465133175, 74.22039847220145, 67.87179916135727, 66.3285896855016, 70.70040072164228, 67.07685239853399, 63.056011123041955, 52.4684004629812, 53.33071393351401, 48.951960302168324, 54.80662338195309, 66.97068952745008, 69.09353117788993, 69.00365398776147, 63.4215211099194, 63.441278088477354, 65.20836860902848, 67.06206506298435, 68.86275460643154, 63.995924765063876, 68.23029595036661, 65.47849832042571, 66.82203954265964, 58.71610856825306, 62.60514251647457, 60.46238699266988, 65.28666696240826, 53.764535919312515, 61.16733889425955, 39.10541088350358, 41.389916942965606, 72.54091016707882, 63.042639763124534, 65.91420696627709, 57.12001769773422, 54.7229866827688, 48.92990873705957, 60.028686600346724, 65.05808299587619, 69.25542308438209, 69.71873344913607, 69.0538917049285, 66.95408221214049, 67.37197153029904, 63.636157128118704, 68.1699542076357, 69.03806886365338, 69.58701241400935, 66.57974689237534, 61.98288594522784, 46.46848417097523, 52.85216908301077, 51.257078416885875, 52.42428556565316, 60.75119895319785, 66.92847697965561, 72.99473624075614, 62.4643058930674, 63.76116306551042, 74.34654189694312, 69.27013981726863, 69.5168569011073, 59.58243462347216, 58.61556253125591, 55.08336620946085, 67.45882065065446, 66.51450218692904, 73.44759741137105, 76.24154090881348, 78.09938723041166, 73.61134067658456, 74.95743536180066, 69.39390628568589, 29.07330393791199, 0.8786267306535476, 4.720496506460251, 10.114396310621693, 4.617438191367734, 3.8109981484951514, 3.4005549598124722, 0.6548089341771218, 0.24447374857000767, 0.2949319305198808, 18.1639902822433, 55.87231174592049, 55.13374905432425, 47.89725457468341, 40.071686775453635, 29.163559636762066, 57.17886893979965, 71.72553570039811, 82.6503486018027, 77.32535454534715, 92.10903444597798, 13.962976894071026, 0.3440276250964211, 0.15698816236709395, 0.1485942595548207, 0.182428885131113, 0.11788803062612012, 0.18099795546262495, 0.1516090913285171, 0.16448730512732462, 0.1680058856765109, 0.1823920363019551, 0.12765749793259368, 0.20788177337136962, 0.08900195765759676, 0.15777864253088353, 0.18205877273313462, 0.09764106223179449, 0.1281958892040195, 0.2674442361439428, 0.2022548882110465, 0.1366766127607515, 0.11766171293152917, 0.126933177121945, 0.16100808617568788], [0.027189305044650555, 0.004147260070538088, 0.08873853066395368, 0.0361325599313263, 0.055609828296808474, 0.040082007481326024, 0.02665255128616287, 0.08358269764651215, 0.07500887142434236, 0.0099404466398541, 0.038665296404712626, 0.030816032310887694, 0.0321669019608488, 0.04951864405865631, 0.15072338643573946, 0.037269219906339725, 0.019318285968995864, 0.12478548793062089, 0.07449874879732248, 0.272302367394009, 18.953190772764145, 82.01823511431294, 69.00728610254103, 73.98675072577693, 47.39895666799238, 35.53430464959914, 28.576202354123517, 50.84309577941895, 42.22875895038728, 59.893153021412516, 25.769687660278816, 0.09279552546720352, 0.060889798201500415, 0.7726387727645136, 1.1547007940469252, 0.48967347270058054, 1.8066554684792797, 0.8429346329742863, 1.9597621238039387, 2.1840973054209063, 49.3008747408467, 75.42841003787133, 70.27283099389845, 69.69991391704929, 72.63038727544969, 72.07723109952866, 71.94613764362951, 70.44330504632765, 68.23261014876827, 68.79436416010704, 69.8583149140881, 61.57482608672112, 65.24179504763696, 67.39471343255812, 53.53361422015775, 48.53251772542154, 57.939138027929495, 62.884450574075025, 65.94356982938706, 64.02231839395338, 61.29527484216998, 65.42198873335316, 62.21862823732438, 57.73144852730536, 49.70389043131183, 46.05371705947384, 46.07225418090821, 46.872484376353604, 49.94570455243511, 57.8387410409989, 63.00786402917678, 64.56692772526895, 59.163878502384314, 57.73092685207244, 60.19297507501418, 57.43948298115885, 62.98106639615951, 59.284644357619754, 59.50197896649761, 58.98095484702819, 61.712160033564416, 55.91736408971972, 53.70085231719479, 55.822348594665534, 63.993873365463756, 59.07951616471814, 63.759633341143214, 35.02159595489502, 29.16497757357936, 66.55123910596295, 56.934913204562285, 67.05412618575558, 58.10058278422202, 57.82897826164, 44.60852761422434, 47.44717828689083, 51.82405702529415, 64.15366288154357, 60.94181045409172, 66.10841920298915, 60.057421884229115, 62.14262839286559, 62.118035131885165, 63.60293857512936, 52.772348850004136, 55.951641682655584, 65.48460937315419, 53.75618127084548, 45.21754618613951, 46.321042276197865, 47.359599605683364, 51.336628006350615, 56.527665276681226, 61.172304614897705, 66.26564348897627, 63.582475569940385, 57.87630558013917, 67.10704680412047, 65.27790830981347, 66.91973009417134, 58.77774469314083, 51.45083958102811, 49.889387161501, 57.33870160195136, 61.177831234470496, 63.63540011067545, 65.05552168815368, 69.51440149737944, 66.50928543459985, 71.65827489668324, 67.92619459090695, 67.90152288252308, 34.69827890396118, 0.4521352563413882, 0.9932608181430448, 1.6789570691124087, 1.7199665524305838, 0.4740368827216087, 0.2136329333147695, 0.17757761802884842, 0.016662592383762522, 1.1973142816174416, 22.863652629237023, 44.908855653578236, 37.740088739702784, 24.18660140806629, 29.208572756859567, 25.154357994756392, 40.538170337677, 48.265839699775945, 62.773380817905554, 65.55390980935866, 47.053897919193396, 1.2251479106564676, 0.056320654468670975, 0.025145066451401483, 0.017351295851591616, 0.02437379402709344, 0.004050095223881786, 0.023554581735703736, 0.05676539149135352, 0.05643664018040704, 0.06770926392486981, 0.04812381628359999, 0.025221175371458935, 0.05863876374919088, 0.04180994177717836, 0.09826665729164116, 0.025203074629028, 0.021116181329313307, 0.05238115073992841, 0.020377120987001448, 0.08527385972199902, 0.07376996935495446, 0.06129715396391769, 0.011794087345591717, 0.0228477583732456, 0.03778577001104432, 0.011276409176418619, 0.0715759854703661, 0.0359427961220424, 0.018866742255106088, 0.11874504552613344, 0.02279507259147302, 0.026470408136505755, 0.026259044478196773, 0.012956842190525945, 0.03491025515681794, 0.015715597584212742, 0.06611850533273912, 0.0478910289764885, 0.05301786556599602, 0.13121789922156643, 0.04838932703639712, 0.12119957591376959, 0.2692745427691168, 23.89491827257218, 95.26834672497165, 77.96073928956064, 83.08046002541819, 53.69925591253466, 47.03871442425636, 33.27135201423399, 39.62596039618216, 37.32960093405939, 54.82947118820683, 26.93853043740796, 0.053751456040528514, 0.006598493407270121, 1.7372888422781423, 2.2278881169134572, 1.06478045784658, 3.303653295001676, 2.4150513641295897, 1.160172500437306, 3.092751373206416, 51.98695305855044, 77.9108859646705, 72.47896025257727, 72.57526228504797, 74.03160695106753, 74.24110074197093, 73.97635644482028, 72.43987775618031, 68.71193947330599, 70.92326195009294, 72.38287787283622, 65.89327719903761, 67.9079241906443, 70.99907352078345, 56.51518821716309, 51.135135850598736, 60.74176173056326, 66.39678401331749, 67.99587941938832, 65.33783428130612, 61.32568890048612, 68.01430671445786, 64.44850352502638, 60.931106305891475, 52.51104839386479, 48.66994188677881, 48.92406440550282, 49.216508480810354, 50.58773771409066, 58.60240690169796, 66.22959690709268, 66.71830854108258, 60.35243118962934, 57.25285660836005, 60.055425397811405, 60.51953200371035, 64.90443591148623, 60.94413641960391, 59.66695777831539, 59.00229646313576, 62.34924316406251, 58.26518112613309, 58.647074853220296, 58.38569202730733, 66.11823297316029, 59.83056376057287, 65.06643764434322, 37.95865105044457, 32.547492327228674, 69.7369489362163, 59.22735814125308, 68.53560539983934, 63.47264136037519, 62.31411049442907, 47.63835460908952, 48.715519828181115, 53.11288902836462, 66.79486536210584, 65.61947222678893, 67.96782662791591, 62.78195904147241, 67.56288113132601, 65.38110979141729, 66.30597329908802, 56.680880900352236, 60.47496995618267, 69.3328663610643, 57.55542824345251, 47.35149206653718, 49.61494676528439, 49.305754169341064, 54.03490881766043, 59.05395800067533, 63.83915155164657, 68.3417304869621, 63.35119693509994, 57.422491273572376, 68.31460337485036, 68.76893935665008, 68.68630286185973, 60.83393350724251, 55.31165599822999, 51.416052079969845, 59.54224994105678, 64.35134641585812, 66.28146633025139, 68.92400633904242, 71.5078127768732, 70.6425065378989, 73.39792451550885, 69.67765838869157, 71.38417182430145, 41.93898208679692, 1.1968733826952598, 0.6042851291356549, 0.4419016393442308, 2.0669927375931896, 1.323988206924931, 1.2208448254293012, 0.9605753397749317, 0.07684847069603783, 0.5057348431118074, 28.0725190331859, 41.00881161228303, 27.37265640689481, 21.499779801214896, 30.68489209298165, 38.73706502299155, 48.038852137904016, 56.28860465941891, 69.84480627121465, 72.34689404887538, 61.793611972562736, 2.3800628415999876, 0.1156947362206636, 0.0404471786121928, 0.015137484653912967, 0.009300983473358136, 0.02823174195063691, 0.04011049446079039, 0.01955440767379778, 0.030762647473884207, 0.03393205663850231, 0.04575736685505798, 0.05678589583464688, 0.05117716695812922, 0.033734559171622804, 0.05590599022745606, 0.0798160118621684, 0.018131213578125163, 0.08456465382609638, 0.0553827713273706, 0.0553221354681638, 0.03812233541881846, 0.08633290732940359, 0.02600629675021816, 0.14801181822774873, 0.0683777982128724, 0.18562969240930774, 0.24552272212120796, 0.227542914329998, 0.15880380606939717, 0.18443433477753596, 0.25474881092386864, 0.20074995444907298, 0.17256125897890137, 0.12439960178228156, 0.08393745764248794, 0.14727589884592643, 0.14949784493975102, 0.24504512758745303, 0.08650299417035234, 0.2319583540121394, 0.24581739018040322, 0.26619094694333695, 0.4016929936985816, 30.237667368304347, 108.65148944239463, 86.9064889415618, 96.26258911625033, 63.86674150343865, 53.040501686834524, 38.415917042763006, 74.34832265300136, 55.81234262835596, 83.9614635898221, 36.723014231651064, 0.21019514439807785, 0.20865958244089158, 2.7491828799247746, 3.4043471563246945, 1.9042358259039542, 6.385348487284876, 5.693708129467503, 8.518040680116224, 3.204030731031972, 56.13228251857143, 81.25279241992583, 76.05602848914363, 74.87734056288197, 77.85503925815706, 77.80928088772681, 78.07256606317337, 74.47921214565154, 71.70277810865834, 74.63809167185138, 75.37278298408755, 67.30946463923301, 70.28164848204582, 74.22042985116282, 60.965893806949744, 54.3484160207933, 63.66905404675392, 68.67372774308728, 71.0639024549915, 66.68736888516334, 63.29115329250213, 70.64875095121323, 66.77266474693053, 60.67383020154892, 54.5910224606914, 51.74113811985139, 52.08709509141984, 50.46535584234422, 55.19418493393929, 61.461677474360314, 69.90466164004418, 69.23990618798041, 61.731626756729625, 60.000410233774495, 63.60225608271938, 60.792403451858036, 66.94833201746788, 63.149234094927394, 60.32581398564001, 60.68449904841762, 62.42932619587068, 59.05128294421781, 59.19722649358935, 60.23588972706949, 68.27271246141004, 61.5593994048334, 65.33769699835008, 42.61630089052262, 36.59578038800147, 69.60814614449778, 63.29898626573625, 72.23332574290615, 63.75043538308913, 63.74281029547415, 50.71707394815261, 50.90429259884743, 55.24151617480863, 70.5718646510955, 68.117857287007, 69.40353178208875, 65.26607844137376, 69.32537463403517, 68.76391087808918, 68.71438703229352, 58.26174905223232, 65.10912872129872, 71.3531929446805, 60.40271205286826, 49.76918612757037, 51.5114245107097, 51.87578524312666, 54.94212950429609, 61.346952069190245, 68.68955058436241, 72.33846879774525, 66.27388046633813, 57.57443997167773, 68.66731859022572, 72.67572202990132, 71.07403001477643, 63.485593026684185, 56.25753948765417, 55.45096289726996, 62.66171486146989, 67.09786845791724, 68.88020915369835, 72.33468763289913, 75.20474080116519, 73.50228309631348, 78.15420627593994, 72.34987505020635, 75.83842323672387, 40.27140994225779, 1.0261320575110375, 3.777466786484565, 9.270917081063795, 3.2803723119920303, 3.1465334421203983, 1.6122603512579397, 0.914610370753273, 0.2177252830757249, 2.03233148782484, 36.41395107392342, 63.33860612684681, 51.813266584950114, 33.63989399325463, 38.82068995506533, 38.77370780514133, 55.787192390811065, 66.0104383960847, 78.69433233814856, 83.44688784691596, 69.92609347066572, 2.4932163569235035, 0.2332539159444071, 0.20748993471985866, 0.13181376240907178, 0.14886209921490762, 0.12252350608187339, 0.20092013322057264, 0.1697288787052516, 0.19805497970552216, 0.17555773528593202, 0.1745277760370124, 0.14067101051970837, 0.14375722636618923, 0.1804774906486273, 0.14820516349807863, 0.08992296388192524, 0.06157022217408784, 0.16424681480613448, 0.13220382373659842, 0.17747390504565932, 0.26482810716955896, 0.15192039881742772, 0.06580748895723974], [0.012605435744438682, 0.08545294043517883, 0.025843395813999158, 0.06144319330492328, 0.10291267411723252, 0.12324563588105863, 0.03916421116540029, 0.02773049828265944, 0.05164923033707085, 0.013668838561692787, 0.053167172271998665, 0.06029043016174148, 0.03996220665172704, 0.017804601567707235, 0.024002930862949263, 0.11256188860223179, 0.04908159855873354, 0.04266088159995214, 0.011176954684478622, 0.15796356083404633, 43.22597057588639, 79.72826127083071, 75.73550808814265, 70.6465858028781, 53.34078265774635, 32.04254992546574, 30.24037184253816, 63.70941523582705, 55.245575827936975, 46.37351966673329, 5.025839786375723, 0.09578742056844697, 0.06024096769491031, 0.6448711803363216, 0.48349540260049606, 0.8018082752823831, 1.4752585801386064, 0.907060421041904, 0.20742394390606111, 34.05664190169304, 79.9156250492219, 67.25825417426326, 70.74495884679979, 66.33277093210529, 67.52590102534141, 65.80280773101315, 69.97492697931105, 65.71841793675577, 71.03512794740739, 66.02328023602887, 66.43113613128662, 65.82631449545583, 67.19824191062682, 63.55280676195699, 49.696010389635646, 52.694689842962454, 62.30404177019673, 65.63750336247107, 66.07653817822857, 60.15279431496898, 65.09517685059579, 61.752599670041, 60.81218004226685, 50.68027427119594, 46.17473002403013, 45.94164709891043, 47.5319524734251, 47.37510473497453, 45.49725824786771, 54.33213818457819, 60.786982736279896, 63.11290118002123, 60.26573111934047, 56.427413417447, 61.98222306466872, 59.7775843066554, 62.20892429351807, 62.685825670919115, 63.363599469584805, 55.939800047105365, 59.04044151306153, 50.635645543375325, 61.0104872334388, 60.29891829336844, 62.9032269600899, 60.441241495070926, 63.58634694930046, 37.30248558905817, 35.96207834059192, 65.26423884976295, 58.85492124865132, 63.43972090751895, 59.67918772851268, 60.23763910416634, 50.06042603523501, 45.42311368450042, 45.26824674298687, 51.6747441599446, 59.96439110848212, 62.26577512679562, 62.51393172048754, 53.72948169708253, 50.89323151496149, 53.53091955184937, 57.0168044490199, 62.12260469313591, 58.29613647153301, 51.266617621144945, 45.769168715323175, 47.235605639796105, 46.06305622285413, 53.90499991755332, 58.70229790287634, 62.76554784467144, 63.62068337778892, 59.26156120915567, 57.4753491340145, 61.597650358753825, 63.66468844875213, 64.925804984185, 63.26844276920442, 52.21406613626788, 47.18976097722208, 51.33991887492519, 57.93567065269717, 61.12847212822207, 66.0718862472042, 64.92495775222778, 69.5321306105583, 69.46424222761586, 73.31531939967986, 65.9699595359064, 69.16746001089774, 45.32568593179026, 1.7424900277007012, 1.0849688971234908, 3.844600848613247, 0.8652678732910465, 0.36456962927214565, 0.1681441645468435, 0.2612828667606077, 0.2315820822672498, 7.466991582224447, 36.55062606257778, 44.50625965672155, 59.495926749321725, 50.97887646767401, 21.111833856951808, 30.668518158697314, 49.30201222819667, 55.827855602387466, 66.22867122773202, 66.27526114063879, 34.02766343085997, 0.7059723307048121, 0.08237571846092902, 0.04700416729094521, 0.023929689026948427, 0.06103417513171031, 0.05406609218147013, 0.0834278789378943, 0.04056108056477482, 0.009318389948607694, 0.0059138602603437205, 0.042524625201739615, 0.030884867226104104, 0.02335607111754437, 0.04175619687885047, 0.09335478497368675, 0.01322603016535962, 0.023307604565014763, 0.06551294347211238, 0.053791618199958924, 0.04334457676797625, 0.03558277693246642, 0.04297382851702072, 0.05291852311441495, 0.06857424613929565, 0.03391550530889823, 0.029952147517413385, 0.043963169784195004, 0.030377749578967213, 0.011165808105180341, 0.01890665160552148, 0.0010278540632439658, 0.027967656121378946, 0.06695609990387194, 0.04480299367118747, 0.008122673213121392, 0.043920062016695745, 0.03259409940050494, 0.05028617988911368, 0.026851699672519203, 0.007248147937183779, 0.03021273998573663, 0.13130218421499576, 52.306088862880586, 89.74875603952717, 81.84026933485463, 80.6951412077873, 63.61366625755065, 39.466155190621656, 26.416943457818803, 53.76431626658286, 57.56535968472881, 52.445701706794004, 6.544434918511299, 0.15322311601090818, 0.023261422869719328, 0.9456654914444493, 0.9166824853708668, 2.3272520495999247, 3.9146671275938716, 0.5293380120588888, 0.776352092864052, 36.72902722512522, 83.07091297641878, 70.228068905492, 75.52506508365755, 67.84801390863234, 69.83074849651706, 68.98095915394445, 72.4688954507151, 68.6305110685287, 72.46553005710726, 67.09083172582811, 71.3834265739687, 68.79496820511358, 70.10001136410621, 66.32673832678026, 52.10038015919348, 55.91972535656345, 66.74607107716223, 67.81362256696148, 69.95627218677153, 63.01055869748516, 65.67902165074503, 63.682703894953576, 62.041235123911214, 53.09286532863494, 48.38227918071132, 48.45414876937867, 49.71206465075093, 48.88449161283432, 47.008402347564704, 57.373379276644805, 63.154384166963645, 67.52654429404967, 62.34445787245228, 56.24484277540638, 63.35064388090565, 61.961108946031146, 63.42837349061043, 63.20602217028218, 63.20664974950976, 55.87678324791693, 59.641689869665335, 53.59051996661771, 61.43962590925155, 62.14427186596779, 65.34119967491397, 61.11536356710619, 65.184661803707, 39.868041238477154, 38.948214054107666, 65.40009014068112, 59.4505919948701, 65.23866107386928, 62.39373460892708, 63.12378575724941, 52.8369620538527, 46.57531384498843, 47.99387431913807, 54.634407797167384, 64.010245338563, 62.27279224703389, 63.09185374167658, 55.787196313181234, 52.61632873165993, 52.43800209414575, 60.33383523264239, 62.844709119489124, 61.12100393541398, 52.711305003012384, 48.13842150472826, 48.71540215707595, 49.394431114196784, 56.999918645428075, 61.647174204549486, 64.68105300780266, 66.11201993880734, 60.674544072920284, 58.10963561457973, 63.25480468811528, 66.05145069860643, 67.78289471903156, 65.40616196970787, 56.23808845396965, 51.014954428518976, 54.47918391996815, 60.33036001266972, 62.2983935571486, 69.62727946619835, 67.71175076884609, 71.84982776641846, 72.22160570083126, 74.35870908921765, 69.99370728769611, 73.91788959503174, 50.89644393613262, 2.820323152888206, 1.1721584056654286, 0.7377900459593343, 2.4394269335654477, 2.1715579782762835, 0.5478214460515207, 0.2529479986837795, 0.15738655873123678, 8.207966041180397, 44.259087577942886, 38.91590156862813, 41.6135508783402, 38.5354708856152, 28.274515213504916, 41.47267895360147, 58.46886196444112, 62.77941734560075, 72.28971373650336, 72.65670637930594, 46.42053319561867, 1.1046542924258018, 0.028543735088239756, 0.12500796752471116, 0.0701888224049922, 0.06865521397201285, 0.048606394219302365, 0.039891921915113926, 0.04978587850928307, 0.034504063848045566, 0.017921064169176163, 0.03883362890431478, 0.047705271807048595, 0.026906750750757998, 0.03247242931637072, 0.03777533972395524, 0.06206020051913877, 0.03702882534614013, 0.07600741340748726, 0.01480239109256335, 0.057112195664235664, 0.07444216554323513, 0.03048951223102068, 0.1057497428489789, 0.2536440048847468, 0.23319652063712, 0.17340890462360076, 0.2276645690923737, 0.22807339957404524, 0.15824528200732124, 0.1982174209889866, 0.12794082022963033, 0.1305200084443054, 0.18158079515541756, 0.17174934367499045, 0.13464094860659492, 0.18533104069290623, 0.16824302053259266, 0.16189232017965088, 0.2067305117605194, 0.12870736780666536, 0.11711821951452764, 0.39169882514303733, 62.23874607393819, 98.87373447418214, 93.21887693097516, 89.05791682581749, 73.5210241809968, 44.072253319524954, 42.44963153716057, 79.1097584078389, 69.59640256820187, 67.49043495424333, 9.10660703336039, 0.3871365570493283, 0.3124953235589689, 2.0770592554923026, 1.996196162316107, 5.249373211014656, 5.3917013156798586, 6.799763075767025, 2.5442277616070164, 40.99260437873102, 86.45793453339608, 74.6995787466726, 77.40674372642272, 71.31181193936256, 72.91778718271564, 73.45682282601634, 74.18186510762861, 70.18161235317108, 75.83222589185162, 70.5678952124811, 71.31575784375592, 70.74289568008916, 74.17362813026675, 70.60240422525715, 55.32419973804105, 58.700666196884654, 67.79947065537976, 70.56756573338663, 73.11007745804326, 62.709736439489554, 67.54527753399265, 68.66293338037306, 65.58400615569084, 54.66504543058334, 49.55270659539008, 52.4918483918713, 52.65167713165284, 52.409596289357836, 49.063634103344334, 61.21060655963037, 67.53199638858919, 70.88015510189918, 62.418437696272335, 58.9509291033591, 65.54439021695045, 62.1973454567694, 66.64449737917992, 67.81025717335363, 63.63472546300581, 55.1411662563201, 59.32991243177845, 53.882697320753536, 62.75752267529888, 65.2349191327249, 66.73074245452881, 66.8287467956543, 65.15694633606942, 44.59927082061768, 41.6209327790045, 66.55815816694691, 63.29893919729418, 67.16819655510687, 65.01358370627126, 64.76753734773206, 55.281426291311945, 47.62790541495047, 50.40477875740298, 56.9408046045611, 65.3317859865004, 65.56588480549475, 64.94241622186476, 57.48377830751481, 52.98591798351657, 53.04650291319817, 61.64358131347164, 66.64375997358754, 63.897461506628225, 56.759948038285785, 50.936287372343, 52.488577135147594, 51.70252238550494, 60.59408057120539, 63.14192671929637, 69.61755983291134, 68.73381060938682, 61.382771153603834, 59.278207748166984, 63.98045885947443, 68.73811737183603, 68.52490517400926, 68.87791064477736, 57.88887677654144, 52.13466167449952, 56.601025366014056, 64.44283962249756, 65.15997832821262, 72.31006299295734, 69.73260295006537, 74.48655482261412, 75.4466490591726, 78.3191184074648, 72.7034531870196, 78.49749211342105, 51.54097172521776, 2.5623709299872, 5.279684307113771, 9.546901910535752, 4.435197028421587, 3.1925335286125063, 0.2746817751997902, 0.6194104013904449, 0.30168334082249676, 11.610422615082035, 55.91186100436796, 60.71279894921088, 76.07254166756907, 64.74050829487463, 31.976299132070235, 43.14757024088214, 64.06978691777876, 72.55845885122977, 82.28365405913323, 83.56346853317754, 51.02871018071329, 1.1935397357709947, 0.19366466770729712, 0.2776787418030924, 0.17182420578695115, 0.19112061228482954, 0.20856661001040092, 0.15043334554760687, 0.13193247539381828, 0.17853432395044835, 0.07127233119981904, 0.136241153062832, 0.1163661509992615, 0.1033405572055809, 0.08206095591547989, 0.14033108198594663, 0.18835491230410917, 0.24447439208386407, 0.16158081350787995, 0.13652650549286796, 0.2236286953331963, 0.12289023237122644, 0.15294888717753274], [0.021904930134394, 0.04254874164959596, 0.013426525908852778, 0.007890984284571342, 0.042686265923323176, 0.08552509059588756, 0.08894054804958644, 0.02483717762985297, 0.02201913660692592, 0.007040436124248851, 0.05365720041276467, 0.09827153727171883, 0.06759897024641115, 0.0616094267236129, 0.04622371521808448, 0.06622763455755289, 0.017504613027877865, 0.007634912213806304, 0.09197830117397732, 3.79824431673173, 73.78215205284857, 70.08288629593389, 79.37498123415055, 50.569165291324744, 30.91869869539815, 24.53732994294936, 50.94847025409822, 48.85814897475704, 45.57007705011676, 27.903455072833648, 0.12962295012848993, 0.13594170461498922, 0.1321964999360423, 0.23191965125020475, 0.3739550950065736, 1.3248464705482608, 2.0668230950832367, 1.1864594898877607, 11.984213705985777, 78.21197494383782, 66.76062307050152, 71.66702962690785, 62.32697979096444, 65.086645695471, 63.96292978717435, 66.75706155838506, 63.821496963500984, 68.43048587922128, 62.43764554300616, 66.55982909664031, 64.4731124754875, 64.36233689708095, 62.60419722526305, 54.5876492223432, 46.45162582397462, 58.197320199781856, 66.03484338329685, 66.9626251343758, 67.87726694537749, 66.1295529334776, 61.69512517990605, 60.925995457556944, 55.941976962550996, 51.02909849536035, 47.79706939574211, 47.74892230187693, 44.76211586306172, 47.0537135677953, 44.73849927225421, 52.6265190493676, 61.29306262539279, 65.81330007122409, 60.51102830517677, 58.666667092231016, 63.532073113226126, 61.4724483028535, 62.928396809485655, 60.43257697936028, 62.38316382131269, 60.866555859965665, 53.787301355792636, 56.906546623476096, 64.9668525880383, 59.26347532579976, 62.63525455228744, 56.44253023209111, 67.09624459666591, 38.77386077757805, 40.51185907856111, 66.10754059207055, 57.37178679435485, 59.885955472146314, 58.68293316133561, 60.06429387677101, 45.52561306184339, 45.023808556218306, 45.825023266576956, 51.13905037603071, 55.16115073234805, 61.579929090315304, 61.69346993969333, 64.45611684553086, 54.967432714277706, 53.60442476887857, 59.07482893236222, 60.85611451056696, 56.1832929426624, 47.940549696645434, 44.644358465748454, 47.07628680813698, 46.20374771856493, 56.510975591598026, 59.929489858688854, 65.14796018600464, 62.83373825011715, 59.80900641410582, 58.49754625751127, 61.651135798423525, 61.65817253051266, 65.63481261653286, 62.948667618536184, 53.57137487780664, 45.933849427007864, 51.04898491213399, 51.62538505369618, 59.79867489107194, 58.55530315829862, 63.41309978115944, 65.48960255038354, 71.38221848395564, 66.24021868551931, 72.79682128660141, 64.85705367980465, 69.67012743796073, 43.10283560906687, 0.15185071545983517, 1.4047194104040823, 0.31978918539900936, 0.5864540343323063, 1.5271672269990368, 0.10955546081306473, 0.12889542707031773, 0.46191038503762216, 17.23728326059157, 30.346016960759318, 40.28749165996429, 55.06993601399084, 38.45989465713501, 20.5559810515373, 39.897721813571074, 49.4011579790423, 57.32705216253958, 57.73093077444262, 71.65618035101122, 10.63086950009869, 0.24582796219375827, 0.1471055821786004, 0.11075231231628888, 0.06816058930370116, 0.023602782072679653, 0.0471679070934413, 0.04287724015152743, 0.044717751067852786, 0.008216226912824618, 0.034041055628368934, 0.03484820203495122, 0.02984200897175939, 0.030984161797189907, 0.048581925371000846, 0.11637394211345142, 0.03712147218926299, 0.017766130547369682, 0.021517550114602334, 0.04870320475029369, 0.06259277718321932, 0.05119072288394936, 0.04391438530517682, 0.021359431482250654, 0.034955645866331556, 0.032122434387283946, 0.021804603259830226, 0.03271827459215157, 0.019406232862703262, 0.05852781506555696, 0.037192385117974014, 0.016100013801347346, 0.03994985348394802, 0.05812890542250487, 0.048580163368775, 0.04883003443659795, 0.04604167357507733, 0.03353089469695284, 0.01972492352398413, 0.05395462638848732, 0.06723289513179372, 6.689400326821112, 85.87659220541678, 77.82493114471436, 86.33309333555161, 62.16732363547049, 49.68345488271406, 37.470759191820704, 41.61668877447806, 54.9116095419853, 52.39752715633762, 29.78476305161753, 0.36971865942881954, 0.13359427331916748, 0.20698139023396278, 1.813679085143151, 1.7661539320984196, 3.1082614054602966, 2.2214794543481644, 0.9264391973134011, 13.7221110059369, 80.60116906319895, 70.1530025851342, 74.66924313575991, 66.32291009349208, 67.83557215044576, 68.04563076265397, 70.22824933451992, 66.64936896293395, 69.34273504441785, 64.03930225679952, 69.69636024967318, 66.57652270409369, 67.14051246643066, 65.45716847142866, 56.841937341997706, 49.115848695078206, 60.592393952031294, 67.28849564829181, 68.03154945373535, 70.51821447187855, 65.42158472922542, 63.325819200085064, 63.23476137653474, 58.919095147040586, 53.10857442117507, 50.12454109807169, 49.02788169922368, 47.40631503443564, 49.27962726162326, 45.3500791518919, 53.36560733856694, 63.7621711146447, 67.18532162327921, 62.42678842236919, 60.229390359693966, 64.21735825077181, 64.33376243037563, 64.01645837291595, 64.1189891292203, 66.12257895931121, 61.499112575284904, 54.048856765993186, 59.463677021764944, 67.14619205844018, 62.71892655280329, 64.35436271852063, 58.14409363654352, 69.58969531520721, 43.167723378827496, 41.67561061920659, 67.02941525367, 58.33020617884975, 62.33800557351882, 61.509028327080514, 62.18948502694408, 47.59371803652856, 46.84583187103272, 47.85450466217534, 52.56986825696884, 54.960305767674605, 62.75176463588592, 65.99367418596822, 64.58212298731651, 54.59115189890708, 54.58679414564564, 61.98562768197829, 64.43918397349697, 59.576719730131096, 50.460162624236084, 46.653961289313536, 48.36821356127339, 48.575514747250466, 58.9474303491654, 62.43688068082256, 68.43543591037874, 64.85413935876662, 61.407886089817175, 56.7354763707807, 62.78682670285625, 64.36580427231328, 68.34060868909283, 64.7792220884754, 55.26802355243314, 48.91887510976484, 52.238431899778305, 52.83734644612959, 62.84974544279037, 61.25557653365597, 67.13775111782935, 66.55651077147454, 71.56909588844546, 70.22486825143137, 76.32096106006254, 68.5001628629623, 72.73304354759955, 50.31319533624957, 0.5589235309631594, 1.209644129680049, 1.423195857674845, 3.108503366670301, 1.9592992841236054, 0.08235250599682331, 0.20685794282584422, 0.35377054745631836, 25.20871812297452, 36.0218866409794, 51.68496585661366, 53.890098833268695, 34.687696349236276, 30.050176112882554, 52.34121761014385, 59.408920734159416, 63.33773536066856, 62.835405257440385, 80.10502061536236, 15.042793635399113, 0.3436041929789128, 0.09102714172894917, 0.006161823769235203, 0.10846655109837171, 0.024266857728962938, 0.035939026969454946, 0.024583204161195506, 0.06070969476094169, 0.0674083752317294, 0.07279819448388393, 0.020773088852424296, 0.05154167925338111, 0.020949480596989877, 0.05245455345439334, 0.029820981773457704, 0.05228233305857547, 0.10304354491733736, 0.05315213779648466, 0.002599283658538855, 0.050163157659793095, 0.0721650917623793, 0.165214613680878, 0.08863422779306289, 0.16008608403705782, 0.09048730255134645, 0.2326032468267987, 0.20714361701280842, 0.17455039095253716, 0.1016260524310412, 0.1631260741381876, 0.09488563549013869, 0.15073213515983475, 0.2239262745265038, 0.14752098569466224, 0.22469417041828557, 0.27442415515261315, 0.10792219200201573, 0.15583074140933253, 0.13474199560380754, 0.35246298858715647, 9.1264767800608, 97.78340185842207, 86.43093293712985, 97.70587228959607, 67.60816881733557, 49.89762413886286, 36.898693269298924, 71.3616652642527, 63.97438703044769, 62.92865176354686, 42.73297571366833, 0.5717975466001419, 0.2499904089997853, 0.6797801522958664, 2.1749209204027733, 2.978063720849253, 5.498937935598436, 5.771761825007777, 4.679085102773482, 13.606743312651112, 85.35756849473523, 72.68561424747591, 78.30902222664126, 68.90059763385405, 70.66777444654896, 70.5668047935732, 74.57877759010562, 69.36237042950046, 73.14870495950022, 66.47279954725697, 71.98119578822967, 69.90907038411787, 68.9243358181369, 68.94659134649461, 60.45391859546785, 50.200493874088416, 63.60393485715313, 70.9702205657959, 69.92219463471444, 73.19782087879797, 67.14965158893217, 64.91541070322837, 66.21779841761436, 61.82601859492641, 55.598055701101984, 52.2142622547765, 52.162177101258315, 49.495820460780976, 52.228818170485965, 49.44965416385282, 56.917976410158225, 68.59942236254292, 71.07562249706638, 63.83812389066143, 60.93430695995208, 68.15249966036889, 66.33241791878977, 67.55753101841097, 66.78936619912425, 68.15822632082048, 62.243688260355306, 53.96892278425155, 62.39967699973815, 67.51950756196054, 64.77316594892933, 66.89330900869062, 61.71405453835765, 70.42722332862117, 48.328503485648866, 45.91282160051408, 68.68347875533566, 64.3679537311677, 65.5369024122915, 64.24499134863576, 66.38616223489085, 50.91457705343924, 48.90693149259014, 50.807900351862756, 56.914301149306766, 60.318337948091575, 67.12876104539441, 69.28747669343026, 67.93375692059918, 55.67378490201889, 55.52718239445841, 64.75817857250091, 68.44993299053561, 63.288360564939445, 51.33515711753599, 49.27618342061197, 51.071416947149466, 51.03508795461347, 61.19827462780861, 65.01665099974602, 70.4745114234186, 67.47102706663071, 61.294090286377944, 58.70857369515204, 65.75065589720204, 68.6068513316493, 71.10493829173427, 67.9814450971542, 59.8763378204838, 50.936012806430945, 54.68521033563922, 56.59573016628143, 65.79650055977606, 62.926008086050714, 70.15990595663749, 71.08594617535992, 76.70122700352823, 72.79981797741306, 78.58329788331064, 72.0557757346861, 76.11522489978422, 51.97727264896516, 0.31498149337787784, 5.969284542145268, 5.013200438791706, 3.452712432030709, 3.886816583333477, 0.19281383513683276, 0.23281615798271474, 0.7320716592573351, 33.2225694964009, 45.25769164485317, 54.272157299903135, 64.52977895736694, 51.097732128635535, 28.934965864304576, 54.324999470864576, 66.29626151054137, 74.6117647232548, 70.52416078505978, 91.74021397867511, 17.396009814354684, 0.5724511115301041, 0.22490115205366767, 0.2947651685005234, 0.1804842935093949, 0.09298674101310392, 0.13555538179653306, 0.1921992334386995, 0.2351141612856619, 0.177098399388694, 0.23905312492241784, 0.10743850706926278, 0.16326380142521474, 0.17333545211342075, 0.16381088013370193, 0.15696015419258227, 0.12938296542532984, 0.14142393705344972, 0.1560135759533413, 0.10190860864015357, 0.12809350155293941, 0.18335025907764513], [0.03637509187683463, 0.03157146203692161, 0.10570975305933146, 0.026409703329385772, 0.06110897595663706, 0.07452976003649735, 0.08671684761441524, 0.035709552992615974, 0.006709399956068205, 0.05794600959146216, 0.017264272093832973, 0.006250522386718301, 0.02263406197720718, 0.10204553153486022, 0.0432430011700959, 0.0652839674524242, 0.017156433727171634, 0.04298716227734282, 0.0575384431548657, 29.338024700841597, 77.77097502062398, 67.39968699793663, 69.91580117133357, 44.5414746961286, 22.80758038643868, 19.258947372436523, 49.55447166196762, 21.43424484037584, 44.426945409467145, 9.793507206824518, 0.09166382208106019, 0.061991133862325264, 0.15261775333314173, 0.4193739352687713, 1.287006262329317, 1.6861111045845094, 2.1845956915809266, 1.579721226326881, 59.977966431648504, 75.83945874244937, 69.74451126590853, 63.853072043388124, 63.24796015216459, 60.86735994585099, 60.53780632634317, 61.87321255283972, 64.70211221325782, 64.72851760925786, 68.37248971385341, 61.746924000401656, 61.33083897252237, 60.12924832682456, 54.43348046272032, 48.58424202088387, 49.708459992562574, 57.097934753664084, 68.41222332369897, 61.734745041016616, 65.50755131629207, 63.01888981173116, 61.754592234088534, 61.36157466519264, 57.22288185550321, 57.41110855533231, 55.96911191940308, 53.74140178003619, 47.05601599908645, 46.660699921269575, 43.67686271667481, 47.81394735459359, 60.62761291380852, 61.82348082142492, 60.85248631815757, 61.40745462909822, 65.85410841049688, 55.46595419606855, 57.55181574052381, 58.43439609773698, 62.93202500189505, 60.68868813976165, 57.062864841953406, 58.50948202994562, 63.50193362082205, 55.89309638546359, 59.92994093125867, 55.554764501510135, 66.17222047621205, 40.24960548646989, 39.972937183995406, 64.62255085668257, 54.445271107458304, 57.72268987471058, 51.870956805444536, 53.80746233847834, 50.632417432723514, 49.76989607657156, 49.30449901088592, 50.83780450205649, 50.29622716288413, 53.25005823566068, 58.969960443435184, 61.62019222013412, 57.508320577682994, 59.33771402605119, 59.41986022457, 57.656629316268436, 52.94836521148682, 45.105032997746626, 46.21302804639263, 44.41400551026867, 47.89404607588246, 56.948057067009714, 61.21995749012117, 61.8778762509746, 61.81954276177191, 59.40233507464009, 55.665802878718225, 61.50828699911795, 63.666088734903646, 63.11406220159223, 61.69860824461907, 51.80051103714974, 48.58802318572999, 48.0476539365707, 49.03429869682559, 52.38359097511538, 58.092283048937404, 57.66282273877052, 61.917096030327585, 64.30366216167327, 67.97451819142988, 67.34129075081118, 70.7106851762341, 66.46757495018744, 70.24135005089545, 30.16440533822583, 0.2418146114195547, 1.8090022715830036, 2.2825733115596156, 1.3039738228244167, 0.26318607431265617, 0.09427196841927306, 0.006990853956179514, 4.6166654844437875, 26.404438941709458, 24.343221649046868, 31.88186022543138, 73.07316795472177, 26.926996707916263, 23.002439814229167, 39.99097224204771, 49.25921132487636, 60.532491514759684, 62.82399116023895, 37.81169160719841, 0.4122706148172579, 0.09915941019332218, 0.009294980216861494, 0.019886313351772485, 0.005295465469375374, 0.05695872910080418, 0.0295037524248924, 0.051726451999838316, 0.07005606702859364, 0.02817458987626578, 0.03369814318214213, 0.027072043796520562, 0.029145131345778227, 0.00843037721595817, 0.030463187534722592, 0.02879770664167741, 0.027915269113896836, 0.032026979831918594, 0.029024286721382412, 0.030360842018478343, 0.06337763809208428, 0.06475915891989585, 0.039586260494205265, 0.03587475985348706, 0.024116129929860754, 0.04825692406044372, 0.06800534924672497, 0.011627141465132516, 0.06377828675472448, 0.07446286523894918, 0.006098154680653205, 0.07301864394497487, 0.05324924327132683, 0.014455776526442459, 0.026301514477499073, 0.026642762597710378, 0.017067063825144883, 0.0339271689975454, 0.08090040165810816, 0.028860974012904113, 38.95884759964482, 90.45119762420656, 75.55807575102776, 77.6463456307688, 50.684584956015314, 29.408050775527958, 20.64389313420942, 42.15199816611506, 30.78064499362823, 50.44474770945888, 11.858487033074903, 0.14217634264740253, 0.06338819095324125, 0.5066740975504922, 1.258234696522836, 4.232970899151218, 2.935428047372449, 0.9923272940420336, 2.006148196035816, 62.17034778287334, 79.83098030090332, 72.60584892765169, 68.0649366686421, 67.86797877280944, 62.86882385130852, 62.75631066291564, 64.38212133223011, 66.03500027810374, 65.88017648266208, 69.73015539107784, 64.53245793619465, 63.030445114258804, 61.282291796899614, 56.88853509964482, 52.818860315507465, 51.17168057349421, 60.548463406101355, 67.30518925574519, 66.10833291084536, 69.49957493812808, 63.36199522018433, 65.1698980023784, 64.80223463427636, 58.26823665249733, 60.29048911986813, 55.78215606750981, 55.202516048185295, 50.85927163400958, 48.076683398216005, 46.13426293096235, 50.18576537409137, 62.567821164284986, 62.59503064617034, 62.43959496098181, 61.965674584911724, 66.43086156537457, 58.62646672033495, 60.05511553056779, 60.57002859730875, 65.60422597392913, 61.81605577468873, 58.084916837753795, 60.642310034844186, 66.27309599230367, 58.52948611782443, 61.07672037616853, 57.307146133915076, 68.94885847645422, 42.44712514262046, 43.12369869601342, 65.00517022225165, 57.310962600092736, 59.902907956031065, 54.654855112875666, 55.99406603843936, 51.41447920953074, 51.20255747149068, 50.597708379068685, 51.888285836865826, 52.47553525432464, 57.600421751699145, 60.31528242172734, 65.03180703809186, 58.012231396090606, 59.104760539147165, 60.73000638715683, 60.36416692118491, 54.827686509778424, 47.572184224282545, 46.88594595078499, 48.43298758229902, 49.84098511357462, 59.5667294533022, 62.410949891613384, 63.08959053408716, 63.591959861017045, 58.605360446437714, 56.9265232547637, 62.9430978528915, 66.06321780912339, 64.6679562137973, 65.26796902379682, 53.92035207440777, 50.2764388053648, 51.43322421658424, 51.72463670853646, 56.31438247619137, 60.86197845397457, 59.71108836512412, 63.45153116410779, 67.9015621062248, 71.56482050495764, 69.02168120107343, 72.98720529002529, 69.11652411184004, 74.92592303983628, 35.59344222468715, 0.21754015026794327, 0.4941216243370887, 1.6217355718535762, 3.0389028691476394, 1.028703967890432, 0.19109177673535963, 0.049371765851373636, 4.969641537435593, 36.440242721188454, 19.900280391016317, 35.63292480284168, 66.21521749804097, 22.17989721605855, 31.71801301740831, 50.949776403365604, 57.943613452296105, 67.60419153398084, 69.12338825964159, 51.57023260670324, 1.2937786021540243, 0.013762604850795002, 0.05677297959224351, 0.10549918613246373, 0.04548670799140969, 0.057622540456753586, 0.01518427060105868, 0.12289200969521077, 0.05194494793672235, 0.014342181966640057, 0.07447817933655555, 0.015376391088319643, 0.052518901009593284, 0.0564056174499133, 0.05311564902865118, 0.06368514578489047, 0.023695735350972223, 0.008555126973548004, 0.05747349039020558, 0.016732409806741823, 0.07984236528676364, 0.11478308392989059, 0.17114349070095247, 0.17342698429861378, 0.19789486732934752, 0.1662582552601253, 0.12477660131069923, 0.1245432509289634, 0.12523951759982493, 0.17688191826305083, 0.13739051477562997, 0.10421006699963924, 0.15819118087810857, 0.15505386696707818, 0.20029972457597334, 0.19855676729592586, 0.119836843392301, 0.16343632442576272, 0.1529986369273355, 0.181819875874827, 47.51556873321534, 101.73766874497937, 86.73533239672261, 90.83118115701984, 59.13512752902124, 36.547441097997854, 30.24725756337566, 62.11293212829098, 36.87599059074156, 64.99905916952318, 15.580830054898417, 0.22568377215535412, 0.4345505967015221, 0.4985082744350357, 1.8914378674760943, 5.400629120488321, 5.154300841592974, 8.511107890836655, 3.131883389526798, 67.05463609387799, 81.68997195459183, 76.53126285922143, 70.14592662934335, 70.6803652548021, 67.22707917613369, 66.52977589638003, 67.91365869583623, 69.67299076818651, 69.03450735153692, 74.24792566607076, 63.970464660275375, 66.10397123521375, 63.953873034446474, 60.32832822492046, 54.43977586684689, 53.635623301229174, 61.95048324523434, 72.31993952105123, 67.84973975150817, 70.70111459301364, 64.35927352597638, 66.6343149062126, 67.45059936277329, 61.23669424364644, 63.78164176018008, 60.147436357313595, 58.25306492467081, 54.62336632513232, 51.212135899451475, 48.36111799363167, 53.92950296401978, 64.98965724822014, 66.16104172122094, 63.85537839704945, 64.71788014135053, 70.86870962573637, 60.630040860945186, 62.98367869469428, 63.92395319477205, 68.00893306732178, 62.93487656501032, 58.85848668313796, 63.45240977502639, 68.84008330683555, 60.63425740888042, 65.55763606102236, 61.08349430945612, 72.24250408910936, 47.39835262298585, 46.41062136619322, 67.11852365924467, 60.27086550189603, 61.69111259521977, 59.02568555647328, 59.3296496329769, 55.4057889599954, 53.420434228835575, 55.219743097982104, 54.53615242435087, 55.31986551900064, 58.91307430882608, 63.27573837772493, 65.88637382753434, 59.8157528908022, 62.24807739257813, 64.87051525423604, 62.9253726620828, 57.86155354592108, 49.75122167218117, 49.558825492858894, 49.83991822888775, 51.66628360748292, 62.01937967731107, 65.0648255502024, 66.44207954406738, 64.76732161737257, 60.43253383328838, 57.79207660305885, 63.78753708254907, 69.75066154233872, 67.05859768775203, 67.66472155048002, 57.31287671673683, 53.29613039570471, 54.33413859336607, 54.62856346561063, 57.712915328241166, 63.235255595176454, 60.79611009167087, 67.34875894361927, 71.51623802800333, 74.83377087500789, 73.02507185166883, 74.08400197182932, 72.58662931380734, 78.5637644798525, 36.25872719672419, 0.5056584488239981, 7.949315146092446, 7.8397844299193356, 5.236847121869364, 1.1786875585394523, 0.352573090743634, 0.20099891770270564, 7.4171691459994165, 41.50186923242385, 33.89036086297805, 42.08820081526234, 84.01998535279306, 36.2729928570409, 32.743548077921716, 56.990732454484515, 66.13994721443423, 77.71839172609391, 79.06224281557145, 61.66957486060358, 1.5632929917304748, 0.2567574168525396, 0.25766288681376365, 0.1705657531537356, 0.14888324324161778, 0.17483076381106533, 0.113530560817209, 0.22255323046157438, 0.19763252818055693, 0.1401390237433295, 0.18476568312654573, 0.1647859568437261, 0.12740147134829916, 0.1969392339308416, 0.1870198355567071, 0.27987677063192096, 0.11058796347389299, 0.12097386342863883, 0.13439944704934476, 0.12723932883912517, 0.12002124841655455], [0.03228620100285738, 0.06652459321964173, 0.018468612106516957, 0.04146127984107983, 0.10514120856720595, 0.015211038670742945, 0.0715656049789921, 0.017248400667261694, 0.06752583183228009, 0.0621741752500736, 0.0201197499183998, 0.037885755976481784, 0.06605720297703821, 0.06022240155406537, 0.061599655272138704, 0.03829572792916048, 0.05861709495225261, 0.1284475414262664, 1.0448371667054392, 59.001496299620605, 71.9536921285814, 76.6139542671942, 52.21923189778482, 37.41317095295076, 27.025754144114835, 51.55387240071451, 63.15610216509912, 52.099317196876775, 36.13446650966522, 0.5757394060492516, 0.04974319209014216, 0.009372549492024608, 0.17766544234848794, 0.7275633850405294, 2.3641458634407293, 1.3311222628239663, 2.6118337338970554, 23.909640889013968, 81.17885574217766, 62.82900787168934, 71.29340817851406, 62.13883938327913, 64.04748432097897, 55.9553090987667, 61.71959684741113, 57.36722115547427, 62.35777431918729, 58.88136194598291, 61.38732110300372, 58.75395944041591, 57.61528361228205, 52.89247535890149, 50.489701994003795, 47.185434602922015, 47.01645105115829, 55.671451091766365, 65.83284916416292, 61.903869798106534, 62.33503241692821, 58.448324434218875, 63.0510179458126, 58.88804566475653, 62.53754046655471, 59.95779368185229, 61.85830754618492, 56.85622653653545, 53.942231055228945, 45.04364790454988, 46.97286175143334, 43.77605945833268, 57.003801791898674, 61.399829541483236, 63.660632717993956, 60.471949731149984, 62.473652901188025, 49.13984183342227, 50.597245539388354, 55.26917280689363, 62.93430782133534, 56.643014338708696, 60.13648902216266, 62.0902882852862, 62.487847958841634, 54.63190532499745, 55.76679214354485, 54.44649096458189, 66.9584438877721, 43.537477370231386, 36.83407614308019, 65.02201287977158, 57.42437401125508, 61.42180658155873, 54.646955459348625, 58.575189575072265, 55.77753159307665, 58.86287189299061, 53.175639106381325, 53.655748982583326, 54.48621280731694, 55.5090335876711, 56.056290518852975, 61.259110589181226, 56.77307621125252, 60.25246958578787, 60.0702323452119, 57.22769460370464, 49.68263902971822, 45.119800721445394, 43.82664626644504, 45.789690556064734, 46.350181564208, 53.73594968549667, 60.343476418525945, 61.2298850090273, 57.99037987186063, 55.79389179906538, 56.89224566182783, 63.916281038715, 62.691493495818115, 62.80114335398521, 58.399565450606815, 49.245031956703436, 46.72139859968617, 49.139116194940385, 49.40223663083969, 53.821120031418346, 53.1206278647146, 54.782022276232325, 55.131579983618956, 61.2568199250006, 60.684067587698664, 67.66479215314313, 65.60018201028147, 71.84452472194549, 66.37697604394728, 63.06786060333253, 10.25886308762335, 0.5437366652392572, 2.8992520272731785, 1.9285464310838332, 0.7388483504614523, 0.20191903526504196, 0.039296323027942455, 0.7353997903485453, 17.47513382665573, 52.027894758409076, 80.87149881547498, 88.01837890378891, 109.10667265615156, 35.87706096710698, 26.44642006966376, 34.76257047345562, 52.269897153300626, 56.57461997001403, 63.871060032998365, 12.843601088370047, 0.2861002544241567, 0.15673323894941038, 0.023981323353044932, 0.06628810953829559, 0.08077191339144785, 0.02618307728440531, 0.03716832995715161, 0.016807727741017457, 0.04500509149605229, 0.03959174568374311, 0.014771569460149736, 0.02529385987849486, 0.039038147567020315, 0.04810942149150276, 0.023080223923428886, 0.03699278473974236, 0.041302266801076556, 0.06806644475868634, 0.01937592833963854, 0.053981236452537204, 0.008221060927626828, 0.04958430162420677, 0.022227117987049204, 0.051683543415199366, 0.01956295338459313, 0.030816503454961126, 0.03193577514931319, 0.039041767332462535, 0.07489443321021334, 0.04591607729033117, 0.050992141402656996, 0.020654216904433507, 0.07928091476881698, 0.08098542975682406, 0.0475065945647657, 0.03417362714366567, 0.037526211761418855, 0.09632495382139761, 1.9705684987768053, 72.25245121986636, 81.61257574635168, 83.04864175858037, 64.64490836666477, 48.974968925599136, 36.336323445843114, 46.10430778995637, 60.016809663464954, 54.49903111304007, 36.76577591126965, 0.8355780438550058, 0.1741590579190562, 0.21025963367954378, 1.0965794805557498, 2.2391811109358266, 6.188834309577943, 1.344648801511334, 1.519956807455709, 27.242541582353656, 84.86318511347618, 67.63790822798207, 74.00363260699858, 65.53020692640736, 65.73084792783185, 60.86744231562461, 64.82324284891929, 58.3661154777773, 63.95009579197053, 61.635889545563735, 64.12572383880615, 61.57891319644067, 60.14784036144134, 55.421215641883116, 52.24724154318533, 51.00206159776258, 48.904589837597264, 57.676813833175174, 67.76769161224365, 66.28955425754671, 65.09995821983584, 59.463374999261674, 63.78410108627812, 61.91205578465616, 63.812118576418975, 62.84429334825086, 64.04987304441391, 59.869391302908625, 57.09915461078767, 47.821560675098056, 50.005975692502915, 46.307239455561486, 60.328179174853915, 62.6180314248608, 65.06344879827192, 62.15305797515377, 64.56917916574787, 51.332533051890714, 52.28954822786393, 58.020417382640225, 65.9009022866526, 58.6318717464324, 62.91422528605308, 63.199526725276826, 63.61437620655183, 55.89544980756698, 56.779948203794426, 57.12365765725413, 69.9686590317757, 46.131136801935014, 39.80223955646638, 66.70526273788946, 61.14315355977705, 63.2393583943767, 57.08595583515783, 60.7947882529228, 58.8051228369436, 60.44267708255399, 55.48028653667819, 56.556726117287916, 56.695676080642215, 60.27675297952468, 58.09148680779242, 61.869937373745834, 55.84394124246413, 61.628707685778224, 62.468714637141076, 59.54738432361234, 51.98461532592774, 47.44222041099302, 47.20352457415673, 47.50402127542804, 48.11937055280132, 57.025696462200536, 62.671634535635675, 65.77976772862097, 58.71305304188883, 55.24066502048124, 59.60303491161716, 65.73665303568687, 65.53403515969553, 65.46102023893788, 61.85402824032692, 51.595759391784675, 49.58592122600925, 52.08531041299143, 51.69720757392145, 55.371511367059526, 55.46303595266035, 57.0002834258541, 57.490795427753085, 63.38535685693065, 63.67449437418292, 70.07326864427137, 66.95864785102107, 74.09618485358455, 68.70300431405344, 67.69238994967553, 12.676346321259777, 0.4379563784647373, 1.0512205790127478, 1.889326896878981, 2.322782753936706, 0.41883745921715615, 0.06877612562910204, 0.4139316772981998, 18.94588928068838, 47.885867934073175, 72.26357506167504, 88.39811924965151, 90.16180515289308, 35.46780086332752, 40.60412106975433, 42.72438572299096, 59.58060287660169, 63.34050063164004, 75.35551671058901, 18.196622440891883, 0.3379063067897674, 0.09722123838840954, 0.06280106882895194, 0.017409993508349986, 0.059739693383415865, 0.050404701351879105, 0.05400441444268631, 0.012963590467528952, 0.029642309002097578, 0.03720846913394429, 0.060080794031701745, 0.03812478306973654, 0.017648499661816225, 0.05805389009295933, 0.05306315285363986, 0.035391025125019016, 0.048771509149622534, 0.015549288514340598, 0.032767645128431826, 0.005862201036389677, 0.10115400437385806, 0.13181877262409658, 0.13772472829347657, 0.1266230417475585, 0.18673115830507972, 0.17942851709742702, 0.15553729909081615, 0.24841432099140462, 0.19834695113522394, 0.13408418654674484, 0.13103452841601065, 0.08903726665002686, 0.24004617405514564, 0.15510225308037576, 0.17328625394692346, 0.1474110367557695, 0.14667209898752553, 0.2905895603039573, 3.0444574356079106, 83.40369470657842, 89.71957360544513, 94.64970265665363, 68.70880157716813, 54.719178061331476, 39.123355727041925, 72.39814373754686, 80.69071677423294, 70.6899123038015, 52.73624343256797, 1.3764093359631877, 0.4220260090885624, 0.30738358656244896, 0.9873079472491819, 3.9756580225882994, 9.88499943287142, 7.504680166321417, 4.845108245649646, 30.095761899025213, 87.30434279288016, 68.54705087600216, 78.59136227638491, 68.5048383282077, 70.56192536507884, 63.04424009015484, 67.11378543607651, 60.84990932095436, 67.28145891620268, 62.40415634647493, 65.70870222583895, 63.632109242100874, 62.714921812857355, 58.550929715556485, 54.97080203025572, 53.14036523142169, 50.66969171647103, 59.78373066071541, 70.25017538378316, 67.75285720825195, 67.9565066675986, 58.86715512121878, 64.90575382786413, 63.998956757207075, 68.29443454742432, 66.35081383489793, 66.99408254315777, 62.28329243198518, 61.57875630163378, 49.7976743021319, 53.031425322255785, 47.93356395536854, 61.9520757275243, 66.51431391316076, 67.1375471545804, 66.12542660005631, 68.75048068261916, 54.575215308896965, 55.02950814462478, 61.77849123554846, 66.56902313232422, 58.6844511185923, 65.13145092994937, 66.68425452324652, 67.40273860193068, 59.462943538542724, 59.45976641870315, 59.916832370142785, 72.22963087020382, 51.195481515699825, 41.67360236567836, 67.28872314576181, 63.543910826406176, 67.37223825147076, 60.884508548244355, 64.12527668860652, 61.64873923024824, 63.731819814251324, 58.570804365219615, 59.33352493470716, 59.54269316888625, 61.817522741133175, 60.28606860868393, 64.25903343385266, 57.971226938309215, 64.44287492382911, 67.8638602841285, 64.19861324371831, 53.41395839568108, 50.341871784579375, 48.47226227483442, 49.53747603201097, 50.60194846122496, 60.00659581153624, 65.55694180150186, 67.52457526422316, 59.87734586961808, 56.14024493002123, 59.972345675191576, 69.5216735716789, 69.01643306978288, 67.08867442223334, 64.11666316370811, 53.57453630816553, 52.09948193642401, 55.72276746073077, 55.18034681197136, 58.57873147533786, 56.478137508515395, 59.97531883178219, 62.08673069553991, 65.04361729468069, 65.76276817629414, 72.16648855516988, 72.99369289029029, 78.01030235905802, 71.86185375336679, 70.10473389779368, 13.763917588418531, 1.393740451143634, 9.23774951888669, 5.666895297265822, 3.1213616315395605, 0.8753709182623894, 0.18660656176507476, 2.0367690368044764, 26.21176623529004, 74.19286343359178, 87.81924017014043, 90.9258593282392, 111.51353313076882, 47.044331258343114, 39.960099266421416, 48.99736958165323, 69.34043653549688, 71.33791923522949, 85.05713062901651, 20.505625663265107, 0.6522783312586047, 0.3246310449415638, 0.2818390588846899, 0.14359630193681489, 0.17239454292481945, 0.15991624234424484, 0.06556551242547651, 0.09947996436347885, 0.20563427058439102, 0.16823735148195298, 0.15806373449102526, 0.0923705688347259, 0.2632283317225595, 0.13491841033101082, 0.14191032627657538, 0.1426993661950673, 0.1749507791452831, 0.17511464535228669, 0.11423602820404115, 0.14606782415461156], [0.056014307399070075, 0.04323221848256165, 0.053121888814794446, 0.02132033035459538, 0.02927041353447543, 0.01684541735167225, 0.10145460195358723, 0.04778015690164701, 0.009904037353642767, 0.06352725123325664, 0.07982408642889031, 0.012710469271687251, 0.024529993609194795, 0.0777810754915399, 0.009048093061503625, 0.013114869849936617, 0.024885759095571218, 0.049751975288194035, 8.070123657103508, 78.44241419146138, 72.86681205995622, 71.45988925810784, 54.76758010925786, 25.082421725796117, 18.612662361514186, 44.45546104061989, 45.47692075852425, 48.23716325144614, 9.65658805062694, 0.20095070012875144, 0.07533586839394224, 0.4139797569763276, 1.2460898127286666, 1.04399741176636, 4.699643715735405, 4.060453046714106, 2.7267165241702913, 70.68624096532022, 74.04754746344783, 71.41888480032645, 68.04511300979122, 64.79372701337262, 59.16198007522091, 56.19486393467073, 53.709124595888206, 56.576977314487586, 55.45218667676372, 59.311744013140284, 58.151899153186434, 55.93985888265795, 53.31183164350448, 49.331602588776626, 47.18354009812879, 49.53583255890877, 46.53816507708642, 51.46410503695088, 62.95124853810957, 61.81514186243858, 66.1199588160361, 57.41721960806078, 59.121269795202444, 62.2718979466346, 61.91925725629253, 60.550907042718705, 62.6013848858495, 62.9150725180103, 57.74970716045749, 44.70387651074318, 45.091802843155406, 42.66020790223153, 52.0022895259242, 60.78035785305885, 62.87956722321049, 61.084019907059215, 55.50998672362297, 44.59704683672997, 50.95546776248563, 57.2751082143476, 62.261907669805716, 57.572894557829834, 60.046352955602835, 56.82278833081646, 58.28609912626205, 50.430336921445786, 53.419936087823686, 55.4194035068635, 65.4126456476027, 45.05056696553385, 38.13031750340616, 62.10080023734801, 54.386596372050626, 62.767069724298295, 56.96441335062827, 61.39037662936796, 57.906331323808246, 64.88496918832102, 58.61903382885841, 55.48329891697053, 56.15378887422624, 59.806456873493815, 59.345970615263916, 60.06010870779715, 54.296185739578746, 60.26413471468034, 58.685223825516246, 57.77731672410042, 51.97056931834067, 45.81466428695187, 44.34695651454311, 45.93041343073691, 45.562863811369866, 52.41566811838458, 60.605957508087165, 61.50958922601516, 57.32682074269941, 52.9528877042955, 62.17192065331244, 61.868690060031035, 59.70310634182346, 56.90891573506018, 54.16106400951263, 48.14595245545911, 48.28528288872012, 47.46640182310536, 52.86382636716289, 54.69967211446455, 54.407706568318034, 51.98745904430267, 51.43736623948621, 51.167793504653446, 54.89497084771433, 55.37624566785751, 62.019301229907626, 64.10571582855718, 68.83110892388129, 67.86480165296986, 43.925238963096376, 0.5156938022663516, 0.14859657314035202, 2.213391036756577, 0.2977985089584705, 0.44840826923328064, 0.05584250835161056, 0.12485472695721735, 6.147405745521669, 19.456619139640562, 59.66683618484005, 70.32899933476602, 61.89089067520634, 48.95867147753316, 17.03228254472056, 35.379465164676795, 45.451311603669204, 56.316673140372004, 57.79003304819907, 33.97192655071136, 0.357256829738617, 0.0038097392074808844, 0.03319844701177171, 0.09620855442218243, 0.03648545450320648, 0.07819606532012263, 0.01072068325048613, 0.04947390069343871, 0.03203372523609189, 0.0815206034589679, 0.010510328913017387, 0.011914001173159529, 0.017369515337650816, 0.06648919229666073, 0.036394351327251044, 0.03528266964900879, 0.028902495978400115, 0.006301259432333492, 0.027154957492565437, 0.0498201034873003, 0.03167377499442908, 0.03883851271483206, 0.0439374866865335, 0.01425945787735644, 0.06315664853900671, 0.03997727943163726, 0.058294728984155005, 0.023330006891140537, 0.03966513690688918, 0.030480734778628237, 0.07816402752312922, 0.01561544978270127, 0.016131036531841083, 0.053429201155179934, 0.06101811409837777, 0.02661114423385551, 0.06532606398386341, 0.07559670601040125, 11.99002960035878, 91.66145278561501, 79.99780654907227, 79.39809968394619, 60.19485389032672, 35.286191201979115, 22.244104454594275, 39.476623996611565, 54.45252749227709, 50.51754297748689, 12.303050429590288, 0.11644346459257988, 0.0882985663690394, 0.7305136815674844, 2.896573538741758, 4.057670370224984, 5.331781227742472, 2.9107178507312654, 4.1336133403162805, 72.61399961286976, 76.60830605414607, 74.48508785616967, 70.72644525958647, 66.10042541257798, 63.165280511302335, 59.398836320446385, 57.49788315065446, 59.38914022138042, 57.56602256528793, 62.08395365745791, 60.218466558764064, 59.43019959234423, 56.67140445401592, 52.12034894574074, 49.03929971879529, 49.715375131176366, 48.561253009303925, 52.73763195160897, 65.50074208167293, 64.7543542615829, 67.51926437500985, 58.83985934718963, 60.547341608232074, 63.679224752610736, 63.468679766501154, 62.17844747727918, 64.8001047872728, 64.13294492229339, 60.87237665730139, 47.57461609378938, 49.01846801081012, 43.5386658483936, 54.872358383670935, 63.2547733091539, 65.1018488022589, 63.30374410075527, 54.45352769667103, 46.615396545779326, 52.449765282292525, 59.13518636457382, 63.93881505535495, 58.129008200860795, 63.44125063188615, 58.3724069595337, 61.1688764633671, 53.810906179489635, 56.30723199536724, 57.38692322084981, 67.04438301824754, 47.68375604383407, 39.34915873312181, 62.202989747447354, 56.091058408060384, 63.261586466143214, 60.891784544914, 63.325015114199736, 59.994597281179125, 67.71226067696848, 61.48455273720526, 58.678398901416415, 57.6802812084075, 62.8554524913911, 61.796487069899044, 61.119819379621944, 54.98112570854926, 61.61776427299746, 63.039407730102546, 59.290422008883574, 55.25042779984013, 46.30653342893047, 45.987601587849284, 45.71252576766476, 48.72036003297376, 54.038003567726385, 63.90862849450881, 63.634192020662375, 57.73897163329586, 53.865085878679835, 64.1908077270754, 62.93087966980473, 62.08249453575381, 60.76751209074452, 56.154628261443115, 50.134492151198856, 51.00761959629675, 51.31208181381226, 55.250549393315474, 55.373468629775516, 57.824451846461145, 52.92257954997402, 53.14458962409727, 55.40998981844995, 57.04153107058618, 58.25549287180747, 65.76896159879624, 66.96079730987549, 71.68042059867614, 69.37886007370489, 48.966539752098825, 0.9400848779947528, 0.08774887530073043, 1.4035938127386955, 1.811412445479824, 1.4314276869258573, 0.305508601689531, 0.18927642414646764, 3.9197647379290674, 26.93353529899351, 62.23183878006474, 76.60415618650376, 64.74656835679086, 52.29050920855615, 20.434728822400494, 44.62887294830815, 51.40346911645705, 63.689120892555486, 65.46866101603355, 44.57614060371153, 0.44573725772000133, 0.025254331656821796, 0.035360615264864705, 0.045555744004706224, 0.028404919956360134, 0.0418677929067804, 0.04341537861393825, 0.00980795460617951, 0.01676407796631177, 0.06921731566469516, 0.11201835688083403, 0.011661935263433525, 0.01872217380291512, 0.029343737724928126, 0.06662008607940328, 0.05164915755871804, 0.03460081309200295, 0.025861900667810155, 0.038481584690030546, 0.0360787958808003, 0.1870222563945478, 0.10932401032938112, 0.1159025758745209, 0.21075552239293055, 0.11760124561166573, 0.07289504331927146, 0.16302510374976745, 0.1317402945771333, 0.1439377473246667, 0.18746450363147646, 0.16404275962662312, 0.15048628222317467, 0.13066404829582862, 0.19336285970864758, 0.17829052412942534, 0.1826637676886974, 0.13148192376379045, 0.18793290511014002, 15.584539636488884, 104.44173505229335, 89.9179200203188, 88.94097528150006, 68.96429692545246, 38.59399657095633, 28.526754994546216, 59.1804858176939, 58.355372105875325, 67.69883048149848, 14.96183983741268, 0.3359323127135154, 0.25485358110839323, 1.2920227286315735, 4.7592961019085305, 4.51431417657483, 13.861245320689294, 10.807911561381433, 3.9319005512422134, 76.90144831134428, 77.6859066563268, 79.21718428211828, 73.73084745099469, 72.87491567673223, 66.30763638404109, 64.89266880096929, 59.22287879451629, 62.93230349017728, 60.17299844372658, 64.63280000994283, 64.50108289718628, 63.13277190731418, 57.965841524062625, 55.04568007684524, 51.771991483626834, 52.48748279386952, 51.020430057279526, 55.33906159862396, 69.8608644547001, 67.16447030344318, 69.49541722574543, 59.37219950460619, 63.121922631417554, 66.31115867245582, 64.41225690226402, 65.03736503662603, 67.4209148653092, 68.80260898220924, 64.27425223012125, 50.79003003335769, 49.48848955092892, 46.23124745584304, 56.40906456978091, 65.04657083942045, 66.83793298659786, 68.24708369470412, 58.73126460659889, 49.7094052837741, 56.38029398456697, 63.86617668213383, 65.50438988593318, 59.46892907542568, 64.9022158499687, 62.10707995199389, 63.52714269391952, 57.18206174911992, 57.74827941771477, 61.990189398488695, 69.51746094611384, 51.84561044939103, 44.17261892749418, 64.36871074861097, 58.407641610791615, 67.5118040269421, 61.03418619401994, 65.82391400491038, 62.082773024036044, 68.75836464666551, 64.5960513237984, 60.208786149178785, 61.934656481589045, 64.39128006658247, 64.40214503195979, 64.4641302477929, 56.573180460160785, 63.53516001855174, 65.08914032290059, 62.59605438478532, 59.24194151355375, 48.489654064178474, 48.25890102694112, 49.32285570329236, 51.238874696916156, 56.00669999276438, 67.64942430680799, 66.2725390157392, 58.62283852792556, 54.95575974064489, 68.09283256530762, 66.20345038752403, 63.616917902423495, 62.28104883624662, 58.36961030960084, 53.655627389107984, 53.67941264183291, 53.27831891275222, 57.76747941970826, 58.972780627589074, 61.28773604669879, 56.985633373260505, 54.64649654203846, 58.81445415558354, 60.822468419228834, 62.67071277864518, 67.48539078620173, 70.73402327875938, 75.5667834128103, 73.53887881002119, 49.6674241558198, 0.9529947465465916, 2.2144885649604182, 9.31367778008984, 2.990559166477573, 1.3307747653415127, 0.3521906902953502, 0.3248527201433336, 9.099647768082159, 32.21455566344723, 67.7372932434082, 75.80196088360202, 68.05899035546088, 60.38265305180704, 27.63308805804099, 49.744757606137185, 59.795011397330995, 72.40935387149935, 74.72599198741298, 53.5785920389237, 0.6466915278184799, 0.16515726433886638, 0.15123746207644864, 0.23015498303838317, 0.14337142448752158, 0.12102696098267071, 0.13999642413710395, 0.15893099198658622, 0.17367640720500102, 0.1546263592618127, 0.2042205625724408, 0.13403897203745382, 0.10493970446048245, 0.22514318987246484, 0.14813600108027458, 0.14028632712941017, 0.11197152592602277, 0.11395503481429432, 0.24925648144656615, 0.1676154413050221], [0.052170986009220925, 0.0630457534815275, 0.09341848518459067, 0.028329829933241974, 0.02961969600179263, 0.08001983721530245, 0.0257560464688727, 0.030210794122408957, 0.021607829746039166, 0.014853269864444532, 0.03319840487693587, 0.04717312032176603, 0.03821104457001052, 0.05327105762497072, 0.057428632111799334, 0.07594292412602133, 0.05133702652528883, 0.10498798332147061, 34.50035610506612, 72.98827217471215, 64.83478246196624, 65.15243561037126, 57.84869209412606, 35.7301603594134, 44.33407937326739, 43.65853740322975, 33.87620502902616, 37.18347303328976, 0.6431194743321789, 0.10476506705726348, 0.06414699721180143, 0.4517071357657833, 1.177430438899225, 3.4740763566186352, 3.83641044939718, 1.0180250086611318, 26.168096526976555, 83.17160021874213, 66.66386604309082, 71.99843068276682, 65.07157594926896, 65.45943560138826, 55.898187621947265, 55.18130779266358, 50.51243997389271, 51.02448971040788, 47.90202809918312, 53.44066189181421, 50.041932059872536, 53.75978985140401, 46.44425176805066, 47.803945310654186, 45.823309190811656, 46.95056307700373, 44.553343788270034, 52.611198271474535, 60.91705245356406, 64.87090749125328, 61.461355840006185, 60.92327333265736, 63.49412810417914, 63.30162209849205, 61.09182542370212, 57.528054022019916, 58.18488236396544, 61.05743015966108, 56.509018328882036, 46.29156174198274, 45.3923426904986, 45.251851235666585, 45.77087102397796, 53.89105589159074, 56.13713449047458, 53.588252836658114, 46.847381207250784, 46.15496520073184, 53.31251805828464, 60.927419277929495, 59.84506084072975, 59.6190970174728, 61.58081554597425, 58.54255937760877, 55.23025112767374, 48.5388994216919, 53.003827525723366, 55.59383915316675, 65.58149976115074, 46.01447374589982, 34.1303510819712, 61.8820692646888, 56.47288937722483, 59.878106809431515, 56.494293751255164, 61.61244161667363, 54.761327851203184, 55.895853811694735, 56.516051138601, 61.52810673559866, 59.48292016983033, 60.497672634740034, 56.91078670563237, 60.28115780122819, 53.111633869909475, 56.77899506784255, 59.84172682608328, 59.155798419829345, 53.13997299440446, 45.41167605307795, 42.89804081762991, 45.45648913229666, 43.70302492572416, 47.83866220904935, 55.10968923568726, 61.87753892713978, 57.88522897228118, 56.451037852994865, 61.88342640476843, 59.444779042274725, 55.922153303700114, 53.90344273659491, 46.345447263410016, 47.793401979631, 46.24421088926254, 49.600488908829234, 54.80785892855737, 57.386695723379816, 55.97899236986714, 55.68704251320132, 54.810741870634025, 55.097706394810835, 56.44245178468766, 59.14718489493094, 62.64056544150076, 66.19311101974981, 68.36061277697164, 64.97238312998127, 66.21637067487164, 15.050243196948884, 0.6729465867242506, 0.856577126729873, 1.9465486392859492, 0.9443904147032769, 0.14549898854907484, 0.03974567189992916, 0.023042806273987217, 19.773634902892574, 29.901479059650054, 50.97098465888731, 67.76103142769107, 75.05196448295348, 50.30838651041831, 21.054478999107115, 46.39471223277431, 50.25764672986923, 53.782512141812234, 52.68182839116743, 4.633391451451087, 0.3337367966530785, 0.07171675412645263, 0.0984996322902941, 0.020544580146369916, 0.02185421702902644, 0.019561028588683377, 0.05866807810361347, 0.04682202988694753, 0.024114630312748978, 0.0337253239816956, 0.07732625675177382, 0.025839458122068358, 0.08449214360406322, 0.06115127933181583, 0.042872222275623394, 0.038106630616370714, 0.016575020873138023, 0.04622021036583089, 0.03575726877897978, 0.07388780899946729, 0.09604839608073236, 0.07682439255257768, 0.0314041024689833, 0.08216766430245293, 0.052066001320077535, 0.03608521952804539, 0.02126931464449773, 0.03407490522330327, 0.022570926756147417, 0.02564640588036949, 0.04513167603422077, 0.07398765323863876, 0.07491419827865978, 0.016243695506765958, 0.0648337452402038, 0.06453282590354643, 0.06387353829678989, 44.78309269874327, 84.36502841211136, 72.13943204572125, 73.07962417602539, 64.25673100256151, 40.986983622274096, 29.263556541935092, 37.96999454498291, 35.43675530341364, 40.8033460955466, 0.817953608930111, 0.09762679001376515, 0.17811769469370767, 1.3539014275996917, 3.2870146007307115, 5.201349181513633, 3.1674914013954902, 0.9336318436168856, 28.711732010687555, 86.4717020527009, 69.14078789372599, 72.7280621374807, 68.27366951973208, 68.64743217345207, 60.396891255532545, 58.211832969419426, 51.59427673585954, 52.26902638712237, 51.82945812902143, 54.89359017341368, 52.60648358252741, 55.935081435788064, 49.68904426020961, 48.511152575092936, 46.740088693557254, 48.66793363325058, 47.17590324340328, 54.731694344551336, 62.40690985033589, 67.11949640704741, 62.729575787821126, 62.732443040417095, 64.64464164549305, 64.35222110440655, 63.82097136589789, 57.44095779234364, 60.20300065317462, 63.946043983582534, 59.46546954493369, 47.11450246072585, 46.46733099414457, 46.731337885702814, 47.787655707328554, 55.84246643127934, 59.340165507408884, 56.529575470955145, 49.75927429814493, 48.44103236352244, 55.11319583462131, 62.567746639251716, 62.55461846628497, 60.966086003088186, 64.10997944493448, 60.59988960143059, 56.886279736795736, 50.100963730965894, 55.60822248458863, 57.956765159483886, 67.13277755245086, 50.82692776956866, 37.29882994005757, 62.87447206435665, 56.93444644251178, 61.80897197415752, 59.774097319572206, 60.37576144741428, 55.24169268146638, 55.62968961654171, 58.18007353813418, 65.40100797530144, 60.803154668500355, 62.82259871882778, 59.13714754965998, 61.2538585355205, 54.47066453195388, 58.33999641479985, 60.992330581911155, 61.96588639290103, 53.93663775536322, 48.16109672669442, 44.595026816091234, 45.64812044943533, 46.4156969131962, 51.105682772974816, 58.694284500614295, 64.55008114537885, 60.13865809286795, 58.0581662731786, 63.916253582123794, 62.17226189951744, 58.68118378423876, 56.207811678609545, 50.96433231907507, 49.75519503316572, 47.342804016605506, 51.810752345669655, 56.23609588992212, 59.181599770822835, 56.336814511206846, 57.79459476470948, 58.675476735638036, 57.08901136152206, 57.883973813826046, 62.7007620565353, 63.77839796004757, 68.31609387551585, 70.02332902723744, 67.4810448000508, 65.9115005308582, 18.057780342717326, 0.43217725631210113, 0.4648130921827209, 1.7364394039877, 2.1092143558686782, 0.9864301943490583, 0.186756944824611, 0.3220778577510388, 20.225254643347956, 36.790118140559045, 54.580887056166134, 72.48456139718333, 73.19571848838561, 54.530559124485144, 32.73007473637981, 52.275227654364805, 59.19903862860895, 60.135108347862, 65.34775003310173, 7.404772985366083, 0.22063436407235362, 0.017296809763196978, 0.08959759101872483, 0.07988095313550965, 0.09899354449683621, 0.0561077356518757, 0.042923063700718266, 0.06912461136497798, 0.027135479707090605, 0.10046851656009113, 0.05932982868304657, 0.014268217135160683, 0.04376721981492254, 0.06613631687697864, 0.06942120996574241, 0.03030754528158615, 0.02406960157977958, 0.0634097678196286, 0.010892293648794295, 0.21463034914866572, 0.17195981867130727, 0.2520258433275646, 0.16452943996316002, 0.12380932337574421, 0.22777313907300273, 0.11147503200317584, 0.1663923053251159, 0.1641789700595602, 0.20085173689069288, 0.08760220776762694, 0.24172361549590868, 0.28191027441813105, 0.19934965297579768, 0.12577897373346553, 0.19745448934695414, 0.17550536551542822, 0.13933138321003607, 52.52581611756356, 94.11721737154069, 81.81311084378152, 83.88693071180775, 75.39747822669246, 48.61482474111742, 62.03364141525761, 60.930572863548036, 47.203069579216745, 54.02490677372102, 1.4900303487816167, 0.3125499609497286, 0.29525466804062167, 2.218932365217517, 4.563639452380519, 11.965073520137418, 12.00730077682003, 4.316255075316276, 29.19685663715486, 90.06788792148714, 73.39283327902518, 77.5304788158786, 71.08163156817037, 73.77652737402147, 63.57497599817092, 62.173768089663604, 55.19159616962556, 57.074973198675345, 55.90438496681952, 59.85735354884979, 54.8425954388034, 59.23583830556562, 51.90230831023186, 51.7245739506137, 50.730362938296416, 51.57751252574306, 48.19322486077586, 59.459433017238496, 65.30376065161921, 71.19818872021091, 66.19807674038795, 64.52849241995042, 66.19886121442242, 67.64805147724768, 66.32366318856516, 59.22947622114613, 61.023462433968824, 65.84538505923364, 62.62247154789587, 49.38244435095018, 47.918980583067864, 49.409265518188484, 51.03778262292185, 59.24018429171655, 60.7871513981973, 59.243714424871634, 52.31829527885684, 51.379895671721435, 57.59716226208595, 66.75141334533691, 64.06320518062961, 63.13503119253344, 65.64060203490719, 63.24698740436185, 59.08549777923092, 52.92815323798887, 57.73965412570585, 59.9199898781315, 68.38819488402336, 53.163036531017674, 40.680536685451386, 64.60981884310323, 59.97345962832051, 64.30707070135301, 61.44562321324503, 63.49318673533779, 56.85691687368578, 56.67094553670576, 59.771332048600726, 67.40113043016004, 64.74043376984136, 63.3762530357607, 62.16942994825302, 64.79785334679389, 54.46905636018323, 58.46883843022009, 64.89841115090155, 65.76165814553538, 57.65382482159523, 49.4721842581226, 46.826788763846125, 48.877666688734486, 50.415859453139774, 53.56920188473117, 59.95378109716601, 67.30311039955386, 61.2074137503101, 59.63082098191785, 67.55301244797246, 66.08383378674908, 60.62256874576692, 59.19619098786385, 52.205483990330855, 51.97122043178928, 50.83796531923356, 53.924097937922326, 59.1534528424663, 62.76131560725551, 60.08507851631411, 60.79835760977961, 60.991067578715665, 59.56510559205086, 61.5261455505125, 65.30532567731797, 68.51071403872582, 71.74305300558768, 71.47745363173946, 69.25613695575346, 68.74430687196794, 20.349038762430993, 1.0667649320056363, 5.50320694523473, 7.894377448866445, 3.4325043809029365, 0.5605623462507802, 0.21249875546463076, 0.5443636928835224, 29.264803855649888, 44.85768048994003, 59.125921726226814, 75.52766953745197, 82.79305227341192, 62.97237050148749, 32.323275919883486, 60.03393080926711, 68.77068088900658, 68.99120438483455, 73.32380740873276, 9.806907984518237, 0.6184615555309481, 0.22745527387146028, 0.22860051403122567, 0.24773512275949602, 0.13295720992309432, 0.11556614070169388, 0.24565902448469595, 0.1652440008136534, 0.0723240013805128, 0.13033384907870524, 0.18042470719064438, 0.13478857374960376, 0.16671878135492726, 0.16532459326328772, 0.16846057418132984, 0.15708997545223083, 0.1496223189056881, 0.22049308213735783, 0.08130711007622943], [0.00972483981205451, 0.0028714603338871273, 0.026196882188800844, 0.030692418278645606, 0.03733200081173451, 0.054646851945548296, 0.08021452313949985, 0.06580744299196428, 0.07455108792430933, 0.02853585587393853, 0.05785136708929654, 0.02213407852386515, 0.042764912509629806, 0.0612081345471163, 0.02085673224721705, 0.06377457505873134, 0.11597477200050509, 2.6828489813112446, 57.54566546409362, 67.95714993630686, 71.0808470941359, 67.23306471301665, 38.04005199863065, 25.884668019510087, 48.0183812879747, 38.88556988008561, 42.70293820288874, 16.39903353106591, 0.13945061713457108, 0.054603296016613324, 0.4244068264961243, 0.29172153182087407, 2.0493550646689633, 3.8238238086623535, 5.106014013290405, 1.8061033948775262, 72.02154128782212, 72.63215234202724, 71.00128573756065, 65.8675072270055, 68.69856419101839, 58.46420218867641, 55.401909735894975, 51.45569939767161, 51.790285418110514, 48.8301589412074, 47.785980855264974, 46.50442484886416, 48.71702994069746, 45.39348017784857, 45.24326908972956, 47.73523322997555, 46.818798895805116, 45.64782234930223, 47.14195120719172, 49.633778064481675, 61.6512534695287, 60.87342000776722, 61.19674098107123, 60.73404642843432, 61.650186584841826, 59.015153992560606, 62.7980133025877, 61.42324609141196, 58.2290639415864, 60.04446629554995, 57.063119796014604, 45.18940318015314, 45.28313213779081, 42.755427360534675, 45.53991010112148, 44.80635627623528, 46.45199060440064, 44.625515399440644, 45.48683258794969, 47.35156659157046, 57.716394470584014, 58.850971421887806, 64.77747271137854, 58.518460335270056, 60.52931831729028, 55.763960192280436, 51.46639570113152, 45.178789246466856, 52.49903417402699, 53.256330105566214, 61.67396399282641, 45.267987866555494, 43.19476027642527, 60.5176257318066, 55.071340222512525, 59.93081561980709, 59.803424881350615, 60.30598640441895, 60.01302457624867, 55.62241754224224, 53.43494307610297, 56.583060910624845, 56.45658800678869, 59.476154081283084, 55.16657144792619, 61.17461881329937, 58.81157121350689, 53.770686195742705, 58.171310963169226, 60.621199838576786, 55.15267841277584, 46.88998599206248, 44.056724656012754, 46.22836059139621, 44.80155137277419, 46.08069512151903, 51.91931178492885, 61.027612301611136, 58.641281512475786, 56.95065759843396, 61.08332172516854, 61.19809812115085, 54.085495625772786, 49.30244368891562, 45.62371938459335, 48.75453564428514, 46.95373235210296, 50.626679005161414, 56.13131761550904, 61.471428486608694, 59.203510130605395, 58.09703696158625, 56.747023828568004, 58.79420688075405, 62.770364515243045, 63.471225384742986, 65.7570219039917, 66.91293654903289, 66.8750778321297, 64.52185576961887, 53.764696736489576, 56.02299351846018, 2.4267537555386944, 0.6900265476396007, 0.9876532383984136, 1.7638230636235208, 0.7754340743826282, 0.10434621614554238, 0.10799657147858413, 3.885077992754598, 33.10122313037996, 33.83673029561197, 63.85674730423958, 71.74325696883663, 34.863285172370176, 16.6731366034477, 31.522877062520674, 49.45804803602157, 51.65852908165225, 63.759401921303045, 18.234385059725856, 0.1627606808418228, 0.08112071322337275, 0.03919146091286694, 0.02409721904944989, 0.042018830971491915, 0.005050528965394704, 0.048626496366435484, 0.025251828464529207, 0.03291145132313813, 0.006574768143060107, 0.057019931865074945, 0.011707440886135784, 0.03058156727122203, 0.05122973974193296, 0.017074531267186808, 0.03880692307927436, 0.03364497284975744, 0.07251055911183357, 0.01453233935359505, 0.02042632106871855, 0.025478002517634345, 0.03675667644147912, 0.02564321895460448, 0.06092617205614525, 0.07111139144868621, 0.0486725842159602, 0.08976004762394775, 0.045047904319700696, 0.025163942857855753, 0.035734255497734395, 0.11128228428142686, 0.06432844130622764, 0.09226954482015103, 0.023865138458448554, 0.056386112851361116, 0.2002821045537149, 3.7404935446477707, 71.10656999772596, 76.9745534466159, 79.31499250473516, 74.06505692389705, 48.447508196676935, 30.840027716852006, 47.243093444455056, 40.16903215839017, 49.076554390691946, 24.81772057471737, 0.09910917014724786, 0.0353663953982534, 0.4878883959064561, 1.6123235994769682, 3.8221531241170825, 5.281904368631301, 2.496284140694526, 2.886343507036086, 74.2437130405057, 76.17679042200889, 73.9531752371019, 71.07923107762491, 69.77075192236131, 61.74263684980331, 59.12835751810382, 54.51798008334253, 54.37546076313142, 52.08119976905085, 51.21581900504328, 49.58470136888566, 51.2824639966411, 47.94317768466088, 48.72375680554298, 47.76100712437784, 49.540606083408484, 48.03212135068832, 50.41989164967691, 50.701643343894716, 66.67597832218294, 62.56258872247512, 65.30077965028825, 62.33709950600902, 63.433268608585486, 61.90108099291402, 66.6219045269874, 62.451264012244444, 60.488933593996116, 63.941101797165416, 60.56718487893382, 48.84424809486636, 47.926711574677505, 44.866760776888945, 47.4904812535932, 45.730231346622595, 48.68910658744074, 47.403812562265706, 47.562684243725194, 49.48062127636325, 59.556790167285556, 62.67166199222688, 63.90249782992948, 59.77906304021036, 62.63324629875922, 58.3771098813703, 55.242418319948264, 47.36796994363108, 54.15342715478713, 57.94187584230977, 65.11663221543836, 46.91148058060677, 46.4053261664606, 63.036662070981926, 58.45101518015708, 62.38480337204472, 60.621866641506074, 62.001242637634284, 61.49604528181015, 55.71516198496665, 55.01600734649166, 56.49114016563662, 57.5505841162897, 60.29306611707134, 58.88036174158896, 63.91023666627946, 60.092350590613584, 54.60621380036878, 60.51474278972995, 63.84773369758361, 57.53238039631998, 50.2331829071045, 45.979113578796394, 47.57441605291059, 46.51843947748984, 47.97213262127292, 53.4002967803709, 62.081129550933845, 60.11201735465758, 58.34388348364062, 63.120514500525694, 64.41371602396812, 54.916838061425, 50.93817403239589, 48.02889324003651, 51.442936005130896, 50.273202849972634, 53.6084020522333, 59.09577831145256, 61.96643160235498, 60.791014932817035, 60.571711294112674, 59.39313711658601, 61.354706595020915, 65.82608699798584, 67.482347026948, 65.734425129429, 70.37132170892531, 68.53483661528557, 68.41235668428483, 60.009549356276, 62.22539040350146, 3.246260439195941, 0.37094734188529754, 0.4728191706442064, 2.7840730980519326, 2.119937135327247, 0.25773155893529615, 0.04407409931563082, 2.3884667648423106, 40.75161395534393, 32.735838659348026, 67.5929186421056, 78.14358449751332, 38.973297611359634, 21.354120623680856, 38.36429472892515, 55.67026653597432, 59.62800079776395, 71.6114810205275, 25.557269742411954, 0.15782833099365234, 0.12167727003895468, 0.02540383371524513, 0.041655008155371875, 0.04073014850878427, 0.03848647233098745, 0.03308153433364726, 0.011675518002331017, 0.03906920094103102, 0.028569423931560693, 0.06715177408149166, 0.053036454689478686, 0.02875711930344903, 0.014478648081421854, 0.0649098637363603, 0.02326304123045937, 0.023313526424669453, 0.024824163711239255, 0.05427225410277325, 0.0804219414449988, 0.10559774334392241, 0.10632873678039159, 0.08651245535621721, 0.18468784859343884, 0.11257084417006663, 0.24476506116409458, 0.23706284381689566, 0.15382959717704406, 0.12567497729774446, 0.1870352492457436, 0.2043752510461115, 0.15432884135553915, 0.20775624220409702, 0.24859819741499042, 0.18250947758074731, 0.27697394091275435, 5.916246742971483, 80.93431165141445, 87.72001204952117, 90.77108260123961, 85.20869885721515, 54.79100058155676, 35.19250931278352, 64.82584730271371, 51.38657939049506, 61.81205495711296, 30.176598025906472, 0.4438750205501434, 0.12156532161057958, 1.001436692332068, 1.6072628839362053, 8.154062378791071, 12.66206399086983, 12.397410888825695, 2.8967218533638985, 79.49314655796175, 76.42159338920348, 76.72833058141893, 73.37302530965498, 74.7858944246846, 64.1359063117735, 63.68937976898686, 57.51223118074479, 58.92245269590809, 53.99456331806799, 54.19803627075688, 51.57333912387971, 54.481443205187404, 50.23712881149785, 50.75929434068742, 50.442053041150494, 51.72560553396902, 50.84809680138865, 53.360672996890166, 52.959755774467226, 69.6787017391574, 65.84816209731564, 68.44412003794025, 65.20389710703205, 68.05054941485005, 64.76569775612124, 70.60068622712167, 64.804639047192, 61.053966706798924, 66.354092936362, 61.82412409013318, 49.928744223810014, 50.196967663303504, 46.90975081536078, 50.96496382067281, 48.96189174344463, 50.008580146297334, 50.299690615746286, 50.18798935797907, 53.125538672170336, 63.26640705908499, 64.7084625305668, 65.57103095516082, 62.929659812681145, 66.45516457096224, 62.370871113192656, 56.986029532647905, 50.30818646953952, 57.8300412239567, 60.40617942810059, 66.03467864374961, 50.66480444323633, 51.16948404619771, 64.74420316757696, 61.20624488399875, 64.11268195798321, 65.50959879352202, 62.90662373265913, 64.78268554133754, 58.53172579119283, 57.9605737809212, 57.540127077410304, 59.012588762467914, 63.367910154404186, 60.70689578210155, 66.87688212240896, 63.868655620082734, 55.46453429806618, 62.34295168230611, 66.20316797687163, 60.32472748910228, 52.00239542991885, 49.222607766428304, 50.36679844702444, 51.477723506189164, 50.49659359839655, 56.81342563321514, 64.88021919804235, 64.93916457699191, 59.802746311310806, 67.9268535490959, 66.45052048467821, 57.43164608555456, 54.16688872921852, 49.91476881888605, 53.97447293804538, 52.62390282846267, 56.54233101875552, 61.96447433963899, 64.82487455491098, 64.67781313004033, 62.04826793363018, 60.63149606027911, 63.993198717794115, 68.76405208341538, 69.79863997428649, 68.91284327353202, 74.62701489848476, 73.48387933546498, 70.41825679040724, 62.485706344727554, 63.99683083257368, 4.061690554503472, 1.5447872492574877, 7.897335406272643, 6.007936558415813, 2.20085195476009, 0.37181357282303995, 0.2768256875776476, 5.58054284703347, 47.54258994133242, 48.270923091519265, 68.59962632579189, 76.48556724671396, 42.57582203034432, 24.11640274909235, 46.16861504893149, 63.820998822489095, 66.27177807592577, 80.3999436286188, 32.473402677043794, 0.339588972950174, 0.18826192455186, 0.1571070592129423, 0.13746237382292747, 0.0983353523958114, 0.11838035703065897, 0.1955330642240663, 0.12364625390018187, 0.05939280494086205, 0.23069708217536253, 0.2714572804829767, 0.14903034744483812, 0.10631012850471082, 0.15006160904322902, 0.09392488462429854, 0.1166637991404822, 0.07829027881305065, 0.15876217685159177, 0.14781600615430265], [0.030186041821575457, 0.048959744613497495, 0.025918225367223064, 0.03979068339592026, 0.001906083374295474, 0.04184084576404384, 0.04471775872873203, 0.0442477714480652, 0.09437287752065929, 0.06938542599879927, 0.04567694677520664, 0.039019313295401876, 0.04474274468638244, 0.04075398150410864, 0.0798149929652291, 0.13040511057742182, 0.15568089461134327, 18.836876807674287, 80.6416557681176, 64.02573477837348, 75.28452965521043, 46.355108061144435, 42.43338900227701, 33.40440273284912, 37.90703658134707, 36.26697986356674, 28.352309542317546, 5.108154156515676, 0.21382728982115948, 0.11744530841467843, 0.21588115622439694, 0.4723402737609802, 4.266088451108625, 1.9690382841133305, 3.1875852134919938, 22.073116571672504, 80.12034139325543, 68.2679977724629, 75.16933748798986, 63.182907642856726, 62.55437527933429, 51.75330138975575, 52.39723297857469, 48.073867136432284, 51.343421551489065, 49.114299358860144, 51.27680401648245, 44.75190201113301, 48.29812472866428, 45.963318194112475, 46.28300705263692, 46.69493829050372, 47.3465734143411, 42.8398249995324, 46.103123234164336, 47.78913836325369, 60.61425332100161, 61.58981346314954, 63.68532011585852, 58.27632850216281, 58.43030114327708, 55.983605077189786, 58.25569291268626, 61.191630132736705, 60.44449706231395, 58.30418125275643, 55.583884177669404, 43.61707010576802, 45.998258667607466, 44.6332581581608, 44.61661161914949, 45.60349564398489, 45.07113979708764, 47.11909163382746, 45.837821960449226, 51.7295475159922, 61.76677903821392, 60.100693471970104, 59.56445055623209, 58.26025070682649, 59.58311319351197, 50.98692517126761, 48.4146426570031, 44.53670901636924, 48.22841244359171, 55.35039332605178, 64.29118510215514, 49.1634270452684, 47.18011979133853, 61.95791221434071, 54.18166429765763, 56.57872276921427, 56.27247979564052, 59.96173566387546, 56.492065844997285, 60.8636180047066, 59.65002490628151, 53.13453658934563, 55.6821709294473, 58.84146751896028, 59.2079580983808, 56.032599403012185, 58.47074862449401, 57.09747583635392, 51.78306825699345, 58.2787250703381, 58.27910946261499, 47.25289544751568, 43.0404777680674, 45.38194448717179, 43.59565788699735, 44.46281940706315, 47.25908887001776, 57.28788337399883, 60.749331904995834, 58.68567882045623, 59.57074203798848, 59.222141388923895, 55.798124036481305, 47.848679942469445, 47.269373324609575, 46.96100442640243, 48.29482209297919, 51.6131551034989, 58.864417306838504, 60.30784560788063, 62.78531659033991, 57.62859613664689, 60.16648730924053, 60.69893729302191, 64.93270051094794, 64.21982934398036, 65.99642768982919, 64.05055161445372, 66.1932679145567, 61.773631418904955, 61.817224641000074, 61.78449638428227, 44.201150248127604, 0.20050937219733195, 0.5954593672387062, 1.0808917159034361, 1.7894074585168593, 0.2596016102019818, 0.02130154587869202, 0.11617738693471878, 22.504914614462084, 41.06617235368298, 20.68346396569283, 21.079639042577437, 29.73482147339852, 26.447233961474513, 29.91214398414858, 57.79371615379088, 54.23772673453055, 60.30470771174277, 39.44336229755033, 1.1679081498615205, 0.05243881034754938, 0.05538038496348647, 0.07861371347380262, 0.09018052264206833, 0.06550626318541265, 0.020926731616078366, 0.05342249022496324, 0.019148572595910202, 0.04885814220253979, 0.042308055975985144, 0.02495370151835584, 0.08194424242021577, 0.035748868624890046, 0.07626547778566038, 0.07092618203211216, 0.059672576420369654, 0.01138293944794925, 0.01920564997670872, 0.008571646702025206, 0.011174704301201049, 0.016642871365371733, 0.04036778892059961, 0.03297711654956783, 0.040545555792989275, 0.0316414728971018, 0.0067852445757917825, 0.03999572682885393, 0.06467488158734576, 0.029314155239732038, 0.04621587813861909, 0.040230904330289176, 0.044387283719955914, 0.05284491355621046, 0.11214810153169018, 0.09077115344905085, 25.239532263048236, 88.95870439467892, 71.84512876695203, 82.76078685637444, 60.15261388594105, 47.96351909637452, 41.016456311748875, 45.856457141137895, 36.305905465156805, 37.17926433009487, 7.351975921661624, 0.18528608665350946, 0.0993765807980972, 1.2545607839861226, 2.6194816202886644, 5.947573732945227, 3.5318724811077122, 2.2377119381581587, 23.174178831038937, 85.26696958849507, 67.57461686288157, 78.10276831350019, 66.61060810089111, 65.74902419121035, 54.1887245639678, 56.23393858632734, 49.86453110171903, 55.447797544540904, 52.20728043586978, 56.178746915632686, 48.317948387515166, 51.9942133657394, 49.311355313947125, 48.40589184914866, 47.68903555408601, 49.56887068287019, 44.919908892723825, 47.787298771642874, 49.720258482040904, 62.42834168095743, 64.95115134023851, 66.31576353503813, 61.497578928547526, 61.05544936272406, 59.09173827017508, 62.01982290514054, 61.70993604967671, 62.75759720033216, 61.339570168525945, 57.53029761775848, 46.809318527098625, 47.17164747176632, 45.97281425229965, 47.63746030869023, 47.88215344951999, 47.00799442106678, 48.06504572591474, 48.29779917193998, 53.13747052223452, 63.119816318635024, 62.619827870399725, 61.79753434273505, 59.82550782542075, 61.36604616718908, 52.12494988595286, 51.80476288641653, 47.805930029961374, 51.18216899133498, 56.90056893133349, 68.20007801055908, 49.70823641746275, 48.194703594330825, 64.73600933628698, 57.754296333559104, 59.17932871849307, 57.71283688083772, 60.89209048978744, 58.383468043419626, 63.373566212192664, 61.50814971616192, 54.40369790600192, 56.50571569319695, 62.557356280665246, 61.09151555645851, 58.17506859379431, 60.50249715005199, 56.45653701597645, 53.20370758733442, 60.379613214923495, 61.13150804273544, 50.31285801241475, 46.16705002323274, 45.333750324864546, 45.05628185887491, 45.8990893825408, 48.298713084190126, 60.07891255040323, 63.53126118260046, 59.55657835929625, 62.72789701338738, 62.36387360480524, 58.97635390681606, 49.109215967116825, 49.74824851559055, 48.74526708356796, 50.124297911121005, 54.203323625749164, 60.634661413008175, 62.28521831573979, 66.00162875267768, 59.58170898499028, 62.76586163428522, 61.85640519665134, 68.40903835911905, 66.06058982110792, 69.13763430810744, 65.0419032189154, 69.15433576030117, 62.28497905115928, 62.642271672525716, 65.86178841129427, 49.78044332996492, 0.37586228621582835, 0.3377264906321803, 1.3112747020298436, 4.482710169207666, 0.9546138886963168, 0.15938998590553963, 0.33136774635603355, 23.260914202659364, 48.31323369856804, 21.770733210348315, 19.27711186870452, 26.700105244113555, 29.6138830338755, 35.96667928080405, 62.86668223719444, 60.38355519694667, 67.66583550360896, 50.34759060029061, 2.1634153829466913, 0.056641246943223866, 0.015991477337065005, 0.027524571933393038, 0.03667908705650799, 0.045206361945958874, 0.09950655527533063, 0.032242403756226265, 0.05666763101133609, 0.053128078805222634, 0.06707776998800617, 0.03627965264322777, 0.057900523120958, 0.023497929533703193, 0.0328198118856357, 0.03762917014800253, 0.10656270003246684, 0.060183537913666624, 0.11200478946369503, 0.1554844390240408, 0.15757132381681474, 0.08972398786535186, 0.20396134906238128, 0.13559022347532934, 0.1594703791723136, 0.22429229601496653, 0.11259510617462859, 0.13451187811311216, 0.19944478577423483, 0.1170958957124141, 0.1836162601267138, 0.10686972508988074, 0.177306545477721, 0.31311230012966745, 0.2854874453717663, 0.24242760433304697, 28.763217041569373, 100.4938224054152, 80.9313149606028, 92.8642789779171, 64.60639069157263, 57.216774725144916, 47.978239751631214, 51.61832870975618, 51.41230621645528, 43.546945971827355, 9.715705033271544, 0.382355249096309, 0.4905301428610279, 1.0106855799113552, 5.446878277486371, 13.162513317600375, 12.174194685874447, 7.7776398677979754, 24.947256849658107, 87.97603299540859, 71.12157698600524, 81.98425954388034, 70.07809315958332, 68.21388475356564, 58.35019457724787, 59.82085197202621, 52.68741776866298, 60.495440806111986, 54.96734249976374, 59.17107212928034, 49.423421352140366, 54.38762795540595, 52.548962023950395, 50.60268586681735, 50.70761319129698, 52.721871868256606, 46.9757015474381, 50.77755297383955, 51.67801149429814, 65.87417525629844, 67.15379361183413, 69.99438193536574, 64.0866413424092, 63.141620774422925, 61.926878421537346, 63.474292678217736, 63.9657146699967, 65.05800454847275, 64.54124404538062, 59.99107107039421, 49.469611183289565, 49.90289580437445, 47.62725822387203, 50.49932749040666, 51.236168261497255, 50.75396383962324, 52.112241406594556, 49.981978631788685, 57.366213106339984, 66.46071864712623, 63.918285369873054, 63.37695514002154, 63.153399652050396, 64.39695573622181, 55.366310304211034, 54.282975196838386, 49.52178655132171, 52.35640502745106, 61.27331741394536, 69.61153507232666, 52.87729186396445, 52.19264215038669, 66.3978744322254, 60.73237549874091, 61.814349543663766, 62.33205141559724, 64.5229697227478, 62.14298925092144, 67.65226410281274, 64.51373646336218, 54.7158165900938, 56.69761765387751, 64.09929883095526, 62.73883650379797, 61.44298738048923, 64.07671382350307, 60.107663523766306, 54.415315966452326, 63.72116665686331, 64.78303463228288, 51.5776772652903, 49.23145271116688, 49.68644372878536, 47.60278263399678, 49.424366643351895, 51.727045043822265, 61.94336806574176, 66.36767218189856, 63.228567954032656, 65.318073380378, 65.71773152197561, 63.05128858935449, 51.93482475896036, 54.14983426370929, 51.78210727630123, 53.65515670468731, 56.92291467420517, 63.9489386927697, 67.03359650027367, 68.49003530317738, 62.63015939343361, 64.27101627472909, 64.46498532449046, 71.05950940039851, 68.69133918516098, 72.52257700889342, 69.98498393643287, 70.05061303415607, 64.42552235818678, 65.55070523292788, 67.79141410704582, 49.411975875977554, 0.5663488841345233, 3.736072298019163, 7.62637758447278, 4.55826384405936, 1.0372786368093183, 0.3762360451923263, 0.6432240912991186, 30.476733869121922, 56.30618080016106, 31.187841930697044, 28.208911611187844, 41.82237002157396, 35.11510525980304, 43.678768988578554, 71.01850494261711, 71.04517705978887, 74.35122520692887, 58.286860066075484, 2.3529533801540254, 0.23047044272384337, 0.22288330710462986, 0.18205213841171036, 0.19087641409808592, 0.23396849211665893, 0.1829310098002034, 0.1166762404083725, 0.16933677958384638, 0.17450346040629572, 0.1242139786782284, 0.17113566128236635, 0.20201605263977282, 0.13288469204018194, 0.19911162945772373, 0.1785190328354797, 0.21865506866766563, 0.37592329745811803, 0.40301915318254505], [0.04905429518511219, 0.08447804758625646, 0.01846490041052382, 0.022149467315044136, 0.00287359508576863, 0.0415204065070758, 0.03328683057559594, 0.0552615877090683, 0.06241889054616613, 0.09389512976931949, 0.039349370786259254, 0.10603049875146921, 0.11074119638050757, 0.08765247845721823, 0.04791237601649858, 0.03409191620566192, 0.13587309378049067, 44.312718145308956, 72.431334833945, 67.44623768714168, 55.28768639410696, 34.08294139369842, 26.653809508969708, 32.64960142873949, 54.283622387916814, 48.06157835068242, 36.88384709819671, 2.4258753897682315, 0.08423933458905067, 0.10140946405308862, 0.5453241219924343, 1.1126545792625797, 1.3720099075186638, 3.793126359101265, 1.0415109967993152, 61.054515838623054, 79.09610071489888, 69.04040659627607, 67.38281296145531, 61.61480288351736, 54.784752245872255, 54.42823233142976, 54.84942820764358, 50.19354343414307, 51.60518484730875, 50.06017892591415, 47.56697531669371, 48.472787872437515, 46.62434739451255, 45.59198740989932, 47.38789558410645, 46.09785549102291, 46.83182900951755, 43.664256218940984, 45.4337001615955, 47.1663091259618, 55.46100416491109, 59.91662056215348, 56.55545919172226, 53.773471078565045, 52.17400696969802, 54.333361964071955, 59.259752996506236, 59.00664244928668, 62.95462569882793, 59.49206321470199, 59.100406708255896, 47.81882678308795, 44.19294072735695, 44.6899599413718, 45.79466019907306, 43.28602206322455, 44.78830945107245, 43.704578184312396, 46.94635045143866, 52.36143742838214, 58.3458407463566, 58.29669344809748, 58.73454763043312, 58.89118748326456, 58.486426338072754, 49.538625286471465, 44.368804116402906, 45.65403930602535, 52.20844930218112, 54.2050612357355, 61.899676784392334, 49.53167876889629, 47.78174861784905, 65.27886536813551, 51.42286915932932, 52.035935617262325, 51.48960044307094, 51.942967599438084, 54.17280366343837, 55.95488940515826, 58.57885699118338, 57.56180993972286, 54.44130559121409, 56.530556063498224, 53.00316856753442, 54.791137864512784, 58.315469834112356, 60.24322063692155, 50.188158019896484, 53.50996625038886, 60.12874626344251, 48.559111395189845, 45.54968856996106, 43.62115721548758, 43.0870912151952, 42.476633133426795, 43.28464923366424, 51.01636648178101, 60.64825634802542, 57.66824345434866, 59.92952123765023, 59.13919502688993, 58.11531128421907, 46.550398949653875, 46.702598679450254, 45.447122512325166, 46.95790183159613, 52.621969099967714, 60.00886686386601, 58.57772734857375, 64.96476588710662, 62.93503738218739, 60.66644830088462, 62.29928785754789, 64.33286812997633, 59.890909425673954, 65.72322676258703, 60.84568492827877, 65.34758921592467, 61.660631856610706, 68.71245722616874, 65.68118679908015, 66.82509899139404, 32.45277885467776, 0.05880110544122516, 1.266126137587332, 2.1462959531814825, 0.6243909534908111, 0.07846372877998699, 0.11137324956155593, 4.746308153675449, 42.25397194585493, 38.36962522998933, 52.15125722269858, 38.49515284261396, 24.208501961923417, 25.8727930438134, 41.845641443806315, 50.30041625422817, 54.327549011476584, 57.457902431488044, 10.659152730818718, 0.18540149013842308, 0.02527395691422205, 0.017368990567422683, 0.06141165346508065, 0.014171989788601716, 0.016455423056838975, 0.05249614053736291, 0.05949360678993887, 0.010720779969086571, 0.08468539694384222, 0.00618568932329635, 0.028052984909605116, 0.06071198536383529, 0.04204664379358292, 0.05283693475047908, 0.010140542102406823, 0.03172820937188883, 0.009629523152515534, 0.01707007646590712, 0.04397713556705464, 0.041486828873354586, 0.011879753212504571, 0.05830615518554565, 0.020770409459909125, 0.019389321471774773, 0.0526476037808724, 0.040026761050666534, 0.05541821055474782, 0.025216879533423532, 0.042744369861940225, 0.015206140496077077, 0.04928477656757159, 0.030734758043000777, 0.09724953001545322, 0.2538950518975335, 53.753094365519864, 83.02883378921017, 75.32186277451055, 66.9918389474192, 39.406456716599, 38.12544984202231, 38.00493894084808, 51.05853980587375, 49.579347333600445, 38.06215063218148, 2.113338237808597, 0.19113499941604753, 0.2827899578598238, 1.5097797277473635, 2.2542479153602355, 4.65167950237951, 2.2957782158928532, 1.766866945451306, 64.8554729646252, 78.6820004063268, 72.3692201798962, 71.60317344050254, 63.50639335570797, 57.72675737257927, 54.999227446894494, 57.79268457043556, 53.04964080933602, 55.318578981584125, 52.843677151587706, 51.44098266478508, 49.38404860035066, 50.19702649885609, 47.594537811894575, 49.96626169450822, 48.424883965523016, 48.679790958281494, 47.45198319035192, 46.745921258003484, 49.553761712966434, 57.0758008187817, 61.715458746879335, 58.599512192510794, 57.11878607350012, 55.50218512935024, 57.22464692208075, 61.74979909773796, 63.586413629593395, 64.23799384024836, 62.25527101947416, 61.2777183132787, 50.586192300242764, 45.7467641368989, 46.26451307727445, 47.58352379645071, 45.76673292344617, 45.84727095019433, 45.47548124867101, 48.42866120799896, 55.92909589890511, 61.99165636493314, 59.704624299080145, 60.34462567298644, 60.832768563301336, 61.586777548636164, 53.144864190009336, 47.14747390439434, 46.10604147757254, 55.570014676740094, 56.02999887158794, 62.82835675824074, 51.063360398815526, 50.16794996876871, 67.84322077228178, 56.257229620410556, 54.623229042176284, 53.75535757310929, 54.53604259798604, 56.321929116402906, 57.936780683455936, 59.513447976881466, 61.24698262060843, 56.435065961653194, 59.06720384474724, 56.097561697806086, 56.59878177027549, 59.444473097401286, 60.55015002527545, 50.55882984592069, 55.8504916006519, 62.40681963582193, 51.059457640494074, 45.86982065631498, 45.66693605915193, 44.45279775127288, 45.462541349472545, 46.211749353716456, 53.36553281353366, 61.49806922481906, 58.840777181809955, 61.622788829188195, 61.93535466347972, 57.42937895559496, 49.579684657435266, 47.16399884993031, 48.189608435476984, 49.18811444313296, 54.463325777361476, 62.956563349693056, 60.711837968518665, 68.16971102068501, 64.7718951009935, 62.793863434945386, 63.47262174852433, 65.40395759767102, 62.40321890000374, 66.1184290916689, 62.17544686409735, 67.45055229433122, 63.460925240670484, 70.76605335358651, 68.04985907769972, 70.74768881643973, 39.531176320968136, 0.1549835707391462, 0.6104984699237732, 3.4527683258056645, 2.106166429096653, 0.3911154951539732, 0.12515143281029117, 3.5425021042746887, 49.59967697820356, 38.266372757573286, 38.047535880919426, 37.218723374028365, 28.584651139474687, 33.614586860902854, 47.63339673319171, 56.084539428834, 58.236602737057595, 66.35288484634893, 16.07891321182251, 0.13116922199485764, 0.0483850101309438, 0.023053721111688404, 0.046378821209673925, 0.03358170164809112, 0.020530995492252613, 0.03548568294894311, 0.06296615694619476, 0.05011189871677949, 0.03943208912988344, 0.02131298165618172, 0.057312244203903025, 0.01845438010810364, 0.0374847166090002, 0.03283890279670877, 0.043916089850808346, 0.03259959991180128, 0.019505935375608748, 0.10137377967757565, 0.1324763058895065, 0.14845081725187842, 0.0690461716224109, 0.15196100147741456, 0.10270278900861742, 0.11476229996450486, 0.1740115859936322, 0.11684330886289959, 0.1952588813559663, 0.1131738166535093, 0.15719764144910922, 0.1360771642817605, 0.18427005488305323, 0.1647339854389429, 0.1472603779045805, 0.522468225850213, 62.158521836803814, 90.40233273659983, 86.62671412191084, 73.71254567177066, 49.61802190349948, 36.83979495879143, 44.52172163994082, 70.8392055573002, 64.42902895712083, 53.43559811192175, 4.2259983958736544, 0.2226603295533888, 0.269619251691526, 1.3185671236245864, 7.290385884623374, 11.613639939215876, 10.819560020200669, 2.493899584777894, 69.88938793059319, 84.24064220920687, 74.61917015814012, 73.89452795828544, 66.49395681196644, 59.140893413174545, 59.35531370101437, 62.20135019671533, 56.12810911670808, 59.108773123833444, 55.62970922839258, 54.72032339342179, 54.216863647584, 53.58309491988152, 50.12931854494157, 53.570104029870805, 51.717262652612504, 52.62868419770272, 48.85813720764653, 50.19417493574081, 51.61163714624221, 61.01045585447743, 65.42376164467105, 60.11091516863916, 58.13502119433496, 57.39166144401797, 58.949458214544485, 64.28774910588419, 64.59059530688872, 67.37804335932579, 65.78480797429239, 65.21836280822754, 53.006059354351414, 48.91588626369354, 48.829205805255526, 49.67891277805452, 47.89779978413736, 48.38346373650336, 49.110392678168516, 51.69022183264456, 57.822149415169996, 64.45705821437221, 61.62769571427376, 60.87544395077614, 62.46888722142866, 64.31271891440115, 55.96934726161342, 49.42872439661334, 48.704446977184666, 57.103339779761534, 60.408301430363814, 63.840198824482584, 52.993543071131555, 55.69663270827263, 69.9706280616022, 61.39422839687717, 57.09884082117389, 56.90972374331567, 57.40604477543985, 57.58277500829389, 60.343496030376805, 62.30715220974338, 62.329086103746974, 58.639869459213756, 62.520540914227894, 58.12625077462966, 60.0691262368233, 64.27647621400895, 63.40655726771202, 51.871494170158144, 56.943350222802934, 64.57745928918162, 53.88977327654439, 48.47921271477976, 47.91213996948735, 45.90977391889019, 47.96591958691997, 47.93880816428892, 56.80798530578614, 66.32636177924373, 60.39533407457414, 63.04757018243114, 65.88586391941195, 61.33971921859249, 52.40404221319383, 49.9741417361844, 50.16588680205807, 51.88387317042197, 56.93526229550762, 65.01841998869374, 62.399202392947295, 70.93801006194084, 65.8008308564463, 67.43626702216365, 66.37791741278865, 69.09000104473483, 64.53573311528852, 68.3339406597999, 63.651870143029, 70.33930732357886, 64.27593492692517, 74.58425321886617, 71.97109960740613, 76.0063163695797, 39.47906763322892, 0.42517092259180167, 6.394248345205861, 12.341759320228332, 1.9342828974608455, 0.46804049803364667, 0.23955321179762964, 6.832760995434177, 55.70188083956319, 54.55009252794328, 69.7241698541949, 51.21820380610805, 32.173374699008086, 38.09400812272103, 55.97357949902935, 65.8319313295426, 67.54676803465813, 75.36336929567399, 22.665123824150335, 0.3054914719635441, 0.17422172391126234, 0.16645060461615363, 0.14962716058136957, 0.1281075975707462, 0.1191488351492632, 0.09361881717679002, 0.2313370873490649, 0.12035959114831303, 0.13220655100960887, 0.13688416130119754, 0.16503197831972954, 0.1632800424892095, 0.11178661528373919, 0.16090213621575988, 0.15022913715051067, 0.13101992678017388, 0.1215958961796376], [0.03794164975143729, 0.0367107303182204, 0.046443390930371906, 0.1287552329801744, 0.04295394470494601, 0.050936967750350316, 0.08323128545476545, 0.041779386360318436, 0.04851758547668015, 0.03761854067805313, 0.023061891439400857, 0.06310214521363378, 0.06472981775239592, 0.02611453922825956, 0.0683609749220552, 0.20844080305147558, 4.502434297915428, 65.73690798974806, 66.09135689273958, 69.8620568552325, 58.62843182779128, 79.87086296081543, 18.264920711517334, 46.93750942907026, 48.568901631139944, 45.28209663206532, 29.87063550180005, 0.16020124237383568, 0.017348099349727555, 0.23170652558966992, 1.6016498496455531, 2.7791524846707625, 1.9920894407456922, 4.077244468273656, 9.38061793004313, 81.32341861724854, 64.67467915627265, 70.54198403512278, 60.14375717409196, 55.446656134820756, 53.36277538730253, 51.05494691479591, 51.813800027293546, 53.190383295859064, 49.497907161712654, 48.627125293977805, 46.908476045054776, 48.00571595468829, 49.323032209950114, 47.11396117364207, 46.8087419386833, 45.17356464939733, 47.192016340071156, 45.71943698390838, 45.61156395942935, 45.17309788734683, 48.73815190407538, 52.73609046013125, 50.309320034519324, 48.403471746752345, 50.30547218938028, 53.60517786395166, 57.02811264222669, 60.58355292966289, 63.78923939120386, 57.27743810222995, 57.034325676579634, 52.44365422956405, 45.86221910292103, 44.424180138495664, 44.92030505211123, 43.92463884046001, 45.618267290053836, 43.91983001462875, 46.01572105961461, 55.39298242138278, 61.54383543998965, 57.786863773099846, 60.035907683833955, 59.456636367305634, 56.13247471470987, 45.35331510728406, 44.201809206316554, 43.05067593051542, 52.085141751074026, 54.202499928012976, 64.15951898021083, 45.58213833839663, 42.645091087587424, 62.852875494187884, 49.491615679956254, 50.07147142964025, 45.70549688031597, 49.651350282853656, 45.526491672761985, 56.134090731220866, 54.254914560625636, 59.76394230319608, 54.646708350027765, 55.826219974025605, 51.609734796708636, 51.648534882453184, 54.85719842295493, 57.892285316221184, 53.64454669337119, 57.6034027530301, 58.83932198247602, 49.71203719415973, 41.73672114649127, 45.269803923945275, 41.848959768972094, 45.204355255250015, 44.48123885739235, 49.32678199583485, 54.63848313977642, 59.54275592680901, 60.81421183001611, 59.366245346684615, 56.143967259314756, 47.95551746122299, 45.111795163923695, 47.23369936789236, 45.33569189809984, 54.526754425418, 57.498444049589104, 62.977453893230816, 56.96384852932346, 64.27037300602083, 62.208426152506185, 63.42224282603111, 62.789639042269805, 65.63758573224469, 58.26579301587997, 62.391502780299035, 63.48548712268953, 68.25548541161322, 62.80411258820565, 66.8649345828641, 61.65035524675923, 65.55636129071637, 25.661057618356523, 0.6143746909595306, 6.26213752454327, 1.404973138724604, 0.13702673026390616, 0.05262677768065084, 0.16760036469467227, 27.539043349604455, 50.60254858386133, 28.94140639612752, 34.63497184938, 26.01443571429099, 20.313049054914906, 34.00270931182369, 51.684816806547104, 50.78469560992334, 59.77318340732206, 33.69043373292492, 0.4034832492470742, 0.06179359809104955, 0.04822771695833053, 0.06299206603979392, 0.024390611572251208, 0.025657259431036732, 0.04456499696619088, 0.06110633678373791, 0.03255327074458042, 0.013090234377511568, 0.05221300976230733, 0.11876580650888144, 0.033908771396043806, 0.016673103110083652, 0.061739596553267016, 0.05145290881515511, 0.07051719833285579, 0.038321847696938825, 0.05260075750430265, 0.017656836613652208, 0.027052784346104152, 0.1301578173954641, 0.04652189962085217, 0.02685033795123379, 0.016726489862306945, 0.07541125144569144, 0.06012049270793796, 0.05643180999604445, 0.08508124989607642, 0.055760582908988006, 0.135186541104509, 0.030416216768865145, 0.07816226552090338, 0.17789116249449793, 7.271255994996718, 80.65052816944738, 72.92996221973051, 79.15182975030716, 61.705209593619074, 83.1347377838627, 20.606805163045085, 41.78564094728039, 49.91787533606253, 53.04314144196049, 33.074664761943204, 0.06723687878899998, 0.089712948538363, 0.9592529494435558, 1.8704830951267675, 2.6941584002587105, 2.644473246989712, 3.838910960382031, 11.745460994781988, 84.86178874969482, 67.70522394487935, 74.36743244048088, 63.120600792669485, 57.681340248354026, 55.21423609026017, 54.632140667207786, 55.79826524180751, 57.0435824701863, 52.59516362221011, 52.326304758748705, 50.879911145856305, 50.65000926294635, 51.30878702286751, 50.618265521141794, 48.678171019400324, 47.480259556924146, 47.20792939586025, 49.638088749301055, 47.35322183178317, 47.35265308810819, 50.44879951784688, 55.150474040739006, 52.276204324537716, 50.734006820186494, 52.66754704137003, 56.881176733201556, 59.64756950255364, 63.65680448470577, 64.65678138117637, 61.7375809146512, 60.16362397901474, 54.49175511637042, 48.08740715826712, 46.59437264165571, 48.03695763311079, 46.70986290900938, 47.66257524490357, 46.34545118578019, 51.9165700481784, 57.681289257541785, 63.452201889407256, 59.63715560974614, 62.26548487140287, 62.44075206018264, 58.93658107326877, 47.64811738844841, 47.33222146188059, 45.75098068483415, 54.069468821248705, 56.688953138166866, 67.96733240927419, 47.589101406835745, 44.69092876680436, 65.57815005702358, 53.08911554275021, 54.305352318671446, 47.27622178293044, 50.8153606999305, 47.60814451402234, 57.35015884522469, 56.60493989144602, 61.011958122253425, 56.96818667073404, 58.15518609939083, 54.21613408673195, 53.09745057936638, 57.45998128767937, 59.37450193589734, 54.24084894118771, 57.283364803560325, 61.531099504040135, 51.77353297510455, 44.13425030246858, 49.142771843940984, 43.932816982269294, 47.370794050155155, 45.20376297735399, 51.54481564798663, 57.80363190558649, 60.29025377765779, 60.518567100647964, 61.95485668797647, 59.75037482477004, 49.58465037807342, 47.12151173622378, 48.99409048018917, 47.198096013838246, 55.718841168188284, 59.794638772164625, 65.17501669545328, 59.015510928246286, 67.68140731319305, 66.28898159150155, 66.4663197917323, 63.87314673393004, 65.0423699809659, 59.24863699943789, 66.12769373001592, 65.49752181576144, 69.64957421825778, 63.50061962681433, 69.97183615161528, 65.36434950367098, 71.73122313714796, 31.047493642376317, 0.4473641833230373, 0.8842721244981213, 2.08952994115891, 1.5805588975068063, 0.19941437208364088, 0.25511189063470213, 28.30054210078332, 59.399707086624645, 31.597000052852017, 28.874628043943837, 20.82726590095028, 27.084978011346635, 40.184486296869096, 56.56869326868365, 59.86286840131206, 67.18409784378545, 43.284355055901315, 1.147424429655075, 0.09438953227213315, 0.016370636275819233, 0.02432225163154785, 0.07037544908422617, 0.07514403231682316, 0.04159595809816834, 0.09205152385778005, 0.04082627339108337, 0.025230019856544755, 0.022405141498893503, 0.0504823022281691, 0.04677240654165226, 0.00858857820276171, 0.02532482132195465, 0.018256675797484575, 0.1542078301070198, 0.033289301209151745, 0.1593901084796075, 0.10232621848943735, 0.0947261896104582, 0.3485096991062165, 0.1527438514054783, 0.06881911082253342, 0.21057506272148704, 0.13974453442760054, 0.14098305345302628, 0.2108562782767319, 0.1844123480541091, 0.1888118224639085, 0.1692130257405581, 0.18787898784202917, 0.27890457441249206, 0.44188083239620735, 9.631995770239062, 94.12401091667914, 82.2683568154612, 90.49900347186674, 68.20068990030597, 92.49313646747221, 26.13634297924657, 62.22304874850858, 64.80647863880282, 64.06142442457138, 39.711471988308816, 0.36205630929720023, 0.16936319429547558, 1.1496278210993738, 5.9555346735062145, 7.174040050275865, 9.345233248126123, 9.312535389777153, 14.114484325531992, 88.21900813810288, 71.10088256097609, 76.50350816788213, 66.73818711311587, 60.07060497037826, 58.06239066585418, 57.66725501706524, 57.74831079667615, 60.743377747074256, 55.43248461138818, 55.289267109286406, 51.92022961954917, 54.00092148011731, 54.88810669991278, 53.77935463382352, 51.37461223909932, 49.90598270970006, 50.735320814194225, 51.86328857175766, 49.6882519414348, 49.773226168847856, 54.277860426133685, 57.66139891839797, 54.1267942613171, 52.44119098109584, 55.187654187602384, 60.69255951912173, 61.918876786385816, 65.76256813541536, 67.94012684975901, 64.50372657468243, 62.007287010069824, 57.75424926511703, 51.36091532245759, 49.42255450833229, 48.81444200392693, 47.61916637420655, 50.04397953710249, 49.37583123483966, 52.440422196542066, 59.42368061311784, 65.32408637385215, 63.35042030580583, 65.70117911984845, 66.78618123454433, 62.12337347768969, 51.45700162456882, 49.1950374264871, 47.43061411765314, 57.06480249281853, 58.9822845305166, 71.10607577908424, 52.456201891745295, 48.656974530989125, 67.38442897796631, 55.06700992584229, 56.14776803601173, 51.14743248108895, 53.35506792991392, 50.916691210962114, 61.085784973636756, 59.270237491976836, 65.3307661702556, 59.88674779092113, 61.54218019977693, 56.194440318692116, 54.75568356052522, 61.33388665414626, 61.05807342836934, 54.2006407245513, 57.22992643233269, 64.38091324221703, 54.98456170482021, 47.04637089083272, 51.035048730911754, 46.31502143798336, 50.2006233123041, 50.56843965284286, 55.16928572808543, 60.28153434876473, 64.1080770954009, 63.52672692268126, 63.8875182982414, 61.95250718824325, 50.81896143574869, 48.735343487032004, 50.94818392107564, 49.50221000179168, 58.06350854135329, 63.86108544565017, 67.83117909585276, 63.39515493762109, 70.20342073132916, 66.07455345892137, 68.63124062938076, 65.51339172547864, 66.96126014955583, 60.34061701067033, 68.72392623655259, 68.28924917405652, 74.33362160959553, 68.0567781386837, 73.64502599162441, 64.54842590516614, 75.99383538769138, 30.876694033222815, 2.039055288318665, 19.914589197404926, 5.812241175482351, 0.9690795898918183, 0.27708376727757916, 0.3857715722293623, 34.52767933568647, 67.16409375590663, 43.66932784357379, 47.51015586237754, 32.99458957487537, 29.51679848855542, 46.24544251349665, 67.6907660884242, 66.57023906707764, 73.68326125606414, 50.13471572629867, 1.5682802854045745, 0.3121450681599879, 0.1168423972182697, 0.16815553329163985, 0.12155795950562724, 0.15755191114881348, 0.11048348440277962, 0.18671536157208105, 0.13317212822937197, 0.17658368023412843, 0.1299796559877934, 0.17258565121841046, 0.19645950967265716, 0.10182905807009629, 0.11039296345364664, 0.08641066525371806, 0.22675791935574627, 0.09741692788778775], [0.07767612144591347, 0.06415872218748254, 0.07651064890406786, 0.09526428210759356, 0.005406230770712418, 0.05045848455460322, 0.0653518888077909, 0.013651064364239575, 0.05268042298754858, 0.16096443448576236, 0.05604066465410495, 0.0598390473263158, 0.0723698900471772, 0.09403520128539494, 0.15610167606463357, 0.10060088889252755, 32.37345087912775, 68.02001768542875, 64.87980734917426, 69.29453695974043, 58.22883644411641, 28.24845498608005, 39.22532166204145, 66.7184889701105, 32.9516984570411, 57.57260430243708, 11.365067574285693, 0.2065761603655354, 0.07238608514589649, 0.9358821196421501, 1.1756335030640326, 0.2942768027705531, 2.4273171059546934, 1.3789055568556632, 30.246733926957656, 80.61630156732376, 66.77405326597153, 67.18133649518414, 60.174218300850164, 56.58994859264743, 51.35810690541422, 48.85808229446412, 46.90825246995496, 48.07953103896111, 48.024464884111964, 50.88435519126154, 47.99742798651419, 46.42522042797458, 45.280374711559666, 46.23894314612112, 46.95485807234242, 46.05729818344117, 46.14699102217152, 49.1744920515245, 46.90149422614805, 44.048895605148815, 44.533394613573634, 47.32571032739455, 47.75940679734754, 45.8965241524481, 47.7604462254432, 54.41810869401502, 57.30766780914799, 59.32317772219258, 62.06390250113703, 59.890387750441036, 60.55140126136042, 53.822567386011926, 49.45097600260089, 42.334651177929295, 43.95284460436913, 44.483847233556936, 43.783774760461625, 44.870134015237134, 49.1667571375447, 53.853891434208045, 59.07962991345314, 56.03613345853744, 62.28803457752351, 55.44255333562052, 50.42884642078031, 42.02258348464966, 45.96531075816001, 47.538291023623565, 57.18555658094345, 54.554214938994384, 65.94800995242211, 42.06144632831697, 41.35341536614203, 62.4370454203698, 53.7411036799031, 49.625929401766875, 40.6897307211353, 47.974886125133885, 42.016437130589644, 46.64617930689166, 56.50922621450117, 59.3572082058076, 55.804823444735625, 53.46700845226165, 47.11211765966108, 46.46966088202692, 53.31834277799053, 58.75629717303861, 57.607427104826904, 56.42029431558425, 58.49134106789866, 48.69191108211395, 42.89937834585867, 44.89244445677727, 42.93326370177731, 43.261750436598255, 43.72443714449483, 45.38846346639818, 53.63324242253458, 58.77919597010459, 61.54795392867058, 59.632436998428844, 57.45276020419214, 46.959105999239036, 44.56965300344652, 45.8297065765627, 45.73163163277411, 52.35051362745224, 58.49382000584757, 59.55367972773891, 62.57670925509546, 58.59589968958209, 60.63836020808066, 61.06497679987262, 63.851624688794544, 57.01473735993909, 63.79937479572912, 64.6458811144675, 63.85528426016531, 59.579394786588615, 62.281468529855054, 63.2324864018348, 68.69961538622456, 61.576042021474535, 66.6493611181936, 13.709087756372268, 2.9484640446401413, 4.88557190664353, 0.6460730803589667, 0.08137728373009352, 0.26853968058863, 5.3123914810918995, 51.66203175821612, 26.584224700927738, 42.07207202911377, 58.22009348100232, 18.170607320723995, 21.323773245657645, 37.470135534963305, 51.36088394349622, 59.32401710940946, 51.26406415816277, 5.2044478539497625, 0.13544135726988316, 0.012728819950303484, 0.07437628964262624, 0.051696291118259394, 0.05490911831598609, 0.06143740934109496, 0.05354609468110627, 0.06323819093766712, 0.046943699971081755, 0.045603237625571995, 0.09734781143525917, 0.07870282482115493, 0.030890639698613557, 0.03361694552304764, 0.07789038091657624, 0.029638016994501797, 0.10340189786567804, 0.025647600977531364, 0.029621549934569388, 0.028869768702274853, 0.05431186850933779, 0.026166259739247542, 0.030042658890447313, 0.07133711925557545, 0.06354683627104087, 0.0737456537242378, 0.08359167619698471, 0.1068282873940564, 0.0508526329612059, 0.0643886941214723, 0.06500799959946064, 0.0755844179600958, 0.05838646418264797, 40.36188333265243, 81.52451069124284, 71.26294705175584, 77.3304771607922, 65.84649116762223, 45.14677093875024, 35.95851290610529, 54.14255826703964, 35.63116758100448, 64.72490118395898, 11.859560781909574, 0.41673022712911334, 0.03592261353567724, 1.6763667113357976, 2.3362411414423296, 3.7852683807573015, 4.133793279047936, 1.2433374120343117, 33.25665489319832, 83.62983503649312, 68.41179186298002, 71.83996692780526, 62.41999487723074, 59.30262058011947, 53.1272723597865, 52.02609046812981, 49.36691960980816, 50.52490134393015, 50.74376567717522, 54.03119825547742, 49.49244722243279, 48.842028033348825, 50.07167539288921, 50.27108477007959, 49.638053447969504, 47.466746991680516, 48.64790208878056, 50.046105461735884, 49.62262284371161, 47.31610836521272, 47.26030088240101, 48.40799031719085, 49.1859414500575, 48.657578575995664, 51.206981905045055, 56.90292235343688, 60.61621450608777, 60.99053413637223, 64.4507981115772, 61.49566481190344, 63.427192857188565, 57.0750359565981, 51.006721373527284, 43.81063122903147, 46.80296820978965, 45.917893225146884, 46.08816331432712, 46.56679053460398, 50.35660420694659, 56.55083079491892, 61.087440213849476, 56.893696938791585, 62.302555191901426, 58.813465718300115, 51.23204585044615, 44.29642854198333, 47.43864713176605, 49.147780710651034, 59.74654266911169, 54.54478163872996, 66.29937587245819, 43.214058337673066, 43.327481515945934, 63.519792172216604, 54.41917557870188, 52.28739484663933, 43.84031964886574, 49.10706650826239, 45.55481510777628, 49.53014512215891, 57.954647079590835, 62.109923670368815, 58.258905333857385, 57.47247795904837, 49.89817327068698, 49.17323297069919, 56.62066467346684, 61.7027267333, 59.345919624451675, 58.666667092231016, 62.761221470371375, 52.058402953609345, 44.544930304250414, 47.18605041503907, 46.016748720599765, 44.948950121479655, 45.84235229799825, 48.50804605791646, 56.77303306518063, 60.11159766104914, 62.03953281525643, 61.43851195612262, 59.61724173638129, 50.354474359943026, 47.36225112791985, 47.39119821979154, 48.548862241929584, 54.65534933151738, 60.29440756767028, 61.79858161557106, 63.76019031770768, 60.90241809045116, 65.45183404799431, 63.70592432637369, 65.19629163126793, 55.72958454009026, 66.2712917020244, 67.91518842020344, 64.94280453651183, 61.89045529211722, 63.61309359150549, 64.71085909874209, 71.46709072974421, 62.63510942459107, 73.66829349148658, 17.8480492484185, 2.196937184179983, 3.587741496101503, 2.3058192383858467, 0.5164919433093841, 0.28197361456771053, 4.062166877331273, 55.22162583566482, 33.209766880158455, 36.244273262639204, 45.286776019680886, 22.765909125727994, 26.2744947402708, 44.11094750127485, 56.21441302760955, 65.15954686749366, 60.6816827866339, 8.951690081627138, 0.1250219486293293, 0.09582293640461662, 0.0664552929060113, 0.02567539464742426, 0.02765669528725407, 0.043116025927086035, 0.06898108479236403, 0.049428429544693044, 0.040015457423343774, 0.04799757648499743, 0.09102038483345702, 0.02732343171843358, 0.05423958045280269, 0.06557081375391254, 0.02046682413727526, 0.055176973297831514, 0.08887838001453108, 0.27689549350930803, 0.1690080818990546, 0.19274474932782112, 0.15226619558468943, 0.09706242070082696, 0.10943063444668248, 0.1501833097708802, 0.11771356942312372, 0.1843683439637384, 0.2743173012089345, 0.1908206275754398, 0.11606677149933194, 0.22686863438256327, 0.19296014260861183, 0.3546287191490973, 0.1680686895645434, 48.890324177280554, 91.29851587357061, 81.48761687740203, 86.53984146733438, 77.03942160452567, 42.543313426356164, 52.56195291396111, 84.01227397303428, 47.615455812023534, 72.7385897790232, 15.081940850903912, 0.5050904099499026, 0.18382328772737136, 2.176910297524545, 6.230979686783207, 4.660209186615483, 13.71721882973948, 3.311978770840553, 36.96575403213501, 86.40875585617559, 73.13636518293812, 74.70881200605824, 64.56246799038303, 62.00085824535739, 56.13043508222027, 53.66171098524525, 51.937201715284786, 53.83645257642193, 54.648100791438935, 57.88207930903281, 53.358272506344704, 53.08641695207166, 52.80965843508321, 52.76673986065773, 53.54755432375016, 50.65165665841872, 51.73981628110332, 55.110469787351555, 50.67576746786795, 49.18593360531715, 49.63535093492078, 52.4975162167703, 53.23959335204094, 52.127393522570216, 52.54173309572282, 60.57314295922557, 61.80806198427754, 63.74667383009388, 65.6339418503546, 62.94266639217254, 67.55451079337828, 58.93978564969955, 54.55645853473295, 45.731870897354625, 49.345507391037486, 49.41390568210233, 46.717535065066436, 48.789829131095644, 53.712603738231046, 57.570631350240404, 63.72565384834044, 59.774956318639944, 64.28089280282298, 59.77432089467203, 54.33799428324546, 47.14665020665815, 50.41745978017008, 52.78103689993582, 62.27760107286515, 60.670657004079516, 70.6491667224515, 47.3279421560226, 46.91276711802329, 64.97242627605316, 58.17933221017161, 54.58154601435508, 45.55886299379411, 51.69062975914248, 48.9929529928392, 51.16076853967483, 63.037626974044315, 64.54551550649828, 59.6642513428965, 58.946747856755415, 51.8017779627154, 51.89477343713084, 58.209197136663626, 63.826329323553274, 60.937888083919404, 60.650033181713475, 64.83511978580107, 52.96123843039236, 46.863502148659, 49.490313453059045, 48.269103111759314, 47.085006237030036, 48.64145371221727, 50.48770158521591, 58.823644268897276, 64.13129752682102, 65.93126143178633, 64.38506310985935, 62.96654185941143, 51.97901418132167, 50.13553942403486, 48.92618640776604, 50.27080628179735, 56.735060599542436, 63.55665068472586, 65.92482874470373, 64.7956685866079, 64.25720953172254, 67.28068228690856, 64.63569471913, 65.9630875433645, 57.84928829439225, 70.80537903693416, 70.54374910170033, 70.16655829644972, 66.1521928541122, 67.92599847239833, 68.72174539873677, 73.34811825906077, 64.6706195031443, 77.95882517291655, 14.99271869659424, 5.525619858695615, 16.407223439985707, 3.186511954953594, 0.3281526591989302, 0.49675751837991905, 6.277005268681434, 62.31067449815812, 40.28414195583713, 58.22886782307779, 75.171981165486, 27.666479195317915, 32.68404964477786, 53.02142327831638, 65.60060170388991, 73.02475806205504, 68.38537077749929, 11.1532066329833, 0.26135068086366503, 0.21723415942922716, 0.15418135410835668, 0.14751128702154084, 0.12118878939579572, 0.15399517942099802, 0.17276788821383832, 0.12018621779016911, 0.1992715886163135, 0.14224614857906295, 0.21517684563033043, 0.09291606940208905, 0.11745958829358702, 0.17110677976762095, 0.1473650561585542, 0.1782943086037713, 0.19483698141430655], [0.028418224988385078, 0.035306575422685955, 0.0471245426864874, 0.01593703817155573, 0.014556792880138083, 0.07624989555728051, 0.03744568059881849, 0.038518046644786676, 0.007346442763528397, 0.021436674212436044, 0.020318769985028816, 0.08405488359952167, 0.09781822006428435, 0.014415320380771113, 0.05318422921963277, 1.0656731647829856, 51.26133418852284, 64.83523353453606, 68.51314590823266, 61.35436142644575, 38.398858654883604, 16.278839361283087, 26.247595125629058, 60.03798654002529, 47.29765361355197, 55.64563012892201, 2.5429478431901624, 0.06405485981714822, 0.0486564580651541, 1.2408843372137317, 0.987234341521417, 2.0711683457897556, 4.758633221349409, 1.007778000447058, 58.87721992308094, 73.74834122196322, 67.10987875538488, 67.2102600528348, 65.45915319073585, 59.79916126497331, 57.17932393473964, 51.87422806216825, 50.46400262463478, 49.46679099913567, 46.89904666716053, 46.291244029998786, 49.819580739544286, 47.46711569447672, 46.00740171247914, 46.62232737387381, 46.35067970521989, 44.504620105989524, 48.248616572349306, 48.806510971438506, 49.44890499114991, 46.8646788597107, 44.18176197236584, 42.88671301257226, 46.011649639375754, 46.839124618038056, 51.92010018133348, 53.16348760358749, 57.724631447945875, 57.7819529656441, 60.351532966859885, 59.575225307095444, 60.89105890643213, 56.17182000990837, 49.69890509882281, 46.30789449138027, 43.54133306011077, 43.039340280717425, 43.176658538080034, 41.32684915296493, 49.13181666404971, 56.07865195120535, 57.17308736616566, 57.73131124434933, 59.01974708803239, 54.88674955983316, 47.29475105962446, 41.56342690990817, 46.98901014943277, 49.79454032836422, 59.6655692592744, 51.82791271517354, 66.7632039900749, 36.57512518667406, 37.695142299898215, 64.03030826199439, 50.01387926840013, 49.36197742339104, 40.624807650043124, 45.52311843441379, 42.521257938877234, 45.4353436346977, 49.58204200190883, 56.8840753647589, 55.58282513772288, 51.70797055767429, 47.572933396985455, 47.49025767849338, 52.09743838156424, 59.40865009061752, 57.85130439266082, 59.443974956389404, 56.83269623787173, 47.68151244809551, 42.63870546894689, 42.73675687851445, 44.01519460062827, 45.31498570596018, 46.34057175728583, 48.43381128003521, 52.95598637673163, 60.19705041762322, 57.52224106942454, 58.31172004822762, 57.78962512170115, 49.867661153116536, 42.98656479004891, 44.88454088088005, 44.9957557647459, 51.413110302340606, 59.83605900118428, 61.19745485244259, 61.148346777885195, 62.886643179001354, 60.73242648955315, 59.669373958341545, 54.507260245661584, 61.94429374510243, 62.347536933037546, 61.052911589222575, 59.206240100245324, 54.962980824132124, 55.96165941607568, 60.74896712456981, 63.82193234659011, 67.94276268251481, 63.6370788851092, 52.3266734615449, 2.3586432683852414, 1.8298674422887065, 4.79001316332048, 0.12450122334543737, 0.24204175648910387, 0.08615940373631255, 33.08565132079586, 40.971760903635335, 28.534891951468687, 37.135110209065104, 13.711069533901831, 30.630898706374634, 31.047170046837103, 48.89880041922293, 54.128767213513775, 59.06018672450897, 21.488004845957605, 0.16254591575313002, 0.052059681094702215, 0.039189449932065704, 0.025965893273091605, 0.03280856954534689, 0.028819430979990193, 0.05274507314747861, 0.02450288175755451, 0.0497336772781226, 0.1090633335913862, 0.032436928801959565, 0.07381460163742304, 0.05681887591978716, 0.047231277886537776, 0.04522711526782763, 0.02302021817153981, 0.07855500049528577, 0.03809376800012204, 0.012648129824458832, 0.03594293401786878, 0.017098691765098803, 0.0356777718350772, 0.10149495946543832, 0.038890135549609704, 0.08019030710021335, 0.019128887966695814, 0.07881848111508355, 0.06853850813762796, 0.06640578064346506, 0.032479052146476124, 0.03571313062322236, 0.0772309860575103, 2.277461237484409, 62.87829245290449, 74.53503531794395, 75.44786499392602, 69.81763993540119, 48.71135819342829, 28.52640198123071, 31.9012543847484, 49.341447737909135, 51.02516828044769, 62.7081714137908, 2.7488759544587906, 0.038377048162322853, 0.009169960413278352, 1.3768399386636674, 2.5584181614460486, 3.7020942761052043, 3.476010330261723, 1.2703312861342586, 60.92246924677203, 75.11050978014546, 69.96261073696998, 69.05798665938839, 68.23595985289543, 62.3338007926941, 59.881460435928844, 54.65875787119712, 53.20229553407239, 50.2394586993802, 49.642513182855424, 48.859125644929954, 51.371717529912154, 48.91518023706252, 48.75741074162145, 49.62574897273895, 48.294170979530584, 47.12239819188272, 52.058991309135195, 51.56044237075314, 51.43394593269595, 47.6233946892523, 45.80516822876469, 44.921317023615686, 48.517926508380526, 48.770676197544226, 54.59442315563079, 56.44388344980056, 60.764738975032685, 58.676418104479396, 63.13768271476992, 59.828331931944824, 62.076410939616544, 59.72114532224594, 54.19154867049187, 48.53364344566099, 45.32301087533274, 46.07016747997653, 45.18431978840982, 44.30581085143551, 52.3736281548777, 59.641015221995694, 60.77934195918422, 59.46062149540071, 62.11592097436229, 56.99507059589509, 48.854540394198516, 43.343563233652425, 50.42052315127466, 52.645001257619555, 62.03211169089041, 54.11728643601941, 68.71057448848602, 38.20997299686555, 40.037189529788115, 66.21032238006592, 52.574971260563025, 51.56387836702409, 42.91403232082244, 47.73109512944376, 44.942925360894975, 48.31613625249555, 50.88004058407199, 59.888414798244355, 57.3269776375063, 53.9756182701357, 50.23414781016689, 50.71661110847227, 55.22721521316036, 60.230998531464614, 59.21453591315978, 58.26542431308378, 61.1097231987984, 50.30899447779502, 45.02338886260987, 44.9180143879306, 45.16590818282097, 46.93488144105481, 47.654475550497736, 51.44553653655514, 53.42078331978091, 62.7973464996584, 60.4277995324904, 59.28784501168036, 60.76758661577779, 52.36751710214923, 44.4382300684529, 48.15278522429928, 47.23074582315261, 53.805771796934074, 60.43195332250288, 63.438936433484486, 62.69068156519244, 64.46291039066931, 62.375240633564616, 61.345685143624586, 55.20751707015499, 64.44613049107214, 63.91453166161815, 63.48025860324983, 60.52805531409479, 55.8750456379306, 56.910955367549775, 63.94389844709828, 64.89016240642917, 73.19670692566903, 65.45563874706146, 60.456542661113126, 3.494344714187807, 1.2081041090911435, 2.6903264897484935, 1.1066159678082312, 0.38073310388192055, 0.049232808993228024, 33.281879655776486, 49.38022036706248, 31.88848314746734, 33.4710124231154, 14.046866586131435, 35.0094993652836, 39.59199659286007, 55.27594281781105, 59.70397318563154, 67.9766990292457, 29.01222675077377, 0.3362392075359822, 0.053191541528870026, 0.06740353355604796, 0.10253061074763538, 0.04472328222266609, 0.08078824638599351, 0.021107786920883005, 0.031311733332732995, 0.0035489279252942656, 0.01635145534941506, 0.035106097873781, 0.05950927711843003, 0.03091646260732124, 0.04082702032680954, 0.10290206379948125, 0.018342948789077423, 0.07167363103719489, 0.11229477672567291, 0.13363479937036193, 0.11401144186815909, 0.0655652596164615, 0.11190265462162996, 0.21728708078303646, 0.1353414440827985, 0.2382751779570695, 0.0758200359620875, 0.13144191865238453, 0.13606432464814958, 0.19226519360898003, 0.17593037577406054, 0.10631539918962987, 0.1659454309171246, 2.7947492993647054, 76.16438004278368, 84.07740100737541, 86.58544294295773, 78.76278554239582, 53.2118857291437, 26.164362430572513, 35.510786118045935, 78.43731511023738, 64.90009777007565, 68.61733190474972, 4.192201293283894, 0.2089550319097696, 0.2043019211099994, 4.412262930024055, 5.816241502761842, 7.11029221934657, 12.315999154121647, 1.7560966072543975, 67.57307144903368, 76.6739273071289, 72.5353011777324, 72.06559734959757, 72.05116302736344, 64.47547374233123, 63.67798136126611, 55.81458230172434, 55.872445106506355, 53.8454112698955, 52.49466073128485, 52.03583755800801, 56.31726149589785, 52.84366930684736, 51.06809469961351, 52.210834103245894, 50.811732507521114, 50.645306341109745, 54.936634263684674, 53.911173728204545, 55.29275017399942, 50.53973967029203, 50.26153772108017, 46.5104692212997, 50.83097565558649, 51.29920075016638, 57.79133135272611, 58.858553363430886, 63.363203310197406, 61.72564906458702, 65.50159323600032, 63.06846072596889, 62.611967440574404, 62.51518295657251, 56.74321912950086, 51.41022736026395, 47.94759427347491, 49.0113292970965, 48.18851017182874, 46.76371705147528, 54.0072992540175, 62.29236487419375, 62.92444306035196, 62.5460284756076, 62.86863949991042, 60.54654928945727, 50.88912087102091, 47.27155808479556, 52.580674386793575, 54.20376293120846, 65.44281651896816, 57.27597505815568, 71.1657585636262, 41.245471738999896, 43.487274954395915, 67.93919332565801, 55.816217930086204, 53.560282414959325, 45.03882338923793, 50.08637251392488, 47.90789988733108, 50.69559504908901, 54.910189643982925, 61.54508275370444, 60.234152117083156, 56.706431219654704, 52.524200101052564, 53.862701077615064, 56.82723629859186, 62.92660036394673, 60.59419824231056, 63.444804299262266, 64.46543639706027, 52.611288485988496, 47.4571999426811, 46.84084653854371, 47.72559988883234, 50.52684291716545, 52.22101657621322, 53.66482926953224, 58.2805960409103, 65.81798338120984, 62.8595749024422, 62.22069532640519, 64.38677326325448, 54.87247213240593, 47.05501971706268, 50.02219077079527, 49.571251561564786, 56.06566106119464, 63.325748597421956, 66.48195435923915, 66.48029127428609, 67.87367405429964, 66.35786625646776, 64.28112030029297, 58.01145868916666, 67.8157720258159, 68.22364361055436, 65.80298816004108, 63.73222381837907, 59.27579941288118, 59.276407380257886, 66.41135954087781, 69.23694087613013, 76.37819628561698, 69.59515525448707, 61.821621617963245, 3.0374295288516633, 5.782982255181959, 15.10374922906199, 0.8179575313002834, 0.5052659666586308, 0.0870416229290347, 41.30982214404691, 54.353919106145064, 45.728179947022475, 51.4990847341476, 21.811094399421446, 42.014405342840384, 43.88480324898997, 64.22545794517764, 67.69638292251095, 77.15554729584726, 34.11978029435681, 0.7393751738052214, 0.16324150826661818, 0.19447446860853704, 0.32504810320754207, 0.11821835241731136, 0.1930608984924132, 0.22708712265856806, 0.12969361407862556, 0.1549265278323043, 0.2063585147862473, 0.17782403787057247, 0.08615463866942352, 0.1502349900622522, 0.16458161055080353, 0.2943387639618689, 0.1304420666588891, 0.2673528878198516], [0.05849196598114026, 0.019494164434652177, 0.12361318188449069, 0.030671293404133573, 0.029049676790412877, 0.021176778884123892, 0.024569563965703693, 0.03665425048600282, 0.06850096982933822, 0.015893944768205045, 0.04910615167670673, 0.023464888161528977, 0.0506395839094635, 0.025591211160644892, 0.2043136269334824, 6.564284563064576, 67.7367284221034, 64.4700373372724, 65.47411703294324, 46.84466692709154, 33.2394003868103, 21.746747916744603, 38.60631673566757, 37.09845958217498, 50.266405382464015, 39.45485876452538, 0.06745332161024695, 0.11659999933814812, 0.5850954233638702, 1.1417259612391073, 1.688158949536662, 2.278878929153566, 2.5841182662594706, 14.964309950028698, 79.63810167004986, 66.0891289864817, 74.92595441879766, 64.16205675371232, 66.30008189908921, 64.26136332173502, 63.745030356991684, 50.92527727926932, 50.72060015893752, 48.80555391311646, 48.633542291579715, 45.110991078038374, 46.466660268845104, 48.62173203499087, 47.32357655802081, 44.896319758507516, 45.13581183648879, 45.87157787815217, 50.67351994975921, 49.94515934298116, 51.4177583109948, 45.38996181180401, 45.86238384246827, 41.50037873175837, 46.17706383428266, 46.10070705413819, 54.511445414635446, 54.24087639777891, 58.49952313207812, 57.908990690785075, 58.36956716352894, 59.407477301936, 59.1061725924092, 55.60624168765161, 50.87326272841423, 42.951749832399436, 45.18796759267008, 43.06873844515893, 44.46055619947372, 42.598901256438225, 49.950709496774984, 52.59612068053215, 55.53841214026175, 57.722595737826445, 61.03974811492428, 51.74795127684071, 43.328603313815215, 42.221926181547104, 50.66749126680436, 54.093003042282604, 62.176651031740256, 54.21208620071412, 61.66614670907298, 34.3611119639489, 37.99675295429845, 66.0420762338946, 52.649437458284446, 51.86975263780164, 43.08012116339899, 44.6162703729445, 41.38867355162098, 43.45797484920871, 41.55332680671446, 48.43545083076724, 49.34844132392637, 49.70081137072656, 44.87168727382537, 43.726633671791326, 47.52641016437162, 55.34223479609336, 54.79433459620322, 58.12562319540209, 54.554752303707986, 49.58945920390468, 42.55399796270555, 44.44504322544221, 41.882276381215746, 43.20431909253521, 46.135502399936804, 50.87491404625678, 53.48318430685229, 58.365942893489716, 58.51584019199495, 58.48906609319872, 58.36850027884207, 49.782031889884706, 42.08922455387731, 45.49818784959855, 44.47142116485104, 54.62151496641098, 59.146247448459754, 61.16916279638968, 61.967549477854085, 60.53628052434614, 59.05164380227367, 57.69170707271945, 59.27199079144386, 62.12159664400163, 59.14455690691548, 61.80330414925853, 52.910443736660866, 51.50903578727476, 49.858725993864, 61.543988412426366, 63.22419058892035, 68.4511410805487, 64.59813017998972, 68.67322567970523, 25.158680446686287, 0.5937577940283284, 2.457168059002969, 1.9157559496741143, 0.038778547182559006, 0.2651673002589134, 5.8538727221950415, 55.635329984849506, 30.35252025050502, 41.058637480581964, 33.971095008234826, 14.51843354009813, 19.539312508798417, 38.27970489378899, 50.31792179230721, 57.198861260567945, 37.48935122643748, 4.740071585101466, 0.035564689596574155, 0.033993113846067465, 0.05673540297955756, 0.02388509121843644, 0.11315822676425019, 0.018793285914486455, 0.005507613889001791, 0.05493357184252912, 0.06996957570194237, 0.06140917900108522, 0.041661293906790596, 0.046405358495371, 0.03772551336536004, 0.005975232521567735, 0.02170361180399214, 0.01751470623628026, 0.031363844548562364, 0.03964540631239934, 0.06279305171882434, 0.0640023444899388, 0.06998672841056701, 0.06265115308304949, 0.004408519992965364, 0.029773976533643665, 0.010012216629430411, 0.058358425364619305, 0.052394358095743006, 0.01650026218304711, 0.004795648161351922, 0.05509683284007254, 0.29000763991667383, 9.883029422452374, 80.16373849684193, 69.91094527706024, 71.93063643670851, 56.74298770966069, 46.96435413052959, 23.630799593464022, 31.40758291367562, 40.7238474968941, 58.47081530478693, 43.16821759746921, 0.0726377220463849, 0.06715559686023383, 0.7468800775466428, 2.440333981667796, 3.820677087191613, 3.528816954743478, 2.120079811542265, 16.271105427895826, 79.8413824266003, 68.3866024017334, 78.48638396109305, 66.85758406116118, 70.85498133013326, 65.43475604826405, 67.29139035747897, 52.981881864609264, 54.66914822978359, 52.193093222956506, 51.48900032043458, 47.82087818268807, 49.03862507112565, 51.013444316002634, 49.149153540211344, 46.96783719524261, 47.5452846096408, 49.29488920396375, 52.95209538552069, 53.09303006818218, 53.80026871158231, 47.682414593235144, 47.99526676054924, 44.48839326058665, 47.03685129842451, 50.19731283187867, 56.90524047420871, 55.72490515247468, 60.77043425652289, 59.95788389636625, 60.74622931018953, 61.21279916455669, 60.983289518663966, 58.8031538071171, 52.34605389256632, 45.34985557679207, 46.286399902835974, 45.672792157819195, 46.612568516885084, 44.60692728719404, 53.35167900208504, 57.05713425913165, 60.7069310834331, 60.31184250308622, 64.48065519332886, 53.4305186425486, 45.941690244982325, 43.867976280950735, 53.263139340185354, 56.79066019673502, 64.16591636596188, 57.464762656919426, 63.58528790935394, 35.40306214363345, 39.147713645812004, 67.51101955290764, 54.497364105716834, 54.15984415238904, 44.875801840136134, 47.53446279033538, 43.41312254628828, 46.25379323959351, 42.86260220312303, 51.81489044620145, 50.960794341179636, 50.22673453054121, 46.49137120093069, 47.39029215228173, 51.32460594177247, 58.58212432553692, 57.37668191232989, 60.98412498351067, 57.141308323029556, 52.23443108220255, 45.7648580305038, 46.15895425119708, 44.18250330032841, 46.268906131867446, 49.75746216312532, 54.46877002716065, 53.98937009995984, 61.11792095245854, 60.726103628835375, 60.24541716421805, 60.56006577707107, 51.91891954791162, 44.39399357764952, 46.759786836562625, 45.21050160931003, 55.46295358288673, 60.08977751578055, 63.55395601641748, 65.53638073705858, 62.76040561737553, 60.405285127701305, 57.608105674866714, 61.84734452155329, 63.62839083517752, 61.015703985767985, 63.2767621163399, 54.1995777622346, 53.23603576229465, 50.9066617104315, 63.07849807123985, 65.83788548746418, 70.41786455339002, 65.38951543069655, 71.19796906748127, 32.10050098357662, 0.42488747005981786, 0.7359518639502988, 5.062730168142627, 0.6815929614728498, 0.32848728640425595, 5.21560650679373, 58.16627856223815, 38.51084232330322, 35.05976453904183, 28.137261675250148, 18.511355384703606, 27.172199756868427, 46.52113414579823, 56.35163714808803, 64.7691180629115, 48.32415357712777, 6.957536983874537, 0.08694906418602313, 0.025202628382812106, 0.051364230307480024, 0.015536604013534324, 0.023954374295088555, 0.010579036466116387, 0.058483336000673236, 0.09089835468799838, 0.05705162875294205, 0.0504648162712974, 0.04388142820267428, 0.027377561575943427, 0.032900197491530454, 0.013284256678044557, 0.027382493266955982, 0.057244851449204076, 0.1801033333064087, 0.10418709202279007, 0.20785966407387488, 0.1714592874650994, 0.1328820720194809, 0.1726008504028282, 0.18259023856972495, 0.1720397369635682, 0.13105262341278215, 0.16647467509873454, 0.2063094391938179, 0.19802165488081594, 0.12590039100858474, 0.21818312786279187, 0.4282176849101821, 13.465357557419809, 88.66707617236723, 81.47309626302412, 81.98377316997897, 63.24435157160606, 46.25412664105816, 32.54506045772184, 52.68478978064753, 51.26175388213127, 65.04813978748938, 49.71147629522508, 0.3104886941371426, 0.2885752087158542, 1.2879119621169184, 4.226107731942208, 5.849678727888293, 14.6813315345395, 6.169208240124488, 18.751879046040198, 82.84339981694376, 68.77734107355919, 83.12319817081575, 70.2568434130761, 75.10494001450078, 69.4535812254875, 69.24399329769996, 55.76689020279915, 59.352783772253225, 55.936324827132694, 54.91380999165197, 49.49382789673344, 51.17073135991251, 54.00994685388381, 53.72826183995893, 50.18443176823278, 49.799772770174094, 50.75242627051569, 55.61661635675738, 56.21454246582524, 58.14236387129753, 50.52087699213336, 51.2927641407136, 46.291538207761704, 50.857785055714274, 52.99652407246252, 58.54856060397241, 58.95906017672632, 63.18445697907479, 62.98979759216309, 64.43459087802519, 64.4214391708374, 62.27594975502261, 59.94235523285405, 54.83341317023001, 47.614416383927875, 50.11518232284054, 49.28412622021091, 48.92040875650222, 47.92157326975177, 56.303544967405266, 59.33899664109754, 61.73205037270824, 62.232027053833015, 67.08774874287268, 57.611941752895234, 48.19518212349185, 47.58592428699617, 56.45487000865322, 59.17359421330114, 66.75159377436485, 60.33176422119141, 63.231274389451556, 38.47317580253848, 41.097892561266505, 70.54913843831709, 57.365518846819484, 57.29649297652706, 46.22208872149068, 48.67836713790894, 46.014501202491026, 48.984351235051314, 45.34798852859005, 55.19320434139621, 53.45923823695029, 54.52540120770855, 50.09660205533428, 49.71266869575747, 53.737883413991625, 61.03349977923978, 60.390062409062544, 62.205323557699884, 57.5320234606343, 54.796962584218676, 47.89853326735958, 48.72450205587572, 46.42125491173037, 49.189051889604144, 51.265852758961344, 55.43313572483679, 58.46641440545359, 64.81321727075886, 63.83685696509577, 62.91596289603942, 63.53987862986904, 56.37838379029305, 45.55590552668418, 48.24661224119125, 47.96187562327231, 58.45731058428365, 64.07483108582036, 67.41543923654865, 67.67017364501953, 66.18398758672899, 62.70825770593459, 59.075966419712195, 64.07516448728501, 66.17061230444139, 63.53023352161531, 67.82071421223303, 57.13822141770394, 56.42867249827231, 52.82671290059244, 67.13100464113298, 68.32811201772383, 74.52636687986313, 68.19009165610036, 72.80168502561509, 31.662633072945383, 2.0481909787462604, 14.448346668674102, 6.650614459668437, 0.41502424125229165, 0.33340909488258824, 7.66856610774994, 67.29124915215277, 45.158487058454945, 55.54623334638534, 45.40241533710111, 22.39068538911881, 31.487518856602332, 54.239636928804465, 65.29508829116821, 71.23095620063044, 57.200159565094985, 8.791929983323621, 0.2144330815081635, 0.1704646295477306, 0.14317498422197758, 0.12754122876832563, 0.20857384188040612, 0.15270401483341572, 0.09538080408087662, 0.13984334444807422, 0.16053619133608957, 0.16707087536492657, 0.18409987611155357, 0.1938446217607106, 0.1684372851084317, 0.1914308166071292, 0.10417250570871177, 0.18104703105505437], [0.04489955522360341, 0.00910640671668995, 0.03424849308606598, 0.040594148750026385, 0.14496812026106543, 0.0615976864261733, 0.03907665114609465, 0.04723288284073915, 0.06020535226731051, 0.034503106238140215, 0.1093354250394529, 0.07736842223112622, 0.018997779679334453, 0.057774084139495134, 0.10872008789691234, 24.83050161792386, 73.10297012329102, 61.40179464893957, 62.80002155611592, 32.13259381632651, 15.597717819675324, 25.027033936592844, 52.89686449112431, 36.336056724671394, 64.14956008234333, 18.851866145287794, 0.20782010329346504, 0.11153500902676776, 0.7497847152333107, 0.4852718379228346, 2.5928114643020015, 3.406092120755104, 0.51088945038857, 66.5671560841222, 73.14679868759649, 72.42039926590459, 69.96978082964498, 70.44124187961702, 67.25234708478375, 63.645406076985026, 63.949805536577784, 59.77644289693525, 54.190218987003455, 51.137132337016446, 48.844985500458755, 50.53758236669725, 47.20909041743125, 45.936222460962114, 46.4642087874874, 46.605202305701475, 43.65080248924994, 47.45466216917961, 49.94581437879994, 50.62845583884947, 49.90695153513263, 46.90777001842376, 45.2211037758858, 43.87784104193411, 44.759758518588164, 46.73309118516984, 52.86040213800246, 52.48794955592002, 54.40772618016889, 55.871825372019124, 56.18650144146335, 56.815194622162856, 61.14607180318525, 57.02466487884522, 53.38269710540772, 44.07680719129501, 44.003364732188565, 43.313023659490774, 43.85965301144508, 42.73646662312169, 49.62105781801286, 52.37493038177491, 54.542161495454856, 58.57479733805503, 56.031152048418605, 44.74785412511518, 42.87818185744747, 42.06925576733005, 56.56179381955055, 56.6012881648156, 59.582140445709236, 53.00667516646847, 58.9956598128042, 36.894555168767134, 37.81326840000768, 63.83534293020926, 51.46776853069183, 51.735889988560835, 43.177474391075876, 46.491798739279474, 41.73454030867546, 45.12586470573179, 40.618120008899325, 43.20930442502422, 43.4681494774357, 43.92665493872858, 44.05651284802345, 43.56997420710903, 49.2560028260754, 55.39989755999658, 54.71503211605934, 59.34961449715399, 54.92724803186233, 50.0037673980959, 40.83951427090553, 41.74340878763507, 41.25576011596188, 44.750058497152025, 47.15804469200873, 52.21803949725244, 53.69253689242948, 56.40883314994074, 56.34385124329598, 58.81092010005828, 55.157522539938654, 47.90717817121937, 42.65567364231233, 45.71616964955484, 45.55803929605792, 52.800993919372566, 60.30216209350094, 59.08808262117448, 57.09318476338541, 58.23441405450144, 57.90928879091817, 61.22510756215742, 58.99716992532054, 62.20863403812532, 58.85343859272619, 49.8108377764302, 47.86548337628765, 48.91705905237506, 52.569840800377634, 59.3129324913025, 62.88134013452838, 64.05852579301404, 66.9381416997602, 63.4714646493235, 58.48881898387786, 3.8868452656653623, 0.5299215259090547, 3.2226690986464104, 0.25043778902580666, 0.20047330477785683, 0.08044064165123048, 33.672990952768636, 46.68393996454055, 36.66558288758801, 34.160855354801306, 67.00258624169135, 28.29009682901444, 27.776009421194754, 55.53518402960993, 48.379172663534845, 58.299137084714836, 14.704114621685399, 0.3786315714880344, 0.05598541822344546, 0.05734349676077405, 0.062352715871266784, 0.076563470666447, 0.0565235068901412, 0.0031036237581452777, 0.09470155222281333, 0.05943839483323598, 0.017711654035074097, 0.04534909561757119, 0.05433806488590856, 0.012586124583087381, 0.013766515729648453, 0.04832311788754118, 0.09077100789234524, 0.061994895354033484, 0.017757506312562094, 0.02176419212182443, 0.024682081214362578, 0.0697451655662829, 0.060012987589523684, 0.052149999030535264, 0.07447853939787996, 0.026138896993812055, 0.023102021040094477, 0.05765889515920032, 0.025717655887767196, 0.035852462864450874, 0.08633505237559158, 0.06385885622172106, 32.658230643118586, 81.18160924603863, 69.67933716312533, 68.82651975077968, 42.588648180807795, 25.41938470255944, 22.428473503358905, 47.152918154193515, 38.56458271703413, 73.50961008379537, 19.610532945202245, 0.23800493278090032, 0.10406590457404814, 1.591339286777281, 3.254528060074776, 4.264425366155563, 2.293289226870383, 1.1080128218858474, 70.36987043196156, 74.96765705846971, 72.38409380758964, 70.65308909262382, 72.39056571837395, 70.18127502933626, 67.8417302716163, 65.8958738080917, 62.34964324582008, 57.37570131978681, 54.6030366805292, 49.97661282939296, 50.63628096734324, 50.80502133215628, 49.076856413195216, 49.43282719581358, 47.660896470469815, 47.151153087615974, 50.07485251272879, 52.73392138942596, 53.001740824791696, 51.33135634083902, 49.12279129028321, 48.4371413723115, 46.704752060674856, 46.40032906686106, 47.92558193206788, 54.08602514574605, 55.382101766524784, 57.60164160882273, 58.69215073124055, 58.410387269912235, 59.60104626993979, 62.82792137515161, 59.581861957427, 56.491014649791104, 46.96201639790689, 46.41104105980166, 44.396437214266875, 46.66702670435752, 43.981772084389966, 50.994236469268806, 57.735272838223366, 57.89807473459552, 60.551263978404386, 60.21651714078842, 46.7109650950278, 43.861308251657796, 44.41886140454201, 58.78892737050211, 58.77741129167619, 61.430188686616965, 54.30935705861738, 61.45212258062055, 38.25100491123815, 40.999821539848085, 64.97275575514763, 54.690438855078916, 54.4706606095837, 46.68472836094518, 49.857004073358354, 44.28804251455492, 47.257586602241766, 42.924301085933564, 43.95576677014751, 44.60491511129564, 46.19975082335934, 45.715953919195364, 46.881321476351836, 51.60012106741629, 58.73499870300294, 58.24304719125071, 62.801798389803984, 56.32509446913197, 51.8323528382086, 43.42103396692584, 44.024957379987164, 44.014166939643125, 45.96254548718853, 49.06943528882919, 55.20087257508309, 57.04667329788209, 57.42728440992294, 57.84897842714864, 61.01379771386424, 58.89909890390212, 50.950258854896795, 45.22320616629816, 46.742979480374245, 47.04230339296403, 54.54804112834316, 61.92052025948802, 61.32393952338927, 59.54508973706154, 60.204220510298214, 60.075660905530384, 63.83606856869113, 62.46239962116365, 63.58409158645138, 58.575475908094845, 52.811462725362475, 51.377310829777876, 51.04994589282621, 54.65838916840092, 62.838382336401175, 65.88914302087599, 67.99667958290347, 68.09108318821077, 64.82497653653546, 63.97222580448274, 4.577517288346445, 1.0582810904710525, 5.112341286674623, 1.2877501643473104, 0.2180922698349722, 0.045524112234312686, 35.731752841703354, 54.6567770742601, 36.489001704800515, 36.621891606238584, 63.46999376050888, 34.92022229779151, 35.102420314665764, 62.6168429466986, 52.32216273584674, 69.34814791525565, 19.942143847865445, 0.5082505839245935, 0.039339269916977615, 0.06691859223909917, 0.08591852271028104, 0.026704018988135843, 0.03106564482403619, 0.052609513889277176, 0.056650302102488864, 0.03461579394136225, 0.04948267240017172, 0.052734635199510285, 0.06316550451541139, 0.09779985693673934, 0.06161609934943338, 0.05805542992968714, 0.05741008895359213, 0.10257278388786702, 0.11610980265803876, 0.08741335943341257, 0.14115055091679096, 0.2079950624536122, 0.1939813531334362, 0.19034137829176842, 0.14437003541857968, 0.12702815670279727, 0.17786388976439355, 0.1810926898953415, 0.2044776770015878, 0.16851078358388719, 0.2013093365296241, 0.13861063236911453, 40.9164672513162, 92.12653606168686, 77.10004575790899, 80.2150744776572, 46.2008333975269, 22.566344814915812, 39.83719179707189, 72.95999188576975, 50.08351310606926, 81.17243874457576, 21.675727521219564, 0.30659987861591004, 0.19354420804208328, 2.163032461558619, 2.81981005784004, 6.8798784671291235, 8.916768239390466, 0.957685349689376, 74.83754419511365, 76.84159294251474, 76.14087720071116, 71.6320263954901, 75.46950078779652, 71.15909053433326, 71.2481204925045, 68.9198721608808, 67.56878037606516, 59.27245363112419, 57.315634142967966, 53.17783563367782, 55.44659729926817, 52.89273031296269, 52.51363715817852, 51.744876138625614, 51.669923567002826, 48.95237607340659, 52.27669069843908, 53.258130473475305, 55.72084157697616, 54.67303529862435, 51.83123104033932, 51.08921666299143, 48.69144039769327, 49.37847098996563, 51.61905827060823, 58.28086276208201, 57.296324314609656, 61.66284015101772, 60.91685241268527, 61.68279324808429, 61.28732027546052, 65.71312273702314, 62.41031446764546, 58.19737511296427, 48.32036456754131, 48.99780104237218, 47.720085036370065, 48.90913978699715, 46.8252472723684, 54.58342875203779, 61.32101343524072, 59.97980602325932, 63.51985100776919, 62.80512063733993, 50.179709234545314, 47.5387813198951, 46.77746495892925, 61.89134174777616, 60.40103327843451, 62.4045564282325, 57.450324412315126, 62.38057897936914, 40.293077115089666, 43.15584644194573, 67.42739462083387, 57.35027651632986, 57.396662465987674, 48.96557092666627, 52.6952507418971, 46.69715442965108, 50.97235356607745, 45.66258615063083, 47.2287493367349, 48.13702514094692, 47.59132146835328, 48.38526018204228, 49.580665249978345, 54.77470313349078, 60.00967094975134, 61.06299208056543, 66.50027182794386, 59.98061010914465, 54.2798843691426, 45.80155180346581, 45.63544727140858, 46.67718956547399, 47.90868043899537, 51.49988882003292, 56.54293898613223, 60.10671038781444, 60.374674950876546, 60.63211971713651, 63.99295945321361, 62.64178137625418, 52.98250159909649, 46.704218618331424, 48.986739958486254, 51.25293639398391, 57.75967782543552, 63.79974349852532, 64.28095163837557, 60.13266471124465, 61.53160941216254, 60.90491664025092, 66.82298091150099, 65.38383583868703, 67.69300968416276, 62.447729956719186, 55.964958129390595, 54.609139888517326, 52.832871021762976, 57.889021904237815, 64.20962333679199, 68.44482606457126, 70.29744778909992, 71.01893640333607, 66.25888916753954, 66.93428993225098, 4.477189433190131, 3.6729392986143794, 11.884776719154852, 0.5648135826472314, 0.6277377158403397, 0.18254859403016108, 41.25443827721381, 60.5796697831923, 51.68184757232667, 46.38681650161744, 75.16524253352996, 36.678440417012865, 41.097876871785815, 70.42715272595807, 62.9286164622153, 76.83690178778865, 25.0810214396446, 0.7291928846989909, 0.12305105720917064, 0.12268531917323991, 0.18985742522824198, 0.1688604107907703, 0.09004764469160188, 0.16332386271847835, 0.2319366430803653, 0.14222722620733325, 0.1435178085680931, 0.15091922915270253, 0.11190115308929836, 0.11814366650557327, 0.15018009220159825, 0.15905787146860556, 0.18848931476954492], [0.06432151587139215, 0.04183824872598053, 0.009914032885834817, 0.05434416294578583, 0.02281312353818888, 0.04785705680748628, 0.027718328975982247, 0.054589039120342464, 0.06632328829577853, 0.07859453829305788, 0.06020489644499556, 0.05266291021759953, 0.04686301176045691, 0.08269011328417449, 0.7369799539446832, 48.49540425885109, 69.89751508159023, 64.63941704842352, 56.44466792383502, 31.583834617368638, 25.37617587274121, 33.723052163277906, 44.88812592721755, 38.31066808392925, 65.87501464351531, 2.594623599321612, 0.0824120999764531, 0.053084626298157446, 0.6852342080204719, 3.059844403497635, 6.732657695970228, 2.6558329213050107, 27.63650836483125, 84.27242909708332, 62.959556118134536, 72.73773470232564, 68.21759531574865, 71.39819822003766, 64.87911308965376, 67.33924327358123, 61.495017620825, 62.36550138842676, 60.83634576489849, 54.0235927797133, 45.724065380711714, 46.89955265291276, 45.15098748668548, 46.082075795819684, 48.602504576406176, 45.91529661609281, 44.73995447158814, 46.63339238012991, 49.245349668687396, 48.081048996217795, 48.619586498506614, 48.740246449747396, 46.34171316700597, 44.0068595640121, 45.27132972594231, 46.41325327657884, 50.06161059102705, 51.60956613479122, 51.17367705991192, 50.69268857279132, 55.001718151953916, 59.26655438638503, 57.88212245510471, 59.212245248979144, 50.49489521211194, 42.727743271858465, 42.1320293795678, 42.510667539411976, 44.46662018376012, 40.92877172654675, 49.18029323700936, 49.520068553186235, 54.54431879904963, 56.74389769954067, 50.54241080437937, 41.065603610008, 42.63210411994688, 46.28983197673675, 59.09818272436819, 56.90727226195797, 61.254725379328576, 55.55303473626414, 63.534999201374674, 38.7872713611972, 39.4283200079395, 63.44220769020819, 51.339985555218114, 53.371247706874726, 43.74056985301357, 47.66407751267957, 45.53679181683449, 45.13463512543709, 42.898982186471265, 43.58503610857072, 40.79628190686626, 42.46136334634597, 41.46685423389558, 41.47868802470546, 45.386741545892534, 56.13602838208599, 54.516469970826186, 58.541264995451904, 52.91722943705898, 47.969304592378684, 42.82284898142661, 41.558771056513635, 41.61472366702172, 43.47943413642145, 47.384467432575846, 52.21453682068856, 53.86755697188839, 57.07813855140441, 56.01878873763546, 58.06989415999382, 50.44567338881954, 44.132175368647424, 43.258541937797304, 45.78997688908731, 46.057753178381155, 48.790217445742705, 61.740024551268554, 57.50199771696522, 58.08652893189461, 59.12145806897072, 60.84306086263349, 59.550212352506584, 63.80679592009514, 56.45887474859915, 49.41082662151706, 46.07876139302408, 50.35307407379151, 52.37710337485037, 60.81111315757998, 60.842911812566946, 68.00697188223562, 60.984611357412035, 68.56467800755655, 62.64936331779727, 63.04124339934319, 26.980766519423458, 0.7470124575399584, 4.135304862453092, 0.49342613907590993, 0.08759965669483909, 0.0802932616563574, 6.848858402621362, 60.119022707785334, 36.56163615565146, 28.195905031696444, 27.645912247319377, 17.26647157822886, 31.629942078744214, 44.29612651948006, 54.423764751803496, 52.40823522690804, 29.21528785459457, 0.6306720164514358, 0.05396148670584925, 0.03043513339493544, 0.04078315030182562, 0.03809731498721146, 0.0315909130093191, 0.01751265695108281, 0.07355886616653974, 0.006645484761740532, 0.027326972959863565, 0.022100240420249682, 0.07713134866207838, 0.06331553517450249, 0.035388025890795455, 0.024608705312974995, 0.0155608325017496, 0.040142076435468854, 0.04749145283694229, 0.01321128297281722, 0.04742245895848159, 0.04690867060074403, 0.04924319331504164, 0.02051585567964902, 0.030934186051449472, 0.021880116546526555, 0.04642597775185301, 0.06155225358182385, 0.018135716259900122, 0.037538070802486716, 0.07235054632708912, 1.3233755817336421, 61.62995107712285, 77.00945469640916, 70.56430232140326, 63.46820515971031, 38.14066079355056, 22.892593837553456, 24.09137606620789, 44.356181929188395, 46.92770350363947, 73.17529862926853, 2.864719235127972, 0.159726022712646, 0.3510595767969086, 1.1395902306802812, 6.522304905999092, 8.14269584032797, 2.2949148041586724, 31.23529084267155, 86.91056036180066, 65.57032885089998, 75.02508055779242, 70.75786344466671, 73.25599747319376, 66.87338336821526, 72.18664953785559, 64.72498747610277, 66.8250911466537, 61.75625531904159, 56.31726149589785, 48.535435968829745, 50.95047458525627, 47.07966789122551, 49.13150679680609, 49.59553887767177, 48.43248159654679, 46.45765058455929, 49.726161649150235, 49.93911497054562, 51.454401093144575, 52.48279163914343, 49.58135558712868, 47.83726192289784, 47.63528339324459, 47.43145350487002, 51.264605445246545, 51.96868265828779, 53.457681055991884, 52.094626042150686, 53.53641479246078, 56.18492464865408, 60.50523888680243, 61.18664872261786, 61.262750548701135, 53.21112871170045, 44.770737232700476, 45.06862555780719, 45.030853133047785, 47.201430028484715, 42.67161023232245, 50.92202563439646, 52.41294207111482, 56.57275684418217, 58.62208935522265, 51.72181652438257, 43.7966715135882, 44.13583101764802, 48.66283847439674, 59.414717997274096, 58.92964632280412, 63.09383061624343, 56.78554934840049, 63.86910669265255, 41.72497757019536, 40.91186631110407, 65.13589105298443, 54.14349571351082, 52.8672545186935, 46.11379992577338, 50.22938997514787, 47.32178011248189, 48.216810072621996, 45.102683498013405, 45.89907761543028, 44.03538696227535, 43.26853613699637, 44.634748658826275, 44.86355620045816, 48.87149287808327, 58.59616641075381, 56.93275197859734, 60.49046331836332, 55.33433514256632, 52.33755803877308, 44.94576907926991, 43.82195118934878, 44.24396684092861, 44.56041582169072, 48.97827940602457, 55.66534003903789, 56.18594838726906, 57.75444930599582, 59.12041864087505, 60.513267978545166, 54.649046082650464, 46.70422646307176, 45.49346923828126, 48.06822284575432, 47.596824553705034, 52.29642022040583, 62.2457867283975, 59.2458442718752, 60.45278895285822, 61.19365799811579, 62.204354732267326, 62.95323717978693, 65.16939986136653, 57.29371201607489, 51.1284403647146, 49.71230391533145, 51.40365346785515, 53.96175661394673, 62.50574965630809, 62.278809162878225, 71.66606472384545, 62.90103435516358, 69.46341068513932, 66.46267198747205, 66.83748583639822, 29.51302516844965, 0.251608616522243, 1.7908673156653683, 3.902541610502428, 0.45692106889140227, 0.16258690145707902, 6.612620420994298, 65.79870885418308, 41.43612638596566, 24.454703254084436, 32.61477470397949, 19.54522744301827, 36.92829147461922, 49.655292264876834, 60.466595695864775, 58.5547540264745, 40.15810835746027, 1.396110543320256, 0.028883751722112782, 0.03348747283340462, 0.026251136535598386, 0.02879819693794895, 0.02848171644032963, 0.03849517125936766, 0.04347304971287808, 0.049455035778303305, 0.00894754019100219, 0.09074133730703786, 0.06150140066541011, 0.015017839914728558, 0.046455177193086956, 0.01358074515366987, 0.01685009623366979, 0.14094749165158119, 0.19297063801317446, 0.10732159439113834, 0.16516178425761963, 0.18274187801345704, 0.2715216012250993, 0.0852633336739194, 0.17142974711473913, 0.2267015506062777, 0.24331462689705435, 0.20533399476159006, 0.2710721527616824, 0.13106589205563068, 0.19361972898965885, 1.766628293741134, 71.45854780750891, 86.31890220026817, 80.56578928424467, 71.69642386897918, 45.1233700783022, 36.2887490180231, 47.35188822592459, 63.337837342293035, 53.127931317975445, 76.14272071469215, 4.257410697398647, 0.3663001299625443, 0.3503645818320013, 2.757395587621197, 6.1743955746773755, 14.337649537670998, 6.008145914923761, 32.13335279495486, 89.68644526696976, 67.44986195718089, 80.08340835571289, 74.40486754140547, 75.05247439107588, 67.16221101822393, 74.45139469638949, 67.16177955750497, 69.38383363908338, 67.06919593195762, 60.259898554894235, 49.96478296095326, 53.09619934328141, 49.4218014132592, 51.53451158154396, 52.53561812062418, 50.75882365626674, 48.782729641083755, 53.36173595920686, 54.03586979835264, 53.69706722997851, 55.22909010610273, 53.143369766973684, 51.015652610409646, 51.01260885115593, 50.294058092178844, 52.61208472713348, 55.02893155620944, 55.448974255592596, 55.36194470620925, 55.68686208417339, 57.859619817426136, 63.85095396349507, 63.28910581527218, 65.7018223885567, 55.63957791174612, 47.39362224455803, 46.93414403546242, 47.89322237814627, 51.37609489502446, 45.77709190307125, 54.07207719741329, 54.66128779995827, 60.0767199454769, 62.078066179829264, 55.899595752839126, 44.9671773756704, 47.53440003241263, 52.4929545002599, 63.059164708660504, 61.98054821260514, 65.6734008942881, 59.5251170281441, 67.04541067923269, 42.526517837278305, 45.31077700276529, 68.35125400174049, 56.71941426492507, 57.4919839059153, 48.8220827810226, 51.715336768857895, 51.15836020438902, 51.769461554865686, 48.157233192074685, 48.92267196409164, 46.12044049847511, 47.43245763163413, 46.972159647172504, 46.32703958019134, 51.42929007930141, 62.67474105281215, 58.533231981339, 63.18984239332138, 58.79746244799707, 53.33180827479209, 47.99211709730087, 46.62258625030518, 46.15334526185067, 48.19851221576814, 51.54557658780006, 57.39499938103461, 57.91973798505722, 60.81690649832449, 59.8477594314083, 63.27535006307787, 56.759999029098026, 48.28385122360722, 47.97324657440186, 50.102085528835175, 50.3402949917701, 54.08602122337588, 66.74983655252765, 62.6488769438959, 62.830925910703606, 62.85950822214927, 63.88769480489916, 65.34558096239644, 68.6352728259179, 62.179043677545366, 54.284191131591804, 52.088318870913604, 53.63660781614242, 58.49450642062772, 66.21468405569753, 66.19890043812414, 73.25527575708205, 66.28848737285983, 69.66162373942714, 68.15635927261846, 69.53237379750898, 31.78801359668855, 1.4211361230381074, 12.75285509324843, 4.504742612761836, 0.2772838387998843, 0.26366052788592154, 9.306052692474859, 74.05740045732068, 50.07905729355351, 39.42895935427758, 33.91140437895252, 25.73095621601228, 43.573990714165475, 59.7300491025371, 69.3462416433519, 67.33225360993417, 47.74091282198506, 2.5879457641032437, 0.26290675865546353, 0.24923847838034555, 0.16759791321331458, 0.1884042636881913, 0.10930242963255414, 0.10295723745178792, 0.13839577534987083, 0.09864811545177814, 0.08881283353172964, 0.1929079107339344, 0.18341791996311757, 0.21794839852279235, 0.0880935535796227, 0.13657849221940965, 0.09834007915830421], [0.02630295280757691, 0.035926298418593024, 0.010438165345769978, 0.09153783892191227, 0.08186863720296852, 0.03335611939790749, 0.07440274265865165, 0.027886448886185407, 0.081940526893783, 0.03528744237677705, 0.03980980112007068, 0.05574832550219952, 0.0315272166288548, 0.033924828598936724, 3.0718064067825197, 68.28888831600067, 59.93581271940663, 63.293228226323286, 45.5213886691678, 25.479979438166467, 19.352189956172822, 55.30737277000181, 41.416357640297186, 59.631546620399725, 49.19773209479548, 0.25306346345572706, 0.11888252000414556, 0.3951610216209966, 1.2199598406591725, 9.837852543400182, 4.477624816279258, 0.21865647826944629, 71.02055241984706, 65.56183691947692, 69.28812780687886, 61.38170426891696, 69.41608336664015, 66.16747440830355, 69.25830994882892, 63.306407390102265, 65.99191696413102, 61.836918861635276, 60.05569996372346, 56.51785150651009, 53.45950495812201, 46.47925499946841, 47.37016254855741, 44.68687303604619, 46.85090349566552, 44.92428233546596, 47.345745794234745, 43.212242280283284, 45.82921628029116, 47.06870486659389, 46.88515363201019, 46.37126038151403, 45.730839313999304, 43.468431888088105, 44.40118720454555, 45.41062485787177, 48.16747842296478, 45.56615467994444, 47.580138790992, 49.30399694750386, 55.38642814082485, 58.84043593560496, 60.04927119901104, 54.07443061951668, 48.2944102441111, 43.10460459801459, 44.453970539954405, 41.51141235905309, 43.32101352753178, 41.81088924407959, 45.56798250444474, 48.89605868247248, 51.05356231812508, 48.708118315665956, 43.673093318939216, 40.432336945687574, 44.728273653214984, 46.54138926536807, 59.22195311515563, 56.42285954567694, 60.66959796413299, 53.46722418262113, 64.0905087993991, 42.17616388874669, 39.149816036224365, 62.97031910188737, 52.560281984267704, 53.92991481288787, 45.4115270030114, 48.350366776989354, 44.59318722448042, 47.617981818414506, 43.30699105416575, 42.67034330675679, 40.6662671027645, 42.054056582912324, 42.192492715774044, 43.342210015942975, 42.039912516070956, 52.743680246414684, 56.89244178033645, 54.63289768465104, 51.89690720650458, 46.64535560915547, 43.16712717856131, 41.335152810619725, 42.491663655927105, 42.594457211032996, 44.90902823786582, 50.051949793292636, 51.954303249236084, 52.246880685129476, 51.88800342621342, 49.18429405458512, 43.910231974817094, 46.11405880220475, 44.163048344273726, 45.7954760520689, 43.46517239847491, 47.57361981176561, 57.61139262107111, 58.735947916584635, 57.58606587686847, 60.430760921970496, 57.42953192803168, 59.20797771023166, 50.3614914801813, 47.126249959391934, 44.9016777161629, 48.48575522822719, 52.65787839889527, 59.65816774675923, 60.5795991805292, 63.40176020899127, 60.73952205719487, 66.05057208768784, 65.95593314017019, 57.99300393750591, 70.6863586364254, 51.85624399492818, 2.3926458051127772, 4.004391100137465, 5.186817290321474, 0.07568705075931165, 0.005485112929055768, 0.4281688697876469, 36.03615230129611, 58.62376028491605, 39.102265142625384, 26.99477722567897, 25.84442646272721, 16.369745192989228, 33.90452454167028, 48.189306412973714, 50.17833248261483, 54.2827320098877, 8.567848897749379, 0.05113679029408002, 0.024283587174009413, 0.07410163946089245, 0.05331210461595366, 0.054504290643718936, 0.06364734317626684, 0.035658290219162746, 0.05138825099434584, 0.02573170785551831, 0.03922952399138482, 0.05033880629907212, 0.040440452360217614, 0.0786973779360133, 0.03946146477133997, 0.07334279106749643, 0.06500040000725178, 0.024184198757152886, 0.024725995289402145, 0.0552984212164677, 0.031597821207176295, 0.009972299618135777, 0.014701075006967351, 0.016943032274984064, 0.11417492503120054, 0.06432458788396851, 0.02427445349073218, 0.05916111313948228, 0.07908713282837022, 0.14665789571740936, 5.339647541123052, 81.98220422191005, 67.2955951383037, 72.53745848132719, 53.04352191186721, 34.22837895731772, 19.66060200045186, 43.8268227731028, 46.98196949497346, 65.27770434656452, 52.74306443429763, 0.12188851112319578, 0.12631798553611004, 0.6236804529063164, 2.690912393792983, 7.232847165676856, 1.3547855543513454, 0.9871711545894224, 73.11341931743007, 70.6260561173962, 71.58268297872236, 66.01920097104966, 71.90396431953677, 69.82631621822235, 69.90052746188256, 68.13101291656494, 67.83438759465372, 63.31368338677191, 64.29373072039697, 58.08233984055058, 57.29766968757876, 49.321173006488436, 49.24658913766184, 47.210412256179325, 48.97346665782314, 46.73964154335761, 48.52948573327834, 46.83564155332504, 48.704250858676055, 49.383738733107045, 49.07688386978642, 48.43895742970128, 49.398169132971, 47.023825107082246, 47.79619862956386, 49.18283493288102, 50.661156638976074, 48.36098071067564, 50.39390986965549, 52.14307123614896, 59.32137343191332, 62.12541311017929, 61.66003957871468, 57.09176486538303, 49.632154203230336, 45.35891625189012, 47.12092338069793, 43.591555087797104, 45.853523208249, 43.53408059766216, 49.801608439414736, 49.87861241063764, 52.820664605786725, 50.72183178317163, 45.86478041064355, 43.67834929497012, 46.6847401280557, 47.74060295474145, 60.40447319707563, 58.71581046811996, 63.55415997966644, 53.58554640123921, 64.7806223746269, 44.58811559984761, 41.44961541698825, 66.48615129532354, 54.90570245250579, 54.64727317133258, 47.44302841924852, 51.87285131023776, 48.438969196811804, 52.11769350113408, 46.423180795484974, 45.167649715177475, 44.000870104758974, 44.750470346020116, 41.535079940672844, 45.280429624742084, 46.12721835413287, 56.052548577708585, 59.080959596941554, 57.614597197501894, 53.5972664433141, 49.270766627404, 44.72412378557267, 44.388274761938284, 42.95579379604709, 44.01581825748567, 48.4250134037387, 52.921194953303186, 55.308114097964385, 55.11904016617806, 53.85049858400899, 50.539355278015144, 45.99100228278868, 47.86376930052235, 46.28722752294233, 46.877971772224676, 45.00161186341317, 47.61859370816139, 59.51772336036929, 60.830772076883626, 57.45800049074235, 62.828682314965036, 60.87927218406432, 59.986183797159505, 53.23647899012412, 49.58856490350539, 46.64556741714478, 51.23196348067253, 56.47970645658432, 63.47388867408999, 63.25774254337434, 64.60300568611392, 63.44203118355044, 65.83276287201913, 67.73726186444684, 59.472572957315755, 71.27634586826449, 57.27574363831551, 3.784132854592416, 1.1503959927828082, 2.947254728886389, 0.3839252696883294, 0.06167593464675931, 0.13010877244655164, 38.72578428637597, 64.92829568924444, 38.46925343236616, 27.287707674887876, 28.56736917649546, 21.94687116530634, 39.98603397800077, 54.82617639726209, 56.53246625777214, 65.53885183026715, 14.439822377697116, 0.09987557982845653, 0.06575210080031427, 0.10033206863989753, 0.010117660971328376, 0.018917562612783045, 0.010971853794950632, 0.061788534249870054, 0.07230728534200499, 0.016368636786336863, 0.020348488450831464, 0.08638311673196093, 0.01402867963582638, 0.044911061864226096, 0.053066768788642464, 0.037016594752428994, 0.1695858807333054, 0.15835763646229623, 0.14325261957222415, 0.1107158235484554, 0.16904454768425034, 0.09989716818616276, 0.11910453228460205, 0.11311853574889322, 0.22884137207461944, 0.14189149583539656, 0.20664446476486423, 0.23091051427106704, 0.15137235483815595, 0.24211972891803712, 8.727882581372416, 94.81315566647439, 73.97412853856241, 82.84594935755577, 61.15701129359584, 37.7479923156, 28.61892677122547, 76.43692985657724, 56.588120768147135, 76.36868061557894, 58.88259357021701, 0.9416758281088645, 0.33181425304182116, 1.1620906620256364, 3.3290891301247383, 24.73949674637087, 18.2236534549344, 0.8960251389972625, 79.66245174407959, 72.81128698779692, 75.73784582076534, 67.38661766052246, 76.23724199110463, 72.65034429488644, 71.8189351789413, 67.19544133832379, 71.55678749084473, 67.0996884376772, 67.39967130845594, 61.069189425437685, 60.346006347287094, 50.98538760216006, 51.1625296838822, 50.03076507199196, 52.5049687200977, 48.54348859479351, 52.53311564845424, 48.527485324490456, 50.906685244652536, 52.557344129008634, 51.32261337772493, 50.65057800662134, 52.56728341502529, 49.694872902285674, 50.782797182759936, 51.524536994195756, 53.33905289250036, 49.59584874491538, 53.26099772607127, 54.6617780962298, 60.98426618883687, 64.14295873334332, 64.73177709887105, 58.1132520398786, 51.59291567340974, 48.44900261971259, 48.57663262274958, 47.29957557493641, 49.12437592783282, 45.09340317018571, 50.8591971089763, 52.96093640788909, 55.150870200126406, 52.348254342232984, 48.43786701079338, 46.26671352694112, 49.461197699269945, 51.38530462018905, 61.89820981794789, 62.15188126410208, 65.63660906207177, 56.477211829154726, 67.24950728877899, 48.02799893963722, 44.643428864017615, 69.76526060412007, 58.17069907342234, 57.68890650041642, 50.264177476206136, 54.157180863042036, 49.9041509628296, 55.6494426727295, 49.274445810625636, 47.63928421082036, 45.39077766479985, 46.992018607354936, 45.204476848725356, 48.53298840984222, 47.24408580410866, 59.20396512554538, 62.887125630532545, 58.799913929354766, 55.31780235229, 52.342527681781405, 47.54876375198365, 46.58033055643882, 45.48744840006675, 47.444322801405384, 51.30588446894, 55.85842263314032, 58.002978524854115, 57.77455537549911, 56.73699432803739, 54.52687994126351, 47.88413032408684, 51.50150091417375, 49.508513250658595, 50.286072146508005, 47.707564830780036, 50.76785295240341, 62.21571391628635, 64.59092478598318, 59.36341731779037, 65.61592248178297, 63.44435322669245, 63.94993497479347, 56.577212656697924, 51.43420873149749, 48.07046644149288, 53.766285296409364, 59.40984249114991, 65.84263940011301, 66.16568580750497, 68.06226161218459, 66.78865232775289, 69.76885349519792, 69.01007098536338, 64.68162959621799, 72.30268893703338, 60.55025200689993, 3.3654048846613978, 10.313458558051817, 15.090744610755676, 0.25741357115968583, 0.12706982422499888, 0.8007418808917847, 45.149693104528616, 74.32190156752064, 56.74700421671714, 37.082056230114354, 35.63648631495815, 25.473772287368778, 48.56175507268598, 63.03182578855946, 65.02053806858679, 70.99757517537763, 17.41119330929172, 0.18224393618443321, 0.1682159316635901, 0.28518220529921595, 0.07279214238928211, 0.1855955402096433, 0.26238462376979094, 0.2989080494209644, 0.11479495829271694, 0.0810508000394029, 0.27343918058660727, 0.15900565491568658, 0.094421363225387, 0.17378880762525145, 0.20218926511945265, 0.15344267681000695], [0.05718374444592384, 0.01891004154458642, 0.05132496830136065, 0.023780432116660862, 0.01267330730409031, 0.027356798677975615, 0.01310710650643394, 0.04089246721818082, 0.049376588374856985, 0.015519407254854038, 0.008165160449401987, 0.06705327049618767, 0.020315274708874283, 0.2107331066602661, 15.045720704140203, 69.41666387742566, 59.239027192515714, 55.91840351781538, 32.70479702180432, 26.151518629443263, 33.76550005328271, 45.071037815463164, 32.379204996170536, 75.44523700591057, 22.94742072782209, 0.07184614637686361, 0.06813997387765877, 0.9515033265756023, 1.657639109799939, 12.735537828937655, 0.308269398707536, 15.929433645740634, 87.20757792072912, 62.50860514179353, 66.50057777281731, 54.090414277968875, 67.51497330204134, 66.36295749295142, 71.98316481805617, 60.97083991573703, 66.0026171899611, 58.89555308126635, 63.62846143784062, 58.62057139796596, 56.36219616859191, 49.33801958637853, 49.24145475510628, 45.88086605072022, 46.48232621531333, 42.12556923589399, 44.71716157851681, 45.67016024743357, 44.90107759352654, 44.332898739845525, 45.46474179913921, 43.75349406273135, 45.28043354711225, 44.711336858810924, 45.620856054367565, 46.22231621896067, 45.71354950627973, 43.63910990376627, 45.744461705607755, 49.52175517236033, 57.52580650391118, 57.507516491797666, 58.77585803308795, 52.82311216477425, 44.228214602316584, 43.09738351452736, 41.54969076956473, 40.61896724085654, 42.69237918238486, 42.891262961972146, 45.82819646404636, 46.93501087927049, 46.761751944018954, 40.757536734304125, 42.49286782357001, 43.51395883867818, 44.39083606966081, 46.74932979768323, 52.46945558055755, 53.81877837642547, 57.81321033354729, 52.170986744665335, 60.83124276130431, 45.33389937493109, 42.31041485263456, 61.724389983761704, 52.80301786238148, 50.53388749399493, 48.508661870033514, 50.957013176333525, 50.118292762387185, 52.643965751894065, 48.16409733987624, 46.92980197168166, 41.96090421368999, 42.24038485557803, 39.64598017354166, 42.1651263390818, 41.44688544734832, 42.75607847398327, 51.26224417840281, 52.131641449466834, 48.1954998354758, 46.685681496897054, 42.40989792731501, 41.276442773880504, 42.55766537881667, 42.44914908562937, 43.963744871078, 44.67250147173482, 46.61979352274249, 44.65167368611982, 45.68413565235753, 42.00680378944644, 44.61401893246559, 43.47672377863238, 43.01349186128186, 44.66449199184295, 44.942603726540845, 45.667677387114495, 49.73861125207717, 55.869860264562796, 56.22865515370523, 55.707023066859094, 53.083161384828635, 48.98192328791465, 45.69294921813473, 46.27748043306413, 49.26028997667375, 55.432374785023356, 59.92530468971499, 56.62911345881801, 59.726032595480646, 62.13703117062969, 64.90028604384392, 65.1308233507218, 57.03571027325046, 64.20177075170702, 64.63527110315138, 63.78728997322821, 22.460913465869044, 0.9724036760387883, 3.864706918116539, 1.4632094266914553, 0.06543027492420328, 0.022994140538597302, 14.416591159759031, 64.36952660160681, 39.82667200026974, 41.730280614668324, 13.702311861899592, 19.34844801502843, 35.13162236059866, 51.96558006348149, 53.595077760757945, 55.34751822871547, 29.963232855643, 0.20603377011514482, 0.054308080204552224, 0.012269159534855956, 0.0370544126828111, 0.027630753634918123, 0.030541562159816106, 0.05519453203305603, 0.00787199296492843, 0.014289531616433976, 0.04050002335720966, 0.025667971255437984, 0.06384539222645183, 0.021196294973994938, 0.029521029622804736, 0.02125560550109273, 0.0049688304763197185, 0.056397048756480224, 0.04343889751321366, 0.05208884223153995, 0.0424231989910045, 0.007920652954658915, 0.06080331453572839, 0.061617282955276395, 0.0972991035650334, 0.015347452116979948, 0.03587715770869005, 0.027453385128249085, 0.06073251268976639, 0.1715596756266971, 23.960619934143562, 78.32772408762287, 63.68013082012054, 62.09961568155597, 38.312374314954205, 27.51773899601352, 30.74697929043924, 49.243608136330884, 37.787690624114006, 84.46344067973476, 23.443114180718702, 0.2231775767981045, 0.2678803240339602, 2.4691165791403864, 5.099987291520642, 15.3617254764803, 1.1565088841222948, 17.84577819608873, 90.68089946623772, 66.22610599763932, 69.69635240493282, 56.58164101262247, 70.06259195266232, 67.18474895723405, 73.84777330583142, 61.991903474253995, 68.72486760539394, 63.323002938301336, 64.94007848924207, 61.00373291200208, 60.39828369694372, 50.37447060308149, 50.49477754100677, 47.768185061793176, 48.25274682814076, 45.77538959441647, 47.29774775043611, 48.64091634750367, 46.77624902417583, 47.84365930864888, 47.648176224001, 46.18649713454708, 48.77225691272367, 46.66235123911212, 48.03973859356296, 46.75340121792209, 47.65080028964628, 46.5126226025243, 48.201838385674264, 51.71917284688642, 60.14429453880557, 60.46939234579764, 60.682424114596465, 55.35501387811477, 46.967684222805886, 45.03376353171564, 44.54218072275962, 42.99417026581303, 43.949538046313876, 45.863144782281694, 47.135518520109116, 46.9035848494499, 48.48340965086415, 44.14282852603544, 45.28314390490132, 44.907074897520005, 46.7839329473434, 47.80932288016043, 54.73236114748063, 56.2192806889934, 59.33890642658357, 52.922069641851614, 64.27733129070651, 47.7861338277017, 45.13360354208177, 62.55732490170387, 53.38681951645882, 51.861421523555634, 50.308123711616766, 54.07736455240558, 52.14967258514897, 52.8528162740892, 49.42219757264661, 48.73320579528809, 43.53582997475901, 43.47058919168288, 42.372713858081454, 44.080129438830966, 45.39784969822053, 44.886050993396395, 52.76212323096491, 55.705465885900686, 50.26475798699164, 48.588187925277225, 44.24042101829283, 42.53291130065919, 45.03208475728189, 43.979905036187944, 46.643763126865515, 48.15026706264865, 48.138919645740145, 47.43462670233942, 46.647775711551795, 44.05875252139184, 46.8435529739626, 45.803877768978, 46.84565536437496, 46.49152417336741, 46.402533438897905, 47.4714812924785, 51.698274458608324, 56.7564453617219, 55.87532412621283, 57.03950320520709, 55.02941400774064, 50.46687772197109, 48.325726447566865, 47.83488496657341, 51.715277933305316, 57.97923249583091, 61.048400863524414, 60.13185278061898, 62.33100806513141, 65.09406681983702, 65.00121255074778, 66.6962726654545, 60.3723999761766, 66.18434844478485, 66.1547580842049, 66.5257986130253, 27.048882399835897, 0.4972221966712706, 5.114029376737533, 4.624646527151908, 0.12016649102611889, 0.03628838221512495, 14.03855900610647, 72.05922742043772, 39.13677415540142, 42.75658445973551, 20.123233795166016, 23.78303070222178, 42.20351457595825, 58.829633728150405, 58.30806047685685, 61.83539305963824, 40.44371966392764, 0.5068344550748025, 0.015647220406531086, 0.0388516741053712, 0.006877911528722654, 0.018852276599875862, 0.02678355232121483, 0.02432962905825867, 0.017149657679481373, 0.04393045399938861, 0.04785396947315143, 0.020890064732802492, 0.06101772722397601, 0.04154669481419748, 0.03472131489205264, 0.03096516473188756, 0.14735696627007377, 0.1599430247780777, 0.1235435981183283, 0.2165697466942572, 0.12757679056977073, 0.1654175350502614, 0.11415391123943752, 0.11426946028105675, 0.19745318699748288, 0.1220358451527934, 0.12028156509322506, 0.21942596762411057, 0.1772231951115593, 0.4441101176123466, 30.383171612216582, 90.42329388280069, 74.80506697008687, 73.93811333564021, 47.04688079895512, 35.84426603009624, 48.79586173642067, 62.46888722142866, 45.55766667089155, 90.11763142001244, 26.078919479923865, 0.3627439498180344, 0.28217463603904175, 3.3208036134319925, 4.40609892529826, 34.53593984726937, 7.3125507081708605, 18.76335786234948, 94.97011323128977, 69.10173677629041, 71.73887175898399, 57.79951341690556, 72.29647590268043, 70.14565990817162, 78.00485810925885, 63.22517118146343, 69.45976288087907, 65.06715151571458, 68.02388514241865, 63.24833277733096, 63.51470093573294, 53.8439521481914, 53.38680382697813, 51.62568315382927, 49.713825794958304, 47.862263110376176, 49.37132835388184, 51.50876906610305, 50.072565770918324, 48.368888208943034, 49.516361913373395, 47.62662279990412, 51.01637824889153, 49.12338356817923, 49.3212200749305, 50.43633422543926, 51.85424750851047, 48.28515345050443, 50.25608562654065, 55.505170053051366, 62.72908941391976, 62.36745865114274, 63.565644679530976, 58.281957103360085, 48.975274870472575, 47.32614963285385, 45.991735766010905, 45.13412521731469, 48.36693486859722, 48.912324751577074, 49.33013954470235, 50.90679507101736, 50.58709052301223, 46.95361468099779, 47.22625470930531, 48.57495384831583, 48.94602183372744, 51.3771931586727, 58.27122157619846, 59.84928131103516, 62.985514363934925, 56.03838489901636, 66.26678882106658, 50.266781930000555, 47.53381952162712, 65.99147765867173, 57.678292566730136, 55.23140822687457, 53.97086435748685, 55.91517148479339, 55.216440462297015, 56.799991515374955, 52.74880286185972, 50.05802554468955, 48.954772641581876, 45.816809823436124, 43.68204024530227, 46.478643109721524, 47.94369543752363, 47.153435907056256, 54.76995706558228, 58.54824289198845, 53.43384481245472, 51.2586042188829, 47.86101971903155, 44.9686796434464, 47.273311384262584, 45.83064794540406, 49.31363028864707, 50.17522596543836, 50.37924804995137, 49.797866498270345, 50.977856651429214, 45.838288722499726, 48.74876583776167, 47.022467967002626, 47.78632210146996, 49.61154607034499, 50.23024505184543, 51.28631576415032, 53.9399992266009, 59.46588139380179, 61.27773400275939, 61.06110149814237, 58.9644181343817, 52.40769786219443, 50.86670844785629, 50.234045828542406, 54.963427974331765, 59.626518141838815, 63.93381795575542, 62.770278223099254, 65.30724763870239, 68.24308287712836, 67.40152266717726, 68.32716280414213, 64.45463026723554, 68.36459006032636, 68.51535812500985, 68.84865760803223, 29.989497046316828, 1.9461131336227542, 13.74970978306186, 5.635628123437205, 0.235329661818762, 0.16914035464006086, 18.54097516305985, 78.01446791618102, 54.01824658916843, 55.24746641036003, 22.279009626757716, 28.452802627317368, 48.961495584057225, 67.7634632971979, 66.42138511903825, 70.84504988885695, 46.35315864316879, 1.1850404499038574, 0.10780190853702445, 0.12843167574535455, 0.11237939879778894, 0.11155350238925989, 0.19991671125735008, 0.11061089248546671, 0.12318870022652612, 0.08241174757600793, 0.16382557370008963, 0.15598734510281395, 0.15684067511991148, 0.1616023865438277, 0.09790713988965559, 0.11569560956089728], [0.04073188369793277, 0.045738911796962066, 0.042723306274462136, 0.02999424979451203, 0.04634772570082738, 0.0836037190991544, 0.09156335731067004, 0.03993945000993629, 0.03473369870334864, 0.06123066902340901, 0.06798497130793911, 0.129376377069181, 0.07758046770768781, 1.889797458725591, 53.18250717655305, 66.81752097222113, 62.83566021150159, 55.36139557438513, 34.60074524725638, 22.032017977006976, 32.31665299784753, 34.19245789127965, 48.811504148667865, 74.13715008766421, 7.626006430195225, 0.20771306548868457, 0.1873293350781164, 8.934222786657273, 10.838765905749414, 5.941785295163432, 0.5382497596644586, 47.7688910884242, 76.58259099529636, 62.529597666955766, 62.54413397081437, 49.39959687571372, 57.70884783037248, 61.22581358878844, 67.7197680934783, 65.26359558105469, 61.791564495332786, 62.22613957620437, 65.79756744446294, 59.384605961461226, 59.026815199082904, 55.40001523110175, 50.478240828360285, 46.49047297816123, 46.565300033938506, 43.305641758826475, 45.52013351071266, 43.13143360999323, 46.03579575015653, 44.34757624903033, 44.93317827101677, 44.830447473833644, 45.08304026819045, 43.84350853581583, 44.88150496636668, 43.9670749633543, 43.55631651416902, 43.29767934737667, 45.336660723532404, 44.57689762115479, 53.08408314181913, 55.55555682028494, 53.99001729103827, 45.9205408250132, 44.659153646038426, 42.72060063577468, 42.95416601242558, 41.1876363908091, 43.66973969244188, 41.16964840119885, 43.46483899701027, 40.99111387806554, 44.34151226474393, 39.94446077654439, 43.49331148209111, 42.70099270728327, 42.94250480590328, 43.42631739954795, 50.62003451008951, 49.84235009839458, 55.23948438705937, 51.513573969564135, 62.501662546588534, 42.45454626698648, 40.43493355474165, 63.80902382635302, 51.0398732462237, 53.332526068533625, 51.92701924231745, 54.992449591236735, 52.95451941028718, 55.710035447151434, 50.699611556145456, 49.15507631917154, 43.90968676536314, 40.83406609873618, 42.0785713964893, 41.67619505236226, 41.06169692931637, 41.13428823409542, 41.154500207593365, 44.20756332335934, 45.38951466160436, 44.125115102337254, 42.69416778318344, 43.235078319426506, 41.08562730973767, 42.83120362989364, 41.90870531143681, 42.639992006363414, 44.39350328137798, 44.868384638140284, 43.63812931122319, 43.69851420002599, 41.91842494472381, 44.437802530104115, 45.28585818506057, 43.974911858958585, 42.929447235599646, 44.26639103120373, 44.97798742786531, 45.066813422787575, 47.65427550961895, 45.37952438477547, 44.02008187386298, 44.475845598405414, 46.04569973484163, 48.04211947225755, 55.97933361607214, 59.088357187086544, 57.841423942196755, 62.458787118234945, 61.78595942835655, 62.70212704135526, 60.87836611655451, 55.575733492451334, 63.46893864293253, 64.46629147375783, 66.37268497097877, 64.33808488230552, 47.34287069689843, 7.006964241304706, 0.4855453619553197, 3.1318534814542343, 0.16042326997605064, 0.0549920205207121, 1.3148883081251577, 49.760764798810406, 55.96471102006974, 42.45438937217959, 41.36557471367621, 19.986246978082967, 14.903401424807889, 37.515897827763716, 52.42091624967514, 51.9251992625575, 52.64103181900517, 4.653486734436405, 0.2961336466814241, 0.15283506183374315, 0.030650823534796798, 0.03206643336001904, 0.022664577174451084, 0.029131772687598586, 0.02413277893567518, 0.031681560362959583, 0.04751139410561131, 0.03075896642140804, 0.03223953092651021, 0.0754048546115237, 0.09936701235992294, 0.041122209325793295, 0.02892715060302327, 0.037566611408105785, 0.015694921828746315, 0.011308467083220041, 0.011807860648860375, 0.018145759672587438, 0.023218039310567325, 0.026280966084150058, 0.050095067765083046, 0.05525086247812837, 0.05851007629967025, 0.0481727501497634, 0.16376431730966415, 3.201482906456917, 63.79959837082894, 75.54513977419946, 70.94456826486896, 62.2264886671497, 43.80172352637015, 32.79145982957656, 37.13273325274068, 37.731137890969556, 51.54228964159566, 78.14717738859116, 8.207414948171186, 0.3284455499341411, 0.33617332397449406, 13.44375608428832, 12.119873781358043, 4.967607298204976, 0.1967138202200013, 50.144247085817405, 78.85462391761043, 65.01727465660342, 65.32341957092285, 50.67799145175565, 61.42061418102634, 64.11336052802302, 71.08318482675861, 63.92032107999248, 63.85345251329484, 64.76703136197983, 67.55455786182036, 61.68266773223878, 61.6208197993617, 58.127137230288604, 51.82232333767799, 49.4900506542575, 47.87130809599354, 45.59321511176325, 47.85469293594361, 46.542338478949766, 49.4181183076674, 46.690564847761586, 48.01285466840191, 46.37583778750512, 48.00597090874949, 45.45695981671734, 47.5259316352106, 46.91966264478622, 44.832318444405836, 46.16273149367302, 45.78931400852819, 46.09063440753568, 56.30291738817769, 59.24958229064942, 56.57244697693856, 49.15675509360529, 47.92745290264007, 43.89421301503336, 45.01606579749815, 42.95669594118672, 45.38791825694423, 43.24482148693454, 45.953159255366174, 42.939527726942494, 47.09731071226059, 42.33227422160488, 45.07088876539662, 45.55992987848098, 47.017313972596206, 45.26767407694171, 52.15279479180613, 51.554456833870184, 58.948352106155895, 54.159820618168006, 63.7689999611147, 45.0482645342427, 43.840951150463475, 65.83166460837087, 52.52101121410247, 55.605096355561294, 53.62179302400159, 57.43146173415646, 53.73940529361848, 57.913340599306174, 52.335487027322095, 51.434789242282996, 47.25784940104331, 43.798558173641084, 43.42092806293119, 42.96486623825566, 42.77806335879911, 44.45548065247075, 43.98137200263239, 47.30318415549494, 47.567049841726984, 45.7198449104063, 44.23839707528391, 44.52413781996697, 43.97813212487006, 44.216019953450854, 45.282269216352894, 46.25232235077889, 45.76162207511164, 46.77095774681338, 45.53272824133597, 46.9958782196045, 43.9162528130316, 45.65855395409369, 46.70082576813237, 44.953833472344186, 45.664931727993874, 46.09208568449944, 46.9419103284036, 47.64523444637176, 50.07720593483218, 47.62066471961237, 47.13251398455712, 46.95824307780112, 48.47793402210359, 49.66219955875028, 59.19651262221798, 61.72951652157692, 62.30491645874516, 64.05020644587856, 62.79920570312008, 64.6462223606725, 63.55257141974665, 58.14046152176396, 64.77611949366909, 65.23240489344444, 67.69425699787756, 64.72395981511762, 53.3516711573447, 10.902329875576882, 1.2117878275532876, 3.0681983165202604, 0.3816757597509892, 0.04968899519993894, 0.878645361911866, 53.20785353260656, 62.94855779217136, 37.63625183413106, 28.91116099972879, 26.448432245562156, 24.748853560416933, 42.97480944664248, 58.6665141197943, 57.83445389040055, 64.1156433474633, 8.549242154244455, 0.27137481877880715, 0.10851890554711704, 0.10906172480674521, 0.03668107888511112, 0.013579237875678848, 0.034540682850826177, 0.030734723569044185, 0.028091997937149102, 0.07731668831359956, 0.057203448227336334, 0.02805334880136915, 0.051345346240146514, 0.03190283719900876, 0.00433371581640395, 0.1155277903402044, 0.20796999605672978, 0.17676360364402496, 0.1216680923056218, 0.22839652013874825, 0.14464647058517704, 0.23044192893130166, 0.21989299014451044, 0.24023555099002777, 0.12879203584405685, 0.1779845486124677, 0.2770518367328952, 0.2120467482675468, 3.3168126017816606, 75.2153939585532, 85.76664816948676, 79.53993258937713, 71.56653850309311, 48.93957737953433, 32.76598207412228, 49.125580095475726, 46.99031237632998, 65.10550052888932, 83.97700402044481, 10.025671316731362, 0.46543671839660217, 0.34838353974684594, 14.269903340647298, 21.317024807776175, 14.448629079326508, 1.0119976740210288, 54.87180925184681, 80.70776339500182, 69.22371464390909, 66.40498176697763, 54.15177191457441, 63.49252777714884, 67.48320994838592, 73.96899807837703, 67.41885954333891, 63.28971378264889, 67.28942917239281, 72.14956745024651, 66.16479935184603, 63.836845197985255, 61.35216097677908, 55.11351354660527, 53.48901687129852, 50.86474726277014, 48.08338280647032, 51.47195369966569, 48.69840260474913, 51.95457781514814, 48.22327806103615, 50.4196092390245, 48.40770790653844, 51.093009594948064, 48.45677283502395, 50.30950438591742, 49.94215480742916, 48.506041726758404, 47.437541023377456, 49.05429493996405, 50.20012909366239, 59.015848252081106, 62.27954264610045, 57.703682068855535, 50.42600270240538, 49.79939230026738, 45.50171798275363, 48.280030835059385, 44.359947404553814, 49.08457171532416, 45.6629587757972, 48.17730396024643, 45.64915203279065, 49.46683806757773, 44.59186538573235, 47.191922203187026, 47.896313205842056, 47.89340672954437, 49.16471358268492, 55.778814208122995, 54.5233811870698, 61.96210130568474, 55.883196323148674, 67.18937735403738, 49.66321545262491, 45.88383528494066, 68.85634545356997, 54.28720743425431, 59.02029229748634, 57.14484237855481, 60.11643786584178, 57.776740135685095, 59.24097268812118, 55.28426216494653, 54.46502808601626, 49.704659215865604, 45.04655438084757, 46.889397636536636, 45.30504641994354, 45.574360278344926, 46.570544242858894, 46.2497139746143, 49.63801422426778, 51.91739766828476, 48.93046179125386, 47.96827300902336, 47.838517081352975, 46.75602528356737, 48.00832040848271, 47.26816915696668, 48.113694883161976, 47.73203257591494, 49.34960626786756, 49.76558146938201, 48.500954412644916, 47.70463482026131, 47.8501312194332, 50.782479470775975, 47.56497098553566, 47.47450936225153, 48.51834227961879, 49.943056952568796, 49.478361991144, 53.45925784880116, 49.12801196498256, 50.451584400669226, 49.47382380885463, 51.87594213793355, 52.78128793162685, 62.4185553673775, 64.11492555372178, 65.6033944314526, 67.57358135715609, 65.37739138449392, 64.02314601405975, 65.60083704610025, 61.02498823596586, 69.82568079425444, 66.37965894514515, 72.34208522304412, 64.60953251008065, 57.74509445313485, 10.956305611518122, 5.518231093883515, 8.333922663042623, 0.3048702972310205, 0.12256233141787591, 1.7558878636167896, 61.07279408362604, 68.35879279721168, 58.59131051648048, 52.69197556280321, 30.114948172723096, 25.328493579741448, 52.663255968401515, 68.49929209678405, 66.1079877422702, 70.48673352887555, 10.569561873712848, 0.5662785879065914, 0.33395016746174905, 0.24453387115030523, 0.09237091357429182, 0.09913917015036268, 0.1219127118407238, 0.14405575550852284, 0.11048460289114907, 0.1170503288026779, 0.17739933404710986, 0.16507736136836393, 0.13370336423958504, 0.16599306626425636, 0.17505482920715887], [0.012418028613131855, 0.007309026071696633, 0.03213489097693274, 0.030914196902285182, 0.017160785106581547, 0.06656492774885509, 0.022697166554749976, 0.07092347008086021, 0.036897169305912914, 0.04061957137779363, 0.02164226348301576, 0.037809740902195056, 0.25602762617411157, 6.704996651218784, 63.33532702538275, 57.69559806393039, 60.934514845571215, 52.67963578624111, 19.364535616290187, 16.517791132773123, 46.03337564776021, 36.43432386459843, 60.49710781343522, 50.15870886464273, 1.5576513976820054, 0.22575926245941272, 0.9287139881522426, 5.926788112809581, 3.6352127165563646, 1.3650522357033146, 3.89505478643602, 78.3039153006769, 67.96884644416072, 68.99081999255766, 58.51724832288681, 56.17030597502186, 49.82281277256627, 60.44921959600141, 61.77460024433752, 66.85927852507561, 63.1327130717616, 59.199407331405155, 62.545091029136415, 61.31550642751879, 58.67784192485195, 58.48570462196105, 54.88383131642496, 48.3173208082876, 45.64812829417568, 45.53598380857899, 44.20290354759463, 44.311506132925714, 45.76167306592388, 45.24517928400348, 43.668072685118645, 45.698821006282685, 42.92236343506844, 41.852419299464074, 43.60277306648993, 42.869105492868734, 43.14271826897898, 43.0726255139997, 44.85372674080634, 42.01762168638168, 41.19060954739971, 45.394601975717855, 45.74603849841703, 41.953659595981726, 45.31531126268449, 42.49278937616656, 44.01165270036267, 42.02336011394378, 40.36563704090734, 40.95878962547549, 43.809164262587025, 41.692782755820986, 42.838491393673806, 40.11854733190229, 43.122012076839326, 40.84388771364766, 46.43353977511006, 43.81017231172131, 47.83244132995606, 49.01641661121, 54.32200278005293, 50.75957675133982, 63.09501517203547, 38.119115214194025, 37.60385305650773, 62.90453310935729, 49.46573195918914, 53.29732671860726, 50.502292802256925, 55.207960297984464, 53.5947718158845, 55.17568311383648, 50.78235003256029, 53.62563302440029, 46.45507750972625, 45.19887178174911, 42.16024298821726, 42.2366899828757, 40.549486375624134, 41.937048358301965, 41.27288518413421, 41.33270132926203, 43.05088381613455, 42.980881275669226, 41.01070219470609, 43.14803700293265, 41.602054411365145, 41.28224788173553, 42.640152823540475, 42.11790492457729, 41.72821744795769, 43.320974303830056, 42.43459709229008, 42.2770707837997, 43.684170092305834, 43.091790214661636, 43.5288756124435, 43.706598204951135, 43.33391028065836, 45.98817817626461, 43.407721442561, 43.80116654980568, 45.4316879856971, 45.262653443121145, 43.240946185204294, 43.62055317048104, 45.016034418536776, 53.22417451489357, 57.067234362325365, 62.03337469408589, 64.00686817784464, 56.454552296669256, 58.709828853607185, 56.95253249137633, 57.88280494751469, 62.008126397286695, 63.485687163568315, 65.90583662832937, 64.25644466953894, 64.050739888222, 65.78074832116404, 27.614960824289632, 1.1135257131630376, 5.686901836625992, 0.6475504043121493, 0.19687943310747225, 0.0944519148118073, 22.19421975074276, 63.203817798245346, 52.84370068580874, 56.77733590525966, 32.069263227524296, 20.674856324349683, 26.15104010028224, 45.73726807871173, 46.54578231996106, 56.00999478370913, 21.395399647374308, 0.1567644340496871, 0.0529084911930465, 0.050163858630243814, 0.05230699342885806, 0.041546725457714456, 0.026899158819428375, 0.030638709769494114, 0.01631331566210476, 0.03012456901131138, 0.030960422647636265, 0.046145666180358785, 0.04185120327278011, 0.04934333249806397, 0.05713958330752869, 0.04508150493605964, 0.06602178673229872, 0.057398329503954425, 0.04304022918785772, 0.05059680172933206, 0.016963268487503933, 0.10347554189783913, 0.025625099059975436, 0.029819242753869588, 0.019767200086085547, 0.04698556284570406, 0.03721378578413879, 0.08600678370003739, 9.370564895291484, 76.53698951967301, 65.05958134128203, 68.92908973078575, 58.89927541055987, 31.134833059003277, 16.220492143784803, 32.62089752381848, 39.3234162176809, 66.36560117044758, 55.37130348144039, 1.194262309901176, 0.2910598157153976, 1.481595169151983, 10.64811812293145, 4.738708071170315, 0.9797394888535623, 5.1232087035332965, 81.38394078900738, 70.26746519150274, 73.64904249868086, 61.196085945252456, 59.31531729236726, 51.964607315678755, 62.49077796936036, 66.03617698915544, 68.98588565088087, 63.62952832252749, 59.12054023435039, 64.73100831431728, 65.18515994471889, 61.070256310124556, 60.3203462016198, 57.49918537755167, 51.69749782931421, 48.72509041140157, 48.133428327498905, 46.81947354347476, 46.08814370247626, 46.881945133209236, 48.026622187706735, 45.47983115719211, 46.80105017077538, 45.44641256332398, 44.85708428967384, 45.88456484579271, 45.732549467394435, 45.21417687016149, 44.382552023856874, 47.04490392438827, 43.96752211355394, 43.05382951613396, 48.84794296756868, 48.23366449725244, 46.314993981392156, 46.86042308807374, 44.76203349328811, 47.368087614736254, 44.49382966564548, 42.08085421592959, 43.435605572115996, 46.54133435218565, 44.47177810053672, 44.691603414473995, 43.55965052881549, 45.50474605252666, 43.98309784550821, 47.291228771209724, 46.21652287821616, 49.21947379266062, 49.179014544333185, 56.01623919702346, 53.129927804393155, 65.29007942445817, 40.17364094334264, 38.955501817887836, 63.08395408814954, 51.27352491501839, 56.082354668648016, 53.59261058991956, 57.592223998039, 53.190045972024244, 57.166466405314786, 52.72141687331661, 55.529806460103686, 49.84640582915276, 46.45604241278864, 45.343485647632235, 44.06032931420111, 41.28348735070998, 43.82026457017468, 42.96968290882726, 44.084479347352065, 44.06466745561169, 46.203245655182876, 43.303162820877574, 44.99916822679582, 43.70103628404679, 43.00145410722302, 44.34621910895071, 44.37408754902501, 45.16596701837356, 46.465126622107725, 44.37088689496441, 44.913511506972775, 45.269980430603034, 45.9801883082236, 44.6578827981026, 46.07508613217262, 46.39524567511774, 47.66276351867184, 45.64883432080669, 47.31453941714379, 46.84284694733159, 46.43284943795974, 45.81919070213072, 45.91091140624016, 48.57356532927483, 55.9115707489752, 61.09976430093089, 62.2439589038972, 65.64370070734333, 60.24972392666725, 59.42182140965616, 57.956306242173724, 59.99836667891472, 63.06426771225468, 64.27651936008085, 67.05696598176034, 65.5400206965785, 66.73633575439453, 66.04567696971279, 32.10361338430835, 0.6305063575986893, 4.16493542732731, 0.85003865822669, 0.24696785505981217, 0.1050358944602551, 21.870233935694543, 70.1855347233434, 49.65777904756608, 47.73182861266598, 30.935876715567808, 26.121181057345485, 35.54351437476374, 48.01101115442092, 52.175140534677816, 64.02712721978465, 32.39354518152053, 0.13444672999603136, 0.03626184109898825, 0.01994354395015586, 0.05759222252715019, 0.05041497842138333, 0.045396474325248314, 0.052343516670648134, 0.029102544518067475, 0.0054538206313736745, 0.06261259204738083, 0.02519048397399245, 0.024992268299683932, 0.033888761179461595, 0.022666898420861652, 0.08686027459559903, 0.11287410773577229, 0.11828734629577208, 0.09049435822112907, 0.1415989575006308, 0.14903810025463182, 0.24511807447960302, 0.12521285774006, 0.10710279967996383, 0.12846285552387277, 0.1151745318765602, 0.15358783514989963, 0.5652184447934551, 12.538301444822743, 89.77074484671317, 73.34480777863534, 77.15626116721862, 67.83833349904707, 32.00682890030646, 24.37365531921387, 59.48790550231934, 50.743145942687995, 75.49811840057373, 59.546611616688395, 2.6487557397734736, 0.47705073390276204, 1.6205549384317093, 10.795988536650135, 12.887125668987153, 8.369617212203242, 5.878677300868496, 84.783215830403, 72.96560871985652, 75.77589281143682, 64.19868776875158, 63.00249430441088, 55.47761932496102, 64.2417710827243, 67.80580136083788, 72.13277186116865, 66.38422458402573, 60.07562168182866, 66.84543255836734, 67.07811540172946, 61.88228107267811, 62.963874647694254, 61.70322095194171, 54.89146032641011, 51.09139357843707, 50.248899844384965, 47.64534427273659, 49.14818471477878, 49.41368995174285, 48.91958505876603, 47.097259721448346, 49.26570676988172, 48.3215844246649, 45.90484742195376, 49.22784020823818, 48.49776944806499, 47.719810470458, 46.981840056757775, 49.19431963274556, 47.05619642811437, 44.34102196847239, 50.630295430460286, 50.725263857072406, 47.522515250790505, 48.87235579952117, 47.90700950930196, 49.81716063714797, 46.903235758504565, 43.904293506376206, 46.90688356276482, 49.1679181591157, 44.94608679125386, 47.549807102449485, 45.48927230219687, 48.4597263797637, 45.676840043837025, 50.697148307677246, 47.448456979567005, 51.47096918475244, 51.859656456978094, 58.6492282344449, 55.90105095217305, 65.95033984030447, 43.31193324058287, 43.86443438068513, 66.63562497785016, 53.93202112567041, 57.08364948149651, 55.138318615574995, 59.68005849469093, 56.47867095085883, 58.937616578994266, 55.0713872909546, 57.82463619785925, 51.70720177312052, 49.83928280491983, 47.87083741157286, 46.79704150845928, 44.26232353333504, 45.80705881118775, 44.761609877309496, 44.692599696497766, 46.652219756957024, 48.04071918610604, 44.880316488204464, 47.86229056696738, 46.528021827820815, 45.2004603416689, 48.83956086251044, 46.31227970123292, 45.75382440320907, 48.83722705225791, 46.49763130372571, 47.55543962601693, 48.34697000442013, 49.151557953126975, 48.596746536993216, 47.72520765181511, 48.29313155143492, 49.3241814644106, 47.55382360950593, 50.55385628054219, 49.21845789878599, 51.231779129274436, 47.83990167802381, 47.169227369370006, 50.5231951129052, 58.00173905587966, 62.30463404809276, 64.9886845004174, 66.79382985638034, 61.5189480012463, 62.2203972262721, 60.4945033596408, 63.23019966002434, 65.10552014074018, 66.08367689194219, 69.01435421359155, 67.18840460623464, 68.2099231596916, 66.71233869368031, 36.20888956131474, 4.106790211892897, 13.748426187422968, 1.208261249046172, 0.41599637618468654, 0.09884123855661, 28.211194430628133, 75.51592596115606, 68.41835791064848, 71.95410005507931, 39.91534502275529, 29.53171330113565, 38.790758348280384, 61.434307175297896, 60.67819579955071, 73.14658687960717, 37.33306438692155, 0.2540296229023126, 0.1282540505992309, 0.19957094513360532, 0.11967124582658853, 0.16262018031650977, 0.10187939770760075, 0.11605555597212046, 0.14598327869128797, 0.07453700722826105, 0.159606788788111, 0.13444594858634856, 0.07531572794241291, 0.13052311876127798, 0.19051275216042998], [0.015033325424507983, 0.04611747414474526, 0.036395875842220364, 0.09388444284277578, 0.04725951971786638, 0.0990327375550424, 0.01652700439726393, 0.01250427287642754, 0.02043473845978658, 0.035539592556174726, 0.026668248427731377, 0.12015708346640873, 0.09976036020464475, 18.895484862789033, 77.45626757221838, 57.67087144236411, 68.14239563480501, 40.090588677314024, 21.029016933133526, 43.43316193549864, 52.877213416561005, 38.88694663201609, 73.76832962036133, 28.490161242023593, 0.27771453343091473, 0.010821431473408256, 0.4059800830098891, 7.908985826276965, 4.532582615652393, 1.902258828763039, 27.557215690612797, 78.98337964088687, 64.9645854580787, 68.47786026616251, 58.91400783292709, 56.355339865530695, 47.444334568515906, 50.848959722826564, 60.56272122167773, 61.87686427947014, 64.98838640028431, 65.28549025135656, 57.262329132326194, 61.27309776121571, 60.65515579715852, 61.70064787710867, 58.11183998661657, 52.25769465969455, 45.37324859249977, 43.458943674641276, 45.40334101646177, 45.27168273925782, 44.642463960955226, 41.25824689865112, 43.6355209350586, 43.92678829931444, 44.090935568655695, 43.430832047616285, 44.17380740565639, 43.335149749632805, 43.210065364837654, 43.325928257357695, 42.951738065288914, 43.487416159722116, 41.77861990467195, 42.548267379883804, 41.81450566937847, 45.29397356894709, 42.7116144857099, 43.30313144191619, 42.30654347327448, 41.92635205484206, 43.36365361367503, 39.55894277941796, 42.31654551721389, 43.36792115242251, 40.69787356161302, 42.726758756945216, 42.012852084252145, 44.40413290454496, 47.634726416680124, 44.371000643699404, 48.59536978506273, 47.853739799991736, 53.91407235976189, 52.59756803512574, 63.39246419168288, 37.29325232967254, 41.08190105807397, 63.12787678933913, 51.057582747551706, 54.6455551731971, 52.65504252526068, 54.409220603204545, 53.490213194201075, 55.1191617596534, 51.73839638310095, 53.002666504152366, 48.81372421018539, 46.24883144132553, 42.5869615616337, 42.23021807209138, 38.09055643696939, 41.84958734819966, 43.654807229195875, 42.04896534642866, 39.75594382132254, 43.22644126030707, 41.703926209480535, 43.40846669289374, 41.83183077842959, 44.033747411543324, 42.07526091606387, 42.34742633758053, 44.48826774474114, 42.59227245084701, 41.693375033717004, 44.076493401681226, 42.30503336075814, 45.24066071356497, 45.21210585871051, 43.17649772090297, 42.0082119203383, 46.029692542168405, 43.2503677183582, 43.313074650303015, 42.749692855342744, 44.886070605247255, 42.798075291418264, 47.61797005130399, 50.95547560722598, 60.33655343517181, 60.99509977525281, 56.984641013606904, 53.85278924818962, 55.6984369985519, 54.26626589990432, 60.443547848732244, 60.65234345774497, 63.774322617438536, 64.14528862122567, 66.0598445707752, 67.27125290901431, 65.44784107515889, 70.62820557625064, 51.98852985135971, 0.7340364602784957, 1.9880737917077158, 0.7634218770169443, 0.10498712530299541, 0.039796103467984546, 3.0407682013127113, 56.28296821348129, 50.827688709382095, 32.485165865190574, 63.43953263375067, 38.754186168793716, 12.132806816408712, 31.45457683071014, 47.56853642002229, 53.12501699693742, 40.732900327251805, 1.1092581744155576, 0.08030831528406951, 0.06813969042512678, 0.023390665732985063, 0.01996927492831263, 0.05509840715075693, 0.007270841376720778, 0.03628068303148593, 0.024427318675143105, 0.04429276379185819, 0.072808766497239, 0.015336992143983803, 0.03274624063182743, 0.034115075043612914, 0.026884850212222627, 0.05204938870343951, 0.037339435695039655, 0.04618438426405192, 0.010219417557480836, 0.09559970604436052, 0.04087650194583882, 0.03952809526855427, 0.0369387602193221, 0.10179203304071581, 0.0365784882207311, 0.09156945537054732, 0.09663207080936241, 27.038219436522457, 87.27579578276604, 64.05353653815486, 70.91760589230445, 47.478906339214696, 27.644688467825613, 38.75453525973905, 50.11952830899147, 39.09804467231997, 83.69024738188713, 28.96318731769439, 0.21903996656258262, 0.13512044303840207, 2.479786651749765, 11.812599224428977, 3.349248887069764, 0.1601036887375578, 30.7652477295168, 82.94786037937288, 67.21415888878607, 71.93564922578874, 60.18479301083473, 58.37161856312906, 50.40623787910708, 54.584758435526204, 63.47845039060039, 64.47276730691233, 65.74182271957397, 66.89406994850405, 58.99512637046076, 65.13310224779191, 63.29422058597688, 62.653254309008204, 60.625643883982015, 56.322250750757036, 46.110650262525006, 46.38342365141838, 46.66180995202834, 46.96436589764011, 47.24952220916749, 44.804987369045136, 44.355417067004794, 46.114694226172666, 45.76485018576346, 45.52986883348035, 46.1351062405494, 45.77633880799817, 45.30972580755911, 46.27310306795182, 45.6385184872535, 43.797306937556115, 44.622036257097804, 44.95209193998768, 45.598055316555886, 47.71426423903435, 45.05101803810366, 45.2908552846601, 44.95006015223842, 43.10771895993141, 44.678424250695016, 44.558568385339555, 43.94345445017661, 44.44399987497638, 43.014994129057854, 44.71976210994106, 43.775961399078376, 46.81854001937374, 48.83331252682594, 48.19223642349244, 52.084055254536295, 50.49760556990101, 56.731475553204945, 55.74040243702551, 65.1457283573766, 40.3157131133541, 42.623929900507775, 65.68223014954599, 52.772846991016024, 58.37351699029246, 54.862521079278764, 57.39787840074109, 54.825635110178304, 57.53773050923502, 55.60966983918221, 55.270051417812226, 50.31605474410519, 50.31013196514499, 43.71168551906463, 44.54350256150769, 41.9662582489752, 44.77982536438973, 45.66237434264153, 44.03650091540429, 43.102968969652736, 44.42698463316887, 42.3086654755377, 44.26624982587753, 44.36441498418009, 45.86267409786102, 43.58145106223322, 43.44356406119562, 45.49512447849397, 44.89386827714982, 44.628135542715754, 44.706418206614835, 45.05425007112565, 46.49393250865322, 46.9422358851279, 46.25064357634514, 44.83671149899883, 48.07147449062717, 44.542341539936686, 45.34077136747299, 43.29289013339628, 45.95322201328893, 45.05412455528013, 48.31177849923411, 53.44905968635313, 61.13810939173545, 62.43156979160925, 59.94237092233474, 54.05496389635148, 56.314029462875865, 55.8608348907963, 61.01714349562123, 62.55126876215782, 65.41833308435255, 64.09806328435099, 66.79493596476894, 66.6015709600141, 67.30989609995197, 70.34758352464246, 55.84729486896146, 1.7978803909594014, 1.4648852593475774, 3.881398809532966, 0.6956699802990883, 0.010975497500640492, 2.8594326155800975, 63.087013536883944, 55.33482936120803, 31.579402339073923, 55.10469213608773, 40.006955900499904, 18.965781581017282, 35.80538749694824, 54.4797291294221, 58.74188638502552, 53.91556678279754, 1.6884025042095494, 0.08471319827461436, 0.013833711216706904, 0.05374395603974981, 0.022409540758798682, 0.024864065400775404, 0.05530729251463087, 0.03336239748844697, 0.03755760221411625, 0.05579198868344388, 0.03174956598799796, 0.025391568647577398, 0.016894705533500642, 0.02332018755917107, 0.104291777937643, 0.1795032719570783, 0.12221920829746993, 0.2315175776640254, 0.18770096433018485, 0.20058547537172997, 0.17873369067186312, 0.1785714332495005, 0.11635442219314077, 0.15238215065290853, 0.2265125567153577, 0.17797057516872886, 0.18476163818230554, 35.76740326419954, 95.35804348607218, 74.35012694328063, 81.8103494951802, 52.50550216244113, 30.02118979730914, 59.10772977336761, 72.62348390394642, 53.841806611707135, 88.31314502223846, 35.75041940135341, 1.206780309157987, 0.16368020085557816, 2.7098150310977815, 16.44205997067113, 13.583494444047252, 3.143132256884729, 35.588629476485714, 81.73930752661921, 71.64520555926909, 73.6280107498169, 65.60596750628564, 61.467733613906375, 53.64424467086793, 55.97041806867046, 66.53596539651194, 69.14825608653408, 68.79489760245048, 70.54334901994275, 58.641316813807336, 65.92461693671443, 65.67762528696369, 66.29822269562753, 64.03800787464266, 57.89546635843093, 49.40995193296864, 48.900110490860484, 49.27066464577952, 51.254101337925086, 50.31250499909925, 46.07427420154695, 46.92312609764838, 48.96645738232521, 49.786938774970274, 47.86698564406365, 49.320408144304835, 48.630875079862534, 49.44361371378745, 48.83509328288417, 48.41977311718849, 48.24600427381454, 45.10852782957016, 47.71312675168438, 46.09054811539189, 50.08421128795993, 46.79282103815387, 47.59745605530278, 47.16502651091545, 46.55938117734848, 48.08806219408589, 45.63036780203543, 47.024378161276545, 46.49187718668292, 45.25771125670403, 46.521216515571844, 46.596004347647394, 49.98177466853973, 51.46250470992058, 49.505732290206424, 54.8305106163025, 53.170575326488866, 59.694175104941095, 57.66104590508246, 69.09011087109967, 45.05582294156475, 46.7910167478746, 67.78869982688659, 55.224143997315444, 62.16987317608249, 57.352182788233605, 58.67891273190899, 58.37741974861392, 58.235888865686235, 56.47728243181783, 58.45974637616066, 53.915303983996, 51.496401832949736, 47.15899390559043, 47.619962615351525, 43.66483280735631, 46.47777626591344, 49.15271505232781, 47.45032010539886, 44.42684342784267, 47.04580999189808, 45.4272674745129, 48.36778210055444, 46.205406881147816, 48.3697707422318, 45.38653758264358, 47.516008038674634, 48.94829288605721, 47.307004544042776, 45.65485123665103, 48.31031545515984, 47.288683152967884, 49.020005579917665, 50.62504337679956, 47.46948872843097, 47.7700521099952, 50.00654835854807, 48.12914117690056, 47.86195324313256, 46.50808442023493, 49.27087253139865, 47.87353992462159, 51.90858802487774, 56.36038011120212, 66.21571171668269, 64.82486278780046, 63.39042848156345, 56.82375715624902, 57.907688463887865, 57.199124059369495, 62.40613714341195, 63.928248190110736, 67.48837178753269, 67.44605725811374, 70.74156207423057, 70.18963752254363, 70.705994021508, 75.32182355080882, 59.002214093362134, 2.016379330908099, 8.05573836449654, 5.298737220225796, 0.7460153787847489, 0.16123466434017306, 4.958963374937735, 68.92078999550112, 63.48842105557842, 43.70439383291429, 73.30513692671254, 47.54795574372815, 20.711383396579375, 46.11461185639905, 64.77029869633337, 66.08121364347397, 62.844638516826016, 3.136582879289504, 0.2998461087624873, 0.1009623138534446, 0.18040298093711177, 0.11653540280437279, 0.19237797707319262, 0.15234376964790208, 0.13097462034033192, 0.0985464326015884, 0.11147619645682075, 0.11902555628048798, 0.18050796562625518, 0.11780415165929065, 0.09104832406005553], [0.042024921370489944, 0.022218962981095238, 0.009559170425599142, 0.017628006809841723, 0.06551870445330298, 0.022151618106891553, 0.050055357597527966, 0.0583997672994531, 0.03558848811794193, 0.04867746802647749, 0.021303219780806574, 0.02332865283073437, 0.21470528786941884, 37.367694993172925, 73.5360154797954, 55.11682794940088, 57.8080798733619, 24.515076375776722, 27.7832716895688, 49.43341555133943, 32.64140171389426, 48.013392033115515, 72.99790551585536, 12.702160419956332, 0.04748659200906273, 0.25664166096718083, 1.9118691259814848, 4.557577429279204, 4.19227974068734, 7.29812374038081, 63.06605239068309, 73.38401579087781, 64.40236468468943, 67.46082105944234, 57.68745130108249, 54.56973183539606, 51.6397056271953, 48.62925514098137, 49.27217868066604, 61.72543725659771, 62.686253209267896, 60.85333355011479, 63.04854293023387, 60.28406819989605, 61.9008574178142, 62.45128754646548, 59.85126603034235, 60.55191901422317, 49.88708865258002, 45.239193747120524, 44.48674978748445, 45.933943563892, 45.831620693206794, 44.62205979131883, 45.06319307511853, 43.87135736403927, 43.35016850502261, 42.885540223890736, 42.21167702828684, 43.34957622712658, 44.09395971605855, 42.59284511689217, 41.52851781537456, 42.94306178246775, 42.86490071204401, 43.461195115120184, 44.99273161734305, 43.147578085622484, 41.87336083381407, 44.48947583475421, 43.869404023693455, 41.53993975731635, 42.20565226770217, 42.03232665215769, 43.16641722956012, 41.17003671584591, 42.16545581817627, 42.9752605192123, 43.50387834733532, 44.20821835917812, 47.74698072864164, 47.64526974770331, 50.67676767226189, 49.63556274291008, 57.67442118737006, 52.162981187143636, 61.59368092013944, 37.95321856775592, 45.2700981017082, 58.158331840269035, 50.19295115624705, 53.96285095522481, 52.84370068580874, 56.67520130834272, 52.08512213922317, 54.31943362759006, 51.82809314420147, 52.779012956926906, 50.03857843337521, 49.81215961517827, 47.33081333098873, 43.54982499153384, 39.70033245701944, 44.00059553884691, 41.69751705661897, 40.306789721212084, 43.03549635794855, 40.5733657652332, 42.12171746838478, 41.907920837402344, 40.566168215967, 43.52427859460154, 42.883096587273386, 41.716226762340916, 43.210241871495406, 43.832427840079035, 43.87649174659483, 41.74770770534393, 42.64713856481737, 43.28315873299876, 42.93350296635782, 43.25419595164638, 42.01264812100319, 43.63932171175557, 42.779887260929236, 43.37930387066257, 42.430027531039336, 42.07384494043166, 43.809462362720126, 47.94125572327645, 57.279120799033876, 59.80149507522584, 57.21084410144437, 53.767944458992254, 44.87757475145402, 58.302188688708895, 60.34428050441127, 63.272729919802764, 60.06542351938064, 62.81972362149147, 62.023988462263546, 61.36548919062461, 58.38632352890507, 67.25765012925672, 59.66505542878182, 69.53413101934618, 14.616964459419252, 2.750359590976469, 0.23105141316210073, 0.4245137110833199, 0.06501897763941558, 0.04508797837901981, 25.711575784990867, 67.9478068505564, 42.11452384148875, 68.00213952218333, 58.40623740226992, 18.30231462755511, 27.771747766002534, 40.55087881703531, 52.18645265025478, 44.03629302978516, 3.183834201866581, 0.087245992204595, 0.049404182861889565, 0.08006382598391465, 0.063496531107493, 0.03944607023450156, 0.026356251459688913, 0.106945583116143, 0.04335528667715769, 0.06438277226181761, 0.02473362744034779, 0.0384633211539157, 0.06409258198653979, 0.056493644782852744, 0.022313241591496814, 0.04707775769695159, 0.029324256109013676, 0.08127504163571904, 0.045084722505341616, 0.011417276466325408, 0.048149625785769, 0.07656022245364805, 0.03906729338209956, 0.0120585878199387, 0.038600454722801526, 0.07691878224572829, 0.1378741920475037, 50.774524904066524, 81.30766637863653, 61.88812932660503, 65.82553786616172, 33.94810207428471, 36.53795288455102, 39.31000563406175, 32.49228300586824, 54.92430625423309, 78.91065889789213, 14.341384614667586, 0.24389794156435998, 0.3755025619701032, 3.4978255725676015, 5.774548178718937, 1.2957962938854772, 9.70082748320795, 64.96319301666753, 76.07575016637003, 68.50792915590348, 68.25065305156093, 58.73151563828992, 58.99826426659862, 52.76605736824774, 50.46685026537988, 51.79373318149198, 64.13383137795233, 64.7057286385567, 64.38483169001918, 64.70483826052758, 61.17982379851803, 62.58294974603961, 63.589924150897616, 62.18948502694408, 62.594187336583296, 52.6427145158091, 47.404385228310865, 47.25991256775395, 46.34957359683129, 47.08362948509955, 46.608465717684844, 45.28812531502017, 46.834256956654215, 45.3883340281825, 46.4527476218439, 45.63683971281975, 44.741896044823434, 45.23631472741404, 44.78978426225724, 44.34141420548962, 46.484734550599136, 44.6068331503099, 45.02309076247677, 45.88687904419438, 45.515418821765536, 44.13376000619704, 44.975390818811235, 45.01330444889684, 44.14402092656782, 44.777766120049264, 44.51879555179227, 46.61669092793619, 43.674489682720555, 43.70507632532428, 45.08395025807042, 45.875641453650694, 46.918281970485566, 49.98650896933771, 50.016828890769716, 53.40553706692111, 50.41545937138219, 59.19571245870283, 56.046288474913574, 63.03792899654758, 40.819349365849654, 49.22058382341939, 60.78610804773147, 52.241283462893584, 55.80760048281763, 55.621393803627264, 57.063492421180975, 53.56272997394685, 59.42428858049455, 52.786414469442065, 55.02971603024391, 54.08205962950184, 51.951949827132694, 48.755065164258404, 45.131779639951645, 41.84511192383305, 44.694278470931515, 43.700538143034905, 42.75369367291851, 44.49746962516539, 44.497242127695394, 44.841700753858014, 43.826963978429, 43.35362411314442, 45.177632147266024, 46.12345680113762, 43.89220083913496, 45.49082948315529, 45.83522927376532, 45.68874443731001, 43.98638086934244, 45.79506420320081, 46.13065435040382, 44.964514086323405, 45.574521095521995, 43.920783150580625, 45.05108471839659, 45.993661649765514, 45.271427785196614, 44.0309742958315, 45.35135784456807, 45.317456799168745, 50.239023316291075, 60.17559897515082, 62.37093387111541, 60.602984351496545, 55.068543572579664, 45.7589077949524, 56.624563509418124, 62.42925167083741, 64.60935992579307, 62.03033485720235, 64.07225801098731, 61.46131269393429, 63.4043058272331, 61.493711471557624, 69.13896006922569, 61.27666711807252, 73.13613768546813, 16.67616467322073, 1.600837673871748, 3.427077291473266, 1.6221143257233406, 0.09256569908991938, 0.1543793571932662, 25.35252594178723, 75.92422116187312, 41.219160479883996, 65.08366469414004, 47.31502186867499, 22.37655701175813, 36.07936505348452, 47.37688941340293, 56.86377317674699, 54.83847302775229, 6.2915940342410925, 0.30356151262117975, 0.1400678235316469, 0.10542017948483268, 0.027991138631477955, 0.04539250598980054, 0.04429074515017771, 0.0074922221134446805, 0.03309631600014625, 0.05996006240527477, 0.01826697968006615, 0.018986688641410683, 0.010934888137384288, 0.05550574759141572, 0.14176191972388377, 0.12920514109634584, 0.1343215665509624, 0.15856596641242504, 0.35148579747446124, 0.10308011795484251, 0.1006263842986476, 0.28010218434276124, 0.10631136190626891, 0.11132977407185302, 0.11789314043257507, 0.13981377345419702, 0.4532312830128978, 63.028158372448345, 90.52765246360534, 69.82955609598469, 76.69936780006655, 36.91957204572616, 37.63785216116136, 60.175089067028416, 45.21897000651206, 64.08312297636463, 85.62318355806413, 16.22120503456362, 0.2901091006013655, 0.6278001673279271, 7.853443103451883, 9.37432840947182, 6.457005777666646, 11.890573982269535, 67.55853514517507, 76.15761003186627, 71.9605484316426, 71.88798458345475, 62.07639525013586, 61.40711338289323, 56.82114093534408, 52.92922404504592, 54.25500869750977, 66.89304228751891, 69.58340383345082, 66.31804635447841, 67.77085304260254, 62.644126953617224, 65.02838280893141, 66.86918643213087, 65.02867698669434, 65.65618168923163, 56.30307036061441, 48.75663803469751, 51.007093998693655, 48.6499221094193, 49.87636881489908, 49.30939805123114, 48.327012984983384, 47.55474536649643, 47.40631895680582, 50.20600088181035, 45.944671246313284, 47.358458195963216, 48.16534857596121, 47.97950667719687, 45.994787370004964, 47.700206464336766, 47.44384819461454, 49.204419735939275, 48.56970963939544, 48.660465440442486, 45.227567841929776, 47.57026618526828, 48.344389084846746, 44.8331029184403, 47.63020392387144, 47.517808406583725, 49.19174655791252, 46.77087145466959, 47.69228327658869, 50.01148662259502, 48.878415861437404, 50.27475610856087, 52.44210881571616, 54.28584244943435, 56.4012159070661, 53.34267716253958, 61.97893219609415, 57.97184275042627, 64.0056404759807, 42.40424186952653, 52.388490015460604, 62.98601250494681, 55.541961885267696, 58.738462155865086, 57.05456118429861, 59.88721455297163, 56.46048684273997, 61.60830743851201, 55.43721498981599, 56.92602119138164, 57.65276185927853, 55.77553902902911, 51.07429596685594, 46.703594961474025, 45.67419244397072, 48.00541393218502, 45.59971840150895, 44.983753312018614, 48.127674210456114, 46.285113365419456, 47.96656285562823, 45.990413927262836, 46.06871620301278, 48.22138747861309, 47.57882479698428, 46.196742365437174, 46.608591233530355, 48.07216090540732, 50.52925125245125, 46.66290429330642, 46.78836522563812, 49.580292624811975, 47.40213378783196, 47.00425640229256, 46.65788758185602, 47.53662009393015, 48.9023187852675, 47.916658539925855, 46.07038713270619, 47.38107066000662, 47.5398442822118, 53.31389088784495, 62.98368653943462, 65.6185112460967, 62.257094921604285, 54.734032077174035, 48.80123146118657, 60.83183111683015, 63.632713287107414, 67.26885241846885, 64.95923926753383, 68.39935794953378, 64.74082992922875, 65.64619141240274, 64.89053503159555, 72.42030512902045, 63.44611437089982, 74.31346847165015, 18.131185539307133, 6.313653934386469, 6.672645432333793, 1.4444202929735186, 0.25615946990588023, 0.36185397015463927, 32.47220047058598, 81.32217130353375, 55.64565758551321, 76.85543106448266, 62.949095156884965, 27.9750402896635, 40.55628776550293, 59.32755116493472, 64.63012103111514, 66.33601080986762, 9.57093721435916, 0.6390905260078369, 0.25247785052464855, 0.2744068109220074, 0.21019289209958048, 0.16883053336172335, 0.15346441838529803, 0.22628703575220802, 0.12389088875704235, 0.15122316687578155, 0.17088032417720364, 0.23338830308808436, 0.2093632648428602, 0.130253731603584], [0.04586618964470202, 0.016755650999144684, 0.0551552432138593, 0.08569892360678605, 0.04867973947717298, 0.024603300562669194, 0.03662735696942095, 0.03897982529334484, 0.056183072738349445, 0.04660012102836082, 0.041296425380653916, 0.14749873850134113, 4.345743944568019, 56.11834241497902, 63.63972256260534, 57.477773158781, 38.513564448202814, 13.675879989900897, 24.543370393014726, 95.15524125868275, 45.679887725460915, 56.000989021793494, 62.098776294339096, 3.405021558846197, 0.04765969723643315, 0.6854244429738291, 5.432582218800822, 5.278331089404322, 2.1028586453007114, 45.95079014378209, 65.612576700026, 70.23888680242723, 66.18256768872662, 61.42563481484691, 52.72414684295655, 52.457982647803526, 48.64494854404081, 48.67175794416859, 45.08074960400982, 47.90294201143327, 56.30432944143973, 62.774129990608465, 59.405645555065526, 63.6767928831039, 56.920031732128514, 56.5876304718756, 62.74852475812359, 63.09413656111687, 54.97626981427593, 43.510593445070334, 47.0991228472802, 44.64389562606812, 45.79644487750146, 44.78838005373555, 46.20530882189351, 43.294478693316066, 44.659243860552394, 43.77231751718829, 43.56365526876142, 42.89428710937501, 42.42286920547485, 42.82560640765775, 45.245073380008826, 41.556362721227835, 41.35043828718124, 43.50534923614995, 42.989514412418494, 42.33946000376056, 44.70364116853283, 44.241872295256584, 43.28209969305223, 44.22118179259762, 44.197227877955285, 41.0532481439652, 43.557571672624164, 43.239679259638635, 42.20918632322743, 40.144733075172674, 43.31788347613427, 44.23895012947821, 47.845169421165224, 45.892633161237164, 52.471067674698375, 50.85469815038866, 57.5172596593057, 53.07952927004907, 62.82906278487175, 34.95964211802329, 44.0421805074138, 61.702585527973795, 50.78087914374567, 58.420283409856985, 52.29598875968687, 55.567567117752574, 52.0834590542701, 54.55618004645071, 51.682690881913715, 52.48706702263125, 48.8110177747665, 50.28771954198038, 48.83003734773206, 45.45024079661216, 42.047757256415586, 42.51816318881127, 41.58263475664201, 44.336679904691636, 41.14955409880608, 43.62218879884289, 40.01552235695624, 43.159164767111506, 41.088157238498816, 44.091237591158965, 43.76146431892149, 42.131962699274865, 42.26741390843546, 41.26634659305696, 41.87290976124425, 44.13487395932598, 41.333423045373735, 42.04678843098302, 44.157204012716974, 45.59504685863372, 42.99341324836978, 44.486702719042384, 42.70523671180972, 43.923544499181936, 40.86180117822463, 43.75007375594109, 42.53096188268354, 52.643094985715805, 58.27319452839514, 63.60533906567482, 55.861670355643, 57.42555072230678, 62.734906288885306, 58.355332882173606, 59.32306005108742, 57.530729078477435, 57.567956293782885, 58.07620525360108, 59.22844071542064, 58.430552174968106, 59.30836293005175, 61.9126598296627, 61.600054771669456, 67.66937348150438, 43.45497423602689, 0.4599772694130098, 4.529512380400012, 0.9043766618255646, 0.03577778461359201, 0.023274775782239535, 6.1706693230136755, 59.16380005498087, 43.85597382822345, 62.597701780257694, 69.98012804215955, 21.732021377932643, 14.657801235875777, 39.344910806225194, 46.3543196647398, 50.33569797392815, 7.614322179748167, 0.1675134443587834, 0.11505672287556434, 0.05905196476247042, 0.015862361835916678, 0.01969233988934467, 0.05352070652729562, 0.04077928538824763, 0.059090387902312705, 0.01765441577581148, 0.06872928701341152, 0.028135657287953843, 0.05743354273539397, 0.04675990015628838, 0.043667793093669804, 0.006465721272698214, 0.08006076929309676, 0.027970157398451722, 0.06986233871430159, 0.020679101355433948, 0.02779061511729754, 0.03492882129766288, 0.028862123144790534, 0.07029728513331183, 0.0599738136835156, 0.19361986688548521, 6.440330801471588, 68.77130062349381, 71.6651939576672, 66.81892518074282, 46.481761394008515, 23.272787217170965, 29.427866589638498, 80.69601197396555, 49.65580609536941, 62.671473718458614, 67.18267794578307, 3.226072245067166, 0.21688721353007903, 0.6778801929566168, 7.044551824369739, 5.7704728361099, 2.9752060290305846, 46.596804511162546, 65.80232527948195, 73.41490053361463, 69.53774744464506, 64.0500456287015, 57.38505225027762, 56.65022757745559, 50.47056082756289, 51.97563702060331, 46.67038817559519, 50.582175793186316, 59.20593807774206, 64.57828298691781, 61.44890231470908, 64.66773263869747, 59.02639942784464, 60.55323300823089, 62.71050522404333, 65.82324720198109, 58.39631380573396, 45.50544815678751, 48.857144847992934, 47.339991677191954, 48.1285410542642, 46.830550316841375, 47.26804364112116, 45.33320511541059, 45.75986485327444, 45.86789477256037, 45.139338047273704, 46.45747407790154, 44.61879637933547, 44.10909222018334, 47.16343010625532, 44.07489699702109, 44.329709852895434, 44.419147737564586, 46.505719231021025, 43.85596206111293, 46.43898010253907, 44.753416046019524, 44.23028561376756, 44.95868936661751, 45.26487350463868, 43.89701358733639, 44.68477849037417, 44.79214945147115, 43.4829132787643, 43.40226934802148, 46.22844296116983, 46.59496099718156, 50.80999881990495, 50.11329566278766, 53.13865507802656, 52.95206400655931, 60.09902254227669, 54.64744967799033, 63.153403574420565, 37.14382179321782, 45.182797908782966, 62.14899832202543, 53.90034014178861, 60.78074224533574, 53.291623592376716, 56.81379433601134, 53.609076699902936, 55.41639112657117, 55.14120155765165, 53.33001575162334, 50.24482450177593, 53.15136747975504, 49.69946207538728, 48.05111346706268, 42.35438854463639, 45.09334433463312, 44.25993088752993, 45.959054577735166, 43.37667980501729, 44.25400026382939, 42.73796496852752, 44.54522448201334, 42.69472083737774, 45.06580537365329, 46.40098410267984, 44.48226651837749, 44.70150347678892, 43.36589328704342, 44.4593834107922, 46.39515938297395, 44.97492013439056, 43.16727230625768, 45.48815050432759, 46.64057816228559, 45.46724427130915, 45.45901513868763, 44.81614651218538, 44.74771291978898, 43.84045300945159, 45.953547570013235, 45.12615103875437, 54.12853971604378, 60.19471660737069, 63.65281151187036, 55.0847194271703, 57.729067648610766, 63.00763653170679, 62.543008250574914, 60.99704919322845, 57.69899483649962, 60.01409930567588, 62.009801249350275, 61.21435242314493, 60.958955134114916, 61.25109326454901, 64.78526646091093, 65.568371588184, 68.58796904163977, 49.59926905170564, 1.447165584371936, 1.2292971654284386, 2.5587701941690137, 0.22274099861181554, 0.06015106344655637, 5.414010776627449, 65.9993459332374, 46.33146009137554, 56.37445357538039, 61.601337386715805, 23.794436954682876, 20.41895697193761, 45.87682993181291, 52.622373104095466, 61.732285714918575, 20.501156122453754, 0.1528456338470982, 0.024302103519139272, 0.035921521860385136, 0.03633167001328642, 0.029921446543847843, 0.02446758808688291, 0.05118455970659853, 0.052550601727900006, 0.02464895557251669, 0.05448342240866154, 0.08639766474164302, 0.03140933676472595, 0.0056274807936842405, 0.1378426751902988, 0.09730888650782647, 0.21323951652213452, 0.19035956521909084, 0.12360226513156969, 0.15440016414128965, 0.13698648000436445, 0.16606929201272227, 0.14007618921178003, 0.2325769700109959, 0.13151138750535826, 0.30007244177883674, 8.05523532052194, 79.612974966726, 80.23542373411118, 76.42907727149226, 55.4437731927441, 25.252583949796616, 32.07007908052014, 105.82604146772816, 62.31567159775765, 68.58530967466294, 72.71189412763043, 4.595123337161157, 0.33531692960569937, 2.38408278073034, 14.634784767704627, 15.347539244159577, 4.5403631271854525, 51.673135988173954, 68.18218415783298, 75.82045093659433, 70.8450577335973, 68.10335236210977, 59.54335604944537, 58.95121543638168, 52.25769465969455, 55.25432271342124, 49.87056370704405, 52.82396724147182, 61.53216246635684, 68.49743289332237, 63.57794131002119, 67.88096966282015, 61.14589137415732, 62.78851724440052, 67.83259899385514, 69.39969570406022, 60.34084058577015, 48.21786911256852, 50.188958183411636, 49.35373260128883, 49.277407200105735, 49.04579908617082, 49.57339709804904, 47.79190363422517, 46.83648486291209, 48.218806559039706, 46.52086742462651, 47.52868513907156, 45.80488974048246, 46.84019934746527, 50.150452275430005, 46.621535055099, 45.08961808296942, 48.361270966068396, 49.16664731117987, 46.89100973067745, 48.73861082138554, 49.22087015644197, 46.91982346196329, 48.71877539542414, 48.655935102893466, 47.55611035131639, 46.58153472408172, 48.26337645130773, 45.2411666993172, 45.59104211868779, 47.82618514953121, 48.726914313531694, 51.94048081674884, 52.57174707228138, 55.75150274461316, 55.26642714777301, 62.47926189053444, 57.962350614609264, 65.31560620953961, 41.78300903689477, 48.53868369133242, 63.87120516069474, 56.531054204510106, 63.331753746155776, 56.725490016321984, 59.41306667943155, 55.315907847496774, 58.557966447645626, 56.4983259477923, 57.036314318257, 53.72183699761668, 54.85457827967983, 53.436053106861735, 50.68754634549541, 45.328223705291755, 48.8540893216287, 45.78361872703799, 47.941545978669204, 46.26401493626256, 47.004303470734634, 44.45904216458721, 48.96836365422895, 45.64601805902297, 48.771747004601266, 48.951544530930065, 46.27735099484844, 46.91255138766381, 46.58907744192308, 46.592042753773356, 48.74498075054538, 48.14281848169143, 44.876268602186634, 49.1274824450093, 49.61606856315367, 48.52790894046907, 49.404021309268096, 48.48204858841435, 46.474234365647845, 46.41552040653844, 48.77718733203027, 47.996490540043006, 56.21779803306826, 62.8638542083002, 69.00107306818809, 60.36537893356816, 59.376690618453495, 67.09330281903668, 64.26277537499705, 64.10881842336347, 60.68556593310449, 63.374637019249704, 64.7991281170999, 65.72136363675519, 63.68447680627147, 64.73629174693939, 69.69807824780865, 67.79166513873686, 71.75895429426625, 51.261840174275065, 1.6980633019439637, 10.001583060910626, 3.9236880886939267, 0.1856233645230532, 0.15817831060098064, 8.721016472385777, 70.13012732228925, 56.47791393341557, 71.46980500990345, 75.89383063777801, 31.769486281179617, 24.175869803274832, 58.062618163324174, 60.30763379989132, 71.27987600141957, 28.02685872200997, 0.3429131816712118, 0.288669069808337, 0.1468553625407719, 0.09809759700851095, 0.16531806619417283, 0.14147393195138824, 0.09793930792159612, 0.08643510345850261, 0.12017953750346938, 0.11494245320077866, 0.24351514275035552, 0.1858436148012838, 0.09530611050825927], [0.026368937875714996, 0.10250994169543828, 0.03524531903226049, 0.04206826662524574, 0.0538627915985642, 0.012050613802256844, 0.06078039701547354, 0.0579130869629162, 0.058936909847562356, 0.10344763331475759, 0.1947210876331214, 0.3282549166150632, 11.309339519469969, 70.6601022904919, 57.970234578655614, 54.963749608685895, 33.94279118507139, 29.816634270452685, 30.132671402346705, 40.097091967059725, 39.12558755566997, 66.17486415370819, 40.437875332370886, 0.08159289917638225, 0.10871955929624458, 0.7820880689447927, 3.010140864118453, 1.0378829269639909, 6.323434364411139, 48.52138211650234, 61.71892612211166, 72.0447224955405, 63.08209488468786, 59.35253666293237, 51.24774317587576, 53.97555551221294, 51.71136340787334, 48.832198573697, 46.34290948990853, 48.601206271879136, 45.75857047111758, 53.00565142785349, 58.287640617739775, 60.23221446621803, 58.12942004972889, 56.32631040388539, 59.24726416987758, 60.90470090989144, 52.953554507224794, 44.06266312445364, 44.126091772510165, 43.732909464067035, 43.858527291205625, 43.82564213968093, 44.10837834881198, 42.12115264707997, 43.44675687051589, 43.108785844618275, 42.731167501018895, 44.17618436198081, 43.42321480474165, 42.282362061162154, 44.42251313117243, 41.956287583997174, 43.48275246158723, 40.232425505115145, 43.15445007816438, 45.676840043837025, 44.22513946410149, 42.46451693196451, 44.044314276787546, 41.920801901048236, 43.61459509018929, 42.54729855445124, 42.89206704785747, 40.41738094822053, 41.36687694057342, 43.32129986055436, 44.238765778080115, 46.67999798251737, 48.88819040790681, 50.424739699209894, 53.21125422754596, 53.63206178911271, 56.90167896209225, 56.348907178448094, 58.294524377392186, 32.40233129070651, 43.520167950660955, 60.18379280644079, 50.83974607529179, 56.08553178848759, 54.49559511676912, 55.30569399556806, 54.80252842749319, 56.638860548696215, 52.213611141327895, 51.26533892846877, 51.02819242785054, 51.13145666737711, 50.38401765208091, 49.53293392735143, 42.22490718287807, 41.60743198087139, 41.71334774263444, 43.768744237961315, 41.500437567310954, 42.68567585176037, 42.84929752349854, 43.54168215105611, 41.37478836121098, 43.69336412798974, 43.31194108532321, 44.38711766273745, 42.038061157349624, 42.24104773613715, 44.58273018560102, 43.59577555810252, 42.61425733566285, 43.64957086501583, 42.95879048685874, 42.08947166319817, 42.77612178556381, 43.27609846668859, 43.60322806142992, 42.66020005749118, 43.47710817090927, 40.95573802148142, 45.87864598920269, 51.83726364566434, 63.11874158920781, 44.41012236379808, 41.71393609816029, 62.24808915968865, 56.31724188404699, 58.80477374599826, 59.307288200624534, 58.20885196808846, 54.6743179136707, 57.09482431411744, 52.56649109625047, 54.586182255898755, 51.728708128775324, 57.81647374553066, 60.625051606086, 63.34231668902982, 61.60805248445081, 11.080808504935234, 1.3658197945164097, 2.927834829015117, 0.26895122302155344, 0.054958124960502314, 0.07369641725334429, 37.3376614047635, 58.533867405306914, 52.48033623541556, 52.224774206838305, 21.27516527329722, 29.187142887423118, 44.717326318064046, 51.130197586551795, 53.38699994548675, 26.70914434617566, 0.12555162182017682, 0.019476293518598524, 0.04216616883152916, 0.04034508207452394, 0.01205958660706998, 0.019214184196185202, 0.06326595779448267, 0.04026361245421633, 0.022296849225137024, 0.04048752463272503, 0.009264181567085607, 0.023707259228573214, 0.06908356437399503, 0.08763428386901656, 0.03840696006532639, 0.03219781743903314, 0.053566817359458056, 0.07694862903125825, 0.06475673808205513, 0.12897480910103168, 0.024162832564944704, 0.06308298152420791, 0.04153788863350788, 0.21558547692914165, 0.4075288676446484, 16.465764814807525, 79.86598353232108, 65.70099476845034, 62.5553088034353, 43.70805340428507, 31.81684497864016, 22.22731867144185, 44.10254578436575, 46.393111905744, 72.6966517971408, 43.65438753558744, 0.09360820685903873, 0.06539455990517332, 2.0773291635897855, 3.1312146254124182, 1.920751946107034, 6.751937125959705, 52.00469001646965, 64.93406941813808, 75.0631118589832, 66.23977153531968, 61.80185679466494, 54.32935330175585, 56.94783349190989, 53.89304061089793, 50.82379379580098, 48.538895499321725, 49.315811126462876, 47.78414518602433, 56.1975742924598, 59.40432763868763, 63.10088696018342, 62.80605023907077, 59.33614115561209, 60.4378447225017, 63.34415235827046, 55.81062855259065, 46.65028602846208, 45.597231618819706, 46.8001558703761, 44.924062682736306, 45.2438299886642, 44.80202205719487, 45.06828038923202, 46.49268127256825, 45.824364308388006, 45.491049135884936, 46.556105998254594, 45.85029509759719, 44.78375950167256, 45.367914169065415, 45.50080799287366, 44.412107083105276, 43.15317923022855, 43.467804308860536, 47.33152720236009, 46.42052927324849, 44.86527812096381, 45.945436108496885, 44.9418310196169, 44.83156142696258, 45.50274956610895, 44.140286830163774, 44.59499935950003, 44.125809361857755, 44.05454381819695, 46.27209501881754, 48.811555139480106, 51.93089062167753, 52.64735075735277, 54.84393296703216, 55.725344457933986, 58.682533079578036, 58.31767028377902, 61.887340930200395, 35.76527341719597, 46.51387776097944, 62.86566242094963, 54.57583504338419, 57.20217174099338, 54.74473230300411, 56.14837992575861, 56.23815121189241, 59.04198692690942, 54.53018649931877, 53.381571385168264, 52.18268717488935, 53.01460619895689, 52.5076751555166, 51.18076478281329, 45.393691985837876, 43.0972776105327, 44.342277126927534, 44.9722921463751, 43.10123528203657, 44.75527132711103, 46.003502876527854, 46.24579944918233, 44.81352636891027, 46.78103823815623, 45.33258145855319, 45.290004130332704, 44.552720131412634, 43.92285808440178, 47.29340960902553, 45.511037534283055, 44.95012291016118, 45.75991192171651, 44.94730272600728, 43.60144338300152, 45.29031007520614, 44.85008678128643, 45.33828458478374, 42.6621102517651, 45.21374148707236, 44.11029246545608, 48.340094089508064, 53.73514952198152, 63.80597614472913, 46.712832143229825, 44.71605154775804, 64.80918115185153, 59.78800996657341, 60.85194110870362, 61.329015070392245, 59.363480075713134, 59.29364227479505, 59.165357235939275, 55.201523688531694, 56.93374041588076, 52.91180872148084, 61.386866108063735, 63.54923348273001, 64.31929672918012, 64.10403313175325, 13.937546207058816, 0.2893445448529336, 3.565944639905807, 0.8973102668120015, 0.08890595917980518, 0.2357366077241398, 39.77261781692505, 64.62182129583051, 50.797541372237674, 52.68604493910267, 17.832693169193885, 31.47023689362311, 50.45355343049573, 57.09298864487679, 61.20492696762086, 41.137453586824485, 0.6097082961951533, 0.07788287325491829, 0.044736267412982644, 0.03320511197671294, 0.0460896153573788, 0.05666733606748524, 0.03275242296137637, 0.05888398466331344, 0.015208843828839882, 0.03288144748958369, 0.024443247558308706, 0.042869146432607405, 0.021533053818969958, 0.26853830163036624, 0.3280177664372229, 0.16624507854782766, 0.10953320595886439, 0.16193718228849674, 0.13709360973969584, 0.21353151859535327, 0.16557701923433812, 0.19904910136134396, 0.2690350330404697, 0.4115849354815099, 0.5955569974837766, 19.84952884335672, 92.17762101081111, 73.1041625238234, 72.80862762082008, 47.913340214760076, 40.41927937538394, 40.770409953209665, 50.14240749420659, 52.66713127013176, 79.52675342559814, 48.39349715940414, 0.4979293264688984, 0.18780032593396404, 1.6151642535002002, 7.425071741304091, 4.44722056388855, 9.177334231715049, 59.20055658586564, 69.53781020256781, 77.57837095568257, 69.25557213444864, 65.21470323685678, 56.58076240170387, 61.173406800916126, 57.69098535660775, 54.81222844892933, 51.36625759063229, 52.96347025902041, 51.11415117017685, 59.090961640880955, 63.7283367495383, 65.72463097110872, 64.51072800544001, 61.04958934168662, 63.80965140558059, 66.6010610518917, 58.76518918621925, 49.506999215772076, 47.40537366559429, 48.4946943098499, 47.3332412781254, 47.013540652490434, 47.69491518697431, 45.69649896314068, 47.900380703710745, 48.692397456015314, 47.500122439476755, 47.98435864910003, 46.9489235262717, 46.605523940055605, 47.946958849507, 46.45499121758246, 47.639805886053274, 43.60234552814115, 46.130458231895204, 48.05963285507695, 48.62387364910495, 45.78098289428219, 49.26235314338438, 46.774052496879335, 47.113180621977776, 47.90261253233879, 46.43627758949034, 45.395668860404726, 46.4980431525938, 46.25738220830118, 48.545186981078125, 51.02933383757069, 54.759790282095636, 58.24593405569754, 57.78737760359242, 59.364260627377426, 62.081882646006925, 60.275799843572806, 62.70134648969097, 39.00395093425628, 48.361290577919256, 64.7822227016572, 55.45080600246307, 59.318643462273386, 57.22826334737963, 57.704623437696895, 60.37199597204886, 61.729292946477095, 55.69397726366597, 55.84641233567269, 56.12698339646863, 56.630588270002804, 56.417113273374504, 53.635976314544685, 46.572132802778675, 45.82663536071778, 47.15105110599149, 46.55702383287492, 45.653141083255896, 48.638609993842344, 48.57488324565273, 49.151522651795425, 46.60677909851075, 47.75268777724236, 48.00427644483505, 47.89859210291217, 46.105437432566, 45.65226639470747, 49.490544872899214, 47.21813932541878, 46.42971546419206, 47.212502879481164, 47.60077438046856, 45.843976159249586, 47.9259898585658, 47.00702951800439, 47.354645652155725, 46.42287877298171, 47.41389305360856, 45.49299855386057, 50.3248094743298, 56.02582939209477, 67.14698437721499, 49.94828547200849, 48.15129864600397, 68.8409697624945, 64.06730405745968, 63.65063851879489, 65.31479427891394, 62.83487181509695, 63.00137642891177, 62.52859746256183, 57.87225377175116, 59.843346764964444, 56.732299250941125, 64.06215398542344, 67.01722452717443, 67.34950419395201, 66.10388494306996, 14.372759653675942, 4.932358918651458, 10.09268795290301, 0.6404267672088839, 0.15348343268757866, 0.4613201909007565, 45.16814001144902, 71.4679850301435, 64.63111339076873, 59.18180765644197, 30.978630550446052, 41.36665728784377, 57.87172032940773, 68.09757078847578, 68.38359002144107, 51.08486675447034, 1.4164425168306598, 0.15751178346333966, 0.16057702382245373, 0.1577010378241539, 0.1461470070024652, 0.1028098114916394, 0.17457015602098358, 0.11569798443346255, 0.10315708680859498, 0.1411887633824541, 0.07402976509183645, 0.11314661287131811, 0.12664118270960548], [0.033019783816510634, 0.00887211021636763, 0.015199045564288334, 0.00696712150989521, 0.04319921541478365, 0.012389494710782123, 0.03109348254398473, 0.01995225053941531, 0.04189990348212662, 0.03494224698853589, 0.025148458305686235, 0.07727214030080265, 24.387367925336285, 76.04220605665638, 56.76698869274509, 44.80498344667497, 23.369671721612256, 24.60001334067314, 49.02765812412385, 34.45996745940178, 47.79238216338619, 71.19399178412654, 18.89429638462682, 0.17337885865521047, 0.08398847909824503, 0.5501596076834587, 2.7600532385610768, 1.0314867669536223, 17.1560941203948, 62.86368554638278, 67.63751599096483, 64.86473760297223, 59.83603546696325, 52.60848399131529, 50.12651012789819, 55.01556019629202, 54.21975051203082, 52.958402556757775, 50.12765938235868, 44.99610877806141, 45.47760325093424, 43.15685449108001, 49.257783582133634, 55.409750553869436, 58.16869081989412, 60.74094195519725, 59.812210990536606, 58.99220812705256, 48.45762398935134, 44.096728909400206, 43.582192390195786, 43.8364992603179, 44.317974121339866, 43.50032860232938, 43.56267467621834, 41.592319088597456, 43.45210698343093, 44.101329849612334, 42.24628410031719, 43.47338191924557, 45.201699810643355, 42.71263037958453, 43.60215725437288, 42.70968860195529, 44.08463624215896, 43.166621192809075, 41.881193807048184, 44.3487568824522, 43.81790722570112, 43.42604675600606, 43.62484424344955, 42.90526974585749, 43.69564694743003, 43.032244713075706, 42.79339590380269, 41.252371188133, 42.03145588597944, 41.505603328827895, 45.506687625761955, 45.697122619998076, 49.681854555683756, 49.194025454982636, 54.82338759206957, 52.225080151711744, 56.65673086720129, 51.19382235311693, 60.5519856945161, 28.68899206961355, 40.06875676493491, 58.35622326020272, 53.74657930866365, 58.68906382591494, 53.666449208413404, 56.8739164260126, 52.629935433787686, 55.5942980704769, 53.534520287667554, 53.91892040929487, 48.268781477405184, 53.14418561996953, 49.33298718544745, 52.7007616719892, 45.385223588635846, 41.06858068896879, 41.0811597301114, 43.91149890038275, 44.38479561959544, 42.666165982523275, 43.4497731731784, 43.57071945744176, 43.44486236572266, 42.8301053662454, 44.64874759797127, 43.75206631998862, 41.43206281046714, 42.01028293178928, 44.54754260278518, 42.35232145555558, 43.086640142625384, 41.73163775474795, 44.400536091096946, 42.637760177735366, 41.434008306072606, 42.74806114935106, 43.401006344825994, 41.84928924806657, 42.881402123358946, 44.07122173616963, 44.49359432343514, 52.60609526788035, 60.228719634394494, 51.43290650460028, 53.93077381195561, 59.60092859883463, 56.68991019648891, 55.773766117711226, 54.96893105968353, 51.671155191236934, 51.74898286019602, 50.012055366270005, 51.5096829783532, 48.854846339071955, 51.12514557376985, 57.31316304975941, 62.616399718869125, 61.560795768614746, 66.6064582332488, 36.813401329901914, 1.11011803150177, 2.116336399509061, 1.342550088321009, 0.12051942007195567, 0.0851327539872258, 9.045248416162307, 56.65177691367365, 39.8147754515371, 31.13222468283869, 25.021958389589866, 17.070560955232192, 32.82181309115502, 47.61735031681676, 51.7356821029417, 43.10751499668245, 1.964840490010477, 0.1477037283081201, 0.07380964504855295, 0.003318492268707844, 0.04429648697917019, 0.11265470781513762, 0.01849159282902556, 0.051743466812636585, 0.05863977115481131, 0.05133107019167754, 0.06662785421095549, 0.014249071640323007, 0.047182780690491206, 0.013169984130429165, 0.04004198321772199, 0.043573954983824686, 0.03606345113967696, 0.042766881355595206, 0.0516207471880461, 0.04825653335560234, 0.019462000233151262, 0.05069353948197058, 0.020848489141151793, 0.02507233023343067, 0.10760317000770762, 35.56119641950054, 86.0609043798139, 62.509542588264715, 51.5201674738238, 28.552838756192116, 32.50032386472149, 42.17468515519173, 34.914954554650095, 53.4663220374815, 77.9503293191233, 19.80591797059582, 0.3191132813451752, 0.25930908718897455, 2.2363753905219417, 6.075955360166489, 1.2219739777426566, 19.114368807884958, 69.3091203320411, 70.19429729830834, 69.37995049261278, 63.28730152499292, 55.39431602724137, 52.156085660380704, 56.6841874584075, 56.27590402480095, 55.363670549085064, 51.0088159191993, 47.431731993152255, 48.139813946139434, 46.87193132215931, 51.93557393166327, 59.144317642334975, 60.728139338954804, 63.2960601775877, 62.699604957334465, 62.32610118004584, 52.191614489401545, 46.43880751825149, 46.09001859541863, 44.94687911002867, 46.188721118434785, 44.81888824893583, 46.16073108488514, 43.419331658271055, 44.96167036794847, 45.78562305819604, 44.72054658397552, 43.281221082133634, 45.27191415909798, 44.34994536061441, 47.019651705218905, 44.166205852262436, 45.271749419550744, 44.57227314672163, 44.46023064274942, 45.69059187366117, 45.233435707707564, 45.59287778792843, 44.582530144722234, 44.1523128171121, 45.49065297649753, 44.17744344280612, 43.29558087933449, 43.53793236517137, 43.91068696975709, 42.48357965100197, 47.26034402847291, 48.97172512546663, 52.69852592099098, 53.35333424229776, 57.1807752117034, 55.49409327968475, 58.251825455696356, 54.95339062906081, 59.91744425988967, 31.52610125080232, 42.11105254388625, 60.60762843778057, 54.709948724316014, 60.53030283220353, 56.37783073609876, 58.65217785681448, 55.628858074065185, 57.70909101732316, 56.05241129475256, 56.38696593623008, 51.56498055304251, 53.342402596627515, 51.74079295127623, 54.37671199921639, 46.78527832031251, 44.0056553963692, 43.05174673757246, 46.071340268658055, 45.7192643996208, 43.824653702397505, 44.97836005303168, 45.867153444597804, 46.35490802026565, 45.58506834891535, 45.158075209586855, 45.96423210636262, 43.137525050870835, 43.60292211655648, 43.844269475629254, 45.007499341041814, 47.15781327216856, 44.66440569969916, 46.120416964254076, 46.16450832736108, 44.094089154274236, 44.44282316392468, 44.7002169393724, 43.58311022481611, 46.06149119715537, 46.40539284675352, 46.075388154675885, 55.64437889283704, 61.370556892887244, 56.539679496519035, 57.284878838446836, 61.603459388979026, 59.11845745578889, 60.670284378913145, 57.72314486965057, 54.82589398660968, 53.42605890766267, 52.638941195703325, 54.01950174762357, 52.45440936857655, 53.94198394590809, 59.69880350174443, 64.71247119288292, 63.59613718525056, 68.54483865922498, 41.5653645607733, 1.8506280573145037, 2.2512267097350094, 2.5715855581145135, 0.11066493232764545, 0.2797412956433912, 8.990549983516816, 66.18592523759412, 44.89338582561862, 34.362814272603686, 32.11259953437313, 29.991948527674523, 38.95614116422592, 53.170751833146625, 56.67025127718526, 56.68315195268201, 5.319936650414621, 0.3164544965951674, 0.04625197237117156, 0.10836595609303444, 0.016962448773424954, 0.017209753446701555, 0.07669990326488212, 0.05044792403256701, 0.0514887732213303, 0.09021370191006892, 0.015461878839790102, 0.021354022901505235, 0.06018656013052791, 0.1371310254739177, 0.16992217801030607, 0.06870012204613417, 0.16182709545377763, 0.11671888086223796, 0.12011081941666142, 0.2059450877770301, 0.11264017512721401, 0.12664633082045665, 0.2679074741899967, 0.07047140925762153, 0.22955116785822377, 42.320746375668435, 96.60529444294592, 70.59214330488636, 59.243749726203184, 34.35938612107308, 32.67486933738955, 65.58051916860765, 48.29720689404396, 62.02320006585891, 85.11733901116156, 23.528304138491233, 0.48034080574589394, 0.5525108847406603, 1.75940316530966, 10.281240209456413, 3.8124533478290807, 22.32131435025123, 72.08749986463978, 73.63718125127977, 71.00935797537528, 65.0288534933521, 58.549607876808416, 55.517984436404326, 60.017362717659246, 58.89393706475535, 58.27911338498516, 54.39517851798765, 48.73086806266539, 50.089467263990834, 47.95544685855989, 54.513689010374016, 61.044447114390714, 65.3070201412324, 66.65706465321203, 64.2784530885758, 64.90896232666509, 54.762077023906095, 47.7096240751205, 47.4455818822307, 46.32451749617054, 48.50653594540012, 46.953708817881925, 47.84629906377485, 45.02479699350173, 48.10709353416197, 47.74499993170462, 46.4742971235706, 48.09699735333843, 47.995815892373365, 46.649152463482274, 49.80619369014617, 46.36076411893291, 48.806173647603686, 46.227332930411066, 46.204261549057506, 47.77504136485439, 48.70823206440095, 48.63577412020776, 47.241257775214414, 46.419431009600245, 48.52248430252076, 45.63055215343353, 46.981396828928304, 45.908228505042295, 45.02527944503292, 44.80976873828519, 49.051133509605165, 50.51244389626288, 55.912421903302594, 54.61551766241751, 60.100854289147165, 58.36024761199952, 61.719914559395086, 57.767381360453946, 60.66771130408011, 34.287653815361764, 45.05670155248335, 62.48803623260991, 58.05312602750717, 63.40403910606139, 59.45762480458906, 60.5327307793402, 57.75102507683539, 60.22779395503383, 58.09310674667359, 59.78433862809212, 54.13665117756013, 58.092741966247566, 52.767410585957194, 57.69557845207953, 49.75090788256738, 45.32215972100535, 45.526581887275945, 47.10064080453689, 49.14159121051912, 46.21735834306287, 46.567355355908795, 47.886456289599025, 48.97111323571975, 46.41279043689851, 47.43827842896985, 47.44109861312374, 45.018607493369814, 45.94099206309165, 47.49269347037039, 47.41238294109222, 49.119131718912435, 46.393331558473655, 50.49737415006084, 48.41104192118491, 47.15682875725531, 48.9868184058897, 48.979091336650235, 45.5941290240134, 47.626669868346184, 48.8424712611783, 50.07775898902647, 59.07304425393382, 65.00768053916194, 59.295285747897246, 60.053734856267134, 62.31868397804999, 60.791391480353575, 62.91494700216479, 62.09834875599031, 58.63559015335576, 56.335602498823604, 56.14508905718404, 57.81873303074991, 55.07126177510908, 56.142598352124615, 62.520450699713926, 68.58512140089466, 65.28631394909274, 73.14078177175215, 42.82353931857694, 2.7571126866725186, 6.971466300948975, 3.857693720248438, 0.23661192446466417, 0.39797627216865944, 11.76164665529805, 72.89819102133475, 50.378691073386904, 42.704420858813876, 38.23457410258632, 28.19285538888747, 44.54948417602047, 64.45683856164256, 65.73405642663279, 66.51351374964561, 7.148957963912719, 0.5937654549075712, 0.24605585802947325, 0.23615728192512067, 0.18662392131743893, 0.2143598128590853, 0.12807973495294012, 0.13268982991576195, 0.15987398493434155, 0.16905271418152318, 0.18356223560629353, 0.08414200311827083, 0.15105465817595684], [0.022526639213244763, 0.042175438495412956, 0.02453753957524896, 0.11474953693968636, 0.04925329801476291, 0.06772761173065632, 0.019665934753814535, 0.024040875197838874, 0.040844916140720736, 0.055319569073617465, 0.040633269029879765, 0.37508433925048, 43.28412755843132, 72.94983294702345, 58.3435461598058, 48.92715915556877, 30.424576151755552, 17.422052391113773, 29.38687389896762, 40.86659823694537, 49.611432321609996, 64.06148326012396, 4.551520309140606, 0.13963011153523, 0.05792985279713908, 4.342793341605894, 1.403834915930225, 2.8747131891788977, 48.89055951949089, 74.29017743756695, 66.05444738941809, 66.85209274291992, 55.63459257925711, 50.23898017021918, 53.53262186050416, 53.44239557943037, 58.422330887086936, 58.143501358647505, 53.956382966810665, 48.16991421484178, 44.70198985069029, 46.29582535836005, 44.9857811773977, 46.162190206589244, 52.67623116893154, 52.24458609857867, 53.63478783638247, 49.81368933954547, 43.48368598568825, 44.22832442868141, 45.82808663768154, 45.05536010188442, 43.41011016599594, 43.310132872673776, 43.47888500459733, 42.60476127747567, 43.734274448887, 41.1586186962743, 42.70828047106343, 41.99504452366983, 43.1471936933456, 43.11774846046202, 42.088636198351466, 43.87367156244094, 43.059312989634854, 42.77687095826672, 44.14332666704732, 43.1573369426112, 44.20644152549006, 43.87665648614207, 42.779373430436664, 42.35767156847062, 43.383889121394006, 41.21521457549065, 40.178300719107355, 41.18112133395287, 42.52389377163303, 43.09641468909479, 48.763439424576305, 48.31211582306893, 52.390682620386926, 51.31803989410401, 54.54712721609301, 50.97766445529077, 55.74623107910157, 51.724605329575084, 62.93635137619511, 30.61259496596552, 32.72425001667392, 56.7080040900938, 49.02966637765208, 53.33952749929121, 50.21821122015677, 52.455684138882546, 50.92652459298411, 54.68873262405396, 54.147484763976074, 54.249890004434896, 49.206486825020086, 52.46350926737632, 52.66407182139736, 52.41370693329842, 46.17554979939615, 41.23202585404919, 41.454906694350704, 43.30646937893283, 44.677930032053304, 42.080775768526145, 41.648820830929665, 43.546679250655636, 43.61694851229268, 42.406281502016135, 42.82750483482115, 42.50862006218203, 42.757910220853745, 43.347179658951305, 42.31973440416398, 43.345912733385646, 43.53557502069781, 44.879277060108805, 43.276192603572724, 43.609519543186316, 42.86803468581169, 42.6013135140942, 42.589024728344334, 42.981293124537316, 43.94054405150875, 42.22367948101413, 42.84606549047655, 47.60723844651253, 56.470077037811286, 62.861026179405954, 60.85847969978087, 56.62507341754053, 56.20769400750437, 51.86579496629777, 50.19938384332965, 49.75133542091616, 46.469637347805886, 47.110646770846465, 47.21577413620488, 48.02072686533774, 50.25244958939091, 57.62519544170749, 60.93369899257537, 62.08675422976094, 64.04262842670565, 56.66679959143362, 12.819528522030001, 1.377943472996835, 1.0478098329997834, 0.12402653228491546, 0.03454893361777067, 1.8215276252838875, 45.775354293084916, 51.42851345000729, 37.10411171759329, 20.32656946489888, 9.957659379128488, 27.319021917158558, 46.714538374254786, 51.1486013474003, 56.92759798419092, 13.0600865041056, 0.27979936510805165, 0.0486207353852449, 0.04940066651831712, 0.031595852361210895, 0.0399190299363146, 0.017865451931532834, 0.017716233325641484, 0.07818854999758544, 0.07213885325097269, 0.01566510377151351, 0.04728276665592867, 0.045534435269092365, 0.0020284243838696353, 0.04335792201961722, 0.022716747762094584, 0.04773836297493789, 0.01292866547667091, 0.030725204926585, 0.0313138285832059, 0.022554768046604532, 0.0456818267552843, 0.04038843499015897, 0.023317021700823982, 0.24721242096875948, 54.36852601266677, 76.25622626273864, 64.09991464307232, 57.4802520967299, 34.6932465030301, 21.981905775685465, 30.289950601516235, 44.57168086882561, 54.9004307869942, 71.39442489993188, 4.741117877344932, 0.20428428576598245, 0.18721472832464403, 4.947837081647688, 4.056678255719524, 3.0757086748077027, 54.28803505436067, 74.0889363135061, 69.67861544701361, 68.97415776406565, 59.38542573682724, 53.44196019634124, 57.22940475709977, 56.09023078795403, 61.626013017469845, 58.869253589260964, 56.749396862522254, 49.55116510391236, 47.023785883380526, 48.32500080908499, 47.68430125328803, 48.02395497598956, 55.126551505058046, 53.60511118365873, 55.758060947541274, 50.85541594413019, 46.43569707870484, 45.720441110672496, 45.357712084247225, 46.40810320454259, 47.650325682855424, 45.51819585984754, 45.75586403569868, 44.893432894060695, 46.040439836440555, 43.070899671123875, 45.05540717032648, 43.2874458835971, 45.78593292543965, 44.67456463844546, 44.37840215621456, 45.62343697394095, 45.290702312223374, 45.11020660400391, 44.24538673893098, 45.09827475393973, 46.263132402973795, 45.57272857235324, 45.122189444880334, 45.4681150374874, 45.35435061300955, 42.684350090642134, 42.731806847356985, 42.666573909021196, 44.29310629444738, 45.79770788069695, 50.0416261149991, 50.741777035497854, 54.73451060633506, 52.30575546141594, 57.48463338421237, 53.84419533514208, 61.242801374004735, 55.12305275086434, 64.08948113841396, 31.492968989956765, 34.648460880402595, 57.752676394677934, 52.124330151465635, 55.909370299308534, 50.791210666779556, 52.918253175673954, 52.89399331615817, 55.5627033787389, 55.204249735801454, 56.60338663285779, 51.82200954806421, 55.26481897600236, 53.42443504641133, 54.489068292802386, 47.15893507003785, 43.45335037477555, 43.45266788236557, 44.434735236629365, 46.088559473714525, 43.685597835048554, 44.13196356065812, 44.125417124840524, 45.24962332940871, 45.069464945024066, 43.64977090589462, 43.7915567428835, 45.92458478866085, 45.20475925937776, 45.622068066750806, 44.78873306705106, 44.21724373294462, 46.660186090777, 44.57172009252733, 45.00460463185465, 45.823830866044574, 43.55714021190521, 45.19556130132368, 46.22208872149068, 45.60386434678109, 43.94569804591518, 44.47885797869775, 50.630028709288574, 58.52151978400446, 62.73090939367972, 62.33951568603516, 57.730942541553134, 58.08446968755415, 55.02848832837997, 53.345379675588305, 50.770531931231105, 49.00750106380832, 48.760109332300004, 50.073263952809, 50.243122193121145, 53.60544458512337, 60.301738477522335, 62.69683968636298, 65.23122818239274, 66.45891435684698, 59.31115957998461, 15.028237719689647, 0.7341047953213415, 2.6671693065474114, 0.09071490727365018, 0.06960321713479296, 0.7146430976929203, 47.27097365163988, 56.008421913270034, 39.32507145789362, 27.080616335715018, 19.59034646711042, 36.25889978101177, 54.429707142614554, 56.08774792763495, 67.93818135415354, 19.607806897932484, 0.3650520808033405, 0.12083678731634734, 0.0539585602499785, 0.09200833948148836, 0.08222037881252267, 0.020017163084459402, 0.03565819062773259, 0.03439833605361562, 0.0966787102421926, 0.01910918227006351, 0.058925950959805524, 0.04973579168079361, 0.16850706039657518, 0.12953340977190003, 0.07977918601564823, 0.2254066321878664, 0.11801315576679285, 0.10922285607985913, 0.10311187229930394, 0.08548464115348556, 0.16881781630218032, 0.11222204433814173, 0.07847253113023697, 0.36203455240015064, 64.95115918497886, 85.84840605335852, 73.41465734666394, 65.81380213460615, 41.91972717162102, 26.569125536949407, 42.16092940299742, 53.370839780376805, 59.80956731304046, 76.19476272213844, 6.029061463571364, 0.37149481895950537, 0.2851213779180281, 8.50710609266835, 7.96625929494058, 5.128415649937046, 55.866153624749955, 78.70827244174096, 72.91413153371504, 72.78290471723004, 61.443469832020426, 56.022507144558816, 60.19811730231009, 58.63465270688457, 64.47073944153325, 62.23268208965179, 60.49525645471389, 52.954017346905125, 48.92839077980288, 51.8852577670928, 49.808578491210945, 50.570036057502996, 57.57545586555236, 56.85962330910468, 57.65889252385786, 54.5111120131708, 48.28269804677656, 48.35522659363286, 50.506105346064416, 49.58452486222791, 48.478298802529615, 48.14947866624402, 48.02724192219396, 46.9323750465147, 47.578864020686, 46.198099505516794, 47.27781034285023, 47.025856894831506, 47.64376355755714, 47.41536002005301, 45.89049546949325, 47.57192534785117, 47.31396675109864, 47.53865972641976, 47.34336491554014, 47.44782940033944, 49.1743939922702, 48.5873838393919, 47.383396625518806, 48.52701071769961, 47.91701939798171, 44.10365581512452, 44.106303414990826, 45.770557234364176, 47.446068256132065, 47.18778410265523, 52.82002525944864, 51.21854897468321, 57.94135808944703, 56.68431689662319, 58.5435752714834, 56.152545482881614, 61.860649201177786, 58.471074181218306, 64.27657035089308, 35.01212735329905, 37.3285379717427, 58.36993194395497, 54.89754392254738, 56.00921423204484, 52.06028176892189, 54.608378948703894, 54.76194758569041, 56.83846996676538, 57.43406226558071, 57.50914427541918, 53.46132493788197, 57.80494197722405, 56.49020271916544, 59.22233358506234, 50.02076302805255, 46.382952966997706, 46.10328012897123, 47.39836831246653, 49.28409091887936, 46.18551261963383, 45.08454645833662, 46.17958199593329, 47.880984583208644, 47.06974429468955, 47.26793773712651, 47.241646089861476, 49.3763921337743, 47.276076655234064, 47.967629740315104, 47.73320144222629, 47.71755510760892, 49.18750647575625, 46.548029838069795, 47.336316416340495, 48.36911570641303, 47.317991102895434, 49.535667819361535, 49.10701551745015, 50.39272531386345, 46.689548953886955, 47.77471580813008, 53.71216835514192, 62.59061013498614, 66.06577519447573, 66.36119242637389, 62.6733603785115, 63.638259518531065, 58.98819161999611, 57.94893610861994, 55.50415808154691, 51.84762262528943, 51.842378416369044, 51.78475095379738, 53.85379729732391, 56.24474471615207, 63.51619143639842, 64.21271416448778, 68.81045372255387, 69.97830806239959, 61.68067909056141, 16.286707635848753, 5.786553082927581, 3.9776596571168596, 0.127482554094205, 0.1800338184881595, 2.10348867600964, 56.97161089989447, 62.54641679025466, 53.30574412499705, 24.69204979558145, 18.433659115145286, 38.93770602441604, 62.87098507727347, 64.83689269711896, 76.44409994925223, 25.27520621976545, 0.7779964852717616, 0.19026161321709234, 0.1327718626106939, 0.19093048458378162, 0.16216340805253676, 0.12449420598005095, 0.11045350738230253, 0.15319267167679726, 0.19593974965954983, 0.15634330019595163, 0.11515764729870905, 0.28240642360141205], [0.03613119629482108, 0.055596617110554254, 0.06482480499412745, 0.13563358405184361, 0.012527114745499867, 0.08328751630840764, 0.004058209531414773, 0.056263439192046086, 0.02442924730149248, 0.07228384305152201, 0.15085922914647287, 2.3021434872381152, 57.24503932460662, 66.9634880558137, 55.494634566768525, 43.15202997576806, 17.59376002896217, 27.814897760268185, 42.241942036536436, 35.74470450801235, 67.50309636515956, 50.05384429808586, 1.102748265670192, 0.04005980625328037, 0.10973428871722953, 3.24355473922145, 2.3409094973917934, 15.263024914649227, 72.46771873966341, 64.65505161593038, 66.60883518957323, 58.504465318495235, 55.31784157599173, 52.27322332320675, 55.713898981771166, 55.30787875575405, 58.04355544428672, 58.63460956081268, 59.62965603797667, 53.91180915217246, 50.57640990903301, 43.62298896235805, 45.212274520627915, 43.36226117226386, 46.60937178519465, 46.31364468605288, 44.95921496422061, 43.423610964129054, 47.564461077413256, 44.24816769938315, 42.9841721442438, 43.024796132118475, 44.04101556347263, 43.63858822853335, 43.5515155330781, 40.64141104298253, 44.1939526988614, 41.24113751995949, 41.459362506866455, 41.37358027119791, 43.60350654971215, 41.635716192183956, 42.350889790442686, 41.86848140531971, 44.4873655996015, 41.49329100885699, 44.4049919036127, 40.96499873745827, 44.94206636182724, 40.53195338095389, 44.729148341763405, 42.1240512786373, 42.70045534256966, 39.88665680731497, 41.78096548203499, 40.42040117325322, 44.4054586656632, 43.12645612224456, 49.4295794733109, 49.53924502095869, 54.055952333634906, 52.62179651568013, 56.12368468315371, 51.68966877845026, 59.4218724004684, 49.27426930396788, 61.588236670340265, 29.603480908178515, 25.092551246766124, 53.51928187954811, 48.043876694094756, 55.22363801156321, 49.48978393308578, 56.58547316828082, 55.29040459663638, 57.36595815227878, 53.47886969966274, 53.76317877923289, 47.80290980492869, 53.552916203775716, 52.1228474955405, 53.31727197093349, 47.659453038246404, 43.102545353674124, 38.92176943440592, 42.68966490222562, 44.487079266578924, 44.58159269825105, 43.13044909507998, 44.08744465920233, 43.194999541005785, 41.69393201028147, 44.08471076719223, 41.61027962161649, 41.01362828285464, 42.56656131436748, 41.82413901052168, 44.05599901753087, 42.50181082756289, 41.97777040543095, 44.9430351872598, 42.209715843200684, 42.3342824751331, 43.168864788547644, 44.996442179526056, 43.65731754610616, 41.94211998293477, 43.33720899397328, 41.65057020802652, 43.755659211066465, 47.493634839211744, 50.65588497346448, 52.03377831366755, 49.32290277173443, 49.02088811320644, 47.60250022334438, 47.65801745076334, 45.65789499590474, 48.696837579050374, 45.55994949033184, 45.470268418712, 45.862823147927564, 52.840178397394, 57.14636425818167, 59.86250362088604, 61.6284841106784, 63.00573810454338, 62.418476919974054, 35.635956794984885, 2.0213631925082978, 1.2012367743638255, 0.32042877688523264, 0.03349198509127863, 0.20257169621125345, 23.078249423734604, 59.82834369905534, 40.786687789424775, 48.312692411484264, 24.2109416761706, 26.451072000688125, 47.68074758591191, 54.45034665446128, 61.658674593894716, 20.688551279806322, 0.14359869213113863, 0.034907570018643336, 0.059622704096498995, 0.021368607300363725, 0.08578945221679826, 0.029601078150012804, 0.016620779304855293, 0.015006370620892174, 0.062060893828710245, 0.015770226356483275, 0.04808688701521005, 0.05214469004122, 0.020329313270086725, 0.03965205978602171, 0.04721713207301594, 0.03765981366497375, 0.03602212452660165, 0.0708286667002305, 0.06805385793409041, 0.027876771280481934, 0.09879025540524915, 0.03163525034793683, 0.22902150998913476, 4.213903767447318, 69.64761303317162, 72.01625393282983, 63.79118096443915, 49.821573303591826, 26.764932217136508, 30.68779072453899, 38.53073658481721, 42.51650010385821, 73.77073795564714, 56.13259238581504, 1.076751163890285, 0.045877726928841685, 0.8359841930289423, 4.291511293380491, 2.2562527368145604, 16.460704957285238, 75.11149037268855, 66.07576939367479, 68.27297133784141, 60.00612120474539, 57.35475586306665, 54.1368825974003, 58.785154050396336, 56.867593565294825, 61.46662750551778, 61.30077792752174, 60.85778936263054, 56.951069447302054, 52.497880997196326, 45.9369755560352, 48.10466558702531, 44.1924935771573, 48.11708773336103, 48.207965127883426, 49.4723686095207, 47.00826506460867, 49.65704556434385, 44.37716268724011, 45.178094986946356, 45.01243760508876, 45.653160695106756, 45.13747492144185, 46.6306741776005, 43.825657829161614, 45.79993186458465, 43.5437806190983, 44.11780772670623, 42.683047863744925, 45.36722383191509, 42.966337127070275, 45.996262181189756, 44.3993240787137, 46.452324005865286, 43.64895113052861, 46.50445230545537, 43.29897765190371, 46.44565205420218, 44.12102407024753, 46.88922897461922, 43.83420075139692, 44.259891663828206, 41.19858372596003, 44.52365536843577, 42.63686979970625, 47.323427507954264, 45.800492763519294, 51.89477735950101, 52.43411502530498, 56.73560580899639, 54.60261306455059, 57.470528541072724, 54.47389656497587, 61.72147566272367, 49.290778560023156, 64.05056338156423, 30.851586941749822, 27.314587677678755, 54.186920273688536, 49.24590272288169, 55.80597269919611, 52.34216290135538, 60.24924539750623, 56.98766123863959, 60.06048525533369, 55.7848350463375, 55.35764971087056, 51.27340332154305, 54.76390877077657, 53.62334628258982, 54.93601060682728, 50.66381208358273, 43.884238427685155, 41.54228141230922, 44.377272513604936, 47.07060721612746, 45.39293496839462, 44.58789986948813, 46.55133247375489, 46.07744739901635, 43.73051681826192, 44.9142881362669, 43.33327093432027, 44.83917082509687, 45.02154927099905, 44.22506101669804, 44.395511534906205, 43.457359037091656, 43.03646910575129, 44.983164956492764, 43.98248203339116, 43.5012464369497, 44.91665724785098, 46.88980164066438, 45.117529669115626, 43.92587438706429, 46.34049723225255, 43.978634188252116, 46.711424012337964, 49.79090429121449, 52.75378427197857, 53.8026652797576, 52.4459998069271, 50.17057403441399, 50.01080020781487, 50.72460097651328, 48.330162648231756, 51.87565580491097, 47.78248210107127, 48.846362252389234, 47.08189971985356, 55.740551487092056, 59.8666181871968, 62.427066910651426, 63.22427688106414, 65.17356149611935, 63.11198334540091, 39.853704975497344, 2.2134863993813916, 2.5026923129635477, 0.43602203709944604, 0.13002621881183118, 0.10127969641959476, 24.227511728963545, 65.39511265293245, 45.676016346100845, 38.052242725126206, 22.364556520215928, 31.725147808751753, 53.97237054763302, 62.615740760680175, 68.52050427467593, 30.738334386579453, 0.0550579538779153, 0.04438944025746277, 0.015344935518148688, 0.05430351049008389, 0.03253140276478183, 0.09445592145165128, 0.03295819417783811, 0.03555040205678633, 0.037436077686687635, 0.05960475082599348, 0.022909667853626515, 0.040581761108290766, 0.25658235044008304, 0.1653572745741375, 0.18655213887893385, 0.12166018627824322, 0.08194570564815114, 0.1292846457011277, 0.2630325196491134, 0.2130733214078411, 0.26098130391009394, 0.37719105039873435, 0.31633881731860103, 5.936475876838931, 79.84799554271083, 81.10029066762617, 71.08468317216443, 59.15553954339797, 28.700025696908277, 41.38775963937083, 58.001354663602775, 50.46090787456882, 80.912244396825, 61.047796818517874, 1.76662620998198, 0.141888891136454, 0.9102958861377932, 11.92006334181755, 11.592401285325328, 20.309599330348355, 77.96691310021185, 69.64823276765885, 70.58725603165166, 62.037579474910615, 61.05777532823625, 57.18112430264873, 62.11740363028742, 59.47796621630269, 64.7692043550553, 63.09004945139732, 62.253600089780754, 58.61929270528979, 55.222147510897734, 48.12313210579657, 50.15737918115432, 46.85952878767445, 51.62215302067419, 50.28400897979737, 49.7530024282394, 47.80107021331788, 52.5169123372724, 48.03621630514822, 46.378924692830736, 47.23884551755844, 48.075294879175004, 47.53280755012266, 49.91638875776722, 45.31291077213903, 48.27232337767079, 45.301857532993445, 44.78407721365652, 44.64884173485541, 48.343322200159875, 45.85124431117889, 48.59072569877871, 46.46843318016299, 49.34293823857462, 46.51343453314997, 49.10010430120653, 45.979541117145175, 49.7240278797765, 45.02653460348807, 48.28893853772072, 46.02702140808106, 46.121064155332505, 42.92387354758478, 47.73782983902962, 46.24874907155191, 48.24207013653171, 48.1796456152393, 52.86752516223539, 54.72364564095774, 57.411085021111276, 57.4551881513288, 59.080939985090694, 56.72265806505757, 63.10128311957083, 51.56387444465391, 64.16532801043603, 33.82580257231189, 30.914886151590657, 53.04998990028135, 51.04176382864676, 56.29799873598161, 54.336786193232385, 62.58758598758329, 60.133582545864975, 63.07896483329035, 58.98785429616129, 57.85057875417895, 54.32403456780219, 57.933772225533765, 56.665552277718824, 56.30081499776533, 51.830219068834865, 47.711134187636844, 43.15592881171934, 47.014874258349025, 50.40088776619204, 48.24702016768917, 47.70030844596125, 48.70131300341699, 48.699296905148415, 45.492739677429206, 48.175452601525095, 47.27994803459414, 45.943137599575905, 47.39431650407853, 46.88478492921399, 46.437493524243756, 46.385953580179525, 44.291933505765854, 49.03648345701156, 47.41236725161153, 47.47446229380947, 47.4804360635819, 50.48795261690694, 47.488625972501694, 46.16030746890653, 47.9421264894547, 44.838594236681544, 47.623951665816776, 52.79538493002615, 56.01754534629084, 57.06262557737289, 55.03191647991058, 53.892895483201556, 53.766959944079005, 53.80487357416461, 51.562227049181544, 55.84022675791095, 51.128950272836995, 52.79066239633868, 50.88948565144693, 58.20473347940753, 63.09709795059697, 65.54013836768367, 67.63031451932846, 68.02592477490826, 64.86734597913681, 41.04650166726882, 3.757270012171038, 11.397271213992951, 0.9981333212025705, 0.3075808388811927, 0.5071765286547523, 29.492038526842673, 71.61494055101949, 55.610924997637355, 61.720177358196636, 34.288277472219164, 39.20345052596062, 62.34762714755151, 71.45544913507277, 79.22907690848075, 40.82640178741948, 0.34314003562734974, 0.12379760989138197, 0.1125469652094668, 0.1291312902204452, 0.16160770319402218, 0.1653826167626727, 0.1296829501347196, 0.12101710143108522, 0.15397648687564558, 0.1704421525280322, 0.1301920921691964, 0.14676030635112716], [0.005522346238590657, 0.02087273390873546, 0.04854579666449178, 0.034593868504969344, 0.030106742145313375, 0.016720447343804182, 0.031206059164457747, 0.01942982454033148, 0.1000529368438067, 0.09387522680504669, 0.13789326763681828, 7.846109251822195, 69.07698662050309, 60.14955443720664, 57.75632419893819, 38.829193653598914, 17.733398368281705, 26.583040145135698, 37.496254597940755, 45.43019356266145, 69.04246191824637, 30.412781584647398, 0.0620093054678892, 0.16860654457442223, 0.6811580073929603, 4.028059172053491, 2.39271346599825, 32.72810570655331, 72.7464972772906, 64.1419546065792, 66.631592781313, 59.77775689094298, 62.42990670665618, 58.57611133206276, 61.89203992966683, 57.23595511528754, 65.49287772947743, 61.7415621203761, 62.41023602024202, 58.15198152296005, 56.64606986507293, 45.69815028098322, 44.016787082918235, 43.068012806677054, 45.13788677030995, 42.87285527875347, 45.38187780687886, 42.875326371962025, 44.28606956235824, 43.337122701829486, 44.289846804834184, 42.54328989213513, 42.92573667341664, 42.219286426421135, 44.27245109311996, 41.758462844356416, 43.54196063933834, 41.3894070348432, 42.41191402558358, 40.55563665205433, 43.592198356505364, 40.956855896980535, 43.306269338054044, 41.29679595270465, 42.723107030314786, 42.50372494420698, 44.811977032692205, 42.89353401430192, 43.59077845850299, 43.36058239783011, 46.721351531244096, 41.69761119350311, 43.29565540436776, 41.013781255291356, 43.452244266386955, 42.44675251745409, 42.964874082996005, 47.050850237569506, 51.10776555153632, 52.26512362880092, 56.028476991961085, 54.45421018908101, 59.40139370579874, 54.205265198984456, 59.637551769133545, 49.72685198630057, 64.27032201520859, 30.25451590937953, 22.399597014150313, 60.261573406957815, 50.02268891180716, 61.67774123530234, 52.31345899643437, 58.59172628771875, 51.556233667558246, 54.56768043579594, 49.927151741520056, 47.632729930262414, 48.78700502457158, 54.00401230781309, 51.68384405874437, 51.667625058081846, 50.578096528207105, 41.776799924912, 40.84908093175581, 42.6410706581608, 42.59011906962241, 44.374707283512244, 44.84810990671958, 43.604385160630756, 43.912008808505156, 41.33635305589245, 44.61088103632773, 42.95143604278565, 42.15617549034857, 40.77824292644378, 42.51579799959737, 42.56834991516606, 42.65826240662606, 42.120160287426366, 42.184291039743734, 43.24725335644138, 42.37070168218305, 42.88055489140172, 43.10467520067769, 42.021002769470215, 43.0303462859123, 41.64298434411326, 43.409545344691125, 44.50268637749457, 46.05855726426648, 46.18992528607769, 43.849596054323264, 43.69564694743003, 43.610715866088874, 43.17058278668312, 45.82048900665776, 45.18327643794399, 45.83115000878611, 43.73254860601118, 45.52095720844884, 45.97828595869003, 52.51857149985529, 59.288743234449825, 60.227797877404, 59.32740603723834, 62.84864717914213, 64.28489362039875, 53.72077011292981, 11.203093298019903, 1.3242356839679903, 1.33170387677608, 0.14778554649843326, 0.07128070454083144, 8.359640663669955, 62.507420586001494, 42.25077129179432, 50.64012489011211, 43.264656912895944, 27.39629457073827, 39.607478187930205, 50.69979982991373, 56.732209036427165, 38.194048173965946, 0.9155369694194487, 0.17481348086749354, 0.0742966548028973, 0.0556967601240162, 0.025562821857390866, 0.08009563395453077, 0.10232400449533617, 0.028346145690809336, 0.02898666605864081, 0.04779050674950404, 0.06879067363878412, 0.07535932600618371, 0.01890307780535471, 0.0379111900955679, 0.0857828561997702, 0.026693856831820264, 0.007527080071609348, 0.06440098217177777, 0.022321109314479178, 0.04823450066690003, 0.053799022439747095, 0.03320610023013527, 0.15693291210599486, 12.23497965643483, 80.36039044780117, 66.30240394223121, 66.98155449282739, 45.73077655607655, 22.88329585905998, 25.434299515139674, 42.19080217422978, 48.570294072551114, 74.90870383477981, 34.549283750595585, 0.055885685067023, 0.057754732758527806, 1.2402224372471533, 5.09806287865485, 1.294179051633804, 34.70621778118995, 74.787792851848, 68.56421516787621, 70.34553604741251, 62.276491042106386, 63.70904653303085, 59.97437354057067, 65.19971193805819, 60.38177836325861, 65.33776760101318, 63.313769678915705, 64.15190173733619, 60.09510409447455, 57.31528505202263, 49.14494091464628, 45.01073921880415, 47.01800430974653, 47.76023833982406, 45.54970425944175, 48.25825775823286, 44.81549539873677, 47.1077795182505, 44.334899148633404, 45.122562070046705, 43.70184821467246, 44.79991574441233, 44.10943346638834, 44.96983674264724, 42.534805805452415, 44.99315915569183, 43.05908941453503, 45.36092450541835, 44.207618236541755, 44.48348245313091, 42.465513213988274, 46.68504215055897, 43.741126829578036, 45.42563184615105, 44.83115350046466, 47.10047998735982, 45.73096875221499, 46.32201110163043, 46.70467753564158, 46.606379016753166, 44.54983718933598, 45.91857179518669, 42.85385531763877, 44.865638979019664, 41.08707858670143, 44.726865522323116, 48.6530403937063, 52.32524964117235, 55.71553461013302, 58.87626678712907, 56.77246039913547, 60.849246440395234, 56.21387958526612, 61.55091924052085, 52.26197004318238, 65.66389699136057, 32.01714865622982, 22.362132495449437, 60.159379974488296, 52.18413845185311, 61.54590645144063, 53.66504499989172, 59.818722125022646, 55.811275743669086, 55.95002566614459, 52.720502961066465, 51.98407011647379, 51.18108249479725, 55.980875107549856, 53.701017056742025, 56.47750600691765, 51.42347320433586, 44.31181207779915, 43.3358871552252, 43.28723799797797, 43.56758548367409, 46.022902919400124, 45.957575844180205, 44.70321755255423, 45.14745343116022, 42.531487480286636, 44.46432951957949, 45.25191791595952, 44.381265486440356, 43.21656865458335, 44.1086450699837, 45.7418768636642, 44.372118519198516, 44.16915547463202, 44.70792439676101, 45.59953797248102, 44.474594362320445, 44.24593979312528, 45.42837750527167, 45.637710478998, 44.56226718041205, 43.45830825067336, 46.06639808224094, 45.89583773766795, 46.90352993626749, 48.13968450792375, 45.66041315755537, 45.92351398160381, 47.056753404678844, 46.57984418253745, 48.489030407321074, 48.297642277133086, 48.18820422695529, 45.82098322529947, 48.90623331069947, 47.33308438331851, 55.122668358587454, 61.95270722912204, 61.90267347520398, 61.33473388610348, 63.38588637690391, 65.9644054597424, 56.50937134219755, 13.992719246495156, 0.31270290274293194, 1.2368651335277867, 0.07197089613445344, 0.07697723475435088, 9.030580712902932, 68.23857999617054, 49.08053951878702, 42.96501136595204, 33.65688570084111, 32.04566624856765, 44.46833033715525, 58.21159370483891, 62.092704465312345, 53.33871949103571, 2.97959320006832, 0.18535488134910985, 0.07771188243021888, 0.025743710538071972, 0.047279143060046824, 0.04247889358309969, 0.06683193237310456, 0.07077579131169666, 0.04205749542903035, 0.04439911211750681, 0.03249045919566866, 0.043985999204338565, 0.10859025897638452, 0.16617617659991787, 0.224128368520929, 0.20347217127921122, 0.16981582968465744, 0.12209645802936248, 0.12273898363233575, 0.13355633664515712, 0.22935586140280773, 0.3610366462699829, 0.45177053720239674, 15.742006128834142, 91.06562122221916, 73.75740189706126, 76.34458157324022, 52.13856443282097, 27.740388416474868, 39.61051802481375, 52.17798425305275, 57.54268446276265, 80.53836407199984, 38.41575230321577, 0.22101045195614138, 0.35303093553070103, 1.4566658100774212, 13.584817263387865, 6.074754624597489, 35.82994153422695, 77.61876352371709, 68.53335395936044, 73.31624507904053, 65.63687186087331, 66.67940647371354, 63.01879175247685, 68.10788662202897, 61.462383500991336, 69.61180963823873, 64.6985036326993, 66.76988770884853, 62.84672129538752, 60.17649327555011, 50.49746828694498, 48.96872843465498, 47.15877425286078, 49.96830917173817, 46.68438319237002, 50.26691921295659, 46.65816607013826, 49.7001249559464, 46.65385146294871, 48.63642523365636, 46.290608606030865, 46.38747938217656, 47.923824710230676, 48.014266721663944, 45.98053739916894, 47.698084462073545, 45.12515083436043, 47.04042457765149, 46.201912049324285, 47.988559507554584, 45.048805821326475, 48.74609862604449, 46.0924739991465, 47.196970293598795, 46.663771137114495, 49.3418360525562, 48.6847056881074, 48.09999796652025, 47.85576766537082, 51.81493751464352, 46.73837461779195, 48.70936170701058, 45.04526784343105, 46.19520479632963, 45.88838915671072, 46.43393985686764, 50.21132353813418, 55.60118575249949, 57.101056960321245, 61.62796635781566, 59.569251537323005, 64.11334091617216, 59.22576173659294, 65.00897099894863, 57.11140809520599, 67.27967816014444, 34.508079251935406, 25.4175490333188, 63.19782441662204, 53.982145094102435, 65.4195176401446, 55.92173753246185, 61.47200507502402, 57.05888755859868, 58.41972251092234, 56.187893882874526, 52.64448742712698, 53.463121383420884, 57.57487535476685, 56.983625119732274, 57.581468859026515, 55.10896359720538, 46.59553758559689, 45.17612987949003, 46.24796851988762, 45.65525524077877, 49.20300376030707, 49.257242295049856, 46.89530472601614, 47.84641673488002, 44.830961304326216, 48.92964201588785, 48.07962125347507, 46.298253305496715, 44.39940252611714, 47.846216694001235, 48.308750429461085, 48.94476275290213, 45.73368695474441, 47.10935631105977, 48.90715506768996, 46.3258550243993, 47.393190783839074, 50.09811609022079, 47.50997543334962, 46.792593540683875, 46.19103139446628, 48.95441178352603, 49.21434333247524, 49.30107085935531, 50.65338642366471, 48.58477154085713, 49.40244451645882, 49.28374182793402, 48.89298746662755, 52.180274917233376, 51.90760350996449, 52.22970070377473, 49.21945025843959, 52.943054322273504, 50.216732486601806, 58.36860618283672, 65.25640979889901, 64.61738509516563, 63.08128295406219, 66.61875094136884, 67.33108474362281, 58.54665825443884, 15.576296775571763, 5.329114016025297, 4.40771984477197, 0.2845455555906219, 0.2548115688466257, 10.456481902830063, 75.06948178814304, 55.720229687229285, 68.437012703188, 54.85334665544572, 38.809009136692175, 53.0574071022772, 67.01982898096885, 68.63919519609021, 63.85458215590447, 3.7841269710371574, 0.3443202093964623, 0.28554888562329356, 0.15635273839917876, 0.19911227297158013, 0.21094797900126827, 0.23662802763283255, 0.16687478749982773, 0.1057790074076864, 0.25393205394427626, 0.09141663615141185, 0.20639904083744173], [0.038351851530493274, 0.02676552052669708, 0.0379277988817663, 0.035108924738221595, 0.10027833523288851, 0.03903917412483885, 0.058432961889212175, 0.01417436178833727, 0.006884273888933803, 0.04952652710339716, 0.037755000089565595, 17.398714288588494, 72.29271827205535, 54.71216486346338, 47.39382228543682, 23.891068466248054, 28.20463230532985, 44.16893582190237, 42.26615090523997, 49.77200238935409, 72.22162139031195, 13.331568452619738, 0.11290756279542563, 0.053356434293692155, 0.8106503395303604, 1.311577705125655, 2.7295793640998105, 51.86281396496681, 68.83645903679633, 64.22281034531133, 65.51751805889991, 63.77477369000835, 63.16526482182165, 64.87697932028001, 62.07229637330579, 63.552112502436486, 63.638702746360536, 61.48498812029439, 60.62976629503312, 60.21630533279912, 57.38676240367275, 54.52760950211556, 47.59834251096172, 44.37366393304641, 44.591029920885646, 44.95017782334359, 45.60659039405085, 42.096398568922474, 42.82428456890968, 44.38756873530727, 44.59557987028553, 42.2082410320159, 41.63237041042697, 42.60324332021898, 43.643091109491166, 41.466791475972826, 42.9355739778088, 41.617673289391306, 41.158167623704486, 42.219839480615434, 42.52767885884931, 40.96599501948203, 42.018653269737, 42.324829563017815, 42.03296992086595, 43.20321298414662, 42.81047782590313, 41.3465198393791, 42.64334563286074, 41.85629460119432, 42.14505557091006, 41.250625733406316, 38.982711299773186, 41.12741231918335, 42.97852000882549, 42.23976119872063, 43.76364907910747, 47.16473233315253, 51.63288070309547, 52.50578849546371, 58.955769308151744, 56.9660529013603, 57.45312106224799, 53.7121291314402, 56.429841364583666, 51.567969399113814, 61.74295848415744, 38.90734687928231, 27.648736353843447, 63.076242708390765, 51.33276447173088, 55.65019184543241, 50.47323588402041, 54.882517322417236, 48.740744590759284, 50.992887173929525, 46.76833760353827, 52.02938525907455, 50.597633854035415, 53.67771817791847, 52.34668539416406, 57.050960448480424, 50.014420555483916, 43.09892892837525, 41.06142628577448, 44.34196333731375, 42.908391952514656, 44.66621783471877, 43.20602140118999, 43.192610817570845, 41.04778820468534, 41.96056688985517, 42.251693048784816, 43.20916714206819, 41.37383130288894, 42.817491023771225, 42.15127645000335, 44.31276129138085, 40.15370745812693, 40.90771644346176, 41.1120758518096, 43.81050963555613, 43.74202897471767, 42.98517627100791, 42.515268479624105, 42.06026961726528, 41.492820324436316, 41.455224406334665, 43.57047627049108, 44.95703020403462, 44.93223690217541, 43.27864016256025, 43.252819199715894, 44.319794101099816, 42.88528134745937, 44.49299812316895, 41.809755679099794, 41.45804851285873, 41.293630599975586, 44.21423135265228, 44.94333720976307, 46.40330222345168, 50.751402531900716, 60.51515463859805, 59.25609342513546, 64.2043791278716, 63.43049549287366, 65.49713742348456, 63.18668488533267, 25.54936812769982, 0.6110039653797305, 0.9615327045321466, 0.20517518473488672, 0.08760295087291349, 1.453977883342774, 53.42032440247075, 53.039944710270056, 43.52469828820998, 42.31536488379202, 17.81277733464395, 37.22266927842171, 47.22182635338076, 56.9704734125445, 53.80630131690733, 6.8720959944109765, 0.3165045068148644, 0.06377782710196991, 0.04391041313928943, 0.05481459455744875, 0.016146281681534265, 0.04234478989195439, 0.09976580708978638, 0.08722420466402847, 0.03447337053535927, 0.06965746382071127, 0.03549086936419049, 0.06205892115230523, 0.010314333936079376, 0.01106489038530497, 0.05653342772876063, 0.033482347705191186, 0.06323153746404475, 0.11884354911143742, 0.03467389787997931, 0.0413762977076394, 0.05470369183909028, 0.153749801458851, 22.470082006146832, 80.41311494765743, 62.54553817933606, 54.606080439782914, 33.64936651722078, 33.36058201328401, 35.299276228873964, 42.13620278143114, 55.75449159068447, 78.67807019141414, 14.612051690778426, 0.08970393934437344, 0.12595279142260551, 2.912877605807397, 3.714045738020251, 3.350092196656812, 55.0821541970776, 70.85574226994669, 67.42367621391051, 66.50963844791536, 67.20625923525903, 67.0682780973373, 66.39083770013625, 64.31877897631738, 66.30815413690382, 64.39486119054979, 63.80186157841837, 62.50731860437701, 62.50177629532353, 59.49488732122607, 55.27323638239215, 49.37068116280341, 46.48661336591167, 46.8793563688955, 47.105280968450735, 47.233448336201334, 45.3841959276507, 44.86671763081705, 45.94992329997402, 44.93353128433228, 44.17386624120897, 44.20066387422624, 44.073645760936124, 46.882270689933534, 44.089849072117964, 44.8238225906126, 43.57661870218093, 43.624106837857155, 44.40709821639523, 43.585240071819676, 42.555986604382916, 44.414413436766594, 43.538473652255156, 43.41810395640712, 44.05503803683866, 43.58015275770619, 43.58119610817202, 45.31190272300474, 44.815256134156265, 44.061913951750725, 43.371286546030355, 42.75269739089474, 41.98103381741432, 45.28948245509979, 44.21804781882994, 46.410625288563395, 48.585301060830396, 53.89515869079098, 54.12987724427254, 59.85327820624075, 57.82026667748728, 59.57079302880072, 56.43559548162646, 59.51365194013042, 53.677306329050374, 63.31907664575885, 42.64436152673537, 29.87014324434342, 64.32709440108269, 53.97692834177325, 57.14846664859403, 52.37218080028411, 57.80778961796915, 52.3388877222615, 52.48898113927534, 48.65180876947219, 54.96838977259975, 53.10529531971101, 56.02383682804724, 56.48263646710304, 58.149883054917865, 53.306155973865145, 44.56461668014527, 41.682302182720555, 45.16443337163618, 45.198636439538774, 45.743406588031405, 44.437496585230676, 45.786764467916186, 43.84005292769402, 44.85371497369582, 44.12898255932716, 45.96997445629489, 44.32095904504099, 45.39434702165666, 44.005345529125584, 45.208885592799035, 43.900371136203894, 43.29262341222456, 43.019034170335345, 46.96205954397879, 45.84010477988951, 46.48501696125154, 44.88579996170537, 44.77218066492389, 43.76440217418056, 44.44916955886349, 45.53391671949818, 47.20712530997492, 47.6255912165488, 45.7132710179975, 46.02773527945242, 46.081091280906435, 45.18092693821077, 47.044115527983635, 45.229905574552475, 44.80649748156148, 43.91146752142137, 46.887134428947206, 46.87994080205118, 48.185148700591064, 52.98924023105253, 61.193591317822865, 62.480340542331824, 65.67624461266303, 66.87587799564486, 65.49233644239365, 65.13248643567486, 29.76206429543034, 1.010986805683182, 1.5448118866451326, 0.4538626620365728, 0.09092833170847547, 1.6985374184385424, 58.16916934905514, 61.06467085499918, 45.77840981944915, 40.26408295477591, 30.576016902923588, 42.24544079073014, 57.00721425394858, 62.13472873933854, 64.40846789267756, 10.108011672573706, 0.44832350926533826, 0.06885206026415672, 0.06908878909363862, 0.03043635338995486, 0.037336842487415964, 0.05782158542124014, 0.04260404553684977, 0.013529760087089194, 0.05805651011366037, 0.06917590095150856, 0.03649098565801978, 0.15750715629227702, 0.11122687314186366, 0.09254476956782803, 0.13710404385722455, 0.17444212740707785, 0.14959153749289053, 0.1764452941114864, 0.1646235002385032, 0.14518403448164463, 0.20867153341251038, 0.2398721495222661, 27.650823054775117, 91.62335872650148, 70.89828429683563, 64.84778904145764, 34.97461772734119, 38.9950079302634, 58.57095341528616, 56.841192091664965, 62.85712734345467, 86.37026956004482, 19.08069133758545, 0.24370772193276116, 0.1506280697762005, 2.7897951006889348, 9.898733612029783, 4.8896320500681485, 58.06930580446797, 72.962478668459, 69.3673518396193, 70.16086301495953, 68.97815858164142, 68.76782540352114, 70.3746400340911, 66.29128010042253, 67.04678350879301, 68.02976085293677, 66.96054627818447, 65.11664790491905, 65.7114008165175, 61.87369108200074, 58.74919768302672, 52.73639248263452, 49.68330583264751, 49.034926276053156, 49.196524004782404, 50.23311230444139, 46.816272889414144, 46.93536781495618, 49.40877914428712, 49.15849270359163, 46.737201829110425, 46.87393173094719, 46.841478040141446, 50.35661597405711, 46.318633940912065, 47.14102552783105, 46.21046281629994, 45.64983060283046, 46.701347443365286, 46.50982987496161, 45.110634142352694, 45.61438806595341, 46.84083084906302, 46.45310455752958, 48.127387877433534, 46.37190365022229, 44.88362304625973, 47.16577960598854, 46.0747488083378, 45.30070827853295, 44.84188118288594, 43.957653430200395, 47.007904206552816, 48.85434035331973, 45.993838156423266, 47.466033120309156, 51.85303157375705, 56.58711664138302, 57.270566109688055, 62.39388365899364, 60.82527291390204, 61.74601008815151, 58.70226260154479, 62.49200959359447, 55.291640143240656, 66.71320161511822, 44.57798019532235, 32.875779021170835, 66.52795591662007, 55.7276939576672, 59.78748044660015, 54.36893393916469, 58.663850830447295, 54.80538783534881, 55.033669779377604, 51.46116718169182, 58.76100401724539, 56.114714222569624, 58.73287670073971, 58.83314424945463, 61.06545532903364, 56.153275043733665, 45.44709113336379, 44.97980348525509, 47.81596345286216, 47.216260510106245, 49.22450227122153, 47.09236068110312, 48.39507002984324, 44.93812437980406, 46.99480741254745, 46.785337155865086, 48.678488731384284, 46.6900392501585, 48.32541658032326, 47.09208219282089, 48.697104300222094, 45.62710046768189, 46.705007014736054, 44.631269516483435, 49.19539436217278, 48.935141178869436, 47.89876860956992, 48.09804854854461, 47.553619646256976, 46.295189934392134, 46.224912828014745, 47.84468304726386, 50.190370236673665, 50.51780969865861, 47.95668632753434, 47.97995774976669, 48.66369747346448, 46.85176249473326, 49.72737758390365, 48.26358433692686, 47.90736644498764, 46.17312577462966, 50.658944422198886, 50.20901326210269, 52.200475123620805, 55.9447814572242, 65.71497017337431, 64.27193018697923, 70.92504270615117, 71.06077240359399, 69.6530023697884, 66.15189475397911, 30.76541050787895, 2.6704015847175353, 3.4510868547424196, 0.6720526540471662, 0.2637599048114592, 1.7746206132634994, 65.75091085126324, 66.28090935368692, 59.01450680148218, 54.55275581729028, 30.234223527293054, 48.672142336445475, 66.00242891619283, 69.74517806883782, 76.4078180251583, 13.09531331062317, 0.7467961143101416, 0.2745814483252264, 0.2970452913113179, 0.12294902961941497, 0.11839816091401924, 0.19349713960001547, 0.21609684061859885, 0.09406415940893274, 0.14283176151014146, 0.18026962035125305, 0.1762204473057101], [0.03586722920919138, 0.04372375964697811, 0.08681730472392614, 0.01773367140201792, 0.05897459754299733, 0.07382404750152942, 0.09830516853159475, 0.026113508840001402, 0.07340263019526198, 0.058922970877780076, 0.06843699382678156, 24.722824711953443, 70.94688246327063, 52.9698754895118, 42.042340463207616, 15.367020676212928, 27.537505780496907, 34.90566638208205, 47.16088056564332, 58.159763505381925, 60.52108918466876, 4.006480987994902, 0.16817802563309672, 0.050608515213694305, 2.316276277265241, 3.54175097038669, 7.033824141948455, 62.49203705018567, 63.73112947710099, 71.15571729598507, 64.95847440535023, 67.95830311313753, 63.779582515839614, 63.847133574947236, 64.46035692768713, 60.41336521025627, 60.31809476114089, 63.78305381344211, 60.749461343211514, 59.70407124488585, 54.57823553392964, 53.65210117832307, 48.247137838794345, 42.42638364914925, 43.369682296629875, 44.16598619953279, 43.614853966620664, 44.47922668149395, 43.75434521705874, 43.02468630575365, 42.25343065877115, 43.26409209159113, 42.34325293571719, 42.186781744803156, 40.552796856049575, 42.09312338982859, 40.99904491055397, 41.48621897543631, 41.96141019944222, 40.9207740137654, 41.967517329800515, 40.43466683356993, 43.32308846135294, 41.952486807300204, 42.14587926864624, 44.47877560892413, 41.779141579904866, 43.62249474371634, 44.072414136702015, 42.76957142737604, 43.163926524500695, 42.18884491151379, 39.62369326622256, 39.77783064688406, 43.3074382043654, 46.65269436374788, 46.17296495745259, 49.73499090440812, 50.9288348690156, 52.513499875222486, 58.32115334849204, 56.61436142459993, 55.71094935940158, 52.79840907742901, 60.503430674152995, 53.43231901045769, 58.86404075930196, 46.2666037005763, 36.3588809967041, 58.681662313399784, 51.4006567770435, 56.70837671526017, 49.246993141789595, 53.36359516266854, 50.387814506407715, 51.57384118726177, 50.29173604903683, 53.30089999783424, 53.759154427436094, 54.44509852317072, 51.54012841563071, 54.539808073351466, 50.412133201476074, 42.67489325615668, 41.88629681064237, 41.766966542889996, 44.292341432263775, 44.39209515048612, 42.53584915591825, 42.80079349394768, 41.94805845137566, 42.594068896385934, 42.80636718196254, 42.73403867598503, 40.56229683660692, 42.301467926271506, 41.711951378853094, 41.95876652194608, 41.500990621505245, 42.18296135625532, 42.831540953728464, 44.922674163695305, 44.07384972418509, 43.368219252555605, 42.08747909915063, 43.12272987058086, 43.364834247096894, 42.45086708376485, 42.52285434353737, 42.65123744164744, 43.58794650723858, 44.67060696694159, 42.89259264546056, 42.680388496768096, 42.74175005574381, 42.68745660781861, 43.57997232867826, 44.00858540688792, 42.98512528019567, 43.69010856074672, 44.803955785689816, 45.494010525365034, 43.89210277988065, 53.63728638618223, 57.866448663896136, 61.5121191547763, 62.27646750788536, 64.73979834587344, 66.47515296936035, 47.85854470345282, 3.062896497787968, 0.6992161093700318, 0.15916325452346958, 0.02153851794108989, 0.8719095491593885, 38.6981237319208, 58.425453093744096, 49.16341135578771, 38.10945833882978, 12.769516341147884, 27.28910403866922, 45.983910637517134, 52.70177364349366, 58.25349246301959, 15.027934716593835, 0.11929952464396916, 0.057253787864840804, 0.07160004829206774, 0.024208184970062108, 0.038304009339621956, 0.059986722265039726, 0.052501801927123344, 0.045559605087844596, 0.02240024428183754, 0.006833210777145841, 0.053183214153133096, 0.06945045920269144, 0.011074715462933865, 0.009785979374071524, 0.021466371610820777, 0.049213200972806063, 0.07223968574356648, 0.046506033939940315, 0.037376093002216476, 0.07469931061589911, 0.05631930998436386, 0.0679205586352656, 30.86392083475667, 80.90407017738589, 58.46038964486892, 49.95991137719924, 21.380512291385283, 29.563139330956247, 32.782758051349276, 51.241302644052816, 63.581208644374726, 67.32639358889672, 3.894588514681786, 0.1466223032724473, 0.13451857372157036, 3.879627123955758, 2.4900662033788623, 8.977984670669802, 64.7254071697112, 64.41620672902754, 74.56421775202598, 66.9171021061559, 70.17607396648776, 65.21995136814733, 67.34405994415283, 65.86797791142618, 64.43306899839833, 63.13823969133439, 65.45772544799313, 62.894076070477894, 62.64704127465526, 56.470010357518355, 55.92446357973161, 51.163784842337336, 45.40676916799238, 44.912919229076756, 46.791973806196644, 47.36240802272674, 48.36469127285866, 45.22152739186441, 44.940160089923495, 44.151853899801935, 44.689085252823375, 45.146574820241625, 45.89786560304704, 43.550636922159505, 46.26048088073731, 43.74172302984422, 45.80243825912476, 43.44932210060858, 44.45750851784983, 44.92555318340179, 42.96037904677853, 45.61439983306393, 43.06386686140492, 43.60820947154876, 45.21747558347641, 45.48161583562052, 45.453449295413115, 46.569030207972375, 45.42821276572443, 46.04372678264495, 43.74732025208012, 40.76827618383592, 42.87354953827397, 45.292730177602465, 49.03774253783688, 49.32530326227988, 51.88075096376481, 53.09636800519882, 54.20984260497555, 58.127831489809104, 57.51532200844058, 57.302584417404674, 56.622190475463874, 61.966870907814275, 56.171243421493045, 60.06917722763554, 48.883585545324514, 37.236248523958274, 60.18682872095416, 54.2056848925929, 59.07333843169674, 52.519775667498195, 55.475897404455374, 51.40096664428712, 52.95532349617251, 53.79133747469995, 55.45401057889385, 56.41092377324259, 55.82003831863404, 55.22342228120374, 55.80581580438922, 52.96913023917906, 45.932994350310295, 43.81660892117409, 45.094073895485174, 44.907141577812936, 47.119880030232096, 45.71584801520071, 45.50143557210123, 42.461214296279415, 45.02963719829437, 43.9075255393982, 43.60792706089635, 43.16910405312815, 45.05226927418863, 43.20508395471881, 44.987867878329375, 42.09221732231879, 45.183515702524495, 45.044455912805375, 47.40796242990802, 46.583146818222545, 45.8836038651005, 43.975339397307366, 44.85711174626505, 45.9719003400495, 43.795628163122366, 45.03711715821297, 43.88021407588836, 45.383352618063654, 46.72891386093632, 44.272961001242365, 43.78641843795777, 46.03421111260691, 46.07623930900328, 45.09186560107816, 46.632584371874415, 44.172767977560724, 46.04257360581429, 46.55569022701633, 48.465766829829064, 47.820870337947724, 55.11754182077224, 61.585742042910674, 64.74525436278313, 63.14411932422269, 69.1217565536499, 67.18948718040221, 51.7093002411627, 4.429910654021848, 1.0616220918393906, 0.608503454394879, 0.06297934898025086, 0.5461657155425318, 40.062151493564734, 65.3722099334963, 52.52667903900147, 38.84753465652466, 20.032597626409224, 34.90286188740885, 52.213968077013575, 57.71668472597676, 67.60179104343538, 23.723330267014045, 0.14358865637933055, 0.12782674207682573, 0.038478114311733556, 0.037563684952235034, 0.050476173524774855, 0.024110525996694644, 0.05177373494652491, 0.08385140298595352, 0.025587890169493137, 0.038813691466085376, 0.05854029080740387, 0.21138719253001675, 0.14076409020250844, 0.1688330614518735, 0.1751062030633611, 0.13116667858294903, 0.19715583763055264, 0.14527530619694343, 0.10897120385761223, 0.14392774221637558, 0.16774952201352966, 0.18328693424982412, 38.41312823757049, 90.15665900322699, 65.60858764956075, 59.344385977714296, 23.634494466166345, 37.96160067281416, 47.004126964076875, 60.22074545583418, 72.7210646290933, 72.6881088749055, 6.094324800275988, 0.3085105631860995, 0.2393233088115531, 7.042644081577179, 10.028267925785435, 10.0886586981435, 65.6530987062762, 67.54963920962426, 76.70856183575046, 68.00178650886782, 72.88273688285582, 66.63542885934153, 68.94734444156771, 66.94218174103769, 67.57529151055121, 68.44077817855343, 70.16986093213482, 65.06864593875024, 65.23903762140583, 58.514522275617054, 59.090177166846495, 54.72275526292863, 47.9109279571041, 48.5984919917199, 47.527096579151774, 49.85319545192104, 48.21143642548592, 47.72370146166894, 47.44896688768941, 46.5116027862795, 47.65617785915252, 45.66922280096239, 47.85593240491806, 44.55230828254454, 49.690522993764574, 46.00507574696695, 47.34980936973326, 46.83926190099409, 47.083833448348514, 47.33112319823235, 45.120259638755556, 49.46600652510121, 44.56626407561764, 46.79005968955256, 47.75579037204866, 48.85973361230666, 48.547634540065644, 49.2418626816042, 47.587073541456654, 47.41371654695081, 46.41257862890921, 42.84486524520382, 45.26582664059055, 46.06175399595692, 51.497719749327636, 51.6677309620765, 54.38055984435543, 56.26437617886452, 57.73891279774328, 62.17479182827858, 59.6483108305162, 60.437946704126176, 60.00945521939186, 64.64284127758395, 58.59309911727906, 62.790027356916866, 50.74740563669513, 40.72732663923695, 61.21043789771296, 56.325282742900235, 61.459983010445875, 54.92971128033054, 57.53946027448101, 54.93979177167339, 55.69889983823223, 56.80287053508144, 58.28238856407904, 59.521594739729366, 57.5149925293461, 57.57253369977398, 58.49070956630092, 55.68298286007297, 48.184579956916075, 46.96300875756049, 46.59470996549053, 49.18037952915315, 49.41385076891992, 46.62133109185004, 47.24226190197853, 46.319061479260846, 48.20547050045383, 46.10053054748043, 46.81943824214321, 47.22705487282046, 45.96376926668229, 45.40457264069588, 48.913285732269294, 44.49109577363537, 47.56229985144831, 47.89994924299179, 49.83882780997984, 47.954556480530776, 48.02269589516425, 47.72865541519658, 47.29364102886569, 47.86553436709989, 46.65938984963202, 49.30202791767736, 47.2009789559149, 46.79158941391976, 49.49032129779939, 47.18432457216325, 46.88850333613735, 48.29193130616219, 48.829245028957246, 48.36066299869169, 49.502147243868926, 47.79641043755316, 48.37314005820982, 49.90557478320215, 50.86977181896087, 50.570859755239184, 59.656524273657034, 65.18121011795537, 66.21710808046403, 67.1784496307373, 71.4718524871334, 71.13980031782582, 54.56855904671454, 4.54604713186141, 2.1111868177690813, 1.5501362590059158, 0.17745706643308365, 1.108451882197011, 47.51544321736982, 71.14764505817045, 63.583240432123986, 48.11167486252324, 19.0454194238109, 41.07866902505198, 63.47280217755226, 67.65686896539503, 76.25493972532212, 29.931610707313787, 0.3464661442464398, 0.19958285013994864, 0.22233892502563618, 0.13509942158575983, 0.2114204713894475, 0.21757097764601632, 0.0989188739068566, 0.23845263456384982, 0.1319601311678848, 0.07496889695645341, 0.0931560617661284], [0.028382192042866544, 0.02340279098960661, 0.03133583062839124, 0.05148845912528135, 0.03252815455198288, 0.03896784750864871, 0.03707770175570923, 0.04881811027805652, 0.014030346834671595, 0.034051574015569304, 0.12994476834372168, 30.44010873763792, 61.32718724589194, 52.25785547687162, 43.85905288880871, 22.92441406557637, 36.96620118233466, 45.07052790734076, 40.99622864877024, 63.90069746202039, 49.235422149781265, 0.7223430780633804, 0.1309513159456753, 0.5385531304824738, 4.471974151749765, 1.403091871930707, 21.824322592827585, 74.15307491056382, 67.31681516093593, 68.80599791003813, 64.68748961725544, 68.98724279096051, 63.99088451939245, 63.483831882476814, 59.827065006379165, 59.67291193623697, 59.41696159301266, 58.82361681230607, 54.062334029905266, 52.62889600569203, 49.63492731894217, 51.77093636605048, 46.300269403765284, 44.906059003645375, 43.75677708656558, 43.68504478085426, 42.319459838251916, 43.381433717666134, 45.16899508814658, 45.52578564613096, 43.552900129748934, 43.40665455787413, 41.8454727818889, 41.428516987831365, 40.84220893921391, 42.19938432016681, 41.15316660173478, 41.12261526046261, 39.657668836655155, 41.10435662731048, 38.64335567720475, 42.373851345431426, 42.09077781246555, 43.25618067095357, 40.93201552667926, 42.759832182238185, 41.679195665544086, 44.74009567691434, 43.68613912213234, 44.3638736970963, 41.572177717762614, 40.900730702184866, 40.475659524240804, 43.17583876271402, 47.28905970050443, 49.53706418314288, 48.84767232402679, 54.597682645243985, 53.73969162664106, 54.351867706544944, 56.742748445080174, 54.64411958571404, 51.044427117993756, 56.30498055488833, 57.62905897632722, 53.0113467093437, 55.33463324269941, 52.569676060830396, 39.26198405604209, 58.07786833855414, 52.60699349064981, 52.69707072165705, 50.995024865673436, 54.662860670397365, 51.04543516712805, 54.0374779701233, 53.69263102931362, 55.22402632621027, 54.441203609589614, 55.88265111369472, 51.76719442490609, 56.95975749723373, 48.30320419803743, 40.88307611403927, 42.359056165141446, 43.55009171270555, 42.06820457212387, 44.95858346262286, 44.26848165450558, 42.575382724885024, 41.100406800546956, 42.983454350502264, 41.666714683655776, 41.69084902732603, 40.95028200457173, 42.33366274064587, 42.1442985534668, 40.03748762992121, 42.553597880947976, 43.44918481765255, 43.223436724755075, 44.56411461676321, 44.66134232859458, 43.20735892941875, 44.331474919472974, 42.516570706521314, 42.0097416447055, 42.622772801306944, 42.884430193131976, 41.9358245788082, 44.01811676640665, 41.81099122570407, 42.02408967479583, 42.77392525826731, 43.273764656436065, 45.094054283634314, 44.299739022408765, 45.75605623183712, 45.30099461155553, 47.217190111837084, 48.326436396568056, 48.54885047481906, 45.33530750582295, 46.66290429330642, 52.791140925499704, 63.02979007844002, 59.35892620394307, 64.88729515383321, 66.5427432521697, 59.22101959105461, 10.619558365114274, 0.42973386484288406, 0.7554896187878425, 0.08163320306207865, 0.03216099925339222, 19.298824148793376, 67.42704160751836, 45.79547997443907, 49.43968349887479, 31.414368614073727, 14.664718335674657, 41.3659159598812, 54.85256610378143, 64.00898233536752, 29.726037325397616, 0.46623158058331865, 0.06190116066605814, 0.06909844180148456, 0.010416471650974165, 0.00648527327294071, 0.03283685351151132, 0.031007448954868223, 0.027586921914330417, 0.05344417817409962, 0.01754632268491532, 0.05271703432944994, 0.04901521704009464, 0.03963153629053024, 0.06251974219095803, 0.0533483712182891, 0.02321983387152995, 0.02292279285498925, 0.02533265840142004, 0.0778594309644353, 0.05935915835922765, 0.035766484816708875, 0.02035172134187193, 41.03176140016125, 67.53976268153038, 59.682941436767585, 52.05653590540732, 22.485961721789455, 28.836614393418838, 40.92689683360439, 47.60398287926951, 68.89848739870133, 54.353330750619214, 0.6677399467556708, 0.024036004793860262, 0.42069436441506114, 4.4241129006108935, 1.5990110751121276, 23.558933927166848, 71.94563558024745, 68.6741199801045, 71.86587810516357, 66.60242603671166, 70.23731000961797, 65.22371292114258, 65.16985877867668, 63.0341439093313, 63.79375011690202, 61.371372745883086, 63.04899400280368, 56.6603708267212, 54.89912856009699, 53.342614404616825, 52.82551265531971, 48.10253181765157, 46.82592192003804, 44.736793041229255, 46.350758152623335, 43.37929602592222, 46.901149057572894, 45.195624059246434, 47.731012759670136, 45.79617423395957, 45.486004967843336, 43.41407175986998, 43.81098816471715, 44.43968526778683, 43.940822539790986, 43.84190036404518, 42.64109027001166, 41.753242169657064, 41.8779617740262, 42.35329420335832, 43.09718347364857, 45.2929380632216, 44.874146599923414, 41.55995561230568, 44.73154883230887, 43.652861733590406, 47.0568161626016, 45.63450590256722, 45.981596439115464, 43.55412783161287, 43.23246209852157, 42.97487220456524, 45.084746499215406, 51.32262906720562, 51.57502966542398, 52.617740784921956, 55.99043392365979, 55.99237941926526, 54.20861098074145, 58.00877971033896, 58.279866480058246, 52.97333109763361, 59.93444773458666, 59.31403859969109, 54.648096869068766, 57.89186562261274, 54.25603635849492, 41.33278762140582, 59.725142217451534, 53.831322116236535, 54.51232794792422, 53.838966815702385, 56.12484962709489, 53.112206535954634, 56.91181828898769, 54.7648109159162, 55.236679892386164, 55.76061441052345, 57.723631243551935, 53.72503765167729, 56.86365942801199, 50.48652095179404, 43.827991639414144, 43.980312962685865, 44.51085275219333, 44.3585471184023, 45.95231594577913, 45.714079026252996, 45.07450519069549, 43.08456520880423, 44.55910575005316, 43.91857093380344, 42.759690976911976, 41.17469256924045, 41.972647789985906, 43.52527487662531, 43.382892839370236, 44.880363556646536, 47.16968628668016, 45.24722676123343, 47.87572860717774, 47.206313379349254, 45.77144761239329, 45.32469357213667, 44.797146551070675, 44.67895769303845, 44.398896540364916, 45.03657194875902, 44.95553970336915, 44.7555027469512, 45.505510914710264, 44.04554982339182, 45.58444469205795, 44.856366495932306, 47.66309299776631, 45.54729592415595, 47.170910066173924, 48.07633430727067, 50.1237880029986, 49.22701651050199, 50.630185604095466, 47.05219953290878, 49.484127875297304, 55.05341499082504, 65.30044232645344, 61.98581595574657, 67.81471298586938, 67.53529902427428, 61.88348131795084, 12.559968617654617, 0.5308244064930947, 1.044385971561555, 0.02315187995742646, 0.01931589577467211, 21.073055344243205, 71.64197352624709, 52.140964923366425, 42.8854892330785, 26.47027200268161, 21.067716998438684, 46.00080036347913, 60.05946151671871, 68.06397176557972, 41.4700117418843, 0.16726852604939094, 0.09841697906414348, 0.028789555466163064, 0.020173048570511803, 0.004530128311260694, 0.018492230597222527, 0.02996776421974984, 0.044266329928030895, 0.045915123510865435, 0.029793620943242026, 0.07007408541657272, 0.1090539183707968, 0.11823369715843471, 0.12109865149062489, 0.2511263794956669, 0.0946610797977736, 0.10708115003522366, 0.11481534389238204, 0.1338428688505965, 0.17924203597489866, 0.13114398705863184, 0.23145011596141324, 50.403503987096975, 77.06170851184477, 67.43055605119275, 60.98449760867704, 33.70966903624996, 50.79379550872311, 59.64096423118346, 54.03283780620944, 75.13179256070045, 63.916163367609826, 1.543586023392216, 0.22888833326437782, 0.7940702356638447, 14.973300022463645, 5.993787588611727, 26.275889142867058, 76.45990710104667, 72.68846188822101, 73.2845837070096, 68.99255368017381, 74.07676127649124, 66.78713044812604, 68.8422170762093, 65.17511867707776, 65.87621488878804, 64.31768071266913, 65.12765799799274, 58.65480584482993, 57.95276041953795, 55.43186487690095, 55.77350331890968, 51.05446838563489, 47.96053025030321, 48.04844233297533, 47.48127152842861, 45.3474433191361, 49.14174810532601, 47.735221462865034, 49.933235337657315, 47.860105806781405, 48.75414340726791, 45.526817229486284, 44.45112682157948, 45.910934940461196, 46.3013009871206, 45.964530206495716, 46.65985661168253, 45.42901685160976, 45.880454201852125, 42.778765463059955, 47.16089233275383, 47.65810374290713, 47.13787978695285, 44.91124045464301, 48.76211758582823, 44.462136914653165, 47.98008326561221, 47.98702978318738, 48.564857667492284, 45.923349242056574, 44.58869218826295, 44.423109331438624, 48.08952916053034, 54.19616530018469, 53.91027550543509, 53.515249683010964, 60.83338437541839, 59.03743305513936, 56.436905553264005, 60.352976399083296, 59.323617027651885, 57.117566216376524, 60.507443258839274, 63.16641799865231, 57.19386416096842, 61.61000190242645, 57.3407922252532, 43.93972819851291, 62.8022494623738, 55.079667414388354, 57.386358399544996, 54.78102991657873, 57.97728700022544, 56.56308427933724, 57.64747450428625, 58.01204312232233, 58.831755730413626, 56.1186562045928, 60.18281221389771, 55.809424384947754, 59.25262997227331, 52.984733427724535, 44.040548801422126, 46.32639631148308, 47.68827069190241, 45.05804300308228, 47.934897561227125, 47.64061781667894, 47.92271467947191, 44.56442056163665, 47.60143726102768, 46.05011240128548, 45.34727073484852, 44.888388726019095, 44.94471788406373, 46.46784090226697, 43.353380926193736, 47.31697913139097, 48.61915111541749, 49.347190087841405, 50.04547396013814, 49.62475269071518, 48.38914332851287, 49.139775153129335, 46.70768599356375, 47.55541216942572, 47.503903604322865, 47.44483270952779, 46.183014069834066, 47.682661702556, 46.72239095933976, 48.197111929616625, 47.55951104625579, 47.851692322761785, 50.852846791667325, 48.524739665369836, 51.997806256817235, 50.401079962330485, 52.05252724309122, 53.08265932144658, 54.44497300732521, 51.369470011803415, 51.170080246463904, 59.485410874889745, 68.93791506367346, 66.32307483303931, 72.0857818665043, 71.2562790224629, 64.62596331873249, 13.782429214446777, 1.77306343230509, 2.493317112807305, 0.14465803851283368, 0.21835915954603305, 25.44837494050303, 79.68987695632443, 59.024838324516054, 62.49807357788087, 42.72361693843719, 25.877492043279833, 56.45635266457835, 71.05855234207647, 77.91276085761287, 53.85505245577905, 0.8282104843566496, 0.21540725423443705, 0.11553273926819525, 0.1240386211523606, 0.16770416960841225, 0.13026456408683332, 0.16898034951619564, 0.11936390667312569, 0.17887587659060958, 0.11222434260191456, 0.2099945979012597], [0.13703694987681606, 0.03467992316150377, 0.03140159161581147, 0.029334058204004844, 0.042371445921279734, 0.05661852094495008, 0.03503358382130823, 0.03552057825389408, 0.032053005753926216, 0.06328558879754236, 0.36366938403056515, 43.438998422315045, 67.17443312368086, 49.832312753123624, 40.49246295805901, 29.57684409233832, 47.43321857144756, 45.18833629546627, 50.242835860098566, 68.01457343562957, 28.78483126240392, 0.18241895663161434, 0.07050434337748636, 0.3599465031537318, 2.12706726885611, 1.3206242842058982, 44.624817217549975, 72.33813931865078, 65.4841818348054, 65.55063070789461, 63.53417942600866, 65.03236793702649, 63.255134167209754, 62.49982295497772, 60.0662079934151, 62.33613068057645, 57.16294803927022, 50.56461141955469, 46.81023636171895, 44.92245451096566, 45.25510680290961, 43.29472188026675, 42.96197152906849, 42.46826279547907, 43.990044363083385, 43.21747079972298, 42.63820340556484, 42.72025154482934, 43.31417683632144, 41.86865398960729, 43.91253440610824, 43.51350776610836, 42.06689842285649, 42.36038977100004, 40.51136878228957, 41.330140021539506, 41.34909683658231, 40.20953063041934, 39.36544833644744, 40.82671557703326, 39.71280167179723, 42.308567416283395, 41.294489599043324, 42.38015459429833, 43.37897831393827, 42.484066024903335, 44.66691601660944, 44.0725867209896, 45.48808382403466, 42.43829588736258, 43.58293764052853, 41.10832998829503, 42.29472144957512, 45.52100819926108, 48.22427042068974, 48.674837004753854, 52.96803197553081, 52.797326503261445, 55.28448181767618, 57.197076582139545, 58.35868258630076, 51.8836574400625, 53.54380453786543, 54.790098436417125, 54.16369984226843, 52.84493623241302, 56.85751699632215, 54.07010424521662, 43.33594599077779, 56.2833643728687, 52.53783033740137, 53.5869231531697, 54.09144193895402, 53.940520901833814, 51.00603103637696, 55.2005313288781, 53.67782015954295, 54.41830481252363, 52.072197929505386, 50.85769091883014, 53.33199262619019, 53.46722418262113, 47.466033120309156, 43.38981582272438, 41.98273220369893, 43.52823234373524, 43.31784817480272, 44.021478237644324, 46.20128447009672, 41.923512258837306, 39.30119599065473, 41.4539731702497, 40.094722855475645, 40.65501382274013, 43.25275644179314, 40.13344057144658, 40.45519651905183, 42.36229212053361, 45.558313861969985, 43.62352632707165, 46.12540229674309, 44.95917181814871, 42.122709828038374, 42.12202733562839, 41.50884320659023, 41.167016490813225, 42.04981650075605, 42.989267303097634, 43.14066294700869, 43.3043630661503, 42.56385487894858, 43.846924920235914, 45.68164494729812, 47.29941868012952, 45.874158797725556, 48.429861453271684, 49.67881471880021, 50.588898735661665, 50.95641697606733, 51.821197617438536, 52.36819174981887, 51.97332282220164, 51.53128739326231, 46.73822949009557, 47.578440404707386, 52.68137731859761, 60.036170482635505, 63.73313773062922, 63.34234414562103, 69.06276410625827, 24.632349360373713, 0.30697685516169, 0.25188459203608576, 0.12705166794119344, 0.04382805102655003, 7.552478659537531, 69.83232528932633, 49.79425007297147, 47.90040423793178, 31.406194394634618, 18.12003424090724, 34.9306518800797, 53.30047638185563, 57.792374703191946, 39.95143475071077, 0.3694281588879324, 0.04280337778430793, 0.03132539842608235, 0.015836394328113287, 0.02491037924623778, 0.05515195669666414, 0.026562262078626987, 0.05932017597520064, 0.1337845235942833, 0.06419006284446487, 0.026439889108822234, 0.03823480478698208, 0.09196657236785659, 0.06392698442082732, 0.015914121608910783, 0.043790501226941426, 0.010599721797681864, 0.03977250795991671, 0.07320565366817099, 0.024375776279597514, 0.03309700547927811, 0.659540354484512, 55.154882784812685, 72.55291261980611, 60.14804040232013, 44.005000360550426, 28.303876115429787, 38.14302598276446, 47.01801999922722, 52.94568231028896, 74.42785263061523, 32.96526593546714, 0.145391276586921, 0.09564057683512088, 0.8728238904187757, 3.8507533313766604, 1.5866532801620423, 49.635201884854226, 74.84946820043749, 67.58330883518343, 68.45291399186658, 64.79590785118842, 66.43059484420284, 64.00088656333186, 65.47378755384877, 62.35753505460678, 65.35565360899895, 58.95404346527592, 52.44002603715467, 48.51219984792894, 48.47766730093187, 48.00257805855044, 45.309043315149125, 45.41561411273095, 45.322897126597745, 44.60630755270682, 44.15971040725709, 45.757048591490715, 45.43706163283318, 44.688139961611846, 45.14075010053573, 45.977242608224195, 44.71707920874319, 43.18687631237892, 43.9702913068956, 43.90396010491156, 43.59840354611797, 42.957888341719105, 42.362001865140854, 42.12565945040795, 43.11214731585595, 41.86351568468156, 44.52313369320285, 43.841284551928126, 44.21245844133439, 45.76793709108907, 44.490840819574174, 46.671129503557765, 46.1384363328257, 46.408236565128455, 45.80811000639393, 43.65600355209843, 44.2375066972548, 43.30748527280746, 46.4279660870952, 50.88815596795852, 50.87305092042493, 55.48859411670316, 54.39887339068998, 57.1713811351407, 59.67495156872658, 59.67088407085788, 54.73684833895776, 56.635420630055094, 58.59706463352327, 55.01096317845007, 54.080918219781694, 58.526163870288485, 55.915948114087506, 43.49625718209052, 58.030988170254616, 53.84423848121397, 55.14171146577405, 57.301443007684526, 54.427812637821326, 53.78985089640464, 57.0656144234442, 54.89908933639527, 56.40391057537448, 53.316299223130756, 53.71854612904211, 54.87826939552061, 56.21484841069868, 49.110035742482836, 44.75530270607241, 44.7697566401574, 45.836347149264434, 43.7040525867093, 44.413805469389885, 46.9320063437185, 45.441042838558076, 41.51545632270075, 44.79960587716872, 43.25824776003438, 44.0361596691993, 44.76124509688347, 42.093005718723425, 44.756424503941695, 45.92138021223007, 46.07685512112033, 47.58925437927247, 46.526064565104825, 46.24121419845089, 46.72501502498504, 43.02653374210481, 44.14214995599563, 44.13885124268071, 45.61307014957551, 45.59770622561055, 44.75671475933444, 45.02000777952133, 45.21481621649958, 45.178969675494784, 46.28384251748362, 48.52953672409058, 48.12765067623508, 50.72814287677888, 51.386442107539025, 52.44976135992235, 53.878225818757095, 54.37571179482245, 55.1902586413968, 55.10974807123984, 54.10986923402356, 51.01095753331339, 49.05363990414528, 55.37706152085335, 62.45280942609234, 67.0362715567312, 65.50599805770382, 71.91449980581962, 28.238382339477543, 0.501713862101878, 1.0317928344011307, 0.1463864554440783, 0.20738418394279098, 7.7954018308270365, 73.7594650637719, 54.37152662584859, 48.678610324859626, 35.16113819614534, 24.468404093096336, 41.759439514529326, 60.5933706222042, 63.27345163591447, 53.266261546842514, 1.9292466967336594, 0.1262918312943751, 0.008682693061869471, 0.03320388240559447, 0.05270619801576099, 0.07754128997124012, 0.007295821588711754, 0.05953217931692639, 0.013088796047433732, 0.06898123800994889, 0.04931614786807088, 0.179680866459685, 0.18508126538607383, 0.21310854613059954, 0.1174492231239715, 0.1437212661990235, 0.12844646124229317, 0.11299782327466434, 0.13213682168674085, 0.08505773865768025, 0.20326290670181477, 1.5396504152205683, 68.47051758919993, 78.21860374942904, 69.87705599877143, 52.6717871235263, 38.98843011548443, 61.32533196480044, 58.33432858990085, 61.512985998584384, 80.06204712775447, 38.769840348151426, 0.48102008058659496, 0.18080323123403136, 1.288554250232635, 10.552486815760213, 5.09533683138509, 49.81178306764173, 79.44691750311083, 70.86328891015822, 70.95572348563903, 69.30283669502505, 68.625851292764, 66.49845184818392, 66.00112668929562, 63.50939004651962, 69.40444177196872, 62.39222449641075, 56.26651387060843, 51.770653955398075, 50.2406354104319, 50.4863287556556, 48.189428006449056, 45.86781632515692, 47.99794573937693, 49.03919773717081, 47.4075819600013, 47.219323881210826, 48.25371957594349, 48.102712246679495, 46.876277308310236, 47.55476497834729, 47.60754439138597, 45.24257483020906, 47.235997876813336, 46.1460300414793, 47.21876298227618, 45.9398663428522, 44.25229011043426, 43.802994374305975, 46.299947769411155, 44.035830190104825, 47.88721330704228, 45.026236503354966, 47.06760660294564, 47.79596328735352, 46.79217384707543, 48.27514356182468, 47.473434632824315, 50.28810785662744, 48.728977480242335, 48.228400676481186, 46.31852019217707, 45.61298385743172, 49.31311253578433, 53.194929322888775, 53.58585626848283, 57.96468442486179, 56.97300334130564, 58.32536205168694, 61.80941912435717, 62.3966803089265, 56.624775317407426, 58.60015546121905, 60.936511331988925, 57.93872225669123, 56.34831097818191, 61.011671789230846, 58.71800699541646, 46.044346517132176, 61.25912627866192, 56.5923333937122, 57.687812159138346, 62.16428379858694, 57.03954242890882, 53.83650748960434, 60.10776942776096, 57.95907543551538, 58.79794097715809, 54.95917612506498, 55.616381014547045, 57.66345031799809, 58.705122009400405, 52.52639270597889, 49.085936700144124, 46.92407531123008, 48.367264347691695, 46.20667772908365, 48.05025446799494, 49.81352459999823, 46.94952757127824, 44.12981410180369, 46.44301622144638, 44.58575041063371, 47.03097951027655, 47.97810246867519, 45.18431978840982, 46.52882983607631, 48.290978170210316, 49.49178434187367, 50.443637678700114, 49.88988530251288, 49.84752370465187, 48.23347230111399, 46.471237674836196, 46.686732692103234, 45.400285490097545, 48.06863077225224, 47.88430683074459, 47.54730070790937, 47.45798049434539, 47.10310013063493, 47.996117914876635, 49.76850755753056, 51.59415122001402, 49.52816824759207, 53.13369327975858, 54.79207531098397, 55.465452132686494, 56.47081444340368, 56.295311912413574, 56.6955505647967, 56.15662474786082, 57.381188715657885, 52.52905207295572, 52.88252038340415, 57.633169620267815, 65.65420089229461, 68.73985890419253, 70.66462086093041, 73.1474890247468, 30.757522621462424, 1.7100956627438146, 2.171438345986028, 0.48657458575983203, 0.3150621164710291, 10.100193408227737, 83.36138017715948, 62.11479525412283, 63.54938253279656, 42.94942386688725, 27.057994065746186, 48.03864425228488, 70.0358727670485, 70.7488969064528, 65.66094344662082, 3.5646926683764306, 0.27543689274499494, 0.12930536071860022, 0.13159266943412443, 0.19983532207627452, 0.13716589779623095, 0.10847747551217195, 0.23846876837553518, 0.21557919500816256, 0.22540007447523458, 0.21791279075607178], [0.05508571307385161, 0.04065072817367412, 0.07459745922636601, 0.013351337251914366, 0.0928177879822831, 0.047104226034735484, 0.025401527790593046, 0.024854952784916087, 0.13166198506951332, 0.36066380659899405, 4.62724607798361, 60.0156407971536, 60.98401907951602, 41.67973695262786, 47.26099906429168, 43.1419651739059, 39.17449166697841, 41.39889917066021, 48.24872639871413, 73.04246364101287, 26.44251338897213, 0.07011306397016011, 0.034814616740350766, 0.11080157943069936, 1.8086977975983776, 5.135574465797794, 72.25779348804106, 62.548193623942716, 65.40374971205189, 60.957299893902196, 62.10905682656073, 59.29433653431555, 60.051004886627204, 57.78135284300774, 57.73550818043371, 49.9950401244625, 45.49810155745476, 43.04989145648095, 42.79797723216396, 43.36676405322167, 42.38315128510998, 43.54938176370437, 40.31423830216931, 42.698678508881606, 43.99106810169835, 43.09194710946853, 41.00511281721054, 42.799840357995805, 43.30091138039866, 44.09959616199617, 42.708507968533425, 41.6504878382529, 40.64119531262306, 40.60172450157904, 41.60810662854103, 42.67985113205449, 40.7129942986273, 40.027061970003196, 41.20165886417512, 40.709523001024806, 41.25338708200763, 40.28392230310748, 41.7057736458317, 41.67198242679719, 42.56591412328905, 41.08360728909893, 44.329870670072495, 44.59749398692962, 43.66564081561181, 43.60400469072404, 42.99648054184453, 39.71457850548529, 42.69039446307767, 44.485471094808275, 45.383246714069, 49.19372735484954, 55.198201440995746, 56.06791250167355, 54.32192041027931, 55.118353751397905, 53.10751145885837, 52.8902356855331, 56.695770217526345, 53.27017607227449, 51.78000880825905, 51.774988174438484, 55.423231740151685, 54.557705848447746, 42.96503882254324, 56.56923063339726, 54.44884046431511, 52.68195390701295, 51.394714386232444, 52.72029507544733, 53.268928758559696, 52.78124870792512, 52.08483188383041, 51.41837804548202, 52.052197763996745, 50.39892658110588, 53.76596758442541, 53.26140173019902, 45.73400466672836, 40.3487826162769, 42.62399265843053, 43.596489429473884, 43.071468414798865, 43.74488053783294, 43.511036672899806, 41.25539925790603, 42.88768968274517, 40.00155087440245, 40.26584802135345, 41.698364288576194, 40.810951571310724, 41.7518771848371, 44.25012888446931, 46.52753937628962, 45.22865041609734, 45.224484858974336, 44.94367061122772, 44.19936949206937, 41.98740766894433, 40.797384092884684, 42.74722568450436, 41.869356093868134, 40.655578644044944, 44.67427830542288, 43.39771547625142, 42.191064973031324, 44.9534490800673, 50.598316346445394, 51.73141064182405, 51.479127714710856, 52.34741495501611, 53.5297820644994, 54.106213585022964, 54.970041090442294, 54.52105914392779, 54.80098693601547, 57.97907952339419, 57.554996782733554, 57.553604341322384, 52.686990230314194, 53.32034318677841, 51.41725624761274, 58.885225480602635, 61.96662379849342, 64.33201305327877, 67.04065676658385, 37.30634127893756, 0.7196313106725294, 0.38183982514085313, 0.10332803932889816, 0.07309662403478738, 2.445084707390878, 55.98267547545895, 59.8153567314148, 45.82282673928046, 34.77666747185492, 17.8446348251835, 28.772997471594042, 49.38902216572916, 54.098882675170906, 48.503543176958644, 4.174271158633694, 0.20990386244750794, 0.0065476055380948375, 0.035824289981035456, 0.04095602953325837, 0.07308599839527762, 0.03605616947395667, 0.031139712119775436, 0.06661018822342157, 0.01917408332378874, 0.03767755626130008, 0.016703606816008687, 0.03525466913537633, 0.05951763130724431, 0.01986040617339313, 0.06889542084067099, 0.09345866649621919, 0.10193118525128211, 0.10836273086287322, 0.07340290598691472, 0.39851663994692993, 7.436418177620058, 69.35914624121882, 67.21925012526974, 48.1196568858239, 53.27013684857277, 57.82434594246649, 39.80440078243133, 43.16368333755001, 51.693908860606534, 79.52825961574432, 27.601916982281594, 0.027687250704113996, 0.10129890990473571, 1.09670058373482, 4.21057318487475, 6.382025749452653, 74.48256969451904, 65.00273050800448, 69.8777541806621, 61.84623449079452, 64.56694341474964, 61.02265442571333, 63.03010779042398, 60.82708897129182, 59.03869605833485, 52.767763599272705, 47.49044987463182, 44.65809068372173, 46.431504064990634, 44.9067924868676, 44.36115549456689, 45.922709895718484, 42.860382141605506, 46.04776682392244, 44.66348002033849, 43.636815317215465, 44.296259880065925, 44.90403113826629, 44.95908944837509, 45.87368419093471, 43.80764238296017, 44.53618341876615, 42.66412635003367, 43.082415749949796, 43.91103998307259, 44.00515333298714, 42.92079056462934, 43.01729656034901, 42.63729341568486, 43.52803622522662, 42.984933084057225, 42.418464383771344, 44.34392452239991, 43.85924900731733, 45.26881156429168, 43.886250603583555, 45.127214001071074, 45.36014395375406, 45.868969501987586, 44.58982967561291, 45.19561229213592, 43.36729749556511, 44.91162092454972, 46.98085161947435, 48.941130638122566, 52.20960640138196, 55.90160400636735, 57.416093887821326, 56.642943736045595, 56.76407829407723, 56.31842251746886, 54.68051918091313, 58.71251959954539, 56.47650972489388, 53.06888787977157, 53.8865412435224, 56.925036676468395, 57.91438787214218, 45.01448115994854, 58.989407554749526, 55.54660989392189, 54.17576505291847, 54.454822078827895, 54.90124663999004, 54.54034936043524, 54.076889945614724, 53.634285773000414, 55.51348547781668, 53.52358471962714, 52.063090185965265, 56.193651922287486, 53.1287746275625, 47.61107452454106, 41.41169786453247, 43.929373141258, 46.141652676366995, 44.25640467674502, 46.01835297000024, 46.740963382105676, 44.1020711775749, 44.68809681553995, 41.86145251797092, 43.1059068249118, 43.82645799267677, 42.9763509381202, 44.41773960667272, 46.2920638053648, 49.15602553275324, 46.77515468289776, 47.12948199241392, 47.9738780759996, 47.15258867509904, 43.743750895223315, 43.72270737924884, 43.47858298209406, 44.43860661598944, 43.848027106254335, 47.44921791938044, 45.51388517502816, 44.21549043347759, 45.69752270175565, 52.01553536999611, 54.306191705888324, 54.04862926852319, 55.584197967283195, 55.56724156102827, 57.228957606900124, 57.606677932123986, 56.47797276896816, 56.418325285757746, 59.16825978986679, 59.0759232736403, 59.603129048501295, 56.56143688386487, 55.72981203756025, 53.76286891198928, 60.005152379312825, 64.05198327956661, 66.95298394849225, 68.39174855139949, 41.47935482763475, 1.0842884884726618, 1.3493198540902909, 0.06763801008703248, 0.03273620871045897, 2.545151479782597, 59.46418300751717, 64.02074944588446, 47.79149570772725, 27.764422739705733, 20.748641990846206, 33.637124799912975, 54.8478514148343, 59.202227515559045, 58.297662273530044, 8.951492001933437, 0.17065935377632419, 0.048445894968725985, 0.09065969531694729, 0.009865748279187228, 0.0685751501230463, 0.024126950921791217, 0.032938210774333246, 0.03682448288365718, 0.033616868914255214, 0.022859707429644563, 0.10571113201759516, 0.1268407256312428, 0.18656707759345734, 0.11537992004905978, 0.15760307050039693, 0.18733506541579, 0.21755564056577223, 0.22721813901537852, 0.3810671488604238, 0.7199884302193119, 10.108506871807961, 81.35060064254269, 73.51128101348877, 60.00373640368062, 56.00473488530805, 55.35537473617062, 48.431234282831994, 53.25789905363514, 59.370257931370894, 84.8728733678018, 32.211341281091016, 0.28228078518183003, 0.15440538886093325, 1.7460552170392007, 9.579288921048565, 7.124267133974261, 79.55304115049302, 66.56575187560051, 73.21033323964765, 67.03531449840915, 68.7007293393535, 65.35101736745527, 66.08606169300695, 62.881096947577696, 64.55996944058326, 55.26813730116814, 49.59606055290469, 47.730424404144294, 47.92626050210769, 47.929833781334665, 47.72358379056377, 49.30389104350921, 45.151995535819765, 48.02408833657542, 48.082692469319994, 46.96671539737333, 46.32737690402616, 47.46447986172092, 47.05183867485293, 48.44249540759672, 46.39798348949802, 47.337120502225815, 46.37981507085985, 45.696024356349824, 46.32301130602437, 46.71693886480024, 46.77678638888944, 46.85046026783605, 45.698373856083045, 46.013042080786924, 45.92240787321522, 45.921815595319195, 47.317100724866314, 47.289373490118216, 47.0808446022772, 45.28521099398213, 48.02513168704126, 47.31922272712954, 48.44901046445293, 47.299716780262614, 47.92485237121583, 45.21796587974795, 47.20894528973488, 48.36706038444273, 50.75836473895658, 53.17587837096184, 59.3745215477482, 60.67781532964399, 58.277728788314334, 59.15071502808602, 57.25412353392571, 57.157766588272594, 62.78267683521394, 58.561998644182765, 56.918980536922334, 57.7669067536631, 59.68853081426313, 60.6468992079458, 48.568933010101325, 61.7413071663149, 58.065355977704456, 57.79548906510877, 56.84123916010703, 57.67916333290839, 57.08687366977815, 56.87861150310886, 56.287357345704116, 56.90611124038697, 58.5495255070348, 55.094748927700905, 59.09961831185126, 55.65077627858808, 50.14210547170332, 44.19693762256254, 47.7459099215846, 47.510638313908736, 45.72457136646394, 48.825357960116484, 48.08381818955945, 45.52834303148332, 47.35865039210166, 44.02981327426049, 45.04571107126052, 46.78980081312118, 46.08195812471452, 47.851425601590066, 49.744435971783055, 52.292258585653, 50.34316224436606, 50.59374286282448, 50.857518334542554, 48.50651633354926, 46.05793752977925, 45.857222003321496, 47.96659031221944, 46.67083924816501, 46.02790001899966, 49.18585515791371, 48.80908796864171, 45.92904844591695, 49.99000772353142, 57.174346446990974, 57.046571316257605, 56.57875414817565, 57.505076777550485, 59.206040059366536, 59.99760181673112, 61.55834820962722, 57.872371442856334, 59.43501626291583, 63.17498837747882, 61.825061536604366, 62.30802297592164, 59.27310866694297, 60.26904944450625, 57.77750107549853, 63.28004121780396, 67.82254203673332, 70.38296330359675, 72.42233691676971, 43.24295443873252, 1.7145964599424794, 3.5484349343084522, 0.5900259039575054, 0.2002265325356876, 3.697311926272608, 67.5799826652773, 70.68745690007364, 60.36935621692289, 44.15865528968073, 26.841471387493996, 41.376765235777825, 65.19496979251986, 67.50028010337584, 68.41123488641554, 13.506824854881534, 0.42309761287704595, 0.14085831901719495, 0.2370104280811164, 0.15100018932454048, 0.21630674870985173, 0.11662033897253776, 0.14450901908980263, 0.15034075616107834, 0.1449869813457612, 0.10413999293720531], [0.012524948631893965, 0.04707227250741375, 0.047097607035069704, 0.046878341179821766, 0.02717732917517424, 0.03789072022623113, 0.022009786503810077, 0.013749145643575298, 0.017356608671346502, 0.153112048583646, 9.548902319323632, 65.4345638521256, 49.20584355631183, 47.091305563526774, 20.065665168146936, 14.547248251976507, 46.83439031724007, 53.3233908684023, 56.15549510525119, 67.21830875642839, 19.793405609746134, 0.2067141328006983, 0.05064857012081531, 1.413513364330415, 2.567700940755106, 16.60220250006645, 77.44406115624213, 61.934707472401286, 65.1974840318003, 54.3603321813768, 53.59558766888034, 50.68902900142055, 53.9383126074268, 49.07291835354221, 48.36405977126091, 45.06778617059031, 46.20454003733974, 43.64591521601523, 42.576437842461374, 43.124290973909446, 41.81728662983064, 42.325131585521085, 40.789217718185924, 41.9366325870637, 42.96292466502036, 40.50685021185106, 41.92245714126095, 43.966906301436886, 43.9806620536312, 44.598360830737704, 45.55718421936036, 42.88433605624784, 42.73189313950078, 40.20540821936823, 41.864002058582926, 40.82126740486392, 40.91740469778738, 41.97303218226279, 43.38837239050096, 40.770158921518636, 41.572158105911754, 41.06376401839718, 41.612809550377634, 42.425571718523585, 43.63808224278112, 41.453247531767815, 43.61136697953747, 43.709594895762784, 43.79319629361553, 43.93868877041725, 43.1423338767021, 41.30464069304928, 42.021948060681744, 45.70823861706642, 42.75647463337068, 45.798888514118815, 53.62335412733017, 55.58225247167773, 58.16765531416863, 53.832267407448064, 54.42117598748977, 56.082978325505415, 53.816774045267415, 51.30966563378611, 46.04134198158018, 52.45622542596633, 55.02966896180184, 55.12127199480611, 40.84016538435414, 54.173870548125244, 53.390765420852176, 52.5575480922576, 52.64793911287862, 53.574383335728804, 54.52513056416666, 52.80689316411173, 52.752984108463416, 50.583156385729396, 52.635336537514966, 51.333172398228804, 52.6607221172702, 51.1598507050545, 43.64392657433787, 41.34667673418599, 43.58091761988979, 44.02802859583209, 44.61181848279892, 44.809282364383826, 42.436719094553304, 42.41460869389196, 41.02895690548805, 40.168243761985536, 42.13878370100453, 40.9425078668902, 42.4076464868361, 42.547396613705544, 46.436320735562234, 46.811950437484256, 46.9134456880631, 45.13354078415902, 43.76466105061193, 40.484857482294885, 41.217666056848344, 42.16224339700515, 42.573123439665764, 42.16481254946801, 43.70375448657621, 42.01617825415827, 40.96214325197282, 45.91465726975472, 53.229924709566184, 55.3482791685289, 55.670937261273785, 57.1673999294158, 57.45110104160925, 56.68490132977886, 57.66457603823755, 56.24965944597798, 57.00168371200562, 60.14966818594164, 58.747801319245376, 56.73187955733269, 56.18426569046513, 56.20599169884959, 56.008119890766764, 55.7002491335715, 55.20206889798565, 60.55343304910968, 62.532449230071045, 68.84018528846003, 50.79182647889661, 3.25652307560367, 1.028612282487654, 0.23414695995949933, 0.10218849120241019, 0.5995331163848601, 40.58244997455228, 66.34434976885396, 47.95070079065139, 63.659883545291045, 27.630134513301236, 27.26104340245647, 47.616773728401434, 53.92178373952066, 62.18284053187217, 15.847282544259103, 0.18664944736707598, 0.0167152954025134, 0.06912984374550081, 0.05567942738472935, 0.029323468953671477, 0.0286815160014216, 0.05568788499541341, 0.01984562067645452, 0.07626715551821456, 0.021060320113094586, 0.052021001315405296, 0.0034792493557512403, 0.07875631308002819, 0.002907546905560359, 0.04965032308152126, 0.040286346113369356, 0.005885385251003168, 0.07705937470159224, 0.06903207560460414, 0.13046420659990082, 15.55891969511586, 74.28062254382719, 56.650682572395574, 52.59518323406097, 26.176755159131943, 19.68445393346971, 41.85843621530841, 52.1181720302951, 60.42321428175896, 75.12045691090246, 23.209152644680394, 0.14059717496556623, 0.06835137584036396, 4.245262136382442, 1.3725520526209187, 19.452135870533606, 79.67379523861794, 62.75006624960131, 68.58048515935099, 58.14022617955362, 56.19674667235344, 51.768673158461056, 57.42992416504891, 51.27003008319486, 51.37452594695553, 46.93115126702094, 46.981855746238466, 46.76160289395241, 46.537204096394206, 44.84689397196616, 44.5220079729634, 42.932518451444565, 44.099121555205315, 43.09954081812213, 45.474379062652595, 43.66450332826184, 45.60963807567474, 45.684861290839414, 46.3686284711284, 45.79415421332083, 47.63781724437591, 45.51917253002044, 43.861170968701764, 42.95977107940182, 42.182808383818596, 43.26209168280325, 44.3149225173458, 44.65349366587978, 45.140867771640906, 41.404468936304895, 42.04618046360631, 41.49549145852366, 44.820802365579915, 43.66886500389346, 43.65627027327015, 44.88536850098641, 43.89153011383549, 45.587570821085286, 46.26974551908432, 47.04319377099314, 44.656996342443655, 43.67579583198794, 45.459960429899155, 46.689297922195934, 45.2854149572311, 48.927727899243756, 54.00121958025041, 59.40802251138995, 59.470807890738214, 57.28356876680928, 55.63656553145378, 57.93119915070073, 56.30544339456866, 52.39823318296864, 48.52903073833835, 55.18279437095889, 55.354237248820645, 57.83034716883014, 40.401240394961455, 55.66071164223456, 54.69168224642354, 54.77809990606001, 54.20861490311162, 55.03186156672817, 57.07010161492133, 55.69395372944494, 54.74250831911641, 53.72933656938615, 54.887792910299, 52.845316702319735, 56.18697997062437, 53.66509991307413, 45.26618357627623, 42.03224820475425, 44.51129990239298, 45.56238920457902, 46.959553149438676, 46.363847101888354, 45.07495626326531, 44.606170269750784, 43.393604832310835, 42.998394658488614, 43.878229356581166, 42.24946906489711, 45.41676336719144, 44.90392131190146, 48.822757428692235, 48.730620953344534, 47.72095188017815, 47.42437754907916, 46.654408439513176, 44.22164070990778, 44.34735267393051, 44.627237319946296, 44.44971084594727, 44.85775501497331, 44.56196123553861, 44.36805102132982, 42.44829793130198, 48.642744172003965, 55.37695953922888, 57.10934100612518, 58.17748869619062, 59.0791670737728, 58.954447469403675, 61.07378644327964, 59.43911906211608, 58.90959908885341, 59.80516249133695, 60.83845992242137, 61.5692602434466, 59.970906165338334, 59.406857567448775, 59.311869528985795, 57.76942491531373, 59.057299860062145, 57.53045451256537, 62.75810710845455, 65.01916916139665, 69.98755701126592, 55.388805097149266, 4.330994852127568, 1.3549344818438254, 0.3874969860959438, 0.15360709460031602, 0.5016763237935882, 44.44398418549569, 71.74690477309689, 50.665420255353375, 53.09214753489341, 32.849106903999086, 35.971699914624615, 55.25315776948006, 58.05945281059512, 72.95306498004545, 23.078520067276497, 0.20724791222281996, 0.06721487674381464, 0.12112157284131936, 0.03747969490265654, 0.024533561663702134, 0.08434837188331351, 0.08341546831352097, 0.05015782568784011, 0.05348079717688022, 0.06224113133465571, 0.14045210855622448, 0.16655874558754508, 0.1485252809981185, 0.18798646997780571, 0.11339698572673144, 0.12445814622145508, 0.10806257761414013, 0.12215637376592045, 0.24778632807635495, 0.24954040895306298, 20.648233236805087, 85.21419802019673, 62.89119312840124, 66.47852620770855, 29.489134011730073, 21.69594341708768, 55.891237182001916, 65.7534800037261, 66.24088548844861, 81.39536273094916, 27.471458950350364, 0.57263650480778, 0.13672616332769394, 7.030487675820628, 9.634158957389094, 19.968211920030658, 85.63141269068565, 66.54142533579181, 71.75499270039221, 61.33767174136255, 59.440570339079834, 54.81312667169879, 60.556186552970644, 53.94244678558842, 53.560262803108465, 48.32989984943021, 50.43345912810295, 49.84620578827397, 49.313045855491396, 47.431661390489154, 46.54085582302463, 46.12598672989876, 46.934595108032234, 45.02194150801628, 49.69981508870279, 45.615831498176824, 46.3590225865764, 48.224427315496634, 48.07629900593912, 48.77994475826141, 51.501324407515995, 46.19566763600996, 46.78489785040579, 45.469299593279445, 45.783077439954205, 45.8443566291563, 46.223575299785985, 48.047857899819654, 48.79575191005584, 43.862253542869325, 45.55371292175786, 44.057493440566525, 46.06062827571746, 46.818014421770656, 48.093333859597486, 47.8517040898723, 48.393367721188454, 48.32212963411885, 48.94302122054562, 48.54015065777687, 48.64992603178948, 46.52109884446668, 47.6610690547574, 48.74268224162441, 46.58399797254994, 50.8797424839389, 55.76392096857871, 60.44672104620165, 61.503305588999105, 58.23003276701897, 57.973901994766734, 60.62170582432901, 58.92273902893067, 55.087135607196444, 50.609954018746656, 58.63832404536586, 60.158222875287464, 60.309653820530066, 44.93057381722235, 59.26565616361557, 56.987578868865974, 56.96899467898954, 56.53530997614707, 58.839525945724986, 59.88304115110829, 56.821776359312004, 58.02461431872461, 56.008241484242106, 59.02238292078818, 54.22579488446636, 56.42149456085698, 57.22911057933685, 48.45614917816655, 43.60975880776682, 47.14974887909428, 47.32551813125611, 49.9517842262022, 49.7340024671247, 45.47386130978985, 46.9866959510311, 44.2942790831289, 44.68095417945616, 44.57945500650714, 44.63955356228737, 48.83847828834288, 45.389946122323316, 51.984234856021025, 53.11184175552861, 52.27064632600354, 50.871815373820645, 48.75612420420493, 46.66319847106934, 46.77286009634695, 47.61236498432775, 47.239618224482385, 45.761680910664225, 47.66857254889704, 47.22443080717518, 44.26425333945982, 51.82687328707788, 57.91607841368645, 60.16855832069152, 60.146224344930346, 63.519894153841086, 60.92127292386947, 62.35069051865609, 61.330725223787375, 61.27851455442367, 61.78369622076712, 64.99517210068242, 63.99557959648871, 62.15788641283589, 63.69415721585674, 61.72745335486628, 61.02367424195813, 61.93648430608935, 57.58562657140917, 66.75928946464293, 67.59651937792378, 72.68115059021981, 58.84431515970538, 5.372009546526018, 2.5840564889292565, 0.8744253206156916, 0.25811181433739205, 0.7334838350934367, 51.633410223068736, 77.3285081309657, 63.86342317827287, 80.92211308017855, 40.15619031844601, 39.868998296799205, 64.00413820820471, 67.8404829579015, 83.90227502392185, 30.964637494856316, 0.5868405103683472, 0.19445675665572767, 0.23608910009985973, 0.15674253925681114, 0.08235639006259941, 0.16455692719788323, 0.20991294825028992, 0.14731207351771095, 0.23983844165359777, 0.12392180040478708], [0.013635948491883616, 0.01632793836535946, 0.018658678520530946, 0.0227297980698847, 0.043506148541646625, 0.013581189484665952, 0.004566661607954772, 0.06537222078130131, 0.0043261933117924685, 0.07377127170442574, 16.267959687017626, 63.461274331615826, 49.95768347094136, 48.77551640233686, 26.60586637835349, 34.93049106290264, 44.425874602410104, 51.198890055379565, 53.09656804607761, 67.56363422639909, 11.942933701699781, 0.01208604058070529, 0.015551202776541394, 0.6495450521188398, 2.3699676413689894, 27.60890272355849, 80.25609462491929, 59.09961831185126, 66.68936929395123, 52.45141660013507, 51.405324397548554, 45.547174330680605, 48.31197461774273, 44.10740560100925, 45.81294628881639, 42.67572479863321, 43.04235266100976, 40.55990811317198, 42.90527366822766, 43.465309681430945, 47.29961872100831, 46.263010809498454, 48.09332209248697, 45.006503059018044, 44.75285514708489, 39.998969954829064, 41.856231843271566, 41.03003555728544, 43.447733540688795, 41.671158729061005, 43.01753974729969, 41.0901145012148, 42.06379975042036, 40.009042601431574, 39.544633973029356, 42.0718837553455, 43.29247436215801, 41.402880376385106, 41.69986655635219, 41.88458665724724, 40.32185946741412, 39.190726357121626, 41.195441907452, 43.634481506962935, 40.92878741602744, 42.08272910887196, 42.38607737325853, 42.848156113778394, 43.603302586463194, 43.960967832996005, 43.07169983463903, 41.31671374843967, 43.148060537153675, 43.13686609268189, 44.263492399646395, 43.35510676906955, 47.330287733385646, 52.565169257502404, 56.31730071959957, 53.9585873388475, 55.24204177241172, 53.849847470560384, 49.02190792945124, 45.12472329601165, 45.212772661639804, 52.314216013877626, 54.17421963907058, 55.95533655535791, 42.02449367892358, 55.203445649916134, 54.310733810547866, 50.34523325581705, 51.5531938306747, 53.22744184924711, 52.80375526797388, 52.256863117218025, 53.9844592925041, 53.67319176273962, 51.87592252608269, 54.05951384575137, 54.7122040871651, 49.11924154527726, 42.45059644022296, 43.229908635539395, 43.32654406947475, 43.52468652109946, 43.6046048133604, 42.916523025881865, 43.25388216203259, 42.87446345052412, 42.93024347674462, 41.06800802292363, 41.82876740732501, 40.924425740395826, 42.686864329922585, 43.89598200398107, 45.079521902145885, 44.52466341757005, 44.426639464593705, 43.11464978802589, 41.01842141920521, 39.8392588861527, 42.630723445646225, 41.37912650262156, 42.46116722783735, 41.06722354888916, 41.66460444850307, 42.610362422081735, 45.437014564391106, 52.28448837034164, 55.97721553617909, 56.224069902973795, 57.1421516326166, 58.37691768523186, 56.797889124962595, 59.02972559775076, 61.68012995873729, 57.47334480285645, 60.45664072036744, 57.39319116838517, 60.74326007596908, 60.34121321093652, 59.99972774136452, 60.82899524319557, 62.84396779152655, 61.628386051424094, 62.02220378383514, 60.87915451295915, 64.5873789633474, 65.13648725325062, 58.6379357307188, 7.129464274452579, 0.7743725829547452, 0.2863328387179683, 0.030512222907535975, 0.1580748887312028, 27.175959348678592, 72.58404054949361, 49.44630445972566, 36.11770229954874, 17.12962008291675, 24.750355828192927, 42.26625680923462, 53.0141237474257, 61.676646894024266, 28.628948427015736, 0.2927113787060784, 0.004008944811029059, 0.023733243015744997, 0.016559565049265663, 0.019196981691845486, 0.005566730500093752, 0.024837485980242494, 0.019338330659534664, 0.021474990099968932, 0.05755476082765287, 0.05371415904993492, 0.05868579005642284, 0.030008859091228055, 0.021318899685396783, 0.024678390585787358, 0.07115836029932385, 0.01937956534205906, 0.03252436624719732, 0.0917170345482807, 0.04248180854765158, 23.15458659202822, 74.02510366132184, 54.955210608820764, 57.38344015613679, 28.900547066042503, 37.07514109150056, 49.3343404031569, 53.04032518017677, 59.44645781670848, 73.30144205401021, 15.229896576173845, 0.2785353813200228, 0.02653719568174453, 2.3689845973445527, 1.8201426608908562, 29.46475059755387, 80.38976115565147, 60.908874311754786, 68.60277206667008, 55.855669129279356, 53.93834790875835, 49.35923176427042, 49.419624497813565, 45.39316638823479, 47.57441997528077, 45.34371314510223, 46.82512175652289, 42.75358776892386, 43.389325526452836, 44.79520497783538, 48.37001785155266, 47.88939022248792, 50.61900684910436, 47.24983599878127, 46.468213527433335, 41.22709151237242, 44.3594531859121, 43.83527548082414, 45.11485461265811, 42.80803811165595, 44.65006943671934, 42.389725177518784, 45.21959366336946, 42.83338054533928, 42.74151079116329, 42.812552759724284, 44.48767546684512, 43.48439593468943, 43.00738080855339, 44.49728135139712, 42.69903152219711, 41.33037928612002, 43.55001718767228, 44.88045769353067, 43.649833663817375, 43.92954572554558, 45.30450121048958, 44.85213425851638, 46.6793704032898, 45.709199597758634, 44.61525055669969, 43.16012182543355, 45.52833910911314, 45.47427315865794, 44.938751959031634, 45.99074340635731, 50.50712516230922, 54.151677777690274, 57.04798336951964, 57.586944487787065, 57.83626210304999, 55.09575305446502, 49.0512982491524, 46.808569354395715, 46.560612801582586, 53.88989487001973, 56.64582667812225, 59.117598456721154, 44.945580805501635, 55.3639921834392, 57.203638707437825, 53.85214205711119, 54.71016837704567, 54.930938982194476, 55.99764716240668, 55.17427106057444, 56.90404415130616, 56.29818700974988, 54.37657079389019, 56.2550134812632, 56.36537328843148, 51.321832826060636, 43.23487435617755, 44.454347087490945, 46.16350420059697, 45.89574360078382, 44.87246390311949, 44.2616488856654, 44.89175411962694, 44.72683414336174, 45.84061468801191, 42.64090591861356, 44.374707283512244, 42.02174409743279, 44.41903006645941, 44.74455541180026, 47.70338358417634, 48.11037263562603, 46.35634753011888, 45.34558019330425, 43.701173567002826, 43.0005794186746, 43.980273738984145, 44.335256084319084, 46.290875327202585, 43.953982091719105, 44.31734261974212, 44.01678316054806, 47.01173636221117, 54.976297270867136, 58.687063417127064, 58.51014491050475, 59.77687828002438, 58.028846556140536, 58.97588322239538, 59.87333720730197, 63.37503710100728, 61.430298512981786, 62.810855142531864, 60.81050911257344, 62.73820107983005, 62.50997404898367, 63.418991181158255, 62.92448620642386, 64.19147060763451, 62.22997173186272, 64.55458794870685, 62.94476486021473, 70.48201099518808, 65.77165234473445, 62.924937278993674, 9.42290892524104, 1.3235647135203885, 0.9431332337760157, 0.09935414974367428, 0.19559516331120846, 28.630221236136656, 76.570768971597, 55.29049481115034, 40.668538155094275, 22.138761358876383, 33.82308436978248, 48.82176506903864, 58.27016253625193, 67.4806054945915, 38.76179556692801, 0.4833850859393997, 0.09655021431465304, 0.04322391025902283, 0.021517149833661896, 0.008761791640051432, 0.052836467436845266, 0.08021338932937191, 0.024477541484239123, 0.027808512846428542, 0.053739792351881345, 0.21801121773258333, 0.08588901300343775, 0.11473115082950362, 0.15491704366380168, 0.12365638924342011, 0.21042754483078757, 0.0758291830519034, 0.2541874216929559, 0.14198007092120188, 0.13853584686594625, 28.44372037918337, 83.75207178054318, 64.70239070154005, 67.30311039955386, 36.021278673602694, 49.45610646278628, 56.71529577624414, 65.35574382351291, 63.93361007013629, 80.3914007063835, 16.586038412586337, 0.5163984192955879, 0.1435963785456073, 4.9106907652270415, 5.506201184565022, 32.611230842528805, 84.18073977193525, 65.02164809934555, 72.35885727790095, 58.60567031368133, 56.331699740502145, 51.555880654242735, 52.343955424524125, 47.319379621936434, 49.60958096288866, 47.64432445649178, 49.416808236029844, 45.468977958925315, 47.08499839228969, 46.86065058554373, 52.55681460903537, 51.52369368460871, 53.20285643300703, 49.45416881192116, 49.167070927158484, 42.51759444513629, 47.95114794085103, 45.19347852276218, 47.00560569763184, 45.81195785153297, 47.175938544734834, 45.088406070586174, 46.518863093468454, 43.79284328030002, 44.97564577287243, 47.04816733637164, 48.45783579734064, 46.87193524452948, 45.73249063184185, 49.15702181477701, 44.549013491599794, 43.18904930545438, 45.54917866183866, 47.054596101084066, 46.13234881431826, 46.30746695303148, 47.257751341789, 46.41781891545942, 48.1303963353557, 47.43028463855867, 46.411409762597856, 46.119310855865486, 48.455976593878965, 47.93545061542142, 47.500781397665705, 47.91600350410708, 51.97322084057716, 58.269456509620916, 58.99764845448156, 59.09178926098732, 59.50945108167587, 58.56804693898847, 52.41681737284507, 49.050133305211226, 48.326738419071326, 57.40836681858186, 57.880377000378026, 59.785844818238296, 48.999217018004394, 58.72579290020851, 59.26147491701188, 55.8475302111718, 55.698958673784816, 56.95780807925809, 58.46985432409472, 55.38502000993299, 59.177175337268466, 59.064536633030066, 56.0395537653277, 59.99856671979351, 58.336674167263894, 54.37102456246653, 44.967228366482644, 46.89736004798643, 48.79415158302554, 47.29244470596314, 45.85131491384199, 46.1158787819647, 46.70645829169981, 47.553984426683, 49.18588653687508, 44.65595691434799, 47.63567563026182, 44.73311385800762, 46.55996561050416, 48.474643153529016, 50.445810671775575, 51.58532196475614, 48.09803285906392, 48.15431887103666, 46.21766821030648, 44.03490843311433, 47.34942889982655, 46.933689040522424, 48.29342572919784, 45.199044366036695, 46.17061938008955, 46.46119248482489, 49.37264234788957, 57.762317580561486, 61.208637529803866, 61.50749860271331, 61.88264585310414, 60.46126911717077, 60.36058579721759, 61.7771105612478, 63.90367846335135, 65.85453202647548, 66.32681677418371, 60.88326907926991, 65.98128734096404, 65.59976231667304, 66.14818419179609, 66.72969125932264, 70.07353536544308, 66.34023912491338, 69.40177456025155, 66.0133566394929, 72.51402624191778, 68.63818322458576, 67.03928393702354, 10.131897926330566, 2.991528727354542, 0.9053262431294689, 0.21741034433005318, 0.32054123859251704, 33.624855626013975, 84.41952582328551, 61.662957822122884, 50.3496184656697, 25.776136036842104, 38.284600011764034, 57.73423341012771, 68.71068431485084, 77.1172571182251, 49.42134249594904, 0.9381167061867254, 0.15627617557202617, 0.15152416282123135, 0.09282962404071324, 0.15722926555862352, 0.11025545833211754, 0.19737804909386944, 0.09267659031695898, 0.11997699917804812, 0.16012768261134624], [0.011852714139217091, 0.05164944867212927, 0.07146873316096683, 0.029080117294084162, 0.02606780786487845, 0.03965038205346754, 0.03646016594082598, 0.04506471611919903, 0.04104106146241388, 0.058219085462511554, 28.04376413745265, 61.89916687626993, 50.73659166213005, 32.70179248625232, 20.873443964988958, 25.439994796629875, 27.956189378615353, 51.203973447122884, 60.32972066633163, 66.62138677412464, 11.758479341383904, 0.19476599570724273, 0.43760305871405913, 2.8347854220098068, 0.8784300605616263, 44.97009169670844, 72.50190611808532, 62.28433186008085, 65.3619647026062, 51.919288250707815, 50.23337902561311, 49.07165927271689, 48.72443929795296, 44.245594624550115, 44.32818012852823, 44.653540734321844, 47.10474360373713, 52.46745517176967, 52.35586766273745, 53.67980095647997, 55.15598104846094, 54.99736432106265, 56.79071510991743, 56.70643906439505, 58.008399240432254, 50.80965757369996, 43.803351309991655, 41.713661532248224, 40.52950974433653, 41.78107530839982, 41.34649238278789, 40.59431122195336, 42.93559751202984, 40.48657155806019, 41.32069887653474, 40.19557091497606, 41.843644957388605, 41.38819502245995, 40.64669055323447, 43.734960863667155, 41.6403720455785, 39.61360100776919, 39.08990183184224, 39.24905984632431, 42.372251018401116, 42.50359942836147, 43.96502748612435, 43.517547807385846, 41.36263685841715, 43.752858638763435, 44.233847125884026, 42.217211492599986, 42.7952786414854, 44.06434582125756, 43.17447377789406, 43.44954175333823, 43.51419025851835, 42.140733118980165, 45.566111533872544, 48.097240540289114, 45.124699761790616, 44.852640244268606, 44.2799545872596, 42.376204767534816, 49.7056515755192, 53.65265815488754, 54.734977368385564, 55.999012147226644, 42.8893292334772, 52.24152272747409, 52.899802346383375, 51.51393482761999, 51.71272447032314, 50.565952870153616, 51.78610024913665, 50.950686393245576, 56.6922636185923, 52.31339231614144, 54.9049650469134, 54.0099625433645, 54.67395313324467, 46.619781755631976, 42.29137174544796, 43.14808014900454, 43.437621670384566, 43.754639394821666, 44.34474429776592, 43.650527923337876, 43.84495196803924, 42.58664384964974, 42.81300775466427, 39.50012291631391, 43.32367289450861, 43.73116008697018, 41.16467483582036, 42.0261489191363, 45.69492609270158, 46.380532864601385, 43.62490700137231, 42.01292660928542, 42.85559684999528, 41.73943150428034, 42.63725419198313, 43.239020301449685, 43.299562085059385, 41.35883608172017, 43.320421249635764, 42.64716602140858, 50.14811062043714, 56.20778814438851, 55.71223981918828, 56.05500790380663, 56.09049750912575, 53.462223160651426, 57.89567816642023, 55.057325593886844, 60.35327449921639, 57.74234094927388, 57.81167276443974, 59.0071915811108, 60.940276807354344, 59.32416615947601, 63.11629795259046, 59.71054315567017, 64.3144565243875, 62.68694354641823, 65.35887387491042, 63.762433913446245, 62.80699945265248, 66.92952033012145, 61.756357300666075, 9.462280696438206, 0.8393807204500322, 0.40782528238431104, 0.8431400058250275, 0.06943872273569146, 15.450276905490508, 68.82717086422828, 53.903736914357836, 44.16457022390058, 28.85916998309474, 18.03684861429276, 28.517741387890233, 48.68427030501827, 57.85389315697455, 44.19464303601173, 2.7743845985781763, 0.05683491780092159, 0.04945947525782451, 0.02145807679382063, 0.05173853703684384, 0.03875410514733484, 0.07450417269982638, 0.06836239218471513, 0.04718848421508747, 0.03418770783971395, 0.04381080638737448, 0.03181831854876251, 0.016547811345287388, 0.06828632731471332, 0.05246192322022492, 0.08631451355834162, 0.02602337285005037, 0.039472308745908166, 0.0347432135153682, 0.19965535270110255, 36.69542427985899, 70.26800647858651, 57.23625321542063, 42.70314608850787, 27.05832354484066, 31.813022628907238, 31.60285811270437, 57.93994995855517, 64.49675260051605, 72.17431760603382, 12.940589535620905, 0.2625649302236496, 0.3916881918426483, 3.3125754614030165, 2.586497428917116, 49.1259527206421, 73.94156502139184, 64.30993010920864, 67.17596284804806, 54.6629548072815, 52.43478575060445, 50.58722780596826, 49.091031858997965, 45.65426680349535, 46.191286348527484, 46.7327852402964, 50.3003966423773, 53.675239239969564, 55.06431917990408, 55.593560664884514, 57.77754422157042, 57.1961901264806, 58.234088497777144, 59.50599155118389, 59.77079860625729, 53.01503373730568, 44.331027769273334, 43.80386121811406, 43.90980051409814, 44.40110091240176, 43.466431479300226, 43.10712275966522, 44.62547225336875, 41.80421337004631, 43.55279422575428, 41.88327266323952, 43.82181782876292, 43.081395933705, 43.03116606127831, 43.97311541341966, 43.80727368016397, 42.23375604998681, 42.7621110793083, 42.65656794271162, 45.11083810560165, 44.285532197644635, 45.75610722264936, 45.176937887745524, 44.08451072631344, 46.54065185977567, 46.505687852059644, 44.633034583060976, 44.2997625566298, 46.96020426288728, 44.79167876705047, 44.81563660406297, 44.51074292582851, 43.57219426862655, 49.034353610008, 49.91536109678207, 47.84405939040646, 46.76746683736002, 46.02102410408759, 46.08869283430038, 51.586330013890425, 54.89146424878029, 56.92183210003761, 57.85255955111597, 46.07073622365152, 53.00007381746846, 54.71364359701834, 55.94141606361636, 52.7817193923458, 52.99779099802817, 55.282391194374334, 52.77166243522398, 59.28290282526324, 54.98345167406144, 56.96445257433, 54.86864389911775, 56.552588016756125, 49.628745663550596, 43.03129157712383, 44.66260533179007, 44.42297204848259, 46.01195166187902, 47.384467432575846, 45.600659770350305, 46.746701809667776, 44.14535845479658, 43.5593092826105, 41.80058517763692, 44.40160297578381, 43.96033633139826, 43.287261532199004, 45.014932232518355, 48.37418340867566, 49.54980011909239, 45.867706498792096, 43.6231654690158, 42.88301421749977, 43.802045160724276, 45.57857290390999, 44.50625573435138, 45.44898956052719, 42.022889429523104, 44.53383391903293, 43.979257845109515, 50.997558716804754, 58.21797540110927, 59.35004988024312, 57.67384459895473, 56.90195745037448, 55.345090281578806, 59.122085648198286, 56.81419441776892, 62.64629210195234, 60.80710841763405, 61.33008979981946, 61.08229798655356, 63.022992610931404, 61.366489395018554, 62.39980643795383, 62.14749213187926, 64.61500029410085, 65.27338189463462, 65.34335697850874, 65.63881735647878, 66.32899761199951, 68.67947009301955, 64.12216624905987, 11.734728409397988, 1.7521581798791888, 3.415526156463931, 1.4068799009246211, 0.11385260885881801, 16.98671244805859, 74.19347532333867, 58.399337953136815, 46.49765876031692, 29.449388634773996, 26.47771470008358, 36.20151942776096, 57.92350738279281, 64.38987978043096, 54.900795567420225, 4.255746631853042, 0.17122377671541708, 0.044165681296538924, 0.060011409448399666, 0.04241621993001431, 0.04632883397261462, 0.06843523948543495, 0.07532965542087633, 0.033777590330329635, 0.06271455835010256, 0.06996244342336733, 0.1616793630584594, 0.13506860952944527, 0.189197777560161, 0.11499696035659122, 0.11886426412890996, 0.12611042933478472, 0.17574725011664052, 0.12134189972834242, 0.3103166920763831, 45.19884824752808, 80.08221595518052, 67.32998647997456, 49.45452574760684, 31.785014944691813, 37.2289333035869, 37.821117062722486, 65.9042755250008, 70.76543361909928, 78.72030627342963, 15.753888949271172, 0.36185415401574106, 0.6686492011912408, 12.207880000914297, 4.440933004502328, 52.651026018204234, 75.14266537081811, 68.598080911944, 70.78615157834946, 55.54234627754458, 54.35890836100425, 54.198706996056345, 53.65915752226307, 49.06244170281195, 47.9549918636199, 50.28611137020973, 53.81585228827692, 57.511227053980676, 57.237673113423014, 57.42229123269358, 59.85447452914331, 59.92575183991463, 60.06371336598551, 60.740314375969675, 61.50508242268717, 56.14866625878119, 47.277516165087306, 45.54220468767228, 45.65410206394811, 47.502436637878425, 46.312573878995835, 45.39189554029896, 47.80619282876292, 45.04378518750591, 45.61328587993499, 45.00902906540902, 46.953336192715554, 46.97667821761101, 45.57059480297951, 47.66746644050845, 45.5548817880692, 45.35626080728347, 43.30005238133092, 44.3482038282579, 46.31988517699703, 45.472370809124364, 48.04468862472042, 48.05423567371984, 45.815472295207364, 49.738928964061124, 48.59702894764562, 46.72715271672895, 45.534230509111964, 49.63178157806397, 48.11371057264267, 46.893935818826, 48.03174480315178, 45.90702825976957, 50.49142783687961, 53.21083453393752, 51.20192596989294, 48.80151387183897, 47.984833255890884, 48.452979903067316, 54.69779722152218, 57.54819539285476, 60.126188878090154, 61.51449218873055, 50.15537092762609, 55.38968763043804, 54.83888487662039, 58.31422644276773, 55.71546008509975, 55.28428962153774, 57.81021364273564, 55.21834673420076, 62.7394836948764, 57.87483861369472, 60.09557085652506, 57.744792430631584, 59.9177658942438, 51.44419900832638, 46.34458826434228, 48.70157187984836, 47.02294257379348, 48.38135742372083, 47.65471481507825, 46.92499706822057, 49.16655709666591, 46.66306511048348, 45.368769245762984, 43.86927458547777, 45.99217114910003, 45.067080143959295, 45.22044874006703, 47.56101723640196, 52.79729904667024, 52.215450732938706, 48.73130344575452, 47.51162675119216, 45.387059257876494, 48.08958407371275, 47.62612465889224, 47.74621586645804, 48.83844298701133, 44.767991573579856, 47.14848587589879, 46.354347121331, 54.948844602031095, 61.535159157168486, 61.560709476470954, 60.33501194369409, 56.55086609625048, 57.036769313196984, 62.20810844052223, 58.45622016537575, 64.64546926559942, 61.446376308318115, 62.38539957231092, 63.7041239584646, 66.21498215583064, 63.09159094287504, 66.14690549911992, 63.85242092993952, 65.15743663234096, 67.5208725467805, 68.96945091985887, 69.67733675433745, 68.22340826834402, 71.80889391130017, 66.90469957167103, 11.571521528305547, 2.9061120075564233, 2.9239739910248788, 1.9339443478853473, 0.190885913588347, 19.955962357982514, 81.06799387162732, 65.53922445543351, 60.353317645288286, 40.82242842643492, 28.281285224422334, 44.1296140609249, 67.065289251266, 73.3516562369562, 65.18124149691674, 5.737294487414822, 0.27262724996093785, 0.16309150825104407, 0.2256522859416662, 0.12349662160681141, 0.15953506763663985, 0.1422586664557457, 0.17703343513271502, 0.1682640726287519, 0.1682978264626957], [0.10062014834294397, 0.023677215175402742, 0.03339166970803373, 0.048813011962920434, 0.04175475280311319, 0.05606664652605692, 0.026023202395487218, 0.06698768570899002, 0.05682602352012069, 0.35524155884500475, 38.92033776929302, 55.05664310147686, 53.06546365061114, 48.924660605769006, 19.06709836375329, 36.324552412955995, 46.757276519652336, 51.45862156344999, 62.632465747094926, 59.371752354406546, 7.955406096673782, 0.5557296797633171, 0.6990691430626378, 1.8701022574978492, 3.578466316384654, 61.632539841436575, 66.89938083771737, 63.16705342262023, 60.509153412234404, 50.40568090254261, 46.61902866055889, 47.31447273685087, 47.872265154315585, 48.12907057423746, 49.2752302846601, 55.077455197611165, 55.69025101200227, 56.53871459345664, 57.24211715882825, 56.338438372458185, 61.098230654193515, 56.79367257702736, 55.890040859099365, 53.62024368778352, 54.789066853061804, 59.35436448743267, 48.49806362582792, 43.08358069389097, 42.90592085930609, 41.831501299335116, 42.315396262753396, 40.641920951104936, 41.786178311994, 38.74284267425537, 40.13992032697124, 39.99894642060803, 41.36640233378257, 42.12631448622673, 40.008791569740545, 41.58277596196821, 39.9197498444588, 40.70052900621968, 42.864520242137296, 41.066215499754875, 44.189508653456166, 42.216128918432425, 44.00095247453259, 43.02499225062709, 43.275561101974986, 43.939630139258604, 43.99865004324144, 44.18008712030227, 42.14033303722259, 44.64664128518874, 44.701927092767534, 45.74379098030829, 45.21012506177349, 44.11267726652084, 40.3362859449079, 42.135402617915986, 41.10328974262361, 42.80374311631726, 42.51471150305964, 50.102120830166726, 53.57636805503599, 55.4172932717108, 58.072761412589784, 56.90955508139826, 35.67270940349948, 53.09053151838241, 58.04602261512511, 55.336013917000066, 54.99926667059622, 52.85254563054731, 53.660761771663545, 53.66625308990479, 51.45217710925687, 49.92062491755332, 52.26718287314139, 52.16486392482635, 53.10572678042997, 44.80307717477122, 43.542113611775065, 42.71523875574912, 43.02753002412858, 44.39817482425321, 45.09298347657727, 43.717098389902425, 41.92657562994188, 42.57319404232887, 44.045647882646136, 43.28242524977654, 42.875589170763575, 41.79663927324357, 41.20568713834209, 41.817474903598914, 43.19155569999449, 43.313466887320246, 43.58314944851784, 40.85854561098161, 41.552761985409646, 42.72818257731777, 42.137359880631976, 41.96101404005482, 42.21004532229516, 42.96329336781656, 41.70890761959938, 43.44893378596152, 52.91078106049569, 56.706756776379, 54.17900100831063, 54.92165865436677, 55.83005605205413, 57.64190473864156, 58.69889720793694, 56.17681318713773, 56.56689290077456, 59.01293393104308, 59.24808394524359, 59.617320183784734, 57.07981340346798, 59.71660713995657, 58.538056496650945, 65.49945946662658, 64.58059718531948, 58.311194450624534, 66.47056379625874, 63.07100242184055, 69.361358457996, 66.63133390488164, 61.339193620989406, 10.115183726433786, 0.12059602120350446, 2.6198522842699483, 0.4139904515637506, 0.04088644193665635, 7.192367324906011, 62.191430522549545, 56.903181229868245, 45.67112515049596, 32.255628762706635, 11.235576406601938, 24.14062926846166, 49.460095513251524, 50.59482935936221, 50.3770201436935, 6.459147391780731, 0.18074908413954321, 0.048081543551938194, 0.06036911505244433, 0.0778727455725593, 0.034348226242488435, 0.01584999526159898, 0.019737996814411976, 0.04569664289573989, 0.041432605170074015, 0.06487702920792565, 0.036596096751670686, 0.03128072975443737, 0.04756478277305442, 0.07126003548863434, 0.04693744869361963, 0.06393464913050975, 0.030188997005743366, 0.028737162713021524, 0.45593569595967576, 46.65376517080492, 64.10370757502895, 58.79201427582772, 56.278484944374334, 26.145270293758763, 34.32174705689953, 52.17687422229398, 56.314778635578776, 68.3478101607292, 66.28947581014326, 9.318227729489728, 0.5298908211050496, 0.426798522352211, 4.0974986072509525, 5.798770775718074, 65.60386903824346, 67.02674804195281, 66.95407436740014, 62.331576808806396, 50.72349486812469, 49.31723494683543, 49.786330807593565, 49.777219141683275, 48.75378647158223, 51.151001837945756, 55.92428315070368, 57.6289922960343, 58.15959484346452, 58.51988415564261, 57.70505882078602, 64.32396827205535, 58.035157649747795, 57.98036606081071, 56.82792271337202, 57.17062804006762, 58.6809798209898, 49.85246196869881, 44.164636904193515, 43.96880080623012, 44.41964587857647, 43.3132746911818, 43.37718971313969, 43.54351782029675, 40.3429304399798, 42.661816074002175, 42.79767520966069, 43.82967433621807, 43.977516312753, 43.56811108127717, 43.50790662150229, 41.65628510136759, 41.98631725003643, 42.804794311523445, 43.053209781646736, 45.16031880532542, 43.78959948016752, 45.62369585037232, 44.34748603451637, 44.911746440395234, 45.194584631150775, 44.32791340735651, 46.46386754128241, 43.41948855307795, 46.897175696588334, 45.26519513899281, 47.87346147721814, 46.65204325029927, 45.31465622686571, 43.35002337732623, 45.34868278811055, 42.74187557158932, 44.560117721557624, 45.053873523589104, 51.918562612225934, 56.22735684917819, 58.544383279738895, 59.336137233241914, 58.585175929530976, 37.20789763235277, 56.364522134104085, 60.626961800359915, 57.7422821137213, 56.97889081893429, 56.285541288314334, 54.99470887645599, 54.94189023971558, 53.63757664157499, 53.8300669577814, 55.10956764221192, 53.64809643837714, 54.80733333095428, 48.00502169516779, 44.97720295383085, 45.660613198434156, 45.05071601560039, 46.11538848569317, 47.043793893629505, 45.926914676543205, 44.2969855185478, 44.79968432457217, 46.370424916667325, 45.05817636366814, 44.58945705044655, 42.83038385452763, 43.121529625308135, 45.329847566543094, 44.82932959833453, 46.09541185440556, 44.733494327914336, 44.399218174719046, 43.01262501747378, 43.45387597237864, 44.65403103059338, 43.74443731000347, 43.22164420158633, 44.48228613022835, 42.58800098972936, 46.53655690531577, 53.91737107307681, 60.51576260597476, 55.96303224563599, 55.45274757569837, 57.056341940356845, 60.07162086425289, 62.432824950064386, 59.44397103401923, 57.66115180907711, 60.53563333326771, 60.68333018210627, 61.09444164460706, 58.93996215635731, 60.74619400885798, 60.91943333225866, 65.86585983153313, 63.853499581736905, 61.780366128490826, 65.73026741704633, 66.08897993641516, 71.07484586777227, 69.94834899902344, 61.658227443695075, 12.895135148879021, 1.5792718697940151, 4.60892370631618, 1.7696651888470498, 0.09134578834017439, 8.097057102187987, 66.72977755146643, 62.822783070225874, 50.165910336279104, 36.259444990465724, 17.795448303222656, 30.785749958407497, 57.33760726067328, 57.97134853178456, 60.50847091982442, 10.514914431879598, 0.2743164431904593, 0.07439931824563012, 0.05256033870541761, 0.033688647522320675, 0.045530620151229446, 0.018403734035429456, 0.02969647716400364, 0.04002208025344918, 0.030535680519777442, 0.32377520215607464, 0.11395289742898558, 0.19837097565252937, 0.2834406422991907, 0.17890017689956775, 0.16933487968579417, 0.17180580435500992, 0.14323582692492393, 0.20531908669058355, 1.1667110915145567, 58.14290908075149, 73.01034727404195, 67.67984620986446, 65.69188310254005, 29.754629442768714, 46.50638995632049, 63.50579715544178, 63.98103544788977, 75.41492492921891, 70.90806668804538, 12.032765784571248, 0.7986420032478149, 1.5874807776943332, 9.98033852346482, 7.67616815144016, 68.78953180005475, 68.71462237450385, 69.97276183097594, 65.21445220516574, 55.84749490984025, 51.9675765498992, 51.6313745129493, 53.114771766047326, 54.03777607025639, 51.78089918628816, 59.519582563830966, 60.72795498755671, 60.72701754108552, 62.1354426107099, 60.890870632663855, 66.67756295973255, 59.796741162576986, 58.99317695248512, 57.66821599775746, 59.00876837392008, 61.855197106638265, 52.82783077609155, 47.920953535264545, 46.379214948223485, 46.505291692672245, 44.9951752539604, 44.88777683627221, 48.09157663776029, 43.36521471700361, 45.12201293822258, 46.05102239116546, 46.38685180294899, 48.131078827765684, 46.156216436816806, 48.39572506566202, 45.06321660933956, 44.94445116289201, 45.75475400493991, 43.90226956336729, 47.27242492860364, 44.65279156161893, 48.27378249937489, 48.170404511113325, 45.197742139139486, 48.479008751530806, 47.66041009656845, 49.10974940946026, 46.76035558023761, 49.32482081074869, 48.97435703585225, 51.42812121299006, 49.804087377363636, 50.69118238264515, 44.55359089759089, 47.22290892754832, 45.61103836182625, 47.846150013708304, 47.698029548891135, 55.10333499600811, 58.81657223547659, 61.4845056687632, 62.44914593235139, 61.50480393440493, 40.22451408447758, 58.74003502630419, 61.60052545609013, 59.65197040188698, 59.030345332237985, 57.91454868931925, 55.720994549412886, 57.95689852006974, 56.87841146223007, 57.46047942869125, 55.56856339977634, 56.38218456699003, 57.026280895356216, 50.38942660054853, 47.54284097302345, 48.750891762395064, 47.5570595648981, 47.61476155250303, 51.202757512369466, 47.68980433863979, 45.287611484527595, 45.95310826455393, 49.55582487967707, 48.15706060778711, 48.01807534310126, 45.9272990688201, 46.85548874639696, 47.91354810037921, 48.36478540974279, 47.65018447752922, 47.50976362536031, 46.75209899102488, 45.43889337970365, 46.46243979853969, 48.02950512978339, 46.270302495648785, 46.893716166096354, 46.56074223979827, 45.68983093384774, 49.21829708160893, 58.69279792231899, 61.93622935202814, 58.75827404760546, 58.4660025565855, 60.045195856402, 65.17112178187217, 66.83898418180405, 61.70338569148895, 60.36175858589911, 63.222111732729026, 64.15282741669687, 64.72523066305345, 61.07429635140204, 64.3388536668593, 62.671261910469305, 66.45725127189391, 65.89217893538937, 62.9823725454269, 69.76624119666316, 67.88926155336442, 75.03515320439493, 70.31111332678026, 65.77018145591983, 14.01453939176375, 2.5441681906100246, 5.158073181106198, 0.8656539816048838, 0.14761598059727302, 9.207727697587783, 75.41890221257364, 67.39336413721885, 63.375025333896765, 43.4039520448254, 20.83245715787334, 36.87504137715986, 67.54544227353989, 68.68182351512294, 73.85066017027825, 14.340250069095244, 0.4262614640737734, 0.12874230141601256, 0.2085430911111255, 0.2506225234678676, 0.16085065510724822, 0.16493945022023496, 0.1817337216268624, 0.16046158969402313, 0.18070645900743623], [0.038910000209486297, 0.025234097359521736, 0.010298699996764622, 0.03731246556966536, 0.026649471612707264, 0.027052849463577715, 0.0798674853098008, 0.103976892818126, 0.07722822048010365, 2.5049351732577048, 49.37685105108446, 53.373134366927616, 52.06045827557964, 32.31391322228217, 22.424011807287894, 39.55447127742153, 34.90811394106957, 50.80106366065241, 65.87795642114455, 56.409374437024525, 5.463780751151424, 0.2446784779068924, 0.5067610025646225, 3.6297748406087202, 8.978178827993332, 72.73945270046111, 62.16213826210269, 65.90633084697109, 52.72295052005399, 50.616014080662886, 49.16625507416264, 53.2796525186108, 52.20503291776104, 57.334300702618016, 57.53518096862301, 57.3304920811807, 59.08481528682094, 57.34092166346889, 57.05913466791953, 58.05699348449708, 56.043487902610536, 53.378845337898504, 51.64911539323869, 53.380696696619836, 53.35684868597215, 51.826296698662546, 50.46520286990751, 42.141984355065134, 41.752241965263124, 41.958264458564024, 41.79978501412177, 40.34937489417292, 39.24622397268973, 40.97664817687004, 39.59417350830571, 41.135151155533336, 40.09546026106804, 41.50311262376847, 41.571605051717455, 39.924162510902654, 40.0334789676051, 39.55537734493133, 41.854090229157485, 42.24086338473905, 40.27821917687693, 43.03398232306204, 42.59972887654459, 43.479893053731615, 40.62126574977752, 43.0672126431619, 42.70264794749599, 43.08613807924333, 39.684764569805516, 42.73670588770221, 42.63933697054463, 45.88732227202385, 45.385737419128425, 43.662903001231534, 42.384818292433216, 41.4813748482735, 42.1015957094008, 43.31208229064942, 42.61437892913819, 51.66946072732249, 57.417396114718535, 56.28583938844743, 53.725704454606586, 51.6743754571484, 36.34820430509506, 45.97709748052782, 55.9070796351279, 53.53106467954574, 55.50962978793729, 52.689214214201904, 52.135901143473966, 49.68769888724051, 51.54942051056893, 51.83357661770236, 51.31254073112242, 51.08136800027663, 50.60121105563257, 41.38808127372496, 43.09916427058559, 42.579324706908196, 42.58368638253982, 43.211634312906575, 42.5025325436746, 43.444646635363185, 44.33563263185563, 42.80299786598452, 41.83459997177124, 42.9554525498421, 42.726707766132975, 40.58845120091593, 42.39696587285688, 40.76885277225126, 41.66688726794335, 43.06315691240373, 41.61588076622256, 41.198752387877434, 41.05582121879824, 40.98474787127587, 40.5443912167703, 40.67590828864805, 41.260631699715894, 39.63855904917563, 42.917362413098736, 42.47274214221586, 52.17723900272001, 57.91365831129013, 55.6496976267907, 58.869892935599054, 58.36969267937445, 57.170851615167436, 54.87937158153903, 56.030724510069824, 58.4718821894738, 57.471579736278905, 57.94977157346664, 57.42931227530203, 59.9281366409794, 56.5171847035808, 60.92659165782314, 51.069043913195216, 33.82334716858403, 56.834116135874105, 56.70032408929641, 63.298931352553836, 61.258561457357104, 65.35123702018493, 56.99253674476378, 11.385857116791511, 1.9835953029894062, 7.833275746914649, 2.721853030304755, 0.1704495989026562, 3.292530678933667, 55.007315374189815, 61.12426342502717, 49.24354537840813, 39.592733998452466, 29.083458954288115, 33.42378316387054, 47.2181942386012, 55.66884271560177, 49.777756506396884, 18.60813790752042, 0.2980581821212846, 0.06742060199500093, 0.05343349507799553, 0.0561722019507039, 0.03186269419177646, 0.026427601058516773, 0.04062593373800478, 0.015656019883951353, 0.022599674205506043, 0.02876676626563553, 0.042755807554649736, 0.09868470381104177, 0.00778978550618875, 0.01399966309808435, 0.09528380202790422, 0.07019901137438513, 0.1399467663178521, 0.20983204936548588, 3.9667790022588547, 59.70768374781455, 61.63474813584359, 60.491522358309844, 40.94555162614392, 24.23022993149296, 36.12907325067828, 45.08624092225106, 56.9009494012402, 71.91273473924207, 61.777981327426055, 5.520266804002947, 0.4025583359743319, 0.6228440687541039, 2.677844282119505, 13.93711474633986, 77.55981814476752, 63.324552274519405, 67.96053886413574, 54.27329478725311, 52.962411219073886, 50.68440844935756, 54.10522907010971, 52.533041123420965, 58.51012137628371, 61.34648922950991, 60.50737657854634, 59.761051516379084, 58.15666875531597, 60.016880266128055, 58.16332109512822, 57.69901837072065, 54.07911000713226, 53.31077260355796, 53.90856142966978, 53.99425737319454, 54.3735231122663, 50.95169052000969, 45.43689689328594, 43.02185043211907, 43.64217719724102, 44.16415053029215, 42.82919537636542, 42.40853686486521, 43.0957047400936, 42.840683998600134, 42.78416264441706, 41.40419437039284, 42.87142753601075, 43.507655589811264, 42.24873950404506, 42.77813788383238, 41.94025293473275, 43.98318021528183, 45.54946107249106, 43.04794203850531, 44.48021511877737, 45.13080296977874, 45.13783185712753, 42.70182817212997, 46.729729713932166, 44.93023649338753, 46.062067785570704, 42.265535093122914, 44.76183345240932, 43.875448396128995, 45.77703698988884, 47.39614040620866, 46.819744187016646, 44.603887450310495, 42.603235475478634, 44.476790889616936, 44.40810234315934, 44.193144690605905, 52.994488362343084, 57.54425733320175, 58.915619927067915, 54.78661537170411, 51.36654784602504, 37.04478979110718, 47.66532090402419, 57.94673565895327, 56.88807225996449, 56.539055839661636, 54.07373243762601, 54.10375818129509, 52.807108894471206, 54.49650118427893, 54.15953036277525, 54.00818178730627, 52.15045313681326, 52.02876552458733, 46.010198362412, 44.75268648516747, 44.70180549929219, 45.577592311366914, 45.1932627924027, 44.8052619349572, 45.71059203916981, 45.89052292608446, 43.920092813430294, 43.45361709594727, 45.466875568512954, 44.04316502232706, 43.61000983945785, 43.83028230359478, 43.81806804287819, 43.76555927338139, 44.858704228555005, 44.09219857185118, 43.30499456774804, 43.80139404727567, 43.52718114852906, 44.04578124323199, 44.24533574811874, 42.741149933107444, 42.863167024427845, 43.586577600048436, 45.16906961317986, 54.289360815478915, 59.095829302264804, 58.61260506414599, 60.6700921827747, 58.347845077514656, 59.25414008478965, 58.7633260603874, 58.754920421108125, 59.715336292020744, 59.652295958611276, 57.942577946570616, 58.80930800591746, 62.74796385918895, 59.311206648426676, 63.399006705130304, 51.88368097428353, 33.80847746326078, 58.00240193643878, 58.10161044520717, 62.53358279505084, 62.443866422099454, 65.41313202150407, 58.36197345487533, 11.584932111924696, 3.086076234617541, 6.1162734031677255, 1.756068537792852, 0.21678327072051265, 3.2025272375152958, 60.872239374345355, 67.16505081422868, 54.536246561235004, 33.870439144872854, 27.102848329851707, 41.50336757782967, 56.29258586514381, 62.13707823907176, 60.40404173635668, 26.43987559503125, 0.39834071551599814, 0.04890557453637162, 0.07924641016870737, 0.0031502940738949207, 0.04750847914105943, 0.053906427966731216, 0.013839296955284814, 0.008213541774650016, 0.035443283812773806, 0.13416439595241703, 0.13649272101540721, 0.27712645369672007, 0.16049456211828417, 0.14981442311358067, 0.27425221437888764, 0.13988364067289139, 0.26496698358847254, 0.29758029647411843, 4.142758836669307, 68.60827907439202, 71.99720690327307, 72.07758411284416, 46.53286595498362, 31.697628459622784, 49.47413759846842, 49.945018137654955, 64.07911039167836, 77.62797324888169, 68.30450719402683, 7.208201933291651, 0.431741965153525, 1.5635968528447615, 7.656628864426767, 16.995094553116832, 83.36387480458906, 66.61045905082457, 72.43445704060217, 56.103892403264204, 57.61302824943297, 53.3200764656067, 56.67942570101831, 55.51904739872102, 60.609577855756214, 63.68792064728276, 61.946494194769095, 61.89791564018496, 61.12918207722326, 60.581285799703295, 60.130821197263664, 59.04959240267354, 56.00697848104662, 53.97404147732643, 53.803528201195505, 56.38877414887952, 58.46692823594617, 53.40613718955748, 48.03709883843699, 46.053991625385905, 46.87825026050691, 47.33716364829771, 46.09617279421899, 43.96910675110356, 46.586500444719874, 45.99421862632998, 45.210207431547104, 45.98566393698416, 47.19245956790063, 45.61700820922852, 45.80189697204098, 44.56012556629796, 42.296392379268525, 47.111721500273674, 47.20400702568793, 43.58390646596109, 46.29067136395363, 47.73412712158696, 49.13904951464746, 43.712626887905984, 48.99289415728662, 46.444891114388746, 48.08824262311382, 43.73050897352157, 47.21074565764397, 46.16244516065044, 49.97225507613152, 50.25877245010869, 49.54981188620291, 47.36037623497748, 45.26986275949786, 47.17758986257738, 47.217264636870354, 45.37023621220743, 56.28438026674333, 62.44874192822365, 60.365104367656095, 57.677190380711714, 51.865857724220525, 38.563429540203465, 50.114103671043154, 60.74581746132144, 58.51082740291473, 59.06526619388212, 56.41974518376013, 57.39800783895678, 55.165433960576216, 56.56176244058917, 57.2163942552382, 55.99781974669426, 56.67163979622626, 54.31213801906955, 46.228011500450876, 47.71255016326905, 47.5558828538464, 46.558741831010394, 47.46721375373102, 47.0341174064144, 49.267283562690984, 47.93754908346361, 46.97960038338938, 46.49646243741436, 47.044056692431056, 46.55489398587135, 45.71964879189768, 47.37952132378855, 45.38193272006127, 48.44056560147194, 47.866491425421934, 45.90807553260557, 44.949216842651374, 45.93890536215998, 44.87512719246649, 45.486981638016246, 45.35215800808322, 46.264450319351695, 43.77028180706886, 46.31787300109864, 47.073866705740656, 58.13690393201767, 63.33535448197396, 62.871934290855165, 62.282460889508656, 61.93963396933771, 61.23016741967971, 62.07941155279837, 61.78715182888893, 63.410487482624674, 61.148378156846576, 60.32031090028825, 61.267755493041015, 64.66572438516926, 62.83689575810587, 64.26339118711411, 56.26282684264645, 38.29268009431901, 58.48311585764731, 59.01198863983155, 65.45712140298659, 64.0114220496147, 66.27764594170355, 59.733720441018384, 12.90183553772588, 3.5459957103575435, 18.487603472125148, 5.301729988667273, 0.30683197261345, 4.6865415284710545, 66.08726193827968, 72.54884904430759, 64.80410560484856, 50.647161622201246, 39.077930758076334, 47.83204124819848, 65.0279748824335, 70.93689610881191, 70.6322613070088, 32.59750646929587, 0.6472209865047086, 0.16020305034133697, 0.13024518206234903, 0.15050056210208326, 0.10156070513110008, 0.13652619905769825, 0.13523442159977653, 0.07506514824326001, 0.18783389590680602], [0.06060271824319517, 0.0635901164083231, 0.01055696260018815, 0.04351388219924223, 0.013061792405712749, 0.005427833971372175, 0.030870663955987945, 0.0789197349560357, 0.13154455911247961, 4.040030736115671, 52.59382609398135, 51.94948265629431, 48.939479320280014, 26.384072034589707, 23.982310641196467, 50.24734266342656, 41.754720903212025, 56.01687462099137, 61.922406919540904, 53.36904333483789, 3.491082282796983, 0.33468110727206357, 0.4703209885666448, 1.403807336764951, 17.245855600603168, 71.56707194543654, 60.54735337534259, 60.17242185531124, 51.55886557794387, 49.498475905387636, 49.86773175577964, 56.66087289010325, 55.279857343243016, 56.682967601283906, 57.677245293894124, 59.61151115355953, 57.60762714570569, 53.70165248070994, 53.73397281092983, 54.047699666792354, 53.320366720999445, 58.025355646687174, 56.0227503315095, 56.78639658035771, 55.07596077457551, 55.38003859981414, 47.32642812113608, 40.44374319814867, 42.04378389543103, 41.51475814081008, 41.63734789817564, 41.36173079090734, 40.63551572061355, 40.118484573979536, 40.84244035905407, 38.209537613776426, 39.58704263933244, 41.46631686918197, 40.8849706188325, 41.06419547911614, 38.795139635762865, 40.55371861304007, 40.74825248410625, 41.947509319551536, 40.61955559638239, 45.511570976626494, 42.879103614437966, 42.70292251340805, 42.10885209421958, 43.341888381588845, 42.92345385397635, 42.564957064967004, 41.97614262180944, 41.34008322992633, 41.79607837430893, 44.13686652337351, 43.364065462543124, 44.42680812651112, 41.75488172038909, 42.876248128952525, 40.87332117942072, 45.83657072436425, 42.68568369650072, 48.538915111172585, 54.34037516194006, 55.751251712922134, 55.15202729932724, 55.78607843768213, 37.62786972907282, 46.56981860437701, 54.06258113922612, 50.925885246646025, 54.227909041989236, 53.05933298603181, 55.351436676517615, 52.2590910234759, 52.81912311430901, 50.87362750884026, 50.67032714043894, 50.16110151044784, 46.489923846337106, 42.1316175306997, 42.74477420314666, 41.93587949199062, 44.31058437593522, 43.55467696343699, 43.01915576381069, 44.17270521963797, 43.830894193341656, 41.404202215133175, 43.336197022468816, 41.269488411564986, 41.64144285263554, 40.57584078081193, 42.638117113421046, 41.6886015092173, 40.815889835357666, 40.24277271762971, 41.579665522421564, 41.89268635165307, 40.277838706970215, 41.22414581237301, 42.2911403256078, 40.45496509921166, 41.3823938369751, 40.96228837966919, 43.2559492511134, 43.67993785488991, 49.92582990277199, 55.37693992737801, 56.8056671850143, 55.9818321658719, 51.79833412170411, 54.76766640140165, 53.9255335254054, 54.18874025344849, 56.63831926161244, 57.74380791571833, 60.78678661777128, 55.7603241551307, 56.42263204820695, 58.56730953339608, 60.340040422255, 57.261434831926906, 47.58832085517145, 59.97516585934547, 64.27064364956271, 64.00959030274423, 67.28636187891807, 64.54857887760286, 63.65331749762259, 11.106538272673085, 1.4639282010255323, 3.8545925963309506, 3.2979668388443613, 0.06374399665923369, 0.6382967363442145, 45.46794245319982, 68.61656312019595, 49.665827751159675, 55.238711680135424, 26.6437231340716, 15.705294705206349, 35.155897909595126, 51.12702046671222, 59.938385794239665, 30.763031590369444, 0.0926252854086699, 0.04296483081435004, 0.023683002969670682, 0.009963735712752228, 0.0030058285647687776, 0.015223404287450738, 0.03433203114376914, 0.03862911407204886, 0.0893082396097241, 0.04093179817221338, 0.0548973435445899, 0.02442347482898303, 0.028737980511880694, 0.021919698394354314, 0.03429173874939161, 0.02582684256917527, 0.061649071773694414, 0.2162586537099654, 4.544605170526813, 64.70250837264523, 58.986716808811316, 57.874544435931796, 31.47920539302211, 25.49640436326304, 46.139103135754986, 44.70950511194045, 60.7892773228307, 66.70784365746283, 58.00937591060516, 3.6897721502088734, 0.5601251245506349, 0.7206128225211175, 2.7543027987403255, 22.54677022657087, 76.48412381449054, 63.79611138374575, 64.56382513046265, 54.16918723813949, 51.77979307789957, 53.07202577590943, 57.85909814219321, 56.88275352601082, 58.843220818427305, 59.974381385311005, 62.01137411978937, 58.797972356119466, 55.32827900302026, 54.624099808354536, 55.26389329664169, 55.10386843835154, 58.75849762270528, 57.38882164801321, 58.493094367365686, 56.22869437740695, 57.33031949689312, 49.27022534032022, 43.55171557395689, 43.98557678345711, 43.579980173418605, 43.69055571094636, 42.929435468489125, 43.00187380083146, 43.41454636666083, 41.43394162577968, 41.51860990831929, 40.74497730501237, 43.25134831090128, 40.62403494311918, 43.42187727651289, 41.86238604207193, 44.167096230291556, 43.645981896308164, 43.119803782432314, 44.49655179054507, 46.84471791790378, 43.5142255598499, 45.09732161798785, 44.225249290466316, 46.23163969286027, 44.86732952056393, 44.11749393709245, 45.202343079351614, 43.349015328191946, 43.63388530669674, 46.46040801079043, 45.560259357575454, 48.4074451077369, 44.89874770564418, 44.829576707655384, 43.8143967043969, 46.17607147462907, 44.10409904295399, 50.92072732986943, 55.745638801205544, 58.15799059406404, 55.866690989463564, 56.82472205931141, 38.8867465911373, 49.791712299469985, 57.16727833594046, 55.63545157832485, 55.49910999113514, 55.861446780543176, 56.72684715640161, 53.82059835618543, 54.65057580701767, 52.56229808253627, 52.58259242580783, 51.30317411115093, 47.650647317209554, 44.78150413882348, 43.36191992605887, 43.7406639898977, 46.318245626265, 47.55855006556357, 46.42475758829425, 45.526797617635424, 45.5606202156313, 43.71874970774497, 45.30414819717408, 42.81368240233391, 43.815887205062374, 42.3233155281313, 45.59604706302766, 42.717309767200106, 41.99451892606674, 42.913906804976925, 44.01159386481009, 43.161839823569025, 42.56530223354217, 42.14045463069793, 44.482297897338874, 41.313720979998195, 43.42224990167926, 42.325861146373136, 44.89639820591096, 44.560474657243304, 50.800035999667266, 56.610337072803134, 58.51795042714765, 57.871088827809984, 56.19900987994287, 55.97651343191824, 57.568881973143554, 57.54931719072404, 57.54612830377395, 57.43466238821707, 62.41160492743216, 57.25452753805346, 58.1908953574396, 57.92550386921052, 60.94587795196041, 60.17096665597732, 50.83670623840825, 60.99287186899493, 66.1345814120385, 65.86316124085458, 69.02932197816911, 65.81038967255624, 64.34910674248972, 12.421526601237636, 2.357902430718945, 5.52465936829967, 3.2441756994493547, 0.008037967828943605, 0.613134915549909, 49.38003993803456, 73.82125023872622, 58.59130267174014, 50.67182548584477, 29.790738782575055, 23.906901113448605, 41.19396317389704, 58.014471069459, 68.68926032896965, 39.78320037164996, 0.6019557315495707, 0.058667993833941806, 0.022950347122405807, 0.07342494633649627, 0.024937918191895853, 0.05644266929237112, 0.03776541888533581, 0.06468007566347238, 0.024128147934172905, 0.15987398493434155, 0.15880734539560734, 0.14041378883825195, 0.16655427163406727, 0.17384620293253855, 0.17314612114381406, 0.1378863268802243, 0.32081460940741724, 0.4348899123649444, 6.863350089519256, 80.03004843188872, 67.02448091199322, 66.49896960104665, 37.44163167092108, 33.397636644301876, 58.240470194047504, 57.53111739312449, 68.40044052370133, 70.72151876265004, 64.21811526821506, 4.740432933453591, 0.9187273885453902, 1.4603045438566518, 4.172955203440882, 28.231000438813243, 81.0480603864116, 66.15307930977114, 66.39650944740542, 57.20637259944793, 55.93442639996929, 54.989527425458355, 61.39299285027289, 59.35996170966857, 61.462693368234945, 62.831306380610314, 63.95724627279467, 60.70940609901183, 56.07521203256423, 56.06726138822494, 55.72965122038319, 55.922949544845096, 60.89368297207741, 59.470854959180286, 61.49328001083867, 59.07162827830161, 58.915157087387584, 51.912051477739894, 45.64583762999504, 47.037910338371034, 46.59221926043111, 45.91883459398824, 44.651152010886904, 46.23802138913063, 45.26273189052459, 45.1055742848304, 43.59794462880781, 43.55683818940194, 46.997760957287205, 44.7095129566808, 46.09769467384585, 44.03582234536448, 46.20825059952275, 45.482278716179636, 45.20869731903077, 46.10646901592132, 48.91256793852776, 46.194906696196526, 45.137518067513746, 45.674341494037265, 46.7449132088692, 47.579299403775124, 46.68896452073128, 49.16216011970274, 46.601511355369325, 45.11462319281794, 49.37208929369527, 47.247368827942886, 52.02323106027419, 46.85095056410759, 46.83940702869047, 45.832530683086766, 48.130506161720525, 46.52311102036507, 52.06054064535326, 59.10922811877344, 60.81691826543501, 60.44761926897111, 59.61033444250784, 42.022999255887925, 51.822495921965576, 59.665988952882834, 57.97211731633833, 58.83037505611297, 58.50674813793552, 61.17670159186087, 56.3139667049531, 57.12823506324523, 55.37728509595318, 56.499836060308645, 55.21941361888763, 49.869853758042865, 47.307616433789654, 47.145230308655776, 45.8342408364819, 48.70245441313713, 50.00880372139716, 47.66273998445081, 47.2397162837367, 48.50204090918265, 45.44190575999599, 47.77361362211166, 44.01400220009589, 43.91922204725204, 44.66911254390594, 48.25554740044379, 44.833852091143214, 45.22595182541878, 44.74368464562201, 48.045606459340746, 48.134926672904726, 45.47570874614101, 46.039372951753684, 46.86586341550274, 43.42152034082721, 45.85400173741002, 45.68329626514066, 48.06526537864439, 47.309558007024954, 54.36195996499831, 58.88806135423722, 59.52521116502824, 58.79580328541418, 58.0740479500063, 58.04411242085119, 61.11095874540268, 58.892301436393495, 60.47215369439895, 61.10242759027789, 64.18068408966064, 59.22474584271831, 58.884542988192656, 60.723020645879934, 63.03596388909125, 63.49441443720172, 53.600533777667636, 63.943635648296734, 70.0621134235013, 68.31967892185335, 71.81924896855509, 66.52424535443707, 67.87409767027825, 14.335507923556914, 4.660717133552798, 14.05231083593061, 8.480295711948026, 0.19860386638151062, 1.0434121205922098, 55.33461363084855, 79.1831773327243, 65.89843119344404, 72.81295791749032, 39.516145798467825, 30.659998770683046, 54.84736896330311, 70.18393439631309, 77.44061731523084, 50.140254112981985, 1.465909855981027, 0.22700470691967398, 0.15129635891606733, 0.20351805994587563, 0.11885881724376833, 0.16238598723805722, 0.1440810364100241, 0.14156701163418833, 0.20950687568514578], [0.048913775507601044, 0.03197766292179304, 0.0729689478213268, 0.015723401147331444, 0.05335340441595163, 0.08468475342998583, 0.05706986164553993, 0.09085391392751087, 0.16144225884589458, 2.401773895948164, 45.24925854898269, 54.5359484611019, 52.5791681966474, 35.446412178777884, 26.986467684468916, 33.558642095135106, 43.42251662285098, 53.389400436032204, 64.86783627540835, 49.4393853987417, 2.089501503975161, 0.23887209834591036, 0.4762397532261187, 1.0494557575833414, 26.347484165622344, 76.12317946649368, 61.14601689000284, 59.98127298970377, 52.095571333362216, 58.29828200801727, 57.31446527665662, 58.21340976222869, 55.99086538437874, 59.67951720760715, 59.59013815849059, 55.02916689841978, 52.31567121321156, 55.424957583027506, 56.203763792591715, 57.49802043361049, 57.96118174829791, 56.87867818340179, 57.14663097935339, 55.98147523018622, 54.822403077156316, 49.80846082010577, 44.57888626283215, 41.93766024804885, 39.03211747446368, 40.81430519780805, 39.71944616686913, 40.66065026867775, 38.96196980630198, 40.44738708003875, 41.33791023685087, 41.28686451142834, 39.80233761572069, 40.43738895846952, 40.254175047720636, 40.63892426029329, 38.73529995641401, 40.617782685064505, 41.29219501249252, 44.285151727737926, 42.29829080643193, 42.871349088607296, 42.08977760807161, 44.06039991686421, 43.57435157222133, 43.36468127466018, 41.79774538163216, 43.13894102650304, 42.30571977553829, 42.22759008407593, 41.57890850497831, 41.71723088910503, 39.998271772938395, 42.569820803980676, 40.88800653334587, 43.46849072364069, 39.61779009911322, 42.73459957491967, 41.61750854984407, 45.21519276403612, 47.87906654419438, 55.26836872100831, 54.665767146695046, 56.69091432325302, 43.14176905539728, 50.73059435813658, 54.65240755388814, 53.573147789124526, 56.507500371625355, 54.86339184545702, 54.13706302642823, 50.640548506090724, 51.236933123680856, 48.1224064673147, 47.34759715295608, 44.88073225944273, 42.14048993202948, 41.096343225048436, 42.276007821483, 43.491981798602694, 43.11118633516374, 41.84169553941296, 44.063573114333614, 43.7137722199963, 45.00045084184216, 42.185075513778195, 43.152375144343225, 42.477386228499874, 42.763201498216205, 41.84331155592396, 41.931270707038145, 41.393788322325676, 42.68301648478354, 40.90077777062693, 41.57930074199554, 40.06030405721357, 42.16687963854882, 40.57430321170438, 40.98328090483143, 40.64232495523269, 41.53482106424148, 43.35883302073325, 43.25550602328393, 42.19976479007352, 48.580841325944476, 52.34783857099472, 50.63442960862191, 51.888125019688765, 51.04377600454515, 49.35571732059602, 47.7153193566107, 53.57116306981733, 54.55919242674305, 56.34567514542611, 57.94663759969897, 58.443672503194506, 55.413923955732784, 57.14116711770335, 58.733645485293486, 62.25722828219014, 65.29318201926448, 61.075590733558904, 62.760939059718964, 61.182130152179354, 64.99519171253328, 67.36109087544104, 69.09076982928862, 18.401468223141087, 2.4561153929079733, 2.8977941313097557, 0.7368195044898218, 0.08284043505667679, 0.137724299284239, 31.00846802034686, 71.8942682204708, 58.683215571988015, 42.04774941167524, 24.61578322995094, 24.636081495592673, 27.249172349129957, 58.488230628352014, 63.28505792925435, 48.685980458413404, 2.2365188021813673, 0.03938410521274613, 0.04816844856606857, 0.04273635658225225, 0.03422031637221094, 0.021070013040556543, 0.11148827766338665, 0.045048739355538166, 0.007022487162987912, 0.04895159726842277, 0.048194143155048934, 0.05372548182945579, 0.023759881808092038, 0.012606814702702387, 0.03982659376737091, 0.06781595699008434, 0.11650477460916005, 0.2197448134181961, 4.790085727168668, 58.967763916138686, 60.815565047725556, 61.99907356692899, 39.79184919787992, 29.211959723503362, 34.295090629208474, 45.88631422288957, 60.38311589148737, 68.93013308125158, 52.48218759413689, 2.3310466975935045, 0.3764963618689968, 2.1228816095859777, 1.7880728720657288, 30.459824531309067, 79.11487317854359, 61.75515705539335, 62.04514964934319, 54.03852916532948, 61.74833997603386, 59.04912956299321, 61.0486009044032, 58.92781849830382, 62.499913169491684, 60.08285453242641, 56.052564267189275, 52.00303085388676, 54.064408963726414, 58.540409918754335, 59.71025290027742, 60.35376087311776, 59.097041314648045, 58.36550751040059, 58.93645555742326, 55.933363437652595, 51.595014141451934, 45.12180505260345, 43.43297758410054, 40.64101488359513, 43.47060488116357, 41.39011306147422, 40.930219081140336, 40.67207221061953, 42.91944126929007, 43.654873909488806, 41.50813325758904, 42.477292091615745, 42.58918162315123, 41.584176248119725, 43.509401044537945, 41.57893596156951, 43.32232359916934, 43.60509118726177, 46.034775933911725, 43.02995797126524, 44.260107394187685, 43.689626109215524, 45.867988909444506, 45.483008277031686, 46.0896263584014, 44.87454668168099, 45.56525645717498, 43.78285300347113, 44.09336743816253, 42.71891401660058, 44.04203145734726, 42.47298532916654, 44.491621371238466, 45.06414228870023, 43.4993480097863, 43.10367499628375, 44.898904600451075, 43.90874539652179, 46.96910019843809, 51.56516098207044, 57.095957879097234, 55.829251966168805, 61.403751911655554, 45.59275227208292, 52.253223157698116, 59.53847662095101, 55.18066844632549, 58.50016640078638, 55.59337239111624, 55.41484963509345, 53.01212726100799, 52.59679140583162, 49.506822709114324, 49.317113353360085, 46.13299992776687, 44.17129708874611, 43.168272510651626, 45.03011572745539, 44.06728367651663, 45.38729460008683, 43.676470479657574, 46.653608275998025, 44.03309629809472, 47.79644966125489, 43.64142410216793, 45.40009721632927, 44.6421697831923, 43.92098711382958, 42.33917759310815, 44.12860208942045, 43.454738893816554, 43.807767898805686, 42.88130798647481, 43.209602525157315, 44.51819150678573, 43.274839385863274, 42.11284898942517, 43.596740461164906, 43.67793744610202, 44.30475573385916, 44.130884908860736, 46.39675186526391, 44.74875234788464, 50.48596397522957, 54.76428924068328, 54.012170837771514, 54.401022849544404, 53.2860146030303, 51.96528980808874, 50.724961834569136, 55.651466615738414, 57.53323155064737, 57.85894124738632, 58.75372802057574, 60.5174570698892, 57.58913317034322, 58.3090449917701, 61.72832412104454, 63.83442901795911, 66.48072273500505, 61.97037750674833, 62.40342678562288, 63.40046190446424, 65.39155898555633, 67.74828372463104, 70.98500005660519, 20.203159932167303, 1.5123499833768415, 3.575919717550278, 2.0570154536154965, 0.14964951502700008, 0.0871040131295881, 33.71484656487742, 76.75864265811059, 63.39648854347968, 47.128422952467396, 27.81136174355784, 28.38123702233838, 34.6119906825404, 64.3152056970904, 68.17804213493102, 59.19770110038019, 4.102202509680103, 0.16575150341997225, 0.05277715690974748, 0.024883374646906892, 0.026314290908856258, 0.06517524425421031, 0.012212127161722992, 0.0781352609215725, 0.01697912459231673, 0.15799751385085045, 0.09822059242475419, 0.2612862069039576, 0.07856157352967609, 0.08312046317563904, 0.24477865156387132, 0.20022230373034555, 0.40896411804902943, 0.4674467492488123, 9.072439266789345, 72.26917620628112, 68.62289382565406, 71.18226389731132, 47.84875446750272, 36.39066788458055, 43.457751274108894, 57.11472642037177, 63.84924381009994, 74.80389810377552, 59.23462629318238, 2.724647228756259, 0.5318882881153015, 2.7889498299168003, 2.6277740011292123, 33.55799882642685, 84.30338444248324, 65.9683592088761, 65.09920904713293, 56.756704238153276, 64.69296132364582, 63.20464934072187, 62.774714423764145, 62.77026645598873, 64.97363436606624, 63.435480825362674, 57.15342060212166, 53.69183871053881, 55.83676722741897, 60.94757633824503, 63.004788890961684, 62.6638525532138, 62.75666367623114, 62.289897703355365, 61.517814436266505, 58.17507251616448, 55.1190911569903, 48.46584527723251, 47.268800658564416, 42.88741903920328, 45.802967779098026, 44.261127210432484, 43.12419683702531, 43.17619962076987, 46.0282765665362, 46.194620363173954, 44.86148911137735, 45.82791797576412, 45.5879944370639, 43.95784170396867, 46.023883511943204, 44.25997403360183, 45.966381565217056, 45.14435475872409, 49.61728057553692, 44.90800449925084, 45.125233204134055, 47.14678356724401, 48.46415473568825, 48.82604045252646, 47.66073173092258, 47.970108678264005, 47.267482742186516, 46.42805237923899, 47.07498458123977, 44.69629456920009, 46.02524849676317, 44.26021722055251, 48.38185556473271, 47.29620625895839, 46.57287020837107, 45.86541583461147, 48.478369405192716, 47.055168767129224, 50.168903104720584, 53.87474275404408, 61.76667313421927, 59.812944473758826, 61.89118093059909, 48.34161989150509, 56.085927947875, 60.347575295356016, 58.14813367782101, 59.91905635403049, 59.07786876924577, 58.93406683398832, 55.78098327882829, 54.77444425705941, 52.90187728020453, 52.20349534865349, 49.24038787041941, 46.23348320684126, 45.824525125565074, 46.74778830620551, 47.10071140719999, 47.39722690274639, 45.00114117899249, 48.51497296364077, 46.17478493721255, 50.279309980330936, 45.93421028506371, 47.01898882465978, 45.68222545808362, 46.43566962211363, 44.63598812780073, 47.40525991685929, 46.189089821230986, 47.00863768977504, 45.677247970334946, 46.17977811444191, 47.53455692721952, 47.750055866856734, 45.943635740587794, 45.55111631270378, 45.82293264327511, 46.320002848102206, 48.256586828539454, 47.6036024093628, 46.37943852332331, 53.34180247399115, 56.446283940346014, 55.976333002890314, 56.36263939642138, 56.67416188024706, 54.61013224817092, 51.23665463539862, 58.739729081430745, 60.58484731181976, 59.638214649692664, 61.46245018128426, 63.118227758715236, 60.64390643950432, 60.16127840165169, 62.904717460755386, 67.56828615742346, 69.43119233654392, 65.11227053980674, 66.7911312657018, 68.91612237499606, 69.15870528067313, 70.76325278128348, 76.2540768038842, 23.210494095279326, 8.1197141831921, 9.2357147893598, 2.975388909539869, 0.2673505282690448, 0.22383570761209537, 37.90892716377012, 87.1054707804034, 70.06444331138366, 56.26330537180747, 35.59544263347503, 38.00752378279163, 43.251960200648156, 76.5593784086166, 78.51023197174072, 70.57194309849893, 6.483552378992881, 0.3492389228795806, 0.14749881511013355, 0.15197879003901638, 0.13049789914681068, 0.2199954620652622, 0.18070003919063077, 0.21717468036278603, 0.0716474308301845], [0.023650149289037914, 0.05888532531718093, 0.014646164697384643, 0.05556454867004387, 0.06637962640173013, 0.017289591299730445, 0.1132603156410398, 0.0575445641973807, 0.17734183148751337, 7.976504035534398, 60.20027460590486, 51.25965149171891, 50.37039133810228, 31.334595449509163, 20.936094022566273, 39.18233640732304, 42.30349186928042, 56.649094012475786, 60.188264308437226, 46.37622217978201, 0.984807926560602, 0.3110985614119038, 0.1948147035774685, 1.1692719089408075, 21.49743618503694, 75.94992053124213, 59.51733504572223, 61.99527671260219, 58.40561766778269, 58.5211314693574, 58.071710217383604, 60.04354453855946, 58.00108402006088, 60.235258225471746, 55.19970763114191, 55.29003197147001, 55.185296843128825, 57.58183756182271, 57.44316216438048, 54.420007121178415, 52.291077952231134, 55.50348735624745, 50.16386678141933, 51.9333028793335, 47.40272998809815, 46.972567573670425, 41.329339858024355, 40.39807896460257, 41.487454522040586, 39.4118421308456, 39.24270952901533, 39.94617092993952, 37.846165318642896, 39.13845292983517, 40.44496697764243, 40.865111658650065, 41.53911605958016, 40.313904900704664, 43.51935602003529, 41.22620897908365, 41.97710360250166, 41.31764727254068, 40.27029991149902, 41.771018351278, 42.49040849747197, 43.33730313085741, 42.358644316273356, 43.03511196567167, 42.9560762066995, 43.8598059838818, 41.9323964272776, 45.65368237033967, 43.68835133890952, 43.27701237893874, 40.69988573751142, 43.07832471786007, 40.79894127384309, 41.00057855729134, 41.172056736484656, 41.248915580011186, 41.178316839279674, 41.566666787670506, 40.845821442142615, 43.944227157100556, 44.017555867472005, 52.640349326595185, 53.161785294932706, 56.884902984865256, 46.05529777465328, 51.08868714301817, 54.69743636346633, 53.00623586100917, 50.99148296540784, 46.51542317482733, 47.623386844511955, 47.30380388998216, 42.88145311417119, 43.434519075578265, 42.61597141142815, 43.34568915828582, 42.49477017310358, 42.313666497507405, 42.4632578511392, 44.24963074345743, 42.80187999048541, 43.8023824845591, 43.21235602901828, 42.85678925052766, 43.22927321157148, 42.428619400147475, 43.796487162190104, 42.2516655921936, 42.04003018717612, 43.096500981238584, 43.4201475112669, 41.5917464225523, 41.373646951490834, 41.35210137213431, 41.91279634352654, 42.33009338378906, 41.19679120279128, 40.703376646964784, 41.09198154941682, 39.833830325834214, 41.205389038209, 40.49666381651356, 42.91991979845109, 43.00979698857954, 42.540210831549864, 46.936701420814764, 48.33842708218483, 46.93340662987002, 44.77363586425782, 43.89125554792343, 45.427404757468935, 48.45923216112199, 52.669441546163256, 53.340688520862216, 55.85140159053188, 57.63713513651202, 58.49926033327657, 58.18210924825361, 59.59796720935453, 60.046674589956964, 57.7131938165234, 58.40769260160385, 59.54776479351906, 59.245828582394516, 64.35608071665611, 61.92407392686414, 71.97232338689989, 28.014942561426473, 1.1525634700252165, 2.3845414528923654, 2.2862669585212587, 0.2877152290555739, 0.13586109684359643, 19.414567409023164, 71.61024155155306, 55.41694418076546, 53.05714038110549, 40.69177819836525, 33.75439974569505, 36.59289744592483, 50.86784985757644, 55.10635129867062, 53.74220978829169, 7.689254158927549, 0.3268529757136299, 0.11029432197251629, 0.029884524936337146, 0.0825604145985938, 0.045754857917105964, 0.03156407120367212, 0.03175518715814237, 0.060283156156900435, 0.04476665812093885, 0.08460892604724055, 0.03812305937190691, 0.04361993175060038, 0.0449849778576003, 0.04354703465416547, 0.07028307420231643, 0.004788223332950785, 0.2624412836326707, 10.64659232093442, 71.7555889006584, 58.71301774055728, 59.31934948890441, 35.4341547719894, 22.62261905977803, 31.585634985277732, 46.63623217613467, 58.703392244154415, 67.26763648371544, 49.23247644978185, 1.361168844084586, 0.4357347234843239, 3.229887240356015, 2.871624077520063, 22.935039766373176, 80.03938367289882, 61.60360059430523, 65.13040757948353, 61.47957917182677, 61.062305665785274, 60.08172096744661, 62.613763886113325, 60.38781881332398, 61.103133616908906, 56.95436031587663, 54.66267239662909, 55.57225042773832, 59.67448480667607, 59.081406747141195, 56.24229715716455, 55.39256665014452, 56.39509308722712, 52.81030170379147, 54.04870379355646, 49.92680657294489, 48.71155431193691, 43.70751996194163, 43.41447576399773, 43.72222100534747, 42.207068243334376, 41.737427173122285, 41.847959564578154, 39.78678934035763, 41.41499657784739, 42.192171081419914, 43.81401623449018, 43.137199494146536, 41.78310709614908, 43.948486851107695, 43.92935745177731, 43.906486111302534, 42.29921256342242, 41.208271980285645, 43.43583306958599, 43.77375310467136, 45.67859334330405, 43.875746496262096, 45.77906093289776, 43.765072899480025, 47.0093241045552, 43.074947557141705, 46.569959809703214, 46.0986791887591, 45.10647642997004, 43.381092471461145, 43.483748743611, 43.51730462043516, 42.866073500725534, 40.50046067084036, 43.09910151266283, 44.67666702885782, 43.874408968033336, 44.08232204375729, 45.218989618362926, 46.692239699825166, 53.94283117786531, 55.30446629370413, 59.503038006444136, 47.96594704351118, 53.50816196010959, 56.02193055614349, 54.25621286515267, 53.86896510278025, 49.99789168757778, 50.25379103998984, 49.3559330509555, 47.33286473058885, 45.80372479654128, 44.21059139313237, 44.61220679744598, 43.58265130750595, 43.90340705071726, 44.236839894325506, 45.25099615896902, 44.501395917707875, 44.525000741404874, 45.916002642723825, 45.7259088946927, 45.960980461489775, 43.96156795563237, 44.416190270454656, 45.25515387135167, 45.528150835344874, 45.292177123408166, 44.3571585993613, 43.315482985588815, 42.789371552005896, 45.407384980109434, 44.07252004069667, 42.78000885440458, 42.631935458029474, 43.34961937319848, 42.324115691646455, 41.74137307751564, 43.315769318611395, 43.042395807081654, 43.666664554226784, 44.646849170807876, 44.80250450872606, 48.793978998737956, 51.0495928795107, 49.02668145395095, 46.17163527396418, 45.391817092895515, 47.49093232616302, 50.06333643390287, 54.64621805375623, 54.295958242108746, 59.83504310730965, 60.3137997658022, 60.66913904682283, 61.439461169704316, 62.49708514059744, 62.87905731508809, 60.02213624215896, 59.94240622366629, 62.02841681818809, 60.99806116473291, 66.18284225463867, 64.29422493903868, 73.98452281951904, 30.564104664710264, 0.6785527568671011, 3.2171571879617633, 3.912213685051088, 0.3623673103509411, 0.18032476336004274, 20.33369445031689, 77.59927718870102, 63.255240071204405, 54.27127868898454, 35.003913910158225, 38.059585402088786, 45.679530789775235, 59.88399820943033, 62.00301554895217, 64.83815570031443, 11.055579819986898, 0.3495353069757262, 0.13203620369876587, 0.051513582978758125, 0.057005403007590966, 0.0035198970234036567, 0.09191120719356884, 0.044433226012775016, 0.06426650309754957, 0.16147962861484097, 0.2051443420350552, 0.1284313463275471, 0.21809135052946307, 0.19931124132727424, 0.1802692526290494, 0.31228262690767167, 0.16422576270997524, 0.3771817347695751, 14.895484120615068, 83.68412848441832, 67.70149769321566, 67.4448020996586, 42.46838046658424, 29.798650203212617, 48.58606200064383, 56.948425769805915, 65.5739962670111, 72.90968356593963, 56.547936085731756, 1.6284277482378868, 0.5724470052988299, 2.3512890694602846, 2.310107859873003, 25.4303712614121, 81.58673517165646, 65.00885725021362, 66.08778753588277, 64.65670685614309, 63.64670045914189, 62.34320271399714, 65.22725482140818, 61.34109989289315, 64.27523282266432, 57.8664251296751, 55.84301948547364, 56.556027935397246, 61.52069345597298, 62.34471282651348, 59.668432589500185, 57.406625286225356, 58.70593394002607, 54.918073608029275, 58.049101675710375, 51.66719359736289, 51.71310886260002, 46.33100901880572, 45.254114443256015, 47.65296543798139, 43.734286215997514, 43.76411584115798, 45.40625141512963, 43.3779114292514, 43.41271461979036, 44.6274059818637, 45.39416659262873, 46.64885828571935, 42.07836743324034, 46.145343626699145, 45.574450492858894, 47.83604598814442, 45.25295342168501, 43.71315640787925, 46.271247786860314, 46.84046999100716, 47.35846996307374, 45.564071901382945, 47.217601960705174, 46.31381334797029, 49.83242257948845, 45.22379452182401, 49.23479064818352, 47.97867513472035, 47.67995918950727, 46.41687754661807, 47.53721629419635, 47.29598268385857, 44.26247258340159, 44.02108207825692, 45.30193598039689, 46.4557796139871, 46.22834097954535, 45.53082981417256, 47.91410507694368, 49.09229486219345, 57.597444672738355, 57.60292030149891, 61.578375831727065, 51.518265124290224, 56.9029184310667, 58.12600758767898, 57.43063019167993, 56.476823514507664, 51.48686262869066, 52.027914370259936, 52.38782321253131, 48.264270751707016, 48.46255440865794, 46.78211688995362, 48.14481496810914, 45.45324925453433, 47.71795126699632, 46.925522665823664, 47.38911151885987, 46.51951420691706, 46.74372865307716, 47.319469836450395, 46.50933173394973, 47.75177386499221, 45.547617558510076, 48.03243906267228, 48.53085856283865, 47.764800056334465, 48.427217775775546, 46.69140815734864, 45.431507556669175, 45.04893525954216, 47.24411326069986, 48.06927011859033, 46.06372302578342, 46.03496420768, 45.41617893403577, 44.61914154791063, 45.49866637875957, 45.72633643304148, 45.756617130771765, 46.188666205252375, 46.60468455283873, 47.459561209524836, 52.05335878556775, 53.97771673817789, 51.991722660679976, 49.036887461139315, 47.66095138365223, 50.086399970516084, 54.145947194868526, 59.072577491883315, 56.59021531381915, 61.392231910459465, 61.56426706621724, 63.84295232834355, 62.765677282887125, 65.1607745693576, 66.04115839927428, 65.28066181367444, 61.829399678014944, 66.26760467406243, 64.23632683292513, 71.73269794833276, 66.57332989477342, 79.59706583330708, 32.53653714733739, 3.3413355052471165, 11.361029494193293, 6.026645773841489, 0.9756997540112465, 0.3070456498572904, 23.907260010319373, 83.18362620569046, 66.4424325573829, 66.3285739960209, 54.207975556773526, 47.326777212081424, 54.613497641778764, 70.02435668822258, 73.22390464044386, 74.7432190372098, 15.15983618074848, 0.5735576489279347, 0.2457309448190274, 0.16478954213521174, 0.16602308158912968, 0.14914595011261203, 0.1390373893082142, 0.07032629688300433, 0.12828498522961332], [0.03770510095261759, 0.06833098257981962, 0.04220882077671347, 0.0797821507759152, 0.03891805179357048, 0.04824755863556939, 0.06257150675200167, 0.009650048563226817, 0.040300001630619656, 9.24654935636828, 59.70922523929227, 50.06838060194447, 50.36032653624012, 27.415378862811675, 25.839645093487157, 39.019832611083984, 40.28545594984486, 58.05590698795935, 61.813619982811716, 41.465293130567, 0.8100041290444713, 0.30993521093360843, 3.4380248717723356, 1.69184940957254, 7.296315527731373, 75.32265509328535, 59.690664583636874, 65.50547246010073, 56.649933399692664, 66.58304168332008, 59.014067496022875, 59.64497289349956, 56.864898896986446, 61.735996277101584, 53.40254822084981, 57.46723375012798, 58.53257694552022, 57.93852613818262, 54.429452188553356, 54.5721911614941, 52.485333335015085, 50.54132038547147, 46.72050822165705, 48.05645965760755, 45.71862505328271, 46.540561645261704, 43.627797788189305, 42.89506373866912, 40.30544827061315, 42.857942427358324, 40.98509696222121, 39.34780943778254, 37.81709663329586, 40.1406773444145, 39.37952180062571, 38.67018861155356, 38.697300034184615, 38.128387697281376, 40.80188305147233, 41.16843246644543, 40.82647239008258, 41.35896159756569, 40.87548632775584, 41.365535489974484, 41.35006958438505, 41.81484299321329, 42.18693471723988, 44.911742518025065, 42.73300317025954, 43.59602266742338, 42.76583340860183, 42.52789458920879, 44.361955658082046, 42.79913825373496, 42.87461642296084, 41.758231424516254, 41.378028238973315, 42.9307573072372, 40.39567455168694, 42.135794854933216, 41.71776825381864, 43.28914034751154, 43.38636021460257, 44.16266787436701, 41.57105591989333, 49.10792550733013, 49.83558008747716, 59.59827315422797, 48.77651268436063, 47.72504683463804, 56.09329808142878, 50.83696511483962, 45.667728377926736, 44.231654520957704, 42.90498341283491, 41.83968336351457, 43.86881566816761, 41.80593136818179, 41.04659972652313, 39.88343261903332, 42.11999554787913, 40.75385362871232, 41.91662065444454, 41.907544289865804, 40.622615045116795, 42.23636050378123, 43.69080282026722, 42.57963457415181, 43.3230649271319, 40.89793012988183, 41.08356414302703, 41.156798716514345, 42.79021093922277, 42.3415937731343, 41.10174040640555, 42.88862320684618, 42.48031231664842, 40.968819126006096, 41.34332310768866, 40.83753739633868, 41.31428580130301, 40.90808906862813, 40.705212316205426, 41.94388897188249, 39.90782976150513, 40.75121779595652, 42.18624438008955, 42.84081343681582, 41.41004262431976, 40.522076852859996, 43.51129947170135, 43.332992446038034, 42.31424700829291, 42.54480000465147, 42.53740241450649, 43.194536701325454, 45.78958857444025, 48.29403369657455, 50.120018605263006, 50.56797681316253, 52.43162432024556, 57.38035325081118, 54.902238999643636, 55.24219474484844, 51.7262605697878, 50.1769910320159, 50.77819232017764, 55.71325179069273, 59.93248262713033, 63.7923929768224, 68.9113135491648, 42.08711039635443, 0.42735218941684694, 1.2407430093134604, 1.8174376963607728, 0.12754518178201493, 0.1378581195228523, 10.70089263300742, 68.09597046144548, 62.901383446108916, 56.17132579126666, 50.80921042350031, 46.20819568634034, 42.377471693100475, 64.3476240865646, 54.69628318663567, 59.327660991299545, 9.428677751171975, 0.5077628923519966, 0.10391415021712742, 0.0553382424667718, 0.026288492898006114, 0.05927743976034465, 0.06800746364939599, 0.0548809492630103, 0.058314670252824025, 0.034205603653625134, 0.036606304873261726, 0.09552502013262242, 0.05189769946399236, 0.03635392103704714, 0.05385386284380671, 0.08293617306457413, 0.00800521134571623, 0.11101208507053315, 13.427532180663079, 70.83256106222831, 57.20862011755667, 59.282628259351185, 35.584667882611676, 29.473052294023578, 36.8487105061931, 44.22082485691194, 62.147856912305286, 68.7869587252217, 46.033650213672274, 0.6501620286895383, 0.24921666019626204, 5.9491868076785925, 6.7673245841457, 9.924839927304177, 77.41444726144114, 61.47850836476972, 66.81073527182302, 59.00961560587729, 68.55471518731886, 59.806401960311405, 62.91127174131332, 60.96587027272871, 63.47121361763247, 55.32114028930665, 59.21335920210808, 58.25919951162031, 58.48362184339955, 57.45689830472393, 55.52225589752198, 53.55588543799616, 51.931749620745265, 49.06517167245188, 50.05438166279947, 47.69463669869208, 48.21904582362021, 45.39122481499949, 43.48993824374291, 44.1398161457431, 44.692901719001036, 42.30420966302195, 41.257172169223914, 40.17483334387503, 41.49904120352961, 41.444810513527166, 42.74021640900643, 41.165678962584465, 41.348006417674405, 44.083569357472086, 42.163910404328384, 41.87755776989845, 43.003489817342455, 41.427304975448116, 43.89095352542016, 43.32191175030124, 44.407047225582986, 44.03117825908046, 46.781151986891224, 43.654254175001576, 45.48004688755159, 44.25484357341644, 43.81704038189304, 45.132046361123365, 44.471032850203976, 42.518371074430405, 43.47704933535668, 41.937389604506954, 44.582173209036554, 42.47043186618436, 42.80406867304156, 43.90526233180877, 47.23601356629403, 46.00660939370432, 47.28174055776289, 45.3879653253863, 50.81377998475106, 54.202041010702814, 61.540870128139375, 49.000911481918834, 50.467148365512976, 57.79495562276533, 51.38919561139999, 48.36529139549502, 45.109386828637895, 45.30003363086332, 45.827286474166385, 45.965710839917584, 43.76853635234218, 43.169311938747285, 41.268805919155, 43.468071030032256, 42.84381012762747, 44.26524569911342, 44.12232629714474, 43.552919741599794, 44.06428698570498, 46.68435181340864, 46.4711239261012, 45.09067320054577, 43.599270389926055, 44.32652488831551, 44.16894758901289, 43.28279787494291, 43.897801983741026, 43.90533293447187, 44.81352636891027, 43.09643430094565, 43.0642943997537, 42.18800160192674, 41.76590750294347, 43.98303116521528, 42.870776422562145, 43.392306527783795, 42.271238219353464, 42.809340338553156, 43.06925619802168, 45.46504774401265, 44.68110715189288, 44.73758536000406, 46.062620839764996, 45.286332791851414, 44.44456861865136, 43.92338368200487, 45.171572085349794, 44.3835404611403, 46.09742403030396, 48.10037059168662, 50.59995981954759, 52.591500128469164, 52.10446726891303, 55.35556300993889, 58.576938952169115, 56.932136166480284, 57.16770587428924, 54.18151132522091, 53.826509368035104, 53.11640739440919, 57.69853984155963, 62.75942502483245, 65.32936196173391, 70.38339476431571, 43.92193632741129, 0.8110348543813153, 0.6661603960298723, 2.9522108887472465, 0.49249279883600056, 0.13297000359142983, 11.53213014525752, 75.4630131875315, 67.72674991238502, 61.687311818522794, 49.47108207210418, 48.06312768690048, 46.176491168237504, 72.36257568482431, 60.875663603505785, 69.7899087782829, 14.300013415275084, 0.5335800554002486, 0.10123733175738205, 0.030636499605832562, 0.018156243585831216, 0.055432547890250726, 0.02777520717392045, 0.05796451444527315, 0.035992810172179056, 0.06660852581262589, 0.17948526889085772, 0.20432102734283095, 0.2860891614710131, 0.14255063788544747, 0.16174320882606893, 0.18419071881761476, 0.09314074000764279, 0.16624394473769974, 17.608380663779474, 81.46230190030991, 65.64780742891374, 70.49140899412095, 40.52832518854449, 37.45070411312965, 53.26537509118357, 53.642271718671246, 65.7541036605835, 75.34397709754207, 50.15244091710737, 1.1189333133159147, 0.5502126822548529, 8.123075654429774, 5.303245984738873, 9.509013775856266, 81.04688367535992, 64.19320037288051, 70.11754435877647, 60.15180195531538, 72.31550724275651, 61.22028696921564, 63.07102203369141, 62.06619708768783, 64.34631401492705, 55.25960614604335, 61.48729055158554, 60.726185998609, 62.87708044052125, 58.60139493019351, 59.14543944020426, 58.135640928822184, 53.10497760772706, 50.96634841734364, 52.46737280199605, 50.31405825768748, 50.30179692852882, 48.935411822411325, 47.50766907968829, 46.24574061362974, 47.848640718767726, 45.731321765530495, 44.33363614543792, 43.456221549741684, 45.25980972474622, 45.18029543661302, 44.18707286157916, 43.43182440726988, 41.695120488443685, 46.64550465922202, 45.26963133965769, 45.01171981134723, 46.236126884337395, 44.375440766734464, 45.33322080489128, 45.103966113059755, 46.45715636591758, 46.01426586028069, 50.87086223786878, 45.820908700266195, 48.61526404657672, 46.20286910764633, 46.047037263070386, 48.980691663680545, 46.37493956473566, 46.43152367684149, 46.421341203874164, 45.44674204241845, 47.44928459967337, 45.09436022850775, 45.567515742394235, 48.06442599142752, 48.925656887792776, 48.53437300651304, 49.4221269699835, 47.34723237253005, 54.183476432677246, 58.47563589772871, 64.09944395865163, 52.48949496976791, 51.77011266831429, 58.97525956553798, 53.716757528243534, 51.32451964962868, 48.31462221760904, 47.61914676235568, 46.49207722756171, 48.74733809501895, 45.53276354266752, 45.67065838844546, 42.596798866025864, 46.77213445786507, 46.19909186517039, 48.54521443766933, 45.76663486419186, 44.809556930295884, 45.96019598745531, 49.102869572178015, 49.15895162090179, 47.90484436096684, 45.0840953857668, 46.32582756780809, 45.82101068189068, 46.71269093790362, 46.049014137637236, 45.36775727425852, 47.05673379282798, 45.81869256111884, 45.5358975164352, 45.55421106276974, 45.08010633530156, 47.1393467533973, 45.66885802053636, 45.46474179913921, 45.86704754060315, 44.9978816893793, 46.085923640958725, 47.37931343816942, 47.13311802956366, 47.38790342884679, 47.38214538943383, 48.159920015642726, 47.98739064124323, 46.25859422068442, 48.2419446206862, 47.88220444033223, 47.80816970332977, 50.69473605002127, 53.48294896464194, 54.91754408805601, 53.77803671744562, 58.86214625450873, 62.3242223647333, 60.15929760471467, 61.12382804193805, 55.88607142048498, 56.24853372573853, 56.00165974709296, 60.745801771840746, 64.47900387548631, 68.95640511666575, 72.15013227155133, 46.92021569898052, 1.9938629649339186, 5.196594288272243, 7.453325554247826, 1.1563146042246972, 0.21723717781564883, 13.493782974058583, 83.09850292821085, 73.68335539294829, 72.21880512852823, 62.93931276567521, 62.36419916152955, 59.111177536749075, 81.57086526193928, 70.55452777493385, 81.10909246629285, 22.40278590110041, 0.8514741844227238, 0.2967462105856788, 0.12407361604874173, 0.14809431057543526, 0.10477916307507024, 0.1426854080730869, 0.14298628144446882, 0.1602204711807351], [0.03983265735329159, 0.05323775195246262, 0.04792597024671493, 0.039253341664950696, 0.03820047638709507, 0.043902733107848514, 0.030817597045473037, 0.04340812376129531, 0.004218259662945545, 12.021713526018205, 64.48275758374122, 51.86135484326271, 48.429249563524806, 27.92232167336249, 23.554948799071774, 31.611379461903727, 39.8958194640375, 58.349971002148045, 63.147610233676055, 37.923663508507516, 0.17319177998410118, 0.0691011154483403, 4.527159938889166, 5.437647469582097, 0.7255011376354003, 53.3288743419032, 65.92615450582197, 59.76276559214438, 63.05457161318872, 52.06289406745665, 55.4300880432129, 57.67776696912704, 57.93823588278986, 58.10796468488632, 55.031332046754905, 58.779913763846125, 57.986061342300914, 55.366467199017926, 54.81923772442726, 48.15141239473897, 47.42437362670899, 48.338219196565696, 47.25865348692864, 47.5842337454519, 43.88077105245283, 43.40014342338809, 42.04034005441974, 39.90478600225141, 40.753563373319565, 40.04792113457957, 40.14299546518634, 37.259759210771136, 37.75049086539976, 40.124246535762666, 38.96203648659491, 38.240489036806174, 39.35432841700893, 39.22129731024466, 40.91197221509872, 39.189373139412176, 42.359201292837824, 41.66937012826243, 39.49140740979103, 40.74060778464041, 43.58857800883632, 41.364190117005386, 39.72567489070278, 42.84324922869283, 42.902731972356, 41.78800221412413, 41.60252509578582, 42.701090766537575, 42.56145438840313, 43.74014231466478, 41.20984877309492, 43.507722270104196, 40.19102096557617, 42.908788111902055, 38.331503714284594, 42.60476127747567, 40.07054536573349, 40.14140298289638, 40.932823534934755, 43.92567826855568, 42.08504330727362, 47.036384536374, 51.50197159859442, 56.81025243574574, 44.731517453347486, 48.874799436138524, 56.242093193915586, 49.414807827241965, 46.08475477464738, 41.057798093365086, 42.078783204478604, 42.13003289315009, 41.17076235432779, 39.74216453490719, 41.862311517038655, 42.632719932063935, 42.68025121381206, 40.96488498872326, 41.945034303972804, 41.45816226159373, 41.42415923456992, 42.056798319662775, 44.34708203038862, 42.13799922697006, 40.95573017674108, 41.75983175154656, 43.06630265328192, 41.81127363635648, 44.036575440437566, 43.11762294461651, 43.548303111906975, 42.34953265036307, 41.72769969509494, 43.26924216362738, 41.094511478177964, 41.1935866263605, 40.52315942702755, 42.51228355592297, 41.69416735249181, 39.07617353623913, 42.197125034947554, 42.87661683174872, 39.64307369724397, 40.21916004919237, 41.65881503012873, 43.209551534345074, 41.54786294506442, 40.3378156692751, 39.994439617280044, 41.25227705124886, 41.01522468751477, 43.599662626943285, 43.719789135840635, 43.93304447973929, 44.59566224005915, 47.47215201777797, 45.894449218626946, 48.85351665558354, 46.10132286625524, 45.90954249905002, 45.641303370075846, 50.735058015392674, 51.82869718920801, 60.39474179667812, 62.8913539455783, 71.54568718325707, 70.95896336340135, 50.95009019297939, 1.066016862469335, 0.9089012383933991, 3.1481423493354552, 0.15848063953941868, 0.19398791084606803, 4.9761820896979305, 61.047851731700284, 67.18783978492984, 51.728366882570334, 52.93857497553672, 45.25209442261727, 27.63585136782739, 52.17597599952452, 48.994223840775035, 62.72513958715624, 14.680164629413238, 0.7545667586307373, 0.05323284898974723, 0.03572047357597659, 0.0672000682642383, 0.09208593652733872, 0.04999012521077549, 0.012842800426897744, 0.0356158297959595, 0.06313864930322574, 0.05356612404988659, 0.06101242589553999, 0.05257560683774853, 0.03458684730914331, 0.011322953805868185, 0.05337609594026881, 0.059752770504283334, 0.04668736695161751, 17.512831726381858, 73.30429753949566, 60.54556477454401, 58.35954943010884, 32.885569257120935, 30.763098270662372, 35.842195018645256, 49.07227900720412, 62.949393257018066, 68.09870827582576, 41.883558996262096, 0.031077459815048405, 0.1642065645465928, 7.49416184040808, 10.140138826062604, 0.7938674981555631, 57.721599455802675, 68.99270273024037, 62.56631889650899, 64.89620285649454, 53.56212592894032, 55.32869477425852, 58.651424761741396, 57.309181844034505, 58.085901352667044, 55.293907273200254, 59.80228739400064, 60.07119724827429, 58.82450719033518, 57.28505534510459, 49.47106638262349, 50.00131591673821, 50.415698635962706, 48.77224514561315, 49.89617678426927, 46.49812159999725, 46.74892187118531, 45.79917876951156, 41.76100454022808, 43.656486003629624, 42.31681616075578, 41.12801636418989, 40.29999225370346, 40.35887879710044, 41.59236223466935, 42.364355287244244, 41.309943737522254, 42.58757345138058, 41.53669203481367, 43.633269494579686, 42.56738893447384, 42.51585291277978, 41.95547957574168, 41.72960988936886, 42.27576855690249, 44.16211089780254, 44.23053272308842, 41.87011311131139, 46.24461881576046, 45.726454104146654, 43.149680476034845, 43.71318778684063, 45.98595027000674, 44.75764436106528, 46.13912666997602, 43.07328054981847, 44.310580453565045, 41.387155594364295, 45.4086793622663, 42.75236006705992, 44.55266521823022, 43.49606890832224, 43.29279991888231, 42.823872720041585, 45.95453600729666, 44.70961493830527, 49.25803461382466, 53.88779247960737, 57.581453169545824, 50.07952013323384, 49.437518350539676, 56.99195623397828, 52.71295632085493, 47.486574572901574, 44.250266167425345, 44.4173316801748, 43.53053869739656, 44.771560930436664, 42.281844308299405, 43.604765630537464, 42.985038988051876, 44.62250694151848, 43.544004194198116, 43.48985195159913, 43.11895262810492, 42.884383124689904, 44.51943097576019, 45.00905652200022, 42.98356809923726, 43.09099397351665, 43.267473174679665, 44.30530094331311, 43.3149613103559, 45.12021257031349, 43.91489175058181, 45.295993589585834, 43.506369052394746, 44.324481333455736, 45.54192227701987, 42.425591330374445, 44.52102738042032, 42.1159751184525, 43.28042876335883, 43.668480611616566, 41.92427319865073, 43.36037843458114, 43.852839854455766, 41.73809397605158, 44.347227158085, 43.63463447939965, 44.984569165014456, 43.94193649291993, 44.273568968619074, 43.729242047955914, 43.93480562394665, 44.19816532442647, 46.03221070381903, 45.91950139691753, 45.414315808203916, 46.29391516408613, 50.49957459972751, 48.24560811442714, 49.089819846614716, 48.94831249790807, 48.88653909006427, 48.98958367686118, 52.39865679894724, 55.372225238430886, 61.600482310018236, 65.27076567372968, 70.19592115955969, 71.424587926557, 52.88608581789079, 1.633138882537042, 1.0696649118777246, 4.60695271530459, 0.42035661157100435, 0.21974741811713866, 4.979602886784462, 66.75118584786692, 72.31259684408866, 59.30478180608442, 50.584227192786436, 57.468512442804155, 37.89850542622228, 58.075185437356275, 59.208162061629764, 71.13525821316627, 21.82950992738047, 1.1225385843746125, 0.07338532426905248, 0.010043359061162318, 0.023052548997164257, 0.014183617088072484, 0.051813299557374376, 0.04880492590487965, 0.010592692940976593, 0.2322488239095096, 0.13293436518119228, 0.09832384575518871, 0.14849413186311722, 0.12353787544153391, 0.1853119038165577, 0.19765037802919266, 0.16590971589809464, 0.14718839628321512, 23.021728069551532, 84.46926147707048, 68.81935750284504, 65.11271769000639, 37.88513014393468, 32.74788425814721, 42.96946717846779, 57.09462427323865, 67.87063813978627, 73.75473468534409, 46.04506431087371, 0.2958333402151062, 0.10550750584732141, 10.17362606140875, 12.481475126358772, 1.3443375859529743, 60.52359950157904, 70.24832402506183, 65.85641476415819, 66.95017553144886, 54.74182582670643, 57.30215295668572, 59.891976310360825, 59.18882085431007, 60.099124523901175, 57.771393945140225, 62.38709011385518, 62.57179060289937, 62.35109844515401, 59.623505761546475, 52.183769749056914, 52.71138345041583, 54.58924170463316, 51.83317653594479, 50.788198286487216, 48.834610831352975, 48.86242828061504, 48.713115415265484, 44.56953533234135, 47.668564704156694, 45.131775717581476, 44.28431626289122, 42.156587339216664, 42.53026370079287, 45.285387500639885, 44.57000601676203, 43.398009654014345, 45.141797373371745, 43.0268043856467, 45.59756502028435, 44.27176467833981, 46.162955068772845, 45.186845794800796, 42.884402736540764, 44.93485312308035, 47.76847531718593, 44.91840270257766, 43.7215934261199, 48.042452873722205, 47.06533555061587, 46.04543693604008, 44.333220374199655, 47.44844521245649, 46.654890891044374, 47.45889440659554, 44.229320710705174, 46.165955681954664, 43.32854055589245, 48.516557601190385, 42.844394560783144, 46.94902550789618, 45.566052698319965, 45.48791908448743, 46.013520609947946, 48.16859237609371, 47.76765554181991, 51.19654447801652, 57.994941588371034, 60.460143396931315, 52.31697736247894, 53.23658489411878, 60.521344138729965, 54.516972034208244, 50.900852680206306, 44.85877875358828, 46.380497563269834, 45.700511547826956, 45.34871416707193, 43.71840846153998, 47.0433702776509, 47.03714547618743, 48.09002337917205, 45.66945422080256, 46.38498083237679, 45.85960288201609, 45.07116725367885, 45.777582199342795, 48.492078088944965, 44.9406974546371, 45.80130861651513, 45.60939881109422, 47.02939095035676, 45.98452252726401, 47.70132041746571, 46.44678954155215, 48.112820194613555, 46.16854444626839, 45.36159130834764, 47.975509781991285, 45.42133292844219, 46.143598171972464, 46.16656364933137, 45.67960531480851, 46.063440615131015, 44.725653509939875, 47.10505739335091, 47.41897644535188, 44.23330191643008, 46.4859583300929, 44.870914566901426, 48.42511146299301, 47.803717813184186, 46.027962776922415, 46.718574493162095, 46.10765749408353, 45.0571055566111, 48.29023291987758, 49.94604187626993, 47.837379594003, 49.997091524062625, 54.51842723354217, 50.31199509097684, 53.23941684538319, 50.10757684707642, 51.11637123169438, 51.38595573363766, 55.46914700538882, 56.86261607754616, 64.14057393227854, 67.58851774277227, 75.7387165869436, 74.86433398339057, 55.73510723729288, 1.462216331593452, 3.6042698737113708, 10.999569354518767, 0.92496469256378, 0.3621735207496151, 6.275501039720351, 72.96164712598248, 76.05111768168788, 66.3459030274422, 63.76611309666788, 58.965983160080455, 43.32264523352347, 70.86990202626875, 67.68990316698628, 83.31009126478627, 31.502072811126713, 1.824102538727945, 0.18970400846052557, 0.14359784943442191, 0.23190822121837448, 0.17006644768820656, 0.14353647046992857, 0.08878612004580999, 0.13680333902518596], [0.07393223443819631, 0.020521813928480112, 0.07384922881160053, 0.03644872824811647, 0.015034812592690992, 0.06471326259235222, 0.02462912538659669, 0.055727997359128735, 0.17914204617902157, 11.402534054171655, 60.35713803383612, 47.16260248614896, 48.27266462387578, 32.444736034639426, 32.76807661979429, 33.061399306020434, 45.24391235843782, 62.08067455599385, 62.82088464306247, 35.04196482319986, 0.0451161474319956, 0.03641832987928102, 7.109070891334165, 16.78749526700666, 0.2993425744916162, 14.993867951054728, 69.53356619804137, 61.274854983052904, 45.6160197719451, 39.20583532702538, 65.96797481659921, 56.446229027163604, 62.85736268566501, 54.48976255232289, 56.36289435048258, 56.39662281159432, 57.25798706854544, 54.12484092097129, 52.45455449627292, 45.86019515991212, 49.771335586424804, 44.18886930711808, 44.24906592215262, 44.62969664604434, 45.336213573332756, 40.211444747063425, 40.87066573481406, 39.8886925174344, 42.29378008073376, 37.829208912387976, 39.38563677572435, 38.70706281354351, 38.95840829418552, 38.190412136816214, 38.70652152645973, 38.339042509755785, 39.34564821181759, 38.437901927578835, 40.813697230431345, 40.092349821521395, 41.300655564954205, 39.91666293913319, 41.09218159029561, 41.21019001929991, 40.698328556553015, 40.12528596385833, 40.782443784898334, 43.36818787359422, 44.223954908309445, 42.36361395928168, 41.10048132558023, 42.14398476385301, 41.57122065944057, 40.599261253110825, 43.72202488683885, 40.39498813690678, 39.37313618198518, 42.00732154230918, 40.942503944520034, 40.547399674692464, 40.57083191410188, 40.97198840110533, 41.45979788995559, 43.26113070211103, 43.11082939947806, 50.24184742281514, 52.34910941893055, 58.97497715488557, 50.60969906468546, 46.84882856184437, 56.128670015642726, 51.67255547738845, 50.85018350232033, 45.03367331720168, 43.125581433696134, 39.48012667317545, 41.28853936349192, 42.38513600441718, 41.540045661311, 41.58584325544296, 42.00642724190989, 39.625811346115604, 41.53281673308342, 39.58633269033125, 42.76260529795001, 42.554492181347264, 42.55290754379765, 42.611699950310495, 42.04401923764137, 40.671232823402654, 40.383648564738614, 41.64959353785361, 42.85514185505529, 40.02946638291882, 41.9658346329966, 41.69894872173187, 40.2375324310795, 42.2546269816737, 39.745828028648134, 41.81632564913842, 42.13619493669079, 40.97494979058543, 39.736088783510276, 41.57853587981194, 40.73978408690422, 41.42869349448912, 41.96244178279754, 41.719831420529275, 42.002653921804125, 41.49816259261101, 41.73638382265645, 41.8607896374118, 41.57507634931996, 41.77813353077058, 42.36080946460847, 42.35785984223889, 44.651238303030695, 43.67691762985722, 44.18945766264393, 45.18515133088635, 44.06919779316072, 47.47600770765736, 45.07868251492901, 48.536467552185066, 53.5096485384049, 57.49637696050829, 60.041198961196415, 61.68037314568797, 62.45623757762294, 73.78604304405951, 74.66846650646579, 56.765313840681515, 3.164166457230045, 0.20465335628438383, 1.2542566777237, 0.4113758854087322, 0.08740259589807642, 2.7046002399536873, 54.31477777419552, 69.80100124113022, 54.05817631752261, 70.50780450144123, 28.91820949892844, 13.171598507512002, 39.09846828829858, 48.46621398002871, 62.77838576224543, 27.638349917627153, 0.797120430056126, 0.13009536590787674, 0.02073024921569853, 0.0657709159197346, 0.11597969794585822, 0.07214398604006537, 0.08082869582839551, 0.05814058443291053, 0.03415962688684945, 0.05791006091561529, 0.009088498453849988, 0.054901832819826184, 0.0548379066129846, 0.09030595421791078, 0.09306239985650586, 0.08801703671774558, 0.1879134311551048, 17.315083472959458, 71.42198347276258, 54.94168627646662, 55.12648874713529, 36.30985136955015, 33.337577312223374, 37.9228868792134, 51.620293817212506, 66.41952591557657, 69.22134553232502, 39.36024727359895, 0.09045362532619508, 0.05365358447776206, 9.39868534764936, 18.81112840867812, 0.6984819519904353, 16.70705137714263, 72.75433417289489, 61.74948530812418, 47.711667629980276, 39.78194129082465, 66.31865824422529, 57.96060123751241, 63.26251606787405, 55.64568896447459, 57.45816523028959, 58.78296929021036, 60.24833932999642, 55.86440032528293, 54.5633932851976, 48.07152548143941, 53.28160585895662, 47.45855316039055, 46.697499598226244, 46.831534831754624, 47.07618090414232, 43.23409380451326, 42.0518365213948, 43.29700077733686, 42.92567783786405, 41.23139043008128, 41.18906413355182, 39.67480567193801, 40.030078272665705, 39.65041637420654, 41.4263165381647, 40.914874769026234, 41.310869416882916, 41.04417177938646, 43.6767646574205, 41.93047838826334, 43.054837565268244, 41.608581235331876, 42.01879839743338, 42.645769657627234, 42.99032242067399, 42.042258093434, 42.79763990832914, 45.251156976146085, 45.164496129558934, 44.271694075676706, 42.41937437365132, 45.30154766574983, 43.30007591555196, 43.19078691544072, 45.23429862914547, 41.994154145640714, 41.73115138084658, 42.61106452634258, 43.71514897192679, 43.7631352486149, 41.59028337847802, 42.19475592336347, 42.947584275276434, 44.96885222773398, 45.52701727036507, 50.107110085025916, 52.0201559220591, 60.07425669700869, 52.91829239937567, 50.53592320411436, 57.719885380037375, 55.09523922397245, 52.82905455558531, 47.530265854251006, 45.49904684866629, 41.7416751000189, 43.00536078791465, 43.37422047891925, 43.534751322961625, 42.41187872425203, 44.59556418080484, 42.96634104944045, 42.864022101125414, 42.9557075039033, 43.715086214004025, 43.534253181949744, 43.59896052268244, 44.5576976191613, 43.97607680289976, 42.48532510572865, 44.38027312678676, 44.0447182809153, 42.68828030555479, 42.57806954845306, 43.771438906269694, 44.1233382686492, 41.98695267400434, 44.215094274090184, 41.18062711531117, 43.99743410848802, 44.05727771020705, 42.77574131565709, 42.4820577713751, 42.873863327887754, 43.57347296130273, 44.89533524359427, 44.30814858405821, 44.118337246679495, 43.55080950644709, 43.949840068817146, 43.124259594948064, 42.82090348582114, 43.58190997954338, 44.23087004692324, 44.53743465485112, 45.16946969493743, 45.98747999437394, 47.40929603576661, 46.67638547958867, 46.498039230223625, 46.093301619252856, 48.0238647614756, 47.24185397548061, 51.429713695280014, 56.692342065995746, 59.401507454533736, 63.51453227381553, 66.07701670738959, 65.91231638385405, 74.16403401282527, 73.00286339175317, 56.80017586677306, 3.455564975738526, 0.8432547964396016, 3.647634617743954, 1.190300593453069, 0.055809421014160886, 3.050380214568108, 58.35077901040354, 74.77794770271548, 62.23056793212891, 69.97197735694148, 42.19226914067423, 26.89034608102614, 48.68182274603075, 57.40366389674526, 70.50396057867235, 36.84269359034877, 0.9646053299788506, 0.09894651435916463, 0.02398632207675086, 0.03499172094668593, 0.06598451655478248, 0.04082646108262482, 0.08508917124521348, 0.07109789297946038, 0.14526625103767843, 0.19279203227450772, 0.19426077604293826, 0.11511073973510536, 0.16915806659287022, 0.21223195768412084, 0.24626450973653027, 0.2054650111184005, 0.24172286472974286, 24.75196203877849, 80.19530573198873, 63.13702767895114, 66.65499364176105, 43.7189301367729, 45.462313852002545, 47.72598035873906, 58.47314127029912, 73.63510239508845, 74.69348338342483, 43.16864121344782, 0.2609498330181645, 0.11119197783691269, 11.680928199521958, 29.09167043624386, 0.45224134419714257, 18.905612422573952, 75.95885569049467, 61.26578646321451, 47.960502793712, 42.27143826023225, 69.36586918369417, 59.44917601923789, 64.3629252526068, 56.63194541008242, 58.00058980141917, 59.43778545625749, 62.05574004880844, 59.71719549548242, 56.58431606907999, 49.30207498611943, 55.57456462613998, 49.90321351635841, 48.52278632502402, 49.13386806364983, 51.35740872352354, 45.197314600790705, 45.4824826794286, 44.34014727992397, 47.56195468287314, 42.95153802441013, 44.55080209239837, 42.30373113386093, 44.01053482486356, 42.03031055388912, 44.75022323669926, 43.126522802537494, 43.744496145556056, 42.64649137373894, 45.894735551649525, 44.92409406169769, 47.28274860689717, 44.07851342231997, 44.8345188940725, 44.09504229022611, 44.90718080151466, 42.30677489311465, 45.87589248534172, 48.1660585249624, 48.33467729630009, 46.41173924169233, 44.84386590219314, 45.65590243185721, 45.36420752925258, 45.18812448747697, 47.76327033196726, 43.271772092388524, 42.993613289248565, 47.28703183512534, 47.943899400772594, 45.262547539126494, 43.69826709070514, 44.93930109085576, 46.22364982481926, 47.92110650770126, 48.69505682299214, 51.94701940782609, 56.183069367562574, 63.54222420723208, 55.83051104699412, 53.315659876792665, 60.1008778233682, 57.55893876475673, 56.42960602237333, 49.186165025157315, 47.515933513641365, 42.9956764559592, 45.69959763557681, 47.87592472568635, 46.99540361281365, 44.9460397228118, 46.91619134718373, 44.794110636557306, 45.233929926349276, 44.52685994486655, 45.67422774530227, 46.33969314636723, 46.51011620798419, 45.61922434837588, 45.37303286214029, 44.532500313174346, 44.72200570567962, 45.45636361645114, 46.75315018623106, 44.33705645222818, 45.702798289637414, 45.588782833468535, 44.21461966729934, 47.71173431027321, 42.8020368852923, 46.74107713084067, 46.55404675391413, 45.323159925399295, 44.62803748346145, 45.58321699019402, 46.18965072016562, 46.934328386860514, 46.79948514507663, 47.76765946419009, 46.45183763196392, 45.87507663234588, 45.08794323090584, 46.234228457174, 46.37186442652057, 47.04688472132529, 47.71977124675628, 48.077091324713926, 49.6744098970967, 48.85877655398462, 50.14476091630998, 50.94772500376548, 48.42452310746717, 52.41950027404293, 50.180191686076505, 55.2710045537641, 61.27099929317352, 61.962399405817834, 65.24678822486632, 68.24036075222877, 69.87092925656226, 77.25661108570715, 74.60217845055365, 59.80478594380041, 4.438242258564118, 1.2760287739576832, 5.469927105211443, 2.0524099781628578, 0.21086217715374886, 3.6827822414136704, 64.48871958640315, 80.60978258809736, 69.00997684847924, 79.92006517225697, 37.05611759616483, 25.97639068480461, 59.958762507284845, 68.67963483256679, 82.52865314483643, 45.792487205997595, 1.466723380069579, 0.15242906587739147, 0.1330116634527522, 0.2157279999265748, 0.21121042540236828, 0.21415001202014186, 0.17430150430769692, 0.165922662784015], [0.01901923780209355, 0.08792510616683191, 0.02788702536734843, 0.05357843508282977, 0.055027367817538406, 0.020774002412274, 0.008334856585509354, 0.006018270862348859, 0.05443106029903697, 15.829293574056319, 64.66177455840572, 43.54350997555641, 58.95912293464907, 27.20771485759366, 29.362392425537113, 35.994943880265765, 49.780000102135446, 61.45666860765027, 62.18964584412114, 31.078629416804162, 0.12443495673998711, 0.8074263963968524, 8.735504727209769, 13.334047390568642, 0.7832026962311037, 1.454778537154198, 52.308050047966745, 63.157878998787176, 51.48342271004954, 58.43034821171915, 60.32510011426864, 57.0089126402332, 61.60256901094991, 60.2937093857796, 58.23414733332973, 57.70155222185197, 56.51022641889511, 53.239459991455085, 49.8750195195598, 46.53093222648867, 42.40365743637085, 43.126236469514915, 42.110589704205914, 43.36485385894776, 45.595862711629565, 40.257689491395034, 39.39962002538866, 40.3379294180101, 37.82967959680865, 38.78754984947943, 37.776707987631525, 38.83156276518299, 35.62186764132592, 37.26070057961249, 36.939050536001886, 36.89450025558472, 40.97592253838816, 36.79242841659054, 40.347915772468816, 40.3773453158717, 39.60321064918272, 39.96127597747311, 40.4241156578064, 40.3006669013731, 40.906743695659024, 40.48374745153612, 39.89175981090915, 44.47664183955039, 40.76020786839147, 40.21061320458689, 41.33525479224421, 41.00594435968707, 39.166321369909475, 40.38895553158176, 41.172951036883944, 41.21407708814068, 40.61563714858025, 41.20735414566533, 41.562371792331824, 41.36872437692458, 39.156107517980764, 39.47277615147252, 41.53122817316363, 43.7812134527391, 44.02920138451361, 52.02190922152612, 52.34233548564296, 55.99598799982379, 43.75853430840277, 51.915205063358435, 55.69246715114963, 52.66453466107769, 53.71558866193218, 51.104506061923125, 45.20597519413118, 41.15855986072172, 43.18392276763917, 38.20185761297903, 41.03249880575365, 40.33257538272489, 41.67439076208299, 41.63367655969436, 42.97753941628241, 41.863986369102236, 42.901265005911554, 41.96930985296927, 41.38973651393768, 43.145813019044944, 42.27614510443903, 43.04429423424506, 39.97465910450105, 39.77383375167847, 42.35572999523532, 42.47600163182905, 41.974879618613954, 40.770515857204316, 41.721521962073545, 42.60250983699676, 41.94798392634238, 41.72454218710623, 42.17836041604319, 40.46178217857115, 40.2963875955151, 41.880766268699404, 40.311688761557306, 38.77755565028037, 42.76993620780207, 41.766809648083104, 41.82941459840344, 40.88841053747362, 41.32484482180688, 42.43612289428711, 40.73021742605394, 42.245260361702215, 40.548807805584325, 44.54449099879111, 44.914613692991196, 46.74924350553944, 46.39369633889968, 47.37131572538807, 46.81541781271658, 51.11790487843176, 53.148076611180464, 60.15668530617992, 57.86858243326987, 64.11646312282932, 57.46904196277742, 72.22021718179026, 75.10047635724469, 55.47173969207272, 61.68846891772363, 61.802672647660785, 6.4250923933521396, 0.718483956110093, 1.3734201221696793, 0.37055467585882834, 0.08106802935681998, 2.348523798488802, 47.72765521080264, 64.55049691661712, 60.48127320504958, 64.54951632407405, 34.67146558146323, 13.724493845816582, 31.07813519816245, 47.30599649490849, 63.161264004245886, 36.79766085840041, 0.7644756462785506, 0.04364866770864014, 0.04103834568072231, 0.026402086500198613, 0.016251249133699363, 0.05986255473427235, 0.07230322507600631, 0.05971588720116885, 0.027152004223617337, 0.04958130622042283, 0.001638537461047001, 0.09759557193085071, 0.06578218507310075, 0.01914644095626089, 0.020045161682872042, 0.036637837052225106, 0.023509855607464433, 24.506274577110048, 73.85836370529668, 51.14464759826661, 66.16967878034039, 31.280433400984737, 33.80874810680267, 41.575978494459584, 53.98081933298419, 66.80941735544513, 68.393968612917, 34.51602597390452, 0.1957256587282304, 0.6223125263087211, 6.717753179611699, 12.072208158431515, 1.2866192959970044, 1.634622151332517, 53.781774736219845, 59.49197300018803, 52.66758234270158, 59.924190736586056, 63.72123333715624, 58.960527143170765, 64.58547269144367, 61.399845230963926, 59.58982044650663, 60.75841219194474, 58.56043361848401, 55.379426710067264, 52.26630426222279, 49.39986359688544, 44.10942562164799, 45.153654698402654, 46.00242814710064, 46.17809934000815, 45.938301317153446, 43.877460572027395, 40.82908468861734, 44.167135453993275, 41.43936234135782, 40.794014776906664, 40.04110797759026, 40.9201229003168, 39.48719870659613, 39.81987061039094, 39.426794205942464, 40.31420300083776, 42.96212450150521, 39.92471948746712, 41.547733506848736, 42.418868387899096, 41.43432209568639, 41.28251068053707, 42.65369676774548, 44.92496090550577, 42.903402697655466, 43.43064377384801, 42.12808347517445, 44.25938567807598, 43.16166723928144, 43.277228109298214, 41.94078245470601, 41.35174443644863, 41.353960575595984, 44.317566194841945, 44.066012828580796, 43.90141056429955, 42.52457234167284, 44.05798373683807, 43.50052864320817, 42.40461841706307, 42.91820964505596, 42.174269383953465, 43.497488806324625, 45.807682468045144, 45.20486124100224, 54.254812579001154, 56.26486647513605, 57.466210011513006, 46.94914710137152, 55.123539124765706, 58.890642273810606, 54.580730161359234, 55.18780716003911, 53.10871954887144, 47.4379881735771, 44.63845137626895, 45.23975856842534, 40.67544152659755, 43.03065615315592, 42.424936294555664, 42.643435847374704, 44.110174794350904, 44.26424941708965, 44.30625800163516, 45.34538799716581, 43.59889384238951, 43.30545740742838, 43.3906199086097, 44.37407185954433, 44.095340390359205, 42.09738308383573, 41.669711374467425, 43.43232647065194, 45.448401205001346, 43.7188595341098, 40.5852387797448, 43.108393607601045, 44.583887284801854, 43.09259822291713, 43.38867833537441, 43.89581334206366, 42.49546835499425, 42.569267749786384, 44.21763596996185, 43.40744687664894, 41.652119544244584, 43.712352321993926, 44.60017296575731, 42.28871237847113, 43.18233420771938, 44.990684140113096, 44.88493311789728, 42.253658156241144, 44.3782844851094, 42.44586998416532, 47.57377278420233, 47.60951734358265, 49.88488035817301, 47.919259071350105, 49.663905789775235, 48.82123162669521, 52.875840587000695, 54.741857205667806, 61.38532069421584, 60.12391782576039, 64.9227886815225, 61.60704051294635, 70.92112033597886, 73.8824470581547, 62.57735644617389, 61.31989555974161, 63.894398135523645, 6.953842111172215, 0.508529072206828, 7.091574668884278, 4.627266670427015, 0.08846203421032237, 2.5231538472637056, 52.31807170375701, 71.52509473985242, 64.67837795134514, 69.28942218903573, 38.752417179846, 18.81465069709286, 37.47099453403104, 52.399417738760675, 70.41911971184516, 46.48442468335552, 1.1247700452804565, 0.0950829184523994, 0.05102401066030707, 0.006505925566964453, 0.012769625623590283, 0.058686510179071665, 0.03659553367704634, 0.012393731177003394, 0.17002860294474711, 0.13820279780174458, 0.08100378522348982, 0.24105071450673768, 0.28934598509823123, 0.13992997367055188, 0.16254191677416527, 0.1343596870860746, 0.15587413262936378, 34.65096727494271, 84.71206403547718, 61.24849665549494, 73.68114317617109, 38.11485159781672, 39.37594067665839, 48.247122149313654, 63.30246148570892, 70.99142489894744, 73.11225829585906, 38.513278115180235, 0.36436581924077005, 1.2081598802920313, 15.925895667845204, 24.749843958885442, 3.442891552563637, 2.779667295755879, 55.90826026854977, 61.906807653365604, 52.91027115237329, 58.48130764499788, 66.7463299535936, 60.830685784739835, 68.7219415172454, 63.4194383313579, 62.25856973278908, 61.6071032708691, 61.74506087456981, 58.58088485656246, 55.68975287099039, 51.4618928201737, 48.039424803949174, 46.58167200703775, 49.554546187000895, 48.95362730949156, 51.09485310892905, 44.789725426704656, 44.1280137338946, 45.8487065376774, 43.17322254180909, 42.20306350338844, 42.52853785791705, 44.64265223472349, 41.405123972123675, 41.65812861534857, 41.69469687246507, 42.37358070188954, 46.80094818915091, 40.7841343264426, 44.619043488656324, 43.95408015097342, 43.53078188434724, 42.97628425782727, 44.75560080620551, 45.55525833560575, 44.968632575004335, 44.088613525513686, 43.681012584317116, 48.25547679778069, 45.22180588014665, 44.1143560409546, 46.30455263199345, 44.402822832907404, 42.05985776839718, 45.44575360513503, 46.33462936647477, 46.15312953149119, 46.31273861854307, 46.29796305010396, 45.67099963465045, 45.913559006106475, 43.42501517265074, 44.53726991530388, 48.66876125335694, 49.18924408574259, 48.895529162499216, 56.71828854468561, 59.610224616143014, 58.74881329074983, 51.02410531813099, 58.678167481576246, 62.09685041058449, 57.93582754750406, 56.361686260469504, 56.35895629082957, 48.89157541336552, 46.09372523523147, 48.08985079488447, 43.96167385962702, 46.14711261564686, 43.679906475928526, 45.55251267648513, 46.427314973646595, 47.732934721054576, 47.41181419741723, 49.25055857627623, 47.180680690273164, 44.46998949973814, 46.41848179601854, 47.08102110893496, 45.28406173952165, 43.53474347822128, 43.42790203709757, 46.548653494927194, 47.02343679243519, 45.185527878422896, 43.3341456228687, 46.83512772283247, 46.43770140986289, 48.014478529653246, 47.669027543837025, 47.19031795378655, 44.43684547178207, 45.001474580457135, 47.2985283021004, 45.52902160152313, 41.555240923358554, 47.631392402033654, 46.82985997969105, 45.51577183508104, 46.23515805890484, 47.824988826628655, 47.424620736029844, 44.452684002537886, 47.00198142759262, 44.28322584398332, 50.43043105832992, 49.54184555238294, 53.11346953915012, 51.11996020040205, 52.28291942227272, 51.31140716614262, 56.29830075848488, 56.8542496619686, 64.99984756592782, 62.73608692230717, 68.69721489567911, 64.31673934382778, 70.3561342916181, 75.08024477189588, 63.82375232635006, 60.35335686899001, 66.1429988184283, 8.24640772035045, 1.4959014014851664, 8.131935308056494, 3.8193537775547277, 0.20337365237214874, 2.9107171152868583, 54.88292524891516, 77.0124121635191, 74.45516017175491, 77.32620177730438, 42.409454699485536, 22.07792735868885, 47.99895771088139, 65.97462715641146, 79.25232087412189, 57.185721320490686, 2.024784970187372, 0.2185877142173629, 0.148869683485358, 0.17116852645431796, 0.10272199483287912, 0.1481973034359755, 0.26480674863823, 0.24196946843256875], [0.032967364250291745, 0.018260027432153304, 0.012172689912990938, 0.008462959892987724, 0.03665323541950315, 0.09658390686156289, 0.04254151744047, 0.02258366105266877, 0.06357960568200197, 30.493678508266328, 63.27505588531495, 48.83511289473503, 55.58037365636518, 25.36674649484696, 24.216731094544937, 33.62597350151309, 53.994006341503514, 58.80515421590498, 66.53260784764444, 26.85252658782467, 0.12311786773704714, 0.8551806403744606, 10.022504002817216, 20.69518008539754, 1.77614469922358, 2.062780112028122, 54.01966256480063, 56.36278452411775, 64.82983635317895, 57.806126533016084, 55.79653939893169, 57.18184209639027, 57.750001338220414, 59.710970694018954, 59.82074214566139, 57.22872618705996, 56.657185862141276, 53.597380192049094, 46.22200635171706, 44.24792451243247, 42.00082609730382, 40.11850026346023, 41.09330338816489, 39.32412224431192, 40.03920170568651, 40.03358094922958, 38.303901995382006, 37.41321409902265, 38.466123380968654, 38.1030099622665, 39.29114687827326, 39.511403652929495, 38.42931978164181, 38.042562315540934, 38.93139493080878, 38.428362723319765, 38.42220460214923, 39.44423698609875, 40.44819116592407, 41.84064042183661, 40.91575730231501, 40.2037686686362, 41.29062998679377, 41.8064961894866, 42.30695924451275, 41.70509115342171, 41.2828323148912, 42.38281003890499, 42.338318594040416, 42.44714867684149, 40.83695688555318, 38.1465051251073, 39.285879135131836, 40.780592426176995, 39.52047217276789, 42.38148035541658, 42.73384647984659, 41.65836395755891, 42.34644574503745, 39.734759100021854, 39.47340765307027, 40.240470286338564, 39.752888294958304, 42.27142257075156, 52.94575683532223, 56.457733338879, 56.925781926801136, 52.06081521126532, 42.527769073363274, 47.726470655010594, 53.03806197258734, 57.74043467737014, 54.125040961850075, 50.2278406389298, 44.30083728605702, 41.199050488010535, 41.29842373632616, 39.46379000140775, 39.184364272702126, 41.17246466298258, 40.383538738373794, 42.66838996641098, 39.81703865912653, 40.15336228955177, 40.0048731219384, 40.615754819685414, 42.077677096090014, 43.862222163907944, 43.33524780888712, 41.01487559656943, 40.559935569763184, 42.21624266716742, 41.046050594699004, 42.81392951165476, 42.12905230060701, 40.227699049057506, 41.39214092685331, 43.20936326057681, 41.58523136569608, 42.721718511273785, 40.53262410625335, 40.505606820506436, 40.619245729138775, 40.331532032259055, 39.72885593291252, 39.23386066190658, 41.192241253391394, 38.870609960248395, 40.05338891859978, 41.97676627866684, 43.77396491266067, 46.43021360520394, 42.85590279486872, 45.291518165219216, 42.248021710303526, 46.72726646546395, 47.34169398584674, 52.196427237602975, 51.001296735578975, 52.29955419417351, 54.401693574843875, 55.88649111409342, 56.166128650788345, 59.35496853243921, 59.90933672074349, 63.221668504899554, 66.65135368224114, 78.11411965277888, 56.95223046887306, 58.591683141646854, 35.382383408085, 53.59906681122319, 12.58721242027898, 1.615714978787207, 3.5339238807078335, 1.6818818089462098, 0.11790986413196211, 0.9265025681064976, 47.39940381819203, 62.746367454528816, 64.90246295928955, 52.73354876425959, 54.05197505028018, 26.36822762027864, 24.479739742894328, 49.412525007801676, 61.40348911285401, 43.40696050274757, 1.80494298617686, 0.13930999403519018, 0.06201145817495643, 0.042648283284037344, 0.030499390934804277, 0.09541053595321794, 0.04430280720454551, 0.027370264588464654, 0.05073700348035463, 0.04788837831227049, 0.06850846983011692, 0.005999148828953866, 0.03734810014946326, 0.0925488987817399, 0.1178923053967376, 0.07367007915050754, 0.19738685910499867, 36.56730790292063, 72.3130989074707, 56.48842980784755, 63.80918856590026, 29.464262262467418, 25.10983713211552, 44.038787657214755, 58.722788364656516, 64.09473319207468, 71.84628978852304, 30.284590682675763, 0.21036190641743524, 0.7598943179172855, 14.04486813852864, 23.520779071315644, 1.629903294867085, 2.9574830445551106, 56.5361140620324, 57.53965639298963, 67.32753892098704, 60.04749828769315, 59.52224977554814, 59.33708644682362, 60.390795892284764, 59.78521331664055, 61.101921604525664, 59.374780424179576, 60.21187697687457, 57.01250945368121, 48.98348831361341, 46.832617405922186, 45.43825011099539, 43.43325999475295, 43.80887400719428, 41.41916997971074, 41.91417701782719, 42.538892915171964, 40.66777721528084, 40.1579906863551, 40.95836600949688, 41.031020072198686, 40.72308655708067, 40.73581857066001, 40.459793536893784, 41.271182875479425, 41.21909772196124, 40.75839181100169, 42.370431038641165, 41.32439374923706, 41.39183890435004, 43.03659069922663, 43.706327561409246, 42.346806603093306, 43.07095850667646, 42.57751257188859, 43.478571214983546, 43.3955228713251, 42.849489719636985, 42.79181518862325, 44.1775885705025, 42.862668883415964, 42.62766399691182, 40.18383518342049, 41.24255349559169, 44.44907934434953, 40.79363038462978, 43.6430440410491, 43.966066914220015, 44.97563400576192, 43.53501412176317, 41.80560188908731, 42.856942222964385, 41.93744844005954, 41.562493385807166, 44.60121631622315, 53.678749761273785, 57.458435873831476, 58.91913829311248, 53.628492432255904, 44.92282713613203, 50.701627654414025, 54.1817819687628, 59.559818237058586, 55.67602065301711, 53.452276029894435, 47.028108335310414, 43.96505886508573, 42.599179744720466, 41.79676871145926, 42.917185906440984, 43.133528155665246, 42.90624249366022, 44.269270050910215, 41.80584115366782, 44.32834094570529, 42.472730375105336, 43.296141778269124, 43.429741628708385, 45.46766788728776, 45.65833037899387, 43.59221796835623, 42.908042861569314, 43.77429831412531, 42.88955673094719, 44.34557976261262, 44.216824039336174, 41.1284831262404, 42.89575015344928, 45.079490523184504, 43.65631734171222, 44.2109836301496, 43.19517604766354, 42.61592826535625, 42.791689672777736, 42.395122358875895, 43.50147001204952, 41.50233599447435, 43.624589289388354, 42.09864608703121, 43.97479811022359, 43.180843707053896, 45.46413775413267, 48.07195301978819, 43.82182959587344, 46.458705702135646, 44.64798665815785, 49.4366083606597, 49.97329058185701, 54.28521487020678, 52.824457537743356, 56.28440772333453, 55.654588822395574, 59.15938738853701, 58.948795333985366, 60.87787582028297, 61.95206396041378, 66.98798717991, 67.06543830133253, 73.88094086800852, 57.18113214738908, 61.74994814780451, 37.447762335500414, 56.513638880945024, 13.16251822056309, 0.6203414127230644, 8.003127613375264, 6.8082672645968785, 0.11259189626622586, 0.9580652680127852, 49.7935087450089, 68.20534183133033, 66.72554139168032, 61.26706907826086, 44.82443055798931, 24.785821899291008, 35.23139569067186, 56.491775589604536, 70.28047177099413, 54.15538833987329, 3.302424857693334, 0.18714680696927732, 0.017342054916004983, 0.02695748109310385, 0.02482770112222962, 0.02659076054941022, 0.0369796195187636, 0.036001091582640525, 0.15372139491861866, 0.1729981129568431, 0.13230557553470135, 0.10706251111602592, 0.10760411229585448, 0.12281475738892633, 0.33090392608315716, 0.18049413007834267, 0.4184729852263005, 46.97400316115349, 80.42981639985116, 65.92519744749993, 72.19738898738738, 35.364991618740945, 31.70186854177906, 48.809848908455145, 66.37298307111188, 67.49955838726413, 79.791638928075, 33.470020063461796, 0.3718123470823611, 1.2182974911505178, 25.383155730462846, 38.359336853027344, 6.6244336193607705, 3.524581530401784, 63.92844038624918, 58.51537342994445, 68.88659477233887, 61.485741215367476, 62.54005470583516, 61.89114562926754, 62.418900535952666, 62.738205002200225, 64.23802914157991, 61.34080571513022, 62.338656686967425, 58.546756313693145, 50.753057772113436, 47.68037888311571, 48.353571353420136, 45.53683104053621, 46.00882161048151, 42.53398995245657, 45.22701086536531, 46.818712603661325, 42.600827140192834, 41.701537486045595, 45.20256665445144, 43.88032782462336, 44.69201918571226, 44.51402202729256, 42.593229509169056, 43.350250874796224, 44.19308585505332, 45.2897217196803, 44.60550346682149, 43.60611100350657, 44.506706806921194, 46.05860041033837, 44.549099783743586, 44.40509388523717, 45.55787847888085, 45.54834711936213, 47.13781310665993, 45.17052873488396, 44.087299531505955, 45.98818994337513, 48.26040721708729, 44.8430775057885, 44.92822823985931, 41.35861642899052, 43.887266497458185, 47.04736717285649, 42.16399669647217, 47.244662392523985, 48.44906930000552, 45.786266326904304, 46.772303119782485, 44.29557738765594, 44.9744886736716, 44.13025732963316, 44.18070293241932, 47.5814292507787, 59.00318684116487, 59.28267532779325, 63.55447376928022, 55.460757055590236, 46.732369469058135, 56.640323592770486, 57.60057080176569, 61.80988588640767, 58.35789026752595, 55.44936257023966, 50.53546036443403, 46.00773511394378, 46.79953613588887, 44.23669084425896, 42.70594273844073, 44.963443279266365, 45.80800410239927, 47.53073653867168, 44.494225825032885, 45.87766539665961, 43.35007829050864, 46.52395432995212, 47.16691709333851, 48.59345959078882, 48.514008060578384, 46.088312364393666, 44.86690198221515, 44.29926833798809, 44.96972299391224, 47.828981799464074, 45.300276817814, 43.328713140180035, 45.95901535403344, 47.91383443340179, 46.91779167421403, 47.58250005783574, 44.81644853468865, 43.350050833917436, 45.37251510927754, 45.20774026070872, 46.53705504632766, 43.527671444800596, 46.61957779238301, 44.79513829754245, 45.18792836896835, 47.11310217457433, 48.49169761903825, 51.736909804805634, 46.57277607148694, 50.56451728267055, 45.701939290569676, 52.94074404624201, 51.70404034276163, 57.04554365527246, 55.01295966486777, 59.076554775238044, 58.65213078837241, 61.87602881462344, 60.68799388024115, 63.66120930640929, 65.93151246347736, 69.82476295963411, 67.91964423271918, 76.92570424848988, 60.28397798538209, 63.32162618637086, 41.244691187335604, 59.870458187595496, 14.938633134288175, 2.5077484932637986, 9.86718696932639, 5.390500580110858, 0.46232563533609916, 1.3458806708935769, 57.22336038466423, 73.79938694738573, 76.36005924594018, 66.35580308975713, 64.5187923985143, 37.668795739450765, 41.37658872912007, 67.70249397523942, 77.07808832968436, 67.02780708189934, 5.562043478412013, 0.3848816232094842, 0.1180327446350167, 0.17839953844105044, 0.138921526170546, 0.23379163305845954, 0.1391689878918471, 0.11751055612318939], [0.040835692442112395, 0.05392417056305755, 0.05343220421984311, 0.017945998415891683, 0.044036894255588134, 0.10433051900397386, 0.09261832933031744, 0.0290113091919451, 0.2851276598390072, 34.93582548633699, 62.21205042254541, 54.216957784468136, 44.60134967680901, 29.99469026442497, 43.357417045101045, 31.130179166793827, 56.01320720488026, 60.598544228461485, 63.00436919735324, 25.443446482381514, 0.1594528204370891, 0.5335801779743164, 4.797072939334377, 7.585470205353153, 1.7385382397520928, 13.448596289080958, 75.78530649985038, 60.4043359141196, 61.4827053008541, 56.19826462961013, 55.95145340888731, 52.26455880749611, 56.61238062766291, 57.567171819748424, 58.0677447011394, 57.795085060981016, 58.92736350336383, 51.09149163769138, 44.07302994881907, 41.157512587885705, 41.261004324882265, 39.690703038246404, 40.884370496196134, 38.04644153964135, 38.52760261104953, 37.5669200189652, 38.86675034799884, 37.75159305141818, 39.16411699787263, 37.815304110127116, 37.42433794083134, 38.451379191490915, 38.158786066116825, 37.52858669527116, 40.53199652702578, 39.509673887683505, 37.34161907626737, 39.26871876562796, 39.266161380275605, 37.89450853101669, 38.51801633834839, 40.00324533831689, 41.515217058120236, 39.980656408494525, 40.43139949921639, 40.82456219580866, 41.16294114820419, 40.68280773778116, 41.5128989373484, 41.33553720289662, 39.80287890280447, 39.06670493464316, 39.46315849981001, 38.86209841697447, 39.77566157617877, 40.61862599465155, 42.920716039596066, 40.43056403436969, 40.51403599400675, 40.97595391734954, 39.07998608004662, 40.32194183718774, 39.00926182346959, 45.45503001059256, 52.77987195599464, 53.55695232268303, 54.77312241831134, 57.603630250500096, 51.26000450503442, 44.182644505654615, 56.16713669992263, 53.779707647139034, 55.65567924130348, 47.88427545178322, 43.78059371825188, 42.44702708336615, 40.65430779610911, 38.05979721007809, 40.467795172045314, 40.69901497133317, 39.2334056669666, 41.05960630601452, 38.76360770194761, 39.672267898436516, 39.675515620939194, 40.85357204560311, 40.257783628279164, 39.555867641202866, 42.294301755966686, 42.12595755054105, 41.699042858616004, 42.65966269277757, 42.41151002145583, 39.99403169078212, 40.92688898886404, 41.35926754243913, 39.796210873511534, 40.840369347603094, 41.07520949456, 42.74358180261428, 43.61349290417087, 41.76583690028037, 39.899145633943625, 38.672663627132295, 41.39206247944986, 39.73258218457622, 39.756716528246486, 40.59619788200625, 39.37186533404935, 41.93424386362876, 44.23862457275391, 43.254203796386726, 46.74114773350377, 47.555388635204686, 50.50039437509353, 53.045883178710945, 52.37795845154793, 55.548649526411495, 54.969931264077466, 58.4022875755064, 56.064829518718106, 58.883546706168886, 57.71846940440517, 64.69394583855906, 57.90282472487419, 60.580179691314704, 59.499135248122684, 36.89991704879269, 50.18804819353166, 63.19800484564997, 36.285548363962484, 43.01788099350468, 15.634473369967555, 0.6459258689034371, 11.482044419934674, 8.732292306038643, 0.26695298992337724, 0.26335390885510757, 41.46209247650639, 65.66991782957508, 62.8373585977862, 54.45069182303644, 52.15224173761184, 22.525675719784154, 16.64261271876674, 37.05938885288854, 60.847175428944254, 43.09809346352854, 2.163305801730002, 0.09364011442108501, 0.00945918350255177, 0.035832261125887596, 0.056177916966619036, 0.09938763544684458, 0.051396153191284794, 0.05078290746877751, 0.020337487428238796, 0.04629527549109152, 0.04155663480501502, 0.0438252356534283, 0.026622846226898894, 0.10183409892863805, 0.06743197073979725, 0.036602210133306445, 0.2593557572653217, 42.022034352825536, 71.16391504964521, 60.9353110867162, 53.62634689577165, 36.71859372046686, 38.574824025554044, 34.94726311775946, 61.92873370262885, 63.75509123648367, 70.8378327277399, 28.57118368148804, 0.1606443169857225, 0.6329688093354625, 8.158400029905382, 9.283571627832229, 2.299941566682631, 16.390173877439192, 72.38598439001268, 61.12219633594636, 63.72127648322814, 59.60741227672946, 59.21932904951034, 56.53002262115479, 58.596837136053274, 60.2933132263922, 58.87473314039169, 60.473906993865974, 58.033541633236794, 53.92770651848086, 46.38693809509278, 42.870117464373195, 43.55299818900324, 41.834964752197266, 42.53392327216364, 41.17080550039969, 41.73595236193749, 40.139735975573146, 40.57669585750949, 40.33088091881045, 40.76503630607359, 39.527344165309785, 40.866559013243645, 41.173715899067545, 40.43093273716588, 39.51171744254328, 42.58268617814587, 40.45985237244637, 39.97953853299541, 41.820593187885905, 41.477899628300825, 40.2910610168211, 41.20665204140448, 43.281648620482414, 41.368932262543716, 42.32158968525548, 42.35973865755143, 44.024188595433394, 42.45561707404352, 42.764237003941695, 43.20048301450668, 43.25782414405577, 42.24137329286145, 41.10826330800211, 41.542242188607496, 40.59108703367172, 42.42429694821758, 41.888254073358354, 42.423916478310865, 44.140388811788256, 43.11738368003599, 43.314416100901944, 41.50334796597881, 42.874863532281694, 42.587702889596265, 47.19074549213533, 54.277844736652995, 56.39810546751946, 57.90480159944104, 58.06243381192608, 52.517583062571866, 46.462843802667436, 55.94531489956764, 56.20830981962143, 57.25652402447116, 50.77380711032499, 46.368346060476, 43.163801008655184, 42.690108130055094, 40.614766382401996, 43.60552264798073, 43.13192390626477, 40.801216248543035, 42.771458087428925, 41.61299390177573, 41.13057767191241, 43.320495774669034, 42.884434115502145, 43.58800142042099, 42.72688427279073, 44.80773302816576, 44.17717672163441, 44.18327600725236, 42.30960684437906, 42.79729866212414, 42.87553033521099, 42.60939359664918, 42.906293484472464, 41.420476128978116, 42.95192241668702, 44.71541220141996, 43.95542160157235, 44.52785230452015, 41.88013084473149, 42.11535146159511, 41.59938719964797, 43.794580890286355, 42.56528262169131, 43.20965743833973, 42.977394288586034, 42.127487274908255, 43.81162358868507, 45.77547196419009, 45.149728405860166, 46.732012533372455, 49.79875295392929, 51.86588910318191, 54.64297425362372, 56.54589253087198, 58.7465226265692, 56.690208296622004, 59.83028134992046, 58.85080668234057, 60.69634068396784, 58.734186772377264, 66.63302836879608, 59.11074215365995, 62.97618696766516, 58.31242607485864, 41.61762622094924, 52.610915860822125, 62.58082774377639, 39.846338764313735, 43.40066117625083, 17.589378741479692, 1.0346255211099502, 9.014341119796999, 14.651477394565461, 0.14063819131303218, 0.19381220091975507, 45.023757565406065, 71.73754599786574, 68.4987586544406, 59.84435481409873, 52.46695703075778, 21.664874322952766, 21.76635584523601, 46.43226500480406, 67.79849790757703, 52.99162895448747, 3.535292542749836, 0.08766014699734027, 0.06914914150031344, 0.027096572016636213, 0.05692035192623735, 0.01832194074297384, 0.04933912284492005, 0.02351739391263935, 0.11300175330571591, 0.09558143484736643, 0.15578059329380914, 0.16253404139030367, 0.15145595035245343, 0.1556388210625418, 0.2926949844244988, 0.13506362995793744, 0.5804854126707201, 53.92584339264901, 80.0412428763605, 70.93741386167466, 60.14643615291965, 40.93896204425443, 54.399591184431515, 44.38457988923596, 69.81190543020926, 69.17472424045687, 75.25526092898461, 31.934539618030673, 0.38102921218641345, 1.322712456026385, 12.31619821440789, 14.923922284956902, 4.100889741413055, 17.223804035494407, 74.8489426028344, 61.82792486683015, 66.61206722259521, 61.11131960345853, 61.11130783634802, 58.24012894784251, 60.94037486660866, 62.492676396523755, 61.738133968845496, 62.537905246980735, 61.47697471803235, 55.996333168398955, 48.63904537693147, 46.04579779409593, 46.03163019303353, 44.77655410766602, 46.63392974484352, 43.173626545936834, 43.56667941616428, 41.820891288019, 43.384854024456395, 42.52356429253855, 44.01376293551537, 42.9100432703572, 42.396440275253795, 42.97128323585757, 42.50024580186413, 43.33600874870054, 44.48095252436977, 44.48332163595384, 41.388277392233576, 45.07849424116073, 43.41460127984324, 41.7362347725899, 44.32319479603922, 45.07452480254635, 44.38186168670655, 43.522431158250384, 44.1904107985958, 45.87735552941599, 45.06985325967112, 45.602903366088874, 45.84499989786456, 46.21532655531361, 43.80186080932618, 42.104580633101925, 42.77772211259411, 41.679489843307, 44.53197471557125, 43.248806615029615, 45.37276614096857, 46.40266679948377, 46.3159510397142, 46.44089421918316, 42.687915525128766, 45.35129116427514, 43.59573241203062, 50.143694031623106, 59.300243623795055, 58.134660336279104, 59.36898316106489, 61.15122579759168, 51.99617847319573, 50.633468627929695, 57.8679980001142, 60.52756109545308, 59.75288121931015, 52.21021436875867, 49.76144336885022, 47.986668925131525, 43.85938236790319, 44.620753642051454, 45.74571294169272, 45.719719394560784, 43.86023352223058, 46.94239670230497, 41.96719961781656, 43.38420291100779, 44.812388881560295, 44.005000360550426, 46.06510370008407, 44.688826376392, 47.684768015338534, 47.158727184418716, 45.44249411552183, 45.12307590053928, 45.72754844542473, 43.69071652812343, 43.480928559457105, 44.9418310196169, 42.879303655316754, 44.60199294551727, 48.044178716598026, 47.67696249869562, 49.065650201612904, 46.07212082032235, 44.78986270966069, 42.839134662382065, 47.52056583281487, 46.05336012378816, 44.2600054125632, 45.95607749877438, 44.677353443637976, 47.75904593929168, 49.035977471259336, 48.59200046908472, 50.57790825443883, 52.29980522586454, 55.60308417966289, 58.47844431477209, 58.77025296611171, 62.61789806427495, 58.81738416610226, 62.86269318672919, 61.163836217695675, 63.828772960170625, 59.987113398890344, 69.27846308677428, 63.60699038351736, 65.84528307760915, 61.621035529721176, 49.66816940615254, 55.14223314100697, 64.45506957269484, 45.01062547006915, 46.6168164437817, 20.129493897961034, 2.297580054690761, 23.794756627851918, 19.636755950989265, 0.7259417914094464, 0.645756594115688, 49.06237502251902, 79.11546153406944, 72.85120887141075, 69.0150680849629, 65.81222534179688, 33.81607509428455, 31.840153663389145, 58.27731301707607, 76.56598367998677, 65.37889757464009, 5.408338048765737, 0.2737770560047319, 0.29645816152614934, 0.13207263884044465, 0.14623780374325093, 0.12974465085614112, 0.16067494518093525, 0.132506106709761], [0.027392605627556483, 0.0436149062138171, 0.11871111549196706, 0.03681478038009617, 0.04171826786571934, 0.03633206837900704, 0.020957786905308886, 0.03669013404437611, 0.10313588915573013, 37.135608350076986, 62.2663595599513, 52.75890296505344, 49.58019848792784, 20.972544608577607, 35.54187090166154, 38.61410264045962, 58.92679083731867, 57.82781331769882, 65.06467257776569, 23.285583949858143, 0.18112702595610775, 0.31849949170024167, 9.947310205428831, 14.306274498662642, 1.0267655202938666, 31.331551690255445, 32.40871690934704, 40.60616854698428, 66.03101515000867, 54.34135575448313, 56.96382499510243, 52.42017884408274, 49.299301870407604, 51.25868658865652, 51.83092117309571, 49.24400429571829, 48.44119318069951, 42.34189579563756, 40.87418410085863, 40.103101038163715, 39.137621387358635, 39.851100521702925, 38.47223051132695, 38.305812189655924, 37.828961803067116, 38.16696028555594, 37.66630111202117, 38.02527250782136, 37.30407807134813, 38.184030440545854, 39.40956323377548, 38.273523238397416, 37.077686709742395, 37.89037435285507, 38.57406700811079, 38.99573749111545, 39.025233714811264, 41.39827159143264, 40.56036703048214, 39.30967615496728, 40.29232402001658, 40.252519807507916, 38.46542912144815, 39.70532955661897, 39.79336715513661, 41.43706775480702, 40.526826843138664, 42.6196192156884, 41.92071168653427, 41.152358593479285, 40.75817215827204, 41.33365838758407, 41.13680639574605, 40.95794631588844, 37.73034949456492, 39.758450215862645, 40.711594012475786, 43.98550225842384, 40.98621483772032, 38.649572633927875, 40.481809800670995, 41.59284860857072, 40.08954924921836, 42.85108220192694, 48.7260631592043, 52.26164840882825, 52.91050649458363, 55.37730863017421, 49.53506769672517, 50.83433712682417, 54.23479280164165, 50.97157301441316, 50.95008627060921, 40.97690705330142, 40.71518298118345, 40.944072892588956, 40.50354757616597, 38.693683608885735, 41.531400757451216, 40.74992341379966, 38.875316804455174, 40.70514955828267, 39.884064120631066, 37.53411331484395, 39.01106611374886, 41.27208894298923, 40.13908486212454, 40.99476952706614, 41.567435572224284, 41.44660695906609, 42.32993648898217, 40.89883619739164, 40.58645079212804, 42.61426910277336, 41.9436457849318, 41.91348275830669, 41.75077499881868, 41.300973276938166, 42.097767476112615, 41.15835589747275, 41.472871149739916, 41.388512734443914, 40.98758766728063, 39.20705518414898, 39.2769165192881, 39.7727668669916, 40.60374452221779, 41.86269983168572, 41.331708969608435, 40.94321389352122, 41.18950736138129, 48.23005199432374, 50.320549780322665, 53.702833114131806, 53.58986885316911, 54.794130632954264, 54.69378071446573, 57.44012232749694, 54.33985740907731, 56.82150571577011, 58.32939817059425, 62.09736816344723, 59.952541628191554, 58.92812836554743, 59.18644782035582, 62.99418672438591, 60.126879215240486, 61.963058364006784, 65.47206171097295, 66.02828518036874, 52.557073485466745, 53.41994785493421, 17.830845732842725, 0.1470939682856683, 9.195587961904465, 13.154721529253068, 0.17962238330754543, 0.17129395036928116, 32.84819691411911, 69.47262825504427, 61.07351187736758, 58.071796509527395, 34.46145011532691, 22.627878958179107, 33.77476076925955, 37.66563038672171, 55.24891376495362, 50.606353282928474, 5.637714824368877, 0.20612208473105587, 0.08338527678842507, 0.008412378937787107, 0.05391849002109901, 0.0852438597188842, 0.030143730785517447, 0.025681873836043864, 0.022067204793734897, 0.051541579661950956, 0.04650431407255031, 0.05414440168909008, 0.0032535038330787497, 0.03834512910895771, 0.08209890791124876, 0.028241247186557423, 0.34187249719135226, 45.03870179576259, 69.64744044888404, 59.70784064262145, 57.72829494168682, 28.513817056532833, 44.20223282229516, 40.97784842214277, 64.92824077606201, 62.56919007147513, 70.51475494138657, 23.499221724848596, 0.15930743227081914, 0.3648840623997873, 10.340126752853394, 7.915094917820347, 1.0594380670978178, 35.97854052820514, 34.20788457316737, 46.944224526805264, 66.59804082685902, 58.08487761405207, 59.13482550651797, 54.434888593612186, 51.902371068154615, 53.06585588762837, 54.33575460987707, 50.57199332021898, 50.92402996555452, 45.49557947343396, 42.295407864355276, 41.18064280479185, 40.35416410815331, 42.205326710977864, 41.467685776372115, 40.53643665006084, 41.190605625029534, 41.508494115644886, 40.98004887180944, 40.06536391473586, 40.477903119979366, 39.544155443868334, 41.345955018074285, 40.040225444301484, 39.777771811331476, 40.49904077283798, 41.368312528056485, 42.48094381824617, 41.96274380530081, 43.100333136896936, 42.7796793753101, 40.25089594625658, 41.69692477872295, 42.51306018521709, 40.68789112952448, 41.246773965897106, 42.23224985984064, 45.12338969015306, 42.227017418030776, 43.85227503315095, 42.474354236356675, 44.008353987047755, 43.1803612555227, 43.50938535505726, 43.596705159833355, 42.64378101594987, 39.90261693154612, 41.09058910800565, 43.451726513524214, 44.519364295467255, 42.149609442680116, 41.566556961305686, 42.78412734308551, 43.338056225930494, 41.732037836505526, 45.15706716045257, 50.908344407235425, 55.552752325611735, 56.32682423437796, 54.705826313264915, 51.95488376002158, 51.903049638194425, 55.60744585529451, 54.039627428977724, 52.16245558954055, 43.78997210533389, 43.11628541638775, 42.58035236789335, 41.56257967795096, 40.881640526556204, 42.372678556749904, 43.5996037913907, 41.8039309593939, 41.458683936826645, 41.75990235420966, 42.278012152641054, 42.01678622153498, 42.64093337520477, 42.70911985828031, 42.06350949502761, 42.93773912614392, 43.91289918653427, 44.08162778423679, 42.23389333294284, 42.7663903851663, 42.9481137952497, 42.56975804605792, 44.38945539536015, 42.76900268370106, 44.11996895267118, 42.71137129875922, 43.258679220753336, 44.10599747011739, 43.798126712922134, 43.29768326974685, 42.91040412841305, 40.056962197826756, 41.45195314961095, 41.350665784651234, 43.80284140186925, 43.60870761256064, 43.77784021439091, 43.66276179590533, 49.714500442627944, 51.060206813196984, 56.56619864125406, 56.98820644809354, 57.222124838059955, 56.92427181428479, 60.05645305879655, 55.986797886510054, 59.7970510298206, 61.87595821196034, 64.55142651834797, 61.156132682677246, 58.97344743051837, 60.93480902333414, 62.62376200768256, 59.059441474176225, 63.50575793174006, 65.07510608242404, 68.35538033516177, 56.885279532401796, 55.90312980836438, 20.88011983902224, 0.33134378312576207, 2.587206152177626, 14.464777477325933, 0.1310378685593605, 0.056008059952047565, 35.369055194239465, 76.02544969128024, 67.11344026750135, 63.920658403827304, 37.7183235076166, 28.047211900834117, 41.57261702322191, 46.443377079502234, 62.2069513413214, 61.39763301418674, 7.5138060508235816, 0.196149856933663, 0.07423374366255538, 0.10716722001351657, 0.039034642714766726, 0.03825209539143309, 0.07380795965511953, 0.04750219338964071, 0.14109330882708873, 0.18913949359088175, 0.1460131561203349, 0.18555345133908335, 0.11299475126208798, 0.10715274095174768, 0.1367278333993689, 0.1378979254513979, 0.8622714276275328, 58.258940635188935, 78.21846254410283, 69.75874946963403, 63.40273687916418, 27.608337902253677, 46.94948834757651, 52.39984919947963, 72.54418142380254, 64.60876372552687, 77.0600611163724, 27.539037466049198, 0.36143881178671317, 1.662280131732264, 14.657188365536353, 23.784940896495698, 1.8769722888546607, 40.945802657834946, 35.439563720457016, 47.759681363259595, 70.45628809159803, 59.301404645366055, 61.5066082246842, 57.5960639984377, 55.68547748750257, 54.83704920737974, 57.05894247178109, 53.28530465402911, 53.65532928897489, 47.3172027064908, 45.862642718899636, 44.725045542563166, 43.953962479868245, 44.590017949381185, 44.77605988902431, 43.691355874461514, 44.04833862858434, 45.3470040136768, 44.130924132562455, 41.55351508048273, 42.41030585381293, 43.74403330587572, 44.945671020015595, 43.83664438801427, 41.445112536030436, 43.48572954054802, 43.83077652223649, 44.729395451084265, 45.42536512497933, 45.92441220437327, 44.31092562214021, 42.0218696132783, 43.78119776325841, 44.117980310993815, 42.522434649928925, 44.38454458790441, 45.42048961885514, 45.60376628752678, 45.360085118201475, 47.0959065037389, 45.64441380962249, 44.80285752204157, 45.692188278321304, 45.17179958281979, 45.73671502451743, 46.258715814159764, 42.250410433738466, 44.205033394598196, 46.386306593495036, 49.056267892160726, 45.80356397936421, 44.96798146155573, 45.09329334382088, 46.474257899868874, 45.39704953470538, 47.77003249814434, 54.74081385520197, 57.2845297475015, 58.95363161640783, 59.17155065844136, 56.18126899965348, 55.08767297191005, 59.30761767971901, 57.11944110931889, 55.049606369387725, 46.55746706070439, 45.819535870705884, 45.35841418850807, 44.80259472324003, 41.56062633760514, 45.786944896944114, 46.781485388355875, 44.406172537034564, 44.67430183964391, 45.01751315209174, 43.89533873527281, 43.39619751899473, 44.19691016597133, 43.895699593328665, 44.25054073333741, 45.34188532060193, 44.949146239988266, 46.777778748543035, 44.01133106600854, 45.41903441952121, 46.89608135531026, 46.29184415263515, 47.62035877473893, 44.442474072979344, 44.81638577676589, 45.69640090388637, 45.80631356085501, 45.72629720933976, 45.43306865999776, 46.18174322189824, 44.34706241853776, 42.99686101175124, 44.09247313776324, 45.5871864288084, 47.368883855881236, 45.858045701057684, 45.98049033072687, 44.90620805371193, 52.77223510126914, 54.5437422106343, 59.50115526876142, 57.819760691735056, 58.8104219590464, 60.2755880355835, 64.36142690720098, 59.25370470170052, 60.77843589167441, 64.47157490637996, 68.36626099001977, 64.9621614333122, 60.46655647216305, 63.56463663039669, 63.85813974565076, 64.65222750940632, 65.22337559730776, 68.10500760232249, 73.92696595961048, 60.6994785801057, 58.64993426107592, 25.150443469324422, 0.387674565276792, 16.189594653344926, 22.192211497214533, 0.26757247926246736, 0.34032708334345974, 39.408253162137925, 82.88545546993133, 73.08512333900698, 73.6307014957551, 46.09728282497775, 34.417852970861624, 48.528822852719216, 57.49101900285291, 69.94358724163425, 74.36107035606139, 10.658734998395367, 0.5362312712015644, 0.25014549583917667, 0.21410315808269287, 0.17271629985301726, 0.1774967038222859, 0.13544091293888708, 0.12755097340672247], [0.05312735868257381, 0.044956379795386914, 0.033028149496643774, 0.06830384774554162, 0.05605933804725928, 0.003964109754663021, 0.11857337288318143, 0.005805892616345157, 0.46277293875332803, 44.444235217186716, 62.287493290439734, 49.19198974486321, 37.480804381832, 17.315350194131177, 38.86757012336485, 36.218993586878625, 57.268157774402255, 55.29077722180275, 69.38760695918914, 19.1606508147332, 0.09334954493228467, 0.10882592294365169, 8.789979584755438, 2.61314723760851, 0.13926700118087953, 43.78845807044737, 29.790075902015936, 42.847869780755815, 58.64292498557799, 60.1052277318893, 53.97460237626107, 53.90241115323959, 44.57299878520351, 44.43098152837446, 43.70569213744133, 42.39773465741066, 41.05580552931755, 40.93086627221877, 39.5872740591726, 39.81748580932617, 38.764403943092596, 39.41310121167091, 39.106438544488725, 40.146317712722286, 38.48140885753017, 40.455847632500436, 37.09396846832768, 38.12979582817324, 37.994980042980565, 38.46383663915819, 37.34556105829055, 39.17018882689938, 38.21159293574672, 38.10297073856477, 38.99796147500315, 38.31784209897442, 38.23636270338489, 38.30987184278427, 39.60818813693139, 39.550697957315755, 38.806357614455685, 38.62989018040319, 38.82568705466486, 40.02165694390574, 37.6714825630188, 41.87613787189607, 40.59565659492247, 42.32703001268449, 40.525740346600934, 41.9207783668272, 39.437580723916334, 39.95957366881832, 40.39256803451046, 40.727495301154356, 38.86622867276592, 38.993493895376886, 39.90548026177191, 42.64476553086312, 40.23268045917634, 40.95154108539705, 38.66178297227429, 40.98193553186233, 39.090839278313425, 42.021375394636586, 44.89624523347424, 48.54480651117141, 50.5210691882718, 55.94615036441434, 53.77356521544918, 54.0177406034162, 53.67612569562851, 50.9828027602165, 45.77971204634636, 42.50744727350051, 42.531973854188, 41.774685767389116, 42.12690284175258, 38.38536962386101, 40.437840031039336, 39.58035892055881, 41.469878381298436, 39.727000651821015, 39.89374060784617, 38.15595411485241, 40.02058221447853, 41.11494702677573, 40.04039802858907, 41.37680445947955, 42.32027176887759, 41.48677595200078, 43.77511808949132, 41.333419123003566, 41.59923030484108, 40.76410670434275, 43.087048069123306, 40.56291264872397, 39.862028245002996, 39.79212376379198, 41.494036259189734, 42.123776712725245, 41.03870007299608, 40.564352158577215, 39.40820609369586, 40.55547975724743, 40.38916341720089, 39.37301851088001, 39.93040692421698, 39.20481943315075, 40.77537567384782, 40.20246644173899, 44.884858592864006, 48.132059420308764, 54.9964504088125, 51.84775206350511, 54.98019610681842, 60.36069170121224, 55.922882864552165, 57.59475784917032, 58.58783529650781, 58.71627723017047, 57.307004928588874, 54.599341807826875, 54.74605806412236, 60.24660956475043, 62.00314890953803, 61.71867116805046, 63.08855110599149, 60.62297274989467, 61.34170786026986, 63.047844748343195, 61.57065268485778, 71.00199176419166, 29.773900047425304, 0.17546221944353274, 3.433444033707342, 16.168102025985718, 0.23334128061129203, 0.02657342014924413, 28.726835097036055, 68.16165447235107, 63.438995269037065, 61.39889601738223, 43.25540011928928, 24.41413417939217, 13.47759044939472, 37.9070601155681, 58.59161253898375, 56.149313449859626, 5.514145455052776, 0.15940149254616232, 0.03253584607474266, 0.04223153911410801, 0.057331051662444114, 0.05173645710812942, 0.029276299004953717, 0.04395113071246494, 0.05928970482801238, 0.04423041572614063, 0.06653698852225658, 0.06993180756727535, 0.043971531633888526, 0.05479794746685413, 0.05422389097211342, 0.10876501129279215, 1.2749287942724845, 55.508962985008, 68.07738627156904, 56.13098029167422, 42.2672374017777, 23.374470741518085, 36.1967812045928, 38.31347650097263, 66.3378543238486, 57.60652495968727, 73.96422847624748, 21.135815228185347, 0.1260962337255478, 0.41398922582307174, 10.129269938315115, 3.671841525262402, 0.17613161175001055, 48.735488614728375, 29.602706240069484, 47.145289144208355, 59.83853793913319, 62.00420794948455, 57.35650916253367, 56.6220728043587, 47.694683767134144, 46.255644598314845, 44.531166707315755, 45.99321842193604, 41.74652314955189, 42.35161935129474, 42.09349601499496, 41.93632664219026, 40.1622699922131, 42.75666290713895, 39.82046681065714, 43.01473133025631, 40.914121673953154, 42.98883192000851, 39.309107411292295, 41.3020597734759, 39.33457143845097, 41.52786670192596, 39.79503808483001, 39.94477848852835, 39.158143228100194, 40.106278158003285, 41.551957899524325, 41.040382769800004, 39.12714473662838, 40.760925662133005, 43.22966544858871, 42.33353330243019, 41.03638195222424, 40.247083402449086, 39.53043499300557, 41.559159371160696, 40.0078776574904, 45.429346330704234, 43.20055361716978, 45.720499946225075, 42.90676809126332, 42.82286074853713, 41.20726000878119, 43.089134770054976, 42.692159529655214, 42.838616909519324, 42.673206636982584, 40.25598718274025, 42.840079953593595, 44.64032234684114, 42.325092361819365, 43.11560292397776, 41.81309753848661, 41.87093680904758, 42.38796795568159, 43.0707976894994, 48.24261142361549, 48.91047339285574, 52.91995940669891, 55.26514061035649, 54.83414665345223, 56.260991173405806, 55.44354569527411, 52.71004984455725, 47.18525417389409, 43.71723959522863, 44.11201830833189, 43.08352970307873, 44.18140895905034, 41.09882608536751, 42.67891760795347, 42.432918317856334, 41.96743888239707, 40.72784439209969, 41.4864896189782, 39.659292697906494, 42.56680450131817, 42.99115396315052, 42.887736751187234, 43.91487998347129, 43.40412855148316, 42.89675035784322, 45.26448126762144, 43.69471734569919, 44.51812482649281, 44.920481558768984, 43.75481982384959, 42.04785923804007, 43.4201475112669, 41.48918036491641, 42.664667637117454, 44.23830293839978, 44.17091661883939, 42.62204324045489, 41.97780178439233, 42.74993604229343, 42.4082701436935, 41.69910561653876, 41.70085499363561, 42.39398879389609, 43.02931078018681, 42.35339226261262, 46.69139639023812, 50.85996589353008, 56.664889397159705, 54.891938855571134, 56.04272696279711, 60.78112663761262, 58.68505908596901, 59.955036255621145, 59.53781374039189, 61.15980009878836, 57.634918997364665, 57.7275614584646, 55.69470682451802, 59.366312026977546, 63.66302928616924, 63.63172484982399, 63.93796390102756, 64.04509167517385, 63.25562446348129, 68.23569313172372, 65.23600562926262, 71.38673705439415, 34.021320958291334, 0.06497629888115392, 1.1773019812760817, 9.106038289685404, 0.11279814245720064, 0.1444378341998785, 31.414821647828628, 74.74173638128465, 67.55185142640146, 66.28463560535063, 49.01196079869425, 28.280249718696844, 21.26533385246031, 48.099613574243364, 65.59423961947041, 66.1773430916571, 9.51808229569466, 0.19344346748004038, 0.0910796034300039, 0.07849775840558353, 0.03384995116521755, 0.06217175058179325, 0.08570152064484936, 0.010690395006789796, 0.12848894081769452, 0.14184171544207683, 0.13173156117479648, 0.2501774876708946, 0.20635117566393268, 0.15617024093385667, 0.18616414598880276, 0.20011581750887059, 1.6991094716133612, 65.68152412291496, 77.71002138814619, 63.05528548456008, 51.56222312681137, 26.149206392226684, 48.398090254875925, 48.03185855188678, 69.56030891787621, 59.35930667384979, 81.2814727906258, 22.80591534030053, 0.20535929098484978, 0.7672078222517045, 27.206120414118615, 8.292197469742067, 0.23297640825471572, 54.29081993718302, 32.167636271445986, 52.288151864082586, 61.27532958984376, 66.80632652774935, 58.84729616103634, 59.07073005553215, 48.7237254265816, 50.40707334395378, 47.4328302568005, 47.860094039670884, 44.43259754488545, 46.32700035648961, 44.334467687914454, 44.8694162214956, 42.624126019016394, 45.01020185409054, 43.34763857626146, 46.026287924858835, 42.799769755332704, 45.90871095657349, 41.556437246261105, 44.842426392339895, 40.73983115534629, 44.018944386513006, 42.66750743312221, 41.931968888928814, 40.42990507618074, 43.20247557855422, 44.165848916576756, 43.72671604156495, 42.20980998008482, 43.019355804689475, 44.8408103758289, 44.02474164962769, 43.005949143440496, 42.69403442259758, 41.8770831631076, 42.99382509723787, 40.9447475402586, 49.01059581387428, 44.84742349193942, 46.60297832181377, 43.400453290631695, 45.30940809557515, 42.42483823530136, 44.645017423937404, 44.13566235573062, 45.14738282849712, 45.29803322207543, 43.80432405779439, 45.14819475912279, 46.95200650922714, 45.879457919828354, 44.71534552112703, 44.15498002882927, 45.04967658750473, 43.81740908468924, 47.30484331807783, 51.01085947405908, 52.30371190655617, 55.10268780492968, 59.74116117723527, 58.68061504056377, 58.753508367846095, 58.00097811606623, 55.15171743208363, 49.3252444267273, 45.85189934699766, 47.22017503553822, 47.25301311862084, 46.845094465440326, 43.49800655918737, 44.104808991955174, 44.42477241639168, 45.24159031529581, 44.57456773327243, 44.390043750886, 42.55653181383687, 45.641770132126354, 45.187081137011134, 43.75824797538019, 46.35473935834823, 47.16847427429692, 45.3895656524166, 46.666422659350985, 45.190450452989154, 47.37010763537499, 46.41548510520689, 47.91849028679633, 44.44818504395024, 44.99512818551833, 44.41255815567509, 45.51792521630564, 47.27116584777833, 46.02781764922604, 45.08887283263668, 44.317625030394524, 45.26202586389358, 45.99230843205606, 43.032209411744155, 44.100451238693736, 43.114128112792976, 45.38516475308327, 44.391040032909764, 48.620139552700905, 54.927875611089895, 60.11728117542883, 56.79490420126147, 60.31209353477725, 64.84119945956816, 61.00175603743523, 61.0172454772457, 63.11867883128505, 62.68428025707122, 59.211296035397446, 58.10396778968073, 55.55940858779415, 62.09901948128978, 65.78051297895371, 68.10317977782219, 65.73627648815032, 68.30567606033819, 67.1932134320659, 68.90325700083088, 68.77246948980516, 73.68324556658345, 38.15123550353512, 0.21635760162626544, 7.95924658736875, 28.780883396825484, 0.6319106274074124, 0.21871178981757936, 34.65631738785775, 82.98767243662189, 73.09748664979013, 77.4888232446486, 54.06063564362065, 31.895933689609652, 26.252792266107377, 59.83495681516586, 74.91271249709591, 78.54143050409134, 13.70009081978952, 0.383147384010015, 0.23506588242467374, 0.17675015114007459, 0.22463913466180527, 0.2056053431043702, 0.2869723382736406, 0.13250805257308867], [0.073130845182365, 0.03198335112463082, 0.06259609817437108, 0.025169525723603946, 0.09365283914150731, 0.04847726626922527, 0.07301957091136325, 0.12694430071860552, 1.0881951691642886, 44.84876102016818, 58.43598073528659, 43.447717851208104, 39.07959776539957, 18.488405596825388, 64.45912530345302, 46.409880038230654, 56.80094465132683, 57.87584274045883, 70.50603159012334, 18.80643137039677, 0.13596482514854402, 0.19389556660767526, 9.308501232054926, 2.96112300407502, 0.941834929248979, 56.2493731129554, 38.49160701997819, 66.23413901175222, 57.74236056112475, 62.45858315498599, 51.00548190455283, 53.97761083418324, 44.98100373052782, 47.62169630296769, 41.44060965507261, 43.054939546892726, 40.34406008258943, 40.87179145505352, 38.190518040810865, 41.374662845365464, 37.56955192935082, 38.77045616026848, 37.33320559224775, 40.65011870476508, 35.8322008194462, 40.12650189861175, 39.07339649815714, 39.297340300775346, 37.9312885961225, 38.03656501154746, 38.169603963052076, 38.64148470663255, 39.15476214501166, 37.81885385513306, 37.332162241781916, 39.109396011598655, 40.07198095321655, 39.934784289329286, 39.171016447005734, 38.76687503630115, 37.65813473732241, 39.94227601635841, 37.84876192769697, 39.42792777092227, 38.46640971399123, 40.59198133407101, 41.288335400242964, 39.862243975362475, 41.308370867083156, 42.41613449588899, 40.995526544509396, 40.10396395960162, 40.8900853895372, 40.47097621425506, 38.812041128835375, 40.00018981195266, 38.24592151949483, 38.040832550294944, 40.078182220458984, 37.90301615192045, 41.41785990807318, 43.04261938218148, 40.35782367952409, 42.25985157874323, 41.08371319309358, 43.6960470291876, 47.899917864030414, 52.18539753267842, 50.97542870429255, 54.318868806285245, 52.06028176892189, 52.69741196786204, 46.2501101340017, 42.33814600975283, 40.30471478739093, 42.17412033388692, 40.56488560092065, 38.0128699733365, 41.17254311038602, 40.60481140690465, 38.20053185186079, 40.69427282579484, 38.857113084485455, 38.55020723035259, 39.63014948752619, 41.1765282384811, 39.78899371239447, 40.71748933484478, 40.57171052502048, 41.981692775603264, 43.33052527519965, 41.424826037499216, 40.35336394463816, 40.185749300064586, 41.342958327262636, 40.85246593721452, 39.43336025361092, 39.57944893067883, 41.37220351926742, 42.89430279885569, 40.034730203690074, 40.7930459514741, 39.87002595778435, 40.65547666242046, 38.322945102568596, 39.28408268959292, 39.82118852676884, 39.08026064595869, 39.10974902491416, 40.730064453617224, 42.981383339051284, 49.55580134545603, 53.657745469001036, 53.372816654943655, 52.64797441421017, 50.73146904668501, 54.672329271993334, 54.63267018718105, 52.208319863965436, 55.13964437669324, 54.89891675210769, 57.85405789652179, 59.27846662459835, 61.91930040236443, 59.941237357354936, 60.80602192109632, 58.38447609255391, 58.99456547152612, 59.69462617751091, 63.267144464677386, 62.32265341666437, 76.36850803129136, 44.10811947238061, 0.11351730749611894, 0.7379004239074646, 10.82116230841606, 0.7572609979298808, 0.07079812277468943, 27.25016666996864, 69.07987348494991, 60.15980359046691, 61.62436169962729, 33.24051041756907, 36.63083068786129, 33.214454112514375, 42.16577353016023, 52.927486435059585, 56.33088780987648, 7.706077694892884, 0.17543499267870383, 0.01775899635357482, 0.049597390236393105, 0.008492107623286786, 0.04389398821419285, 0.03835357905876252, 0.037779124198301185, 0.06420410523611693, 0.06422887285870892, 0.09589379187673332, 0.04080484208140162, 0.038432957259036844, 0.03227608098137764, 0.05962033688481297, 0.06919786469229768, 1.4971905129571117, 52.932354096443426, 67.59987692679128, 53.02221559709119, 50.33509392892161, 22.898767648204682, 50.56348177694505, 45.43125652497815, 60.78630024386991, 60.60438463764807, 74.04389181444722, 20.407619360954534, 0.2698784345580686, 0.07432723703283457, 5.914546395501783, 1.35646065156306, 1.1905852104386976, 56.68531710101713, 41.667059852230935, 68.87029340190273, 59.57262869804137, 63.83238546309933, 54.61763966468073, 56.04881055893437, 46.89195502188898, 48.418733689092825, 44.27116455570344, 46.46123170852662, 42.36071140535417, 44.06574218503891, 41.4363891847672, 43.878904004250806, 38.97248960310413, 41.37825573644331, 39.28305502860777, 43.266829905971406, 37.44187485787177, 41.922072748984064, 42.09599456479473, 41.00581884384155, 40.63144822274485, 40.27868201655727, 40.76746425321026, 40.88182095558413, 40.36919463065363, 40.28409880976523, 40.36001628445041, 41.691892377791866, 40.95071346529069, 42.49639011198475, 41.24624836829401, 39.82481279680806, 41.08080671679589, 41.229056619828754, 39.318881957761704, 41.59622184691891, 41.69678357339675, 42.69461101101291, 43.2311834058454, 43.03868916726882, 43.57877208340553, 43.559799578882036, 43.73384691053822, 43.04216438724149, 43.981791696240826, 42.806896701935806, 41.60389792534613, 41.38030321367326, 41.44967817491101, 40.017581601296705, 42.77747108090309, 40.54155142076554, 42.23942779725598, 45.28827828745688, 43.01988532466274, 43.05735572691887, 43.786096803603634, 44.3004568161503, 49.21016600824172, 55.647473642902995, 52.12549117303664, 56.64055893498083, 53.67556871906404, 56.926433040249734, 46.68979214083764, 44.103593057201756, 42.869117259979255, 45.32047702420143, 42.598520786531516, 41.484928515649614, 42.826916479295306, 43.06905615714289, 41.441762831903276, 42.11123297291417, 40.97658149657711, 40.45796179002331, 39.45170125653667, 42.00003770089919, 42.032569839108376, 43.10681681479178, 43.77145067338021, 43.735011854479396, 43.892702902517016, 43.47788872257356, 41.55170294546312, 42.01207545495803, 42.706095710877456, 42.57509246949227, 42.03199325069305, 42.80885396465179, 42.63266109651135, 42.9530442145563, 42.7466098723873, 42.00794127679641, 42.84669306970412, 41.73383035967427, 41.40412376772973, 41.06579580614644, 42.80269192111108, 41.135782657131074, 41.91199225764121, 43.41187523257348, 46.85306472163047, 51.5416463728874, 57.30907986241003, 55.61352160669143, 55.09825552663496, 53.01664190907633, 55.60078959311209, 56.29533936900478, 54.40100716006372, 55.761414574038604, 55.356912305278165, 58.87926740031089, 60.8179537711605, 63.663292084970784, 61.89882563006494, 62.758475811250754, 59.741435743147335, 60.85263929059429, 62.89699039151592, 65.71595076591738, 66.03206634521484, 77.69699127443376, 47.48808076304775, 0.06366599741722308, 0.4630951859777974, 3.9807889730699606, 0.17676668331748058, 0.04666885826736689, 28.308557464230446, 75.14667403313422, 63.37911636598649, 69.89334167972689, 33.17392426152384, 25.209339818646832, 33.58554170977685, 50.80842202709567, 61.383712522445194, 67.02234714261948, 11.910316251939344, 0.1736677963767321, 0.0642188294460216, 0.028712071418281526, 0.028739999153561173, 0.06274322919066876, 0.05664497013053587, 0.05553446056681776, 0.20761952615312992, 0.2048818649904382, 0.2541931826741465, 0.12080872551568093, 0.1588526518354493, 0.17503814381216803, 0.19430784448500604, 0.22382847574209014, 2.5688099909213284, 64.83093461682721, 75.82193359251946, 59.39927562590569, 53.33405187053066, 28.1078831226595, 72.99418710893201, 59.92097831541493, 68.12546668514129, 63.67303133010865, 82.87003271041378, 23.319094719425326, 0.31609881729368244, 0.5840387736116687, 23.437281616272468, 6.628077991547124, 1.2556648086155615, 63.75605613954606, 42.65157084311209, 71.0693859284924, 61.79178807043261, 68.28043168590915, 55.76236770999048, 59.59967736274966, 49.59671951109364, 52.89489938366798, 47.258869217288115, 48.390704431841456, 46.43314361572266, 46.446856221845074, 43.86719572928644, 47.11231770053987, 42.661047289448405, 44.896284457175966, 42.02164603817848, 45.5985495351976, 40.308609700972035, 44.01603398784515, 45.43566526905183, 44.31070204704039, 43.248857605841856, 42.5187123206354, 43.52141134200558, 42.32969330203149, 43.76405308323522, 44.37943766194005, 44.306226622673776, 42.958225665553925, 44.76806217624296, 45.151622910653394, 44.64440553419052, 42.60534963300152, 41.77747849495181, 42.692194830986764, 39.79740719641409, 44.03080563391409, 43.4736329509366, 45.166504383087165, 45.56935141163488, 46.08659044388802, 43.60101192228256, 47.09613007883872, 44.917112242790964, 45.124844889486994, 44.71540827904978, 45.06607601719518, 43.635870026003936, 43.81513018761912, 43.55226862815119, 40.72850727265881, 44.944368793118386, 43.56868374732233, 44.80899603136125, 47.84731495764948, 45.38421161713139, 46.48354999480709, 45.10888476525584, 47.38857415414626, 52.971573875796416, 55.89029581316056, 54.894986537195024, 56.39805055433705, 55.30912214709867, 58.485210403319336, 50.34413106979863, 47.49713751577562, 44.688826376392, 47.28759665643015, 44.731250732175766, 43.304288541117025, 47.70171657685311, 44.97490444490987, 42.69015519849716, 46.0230911931684, 43.622647716153054, 41.822428857126546, 44.90606292601555, 43.96321142873457, 44.70209183231477, 45.303198983592374, 45.273228153105705, 44.439740180969245, 47.00279335821829, 45.151622910653394, 43.4973358338879, 44.18180904080791, 45.895947564032774, 44.979485773271136, 44.32272411161854, 44.38904746886223, 44.70248014696183, 45.57866311842396, 44.7126430080783, 44.542753388804776, 44.13436797357375, 45.8410696829519, 43.8760289069145, 43.024278379255726, 44.73318446067072, 43.01035004277384, 44.589590411032404, 45.663535364212535, 50.81337598062331, 55.76573310359832, 59.857180964562204, 57.04095055980068, 56.03272884122787, 56.40320847111364, 56.43898440945534, 57.29973677665957, 54.18598674958753, 56.931528199103575, 55.946024848568825, 61.87520119451708, 63.79014545871366, 66.99135257351783, 64.96040028910484, 64.71711135679676, 63.5797534450408, 63.97163352658672, 65.07474914673837, 70.65781947105162, 70.09251179233675, 80.8474939100204, 50.69113531420308, 0.15650488346094088, 3.121960773583382, 19.239790516514933, 1.7608403462556101, 0.16828477232446595, 32.063048231986265, 80.78250023626512, 69.28971244442847, 76.55271037932366, 41.838832209187174, 51.02953387844948, 47.31411187879501, 61.868313512494495, 69.54927921295166, 77.77712529705417, 18.033830350445164, 0.28570761904120445, 0.17309761245644864, 0.2746570458815944, 0.11511220296304073, 0.20254063900680314, 0.159319858216951, 0.19576574044842876], [0.05211413079392045, 0.047703276148005846, 0.0019118240062755744, 0.02313551823458364, 0.024657384454903584, 0.09161566579413992, 0.014747183923909982, 0.02888290519495645, 1.2628706929183777, 48.48925790479107, 60.1510057141704, 50.712037624851355, 31.16819085613374, 29.17957075180546, 43.95116975230556, 42.60908372940556, 61.3655323366965, 53.2086262395305, 70.16642493586387, 19.834508126781834, 0.13641130119081468, 0.14421383009081887, 2.4364905491951974, 1.1937144038177308, 2.2244070133855267, 68.26519720015988, 52.57089591795399, 55.991198785843395, 54.61569416907526, 59.911803891581876, 53.16332678641043, 51.86572828600484, 43.489718591013265, 44.39294238244334, 42.741326439765196, 43.51562976837159, 40.438820623582416, 40.16550986997543, 39.48524144388015, 39.68380751148347, 37.833562743279245, 38.41256341626568, 37.55999703561106, 40.040951082783366, 37.877489366839015, 38.85382613828106, 38.400333466068396, 40.465084814256244, 37.29500170676939, 38.672663627132295, 37.442718167458814, 40.506210865512976, 38.96375448473039, 39.34507554577243, 38.34757366488057, 40.67238207786314, 38.6700277943765, 38.55126234792894, 38.530893479624105, 38.47801208496094, 38.79330788889239, 39.42795522751347, 38.16241033615605, 39.25537093993157, 39.38267538624425, 40.17310750099921, 38.56354328893846, 40.221941009644546, 40.21533181590419, 39.238685177218535, 39.24149359426191, 40.04343394310244, 39.46657096185992, 41.32661773312477, 38.81075066904868, 39.14319115300333, 38.10133118783274, 39.621100579538655, 39.33221017160724, 39.67065972666587, 40.49820923036145, 42.88212383947065, 43.498469398867705, 42.51916339320522, 42.33169371081937, 41.35051673458469, 50.733410619920306, 52.14680141018283, 54.0801808141893, 54.09499560633014, 52.817130550261474, 51.41590695227347, 46.50551134540189, 43.29584367813603, 42.887964248657234, 44.44007358243389, 40.58843158906506, 40.19706533801171, 40.22910717994937, 39.16090849907168, 38.999200943977606, 39.67100489524103, 38.433854041561005, 38.435352386966834, 38.12904273310016, 38.54599852715769, 42.47076526764901, 42.48243431891165, 41.01478930442564, 43.237302303314216, 43.46781607597105, 41.05228324090281, 41.27953360157628, 41.72273789682696, 39.84305574047951, 39.663905405229144, 40.63488814138597, 39.23348803674021, 39.71419411320841, 38.79282935973137, 42.637356173607614, 40.01969183644941, 41.23126099186559, 41.25111602967785, 40.04766225814819, 38.991085560091086, 38.66799992899741, 39.67372702014062, 38.904157992332216, 40.450948592155214, 39.03527498245239, 46.081322700746604, 51.66487155422088, 55.43356326318557, 52.29368632839572, 51.24774317587576, 54.26762303998394, 53.105820917314105, 54.386823869520626, 55.43140203722062, 58.708565850411695, 58.69042488836474, 59.945461750030525, 59.251257142713, 58.01827184615597, 53.30994890582178, 53.26084475363455, 51.195591342064645, 53.364265887968, 63.707571721846065, 64.30665100774458, 71.50799320590112, 53.32857231939993, 0.04066672025909347, 0.08291079257164272, 2.0789454252489152, 0.13648142887940332, 0.05098851014589591, 26.809966910269956, 75.68944377283897, 59.20947605563749, 61.671547812800256, 70.38771721624559, 88.27094816392469, 25.763704084580947, 29.658919688194032, 53.35007867505474, 60.71844716225902, 12.023184414832825, 0.3189674182043922, 0.07630125409172428, 0.03190847177569184, 0.15564896406665926, 0.014313569540278086, 0.047738880084286776, 0.046297064306394714, 0.038932182285333836, 0.03609081196989264, 0.053747480044201504, 0.0782168722681461, 0.05106590800888596, 0.19365559722627365, 0.1141984898957514, 0.11034437815748876, 1.5546294566123717, 59.17898747228808, 66.6828424699845, 59.13289570039319, 37.31154234178605, 32.48514429215462, 46.734793493824625, 42.34320194490495, 66.24035989084553, 58.841918591530096, 72.97458310281077, 22.121840253953014, 0.3320427923913925, 0.14616514796451216, 3.292909432803431, 1.3531630414147533, 3.057767508491393, 67.15023209971767, 53.66163646021197, 57.81894483873921, 57.02891672811201, 62.84263418566797, 54.28124543159239, 54.938234590714984, 45.26917634471771, 45.73485582105575, 45.143401622772224, 46.24193199219243, 43.53355500005907, 42.23009255624587, 41.180011303194114, 42.31160333079677, 40.07098074882261, 41.24976673433858, 39.341184554561494, 42.41670716193415, 40.302902652371316, 41.04624279083745, 39.943076179873565, 42.49649209360923, 39.672158072071696, 41.72226721240629, 39.79301021945092, 41.718082043432425, 41.03811956221058, 42.138273792882124, 40.774779473581624, 42.07167979209654, 40.1784223125827, 41.95932349851055, 41.599771591924856, 39.64146944784349, 39.1329223878922, 40.7018861462993, 39.69989315156014, 39.742921552350445, 41.055746693764966, 42.089338302612305, 39.92832806802566, 42.32166813265893, 40.77053154668501, 40.89847533933578, 42.1123626155238, 41.68620886341218, 41.0483177246586, 43.38938043963525, 41.59888905863608, 42.1182422484121, 41.57920268274123, 40.57438165910783, 40.3546622491652, 41.3178708476405, 42.74761399915142, 46.163955273166785, 44.402301157674486, 45.43190763842675, 44.536799230883204, 45.17709086018224, 53.29206682020619, 54.35444078137798, 56.602939482658144, 55.12120531451318, 56.14107647249776, 53.5419806357353, 47.570932988197576, 44.96074861095798, 45.69921716567009, 45.774197193884085, 43.36963915055798, 41.27791758506529, 43.63947860656246, 42.16452621644543, 41.903476791997115, 40.722988497826364, 40.82309522936421, 40.33259499457575, 40.87348591896796, 41.022179049830285, 43.348254388378514, 44.724315981711115, 43.02282710229197, 43.991224996505245, 45.03287315368653, 42.710398550956484, 43.8972253953257, 43.842237687879994, 41.7214435146701, 42.929435468489125, 42.571338761237364, 41.07912794236214, 41.44388091179633, 41.33942427173738, 43.045725899357954, 43.34693647200062, 43.03775172079764, 43.08474563783215, 41.97515810689619, 40.81972591338619, 41.72666026699928, 41.57889281549762, 41.576955164632494, 43.04327441800026, 41.33732188132502, 46.475968053264005, 56.10475532470211, 58.080480637088904, 53.65709043318226, 54.087299916052054, 54.96500868951121, 54.073924633764456, 54.64500604137298, 56.82379637995074, 61.127236581617794, 61.94027723804597, 61.99009526160456, 61.077693123971265, 61.368219160264545, 56.89990997314454, 55.86076036576302, 54.66008755468554, 54.2634770947118, 66.7802506108438, 66.00128358410251, 74.75679828274635, 55.65069783118464, 0.2291661320674804, 1.500877173196885, 6.115811053783664, 0.26392660554378267, 0.017171087073943308, 28.24921004233822, 79.86300253099012, 63.294102914871715, 70.01436248902353, 51.62766002839612, 76.05468703854469, 34.309940722680864, 38.38438903131793, 61.509718664230846, 71.4488281742219, 17.553520433364376, 0.3323136504379011, 0.15327577689482322, 0.052856420196833155, 0.12375351387046038, 0.03876694478094578, 0.09577209880996136, 0.07647712489650135, 0.12378869262794334, 0.1617807164908417, 0.18492427864863029, 0.17865783264560087, 0.11219605863575013, 0.2584260329604149, 0.28244760848822137, 0.1513691985559079, 3.490598115228838, 70.57491625508955, 74.23327169110699, 67.1343308110391, 44.31109820642779, 41.04346967512562, 56.492509072826756, 53.45591991178451, 73.82110118865967, 61.96157963045182, 81.6224052060035, 24.412437754292643, 0.567904839352254, 0.34159857479314654, 10.08038543885754, 3.590734999987387, 2.740950805525626, 71.60041993664157, 55.89816408772623, 63.717326656464614, 58.69956008849606, 65.30276044722527, 56.67324012325656, 58.33949435141779, 47.38082355068576, 48.614310910624845, 47.432587069849816, 48.58000978346794, 45.440576076507575, 45.83089113235474, 44.51960748241794, 45.96177670263475, 42.70455421939973, 44.68523740768433, 41.8838414069145, 45.22969768893334, 42.08799292964321, 43.87296161343975, 43.827791598535356, 45.4143040410934, 41.374372589972715, 43.97875970409763, 42.29008520803144, 43.794149429567405, 43.82581472396851, 45.438316791288315, 43.868658773360714, 45.39254273137739, 43.41177717331917, 45.024098811611054, 42.181635595137074, 40.813050039352916, 43.420739789162916, 42.867693439606704, 42.34213506021808, 41.684957627327215, 43.4388493722485, 44.683613546432994, 42.957829506166526, 43.88097501570179, 42.78824190939627, 42.7405184315097, 42.541418921562936, 44.82928252989247, 42.68088663777998, 44.11269295600153, 42.910000124285304, 44.07917238050892, 44.21707899339738, 42.779459722580455, 43.88722335138629, 44.79899398742184, 45.575623281540416, 48.41716866339407, 47.41341452444754, 47.433732401940134, 47.84643634673088, 47.00054976247972, 55.5943412165488, 57.227576932599476, 57.90686476615168, 57.94723772233533, 59.954612639642534, 56.829997647193174, 49.828386460581136, 49.19638672182637, 47.55749494798722, 49.282561194512155, 46.19528716610324, 44.20262113694222, 47.17644060811689, 42.52650214779762, 44.62997513432657, 44.02151746134604, 41.594374410567745, 42.22052589539559, 43.19528195165819, 42.964662275006695, 47.027465066602154, 47.241936345254224, 44.855621245599565, 46.576835724615286, 47.79101325619606, 43.7145096255887, 46.44127468908987, 46.41725409415461, 43.51069150432464, 44.15796103016023, 44.710713201953524, 43.37013729156987, 43.86237513634467, 42.927344845187285, 46.602323285995, 45.94331018386349, 45.91283336762459, 46.725881868793124, 43.726531690166844, 43.245668718891764, 44.30646588725429, 44.374169918798636, 43.97331937666863, 45.034151846362704, 43.22588820611277, 50.536393888535045, 58.117527423366425, 60.07730437863258, 56.128991649996856, 55.45375562483265, 58.32221631080874, 54.83666873747303, 58.69249982218589, 59.13943821384061, 63.04392630054105, 63.85765729411956, 64.6205779044859, 63.54264782321069, 65.07955405019945, 58.29288874903033, 58.49390237562118, 57.280995691976244, 57.28495336348011, 70.24007135821928, 70.91946509576613, 76.1490749543713, 61.62306731747043, 0.5263975214573645, 2.7555346681225688, 10.226051480539384, 0.6646574540965019, 0.1311834405867323, 31.664815871946274, 87.78035379225209, 71.94090520181965, 77.8005418469829, 83.57194085274973, 104.37012826242756, 38.93962798580047, 50.070616352942686, 69.62907591173726, 84.35945864646666, 23.29206370538281, 0.45133166075233494, 0.23506727670469593, 0.21809086023319155, 0.2886931862561934, 0.13524173007857415, 0.16744343924426264, 0.17499118262240965], [0.055040261077304045, 0.0473320797356146, 0.05872053597422858, 0.07896147908702975, 0.021711692116373492, 0.03238311112527886, 0.04412976326420904, 0.2952740040998305, 3.1968741215044454, 56.36800127644693, 58.8579140170928, 50.902390249313854, 38.32349031202255, 25.896282157590313, 33.07315464942686, 42.586757598384736, 57.49422357928369, 55.76614495246641, 65.71453871265535, 24.812960778513265, 0.10177246715512969, 0.040016932142598015, 1.610976020174642, 0.7410244078886125, 8.765438295179798, 74.96381313570085, 57.966378888776234, 65.28625119117, 54.57942793446203, 57.66396807086084, 48.37041401094007, 50.93635797500611, 43.214344670695645, 45.50956664546844, 42.64114518319407, 44.7675601128609, 42.388654370461744, 42.824782709921564, 40.1586143432125, 41.93354960410826, 38.992854549038796, 41.0267682229319, 38.527967391475556, 40.29452446968325, 38.246019578749134, 41.04430906234249, 37.90920172968219, 39.55639716117613, 37.7200807294538, 40.36051834783247, 37.27871994818411, 39.118848923713934, 36.74069235401769, 39.522868740943174, 36.50131010240124, 39.27068387308429, 38.42083177258892, 39.597354550515455, 37.09518048071092, 37.121738849147675, 37.55484304120464, 39.964382494649584, 38.66332446375201, 39.4575338209829, 37.828467584425404, 40.31247323559177, 39.64454850842876, 41.47676606332102, 37.95122600370838, 41.23139827482162, 40.18496482603012, 41.95670335523544, 41.64444738818754, 39.26139177814607, 38.86719357582831, 37.93593660477669, 38.35033893585205, 41.03045525089387, 38.52327623674947, 38.19999056477701, 39.53549485052786, 43.68758255435575, 41.543528726024014, 41.36845373338269, 42.229782689002256, 43.96625911035846, 48.13158089114774, 52.558144292523785, 54.63094434430523, 55.48052187888853, 52.35892318910169, 51.56243885717085, 45.88776157748315, 42.63724634724279, 42.593158906505955, 44.5451303451292, 40.22423559619535, 37.592740981809555, 39.64648223692371, 41.164533630494155, 39.61380497101815, 37.777261041825824, 37.043597390574796, 37.65225510443411, 38.574235670028195, 38.20652131111392, 38.683057908088934, 41.522273402060236, 40.78589939302014, 41.978613715018, 41.845657133287006, 42.69978069490002, 41.60409404385475, 40.01372198904715, 40.01032521647792, 40.58024560251544, 40.4280968635313, 38.62547751395933, 39.90633926083965, 39.2953202801366, 39.75642235048356, 40.56933749106623, 40.119072929505386, 40.163807561320645, 38.007743435521284, 36.05290082193191, 38.30865590803085, 40.890532539736846, 39.77675199508667, 40.29652487847113, 42.874643879552046, 38.44751957924136, 45.83672761917115, 52.02971473816903, 56.00095372046194, 54.29961781347952, 58.7229178028722, 56.693020636035556, 57.914125073340635, 57.746522195877574, 56.839803572623964, 54.59596072473834, 54.867278914297785, 51.43595418622417, 47.81030347270351, 45.50406356011668, 45.75252609868204, 47.21634680225004, 53.53192760098366, 59.921515680128536, 66.05945233375796, 67.99092938823085, 61.61969407912224, 0.6406187794862256, 0.37729051925482293, 0.9585608962562777, 0.06956822989929108, 0.0374713292225234, 27.07965731620789, 70.43764898853918, 63.548296036258826, 64.05622336172289, 63.04630717923565, 58.11366781111687, 20.0211246936552, 39.42289536999118, 50.028968626453036, 67.21499827600294, 18.911256713251916, 0.04359183547597739, 0.024253428207650304, 0.011693437756489844, 0.04689461288733348, 0.04655432812268696, 0.08217710250568006, 0.06930408278299917, 0.018234759937190724, 0.06808495344293695, 0.08067154821248786, 0.05406722982203769, 0.08684499114150963, 0.0638723929953431, 0.04426734882497019, 0.3321914440922199, 4.662423854874027, 64.04542115426833, 66.57074897520005, 57.49214080072219, 51.08441175953035, 31.220327000464167, 31.32623491748687, 48.31237862187047, 61.18710763992802, 59.68473395993633, 69.88633632659912, 27.58469189366987, 0.029582498602629192, 0.12565063868439005, 2.464432043413962, 1.206220145667753, 8.589916152338828, 77.4383972537133, 58.10921199860112, 68.0390254912838, 56.429429515715576, 60.08665530912338, 50.312155908153905, 51.79700836058586, 44.93983061082902, 49.29330456641413, 45.425369047349506, 46.841654546799205, 44.80999231338502, 45.46155291218912, 42.72213428251205, 43.81875445765834, 41.56983606276974, 43.75921680081276, 39.62361089644894, 42.22216152375744, 39.80833491971416, 43.02639645914878, 41.319620224737356, 43.74725749415737, 40.59358558347149, 42.147597266781716, 40.147474811923125, 41.94638752168225, 38.9006043249561, 40.47416510120515, 39.189910504125784, 41.724589255548295, 39.58433620391354, 42.50911035845357, 39.76817377151982, 40.8052170661188, 39.2594894286125, 40.64549815270209, 41.45045480420513, 39.6002100360009, 39.66325036941036, 41.5304672333502, 40.380706787109375, 42.499990847802934, 40.95069385343983, 43.72060891120665, 41.357404416607274, 42.96800021202334, 41.61508452507758, 41.94176696961926, 39.439643890626975, 39.60121808513519, 40.24552229912051, 42.06117568477508, 39.217331794000444, 41.28120845363986, 41.420374147353634, 46.20257885225358, 44.566624933673495, 44.12577798289638, 45.010707839842766, 46.647203045506636, 50.84892049912484, 54.36908691160141, 54.513065353516616, 57.23759466601957, 56.08654768236222, 54.20592023480324, 48.103532022045506, 44.41737874861687, 45.34574101048131, 47.46989273255872, 42.83121147463399, 39.07966836806267, 41.67022128258982, 43.22158928840391, 41.205389038209, 39.910057667763006, 38.19370692776096, 39.81793295952582, 38.85546176664291, 41.935691218222345, 42.12160764201995, 43.16857061078472, 43.73270550081807, 44.56253782395394, 44.65661195016677, 44.558835106511275, 42.4345382567375, 41.568239658109604, 41.71590120561662, 41.31378373792095, 41.33815734617172, 43.16034932290354, 42.690767088244044, 41.94841930943151, 42.31508639550979, 42.30648856009207, 41.607086812296224, 43.70394668271465, 41.22648354499571, 39.69725339643417, 40.89801249965545, 42.76275434801656, 43.21408579426427, 41.578418208706765, 42.41400857125559, 41.71624637419178, 48.181296933081846, 56.12805812589584, 57.59675433558803, 57.18185778587096, 60.64460069902482, 59.410293563719726, 60.519061319289676, 60.306072696562744, 58.928453922271736, 58.12562319540209, 57.144034370299316, 52.92341109245054, 50.74057286785495, 46.84503562988774, 48.310233085386216, 49.394466415528335, 54.194266873021284, 61.31181939955681, 69.00239882930633, 70.63479515814012, 65.28573736067742, 0.9400282487753899, 1.222061985923398, 3.3584316459394272, 0.20796460279774284, 0.07442598576627432, 29.399005789910596, 73.79707274898406, 67.95128207052907, 71.13346176762735, 78.06377995398738, 75.94636686386602, 24.054956859157933, 44.54340842462356, 56.786710369971495, 75.28747927758002, 23.76958089490091, 0.03636725479736924, 0.07701723986575681, 0.03580602644492061, 0.06915628143976774, 0.053558474661962646, 0.06468454961695018, 0.05318738933232042, 0.16006276432064273, 0.12000924381878107, 0.2192753087729216, 0.29112373809179953, 0.1759940070370513, 0.12351051078087862, 0.2690859319221589, 0.5768767708251553, 5.819442647118723, 74.32218397817304, 73.51368150403424, 66.75881878022226, 54.14228762349775, 37.031026194172526, 44.23165844332787, 56.46625664926345, 68.10430157569148, 64.53465446349114, 75.76146633394303, 31.898455773630452, 0.35227903555477824, 0.5316129867588321, 6.7247349985184215, 2.7699486430614226, 10.008365819531104, 79.65049635979437, 61.67401106126847, 70.30884619682067, 60.978821939037694, 63.97099810261881, 53.24722236202609, 56.10357861365042, 48.57937043712985, 51.99069499969483, 48.26953457247827, 49.789594219576934, 48.46420572650049, 46.86654590791272, 44.51165291570848, 47.49684726038287, 44.92849103866085, 45.583722975946245, 42.20552282948648, 46.44031763076783, 42.32440986940938, 46.95896087154266, 42.77230531938615, 46.09694550114293, 42.12059959288567, 46.13607506598196, 41.483728270376886, 45.6100263903218, 41.3059978331289, 43.63230851388747, 40.47676955499957, 45.397257420324514, 43.221652046326675, 46.386416419859856, 40.793748055734945, 41.67318267206992, 40.575832936071585, 43.002528836650235, 44.06141581073884, 42.32177011428341, 41.39328233657345, 45.199330699059274, 42.20914317715553, 44.142710854930264, 41.807433635957786, 43.87488749719436, 43.1192389611275, 46.15700875559161, 45.05807830441383, 43.359892060679776, 41.62921290243826, 42.6924301731971, 43.021195396300286, 45.85534318800896, 42.66313791275025, 43.547318596993726, 43.777071429837136, 50.66753049050608, 44.96574963292768, 46.5626367445915, 46.406169476047644, 48.84018844173801, 51.72828843516689, 55.8453768299472, 57.97219968611195, 58.92934037793068, 58.098500005660526, 58.556472024609974, 49.81701943182176, 47.13780918428975, 47.531677907513036, 51.571942760098366, 44.88761994146532, 42.56039142608643, 45.05203000960812, 46.40592628909696, 44.384944669661984, 42.56317630890877, 40.90488056982718, 43.14786049627489, 41.64644387460525, 44.515336021300286, 43.919127910367905, 45.82029288814914, 44.736561621389086, 46.70764676986202, 47.37646971979449, 47.371955071726155, 43.97144056135609, 44.00006994124382, 44.582902769888605, 43.746547545156176, 43.85802522782357, 45.25831530171056, 45.87294286297214, 43.22060869586083, 43.77116434035763, 44.65991458585186, 44.78728963482765, 45.45468876438756, 43.437551067721465, 41.041096641171364, 42.24923372268677, 46.73997886719243, 44.21439216982934, 43.95577853725803, 46.717805708608324, 43.49357035852248, 49.478616945205204, 57.23329967068088, 59.34081662085749, 59.848135978944846, 65.08890890306043, 61.33465543870003, 64.78819254905947, 62.73636541058941, 60.288582847964385, 60.11235860086257, 59.81628633314564, 56.88548741802093, 53.987514818868334, 50.29592514038087, 51.66899396527199, 51.576916325476866, 57.232056279336255, 63.361548069984686, 71.17428579638081, 72.29253784302743, 69.21015108785322, 1.2512954108176695, 2.43186239754, 6.039371903865568, 0.6481570233741115, 0.17088772458655221, 32.465336322784424, 81.45144477967294, 74.55401174483761, 79.21478379157283, 76.70820097769462, 66.64517987158992, 33.3560634428455, 57.84486778320805, 66.43854156617196, 85.87186182698896, 31.995840380268714, 0.1812976490586035, 0.11491833675292232, 0.23450037164072837, 0.2800677103861686, 0.20989830064917767, 0.301114535860477, 0.13068497781791996], [0.032506581516035145, 0.04703258532249639, 0.07391227784776881, 0.0419215033311517, 0.01859600486744556, 0.07800290391089455, 0.03809143526239261, 0.1527209606983008, 4.188393162142846, 60.197587782336825, 52.63126903964628, 44.96512989844046, 16.743170522874404, 41.567612078882036, 66.8263541498492, 41.90824247175648, 57.612133949033684, 56.142433612577385, 66.7664046441355, 28.029873063487393, 0.04416689937633853, 0.16570314795019167, 0.3749451870399137, 1.006403516136831, 15.184947194591647, 74.93556422571983, 55.23971188452936, 63.27900963444864, 52.524878671092374, 54.18138188700522, 46.944259828136815, 48.28046621814851, 43.00368593585107, 45.01096671627414, 38.906601628949566, 43.221436315967196, 39.697261241174516, 41.59983434984761, 39.289115090524, 40.83097919341057, 37.99548602873279, 38.314355111891224, 37.74093597166, 39.28203913473314, 39.25459823300762, 39.591290566229056, 36.915253516166445, 39.43086562618133, 36.12235815294328, 39.427594369457616, 37.64553608432893, 38.05421567732288, 38.15178071298907, 38.341619506959, 37.17664810918993, 39.02298227433236, 37.26481514592325, 37.55320741284279, 37.56400962029734, 39.7961873392905, 37.99104198332756, 40.62016748612927, 37.8943516362098, 37.16208042636995, 37.86731473861202, 39.16166159414476, 38.457047016389915, 39.84249091917469, 39.169816201733006, 40.59632339785176, 41.290653521014804, 40.85898883881108, 40.04077065375544, 38.95752576089675, 38.845024339614376, 40.14616866265574, 37.14030342717325, 38.79352754162204, 39.596656368624785, 40.723200305815666, 39.96843430303758, 43.18443659813174, 40.348861063680346, 45.37234252498996, 43.011263955023985, 44.168116046536355, 49.03937424382856, 54.30858435169343, 54.52368320957307, 53.744661269649384, 54.242417889256636, 50.47494603741554, 46.331593451961396, 43.37139637239518, 45.463400348540276, 44.43555501199538, 42.81827549780569, 37.82288212930003, 40.37392500908145, 42.77762797570998, 40.29351642054897, 38.94110671935543, 37.18528909067954, 38.67823339277698, 38.23208731989707, 39.928583022086855, 39.2284595581793, 39.804679270713564, 41.77445826991912, 44.018979687844556, 41.321604944044545, 41.0469723516895, 41.06694113823676, 40.73112741593392, 40.350288806423066, 40.523347700795824, 40.04031565881545, 40.96879166941489, 41.131891665920136, 38.662842012220814, 39.16916116591423, 40.01047426654447, 39.88847286470475, 40.01871516627651, 40.222835310043834, 40.09076910634195, 38.98885765383321, 38.956772665823664, 39.72537286819951, 40.70052900621968, 41.21208060172297, 39.67226397606635, 40.961919676872995, 42.699325699960035, 49.5609357280116, 54.06849999581614, 54.73079612178188, 55.96387555522304, 54.114399571572584, 54.77410693322459, 52.684632885840635, 49.798219511585856, 44.325642355026744, 40.52528142929077, 44.72785003723637, 46.48091023968112, 48.01939718184933, 48.00013442193308, 49.21162120757565, 55.97080246094735, 65.00237749468896, 66.45151676670199, 66.64317161806169, 2.0996432823519555, 1.696578684833742, 4.683270271747343, 0.26530963939524466, 0.11432880145167151, 23.780949884845366, 74.18602282001127, 59.14566693767425, 67.16132456256499, 36.534461975097656, 24.361676400707616, 26.573636262647568, 40.78301645094349, 50.26315373759116, 62.46075222569128, 19.650390109708233, 0.12802444638744478, 0.07447592703805817, 0.048433518818309235, 0.03624447005530519, 0.04516772813193741, 0.0329350889660418, 0.11466392661414801, 0.052741353790606224, 0.03504429756092929, 0.09749393504593643, 0.05479798960168997, 0.04011879119301035, 0.05999779989642482, 0.061849526339961644, 0.21030973582979173, 5.305027231093376, 69.41453010805192, 59.65280194436351, 51.98432114816482, 22.78170451041191, 28.16807189295369, 62.2112149576987, 49.020915569797644, 62.014916020054976, 59.2851189644106, 72.109174882212, 31.31518363952637, 0.026204263445951288, 0.21378942975594153, 4.782326298375284, 0.5753608973276231, 15.960896938077866, 78.30799456565612, 56.37828965340891, 66.47756130464616, 53.91963035829606, 58.17474695944018, 50.670715455086004, 51.75276794741231, 44.02635374376851, 46.91433606609222, 41.83258387350267, 46.324121336783136, 42.453067533431515, 42.97189120323428, 40.43879708936138, 42.08092874096286, 41.13803801998016, 39.78423587737545, 39.178806274167954, 41.66305118991483, 40.55703301583567, 41.60648668965986, 39.213585930485884, 41.71035497419296, 38.50775541797761, 41.373231180252574, 40.28827221162858, 41.031055373530236, 39.377850870932306, 41.49258890459615, 38.83426527823172, 42.00412088824857, 39.45844773323306, 42.06007742112683, 39.748357957409276, 40.45496117684149, 39.41318358144453, 42.22662518101354, 40.408712510139715, 39.61408738167056, 39.33359084590789, 41.7838837254432, 41.673425859020604, 41.09542931279829, 41.061398829183275, 42.79027369714553, 41.6063964751459, 42.35425518405053, 42.08339983417142, 41.995005299968106, 40.31181035503265, 40.83618810099941, 39.64223431002709, 40.635417661359234, 41.5937860550419, 42.348112752360684, 43.34323375455795, 45.77542489574802, 43.20129102276218, 47.149960687083585, 45.54948068434193, 46.78255227304275, 51.430027484893806, 55.375484728044086, 56.61053711368192, 55.23983740037488, 57.67159708084599, 54.01787396400206, 49.47609093881423, 47.11348656685122, 47.75644540786744, 47.19259292848649, 43.61769376262542, 40.944057203108265, 41.19212358228622, 44.79283194388113, 41.37562774842785, 41.44683053416591, 38.68361880702358, 41.74200065674321, 39.97448652021347, 42.00387770129789, 41.56708648127895, 41.82994804074688, 42.66777415429392, 45.96089809171615, 43.919108298517045, 43.54240386716781, 41.951631730602635, 42.468560895612164, 42.193932225627286, 41.78627244887814, 40.36559781720562, 42.2404593806113, 40.651726876535726, 42.13628907357493, 40.54519138028545, 40.95136065636912, 41.86096614406955, 40.74953902152277, 41.52987887782436, 42.04327398730863, 41.420401603944846, 41.215720561242875, 41.453259298878336, 44.14303641165457, 43.25254071143366, 41.32084008186094, 41.714120449558386, 46.019568904753655, 52.53619863140968, 56.48645685565088, 57.107972098935036, 59.455620473431004, 57.32455753510999, 55.922886786922334, 55.64797570628505, 50.51738216030983, 47.83089983847834, 44.07850557757963, 47.441235896079775, 48.65822968944427, 49.19593957162673, 49.4382792903531, 52.18162813494283, 57.49337634732647, 68.4634651676301, 68.3025146299793, 71.90178348172095, 2.394671709306779, 1.860603134958975, 3.94885033849747, 0.18209370634248181, 0.04959061035826322, 25.909192639012492, 78.28348759681948, 64.23635428951633, 73.60705744835639, 46.61574563672466, 30.779201561404815, 35.996410846710205, 52.93270318738876, 56.116141965312345, 71.15832959451984, 25.161222142557946, 0.06783186863627165, 0.05666976839664483, 0.0441199841518556, 0.020956446251441396, 0.03681361209601164, 0.015568126616398654, 0.00852880131964001, 0.18150455408519317, 0.12611129501413915, 0.2732570355217303, 0.16193258576095104, 0.15193515367084934, 0.23200076463962757, 0.2950396731255516, 0.3313323530939318, 6.17925686220969, 81.13051645217404, 67.20825179930657, 60.105521909652225, 26.97733444552268, 53.47844216131396, 75.37412443468648, 54.049892271718676, 68.91443575582197, 64.79109510298699, 78.20020783332087, 34.61443039678758, 0.1416201781361334, 0.641705337310991, 7.632260159138711, 1.8009709735070507, 17.43083065555942, 79.16486770875993, 60.538390759498846, 70.11974088607296, 58.090427767845895, 62.27966031720562, 53.45594736837572, 54.71818570167788, 47.88702895564418, 50.09844949168544, 43.26177004844912, 48.96807732120637, 44.40750614289315, 47.1999591396701, 45.91009555324432, 45.845117568969734, 42.82555541684551, 42.42884689761747, 41.39477283723893, 44.44724367510888, 42.6016822168904, 43.571460785404334, 41.00899596368113, 44.126558534560665, 39.22541972129576, 45.56944554851901, 42.41998234102803, 43.23627856469924, 42.685028660681944, 43.771795841955374, 41.460625510061945, 44.020156398896255, 42.71199495561662, 42.76403304069273, 41.790838087758715, 42.67319879224224, 40.820365259724284, 46.192804305784165, 42.40068035741007, 40.97365540842856, 41.38188785122287, 43.21481143274615, 42.29467438113305, 43.95793191848263, 43.56497710750949, 44.62433476601878, 45.26728183992448, 43.736388606409875, 43.261197382403964, 44.87367199313256, 42.91582484399119, 45.98480886028659, 42.6518375642838, 42.291932644382605, 44.01073878811252, 46.59537284604965, 45.106268544350904, 49.000876180587284, 45.3962532935604, 50.195359491532855, 48.333073046899614, 49.03535773677211, 52.75889904268327, 57.94040887586532, 61.09884646631057, 55.93295943352484, 60.31132475022347, 56.9190707514363, 52.62821743565222, 48.486139620504076, 50.21348476409913, 49.769645044880534, 46.526064565104825, 41.444296683034594, 43.66592714863439, 48.159551312846524, 44.44312126405778, 43.447392294483805, 41.52453268727949, 43.44337186505718, 42.02778062512798, 43.76943457511164, 43.68374647632722, 42.25599588886384, 44.84612910978256, 48.8051655984694, 45.90407079265964, 45.277507458963704, 45.464020083027506, 44.536532509711485, 45.057270296158336, 43.42412087225145, 44.261476301377826, 45.76288115593695, 43.8529339913399, 44.76577935680267, 43.20799827575684, 43.113527990156605, 44.01258622446368, 44.75479279795001, 45.35855931620444, 45.08507205593971, 45.051190622391246, 44.412699361001295, 43.30397475150324, 45.863784128619784, 46.07654525387672, 43.96595708785519, 45.131705114918375, 48.05684404988443, 53.787320967643495, 59.45755420192596, 59.97885288730745, 61.36782300087714, 59.36701413123839, 59.41067795599661, 58.53328297215124, 54.12046747822916, 50.86645349379509, 45.41862257065312, 50.58641195297242, 51.02758838284401, 53.07420661372524, 52.082254886627204, 53.54792302654636, 59.890195554302586, 70.64715846892327, 71.99195092724216, 74.43650537921538, 3.5358220627230987, 5.144591994823949, 11.724698908867376, 0.7243906778673972, 0.260524470359087, 28.114584492098903, 88.58636163896131, 69.11190355977705, 81.20986600075999, 49.26081557427683, 37.02499751121768, 40.731523575321326, 62.237836084058216, 66.6138401339131, 83.23796672205772, 31.82282659315294, 0.3379037327343418, 0.2822757902885637, 0.1727749209009832, 0.08635425053897404, 0.1167030151813261, 0.14880946897450956, 0.3381296060979367], [0.053719456547931324, 0.07933500057627117, 0.10915779223245, 0.06642531588553421, 0.04145253877786379, 0.0635662068042063, 0.06854706533974217, 0.3958309808325383, 5.496330049730116, 57.05157233822731, 56.85838384013022, 38.61947628759569, 36.80394057304629, 73.80337992022115, 84.01629832483108, 54.6455551731971, 52.4912678810858, 57.403526613789225, 63.53179462494389, 29.69064970170298, 0.14241068894343992, 0.023820012049268813, 1.3407526621895454, 0.5389411999813972, 20.31952096569923, 75.96813601832237, 53.53056261616369, 63.61967140628446, 46.27726862507482, 52.8638106776822, 40.82502111311882, 46.59420790210847, 40.73285325880974, 45.34974967279742, 40.23847772229103, 41.725675752086026, 40.570463211305686, 42.57700658613636, 35.78829380773729, 39.964468786793375, 39.00109937114101, 38.993019288586034, 36.90623598714029, 38.81876014894055, 36.39552377885388, 38.9074331714261, 37.77920653743129, 39.815975696809836, 36.37923025315808, 40.90345674945463, 38.51205433568647, 37.92129831929361, 38.29823809285318, 37.8216818840273, 37.01456792892949, 39.24568660797612, 37.53418783987723, 38.687941258953465, 37.17945652623331, 39.56648157488915, 37.770573400682025, 39.70625915834981, 37.73705282518941, 38.19213013495169, 36.727842669333185, 38.11280804295694, 38.14685029368247, 40.10794124295635, 40.12477213336576, 38.69333059557023, 39.88359735858056, 41.6058865670235, 42.42186115634057, 41.74495812385313, 37.24900014938847, 38.91809417355446, 37.381992032451016, 40.25953300537602, 37.16651662703484, 38.23591555318525, 41.20901330824822, 44.77554605853173, 42.562709546858265, 45.528845094865375, 42.3201423306619, 44.74515553443663, 48.09690713882447, 53.084840159262384, 54.05413235387495, 52.63457559770154, 54.02419290234966, 50.525540690268244, 45.06810780494444, 43.21546254619476, 43.5266084824839, 45.611054051306944, 40.24816597661665, 38.40626016739876, 40.16091285213348, 42.164067299135276, 38.92925723906487, 40.090443549617646, 37.697887959018836, 39.531654850129165, 37.820960167915594, 40.257261953046246, 40.40700627911476, 42.18859780219294, 42.02020652832524, 42.48496424767279, 41.96961187547253, 41.06659596966159, 40.852026631755216, 39.780984232502604, 40.30030996568742, 40.20692617662492, 40.85433298541654, 40.20690264240388, 41.47301235506612, 40.7505274588062, 39.21986956750193, 41.36575514270414, 38.27875960257746, 38.47492125726516, 39.27519459878245, 38.53517670785227, 40.78159655294111, 39.34058050955496, 38.42288709455921, 39.090839278313425, 39.126815257533906, 40.65469611075617, 41.402025299687544, 40.774850076244725, 42.09586120420887, 42.005117170272335, 46.2801907908532, 46.11139943522792, 46.46387538602276, 45.78905513209682, 45.51377142629316, 42.714909276654645, 43.770438701875754, 50.01724466200798, 56.78894612096972, 55.664477117599986, 57.35610908077609, 55.872248987997736, 57.41247746252245, 55.12672408934563, 64.78115581697034, 63.053241929700306, 72.53129251541631, 3.2018577379565087, 1.6422034800052645, 2.625846891633926, 0.06017022330554263, 0.12970027904356682, 19.136006562940537, 72.57909051833614, 60.13747745944608, 70.22481333824896, 56.42508745193482, 34.43983785567745, 15.982158145596905, 41.897895259241906, 48.71567280061784, 60.877589487260394, 14.817724112541447, 0.3141222798055218, 0.06117452626987811, 0.025287980153676004, 0.007980639554349887, 0.06651304827462282, 0.0862816866907862, 0.10761532016218671, 0.026254825248953798, 0.09882526562338877, 0.04425866904878809, 0.07620614427592486, 0.16778106951425154, 0.0629206704756906, 0.22233788314605915, 0.3995193571092621, 6.306032769141659, 64.9307785495635, 61.54297644092191, 46.450598162989465, 39.236990713304095, 74.67312628223051, 85.09201618932909, 54.67833442072715, 58.81454829246768, 61.666648772455034, 69.55946953065934, 31.28285546456614, 0.05447147526748238, 0.12484862123646083, 2.344760774604736, 0.5279345389816069, 21.492286113000688, 80.50671054470925, 56.79440606024958, 66.86815877114573, 51.25892977560721, 55.41234716292351, 42.054197788238525, 49.28985680303266, 43.12927630639846, 46.969147266880164, 42.07089139569191, 44.31078441681401, 40.87898900431972, 43.56954274639007, 39.47092087038102, 42.614818234597486, 40.2320058115067, 41.99587606614636, 39.881840136743364, 41.0780296787139, 39.87037897109985, 42.73782376320132, 39.39622325281943, 41.11122077511203, 38.333747310023156, 41.37139158864176, 39.52346886357954, 42.181313960782944, 39.70901658458095, 38.949622184999534, 38.58564976722964, 41.76271077125303, 39.94962653806133, 40.76708378330354, 38.10457498796525, 39.98757939184866, 38.70561545894992, 40.68726355029691, 39.841259294940585, 41.30782957999937, 38.695766387447236, 40.199234408717004, 40.34294220709032, 43.26248391982048, 41.72971579336351, 41.902245167763006, 42.325080594708844, 44.20301337395945, 43.02199948218561, 42.13263342457433, 39.95187013379989, 40.31547384877359, 39.347883962815814, 40.149938060391335, 39.90316606337025, 40.24503592521914, 42.793921501405784, 45.47432022710001, 46.65272182033908, 47.20725474819061, 45.418006758536066, 45.98449507067281, 50.23477146702428, 54.43288426245413, 54.43335494687481, 56.12798360086257, 56.611403957490005, 51.85950740691155, 48.86728417488837, 47.513030959713845, 45.568461033605764, 46.671917899962395, 44.26535944784842, 39.53795809899607, 41.86231543940883, 45.22286884246334, 42.102490009800086, 41.58896153972995, 40.53053740532168, 41.343534915677964, 40.208448056251775, 42.27884369511759, 43.37629933511057, 44.72471998583886, 43.85377730092695, 43.645319015749045, 43.520218941473196, 43.081293952080514, 42.51793176897111, 40.325009130662494, 41.18866797416441, 41.34757103458528, 42.36593600242369, 42.565396370426306, 42.44135141372681, 41.496817219641905, 41.55440545851185, 44.190383342004594, 40.24211768181094, 41.56833771736392, 42.011283136183216, 39.42663731113557, 41.713355587374785, 41.208966239806145, 41.65086046341927, 41.3222913588247, 41.077766879912346, 43.86606216430665, 42.50662357576432, 43.19101049054054, 45.24933307401596, 44.42570201812252, 49.29415179837135, 48.45576086351949, 50.4409194761707, 46.70443042632073, 46.96127114757415, 44.097332954406745, 46.090485357469134, 52.21306593187394, 60.152715867565526, 56.37179028603339, 60.719757233896566, 57.77566148388771, 59.138151676424094, 57.492203558644945, 68.87211338166269, 66.12933328074794, 78.17279046581638, 4.038909183394525, 1.1101103093354934, 5.353554304568998, 0.28180685254835314, 0.0694548182429806, 21.43088140795308, 79.19758027599704, 66.27638293850806, 75.01100709361415, 56.67584065468081, 35.111547670056744, 15.862218929875283, 45.58238937008766, 57.27353142153833, 70.28617489722468, 19.482508743962935, 0.31460295401273236, 0.07560595269164733, 0.05690578859479678, 0.07814792435496085, 0.06739224142004406, 0.05909324541027027, 0.03652136104421751, 0.19207244588723107, 0.2151590111034532, 0.23598730233648132, 0.17290604451010305, 0.23127095863944103, 0.13655486606782483, 0.2623602315302818, 0.6106597773971096, 7.304921698185706, 73.4987372736777, 70.71551753628638, 53.581992733863096, 49.590094627872595, 84.92333858243882, 83.50190301095286, 64.12411566703551, 66.17667628872779, 66.65942592005577, 74.44467175391414, 36.919407306178925, 0.28334966169730313, 0.2801171690225601, 7.23538984214106, 1.8088084819816777, 25.324632006306803, 84.70943604746174, 59.48855661576795, 70.93517811067643, 52.25614924584666, 57.162881358977295, 45.14812415645969, 51.781260044344016, 44.916488585933564, 49.593891482199396, 44.07519901952436, 47.31151919211111, 44.90352123014389, 46.53933394339777, 41.63057004251788, 45.79745292663575, 43.75939722984068, 44.2932592668841, 41.95107867640834, 43.161110262716974, 42.419837213331654, 45.67482786793863, 42.01970446494318, 44.118086214988466, 40.35612529323947, 45.640362001234486, 41.834890227163996, 43.39308315707792, 42.90519129845404, 41.722114239969564, 40.745024373454434, 43.68749626221196, 42.54920874872516, 42.94847857567572, 40.31888238845333, 43.8451127852163, 41.059296438770915, 42.53511567269602, 42.11612809088923, 43.09717170653805, 39.4679202571992, 42.391098007079094, 41.08132446965864, 45.029531294299716, 44.194125283148985, 43.842269066841375, 43.44898477677376, 47.840509645400516, 46.72805093949842, 44.35467573904222, 42.266707881804436, 42.3020209804658, 42.22305190178656, 43.57772481056952, 42.7427424153974, 42.30223671082528, 45.68845418191726, 49.07769580041209, 48.02440997092955, 50.05688021259923, 47.712134392030784, 48.700524607012355, 53.82870981770178, 58.65423317878478, 60.49343255258376, 57.23297803632675, 60.85819336675829, 54.940442885121996, 50.69434381300404, 47.457800065317464, 47.359709432048184, 50.288782504297075, 46.34019128737911, 41.54324631537161, 45.05207315568001, 47.14641878681798, 44.60681353845904, 45.777817541553134, 41.55957906476913, 43.12328684714533, 41.842021096137266, 44.80639157756683, 46.142135127898186, 45.90301959745346, 46.34332918351697, 45.27068645723405, 47.52186021497173, 45.830389068972686, 44.1835819521258, 41.7950624804343, 42.64367903432539, 43.192626507051536, 44.76340240047824, 45.89375495910645, 45.59167362028553, 45.341489161214525, 42.434542179107666, 46.643696446572584, 43.23239541822865, 43.57232370684224, 43.76890113276821, 43.32121356841057, 44.17739637436406, 43.76777541252875, 44.35009441068096, 43.613783159563624, 43.256921998916134, 46.81016183668568, 47.41353611792288, 45.39810465228173, 47.23704122727918, 48.416717590824256, 52.33454958085091, 50.736144511930405, 52.61094331741334, 50.439946728367964, 49.73824254928097, 46.70759970141996, 49.90202896056637, 53.58431869937528, 61.96365456427298, 58.78061586810697, 63.997297594624186, 58.811041693533625, 62.56275346202236, 62.28789337219731, 72.34207737830378, 68.3130265820411, 79.64069043436359, 5.631555722605798, 3.529093726988762, 7.8981017393450585, 0.49311241074915857, 0.16790624828107897, 24.0586595766006, 87.92424201965333, 72.38825936471262, 82.76847470191218, 69.88033510023548, 46.35331946034586, 25.838666462129165, 61.07112315393264, 66.07088212044009, 83.45695264877813, 26.646260907573087, 0.45303473549504436, 0.13777954954533808, 0.10686472253573519, 0.10754528440414898, 0.18965139354188598, 0.11436369675662249, 0.16697433296470873], [0.06533696541502591, 0.04888129721005117, 0.03456167749039108, 0.09262667202781286, 0.05839051295732779, 0.11302091316470217, 0.07519804917636418, 0.385221459812695, 6.410089327443031, 60.29784356394122, 61.705950921581646, 38.42274196686284, 30.475113930240756, 59.135923770166215, 87.55872418803554, 53.67710236580142, 55.14246456084713, 59.27510907573085, 63.9657852726598, 33.123780681240945, 0.06997921308802982, 0.18284569824895552, 3.781562721537006, 0.26075751430565314, 22.8161213474889, 72.67990327650502, 52.82090779273741, 59.026509254209465, 43.94752979278565, 48.26458454132081, 41.85832246657341, 46.957395845843905, 43.10625591585713, 47.13695802996236, 44.551817986273, 46.94408332147906, 39.55047438221593, 42.05864183364376, 38.26957733400407, 38.51656506138463, 37.706787816939816, 40.917867537467714, 36.74723486746512, 38.907013477817664, 37.798010380037375, 40.17108355799029, 37.93297913766677, 38.8952346001902, 39.35708976561023, 42.31211323891917, 38.130682283832186, 40.58683126203476, 37.986954873608006, 38.60552833926293, 37.945640548583, 39.136923205467966, 36.478466218517674, 38.220881108314764, 38.60278660251249, 38.216209565439534, 37.937054480275805, 40.35047315782116, 35.87550770851874, 37.89375935831378, 36.66224495057137, 39.45478423949211, 37.485895618315666, 39.73718704715852, 39.0987624660615, 38.38935867432625, 41.62737723319761, 43.52398833920879, 42.65818788159279, 42.38251586114207, 39.843648018375525, 40.36868080016106, 39.0010719145498, 39.24839696576519, 36.49578740519863, 39.01279195662468, 39.390084743499756, 45.213039382811516, 44.280503719083725, 43.641275052101385, 41.79745120386924, 43.06150167219101, 48.70539619076637, 54.229474067687995, 55.48291844706382, 52.838632983546105, 54.69312960101713, 51.468572616577156, 47.468939596606845, 44.70717522405809, 43.46808279714277, 43.53272737995271, 41.116206107601045, 40.65453921594928, 41.1387832703129, 40.960170299776145, 37.40926427225913, 38.816230220179406, 37.97521129731209, 39.51783241764192, 39.22904006896481, 41.247095600251235, 39.89947903540827, 40.18763203774729, 42.09907754775017, 41.34911644843317, 39.943437037929414, 41.15513563156128, 40.37043017725791, 38.739767536040276, 39.9937649696104, 39.64039471841628, 40.32878637313843, 39.26987586482879, 39.53325909952964, 39.734723798690304, 40.87194834986041, 39.976310422343595, 38.70740013737833, 40.38613534742787, 40.87154042336249, 37.666422705496515, 39.17922204540622, 39.56923507875012, 39.36289095109509, 37.98329922460741, 39.83267322663338, 40.544599102389434, 41.841491576164, 42.159003519242816, 42.536574794400124, 40.51752690346011, 42.341742823200846, 41.01079633159023, 42.48213621877855, 43.315890912086736, 45.31625655389602, 43.589946916026456, 52.80623812829295, 58.34566423969885, 62.77349064427038, 61.6853702452875, 65.59417686154767, 63.08507980838899, 62.50184297561646, 60.95197723757837, 68.13716319299513, 61.75553752530006, 75.03472958841633, 4.1007088220888575, 0.9862909502079411, 2.7342952787876134, 0.1301408868523375, 0.05111088120048085, 15.460645691041025, 73.73993950505411, 61.118979992405066, 69.47062784625639, 52.753682290354085, 35.51308070459674, 29.395769834518436, 42.84415529620263, 46.412963021186094, 61.7060136795044, 18.83215819635699, 0.18192118334193386, 0.07654667801914677, 0.023828536692646243, 0.024534850606634736, 0.07664761010317073, 0.02336705490315874, 0.05338007193659583, 0.025756875759050734, 0.17373139699620588, 0.052022391764987866, 0.04532702079403304, 0.11926354915504495, 0.05534337142542486, 0.1435696727205669, 0.42258206634752216, 7.675710705018814, 66.61944912325951, 69.52843573785597, 46.009225614609264, 38.23433091563564, 66.57274153924757, 87.23555226479807, 60.838867848919286, 60.5205871212867, 64.93633654809767, 69.85173317693895, 35.94755380384384, 0.18948683785575052, 0.21345733064076594, 3.4827087579234957, 0.18408764934828206, 25.297530389601185, 76.26790708111179, 55.87298247121996, 60.64839755335162, 47.18759975125713, 48.68288570834745, 43.761648670319595, 50.306731270205596, 45.228034603980284, 48.9127601346662, 46.607912663490545, 48.71718683550435, 41.902547190266276, 43.39344793750394, 40.92566520937028, 42.1232589598625, 39.312135481065326, 41.63511214717742, 37.597000675816695, 41.7994398455466, 40.64050105310256, 42.502399183088734, 39.794245766055205, 41.31195983579082, 41.17284905525946, 43.644016788851836, 39.36541303511589, 41.620316966887444, 40.59509177361765, 41.53242449606619, 39.720528741036695, 40.14222668063256, 39.22974609559582, 39.747200858208444, 39.7439766699268, 38.47554491412255, 38.283870450911984, 42.45063174155451, 38.17708000060051, 38.82780121218774, 38.63402435856481, 40.698367780254735, 40.29424990377119, 42.11315101192844, 40.951509706435665, 40.895278607645345, 43.470000836157034, 44.835546555057654, 43.47804169501028, 44.83174577836068, 41.10219540134553, 41.34109127906061, 39.304490781599476, 40.75495581473074, 39.144642429967085, 41.33634913352228, 41.34175415961973, 47.33484944989605, 44.97472401588194, 46.174435846267215, 45.561420379146455, 45.71584017046037, 50.42605369321762, 55.05806692184941, 55.57186603546143, 54.65445895348826, 56.93306184584095, 52.326520489108184, 49.64412135462607, 48.30149012227213, 45.67977397672592, 46.592278095983694, 44.79894691897977, 42.407583728913345, 42.889533196726155, 43.25546679958221, 39.340486372670824, 40.39478025128765, 39.48471976864723, 41.866963448063025, 41.4175029723875, 42.85033302922403, 41.328751502498505, 41.948121209298414, 42.118355997147106, 43.514751157452984, 41.15195458935153, 42.23461504905455, 41.56031254799136, 40.94492012454618, 40.408339884973344, 40.77344586772304, 41.558790668364495, 43.14332231398552, 40.57941798240908, 40.85196387383246, 42.71729015534924, 41.93595009465372, 40.94979955304054, 41.39043861819852, 42.45362450999599, 40.89220346943025, 41.20402405338903, 42.05626095494917, 41.281506553772964, 40.34041620069935, 41.81101868229528, 42.60136450490644, 43.7557258913594, 45.36021455641716, 43.677819774996856, 42.987965076200425, 44.06300437065863, 43.033656766337735, 44.2325331318763, 45.665480859818004, 47.07298417245188, 45.88103079026746, 56.436846717711425, 60.56611799424695, 64.15369818287512, 65.00814337884226, 68.95274946766516, 64.41390037536621, 66.35959209934359, 63.81098893380935, 71.50499651508947, 64.11493339846211, 79.86696412486415, 5.259120791189132, 1.362814768668144, 4.1541645988341305, 0.4795977617463758, 0.09068290778105298, 16.373078227043152, 80.29924069681476, 64.98710378523796, 75.33427315373575, 54.21940926582583, 35.17222673662248, 37.05317581853559, 54.67836579968853, 53.392126483301965, 70.14139236942415, 24.706513535591867, 0.07455479578986283, 0.14832559251977553, 0.02068279581444879, 0.0896347233004147, 0.09878792649795932, 0.04937212208225843, 0.02807289744997698, 0.17186915982634793, 0.2383738807252338, 0.2126323305551083, 0.16653645242894852, 0.17671727064636447, 0.2545596025283298, 0.4116782449906872, 0.7967287446221998, 9.45984882693137, 78.93428725581016, 78.94603083210608, 54.56291867840675, 40.79858826052758, 66.37911765806138, 85.99215307543355, 63.50947633866341, 66.17276960803618, 68.5092862959831, 75.90646066973287, 41.52337951044883, 0.3039372940697978, 0.8482803332228815, 9.092807154501639, 0.658094470779742, 27.16635346412659, 78.79513725157707, 58.082190790484034, 63.349051398615686, 49.8722856275497, 52.719361551346324, 47.05225052372102, 52.47077741930562, 47.543731351052564, 52.25436064504808, 48.80131775333036, 51.03792775061823, 44.337338862880586, 46.941423954502234, 43.18059659773304, 44.53520674859324, 41.90132733314268, 43.609539155037176, 40.84608031857399, 43.46687862949987, 42.56562779026647, 45.30065336535054, 42.738549401683194, 43.55785800564674, 43.79262754994054, 47.38075294802266, 40.71870134722802, 44.02736963764314, 42.90925487395256, 41.840561974433164, 42.99697868285641, 42.982132511754195, 42.1855854219006, 41.469380240286554, 43.119870462725245, 41.375047237642356, 41.70212976394161, 45.13720427789996, 40.57330692968061, 40.447951901343565, 40.85408195372551, 42.77760051911877, 42.89260441257108, 43.08451421799199, 43.26339390970046, 42.82086818448959, 46.14120944853752, 46.92675821242794, 47.18566210039201, 46.60314698373118, 43.52848337542626, 43.69689426114483, 43.022246591506466, 43.09244132811024, 41.0942526017466, 43.687966946632635, 43.03402154676376, 49.56971007008707, 48.45354472437213, 46.67136876813827, 46.198860445330226, 46.826110193806315, 53.56899399911204, 58.75620695852465, 58.46178208628009, 56.73855935373614, 59.41576134773993, 55.32086572339458, 52.04654170620827, 51.8440140447309, 49.03145890082083, 48.25302923879316, 46.7739583599952, 45.27024715177475, 45.28934909451393, 45.938234636860514, 41.40091134655861, 44.02212150635258, 42.195269753856046, 43.60675034984466, 43.55289620737876, 45.96147075776131, 43.32712850263042, 44.69951483511156, 45.56160473054456, 43.98377641554802, 43.48262694574172, 45.33555853751398, 43.813620075102776, 41.867783223429036, 43.767712654605994, 44.34223005848546, 42.98415645476311, 44.941234819350704, 42.89182386090679, 43.107005088560044, 43.96013629051947, 43.93762580810055, 43.674595586715206, 44.38809825528053, 45.00928401947022, 42.5072354655112, 43.02694166860273, 44.01184097413094, 45.81254228468865, 42.72445240328389, 44.18801815279069, 44.222684060373616, 47.73022044089533, 46.72274789502544, 46.44744457737092, 44.86067325838151, 47.27145218080091, 44.77937821419009, 47.678382396698005, 48.393654054211034, 50.77140269740936, 48.29804628126083, 58.46270776564076, 62.50941315004903, 66.9650177801809, 65.68267729974562, 70.64922163563391, 67.19442936681932, 68.53864915909307, 65.94720194416662, 75.16881189038678, 65.75700229214084, 84.21278553624308, 6.67772097933677, 2.630002642831495, 9.92804450373496, 1.3184097385214222, 0.21812248434270584, 19.092762431790753, 89.32053519833474, 71.37917472470191, 80.8642267411755, 66.7466280537267, 47.38547548171013, 43.09077039841683, 64.36796157590805, 65.48614694226173, 80.65247366505285, 32.32111665510362, 0.20746889794545792, 0.20296515896916392, 0.12051127655732057, 0.33611592866720696, 0.1891583853190945, 0.215708066318785, 0.33431231254531496], [0.042291385902752804, 0.09961367734978277, 0.0321500595178335, 0.03004377737881676, 0.03156991262409476, 0.04333152262974651, 0.026798559983651486, 0.12366606493390377, 2.5144170128530074, 54.7385859489441, 57.70212096552695, 45.51671712629257, 31.605435109907585, 41.36071489703271, 51.58179575397123, 32.83663376685112, 62.01022486532889, 56.537294695454264, 64.6036724890432, 32.423074745362804, 0.012551312590198172, 0.12678387424638196, 0.5296238547851962, 0.22670211751134167, 22.329484647320164, 73.45406932215538, 53.40936922257947, 57.742136986024924, 45.043298813604544, 48.50992879559917, 44.882363965434415, 51.217486012366514, 48.730997500881074, 52.066816437628965, 49.8687437272841, 51.1711000627087, 45.13164627936579, 42.14362390579716, 40.755485334704005, 41.7776353897587, 39.11136504142515, 40.97596960683023, 38.5782874784162, 40.47399251691757, 39.795567604803274, 39.63658609697896, 38.35708933491861, 40.59696274418985, 38.38282792798935, 38.38393011400777, 36.42328239256336, 39.67045968578708, 37.909990126086825, 38.398144783512244, 36.57822385911019, 37.88285516923474, 37.48049843695856, 38.02878695149576, 37.296915823413485, 37.96553088772682, 37.08835163424092, 39.64827476009246, 37.326031577202585, 37.961067230470725, 37.92737014832036, 36.939623202047045, 37.10046391333304, 38.79247242404569, 39.391849810077304, 40.31311258192986, 40.583195224885024, 41.44257868489912, 39.33935280769102, 41.16649089321014, 39.04367277699132, 38.97312894944222, 36.582456096526116, 38.44229890454201, 39.45830260553668, 39.7978308123927, 39.51088982243692, 43.91462110703991, 45.37212679463048, 45.121530486691384, 43.58969588433543, 46.53190105192123, 48.095346035495886, 56.17997461749662, 51.24168703632971, 45.56148313706922, 49.847657065237726, 49.668216474594615, 45.82987916085028, 46.994603449298495, 44.86683922429239, 45.804093499337476, 41.96757224298293, 40.13321699634675, 39.07243551746492, 42.24913958580264, 38.82469077264109, 38.21040837995468, 36.259444990465724, 38.80980145546698, 41.34273082979264, 42.48565850719329, 41.84202894087761, 42.40548133850098, 41.45946448849094, 40.565921106646144, 39.079005487503544, 39.773853363529334, 38.837783644276286, 39.696170822266616, 38.42296554196266, 39.218041743001635, 38.604716408637266, 39.3403334002341, 39.78268654115739, 39.34505985629174, 40.80541318462741, 41.29605854711225, 38.69854342552924, 38.84975471804219, 39.02171142639653, 39.047854023595015, 39.69637478551557, 39.51295298914756, 40.18796936158211, 40.65013047187559, 41.442566917788604, 40.42913236925679, 39.382832281051144, 40.42699467751288, 41.2169914091787, 42.36214699283723, 43.038449902688306, 43.06307846500028, 43.551299802718624, 44.21323507062851, 45.48231009514102, 45.687587338109175, 58.861424538397024, 56.607069738449596, 64.6299837481591, 50.50038653035318, 56.92848836222003, 64.18373961602488, 63.679550309335035, 61.65414033397552, 65.87979993512555, 65.1781310573701, 70.96598440600981, 5.62298289229793, 0.22537148407390042, 3.9372187948996022, 0.37705517704448394, 0.1044922631474272, 13.583548376637122, 73.68970178788709, 61.755321794940585, 69.65144126645981, 58.300105910147394, 41.60461964145784, 9.63684872273476, 26.933137178421024, 51.16726398468018, 62.61721557186496, 18.500682615464736, 0.03934643283906964, 0.05651369713427079, 0.04543490512596984, 0.04065584947144793, 0.07222822506821926, 0.007263292059031947, 0.05075912809960785, 0.00825900909295606, 0.10919762880451257, 0.09747764035578697, 0.05488189921203641, 0.06273896974180976, 0.03139854833153227, 0.10225161684737091, 0.15576589972742144, 3.2175040725738775, 62.906341322006725, 63.17858519092683, 51.143106106788885, 27.810410568791053, 49.29728577213903, 73.8049174893287, 42.185730549596975, 67.3095509313768, 61.568201203500074, 71.12827639425956, 35.49150374627883, 0.03546274244605053, 0.14480267591293783, 1.0296383500099182, 0.35016037343490514, 24.915360135416833, 76.49656557267713, 57.12782321437713, 60.80616704879269, 47.129599663519095, 51.96481520129789, 47.76052467284664, 52.83118832495905, 51.101175969646825, 54.47830530904955, 50.87617312708209, 51.934475668015025, 45.15229363595286, 43.98596902047434, 41.552063803518976, 43.59642274918095, 41.05976320082142, 42.88987836530132, 41.66635382559992, 40.26386722441643, 41.342554323134884, 40.76250245494228, 39.92950477907735, 43.46019883309641, 39.888288513306655, 41.39765185694541, 38.37447327952231, 40.366762761146795, 39.60503455131285, 40.085183651216575, 39.38021213777604, 40.14667464840797, 39.23416660678002, 40.86610401830366, 39.1484510514044, 39.21180909679782, 39.10400667498189, 41.244797091330256, 37.66158642307405, 40.54464224846133, 38.93051631989018, 38.968465251307336, 39.264215884670136, 41.132158387091856, 40.656272903565444, 42.574174634871945, 42.5226935263603, 43.87709971397154, 42.1756108345524, 43.36594820022584, 40.96007616289201, 42.22704879699215, 40.54929417948569, 40.12908281818513, 39.878914048594815, 41.43765611033286, 40.58730586882561, 44.94042288872504, 48.16826289699924, 49.87032836483371, 47.00122833251954, 47.33864630422285, 51.06474891785653, 58.551890696248705, 53.16031832848826, 48.82594239327216, 50.81450562323294, 51.95691554777084, 46.91271612721105, 49.665015820534, 47.622174832128714, 46.305564603497906, 43.48348986717963, 42.442386919452304, 40.90084837329003, 42.40718364715576, 40.27998816582465, 40.07848816533243, 39.34580118425431, 40.626698232466175, 42.32459029843731, 43.49405673242385, 43.02973831853559, 43.91767663340415, 43.75349798510152, 41.9136514202241, 40.941240941324544, 42.023979848431004, 40.58146545963903, 40.368810238376746, 40.073079216864805, 40.97221589857533, 40.93313732454854, 41.12564725260581, 40.62479980530278, 41.672445266477524, 40.4566321065349, 42.5468514042516, 41.35618063711351, 41.658109003497714, 41.1376065592612, 41.86056998468215, 41.62800481242519, 42.317392749171105, 41.92571663087414, 42.94555248752717, 43.31440041142125, 42.80506103269516, 42.37810319469821, 41.61014626103063, 44.56952748760101, 43.85265158068749, 45.277895773610766, 44.88357990018783, 45.61607076275734, 46.355539521863385, 47.08919532837407, 46.88827583866735, 62.7475167089893, 59.29280288757817, 67.29995681393531, 54.22160187075215, 60.310673636774865, 64.8464632803394, 65.95490547918504, 62.76481828381939, 68.40007966564548, 65.82784421982305, 75.89401106680594, 7.086880572380559, 0.32817309842475, 1.3353374624444594, 0.4348765824350619, 0.07301266845916549, 14.366419142292393, 79.10632241156794, 65.86462820729902, 76.48468079105501, 60.03643328143705, 42.84586544959776, 14.114279381690489, 38.29032667221562, 58.99485572691887, 72.54812732819589, 23.356057174744148, 0.10176090688835229, 0.020511686246121125, 0.014595050353466745, 0.03978476919714482, 0.0914652903954829, 0.05848267716505836, 0.034533822533464244, 0.1312137470250168, 0.1451609752351238, 0.2028806288275988, 0.2729434910560808, 0.1254208812550191, 0.12206636609569674, 0.21651051277595185, 0.3330987066991868, 4.054630533341439, 72.72548121790733, 70.88749777886176, 59.77368154833394, 44.506369483086374, 53.85242054539343, 63.10192246590892, 47.06922654182681, 72.13652949179374, 66.35879193582844, 75.99421977996826, 39.97669481462048, 0.11456732292689624, 0.47289246993680156, 7.358423317632369, 0.39604061313213845, 26.43914407299411, 80.65095963016634, 58.038546577576675, 64.01631716758975, 48.93901648059968, 54.58319733219763, 50.55593121436335, 56.810436787143836, 52.944030992446415, 56.22144191495834, 53.59620740336757, 56.14847406264275, 47.81579479094475, 45.97790941115349, 44.61938473486131, 46.99142632945892, 43.64030230429865, 46.3195635426429, 44.851306638410016, 44.361033901091545, 44.280754750774754, 44.09921961445963, 41.79364650480209, 45.40931086386404, 42.03099304629911, 44.0331276770561, 40.96231975863057, 43.42116340514153, 42.06760837185768, 42.903689030678045, 40.54082970465384, 43.09946629308885, 42.68469133684712, 42.979206423605646, 41.03525623198479, 42.06937736080539, 40.59869643180601, 43.9473375966472, 39.40079281407018, 41.82402918415685, 43.62207897247807, 39.648447344380045, 41.532369582883774, 42.506870685085175, 43.58072150138117, 44.38477208537441, 43.94419577813918, 46.35161715169107, 42.33658098405407, 46.02943758810721, 43.04774591999669, 43.131496367915986, 42.82880706171836, 43.71129720441757, 42.24633509112943, 43.70468408830705, 44.17306607769382, 48.55812688027659, 51.150570377226806, 49.6177355704769, 49.590110317353286, 51.7438288657896, 52.81096850672076, 62.08434981684532, 56.04286424575314, 51.77075593702255, 55.31921440555204, 54.66932473644134, 48.1553190754306, 53.64018109536941, 48.124053862787065, 50.879126671821844, 46.09247007677632, 44.34024926154844, 43.05871678936867, 46.355982749692856, 42.1938733900747, 42.68633088757915, 41.53400128887546, 41.754395346487726, 45.171925098665305, 46.521357720898045, 44.92212110950101, 45.76517966485793, 45.55819226849464, 43.35029009849795, 41.42644205401021, 44.226641731877486, 43.39500511846235, 42.148844580496515, 42.94000625610352, 41.530996753323464, 41.4171342695913, 42.813549041748054, 42.382037331981046, 43.40737627398583, 44.290807785526404, 45.40224275281353, 44.47738316751296, 44.58917071742397, 42.94548972960442, 43.27896571928456, 44.017430351626494, 45.17489041051557, 44.853958160646506, 46.524581909179695, 46.985228984586655, 45.3838703709264, 45.8012850822941, 43.84350853581583, 46.47552482543453, 47.23702161542831, 48.171047779821585, 48.313135639313735, 47.55709486622965, 49.249774102241766, 49.47281968209052, 49.19248004113474, 64.81324472735005, 60.117665567705714, 68.92104102719215, 56.13014482682752, 63.031798331968254, 64.8839532944464, 68.70312982989897, 64.49487378520351, 71.65310521279612, 66.83645817541307, 79.03002446697604, 9.88227338560166, 1.171575565972636, 11.565499709498498, 1.6785382335224461, 0.3760560145301204, 16.003492897556676, 84.91107725328015, 73.12363316935878, 81.40710630724507, 71.76643033181468, 55.7873296737671, 18.682192256373746, 45.53355586144232, 69.2486922971664, 84.06072308940273, 30.98999954039051, 0.14493343179985402, 0.11884461397365217, 0.17304649907014064, 0.1399056427180767, 0.30374613981093135, 0.13254525380269175, 0.13925747104710148], [0.04579779331482226, 0.02838537130775231, 0.031911821495140755, 0.054992430377751596, 0.044883555477304805, 0.03173037548549473, 0.06497174065800444, 0.05983525902153023, 0.7795971800242701, 47.85512047429239, 63.16403319758754, 52.05970910287673, 37.26949453353882, 16.276711475464605, 26.962731461371146, 33.35161155269992, 59.225828416885875, 57.292421556288204, 66.21080090922695, 30.570478516240275, 0.04978281798802557, 0.07794638194384114, 2.245661847053036, 0.46308069159427, 16.71261525923206, 74.37354349320935, 53.99449663777506, 58.07231818476031, 48.63618204670568, 52.540489704378196, 51.340107148693455, 54.06024732897359, 52.61243381807881, 55.891719633533114, 53.759436838088504, 53.95693602100496, 48.678884890771684, 42.753434796487134, 40.20551412336288, 42.866410824560354, 40.192240822699766, 40.79009632910452, 40.45223512957173, 42.49271877350346, 39.452623013527166, 39.52278244879938, 38.055415922595614, 40.96126464105422, 37.706070023198286, 37.29316211515857, 37.46115722963887, 37.80882827697262, 37.60022486409834, 38.078165669595045, 35.241833117700395, 35.86714521531136, 37.19504402529809, 37.18284937643236, 36.90091333081646, 37.527668860650834, 37.35777924137731, 39.499867962252715, 36.608379040994954, 37.592187927615264, 36.901725261442124, 38.80507892177951, 37.88327486284318, 41.20959381903372, 38.783376447616085, 39.44899482111777, 41.25384207694761, 39.80224347883656, 40.755504946554865, 39.83669365606001, 39.19722180212698, 38.27766918366955, 38.023468217542096, 40.193044908585094, 39.337152358024355, 39.89403870797927, 39.614005011896936, 44.99992916660924, 46.92302019365373, 49.358188413804584, 50.70903701166953, 48.53259617282499, 50.4817670391452, 51.300973661484264, 52.75099546678605, 46.035395668398955, 52.31240780122819, 52.10684814760762, 47.71435445354831, 45.94629510756462, 45.36522342312721, 43.9257449488486, 40.078786265465524, 38.694679890909505, 41.096927658204116, 39.5883370214893, 39.12041787178286, 39.11434604275612, 39.132416402139974, 38.12640297797419, 40.699650395301084, 42.503783779759566, 41.07010649096581, 42.137348113521455, 41.63962679524576, 40.08913740035027, 41.16575740998791, 38.66475612886491, 38.69328352712816, 39.85086517949259, 38.972638653170684, 39.26875798932968, 39.58426167888027, 39.412995307676255, 39.23534724020189, 36.90057208461147, 39.90175793247838, 39.836960377231726, 38.37311613944269, 39.049599478321696, 40.12104980407223, 38.345447740247174, 39.11607188563193, 39.46360565000965, 40.11441315374067, 39.441424646685206, 39.79370055660125, 40.123783696082334, 42.93398541788901, 41.570518555179724, 39.63771181721842, 37.590870011237364, 43.89118494526033, 41.65937592906337, 42.1497114243046, 43.99199770342919, 45.124040803601666, 47.11086642357611, 58.38562142464423, 61.31136048224665, 61.24042049531014, 60.13519856237597, 59.792638363376746, 55.752142090951246, 64.02068668796171, 64.56622169863793, 64.14751652748355, 62.94845581054688, 62.67038329955071, 11.366473743992469, 0.635050913739589, 2.0040667657890627, 0.0673317204740259, 0.11216222819301391, 14.487160482714254, 75.0373105079897, 61.673579600549516, 70.76492371097689, 54.497560224225445, 41.2410080817438, 24.669519701311668, 37.0581768405053, 46.962408634924124, 62.23134063905286, 14.24698297054537, 0.1002612055069016, 0.014733143447477733, 0.030924343736842278, 0.027853447733627214, 0.0900657243666149, 0.007089070737316844, 0.03278712674434627, 0.037612829492577625, 0.054792554207867196, 0.04022559917141353, 0.03450636594225803, 0.06819854129947002, 0.05845588323990664, 0.058432111531616225, 0.026861024877777504, 1.210419410659421, 54.845046920161096, 68.58130885708717, 59.82968514965427, 42.22309504785846, 22.70412591195876, 40.67861864643712, 40.79758413376347, 64.78129309992637, 61.77856183821156, 72.61359953111219, 33.88665030079503, 0.01841240232029269, 0.28009136718127037, 1.7439973210134816, 0.8934083665090223, 19.15758156007336, 78.08586289805751, 55.575251040920136, 59.14894603913831, 50.8549766386709, 56.36031735327936, 52.39060417298348, 57.4382278227037, 55.570579498044914, 57.40126732856997, 55.795017519304835, 56.57657723273001, 51.967960942176084, 44.93806554425148, 43.67219901853993, 43.97185241022418, 42.25018293626847, 43.322562863749845, 42.05058920768, 44.343649956487845, 42.09325282804428, 41.990212163617535, 40.64085798878824, 43.397617416997115, 40.972741496178415, 39.46419008316533, 40.367064783650065, 42.33871867579799, 38.83197069168091, 40.23974857022686, 38.90511505065426, 38.950512563028646, 39.474658889155236, 40.10880024202409, 40.006865685985936, 39.993533549770234, 38.5292656960026, 40.2579483678264, 38.88838614186933, 38.70034379343833, 37.599369787400775, 40.294147922146706, 39.94070314591931, 41.84958342582949, 41.45350248582902, 41.907952216363725, 41.74550725567726, 42.159297697005734, 43.673097241309385, 41.59681020244476, 41.94070792967274, 40.593730711167865, 39.7369203259868, 40.59431906669371, 41.71216710921257, 42.167832774500695, 41.89811883434173, 48.344659728388635, 47.95599206801384, 51.93057683206374, 51.39739336506013, 52.416193715987674, 50.78944560020201, 53.975708484649665, 56.04132667664559, 47.777512458062944, 54.770474818445024, 52.313502142506266, 48.38845691373272, 48.59940982634022, 47.719743790165076, 47.814092482289965, 41.667593294574374, 40.13392302297777, 43.24767305004982, 42.374941764339326, 40.45400411851945, 40.9695839881897, 40.92736359565489, 39.86806477269819, 42.17174729993267, 44.49439056458012, 44.799496050803896, 44.485114159122595, 43.8750796933328, 41.93278866429483, 40.90527672921458, 41.77854537963867, 41.105686310798895, 42.249539667560214, 41.24896657082343, 39.82613071318596, 40.83431713042721, 40.60212850570679, 40.14292094015306, 38.5822961407323, 41.45054894108927, 40.43191725207914, 40.21320196890062, 41.43280413842971, 42.139379901270715, 40.20121520565402, 42.09628482018748, 41.827527938350556, 42.29283478952224, 42.39953502531975, 43.78066039854481, 42.44259088270126, 45.52562875132407, 43.21983206656672, 40.06723880767822, 39.64551733386132, 45.92964464618314, 42.25632144558815, 43.329956531524665, 46.6357889483052, 46.27873951388944, 49.35370122232745, 60.20095317594467, 63.23499279637491, 64.00176517425045, 64.73478163442304, 61.304304138306655, 57.75158205339986, 65.24372877613192, 65.31272326746296, 69.79905574552475, 64.33509211386404, 69.49895520364085, 16.308396381716577, 0.6286254585269959, 2.394728828822413, 0.13029870096473925, 0.2740088435671022, 15.966765784448194, 80.1567017647528, 66.15245957528391, 74.2570177201302, 62.703080177307136, 39.8871196469953, 27.128561427516324, 47.1219196627217, 53.59316364411385, 72.42419612023139, 17.60495839580413, 0.19320349809863877, 0.05593038629740477, 0.06432685550422439, 0.10659414794175856, 0.043499839807590174, 0.024898964536166, 0.04033186322739048, 0.10056328929720387, 0.136209697492661, 0.1739275001830632, 0.11890016300904176, 0.17868414010492065, 0.15833143625528584, 0.22456578940393465, 0.22449737775229642, 1.3314529676591198, 62.33466763650218, 77.64095629415205, 66.20228936595302, 52.75880490579913, 25.106781605751287, 37.640017309496486, 49.16595697402955, 72.10497010138728, 69.08907536537417, 77.79679206109817, 38.29642988020374, 0.1539351794147684, 0.39384558736797304, 6.7386201889284205, 1.087054249740416, 20.201271310929332, 84.47697285682925, 58.81513272562335, 62.60868833911035, 55.29810028691446, 58.8764746727482, 55.00511100215297, 60.02974171792308, 57.97681631580476, 61.146632702119895, 58.41674935433173, 59.527215496186294, 54.472347228757805, 47.25484878786149, 44.91159739032869, 46.41946238856162, 44.41706103663291, 44.81979039407546, 44.83509156011766, 45.58984187341506, 45.32502305123114, 45.291831954833, 42.77330160140992, 46.644461308756185, 44.249230661699855, 42.239878869825795, 41.336078489980395, 44.41681000494188, 42.207660521230395, 44.300986336123565, 41.48481084454445, 41.78475056925128, 42.454636481500444, 40.980284214019775, 39.950532605571134, 41.798949549275065, 40.13783754840974, 44.33003933198991, 40.133691603137606, 40.7919555325662, 39.232876146993334, 42.51517434273997, 41.71532461720128, 46.500620149797015, 43.95437432873634, 45.071124107606956, 44.367984341036895, 43.928808319953184, 46.07927130114648, 42.53762991197648, 43.901583148587136, 42.10895407584406, 41.7106177729945, 44.17191682323333, 44.28023699791201, 44.705665111541755, 43.84204549174155, 50.19387683560772, 52.012224889570675, 55.08609225673061, 53.273980771341634, 55.552807238794145, 53.81988448481406, 56.19723696862498, 57.586230616415705, 52.85496573294363, 57.01159161906089, 54.83802587755265, 50.82075788128761, 51.49591545904837, 50.64298037559756, 50.43141949561335, 43.86636026443974, 43.53475916770197, 46.363631371528875, 44.879971319629306, 43.37046677066434, 42.93569949365432, 44.6325638986403, 42.95356196741904, 44.675623678391986, 46.90207473693356, 45.149571511053274, 46.32947929443852, 46.6302623287324, 43.47385652603642, 43.087475607472086, 43.15102977137412, 43.267328046983295, 44.98559290362943, 43.21167745897847, 42.064164530846384, 43.16452664713706, 42.54301924859324, 42.403606445558616, 40.90968155091809, 43.57460260391236, 43.59576771336217, 41.803475964453916, 43.470412685025124, 44.9472007443828, 43.04021496926585, 44.61151646029565, 43.84009999613608, 44.06903305361348, 42.964768179001354, 44.218902895527506, 45.73977447325184, 49.52281813467703, 45.54813138900265, 43.10670306605678, 40.52751325791882, 50.176477201523326, 46.314178128396314, 46.578942037397816, 49.66653770016086, 49.06585808723204, 53.01563385994204, 63.59139111734206, 66.67873967078425, 66.25466085249379, 66.35762306951708, 62.61973373351559, 59.7805456961355, 67.19745743659236, 68.28236149203393, 71.69564723968506, 66.16400703307121, 72.31280865207796, 19.852062694488033, 1.1038633219657408, 7.391409960485275, 1.7904099918180898, 0.45860067070011173, 17.900589396876676, 89.59505404195478, 72.04649540685838, 80.13503459192093, 68.40984636737456, 55.54315820817025, 39.492807695942545, 55.2639207532329, 62.73830306145453, 82.87735185315533, 26.31279472381838, 0.3733506822778333, 0.19813463752788885, 0.18332798124080707, 0.1484486109186565, 0.1884598357062186, 0.12744642538769593, 0.08585051708524266], [0.04724823524274173, 0.023012120622180166, 0.024935332645151406, 0.006748766341667262, 0.003503641834662807, 0.04662308068345151, 0.03133923014355523, 0.07371427476285927, 0.07340685900060401, 30.571078638876642, 64.19666774811284, 45.50013726757419, 33.77013237245622, 24.876073675770915, 35.30461457467849, 35.997340448441044, 56.908578411225356, 55.81901065764889, 63.136451090535815, 33.31365477654242, 0.04274160428453357, 0.13610676591915472, 0.5976454757394329, 0.18445570863062338, 10.470018002294726, 71.74393946124663, 52.799715226696385, 59.849136183338786, 52.508561611175544, 57.52701459392425, 55.32023422179684, 58.43569047989384, 51.8466498774867, 52.00312891314107, 57.06814042983517, 55.10317025646087, 53.54758178034137, 49.6724408672702, 40.36235401707311, 40.31410886395363, 39.230271693198915, 40.67037774670509, 38.82848370459772, 39.20687083275088, 40.340765291644686, 41.13364104301699, 40.00580272366924, 40.2177676077812, 38.2240072373421, 38.018580944307395, 37.581456322823804, 36.35231887140582, 36.95751313240298, 38.08996415907337, 35.69448248032601, 36.809780982232866, 36.47115099814631, 38.16586594427786, 37.78083824342297, 38.597765968691924, 38.94711579045942, 39.462448550808816, 35.59832949792185, 38.37332402506183, 35.55155131124681, 37.467515391688195, 37.84656540040047, 38.649964870945105, 40.235120173423525, 38.58192351556594, 40.26103527315202, 41.4233551486846, 42.100768089294434, 39.93280349239227, 39.598280229876124, 38.55773033634309, 38.88902156583725, 39.57359283201156, 38.93479954811835, 39.33980388026084, 43.195038764707505, 45.60985380603422, 49.43566306944817, 54.61501559903545, 45.63227407393917, 47.857611179351814, 48.67339357253044, 52.989777595766135, 53.158039431418146, 50.87861676369944, 52.895774072216405, 52.81845631137971, 47.25930460037724, 46.44982153369535, 46.169717234949914, 43.577007016827984, 39.993247216747655, 39.855858356721946, 39.52415527835969, 41.272787124879905, 38.14075493043469, 38.801897879569765, 41.06696859482796, 37.52004769540603, 40.1867102807568, 41.2745443467171, 41.97313416388727, 44.26462204225602, 41.5207476000632, 38.923357994325706, 40.315720958094445, 38.87368509846349, 37.89565386310701, 39.843342073502086, 39.27257053313717, 40.25574007341939, 39.17509963435512, 39.456988611528956, 39.054898600424494, 38.2692047088377, 37.02309123931393, 39.67420554930164, 38.479424138222974, 38.276445404175796, 37.48029055133943, 37.17126269494334, 36.98726823253017, 37.720857358747914, 40.85142650911885, 38.80545546931606, 42.19114342043477, 39.682768083387806, 42.40215124622468, 42.624000503170876, 40.08986696120232, 40.81628599474507, 42.34778327326621, 41.085792049284905, 44.705614120729514, 43.68602929576751, 44.60433460051014, 45.12948113103067, 49.76687977390905, 53.27840912726618, 58.14395243121732, 59.57124017900037, 63.60556656314481, 61.635999371928555, 59.01123946712863, 54.28112776048722, 64.75616639660251, 56.02524103656892, 59.20654996748894, 17.019534841660533, 0.4144889296543214, 0.3174969277554943, 0.07563533216354347, 0.048130148000294165, 12.828577430017534, 76.29115889149328, 59.49151408287787, 73.02411479334678, 57.29641845149379, 42.48904743502217, 13.375383288629594, 28.791218842229537, 51.32310759636664, 57.671824578315984, 10.451821146472808, 0.16160713628895823, 0.06451060169286306, 0.037623393845053456, 0.07770113421664124, 0.03247098524063345, 0.053946888900452086, 0.03676469738204633, 0.013548621171784979, 0.033342245545598774, 0.08101700790106289, 0.03865121953910397, 0.043906801034726446, 0.04013004119417841, 0.007844206477109825, 0.0207820022854233, 0.14217065827500436, 36.16604158955236, 72.82816102427822, 53.323061389307824, 39.958569542054214, 22.26735430379068, 40.62979690490231, 44.03972902605611, 63.348925882770175, 61.34312775827224, 68.86644947913386, 36.0004783445789, 0.03596357625698851, 0.10268778134618076, 1.8851125552769632, 0.5454541117914262, 11.656395735279208, 75.12919595164638, 55.222892761230476, 61.151104204116336, 53.49797948714226, 60.293073961811686, 57.2177827742792, 61.777322369237105, 52.882614520288286, 54.91971708113148, 58.28743273212064, 56.566422216353885, 54.68579084642472, 50.60056386455413, 40.30859793386152, 42.31045015396611, 41.716105168865575, 42.77325845533802, 41.44266889941308, 43.586467773683616, 41.962771261892016, 43.439261221116595, 41.73652895035283, 42.377208894298924, 38.8681153328188, 40.532439754855254, 40.00487704430857, 39.05045455501926, 39.23774773074735, 38.58623812275548, 37.73204395847936, 38.524029331822554, 39.41565859702326, 40.33393252280451, 38.81563009754304, 40.74816619196246, 40.163089767579116, 41.39454926213911, 38.91644677808208, 38.89488550924486, 36.35280916767736, 39.52919944640129, 39.411547953082675, 39.95783213646182, 40.64792217746858, 40.23490836543422, 40.37764733837497, 42.818648122972064, 42.102886169187485, 41.86515131304341, 40.40823005860852, 40.81520342057751, 41.068729739035334, 42.66598947586552, 40.40171107938213, 40.50943897616479, 42.91977074838454, 46.65716978811449, 52.30602610495783, 55.99288148264731, 49.37638821140413, 51.777427888685665, 49.70347073770339, 56.04222882178522, 53.98161557412917, 51.486474314043605, 52.198227605512066, 53.30282980395902, 49.88792019505655, 49.62879665436284, 48.98994061254686, 47.169501935282064, 41.82691997097385, 42.88875656743204, 39.78471440653647, 42.298388865686235, 39.779415284433675, 41.50636426864132, 42.883775157313195, 39.843220480026744, 41.848708737281065, 44.18654726397607, 44.56729958134313, 44.12922182390767, 43.8598059838818, 41.385500354151574, 43.44109296798707, 40.58394047521776, 38.93836890497516, 40.7259302754556, 40.487155991215865, 42.19339486091368, 40.996063909223004, 41.52820794813095, 41.38405692192816, 39.852834209319084, 39.63442487101401, 42.375086892035704, 40.85750618288594, 42.362641211478945, 40.279423344519834, 40.763636019922075, 40.06854103457543, 39.67160894024757, 42.13784233216317, 42.17644237702893, 43.18243618934385, 41.990729916480284, 44.71981310075329, 45.23028604445919, 41.14312925646382, 44.78272791831724, 44.51263350825156, 43.67865523984356, 46.70486580940985, 45.18578675485427, 47.11925245100453, 47.79912864008258, 52.06927184135684, 56.62687770781979, 60.667876043627345, 61.26773588119015, 66.28662816939816, 63.015002742890395, 61.673862011201926, 58.37423870640417, 68.40148387416717, 58.829923983543154, 64.22961565756029, 21.82558951839324, 0.29572467830392624, 1.197348970078653, 0.4230661726286335, 0.23480830834277217, 15.53225346149937, 82.40388254965507, 64.30871809682539, 77.57331894290063, 61.796326252721975, 48.62354809238065, 20.863592932301184, 38.90988857515397, 57.74414916192332, 67.3452131209835, 13.481590286377939, 0.16735682534354349, 0.03921470785092923, 0.006711075773402568, 0.031249490604105017, 0.051782928001616275, 0.03274856953911724, 0.02829725970514119, 0.09242491511207435, 0.1272037134115254, 0.14153100550174713, 0.18792719009422487, 0.15347017936648863, 0.08061602215973601, 0.15492943896641656, 0.13327821608512633, 0.2423648464102899, 42.31644353558941, 81.61854559375395, 59.73549727470645, 47.884157780678045, 34.52576914141255, 47.645257980592795, 50.099586979035415, 70.64840578263806, 64.32046559549147, 74.76991468860258, 40.34077313638503, 0.22159004343613503, 0.39232327873187683, 3.8758667967011853, 0.9024778056529261, 13.699256335535358, 79.8954091533538, 57.089003516781716, 64.09651394813292, 55.186704974020685, 63.17288206469629, 59.173429473753906, 62.51552028040733, 53.557089605639064, 57.38650744961154, 62.216200290187714, 60.04759242457729, 57.765169143676765, 52.32777172519315, 44.49574770465974, 45.139851877766276, 43.27723203166839, 45.33962603538267, 43.26737119305519, 45.531257352521344, 44.5647108170294, 47.13187463821904, 44.63834547227429, 45.08257742851011, 42.595904565626576, 43.67557225688812, 41.424916252013176, 41.22906446456909, 40.58445038334016, 42.247900116828184, 40.025085095436346, 42.183647771035474, 42.028467039908136, 41.41496127651584, 42.33244680589245, 42.74879071020311, 43.323559145773615, 43.86959229746173, 40.78573857584308, 42.224632616966005, 37.659401662888065, 41.24278883780203, 41.468027022577104, 42.589393431140536, 43.33462022965954, 41.995954513549805, 42.74763361100228, 45.997281997434555, 44.3908086130696, 45.439246393019154, 42.61800319917741, 42.055354887439364, 42.48872580066804, 44.92121896436138, 42.44834499974405, 44.323002599900775, 46.04157732379052, 49.75949002850441, 53.74864639774446, 57.05282357431228, 50.77482692656979, 53.872985532206876, 51.227193878543, 58.899330323742284, 56.03622367305141, 53.4408187866211, 54.7124158951544, 57.14399514659759, 50.43826010919387, 51.707774439165675, 51.65321427006876, 49.10150458735805, 43.50334882736207, 45.115340986559474, 42.50580772276848, 45.33418963032384, 42.98531747633412, 43.15065714620775, 46.98262060842207, 41.80560581145748, 44.3824343527517, 46.54116961263841, 46.353629327589466, 47.55277633666993, 45.790471107729026, 42.70146731407412, 44.308403538119414, 43.59479888792961, 41.01139645422659, 44.21474126077468, 43.65088878139373, 44.924631426411295, 42.46817258096511, 44.018199136180264, 44.271180245184134, 41.68410647299982, 41.52777256504182, 44.59110052354875, 42.680051172933275, 45.22302965964041, 42.447682119184925, 42.990726424801736, 43.832769086284024, 41.08891425594207, 45.25157666975453, 45.17217220798616, 46.28168913625902, 44.260111316557854, 47.00236581986951, 47.63421650855772, 43.978834229130904, 48.212071849453835, 47.02487237991826, 45.41140148716588, 48.67975173457977, 48.085096882235625, 49.2606076886577, 50.61440198652206, 53.58448343892252, 59.78610369466967, 63.71215305020733, 64.23114930429767, 67.79297521037441, 65.5121640236147, 64.91858390069777, 61.47746501430389, 70.42592110172396, 59.028564576179754, 64.898489598305, 27.78194396726547, 0.9142053860329813, 4.124885086090335, 1.2559684245817124, 0.3150032196314104, 16.75847561128678, 89.84946681607155, 69.39741288461994, 85.70846373035063, 69.87588713246008, 58.31856066180814, 26.177592585163733, 47.30232907879738, 67.04650894288095, 78.81580814238518, 20.80643419296511, 0.33257415097567344, 0.19039567860384143, 0.09159234607772482, 0.19502438184234405, 0.18674099487402748, 0.13167723021920652, 0.14368959612423374], [0.044953794248642466, 0.02744620688439858, 0.04682263126596809, 0.05843190085743705, 0.03462622422845133, 0.04947028475843611, 0.011675695160163507, 0.11952476215458686, 0.17145216284740358, 17.791284707284746, 64.19615391762026, 50.517319402387066, 42.29322702653947, 19.151907851619107, 21.324789139532275, 36.04540517253261, 56.62282982180196, 52.768261740284586, 67.29936845840948, 35.24807360864455, 0.12770204594539059, 0.29796600642223514, 0.6229208614076338, 0.848491589628881, 4.406431346170364, 66.62470509929042, 55.2163149464515, 58.56659173965455, 57.250220775604255, 59.65984652119299, 53.53554010391236, 57.49902848274478, 51.74885342198034, 52.773364743878766, 56.215962363827614, 55.91867808372744, 55.614917970472774, 52.30316669710221, 45.41478649262459, 39.93878510690505, 41.07788062864735, 39.70504714596657, 39.48202902270902, 40.642081768282004, 38.816175306996996, 38.97928314824259, 38.79193113696191, 37.03962010722007, 36.90572215664771, 38.39082956314087, 36.15617290619881, 38.206544845334946, 37.18815242090533, 35.48476903669296, 35.96713819811421, 36.15293695080665, 37.63511042441092, 37.08049904915595, 36.96983329711422, 37.68615614983344, 38.513278115180235, 38.318861915219216, 37.96560541276009, 39.22987553381151, 37.21602086097964, 39.57618944106564, 38.290624772348714, 38.24939281709733, 40.69732050741873, 38.683144200232725, 40.645682504100186, 43.13043732796946, 42.6486643668144, 39.45723179847964, 39.64366205276982, 39.460495210463, 38.20204196437713, 38.921275215764204, 38.93470541123421, 38.83635197916339, 40.043359418069166, 43.556253756246264, 52.95151095236502, 48.34771917712305, 47.55771460071687, 50.72124342764578, 50.2309589232168, 51.57580237234793, 52.60822511488392, 46.84118386237852, 52.488988984015684, 53.552649482604004, 47.82983295379147, 47.827569746202045, 45.797303876569195, 43.400131656277566, 38.68255192233671, 37.5636762188327, 39.277893189461004, 39.70514520522087, 38.522103448067945, 38.96392706901797, 38.14168453216553, 38.942793338529526, 39.954258857234834, 40.99533434837095, 42.545290300923014, 44.145111345475726, 41.19436717802479, 40.11725294974543, 37.91150023860317, 38.32805595090313, 37.82098370213663, 38.0610562909034, 37.851017290546054, 39.467779051872995, 37.83015028122933, 38.28182297368204, 37.538757401127974, 37.948284226079146, 38.78867949208906, 38.984652873008486, 40.09632318250595, 37.170999896141794, 39.44016948823006, 37.65490270430042, 37.891378479619185, 37.041208667139855, 38.8703824627784, 39.344196934853834, 38.91982786117062, 40.71797178637597, 40.751492361868586, 40.941699858634706, 43.616230718551144, 41.3302537702745, 41.48308500166863, 40.50697965006675, 42.77181894548478, 43.45019678915701, 44.785144098343395, 46.19733464333319, 49.303879276398696, 48.70265053164575, 52.47136969720164, 54.70908972524828, 60.50496824326054, 55.741159454468765, 63.480764589002064, 64.24877643585205, 66.5289443539035, 59.35639627518193, 62.53910156988329, 18.832050331177253, 0.8280052953670103, 0.977560489648773, 0.2649255535535274, 0.1844569650148192, 13.486891369665823, 71.80210821090206, 58.935804443974654, 72.03086083935153, 57.2930020670737, 32.66442406562067, 20.974180236939464, 30.60997482269041, 44.921709260632916, 57.43173237769835, 13.348675870126295, 0.08194374446306499, 0.08872841064247394, 0.08093080768782286, 0.05783964977449468, 0.02516868877254667, 0.06924737695484393, 0.08521504715205201, 0.04882032810259731, 0.05381299588348597, 0.07323288043299991, 0.04558220851205049, 0.09386289278946577, 0.04392330639905507, 0.03390042486810877, 0.05143429287859509, 0.014605659713608124, 21.73536127613437, 72.06001973921254, 57.61648777992495, 50.182199939604736, 22.656484803845807, 29.09634590148926, 43.34396723778018, 62.519685837530325, 58.774991189279866, 71.80881546389672, 39.053470857681766, 0.03841333008641678, 0.05227315532524259, 1.5047733125186737, 0.6702869745992845, 5.036144343114668, 70.96994599988385, 57.65491524050313, 62.19190512934039, 58.34791175780758, 61.52815380404073, 56.68104563989947, 59.14194068601055, 51.760157692816954, 55.183888712236964, 58.2475539945787, 59.28214188544982, 56.62820346893803, 53.83504052315989, 46.66596766441099, 42.57426877175608, 44.44070116166146, 43.60060399578464, 42.443132169785045, 42.12401597730575, 41.15693992184055, 41.87118784073861, 40.36702163757817, 39.13242032451015, 39.91658841409991, 38.961907048379224, 39.33473617799821, 40.21920711763444, 38.64907841528616, 37.79221311692269, 37.767011888565555, 38.467994351540845, 39.34282410529352, 39.89646665511593, 40.07011390501454, 39.55027434133714, 40.044430225126206, 40.23568499472834, 38.72125394882695, 39.4972909650495, 38.79989354841171, 41.16183111744542, 39.88988884033696, 40.853313169171734, 42.203718539207216, 40.816493880364206, 40.693158872665904, 44.4599639215777, 44.58959433340257, 42.060528493696644, 41.122281858997965, 41.37367048571187, 40.43968746739049, 40.4722313727102, 42.377667811609086, 41.070133947557025, 40.81502299154959, 45.551041787670506, 54.47767380745181, 52.88376377474878, 49.95903668865081, 51.85361600691273, 51.71233615567608, 55.17675392089352, 53.57674852494271, 49.93157225270426, 52.629441215145974, 56.673710807677246, 48.909669306970414, 50.00296331221058, 47.940887020480254, 45.145217680162006, 41.62682810137349, 42.29441550470168, 39.78656968762798, 40.73961150261664, 41.43948785720333, 39.819509752335094, 40.517377853393555, 42.36817175342191, 42.88804661843085, 42.801052370379054, 45.32308932273619, 44.319295960087935, 43.22192268986856, 41.646271290317664, 40.72094886533676, 39.88628810451877, 39.41435244775588, 40.19635538901053, 38.506594396406605, 40.255677315496634, 39.678830023734804, 39.32154132473854, 40.590024071355025, 39.60803516449467, 40.94084085956697, 41.53355021630564, 42.17356335732245, 39.47538452763712, 41.290798648711174, 39.44409578077255, 40.19841463335099, 40.49076064940422, 42.030773393569454, 40.19895592043477, 41.923104332339385, 41.707687762475786, 43.46355638196392, 42.80291157384073, 45.37295049236667, 42.3028564453125, 44.4823645776318, 43.055798545960464, 44.06412616852791, 45.16059729360765, 47.07976595047982, 46.67066274150726, 52.51630829226587, 51.92512473752422, 56.43019437789918, 57.691452118658255, 63.36813372950401, 60.30236997912007, 65.06168765406456, 64.34271327910885, 68.91699314117432, 61.331372414865804, 65.98529600328015, 20.99456479472499, 0.9631113359524358, 1.8777049140584086, 0.8487431116161809, 0.15638108365237713, 15.529290110834184, 77.19941508385443, 64.58410378425353, 77.61087955967074, 64.98603297818092, 40.329821878863925, 22.41707705682324, 36.59988318720172, 51.56536886768957, 67.97790711925876, 16.733394015219904, 0.05888026530644106, 0.054519604741325306, 0.043078177353186954, 0.02247312414129415, 0.044361432082951076, 0.02454322969330655, 0.031149010511956392, 0.17069056419835937, 0.09553816620140307, 0.19058382979804472, 0.1311952383407662, 0.22675928299225148, 0.11499925862036406, 0.0877006347441385, 0.3028882132662881, 0.3072476825646816, 25.128450739768244, 85.29104509661275, 64.70705439967494, 59.536825303108465, 28.507398097745835, 29.455442813134965, 45.5044714866146, 69.40274730805429, 63.40084629674112, 77.63626513942596, 41.81171294181578, 0.21944392472505572, 0.5671662080191797, 4.552592096790191, 1.9576426955961415, 6.452246471758812, 76.00724989368071, 59.71384186898509, 65.00277757644653, 61.4192884199081, 65.2839409151385, 57.952101461349, 58.15422904106879, 53.98962897639121, 56.49449379213395, 59.48378701363841, 62.071609958525634, 58.41516079441194, 56.36397300227996, 49.69455911267189, 44.57698391329858, 46.63689113432362, 45.57514475237939, 44.47912862223964, 44.073751664930775, 41.82553145193285, 44.49122128948089, 43.69356024649836, 40.82549571990967, 42.99222869257773, 41.24403615151682, 41.32579795775875, 43.902634343793316, 40.94651260683614, 39.79503808483001, 39.41458386759604, 41.33835346468034, 42.802942952802105, 42.22013758074853, 40.48543799308039, 41.80195800719723, 41.827476947538315, 42.670904205691436, 39.23117383833855, 43.00016364743633, 40.30130232534101, 45.00504785968412, 41.30322863978725, 43.1431693415488, 44.997367858886726, 43.325218308356504, 44.50653422263361, 46.28830225236955, 46.90073328633463, 44.18448409726543, 43.33834255895307, 43.0322878591476, 41.72727215674616, 42.73539581606465, 44.50248633661578, 43.0578617126711, 44.57724671210013, 48.730762158670736, 54.88595724105836, 54.715294914860884, 52.80100960885325, 53.650383180187596, 53.64803368045438, 55.29646465855261, 56.026908043892156, 52.2846648769994, 55.78237572023946, 59.380828718985285, 52.23134417687693, 53.150888950594016, 49.22891493766539, 47.63759759164626, 43.09469669095932, 43.546212488605136, 41.50162212310299, 43.23908305937245, 44.785183322045114, 42.95885716715167, 41.83921267909389, 44.30318286342006, 44.524051527823175, 45.186834027690274, 46.66291606041693, 47.0411462937632, 46.384525837436804, 44.72607320354831, 42.22794309739144, 41.24548742848058, 42.91185932774698, 42.06200722725161, 41.04502293371385, 41.89590269519437, 42.060720689835094, 41.1572301772333, 41.924335956573486, 40.60046542075373, 42.557881109176144, 44.642161938451956, 47.244929113695704, 40.841102830825314, 45.26647383166898, 43.126989564587994, 42.05531174136747, 42.88266120418426, 44.73597326586324, 42.81011696784727, 43.694399633715236, 43.99919917506557, 46.1503799500004, 44.01706557120047, 48.16841586943596, 46.17799735838368, 48.02764200395154, 45.34937312526088, 46.47997279320994, 48.128407693678334, 49.87396047961328, 51.054213431573686, 54.564821027940326, 54.67440812818466, 56.618146511816214, 61.36136677957351, 65.47350122082618, 63.784089319167606, 67.15614703393751, 66.47021862768358, 71.83882159571495, 64.598318453758, 68.22773072027391, 26.561845617909587, 1.4781752300839273, 4.622961378866627, 1.3875366098457769, 0.40973884744509576, 17.02903482221788, 83.84564384337395, 69.11457077149423, 84.50708097027194, 69.50796881029683, 46.58155433593258, 32.42652446992936, 47.726502033971975, 63.177082923150834, 80.99176652969854, 23.22485585366526, 0.22916512083142038, 0.13922505020614595, 0.14623660864608903, 0.2860278437935537, 0.13478108140970432, 0.23053200554943856, 0.13853983052315252], [0.04885305920916219, 0.06729633487280338, 0.021350449101338466, 0.01664049266236684, 0.008757097436295403, 0.05767120236170389, 0.02760826320868106, 0.05061260612320997, 0.10042448182620349, 8.275023371942583, 61.45057716677266, 49.025371382313395, 34.64128294298726, 16.08062630699527, 31.699579838783514, 40.36816304729831, 43.03148769563244, 54.224445589127086, 62.887106018681685, 41.87282346910046, 0.2566271972271704, 0.2622494245729139, 0.1782256364822388, 0.21222587494600206, 3.0156517942105574, 57.79908587855678, 56.73939874095302, 63.262759254824736, 57.078785742482836, 61.237627767747455, 47.586551866223736, 51.54217981523084, 51.06140313609954, 55.08768473902057, 54.85251119059902, 56.607179564814416, 53.43674344401206, 53.85358156696443, 48.06278644069549, 40.2168183941995, 38.47556060360324, 38.066378947227236, 36.825239043081964, 37.84962877150505, 38.21138112775741, 38.867883912978634, 37.77923007165232, 38.69487993178829, 37.86873071424423, 37.481655536159394, 36.255773651984434, 37.21616991104619, 36.96879779138873, 35.60193023374004, 35.82628588522635, 36.77802155094762, 36.13376440540437, 38.162120080763295, 37.30143831622216, 37.999616284524244, 37.4355363076733, 37.8270516087932, 36.76091217225598, 38.41876076113793, 35.23401975631714, 37.73744506220664, 37.99759234151533, 39.4555373345652, 39.762101942493075, 37.70362246421076, 40.909720774619814, 44.237039935204294, 40.30612291828279, 41.273304877742646, 40.85725515119491, 37.79574325007778, 37.94471879159251, 38.805855551073634, 39.855736763246604, 38.242077596725956, 39.92578637215399, 44.44807521758541, 45.38199155561386, 50.43494570639826, 49.91335676562402, 49.189106802786554, 50.42041332490983, 55.21220822488108, 53.15551734739735, 47.738092637831166, 52.6279781710717, 52.226096045586374, 49.729801608670144, 47.07031696073471, 44.60090252660936, 42.21166526117633, 38.09043484349405, 39.322643510756954, 39.636633165421024, 40.13439370739845, 38.125979361995576, 39.18679221983879, 38.10042512032294, 40.454729757001324, 41.24502066643008, 45.0051498413086, 43.73382729868735, 45.44218032590805, 42.11889728423088, 39.40573107811713, 39.99507504124796, 39.98259405935965, 38.48662953222952, 37.687513289913056, 38.66740765110139, 39.22222298960532, 37.986954873608006, 39.63405616821782, 39.34999419796852, 37.07254056007632, 39.05822869270079, 38.916317339866396, 38.54560629014046, 36.997262431729226, 38.713417053222656, 38.06719872259325, 36.765744532308275, 36.60788874472342, 38.28602775450676, 39.77500261798982, 41.28779019078901, 38.571827334742395, 41.1961793130444, 41.56865935171805, 42.154320209257065, 41.70689936607115, 42.7103671719951, 42.13489270979359, 42.95872772893598, 43.86372835405412, 45.87639847109395, 49.90361752048616, 53.51600277808405, 53.09385768828854, 55.711902495353456, 56.723469995683246, 56.58250001169021, 55.627167532520915, 64.58500592939316, 59.43922496611073, 72.97563429801696, 59.547376478871996, 63.903113642046534, 18.27570919067629, 0.592429397567626, 0.43876567374794717, 0.4242682565123804, 0.17750934427303655, 12.766822653432047, 73.188579774672, 60.830293547722604, 73.39360990831929, 56.966327467272365, 52.47196589746783, 23.598443961912587, 31.08742140954541, 53.732360716789, 51.17258271863384, 7.916418717753503, 0.10565553701693013, 0.05331969271684366, 0.013816804613827938, 0.0268630281976995, 0.056216163906238736, 0.027434351673770337, 0.10270771495397053, 0.019297850573615685, 0.018701648392203837, 0.03809550318927054, 0.05349373640192132, 0.04940560395498911, 0.014337612252171724, 0.012649954071328526, 0.05122024408211151, 0.11824295916143926, 10.315422684915605, 70.07656343521612, 56.52515888214112, 43.06796573823498, 17.676257279611406, 26.803824478580108, 48.38979444196148, 52.691728453482355, 57.7871108824207, 69.30901835041662, 45.955653882795765, 0.24090976965042854, 0.1396582116402926, 1.3653097638199407, 0.4985826768942418, 3.751349194395927, 63.10686857469621, 59.7051695085341, 63.69412583689537, 59.53046321868897, 61.90009647800077, 49.84510752462572, 52.49000880026048, 51.807932161515765, 56.82713431696738, 56.82860128341183, 57.76865220838978, 56.522405378280155, 56.0410560331037, 48.689455678386075, 42.260522304042695, 41.97984141688193, 40.795418985428356, 40.260309634670136, 40.683125449765114, 39.74721262531896, 41.75599567351803, 39.46761038995559, 41.19246875086139, 39.51523973095802, 40.53054132769185, 39.60971001655825, 39.75622623197494, 39.072651247824396, 38.625363765224336, 37.95665848639704, 38.521515092542096, 38.969037917352495, 40.194488340808505, 37.98669599717663, 38.23618227435697, 39.30385535763156, 38.55525139839419, 38.745007822590495, 39.9684186135569, 37.816943660859145, 39.43762386998823, 38.94667648500012, 40.61885741449172, 42.28349170377178, 38.68126146255001, 40.860777439609656, 46.63159985696116, 42.66705243818222, 42.055464713804184, 42.18929598408361, 40.071098419927786, 40.58551726802703, 40.14488212523922, 41.0740759295802, 40.785224745350504, 41.93732292421403, 44.79894691897977, 50.983332280189764, 50.03187118038055, 50.98318323012322, 51.26801398492629, 51.32039723857757, 55.47710549446845, 53.68119339789114, 49.12842381385065, 53.612673513350956, 55.53654116968955, 50.34651587086339, 50.162148783283854, 47.06418237378521, 45.08730388456776, 39.654852574871434, 40.376568686577585, 40.33000623026202, 43.27805965177475, 39.33975681181877, 40.52638361530919, 40.24598513880084, 42.32582976741176, 43.76100147924116, 48.21528427062496, 45.73377716925837, 47.63303587513585, 43.495205986884336, 41.637944098441835, 40.07239672445482, 40.40787312292284, 40.5781392897329, 39.58051973773588, 40.50194724913567, 41.04532103384695, 41.10931058083811, 41.62948354598015, 41.876463428620376, 39.219740129286244, 40.589380802646765, 39.6878279409101, 40.026332409151145, 40.233512001652876, 40.01389457333473, 39.48415494734241, 39.94226424924789, 39.325581366016024, 42.289991071147305, 42.4412533544725, 42.55702995484875, 40.65933235229985, 42.00992991847377, 41.8229034639174, 44.07149237971152, 41.87758522648966, 44.744661315794914, 44.26868954012471, 45.77738215846401, 45.01558334596696, 47.94322475310295, 52.34121368777368, 55.1658183528531, 55.38013665906845, 59.503645973820845, 59.18187825910507, 60.1777562787456, 59.19664990517401, 66.67994776079732, 60.68908429914906, 74.4984317594959, 62.22421369244976, 66.53160372088033, 20.03343113007084, 0.8478709971231799, 2.686430105278569, 0.9298419147249192, 0.20135579210135246, 13.917270495045571, 79.40238291217436, 65.71583309481221, 75.8784314124815, 63.12719429692915, 51.44703095959079, 23.536858827837055, 39.69555501014956, 61.554449373675936, 62.944988435314556, 10.852180411738734, 0.06384081102066463, 0.048155045857833284, 0.018470127045387225, 0.03947212105436672, 0.017664727319272298, 0.045572387264861215, 0.0885615107272902, 0.1567254401743412, 0.12305669561629334, 0.13136927819540425, 0.13825011139194812, 0.1482094535904546, 0.08202969952816926, 0.241271807481685, 0.1632200118394629, 0.2558737344318821, 12.426246193147476, 80.9629527984127, 63.82885140757408, 51.478131432687086, 26.220603335288267, 42.26424071096605, 54.073885410062736, 60.853521823883064, 62.69048544668383, 75.1471996307373, 51.21026100650911, 0.4841238092030249, 0.535772844187675, 4.623624259425748, 1.989115916432873, 4.554142903897071, 68.44236281610304, 60.02399152325046, 67.5022569779427, 60.86021338739703, 64.81020489046651, 50.7359052473499, 54.06864512351252, 52.46792193382017, 58.16338777542115, 59.467458186611054, 59.95953521420879, 56.07139556638656, 59.62864798884238, 51.13989760798793, 44.181252064243445, 43.188476639409224, 41.90111552515338, 41.10867123450003, 42.773203542155606, 43.21150095232072, 45.86680827602264, 42.09901086745724, 44.107907664391306, 42.49451129667221, 43.2447704961223, 42.715960471860825, 42.601450797050234, 42.08281540101574, 41.172809831557736, 41.19742270438902, 42.13816788888747, 42.06476857585292, 42.20032176663799, 39.947481001577074, 41.342519021803334, 41.13197403569376, 39.82998248069517, 40.80173792377595, 42.719184660142474, 38.80182335453649, 43.209637826488866, 40.37729432505947, 42.805296374905495, 43.23883595005159, 42.16626382643177, 43.87938253341183, 50.13872831098495, 44.55359874233123, 43.18392276763917, 43.3661090174029, 41.275995623680856, 41.90121750677786, 42.3631158182698, 43.34848188584851, 42.55244470411732, 44.88230120751166, 47.862745561907374, 49.46372762803109, 52.58523610330398, 53.37036125121578, 52.818220969169374, 55.32368982991865, 59.716105076574514, 56.663979407279726, 50.48887045152726, 55.052477544353856, 57.09921736871043, 53.228979418354655, 52.51626514619397, 49.68168981613652, 46.17343564187327, 43.47853199128182, 42.31753787686748, 43.84037456204815, 46.07716106599378, 42.13041728542697, 42.12942100340321, 42.43158471199774, 45.023737953555205, 45.83631577030305, 49.269668363755756, 47.66480707353162, 49.717744242760446, 46.38781670601138, 42.93110247581236, 42.641435438586825, 44.06409478956654, 42.512518898133315, 41.249131310370664, 43.015292229190955, 43.21540371064217, 43.53453559260215, 42.88636392162692, 43.48589035772508, 40.11871207144953, 42.258521895254816, 42.14760511152206, 42.16363976078649, 42.20247514786259, 42.366187034114716, 42.409439010004846, 41.236756232477006, 40.93525932681176, 43.739330384039114, 46.600456237792976, 46.42953111279396, 41.59615124425581, 44.29673840922695, 43.929271159633515, 45.45660288103166, 45.804375909989886, 48.824765682220466, 46.58062081183157, 48.40688420880226, 47.61454974451373, 51.171653116903, 55.861697812234205, 57.4114498015373, 57.550909673014, 60.42927434367519, 62.36257530027821, 63.98378895175073, 60.853929750380985, 69.94662315614762, 62.95251154130506, 76.65204048156738, 65.97963994549167, 70.12865251110446, 23.558941771907193, 1.2885233615675282, 4.882930680628746, 1.6753933506627239, 0.42163668320544306, 15.999563663236557, 86.60943215893161, 72.66370388769334, 82.54853956161007, 68.54068879158267, 67.68456874355194, 34.61644257268598, 49.02659908417733, 70.87562868672033, 76.95208611026888, 14.886352842853917, 0.18604339521017768, 0.20157590448375673, 0.09886390709828946, 0.17104671847435737, 0.10808867822972038, 0.13410874732559727, 0.23128828754828823], [0.05453112670370648, 0.06074258291553106, 0.06209287033866971, 0.055192704913356615, 0.044868118805630554, 0.01807111589568517, 0.002055531208057918, 0.026061234830488122, 0.075843462930812, 1.5185394835087562, 46.339191082985174, 52.071111432967655, 47.99291333844585, 33.18496181118873, 34.74550816320604, 32.26275178693956, 45.749525485500214, 60.54720824764621, 59.799592725692264, 49.62301115835867, 1.016279615221485, 0.304221359472121, 0.615182392779858, 0.2792088338924993, 3.102060873662272, 53.96751465335969, 55.862925514098144, 60.234156039453325, 56.36009377817954, 59.483892917633064, 53.55737593866164, 44.89133834838868, 53.846442853250814, 56.37365733423541, 55.85235864885392, 57.14239089719711, 54.036058072120916, 51.31040696174868, 47.73710420054775, 43.048059709610484, 39.22707888387865, 39.73477871187272, 39.01382746235017, 38.295362995516875, 38.14625409341628, 37.87533598561441, 38.239155430947584, 38.83177065080212, 36.90922091084142, 38.284007733868016, 36.43775593849921, 36.842960311520486, 36.70041745708835, 37.257499925551876, 35.667731915750814, 37.20955287256549, 35.93216634565784, 38.22272854466593, 37.61871099472046, 37.231612282414595, 37.6271362458506, 37.602401779543975, 37.27176166349842, 38.01125003445534, 35.30366536109678, 37.93556005724015, 37.59919720311319, 38.91598786077192, 39.7259259223938, 39.87116344513432, 39.71384894463324, 43.65665074317686, 42.52599223967522, 41.75305781825897, 39.021432938114295, 41.50564647489979, 38.21933569446687, 38.952579652109456, 38.64641512593916, 41.313065944179414, 36.24722288500878, 44.91966570577314, 41.89551045817714, 49.72427891146753, 49.76515393103323, 48.082402213927246, 51.19597573434153, 52.07967788942399, 52.7623938745068, 46.83608870352469, 50.545972316495835, 51.436146382362615, 49.721148860070016, 45.30143391701483, 47.34204307679207, 42.84071145519134, 39.233731223690896, 39.711507289640366, 39.15603299294749, 38.504417480960974, 38.46877490320514, 38.61970770743586, 39.23551197974913, 40.868496664108775, 43.60910769431822, 43.627385939321215, 44.515889075494584, 45.3740369889044, 38.32082702267555, 37.28525069452102, 37.89299057376, 39.13363625926357, 38.481189204800515, 38.47479181904947, 37.80190921598865, 37.02310300642444, 38.342733460087935, 37.60969738806448, 38.75202494282877, 38.56502986723377, 38.1706630029986, 39.8940190961284, 38.82898969034995, 36.59478410597771, 39.18977322116975, 37.94642894498764, 37.72537200681625, 36.89265281923356, 38.56903460717971, 40.14057536279002, 41.01040801694317, 39.49392164907148, 40.69357856627434, 39.85271261584374, 42.27112054824829, 41.22590695658038, 41.137539878968276, 41.910089908107636, 42.143494467581476, 41.0248972523597, 45.51979618687784, 53.367807788233605, 58.99295729975547, 57.39303819594845, 57.6987281153279, 57.5766678779356, 59.208589599978545, 56.842921856910955, 63.02934685061055, 59.07971620559693, 64.9840247246527, 63.97604227066041, 69.80385672661566, 19.839405205941972, 0.34097356962100156, 1.7762030444798933, 1.1727683342272237, 0.18088540182478968, 15.587826582693285, 71.96166238477154, 58.94737935835316, 73.52820211841215, 55.12339007469916, 44.276098897380216, 29.38682486934047, 38.24996940551266, 52.82985079673029, 46.752463771450905, 5.369056001786263, 0.1003493132790731, 0.021944722656400937, 0.051402193794567744, 0.02525920397602022, 0.047462337665380015, 0.03275094441168251, 0.06728331137809061, 0.04329106169602564, 0.03415214603826885, 0.02446567861273164, 0.05475127356006734, 0.06247162037799436, 0.09049755280777332, 0.013715598653371056, 0.036588370754954316, 0.0298612320329994, 2.4604635853921217, 56.6426887819844, 57.99297255854453, 53.12977875432661, 30.485865146883075, 28.709780631526826, 42.635693088654556, 50.529584653915904, 65.25990855309271, 63.769243148065385, 54.14619430418938, 0.8594729390836532, 0.1843806933010778, 1.1495563604177967, 0.6929427685756838, 4.389178310671161, 59.004261570592085, 56.592811922873224, 62.8160209040488, 57.82164735178794, 61.29080334017354, 52.852675068763, 47.8734104864059, 54.823634701390425, 56.56552007121425, 57.471097284747714, 59.18768728933027, 56.061746535762666, 54.59565870223507, 51.02061440867763, 45.08174588603359, 40.81067308302849, 42.11522594574959, 41.52998478181901, 39.696763100162634, 40.02150004909885, 39.1906871334199, 39.7773011269108, 40.25731686622866, 37.73163603198144, 39.30183925936299, 38.77096999076105, 39.079664445692494, 38.2686085085715, 39.95718886775356, 38.34904847606536, 39.73970913117932, 37.92474608267508, 40.22591829299927, 38.05968738371326, 38.21033385492141, 38.36010563758112, 38.78988758210213, 39.61336566555885, 39.87352078960788, 38.75176214402722, 40.95041536515759, 39.81354774967317, 42.223530430947584, 39.69587664450369, 42.08465499262656, 40.870995213908536, 43.90943573367211, 43.63992967913228, 42.028702382118475, 43.44828659488309, 43.542737268632465, 40.966336265687026, 41.412278375317975, 40.10835701419462, 42.86971738261562, 39.978397123275265, 45.59936931056362, 46.68661502099807, 54.320539735978656, 49.407465150279386, 52.26885380283479, 53.94503162753198, 53.10111015073715, 54.92479655050463, 46.87763837076003, 51.359613095560384, 54.11948688568608, 50.390987703877116, 47.47925543016004, 47.10119385873118, 44.438763510796335, 40.61857500383931, 40.136331358263575, 40.480060423574145, 41.323264106627434, 39.702379934249386, 41.65565752214001, 39.81175914887459, 40.73397505667902, 46.66359070808657, 44.34097097766015, 44.91529226303101, 45.882038839401744, 39.44857120513916, 40.514322327029326, 39.177111810253514, 41.42318256439702, 39.933666413830174, 38.1057007082047, 38.51129339587304, 38.965009643185525, 40.4399698780429, 40.323797118279245, 40.6073844817377, 41.28782156975039, 40.98583044544343, 41.60504717980662, 41.44926632604292, 40.70754220408779, 41.96865481715049, 40.50510083475421, 40.158335854930264, 39.537161857851096, 41.59884591256419, 40.755826580908995, 43.66485241920718, 42.32197799990254, 42.2738818968496, 42.11860310646796, 44.340406156355336, 44.37788832572199, 44.14998685159991, 43.13599532650363, 44.90289757328649, 44.70070723564395, 48.91804356728831, 55.755095635691, 61.09333161384829, 60.98509380894323, 59.83483129932035, 60.48689788387668, 63.58451128005982, 60.32977557951405, 66.63574264895531, 61.5165828120324, 67.01506722357966, 66.54735595949235, 72.63379973749961, 21.693501741655414, 0.4728553606377494, 2.892492557725599, 0.7896327479712425, 0.18619846672781054, 16.705170600645005, 77.33108120579874, 64.42871124513688, 78.64299635733329, 59.65269211799868, 48.55657754405853, 27.943563269030665, 42.83095652057279, 62.045941968117994, 57.39388935027584, 7.196470124106254, 0.09862844231388262, 0.03543071614037599, 0.09286568379930912, 0.08370781512630564, 0.08601368615223516, 0.044285470634819045, 0.025853893133781614, 0.11040303750985092, 0.23350456459147317, 0.11970423357260805, 0.1329173273857563, 0.22203298015219552, 0.18500916119064056, 0.09695434101646948, 0.15889700832626513, 0.13185762860361608, 3.272684221306155, 64.97450905461466, 66.38559741358604, 63.137341468564934, 44.22542579712407, 45.510786502592026, 44.972484342513546, 58.35097905128234, 70.13179040724232, 71.24239383205291, 60.38976823129962, 1.4834525340026425, 0.6111803494634167, 4.410120335317427, 1.5371182801262027, 5.750894815691057, 61.71179525313839, 57.06717160440261, 63.39384486598354, 58.847409909771336, 62.876605833730395, 54.08880218382805, 49.73191184382285, 54.954614408554576, 58.450415057520715, 60.01568002085532, 60.665542233374815, 57.719865768186516, 56.87831340297576, 52.73502749781455, 47.51391349300262, 42.978759273406, 44.80071590792748, 43.39801749875469, 41.55250310897827, 42.123776712725245, 41.8332467540618, 43.69422704942765, 43.51288018688079, 40.67957962712934, 42.29108933479556, 40.05919794882498, 41.20369849666473, 40.56244980904364, 42.82794806265062, 41.129785353137606, 43.41300487518311, 41.651029125336684, 41.761851772185295, 40.95570272014987, 40.4635040990768, 41.088372968858295, 41.89328255191926, 41.46701505107265, 41.41140760913972, 39.6464979264044, 43.474154626169515, 40.85023803095664, 44.82514442936067, 45.047915443297356, 44.27487119551628, 42.8548280654415, 46.542338478949766, 44.98000352613388, 43.5236902390757, 44.46527873316119, 45.56816685584284, 40.8466882859507, 43.938990792920514, 42.6950660059529, 45.835758793738584, 40.84810033921273, 47.84467520252351, 50.098359277171475, 53.420559744681086, 52.133865433354536, 54.98396942692419, 54.732941658266135, 56.7367668305674, 56.03942040474185, 49.87077159266318, 53.52594990884104, 56.30036392519551, 53.35505224043324, 50.415933978173044, 50.78967702004218, 46.84189773374989, 43.535053345464895, 43.37571097958473, 42.62998604005383, 43.57046450338056, 42.103862839360396, 44.018979687844556, 42.3113719109566, 42.95147526648737, 47.89058654539047, 46.25896684585079, 47.404812766659646, 48.74748714508549, 42.27532532907302, 41.180478065244614, 42.05728469356414, 44.56704854965211, 43.0302050805861, 39.69633948418402, 40.7830007614628, 41.13360966405561, 41.619348141454886, 41.97164758559197, 44.48798533408873, 42.14085471245551, 43.34888196760609, 45.19382761370751, 45.06737039935204, 41.73404609003375, 45.587500218422186, 42.61509280050955, 41.87051711543914, 41.74539742931243, 44.12762149687737, 44.708379391700994, 47.402565248550914, 44.26168026462678, 45.73477737365231, 42.86530079380159, 46.48198496910834, 47.456152669845096, 45.40360773763349, 45.65493360642464, 46.237550704709946, 46.09787510287377, 50.24249461389358, 58.72121549421742, 65.17225926922214, 63.98221215894146, 62.390106416517696, 65.11449844606462, 66.67873967078425, 63.00266296632829, 69.64605192984305, 63.323897238700624, 70.03013826185658, 67.7003131374236, 75.75188790598224, 24.015042820284446, 0.625237450003624, 6.042352414900257, 3.2364706935421115, 0.33586845162414736, 19.207754558132542, 84.39190449253206, 67.99201196239841, 85.22690649955504, 67.27002912952055, 58.48775209919099, 42.59843057201755, 55.029747409205285, 70.29126613370835, 71.10780162196006, 13.103706202199383, 0.27817014124124284, 0.17298968598967598, 0.2865023280103361, 0.15812828505952514, 0.24706442810354695, 0.09454767580234236, 0.15934854054883604], [0.037914331056057446, 0.010854943032046, 0.01588370121504751, 0.019888054286580414, 0.02960276162822641, 0.08771767253957449, 0.042178257698974306, 0.08024528156965971, 0.07055502775455676, 0.19216592393575177, 38.471936333564024, 60.321495456080285, 47.717610020791334, 32.98501114691458, 22.150300971923336, 32.0588061886449, 46.46615428309287, 59.89749900756344, 56.58172730476626, 56.69355015600882, 3.471165957950777, 0.4218369998758839, 0.2244394615052208, 0.3007783458357857, 6.110597733528384, 55.60041696794572, 58.68609066932433, 59.15126415991015, 58.54060995963312, 58.45798130958312, 59.513718620423354, 47.80138400293166, 51.31927936307846, 55.27207928319132, 56.218633497914965, 55.057698219053215, 54.30760375915035, 50.768178509127715, 47.972442488516535, 44.44459999761274, 38.987025906962735, 38.64090027347688, 38.65781745603008, 39.89985166057464, 36.61766329119283, 37.531626532154704, 37.51893766464726, 38.231396982746745, 36.55208910665205, 37.86767951903805, 37.10944221865746, 37.88199617016701, 37.09812225834016, 35.43924993084323, 35.515920500601496, 37.848785461918006, 35.512927732160016, 37.16929366511684, 35.09743498217675, 37.838979536487216, 39.986434059758345, 38.122308023514286, 39.085795110271825, 37.84387073209209, 35.43996380221459, 38.46452305393834, 37.065099823859434, 37.96493468746063, 39.60078662441623, 38.99163861428538, 38.032556349231356, 41.79880049920852, 43.445340894883685, 42.12236465946321, 41.19220202968967, 39.5440613069842, 38.020702946570616, 38.008763251766084, 39.69697490815194, 40.014745727662124, 37.65192170296946, 43.12172574381675, 42.756800190094985, 40.65923821541571, 52.70926144815261, 51.03682556459981, 47.232785455642215, 52.97647683851181, 47.61483607753631, 45.89188791090443, 49.80650355738979, 49.11823741851315, 47.902306587465354, 45.63364690349948, 44.37835116540232, 41.0418575809848, 37.20005289200814, 38.67142415815784, 39.66264632440383, 37.73234598098263, 37.76906328816568, 38.6889140067562, 38.59673830770677, 42.67496385881978, 42.016237089710856, 43.26719468639743, 43.593708469021706, 43.6138851411881, 38.39517162692162, 37.90442428281231, 40.659736356427594, 39.27458270903557, 38.76319193070935, 36.9805335229443, 37.50941807223905, 38.162477016448975, 37.74035938324467, 36.8689577810226, 39.53355327729256, 37.5755060872724, 37.88925255498579, 37.13531417231406, 38.15241221458682, 36.49662287004533, 37.93567380597515, 37.77586467804448, 38.089736661603375, 37.83041308003087, 38.504221362452355, 38.81465734974031, 41.19230008894398, 39.08247286273588, 41.95222400849865, 40.054663688905784, 42.75321514375749, 41.94736419185516, 43.75700458403557, 42.633786816750806, 44.58795870504072, 40.92351182814568, 49.22067403793336, 55.49221446437221, 60.518869123151234, 54.0041535131393, 59.45394562136743, 60.568749904632575, 61.83662860624252, 57.812594521430235, 62.511213517958126, 59.000213684574256, 67.51991548845845, 58.29855657392933, 73.07003005858391, 22.170660034302745, 0.1996607153165725, 1.530037666520765, 0.4664455336188117, 0.23423211829316234, 17.461164305287024, 75.30751474442022, 58.920715085921756, 71.20149920063635, 54.69683624082997, 56.38052148203696, 39.27956411915441, 30.772398210340935, 54.66016207971881, 50.82191105811827, 5.425779848329483, 0.14627633796584222, 0.06331085437728513, 0.06841211129100093, 0.03701955185181672, 0.03323210125428534, 0.03796696895733476, 0.02569306446539779, 0.0346386386832643, 0.0058798382956264245, 0.03151253838422558, 0.06430496837222768, 0.03485545688759416, 0.07729787319417923, 0.014947732335947936, 0.05753596869087028, 0.04302152898162604, 0.5014801439979385, 47.05763201559744, 64.95755264835974, 55.51153998221121, 37.98109877494074, 24.815492668459495, 35.521631471572384, 51.63495563691663, 62.7386050839578, 62.5762071917134, 62.015182741226695, 3.425773838835378, 0.4131379795651282, 0.5671923162956392, 0.5952535653787275, 7.534943213385921, 58.775199074899, 58.44690453621649, 60.52557637614589, 60.67738779129521, 59.43358852017311, 58.28666786993704, 50.96101791627946, 50.50492471264255, 55.282477486518125, 56.68224980754238, 57.09041557004375, 54.90347846861809, 53.223935250313055, 49.27889377840104, 45.822297219307195, 41.509137384353146, 40.3082606100267, 41.09863781159924, 40.953863128539055, 40.419910876981675, 40.126866679037775, 40.0648343947626, 38.880039338142645, 40.59937500184582, 40.798721621113444, 39.66110091055594, 39.00082088285877, 39.30347096535468, 38.334747514417096, 38.1313177078001, 38.4413496909603, 37.76018696446573, 40.29781141588765, 37.32393310916039, 39.80830354075278, 40.72666375867782, 39.00961875915527, 41.937762229673325, 38.580864475619414, 37.032046010417325, 40.59733144698605, 38.88350671337497, 39.68181494743594, 40.53103946870373, 40.172154365047334, 41.52650563947616, 44.99174710242979, 46.02294606547202, 45.17179566044962, 43.09135875394268, 40.267652311632716, 39.4937765213751, 41.07374645048573, 39.77716384395477, 41.74370688776816, 39.09365161772698, 44.587982239261756, 44.7695016860962, 45.34524679183961, 54.83949676636727, 51.052679784836315, 49.9235039372598, 50.57315826416016, 50.02645438717258, 47.64662688778293, 52.17502678594282, 49.93494941342262, 49.12912199574132, 47.86703663487589, 46.332911368339296, 43.37655428917178, 39.14953754794213, 41.03339702852311, 40.721419549757435, 40.179034202329575, 40.42222115301317, 41.29033973140102, 41.711347333846554, 43.70338578378001, 43.33565181301486, 44.17398391231414, 47.386377626849765, 45.00144712386593, 40.861083384483095, 40.99799371534779, 41.34464494643673, 40.04753281993251, 40.412085748487904, 39.34844093938028, 38.58757957335442, 40.98848981242026, 38.35445350216281, 40.02996844630088, 42.2689240209518, 39.90928496083906, 40.5926481370003, 39.45649047051707, 40.7180816127408, 39.18907896164925, 40.162968174103774, 39.689047798033684, 42.2174076111086, 40.097437135634884, 39.45506272777435, 41.12147385074247, 42.62032916468959, 42.13888960499918, 44.64561754657377, 43.695168418269006, 44.6635506230016, 43.887552830480764, 44.892864150385705, 43.466094155465406, 46.783164162789625, 43.134900985225556, 50.869603157043464, 59.00609331746256, 62.39373853129726, 58.04529305427306, 62.12542095491963, 63.35666864149032, 65.03170505646737, 60.4494902395433, 65.81046027521934, 62.74280594241235, 68.64358825068321, 61.238357328599506, 76.51846024297899, 23.2466838436742, 0.24507244628283287, 2.4497437477111816, 0.6883720428712907, 0.25473684463049134, 20.02342124139109, 82.39507290624803, 63.0010744064085, 80.98687925646382, 55.80636493621334, 58.03960953989337, 45.991920117409, 39.90846518547305, 62.71712226252403, 61.445521231620546, 8.930745605499514, 0.2284832412917768, 0.05304797665185986, 0.033952212411790125, 0.03193510482237945, 0.0840139055564519, 0.018456383428025632, 0.03212093093973254, 0.12598197171164136, 0.12528419584756897, 0.09421374573702775, 0.16956807684994515, 0.11990898589213049, 0.21727431775821796, 0.10774753927703827, 0.2698383528378702, 0.14607435122372645, 0.6844704490034812, 54.622997622336115, 74.4901555584323, 61.99242514948692, 46.34160726301132, 31.192407569577618, 44.34455210162748, 60.793850806451616, 69.76685308641004, 67.57863336993803, 68.2835852715277, 4.387090138850674, 0.7476088416672523, 2.869598418474198, 1.63268756481909, 10.220858262431237, 60.98446230734549, 59.03465209468719, 62.90318381401801, 60.96307754516602, 61.118960380554206, 59.90889349291402, 50.968976405359086, 52.491126675759595, 57.266800634322635, 58.186341485669544, 58.10742339780254, 58.566113210493526, 54.143935018970126, 51.7351721948193, 49.5151145996586, 44.529829179086995, 43.07991327777986, 44.263496322016564, 43.12464398722495, 42.368379639041045, 41.88596340917772, 41.37780074150332, 42.5217443127786, 42.62523604977516, 44.49874047310122, 43.126989564587994, 41.371128789840206, 41.8881481693637, 40.955200656767815, 41.68056457273422, 41.269009882403964, 40.29829778978902, 42.769120354806226, 39.78767579601657, 41.57477432681669, 44.84521127516224, 41.2039573730961, 45.75005500547348, 41.376318085578184, 38.20407767449656, 42.74150294642295, 40.59274619625461, 42.65774465376332, 42.930270933335834, 43.856491581086196, 42.83594969780215, 45.71379269323042, 49.034875285240915, 46.23053358447167, 44.70842646014306, 41.8739099656382, 40.525822716374556, 42.828665856392156, 43.2756160151574, 43.61564628539547, 41.74010615194998, 47.64041777580015, 46.742245997152025, 49.623324947972456, 53.74171949202015, 52.99272329576554, 52.12511070312993, 55.06400931266047, 52.74932845946282, 46.286509729200795, 52.81300813921037, 51.51925356157365, 51.90068444898052, 51.86584595711001, 49.231158533403956, 44.68887736720424, 41.335807846438506, 41.74955514169509, 43.58609122614707, 41.31653331941174, 42.52967142289685, 42.47248326578448, 42.69078277772473, 46.41579889482068, 45.64237025476272, 45.325572183055264, 48.03873838916902, 46.4117863101344, 43.07639098936512, 42.84891313122165, 43.143263478432935, 41.96381853472802, 42.71725485401769, 39.048316863275346, 40.750923618193596, 42.2168545569143, 40.94786190217541, 42.03091067652549, 43.11207279082268, 42.12767162630635, 43.88039058254611, 40.1516011453444, 41.96598368306314, 41.89953088760376, 41.511741838147564, 41.826978806526434, 44.5342065441993, 42.53795154633061, 42.45218500014275, 43.8263403215716, 46.066574588898696, 43.73038738004623, 48.103371204868445, 45.20799129239975, 47.108367873776345, 45.860199082282286, 47.82301587443198, 46.22017460484659, 49.333442180387436, 45.61196404118692, 54.95485759550526, 61.77543963155439, 64.91314749563894, 60.63171179063859, 62.62506815694994, 64.11016771870275, 66.87470128459316, 62.23633773865239, 68.65060144855131, 64.83651614958241, 72.75288289593112, 64.93566582279821, 79.14891150689895, 26.075305015810077, 0.6036888675824289, 5.146372260585909, 1.9861184901768163, 0.33970474415729124, 22.15476659036452, 90.08436187621086, 69.96209298410724, 83.96627241565336, 67.45107004719397, 70.26926948178199, 52.290097359688055, 49.50401821444112, 69.96557604882025, 75.46984595637169, 14.646498926224249, 0.4481781977078607, 0.18522201105952266, 0.12133059993145928, 0.1369287476183907, 0.17515985986157773, 0.08395855570392263, 0.18931927910495192], [0.01695561909957999, 0.024378752531183344, 0.05051951877953065, 0.1464071091745169, 0.06048389034526003, 0.03795841175522055, 0.04334761430659602, 0.010644516873834355, 0.029266295811882424, 0.04159853598403354, 31.07380294030713, 58.90382535995976, 45.99101012752902, 32.15912865054223, 23.43868974716433, 28.91239066277781, 44.06784457545127, 62.339331334637066, 56.37905451559252, 59.45911530525454, 6.319726744005758, 0.2251220458457547, 0.47345658644072475, 0.7844328495763964, 12.928462547640647, 60.01187924415835, 58.681713304212025, 62.38825898016653, 57.57232973652502, 59.39139166185933, 58.075099145212484, 59.65163307805216, 52.99932856713572, 56.17136109259821, 54.762324133226954, 54.256934581264375, 53.34228884789252, 51.56235648739723, 45.36638444469821, 40.76861350767074, 37.79250729468561, 38.70839641940209, 39.94005595484088, 38.33930530855733, 37.76780028497019, 36.613819368423954, 35.52224728368944, 36.80195977610927, 36.25844478607178, 35.29156877148536, 36.294711020685014, 36.52802144327472, 36.59938896856001, 35.49239412430794, 35.203997935018236, 37.726772292967766, 36.441592016527736, 38.42487573623657, 37.36785188797982, 38.95982426981772, 36.692655086517334, 39.30827586881576, 37.51375621364963, 36.48608346139231, 37.268549242327296, 36.7277838337806, 38.32125456102433, 38.22522709446569, 38.21474259899509, 38.05849106081071, 40.3710263775241, 42.5374573276889, 43.311650829930464, 42.75088133350496, 41.12815364714592, 40.34129088924777, 38.060495391968765, 37.89258264726208, 38.14952142776982, 37.73951215128745, 36.718111268935665, 40.225349549324285, 42.70806866307413, 45.88737718520626, 43.44934563482962, 52.18227532602126, 55.16114680997787, 49.379047578380955, 47.78101513462682, 45.92642438027167, 52.77631044387818, 47.61261993838895, 46.233895055709354, 46.38126634782361, 43.80715208668863, 41.97597395989203, 38.44245187697872, 39.58650527461883, 38.97987150376843, 36.86916566664173, 40.83792963335591, 38.115710596884455, 38.67794313738423, 40.83324240099999, 43.858794012377345, 42.39034098963584, 43.61290454864503, 43.915095713830766, 38.87208477143319, 38.048410569467855, 38.943668027077955, 39.12395584967829, 38.229439720030754, 38.905550433743386, 38.82907598249374, 37.9526262898599, 38.60518317068777, 37.85418264327511, 36.910852616833104, 39.10957251825641, 38.768487130441976, 38.42151034262873, 38.87648174839635, 36.25422823813654, 37.44534223310409, 36.12343288237049, 38.7974302999435, 37.21152190239199, 37.22329685764928, 37.56158167316068, 38.89381862455799, 38.44941016166441, 41.48730154960386, 40.51066275565855, 42.849740751328014, 39.68474103558449, 41.41043093896682, 40.56596425271804, 43.863304738075506, 41.32626079743908, 48.74842459155668, 54.21903664065946, 57.5622021767401, 55.44423603242444, 61.00061462771509, 57.02996792331819, 61.995198265198745, 59.98025709582914, 63.93346102006974, 57.461773810848115, 66.47780449159684, 61.0628116515375, 74.7936293386644, 18.879883635428644, 0.26751318405712804, 0.207124893823939, 0.057007195653333786, 0.1266276229533457, 20.58624605978689, 71.62902970467844, 58.20349793280325, 69.33357238769531, 53.52012911150533, 36.46081947511242, 29.269749964437178, 32.25467562675476, 57.29306482499646, 54.02219249356178, 4.00884495146813, 0.11578334961086513, 0.019844034874451258, 0.03279785580572582, 0.06418643158770378, 0.06495919979868398, 0.0798549750939973, 0.025752890186624664, 0.030213812508830623, 0.06761944011574791, 0.05597403415689065, 0.1414952751609587, 0.11795909294197637, 0.04348963551643876, 0.02723157586109254, 0.04231948983825503, 0.03420823899608466, 0.06272241458176606, 35.356127062151515, 68.73439896491267, 53.3469250894362, 39.59314976969073, 24.735558686717866, 38.21980637888755, 51.22284004765173, 66.05800890153455, 61.59025669097901, 63.94325910076019, 7.808101975148725, 0.5197206668315396, 0.640835429151212, 0.7227214029239071, 14.358366516328628, 64.34892239109163, 59.439766253194506, 63.0409021531382, 59.753026347006525, 61.930894928593794, 58.977644366602746, 60.89747590403403, 53.73479258629584, 56.70830611259707, 57.093635835955226, 56.84454964053247, 55.245179668549575, 53.59131228539252, 47.39532455321282, 43.703315181116906, 41.511490806456536, 38.850566648667865, 41.408909059339955, 41.64274507953275, 38.19899036038307, 39.488477399272305, 38.10779133150655, 38.615899085998535, 38.08947386280183, 37.100440379112, 38.27044417781215, 37.573340938937285, 38.18921973628383, 37.514489696871856, 36.28508552428215, 39.77926231199696, 38.27788883639921, 39.97183892034715, 38.212055775427054, 41.991177066679924, 39.034894512545684, 39.7447415321104, 39.042558823862386, 38.836842275434925, 39.59125134252733, 38.03598842313213, 38.9125479421308, 40.54672502702282, 42.051593334444114, 40.658375293977805, 41.50703891631096, 44.55444205191828, 46.07697671459567, 44.16698640392673, 42.79280754827684, 41.238666426750925, 40.98116674730855, 40.140057609927275, 41.50821954973283, 38.4827071620572, 39.02668106940485, 40.13251489208591, 44.17597255399151, 47.069269687898704, 47.02970473997055, 56.851707966096946, 53.673913478851325, 50.37594933663645, 49.5469367888666, 47.37735225308327, 52.33398083717593, 47.56192330391177, 48.49718893727949, 46.68274756400816, 46.22816839525777, 44.58584846988801, 40.167337694475734, 40.11862185693557, 42.14573414094987, 40.68414918838009, 40.58513287575015, 40.3889359197309, 40.63840650743054, 42.52663943075365, 44.92266239658479, 43.658553092710434, 45.63369789431172, 45.71438889349661, 40.54533650798183, 39.284129758034986, 40.30517762707126, 41.61914417820592, 39.66278752973003, 38.7783871927569, 39.893960260575824, 40.375286071531235, 39.743474606544744, 40.13626860034081, 38.2646704489185, 42.58110546296643, 41.85711829893051, 39.46684552777199, 39.68597265981859, 39.74281957072597, 41.286087882134225, 38.5748161808137, 40.438608815593106, 40.75829767411755, 40.21373148887388, 38.78647904242239, 40.17439011604556, 39.94976774338753, 41.54525064652966, 42.374208281117106, 44.03186075149044, 42.64542841142224, 42.86908980338804, 42.81773421072191, 45.60018908592963, 43.246719914097945, 52.053802013397224, 56.71047910567253, 59.092138351932654, 57.88762554045647, 62.399524027301425, 59.407869538953236, 63.93093501367877, 62.25339220416162, 66.02012665041032, 59.792567760713645, 68.60729063710859, 62.50389437521658, 76.9814960418209, 20.30493563221347, 0.26644259150470456, 1.0012061917974104, 0.2560870592752772, 0.1689754005882048, 22.226536158592474, 78.80645721189438, 63.873444834063136, 73.71300066671064, 59.95831143471503, 48.43641573382963, 34.63811366788803, 39.50926203881541, 63.545821020680094, 63.527542775677105, 5.705828743596231, 0.0509753908901926, 0.05235322683508839, 0.025336906358960177, 0.0840833820703049, 0.07055810742801236, 0.032507837900230964, 0.01825476823855312, 0.11083056053687489, 0.13087256210705928, 0.22412253093094597, 0.2353769294436901, 0.3023513694924693, 0.18178431407338191, 0.09923175187601198, 0.22646993158325074, 0.10382229627500619, 0.294005423784256, 39.814857821310724, 74.81898353945824, 60.79898126663701, 47.043648765933135, 32.308802373947636, 39.71056984316918, 57.19422894139444, 72.97295924155944, 65.19691136575514, 70.16704467035109, 9.004241997195829, 0.6503252360609271, 2.701182629792921, 1.6896461407023093, 17.645735356115527, 67.29919587412189, 62.4199870324904, 65.09647515512282, 61.163871519027225, 61.948545594369214, 61.960469599693056, 60.876675575010246, 55.77428779294414, 59.808257241402906, 58.46981902276316, 58.95212150389149, 57.05467493303361, 56.16911749685965, 49.72289039242653, 46.824737364246005, 43.7617467295739, 42.06484310088619, 45.555964362236764, 44.302680800038004, 41.82851245326381, 41.30538202101185, 40.11280890434019, 42.38279042705413, 40.448626549013206, 39.571678715367476, 41.01582873252131, 41.72601307592085, 39.72502377725417, 40.690985879590436, 40.420636515463556, 44.57768601755942, 40.94928180017779, 43.106765823979536, 41.0030927965718, 44.114038328970636, 40.60073998666579, 41.780624235830004, 41.62935018539429, 40.16457242350425, 42.029757499694824, 40.55255759146906, 40.502417933556345, 41.19436717802479, 43.342688545104, 43.154940374435924, 43.440277114991225, 46.235699345988614, 48.81501074760191, 45.9209369844006, 43.92959671635782, 44.136646870643865, 42.066623856944425, 42.59929741582563, 43.12287892064741, 40.503735849934245, 41.06053198537519, 42.788692981966086, 45.45403372856879, 52.201188994992165, 53.491299690738806, 55.36446679023005, 54.49744255312028, 53.39491136612431, 50.168777588875066, 50.708938952415224, 56.59324730596235, 50.25310070283952, 49.8960316565729, 51.392517858935946, 48.59146310437111, 47.571501731872566, 43.032656561943796, 42.04668252698837, 44.93309197887298, 40.569074692264685, 45.91622621782365, 42.53961463128367, 43.20771586510443, 44.27845624185378, 46.35967762239518, 46.329079212680945, 46.53291694579586, 47.005154625062026, 42.5452353877406, 40.87044608208441, 43.14580909667477, 45.072787192560014, 41.77644691159649, 41.588867402845814, 41.67088024077877, 43.448196380369126, 42.15664225239908, 42.02293649796517, 40.53380081730504, 44.36962389176892, 43.978900909423835, 41.744091280045055, 42.94539951509045, 41.01414211334721, 43.84496765751993, 40.7331278247218, 44.13127714587797, 44.21566301776517, 42.434734375246116, 43.87344014260077, 43.24407231423163, 43.08480839575491, 44.15600376744425, 45.493049544672814, 48.45913802423785, 43.612182832533314, 44.578909797053186, 44.269909397248306, 48.65437399956488, 44.404050534771336, 54.324822964206824, 58.74130587424002, 63.459242543866566, 60.202882982069454, 65.46051033081548, 63.2248495471093, 66.92342496687367, 66.53944061648461, 70.15939604851508, 63.15629828360773, 71.49384129431941, 66.47570994592482, 77.25049218823834, 22.889659904664565, 0.5374158882806378, 2.2833570501496716, 2.2311794757843018, 0.2689972802275612, 26.25353555525503, 85.97326294068368, 68.75857645465483, 80.43667270291238, 67.63363284449424, 50.2314256852673, 38.68475629437355, 51.524391866499386, 71.44223074759208, 76.46521014551963, 10.56456575470586, 0.19223884018438478, 0.19808409104664482, 0.11352022629111044, 0.1602682750672102, 0.23382432969106784, 0.18408928877644, 0.1818057338917448], [0.1203308628511525, 0.15338148170661542, 0.05616235005999765, 0.032246241856726914, 0.03389855561357352, 0.05057898252421329, 0.04158942336817423, 0.04719163283645626, 0.007846974927346193, 0.05953354295343161, 21.76599890955033, 63.46755012389153, 45.62108355183756, 39.6875729868489, 25.034690403169204, 28.88504978149168, 44.586201483203524, 63.820692877615656, 52.510687535808934, 63.738687884423044, 14.228622355768758, 0.32003059502570863, 0.3237702072628083, 0.3105649964944009, 25.37090812959979, 69.58079153491606, 57.083747540750814, 59.11735919214065, 57.860588642858694, 57.36497363736553, 55.32317599942608, 60.97856306260633, 58.42067956924439, 56.60602638798376, 55.042848125580825, 54.44121145432996, 52.9850785962997, 48.77794434947353, 42.84825025066253, 38.96564506715344, 37.57299969273229, 39.86719792889011, 40.68966796321254, 38.6310080559023, 34.70794362406577, 37.55862028368058, 36.746760260674264, 37.109191186966434, 39.32432620756088, 36.97099431868523, 35.41577454536192, 36.141205141621256, 34.964784345319195, 35.84972204700593, 35.53521856184929, 35.23404721290835, 36.805321247346946, 36.162691885425204, 38.14554806678526, 39.48093075906077, 37.39491231979863, 38.268255495256, 36.5926032681619, 36.6256296250128, 36.55527799360214, 38.04292709596696, 38.69481717386554, 39.71068359190418, 39.13942175526773, 37.4664524293715, 38.626505174944484, 42.90984715184858, 41.488956789816584, 42.790924810594134, 43.32667350769044, 40.020699885583696, 38.74606686253702, 38.5251275954708, 39.55822498567643, 38.167854585955226, 38.48275423049927, 36.20824629260648, 40.06862732671922, 43.88044549572853, 44.83714688208796, 40.3990242558141, 47.566367349317, 54.887600714160556, 44.56934705857308, 43.569911449186264, 48.767930538423606, 47.624347825204175, 46.58242117974066, 44.93621810790032, 44.21540021896363, 41.33289352540047, 38.87630131936843, 39.04244507512739, 40.17881454959993, 40.33284602626678, 37.160856646876184, 39.85934926617531, 41.0952998745826, 40.58415620557724, 40.876682650658395, 45.32295596215033, 45.078027479110226, 43.054496319063254, 39.184811422901774, 40.07176522285708, 39.53766392123315, 38.63975886375674, 37.89395939919257, 36.61346635510845, 37.66022928299443, 37.34456869863695, 36.81559785719841, 39.0862657946925, 40.4943339286312, 39.143018568715746, 38.081574209274784, 37.37939542339694, 40.02896824190694, 37.050571364741174, 37.786243269520426, 36.47568918043567, 39.41765508344097, 36.7099880403088, 38.304529574609575, 37.69306736607706, 38.074580623257546, 38.39665036047659, 40.13080081632061, 40.42322920214745, 41.02922754902994, 40.96575967727169, 41.44453202524493, 41.55212656144173, 46.795092090483635, 50.027493815268244, 52.7652415152519, 55.89046447507797, 55.39179394322058, 54.61284260595999, 58.98357106793312, 57.47365467010006, 61.960147965338926, 56.595432066148334, 61.39848416851413, 57.543798415891594, 66.4069978652462, 58.62141862992318, 71.62912384156259, 17.19044427717886, 0.07227939208068195, 1.0871892037891573, 0.3909782734849761, 0.08486865283620935, 22.38833392820051, 73.16916404231903, 57.9270806620198, 70.08293336437595, 48.320054700297696, 36.53086908401982, 32.968211635466545, 38.82927602337253, 58.194582385401574, 58.39707474554739, 5.9328079704315435, 0.1333885480679812, 0.13311569819286947, 0.12064845992192147, 0.08370462820054063, 0.0317661632828775, 0.015138322562580148, 0.019321022818105358, 0.059737751350527814, 0.04185036823694264, 0.01509802346493328, 0.024414886983351845, 0.005636715983611442, 0.05415996476527184, 0.042905190869444804, 0.07543754358325275, 0.1098372815777698, 0.036825559237190796, 25.437119699293568, 70.45304821383569, 50.35117172425794, 45.37339372019614, 24.089157965875444, 29.392482888314035, 51.714156135436035, 67.46468851643225, 58.24323938738916, 68.67681072604272, 14.3676507665265, 0.3537630397946604, 0.42643931904627436, 0.5077616972548347, 26.763212257815947, 70.9257173538208, 59.9476465102165, 61.273944993172925, 60.654771404881636, 59.6976032564717, 57.963778357351984, 61.74591595126737, 59.84721814432452, 58.074275447476296, 56.73589214201897, 57.61287919936642, 54.064495255870206, 52.280667981793805, 44.06817797691592, 41.07173035221715, 39.998020741247366, 42.01595860142862, 42.50867889773461, 39.97057591715167, 37.954685534200365, 38.7043720676053, 39.03019159070907, 39.05176070428664, 41.04363441467285, 38.10882683723204, 36.85872431724302, 38.97199930683259, 38.87549331111293, 38.644493164554724, 37.52153035133116, 36.25645614439441, 37.443730138963275, 38.7745903384301, 39.76901315873669, 40.37986347752233, 39.15188704767535, 38.79223708183535, 39.4782204012717, 38.75038931446691, 37.841689894276286, 38.66680360609485, 40.28973525570285, 41.20876227655719, 40.42851655713974, 39.13557783249886, 41.11742988709481, 45.710980353816865, 43.89934739758892, 45.044440223324685, 45.32242644217707, 41.85558465219314, 40.70997799596479, 39.75405323889948, 41.67097830003308, 40.03462822206559, 40.10372861739128, 39.02718313278691, 42.7675514067373, 45.137145442347375, 46.94704863332933, 45.297185990118216, 52.02947547358852, 54.09785893655593, 46.31045972147296, 45.77823723516157, 49.01975062585647, 48.86601332695254, 48.71755553830055, 47.22039076589769, 46.34948338231733, 43.208551329951135, 39.99301971927766, 40.25667751989057, 41.62425502654045, 40.556868276288434, 38.61454586828909, 40.13823763016732, 42.84773642016996, 43.274317710630356, 44.12984548076507, 46.580954213296216, 46.48185945326283, 45.3228186791943, 40.31310865955968, 42.887928947325676, 41.19763451237833, 41.781408709864465, 40.36450739829771, 38.83583422630064, 38.74322706653226, 38.19406386344664, 39.28037997215025, 41.12065015300628, 42.605851696383574, 41.34674733684909, 40.35192051241475, 40.702462734714636, 42.17580695306101, 39.98156247600433, 40.25359061456496, 39.06141757965088, 39.695868799763346, 38.94749233799596, 42.02500358704598, 41.00956862972629, 41.18312566511093, 40.28942538845924, 43.0653142159985, 42.772066054805634, 43.498469398867705, 43.139552916249926, 44.125699535492934, 42.915832688731534, 49.36916320554672, 51.38856803217242, 56.36443976433047, 56.618609351496545, 59.81853777362455, 57.385891637494495, 62.315695131978686, 59.87531015949865, 62.962144882448264, 59.09603326551376, 64.79245616543677, 60.563886165618904, 70.5541120036956, 61.13670126084359, 74.04309165093207, 18.363236881071522, 0.1160446085756825, 1.6681591517502263, 0.7477095362640197, 0.07737317197625676, 24.5271651206478, 77.64800087098153, 62.50592616296584, 72.90945606846964, 53.87165192634829, 40.57329908494027, 33.92543077468872, 45.63762810922439, 63.543094973410334, 68.22875053651872, 8.408348656469776, 0.16731533402156445, 0.12485430560885899, 0.10663358614810052, 0.03969299952469526, 0.04945224721825892, 0.05158572930902724, 0.054278551345510836, 0.16924524739865335, 0.24745455071810754, 0.1275908329614228, 0.1499768797188036, 0.22743495721970836, 0.14471567896825654, 0.1755871683839829, 0.2083518602434666, 0.2260972144863298, 0.15246865730131828, 29.340038837925082, 82.25603272837978, 57.64456802798856, 53.19755731090423, 35.11593680227957, 39.31595979198333, 58.875058697115996, 73.647748116524, 61.78157029613372, 74.76356044892343, 17.037691493188184, 0.502747621146902, 0.8154924442210506, 0.6556190874788069, 30.93964219093323, 72.12296593573787, 62.45257800625217, 63.534034298312285, 63.47090767275903, 61.34045662418489, 58.93802058312201, 64.96463252652076, 62.15926708713655, 60.68600131619362, 59.1465102472613, 59.60202686248287, 57.401463447078584, 54.613850655094275, 46.40496138603457, 41.54954171949818, 41.46764655267039, 44.78981956358879, 45.68107228125296, 42.736654896889966, 40.43929523037326, 41.90132341077251, 40.443817723181944, 41.99985334950109, 44.98603220908873, 42.86970169313493, 40.771872997283936, 41.560747931080485, 41.73819595767606, 40.93900126795615, 39.799333080168694, 37.866753839677386, 41.603105606571326, 40.578543293860655, 41.9215432290108, 44.00438454843337, 41.480111845078014, 41.96424999544698, 41.137990951538086, 41.25739182195356, 39.58975299712151, 40.76900966705815, 43.03951678737518, 43.86677603567801, 43.89386000171785, 40.5290469046562, 42.052362118997884, 47.84068615205827, 45.70012715555007, 46.49494840252785, 47.179464755519746, 43.70915951267366, 42.83991521404636, 42.04127750089092, 45.564464138400176, 42.01578601714104, 42.722769706479966, 40.28007838033861, 43.61785457980248, 48.56623834179294, 48.238030095254224, 48.82996282269878, 52.88403834066084, 53.66768083264751, 49.09838238070088, 45.21403174246512, 51.24716266509026, 52.29937768751576, 51.59202529538063, 49.2802313066298, 50.72788400034751, 45.69845230348649, 41.198854369501916, 43.17782740439139, 45.70941140574794, 45.00629909576909, 39.35073160356091, 41.9670231111588, 44.168810306056855, 45.34031245016283, 45.77487968629407, 48.32635794916461, 49.84256975112423, 48.52999564140074, 42.64971163965041, 44.806168002467004, 44.23571025171588, 45.22700694299514, 42.917558531607355, 40.6342331055672, 39.40333450994184, 39.795371486294655, 40.44857163583079, 43.177117455390196, 44.200189267435384, 43.34730125242665, 41.28226357121622, 42.197995801125806, 46.93904307580764, 41.81671396378548, 44.107197715390114, 41.31454860010455, 44.04321993550947, 42.370823275658395, 44.48661642689859, 43.9877890002343, 42.53267988081902, 41.8173062416815, 45.64461777287145, 44.84863942669284, 46.07737287398308, 46.43120988722771, 47.26624719558224, 46.838850052126, 52.88130444865073, 56.42478935180172, 58.292061128923976, 59.546984241854766, 63.158235934472856, 59.87576123206847, 62.561188436323604, 62.28397100202499, 65.01023792451429, 61.701247999745036, 67.14357975990542, 62.471354392267045, 71.41205987622662, 63.62668068178239, 74.93407372505435, 21.264337570436542, 0.24551624101736855, 2.655964565853919, 1.9972246813197292, 0.1604949758057633, 26.98789542721164, 87.1880288277903, 67.31603068690147, 80.76157046902566, 60.35414918776482, 52.1994278507848, 42.58309018227362, 56.735221416719504, 71.30665010021579, 79.68848059254309, 12.136228103791515, 0.28570817062451, 0.19242391170513248, 0.35131109878420835, 0.1164435412013723, 0.2014963998789749, 0.19492299776644478, 0.13410206703889754], [0.035540427592012196, 0.11778391161633116, 0.053700534176201596, 0.03230409298632895, 0.012643527551253718, 0.022624579723924402, 0.029285172218336698, 0.04779393882340482, 0.07374163176263533, 0.08694812955875551, 13.792658755856177, 63.049162664721095, 50.932357157430346, 38.507167062451764, 20.4654449032199, 38.3004738438514, 44.389396559807565, 63.84826713992704, 54.5712144913212, 61.61026077885782, 25.763172603422596, 0.20742366811440838, 0.203905746400837, 0.033417973336913896, 32.86884034833601, 65.37843473495977, 56.47823949013987, 54.96906834263956, 55.209203689329094, 54.35858672665012, 54.77750762816399, 54.62356244364093, 55.525099615896906, 56.08950907184232, 55.66362988564276, 53.925239347642474, 50.68097637545679, 45.02087854569958, 40.22719698567545, 39.482417337356075, 38.78176435347527, 39.373163638576386, 37.01227726474885, 37.870519315042806, 37.85509655552526, 38.21555845199093, 38.78346273975988, 37.251106462171, 36.084213103017504, 37.2603593334075, 37.71788812452747, 35.947259626080914, 35.92994236177014, 35.848490422771825, 35.34759198465655, 36.995140429466005, 36.84631786038799, 36.68701079583938, 38.4576432166561, 38.207160657452, 36.62342917534613, 38.79193113696191, 36.61134043047505, 39.36980216733871, 38.087132207808956, 38.38351042039933, 38.95717274758124, 40.143160204733576, 39.34434598492038, 36.05300672592656, 39.24181522861604, 44.40974973863171, 43.61800362986904, 42.12302754002233, 43.18796673128682, 42.189370509116884, 38.43027683996385, 39.479330432030466, 40.26957035064697, 39.036945912145804, 36.57097924140192, 37.95534057001914, 39.072298234508885, 42.6733596094193, 42.956193877804665, 47.78203102850145, 37.5130384199081, 47.760932599344564, 50.080390899412095, 43.11383393503005, 51.324182325793856, 44.52527922968711, 46.59948741236041, 43.51200942070254, 44.064157547489295, 40.02751696494318, 39.65574295290055, 37.989645619546216, 41.01930003012381, 37.01297152426935, 39.56949395518149, 38.60786607188564, 41.681199996702134, 40.90202508434173, 42.59104867135325, 43.78655964328397, 44.238855992594075, 42.65253574617448, 38.892265365969756, 39.13751940573416, 41.46241803323069, 39.50943070073282, 38.12228056692308, 38.28815760151033, 37.63669506196053, 37.04364838138704, 39.236688690800825, 37.682112186185776, 38.61188257894209, 38.96733168632754, 38.199896427892874, 39.071835394828554, 38.21224404919533, 38.685250513015255, 39.31685409238262, 35.849522006127145, 38.0845199092742, 38.647615371211884, 37.97282649624733, 38.24277577861663, 39.20464684886318, 38.32904831055672, 39.98871295682846, 38.346620528928696, 41.77059081292922, 41.449125120716715, 40.81012787357454, 42.535127439806544, 51.23831379798151, 52.26172293386152, 57.31124501074515, 56.050814890092425, 55.40138021592171, 57.141684870566095, 63.26699149224066, 55.09514116471814, 62.27671853957638, 53.12871186963974, 60.992738508409076, 56.799583588877034, 66.71863802017705, 60.441955366442286, 70.71064595253237, 15.56018760127406, 0.08901627584090156, 0.9831433094316914, 0.43430370188528494, 0.11259087736928657, 25.769852399826053, 71.50379626981675, 60.16122348846928, 69.54647079590829, 52.018500681846376, 37.32958916694888, 37.994301472940755, 49.311068980924546, 61.52905987155054, 52.09452798289638, 3.061883300542832, 0.12773378496809354, 0.029141528817314296, 0.027735981556977478, 0.009470446910258503, 0.046322751234495835, 0.030021846196764422, 0.06180877046238992, 0.029234288658405987, 0.016297325491905212, 0.017913148565698537, 0.02500425566047911, 0.04230808661950212, 0.0634293835009298, 0.019501453761251706, 0.07357996422797441, 0.055867459835304376, 0.051674181820764664, 17.592428384288667, 70.46388180025163, 57.67105971613238, 44.33583659510459, 22.110102561212358, 38.2356684438644, 49.98850545575542, 69.07691601783999, 58.55621707054877, 68.29579168750395, 27.14565903909745, 0.2162120908859276, 0.09942784740199005, 0.03164527460842604, 38.74387817998087, 66.75645751337852, 60.08385473682035, 57.18612924698861, 59.19642240770402, 56.74971065213604, 56.9851234651381, 57.15129467748827, 59.204486800778305, 58.733845526172274, 58.781306205257295, 56.949461275531405, 52.62895876361478, 45.98862532646426, 41.652817726135254, 42.057496501553445, 41.58284264226114, 41.009345054626465, 38.6265443986462, 40.60337974179176, 40.52799570945002, 39.41604691167032, 39.657610001102576, 40.59597038453625, 37.3982737910363, 39.441267751878314, 39.69258185355894, 38.408821475121286, 37.17658535126717, 36.7679371372346, 37.99673334244759, 38.61068233366936, 38.9333757277458, 38.62974505270682, 38.843239661185976, 38.60164127042217, 39.18280316937355, 40.74513419981926, 39.41713733057822, 40.566721270161295, 40.568400044595045, 38.93951815943564, 39.43650599448912, 41.2307353942625, 42.126204659861905, 39.29480644964403, 40.08925899382561, 45.37150313777309, 45.843529009049945, 45.41289591020154, 47.18300273341518, 43.7486695474194, 40.998146687784505, 41.218058293865575, 40.94251178926037, 40.80859422683716, 39.00974427500079, 41.05318930841262, 43.0502248579456, 44.25312557528096, 44.790262791418264, 48.17462498141874, 41.29987893566009, 53.3630342637339, 50.1758143209642, 45.77300087098153, 52.97156995342624, 46.62406106148997, 48.5123057519236, 46.258460860098566, 45.143566362319454, 43.394067671991166, 40.91622014199534, 40.65172295416556, 42.326057264881754, 40.825354514583466, 41.29084179478307, 40.28679347807362, 42.801605424573346, 43.35622072219849, 43.66375023318876, 48.02874026759979, 47.305074737918, 42.985164503897394, 40.613036617156, 40.074805059740626, 42.233654068362334, 40.79335974108788, 39.72289000788043, 39.487477194878366, 38.85255136797505, 39.406507707411244, 41.23177089998799, 40.0573818914352, 41.30210684191796, 41.6487031598245, 41.43326697811004, 39.838552859521684, 41.05203613158196, 39.2069100564526, 40.40758678990026, 37.91493623487411, 41.63782250496649, 40.41076783211001, 39.723541121329035, 39.83894901890909, 43.05851674848988, 39.38382071833457, 42.02016730462351, 41.421013493691724, 44.473919714650805, 42.821695804595954, 42.79736926478725, 45.09606253716254, 51.92678390010711, 53.53602647781373, 60.54002246549053, 59.24526768345987, 57.655028989238126, 58.385339013991825, 62.90909874823786, 56.92294605316655, 64.234730428265, 56.90305179165256, 63.74794467802971, 57.59636602094097, 69.81974232581355, 61.294929673594815, 71.79511070251465, 17.53028235127849, 0.12908013086886178, 2.215615265792416, 0.8992764774349429, 0.06628540524792287, 27.405645501229074, 78.91402429149997, 63.77572682596023, 76.36052208562052, 55.27538584124658, 44.46757724208217, 40.168941943876206, 53.65342301707114, 68.0326634068643, 60.53506066722255, 4.648060135303005, 0.10284161180137627, 0.1432273386707229, 0.020389202193567352, 0.045135207699551705, 0.0681039677452176, 0.05661398570443835, 0.04195351431506776, 0.23425309378052914, 0.2015339841525401, 0.2136255175836625, 0.10010829435721522, 0.21100986358379165, 0.1698302474593924, 0.1298908817191278, 0.13714714396384456, 0.17219398110624284, 0.18119750604514154, 20.365096945916456, 81.93918366586009, 64.73415797756564, 53.65759641893449, 31.962966995854533, 51.16420845831595, 57.84486778320805, 75.2583360671997, 63.67574561026789, 73.89484959263956, 31.680568110558298, 0.30414018479566424, 0.5095058955973195, 0.08512356859301368, 42.710555445763376, 68.06295194933492, 60.491698864967596, 59.986827065867764, 62.18929283080563, 59.04474043077039, 59.57054591947987, 59.33161866280341, 61.81079195391748, 60.0211242706545, 60.598971766810266, 58.001660608476215, 55.07168931345786, 49.043359371923636, 44.438673296282374, 44.181287365574995, 44.41896338616648, 42.7877280789037, 40.695210272266024, 41.359914733517556, 42.756925705940496, 43.43673129235545, 43.4701185072622, 42.76283671779018, 40.753563373319565, 42.996092227197465, 43.90800799092939, 40.66970309903545, 39.433368098351266, 39.22698474699451, 40.55348327082973, 41.760620147951194, 41.86822645125851, 40.3912305062817, 40.70343548251737, 42.155908769176854, 40.66026195403069, 42.594335617557654, 39.57541281177152, 42.81605543628816, 41.69807403318344, 41.764456225979714, 41.55307577502343, 44.04320424602878, 42.46255574687835, 41.052593108146425, 43.94476844418434, 47.35700691899946, 48.12903527290591, 46.86041524333339, 47.94422103512672, 44.58731151396229, 41.165235734754994, 43.79207057337607, 44.394781974054155, 42.55968932182559, 39.73071905874437, 41.81354076631608, 43.71375653051561, 46.452931973241995, 47.9902422043585, 49.16765928268433, 45.3566530443007, 54.45466126165083, 49.05871937351842, 49.52672873773883, 55.23998252807125, 48.414022922515876, 51.233673634067664, 48.76124289727981, 48.60394408625942, 45.56825314798663, 43.36355163205055, 43.45981051844936, 45.427102734965665, 42.26297378540039, 44.19576091151084, 41.53686461910125, 44.89899089259487, 44.496845968307994, 44.97684209577499, 49.68484340175506, 48.465033346606845, 44.721303601418775, 43.46041848582607, 42.50958888761459, 45.88190547881588, 44.69762033031833, 43.20731578334686, 41.61486487234793, 41.439013250412486, 42.25895335597377, 43.056547718663374, 41.74157311839443, 42.82632027902911, 44.078403595955145, 42.24473084172895, 44.07588935667469, 43.54959357169367, 43.484674422971665, 42.78663765999579, 39.96669277068108, 43.81457713342483, 42.94229692028415, 43.59337898992723, 42.79567872324298, 46.03079080581666, 41.41345900873984, 45.713886830114554, 44.49182533448742, 46.53503894805909, 46.48119265033353, 44.29246694810929, 47.38311029249623, 56.5636137993105, 54.98145911001391, 62.92048931121827, 61.76317830239574, 61.99693587518508, 61.614583230787716, 65.79909324645996, 59.05691546778525, 66.40174188921529, 58.22588289937666, 67.09322437163323, 61.228963252036806, 71.824277447116, 64.43583819173998, 73.23604045375701, 20.46134602638983, 0.2728120303682743, 3.6229580063973708, 1.845490487833177, 0.2135714011326913, 30.326887561428933, 86.56517997864755, 71.48938548180365, 82.36666710146012, 62.83134952668221, 51.808649955257295, 50.070486914727, 67.16872215270996, 75.71911258082237, 73.6669049724456, 7.191669143015339, 0.2225297881710914, 0.3611098842755441, 0.21440855137282805, 0.1742212336149908, 0.16385886788127885, 0.24681676719938558, 0.1850085942855766], [0.026764101348817352, 0.03283392322520095, 0.02283416031258962, 0.0583732798094711, 0.02571425062694377, 0.046958535263735446, 0.08386839481611406, 0.06658145226538181, 0.058828201971106955, 0.13573340530837738, 6.78371322731818, 53.72412766179731, 47.33324520049557, 47.663838248099054, 41.1719939785619, 31.793189164130922, 40.34674690615746, 62.03795994481733, 57.08351612091065, 59.865304193189075, 34.38399507153419, 0.04289727718118699, 0.056820706869926185, 0.2089505426345333, 33.958496355241344, 64.29373464276715, 57.912732631929465, 56.49868680584816, 53.905019529404186, 53.99419069290162, 53.202981948852546, 55.521357674752515, 53.611288916680124, 54.20054658766716, 52.16081211643835, 48.84282819686398, 42.71632132991668, 39.30854258998748, 39.99018776801325, 38.07358826360395, 38.241759884742, 35.77493813730056, 39.606462294055575, 40.885562896728516, 39.28667145390665, 42.441406326909224, 40.62105786415839, 40.38946543970416, 39.57846833813576, 36.713702524861986, 38.14410463456185, 37.83788519520914, 35.70691247140208, 37.022506806158255, 34.88784705438922, 36.56659795391944, 36.64310770650064, 37.66306515662901, 37.57955397329023, 37.781254014661236, 37.72736457086379, 37.379728824861594, 37.71727231241042, 35.47164870846656, 36.99086896834835, 37.76035170401297, 37.160589925704464, 38.27473132841049, 38.76503936706051, 37.99026535403344, 37.43250823790027, 42.89331436157227, 43.15172010852445, 43.300295568281605, 43.20456227948589, 42.23623106556554, 38.50232293528896, 40.28709942294706, 40.054114557081654, 38.316382977270315, 38.35930939643614, 39.07187461853027, 38.78427074801537, 43.49737113521945, 45.08101240281136, 42.56667898547265, 46.058235629912346, 39.25778711995771, 45.75137684422155, 47.00993207193191, 47.048500737836285, 46.719778660805, 44.184927325094904, 42.81600444547592, 42.44907848296627, 40.71427299130348, 37.5400713951357, 38.589191667495236, 38.36135295129592, 38.79462580527029, 38.50043627523607, 40.14985961298789, 42.506015608387614, 42.228700114834695, 43.654022755161414, 44.05052731114049, 46.52340127575783, 42.5211206559212, 39.932026863098145, 39.67462916528025, 39.613008729873165, 38.43117114036314, 40.482539361523045, 39.29330810423821, 38.79492390540339, 36.64987771741806, 38.68712540595762, 37.6925378461038, 37.600746539331254, 39.070925404948575, 37.167003000936205, 37.58950894878757, 38.021452119273526, 36.462255062595496, 39.04701855874831, 37.06808474756057, 37.756095932376006, 37.65677367487262, 38.837716963983354, 37.00183591535015, 40.07351067758376, 38.95258357447963, 40.67770865655715, 40.36158523251934, 41.92108431170064, 40.30632295916158, 44.03641070089033, 40.82402483109505, 48.564285001447125, 52.96887136274769, 58.661728828184074, 53.068009268852975, 55.339724479183076, 55.949907995039425, 60.54228567307996, 55.256931089585834, 56.635828556553015, 52.07131147384644, 60.916617070474935, 60.210445311761674, 65.22110454497799, 57.30595765575286, 77.73419103314801, 21.31675808660446, 0.10749655355128551, 1.3145719444559467, 0.5975159762367126, 0.10955484028184607, 26.99405747075235, 71.79989599412488, 60.91815856195266, 68.254410682186, 49.544100915232015, 35.83388351625012, 47.98056179477323, 49.62827890150009, 59.014444043559415, 45.878489094395796, 1.3077546199483256, 0.08439600723044527, 0.030216218024912863, 0.06403903627107221, 0.03655681176291358, 0.03333179227587196, 0.039834423185957056, 0.08563960541880901, 0.04088295240616126, 0.06612058143101393, 0.05178151073895636, 0.02790218624736994, 0.07532533468498338, 0.12048682303077753, 0.030443748053643974, 0.056122547961891665, 0.17919112177145097, 0.13829043826028226, 8.40233370181053, 63.75271820252942, 54.06510714561709, 53.75799732823526, 37.853778639147365, 33.13364151985415, 47.65826456008419, 67.71079371052404, 60.62946427252985, 64.57375264936879, 37.968343227140366, 0.019437014275500854, 0.15464264629108293, 0.40339021552954957, 37.66095884384648, 65.34603595733643, 61.57381803758683, 58.845821349851555, 56.432355603864124, 56.16451263427735, 54.136113812846524, 57.527646095521995, 57.55855045010967, 55.72303810427266, 54.075277851473906, 51.358075526452836, 45.735044094824026, 41.6390541292006, 41.97517379637688, 40.03241992765858, 40.462256785362, 38.39709358830606, 41.455612720981726, 42.792062297944106, 42.68537775162728, 44.70148386493806, 43.324006295973255, 42.3363652536946, 41.3484182665425, 40.67808128172352, 40.59528789212627, 40.373858328788515, 37.39294328997212, 39.0374989663401, 38.050156024194536, 37.50357766305247, 37.9203216491207, 39.55016059260215, 40.58918076176798, 40.28044708313481, 38.68603498704972, 39.380420023395175, 38.6974020158091, 38.47395243183259, 39.917443490797474, 40.347366640644694, 39.21949301996539, 40.294379341986875, 40.29147678805936, 38.73308773963682, 40.36654310841715, 43.82932132290256, 44.74701866026848, 44.875017366101666, 43.78251960200649, 43.36191600368869, 40.86193846118066, 40.443872636364354, 42.32351164663992, 41.035742605886156, 39.827138762320246, 40.83636853002733, 41.26548759398922, 45.29889222114317, 46.595039444585005, 46.687160230452015, 46.986421385119044, 41.834286182157456, 49.47739708808161, 47.94386017707087, 50.51130640891291, 47.64210047260408, 47.221645924352835, 44.54591481916366, 44.74569682152041, 42.36338253944151, 41.54907495744767, 40.95873471229307, 40.14251301365514, 41.08560769788681, 40.029187894636586, 41.625431737592145, 44.74113510501, 44.42986365287535, 45.747540766193026, 45.24574018293812, 49.41809477344636, 43.12300443649293, 42.02237559903053, 41.87757738174931, 41.93180414938158, 39.75885029762022, 41.348273138846125, 40.08819603150891, 39.32383198891917, 39.66812587553455, 38.87496379113967, 38.999542190182595, 39.74375701719715, 40.91467865051762, 38.150725595412716, 39.61146331602527, 41.88877967096145, 38.036588545768495, 41.27069650157806, 39.01465116008636, 41.28253421475811, 40.37130094343617, 41.865680833016675, 39.70621993464809, 41.8060568840273, 41.82246808082827, 42.3277360393155, 42.24113402828094, 42.93762145503875, 41.412643155744, 44.569978560170824, 43.751591713197776, 52.61263778132778, 55.91222578479398, 61.250175429928696, 55.593741093912435, 57.0647358125256, 58.009097422322924, 62.59517969623689, 57.584948001369355, 60.34009533543741, 54.78762734320856, 63.789494345265055, 64.33009893663468, 66.78047810831379, 60.794062614440925, 73.81284067707678, 21.89931634933718, 0.047239543975240765, 1.5655135435442773, 0.3570270033613328, 0.13760485085508517, 29.950632241464433, 78.28675885354319, 64.39570450013684, 72.443604007844, 55.75328742304156, 37.82025806365475, 50.40837949322116, 57.504076573156546, 64.839124525747, 53.92118753925447, 1.6158716284459638, 0.0262725257104443, 0.02011857014299641, 0.053224291787633014, 0.03268139511947671, 0.06327988144250647, 0.055383468467381694, 0.028053195583784295, 0.16078887777703424, 0.1618624580723624, 0.22974370107535394, 0.09731987220866066, 0.11022268509071682, 0.24429215508843624, 0.17699064146126472, 0.17366934387433916, 0.2268138744177357, 0.3094866817757007, 10.092303560626123, 75.55205099044308, 60.65120989276517, 61.88873337161157, 53.37147128197455, 45.45655973495976, 53.969970057087565, 71.85669975896036, 65.99889878303775, 69.76788859213553, 41.82523727416992, 0.17780126973746285, 0.2383351473197822, 0.6683616424279829, 41.50393632150466, 67.53929984185004, 64.44350250305669, 62.713160668649984, 58.20153282534692, 59.20405141768917, 57.264360920075454, 61.41610737769835, 59.68063508310626, 58.74987625306653, 56.0948395729065, 53.78313579866963, 46.53087339093609, 44.148182561320645, 43.765480825977946, 42.940249443054206, 41.655861485388975, 40.35889056421096, 44.835511253726104, 46.02033768930743, 45.229474113833525, 48.412348070452296, 47.28428225363455, 45.74759960174561, 46.03825899862474, 41.607937966623616, 43.08454951932354, 43.445591926574714, 37.761375442627944, 41.07449954555881, 41.17793636937296, 40.4998880047952, 40.83302667064052, 43.137148503334295, 41.94903119917839, 41.95348308932397, 41.697866147564305, 40.590647728212424, 42.90116302428707, 39.97444729651175, 42.27709039565056, 40.892336830016106, 41.49889215346306, 41.94400272061748, 42.51144809107627, 41.705585372063425, 41.98769400196691, 47.919031573880105, 49.165572581752656, 46.25597407740932, 45.82722371624362, 45.04005893584221, 43.18778237988872, 43.95202090663295, 44.355573961811686, 42.97458979391283, 41.57011847342215, 43.3859169867731, 42.51042827483147, 47.296131733925115, 49.99539706014818, 48.65133808505151, 48.61074155376804, 46.2690394924533, 46.47136711305188, 49.399530195420795, 51.497598155852295, 50.52865112981489, 48.69251120475031, 47.109670100673554, 47.86118838094896, 45.11432117031467, 43.31356102420438, 42.188425217905355, 42.413698704011985, 41.55766102575487, 41.833909634620916, 43.42490534628592, 47.16039419174195, 47.02376234915949, 47.669772794169766, 47.69136936433854, 51.830183767503314, 46.31732386927451, 42.945662313892, 44.65629423818281, 43.162804726631414, 42.33200750043316, 44.62716671728319, 42.570624889866004, 41.42658718170659, 40.974310444247344, 40.63395069491479, 42.34219389577066, 41.00991772067162, 42.7709521016767, 40.96777577554026, 40.33954151215092, 43.81868777736541, 41.2243458532518, 44.057171806212395, 42.51091072636266, 42.63709337480607, 42.60856989891299, 42.55438627735261, 42.28600986542241, 45.68714803264987, 43.40789794921876, 45.040690437439956, 45.89242919798821, 45.3253407632151, 45.395582568260934, 47.675338637444284, 45.73618942691434, 53.51005254253265, 57.204599688130045, 63.08445222916142, 57.09758566271875, 58.94314319856706, 59.727248530234064, 65.60734033584595, 59.277729219005955, 61.831058840597834, 57.60661125183106, 65.99769853776502, 66.10694439180436, 70.12385937475389, 60.05928893243114, 74.8580817253359, 23.930072515241562, 0.25557777934497405, 5.231456314363788, 0.8275878693788283, 0.4362147235341611, 33.72402883345081, 84.59541274655251, 71.4568062751524, 78.99188333942045, 63.4023799434785, 49.47592619926699, 55.21546771449428, 69.57230352586316, 72.43387652981666, 68.56012021341633, 2.9424037375757774, 0.14800883048484403, 0.11101498088288693, 0.2021142497899071, 0.16966904723836532, 0.16725947089012594, 0.19108144987014034, 0.12374882541236379], [0.019185999821450923, 0.03931477425559875, 0.022955794007547443, 0.06293320750457145, 0.06642884755086514, 0.07046408545706542, 0.054487141765533924, 0.06423416652626569, 0.1212642030910619, 0.12141775775460467, 2.5046738453449744, 42.874290866236535, 57.485449237208215, 45.167579112514375, 35.3949075360452, 35.39049094723117, 38.953168007635306, 59.94053133072392, 57.764992637019006, 57.14122987562611, 43.46721595333469, 0.5083722693304862, 0.07882677018642426, 0.14768949439448698, 22.496840415462373, 64.6814570119304, 56.41245349760979, 57.99092115894441, 52.320601632518155, 53.50864833401096, 52.85365173893591, 56.18389698766894, 50.342640569133145, 50.08254820300687, 44.36510139896024, 42.36528881134526, 39.21387618587863, 41.155210156594556, 39.726302469930346, 39.52146845479166, 40.47972702210949, 42.99732777380174, 44.1004983071358, 45.402995847886615, 47.81745395352764, 45.100953732767415, 45.443980693817146, 46.399462223052986, 40.068317459475615, 38.68437190209666, 37.26637232688166, 38.22587036317395, 35.94991899305774, 36.57407791383805, 36.632729115024695, 36.90752644692698, 36.89017780365483, 38.17650733455535, 36.71492630435575, 38.329970067547215, 37.51705884933472, 37.76250900760774, 37.707662505488244, 38.04592378677861, 36.14441364042221, 38.7754258032768, 37.05906329616424, 40.10100649249169, 39.164928928498306, 38.233801395662375, 38.475980297211684, 41.530333872764345, 43.089511317591516, 42.91617393493653, 44.86150087848787, 42.99862215595861, 39.6505654242731, 40.062830063604544, 39.09327114782026, 39.835944483357096, 37.596784945457216, 38.92724506316647, 39.670145896173295, 41.5735113236212, 42.348807011881185, 45.66411979736821, 44.58471882727839, 47.70131649509553, 35.956277155107074, 45.25871930583831, 45.3362214180731, 48.55528316190166, 43.15315961837769, 43.40087298424014, 43.64955517553514, 38.653961766150694, 38.7915075209833, 39.65404456661594, 39.97721256748323, 38.21608404959402, 38.63496572740617, 41.84346845073085, 41.400189630446896, 42.32188778538858, 44.13295984268189, 46.00032575668828, 43.23211692994641, 44.2028643238929, 37.500196579963934, 39.446166792223536, 39.14465027470743, 39.72636915022327, 38.4846918813644, 38.149242939487586, 36.69389455549179, 37.877614882684526, 37.32852228226201, 37.09045794702346, 38.72893002725417, 37.01601528352307, 39.08212769416071, 37.44862525693832, 37.23173387588994, 37.53544692070254, 38.09641645800683, 37.722367471264256, 37.575321735874304, 37.238951037007, 37.92545603167626, 37.80638856272544, 39.96940705084032, 40.23126056117397, 38.49729053435787, 41.526180082751864, 40.942719674879505, 39.796563886827045, 40.565724988137525, 41.28706062993696, 43.141996552867276, 50.75318328795895, 54.571594961227916, 54.90611822374406, 57.7016620482168, 56.6738167116719, 58.271633425066554, 55.21385954272363, 54.25295337553948, 53.99333561620405, 59.822428764835486, 62.75406706717707, 67.5987708184027, 60.172449311902454, 53.353899063602576, 19.865073196349606, 0.04113741617109026, 2.9241340727575365, 0.2917060568448036, 0.045073403556260376, 26.210030586488788, 65.38817790246779, 60.48737249066753, 64.80143054839104, 51.700019913335005, 58.516040232873735, 50.59987352740381, 56.96628039883029, 53.25854624471357, 36.95365744252359, 0.36409030337968185, 0.09462175650462028, 0.03603996671435814, 0.09196638084587552, 0.033671965957769466, 0.00633199583746553, 0.054402297527919856, 0.03349395393724403, 0.03135512838320386, 0.039535369273395314, 0.04605854283116999, 0.04165306995292345, 0.08671820359004122, 0.04573204381872089, 0.011976684402343968, 0.13985570910717213, 0.053848967541970556, 0.11088421733509149, 3.401256573777045, 51.1174028150497, 61.82350043327578, 52.16623283201649, 45.48372607077322, 39.57658167808287, 43.23983615444553, 65.67886083356797, 63.320861324187256, 59.8537959591035, 47.44241652950164, 0.5347329870827737, 0.015575965611083854, 0.21172971044096256, 23.559086899603567, 63.82690198959843, 58.95467496687367, 60.9289764588879, 55.21593447654478, 56.90785669511365, 55.65202751467305, 58.22493760816513, 51.8061278712365, 52.44267755939115, 47.140115537951075, 43.94746311249272, 40.97852306981241, 43.75810677005399, 41.360416796899614, 40.45394528296686, 40.81958470805999, 43.234635091597035, 45.51988247902163, 47.71162056153821, 48.35645429549679, 48.17335413348291, 47.75064814475275, 48.21861044053109, 42.11459052178168, 40.940236814560436, 39.182544292942175, 40.026391244703724, 38.74639241926132, 38.3461812234694, 38.674393392378285, 39.237692817564934, 38.61317303872878, 38.75653174615676, 38.99395673505722, 39.631459559163744, 40.36828464077365, 39.95238788666264, 38.38015287153183, 38.247761111105646, 37.87401414686634, 40.444511982702444, 39.540123247331195, 41.51501701724145, 42.090687597951586, 40.595891937132805, 40.4917412419473, 44.92044625743743, 45.07641538496941, 42.81847553868448, 47.41669362591159, 43.53992492921891, 41.24615815378005, 40.04310054163779, 39.9385929107666, 41.37133275308917, 40.365393853956654, 40.73736006213773, 40.994738148104766, 44.48412572183917, 45.14666895712576, 47.71382493357505, 45.215588923423525, 47.933630635661466, 41.00985496274887, 48.35824681866554, 48.65910045562252, 48.59005889584942, 45.731694390696866, 45.26191603752875, 44.60603690916493, 40.10629776985415, 40.000252569875414, 40.864915540141446, 40.57828833979946, 39.82602480919131, 39.56149624240014, 41.75617610254596, 43.409153107673895, 43.88317938773863, 44.79437343535885, 47.074133426912375, 45.735632450349875, 45.784289452337454, 39.28992702114967, 40.64658072686965, 40.261486345721835, 40.5999319784103, 40.80814315426735, 40.14340339168426, 38.70244226148052, 37.48915118555869, 38.78742825600409, 38.787738123247706, 38.85579516810756, 38.1264147450847, 42.10105834468719, 40.640085281864295, 38.46201273702806, 40.63464495443529, 39.630820212825654, 40.52011174540366, 38.50722589800435, 38.82407888289421, 42.190406014842374, 40.04608154296875, 41.848281198932284, 41.84274281224897, 41.40984650581114, 43.37012944682952, 42.71231266760057, 41.37273696161086, 43.12303973782448, 43.10935066592309, 46.06070672312091, 54.2093405415935, 57.22430959824593, 58.183027082873934, 57.95675731474354, 58.27159420136483, 60.813352830948375, 56.911884969280614, 56.239724082331506, 56.287969235450994, 62.12458941244311, 65.07233296671222, 69.22031002659952, 62.5011997069082, 56.285525598833644, 21.191106919319402, 0.062016928042735786, 2.5954977975737665, 0.07804138450733117, 0.05369826655594572, 29.45024959502682, 73.52111831788095, 65.26268166880455, 70.2727133227933, 59.980053132580174, 59.10184621810914, 54.99994524063603, 61.54390212028258, 62.05569298036637, 46.43352408562937, 0.34900802397920244, 0.018024721610990745, 0.049021759430967995, 0.05921052198015875, 0.04320205377054311, 0.04279000188914999, 0.016263818721316995, 0.049888867539383715, 0.14469554617760644, 0.17352688216393994, 0.18264040200700685, 0.13196869603087827, 0.20884500636208445, 0.12861082540644755, 0.1351334205678394, 0.19279995362364477, 0.36562471620498166, 0.27200000781205397, 3.8963391175193176, 59.090655696007516, 69.92701130528604, 60.45549538827712, 46.9564466322622, 46.53951829479587, 51.17568923581032, 70.78725768673804, 67.36576634068643, 66.87695272507207, 53.08821339761057, 0.7704168726359645, 0.22141240296825287, 0.37599494200079675, 25.50205453749626, 67.18575308399816, 60.22957078872189, 62.9174377072242, 57.798830924495576, 57.78335325179562, 58.12655279713293, 61.47861819113455, 56.60074687773182, 55.94371457253733, 48.716888735371256, 46.38708322278915, 42.20365578128446, 46.595380690789995, 44.73320799489176, 43.85835862928822, 44.723904132843025, 47.393543797154585, 47.60692073452858, 50.2473936542388, 50.010984559212964, 49.629322251965924, 51.05116182757963, 50.883888429211034, 44.748972000614295, 43.917056898916925, 42.236525243328465, 43.08078012158794, 40.75497934895177, 41.457487613924094, 42.86301405199113, 41.55332288434429, 40.96847787980111, 40.9160279458569, 40.974502640385786, 41.033569612810695, 41.74176923690304, 42.41826826526273, 40.577758819826194, 41.89756185777726, 39.24773800757624, 41.56291700178578, 41.12748684421663, 42.18738578980969, 44.314608727732015, 43.194015026092536, 43.28282140916394, 46.68148848318285, 48.09947629128733, 46.30227373492333, 49.42036582577614, 47.09322752491121, 43.87625248201432, 41.68033315289406, 41.90715989758892, 42.41821727445049, 42.2255818305477, 42.64410657267417, 44.375436844364295, 46.04891607838292, 47.261273630203746, 51.297443528329175, 47.81160569960072, 50.602411300905295, 41.348610462680945, 47.169835336746715, 50.85259183760613, 51.74014968256797, 48.43960069840955, 47.851013752721975, 47.56818340670678, 42.22748810245145, 43.82204532623292, 43.500928724965746, 43.31677344537551, 41.54207352669009, 42.70056516893449, 45.64277033652029, 44.152920784488806, 45.79477394780805, 47.83453979799825, 48.88791191962458, 49.39370939808507, 48.60669366775021, 42.68555818065521, 43.5008502775623, 43.35255722845755, 43.840876625430205, 41.26118083154002, 40.49314152809882, 41.150985763918975, 41.05565255688083, 39.465158908597886, 40.658128184656945, 42.58259204126174, 39.78557732797439, 43.99194671261696, 43.03918338591053, 39.614216819886245, 42.90992167688186, 42.86221781084615, 42.85989969007431, 40.63519016388924, 41.92957232075353, 45.014398790174916, 43.039740362475, 44.116752609129875, 44.93502178499776, 43.59100203360281, 46.981181098568825, 44.96405516901324, 43.30919150383242, 44.76120979555192, 46.39608506233462, 47.351825468001834, 57.330539149622766, 59.51870003054219, 60.394392705732784, 60.55843799344955, 61.49524904066517, 65.03414869308472, 60.03589591672344, 58.62345041767244, 59.57686878019764, 64.24278697659894, 68.52970615510019, 73.24117875868275, 63.98462049422726, 60.8419979003168, 23.891821561321137, 0.1398809593651564, 6.993944423813974, 2.6226018657607417, 0.13728949842193436, 32.49965706179219, 79.79036808013916, 69.10014429400044, 76.84168707939887, 65.96837489835679, 75.28135253537086, 59.496601396991366, 73.39582212509649, 69.67982353702669, 59.00290050814229, 1.004474139021289, 0.18511125006743018, 0.17965976839825032, 0.17685069251925717, 0.1629807625807101, 0.07878547804730554, 0.16289134479818806, 0.13977733831251823], [0.02324958106562976, 0.006587612564720575, 0.047157453823714494, 0.0400007332134391, 0.02925093957944022, 0.006524066529011415, 0.08044508496119131, 0.0574622365585979, 0.03287107465908893, 0.07357734420727338, 0.5625102933376067, 42.214775700722974, 60.26576249830185, 40.911215197655466, 27.714288965348278, 17.91236827450414, 39.304404489455685, 55.96134170409172, 59.480970751854684, 53.97966223378336, 54.941246971007324, 2.22404983255171, 0.2080429123053628, 0.12372988771887557, 8.425195236359874, 58.167945569561375, 59.52901978646556, 59.37252506133049, 54.80930628315095, 57.44334651577858, 54.99814095035676, 55.903023904369725, 51.9916481356467, 44.886341248789144, 41.60226229698428, 43.15617984341037, 41.39554946653305, 40.26695412974204, 39.1281488633925, 43.620627695514315, 46.12615539181618, 47.93032799997638, 49.61921822640204, 51.56786349511916, 49.39063818224015, 50.86162897848314, 50.17841877475862, 48.43867894141905, 43.3898550464261, 37.89271208547777, 35.348643179862734, 37.5254487991333, 37.12428054501934, 36.44844439721877, 37.13634575566938, 37.03119093371976, 36.11527827478225, 38.077969551086426, 36.13083047251548, 38.06053853804065, 37.16078996658325, 37.82442754314792, 37.48752732430735, 37.147787309462025, 36.154105817118, 40.70286673884238, 36.88230168434882, 40.10163799408944, 37.91255143380935, 37.825200250071866, 38.62090010796824, 42.66552663618519, 41.28527595150856, 43.56503594306208, 42.79050119461552, 42.64944099610852, 38.81889743189658, 39.322333643513346, 41.87221550172375, 40.04106875388853, 38.60542243526828, 38.8943128431997, 37.73358152758691, 39.89023793128229, 42.675293337914255, 42.86054295878257, 41.87864818880635, 44.870130092866965, 40.73004091939619, 42.081473950416814, 46.74346585427561, 45.44144292031565, 42.46374030267039, 40.07927656173706, 41.16005036138719, 38.194707132154896, 37.28892595537248, 37.938356707173014, 37.41747771539996, 38.49091276045769, 37.2941780090332, 40.2969681063006, 41.00294766887542, 42.45168293676069, 41.57298572601811, 44.232097748787176, 45.15459606724401, 42.60802076708886, 37.65533024264921, 37.94426379665252, 39.35406561820738, 39.49498853375835, 39.30258058732556, 38.123539647748395, 37.396151788773075, 37.51265402763121, 37.76072432917934, 37.36808330781999, 37.75491922132431, 37.83248409148186, 38.403118348890736, 38.91548971976004, 37.752322612270234, 37.28097531103319, 35.857225541145574, 35.294675288661836, 37.911351188536614, 37.097329939565356, 37.0831270371714, 38.017945520339474, 37.6025390625, 37.52004769540603, 40.43040321719262, 40.30478539005403, 41.85416867656093, 41.29362275523525, 41.316949090650006, 40.13839452497421, 40.22606734306582, 41.19064877110143, 49.61350725543115, 51.165393014107984, 55.53808658353744, 51.400272384766616, 55.576890591652166, 50.009360697961625, 52.30513180455854, 52.045490511002086, 62.16721773147584, 57.15501308441163, 67.3216788999496, 56.32236057712186, 71.73160752942486, 30.158158963726414, 0.11543249666330316, 1.260043522042613, 0.3965048624142524, 0.18589679662498737, 23.563760403663885, 69.16307480104508, 61.54500822867117, 62.63355224363266, 48.07198439874957, 33.94926309585571, 34.362457336918006, 63.60249926967006, 51.69173978990125, 38.774190256672526, 0.5386428547001655, 0.09845692288851547, 0.009390848459705952, 0.032614124938845634, 0.06392616470674835, 0.04908246423808798, 0.04551246003698438, 0.03378732347740762, 0.033582670749315334, 0.06284195111103116, 0.047373693631661516, 0.009859605211644404, 0.07525915234920479, 0.004703686966921293, 0.04513742935453211, 0.08122129290695153, 0.07733676747809495, 0.05552579994283377, 1.3125520463912719, 50.741220058933386, 65.5580282980396, 48.52987797029557, 32.86511409667231, 29.78267242831569, 49.23397479518768, 62.17021049991731, 66.43636072835615, 58.081496530963534, 60.182969108704604, 2.2383733478284653, 0.12770221448473393, 0.07914680341679244, 9.255230542152159, 59.95761325282436, 58.59736273365637, 60.59274304297663, 56.34625173384144, 58.73747764095184, 57.27480619184433, 58.393866246746434, 53.44807517143988, 46.47168874740601, 42.59799126655825, 44.39733935940651, 42.492557956326394, 41.371913263874674, 40.603269915426935, 45.66962680509014, 47.54726148420765, 51.23007682061965, 50.570875444719874, 53.724476752742646, 50.84326836370653, 50.73679170300884, 51.73803160267492, 51.31907932219967, 44.68781048251737, 40.41082666766259, 37.60387659072876, 40.51143154021233, 38.919545450518214, 38.20573291470928, 39.33184931355138, 38.47526642584032, 38.59351019705496, 40.270719605107466, 38.15074520726358, 40.66867543805031, 40.16077164680728, 39.40443277359009, 38.04201318371681, 38.72943993537657, 38.83490854693998, 41.14743601891303, 40.82534666984312, 41.361162047232355, 39.62010821988506, 40.90851268460674, 41.360467787711855, 44.80097870672903, 45.097800147148874, 45.870256039404104, 44.88388976743145, 43.96318397214336, 40.04561085854807, 40.57300098480717, 41.71290843717514, 41.26368330370995, 39.36346361714025, 40.42202111213438, 40.20171726903608, 42.684150049763346, 44.61224209877753, 44.935080620550345, 43.37491866080992, 46.49679976124918, 42.95276180390389, 47.316728099699944, 48.65215001567718, 46.43924290134061, 45.76176720280802, 42.341083865011896, 43.68861806008124, 41.155461188285585, 38.44729208177136, 39.54305325784991, 40.090961302480395, 39.61419328566521, 39.746467374986224, 42.6021489789409, 41.153076387220814, 43.56906813959922, 44.522392365240286, 46.28724321242302, 47.352186326057684, 44.20595515158869, 40.3658841502282, 40.52629340079523, 41.308837629133656, 41.132797733429946, 40.09305584815241, 39.93816145004765, 39.20372509187268, 39.85918452662807, 41.21243361503848, 40.63025582221247, 40.34267156354843, 39.29801494844499, 41.141560308394894, 40.51356530958607, 41.434255415393466, 39.74253716007356, 39.15829227816674, 36.97186900723365, 39.97500035070604, 38.9258526217553, 40.19111510246031, 38.82542033349314, 39.795834325974994, 39.02420997619629, 42.85568314213907, 42.121854751340805, 42.83750295639039, 43.109782126642045, 42.30413906035885, 43.677180428658765, 44.69260754123811, 45.69189802292855, 51.89816628732989, 53.84257147389074, 57.480581575824374, 54.76327726917883, 58.316681846495605, 53.56337324265511, 54.65276448957382, 53.28567727919548, 65.06160136192076, 60.48537600424982, 68.8227778096353, 59.41887570965675, 75.49086201575496, 32.445726433107936, 0.09414322734359773, 1.189624474894616, 0.2640846648043202, 0.2244822858201881, 26.28030573168109, 75.82870360343688, 65.56961890189879, 69.23440702499883, 55.23069827787338, 44.853895402723744, 40.72316108211395, 70.56192536507884, 58.53899394312213, 47.29706525802613, 0.6076766310199615, 0.07951722224994053, 0.08030363448685215, 0.024317545936472958, 0.028385578151491862, 0.05570076676386018, 0.05498576924324997, 0.04168066443995603, 0.15934510847493527, 0.15312714051575432, 0.10924220746082645, 0.16300126309356383, 0.22900693899681493, 0.13789329828033525, 0.11369565276489144, 0.20861257528585775, 0.28725349254185156, 0.15202852446706067, 1.4415570853217956, 58.81028467609037, 74.324003957933, 55.23391069904451, 39.24188583127914, 30.094579304418257, 53.00634960974417, 67.8271939677577, 70.32246466605895, 63.08130256591305, 65.91739977559736, 2.6840722705087354, 0.31212913353116284, 0.1636860231238027, 10.209617730109922, 61.356024511398815, 63.11199511251142, 64.53067718013641, 58.58714495935748, 62.663950612468106, 61.188264739128854, 61.26665722939276, 55.048570863662235, 48.82520498767976, 44.55768977442096, 47.38137660488006, 45.80362673728697, 44.06475767012566, 43.2270178487224, 48.609890399440644, 51.16283562875564, 53.730893750344556, 52.664405222862, 58.5569074076991, 52.17385007489113, 51.304095868141424, 51.6915475937628, 54.91139381162582, 47.11898965220298, 42.3224094606215, 38.31332745090608, 42.35391786021572, 41.899358303316184, 41.040202340772076, 41.697524901359316, 41.76494652225126, 40.28391053599697, 42.179941131222634, 38.66601913206039, 43.269755994119954, 41.04923163690875, 40.70502012006698, 40.65147976721487, 41.98447373605544, 40.8433856502656, 43.23991852421915, 40.75223761220133, 44.03917204949164, 41.09818673902943, 43.081662654876716, 44.00881290435792, 48.37429715741066, 46.51779620878158, 46.95638779670962, 47.214479754048014, 46.09851052684169, 41.23468129865585, 43.36700331780219, 43.70692376167544, 43.672810908286806, 41.7593296881645, 43.824779218243016, 41.72940984849007, 43.16304006884175, 46.59750661542339, 46.3444156800547, 45.51547765731812, 46.81594341031967, 43.42682338530018, 48.03345495654691, 51.47500138128958, 49.17399391051262, 47.71017712931479, 44.26391209325483, 46.374539482978086, 43.44008099648261, 41.271822221817516, 42.25136749206051, 42.11275485254104, 41.90708537255564, 42.546823947660386, 44.31381640895721, 43.74561794342534, 45.4633689695789, 45.43764998835903, 48.879557271157545, 50.045568097022276, 46.97444638898296, 42.473695278167725, 42.20696233933972, 43.62316939138597, 43.33327093432027, 41.35253675522343, 42.244562179811545, 42.31706327007663, 41.85801652169997, 43.93856325457173, 43.17079851704259, 43.098979919187485, 43.25986377654537, 42.68185546321254, 43.14389890240085, 43.71331330268614, 42.45744489854382, 40.637892676937966, 39.337156280394524, 42.87169425718246, 43.06104667725102, 42.71971025774556, 42.717654935775265, 41.2787099038401, 41.878161814904985, 45.42894624894666, 44.16835138874669, 45.566852861835116, 46.13632609767299, 44.04464375588202, 44.81644461231847, 45.65292535289642, 47.00495066181306, 53.39143614615164, 56.994745039170795, 60.07790450126895, 55.332840719530665, 58.984151578718624, 55.68656006167012, 56.78990317929176, 56.960942053025775, 68.17373537248181, 62.08483226837651, 71.59494430788102, 61.91051037080827, 76.48246857427782, 34.29499256995417, 0.40258487326002895, 4.292350680597367, 1.3596871687519936, 0.419279461305949, 28.120324880846088, 82.19412988232028, 69.44691319619456, 75.36126690526163, 60.80988153334587, 50.63176239690473, 43.694705578588675, 78.84211155676073, 66.64337558131065, 59.74041592690253, 1.282675230214673, 0.17758789892879226, 0.14528889659672015, 0.1274493901479629, 0.1322454835979208, 0.11994205024694243, 0.10957124222430492, 0.13968828825219987], [0.03885229463658987, 0.06422489686238189, 0.08287232729696459, 0.0655024940328252, 0.023694570897327318, 0.02938532289267788, 0.02495867151376461, 0.01624839354096161, 0.08495665335607144, 0.03740009453688418, 0.049422021219206434, 33.03944187779581, 65.45341476317375, 46.916144278741655, 39.54934866197648, 23.270939780819802, 39.31028804471416, 53.85002789958831, 64.57421548904912, 52.11699531924341, 58.71864634175455, 6.539896245925657, 0.1883701880973193, 0.06418606769593974, 0.9512354409502399, 36.4674678925545, 58.509815431410274, 57.23160128439627, 57.2421524601598, 57.47771432322841, 58.9099403350584, 56.72629410220731, 51.32641023205173, 43.19928276923395, 42.868764246663744, 41.867979341937655, 37.56601002908523, 42.34646143451814, 46.36499635634884, 51.13204502290296, 51.19929013713714, 55.11009323981501, 52.9703147949711, 51.93184767999957, 52.293196032124186, 51.09631223063315, 47.36358081140826, 49.659195023198286, 44.40131664276124, 37.35606516561201, 37.46760952857233, 37.072211080981845, 35.23976995098975, 36.72981562152986, 35.01674790536204, 37.04185978058846, 37.782269908535866, 38.38042743744389, 39.82751923222696, 38.24734926223755, 36.49100995832874, 38.74433709729103, 38.98546088126398, 36.98996290083855, 36.28783902814312, 38.556620305584325, 38.19884523268669, 37.77031844662082, 39.02713606434484, 37.1856068026635, 38.14338291845014, 43.769744442355254, 41.439303505805235, 42.733501311271425, 43.018771371533795, 41.01292225622362, 41.345245069073094, 39.61442862787555, 39.68041073891425, 38.76471381033621, 40.143485761457875, 39.21378989373484, 38.88999823601016, 39.76683624329106, 40.98278276381954, 43.482246475835005, 43.37947645495015, 45.68830905422088, 42.801856456264375, 41.90888966283491, 45.64295468791839, 43.7834805826987, 43.63332833013227, 41.56812198700444, 39.149098242482836, 38.35099397167083, 37.92606792142315, 36.692647241776996, 38.359740857155096, 38.4227890353049, 38.17742516917568, 40.726836342965406, 43.06659683104485, 43.8670741358111, 43.7500580664604, 43.23052444765645, 42.70767250368672, 41.82823396498158, 39.1416222049344, 38.99228188299364, 38.79152713283416, 41.49294584028183, 38.26670615903793, 37.19569513874669, 38.60544204711914, 39.191373548200055, 36.32434060496669, 38.493670186688824, 37.98939066548502, 36.6555965331293, 37.17155687270626, 37.639683908031834, 38.13558524654758, 36.00371037760089, 37.845416145939986, 36.245767685674856, 36.70523020528978, 36.920419277683386, 36.61100702901041, 37.67225919231292, 39.22042262169623, 38.49699635659495, 39.07104307605375, 39.426794205942464, 41.189817228624904, 39.139582572444795, 40.89105813733993, 38.04788104949459, 39.54224132722424, 39.866331085082024, 44.3931894917642, 44.81239280393047, 49.051882682308076, 48.379443307076734, 54.0400275107353, 49.53099235411614, 49.49511051177979, 51.14241969200873, 61.13594032103016, 57.723701846215036, 65.04005578256422, 58.932290000300256, 71.09011173248291, 39.998667932325795, 0.15465415293170562, 1.0581797217169115, 0.1018953323364258, 0.1000127019060235, 25.728993069741037, 70.7335525943387, 59.063775693216634, 65.49004577821302, 46.600691580003314, 32.54337579973283, 29.594798741802094, 58.23190765996134, 61.22581751115861, 31.11884351699583, 0.4024428405588673, 0.056813076634200356, 0.021104314627366203, 0.016036614279953704, 0.034892083551254005, 0.024480887373248418, 0.03178972240176893, 0.03212185599090111, 0.028176037782442667, 0.03441658426797198, 0.026383028147862326, 0.007618189472029167, 0.030025870073586706, 0.039864059297307845, 0.021645389121746825, 0.05338319374488727, 0.011485615339610847, 0.020509112190695542, 0.17234886876277386, 39.0514547594132, 70.46513695870676, 51.41050584854619, 41.86932471490676, 24.157754336633992, 47.69371101933141, 59.05249495660106, 69.2980827823762, 56.68443849009853, 64.76711765412362, 6.80031563966505, 0.4305063572622115, 0.023571401196081313, 1.2459432141434763, 41.11674739468483, 61.40456384228122, 60.1505664087111, 58.54061780437347, 58.20107390803676, 60.01796284029561, 57.92935955908991, 53.60735477939729, 45.81065954700593, 45.14617473848405, 43.97114246122299, 40.14458010273595, 42.95074962800549, 46.79473907716813, 52.63021392206992, 52.788587462517526, 57.14470509559878, 53.278703305029104, 53.607558742646255, 51.91311444005659, 52.39917455180999, 50.41881299787953, 50.081406793286725, 45.86286629399946, 39.49092495825983, 39.33075889464348, 39.67814360895465, 39.16141056245373, 38.50334667390393, 37.7846743214515, 38.20837659220542, 39.32482042620259, 40.65439016588273, 41.05610755182082, 41.58738866929085, 39.2480557195602, 39.900859709708925, 39.267746017825225, 37.42975081166914, 39.278265814627375, 41.67599501148347, 39.84408340146465, 41.092240425848196, 41.280902508766424, 41.32289540383124, 40.224227751455004, 45.475575385555146, 44.03056244696341, 44.70567687865227, 43.83910763648249, 42.95422484797817, 42.69814898890834, 40.35034371960548, 42.12813446598668, 41.68150594157558, 42.122784353071644, 40.48867394847255, 41.43402791792347, 42.25414453014251, 42.63090779704433, 45.54092207262593, 46.22685047887987, 47.87654838254375, 44.74681861938969, 43.67191660788752, 47.9040991106341, 46.212427923756266, 44.67160717133553, 44.04085082392539, 41.104670416924264, 39.72629462519, 37.83761847403742, 39.688063283120435, 41.18994666684059, 38.85088043828165, 40.16704743908298, 41.70070202119889, 44.370376986842004, 45.379998991566325, 44.28845828579318, 46.40680490001556, 43.250822713298184, 44.34032770895189, 40.9438257832681, 41.60755357434673, 40.90930500338155, 42.23838836916032, 39.65055757953275, 38.7876675205846, 39.741246700286865, 40.82338548475697, 38.49087745912614, 39.34601691461379, 41.6780307216029, 38.84773077503328, 40.11854733190229, 40.21792842495827, 40.927744065561605, 38.88327137116463, 39.93677685337682, 38.325514255031464, 38.40895875807732, 40.39299165048907, 39.050548691903394, 39.94096986709103, 42.46470128336261, 39.72524342998382, 41.199780048862586, 41.64868354797363, 42.92154365970243, 40.633350572278424, 43.26042075310984, 39.66855341388334, 42.41897036952358, 41.89029370584796, 45.661876201629646, 49.51062740818147, 52.07277451792071, 51.52246598274478, 54.18085236703196, 52.73182684375394, 52.089389677970644, 53.43260926585044, 60.9170328417132, 59.05999845074069, 67.44008741071148, 60.97895529962356, 74.04777496091782, 42.014848570669855, 0.1856259079349618, 0.6427396172958036, 0.13407948276688977, 0.10456688777213136, 28.660715703041326, 76.08659944226666, 63.41876760605843, 68.6468751968876, 51.745911644351104, 40.48616363156227, 35.54452634626819, 62.28178231946884, 67.35382664588191, 39.08524205607753, 0.4903059548908665, 0.017908961895192345, 0.08040524838912873, 0.03204082304071034, 0.05524573734991493, 0.06099246164423324, 0.06505737396618051, 0.029747490958881476, 0.1891766028899339, 0.11441235100069355, 0.10604339967211408, 0.18086980427465132, 0.1053022402488897, 0.183900831147067, 0.12075955033182137, 0.10491609363065613, 0.1184253034091765, 0.06436676102420015, 0.23521822666929615, 44.15573312390236, 80.23219954582953, 60.29112062146587, 51.52214434839065, 34.98985221309047, 53.8032457905431, 65.37579105746362, 75.6403592325026, 61.47690803773942, 71.18226389731132, 8.31133863618297, 0.5182321273511457, 0.14972529644446989, 1.3146757646914453, 41.98700758718675, 61.33629891180224, 61.10893480239376, 62.116395581153135, 62.32970191586403, 62.01842261898903, 60.65433602179251, 56.75944597490373, 47.52702597648867, 46.486091690678755, 47.009422163809504, 41.979366810091086, 45.341830407419515, 51.347489049357755, 56.28883607925908, 55.14890509267008, 59.91859351435016, 57.46871640605312, 55.005307120661584, 54.4551750921434, 53.04764432291831, 53.225594412895944, 54.81706080898162, 48.88235784346058, 40.847888531223425, 41.38957177439044, 41.45112945187477, 40.224388568632065, 41.68398095715431, 39.97242335350283, 41.98540726015645, 40.487709045410156, 42.805633698740316, 45.19236064726307, 44.586597642590924, 39.87932589746291, 41.43213341313024, 42.29761223639212, 40.601504848849395, 40.169498920440674, 44.50177246524442, 41.922449296520604, 42.96730595250284, 43.96037163272981, 42.31417248325963, 42.48434843555574, 48.55887605297951, 45.184904221565496, 46.24004140976937, 44.64602547307169, 44.88897315917477, 46.020651478921216, 41.066497910407286, 45.87074633567564, 41.11701019348637, 44.94173296036259, 42.536339452189786, 43.5802782735517, 44.83958659633514, 44.72420615534629, 47.54465310804306, 49.02684619349819, 49.521155049723966, 46.12233892563851, 47.60553613785775, 51.17170018534507, 48.1092155364252, 47.632529889383626, 47.32151339131017, 43.231206940066436, 42.1706098125827, 41.58573342907814, 41.63744203505978, 42.73952214948593, 41.521559530688876, 41.37120331487348, 44.549833266965805, 47.96558618545533, 48.54244524432767, 47.13124705899147, 49.38382110288067, 45.503941966641335, 45.346164626459924, 42.588008834469704, 42.33925996288177, 42.71032402592321, 45.09972995327365, 41.12820463795816, 39.78662067844022, 42.132213730965894, 42.8892860874053, 39.44882223683019, 41.94085697973929, 42.79093657770465, 41.519527742939616, 41.03452274876256, 42.70183209450015, 43.75684768922868, 41.32264829451039, 43.339440822601325, 41.24011770371468, 41.8743061250256, 42.72619001327023, 42.50214030665737, 42.64989599104851, 44.16845729274135, 43.80296691771477, 43.18497396284535, 45.30049254817348, 46.6700469293902, 44.78342217783774, 45.12411140626477, 42.24398951376639, 46.17902501936882, 44.20958726636825, 48.00034622992239, 49.52492052508939, 53.398312061063706, 53.70874804835166, 57.186019420623786, 55.53254819685414, 54.37442525740593, 54.87013439978323, 66.69955176691856, 61.62312223065285, 71.34768593695857, 64.63269802831834, 76.32927648482784, 44.75743255307598, 0.4324782062922755, 2.2576277727080933, 2.015044867031036, 0.20169878498681132, 31.819574948280092, 84.47102654364802, 67.05151388722082, 77.65954048402848, 60.456044520101244, 46.21627184652513, 42.88224543294599, 70.8005545216222, 77.84208759184807, 46.927628978606194, 0.8403990045189859, 0.1426124918244539, 0.12245553876123122, 0.1640285103912315, 0.15931734544855936, 0.12097270663587317, 0.1591881370592502, 0.07037157267932931], [0.03050237101682973, 0.0290129198918059, 0.07429649392443319, 0.028634248376493494, 0.03845270317528517, 0.011825372461199522, 0.03739933610983914, 0.046871492353778695, 0.010452976698176035, 0.055409028990975315, 0.026116912185605017, 18.529635590891687, 62.578140920208355, 53.043580747419796, 34.12733477930869, 29.652804713095392, 38.872782953323856, 46.50731563568116, 66.10677965225713, 50.39128580401021, 64.01288509368896, 15.682980341296043, 0.22064148869004943, 0.1360140233150413, 0.03697869638281484, 15.785956286614942, 54.377790651013775, 58.587454826601096, 57.84002365604524, 55.6332197496968, 56.53778106935563, 57.27231940915508, 51.836263441270404, 42.94991416315879, 41.027168304689475, 41.98601130516299, 42.53480188308224, 47.57227443879651, 51.421260987558675, 54.685979120193, 52.93193832520516, 50.26962957074566, 50.389724700681626, 48.190694932014715, 47.7131228293142, 48.78577340033747, 50.74702124441824, 49.50649323001985, 39.2091340403403, 37.99809048252721, 37.11530616206508, 38.12112346772225, 36.36946747379918, 37.52730408022481, 36.15535705320297, 37.5455117225647, 35.981325411027484, 37.49337557823428, 38.703705264676, 35.463439187695904, 37.121683935965265, 37.636275368352095, 38.30575335410334, 37.923259504379764, 37.51737656131868, 38.95512134798112, 38.420286563134965, 39.66867500735868, 38.486217683361424, 37.862619661515765, 38.951120530405355, 41.38122889303392, 41.402433226185465, 41.14111315819525, 41.65675970815843, 39.52927397143456, 39.384161964539565, 38.687941258953465, 39.50596332550049, 38.600335121154785, 37.68420673185779, 39.68519603052447, 38.936858792458814, 39.16140271771339, 41.824727366047526, 43.0459886981595, 44.0447182809153, 44.505420269504675, 44.70658686853225, 40.43901281972086, 43.47639037716774, 41.86387654273741, 42.25115568407121, 41.29015930237309, 40.27267294545328, 38.991391504964525, 37.662684686722294, 37.970747640056, 40.535667865507065, 38.97465082906908, 39.43188544242613, 39.99518094524261, 42.896593463036325, 42.737941434306485, 42.45487966845113, 41.118881164058564, 43.76254297071888, 41.8868733990577, 38.635063786660474, 38.22035551071167, 39.581755284340154, 40.420460008805804, 37.399858428585915, 38.94187158153903, 39.40367575614683, 38.3258201999049, 37.62411209844774, 36.44207446805893, 38.629372427540446, 39.20514891224523, 39.416313632842034, 39.69671995409074, 38.77603377065351, 37.368248047367224, 37.80584727564166, 37.87064090851815, 37.340650250834805, 35.79828800693635, 39.08961942118984, 37.54405652323077, 41.40557896706366, 40.605929282403764, 43.74673581892445, 42.596171286798295, 45.28438337387578, 44.29835834810811, 43.31125467054306, 40.5721184515184, 38.292778153573316, 37.20677583448349, 38.67350693671934, 42.584976842326505, 45.54626041843046, 45.86587475192162, 49.16366238747874, 46.97549366181897, 48.54326894206386, 44.666104085983775, 51.272752208094445, 52.06756168796171, 59.32550368770477, 54.953174898701334, 70.797636278214, 42.94388155783377, 0.06624136285315599, 0.4242661421097094, 0.10593591753633753, 0.097708661830233, 27.213729812252907, 68.58333280009609, 58.57498953419348, 62.12531897329516, 45.601926695915964, 34.56522818534605, 29.526286702002253, 57.09867608162665, 60.98886320667883, 20.01358982055418, 0.35425713586230434, 0.01833510979439222, 0.12377890968515028, 0.03744876410271372, 0.017945575152313518, 0.04657858246636968, 0.09388688666325423, 0.04474095970151886, 0.07260492582234644, 0.08752182216173218, 0.028345431313819947, 0.04703986698821668, 0.011618059492790172, 0.09647485424554157, 0.04969960934812984, 0.043165702898536, 0.014815754538792518, 0.03241618697140967, 0.1318307848827493, 23.547439421376875, 69.32451955733761, 59.102438496005156, 39.28116836855489, 28.761236244632354, 47.51783978554511, 51.63228842519945, 71.40496823095506, 56.16583839539559, 68.2542145636774, 16.630372962644024, 0.32224606001569384, 0.26972561533893313, 0.09331449640974884, 17.681311253578432, 55.91424580543272, 60.069424336956395, 57.86371084951586, 58.92588476980887, 58.948442320669855, 59.85199951356458, 55.469868721500525, 43.52097203654628, 43.230763712236964, 42.2017377422702, 44.30939197540284, 49.32216536614203, 54.95665404104418, 55.30042233005647, 55.43213159807267, 51.304146858953665, 52.72421744561965, 49.63070292626658, 49.24247457135109, 50.00538733697707, 51.82668109093943, 52.5751163882594, 42.22207915398383, 40.294383264357045, 39.4433230738486, 38.99447056554979, 39.12370481798726, 39.99482400955693, 37.26578004898564, 40.02256301141555, 38.60555187348397, 39.236065033943426, 40.21706942589053, 40.05666409769366, 37.31603345563335, 37.73099276327318, 38.81754421418713, 39.10588156792426, 39.537734523896255, 40.12126161206154, 39.594377471554665, 41.5836271162956, 41.08597640068301, 38.55735378880655, 41.90755605697632, 42.664487208089525, 44.05153928264495, 43.89874335258238, 43.60147083959272, 42.255030985801454, 41.02462660881781, 40.069333353350245, 42.94235183346657, 38.8636948216346, 38.80520443762503, 42.004666097702525, 40.289727410962506, 41.379185338174146, 42.28604124438378, 45.84642764060728, 43.857425105187204, 46.73726458703318, 44.93221729032455, 43.93606862714214, 46.635310419144176, 42.8690388125758, 44.397668838500984, 41.71451268657562, 42.201274902589866, 40.32142016195482, 38.80818543895599, 39.38575444682952, 41.20605191876812, 39.95959328066918, 41.24358115657684, 40.47383562211068, 43.59410462840911, 44.69974233258156, 44.63017517520536, 44.74200979355843, 44.42481164009341, 45.446800877971036, 40.283914458367136, 40.00122531767815, 40.60610971143169, 43.59636783599854, 38.82228635972546, 39.81819575832736, 40.83550953095959, 39.30451823819069, 39.847680214912664, 39.18939667363321, 40.307593807097405, 41.800679314521055, 40.35356398551695, 42.14878182257376, 40.197304602592226, 38.725682304751494, 39.5033549493359, 38.18430500645792, 39.53995850778396, 37.89229239186933, 40.92817552628056, 39.718143939971924, 44.07669736493019, 43.766532021184126, 45.44090947797222, 45.856437529287035, 48.6134244549659, 45.350028161079656, 45.34159114283901, 40.95334145330614, 40.80440513549313, 39.08932132105674, 41.52070445399131, 44.30154331268803, 48.44437814527943, 50.36974414702385, 51.067000358335434, 50.55248345098188, 51.76572353609147, 49.0742519594008, 55.382211592889604, 55.495203310443515, 61.87225549451767, 57.61882159017748, 73.29550358556932, 45.59063026981969, 0.20899327501894968, 1.3392372789882845, 0.05096390723220764, 0.11790021908499541, 30.298362124350767, 73.66484180573495, 63.8445173540423, 66.46161294752552, 53.44042654960386, 37.62303736902053, 32.87900320945248, 64.58724952513172, 67.5098349971156, 27.011572814756825, 0.358655828862421, 0.03905909241087014, 0.06296539851914972, 0.06868582684546709, 0.008648311035827765, 0.08128127759142269, 0.06912258123197863, 0.08161883125261915, 0.13986853341902458, 0.22159937438705277, 0.1380451675504446, 0.13857911551190963, 0.10516725555663148, 0.14356213441539195, 0.21194896480489164, 0.25643552202851544, 0.13172543247140225, 0.19885160389446443, 0.29496971397630634, 25.710059788919267, 79.29956974521761, 66.38691532996394, 47.33513186054845, 41.3011380164854, 51.43560117290866, 57.63260872133317, 76.673291883161, 60.66898607438611, 75.24227003897391, 20.1452539813134, 0.684068160912683, 0.49412070503157957, 0.1354453562488479, 18.4524158893093, 58.00968970021894, 61.767979283486646, 60.41283961265319, 61.649782580714074, 61.49614726343463, 62.943854870334754, 57.55930354518276, 46.46479322064308, 45.285242372943515, 45.70016245688162, 46.39145666553129, 53.50178810857958, 57.08355534461237, 58.372269676577666, 56.60018205642701, 54.23573024811284, 54.0790903952814, 49.67284487139795, 51.46095145133234, 55.71067871585969, 54.652089841904186, 54.56001612447924, 43.84868214207311, 41.63880701987974, 40.96886227207799, 42.01992411767283, 41.73720752039264, 41.95474609251946, 39.77273156566005, 42.82938757250386, 40.43312534209221, 41.366225827124815, 42.355898657152736, 41.49899805745771, 39.7570538520813, 41.46873304920812, 42.423987080973966, 41.52234008235317, 41.333764291578724, 43.127024865919545, 42.86328469553302, 43.88449730411653, 43.332435469473566, 41.73636421080559, 43.958685013555716, 44.44330169308571, 45.244649764030214, 45.703367033312404, 45.82740414527155, 44.32582670642484, 42.343370606822354, 41.701768905885764, 44.6030362959831, 41.75178304795296, 41.18502409227433, 45.93093510596983, 42.9629050531695, 42.785543318717714, 44.90929888140771, 48.48346456404656, 46.72205755787511, 48.127478091947495, 47.09076035407282, 45.473990748005534, 49.180654095065215, 46.36724387445758, 47.014964472862985, 46.279680882730794, 45.11875737097956, 43.575614575416814, 40.402648525853316, 41.961065030867054, 43.382841848558, 41.48583850552959, 42.73874159782164, 41.51361673108993, 45.31488764670588, 46.32425861973917, 46.6449829839891, 46.13415310459752, 47.8450164487285, 46.904926300048835, 42.48572126511605, 41.300632030733176, 42.59372372781077, 45.434531704072036, 40.08908640953803, 43.89549170770953, 43.91654306842435, 43.01939895076137, 43.461689333761896, 40.99353398046186, 43.16880987536523, 44.824387411917414, 43.835169576829486, 43.72201311972834, 44.36721947885329, 42.56378819865566, 42.89004702721873, 41.735144353681996, 41.48272806598295, 40.215849568766934, 44.045420385176136, 41.242679011437204, 46.81693576997327, 45.84852610864947, 47.96790038385699, 47.574216012031805, 51.784472465515144, 49.09045134821246, 47.86775835098759, 44.49653610106438, 42.890207844395796, 40.8314851791628, 43.88276753887054, 48.520781993865974, 50.84946963094896, 53.10854304221369, 53.12901781451318, 52.151735751859604, 54.383081928376235, 51.0011790644738, 56.85239830324727, 58.731331286891816, 63.4854204423966, 60.8499603117666, 77.29818036479335, 46.88805226356753, 0.33196121934921513, 2.3685693164025587, 1.6943602167790937, 0.2067416200354215, 33.29816533673194, 81.08912760211577, 67.99056068543466, 72.70318646584788, 59.38681033349807, 49.72306297671411, 40.726675525788345, 72.58573501340805, 76.3166307633923, 35.1960119893474, 0.430176786237186, 0.2142902980408361, 0.27893537114704814, 0.16750573751426515, 0.08863530797703613, 0.2769733280424149, 0.3241737210942853, 0.1550959405158797], [0.07003253280755974, 0.014930416833639387, 0.039981098379939795, 0.019328499836246335, 0.03837656169649094, 0.0360137933204251, 0.028553539098450736, 0.020838667893962517, 0.034087515030536926, 0.03429212179335375, 0.09578655488909253, 8.964390716245099, 57.36153764109458, 50.62120337640086, 40.17602574440741, 23.73675850129897, 34.03870490289504, 50.06867085733722, 64.1846025374628, 51.39904468290268, 58.91401175529727, 25.494564771652225, 0.0502624158417025, 0.024965482035411463, 0.04578443274142281, 1.5648287222270043, 36.13965580540319, 54.86158363280758, 54.77271841418359, 56.93545841401624, 57.105814795340265, 57.74660456565119, 50.467313105060214, 43.57550082668182, 41.60930295144358, 47.20089658614128, 48.367209434509284, 53.337519245762984, 55.74244991425545, 53.775553857126546, 49.2565558802697, 50.643368690244614, 47.907868508369695, 50.44184515553136, 50.469093861118445, 53.22986979638377, 50.376851481776086, 41.464457665720296, 37.47427755786527, 37.95291262288248, 35.3170955565668, 37.449260680906235, 37.83882264168032, 36.59854565897296, 36.0485666028915, 37.60053473134195, 37.17644022357079, 37.6369264818007, 38.14481458356304, 37.553787923628285, 37.87198628148725, 38.228741538140085, 38.023805541376916, 36.43504165833996, 37.09420381053802, 37.34560028199227, 38.748483042563166, 40.50520673874886, 39.57647185171805, 38.89964334426388, 39.33380657626737, 40.43769490334296, 42.47183999707622, 41.47542069035192, 42.69304206294399, 43.08494175634077, 38.38586384250272, 39.88947306909869, 38.79064067717522, 40.28249848273493, 38.6011980425927, 38.40048643850511, 38.47603128802392, 41.07935936220231, 41.3255508484379, 41.42248046013617, 43.00885169736801, 45.29792339571061, 44.174070204457934, 42.20606803894043, 42.61698730530278, 41.1150372412897, 40.07623280248335, 40.859977276094504, 37.32282307840163, 38.71961832046509, 37.150780077903505, 38.5877953037139, 40.09527198729977, 39.10768193583335, 38.17212996944305, 41.4441397882277, 42.027596273729884, 39.8901516391385, 42.07564138597058, 40.753916386635076, 43.15833714700515, 41.470180403801706, 36.68948188904793, 38.764956997286895, 40.026603052693034, 37.91093149492818, 39.322388556695756, 37.10985406752556, 38.00475851182015, 37.60961501829086, 38.65956683312693, 36.823548501537694, 36.88076803761144, 37.18031552530105, 38.81750499048541, 37.776135321586366, 37.36727922193466, 37.9964352423145, 37.82962468362624, 37.55558829153738, 36.823293547476496, 38.01315238398891, 39.99007794164842, 39.7082870237289, 42.897825087270434, 46.42144318549864, 46.020439670931914, 47.624987171542266, 49.67988944822743, 50.49091792875721, 50.78449556904455, 49.7794117466096, 46.795088168113466, 41.817561195742705, 40.1987676466665, 38.10585760301159, 41.09631576845723, 40.928865863430886, 46.06004776493196, 42.437076030238984, 45.628434073540475, 46.20634040524883, 48.17795115132486, 44.377252901754076, 56.51140312994681, 56.38731502717542, 70.77395300711356, 43.21902405831122, 0.17208262256556944, 0.234559329767381, 0.09191430984966217, 0.1495502606755303, 28.521663758062548, 66.77943475784795, 58.84627634479154, 61.50131302495157, 44.3812733311807, 45.42683601379395, 29.193250017781413, 48.02021695721535, 61.42132413002753, 13.622257267275165, 0.17447117746116655, 0.07001321207010938, 0.02203888443839406, 0.029611659739466927, 0.01243448609696521, 0.019617678875464107, 0.034809296259716634, 0.034065876877115625, 0.010506845128181721, 0.03255088438069628, 0.05278407851414335, 0.0342623669383747, 0.019103484491126674, 0.03757395053042039, 0.035593597924396876, 0.01986768975433323, 0.01136037624335938, 0.055359585676342256, 0.10231003871247654, 11.40390492254688, 65.74823579480572, 57.8435145654986, 43.70644131014424, 29.32296476056499, 39.614754184599846, 54.62712787812757, 68.28038461746709, 54.72304551832138, 65.43272033814462, 27.793573794826386, 0.1136565592981154, 0.4419123952186877, 0.1250126253392908, 1.8008689918825704, 41.00949018232284, 56.436474092545055, 57.12652098747992, 57.716339557401604, 59.06019064687914, 58.45487871477681, 51.303091741377315, 44.71642417292441, 43.6948585510254, 47.98418606481245, 51.48160273028959, 53.96516907599665, 58.06491274987498, 54.55007683846259, 50.99294993185228, 52.851772923623365, 51.51888878114762, 53.355864171058904, 52.85213378167922, 53.53615199365924, 52.69320326466715, 44.31591879936957, 39.05192936620405, 38.97454100270426, 38.31767735942718, 39.85351670172907, 38.90878246676537, 38.91643108860139, 38.762085822320756, 38.598942679743615, 38.503221158058416, 39.62522691295993, 39.82060409361317, 39.98556329358009, 39.510011211518325, 40.26051752028927, 40.20166627822384, 38.276806262231645, 38.74789076466715, 38.576620471092966, 41.10988324688327, 41.992887220075055, 41.62417657913701, 41.3842922641385, 41.41269414655624, 41.272132089061124, 44.67194449517035, 43.30023281035885, 46.02813536121, 42.382288363672075, 40.5832540604376, 40.888755706048784, 41.24802912435224, 41.96218682873634, 40.21763816956551, 40.02235120342624, 39.68600796115014, 43.20534675352035, 43.058293173390055, 42.46351672757057, 42.71168116600283, 47.226282165896514, 45.53957277728666, 43.87331462675526, 45.582636479408514, 43.833102487748675, 42.35810302918957, 42.28924974318474, 41.17189591930759, 40.67015417160527, 40.09317744162775, 39.17759818415488, 41.28469151835288, 40.112569639759684, 39.23082082502304, 42.546055163106615, 43.58423594505557, 41.986199578931256, 42.77403116226197, 42.830948675832445, 46.43415558722712, 42.45986107856997, 40.108360936564786, 40.866790433083814, 41.04252438391409, 39.9126228978557, 40.78354204854658, 40.052467161609286, 39.6782495129493, 39.926657138332246, 40.771708257736705, 38.86837028688, 40.83741972523351, 39.28467496748894, 40.05431852033062, 39.54550473920761, 40.72586359516267, 39.88056536643736, 40.51823293009112, 38.88067083974039, 39.276410533535866, 41.10464296033306, 41.23419492475448, 43.92059487681235, 45.68339432439497, 49.53241617448869, 48.60099446388983, 50.35092461493708, 52.81641667889011, 52.71090884362498, 54.12073419940088, 50.813175939744525, 47.722242339964836, 43.243350598119925, 41.71933720188756, 39.63915524944183, 43.86717219506541, 43.991523096638346, 49.84941036470475, 46.054689807276574, 46.866757715902025, 48.74039942218412, 50.90657149591754, 48.62082988985124, 58.965328124261674, 59.48138260072278, 73.29783347345167, 44.39166761213734, 0.23693188874711915, 0.48861991794359305, 0.12346503580169332, 0.11758485133008612, 31.744581191770493, 74.3305778503418, 64.55843187147572, 67.40875551777502, 47.21563293087868, 42.097661572117964, 33.13719126486009, 52.43895130772745, 70.85352220842915, 19.072562225403328, 0.2042993470545738, 0.06543644959287298, 0.06308033852086914, 0.043756869967065515, 0.04554332188901402, 0.0494066764780831, 0.018736873114962253, 0.03220743567292248, 0.12364007923151217, 0.15837485811883406, 0.1765923523494313, 0.1328496052132499, 0.08898957767674039, 0.20583314700953423, 0.13505290472699752, 0.12970406351791275, 0.2062864259125725, 0.26593231566009984, 0.1781719490405052, 12.697410429677657, 74.86383192000851, 65.45528573374595, 53.09338308149769, 33.731465647297526, 47.47064190526163, 62.575152074137044, 72.97292001785772, 61.56578110110376, 71.48495320350894, 31.107955017397483, 0.17901423206973463, 0.373178526999489, 0.1791586396434615, 2.2588868535334066, 42.80842642630301, 58.30171015954787, 59.15238595777943, 60.75241488795127, 60.876071530003706, 60.53700616282802, 54.55743912727603, 48.20154420791134, 45.993057604758974, 52.84046473041658, 53.897163021949034, 57.58818787913169, 62.17371709885136, 57.2088280031758, 53.7714236013351, 55.82027758321455, 54.734906765722464, 55.86764412541544, 55.165331978951734, 55.73860599148659, 54.98453817059917, 46.53735314646075, 41.15363728615546, 42.099136383302756, 40.040276435113725, 41.1072866378292, 41.437338398348906, 41.81209341172249, 41.370305092104026, 41.77172045553885, 42.39955071480044, 41.601450366358605, 43.737043642228656, 41.72032956154116, 41.226118764569684, 41.81704736525013, 41.68757384823215, 41.29301086548836, 40.63862223779002, 39.716496544499556, 42.83988775745515, 44.19484699926069, 42.88988228767149, 43.47557060180172, 46.00060816734068, 42.37589097792103, 46.87803453014743, 44.74884256239861, 46.995336932520715, 45.552736251584946, 44.1495632356213, 43.8492077396762, 43.09733252371512, 44.093842044953384, 44.41606083223897, 42.76669240766957, 43.23535680770875, 46.83781846877068, 46.078094590094786, 44.919246012164706, 46.25583679445329, 50.23981563506588, 47.68916106993153, 47.0633625984192, 47.60727767021426, 45.22894851623043, 45.12411925100511, 44.684366641506074, 42.94071620510471, 41.8200126771004, 42.68314200062906, 41.50443838488671, 43.99473944017964, 43.35791126374276, 40.39781616580102, 45.68759910521969, 44.76650499528454, 42.373035492435584, 44.515869463643725, 43.79704413875457, 48.3464365620767, 45.00567151654152, 41.11690821186189, 43.11658351652084, 43.120886356599875, 41.17456705339494, 43.810195845942346, 41.43968789808212, 41.02322240029612, 41.98355982380529, 41.721145414537006, 40.36489963531494, 42.57033071210308, 40.63550003113286, 43.237388595458, 43.04527874915831, 43.20993200425179, 43.296765435126524, 43.51150735732048, 39.98041714391401, 41.98862752606792, 42.38779144902384, 43.99792048238939, 45.25208657787692, 47.67353042479485, 50.76483272737073, 51.6665267944336, 53.0478012177252, 54.07763911831764, 55.16322958853937, 56.078145965453125, 54.57096738200034, 51.4489568433454, 46.2714203711479, 44.57006092994444, 41.92188055284562, 45.77877459987518, 45.128088689619496, 51.29521169970113, 47.3460635062187, 48.47541193808279, 52.72772796692387, 53.53910161602882, 49.73028406020134, 62.649273103283306, 62.366705556069654, 77.99266738276329, 47.491669731755415, 0.5558143784442257, 0.7677490480484501, 0.8448416403224392, 0.4458927735686303, 36.53277143355339, 79.22018097292992, 70.67209689847886, 73.72850187363164, 58.14874164519772, 57.754119826901345, 42.85196081284554, 62.381536037691184, 79.06036792262908, 24.722624671074655, 0.3719184042945985, 0.15035551101449998, 0.163658014949291, 0.1909928134973011, 0.13123941097048022, 0.1289937161510029, 0.17836152515824766, 0.14741898874842352], [0.045617494521842855, 0.0188998181012369, 0.0695903008923896, 0.015009010751401226, 0.023326151553661596, 0.032787586397100846, 0.006018861228855508, 0.0804878403282454, 0.03694883810596601, 0.08344831050283487, 0.207338908146466, 5.524565721711805, 52.55015834685295, 52.20909257088938, 33.85548314740581, 19.992254088001868, 40.18181124041158, 46.663359288246404, 63.15168557628509, 53.58231044584706, 60.856624418689364, 33.62596957914291, 0.1953570631843421, 0.6027579175368433, 0.5255254069643637, 0.05380639986645791, 11.884019701711594, 52.95919095316241, 50.34919484969109, 55.68859577178956, 54.006161766667525, 54.92358061575121, 45.45136259448144, 42.62720507960166, 42.746072507673695, 48.129203934823316, 53.68395866886262, 52.065761320052616, 52.95892423199069, 52.70453499209497, 49.58722737527663, 51.30973231407904, 51.25969071542063, 51.84765792662098, 48.71235839782223, 47.91998470983198, 41.345366662548436, 37.614647419221946, 37.540522467705514, 36.86354098781463, 36.65985230476626, 37.03656458085583, 35.13975343396587, 36.68361794564032, 36.14750839048816, 37.75703337884719, 35.82888641665059, 36.040588501961004, 38.2041992679719, 38.437862703877116, 38.41667013783609, 37.8519312027962, 36.95019006729126, 37.182174728762725, 35.71416101148052, 38.106277296620036, 37.836218187885905, 39.06997619136688, 40.888077136008974, 40.32904917193998, 37.88139212516047, 42.97464862946541, 45.139447873638524, 40.96584596941548, 43.59579124758321, 42.96533300030617, 39.09139233250772, 40.33731752826322, 40.07162401753087, 39.48169562124437, 37.772126659270256, 38.67611139051376, 37.21939017695766, 40.30915098805582, 41.50172410472747, 41.38368429676179, 44.839751335882376, 46.48154958601921, 44.251548782471694, 41.60967949898013, 42.20082383002005, 42.15412016837828, 41.52859234040783, 39.702807472598174, 39.89438387655443, 37.27420922248594, 38.64131604471515, 38.634349915289114, 39.2429684054467, 38.860160766109345, 38.73314265281924, 41.92277877561508, 41.20159218388219, 41.437236416724424, 41.834945140346406, 40.57923363101098, 42.41325939855268, 42.52047738721294, 38.19890406823928, 38.9995696467738, 39.871732188809304, 37.34005012819844, 39.051046832915276, 37.54931642163185, 39.706317993902395, 38.09257645760813, 39.25021694552514, 39.381918368800996, 38.839905646539506, 38.49150111598354, 37.33375864644205, 37.2741582316737, 38.19487971644248, 36.41247234036846, 35.84389732730004, 37.734989658478774, 36.80136357584308, 38.37912521054668, 39.92033819998465, 41.07950841226886, 44.12944147663732, 45.61052453133368, 48.298552267013065, 46.95872552933232, 51.37875033963112, 51.3704780609377, 53.739189563259, 53.93131509903939, 55.71021979854953, 51.64783277819234, 51.459178540014456, 45.427691090491514, 42.70899042006462, 42.11473564947806, 41.187499107853064, 42.07664943510487, 43.173018578560125, 43.26816351183, 49.75594420586863, 46.36924036087529, 60.00254400314824, 56.038071109402566, 71.46027365038472, 34.045208192640736, 0.09207295899790141, 0.2109684029053296, 0.26115253988292914, 0.03780426337353645, 36.29432270603795, 65.20542683139925, 59.12669835552093, 62.33333795301376, 49.59547611974901, 27.568312075830278, 20.270640388611827, 49.775132440751605, 48.635880024202415, 7.551333327447215, 0.25056299843615104, 0.15950365803174435, 0.06181296096333574, 0.10838307049726287, 0.060981644482742396, 0.042478813143867644, 0.06282101009762095, 0.022710360504025896, 0.07666461725508975, 0.031172929692172238, 0.07906656336760329, 0.021236518420459285, 0.032724468413019375, 0.00958463997625175, 0.10449284537424965, 0.03692009448704701, 0.02210698199398335, 0.047645202852905764, 0.18544144928455356, 7.151392284900912, 61.09639890732304, 59.545187796315844, 39.78691485620315, 21.723878537454915, 42.95732744278447, 54.040710003145286, 67.2638160951676, 59.004971519593276, 64.99349332624867, 35.986832418749415, 0.15151568988878883, 0.340656868873104, 2.2781280404137028, 0.06214060144679201, 13.460651693805573, 56.04920671832178, 52.5457731370003, 58.14335230858096, 56.785996498600134, 58.0003309249878, 47.329471880389804, 45.46831507836619, 44.764681093154415, 51.2936858977041, 55.28055552513369, 55.647120629587484, 53.847184181213386, 53.84406197455622, 53.34774094243204, 51.93703305336737, 52.67106148504442, 53.1200042078572, 51.931910437922326, 49.46923463575302, 44.03731676840013, 38.91891394892047, 39.776614712130645, 38.97667084970782, 39.25878340198148, 39.67578626448108, 39.45953815214096, 40.2287620113742, 37.98621354564544, 40.57987689971924, 37.29876718213482, 40.04768579236923, 40.546776017835064, 40.06652493630686, 39.03756172426286, 40.14236396358859, 39.17081248375678, 39.378407847496774, 37.70345772466352, 38.68081431235037, 39.94617092993952, 41.23082953114664, 41.57543328500564, 42.126859695680686, 40.6396028303331, 44.922831058502204, 47.04342519083331, 42.11355109368601, 43.630719953967684, 45.063087171123875, 39.83606607683244, 41.53087123747795, 40.80578973216396, 41.33931052300238, 39.06914857126052, 41.75321863543603, 39.58483042255525, 42.68451875255954, 41.49821750579342, 44.15876903841573, 45.00258853358608, 46.33873216567501, 45.82348961983958, 43.108409297081735, 44.24985824092742, 43.99718307679699, 43.82485766564646, 41.74617013623638, 42.37693432838687, 39.717943899093136, 39.61253020071214, 41.86913251876831, 40.04719941846786, 39.62635655556956, 41.96286539877615, 42.23576822588521, 41.99750777213804, 43.47097750632994, 44.64617060076806, 44.631932397042554, 44.757848324314246, 44.608311883864864, 40.81212043762207, 40.47180775673159, 40.595566380408506, 40.90278602415516, 40.526038446734034, 39.91030085471369, 39.70990696261006, 40.01103124310894, 40.67887360049833, 40.31549346062445, 41.326111747372536, 38.89571705172139, 39.10464994369015, 40.917906761169434, 39.38074558011947, 38.183351870506044, 39.80054117018177, 40.100818218723425, 40.891195420295965, 41.96461869824318, 44.06076469729024, 43.95974797587241, 46.07986750141267, 47.623900675004535, 49.11664101385301, 49.70060348510743, 54.57255594192013, 52.7030288019488, 56.64909793484596, 56.08991699834024, 56.631961099563114, 54.96559704503706, 51.71348541013656, 46.9015020708884, 44.48813830652545, 43.61950197527486, 44.00325098345357, 43.5985839751459, 44.8607320939341, 44.65410163325649, 52.11747384840443, 48.435992117851015, 63.60603724756549, 60.052699350541644, 72.3660901284987, 36.7327848557503, 0.007710166467023233, 0.9258507192134858, 0.18406711819191135, 0.02215341075263437, 39.414081804213986, 73.56037339856549, 63.77891571291032, 67.87215217467278, 57.89822770703224, 40.541696548461914, 28.81951285946754, 55.39298242138278, 57.61351070096416, 10.043908376847545, 0.3315957341222994, 0.15623803971515549, 0.10226835586851644, 0.017410027982306578, 0.10249488040684693, 0.06817410309468547, 0.05148042286295564, 0.04166589043433628, 0.1346514133676406, 0.12853369567423098, 0.16965953242634574, 0.10229373636144785, 0.12630189768970013, 0.18884615852467476, 0.20990924038473638, 0.1767191399008997, 0.14605591914826824, 0.0902653668796824, 0.35090798331845197, 8.386482423351657, 69.98791786932176, 64.26899233172017, 47.26889479544855, 29.351272506098596, 54.633458583585686, 58.81152414506482, 71.6047659227925, 65.43612495545419, 70.89464433731573, 42.183035881288596, 0.3201186644934839, 1.4784920840494096, 2.943215423053311, 0.1904585437789079, 14.80532353924167, 60.840432874618045, 52.45701774474114, 59.163980484008796, 58.36923768443447, 59.43926026744228, 49.571890907902876, 47.31655551541237, 47.53580816330449, 52.197015593128825, 58.405966758728034, 56.58766577320715, 56.34130562505415, 57.24934216468566, 55.537957145321755, 54.783987383688654, 55.5297044784792, 54.82677651989845, 53.208265381474654, 51.595406378469164, 45.80210878003029, 41.48776831165437, 41.743381331043864, 41.00448131561279, 42.91045119685512, 42.555900312239125, 40.998362418143984, 42.25997317221857, 39.88042416111116, 44.271341062361195, 38.48813180000552, 41.31720796708138, 42.73192059609198, 41.93712288333524, 41.69874868085308, 41.57912423533779, 40.874846981417754, 41.942625968687, 39.641104667417466, 41.10958514675018, 40.95496139218731, 42.55762223274478, 44.38852579362931, 44.34627402213312, 42.65748969970211, 46.804137076101, 49.7113468570094, 46.08586088303597, 47.39945480900426, 46.75526826612411, 41.69677180628623, 44.891456019493845, 43.66002790389523, 43.5128370408089, 41.32003991834579, 43.36460282725673, 42.63622653099799, 44.497042086816606, 44.96045835556523, 45.05528557685114, 49.10849425100511, 50.90582232321463, 47.59561646369196, 46.20059805531656, 46.9078641553079, 46.82771052083662, 46.263810973013605, 43.55926221416843, 43.9245839272776, 40.52899983621413, 44.22056990285074, 44.15528597370271, 42.58878154139365, 43.20928481317336, 44.01191157679404, 43.608025120150664, 42.61238244272048, 44.203660565037886, 46.402207882173606, 45.68023289403608, 46.610583797577895, 45.86862433341242, 44.87282083880517, 42.24107911509853, 44.34219867952409, 42.792705566652366, 43.15619161052089, 42.280098853572724, 42.26310322361608, 42.81706740779262, 42.12575358729209, 42.78306438076881, 44.020336827924176, 40.691111395435954, 41.659250413217855, 41.78044772917225, 41.17180570479363, 39.776006744753936, 41.37696919902679, 42.78155426825247, 42.347132159817605, 42.743628871056345, 46.32013620868806, 45.76801946086269, 51.142658956589244, 49.56887068287019, 51.791975959654785, 51.29513325229768, 56.849911520558024, 57.626627106820386, 59.13118554699806, 59.502681070758456, 59.466187338675226, 56.83899948673864, 56.068324350541644, 51.466007386484456, 48.38613487059071, 47.31218599504041, 46.934112656501036, 46.74105751898981, 47.55742826769429, 48.08899571818691, 54.07507388822494, 50.909085735198, 67.30675820381411, 62.51422589825046, 74.95920042837821, 38.00022817427112, 0.16239626813800107, 1.6416707731062368, 1.089297600330845, 0.10111468874158398, 44.3771352306489, 78.47057680929862, 70.22102432866251, 74.1382012828704, 64.07977719460764, 40.63164041888329, 34.29701651296308, 64.18902304864699, 68.24033721800774, 14.900919545081356, 0.40264401524778337, 0.5128306252581458, 0.17109933339299696, 0.16220056331686436, 0.25789203903367447, 0.1796640431688678, 0.16651399073100862, 0.2055376209318638], [0.024617590017676837, 0.020148549078693314, 0.14363475955061375, 0.018892304693919518, 0.033451018539527734, 0.0621707929718879, 0.007595136449972709, 0.05548324758907961, 0.07068526270168443, 0.039208785991274545, 0.04625686767300771, 3.5712577354523445, 48.64645865655715, 52.38598754329067, 44.78588934867613, 26.908424285150346, 33.78120130108249, 46.867381372759425, 59.72752309614613, 55.58512364664386, 55.19029786509853, 47.19165155964513, 0.6283650499197745, 0.46563672863187333, 1.745532193491536, 0.0917540442559027, 1.7502335218652603, 43.207158888539965, 54.41182897936914, 54.632552516075876, 55.20656001183295, 51.35569072538807, 45.716879598556034, 41.87954641157582, 46.477215366978804, 53.27746383605465, 54.058701915125695, 53.75607536685083, 52.4217438697815, 50.056335003145286, 50.66566344230406, 49.45416881192116, 47.09707144768008, 48.51314513914047, 44.821335807923354, 41.86308814633278, 37.53256005625571, 37.75816302145682, 37.12281750094506, 35.96564769744873, 37.40959767372378, 37.57843217542095, 36.17956199953633, 37.71594655129218, 37.1003697764489, 36.55791774872811, 35.863642538747484, 35.40338377798758, 37.35370389876827, 38.93602332761211, 36.427722515598425, 38.98256224970664, 38.09900522232056, 36.952994561964466, 38.58011922528667, 38.4463938590019, 38.441486973916334, 38.399619594697036, 40.85862013601488, 39.71469617659046, 37.27920632208548, 43.08396116379769, 44.8446072301557, 43.50639650898595, 42.782158313259, 41.55113027941796, 42.52523914460213, 38.14537156012751, 39.86229104380454, 39.45277990833406, 36.3608225699394, 37.710404242238695, 38.25611575957268, 38.50729650066745, 39.71057376553936, 41.3894776375063, 43.40427760154971, 43.87506792622228, 43.85533055951519, 41.55296594865861, 42.12656551791776, 41.63505723399501, 42.147526664118615, 41.070530106944425, 39.18686674487206, 37.90687968654018, 37.66395553465813, 37.98332668119861, 39.225439333146625, 39.63936705743113, 38.81797959727626, 39.57462833773705, 42.218054802187034, 42.83583987143732, 42.89062753800423, 41.682874848765714, 42.46899627870129, 43.05548475634667, 38.38378106394122, 37.39383759037141, 39.27543386336296, 38.558546189338934, 38.173647926699736, 38.39941955381824, 36.939646736268074, 36.71296511926959, 35.866392120238274, 36.276809323218565, 38.4751565994755, 38.20782353801113, 38.00498993166032, 38.670023872006325, 36.754016645493046, 37.68774078738305, 36.525189492010306, 36.12643349555231, 36.33618224051691, 37.3711976697368, 39.22414887335993, 42.48092028402513, 43.95473518679219, 48.26947181455551, 49.65188372519709, 47.4075819600013, 48.66201085429038, 49.722576602812744, 52.239302665956565, 51.87008603926628, 53.437194516581876, 55.0065662014869, 54.58881024391421, 50.84856748580933, 54.144295877025975, 53.96323926987187, 55.73222037284605, 48.128078214583866, 44.48742443515409, 42.795741481165734, 47.53908334239837, 46.83673981697329, 59.47354570511849, 56.67723309609198, 74.07926374866118, 22.70238437960225, 0.03298866532502636, 0.16289272375645178, 0.20810046083023473, 0.0990753703480286, 41.56549792135916, 62.294910492435584, 58.77275151591147, 58.84901023680165, 42.62622056468841, 27.89264894300892, 30.887413870903757, 45.830534196669056, 55.24123376415622, 6.137763579045573, 0.33732843134672413, 0.054080203521035375, 0.09584021934818837, 0.07620926991465592, 0.03120756452722896, 0.060466304796958165, 0.04340576421048853, 0.03121273179027823, 0.02181569812819362, 0.027260543560729395, 0.004814915272647575, 0.00997251124992486, 0.036463069414059, 0.04159205871063375, 0.05786156371956872, 0.077372390566574, 0.037132829442740455, 0.06702040532423605, 0.08133015400099178, 3.9927862776863963, 54.88394114278979, 59.18485141569569, 50.12972647143949, 28.972742211434152, 42.29807115370228, 53.45233486544702, 63.902595889183786, 60.17130397981214, 60.4060931359568, 50.276980092448575, 0.44260686924380643, 0.4707374339622836, 2.1936379805687936, 0.1891246468069092, 2.5906014538580373, 46.16758346557618, 54.5483470732166, 56.10216656038838, 57.93691796641196, 54.0706455323004, 47.96435848359139, 43.95539806735131, 47.37028806440292, 56.33933659522765, 54.41905790759672, 53.83432665178853, 55.42805625546364, 52.673489432181086, 52.095230087157226, 52.062482218588556, 49.37362294043265, 50.62288215083461, 48.69160513724051, 43.91885334445585, 40.50443795419509, 39.67500179044662, 38.286274863827614, 36.845882477298865, 39.793943743551935, 38.97050096142677, 39.132734114123934, 40.04706213551183, 39.52184107995803, 38.890927837740996, 38.24762775051979, 38.13653838249945, 40.14229728329567, 40.550466968167214, 38.71325231367542, 39.50406882070726, 37.79016171732257, 38.9027577061807, 40.189338268772254, 40.909665861437404, 40.840204608055856, 40.920432767560406, 43.50352533401982, 40.68102698172293, 41.34241311780868, 43.20160481237596, 47.17451080199211, 44.69283896107828, 44.12446006651848, 42.81082691684846, 43.08016038710072, 39.5957620682255, 41.435914577976355, 40.986540394444624, 39.09571478443761, 39.78633434541764, 40.012553122735795, 39.91208161077192, 41.49034923122775, 43.24558242674797, 44.84093981404459, 46.74318344362321, 45.71260813743838, 44.72245677824944, 42.407705322388686, 44.283837733730195, 44.910408912166474, 41.9962251570917, 41.748213691096154, 41.86158587855678, 39.78842104634931, 39.60161032215242, 41.88904639213316, 42.328128276332734, 39.84785279920025, 42.067957462803015, 41.772246053141934, 43.00749847965856, 44.13500339754167, 43.451424491020944, 44.401912843027425, 43.96083447241014, 40.90792432908089, 38.324463059825284, 40.677222282655784, 40.601861784535075, 40.107882407403764, 38.71312287545974, 39.50212724747197, 39.69772015848468, 37.806463087758715, 40.076750555346095, 39.87113206617294, 40.06236722392421, 40.007254000633, 39.71825768870693, 38.35759924304101, 40.26587940031483, 39.08583825634372, 38.69069476281443, 39.01201532733056, 39.393689401688114, 41.62484730443647, 44.0743439428268, 46.42546753729544, 49.930152354701875, 50.69932522312288, 49.44291160952661, 51.9552916865195, 51.31985987386396, 54.319402248628684, 54.660617074658795, 56.07531009181854, 57.59172585702712, 56.619217318873254, 53.07046075021067, 56.820670250923406, 55.37153097891039, 56.708121761198974, 49.54045311097176, 48.36782916899651, 44.72029555228449, 50.33937323477961, 48.26913056835052, 63.15737693540512, 60.245326949704086, 76.041013656124, 25.099176129987164, 0.0659021927464393, 1.0962942506997817, 0.24539765060668994, 0.1399904180077776, 45.54807255345006, 69.16931921435942, 64.91248853745, 63.63662781253938, 52.10518506265456, 32.13505706479473, 31.262378731081565, 55.50992004333004, 63.8487692033091, 8.84560859972431, 0.3334472767047344, 0.12084886852291324, 0.05807122283224618, 0.1069482874065157, 0.07604304415684554, 0.11075402835323928, 0.020196017801701542, 0.05601631837987131, 0.17690778139137453, 0.13994619941278813, 0.15066237519344977, 0.15072232923440396, 0.10197389465306075, 0.1579001440756744, 0.13463999865756882, 0.23077554490056731, 0.13540538178095896, 0.24405750235722912, 0.156486083663279, 4.779109464537713, 64.3246272302443, 68.04927072217389, 58.626556934848914, 38.797508747346946, 46.92741717061689, 59.368688983301965, 69.38315899141374, 67.43851061790221, 65.60736779243716, 57.35363406519736, 0.7655873317872325, 1.7021976026796526, 7.6286775642825715, 0.17658432374798483, 2.720534868778721, 48.09717385999618, 58.181599340131214, 57.96562187133297, 60.821487826685754, 55.896783413425574, 51.06171692571333, 46.303442601234686, 50.542261754312825, 58.49343561357068, 58.10579169181086, 56.160099967833496, 57.40154189448203, 55.82628273194837, 55.4084522493424, 54.29101213332146, 51.00941996420584, 54.7552050313642, 50.033765685173776, 45.76498354634931, 41.696332500826934, 43.068510947688935, 40.30972757647115, 40.12983591325822, 40.81242246012534, 41.865363121032715, 41.16065440639373, 41.623843177672356, 42.22543278048116, 41.339279144041, 42.15835240579421, 39.71632788258214, 42.60128213513283, 43.19274025578653, 39.03753819004182, 42.3547415579519, 40.95536147394488, 41.31334443246165, 43.34802296853835, 41.67535958751556, 43.81751891105406, 44.14528785213348, 46.24868631362916, 44.04441233604185, 41.96699173219743, 45.62509613652384, 49.367743307544345, 47.8062516643155, 45.64690059231174, 44.971252718279445, 46.16056242296773, 41.25638377281928, 44.92061491935484, 43.087193196819676, 39.66455259630757, 42.67801154044367, 42.73463487625123, 42.177528873566665, 44.38756873530727, 45.782257664588194, 46.69808403138192, 47.76504324328515, 48.064841762665786, 46.10304478676089, 45.49382225159676, 47.59946823120118, 48.14244977889523, 45.42251356186406, 44.890812750785585, 43.23770630744196, 41.42756385187949, 41.77377969987931, 43.11424970626832, 43.91848071928948, 41.93952729625087, 43.88288913234588, 44.176294188345636, 44.787674027104536, 46.87000936077487, 46.02574663777506, 46.150513310586255, 47.30318415549494, 43.07268827192245, 41.29342663672663, 43.525553364907545, 43.34018607293406, 42.01938675295922, 42.29684737420852, 41.75955326326432, 39.87760789932744, 40.05294176840013, 41.76779416299636, 43.717631832245864, 41.22169825338548, 42.4519653474131, 42.37567132519138, 40.55663685644827, 42.290489212159194, 41.78806497204689, 42.35745583811114, 41.81432131798037, 41.644023772208925, 43.72628850321616, 47.19924134592856, 48.925162669151064, 54.35728057738274, 54.16776341776694, 51.909074398779104, 53.52656964332827, 53.547338593390684, 57.70276815660539, 57.286734119538345, 58.320109998026204, 61.47018901763424, 59.795046698662546, 55.16815216310563, 60.15657155744491, 58.22851088739211, 60.43321240332819, 54.322238122263265, 50.67610479170277, 47.53088166636806, 53.28181374457575, 50.08760021578882, 65.13578907135995, 63.071716293211914, 80.41824540784283, 26.740054584318592, 0.16773789279883908, 1.5968671320907533, 0.8189376948341247, 0.30638034846032824, 49.971050908488614, 73.49133183879238, 70.03924600539669, 70.47743751156715, 57.70563148683118, 40.01680889437276, 45.17480804074196, 62.45450781237695, 76.60542703443959, 12.89866332084902, 0.5496952971143108, 0.3660102422919966, 0.23540561177557517, 0.19031746102677238, 0.21380965447714254, 0.20560635434043026, 0.18031080523806234, 0.1525677584352032], [0.04273043855303719, 0.028059337693717212, 0.022252268653603333, 0.0689568993965945, 0.026305452169429873, 0.004921605943837354, 0.03136738387477254, 0.10299462254249281, 0.05325297411951808, 0.03831885995403413, 0.03656146191661397, 0.7075456914401824, 38.86279267649497, 56.90352639844341, 43.69191677339616, 27.309286594390873, 35.768368167261926, 44.96181549564485, 57.1667056698953, 62.97825405674597, 51.435809058527795, 57.00136600002166, 3.9586780821123435, 0.23717357416547116, 1.6723031358372782, 0.2570386936948184, 0.7160800947777687, 33.2094923142464, 56.912842027602665, 54.291910356090916, 56.83866216290382, 50.00685822579169, 44.61994171142579, 42.942265541322776, 50.802726745605476, 50.90155870683732, 55.61183106514716, 53.81003933568155, 51.44655243042977, 48.30827190030006, 47.206725228217344, 44.293020002303585, 42.99033811015468, 41.41500834495791, 39.20856529666532, 37.07585104050175, 36.754910945892334, 37.15295307097897, 37.57062665877804, 36.54035729746665, 37.093019254745975, 36.128531963594504, 37.94708005843624, 37.829620761256066, 37.76872988670103, 36.255899167829945, 36.806023351607784, 36.8217206770374, 38.21748825811571, 37.4007527289852, 37.9825500519045, 37.38090945828346, 37.8136763265056, 36.61446655950239, 38.22827085371941, 38.30878142387637, 38.713526879587484, 38.98648854224913, 40.29123752347885, 39.26955423047466, 39.36094153311945, 42.13407293442757, 44.66560986734206, 43.276192603572724, 41.52918854067403, 43.36744262326149, 37.83681831052227, 38.95428980550459, 39.68508228178948, 39.530125125761955, 37.57557276756533, 37.126049533967056, 37.374770948963786, 37.85446505392752, 43.03671229270197, 43.91647638813142, 42.118234403671764, 42.91105524186165, 43.98099937746602, 41.20306699506698, 44.75521641392862, 44.92410190643803, 43.43835907597696, 39.81341046671714, 39.184097551530414, 37.37816772153301, 38.557977445663944, 38.25493512615081, 39.24921281876103, 39.86059265751993, 39.67042438445553, 39.29526536695419, 42.26758649272304, 43.90970637721401, 41.81796127750028, 42.019641707020426, 43.08060753730036, 41.56610196636569, 38.43638004795198, 39.572000349721606, 39.20751410145914, 38.85202184800179, 40.1581044350901, 37.75758643304148, 40.044037988108975, 37.84796960892216, 38.346479323602495, 36.514281380561094, 38.27376250297793, 39.20621187456193, 37.881843197730284, 36.159020546943914, 38.223289443600564, 37.559879364505896, 37.53475658355221, 36.039996224064986, 36.551861609182055, 36.66060147746917, 38.970336221879535, 41.07053795168477, 43.43341296718967, 41.547215753985995, 45.7662465495448, 46.188756419766335, 50.308339441976244, 49.2597290777391, 50.737105492622625, 50.7752505425484, 56.16671700631419, 53.30965472805885, 54.274863735322036, 52.205162355976725, 54.87861848646595, 51.384998675315614, 51.691586817464525, 54.722959226177586, 53.08064714554818, 44.211313109244074, 44.86997712043024, 47.58039766742338, 62.02621636852142, 58.50294736123855, 67.29753278916883, 12.665284256781302, 0.17768940557875942, 1.0802353317699125, 0.30381018476140115, 0.4016697965562344, 50.28941400589482, 60.28213839377127, 60.07584917929865, 54.85062060817596, 39.324294828599506, 45.43322947717483, 43.558089425486905, 49.115511371243386, 49.746573663526966, 2.5869737517449165, 0.07018181270048504, 0.06631986388275701, 0.040227843809031674, 0.05796224682501728, 0.026877899879529595, 0.06612540778493689, 0.03854084542141326, 0.026090332765072107, 0.06897466497555857, 0.038339218740621885, 0.04193166548746728, 0.07692550849770347, 0.055906323475703124, 0.011256987889928204, 0.029485973439389662, 0.03713122831897871, 0.002473500400458673, 0.0785058253114262, 0.04049846053784413, 1.0449608439399352, 45.005091005756015, 61.31686748996858, 51.10746352903305, 31.092640123059674, 41.87327454167028, 52.5784739371269, 61.10146660958568, 66.86680163106611, 56.0382083923586, 60.37951907803936, 3.9620523010530784, 0.37929347145461273, 1.9746320742753245, 1.114912516167087, 0.5686967904048582, 36.601565884005645, 57.50225267102642, 56.7380416008734, 58.215598444784845, 52.28042087247295, 46.99097133451893, 45.7902475326292, 51.576202454105506, 53.86754128240771, 57.42425241777974, 53.564345990457845, 53.698004676449685, 51.78489608149375, 49.70330207578598, 46.01906291900143, 45.871326846461145, 42.941908605637096, 41.889732806913315, 39.34786435096495, 37.76437213343959, 39.17600962423509, 39.34475783378848, 39.150451460192286, 38.70161856374433, 38.677280256825114, 39.34456563765003, 39.036996902958045, 38.97472143173218, 38.161763145077614, 37.989790747242594, 39.548721082748905, 39.1168563596664, 39.443887895153416, 39.734704186839444, 39.03776960988199, 40.562351749789336, 38.04449604403588, 39.69031472359934, 40.59059673740018, 39.69589625635455, 42.339569830125384, 41.287405798512125, 40.20453745318998, 40.01443586041851, 44.25125068233859, 46.42901335993121, 44.16444470805507, 44.756444115792554, 44.59788230157668, 39.635024993650376, 40.70157627905569, 41.367543743502715, 41.6868717439713, 40.275571577010616, 38.917533274619814, 38.65951584231469, 41.12409399401757, 44.68283691713887, 44.581690757505356, 44.65413301221786, 44.25505145903557, 45.80966718735234, 42.84230001511113, 46.00994733072097, 45.24940367667906, 45.05597983637164, 41.666789208689046, 41.286742917953, 39.29435929944439, 40.94908960403935, 40.12733344108828, 40.027473818871286, 41.92868978746476, 40.46404538616058, 41.62940117620653, 42.916581861434445, 45.26093544498567, 44.579211819556456, 43.209869246329035, 44.221236705780036, 43.30786966508435, 40.83741580286334, 41.85447462143437, 40.50956056964013, 40.303420405234064, 41.61280170563729, 39.430963685435636, 41.5637916903342, 40.92552400404408, 40.057319133512436, 38.50600211851059, 40.87481560245637, 39.38469148451282, 41.01189851760864, 39.95644361742082, 41.11141689362065, 39.53143519739951, 38.848907486084975, 39.89729819759246, 38.49825543742026, 39.13736643329744, 41.52265779433712, 42.9661919993739, 44.5966467549724, 43.71154431373843, 48.88846497381888, 49.236524335799686, 52.096320506065126, 51.40677959688249, 53.63713341374552, 52.903242265024495, 57.04906986605737, 56.60150781754525, 56.631713990242254, 54.10244810965754, 58.37345815473988, 52.99697514503233, 55.03312849229383, 58.08988255839194, 57.12510893421789, 45.64313511694632, 46.0865943662582, 50.18722449579547, 66.72407442523588, 62.02820893256896, 70.84601479191934, 14.100555008457555, 0.12216293147855228, 1.2944477339906078, 0.37143129494882404, 0.554295685743132, 55.7396375748419, 67.05563237590175, 65.17960979092506, 60.1000423585215, 45.284673629268525, 43.47799854893839, 49.23360217002131, 54.45874052663004, 60.54862030090825, 4.229226996821742, 0.20960626793244194, 0.10107594001437388, 0.06911508123119993, 0.053977961426660906, 0.04071781832364298, 0.049282937956553315, 0.07342484674506611, 0.028347497835995692, 0.14167591869350404, 0.10441845823680201, 0.12082186392358235, 0.2685791187949719, 0.07281784463914172, 0.06661113817244768, 0.1226741879157001, 0.19736070486326374, 0.12189496158351823, 0.2191588174431555, 0.2075141430982659, 1.1963661712023521, 50.21514784905219, 71.51150764957552, 56.53129739146079, 36.903898254517586, 48.218484924685576, 58.291778718271566, 67.03263159721129, 74.24994960907968, 59.592558260886904, 66.40811966311547, 5.008066056236144, 0.9272902903537598, 5.488270559618551, 1.5751403882618875, 1.4586111831088222, 40.06883128996819, 59.54431703013759, 58.573926571876775, 63.154050765498994, 55.18053116336946, 49.08442266525761, 48.40911995980048, 55.02125155541205, 55.18379457535283, 59.919950654429776, 57.56516748859037, 57.31605775894658, 54.87211911909042, 52.36130799016645, 49.038993773921845, 48.42067133995795, 45.3226343277962, 43.87001983581051, 40.13076551498906, 39.454191961596095, 40.267652311632716, 41.97205943446006, 39.94018539305657, 40.91703599499118, 39.94964614991219, 42.95628016994846, 41.71837622119535, 40.96989777780349, 39.12397153915898, 40.235351593263694, 41.83259564061319, 42.372286319732666, 40.86226401790496, 43.076783226382354, 40.361024333584695, 42.028412126725726, 40.19595922962312, 41.07771588910011, 41.78080466485793, 43.15247712596771, 43.60986863413165, 44.035810578253965, 42.003689427529615, 43.21558806204027, 46.62665374817387, 48.73833625547348, 46.41515954848259, 46.11098366398966, 46.965828941714385, 40.74339266746275, 43.99610442499961, 43.258487024614894, 44.881916815234774, 41.49697019207863, 39.744576792563166, 40.68794996507707, 42.34895606194773, 47.4318104405557, 48.40007889655329, 45.60653155849826, 47.6528516892464, 47.10981130599976, 46.3997995468878, 48.43400347617365, 49.04817996486541, 49.38374657784739, 43.22971643940095, 43.43546436678979, 41.9527849074333, 43.29875407680389, 43.91116157654793, 41.99850405416181, 43.81107837923112, 43.773827629704634, 41.989831693710826, 45.18670458947459, 47.205493603983236, 46.472598737285985, 46.03148898770733, 47.1918829794853, 45.765567979504986, 43.02116401733891, 43.71489401786558, 42.285998098311886, 43.265084451244725, 44.20098550858037, 41.4906120300293, 44.14047510393205, 41.72864890867665, 42.45386769694667, 39.64430924384825, 43.41512295507616, 43.54645567555582, 41.659552435721125, 42.77179148889358, 44.001309410218276, 42.42006078843148, 40.87767501031199, 41.39471007931618, 39.156535056329545, 41.505748456524266, 43.52012480458906, 47.16847427429692, 45.69143126087804, 46.070073343092396, 51.44755263482371, 50.27049641455374, 55.367588996887214, 54.58163230649887, 55.49294402522426, 54.908820736792784, 60.71801570154006, 58.609027862548835, 58.122857924430605, 56.8012466738301, 59.22924087893579, 56.40132573343093, 57.898062967485004, 60.38643029428298, 59.16427466177172, 48.47512952743038, 48.71859104402604, 51.9293922762717, 68.97891952145484, 64.48997082248812, 73.4897550459831, 16.230118620780207, 0.23710021358584207, 2.854848590589339, 0.5669664122885274, 0.7687348499894143, 61.705366488425966, 72.84662754304948, 72.66527283576228, 66.26532969936248, 53.493939445864775, 60.90410470962525, 60.944387451294936, 63.62440962945262, 72.13284246383175, 6.443714336041482, 0.35315032267282087, 0.24482814084377982, 0.18073333337182002, 0.20077491359364605, 0.24393270663436384, 0.14290467775877447, 0.33920464196032096, 0.09299791057503994], [0.09699360302258885, 0.052487395643707246, 0.060694461102567376, 0.024750444985505556, 0.02432580819473632, 0.02129761010198103, 0.05638098389270806, 0.03833454560428377, 0.06108710414639885, 0.03186652846183748, 0.05097747081890703, 0.2308318063977265, 27.070730001695697, 57.62292831174789, 48.84322435625138, 33.88362615339218, 30.18232272517297, 44.61291282407699, 53.07384183329921, 62.19556470071117, 51.01726470455047, 62.31408696020804, 11.859895163966764, 0.2980155569891776, 1.310317030837459, 1.1274036717030311, 0.3778739718179549, 28.482906818389896, 61.872027997047674, 51.634751673667665, 56.86530290111419, 44.4848866616526, 42.33646723531908, 44.26020545344199, 53.48523570645241, 54.50551871330508, 53.64247568192021, 51.64374959084296, 50.79576846091978, 47.293370385323804, 43.700267499493016, 40.416572939965036, 38.01978511195029, 35.22519050105926, 35.23467479213592, 36.308262809630364, 37.05278358151836, 37.925644305444536, 36.451433243290076, 35.274529995456824, 38.32876197753414, 37.62692836023147, 39.249279499053955, 38.16704657769973, 39.41122239635837, 37.882914004787324, 37.59193297355406, 37.833558820909076, 38.14321425653274, 38.43434041546237, 38.17867248289047, 37.49982395479756, 38.5534784870763, 38.6419750029041, 38.84223161205169, 38.137048290621856, 39.49813819700672, 38.75271920234927, 39.242521255247055, 37.485040541618105, 37.69378123744842, 42.24862575531006, 44.550790325287856, 44.23763613547049, 42.77291328676286, 42.53358594832882, 42.828650166911466, 38.362219795104, 39.882640300258515, 39.52583797516362, 37.20429297416441, 37.70912947193269, 36.89148395292221, 38.38190617099885, 42.16215318249118, 43.3069126067623, 44.450154073776744, 45.894409994925226, 42.672422162948116, 43.38998056227162, 44.65611380915488, 43.255953173483576, 43.03920692013156, 42.5693069734881, 40.04468910155758, 38.390013710145034, 39.72341168311335, 37.88056450505411, 38.33545746341829, 38.851762971570416, 38.78488656013243, 39.34879003032562, 41.69459881321077, 44.24915221429641, 41.147184987222, 41.45074505959788, 42.58245083593553, 41.04450910322128, 38.96357405570246, 37.80639640746578, 40.18442353894634, 39.022307626662716, 37.65702470656365, 37.3003988881265, 36.07911009942332, 38.30183098393102, 38.316241771944114, 38.16342623003068, 38.978129971411924, 38.09652236200149, 39.81835657550443, 37.18937227802892, 38.81966229408018, 37.21931957429455, 38.490598970843905, 37.28431717042, 36.516634802664484, 35.86088511251634, 38.76417252325243, 38.30978947301065, 38.86407136917114, 42.323633240115264, 44.54043919040311, 44.01362957492952, 46.95532091202275, 48.285722194179414, 48.22476856170162, 47.946699973075624, 53.68290355128627, 53.929624557495124, 55.35331156945998, 52.512735013038885, 49.84257367349441, 48.15053378382037, 51.88980771649269, 52.59633641089163, 57.99991123137936, 48.562092396520804, 43.4647919285682, 48.48069144833473, 60.41967630386353, 58.58587803379182, 61.44071240578929, 4.871082671226994, 0.16091728943490213, 0.3867828082894126, 0.40983819372711644, 1.1933878665008855, 51.90501474565076, 57.30194899343676, 63.40669847303822, 52.48671793168592, 34.193058013916016, 19.232424305331325, 27.929654544399632, 48.68314850714899, 41.79439959987518, 1.717608962808886, 0.16642684056874246, 0.07760803921208267, 0.06360141620520623, 0.008415965186882644, 0.10350119818242327, 0.013986021944982632, 0.027159569341869607, 0.03256573499510846, 0.01167772720838266, 0.06023993347621253, 0.0372356767465751, 0.025389099929241404, 0.10186156318072351, 0.041384395256999044, 0.025890732386840448, 0.03258483739750039, 0.12484284493351176, 0.03172867860074245, 0.04532441226465087, 0.36951772988803927, 34.66310308825585, 64.91017041667816, 54.11700794773718, 34.5831298828125, 34.434891746890166, 50.609565704099595, 58.43909509720341, 67.8897322377851, 56.624241875063994, 67.85323850570187, 12.082147444448164, 0.43596127100529214, 0.8705742272638506, 1.6178770627706283, 0.7350549894955851, 30.359837432061475, 62.94556894610005, 52.86446179113081, 59.70305535101122, 46.05350917385471, 45.88529048427459, 47.00755119323731, 56.20690953346991, 54.84583531656573, 56.80228217955559, 52.913024656234256, 52.607738740982555, 48.94332324304889, 47.00710796540784, 41.77073594062559, 41.07339735954039, 37.97122224684685, 37.470566995682255, 39.41977316333402, 37.90032540598224, 40.166176672904726, 38.36313762972432, 38.66020617946502, 41.06424646992838, 39.587815346256384, 39.71089932226366, 39.3453775682757, 40.6491655688132, 40.61173046788862, 38.96306806995023, 39.01201140496039, 40.39934589016823, 41.01435784370669, 39.83943147044028, 38.36704038804577, 41.17484946404734, 39.5430689473306, 40.862546428557366, 39.98517497893303, 40.58939256975728, 39.368668602358916, 41.31229323725547, 39.14511703675793, 40.37677264982655, 44.12920221205681, 47.08306466379474, 45.22488494073191, 44.479003106394124, 43.94890262234596, 43.998869695971095, 39.62066127407936, 41.24729564113002, 41.124015546614125, 40.27861925863451, 41.01138860948625, 40.02757972286594, 40.842381523501494, 42.95115755450341, 45.32487007879442, 46.91932924332158, 47.8674602508545, 47.00426032466274, 44.798460545078406, 46.305443010022564, 45.79180079121744, 45.64420200163319, 44.664072298234515, 42.41201208483788, 40.04691700781546, 42.48882385992235, 38.472701195747625, 40.45525143223424, 39.95410980716829, 40.49147452077558, 41.488792050269346, 43.48133256358486, 45.61908314304967, 44.222166307510875, 43.438013907401796, 44.19087756064631, 43.370576597029164, 41.36773201727098, 39.811488505332704, 41.738478368328465, 39.85310877523115, 40.50349266298356, 38.60246889052853, 38.49053621292114, 38.67377365789106, 38.875991452124815, 40.3791456837808, 39.29569290530297, 39.77393181093278, 41.49829987556704, 38.200465171567856, 40.616127444851784, 40.085238564398985, 40.942966784200365, 38.707835520467455, 37.91750538733698, 38.50203660226638, 41.48145329567694, 40.23505349313059, 42.01092227812737, 44.88514884825676, 45.351918743502715, 46.87862288567328, 48.94301729817545, 49.089694330769206, 51.409674306069654, 50.55762567827779, 56.65007852738904, 55.363348914730935, 55.83205646084201, 52.48643159866334, 52.96238376248268, 51.944960163485625, 52.996610364606305, 54.21848358646516, 61.35371423536732, 50.358184922126036, 46.935826732266335, 49.65533541094873, 64.0797693498673, 58.93757343292237, 64.18891714465234, 5.05850185309687, 0.35198366269469267, 4.174923252674842, 0.4204513306819624, 1.0558655233152452, 58.27188837912775, 61.5709037165488, 68.60874191407235, 56.4656682937376, 44.76974487304688, 26.791198368995424, 31.54122591018677, 54.444251291213504, 51.69976103690363, 2.671133351902808, 0.10762972261516318, 0.08725579046914655, 0.14251945810692926, 0.04105861253675915, 0.06093004846104211, 0.033553057620602275, 0.056443979302721645, 0.08391157153152651, 0.1714908809310967, 0.2293554477153286, 0.1242355440532969, 0.17999470203874574, 0.27108021200664584, 0.09012645981725186, 0.1657293021919266, 0.29039791574881924, 0.2839443297876466, 0.1404000911861658, 0.11323304291093543, 0.4590509158949699, 40.040900091971125, 74.5353255733367, 61.929200464679354, 46.37330001400363, 39.65469175769437, 59.295305359748106, 62.0739241569273, 74.48350321862006, 60.71058281006352, 73.96315374682027, 15.327047801786854, 0.9376685753945382, 4.547508214750598, 3.267518214641079, 1.0065847418961986, 32.70052359950158, 65.19719769877773, 56.39233958336615, 63.86039903087001, 48.3215844246649, 46.798371191947695, 49.260721437392704, 57.33393199982182, 56.45001411437989, 58.15067929606284, 56.5625665264745, 56.18152003134451, 52.33626365661622, 49.31282228039157, 43.77006215433921, 43.873946128353, 40.08925899382561, 39.63605265463553, 41.59839483999437, 41.32245609837194, 42.76795541086505, 40.90796355278262, 40.31354012027864, 43.593586875546364, 42.12115264707997, 43.5217055197685, 42.018825854024584, 45.08074175926947, 43.794274945412916, 40.27587752188406, 43.477720060656154, 42.97516638232816, 42.98289345156762, 43.31400817440402, 40.423276270589525, 43.35034108931019, 42.22564458847046, 44.80421073975102, 41.955252078271684, 43.06099176406861, 41.40814811952653, 43.30755195310039, 41.279262958034394, 42.86597544147123, 46.0531561605392, 50.1145508212428, 47.14399083968132, 47.96986156894315, 45.34877692499469, 47.271154080667806, 43.48899687490156, 43.69986349536527, 44.470958325170706, 41.784189670316636, 40.52794471863778, 41.82591584420974, 42.38247271507017, 46.050551706744784, 47.81217052090553, 49.053094694691325, 49.169973481086, 48.607748785326564, 47.27577855510097, 47.7027520825786, 48.502291940873675, 48.074224072117964, 48.42414655993062, 43.73279571533204, 42.04985964682795, 45.150673697071696, 40.31243008951987, 40.13823370779715, 43.05107601227299, 40.960264436660275, 42.81295284148186, 44.82947864840108, 47.72499584382581, 44.74338654548892, 45.335480090110536, 46.52720597482497, 44.92423134465372, 44.37544861147481, 41.507442920438706, 43.62250651082685, 42.215183627220895, 42.01737065469065, 40.48293944328062, 39.760356487766394, 41.39046607478973, 42.28357799591557, 42.34407663345337, 42.65846636987502, 43.20798650864632, 44.4928059270305, 40.382738574858635, 43.78798346365652, 41.6334294503735, 43.873679407181285, 41.11421746592368, 40.47489858442738, 40.65911662194037, 42.91124351562993, 42.56847935338175, 45.928389487728, 46.90183154998287, 49.176539528754454, 50.167032134148386, 51.90628951595676, 51.98417209809827, 53.563204580737704, 52.9702873383799, 58.26707563092632, 58.10000619580669, 58.168161299920854, 55.21115310730473, 54.01592846839659, 50.46794852902813, 53.92059526135845, 55.80701212729178, 62.52518500051191, 52.79747947569817, 50.39272531386345, 51.78406061664705, 66.64207335441344, 60.63357883884061, 65.61128624023931, 6.252893968935936, 0.5528118653643517, 4.149625926248489, 0.9428639385488726, 1.5732026148226954, 63.317205675186656, 67.61508003357919, 73.2463013741278, 64.12616706663563, 50.37159942811536, 32.67436923519258, 43.01419788791288, 63.14346428840392, 63.02136482730989, 4.307037015115061, 0.20740255473121522, 0.2833283031659742, 0.28441277723158565, 0.17338823557140368, 0.22822289397158932, 0.09492105939575742, 0.17590288853933736, 0.24200267068320708], [0.010405495526239036, 0.03336411352539736, 0.03842184132325553, 0.05761481829047684, 0.042044062077278094, 0.03803976646233951, 0.06857298975509983, 0.01979585943533288, 0.03465003424113797, 0.06307960690690145, 0.07609900687971423, 0.043739989219653996, 15.17710735720973, 59.382840894883685, 43.68628424982871, 32.35210926302018, 24.837924703474968, 38.21640568394815, 45.601640362893384, 60.841040841994754, 52.1738539972613, 59.903653206363806, 25.75533178544814, 0.09229343910250934, 0.7014675498489411, 0.3899495093332183, 0.2189920707455566, 23.60548853874207, 57.630263143970126, 54.280696299768266, 53.59530133585776, 42.5675654411316, 45.001203936915246, 49.1211909632529, 51.53567260311496, 52.94523908245949, 55.204265425282145, 51.32154257066789, 52.425077884427964, 46.16772467090238, 41.69166880269205, 38.04679063058669, 36.11118724269252, 35.19535695352862, 37.024864150631814, 36.12940272977276, 36.90259210525021, 36.93080571389968, 38.53453736151419, 38.141825737491736, 39.665474353298066, 38.76469812085552, 39.526861713778594, 36.14237008556243, 39.129882551008656, 38.14506561525407, 39.142167414388354, 38.63699359278525, 35.86206182356804, 36.40325477046352, 36.851267891545454, 38.354253461284024, 38.895211065969164, 38.34674212240404, 38.022824948833836, 38.174957998337284, 39.27859921609202, 39.25006397308842, 38.98543342467278, 38.42251054702267, 40.50650896564607, 40.48483002570368, 42.271018566623816, 41.109416484832764, 41.254606939131214, 41.41341194029778, 39.04751277739002, 39.9803622307316, 39.468563525907456, 38.391974895231186, 38.255680376483554, 38.26009696529758, 38.06492767026348, 40.56995330318328, 42.75561563430294, 40.820557455862726, 43.30899930769398, 42.648636910223196, 42.36523389816284, 43.070789844759055, 43.83388303941296, 43.20055753953996, 41.209248650458555, 42.42385372038811, 39.84843723235592, 39.037357761013894, 38.6277642557698, 36.579694747924805, 39.172691299069314, 38.57554574166575, 38.95997331988427, 39.880941913973906, 42.55095812582201, 41.951918063625214, 43.812513966714185, 42.081885799284905, 42.36036231440883, 40.949026846116595, 37.79638259641586, 39.80377320320376, 39.21925375538488, 37.87408082715927, 38.13781315280546, 37.20753677429692, 38.12559496971869, 36.291373083668375, 38.92171059885333, 37.44785647238455, 37.20613256577523, 39.78455751172958, 38.10509274082799, 37.56474702588974, 38.99103064690867, 36.94645989325739, 36.41042094076834, 36.53354806284751, 37.70011194290654, 37.03699211920462, 38.26206991749425, 36.38175625954905, 36.729925447894686, 36.54030238428424, 40.45311374049033, 39.60988260084583, 42.0012261790614, 43.00931453704835, 44.6645978958376, 46.54040867282499, 51.49337768554688, 51.18003522196124, 55.93182979091522, 57.77200583488711, 57.093514242479884, 59.45630296584099, 57.274253137650035, 54.71419665121264, 56.58069572141094, 51.544788191395426, 45.53276354266752, 46.58814784019224, 58.08029628569081, 61.58861714024698, 51.511985409644346, 1.1772139730953401, 0.23346440626248238, 1.5418639803125014, 0.532284815224909, 1.475237987695202, 55.07343869055472, 55.523620882341945, 56.62423403032365, 52.09608124148462, 34.215023286880985, 23.776601937509355, 46.17378473281861, 53.998850468666326, 37.66336717913228, 0.5238387877902677, 0.019890239552384423, 0.017426977677631284, 0.01680374216859139, 0.012222465518261156, 0.0745203371550287, 0.011814769804327479, 0.031684266568552104, 0.028347078402857148, 0.022937112953513864, 0.03347857855260372, 0.01803292641265979, 0.08221208974118195, 0.07928071558595666, 0.019659957352785334, 0.04555001749747223, 0.026371092498002034, 0.10431468396657899, 0.05722232846423023, 0.09013287963405733, 0.041976730609613086, 21.269724945868216, 66.52196253499677, 52.35622459842313, 38.41587389669111, 32.21757000492465, 48.0100501737287, 49.57192620923443, 67.13244807335639, 56.00453876679944, 67.26864061047955, 27.19937001505206, 0.05839020269171846, 0.38008609666459026, 1.5967079083765707, 0.23462352793543573, 25.34610894418532, 58.85458000244633, 56.22516424425187, 55.48381666983328, 45.62417437953334, 46.782163958395685, 51.408281864658484, 53.43513134987124, 55.94813116135136, 55.81023239320325, 55.1388285236974, 53.84325396630072, 48.24452554025958, 44.352796923729684, 40.21644576903313, 39.01399220189741, 38.18116318794989, 38.86560109353835, 38.63083939398489, 38.186721186484064, 38.37395944902974, 40.583054019558816, 40.95332968619562, 39.438078864928215, 39.2377555754877, 40.703141304754446, 38.046998516205825, 40.402848566732104, 40.844091676896625, 39.616785972349106, 40.192888013778195, 38.74506665814308, 39.18537624420659, 40.86647664347003, 38.73438604416386, 39.663940706560695, 40.84463688635057, 39.60910989392189, 38.55536514712919, 40.6167628688197, 40.34211458698396, 40.53697793714462, 41.54227356756888, 40.77495990260955, 42.41844869429066, 45.23543219412527, 43.3046886228746, 43.26927354258876, 42.327182985121205, 42.31326249337966, 41.08114011826054, 43.871361286409446, 41.366257206086196, 39.69352714477047, 41.42120176746, 39.740866230380156, 43.71991857405632, 42.84584191537673, 44.00836967652844, 45.43597121392527, 46.80939697450208, 44.706096572260705, 44.68248390382336, 46.61250575896233, 45.42939732151647, 43.75178783170639, 44.33519332639633, 42.90896461855981, 39.38873937053066, 40.7980469734438, 39.79986652251213, 40.19426476570868, 40.620955882533906, 40.635860889188706, 41.78729226512294, 44.342920395635794, 44.60503278240081, 43.83302011797505, 42.94900025090864, 44.05492036573349, 42.720275079050374, 39.11905680933307, 40.771410157603604, 40.65180924630935, 39.986237941249726, 37.8448748588562, 38.89113572336013, 39.63214989631407, 39.63975537207819, 40.74620108450613, 39.43787097930908, 38.873904751193145, 40.386731547694055, 39.3805573063512, 40.38249931027813, 40.23343355424943, 40.40590017072616, 39.58357918647028, 38.256464850518014, 38.67961406707764, 38.776900614461596, 40.00717947559972, 38.90295382468931, 41.07084389655821, 39.073008183510076, 42.21897655917753, 41.79820429894232, 44.54928413514168, 46.22240251110446, 48.0431902793146, 51.25486620010869, 53.66171490761542, 52.427803931697724, 57.62159470588931, 60.19447342042, 60.178925145056944, 60.37133309148974, 57.43179121325093, 54.4904685789539, 60.291971775793264, 52.99153089523316, 47.85196688867385, 48.978024451963364, 63.284402893435576, 61.093559111318285, 55.546904071684814, 1.572965679149474, 0.6997923300631586, 4.987398107205668, 0.49314121565511154, 1.7426559929886174, 61.29876967399352, 61.79558884712958, 65.89263393032935, 59.4569109332177, 42.49056539227886, 27.19895620499888, 50.63363336747693, 60.77792206118184, 45.775499420781294, 1.0367953272596484, 0.04457202199245653, 0.08545666362249082, 0.02055912241039257, 0.04185673442759341, 0.023488809256964636, 0.06342667538011748, 0.049001438948776455, 0.046725184881999615, 0.07504831729156357, 0.12799446936696768, 0.09536871521343147, 0.26566657508092545, 0.18435820095962097, 0.13085290429092225, 0.25509820830437446, 0.1759686188832406, 0.13490154107491817, 0.13673174044778272, 0.1433026144701627, 0.2206133119761944, 24.790205147958574, 76.73924261523833, 59.40468849674348, 44.739220988365915, 35.17366624647571, 52.853910615367276, 55.47976878381545, 71.07277485632127, 59.62374894849716, 71.9880207123295, 32.88479262782682, 0.24853573060564457, 4.62140517850076, 3.258391594694507, 0.45097677818229126, 29.362696409225467, 60.53165604991298, 59.43804825505903, 59.711288406002915, 47.73867314861667, 49.75867025313839, 54.503188825422725, 55.53784339658676, 57.055004412128085, 58.21234287754182, 57.710330486297615, 59.18945627827799, 51.56414901056598, 46.281712670480054, 41.93858200503934, 40.393058330782004, 40.592181374949796, 41.08278751373291, 40.82629196105465, 40.80942184694352, 42.73710989182995, 43.57212366596345, 43.768104891623224, 42.2545289224194, 43.04942861680062, 44.2562517043083, 40.60381904725106, 43.410557316195586, 44.304834181262606, 42.24648806356615, 43.032013293235536, 38.81919945439985, 41.67896032333374, 41.88841489053542, 40.72647156253938, 42.00924742606379, 42.91621708100842, 41.21999202236053, 40.58639195657546, 41.91364357548375, 42.79891860100531, 43.33525565362746, 44.064871418860655, 44.317617185654186, 45.63275652547037, 47.038051543697236, 47.14066859214537, 45.19798140372, 43.69914962399391, 41.85722420292516, 44.12926889234974, 44.00829122912499, 43.15008448016259, 41.80325238935409, 43.80360626405285, 42.34948950429117, 46.553391718095355, 46.20037840258691, 46.45642288269536, 48.10085696558799, 47.71177353397493, 45.561843995125066, 46.052371686504735, 47.37333966839699, 47.942310840852805, 45.39823016812725, 46.866404702586514, 44.234043244392645, 42.83923272163638, 42.19052368594755, 41.186287095469815, 42.02849841886952, 43.30094668173021, 41.99767251168528, 42.676254318606475, 46.279410239188906, 46.146077109921364, 47.75133848190308, 46.52017316510601, 45.579906509768584, 45.630093236123365, 40.55792339386479, 43.6690572000319, 42.64714640955771, 41.45939780819801, 41.31323068372665, 41.87361971024544, 42.73461134203019, 40.25620291309972, 42.27281893453291, 41.54038690751599, 40.4474929840334, 43.40667024735482, 41.8756514979947, 41.77985152890606, 42.60881700823384, 41.842915396536554, 41.46997644055275, 40.01543606481245, 41.8981227567119, 41.49911180619271, 43.06514555408109, 40.975808789653165, 43.89551524193057, 40.4414015431558, 44.47210365726102, 44.133952202335486, 46.31959099923411, 48.470042213316894, 50.642654818873254, 53.98877782206382, 56.55450213340021, 55.74503867856918, 61.457664889674035, 64.83412742614746, 60.46663884193667, 62.05190397077992, 58.73678338143134, 57.680363578181115, 61.645362069529874, 55.1117524023979, 50.39585536526096, 51.723393317191835, 65.47710195664438, 65.60344542226484, 56.091054485690215, 2.4954842223275095, 0.4728919183534961, 3.883898339925274, 0.9633835729572081, 2.189806560354848, 68.51110627574306, 65.85962326295915, 70.5829414244621, 64.33271515753962, 47.19491104925833, 36.46591855633643, 61.51975208713163, 69.48429338393673, 56.42899805499662, 1.559716403003662, 0.17984752122673298, 0.15131057750794197, 0.17473981385269474, 0.14349162368284119, 0.12514045477033625, 0.11407663595051536, 0.17872440568622083, 0.14587637878233387], [0.061476675177653956, 0.04304006064851438, 0.03546994750297839, 0.04474842522834097, 0.011294012919308679, 0.08866641114676192, 0.021766635942302888, 0.019032833947529717, 0.07093520654786019, 0.013018225943068824, 0.03218992673341305, 0.06353089781177622, 8.258110111759555, 51.543701694857695, 49.04418699202999, 38.16121793562366, 21.705062927738314, 34.986800609096406, 48.71581400594404, 62.22146411095897, 51.47550344467164, 58.938585404426824, 36.407918468598396, 0.14585618470464984, 0.2704218360445192, 0.8167637824531525, 0.14321060731045662, 16.09099901491596, 59.11186395152923, 51.36211556773032, 51.780887419177645, 46.16229218821372, 52.76292339448006, 49.30348311701129, 56.78436479260845, 51.42091189661334, 52.27443533559, 51.40583430567096, 49.871442317962654, 45.17915010452271, 38.78352157531246, 38.0464768409729, 37.19326719161003, 38.22292074080437, 36.510664955262214, 36.18211546251851, 38.21086729726484, 39.216096247396166, 38.095169144292036, 37.22889407988518, 38.97505483319683, 44.32016672626619, 45.140569671507805, 42.98889860030144, 43.29878937813544, 41.76276960680562, 40.37853379403391, 37.90889578480875, 37.0276725676752, 36.0764350429658, 38.87015888767858, 37.85787359360726, 38.11061936040079, 39.01757724823491, 38.59642059572282, 38.62428119105678, 37.81708094381517, 38.70967903444844, 39.89100671583607, 40.283824243853175, 37.26263823047761, 41.12717697697301, 41.09984197924214, 41.877930395064816, 40.044402768535, 41.457899462792184, 39.787330627441406, 39.916851212901456, 40.04279067439418, 39.46170722284625, 37.71734291507352, 37.382513707683934, 37.861693982155096, 38.546457444467855, 41.46464201711839, 41.34370357759538, 42.69553669037358, 44.694235324859626, 45.69929953544371, 45.763343995617284, 43.130013711990856, 40.755712832174, 43.603961544652144, 40.699277770134714, 40.600312448317005, 37.76348567778064, 38.92086728926628, 39.861706610648866, 40.045571634846354, 39.335940345641106, 39.07918983890165, 39.54689325824861, 40.811685054532944, 42.04583137266098, 41.643078480997396, 40.24039576130529, 41.77272850467313, 39.365232606087964, 38.14745433868901, 38.05099933378158, 40.32769595423053, 38.535082570968136, 36.932578625217566, 38.2813326774105, 37.58103270684519, 39.024982683120236, 37.27731573966242, 36.72475576400757, 37.737558810941636, 37.09857333090998, 37.17899760892315, 38.32222730882707, 38.52427644114341, 36.151991659595126, 38.4582394169223, 37.92063151636432, 35.8846232967992, 38.1907965290931, 36.460544909200365, 37.52767670539118, 38.55754206257482, 38.56424539319931, 38.607089442591516, 37.55834571776852, 38.92567611509754, 40.00637931208457, 41.60795365610431, 42.03805723497945, 46.01217131460867, 46.87208037222586, 49.94992110037035, 50.61800272234025, 52.746265088358236, 53.80978045925018, 57.02941094675372, 55.51397185171805, 54.69308645494523, 56.40967253715762, 47.70500744542768, 47.15992742969144, 56.55846372727425, 63.42469038501863, 42.89257695597988, 0.04616373053361331, 1.6977482865894995, 11.913822850873395, 0.49341259464140863, 3.649710777305788, 56.61080775722381, 55.9234163068956, 47.26362312993696, 44.96040736475299, 40.449591452075595, 27.864543199539188, 32.92338678913732, 56.05815364468483, 24.43562092319612, 0.0047330899002601306, 0.044734582019549225, 0.05739294390584673, 0.015078814767841852, 0.025379745995685942, 0.056794908859076045, 0.049817108083516366, 0.0416700464613255, 0.05760788136432248, 0.08899018288620057, 0.06198648370862488, 0.06829999432328247, 0.02228468566411926, 0.0552701257589844, 0.03571728665021158, 0.06464243776375247, 0.004210701726767565, 0.05329230890399026, 0.0296232698019594, 0.02922145477045448, 0.09524243327999309, 10.935450369311917, 60.61504171740625, 55.12297430346089, 40.46204889974287, 23.137918479980964, 45.84767887669225, 52.6222828895815, 67.05406342783283, 56.05219556439308, 62.987318654214185, 39.00296641934303, 0.09910526309883404, 0.23446422761246083, 0.9900801436555002, 0.4495811192018371, 18.140820841635428, 61.027667214793546, 53.74994077990132, 54.66982287745322, 48.87377569752355, 53.95788915695683, 50.28178107353949, 56.73677859767791, 55.48322831430743, 54.765195308193086, 54.10719417756604, 52.00062644097113, 48.14313227130521, 41.67200203864805, 39.39583493817238, 39.49336467250701, 37.87789337096676, 37.071516821461344, 39.2895543959833, 39.913819220758256, 40.776505316457445, 40.41829093810051, 38.83594797503564, 40.30981779098511, 44.872828683545514, 46.99066931201566, 45.53083765891291, 43.55757559499433, 42.10803231885357, 42.48044175486411, 38.13549503203362, 40.532620183883175, 38.66033169531053, 39.675511698569025, 39.21683365298856, 39.14724296139133, 39.72493748511038, 40.94440629405361, 40.4467712679217, 39.59547573520292, 41.14204668229626, 41.195665482551824, 40.8976084955277, 39.49089357929845, 43.87535033687469, 43.364795023395175, 43.62119251681913, 42.8280225876839, 43.12252198496173, 42.727296121658824, 41.5314595930038, 41.12148561785298, 40.27052348659885, 40.04059022472751, 39.991572364684075, 38.98430378206315, 41.26042381409676, 43.75073271413004, 42.95462492973574, 45.25225523979434, 46.04396212485529, 47.52815169672812, 47.388891866130216, 45.50106686930503, 43.31329822540284, 44.299672342115834, 43.03724965741558, 43.85578947682535, 40.545348275092344, 40.92906982667985, 40.339557201631614, 40.91606324718845, 40.267581708969615, 39.55126277862057, 40.85296015585623, 43.07290792465211, 42.80699868356028, 46.3032700169471, 41.13368811145906, 44.262692236131244, 42.49381311478154, 40.136064637091856, 41.41594186905892, 42.65652479663972, 39.97152513073337, 39.416611732975134, 38.672675394242816, 38.98541381282192, 39.06018595541678, 39.245851347523356, 38.66903935709308, 40.531455239942, 38.391818000424294, 39.33705822114022, 40.44646140067808, 41.01293402333414, 39.255802400650516, 40.291849413225734, 39.808899741018976, 37.87953684406896, 39.40945732978083, 38.550262143535, 40.30263985356977, 42.9904204799283, 40.63381733432893, 40.12599983522969, 40.21931694399926, 42.11949348449707, 40.80006699408255, 43.56773061137046, 45.31125160955614, 48.87378746463407, 51.386065560002486, 51.14537323674848, 54.30171235915154, 55.33782997438985, 54.58980652593798, 61.24357800329886, 56.61291799237652, 57.70295643037366, 59.23325738599224, 49.7091934757848, 50.19946621310327, 58.482217634877856, 67.26067819902974, 44.108570544950425, 0.06404104342143382, 2.720658913735421, 6.409346038295377, 0.658350037711282, 3.9793217614773786, 62.84766658659905, 61.55774024225051, 54.12274637529927, 53.45365670419509, 43.818232782425426, 25.32360434532166, 43.30111534364762, 61.237004110890055, 32.77692548690304, 0.1019178859649166, 0.07752357801843075, 0.046536834504936016, 0.05915152554910991, 0.02118750794550344, 0.0068103875814666676, 0.018968218261556282, 0.02767411804187202, 0.03443553728321868, 0.17396534492652263, 0.139970806156916, 0.19370554615893673, 0.08422263387230136, 0.131678854325606, 0.11898213441693976, 0.12241698155600218, 0.19966693595051768, 0.16530272911392874, 0.11226495292278067, 0.14495855948377043, 0.226440912172679, 11.986624002456667, 68.46103329812327, 62.1014670402773, 50.25015500284011, 29.997761480269897, 48.98284504490514, 58.53473032674482, 72.20568872267201, 61.77499248135475, 67.88878302420339, 43.544129710043634, 0.2976644435717214, 2.0778675088959355, 3.1437063938187015, 0.6215692371610673, 18.341730525416715, 64.52427979438536, 56.077918467983125, 56.83314731044155, 51.532471949054354, 56.29896756141417, 53.83884914459721, 60.73171654055196, 55.889468193054206, 56.263560325868674, 55.227301505304155, 53.92993834710891, 49.638092671671224, 42.75973804535405, 43.35183158997567, 42.37587921081051, 41.386280905815866, 40.644435190385394, 41.520441655189764, 41.2189055258228, 43.10986449641567, 41.6413212591602, 39.51287061937394, 42.01104387160271, 48.47162685086651, 50.09541357717207, 47.778253786025516, 47.377375787304295, 45.80065750306653, 45.43708908942438, 40.544708928754254, 40.525057854190955, 40.045732452023415, 42.35994262080039, 41.09546069175967, 41.81848687510337, 43.10588329069076, 43.04746743171446, 42.819648327366004, 41.874772887076105, 42.3368045591539, 43.992844935386415, 44.33893526754072, 41.86918743195073, 46.0643074589391, 45.70116658364573, 46.58340177228374, 45.01237092479583, 45.989099933255105, 44.560494269094164, 44.0702489883669, 43.04170546993133, 42.113904107001524, 40.38485665475169, 40.665792495973655, 42.15713647104079, 41.066462609075735, 45.31324417360368, 45.98639742020638, 48.040064150287265, 48.36542867845105, 49.351751804351814, 50.969278427862356, 48.29180579031668, 45.21225883114723, 48.57628353180424, 45.702472732913115, 47.556012292062086, 42.22558967528805, 44.29522437434043, 42.909501983273415, 44.1596947177764, 42.06782017984698, 41.321510807160415, 43.29150945909562, 45.85806923527872, 46.08222876825641, 48.04818345654396, 44.086903372118556, 45.93299827268047, 44.53020964899371, 41.752614590429495, 42.24036132135699, 45.46362000126993, 42.17026072163736, 39.95239180903281, 41.60813016276206, 40.96647354864305, 41.85723597003568, 40.69339813724641, 41.80564503515921, 41.239466590266076, 40.3325596932442, 41.197697270301084, 43.13653269121724, 44.50009761318084, 42.1085226151251, 42.281483450243556, 42.49717458601921, 39.861349674963186, 43.16675063102476, 40.888073213638805, 40.58422288587017, 47.83836803128643, 42.478437423706055, 43.29757736575219, 41.61433143000449, 44.39703733690324, 42.978516086455315, 47.15153747989286, 46.66566564190773, 50.22895459205874, 54.1706032137717, 54.15902437702302, 56.03149721699377, 57.4614796330852, 58.331033798956106, 62.504392516228464, 58.12437980405746, 60.67044127372004, 62.03976815746677, 55.54040470430928, 50.54991429851901, 62.44462343954272, 67.72048196484967, 48.25162503027147, 0.09856790604610598, 4.318866393258495, 24.914812964777795, 1.1273863887594593, 5.042853557294415, 69.68472649974208, 67.20498054258286, 62.281825465540734, 64.54484478119882, 56.208486326279186, 38.55682426883329, 49.28399678199522, 69.33992662737447, 41.10453705633841, 0.6100435975578524, 0.12212889419207651, 0.14857832492599565, 0.20528329506276116, 0.12317737744700526, 0.22539806732487297, 0.30248957175400953, 0.13724002446378433, 0.20294968399309343], [0.004361633496779588, 0.04022873630146346, 0.04245406850391338, 0.07586197161506261, 0.011595803680979918, 0.035053073098101926, 0.05390490728220152, 0.05615006967057144, 0.08206939054352623, 0.010486753514757561, 0.06224798016069878, 0.1069479120234328, 4.284438279367262, 50.71821143550258, 49.247067666822865, 37.554105635612245, 30.002199642119873, 32.47909991971908, 48.955255093113074, 58.47992304832705, 55.69789963383829, 53.25498081022694, 47.72422705927203, 1.5864392658395152, 0.24953674705278492, 0.4473302915932671, 0.5162603396081156, 7.635001405592888, 49.18146994806106, 56.52821440850535, 50.58135209545013, 50.604356796510764, 52.67176751167544, 59.02373613849763, 54.17095622708721, 48.42712756126158, 53.964588565211145, 54.43682232210713, 51.25512507654006, 42.59350407508112, 39.14936104128438, 36.258107462236964, 36.50687202330559, 37.7488003238555, 36.55506226324266, 38.53183092609529, 38.84447913016043, 39.403173692764774, 40.835627202064764, 44.79762900260187, 46.4711239261012, 48.10424981578704, 48.92246407847251, 48.63890417160527, 47.68119081374138, 46.63016819184827, 45.435712337493904, 42.664471518608835, 40.237187262504335, 39.10051184315836, 39.46517852044875, 38.6079131403277, 38.09038777505198, 37.344717748703495, 36.70444573125532, 37.08024801746492, 37.505009328165364, 38.58315513980004, 39.222799578020656, 38.18117887743058, 38.20683902309787, 41.406163400219334, 42.925599390460604, 39.76353360760597, 41.01796250189505, 39.8682334346156, 40.261929573551306, 39.88911613341301, 40.66851069850307, 39.53746388035436, 37.838677513983946, 38.31804998459355, 37.829103008393325, 41.20295716870216, 42.37166658524544, 41.709076281516786, 44.19047355651856, 42.67758400209489, 47.9324068561677, 44.19168949127198, 43.34271992406538, 43.55348848527478, 43.03690448884041, 40.64875371994511, 40.797780252272084, 36.35151478552049, 38.07255275787846, 38.53284681996992, 39.55935855065623, 39.43035179568876, 40.23087224652691, 40.56936887002761, 41.12280353423088, 40.24741680391374, 41.56609019925518, 39.61682127368066, 40.72025068344609, 42.46660363289618, 38.496003996941354, 38.35759924304101, 38.4928386442123, 40.29136303932437, 37.31099320996193, 37.516329288482666, 38.87341053255143, 38.71114992326306, 37.61419242428195, 38.66420307467061, 38.580687968961655, 36.838214243611986, 37.41302190288421, 38.81376304934102, 36.0479429460341, 37.191145189346805, 36.60643746775966, 38.0708465268535, 37.20368892915788, 37.369907209950114, 38.69479756201468, 37.5386828760947, 37.17458494247929, 37.940423796253825, 37.7059405849826, 39.333390805029104, 41.33721205496019, 36.24416343627438, 38.689310166143606, 39.193417103059836, 41.46749750260384, 44.25642821096605, 45.70019775821317, 49.600547744381814, 50.74995125493696, 54.362187462468306, 55.076329477371715, 54.954547728261645, 55.14358635871641, 58.63597846800282, 51.604333692981356, 53.7545064187819, 53.81569539347003, 66.76407475625315, 22.713892613687825, 0.08804454693510648, 1.197286212155896, 1.8929177041976684, 0.2478181054034541, 3.9061494556165512, 60.07191111964565, 53.35289493683846, 64.93029609803231, 40.29820757527506, 39.019542355691236, 37.75555464529222, 41.75116723583591, 56.882086723081535, 14.342797648522163, 0.049792849909394025, 0.013669666894260916, 0.05046248353356796, 0.048564420261931036, 0.02051839717633782, 0.029958756940980113, 0.06141838737793508, 0.007877418303847193, 0.06351134341750896, 0.06132742209780601, 0.14351172582997432, 0.03809215538504143, 0.03969149416192405, 0.05233597836547321, 0.09411122785100053, 0.011661188327707352, 0.026358231796973178, 0.04401601452921187, 0.02338357941968547, 0.02572904186954181, 0.09479326060822896, 5.221922503363702, 57.56156283040201, 56.97819263704362, 43.130335346344985, 29.535374833691506, 42.035405712742964, 56.18938438354, 63.48440847089214, 59.529325731339, 59.40917961059078, 52.748579286759906, 1.5594963825518087, 0.6158791650687495, 0.6240275213795324, 0.3477888410129855, 8.814928800828996, 53.80569334953062, 58.28367510149556, 51.898181976810584, 52.40890987457768, 55.69791924568915, 61.02400764342278, 56.85008018247543, 50.17360602655719, 54.92422780682964, 54.46523989400556, 51.98813761434248, 43.62224371202531, 42.51615101291288, 39.09045488603654, 39.01453741135136, 37.6912199297259, 37.067131611608694, 39.66300326008951, 40.44544550680345, 40.3636170202686, 43.076249784038914, 45.14196211291898, 48.02548470035676, 50.128385020840554, 50.798953425499704, 50.384876651148645, 50.29890221934165, 49.58857667061591, 45.95582254471318, 44.27803262587517, 40.87679639939339, 42.811015190616736, 39.90481345884262, 40.91103476862754, 39.4834057746395, 38.56568490305255, 39.549948784612845, 39.6075919366652, 39.88504079080398, 41.659336705361646, 41.707189621463904, 41.6874954008287, 39.84946881571124, 43.89429930717715, 44.563365444060295, 42.73126163790303, 42.08035999728788, 43.29217233965474, 42.59997990823562, 42.873580917235344, 42.73194413031302, 39.2313934910682, 40.422174084571104, 39.60359896382978, 39.27555153446813, 42.82471602962863, 43.85641705605292, 43.9816975593567, 46.586551435532115, 44.89069507968041, 49.0882077524739, 44.959807242116625, 46.34673380082654, 47.03028917312623, 44.342653674464074, 41.868320588142645, 42.050004774524325, 39.332390600635165, 39.96436680516889, 39.68689441680908, 40.116009558400805, 41.816274658326186, 41.633755007097804, 41.605447261564194, 44.773380910196614, 42.77128550314134, 42.82463365985502, 42.22648005331717, 43.92256390663886, 43.31804429331134, 39.84553075605824, 40.08743901406565, 41.55368374240014, 41.754736592692716, 39.016455450365626, 38.21364433534684, 39.64731770177042, 39.56363785651423, 40.24070170617873, 40.76385175028155, 41.16650658269083, 39.74391391200405, 39.18556844034503, 41.90597926416705, 39.035110242905155, 39.74786766113774, 39.44125990713797, 39.795014550608975, 38.57620077748453, 39.979001168281805, 40.363303230654815, 39.71494720828149, 38.82278450073735, 39.945610031004875, 40.51913115286058, 40.78277326399281, 42.05329172072872, 39.08874081027123, 41.38724973124843, 41.08346608377273, 42.75820439861667, 44.5921124950532, 47.31020912047356, 49.69236258537539, 52.465133128627656, 57.19235797082224, 57.72922062104749, 55.72314008589714, 56.533725338597456, 60.39473787430794, 55.5208634561108, 56.02690412152199, 58.05509897970385, 69.47400108460458, 26.43443918997242, 0.03940644050617853, 6.415379133916671, 3.4804818322581634, 0.4598754103625975, 4.5407872334603345, 67.07627973248883, 57.05944845753332, 68.69726196412118, 49.244247482668975, 44.90512155717419, 37.18850151185067, 47.870213754715465, 64.96001981919812, 20.743550754362538, 0.08548212072421467, 0.0048104082816280425, 0.04952287286399834, 0.03788664846891358, 0.010009833138375994, 0.02301347085214671, 0.021855486819760937, 0.09163101053526325, 0.0613663470252387, 0.13130039156925294, 0.29277094970307044, 0.11958306910650385, 0.24993790133345514, 0.19414759421300506, 0.13203660206448647, 0.1914909851527022, 0.19887887662456882, 0.14978411667529615, 0.1627520393700369, 0.25604504701350966, 0.23040308827354064, 5.9418338344943145, 67.6787793251776, 63.118784735279704, 51.45063561777915, 40.592785419956336, 45.2524435135626, 60.805225679951334, 68.62068160887688, 66.03859316918158, 62.381281083629986, 60.29718460575227, 2.1500501517326605, 1.4582041146293765, 4.187054163025272, 0.7698982617547436, 10.880711732372161, 54.457175500931285, 61.0419564093313, 54.69161164376044, 54.635835539910104, 59.595425513482866, 62.291627468601355, 57.246553359493134, 54.78278713841593, 57.0051432424976, 58.99735035434846, 54.660260138973115, 46.346070920267415, 44.39724522252237, 41.535680063309215, 40.36966139270414, 40.22396495265346, 39.060762543832105, 42.50429368788197, 42.60152532208351, 44.00023860316123, 43.96418809890748, 47.89948640331146, 49.999484169867735, 52.7579027606595, 51.843445301055915, 53.41761404468168, 52.072845120583814, 51.34617505535003, 50.48293982782672, 47.00641762825751, 43.44364250859907, 45.6000792595648, 43.09705403543288, 42.58245868067588, 42.477986351136245, 40.47839733862108, 41.64818540696175, 40.901052336538996, 41.90328459585867, 42.03664518171742, 44.376472350089784, 43.04697713544292, 42.6825693345839, 46.60911683113345, 48.5921299073004, 42.79437649634577, 43.15245359174667, 44.50741283355221, 43.88031605751284, 44.379931880581765, 44.70378237385904, 40.91791068353961, 42.78098944694766, 42.78613559661373, 41.41242742538452, 46.066170584770944, 46.28052811468802, 47.380282263601984, 49.39542739622055, 46.865973241867565, 50.5957236597615, 44.75645588290307, 46.44015289122059, 49.51153347569127, 46.5790440190223, 43.76142509521977, 44.71373734935638, 40.22601635225358, 42.91785270937028, 41.43221970527403, 42.786967139090265, 44.00907962552963, 43.60707198419879, 42.734054365465724, 45.87550024832449, 43.402747877182506, 44.924262723615094, 45.10955156818513, 44.89975967714864, 47.2908208447118, 43.29819710023942, 42.79862442324239, 42.78741821166008, 43.231442282276774, 41.1981483428709, 41.04260283131754, 42.895608948123076, 41.26082781822451, 42.25140279339206, 43.36710137705649, 42.940845643320394, 40.421248405210434, 40.84099692683066, 46.34654944942844, 41.10869084635089, 42.993809407757176, 41.55694323201334, 42.97464862946541, 40.79668591099401, 43.491730766911665, 42.69990228837536, 42.70462874443301, 41.09346812771213, 42.86497131470711, 41.541853873960434, 42.88239056064237, 46.812381898203206, 39.89434465285271, 44.31919790083363, 42.45667611399005, 44.76979194148895, 47.43573673309819, 48.896258723351266, 53.28635977160547, 55.86748330823837, 60.470325869898645, 58.880714754904474, 58.80595045704996, 57.63676251134565, 61.91738628572034, 58.473019676823775, 58.29975289683188, 59.115190121435354, 71.02679683316138, 27.559488704127652, 0.11548845938617185, 8.505266501057534, 9.50309197748861, 0.728512353474094, 5.400948303361093, 73.95049233590403, 63.877794742584236, 75.57065871454056, 51.6646283672702, 53.594454103900546, 49.8736741465907, 57.78341993208855, 73.56442912932366, 28.35884224983954, 0.13607390074720307, 0.14961335567697404, 0.0965937510913899, 0.14391785968215237, 0.17682976299716582, 0.13004825150053348, 0.1845911223321192, 0.23877915655893667, 0.18915711361314022], [0.05116865189085084, 0.030923054793909676, 0.033475399287717963, 0.026478019220033483, 0.005287585297464243, 0.07948742909056526, 0.025154248015173984, 0.050779211094542864, 0.12169866687467984, 0.030752311032565854, 0.008065255880806475, 0.03650807324917086, 1.3782760164430066, 36.851962151065955, 55.318684885578776, 34.462975917323945, 24.3887544831922, 30.61898058460605, 49.990725517272956, 56.49921632582142, 58.02344153004309, 52.40896871013027, 54.547586133403165, 3.851847182358465, 0.2967675078299738, 0.298579428344965, 0.2632427954625699, 1.0822794995000287, 30.470877770454656, 58.403703551138605, 52.68431909622685, 53.592316412156634, 55.47486582110005, 51.935817118613954, 48.1174329019362, 53.696200386170425, 55.211109961232836, 51.68224373171407, 48.333677091906154, 38.93998492148615, 37.03335608205488, 37.36809899730068, 37.03417193505072, 38.722434582248816, 38.822686441483036, 38.95109699618432, 42.91667599831858, 45.13197968083043, 49.501778541072724, 49.822612731687485, 50.85123077515633, 51.00080643930743, 51.2843624238045, 49.80675851145099, 51.85343950025497, 50.12125807423746, 48.28156840416693, 44.39193825567923, 44.06137266466695, 38.84886434001308, 37.105068775915335, 37.32332906415386, 36.024200839381066, 37.34836163059358, 37.72984743118286, 37.702583036115094, 38.71055372299687, 40.03940959130564, 39.300140873078384, 39.719159833846554, 39.52237452230146, 42.624624160028276, 44.15541933428857, 38.9728622282705, 39.657884567014634, 41.23363010344967, 41.160152343011674, 39.86722930785149, 38.75651213430589, 39.55802886716781, 39.51649488941316, 36.78577607677829, 36.88607892682476, 39.989179718878965, 44.40994193477016, 42.85971141630604, 45.53617600471743, 43.86344594340171, 47.26180707254718, 47.11255696512038, 45.100561495750185, 44.36015529017295, 42.281455993652344, 42.08823611659389, 40.85690213787941, 38.31291952440816, 38.47158724261869, 38.9586514811362, 38.286321932269686, 38.95470949911302, 38.35588908964588, 40.23739122575329, 41.19174703474968, 43.836813049931685, 42.45007476499004, 41.14684374101701, 40.86066761324483, 43.40910211686165, 38.90816665464832, 40.31201824065178, 38.54313519693191, 39.08366134089809, 38.842886647870465, 37.670898129863126, 37.47128086705362, 38.22587428554412, 38.74569031500047, 37.94373035430908, 37.95861574911302, 37.959145269086285, 37.83487673728697, 36.61733773446853, 37.66979986621488, 39.164289582160215, 39.65740603785361, 39.76270206512944, 38.598479840063284, 36.81802972670525, 38.871147324962, 38.36484386074928, 37.62266866622433, 38.28861651882049, 35.496489078767844, 36.536634968173125, 37.92670334539106, 39.423797515130815, 38.51330557177144, 37.883612186678, 37.52617835998535, 40.616429467355054, 39.237386872691495, 43.54571434759325, 46.26701554944439, 51.00766274236864, 51.57120927687615, 54.52949616216845, 58.08168088236163, 58.28942137379801, 53.8510634053138, 60.881511857432706, 56.007547224721606, 62.61663113870929, 6.134330034255982, 0.1184313171993821, 4.091784939650567, 1.7548592220390997, 0.3039897251273355, 6.27243080446797, 59.48664642149403, 56.86345546476303, 57.00258193477508, 37.23581314086914, 22.907157598003266, 33.17187286192371, 49.60774921601819, 46.022008619000836, 10.073179064258452, 0.18054270005274206, 0.14862881012020573, 0.02570089771442356, 0.0638314609175488, 0.030932891362857436, 0.04809740540241042, 0.06092347159621216, 0.08296253415004862, 0.006133860123584108, 0.01825294111885371, 0.03677132021215174, 0.02435008360583696, 0.03247706414831262, 0.030804219235095288, 0.004094498637582987, 0.028546952657521735, 0.13046420659990082, 0.030514632254057837, 0.05999551312397084, 0.023019241409436352, 0.06461112008940789, 1.7585083746141004, 44.69227413977347, 59.5903774230711, 43.932946420484974, 31.490260593352783, 36.28594844572006, 57.81483027242846, 61.942073683584894, 62.76954473987703, 57.67642551852811, 58.876113814692346, 4.368443681347755, 0.6390826199804583, 0.9722886402760783, 1.7525186702128381, 2.28759860319476, 33.58219985039004, 59.642650850357555, 54.15288194533318, 55.992218602088194, 58.60939264297486, 54.87865771016767, 50.81388588874571, 55.9747915114126, 56.690953546954745, 54.20707341163389, 51.25078301275931, 40.60834154005974, 39.89077921836607, 38.321807615218624, 38.37162563877721, 39.615342540125695, 40.80679778129824, 39.21135017948766, 43.54692243760632, 47.03231311613514, 49.06840370547388, 53.22060908040693, 52.194411139334406, 51.92634459464781, 54.17442752468971, 51.94254790582965, 54.45431609307566, 51.76069897990073, 50.8445627458634, 45.97029216827885, 44.85063591311055, 41.34097360795544, 39.85510133927868, 37.89332005285448, 38.9376550336038, 39.4795383176496, 40.135586107930834, 38.746451254813906, 39.97282343526041, 41.745879880843624, 40.47375325233706, 41.35840854337139, 40.65153468039728, 43.35486358211887, 44.97184107380529, 41.162560678297474, 41.263342057504964, 42.88766614852413, 43.63434814637707, 41.72349099190005, 42.086196484104285, 41.30494271555255, 41.11658265513759, 38.796179063858524, 40.087642977314616, 41.344193873866914, 45.82014776045277, 46.69185922991845, 47.50264060112738, 45.81595474673856, 49.0437751431619, 46.80088935359832, 46.59003450024513, 46.67288280302479, 43.7776009498104, 43.57824648580244, 44.08857430181196, 40.448253923846835, 40.39050486779983, 39.72146618750788, 40.841577437616166, 40.50481057936146, 40.94201757061867, 41.39825590195195, 43.08853464741861, 44.37020048018425, 43.838738933686294, 42.4380801570031, 42.5909427673586, 43.68569197193269, 40.937867702976355, 41.283146104504986, 41.25992567308488, 41.58772599312567, 39.22199549213533, 39.826679845010084, 39.32578532926498, 39.372669419934674, 40.3267781196102, 40.23895625145205, 39.54708545438705, 39.564849868897475, 39.73273515701294, 39.93688667974165, 39.451250183966856, 41.22783284033499, 40.88901458248016, 41.849034294005364, 40.31255560536539, 38.26884777315202, 39.23019716816564, 40.699273847764545, 38.451716515325735, 39.26526315750615, 37.821670116916785, 39.3596589180731, 40.13402500460225, 42.82703807277065, 39.31033119078606, 39.932077853910386, 40.00094290702574, 43.64804114064863, 41.79172454341766, 46.03594872259325, 48.115922789419855, 53.72124471972066, 55.862286167760054, 57.48020110591766, 58.85243054359191, 61.17586612701417, 56.00514673417615, 62.977081268064445, 58.37958881931921, 65.8840282501713, 6.761183623344668, 0.1228579034608218, 6.446552170861152, 1.5411032856472078, 0.4892056381269809, 6.117463842515023, 66.59088642366471, 62.179592809369495, 61.61015487486317, 41.61163283932594, 34.14877445467057, 37.97607421875, 55.14555146617275, 54.231223444784845, 13.664809100089537, 0.15200348871369518, 0.0920816004696873, 0.04387156865108879, 0.08690870667417204, 0.07378963483197075, 0.031672687149576606, 0.028516245938296762, 0.029088291452236237, 0.015221658564593284, 0.13796400819574633, 0.16128278998357637, 0.08997600780980242, 0.1722230924473655, 0.1340465256643872, 0.2011452558180017, 0.06335913323827329, 0.1499306539734525, 0.2303799217747104, 0.17036919031412373, 0.16975192263001398, 0.2024865991646244, 2.1272641228091334, 51.25563106229229, 68.55176556494929, 48.06441030194683, 35.93865786829303, 41.36439015788417, 63.542181061160186, 68.40032285259616, 68.55087126455, 62.30019000268752, 65.77803011863463, 5.774018658745674, 1.5194450607222896, 2.5218707419210866, 1.665907588697249, 2.0139179210509024, 35.202578037015854, 61.72982638882053, 58.723219825375466, 58.01102330607753, 59.71559516845211, 54.334052301222286, 53.30870943684732, 57.10511269107942, 57.17526820398147, 56.23304036355788, 53.54324363893079, 44.15223436970865, 41.72979031839679, 40.01425935376076, 40.417125994159335, 42.6693784036944, 43.74406076246693, 43.49531189087899, 47.25281700011223, 49.47094086677798, 51.858028673356586, 54.45438669573877, 54.739825417918546, 55.0452172371649, 54.68752453404089, 52.82477132735714, 56.277892666478316, 54.613297600899976, 53.18259739106702, 47.32299604723531, 48.242850688196, 42.491804861253314, 40.99820552333709, 40.245157518694484, 41.29187730050857, 41.4414333528088, 41.63274695796352, 41.26064346682641, 42.337165417209754, 43.6885239231971, 42.32732811281758, 44.73904840407833, 43.02668279217136, 45.40682015880462, 48.46512748349098, 43.012597560882575, 43.13487352863435, 44.57552871396465, 45.21148220185311, 44.60163600983159, 43.542470547460745, 42.952699045981134, 44.44691811838458, 42.03300914456768, 41.66165090376332, 43.71173650987687, 48.60647793739073, 47.29768891488352, 49.319443241242446, 49.26867992647233, 49.42823802271197, 49.73242175194525, 50.412631342487956, 47.69938276660058, 46.34201518950924, 47.809726884288175, 46.38523186406782, 42.222494925222094, 43.783472737958355, 43.552637330947384, 41.311136138054636, 42.92417164771788, 40.71094682139736, 45.00771507140129, 45.569457315629535, 45.30064159824003, 47.19468355178834, 45.563950307907604, 44.369874923459946, 48.914301626143924, 43.02194849137337, 44.620129985194055, 42.36589677872197, 41.23676407721735, 42.88301421749977, 41.75952972904329, 41.90783062288838, 42.16365545026718, 43.14070217071041, 41.62376473026891, 42.5313501973306, 40.42970111293178, 42.05536273217971, 41.478185961323405, 43.266116034600046, 43.86288896683724, 43.994076559620524, 44.131084949739524, 43.13736423369377, 41.61945796781971, 42.498151256192116, 43.05171143624091, 41.19719128454886, 42.36204108884258, 38.9205534996525, 40.26569112654656, 43.064804307876095, 44.694364763075306, 42.60941320850004, 42.238827674619614, 43.02090514090754, 46.74039071606052, 42.41871541546237, 47.2666355102293, 50.456275555395315, 55.97931792659145, 56.66648580181984, 60.05936737983458, 61.00812988896524, 62.08449102217152, 57.753476558193086, 65.8094326142342, 60.1269615850141, 67.74477712569698, 7.937493612689357, 0.16086760097213332, 11.610179428131351, 9.245918835363081, 0.6438954294689241, 7.649434747234468, 71.94976975840908, 69.72242047709804, 67.11390310718168, 48.34757012705649, 35.20368806777462, 44.50860915645477, 63.27512256560787, 61.72547255792926, 21.181344139960505, 0.30280158404381047, 0.2745475872389732, 0.18426067796686005, 0.2182442003921155, 0.28971940699604254, 0.15815329016937366, 0.14197755815281024, 0.2625205277675583, 0.08225252386182547], [0.04682045940670275, 0.036727906009482766, 0.05004498093659359, 0.08456686782019754, 0.033448582379928524, 0.011926712487043153, 0.013279696539675277, 0.0050690678143573385, 0.017320485710496866, 0.029526129853160634, 0.027813385165626966, 0.03867475376013787, 0.26543549231944547, 25.328972108902473, 56.07617693562662, 35.62538208500032, 29.193387300737445, 22.674090362364247, 48.675527341904186, 58.506857964300345, 60.40328471891342, 50.34384473677605, 57.792072680688676, 7.950218762120894, 0.3680350739629038, 0.1917526654658779, 0.826051771160095, 0.10470981679616437, 5.068259729493049, 46.033116771328835, 55.07742381864979, 56.84741689312843, 51.13102912902833, 54.74380662364345, 55.873547292524776, 58.4734982059848, 49.09168689481674, 51.30965778904577, 41.74504049362675, 37.544676257717995, 38.2353703437313, 36.42121138111238, 37.861035023966146, 39.98020533592471, 38.92416992495137, 43.04563960721416, 46.76366213829287, 50.272253636390936, 51.829309078954886, 52.22167945677235, 52.59706989411385, 53.80537563754667, 49.04244938204366, 49.9570402022331, 50.586102085728804, 52.390219780706595, 50.89449844052715, 48.91404274971255, 45.51355961830386, 42.824194354395715, 38.893622506049375, 38.539255972831484, 38.14301029328377, 38.49338777603642, 39.165697713052076, 38.62454791222849, 38.52970107909172, 40.37437215928109, 39.08904675514468, 39.24019921210505, 39.59616999472342, 42.092346760534475, 42.641470739918375, 38.687780441776404, 39.73556710827736, 40.375235080718994, 42.63258657147808, 39.028010752893266, 40.27504597940753, 38.27957937794347, 38.537577198397734, 37.01796862386888, 36.439011096954346, 41.72563260601413, 42.58267048866519, 46.83906578248548, 46.1438335141828, 47.3526373986275, 45.52147103894142, 50.59400958399619, 45.83657072436425, 44.664786169605875, 44.1212554900877, 42.64471061768071, 40.399993081246656, 37.62141743013936, 37.94731540064658, 38.6246891175547, 39.18501930852091, 40.116378261197, 38.753103594626154, 39.735986801885794, 40.041511981718, 43.90674106536373, 42.06691411233718, 40.02207663751418, 40.5735069705594, 42.11841875506986, 37.7696987121336, 38.511246327430975, 39.61178887274958, 40.23426509672596, 39.15545640453216, 37.366663409817605, 37.822458513321415, 38.19104363841396, 37.90500479359781, 38.894693313106416, 40.441409387896144, 36.48158842517484, 37.80730639734576, 37.54587258062055, 37.799438122780096, 37.973210888524214, 38.219539657715835, 38.62509312168245, 39.37837646853539, 36.889169754520545, 38.91709396916051, 38.740908945760424, 37.73626442878477, 39.14805881438717, 36.57400731117495, 37.25050633953464, 37.954332520884854, 37.16715597337292, 37.79431158496488, 38.02044014776907, 38.72015960754887, 38.33095458246047, 38.09909935920469, 40.80642515613187, 40.69814420515492, 47.830138898664906, 51.781817020908484, 52.81739727143319, 56.66295174629458, 58.14505461723574, 58.8442131780809, 60.149236725222686, 61.17807049905101, 40.00151165070073, 0.2602022844216516, 0.20893693691299808, 2.0756861807838565, 1.4076609428851836, 0.4450064404837547, 6.894871727112801, 59.23345350450086, 55.63312953518283, 59.35727488610053, 37.881662768702355, 18.59356826351535, 30.442548451885102, 49.55619750484344, 46.16150379180909, 4.96060537715112, 0.24954114439747027, 0.09318131968499192, 0.04122563502601078, 0.030761879470740116, 0.036051450372343107, 0.06872115115965567, 0.06372258833218968, 0.03922280156984925, 0.07756005146450574, 0.09208428943830152, 0.01964153293820639, 0.09120521886694817, 0.015918390633868837, 0.09231533389538528, 0.009417655791396336, 0.010280635643510089, 0.031505584221092925, 0.07897209706566027, 0.03362018224452773, 0.0030092424440813525, 0.01871804458900325, 0.27603349137690764, 33.26166375990837, 65.1394643322114, 41.65011129071636, 29.84008808289805, 32.660995914090066, 58.264196611219845, 60.89426740523308, 64.95563460934547, 54.07740769847747, 64.40719704474172, 8.265055648742184, 0.7605556663005584, 1.116717174168556, 2.379976059159925, 0.1848422612754568, 6.950350711422582, 49.83743536856867, 55.72476002477831, 59.24394192234163, 54.09224994720952, 55.28175577040642, 56.15864869086973, 59.45305524333831, 52.43381692517189, 54.08349129461474, 44.57614060371153, 37.868503216774236, 39.043202092570645, 37.47326558636081, 39.20113240518878, 40.638410429800714, 40.94018190137802, 44.88047730538153, 48.529015048857666, 52.40108474608391, 53.896288333400605, 54.367286543692316, 53.96938954630206, 54.445125979761926, 53.67746714622744, 53.0527041804406, 51.85378859120031, 54.101220407793605, 53.095430558727635, 50.72698969994822, 47.600276239456676, 43.74327628843246, 40.22792262415732, 40.83822381111884, 40.53028637363065, 38.930798730542584, 39.84851960212954, 39.4418364955533, 38.408731260607325, 41.82447241198632, 39.23649649466238, 41.23606981769685, 40.43222711932275, 41.700239181518555, 44.666178611017045, 41.74909230201475, 42.764323296085486, 41.181278228759766, 43.157195737285, 41.11840655726772, 40.93499652801022, 40.887700588472434, 40.9985585366526, 38.912167472224084, 38.89388138248075, 42.86616763760967, 43.204840767768125, 48.32020767273442, 46.99717260176136, 48.788774013519294, 45.75107089934811, 50.297643138516335, 47.82438478162212, 46.51667048854213, 46.225818895524554, 44.21617292588757, 44.06679338024509, 41.18301583874611, 39.02959146807271, 39.74453756886144, 39.4775261417512, 40.64408217706988, 42.145902802867276, 41.418714984770745, 41.18478090532365, 44.916143417358406, 43.12344374195222, 41.59138164212627, 42.255776236134196, 44.95960720123784, 40.84774732589722, 39.997361783058416, 40.772637859467544, 42.21877259592856, 41.02808221693962, 39.78696192464521, 39.35416367746169, 40.59603706482918, 39.2063570022583, 39.975718144447576, 41.63301760150541, 38.57351395391649, 40.27164528446813, 39.734719876320135, 39.47716528369535, 40.26156871549545, 38.656797639785275, 40.74351818330827, 40.24927992974558, 39.77330423170521, 40.7818240504111, 39.90983409266318, 39.56582261670021, 40.80234981352284, 39.36773900062808, 39.907919976019095, 39.20984791171166, 39.598405745721635, 39.46785749927644, 40.55174173847322, 40.6252077318007, 39.77718345580563, 40.39878891360375, 42.5166295420739, 43.93004778892764, 50.645110222601126, 54.136878675030125, 55.13541606164748, 56.93773731108635, 59.02168473889751, 59.61175826288039, 61.49637083853445, 62.96974251347204, 42.65410077187323, 0.5095301039757267, 0.8322763274754248, 6.727934181690217, 2.4735336582506857, 0.5495362572612301, 7.863689805230788, 64.4452989485956, 60.72936311844857, 62.9419917445029, 45.94846025589974, 25.314018072620517, 33.92960025418189, 54.688618875318966, 53.87632346922352, 7.729868340876795, 0.41471903182325826, 0.061610836325393575, 0.031133727057866996, 0.060046645662476944, 0.07750349885393536, 0.036933309503740845, 0.058070127326514454, 0.002838150591536936, 0.07376229315395318, 0.2094869573991145, 0.16339670235831893, 0.12116384557298115, 0.20771608387510623, 0.12115328888138457, 0.11757231047076565, 0.2552027180190048, 0.09079726172551032, 0.27519336871562466, 0.1141383366719369, 0.10958493987639105, 0.07906909145775341, 0.565585799274906, 37.80707497750559, 72.71535365812241, 48.7549945615953, 39.92836336935721, 34.70981067226779, 61.56388659631053, 66.51891877574306, 71.04997804087978, 58.99513813757128, 69.98303059608706, 10.656441392437106, 1.0342497090178153, 3.4813280836228406, 3.7451476820053595, 0.3057752922177315, 6.854209005832673, 51.48967496810421, 56.080538611258234, 60.66045491926132, 54.59545866135628, 57.934395882391165, 58.032184493157175, 63.768152729157485, 53.95327644963419, 56.821490026289425, 45.243418139796105, 40.77994131272839, 40.39972243770477, 39.010952365013864, 41.99130650489561, 44.38646654928885, 42.434722608135594, 48.1492550911442, 50.41341973889259, 55.86908755763885, 55.926981741382235, 56.48246388281546, 56.414599034094046, 57.628164675927934, 53.404532940157004, 53.553775202843454, 54.25602066901423, 56.38344364781534, 55.63269807446388, 53.437798561588416, 50.757125269982126, 48.905546895919315, 43.34889765708677, 43.384446097958474, 41.42167637425084, 40.443974617988836, 42.58676936549526, 42.50294439254269, 42.075998321656265, 43.57785817115538, 41.471427717516505, 43.692940512011134, 42.75055185441048, 44.99084103491999, 47.26951060756561, 42.719290564137125, 42.44717221106253, 42.18491077423096, 45.604723345848825, 41.41258824256159, 43.62487562241093, 42.198654759314756, 43.02485889004123, 39.84475020439395, 41.08462710534373, 46.263559941322576, 46.24530130817045, 52.04963645627422, 48.070890057471495, 50.614237246974824, 49.653119271801366, 52.525518017430464, 50.479594046069735, 49.27322595350204, 48.5324667346093, 46.13540826305267, 45.567837376748365, 43.39776254469349, 42.07492359222905, 41.73255558936827, 43.25918912887574, 42.497064759654386, 43.839276298399895, 42.68676234829811, 42.63217864498016, 47.36235310954433, 43.9909347411125, 43.613657643718106, 43.605083342521425, 46.07620400767173, 42.09053462551486, 42.935370014559844, 42.08226626919162, 45.35470754869523, 43.16694674953338, 42.13797569274902, 41.24288689705634, 43.970236393713186, 42.11473172710788, 43.99387259637156, 44.76601077664284, 40.048744832315755, 42.080203102480986, 40.92421785477669, 41.69470079483525, 41.479252846010276, 41.662353008024155, 43.401700604346495, 42.31227013372606, 41.329747784522276, 44.037167718333585, 41.78100470573672, 42.00010830356229, 44.325022620539514, 40.84274630392752, 42.43233780707083, 41.96486188519386, 42.39154515727874, 41.69331227579425, 43.1983414003926, 43.17038274580433, 41.711057078453806, 41.975216942448775, 45.304956205429576, 45.66217037939256, 52.566808808234434, 56.61794254856726, 56.81330011736963, 60.233191136390936, 62.25057594237789, 60.333242954746375, 62.96977781480359, 61.703817152207904, 47.05368218883392, 1.2797240143822086, 0.658739761960122, 12.941755460154626, 5.584011202858341, 0.8542497516159089, 8.348459947493769, 70.06258410792198, 66.28119176433933, 70.88292429524084, 47.80843642450149, 29.70996149124638, 42.86224918980753, 61.69301886712352, 63.86318391369235, 10.728922870851333, 0.49738819260270367, 0.21614357198197998, 0.1302852331390304, 0.18348568810089944, 0.15051176230753624, 0.1641318250087, 0.14349531622663622, 0.20088996467811449, 0.33838535689057847], [0.01090087479115614, 0.014412042482065098, 0.00743333101948543, 0.05563894346837075, 0.011075009449174809, 0.040750825221860604, 0.03768343598611894, 0.04021390100880977, 0.03548296333681192, 0.01661298052978612, 0.017050673374004902, 0.029784010370231928, 0.02773675339056119, 18.128396734114617, 52.39655833090506, 41.32899468944919, 25.40045338292276, 24.08517283778037, 42.77408607544438, 52.3673798191932, 60.20237699631722, 49.723788615195986, 58.998252499488096, 21.093677205424157, 0.4731799061259916, 0.21795955276296985, 2.1578429206725094, 0.46508689200685877, 0.08766842840780174, 17.91655932703326, 55.689050766729544, 51.639811531189956, 58.739352533894206, 55.150709382949344, 54.52009816323557, 51.42877624880884, 52.1388860671751, 43.94885163153372, 38.23278157941757, 37.43864282484978, 36.275330589663604, 38.49785927803286, 40.012054981723914, 38.56527697655463, 43.8564484350143, 47.0939374739124, 49.50176285159204, 52.057422361066266, 51.670178521064024, 50.43885630946006, 49.50656383268295, 52.023760580247455, 52.26928526355375, 51.34056214363345, 50.757321388490745, 52.70166381712883, 51.326398464941214, 52.778961966114665, 48.54045660265031, 44.30901935023647, 38.89623480458414, 38.32168602174328, 38.41038650082004, 38.388448684446274, 38.49883987057594, 36.81537428209859, 37.81979130160424, 39.36452657945695, 38.45412877298171, 37.71274981960174, 36.84876149700534, 41.434902606471894, 41.68771113118818, 40.17315849181145, 42.64333386575022, 40.280207818554295, 40.81796084680865, 40.86105592789189, 39.10437537777809, 38.37609714077365, 39.639429815353886, 38.946499978342366, 36.2255714016576, 43.742181947154386, 44.626562672276656, 47.13620493488927, 47.77569247830299, 49.06406948643346, 45.36838877585627, 48.55795037361884, 46.806800365448005, 46.277292159295854, 45.5443972925986, 43.21580379239975, 42.53346435485348, 38.91644285571191, 36.348478871007124, 38.323815868746856, 38.497251310656154, 38.200982924430605, 39.85719196258053, 39.9486106441867, 39.87041427243141, 42.80811263668922, 40.607282500113214, 40.51447137709587, 42.50411325885404, 41.53879442522603, 39.60008844252556, 37.32840853352701, 39.57835458940075, 39.311837380932225, 37.73315006686796, 36.40755368817237, 38.5092027725712, 37.017890176465436, 38.78002674348893, 36.543040198664514, 38.285506079273844, 37.22953342622326, 37.45004907731087, 36.80516043016988, 38.46991631292528, 38.263379989131806, 43.12638944195163, 42.23597218913417, 41.23211999093333, 38.80281571419009, 38.346534236784905, 37.76535664835284, 39.32962532966368, 38.69069476281443, 37.70874115728563, 37.8888407061177, 38.330487820409964, 39.752778468593476, 37.74662340840986, 36.735153967334384, 37.72799607246153, 38.244254512171594, 39.15651152210851, 39.27768922621204, 39.497498850668634, 40.01436525775541, 47.13186679347869, 50.74978259301955, 54.30881969390377, 56.04956365400746, 56.87880369924731, 56.560291551774554, 60.423896774168945, 21.0015623031124, 0.07301620778537567, 0.800733974864406, 2.9223849408088194, 0.3614260027966192, 0.4387599434102736, 8.820332846333905, 61.35474974109281, 55.67456545368318, 57.815304879219305, 38.739445901686146, 23.181478361929617, 24.400329397570705, 48.12251629367952, 43.35833095735119, 3.313295461477772, 0.10774540189172953, 0.07690972708646329, 0.08314075684475322, 0.0773584324445936, 0.04797485431716327, 0.03961239558374209, 0.02549085747300377, 0.0862755656482712, 0.09618853654472098, 0.011731559249211945, 0.06850182018693417, 0.030017180721305554, 0.09367469562998704, 0.07472891225329331, 0.008811244530783547, 0.02887372746162357, 0.06914022423687481, 0.03725222041529994, 0.01102617900488117, 0.02530989984440948, 0.04863020040154938, 0.06934970331889007, 23.668726951845233, 59.35936550940237, 45.926342010498054, 26.93904426790053, 26.805664070190925, 54.03068834735502, 57.93601189890216, 64.52298933459868, 54.330098552088586, 64.97849026033956, 21.790421547428256, 0.41223785689761566, 2.1593062098949187, 2.5967232931044797, 1.7413511920359828, 0.15065955598988842, 22.395804082193685, 56.916085827735166, 53.31117268531553, 57.92973218425628, 59.868018473348315, 55.879630888662035, 55.025538706010394, 55.138922660581535, 48.154518911915446, 41.14675744887322, 38.73301713697372, 40.108949292090635, 39.90721787175825, 40.24538501616448, 40.94843456822057, 44.35300480934882, 47.49693355252666, 52.19269314119893, 52.305324000696984, 53.662134601223855, 52.62957065336166, 51.498092374494, 53.05130781665925, 52.603537882528, 53.5069146463948, 51.056158927179155, 53.412730693817146, 53.32162580182476, 54.04362432418331, 48.306467610020796, 44.44456861865136, 41.63857560003958, 40.35382286194832, 40.50774451225035, 38.235107544929754, 39.27201747894287, 38.00285223991641, 39.54609309473346, 41.25077870584304, 39.088862403746575, 39.49454922829905, 39.95496096149568, 43.56190981403474, 43.93396623672978, 41.46956459168465, 45.9787017299283, 41.87076814713017, 41.89835809892224, 43.20029081836824, 40.939205231205115, 39.45703960234119, 42.177262152394945, 40.6717937223373, 39.454191961596095, 45.05703887631817, 44.996728512548636, 48.09108634148875, 50.64351774031117, 49.96149601474885, 48.15234984121015, 48.36092579749323, 46.810153991945334, 48.10665422870267, 48.09644822151431, 43.9884126570917, 44.76275520939981, 41.37431375442013, 39.580704089133974, 40.60653724978047, 40.00881902633175, 40.7299114811805, 41.02377937686059, 41.84670440612301, 42.50249724234305, 43.53460619526525, 43.15803904687205, 42.68837052006876, 44.2206601173647, 45.43713615786645, 40.63059314604729, 39.134232459529755, 40.256924629211426, 40.37913391667028, 40.495322365914625, 38.07926001087312, 38.44864137711064, 39.41018689063288, 40.23761872322329, 37.951943797449914, 40.8566903298901, 40.51030581997287, 39.90504095631261, 39.53560859926286, 38.79663405879852, 41.9803983934464, 42.91480110537621, 44.93023649338753, 43.63607791162307, 40.99838202999484, 39.06628524103473, 40.527234769636586, 41.64615361921249, 39.75221756965884, 39.70556097645914, 39.49708307943037, 40.579971036603375, 42.26682555290961, 38.70472115855063, 39.26590642621441, 40.245267345059304, 40.677277195838194, 40.68074064870035, 40.52312020332583, 41.45718951379099, 43.536873325224846, 50.07920634362006, 53.78880362356863, 57.07431816285657, 57.25781448425786, 60.96814524742865, 58.17961069845385, 60.22275763173258, 24.263038596799298, 0.17280501283464894, 3.8984878409293393, 5.272703959095863, 1.4724397442994581, 0.5622844506175287, 9.480222598198923, 68.77252440298759, 59.64793036060949, 61.37584424787953, 46.97152422320458, 28.336200368019846, 30.65621368346676, 55.110685517711026, 52.12242387956189, 5.021107937059095, 0.1820701874432064, 0.18368315492426196, 0.04651043511506531, 0.04553540437031658, 0.050756845157593496, 0.004332214762877313, 0.01805379847815681, 0.032788831289977796, 0.03342109131476572, 0.08740485585745304, 0.1286083279598144, 0.09487527798140243, 0.2689831229227205, 0.2892411842701897, 0.09519204001633391, 0.08952917170620735, 0.19122763476785154, 0.15512558811854932, 0.15576813670416034, 0.10642365507420995, 0.2657600990947216, 0.22489532978544313, 28.021459579467777, 68.53528376548522, 55.12329593781502, 36.32550947127804, 37.67730728272469, 56.183081134673095, 61.62436562199747, 68.9643753728559, 58.50859165191651, 69.204204774672, 26.830680947149954, 0.9745747692161991, 3.292646634001886, 6.271943449974061, 1.1070637308782147, 0.2592568399925386, 23.07836513365469, 56.984421360877256, 55.458689966509425, 62.735584858925115, 60.74736287516933, 58.70503179488644, 56.557032062161355, 59.237724965618504, 49.86934777229063, 43.933209219286525, 40.28351437660956, 41.19453976231237, 43.06557701480004, 43.71927138297789, 42.74900644056259, 49.441927094613355, 48.90104009259132, 52.989385358748905, 56.823545348259714, 56.55042679079118, 54.96671099816599, 50.4113212708504, 55.479980591804754, 56.367922829043486, 56.017247246157744, 53.53702668220767, 57.49656523427656, 53.90967146042855, 56.91006106715049, 51.92141809771138, 47.962962119810044, 44.21235645970991, 42.533774222097094, 41.61310765051073, 41.64043872587143, 42.64481259930519, 40.70129779077346, 41.66380428498791, 44.335110956622714, 41.1641296263664, 40.725392910741995, 41.506783962249756, 47.05168178004604, 46.8315387541248, 42.21653292256017, 48.3047103881836, 42.9262661933899, 45.579267163430494, 45.123609342882716, 43.124561617451334, 41.90999184885333, 44.02863264083863, 42.098465658003285, 40.96892895237092, 48.31699132919312, 47.07594163956181, 51.10037972850185, 53.660334233314764, 52.66714695961245, 52.090919402337846, 49.68605541413831, 49.916137726076194, 50.726299362797896, 49.036142210806574, 46.51130860851657, 46.86125855292044, 42.61522223872524, 42.34177027979205, 43.137430913986705, 41.17865416311449, 43.19759222768968, 44.33202797366727, 44.89696694958595, 43.4172567244499, 46.91184143866263, 46.306400068344615, 44.86397197169643, 47.36139605122228, 47.897329099716686, 43.13529714461296, 40.46702246512137, 43.29001111368979, 43.71170905328567, 42.253403202179946, 40.44116620094546, 41.32473499544206, 40.19839109912996, 43.64080829005088, 40.576511506111395, 43.99751255589147, 43.90449746962517, 43.11987830746559, 42.682098650163226, 41.535432953988355, 43.762146811331476, 47.69409933397847, 47.84868778720979, 45.14424493235927, 43.84008430665539, 42.58054848640196, 42.30238576089182, 44.58915502794328, 43.36448515615156, 42.570675880678245, 43.2240133131704, 43.26689658626434, 46.63949166574786, 40.85396428262034, 42.34277440655617, 42.91820964505596, 44.038167922727524, 44.18888499659877, 44.7138903217931, 43.93168733965966, 45.28573659158523, 53.1208828187758, 57.70083442811043, 59.36641400860202, 60.075076472374704, 61.745602161653586, 60.50734127721479, 60.659462559607725, 26.296728695592574, 0.22067204027646975, 3.4184564121307868, 9.682753201453917, 3.3796886859401583, 0.9563111105272848, 11.564954500044546, 74.99929489627962, 65.50294645370977, 67.1647919377973, 51.56926770364085, 35.41106770115514, 38.14126876092727, 62.02518086279593, 61.832106113433845, 7.054360691578158, 0.3130195728473125, 0.35464330546317563, 0.12297155260438881, 0.3273360094716472, 0.1978836058368606, 0.13213864497600064, 0.14862206854647206, 0.19340442763941904, 0.1902672975894905], [0.04774896946224955, 0.047488162489307505, 0.0960727270332075, 0.007135835617044641, 0.09868977531310051, 0.025640077994114933, 0.012250307068649319, 0.04057403894201402, 0.0575738440778467, 0.06166926202093882, 0.041753894784638, 0.04988032182858837, 0.03445183580380774, 11.02447836629806, 49.01094098244944, 41.1240626150562, 29.181465256598692, 19.995590063833422, 30.350470812089984, 56.641712111811486, 57.89439947374406, 51.18455379239975, 54.51665824459445, 28.573089953391786, 0.3719633583339953, 1.0571527961761722, 1.0885847095520267, 0.7454813848580084, 0.28508767004935975, 7.711600392095505, 49.85988701543501, 59.05078088083575, 56.85112353294127, 50.599398920612956, 52.09607339674427, 49.285891286788456, 43.78790893862325, 39.99581636921052, 38.500428430495724, 36.810173219250096, 37.117173210267104, 37.71030226061421, 37.87286881477603, 42.219764955582164, 45.61106581841746, 46.21313787275746, 48.319682075131325, 49.195614014902425, 49.41825559062343, 49.46531226558071, 50.04804311260101, 51.272199153900154, 50.91212949445171, 51.61038983252741, 50.84838313441123, 50.443029711323405, 50.872062483141505, 50.59817121874902, 50.202902209374216, 44.48785589587304, 37.05677655435378, 39.12708982344597, 37.89160989945935, 36.662664644179806, 36.19117221524639, 38.54531211237754, 38.190302310451386, 38.27215825357745, 39.65431128778766, 39.210318596132346, 40.083257767461966, 39.336297281326786, 40.22097610658215, 40.59897884245842, 38.773480307671335, 40.46433171918316, 41.040076824926565, 42.15232764520953, 38.37331225795131, 40.839780992077245, 37.49426595626339, 39.159872993346184, 38.86897825425671, 45.73628356379848, 46.81480984533987, 47.43873734628001, 48.814908765977435, 50.0101726285873, 46.097082784098966, 46.08937924908054, 49.10951406724992, 44.30390065716159, 47.87085310105355, 42.729112179048606, 42.293999733463416, 39.34670332939395, 37.81926178163098, 38.28260352534633, 38.49151288309405, 39.05151359496578, 40.27402616316273, 40.6675850191424, 39.01545132360151, 39.199159452992106, 38.62469303992487, 41.41037994815458, 41.377349668933505, 39.548328845731675, 40.101587003277196, 38.474003422644834, 38.82065857610395, 38.06956391180716, 37.72246160814839, 36.595541123420965, 37.68779177819529, 36.58645691410188, 38.07081122552195, 38.22424257955244, 38.056149405817834, 36.39594739483249, 38.36863287033574, 38.82356505240164, 40.72217264483052, 44.1297278096599, 46.803183940149125, 49.334387471598966, 49.8349093621777, 46.37121331307196, 43.177156679091915, 39.02608879150883, 39.399851445228826, 37.468225340689386, 39.8521242603179, 39.38070243404758, 39.020346441576564, 38.628984112893384, 38.132933724311094, 40.290260853305945, 38.63036478719404, 36.89099365665067, 36.97158267421108, 38.540683715574204, 38.70984769636585, 38.90352649073447, 42.26191474545387, 45.052124146492254, 52.78517892283779, 52.94354461854505, 56.12608517369917, 56.013571985306285, 60.44533252716065, 9.437701163753387, 0.1569347813605301, 1.8901774383360341, 3.6348138605394675, 2.5911187164245115, 0.5909993872046471, 14.659929121694258, 62.65304642338907, 53.97060155868531, 55.98316577173049, 38.1761033304276, 24.89556001078698, 34.75609071793095, 50.000194118868926, 38.51674549041256, 1.332062896220915, 0.10424762829056672, 0.03891774918884039, 0.045359713596201716, 0.02399530445766305, 0.01626114890490088, 0.03529723298044936, 0.05407430464401842, 0.12809978347391854, 0.1058490738092411, 0.02784726157363865, 0.05444228348712768, 0.09148912339080727, 0.01356011153303928, 0.032987972015454885, 0.0049161537918412405, 0.06273308235611166, 0.014693974329519176, 0.015088461730028353, 0.10874303989112379, 0.022285269806161526, 0.04974755879131056, 0.06406953040089819, 14.633255043337423, 58.98240612399194, 47.31587694537255, 29.225409530824233, 26.43858317405947, 45.117804235027684, 59.14018738654352, 64.72249677104335, 53.74279814381754, 62.65279539169804, 29.899002082886238, 0.3037989998777067, 1.226961761713028, 1.074152225928922, 3.4225562695534, 0.13958695014157604, 9.762795048375285, 51.44162593349334, 59.8126502959959, 58.401244225040564, 54.03029611033779, 53.44374487476965, 50.93243168246362, 46.23618571988998, 41.047223383380526, 40.2629219332049, 39.51875809700259, 39.31530867853473, 38.683175579194106, 40.092283141228464, 43.98480799890334, 47.77279384674565, 48.71373122738254, 50.04691739236155, 49.68605149176813, 50.67979181966474, 50.769904352003536, 51.3826923216543, 52.037579090364524, 51.83119573900777, 53.601157434525035, 51.89878994418729, 53.03699508790047, 53.516457773024044, 54.099957404598115, 52.27405486568328, 46.68161007665819, 38.82627541019071, 40.186820107121626, 40.11566438982564, 38.86649931630781, 38.27462542441584, 40.45509453742735, 39.627878435196415, 39.377513547097486, 40.50051950639294, 40.12534872178109, 40.661442587452555, 40.540249193868334, 42.86564988474692, 42.79148570952877, 41.20496542223039, 42.92591318007439, 43.70158149350075, 42.62975462021367, 42.8199032814272, 40.54485013408046, 41.008913593907515, 41.1632235588566, 40.06091594696045, 46.05296396440076, 47.30842444204515, 48.40844923450101, 50.57147164498606, 51.55476277874362, 49.100590675107895, 47.39867425733998, 49.742435562995176, 48.23286041136711, 48.716751452415224, 45.73942145993633, 45.132364073107325, 40.26468307741227, 41.58045784119637, 39.89853374419674, 39.67469192320301, 40.10521519568659, 40.8318107358871, 42.140387950405, 38.89561507009691, 42.480288782427394, 41.38602595175467, 41.99332260316418, 43.172253716376524, 40.997464195374526, 40.68404720675561, 39.5048572171119, 41.0142009488998, 39.64528983639133, 38.96829266701975, 38.599189789064475, 38.47654119614632, 37.820850341550766, 39.27139382208548, 40.27867024944675, 39.65717461801345, 39.21594327495944, 39.43316805747248, 40.4287911230518, 44.06416539222964, 47.0994484040045, 48.70237204336351, 50.47055298282255, 52.247453351174634, 47.78659666738203, 44.762182543354655, 41.67685401055121, 41.93314559998051, 39.9546746284731, 42.50972617057062, 41.06000246540193, 41.6808077596849, 40.92443750750634, 40.909183409906205, 42.818291187286384, 40.55580139160156, 38.90873539832331, 38.983460472476104, 40.09930810620708, 39.96866572287775, 41.48791736172092, 43.67523885542347, 47.23411121676045, 54.764285318313114, 54.8153349661058, 59.95596977972216, 59.37056387624433, 60.7534307818259, 11.920010389820224, 0.33629883982000813, 6.264294337841773, 5.383052979746173, 3.2455625024534043, 0.7959873553725981, 15.56914629474763, 69.83601231728831, 58.174076234140706, 60.97345613664197, 44.085263821386526, 25.011034588659964, 37.45170431752359, 55.083103410659305, 45.961925752701305, 2.228614490839743, 0.18222941115738886, 0.05099812837978525, 0.06783936863705035, 0.030362707442573966, 0.08553375505031117, 0.07245515563314961, 0.012832250438570496, 0.03589843963122657, 0.0456261474849476, 0.10120974493122871, 0.14572492319970362, 0.16505301509413028, 0.10852937796904195, 0.22889829240739348, 0.09273718021089032, 0.25932214132720427, 0.1066379145448727, 0.20813210026150752, 0.17049842934694984, 0.1500256488760633, 0.11939831934268437, 0.17409159621644407, 17.90471573029795, 67.26967611620503, 53.74142139188705, 41.00264172400198, 29.22487020492554, 41.00446562613211, 65.98961845521005, 67.98816803962954, 61.32418663271012, 64.65209022645028, 35.61117133786602, 0.6393695045863429, 4.696669578552246, 5.164189136797383, 3.455638275031121, 0.49474586342130944, 11.67055647219381, 54.03659935920469, 61.97576292099492, 61.04935792184646, 56.14012725891606, 56.36715404448971, 54.99750160401868, 47.93292853140062, 45.02722886300857, 41.872168433281686, 42.82870900246405, 42.001406608089326, 40.77694462191674, 41.302683430333296, 45.97176305709347, 51.18595015618109, 52.15052766184653, 52.18264795118763, 52.88360295757171, 52.469039809319284, 51.724997566592315, 53.83838630491688, 54.971551202958636, 55.261814440450365, 55.825808125157515, 53.66039699123752, 54.16883814719416, 56.18035116503316, 56.28884392399942, 54.06931977118216, 48.25636325343963, 40.296124796713556, 43.5659537776824, 41.54519573334725, 39.47656123868881, 38.89732130112187, 42.188691939077074, 42.45544056738577, 41.048906080184445, 41.55287181177447, 42.25581938220609, 43.55271577835084, 42.780820785030244, 45.4559164662515, 43.97169943778746, 42.55339391769902, 45.045048190701394, 45.88392157708445, 44.52353377496043, 44.293161207629794, 43.559709364368075, 41.427108856939505, 43.32441030010101, 43.10518118642992, 49.98738758025631, 51.88726602062103, 50.169369866771085, 53.74339434408373, 51.726135053942286, 52.40798027284684, 52.31450626927038, 51.13153119241038, 48.80559313681818, 51.39820137331563, 47.786957525437884, 48.3002898769994, 42.56823224406089, 42.775807995950025, 43.57584207288681, 42.01254221700853, 42.16356131338304, 43.120156795747825, 43.95611193872268, 41.44528904268819, 43.36478325628465, 42.010051511949115, 44.7151650920991, 45.86213281077724, 43.92778458133821, 43.5359594129747, 42.66222792287027, 42.58611825204665, 41.83643564101189, 39.55961350471743, 40.941950890325735, 41.86360589919552, 40.938989500845636, 41.13118956165929, 41.158453956727065, 42.46097110932873, 42.1421451722422, 41.86518661437496, 43.305747662821126, 47.17483243634624, 51.107322323706846, 50.5880436589641, 52.90800402241369, 53.79597371624362, 50.963504698968705, 46.883196369294204, 44.58880985936811, 43.92491340637208, 41.898432623955514, 44.15715302190473, 43.51155442576255, 43.217604160308845, 44.31616590869042, 42.99028711934244, 44.92858125317482, 42.468341242882516, 41.26658978000764, 40.540927763908144, 43.13050793063256, 42.21327735531715, 43.63595239577755, 46.844992483815844, 49.44895598196214, 57.42085172284035, 56.02353088317379, 62.39319724421348, 61.094218069507235, 64.02562495200866, 14.831197454083352, 0.5356239779822288, 7.319651669071567, 12.46693588072254, 10.388013009102115, 0.8528896084716244, 18.5594299147206, 75.40633493854155, 62.61443461141279, 66.37536002743629, 52.395817002942486, 36.65019542940202, 49.17622573914067, 62.549903777337846, 54.9038746280055, 2.9151989135050007, 0.3611040620073196, 0.18965248138673846, 0.12952392560339746, 0.1781281900982703, 0.1993564405148068, 0.2670038888050664, 0.07701428276636908, 0.20884500636208445, 0.13397668908920982], [0.038879260931524544, 0.037455746994143536, 0.06228959788718532, 0.03159933614604656, 0.03916024666039213, 0.03917307480268421, 0.01847369701511437, 0.10904324676601157, 0.036339916949791294, 0.06907243311645524, 0.08350169150939873, 0.0700004184017739, 0.08352327220622571, 10.614746597505386, 50.195061391399754, 43.61757216915008, 24.63464394692452, 29.770948463870635, 33.533519314181426, 40.28681701229465, 56.04047944468837, 50.05092605467766, 53.59916879284767, 36.28376368553408, 0.24712196130666042, 1.3622948094721765, 2.2868474693067613, 6.728364171520357, 0.3365479409694672, 7.560728384602455, 57.03816175460816, 55.4845932991274, 52.42932581132459, 50.565513564694314, 46.83095039859895, 42.54865569453086, 40.43947565940119, 37.72558381480556, 37.66803872200751, 36.44111740973688, 36.506271900669226, 37.24501894366357, 39.508104939614576, 42.16575391830937, 44.58511890903596, 46.93483829498292, 47.97867513472035, 48.056361598353234, 48.94682591961276, 53.00689481919812, 51.28519004391086, 51.2448759232798, 49.63740625689107, 50.129075357990885, 50.00996082059799, 51.462959704860566, 52.326712685246626, 50.704263487169825, 51.13069180519351, 46.535544933811316, 38.69939457985663, 37.1830415725708, 38.831601988884714, 38.427684153279955, 39.86485627389724, 36.3678357678075, 36.97021376702094, 40.774795163062315, 40.11888857810728, 38.828946544278054, 39.11784087457965, 39.739552236372425, 39.02479833172214, 39.25048366669686, 39.8235890173143, 39.26112897934453, 40.77026482551329, 39.35579538345337, 39.106438544488725, 39.60504239605319, 37.97711756921584, 37.416242168795684, 36.89628885638329, 42.88761515771189, 45.22667354153049, 51.08064236179475, 49.29619143086095, 50.8291752876774, 50.41486709348617, 43.90403070757466, 53.51311591363723, 49.39271703843148, 50.69931737838253, 45.400787553479596, 44.01964649077385, 38.66948650729272, 38.50058140293245, 39.163701226634366, 38.86063929527037, 38.803325622312485, 39.743384392030784, 39.26429040970341, 40.0484702664037, 38.30445112720613, 41.25063357814666, 39.73447668936945, 39.85180262596377, 41.396800702618016, 38.55414921237577, 37.84237630905644, 38.98180523226338, 39.47230938942202, 39.31530475616455, 36.97054324611541, 36.435284845290646, 36.73786824749362, 40.3239304788651, 38.46468779348558, 36.7574800983552, 38.71717076147757, 39.53424753681306, 39.87544667336249, 42.74245608237482, 45.09725493769492, 49.641599270605276, 53.615764341046734, 54.33671951293946, 49.79821558921568, 49.587015567287324, 42.59422186882266, 39.665795987652196, 39.00882644038047, 38.88710744919316, 39.88772761437201, 39.82821349174746, 42.621874578537486, 41.57354270258258, 42.826547776499105, 40.50792101890811, 39.72784003903789, 38.85822311524422, 37.45392437904112, 37.72340689935992, 38.37009199203984, 39.00476286488195, 40.2122135316172, 46.331840561282256, 52.51018547242688, 55.384984708601436, 57.16952193167902, 53.61593300296415, 12.180423409708085, 0.23285150527954104, 7.388171063315484, 4.571323865844358, 0.4435084934436506, 0.2096264466883675, 22.51722889561807, 61.692406977376635, 54.689262144027225, 49.470560396871264, 32.833964593948856, 31.934221906046716, 29.993258599312078, 52.812710039077274, 22.518554656736313, 0.08554738375448412, 0.050499006775358034, 0.05703881210196884, 0.08694887266404207, 0.013246037509112109, 0.15507531742895805, 0.011151541632810428, 0.044328796737376726, 0.05802848661739019, 0.023227021691479513, 0.021288748379916917, 0.034813034768787124, 0.04725657794023714, 0.006020520288016528, 0.06500700368515908, 0.021976386985531258, 0.062179273565209685, 0.011266699969588269, 0.0697623489184245, 0.042347678043428934, 0.049892004669433644, 0.05382887305571668, 0.011269569926474605, 13.377160122317653, 59.20250600384128, 49.64094815715667, 32.24960007975179, 23.531732290021836, 32.68182173851998, 52.2181297117664, 62.2774951688705, 58.24023092946699, 57.92715910942324, 40.19929324426959, 0.09646062033190843, 0.25675645158175503, 4.299768372889488, 7.473446332639264, 0.292611725988888, 8.547096617760198, 57.61806457273422, 58.56320281182566, 56.30255653012184, 50.840612919099875, 48.736469207271455, 45.40046984149564, 42.03806900208996, 40.85690606024958, 38.37349660934941, 38.77126809089415, 38.948123839593705, 39.97805979944045, 42.751650118058734, 44.444325431700676, 45.778923649941724, 48.90886129871492, 50.00944306773525, 52.12933509580551, 51.732148047416445, 54.86969509432393, 53.2172985999815, 54.85266416303573, 52.132437690611816, 52.476900239144605, 52.65087304576751, 52.679639708611276, 54.26202189537787, 52.020108853617025, 52.643824546567856, 46.850872116704146, 40.79180648249965, 39.70327815701885, 42.05600600088797, 39.75869340281333, 40.91443546356694, 40.3235774655496, 39.385911341636415, 40.43993849908152, 41.57824562441918, 41.082383509605165, 39.49467866651474, 41.1839807418085, 42.743915204078924, 41.405520131511075, 42.04507043284755, 40.51298479880057, 41.41854632285334, 41.820914822240034, 39.72642014103551, 40.44020914262341, 39.45142276825444, 40.477063732762495, 38.87711717236427, 44.509075918505275, 47.51837322788854, 52.526278957243896, 51.40525379488545, 54.07941987437587, 52.2840843662139, 46.45068837750343, 54.851750250785585, 51.44109249114991, 51.96279518065914, 48.01156420861521, 45.85817513927337, 40.89359198847125, 39.39415616373862, 40.821220336421845, 40.07584841020646, 40.98567747300671, 42.38766201080815, 41.78784924168741, 41.29768633073376, 42.07708089582382, 42.454471741953206, 41.14213297444005, 42.30510396342124, 42.59998775297596, 41.72146312652096, 39.34825658798218, 40.29460683945687, 40.72509873297907, 41.17638703315489, 38.921004572222316, 38.50190716405069, 40.114726943354455, 40.863813354123025, 40.46837568283081, 39.45029704801498, 41.03085533265145, 40.265710738397416, 41.89690289958831, 45.93715598506313, 48.436011729701875, 52.830627426024414, 55.93519126215289, 54.95246494970014, 52.82489684320266, 52.165283618434785, 44.60999458066879, 42.41964893956339, 39.30123521435646, 42.78283688329881, 42.00113988691761, 42.84029960632325, 45.43753623962403, 44.31171009617467, 44.405011515463556, 42.95801777993479, 42.097033992890395, 41.01551886527769, 39.48782236345353, 39.33591681142008, 40.75499503843246, 39.95436868359966, 42.80745760087044, 48.856823213638805, 54.23844845064225, 58.69491600221204, 59.12746714007471, 55.80675717323057, 13.416232812789179, 0.391206199964208, 8.072853136447169, 6.981277619638751, 2.920229598399132, 0.3320332316140975, 24.82920135221174, 68.30270290374756, 59.06315203635924, 56.35819535101614, 36.145307940821496, 27.584591873230476, 36.040729707287205, 60.43772312902636, 28.699184348506314, 0.13169547843356288, 0.049686490092426545, 0.037653819026966254, 0.055514442689356305, 0.06744154683885074, 0.03129555164055238, 0.011691842378387529, 0.04082827288056574, 0.005603821604557697, 0.05066473457601763, 0.1484700920240533, 0.06879344687707002, 0.1742347474059751, 0.08760680429517262, 0.1708967644240587, 0.10061353700415743, 0.16238168182392276, 0.2651884442856235, 0.1666752982043451, 0.16886087044352488, 0.22774880812052758, 0.17628014087677005, 0.14504935622455614, 16.73501395410107, 67.573989283654, 55.796660992407034, 38.79704590766661, 38.99976576528242, 46.30117547127509, 53.451628838816, 67.49616945943525, 61.098567978028335, 62.67381145108131, 44.56686812062418, 0.6171539966617862, 3.6101678927098555, 8.958594433722958, 18.403688284658617, 0.5331287989693304, 11.310143605355295, 60.862080435599054, 59.95639731807094, 57.76582417949554, 53.90064216429188, 50.92336316262522, 47.56681057714647, 44.568358621289654, 42.293678099109286, 41.82259751904396, 41.28486802501064, 41.098237729841664, 41.99137710755871, 45.13159528855355, 44.65441934524044, 49.08735267577633, 51.54555305357903, 53.58065912800451, 54.26170026102374, 52.772207644677934, 57.065273177239206, 54.75051779900828, 57.95376846867224, 55.114341166711625, 55.59813414850543, 54.89897951003044, 54.880842470353656, 56.99131688764019, 54.00051355361939, 55.17482019239857, 49.940381896111276, 41.042469470731675, 40.8337797657136, 44.23508267248831, 42.57608482914586, 44.92321545077909, 40.59413079292544, 40.61153434938, 44.41149127098822, 43.50106993029195, 42.76701011965352, 42.50914173741495, 42.89786823334233, 44.393369920792125, 43.23299554086501, 43.67348163358627, 41.493553807658536, 45.031174767401914, 43.271415156702844, 42.02061445482316, 43.84564622755974, 41.02550129736624, 41.886504696261504, 40.85380738781345, 46.54103232968239, 50.64651050875264, 56.81306869752946, 52.700573398220925, 55.281410601831254, 53.3156128083506, 50.08697263656124, 56.75579817064347, 54.10180484094928, 55.15347857629099, 49.87581183833461, 47.40305162245228, 43.352051242705315, 41.71078251254174, 43.752862561133604, 42.92831759299002, 44.02348649117255, 45.750290347683816, 43.78628507737191, 43.71114423198085, 44.47483754927113, 44.702083987574426, 43.40143780554495, 46.323646729992284, 45.714059414402136, 43.35858983378257, 40.85760031977008, 44.29867606009207, 43.51522184187367, 44.31474208831788, 39.93345460584087, 39.506998831225985, 41.13245648722495, 43.73514129269508, 41.56499978034727, 41.04643498697589, 43.768748160331484, 44.18137365771879, 44.82270079274332, 49.076574002542806, 49.73023699175928, 54.881858364228286, 57.666113607345096, 57.283188296902566, 55.55643150883337, 54.76989430765952, 46.50820601371027, 44.45859109201739, 43.389200010607325, 44.14655477769914, 44.511790198664514, 46.72499541313418, 47.70968683304326, 47.54849703081193, 47.49989886437693, 44.88728654000067, 44.41923402970837, 44.134524868380645, 41.233190797990375, 41.05921799136747, 43.29560833592569, 43.25842034432196, 44.6161291676183, 51.91238487920454, 57.13593859826365, 62.15687836370161, 60.51738254485592, 57.85658390291276, 17.73770513073091, 1.4555234197647342, 16.729779551106116, 12.957526330024967, 3.705319444979391, 0.5321819142949197, 28.27783157748561, 73.20794843858289, 65.86190608239943, 59.46416339566631, 46.794429209924516, 44.956990980332904, 41.80757484128399, 67.86814351235667, 36.66638305110317, 0.3834829918078838, 0.13782018284884193, 0.1406944987754668, 0.11878324267003806, 0.2563526466368668, 0.23651142905075706, 0.06979097762415487, 0.09756544169278876, 0.22439191808863995, 0.14790556183265102], [0.03694574311075192, 0.0773202736050852, 0.018085466637726755, 0.13004835875284287, 0.11999101858706245, 0.032037025159825726, 0.04449137974710715, 0.033727250692825166, 0.013248962049763049, 0.015669940659145436, 0.0621671961890834, 0.07443558484796556, 0.05937561775828081, 7.555306688431771, 49.921558441654334, 43.42256761366322, 42.76807700434039, 87.91551082364975, 78.03404838808122, 33.12282754528907, 50.55657448307161, 54.447495091346006, 51.934785535258634, 47.84244729626564, 1.181871297378694, 0.4325648355147531, 0.711228858319021, 1.914170944402295, 0.3118596850864349, 11.972161243038794, 57.925374430994836, 54.69087423816804, 54.58550760822912, 48.19462514692738, 43.14896268229331, 39.240701275487105, 39.304024019548976, 38.407397654748735, 37.815292343016594, 36.3461725173458, 37.100271717194595, 38.85714054107666, 41.02610534237277, 41.99446401288433, 45.93542229744696, 46.20259454173427, 47.50861437089982, 47.923785486528956, 49.993710440974084, 49.635076369008715, 51.708237278846006, 52.2796913116209, 50.58377612021662, 51.76846527284192, 51.39465947305003, 50.80862991271481, 50.98467765315887, 51.122192029030096, 51.04012427791473, 44.01959942233178, 38.13128240646855, 39.23505698480914, 38.900345448524725, 39.90367204912248, 37.68096293172529, 37.98771973579161, 36.85355855572608, 36.54000036178097, 40.6420111656189, 38.15279268449353, 39.80814272357572, 39.66509388339135, 38.7252273098115, 39.2938611584325, 39.721921182447865, 39.34875472899407, 39.97048962500788, 39.4568827075343, 40.13468788516137, 39.988454080397084, 38.89319104533042, 37.22511291503906, 38.613169116358605, 42.35524754370413, 48.28021910882766, 49.431925050673954, 51.28119314870527, 50.79312478342364, 57.09493021811209, 45.15999324860112, 51.29865946308259, 52.585224336193455, 49.6205557546308, 45.91103692208567, 47.968433826200425, 39.3365365459073, 37.74506230508128, 37.51434849154565, 37.951308373482, 38.16789773202712, 38.304596254902506, 40.556903577619984, 38.81207250779675, 39.94457060290922, 39.957361452041134, 39.44712385054558, 38.80582809448242, 42.39631868177845, 39.9886227423145, 38.59638137202109, 38.65126317547214, 39.447116005805235, 39.085504854879076, 36.929550555444536, 37.5444919063199, 37.30011647747409, 37.37619084696616, 38.41511295687768, 37.318936009560865, 37.88472221743676, 38.36456929483722, 40.34502498565182, 42.5396107089135, 48.289495514285186, 50.4278697506074, 49.93734990396808, 55.94447943472094, 52.02873806799612, 50.30254217886156, 50.06440724095991, 45.61396052760463, 42.52363881757183, 43.14648374434441, 41.97582883219565, 43.69574500668434, 44.045279179849935, 44.437657402407744, 45.3525149437689, 43.67339534144248, 44.576113147120324, 44.13480727903305, 38.57585168653919, 38.66526995935748, 38.78973460966541, 40.24229026609852, 39.877199972829516, 43.79624397523942, 51.73149301159767, 55.45337123255576, 57.26946392366963, 51.96166946041969, 7.919797349360682, 0.24592127170293565, 2.649985157674359, 3.988178718474604, 1.5885615132508741, 0.21187168185509023, 32.99205180137388, 61.763699977628654, 52.53138980557842, 49.50088816304361, 29.144138020853845, 25.828997819654404, 32.62126034305942, 50.50673292529199, 12.456125828527636, 0.13986756814823997, 0.01840694394383219, 0.04553190717894224, 0.025839515578662677, 0.06278769676423361, 0.008018420616750637, 0.030188284543973785, 0.0648092610701438, 0.038326080332720475, 0.020408300765519662, 0.03912422903663209, 0.07504238777102963, 0.033571501187379324, 0.034004126359978994, 0.07830048310420207, 0.003957166125239324, 0.028110851360965642, 0.02362760140620653, 0.04755817143426788, 0.0648509975402586, 0.05851037890440034, 0.084476423479857, 0.0749390961361989, 10.005884920397113, 58.70483175400765, 49.05782899548931, 43.706880615603545, 66.00828109248992, 60.07535103828677, 36.605327437000895, 52.92789043918733, 59.46234341590636, 57.02076604289394, 52.21964766902309, 1.060401376697325, 0.3358403208755678, 1.8898300634276484, 4.256028552209178, 0.4196290425475567, 13.120503752462326, 60.21915689591439, 56.457764717840384, 57.62797247978949, 50.42669303955571, 46.67817015801707, 42.21749390325239, 40.874168411377944, 37.906746325954316, 38.67426003179243, 37.87186076564174, 38.90876677728469, 40.85875741897091, 43.41103584535661, 43.94371724897816, 48.05657732871271, 48.58440283806094, 49.68350195115613, 49.3143912284605, 52.52767924339541, 52.51890882369011, 52.76836372190907, 53.098474317981356, 53.02323541333599, 53.2535687569649, 54.46867196790634, 50.77285397437311, 52.08862481578704, 52.22702956968739, 52.48159923861104, 46.574399932738274, 39.727553706015314, 40.510905942609234, 41.211405954053326, 40.22357271563622, 39.74871881546513, 39.53369448261876, 40.027030591041814, 39.41083015934114, 41.97091017999957, 39.03240772985643, 39.79496748216691, 41.46643061791697, 39.97630257760325, 41.154194262719926, 41.283824674544796, 41.576649219759055, 42.4545854906882, 41.45887221059492, 41.83281529334284, 40.12867489168721, 40.89263493014921, 39.93378016256517, 41.251516111435436, 44.447267209329915, 50.83154832163165, 52.3856423747155, 52.63069245123094, 54.35032229269705, 57.260760184257265, 46.02881393124981, 52.35283174822408, 53.38033191619381, 51.906109086928836, 48.11446759008592, 49.53542855478103, 42.504446660318685, 39.48219376225626, 38.29051494598389, 39.29034279238793, 39.79607751292568, 40.10769021126532, 40.79514834188646, 40.407963337436804, 41.91731883633522, 42.21125341230824, 40.843875946537146, 40.93574570071313, 42.744056409405125, 41.76867277391496, 40.80040039554719, 39.32979399158109, 40.13220110247212, 39.6041912417258, 38.473807304136216, 39.965574895181966, 39.41141459249681, 40.454694455669774, 41.36399399849677, 39.00304878911665, 39.73559064249839, 40.08536800261467, 43.06896202025875, 46.85056224946053, 50.43756192730319, 53.77807201877717, 50.90608904438635, 56.31990125102382, 54.036415007806596, 52.57499479478406, 52.04653386146792, 49.418840023779104, 43.45601758649273, 44.89987734825381, 43.60883705077633, 44.32006866701188, 45.77607208682645, 46.94806452720396, 47.565174948784616, 45.34387396227929, 47.636146314682506, 45.65183885635869, 40.96070374211958, 41.005865912283625, 40.63606877480784, 42.28637464584843, 40.829065076766476, 46.68563050608481, 53.74519078962265, 57.338811428316184, 58.47005436497351, 55.94973541075184, 10.634179980524125, 0.624805253840262, 7.1114409835107875, 6.911728603224601, 2.314321711178749, 0.20709687032766882, 35.209940325829294, 66.63469929848948, 57.72282323529644, 55.258766758826475, 38.0001183479063, 29.07961307033416, 35.24093881730111, 57.11411060825471, 16.841484731243504, 0.06272893782044131, 0.02595603372150612, 0.029230054107404528, 0.03270566095447829, 0.05416902375497645, 0.023143837949441328, 0.01643303413725188, 0.01778631313373485, 0.09293660055845977, 0.008918962238596813, 0.09213955502115911, 0.16624671797598564, 0.15467307530343533, 0.19050597994317933, 0.2024919158148189, 0.08371767467789112, 0.0939142819674265, 0.10121753604541864, 0.1668628978152429, 0.1495419409606726, 0.18096813932061198, 0.1832655603967367, 0.17744580494059672, 11.91615862231101, 67.5584488530313, 56.44513468588553, 54.92786384397938, 88.48622352846208, 83.0231071287586, 44.240389639331454, 59.74065911385321, 66.09784449300459, 60.58507873165993, 57.99390216027537, 1.9413602015664502, 2.63120656532626, 3.2860511685571367, 9.314879986547655, 1.4010387562936353, 15.305079587044256, 61.77869912116759, 58.4084221624559, 59.18314518467073, 53.90226602554322, 47.71070272691789, 43.73678476579728, 43.119282107199396, 40.928352032938314, 41.74232229109734, 41.710680530917266, 40.95871902281239, 44.1204906279041, 46.64925836747693, 45.753855782170454, 49.568148966758486, 50.62896574697187, 51.39660889102567, 52.76979146465179, 53.27859740103445, 53.96200764563776, 56.428095909856985, 57.444460468907515, 55.6880937084075, 55.231078747780096, 55.43953311058783, 53.235557233133626, 54.64869306933496, 55.06631566632179, 55.66823474822506, 49.53376939219814, 42.96898864930676, 42.55128368254631, 43.88923944965486, 43.33696188465242, 40.9997195582236, 41.45311417118196, 41.196022418237504, 40.1713228225708, 45.5382352490579, 42.61236675323979, 43.28185650610155, 43.309081677467596, 41.996182011019805, 43.06493374609178, 43.70780629496421, 43.643699076867875, 43.882116425421934, 41.922464986001295, 43.43129880966679, 42.40214340148434, 42.64198064804078, 43.4091805642651, 42.844751496468824, 46.592333009166104, 51.991922701558764, 55.582272083528586, 54.123024863581506, 55.38921302364719, 59.80384065258888, 48.56555977175313, 54.95521453119094, 54.185441540133574, 53.87497025151407, 50.31026532573085, 52.118913358257664, 43.747904685235795, 42.14148621405325, 40.449948387761275, 40.459860217186716, 41.23514806070636, 42.19483437076692, 42.56646325511318, 42.575884788267075, 45.383117275853316, 43.84601885272611, 43.145632590017016, 42.11996024654758, 46.167685447200654, 45.589622220685406, 43.329568216877604, 40.97110586781656, 42.4951780996015, 42.354619964476555, 40.182383906456735, 41.577194429213, 42.02785515016125, 42.340299390977435, 43.366579701823575, 42.856640200461115, 41.531388990340695, 42.13031138143232, 44.420147941958525, 47.524476435876664, 52.106381385557114, 55.015481748888575, 53.290450803695194, 59.071934223175056, 54.138463312579745, 55.13100339520363, 54.977615187245036, 51.33399609596499, 46.793028923773, 47.46791978036204, 46.46295755140243, 49.17492743461363, 48.47042660559378, 50.08018301379297, 50.76500138928814, 47.67893937326247, 50.54514469638948, 49.391152012732725, 43.43917100660263, 43.00358395422659, 42.93054942161807, 43.96021081555275, 43.067851989499985, 48.103018191552934, 56.81747351923297, 60.31742403584143, 59.6896683016131, 56.357944319325114, 12.514686815200314, 0.9162392575413951, 11.50979518890381, 14.159099325057, 6.230220708154864, 0.24056424867481957, 40.96163726622059, 71.91371533178514, 62.59865491620956, 60.86889751495854, 41.895702654315585, 38.20156735758628, 46.00752722832465, 66.51412563939249, 21.934056781953384, 0.30644663038753694, 0.17473841957267255, 0.10541486283463818, 0.19263044900951848, 0.165290211237246, 0.16058980216903074, 0.07151967800793148, 0.14428542866822214, 0.16504959834198799, 0.059248251810429566], [0.04287996742453787, 0.030476032913992965, 0.02683459292917002, 0.043866807414639386, 0.03829634462993953, 0.04123326526173661, 0.04076212118830412, 0.04757163542953711, 0.050637668689652804, 0.05167690526333548, 0.024285362582773935, 0.03551800802890812, 0.021199052890522346, 3.1373570571022653, 41.68240024197487, 45.61569813759097, 45.917999129141535, 78.4564248977169, 72.95865827991118, 49.36908475814327, 51.51444081337222, 58.81489346104284, 50.05720184695337, 58.63200118464809, 6.576893021983485, 0.3453492186963559, 2.758162165841749, 5.013461766704436, 0.30174352468982824, 7.813812455823345, 58.69839122218471, 53.62237745715726, 55.097369070976015, 44.02433764549994, 41.44460262790803, 38.39610122865246, 41.4180991726537, 38.11479276226413, 37.46304781206193, 36.113113126447125, 37.70025314823274, 40.36737465089367, 42.304417548641084, 42.84268832975819, 46.52857488201511, 48.24027761336296, 48.93148552986884, 50.936299139453524, 51.10710659334737, 50.18255295292024, 49.97321213445356, 49.74917027258104, 53.00526703557661, 51.45660938755159, 51.69423441733084, 50.51117697069722, 49.64143845342821, 50.17730482162968, 50.649424829790675, 43.955672633263376, 37.61289019738474, 39.63567610709898, 38.437207668058335, 38.820438923374304, 39.76937009442238, 37.48896683416059, 37.05628233571207, 37.71338916593982, 40.33298330922281, 36.96195325543804, 37.677260214282626, 39.66846319936937, 40.17080506970806, 38.569795546993134, 39.850190531822946, 40.17521381378174, 42.83007790965419, 40.83743149234403, 39.94691618027226, 38.93512118247248, 40.07720555028608, 36.55908661503946, 38.38447924583189, 42.20661324839438, 49.20414517002721, 47.72505467937839, 50.12066971871161, 50.69197470141996, 53.70864214435701, 51.025207504149414, 50.47984900013093, 55.376006403277, 53.11350484048167, 49.582159673014, 47.89370482967746, 41.77398366312827, 38.07591030674596, 37.07878497339065, 38.34301194837017, 39.32076469544442, 40.512239548467825, 39.67406434397544, 39.5979154494501, 37.58686134892125, 39.03799318498181, 40.15741409793977, 40.69061717679424, 41.160579881360455, 38.58304531343522, 38.70785905468849, 38.507445550734, 38.95242667967273, 38.308271515753965, 38.175044290481075, 37.42225516226984, 36.4418508929591, 37.57806347262475, 38.166873993412146, 36.7685882506832, 36.80778841818533, 38.933842489796305, 39.52307270419213, 43.034849166870124, 47.96940265163299, 51.15092339054231, 48.26901289724535, 47.06271148497059, 50.9742598379812, 52.67396403897194, 49.757697505335656, 51.4220376168528, 47.89101800610943, 47.471398922704886, 45.81514281611289, 46.70470891460296, 45.259444944320194, 46.35359794862809, 46.00851958797824, 47.84354948228406, 45.355731287310206, 46.37435120920981, 45.112383519449544, 43.389345138303696, 38.36972328924364, 37.68210826381561, 39.43842011113321, 47.52493143081666, 53.2913843277962, 56.46918665978217, 57.08404171851374, 43.026863221199285, 2.716322978658061, 0.11983603133910126, 4.9723881771487575, 6.142716061684394, 2.692890494100509, 0.21451753504093618, 43.032903671264656, 56.52505690051664, 55.82264669479863, 41.57739054772162, 25.203132667849143, 21.89569600166813, 31.180669876836966, 46.27277358885735, 5.420690573030903, 0.2202759115325828, 0.02442572329704079, 0.026073340934911565, 0.005377482842548841, 0.04962698038246843, 0.11947659820678735, 0.061558171611038916, 0.04992379348785166, 0.0327710772023326, 0.06955002765021018, 0.040200038647819916, 0.05626582938636984, 0.045662483035196225, 0.02946024054601308, 0.03180978815972565, 0.08756176598610417, 0.022581052523286595, 0.02026301410589968, 0.04398300763099425, 0.016604164772997462, 0.024996424326673154, 0.0633565591828477, 0.02917975277429627, 4.689515665654214, 48.27289212134577, 50.24094527767551, 56.353935657009, 80.73390206983014, 73.64777165074503, 52.114896851201216, 53.67112467365881, 65.11169002902123, 53.5984274648851, 61.86525798613026, 5.137014956243577, 0.3472668899884147, 2.0451024799577655, 6.627319993511324, 0.4121986025523755, 9.791592109587885, 61.7841237591159, 54.961360885250954, 55.46678181617491, 47.80607515765775, 44.66487246174967, 40.15141287157613, 41.12031675154164, 37.79184049175632, 39.57116096250473, 38.442483255940104, 40.10510929169194, 40.431823115195, 43.836224694405836, 44.94028952813918, 48.07018795321065, 49.095468059662856, 50.83297606437437, 51.4756211157768, 52.305712315344046, 51.45002765040244, 54.56042797334733, 50.29208906235234, 54.63541192393149, 51.88989400863648, 51.662098438509055, 53.20127964019776, 53.851769431944824, 52.27593368099582, 54.63170136174848, 44.92371359179097, 38.91781960764239, 39.66040665103544, 38.323886471409956, 40.64001860157136, 40.94721078872681, 40.581751792661606, 40.24574195185016, 40.599920211299775, 42.384551571261504, 38.670341583990286, 40.51052155033235, 41.01481283864668, 42.32478641694592, 40.09852363217262, 41.87156831064532, 41.99238907906317, 43.0649180566111, 42.3504347955027, 41.749955223452666, 40.44845004235545, 40.60358370504072, 38.959926251442205, 39.99027406015704, 42.78072664814611, 51.51105580791351, 50.79331305719192, 50.963081082990094, 54.34543501946234, 56.50191491649997, 50.72738193696546, 50.90762269112372, 57.48826942136211, 53.57800368339785, 51.245636863093225, 48.84439322256273, 44.23617309139621, 39.051972512275945, 40.07739774642452, 41.27808232461253, 40.474321996012044, 41.8141330442121, 40.970082129201586, 40.87895762535834, 40.374658492303666, 40.59362088480304, 41.321248008358864, 42.42251226978917, 43.29037197174565, 40.06148469063544, 39.58696419192899, 40.271151065826416, 40.50904281677739, 40.02766209263956, 39.191550054857814, 38.43918062025501, 38.78281162631127, 39.737037997091974, 40.45050928669591, 37.79550790786743, 38.4479235833691, 41.3867712020874, 41.60765947834138, 44.90581581669469, 49.83349338654549, 53.20515494192801, 52.08394542817147, 49.9526196910489, 52.8798923953887, 54.26423411215506, 51.69925897352157, 53.05608918589931, 50.622097676800145, 48.37997282705, 47.27955579757691, 48.3540302707303, 47.414198998482, 47.15151394567182, 47.38791911832748, 49.232696102511504, 48.45953810599543, 48.21871242215557, 46.19621284546391, 44.68037759104083, 39.19659814526958, 42.07013830061882, 42.095072807804236, 49.55842541110132, 56.43632504247851, 58.753155354530584, 58.406629639287154, 43.8728125633732, 3.4335234617033317, 1.0867239126274664, 9.48344188351785, 6.736846787314262, 1.3721589575852118, 0.3482785857012195, 43.8054850793654, 62.45652391064552, 59.60297607606458, 48.30809931601248, 34.91811206263881, 26.417382763278102, 37.20262988921135, 55.17983298147879, 8.383289614031392, 0.32777464077357327, 0.1698943383751377, 0.006885399559377543, 0.05827149353741158, 0.17136286763894945, 0.07256304379552603, 0.060527503730789314, 0.03261091886088252, 0.06645017543867712, 0.05493738696039204, 0.1645285206576509, 0.15659719705581665, 0.15810560885696642, 0.16455498133455554, 0.15992258555225788, 0.18507781799041456, 0.12917236785494512, 0.08677435017401174, 0.139475729496729, 0.1679835159091219, 0.13649992224189544, 0.13163900243178492, 0.14499957583123638, 5.54324895143509, 56.131611793271965, 58.30465585954728, 57.933376066146366, 82.44395348333543, 74.84025847527289, 59.63078175821612, 62.24695951707902, 69.36162517916772, 58.14466630258868, 69.70887261052286, 8.546274881209097, 1.3573271276489383, 8.523397657179064, 15.447783258653457, 0.7243590537578829, 10.93977870479707, 63.45689696650352, 57.03457670827066, 58.4476262523282, 48.46028727869834, 47.321768345371375, 42.57999543220767, 44.09730549781553, 41.10581574901458, 42.798059601937574, 39.45722003136912, 43.118838879369925, 43.437535378240774, 46.76564293522989, 46.91055490124611, 51.27576851075696, 51.37312958317419, 53.50460044799313, 56.02665701220113, 54.28558749537314, 52.7500815545359, 56.463805167905754, 51.575131647048465, 57.31472023071782, 55.80216015538862, 54.210525097385535, 54.45205680785641, 56.01612152591829, 53.88547828120571, 56.28555305542485, 48.8025297657136, 41.3532074805229, 41.699380182450824, 41.233618336339156, 43.70038909296836, 42.4557622017399, 42.82160166771182, 42.0192063239313, 42.43916665354083, 44.2551612854004, 40.877416133880615, 40.875596154120664, 43.04544741107572, 44.898104436935924, 41.978711774272305, 43.010961932520715, 45.19925225165583, 46.64665391368251, 43.35116478704637, 44.32192394810338, 42.710822166935095, 42.68567585176037, 40.17471567276986, 42.18577761803904, 43.44242265147548, 52.38907052624611, 51.9789671128796, 53.7025938495513, 55.296649009950706, 58.384731046615116, 54.00576168490995, 53.010656372193374, 58.24019170576527, 56.83017023148076, 52.79363947529947, 51.77897330253355, 45.45210784481418, 42.76034209036058, 42.1170812268411, 43.94899283685992, 41.709754851556596, 43.080937016394834, 42.69040230781802, 43.692387457816835, 41.399793471059496, 42.86285715718424, 44.11870202710552, 44.69761640794816, 44.50510647989089, 40.942982473681056, 41.48946277556881, 42.79471774255076, 44.38307762145997, 41.64763235276745, 42.34145256780809, 41.835945344740345, 41.82520589520855, 41.168973753529215, 42.621094026873195, 40.13156567850421, 39.614252121217795, 43.6542227960402, 42.92190059538811, 47.994478364144605, 52.640314025263635, 55.60440209604079, 54.08375409341628, 53.6537132724639, 54.492676873360914, 57.15549161357265, 53.998403318466686, 56.4421340727037, 54.25095688912177, 52.865611045591294, 49.63393888165874, 51.934122654699514, 49.984936098898615, 49.41046576346121, 50.13737901564568, 51.45787631311725, 50.56243842647922, 50.70707974895355, 50.50778412049817, 47.85651683807374, 42.29050490163988, 44.232380159439586, 43.77339224661551, 54.376559026779674, 57.650000510677216, 62.166417567960686, 58.91752619897166, 46.81055799607308, 5.723925088682483, 0.8068767129894227, 14.030041579277286, 16.271105427895826, 6.716893199951419, 0.48277399292395967, 50.61823806455059, 67.70145846951392, 66.04373147410732, 53.18693161010743, 38.9763766719449, 34.40942771973149, 45.81135772889661, 63.89584156774706, 11.508829305248877, 0.6084550989250983, 0.2781601820982272, 0.20355660949022542, 0.13960237915237106, 0.22626668845693912, 0.2522883816592155, 0.11285040497539506, 0.16893606963417224, 0.1413663425633023, 0.09465819164629906], [0.03674036642957119, 0.041731268377794374, 0.05112620295896646, 0.029436457346403794, 0.034842728336732236, 0.05821856069228342, 0.036644996143877506, 0.03818231627285, 0.047197826657324075, 0.04769798631088869, 0.07121561004990531, 0.049265482643198584, 0.04868591414584268, 1.4639089568968744, 39.68571378338722, 52.93804937793363, 33.95070652807913, 54.437496969776774, 65.61227075515255, 46.70618764815792, 47.589528945184526, 59.116166791608265, 48.725596397153794, 64.5789223332559, 19.667389662035053, 0.19544546973080407, 1.0240750807908274, 6.5456768389671085, 2.9324431236713164, 6.045652108807718, 62.195980471949426, 49.92804211954917, 55.14724593008719, 43.06391785221715, 43.02864789962769, 38.830997943878174, 43.13859978029805, 36.79144390167729, 41.16916594966766, 36.5840878025178, 40.36938682679207, 42.29004990669989, 46.232686965696274, 45.771737867786044, 47.74214444621917, 47.21864531117101, 50.73423039528632, 51.85565563940233, 53.61377569936938, 50.51327151636924, 52.04443147105556, 48.761780261993415, 52.52351368627241, 51.872921912900864, 51.24460920210808, 49.53747995438115, 51.035782214133974, 51.546110030143495, 51.434028302469564, 43.36411253098519, 37.74465830095353, 39.952701676276426, 38.92135758553782, 39.51200769793603, 38.50781033116002, 37.604206069823235, 38.41714082225677, 39.28937788932554, 40.438306793089836, 38.94105965091337, 38.02618249770134, 39.56181787675427, 40.262521851447325, 37.86197247043733, 39.317771927002944, 39.03048184610183, 40.083151863467315, 40.197857656786525, 41.04092797925396, 39.91422322488601, 38.536933929689475, 36.50068252317367, 37.698233127593994, 43.68829250335694, 48.02894815321892, 47.137977846207164, 48.50608095046013, 50.68286695787984, 55.32728664336666, 50.147706616309385, 51.960171115013864, 54.20009943746752, 49.91001882860738, 49.731421547551314, 49.07991586192962, 39.92836336935721, 38.76019131752753, 37.24910605338312, 37.978007947244954, 40.91207811909337, 39.743560898688536, 39.01587493958012, 39.770307540893555, 39.30428289598034, 39.96668492594073, 38.793821719384965, 40.0540517991589, 39.5741694204269, 40.669004917144775, 36.461105808135, 37.8973130256899, 38.95476441229544, 37.73837466393748, 38.550874033281886, 38.07060726227299, 37.47667412604056, 38.49043815366684, 39.28664007494527, 37.38323150142547, 36.6708545530996, 38.29207604931247, 39.005688544242616, 41.66292959643949, 44.430722651943086, 50.21821122015677, 50.81448601138208, 48.828409564110544, 46.98800602266866, 55.02208702025875, 50.228644724815126, 51.99073814576673, 47.59162349085654, 49.984559551362075, 49.27415163286271, 51.10717719601047, 46.944632453303186, 51.33271740328882, 49.5772723997793, 51.58259199511621, 48.077020722050825, 51.88974103619976, 47.38221599209694, 47.39302604429184, 41.68040767792733, 40.494377074703095, 37.2392059910682, 48.78641666904573, 53.268524754431944, 60.10674961151616, 54.32443072718959, 43.39056499542729, 0.9939815536622079, 1.7542887623271637, 5.72363434299346, 3.6984974626571905, 0.44297652198903026, 0.6677678323561146, 50.325276236380304, 54.95723455182968, 55.588653779798946, 42.63293958479359, 24.745105735717285, 18.856800486964566, 41.10997738376741, 36.96211015024493, 1.3822186113365236, 0.15846896435945265, 0.02827226800183135, 0.034783693601287184, 0.030962966059544877, 0.06487973349829836, 0.04371473896166971, 0.0516047474417475, 0.0860133184300315, 0.025016036177534732, 0.04460175386479786, 0.05380446932488873, 0.06095740163037854, 0.0058268221384365, 0.05467659147876886, 0.08685766989665647, 0.053053814241842884, 0.07703751055223328, 0.044108967807504444, 0.025623743084349462, 0.08200509278404136, 0.040877103324859373, 0.12465198178805652, 0.11089534093175205, 2.016395878407263, 47.668419576460316, 55.84835783127816, 38.06087586187547, 67.9893212164602, 69.0187394234442, 54.62729654004497, 51.08884796019524, 63.20338241515621, 53.66093435595113, 69.71814509361022, 20.105761597233435, 0.05120091951422153, 1.2614060553812212, 10.807634053691741, 3.2762700030880594, 6.905080185782525, 64.73664868262507, 51.02483487898304, 58.1107731019297, 45.15476865153159, 46.74694499661846, 40.15768081911149, 44.907608339863444, 38.635165768284956, 42.45343231385754, 37.920874703315, 43.370376556150376, 42.97580965103642, 47.195989701055716, 47.44392271964781, 51.30561382539811, 49.5717026341346, 52.934048560357866, 52.78963081298336, 53.9441647837239, 52.71764355321085, 53.17235216017693, 51.44285755772745, 53.97148409197408, 53.224880541524584, 54.89237423866026, 51.53746904865388, 52.93564104264783, 53.68999127418765, 53.268218809558505, 44.63142641129033, 40.7681663574711, 41.349308644571614, 39.87379143314977, 41.21475173581032, 40.79836076305759, 39.51229403095861, 40.40588448124547, 41.02596805941674, 41.77010836139802, 39.892002997859834, 39.846377988015455, 40.99842517606674, 42.89548343227756, 39.72204669829338, 39.712950721863784, 42.241910657575055, 41.379432447495006, 40.57565250704366, 42.05963811566753, 41.47376937250937, 40.55472666217435, 38.65150636242282, 39.531403818438136, 44.43218961838753, 49.78122388162921, 48.428947541021536, 51.514072110576016, 53.02610266593195, 56.2737153422448, 51.03029089589273, 53.94672609144642, 56.000753679583156, 53.562369115891, 51.7855824962739, 50.484194986281864, 42.92810578500071, 40.63572360623268, 39.99633804444344, 39.24108959013416, 41.036711431318714, 41.432815905540224, 40.731833442564934, 41.127863391753166, 38.6941699827871, 41.42027216572916, 43.1050282139932, 42.93023563200428, 41.80118137790311, 42.08566696413102, 39.43106958943029, 39.539323083816036, 40.77154351818947, 40.3469116457047, 40.12771783336517, 39.58712893147623, 39.82286730120259, 41.69603832306401, 39.5440887635754, 39.660979317080596, 37.643802396712765, 40.700285819269, 41.8981227567119, 43.962144544047696, 47.419164719120154, 51.20990014845326, 51.68295760308543, 51.34178984549738, 49.72489080121441, 54.341191014935895, 52.43321288016535, 53.75025849188528, 50.13206028169202, 51.48767063694616, 51.64178056101645, 53.09780359268189, 49.52828984106741, 52.25906356688469, 51.9989594336479, 53.66226403943954, 50.607832016483435, 52.581356879203554, 49.94945041594967, 50.03170644083331, 42.95466807580764, 41.906971623820645, 39.9840178797322, 52.18076129113474, 54.51675238147859, 62.702691862660075, 53.99277471726941, 45.63441961042343, 1.5341784636820517, 3.8636782765388493, 9.991856563475825, 4.889811988799803, 1.261668363886495, 0.6833945551226217, 56.06203679115542, 61.129841035412205, 58.295822681919226, 50.5204180748232, 30.36903735130064, 22.184198094952492, 45.85438220731674, 43.62417351815009, 2.3657403069157756, 0.09952899399063281, 0.028267937689839352, 0.0644425807460662, 0.033815661069726756, 0.02129440976967735, 0.032825427310120676, 0.01922595896758139, 0.04089291537961653, 0.020674445456074133, 0.051686841423713395, 0.1387702544490176, 0.15215002601185154, 0.18552941150001942, 0.21022969496346292, 0.3805451365488191, 0.16259922015090145, 0.1907937072457806, 0.11965388627422434, 0.08893827276845133, 0.2685206509645908, 0.14442091897851037, 0.17905719428052827, 0.2199904518502374, 2.887025509149798, 54.378269180174804, 66.75716354000953, 46.87874840151879, 65.57691058804913, 69.60340792132963, 59.18755785111458, 55.735809341553725, 68.06855309394099, 58.06111589554818, 75.06235876391011, 23.99469356383047, 0.2979143414526217, 2.4220277897773252, 13.318656990605017, 3.691548738748797, 8.435447331397764, 66.78528693414503, 55.945703214214696, 60.05771213962186, 47.36315327305948, 49.79316357643374, 42.024026916873076, 48.33466552918958, 40.21745774053758, 46.013363715141054, 40.27829762428038, 45.68036233225177, 45.1968046926683, 49.785918958725475, 48.94240933079874, 53.617435270740145, 51.93519738412673, 55.01348134010069, 55.982483279320505, 56.48398184007215, 55.61332156581264, 56.93152035436323, 53.28682653365597, 56.61141180223035, 56.328848177386874, 56.30229373132029, 53.09707403182984, 54.84927523520685, 56.66604257399037, 55.00056889749343, 46.988955236250355, 41.760745663796705, 43.246147248052786, 42.841735193806315, 43.35014497080157, 41.938366274679865, 41.163517736619525, 42.152625745342625, 43.33638529623709, 44.33588366354666, 42.942657778340006, 43.039399116270005, 42.930894590193226, 43.99167214670489, 42.38995659735895, 42.548800822227236, 44.508542476161836, 44.611359565488755, 43.491718999801144, 44.30641881881222, 42.44417944262105, 42.08178381766043, 40.14901630340084, 42.77720828210154, 46.23185150084957, 51.8669952115705, 50.30230683665122, 53.22639065404093, 53.68460978231123, 57.09659330306515, 53.12712330971995, 55.457568168640144, 59.77950626803983, 54.45750498002576, 53.15566247509372, 53.36793330407912, 43.82475176165181, 43.840201977760564, 40.87478422349499, 40.03604027532762, 43.81240021797919, 44.13378354041807, 44.43446067071731, 43.521434876226614, 40.77195928942773, 43.16089845472767, 43.16194964993385, 45.111473529569565, 44.22311552109257, 43.67332081640921, 41.766233059667776, 42.74321309981808, 42.732199084374216, 42.172857330691436, 43.28155056122811, 43.199455353521536, 41.422421624583585, 43.79548303542599, 41.98026895523071, 41.13832043063256, 40.740725455745576, 42.77112860833445, 44.06751901872697, 47.63022353572231, 49.41827520247429, 54.123573995405636, 53.90332114311957, 52.787410751465835, 51.54691019365865, 56.762497578897786, 55.83080914712722, 57.69362118936355, 52.37069029961863, 53.625225097902366, 54.68173511566655, 54.80736863228583, 51.42379483868999, 55.57491371708532, 54.71453397504745, 55.41823464055216, 52.31372571760609, 56.28820065529116, 53.02071725168536, 53.35672709249681, 45.509641170501716, 46.03969066373764, 41.46791327384211, 54.19661245038433, 57.365232513796904, 65.98579806666221, 55.35538650328114, 49.0654109370324, 1.9062022816750313, 4.923184494818411, 16.58803882137422, 12.724089410997207, 3.582673303542599, 0.9895297248036632, 62.58635044097901, 65.44695069712978, 64.8991995473062, 56.268341695108724, 36.7971666397587, 29.844359544015703, 54.17642793347759, 51.16331023554648, 3.4453621554759244, 0.32508315939095717, 0.1861234360765065, 0.14867647611085447, 0.17041460400627506, 0.19516768624945996, 0.09744293657281707, 0.18890312482272426, 0.17830518705229606, 0.08241498812792764, 0.2108203027878077], [0.054031166233002186, 0.027204908340448336, 0.08295586918510738, 0.04372559442755677, 0.019494535987295454, 0.030906694986286665, 0.05649446066649211, 0.04312289390532721, 0.08424036114686921, 0.06967612572254674, 0.01804609929451779, 0.048945476225907766, 0.0887606552832069, 0.05105943839636542, 20.6314984444649, 56.35842677085631, 39.22146989453224, 24.143067021523755, 22.754875498433268, 36.15550218089935, 50.43264327510711, 61.633147808813284, 49.05233767724807, 59.19197051755844, 30.552698412249168, 0.08159764892151279, 1.2271230691863646, 12.618260921970492, 4.090868821067195, 6.482243778244142, 65.17421260956796, 50.05022787278699, 54.78920021364766, 44.910099044922866, 43.97343704777379, 42.44293212890625, 43.191669448729485, 38.99995796142086, 38.15650324667654, 38.02684537826046, 43.68862198245141, 46.21863703573904, 50.69938405867546, 48.57656202008648, 50.711719912867395, 48.231303230408706, 52.303625614412375, 50.385249276315015, 50.777933443746264, 48.78958202177479, 51.695936725985625, 50.13237014893563, 52.69416424535936, 51.941198610490375, 52.02463134642571, 51.78833600013487, 52.4229048913525, 47.880682560705374, 50.73953736212946, 42.73448974855485, 38.47926724341608, 41.32469184937016, 39.395803559211, 39.24378033607237, 38.081519296092374, 37.77253458576818, 38.7975715052697, 38.88263202482654, 40.30690346994708, 38.06661821180774, 39.44762591392764, 39.28354532487931, 39.190012485750266, 39.55079601657006, 37.44970783110588, 39.46834779554798, 41.355027460282855, 38.69253043205508, 40.422566321588334, 38.93339141722649, 37.016372219208755, 35.14770800067533, 37.8818549648408, 42.37296881214265, 45.702476655283284, 45.311326134589414, 45.47122155466388, 51.12875023195821, 53.7414566932186, 54.14936750165878, 53.659973375258915, 52.0956733149867, 49.03301608177924, 47.323925648966146, 44.60318142367948, 39.81067265233686, 35.83915518176171, 36.15128955533428, 38.92503284638928, 38.4443816831035, 39.20876141517393, 39.10849778882919, 39.351108151097456, 39.185489992941584, 41.81564707909861, 39.10052361026887, 39.22308198867306, 39.17600962423509, 39.56405362775249, 38.25589610684303, 36.6360709744115, 38.81623414254958, 39.26137216629521, 35.99145689318257, 35.228940286943995, 37.92629149652297, 38.325902569678526, 37.79775934834635, 37.41665794003395, 37.91402624499413, 38.815837983162176, 39.094118379777484, 37.604025640795314, 39.211271732084214, 46.03798835508285, 48.52881500797887, 49.28841337080925, 46.06719824575609, 49.2204975312756, 50.43230987364247, 51.86155880651167, 51.63860736354705, 51.0115223546182, 51.1858638640373, 51.8403858523215, 52.910302531334665, 53.143762003990915, 49.19601801903018, 51.9337421847928, 51.502783529220096, 52.8777390141641, 53.5888921829962, 50.16940909047281, 46.18992528607769, 42.204310817103234, 38.148925227503625, 48.98918751747378, 53.7835515699079, 56.812292068235344, 56.69841389502249, 35.52234926531392, 0.28484175582566573, 3.256698846817017, 8.777360339318554, 3.9158210398689395, 1.0815840142388498, 4.150433444207715, 55.63118796194754, 50.749174625642844, 54.30842353451637, 34.5512370909414, 26.59446208707748, 27.714222285055346, 49.49340820312501, 26.2965835678962, 0.2694230718958763, 0.09069127346118612, 0.03547996027214873, 0.04744485170850831, 0.06298956476272115, 0.03886405025578795, 0.010872044029735751, 0.030791812441161567, 0.05734731953951621, 0.023069954514803908, 0.023894230647373105, 0.013386965128442934, 0.01027322278523277, 0.02905249407875442, 0.018210206819217534, 0.01165856447656669, 0.01294986121431594, 0.05195964533354967, 0.043539032865796364, 0.0863120237725877, 0.008644299607934251, 0.005928098962026378, 0.05287063495826818, 0.0605949386203241, 0.1330163365890903, 28.150327090294134, 64.77216966690557, 39.53541248075424, 31.380143973135183, 46.093999801143525, 46.668277940442486, 54.78314407410161, 67.19896362673852, 53.60713120429747, 64.19834652254659, 32.67900547673626, 0.34644938224265653, 1.2339495867490768, 18.34177367148861, 6.404663218605903, 6.6672992417889265, 69.4876273985832, 52.03955988730154, 59.77018671651041, 45.62679060043828, 46.699633367599986, 44.202919237075314, 45.64245262453633, 39.85649770306003, 40.50806222423431, 38.58004862262357, 44.92974227474582, 48.075636125379994, 52.32749323691092, 49.463304012052475, 51.53819860950593, 50.68209817332607, 54.55353636895457, 51.967047029925936, 53.63320319883285, 50.47000777336859, 53.33280063444569, 50.92345337713919, 54.70070369781987, 52.836742401123054, 55.13271747096893, 52.965160800564675, 53.97956417452905, 51.10920506138956, 52.97570805395804, 44.48282349494196, 41.09323278550179, 42.53272694926108, 40.57882570451306, 40.365531136912686, 40.485245796941946, 39.43958897744456, 40.99186305076846, 40.42865384009577, 41.95968043419623, 40.940491768621634, 40.76728382418233, 39.755065210403934, 39.953701880670366, 40.264785059036754, 40.37955361027872, 41.97278507294194, 42.47136931265555, 40.19296646118164, 41.696367802158484, 42.32362539537492, 39.49197615346601, 38.70472115855063, 39.18892206684236, 44.65192079544068, 48.06088016879175, 47.61742484185004, 49.94290398013208, 54.45893664513865, 53.83535823514385, 55.587637885924316, 55.13780086271225, 53.569778473146506, 51.09704571385538, 49.53917049592542, 45.879202965767156, 41.40545737358832, 38.05179165255639, 37.34522373445573, 40.904990396192, 41.13462163556007, 41.84499425272788, 41.6333588477104, 43.070527045957505, 41.83875376178373, 42.27356026249547, 41.704800898028964, 40.86022046304519, 41.65289617353871, 41.83506673382175, 40.01539291874055, 38.26831040843841, 39.68614916647635, 41.9616533863929, 37.54858293840962, 37.05642746340844, 40.10370508317025, 38.82206670699581, 39.457369081435665, 40.6225012963818, 40.35965934876473, 40.39559610428349, 40.14545086891421, 40.22609479965703, 41.62107398433071, 48.92534702054916, 49.9924474377786, 51.33955801686933, 48.675515574793664, 50.940186208294286, 50.42827375473515, 53.741641044616706, 53.80741527003627, 54.27920579910279, 52.58207859531526, 53.65812593890775, 53.00045428737518, 55.54186774838356, 51.98980462166571, 54.06895499075613, 52.52849117402108, 55.69986081892445, 54.65776551154352, 53.1737720581793, 46.060498837501775, 44.67982061447636, 39.85351670172907, 52.902955932001916, 55.80058728494952, 60.03980651978524, 55.75819038575696, 38.37105689510223, 0.37443972222747346, 5.3851906714900855, 9.119037024436459, 6.382963195923836, 1.0402640508067225, 4.522194708547285, 59.748817643811634, 56.23469952614077, 57.35812517904467, 46.15001909194454, 31.24585770791577, 25.76120553478118, 57.363859684236594, 33.47533879741546, 0.39066760950992185, 0.08915384991034385, 0.013389977769205167, 0.01518383010050222, 0.012750243599105988, 0.09277130176703777, 0.014939317817709621, 0.020812640056735086, 0.005231726475270285, 0.05747041071674997, 0.02679067502369083, 0.1108730860775517, 0.08754737885488618, 0.14946433625394298, 0.15542612441124457, 0.1263565504022183, 0.06984874831452485, 0.1705484089231299, 0.11832650871046128, 0.29788847832429793, 0.1959806587547064, 0.13265947751220197, 0.15034614942006527, 0.15581229401211585, 0.15805213591985165, 28.632243217960482, 72.00377295094152, 50.49282812303113, 37.952402714760076, 34.85361260752524, 48.111929816584436, 61.42795293561874, 71.43762588500977, 56.40689549907562, 70.347505077239, 36.92419259778915, 0.7189094719867553, 4.14801481270021, 27.16486688583128, 7.263954993217223, 8.056721898817248, 71.29915052844633, 53.4173551682503, 62.936774992173724, 47.71067527032668, 49.052502416795306, 47.624618468746064, 47.39269656519736, 42.184408710848906, 41.6356534342612, 41.179870097867905, 48.11429500579835, 50.389222637299575, 53.47540232443041, 52.68610377465525, 54.122671850266, 53.333683167734456, 55.86122712781353, 53.14526819413709, 54.67335693297848, 51.38893281259845, 54.86928716782601, 52.370984477381555, 57.34616979475945, 54.49524602582378, 56.413230126903905, 55.36849506439702, 55.95629753605012, 52.106608883027114, 55.087476853401434, 46.32675716953893, 41.9438301363299, 45.35978701806838, 42.95453863759195, 42.34931692000359, 40.871991495932306, 41.18669894433791, 43.305692749638716, 42.19474023388278, 43.476864983958585, 42.42734855221164, 41.860868084815245, 42.33454919630482, 41.08801603317261, 43.402736110071984, 41.93786813366798, 43.21554883833855, 44.225916093395604, 41.810163605597715, 42.78403712857155, 42.35849134383663, 42.38892893637381, 41.130307028370524, 43.698682861943404, 46.92793492347964, 49.947779486256266, 48.34915476460611, 49.86402903833697, 54.34372486606721, 55.98364430089151, 56.884530359698886, 55.96904131673998, 55.760128036622085, 52.102309965318256, 52.04051694562359, 47.137389490681315, 43.37203964110344, 39.815316738620886, 38.64787424764326, 42.835816337216286, 41.36327620475523, 44.441917096414876, 42.091370090361565, 46.39375125208209, 43.276118078539454, 45.96116481288787, 44.76301408583119, 43.156081784156065, 44.05803472765031, 43.85661709693171, 41.761671343157374, 40.79423442963631, 42.93047097421462, 44.01054659197408, 39.515541753461285, 38.11183137278403, 41.759478738231046, 42.22171829592797, 41.23890569133144, 41.78107923076999, 41.962202518217026, 43.070523123587336, 44.894542924819454, 42.76003222311697, 42.643577052700905, 50.274230510957786, 51.80074245698991, 54.27518144730599, 50.96909799883443, 51.67144152425951, 50.80664127103744, 56.25502917074389, 55.26038277533747, 56.05675728090348, 53.908337854569965, 55.63517701241278, 56.14293175358927, 58.14563512802125, 54.31957091054609, 57.35309670048376, 54.27260052773261, 58.48735593980359, 57.39781564281833, 55.02939439588978, 49.655311876727694, 47.1870663089137, 41.91187066416587, 56.575106343915394, 59.14705153434508, 63.32445421526509, 55.915434283594934, 42.427995743290076, 0.8816479975658079, 7.701516958975024, 21.666125559037734, 12.913222178336113, 2.7458704383142534, 5.502825004439201, 64.76045354720085, 60.37037211079752, 62.8096313630381, 47.130682237686656, 39.24399214406168, 39.44566472884148, 64.02461690287437, 41.64389433399324, 0.9325458986624595, 0.21278482801731557, 0.1405982628104187, 0.19357246136473072, 0.2799775265157223, 0.16922588069592753, 0.06633989708197695, 0.0871104023028766, 0.10226953564391983, 0.18915591851597835, 0.17391383317449402], [0.04259051642410698, 0.00966003930736934, 0.039288757909690185, 0.013711355483880448, 0.026176619163203626, 0.04251097734536856, 0.06192822655242297, 0.017548933129517302, 0.024453371410228075, 0.041417513237965685, 0.08958343371388414, 0.031856931295366056, 0.058079006285556865, 0.06593521879685503, 3.871912066974948, 46.171054763178674, 48.8993848523786, 34.65876886921544, 15.376399063294935, 34.52936987723074, 45.68814431467364, 59.632809623595215, 50.07381308463312, 54.151014897131155, 41.236681707443736, 2.875274333261675, 1.6591521640939098, 10.759994906763877, 5.196224604883502, 4.327619162298018, 57.98095833870673, 53.25869529478012, 55.268713889583466, 47.12566944860643, 45.97646990130025, 43.970597251769036, 45.123170037423414, 41.11706118429861, 39.55858192136211, 39.94095417761034, 48.05587914682204, 49.704553311870946, 48.782870846409956, 50.61889310036936, 50.65991717000162, 50.84299772016464, 49.83682347882179, 49.24816593047112, 50.175571134013516, 52.55717546709123, 53.52964085917319, 52.47348385472452, 54.08172622803719, 51.316698443505075, 53.23474530250796, 50.89412581536078, 52.23741992827385, 50.03152993417556, 47.73874767364995, 41.15326073861892, 39.07553418990105, 37.2411044182316, 38.850535269706484, 39.97086617254442, 38.12869756452499, 37.81344098429526, 38.65958252260762, 40.35613313797982, 40.914902225617446, 43.213685712506695, 43.336342150165194, 41.46466555133943, 39.56359078807216, 37.419360453082675, 39.90270322368991, 40.15593536438481, 41.290331886660674, 39.81077071159117, 39.25505715031778, 38.852547445604884, 38.0979932508161, 37.62166453946022, 36.763657831376605, 39.472991881832, 42.99187175689205, 44.35296558564709, 44.086354240294426, 50.09235412843766, 54.822230492868734, 53.046063607738866, 55.54355044518748, 54.07058669674782, 46.50413067110124, 45.8599558953316, 43.669661245038434, 38.295912127341, 37.929354867627545, 36.772553766927416, 37.2657996608365, 37.031794978726296, 39.16153215592907, 38.55735378880655, 40.138453360526796, 39.27524558959469, 41.69525777139972, 39.91087352075885, 39.35590913218837, 38.98316629471318, 39.29990553086804, 37.31786128013365, 38.54481004899548, 39.08450072811496, 39.28699308826078, 37.49064560859434, 38.538879425294944, 38.25819853813418, 38.39078641706897, 37.411696141765965, 37.90783282249205, 36.3534406692751, 36.949158483935946, 36.770008148685584, 37.333358564684474, 38.04121302020165, 39.36049830528998, 45.60255427514353, 51.04556068297356, 49.02665007498957, 46.68659148677703, 47.227745209970784, 47.60997626089281, 48.469120456326394, 48.476996575632405, 52.20131451083768, 52.58468304910968, 51.953126538184385, 51.36375119609218, 54.43438653023013, 53.5679937947181, 53.46135631684334, 53.26771674617645, 53.78070000679263, 54.61407815256427, 49.60396020643173, 45.25674635364164, 38.58173131942749, 46.25563283120432, 51.28036945096908, 58.22969544318415, 56.57950332087856, 29.18201242723773, 0.12992360899525304, 5.326838551029082, 5.309957160103706, 2.5707895621176693, 0.5972040865209796, 5.430485711943719, 61.51987368060697, 48.58249656615719, 52.46865933941257, 34.993500017350726, 23.15877764455734, 34.00195229438044, 50.968207620805316, 14.672542483575883, 0.058106095154559424, 0.0428434633349459, 0.05736706928620416, 0.08204008001954326, 0.018202431026786085, 0.01843638278754248, 0.07497762269791096, 0.07172654473012494, 0.05689242802139732, 0.029288851355593053, 0.007120768103988902, 0.02898972849511812, 0.03508206569559632, 0.03627533190733483, 0.044917225041576934, 0.013507061859502668, 0.010179778253058753, 0.06019086554466237, 0.049920173722409436, 0.027295827655301943, 0.03874121954844844, 0.012511640727039308, 0.018394552471656955, 0.07866048314157995, 0.18134255713272482, 7.103800696711387, 56.16608158234627, 50.30435431388117, 32.71001769650367, 18.25241227303782, 46.8067297627849, 50.61151904444541, 64.50454242767827, 54.50644439266574, 60.94013560202814, 42.782476025242964, 3.414760558835922, 1.5729320938548736, 13.057973327175265, 9.719175350281501, 4.195329383496316, 63.374280083564024, 52.24619034797915, 60.22659763213127, 48.59502461648757, 48.54824642981253, 45.86395671290737, 48.37058659522764, 42.175501008187574, 41.800000744481245, 40.858341647732644, 50.894329778609745, 49.61918684744066, 52.25898119711107, 51.056511940494666, 53.71703209415559, 52.54759311676026, 53.779617432625066, 50.2747521861907, 53.24804213739211, 54.252529759560865, 53.378021640162316, 53.17868286563505, 54.98846054077149, 51.16755031770276, 56.05134833243586, 52.23731794664937, 53.22593958147111, 50.56300717015421, 49.84645289759482, 43.98512178851713, 40.4749652647203, 40.65446076854583, 39.91511360291512, 41.68176089563678, 38.93195975211359, 38.99424699044997, 38.926001671821844, 43.06042694276379, 42.47987301118913, 44.660385270272535, 44.94542391069474, 43.21007320957799, 42.509632033686486, 38.6403589863931, 39.984119861356675, 41.821981706926906, 40.92680661909042, 42.27764737221503, 42.132590278502434, 40.45040338270126, 40.18208972869381, 39.275182831671934, 39.17410727470152, 40.26380838886384, 45.38969116826212, 45.618557545446585, 45.09701567311441, 52.39347927031979, 54.808121727358916, 55.77240505526143, 56.671647640966604, 55.624261056223226, 49.34473468411354, 48.1662428763605, 45.545675985274784, 41.37277618531258, 39.70145425488872, 39.007045684322236, 39.70293691081386, 38.881361176890714, 41.429281850014966, 40.28342808446577, 41.12103846765334, 40.16394092190651, 41.03908446527297, 41.0927503339706, 40.95462014598232, 40.909057894060695, 41.68307096727433, 39.004217655428, 40.36228341441001, 41.10692185740317, 42.127110727371715, 39.4002240703952, 39.58437150524509, 39.632636270215436, 39.975592628602065, 40.028489712745916, 38.99143857340659, 38.21577418235041, 38.38999409829417, 37.20621885791902, 39.06492810095511, 39.704305818003995, 41.024014719070934, 47.2275020230201, 52.55715193287019, 50.29204591628044, 50.73262222351567, 48.717355497421764, 48.4743764323573, 49.94643411328716, 51.40111569435366, 54.141816939077074, 52.987659515873084, 54.56096926043111, 54.810785016705914, 57.03749102930869, 52.96489800176313, 54.82960454879269, 55.969912082918235, 56.42487172157534, 57.02970120214648, 51.007466623860026, 47.66655252825829, 40.93055248260498, 47.81668516897386, 52.931000878733975, 59.359098788230654, 60.15002119925715, 31.632342569289673, 0.1960010979805262, 4.80711518756805, 8.926719292517632, 6.415570839758843, 1.0227301368309607, 6.286615075603609, 66.957212263538, 54.88052868073987, 58.229236525873986, 42.06661208983391, 29.26265047442529, 36.919297479814105, 56.12363761471164, 18.899668070577807, 0.01457987989734618, 0.0946678290323865, 0.05688970074838689, 0.04704164048176139, 0.018633217588367484, 0.02542410057128197, 0.018255342804496328, 0.03928641368064188, 0.036985970387655887, 0.013774159371912962, 0.05167907329216119, 0.10107849874804098, 0.12167910864997296, 0.1760877915207417, 0.16380822946948392, 0.14246586259574662, 0.12432181321445013, 0.2751477711623715, 0.18673269048092828, 0.15524744206378538, 0.1609779176332297, 0.28350465660614355, 0.1972303013767927, 0.20407207941095676, 0.21656075282202614, 7.695564271942263, 64.66860732724591, 57.66191667126071, 47.178448861645116, 24.705427039054133, 49.765259835027884, 54.54259687854398, 72.0785568606469, 58.453729460316325, 64.14749299326252, 49.722506000149636, 4.724659121805622, 2.9258407940787654, 19.939315818971206, 9.84394496487033, 5.929202821946913, 65.76334476470947, 56.061977955602835, 63.6329564740581, 52.2072059108365, 51.26901418932023, 48.98041709776848, 51.51534688088202, 46.517953103588475, 44.67428222779305, 42.979457455296675, 53.98776585055936, 53.282837483190725, 53.30828582086871, 54.61002634417627, 56.28337613997921, 54.81569582416166, 54.372970058072, 51.8913217513792, 53.1300768544597, 56.708588523249475, 55.912131647909845, 56.07081505560107, 57.330817637905, 54.542416449516054, 59.223796629136615, 54.53171230131581, 54.912272422544426, 53.994661377322295, 51.4324789662515, 44.972711839983546, 43.17340297083701, 41.30171068253056, 42.3077868646191, 43.762699865525775, 41.20501249067245, 39.511674296471384, 40.916173073553274, 43.97636705829252, 45.195624059246434, 46.6748361433706, 46.91352805783672, 44.9433607439841, 42.619203444450136, 40.14527828462663, 42.84539476517708, 44.248575625881074, 43.60056477208292, 42.78897539261849, 43.2765926853303, 41.38721442991688, 43.01041672306676, 42.84011917729532, 41.22053723181448, 43.65185368445612, 47.13244338189402, 50.949117445176654, 47.19982970145441, 54.559619965091834, 57.38001200460619, 55.93085312074231, 58.04961942857312, 59.048847152340805, 51.03940256180302, 51.153621981220866, 47.91974936762164, 42.996802176198656, 41.20327095831595, 39.860337703458725, 41.950223599710775, 40.584375858306885, 42.235901586471066, 42.84122920805409, 44.820057115247174, 42.94982394864483, 44.52249826923494, 43.59167275890228, 42.578846177747174, 43.355397024462306, 43.82991752316875, 39.21456260065879, 41.807437558327955, 42.863520037743356, 44.44887930347074, 42.269022080206106, 41.7883042366274, 41.24791537561725, 41.861938891872285, 41.683745614943966, 43.31363162686748, 40.38565289589667, 41.639920973008685, 40.391458003751694, 41.87489448055145, 42.006003625931285, 43.12271810347035, 49.6650589666059, 54.85231114972023, 51.79885187456685, 53.84158695897749, 48.47408225459438, 47.63508727473598, 50.03145540914228, 53.34865485468219, 55.35835181513141, 56.41376749161751, 55.39327267677554, 55.70346155474263, 58.04172369741625, 56.53275651316489, 57.543606219753144, 57.55953496502292, 57.4390358309592, 60.12758916424167, 53.385438842158166, 50.728688086232836, 42.035405712742964, 50.5516166071738, 54.62557069716915, 64.25328716155022, 58.38116953449865, 37.78494104262322, 0.40005307524434985, 9.361253188502404, 16.54845033922503, 11.57834743299792, 2.499591434194196, 6.808726181907039, 74.38547534327354, 58.328590162338756, 63.522981059166696, 46.80746716837729, 34.215662633219075, 46.249282513895345, 66.74625150619015, 23.987580345522975, 0.12431128716637051, 0.27279165242948844, 0.14640681806110567, 0.2942140142042791, 0.0888884081054599, 0.06803920267209893, 0.1386933851866953, 0.19338536737186296, 0.17038048245012763, 0.09768325835466386, 0.12817361136718144], [0.06438854090388745, 0.055879544872309894, 0.07061007883279555, 0.0111970491707325, 0.009908404054811165, 0.05154555565827797, 0.021323354486676476, 0.06564075758139934, 0.0297957640742102, 0.019115559952033144, 0.009582226799290267, 0.04964952635008001, 0.03536401669524851, 0.05093866080466298, 0.03338949784876839, 28.655479338861284, 55.32134817492578, 33.261855956046816, 31.842713009926584, 34.09565379542689, 44.27928778433031, 56.76596103175994, 57.879184599845644, 51.63388482985958, 50.44099400120397, 6.70856551777932, 0.8395181872671651, 5.642494722720116, 5.943895530316138, 0.9843855363226707, 43.57114699579055, 55.253259751104544, 52.736035546948834, 50.28315782546998, 47.66753312080137, 46.97652132280412, 44.04816996666693, 39.20043422329811, 38.93152044665429, 45.758829347548954, 50.92241394904352, 51.39423977944159, 53.228551880005874, 52.342225659278135, 52.221848118689756, 51.84566144020327, 49.276144196910245, 50.43456915886172, 52.82166873255084, 51.507764939338934, 52.28728894264468, 50.855749345594845, 50.215689136135964, 49.08932955034318, 49.194170582679014, 47.57378062894268, 49.735249780839496, 48.226918020556056, 43.12153747004848, 39.323086738586426, 36.20481421870571, 37.7487571777836, 39.052686383647305, 38.96389961242676, 37.037180392972886, 39.218790915704545, 39.90096169133341, 40.28672679778069, 42.00903169570431, 41.75785095460954, 43.56485551403415, 38.65277721035866, 39.74574958124469, 39.420749833506925, 39.53051344040902, 40.4305051988171, 39.81632478775517, 39.74293331946097, 39.58828603067706, 40.84846904200893, 38.46376211412492, 36.29402852827503, 37.39526533311413, 38.09341584482501, 41.58676501243345, 41.12756529162007, 44.67180328984415, 48.6653370241965, 54.133187724697976, 52.87323221083611, 53.98381602379584, 52.504176401322894, 46.198864367700395, 44.204519564105624, 41.880476013306655, 40.21954836383943, 39.2882796256773, 38.19100049234206, 37.96806866122831, 37.079808712005615, 39.638107976605816, 39.48359797077794, 39.554706619631865, 38.70786689942883, 40.25089594625658, 38.64207698452858, 39.78300425314134, 37.70116706048289, 39.43650207211895, 37.90244740824546, 38.55230962076495, 40.028689753624704, 38.65497373765515, 37.9832011653531, 37.42422026972617, 38.4332029281124, 38.96373487287952, 37.10898330134731, 36.66717929224814, 35.908424239004816, 37.028013813880186, 36.24697185331775, 36.472704256734545, 35.42470578224429, 37.032293119738185, 37.69470299443891, 46.65555377160349, 49.66732217419533, 49.96005650489561, 47.22724314658873, 50.16165064227197, 47.57207047554755, 51.27185006295481, 51.06844379055885, 51.524113378217145, 49.29424201288531, 50.370305045958496, 48.86404037475587, 51.159278039009344, 50.56934964272284, 51.900103938195016, 50.94994898765318, 53.195768710105654, 50.51225562249461, 48.71777126866002, 41.72650337219238, 43.02937746047974, 53.75181567284369, 56.33027984249977, 57.27900312792871, 23.85368435613571, 1.396720717030187, 4.385377043677915, 4.663440239044928, 5.726227029677361, 0.8673304271313452, 7.322344866491134, 59.40763811911307, 45.53250466623614, 42.56079150784401, 30.944939351850945, 24.56419425625955, 26.15183634142722, 52.1419886619814, 6.186726525906594, 0.11715822462593356, 0.01688229873956692, 0.0790940199588095, 0.10795668894124609, 0.050425305286602634, 0.02435688646660457, 0.04239876078621995, 0.06899775486559638, 0.018931499667345517, 0.025289054591989806, 0.013474917767809765, 0.0794025312267965, 0.047103007954935876, 0.02371446237028126, 0.03465168133017517, 0.06887750970500131, 0.01072983225552185, 0.007279380384246789, 0.08403427583435852, 0.03881896598144405, 0.05298264467367723, 0.0225440064264882, 0.052521865769860246, 0.030817001412111907, 0.036001336730776295, 0.08736994523074358, 35.28323373486919, 62.196976753973196, 36.24965475451562, 32.08898294356562, 39.74289409575924, 50.59486073832358, 65.67653486805578, 59.809967394798036, 56.928492284590206, 52.839523361575225, 7.441330946260884, 0.9121361519059829, 4.616465443565, 11.395346310830886, 1.4687221953945777, 47.49785923188733, 57.14052384899509, 55.81914401823475, 50.79203828688591, 48.929724385661466, 48.01714966374059, 46.792381732694565, 43.49063250326341, 40.51142761784215, 45.86684749972436, 52.61637580010199, 54.290984676730254, 54.93405726648147, 54.08689983429448, 53.92676122726933, 53.31761713950865, 51.39713056625859, 51.77738474261377, 54.76870190712714, 54.444647450600904, 53.14153802010321, 53.22904217627741, 52.73086586306172, 51.278114088120006, 52.570209503173835, 50.86810873400781, 52.2393968028407, 50.86101708873626, 46.226140529878684, 41.111475729173236, 37.71104358857678, 40.32679773146107, 40.35916905249319, 40.352481411349395, 39.03702043717907, 42.44404215966502, 40.67986596015192, 42.96208527780349, 43.04623188511018, 44.02607133311611, 44.676357161614206, 41.3976244003542, 42.24423270071707, 40.81362270539807, 42.59139776229859, 41.62455704904372, 40.99898215263121, 42.12565552803778, 40.72832684363089, 41.1975246860135, 41.14760860320061, 37.94311061982186, 38.90726843187886, 41.01211032559795, 44.24968173426967, 43.83738571597684, 46.24711344319005, 49.72699319162677, 55.23855478532853, 56.2423324584961, 55.136961475495376, 54.261174663420654, 48.27298233585973, 44.902262149318574, 44.52741692143102, 40.00166854550762, 40.763369298750355, 40.02274344044347, 40.60121067108647, 40.77328897291615, 40.77951377437961, 41.13696721292312, 41.465281363456484, 40.33062988711942, 41.822628898005334, 40.25611662095593, 40.701733173862586, 39.95206625230851, 40.95984082068167, 39.75049564915319, 41.9578290754749, 41.80180503476051, 39.3189251038336, 40.5769782681619, 38.70463486640684, 39.880604590139086, 40.620559723146506, 37.720300382183446, 37.15245100759691, 39.4728506765058, 39.70807129336942, 38.57034860118743, 38.3238668595591, 38.9424717041754, 38.40651904383014, 40.09599370341147, 48.78161176558464, 52.17247332296064, 51.29311323165894, 51.01058098577684, 50.77200282004572, 48.89156364625501, 49.74491842331425, 50.12624340672647, 52.51693194912326, 50.92527335689914, 51.56091697754399, 51.16460854007352, 52.71928310394288, 52.05593578277096, 55.358638148153986, 53.924847110625244, 55.3177748956988, 52.973927297899806, 51.10927174168249, 43.15530907723212, 45.07234396473054, 55.597839970742505, 58.93144276834304, 58.89647483825684, 25.51415308829277, 0.9673019594723179, 4.425265096849011, 7.3976622185399465, 4.484025143807934, 0.5203608099010684, 8.200956275386195, 65.03472920387023, 50.13508835146504, 51.430655064121375, 37.09967943929857, 16.922830766247166, 28.6282875076417, 61.56670285809425, 8.68267628454393, 0.11354533099238912, 0.02808042426383303, 0.03497228529604693, 0.04480015148498839, 0.026721776906220664, 0.14754200714730448, 0.07405986468638144, 0.04057977311012726, 0.030084864589415734, 0.025152882463448954, 0.034885326655761856, 0.1781344720192494, 0.1611233670865336, 0.14189364088158454, 0.07937765635189512, 0.11774172315434103, 0.13322817522191233, 0.1270117164559422, 0.14723489782021892, 0.13277417619622525, 0.24180880447308867, 0.1157389241721361, 0.20465593033980942, 0.11064853804606585, 0.13418224580105276, 0.20143834573607292, 41.91771107335245, 70.31298821972263, 44.8259053691741, 43.313682617679724, 45.03643466580299, 57.043096096284934, 63.54625640376922, 66.50567685404133, 61.2584633981028, 59.53913165676979, 9.213225879976827, 1.3291086160367536, 12.395193769085793, 15.621956106155151, 1.5835965280571294, 48.50042097030148, 58.71397087650915, 57.25101309437906, 53.44894985998831, 52.580533181467366, 49.78280851917882, 47.986257076263435, 45.46291397463891, 41.93511070743684, 49.832697145400516, 55.50356188128072, 56.30917356860254, 59.00761911945959, 56.11074870632541, 55.43468506105485, 54.38538828203755, 51.94092012220814, 54.94442801321707, 56.1581152485263, 56.54162891449467, 56.48204026683685, 55.78226197150446, 54.637796724996264, 53.9668478504304, 54.817217703788515, 51.42374384787775, 54.35162451959426, 53.58483252986785, 47.14227284154585, 42.38441821067564, 39.23065216310563, 42.257506001380186, 43.36056278597924, 42.2917914390564, 40.44137408656459, 44.24245280604209, 43.154638351932654, 44.4310756652586, 44.28877207540697, 45.48601673495385, 47.884510793993556, 43.08128218497, 43.615579605102546, 43.34829361208024, 43.436374356669766, 44.010460299830285, 43.20064383168375, 44.33676227446526, 41.99541322646603, 43.49712794826877, 42.62793464045371, 40.68958167106875, 42.044246735111365, 42.67519920103012, 45.759664812395656, 44.73841690248059, 49.879361583340554, 51.96692151408042, 58.91461187793363, 56.542821315027055, 57.32755030355146, 58.27093524317588, 49.81899238401844, 48.55796606309953, 47.10602621878348, 42.7412832936933, 42.13270010486726, 41.737748807476414, 43.09430445394209, 42.697219387177505, 42.76912819954657, 44.24276659565587, 42.73431324189709, 42.073774337768555, 45.039290151288434, 40.818506056262606, 43.41173010487711, 41.686738383385446, 44.19609039060531, 41.442759113927046, 43.71894190388341, 43.46701199008573, 41.76353054661905, 41.39947968144571, 40.86549997329712, 40.97681683878745, 41.56092443773824, 40.97449479564544, 40.24806791736234, 41.009215616410785, 40.9572010655557, 41.562889545194565, 40.91925213413854, 40.06819978837044, 40.433066506539625, 40.60581553366877, 50.367994769927, 54.69907591419836, 54.98643659776258, 53.1858451135697, 53.51702259432886, 51.78091487576885, 50.429156288023925, 51.83972689413255, 53.61514460655951, 51.031094981778054, 53.230367937395656, 52.2736979299976, 53.51705789566041, 53.32650915268929, 58.7140061778407, 55.776492164980986, 58.37603122957292, 54.186598639334406, 52.70857111100228, 47.12506932597007, 46.96965325263239, 57.903518984394694, 61.14065500997729, 59.81139121517059, 30.463597851414836, 2.286019604052267, 9.756394720846608, 13.817136306916515, 14.401946010128146, 1.868930081686666, 9.719636228776748, 72.02450659967238, 56.19422066596247, 56.749020314985714, 41.676438239312944, 35.65173649018811, 37.2379586773534, 70.00551362191477, 11.034190154844715, 0.19517749217489075, 0.08229600701240763, 0.18382759314150582, 0.24144065326019643, 0.19578374351464933, 0.2051850825908684, 0.14597194059000862, 0.18901315037040942, 0.1639868811734261, 0.1154951090293546, 0.09580884804768909], [0.0024634656062605042, 0.03565615666429362, 0.10615948497528031, 0.03671006382172627, 0.01313635957382259, 0.02014224992073592, 0.0137293872783982, 0.03171151823123857, 0.044518464785670085, 0.05314107931729767, 0.0624389658802219, 0.0016607722054393364, 0.03253270511425311, 0.11778291570202959, 0.08019055990922837, 6.0051609912226285, 47.88296538014566, 41.91692659931798, 24.59968190039358, 33.985517563358435, 39.33166496215328, 40.25424172801357, 57.77692840945337, 46.42503607657648, 57.50822644079886, 14.255523931595588, 0.40604967443693074, 1.5485615499557988, 34.371659217342255, 1.4426891794127803, 19.98979280071874, 65.63188260601413, 49.308550819273925, 54.17865583973547, 49.82214204726681, 52.485066613843365, 46.080965765060924, 43.39570330035302, 43.53016214986002, 49.68392164476457, 50.84388809819376, 52.53559850877332, 52.05726938862955, 51.71173995540988, 46.029712154019265, 47.564123753578436, 50.34655901693529, 51.426018822577696, 49.54596404106387, 48.584842143520234, 47.11487508589222, 46.03121834416544, 44.51329246644051, 45.08437779641921, 43.95853988585934, 42.804296170511556, 41.08313660467825, 40.23648123587332, 38.61078823766401, 37.172690437686065, 37.88828372955322, 38.038157493837424, 40.29415576688705, 39.89698833034885, 39.403456103417184, 37.5007260999372, 38.500777521441066, 39.62218315370622, 38.98639440536499, 40.02743067279939, 40.05200039955878, 39.30625977054719, 40.43312926446238, 38.93258340897099, 38.56084077588974, 41.21134711850075, 38.98494705077141, 40.013874961483864, 40.51980187816005, 40.89997368474161, 36.529292291210545, 36.554320935280096, 37.09385864196285, 37.29362495483891, 38.06475116360573, 42.61828953219999, 45.58862593866164, 52.20135765690958, 55.102381860056234, 52.6712066127408, 53.80929408534881, 52.13541084720243, 48.03720866480182, 44.73813841419835, 43.18234597482989, 42.13801099408058, 40.84746883761498, 40.65777909371161, 38.34836990602555, 38.03745931194675, 40.864813558516964, 39.38127117772257, 39.66395247367121, 39.779340759400405, 39.175840962317686, 40.68555731927195, 38.81322960699759, 39.1575901739059, 37.82538852384014, 40.022625769338305, 38.65787629158267, 38.36156868165539, 38.84682862989364, 38.92315795344692, 37.21184353674612, 37.26267745417934, 38.025092078793435, 38.43057101772678, 36.76619560487809, 35.877261007985766, 36.957242488861084, 35.268917083740234, 37.15380030293619, 35.45888139355567, 36.85618262137137, 36.54089858455043, 39.48930501937866, 45.63874206235332, 50.21584210857269, 51.6945089832429, 50.863507793795684, 51.6588467936362, 49.92930512274466, 51.76531953196372, 51.22446390890306, 51.00667822745539, 52.40152797391338, 51.75561951052759, 53.82663488388062, 49.8937645266133, 50.347272888306655, 49.82814719600063, 53.57999232507522, 52.32644204170474, 52.22676677088584, 45.378233924988784, 47.46318547956405, 50.094523199142955, 58.55902548759215, 49.987164005156494, 26.987332567091915, 7.926493325541097, 2.668284485417028, 5.986162010700473, 2.680904466298319, 0.3762897019905429, 8.015326184611167, 60.72663707117881, 48.29902295143374, 39.40864932152533, 30.98950924411897, 41.13332333103303, 38.342784450900176, 37.63274915756718, 0.5414450204660816, 0.028250051452027216, 0.06924770637265137, 0.07369889937821897, 0.06639717747607539, 0.05322570905029293, 0.030993113534585125, 0.029098229527833964, 0.06867707046049257, 0.03393449279810152, 0.02289086614074486, 0.0689553595598667, 0.024678040100561998, 0.0601956689159476, 0.056887322045381994, 0.06220830063666068, 0.04805058976935764, 0.042145070770094474, 0.017041524368969184, 0.029849757951113488, 0.058300114582262696, 0.016312459558849374, 0.022517187603478952, 0.047027008202407634, 0.03164896906744088, 0.060543779268740654, 0.026075508963737278, 10.2718912401507, 56.65113364496539, 42.7078882340462, 24.419945170802457, 40.363801371666696, 47.464201373438684, 45.822352132489605, 70.9554567644673, 49.59737846928258, 62.9340018764619, 11.82723064576426, 0.5796829815353117, 4.767304110911585, 36.06630356081071, 3.271581299843327, 22.215904574240408, 67.18649048959055, 50.67433580275505, 58.244000327202585, 51.09800669454759, 55.22197884898032, 46.607540038324174, 44.80033936039094, 45.20548489785964, 52.697164858541186, 51.19019808307771, 54.20926993893039, 52.82392017302975, 54.00028997851957, 46.861960657181285, 47.37578722738451, 52.63277915216262, 53.11219084647394, 51.46102597636562, 51.653418233317716, 48.58202588173651, 50.31153617366668, 46.2692238438514, 48.70757702858218, 46.04363656813099, 47.56320199658794, 43.775608385762865, 43.245311783206084, 41.102564104141734, 39.33099815922399, 39.595248237732925, 40.35506233092278, 42.47825307230796, 41.644274803899954, 40.11873168330039, 40.252002054645175, 40.311622081264375, 40.88261327435894, 40.39964791267149, 40.57216944233064, 41.15206441571636, 41.03246742679227, 39.90115388747185, 40.85684722469699, 38.88704861364057, 42.349913120269775, 42.44688587803995, 41.85854211930306, 42.10596130740258, 42.4782609170483, 39.62965134651431, 38.172530051200624, 38.550948558315156, 39.70375668617987, 41.075629188168435, 44.360586750891905, 46.64386118611982, 52.9672122001648, 55.588928345711004, 54.84636091416883, 54.72892515120968, 54.7631399862228, 49.231715509968424, 45.63286242946502, 44.06033715894146, 43.503282147069136, 41.564493794595045, 42.461614378037, 39.70142287592734, 38.56140559719455, 40.334403207225186, 41.543634630018666, 39.71775954769504, 42.38579496260613, 41.56462323281073, 40.718026699558386, 40.0644225458945, 41.543548337874874, 40.78403626718829, 41.06114779749225, 39.15511908069734, 40.97457324304889, 40.224192450123454, 39.00202505050167, 39.975686765486195, 39.17797473169143, 39.40644102711832, 39.82196515606296, 39.00474717540126, 38.660453288785874, 39.153165740351525, 37.704540298831084, 38.67056908146028, 37.18983511770926, 39.885421260710686, 37.84533769853654, 41.893051132079094, 47.276429668549575, 51.753430827971435, 52.50843217295986, 52.04097978530392, 52.278153742513354, 53.06414573423324, 51.621894144242816, 51.89911157854142, 51.31306240635534, 53.76337489774151, 53.56831150670206, 53.35814699049919, 50.840189303121264, 52.41657810826456, 51.650366629323656, 56.76136793628816, 54.534352056441776, 54.56575847441151, 46.13718117437055, 48.164650394070534, 51.67965104503017, 61.500289286336596, 52.434985791483236, 29.683693378202378, 9.39026205770431, 6.057822733156144, 8.555918028277736, 4.4897380759639125, 0.33861319143925944, 9.456321635553914, 67.9450455019551, 50.94504994730796, 45.55546622122488, 35.84594872690017, 40.9386404099003, 40.88264857569049, 46.81668473828224, 1.4515553294650971, 0.05475056109829776, 0.06344909494322154, 0.016008588868463715, 0.04451607459134633, 0.01369228085217577, 0.04589663014837331, 0.020637960518680273, 0.03997865455946134, 0.01426206736434852, 0.015339491505836769, 0.11233920216440194, 0.10003086585070818, 0.18616164854216963, 0.2556531470749648, 0.18679915626923885, 0.18574783848899026, 0.12347737747815349, 0.0765666039660573, 0.0851350445901194, 0.0888890516193163, 0.11730630176081774, 0.1725713560177434, 0.16047539459841867, 0.14283215987586206, 0.31757641703851763, 0.22478482926324492, 11.177793029815922, 66.62222616134152, 50.85588662855087, 35.805591460197206, 44.814918810321444, 51.349873850422526, 52.287261486053474, 71.7379774585847, 52.97381747153498, 71.05670098335513, 17.17164239575786, 1.1520033065349826, 9.1615859154732, 56.72086554188883, 5.208533983076773, 25.12989809436183, 70.86305356794789, 54.51887438374182, 58.743988775437884, 53.86014369226272, 57.156856598392615, 50.1370495365512, 47.54304101390224, 48.33537547819076, 53.23818522114908, 54.94855042426817, 56.035949107139345, 55.31995965588478, 53.7303210842994, 47.28037557294292, 50.36027554542788, 55.125143374166186, 56.480918468967566, 53.0504801965529, 53.33322817279447, 51.24787261409145, 52.7592912797005, 48.62938457919706, 50.56214817108647, 47.60993703719109, 49.88125216576361, 45.20968575631419, 43.700534220664736, 42.957154858496885, 41.23279463860297, 42.81429429208079, 44.04876616693313, 44.836350640942975, 43.925525296118956, 41.81603931611584, 39.92206012049029, 41.82756716205228, 42.12524760153986, 40.97969193612376, 42.9901223797952, 42.8466538460024, 43.34472425522343, 44.939144196048865, 43.57614801776025, 41.61473543413224, 44.75887206292922, 43.164977719706876, 43.92100280331027, 44.47069944873933, 46.17742861470869, 41.24047071703019, 39.93379977441604, 41.48150820885935, 40.98524993465793, 42.784935351341005, 46.32389776168331, 48.94665725769536, 57.256692686388575, 57.43683930366271, 54.963906503492794, 57.78496142356627, 57.26643585389661, 52.762805723374896, 48.96552778059437, 47.71884556739561, 45.95249245243688, 44.50048985019807, 44.85957499473326, 41.605784585399014, 42.06948718717022, 45.09069281239664, 42.52697675458847, 41.608440030005674, 43.32406905389602, 43.22159713314426, 44.12100838076684, 43.65126925130045, 43.48954600672568, 42.251069391927416, 43.434613212462395, 41.03719388284991, 42.512613035017445, 41.434169123249674, 41.5166251890121, 40.00966625828897, 39.73320976380379, 42.4748327655177, 41.727872279382524, 40.425025647686375, 40.05132182951897, 40.68097206854051, 38.87323402589367, 41.15863046338482, 39.0231313243989, 41.46652083243094, 40.86506851257817, 43.067138118128625, 48.80545585386215, 54.04818996306389, 55.99946714216664, 55.25381672766901, 55.23194951395835, 53.63663135036346, 54.743802701273275, 55.7417203534034, 54.230905732800885, 55.65560863864038, 55.20582652861073, 56.94965347166985, 50.710331393826394, 52.86066493680401, 54.79242832429948, 58.09029832963021, 55.812224957250784, 55.71072186193159, 48.064363233504764, 51.03616268404069, 54.31313430109332, 62.20316625410511, 54.66756359223397, 34.065941841371604, 12.302862155822016, 9.405843673213836, 14.811083539839714, 13.001028357013581, 0.9003626675375047, 10.86820133270756, 74.28044211479926, 55.24449717613959, 50.5677257814715, 42.82926597902852, 54.890381674612726, 49.710848715997514, 53.68293493024765, 2.1486069646573838, 0.13159743450101347, 0.1864394473452722, 0.11671220823641747, 0.21804797463119033, 0.1712652527156376, 0.12740267410634026, 0.06512721054135792, 0.16403909772634506, 0.1417829564982845, 0.1055081110567816, 0.239642292501465], [0.08009614723344004, 0.008147748228492997, 0.014549738167965365, 0.04967562696566025, 0.042159511527467164, 0.057025443867690144, 0.023621417161437775, 0.02181394761728664, 0.016271761137871973, 0.0411685461538934, 0.04026782976823949, 0.024950872738695434, 0.08154794513698548, 0.020600374329895265, 0.03307292733581797, 0.4886417974147105, 31.58738632355967, 49.09908056259156, 33.87089413981284, 24.37429270436687, 47.23799044086088, 45.32938864923293, 47.5081358417388, 48.49187804806618, 58.34793921439879, 25.56117053954832, 0.18492006516504675, 2.484585181359322, 16.18818848363815, 0.40192996001532005, 14.342986902882977, 60.411455015982355, 51.565023699114406, 55.89591264724732, 50.28258515942482, 55.193871144325506, 47.7990266584581, 49.141183284021196, 49.38923397371846, 50.83867526823475, 52.47750036178097, 52.20793154931838, 44.018183446699574, 49.28753083752048, 48.39401883463706, 49.79197509827153, 50.205275243328465, 50.66103504550073, 48.37021397006128, 48.021060266802394, 42.691555484648674, 42.54196805338706, 40.78102388689595, 41.74240466087095, 38.700598747499534, 39.75296674236175, 37.93455200810587, 38.62757990437169, 37.13600843183456, 40.02148435961816, 37.85683416551159, 37.631839167687204, 40.26297292401714, 39.65075762041154, 37.74942790308307, 38.09940922644831, 38.91653699259604, 39.53382392083445, 39.73193499349779, 40.187000536149554, 40.8494221779608, 38.906158401120095, 38.296986856768214, 38.99514129084926, 39.6094472177567, 41.43094493496803, 40.16723571285125, 41.623717661826845, 40.2154298751585, 39.821345421575735, 36.43936411026986, 37.39535946999827, 36.99602688512495, 36.35346812586631, 41.01250256261518, 44.379092493364894, 47.07761649162539, 53.71760476020075, 53.60749598472349, 53.18465271303731, 52.533700081609915, 54.85933611469885, 48.61861375070388, 44.467196772175456, 44.682421145900605, 46.237138855841856, 43.32094292486868, 47.16106099467124, 42.642600382528, 40.5117335627156, 38.17915493442167, 41.7310493992221, 39.45566285041071, 39.326993419278054, 38.02000084230977, 39.25890107308665, 39.245051184008204, 37.876245975494385, 38.91359913733698, 39.18462707150368, 40.17339775639196, 39.023182315211145, 38.3426393232038, 38.106618542825025, 39.77923093303558, 37.82046594927388, 38.16217499394571, 36.97499905863116, 36.6775421942434, 36.42663209669052, 36.887498824827134, 36.64454721635388, 36.6677519582933, 36.75480896426786, 35.1750704549974, 35.493833634161184, 36.177671417113274, 36.86533743335355, 42.82011901178668, 44.85088302243141, 48.30859745702436, 47.46298936105544, 47.010740080187404, 45.56592718247445, 48.91797688699538, 48.21967732521796, 49.68399224742767, 50.55448778213994, 51.82166045711887, 54.051904447617076, 52.79809528781522, 47.95519190449869, 50.594837204102554, 52.67048097425892, 54.3820385779104, 49.7770740139869, 51.59154676621961, 50.263145892850815, 59.107125728361076, 46.829087272767104, 27.94193352422407, 0.8130866217036402, 7.6021466524370265, 5.856021690753199, 3.6569068556831734, 0.19131291567558245, 13.144338034814405, 60.77316030379265, 47.65477365063083, 44.69920104549777, 25.43750213038537, 24.20587593509305, 46.25724492534515, 21.066526559091386, 0.15325791172442899, 0.08522058596774455, 0.07823678289329813, 0.08332746013277963, 0.06720557643641388, 0.07243855450783046, 0.04721104550445753, 0.019541137115729433, 0.005532497861197279, 0.017987960881944147, 0.06377604594754596, 0.026499806760600018, 0.05115588503559271, 0.04675979290397898, 0.0676681173424567, 0.06062778464007763, 0.009708227195416488, 0.06645150077078613, 0.05043224987363623, 0.049554864695716294, 0.026546285314966115, 0.05711607589957215, 0.04205710472418897, 0.03854754102987148, 0.08571596906310128, 0.033178808347832774, 0.06860431509032365, 0.8023952212064498, 40.8863865944647, 54.810157437478345, 33.199635398003366, 31.37824554597178, 56.33319024116763, 48.404115015460604, 54.90388247274584, 52.68040064842471, 64.2201784349257, 25.89070454720528, 0.2578911197281653, 2.0914621987650475, 24.771397382982318, 0.6685448906594708, 16.284978851195305, 63.45974068487845, 52.94070874491046, 58.90521780137093, 51.54107762921242, 56.495470462306855, 49.78893133901781, 50.32622937233218, 50.3454097624748, 53.47359411178097, 53.22610432101835, 54.99971774316604, 45.351510817004794, 50.19289232069447, 50.12879686970865, 53.60348340003721, 53.12072200159873, 53.122510602397305, 50.441421539552756, 48.616680022208925, 45.590744018554695, 45.81731580918836, 42.7087668449648, 42.80623382137668, 41.38616715708087, 41.81655314660842, 40.797505686360026, 40.66912651062012, 38.631745461494695, 39.3816634147398, 39.60254384625343, 39.09166297604961, 41.50284982496693, 42.536641474693056, 39.688063283120435, 40.79639957797143, 40.72834645548175, 41.102568026511904, 41.921464781607355, 41.13120525113998, 41.12718482171336, 40.23381010178597, 40.59384445990286, 40.284526348114014, 39.805746155400435, 41.83176409813666, 42.30329967314198, 43.22644126030707, 41.058723772725756, 40.74090980714367, 39.116209168587964, 39.36176523085564, 38.2798304096345, 39.9580047207494, 43.43923376452538, 45.22717168254238, 49.300247161619126, 53.47235856517669, 55.053387534233835, 54.82918093281408, 54.99765849882557, 58.26584008432204, 50.10756115759573, 45.10266780853272, 46.040459448291415, 46.802701488617934, 45.30337549025013, 47.83329640665362, 43.594602769420995, 42.71206555827972, 38.874657846266224, 43.341315715543686, 41.100618608536266, 39.50447674720518, 40.721937302620184, 40.95600474265314, 40.76544031020134, 40.82957106251871, 40.57668409039898, 40.14133238023327, 41.26297727707894, 40.81842760885916, 40.062951657079886, 39.488438175570586, 41.21748955019059, 39.78025074928038, 38.546598649794056, 39.28970736842002, 37.468409692087484, 37.94886081449447, 39.350433503427816, 38.110611515660445, 38.753299713134766, 37.97803540383616, 37.94713497161865, 37.585872911637836, 36.29855494345389, 39.3357010810606, 45.009974356620546, 47.89627005977016, 51.83773433008502, 50.93812696395382, 48.455529443679325, 48.255013958100356, 51.00321085222306, 50.10091274015365, 52.29096028112596, 53.96944838185465, 54.32875317911948, 53.308901632985766, 54.023761441630704, 49.605003556897564, 51.556202288596864, 55.03516028004309, 57.97070918544647, 51.49080068834367, 52.834479193533625, 52.14373411670808, 62.358299916790386, 49.37575278743621, 31.28916459698831, 1.699779216320284, 10.009657259910338, 7.521423783994491, 2.8868820974903726, 0.17224239786305737, 12.577596729801549, 67.95648313337757, 52.57652451915126, 53.48492976157896, 31.896949583484282, 28.087339708881995, 52.394067625845636, 27.478495682439497, 0.06703389613258262, 0.03225564175555783, 0.057519750609513254, 0.06530982291986866, 0.04698368593028957, 0.05762466252030385, 0.09688451976305056, 0.04246328071120285, 0.0670500529269057, 0.025316706535616712, 0.03730096658992191, 0.006233177677307639, 0.20485074649895393, 0.13895025446770654, 0.1732712999106415, 0.12267290088798731, 0.10027112634552103, 0.12445467584315809, 0.18252389535548227, 0.17270534479570004, 0.10664780473997516, 0.11341233812873402, 0.11361816297135047, 0.17367328156626996, 0.19697962208620964, 0.17979015656296285, 0.16454028776816784, 1.1227715976776615, 46.713738210739635, 63.515426574214814, 45.61052060896351, 33.96820422141783, 59.98649758677329, 56.916764397774976, 61.56108994637767, 58.21083276502548, 69.96153600754278, 32.49055324062225, 0.7952364666327354, 9.205647860803913, 26.223607870840258, 0.9621610804911583, 18.97032564686191, 64.30811797418903, 55.655424287242276, 60.99469577112506, 53.91211117467573, 59.4288149956734, 51.9832464187376, 53.60167126501761, 54.343163967132575, 55.92618942260743, 55.804894047398726, 55.13738901384416, 46.8614625161694, 53.22625729345506, 53.79262401211647, 55.043208983636674, 53.603314738119806, 55.82433331397272, 54.272318117080204, 50.89145075890326, 45.68855616354173, 48.08592842471216, 44.64520569770567, 46.18919572522564, 42.72495446666595, 44.33533845409271, 43.122227807198804, 43.124581229302194, 40.627945546180975, 44.49806190306141, 42.340711239845525, 41.53353452682495, 44.91449602188603, 44.90025389579035, 42.14691085200156, 41.640850574739524, 42.72285992099393, 43.331635305958415, 43.98688685509467, 42.89578153241066, 43.50064239194317, 42.3165298277332, 42.77902433949132, 42.47993576911188, 42.90295162508565, 44.01020142339891, 43.315769318611395, 45.52552284732942, 43.035955275258715, 42.24250293547108, 41.27356767654419, 43.14538940306633, 42.10265474934732, 41.79615682171237, 46.96936691960981, 47.999718650694824, 53.10873523835213, 56.16137473813949, 56.14517534932783, 54.117478632157855, 56.516968973221324, 59.78052216191446, 54.39091882398052, 48.705290286771714, 49.41970686758719, 49.385448886502175, 48.11186313629151, 51.23510922155073, 45.537721418565326, 45.915182867357814, 42.43477752131801, 46.45524224927349, 42.93157708260321, 41.48918036491641, 42.05171100554928, 43.14279671638243, 43.0279810966984, 42.0792381994186, 43.54124676796698, 42.168495655059814, 45.32818448159003, 41.95433032128119, 42.17254746344782, 41.772457861131244, 44.25131344026135, 41.65806977979599, 40.733614198623165, 41.07367584782262, 39.68244644903368, 40.71111940568493, 41.333207315014256, 40.913215606443345, 40.47923280346779, 40.940134832935954, 39.86797455818423, 39.69443321228027, 39.02930513505013, 40.99719747420281, 46.954328552369155, 49.01798163690875, 53.19189340837541, 54.0223454659985, 51.53131877222369, 48.987469519338305, 55.03530148536929, 51.82336668814383, 54.36150497005832, 54.118816160386615, 56.473218856319306, 57.46525295319096, 55.18392009119834, 49.15139321357974, 53.42642761045887, 56.60563415096652, 60.374886758865856, 54.13462331218105, 57.59114142387145, 52.4954334382088, 63.66891676379789, 50.16448651590655, 35.875162539943574, 1.9460316218676108, 17.87486453210154, 17.979350589936782, 8.686626111307453, 1.007053955428062, 16.24052957181008, 74.69877858315745, 55.779080929294715, 56.76658468861734, 35.89711212342785, 32.94007255185035, 58.74524001152285, 32.995417194981734, 0.2603636225385051, 0.14537633787239754, 0.13567251664015556, 0.3015378147604004, 0.09780492843879808, 0.21686793875790414, 0.2403720065711006, 0.16078847941131363, 0.12638748503260075, 0.07597884598879084, 0.12377825084953539, 0.04189440297083028], [0.013336688693192218, 0.036975677996393175, 0.025748826090186357, 0.043999555130158706, 0.018860770599736322, 0.02457834524853576, 0.045864561707862926, 0.03992148524811191, 0.027207396210982438, 0.05188178781780505, 0.10238012043578971, 0.01295267275699805, 0.02233267149647638, 0.09688975980445262, 0.03673180539701735, 0.02660269619927051, 14.19469581496331, 53.27050947373914, 38.39070404729536, 30.87622727117231, 39.61401285663728, 39.25274687428629, 64.74417963335591, 46.68665424469979, 55.99508977705433, 32.42666371407048, 0.13787371707299065, 2.498802302345153, 4.340603678457199, 4.457953639568822, 7.214772883922824, 52.33086647525911, 54.516348377350845, 54.60348383072884, 55.46203967063658, 53.84887472275765, 48.54447310970676, 53.724033524913175, 51.840221112774266, 55.12420200532483, 51.798110546604285, 49.679450142768125, 46.44916649787657, 49.16381143754529, 47.69679007991668, 50.62515320316438, 48.86953953773745, 51.577183046648585, 47.414222532703036, 47.27620609344975, 43.38323408557523, 42.62986052420832, 39.71961090641637, 39.33439885416339, 39.125838587361, 38.87861551777009, 37.7210299430355, 38.863581072899606, 36.65083085336993, 39.119327452874955, 38.45479165354083, 38.135389128038966, 37.613725662231445, 38.55971505565029, 38.41670543916764, 41.01116503438642, 38.81004072004749, 39.65518205396591, 39.13295376685358, 39.962542903038766, 42.417511247819476, 40.79021007783952, 38.76930298343782, 39.827174063651796, 38.62259064951251, 40.2814119861972, 37.94025513433641, 39.52759911937099, 41.07984573610368, 39.6805166429089, 37.467389875842684, 39.612867524546964, 37.25384819892145, 37.572791807113155, 40.03123929423671, 47.14871729573896, 50.74764882364581, 54.74247301778486, 67.95783242871686, 51.03821408364081, 49.09685657870386, 54.87633958939583, 47.11656170506632, 47.10333155047509, 45.60246798299974, 47.55097204639066, 47.91712530197636, 48.60071989797777, 47.33006808065599, 42.22979837848295, 36.919391616698235, 40.00080170169954, 38.26611780351208, 40.64886354630993, 39.33696800662626, 39.69816730868432, 38.15104330739668, 39.07554987938174, 37.38382377932149, 39.48592001391996, 38.04633171327653, 38.80116439634754, 37.23184762462493, 39.49321562244047, 38.51233674633888, 39.19965759400399, 37.18215119454169, 37.13188602078346, 37.06926145861226, 36.345874417212706, 35.36843545975224, 37.35581413392098, 36.15022659301758, 35.778778137699256, 37.17123131598196, 38.33743433798514, 35.81182802877119, 37.74822373544016, 37.53304643015708, 36.04214176054924, 37.522252067442864, 40.210750487542924, 40.345350542376124, 41.4273363544095, 42.367701069001235, 43.590751001911784, 45.88828325271607, 47.71447996939383, 47.3758029168652, 49.8545329801498, 52.02931465641145, 52.58214527560819, 50.38257814222767, 50.36315456513436, 53.19313287734986, 54.0236633823764, 52.82279053042012, 52.61145322553573, 58.03782486146497, 44.22412357022686, 6.093556506018485, 4.9520438236574975, 17.400999069213867, 4.308275013200698, 1.8665009088093236, 0.3576693527640835, 20.61214743121978, 56.84604798593829, 46.566335539663996, 33.00945928019862, 23.226662105129613, 39.8886925174344, 48.29302956981044, 7.014321136859156, 0.2905442691858738, 0.09450334995504349, 0.057993005255177144, 0.15270640502773947, 0.09260959592798064, 0.021210036676136718, 0.04019183001571125, 0.052625283809198495, 0.03858486483354242, 0.018719597832269726, 0.012302184627661783, 0.06970440202783193, 0.050025867042882796, 0.01183883645646875, 0.042200267405038884, 0.0034532586259076433, 0.08060017946146189, 0.05427811467539399, 0.011983498754430444, 0.018830914238107302, 0.05842862966200037, 0.030401143988954927, 0.07212370003183043, 0.023152542623480963, 0.05367260261048233, 0.05276621717418875, 0.02475667711076958, 0.04953978808536645, 20.464411358679495, 61.057030077903505, 40.578609974153586, 29.61589913214407, 50.83179935332268, 44.566052267628336, 63.85975183979158, 50.57158539372106, 61.665326933706964, 35.07615220162177, 0.06108322774150199, 3.3610157524385764, 11.20468185793969, 3.8189750236849633, 9.59124332474124, 55.78431729347476, 55.68051961160476, 59.4754284428012, 57.15716646563623, 56.02991257944415, 51.72335017111994, 55.41860726571853, 53.15111644806401, 57.19127931902486, 54.378053449815326, 48.42289532384565, 45.34251682219967, 51.647444463545284, 48.978695177262836, 52.919782900041156, 52.38969810547368, 52.998249915338334, 48.45432919840659, 49.87237584206366, 45.63146998805385, 46.03935726227299, 43.02594930894914, 40.63053823286488, 40.341161451032086, 40.53672690545359, 38.98339771455334, 41.178940496137066, 39.87269709187169, 40.53050210399013, 39.797634693884085, 40.84373081884077, 39.61010617594565, 42.60882877534436, 41.53828451710363, 41.51291070445892, 39.60547385677215, 40.609651611697295, 40.85929478368452, 41.826974884156265, 41.53360512948806, 43.182177312912486, 39.77193924688524, 41.0009394153472, 41.3474690529608, 41.587274920555856, 40.70740884350192, 41.50608185798892, 41.46936847317604, 42.33000709164528, 39.88022412023237, 39.99060353925152, 39.967037939256244, 40.04474401473999, 42.697650847896455, 48.9707366881832, 50.95347127606792, 57.59323989191363, 60.98877691453504, 50.702212087569706, 53.39969665773454, 56.69629973749961, 49.76487152038082, 48.637998104095466, 47.903502910367905, 48.03896196426884, 49.06963532970798, 50.29306181015507, 48.899592737997736, 43.47630408502395, 37.81654750147174, 40.78448341738793, 40.63460180836339, 42.5561160425986, 41.79677263382943, 40.5205314390121, 39.428876984503965, 41.49431082510179, 39.45011661898705, 41.535448643469046, 39.55737383134904, 40.7292603677319, 39.91492532914685, 39.635562358363984, 39.17156950120003, 39.22498433820663, 39.76335317857804, 38.931634195389286, 40.2747949477165, 39.037549957152336, 38.109289676912375, 39.122947800544004, 37.88976638547836, 37.38503579170474, 38.76131311539681, 40.30437354118594, 38.6048105455214, 37.10737512957665, 39.200767624762754, 40.15787301524993, 41.65176653092907, 43.1016275190538, 44.50487898242089, 45.28083362886983, 45.8093612424789, 47.30464719956922, 48.94493925955988, 50.74840584108907, 49.80789992117113, 52.51867348147977, 53.439136089817175, 53.80253584154191, 50.537358791597434, 52.73410966319423, 54.77709185692572, 57.52500241802585, 54.58508791462068, 55.64241770775088, 59.69797980400824, 48.29360615822577, 9.724415636831715, 8.456141756426904, 17.597221520639238, 9.057462676878899, 1.9310257367549406, 0.1509784477492494, 22.437085067072225, 64.54609209491362, 50.03752331579886, 42.368842478721376, 23.839752097283643, 38.05577678065146, 56.03250134375788, 9.74378037837244, 0.2998476715818528, 0.07852790396540396, 0.05631584343650649, 0.10777820577664722, 0.045051114228103435, 0.006471487041938329, 0.0940405255964687, 0.05502319263835108, 0.010607577071735456, 0.013481971522372578, 0.07740733183680043, 0.0689736154351023, 0.1398305048144633, 0.10546686488293833, 0.10679526134364067, 0.12274372571658705, 0.14666249224495503, 0.15581333589169288, 0.09610124848662846, 0.1654803695818109, 0.1678736282572631, 0.10522025351923321, 0.14496309472428215, 0.16877722896395192, 0.08109357838909473, 0.23177850721103532, 0.21556384260615996, 0.15650561890534817, 23.273167687077677, 68.68400435293876, 50.22284353933027, 42.061450250687145, 51.47059655958607, 48.85026501071069, 75.21770815695487, 57.03107403170679, 68.13053438740393, 41.35048927799348, 0.27128497198704754, 6.1501626814565356, 14.483358725424736, 8.34806869106908, 14.48108571190988, 57.05960535234021, 56.418576317448775, 60.205381531869214, 59.855486500647764, 59.30049073311591, 52.99155835182437, 58.25445736608198, 55.17545169399631, 59.47818194666217, 54.236891269683845, 49.82571532649379, 45.87596701037499, 54.08351875120594, 51.1211996693765, 56.59300411901167, 52.42579175579933, 55.48109454493369, 50.072149999680065, 52.23439185850082, 47.04179348484163, 48.82628756184732, 45.73316920188166, 44.17230121551022, 42.923669584335826, 44.31134139337848, 41.840577663913855, 43.25195627827799, 41.76255779881632, 43.32223338465537, 42.581642827680035, 42.66907245882096, 41.54989865518386, 45.73730338004328, 43.414338481041696, 44.05170794456236, 41.90502612821518, 43.31569087120795, 41.43038011366322, 43.875785719963815, 46.260123945051625, 45.39373905427995, 41.63465715223744, 42.11994063469672, 42.911063086602, 43.12937044328259, 40.627820030335464, 43.22520571370279, 43.88673305511475, 43.22453106603315, 42.88350451377131, 44.337821314411784, 41.084097585370465, 41.45701692950341, 44.01583394696636, 52.456005773236676, 53.4165628494755, 59.684957535036155, 61.70443296432496, 49.38939086852535, 52.74706917424356, 59.06161838962186, 50.08533700819939, 50.64836186747397, 51.483783568105395, 50.804793834686286, 51.83138401277604, 51.37536925654258, 52.615583481327185, 48.37052775967506, 40.86599419193883, 44.069488048553474, 41.52537991923671, 45.54287933534192, 44.211524917233376, 41.55232267995035, 41.685702877659956, 42.72790016666536, 41.34923019716817, 42.58803629106091, 40.76140419129403, 43.22384072888283, 41.272861649913175, 42.84584191537673, 42.623267019948656, 41.80644912104453, 40.73353182884955, 40.926441838664395, 40.46705776645292, 41.05482493677447, 40.354015058086766, 40.160014629364014, 39.65760215636223, 39.4279787617345, 41.10185023277037, 42.030753781718595, 41.05825701067525, 40.89031680937737, 42.22325586503552, 41.05990440614762, 42.3987348618046, 43.87422069426506, 46.37632808377666, 46.90232184625442, 47.659092180190555, 48.57770342980662, 51.063944831971206, 52.45522914394256, 52.74435097171415, 54.74089622497559, 56.18446573134392, 55.6780759749874, 51.03595087605139, 53.70304099975094, 56.82203523574337, 60.71511706998272, 55.9580429907768, 58.3990437753739, 60.033781759200565, 51.892682813829, 11.767584143146394, 10.038373912534407, 27.82711986572512, 16.999207158242505, 7.212100278946662, 0.850512406999065, 27.921394032816735, 67.75215118162095, 56.574517988389545, 44.81311059767201, 34.11535586080244, 50.84340956903274, 65.29630030355146, 14.058300295183736, 0.4975371507387008, 0.35581627800579996, 0.11574618668565828, 0.2658266568135831, 0.19371731326945368, 0.12696290133340707, 0.13820400822066492, 0.11931913649483074, 0.06874926658647676, 0.12703557243390431, 0.12535633834739848, 0.2577986988809801], [0.07549066411992235, 0.09263308418373908, 0.048630257858143705, 0.052756173761501435, 0.015061375733855513, 0.08109256715303467, 0.04175183017768207, 0.05087262019515038, 0.03451397319534614, 0.02878866871939071, 0.0676264344984966, 0.09999809260930746, 0.039106769892837734, 0.0528193989978923, 0.0636569652405958, 0.08520070598610947, 3.1304527050064457, 38.64354395097302, 47.24458786749071, 32.16295100027515, 31.727922885648667, 38.97836923599243, 50.28131823385916, 53.757510954333895, 50.489705916373964, 47.95402303818734, 1.7396235105491455, 2.0696153323496542, 5.59720213374784, 6.408099214876852, 33.556810348264634, 24.571844839280654, 57.51239592029203, 52.25892236155849, 56.25096167287519, 52.53226841649702, 58.007814807276574, 52.60548337813347, 52.58096071981615, 50.024618717931936, 46.91152764904884, 48.3446793402395, 51.290347960687455, 51.84806193074873, 52.11935266371697, 50.8404246453316, 52.777640127366595, 51.8314467706988, 48.73360195467549, 48.28260390989242, 45.81485648309031, 44.878939736273985, 43.193308999461514, 38.810491792617306, 40.016906953627064, 38.343855257957216, 36.04007467146843, 38.4649545146573, 39.7974346530053, 37.638648402306345, 38.42150642025856, 37.637989444117395, 39.61896681016491, 40.60742762780959, 39.54712860045895, 38.297861545316636, 39.883193354452814, 39.37619170834942, 40.67246444763676, 40.80143982364286, 40.222497986209014, 39.07271400574715, 40.55711930797946, 39.14919630173714, 39.99813448998236, 38.11632640900151, 40.22369823148174, 38.57031722222605, 39.46018926558956, 40.32611916142125, 39.13463646365751, 38.152616177835775, 36.49654442264188, 38.81911316225606, 43.8558247781569, 47.66869806474256, 52.05420601752497, 54.05587388623146, 69.83260769997874, 65.13871908187866, 49.437612487423806, 56.01402698024627, 51.67880773544312, 49.48384938701507, 47.54965413001276, 50.975338489778586, 49.807939144872854, 52.9023911106971, 52.024046913270034, 49.81860799174155, 37.95638784285515, 38.46580959135486, 38.43530139615459, 40.76981375294347, 38.48217764208394, 39.43609022325085, 37.30714144245271, 38.557365555917066, 38.7060429972987, 37.61673019778344, 40.098719750681234, 38.71065962699152, 37.36452571807369, 37.84696155978788, 37.693165425331365, 35.80317528017106, 36.86187005812122, 38.40012558044926, 37.01975330229729, 36.75436573643839, 36.24790929978894, 35.791651356604795, 37.05758456260928, 35.48163506292528, 38.268890919223914, 36.52069445579283, 35.81700947976882, 35.14416610040973, 38.552623410378736, 36.42598882798226, 34.791796053609545, 34.28922668580086, 34.94871831709339, 34.029200999967514, 34.636889888394265, 35.45317826732513, 37.97000631209343, 38.66974146135392, 44.1642132882149, 46.86857377329181, 50.74914716905164, 51.83377665858115, 53.0072242982926, 47.81393950985324, 55.03872571452972, 57.29503385482296, 54.76149259075042, 55.73038470360541, 55.02510724529144, 22.0406432690159, 3.1930571650305106, 18.237426857794485, 3.275319318617544, 4.762945867353871, 1.304251453088176, 0.046498947626640724, 25.998475590059837, 58.25210002160842, 42.16937034360824, 35.54047453788019, 31.179765770512244, 47.09588296951787, 37.56128357302758, 1.7448521525629106, 0.1040314612609725, 0.04437606053186521, 0.022631413228208982, 0.055497489163591984, 0.08170140786997734, 0.009064520859429914, 0.05900772701528284, 0.024099034677830436, 0.041586979547695774, 0.03687315627992634, 0.10363692597996804, 0.007061904780716906, 0.020828392739678105, 0.10961592047204895, 0.008502459386363626, 0.06347421879669832, 0.006835179623111242, 0.028541088254461368, 0.05003652715634915, 0.015121710903552032, 0.04168093640116915, 0.021407752478074644, 0.06637217236622688, 0.034800248761330886, 0.02430299792679087, 0.06999336273199128, 0.06775867659598589, 0.07949818496502216, 5.9519863993890825, 51.10328228242936, 49.89699655963529, 30.242374212511127, 41.57813972042453, 48.451163845677534, 57.177413740465724, 58.91881665875835, 53.21193671995594, 51.8046256034605, 1.2327354906066772, 0.7342271855281246, 6.506439408948345, 11.567155930303759, 35.90833010212068, 28.965960433406217, 58.80305967023296, 54.39894007098291, 57.25184071448542, 55.82394107695549, 60.20406753786149, 55.02832751120291, 53.387741273449315, 53.424697845212876, 48.36267125221991, 50.55478980464321, 51.79801248734998, 52.647978336580344, 53.715168968323745, 51.94424236974409, 54.72778374148954, 53.74632827697262, 51.6535908176053, 50.52936500118625, 48.50347649666571, 46.65166670276273, 43.30946606974448, 41.30144396135884, 40.38854368271367, 40.26676585597377, 38.69191069756785, 39.44395849781652, 39.63888460589994, 40.684439443772845, 40.91392947781471, 39.798293652073035, 41.915436098652506, 41.06659989203177, 41.450980401808216, 40.852920932154504, 42.540905091070364, 40.6816114148786, 41.311171439386186, 43.46319944627824, 42.884971480215754, 40.855329267440304, 41.492502612452355, 39.33060592220676, 41.842236826496745, 41.076645082043065, 41.81945177816576, 40.78382053682881, 41.10737292997299, 43.3788880994243, 42.62060373060165, 40.836176333888886, 38.614381128741854, 40.14994590513168, 47.34062710115987, 50.53337758587253, 52.53515920331402, 55.66324549336588, 70.2117753797962, 60.04759242457729, 50.2713240346601, 57.724878557266734, 50.39529054395614, 50.44487714767457, 49.78052962210871, 52.38884302877611, 51.55637095051428, 53.17805920877765, 53.723280429840095, 50.155621959317116, 39.79208454009026, 39.709365675526286, 39.70933821893508, 42.273015053041526, 40.49280812663417, 40.40996374622468, 38.81191169061969, 39.47230154468168, 41.06542318098007, 40.738195526984434, 40.50060579853673, 39.86624479293823, 39.30492224231843, 39.05618906021118, 39.32564804630895, 38.35037423718361, 39.42341312285393, 39.63471904877694, 40.09051022991058, 39.18336406830819, 38.75335462631718, 38.27293880524174, 38.21371886038011, 38.04196219290457, 39.45887134921166, 39.031313388578354, 39.051941133314564, 37.15166261119228, 39.4618131268409, 37.4074835162009, 37.264093429811545, 36.3120125955151, 36.17503558435748, 36.72748181127733, 37.2264112195661, 37.93758792261924, 40.38759446913197, 42.59409635297714, 47.50526858914284, 50.28555831601543, 52.90748234718077, 54.7071873757147, 54.54624076043406, 49.15262091544367, 55.7225791869625, 58.54332816216254, 57.71868121239447, 58.086183763319454, 59.3674652038082, 25.416066377393662, 6.696709173340952, 22.8348938111336, 4.671826756769612, 5.930824722013166, 0.8901333099892064, 0.03400777293849857, 28.769724253685247, 61.77700857962332, 48.20544304386262, 40.84355038981284, 30.455962957874423, 50.46450076564666, 45.07090837724748, 3.1287190173902824, 0.2490113333107964, 0.0573562138203171, 0.0014226025321535888, 0.02986333111391193, 0.08329922979276988, 0.05521066967518099, 0.01933485453557824, 0.033216607126016776, 0.05149754875850293, 0.015603128216049124, 0.02769020971872153, 0.028280666240701274, 0.13350903837671205, 0.27548077426129775, 0.12287955310556198, 0.1463242797481437, 0.06645883989310072, 0.16170424559424001, 0.14225972365708123, 0.20240401488638696, 0.0862720033394233, 0.08996738932065426, 0.21699956798505401, 0.11706873789549836, 0.12138666224575813, 0.1407153670105242, 0.17827186222758987, 0.2649659723524125, 5.772946380799817, 57.67879070774202, 59.16551413074617, 42.681941755356334, 43.20146360704976, 50.97715846953854, 59.72371447470881, 63.80756862701909, 56.95043402333414, 59.54979658126832, 2.4631857102917087, 4.4103399880470775, 11.721948346784039, 12.793749724664996, 41.83943233182354, 31.826070393285445, 59.45745614267165, 54.62220138119113, 59.40014639208394, 60.38776782251174, 62.58651910289642, 57.544888834799494, 53.82698005245578, 54.1022127674472, 48.8061148120511, 51.705405327581595, 53.41249142923663, 53.666072660876864, 55.3331192078129, 53.77260031238679, 56.62008024031117, 56.63453417439615, 53.124860102130526, 54.03342223936512, 50.72679750380978, 49.00944655941379, 47.34691466054609, 43.10480071652321, 43.53728517409294, 43.02700050415532, 40.7197525424342, 42.30627282973259, 42.962304930533136, 42.626553966153054, 43.1376858680479, 41.72596600747878, 43.80970162730063, 43.495794342410186, 44.424591987363755, 42.9363113834012, 45.47665795972271, 42.61964274990944, 43.708590768998675, 45.855688356584125, 43.305641758826475, 43.13408905459989, 42.941520290990034, 40.73556361659881, 42.836655724433164, 42.6234160700152, 43.58767586369669, 41.631436886325965, 43.10417313729563, 47.1965584447307, 44.48045438335788, 43.63737229377993, 39.066928509742986, 42.23954154599098, 48.03108976733301, 53.88889074325562, 53.91460187973515, 58.988913336107814, 69.49154192401518, 54.605445015815, 53.40185003895914, 58.92629661867696, 55.54538219205795, 51.31287021021689, 51.61042121148879, 54.964816493372766, 54.36065381573093, 57.05080355367353, 55.66936831320486, 51.43054131538638, 42.49983003062587, 42.35029359017649, 41.881546820363695, 43.100352748747795, 43.007588694172526, 43.10874269854638, 39.164183678165564, 42.4134555170613, 42.38482221480339, 42.760510752277995, 43.81903294594058, 42.65653656375024, 41.55480554026943, 41.548659186209406, 40.83597237063993, 40.70835805708363, 41.06169692931637, 42.05103635787964, 41.73965115700999, 41.716850419198316, 40.999750937184984, 41.43853079888129, 41.90492806896087, 39.274845507837114, 41.48614445040303, 42.303507558761105, 39.365193382386245, 39.147341020645634, 40.991106033325195, 39.079307510006814, 39.303937727405184, 38.91136730870893, 38.38149039976059, 38.83519880233273, 39.19615883981028, 39.55131769180298, 42.18899788395051, 43.63229674677695, 47.57576927062004, 50.95174935556228, 55.57381545343707, 55.82437253767445, 56.43034735033589, 49.331480995301284, 55.80643161650627, 61.7033503901574, 59.50299093800207, 59.915710572273504, 59.83843595750871, 28.33529430051004, 9.516153470162424, 28.753538593169186, 10.845920308943718, 15.1859454378005, 4.7376333417431, 0.21354474127292636, 32.785588041428596, 68.20525553918654, 52.0108324481595, 48.80637368848247, 42.56962860784223, 56.074917854801306, 52.81822881390972, 4.522557527788224, 0.31545389383550615, 0.1581512217319781, 0.12425607520966761, 0.16158943965790734, 0.23336214884634943, 0.12878282746720698, 0.19529841149285918, 0.1617161046353079, 0.1709372445099777, 0.09692463978764512, 0.2792382823123086, 0.12887596843704102], [0.05156134089995777, 0.06939166195450291, 0.00919416974929552, 0.0653713244584299, 0.06330690902447508, 0.013427454790460968, 0.025289895373486707, 0.0553075836280421, 0.07068582194586916, 0.10014490569911658, 0.0172074705046872, 0.013677333519163152, 0.10580024336494746, 0.16402887811343517, 0.09387292854127385, 0.05955093314931278, 0.03189557468548658, 22.020119467089255, 47.67953557352866, 37.39685389303392, 24.644802885670817, 30.609564935007405, 49.99066668172037, 55.34893420434768, 50.18265493454472, 52.8779233655622, 4.499659711314786, 1.9455333582816587, 2.1873065396662685, 0.5187951100449408, 8.283877142014044, 16.291442917239284, 42.50655689547139, 53.661169698161466, 52.22016934425601, 51.822444931153335, 52.49158167069959, 52.17684676570278, 52.732356363727206, 51.33738502379387, 52.00294456174297, 53.3745385754493, 52.62212207240444, 51.728743430106874, 49.25839154951034, 50.071973493022305, 52.039359846422755, 52.427101827436886, 52.336091072328635, 49.392171828977524, 46.83379019460371, 43.35323972086753, 43.488683085287775, 41.21335929439914, 38.336583183657744, 37.21973142316265, 36.6900820116843, 38.037518147499334, 38.1892668047259, 37.51218334321053, 39.28922491688883, 38.66311657813288, 39.502260608057824, 40.824797538019, 38.88979427276119, 39.71131509350192, 39.48274289408038, 39.912430701717255, 41.10930273609777, 40.951474405104115, 41.04052005275604, 41.12341150160759, 37.419364375452844, 41.25941968733265, 39.15229889654344, 39.63749216448876, 40.80178499221802, 39.30072138386388, 37.800136304670765, 40.683804019804924, 39.9970519158148, 39.22819283700759, 37.09198767139066, 40.98750137513684, 43.2325719248864, 52.7925725906126, 49.60801985956008, 55.63817762559461, 37.54470763667938, 61.47925753747264, 58.27599902306834, 53.86321883047781, 55.035430923584975, 53.545765722951586, 53.885839139261556, 49.15135398987801, 52.42932188895441, 53.26431997360722, 53.168484703187026, 52.049930634037146, 45.192858788274954, 37.14571237564087, 40.20052094613352, 39.2645335966541, 41.935604926078554, 37.56107568740845, 38.32802064957158, 38.09004260647682, 38.663587262553555, 36.55015930052727, 40.05045106334072, 38.94420146942139, 40.137939530034224, 37.714118726791874, 38.68761570222917, 38.330542733592374, 37.49537206465198, 37.10069141080303, 38.12171574561827, 36.83407614308019, 35.86721189560429, 36.39371556620444, 35.04203542586296, 37.35841466534523, 36.56748440957839, 36.228336672629084, 36.80999279022217, 35.07520298804007, 35.666751323207734, 35.19240340878887, 37.93074730903872, 37.60806175970262, 41.826461053663685, 39.39952196613435, 40.03923700701806, 37.09674550640968, 38.47488203356343, 35.34579161674746, 36.5936662304786, 39.17401313781738, 46.50562117176671, 49.10952583436043, 53.24732826602075, 50.728546880906634, 48.97825979417371, 52.37884098483671, 63.36592543509699, 50.504575621697214, 43.602765221749586, 3.717325084632443, 20.8261578313766, 29.21472695565993, 2.444390447870378, 7.556861417908823, 0.8988691638073615, 0.5442205263722328, 42.27861227527742, 53.41144415640062, 37.58174657821655, 24.598840551991618, 28.902757321634603, 46.63114486202117, 20.278553770434474, 0.044566295485222535, 0.05054420596289058, 0.040267071341194456, 0.03193639376531205, 0.025078704084960685, 0.024406856466685573, 0.030394592021982518, 0.0385560292840725, 0.06809970829635859, 0.060012447497537064, 0.054339141239442175, 0.024889980240034002, 0.0478146423495585, 0.06376972189173102, 0.03096587144799771, 0.042609224291217905, 0.048387817843186284, 0.0586029376474119, 0.012614625926700332, 0.02742822105515628, 0.045696279003975854, 0.06043491434426077, 0.03280899855458448, 0.059613419110856714, 0.011246225312201968, 0.040154609633910085, 0.0572419211628937, 0.04022526592316647, 0.020633955794056098, 0.1535937340269166, 29.61093145032083, 54.99619937712147, 37.04807673731158, 29.023136823408066, 39.795281271780695, 52.715062633637466, 62.759632910451586, 52.990260047297326, 58.6528407373736, 4.626415516099622, 0.8049447618184552, 5.122529643197214, 2.180070256994617, 13.14660124240383, 19.6055240784922, 46.926252226675714, 54.40021091891874, 53.39811986492526, 52.8894002206864, 54.72539109568442, 53.42917719194966, 52.10907997623567, 49.38452320714151, 51.11032293688867, 54.65782826946628, 53.46305862549813, 52.91686073426278, 51.84396697628883, 51.30747302885979, 52.777338104863325, 54.42891482383975, 54.12140884707051, 50.524258075221894, 48.009669703821984, 45.840842185481904, 45.270074567487164, 42.24855123027679, 40.43569449455508, 40.30392246861612, 38.32889141574983, 39.04219012106619, 39.20106572489585, 38.980267663155836, 42.029361340307425, 39.9745532005064, 41.48132777983143, 41.56601959659208, 40.45662818416473, 40.41672591240176, 41.10405068243704, 41.19401808707945, 42.97246386927944, 43.35414186600716, 41.66988003638483, 42.96286582946778, 40.47789527523903, 43.746300435835316, 41.27884326442596, 41.460680423244355, 43.04456880015712, 40.60800029385475, 42.36630078284971, 40.91266255224905, 42.194234248130556, 41.101014767923665, 40.445924035964474, 40.928489315894346, 45.00607944303944, 51.65088045981623, 53.78225326538087, 54.393229100012014, 47.29731628971715, 64.22148850656325, 53.59158292893441, 54.521643577083466, 56.56482581169375, 51.90591689079039, 55.019549246757265, 53.27118412140877, 51.6791646711288, 54.07707037464265, 52.929306414819536, 53.4703738458695, 46.134219784890455, 38.73642959902364, 41.25103758227441, 40.670962179860766, 41.47045889208394, 39.52130371524442, 40.082206572255785, 40.476765632629395, 39.644654412423414, 39.528693460649066, 41.28992003779258, 40.7331278247218, 40.39265824902443, 38.73641783191312, 40.08179472338769, 39.011678003495746, 37.992877652568204, 37.88786403594479, 39.25307243101059, 39.73229192918347, 39.05449067392657, 38.26784756875808, 38.54434720931515, 37.71559746034684, 37.81331939081992, 37.2729972101027, 38.19603289327314, 37.89444185072376, 37.52050661271618, 35.215804269236905, 38.69753929876512, 40.60421128426829, 43.44476822883853, 40.950650707367934, 41.240305977482954, 39.78198443689654, 39.19260909480434, 36.99132004091817, 40.23349238980202, 42.67863519730107, 50.90415139352122, 52.01755539063485, 55.90267481342439, 50.90200193466679, 51.23587408373433, 51.5201674738238, 61.957990661744155, 52.00207771793489, 47.497039456521314, 7.71237260872318, 24.85681679940993, 37.3745003054219, 3.5581332397076393, 1.6531164944171908, 0.29543292137884325, 0.6945200516812263, 46.58265259958083, 60.2810009064213, 44.30625800163516, 37.40609891953007, 32.03855106907506, 52.74937552790488, 26.509738891355454, 0.09701050292219847, 0.06930262721594303, 0.034634842717599486, 0.06756553816939555, 0.029745119916755828, 0.0114957727078769, 0.08624188076224058, 0.04073437348368668, 0.0523610141188387, 0.03443502400430941, 0.06424892521012696, 0.021575500835634528, 0.04915492849484567, 0.14511314070513173, 0.21958911370846534, 0.13631946257045194, 0.12296661133727721, 0.1229355771154646, 0.11761183294677928, 0.11794917210335694, 0.12225057193708998, 0.3367904844062944, 0.16311999140006883, 0.169936626428558, 0.06515332647869665, 0.16834354659001674, 0.20942032307146058, 0.1489955517313173, 0.20293859103994988, 0.4611997618790596, 32.485381595550045, 64.36513354701381, 46.92975490323959, 35.19789472703011, 43.038312619732274, 59.72111786565473, 65.70266962051392, 61.71303864448302, 64.3402264964196, 6.186386750590417, 3.8154488129000512, 9.927417905099931, 1.3131580525828948, 11.349186878050528, 23.61161724213631, 46.90715420630671, 54.71324743763093, 54.274098873138435, 53.5715356949837, 55.40443181991578, 54.65940113990538, 52.769085438020774, 50.2630635230772, 51.58863636755174, 57.21906931169572, 54.62708865442584, 54.81233043055381, 52.0064825396384, 53.45661809367519, 55.4418904550614, 56.075153197011645, 57.416380220843905, 53.65304254716443, 50.76564858036657, 48.45856535819269, 47.15183558002595, 44.6866023925043, 42.791713206998764, 42.17094321404734, 40.349520021869296, 42.18653071311213, 43.213913209976695, 40.476530290419056, 44.51762276311075, 43.3099171423143, 45.358410266137895, 44.541204052586714, 41.64330205609722, 42.79658086838261, 42.250284917892955, 41.559449626553445, 44.038383653087, 44.93087583972562, 44.41710810507498, 46.132007568113266, 41.50148484014696, 46.8578774698319, 42.703691297961825, 43.526800678622344, 44.842395013378514, 42.07646900607694, 44.28385734558106, 42.832996153062396, 43.95550004897579, 42.4798769335593, 43.55818748474122, 44.57071596576322, 48.42560568163472, 53.871895113298976, 54.6515485548204, 56.74627073349492, 52.75891865453413, 60.70427171645626, 53.62628806021906, 57.935517680260446, 56.84682069286224, 53.06428693955945, 56.77717508808259, 53.772706216381444, 53.24762244378367, 56.91308129218317, 54.898763779670965, 55.886036119153424, 48.374199098156346, 41.72915881679904, 44.35272239869641, 43.63434814637707, 44.13603498089699, 41.523152012978834, 42.320922882326194, 42.4878393450091, 41.47555797330795, 40.901283756379165, 42.89058046956217, 41.40126043750394, 42.909466681941865, 41.60981678193615, 43.99939137120401, 42.60432981675671, 40.05496963377922, 40.90446872095908, 42.26514285610568, 41.02375192026938, 40.12862782324515, 41.087357074983665, 39.902907186938876, 40.984669423872425, 39.281046775079545, 40.56343432395689, 39.379494344034505, 40.86259741936961, 39.95611413832634, 37.03039469257478, 41.254210779743815, 42.99860646647792, 45.999670720869496, 42.67099834257557, 44.24975233693277, 42.78013437025009, 42.5177199609818, 39.63608011122673, 40.99319665662704, 45.47569305666032, 51.3109286369816, 53.716632012398016, 61.17188099891909, 53.405729263059555, 52.75971489567911, 51.085588470582046, 62.429565460451194, 51.54788686383156, 51.38628521273213, 10.869064254145469, 28.491481119586577, 39.89052818667504, 9.50453737089711, 17.530382371717884, 3.198344029726521, 1.2840342089053125, 50.91817778925742, 65.99696113217261, 46.09928323376564, 37.428311301815896, 41.02452462719333, 61.29301163458056, 33.29331728719896, 0.26469860766683856, 0.1671625301241875, 0.25289331532774434, 0.23440755242782257, 0.07585742105279239, 0.1575733922542103, 0.2115313243120909, 0.21083576244211968, 0.1749582101981486, 0.172305584795052, 0.18677062715493864, 0.14311475438937066, 0.17958476839046325], [0.038753599529304815, 0.0625375077699221, 0.052043206373890566, 0.09764226498983561, 0.06819427418973177, 0.0599339388070568, 0.0748526890792193, 0.009466821399156847, 0.05611101450819162, 0.03495185756154599, 0.055419654630485086, 0.05752302946582918, 0.0786811292111393, 0.09028331631974829, 0.0365532532845053, 0.020249362419089003, 0.060422534363404404, 5.398097230542091, 54.60703357573479, 41.879730762973914, 24.54142881977943, 38.04892439996043, 40.5138869439402, 57.406648820446385, 47.34158808185209, 58.57227917640441, 9.436427374039928, 0.4297266023293619, 5.38835455333033, 2.837998088329069, 0.07790634618891824, 10.60958573895116, 44.56245545418032, 50.09067535400391, 50.39490615167926, 53.747403006399836, 47.208105902518, 46.598483285596295, 52.61571684191304, 51.972330462548044, 53.098442939019975, 53.264602384259625, 51.47577408821353, 53.05830140267649, 50.950274544377486, 50.71994512311874, 49.69209978657384, 51.5956142640883, 50.1469535212363, 49.43328611312374, 46.50802950705252, 43.30349229997204, 42.969400498174856, 41.052789226655044, 38.0323366965017, 38.04066388837753, 38.93068105943742, 37.37555542299825, 37.14030342717325, 39.18394457909369, 37.61110944132651, 37.85007984407487, 39.945927742988836, 40.14556069527903, 41.2784824063701, 40.45358442491101, 37.514419094208755, 42.076908311536236, 41.16868349813646, 43.04077586820049, 40.29207691069573, 39.54512819167107, 38.9258526217553, 41.17042895286314, 39.67958704117806, 39.62554462494389, 38.85012342083839, 40.27595204691733, 36.994426558094645, 39.56500284133419, 38.74720827225716, 39.14643495313583, 37.67458123545493, 39.83807040799049, 42.16323183428857, 50.34884575874575, 51.25536434112057, 58.43194853874945, 43.62960992320892, 41.225793207845385, 66.24736524397328, 59.15158971663445, 53.801151244871086, 55.63966028151974, 62.14531913880379, 50.22870748273788, 54.03562268903179, 51.821127014775435, 53.01838736380301, 51.19584629612585, 49.03571467245779, 37.95105734179097, 41.9043436358052, 39.891002793465894, 41.393984440834295, 40.5283094990638, 38.72807887292678, 38.46168718030376, 40.22995833427676, 38.093353086902255, 41.068819953549294, 38.25874374758813, 38.585983168694284, 36.49361048975299, 37.09814971493137, 38.294598133333274, 38.05607095841439, 36.495348099739324, 36.18123685159991, 36.01851340263121, 35.99233550410117, 35.394566289840206, 36.12474687637822, 36.066170200224846, 36.49219451412078, 37.60202523200743, 37.347800731658936, 37.425957879712506, 35.735745814538774, 40.33743127699822, 39.982441086922925, 45.26510884684902, 46.89543416423183, 48.11161994934083, 47.923667815423784, 48.807817120705884, 47.565873130675286, 44.47633197230678, 41.494181386886105, 38.84081171404931, 39.16809428122736, 47.83265706031553, 51.48169294480355, 51.506246982082246, 51.57952470164145, 48.2804113049661, 48.955682631461855, 51.43722895653018, 16.607558496536747, 0.6709617448429908, 8.372277559772614, 7.748468220233918, 2.0394911617040634, 1.7272854500239896, 0.7976714617783024, 1.0285839678779727, 46.69718580861246, 47.78454526778191, 28.219415718509307, 22.21489848629121, 26.151267597752234, 48.88782954985096, 9.988276420101043, 0.29836887673985574, 0.10417742399318565, 0.06251688085256085, 0.04175115218986908, 0.030921062965306546, 0.01787623270384727, 0.034821285535731626, 0.03101112617690477, 0.06356021599663843, 0.043157950088742285, 0.08536800426701385, 0.036662842162073626, 0.056162346229558034, 0.02848026661893293, 0.025987596543986472, 0.03604609541775238, 0.018517417652953057, 0.04347448229729649, 0.029188807933561267, 0.07099406508308265, 0.02282347913170534, 0.0389433441863906, 0.02755860921986882, 0.01814996932573136, 0.05796753666213444, 0.060916753005116224, 0.05219687595062199, 0.08085507223562849, 0.07946196432796218, 0.14109732312781198, 11.29021208132467, 60.34086019762101, 46.69707205987746, 24.44248507099767, 47.179033294800796, 52.761079880499075, 62.96759305461761, 54.5450601270122, 61.03086786885416, 9.68756300787772, 0.6163314020922107, 3.767698859014819, 4.21004758727166, 0.41928467070383413, 13.793428521002493, 46.00602888291883, 49.69643008324408, 50.85272519819198, 52.40696830134238, 48.737002649614894, 48.10140609741212, 50.44856809800672, 52.11614024254584, 54.554877819553504, 54.085013174241595, 52.470808798267, 52.39786840254261, 53.15842382369503, 53.910781491187315, 52.61892926308417, 52.5287147491209, 51.99884960728308, 50.34750038577665, 47.97395260103288, 47.33147621154786, 45.75677010320848, 43.659604287916615, 40.43134850840415, 38.33972892453594, 40.671993763216086, 38.76823217638078, 38.86063145053002, 39.82143955845987, 42.04067737825456, 39.75461021546395, 41.5487729349444, 42.020218295435754, 41.3608011891765, 41.79172454341766, 40.28218077075097, 42.87954291989727, 42.29779266542004, 44.354526688975675, 43.78638705899639, 40.957126540522424, 40.19492372389763, 41.27513662461312, 42.023367958684126, 41.234920563236365, 41.58070495051723, 42.14467902337351, 39.65215006182271, 41.35361932939099, 39.63507990683279, 43.319224926733206, 40.77015499914847, 41.50133971245059, 43.642487064484634, 51.36752059382778, 53.254117888789025, 59.05359714261947, 43.024921647963986, 49.46229204054802, 66.4555803422005, 58.186506225216775, 56.23176951562205, 56.21767643959292, 56.686517346289854, 52.71539603510211, 55.45709748421946, 53.120392522504254, 54.3380452740577, 51.881653108904445, 50.648801172933275, 39.328648659490774, 41.79774538163216, 40.647502483860144, 41.71575215555007, 40.25475948087631, 39.744647395226266, 41.98335193818615, 39.979715039653165, 40.52300253222066, 41.64237245436638, 39.80332605300411, 40.01266687147079, 37.998361126069106, 39.67458994157853, 39.31133531755017, 39.01076409124559, 37.60169967528313, 39.46293884708036, 37.68946663025887, 37.068273021328835, 36.771486882240545, 38.66199870263377, 36.29514640377414, 38.78590245400706, 41.02232417752666, 38.76829493430353, 37.827357553666644, 38.116655888095984, 41.07975159921954, 40.899734420161096, 47.53844007369011, 49.813803088280466, 49.34168308011947, 50.35229744449739, 50.4029195539413, 48.41232845860143, 45.547903891532656, 43.05908549216486, 40.42191520813973, 41.66062716514834, 49.25481434791319, 53.5840323663527, 55.33335455002324, 51.66194154370216, 49.828939514775435, 49.52563047409058, 50.327308024129565, 21.289680004119877, 1.1641524804215277, 13.445805522703356, 8.053805616594131, 1.619151710502563, 0.2612159719630595, 0.6192128732800484, 1.1074763151907152, 52.62653473884829, 52.84914493560792, 36.94551852441604, 27.146384677579327, 29.253311311045003, 56.0344115380318, 12.777320877198251, 0.2569616405713943, 0.11185704940749754, 0.017373822667005084, 0.09209746615059915, 0.026836569436014663, 0.019983194745896805, 0.033098342302705974, 0.10717118834896434, 0.03494928350612041, 0.016249035139598193, 0.05579643965428395, 0.0338681610751777, 0.14769922371112532, 0.1410364804248656, 0.13312826203482767, 0.12630434917105784, 0.17183951222367827, 0.17266417523064923, 0.2455315168105787, 0.1142329408697063, 0.13072504421635983, 0.08996247103618038, 0.1641261712798188, 0.10312029160559179, 0.15017010241506562, 0.16988595737324608, 0.28594645461247814, 0.10900252153195682, 0.1447811028769901, 0.35776067044465776, 14.157954973559226, 71.59423828125, 53.59180650403423, 34.0658280926366, 49.844256370298325, 53.60507588232718, 66.75218997463104, 56.76522362616755, 69.87949571301861, 12.657701334645672, 0.8917314306862894, 13.291655394338793, 7.154376228009501, 0.9230250805135697, 16.146600573293625, 48.31500660988593, 48.21985383187571, 52.99187606380832, 53.84603884912307, 48.91831028846003, 47.224250378147254, 52.93784933705484, 52.34993311666673, 56.55356468692903, 54.87871654572026, 55.12160931864093, 54.87761435970184, 53.84023374126804, 54.64670050528742, 53.12913156324818, 55.78315627190375, 52.91441317527525, 54.4255768868231, 50.56157158267114, 49.461523255994244, 50.491023832751864, 45.943098375874186, 43.61530896156065, 40.80867659661078, 43.52279986104658, 41.233920358842425, 41.92910163633285, 42.42100215727284, 43.62988841149115, 39.79623833010274, 45.09382678616432, 43.274851152973795, 44.292251217749815, 44.27919756981635, 41.75567011679373, 44.83097307143673, 44.800511944678526, 46.327690693639944, 45.5434912250888, 44.54336527855166, 43.46452520739648, 43.46408982430735, 44.51412008654687, 43.519826704455966, 44.98641267899544, 43.76535531013243, 41.303918976937574, 43.245111742327296, 40.57227534632529, 44.06316911020587, 42.74811606253348, 44.68288790795111, 47.57402381589336, 50.43836993555869, 55.479266720433394, 60.1322607071169, 47.997522123398326, 53.17352494885845, 62.0302564097989, 60.58262725030223, 56.400301994815955, 60.625483066804954, 58.44078956111785, 53.898014176276426, 57.41149686997937, 54.594254493713386, 56.43526600253198, 53.46111312989266, 53.04469470054873, 43.848042795735026, 45.87560615231914, 43.96748288985222, 43.29899726375457, 44.04469474669426, 41.54308942056472, 43.71898504995531, 44.30597951335292, 41.29932195909562, 45.309561068011874, 41.632864629068685, 43.53321375385408, 39.539193645600356, 42.94243420324018, 41.88374334766019, 41.79643923236478, 39.42192654455862, 41.47591490899363, 40.639210593315866, 37.993516998906294, 39.26047786589592, 40.79033559368503, 40.052435782647905, 40.44102499561925, 42.884775361707135, 40.81172820060484, 39.83226922250564, 39.269440481739665, 43.93822200836674, 43.250426553910785, 50.06067706692604, 52.506329782547496, 51.70280871852752, 50.91106260976484, 52.739440164258404, 51.917236851107695, 48.54184904406148, 46.101271875443004, 42.99282097047375, 44.640969537919574, 52.648747121134114, 56.09188210579657, 55.93519518452307, 52.69788657465289, 52.152661431220274, 52.02660822099256, 51.784005703464636, 27.005934407634122, 3.351855302049268, 13.585332074472982, 13.714898747782554, 8.038303429080594, 4.510985555187348, 2.353862879737731, 1.4968833423429921, 56.974191819467855, 57.73312337936894, 37.00584850003643, 32.01483641901324, 36.20648907076928, 64.1573420647652, 16.45547055429028, 0.5477148678994949, 0.15212681354774585, 0.15307109352321396, 0.1445814450421641, 0.20657714095807847, 0.09682383027768905, 0.11066451864016634, 0.11231704690163175, 0.1307793751719498, 0.10706430376176873, 0.19775591430164155, 0.09220890896094423, 0.23333006508408055], [0.0855825854946048, 0.011837350245895646, 0.05551394473220553, 0.044079913922976104, 0.03698052350251425, 0.038205080575519995, 0.05312728207378138, 0.08094101197897427, 0.037898534323058786, 0.0324368100583313, 0.01545974528492098, 0.05500995463901951, 0.007805747905701039, 0.07934459965796241, 0.012260594671862501, 0.04629460516415777, 0.029709035260302406, 0.09723662909480835, 32.17934454641035, 46.434269335962114, 28.255311289141257, 20.319118922756566, 32.887334323698475, 52.09308062830279, 51.83700476923297, 57.42784923122775, 18.843768412067046, 0.0795615864016356, 2.9609320336772553, 4.099468862818134, 0.8203170208200332, 4.698511131348149, 43.37593063231438, 51.89199639904884, 51.11045629747453, 51.72571928270402, 55.36009726985809, 52.900426003240774, 52.19609383613833, 47.63221217739967, 50.839918659579375, 51.72120855700586, 53.318009376525886, 50.66864836600519, 48.68161878278179, 48.78633037690194, 48.701615025920255, 50.986505477659165, 50.945838343712595, 48.620672995044345, 47.88289869985273, 41.49953542217132, 41.96764284564603, 40.87312898328228, 38.27863016436177, 37.05528213131813, 37.071014758079286, 37.56040888447916, 39.312551252303585, 37.021471300432765, 38.02465277333414, 37.15298052757017, 38.79869722550915, 42.1025017769106, 41.969564807030466, 41.366869095833074, 40.812324400871034, 41.687291437579745, 41.739957101883434, 40.430422829043486, 40.90393920098582, 39.16115953076271, 39.86584078881049, 40.099661119522594, 40.19874411244547, 37.59046992947979, 40.974486950905096, 38.19924139207409, 41.00473234730382, 39.33660322620023, 41.61807337114888, 40.542924250325854, 39.592573181275405, 36.476485421580655, 42.54353307908581, 49.628745663550596, 55.03431304808586, 52.35336126819734, 53.3015864126144, 33.53187584107922, 55.667387516267844, 63.181377918489524, 51.315604102227, 48.20808279898859, 63.12439372462612, 56.923805052234286, 52.67396403897194, 55.5837429723432, 51.50802773814048, 53.82952959306779, 49.449363908460064, 38.821097881563254, 38.576318448589696, 40.10336775933543, 39.2382223375382, 40.31312434904037, 40.360400676727295, 40.8129519800986, 39.86478174886396, 40.919542389531294, 40.167749543343824, 41.139097059926684, 40.47314528496035, 38.58664997162358, 38.48144415886172, 38.562076322494015, 38.950053645718484, 38.11955451965332, 35.33160048146402, 35.45952073989376, 35.966957769086285, 36.007016935656154, 34.64308723326653, 36.558317830485684, 36.06564460262176, 36.86998151963757, 35.79137679069273, 36.78725873270343, 36.60448412741385, 37.77992040880265, 43.24344473500406, 48.72438830714072, 48.071207769455455, 51.5291065554465, 49.393113197818884, 50.32018107752646, 48.597103472678896, 51.84720293168099, 48.61633485363376, 50.609651996243386, 43.79285896978071, 47.96059693059614, 48.36919415381647, 52.20975545144851, 54.08316573789043, 49.81918065778671, 48.53296879799136, 32.663641552771296, 1.337622610792037, 1.2220807397557845, 1.6612251367299788, 2.0840415646952968, 0.9089472649558898, 0.35495323399382256, 0.2842632062252491, 2.4593221756719776, 55.27034167320498, 40.935514280872965, 28.049867345440774, 23.70643269631171, 32.35342914058317, 39.4338309380316, 2.5812784702547136, 0.10887913541087221, 0.11262518278653584, 0.031775494233795235, 0.008825058053668228, 0.07747852438760382, 0.08329459496082799, 0.03852952647233202, 0.06061430915348953, 0.04044357416850906, 0.07871888968492709, 0.01848655771614323, 0.06538608697273078, 0.04112831887698943, 0.05309593758635944, 0.01757831643185308, 0.03394319938736097, 0.016361353205396764, 0.0327072199434042, 0.08994066051297611, 0.017067839489168218, 0.04566217276958689, 0.10222628231971495, 0.010412090585657187, 0.05426578065981308, 0.08076342513724681, 0.013487322646523676, 0.11534125559152135, 0.06049499862016209, 0.02563750776912897, 0.15095178788948446, 2.045431836478172, 45.326854798101614, 50.26726830390192, 29.690837975471254, 30.924931341601958, 43.30210770330122, 56.280622636118245, 56.099271851201216, 63.020850996817316, 19.820893579913726, 0.1500049798238662, 3.26884814327763, 4.447836376005604, 0.6422670329770734, 6.506774771598078, 46.40248637045584, 50.114154661855395, 51.50283452003233, 52.52500418693789, 53.73026224874682, 50.53941411356772, 54.47884659613333, 49.22360797082224, 51.72261668789772, 53.297385554159845, 53.62033390229749, 51.61147240669497, 51.181682617433616, 50.39250958350397, 50.543222735005045, 52.657144915673044, 52.8687842430607, 50.96068059244464, 48.628192178664676, 45.54880995904246, 45.587123670885646, 43.41815494721936, 39.20997734992735, 40.210840702056885, 39.22774960917812, 40.502790558722715, 41.009968711483864, 38.92527211096979, 40.90313119273032, 40.1139699259112, 40.99120017020933, 42.14763649048344, 44.48544363821707, 41.65097421215427, 43.45013010886408, 43.0399953165362, 44.110637634031235, 43.25537266269807, 42.716533137905984, 39.928579099716686, 42.974107342381636, 41.95724071994905, 42.7197337919666, 39.22447443008423, 42.65335944391067, 41.347096427794426, 44.350051264609064, 41.42310411699357, 42.66574628891484, 42.57489635098366, 41.1598228639172, 40.3913717116079, 43.149252937686065, 51.09854798163138, 55.06805327630813, 55.37886581113262, 53.49790496210898, 38.512015111984745, 59.356098175048835, 66.08244526770808, 52.165993567435976, 51.55877928580008, 61.629080310944595, 53.41654323762464, 55.56507641269315, 56.49670600891114, 54.781006382357695, 54.371809036501, 51.60412972973239, 41.234995088269635, 39.720548352887555, 41.82682191171954, 39.76036041013656, 41.324954648171705, 41.29400322514196, 43.02059135129375, 40.57935130211615, 41.209283951790106, 41.92852112554735, 41.49706432896276, 42.89573446396859, 39.31240220223704, 40.33534065369637, 38.831366646674375, 39.42840630008329, 39.44061663842971, 39.159084596941554, 37.176914830361646, 36.44314527511597, 37.824541291882916, 36.823972117516306, 38.547755748994895, 37.813864600273874, 38.57668322901572, 37.914061546325684, 37.601150543459006, 38.014658574135076, 41.569612487669914, 44.16961831431235, 48.96892063079342, 50.516107390003825, 53.3073954428396, 49.41934208716116, 51.649633146101436, 51.60268629750898, 53.84528575404998, 49.90448044192407, 52.53450808986541, 45.953516191051854, 49.97875836587722, 50.05791571832473, 54.42694971638342, 56.141139230420514, 50.31366602067025, 48.75018181339387, 34.758997194228634, 3.548547947599042, 3.1193318049753866, 1.917768493294716, 1.6073553047833906, 0.5464890659336121, 0.25518946469791476, 0.3040970080802518, 2.304507941007614, 62.76348860033097, 48.365730700954316, 37.25379720810921, 26.090170798763154, 34.80155491059826, 48.44842995366743, 4.455030002901632, 0.1988136365769371, 0.011291391940997734, 0.05957084760490445, 0.051095976959913976, 0.032292643802300576, 0.04632386589242567, 0.0007853701179321375, 0.08010173967528729, 0.06262679148705737, 0.06931807154849653, 0.015694556021762472, 0.006310473076037822, 0.029045783148537722, 0.12495348335153635, 0.06809471340309228, 0.20647761081495594, 0.12481746444058035, 0.08963492248327502, 0.14607038288827867, 0.22623075893329037, 0.10777593815639135, 0.1918596879488999, 0.15917751908061967, 0.2002552761546066, 0.21047429151592717, 0.12780411950042173, 0.3007095204966684, 0.2070201083176559, 0.18954576533888617, 0.328165682693643, 2.9725768152744543, 48.68616088744133, 60.34595535647485, 39.14850596458682, 28.214338210321245, 44.131563478900546, 61.594834096970104, 61.58956635382868, 68.18685962307838, 24.31514532335343, 0.32081675445360525, 9.860015896058853, 9.023218424089494, 1.3283420378162016, 7.970172349483737, 49.56050426729264, 51.05487631213281, 53.192254266431256, 51.24917876335883, 56.95713343158845, 52.08500839048817, 53.39524868995913, 51.98175199570195, 56.39848985979634, 53.9434273781315, 55.92710333485758, 52.004913591569476, 52.76518660206949, 51.96552515029908, 53.68526089575983, 54.77385197916339, 55.7794653215716, 53.19452531876103, 51.21127690038374, 47.221304678147845, 47.170105980288604, 45.51494421497468, 40.771802394620835, 41.44150003310173, 40.733151358942834, 42.33076018671836, 43.73874987325361, 42.313489990849654, 43.81578914580807, 42.554170546993134, 42.326429890048125, 43.363528097829516, 45.42423940473988, 44.35966499390141, 45.1838844053207, 45.1779616263605, 47.234252422086655, 44.72160170155187, 44.7514077924913, 43.03588859496578, 44.16906526011806, 45.241351050715295, 44.47333528149513, 40.108647269587365, 45.409326553344734, 43.34551657399824, 44.55162971250473, 44.087601554009225, 45.191536949526885, 46.394061119325706, 41.728668520527506, 43.12823687830279, 45.965353904231904, 54.26306916821388, 56.870017590061316, 57.41659202883321, 55.14750872888873, 44.2523411012465, 55.516846949054354, 61.77251746577602, 56.22504265077653, 56.122151036416334, 63.371907049609774, 54.39400572930613, 57.24199948772308, 56.64708575894756, 57.206533416625, 56.421694601735766, 53.99037030435378, 42.758894735767, 43.59375945983395, 44.17200311537712, 42.19421071390952, 44.82762336730958, 43.0540648583443, 43.649774828264796, 43.46997337956583, 42.90030794758951, 43.18606438175325, 43.95056570729902, 44.98955449750347, 41.718384065935695, 42.12304322950302, 42.098477425113806, 43.94193257054975, 42.343511812148556, 40.947979573280584, 39.218841906516786, 39.07210996074062, 39.24860877375449, 38.821596022575136, 40.541320000925374, 41.274928738993985, 40.52631301264609, 41.28796277507659, 40.71581840515137, 39.71549634010562, 44.018018707152336, 45.321826319540705, 51.28196585562922, 51.33073660635179, 56.172278927218535, 50.69188448690599, 53.54336523240613, 52.06206644735029, 54.75702108875398, 53.117678242345015, 56.14526164147162, 48.079605563994384, 53.81263202236545, 52.62182004990117, 57.997718626453036, 55.1140901350206, 51.316235603824744, 49.181599386276744, 39.6324715306682, 5.965996125052053, 5.1013797329318145, 8.367641318228937, 7.960847404695327, 5.604309468500076, 0.7964143421380752, 0.8223671333924417, 3.382211505405365, 68.10377597808838, 50.50568957482615, 41.307445187722486, 31.491949173711966, 43.79927596738262, 57.101409973636756, 6.978437333337723, 0.44509892261797385, 0.20239715073858539, 0.09426498169740362, 0.15837698784326354, 0.13433759311033835, 0.20465626741849607, 0.2473287590809407, 0.25582225332337044, 0.14921278362312626, 0.1645083878670008, 0.12493682093918325, 0.1260123700804768, 0.09559316365348716], [0.04672076455467651, 0.0720015090079077, 0.02650660962136763, 0.02114852939191605, 0.0026996043086382412, 0.007019707700237633, 0.0704444123191699, 0.08219933437724268, 0.07815743150610117, 0.06835233345026932, 0.08235754685536509, 0.02128816232265484, 0.08462703636577053, 0.009824953139609387, 0.04817443554319682, 0.048567247126371636, 0.05418525715809196, 0.16404475145522626, 10.100868055897376, 51.16825634433378, 32.7309827650747, 34.57066459040488, 31.226998952127275, 41.4539300241778, 53.3818067273786, 54.608398560554754, 30.46682792325174, 0.01111020640124597, 2.2130294432563167, 2.202045335885017, 0.25031736000410976, 2.1194343365007833, 32.33525483838974, 53.89398197973929, 53.86477208906605, 53.880477259236, 51.24961806881813, 53.95235077027352, 53.65971449882754, 53.12871186963974, 54.1931882212239, 52.77504744068269, 53.38415230474165, 52.58331806428971, 49.3638248597422, 48.655378126329, 48.15884136384534, 49.12096346578291, 53.64833962532782, 49.147157053793634, 46.26396002308015, 45.011935541706706, 41.6905705390438, 39.19737085219353, 38.2213714045863, 38.69659008518342, 38.28254076742357, 36.38453329763105, 37.50808446638046, 37.51911809367519, 37.81495501918178, 39.23056587096184, 37.99457603885282, 37.95954142847369, 42.07018929143106, 39.926959160835516, 39.974329625406575, 40.176896510585664, 40.862797460248395, 38.724874296496, 39.27455133007419, 39.848499990278675, 40.66663972793087, 41.72051783530943, 40.23594779352988, 38.96304061335903, 39.28207051369452, 40.437400725580034, 43.410200380509906, 44.88283857222527, 46.23563658806586, 42.71708226973011, 40.438844157803445, 39.7204855949648, 39.70119537845735, 43.631182793648016, 55.106621942212506, 53.38970638090565, 58.784636297533595, 40.33473660868984, 39.00062084197998, 56.792535089677386, 50.26036885476882, 50.39855395593951, 44.466235791483236, 66.07757368395406, 51.08282319961056, 54.90501996009581, 51.21024139465825, 52.99155050708402, 50.616998595576135, 41.14666331198908, 36.854405787683305, 40.12749818063552, 38.288318418687396, 41.20179222476098, 39.38054161687052, 39.71065613531297, 39.76751873570104, 40.720952787706935, 41.06891409043343, 39.25870103220786, 38.66935314670686, 39.678830023734804, 37.52154211844168, 39.183619022369385, 38.237939496194166, 37.57995405504781, 37.11562779641921, 37.11265071745842, 37.440466726979906, 36.39100520841537, 35.27414168080976, 37.498302075170706, 38.40236133144748, 36.107586506874334, 37.32166990157097, 35.58296557395689, 37.68952154344128, 36.16310765666347, 39.391081025523526, 42.57938354246078, 46.86139583587647, 49.23835216029998, 49.6121540377217, 49.114354272042554, 48.93889096475417, 48.59315364591537, 49.823126562180065, 52.60553436894571, 51.21763506243306, 50.69463799076696, 50.516695745529674, 53.777036513051684, 50.308104099765906, 50.38093859149564, 53.51564584239837, 13.25686397091035, 0.15931595116853714, 9.107529770943428, 3.2172868713255856, 1.9444424490774832, 0.6406720379187215, 0.10949949809019605, 0.27019246931998964, 3.340673605280538, 55.51749806250296, 30.532021637885805, 25.20968890959217, 17.30126888521256, 41.539390625492224, 27.24707191990268, 0.1251347014500249, 0.06758557136861548, 0.06162325844108578, 0.042885421970558744, 0.02110092468830126, 0.05672425256981965, 0.016736519868455587, 0.039368925180526516, 0.05649772803148916, 0.0835557696559737, 0.042387093267133163, 0.0531703285542467, 0.020526967784990708, 0.01766457027124782, 0.045785915121556296, 0.06719918726312538, 0.06546859464217579, 0.07990520747919237, 0.0071041923553322355, 0.0316345474622663, 0.025180170515311823, 0.09149624800850308, 0.042262772518780925, 0.03023808600471145, 0.09978640719407028, 0.08213545796611617, 0.06599888070336273, 0.06606025966785609, 0.08841546372540536, 0.062302778429922566, 0.08309787890363125, 0.039489679789591225, 16.626946772298506, 58.266369604295306, 30.69915383092819, 25.247510363978726, 42.89356931563347, 48.0371262950282, 59.56379159804314, 58.86742576476067, 32.20419668382214, 0.02436956522175141, 0.30425460768803475, 3.393019351267046, 0.38058353287558405, 3.1600442913270768, 36.310235761827045, 54.47606563568116, 53.71993857045328, 53.459799135884936, 52.53199385058496, 54.22691668233564, 55.050586961930804, 54.46185881091703, 55.3843806635949, 54.79183604640346, 54.25156093412831, 52.150966967305834, 50.54099875111734, 49.75222972131545, 48.58235536083099, 51.4793199108493, 55.11130132982808, 50.9270501905872, 49.29049614937075, 46.23139258353941, 44.54038035485053, 41.178763989479314, 39.95563953153549, 40.756505150948804, 39.77623031985375, 40.20519641137893, 41.317251113153276, 39.36098075682117, 38.1664268432125, 39.886652884944795, 42.23261464026667, 39.65406810083697, 43.405924997022076, 42.73614891113774, 42.5848081804091, 42.32385289284491, 43.33332192513251, 42.93103187314926, 42.67142980329452, 41.17402968868133, 42.759796880906634, 42.96071244824318, 41.949576408632346, 40.077519339899865, 41.495805248137444, 42.07523738184283, 46.28729420323526, 46.96902959577499, 46.53978109359742, 44.92716135517244, 43.91327181170064, 42.964803480332904, 42.4365504326359, 44.95577112320931, 57.5321646659605, 54.34258345634707, 59.37501184401974, 40.055452085310414, 45.93555173566265, 60.10492570938603, 51.44337923296037, 49.71965835940454, 50.52130060811197, 62.418543600266986, 53.192379782276774, 57.176095824087824, 52.235949039459236, 55.55320732055172, 53.89436637201617, 43.93136178293536, 39.658202278998594, 41.22585988813832, 40.095205307006836, 41.881782162574034, 41.078590577648534, 40.52130022356587, 42.66192197799683, 43.33968400955201, 42.08260751539662, 40.50546169281006, 42.10041507597893, 42.054711618731105, 39.163932646474535, 40.29625815729941, 40.26944091243129, 38.0451314680038, 39.085045937568914, 39.50255478582075, 37.97726269691221, 37.91939596976004, 38.30085039138794, 40.23598309486143, 39.84498162423411, 38.83305326584847, 39.648808202435895, 38.1633517049974, 38.20956899273781, 38.476874597610966, 42.63856034125052, 44.477896998005534, 50.22317694079492, 52.61272015110139, 52.64470315748646, 49.317933128726104, 51.59904633798907, 50.66383954017393, 51.505799831882605, 55.58034227740381, 54.24045670417048, 52.680302589170395, 52.26752804171655, 54.41453933715821, 51.500739974360314, 50.798682781957815, 53.71492578137306, 17.28751901657351, 0.39114739505514023, 15.312585042368982, 2.954162758204245, 1.5350663902298098, 0.6279936504940833, 0.0879283237361139, 0.34344457089900976, 4.223296863417472, 61.38706614894252, 34.005882509293095, 38.99663963625508, 17.89985199128428, 46.87494762482182, 35.157239360194055, 0.23671301742715223, 0.008608137385078497, 0.07844929568349354, 0.04520863339665436, 0.027918532648454272, 0.02460874936303064, 0.041636484149362774, 0.025165729757939136, 0.09687587063038543, 0.03689195990802781, 0.02127218555899397, 0.03298828611150384, 0.061941912713190245, 0.015685458727661642, 0.19416008144617083, 0.15866629328698884, 0.19765935657966524, 0.14735042387920042, 0.11789307148466188, 0.13635744520973775, 0.1959564810198161, 0.27802476839673135, 0.17127674403450183, 0.24747598585822891, 0.2570593321034985, 0.2063045362311025, 0.31890306681875263, 0.11502291541546585, 0.2526309302136783, 0.0892908800573599, 0.16490987922635772, 0.15821797863369988, 18.345505806707568, 66.9969694076046, 43.2334779923962, 46.15805995079779, 42.918272402978715, 52.00212478637696, 62.04161167144776, 64.28466612292875, 39.524614195669855, 0.0786206006042419, 6.954578536172067, 9.979784488677979, 0.6185251714721803, 4.315381857656664, 38.454944625977554, 55.16553986457087, 55.284470050565666, 55.64225689057381, 52.66826091274139, 56.70500739928215, 55.25790775975874, 55.76147340959119, 57.449755668640144, 55.90746402740479, 55.77484869187879, 52.82258264480099, 49.07519725061233, 50.06450922258439, 51.350803452153365, 53.22480601649131, 58.27363775622461, 54.64718295681862, 50.95984120522776, 50.8903250386638, 47.73740622305101, 44.50602039214104, 41.625145404569565, 44.68104047159995, 43.64372261108891, 42.70962192166237, 42.11641050154164, 41.59040889432354, 41.160132731160815, 43.1562190671121, 42.15650889181322, 41.554813385009766, 45.61037155889696, 42.85162348901072, 42.05460571473645, 44.19381541590537, 44.076301205542784, 42.62413778612691, 43.73131698177707, 44.13104180366763, 44.825101283288774, 45.55110454559327, 43.323967072271536, 43.26154255097912, 43.28151133752639, 45.02975486939953, 48.28558098885321, 47.816532196537146, 48.963131212419086, 48.18927895638251, 45.87353906323833, 45.66823044130879, 44.36012783358174, 49.14631374420659, 57.40153404974169, 57.17652728480678, 58.895957085394095, 44.13653704427904, 47.12774046005742, 51.88462626549506, 54.079972928570164, 52.86664655131679, 55.15505536910027, 61.167401652182306, 54.476430416107185, 58.71743040700113, 54.45078203755041, 57.74266258362801, 56.13700112988872, 46.075776469322946, 41.86679478614561, 43.59003713054042, 40.8372236067249, 45.085425069255216, 44.05193151966218, 43.05151531773229, 45.335425176928126, 44.98242755090037, 43.137862374705655, 43.132088645812004, 43.56629894625756, 43.048597074324086, 40.72715405494937, 44.164013247336115, 42.453346021713756, 40.9227430435919, 41.371289607017275, 42.259431885134795, 40.30820569684429, 40.70623997719058, 39.39456801260672, 44.64203250023627, 43.06599278603831, 41.00515988565261, 42.2635817527771, 39.86573096244566, 40.612487485331876, 40.39908701373685, 44.94886382933586, 47.41309681246358, 52.205503602181714, 54.5684649098304, 54.48061558508105, 52.95842609097881, 51.48185376198062, 51.15798365685248, 52.354224189635254, 58.809351151989354, 55.35301739169706, 58.345444586969194, 54.05271637824274, 56.96469576128068, 51.194681352184666, 51.44878425905782, 53.47549253894437, 22.669758104508926, 0.5273629148160258, 16.80900162266147, 8.496286234548016, 6.250327267954427, 2.370255445280383, 0.2977605109974262, 0.6174611672759056, 5.014153084447307, 65.76993434659897, 38.11671864601874, 36.05849412179763, 25.721748452032767, 54.96324362293367, 42.388434717732096, 0.8270659489977745, 0.15387940821388077, 0.14604827359078393, 0.22705583562774045, 0.20831847413172647, 0.1371468834939503, 0.22996185227267205, 0.09562588326873318, 0.39639975515104114, 0.2628720395507351, 0.07919188769113633, 0.13771645454389436, 0.0931034621692473, 0.06842571701253615], [0.06169463102255137, 0.03173631649734753, 0.05510958437357218, 0.03022114780070561, 0.07891692341335359, 0.05503367272115523, 0.07563221418569166, 0.13010013097476575, 0.041515323513698195, 0.0243354685634615, 0.017542716326011766, 0.05171729724914317, 0.0354722227841135, 0.07622512027380929, 0.09774032424414351, 0.0317440424940639, 0.04776272840136963, 0.11535518306998477, 1.818314713816489, 39.65851214624221, 47.23507611982284, 28.32241912041941, 28.82215261459351, 45.27734271941647, 45.63100714837351, 50.375498264066636, 38.25057737288937, 0.40674659994340717, 1.1309550101718595, 2.1883283170961567, 0.4241345282043181, 1.1923175497401146, 20.766600562680154, 52.596010854167325, 54.18128775012109, 53.168810259911325, 53.62888859164331, 56.33524948550809, 54.023486875718646, 51.589075673011045, 50.66981330994637, 54.520039327682994, 50.992102699895064, 47.97157956707863, 48.23076978806527, 49.63579808512042, 50.88857958393713, 54.75843314201602, 51.938986393713186, 48.57997840450656, 46.51974562675723, 43.34655207972373, 39.35028445336127, 36.3825564230642, 36.760237524586344, 39.2178338573825, 37.794660675910215, 38.05848713844053, 37.856634124632805, 38.93583505384384, 37.2050735258287, 37.86871502476354, 40.275124426810976, 39.84486395312894, 40.244608386870354, 41.85570624566848, 38.12119014801518, 40.91268608647008, 40.285197073413485, 41.609557905504786, 38.17275754867062, 42.362645133849114, 38.17711530193206, 38.243717147457986, 38.038887054689475, 38.96240126702094, 39.217704419166814, 45.67909148431594, 45.712996452085434, 48.29684995835828, 47.366804999689904, 48.34327905408798, 47.80116435020201, 41.91269828427223, 39.98104472314158, 43.476457057460664, 50.63607700409428, 54.568884603438846, 53.099133276170306, 53.7374480309025, 33.99870849424793, 47.737735702145486, 50.99583287392893, 54.875107965161725, 42.58244691356536, 52.679945653484715, 59.48251224333241, 49.804993444873446, 53.24002089038972, 48.851371119099284, 51.359970031246064, 41.271806532336825, 35.80414410560362, 39.23483340970932, 40.49404759560862, 40.8496065293589, 41.04560736686953, 38.69444454869917, 39.640924238389545, 40.06148861300561, 39.06861512891708, 38.90806859539401, 39.253146956043864, 38.88282814333516, 37.97015536215998, 39.53669117343041, 38.68208123791603, 37.15149787164504, 36.26807812721499, 37.24100635897729, 37.994642719145745, 36.12046757052022, 37.7572294973558, 40.344742574999415, 40.79083765706709, 38.708867103822776, 37.11320769402289, 37.46532670913204, 36.420540655812914, 35.285414572685, 34.617509457372854, 36.73070992192915, 40.23885819219774, 44.03968587998421, 46.202516094330825, 50.38935599788543, 48.55120781929263, 50.21759540803971, 50.790269297938195, 50.84985402322585, 47.841513772164625, 50.59233080956244, 51.08436861345845, 54.03336340381254, 47.48209522616479, 53.38284615547427, 34.9628427720839, 3.057788100934798, 0.3181492056577437, 2.2496582519623542, 1.8517970461999218, 0.39617440272723475, 0.17668504898826923, 0.058302627350654335, 0.26425231548566974, 8.717236288132208, 58.55087872474425, 28.281222466499578, 24.820585866128248, 22.461225294297744, 47.74713762344853, 14.101929799202951, 0.05392710084936792, 0.04653678470922094, 0.026853287389742273, 0.006255114126214457, 0.030963117361909924, 0.035445298624014666, 0.0363995339120588, 0.12919535049267356, 0.020182772141490734, 0.08475557825858555, 0.05922310114387543, 0.024419837826562506, 0.04762651030755332, 0.036886513022886175, 0.022140977145623297, 0.05538730656788234, 0.013279678345087075, 0.006179717667926584, 0.03266300134841473, 0.023304247184686606, 0.0042798378102992096, 0.0678877011241932, 0.02401081390769011, 0.12317165477021087, 0.028884665281962485, 0.13795869154555185, 0.017336428000201142, 0.03191879864091114, 0.042906508540674564, 0.07938838924371427, 0.030727918793056763, 0.1391414240483315, 3.3504819821926857, 49.17645323661066, 48.10470481072703, 30.962135022686375, 35.03295121654388, 50.398620636232444, 52.23250127607777, 57.05444743556362, 43.59737588513283, 0.17190617719484916, 0.1294654118077409, 1.6083079504389919, 0.9988309515099373, 1.3357549497196752, 23.922200318305727, 54.17881273454236, 53.8041950041248, 55.10468036897721, 53.48620845425514, 56.83262171283845, 54.3505419454267, 54.22877588579732, 52.65829024776336, 55.5479827234822, 52.55485342394922, 50.11674734853929, 49.140540015312936, 51.427838802337654, 52.19258723720428, 56.36174901839226, 53.5473072144293, 49.88521375963765, 49.099108019182765, 44.74429261299872, 43.04267037299372, 39.614734572748986, 40.02035471700853, 40.809025687556115, 39.62192035490467, 39.906637360972745, 39.465782565455285, 39.93928324791693, 40.01099201940721, 39.77314733689831, 42.36856791280931, 42.13755599914059, 42.25528593986265, 43.07093105008526, 40.05595807106265, 42.91680543653427, 41.00479902759675, 42.62882109611265, 41.244816703181115, 43.34062537839336, 42.402202237036924, 41.51050236917312, 40.0204723881137, 41.42401018450337, 40.41558058031144, 47.8301820447368, 48.93332119910948, 49.862079620361335, 48.98241750655636, 50.46002926365022, 48.801325598070704, 45.144558721973056, 42.674971703560125, 44.33024721760904, 53.257985345778934, 56.09924439461001, 55.20615208533503, 52.607899558159616, 38.82538503216159, 56.45199098894673, 53.28899168199109, 54.14362515172651, 42.93981405996507, 56.266466802166356, 57.7077534890944, 52.749151952805065, 55.24470113938855, 52.1239810605203, 53.95496699117846, 43.35727583977484, 37.94507180490802, 40.716673481848936, 40.98612854557653, 40.76697395693871, 41.06642338537401, 40.518264309052505, 39.68047741920718, 41.55175001390519, 39.082492474586736, 40.83201077676589, 39.96185256588844, 40.99087069111486, 40.15105593589045, 41.07963392811437, 38.45011618829543, 38.54189180558728, 37.83937961824479, 39.84153386085264, 39.5172401397459, 38.40411070854434, 38.983927234526604, 42.72753146386916, 42.727402025653475, 40.238116864235174, 40.08325384509179, 39.65500162493798, 38.21969263015255, 36.44478874821817, 38.389801902155725, 39.08312789855465, 42.37585959895965, 47.1425630969386, 48.64998094497189, 50.808167073034475, 51.6472012765946, 52.385195224515854, 51.34248410501788, 49.9286187079645, 49.53671116982737, 53.061627572582616, 51.52056755558137, 53.69929121386621, 49.72237656193395, 53.72844619135703, 37.73794320321853, 4.88896720832394, 1.0195390435476457, 5.914079143155006, 2.4172966759051047, 0.11421781829408101, 0.1824489106694537, 0.10045637406649129, 0.4192280721279883, 9.1542608891764, 63.872413250707815, 34.49824586991341, 30.49132900853311, 20.376244321946178, 54.2074695710213, 19.083154586053666, 0.032396460207359444, 0.07160011723998093, 0.00411581120363647, 0.04513684329727004, 0.03636308344862154, 0.043839255062442635, 0.06115377677844898, 0.08591154364929085, 0.019772570362434756, 0.056890861371592175, 0.07561417281507485, 0.039882276868147236, 0.03834426726004289, 0.1312615815550089, 0.13772408477962017, 0.1793579450778423, 0.2085575854946529, 0.11080299669335927, 0.20096078184583496, 0.11829809450934972, 0.08718806063576091, 0.22546483954835325, 0.14910930046631446, 0.2287890329476326, 0.15499501609273497, 0.16915153952375536, 0.11414068856186445, 0.1852533440556257, 0.2680383832944978, 0.27693781220624525, 0.1557328047290925, 0.46579340893414717, 3.9593880311135328, 54.550488687330684, 59.924104444442264, 37.74462299962198, 40.88627284572971, 55.890150685464185, 57.135409078290394, 60.9841210611405, 52.49673174273584, 0.9010219934486574, 3.5725810450892297, 7.387747937633146, 2.073129285727778, 2.3046410564453375, 24.754629250495668, 57.09893888042819, 54.73541667384487, 54.373778066327496, 54.274793132658935, 58.868194549314445, 55.593062523872625, 54.76164164081697, 53.16532327282814, 57.53846399245724, 55.24930992434102, 52.667339155750895, 49.147298259119836, 51.43506380819505, 51.66498138058571, 58.573248001836966, 57.61658191680909, 51.71772941466301, 52.560721289727, 45.38224650967506, 44.624856441251694, 41.0567625876396, 41.21847014273367, 42.750759740029615, 41.75854129175986, 41.86959535844865, 41.42981136998823, 43.40579555880639, 42.053425081314586, 42.010459438447036, 43.889584618230025, 43.05966208058019, 44.73474164162913, 45.94083516828476, 41.651848900702696, 45.0745601038779, 42.32290760163338, 43.85964516670474, 42.0010418276633, 47.24917704059232, 44.58882162647863, 41.83775355738979, 41.76212633809736, 42.16946055812221, 43.04332148644232, 49.09963753915603, 50.49202795951597, 50.236332570352864, 52.76979146465179, 50.70789560194939, 49.904123506238385, 45.54532689432944, 44.92394501163114, 46.25954343426613, 54.58715108133132, 57.916372591449374, 56.57412967374248, 54.65799693138369, 41.988729507692405, 47.42237714029128, 55.214459665359996, 56.65347137758809, 48.779007311790224, 59.68647941466301, 57.841976996391054, 56.726145052140765, 55.83360971943025, 54.799943585549634, 54.367894511069025, 46.61720868079893, 40.03062348211966, 45.327870691976244, 42.666522918208955, 43.42756471326275, 41.8594991776251, 42.34397857419906, 40.63239351395638, 45.28315174964167, 40.80899823096491, 42.90304183959962, 42.92664666329661, 41.910999897987615, 41.157030136354514, 43.06553779109832, 41.774203315857925, 40.15742978742046, 38.82408280526438, 41.817635720775975, 41.04935323038409, 39.114463713861284, 41.0527107792516, 46.05524678384104, 44.52549103767642, 43.36984703617711, 41.134515731565415, 42.66125517506754, 39.72960902798561, 38.10760698010845, 40.10760391912153, 40.350355486716, 44.488110849934245, 48.26244292720672, 50.94372810855989, 53.52447509765626, 54.11923585399505, 54.918552137190304, 53.08935480733072, 52.09022122044718, 50.956907272338874, 53.702778200949396, 52.91584484038815, 53.877331518357806, 51.00416398817494, 53.05658340454102, 41.523520715775035, 9.016409189470354, 1.217110116154917, 4.262300912410983, 5.460955664034813, 1.4451722848799922, 0.6140928931774632, 0.19313609768306056, 0.5099043532484963, 12.47700362436233, 69.0921583483296, 36.889173676890714, 35.21853816124701, 30.63846495843703, 63.27274168691328, 25.273994207382206, 0.2992987236188304, 0.16131732522720293, 0.1293746763539891, 0.15898248841685636, 0.1641914419709675, 0.3186189094858785, 0.1117726035356041, 0.19213760932607038, 0.1333031599079409, 0.1909777981739852, 0.18888881430029872, 0.06921618951544647, 0.1884805047584157, 0.38131137769068446], [0.006665905792972134, 0.008102743435771236, 0.07811013323765609, 0.07341515573282396, 0.030466993076486454, 0.0336157925607216, 0.045363873453630556, 0.0329485644526299, 0.04725255597863467, 0.04458987950197151, 0.04109707398099765, 0.038908552303309404, 0.020921365170168783, 0.06992643729092614, 0.06375160391232179, 0.0684105484716354, 0.0583979057057971, 0.07964331266139785, 0.07777083289599226, 18.18406105041504, 47.92328734551707, 29.10891905907662, 33.74583328923872, 30.428161198093047, 39.64831790616436, 50.728707698083696, 45.68162533544725, 2.197030830767847, 0.1742528577245051, 0.33333159742816804, 0.9693840025894105, 0.3274907592323519, 10.824937589706915, 45.745885525980306, 53.03379051146969, 54.34760016779746, 53.00273318444529, 54.734942067054014, 52.608150589850645, 54.232133434664824, 49.91088567241546, 50.95753485156644, 52.12130600406278, 53.11918051012101, 52.751203352405184, 50.099230043349735, 50.71129629688878, 51.39964872790922, 51.898962528474875, 47.89883528986285, 43.10116075700329, 40.58960830011676, 39.26632219745267, 37.443094714995354, 36.900866262374386, 38.392402433579974, 38.394846070197325, 37.94289096709221, 38.45801976419265, 38.07795778397591, 38.01484684790335, 37.94036888307141, 38.11388669475433, 40.15440564001761, 38.52884992476433, 39.78469871705578, 39.358956813812256, 40.31416377713604, 41.46084516279159, 39.47283498702511, 40.03926838597944, 41.57988125278104, 37.44689156932216, 38.659821787188136, 39.95503156415878, 41.154359002267164, 41.23746225910802, 48.72399214775332, 48.124606916981364, 51.43751136718258, 47.75408806339387, 50.48734072716006, 54.18026401150612, 45.72459490068498, 44.74858368596723, 42.56082288680538, 46.830605230023785, 54.06678199768067, 51.898950761364354, 57.53700879312331, 39.81617966005879, 35.696592715478715, 53.40212068250103, 52.50873419546312, 52.14193374879899, 41.09653149881671, 60.211139571282175, 51.034942826917096, 53.60305193931826, 50.32645686980217, 50.77462296332083, 42.857001058516964, 37.916999401584754, 38.75648075534452, 38.8125196579964, 40.22003866011097, 38.74918514682401, 38.58486529319517, 38.35441820083126, 40.89777715744511, 39.357509459218676, 38.55065438055223, 38.97555689657889, 37.716554518668886, 39.724647229717625, 39.04566534103886, 37.949143225146884, 38.017925908488614, 37.02469548871441, 37.82346264008553, 37.49453267743511, 40.17728090286255, 41.903818038202104, 41.9480388395248, 41.891905799988784, 40.30528353106591, 39.958730359231275, 37.84321177390314, 36.54835108787783, 34.34250423985143, 34.82801129741054, 35.80084146991853, 35.46634566399359, 37.09621990880659, 40.7549479699904, 46.16187641697545, 46.57181509079472, 49.05968819895099, 51.57353524238833, 52.27393719457811, 49.049419433839866, 48.22720043120846, 47.797120386554354, 51.0039992486277, 50.75267337983655, 49.30294182992751, 18.68463393180601, 0.5488567679159103, 0.8384229266835798, 5.499920979622872, 1.9344936022835395, 0.017785688772076563, 0.19765253839713914, 0.11325191165651045, 0.8575312432742889, 17.408131899372226, 54.24957621482111, 26.90486865658914, 32.61356661396642, 33.386014661481305, 52.5706958770752, 4.918044719003863, 0.17938904824756807, 0.07164670304665643, 0.05415442978001891, 0.018708767264240214, 0.002496748774935822, 0.04529132875764082, 0.060889748405785336, 0.06054294806334281, 0.039848067211888494, 0.11496768047612523, 0.03522840381089238, 0.005642711579228842, 0.014050350347984464, 0.020948668543790138, 0.05317502467322254, 0.07346583244901511, 0.09625587567326524, 0.03972857281745922, 0.027341886776529496, 0.12178190998853215, 0.05692647679919197, 0.00678042971318768, 0.05958941374574939, 0.045765521861011946, 0.05793230044805716, 0.0261122198970688, 0.03580171336990691, 0.04350742407804055, 0.05526024705520081, 0.049234126664457784, 0.020924082867080168, 0.04198170635068128, 0.2859733289768619, 25.238277104593095, 55.52871211882561, 27.370422617081676, 37.13461991279356, 42.67094735176333, 46.311750181259654, 54.1797423362732, 52.06126236146497, 1.935155502250118, 0.5996848017938676, 1.0511022950372388, 0.46222717771607064, 0.5186562949130612, 12.156926451190827, 50.57066755910074, 53.24466497667375, 54.41381369867633, 53.64613525329098, 56.11603998368787, 53.7653596170487, 53.609696434390166, 50.93547151934717, 54.91450817354264, 52.565114344319994, 53.43870462909822, 54.12276598715014, 52.82153929433515, 53.071398196681855, 53.52063509725756, 52.611268874137636, 49.17307999826247, 44.86166954040528, 42.91015309672202, 41.28717045630179, 39.74465523996661, 38.01166188332343, 39.886382241402906, 38.549077587742964, 39.36047869343912, 40.9098502128355, 41.83701615179739, 40.24399257475331, 39.267942136333836, 40.51014500279581, 42.62602052380962, 39.68760828818045, 42.58936597454933, 40.85370932855914, 42.710751564271995, 42.1508724458756, 40.99503232586769, 41.8598404238301, 43.62388326275734, 39.55143928527832, 40.65039327067714, 41.80277778256325, 41.638963914686634, 41.96729767707087, 49.66533353251796, 50.1720880693005, 54.10543695572884, 49.01418086021177, 53.083200608530355, 55.34374883097988, 49.26461635097381, 45.063761818793516, 43.24923023100823, 49.041186378848174, 57.21382902514551, 53.88018308147308, 56.41633664408038, 41.84951674553656, 43.55647733134609, 56.23826888299758, 52.93737473026399, 52.71129715827204, 42.36345706447479, 61.04972270227248, 52.81459277675998, 56.253738710957194, 51.86898777561804, 51.52504690231816, 45.132689629831624, 39.26765972568143, 39.786832486429525, 39.99902879038165, 42.36609289723058, 39.54006441177861, 41.08850632944415, 39.71096992492676, 42.11475133895874, 40.93258819272442, 40.51385948734899, 40.998076085121404, 40.902354563436205, 40.872850495000044, 40.94714803080405, 39.6654704309279, 38.506076643543864, 38.96986161508868, 39.12350477710847, 38.157020999539284, 42.38954082612069, 43.43059670540595, 43.669017976330174, 43.37007845601728, 43.502858531090524, 41.811195188953036, 41.1620468478049, 37.6758324715399, 37.120028695752545, 37.33071096481816, 38.69029860342703, 36.91783051336966, 40.48180195593065, 44.9355120812693, 48.381098547289454, 48.135126713783514, 51.916899527272875, 52.02798105055287, 53.5547322611655, 48.58762310397241, 48.80351035825668, 47.51288975438764, 50.60161898213048, 49.57516216462659, 50.55595082621421, 21.196670801408832, 0.33579916663227544, 3.2075103636710875, 10.17265429419856, 3.629510325770225, 0.15533155851787137, 0.2990597348299719, 0.15469497009631128, 0.8747119600734404, 19.5060900334389, 59.888967852438654, 37.02664882906022, 32.62057196709418, 32.57434291224326, 60.598218671737186, 6.678285800641583, 0.11090846401789498, 0.04666759805273145, 0.06298608672354492, 0.036835522210646066, 0.0381251163179836, 0.05187043822520683, 0.05488221330808536, 0.04813291357770082, 0.07920716348434649, 0.05737550391425049, 0.07934255420320457, 0.047802787138930256, 0.03473402812115608, 0.01077857364209429, 0.11832650104958205, 0.18326675549389856, 0.20137016391081197, 0.17747149952957708, 0.08831276963915556, 0.2162250837371234, 0.17893485003902068, 0.12412776314322987, 0.1768320306174217, 0.16108965921786525, 0.1169820320642283, 0.09232538496895183, 0.11685640130552555, 0.15624691101331867, 0.15678778440961916, 0.13346141835133876, 0.19783056190898343, 0.1459090447714252, 0.7014009921300797, 29.93163424153482, 61.934762385583696, 38.76970698756557, 45.84541566910283, 39.600563049316406, 50.926195113889634, 60.17790140644197, 60.97585270481726, 2.943776321987952, 1.5570049420479806, 6.873827230545783, 3.6313567815288423, 1.4489283220421885, 13.798849236580635, 52.8326827479947, 51.47728027835969, 55.28976132792812, 53.85557805338214, 56.7822467127154, 54.77198885333154, 54.15674940232308, 51.828383399594216, 55.503440287805375, 56.73959485946163, 56.81515147609096, 56.20512485504151, 54.65878532778833, 54.2422531497094, 55.70049232052219, 55.23685247667375, 52.936919735324004, 47.21746860011932, 45.52136513494676, 43.01697884836505, 41.927293423683416, 39.497910699536725, 42.399562481910955, 40.31247715796194, 41.91521252355268, 42.458076400141564, 43.737067176449685, 43.31832670396374, 41.61612787554341, 42.73448974855485, 45.75642885700349, 41.36208772659302, 44.566609244192804, 42.03986936999906, 43.97242115389916, 44.160341908854825, 41.82257790719309, 44.378076599490264, 45.6506896018982, 40.859357541607274, 42.24724508100941, 44.98700495689146, 45.410558177578835, 43.89226751942789, 51.91259668719385, 52.74149940859888, 56.33850505275112, 50.9593116852545, 52.241138335197206, 56.21078483520016, 50.20968790977232, 47.76952651239211, 45.733639886302335, 52.540744658439394, 57.249153890917384, 54.64748105695171, 58.62592543325117, 44.867458958779615, 41.273179361897135, 52.353757427584746, 56.80149770552113, 53.69902449269449, 49.29883118598692, 61.62712697059878, 53.84894532542075, 57.390476888225926, 54.55302646083217, 53.62812765182988, 48.73392358902962, 42.358487421466464, 41.51408741551061, 42.88088044812603, 45.901168238732126, 41.15286065686134, 41.33655309677124, 41.28241262128277, 45.67499652985604, 43.317891320874615, 42.685577792506066, 42.601925403841086, 41.94813297640893, 44.255863389661236, 43.50652594720164, 41.14079936858147, 40.40751618723716, 40.922699897520005, 41.47873509314753, 41.10635311372819, 44.267810929206114, 46.107602580901116, 46.98194596075243, 46.30277972067557, 44.250250477944654, 44.908302599383944, 42.7471629265816, 39.814214552602465, 37.51977312949396, 39.17524083968132, 41.2037024190349, 39.895046757113555, 41.67119010802239, 45.39841844189552, 50.96819977606497, 50.95484410562823, 54.3542956536816, 55.343591936172984, 58.33078276726508, 50.829010548130164, 49.758803613724254, 47.00054976247972, 50.254975595781886, 50.52280679825814, 52.03840671047088, 25.690465588723463, 1.0439991278033103, 2.5189260225142203, 11.977002428423974, 3.9723085636092774, 0.27660514618600573, 0.6136433527834955, 0.5044975191835435, 1.4601825826591062, 22.146045200286373, 65.72110083795363, 36.340100688319055, 45.72373197924706, 41.75481896246634, 70.17395588659471, 10.204035216762174, 0.29410452491814093, 0.26387987418040154, 0.1582771665867298, 0.13629188340517784, 0.11284044583237941, 0.29212112328217876, 0.19883668050169948, 0.08711830833025518, 0.13305664813566592, 0.13681539724911415, 0.2787578226097169, 0.14706680280787332, 0.10723601470911696, 0.08441900518993217], [0.08554081838097304, 0.043331725643046444, 0.03384203364652011, 0.036157273927763585, 0.021899224694577918, 0.041126993544880426, 0.0453459661484005, 0.1082050163419016, 0.05357204973998089, 0.05810261711538319, 0.12873200519431022, 0.041180719291010214, 0.022847808168960676, 0.04074535535408124, 0.07810749023431733, 0.0808545896002362, 0.02246533685754384, 0.047143664241077445, 0.06192777456054765, 5.5207536682005856, 40.46648510040776, 34.46430167844219, 23.98303627967835, 30.84906093535885, 40.0290584564209, 47.28890280569754, 48.52535939985707, 4.579017104641084, 0.4450378500886502, 0.45079294772398093, 0.2301724958083322, 0.23412201613668474, 2.915376155607162, 30.904821349728493, 54.22422593639743, 54.812440256918634, 54.2980057193387, 53.90458414631506, 51.75401133875693, 52.72589229768323, 52.07075449728197, 48.97134857793009, 49.595072115621264, 55.65299241773544, 50.30649200562508, 52.50074824979229, 48.805514689414736, 46.681131547497166, 44.771360889557876, 43.88750576203869, 40.571518328882036, 38.285490389793154, 38.62066868812808, 38.42557391812725, 40.509937117176676, 38.809028748543035, 38.80918564334993, 39.117613377109656, 37.7480354616719, 37.639593693517874, 38.56606145058909, 37.189701757123395, 39.51706755545832, 38.103445345355624, 40.770213834701046, 39.004213733057824, 39.25040521929341, 40.95639697967037, 40.121089027773955, 38.10281384375788, 38.864479295669064, 39.23168766883112, 38.82646368395898, 38.589152443793516, 39.962527213558076, 39.45391347331386, 42.91045119685512, 48.77475546252344, 51.08571398642756, 50.70198851246988, 51.90415574658302, 53.610320091247566, 48.620335671209524, 47.650537490844734, 45.7148713450278, 43.88166143048195, 46.422910151943086, 54.617274884254705, 52.99278213131813, 56.03048916785948, 46.27587618366365, 32.559143727825536, 50.708582016729544, 48.73576318064044, 52.48204638881069, 45.40390191539642, 47.71252270667784, 53.78099418455555, 52.49657092555877, 49.576527149446555, 49.06104926140078, 40.55033360758136, 36.96492641202865, 38.54838725059263, 39.132145758598085, 38.848750591278076, 40.17717107649773, 39.73826962132608, 39.00206035183322, 37.95788618826097, 39.45876936758719, 39.203211261380105, 40.33248516821092, 37.60839516116727, 40.043257436444684, 39.42387988490444, 38.72977725921139, 38.933163919756495, 37.314319379868046, 35.75365535674557, 37.51644303721767, 36.74210048490955, 40.53523248241794, 41.40083682152533, 44.5276601083817, 41.689735074197095, 41.294254256832986, 39.25810483194167, 38.174224515115064, 35.42470970461446, 35.74922700082102, 36.067099801955685, 36.545228881220666, 37.476289733763664, 38.71646865721672, 39.18208145326184, 44.28361415863038, 45.40420393789969, 48.35069233371366, 49.44693203895323, 51.54168167421895, 49.72899360041465, 51.04712178630214, 49.351559608213364, 53.462795826696585, 38.59094496696226, 3.625530100637867, 0.13125182159485357, 3.0479272623215956, 12.87789240960152, 0.6206512799666775, 0.12122641963463639, 0.1692044149122892, 0.33217986084280476, 0.8025736277622562, 25.9307558690348, 46.553854557775686, 24.734230964414536, 25.0899899390436, 41.03356176807035, 33.1919514748358, 0.12787106026324535, 0.05258961475544399, 0.02976148930047789, 0.05110254233342506, 0.0667068915021035, 0.06335389319687121, 0.05940686648471221, 0.047258500820927085, 0.031010339021562573, 0.04963352660378141, 0.04050096181491691, 0.0036355770181774375, 0.036355108473329775, 0.044387306702593644, 0.07453020436749344, 0.017052963976898504, 0.042567284807803175, 0.016393592100470297, 0.04687300920786877, 0.03966556591612678, 0.010180363352710923, 0.05076480098068715, 0.04131373896774265, 0.05369664244954625, 0.05128238913452914, 0.03978916654183019, 0.021470546790008104, 0.023010029202146877, 0.035927968490267956, 0.05855813299516036, 0.09012040772265004, 0.0021879837403239143, 0.035539853026068983, 0.08715321895696464, 7.5006406153402025, 50.2828714924474, 35.564322548527876, 27.741853421734227, 38.55436886510542, 43.74582582904447, 53.28002906614735, 55.09400759973834, 5.147721555925185, 0.7998938522031231, 0.2052216096630981, 0.29300595483472275, 0.2141431785158573, 3.4224270764858495, 35.26803847282164, 54.16580615505096, 57.33672864975468, 52.409455084031634, 53.18850055817635, 51.515605757313395, 54.468569986281864, 52.26322520163752, 51.1803529339452, 52.41138881252658, 56.05041088596467, 52.27294875729469, 52.66613891047817, 51.66127474077287, 49.01643230069069, 48.55049787029144, 45.719303623322524, 41.87152516457343, 42.1387876233747, 41.73730557964694, 41.093652479110226, 40.6593676536314, 41.06970248683807, 39.53280802695982, 42.198705750127, 40.38144419270177, 39.54388087795627, 40.242164750253, 40.481025326636534, 40.568988400120894, 41.535483944800596, 40.63964597640499, 41.6903861876457, 42.186660151327814, 41.401723277184274, 40.61563322621007, 40.78515806505757, 40.79551704468266, 40.23418664932251, 42.02181077772572, 40.30771540057275, 40.63831237054641, 41.245707081210234, 44.62482898466049, 51.30924986254785, 52.819609488210375, 53.42266997983379, 51.914224470815356, 56.092039000603464, 53.75313751159176, 48.389084492960286, 46.474661903996626, 44.56863710957189, 47.3768658791819, 55.71635046312886, 57.09379273076212, 55.728643171248905, 47.35035850155739, 39.28906017734159, 54.13010866411271, 49.122485345409764, 53.687461345426506, 46.32521960043138, 50.47438121611073, 54.920960472476104, 54.15926364160354, 52.10551846411921, 50.48634444513629, 42.725993894761615, 40.17020102470152, 39.92048332768102, 40.15664923575617, 39.84513459667083, 40.22974652628745, 41.07549974995275, 40.0509766609438, 40.23004854879072, 40.79013947517642, 40.805213143748624, 40.63654338159869, 38.906813436938876, 40.92585740550872, 41.638603056630785, 41.470486348675145, 39.885280055384484, 39.68714937087029, 36.36982440948486, 39.39970239516228, 39.728212664204264, 41.93680909372146, 44.472707702267556, 45.73206701586324, 43.158721539282034, 43.768548119452696, 41.887324471627515, 41.08212071080362, 37.588618570758456, 37.72918062825357, 38.36154122506419, 36.85616693189068, 37.8715116746964, 41.662353008024155, 41.62212125716671, 45.822156013980994, 48.69222487172773, 51.2425381906571, 51.65173945888397, 51.914832438192065, 52.895111191657286, 51.08601600893083, 49.28945672127509, 52.744194076907256, 41.29578005883002, 4.7548500953182105, 0.2666191900930097, 3.968739697048741, 11.367944632807086, 1.752788088014049, 0.175241555477823, 0.20346441846941749, 1.2535260137050384, 0.724718808647125, 29.498743818652247, 54.29459717965896, 35.82324212597263, 25.168368701011907, 43.85591107030069, 43.949828301706624, 0.2603479637013328, 0.056034164398067424, 0.017932534420622454, 0.06133713226224627, 0.06371637918956338, 0.029772264327132897, 0.020372587661709518, 0.047125101930672125, 0.06300470266010492, 0.0408617164489002, 0.025184339948839722, 0.02531599215862732, 0.09563961922521554, 0.10217500039406362, 0.08998376828047538, 0.18342371158782514, 0.1094377973687745, 0.12635701771585212, 0.16497280568845812, 0.12798725281872098, 0.10801842030618461, 0.19923329954185795, 0.26242740211948273, 0.17727746478011533, 0.07923829729758924, 0.15833047098450123, 0.15199916797780222, 0.09213762447958992, 0.07024555121578517, 0.20836980202265326, 0.18738302251984998, 0.06138847930537117, 0.20005643037298035, 0.1733409219812001, 8.648594810116677, 59.07113013728973, 43.91052615258002, 33.898570383748705, 43.35322010901667, 52.05601815254458, 56.46204402369838, 63.766246457253736, 5.833171433018101, 1.253999272181142, 2.123360383895136, 1.7405643890942297, 0.6548007830016075, 3.561132872296918, 38.16672102097542, 54.32217144197034, 54.95091953585225, 53.664856726123446, 54.46580079294021, 52.73618067464521, 55.79085196218183, 52.64431092046922, 52.806363644138465, 55.25680165137015, 59.31887095974338, 54.629038072401485, 56.82058788114979, 53.14949650918284, 51.73175188802904, 49.10609376045966, 48.232628991526944, 45.08415422131939, 44.42461552158479, 43.197678519833474, 43.572476679278964, 44.606809616088874, 43.27161911995181, 41.85353325259301, 44.65862804843534, 41.415302522720836, 42.10697720127721, 42.2819306004432, 41.739051034373624, 43.21880832795174, 42.44643480547013, 44.1857784794223, 43.55060554319813, 42.485850703331735, 44.152854104195875, 41.628871656233265, 42.23737639765586, 41.6765009972357, 43.06963666792839, 43.844999036481305, 42.518657407452984, 42.81663986944383, 43.21316403727378, 47.62551669151553, 53.37444836093534, 54.796891981555575, 54.58935937573833, 55.846027943395804, 57.308824908348825, 54.66864616640153, 51.85340027655325, 47.98156199916717, 48.60950600716376, 48.745573028441406, 59.25960394643969, 58.560986672678304, 59.01559722039008, 46.49345005712202, 39.67780236274966, 49.81484251637613, 52.6028436230075, 54.07111621672108, 50.39950709189139, 53.275655623405214, 56.6799512986214, 57.223462366288715, 53.11071211291898, 53.19361140651088, 43.1795532472672, 41.76469156819005, 42.20543653734269, 41.729327478716456, 41.91566751849267, 42.947992201774355, 42.761365828975556, 42.692336036312966, 41.68213352080315, 42.86918001790201, 42.40757196180282, 44.638737709291526, 40.37555671507313, 45.05223397285708, 44.129249280498875, 43.61124538606213, 44.239585553446126, 42.95387183466266, 38.650109998641476, 41.13645338243054, 42.594190489861276, 43.848952785615005, 45.31308335642661, 47.30603179624004, 45.199719013706336, 46.24481885663925, 43.952428833130874, 43.125275488822695, 39.3718731787897, 40.84810033921273, 40.51321621864073, 38.49426246458484, 42.48917687323786, 44.120157226439446, 43.312023455096835, 47.22515252328689, 49.44752039447908, 52.830003769167014, 55.34449015894244, 54.203790387799664, 53.63093999124343, 51.47041613055814, 49.351339955483716, 53.77137653289303, 43.304178714752204, 5.931538103088256, 0.24283606709251482, 7.011102341836499, 20.19286959402023, 2.8738745374064294, 0.2867977621574556, 0.3230850488668488, 3.49079791095949, 1.6969755796655532, 32.98926299618137, 57.05296085726831, 35.516940316846295, 36.73579331367247, 53.32972941860076, 51.148311092007546, 0.9384820381960562, 0.17373033979487035, 0.06557942458218144, 0.18282746535635766, 0.14813823805701348, 0.21443783125329405, 0.16175436306624644, 0.12758036820037713, 0.19820827389917067, 0.14184474915025697, 0.11653068370275921, 0.04882485568222981, 0.1247626891539943, 0.22263898634381835, 0.251548478620187], [0.06635076786962248, 0.06126793154004601, 0.05242135120375503, 0.029549899646231247, 0.010521995474494273, 0.011361108814936974, 0.014503793002316549, 0.07440129475247476, 0.10002827647352412, 0.016668749815453927, 0.038609375816679774, 0.018104396670335726, 0.0407621709840192, 0.023914915021328677, 0.03186709919734107, 0.043842859506126375, 0.0017934097958195415, 0.02843413471935257, 0.04969181440350029, 0.2831367505413871, 27.949238938670007, 49.29991376015448, 29.091258587375766, 29.93563702029567, 34.3041120806048, 42.71883556919713, 50.8166080136453, 3.4074612730933778, 0.2931725329929783, 0.18039554988424625, 0.1491080900473941, 0.09344503013116699, 0.04474114739306031, 11.435101493712395, 40.685529862680745, 52.8083130621141, 53.386435124181936, 53.10494230639551, 56.41689362064485, 54.03777607025639, 54.943455265414336, 55.32833391620267, 52.251191369948856, 51.356526190234774, 49.843648402921616, 47.04451560974122, 45.45057027570663, 42.516300062979425, 40.88224849393291, 39.032364583784535, 38.20509356837119, 38.49934585632817, 37.998706294644265, 37.27590760877056, 38.07428644549462, 37.03413663371917, 40.57161638813634, 39.058981787773874, 38.657331082128714, 38.238688668897076, 40.52702296164728, 37.45387338822888, 39.345267741910874, 38.94242463573333, 40.60385434858261, 39.61284006795576, 40.526756240475564, 40.89611015012188, 40.99639338831748, 38.70452896241219, 40.50910557470014, 40.345829071537146, 40.121787209664625, 38.44237735194545, 39.41473684003277, 38.73754355215257, 44.649257506093676, 51.034213266065045, 53.052680646219564, 51.846908753918065, 53.92307812167753, 53.095430558727635, 44.98361602906258, 50.763044126572154, 47.29728491075578, 45.84223854926325, 46.87941128207792, 51.243263829138975, 54.185155207110995, 54.80418366770591, 46.76183431379257, 35.60687242015716, 45.98493829850228, 50.94665419670844, 54.90863246302451, 51.91398912860502, 47.348134517669685, 51.049079049018125, 50.84251134626327, 48.28119185663039, 46.71214572844967, 39.36928441447597, 36.69394162393386, 38.228047278619584, 38.02062842153734, 37.325403997975016, 40.47332963635845, 38.89508162775348, 40.17127183175857, 38.065719989038286, 37.73665274343183, 37.65355733133132, 38.35227658671718, 38.81955639008553, 37.84159967976232, 38.392798592967374, 39.564783188604544, 37.12607699055826, 37.2266661736273, 35.540223506189164, 38.13982532870385, 35.70551610762073, 39.79249638895835, 41.55605285398422, 43.153763663384225, 43.405211125650716, 38.76136018383888, 39.943770439394065, 38.70064189357143, 36.289235391924464, 35.986887331931825, 33.973342526343565, 35.77672673809913, 36.54210275219333, 37.89012724353422, 38.808726726039765, 41.214916475357555, 43.26863811862084, 46.12156621871456, 47.76971478616038, 50.4569580478053, 48.55729533780006, 51.128197177763916, 45.73279265434512, 51.5800424545042, 19.197997662328905, 1.5364403229567314, 0.5523929684873551, 5.176524990989316, 7.999442546598374, 2.226410609099173, 0.019011226437625386, 0.10567925509906585, 1.1390287188753005, 0.37357027372044904, 37.09101100121775, 34.891310507251376, 27.689144611358646, 27.105121343366562, 39.59536590883809, 9.640828947867117, 0.067579687813357, 0.03605974327412344, 0.04045495823506386, 0.07169408558477318, 0.05649940193360371, 0.045968018051597385, 0.022588096701750354, 0.07723591966374267, 0.05241618777114538, 0.08341715370695438, 0.05874531125769981, 0.02589293872006238, 0.02691646091519825, 0.05915025001271598, 0.063703604673426, 0.03800964005471718, 0.07427744131775633, 0.05446819258072684, 0.05630399205631787, 0.02316269520369749, 0.03787253712934833, 0.05060212987084543, 0.07828481660615053, 0.05481550237163902, 0.03775809508477969, 0.0844268499302768, 0.02672569927639298, 0.06629307378804492, 0.0569960835479921, 0.022166625769328208, 0.08593178369225034, 0.05151993384765041, 0.050685560676239194, 0.043124970003602006, 0.7650196299918237, 35.36348935096495, 51.93156526934717, 24.5577694139173, 39.90229137482182, 45.88926776762932, 45.59490565330752, 58.657147499822806, 4.70083317449016, 0.30111168601339866, 0.10824310623349682, 0.10551515140480573, 0.29881265615263297, 0.039918505166086464, 14.179932994227256, 44.50339632649576, 54.609877294109715, 53.01048771027596, 52.41913941598708, 54.32267350535239, 55.88351011276246, 56.33199391826507, 57.522547014297984, 54.025291165997906, 53.483031334415564, 51.82737927283011, 49.357670660941835, 49.03971941240373, 45.36913794855918, 42.77119136625721, 42.304162594579886, 39.809154695080174, 40.75775638703377, 40.234461215234575, 38.13636579821187, 40.29283000576881, 38.607269871619444, 42.82634773562032, 41.0476234651381, 39.29033494764759, 39.902463959109404, 42.00421502513271, 40.48712853462466, 40.507411110785704, 41.98054352114278, 43.05708508337698, 40.98965475636144, 40.872670065972116, 43.34203743165539, 41.71070798750847, 41.170617226631414, 42.66230637027372, 41.27066120024651, 41.83859294460666, 40.0731223629367, 40.77450098529939, 41.03775085941438, 45.35513116467384, 52.54623989905081, 53.03424942877985, 55.18592442235639, 54.28280653492097, 56.526292447120916, 47.68599963957264, 51.861864751385106, 50.649444441641535, 47.250459655638664, 49.249381865224535, 53.1707400660361, 56.44824904780234, 56.870609867957334, 49.43970703309583, 39.084084956876694, 52.29990720748902, 51.50256779886062, 55.750361334893014, 52.078528634963504, 49.46585747503465, 52.32991726167741, 55.548402417090635, 51.54109724106328, 48.33793286354312, 41.91178829439225, 38.195883843206595, 40.23236666956256, 39.15216161358742, 38.8070361844955, 41.0650074097418, 39.002193712419086, 41.696442327191754, 39.81319473635766, 40.095844653344926, 39.905707759241906, 41.13354690613286, 41.85925206830425, 40.22889144958989, 40.3142108455781, 40.94750496648973, 37.21968043235041, 39.68272885968609, 39.62660366489042, 38.398195774324485, 36.983106597777336, 41.02745071534188, 44.051978588104255, 45.27130619172127, 46.28972215037192, 42.889815607378566, 43.23594516323459, 41.21784648587627, 39.17952014553932, 37.76807092851208, 37.24136329466297, 38.20184584586851, 37.160209455797755, 40.622650346448346, 41.260933722219164, 42.13477111631825, 46.555086182009795, 49.22229397681452, 50.425143703337646, 52.07119380274127, 50.89145075890326, 50.84855179632864, 46.66949779756608, 52.21438384825184, 21.65855538460516, 0.5149459165911521, 2.154621183872223, 10.111753613718095, 6.377227219843096, 1.303288878933076, 0.011976777290504788, 0.24626726765305768, 1.796049502107405, 0.8981719625092323, 40.72203536187449, 41.89374931396977, 34.771576235371256, 27.215626278231223, 45.33929263391803, 15.42715943628742, 0.024078003649089127, 0.05922537642501055, 0.03144487941397294, 0.020636541340800545, 0.0788771021630495, 0.04555796182924702, 0.016691414526693763, 0.0947135721423453, 0.0494085916978938, 0.023883961238748124, 0.0560081901869947, 0.036381986668153156, 0.05625298209187966, 0.010378015952395096, 0.012857760208839131, 0.14529527044825016, 0.20959266221090672, 0.14755066394084884, 0.17907640776566922, 0.09544998948131839, 0.16678192232164646, 0.09735185637949936, 0.17351208134524285, 0.11460650832422319, 0.14732563327397072, 0.16316810172171364, 0.09886284223607472, 0.15301519974825845, 0.1495048929486544, 0.07183960398599025, 0.14098323731412812, 0.1649955891433262, 0.19477224698470486, 0.14272018846484924, 1.0047589398680195, 41.50251642350228, 61.782562655787316, 38.408409626253196, 39.433976065727975, 45.522498699926565, 51.81517677922403, 65.54017759138539, 5.938870974125401, 0.9354931308377175, 0.5174859577128964, 0.39807163479347385, 1.0649304885056712, 0.23964851313541013, 14.649130836609872, 46.24424226822392, 55.24716438785676, 54.04422052444951, 52.01188364336568, 54.68336682165823, 56.195977887799664, 57.86314995058122, 59.4862541844768, 56.183508673021876, 57.271205456026145, 54.435582853132686, 51.62944470682452, 50.467509223568825, 46.556784568294404, 44.454382388822495, 43.906505723153394, 42.69854514829574, 42.88251215411771, 41.410725116729736, 41.51555045958489, 41.6705507616843, 40.35675287246704, 44.76701882577712, 44.686735753090154, 42.009714188114295, 43.10262772344774, 45.542789120827955, 42.89483231882895, 43.49708480219687, 43.92499577614569, 44.971770471142186, 44.01575157719274, 44.06620110234907, 45.759633433434274, 43.600611840524984, 42.0691773199266, 43.498222289546845, 44.27549093000351, 44.52244335605253, 41.523865884350194, 41.85206628614857, 42.792046608463416, 46.5848099031756, 54.06614265134258, 55.63168218058925, 58.35974947098763, 57.427590354796386, 53.98839342978693, 49.16500776044784, 56.369174065128455, 50.396286825979914, 50.81044204773442, 49.89770650863648, 55.84072489892283, 57.6083057157455, 58.28836233385148, 46.99741578871205, 40.087019320457216, 48.85008065931259, 53.428314270511756, 58.459789522232555, 54.65181527599212, 52.52687907988026, 51.71241460307952, 56.1765621554467, 50.89899347674463, 51.08776930839785, 42.50293654780234, 40.675688635918405, 42.34360987140287, 42.28256602441111, 39.837336924768266, 44.622428494115034, 41.34262884816816, 43.4031871826418, 42.40759941839403, 41.66789923944781, 41.477507391283595, 43.61568158672702, 44.749470141626176, 40.78389898423226, 42.41302013397217, 43.65672919058031, 40.08509343670261, 40.84601363828106, 39.91684729053129, 41.27066512261668, 38.266376679943455, 43.796698970179406, 45.53086903787429, 48.00390381966868, 48.70249755920903, 44.42644726845526, 45.177385037945164, 43.10790331132951, 40.80654282723704, 40.572000780413234, 40.00155871914279, 40.00974078332224, 40.63489598612632, 42.884077179816465, 42.615265384797134, 43.8788059449965, 47.67314603251796, 52.03742219555763, 52.7814644382846, 56.132384500195904, 52.415354328770796, 53.47028755372571, 46.392747125317975, 52.249591042918546, 24.557618402665664, 2.446517843392588, 2.215249259625712, 12.527883629645071, 16.787875736913374, 7.078634279389536, 0.33601180199653874, 0.4625214780530622, 4.621338498207831, 2.7829853757735226, 47.253271995052216, 46.54504099199849, 40.13158529035507, 34.635120899446555, 53.801370897600734, 21.637170622425696, 0.13728217462137823, 0.19751151693203758, 0.16219933757618551, 0.23066669912828555, 0.17714981921017173, 0.12501485465515044, 0.09694356215937484, 0.19516462189776285, 0.1798034098840529, 0.1547010068691546, 0.2132992867019869, 0.12222097796057502, 0.13663233287872809, 0.19055206779270403, 0.14156403921304211], [0.04516300519988422, 0.04656282786820685, 0.03838391997100365, 0.003776629366198435, 0.037499272279561534, 0.03391249841379543, 0.12234040340709111, 0.06913332178467704, 0.07562233931234769, 0.06739290791653818, 0.04417017057177521, 0.027982537379308094, 0.030855443704152302, 0.024095560469093825, 0.11818436109611105, 0.08268609898345125, 0.04511214845303086, 0.09228549477073456, 0.04188313381746412, 0.03378277674557702, 10.65260531440858, 48.39335203170777, 35.554057705786924, 24.256645133418424, 34.194944673968905, 36.2683879944586, 54.14960284386912, 6.088043124445024, 0.1769032308291043, 0.08148293491573104, 0.05741467015937932, 0.17752512568427672, 0.039818320017788685, 1.051910425866804, 22.010168413962088, 48.415042738760675, 55.732459637426565, 55.309149603689875, 51.82933261317592, 52.69572927105812, 55.08104416631884, 51.61824633998256, 50.38634753996327, 47.559256092194595, 45.700742967667125, 40.23414350325062, 37.724901322395574, 37.34092873911704, 38.57540845870972, 39.851441767907914, 38.741799323789536, 40.20137994520126, 40.971407890319824, 43.79615768309563, 44.07690525054932, 41.26521695044733, 38.959930173812374, 39.44765337051884, 36.96161200923305, 39.78394169961253, 40.12843954947687, 39.19529984074254, 39.83610137816399, 38.987331851836174, 39.832520254196666, 38.769471645355225, 40.63706113446144, 40.21400605478595, 39.25922270744078, 39.816709180032056, 40.27453607128513, 38.69862971767303, 41.4787390155177, 38.59831510051605, 39.91541562541839, 37.87365328881049, 45.12615496112455, 51.41462825959729, 52.0427252400306, 51.16021548548053, 55.35066396959367, 50.286527141448, 47.40624443177254, 52.730308886497255, 47.829660369503884, 48.26625154864404, 46.960161116815385, 51.65904683451499, 52.18160852309197, 56.51886740038472, 47.817265679759366, 40.34768435262865, 42.98619216488254, 53.24208797947053, 52.2387731459833, 52.216341110967825, 51.291559973070704, 50.301263486185384, 48.25404905503797, 48.52727743887132, 44.43956759668166, 39.02188401068411, 37.83218599134876, 38.34535752573321, 38.85890560765421, 39.54075474892893, 39.233656698657626, 37.30774940982942, 38.351970641843735, 38.960891154504594, 38.400266785775464, 38.951187210698286, 37.85970141810756, 37.99619597773398, 38.982193546910445, 37.86539669959776, 39.527363777160645, 40.33308921321746, 37.5086179087239, 36.12656685613817, 37.46678975320632, 35.586558465034734, 36.78898849794942, 41.557464907246256, 44.19264262722385, 42.9896124716728, 40.17708478435394, 38.548806944201075, 39.00562970869003, 38.079020746292606, 37.26590556483115, 35.8269016973434, 35.88295628947597, 35.92487465950751, 36.291804544387325, 37.823439105864495, 40.70516524776336, 43.7311718540807, 45.02361636007986, 47.15659341504497, 49.59005540417087, 52.262103403768236, 50.863288141066036, 50.56287773193852, 43.59236701842278, 7.0660660247648925, 0.12208342687377047, 1.681495087762033, 3.4470892240924225, 4.711087721009409, 0.9107698187712701, 0.06804588295879864, 0.11360271097791773, 0.6835887124461513, 3.8394321453186775, 43.85484810798399, 29.79974258330561, 24.11953672286003, 24.51263862271463, 36.35697472480036, 2.1206242855518096, 0.12201597283203756, 0.019669359166836067, 0.041156361525457714, 0.016653523817958853, 0.05380826912099316, 0.003245088596633005, 0.023202658180267583, 0.06361314884176658, 0.03258839204546905, 0.06083299661235464, 0.029549235064956932, 0.08783040237763236, 0.006736698541640034, 0.08704005244878993, 0.08126918872397754, 0.06027125498099674, 0.03596547232460111, 0.059945809339443525, 0.030497163534164432, 0.015479267120451458, 0.09456181012454534, 0.036801890950770154, 0.03685141087419564, 0.11650728737755169, 0.049756070028149316, 0.04738905369454334, 0.016275446020787763, 0.02345599579594789, 0.04992110068879781, 0.03991806083509038, 0.03063941265516464, 0.06408079189338511, 0.04922393003418561, 0.033497799698623924, 0.05767950292436346, 15.700681017291163, 58.65180523164811, 35.87400936311291, 27.12469004815625, 43.866693665904386, 40.986967932793405, 59.201141019021314, 5.61894775398316, 0.6115554261111444, 0.055334837205948374, 0.2522435808374036, 0.1818274448235189, 0.11820894485760121, 1.450617392697642, 25.402659716144687, 49.82593105685327, 55.251012232995805, 54.487981796264656, 54.287670273934644, 54.230313454904866, 56.99655325182023, 55.372068343623994, 52.2696461216096, 50.87762440404585, 48.68614519796064, 42.4050812567434, 41.04436005315473, 39.96484925670009, 40.5894749395309, 40.886041425889545, 40.382295347029164, 41.729331401086625, 42.652320015815, 44.65928308425411, 44.1065622914222, 42.07088747332173, 41.40635951872795, 40.617464973080544, 39.29101744005757, 40.746875732175766, 41.84819882915866, 41.247119134472264, 41.38879122272615, 41.90371213420745, 40.88648073134884, 40.91646332894602, 41.26283214938256, 43.497406436551, 40.95142733666205, 41.27017482634514, 41.86893247788952, 40.59640184525521, 41.74303224009853, 40.24413770244968, 40.32524447287283, 39.90636279506069, 46.37709686833043, 53.062125713594504, 55.35472754509219, 54.340920371394006, 57.335940253350046, 53.802210284817605, 50.04452866892661, 53.11270075459635, 49.19551203327794, 51.024301436639604, 47.840890115307225, 54.372691569789765, 54.498862451122655, 56.47741579240369, 49.46346875159971, 41.72236134929042, 48.48083265366093, 56.7581045243048, 53.018340295360936, 53.27509472447058, 51.93528759864069, 51.773423148739724, 50.09984193309661, 49.862707199588904, 45.99386561301447, 41.49281640206614, 39.66697662107406, 39.90608038440828, 39.52074281630978, 41.38224086453838, 39.46755939914335, 39.39968278331142, 40.28609137381277, 40.82700191005584, 40.516291356855824, 40.73372794735817, 40.645611901437086, 39.78460850254182, 40.43355288044099, 40.434223605740456, 40.50266896524737, 40.13904956079299, 38.318293171544234, 37.504417050269346, 40.38292684862691, 37.76944768044257, 40.61975955963135, 44.208477235609486, 46.08142468237108, 45.76521496618948, 42.99076957087363, 41.67071942360171, 41.099747842358006, 39.433552449749364, 38.639143051639685, 36.867510426429014, 37.95031209145823, 36.71078035908361, 38.47576064448203, 40.442178172449914, 42.5565278914667, 44.46995419840659, 47.85544603101669, 48.633314794109715, 52.03455886533184, 53.90536862034952, 53.23943645723405, 50.01560903364613, 46.68508529663087, 8.53389293916764, 0.5686745432115371, 4.112176361583894, 8.704394448188044, 7.948867505596531, 1.369443696833426, 0.23807362022419132, 0.050437493745477936, 1.2998895323084247, 5.511410582450129, 47.61469487221011, 36.43011908377371, 28.248598152591338, 25.942273909045806, 46.590760138727006, 2.984579758298013, 0.12598171124174712, 0.03290037369175303, 0.06730165918387714, 0.04864964754350724, 0.05439400845657914, 0.05118216185139553, 0.05522422943144076, 0.03528540075245885, 0.00991303314109363, 0.030855311553985364, 0.04885557963843307, 0.023216775265492262, 0.03610323791602447, 0.022335197671406695, 0.03848126293310235, 0.1366750959066614, 0.11944127389259877, 0.0970480565522467, 0.12493232400306772, 0.14388787500079603, 0.19938826380718142, 0.1613501291121206, 0.1477163840806292, 0.2979426254187861, 0.15295288615649746, 0.0968668461146374, 0.12578311060825664, 0.09316512458627263, 0.1791881187067878, 0.2398672618813092, 0.13178524861653007, 0.23560251169387372, 0.18463474337852773, 0.1833107136189938, 0.1705006050366548, 18.87395497291319, 64.66144115694108, 45.21707942408901, 32.3185416190855, 46.367032066468276, 46.17587143375028, 67.94601040501749, 9.388393048317203, 1.0011872541039222, 0.2301393854882448, 0.4530569214013315, 0.8549007424904455, 0.4152895834657454, 2.1584918277878917, 26.01480833945736, 52.69471729955366, 56.47636067482733, 56.884902984865256, 52.8081718567879, 55.397006773179584, 59.357133680774325, 56.852029600451075, 54.3341778170678, 52.178686357313595, 50.757662634695734, 44.91321732920986, 42.50900445445892, 41.82583739680629, 43.015700155688876, 44.608578605036584, 42.00986716055101, 44.480105292412546, 45.48782102523312, 48.94783396874705, 48.49123477935792, 44.74910143882998, 41.99567602526757, 43.358770262810495, 39.169977018910075, 44.06801323736868, 44.92641218246953, 44.75457706759053, 43.10689918456539, 44.3450306307885, 43.018324221334154, 42.3137527896512, 44.024008166405466, 43.74066006752753, 42.77861249062323, 44.52143922928841, 42.607369653640255, 43.37517753724129, 44.38833751986104, 42.83972694027809, 40.83918479181106, 43.81473402823172, 48.51134477123138, 54.990774739173155, 55.67988811000701, 55.80874973727811, 57.99074072991648, 52.02547857838293, 53.208265381474654, 54.09968283868606, 52.928627844779726, 51.8926122111659, 50.09311114588092, 57.258010602766475, 56.01852201646375, 60.60830308545021, 46.72978854948475, 43.3336631713375, 45.07259891879174, 55.09916551651494, 55.09538435166883, 55.88033299292288, 55.10761430186611, 52.88485027128651, 51.249947547912605, 51.82636337895548, 48.406915587763635, 42.83087415079917, 40.22887183773903, 43.18300885538901, 41.96567381581953, 43.27946778266661, 43.44158718662877, 40.629228161227324, 42.72767659156553, 42.85429854546824, 42.86969384839458, 42.781209099677305, 41.692480733317716, 41.161882108257664, 41.528298162644916, 42.81761261724657, 41.650742792314105, 43.138215388021166, 42.456401548077984, 39.253613718094364, 41.15379810333252, 39.89328169053601, 41.80019686298986, 45.68849340561898, 47.9982909079521, 48.161367370236306, 44.655894156425234, 43.499771625764915, 43.39516201326924, 42.13610472217683, 40.771621965592914, 40.86558626544091, 41.33922423085859, 38.79850110700054, 40.67726542872768, 43.059312989634854, 44.35571516713789, 47.04362130934193, 49.91364702101677, 51.224330548317205, 55.45538733082434, 57.8344617351409, 54.14570400791784, 50.45805238908338, 48.441856061258626, 10.23451203300107, 0.4381604336442486, 5.177130506884668, 8.951869530062522, 15.999574449754531, 4.463637644244779, 0.5927740145594843, 0.4375048155986494, 2.1875112383596362, 8.085242923228972, 54.28304579950149, 41.39778521753127, 33.92278317482241, 33.709092447834635, 53.89394667840774, 5.431968858165126, 0.19014570411414872, 0.14898694090304837, 0.16130440898479956, 0.1309929451634807, 0.2389457653607092, 0.09214231293768653, 0.1839434409574155, 0.1803807031002737, 0.09155683024155517, 0.15652628795754525, 0.16229779519621404, 0.21898467033620805, 0.13782289480009388, 0.21116337228205898, 0.17523007948071728], [0.009778960093465305, 0.03602801191229974, 0.07351725227049283, 0.05285913597852473, 0.009947829812224354, 0.023371214760587584, 0.13082219948691706, 0.07260356218584123, 0.044307629728028854, 0.009064463402835593, 0.04659716775941272, 0.041398912623164155, 0.07458082745752989, 0.023562767385174672, 0.09241255045297647, 0.04744176437417346, 0.0873071106991941, 0.05635825789443428, 0.03783135990341825, 0.07514780913028987, 2.148930315048464, 36.74591695108722, 45.274506845781886, 35.895825586011334, 42.55075416257305, 30.057352089112808, 51.69664275261664, 16.968551874160767, 0.46735650409133206, 0.09138755545380617, 0.09724362347755702, 0.08497138522685536, 0.051951892523755955, 0.09665613363106405, 2.1547349326072203, 27.182397919316447, 47.11914654700987, 56.20293225011518, 51.797435898934644, 56.30401957419611, 55.43675215013566, 51.442151531096435, 49.544508841729936, 45.77413051359115, 40.197571323763945, 39.250350306111, 38.679186528728856, 40.37788268058531, 40.49781307097405, 42.85120771777245, 43.58371426982265, 46.866832240935295, 49.15858684047576, 51.88876044365668, 50.52948659466159, 50.942433726403024, 43.24381736017043, 40.305146248109885, 38.103519870388894, 40.100249475048436, 38.12026839102469, 38.47623917364305, 39.33056277613486, 38.79964643909086, 38.59338860357962, 39.12407744315363, 39.974647337390536, 39.922609252314416, 39.112835930239775, 39.9462454549728, 40.755308828046246, 40.14226198196411, 38.42584848403931, 39.41867489968577, 39.01742819816836, 38.81083696119247, 45.93145678120275, 55.49163003121653, 50.44756789361277, 50.89535351722471, 50.95187094903762, 51.12810696324995, 49.83190874899588, 53.33951180981052, 51.65873696727138, 50.653135391973684, 47.666850628391394, 51.126914562717566, 52.64330287133494, 55.502832320428666, 50.983363659151145, 44.541666892267045, 42.65550890276509, 53.365670096489694, 54.126354955857806, 53.20914007002308, 50.559802593723425, 49.59808057354343, 48.44375448842203, 45.37205226959721, 41.52688218701271, 37.65515373599145, 35.63304639631702, 38.261544319891165, 39.54792091923375, 39.209663560313565, 37.87719911144626, 38.73050289769327, 37.16078996658325, 39.33327313392393, 38.68707049277521, 38.77637893922868, 38.1503882715779, 40.77371258889475, 37.418007235373224, 36.54600943288496, 38.26938121549545, 38.52325270252843, 38.313551026005904, 36.21847975638605, 37.0028204302634, 37.67171398285897, 36.71134518038842, 40.99091383718675, 41.18307467429869, 43.11327303609541, 40.33910220669162, 38.64161806721842, 37.475250305668006, 38.45598405407321, 35.052727806952696, 36.93646177168816, 35.55224557076731, 36.49011565792945, 35.5153674464072, 37.557741672761985, 39.89831409146709, 41.023783299230764, 43.44617243736021, 47.615738222675944, 49.38950461726035, 50.496087612644324, 51.365939878648334, 50.71254753297376, 26.30551088240839, 0.8986299605138841, 0.3012180190172888, 4.023572961168905, 10.264488747042995, 6.237520729341815, 1.4246309548616412, 0.0170917644150435, 0.10246907856555716, 0.6120991033892478, 12.113880399734745, 47.337457826060636, 21.069472259090794, 21.826807414331746, 35.71397273771225, 25.512558644817723, 0.17895939549611461, 0.04732094081719557, 0.06324561432965341, 0.03836657190995832, 0.01041358062666991, 0.09454842656850816, 0.07393332228304879, 0.04297571692375406, 0.014603299205191435, 0.07192847018520679, 0.0240798422601074, 0.04157939144680577, 0.03664781534743886, 0.06533777746822565, 0.005874620758057122, 0.014524685177621583, 0.028840289638948538, 0.015538881209889248, 0.04146269710373975, 0.06525543067724475, 0.03765510605467904, 0.03384077726232429, 0.05053499375560111, 0.03377088706099218, 0.04046046257679982, 0.10914554248654074, 0.05335999660254006, 0.00513116259225494, 0.02117079190699564, 0.026355305341102427, 0.015787247872550883, 0.05362386792717923, 0.05957297732933395, 0.04949400284057183, 0.07200910860011656, 0.042242340953840364, 4.042362830331249, 44.7594408066042, 50.40522198523245, 29.438060829716346, 46.791593336289935, 36.54085151610836, 59.6153982224003, 16.620935740009433, 0.4793233184083816, 0.1034740173828698, 0.10158454578730369, 0.33708843132180555, 0.21999797483365383, 0.14422250220612173, 3.199471711151062, 30.583020294866255, 49.722003936767585, 55.55819657541091, 51.5758768973812, 57.64376786447341, 57.28055638651694, 53.71708308496783, 51.481434068372174, 47.433524516321, 42.6363089007716, 42.289987148777136, 40.89197204959008, 40.68895801421135, 42.260271272351666, 44.622216686125725, 44.51231579626761, 49.27078231688469, 50.43376115060622, 53.86381110837383, 52.93277771242204, 51.344672787574034, 44.824799260785504, 41.6322958853937, 40.32114951841293, 43.2292418326101, 39.993635531394716, 40.839459357723115, 42.13664208689044, 41.74910406912527, 41.16394135259813, 41.04597606966573, 40.22896597462316, 41.76293434635286, 41.96873718692411, 41.99676644417548, 42.30859879524478, 42.605263340857725, 41.537017591537975, 39.97896978932042, 40.27829370191021, 41.49144357250583, 48.57448316389515, 57.538397312164314, 54.335040738505704, 54.11120283988215, 54.04915486612628, 53.83815880744688, 50.16869914147162, 56.009312291299146, 51.881653108904445, 52.47773178162114, 50.352395503751694, 52.27650634704098, 55.255985798374304, 55.81565310878139, 52.373514406142704, 43.91344439598822, 49.63043620509487, 55.461631744138664, 53.58831559458087, 54.86630224412488, 52.367701453547326, 53.240856355236424, 48.546559810638435, 48.37158679962159, 42.84882291670769, 39.47270162643925, 37.75186761733025, 40.43174074542138, 39.5153417125825, 42.037115866138095, 39.59240844172817, 42.42075504795198, 39.69812416261242, 41.238646814900065, 39.64792174677695, 39.96297828612789, 38.95428588313442, 40.00017804484214, 38.71667262046568, 39.48184074894075, 39.91530579905356, 39.95819691688784, 38.733189721261304, 39.256853595856704, 37.86773050985029, 40.373109156085604, 38.51338794154506, 43.33250607213667, 44.49400224993306, 45.72876438017815, 42.61321006282684, 40.64849484351374, 39.10459110813756, 39.10643069974838, 37.27462499372421, 39.33685425789126, 38.33253137526974, 38.930543776481386, 38.17977859127907, 40.13263256319108, 41.90106061197097, 43.82692475472727, 45.088115815193426, 49.40387618157172, 51.74677456578901, 52.52878142941383, 52.7029150532138, 51.292395437917406, 28.88440651278342, 1.124695029950911, 1.7851934846370452, 7.578356006453115, 10.996644246962763, 8.457514585987214, 1.8765372734877372, 0.06656794613527675, 0.16724382737471213, 1.108780870995214, 14.888443466155762, 51.689178482178725, 30.376048587983657, 23.563605470042077, 36.60853985817202, 33.90660339786161, 0.2583221207943655, 0.046248065322757735, 0.05583405840180575, 0.05017526950987597, 0.07548233674418542, 0.0409083022555757, 0.013176311059073817, 0.020634164553015463, 0.013737060606569774, 0.0663244987146989, 0.035026623912516146, 0.0523316269860633, 0.06694859990309324, 0.05299474886288086, 0.0358664631212671, 0.044107259431433295, 0.1400430022829002, 0.055065526657046816, 0.13342803223959862, 0.2158133727648566, 0.23185507003818792, 0.19827993376360786, 0.17867784286218305, 0.1609860075217101, 0.14554242573438153, 0.21310863806115043, 0.16433765751219567, 0.1538257054503887, 0.17721735752157627, 0.14362078610687487, 0.19661813583825866, 0.15895205940450394, 0.17743026867749231, 0.12226672107053381, 0.2695618870277559, 0.18569476391759612, 4.423245076210269, 51.43469510539886, 57.21963021063036, 46.31318576874272, 53.804528405589444, 39.309750680000555, 62.97495142106087, 20.11975661400826, 0.612254404733258, 0.2871429920196533, 0.2920802141870222, 1.0176415969767878, 0.4792697841842329, 0.4750627663827712, 3.81941334855172, 32.63480232607934, 50.79917307822935, 57.26935409730481, 54.715349828043294, 60.7115634026066, 60.16133331483411, 55.643908208416356, 53.221562216358805, 50.925171375274665, 43.99830879703645, 43.95247590157294, 43.343457329657774, 43.22247966643303, 45.247803349648755, 47.97701989450763, 47.47552133375599, 51.932126168281805, 53.07325740014353, 58.21364902680921, 54.89898735477079, 57.08244923622378, 46.62034265456661, 44.322504458888886, 42.81849122816517, 45.023455542902795, 41.897397118230025, 42.277439486595895, 44.1984869587806, 43.20926912369267, 42.88877225691273, 41.266103406106275, 44.20819090258691, 43.77114080613659, 43.05947772918209, 44.66295050036523, 43.79959760173675, 43.88740770278439, 40.79188885227327, 43.26510798546576, 41.227593575754476, 43.51016982909172, 50.71128452977827, 61.97411944789272, 53.31481264483545, 56.63628747386318, 53.890114522749386, 53.00986013104839, 51.97878668385168, 57.97104650928129, 55.33755540847779, 56.245717463954804, 50.96728194144465, 54.059556991823264, 55.28296386041949, 59.5204847089706, 50.579026129937944, 43.42135560127997, 44.667571052428215, 55.17106648414366, 56.45033574873402, 55.03975729788504, 53.75974278296194, 53.66511560255482, 52.410757310928844, 50.49282812303113, 44.15779236824282, 41.594927464762044, 39.8703436697683, 42.298318263023134, 44.18777104346983, 44.32428129257695, 40.892940875022646, 44.147880538817375, 42.11862271831882, 43.621055233863096, 43.77682824288645, 42.15907019953574, 41.873505961510446, 43.84378310172789, 40.56008461982974, 40.52398704713391, 42.40356722185689, 41.760514243956536, 41.246797500118134, 40.491560812919374, 40.53751530185823, 41.55631565278576, 39.95241142088368, 44.621895051771595, 45.04031388990341, 48.23870082055369, 45.156059111318285, 43.11838388442994, 40.56087301623437, 43.05229194702641, 40.21189581963324, 41.017648712281265, 40.42517077538275, 40.38175798231556, 41.38305279516405, 42.30360954038559, 44.61892973992133, 45.68706566287626, 48.41834929681594, 51.249006179071245, 51.836710591470045, 55.32939687851937, 55.4151398904862, 52.27573756248721, 31.422805632314375, 2.446579375574666, 1.61705115870122, 10.55017065617346, 17.295859936744936, 15.092173334090942, 4.547236100319894, 0.17007700437980314, 0.39932112419797533, 2.050506035166402, 18.262353520239554, 58.210393459566184, 30.891620612913567, 32.27105936696453, 46.32361142866073, 42.45692714568108, 0.6555002519199926, 0.21595365878555084, 0.16132155403254494, 0.19648109803036337, 0.17036558970087962, 0.1367597639440529, 0.11796583451571004, 0.125134862328489, 0.1193939756241537, 0.17340879737129136, 0.0784402481851078, 0.11576851048777181, 0.08742452899534857, 0.12100466016319492, 0.07319962455620689, 0.21260950113496474], [0.07459587342436276, 0.0313494076216293, 0.026320042313947797, 0.11955964213777935, 0.01940007160057224, 0.07240127666943497, 0.014447063233913674, 0.10606801407712121, 0.07907342751540485, 0.04209125309341377, 0.04691457330820061, 0.04940123725382071, 0.056756382297363975, 0.02267150069406677, 0.03878894682613112, 0.04660557940482132, 0.02379277379312102, 0.05187785395631387, 0.02073008450679481, 0.031756893618993705, 0.1907174508537977, 11.316225240307471, 45.59715317141625, 31.446922325318862, 29.426529061409738, 30.907527785147394, 41.81220323808732, 27.767168398826357, 0.16760896020118268, 0.3743100388636512, 0.345159535326304, 0.14946884085093776, 0.0053847941941761925, 0.04947766218514693, 0.3019256084676712, 4.3416298685535315, 29.336428296181467, 53.18344854539441, 56.14065285651915, 56.34616936406782, 53.89681785337387, 51.404555612994784, 45.97792902300435, 43.763754983102125, 41.94051181116412, 41.5538602490579, 41.38635935321931, 42.61461034897835, 44.46453740519863, 48.102661255867254, 49.75046857710808, 50.23521077248358, 53.322826047097486, 52.208496370623195, 52.127373910719356, 53.20260147894583, 49.56301066183275, 43.54627524652789, 42.02918875601984, 40.32737824224657, 39.49803621538224, 40.39812603304463, 39.092443527713904, 38.25331518726964, 39.24774977468675, 38.65082779238301, 40.0686312490894, 39.29061343592983, 39.091784569524954, 40.362467765808105, 38.260191102181714, 39.45710236026395, 38.37697575169225, 39.193726970303445, 40.960633139456476, 39.937392665493874, 44.594705181737105, 51.82876386950093, 50.15730857849122, 52.3095444710024, 46.17811895185902, 50.76541323815623, 50.750869089557284, 53.15341495698499, 50.787221616314305, 52.011012877187426, 51.14194116284771, 49.872046362969186, 51.58063473240022, 56.116424375964755, 50.156779058517955, 50.64300390981859, 43.53633203814107, 49.624737001234486, 55.580514861691384, 50.71592861606229, 50.09055376052857, 45.985691393575365, 43.46518024321526, 43.077477485902854, 39.903585756978686, 36.69451821234919, 38.59435742901218, 39.435293982105875, 39.48265267956642, 38.0270375743989, 39.29562230263987, 37.65771896608415, 39.73588874263149, 40.40710041599889, 37.22154748055243, 39.11482849428731, 38.94007905837029, 38.85514797702913, 37.95244978320214, 37.24085338654057, 39.10331241546139, 43.39004332019437, 39.6187432350651, 36.29138485077889, 37.73015729842648, 38.04941861860214, 36.51019034847137, 37.51594881857596, 42.4464112712491, 42.73905538743542, 41.34273867453299, 37.765533155010594, 37.32682781834757, 35.64037338379891, 36.09633322684996, 35.67770650309902, 33.747064913472826, 34.914362276754076, 35.648496612425774, 38.34058792360368, 40.14805140033845, 41.75443849255962, 41.945818778007265, 47.19409127389231, 48.85486987329299, 50.34875162186162, 50.5967709325975, 46.035164248558786, 8.290825620774301, 0.16475857686131232, 2.1834410438614507, 4.533216568731493, 8.596496908895432, 6.293775852649443, 0.8596120606507025, 0.1544436626136303, 0.1204221192446928, 0.935536093048511, 24.064647074668642, 34.43253048004643, 25.943493766169397, 25.583251522433375, 38.51543149640484, 14.022617513133635, 0.19070975933103793, 0.14017685316503048, 0.041748279360153025, 0.07036643989023662, 0.0351983769947002, 0.02066848912246285, 0.01437749574711967, 0.001299833710354212, 0.010237728016481045, 0.02179398145076008, 0.10401871355791246, 0.05974549649944229, 0.04109658368472611, 0.07876212768737348, 0.033072038673825806, 0.0798040762123081, 0.03219222116674627, 0.05439088281784808, 0.02863535728876389, 0.06943317625911967, 0.04684714990998468, 0.03985188616019103, 0.04418715474105651, 0.03751730215885947, 0.03260435348737144, 0.029478500251688307, 0.054985202338186004, 0.06814768838305628, 0.023246888266575914, 0.022609137306590716, 0.05004248732040006, 0.03904243382895666, 0.03681499871515459, 0.03884752956970085, 0.047340357315636454, 0.0500909615338089, 0.48624663884120606, 19.483740368197044, 52.6471350269933, 32.53597036484749, 38.07337253324447, 40.15143248342699, 47.1192563733747, 30.180124236691384, 0.14442916208457562, 0.6102690725557266, 0.5257146613251779, 0.15736818794281254, 0.14790620534650742, 0.2631144910570114, 0.8638923471012424, 5.503130459016369, 31.463174666127852, 52.623388997970096, 53.95715567373461, 57.9595971107483, 55.52724515238116, 54.72303375121086, 47.59101160110966, 46.77801409075337, 43.70539795967841, 42.94349716555688, 42.64583241554999, 44.18509206464214, 47.168176174163825, 48.09405165333902, 49.95707550356465, 52.73942447477772, 56.06751241991597, 54.24013114744618, 53.929624557495124, 58.481593978020456, 49.722506000149636, 44.324375429461085, 41.90432010158416, 41.36992462219731, 41.67109204876808, 41.709986271396765, 41.47436165040539, 40.88685335651521, 41.66855427526659, 39.70894990428802, 42.03719823591171, 42.303448723208525, 41.84113856284849, 42.38135091720089, 41.084026982707364, 40.984685113353116, 41.61843422920474, 42.03386422126524, 42.20846852948589, 40.75754850141464, 46.67215716454291, 54.4370262853561, 53.21449410530829, 52.28219378379084, 49.742223755005874, 53.130904474566066, 53.61758432080669, 54.26317114983836, 52.52365881396879, 53.8937113361974, 50.82457434746527, 53.430224464785674, 54.367149260736284, 57.077393301071666, 52.26837527367377, 48.423385620117195, 48.9706660855201, 52.828842747596006, 54.77307927223944, 52.7204558926244, 51.92742716881537, 48.9602953387845, 45.67470627446329, 45.540149365701986, 42.588652103177964, 39.059083769398356, 38.15964506518456, 39.90975956762991, 40.39494106846471, 39.568399613903416, 40.30936279604512, 39.214425317702755, 41.479931416050086, 40.983567237854004, 37.1270065922891, 41.37328217106481, 40.33329317646642, 40.23972111363565, 37.552022857050744, 39.51059172230382, 41.45099609128891, 42.05853985201928, 41.8113834627213, 37.86301974327334, 38.80032500913067, 40.04102168544647, 38.33857182533511, 40.42981486166678, 42.91301642694781, 45.21153711503552, 42.27800038553054, 40.19118570512341, 38.84777784347534, 37.13242338549706, 37.379924943370206, 37.93386167095554, 36.20996429074195, 36.836182455862726, 37.663053389518495, 40.787629158266135, 42.99429970402872, 43.014331248498735, 45.06458943889987, 49.33850203790973, 50.6529628076861, 53.100062877901145, 51.58958165876327, 48.84189467276297, 11.318042278289797, 0.4923299591868155, 5.100223614323524, 10.41630800693266, 11.382215196086515, 10.993476933048619, 3.2257138384926707, 0.28494021344569426, 0.10584431640323132, 2.086075313629643, 27.481525713397613, 42.57028364366101, 28.341515179603334, 24.473954246890163, 44.99046448738345, 20.065008171143074, 0.12119726232823827, 0.026314526480892976, 0.0565738886624815, 0.09306538759941056, 0.03700835930724298, 0.02601667915681197, 0.004045394795661372, 0.005756939597983635, 0.02241756552980552, 0.05994592808307179, 0.045127125471950545, 0.015804453249720317, 0.04387218918230745, 0.015228516966735405, 0.017224469995726983, 0.08164697732295721, 0.15786712568613792, 0.14956673156590233, 0.1298973475012087, 0.2958869663698058, 0.21905343438829147, 0.2132673255137859, 0.14671893760321603, 0.14836441785577806, 0.15308685961269564, 0.17697561081619034, 0.32135782703276605, 0.1875685690151107, 0.11631500696943653, 0.10976484796452908, 0.1915455918999449, 0.19328137859702113, 0.09698222661691328, 0.1307254885473559, 0.11859035705246272, 0.1628538218116568, 0.6276172255316089, 22.729205546840547, 59.72226712011523, 41.01560515742148, 39.90659029253068, 41.403464809540786, 52.78832466371598, 36.00598142993066, 0.29162384028876986, 1.1588244308387081, 1.2478576985097702, 0.5112762328597807, 0.3854462912967129, 0.40418170692939914, 0.6474582286130998, 6.080189558767504, 33.432059364934126, 53.32938032765543, 56.24419558432795, 61.028557592822665, 58.34082795727638, 54.854193887402936, 48.41307763130435, 48.43886721518732, 46.57089333380423, 46.00049441860568, 45.567460829211825, 47.426652523779104, 49.705106366065245, 52.166687826956476, 53.761825561523445, 53.989672122463105, 57.13609941544072, 54.44975045419509, 55.84321560398225, 58.34260086859427, 52.97903814623433, 47.46474658289264, 45.19261560132427, 44.896233466363725, 42.60633807028494, 46.04192641473586, 41.912608069758264, 42.82744599926857, 43.253333030208466, 41.7866882201164, 44.703598022460945, 43.35243563498221, 43.51093076890515, 43.62370283372941, 42.8230490223054, 43.13954114913941, 41.945159819818315, 44.587217377078154, 44.482031176167155, 43.868690152322095, 47.76556884088824, 56.314496224926366, 54.157129872229795, 54.98152579030683, 49.43695745160503, 52.49232692103232, 52.45818661105249, 55.929405766148726, 53.294286881723714, 55.491516282481534, 53.313910499695815, 53.9852241546877, 56.577620583195845, 61.43673512243456, 50.38003252398584, 50.64363933378651, 48.598354708763864, 52.57542233313284, 57.5300112847359, 54.89193101083079, 55.41760313895441, 49.76757403342955, 47.90709187907558, 46.97472095489503, 44.85024367609332, 40.34053779417469, 41.76606439775036, 42.876252051322695, 43.43761774801439, 40.711899957349225, 43.783100112791985, 41.413863012867594, 44.24176639126193, 43.41524062618133, 38.85724644507132, 43.29147415776407, 42.49509180745771, 42.144741781296275, 39.850602380691036, 41.25652497814548, 42.28001256142893, 45.28469324111939, 42.76300145733742, 39.61958262228197, 41.61654756915185, 41.703428068468654, 40.920542593925234, 40.96851710350283, 46.290447788853804, 46.53931433154691, 44.92123857621224, 41.2903554208817, 42.03495464017315, 39.380725968268614, 39.51050150778986, 39.3479702549596, 38.456905811063706, 39.22374486923218, 40.13604110287082, 44.18314656903667, 45.03885084582914, 45.54488758887015, 47.14268861278411, 52.80343363361975, 53.194588076683786, 55.82275259879328, 52.52627503487372, 48.70732991926132, 12.378194216758976, 0.552483550723522, 7.581313473563041, 12.159099444266289, 17.389233919882006, 13.939182816013215, 2.073939745464633, 0.5126327907125796, 0.31864749988721264, 3.74567965345998, 32.39841872645963, 45.671740962613015, 36.306670327340406, 32.923814327486106, 51.98969871767106, 25.01386653992438, 0.293968191911136, 0.2317801159956763, 0.18852985614249784, 0.2392995600859004, 0.12793352707259117, 0.1432503366302098, 0.10239751063167088, 0.13333331312864058, 0.14589333996897744, 0.08386683199674853, 0.2445948977143534, 0.17966497779613544, 0.12402528356159888, 0.180855784865637, 0.17219077885871933, 0.23867493795771755], [0.057090469410703074, 0.035330638244387605, 0.016665938272771817, 0.06690929959257765, 0.0197176514343629, 0.02410614014332814, 0.013381061463376448, 0.046467982352741306, 0.028775618411600593, 0.04231482819323579, 0.04730805904874879, 0.07621521475694834, 0.04508539666271499, 0.03371529589076677, 0.021591908523752805, 0.022018602260598735, 0.019326391179234754, 0.014968425328392657, 0.0214251943848907, 0.08100891035170325, 0.11232463883296137, 3.2826595440987623, 39.985469156695956, 46.136055454131096, 18.226299093615626, 31.272637690267256, 37.30793376122752, 44.37391496473744, 0.8321172263353103, 0.48059750648756183, 1.27943302354505, 0.15651717151124633, 0.04645883909336502, 0.37413926254357066, 0.347970373207523, 0.48403705740647934, 6.068559240910315, 34.17049261831468, 56.08152312617148, 57.08234333222913, 55.87776384046001, 52.248182912026685, 50.78728045186689, 43.498936160918205, 42.49915538295623, 42.04022630568474, 45.00305137326641, 45.985726694906916, 47.949735887589, 47.99876551474295, 52.32834831360848, 52.247841665821696, 53.747352015587595, 52.44583506737986, 54.916092811092255, 53.674293948758034, 49.74335731998567, 44.27446326901836, 38.936517546253825, 39.62221453266759, 39.88100467189666, 40.506532499867106, 39.3085818136892, 37.96191446242794, 38.946468599380985, 39.15928463782034, 40.71528888517811, 39.960742535129675, 39.85863539480394, 40.874846981417754, 37.988202187322806, 39.58396750111734, 38.844863522437315, 39.5738713202938, 41.49836655585997, 39.61558180470621, 43.87223597495787, 51.36976811193651, 50.71049221100346, 53.479426676227206, 47.74013227032077, 50.005705048961026, 54.433413782427394, 50.145317892874445, 56.713613079440215, 52.69789049702307, 54.1849983123041, 54.16264472469207, 54.851373703249045, 56.23609981229229, 46.216016892463934, 57.167392084675456, 42.98930652679936, 48.94573157833469, 52.451455823836795, 49.245267298913774, 47.30024630023588, 42.76734744348834, 43.98649069570726, 39.02165259084394, 38.891214170763575, 36.88814993827574, 39.2468084058454, 36.787282266924464, 40.9785387592931, 38.2356252977925, 38.14165707557432, 37.508574762652, 38.93825515624016, 37.1329293712493, 37.12457080041209, 38.07344705827775, 39.06050758977091, 38.24880838394165, 36.54621731850409, 37.55918118261522, 44.33276537925967, 48.31931337233513, 48.34487938111829, 41.005508976597945, 37.032795183120236, 38.8693626465336, 35.99810923299482, 36.983302716285955, 40.109290538295625, 39.47687895067277, 38.240328219629106, 38.91762741150395, 36.81258939927624, 34.501164113321614, 33.82574765912948, 33.60350616516606, 34.06910327173049, 33.99223658346361, 36.01233174723964, 36.52787631557834, 39.72173683104977, 40.72392594429755, 41.848351801595385, 46.95902362946541, 49.3486923556174, 50.28935909271241, 50.70821723630352, 33.98383878892468, 1.7476586084212027, 0.8624719588025924, 2.8266009063489976, 10.641973730056517, 12.327072985710638, 8.762058192683805, 0.6673020508981521, 0.17065215254983596, 0.045778438103415316, 5.198053409976344, 34.06880517159739, 26.95295887608682, 25.292854924355787, 24.070105052763417, 39.04226856846964, 1.6159020268147992, 0.09147518825146461, 0.07052072999818672, 0.04697673751281635, 0.014533589034521533, 0.02095399285486389, 0.05953987850056541, 0.05045145569789795, 0.043023827245398875, 0.0417215543829145, 0.06948082692800991, 0.011606779805715046, 0.019716711061435844, 0.007071307073572591, 0.03952234960912217, 0.0412561712906726, 0.02480287029738388, 0.01453256822236243, 0.04529736170004453, 0.026022104974535686, 0.0745166139677167, 0.027429075243191856, 0.04864186025975693, 0.026947581321902336, 0.047957161516552015, 0.06823740493986877, 0.025368093798357635, 0.023358568564177524, 0.11086279751672862, 0.0467782479620749, 0.04536230680382541, 0.02959484027908935, 0.04677087053536408, 0.025894922887786262, 0.025062399818712187, 0.05381343255360281, 0.10885847401955437, 0.0132005050733325, 6.443499095978276, 48.48016585073164, 47.47938486837572, 21.434809661680653, 41.96891761595204, 43.299652299573346, 48.17795507369503, 0.6691357589537098, 0.7378893309543211, 2.1899617391247905, 0.11314138049079527, 0.028787262948049657, 0.7372161541734973, 0.7134103702922022, 0.5783627362501237, 8.396771780906185, 36.91450042109336, 56.70082223030829, 55.74836877084548, 59.9354204823894, 54.39444503476543, 53.69885583077708, 45.32507404204338, 44.941623133997766, 43.86962367642311, 47.090666217188684, 45.99874111913866, 49.979209438447036, 49.92267239478327, 53.59683498259514, 53.42392121591876, 56.928747238651404, 53.88197560464182, 56.882890808966856, 56.49226980824625, 51.65983130854946, 44.827490006723714, 43.61632485543528, 42.53473912515948, 41.85830285472255, 41.022128059018044, 41.836655293741536, 40.64914595696234, 42.08722414508943, 40.80620550340222, 42.53671207735616, 40.88420967901907, 41.426591104076756, 43.25510986389653, 41.23004505711217, 41.15616329254643, 41.94572464112313, 40.29768982241231, 43.394318703682195, 42.15746987250544, 45.841979672831876, 52.47370350745417, 53.464188268107755, 55.4577721318891, 48.93343494784448, 54.513763535407286, 53.43220918409286, 51.9546405730709, 56.54127197880899, 55.05857682997181, 55.75687246937906, 57.37279484348913, 56.33847759615991, 57.11268678788216, 50.07211862071868, 54.86466661576302, 49.29224944883778, 51.64636973411807, 55.87903468839584, 51.07590021625642, 49.48266483122303, 45.57783157594743, 45.739021378178755, 41.79785520799699, 40.79579161059472, 38.95780032680881, 39.996185072006725, 37.77687664954893, 42.23189684652513, 39.268958030208466, 39.94873616003221, 39.74754602678361, 40.729068171593454, 37.94304001715876, 38.96808085903045, 39.385252383447465, 40.45550638629545, 40.63180123606036, 37.92565607255505, 38.32034457114435, 44.658082838981386, 49.65374685102894, 47.45090061618436, 42.952055777272875, 39.56642273933657, 40.1767356934086, 37.50460924640779, 38.70996928984119, 42.07497066067111, 42.10475321738951, 40.84421327037197, 41.93172962434831, 37.82109352850145, 37.70576407832485, 35.91135817189371, 35.348745161487216, 36.56834340864612, 36.79297362604449, 37.83678300919072, 37.63036435650241, 41.871297667103434, 42.963787586458274, 44.247642101780066, 50.72407930128036, 51.22966497175155, 52.50634154965801, 52.10240410220239, 36.60481752887849, 2.5311042464548543, 2.661731185451631, 8.996922854454287, 8.86082543480781, 10.198443878081537, 9.88335301799159, 3.215997146983301, 0.21046831603011779, 0.11990969835390007, 6.280651111756602, 38.1498783634555, 33.99954788146481, 29.618697743262018, 26.207708543346776, 45.761661298813365, 4.247551819970531, 0.18725015223026278, 0.04602127648409336, 0.020454160703886903, 0.0771868517321925, 0.06855188403278589, 0.049060289823119684, 0.02699979212916186, 0.006431182198632028, 0.07878824362471219, 0.06599374791427005, 0.01741613178784328, 0.012312327631779257, 0.027381022378141363, 0.0026802869228225563, 0.036045547664886525, 0.02634032449174312, 0.12854681109949467, 0.13197752136376598, 0.07294484669522894, 0.21934010448955724, 0.11652398043342176, 0.23495781806207475, 0.08219590996422114, 0.1831176747838336, 0.1261620943043982, 0.1346238342023665, 0.08305730688716136, 0.19258111294719482, 0.23713568345673625, 0.27061924158084777, 0.1296105241823581, 0.1505302097047529, 0.09208331650663769, 0.22432965046215445, 0.11465221312978577, 0.32489978858540136, 0.26306579850854417, 8.736890304473139, 55.52193818553802, 57.80940955685031, 28.28078708341045, 42.61840720330515, 48.03907963537401, 54.454057216644294, 1.5999534245460265, 1.4493542669280883, 4.3457856197511, 0.7811243303360478, 0.24530377419244861, 1.3530666981973958, 0.6018103587050593, 0.9043133523195022, 8.346445810410286, 37.22957657229516, 56.86457726263232, 58.013996462668146, 63.13973803674022, 56.26946741534818, 56.980498990704945, 47.705234942897675, 48.067505052012784, 45.6303011217425, 50.17116631231001, 49.5174523322813, 52.11617554387739, 52.85986085091868, 58.118362888213134, 55.099773483891646, 58.53057261436217, 55.970394534449426, 59.33556456719676, 57.28936602992397, 53.39459365414035, 46.55044601809594, 45.77708798070108, 45.14285641331827, 45.22235501197077, 44.78283774468207, 42.67525019184236, 41.975644480797556, 44.86392098088419, 41.74771947245444, 44.982215742911066, 42.041807020864184, 43.89513869439402, 44.73809134575629, 43.81665991198632, 43.59315149245724, 43.43685288583079, 42.22471106436945, 46.4368071094636, 44.93258991549092, 48.21972439366002, 53.88147354125977, 54.213898335733724, 55.59374501628261, 50.940201897774976, 54.07062592044954, 52.63543851913945, 51.79803209920084, 59.57536259005147, 56.24443484890846, 59.44873279140842, 60.4504551426057, 57.43585478874945, 59.243388868147335, 50.429893693616314, 54.40689856006254, 48.72166618224114, 52.27035607061079, 55.74888260133805, 53.57875285610076, 50.72126696186681, 45.446373339622255, 46.44217683422951, 45.041729865535615, 43.59433997061945, 41.67269629816855, 45.21712649253107, 39.346640571471184, 45.93814442234655, 42.66291433765043, 43.12717783835627, 41.81321913196195, 43.040968064338934, 38.98630026848086, 40.65097378146264, 40.181995591809674, 42.38197849642846, 41.978088117414906, 39.60431283520114, 40.47701666432042, 47.938035457364975, 53.51104882455642, 50.671464627788914, 45.9130883216858, 42.295980530400435, 42.24972794132848, 39.633605095648, 40.33037885542839, 44.269591685264345, 43.22181678587391, 42.6143632396575, 43.8446460231658, 41.8966204889359, 39.054678947694846, 38.16651313535629, 37.68188861108596, 38.98662582520516, 38.2448624795483, 39.337383777864524, 40.48031537763534, 43.672740305623705, 45.23090970131659, 45.658259776330766, 52.73942447477772, 52.96880076008459, 53.596117188853604, 50.81149716531077, 37.956787924612726, 3.2040248474767132, 2.588335059342846, 9.240976648945963, 18.82779455954029, 21.77168634630019, 21.352322216956846, 3.0694684290116836, 0.3698730108238036, 0.25268921418295753, 9.944642993711657, 45.2070067774865, 39.01320772786295, 37.67002736368487, 32.24547374633051, 54.15624733894102, 5.138857489632023, 0.2447534472711625, 0.21374295886245467, 0.12832561087223793, 0.13847748628787457, 0.17783494696261423, 0.1298686038822897, 0.13105890533376124, 0.10108583787035558, 0.13421782292425632, 0.17301564104855063, 0.12304154239715108, 0.10520287098423128, 0.07304456836033253, 0.08388279726909054, 0.11976477750126394, 0.12246058728065222], [0.06398962359995612, 0.006993699972818216, 0.05986978660427755, 0.023868084066517414, 0.08947661041372246, 0.0022590357618736887, 0.050545604073352395, 0.016955077092373566, 0.02216065219873863, 0.03368930252749593, 0.11936615131074384, 0.03313291202028913, 0.11080054521200158, 0.0858808235235272, 0.045522281284173655, 0.023424873474024, 0.049632772007175995, 0.0823419799487437, 0.08888780289599973, 0.05653634652375214, 0.10388604245118557, 0.2814286502618944, 16.344352749086198, 42.402555250352435, 26.433664521863385, 38.742383756945216, 28.4619652840399, 41.85356855392456, 8.011501383396888, 0.2485283761615715, 2.227545644967787, 0.09476102362837523, 0.21873872546899706, 0.45449591031478304, 0.6741975776610837, 0.2662498744264726, 0.6506742044321953, 12.532891515762577, 51.61901512453633, 54.1088572625191, 57.53689112201814, 51.93470708785519, 49.610032035458474, 46.372652822925204, 45.82295225512597, 44.03516338717553, 43.50684758155577, 47.116408732629594, 50.14391760672293, 51.09712023888865, 55.537651200448316, 51.7378786302382, 51.05466842651368, 52.01324862818564, 52.99016198804302, 51.64529892706102, 49.41973824654856, 44.88458794932212, 41.39774991619972, 39.30578124138617, 39.48971686824676, 40.69889337785783, 38.93598018154022, 41.04552107472574, 39.42067138610348, 39.75210774329401, 41.462641608330514, 40.825142706594164, 40.398604562205655, 40.9605586144232, 38.769040184636275, 39.334834237252515, 39.00641810509467, 39.768452259802054, 38.91825891310169, 38.454391571783255, 41.258654825149044, 49.097774413324174, 49.470591775832645, 53.59073961934736, 51.784954917046335, 42.80056207410751, 59.76009445805704, 47.889252939531886, 53.7466852126583, 55.148571691205426, 54.831675560243674, 52.931298978867076, 49.99423996094735, 53.85544469279628, 47.503742787145804, 53.32206902965423, 47.677331201491825, 50.32069883038921, 52.559160186398415, 46.87477111816407, 48.38460122385333, 43.02480789922899, 41.60402344119164, 40.58184592954574, 38.73014596200759, 36.61501961369669, 38.4604202547381, 37.98059671155868, 39.3807848038212, 37.13334122011739, 38.64448531981438, 38.223371813374186, 38.77879904162499, 38.114337767324145, 39.69770054663382, 40.27545390590545, 35.97250792288011, 36.66009156934677, 36.180538669709236, 38.71574301873484, 48.65966919929751, 50.862578192064845, 50.09433884774485, 48.73733605107954, 42.87114904772851, 37.064221212940836, 37.21736231157857, 35.78333200946931, 36.88836174626505, 37.28119888613301, 37.76099497272123, 35.97922694298529, 37.11640442571333, 34.36334379257695, 33.67619160682925, 34.41890808843797, 34.63872948000508, 34.185801629097234, 35.50644405426518, 36.01612860156644, 38.1032923729189, 40.179606868374734, 42.348536368339296, 46.65177260675738, 49.83258731903569, 50.829940149861, 50.03502084362892, 16.48114246706809, 0.24658853428498392, 1.939983817358171, 6.885792911052705, 9.72117183669921, 7.174787752089962, 8.48127434330602, 7.161966504589205, 0.17255425693527346, 0.21033889313618984, 15.731605964322245, 41.5870709573069, 28.271993129484116, 23.373219505433116, 32.571846323628584, 20.788726652822188, 0.12069678474818507, 0.018031306136699937, 0.04174430719426563, 0.0880763549057226, 0.04551566994538711, 0.02261482742464831, 0.11443254507837758, 0.0359264899405741, 0.005410152662079782, 0.048696294637216676, 0.012030080730666318, 0.0730502910371269, 0.01131212515305848, 0.0276113313908178, 0.10114754625265637, 0.04139141262238545, 0.04281560454757945, 0.05133321906830515, 0.03479750616656196, 0.00704383276658313, 0.04118377598182809, 0.057259001093165535, 0.002264824513751533, 0.032975890808888984, 0.008472307123273851, 0.06464271355540523, 0.03005604053126468, 0.012422478626362018, 0.032502708941577904, 0.07453103174245165, 0.0604852807948426, 0.03314792734360503, 0.04184156588669266, 0.06291557599099414, 0.1013710524045652, 0.05349776219396342, 0.058507249435229655, 0.03241096991264532, 0.7921775081946004, 27.646567283138154, 54.03703474229383, 22.55087302577111, 41.72730353570754, 40.50161384767102, 46.66145693871283, 6.399815169072921, 0.564153889013875, 3.0832060402439487, 0.0973287052024276, 0.45411568555620413, 2.2202056646347046, 2.822792284911679, 1.0149618827046887, 0.5935807970743026, 14.793882966041567, 52.96928321161578, 54.56378159984466, 58.38205206778742, 55.41883084081835, 52.36086476233698, 49.07189853729741, 48.86895902695195, 44.64900647440265, 47.19316167216147, 50.25781931415681, 52.249802850907855, 51.81993853661322, 57.21341717627741, 54.14815156690536, 53.34474425162039, 51.687950780314786, 56.39889778629426, 54.855099954912745, 49.91702025936496, 48.204952747591086, 44.28372006262503, 41.117520101608775, 41.356780759749874, 42.21800381137479, 40.2868091675543, 41.44173929768224, 40.80358143775694, 41.45855449861096, 44.43718671798707, 41.51794702776017, 42.878303450922814, 42.032052086245635, 39.26811472062142, 41.53043193201865, 40.5229123177067, 41.43278844894902, 42.0181708182058, 40.83748248315627, 43.41413451779274, 51.150939080023, 52.79394149780274, 55.5873711647526, 52.39686819814867, 48.761533152672556, 58.18433715451149, 48.16438759526899, 55.7732169858871, 57.09432225073538, 54.45584581744287, 54.057540893554695, 53.86794920890562, 54.68442193923458, 48.40440919322353, 57.12650137562906, 47.16552857429751, 51.14254913022442, 53.92415285110474, 50.96709759004655, 49.09454238030219, 44.667410235251154, 43.79301194221743, 41.80150693462741, 42.00528975455992, 38.67291465882332, 39.655189898706254, 39.88908475445163, 41.08625488896524, 38.470900827838534, 39.833755800800944, 40.3217339515686, 40.036228549095895, 39.627411673145915, 40.265997071419996, 41.37856168131675, 38.545084614907545, 39.566567867032944, 38.59801700038295, 40.70853456374138, 48.97646334863479, 54.216926405506754, 52.67066140328684, 49.784263718512754, 44.22518653254355, 39.610212079940304, 38.50910471331689, 37.75805319509199, 38.11849940207697, 39.42287575814032, 40.80243218329645, 37.00892756062169, 37.014948398836204, 36.577976749789336, 36.87966585159302, 35.628955364227295, 37.304474230735536, 35.9514840187565, 37.08242101054038, 37.18766212463379, 40.73440651739798, 42.73252464109852, 44.148166871839955, 47.3459929035556, 53.882732622085086, 53.74316684661373, 52.375118655543176, 18.626935866571245, 0.8227725471219709, 5.494259528575405, 8.988475049695662, 10.400183143154269, 9.74339206372538, 8.022998340668218, 5.190191509262209, 0.24814248235235292, 0.04103124787610385, 17.388408260960734, 43.151571058457904, 34.06737742885467, 26.773569276255948, 35.285457718756895, 29.635042259770056, 0.1423436562500654, 0.05520364464891534, 0.03130188910290599, 0.08007271260383629, 0.02296841339088015, 0.06201408968697633, 0.06906771401484167, 0.04432394740081603, 0.022296673024914438, 0.045089495233109886, 0.012881210160201356, 0.045584797889234564, 0.05898235801367029, 0.019649860313943317, 0.0107248478959645, 0.009454863724268733, 0.051860233934055415, 0.15319567474146045, 0.13625161782387765, 0.1385775526925441, 0.09649119490096647, 0.2908114806538628, 0.10721823380839442, 0.28180332854390144, 0.11448309922050084, 0.20975007795758788, 0.11775427167454075, 0.30440089983805535, 0.11220817048583301, 0.5316889213938867, 0.2035301947785962, 0.1910810668261782, 0.11351595152049296, 0.23827214424888934, 0.2676446141014176, 0.19113106172411673, 0.16094290741509007, 0.172749042450901, 0.6293457037498874, 28.759900677588682, 60.70797443389893, 35.296385442056966, 50.29774512014082, 38.84380448249079, 54.77037283682055, 10.013455094829684, 1.056278843072153, 4.604489466836376, 0.608769562696257, 0.7152874082807572, 2.576795691444028, 3.4263442985473143, 0.8244415156302914, 0.9697104173321879, 15.26516947054094, 54.925345682328754, 54.76263400047056, 62.780084148530044, 56.33581430681291, 53.81590327908916, 49.993796733117875, 51.69381864609257, 46.889758494592485, 48.66734135535456, 52.79822080366073, 54.94265902426935, 53.739326846215036, 60.93482471281483, 55.33495487705354, 54.0418984813075, 54.49485378880655, 58.16429776530112, 57.28808341487762, 52.97710049536921, 50.42130762530912, 46.09311726785476, 43.23941646083709, 44.12432278356245, 44.66622175708894, 42.67597975269441, 44.16454276730938, 44.06161977398781, 43.098995608668176, 46.3000262168146, 44.27075662920552, 45.41882261153191, 43.6774157708691, 42.23037888926845, 43.272156484665416, 41.676814786849484, 42.91427550777313, 43.274443226475874, 42.6891157704015, 45.47470854174706, 51.5987874615577, 53.216490591726, 56.44485619760329, 54.48617358361521, 49.75783086592152, 56.96258944849814, 48.616609419545824, 57.46584915345716, 59.619599080854854, 57.45561176730741, 54.62644538571758, 54.560420128606985, 57.48105226024505, 51.934354074539684, 60.1899548499815, 48.674887995566095, 54.05305370207756, 54.59339549464565, 52.85350661123953, 51.14566741451141, 46.676816940307624, 43.74797921026907, 43.627758564487586, 43.955194104102354, 40.89929903707197, 42.95994758605958, 40.95015648872622, 43.275584636196015, 40.22523580058929, 41.315827292780725, 41.34064805123114, 41.76433463250437, 41.81594517923171, 42.945674081002515, 42.99392315649217, 40.22300789433141, 41.41139191965903, 40.231519437605336, 42.812305650403424, 53.197886789998705, 57.250683615284586, 53.415978416319824, 53.25419633619247, 47.8924810501837, 41.48837627903108, 40.32680557620141, 39.524829926029334, 41.08931433769965, 40.8292886518663, 41.821679684423636, 39.84096511717766, 39.909124143662, 38.387146457549065, 37.83171138455791, 39.06087237019693, 39.62202233652915, 38.26982052095475, 38.048037944301484, 38.81047610313662, 42.87909184732745, 46.657722842308786, 46.001294582120835, 49.80109853129233, 54.83495466170773, 55.52646460071687, 51.457107528563476, 20.20693913582833, 0.6915419308408615, 7.600046713506022, 12.847298902849998, 17.942917654591223, 19.433355562148556, 18.4477541523595, 16.763821801831646, 0.40985645726323133, 0.2727327862333867, 21.1211298742602, 52.645499398631436, 40.55168290292063, 32.66077626136042, 42.937990157834946, 34.963744917223536, 0.23418812952455015, 0.09935037293020757, 0.1511193313185246, 0.17746256694437998, 0.07209154732164837, 0.14295310983734746, 0.1990516141297356, 0.1433027370442306, 0.07997919625091938, 0.09051898794789469, 0.1810520106265622, 0.22016680529040678, 0.1562947915085862, 0.1880864597736828, 0.15164243147498177, 0.1065084073812731, 0.1716086286450586], [0.06099572134835105, 0.03312448888356167, 0.029171237707017895, 0.016103068576945413, 0.030473556534777728, 0.07351606483421019, 0.13131499320508974, 0.02916977447908252, 0.06737856675059566, 0.035951920229220585, 0.02119312528520823, 0.08000021770356164, 0.05355265239373811, 0.04649846116080881, 0.06730452435271395, 0.028386095260840752, 0.07849553675060311, 0.07651621836327738, 0.027689162093485077, 0.04174482430361452, 0.0856618143077339, 0.0463743242735584, 1.2002623105241408, 32.30672744012649, 39.20423107762491, 28.802664318392356, 35.90130121477189, 43.52464729739774, 24.87050194894114, 0.14391189951810146, 1.260139129815563, 0.141197879828753, 0.037394804699767026, 0.9552695373854331, 1.5591154223488224, 1.133248003259782, 0.0760521989075407, 1.8885523513440166, 27.194737695878555, 55.13231738921135, 58.93770287113806, 54.77700556478193, 54.9788389667388, 50.72630720753824, 45.80558400000296, 46.319257597769464, 46.884176961837284, 48.425491932899725, 51.095931760726444, 53.02216068390877, 55.01153192212505, 54.1964751674283, 52.70132257092384, 53.187029669361735, 53.86976526629541, 51.40406139435307, 49.142179566044966, 46.41756788376839, 45.633266433592766, 40.852340421369, 41.77751379628336, 39.760835016927416, 40.65959907347157, 39.25486103180916, 39.52113505332701, 39.347099488781346, 41.080332110005045, 40.522755422899806, 41.182772651795425, 38.850433288082, 40.672389922603486, 38.47723545566682, 39.37756061553955, 40.61638239891299, 39.73026014143421, 38.06245657705492, 40.19601806517571, 43.81181186245334, 49.532263202051965, 50.86674374918784, 55.75113404181696, 39.974510054434504, 52.51603764872397, 51.01018874875961, 50.1191556838251, 52.973931220269975, 52.56085465031286, 55.15624776963265, 53.65317590775029, 52.9215754232099, 45.93838760929723, 35.62054580257785, 57.16135947935043, 56.286988642907914, 51.44332431977796, 48.17537023175148, 45.35922611913374, 43.456558873576505, 40.853022913778986, 38.2768690201544, 41.941684599845644, 39.110196175113806, 39.05238828351421, 39.91992635111655, 37.255625032609515, 37.3701503969008, 38.9459430017779, 38.523793989612216, 38.4014944876394, 37.36472183658231, 39.448433922183135, 39.98159385496571, 38.09189788756832, 36.00127066335371, 36.324603403768236, 40.8269509192436, 49.85242666736726, 50.12339968835154, 52.65139472100043, 49.038385806545136, 49.96105278691938, 44.251603695654104, 39.15753918309366, 34.873044029358894, 35.920909143263295, 35.17393296764743, 37.293334699446156, 34.944015395256784, 37.69878618178829, 35.800672808001124, 39.547701266504106, 40.18419604147635, 39.491183834691206, 40.88089135385329, 40.1908052352167, 37.37439047905707, 40.81359132643669, 40.63521762048045, 47.626006987787065, 48.97145055955457, 53.37740975041544, 50.71828988290603, 43.283998120215635, 3.314848965214145, 0.613272259792974, 5.57038979184243, 9.163820685878877, 5.809032676681396, 7.82703721715558, 6.393489366577518, 3.8038753694103615, 0.18216262361215008, 0.5025061195896519, 35.29177665710449, 31.508095610526304, 28.07439784849844, 34.977653641854566, 33.94030048001197, 8.158702542704921, 0.10321887946056743, 0.07067095217925888, 0.04066342608101907, 0.034788650190157276, 0.0201342289801687, 0.026161488926699086, 0.041884964767603144, 0.04168859344997233, 0.04356660437019121, 0.06631905949043651, 0.024471516202714656, 0.06626393946428454, 0.019639052728551532, 0.0038705160747462466, 0.05357309544999754, 0.048222656947590654, 0.023195569951748176, 0.03212113969869191, 0.03810167785794024, 0.08759959540780514, 0.053565549483943375, 0.05123775302162094, 0.0457374677212248, 0.08316665061659391, 0.02339571233718626, 0.06978353124953086, 0.021997651671089476, 0.04702798879495071, 0.05409198212287119, 0.02325845810945236, 0.047826577999418786, 0.015014037245794412, 0.01991986608763616, 0.04171393180806791, 0.01119838790938018, 0.09106026737079506, 0.01957483540829872, 0.040024052929854205, 0.023289743225060167, 3.723294932034708, 41.341801228061804, 40.31449717860068, 30.445749105945712, 41.034993433183246, 48.98287642386652, 24.87337116272219, 0.4309309538333647, 2.9366456981628173, 0.2616114571930901, 0.14611925929784775, 1.7028571737389413, 5.225415864298421, 3.2936632633209233, 0.2581750012693867, 2.124875154226057, 32.23655035418849, 53.46403137330086, 59.498637107110795, 55.62469251694218, 58.12172043708063, 51.671598419066406, 47.85282981011176, 47.56803827901041, 49.53906066956059, 49.951078199571185, 52.92166171535369, 54.096996015118016, 56.57097216575377, 56.02453500993791, 53.61545055143295, 55.65201182519236, 55.5326384113681, 52.4722404633799, 52.1092604052636, 48.08829753629623, 48.931614968084524, 42.944964132001324, 42.34157023891326, 42.080909129112, 42.83011713335591, 40.42633179695376, 40.88439010804699, 41.16151340546147, 43.800640952202585, 42.210794494998076, 41.17799520492554, 40.9974955743359, 41.2961369945157, 40.548435180417954, 40.69988965988159, 42.07825368450534, 41.26759782914193, 39.936780775746996, 40.847908143074285, 46.114858965719904, 51.1773640878739, 54.17543165145382, 55.81057363940824, 44.47232723236085, 56.10241759207941, 50.659269978923184, 50.92570089524793, 54.417567406931234, 54.988633125059074, 55.183763196391446, 56.268404453031486, 55.37156235787177, 47.1396017074585, 40.253751431742025, 54.939215183258064, 55.79169134939871, 54.04150624429026, 51.77697289374567, 46.08708858489991, 44.86386606770177, 43.64354610443116, 42.070456012602776, 43.846979833418324, 40.9909922845902, 41.845766959651826, 42.23042203534035, 39.095299013199345, 38.164916730696156, 40.411509160072576, 38.87746626330961, 38.54202516617314, 39.61857849551786, 41.345562781057055, 39.950905230737504, 39.350719836450395, 37.0773886096093, 37.030708482188565, 42.739349565198346, 51.94008857973161, 51.06916942904073, 54.244406530934, 50.20551450790898, 51.658980154222064, 45.02751127366097, 39.991799862154075, 36.888259764640566, 38.61734644059212, 36.387133829055294, 38.745721693961855, 37.569579385942035, 39.59040803294028, 36.34130485596196, 38.81793645120437, 42.32253497646701, 41.631346671812, 41.300333930600075, 41.7104059650052, 38.98007154464722, 40.18936964773363, 43.90002596762873, 47.86974307029478, 50.158277403923776, 53.16515068854056, 51.295709840713016, 45.99918042459796, 4.405544890511421, 2.341048251236639, 7.89795857283377, 10.397362959000374, 9.309965256721744, 8.881827765895475, 8.788218440548066, 2.8435779050473244, 0.2962177631355101, 0.431363977371685, 36.380104941706506, 43.679875096967145, 34.83846441391976, 33.97344058559787, 41.80395841598511, 12.700540481075166, 0.08177036344404183, 0.1322247992239652, 0.08106662741591854, 0.06053769653062187, 0.05717003913295846, 0.04964265837183884, 0.03805298530947297, 0.06746882722983438, 0.02992687044635175, 0.0636344843904578, 0.05937560626696195, 0.07406630748582464, 0.07723600393341434, 0.02823443666491057, 0.06056606476645797, 0.024902168698909304, 0.04842825962470905, 0.28937791564291526, 0.18447795582394447, 0.12026654976990916, 0.18374134696299033, 0.18769469773096426, 0.1156207857533328, 0.23118426812992943, 0.1267014125422124, 0.15910599711200885, 0.06969813542861132, 0.056678670338324966, 0.1649401396993668, 0.13620399779850437, 0.13755313992019624, 0.1612390003978245, 0.16388561967159473, 0.2105757368788604, 0.18073203102234872, 0.17930632607350427, 0.1740814532123266, 0.20623558831791725, 0.11174184510544424, 3.516769885055481, 48.744831700478834, 49.81763132156865, 38.9689516252087, 44.799511740284586, 56.907523293649, 31.761596433578003, 0.9190737828612329, 3.918608129024506, 0.48783308435832307, 0.36805557447575754, 3.313397197954117, 6.805741748502178, 3.164820512456279, 0.17674740854530566, 3.396047175891938, 31.370820499235588, 55.76444264381163, 62.6853039956862, 60.04851810393795, 59.92261786614696, 55.64372385701826, 50.67433188038488, 50.57859859158916, 52.853055538669715, 52.62101204164567, 54.20874041895713, 56.259618343845496, 57.450289110983576, 57.53136842481552, 56.051246350811375, 56.96857890775127, 57.7932729259614, 54.88938147021879, 54.14619430418938, 51.32160925096082, 51.5903151419855, 45.01983127286358, 45.534709038272986, 43.75237618723224, 46.3219012752656, 43.941983561361994, 43.24413114978422, 43.84842326564174, 44.49628899174352, 44.35539353278376, 43.910659513165875, 44.301111851969075, 44.958795270612164, 41.95927643006848, 42.909874608439786, 44.885305743063654, 43.3436377586857, 42.497955137683505, 43.39824891859486, 47.606450050107895, 51.0552881610009, 56.740375411125925, 56.09656933815249, 47.488978985817205, 53.36874131233462, 51.33521203071841, 51.189723476286865, 54.60125984684114, 56.38183939841486, 57.25229963179558, 56.589905446575536, 55.73150257910452, 46.56269558014409, 48.41186169655093, 57.426849026833814, 57.79244138348488, 56.070462042285556, 51.98843571447557, 48.747914683434274, 47.47522323362289, 44.598827592788204, 43.57450062228788, 49.22108196443128, 43.58183153213994, 42.97524090736143, 44.50723240452428, 39.93177975377729, 40.94388069645051, 44.26886604678246, 41.91475360624252, 41.67660690123036, 41.56776897368893, 44.103793098080544, 42.8438336618485, 42.10789895826771, 40.96927019857591, 39.1068386262463, 44.96110162427349, 53.290274297037435, 53.304143797966745, 58.3728737215842, 52.14804480152746, 53.72813632411342, 48.67664521740329, 42.6195211564341, 39.21592758547875, 40.10916894482028, 39.83410096937611, 39.600064908304525, 40.26110195344494, 41.66991141534621, 39.20653350891606, 43.99065625283026, 44.50027411983859, 44.663076016210745, 44.427529842622825, 44.21119151576873, 40.84782969567084, 42.174265461583296, 45.71762484888877, 52.10884071165516, 51.35573387145997, 56.73306019075456, 51.5879774093628, 44.19429394506639, 5.408180173366301, 3.381842802609167, 11.475802948397975, 21.81331249975389, 17.959091547996767, 16.623675515574796, 15.14437419752921, 12.020014159141049, 0.6492731828362711, 0.8486456652322124, 46.03337564776021, 42.2786005081669, 39.86027494553597, 42.64845648119527, 51.00645857472574, 15.223445257832928, 0.35898965933630544, 0.26677332698337497, 0.15848682952984688, 0.20157052654652827, 0.2084837805840277, 0.11609740735542391, 0.1165625223168923, 0.14634795186500396, 0.16766450157569301, 0.2215483222877787, 0.15442601194785488, 0.14518752784257935, 0.08848959805383798, 0.10810506485042073, 0.13709328798276765, 0.08367069816637425, 0.11187174297388523], [0.027682403282773112, 0.09265394475791724, 0.009943593346003083, 0.006361930244301837, 0.02270351167798283, 0.04288036962069812, 0.009849509130412293, 0.039818097852290645, 0.010587850307685234, 0.031751630594953895, 0.07759073328587317, 0.04785060251672422, 0.061752688995892965, 0.057260832043304566, 0.08129312897161131, 0.022241796231678417, 0.07131121016197628, 0.01547168285000108, 0.03434490142089706, 0.041669770669672763, 0.050883663352578885, 0.008547242013587347, 0.02927988238121954, 10.962046980857851, 41.92741893952893, 32.284101247787476, 35.00078778113089, 37.30605886828515, 36.98652298219743, 3.3454846374450193, 0.8250702593115069, 0.032702068002113414, 0.12717648664669645, 1.1358686368311606, 4.025194616087021, 2.0432643592357635, 0.62089134127863, 0.19576471389061023, 5.781621683028437, 42.06661208983391, 55.09495681332004, 57.02399415354575, 52.630202154959406, 52.629880520605276, 50.01155722525812, 48.7941005922133, 46.70269673870456, 47.218629621690326, 48.551698115564164, 52.499151845132154, 52.44750599707327, 53.32383409623177, 50.22480080204625, 52.37718182225382, 52.641043586115686, 51.94985528146067, 51.28533124923707, 48.603555771612356, 45.96389870489798, 41.855431679756414, 40.870124447730284, 39.610259148382376, 38.34462796488116, 39.41550170221637, 39.050689897229596, 39.570662821492846, 38.60865446829027, 40.73796802951444, 40.48855627736738, 40.92395505597515, 38.62228470463907, 39.32588338851929, 40.37736492772257, 39.86038084953062, 41.400060192231216, 39.053686588041245, 41.22298086843183, 42.03097343444824, 47.52555116530388, 46.89633630937146, 55.601099460355705, 45.96996661155455, 46.20928218287807, 58.19180534731958, 45.058592134906405, 53.77509886218656, 50.01997463164791, 52.91964561708512, 47.11765996871456, 47.75009509055845, 41.057209737839244, 40.520743247001406, 44.41962234435543, 54.90690269777852, 48.370633663669715, 46.59842052767354, 44.45657499374882, 42.4938327266324, 41.4857953594577, 43.77675764022335, 43.22830046376875, 43.27459619891259, 40.392791609610285, 38.43426981279927, 37.889542810378536, 37.534831108585486, 37.16535560546383, 36.141781730036584, 37.24433645125359, 38.107756030175, 38.53745560492239, 39.660198765416304, 37.778437752877515, 36.73549521353937, 36.96106287740892, 38.45532117351409, 49.707279359140706, 50.348359384844386, 50.28693114557574, 48.845095326823575, 48.67841028398084, 49.598119797245154, 45.91979557468046, 37.28712558746338, 35.4060588344451, 34.775145592228064, 34.86206531524658, 36.61204645710607, 36.97128065170781, 39.46020495507025, 43.495864945073286, 46.00051403045655, 47.59299239804668, 47.3267654449709, 45.84389771184614, 44.061039263202304, 42.385316433445105, 42.10622410620413, 46.50298141664075, 47.582990354107274, 51.54930676183393, 55.6253279409101, 26.327611477144305, 0.27604581007073004, 1.7097466943725463, 6.289655893079697, 8.758108365920283, 7.601827959860525, 9.790158483289904, 4.201177147126967, 1.6940520655724312, 0.1112721412773094, 7.378855924452505, 50.33553715675108, 18.37254466549043, 32.81303286552429, 35.95131143446892, 25.7303443262654, 1.3875047405881267, 0.11473632192299252, 0.11001207985945287, 0.03222255441810816, 0.014396051354255649, 0.05917614761499628, 0.03676666239757211, 0.04594176038799267, 0.03921230616528661, 0.047058107541693796, 0.0246127694094133, 0.03498073141541212, 0.05223922529107621, 0.021005113902051124, 0.020072131808246338, 0.018468782561080112, 0.04649511718701932, 0.12690542941732755, 0.007878403684439799, 0.08232138750533904, 0.00930565182164672, 0.05747873043160766, 0.028564137924883156, 0.03082066522760978, 0.04203659655045598, 0.04246009761587747, 0.029342573271283222, 0.07090493841397186, 0.020232613821844422, 0.02341150140930568, 0.07612121576863913, 0.050963711879786947, 0.12909238827565025, 0.021043134845733162, 0.08170377508166336, 0.038047369884988, 0.05428877478886036, 0.05353803926658246, 0.02841146809289292, 0.04577781757219665, 0.014980113914897366, 18.06699791262227, 48.31802683491861, 28.43370068457819, 41.36730055655203, 44.99366906381423, 37.78409381066599, 2.953937957363744, 1.3002335977169777, 0.05099550835908421, 0.18055909433432166, 2.395523108782307, 4.7217359754347035, 5.235869961400186, 3.2151768813210153, 0.39695624141923846, 7.748611877041479, 44.18248761084772, 56.36345917178739, 57.786549983486054, 54.80090064387168, 54.719805640559045, 52.77867171072191, 49.7769602652519, 48.675174328588675, 49.84045167123118, 51.31795752433039, 55.118957796404445, 55.473202736146995, 52.05071903044178, 53.371781149218165, 53.452989901265795, 55.42033703096452, 54.46384745259439, 52.99412358191706, 48.2078553015186, 47.31709288012597, 43.54408656397174, 42.27199131442655, 41.63331177926833, 41.65266867606871, 41.18501624753399, 40.8949883522526, 42.91564441496327, 41.068494396824995, 43.30756372021091, 41.83992655046525, 43.34955661527572, 40.79621130420316, 40.374556510679184, 41.549318144398356, 42.59709304378879, 42.739545683706964, 40.10003374468896, 43.03681427432645, 44.34784689257222, 48.41887097204886, 49.86736697535361, 57.7051176563386, 45.920619272416644, 52.13470089820124, 56.95911422852547, 46.57846743060697, 54.36349753410586, 50.915118340523016, 53.85676653154435, 48.929167409097, 47.336704730987556, 42.79753008196431, 40.87334079127158, 49.48763055186118, 59.39751840406849, 51.158705372964185, 49.31988254670174, 46.4686999013347, 44.09777225986604, 41.955252078271684, 45.67249798005628, 44.5420277503229, 44.19938125917989, 41.43900540567214, 40.129545657865464, 39.87962007522583, 38.020718636051306, 39.28434156602429, 37.93083752355268, 38.807047951606016, 38.682449940712225, 39.18268157589821, 41.72262022572179, 40.09758226333126, 38.33409247859832, 40.53212988761164, 39.69711611347814, 51.16725613993984, 52.06387073762956, 51.790783559122396, 51.4316435014048, 52.063643240159564, 52.41715861905006, 47.5699092495826, 38.793751116721864, 37.086849366464925, 37.573737098324685, 37.327082772408765, 38.41096701160554, 39.37657217825613, 40.077927266397786, 45.73130607604981, 47.10737159175258, 48.53467502901631, 47.16863509147398, 47.72656871426491, 44.328031078461684, 44.0118605859818, 43.5129782461351, 48.94561390722952, 47.67821765715077, 53.04109788710072, 54.829443731615626, 29.58354546177772, 0.476500345694442, 4.002550037637834, 7.534946645459822, 10.71991220597298, 9.213323939231135, 12.357860649785689, 7.882943249517872, 0.46682183600721827, 0.21082664599582074, 6.853197034328216, 52.22149902774442, 25.202944394080873, 35.433327151883034, 39.79413986206055, 34.7910508032768, 2.9354498655565324, 0.16933949153509834, 0.1066244543800431, 0.02210755655992656, 0.08415784581654495, 0.038574610746675925, 0.06548983059943685, 0.04126429182266997, 0.03763740176274892, 0.030740509448092312, 0.05215465684511489, 0.017490494027433377, 0.04338576931566481, 0.03760529501784233, 0.024821976530215433, 0.06142734294576992, 0.10374366501045805, 0.06084882015843065, 0.11963384541412515, 0.20854120653483177, 0.07591254107894436, 0.07174071735672413, 0.0976809754126495, 0.15475823363709837, 0.10715952082987755, 0.16307258587931434, 0.2030852662339326, 0.14821853939323656, 0.14776647090911865, 0.15516194665143568, 0.1574696945927797, 0.12714423434508423, 0.18643687328984662, 0.18655183244376414, 0.23931230778896043, 0.17841228614411048, 0.1505692801888912, 0.10977051701516875, 0.15200425480161944, 0.22141958887298263, 0.2538656954082751, 20.162586935104866, 57.46026369833178, 41.73088858204503, 46.12488454388034, 47.690204420397365, 47.12945453582272, 4.793427586555481, 2.5388580368411158, 0.1234354111816614, 0.25828746297667105, 3.274228409413369, 11.799189621402371, 5.1821952673696705, 4.226686771838896, 0.9764608163987437, 7.049818096622345, 45.69499277299451, 56.37395935673868, 60.72891204587875, 56.879129255971606, 57.53116446156656, 55.18622644485966, 53.33604051220802, 50.48278293301983, 51.96681561008577, 54.09265787370744, 55.88477311595794, 57.93224642353674, 55.39971320859848, 54.35055371253721, 55.90160400636735, 57.56600687580725, 59.30655863977248, 55.79076959240822, 50.92373971016177, 50.60931859477874, 46.82094835465955, 44.223578360772905, 43.12336921691895, 42.29190911016157, 44.26428864079137, 43.12116092251193, 45.465930277301425, 42.189794125095496, 45.378339828983435, 43.411165283572295, 45.762414393886445, 43.148288034623675, 43.79027805020733, 43.932675776943086, 45.52017273441438, 44.33222801454606, 41.762757839695105, 43.90199107508506, 45.6924432323825, 50.67296297319474, 50.61693976002355, 58.84635086982482, 50.85665541310465, 53.069095765390706, 54.48462424739715, 49.36675879263109, 54.727007112195416, 53.60237336927845, 55.05199117045249, 49.02181771493728, 48.50034644526821, 41.7118650867093, 45.840606843271566, 55.100365761787664, 59.6191950767271, 54.23372983932496, 51.05668844715242, 50.14507078355359, 45.75279281985375, 44.91635914771788, 48.73458646958875, 46.49324609387306, 46.97933758458784, 42.173892836416925, 42.75415259022867, 41.87289014939339, 40.163587908591, 39.71765756607056, 39.42926529915103, 41.13915981784944, 40.583214836735884, 41.34432723445278, 44.85073004999469, 42.295960918549575, 40.24341598633797, 40.82210286971062, 42.34280186314737, 54.662327228053925, 54.96317694264074, 54.06967278449766, 50.801499043741536, 54.169234306581565, 53.553186847317605, 51.161309826758604, 40.53567178787724, 40.026693267206994, 39.69884195635396, 38.46378564834595, 40.14999297357375, 40.890461937073745, 43.521183844535585, 48.21125599645799, 49.54190046556535, 52.21681964012885, 52.13572855918638, 51.16593037882159, 47.228153136468705, 46.05589789728965, 45.93628521888487, 53.09718778056484, 50.044532591296786, 54.393495821183734, 57.60804683931413, 30.412854148495583, 0.8297247643912993, 7.064528455657344, 11.560203529173329, 17.217638069583526, 16.581053080097323, 19.63091946417286, 16.071107695179602, 5.9379011681002964, 0.6089671520936875, 10.13396893778155, 62.72626138502552, 27.8445351892902, 43.21057135058988, 44.74675193909676, 46.0845390442879, 3.7171235728648404, 0.23788582143043321, 0.2916261998395766, 0.18125094833873934, 0.20123862661421302, 0.08836307863314306, 0.10626342012396744, 0.20705447502193913, 0.12441667788211377, 0.10310365983675565, 0.1426676195114851, 0.08200571331526003, 0.16195207503774475, 0.1268887976484914, 0.09371183557255615, 0.1751077352392097, 0.23189483000145805, 0.14968899919861747], [0.05326253872725272, 0.10023135872137162, 0.10889494746562936, 0.02077602296917429, 0.014438186190091075, 0.05304996465002337, 0.031172404921944105, 0.07713385376959078, 0.027818713307140336, 0.07244786247611046, 0.023681612520088113, 0.007445134040373828, 0.02996352200786914, 0.05107107910237486, 0.036812014802689516, 0.06305775807930097, 0.05534450140511317, 0.017844767557577263, 0.03485662517167869, 0.10470916562142873, 0.06549792814879649, 0.06766077822014209, 0.026174562217126933, 0.138140055200746, 29.78483561546572, 34.22717478967483, 28.936034710176532, 37.00039248312674, 45.64106802786551, 12.425746090950506, 1.384384862838253, 0.3249122298532917, 0.39332477015353023, 0.9000501649514322, 5.904938549764696, 4.71943550532864, 3.423202480039289, 0.38468323708061253, 0.444744223909032, 15.959487826593461, 53.09081000666465, 54.75163175213722, 55.89523407720751, 54.106947068245184, 51.26866117600472, 46.49589369373937, 46.07905164841683, 48.31903096168272, 51.46624665106497, 52.50139544087072, 55.17704809865644, 54.86507846463112, 50.67543014403313, 54.34770214942194, 53.06204726619106, 54.09372475839431, 50.32533899430306, 48.48092286817489, 48.38565634142969, 42.34652027007073, 40.211746769566695, 40.96492813479516, 40.48497515340006, 40.29418322347826, 39.28076828679731, 41.748551014930975, 40.31749386941233, 41.75811767578125, 39.629427771414484, 41.08797680947089, 38.8713316763601, 40.976432446510564, 40.64910281089045, 40.23967404519358, 39.718230232115715, 39.702309331586285, 38.17522864187918, 44.8384020405431, 45.57289331190048, 49.08064934515184, 47.50596284866334, 56.18679954159645, 38.143178955201186, 54.53090429306031, 56.56624178732596, 45.7300469952245, 46.04949658916843, 45.919673981205115, 47.52113065411968, 49.81358343555082, 32.410558462142944, 55.09012053089758, 48.99811483198597, 46.19621284546391, 51.59892474451373, 43.49064034800376, 45.24362210304507, 41.89653027442194, 43.642934214684274, 44.247716626813336, 44.59662322075137, 40.486583325170706, 41.29685086588706, 40.25018207488522, 40.10110062937583, 38.01334458012735, 36.696965771336714, 37.76207754688878, 36.839234059856786, 37.26665081516389, 37.94057284632037, 37.376073175860995, 39.12412058922553, 36.177934215914824, 36.99937266688193, 37.27511921236592, 42.80264485266901, 49.305789470672615, 48.89636462734592, 51.974326948965754, 48.91038710071195, 51.051055923584975, 47.43266551725326, 47.43300284108808, 38.63512654458323, 37.76262667871291, 34.70461353178948, 34.99104853599302, 35.159663384960545, 41.19870531943537, 44.98540462986116, 47.93551337334418, 42.18994709753221, 49.59439746795162, 47.855344049392215, 46.948821544647224, 45.589410412696104, 45.940321337792184, 45.62353503319525, 51.20629156789472, 50.82400952616046, 47.52936370911137, 7.968103789514112, 0.24426531136756946, 2.1945626793369173, 7.883949827763343, 7.23914453098851, 7.443268106829736, 5.014059437859443, 3.5680923827232855, 0.4390688913483774, 0.03703341421280657, 24.65961571662657, 44.93563367474464, 51.38485354761924, 42.809591370244185, 40.67184471314953, 14.895939115555057, 0.1624258238101198, 0.08884646479160556, 0.017398963757460157, 0.037225020463548364, 0.04234854755322299, 0.009482318400255135, 0.054886859631346124, 0.02202255335906821, 0.08072783269228474, 0.05897640551049864, 0.04554337168472909, 0.10745201319936784, 0.03131539714823087, 0.032054951617253885, 0.051857686691707185, 0.05346329589825004, 0.022433772119843674, 0.03127760220048649, 0.06456072682574873, 0.03743347298774508, 0.1104599655035042, 0.05344823460965868, 0.03539987344054445, 0.022262702771132032, 0.06404903371848407, 0.03407177575413258, 0.006463880267655177, 0.03773539973002288, 0.09005521364029377, 0.038091167131619114, 0.02278679309623136, 0.025276259008434512, 0.035830456988825914, 0.04785225726664067, 0.0352163455869642, 0.03892301987375944, 0.047406160437892524, 0.05271728330802533, 0.0745101711682735, 0.08883887286027593, 0.04163966341424854, 1.3033727195955094, 41.49460108049455, 37.51667445705783, 30.072559118270878, 45.020654970599765, 49.754649823711766, 12.049660413495957, 2.3096822827093066, 0.44706871853240077, 0.32572897151112556, 1.3847670487819181, 7.168491367370852, 5.859584183462205, 8.44575826198824, 1.2255427217291248, 0.5528624271673541, 20.204603364390714, 54.73493422231367, 56.70203424269154, 58.013549312468506, 55.72014339508549, 52.51445693354453, 50.04057491979292, 48.01726341247559, 49.950027004365005, 52.520473849388864, 53.235164996116396, 55.94393030289681, 55.886730378673924, 52.94725125835788, 56.12060170019827, 53.304822368006555, 55.83530026097452, 52.500128515305065, 51.41080002630911, 48.70259954083351, 46.54257774353028, 40.12110471725464, 40.617053124212454, 42.05687676706622, 42.21348524093628, 43.100223310532115, 43.25634148813064, 41.52816872442923, 43.19017502569383, 41.880636830483716, 42.049436030849336, 41.32033017373855, 42.66151405149891, 40.37939671547183, 42.93674676649032, 41.1509386954769, 43.31873070809149, 40.740709766264885, 46.519682868834465, 48.445798043281805, 50.2423494861972, 50.68505956280617, 56.549097107302764, 41.30797863006592, 63.04113357297836, 50.33667464410105, 48.685745116203066, 48.53798550944175, 47.39057456293414, 46.21746816942769, 50.733347861997544, 36.19209004986671, 55.68427724222983, 47.15686405858686, 48.40427975500784, 54.01650505681192, 46.32199148977957, 46.32580403358706, 43.813298440748646, 45.207544142200106, 48.07106656412925, 44.76675602697557, 43.86266146936725, 42.9562880146888, 41.6576853875191, 41.66257266075381, 40.99737398086056, 38.747435769727154, 38.75737897811398, 39.87971421210997, 39.0397660962997, 39.76943285234513, 39.95177207454559, 40.474977031830825, 38.73530387878418, 39.59253787994385, 40.31982767966486, 46.14059363642047, 51.33808712805472, 50.55965746602705, 52.367269992828376, 49.658002622665904, 52.56825616282802, 50.778502187421246, 48.363251763005415, 39.33338688265893, 38.95981642507738, 37.46591506465789, 37.36643591234761, 37.520592904859974, 42.367701069001235, 47.03947144169962, 50.3007653451735, 44.867851195796845, 52.70515080421202, 48.2588892598306, 48.994565086980025, 46.71394609635877, 46.938156620148696, 48.525312331414995, 52.61480685203306, 50.492463342605106, 49.754171294550744, 10.630283105757929, 0.5347533956650765, 3.450355823001554, 10.225975974913567, 11.653202925958942, 6.064546656224036, 8.225406369855328, 4.579537308985188, 0.22897042724634373, 0.05107799304589149, 27.19605561225645, 51.01540942345896, 40.11893564654935, 41.91291793700188, 46.29096946408672, 23.076290199833533, 0.15171905558916832, 0.06218416503660622, 0.043654532111700506, 0.054413539868208675, 0.00860910265586309, 0.057810094102375933, 0.049802705630539894, 0.019004977075383067, 0.03751972682713982, 0.09036776219164172, 0.028704617382778276, 0.043803605160886244, 0.05620252754118654, 0.056414454274119875, 0.03360645394892462, 0.08822361998740705, 0.06435198318814078, 0.023668541144880078, 0.21172834680445735, 0.16565761168397244, 0.309724812546084, 0.15969954671398287, 0.11671531855339005, 0.15709968944711072, 0.20646538405168444, 0.13995470298874763, 0.11334205722256054, 0.1379319244334775, 0.11001166617197376, 0.10282956889920658, 0.10610168364139334, 0.13449174532246205, 0.10392253121901905, 0.15048125668639137, 0.09270832167878267, 0.12809080492344596, 0.25176822328038756, 0.21235683001577857, 0.20007484712668006, 0.18995307896646763, 0.12778508221550336, 1.7208737231069997, 46.9918107217358, 45.084605293889204, 38.66109655749413, 46.11301152936874, 57.74300382983301, 16.48674165048907, 3.7589377549386795, 0.882954391981325, 0.6613562280131925, 4.947901800755532, 16.881294827307425, 12.342068206879402, 6.285068190866902, 0.6673295074893583, 0.9721411836724129, 19.790705057882494, 55.4516806910115, 56.06144843562957, 60.1423058971282, 59.08218337643532, 55.07124608562839, 52.916111561559866, 51.09923439641153, 52.46109308735017, 54.66676735108899, 53.71357648603378, 57.88782165896509, 58.640622554286836, 54.66175848437894, 58.50437510398127, 55.13449822702716, 57.74196440173734, 54.4823924187691, 51.01382870827952, 54.047025019122714, 48.0994253004751, 42.19459510618641, 44.352153655021425, 44.61426604178644, 45.05831364662417, 45.703543539970156, 45.291408338854396, 43.8411041229002, 45.27585221875099, 45.304191343245975, 43.675878201761556, 43.00510583385345, 45.071484965662805, 44.54128249999016, 44.76204133802845, 44.684790257484686, 44.06235325721003, 43.2926038003737, 48.63238519237888, 49.901056212763635, 51.573186151443, 52.27476873705464, 59.9461167858493, 46.35085621187764, 59.40185654547907, 49.896671002910985, 50.09414272923624, 49.22518476363152, 48.77266483922159, 47.5105441770246, 49.834054285480136, 36.77845301166658, 58.54761923513105, 52.13943519899922, 50.159881653324256, 54.41074640520158, 48.63562507014121, 48.85439134413197, 46.09422337624335, 47.585763469819106, 50.54169301063784, 46.92920577141547, 45.926471448713734, 45.6407424711412, 45.29999440716159, 46.405028066327496, 42.828061811385616, 39.35860772286692, 40.83882785612538, 40.67895597027194, 41.31196768053117, 43.16120832197128, 41.397655779315585, 43.0609643074774, 40.621187302374075, 42.029400564009144, 42.377667811609086, 47.88560513527163, 52.28830091414913, 52.34895644649383, 54.70221381033621, 51.016080148758434, 55.81821833887408, 53.05602642797655, 51.11954050679361, 41.18851107935752, 41.945850156968646, 39.089184038100704, 38.81836398955315, 39.089466448753114, 45.60134618513046, 49.351339955483716, 52.27520412014377, 46.36076019656274, 54.46066641038465, 51.14129789413945, 51.96386991008636, 49.97434177706319, 49.06561490028135, 50.66881702792261, 55.0972160985393, 52.74684559914374, 48.857325277020855, 11.536714415396414, 0.5591616310900258, 7.718976409204545, 19.065058731263687, 16.882432314657397, 17.683884328411473, 13.069157965721624, 12.553541814127277, 2.4410838898151153, 0.20018142527870594, 32.11593158783452, 55.328063272660785, 57.64808639403313, 51.230661253775324, 53.447784916047134, 29.486735482369703, 0.25844975104255064, 0.25991739164437017, 0.13090315965875504, 0.22670364968719023, 0.1614141127755565, 0.13494450328571184, 0.24206199653206334, 0.16989724950924998, 0.10134803912331981, 0.2598308237089265, 0.15329246228981405, 0.27458723994993395, 0.21718254042488916, 0.2126106196233342, 0.16149459797288143, 0.1839103306373281, 0.10371674468079883, 0.12753639475352344], [0.010943501838482918, 0.01434145801355161, 0.018624949584444685, 0.04107735104738705, 0.02696829825459469, 0.07608162434471231, 0.04399691978769918, 0.026021444223700993, 0.012855922555430763, 0.0713174767611969, 0.046557442270099156, 0.05979211678007438, 0.024324760569499868, 0.029555896199458552, 0.00990474694258263, 0.031976057967591676, 0.016729741905545516, 0.041870669566936074, 0.038891583455786596, 0.033311789720169, 0.04109409772941182, 0.02237661813025273, 0.03985737134972888, 0.07350021447505682, 5.59752082632434, 39.412960006344704, 27.65157222747803, 35.76573233450613, 43.2636292519108, 25.742613500164403, 0.7163284298393034, 0.2812451875257877, 0.08596744508512559, 1.9255787903262724, 3.5301682112678407, 5.9133839030419635, 5.541035263769088, 0.5846129105456415, 0.24317832453356636, 2.794742435216904, 33.64640512774068, 59.44894459939773, 55.37537490167926, 54.77155347024241, 51.9843799837174, 47.583037422549346, 47.3791604657327, 48.95323115010416, 48.90941043053904, 51.770940288420654, 54.01812107332292, 53.59327739284885, 51.721020283237586, 52.095908657197036, 53.31290245056153, 51.79960104726976, 49.49094887702696, 49.165909905587476, 46.41626173450101, 43.08483585234612, 39.28389049345447, 41.22898209479548, 40.95265503852598, 40.15650410805979, 40.67844213977937, 39.95964427148142, 42.23635265904088, 40.24496924492621, 39.87035151450865, 40.46151153502926, 40.284518503373675, 39.22882433860533, 39.96255859251946, 39.8768195029228, 41.83845566165063, 38.54485711743755, 44.1737211135126, 48.934446919348936, 51.75481542464226, 51.85756975604642, 50.13322130326302, 51.522701324955115, 47.96559403019567, 39.33398308292512, 58.30719363304877, 55.556317760098366, 52.21378372561548, 47.45792558116298, 44.51808952516125, 37.37055440102854, 50.973632258753625, 56.711632282503196, 51.09360971758443, 52.18613101590065, 48.11092176745015, 46.24035912175333, 42.56137986336985, 43.428474703142726, 40.55116907242806, 42.86610095731674, 44.2733100921877, 43.69388972559283, 42.765519618988044, 40.235869346126435, 36.058752998229, 36.68039375735868, 37.195102860850675, 38.68163408771638, 38.30161917594172, 37.089343993894516, 38.02607659370669, 37.0376746116146, 37.507060727765484, 37.44054909675352, 37.32194446748303, 35.95776373340238, 38.539008863510624, 46.87015841084142, 48.83038251630722, 51.12382765739195, 49.07227508483395, 50.09541357717207, 51.19799183261011, 47.999648048031716, 45.94862499544698, 40.69161738118818, 36.42720868510585, 36.45674021013322, 35.42909491446711, 38.019510546038234, 45.3923858365705, 49.346758627122455, 45.95632460809524, 44.67341538398497, 50.41416106685516, 48.114640174373505, 51.44522666931153, 47.37515572578677, 50.439283847808845, 48.24860872760896, 52.926556833328746, 33.69667814623925, 2.947716342826044, 0.4516886270815327, 3.1370660662651066, 5.939343129434894, 11.702734616494949, 5.485080692075915, 7.990410798980345, 4.9659123439942645, 0.21265051748243072, 1.6704545963195063, 25.04180166029161, 33.624467311366914, 34.63495223752914, 46.78008902457453, 40.35373656980453, 6.8936239231017336, 0.012334738576394177, 0.03470867444130202, 0.10804959242382359, 0.05811002135517136, 0.012795924464420927, 0.029115477997449138, 0.0672122720448721, 0.03339083850263588, 0.07770104994696957, 0.04637802064779305, 0.03216558045917942, 0.10259996468742048, 0.05033890589050228, 0.11055126786231996, 0.026391817091573632, 0.010486625195030245, 0.016554541427702192, 0.026698462935465, 0.035196438792251775, 0.03286524089954553, 0.017289164205712658, 0.009688187292927216, 0.06481560427815684, 0.05486023424553776, 0.05252708665906422, 0.05870400762726223, 0.037610060084731355, 0.02135945446488838, 0.023795029922058026, 0.06390572165048893, 0.021610610645204302, 0.01296928154319645, 0.03911830334653778, 0.03571958874442405, 0.03623332347600691, 0.0371659665759052, 0.08169007742957723, 0.023700632568028186, 0.041659068421370564, 0.02095055695052349, 0.02914524625896687, 0.06131912536558606, 11.175260159277148, 45.45125276811662, 29.20268527923092, 38.617107176011615, 51.59864233386133, 27.19823252770209, 1.7265048983596987, 0.4180783886582621, 0.37122019176040927, 1.626713427324449, 6.287368660972965, 7.298692484055796, 7.621888431810564, 3.6876106790957914, 1.1372398729285886, 3.45212996006012, 39.14133587191182, 57.67461730587868, 57.987273354684156, 59.018456628245694, 52.95837510016657, 50.05092605467766, 49.2397799030427, 51.39576165906845, 52.84595212628765, 54.13028909314064, 56.42311842210832, 54.00789545428369, 53.27778154803861, 52.10676185546383, 55.86385903819915, 54.52005109479351, 52.20604881163567, 52.48550591930267, 48.28393359338084, 43.835244101862756, 40.87065004533337, 43.941818821814756, 42.06869879076558, 42.729386744960664, 43.19287361637239, 40.64880863312752, 42.875804901123054, 42.50791011318084, 41.877946084545506, 41.68547145781979, 42.4824696202432, 41.64891889018398, 42.22635453747165, 41.51694290099606, 42.712842187573834, 42.68294588212044, 44.80264179168209, 50.89525938034058, 52.33163918218305, 52.22862989671769, 50.970953279925936, 55.980412267869525, 47.78342346991263, 45.354452594634026, 64.89196277433827, 50.63036995549356, 50.79897695972074, 47.177040730753255, 46.50977888414937, 39.07441239203177, 52.70291897558397, 58.520994186401374, 53.986887239640765, 53.00895014116841, 50.64403549317391, 47.15775835898615, 45.118926032896965, 45.09472893130395, 41.528196181020434, 44.14813941524875, 45.58187946196526, 46.80091288781936, 44.04855043657365, 39.93523143952893, 38.148819323508974, 39.137244839822095, 38.93379934372441, 39.77470059548655, 38.61933508226949, 39.3197605686803, 38.77797926625898, 40.32336565756029, 40.291617993385564, 39.3236437151509, 37.75539775048533, 38.762050520989206, 40.31792925250146, 49.71357868563745, 50.33021450042725, 52.931142084060184, 51.0738488166563, 51.54178365584343, 52.22711586183118, 51.11431983209426, 45.543573594862416, 42.5608777999878, 38.46515455553609, 38.32836581814674, 36.482047342485004, 41.375337493035104, 46.79238957743491, 53.28431621674569, 46.63183127680133, 47.455548624838556, 50.74773903815977, 52.12722878302298, 49.747448352075395, 48.592969294517275, 51.386442107539025, 53.49833250045777, 53.405297802340606, 36.97297119325207, 1.8793053636627814, 1.3727789372205736, 4.939778081832394, 9.68153432492287, 12.802917284350242, 9.548575782006788, 8.986628593937043, 3.762191606144752, 0.31813985938506745, 1.8756912672711958, 31.342132283795266, 41.4255516759811, 47.772374153137214, 50.570961736863666, 44.73735786253407, 11.800673257920051, 0.05668411339302698, 0.057399536092435165, 0.028326602787860942, 0.11277665369092457, 0.048918402678663694, 0.06166145175455078, 0.05414460853282964, 0.03861273511222774, 0.04680694944615807, 0.042683427567563714, 0.003345668040809312, 0.02863549135415064, 0.02756395842880011, 0.04082506680260262, 0.09910234430384252, 0.051888640474287734, 0.03939764581680779, 0.02781959239303345, 0.11607490735308779, 0.15577950544895666, 0.14193343148837168, 0.13131411986485605, 0.1291127662144361, 0.21744443524268367, 0.2580997101481884, 0.1368106321822251, 0.16599640640760624, 0.1489868183289805, 0.13854992756199452, 0.16269841321533726, 0.13178319550089299, 0.12895581012050952, 0.09025558393688933, 0.0897899097312362, 0.14758147599716342, 0.133039012791649, 0.14785817163365503, 0.09266301523894073, 0.2135795063429302, 0.1230941649766699, 0.10310458680314404, 0.16161913322585245, 13.51826640867418, 55.89629703952421, 40.219611121762185, 44.64549203072825, 55.198079847520404, 34.579411475889145, 2.850435188701076, 0.7700025722865136, 0.6889572114713731, 6.6377108423940605, 8.766987631397864, 12.017640144594255, 11.752737972044176, 3.6916588102617576, 0.8909914510384683, 3.6707815047233336, 37.48785288103166, 59.358255478643606, 58.85474866436374, 61.01412719295871, 55.367020253212225, 54.043545876779866, 51.82459046763759, 52.81743257276474, 53.48114859673285, 56.83733640178558, 57.30275700169226, 57.0528196519421, 55.89990954245291, 55.30177162539575, 56.79992483508203, 55.6542161972292, 52.81771498341715, 55.2114982758799, 49.58264996928554, 47.08804999628375, 42.69487773218463, 47.04287213663901, 45.20796775817872, 43.68710010282455, 43.97256235922537, 43.59158254438832, 46.28788648113128, 43.52512974892893, 43.74909316339801, 44.42381143569947, 44.10123179035802, 44.13203416332122, 45.2879213517712, 43.73878125221499, 45.43297060074345, 43.34795236587525, 46.9496177857922, 54.13094805132959, 53.623836578861365, 55.59088953079716, 52.928929867282996, 56.80308234307074, 51.12514165139968, 51.41392615533645, 61.38838798769059, 50.780039756528794, 51.75814943928873, 49.05891941439722, 47.58298250936693, 42.13559089168426, 53.128982513181626, 58.90876754637688, 58.05353003163492, 55.75734315379974, 52.818181745467655, 48.03627514070081, 47.26741606189359, 48.06655191606092, 43.03106800202401, 47.029798876854684, 49.92289989225326, 47.81251176711052, 46.989629883919996, 42.61377880650182, 39.74660465794225, 41.03860593611195, 39.999287666813025, 41.25749380357804, 40.86425265958233, 41.24555410877351, 41.069902527716856, 42.476417403067316, 42.588557966293834, 40.562461576154156, 40.21963073361305, 40.090996603811945, 41.4404841392271, 51.41101575666859, 52.27098364983836, 55.06193437883931, 50.42205287564186, 51.836745892801595, 55.47519530019453, 52.32274324663224, 49.570773032403764, 46.409931029042895, 41.071153763801824, 40.84759827583067, 38.63451465483635, 42.372129424925774, 49.700489736372425, 55.237174111027876, 48.642387236318285, 48.372704675120694, 52.16669567169682, 53.26883854404573, 54.82004573268276, 51.107377236889256, 54.41002468908987, 54.320826069001235, 54.92700876728181, 37.018533445173695, 4.7698448261907025, 2.09653970695311, 7.157138066907083, 12.88214033649814, 19.821323079447595, 14.741333992250505, 16.59453622756466, 13.101997029396797, 1.3118794824807876, 2.151351643185462, 35.681244480994444, 43.63070818685716, 46.78093233416158, 52.40233205979871, 53.36437179196266, 15.062460399443104, 0.12144030372221624, 0.14740599589722772, 0.1485649643525962, 0.202976236600549, 0.11638717245190375, 0.08157403043080723, 0.1581129939445565, 0.08285353516018198, 0.2243194614927615, 0.1032412798714734, 0.08780750400957563, 0.21641187129482148, 0.13034953855939452, 0.15402905582900972, 0.12387750520100518, 0.20174364709565717, 0.11931143731119172, 0.11871159812735936], [0.023391797627893188, 0.010440175368961309, 0.042826360422036344, 0.00699302773066466, 0.06236594620971911, 0.06504516252466748, 0.05405341725676291, 0.04805696745132727, 0.033706263714139505, 0.007968796792650416, 0.027383929681814006, 0.06815128133542116, 0.03420475712646881, 0.0484661388421251, 0.03462489889634233, 0.056714025296030514, 0.04902766979930382, 0.04038393422360382, 0.045705230741371075, 0.02318462255531021, 0.024326399997657826, 0.09417272938956177, 0.04134188503808072, 0.040270897950376236, 0.19059158260783843, 21.953456824825658, 34.871314264112904, 32.525646686553955, 35.58686833227835, 38.46098507604292, 5.40257461609379, 0.2627930712075003, 0.05759255577539725, 0.7715664948186567, 4.835356743104996, 4.013388772164622, 13.434967033324705, 5.165397226810455, 3.2257307537140387, 0.4510338976979256, 13.958868211315526, 53.75525559148481, 59.01634247072282, 53.02987990840789, 52.30418651334701, 49.44992088502454, 50.04497974149643, 48.05002304815477, 52.46072438455398, 53.28905443991385, 53.137878448732444, 55.448617319906916, 53.62201659910141, 50.224475245321955, 49.882350429411865, 50.86522186956098, 53.54551469126056, 52.606918965616536, 44.57781153340494, 40.33485820216518, 42.911247438000096, 42.47205964980587, 40.79294004747945, 40.051133555750695, 40.87592955558531, 40.87257592908798, 39.30068608253233, 43.69124997046686, 40.344107151031494, 40.17166014640562, 40.1418540554662, 40.03371038744527, 40.20992678980674, 38.70152050449003, 41.01767616887247, 40.01686380755517, 44.957257701504616, 50.807206092342255, 52.0672792773093, 52.89900218286822, 53.58477761668544, 52.62224366587978, 56.20799603000764, 48.74150553057271, 41.69563824130643, 50.320926327859205, 54.71130586439564, 51.61963485902356, 43.79129002171178, 57.898969034994806, 62.30868193411059, 53.59234779111801, 51.73231278696368, 48.22128549698861, 48.91148144199003, 47.48354650312855, 43.948400558963904, 41.49579348102693, 41.85492177163401, 40.57579371236986, 44.978399276733406, 43.501838714845725, 43.95298973206551, 40.664811903430575, 39.230558026221495, 38.826977514451556, 38.28008144132553, 38.34186661627985, 37.97039070437032, 37.81588854328279, 37.31853592780329, 37.24408934193273, 39.05047808924029, 35.45039338450278, 37.95294792421403, 35.75489874809019, 38.61057642967471, 42.82306078941592, 48.52029169759443, 48.07057626785771, 49.563697076612904, 49.77688574021863, 49.809704211450395, 51.31916561434346, 49.408426130971606, 45.447063676772586, 41.321546108491965, 37.89295919479863, 34.89178511404222, 36.048091996100645, 45.57929069765153, 46.82927946890555, 52.30033866820797, 48.88815902894544, 47.82123511837375, 50.13584144653813, 47.93313641701975, 51.38026437451763, 49.4932238517269, 52.79253728928105, 47.357356009944795, 22.8047719693953, 0.4181138432073978, 0.9352783810707831, 3.0765157024706564, 10.70363142798024, 13.582408928102064, 4.020441438882582, 4.159846642325002, 1.3016553343303743, 0.0974729365759319, 10.27132151588317, 40.13536253283101, 26.73836208158924, 24.590884024097075, 44.04505168237994, 31.10464257578696, 2.2978712906760554, 0.08083555231531782, 0.03500221635124857, 0.08029019730466028, 0.026426450011410543, 0.04213100539580469, 0.01687699932635071, 0.017378426855430007, 0.046236922573899074, 0.032088621181526014, 0.07233343958373993, 0.027808482202911572, 0.011743604066601444, 0.010301785415879661, 0.04123681990970527, 0.021246332006769317, 0.03477525897324085, 0.03192953727838974, 0.07150728270531663, 0.013798013434655244, 0.019340745751715956, 0.03024685196578503, 0.030205226578419248, 0.00889591544100474, 0.019930742620941133, 0.043452392151999863, 0.010228024555310126, 0.012088636661158695, 0.023346115804968343, 0.041230170266522516, 0.057980567817726446, 0.046798541631189086, 0.018658186309039593, 0.0718776249296723, 0.008983874783640908, 0.010658261448805852, 0.037455038362813574, 0.08883078297179553, 0.019294929863404364, 0.05556207803648807, 0.030544871659648996, 0.03390567640082971, 0.02745364176770372, 0.8073855179452127, 31.94105859725706, 37.93434020011656, 34.225041020301084, 45.95489294298234, 43.312486294777166, 7.238121282669806, 0.303744301199913, 0.031413778159466964, 0.7159240579893513, 2.3789714420995405, 7.524040985491968, 9.01629053777264, 9.021578873357466, 1.8785494493861354, 0.5401282072547944, 16.90046541152462, 56.67204380035401, 59.116296229823945, 55.50104371963009, 53.9108834728118, 51.44173968222834, 51.73130081545923, 49.93158794218495, 53.30604614750032, 54.345160453550285, 55.408075701805856, 54.66914430741341, 55.51939256729619, 51.504430924692464, 51.414149730436264, 51.997429709280695, 54.970252898431596, 52.430490755265765, 46.940517886992424, 43.837577912115286, 43.19414838667839, 43.19062217589348, 41.99436203125985, 41.65317858419111, 43.35786419530069, 44.189449817903586, 41.52717636477563, 44.0509234705279, 43.95798290929487, 41.55733546903057, 42.396569713469475, 42.67273203019173, 42.07782222378639, 42.133955263322406, 41.90455936616467, 40.46916015686528, 46.87282954492877, 52.38839587857647, 52.58660501049411, 55.23975110823109, 53.95349217999367, 53.47887754440308, 58.78465983175463, 48.20603924412882, 46.169501504590436, 58.111608566776404, 55.183245443528705, 52.805379129225216, 45.22272763713714, 57.03306659575432, 62.547801386925485, 55.94417741221767, 52.00915759609592, 51.02953387844948, 50.72125127238613, 49.636060883921964, 45.79522894274804, 44.13984752470448, 46.250298407769975, 43.4468549297702, 45.85713963354788, 45.68546925821612, 46.055309541763805, 43.371341459212765, 42.52758864433535, 39.67510769444127, 38.13518908716018, 40.51884089746783, 40.599900599448915, 39.96722229065434, 37.26758041689473, 39.131843736094815, 37.66435169404553, 38.06136615814702, 38.78724782697616, 37.66433208219467, 38.283850839061124, 45.19265482502599, 51.32476283657936, 50.36801830414803, 51.103811802402625, 50.085435067453695, 50.17734796770158, 53.60892372746622, 52.10332193682271, 48.40735097085276, 41.67354353012578, 37.42449091326806, 37.2230536706986, 38.795461270116995, 47.99765940635435, 50.34502537019792, 54.05545811499319, 49.53502847302345, 49.35759613590856, 51.72113795434275, 49.959958445641306, 53.062231617589156, 52.03588070407991, 51.83326282808858, 49.29957643631966, 24.763005471998646, 0.9688034918039077, 1.5157962758694927, 4.754593180071923, 9.405865246249784, 14.335441243263984, 7.832608453689083, 5.949492262255761, 0.4476905061352638, 0.21601932784242017, 9.616184696074455, 39.93778882488128, 32.43274731020774, 29.360970566349646, 50.036495654813706, 38.04865375641854, 5.297477649104211, 0.09454370746689458, 0.03684089248699527, 0.024207137344825654, 0.05495238313150983, 0.03282924625842321, 0.016429747620056716, 0.033933719049298, 0.05582442484615792, 0.03433399615929492, 0.05260716199934964, 0.06386832889890479, 0.01411548888896622, 0.045547228937427846, 0.09394772936620059, 0.010253834057479136, 0.026023686946099325, 0.030720843971076033, 0.039660613157696305, 0.12905141789345972, 0.08011160688775201, 0.17654551373374078, 0.1472583554324604, 0.276984941935347, 0.14719503060463937, 0.10429599142122654, 0.11512840572263926, 0.1293113515261681, 0.14668306936660122, 0.13433704152703285, 0.21117353060793495, 0.1341899373238125, 0.19347988729996068, 0.11874723653759688, 0.1382387579689103, 0.1572974473838845, 0.13743405921324608, 0.32217512027390544, 0.16610917455006033, 0.2318642171280038, 0.17520818468784133, 0.14483403955255786, 0.16858319421449017, 1.1130348040211586, 36.57548996710008, 47.719586895358184, 44.580765078144694, 45.59945952507758, 50.571926639926055, 11.770203305828957, 0.46681497185941667, 0.1865830888310748, 3.861303281399512, 11.654879739207606, 10.990129190106547, 23.49006691286641, 10.30033528804779, 6.590501685296336, 0.6276782061303816, 17.379229914757516, 56.396842464323974, 61.822370790666156, 58.32167110135479, 56.763050633092085, 54.4792623673716, 54.21928374998031, 50.99880603051955, 56.53958928200507, 57.80138438747775, 58.14230503574495, 55.515936959174375, 56.87933714159074, 51.59280584704492, 53.88157552288425, 53.89246010011243, 58.57236546854819, 56.56078184804609, 48.76920923109978, 46.31969690322877, 46.2617007378609, 46.56481366003714, 43.82825443821569, 42.771920927109264, 45.881858410373816, 45.42424724948022, 43.97988934670725, 47.1675838962678, 45.610834398577296, 43.87023556616999, 43.52720468275009, 44.989044589381066, 42.99686493412141, 43.836883652594786, 44.01014258784633, 44.78963128982052, 47.090948627841094, 53.748956264988074, 55.80854185165898, 57.01585915780837, 57.76530250426262, 55.11889503848169, 61.24289943325905, 52.16386764280258, 53.40049289887952, 59.38085225320632, 55.517133282076934, 52.72329961099933, 46.65243940968668, 57.16342264606107, 58.27328082053893, 58.37732561172978, 54.83073811377249, 53.29992332766133, 52.28008747100831, 51.495264345599765, 47.276810138456284, 45.86328990997807, 47.73790828643307, 45.73447535114904, 47.383847698088616, 47.962832681594364, 49.29252401474984, 45.69669115927912, 45.00490273198774, 41.59252697421659, 40.907936096191406, 41.370916981850904, 42.511577529291955, 41.93572259718373, 40.68320389716856, 41.84399404833394, 42.849846655322665, 38.85425367662984, 42.55406464299848, 40.3305475173458, 42.13518296518634, 46.54582938840313, 52.424058068183164, 52.31959358338387, 51.77722784780687, 52.31769515622047, 50.03282039396225, 54.860202958506925, 53.12114953994752, 51.205326664832334, 44.82826663601784, 40.93290982707855, 38.13699337743944, 40.07324787878221, 50.34384865914622, 51.950682901567035, 54.47769341930267, 50.44512817936559, 51.04751794568954, 51.92673290929487, 50.812587584218676, 54.43675564181421, 54.48614612702401, 54.350494876984634, 52.02560017185827, 28.01436597301114, 1.010618593183256, 3.681982077898518, 7.301086600749724, 20.909416021839267, 24.35861106841795, 13.630076512213677, 12.982838365339465, 5.06016738953129, 0.6366193102252099, 14.058613104204978, 52.614838230994444, 37.27941813007478, 35.96942493992467, 54.62138552819529, 46.13246256305326, 6.166793530987156, 0.16331529785548488, 0.2150507322362354, 0.20068544984584857, 0.18582277720974338, 0.18675222572299743, 0.0896068376999709, 0.3003574264866691, 0.16437996088737444, 0.10615422961211975, 0.16063852536101497, 0.10694231958158555, 0.10443715078215446, 0.16926625352953711, 0.21515274450423258, 0.10033166261329766, 0.1030177277542891, 0.17347848072888392, 0.22726608079768], [0.043080487108278664, 0.06105175684957255, 0.04275466991408218, 0.07100634547250886, 0.03620382526048249, 0.039059356711204016, 0.03099560715077866, 0.03248881593707108, 0.03033158512065007, 0.054507661430585774, 0.005553686895572971, 0.04639055384623428, 0.02591995864115175, 0.009070186079629968, 0.030142338420715065, 0.045071817754257115, 0.0548276870000747, 0.0352133386918614, 0.0526136699162664, 0.010942725216849677, 0.07207706059900022, 0.031181722466323166, 0.048892554872098475, 0.049950744461027846, 0.013234702280662475, 4.276764652421398, 39.44074215427522, 29.816398928242346, 28.589293264573623, 45.24588923300467, 20.730240191182784, 0.050328452620775475, 0.11700850040201219, 0.16871626368693768, 2.7177426315123037, 5.718886313899871, 5.076052498432898, 8.210572946456171, 11.248833037191822, 1.9060984614395329, 1.1141909226294489, 33.70400905609131, 59.34858291379867, 55.821509207448656, 55.977439111278905, 51.40517534748201, 49.72884062797793, 50.99197326167938, 54.22188428140456, 54.38726317497992, 54.68302165308307, 53.6001140840592, 51.449251021108324, 51.77384284234817, 52.85425970631262, 54.165582579951135, 50.080104566389515, 47.45654490686233, 43.66861004983225, 42.419405752612704, 42.41333784595613, 41.55822584705968, 41.833270288282826, 42.56995024219636, 40.12917695506927, 39.79483019921088, 39.571396304715066, 41.64180763306157, 41.37422353990617, 39.95973448599539, 40.49222761584867, 40.58370513300742, 39.50760287623252, 40.43023455527521, 39.907402223156346, 39.76587134022867, 45.99237511234899, 52.95931646900793, 53.190704930213194, 52.32439456447479, 56.199931636933364, 55.16518292888519, 51.83556525937973, 53.695608108274406, 50.809469299931685, 44.38137923517535, 46.82924024520382, 50.613644969078806, 55.83852052688599, 57.88829626575593, 53.24984642767137, 54.79879040871897, 53.26564573472547, 50.5277568294156, 46.90147461429719, 45.009923365808305, 42.95448764677971, 42.94756858579574, 41.73786255621141, 46.52918677176199, 46.867098962107015, 45.54786074546076, 47.94494275123843, 46.97321868711903, 40.77560317131781, 37.201202146468624, 38.54441388960808, 37.219382332217315, 36.51426961345058, 36.00130596468526, 36.11127353483631, 37.76643530015023, 37.1247826084014, 36.121189286631925, 35.60967691483037, 36.67493774044898, 36.454159290559836, 37.12058567231701, 43.908251177880075, 49.55382447088919, 49.90696722461332, 51.02630969016783, 48.200375341599994, 49.35874931273922, 50.93050187633884, 48.26358433692686, 46.583841077743045, 38.390225518134336, 38.08788922525222, 35.85354635792394, 41.097594461133404, 48.391045678046446, 47.77670444980745, 50.41920915726693, 49.45003071138936, 50.63445706521311, 49.19464518946987, 47.97409380635908, 52.40900793383199, 45.64218590336461, 45.34896519876296, 10.389428984734321, 0.6309331605030645, 1.0126264789892783, 3.9868801687994315, 7.838275297995537, 14.700394253576956, 8.524730282445109, 6.175080028272444, 0.8715642580101568, 0.30737473058604425, 24.249216164312056, 40.477032353801114, 29.20434444181381, 35.22810089972712, 34.63915701835386, 14.66929574166575, 0.5879689272372954, 0.023360244381511887, 0.001621535695683692, 0.008870862450660958, 0.06689495842663512, 0.1027634784939789, 0.022463576770537806, 0.04142761793768695, 0.09071832402579247, 0.0660047106324665, 0.04876136614550506, 0.09705887371373755, 0.049865026883180105, 0.07980851952226893, 0.0922268354183724, 0.04390929082048036, 0.0308313176801969, 0.03923704314436163, 0.1426899739571156, 0.03410666722864394, 0.05727961651920792, 0.07438499240144607, 0.06378383706173589, 0.03646414576759262, 0.08845900050214223, 0.057184357316263264, 0.06006957084361104, 0.021653304725224455, 0.07404686417430639, 0.01775137569394804, 0.03232064431593303, 0.023665093749220815, 0.05364886154570887, 0.004622611403089738, 0.04266297685042505, 0.06351351910721391, 0.03916649793785426, 0.032124012528407964, 0.038503973609617645, 0.06409271988236616, 0.028006889399201162, 0.11156151566894786, 0.06125286642101504, 0.022427089917924137, 7.410889921649811, 44.758205259999926, 31.0142005643537, 34.95537457927581, 51.92188878213206, 22.324726812301144, 0.1168879641280059, 0.12298972420995274, 0.11998997670748543, 2.3887190222740173, 6.236961301295988, 6.967379191229421, 10.596721345378507, 15.389508605003359, 5.039319011472887, 2.2163997398268793, 37.08387620987431, 61.041662231568374, 58.00268434709119, 56.01974971832768, 52.63133964230938, 50.40340985021284, 54.32097904143795, 54.38317998763054, 55.73527197684012, 55.509837673556426, 56.21004742960776, 53.733498204138975, 51.3114816911759, 53.642714946500725, 57.0591817363616, 54.156043375692065, 49.0777232570033, 45.37620605960969, 42.81799700952346, 44.550704033144065, 44.7995941100582, 43.44619989395142, 43.87193787482477, 41.95505595976307, 41.085788126914736, 42.514680124098255, 42.90716817302089, 43.25166602288523, 41.93299262754379, 41.90910539319439, 43.06901693344117, 40.731256854149606, 42.784609794616706, 40.7220196723938, 42.86095873002083, 47.73439776512885, 55.32101477346113, 54.2822927044284, 55.1361495448697, 55.61510232187087, 54.948860291511785, 53.17916139479607, 55.38467876372799, 50.08440740646855, 44.0496761568131, 49.70304712172478, 54.035575620589725, 55.80356436391031, 58.48573600092242, 55.00592293277864, 55.16544180531656, 56.19806851110151, 51.99973606294202, 48.27799120256978, 47.70093602518882, 44.32041383558705, 45.05109256313693, 44.309223313485425, 46.8522959370767, 47.89592096882482, 47.252424763095, 48.69580991806523, 48.689722399557795, 41.20522429866176, 38.85954495399229, 40.97780919844105, 38.74497644362911, 38.131258872247514, 38.32640071069041, 37.8084203504747, 38.30164663253292, 40.02562638252012, 39.53509084640011, 37.67263573984946, 39.06126852958433, 37.60161730550951, 38.661716291981364, 45.21771877042709, 51.63292384916737, 52.27081498792095, 51.586883068084724, 49.83091246697211, 50.33033217153242, 53.16400927882041, 49.955643838451756, 47.687870610144834, 40.973843682196836, 39.1327380364941, 37.60472774505615, 43.177066464577955, 49.67728107206283, 51.18786819519536, 52.536002512901064, 50.57318179838119, 51.209731486535844, 51.512220751854684, 50.66687545468731, 53.476983039609856, 47.423408723646595, 47.959910515815984, 12.093355617215558, 0.7510680044370314, 3.8738859997641657, 5.042680973006833, 8.77859196355266, 14.068815189023173, 9.102542477269328, 4.522786986443305, 0.5404348875726424, 0.17537324599200682, 27.66715776535773, 45.40486289608864, 32.74406386959937, 36.320163280733176, 46.701100334044426, 25.74232520595674, 1.3685829817287385, 0.09545674637681055, 0.06426422781641446, 0.039094566112203945, 0.11371708024413356, 0.07455886371674077, 0.04541966763715591, 0.045838545361954364, 0.045542716679553834, 0.04609247286533637, 0.05145841698733069, 0.07863554697964462, 0.028236292512907137, 0.040313094073245605, 0.03164681444515384, 0.07065821979795733, 0.021744806266900514, 0.0677679845642659, 0.05951077865076162, 0.16461564017640007, 0.11474755277196247, 0.144446337775838, 0.1322113313982564, 0.10027864932893746, 0.25972148764037317, 0.1329707696793541, 0.14709603672306384, 0.09689745898809164, 0.15732856587536875, 0.06576245830905053, 0.12010400889501457, 0.22240569724911646, 0.18279671458707702, 0.1473943973260541, 0.16772874570902319, 0.1822423427215507, 0.11296645197416506, 0.19385540827868447, 0.13308119359275988, 0.1435617820149468, 0.08990256296050164, 0.1719599106018582, 0.24577189987945944, 0.17922576426738696, 9.654069888976313, 53.2189695296749, 39.19866131198022, 39.25204477002544, 56.06176614761353, 31.177908528235655, 0.18641540750620827, 0.616797489985343, 0.5878429823825436, 8.772848633027847, 16.42501727227242, 11.99900790568321, 14.583702760358012, 16.330155730247498, 3.897175562958564, 1.8571762091690496, 37.593580369026434, 60.54911451954996, 60.86945056915284, 59.28623683990971, 55.301324475196104, 53.2982563203381, 56.45418751624323, 56.597608981593964, 59.186804756041504, 56.676158366664765, 58.930811266745295, 54.58494670929448, 54.346572506812315, 56.769702972904334, 59.01358896686185, 55.39862278969058, 52.459712413049516, 46.933363483798125, 45.867596672427275, 46.57560017801101, 46.787616052935206, 45.39864201699534, 46.03529760914464, 44.234717892062285, 43.650775032658736, 44.465757262322214, 43.62970798246322, 45.525958230418546, 43.50358024720223, 45.41875593123898, 44.22926971989293, 43.694795793102635, 44.554826444195164, 43.78624193130001, 44.661369785185784, 48.595197200775154, 56.725560618985085, 57.3095230902395, 56.76558056185323, 56.780007039347005, 58.566556438323, 55.4930381621084, 58.918098865016816, 53.12352257390177, 48.29977212413665, 53.3076503969008, 55.27373844577421, 55.14595547030049, 55.63790305968254, 55.515191708841634, 59.46254737915532, 58.83934943906723, 55.076419691885675, 52.01408409303235, 50.42643808549451, 46.596608392653934, 46.39314720707555, 46.26840799085556, 50.95572663891701, 51.34109166360671, 49.9231352344636, 51.106271128500666, 51.18992743953582, 44.72040145627914, 39.35701524057696, 43.29359616002729, 39.69251517326602, 38.463111000676314, 41.075005531311035, 40.017475697302054, 40.27017439565351, 41.20473400239022, 40.63535490343648, 39.87551335365542, 41.23899198347523, 39.97592603006671, 40.424582419856904, 47.0136308670044, 54.896798672214636, 55.488374463973514, 53.749454405999955, 53.161447971097886, 51.16024294207173, 54.47808173394973, 52.91351495250579, 49.31384601900655, 42.843057032554384, 40.73998412778301, 40.74239638543899, 44.68540999197191, 51.58926394677932, 52.16984925731536, 54.13765922669442, 50.74658193895894, 55.58248389151789, 52.66055345535279, 52.58382012767177, 54.40807134874406, 49.59082026635447, 51.00131242505966, 12.626351791043437, 1.2843289995385756, 6.279899977868603, 9.17209884812755, 17.006689079346195, 26.222446849269254, 19.58231737536769, 18.16492772871448, 2.5026626500391194, 0.4757416122142346, 32.995848655700684, 50.55364839492306, 39.16347765153454, 46.450437345812404, 52.58621277347688, 27.431588057548772, 1.857457884377049, 0.2354959488636063, 0.10527744964365998, 0.09241240489627085, 0.19832615950895896, 0.19875222696892678, 0.19429564836525148, 0.15233381050488642, 0.177715958186215, 0.18152923743811347, 0.17275855726292058, 0.3944662411607081, 0.15128229354177752, 0.20992353558540347, 0.19553704788127255, 0.17256418543477214, 0.0862783925127118, 0.16622900602317628, 0.245288452433963], [0.0217328303974242, 0.013881439451999484, 0.05134593995828783, 0.04014956111448907, 0.03402295297071819, 0.08284021289117875, 0.036639200688730326, 0.049442537053818666, 0.04048112779855728, 0.051395023211596474, 0.01620049389349597, 0.02599804406805385, 0.02388328325093514, 0.03224467520692176, 0.024623416116340988, 0.08992097971420135, 0.04945557970072954, 0.01413840066356164, 0.028418774656470747, 0.022915285193331303, 0.010946590130427673, 0.05266314387441643, 0.022365239809357354, 0.010421815114246022, 0.044100322505278934, 0.19289003024178167, 18.99015715045314, 38.763705761201926, 25.65397381782532, 39.13320479854461, 30.989813227807325, 4.603949160345139, 0.14606737982361548, 0.2900144734209584, 0.9974908492257519, 4.484905715911619, 5.168996001443555, 12.116720195739502, 2.118711394648398, 1.9560021642715701, 0.09805682580918075, 9.383684242925337, 54.38518039641842, 57.242038711424804, 56.07457268622614, 54.344148482045824, 53.310454891574004, 52.23447815064461, 55.17321202062792, 54.2103878144295, 52.17727822642173, 51.38650486546179, 52.90366588100311, 54.208583524150235, 53.57428135410432, 50.99416194423553, 50.678681788905976, 45.349479029255534, 41.15964243488927, 40.720419345363496, 43.371608180384484, 41.47858996545115, 43.011852310549834, 41.91462416802683, 40.96642255783081, 41.922213954310266, 41.48110420473161, 41.30653519784251, 39.88558600025792, 38.96038124638219, 39.656260705763295, 41.401703665333415, 38.6216139793396, 39.001056225069114, 40.008399332723315, 40.23517900897611, 44.83384424640287, 51.40538323310114, 52.37343203636908, 50.83183465465423, 50.793030646539506, 53.25669096362207, 51.85370229905652, 51.31378020009687, 52.054284464928415, 54.006875638038885, 54.09916116345314, 50.55144794525639, 48.797650337219245, 46.60232720836517, 54.1498460308198, 54.78880405426026, 51.490216255187995, 50.395745538896136, 45.83633930452409, 45.36713361740113, 45.08807266912153, 45.69784825847995, 47.41011581113262, 47.99101098891228, 48.992352870202836, 50.11916745093561, 52.40206533862699, 53.32082171593943, 45.176278929556574, 36.774479650682025, 39.508497176631806, 37.93591307055566, 36.46423193716234, 37.495701543746456, 36.85011079234462, 37.00784498645414, 38.596106806109034, 37.3534450223369, 36.80135180873256, 36.0806712027519, 36.85667684001308, 36.367788699365434, 38.7597559344384, 46.66122944124284, 48.16438759526899, 47.58015448047269, 51.929753134327555, 49.51955472269366, 50.408975693487356, 48.83021777675998, 48.56806616629324, 43.92088905457528, 38.92634684039701, 37.49921990979103, 38.289283321749785, 42.86467713694419, 46.18817983135101, 45.0942268679219, 48.472485849934245, 46.25704880683653, 51.01041624622961, 51.49182834932881, 50.405057245685214, 45.04560516726586, 38.709227961878625, 3.137494585206432, 0.7556705381120405, 1.3066507178929545, 4.592624787361392, 4.921068376110447, 7.007634966604172, 4.4627835481397575, 1.7238549695860956, 0.17395164727443652, 1.2267237228731955, 25.70983425263436, 38.83055863841888, 25.08270021407835, 32.82608651345776, 20.382412249042144, 3.747976936640278, 0.0545633445313621, 0.08072459214036504, 0.03621138654829514, 0.04882021701984829, 0.05048394165632706, 0.03931871960840879, 0.03765425569708309, 0.03175397290878239, 0.03505588464078403, 0.0748064786556267, 0.023740227822394624, 0.021699015276446458, 0.07982654557112726, 0.0376800115730974, 0.02467312947696736, 0.06541154407445463, 0.03325280478043902, 0.03943823315503617, 0.018731468364656455, 0.02083544840946073, 0.015643968363292515, 0.011978210832533098, 0.03558245517553822, 0.03608885844568572, 0.014988411604727228, 0.0717657684318481, 0.044895487296725475, 0.013720128148223364, 0.05247279017743084, 0.026781420681565523, 0.05458468391049293, 0.04585188678315571, 0.031252131692223975, 0.05998050163109457, 0.01614099759007654, 0.043791206027831764, 0.046633687170763174, 0.02881877597481493, 0.0490959090811591, 0.04422178191523399, 0.05875499843950233, 0.03382615264384978, 0.05812538907893243, 0.055250387503615314, 0.5037649859103465, 27.34550968293221, 42.093276362265314, 26.00350799099092, 46.620695667882124, 38.191196610850675, 5.418015516573384, 0.10047004873593969, 0.3281398195653193, 0.3848309388324138, 7.632697993709196, 7.358094819130437, 10.529783156610305, 8.751714902539408, 6.313283760701457, 0.6461525696419901, 11.869119598019509, 56.39283772437804, 61.08852278801703, 57.52690084518925, 55.742140047011844, 53.72822653862738, 54.189685544660016, 57.55511445383872, 58.14873380045737, 55.26316373578964, 53.20370366496425, 52.730877630172245, 56.195330696721236, 54.53836071875788, 53.27632634870468, 51.25979661941529, 46.304081947572776, 42.66706812766291, 43.75180744355725, 44.4132092691237, 44.12389524521367, 43.06438461426766, 44.48336085965557, 44.19376442509313, 42.92621520257766, 42.8043471613238, 44.380002483244866, 42.217089899124645, 40.161689481427594, 43.23353682794879, 43.005878540777395, 40.58483869798722, 40.215794655584524, 41.55353076996342, 41.55377003454393, 46.8729668278848, 53.56379293626355, 53.323328110479544, 53.18347992435579, 52.28388432533511, 54.79360503535117, 53.910691276673354, 50.94818392107564, 53.00203500255462, 55.209635150048044, 54.12609607942643, 52.150747314576186, 51.16648343301589, 48.66185788185366, 55.726948707334465, 56.67987677358813, 51.79572966790969, 52.57048799145607, 46.28992219125071, 47.68618791334091, 46.44582463848976, 48.32869568178731, 48.69490385055543, 50.03497377518685, 52.19984362202307, 53.11371664847098, 54.08907282736994, 54.94929175223074, 45.64566112333729, 39.37446194310343, 39.437384605407715, 39.62034748446557, 38.61285924911499, 39.46482550713324, 39.16763144154703, 39.19947716497606, 40.28481660350677, 40.265177296053984, 37.75519770960654, 38.0934746803776, 38.362007987114694, 38.367495382985766, 41.80420552530597, 49.311924057622115, 50.47468323861399, 48.70109727305751, 52.44061439268051, 49.32071801154844, 52.26651214784192, 51.2946351112858, 50.78851599847117, 45.2225628975899, 40.39411737072853, 39.02121328538464, 40.4109678729888, 45.46267863242857, 49.43132885040776, 47.629658714417495, 49.8152857442056, 47.73096569122807, 52.564114139926055, 51.3427939722615, 52.74830079847767, 45.98536191448089, 41.65332371188749, 3.037077005832426, 1.7494199977767084, 5.784245748673716, 5.4502083697626675, 6.964868874319139, 10.125049468009703, 5.319061961866194, 1.3929413907950925, 0.09187541556574645, 1.5352501287575693, 30.127674302747174, 44.24016214186146, 31.504290911459158, 37.003965762353715, 28.165173261396347, 8.727401110433764, 0.044021488227430856, 0.030567873449575518, 0.042746227625156605, 0.043643117401628725, 0.06316274659888399, 0.026714539290556026, 0.043692802033957936, 0.07082174892627424, 0.0201624708114973, 0.12576726790998252, 0.05460787722240052, 0.021752145389215122, 0.015027840234970134, 0.028155188699583375, 0.00418776361789975, 0.020802449172122345, 0.049802720952298374, 0.04621418508430643, 0.07942022785784737, 0.05619122774430341, 0.10369419871318726, 0.11981145523849035, 0.11315999642735529, 0.11075913815969422, 0.2204420147163253, 0.16532666170068328, 0.10249813628052512, 0.1077967068000186, 0.19225190964437303, 0.10744398459792139, 0.11633317091412122, 0.10853629574299821, 0.08830264195679657, 0.1381765669512172, 0.1993340707474178, 0.12839330240122734, 0.1526529474123832, 0.10948224579014125, 0.07644956105298574, 0.11652333691956536, 0.198012032816487, 0.17409898130403412, 0.1284654372401776, 0.12058174898547512, 0.5865733601873921, 28.883516134754306, 53.64032622306578, 36.99245752826814, 46.953493087522446, 44.00321175975185, 9.66405918521266, 0.2779161371290684, 1.183448090187965, 3.606746360178917, 12.532673824218012, 12.868363011267878, 23.011769171684023, 6.058928841544736, 5.462166695825515, 0.5687826535394115, 11.455640004527185, 57.44131865039949, 63.72624612623646, 60.89039994824318, 59.142250553254165, 58.18078348713537, 57.125799271368216, 60.908819398572376, 58.923362685788064, 57.4529210213692, 53.359253098887784, 55.14644184420186, 57.81595599266791, 56.666458345228634, 54.31308331028108, 54.41370779468168, 48.449967522774976, 45.80385815712714, 45.366058887973914, 47.51207782376198, 46.18077439646567, 47.24574496669155, 45.83614318601547, 44.33393816794119, 45.645943533989694, 45.772518419450336, 46.012363510747115, 45.03811344023674, 43.47977538262644, 45.043349804416785, 46.05239522072577, 42.48236371624855, 41.9030963220904, 44.33061984277541, 44.28502621189241, 47.8077970781634, 55.20475572155368, 56.17201612841699, 56.701524334569136, 54.18776750564576, 57.257798794777166, 54.37997148882959, 52.95381730602634, 54.64966189476752, 55.38252146013322, 56.100487785954634, 54.40329390187418, 52.88236348859726, 50.12179543895107, 56.95169310415945, 58.2707626588883, 54.58293061102591, 54.21407092002131, 48.694138988371826, 49.89414107414984, 49.619551627866684, 50.683851472793094, 51.424877412857555, 51.172880818766934, 53.83786070731379, 53.59077099830874, 56.76908716078728, 57.956804383185606, 48.67206388904203, 41.65943868698613, 41.565525377950365, 41.29465433859056, 40.20246644173899, 42.296604187257834, 40.07435790954098, 41.06961227232411, 43.25283096682641, 42.017860950962195, 39.94100516842258, 40.02354360395863, 40.91464334918607, 40.61433492168304, 43.41791176026867, 51.97003979836741, 52.78376686957575, 51.981261699430405, 56.497768971227835, 50.99574658178514, 52.638172411149554, 53.266257624472345, 52.56331789878107, 47.39692488024312, 42.61807772421068, 41.47322024068525, 42.80167210486628, 46.87566149619318, 51.055837292825025, 48.42807285247311, 51.440798313386985, 49.58495240057669, 54.82365823561146, 53.25325104498094, 53.979524950827326, 49.51135696903352, 40.44166041958717, 4.672247921266864, 3.259931860431548, 7.270434258445618, 11.79917295132914, 14.06912015330407, 14.239749139355077, 12.79950580289287, 6.3748022144840615, 0.3739875771345631, 2.082433883220919, 38.10828947251843, 48.51195273860809, 36.15894602191064, 44.59792937001875, 35.6361529134935, 8.532051386371736, 0.1269820228879971, 0.09697013774946814, 0.12250534979806793, 0.17812828202882122, 0.117215252211017, 0.08925937086103425, 0.09063398540620843, 0.32316827665894265, 0.13905194497877552, 0.24572637893499868, 0.09133155442654126, 0.1470385954505013, 0.16614818374716467, 0.09462569419655109, 0.20015194621537963, 0.12537403497844934, 0.2299427460398405, 0.22482857288372135, 0.17291102408161088], [0.008242683759289644, 0.03699041752805633, 0.038709955500258554, 0.022790414776893395, 0.05903715245245446, 0.08517627544220417, 0.013291400447938473, 0.0603568499847766, 0.02207650127069604, 0.030358585889541337, 0.06584116618239111, 0.013180310995648465, 0.03243947221386818, 0.023535345267925053, 0.06839476706039521, 0.07323998972893724, 0.014093114333527704, 0.014590112916794757, 0.015624517390895036, 0.04237634888399513, 0.032135982652224844, 0.012830439598239478, 0.031064673807592164, 0.06829106173808537, 0.02902763452561152, 0.08559088222682477, 2.4472037678764713, 28.496097749279393, 28.69320469517862, 32.24235938441369, 39.84246738495366, 18.12700821507362, 0.4508007618208086, 0.2781119798460315, 0.30976685545136856, 6.62135063640533, 3.799236921533462, 8.266072523209358, 11.735100053971815, 6.099879366736259, 0.8379927529923378, 0.4506940917382318, 29.093527678520452, 58.3197569847107, 56.869182125214614, 56.29471178977721, 54.25576571495303, 54.99044526007868, 56.27802994943435, 53.96178014816777, 54.068366635230284, 53.42221106252363, 59.52845496516074, 54.460866451263435, 54.57192444032239, 51.60896601215486, 44.71625158863683, 39.49430996371854, 41.88308438947124, 44.89095395611179, 45.44440430979575, 45.17389805086198, 43.74904217258577, 43.615905161826845, 39.72640052918465, 39.75789716166835, 40.62401925363849, 41.46792504095262, 41.48017460300077, 40.50190802543394, 41.259635417692124, 39.273755088929214, 39.3737990625443, 39.69197780855241, 40.08248898290819, 40.62337598493023, 46.10418227411086, 50.41701262997043, 51.97853957453082, 51.42676407291044, 52.96480778724917, 51.55537466849051, 50.96298302373579, 51.57440993093675, 51.707688147021884, 48.84713888168336, 49.34870412272792, 51.48254017676077, 51.075731554339015, 51.75144218629407, 53.21532172541465, 55.922294509026315, 52.80193136584375, 50.80500956504576, 46.897544399384536, 44.85295011151222, 48.577048393987845, 52.165922964772875, 49.9330823652206, 53.56755841162897, 49.822471526361284, 53.00870695421773, 52.636674065743726, 53.340778735376176, 46.377410657944225, 36.83901048475696, 38.03791822925691, 37.510853659722116, 38.07039937665386, 37.591564270757864, 36.393013461943596, 37.56240144852669, 38.37072349363758, 36.03377926734186, 36.99704277899958, 36.968044696315644, 36.270804174484745, 37.09954607871271, 37.765352725982666, 39.818317351802705, 42.89285936663228, 49.705800625585745, 48.88895919246059, 50.96324582253733, 48.052046991163685, 48.97583184703704, 47.47809440858903, 47.18875685045796, 45.258625168954175, 41.74276944129698, 39.00715943305723, 42.50509777376729, 43.84222592076948, 46.89397504252773, 46.96988467247256, 49.37113615774339, 48.7009286111401, 51.22797835257746, 49.060527586167865, 49.171063899993904, 24.87746023362683, 0.26165867885274274, 0.478431775925621, 2.5803932403364493, 3.6814407908147384, 6.3282946713509105, 6.185689058996016, 4.948878470928439, 1.4199470320055563, 0.04755185120889256, 3.180371484448833, 37.74997311253702, 26.772729889039073, 23.811210970724783, 32.88081926684226, 10.594697402369592, 0.35073463294294577, 0.01891334146832026, 0.08651545076000114, 0.06444854091011709, 0.041950947920521425, 0.04234261803268906, 0.025891944720980622, 0.08890001433751277, 0.04107161304883419, 0.010122238346675952, 0.0694253238578958, 0.019523497941272876, 0.028468145192751003, 0.028303447780349565, 0.05880899231640562, 0.07460302868557554, 0.01794500441680993, 0.01764081196949607, 0.07522703028253971, 0.04586839597792395, 0.031135958288946462, 0.09990361098560596, 0.024190905856929963, 0.03958844767522909, 0.04819587068331819, 0.04212107306586639, 0.07917121863893925, 0.04355576805650227, 0.050051458209993384, 0.007187528836150324, 0.08442023859149025, 0.051713118239516215, 0.046029837516647194, 0.024834069228100202, 0.015091409253317024, 0.057951326241656664, 0.04180028140845318, 0.016492028653080908, 0.017678166416683988, 0.032277720409535596, 0.015195747555774308, 0.06624747623479174, 0.033776406724486625, 0.062030794234165264, 0.038352713379408085, 0.058843688438496286, 4.97574866779389, 37.10133860188146, 28.87109987197384, 33.56410595678514, 43.5514174738238, 20.915880087883245, 0.3751285272019525, 0.06735454223329021, 0.4344699429648538, 4.926121369484933, 7.210144487119491, 7.690220532878754, 14.469123463476858, 8.664495118202703, 1.812547113626234, 0.6794029306019507, 34.23453315611809, 60.09309191857616, 58.462178245667495, 57.58671699031707, 56.20541118806409, 55.63206265049597, 58.53580897854221, 54.92708329231509, 56.417007369379846, 52.73045009182346, 60.50745110357962, 55.47007660711966, 55.25253803499284, 51.68902158737183, 46.57180724605438, 42.90876457768102, 43.21533703034924, 44.544302725022845, 47.78055229494649, 47.181072927290394, 44.315408891247166, 44.733713980643984, 42.502787497735795, 41.90903479053129, 44.07042157265448, 44.48626341358308, 42.9424459703507, 43.68185981627434, 43.01961468112084, 41.13259769255116, 41.627710634662265, 41.878589353253766, 41.26529147548061, 40.08508559196226, 47.72706685527679, 52.6349207662767, 54.47148430731989, 52.980348217871885, 53.4320915129877, 54.29926872253419, 52.07616736811977, 53.28606951621271, 52.55688913406865, 50.1022659578631, 53.70713595421084, 53.43971660060268, 52.76078178036598, 51.17779554859285, 53.592422316151286, 55.59191719178231, 53.729112994286325, 52.509718710376376, 48.31728158458587, 46.76632935001005, 49.33854518398162, 53.66900659376576, 52.09876022031231, 53.90238761901856, 52.44721181931035, 55.32900464150214, 54.26893311162149, 54.252204202836566, 48.49024634207449, 37.62754809471869, 39.61795876103063, 39.18023793928085, 40.71578310381982, 38.92677437874579, 38.84769547370173, 40.05417339263424, 39.82267510506415, 37.88775420957996, 38.663481358558904, 39.20929485751737, 37.939105879875925, 39.53130575918382, 38.77058167611399, 42.795184504601266, 46.10686125293855, 52.310744716275124, 51.52283468554097, 53.11460702650009, 50.05036123337285, 49.3968512165931, 49.41668272018433, 48.78737372736777, 47.04567270894205, 42.29479205223822, 40.40076971054077, 43.851718056586485, 45.56590757062359, 48.28830703612297, 47.53621216743223, 50.18410228913831, 50.357188640102265, 52.205554592993956, 51.68227903304562, 50.84241328700897, 29.13178255481105, 0.36490278558865674, 2.680425201692889, 3.1288276180144283, 7.778868550254454, 13.908920749541252, 8.386835436667166, 4.007349057543663, 0.7296785844429847, 0.091798446711994, 4.164360309800794, 40.06931374149938, 38.43433257072203, 23.963687227618312, 41.77676854595062, 15.613537719172818, 0.7557699456810952, 0.04584477748721839, 0.027916487193696445, 0.04359375835666734, 0.07152128679257247, 0.04123611893925456, 0.009806038428758903, 0.007257045569619345, 0.0729898160563842, 0.018633298027599533, 0.04643154338062291, 0.027715548076817108, 0.023707653763854218, 0.012438454432412984, 0.03129153159416972, 0.02700861171639014, 0.020387920911513993, 0.06114577882051949, 0.05464744183324999, 0.04314299988289995, 0.1125594217991156, 0.21878087562659096, 0.08375077733709928, 0.12059897830289219, 0.2867230532630798, 0.24619225232351213, 0.17702289376287692, 0.1710954416663416, 0.1376255811943162, 0.06138138150075271, 0.2034864511581198, 0.17327689235248875, 0.12585473216829762, 0.10755019502774363, 0.16877390414236054, 0.13384933463267742, 0.1347878076616795, 0.11740474405908778, 0.0823695054878631, 0.1797421994589029, 0.12868164257416803, 0.22234097814127324, 0.13897843118156158, 0.17969304725768107, 0.1763767292422633, 0.19833224224707774, 4.42847800831641, 42.627369819148896, 40.38099704250213, 42.781260090489546, 51.327767372131355, 29.7752179638032, 0.7582402421582131, 0.5244065508727105, 1.685869878818912, 13.77471685409546, 12.773809375301486, 15.093537338318365, 16.523355014862553, 12.765479241648029, 1.6363467684676571, 0.8531872183084489, 33.14227465660342, 62.381316384961536, 60.48220672915059, 62.64800617771765, 59.35730234269173, 58.63453895814958, 60.859028831604995, 57.69797894262499, 56.869664576745805, 53.447251473703695, 62.747348047071895, 59.217163901175226, 57.559829142785844, 54.04590322125343, 48.94390767620456, 44.17198742589643, 47.76083061772008, 48.25744582760719, 50.085768468918346, 50.054750365595666, 47.586355747715125, 47.2290317473873, 44.230348371690326, 44.14965737250544, 45.919156228342366, 45.9170969840019, 45.32898464510518, 44.55269267482143, 46.60151920010967, 43.29606333086568, 44.39299337325558, 45.102236347813765, 45.25259256362916, 43.75105827085434, 50.3349252670042, 55.441576665447606, 56.88065898033881, 56.328703049690496, 54.931848972074455, 54.26043333545808, 53.84505825657999, 54.56420913819344, 54.36392899482481, 51.89367517348259, 53.755494856065326, 53.60080834357969, 53.77411826964348, 51.06111680307696, 56.1202290750319, 59.80895542329358, 57.84856657828055, 53.370553447354226, 50.928489700440444, 48.558613254177956, 52.415162132632354, 55.95309295961934, 54.223680726943485, 55.86656547361805, 53.68012651320427, 55.525189830410866, 55.51652139233005, 56.634530252025975, 49.284883237654164, 39.522194093273534, 41.59222102934315, 41.6268124118928, 43.105090971915956, 40.413560559672696, 41.16193702144008, 42.516606007852864, 42.06153654283093, 39.84829210465954, 41.35210137213431, 41.77417978163689, 40.88265249806066, 41.168263804528024, 40.77707013776226, 43.777640173512125, 47.109776004668205, 54.33280498750749, 53.38742748383553, 55.505507376886186, 50.57062049065867, 50.49844495711788, 51.57473548766106, 50.71462246679491, 49.57444044851488, 44.81675840193226, 42.401825689500384, 46.25340884731662, 48.64785109796832, 51.266903954167525, 51.322738893570445, 53.87273057814568, 53.32570506680397, 53.697988986969, 55.77145584167973, 51.12100747323806, 30.448610474986417, 0.45302155878274675, 3.4235714279836227, 8.34779804752719, 10.504978087640579, 15.895601241819321, 14.523330619258267, 14.593069380329503, 3.0167135307865762, 0.20538581294878838, 6.737196858852141, 50.60267017733667, 36.15442352910196, 32.3747472224697, 49.37322285867507, 17.287164042072913, 0.5952919310619754, 0.12484895831514752, 0.14504552578493474, 0.14914100118462117, 0.16363540003376623, 0.17084885328527422, 0.14737061795688447, 0.15340006699965847, 0.16984789812516782, 0.08211661220317887, 0.1136747079210416, 0.09395044897833178, 0.08113778166232571, 0.06583044095145119, 0.19161571958853355, 0.1015244308678854, 0.09761617203513462, 0.18261887493633455, 0.17728720941851217, 0.13911801240136548], [0.05001809891133059, 0.05460684300370274, 0.031111165768496936, 0.03376491157518279, 0.05327253617466458, 0.05084863398224116, 0.030627291228982712, 0.005496888658061865, 0.0672943507050795, 0.095938837846681, 0.06451918953849424, 0.023572165368785782, 0.01734611709722348, 0.03803218602232876, 0.07488514056369182, 0.034767012036735975, 0.03364344833478813, 0.031192937993534633, 0.014498314516048038, 0.02910190674987051, 0.0059855129427066256, 0.032420411946312074, 0.032531958178526936, 0.10828249081368409, 0.04423838304055314, 0.044008721372172724, 0.026884066887320052, 9.040832807940822, 38.4796477133228, 30.953988259838475, 39.43738852777789, 28.811779906672818, 1.4535736340668894, 0.32769040174541936, 0.173600304030603, 6.349158738890003, 5.414796721550727, 6.766915186758965, 12.725783874911647, 13.06800086652079, 1.942600773707513, 0.058783619484353455, 6.22998389505571, 46.84351375026088, 58.401707064720895, 56.247388393648215, 54.195745606576246, 56.33857173304404, 56.126642150263635, 55.76745894647414, 54.150748175959436, 57.357407385303134, 56.06221329781317, 55.52822966729441, 52.37106684715518, 44.77509498596192, 40.00048006734541, 42.22476597755186, 44.351902623330396, 46.92038043852776, 50.81066954520441, 52.49973235591766, 51.79940885113132, 53.197780886004054, 47.45240288396036, 40.15309556838005, 40.6788775228685, 41.25978446775868, 39.457988815922896, 40.401291385773696, 40.13607640420237, 40.82973580206595, 38.36734633291922, 39.846397599866314, 38.534886452459524, 38.88642887915335, 42.83238818568569, 48.59363609744657, 50.8648374772841, 52.71283472737959, 54.6993112564087, 51.80000505139751, 53.40069686212848, 53.74022899135467, 50.992938164741766, 53.68906167245681, 49.485822339211744, 50.74297728077058, 48.85802345891153, 47.424350092487956, 53.638423873532204, 56.47721967389507, 52.049612922053186, 51.431706259327555, 46.51812568787606, 52.625765954294515, 52.057026201678866, 57.5072850719575, 65.55188586634975, 53.489130620033514, 53.471138708053104, 52.210849792726584, 52.6042046854573, 52.059097213129846, 43.76484540201003, 35.329156844846665, 37.68905478139078, 36.8413717516007, 39.1489335029356, 38.86524808022284, 38.73422914935697, 38.14524212191182, 37.15180381651848, 37.25950033433976, 36.892182134812884, 37.50326779580886, 36.79000831419422, 37.20616002236643, 38.49242287297403, 38.98864192347373, 41.58025387794741, 43.871792747128396, 49.468865932956824, 48.59045897760699, 50.24594629964521, 48.61436582380726, 49.93926794298234, 49.74959388855965, 46.7656703918211, 47.22120661889353, 44.77525972550915, 44.7827200735769, 47.112392225573146, 47.84624807296261, 46.078396612598056, 49.10093976605324, 50.82900662575999, 49.25401026202787, 48.628321616880356, 44.98912303678451, 10.634714403460103, 0.1087537804438222, 2.470230532269324, 3.036458987382151, 4.10687233651838, 5.041181647008465, 3.6990568907030172, 1.8751557411686068, 0.07014074272686435, 0.10900699548543462, 10.24772551751906, 43.0571243070787, 24.068361559221824, 34.09071945375012, 24.953550292599587, 1.9472189968632114, 0.0038879891038842264, 0.041844660881906755, 0.0632612003884729, 0.06604923566262569, 0.035248230166372754, 0.023545591693912304, 0.10087376941115626, 0.033161743739319426, 0.07105356713216152, 0.016494401610426365, 0.04291928305681195, 0.01590191495544728, 0.06904896018245528, 0.05682637209012624, 0.019599727520178405, 0.057229908904240984, 0.0340703125261972, 0.014701806620935039, 0.09123297423244485, 0.07191869490329297, 0.019938254113038702, 0.025404029067665822, 0.016626923330008023, 0.04345971212211636, 0.01978561683978525, 0.04271337394452384, 0.08380156130559983, 0.034268143241323774, 0.028762847725902835, 0.0742158861530404, 0.017980715605400262, 0.026496983726599047, 0.04029005397892287, 0.008629424095664535, 0.05608528544525466, 0.10481546032092265, 0.012605857092797036, 0.045896951905301506, 0.011712139877941341, 0.009159269656295018, 0.05271470542216013, 0.032793293752136736, 0.036751616430739244, 0.06376607531321145, 0.048346077542631864, 0.027627779298552105, 0.09807067667885173, 15.233272756299666, 43.69079497552688, 32.59576493693937, 46.33582568937733, 34.19736477636522, 2.3373178320546306, 0.05910231206085413, 0.29791523011461385, 0.7158801151860146, 8.170636844250465, 8.20429519299538, 10.76918992304033, 6.270570130117479, 3.493579361707934, 0.12897726058238937, 7.615764141082765, 50.544811294924834, 60.144827981149, 58.670628686105054, 57.41041037344164, 56.93734899643929, 57.63513080535397, 56.23131059831189, 55.8629176693578, 58.357011656607355, 57.93600405416181, 56.030438177047245, 55.34709853510703, 48.10595996918217, 41.77550162038496, 43.52143879859678, 45.90845600251229, 47.86113346776655, 52.15384990938249, 55.07172461478941, 52.86556397714923, 54.1828449310795, 49.05103545035086, 42.64480083219467, 43.46066167277675, 42.3313916883161, 42.08444318463726, 42.749335919657064, 40.688291211282056, 42.77458421645626, 39.61242429671749, 41.42925439342376, 41.672088330791844, 41.29800796508789, 45.62491962986608, 52.26053053332914, 52.34656772305889, 55.36898536066855, 56.39704250520276, 54.17454519579488, 54.41306060360324, 52.99698691214285, 53.449530370773815, 54.5572155521762, 49.472921663715, 51.381970605542584, 50.21724631709438, 48.05584776786066, 53.15676858348232, 56.519408687468506, 53.0512019126646, 51.661482626392, 48.36582876020863, 52.19983969965289, 52.92648230829547, 59.022108354876124, 58.66474120847641, 55.514262107110795, 55.31936737798876, 54.590551776270715, 54.05441868689753, 53.663276010944, 45.68192735795052, 38.26470967262022, 39.128780364990234, 39.941668048981704, 40.34736271827452, 41.32669225815804, 39.60061404012865, 39.09833885008289, 38.737896565468084, 38.848915330825314, 38.31011502973495, 38.92105556303455, 38.33917979271182, 40.5457797358113, 41.51291070445892, 40.5076660648469, 44.93897161176128, 45.57388567155408, 51.116716400269546, 51.707025266462765, 51.88455174046179, 49.75357117191438, 50.81474881018362, 52.28249188392393, 48.10120605653333, 48.350417767801595, 45.42550633030553, 46.55417226975965, 50.048976636702015, 50.11774755293324, 46.42494586206252, 51.84713232901789, 51.58047783759333, 50.95380859990274, 49.33984741087883, 45.44587519861037, 12.78371237939404, 0.13557192929569753, 2.6457860152567587, 4.320546148284789, 7.328057798647112, 13.046663172783392, 5.809893146637948, 1.7216774412701208, 0.09643612084008994, 0.028902831141866987, 11.240513690056341, 49.764028210793775, 25.946986636807843, 35.09167694276379, 33.89026672609391, 3.7190474954343613, 0.08594155131328492, 0.04415626607594952, 0.02226255721442642, 0.033927670785135804, 0.02503668607753371, 0.0512160727333638, 0.06794097487844768, 0.09598933070177033, 0.007788859018605323, 0.013946704397488748, 0.04580141691070411, 0.017881076294748534, 0.04390413504874995, 0.05859527293772948, 0.019599311917479482, 0.0440623743399497, 0.047215887180138985, 0.06590589295111357, 0.07381828652033884, 0.042457987043646075, 0.11559894458661157, 0.1277090250063808, 0.06640211108230776, 0.18850311967394046, 0.07821006174649923, 0.10317043206023593, 0.11054768257083432, 0.08843250152084137, 0.16981904725393943, 0.16436811716806504, 0.1926394735252665, 0.07459411142213691, 0.14036992264370765, 0.14736591417702938, 0.14472065853976435, 0.11393392143110115, 0.1197770502298109, 0.13042649975226772, 0.2666707018450383, 0.11910402666657202, 0.18449222038109458, 0.15908747310599974, 0.1720249514666296, 0.2237949976997991, 0.1542407565660054, 0.15033586852012143, 0.13787644434600108, 16.95174647915748, 56.02850052618212, 43.99533956281601, 50.22264742082166, 43.41175363909814, 3.446505036084883, 0.5882490089824123, 0.7461570131201899, 10.636929562014918, 17.257246163583574, 16.089266307892338, 22.89528850586184, 25.78171168604205, 6.210015598804721, 0.24170671559629903, 7.830593826309328, 51.20339293633738, 61.93243642007152, 60.08010887330579, 59.19734808706469, 59.86686529651765, 60.64827203750611, 56.89024917541012, 55.51752944146433, 62.332490721056544, 62.11106900245913, 58.673052710871545, 58.89645130403581, 50.54681954845306, 44.421379566192634, 47.76885186472247, 48.87187727036015, 50.82641393907609, 55.30507426108084, 57.48561005438528, 56.79010322017055, 58.27690116820797, 52.056045609135786, 44.68821840901529, 45.54650752775131, 44.89755922748197, 44.56684850877331, 45.68640670468731, 43.506569093273534, 44.66463319716915, 42.772776003806825, 42.78435091818533, 43.06483176446731, 42.005434882256296, 47.122092247009284, 52.5791407400562, 54.809141543603715, 59.95785643977504, 59.491023786606334, 55.41584199474704, 54.91669293372862, 56.261916852766475, 56.97601572159798, 55.84389025165189, 50.46634035725748, 54.416743709195046, 51.44751733349216, 48.45818488828598, 55.751945972442634, 59.543885569418634, 55.012081053949174, 53.93983448705366, 50.71060988210863, 54.867027882606756, 53.9955242987602, 60.78415862975582, 60.92043745902277, 58.12821195971582, 55.74805105886152, 53.922156364687034, 55.572434779136415, 55.04569576632593, 48.555443979078724, 39.357819326462284, 41.677183489645685, 41.91384753873272, 42.42907439508746, 44.29860937979914, 42.650817748039, 42.18656209207351, 41.545846846795854, 40.87373302828881, 40.6147232363301, 41.27757241649013, 40.36179311813847, 42.1410116072624, 43.92519581702448, 42.32193093146048, 45.96363590609643, 48.266479046114036, 53.42872219700968, 53.81248689466908, 54.33283244409869, 50.67648133923931, 52.41003951718731, 54.50714649692659, 50.75818430992865, 50.423131527439246, 49.18836939719416, 48.25401375370641, 52.01789271446967, 52.327038241970925, 49.50184129899549, 53.49453956850114, 53.395440886097575, 53.83318524206839, 51.49813159819573, 46.5929998120954, 12.405190910062483, 0.18535080576135268, 6.637848615646363, 9.007413233480147, 12.072798475142449, 18.77551720988366, 12.134800361048791, 4.667124325229276, 0.4314769293752409, 0.22700620845200556, 17.31838610864455, 54.34622733823715, 32.18035259554463, 44.17980078727969, 39.20039892196655, 3.250117845112278, 0.2005908686307169, 0.10207814389779683, 0.175515171440859, 0.15676765161896908, 0.12694325117814925, 0.1325303916969607, 0.23649439125532107, 0.2738884145454053, 0.20612413784669292, 0.11630765252536344, 0.1285297273387832, 0.059099565635645585, 0.15362019470382124, 0.10372560065720351, 0.09903485195771342, 0.16852529328917304, 0.13424662783020927, 0.1168277572780367, 0.22891793490177204, 0.10767982476541113], [0.06153169561237578, 0.06617986131459475, 0.07306034211069345, 0.09325203726128226, 0.034750146611082944, 0.0865461555640063, 0.04067787832971062, 0.13824235858215442, 0.023551486740489642, 0.030409691614970088, 0.05985634559164605, 0.021769328741356734, 0.016592376595062595, 0.018817925217351126, 0.07025004049102146, 0.019861336970221133, 0.05649450663176756, 0.08272438039702755, 0.08252128282742155, 0.04158321805598755, 0.02081972062437525, 0.018431671346808155, 0.09402280598278008, 0.04554822868216903, 0.042685086147919785, 0.03544942783792654, 0.06524352567090143, 0.3414973899001076, 23.760879116673625, 31.359631938319055, 23.191327433432303, 46.5433112267525, 10.34663200378418, 0.07707936193553672, 0.0610979404600878, 0.9442234075357838, 5.403180622285412, 4.848374599410642, 12.447207339348333, 12.971178139409712, 2.606121046889213, 0.30409265670084185, 0.5817196109602528, 23.61906974546371, 55.372013430441584, 58.18829482601535, 56.85561856915874, 58.576958564019975, 59.818702513171786, 57.12661120199389, 58.320035472992934, 55.91465765430082, 54.8397477980583, 51.45453053136026, 44.67043046028384, 40.22956217488935, 41.76440915753765, 41.76784907617877, 48.01731048091766, 53.15779232209729, 54.93874057646721, 53.24759890956264, 55.91914484577795, 54.657212457349225, 54.495328395597404, 48.37121417445522, 40.60419167241743, 42.27636083479851, 40.20382358181862, 40.5130789356847, 39.13962179614652, 40.63519408625942, 38.99366647966447, 40.22609087728685, 39.43439183696624, 39.547312951857045, 42.16132164001465, 46.02334222485943, 49.25324932221444, 53.38354041499477, 52.765590606197236, 56.24629797474031, 55.34179549063406, 54.54234976922312, 54.5681118965149, 54.668320609677224, 51.87409862395256, 51.76399377084548, 48.92964201588785, 50.918185633997766, 50.19351205518169, 54.58837093845491, 52.73104629208965, 51.91703288785873, 49.834732855519945, 54.30002966234761, 50.00204547759026, 56.44276949667162, 65.61002715941399, 47.35278252632388, 53.57114738033664, 52.255137274342204, 52.161090604720584, 48.338611433582926, 38.906083876086825, 36.70189619064331, 36.8284357747724, 38.6391548187502, 40.075875866797666, 35.86490946431314, 36.63842831888507, 37.24631724819061, 38.4126732426305, 37.2264112195661, 36.55119088388259, 36.56661756577031, 36.89719100152293, 36.94207860577491, 38.49233658083024, 40.19031493894516, 43.13466564301522, 46.074623292492284, 47.3188030335211, 48.09916642404372, 48.83677205731792, 49.174613644999845, 47.54533167808287, 50.56338371769075, 49.866645259241906, 48.11942154361356, 48.187572725357555, 49.54722312188918, 49.29452442353772, 48.89154403440414, 51.260306527537686, 51.02070854556177, 50.097394374109086, 50.35534120375111, 49.97434177706319, 28.9102529710339, 2.5187725597812287, 0.3659844710942238, 1.933800936225922, 2.068389101374534, 6.895949888613917, 16.023700948684446, 5.802742175517544, 1.2985452625059313, 0.21196607920912006, 0.15487385162663075, 25.413216775463475, 40.54585818321475, 24.13214125940877, 40.79761159035468, 11.172791027253675, 0.23943600034521473, 0.034910251326378317, 0.11247948818509618, 0.026718773841557485, 0.033442001684658954, 0.05978748960901172, 0.01338124628208818, 0.027767360518356005, 0.049631232170448195, 0.0609774386600381, 0.032745087669501384, 0.04599941616517402, 0.022044256629963076, 0.05995664948357209, 0.019014941964058146, 0.046741387641598145, 0.08769980736918027, 0.05542922689909897, 0.06360266109808319, 0.056905685172927, 0.062219929851351254, 0.05252831239974307, 0.02105576955082436, 0.05184621835548071, 0.04472603630875388, 0.04604566489316283, 0.03801455067831182, 0.02824987333658482, 0.04085243912413716, 0.034892267412355835, 0.011754740112190767, 0.05004459789263145, 0.01312743943755425, 0.025394696201528275, 0.08320715368515061, 0.03924856510674281, 0.03619652827300372, 0.06409000027023497, 0.0631394115607104, 0.006951514383657806, 0.06002571230994598, 0.04018721433596746, 0.059079153222903136, 0.022289339648259264, 0.0737489632240707, 0.06487214922784798, 0.04312837143398581, 0.022441758586454297, 1.1981192255212416, 33.71257943491782, 35.547264160648474, 32.61601809532412, 51.92033552354383, 11.20115956952495, 0.04195776993348714, 0.1068173706411354, 0.803632116125476, 2.4770706555535718, 5.2803432653027205, 7.14746795354351, 5.311077977380445, 4.7200738710741845, 1.804958920805685, 0.44205513272073965, 27.896349699266498, 55.351848525385705, 60.7683789345526, 57.97890301673644, 61.2788087321866, 60.787057261313166, 56.80625946291032, 59.998594176384714, 59.2481114018348, 56.44998273541851, 55.66228059030349, 46.09280740061114, 43.96042654591222, 42.62138428226594, 43.96163855829547, 49.84034184486636, 54.70450055214667, 55.63265100602181, 54.20354327847881, 56.110595733888694, 56.89281832787299, 54.864462652514064, 49.34593492938627, 41.41676164442494, 44.21452945278537, 42.17168454200991, 41.824393964582875, 41.44991351712135, 43.81101169893819, 41.27901584871354, 41.33788670262983, 40.72941334016862, 41.645357378067516, 44.69960112725535, 48.539075928349654, 51.08840080999559, 54.12573914374075, 54.166880884478175, 57.83332032542075, 57.260332645908484, 55.54056944385652, 56.345161314933534, 55.170391836474025, 53.09315558402769, 52.915974278603834, 49.23370022927561, 51.57557487487794, 51.743338569518066, 56.66080228744015, 54.37963416499477, 51.737815872315444, 52.62757808931413, 56.143790752657004, 52.111139220576135, 57.01389797272221, 65.5922313659422, 50.0808302048714, 53.849521913836085, 54.945118350367395, 53.24333529318533, 51.91784874085457, 40.39898503211237, 38.295990574744444, 39.25184865151682, 39.91363094698998, 41.98632901714694, 39.99003479557653, 38.39472447672198, 38.72596863777407, 38.69457006454468, 37.98584484284924, 37.693934209885136, 38.80817367184547, 38.37934094090616, 38.127658136429325, 39.68924783891247, 41.73585038031302, 45.26808200343963, 46.4452245158534, 47.95903974963773, 49.88761425018311, 50.90670093413323, 50.07036139888149, 47.29293107986451, 51.208801884805005, 50.49661713261759, 50.11931257863199, 48.33940375235773, 50.84740254186815, 50.20607148447345, 51.35863642538748, 50.759082532698116, 51.22674672834335, 50.536433112236764, 51.99954778917375, 50.552385391727576, 33.330744543383204, 3.776799002962728, 1.0312042337271476, 2.8494568024912192, 4.427300806968443, 7.346215430767306, 10.507880641568093, 4.703506760058865, 0.4179916368617166, 0.2604462987472934, 0.15378697204493708, 26.40333675569104, 51.18173360824586, 24.67236145850151, 43.9070156312758, 15.821844993099091, 0.30016593514911594, 0.01814365484601548, 0.0805250492187277, 0.0591673797387029, 0.06595948080141699, 0.06733763467280135, 0.029577869516346725, 0.11527046906731783, 0.0349920924993292, 0.047644685743556875, 0.02606622014765538, 0.02929515242877026, 0.03970802633933002, 0.010693262090846416, 0.009123104560609547, 0.015617181141410145, 0.03294094953866255, 0.011088709016480755, 0.06405615450574026, 0.02903190163534976, 0.027829660703578306, 0.11182948556398192, 0.13334318034110532, 0.15686842282452892, 0.14068164382009737, 0.18319713342333996, 0.27829620867006244, 0.09524136841777833, 0.2158690673569518, 0.18133530994096111, 0.1264979702330405, 0.2985532587814716, 0.10525532502440677, 0.13509323159533163, 0.2288747428646011, 0.18101787374865624, 0.14179948867569048, 0.11982782653743222, 0.24329385059254788, 0.2039183868515876, 0.11100760345617611, 0.28094242957811205, 0.11990900121388898, 0.28407101008680563, 0.20893482251032708, 0.11200602286525312, 0.11352974876400926, 0.16707752500810932, 1.1901020234630955, 38.52734765698833, 46.23565227754655, 33.829681796412316, 60.11182515851913, 18.504956037767474, 0.20986643139152758, 0.4179382558551527, 3.288514662173487, 10.978518974396492, 13.094979909158523, 20.332568730077437, 20.458690581783173, 9.211302937999848, 1.5322465737981181, 1.0837078551130912, 26.532569046943422, 56.66293997918406, 60.511581359371064, 61.545074908964104, 61.3143571730583, 60.79027752722464, 58.59725682966171, 62.55226112181141, 61.01959105460875, 58.79552087476177, 57.41854144680885, 48.241128767690356, 45.23264731130293, 46.327420050098056, 45.96442822487124, 53.7569147540677, 58.22919337980209, 57.96470011434248, 56.461526270835634, 59.98769390967585, 59.30932391074396, 57.668753362471065, 52.37370267991097, 44.50144298614995, 47.78798126405286, 43.6716498867158, 44.28097048113423, 43.70122455781506, 45.38054420102028, 43.936241211429724, 44.63551744338005, 43.603765426143525, 44.002011514479115, 45.8547705219638, 51.66070599709788, 52.98814981214462, 55.706748500947036, 57.193456234470496, 58.50510074246315, 60.15537915691253, 57.47600416983328, 57.40616244654502, 58.358349184836115, 55.418403302469564, 55.552148280605195, 52.81924863015452, 51.71070444968439, 54.25541270163752, 57.51697724865329, 58.487587359643754, 54.11064586331768, 54.82464275052471, 58.268067990579915, 55.68177869243007, 56.64690532991963, 65.56054645969023, 51.483442321900405, 55.18598718027915, 55.11347040053337, 56.31121712346231, 53.01270384942332, 41.09768467564737, 41.05194591706799, 40.19736736051498, 41.964414734994214, 45.22556351077172, 39.75242937764814, 41.08926726925758, 40.93274900990148, 42.360715327724336, 39.76806002278482, 40.377937593767726, 40.56558378281132, 40.50044890372984, 40.43840877471432, 42.47611145819388, 43.40965517105595, 47.42140439248855, 48.99032500482375, 50.109432128167924, 52.184836633743785, 52.0520487139302, 51.68036099403135, 47.781681937556115, 52.65986311820246, 52.593512304367565, 52.954017346905125, 50.49170632516184, 53.76887013835292, 52.326630315473004, 52.53627315644295, 53.82148873421454, 52.99698691214285, 52.084627920581454, 55.50591530338411, 52.10924079341274, 31.902819410447155, 4.196879700306924, 1.2887474269636217, 6.2163732705577734, 7.365108016998538, 16.643044179485692, 32.766690061938384, 20.233222938353016, 3.4600330456610653, 0.5946198574477627, 0.3708662591393917, 35.66388407061177, 51.25976131808374, 33.52338390965616, 52.79908372509865, 17.858388616192727, 0.4785570159794823, 0.19446107739162063, 0.24837345786152348, 0.34624584800293373, 0.21708923091571178, 0.12610076896605954, 0.09676150902504883, 0.20726991426800528, 0.08393661494577125, 0.15081154783406567, 0.16139660000560746, 0.1033391246211625, 0.25117712515977125, 0.11750405203671226, 0.10538346855150116, 0.16232379622036414, 0.13520437563138624, 0.18170525379959615, 0.1991308122993477, 0.10338350409461607, 0.1651016463555636], [0.024509044934905345, 0.04550251621572722, 0.05689839584632747, 0.04778872559508009, 0.03177476261982755, 0.057410866532835274, 0.058023859446327535, 0.00912644470395941, 0.035256569033428546, 0.03971688997661395, 0.08513751139323558, 0.13183974811146337, 0.08970540257230883, 0.05961051946806331, 0.029941609978014906, 0.036528401392241644, 0.040719220264544415, 0.041722826088868806, 0.05084728566749443, 0.03620771698713784, 0.06784005811618221, 0.014825977024532136, 0.032877586406445315, 0.03714556948492124, 0.006972155665167638, 0.06329357526415298, 0.032494132587265585, 0.10625723013353926, 6.3476800053350395, 38.87508538461501, 24.724952597771924, 36.23405548834032, 28.93643871430428, 1.017476428420313, 0.1204815217023415, 0.048252461598284786, 3.158485639479853, 4.395544317460829, 3.097851925319241, 6.4102089597332865, 5.2206644031309315, 1.187716364379852, 0.014579971827897093, 9.585756909462715, 40.87501564333516, 55.56830452334497, 55.659687903619584, 56.45143793475244, 56.85088819073093, 58.01705591140255, 58.17991272095711, 55.294279898366625, 54.67898161180558, 47.9727876570917, 42.08263497198782, 41.71955293224704, 42.24077317022508, 48.214691992728945, 53.38505052751111, 55.499714036141675, 54.247379687524614, 54.115697876099624, 58.54533641569076, 55.19302783473846, 52.8067833377469, 48.1305100840907, 40.23411604665941, 41.71574038843955, 41.5591868277519, 40.248703341330256, 38.98228768379458, 42.01380914257419, 41.23204938827023, 39.848001849266794, 40.896827943863414, 39.886919606116514, 38.857262134552, 43.7794013177195, 48.051705744958696, 48.882942276616255, 52.360786314933534, 53.16714325258809, 53.57035898393201, 54.6833001413653, 53.049362321053785, 56.46341685325869, 54.067346818985484, 53.988228690239694, 53.517563881412634, 49.65453916980375, 48.42881810280585, 52.80353561524422, 53.20724948760002, 54.43203310812674, 52.08165868636101, 55.80952636657223, 52.14433816171462, 57.03969932371571, 42.374424011476584, 51.74351507617582, 56.69645270993633, 52.14892341244606, 51.898374172949026, 42.549675510775664, 36.48089808802451, 38.73416246906404, 36.48300047843687, 38.43248513437087, 38.92185180417953, 38.03372913791288, 35.69445894610497, 36.47782687217959, 37.18540676178471, 36.7402373590777, 35.760562650619015, 36.57643918068179, 37.80087763263334, 37.77114998909735, 38.64684266428794, 43.392930184641195, 45.107053018385365, 48.49400789506974, 51.48252448728008, 50.28003561881281, 48.83656809406896, 47.918439295984086, 49.555581692726385, 48.31206090988652, 48.42910443582843, 48.497549795335345, 49.8690261379365, 47.8417020459329, 51.68845676606702, 48.91126571163055, 47.8465187165045, 47.03181889749343, 48.52535939985707, 49.368421877584154, 41.61622201242755, 12.467527178026016, 0.31281040020046696, 1.4569245639347261, 1.5934832297986554, 3.8203802127991957, 3.0367806217362805, 5.1416286441587635, 1.5131914543528713, 0.1476270582286581, 0.07669630265163799, 2.736258670206993, 38.13951546146024, 29.17884119095341, 27.67772266941686, 36.3498281663464, 2.5063884114065482, 0.06355476145061754, 0.024411364894119963, 0.06738209075504734, 0.04241211752917978, 0.028154041482916767, 0.04007732668410867, 0.03721088997178501, 0.04727697503122111, 0.02437461757161204, 0.08432126769255247, 0.016764838308576616, 0.028766467491345062, 0.04212508736658962, 0.05082454817790178, 0.07870559039856158, 0.042084185932312286, 0.007713788626490222, 0.039946344801254814, 0.02803711731347346, 0.019567973175716978, 0.057579865528931545, 0.04011453557459097, 0.04967398753750229, 0.0352540179606407, 0.05521434689721754, 0.06860790038180929, 0.08108006459811042, 0.020941902072198933, 0.05739687393689829, 0.017503823957315857, 0.05493550621453793, 0.034811939263055404, 0.07348412662864694, 0.025743291104933428, 0.007782595292214425, 0.061238011976163235, 0.027352767140274088, 0.023120117952085795, 0.0504989837927203, 0.05380898541320236, 0.0424632347459274, 0.022453161805207213, 0.03045826158936947, 0.033641828058828274, 0.042662092018872506, 0.026025401067829905, 0.04959621046098971, 0.06584632195412152, 0.07968353227742257, 11.456698063881168, 45.4299033072687, 24.838703293954175, 50.80837103628343, 33.09485320122012, 0.7922872732723913, 0.042919758031325, 0.044706359340418736, 1.9249619976166759, 7.448453480197538, 6.908781922632649, 8.431829925506346, 5.411307773282451, 5.813212942692542, 0.3187986030693977, 11.443336509889173, 44.06160408450712, 56.869911686066665, 57.19124401769331, 58.07420876718337, 59.15768507988223, 57.9203224182129, 61.41306361844463, 57.597621179396114, 54.98511868138468, 51.338091050424886, 43.187535270567864, 45.8119539291628, 43.454095625108295, 49.15852408255301, 56.36496536193356, 57.05474161332654, 55.9826676307186, 57.02923836246614, 59.61304872266708, 56.94191463531987, 54.178165543463926, 51.1285109673777, 42.46621531824912, 43.6596631234692, 43.07228426779471, 41.84585717416579, 40.97493802347491, 43.95657870077318, 42.845210413778986, 42.495637016911665, 41.563619106046616, 40.974702681264574, 39.53731483028781, 45.08060055394327, 50.13306440845613, 51.002708788841005, 54.057737012063306, 54.65971885188934, 54.94097240509526, 56.155502949991536, 55.81806144406719, 57.68710613250733, 55.584986363687825, 56.94757069310835, 53.803132041808105, 50.37953046060378, 51.75727082837013, 55.08063231745074, 53.96233712473224, 55.5911680190794, 54.21989171735702, 57.138668567903586, 54.21843259565292, 54.57034372514295, 49.92392363086824, 51.6659462836481, 58.06986278103244, 54.66547296893213, 53.194215451517415, 44.49626937989266, 39.171655793343824, 39.948979346982895, 39.67394667287027, 39.83879604647237, 40.750743189165675, 39.27505339345625, 38.45649003982544, 37.69479320895287, 37.450562907803445, 39.62246164198845, 37.89704630451818, 38.36724435129474, 38.78245861299577, 38.75602183803436, 40.44814409748201, 44.33946086514381, 47.09743230573593, 50.20848766449959, 51.272501176403416, 51.320675726859804, 49.050400026382945, 49.04785048577094, 50.01897834962415, 48.806405067443855, 49.53948036316903, 51.4577978657138, 51.11593977097542, 50.157830253724136, 53.07080591878584, 50.287621482726074, 49.15483313222086, 49.24291779918056, 49.797756671905525, 50.55094980424451, 43.440402630836736, 14.967354689874957, 1.142365307577195, 1.7831804507201718, 2.4124081769297203, 3.8282305915509505, 7.548289568193498, 5.303359243177599, 1.573436240996084, 0.22536020725965503, 0.09221111529416616, 2.6167555730189047, 45.7300744518157, 35.95955233420096, 26.28144910258632, 44.87676282082835, 4.449830901238227, 0.057451568784252297, 0.05305366868513727, 0.037720909176935116, 0.02862074224638843, 0.0023028983653808435, 0.01799923003531031, 0.06473875033759302, 0.057808037156299244, 0.056047953980704474, 0.09491642456381552, 0.019879949076341528, 0.01639428349482196, 0.04648452602146615, 0.04091629638306556, 0.05080772105664496, 0.012435867928058631, 0.06804761431750751, 0.02613267827508671, 0.02205549513981227, 0.037718944161409335, 0.028361798782322197, 0.14006039247878138, 0.2169607120055345, 0.1003405262505816, 0.1255871070128295, 0.18060050904750827, 0.15542237058041558, 0.13071981949671624, 0.15919032807071365, 0.18259299648625238, 0.16132579815964546, 0.17809097354690875, 0.18947481027533933, 0.19401568919420245, 0.2776643393501159, 0.1877659592296808, 0.16882530864207976, 0.1495494026570551, 0.15073642525221073, 0.18307783821177098, 0.11110989151582604, 0.15973725356161594, 0.08842146985473172, 0.10305675227315196, 0.10662058563602549, 0.1831393703938492, 0.17581261273834015, 0.1603863751816173, 0.20824063959861958, 13.844702724487552, 54.13157170818698, 37.54626874000796, 45.40076009688839, 41.04161047166394, 2.2483709791014275, 0.3709133275814595, 0.22825260286129292, 9.59407429541311, 17.680177688598633, 8.180026017850446, 9.773448205763295, 12.444952957091793, 4.3688187579954825, 0.4026154861334832, 12.250069014487728, 42.85624404107371, 56.10615168848346, 58.70430615640456, 58.93258810043336, 59.09099694221251, 61.52175249591951, 64.59599248824581, 59.027685965261156, 59.30422875189013, 53.75457309907483, 45.59541163905975, 47.39068438929897, 46.66061755149595, 52.27285069804038, 57.98779502991707, 58.52333976376442, 59.34437421060378, 58.51867214325936, 63.04364781225882, 58.724392614056995, 57.09154129028321, 53.5890490778031, 44.28456337221208, 45.53197122389271, 45.832083532887125, 44.4903701351535, 43.6567723366522, 45.64724968325707, 47.2584181447183, 45.387639768662, 43.877978324890144, 44.374424872859834, 41.57286021017259, 47.641551340779955, 53.02064664902226, 52.27276440589659, 57.141363236211966, 57.433670028563476, 58.03917415680424, 57.45814561843873, 56.30135236247894, 59.76116134274391, 56.32945614476358, 59.07526431545135, 55.14064850345735, 52.21727463506883, 53.48626728980772, 58.35005337192167, 57.316238187974506, 58.092392875302224, 55.930052957227154, 60.88980767034716, 52.253156477405184, 57.567438540920136, 52.90038285716888, 52.54571037907755, 60.63152351687032, 56.695338756807395, 57.064453401873195, 46.15464748874788, 39.47354885839647, 42.89677389206425, 40.93445131855626, 41.03324405608639, 42.146055775304, 41.48891756611486, 39.02903841387841, 39.96437857227941, 39.169012115847686, 41.73478349562615, 39.98710870742798, 40.0369934112795, 42.037276683315156, 41.263377358836514, 42.20454615931357, 46.45176702930082, 49.561626065161924, 53.339994261341715, 55.51141446636569, 52.63636027612994, 51.23815298080445, 51.096163180566606, 51.37241571180282, 51.34189574949203, 50.83379583974039, 52.42294411505423, 54.38612176525978, 51.42547361312374, 56.87352811136554, 51.1770659877408, 50.118359442680116, 48.09244740393854, 51.281789348971465, 51.508494500190984, 43.84343793315273, 15.796743785181354, 0.9649159939539049, 2.7309411619940116, 4.180237083665786, 8.97359553844698, 11.586452030366468, 14.58800167806687, 6.564835165777515, 0.9391250004691463, 0.4216175003638191, 5.197015452769495, 50.65137817013649, 37.800744272047474, 36.27033349006407, 50.12922440805743, 4.789087483959814, 0.19242426410557764, 0.1551178199869971, 0.1497933097303875, 0.18258766451429936, 0.0793911854646379, 0.2395897848351348, 0.16315524676634421, 0.08287759032100439, 0.16184100761048256, 0.2267802278361013, 0.26307514478122035, 0.1591550267391628, 0.15516441345455187, 0.17107546209327637, 0.16517212644459742, 0.09066582402034153, 0.16744134016335013, 0.06165926457352697, 0.09553639653829799, 0.08913003223677797, 0.10687883387530044], [0.04134716338387901, 0.01754619244996819, 0.04474625336907564, 0.04053065921330164, 0.02512460615816376, 0.018531992475712494, 0.07277401674899363, 0.044304672628641135, 0.0373029699098439, 0.047977669690285, 0.057838680673270464, 0.06441241220360802, 0.07056864879785046, 0.014307530852214945, 0.04397204108235817, 0.005778126238334564, 0.016225882047306628, 0.01762019079779425, 0.015492151761727949, 0.02101526456704784, 0.06533497358642279, 0.028949376728926456, 0.020526822228285096, 0.04060394318413831, 0.013058883186820294, 0.1409882475291529, 0.061971253880690184, 0.008837825866536269, 0.2566615945749706, 29.398076188179758, 31.5005019018727, 26.326785818223033, 55.15130950558571, 8.829529823795442, 0.05096516744684308, 0.12702899173863474, 1.1149601974794943, 4.941624537591012, 6.562758761067545, 1.5824687240585205, 12.027831442894476, 5.203063747575206, 0.5453625489627162, 2.4351044816355554, 23.349757848247407, 50.352285677386874, 55.9774822573508, 55.83273503088183, 57.35692885614211, 60.511381318492276, 56.02309942245484, 53.1646486251585, 46.76666275147469, 45.153721378695586, 43.40203008344097, 44.1604164338881, 48.127117233891646, 54.35979089429302, 54.42367453728953, 56.320807318533625, 56.063276260129875, 56.85255912042434, 57.72076791332614, 53.407278599277625, 51.73197154075869, 46.263167704305346, 41.877447943533625, 41.05927290454988, 40.09932379568777, 41.64105061561831, 41.504677649467226, 39.98932876894551, 40.69402963884416, 40.26277680550852, 38.720477319532826, 40.8465313911438, 42.07306831113754, 39.939510745386926, 42.732822741231615, 45.57465445610785, 49.0533535711227, 51.34499834429834, 52.345591052885986, 54.6795738897016, 51.528549578882036, 52.11667368488928, 51.82976407389487, 51.95493082846365, 54.13960079992972, 49.42899504015523, 44.606225182933194, 48.645685949633204, 53.09290847470684, 54.529237285737075, 55.266948823005926, 51.60092515330161, 53.01504942678636, 42.8813236759555, 42.94619575623543, 58.613095360417525, 50.92459870922951, 52.20207152828094, 44.38403860215218, 39.51678122243574, 37.56992847688737, 37.64483005769792, 38.20080249540268, 39.42733549302624, 37.25458560451385, 38.760269764930975, 37.50984561058783, 38.93122626889137, 39.87350510012719, 39.05511433078397, 37.11301157551427, 37.74088105847759, 37.76202263370637, 37.93599544032928, 40.016526483720355, 44.71412566400344, 46.869377859177135, 49.067929098683024, 49.72724030094762, 49.89019124738632, 49.52757989206622, 49.47750299207626, 50.31148126048427, 50.38735951146772, 47.647042659021196, 48.48670051943872, 49.77428520879438, 49.43695745160503, 48.24689857421383, 50.4015035783091, 46.69786437865227, 47.32028961181641, 52.3095013249305, 48.34070597925494, 23.028917774077385, 1.9956498496955442, 0.8771311431642502, 1.2726484263135542, 1.2097627813777616, 3.1994025793767746, 5.6220366204938585, 5.1903734091789495, 0.9182108001362894, 0.1060475901730599, 0.04216889993497922, 8.862187477850146, 44.86055166490617, 26.80969430554298, 36.76881967052337, 18.923139533688946, 0.10362431617273439, 0.03354584490279517, 0.02671416773791275, 0.029267613483112187, 0.04017388057564536, 0.027940996261613987, 0.04987090277755934, 0.07831612661961587, 0.04245889485783635, 0.04869225735385572, 0.05399953063216902, 0.08619141855066823, 0.03385339473043719, 0.0677568686284846, 0.044807034784988056, 0.0331477971086579, 0.012002399101132348, 0.009775479181459355, 0.049405573311472134, 0.040831536415123174, 0.044673260511650194, 0.0409321773857359, 0.1024171837695664, 0.037933088718883456, 0.05459430980526152, 0.05087555048146075, 0.03306755705946877, 0.03995679041010238, 0.017143025273276914, 0.04097037452964052, 0.07482009203804117, 0.041441832699121973, 0.03286873809091988, 0.006416551834498082, 0.01602621176355188, 0.0514338102432028, 0.04551216509313353, 0.025186316455684366, 0.02627015658353846, 0.07103069940762174, 0.03193456089995321, 0.014361876171953497, 0.09542907528098553, 0.04402901121084729, 0.011464747104553447, 0.04085830735763715, 0.04579513882016463, 0.03743472171106166, 0.03974050463687989, 0.028682617252812754, 0.6305333851806579, 36.78716067344912, 32.369026445573375, 26.95760492355593, 54.87883421682543, 8.425496278270598, 0.019756191402613636, 0.16037949571205726, 0.6212932003601905, 2.413482906356935, 4.94164611062696, 5.177767401741398, 7.014969798826403, 10.438669439285032, 2.2915736802162665, 2.5434604479420573, 26.87206783602315, 50.268366567550174, 57.17592323980024, 56.15210617742231, 56.400996254336455, 60.659089934441354, 58.17900273107714, 56.33666938351047, 50.49169455805133, 45.63264277673537, 44.57665835657428, 46.22392439073133, 49.12639987084174, 56.01488990168418, 55.89939963433051, 56.80068185252529, 57.98305288437874, 57.724560845282774, 59.3359136581421, 55.27203613711942, 53.45964224107804, 48.2078121554467, 43.19324231916859, 42.976802010690015, 43.77799318682763, 42.26338171189831, 44.127790158794774, 41.77081046565887, 43.14511483715427, 41.33890651887463, 40.66518060622677, 42.2519362357355, 43.42860021898824, 42.45003946365849, 44.676714097299886, 48.461342396274695, 52.80394746411232, 52.63173187932661, 54.291322000565074, 56.39475968576247, 54.14011070805212, 55.45375562483265, 54.95646184490573, 55.05080269229028, 55.860058261502175, 52.08756577584052, 46.82805176704161, 49.958424798903934, 53.96434930063064, 55.343666461206254, 56.7526485073951, 54.52209857202346, 52.99005216167819, 48.369668760607325, 44.682044598364065, 59.00776032478579, 52.477931822499926, 52.30516318351992, 46.42169421718967, 41.79717663795718, 38.93679995690623, 38.582417734207645, 39.36402451607489, 39.95741636522355, 38.915285756511075, 40.06252019636093, 38.861086445470015, 39.73968167458811, 41.962759494781494, 40.066611228450654, 39.99626744178034, 39.14365399268366, 40.94521037993893, 39.61032582867531, 41.795187996279815, 46.939780481400035, 49.50899177981962, 51.296015785586455, 51.01844533797234, 52.32120175515452, 52.09549288595877, 49.67977569949243, 50.935997116950254, 50.33016743198518, 49.3909284376329, 49.624183947040194, 51.41908014974287, 50.410030811063706, 50.2148340594384, 50.97187111454626, 47.4346306247096, 48.10765443309661, 53.57598366275911, 50.03334991393551, 26.981953036400583, 3.293123447125958, 1.983036365239851, 2.2589623591592236, 2.8433876700939673, 5.818818990261325, 6.650155542358276, 3.0615673045958243, 0.8786831147247746, 0.06876944534240231, 0.03978305316019443, 10.320285443336735, 51.83738131676951, 26.138415951882642, 39.619888567155414, 26.042374757028398, 0.28774164376720307, 0.04924178371326097, 0.044186675936103835, 0.04445997397265127, 0.02952204468930441, 0.04069385892381111, 0.04354211253925197, 0.016940954261489453, 0.04697946861626641, 0.06122915983019818, 0.05803938421811308, 0.018792607926673466, 0.00019733241383472624, 0.07237940485919676, 0.05735773067440718, 0.04424434320460405, 0.003483237561604549, 0.05555793350081771, 0.042394175749993136, 0.032842664288416985, 0.01207241187653234, 0.011876620870504168, 0.1460360774710294, 0.11783844941566068, 0.11008272848783002, 0.13498608653824176, 0.12804347601148391, 0.13026965091065054, 0.1352425574535324, 0.13537507534267443, 0.14544565350778643, 0.12663090947054087, 0.13499057581347806, 0.15381530197637697, 0.15410981681798736, 0.12098370765846585, 0.20423691088874496, 0.10664080269634725, 0.087907976440845, 0.20971782565597566, 0.14107081648563186, 0.037615828726801186, 0.23823328826936985, 0.07172954779478811, 0.13441038678490347, 0.16407913348126799, 0.10635869081823096, 0.25642960782974, 0.14528379445114445, 0.07475280653565161, 0.7871548519019158, 41.9029551167642, 42.71305007319297, 33.85688343355733, 67.63642557205694, 14.388578572580892, 0.13709681198721932, 0.7495958285947001, 2.3319699254728135, 9.987726307684376, 15.777039758620726, 4.4184455660081685, 20.851580673648467, 13.30441584510188, 0.9503969730388735, 3.2449663021872124, 26.774285108812396, 50.822326829356534, 57.32553028291272, 57.58234354757494, 61.40365385240125, 64.3614229848308, 60.85383561349685, 58.9811509655368, 51.81231344899824, 50.25535998805877, 47.61149814051967, 49.14804350945258, 53.02405911107218, 57.06468482171336, 58.38174220054381, 57.12895677935693, 59.99030228584044, 63.2047591670867, 63.02846039495161, 57.32168243777368, 54.72127652937367, 51.5458119300104, 45.35646084816226, 45.052281041299146, 44.94077590204055, 45.38897729689076, 46.84039938834406, 43.23190904432728, 45.53791753707394, 43.66855905902001, 43.86233591264294, 44.89509597901375, 45.40003053603634, 45.122954307063935, 47.01964778284873, 50.578147519019346, 53.976547871866536, 55.09637671132242, 55.30767479250508, 59.57113427500571, 55.17025847588816, 58.46198604952905, 57.36411463829779, 57.18004957322152, 57.91728650369952, 54.40488246179397, 49.89159545590801, 51.40297882018551, 55.45130414347495, 56.27158157287106, 58.10168889261062, 54.70781887731245, 54.7397469705151, 50.25024913972425, 49.73441039362262, 61.666786055411066, 55.14994059839557, 54.127657182755016, 48.41168518989317, 43.423575662797504, 41.09895160121303, 39.74167031626548, 42.8436924565223, 41.609471613360995, 39.43357206160022, 42.05033817598897, 41.523273606454175, 42.62638138186547, 44.82190062922817, 42.86373184573266, 42.44816457071612, 41.24812718360655, 42.810273862654164, 41.094166309602805, 44.63411715722854, 48.48971682210123, 51.064337068988436, 51.51414663560929, 51.99899081260928, 52.566573466024096, 52.10915057889877, 52.841578683545514, 52.16307924639795, 54.39952450413858, 51.34348038704165, 51.03421718843522, 53.17849459186677, 53.5208704394679, 51.39625195533999, 53.9119738917197, 48.34354185288953, 50.75544649554838, 53.761900086556714, 50.81609026078255, 27.210884132692893, 3.0593889182613743, 2.1945072758582334, 4.93212063466349, 6.548720598220826, 9.654187560081482, 13.341591089002549, 13.337590271426787, 3.2009604957795914, 0.5005046382786766, 0.13990562739631823, 14.121220996302945, 58.74067829501245, 34.75557688743838, 48.79899571018834, 28.440690348225257, 0.3374885743664157, 0.08325865011542075, 0.10485423969164973, 0.10039838121062326, 0.1918377471907485, 0.16975034448888995, 0.13842906953106004, 0.1375737323636009, 0.15404782498315459, 0.14629945849939702, 0.12666128485673858, 0.24870624645583092, 0.14844778354369825, 0.19752372837355062, 0.19128440188304072, 0.19278233360138633, 0.12707174710568883, 0.21188838257183953, 0.21883261720499686, 0.13512130105687728, 0.14085873270467406, 0.16961589605817873], [0.03270913133277528, 0.11719557907312148, 0.030334157260855844, 0.08353677833633077, 0.030462528699107712, 0.043448711099523696, 0.07325892742242544, 0.024842515347465396, 0.033110457983228474, 0.0660486304531655, 0.014368024027545848, 0.022916083839992364, 0.029252372163858627, 0.0655681247852983, 0.014248348644844467, 0.04492567116094213, 0.07059707065984126, 0.021878069176548914, 0.0943258473829877, 0.031177118277898243, 0.01699652244907714, 0.028860002996460087, 0.035693411520051385, 0.038594241749735615, 0.09606770149642423, 0.049542243397163774, 0.023563514320900845, 0.07199434608581566, 0.11411445771133709, 13.15737795445227, 39.834112736486624, 39.58973338527065, 56.82746771843203, 23.96461682934915, 1.0089912998580164, 0.2121993989473389, 0.17473186186004072, 2.4790075709742885, 6.558630956757454, 3.908808577445246, 6.506907641887666, 15.995914878383761, 2.0536575370257903, 0.39933417833620505, 7.265288108779538, 37.28582336056618, 51.6454009086855, 57.81381045618365, 57.70447046526017, 56.13052137436406, 55.89428094125564, 49.543728290065644, 47.39670522751347, 44.28296304518177, 48.25133869724889, 52.292431169940585, 54.50514608813871, 54.97612860894973, 59.273932364679155, 57.70260733942832, 56.26312886514972, 54.8364608518539, 50.60711030037173, 50.314795663279874, 52.19183021976102, 50.353458466068396, 50.959849049968106, 44.51140188401745, 42.18383996717392, 40.35496427166847, 40.24083114439442, 39.681254048501295, 42.423861565128455, 40.121234155470326, 41.3057428790677, 39.46486865320514, 42.52608245418918, 40.560323884410245, 40.080461117529104, 43.13088447816911, 45.542004646793494, 45.36321909196916, 48.6972729621395, 48.00952849849578, 52.03498640368062, 49.556311253578436, 52.48733766617314, 52.337518815071356, 53.063996684166696, 49.932768575606815, 46.651588255359286, 51.25188127640755, 46.74221854056082, 49.78680149201424, 51.66248283078594, 48.2481066642269, 50.23835259099161, 45.63556886488392, 46.54684920464793, 54.66205658451204, 50.79758451830957, 48.33646197472849, 39.86216552795903, 36.81127540526852, 36.62247603939426, 39.35176318691623, 36.966295319218794, 37.90876634659306, 38.69642926800636, 39.22247402129635, 38.919757258507516, 38.45366985567155, 37.19029795738959, 38.21103595918225, 36.78160659728512, 37.54897909779703, 38.25906145957209, 36.578357219696045, 39.16960831611387, 45.60557057780605, 48.17618608474732, 50.902500075678674, 49.11591537537114, 49.427630055335264, 47.98027546175065, 50.28941400589482, 49.96278255216537, 47.42444422937209, 44.3784962930987, 44.14424057929747, 46.80683174440938, 47.66030027020363, 48.149313926696784, 48.69039312485726, 48.02197025668237, 45.724261499220326, 47.396928802613296, 26.61934364226557, 4.847104241771083, 0.08049328721338704, 2.241921376797461, 1.6987602580939571, 2.091449696210123, 2.5796563250403253, 3.660231064404211, 1.3492423872793875, 0.7624783631294005, 0.11812893463478935, 0.1143616589627439, 22.828721961667462, 40.8996912740892, 22.322342011236376, 35.30529706708847, 6.090783880602929, 0.09555058448665565, 0.034730611369013786, 0.0598835570347165, 0.038450240202608614, 0.028165739645520528, 0.10927162523711882, 0.14505284958549086, 0.06768823481134831, 0.03417324409970353, 0.01218429135699426, 0.047433417846238425, 0.03997645588711866, 0.047617003156413, 0.09509449404093528, 0.021595863452661904, 0.05920934603519498, 0.03367817510039576, 0.07666834810328099, 0.04393405461263272, 0.04513942501357487, 0.08264676036853945, 0.040665548144569325, 0.022293493760028676, 0.0770835830799995, 0.01886201549261328, 0.031666954896683176, 0.04874681430538336, 0.06823316081276826, 0.03571293527080167, 0.017716486134656498, 0.023231126007533843, 0.057202502108749845, 0.02414569517807855, 0.052716574676695376, 0.06021273735490057, 0.007611346391645531, 0.036450026767148126, 0.010330028204818167, 0.06426108685592491, 0.0103045126888901, 0.00798792983855932, 0.1148793352166972, 0.04725716399749921, 0.0889862145507528, 0.019394009929871368, 0.07171827864142195, 0.09292090341689126, 0.11611454474229006, 0.02573443704374856, 0.03069391215009795, 0.2053020029298721, 17.122877528590543, 41.937848521817116, 34.17858054561, 66.77055451177782, 26.800559105411654, 0.6470830906783381, 0.0318519095890224, 0.5396085544939965, 0.7875111747172572, 4.122218854965703, 5.364289831730628, 11.986771091338127, 13.071116209030153, 6.121717162670628, 1.330122671300365, 10.362238134107283, 39.58430874732233, 54.518776324487504, 57.225800098911414, 60.81905203480875, 56.388248551276426, 57.37784685627107, 51.477076315110736, 48.338132904421904, 46.70883917039441, 49.24897786109678, 53.59248507407404, 57.11070599094514, 57.63858249110561, 59.15382939000284, 58.287358207087365, 58.01502412365329, 55.77796697616578, 54.450095622770256, 52.868046837468306, 55.88229810037921, 51.280789144577525, 49.83461910678495, 45.586413721884455, 44.168398457188765, 42.55062080198719, 42.963948403635335, 42.49435047949515, 44.162569815112704, 42.3498817413084, 41.8209187446102, 42.3643474425039, 44.14658223429034, 42.833659033621515, 41.82252299401068, 45.14296231731292, 47.43138290220692, 49.54526978154337, 52.338162083779615, 50.565097793456054, 54.2747695984379, 51.09117784807759, 54.183033204847774, 53.39507218330137, 54.832083486741595, 54.04725643896288, 47.82706768281999, 50.56677264551963, 48.781376423374304, 51.22959436908845, 52.33090177659066, 51.323119363477154, 52.778334386887096, 45.635490417480476, 47.616860020545225, 57.30449461167859, 52.622290734321844, 51.4311610498736, 40.51509895632344, 38.672071349236276, 38.79237436479138, 41.070510495093565, 38.628254552041334, 39.89429366204047, 39.62112411375969, 39.96094257600846, 41.026885894037065, 40.18665536757439, 39.66992624344365, 39.38766856347361, 38.80598891165949, 40.209769894999845, 39.207827891072924, 39.94100516842258, 41.329979204362445, 46.82749479047714, 49.77881946871358, 51.30747695122996, 49.71982309895177, 51.13065258149178, 48.646435122336115, 52.86939613280758, 52.7785736514676, 48.97207813878214, 44.87689618141421, 47.507504340141054, 48.64319524457378, 48.753009842288115, 50.59693174977457, 51.062681828775716, 50.767856874773585, 48.105740316452525, 47.93572910370366, 31.310688603308897, 7.423839626773712, 0.5777135226995714, 3.7394109704802116, 3.233236699335037, 3.7291444117023103, 7.786925588884662, 7.576807650827593, 0.6073762632666097, 0.3656922851599032, 0.04318112424845177, 0.13983317080043978, 24.737412006624286, 50.5275018753544, 22.920344606522594, 42.77966368582941, 9.095916613455742, 0.07855935187469568, 0.03367891437524269, 0.10494433929242435, 0.07774643299560394, 0.0010792895655838714, 0.046466358246341835, 0.08270881349040617, 0.04501095206867303, 0.028243474587197268, 0.0297582334267997, 0.0801856799291507, 0.11559948850903781, 0.04178539632008441, 0.028874794239058133, 0.047576078739497936, 0.009119167826288651, 0.037120399666169, 0.06721042577297458, 0.03431931025378647, 0.04332682651077067, 0.07155383020759591, 0.04363580509239147, 0.12277561795687485, 0.2257461929994245, 0.06601434035767471, 0.20462711011209797, 0.10558019226957714, 0.09476352107500839, 0.1997947653815631, 0.10603985268502467, 0.09400418238534082, 0.14441906504573362, 0.14275345200252149, 0.08313712558799213, 0.08672757284535516, 0.1707892669665237, 0.11184483030510527, 0.11290183245775201, 0.19726961700906678, 0.14681324302669496, 0.12729672414641227, 0.1942234675610258, 0.08489825447360355, 0.2286785017819174, 0.10793860160535383, 0.17325446129806582, 0.1597205068795912, 0.15438439805180798, 0.14997349361017828, 0.23079648974441716, 0.2840651878185811, 18.76003561481353, 52.86659948287472, 49.801110298402854, 65.99737690341088, 34.448694567526545, 2.503970515343451, 0.48271855880175873, 1.0579136134155336, 6.440001322377113, 13.021169727848424, 9.605671763420105, 11.117597395373929, 26.61092035232052, 7.21330983984855, 1.499125712340878, 9.492609443203095, 39.299215193717714, 52.81049389992991, 57.87948269997874, 62.931977933452984, 61.1417571959957, 59.437648173301454, 55.10605712090769, 52.797589302062995, 49.87811819199593, 53.124381572969504, 57.079750645545225, 59.551765611094815, 57.88254607108332, 63.29651517252769, 60.068012283694365, 60.47334609493133, 58.24041920323526, 57.0805900327621, 56.27467240056684, 58.53389486189812, 54.9046394901891, 54.58320909930814, 47.8017605504682, 44.7905687362917, 44.35775479962749, 45.54429138860395, 44.162765933621316, 48.16320696184712, 43.78089574075515, 44.17809063388456, 44.43209155913323, 46.83874807050152, 45.73077263370637, 42.85605968967561, 47.97037932180589, 48.568987923283736, 51.816883010248986, 54.10997121564804, 52.18031806330527, 55.99746281100858, 54.219546548781864, 56.09239985865932, 56.808997277290594, 57.07296886751729, 57.499871792331824, 50.44304147843392, 50.092134475708015, 49.693268652885195, 53.876711783870576, 55.33298584722704, 55.09318390200215, 54.75002358036657, 48.68270527931952, 50.11620998382569, 58.096793774635564, 53.991754901024606, 53.41074989688013, 44.04736980315178, 39.85232037882651, 40.58846296802644, 42.36222544024068, 40.69269995535574, 41.73394410840927, 41.78258149854599, 41.988533389183786, 42.893098631212794, 41.573068095791726, 40.13852004081973, 41.725573770461544, 39.95420002168225, 41.31207358452582, 42.19874889619889, 41.12327814102173, 41.872062529287035, 49.36445243896977, 51.64605594450428, 53.71973068483415, 51.52353286743165, 53.07194340613581, 49.98604612965738, 54.63575317013649, 54.27457347992928, 50.99861775675128, 47.32367461727512, 48.84817438740885, 51.73992610746815, 49.9408172792004, 52.88804700297695, 51.37937399648851, 52.26784967607068, 47.12021735406692, 50.207891464233406, 30.735006255488244, 5.76815422504179, 0.23614787436541052, 6.122485947224402, 4.834202095385521, 5.1297688676464945, 9.88782746176566, 12.594859080929911, 6.70274030777716, 1.8330468910355724, 0.30741790730145674, 0.26697051801508476, 33.03365245942147, 51.513860302586714, 30.30704821309736, 49.42953632723901, 10.432457385524627, 0.26249236637546175, 0.18577621438570563, 0.17685804696333024, 0.16460131433221603, 0.13899217479892317, 0.19415070452997762, 0.2621443173097026, 0.14667717048958426, 0.12897879275823795, 0.07727305960631178, 0.14563309990109938, 0.2413107860352724, 0.1883067406954304, 0.1823204070810349, 0.10250954332971766, 0.10195560047342893, 0.11451610994915809, 0.17722019204689612, 0.1842255145311356, 0.120737862382685, 0.2830887934373271, 0.10759064447014563], [0.02793934342691735, 0.04983695742163447, 0.051296707317833944, 0.05438373904795416, 0.008572153277665136, 0.07095573004335165, 0.009268276307040886, 0.03647502038567778, 0.046752963230134024, 0.03896670986808116, 0.022212336320550214, 0.03524226617188223, 0.07384492339746607, 0.04697677581721256, 0.015945506315948745, 0.05044094880201644, 0.034440229571754896, 0.029499224845259905, 0.06523244803951633, 0.03439336414298704, 0.04351885027943119, 0.0581484176819363, 0.037007528101845134, 0.07072711408498787, 0.05407833426650013, 0.03792860710452642, 0.03488349953606244, 0.06014813699068562, 0.03949676993333044, 0.8586465447179733, 30.736433998230968, 33.92757238880281, 31.298448847186183, 43.10392602797478, 5.550155755012266, 0.09109536185860635, 0.26423389873197006, 0.7402510268072928, 1.3856140355910025, 3.1432116848807183, 3.410878638106008, 9.381172945422511, 8.688528460841026, 1.129774989620332, 1.354743143723857, 19.285695975826634, 39.19020468188871, 59.074322946609996, 56.47037513794438, 58.49858176323676, 54.00720119476319, 52.94819262719924, 47.60544200097361, 50.05853153044178, 54.59294442207583, 57.67564496686382, 57.58470481441867, 56.31361761400777, 56.45654093834662, 56.25231881295481, 53.921603310492735, 51.786861188950084, 49.24364736003261, 52.47072642849338, 53.73447095194171, 56.193777438133, 53.26495931994531, 53.85433073966734, 45.279947173210886, 40.76147087158696, 41.301565554834184, 40.64488626295521, 41.57211495983986, 41.02188879443754, 41.33059893884967, 40.437110470187285, 40.29325362174742, 41.80195800719723, 40.457753904404186, 41.73022962385609, 43.93680995510471, 42.51247575206142, 46.078769237764426, 46.89196286662933, 45.688250218668294, 46.139314943744296, 47.29011874045096, 51.94070831421883, 53.93441377147552, 54.59444276748165, 46.38104277272379, 50.17845407609017, 50.561477445787006, 53.22132295177829, 52.838295659711285, 52.39570325420749, 53.63024573172293, 54.811538111779, 54.15289763481387, 52.59530874990648, 50.41836192530971, 42.068063366797666, 37.7641014898977, 37.06899473744054, 36.95929781083138, 38.334214072073664, 38.109756438962876, 37.431288380776685, 37.96581722074939, 39.502633233224195, 41.807468937289336, 45.036524880316954, 44.68830470115908, 41.026870204556374, 41.65620665396414, 37.97195573006907, 38.632639761893984, 38.01212080063359, 38.819901558660696, 46.16926224000993, 49.25215105856619, 50.50467368095152, 48.43757283303046, 49.119488654598115, 50.61329980050364, 49.6738999889743, 48.232574078344534, 46.455038286024525, 44.45030704621346, 44.10041593736218, 45.42298816865491, 45.82425448202318, 48.705251063069994, 49.529035091400154, 50.13630036384829, 46.14335498502178, 34.61033151995751, 7.9430089554479055, 0.28624400316226867, 1.3581361164969783, 2.4193360632465732, 1.414894161205138, 1.9714131566786, 8.50775916730204, 6.437619463089974, 0.5944529728543374, 0.37486508488655096, 0.02677125277959051, 1.2838341680265244, 38.35275119350803, 24.88193173562327, 27.39308999430749, 29.850574539553737, 0.536344652214358, 0.051610301579198534, 0.029598320233485395, 0.08276704383353073, 0.055475801214455604, 0.07424581720824204, 0.08931593113248387, 0.05228069363041751, 0.038583072187799605, 0.014301563984894705, 0.02027805815751274, 0.05004418803559196, 0.026848294411695776, 0.029603209789662115, 0.021972744237451304, 0.03433095095979591, 0.0805646176600168, 0.060975259139893524, 0.010928931803773008, 0.03290769366186953, 0.0537192190606748, 0.0892223688142915, 0.020833592561464158, 0.025556036233601552, 0.07378804136908824, 0.027916282265176697, 0.0682587251668015, 0.026557918360096314, 0.007539129677048374, 0.027940369984735886, 0.07167386086357218, 0.039135184093949296, 0.03560242325728459, 0.007602846646125639, 0.04671827093848298, 0.02049857082085744, 0.01967581728803775, 0.02514790480716094, 0.04409633118719344, 0.0351392618200231, 0.03414209496470229, 0.02311797673633743, 0.07685496712163573, 0.033889768585082025, 0.013425230262650838, 0.06325995549559593, 0.032926091263371135, 0.02742531375148364, 0.010701402732651803, 0.04712633916266984, 0.07426243365531968, 0.08901550975297728, 1.7585325217054737, 39.497820485022764, 38.6274661556367, 43.64516604331232, 52.536143718227265, 5.134017775135656, 0.06328004998184981, 0.21744173861319022, 0.4548059614194978, 1.9557790794680197, 5.956777084258295, 8.297581903396114, 13.532971374450193, 6.76090709624752, 3.013422662212003, 2.2460668317733274, 19.569659886821626, 40.855270431887725, 58.62658439144012, 58.08432455985778, 59.51523657768004, 56.343537453682195, 53.56103943240259, 49.647216104692035, 49.83176754366968, 56.839089701252604, 59.4791272378737, 59.37230148623067, 58.95421212719333, 59.12588642489526, 58.608419895172126, 54.87957162241782, 52.11157852603544, 52.07909345626832, 54.048127205141135, 56.33252736060851, 58.76243568235829, 56.09865211671399, 55.55526264252202, 47.302227097172896, 43.21783950251918, 44.16969283934563, 42.68420888531593, 43.06472193810248, 43.70067542599094, 41.922111972685784, 43.10445947031821, 41.970243377070275, 45.15555312556606, 42.89703276849563, 42.098018507803644, 45.03687004889212, 45.41888929182484, 46.30085383692096, 47.406844554408906, 48.43489385420277, 48.60626220703126, 50.23995684039209, 53.69763989602366, 55.67703654689174, 56.29339387339931, 47.201786964170395, 50.42038194594845, 51.29094416095365, 54.68745393137778, 53.650453782850704, 54.07938849541449, 55.231274866288715, 55.42079594827468, 55.59389014397898, 54.94535761494791, 53.129566946337306, 43.99097004244405, 38.98694745955929, 38.966037304170676, 38.430147401748165, 40.13572339088687, 39.876254681617986, 40.01823271474531, 40.22512597422446, 41.919413382007235, 43.92136366136613, 46.15761672296832, 44.51516735938288, 42.98214035649454, 42.66745251993979, 39.40606447958177, 39.154428743547015, 39.627819599643836, 40.32102008019724, 46.74749412844258, 51.03707659629084, 51.06637670147804, 48.627592056028305, 50.14205840326125, 51.972095120337706, 51.338126351756436, 50.90814436635664, 48.844773692469445, 46.857308726156916, 44.03997221300679, 48.94276626648442, 48.01256049063898, 47.96751599158011, 50.02263399862474, 51.16699726350846, 48.08437516612392, 37.63650286582209, 10.579170700042479, 0.9528098435651873, 2.63508873120431, 4.6239620735568385, 4.93494866355773, 6.465652642711517, 6.297844331110678, 3.716940937503692, 0.5779382622530383, 0.11404298170800171, 0.022322518916259852, 0.9805438198870229, 45.968542791181996, 31.84521744328161, 28.525576322309433, 36.90429441390499, 1.3481202216879016, 0.029018265270297567, 0.01177478192989985, 0.06200027329126193, 0.024768363782054475, 0.06255628458494622, 0.039457810531941154, 0.0046237500012672, 0.020474293494536992, 0.008353685111468358, 0.035012972225705465, 0.02961639033239936, 0.038371704699051, 0.03470333480846978, 0.04696073393607813, 0.044598141760234876, 0.09853217570531754, 0.04602100069244062, 0.02083315972178694, 0.022665956132714788, 0.06231629605134649, 0.049045944826737534, 0.013110596036929037, 0.09342156485804627, 0.14642688956472183, 0.09858667520025084, 0.15706564449975569, 0.25388884658534683, 0.11818945558080751, 0.09627474441884026, 0.1728064377581881, 0.0920943788162643, 0.18298780755890956, 0.12768659395195786, 0.23299830304759167, 0.14951667538092983, 0.25171534789185374, 0.07516714518949871, 0.11306893155579606, 0.1865419805530579, 0.11117399009245058, 0.15641695188899196, 0.17550076898788253, 0.24110967263339028, 0.10893639282233293, 0.14038277759907708, 0.12873531469414312, 0.15187510769934426, 0.15633723277959133, 0.19578066384119375, 0.19208128654187728, 0.17648554437102812, 2.1159132738267226, 48.38276947698286, 45.30405798266011, 44.5484878939967, 57.55567927514353, 10.142714842673271, 0.3209637207609992, 1.450002928895335, 2.8632625649052286, 9.74976199288522, 8.515345031215299, 6.90683642702718, 16.193110077611863, 15.458318744936298, 3.80750086519026, 1.958343819264443, 21.741876332990586, 39.80575792251095, 61.156885777750325, 60.055515612325365, 62.287579582583525, 59.48794080365089, 57.405664305533136, 51.19781532595235, 54.628504630058046, 59.74529535539689, 63.52277317354756, 62.62065941287626, 60.0723425803646, 60.55091880982923, 59.77698026164886, 58.402350333429155, 56.076812359594534, 54.29059243971302, 55.81335852223059, 58.41128941505187, 61.398276282895004, 58.193221322951786, 58.70653798503261, 50.10448601938064, 44.961568386324, 46.906106933470696, 44.893185784739835, 46.73971214602071, 44.737879537766986, 45.568943485136955, 44.89669238367389, 43.252854501047445, 46.21991572841522, 44.91459800351051, 44.31955875888948, 48.28740096861317, 47.7174021351722, 49.37129305255029, 49.32260467160133, 51.0807482657894, 50.29317948126024, 52.45970456830917, 56.570811348576704, 58.371630330239576, 59.09911232609903, 50.845374676489065, 50.39980519202448, 52.94725518072806, 57.75719888748662, 57.08525373089699, 57.39022977890507, 56.72398382617582, 59.25548938012893, 58.59301674750544, 56.502758226087025, 54.87025991562874, 46.52386411543816, 41.06157141347086, 39.813002540219216, 39.394042415003625, 43.05285284596105, 40.034588998363866, 41.64476510017149, 42.297106250639885, 45.39165235334828, 46.858269706849136, 49.55152203959804, 49.384946823120124, 44.278668049843084, 44.86052813068513, 42.27248553306826, 42.967231427469564, 41.27954144631663, 41.20512231703728, 49.855376289736846, 52.25244652840399, 52.718443716726, 49.43501195599956, 51.44806254294611, 54.5859351465779, 53.47411186464372, 52.232171796983295, 51.197179901984434, 49.158245594270774, 46.0604243124685, 49.80438547749674, 48.884405320690526, 51.244691571881695, 52.76428053455969, 53.65342301707114, 49.864119252850934, 36.8240858662513, 9.916758864156662, 0.9587627757460842, 4.294432968862595, 8.351658640369292, 6.709553464766472, 8.107767133943497, 16.38081902457822, 15.868522178742195, 2.1728984482826728, 0.8498299145890821, 0.14618719597497296, 2.3814535669742094, 51.71417182491672, 34.29664781016689, 37.772005065794914, 42.26600185517342, 1.6989889813046304, 0.2463692492775379, 0.11348749135410595, 0.2815811630458601, 0.1964947956824495, 0.16884896543718156, 0.10715485535441868, 0.1808667399229542, 0.19096296671177113, 0.0631144447552581, 0.10501528669509197, 0.11171769801407092, 0.11577375819005313, 0.13753360467812709, 0.13086992676459974, 0.10446813903869161, 0.19424908554121373, 0.1310934558991463, 0.1713427961353333, 0.10454785814809223, 0.11463543580424403, 0.2670599051540898, 0.1331251517178551], [0.04921276430268923, 0.04916039453218541, 0.08744471541215336, 0.024744651445578185, 0.15071181850808282, 0.019619965647918083, 0.05648338303510701, 0.05698091117665172, 0.020160155310746164, 0.0799307335288294, 0.028779759116831328, 0.05565223892429664, 0.0056308918001671, 0.03518179502157915, 0.04229670255294731, 0.053080014448853276, 0.05463820281288317, 0.05589430738661078, 0.028984829362842347, 0.05807646287364825, 0.05682147678829009, 0.05056039723117025, 0.10061188991512023, 0.025786655511887326, 0.036200929448128714, 0.042487178824000785, 0.057022662968525005, 0.04218900208211234, 0.013742257555526112, 0.03031311665601548, 13.840567565733387, 42.96097916941489, 27.74862147146656, 48.13635833801762, 25.46977931453336, 0.07884213024930609, 0.14625887116116865, 0.5756256573142544, 0.4543556855811227, 5.965600946257192, 8.962138295173645, 8.690543578517053, 3.1649136687478716, 1.3234255919533393, 0.5705366884508442, 2.409374713897705, 24.296221848457094, 50.28872366874449, 60.762954296604285, 56.36340818097515, 55.28839242073798, 53.72448459748299, 51.464583566111905, 54.542773385201734, 58.24286676222279, 57.5612804197496, 58.080570851602864, 59.496856351052564, 56.830421263171786, 53.6419108606154, 50.91259233413204, 48.33770144370295, 50.266456373276256, 55.92782897333945, 59.22345146056145, 56.96205208378454, 57.718461559664824, 56.82473382642193, 50.935126350772, 40.83012019434283, 41.377047646430235, 41.962469239388746, 41.89725983527399, 41.868642222496774, 40.94937593706193, 38.67789606894217, 39.613271528674716, 40.307534971544825, 41.70249454436764, 40.26210608020906, 40.50457915952129, 38.66543077653454, 41.84663380345991, 41.589914675681825, 43.5863422578381, 44.41719831958894, 51.04529396180184, 52.10278064973893, 57.0387226535428, 50.3275865124118, 47.82071736551101, 53.201864073353434, 51.015903642100675, 54.331969522660785, 52.59372411235687, 55.15959747375981, 53.55390856342932, 53.66576279363325, 52.34253944889192, 52.747265292752175, 46.88773455158357, 41.1988426023914, 38.66195947893205, 39.82725643342541, 37.48740573083201, 37.581401409641394, 37.38070941740467, 40.0750207901001, 38.8237964722418, 41.75517589815202, 49.27882317573794, 54.50689154286539, 52.364175242762414, 49.634829259687855, 43.15485408229213, 41.006207158488614, 37.624778901377034, 37.051587258615804, 37.90918211783133, 43.65097507353752, 47.89104938507081, 48.81140608941355, 50.72477748317104, 49.89366254498882, 50.05373054935087, 50.59023234152025, 48.17458575771701, 44.335201171136674, 46.0954353886266, 46.43511656791934, 46.07557250607399, 47.320003278793834, 51.05896734422254, 48.881981295924035, 47.63396939923687, 35.72617523131832, 11.792396076263922, 0.45313515430015905, 0.07538807728598196, 2.86318191116856, 2.873825752927411, 4.70714524868996, 7.040904510405756, 4.298327392147434, 2.257096291549744, 0.11605210091558196, 0.11705624300145334, 0.0668191616874068, 6.680694135927386, 45.640256097239835, 23.182229495817616, 33.86321021664527, 12.834793406148112, 0.0836460990831256, 0.03550988749691075, 0.007724283552247912, 0.027458592610914382, 0.004446284775997723, 0.04717751000557215, 0.03695202503173101, 0.01934432721276197, 0.059765564172618815, 0.0482131268138126, 0.04025043191147908, 0.07531321517402127, 0.004941864660189998, 0.022864290550651572, 0.07875733197696748, 0.07029116409079683, 0.024179330268394084, 0.05204409886632235, 0.027730082679960518, 0.093585561299997, 0.08188250339439801, 0.007789915741135878, 0.05088743250516634, 0.024172496764109503, 0.041400743573303186, 0.11741147031106296, 0.036127488429267565, 0.08362689325886388, 0.03917551862316267, 0.05243042168477851, 0.026065804544956456, 0.07258930528957037, 0.05581418991148953, 0.023549561944579887, 0.08066456915149767, 0.07231732109381307, 0.029090367550511035, 0.0541047451476897, 0.026284212381729198, 0.031701289042229616, 0.046495787513953064, 0.029438891590783195, 0.06499891379667867, 0.027978595856937672, 0.03732746940166239, 0.0912178593176988, 0.02189264591452816, 0.04507797710116833, 0.03443220097030844, 0.005482707412973528, 0.018280736703966415, 0.04866582732046804, 0.009343165232078924, 19.974073902253185, 46.69896656467069, 29.351170524474117, 58.476424294133345, 25.653303092525853, 0.03501424393165977, 0.2180113709501682, 0.5263322507662158, 0.18997181747709552, 4.021517394050475, 9.01053249835968, 10.459307970539218, 5.400210897768698, 3.8873380134182596, 1.40669162715635, 3.3160774025224873, 26.212807624570786, 53.15800020771643, 62.85005531003399, 59.02416759921659, 58.29595996487526, 55.555054756902884, 54.152015101525095, 57.508873631877286, 58.93654184956705, 58.50913293900029, 59.657595080714074, 60.13162920551916, 59.30483279689666, 55.89521838772682, 53.68287609469507, 51.07261719242219, 52.712775891827, 56.342219537304295, 60.05843385573357, 59.28281653311945, 59.70751116352697, 58.97130581640429, 51.708794255410474, 42.37230593158353, 43.2698344415234, 43.19809429107174, 43.492962391145774, 42.73227753177766, 43.79462011398808, 41.13275458735805, 40.987395471142186, 42.31274081814674, 43.18511124580137, 42.6054084685541, 42.119681758265344, 42.18924891564154, 45.175349327825735, 43.866929008114724, 46.550328346990774, 47.35656369116999, 52.28544542866369, 54.25515382520614, 57.94754366720877, 54.574717167885076, 48.58775646455827, 52.265315824939364, 52.21789829192623, 56.215938829606586, 55.67331421759821, 56.985025405883796, 55.26036316348661, 55.78978507749496, 55.61716941095168, 54.58479765922793, 49.50436338301628, 43.26234271449428, 40.13180886545489, 41.367814387044604, 39.975596550972234, 39.749711175118726, 40.05932738704067, 40.018864216343054, 40.14171285013999, 43.04323911666871, 50.470411777496345, 54.744767604335664, 53.208814513298776, 49.430697348810014, 45.52441673894083, 41.988443174669825, 39.32618541102256, 38.57967991982737, 41.281330047115205, 43.56132538087907, 50.187499061707534, 50.706656132974935, 51.14330614766767, 49.53303198660574, 52.185997655314786, 52.394267666724424, 49.369100447623964, 46.70799193843719, 47.97223068052723, 47.70608609722507, 48.38600543237502, 50.030004132178526, 52.03081300181728, 51.06534511812272, 50.42649692104709, 38.96382508739349, 15.512694562635115, 1.5687146879011586, 1.7351073915919952, 3.328937138280561, 4.593992223662715, 6.715916039482241, 5.847589085178991, 6.116544046709615, 0.6542694244173266, 0.13106506468067247, 0.11752966235602096, 0.12513990318703075, 7.501316243602385, 53.16769238441221, 23.44636974796172, 36.170301283559496, 18.64996802422308, 0.10542555742206113, 0.02115014009177685, 0.02843424580210159, 0.007890394875674599, 0.01752811469017498, 0.07500370799173271, 0.0055871998906255734, 0.005231075300534647, 0.08643444462288773, 0.015622189441215129, 0.024356378933354735, 0.0038359729308379636, 0.014870545147137057, 0.05047103307480293, 0.16715707557816661, 0.022002571870783166, 0.06820810207676503, 0.03216243566825025, 0.046997176738636154, 0.12628394824963424, 0.019731324188591495, 0.023711476542596376, 0.05110780918790449, 0.14537267597211948, 0.11248239931920845, 0.171052448812031, 0.10464214824981267, 0.2427841416530071, 0.14267341113619267, 0.1298388949925861, 0.08962336987737687, 0.23670184786521622, 0.151360051466092, 0.10397332284839884, 0.18336323660708245, 0.15653191104290948, 0.12155310250818731, 0.12591336853802204, 0.17459747471636342, 0.13504594864864505, 0.18280748578329242, 0.12243100862589576, 0.14898153232230296, 0.17086662652511753, 0.1398480788714463, 0.2199449768710521, 0.10647502893041219, 0.15840582339273346, 0.20048488802727193, 0.13540867595903336, 0.12261331456923678, 0.144293028260431, 0.09578830923043913, 24.632706296059396, 57.13709569746449, 38.21430721590596, 62.15334038580618, 36.36658453172253, 0.3799516941991545, 1.0189524040587488, 2.085170962156788, 3.823844401105758, 14.794076142772553, 14.644765238608084, 17.5783117740385, 8.932077250173016, 6.587656496032593, 1.584718938796751, 2.704084203127892, 26.357698017551055, 53.531488295524355, 64.75174196304815, 61.62585612266295, 60.992365883242705, 60.01431111366519, 58.13136946770453, 59.41525143961753, 62.20162476262739, 60.89988816169001, 60.83390212828114, 61.938092477859996, 61.607919123864946, 57.6952568177254, 55.32710621433874, 53.44065796944403, 54.346662721326275, 59.79606651490735, 63.329317954278764, 60.308571246362504, 63.202107644850216, 61.93959082326582, 54.62792411927254, 45.175404241008145, 46.03088886507096, 45.34563510648666, 44.923690057569935, 44.74484958956319, 46.23137297168855, 41.97306748359434, 42.321279818011874, 44.14017308142878, 45.25235329904864, 44.21618469299809, 45.06364807005852, 42.5368336708315, 47.6355383473058, 46.4879273599194, 47.29476674910515, 49.50871329153738, 54.68110753643898, 56.65360866054412, 59.5904048796623, 57.337991652950166, 51.293305427797385, 52.05070334096109, 54.11310518941572, 57.11899788148942, 56.64323791380852, 58.152381604717625, 57.20518019891555, 57.95990305562174, 56.61204330382809, 57.903036532863496, 51.77960872650147, 45.98380473352248, 42.91723297488305, 44.371675291369044, 40.36101648884435, 41.304005269081365, 42.734199493162095, 42.2224517791502, 42.66769962926065, 45.87228390478319, 54.37016164102862, 56.66381466773249, 55.87793250237742, 53.166723558979655, 48.27201743279734, 44.24643793413716, 41.702090540239894, 40.58883951556298, 42.25331298766598, 45.019744980719786, 51.96417193258963, 51.94108486175538, 54.06668001605619, 51.656662033450225, 53.86059084246236, 54.428808919845096, 52.24653159418414, 47.62280241135628, 50.870081686204486, 50.32713151747181, 50.83520004826208, 51.431796473841516, 54.934225928398874, 52.35582451666556, 49.561394645321755, 37.145324060993815, 14.717282998946406, 1.0804433399631133, 0.9130500641561324, 7.0616974849854754, 9.296678227763023, 10.029328926917046, 12.8460378608396, 11.988967618634625, 7.640809455225545, 0.5142770911897383, 0.36962881263705993, 0.3676102016000979, 10.830061185744501, 60.068314306197635, 30.911295221697902, 47.3128096518978, 21.431960059750466, 0.20342471979318127, 0.09449911348882223, 0.15802077228023162, 0.07535846798770851, 0.10711675014106498, 0.12686315668566575, 0.0878756168869234, 0.09979157062667994, 0.1732485164557734, 0.13457915595462247, 0.09437869978888382, 0.21848311257218161, 0.13389349194063296, 0.099221877002668, 0.23161949800147166, 0.2009763027871809, 0.22600882326162633, 0.22517781704664233, 0.11690054329172259, 0.17160872057560952, 0.1811498553762513, 0.13073478885475667, 0.1500237183344941], [0.0332296229598503, 0.041716785485585856, 0.04330021644672079, 0.023298917127953424, 0.0396497308787319, 0.04561713063007882, 0.016793811753872904, 0.015918805278957854, 0.019287667349882184, 0.04163769073784352, 0.051881404773842905, 0.05105371188913142, 0.028084543901645852, 0.006518853300686685, 0.07471103176114059, 0.042037538838602846, 0.025706959385124427, 0.018067268219085473, 0.05235901079891671, 0.023879567724502376, 0.04231898805066463, 0.015302006823701725, 0.06895180491189803, 0.012922872894353444, 0.028887066967605107, 0.05438885651528836, 0.0011343348981632342, 0.020311838804533886, 0.053067013936778235, 0.05569340465890785, 1.1651961986095676, 34.662844211824485, 34.361210023203206, 32.54739819034454, 48.05708331446494, 4.713838283092746, 0.03921281561375626, 0.1277373242943037, 0.22660195917612125, 3.321373337699521, 9.319662336380253, 17.473808065537487, 5.864908800971124, 3.8750840387036725, 0.9011671824320671, 0.07265967046541554, 6.101868498709894, 36.86063843388712, 58.77482644973263, 58.568097929800714, 57.26149366747949, 56.62925466414421, 55.758100171242994, 57.526649813498224, 61.23376423312772, 63.28477159623177, 56.799614967838416, 59.41200371711486, 54.27712694291146, 51.356510500754084, 46.591564224612334, 51.265158499440844, 52.272485917614354, 57.07968788762247, 56.94899059111073, 57.78837388561618, 56.21738226183, 58.058448683831, 52.26330757141114, 43.798605242083156, 42.7489201484188, 43.845371661647675, 42.46681544088548, 45.00000761401269, 44.37819034822526, 41.470462814454116, 39.906527534607925, 42.231175130413426, 40.212390038274954, 41.88897186709989, 42.847763876761164, 41.44698350660263, 41.84586894127631, 46.360316968733265, 46.977992211618734, 50.81482725758707, 52.98912648231753, 55.27523286880986, 53.62507212546564, 48.10963130766346, 39.63593890590053, 47.39172381739463, 54.12375442443356, 55.48694279886062, 51.71155952638196, 52.644055966408025, 51.258721889988074, 52.356110849688136, 51.05702184861707, 49.57812355410669, 42.98524687367101, 38.94953589285574, 39.72050520681566, 39.15753918309366, 40.056887672793486, 37.02677826727591, 37.31882618319604, 39.83561500426262, 39.00869700216478, 46.88022713507376, 52.16867646863384, 52.4961983003924, 52.01961071260514, 53.02744411653089, 45.19229788934031, 41.24178078866775, 37.643425849176225, 37.16852488056306, 38.97210913319742, 42.36357081320978, 48.85645843321278, 48.14582301724342, 49.660893409482895, 50.048615778646166, 48.913466161297215, 49.816101597201445, 48.23046384319183, 47.57957396968719, 47.54941878780242, 46.29950061921151, 48.13780177024103, 50.7223456136642, 48.34761327312839, 49.20954235138432, 35.29301220370878, 14.301895172365251, 1.6636033187950812, 0.9334425279690374, 2.7502666798330124, 1.5140585433090887, 3.9501834540597858, 5.295462041131912, 34.330795964887066, 3.7275511939679427, 1.7434668204476758, 0.2313347584417751, 0.04351804205667108, 0.2717600997176863, 23.224051767779937, 41.31383472873319, 20.883485232630086, 39.225443255516794, 4.299329067430189, 0.07830649689440766, 0.0640196887205445, 0.060081127279948805, 0.06714370717564899, 0.10239813882376879, 0.040063023822562355, 0.08553541746110686, 0.013214607794408598, 0.026161485096259464, 0.0132744210667067, 0.03563058464938114, 0.05334272898072678, 0.025287629668450644, 0.039408834530941905, 0.025996667025009954, 0.047503415299879934, 0.05916439965667744, 0.05440367265574394, 0.030192735514813857, 0.012461628592122468, 0.06716276744320508, 0.013872696473563631, 0.013798420418865018, 0.019211596734220945, 0.032505734988878814, 0.015981512448389926, 0.01378270699792812, 0.01230881511864643, 0.011610314343875695, 0.10242374148219825, 0.062206986795870535, 0.03239410065655266, 0.011858599609695377, 0.05685243440131026, 0.06793379663459717, 0.0694658805526072, 0.043615300749098106, 0.02550431763783338, 0.03816097689371917, 0.05077292151268452, 0.04933570226233813, 0.1007138638787212, 0.04727198779883404, 0.06533996847968909, 0.051050425371936256, 0.01501314571097253, 0.03592767737685673, 0.09336535698704182, 0.03491333099983392, 0.03011733522608636, 0.06661015757990461, 0.058269999665959235, 0.035006253634609526, 2.020140761329282, 42.806629980764086, 33.982952333265736, 40.052753494631865, 55.973763850427446, 3.089656132844187, 0.0778853630406722, 0.13274871143362216, 0.024835440525484663, 0.11431436069429883, 8.148240600862811, 11.074018882166955, 1.603110932534741, 8.20917462148974, 3.218263296350356, 0.4414597904730228, 8.724341661699357, 38.48620591625091, 60.45455401943576, 59.986521120994325, 59.64995430361841, 59.55185582560878, 56.9715795209331, 58.964700545034106, 61.97668075561524, 61.38508927437567, 58.5491568042386, 59.754646285887695, 58.9796486977608, 52.92772962201027, 50.564525127410896, 51.147793339144805, 55.6112152530301, 58.16629425171883, 58.25667350522934, 59.179438544857895, 57.73350384927566, 59.90851302300731, 52.87960606236612, 45.31545246801069, 44.75584007078602, 44.85011816024781, 44.49824233208933, 48.01697315708284, 46.72171631167012, 43.54844039486301, 42.757215961333245, 43.669692623999815, 40.52419101038287, 44.418724121585974, 44.85776678208382, 42.6943717464324, 42.40722287085749, 46.91302991682484, 48.353112436109974, 51.69906677738313, 54.378041682704804, 57.02775570654101, 56.26458014211347, 51.228037188130045, 43.05074653317852, 48.51026611943399, 53.36801175148257, 57.123783173099646, 52.69155586919477, 54.30996110362392, 53.723621676045084, 55.55836523732832, 54.95913690136325, 50.2732224618235, 46.57071682714647, 39.58518735824093, 40.62808282913701, 40.655060891182195, 41.43543212644516, 39.31605000649729, 38.93663129498882, 41.03486007259738, 39.81334378642421, 49.25477904658164, 54.47696385845062, 55.533175776081706, 55.331130566135535, 54.619200768009314, 47.940726203303186, 44.36528575035834, 39.622795043453095, 38.955556731070246, 39.96601420064127, 43.82653644008022, 50.83302313281644, 50.3665356482229, 50.78143219793997, 51.05508419775194, 51.1974544678965, 51.4963076960656, 49.11890029907227, 49.88839872421757, 49.45411389873874, 48.99348251281246, 49.502076641205825, 51.24544074458461, 48.66204223325176, 50.11864185333253, 37.16082526791481, 17.885717730368338, 1.5682034314640108, 1.1379644082438563, 5.499134054107051, 3.078578378885023, 8.593189370247627, 7.134766828629279, 25.721797481659923, 7.2707014699136066, 0.5451527021584973, 0.14304459605726505, 0.01806748272370427, 0.19680745148610687, 23.642058757043657, 48.26428644118771, 21.656654996256677, 43.83197284513905, 7.396008449216043, 0.11985444043192173, 0.04448823495617798, 0.04714225846973639, 0.03645266594004728, 0.058935802850511775, 0.05923040962267307, 0.015185773091000176, 0.04494857718987812, 0.020099984849953366, 0.05439898036720772, 0.021694359377086646, 0.04976113003888919, 0.026632705778484384, 0.020951688845431613, 0.021226327535846544, 0.15810807566008261, 0.052913156668505365, 0.032677943893377824, 0.023594272751060706, 0.024285236178266428, 0.08663981747362884, 0.07686488029937591, 0.07951248782656847, 0.14145753766980865, 0.15999969996271596, 0.17014782154752364, 0.09088583681131564, 0.12164111834980788, 0.18934592364295838, 0.13416107113082565, 0.0967470069806422, 0.09379550003476682, 0.15935408702540785, 0.2055253788468338, 0.1486484679363428, 0.257988351607515, 0.1163032245371611, 0.147843309527924, 0.09100248901954583, 0.19214963690648157, 0.08980958286913172, 0.19161850814857792, 0.1238969102081272, 0.2501782384370604, 0.13017044252445623, 0.13415863497122643, 0.10216528639918375, 0.17253588614684923, 0.122770921837899, 0.20274918346155077, 0.09220363061514594, 0.17702699999415106, 0.18759752713864852, 2.7939986557729783, 51.282220809690415, 46.68051965775029, 42.931122087663226, 61.95684532965384, 7.533651282710414, 0.18864285411132922, 0.9919704196433868, 0.7486331931525662, 9.994984653688247, 16.1603759373388, 28.169044640756425, 13.709038726745115, 8.586981238857392, 4.178149892437843, 0.2878426754426572, 7.9746830751819004, 39.923962470023866, 62.24474730030183, 62.31992344702444, 62.55156686229091, 63.151105065499586, 60.126902749461514, 61.20933178932437, 65.91486592446604, 65.87473223286291, 59.267868380392756, 63.43348041657479, 58.89962450150521, 55.60485316861061, 51.25683522993519, 54.56873947574247, 56.93477984397643, 60.1188854248293, 61.99151515960694, 61.814314242332216, 58.512525789199344, 62.39302073755572, 55.006299480315185, 48.89778844771847, 47.72420744742117, 48.26825980217227, 46.49719199826641, 51.844641623958466, 50.11517840047037, 45.44771871259136, 43.52520819633238, 46.53671380012266, 43.17483071357974, 46.01955713764314, 46.66896043285247, 45.8547705219638, 44.41293470321163, 50.99673894143874, 50.86558664998701, 54.51049620105375, 58.26992719404159, 61.352298259735115, 57.49027375252017, 53.35957865561209, 42.86349258115215, 50.52644283540788, 55.53051640910488, 58.4797465416693, 54.09230486039193, 56.26195999883837, 54.93907790030203, 56.535635532871375, 56.23468775903025, 52.52762825258317, 47.299661867080204, 41.22591087895055, 44.263139386330884, 42.205989591536984, 43.94729837294548, 41.62033657873831, 40.55808421104185, 44.40381127019083, 42.00052799717073, 51.06372517924155, 56.73283661565473, 56.723419004871005, 57.64234404410086, 57.10163747110675, 49.43598862617247, 45.598910393253455, 41.392023255748136, 40.32538175582886, 43.365489282915675, 45.89595148640294, 53.285602754162205, 52.247127794450336, 52.48817313101984, 52.49564916856828, 52.87029043320687, 52.775663252799745, 50.76425221658523, 51.600787870345584, 50.88872863400368, 50.955377547971665, 50.538857137003255, 52.68126749223279, 48.67008309210501, 51.203938145791334, 37.34851068066013, 16.45910463025493, 3.036940703468938, 1.8632716949908965, 7.046759628480481, 6.437262037108022, 12.475878884715419, 13.108878827864125, 47.665528789643325, 10.854138655047263, 2.5631316246524936, 0.7597729695900794, 0.19980653249208005, 0.5628473107372561, 31.002196150441325, 53.72142514874859, 28.52459376858127, 52.995896493234945, 7.879382717993952, 0.26894619748477017, 0.2718363407879107, 0.12895993167354217, 0.22083449688169265, 0.1623246848823563, 0.13413701597000324, 0.2718215093256966, 0.09295484111193689, 0.08307901781893547, 0.09473407265519905, 0.09976288063391563, 0.1682901655834529, 0.2096334487319954, 0.12646218626609734, 0.135803563640483, 0.3286758359641798, 0.13119127000531844, 0.14307215990078065, 0.14691055151483706, 0.18222726611120088, 0.17685116749377022, 0.09377365886804559, 0.13890540768061915], [0.024254370495797168, 0.08167863973686773, 0.06713022402818165, 0.015542807410501186, 0.08175380062311888, 0.028453729333235856, 0.017312543293941888, 0.024863735982967962, 0.063262008611233, 0.06504926875594162, 0.03375355815214496, 0.018323922995477915, 0.003709198067700791, 0.05394286310841, 0.03096020814301747, 0.025023059288580573, 0.04298205630132749, 0.058675980300552426, 0.03940232278358552, 0.018796210455137397, 0.016863443400530566, 0.024989845546623392, 0.013317464674342305, 0.055915118165073864, 0.018057852998496066, 0.042233343251169696, 0.07615704570085773, 0.010154045359682172, 0.09655976743106881, 0.030756212335320252, 0.030958026707653078, 17.24539472210792, 46.18325725678475, 28.195012692482244, 43.884163902651885, 28.963710954112393, 0.2630907729748757, 0.15608925011850175, 0.03298899857327342, 0.46777705571824507, 7.328157328790234, 6.360295328401751, 1.8544516327881047, 3.583483272983182, 2.1265956038428895, 0.3874713068287219, 0.5398173594186383, 13.691556722887102, 45.00906828911074, 56.729251569317235, 59.98181819915772, 57.26488259530837, 58.81191245971188, 59.16545137282341, 62.21807126075991, 57.82043141703452, 57.39397956478981, 57.154891490936286, 53.474206001527854, 47.073870628110825, 50.64198017120362, 55.23474224152104, 56.96750810069423, 58.55085126815304, 59.39772236731745, 57.248851868414114, 58.92799500496157, 57.25280169517764, 50.6580501217996, 41.42006035773985, 43.8187034668461, 43.796930390019575, 44.42881245766917, 46.63762069517567, 44.61374044418336, 45.11792190613286, 42.34075438591742, 42.480465289085146, 41.44560675467215, 40.526501286414366, 41.75613687884423, 42.01198131807389, 41.73432850068615, 48.74920122085079, 49.75847805699995, 55.842639015566924, 54.3992107145248, 56.90916284438103, 53.96943661474413, 59.85390186309815, 43.396656436304895, 51.394482966392275, 62.09062560912102, 53.74399054434992, 56.02891629742038, 49.590220143718106, 50.22079213973015, 49.66975012133199, 47.901447588397616, 45.337441275196696, 40.037530775993105, 38.261191306575654, 39.272794108236994, 39.23136995684716, 38.38897035967919, 38.1490428986088, 39.012109464214696, 38.62906256029683, 43.9156723022461, 50.90158224105836, 52.62614642420123, 53.528546517895116, 54.895143432001916, 51.16397703847578, 48.185650763973115, 43.44021827943864, 38.587693322089414, 36.88194082629296, 39.0583267519551, 43.13666997417327, 47.27824180356918, 49.29968234031431, 50.86484139965427, 49.63858296794277, 50.16996606703728, 50.70615799196305, 51.04527042758081, 48.059334754943855, 49.34099274296915, 49.58758823333248, 49.89202691662697, 51.02058302971625, 49.935302426738126, 38.33323740190075, 19.35102697341673, 3.0603160685108555, 0.05064375525821121, 1.2044881740885398, 5.49774504476978, 2.243290774283871, 3.492604652720113, 5.193891284927245, 9.779424917313362, 5.138698143343772, 0.24101015781202625, 0.061534430546265464, 0.01013220132013122, 3.701207820446261, 41.06119878830449, 24.765231417071437, 25.07254715888731, 25.218086704131096, 0.3552065026615897, 0.02261174200553327, 0.05730677050568404, 0.018887003365483497, 0.034784023019094626, 0.05173159244981024, 0.06245240306241378, 0.05574517688083072, 0.029480359930124496, 0.014821189932615287, 0.02270594783758204, 0.008836205590576416, 0.033173476375879786, 0.09288137327999839, 0.029993477960928317, 0.023409212721631895, 0.0467517413198948, 0.045848251695954995, 0.024295800530742255, 0.07446847300255492, 0.037448698985240156, 0.050739474113910436, 0.03424248695673962, 0.024208391813801664, 0.037720713824514425, 0.10284613172012953, 0.0165109452791512, 0.06292424427585737, 0.01980427108074148, 0.07520532701164484, 0.0676711970159123, 0.01533306307054215, 0.1157457423546622, 0.016805333716254083, 0.05433268694868011, 0.03808516100229275, 0.03876595652752346, 0.0742410138369568, 0.02310789884969352, 0.039457278100833784, 0.05180218745203269, 0.028800554573535923, 0.02316966277336882, 0.025404672581522215, 0.07015257878529449, 0.04752847786632277, 0.02119438741506348, 0.015447253263705682, 0.03736409606532224, 0.056907987267139463, 0.04288507723099282, 0.060508680950489745, 0.07799933394116741, 0.04065832776588298, 0.014140678817526469, 22.666782986733224, 49.11049073742282, 28.73080453565044, 59.31134393138271, 29.261134478353686, 0.09877393773246197, 0.286223441362381, 0.039584464018022826, 0.03480135192794185, 1.0405974522713692, 5.941093977420561, 4.398744481225168, 5.7552672778406455, 4.760669912061384, 0.9921728507164986, 0.8942591531142112, 18.186818476646177, 47.77798314248362, 60.93450700083087, 60.778196627093905, 59.69337886379611, 59.54042996129682, 60.76352696264944, 62.86123014265492, 60.651205970395004, 60.20255350297498, 61.097124545804924, 56.24283844424833, 50.70814271127024, 53.045310512665786, 57.48790464093609, 57.988912905416186, 60.871188179139175, 61.6727323685923, 57.61979433798022, 60.40999981664843, 59.74581703062981, 54.10813162403723, 43.9739744124874, 44.23364316263507, 45.67313340402419, 45.77029051319246, 48.01099546494023, 45.78692136272308, 46.575753150447724, 44.22745366250315, 45.39867731832689, 42.95664102800431, 42.790626710461034, 42.365367258748705, 43.12944889068604, 43.81374166857812, 49.26397308226555, 51.95523677333709, 56.1377699144425, 56.101021228298066, 59.69903884395477, 53.919265577870036, 59.385566942153446, 45.83965370731969, 51.24621737387873, 61.87606019358482, 56.622335603160245, 58.75351621258644, 51.518351416434015, 52.35549503757108, 52.70710806692801, 51.21968253966301, 47.55330585664319, 41.88917190797868, 39.86113002223354, 40.94988192281416, 41.06483482545422, 40.42915590347783, 39.76254124795237, 41.710633462475194, 40.15746901112218, 45.130814736889256, 51.64910754849834, 53.59651334824101, 52.96759267007151, 55.90385544684626, 53.7636729978746, 49.10702728456067, 43.91642539731918, 40.78209077158282, 38.771036671053984, 41.41276867158952, 45.51969028288319, 48.508120582949736, 50.30548787886097, 52.664381688640965, 49.19886958214545, 50.71206900381273, 52.422700928103545, 53.46065813495267, 48.514521891070956, 51.11901490919052, 50.63087986361597, 50.01356155641618, 49.7792979978746, 50.82075003654727, 42.03382499756352, 22.27516962635902, 4.503312908834027, 0.6895557406448549, 2.4217622943462866, 7.956998578963741, 2.633401131437671, 7.251386738592579, 9.471223700431086, 15.77409209743623, 6.151499719389024, 0.8743938803672792, 0.09090811464815371, 0.07171333737431035, 3.139586924545227, 45.84841235991448, 32.54150482916063, 25.2405854194395, 34.330623380599484, 0.5544930912794606, 0.02652608740684246, 0.053742385559505036, 0.05937821479634412, 0.040098317493233955, 0.06465710834750245, 0.02490726701404539, 0.10844527683671444, 0.030285633251731916, 0.026230040389383515, 0.02930181547849169, 0.06550741997817833, 0.0414318505734686, 0.04981994643927582, 0.04146551247686148, 0.05307550985185851, 0.04381833703167016, 0.15331307005497719, 0.052142717364814975, 0.050171140295964096, 0.018498707870622317, 0.030765527964479504, 0.04246637953685657, 0.020653550407939383, 0.11919155987280032, 0.23416758304642094, 0.3138653952027521, 0.23207789437184412, 0.14698602649713718, 0.13269549896640162, 0.1558564513200714, 0.09756777060007858, 0.21545528794728944, 0.2714741344173109, 0.15393370852595376, 0.12208263014232922, 0.12635995949348136, 0.17760631568249197, 0.1766870254951139, 0.14826861089996754, 0.2122480761740477, 0.22831462533964267, 0.1390743453896815, 0.12792944382395477, 0.10273822823599463, 0.14371676160202873, 0.13678173534572124, 0.09870977786880347, 0.10490351446693945, 0.11372143928442272, 0.14973357019405212, 0.12815022270285314, 0.18742570893899088, 0.17577660660589897, 0.12483777343145303, 26.222211507058915, 60.77813386917115, 36.992681103367964, 56.09060733549057, 39.13713501345727, 0.6201092574384905, 0.47721896681093406, 0.08746706985778387, 1.4069784504752005, 11.957141507056452, 12.983659121298022, 8.361737170527059, 9.866253445225379, 7.132841435170944, 1.141731477072162, 0.8902642803807413, 16.54120179914659, 47.823184536349395, 61.09987412729571, 64.36895393556165, 63.864050757500436, 63.52388320430633, 61.79159195192399, 64.46049813301333, 60.98306986593432, 62.19644723399993, 64.07073613136046, 59.64897371107533, 53.15204212742468, 56.81694792162988, 59.15996397695234, 60.992385495093565, 64.01712125347507, 63.53759973279892, 59.31305016240766, 63.94604006121236, 61.874859948312086, 55.537635510967625, 45.45396704827586, 48.5483209548458, 47.24503109532018, 48.79041748662149, 51.065894249946844, 47.97314459277738, 49.590078938391905, 47.65485994277462, 47.187933152721776, 46.056325435638435, 43.82915266098515, 45.108029688558275, 47.03818098191292, 46.68055495908184, 52.33938586327338, 53.77900946524836, 58.501723581744784, 57.90038108825684, 60.41059209454445, 57.497945908577215, 61.47105586144232, 47.54630050351543, 51.68126706154116, 64.17964073919481, 57.27310780555972, 60.853537513363754, 53.37778237558181, 54.256004979533536, 54.39650035673573, 51.75600390280447, 49.771676832629794, 42.28264447181456, 41.03736254476732, 42.623090513290904, 44.05610492152553, 42.66050600236462, 42.35138793145457, 43.51621420152726, 42.005791817941976, 48.500938723164225, 53.37858253909696, 55.322713159745746, 54.751486624440844, 57.0785778568637, 55.63928765635337, 52.3099837764617, 48.633632506093676, 42.7123518913023, 39.478832291018584, 43.646072110822125, 48.179465186211374, 49.80183593688473, 51.86879557947959, 54.95612452107092, 50.58121089012393, 52.041038620856504, 54.34770607179212, 54.56363254977811, 51.49884154719692, 52.88947474571967, 51.833353042602546, 50.32089494889783, 52.12738960020004, 49.835713448063025, 41.162576367778165, 20.7678831777265, 3.8271254637549004, 0.5319890439991029, 3.9113931742406662, 11.331752923227127, 6.286937690550282, 9.788765061286188, 10.415308783131263, 14.72487670760001, 8.816573254523739, 1.4761924719618214, 0.1258960702726918, 0.18915028010885562, 5.900141981340224, 52.430137741950254, 34.53272350372807, 35.6396948137591, 37.129618890823856, 0.8328329363176901, 0.2151671929224845, 0.19014829349133278, 0.2298440432716762, 0.16067569594710104, 0.21075137019638093, 0.13739736360167304, 0.17553132057430285, 0.30794546608963325, 0.1310528992044349, 0.0927447644813407, 0.14819384071855776, 0.1069693165200372, 0.16237115577584313, 0.1354320722842409, 0.11889752766658222, 0.12415412422870437, 0.2278108612423943, 0.11791662868833351, 0.22137878703013544, 0.0725091495100529, 0.21036020570224334, 0.17834873148991218, 0.09215961886389602], [0.06690516271778653, 0.04074103844862792, 0.03887142002161953, 0.03141328977841524, 0.007454298367168034, 0.07387637896763702, 0.054629373649555835, 0.01014219685232327, 0.012752967999286711, 0.011253186178603962, 0.028990969557555455, 0.04453835242818441, 0.021910143362718727, 0.08218356062688174, 0.06925473139891702, 0.09588474437834756, 0.05044147357224457, 0.046806390201973344, 0.050302620135968736, 0.023758763319722587, 0.03753483791144625, 0.024901103836694555, 0.043001572391198534, 0.058528041061494625, 0.025724629203097957, 0.0594232760880503, 0.044628701007534424, 0.02672351018014935, 0.054553645858240706, 0.037069343736455325, 0.04546407392368682, 2.0368207630611237, 36.63570227161531, 31.376080397636663, 31.610308654846687, 49.15224436790713, 10.605953624171596, 0.24761896850841664, 0.06851146523390086, 0.06286881015365643, 1.0380895868424447, 1.1435986478482525, 2.8994361335231416, 10.557375069587462, 4.422433145584599, 0.26688205018158884, 0.11476225399922942, 1.047698413172076, 17.352312649449996, 45.88335675577964, 58.586740955229736, 60.48293629000264, 57.30034866640645, 59.77699595112955, 58.86426433440178, 59.38095815720097, 56.04018526692545, 55.14761071051321, 50.17860704852689, 51.96126153392177, 55.31271503817651, 58.12363063135455, 57.69926940241168, 59.73156705979378, 55.162602009311804, 54.99503835555046, 59.51394611789335, 57.590972761954035, 48.40671554688485, 42.28979887500886, 43.85800953834288, 43.026259176192745, 46.715236556145456, 50.24616595237486, 50.706244284106845, 46.8573401051183, 43.361551223262666, 43.304339531929266, 41.55633134226645, 41.13836357670446, 39.826032653931655, 40.64438419957315, 42.06275247758435, 47.780842550339244, 50.31094389577066, 52.68824931113951, 55.46217695359261, 55.59645929644185, 58.29150807472968, 52.56829146415957, 57.59104728698731, 56.19645249459052, 54.30883538338446, 55.63842081254529, 53.74581836885022, 48.40331485194545, 47.66244972905805, 45.59571366156302, 43.49487650778986, 41.323009152566236, 38.63047069118869, 38.77907752990723, 38.961636404837336, 37.692431942109145, 38.363078794171734, 40.62811420809838, 38.62653655390586, 43.24290737029045, 48.34584820655085, 53.738667888026086, 53.95163297653199, 53.729505231303555, 52.644911043105594, 52.29994643119074, 49.182011235144834, 41.91344745697514, 37.612066499648556, 38.54441781197825, 39.12110820893319, 44.04437311234013, 47.233589541527536, 49.81159871624362, 50.49205149373701, 50.85125430937737, 50.04210464416012, 51.12057993488928, 50.74209082511164, 49.00493191134546, 52.014703827519575, 51.244691571881695, 49.40351532351587, 48.990109274464274, 40.243286548122285, 24.92849419193883, 5.407110346901802, 0.43069343593332077, 0.4454685140761637, 1.1220148253825404, 5.767711487508589, 1.3073540478944778, 8.618923060355648, 9.297754918375324, 2.893876664100155, 0.6741965357815066, 0.0603007608574004, 0.16993100334319378, 0.3591772283036863, 18.953598699262066, 39.98286078053136, 22.98599527728173, 31.281541470558416, 9.140822848966046, 0.01721085661331252, 0.020911302605283358, 0.07691081493131577, 0.033768734353924953, 0.06412335956889777, 0.03617200196810788, 0.024090919891492497, 0.03785531164237088, 0.08761426599155511, 0.04701410728176275, 0.05116770577226436, 0.01633640172170295, 0.022185523243200396, 0.01980096924178783, 0.0032898233433614576, 0.041880398883574435, 0.019765635351500204, 0.00615763709872901, 0.10094076380013459, 0.04285275598146743, 0.03528003430654926, 0.0421633304757697, 0.026418511425295187, 0.041572466011970274, 0.04944309629800339, 0.024442519774780642, 0.017009379319666375, 0.023354535111256187, 0.01671431864040994, 0.04610394886244209, 0.0565220398317662, 0.03512043137884429, 0.02369848560662039, 0.015042964725815242, 0.0394246006204236, 0.0169748057716436, 0.02674680882914653, 0.026711086149237333, 0.021206265608329448, 0.024257697232608354, 0.03775805294994385, 0.05845402930712989, 0.043662932265790246, 0.08295437531365503, 0.05725620104180229, 0.05852925531085461, 0.0404654536396265, 0.04915276429645958, 0.06844212661587423, 0.07689595282558473, 0.015871669804196686, 0.03795065128454759, 0.043976013248245564, 0.04776884561344501, 0.015476487178896225, 4.028362665445575, 46.1186989661186, 30.202595495408584, 37.324725427935206, 58.93079949963478, 8.528120190866533, 0.22542776089281807, 0.07906464048691335, 0.045889279534739834, 0.21390325509973113, 0.5971162622013401, 3.137065330820699, 7.807455764662835, 7.588590941121502, 2.215939106479768, 0.4487812314783374, 2.026716492349102, 21.291011648793376, 50.14883625891901, 60.478668751255164, 61.71878491678546, 59.35601972764539, 60.82342155518071, 61.841202089863444, 60.72222048236478, 57.560966630135816, 56.868895792192035, 50.15657901763917, 53.19867910877351, 57.076699041551166, 59.54481909351965, 58.63713556720365, 61.27714956960371, 55.750020088688025, 56.14975275531892, 59.67186074103079, 59.43014467916181, 50.845441356782, 43.15332435792492, 45.36836131926506, 45.45545362657117, 49.317862526063, 51.48490928834485, 51.83118004952708, 49.12689801185362, 44.921548443455855, 45.77677811345747, 44.14597426691363, 43.164318761517926, 41.9853013561618, 43.071060488300944, 43.704864517334975, 50.55727658733245, 53.680565818663574, 55.401874434563425, 58.452125210915845, 57.28733424217471, 60.39892696565198, 54.279892213882945, 58.04321027571156, 57.54897594451905, 55.32465081061087, 56.215621117622625, 55.107206375368186, 50.829900926159276, 49.80566024780274, 48.21589223800167, 45.99375970901982, 44.93940307248024, 40.48364939228181, 40.35539573238742, 40.59918280570738, 39.92220524818667, 40.87818099606422, 41.37679269236904, 40.8899010381391, 43.09677946952082, 48.81741908288772, 54.904039367552734, 53.73999364914433, 54.73043526372602, 54.3475099532835, 53.78727389920143, 51.888607471219956, 44.146523398737756, 40.70873460462017, 40.339321859421275, 40.852242362114694, 45.457191236557506, 49.63964200788929, 50.943163287255075, 52.65873347559283, 52.39265165021343, 51.85012901982954, 50.719952967859086, 51.02738834196522, 51.334188292103434, 51.87854659172797, 51.60350215050482, 51.34426093870594, 49.239207236997544, 42.6832635941044, 25.862565463589085, 6.764901049675481, 0.9640649009135462, 2.1002088391011764, 2.888369901526359, 7.176198824759453, 4.6861958695996195, 6.0319708816466795, 10.063428052010076, 2.5861331387873623, 0.3137351296121075, 0.059205435156341524, 0.14037672550447527, 0.13937492764765216, 19.505923332706576, 50.51704875884518, 23.43806609030693, 36.4623962679217, 14.134792397099158, 0.05034504225477577, 0.017054233767632997, 0.04695363613145967, 0.034921164248859694, 0.04089485741250458, 0.028604995309104844, 0.039216374092164545, 0.023272477518466693, 0.07868697446200155, 0.02314436655010908, 0.028171830044518557, 0.050341617841754234, 0.0263566613167284, 0.037834408933356885, 0.04759999600449397, 0.02685535391191802, 0.057241718149593765, 0.009943543550288005, 0.03712641728681423, 0.039941978100086414, 0.09231022408893032, 0.03675169303953167, 0.013045404827402485, 0.05045693705699617, 0.11667500700681441, 0.1209944558720435, 0.11993821214644179, 0.12261607248576419, 0.15018743132391285, 0.11342969002021898, 0.10431921154621149, 0.14774253832236414, 0.1821391813216671, 0.11693483338721337, 0.14155201163263093, 0.14928563858472532, 0.10660220718672199, 0.17257641219804365, 0.16793540558747708, 0.14042221580541905, 0.314874853938818, 0.10722052441128802, 0.1264013665457887, 0.10393324112820049, 0.19866120040176377, 0.1964652093668138, 0.1680335720940944, 0.12882460990259725, 0.10525547058111238, 0.1496521350477011, 0.17604951776804464, 0.12555959679546858, 0.18413798132490727, 0.12238239268622092, 0.16911927190038467, 4.757161351942248, 52.60122760649651, 43.55286875078755, 42.59196650597357, 59.490219700721006, 17.427867304894235, 0.49238248217490416, 0.28084268493037073, 0.34000204755894603, 2.546942286914395, 3.9726529967400337, 8.374002422055892, 22.096082049031413, 10.799606923134098, 0.970487598209612, 0.2872680175688959, 1.5146841613515731, 20.63378518627536, 49.839086686411214, 61.63573265075684, 64.64270007225775, 59.77983574713431, 62.35057284755092, 62.43620603315292, 65.02951637391122, 58.54403418879355, 57.49409021869783, 53.67893803504206, 55.2955154449709, 59.206185187062914, 61.4401436621143, 61.06314897537232, 62.71878926984726, 56.1477445017907, 58.461789931020434, 62.27762460708619, 61.30442180941182, 53.77269052690076, 45.33869643365183, 48.99903266660629, 48.60398723233131, 52.011208995696045, 54.78459535106536, 54.99569731373941, 53.536371646388886, 46.81119342004099, 48.016886864939046, 46.89657557395197, 45.16917159480434, 43.49226028688493, 44.59005717308291, 45.21796587974795, 52.60460476721487, 54.83157750098936, 58.364052311066665, 59.798592521298325, 59.569949719213675, 61.57341403345908, 55.13871869733257, 57.66593710068734, 58.21992481908491, 57.99773039356355, 59.633633321331395, 58.34174186952653, 52.750222759862105, 52.73523930580386, 50.65809719024166, 47.13479680399741, 45.71373778004801, 42.51844559946368, 42.50290516884097, 43.31837377240581, 39.92417427801317, 42.20356948914067, 43.96526675070486, 43.38136311500303, 44.45042079494846, 52.23472918233564, 57.57613051322199, 57.50694382575251, 56.25560575915922, 55.13032482516382, 55.3615681586727, 53.60058476847988, 47.109630876971835, 41.71324576100996, 41.64253327154344, 42.32905003332323, 47.702740315468084, 51.37415332178916, 53.304908660150346, 52.930573340385195, 53.165691975624334, 53.107566372040786, 52.615265769343225, 53.69065415474677, 53.52027816157187, 54.28662692346881, 53.617380357557735, 50.33765131427396, 49.828923825294744, 41.519406149464274, 28.153184536964666, 7.040475010871888, 0.7492000982165338, 1.9796745262799726, 4.642942422820676, 12.218612586298297, 7.09679828536126, 18.411234924870154, 20.54039159128743, 8.614969311221953, 2.7738624330489867, 0.20544899988078302, 0.2651689550088298, 0.7500321309893363, 25.88494258542215, 50.54821983460457, 31.33341677727238, 45.89855986256754, 16.288778647299736, 0.16430053289138502, 0.16757574262878588, 0.2845969754120996, 0.13378948784403263, 0.15637362195599466, 0.08557621930395404, 0.11156611985737279, 0.10664908410680872, 0.16225155412910447, 0.11747027522013073, 0.09179846203375248, 0.12002267334009371, 0.2127542304656198, 0.1503704190855065, 0.10005784746740135, 0.12165156778909507, 0.1315220208057473, 0.08529410742583775, 0.15833505219028843, 0.18022253658742676, 0.20373354515721723, 0.10053348847694936, 0.1167094043546146, 0.2899260668744964], [0.031843806294003324, 0.018108845725955985, 0.04390703086110373, 0.06554601548780357, 0.030209834597283797, 0.014163409603849776, 0.033603680710638725, 0.03609209516716581, 0.04041654275610082, 0.02681135365198697, 0.08856144177937701, 0.0876461735536014, 0.02691452079753001, 0.04129395091665849, 0.06134985315222895, 0.017394631530248353, 0.022417862388876178, 0.06580130662769079, 0.011641334201539717, 0.02018492293333815, 0.05797968681661352, 0.05792697996742303, 0.032575805220873125, 0.06588826526797588, 0.060282355595019564, 0.030852971155376687, 0.030343620361940517, 0.042323737795795166, 0.029753870556070924, 0.004340462656992098, 0.07780590440116583, 0.01336013289889501, 12.79122175708894, 45.263975281869214, 27.197789299872618, 37.46003543176959, 44.11272825733308, 7.17376156199363, 0.5062112578701589, 0.012100223741013438, 0.034216462949951815, 0.8961196436036019, 1.2398663595799477, 0.8355349590701442, 6.821620483552256, 9.263655793282295, 1.134250781709148, 0.2605039085591993, 0.6603290573243172, 13.952228619206338, 36.50966867323845, 51.880994150715495, 57.936443359621116, 59.92268454643988, 61.59321808045911, 60.02325411765807, 56.50634719479469, 51.969118041376916, 51.40748170114333, 57.973207735246234, 55.847914603448686, 58.91236435982489, 56.41402244567872, 56.71805712484545, 57.506449607110795, 58.07441273043233, 58.68414909608903, 54.72074308703023, 44.361975269932906, 42.154618309390166, 44.11217520313878, 44.27052913173553, 49.30109831594652, 52.12612267463438, 52.77969937170706, 49.875239172289454, 42.814851268645256, 41.60687892667709, 42.413447672320956, 41.549318144398356, 40.06759574336391, 40.22138403308007, 42.52037540558846, 44.03837580834666, 49.987626844836825, 53.70057775128273, 56.02517043390582, 57.43517621870964, 57.1045910158465, 55.248227350173465, 54.20076231802664, 57.04129572837584, 55.53134402921123, 52.798256104992284, 50.7899437412139, 45.27527170796549, 43.76158983476701, 40.78036100633683, 39.266428101447325, 40.33093583199286, 39.20138343687981, 40.338541307756984, 39.50446498009467, 38.314621833062944, 40.62668646535566, 39.66189715170091, 44.14348356185421, 49.05605608417142, 52.50113656443935, 52.894809169154016, 55.038729636899895, 54.28398324597267, 51.58999350763137, 54.242362976074226, 52.182773467033144, 44.049911499023445, 37.825733692415305, 38.81047610313662, 42.132962903668805, 45.90252930118192, 47.25247575390724, 48.70942838730351, 53.153352199062226, 50.208201331477014, 52.2780909845906, 52.03965402418568, 52.2631428318639, 49.908842117555686, 49.7766778545995, 51.52159129419635, 51.23038668786326, 43.71859673530825, 29.072913662079845, 11.115004708690028, 1.584498673196762, 1.5207986461539424, 2.8067247857970576, 1.824106828820321, 7.52567514296501, 2.4382185984042386, 2.94715789537276, 10.496676391170872, 2.1341218967591566, 0.20724429628781735, 0.08333081559788796, 0.3167509726218639, 10.422866209860771, 41.57045187488679, 26.23307255006606, 26.716028105828073, 25.768222655019454, 1.4181201880978, 0.12021151401342885, 0.0456493599490533, 0.08332585900901787, 0.051094674610442696, 0.05157855106517673, 0.056409482363491296, 0.05554360382619405, 0.025602476483571435, 0.007420480373360578, 0.022689432897154364, 0.008158269488523084, 0.06566955482647305, 0.0519705850691084, 0.05029747585555719, 0.05833453874314024, 0.035488122938981945, 0.01182797428731236, 0.0891868606390011, 0.044192360308501995, 0.03411424383821507, 0.02931014476944843, 0.04845183215013916, 0.03378685616377381, 0.05129093101488487, 0.0554490992198548, 0.03152510222618378, 0.006155305797414434, 0.06949776513201576, 0.0589330525948636, 0.0327468266890895, 0.10109483940346588, 0.03371644502265319, 0.03723254727740442, 0.01889995599706327, 0.026784847009806868, 0.014367422648525287, 0.021173432995114597, 0.02542180805316856, 0.075317497605518, 0.005902077349263334, 0.034698504624107195, 0.017935229134896112, 0.050923059424085, 0.009735933722807996, 0.019905976913568955, 0.03866680559792346, 0.040975721823352004, 0.024966964415544947, 0.07248884818005948, 0.04150957019338685, 0.01936837471270513, 0.042832573395102255, 0.05673257994555658, 0.026765777166151715, 0.09004523917551964, 0.034450242340925245, 19.413767245508012, 49.19776739612703, 25.36335168346282, 47.10311974248579, 47.65831162852626, 6.188723502620575, 0.33038448782697805, 0.06899029316921389, 0.06458547912658223, 0.29035863076006213, 0.33586857419821525, 3.1285295178813324, 12.03640966646133, 6.255599423762291, 2.551833237371137, 1.1896548732634515, 1.6142265618808809, 17.82339519070041, 42.81955026811169, 56.30690643864294, 59.62628279962848, 62.05653236758325, 63.14490772062733, 61.421006418043575, 58.91825183745354, 54.77377353175994, 52.83366334053778, 58.62656085721908, 57.78142344567084, 59.589898893910075, 58.27253164783601, 57.30738932086576, 57.34629531060496, 60.301452144499756, 61.220549768017186, 56.802415540141446, 47.025409744631865, 44.60698220037645, 45.828482797068936, 47.29067179464525, 51.46847455732284, 53.58982570709721, 54.50142375884518, 51.34822253257998, 44.33167496035176, 44.25454547328334, 44.64426432886432, 43.273462633932795, 42.27648635064402, 40.7300526865067, 43.84121002689485, 46.17878575478831, 52.22928885490664, 55.43270426411783, 57.7069886269108, 57.47419203481367, 57.97026987998717, 53.54054112588206, 55.9622242373805, 56.909884560492735, 56.64471664736348, 54.254239912955995, 51.737925698680264, 48.476996575632405, 43.91931226176601, 43.5953244855327, 42.19475592336347, 43.12751908456126, 41.072259872190415, 40.6498598283337, 42.69512484150548, 40.54407350478634, 42.48742357377083, 43.06354130468061, 44.848129518570445, 51.45145539314517, 53.86312077122351, 54.26108837127686, 56.5442882814715, 55.490912237475, 52.59723071129092, 55.007440890035326, 52.83125500525198, 45.637294707759736, 39.862545997865745, 40.50925070239652, 43.25428224379017, 46.62339425856068, 50.845390365969756, 49.49426720219274, 54.173674429616625, 51.27213639597739, 52.87823715517598, 51.83172133661086, 52.94418396488313, 51.465870103528424, 51.73716083649666, 52.7801896679786, 52.31641646354429, 44.95261753759077, 33.17452830653037, 13.185260122822179, 2.5410866785433988, 1.2904065895465113, 2.9142163597768356, 3.306523734523404, 4.849091902855904, 5.866406165784405, 6.979148262931455, 3.8990955631579127, 0.8981779073515247, 0.17096678486033795, 0.043005988888082006, 0.2651823462257462, 8.538383072422397, 45.05355581160515, 34.56558904340191, 27.023355614754465, 33.13300217351606, 2.607740250325972, 0.018459087718398343, 0.07635517902071438, 0.03899384470235917, 0.011684482188655004, 0.03729637389281585, 0.05186252453694901, 0.01962989223219695, 0.07183924392466584, 0.049565379252477046, 0.03779549932768268, 0.05587411713936637, 0.06514596437374431, 0.03622806428240673, 0.015184459250210034, 0.016601041049486207, 0.030568894261734623, 0.04850253184896804, 0.03976136521105805, 0.026887751770235842, 0.06816463424794136, 0.007163319978938108, 0.05406017032181544, 0.027201524147042827, 0.02796042425137374, 0.14519878933506628, 0.1298792678261957, 0.1162852214709405, 0.21808157524754926, 0.16234697804095286, 0.09414011702662516, 0.13068669385487033, 0.1172538017553668, 0.16097257033951823, 0.11672455757375687, 0.12365275032577977, 0.13964638324274173, 0.09580786745514601, 0.18354884438937713, 0.09673155498720946, 0.09497476982012873, 0.14927356503903866, 0.08626924542289588, 0.09750505864259698, 0.10878099188689264, 0.1495993362679597, 0.2504101332517401, 0.18599942176332399, 0.21042831091871186, 0.10666006214676366, 0.10430209714198306, 0.16814255576220252, 0.14236230283014237, 0.1152380865307585, 0.19850173153944556, 0.2648177190173057, 0.180784983019675, 22.158496764398393, 60.43631107576432, 36.99252813093124, 46.990590864612216, 57.240112827670195, 11.27356161994319, 0.6418866856444267, 0.11682581907558827, 0.19803463241025326, 2.2962378686474216, 5.985360866592777, 4.604066831450309, 15.461503709516219, 23.097943644369803, 4.105596585619835, 1.3365191990329375, 1.1937004303739918, 16.31714620897847, 40.28642085290725, 54.360869546090406, 60.00387760900683, 63.03279853636219, 64.67232573416926, 63.843564218090435, 60.592460632324226, 56.925785849171305, 56.05735348116968, 62.34501484901675, 59.418675668777965, 62.21930680736419, 59.52691739605319, 59.2450088070285, 60.137489226556596, 62.26086431933988, 64.70535209102016, 60.91508734610773, 49.261894226074226, 46.28226180230418, 49.29731322873024, 48.15974743135514, 54.59060668945313, 55.770400724103375, 57.031360364729366, 53.78401440958823, 46.06029879662299, 45.44638510673277, 47.17371848321731, 45.627057321609996, 45.639487312686065, 41.89100365484915, 46.04699019462832, 48.30520852919548, 55.228976357367735, 57.14030027389527, 59.06565450852918, 60.561834766018784, 60.349073640761844, 55.61220369031353, 56.35153124409338, 60.24711947287283, 58.540515822748986, 57.39920023948916, 54.92252157580469, 49.00090363717849, 45.86206220811414, 44.59057492594565, 44.07461850873886, 44.55101390038767, 43.92583908573274, 43.34184131314678, 43.875444473758826, 43.65286957833075, 43.86668582116404, 45.81788847523351, 49.09216150160759, 54.09104577956661, 57.261101430462254, 56.2803598373167, 58.71656356319305, 55.20887813260479, 51.72602130520729, 57.66648231014129, 55.08474296139133, 48.46573545086769, 41.25306937002367, 42.99069504584036, 45.47977232163953, 49.06519128430275, 52.27657694970408, 51.86557531356812, 57.576012842116825, 53.149539655254735, 54.05007662311677, 54.36725908710111, 55.51270492615239, 53.757263845013036, 52.50180336736864, 53.917861369348344, 53.49804616743519, 44.446110110129084, 31.911372138607888, 11.683579721758443, 2.544938446052613, 2.547097710832473, 6.455634909291422, 4.6567472046421425, 14.105640361385962, 6.803375088399457, 12.952032070006094, 24.425816958950413, 5.797312634606516, 0.3575545621495093, 0.18479572909493602, 0.5518226926365207, 14.882905079472451, 53.42261506665138, 36.45899165061213, 37.07106574889153, 37.76097928324054, 2.8255867285113183, 0.2539045360660361, 0.16482553294589444, 0.26064358170955415, 0.1641693939605067, 0.12573361366746888, 0.23372070863842967, 0.09475252771329495, 0.11421093882452096, 0.10687284306773256, 0.08998067328526128, 0.09912402459209967, 0.14876263035881906, 0.14136465716986887, 0.09987721159573525, 0.07867979621815105, 0.18892243023841612, 0.2479916549618206, 0.2127894858318952, 0.15159553157225733, 0.13876625547005286, 0.07764471184101797, 0.16755349543546477, 0.07102205793583585, 0.24401614893107648], [0.05167671757179403, 0.02575923722507733, 0.04603887352371409, 0.03548320465450806, 0.03410023209007998, 0.027232510488360163, 0.03560424271610475, 0.02680859765067937, 0.050174265934695164, 0.04141222723128815, 0.016049307399249126, 0.0788167191128577, 0.026486767944128766, 0.061384484156846046, 0.009006117188912487, 0.0686402063095762, 0.03231096862544937, 0.030766251917567947, 0.02479055543400107, 0.09857179011188208, 0.07028324274165977, 0.03896762151271105, 0.057398712547916564, 0.07545874889699683, 0.002385220737309165, 0.03983556082652461, 0.00789168717024187, 0.06867071193072104, 0.03300263876876524, 0.03953170737311725, 0.03170599473730451, 0.17119920061480615, 0.6909434016673797, 26.75012330855093, 39.929190989463564, 29.1806141022713, 37.26615659652218, 39.83534436072073, 11.179339424256357, 0.9114057943224908, 0.026480079996549798, 0.1049925109011031, 0.36221354118277954, 1.2760401733459965, 11.148421341373075, 1.0461467480467213, 2.0488246866772255, 1.3798958327501052, 0.11945030606922605, 0.684379131322907, 8.410338278739683, 26.68242123819167, 45.633658670610004, 60.9495218338505, 62.85475038713025, 58.22826770044143, 55.68874089948593, 52.12940177609844, 55.28575266561201, 57.04766565753568, 58.56988260822912, 59.726287549541844, 55.443733969042384, 56.44679384846842, 57.52764217315182, 57.75041318708851, 57.381294619652536, 50.398620636232444, 44.034084735378144, 43.74073067019063, 45.46998208568942, 48.031952688770915, 51.28657464058169, 53.622730470472774, 56.61464775762251, 53.56744858526415, 47.58171558380128, 43.37083547346054, 43.62149846169257, 44.47913254460981, 43.154191201733006, 39.92837513646772, 43.26673576908727, 43.09703050121185, 45.39293104602445, 47.59696968140141, 52.453562136619325, 54.32891007392637, 56.34851886380104, 53.098070313853604, 53.48763227462769, 55.91258272047966, 54.34162639802503, 51.84701858028289, 49.12639202610139, 44.759758518588164, 43.13756819694273, 41.16851875858922, 41.182862866309385, 38.59035661143642, 41.71451268657562, 41.66015255835749, 39.90122841250512, 39.5212919481339, 41.60294086702409, 44.02462790089269, 51.64187862027077, 53.126856588548236, 54.6097949243361, 55.350828709140906, 55.752679455664854, 53.41020468742617, 55.65625190734864, 53.74170380253946, 51.28706101448306, 48.01946386214226, 39.42395048756754, 39.37958848091864, 43.71432919656077, 45.39892835001792, 48.29012701588292, 51.10239190440024, 51.98971832952192, 50.923163121746434, 51.48548979913035, 52.03311543310843, 51.17454782609017, 50.023944070262296, 52.54698514938355, 51.806614245137865, 51.114700302000976, 35.430561880911554, 17.071604305698028, 2.7350927456732723, 0.3377231811323474, 0.9557080461132912, 2.682782301018315, 3.773312506175811, 2.5797583066648055, 6.586905852440865, 3.745059918972754, 1.851266545634116, 0.09008437860757114, 0.08894413334107207, 0.2507362415593478, 7.08551166519042, 35.629559409233835, 35.46095240500666, 24.141137215398974, 33.49637446864959, 9.079018062160863, 0.05620379924714085, 0.07115922597867828, 0.02845046771389823, 0.060788605647582206, 0.037148603193101384, 0.03012694771431627, 0.06068914445237287, 0.07903441065742124, 0.03626679002697911, 0.04188914760766972, 0.04347945803836469, 0.04721605571948233, 0.07213351361814045, 0.021630938788275086, 0.023055609518421755, 0.06305404255286821, 0.05605340469628573, 0.03552494878550211, 0.009655483957049588, 0.06299577390534744, 0.032994713589188554, 0.09188161321705388, 0.062332035327750834, 0.011043091353419568, 0.09638770408327542, 0.03772091683781436, 0.033280150288896214, 0.059804734248187275, 0.020736427714807854, 0.03320338061800407, 0.06847653928543292, 0.0762484246684659, 0.019019670641770767, 0.045173726600384524, 0.04350725170825759, 0.05057754610935527, 0.01890652137057435, 0.030979207123539625, 0.0571860465401363, 0.027676106040035526, 0.030500153192288937, 0.07210188950862616, 0.025444248683690548, 0.15228191570889565, 0.0676959646385043, 0.06491868906924803, 0.027188458517494223, 0.026330915016813145, 0.022295970139243913, 0.035702443696678646, 0.031392936737486915, 0.029820470409768245, 0.06798743045017605, 0.05129312202634831, 0.04083221440293616, 0.06297550321887098, 0.05156406051208896, 1.5806644337792553, 37.247478269761615, 36.85336243721747, 30.74493181320929, 53.22934419878068, 43.20136162542528, 9.182715723591468, 0.6244877870044401, 0.03905896983680226, 0.033360478438196645, 0.21537074248396584, 1.3306660421432988, 6.844006430718207, 5.225047651798495, 3.762371299728271, 2.665885956056657, 0.8403762057423593, 1.4199743660226947, 12.516882361904269, 31.040209800966327, 50.867661583808164, 61.426164334820164, 64.04634291125883, 61.61444987020185, 58.407641610791615, 53.65729047406105, 57.60898428578531, 59.23954886774863, 59.9963584253865, 58.44594747789445, 57.541962746650945, 55.410648776638894, 58.576687920478086, 60.25619975982174, 60.331497500019694, 52.78730876984135, 45.227426636603575, 46.962161525603264, 46.61833047866822, 49.02799937032884, 53.2298933306048, 56.67519738597255, 58.3394786619371, 55.637954050494784, 48.869092387537805, 45.02127470508699, 43.981524975069114, 46.34647492439517, 45.29849998412594, 43.71703955434984, 45.55103786530034, 44.48910320958784, 48.74269400873492, 50.36615125594601, 55.670866658610684, 55.967217414609856, 59.817227701986994, 55.47230451337753, 55.707607500014774, 56.89137489564958, 56.907174202703665, 53.40263843536378, 49.49753061417611, 45.75102383090604, 44.52015661424206, 43.8771624718943, 41.91052136882659, 40.557166376421534, 42.78870082670643, 42.853145368637584, 41.07908871866042, 42.435824794154016, 42.81745964480985, 45.27532269877773, 52.67900036227319, 55.49622704905849, 55.75929257177538, 56.8480876184279, 56.1801472017842, 54.5402277669599, 54.425192494546216, 54.92171748991936, 53.08327513356363, 50.019060719397764, 40.757183720988614, 39.95040708972562, 45.65985225862073, 48.03636143284459, 50.801126418575166, 51.647299335848906, 54.97206895582138, 51.957817692910474, 52.12922134707051, 51.38724619342435, 53.58303216195876, 53.072653355137, 53.99584985548451, 52.62153371687859, 53.33738196280695, 36.96446357234832, 18.992971451051776, 4.781354531165093, 0.9583347471010302, 3.2931511488653, 3.1270321530680505, 2.465665138536884, 4.46520168935099, 6.732414018723273, 2.4369732458745283, 0.3772585887101389, 0.06677268313304072, 0.05198188869643116, 0.3481223037646663, 6.3087642096704055, 39.90053415298462, 45.88703986137144, 22.921966506588845, 37.221559247662945, 14.470864995833367, 0.05519804837662847, 0.07756721438659776, 0.016418656582132946, 0.04580527033296324, 0.024543727650457335, 0.03541503432056597, 0.0621093871943172, 0.08191757489957156, 0.03392995755758978, 0.03278510810266579, 0.052845963096666726, 0.047609070315957076, 0.0392786302273312, 0.030299359632115212, 0.025145196686348608, 0.09906932591430603, 0.013193576765667289, 0.025235349913277937, 0.03353693530023579, 0.01033902207704922, 0.04134849254642764, 0.029857531828325123, 0.05759137216955424, 0.06555302519231074, 0.06894096476776947, 0.1600610942489678, 0.11039217438308463, 0.13957450887368572, 0.11912088826178543, 0.22059535487524926, 0.12063516063555596, 0.19929677758726383, 0.08142550130404773, 0.1015007357683874, 0.15362060839130035, 0.13317467164128058, 0.1767445127329519, 0.10366547041602674, 0.14245305360565264, 0.1435549638324207, 0.12633025060377776, 0.13611718471492493, 0.061974992389760675, 0.23117421705636287, 0.24252278309675956, 0.1688989296916031, 0.12851918596894513, 0.13478635209462336, 0.1825183182353935, 0.15674116029854746, 0.10459695672315937, 0.1374359591112983, 0.1833354735807065, 0.18055771537605794, 0.17590760764095092, 0.26052581867383373, 0.25067754390258945, 2.3049322924306317, 40.15990480299919, 51.95012592500257, 40.315917076603064, 48.610157120612364, 52.73378018409976, 16.52717540341039, 1.4210402701170215, 0.18306807825161567, 0.214394731146674, 1.628161272214305, 6.299204412967929, 26.98817195430879, 11.752212374441086, 8.860514586971654, 5.897266884003916, 0.7789084976238589, 1.1241570523669644, 10.944753250768109, 30.206868917711322, 48.13098469088155, 61.59314747779601, 66.39192811904415, 64.8421565178902, 61.745162856194284, 56.394277234231275, 59.70025870107836, 61.862520171749985, 62.64564883324408, 61.43783730845298, 60.107235985417525, 56.93368158032818, 60.391521530766646, 62.12034540791666, 62.65160299116566, 54.21713821349606, 47.18660346923336, 48.6969474054152, 50.08758060393795, 51.93359313472625, 55.22902342580981, 59.47907232469129, 60.837298900850364, 58.311441559945386, 51.706260404279156, 46.8431999606471, 48.179712295532234, 48.16369725811867, 47.760410924111646, 45.38165423177904, 46.832170255722545, 48.67238160102598, 50.2066166939274, 52.10008205906038, 57.95350959224086, 59.804793788540756, 61.60697775502359, 55.700606069257184, 55.89697560956402, 58.84171070591096, 59.869352079206905, 56.47631752875544, 52.89281660510648, 48.37572490015338, 47.222198978547134, 46.20357905664752, 45.67148208618165, 42.800817028168716, 44.961446792848655, 44.322680965546645, 44.38488975647957, 43.21315227016326, 45.460831196077415, 48.09245524867889, 55.887691359366144, 58.190197175548924, 59.08152441824637, 58.62317585176038, 58.10272047596594, 54.40594542411066, 56.333088259543146, 57.062617732632546, 54.880524758369695, 52.80422595239455, 42.34824611294655, 41.84522567256805, 47.42277722204886, 49.983225945503484, 52.258541891651774, 53.643452352093114, 55.65167842372772, 53.0748498824335, 54.726556039625606, 51.82997588188418, 54.91162523146599, 53.6666767058834, 55.977152778256325, 55.63097223158806, 52.910910498711374, 37.80679648922336, 20.582817908256285, 3.7449498474597935, 1.4230749996439105, 3.8623868361596143, 6.098356506516857, 8.92896386884874, 9.118254511587082, 16.097809230127645, 9.69149616456801, 4.286727472659081, 0.2699848901360266, 0.21220454705819009, 0.687937272652503, 11.118126915347192, 44.50123510053081, 45.70302578710741, 32.11770646033749, 46.48716642010597, 14.714870741290433, 0.23620033606646523, 0.17645243405094072, 0.11806509652805906, 0.16665459850863104, 0.14027379393096895, 0.14855034739500092, 0.15843424525472427, 0.31916332220838917, 0.17102490029027387, 0.13917828819924785, 0.1653745575177093, 0.1589454863701136, 0.15923532807538587, 0.18484400795592418, 0.09569955794441123, 0.2481626304647615, 0.11469590312410748, 0.16996530876044305, 0.1427926297389692, 0.13039717390652628, 0.11509885771139977, 0.16129360714506719, 0.19436833478750723, 0.07728949985316685, 0.25739690108645347], [0.04154242004358, 0.022351666646558913, 0.02052991722349919, 0.03760010477215533, 0.03507509812592499, 0.1241362667191894, 0.03274810988636267, 0.0328046165316576, 0.06573845677438282, 0.04873437303749304, 0.038674883995084994, 0.02126013691116485, 0.024823995171895912, 0.07956193880208078, 0.051104308166090524, 0.035361500096417246, 0.006114957382857439, 0.08102532761592059, 0.02978516524777778, 0.02186077091121866, 0.018803827284324556, 0.048260076512252136, 0.04234843264003435, 0.03713606999466016, 0.016200547519650672, 0.01778964753142528, 0.07054914419929828, 0.04082209821189604, 0.018628770447967034, 0.03374718430061494, 0.015679481326632442, 0.027559089940041307, 0.05473235884921686, 4.610812817850421, 39.70227795262491, 35.407035504618, 29.282289781878074, 39.081633475519, 45.12125199840915, 14.902129596279515, 0.7664400795775076, 0.019453977377364234, 0.012313846401089143, 0.6373246014118195, 2.0035734051658265, 3.568347827080758, 1.5391295980061255, 1.5993519535949154, 0.7413205468366224, 0.017268018263782707, 0.543664469113273, 5.9338846610438445, 22.428952032519927, 55.36865588157408, 61.440677104457734, 58.350571124784416, 57.33906246000721, 57.71125616565828, 60.59329609717093, 59.61235838551676, 59.299941601291785, 57.74868734421269, 56.2224970325347, 59.91905635403049, 60.02236373962895, 58.418804676302024, 54.86031670724192, 45.677852015341486, 44.0684643099385, 45.93023692407916, 47.47468586890928, 48.42926133063532, 53.0802470637906, 55.304709480654815, 57.05342761931881, 56.05086588090467, 50.08077529168899, 46.502530344070934, 44.37604873411117, 42.42337519122709, 42.53874778747559, 40.94417095184326, 42.20760168567781, 45.30785483698691, 50.321479382053504, 52.284072599103375, 54.848596665167044, 55.62870510162846, 57.37064146226453, 57.30624791114562, 51.763738816784276, 57.670879287104455, 54.16530016929873, 53.16577042302778, 50.613570444045536, 46.53296401423793, 44.15696082576629, 40.35867875622165, 40.73803863217754, 40.97457324304889, 43.02766338471444, 40.74994302565052, 40.57657426403415, 40.818792389285186, 45.73751518803258, 50.99893939110541, 53.55519117847566, 53.95123681714458, 57.21480177294824, 55.004181400422134, 54.95109212013983, 55.51438370058614, 54.23099986968502, 55.140064070301676, 52.686982385573856, 49.32567196507608, 40.59313843327184, 40.201246584615404, 46.90007432814568, 48.01895787639003, 49.55495019112864, 50.923104286193855, 53.73125853077058, 52.05774791779057, 52.50065803527833, 52.97008729750111, 52.45265214673935, 51.76732778549195, 50.36544522931499, 51.09822242490707, 45.14959896764448, 21.919436147136075, 5.927578470399303, 2.1493068625850063, 1.2193121592844687, 2.30326283362604, 2.240062418483919, 1.511350759575444, 2.7036819150370937, 4.546584496575018, 2.7325691907636585, 0.1612420647495216, 0.10302207913369903, 0.0819752996246661, 5.933420840770968, 28.022014594847157, 34.9652511073697, 25.35042747374504, 32.85547487197384, 21.293941659312097, 0.5781200395957117, 0.050448778220602584, 0.04110194630019608, 0.052835310644079606, 0.05564373917877675, 0.03573904354726115, 0.04940930032922376, 0.0475586579000998, 0.09597553345825403, 0.019127652649917913, 0.05582308419229043, 0.02728511008524126, 0.022335816287405552, 0.035460945969868096, 0.05303276214568366, 0.043832586267061775, 0.027178656422503056, 0.043378050979827686, 0.1094038979781251, 0.026520851195880005, 0.028638486757934577, 0.05873829772275302, 0.029402831832187313, 0.07068397567397164, 0.042571000334235935, 0.0890837911696684, 0.08324163530262248, 0.06973301541180381, 0.029414282931435495, 0.023013319549781662, 0.032621935205233675, 0.09585286745981825, 0.07278649632128016, 0.019997093496063066, 0.03478342930095331, 0.008554832029697156, 0.01772693365872387, 0.022681844796264367, 0.05590659926735586, 0.06523217990874283, 0.07484666762813445, 0.04185673059715379, 0.01449061724762883, 0.0464084190166285, 0.020021412957219348, 0.02374600987100313, 0.04032274295065192, 0.042699404331224586, 0.011045844481897452, 0.03448958095583705, 0.024487245903019945, 0.004982858025018247, 0.03888092334232023, 0.0171883566109764, 0.03297693268846601, 0.016909247797523296, 0.09208658770207437, 0.02745268607301818, 0.07586978571189028, 8.524807749256011, 48.71165629356138, 33.40351627719018, 29.13779162591504, 50.48921562010243, 50.53664884259624, 12.577676157797537, 0.3970392547067135, 0.012109290391597296, 0.036636431280884056, 0.3370856121182442, 1.69036932770283, 5.7042852909334245, 3.8795959901425148, 3.204187135542593, 1.2982822185562504, 0.9044095729627918, 1.2951667534728206, 8.271049030365484, 26.09886080987992, 56.851958997787975, 62.853197128542014, 60.51704129865093, 59.96251621553975, 57.35646993883195, 60.745609575702304, 60.56685932220952, 60.348077358738074, 58.34134571013912, 56.21071423253706, 61.43054169993247, 61.68455439229166, 60.421206028230735, 57.25746931568269, 49.20535718241046, 46.16983098368491, 49.14861225312757, 48.606285741252286, 50.8565769657012, 55.326427644298924, 56.74300339914138, 57.23384880250501, 57.00600224156534, 50.749284452007664, 46.62275098985242, 45.00080777752785, 43.663150110552394, 44.14808057969616, 42.30365268645748, 44.24568091669391, 46.477305581492764, 50.67353956161007, 53.22075813047348, 57.00648861546671, 55.5318304031126, 59.615339386847715, 56.623331885184015, 53.187104194395005, 60.06153645053987, 56.06414310393795, 55.601193597239835, 52.01717099835796, 46.11578856745074, 45.28195542673911, 42.71359528264692, 41.354337123132524, 42.618724915289114, 44.07444984682145, 41.65333940136818, 43.27691039731426, 43.10439279002529, 45.93727757853847, 53.24512389398391, 54.56975929198727, 56.755456924438484, 57.749409060324396, 56.56912865177278, 53.54342406795871, 55.10697887789819, 54.63940881913709, 55.28605468811528, 55.200076333938114, 51.727492194021906, 42.624784977205344, 42.183914492207194, 47.38715033377371, 49.57359321655766, 51.36398261593234, 53.748830749142556, 55.15474942422683, 53.29844851647654, 53.612818641047326, 53.71760083783058, 52.449337743943744, 54.317884291371996, 51.034797699220725, 53.424913575572354, 46.09694942351311, 24.940141670165527, 8.025498851653069, 2.178869766573752, 1.7371130710647953, 2.0602403773415476, 3.2459755770621763, 3.483309861152403, 5.299827148837428, 3.806920844701029, 1.2779563737492408, 0.35333084363129835, 0.16168086459079098, 0.1319027511823562, 5.2614825483291385, 29.950789136271325, 44.04711484909058, 27.834264462993993, 34.48605514341785, 29.467764939031294, 1.3351702714158644, 0.05181861237712926, 0.0301206887759749, 0.057978809645940224, 0.03718784987746227, 0.017908222620345412, 0.04549899604171515, 0.010714550716652265, 0.0801998372339914, 0.02910756239397151, 0.015548046494293359, 0.031159628490586917, 0.07030643988400698, 0.03330466127203357, 0.058877380985406146, 0.06879003012492772, 0.10228321797424748, 0.04415060468618909, 0.014625355834141375, 0.03290660581701706, 0.00987729035137642, 0.05132159751449382, 0.06652642416978075, 0.07463146586932483, 0.02788159954962471, 0.05272233565788596, 0.17743854242707455, 0.19081013217087717, 0.1624678667154043, 0.10263842230121936, 0.17626880277549067, 0.26602302047033466, 0.23896477966298982, 0.1176596061897374, 0.14745756893629028, 0.16442506814435606, 0.10449351953162302, 0.11718095445464696, 0.07976384127452489, 0.1641158444145995, 0.23227343065363748, 0.2050833001492485, 0.10811009038720401, 0.10700255707507172, 0.20093127213899167, 0.13584799674009124, 0.09339057660150914, 0.12882862420332047, 0.09039839038685446, 0.15368960226976103, 0.1463104442002312, 0.15770102250239543, 0.09677344467490913, 0.15644776394530652, 0.13022616776006837, 0.1227934371619936, 0.11048508552654136, 0.05928954394954828, 0.14659264034801914, 8.224775848850127, 55.97967486227713, 44.660471562416326, 38.913285347723196, 48.156550699664706, 58.95248236194734, 20.377777968683553, 1.6199052958719193, 0.1482472830121556, 0.2765745945995854, 0.9219977872506265, 11.501271878519367, 13.565903594416957, 5.355430668400181, 5.208001031029609, 2.769789541921308, 1.0085621680463515, 0.826077450427317, 7.549126994225287, 25.258722459116292, 58.822145923491455, 65.9809107934275, 62.04329044588151, 63.4311269944714, 62.37599765100787, 65.63100399509554, 63.13166187655542, 62.52964473539784, 60.236042699506214, 56.86990384132632, 61.90986317972984, 64.85751259711482, 62.950381694301484, 60.38864643343034, 50.96130032693186, 48.1818421425358, 52.663718808081846, 52.60866049797305, 52.408474491488555, 56.75840654680806, 59.86480997454736, 59.75052387483659, 60.852321578610336, 53.75381608163157, 51.094990391885084, 47.75777509135585, 46.530379172294374, 47.93182242301203, 45.007911189909905, 46.00244383658133, 49.72391020867133, 54.81023588488179, 56.63492641141338, 59.83604723407377, 57.882671586928836, 62.22369201721684, 58.87970278340002, 55.213608511032604, 60.92186127939532, 58.30431853571246, 57.86251060424313, 54.59589404444541, 50.09972426199144, 47.61882512800155, 43.944870425808816, 44.54895465604721, 46.38280391693116, 46.2169857178965, 43.384124463604344, 45.411217135767785, 45.32593304111112, 50.544881897587935, 55.702582943824034, 57.81834471610285, 58.882299392454094, 58.7546693894171, 55.03066524382561, 56.177428999254786, 55.867189130475445, 54.70148817185433, 57.26485121634699, 57.91557635030439, 53.16491142396004, 45.09701567311441, 44.68829293404856, 49.9742554849194, 51.33061501287645, 54.12053415852209, 54.916073199241396, 57.212342446850194, 54.7077835759809, 52.91808451375654, 55.14452772755777, 54.9047100928522, 56.250883225471746, 52.456484302397705, 54.48049006923553, 48.006994647364465, 23.990478977080315, 7.321894284217589, 2.9257454314539513, 3.584442047342178, 5.308277405077412, 6.24994581745517, 6.208707488352253, 9.120946238117835, 12.36104267258798, 7.259141264423248, 1.038724765662224, 0.2619386380237918, 0.4672644816098675, 9.445181123671993, 37.15910334740916, 46.580565898649155, 34.51074646365258, 45.151120847271336, 32.26199673068139, 1.238280864011857, 0.21859880717050648, 0.18046658155658554, 0.12609203556372275, 0.14004027500988978, 0.08464117068797351, 0.23717997866051815, 0.10334829469361614, 0.20525833591818812, 0.14399419268292768, 0.17175562559596955, 0.14558454524845849, 0.17434204568064984, 0.0927422976782245, 0.1728954571749895, 0.19834534235058293, 0.25166814155395956, 0.16571755040316813, 0.21676134528411975, 0.10639232973898612, 0.13380090255410443, 0.13861717475998786, 0.13647218985903647, 0.15432657373528327, 0.12070943285981495, 0.1477108682475744], [0.020415733733604995, 0.035098467638055166, 0.055774483574374076, 0.022784044755803003, 0.027920285074581063, 0.07577979336342505, 0.04890534470999434, 0.01788445665771442, 0.04290398045052444, 0.045886215183042714, 0.056807051352675886, 0.07116391443677487, 0.006007033788914522, 0.028678884489401698, 0.04407412229826854, 0.02589221093653431, 0.01801143956160353, 0.010339208810980762, 0.03292954248947001, 0.06442887543310082, 0.023306861459728212, 0.026964542508545904, 0.09811730078992345, 0.038662507844668244, 0.07214076080990416, 0.0035166746660721523, 0.025291781865000248, 0.0907650783718113, 0.02811229735192272, 0.04463527404192475, 0.020908908580519983, 0.030779325207995794, 0.018684254365883047, 0.12098020663665188, 11.39254181615768, 42.87416927276119, 34.805704778240575, 26.68737715290439, 37.91160222022764, 42.739208359872144, 17.06254166941489, 1.562592358358445, 0.12023155487352803, 0.047578786860310265, 0.8245390233012938, 4.986422907921576, 1.2085347117916232, 1.0059427602156517, 1.1158913926732157, 1.2514318357552252, 0.38849593410568856, 1.0852619717198035, 10.431565046310425, 36.23625986037716, 60.08063054853871, 61.19263818187099, 60.06682380553215, 57.80084702276415, 58.792410435215125, 59.3769730291059, 59.41307060180172, 54.957077657022786, 54.60209531168784, 60.64062341567009, 59.99025913976855, 56.78090133974629, 51.97328359849992, 46.62034265456661, 48.17312271364274, 47.0278416141387, 51.18516568214663, 50.45030178562288, 52.71343485001595, 57.68840835940454, 56.99548244476319, 55.743497187091464, 52.74885777504214, 47.3762422223245, 44.66260140941989, 43.72550010681153, 43.48735340179936, 43.200031941936864, 44.89306811363467, 47.99621205176077, 57.2883697479002, 55.23902546974921, 58.91273306262109, 57.82215725991034, 58.42378216405069, 54.61371337213824, 49.88628064432452, 59.92571261621291, 54.79340891684256, 56.165414779416984, 53.74637534541469, 50.986536856620546, 46.3396264660743, 44.607935336328325, 43.66536624969975, 42.18301626943773, 41.009274451963364, 41.5364606149735, 41.47513435732934, 42.863343531085604, 51.37491426160259, 55.58888127726894, 56.39423408815938, 57.20740418280325, 56.901310259296054, 53.1675668685667, 54.53716047348515, 54.398634126109464, 53.92630230995917, 56.36662060214628, 51.867175640598425, 52.8706826702241, 41.15217031971101, 40.96954476448798, 47.14830544687087, 50.52311666550175, 51.60789128272764, 52.56098016615837, 51.886465857105875, 52.021336555480964, 51.58349021788567, 50.8692579884683, 52.77574170020319, 52.86499131110407, 54.75903718702255, 45.107708054204146, 26.317703570089034, 7.6466130921917586, 0.9086630769794988, 0.8221623121250061, 0.9700243908070749, 2.1892157533476433, 2.333075543565135, 1.3210691054982524, 3.3938329979296658, 2.8521254850972086, 0.20115117001677715, 0.04356812888516053, 0.11034715139577467, 5.821832841442478, 30.375936800433745, 41.23850560957386, 35.328780297310125, 30.154095388227898, 33.37625188212241, 4.055927612127797, 0.13381558079873362, 0.0750170762260114, 0.04516021663983984, 0.04690169920063308, 0.02848515042945022, 0.05005313977298718, 0.08660095383323009, 0.021800558315590027, 0.05593233599117207, 0.08189425518315646, 0.03743288310004338, 0.06731750188215126, 0.04834694705242592, 0.035140587152132106, 0.043947568403617035, 0.02021649533191756, 0.007813990054156391, 0.008033438334091297, 0.09057118917905516, 0.05598519222750779, 0.04472046684954436, 0.02601282956499246, 0.042139313619343505, 0.017023339356866576, 0.040872671506217415, 0.024497111200264866, 0.04749563184656924, 0.022211474471635396, 0.03317182928684258, 0.023562001297250394, 0.027467992509745305, 0.005102928421805583, 0.0373601698647103, 0.01914452956688981, 0.05134284496307374, 0.03415296958278745, 0.07929413744639005, 0.09365899848841852, 0.03066443308677164, 0.012279434689140369, 0.015412085997541587, 0.08098205130907797, 0.017162016592919827, 0.0133375266018594, 0.041991309262812145, 0.07550875911669386, 0.034792120568454266, 0.006795874045741174, 0.04458951561020748, 0.04754858767433513, 0.06619201146907384, 0.05645251352219813, 0.01304484749843757, 0.07852936719333933, 0.055690734842491735, 0.01260999396758815, 0.06670917444411786, 0.012418768845588691, 0.022962231061331207, 0.40786018535014124, 19.14634789189985, 48.34616984090498, 33.62318861869074, 30.1606124062692, 51.7718267440796, 50.610295264951645, 15.245091838221397, 0.7548578107549299, 0.06299203156583733, 0.01585201198805965, 0.19529793651834612, 1.671106567786586, 6.633298666246477, 2.623629526745889, 1.645191590632162, 2.3680893163527212, 0.7268341306236483, 1.550205513354271, 12.474493307452049, 40.9479481943192, 61.93689223258727, 61.4550486687691, 60.93433833891346, 61.16677799532491, 59.17845010757447, 61.67572513703377, 61.2234954680166, 54.45597917802873, 56.27959105276293, 62.909906756493356, 61.027471096284934, 60.18618937461608, 55.63159588844546, 48.50786562888853, 49.380667517262125, 49.50190797928841, 51.35800100141957, 53.13992200359222, 54.363489689365515, 58.448826497600926, 57.83274373700542, 57.280991769606075, 55.488731399659194, 48.77341793429468, 46.25634670257569, 44.91395081243208, 45.539047179683564, 43.86531299160373, 46.075352853344334, 50.94921942680113, 58.27714827752883, 57.906586277869444, 59.33286205414803, 59.27843916800715, 60.27017124237553, 57.51843637035739, 53.43103639541134, 60.95049458165323, 57.90757471515287, 57.731079824509166, 53.55675228180424, 52.1570074173712, 47.4480765096603, 46.82635730312717, 44.95500233865554, 44.2962481129554, 43.21200301570278, 43.324661331792036, 43.982952717811834, 44.032794275591456, 52.9675377568891, 57.0525372412897, 58.519001622353834, 59.20202355231009, 58.72982117437548, 54.97437923185287, 55.301803004357126, 54.134740983286214, 55.319900820332194, 56.030296971721036, 55.25264001661732, 55.3378652757214, 42.86059394959481, 43.08966821239841, 49.6215049682125, 51.107604734359256, 53.607739171674176, 53.34986294469526, 54.42476103382727, 52.81296499313847, 50.73013936319659, 51.29103045309744, 53.848772741133175, 54.691831296490086, 54.626633659485854, 46.82811452496437, 30.378892306358587, 9.275601371642082, 2.0283670747472398, 1.701969492339319, 2.192218327714551, 2.8144751441094185, 5.230707141660876, 5.073181813763035, 3.2275661778065468, 0.6260979199601758, 0.18274814461267766, 0.13446248076375455, 0.1525889484271888, 3.9137897424159513, 33.468129481038744, 45.015093049695416, 34.536375230358495, 31.210734844207767, 38.8596861593185, 7.555749425964971, 0.25572768742999724, 0.06093707731774738, 0.04948023241013289, 0.01601076647338848, 0.018505838233977556, 0.029775671503176133, 0.12377090406634154, 0.035139974281792684, 0.020849259059515693, 0.05689432791944954, 0.03132093979436303, 0.06847561231904453, 0.05958551818865442, 0.018317706191972382, 0.022520286429132667, 0.09477187143338305, 0.06854056891414427, 0.03508601487884599, 0.09442087292911545, 0.01126947225026426, 0.02992291168700303, 0.02398296086598308, 0.03279637725603196, 0.08244789926515472, 0.03956675589565308, 0.028894982571082733, 0.12764324103632282, 0.17241614660428417, 0.17628182627020345, 0.12963051907718182, 0.11964082447511536, 0.14824572019279003, 0.10778071854503886, 0.15421621110891143, 0.10291360108362091, 0.16269161035456967, 0.1762372705965273, 0.18260085654835548, 0.1555040202313854, 0.17446716316044333, 0.16569173324011988, 0.16772974162332474, 0.13093528938629936, 0.0792797579760513, 0.11021012890963786, 0.10722772563777624, 0.1408398409764613, 0.11944994600790164, 0.24597472931829192, 0.2037872479207093, 0.17960885419480263, 0.1310575876625315, 0.1096478586776122, 0.225750973388072, 0.09257850808001335, 0.1171228849899865, 0.2153489242998823, 0.12766874410332213, 0.13435982498190097, 0.3752944618463517, 19.713283354236236, 59.330728284774295, 46.74927880687099, 36.59984396349999, 47.77676328536003, 55.2975276208693, 22.382205224806263, 2.5800551810572228, 0.18465202632209948, 0.3367453465057958, 1.5572006928343929, 10.203118362734395, 9.526781132144313, 6.378239681643825, 4.693580712041547, 2.5530925633445865, 1.3547351764094446, 1.5780967522052027, 12.284931040579274, 39.9450687439211, 64.15811869405931, 66.06405719634026, 65.58517894437237, 63.39273483522477, 62.15442295997374, 62.85747643440001, 62.613426562278505, 54.944796716013265, 56.604461362285, 66.16629769725185, 64.46471468094857, 64.17422786835702, 57.374359869187884, 50.5797125447181, 52.69555276440036, 51.85750699812367, 54.81573504786338, 53.52452216609832, 56.92131826954504, 61.07326476804672, 59.59790837380194, 60.75062236478252, 57.70397232424829, 52.25375660004155, 49.15741405179424, 47.58319431735624, 47.991693481322265, 46.722618456809755, 48.05961716559626, 53.59321071255592, 62.00150151406566, 59.288531426460516, 62.47887357588738, 63.239244645641705, 62.617650954954094, 57.647682389905384, 53.26704994324715, 62.67656495494228, 61.301236844831905, 61.30242140062394, 56.15449097848708, 54.25199239484726, 50.89660083093951, 49.26810726042717, 49.3683591196614, 46.50529953741258, 45.76532871492448, 45.9055926722865, 46.96907666421706, 46.43433209388487, 56.19810381243306, 60.622627581319506, 60.86437109977969, 60.393180693349535, 58.54831741702173, 55.1143882351537, 55.3978540051368, 56.21161637767669, 55.9176778793335, 57.606497503096065, 57.11926852503131, 57.66316790734568, 44.1078802078001, 44.52526746257659, 50.90897590883317, 54.39237010094428, 56.055270702608176, 56.02997925973708, 55.69585215660834, 53.68872042625181, 52.344524168199115, 52.18101232282577, 55.29244030675581, 56.968363177391794, 57.147603727156124, 47.847256122096894, 30.81629933849458, 9.798089515778328, 1.5779334835467802, 2.829400007763217, 2.393127276051429, 6.083594176077074, 6.388268201581894, 7.597895293466507, 8.802268370505303, 7.116280207710882, 1.2967380304490368, 0.20575776395778503, 0.35865907707521993, 8.166483544534254, 40.42881465727284, 51.745464494151456, 44.82580338754962, 40.071172944961056, 45.739021378178755, 7.8738075590902765, 0.4113251397446279, 0.1713194764189182, 0.1252525181119, 0.09595040577433764, 0.06074854307958196, 0.14537440733082835, 0.3064598990303855, 0.10290233959113398, 0.14764198162142309, 0.14028687871271564, 0.13627374244313087, 0.27470684159667264, 0.1100483081573921, 0.12076131999492647, 0.237933426134048, 0.1056811243536011, 0.15378246744794233, 0.1401533036222381, 0.2191763608566215, 0.22313778619131736, 0.1891050655995646, 0.16818418498000792, 0.11063142364183742, 0.15991939862649288, 0.08008470954073053, 0.09521300784282147], [0.05106570116514641, 0.049697230645124955, 0.0939328059734356, 0.03591211047023535, 0.032918771293254635, 0.0684597849425289, 0.06069851370768682, 0.02198406127131274, 0.04764538671400759, 0.007181661081455288, 0.026280290011556882, 0.030307250337735302, 0.054062142998220465, 0.0792788616531799, 0.01997692431623657, 0.019184931128796552, 0.04707029983100872, 0.0653860180248176, 0.05819039546974725, 0.09650385833435482, 0.01940706598332092, 0.019634161257155, 0.055269673767109076, 0.012552857214975502, 0.02404914511698148, 0.02893300351476477, 0.016970124974426244, 0.04068507189531961, 0.05404181485514968, 0.03200840794541423, 0.076207316390449, 0.05811208979256692, 0.03493905623233126, 0.06428937848296858, 0.6313536508429436, 15.96044586550805, 40.99975878192533, 30.799782237698956, 28.903337832420107, 35.61789035797119, 39.783157225578066, 20.949798783948346, 2.6482272003927543, 0.09324254543190041, 0.41691228026343935, 1.4117963467874837, 6.385718170673617, 2.094569451385929, 0.3713117545891193, 1.3730005511353094, 0.5552263906405819, 0.17018174392081079, 3.8283632166924018, 20.76354111394575, 43.83535392822758, 61.85191016043387, 59.88309998666087, 62.6075469293902, 61.331968615132, 63.19768321129584, 61.16677799532491, 56.340348566732104, 55.48697025545182, 62.80681510125438, 59.87704776948499, 57.76596146245157, 50.573350460298606, 49.90910491635723, 49.49638528208579, 50.901676377942486, 50.30260493678432, 51.47309510938583, 52.817005034415956, 55.76363071318596, 55.27739017240463, 56.739022193416474, 52.90858453319919, 51.734591684033795, 46.42876232824018, 44.723939434174575, 42.176975819372366, 43.9611247278029, 42.32736341414913, 51.408423069984686, 59.456185294735825, 58.23231166408908, 59.14931866430468, 57.2255608343309, 59.2369601034349, 55.63912291680613, 45.48953117862825, 57.89485839105422, 56.83595180511475, 57.27681444537256, 55.322034589705936, 52.64830781567482, 49.95422786281955, 49.756505104803274, 45.76340283116987, 43.041242630251, 40.906543654780236, 42.031146018735825, 41.018452798166585, 51.14307472782751, 54.6627273098115, 56.653122286642756, 54.673027453884, 54.95977624770134, 55.006268101353804, 53.35418147425498, 56.8294563601094, 56.56251161329208, 56.13939769806401, 56.180460991397986, 55.55108139591833, 49.31688193351992, 41.22964105298443, 40.907779201384514, 49.15790434806578, 51.50229323294855, 53.12813920359458, 53.99518305255521, 52.51209958907097, 51.59880315103839, 51.633359232256495, 52.266865161157426, 53.84976902315694, 52.78924249833631, 43.98361559837095, 28.513999446745846, 10.099026503101474, 0.8780989267172352, 1.0332280541619947, 1.4498950637155965, 2.1730570591265157, 0.8316334877764026, 3.688797441221053, 3.0836607900358017, 2.846728058591966, 0.08827699333309166, 0.04939222805983117, 0.29085658791084446, 7.438294541451239, 33.3946438758604, 35.89784952902025, 46.149101257324226, 34.75322738770516, 36.00403201195502, 13.895637642952705, 0.07561282450032812, 0.0604674386070861, 0.033441480744870446, 0.09982884080419618, 0.06357921497716058, 0.09727652695390487, 0.053238276722690756, 0.021873953369175716, 0.05861488478859106, 0.04510208971858506, 0.06122525661222397, 0.05886579773599102, 0.016063368943099295, 0.024024810334066712, 0.02449880808501715, 0.02710118769638, 0.01871564290336063, 0.07118604671690734, 0.00837167572876018, 0.0295051658571127, 0.0623030542215753, 0.016178865316173723, 0.05771579250933663, 0.0010689735931772438, 0.025541674000241106, 0.03533948655991304, 0.07116586030010255, 0.10969904101183338, 0.03875415494304992, 0.05118482783737202, 0.03338353385427787, 0.04177607303004592, 0.07040606195768041, 0.05120309137348687, 0.034349053617446654, 0.03181350751659803, 0.010048858614848747, 0.05669915935985985, 0.009970077963155365, 0.026608376741229046, 0.05556437630026091, 0.0619074885523127, 0.05170111747218236, 0.04927461441125601, 0.01676073016208266, 0.08091840472432875, 0.036087805074789835, 0.06726703200969966, 0.035682613510758646, 0.10130349877140216, 0.05457677788311436, 0.059822790940562566, 0.011465511277257916, 0.04427615117522017, 0.04038085455014821, 0.0360356996046199, 0.010057180244926243, 0.0418987735024383, 0.036971851387211395, 0.00924006033117973, 0.025896319083028266, 1.199121636248404, 24.464554286772206, 43.56731484013219, 28.625294739200225, 26.767930869133245, 47.18481879080496, 50.919472171414284, 21.07584414943572, 2.1622634318567093, 0.0836995950028781, 0.16798026769632296, 0.3815022868014151, 1.5094143344509987, 3.0099594544979835, 3.9626485013192703, 4.3059720916132775, 1.2595163309766402, 0.5702798957786253, 5.285734072808297, 24.25263450991723, 48.44264838003343, 63.30387746134112, 61.44207346823908, 64.27845701094597, 65.03205022504254, 64.64762264682402, 62.337232866594874, 56.50763373221121, 57.317967953220496, 65.34586337304884, 62.13848636996362, 60.122796027891106, 52.69223443923458, 52.788834571838386, 50.46205712902931, 52.84201014426447, 52.89928459352063, 53.90793777281239, 55.06592735167473, 57.354500909005445, 56.55786360463789, 58.694049158403956, 54.61676105376213, 52.45158918442265, 49.37115576959426, 47.47508202829669, 42.68830383977583, 44.45187207191221, 45.27835469092093, 54.57968288852323, 60.380684021980535, 58.90400578898769, 60.10993457609608, 59.20059188719719, 60.76512336730958, 55.278107966146166, 48.75825012883833, 59.32580178783786, 57.596369943311146, 58.509921335404925, 57.470454016039454, 54.59756889650899, 52.33185099017236, 50.924869352771395, 46.95581513066446, 44.440826677506976, 42.47033380693005, 44.334110752228774, 42.03036938944171, 53.15177148388278, 56.85077444199593, 57.88025932927286, 55.401909735894975, 56.28374484277541, 55.68621489309496, 54.92305894051829, 58.11515831178235, 55.943616513283025, 57.062798161660474, 56.85599903906546, 56.335731937039284, 51.94035530090333, 44.20913227142827, 43.177062542207786, 49.76956659747709, 52.403928464458836, 54.57442299012215, 54.83897116876418, 54.45069966777679, 52.63281837586434, 53.54919387448219, 51.743699427573915, 53.54605990071451, 53.17337197642173, 46.86566337462395, 32.85969926464942, 12.662997514970842, 2.670173351803134, 1.2342077277360426, 2.3400872705444216, 2.0282426620683363, 2.482560502906, 5.502447476310115, 4.362462066834973, 0.9637823676870716, 0.1795818419345925, 0.06592208804983286, 0.1843387576481027, 5.231528387915704, 34.34845055303266, 44.66393501527848, 48.324384996967936, 37.37423358425018, 39.05782861094321, 20.596905100730158, 0.19419582710871774, 0.02995435385063531, 0.03440131230520145, 0.04567695443608588, 0.03547079786057434, 0.10151697683238214, 0.07997409410534367, 0.004491082724979929, 0.014055751267850641, 0.0327963657647131, 0.07833085082952054, 0.04404267821941645, 0.04306727209158483, 0.030560515175062804, 0.0053684382169928045, 0.011485733125629205, 0.05516937370562265, 0.00820162144654821, 0.0256898986070507, 0.04204955492769519, 0.06386300458783103, 0.03609614011140601, 0.0197051412185594, 0.04538523581539912, 0.08329248821903622, 0.012826322833256376, 0.018103636328070875, 0.36965847556148806, 0.1491735599214031, 0.21470803046418777, 0.15956914322751184, 0.11432644956174398, 0.1571848937460492, 0.23076662763712869, 0.15131727311640017, 0.0788067140045666, 0.07867005157975421, 0.17938469686815817, 0.13042689811798835, 0.0909049277223887, 0.19664678752662676, 0.20030899423985712, 0.11958819423471728, 0.2580073199445202, 0.1488985343565864, 0.19189644484750687, 0.1736248801312139, 0.1183165955327211, 0.12263546217112772, 0.21820059466746547, 0.15657073637891203, 0.10324657353903018, 0.1366627618910805, 0.10645711013386328, 0.15990588483550858, 0.16489100281990346, 0.09053238682569036, 0.1405831402347934, 0.11466140618487713, 0.09127468771992192, 0.14678443812074202, 1.1594756668613804, 23.130809184043642, 54.26878013918477, 42.2542033656951, 40.23774816143898, 47.07411381506151, 51.840503523426676, 28.288396481544744, 3.6837356225136793, 0.146648166400771, 0.904359256307925, 3.862451800415593, 12.458970527495108, 10.046327498651321, 3.026185074160176, 5.373009750919958, 1.9377375249901128, 0.4278004734266189, 5.057137358573176, 24.65560901549555, 47.4244991425545, 65.16853693992861, 62.73864430765953, 67.3147363047446, 67.01149002198251, 66.51566320850004, 63.8083452563132, 58.7640203199079, 58.037926843089444, 67.3457230291059, 64.63554174669328, 62.44479994620047, 56.03755727890999, 55.354947197821836, 54.34086153584143, 55.91996854351413, 55.195871553113385, 54.6237507174092, 56.274421368875814, 59.298906095566295, 58.77230436571183, 62.92285842280235, 56.51438805364794, 56.19622891949069, 51.409744908732755, 49.46784611671202, 44.97968189177975, 49.065395247551706, 47.33810893950924, 56.692969645223315, 62.928769434652025, 61.972538732713275, 61.92163029024678, 60.60800106294694, 60.297192450492616, 57.23038927201302, 51.28104409863872, 59.63071900029337, 60.06304264068604, 60.60814226827314, 59.967532926990145, 56.06006383895875, 55.89915644737982, 53.308066168139064, 49.27697573938678, 47.31442959077897, 44.912099453710745, 47.42388333043745, 45.468942657593765, 56.82041921923238, 58.3949762775052, 60.94099460109588, 56.88600517088368, 55.451861120039425, 56.54541400171096, 54.85444884146414, 59.744150023306574, 57.543908242256414, 58.60504273445376, 58.37141067750993, 59.59597072293682, 54.52361260690997, 46.45206905180409, 46.30762384783837, 52.28008747100831, 55.71822143370106, 55.15553389826129, 56.84673047834828, 55.91568923765614, 53.770242967913234, 52.62786442233671, 53.53162165611021, 54.2073283656951, 54.83813962628765, 45.121887422377064, 31.403715456685713, 11.978933215141298, 1.6755145764158619, 2.7379305804929426, 3.4764839564600303, 5.791550182527112, 4.281553376105524, 8.017685980566087, 11.409820837359275, 7.887988398152014, 1.0974436277343382, 0.2196006663143635, 0.5069094091173142, 9.577802342753257, 41.89054473753899, 44.94868732267811, 54.712031502877515, 45.684865213209584, 47.50553531031455, 22.275093140140658, 0.2202747317571794, 0.16253063995991984, 0.1765099212887787, 0.21855662636939557, 0.33832345698629657, 0.14203182782136625, 0.11884265278856601, 0.1438163377104267, 0.18382978415296924, 0.12579728323485584, 0.20333225298072063, 0.18079462040576244, 0.13298871145854074, 0.06950118954503728, 0.2686723057300814, 0.10076270198389407, 0.1180605229831511, 0.139979861316181, 0.11712349019944669, 0.10405754655479424, 0.15578460759453236, 0.19621943303894615, 0.1298655242088341, 0.09962270952641003, 0.08475240665457903, 0.11489598996817105, 0.1473211746422514], [0.01606874975315746, 0.05465888335639912, 0.04388698234012531, 0.07024902159408217, 0.017573635634635727, 0.037298790900216955, 0.05023141609384649, 0.0160048637659319, 0.02261534644921701, 0.0620190769193634, 0.029913122998550538, 0.07294359031103312, 0.10998598690475188, 0.009432961270513554, 0.04904533578683773, 0.006644770863556093, 0.03382944299148456, 0.09858449951054589, 0.0429318392378909, 0.016914432297550866, 0.028205750502585888, 0.04050543193795508, 0.0343868600565099, 0.03928176735738113, 0.027589384887006976, 0.026362403145720883, 0.02350335152098729, 0.015720397125058357, 0.1396327775212065, 0.03374541846794948, 0.07783287069610051, 0.020101846443609368, 0.025061605002490744, 0.06441890096832668, 0.0051060712975149435, 0.5473258790950621, 19.887697427503525, 42.15720315133372, 31.068431254356142, 29.86157874907217, 33.611951028147054, 41.54199115691647, 25.34525778985793, 4.29712224391199, 0.1277730316524544, 0.05421190935697767, 2.2965278788920376, 0.7601675968016348, 3.788612936773608, 4.256569839292958, 1.3772004289973168, 0.2710776073077033, 0.24668976514329835, 6.349636777754753, 26.692892005366666, 52.21062621762676, 63.90552589970251, 57.792323712379705, 61.99192308610486, 60.22167897993519, 61.60140406700873, 56.309914896565104, 56.634777361346835, 60.55740248772406, 61.81202357815158, 55.805909941273356, 54.8154487148408, 52.06684781659035, 52.55693228014054, 52.655877990107385, 51.416765951341205, 52.05269198263846, 51.33869117306125, 53.59434035516555, 53.41467226705244, 54.366396165663204, 53.47694381590813, 52.905199527740486, 49.45660068142799, 47.88364787255564, 43.80162938948601, 46.423839753673924, 42.51313863262054, 51.60245095529864, 61.6983062221158, 58.64665908198203, 60.119462013244636, 59.39609850606611, 55.390048488493896, 58.12603896664035, 43.741452386302335, 55.645853704021825, 61.271179722201445, 57.251201368147335, 59.051169195482814, 57.14455212316206, 54.728893772248306, 50.559076955241544, 48.97581615755635, 44.021297808616396, 41.867696931285245, 40.74225518011278, 43.57736787488384, 51.357200837904415, 54.80446607835832, 56.146591324960035, 56.342858883642386, 55.9210785742729, 55.03504653130808, 56.61563227253576, 56.04288777997417, 57.19740213886384, 54.75225540899462, 54.272510313218646, 51.62510264304377, 49.427806561993016, 41.352266111681544, 41.74332249549128, 46.72785089861962, 52.68257756387034, 55.96370297093546, 52.20189502162319, 53.54599322042158, 54.21775402561311, 53.82833719253541, 53.387953081438624, 53.40205792457827, 46.927766261562226, 32.498788256799024, 10.67774574602804, 1.303138848273985, 0.4378921802966826, 0.39485844753442273, 1.803229032985626, 1.3741684368541165, 2.2760445264077958, 6.046654274386745, 3.7182272297720758, 0.2770986293833102, 0.0909893659334029, 0.22975893090328864, 8.282312116315289, 32.28599575258071, 39.871673353256725, 27.71531858751851, 47.432159531501036, 38.01829068891464, 22.509988200279977, 0.6347659290317567, 0.14682645038250955, 0.03229373164715306, 0.054453583284010815, 0.04537949781684626, 0.05263076516829672, 0.018775840177230777, 0.04794663929891202, 0.013521689350806899, 0.06741697839911907, 0.013362936780697877, 0.022646395992788098, 0.04242021507853943, 0.0847596844898597, 0.020005321280369838, 0.04588437274158482, 0.11295367362758807, 0.004866307802242978, 0.008023023847565657, 0.01827889234728871, 0.0294419348750624, 0.07941325645773642, 0.03248928325070489, 0.05050994268047714, 0.02678068140671859, 0.029365414182745644, 0.02094099617322847, 0.03414297979625483, 0.022211474471635396, 0.05989102256153861, 0.03679195479039223, 0.08541359415938778, 0.0023094249556907605, 0.01577015166291066, 0.02292282349850622, 0.05182443081491417, 0.0043559467303566635, 0.053825165190163164, 0.04272853099410573, 0.07878796783305946, 0.02798897251787205, 0.09167263975306865, 0.08693757286715893, 0.055339437563933676, 0.018205707967882196, 0.05269093754430933, 0.024235413650110848, 0.018096199529545925, 0.028989360772914467, 0.04960198676393879, 0.03355318019467016, 0.030010437232352076, 0.026407839820509958, 0.054641477838759465, 0.07517691281053328, 0.05884444686554133, 0.020244239206095378, 0.014436187658218608, 0.09485140668168184, 0.007208562737721349, 0.01282921577278044, 0.13398522330868629, 0.03392097517667759, 1.9784736681369044, 30.36785867906386, 46.53630587362474, 33.61602244838592, 29.321323248647875, 42.107891113527366, 56.545245339793546, 25.443330772461433, 2.2826804412949473, 0.10189166277526848, 0.01575620982029866, 0.047971073673256946, 1.3428410791581677, 3.4913127220446065, 4.406408302245602, 3.845981032617631, 1.0099183888204637, 0.686328549298548, 8.903151731337271, 29.30448647468321, 55.76864350226618, 64.56917916574787, 61.15450097668556, 62.651755963602376, 62.41944182303644, 60.49402875284995, 56.434528596939586, 58.534636189860684, 61.902975497707246, 64.0602045674478, 59.49804482921478, 57.03307051812449, 55.214122341525176, 54.102597159724084, 54.39833602597637, 53.52005458647206, 53.8269918195663, 53.60508372706752, 55.46317323561638, 55.28696075562508, 56.15624035558393, 55.902949379336455, 55.48227125598539, 52.93530371881301, 49.92209972873811, 47.61320044917446, 48.5540593824079, 46.19558918860651, 54.49524602582378, 61.77059158202141, 60.346080872320364, 61.24594319251276, 60.28920258245161, 55.820191291070756, 58.08812141418458, 45.944451593583636, 58.17333882854831, 61.67564668963033, 58.45074061424502, 59.83229744818903, 58.436867190945534, 56.96690013331752, 53.83391872529061, 50.00982353764196, 46.34212501587407, 42.3947811126709, 41.380381661076704, 46.01268906747141, 54.05305370207756, 55.716899594952984, 58.30915089576476, 56.31764588817474, 55.09230921345373, 55.75074180479973, 59.037370297216604, 57.19612344618767, 57.8099508439341, 56.59360424164803, 56.811433069167606, 53.312643574130156, 50.977272218273534, 43.71780441653344, 43.43192638889436, 49.04154723690402, 55.46754275598834, 56.18098658900107, 53.45887737889444, 54.05962367211619, 53.25674979917465, 54.3017319710024, 52.866371985404726, 55.13506304833197, 50.33035178338328, 34.79018395946872, 12.444950995906709, 3.6922197091963986, 1.361169702103061, 1.3345609557244087, 3.0112982084674225, 3.083087878842508, 5.0631341722703755, 2.216419596825877, 1.4889389492811695, 0.06879438150433764, 0.04856461561435173, 0.28901886555456346, 6.6056175193478985, 31.33533285510156, 48.98659875316005, 31.02670115809287, 50.39269393490207, 41.587525952246885, 30.2522821195664, 2.3282186686992645, 0.06195983150973917, 0.13416307828118726, 0.015922809045972125, 0.05902649999986734, 0.020971655011958173, 0.03940093999488219, 0.05185484833594772, 0.07580740317221611, 0.012149521498940887, 0.048663214960646246, 0.020202964303954955, 0.04987391350310176, 0.0714813812725967, 0.028704485232611338, 0.05561802926803789, 0.018297282287911065, 0.04487060476094485, 0.03507468060800626, 0.012874473374517215, 0.042569353245198734, 0.059130304913607344, 0.010840626763961008, 0.06064837325304266, 0.028926985894119548, 0.05784423481072149, 0.014650385841847429, 0.01872454676026058, 0.11958137605219119, 0.11975317893009033, 0.19490344720261712, 0.1671856200142253, 0.09800824817390212, 0.12654653254656062, 0.09024866616293307, 0.15706238096519826, 0.11965443785752981, 0.14518830925226212, 0.15836480704526748, 0.18861138321939977, 0.2834478128821619, 0.16895082448759388, 0.19878651706441758, 0.1538724368137698, 0.1377331092953682, 0.16082401056924175, 0.12047899361219137, 0.11731948613399461, 0.10761548870153005, 0.10285728596030705, 0.15249268181862372, 0.09717016330649776, 0.08668651819349298, 0.15375720186819955, 0.15961205947303003, 0.20859339244423375, 0.23919664383415254, 0.08891440146873075, 0.24334599053667438, 0.13641416635965148, 0.16476681996737758, 0.27392307236309976, 0.17151830687878594, 1.636410629557025, 31.603938725686845, 55.9031690320661, 43.870702328220496, 39.94084435124552, 42.7436916289791, 55.43637560259912, 34.60524812821419, 6.229233251463983, 0.6012169163553946, 0.2067077436274098, 4.735056344539889, 7.890846825415089, 10.701920293992567, 10.97825421440986, 5.303099876449955, 2.2282859923378115, 0.5754310096944533, 7.410932577425434, 28.52661378922001, 57.78274528441891, 69.46629754958614, 61.236290239518695, 65.4907008140318, 64.71205149927448, 62.05372395053987, 57.240736484527595, 59.947242506088756, 63.22589681994531, 67.28357699609572, 60.529122198781664, 60.98005748564198, 57.23391940516811, 58.681697614731334, 57.34391443191036, 56.526237533938506, 58.28531072985742, 54.861199240530695, 58.74241198262861, 59.709617476309504, 58.10029252882927, 58.33469729269705, 59.58634130416378, 55.484487395132746, 53.01679488151304, 49.49749139047439, 51.38983495773808, 49.650691324664706, 57.63072598365046, 65.04225230986073, 62.25622415542603, 62.79080398621098, 61.50188176862655, 56.210827981272054, 57.44517826264905, 50.48266918428483, 57.44453891631096, 65.79465704579508, 61.78590843754431, 62.747297056259654, 62.26570060176235, 60.3385813005509, 55.147520495999245, 53.72047201279671, 47.9739486786627, 45.55281862135857, 43.94338384751351, 48.65136946401289, 55.336355163205056, 57.97845586653679, 59.12421157283168, 56.853033727215184, 56.206454538529925, 55.16395130465108, 60.2690141431747, 57.255178651502064, 59.30159291913433, 58.98646577712029, 58.31421859802739, 56.125606644538145, 52.97025988178869, 44.72867373497256, 45.29670353858702, 50.32553511281168, 57.68798082105575, 59.37370961712253, 54.920352505099395, 53.76206874847413, 53.43086381112376, 55.64862681973366, 53.36585052551762, 54.55336770703716, 48.61988067626954, 35.592422408442346, 12.411720675806846, 2.8423175984813325, 1.5159467968248552, 1.1919123198716872, 4.928453218552375, 4.6593349883633275, 7.0692789362322905, 14.06593224694652, 11.76109262051121, 0.919591045427707, 0.19651359548011135, 0.5591844911536863, 11.383333071585625, 40.86769257822345, 49.67923441240865, 38.13107452084942, 53.68028733038134, 48.52257451703472, 34.647421452306936, 2.0030536911179944, 0.3525226208711824, 0.2399827572967737, 0.16402965952311793, 0.2092524885290092, 0.15273499542907362, 0.06803963168133652, 0.18002361419700807, 0.20442092520815713, 0.1184480332378899, 0.14576972402151556, 0.1385067508465821, 0.08815135491350967, 0.17267338360749906, 0.24952534766447163, 0.17548131035460582, 0.22925613207682488, 0.12588679294792876, 0.14548919794540252, 0.10211107035678241, 0.11312502451361188, 0.1126688804417368, 0.0831152844212709, 0.25612560881962704, 0.11344875028777508, 0.26848259171651256, 0.09096177910724956, 0.09435742552722655], [0.012323993235646237, 0.03230181770519384, 0.01916001411905933, 0.08107505438308563, 0.02943021372982091, 0.015777027302031076, 0.04890307708973846, 0.039355495659213875, 0.07499310533486067, 0.029259383783585606, 0.11580076278938402, 0.05192562336883238, 0.03832022742097897, 0.03427754697059432, 0.06749382467880365, 0.008986812730830525, 0.013169158670690753, 0.007510042754978303, 0.030911280022513483, 0.04325890515540396, 0.02815847904721816, 0.017159632144255504, 0.028221206326458245, 0.053932141707909685, 0.07263107240320214, 0.0547790059429263, 0.04671639402306849, 0.03296385173715892, 0.05641391801257288, 0.0349297559249305, 0.018885392665622697, 0.04520741148641513, 0.03471867188871388, 0.04577632753118392, 0.10990823664131666, 0.04917521833352024, 0.9263632013913125, 19.98266193174547, 41.076272456876694, 37.63175679791359, 29.020393125472534, 32.74282243943984, 45.65916584384057, 28.650356723416238, 7.008683710328995, 0.43958382500756177, 0.03432986311494343, 1.5251429162679182, 5.374451712254555, 2.703555908895308, 1.8422604159962748, 1.5453937457453821, 0.6728804580146267, 0.9752340951273519, 8.005867388940628, 30.03394534510951, 52.65334806134624, 63.813099168962054, 60.17773274452456, 63.30152796160791, 60.28734337898993, 58.56752134138539, 54.07334412297895, 61.13248471290835, 61.07013863901938, 60.09991684267598, 56.07473350340321, 55.121456346204205, 54.04558550926947, 54.26813687047651, 52.385156000814135, 52.41912764887656, 51.02287761626705, 47.477713938682314, 50.69093135095412, 51.29809071940761, 49.025477286308046, 49.77708970346759, 49.36084778078141, 47.22429352421915, 44.99286890029908, 43.40051604855446, 43.02357627499489, 44.12642517397481, 55.2985199805229, 57.12155918921194, 60.303844790304865, 57.89631751275832, 62.85988084731564, 41.53564083960749, 37.68037457619944, 57.83828996842908, 59.60696512652982, 58.28417716487762, 56.013662199820246, 57.63682134689824, 53.400575268653135, 50.6222467268667, 47.28204258026616, 43.000548039713216, 43.123886969781694, 42.20504430032546, 45.37291519103512, 56.051567985165505, 57.908994613155244, 58.292367073797415, 59.327053023922836, 56.802395928290586, 57.37113568090624, 58.4828491364756, 57.24270943672427, 57.56717966448877, 54.332597101888354, 53.57862734025525, 50.3810013494184, 47.3469695737285, 43.34204527639574, 43.3740714288527, 48.70461956147225, 52.795847769706484, 53.427533718847464, 53.02170176659861, 54.09857673029746, 54.85679049645701, 55.18663829372775, 54.21041527102071, 46.38326675661149, 27.48009208709963, 9.0774893183862, 0.7010746999613701, 0.9207692886552504, 1.943960365268492, 1.5421639190566157, 2.4857251201906516, 1.6292344081786372, 3.1832426594149683, 1.9980977764052732, 0.19811384590162387, 0.10049765854473076, 0.5818892534702056, 9.023025247358508, 34.33348671082528, 37.49895318861931, 26.76159231893478, 26.4210246839831, 34.14751929621543, 23.74301468172381, 3.392005418577502, 0.038206237368285656, 0.026325810956017628, 0.09926256393232655, 0.024521225732901407, 0.046764933353950905, 0.02562693767099371, 0.06415356641575214, 0.09553921574185933, 0.09537845985182831, 0.09255014750505648, 0.04024926745783418, 0.025600017341334495, 0.035938034885593, 0.04348732959178667, 0.012161826786224642, 0.02313759433285844, 0.09196946051933112, 0.03635778212018552, 0.04465444922266949, 0.034880779923931245, 0.020710514790769068, 0.004709429753523681, 0.03211190450876471, 0.0482424947943899, 0.08395061137214785, 0.02629814369063224, 0.03038372314955679, 0.01006354930840673, 0.038998035203304984, 0.07480795720532056, 0.005046889568949419, 0.047264280954315785, 0.034587038831124385, 0.09442984381870878, 0.029976323337083863, 0.05404224386438728, 0.07180420306300925, 0.05444499160794001, 0.05489750825349362, 0.0006107296623315873, 0.02663728506905177, 0.029658632420544184, 0.06463414869241177, 0.07872121093133766, 0.07796722719626081, 0.03355050654781442, 0.07804889982986836, 0.015871558721447666, 0.04397261181786176, 0.05180243643060808, 0.08855216445461397, 0.034606535768797325, 0.024345077221251787, 0.020238581646774566, 0.027672354124426365, 0.019758836321172216, 0.03826866204279565, 0.07689155548089936, 0.01773649252079908, 0.04785893755334039, 0.011128138604333565, 0.04119174712668023, 0.045652627314050356, 0.07920958432218722, 2.2060316897207692, 29.56002300785434, 44.72427675800939, 36.84541571524836, 26.89467049414112, 38.59503599905199, 60.35942869801676, 31.05351055822065, 5.315708825665136, 0.30992696782754314, 0.05648290806059396, 0.12624798042158927, 1.3978721778238974, 3.0760504113089655, 5.317475853427764, 2.3932473986379565, 1.333259586845675, 1.2825245866852424, 10.862795326017565, 34.7134506317877, 57.952007324464866, 65.65385572371945, 61.455613490073915, 63.401685683958, 61.34445351939048, 59.47384772762176, 57.149690428087794, 63.44987984626525, 62.072719989284394, 61.66600942611695, 57.35028828344038, 55.67609517805038, 55.093285883626635, 56.78443147290138, 52.94760819404356, 54.00261986640192, 51.972471667874245, 50.73421470580563, 52.07872083110195, 53.592371325339045, 52.84787016530191, 51.92243399158601, 50.806386316976244, 49.20470999133203, 47.9196983768094, 45.739594044223914, 47.13178834607525, 47.23691571143366, 59.19119388826432, 59.10630595299506, 63.39015391565139, 60.66595408224291, 62.54564800570088, 43.36710137705649, 41.53893563055223, 58.664545089967795, 59.96872140515236, 60.656591384641594, 57.810492131017874, 59.1524604828127, 54.929570075004335, 52.63088464736939, 48.88332274652297, 45.85057750824959, 46.24900794798329, 43.11276705034318, 47.65366361987206, 57.2621016348562, 58.11145167196951, 59.69445359322333, 59.06190472264444, 57.150706321962424, 58.560927837125725, 57.67613134076519, 57.693217185235795, 58.2178577300041, 53.58560915916197, 54.69492604655605, 51.91618173353134, 48.81994508927869, 46.28400725703086, 43.0416387896384, 49.078484196816724, 54.151301230153734, 55.512869665699625, 54.672360650954715, 52.625714963482274, 54.795927078493186, 56.65055705655006, 55.929370464817175, 48.8993573957874, 32.02765276355128, 13.13263270162767, 1.674466690709514, 1.7254149697480665, 2.5200760124191164, 3.353884393169034, 3.3946157559271786, 3.8205143088294617, 4.969508667146006, 1.0704057495440207, 0.13433131118935926, 0.10721266434918489, 0.5761215919929167, 7.633646716994624, 34.59417919958792, 47.54222908327657, 31.627992660768573, 27.710039077266572, 40.694504245635, 34.17884334441155, 7.512019411210091, 0.0719408042007877, 0.009824750126309453, 0.03372160845526284, 0.027267706482821417, 0.030380852235060547, 0.02337934869912363, 0.038785227469258735, 0.10601674747322837, 0.047850774886507186, 0.027186171745040247, 0.03203195365776699, 0.06931284682885294, 0.037840683193456744, 0.01638739827960249, 0.04795015947292409, 0.03855402213371089, 0.04163702807178901, 0.033808145747189565, 0.07620747726891311, 0.06264315895555962, 0.013729509852466085, 0.044934653541854316, 0.03005719157837091, 0.06447330087182984, 0.08512172232111616, 0.030394143860546813, 0.01589622579499959, 0.06823673844337463, 0.12143602129071952, 0.19400792106265025, 0.11323645966307772, 0.24004203718035455, 0.2020879423305873, 0.1841980119746539, 0.17365828156471255, 0.20366828978782703, 0.13751722571830596, 0.21953515047507904, 0.20641713583421326, 0.06939340863497027, 0.11671901109718508, 0.12666872357048337, 0.1944011539941834, 0.13496351758799247, 0.21623945554658291, 0.0947833704131265, 0.19771387139635702, 0.06299471670401192, 0.14393013241069932, 0.19443835522378647, 0.18412034598089036, 0.30351104274872814, 0.16312507822388606, 0.14461449407521756, 0.08072864474548448, 0.11996489498884448, 0.1265245151796168, 0.17937089196376263, 0.12538624641996238, 0.145934279707651, 0.2398745090730729, 0.27742774075558113, 0.18905997366434146, 0.2685960033728231, 1.7854910944738698, 29.807614780241448, 56.29418619217412, 49.60609397580547, 39.79588531678723, 41.24746430304743, 58.59452686002178, 37.32518826761554, 11.434831830763049, 0.796133341087449, 0.15961170707258487, 4.640132534888483, 14.19120196373232, 8.85285125624749, 6.8291416283576725, 4.209299395161291, 3.7892490961859306, 1.8787271817845685, 9.282959738085347, 32.21248072962607, 56.416968145678126, 68.44902300065564, 62.99882688829976, 66.12996870471586, 61.817667868829545, 61.36267292884089, 56.40209844035488, 65.11686755764869, 64.8849456541, 65.25919468172135, 59.459593834415564, 62.01937967731107, 57.68146968656971, 60.99251493330925, 56.395312739956765, 57.145787669766335, 54.796107507521114, 52.388490015460604, 53.29089010915449, 56.99159145355225, 53.058434763262355, 53.67184246740034, 53.931872075603856, 52.97219361028364, 50.29841584544028, 49.30473435309626, 49.559323633870775, 48.33834471241121, 60.37459258110293, 60.38217060027584, 65.22276762993106, 63.98929988184283, 63.82473684126332, 46.95719580496512, 45.524244154653246, 57.67295029855544, 61.525392455439416, 62.384705312790416, 59.36778683816234, 60.785241203923384, 57.18426612115676, 54.836649125622166, 51.14463975352626, 48.784530008992846, 48.38675068270776, 45.898422579611506, 51.462865567976436, 60.87376909871256, 61.771882041808105, 61.763378343274525, 60.95363247779108, 57.25459814071656, 60.873949527740486, 59.29973371567265, 61.67219892624886, 62.11277915585426, 56.30157985994893, 57.692083620256, 55.347086767996515, 51.850348672559186, 49.65071485888574, 47.36178044349917, 50.96748590469361, 57.09986455978886, 58.39412512317781, 56.59072914431172, 54.243935846513324, 56.77307621125252, 56.209898379541215, 56.69225185148178, 48.699493023657034, 30.10572668044798, 11.516803483809195, 1.3028228523269778, 2.27217486308467, 4.602889139806071, 4.310926535437185, 5.603976557331701, 5.1644225178226355, 10.92104938722426, 6.842432579686565, 0.990093136506696, 0.26340385778777065, 1.0124388180913464, 12.516420502816478, 43.12656987097956, 48.37588963970062, 36.06655459250174, 38.546241714108376, 45.58515071868897, 36.737326960409845, 7.0531344606030375, 0.19868049049569717, 0.11857229269920819, 0.15859431166562343, 0.10898634941587526, 0.2253871735545897, 0.15547138488581105, 0.132194691968541, 0.20423127248162226, 0.19504269134373436, 0.19967315658446283, 0.10223951265816728, 0.1518727941138129, 0.1308734814125684, 0.1754263665286764, 0.0544293825664828, 0.17292210171299596, 0.2526299649428937, 0.13042521272455493, 0.1963424361160686, 0.14047429446251164, 0.1573723707828791, 0.15040803400258865, 0.10343146885955527, 0.14312667471747245, 0.16086329555799886, 0.09670293394235835, 0.0841692528657375, 0.12784211746146604], [0.026423960225656632, 0.04921887002344574, 0.03515498960510858, 0.01707369048568991, 0.07220325826276695, 0.06356097059324384, 0.04394430103861997, 0.028298502682798335, 0.05330604486047261, 0.032959772318962126, 0.036948979832232, 0.018476062311580586, 0.08998535408247864, 0.08591123721412114, 0.06372055053831109, 0.026724940849347945, 0.04035429428181341, 0.018864987913759488, 0.049737569004777944, 0.0408045164940338, 0.01224253414904759, 0.019663335800531413, 0.013039285700107294, 0.03526952741066775, 0.04100212504366233, 0.03314030476875844, 0.07649642265131397, 0.07506546233930896, 0.04729992702543255, 0.05003981750398394, 0.08044840212190345, 0.10579206154591615, 0.020130689653958526, 0.0490724093340818, 0.065309455197665, 0.08374750614166261, 0.014213300122308635, 0.5736759329034437, 20.79920722592262, 42.820479869842536, 43.58826814159271, 29.05705748065826, 22.737756313816195, 47.02859863158196, 30.77919371666447, 7.069246576678369, 0.30175682397619374, 0.02568126288092425, 0.11132350747263241, 2.3724960992413187, 7.607471760242217, 1.3347817116206693, 0.9129790937708271, 0.2843974554731, 0.48020006007244515, 10.721292880273635, 31.993202586327833, 50.845378598859234, 59.251645457360056, 63.040925687359234, 61.26767704563757, 59.712645546082534, 58.216810457168094, 58.492647217166045, 59.80246782302857, 61.9677887424346, 61.36391239781534, 58.241627293248335, 56.142292407251176, 55.10573548655356, 54.428973659392334, 54.72561859315442, 50.17322555665047, 48.07169414335682, 48.23844194412232, 46.32146196980631, 47.78899715792748, 48.246957409766416, 48.09227089728079, 48.92135012534357, 46.97923168059319, 44.592139951644405, 43.7469554716541, 43.66937883438603, 46.3478869776572, 53.41901433083319, 58.764024242278076, 61.82583424352831, 61.65878049788937, 63.82720008973153, 39.54578322748984, 58.06183368928971, 61.934687860550426, 58.411920916649606, 57.449896873966345, 57.061080163525, 53.41776701711839, 48.41994962384624, 45.99495603192238, 43.669661245038434, 41.425575210202126, 41.795850876838934, 48.85412462296025, 57.78744820625552, 57.54231183759628, 56.33437871932984, 57.43796502390216, 58.127615759449625, 58.98432024063603, 58.077644763454316, 54.84918894306306, 53.52899759046493, 53.597097781396684, 51.43850764920635, 51.62976241880848, 49.053094694691325, 49.84263643141716, 46.597000629671165, 46.77797094468148, 51.90288097627702, 52.758283230566214, 55.32720035122287, 56.859019264098144, 53.23124654831425, 53.30637562659479, 38.51667488774946, 21.800733458611276, 7.374674187552545, 1.2834083457146923, 0.25253235001958185, 1.9672598569623887, 0.8632738996417293, 2.545929825113666, 2.2648427274919327, 3.3683226377733293, 5.564469954659862, 0.2893075274844324, 0.046873756143594944, 0.49357941794779997, 8.182583893499068, 35.002188067282404, 33.657321083930235, 21.18363284295605, 28.48294015853636, 30.991201746848326, 19.34707714665321, 4.244533556122934, 0.0684219325381902, 0.019384579387523474, 0.012468373038685851, 0.01400173345069972, 0.03426832327198598, 0.03668142745511667, 0.026547844303892027, 0.045776580340198936, 0.03734118620594663, 0.024153712288206144, 0.057830747832814534, 0.03912717081426133, 0.027873028940971822, 0.030078613311953606, 0.06821909543847846, 0.0694737023103141, 0.04476788769205732, 0.05450874927543825, 0.07271489008299767, 0.043269860212721174, 0.08569971267734805, 0.056756209927581014, 0.04002260502367731, 0.08132642315280053, 0.03247763871425583, 0.03683272598972244, 0.025786697646723162, 0.03495813948252509, 0.05979917628029662, 0.10210120314431768, 0.06449167166025409, 0.0501860675191687, 0.023697771229630998, 0.05399167440050552, 0.02861472462574321, 0.06896345710922634, 0.03728774391234883, 0.043715731045531656, 0.047303267168782415, 0.039359490807739, 0.07675035781557522, 0.02920703508049971, 0.02397268762691848, 0.030318640149949543, 0.016218606127245773, 0.0908544195455409, 0.032164534749162775, 0.06530056857774336, 0.035719086956833644, 0.03516730063805177, 0.024293429488616607, 0.050608982527328115, 0.04205351177182409, 0.021420896631635485, 0.016925259035140756, 0.04654369865273757, 0.07713609840720892, 0.06120923388328764, 0.005577572080637179, 0.03505214996215317, 0.12133821484542663, 0.017149718966515317, 0.01917974088310955, 0.03742393519308779, 0.012257890381489792, 0.05725095333952097, 1.8013526691544441, 28.901694359317904, 49.135303651132894, 42.70040435175742, 25.578460347267892, 33.18300847084292, 62.83747626889137, 34.58512636923021, 6.0005585801216865, 0.13344056543803987, 0.022364259216814272, 0.33253550950077276, 1.1789818588764438, 4.364096714604286, 3.237941337208594, 2.587050973407684, 0.3483779626267572, 0.9854995507386424, 12.501096783145783, 36.984659856365575, 54.26725825955791, 61.42284208728422, 62.977116569395996, 62.28667351507372, 60.20970790616928, 59.607957486183416, 59.41844817130797, 62.791298204852694, 61.95896340954689, 63.95274731420702, 59.24270245336718, 58.42610812956288, 56.807906858382694, 54.68871693457327, 55.50740972641976, 52.87843719605477, 49.64964797419887, 49.55396959858556, 49.035514631579005, 51.10598871784826, 50.6720059148727, 50.48914501743932, 49.650671712813846, 48.67418196893508, 46.35654757099767, 44.81578173175935, 45.153548794408, 48.62396386361892, 54.92283536541847, 60.15077037196006, 63.10788446857084, 64.3306912145307, 61.21416022700649, 41.11658265513759, 57.139264768169774, 62.8814931069651, 60.858052161432084, 58.83433664998701, 59.54313247434555, 55.389197334166504, 49.9783072933074, 48.56670118147328, 45.453735628435695, 44.71817355002127, 44.451672031033425, 49.92734786002867, 59.21038212314729, 59.949207613545084, 57.53145079458914, 58.82136144945699, 57.15879817162791, 59.81273266576952, 58.97718544929259, 57.871834078142726, 55.325709850557395, 55.37768517771075, 53.40139112164898, 54.43056614168229, 51.69537190468081, 50.85670248154671, 48.59442057148103, 48.27138200882943, 53.84275582528884, 54.722174752143125, 55.764281826634566, 56.29719465009628, 54.22945053346696, 53.97338644150765, 41.975358147774976, 27.071273249964563, 11.034024434704936, 3.023377882857477, 0.7770754637256746, 3.297938156512476, 2.6159804146136008, 3.71182567650272, 6.102601001339575, 4.055048265764791, 0.7707106213896506, 0.0884124453389837, 0.04045611885826915, 0.24986014340914067, 6.529003333660865, 38.260865749851355, 46.14845406624579, 24.166042304808094, 28.20316730007049, 35.9160061805479, 28.461979012335505, 7.401773352776805, 0.07731082008009957, 0.05476573346963814, 0.1156238271223922, 0.06913314558445446, 0.0499443821008167, 0.06694689918790134, 0.048606015005779844, 0.044502239043433825, 0.05176821145259085, 0.01665196099859332, 0.09311760415232952, 0.047576484766097805, 0.05104998870181942, 0.04280954862253801, 0.1071580269584252, 0.0462870400459055, 0.02638973333241959, 0.03209591816900478, 0.0481474424351848, 0.028210850732941783, 0.0643720853352739, 0.049603764087923115, 0.0435402930804318, 0.09896469362560781, 0.04552491662663318, 0.04310694778518331, 0.08241117301006472, 0.02777239754645815, 0.0053092435606935575, 0.1608123660327927, 0.14870043934112595, 0.22321090162281068, 0.09928150928669399, 0.20257575647725215, 0.1871228897042813, 0.13686108673291822, 0.14681284466097433, 0.12231635590714794, 0.19052344674785293, 0.10356680595225866, 0.2025685858942809, 0.22395365450891758, 0.1581760276589663, 0.20375458193161797, 0.1888112095935691, 0.13017755182039353, 0.13800203680030762, 0.16587403152258168, 0.13979911053132626, 0.06029303103024441, 0.09798818433116521, 0.13406578511480363, 0.15050111368538874, 0.13162401775198598, 0.05594423333663614, 0.12878124932608298, 0.2582404558216372, 0.16828927692146073, 0.23932965201956613, 0.17877977852138782, 0.14452244095023603, 0.07945722990459012, 0.12201794933888221, 0.21418612540489246, 0.284174922252855, 0.12023908551782371, 1.1330889021196673, 28.14686755980215, 59.07367183316139, 55.50882962442214, 40.7684919141954, 32.14922270467205, 59.59852026354883, 41.119787231568374, 10.239671910962752, 0.6330995958658957, 0.17094669803496332, 1.6656494477102834, 8.064241572733849, 15.92188504434401, 4.916777303141933, 2.071544157881891, 1.1267615061613823, 0.7157195431570853, 12.570299160095955, 37.45550117185039, 54.91100549697877, 62.19740429232198, 64.86700865530199, 62.28470448524722, 61.84276319319203, 61.662957822122884, 62.02287843150478, 62.036826379837535, 65.33581426066738, 68.69216288289716, 64.92963713984336, 63.34474071379631, 59.6575637017527, 58.62794153151974, 60.30665320734824, 54.88975017301498, 50.90342575503934, 51.729778935832364, 51.17141385232249, 52.75330182044737, 53.398504257202156, 53.54854668340376, 53.336181717534224, 52.12383593282392, 48.35992559309929, 47.17238095498855, 47.421675036030436, 49.52401445757959, 57.03929924195813, 62.110637541740175, 65.73188343355733, 67.5228572660877, 66.72398028835174, 44.78249649847708, 58.22475325676703, 64.70014710580149, 64.30876516526746, 61.82126075990739, 62.595081636982584, 58.33259882465486, 51.91089830090923, 50.406998818920506, 47.58239023147091, 46.3031288116209, 46.7308162104699, 51.95031419877083, 62.27895821294477, 62.155905615898874, 58.099570812717566, 58.09950805479481, 57.805408739274554, 59.92947416920816, 61.62929604130407, 57.950512901429214, 56.76971081764468, 57.426543081960375, 55.92608351861277, 56.2047012390629, 55.28688623059181, 54.99317522971861, 52.90021811762164, 49.42811250686646, 55.257378239785474, 57.11070991331532, 58.45325485352547, 57.31648137492519, 54.77329892496909, 54.57836497214533, 39.853881482155096, 24.39577160343047, 8.869229112901996, 2.335634154658164, 0.7205799113838904, 3.7450297657520544, 3.679468328914335, 5.586137617788007, 9.90146162048463, 9.662953076824065, 10.575616052073817, 1.241428075778869, 0.2514559811642093, 0.8071483371238556, 10.640531278425648, 43.46516847610474, 44.68580222898915, 29.658194049712154, 38.941310682604396, 45.17312534393803, 30.28629887488581, 7.044502794742585, 0.15294151741170114, 0.14173257855638383, 0.29018531102807293, 0.191075413097297, 0.13489389551743386, 0.2040804757346069, 0.13122149983481055, 0.11753166184550333, 0.08616033836358017, 0.12072456309631949, 0.17836120340131945, 0.11400304554450898, 0.32419186205633227, 0.21287838267462872, 0.1596803485506004, 0.1468906025852888, 0.12752728596810373, 0.11090074951249747, 0.18001460500301855, 0.13085327201312588, 0.16732610521777985, 0.1741998597619034, 0.10154747479264775, 0.16785737187150987, 0.1572009509489421, 0.1478081767357165, 0.19291678203209756, 0.15777809094757805, 0.13677595904277218], [0.03916644048125994, 0.038212201362776185, 0.0302162601597487, 0.011803224859308573, 0.01767489905168693, 0.02446196117107907, 0.05159265091342311, 0.05983114129893723, 0.08662061164936713, 0.012850813706585718, 0.04421437384500619, 0.009753196556571751, 0.03691629086050295, 0.023451121561529658, 0.0456545501947403, 0.010925420248250087, 0.06377672776579857, 0.03207154316647399, 0.048174347443085526, 0.018482076101786187, 0.017485347831802025, 0.10723199274751449, 0.013230265673970985, 0.035988612010354, 0.02016776639427389, 0.02528397925949145, 0.05323470292252399, 0.07307292127441015, 0.024550124484625076, 0.04241469924548461, 0.09192835990219347, 0.056075276506523934, 0.04886038300971832, 0.02810669533397642, 0.02076671117045466, 0.03909815906456882, 0.06349104591795514, 0.03136371239839542, 1.0415980243875136, 14.42667067050934, 37.54465272349697, 37.29045960210985, 25.852279047812186, 29.18449724874189, 48.60720749824278, 37.06609218351303, 6.983176537098424, 0.5793839008096726, 0.18196817517520922, 0.471184185796207, 1.4945777241260776, 2.620454122943263, 5.220386895441241, 0.27264085568247304, 0.0950338811643662, 0.21041585432906307, 7.0606487412606525, 25.799234874786872, 48.4789106922765, 56.35046435940651, 63.439901336546875, 61.3581935821041, 57.707267115193034, 57.205278258169855, 59.606819998833444, 63.47145288221298, 61.86578750610352, 61.633214489106216, 59.74737028921805, 59.35748277171966, 57.09359268988333, 55.69082367804743, 52.10192949541154, 46.66993318065521, 48.05684404988443, 46.61483956921486, 50.38648874528947, 50.04980425680838, 47.67100834077405, 49.99725626360986, 46.291549974872225, 45.377484752285866, 44.768332819784845, 46.63697742646741, 47.590901774744836, 47.26042639824652, 54.43860700053554, 60.67182979276104, 59.53563290257608, 58.50412014992007, 39.66334842866467, 58.291100148231756, 60.64562051526962, 59.022551582705596, 57.485461004318736, 56.3054669287897, 50.706832639632694, 45.15070507603307, 45.07769800001576, 45.359457538973906, 46.90438501296505, 46.07788670447565, 48.97851082586473, 55.52828458047683, 57.45742390232702, 58.63926933657739, 60.06360353962068, 60.38306490067513, 57.30015254789784, 56.43060622676727, 54.613136783722915, 53.842677377885394, 53.16831996363979, 53.186747258709325, 51.84652043927101, 51.24956707800589, 51.512644367833296, 52.60560104923864, 50.63772832193683, 53.72789313716274, 53.84867860424904, 56.39473615154144, 57.408037339487386, 51.82740672942131, 36.47359855713383, 16.82416158337747, 5.264112007233405, 1.0114250692629045, 0.6541089136754313, 1.2198775934596215, 2.7992019249546916, 4.493642795470453, 3.9569926886789264, 3.210599965626194, 3.0540554754195677, 0.2732125717786051, 0.11085064736224952, 0.8606888125500373, 11.51951188041318, 38.19262827596357, 32.79074399702011, 20.94222664833069, 31.887710440543394, 33.85584792783184, 14.542965023748337, 1.7832223710513886, 0.051494921076922655, 0.06696353861761671, 0.07685517396537528, 0.052005269699880195, 0.04080584948702205, 0.011998807106377378, 0.036928609554325385, 0.034560478562789584, 0.05240596432779586, 0.029666967457160357, 0.07009693015847476, 0.02633762403181003, 0.009807893319145567, 0.021015620797932632, 0.040421717680029334, 0.050863316057309996, 0.04493986293973942, 0.05328527621684536, 0.05166188994001958, 0.028308408199659282, 0.03239214713234575, 0.041712246414634495, 0.041963301088300445, 0.035991297148528605, 0.04815239519361527, 0.06369841825817862, 0.012938586315290343, 0.039487959922201214, 0.10370316960278059, 0.060166523100868355, 0.06754077054680356, 0.017952695939569704, 0.05078678004323475, 0.04449300768394624, 0.03126427801626344, 0.042209713269145265, 0.02381303681871824, 0.014498326964976807, 0.0206634865683173, 0.02158265609684731, 0.07429382027757746, 0.03463501891782207, 0.041056693486508825, 0.027211887401438532, 0.030042321811760628, 0.047594077975278905, 0.040886028249177246, 0.014709177344376522, 0.041836689737054615, 0.04275730142610208, 0.06680194769174823, 0.026501321699470285, 0.012547506090824403, 0.04202576023676703, 0.03974108686370235, 0.026924698275604078, 0.04885783576737008, 0.055758947311269666, 0.058901259946005965, 0.035623172748713725, 0.03097271835882097, 0.01127809169702232, 0.021230479732396144, 0.07205323526455511, 0.08442075953127877, 0.03421529083542767, 0.03157547059198541, 0.05702704116101227, 2.9815700746351674, 24.92049059560222, 48.326456008418916, 37.25287937348889, 17.77040789204259, 36.2915535126963, 64.10579035359045, 37.724312966869725, 5.656728513779179, 0.41590714226326636, 0.2640043787898556, 0.5473818341570517, 0.9051265699728843, 1.9546957698560532, 6.0376607698778955, 0.9560350737264081, 0.5323752135999742, 0.7260861223743809, 9.52526121370254, 28.4896219161249, 52.13655617929275, 59.30201653511294, 62.84926691362935, 61.27163863951161, 59.30989657678912, 57.02479823943108, 61.89551907200968, 64.44723267709055, 64.238440990448, 63.42520029314103, 61.369933236029844, 58.47547115818147, 58.52150801689395, 58.0855679512024, 52.63611708917926, 48.577044471617675, 48.68307398211572, 49.94113891355453, 52.67485049463088, 51.923653848709606, 50.69948211792977, 50.58676496628792, 47.91091226762342, 47.32694587399883, 47.1327297149166, 46.99913770921769, 48.98766563784692, 51.376561657074966, 58.874011424279985, 62.99399452824747, 61.27916174550211, 61.65823921080559, 41.51884525052963, 56.53816153926235, 62.42182270173104, 61.26693179530483, 61.009569398818485, 59.28975128358411, 51.90155521515877, 47.442977428436286, 46.38952293703633, 47.02047932532526, 47.01181480961461, 46.09820065959808, 51.48841980964907, 58.672660473854314, 58.276140228394546, 60.59624964191068, 59.1433645063831, 59.509011776216575, 59.65916795115317, 57.84007856922766, 55.57515298166583, 55.31915164762928, 53.26059764431369, 53.571688667420425, 53.10606802663496, 52.91750008060087, 53.771682477766475, 52.3931380241148, 52.04346656799317, 55.45686214200912, 54.52778600877332, 57.134961928090746, 58.17931259832075, 53.714227599482385, 40.412113205079116, 20.958065179086503, 7.2151670821251415, 1.7836081116430222, 1.72302195622075, 2.2537826241985446, 5.242559563729071, 3.7956508946034218, 5.517782472795056, 5.610994658162517, 0.8968031778931619, 0.10458451545526905, 0.04361240876718395, 0.9387993211707762, 10.300082295171677, 44.205107919631466, 42.092401673716886, 23.223920368379165, 31.673362716551754, 37.74913372532014, 23.77888671813473, 5.188139129069544, 0.2110856143577445, 0.08408175030302617, 0.02507664330844437, 0.04555460253369905, 0.010015862250340082, 0.04239260143930874, 0.043238722569038796, 0.04495651003033404, 0.038422009862598874, 0.03454651661036957, 0.10455341228554327, 0.03635226245669108, 0.006455995786499473, 0.020172234602092255, 0.04113849252462387, 0.04090690031467427, 0.0485152489085111, 0.02565603177513807, 0.02316127219537814, 0.012635497992197353, 0.03784714514509805, 0.08370497294010655, 0.06373693715901145, 0.021673324517905716, 0.08052856556230015, 0.013877706688588426, 0.018618311432580796, 0.023225661885413914, 0.06183798139494273, 0.03095286327504343, 0.16921477242102548, 0.1024965581394011, 0.204981119341908, 0.14712447390681313, 0.08444070846082703, 0.1466310060312671, 0.22280066153935849, 0.18713176100244447, 0.19374570448792752, 0.08444866045348107, 0.15415774327853035, 0.14093348756432533, 0.14837537291309527, 0.08975876825711421, 0.13972233319955488, 0.12897010532117661, 0.1570781930199554, 0.18757192448021906, 0.16459969022581655, 0.13916714928082882, 0.16217940396839575, 0.21908766319674833, 0.12296153217433922, 0.11138735324024193, 0.22379652987564766, 0.11926394752076558, 0.11599020867217934, 0.11810555363134032, 0.15106403509215002, 0.14390443782171897, 0.18298503432062366, 0.09655533944286647, 0.12075772704256159, 0.19600633802192827, 0.17130302085030466, 0.18365801191858708, 0.1795780114949711, 0.11194547893659723, 2.4137461954547517, 25.02521395683289, 57.052968702008656, 49.36288741327102, 35.26246478480678, 36.898046078220496, 60.344417787367306, 47.52774769260038, 9.879901332239951, 0.9825754850622147, 0.7160823623980246, 1.751800018452829, 6.799001645657325, 11.171089699191432, 12.104856987153331, 0.7403387285528645, 0.5402881664133842, 0.3580180147001821, 8.02083025055547, 26.752078610081828, 54.84552152695195, 58.184435213765795, 67.54426556248819, 64.65291392418646, 60.03507221898725, 61.17999246043544, 63.49610890111616, 66.1029592637093, 67.81279102448495, 66.31054678270894, 63.60337395821849, 62.850988834135, 63.28166900142547, 59.23541076721684, 55.85562206083729, 50.09640201445549, 52.81526350205945, 51.38460251592821, 56.86057644505655, 53.96081524510538, 54.26585012866605, 55.01560334236392, 51.30461754337434, 49.54146508247622, 50.83560013001966, 51.703514745158536, 52.47111082077027, 53.004380579917665, 60.28222468591506, 65.14803471103792, 61.52602787940734, 60.433777224633005, 46.17359253668016, 56.959016169271166, 62.215486418816354, 64.36647107524257, 62.426211833953865, 60.73265398702314, 54.69623219582343, 49.45929927210654, 48.664658454156694, 48.98864230801983, 51.5769124031067, 48.68243463577763, 54.30852551614085, 61.14011764526368, 61.32300207691809, 60.93363231228244, 61.54231356036279, 61.44829826970255, 60.56838512420655, 59.57322097593739, 59.48443812708701, 57.13165929240566, 55.35358221300187, 56.966503973930116, 56.629160527260076, 55.52858268060992, 57.77094287257041, 55.09039901917981, 55.3197164689341, 57.92832797573459, 57.324388873192575, 60.94901584809827, 60.00528966226886, 52.61775255203248, 39.09613840041622, 19.059061427270215, 6.596064096496952, 1.5476974027772106, 2.089217867582075, 2.100697664483901, 8.331082867037866, 10.60745785313268, 11.0177005106403, 7.618834866631416, 7.9687588253328885, 1.8019842933262549, 0.2896182833900375, 1.3699075171063024, 14.91188649208315, 46.48407167004001, 41.20641669919414, 29.10208432905136, 42.23350109592561, 45.22275901609852, 24.421578837979226, 4.307092908890017, 0.22395316421264605, 0.13344931416213512, 0.13311646428079377, 0.12514579440316848, 0.21123173796842176, 0.07991227847073348, 0.14454232859275035, 0.176736407522713, 0.16021163052608892, 0.14555882001596113, 0.1747673317309349, 0.19908837102834256, 0.10567902527268856, 0.11319073953575666, 0.13516038686277407, 0.14731207351771095, 0.11498428926232362, 0.15230260008285124, 0.17074362344799504, 0.1689360083471383, 0.13132597890592393, 0.11069168411796132, 0.2159436996425352, 0.11248178644886903, 0.18069754174399763, 0.17891695422510948, 0.10917498324547084, 0.1530319617520417, 0.2329890946707418, 0.11494152623439029], [0.04643009930488564, 0.07322521189287787, 0.04035430960357189, 0.03739858917411297, 0.04455334476886257, 0.08847655157648748, 0.04574686378961609, 0.04716840505059208, 0.034158090880561265, 0.07870074872288012, 0.048791902410166885, 0.06688015760793802, 0.023123442773677172, 0.025468428333800648, 0.014620664503215062, 0.021203743263838754, 0.05078922003327359, 0.06502250164386726, 0.030954650175126813, 0.03537727001633856, 0.05587312505550443, 0.009158255547405252, 0.022999706167367198, 0.016456531969109373, 0.019028407874547185, 0.032166243125233925, 0.028574190913669528, 0.07586030154338769, 0.09746290082412382, 0.02170267717672452, 0.06558251191651629, 0.028244993356507153, 0.05285804047279301, 0.04536890282085346, 0.02982040146185506, 0.017852911072212364, 0.03283791837372607, 0.010138941936254984, 0.0383652618996078, 0.2989013078472307, 13.404120533697068, 36.5805027561803, 40.80333432843609, 28.469427593292732, 23.55952424387778, 44.680977713677194, 38.16797225706039, 10.639889970902475, 0.7344915777925523, 0.16694313786443205, 0.9522881070452353, 1.5945171420612645, 9.368126161636846, 0.38115644406887794, 0.5277284919734925, 0.17129490031830727, 0.24466660354406605, 3.2136711814711174, 16.219076168152593, 34.56028599892893, 47.69986521813178, 56.64281037545974, 60.28262084530246, 55.89157058346657, 57.79124113821215, 60.09173085612636, 65.50583331815659, 64.78803173188241, 64.80618446103989, 62.448855676958644, 63.879418603835575, 59.70723659761491, 54.84100687888361, 51.17595203461186, 50.008972383314564, 52.01348397039598, 52.18165559153403, 54.028962504479196, 53.50995448327834, 53.69911078483828, 54.37832017098704, 53.12207129693801, 52.10412210033786, 46.863725723758826, 47.189486411310014, 48.16549762602776, 59.250915896508005, 64.07490168848346, 61.83842897415162, 62.442203337146395, 40.66824397733135, 60.37194498123662, 63.63555700548234, 60.0367235368298, 59.15547286310504, 55.275652562418294, 49.021394098958666, 44.832585165577555, 50.93484394011959, 51.507564898460146, 51.24019261329405, 51.85034475018902, 52.465454762981786, 53.86399545977193, 57.87631342487951, 59.91109786495086, 61.56900921175557, 61.849333163230654, 60.17105687049128, 57.358850817526545, 57.69901837072065, 55.2679725616209, 54.60736697719943, 53.06200412011916, 53.683436993629705, 53.98477700448806, 56.14137849500103, 54.93365718472389, 55.29348757959182, 54.323873750625125, 55.63644001560827, 56.613220014879786, 50.337753295898445, 28.69051983279567, 12.336789677220008, 2.6202307929915767, 0.13733429924374627, 0.3841442789041227, 3.0670750477621636, 2.1959166324907735, 3.9919897913932805, 1.4073748550107403, 3.326377546594989, 7.156119721551096, 0.768508394398997, 0.12206540848579138, 1.2344677073340262, 13.56401595377153, 36.62233091169788, 23.791563818531653, 21.678606540926044, 31.143860393954863, 28.896844348599835, 10.958016745505795, 0.6996734332173102, 0.04586503668237598, 0.013875206369125556, 0.011672673900912126, 0.010951607048721805, 0.04715336291419883, 0.03242277532755848, 0.08251140029319833, 0.06734766276373018, 0.06399127068899332, 0.0839478994208959, 0.015868520225217987, 0.0460065178002321, 0.08538434492243875, 0.024159153427688346, 0.03131076040106916, 0.03934881154207453, 0.024674104323851007, 0.019166047061463038, 0.06573031325974772, 0.08328069812588154, 0.024775208777657924, 0.04128234468460564, 0.04908347930458765, 0.017603018936971505, 0.020983155906921434, 0.12397138927612575, 0.03216039404393204, 0.02367317023116254, 0.034578516102966764, 0.0661969450753062, 0.04373570678815727, 0.028965661842976848, 0.03590792763016878, 0.01485855970156169, 0.03561236707854175, 0.04067683261969397, 0.045252959243953235, 0.03055899832097273, 0.04042664745582208, 0.03202922255431693, 0.060518682228341225, 0.03827626929588376, 0.04667252016764495, 0.01519851504840077, 0.01943179147107707, 0.048191186055661216, 0.037567078721739595, 0.04466371888655328, 0.04851416489409824, 0.04060799195881813, 0.012894933667754935, 0.04959609554780107, 0.010808109204405019, 0.05702540939373355, 0.03569673634164276, 0.03801057468198481, 0.03576522460207343, 0.04089729740254341, 0.04407220324801822, 0.04080054432814641, 0.01848989019861385, 0.09598294152848183, 0.03737458380900564, 0.01663120576150475, 0.033728150846136194, 0.018986964433063424, 0.055250655634388815, 0.025096645864147334, 0.09502252008044913, 0.04079887042603186, 0.9930195310904134, 21.307240455381333, 45.20421012755364, 39.30630683898926, 20.55479257337509, 31.98339273852687, 58.83800406609812, 41.013440009086366, 9.227818077610387, 0.10178611118106112, 0.014713866760083025, 0.45575456213085885, 1.4603927971855288, 11.399651112095004, 1.4606499575799512, 1.1660819188241036, 0.2867826549035888, 0.6083002265903258, 6.106632217284172, 21.885111485758138, 41.31862786508376, 52.218051264362956, 59.23217088945451, 61.29586319769583, 59.34585294415874, 57.00926957591888, 62.61347363072058, 66.52225279038953, 65.97457224322905, 65.36958194548085, 64.89670884224677, 62.82776055797454, 61.80091934819376, 56.633565348963586, 51.14233339986494, 52.45690791837631, 53.611767445841146, 53.94340384391047, 55.67896635301652, 54.272886860755186, 55.21942930836832, 55.701920063264915, 53.91404098080051, 50.61724178252682, 47.6528516892464, 48.47561197896158, 51.19761528507356, 60.350109146487334, 64.60233888318463, 63.84413296176542, 62.20311918566304, 42.64525974950483, 60.01490731393138, 64.47157490637996, 63.09486219959875, 60.44622682755994, 59.45845242469542, 50.158297015774636, 45.51188476624028, 51.6318569644805, 53.94419616268527, 53.205268690663004, 52.44109292184153, 54.065456236562426, 56.131988340808505, 59.06169683702531, 61.05434325433547, 61.78775587389546, 61.75383913901545, 60.509922196788175, 59.02899603689871, 59.07987702277399, 57.32788370501611, 57.16424242142708, 55.85241748440651, 53.78950572782948, 56.27314659856982, 55.847577279613866, 55.83169952515633, 56.60139406881025, 56.188572452914336, 56.44446003821589, 58.2363752395876, 52.95896737806259, 34.927541440533055, 17.184621518658055, 5.148605069806499, 0.7288562350215451, 1.0691109996649528, 3.7396816140221016, 4.268477174543565, 6.027698930232756, 6.9261624351624524, 6.876629764033902, 2.769805721698269, 0.2318019495015183, 0.06301021466272012, 0.9720414696681885, 9.824770458282964, 36.86577281644268, 35.16605292597125, 21.87166560080744, 29.25705521337448, 34.861912342809866, 18.785882073064005, 2.361785577189538, 0.1249947984732928, 0.04797604175344591, 0.059362215050045526, 0.03585935382532977, 0.11821852861753396, 0.017741048828728737, 0.019137106174903534, 0.051622612612141724, 0.018110680506534634, 0.042587919386043664, 0.026956921848919124, 0.06728138849740067, 0.04401824767551115, 0.029341054501973336, 0.033744533636396935, 0.04580232472489438, 0.07242579148301194, 0.016886324531609015, 0.01637021684268069, 0.06664286953427138, 0.03887192180920993, 0.042091804676719254, 0.06506287447747684, 0.04136911180290965, 0.007888753053491876, 0.06094698283460833, 0.03198269228901594, 0.02017451371366699, 0.019866726398768447, 0.09044453952341311, 0.049354272233622695, 0.16340739694574188, 0.21549477211890683, 0.16101861222376748, 0.14210489728758413, 0.08706167911089237, 0.13584611216379752, 0.11952460893700201, 0.11157887522131206, 0.29908979612012065, 0.14246457556803382, 0.18040215356215356, 0.1563248987640104, 0.18191661745790513, 0.0765270125421305, 0.10643253403325235, 0.12684783492718013, 0.09275175120321014, 0.195841062213144, 0.13621578023077982, 0.13641056574640736, 0.18825974886215505, 0.08119113968625184, 0.2034643265388666, 0.13349229169468727, 0.2014848932383522, 0.21507238188097555, 0.11885491785623374, 0.17224377682132108, 0.15742449540524714, 0.15576839717405458, 0.18809548428943082, 0.2170835618650721, 0.30230332045785846, 0.12601794720056558, 0.2374181094309015, 0.11452718758054319, 0.12991899714594887, 0.2359693452355362, 0.17061476745913107, 0.7720427563594234, 21.49089171040443, 52.78892086398218, 53.45180534547376, 37.143739423444195, 31.62879086309864, 53.74484169867731, 47.970320486253314, 14.557535648345949, 1.1345242444545993, 0.4040966405262871, 2.8514971704252305, 4.64746295444427, 19.0413950720141, 0.9599792007957736, 1.4481226426939813, 0.8523465440638605, 0.6675688946439374, 5.080889271151635, 19.193251594420403, 39.84637014327511, 51.98980462166571, 58.3065660538212, 62.83937469605477, 58.889524398311494, 61.454346564508256, 63.0649031362226, 69.93887255268713, 68.81810234438989, 70.21834927220499, 66.35185718536377, 66.70815744707662, 63.74894488242365, 59.66562417245681, 55.83644951543501, 56.86318482122114, 57.00574728750414, 56.39099421039705, 58.41289758682252, 58.22559264398391, 57.86498561982186, 58.79810179433515, 57.30223924882951, 57.03148588057488, 51.76280921505344, 52.501199322362105, 53.38081044535483, 64.86378054465017, 68.5285137545678, 66.23990489590552, 66.6084586420367, 47.464950546141594, 61.428125519906324, 65.67027476526076, 64.37422167870307, 62.29789541613672, 61.505051043725786, 52.98563165049399, 48.22369775464458, 56.01051645894205, 57.380867081303755, 56.46835903967581, 56.53143075204665, 56.342517637437396, 56.99063831760038, 61.6205216992286, 61.621415999627885, 63.68184097351567, 64.19423980097618, 60.696454432702836, 60.73102620340163, 62.52327088386782, 60.72577022737073, 60.00605452445246, 56.11394543801585, 57.12435191677463, 57.68277975820727, 60.476848771495206, 58.65159734602898, 59.37600420367334, 57.83121401263822, 59.254928481194284, 60.6436397183326, 53.083216298011045, 31.886023821369296, 15.769244047903246, 4.059080462301932, 0.35832828030951563, 1.2716936968987989, 6.558485829061078, 6.637126899534657, 8.504591853387895, 4.594266299278506, 9.882236123085022, 13.766272971707007, 2.5950472153002218, 0.3301085429566522, 1.8703715527249922, 16.326473605248236, 46.27612721535468, 32.39521022765867, 29.601694268565026, 41.817223871907885, 42.43858614275533, 17.854560382904545, 1.6120807802484882, 0.22669756694907145, 0.1690590880330532, 0.14749043410824192, 0.11411328559681294, 0.24242518349520623, 0.1138943759724498, 0.19606760973411222, 0.2464898468385781, 0.17596711735090903, 0.18525541249302127, 0.1737752325472332, 0.16964352118872827, 0.14949603697224972, 0.09855676712768693, 0.1739018055940828, 0.10839445456381767, 0.19573983135482959, 0.10967200576898553, 0.12800379265700618, 0.2582467377426163, 0.1968493411738065, 0.1872624556023267, 0.13372504452784217, 0.11348218236479068, 0.12676504380520315, 0.148082880543605, 0.14723794685015756, 0.10999433726312653, 0.08678989409799538, 0.2531379272019671, 0.12732431863344487], [0.03602856732604485, 0.040148706926453503, 0.047481520507003994, 0.04856712455230375, 0.03903262024264663, 0.018898898795727762, 0.004405289974754616, 0.05441561596648348, 0.043393725138758464, 0.0392819244054056, 0.05627544378981956, 0.03373476218492274, 0.02444178049993371, 0.023399761111866084, 0.038140805798672864, 0.006959301667408117, 0.08028304970432674, 0.04359284671203744, 0.04510913389704881, 0.05146182224815411, 0.06470027740203566, 0.012061495123611344, 0.04540698505156944, 0.03448281639946565, 0.009115060637404603, 0.02115470406058575, 0.04658279978039284, 0.014728834202903655, 0.08417872937336084, 0.09056922033308976, 0.0690344657989279, 0.11702523942315772, 0.021567816973753998, 0.036819116437747594, 0.04257219926183743, 0.03988632947326668, 0.02910269965087214, 0.046222481816526384, 0.053431710093131954, 0.11384443470066595, 0.38634022397379725, 12.527299196489396, 35.91720642582063, 37.77040473876461, 33.79391762518114, 32.11063638810189, 35.81116122584189, 42.522007111580145, 17.928189154594175, 0.944578811045616, 0.16460574232041836, 0.4579790056713166, 2.3878183480231994, 3.187132670033363, 0.1433277727975961, 0.4740233995741414, 0.9800967309744129, 0.1900449941956228, 2.0276934076701445, 7.401632147450601, 18.195402583768292, 32.54375234726937, 47.56435125104843, 57.60328508192494, 61.359876278908025, 60.06846335626418, 62.042674633764456, 66.77936415518484, 65.94296578438052, 65.80376478933519, 64.29053398870653, 61.35196878064064, 58.27319060602496, 52.77117606132261, 55.71704864501954, 57.72004619721444, 57.351751327514656, 56.74402321538618, 57.23767703579318, 57.66797281080677, 55.793989858319684, 59.54775694877871, 55.812044528222856, 57.689506623052786, 47.80787552556684, 51.108714765118016, 58.37103020760321, 61.98268982671923, 61.677592185235795, 61.44984760592061, 36.293695126810384, 59.77435619600358, 63.61938899563205, 60.85367087394961, 58.257814914949485, 53.34213195308563, 46.5887205062374, 53.4013165966157, 59.25021379224716, 60.04698445720058, 58.14794540405274, 58.226635994449744, 56.756272777434326, 59.61528055129513, 60.48641935471566, 61.14084720611573, 58.34250280933996, 59.42837961258427, 59.5701026916504, 59.07313839081795, 58.99902520641204, 56.10928958462131, 53.8153737591159, 55.172086300388465, 57.65510743664157, 58.89304668672624, 56.46954751783802, 57.94870861114995, 57.722831080036784, 61.64304787112821, 56.52571585870559, 50.58447037973712, 28.01970628000075, 8.504383967768762, 0.8408582895513504, 0.5665498443188206, 1.0362849288409757, 1.2761325941931818, 2.0539609078438055, 3.464491309658174, 4.572637859852084, 9.14609843684781, 6.98070397300105, 2.923317239169152, 0.08493922485579407, 1.1472970751985427, 17.453766715142038, 36.408310705615634, 51.05256995847149, 40.207969527090754, 26.41953222213253, 37.17675009081441, 8.468628621870472, 0.40851019563213475, 0.12239657297369935, 0.049198817672027696, 0.0020077173863800486, 0.05200373752403164, 0.012828502353400955, 0.04612451832320902, 0.031508340222400524, 0.06727521382873097, 0.1551059303024123, 0.02913806609989655, 0.029189246518897916, 0.033464045864680124, 0.031239621476420475, 0.03331513752439811, 0.056271115393047376, 0.007272666102395423, 0.07122261975441249, 0.07887622116193657, 0.06415777989933569, 0.059045069971151894, 0.02562739540852847, 0.02157962621910678, 0.02504061610858527, 0.049587327671507676, 0.02326665525024216, 0.04143144454686873, 0.02826667747520391, 0.02513231300268202, 0.0303147311863159, 0.028454313475278117, 0.057115501333628936, 0.06435605111501871, 0.06003267221873807, 0.06491878099979893, 0.06186133175487481, 0.007377081492450089, 0.014708494568514007, 0.06055101113874586, 0.04836078260033842, 0.06466849241405725, 0.01906441783742799, 0.021112385363648498, 0.07179074289817965, 0.06337670729525628, 0.007442256901413203, 0.03471507127546976, 0.04472817752450224, 0.010823588010915106, 0.05658785827578076, 0.030159833953685822, 0.083109860518767, 0.059221228058900566, 0.06837238963212698, 0.02602732969417928, 0.05969948525871, 0.005936442138326745, 0.033002006746227705, 0.049209370533184665, 0.056511896827648726, 0.05418237666749666, 0.027142604324786414, 0.06879331664212289, 0.03822147102665998, 0.10904902306896065, 0.05602774841170158, 0.03729930417912622, 0.05016214259329343, 0.08923342346303886, 0.01020338046439593, 0.018712262540394743, 0.015913365097085557, 0.10371725029882886, 1.3817676613407752, 21.621428189739106, 43.53759504133656, 35.90493725192162, 21.967787204250214, 33.73784734356788, 51.08764771492251, 45.98671513219034, 17.613944545868907, 0.9465304966415129, 0.13039657635794533, 0.017857279688600573, 2.640454043303767, 2.7912902591689943, 0.9105974796318239, 1.374584085518314, 0.788362145183548, 0.5895194279090051, 3.0549384990046105, 11.292019313381566, 22.61351131623791, 38.96796318792528, 51.68779780787807, 59.77243031224897, 61.106769654058645, 59.856569074815326, 62.657639518860854, 67.9143568777269, 67.00758334129088, 67.9083634961036, 65.2012534295359, 64.45347316803472, 59.75910994314379, 55.4243064695789, 55.191447119559015, 58.28676985156152, 58.6449920746588, 60.312881931181884, 59.62225844783168, 60.179674317759854, 58.444029438880186, 61.07554758748701, 58.91883234823904, 57.19865337494881, 50.640925053627264, 52.23712575051093, 59.5067407238868, 64.38631042357414, 63.41903432723015, 62.270733002693426, 40.81897674068328, 61.47655110205374, 64.29516238550987, 64.15722439366003, 61.86037463526573, 55.26353243858584, 48.597334892519065, 52.72106386000111, 59.10445067190356, 60.35879719641901, 60.100140417775805, 58.85699226010231, 58.91098760789441, 59.16129758281093, 61.62654645981328, 63.26945474070888, 60.65797205894225, 58.7227334514741, 61.62493044330228, 60.14818160764633, 61.934640792108354, 58.221536913225734, 55.56813586142756, 56.29979518152053, 58.79416373468215, 59.633664700292776, 59.495907137470866, 59.59445276568013, 59.16136034073369, 60.745997890349365, 58.10536023109191, 53.82685845898044, 32.49089448682724, 11.697739478080504, 2.1212474521129363, 1.4982816673094228, 1.478273166764167, 3.1279852890199233, 7.190753269580103, 5.965673019809108, 5.891344595339991, 7.472488784020947, 0.340890004750221, 0.519231412439577, 0.07723922150269633, 0.9422353174417251, 14.355421796921762, 46.25786465983237, 53.73093689641645, 28.656391289926347, 25.461424666066325, 44.433323183367335, 15.17626993117794, 1.5218768076550577, 0.12541878217410657, 0.10367172935436811, 0.025496582065017957, 0.028416332751212102, 0.022421863283060735, 0.0802065864686043, 0.0072973317395324915, 0.05988422353121062, 0.055995990236800526, 0.031140491614238392, 0.04524694545374763, 0.09384744845691229, 0.03459144000624938, 0.04058759486783416, 0.01865241766696976, 0.06567100273264993, 0.03655347928044297, 0.013006268268180712, 0.05119394045323134, 0.04422171679776042, 0.02070300712911112, 0.03786683743519168, 0.03415974563047771, 0.01220096430305632, 0.03901619531755005, 0.03882564243770415, 0.13386338468520873, 0.06223605217171773, 0.030930392001004472, 0.10044601655775502, 0.05076909490350274, 0.03384265034729916, 0.24821234957104732, 0.14599993344276183, 0.1531795562515336, 0.17076783182640232, 0.13680606629819642, 0.22277421618421234, 0.14238936105562797, 0.2197933833925955, 0.10014298281842664, 0.08645931949778911, 0.17654551373374078, 0.07805489829831547, 0.17019213207306402, 0.09837810010198625, 0.19978174188685036, 0.0612871871600228, 0.1348065614940659, 0.1143706604958542, 0.21440845944227713, 0.1629207932179974, 0.20738453634323614, 0.08676439869187533, 0.10814140040066936, 0.15187507705582728, 0.21351322441572146, 0.10057300329208375, 0.11608719540339325, 0.11876373807148588, 0.11582907739906542, 0.22582952804382772, 0.1465220989719514, 0.2840623992585367, 0.16014547117294806, 0.12000520653542011, 0.15473307530966499, 0.1389723331216843, 0.09109767544413767, 0.11961965746576748, 0.1462028241686283, 0.24985568477742134, 0.9331668588903643, 20.57054873435728, 51.777749523039795, 48.250291424412886, 45.519325502457164, 39.81121001705047, 46.237640919223914, 51.94282639411188, 23.427491380322365, 1.356992010147341, 0.4511552153816147, 1.0606999671266926, 7.619888023022683, 13.286923054725895, 0.4762484559849386, 1.7276292702844067, 2.6548216852449604, 0.9080163149103042, 2.7251823871366443, 9.116736554330396, 21.028118710364065, 36.44402780840474, 49.87048918201078, 60.89302401388846, 61.68136550534157, 65.44624859286894, 63.69813449921147, 72.07525422496181, 67.72510251691266, 72.09860801696777, 70.35646377071258, 67.45469431723318, 61.463705339739406, 58.092494856926706, 59.05732339428317, 62.85161641336257, 62.18812396449428, 62.146080078617224, 62.885442933728626, 62.78290433268394, 59.55890040243826, 64.95338709123673, 61.14453815644788, 61.83418496962517, 51.90810165097637, 55.405530083564024, 63.03228862823979, 65.90732712899485, 65.23054961235293, 63.839504564962084, 42.99160895809051, 61.96834571899907, 63.658263606409875, 66.31937211559665, 62.844422786466545, 56.72014774814729, 49.752598424111646, 57.27756361807547, 62.358574482702444, 63.79506803327992, 61.79383554766255, 63.75047460679085, 63.046381704268924, 63.5051146630318, 64.26346178977721, 62.964247272860625, 61.36701891499182, 60.09283304214478, 61.83020376390027, 61.911710616080995, 62.8917657944464, 61.30451594629596, 56.93249702453614, 59.43580465932047, 61.21818065643311, 63.21489849398213, 60.739831924438484, 62.201361963825846, 61.51832826675908, 64.96812343597412, 58.88234646089616, 52.97668864650112, 31.34839434777537, 10.601764532827563, 1.872162605004926, 1.5988215756031776, 2.570953566220499, 4.253908511131041, 5.878805268195368, 5.677555809097906, 13.134271271767156, 21.227388843413323, 13.674402236938478, 6.2550669620114, 0.17836996744717323, 1.9455188945416484, 22.9294680395434, 45.78540340546639, 58.19070316130116, 46.34960889816285, 36.78996516812232, 51.305892313680346, 15.805746605319364, 1.0970776215676339, 0.28570342087937944, 0.29885650702541877, 0.05243414487209051, 0.26568713688081314, 0.06606726171148401, 0.14199861024896945, 0.12185844217216778, 0.13030424744131106, 0.4071706755747719, 0.13207663781940937, 0.17722555466236609, 0.20979504731874313, 0.16917475198786106, 0.12630724498341162, 0.12716729359160509, 0.21076603311925166, 0.15199466338080747, 0.10355880033344993, 0.15483637460537497, 0.17851281220153456, 0.11860641425535565, 0.09603984653949739, 0.12118299777108817, 0.0924664983646043, 0.14213786971184517, 0.10046755895018579, 0.25843023112223995, 0.2844256475087135, 0.12887402257371333, 0.1263363256810173, 0.17718296017377608, 0.16915985923861304], [0.01829719035736015, 0.02687243192697004, 0.05963902176928617, 0.04470770765516547, 0.04575358621115166, 0.03360172335599219, 0.02876518429407189, 0.016372444243320537, 0.06422679676043411, 0.02155237072598069, 0.0017879705715571502, 0.07499624629535022, 0.09368067877667566, 0.03469473164108011, 0.026975706324822483, 0.08082813658421079, 0.025549076324809464, 0.040330610673634276, 0.09507865134266116, 0.0668267306360987, 0.050728936574511954, 0.042752785337788445, 0.007798377661064508, 0.025624386598205855, 0.018819562730289275, 0.049351962478530985, 0.03932194483857002, 0.05541551775569397, 0.028345534735689723, 0.04772705168673589, 0.0348651478998363, 0.05251096050825812, 0.0631987220878082, 0.025901833000863274, 0.02473177542279084, 0.010504145625858538, 0.07537581221831423, 0.048668003010173, 0.0306072082340477, 0.04426520760922183, 0.029294133531830968, 0.1134643248552757, 11.446487153730086, 41.395004257079094, 45.14519806831114, 31.990168632999545, 31.350873285724273, 37.10696720307873, 35.9406308204897, 23.712363320012248, 3.96593667326435, 0.10208120824949396, 0.3870697541823311, 0.9906732182829612, 6.307893443492151, 0.7266735585947192, 1.3967702369536124, 0.24267103643186633, 0.6155604724922489, 0.32503648931461, 1.0221708926462358, 7.300404598636012, 18.81351713211306, 34.80330821006529, 48.26388243705996, 56.38120005207678, 59.160116949389064, 63.89585333485758, 65.7228894387522, 64.66883090234572, 67.77698762955205, 65.17626008679791, 60.6930733496143, 61.46490950738231, 60.46492476617137, 62.433805542607466, 62.82689371416646, 65.65864101532968, 60.416769827565844, 60.78855952908916, 61.02845561119818, 64.63407085787865, 62.577485884389574, 63.79973957615515, 58.714539620184134, 55.23595817627446, 60.685008956540024, 64.44276901983446, 62.948436198696015, 64.7902008025877, 27.95605209565932, 59.69495173423522, 69.73727841531077, 62.60914333405034, 62.27428667006954, 52.68824931113951, 52.40809794395201, 61.083772797738355, 63.257734698633996, 61.77971893741239, 61.77583971331197, 59.96297121047974, 59.582485614284394, 59.35656101472917, 60.10611026517807, 61.90006509903939, 61.647531140235166, 60.83217628540532, 61.86210832288189, 62.007000677047245, 62.883807305366766, 59.10290133568549, 60.43045105472688, 55.732867563924486, 58.75512830672726, 58.366444956871774, 61.285339478523504, 61.22634703113187, 61.64226339709375, 55.173298312771706, 49.32729582632742, 23.986772337267478, 6.840106614174382, 0.3685307328499133, 0.22927870102707418, 0.42255359852025587, 1.0224717506958594, 1.4508534703523883, 13.678513861471608, 8.741913880071333, 3.7675412287635193, 7.931084950124064, 1.4546109784033991, 0.031846474195199634, 1.6974808299733748, 18.692390418821766, 46.137604790349165, 24.611194056849328, 32.470859019987046, 52.12059213269142, 34.1218081597359, 12.198589867161168, 0.5578744195161328, 0.07568300581507145, 0.13274302706122398, 0.01737067213041648, 0.022720815688972513, 0.03824448430790536, 0.0715042719797742, 0.07873408886934481, 0.023149507000081004, 0.06178966039911874, 0.015518959093418334, 0.01837985124439001, 0.04323710612351856, 0.026375489842687404, 0.008220377194154407, 0.07242142478184355, 0.0028207742809993968, 0.038173942931837616, 0.028379679274474903, 0.01049864990261173, 0.038133903346475095, 0.04297357953844532, 0.04493334736194342, 0.0656426115141761, 0.05123398386903348, 0.03527490151745658, 0.022907413639909318, 0.02297270156803631, 0.028236292512907137, 0.02150757948026782, 0.09756858265327831, 0.014280201623126144, 0.021214502968735272, 0.03409580410187764, 0.09560109266350347, 0.03837211455609049, 0.045576148756569436, 0.04645771677455595, 0.03671940243352325, 0.02058053456787621, 0.04600230814708818, 0.04139851425744353, 0.07515393783368411, 0.018834629764540062, 0.05060257037140189, 0.04052035533072006, 0.0250891228807309, 0.059495506687991084, 0.02791208410335164, 0.035905096935288566, 0.0890031450938794, 0.023270428233269243, 0.05214284759976211, 0.0490761133691957, 0.02131761074246418, 0.0440856404302101, 0.04421166189375424, 0.03180976326186811, 0.007011222318866321, 0.00760506064022681, 0.08070712533569144, 0.03408157401868413, 0.04010309022100222, 0.03359328489750624, 0.06123120528495601, 0.03674108272178039, 0.036338783139663364, 0.015013535458204007, 0.03601337197206674, 0.04186671272280716, 0.028709529921592727, 0.05874624971540705, 0.038050817280647256, 0.030937089524682493, 0.10390235246309351, 0.564723490707336, 20.10666766474324, 48.17750792349539, 43.72367228231123, 28.333858713026974, 26.633126851051088, 50.17993673201531, 53.987656024194536, 21.78504005555184, 2.5407334200797544, 0.039377011238567294, 0.36557534949914106, 0.7483094750392822, 4.039004546019339, 1.87974761089971, 4.1338874159320715, 0.8148356310782895, 0.3413124256316693, 0.4980338515052873, 1.9714384069365842, 10.913987159729006, 24.98706106216677, 40.33157517833095, 53.66198162878714, 60.150899810175744, 60.11685755945022, 63.59289338511806, 66.31246089935303, 67.32010210714033, 68.00395165720295, 66.18310113107005, 61.45558211111254, 63.3523226553394, 63.24629706721153, 65.5577733439784, 63.403890055994836, 66.36566392837032, 62.641718618331424, 63.741092297338675, 64.12858716903195, 64.8207482214897, 65.2259486721408, 66.40858250279581, 61.06803232623685, 56.521138452714496, 65.01846705713581, 66.55344347799978, 64.99853749429026, 64.97465810468121, 32.95274572987711, 59.59737493145851, 68.8239231417256, 65.91915699743456, 62.98234508883569, 55.14472776843656, 54.55215177228374, 62.01308819555468, 63.352326577709576, 63.90693795296454, 63.54256545343707, 62.438049547133915, 61.281307281986365, 62.52564784019225, 62.537156074277824, 61.82660302808208, 61.82828964725618, 61.336879422587735, 60.140748716169796, 63.24080574897028, 63.00332192451724, 62.302504201089185, 62.538991743518466, 58.067015140287346, 58.58805887160763, 60.29186194942844, 60.864735880205714, 62.20590014611522, 62.78178645718483, 58.23012298153293, 53.52926038926648, 30.01118971455482, 10.290329321738213, 1.6478800076630808, 0.770514380306967, 2.448229467676532, 3.9061107222111, 6.623614334291028, 13.215587888994525, 4.5236945248419245, 2.4659997657422097, 0.7970069877562985, 0.4454311902724928, 0.03368177571363988, 1.0915295515329608, 15.388860433332383, 53.8968845336668, 33.003297236657914, 40.98066468392649, 53.536728582074566, 37.83016989308019, 20.536065216987364, 1.066565013700916, 0.02330696296637818, 0.06016809358111313, 0.01104908886425678, 0.04466125591387672, 0.017159360183042385, 0.04601735411392105, 0.030677858777644656, 0.01492447390656678, 0.061974203319198666, 0.03896946395416895, 0.06417700104535588, 0.010499242663143143, 0.11728393199342875, 0.009042665328560098, 0.008142960178966244, 0.053528547437200626, 0.034342702748554374, 0.06276893144052836, 0.020175392799560102, 0.015017959615966726, 0.03819514441514208, 0.0294592771904483, 0.05074864035592445, 0.09484258134879413, 0.08337525635837548, 0.046804137903475956, 0.04485832054107901, 0.03302113979213661, 0.06136442031410914, 0.11215514187971432, 0.019873299433158773, 0.054189271458815184, 0.01816131125745033, 0.18055560097338694, 0.11502110744796454, 0.1453741162174171, 0.11238318327213488, 0.1857483441070203, 0.13317267981267747, 0.10695840742799545, 0.11510620449459362, 0.16524079856612992, 0.1086921793138308, 0.15180441310569165, 0.1676781532625037, 0.1624104714081172, 0.2316607594970734, 0.14588845232802053, 0.11949098533800534, 0.14995224233115875, 0.1690655844586511, 0.25331772803779573, 0.14784292648396186, 0.18332433466228748, 0.12722794477257038, 0.1390329153547364, 0.09259450399587232, 0.1307598705733976, 0.14025393693197158, 0.20869730461028316, 0.07935622121177374, 0.16680286716549628, 0.09640021429907891, 0.11849012210844986, 0.14351903430877194, 0.13798271606285728, 0.17540957388137618, 0.15920823920638333, 0.14342266044789745, 0.10133480878486749, 0.1476556026647168, 0.10600578475503192, 0.21311269832714913, 0.16300138566763173, 0.4887054746429767, 19.868848477640462, 56.282513218541304, 60.019163085568344, 42.687127128724136, 39.38540927825436, 46.48975126204952, 49.23092319119362, 29.549428686018917, 5.374221763303203, 0.42594654064986015, 1.7364326624139663, 5.700823799256356, 17.406284463021066, 2.339569027385404, 2.1517142172782653, 0.5005903788391621, 0.8241641918017019, 0.912479910879366, 1.3507390166482618, 9.788752313583128, 23.740492597703014, 38.539593296666304, 52.747885027239406, 61.680549652345725, 63.58427593784948, 63.004467256607555, 70.18995131215742, 67.78690338134766, 74.30243092198526, 71.35325570260325, 66.89039076528242, 66.95007354982438, 64.70337913882348, 68.59706109569919, 67.33103767518075, 69.96774904189571, 66.0984956064532, 66.31286882585096, 66.69720618955552, 67.17127169332197, 66.74658098528462, 69.41900161004835, 64.5299986100966, 62.76894461724066, 67.07136108029273, 70.12107449193155, 67.88953611927649, 67.21209572207543, 36.24150406929755, 61.65155156966179, 72.41962263661047, 68.68272566026258, 68.32611945367628, 57.56372797873713, 57.363467447219364, 66.19163620856501, 67.9912353331043, 65.70941217484014, 65.79905794512841, 63.32443852578441, 62.77088619047596, 63.31838238623835, 63.79506018853957, 64.29894747272616, 63.339151336300766, 61.880512083730395, 61.39076494401502, 64.09117167995822, 64.60099351021552, 63.12633137549124, 66.76453759593349, 59.30765690342073, 62.15443864945443, 62.022650934034786, 63.802975531547304, 64.84214082840951, 63.930354502893266, 57.48469221976496, 53.96407473471857, 27.858602769913215, 8.768624240352262, 0.9799195501592852, 0.722634252761641, 2.44335935481133, 4.087840751294167, 8.695883885506662, 29.436411473058886, 18.69124116436128, 12.076173674675728, 12.712610594687924, 2.7400964642724683, 0.10730146926136748, 2.246686811408689, 23.409513196637555, 55.14351967842349, 33.62795037607993, 40.040613758948545, 58.38276201678861, 47.186842733813876, 21.52673432903905, 1.160106555588784, 0.10237026854508346, 0.1657346188421211, 0.19026823221675812, 0.2574425905702576, 0.20090019961278285, 0.20273046027268135, 0.18214368591866187, 0.15340723758262975, 0.17426738275154946, 0.12733890494752315, 0.18623644936709635, 0.1268422807897291, 0.1284510118045634, 0.05117226399541382, 0.12414838623015151, 0.13536491701679845, 0.11517178162091202, 0.12869523297394478, 0.1290944413912873, 0.0935423232975506, 0.08882820891636996, 0.10383819259943501, 0.22225171357633608, 0.26739339854928756, 0.17877853745895048, 0.13365937547097284, 0.12896875700642987, 0.10637178326085692, 0.1801592424031227, 0.298955271080617, 0.09278466234043722, 0.08340607607556928, 0.07467242092975686], [0.06015166865601655, 0.05100101653125979, 0.03391829769938223, 0.08584332351963367, 0.034531259969357526, 0.023298229564041383, 0.01776050363156584, 0.028599316682366115, 0.03013104436949136, 0.01004538344850223, 0.07794568480383005, 0.006602588626030352, 0.03244334095788579, 0.016487571936581406, 0.08400444437058703, 0.09372166448062468, 0.04587883775633189, 0.047246124670510335, 0.03618223690277627, 0.08251670162163435, 0.012981914333067836, 0.059557372118316354, 0.07510197408978017, 0.021440544871673472, 0.04272995974808451, 0.07004793883571703, 0.021574070166435935, 0.11265810158464218, 0.1220898773340929, 0.05752715101886181, 0.05875379185102159, 0.04357013603552215, 0.05377639986334309, 0.08775025425899415, 0.008613502873378176, 0.07475888161289115, 0.0109504071635104, 0.059723356558430585, 0.0037472805378192496, 0.020515733105581135, 0.03407004822586333, 0.04780932952980361, 0.06452162569809346, 8.924899312757677, 38.59062333260813, 42.025619399163034, 37.64593616608651, 28.93504038933785, 30.867392132359168, 38.03852619663362, 26.773892871795166, 6.496724678624061, 0.17950043743175847, 0.030265169128054575, 2.0504681597794256, 5.162188728009501, 11.615444229495141, 17.985261601786462, 2.933825514008922, 0.5095918200189068, 0.04559243578583964, 0.09486717277116354, 1.5788156491133476, 6.667573317404717, 20.381339480800015, 37.80239558989002, 50.94502641308693, 61.3617080257785, 64.20894084438201, 63.578443373403246, 67.50020165597239, 66.25989329430365, 64.0126536738488, 61.11212368934386, 64.28783147565781, 64.15687922508486, 65.01888675074424, 61.62151798125237, 63.79742537775348, 62.79995095345282, 63.508040751180346, 65.40947637250348, 64.99049271306684, 63.64153469762495, 63.32567015001851, 60.65864670661188, 62.23549442906534, 61.6611143081419, 65.83583016549387, 57.03657319468837, 25.15020420474391, 55.24053165989538, 65.37055077091341, 62.04256480739963, 61.443665950529045, 57.96437455761818, 54.02933512964557, 64.95761540628249, 62.77880937822404, 62.21128163799163, 62.31989206806306, 63.37615497650639, 64.07914961538008, 63.835401765761844, 64.46434597815237, 63.554979755032456, 64.50362851542812, 60.85643614492109, 60.12106234027494, 60.85490642055389, 62.43210715632286, 61.47570779246669, 61.61481465062788, 62.844783644522394, 64.81820260324787, 63.36756890819919, 61.52167404851606, 57.16289704845798, 51.14412984540386, 36.98705250217069, 16.241003198008386, 3.184071505262006, 0.1452532888299996, 0.3922244533896447, 1.4876948224921382, 4.4059719385639315, 2.070211042319575, 5.047857521041747, 15.111068371803531, 14.764903514615952, 2.3462395081596994, 0.5878869251858804, 0.35584909721247615, 2.9058945611599953, 20.933889650529434, 40.72318461633498, 25.802182535971365, 30.499224739689982, 28.016284012025405, 30.624528777214792, 19.33512176236799, 0.8174621482049266, 0.03830413574412946, 0.051218650619229006, 0.054893390530900615, 0.03422010952847139, 0.015653475514432837, 0.04629403059821456, 0.042046593997867844, 0.04760539309392053, 0.010370500629857905, 0.009573716520061417, 0.054889000847094485, 0.018047642961685217, 0.04677770403964866, 0.016180535387848655, 0.023005980427467057, 0.10976262630954867, 0.03542040076647555, 0.0224232173434669, 0.03500448780194406, 0.029379433591759978, 0.025147023806048018, 0.020827417892794457, 0.0721262894090145, 0.05479427024481758, 0.03855462351273145, 0.035942708021931113, 0.029090582055129835, 0.04420730285346509, 0.027259735337969278, 0.03076838355721726, 0.0208989609288232, 0.057456529203562014, 0.08013578462264231, 0.03708653091903656, 0.01807630805659198, 0.03455123954242276, 0.06020331447343192, 0.12640027870093623, 0.022220027843309988, 0.027834770510033257, 0.018386952879448092, 0.03629852521924242, 0.03371062658486828, 0.04284000061752816, 0.021691892573970462, 0.03071897854698041, 0.03818307469989504, 0.020753090127160954, 0.042644862701455434, 0.07347524766960452, 0.046878747206421635, 0.04811830811142441, 0.025156161319764874, 0.03919116213857647, 0.019077383875546437, 0.03055547431652104, 0.052386536338036103, 0.030940270704788067, 0.06785033135524682, 0.01811566199326227, 0.013036301787642222, 0.010021242102788342, 0.09185166684009376, 0.017767664638438055, 0.016972176174843506, 0.09380496888151092, 0.09955265078573458, 0.04652918128657245, 0.04284837395854054, 0.06324750273638675, 0.012658165576266906, 0.06349000403837812, 0.03125817612594655, 0.018365134695364584, 0.06546462630672802, 0.05783012730159587, 0.27808087667630565, 16.629698314974387, 47.91847067494547, 43.328960249500895, 34.31677349152104, 26.817823417725105, 35.880646013444476, 57.551372512694336, 31.10242447545452, 4.661547205140514, 0.19804477541437074, 0.039972878256512266, 0.5051113701155109, 0.7800564650566347, 11.869634409104625, 20.421759505425733, 5.032554393814457, 1.1571054521106905, 0.2731452479718193, 1.0964926981156873, 2.7730848231623253, 10.331444586476973, 26.198045784427276, 45.28000993113364, 55.081840407463815, 65.15807990104922, 64.53945152221188, 64.67349460048061, 68.99857059601815, 68.64053664668914, 66.29636349216585, 62.35814302198349, 66.19227947727327, 66.17538975131127, 66.36454997524139, 64.85052293346774, 65.76998141504103, 64.53164600556897, 65.22738425962388, 66.9434682784542, 67.3650210903537, 65.40911943681779, 65.6897375660558, 63.03185716752083, 63.36428980673514, 64.19878975037606, 68.26918232825496, 59.57962228405861, 24.97163830264922, 55.764262214783706, 66.26056794197329, 65.03975768243113, 63.38460768422773, 58.43533354420816, 56.6937658863683, 65.55307434451196, 64.74800394427392, 62.0620079963438, 62.58396171754407, 65.26338377306539, 65.22794515855851, 63.06071012250839, 65.49439568673411, 63.3220301904986, 65.19613081409086, 60.7176979895561, 61.735458912387976, 59.343530901016734, 62.30706983996976, 61.567628537454915, 62.42237967829551, 62.661440295557824, 64.57722786934146, 62.57408518945018, 63.96690707052908, 58.613326780257694, 53.97361786134782, 42.140093772642075, 22.20219785167325, 5.960729852799447, 1.1724659440017517, 1.7849098482439596, 3.2024799239250923, 3.148645638458191, 6.165076513444224, 8.12064721699684, 16.752019389983147, 11.884560988795373, 0.7932396124928229, 0.5672344204879577, 0.2518880547535035, 1.8631607654594609, 19.782317069269, 51.172790604252974, 33.844857446609005, 24.207984209060672, 27.84918712031457, 38.9004631196299, 26.832885319186797, 2.1715209609077823, 0.13066559579343567, 0.03670876147225499, 0.0220796977725601, 0.0200438478420819, 0.027379928787629453, 0.05533116381435145, 0.08036205635195778, 0.14595335529696557, 0.06284293170357425, 0.03660576095083549, 0.016084716940719276, 0.016766719054430723, 0.056101331156828714, 0.04773919418033573, 0.03435772956318913, 0.08410905367664753, 0.02893725721796434, 0.0350581867349965, 0.044421478054456176, 0.046441291849459373, 0.04718681414341254, 0.05416453447974017, 0.028331095893536846, 0.06397419841960073, 0.08343045299331989, 0.06241395693993377, 0.015294215709511793, 0.01651331632127685, 0.01760139100013241, 0.01619936965946709, 0.07772276853962291, 0.05062294447974813, 0.04360091744831974, 0.027367700109138127, 0.10505152265391043, 0.13797306335501133, 0.18883672032144763, 0.2474104087319105, 0.0910955687023459, 0.1079489974184863, 0.05960093570813056, 0.09741207855122705, 0.10330321808015147, 0.13326680137505456, 0.2220509985401746, 0.1699062893467565, 0.17141110053466213, 0.10595546810016518, 0.1277109785305877, 0.22500711733535414, 0.1628005940226778, 0.07090395016054954, 0.10403655574566896, 0.1996629676150699, 0.1184706021881392, 0.2100935458175598, 0.2206199156541017, 0.07419880239232894, 0.12338006899001137, 0.2449321909056556, 0.10244688499839076, 0.2627841539440617, 0.24734480096207512, 0.09457047457896894, 0.13754066800878895, 0.19554279354070464, 0.17100032418966296, 0.1657799712472385, 0.09859666498678346, 0.17463538074685683, 0.1094569112624853, 0.15444236026415903, 0.14317119974763165, 0.13133236807921242, 0.19972794719280737, 0.1077503354979619, 0.31832987983380595, 15.839953595592132, 53.23335286109678, 55.50253422029557, 52.36560690787531, 40.53257311544111, 40.418090897221724, 49.52901940191946, 32.698274120207756, 9.038504881243552, 0.3604207115788614, 0.16492405185295692, 5.464028841064823, 13.588349357728037, 20.28552382223068, 23.471539597357474, 4.135722104580172, 1.4568903657697863, 0.27046001786666535, 0.5337401371329061, 2.618921211650295, 8.1549473635612, 23.817265149085756, 44.85500151111234, 56.70695289488762, 67.84789623752718, 63.803367768564534, 66.5157808796052, 72.18963838392689, 71.27247841127458, 68.68167446505639, 63.03133941465809, 67.78104336031022, 68.65493174522155, 68.84412334811303, 67.17317796522572, 67.64676493983116, 69.06405064367479, 67.62144996273902, 71.22657883551814, 70.22931621920678, 70.22806106075164, 68.53494644165039, 66.18835710710096, 67.42261717396399, 66.46045977069487, 70.95164422065982, 59.73192007310929, 33.96055167721164, 57.34812313510526, 65.21685661808138, 67.08887054074195, 66.97518456366755, 63.60693939270512, 57.24789481009207, 68.89403943092593, 65.90750755802279, 64.49633290690761, 64.25196924517232, 67.41898505918442, 68.61412340594877, 65.06092671425112, 66.67327973150438, 62.81792325358238, 63.809051282944225, 62.29109402625792, 61.859868649513494, 59.921931451366795, 61.86699167374642, 62.581545537517925, 62.53268849465155, 66.11470284000521, 67.05517738096177, 65.29511182538926, 63.93767364563481, 59.58908696328441, 52.70078128384006, 40.63861831541985, 18.614668653857326, 4.719876771973026, 0.9134459171083666, 1.440867851338079, 3.1923874203235876, 9.775024998572565, 5.640938032057978, 11.41937671169158, 22.960631270562452, 18.61400381211312, 3.7421470688235376, 1.451033899380315, 0.46569780116119697, 3.6724205651590904, 26.895949186817294, 52.03658673071092, 33.00547415210355, 38.72804357159523, 38.46333849814631, 42.48310112184094, 30.071160793304447, 2.166705516076857, 0.30058903018793753, 0.18708073954668739, 0.08053373665578904, 0.1641262938538867, 0.08560950582426402, 0.14083253249766367, 0.15618717147698327, 0.20669536364655341, 0.12555595787782825, 0.18502037671785201, 0.09529672593118683, 0.10059320503064703, 0.13489302217720017, 0.10817964350984943, 0.09321524205827907, 0.2268133534779472, 0.14670934618240403, 0.1535046992883567, 0.12358970895049073, 0.10248083801519486, 0.165336528913148, 0.07929796788601146, 0.17416547773586166, 0.07552879231591379, 0.22784977850894775, 0.1770811470886392, 0.16183078799757267, 0.17600307751807476, 0.12744061844122986, 0.09062520603859618, 0.12935183161208708, 0.17090125369929499, 0.17781918087313253, 0.14034956002668028], [0.03960816294796044, 0.045453992206603296, 0.019853720141033974, 0.03914885493295808, 0.032470709448980714, 0.03761998092335078, 0.053206514717350085, 0.03649272084716828, 0.02285748960510377, 0.03349386966757236, 0.08053280202852142, 0.04408057275859099, 0.007258221514583115, 0.036364554337436156, 0.016664892562755173, 0.010693074399304968, 0.12283841418402812, 0.035997716965334076, 0.021068013551074172, 0.02827715755800807, 0.01953146334046558, 0.03378008777696279, 0.09661436651743228, 0.034104284695199424, 0.05267932365137724, 0.06783658773788522, 0.08252248558546267, 0.006376767930980291, 0.05927432944337207, 0.04928191905961402, 0.10163720667121873, 0.012336476638372387, 0.031882407549288005, 0.02211028000249738, 0.0841079198665196, 0.04045231523172509, 0.01810747251335171, 0.03578006372516675, 0.0940311486802755, 0.016818213569481048, 0.002945626502849102, 0.02629164151937491, 0.012763406904864938, 0.06799499173798869, 6.927321985844643, 31.042759341578332, 40.25783854146158, 41.59726519738474, 20.133153469331805, 25.21431338402533, 47.87122572621992, 39.46732013456283, 12.769630089882883, 2.007844130839071, 0.08796808369938405, 0.364497923442433, 4.347889481052276, 9.481623864942982, 7.053544838582316, 0.74774747293803, 0.47285695410063194, 0.32061904248210693, 0.06499155935260557, 0.20331339189602485, 1.6206353470202417, 7.412140177142236, 20.17007866213399, 38.08767741726291, 50.741867250011815, 62.704099993551935, 66.71067560872724, 63.51040201802408, 66.86028265183973, 68.22405153705229, 66.86619758605957, 65.59217645275977, 67.83179098559965, 67.59547602745795, 65.55781649005029, 66.80690703853485, 67.22124268931728, 68.6609878847676, 65.23842573165894, 65.75008323115688, 65.82510640544277, 64.30668238670596, 65.30685932405534, 66.67506048756262, 71.22738684377363, 45.70678341773249, 44.80161413069695, 46.729337476914935, 71.45171503866874, 67.0404214243735, 64.58376253804853, 63.38358002324259, 62.09230438355477, 65.26610589796498, 64.78202658314859, 63.30778414203275, 63.33652727065548, 60.70033365680326, 61.02327808257073, 60.76784549220916, 58.53146299239128, 62.428067115045366, 60.745036909657145, 63.22695978226201, 62.72457084348125, 64.02282437970563, 57.29787365082772, 55.806784629821784, 52.86744671483194, 49.79745072703208, 49.32723306840467, 42.40648154289492, 38.01651777759675, 26.938879528353294, 19.1931103890942, 6.0095790509254705, 1.8266073398051725, 0.3232163256935535, 0.21696809709312456, 2.170672993506155, 2.0318046644810708, 1.809666255308736, 6.635755050566889, 10.147430512212939, 6.165058862778449, 0.6073888271085678, 0.9409846329400617, 0.11290450610460774, 5.021737477471752, 27.326849006837417, 39.04365708751064, 23.30864356410119, 23.711808304632864, 36.45273154781711, 37.6709020522333, 14.513026552815592, 0.9069428725108024, 0.057794848952682755, 0.033921814042954676, 0.08174198754732648, 0.031413257219678456, 0.04380610643795902, 0.045473933475272316, 0.04297439542208468, 0.029031045532094377, 0.15244423441829222, 0.0651166308671236, 0.021586092001187707, 0.006604678130843827, 0.03735754218313002, 0.05221158866920779, 0.03981868773999234, 0.025473128283216108, 0.04547866406820474, 0.0896018274849461, 0.00620621569161754, 0.04562759922156411, 0.05820791207013592, 0.05171804801530896, 0.07348709904979314, 0.016083757415594115, 0.0685188809650079, 0.03573712832745045, 0.05576819016207611, 0.06579641898673388, 0.028834651231825836, 0.11675760660681034, 0.03309137473303465, 0.04656818665323719, 0.026784711029200305, 0.06144868232490075, 0.050515132926164136, 0.015049823127957362, 0.014923045152587997, 0.04436900869252221, 0.044854892297617854, 0.05496637189700719, 0.033908491773951444, 0.02903051118576719, 0.05645795274646052, 0.02073180437418482, 0.13066570304574507, 0.048205113534124634, 0.029859709433249892, 0.03599511992727076, 0.027651926389925426, 0.06293992992610702, 0.024351462564100663, 0.029398323404752923, 0.041892798016628915, 0.05604865878159481, 0.042671430630669485, 0.037975445720216924, 0.034810659896221854, 0.03487656644034771, 0.030279839711804545, 0.0859974067838442, 0.03023923705181768, 0.08727780017521113, 0.049123691259733135, 0.05981015048981194, 0.10084652732456885, 0.07028233875790912, 0.0290588257954486, 0.1369723686647992, 0.04745829655157943, 0.05135002703736386, 0.05639871116727591, 0.022874866394446264, 0.037213801105897275, 0.05695890913146639, 0.05930273215316477, 0.04207459834193991, 0.031380353743330605, 0.01625708289324276, 0.2878427980167251, 12.231170054404968, 40.72688341140747, 44.87886128887054, 36.69685986734206, 14.871464506272348, 26.935990702721384, 56.65430292006462, 46.502424440076275, 10.438172278865691, 0.7903996939139982, 0.02614645062074546, 0.3494656542616506, 0.25024600657484225, 9.942456272340591, 9.330354717469985, 3.541948804932256, 0.6219228633469152, 1.5843020643918746, 0.5394122521242788, 0.7921607155473002, 3.1655983674910764, 12.40429170670048, 26.672499602840794, 45.55454838660456, 55.97850207359561, 64.09496853428503, 66.78307471736785, 65.38329847397344, 67.71455134114912, 68.17774403479793, 68.52843530716436, 66.53113303645965, 69.03106351052561, 68.81321507115518, 66.4162781930739, 66.01274474974602, 69.58720068777762, 70.06190946025234, 66.19930836462206, 68.96719947937997, 66.27902661600422, 66.08046839314123, 68.2920575910999, 69.24670757785921, 71.53061743705504, 49.348131456682765, 40.624309509031235, 49.83039471410936, 71.73767151371126, 67.70567893981934, 66.26573762586041, 65.13438094046809, 62.357519365126095, 67.56248889430877, 65.0446920241079, 64.28719212931972, 64.58405279344129, 63.01098231346377, 63.650752267529896, 60.67040989475866, 60.16764833081154, 62.85641347208331, 61.46479968101748, 64.39700672703405, 63.9856638446931, 64.87939550030616, 60.41022339174825, 60.81858919512842, 56.962083462745916, 57.17539371982698, 53.15604686737061, 50.19811299539382, 42.82267639713903, 35.71068971387802, 25.652373490795014, 11.699054452680773, 3.0382586198468364, 0.7128277144605114, 2.368967191826913, 4.549732688934573, 4.798366340898699, 7.469488661135397, 8.868794710405412, 6.348478697961377, 2.389717510631008, 1.5146335382615368, 0.17752255162885114, 0.10144235986855724, 3.6458952917206675, 29.62911555843969, 48.252915490058164, 29.00429571828535, 20.14606591193907, 36.19519656704318, 41.359808829522905, 21.26677336231355, 2.3220892298606137, 0.0641280556878736, 0.04671557047854989, 0.031194709571859533, 0.013990752537915064, 0.03336872920514115, 0.056318329391820784, 0.05011487879880494, 0.03749156926548289, 0.11161931700283483, 0.06723746867670168, 0.05310760127500661, 0.0730100407775852, 0.02456442160051196, 0.04701835523930289, 0.05488261933468523, 0.03808690385232049, 0.0534653107094909, 0.08251808057989805, 0.057948656425240545, 0.08561604055425814, 0.018549750393797314, 0.0386233415995394, 0.09866389686301832, 0.06362592335790396, 0.02074528943687197, 0.033421075993007233, 0.011090067864936447, 0.01682049268105578, 0.03605419679755165, 0.031108451902025172, 0.11512266006320716, 0.017616821926147226, 0.04213860498801355, 0.00830620776997098, 0.05021445873764254, 0.10019807220106164, 0.09790921598793038, 0.2138013807275603, 0.17385735717271605, 0.16762589074430928, 0.1578933412149068, 0.1708359830081463, 0.2075324832431732, 0.14700019912373635, 0.15891879586683166, 0.24110904444129239, 0.09607396809564483, 0.15389350423168752, 0.16427172798543208, 0.10862882384249281, 0.1501401024119508, 0.1343422356031595, 0.11219385230252821, 0.11517290010928147, 0.18964397781077894, 0.0809875671421328, 0.1726866522503476, 0.21239761653686726, 0.16870950679144553, 0.1728626686118303, 0.09393380188773717, 0.19202292596380557, 0.15167168071193082, 0.16118013420172278, 0.1872699172987092, 0.16590559434506202, 0.20967608918586086, 0.1820094826360864, 0.14378646028137979, 0.09449901389739207, 0.1064346177924064, 0.08903048677189697, 0.2222104674024928, 0.25670995004475117, 0.1465186975415676, 0.21217235604361182, 0.12354253325611354, 0.12256836819071924, 0.36481235657007466, 10.21569642328447, 43.92419953500071, 57.27871679490613, 55.15137226350846, 29.437821565135835, 32.39289014570175, 58.512686606376406, 49.78069436165595, 18.198024688228486, 2.7350679857115594, 0.4288615052017474, 1.6151268684094953, 12.67376442109385, 15.783909789977537, 9.798731803894043, 2.03969304119387, 1.7179052243309638, 1.0953159870639926, 0.2275329858304993, 0.48850711915762196, 2.538552337115811, 9.550935087665435, 22.006271539195893, 44.2762283355959, 59.81215607735419, 65.40974309367519, 68.48302995004963, 68.68905636572069, 71.661342190158, 71.89729629024383, 71.35461284268287, 67.76627955898162, 70.27894989136728, 71.92821241194203, 68.13975980204921, 67.24682438758113, 69.1884054676179, 70.38675231318321, 65.9193923396449, 71.1018866877402, 70.75437253521335, 70.20672336701425, 69.97495835827243, 71.75496916617118, 72.68083680060603, 52.86274771536551, 47.18089642063264, 54.28042565622638, 71.78845051796206, 72.57446996627316, 70.01448800486904, 68.17514742574384, 65.51533722108411, 69.89613440728957, 67.16992239798269, 64.68715229342061, 65.59260399110856, 63.123326839939246, 62.83276942468459, 62.18245613959528, 59.25836055509506, 63.79745675671486, 62.06783271604969, 64.00604448010846, 64.8653063466472, 67.2282401977047, 59.37656510260798, 59.12574914193923, 55.21826436442714, 53.61851392253753, 51.46873343375422, 45.00035670495803, 40.972082537989465, 30.885336975897516, 21.662491483073083, 7.801472679261239, 3.4129699968522598, 1.1439788726068314, 1.7735741984459663, 5.054568206110309, 7.256957975126083, 9.184727899489864, 13.211967541325478, 19.513646479575865, 13.353102264865754, 2.59502122959783, 1.6473427655235415, 0.49622545499474774, 5.993678742839444, 34.1374780285743, 47.51498037768949, 31.2013505735705, 32.15462184721424, 47.26604715470345, 49.15403296870571, 24.252203049198275, 1.9517812036698865, 0.15617394879941018, 0.14709530127865655, 0.08848155413063304, 0.11449835969195252, 0.15409121620318583, 0.14774287540105083, 0.11328182738995361, 0.16496349005929886, 0.20044644573523154, 0.3444435189087545, 0.17457250025003188, 0.17753341475561743, 0.19751360069119162, 0.15178952035644364, 0.13302013638519472, 0.18435760341104002, 0.13402521309833373, 0.21301814775553443, 0.1769118723008902, 0.30031624159985976, 0.09091837256545983, 0.08679387009432239, 0.15258246732334937, 0.16416164115071297, 0.15835369877036543, 0.10237208417346401, 0.2147451704067569, 0.15210787585425764, 0.07776936966805689, 0.26829008914289937, 0.192448916814981, 0.09455654710050553, 0.13409249093984404, 0.11658416430075323, 0.11971956299197291], [0.07711927511639173, 0.05937910345833629, 0.07258465513586998, 0.03603538167813132, 0.04787072764649507, 0.05963861957312592, 0.0076445328417204085, 0.04917186669885151, 0.029192259159660148, 0.06839726450702838, 0.1165829768644706, 0.002471404431778337, 0.015691614244133234, 0.041853681567215154, 0.008012827696098436, 0.08236612704011702, 0.025494373816576217, 0.06300275296633763, 0.057042860876648664, 0.04896693434866686, 0.07671863411463077, 0.032530682642133005, 0.030836605602094246, 0.10123784503629131, 0.013072581796516335, 0.12651044214444776, 0.07183958100335253, 0.08925549445613738, 0.04639334240627866, 0.05202590044768107, 0.08548285616862197, 0.04866625632970564, 0.1312656264992491, 0.06717705498299292, 0.06474122480158845, 0.04110598741399665, 0.05114520960036786, 0.014725087075344017, 0.055083525892827785, 0.03206269485094855, 0.025860983277520826, 0.02431791365867661, 0.06881573237478733, 0.06506697304787175, 0.08551942154524789, 2.5004082677825807, 24.798677467530776, 37.97370118479575, 37.9829462112919, 35.78173168243901, 25.873883462721302, 29.269067472027196, 41.69401045768492, 21.2219661666501, 4.4970292718179765, 0.26611246889637363, 0.25206387193212587, 6.470201611518861, 8.17692489393296, 6.187760070446999, 0.6157602682229012, 2.96514539468673, 1.3212535794704192, 0.4054883771365689, 0.13085175515903583, 0.17596137169147694, 1.5093220361778814, 7.0964737092295005, 20.713915286525605, 37.10388422012329, 48.91443498672978, 65.29965393004879, 65.21709196029171, 64.86270973759314, 69.42162959806382, 68.65321374708607, 70.13186100990542, 63.81397777988065, 65.15067446616389, 65.29779472658711, 67.11178502728863, 67.33453642937445, 65.82137230903872, 65.96984970954158, 66.44371909479942, 66.48905384925105, 64.36892647897044, 66.06441805439611, 63.897084959091686, 32.938028996990575, 38.92995149858537, 35.639988991522024, 63.181766233136585, 67.98201776319935, 62.534696748179776, 66.01824391272761, 64.66134702005695, 66.60142190994756, 64.59045802393268, 65.35563399714809, 65.06185631598196, 62.018591280906435, 65.06705345646029, 63.91683801527947, 62.87085171668761, 61.484850837338364, 57.16377958174675, 49.602238285926084, 44.04981736213931, 37.58743009259624, 32.26896874366268, 25.834006686364454, 20.504835305675385, 17.261364652264504, 13.69278540534358, 11.523885323155312, 6.3700938993884675, 3.0088207414073334, 0.6991619929190606, 0.417828276272743, 0.20828732499672523, 0.631002966434725, 2.1786216766603532, 4.229375556592019, 4.406391141876098, 5.1335451295298915, 8.911658371648482, 5.932171565871085, 2.556850439117801, 1.3379600572009243, 0.27466970165410354, 10.359134558708439, 33.025705737452355, 35.76056657298919, 26.464329611870554, 25.522256705068774, 38.900698461840236, 30.823659666122932, 8.41609239578247, 0.2534085707438569, 0.1109510661673642, 0.13455609670810162, 0.08235654328018427, 0.030625094471859838, 0.028948583827924826, 0.058448697335176894, 0.025702776545057857, 0.04969724596688344, 0.07736607800207793, 0.03381515928213635, 0.018400648616314418, 0.021193096556911067, 0.11075945991662242, 0.03354995113406931, 0.01940843536548557, 0.024689537165085637, 0.00694693700831023, 0.04478271532383177, 0.037071431326048995, 0.03678801709846143, 0.05396227577641126, 0.029610430168348457, 0.09065909776836635, 0.026678483362399766, 0.033601650577639385, 0.019677931690708767, 0.04458353629395847, 0.013370032670096526, 0.07109193281540949, 0.018354206451124722, 0.008020878322572719, 0.03456771809367403, 0.05182036671847586, 0.022172605085577217, 0.050574117865894115, 0.03301981062958798, 0.11839076050467069, 0.07295250757447175, 0.03521109788468288, 0.11188606115719003, 0.05739983486672563, 0.008630011110536514, 0.05899053983270161, 0.04241852202422677, 0.052986375521868474, 0.029850263569143512, 0.02805605117652205, 0.050485040992498405, 0.02112976598343061, 0.09022963653889396, 0.05246098093207806, 0.03555314082111563, 0.07337344990622613, 0.07637572549884358, 0.06718723629150661, 0.042831301689147956, 0.08338764400011109, 0.036832745141920545, 0.012127856532442234, 0.06411815400145228, 0.07330695347439858, 0.1878875527050226, 0.03312443525740697, 0.038493443731098406, 0.04350649328121255, 0.07667282971763804, 0.058479474917534864, 0.02317883859148189, 0.12968887965525353, 0.05210118773843973, 0.09519043889257217, 0.022102056048630227, 0.04259249676139124, 0.034197126890742974, 0.043845207565614296, 0.011525321676726303, 0.045459626783286376, 0.03119348191596087, 0.02810811259663634, 0.0569702050979099, 0.09655742320202051, 6.272577893349433, 35.79390671945388, 48.36063946447065, 32.16599868189904, 20.87609744841053, 31.025704876069103, 47.99829875269244, 56.78614162629651, 22.899416800468202, 3.216042744536554, 0.11419767784255166, 0.23376929393458754, 2.0047867658638188, 2.527767780327028, 4.592115859831534, 0.8968544751405717, 4.088451905596641, 2.7273308653985304, 1.2663970262773576, 0.7165989508071254, 0.652356778662051, 2.6011408625110506, 12.255793713754224, 28.467409533839074, 44.600733864691954, 56.206529063563195, 66.65488381539622, 66.00555896759033, 65.75360944194179, 68.3065938949585, 66.92833577432941, 69.60121139403313, 64.99156744249406, 65.78489426643618, 66.03409028822377, 66.75930515412362, 66.33117844981533, 65.42970011311193, 66.3674525291689, 66.05059562190887, 65.76357618454965, 63.08929635632423, 68.00620309768185, 64.98644874941918, 37.42968805374638, 43.34895649263936, 40.449058009732155, 66.86597793332993, 68.09289532323038, 65.06440977896413, 67.60696857206284, 66.77965441057759, 68.91339240535613, 66.21129512786865, 65.15337305684244, 65.19982568679318, 62.11512081084713, 64.2984454093441, 63.17378420983592, 62.35546796552597, 64.6127410088816, 60.53119321023265, 55.921172711157034, 51.34277436041063, 45.32544274483958, 37.89364953194895, 30.957155573752623, 26.35354618872366, 22.828923963731338, 18.158597023256366, 16.69984794432117, 10.334776639938354, 7.315502291725529, 2.2844119225778887, 1.2375250723092788, 1.169105330782552, 2.08072078804816, 4.8882592205078375, 7.537599638585122, 7.186674985193438, 4.430689734797324, 4.6391078156809655, 0.6101844351618522, 0.6958616248542263, 0.38559463656237053, 0.4076949248631155, 8.505253753354474, 39.31060967906829, 45.012598422265825, 30.445590249953735, 22.485363560338175, 38.939514237065474, 39.27244893966183, 15.245809631962931, 0.800711605097017, 0.19955917802308837, 0.08034322591077897, 0.08208365510067633, 0.057249689294445905, 0.047335764618530396, 0.05004732133520227, 0.029525250767267523, 0.02560579364428357, 0.047793142091963565, 0.013856984967846545, 0.052807019017035925, 0.07416730851776178, 0.040513843583363685, 0.016992584757146337, 0.015032873432632658, 0.038845786719673106, 0.03385268609910723, 0.011071564926345263, 0.04404260927150327, 0.04614671955125467, 0.023147352377793962, 0.03186408464135903, 0.0174084747390401, 0.05080158086193185, 0.055063389271738074, 0.03493615658953786, 0.031178725147319418, 0.07473408334678219, 0.059012258425354965, 0.06316615185970742, 0.022545553924095248, 0.06544512170817583, 0.03145630944580321, 0.061488223953112486, 0.026191619164761037, 0.040715075728874055, 0.16821398580026242, 0.16949801044839044, 0.13531133682737428, 0.10239554944658473, 0.12218814343214036, 0.14900577134422718, 0.0782671123142204, 0.1823524448780283, 0.11782544890358565, 0.1522182078371125, 0.13516521321669703, 0.1815637267164646, 0.10020299048553552, 0.18507487621278534, 0.0951801196882321, 0.16171878594304287, 0.12171287780567525, 0.067471370641743, 0.13601324190535855, 0.187153548543011, 0.22484954837108814, 0.15208152242966239, 0.10676184458838356, 0.140459003347543, 0.1711706255352305, 0.3660071472967825, 0.13621507542988948, 0.12939880812360396, 0.09484421311607284, 0.2588175345332392, 0.18329246540463742, 0.08836092592607583, 0.41669262753378966, 0.1642112530046894, 0.19749336064823214, 0.11455907982083098, 0.16625647793614096, 0.24527751269840428, 0.18336620902822864, 0.14088919236054345, 0.12362192294770673, 0.20219461241316414, 0.24166317115868294, 0.14695524508433958, 0.13370252154286832, 5.26587805440349, 39.38957875774753, 56.37396327910885, 49.61459375196888, 49.56891382894209, 37.55965578940607, 35.97712455257293, 52.912942286460634, 27.83955377917136, 5.438741320563901, 0.5376962151738905, 1.865448610436532, 12.251447727603297, 17.151442189370435, 13.738837953536743, 2.172417712788428, 7.504568378771506, 2.7654023708835727, 1.0607775565116637, 0.47807551439731355, 0.41616954269909096, 2.4865122908546082, 9.510047320396671, 25.56223350186502, 44.1180822926183, 53.49080939446726, 67.75103722849201, 65.78406272395965, 65.80522391103929, 69.49803736902052, 68.23536365262925, 69.21620722739928, 63.799943539404104, 66.62126910301947, 66.61959817332607, 67.96700293017973, 68.75330478914323, 66.43395239307036, 68.61209946293985, 68.80505654119676, 69.65821912211757, 66.64067699063209, 69.75143817163283, 64.37031107564127, 41.23023725325062, 43.804029880031464, 44.521984438742365, 64.0353641971465, 68.87084253372686, 66.89275203212615, 70.46800813367291, 67.17579810850083, 72.04848797090592, 68.18762840763216, 67.59973572146508, 66.5027036974507, 62.74011519647414, 65.52135413692844, 64.42146270505845, 64.17183130018174, 64.32466645394602, 59.514361889131614, 51.37783642738096, 47.15784857350011, 41.404147301950765, 34.76688115827499, 26.978048316894043, 22.455000492834277, 19.13942490854571, 14.619159025530662, 13.330671210442821, 7.583954699577824, 5.217194086120975, 1.3591537264085587, 1.1033244863633187, 1.1294826504684266, 1.8074309946067872, 5.558145132757002, 9.919328997212073, 13.67509453527389, 12.621577285951185, 18.99774105318131, 12.64742668597929, 7.580693739075815, 1.8210334066421756, 0.9447692298600752, 13.242708136958461, 43.24484502115558, 45.004467348898615, 36.594152604379964, 35.59217529912149, 50.28531905143492, 44.37653510801254, 14.016077941463841, 0.630004110355531, 0.3657876477847177, 0.22127168793832103, 0.16848504302963135, 0.14954309009255903, 0.12566892520314263, 0.12125861064921464, 0.10854923496803931, 0.16501576789925176, 0.12503271982554467, 0.11570222856056307, 0.16279233559485407, 0.1569059151675432, 0.23204979426678152, 0.13970033115436956, 0.08189608613329549, 0.13882529020549791, 0.10538412738711604, 0.14022790526430454, 0.27598682130056046, 0.1391441972866174, 0.13688391615306178, 0.10431532748043539, 0.13847295104736282, 0.12056245889154174, 0.17506141756330768, 0.19159696575614715, 0.15110106778240975, 0.15051088896730255, 0.2189415089425541, 0.20861300429509533, 0.08150177301778909, 0.15368811605918795, 0.16929985414589607, 0.19988517907838668, 0.13702184262294925, 0.08984717480357617], [0.06577788731984555, 0.03901476273313165, 0.029792203680582108, 0.04082037068362679, 0.1066363900299034, 0.06659181743499733, 0.06158647472940146, 0.04423158784066478, 0.03911434650240887, 0.050382373719325954, 0.020025176364147378, 0.03434532659969503, 0.0685938886336742, 0.11058434753889039, 0.015776432626279854, 0.04111915646541504, 0.06463246329897834, 0.04365846214275207, 0.011341479727097098, 0.015345350163237704, 0.08069569530386118, 0.05664732968134265, 0.05534403026103974, 0.05365056226090078, 0.0006943735359292929, 0.10080864427671318, 0.08931950876309026, 0.06924586776163309, 0.07177314585855893, 0.08184464332918007, 0.05662683682936815, 0.10773797083886401, 0.04515622532175434, 0.03483686393367187, 0.05118875020754434, 0.03697185904809064, 0.01847648557515875, 0.03125912415975284, 0.03995947171783736, 0.11102009835022111, 0.0662745114776396, 0.027110698677959944, 0.09070232810993349, 0.03783274269212158, 0.02026082884009567, 0.08625398495144422, 1.497129471071305, 8.205020341180987, 38.75710441220192, 39.68302303744901, 22.66988362035444, 23.052863843979377, 23.870929056598296, 45.372687693565126, 30.949363785405314, 9.915117352239548, 0.41811399642498265, 0.09410315328427861, 0.8866447294431349, 3.369483659344335, 0.35719692166293826, 2.996496654325916, 4.446524343182964, 1.0443721206918841, 0.6439980852507776, 1.1150159686803818, 0.5231307999741647, 0.16888081937307314, 1.9161796882267923, 7.408040810015894, 17.709352277940322, 30.673874155167614, 46.516615575359715, 55.42066651005899, 58.842954097255586, 61.73620808509089, 59.661356633709325, 65.0666690641834, 61.982148539635446, 69.1127037232922, 70.02212878196471, 69.48111626409715, 66.50679080717026, 67.24564767652943, 66.59778195042765, 69.0400065145185, 70.49814762607699, 69.29171285321637, 53.578533203371116, 28.13230379935234, 40.04552848877446, 35.16707274221605, 59.350269532972774, 74.36572228708576, 66.35926262024911, 71.21499999876946, 69.32330362258419, 70.68200480553412, 67.12887871649959, 68.63210355081867, 67.68917360613423, 64.73598580206594, 62.59530913445258, 59.6256003072185, 52.90435229578326, 41.73190447591966, 29.772387973723877, 19.189482196684807, 11.489691080585605, 9.200261465964779, 5.965875512169254, 3.60887473629367, 2.3826844557639095, 1.521883916950995, 0.542062058323814, 0.46833648376407166, 0.18945193488992032, 0.5706182614930215, 1.230833141073104, 1.9032233641032252, 1.3585817958078077, 2.1686399800162164, 6.284853441099967, 9.452432605528063, 4.776203478536298, 5.200840744280047, 4.512043614541331, 0.78453550535825, 0.04081301240911407, 2.2933183994985398, 20.339895717559322, 33.9702909223495, 29.017098334527788, 19.26693331810736, 27.639140275216874, 40.18196029047812, 25.758912909415464, 3.0536671607725085, 0.10448186733429471, 0.028931733724030278, 0.046031396505573106, 0.036529286223794186, 0.09341189682844186, 0.04922459653067974, 0.036584984646329, 0.04085058902180003, 0.022852937127613736, 0.031133395724839745, 0.05193359068324489, 0.05012243242573835, 0.04533083591189596, 0.015385116829777197, 0.01423938254330067, 0.01154340613978885, 0.05325462886943452, 0.0678680279862977, 0.03696703269416767, 0.027091701612657598, 0.009847672434613831, 0.05117116082880286, 0.04326859616764611, 0.021630140141614025, 0.061444602906703956, 0.04021194365416323, 0.042713304996610656, 0.019877432477510264, 0.03421992183692994, 0.03576318680819485, 0.09477586275146854, 0.0551961025133008, 0.0483886452181445, 0.05900661618779263, 0.06604568867553627, 0.014601740216265523, 0.07647874134202158, 0.11090189098350464, 0.06833038503123869, 0.0321469108964647, 0.033622059159942215, 0.06400491854536437, 0.0681784391523369, 0.050338369628955285, 0.023477515205740932, 0.045892566051935, 0.01596122260971536, 0.06921169257933094, 0.0476298542813428, 0.029742865703038635, 0.0870294880963141, 0.0549851831859879, 0.030997974362464684, 0.045631483287340215, 0.08357456179275628, 0.02347713599221841, 0.055820605897855376, 0.013367526604974223, 0.03979587747204689, 0.02111347895416041, 0.10973215899280003, 0.022554666539954565, 0.011824578602587985, 0.09602447881573632, 0.08932002970287878, 0.05386823465326621, 0.0638771887057491, 0.11062437563293404, 0.06044233390580743, 0.04148898924130105, 0.004996425920962206, 0.05233597836547321, 0.09446712931798351, 0.06231612751200315, 0.031965198671264995, 0.10437553433040458, 0.0611256460298694, 0.015150572308489393, 0.07945660937337146, 0.030341302945969567, 0.05915400384354496, 0.09121009884702583, 0.051497246153772845, 0.04233185832779254, 3.719809415840334, 16.979340353319724, 47.61826030669674, 42.31260745756088, 19.92600917816162, 18.91044282144116, 38.77965804069273, 63.1565728495198, 34.453079777379195, 7.415821811845226, 0.04837780890445556, 0.39292015315544226, 0.5548303538272458, 0.6466705063658377, 1.7226932125706829, 2.8732991747317778, 4.379347870426794, 2.4735660178046075, 2.0911148238566617, 1.2784264452995793, 0.8752534923053558, 0.8851619509439316, 3.675333660456442, 11.270691425569597, 24.788049805548884, 37.88985659999233, 50.330963673130164, 58.25654014464348, 63.82086546190324, 64.6206602742595, 63.386510033761304, 65.0713445294288, 63.45611249246905, 69.19319075922813, 70.78029940205236, 68.62203090421616, 67.00199004142516, 66.35363009668166, 66.71078543509206, 70.145691287133, 70.20208712547057, 71.43593142109533, 56.27728077673144, 32.81004598063807, 40.6474514930479, 38.90731157795076, 63.134842918765166, 74.2985713097357, 68.04158287663614, 73.10729257522091, 72.85730423465853, 72.51732103286251, 69.27037515947896, 68.18748720230596, 68.05685658608714, 65.04179339255056, 64.9263031251969, 62.897217888985914, 57.62130052812638, 47.510406894068566, 37.745850701485914, 24.916054394937333, 16.717782981934086, 13.319187491170823, 10.267927685091573, 7.474384269406719, 4.715617077965891, 3.940915138490739, 1.644546238164748, 1.6886543939190528, 0.9315814858963414, 1.1729648204580432, 3.9992903028765037, 4.205352019879126, 3.825483216393379, 4.21268440062, 6.500139101859062, 6.3882074048442234, 4.5450376118383105, 1.9636399995896126, 1.1692317046465412, 0.14684285998584765, 0.09514091130826743, 2.16665378982021, 17.217004606800696, 45.01458706394319, 38.865616783019036, 21.418618117609334, 26.643991816428404, 40.45457678456461, 35.48803244867633, 8.145762643506451, 0.3141092256672921, 0.08874836723290144, 0.07783440287194907, 0.05237686064755244, 0.0587004414879747, 0.012139597787491739, 0.10310166800815253, 0.07874140500902169, 0.10787002907525148, 0.05503536194502827, 0.018736501562318975, 0.026644689308839942, 0.04100556860888197, 0.08035689291934814, 0.026686674757530133, 0.03153944339212631, 0.06096553365369478, 0.01975816024857904, 0.03216244715956911, 0.021746888110834747, 0.0189502707367102, 0.06500261400135295, 0.05379905691370369, 0.131609094359221, 0.0722557582682179, 0.0527636316274443, 0.03875801985662791, 0.029699930305322333, 0.042134353200033794, 0.036587547210435716, 0.05166397752961324, 0.053555498410376816, 0.040260073128006155, 0.028040505337318587, 0.042351198217441, 0.03562155247275387, 0.05817949403858474, 0.05867265164852143, 0.2178337764475615, 0.12446321006263457, 0.16185153365856217, 0.16494252989369054, 0.18076319547910846, 0.15807183970126415, 0.12515435926616192, 0.16175134467982477, 0.13908324733136163, 0.15926002675006468, 0.1349478434290617, 0.1369957956335237, 0.1633094449437434, 0.2321937728312708, 0.07589486743053121, 0.17218674923623764, 0.21821418506724222, 0.11912076568771755, 0.17502076893804536, 0.07487972432206716, 0.13713451883485242, 0.19068352848051057, 0.1973389020009387, 0.16829730552290717, 0.05781629941456261, 0.20210706388517735, 0.31708921576219223, 0.15521810089628543, 0.20041471437340785, 0.2234822959308663, 0.16933555384316754, 0.27351937467052095, 0.13727673539711585, 0.16601448608261926, 0.21622238710762995, 0.15215085338680975, 0.09298894734632585, 0.24752293172622883, 0.1427320475059171, 0.15521117546144994, 0.17329742350885946, 0.11800673594998738, 0.14164743554447928, 0.18727964661534757, 0.1719710801637942, 0.1767472706494793, 2.8549611135836575, 18.36160125270967, 58.543814536063906, 55.02096522238947, 34.281056388731926, 32.39482779656687, 31.123681760603386, 56.83583021163941, 39.43829851765787, 11.808232645834646, 0.6712863822617839, 0.45204280485068604, 3.0371297126816166, 11.721606119986504, 2.9053540095206234, 6.725998492010179, 10.097695839020515, 2.9147708848599465, 1.6009391651999567, 2.0408856868743896, 1.085769305786779, 0.629174712925188, 2.70095611291547, 9.197488350252952, 21.77144512053459, 36.28716045810331, 50.27841175756147, 57.65532708937123, 61.11159024700042, 63.42756155998477, 60.51864947042158, 65.78036000651699, 62.18419374958162, 69.93730360461821, 70.45622533367526, 67.09484823288457, 66.58318288864629, 67.61864939043599, 68.18222338153471, 71.16178128027147, 72.98742494275494, 71.73891882742606, 55.854990559239546, 37.57971086809712, 44.80545805346581, 44.473958938352524, 65.51568631202944, 76.39593324353619, 70.69032023029943, 74.85652062200731, 74.06560605572116, 72.55748610342704, 70.330364319586, 69.8319330523091, 70.07282933881207, 67.3452837236466, 64.7857096887404, 61.206997979071836, 55.778849509454545, 44.77833878609442, 33.0553823901761, 21.143448160540675, 13.482021747096894, 10.82055728281698, 7.728711731972234, 4.903828578610574, 3.1683516262039064, 2.4074858475115994, 1.5498098442631385, 1.0013591642341306, 0.35555501138010337, 1.4422533060273817, 3.992130751571348, 5.840884283665688, 5.138857979928294, 6.725840126314472, 13.68930136003802, 20.458408171130767, 13.389182186895802, 12.970688823730717, 10.43638171688203, 1.9092712911867329, 0.221957934179133, 3.538091399015919, 24.52051474202064, 44.77452231991676, 36.33757468192808, 28.339961921015096, 37.82694178242838, 51.98540372233237, 39.1115140914917, 6.841326961594244, 0.4502561652371961, 0.16487655440165153, 0.17017700949743872, 0.1282173626485371, 0.14759875894073518, 0.09924970897695712, 0.16500354113598026, 0.22499712754882153, 0.16139315260994821, 0.18059666328612836, 0.1323023579654194, 0.1504543976437661, 0.10341363433267801, 0.16671032374424322, 0.1178620219410908, 0.11068848953131707, 0.15591557798606737, 0.19907767644091962, 0.12230160871460555, 0.05540966484395247, 0.14565879449007973, 0.14029152120553678, 0.1472693258115361, 0.24242763497656394, 0.22443550849153152, 0.13531938075057923, 0.13227876245735154, 0.15802072631495614, 0.20024795235405046, 0.09962111606352753, 0.20042280426188824, 0.18082434461722452, 0.11244288450407405, 0.16232431716015264, 0.09144736393805473, 0.22462732158601287, 0.1662284237963538, 0.2833688751824441], [0.06175084655443507, 0.0574027460008379, 0.055454864031485016, 0.03128126027032493, 0.013021361157898943, 0.07387791880436483, 0.02610610268499342, 0.015289733137544847, 0.009935152014687417, 0.04547061631456018, 0.03300483744110792, 0.057467844322203636, 0.022297496569433042, 0.11983977750905099, 0.05917243208856352, 0.09407068647804762, 0.023452730346170646, 0.079902671728163, 0.04941451355754849, 0.03213217902568079, 0.027721529308285926, 0.015130496016823718, 0.07876831001692242, 0.03617967433866955, 0.13661348711579077, 0.021074161406666524, 0.03205887207220639, 0.05622529184385654, 0.051749446128885594, 0.018408529745835452, 0.09885768646434431, 0.06359100123987564, 0.059045131258185835, 0.09266954230805559, 0.08842756025372975, 0.010197080348828628, 0.02759608624112462, 0.036029444496718147, 0.08726320620025359, 0.06243270694188053, 0.07557647362832101, 0.05670310854310951, 0.021010706343898372, 0.0655693581868564, 0.06113653980015267, 0.04449117673380722, 0.1507238001232186, 0.29440912147683485, 15.053446792787122, 36.5558781162385, 41.790806708797334, 35.16846126125705, 25.075512470737582, 28.61887578041323, 36.78592512684484, 41.25866266988939, 19.603068674764327, 2.9745365294717976, 0.16247604853443562, 0.6592537763137972, 0.8845117568008362, 1.4052589814509115, 2.7946078488903665, 2.156073441428523, 3.1206619787600736, 1.1741589370273775, 1.3165300651904077, 0.9507936227225489, 0.1646702469236428, 0.11526983321434069, 1.7999829039458306, 5.731675201846707, 12.870661520188856, 17.577950915982647, 21.532362930236324, 22.939695619767715, 22.022961224279097, 23.88896607583569, 29.562084213379894, 36.470315533299605, 48.594377425409135, 63.61951058910739, 68.21728152613487, 65.15732680597614, 63.01501058763074, 62.29300814290201, 53.60954346195344, 47.14973711198377, 47.18219864752985, 28.373298145109608, 47.8937558204897, 36.250474529881636, 42.37944072292697, 72.33722148403045, 65.81800691543087, 71.42800823334726, 69.65417123609974, 69.23177903698337, 67.21510025762743, 68.5445248696112, 67.84523687055035, 68.55280107067478, 62.60029838931177, 48.70398805987451, 30.03718718405693, 14.531919629343095, 6.598601379702169, 1.7058368267551547, 1.3800415733168203, 0.4622148896657652, 0.4910267210535465, 0.29883778383654935, 0.1402144221168372, 0.2028262365849749, 0.3506733765525203, 1.0473270137463848, 2.5598120737460355, 0.6943857717898585, 3.7279272512082136, 3.9022172795188044, 1.8923112077097741, 4.48502387731306, 4.675326981852132, 3.2646058547881345, 4.287031946643706, 0.541339239045497, 0.07103494353472226, 0.5062541281504016, 8.515118514337848, 28.466144569458503, 29.377560230993456, 27.044967874403927, 21.473943148889852, 31.558180355256606, 37.03659988218738, 20.75384109250961, 2.3477202028997484, 0.14266057150258174, 0.07060150630892285, 0.023627256666640603, 0.050500259329114235, 0.01720709129116468, 0.03772871944332316, 0.06284911020268356, 0.01707873708989111, 0.10681023836256036, 0.09658998959968168, 0.02478915732353926, 0.028747282734501268, 0.03502020792615029, 0.027178307852497505, 0.03743167268112302, 0.057952260868924285, 0.043870105423153415, 0.01559811991624414, 0.03605983520467435, 0.028830250056700844, 0.063582225702703, 0.030877116331530195, 0.043543411058283625, 0.0499954073870134, 0.03684966419372828, 0.04424299872029693, 0.06968521918620794, 0.012320191524321995, 0.03682603804214347, 0.029169000730278994, 0.03423432812034603, 0.052078994171273325, 0.03374392459649713, 0.12350159351743999, 0.043572526229845907, 0.03587173763662577, 0.02479552925984946, 0.09388389892034954, 0.03689962078727061, 0.07839875686312876, 0.007000012058509334, 0.030284215989071998, 0.07883016395592883, 0.06156926073374287, 0.02730054292647589, 0.022287562324274934, 0.06275161019256038, 0.03587890438915741, 0.04484374954875919, 0.015034347194276992, 0.06172443950368513, 0.049045772456954566, 0.07919522017360696, 0.05605302548276321, 0.06341296240627285, 0.042514685210922075, 0.029084995358942017, 0.01895220702393882, 0.04520170796181887, 0.08257981194483657, 0.03819911658102947, 0.04940128704953579, 0.02999955686860748, 0.06965383256395018, 0.07533359311280713, 0.0330444403563536, 0.029377872687614257, 0.04224639355895981, 0.03001112862670374, 0.11227772360847843, 0.05047665999060677, 0.026722096747929053, 0.010429703904646299, 0.10749934977220912, 0.03676735570714359, 0.05787186760215029, 0.05112984187660679, 0.06689015505534988, 0.03575191382438906, 0.04965840530912242, 0.06045049274220102, 0.022070475989171577, 0.11620323474128401, 0.07562555688162965, 0.12414265589247789, 0.26410449115980056, 0.7092299204199546, 23.97222426629836, 47.26589025989656, 42.75200313137424, 23.40115070343018, 13.751998486057406, 31.397235701161048, 49.50871329153738, 54.70428089941702, 18.171352571056737, 1.507851024789195, 0.070979310229661, 0.3697750435000466, 0.4507663185077329, 1.3440920700950008, 1.8218504853786963, 2.448988446304875, 4.215755126168651, 2.915625226113104, 3.327927863405597, 2.400096347255092, 0.5886793665347562, 0.720488777564418, 3.6274040129876908, 9.118471222539103, 18.10573131807389, 24.113378601689494, 27.178865824976278, 31.7903160279797, 30.37982386927451, 32.75759408550878, 37.52865337556408, 44.581192616493475, 56.08038563882151, 67.29349274789134, 68.06021413495465, 64.306592172192, 62.75557717969341, 62.60377360928444, 56.22045740004509, 56.22104967794111, 48.70700828490719, 31.97024299252418, 50.435843929167724, 40.560963230748335, 46.25489542561193, 71.2198402035621, 67.47167818007931, 73.30074387211954, 70.2615894809846, 71.76120573474516, 69.40136663375363, 66.4226245880127, 68.70342008529171, 70.15756037927443, 63.209524846846065, 50.99563675542032, 34.01424500250047, 19.52702372304855, 9.084093609163839, 4.46284189339607, 2.2121204339688827, 1.672605771210886, 1.3135353355638444, 0.8827553316950799, 1.0443506702300043, 1.3755236157486517, 1.3788343413222222, 1.6536441757794351, 4.263764446781528, 3.4991778096845074, 5.986354206838916, 5.268184408064812, 5.519619122628243, 2.8926644065687737, 3.142864064824197, 1.0251765926518748, 0.2881736560694633, 0.3267137009289957, 0.10192439771227299, 0.25599535855074085, 6.149175715061927, 33.16694244261711, 46.120314982629594, 28.868430699071578, 17.651136459842807, 25.71767899297899, 41.9919458512337, 30.24731836011333, 4.965708871041575, 0.3259684505962557, 0.17454786286238702, 0.06560865849737199, 0.039714568730203376, 0.023678199598385442, 0.03677953650513965, 0.0603510698513879, 0.03070810967455468, 0.042232312862911535, 0.025809025279276317, 0.014700759953308492, 0.009821269214303504, 0.026084575614321138, 0.019821324197935964, 0.0868782010530272, 0.027871314819241245, 0.017504036546714844, 0.01903358088325589, 0.03361074787174021, 0.024563915982481935, 0.04252703071782186, 0.01763493799033665, 0.01929549485324852, 0.036845879719382336, 0.08581797367021923, 0.0516620546489233, 0.020838692791820056, 0.13737661794068354, 0.07063110794631705, 0.05782278817928126, 0.05110792027065351, 0.046939804413986784, 0.0592851274526648, 0.021376588021314914, 0.048506285679797013, 0.030636365540445815, 0.016048738578965348, 0.047851380095967365, 0.04189887692430808, 0.2200152577772256, 0.1462395351019598, 0.16572400086349057, 0.24776450989227145, 0.09135580877022398, 0.1579513493925333, 0.16575000188764066, 0.16866496643952786, 0.09114293591870416, 0.14491047980564256, 0.1587135149466415, 0.1454255513606533, 0.09299930485506212, 0.1757545279519212, 0.24376640426776103, 0.17034783178279478, 0.09484088829448147, 0.1290024648750982, 0.09719300038752057, 0.20115429565550821, 0.15040147628995681, 0.16365798430577402, 0.1667114728761296, 0.09944534485018063, 0.32913876757506405, 0.19485392727919165, 0.14358931521494545, 0.11525488683893798, 0.167781621097557, 0.06276753333006656, 0.16952470095167238, 0.17455446654029433, 0.16499261672218002, 0.18291585658106113, 0.24887153758637368, 0.1460342541817696, 0.13368215892584095, 0.1641248995738645, 0.15314059301970467, 0.20524831548813852, 0.14667202237873309, 0.2465600511359592, 0.17955101455651945, 0.2112835561556201, 0.14886067429136846, 0.22976532007657716, 0.2774112545434506, 0.7027955785874398, 24.056313999237556, 57.32452223377844, 57.924586034590206, 46.256362392056374, 35.129178723981305, 36.48895463635845, 43.60852718353272, 51.36002494442848, 25.81273763410507, 3.738146741544047, 0.6344261537155798, 1.3832440659884484, 2.5380769948805533, 9.563957356637525, 9.574648757134716, 5.845778421048196, 7.880779081775297, 4.443181503203608, 3.656988980308656, 1.7931782045672018, 0.39259919295868567, 0.382092266433662, 2.351310152199961, 7.064924615044748, 15.464334680188088, 20.717931793582057, 26.062043482257476, 27.76537391447252, 25.587034648464574, 28.20958822004257, 32.59934017735143, 41.1050195078696, 54.89768905024375, 68.33645882145052, 72.7881371590399, 66.78943680178735, 63.374601717918154, 64.24339886634581, 62.24602599297801, 63.4903077156313, 52.586452038057395, 37.67245531082153, 54.81868467023296, 46.534121113438765, 49.71912099469093, 70.69652541991204, 69.0291964623236, 72.6619545105965, 70.25725133957403, 71.02179973356186, 70.6653190428211, 66.59085504470333, 67.7512804154427, 71.39896700459143, 64.60071502193328, 50.983775508019235, 33.36721866361557, 15.986270750722579, 8.41745836119498, 3.101515173912049, 1.854536331469013, 0.7671307231630049, 0.7960331367869532, 0.6401672779071717, 0.4263983180205669, 0.8730707545914959, 1.1327289020822895, 1.724234826622471, 5.764897186909953, 2.4767867740123504, 8.126465072554927, 6.033487368014551, 8.050224492626807, 12.243839310061547, 13.687896170923787, 9.950514781859614, 10.229145250012799, 2.818493857499092, 0.22346223974900864, 0.9136569896532644, 11.349551658476553, 35.699856127462084, 38.28110910231067, 35.260817389334406, 30.463323285502774, 40.18180339567123, 51.30130706294891, 32.65094876289368, 4.056501258765498, 0.34010001488270303, 0.2924262407806612, 0.22544502851463136, 0.18458582100368318, 0.13544405389937664, 0.0977584881888282, 0.17950043743175847, 0.19513872812592215, 0.23359068819592077, 0.14483258398550172, 0.21222929169814433, 0.1557845616292569, 0.19385084239465578, 0.16406563501204216, 0.14204419248046415, 0.14227662355669085, 0.12282260212927096, 0.06835541312372492, 0.19398242565653018, 0.15082552127780455, 0.16086626797914505, 0.13920860995929088, 0.1655321111602168, 0.20508782006800177, 0.16112077770934952, 0.15420715594964643, 0.32117994141674816, 0.19778242094382165, 0.1399539981878573, 0.13929474888549698, 0.18709250665720434, 0.15151181348389195, 0.16793321457601365, 0.19790646590052113, 0.1218869559647095, 0.12853274572520487, 0.14461322236926327, 0.22510998762182652, 0.15706622672657813], [0.07444667780110914, 0.02051102741050624, 0.04282482824618778, 0.029289379956260807, 0.10821880592453866, 0.009270303567210514, 0.028073115785035397, 0.11447595928104655, 0.02162548041181459, 0.04661134038601191, 0.02659791964106262, 0.12118059991588517, 0.0601667107924098, 0.052980151057483695, 0.07560089651134706, 0.02700740704312921, 0.03852826242725696, 0.020298669753115506, 0.02516795141291955, 0.004026524613671486, 0.07838469914971821, 0.032194132556117354, 0.029225762099808747, 0.13619059125982946, 0.06290408850256955, 0.04938613766083314, 0.03631883804055472, 0.04431310725668746, 0.030887144422459028, 0.023131295174901045, 0.07255640947410176, 0.043910371004453594, 0.05487186729066795, 0.012503654260428683, 0.05256754759278509, 0.015833156649023294, 0.034718602940800695, 0.02083900880308882, 0.05229894184477387, 0.04639798872953942, 0.026947152312664736, 0.036166681487473755, 0.07469635351651138, 0.10735965363921658, 0.04024545233997126, 0.018152150761095748, 0.06592180459730088, 0.05848712047501918, 0.21013658463714585, 6.118750379931543, 22.724851715949274, 47.804306168710035, 41.02418730335851, 30.09227687312711, 23.963687227618312, 28.676622875275154, 43.40948258676837, 34.26491975784302, 8.701203600052866, 1.8233406183219727, 0.27387646357378653, 0.7565976883615217, 1.9634113989530073, 3.155975077421435, 2.525027269317258, 0.6274899323621105, 4.265156397896429, 2.200282230492561, 0.998662963749901, 0.23184287391843336, 0.13466603032523586, 0.04934853423506983, 0.8550050530222155, 0.6214489920004722, 0.8516699964961699, 1.343695788133529, 1.4020466828538527, 0.880818538848431, 1.0265515672583734, 3.32175993630963, 9.686698125254724, 19.47342453464385, 37.32184640822872, 51.118752110388975, 58.95487108538228, 61.61033138152092, 59.705922603607185, 51.79991875925372, 41.13886956245669, 44.391424425186656, 42.901366987536036, 38.03948325495566, 48.49390591344526, 61.22080472207839, 63.913700119141616, 68.9703687544792, 74.36784821171915, 69.8925728951731, 68.9646577835083, 65.55843622453752, 57.7677422185098, 55.19304352421915, 36.35386820762388, 21.588968615378104, 6.987500950213402, 2.516839321582548, 0.14563368212792183, 0.4416519559679493, 0.29074286981936426, 1.272660193424071, 1.0725268937887684, 2.5131275336588583, 2.42793855647887, 1.5238669202212365, 2.053025422557708, 0.846268586333721, 4.585479209499975, 6.967287996122915, 6.348050179020052, 4.645101687600536, 5.514876486793642, 1.977556446386922, 0.9937565689606052, 1.057739680813205, 0.15801605317861805, 0.18979514227999797, 4.434590531933693, 20.812582508210216, 35.52751502683086, 25.77312954010502, 24.90393623228996, 25.46187573863614, 40.8839782591789, 38.74762404349543, 12.156343979220237, 0.5892626965238202, 0.10238035792304624, 0.02788104605109942, 0.032066994519423575, 0.014171975424453137, 0.015806554245852655, 0.028680349632556883, 0.10593053193822985, 0.025372242164467613, 0.0425358254071926, 0.05036173914108546, 0.023032657524210312, 0.033544347200903206, 0.01652793327887212, 0.1262701969713934, 0.013804624773441784, 0.020006648527698654, 0.05494617015844392, 0.03657623209179409, 0.06317967331157097, 0.07529112119828502, 0.13230557553470135, 0.050158840754339774, 0.0175817025404784, 0.05648313788697124, 0.0353336259872923, 0.02350286122471575, 0.017223479827084852, 0.05439358327778117, 0.05044356499227786, 0.021409585343433485, 0.05085871569932469, 0.011764674357348874, 0.06412980619878059, 0.055312532556032946, 0.083752661913393, 0.056717618248395385, 0.082885465704866, 0.0237085634932643, 0.03684910877998318, 0.03233173343863699, 0.047421336639672525, 0.024204467528409535, 0.014973201886600545, 0.02809328113442227, 0.04316590208139631, 0.010663681520870136, 0.04590772310151689, 0.033611161559219324, 0.026895330295026786, 0.045047731949917735, 0.0461449881925458, 0.09119332152148409, 0.08626349976346379, 0.02582304851873027, 0.045781636520499186, 0.07795812607172035, 0.03462156258343208, 0.08441555779427291, 0.06738717757886456, 0.048182651836184726, 0.04913915091404512, 0.024950790384243575, 0.06026672740136424, 0.05195696785625431, 0.045796931465907444, 0.06596058396802795, 0.07436024010061257, 0.07045216512896361, 0.01620559412385187, 0.029313682180438793, 0.013264532786824051, 0.04864311281351313, 0.05086939879542878, 0.06997289286265451, 0.06370574971961399, 0.05816232983864123, 0.04283232058608725, 0.019105288628188354, 0.03807998990880386, 0.041827872065046144, 0.0581722928120965, 0.02636914088901493, 0.06484588773380365, 0.03022022466475685, 0.025949313215190367, 0.0495966203180292, 0.11801887844358722, 0.044330524265645974, 0.5335420574392042, 14.451517904958418, 42.21847841816564, 50.62336852473598, 34.28732433626729, 21.416529455492576, 24.080511100830574, 39.332163103165165, 58.17392718407416, 41.72180045035578, 10.859976122456214, 0.7919252507628933, 0.32060709151048816, 0.5408410367465789, 1.2644306930803484, 1.976195629085264, 4.368688339187253, 3.093750106711542, 3.9065936640385663, 2.3741726673418477, 2.985234303820518, 0.38220466685391247, 0.6040472128698903, 0.19973917804177732, 1.3844395308725297, 1.959686250455918, 3.2207473824101114, 3.7045501701293455, 3.558010175343483, 3.2342753919862934, 3.5596308496690567, 7.4363818956959635, 14.612458636683805, 29.14019407764558, 46.96291854304653, 59.26202797120618, 65.63110597672002, 65.85360634711482, 64.14359415731123, 59.125243156187004, 50.62330576681322, 50.60537661275556, 49.17819869133734, 44.80605425373201, 52.374997062067834, 67.4297558876776, 66.39861968255812, 71.1815578706803, 75.44918291030392, 70.57546538691368, 71.39469946584394, 68.09456625292378, 62.205962904037975, 57.006955377517215, 42.60132528120472, 25.899894660519017, 12.20886451582755, 4.896625636085387, 1.579433912711759, 1.3366992603386603, 0.6567992918914365, 2.8777422395444687, 3.301233682901629, 4.659992965959734, 3.974433997946401, 5.160023089378111, 5.859644980199876, 6.056664163066495, 3.2729734961063635, 6.725475836184717, 6.606243137390384, 6.020185139871413, 1.6126132419993802, 1.913812170105596, 0.210005997289573, 0.3985606133937836, 0.1648131376432796, 0.12242324049434355, 1.6286010679698761, 19.461747638640865, 47.7426504319714, 37.991218489985314, 20.654022655179425, 22.202272376706524, 32.50479732790301, 46.8765950202942, 20.80364146540242, 1.8470287923851323, 0.03340105045466654, 0.07128797471523285, 0.03960414481679759, 0.01633602250818043, 0.030346077588957646, 0.034879324356875116, 0.024692455960077145, 0.018556526441487576, 0.030711279363341393, 0.029774629623599114, 0.05156691035916729, 0.03289371638769104, 0.04999171867365799, 0.09850582994160154, 0.05122527344933441, 0.12138639411498463, 0.05157364810246134, 0.04833676957435185, 0.04405040804657244, 0.05335352699001951, 0.05253743267648163, 0.011331217021741455, 0.03941500153873236, 0.0820161780763057, 0.13176128538625856, 0.02978245904218526, 0.05556460229619857, 0.006293129324237066, 0.06266645185889737, 0.034932100153978796, 0.0018351872037577954, 0.03029025467713514, 0.036031398020925066, 0.046417891693812226, 0.04213240733670612, 0.11732618174245281, 0.014665359987937396, 0.03174338748888864, 0.07896164762637309, 0.03153237048536539, 0.33249898242854303, 0.11106488385027456, 0.15199987277869256, 0.13199645905725418, 0.14008904416714946, 0.10566051658843795, 0.1574030449433673, 0.13823324213585547, 0.1385964750642738, 0.06976940458820713, 0.1598086529561589, 0.26782369481459745, 0.26977642229007137, 0.07177751255972732, 0.12785518692145426, 0.13935271109784805, 0.17147660105218812, 0.1618307726758142, 0.16842469062295654, 0.25284606302457474, 0.2339360712757034, 0.11309076506163805, 0.13800074977259483, 0.21299939392314804, 0.1385125731148066, 0.0918037633621885, 0.18378317536365602, 0.22773969167422867, 0.17650740852038707, 0.10578239351631173, 0.18642718993848373, 0.23346488123699544, 0.11507553799498467, 0.1061726387049402, 0.20007103200881712, 0.24947688494238163, 0.20587987837291535, 0.0938513172009299, 0.20201850412113054, 0.073339780341954, 0.20064038855414237, 0.10032806200005355, 0.12669758976347026, 0.16566536449376615, 0.1458710161668639, 0.12066089352893254, 0.22518651980546214, 0.09849626150342727, 0.2801514897615679, 13.911752700805666, 47.576891068489324, 64.79104803454491, 54.32648212678971, 41.994471857624674, 32.94511671989195, 38.0489714684025, 54.9323667249372, 44.02675774789626, 11.543707020821111, 2.472190001318532, 0.8435893623578934, 2.015250546316947, 5.328665885233111, 10.952180258689388, 8.331891855885907, 6.536100372191399, 11.993530315737571, 5.398713532955417, 2.6696198073125657, 0.6117303393060162, 0.4119933216321853, 0.14273285955911683, 1.2693299785737069, 1.1015487558418706, 1.8076561631694918, 2.342941039992917, 2.43486546220318, 1.9319831627991892, 2.0945807282001745, 5.051124855395287, 11.676939149056713, 22.55878640759376, 44.0881153845018, 58.976161710677616, 64.61175257159819, 70.32445723010649, 70.22808459497267, 62.34759184621996, 55.4582114373484, 59.61571985675443, 51.69029243530766, 52.49402530731694, 60.61326096134802, 65.10339421610679, 65.85424177108273, 70.48046558134018, 76.85794138139295, 72.15939690989833, 70.44893756989511, 68.21874064783897, 61.23907904471121, 57.71362135487219, 37.47019437051589, 23.87300987397471, 9.314633857819343, 3.5538639849232094, 0.7685795486454041, 0.9468126621457839, 0.5710827559232712, 3.0167569220066075, 2.9107663900621477, 6.180726280135493, 6.365829302418617, 4.814943748135721, 3.3582772026138925, 5.480452785568853, 11.008051480016402, 10.644170257353014, 12.996921635443165, 11.447101985254596, 12.47096513548205, 7.2356237134625845, 7.318010647450724, 3.276054027580446, 1.1306458783726538, 0.2633828669786453, 6.002649203423531, 26.07044912153675, 47.35348070821455, 32.877467601530014, 30.96911095803784, 35.19793395073184, 50.98400300548923, 54.21612231962143, 21.683229054174117, 1.8219674210394583, 0.3299666941165924, 0.12587058252745098, 0.09229972102348843, 0.07592852167304485, 0.20856451092948838, 0.2537607566844071, 0.19675433094943726, 0.11170816021941363, 0.3530188006979804, 0.17367671364017073, 0.16669086511096648, 0.16628588039067485, 0.13074511571997596, 0.2057268293274026, 0.1677946292705113, 0.16282596685472997, 0.14912252314388752, 0.11749380944116462, 0.12896344035623536, 0.1657862531682176, 0.3168045374895296, 0.1660258241838986, 0.15754778959578083, 0.214542739333645, 0.1408105610959953, 0.11819582943233753, 0.16683262202047533, 0.10894089741932769, 0.16315042041242123, 0.10061230360259933, 0.14416754305843385, 0.15361932136358755, 0.12454108290013768, 0.1272545280235429, 0.19742566911924272, 0.2475005926023568, 0.1575675393424688, 0.1480793412173948, 0.16695602346331845, 0.11179799168941476], [0.02346249222154579, 0.04482606440902718, 0.03128801142015765, 0.11593866627663375, 0.011430089286858998, 0.03316827846931354, 0.06523911300445757, 0.024244344320088148, 0.10661506980297067, 0.058877446102879705, 0.03600061660812747, 0.012287655770177803, 0.06747425113233828, 0.008497846579449552, 0.0402951599549382, 0.049882876731815844, 0.01631518300142019, 0.06344886511684426, 0.08578682453521798, 0.07274705045405896, 0.016180449202957175, 0.022007675931578683, 0.024575912919376167, 0.05292897255370214, 0.08670373218915156, 0.05196627582453432, 0.03483126000050576, 0.0702405256790019, 0.03444700178900554, 0.021947800414636735, 0.02799613352474426, 0.07718486756446861, 0.03455285598794299, 0.02202339605578492, 0.015350151619303132, 0.041771848055143515, 0.0795772988649626, 0.06557763959731787, 0.019525457211139224, 0.024780933369672107, 0.06748086247112482, 0.011783681956360178, 0.0067846240445731155, 0.04542325675908116, 0.04349326677319985, 0.0540322081125792, 0.03054184561234809, 0.1422680280501804, 0.055405106620803, 0.22932725567971507, 2.9812678069837633, 16.366623966924607, 45.03477158084993, 39.32349858745452, 37.33363313059653, 24.79283509715911, 27.785689830780033, 28.790965849353423, 37.96121628053727, 18.834780300817183, 7.0783660873290035, 1.36637726137715, 0.32321151466138903, 0.5935725233247203, 3.5987388414721337, 3.6073879128502266, 2.8302192928329593, 2.9101983818315693, 4.105863797087824, 0.8328126503094551, 0.7911599595700541, 0.17455009983912592, 0.2685596601616952, 0.3464698521119933, 0.0932842972237737, 0.26455853615076314, 0.34497319209960203, 0.32534240354453364, 0.19280067374629362, 0.23926090328924118, 0.025180203074048606, 0.9246806884484907, 2.177724434483436, 4.588393040241734, 4.585903806071128, 14.499560075421488, 11.891769324579547, 4.429091859248377, 4.361242700007654, 16.917639509324108, 24.545445326835882, 18.697014893254927, 8.960231042677357, 7.675954382265768, 22.066581902965424, 32.16483569914295, 42.04622360967821, 46.36147014556393, 48.670859721399125, 41.40154677052652, 35.67365861708118, 25.526545816852202, 15.204654162929906, 4.084775909300774, 2.11586645053279, 0.8859581308018778, 0.23761986634663998, 0.7969051899929201, 1.1395257567205737, 2.307099647098972, 5.0610808114851675, 2.8042637436620654, 3.9395229422277023, 7.267927863905507, 8.261979529934546, 4.870606103251058, 3.0227103444837757, 8.2027478179624, 6.652260874548267, 5.1528858465533105, 2.130087248740658, 0.9381634069065895, 0.028196549786615278, 0.26688241790379247, 1.8513383740378966, 15.601740210287034, 33.28347606043662, 31.46497699522203, 16.79726196873573, 22.306391692930653, 37.75190684103197, 43.745374756474654, 33.585561321627715, 7.902976755172976, 0.18597722053527835, 0.01773004206047664, 0.07052433061143083, 0.013736673732168012, 0.020607052701375177, 0.02052011321328821, 0.05018642758049312, 0.03709188587362728, 0.026260588145364198, 0.06227413823287334, 0.05975436013672621, 0.06776521898685925, 0.007740229672391809, 0.01868292328811461, 0.021497771639617223, 0.023143449159819755, 0.006453390129947014, 0.06309050833806396, 0.02799802959235686, 0.045888390872747674, 0.06808857703881879, 0.018481965019037167, 0.055366633685245636, 0.13291915067501608, 0.07603124640281163, 0.011940781691772564, 0.03742379346682179, 0.0780143109600871, 0.028123129835172046, 0.022146943055333632, 0.02228755466339569, 0.059757236796881885, 0.06332210054801357, 0.02183596689945027, 0.07727895082244951, 0.0244110488828512, 0.04951718083072094, 0.09164643188517901, 0.036425646018957904, 0.01617125997830543, 0.03972970279714754, 0.005306808837509204, 0.034587889188720335, 0.03379111944307243, 0.013912124146196633, 0.05129098081059995, 0.02072786668225402, 0.005150916169382512, 0.028992631968351144, 0.021669130186520277, 0.045957783116928996, 0.05067894933745266, 0.028974734239220142, 0.0360012831046216, 0.01686861640923927, 0.03184954429255619, 0.04617171700022394, 0.05749589080111154, 0.009380840478585133, 0.020352906862934752, 0.025059369940971656, 0.018202988355751, 0.03126206019172265, 0.01377004452214967, 0.031005759730995185, 0.07627536798076284, 0.057173011554104675, 0.023180629322004896, 0.024350920556894234, 0.0605871704887719, 0.0323941427913885, 0.06744396767669147, 0.02863401855011621, 0.06590377088756331, 0.04285655577757186, 0.0821067373298349, 0.023180811267886913, 0.07592941033503703, 0.03241659682844916, 0.03419195196681446, 0.016167406556046298, 0.07006244088012366, 0.05467438131510731, 0.04500447862571286, 0.03735876792380887, 0.04224634376324473, 0.021330438884756258, 0.034880262814582355, 0.016778991782977697, 0.06792368427399667, 0.07247327361255884, 0.22590198463970618, 6.055660526598654, 31.61424279212952, 53.11826267550069, 40.22809913081508, 28.349658020081062, 19.94438352123384, 33.514484051735174, 44.84429344054192, 46.71186331779727, 21.590010004658854, 5.100202531583848, 0.49290709918545145, 0.08914860220806253, 0.1875662094643039, 0.5888588762571735, 0.7771797742574447, 1.6896337607214529, 1.7591201417869138, 2.7391170974700683, 2.6740312480157424, 2.1107408933101164, 1.2734898972895838, 0.7219518829257258, 1.0948579277723067, 1.6273402711076121, 1.3843100926568432, 1.2276766136769326, 1.3957957731139277, 0.8427046227359003, 1.4508646245925658, 0.051347437660179795, 2.2402693235105087, 4.398876861218484, 9.297007706857498, 10.26984376292075, 24.971514747988795, 25.284984688605032, 8.9436904076607, 9.639756179624989, 26.65672383000774, 34.93008705877489, 28.760010503953506, 16.797265891105898, 14.263758947772367, 30.10211221633419, 38.65497373765515, 48.67374266347578, 51.32639062020087, 52.6660486959642, 45.64070716980965, 39.83959620998752, 31.608843649587325, 17.507920918926118, 6.354404908995475, 2.2758648328242765, 1.5849982850974607, 1.6835191533450158, 2.4060031915864637, 2.8773602987489397, 4.771313263523964, 7.129579494076391, 6.482250642391944, 8.246266515024248, 6.687462185659717, 15.261556967612236, 9.329521213808368, 3.6975872276290773, 4.963307890199847, 2.7800190833307084, 1.5698521752511303, 0.901001155857117, 0.351186869966407, 0.09129917188998192, 0.1730236543282386, 1.1300339886257726, 10.682367278683571, 41.62110928566226, 48.91839658060382, 25.722525081326886, 13.934545593876994, 29.101293971461637, 43.89475037974697, 43.86441869120444, 15.81028674879382, 0.7979514822363855, 0.028611654528386654, 0.069032228822189, 0.007713038817934332, 0.011281680818947573, 0.028675846950781923, 0.07736459945238407, 0.10426272022267503, 0.0106595408156394, 0.07265771694120861, 0.030702092053909457, 0.05718102483379264, 0.04434899081506076, 0.02117617750510333, 0.01757006566490858, 0.04134284647842569, 0.041827649899548104, 0.016410112786557407, 0.033250648242932175, 0.014147152260486639, 0.04047681089310397, 0.044206793404995434, 0.018045130193293575, 0.006887648506240259, 0.03141304079983984, 0.018304383922969143, 0.027258362125365004, 0.03671526938917176, 0.03058458757286351, 0.057545755464102955, 0.03586585025092767, 0.07340102141062099, 0.03136012327647017, 0.0573792654059587, 0.01666974381453568, 0.025532036614153656, 0.04860399253365975, 0.04110807883402994, 0.03608539955870759, 0.0333685415135997, 0.08616350996758669, 0.06475041019580056, 0.11779061488566861, 0.06693625822663307, 0.1153098536475051, 0.21897032917026552, 0.09744868223224917, 0.14360535709607986, 0.1321463671422774, 0.07745194113663129, 0.1818081547295855, 0.1268544539268459, 0.13885366610221325, 0.12357299291198293, 0.20201000054517101, 0.1000007662561632, 0.12138017348103947, 0.11109817037058455, 0.13482865546980213, 0.1052780242096032, 0.22249365946458233, 0.1183793611163574, 0.12596564637797494, 0.09849948673358849, 0.16010712081145856, 0.1827187268363853, 0.3038302562650173, 0.20112080229145868, 0.09019802775113814, 0.2423773183216972, 0.17102643246612242, 0.20315067482090768, 0.20801922486674404, 0.12548104213971284, 0.14227136819353028, 0.1568975035221346, 0.17372638678118107, 0.2359195954857334, 0.18811990717245688, 0.1546641733617552, 0.10378787594456827, 0.13798262413230636, 0.21277712117279732, 0.13274690346612086, 0.08063011051666352, 0.16565975673016042, 0.15124279404840163, 0.18128016693217142, 0.14015472854577726, 0.2743788333910127, 0.17780928301715082, 0.20355984238126587, 6.120761575237398, 34.64011015430574, 65.6805984435543, 51.921018015953806, 50.78356988968388, 36.15373711432181, 37.56231907875308, 36.37052651374571, 49.01172153411373, 25.632649852383523, 9.558956334667823, 1.5517144001299337, 0.8079359367970498, 1.2374463797576967, 8.964883954294267, 10.810976893671098, 6.68654288015058, 7.283751685773173, 7.988051003025425, 3.818228057315273, 2.9152150932819616, 1.246964746425229, 0.7834656176067168, 0.9079906356430824, 0.9263645497060592, 0.6926645867286191, 0.941442140648442, 0.6295988192000698, 0.463721692682274, 0.5403295351612953, 0.07108945069053481, 1.9771389591117061, 3.242944810659655, 5.738335876695572, 6.477049089247181, 19.18253371792455, 21.610433786146103, 4.93949321969863, 6.947102988919904, 27.173084251342285, 33.88918022955618, 26.697965591184555, 14.057187322647342, 9.673534650956432, 25.6474587609691, 33.98289349771316, 44.50273736830681, 46.81640625000001, 49.70197239229756, 43.80293161638322, 38.356779467675, 28.76606272112939, 18.07290892447195, 5.3643722015042465, 4.006325809224959, 2.07302485262194, 0.9051238733433908, 2.640911489725113, 3.71484148886896, 6.265767187841478, 9.990563161911505, 7.540206543860897, 11.61009313598756, 13.711242118189412, 19.9869647718245, 14.910960812722484, 9.530600540099606, 19.06816524844016, 14.45052162293465, 13.763825412719482, 8.402261137962341, 5.563742845289169, 0.8110143845119785, 0.41190797943742047, 2.863109347320372, 20.191726223115, 42.73891418210922, 41.119465597214244, 22.25674625365965, 30.797848509204005, 47.654997225730654, 57.096918859789454, 47.7550058980142, 15.56650555902912, 0.8619434807089068, 0.12958398689666104, 0.19541329403798427, 0.12034570963512506, 0.18864847719669345, 0.1693190829527955, 0.19407360544127805, 0.19209355927042424, 0.10151949726165303, 0.2085997356522468, 0.13438159720070902, 0.17924100941708013, 0.15726435238555556, 0.10667344570280084, 0.14249604645996325, 0.1490595353947532, 0.10544805742439725, 0.15411527136400824, 0.1185389525527435, 0.20893735060047722, 0.19576210919166767, 0.11748679207577822, 0.16218772368325343, 0.1941310313920821, 0.21536583952125044, 0.09659951973345973, 0.1906814753648735, 0.20099870319808685, 0.07999986530311647, 0.16730067109869373, 0.11834744589343188, 0.1389110001224664, 0.12813700768615932, 0.16469805591529416, 0.1275091679886945, 0.11703907497107022, 0.12242221393652501, 0.14334546942864695, 0.15005761006426427, 0.13570073931928606, 0.1968879060399148, 0.14896783467021682], [0.07484376415490143, 0.04989218470009585, 0.02474203908575639, 0.053403230774546825, 0.02623374442449741, 0.03686934499250304, 0.045784861750660405, 0.08673108152804837, 0.022176768773445682, 0.0831329504088048, 0.038329416645630714, 0.04434536721917891, 0.04205366115896933, 0.08125685470839662, 0.04504607720000129, 0.01901710424722443, 0.02025528236352388, 0.031265603348372445, 0.05154417286957464, 0.046725579417280616, 0.03286309968379717, 0.036339756071327195, 0.03354632753818747, 0.0019540389222393356, 0.042626580013142484, 0.007711850424041792, 0.030000545122029803, 0.026778714475973, 0.021451266272173777, 0.03273385682053143, 0.025199433796167858, 0.08178464332295042, 0.02390776359055552, 0.06808540543481227, 0.034236319948949163, 0.08764828029539316, 0.06240143140237178, 0.04339180225806852, 0.043559981540085814, 0.04890692668155797, 0.024381889661233273, 0.05592890391727129, 0.043245502447168675, 0.04637666467216708, 0.052445766425901846, 0.08068981174860271, 0.06949031875739176, 0.011256216056344491, 0.037370607812678626, 0.024132867035786473, 0.11570690169690118, 0.3627636229559299, 14.009802149188134, 39.07879760188442, 47.10846593303066, 34.47430764475177, 34.244829377820416, 31.158355512926658, 26.962654975152788, 30.43064994196738, 37.427209115797474, 17.221052492818526, 7.039398320259587, 0.855951079678151, 0.7145177657085081, 0.39901245205152425, 0.8125814326828527, 1.1257360515094574, 3.4638845680221437, 2.5417738287679614, 1.8193585545785966, 1.586333116696727, 1.006926171962292, 2.0520731446243103, 2.478009327765434, 1.9668041265779928, 1.8811383362739318, 1.698020401020204, 0.9313413632973548, 5.094022837377364, 1.4745722879325192, 0.5511959101403914, 0.12642670107344467, 0.1484844791552713, 0.061655874634462024, 0.5544311300881448, 2.209429688030674, 0.04059634742236907, 0.134614763721343, 0.39620262540636525, 1.9872431072496601, 0.7818942793434667, 0.16971397063424512, 0.07259735687365455, 0.3955088868256538, 2.173373055073523, 5.263902650725457, 10.729131737063009, 10.555149124514672, 9.068494342988538, 5.037310267648389, 1.5859085201255738, 0.8692798451069863, 0.06874173594218108, 0.2629439598850666, 1.1014475096617977, 4.990381560017986, 4.369091362722458, 2.4084620273882344, 4.253682484549861, 8.597568696545018, 6.243710719770001, 6.609779644396998, 5.492468476295472, 22.813764003015336, 12.239752200341995, 1.2475537148214157, 2.2479981087869216, 1.5843694801292114, 1.6254278705004723, 0.17026187671769052, 0.03239898063663033, 2.1588627369173112, 12.330173619331854, 39.966892811559866, 35.766050046490086, 25.461920845893125, 22.529472574110954, 26.678604772014005, 36.70844262646091, 37.62849730830039, 21.04737166435488, 3.331207455165925, 0.07175993850274433, 0.028115001642295433, 0.028611600902231953, 0.012196677083510065, 0.04023078558666091, 0.07376483656586179, 0.10427406598483363, 0.03883752063097012, 0.038549180458029436, 0.06215472810811574, 0.019802239032522328, 0.046114731549976334, 0.05821242432800993, 0.012547091445735386, 0.03074219292630592, 0.056412546715188416, 0.06504314771342663, 0.08963852309651914, 0.05437769461423159, 0.031149868530431585, 0.07248700190816196, 0.0753894102789702, 0.022811564549262968, 0.06635379391692339, 0.04822223942967192, 0.010939957724223215, 0.02446445670249241, 0.06261245032111484, 0.03148121879466119, 0.021189645330812183, 0.03836510868202295, 0.03375571852009143, 0.009687715191243878, 0.04006352177971313, 0.06823335999562856, 0.08950397507437775, 0.030397007114163814, 0.014626090320938779, 0.03526113108701764, 0.04589562274275288, 0.05496024702405257, 0.06422246836366192, 0.008589234165546876, 0.035172736031874534, 0.037949142091336756, 0.018164344965630484, 0.04000298934237611, 0.008248489748145784, 0.09625482613280897, 0.05129319863514074, 0.029673381528306394, 0.056229980301953135, 0.16435065036339147, 0.019707031540512558, 0.019044570414529696, 0.018202992186190623, 0.015995940756833842, 0.07637489812388536, 0.011859932602683624, 0.028108045563942967, 0.03583971133095122, 0.02553396332528322, 0.038845920785059856, 0.030827918165032903, 0.06649305337979909, 0.04254132208804931, 0.01195881444390022, 0.03938169969666389, 0.01380355703839732, 0.015693336026743054, 0.05102768022146437, 0.08757898764264199, 0.045949333167124184, 0.027592332410295645, 0.02443825841070183, 0.020920382662405892, 0.01292836478716063, 0.04630669403160292, 0.07479396077894396, 0.03328612194426599, 0.017375249505764054, 0.03614727648035173, 0.020016056087408817, 0.03065599845872531, 0.06441363028340763, 0.08688356366849716, 0.0457123591895065, 0.06551944755858953, 0.06563777749937388, 0.05068544193261093, 0.022130834141505823, 0.03516062035135204, 0.03533413926620157, 0.04437724413770822, 2.230000068103114, 26.556313114781535, 50.10557643828854, 51.69244581653226, 32.02442857526964, 28.044411328531083, 22.99310261203397, 33.89328695112659, 45.586060708568944, 46.723328405810946, 20.843392725913755, 5.0760426925074675, 0.29998507711195177, 0.29195050017968305, 0.3492088309459148, 0.3290416889132992, 0.6395647650764835, 2.0240576156685433, 1.4693369043450204, 2.112075479761247, 2.353304922580719, 2.1275933567554723, 2.5947282775755856, 5.810277538914835, 3.931686046623415, 3.379969135407479, 2.6843468364207976, 3.4711931693938474, 7.139149096704299, 4.063368593492816, 2.2161800870972295, 0.5618933167669081, 0.6799646262680331, 0.1738370711644811, 1.9185496578293464, 3.0446829718928186, 0.14152981040458526, 0.218699915454753, 1.426216205281596, 5.328453096651263, 2.4335276888262842, 0.11173376287784308, 0.2019163079920315, 1.9382084545589264, 5.065060056024983, 9.852012299722242, 15.555698448611846, 16.257571289616248, 14.676733536105003, 8.949165055828711, 3.659039889612506, 1.5919509313760267, 0.6827303875357874, 1.0517521827451646, 1.7400012838263668, 6.710807152332799, 5.9506812307142445, 5.491186351545396, 8.50663442765513, 8.75247682294538, 6.151003539562226, 5.427896947629991, 4.42260229779828, 15.01562043543785, 9.335331224626112, 2.071181828937223, 0.3280228839045571, 0.7744870058471157, 0.3067589797560246, 0.27211020189908247, 0.08370776916103018, 1.739299424713658, 8.7689870595932, 33.754717457679014, 53.726669357668975, 36.674537658691406, 18.601913106056955, 14.321448187674246, 33.401876726458156, 44.16769635292792, 34.40753713730843, 8.368660153881196, 0.07474515331728805, 0.012753989769055719, 0.06438153119938028, 0.022222728303243077, 0.01759528144893627, 0.05747151005292132, 0.15679204385847817, 0.013545345188298774, 0.0911210717693452, 0.06243590152852478, 0.0433381607816104, 0.034175435111166975, 0.06371277857631927, 0.04123198589490306, 0.02432692859832558, 0.047540417346622676, 0.028650774808240034, 0.02047452523613409, 0.03393031378847457, 0.06518190921915155, 0.060608475393946135, 0.01565782689384275, 0.030468111564855904, 0.019114470191960855, 0.04302368551913289, 0.03751984940120771, 0.05299278384735508, 0.03410198643142658, 0.03834248227517932, 0.12816840196929633, 0.07099738990467402, 0.010268327483396617, 0.008332902103692533, 0.04935724082432928, 0.0444498309685338, 0.009267874110880639, 0.02385430789041904, 0.0694321267186634, 0.03278345335274935, 0.09411620742250836, 0.02646801411174238, 0.024321004823451082, 0.033833438140009685, 0.18939366624239953, 0.14870236988269514, 0.08967739439779714, 0.16040345894232874, 0.12041356970345783, 0.20114991363258133, 0.19205309450626376, 0.16319958793540157, 0.10186373887042846, 0.2758640940150907, 0.16824633003242556, 0.13840388056010972, 0.1803991351757319, 0.20292138470517052, 0.12773256688829393, 0.14581349828550894, 0.17711035036031278, 0.15207533243923418, 0.19105983086891715, 0.1771733534312056, 0.15890687553872987, 0.14653567404996964, 0.12770047546514582, 0.17478476789209152, 0.11206263676285745, 0.10617509018629791, 0.11054123211051188, 0.17472003346248982, 0.2049463083066287, 0.14784173138679998, 0.10306308782028575, 0.21742595720195004, 0.11704421542104214, 0.18399919683654464, 0.19489011727273467, 0.13992147009459235, 0.2116609004236037, 0.12368322530340765, 0.162663035274994, 0.1659548997638687, 0.10816538661357858, 0.22557697949870942, 0.246400015368577, 0.16243202912230648, 0.16470075254478764, 0.1664876066628964, 0.15072571534302928, 0.10005099098047904, 0.09442767578988306, 0.17983031489195364, 0.2663690470639737, 2.114255827280783, 27.88684383515389, 58.800215951858036, 66.69923013256442, 48.33219051361085, 44.33080811654368, 41.779627953806234, 35.07644637938469, 40.46130364941013, 48.09398889541627, 22.336784178210845, 8.892942782371275, 1.235711588974922, 1.2252831098533448, 1.540406819793486, 4.449748531464608, 4.834337417156466, 7.138431793259037, 6.3976407051086435, 5.928999348994225, 3.553944148363606, 3.9481641688654503, 5.24828524358811, 9.786315541113577, 5.308116587900347, 5.085858423863688, 6.3368910358798125, 4.185800965755217, 8.64031860905309, 4.814296557057289, 1.1724514802617412, 0.3526413951429629, 0.4502941631982404, 0.195306041728585, 2.1126094124009533, 4.431745342669949, 0.20711547094247035, 0.32441889987357203, 1.0694667096099546, 3.873096622766987, 1.6252326100103318, 0.2623934797461956, 0.5358082068062598, 1.3546664123573613, 3.363075241927178, 7.45065785223438, 11.605813830129563, 13.841112775187339, 11.015427497125442, 6.625139645991787, 2.1119962969133934, 1.604815447522748, 0.6426775335304199, 1.189519061196235, 2.6141900977780743, 11.494719559146512, 8.91499238629495, 7.843939690820633, 16.36231328210523, 21.390184856230213, 16.85176330228006, 15.09487976950984, 15.41337916927953, 31.667877281865767, 21.891728524238836, 8.63782202043841, 9.183220728751152, 5.18171722850492, 3.9555848029352005, 0.6975680397402856, 0.3433223032662946, 3.3939514044792425, 16.21938995776638, 48.69437825295233, 45.70232760521674, 32.25575427855215, 27.68336303772465, 35.47856776945053, 47.26350938120196, 54.22681470071116, 36.71944095242408, 7.34210821890062, 0.15706164552079094, 0.05694630315467235, 0.20929491447825588, 0.12126293138510759, 0.04547903562084802, 0.10995922745355677, 0.2523009608229322, 0.13509781280111882, 0.17938553956487488, 0.2760325720713985, 0.23251560636826102, 0.18667054542851064, 0.14844111857875703, 0.18183832327204366, 0.14909212477505207, 0.18098487068087826, 0.14156417710886848, 0.18347557574029894, 0.17350250524618935, 0.15009033734038954, 0.18180349691500589, 0.15414050630023404, 0.1270676791788109, 0.23852021884052987, 0.10677895899261199, 0.1014924313752882, 0.17532248500614397, 0.18078590232518413, 0.07476768396314114, 0.1946961744538238, 0.17656342486941046, 0.1993598419451906, 0.17475171885903806, 0.20684931667581682, 0.21281269829600089, 0.20516288136282276, 0.14822036268249636, 0.17480125410422204, 0.23493960049123536, 0.2445691265165806, 0.14738656790746799, 0.10344893566422886, 0.19413549002380143], [0.010439920644726484, 0.04203091217805782, 0.06305116206227292, 0.03830628845119669, 0.02522023308331207, 0.02913211934238432, 0.06598765751527202, 0.04839985308447673, 0.06192587466249543, 0.04774447252613403, 0.033253268263633215, 0.06473664359580125, 0.13500410492622084, 0.03254058815899395, 0.020979252688947226, 0.03633244376208994, 0.01876765069732022, 0.009984231437556446, 0.016887885435754736, 0.07705489308723519, 0.07019118961667822, 0.03311108234488676, 0.079402263096023, 0.024463286503188075, 0.09569042617635382, 0.06082568430311738, 0.12494009213461993, 0.054336161157416726, 0.06329983803293397, 0.08243095340026964, 0.04074712884762595, 0.09199861782572924, 0.06254143014009442, 0.07532844500195596, 0.0345539131892785, 0.033301305806925224, 0.06587590060887799, 0.032101954941848115, 0.029928477315772927, 0.027504536818953294, 0.08747759590586347, 0.014141830822242605, 0.026359666296611392, 0.01024151249082699, 0.050495498092664834, 0.020977371943093116, 0.04743491171769077, 0.03449518871944278, 0.028648286937705936, 0.054458873121127974, 0.057988121444659854, 0.06699527764031965, 0.3413607504579329, 6.224151330609476, 31.0705199164729, 50.61025211887975, 44.932444787794545, 32.83569828156502, 21.768619052825436, 16.132481021265832, 21.173289552811656, 36.343218972606046, 29.644779543722834, 21.074847867411954, 10.062417061098161, 3.010994224779068, 0.6546601905457435, 1.132367553730165, 0.9058657528892641, 0.48237446274968887, 1.7457389759440578, 1.91506830915328, 1.2803552708318158, 2.7635201234971327, 3.8134817442586346, 7.056105165712296, 1.3746489272002251, 2.6392594364381607, 4.270085836610487, 9.317395206420652, 2.1709875185643477, 2.7145125596754016, 0.5298163573588095, 0.7061101652441487, 0.05649627629487265, 0.07171697629195067, 0.43748195553498886, 0.194170025267428, 0.050452198803184495, 0.02335678357931395, 0.03281101336582534, 0.059592332540740894, 0.021510592121030056, 0.14648393247156374, 0.1199960747673627, 0.1577579121916525, 0.1322048196509, 0.2746996403701844, 0.24125625589682212, 0.3533469927647422, 0.2111023150744938, 0.8013875397943682, 0.5601312532540291, 0.7288572769011221, 0.9193243855430234, 2.434040048430043, 6.3514190047018, 5.941578390136843, 4.728941369441248, 5.068668146287242, 4.872206430281363, 5.732265518557641, 6.217376907025614, 2.0480366579947935, 11.346360810341375, 7.044223325867807, 1.1327487590812868, 0.2573497100703178, 0.1739192877205149, 0.6411569409312741, 3.9123808760796828, 15.656000318065768, 31.822034274378133, 61.36583828156995, 27.933720081083237, 18.9692783740259, 32.04138694270965, 30.519393567116033, 47.28176409198392, 37.224732445132354, 13.493985956715001, 1.7419127038409634, 0.046716562562411836, 0.07444303122258956, 0.03421052959897826, 0.05082313474568148, 0.03740873600867006, 0.035101888220637076, 0.05039017249439513, 0.019087421542574323, 0.036170462131380074, 0.041790314604558294, 0.03950360343761502, 0.06775465463438342, 0.046949962739862745, 0.06769574247300625, 0.01813986845644972, 0.02909095360777311, 0.022622390627680768, 0.0693920526593443, 0.06287090157368971, 0.036987989029336366, 0.0506229214971104, 0.02538580383594719, 0.02035320372200541, 0.05489160554603704, 0.06397419841960073, 0.03721919436488421, 0.015126676110911275, 0.09409542345712263, 0.043595497376255454, 0.07795313117845405, 0.07329543917289666, 0.012410069917208486, 0.0037321366553735593, 0.03213808939401661, 0.04038484586823372, 0.05033907442984562, 0.013639189043803322, 0.05573074378433728, 0.04294180604178579, 0.0655110665566979, 0.09236096209215541, 0.024952531319051504, 0.036956587085320104, 0.04014583026629783, 0.09905351385954889, 0.004134475499496706, 0.03951561186582812, 0.021280076264614062, 0.06267081856006576, 0.053897606464283127, 0.010260798754320751, 0.06904865374728557, 0.0750157508939024, 0.016586207672052326, 0.11102764431627528, 0.057773003955521894, 0.09457366150473395, 0.032311049064681414, 0.05965500619382628, 0.05701222502055669, 0.05954438309756018, 0.011902085633107252, 0.03136510093275818, 0.04178348110027371, 0.007454966300077016, 0.059159669063745014, 0.03463015808994251, 0.008705584726656878, 0.0061925553863177146, 0.014280298341726585, 0.11459604356317751, 0.016794955140099894, 0.03140621687165432, 0.041005013195136865, 0.05761818907734367, 0.06047355581916148, 0.04817610178443213, 0.04672848289051364, 0.04928969868248509, 0.06531566817073092, 0.05539083823321327, 0.021322778005513455, 0.011216823815277988, 0.012766431036946035, 0.06837851833552122, 0.013972090636079591, 0.015654543249477303, 0.05573638219145998, 0.021555165031684503, 0.03889611869629833, 0.0153970725894455, 0.08789704436616552, 0.05900083988484356, 0.04051643679098737, 0.047436738837390184, 0.053650933813544056, 0.9913525237671792, 14.913886900871033, 43.89010629346294, 53.30197080489128, 46.27597816528813, 30.702664352232414, 17.61849645645388, 21.334216556241437, 37.12008753130513, 47.12110380972586, 44.92110913799655, 27.153399836632516, 7.82903076179566, 2.112990617752075, 0.28116536116407764, 0.32451119814668933, 0.22621854749177733, 0.6920230340573096, 0.4286560710639723, 0.5937184477525373, 1.4774931053961478, 1.2562162693469756, 2.9586041069799855, 4.524879570930235, 7.2525100073506765, 5.617433228800374, 4.142206763067554, 6.635970780926367, 3.4691572141262794, 5.198742276237858, 2.613377186559862, 1.388678877584396, 1.4778711238215048, 1.7310506802412773, 1.9036108207318092, 0.6370141825849011, 0.438766899488626, 0.191209570414597, 0.19131218023117513, 0.14924526575111574, 0.5648463712103906, 0.33992926920613936, 1.1300341111998404, 1.104832024824235, 0.7424381159005627, 1.180970500553808, 0.706135415502133, 0.33655287457569955, 0.4050234536970816, 1.0507478108329158, 1.2188270111237804, 2.5296867999338337, 1.8272601692907273, 4.1216584463273325, 11.472333611980563, 5.940787542250849, 5.027076803868817, 3.8337466697539058, 2.896297747089017, 1.9698013076859138, 2.6864551103884176, 1.6092103407267602, 2.3011442634367176, 2.0687256897649458, 0.3652679030933688, 0.2190430615577967, 0.10131580980434533, 0.45962284649572066, 0.9343964606523515, 13.31229196440789, 30.688957629665254, 58.68254876905873, 52.26821445649671, 24.64564423407278, 21.136321213937578, 25.23822219141068, 42.24742551003733, 46.74484652857627, 24.29147185817842, 4.069461260111102, 0.08848710060720483, 0.04262680600908014, 0.060267259832471616, 0.0377255593306355, 0.05929888256134526, 0.11826277785604039, 0.020170122114641052, 0.020426930108618353, 0.053291814777279095, 0.03769162929646912, 0.04880370782508005, 0.08211871894497065, 0.06390146603206955, 0.07802325886704269, 0.055194225597886316, 0.004710049805937395, 0.05106442179831286, 0.07336907554417849, 0.05798193145423167, 0.06482103584153999, 0.0820253941140348, 0.042840345357094085, 0.043396873760127255, 0.022305804792971864, 0.07521549299840005, 0.05752434713705894, 0.034469555417496356, 0.05790881985317796, 0.0742170123022891, 0.04338796032712825, 0.027279375917128017, 0.02435872316240303, 0.03075259831553746, 0.018191937537443255, 0.00450892826437109, 0.017776773423857747, 0.024768063092544198, 0.020917550052305865, 0.04619223283483617, 0.05265311195304798, 0.018697986491925774, 0.07285391205861684, 0.04973272732909649, 0.04923687308966633, 0.16642714700391217, 0.13668347690855304, 0.1677512840157555, 0.13844069874575063, 0.15737509805588953, 0.13723899790596578, 0.2432092591639488, 0.1686425660286219, 0.16124574197155817, 0.07482599857593737, 0.25013659389749654, 0.2427191007882357, 0.29324828376693113, 0.10414232184449512, 0.1525598677295831, 0.1294382463299459, 0.07785902493783543, 0.10504198485925313, 0.20596727368331727, 0.31339060455080003, 0.10379660934690507, 0.19832658851819657, 0.16334151338425376, 0.12446507931716981, 0.18249685245175518, 0.20846626781407865, 0.18599051982164386, 0.15675346367061138, 0.1372687834044618, 0.15096927001591653, 0.0602872317446576, 0.2404174968720444, 0.1336937268534976, 0.26793088583696273, 0.15324709456293814, 0.22020412909407772, 0.1724171884838612, 0.18476416627245565, 0.12955041692381905, 0.11934912883706632, 0.24169946840453535, 0.17370839903671897, 0.13193411482197623, 0.1601322331736165, 0.1786245844296871, 0.09162528785846888, 0.13239893100915417, 0.13236010567315165, 0.07833321038032733, 0.285746505664241, 0.16036907691628705, 0.17062789820615323, 0.7690607131488862, 13.362175687666863, 49.93642030223724, 67.42436655106084, 58.32976295102028, 44.55624241982737, 33.997680833262784, 23.116625893500544, 29.39937645389188, 46.32353690362746, 41.41318836519795, 28.73925724337178, 14.43331124321107, 4.150170155109898, 0.8041966309951198, 2.0033090129013984, 2.607510791670892, 3.6259245439883205, 5.232469266460789, 6.077969497249973, 7.731220577993701, 5.89836367676335, 11.608703636354017, 17.109302205424157, 11.988902899526781, 12.096096373373463, 9.104717431529876, 17.457985224262362, 3.7961326106902096, 5.530114404616818, 2.525586207066813, 1.995173281719608, 1.3917522997625413, 1.5922938936179685, 1.9424845734911582, 0.504768407873569, 0.23793751704356364, 0.1595680247391424, 0.22203898628152188, 0.20671496017565652, 0.2511828401756864, 0.3315215155241951, 0.6292574504210103, 0.5033968346974542, 0.4462538461291021, 0.8210004325355253, 0.5351981556703967, 0.5706147068450528, 0.5515054709488346, 1.787685170289009, 1.4906211557888216, 3.211775941233481, 2.7228605891427686, 9.818123021433431, 22.9944440626329, 13.485986282748561, 15.653570409744018, 12.229911954172197, 14.314592865205581, 13.07148491182635, 17.30883905964513, 9.72304182667886, 22.313157781477898, 14.222532876076238, 3.5719372860846983, 0.8074483371550037, 0.6216533842586702, 0.8675732463598252, 5.039299399622026, 19.230421935358358, 39.63395026422317, 72.27673853597334, 38.82984868941769, 27.53490721025775, 42.51928890905073, 42.002281296637754, 59.92329643618677, 54.50957052169308, 26.824824848482688, 3.356217467977155, 0.14069233840752032, 0.19526030627950547, 0.15348815178919226, 0.08106358604685915, 0.13375495260040607, 0.2665480971336365, 0.10684076696634294, 0.1204500737930498, 0.1117936862752803, 0.18663688352511776, 0.14752415729866875, 0.21456176895768414, 0.15949621165712036, 0.2095597817171966, 0.07526174938726811, 0.1368263063411559, 0.27405652487950943, 0.14645685892431967, 0.2745767292236128, 0.1554959456646635, 0.18895906456295522, 0.14865819725298113, 0.1768013564569335, 0.11483199098297667, 0.134074441908348, 0.08433587698926849, 0.21975690228564126, 0.16964238737860035, 0.16561733078091376, 0.17728992136976413, 0.13301598418864513, 0.14055583686117204, 0.07983588418292423, 0.12627224242615123, 0.15571172198941632, 0.15121624144094606, 0.07652643797618729, 0.17096957342038233, 0.16759952199795555, 0.27916584103818864, 0.27612554450188914, 0.14866821768303073, 0.20402378522821013, 0.16291694745661753], [0.01627625615876769, 0.053279055582900206, 0.01748115924607602, 0.045354327998094024, 0.014536507829513042, 0.012658621398581853, 0.022427063104846788, 0.02740603514886912, 0.041690351621758555, 0.04118188374465512, 0.03756022223481729, 0.034827080990878806, 0.029847936577073512, 0.036467627637208476, 0.03991144949630384, 0.0326499855145812, 0.08062005944309697, 0.05368487916946892, 0.042640063160609816, 0.06181111852187784, 0.014148039007258993, 0.014486692962236704, 0.02148574788964564, 0.053682515788222515, 0.02429848758413667, 0.05721250721704095, 0.005517235953330753, 0.02112615962452706, 0.006765445990998659, 0.018058793371423118, 0.03528033691127935, 0.06334470014177984, 0.06937472375049707, 0.08519948024543063, 0.02382866118193394, 0.017637458419607534, 0.04717261087329638, 0.037006076365228624, 0.07781310562765406, 0.08415396175076885, 0.04748141708513422, 0.07364243869819949, 0.01510755742915095, 0.05688000590570512, 0.06478413338622739, 0.053375590322238785, 0.05650643845118823, 0.04811271183913754, 0.08298186254837821, 0.08511888779579632, 0.09618315094661328, 0.044932462530390876, 0.06322754614595925, 0.09225314287769218, 2.605126480902395, 21.835738651214108, 44.89856335424608, 46.0828955711857, 39.901271558577015, 25.26735559586556, 26.683321422146214, 27.90559864813282, 16.269981668841456, 29.412120234581735, 38.6800298383159, 26.996193201311176, 20.523372427109752, 7.142474776314152, 2.6376564127783624, 0.2659179438506403, 0.048852170547170025, 0.5764601415684146, 0.7436777687361165, 0.6546153897239316, 1.8609950042540029, 2.114836828362557, 6.35620576720084, 4.864457297709681, 3.0677501857280736, 4.229080398236552, 2.457951307296753, 7.807081668607651, 4.261331596682149, 1.8289812317778988, 1.1563836134249166, 1.8885253850490817, 0.23743217480519127, 0.5779817760471375, 1.0585675460676993, 0.3427332429395568, 0.47454801658468865, 0.06862317617501944, 1.1049590115585635, 0.5453423855285491, 1.677168100591629, 2.0504458512990706, 1.3367026924125611, 0.42237329206639723, 0.24331707837841204, 0.20819824429288988, 0.17157858267666834, 0.5232829143924098, 0.8839052603129418, 0.993696078658104, 1.5978480923560359, 1.1529303342103958, 6.019066774076031, 5.458020750553378, 3.6675982561803635, 3.6279879558470944, 1.4587397633060333, 1.5301309453864254, 0.35974018035396454, 1.199427213399641, 0.7514560739359548, 0.4744248602899813, 0.41457228002048313, 2.6915139873181624, 9.062047927610337, 18.415149450302124, 40.81212043762207, 31.482464882635306, 42.82994454906833, 38.10816003430275, 20.307353773424705, 37.93510506230016, 36.07372468517673, 46.224697097655266, 37.75185585021973, 9.739243176675613, 0.22583268432607576, 0.04149020732110066, 0.15779094590294748, 0.010582834347001007, 0.07125298747973097, 0.02404971202204545, 0.05300141765826172, 0.07521573048565658, 0.041496278567900585, 0.06750812754034996, 0.053344736131088394, 0.0027987906698047397, 0.009001784004090775, 0.06899835241417732, 0.028259589246684508, 0.045445913809441754, 0.012510878469554648, 0.03869347694900729, 0.014122365485696543, 0.013742792859463202, 0.03894113019228943, 0.08209994979082577, 0.06904000461462044, 0.022416071658353173, 0.0770361545766073, 0.05716661088949731, 0.009554533678437433, 0.06802650093431435, 0.06165489787235857, 0.07875358580701775, 0.04816400525610774, 0.15836376516569048, 0.031162514726841645, 0.042929916357200955, 0.031325139871407906, 0.009734964621583781, 0.13810882945695233, 0.03352078999723158, 0.046323758640116265, 0.03432122164315755, 0.20855380102030693, 0.08036765645468429, 0.022794264368712906, 0.06871273185336782, 0.039709382314956, 0.037889345098407044, 0.029625510609137918, 0.0170972055545257, 0.036066917687534325, 0.06553935052286233, 0.022145424286023747, 0.013696647553344168, 0.05159627450930496, 0.07133480567004412, 0.03167483219576459, 0.04183354877656506, 0.0265756341433453, 0.001671432318905699, 0.029731433755988558, 0.020445413895011432, 0.03354066614842704, 0.019532840383509477, 0.060761555082975864, 0.05956702865660191, 0.06039730708805784, 0.028541597702931014, 0.02212199348685963, 0.03327204507865733, 0.00920045167027462, 0.03603895547829809, 0.030018375818467433, 0.007220617131209903, 0.07237461680967001, 0.05602997389712161, 0.04724336675398293, 0.031254654036714666, 0.0556895474062091, 0.03577750882193927, 0.026324596706657644, 0.036509973147223075, 0.09097088023179001, 0.08799072925842578, 0.03493205418870334, 0.03708455441219192, 0.02370416614857893, 0.03417395273103349, 0.083615064861313, 0.024829685289953506, 0.02899327548220754, 0.03510041733182246, 0.03881983932167773, 0.05598333829473104, 0.05664690450254468, 0.07696636396670535, 0.0492360610364666, 0.049518513823709184, 0.04882150404756108, 0.04971226895107858, 0.06598355894487712, 0.11554412333475006, 7.477939897967924, 35.70958360548943, 53.208351673618445, 47.546739808974735, 37.1664224901507, 15.992448483743976, 17.35911403932879, 31.1787381095271, 27.665937908234138, 44.84832563707906, 51.141462633686686, 36.17416481817923, 15.867487653609246, 5.5388764892855, 1.4451098946794387, 0.405563882762386, 0.15137874401144444, 0.13450400272925056, 0.4480492191449289, 0.477500090435628, 1.5009094101767388, 0.6239173885795378, 0.594929295682138, 1.7628298459514495, 1.8308951032738534, 2.9545625948136855, 2.126551232030315, 2.98065836871824, 2.185024945966659, 1.3735641466994442, 1.6086800853090903, 1.6183253161368834, 1.4713510414285045, 2.2916119233254464, 3.033082316960058, 2.9737219022166346, 1.327122548414815, 1.0225471337476084, 2.5911510759784333, 2.181606600361486, 2.6002463169636267, 4.547509685639413, 2.7655497049131705, 2.0568063422556846, 1.0752312454485125, 1.7805517272603129, 1.4838942909432997, 1.6997467341922945, 1.1323181563808074, 2.828997229376147, 2.944840019749057, 3.1755565299141795, 3.3946919969974028, 2.90080504071328, 1.146956074141687, 1.4163939774997774, 1.227921271516431, 0.32020878707689626, 1.0411611704095718, 0.611846600809405, 0.11647942475974561, 0.08957948070019485, 0.0876667200317306, 0.9366020584298719, 4.644973720273664, 19.049918382398545, 45.71787980294997, 51.95340502646662, 57.52924250018213, 55.789989040743926, 17.417055291514245, 24.32667709166004, 37.929998136335804, 46.115266892217825, 48.077628689427534, 18.338529871356105, 0.9734478845230996, 0.07722863416758276, 0.05292391254296226, 0.013558954740273617, 0.06467140354816953, 0.02699216572387565, 0.03334133007052926, 0.11504724636794099, 0.01520877009287717, 0.07259944829368785, 0.08364449795936385, 0.054239718348629055, 0.04764889922714041, 0.07125720862419375, 0.04796556550108137, 0.02806967413503557, 0.05893407532224252, 0.02960275779778679, 0.03855315645435645, 0.053656828860121394, 0.06638454468620401, 0.03175732837389073, 0.06419268669560552, 0.014860397354970056, 0.039812424971211346, 0.018151689193121368, 0.04788487346001691, 0.043416596693737854, 0.04667207200620924, 0.02014293173898853, 0.04997088874299681, 0.06847810210479845, 0.0724397419441131, 0.043023815754080014, 0.027712177289950273, 0.08202759278637749, 0.12371514052633317, 0.06232899778913106, 0.026163656955524802, 0.09425025748749895, 0.11104911776079286, 0.050745162316748214, 0.04167498772843711, 0.020114086613419558, 0.06707257591187954, 0.05089403618307364, 0.09942627692174527, 0.2146864727499985, 0.13000453852357405, 0.18856253745334764, 0.0625287743675853, 0.12373956340935924, 0.2443675841054609, 0.10228211480763652, 0.10805699283317213, 0.156067140821007, 0.2462146527344181, 0.13848291019037848, 0.15867432188843528, 0.14688488756937368, 0.14581130727404548, 0.07850233961137072, 0.13515427348113832, 0.14266936619195247, 0.09002446287101315, 0.2446721959859133, 0.15708403060993842, 0.11634352076197825, 0.1792216427143543, 0.1334818116118831, 0.1083791021618151, 0.08901459044746815, 0.19071696055752618, 0.0930174304953506, 0.1341107391542004, 0.09503976471962468, 0.15132763062513646, 0.14314833968397112, 0.11231899276495942, 0.1333161680808952, 0.15162583801054186, 0.16317741735087288, 0.14120878892079478, 0.09715018373343254, 0.14274505567887139, 0.16339913851791815, 0.2126538576257806, 0.2100773200753235, 0.1369371439420408, 0.13782546885551947, 0.13654008057088624, 0.1773104065608594, 0.16339624270556435, 0.12918297051181718, 0.25942816789592466, 0.16284047656001585, 0.22219185146593282, 0.17972221988583767, 0.21361863811410245, 0.21917231591238132, 5.6709878002443626, 33.54374885559082, 60.63046055455362, 62.19699244345389, 53.705135545422955, 36.65690268239668, 38.17507174707229, 37.60720668300506, 22.18649660387347, 39.77790517191733, 48.06399845307874, 36.949786063163515, 28.315525554841567, 9.855311993629703, 4.100330068219093, 0.5906988355901934, 0.7496191176675981, 1.5028900845396904, 2.7001204029206307, 2.82289132475853, 8.187984016633804, 8.075220777142434, 13.785727927761695, 12.786685535984656, 12.37782943633295, 13.243004275906472, 8.972565916276748, 17.84269521313329, 15.411979863720557, 5.439437050973216, 4.289658463770344, 4.437118989806022, 2.5536630230565227, 4.264578338592283, 3.742600347726576, 2.300749084641857, 0.9771149329120113, 0.8140240068877898, 4.094291579338813, 3.3736837823544783, 6.634990678679559, 6.041084508742056, 4.1649535682893575, 1.7693906229349876, 0.9938546895019471, 1.7052425876740487, 1.3978976732300175, 2.473784689941714, 2.7262105384180626, 4.45165676455344, 5.737519043107187, 9.408862917653977, 15.411459169080182, 17.738283680331325, 13.376653155972882, 12.19616093943196, 8.872905354345999, 6.354885889637855, 3.727216076466345, 3.6000165535557658, 1.3681114392895855, 0.9064808908489443, 1.0577905490513773, 3.4774069391912033, 12.082472020579923, 25.348072090456565, 50.65415913058866, 43.210794925689704, 51.17677965471822, 48.1079250766385, 28.360599471676736, 49.630620556492964, 45.900352385736284, 60.89572260456701, 51.22212617628036, 18.49500890701048, 0.7501288419288974, 0.19999135886469196, 0.3211535879921529, 0.06050567405538694, 0.1821514387284556, 0.08213470719995038, 0.151901982063728, 0.2050035657180894, 0.0877246362788062, 0.2392787991031524, 0.13691569348016094, 0.06892318386704692, 0.1462439937336791, 0.1421726501036075, 0.08925190916465175, 0.13174812399571942, 0.118781978624963, 0.16639553821615635, 0.18660285389952122, 0.15579953098729735, 0.18004878784619993, 0.15508458709284184, 0.18826796132470333, 0.07254395288445296, 0.15789422987689897, 0.17636419604382209, 0.1397186100122429, 0.2046704094015783, 0.12156045695226039, 0.10524035566636633, 0.15238713022441636, 0.2764509173650896, 0.14165385536128475, 0.21647864351830176, 0.30284203348621247, 0.2896746981047815, 0.21181828552676787, 0.18745733304850518, 0.09508460384583282, 0.14576557182496594, 0.4857052904703925, 0.1889578081787594, 0.24903204832826895, 0.19827870802292902, 0.1497192137063511, 0.11602187874696909], [0.0563655816949904, 0.10987476625990485, 0.010088939377437196, 0.030718202882957076, 0.032020429780166, 0.03027899701508784, 0.019684567927352844, 0.03817603052143128, 0.01085031490337344, 0.06334420601506868, 0.0637829062649079, 0.068340964705473, 0.02717907777086141, 0.038715034663196535, 0.054841196960619384, 0.02490409732525868, 0.02932656011844595, 0.004002682760455496, 0.03847429536343102, 0.05389821550418293, 0.05319264469548099, 0.030925138553063718, 0.0356008144726436, 0.050843355636442863, 0.09159956262597153, 0.012250159596723896, 0.05256977690864475, 0.022952626233980544, 0.025773105331726616, 0.030777377429448312, 0.01662986510763726, 0.04418113712041129, 0.038558902113788554, 0.007637835318042387, 0.05793725320648763, 0.030706022084961017, 0.0291780578047638, 0.0068401946261855626, 0.0163228266436847, 0.017145216284740358, 0.038573021114233046, 0.020100890748923825, 0.06008820210192954, 0.056973897641704935, 0.025026748001935984, 0.04586327468015013, 0.01743469792868822, 0.042329989073257294, 0.05020354581516116, 0.031482668616057884, 0.09593961159548453, 0.05408574233672792, 0.032381732167015155, 0.03738216424901639, 0.02441173261632362, 0.79997806058776, 9.885387747518479, 38.164897118845296, 47.3182225227356, 48.33662279190556, 47.818920919972086, 26.63196582948008, 33.93742538267566, 25.975035505910075, 17.91743597676677, 26.534612601803197, 37.29398189052459, 38.17271440259872, 30.68238569844154, 22.05361846954592, 13.910035683262734, 7.039085020942073, 3.127272398241105, 1.0387782079558219, 0.13797531565350873, 0.5416667569548853, 1.456411591460628, 2.6583934935831257, 1.0762862404507976, 1.5454509878350844, 3.2022860117496985, 0.7281724555838494, 1.8968344359628617, 1.703690922548694, 1.8551629301040404, 1.5639676394001132, 1.0508176780516103, 1.0000931579739818, 2.405416552097567, 3.3979281975376994, 1.5681738911136505, 0.2939971193911568, 3.6934532946155922, 2.3400831030261133, 2.5054497391946855, 4.197243500140406, 3.263793924162465, 2.5124112108061394, 2.1827847823019955, 2.3748693783437056, 0.91592951287185, 1.2877815433086888, 1.1460963396295425, 2.987079533838457, 2.0826015645457856, 2.489811004169526, 1.8033405753874012, 1.4910852212098338, 0.9234801367405923, 0.3941329009830952, 0.43002173004131167, 0.011941746962557157, 0.05026335046897012, 1.979483678456276, 6.2782050236578915, 11.73584726548964, 21.226023858593358, 37.31291909371653, 53.30524990635534, 41.83883613155734, 18.90865618182767, 25.822749483969908, 28.339051931135117, 23.740977010419293, 34.465631361930605, 35.463329361331084, 41.58875365411082, 26.74876616847131, 4.045491410839943, 0.04352173843090573, 0.0681311562056503, 0.07127358758401486, 0.13668530019781283, 0.03175821895110271, 0.06105364142586628, 0.026495233215692065, 0.02004967968640549, 0.05090731248680142, 0.02055166071401008, 0.057394246255318006, 0.051202869207988826, 0.0886119269735871, 0.02531372070793183, 0.07886626967980016, 0.03167752882525806, 0.017922466110077598, 0.07439613898074435, 0.024277778312323556, 0.05487571688248746, 0.06220129476259313, 0.047054663976474155, 0.07744673173874617, 0.036044808390039595, 0.04696685880903275, 0.01808054069237363, 0.03281609252876332, 0.05673119332641364, 0.03650454541427955, 0.011991622159257533, 0.1431277932058419, 0.06625152883991119, 0.03619166361468454, 0.04086793708284536, 0.06089408446343676, 0.07168493849495727, 0.07171725974448266, 0.07298658316534373, 0.10688942121041399, 0.03934038074446782, 0.025899793291764877, 0.024073680997976375, 0.05908277681878498, 0.04202418592608264, 0.0499572676997031, 0.07048926676713652, 0.018861956120799148, 0.057860812953402924, 0.06541829330906754, 0.07662684912042272, 0.1271280622290027, 0.07054958853029436, 0.04444092519641404, 0.058481845959660515, 0.03797651058243167, 0.02477244511547108, 0.0210506042029949, 0.07365431306102584, 0.03839325475236101, 0.11189369139291587, 0.09228695033779068, 0.019310881729207693, 0.03415585773426198, 0.01669345423579216, 0.06047446363335175, 0.02202038724546231, 0.02815394189148661, 0.034229946097419146, 0.04169423185709504, 0.030802893902986284, 0.041409281623219295, 0.05600863068755116, 0.02317992452111456, 0.03612384951162723, 0.007777978176055777, 0.052678821863786834, 0.01952804467310348, 0.04162444507763271, 0.05113607400187081, 0.0582350583957328, 0.04449983735779121, 0.027262970144229553, 0.03553005093107781, 0.038659612032314467, 0.04572786480909394, 0.05552469294578318, 0.01909303505183949, 0.043998436641789256, 0.054260804918744875, 0.02823586158844973, 0.01217177731075114, 0.057683666612231926, 0.03477644257908387, 0.0429623716721131, 0.05684171300080996, 0.13186044780717743, 0.007240332403941261, 0.08650376791915587, 0.017760662594810128, 0.05801820954788597, 0.02754756797766013, 0.10614997016326075, 2.4656038515029417, 21.34273986662588, 52.7853318952745, 52.697753214067035, 45.26948621196132, 40.737662084641, 22.902680212451568, 15.407171037889297, 22.19094849401905, 29.055649349766394, 40.650299133793006, 54.66587697305987, 48.89409749738632, 33.688288196440666, 19.516111689229167, 11.357839626650657, 3.8092968204329094, 1.855813798404509, 0.14916628208612243, 0.40363125743404515, 0.320004639966834, 0.36874073287171705, 1.0239015159107026, 0.9936615127709605, 1.440647340589954, 0.5892213277759091, 1.1663123580717272, 0.35348136458666096, 0.6601053596504274, 1.126913988301831, 0.8501346950088778, 1.4229101375226052, 1.2539187410185415, 1.8470604164946465, 1.5109272661709017, 2.0789677337292702, 1.9340580966203444, 1.685656967662996, 1.0861745356552064, 1.8667391927972918, 3.4003183918614543, 2.291398399299191, 3.304467186812432, 2.049073389460964, 0.46346162115373923, 1.2968146392414648, 1.647348526504732, 0.787346312595952, 0.6363043561577797, 1.6587694878539734, 1.2815010932184037, 1.1452232445439985, 1.0777369045442151, 0.28248370655121346, 0.36803675935633723, 0.2083691278652799, 0.03527608512329959, 0.06769096208435875, 0.40477113497834055, 2.9582103990739395, 8.058475198284272, 21.325218639066144, 29.943358205979873, 46.849181575159875, 55.30210110449023, 37.7851842295739, 25.10432424083833, 29.731705150296612, 27.523510763722083, 27.70242967913228, 41.57056170125162, 48.09279649488388, 40.24545954119775, 9.686214693130987, 0.23395306310586392, 0.05146022878527161, 0.047097928791997895, 0.06773207802325487, 0.030991100638564077, 0.04655885187187984, 0.008014550915123115, 0.04560206168060822, 0.041744785999218305, 0.056276455025879614, 0.015328122761040447, 0.02879584887846103, 0.0922779871090766, 0.0070044323858324325, 0.08879011136389549, 0.03303326313353835, 0.02327257327945723, 0.024596470888824235, 0.05434296018774471, 0.06262418295767519, 0.026561260418665987, 0.10828164045608814, 0.06817334466764043, 0.030082541427785353, 0.07511908083312935, 0.05397808400072879, 0.012667003358083387, 0.036589209621231404, 0.01533770556336329, 0.11315513942991534, 0.09730585279964632, 0.09369692750154965, 0.11586408761720504, 0.043778791573018803, 0.09427406750018559, 0.039195379452599634, 0.0657030864949188, 0.07466658333977384, 0.06759537729404627, 0.05048753077825231, 0.025189055220013665, 0.013111118891937359, 0.08122452579799198, 0.1445830385050466, 0.06395258324881715, 0.10120186188648786, 0.04712205673117311, 0.19972731900070945, 0.2160463401026303, 0.16419544094993224, 0.18463969230651858, 0.07804156070755375, 0.21885690219219656, 0.19670094994287338, 0.1249609910131943, 0.1355120212200188, 0.13435124479714902, 0.20322375960888403, 0.185282853762469, 0.239150908385073, 0.20678645150075037, 0.16525385270435966, 0.1335773274542824, 0.12130921075661337, 0.11118311419962876, 0.19189221604216486, 0.1856984104961157, 0.1510499084308263, 0.12379269160690809, 0.2041839742131772, 0.10519184697900089, 0.19060209333415956, 0.15867819829333216, 0.15595233488467433, 0.14992869278836637, 0.19397983627934612, 0.1024947654936583, 0.11008277445310548, 0.15190578185983244, 0.12366807208426538, 0.14455581174021767, 0.12081817137978731, 0.09555176426205905, 0.16289007309223377, 0.10239091461464282, 0.11715680736327365, 0.10325893053724881, 0.1481854903601831, 0.10860060882424155, 0.16261346938629306, 0.25058185952084683, 0.14708243100152862, 0.09043107935858351, 0.19997645079368548, 0.20404997011346204, 0.2133519782294189, 0.1846946208106895, 0.1755597730798106, 0.0933666057103584, 0.14678302851896133, 0.13565783839552634, 0.1604800677347568, 1.452227280505242, 17.407029713353804, 54.91932484411425, 64.03289310393795, 63.19183495736892, 61.830415571889574, 38.10060554935087, 45.15499614900158, 39.643030551172075, 29.33945440476941, 37.257358720225675, 49.139579034620716, 49.15801809680078, 41.068761117996715, 30.429535988838445, 19.28074594466917, 9.033004737669422, 4.523022818949915, 1.5239763788638578, 0.8033122590953304, 1.3916194294729543, 3.2787982158122526, 5.343762597730083, 4.162749686548787, 6.495061103374728, 11.433704149338508, 8.658980265740427, 7.505644088791263, 9.948696763284746, 6.484457956206414, 5.385446606143828, 6.319540921718844, 6.415970431220147, 6.286983288103535, 6.403777743539503, 5.172746767920833, 3.953964128609627, 10.2813059091568, 9.481932751594051, 8.981769757886088, 12.047228543989121, 9.610974807893077, 8.720200619389935, 8.004733333664557, 4.612950999890605, 5.185543990904286, 7.420118278072727, 6.875579549420265, 13.430030730462844, 7.566271183952209, 8.91791553266587, 7.731713325746599, 5.50567215488803, 2.8429924912991065, 1.834948627698806, 0.838857145319062, 0.24478586811211803, 0.13871799193082318, 3.0494113891355457, 8.212799872121504, 15.488738686807695, 29.098915053952126, 45.79982203821982, 64.81566482974638, 51.170095935944595, 25.215856836688136, 34.1945053685096, 36.91114679459603, 35.046793260881984, 44.584224608636674, 51.83011316484021, 57.04330398190407, 39.499636542412546, 7.822743202409438, 0.16031425566442553, 0.15717873439913796, 0.1601024170316035, 0.1927920475962662, 0.06918435090131338, 0.19167833961546424, 0.11661286195439678, 0.12934738830212625, 0.1310168164632013, 0.1588733974964388, 0.13950572949984383, 0.14374860021616184, 0.19726525030789838, 0.16951006867231863, 0.17053823527549544, 0.11567923060107617, 0.16066527715133083, 0.0801449623559752, 0.12382076872933297, 0.15354468907800414, 0.24788267129371244, 0.21251370950091272, 0.13036505950074043, 0.17254992087762203, 0.23293303235644297, 0.12421169573621405, 0.1245478857609053, 0.1471147292684163, 0.10294812866636824, 0.209384745948257, 0.2950426761902148, 0.13933567330241203, 0.16691830129392687, 0.20061113931719335, 0.1273630213953795, 0.16068548655077336, 0.18446511619033354, 0.18704021349549296, 0.17130862861391039, 0.09918184890862435, 0.1550647300938445, 0.10277111639058399, 0.1895104027203014, 0.1514008226654222, 0.17618549837460443, 0.0870155299743337, 0.20878656917522032], [0.012207759502944688, 0.057505761844015894, 0.047743246785455176, 0.06807185333943175, 0.01599010220924092, 0.12816500819979176, 0.04653768103209235, 0.06150005235066337, 0.03918275049316787, 0.09959363648968358, 0.05401618155320326, 0.026556024207703532, 0.04584812529144749, 0.08759409489650881, 0.08576740420633748, 0.11938472894290764, 0.04479470843028638, 0.041219050500301585, 0.010536757988795158, 0.04990594746965555, 0.058844328121913064, 0.05790367940320604, 0.026586187004502264, 0.03269924113767282, 0.07181052328838457, 0.06239426081940051, 0.12553099873325518, 0.0682230944174432, 0.0749120532324718, 0.02941361260450175, 0.03401746395074072, 0.014940747529298309, 0.029129451441188014, 0.037489443371493014, 0.04201950129842566, 0.014936767702531672, 0.02590049043177597, 0.03876837736536418, 0.11742004283493566, 0.10866189585818399, 0.0192326718130179, 0.04768368344934237, 0.06514798684586441, 0.024043667588322878, 0.07287197641187138, 0.022191584913901264, 0.09095905949511836, 0.04322694396720298, 0.05337002086302927, 0.06530191689249008, 0.04552717275557019, 0.04022582133691158, 0.011156301911649926, 0.046908961714155255, 0.05801603002774139, 0.05520353739660594, 0.0854332136711286, 2.2327778416295208, 23.487456575516735, 45.65296849896831, 46.7224850962239, 41.96490895363593, 42.80929719248126, 30.854989597874305, 31.694694526733894, 35.090202131579005, 22.195474909197902, 23.492077127579723, 31.064973685049246, 33.89261230345696, 33.931341786538404, 38.922416625484345, 34.96424698060559, 30.925902128219608, 23.80693558723696, 15.442111511384288, 7.7108487679112345, 3.032544707098315, 1.0018598793014404, 0.16841157519769284, 0.021253743907436732, 0.4530394852401749, 0.16924320960477476, 0.46246874056035475, 0.15074787060579947, 0.30570092040204233, 0.44960446956176914, 0.9873335652293699, 1.8126627009722496, 0.804257060010587, 1.6250384526868022, 1.8045576133074301, 0.9420559302933755, 0.3168544557786757, 1.3447310487108848, 2.6704518400853683, 1.5971403496880687, 1.6226253370123527, 1.8876516770931984, 1.136095153708612, 1.8075543041190796, 1.268620887590993, 0.05449421275707503, 0.7122809728307109, 0.5216348447626638, 0.2744572195074251, 0.02906549650604927, 0.6387327935907149, 1.694190696843209, 4.528200347577372, 9.098971159227434, 16.504884573721117, 30.13432272018925, 30.427851330849435, 32.844876627768244, 50.247205380470525, 48.219147805244695, 70.19735674704276, 67.20538062434044, 18.95018819839724, 23.160707450682118, 29.69629203119586, 35.64135005397182, 39.17528398575322, 36.83104415093699, 34.597328862836285, 12.116246569541193, 0.45478965906846913, 0.05046982648632219, 0.11279157708368956, 0.022042002416245883, 0.014469437789352191, 0.0914423460621507, 0.05159426352850372, 0.049577510254758025, 0.03999052509184807, 0.056615759197983055, 0.04545056779358176, 0.002888373161230477, 0.0327947914540287, 0.030177737428476254, 0.031608067633163546, 0.042060176736765334, 0.025516473537971898, 0.046710782429023136, 0.0403338359037955, 0.009267308163426576, 0.02697646283664771, 0.03375507117579541, 0.02040952650619851, 0.09207849781359397, 0.016495198341867617, 0.009237050563247215, 0.07182773728404315, 0.029642734180895552, 0.029605243753101078, 0.04194741625519049, 0.03451275894598615, 0.025721783186459256, 0.03114446952578522, 0.013968218061622354, 0.045344966403659315, 0.021216119414255507, 0.022861588175498673, 0.05330013449213678, 0.034793851927163146, 0.05695306388060412, 0.018110435358398867, 0.09817695605658716, 0.08609204928600982, 0.03415769634528026, 0.018454213483980107, 0.03875571776241545, 0.02295242705112023, 0.0239964229460325, 0.031015293695212855, 0.05273819367791857, 0.029187796697501215, 0.033734547680303935, 0.0695907145798687, 0.037651528424072656, 0.1016581055497931, 0.05032427744158814, 0.046364786478901104, 0.0526430570490418, 0.059030453013556625, 0.06677827557488795, 0.06830731046295936, 0.059213685923286026, 0.032333828689109896, 0.06736358973167597, 0.10663532516768864, 0.1107979175304213, 0.055543144173439474, 0.05514118933088838, 0.09162103607048912, 0.0441933102575281, 0.017372380506487626, 0.07177656261070121, 0.07001206293822297, 0.05689149722456933, 0.0457436960160492, 0.05368259239701494, 0.05158935673534871, 0.12971512582753936, 0.12427406295412972, 0.026612772170694608, 0.007107659381994557, 0.029890557878740856, 0.016868524478688356, 0.028689996594743385, 0.014244717388083378, 0.04751477638379701, 0.020094534134372108, 0.050238988872978, 0.04843769399749656, 0.054698804198133374, 0.04429010163632132, 0.05173446527952629, 0.03229133762238968, 0.04922267364998979, 0.04138578187614199, 0.044186319705219045, 0.03833114034346035, 0.022899743184567462, 0.03723731234429344, 0.03947433887890751, 0.04900616954170889, 0.031026152991539532, 0.05263398656801832, 0.03342833084565017, 0.04127998896423848, 0.36010934280291684, 7.51852858451105, 37.38682047013314, 55.512120492996715, 57.44836714959914, 46.898854471022084, 39.54136271630564, 29.24300136104707, 24.189494156068374, 24.633553528016616, 26.502598216456754, 34.905470263573434, 46.042385332046024, 54.88574935543922, 49.28082358452582, 47.13457715126776, 37.18177464700515, 28.881280383756085, 21.602004612645796, 11.675805584076913, 3.962726458426445, 1.5210868177875396, 0.4475558891652092, 0.2095782904014472, 0.03021124419906447, 0.422753670042561, 0.33834787986932263, 0.5421889224840749, 0.418308460183682, 0.7109284292786353, 1.145119546882568, 0.24242982598802737, 0.26155228456181867, 0.33843564290192824, 1.0290069709862433, 0.42506973769876266, 0.578222940525701, 0.41756409851293413, 0.8006170392036439, 0.5271012191810917, 0.5693316627894679, 0.9100773365747545, 1.2962960283602438, 0.627825785308115, 0.9557325609268682, 0.9577914988321643, 0.4355725886360292, 0.38788453465507877, 0.21429610498730214, 0.28716140877335306, 0.01777421660541046, 0.32260792930760696, 0.7944125237484133, 1.7142152545913574, 4.9409391034034, 13.56758236885071, 23.327845527279763, 38.8597567619816, 44.92328605344219, 52.55832864392189, 55.94982954763598, 71.57167680801885, 73.37858723055932, 24.897323116179436, 12.41291601811686, 20.710893100307835, 30.91920271996529, 36.02231810169835, 41.73090427152572, 47.534760890468476, 22.538874495413996, 1.2194078896314868, 0.012811750883326657, 0.040920115331368107, 0.036119344914632465, 0.010298718191352824, 0.07665118007289787, 0.021234928788016402, 0.10779784061014654, 0.058109082897464116, 0.04598080788949325, 0.032915538402214166, 0.05664559832263378, 0.04589307550040465, 0.03143974854010007, 0.014359567374471697, 0.008274276267677065, 0.022296498739911665, 0.06704593903475231, 0.06504621206512375, 0.009753087389042542, 0.06675749927038147, 0.05496620335766385, 0.04561025882139803, 0.03330356576630185, 0.036819924660507715, 0.03981647757633079, 0.02944950382375429, 0.02688627513576179, 0.02742587108044855, 0.02002843606826519, 0.027552966982306495, 0.041585899363722534, 0.06583269324994857, 0.07162414175728637, 0.060085762111890706, 0.01041812065523118, 0.0761659553034171, 0.10424683155912547, 0.06037782164170377, 0.07198449419510942, 0.07801716080716542, 0.0628078295548837, 0.042755600710910176, 0.07228198911874525, 0.06924717777198361, 0.0929026015763802, 0.05416820021045785, 0.08534177341648648, 0.05219423294728322, 0.12155672610406915, 0.1636786686797296, 0.13508716417897132, 0.12952435461263503, 0.12502443075420397, 0.31273995075495015, 0.1929806124779486, 0.17317578406824222, 0.16913338323994992, 0.1678623361212592, 0.17828563648846843, 0.18822567327128303, 0.18808115844524678, 0.24730289595261698, 0.24330889655938073, 0.458835706475281, 0.18172952346503737, 0.18429152066669158, 0.1274109478559225, 0.1970624208690659, 0.17427268407998547, 0.1488692544761204, 0.2551418140290245, 0.16032305035379626, 0.12031416979528244, 0.17838231678451263, 0.268591805210998, 0.12026298746106126, 0.22837427294542714, 0.2951430030647786, 0.16602856677866754, 0.1582460787387625, 0.1678307120117449, 0.1699418358264431, 0.18608700093482772, 0.12761283500660814, 0.1495615528115342, 0.10542178060859443, 0.21597492538632887, 0.2081687499078051, 0.19882382554633005, 0.09832844994361363, 0.20907198289229026, 0.12533990576142265, 0.151139096386971, 0.12755550098635499, 0.18902940675616267, 0.18464407432944546, 0.17278187697933567, 0.11031808601992746, 0.13527294050060934, 0.14847121051242276, 0.10136733687813244, 0.13621881393895996, 0.11456597461214951, 0.25403190584432694, 0.24235891688975597, 4.351797142336446, 34.7023150228685, 60.390219303869436, 64.44397710984754, 61.694387774313654, 57.085096836090095, 45.207226430216146, 46.46374987017724, 47.47092431591403, 32.60565127095869, 34.30806975210867, 43.5625962288149, 45.39781831925916, 44.1627541665108, 52.48263474433653, 45.62137772960048, 38.38229056327574, 30.7541258488932, 20.511095408470403, 11.089525972643207, 4.643345446355881, 1.8056188595871774, 0.3479580238701836, 0.11875417729419087, 1.6212526300261099, 0.6316944067516636, 1.9483241246592615, 2.9498912970865927, 2.8352536549491267, 3.8340952704029703, 6.989079704207759, 8.627890579162106, 7.237220608418988, 9.061200695653117, 8.671282779785896, 5.316715894206878, 5.870613888386758, 8.740204707268747, 10.066139390391688, 7.974655618590694, 6.569864134634695, 5.318877120171824, 4.273622833913373, 5.562928463182142, 4.019668241662364, 1.0351498929723617, 1.6976730261118183, 1.6349810482032838, 0.6692849928813597, 0.1542950415563199, 0.8591187000274659, 2.429143704714314, 6.315304271636471, 11.219265230240362, 22.69699896535566, 38.337261753697554, 40.33986706887522, 44.29634617220971, 62.11086503921017, 60.14760894160117, 79.01106372956308, 75.1754093170166, 25.89787267869519, 31.30637791848952, 41.19226478761242, 45.901152549251435, 53.52225503613872, 56.68218704961962, 55.09873013342581, 21.755745833919896, 0.8722929608437323, 0.09842732891200051, 0.13315440095480413, 0.12638618268312948, 0.08958938621705578, 0.25117848879627647, 0.15296073089684212, 0.19251009659661403, 0.17939670912681088, 0.15818600212374043, 0.2603630403116826, 0.20620969454607657, 0.10831917876437788, 0.11117908457714705, 0.2175794046131834, 0.09856955313514318, 0.11759494070804889, 0.22285424172878268, 0.10084822037888151, 0.17508073830075804, 0.16693186105018662, 0.11841301535887104, 0.10440377233129355, 0.21308168708797426, 0.14443663910271662, 0.07300451728365115, 0.1283539944298325, 0.11001554257687061, 0.09729912654767114, 0.13710736867881593, 0.09800451732571087, 0.17195768894687777, 0.15967515447447378, 0.13066020253444874, 0.1452080436771916, 0.21580532884165166, 0.14460248181656485, 0.16611861275328746, 0.15217052652470528, 0.18757290507276214, 0.2318286859700757, 0.2590472996234894, 0.19451288025706046, 0.18160563172592273, 0.19907329441799274, 0.1629845930203315, 0.1265926663613608, 0.318220206686566, 0.1324253150772664], [0.047671958473661256, 0.017586908107923887, 0.04547625472168288, 0.03760267499714129, 0.029074413769487894, 0.030203110260528424, 0.04804220493702639, 0.06820464702022654, 0.0433186523526186, 0.010225332713866187, 0.0436509698028526, 0.04737530241630251, 0.0577708206049377, 0.07956033001743978, 0.04393430359120812, 0.019033567476717216, 0.015989321757168058, 0.08630644665249894, 0.01822761999773643, 0.019644112739291404, 0.008130072664860035, 0.040036122645101244, 0.038126433989213365, 0.023844756689223073, 0.032598807010799646, 0.02553409547545016, 0.03889072160687178, 0.022489934025572676, 0.047283459965500145, 0.0795762263418686, 0.035093526370943554, 0.028091739382474657, 0.040295006737353346, 0.045629870672259605, 0.03968084553977655, 0.056374146557983854, 0.007050688774700487, 0.036637442516944105, 0.044179421083460894, 0.03374584747718708, 0.040546099715415514, 0.06144898876007046, 0.06618225916979775, 0.016216066545776783, 0.01936178827177613, 0.015967847355040574, 0.003821041877193737, 0.009484499835619524, 0.045741665883049856, 0.027201851649630456, 0.07777216588898052, 0.0403598943845399, 0.10206249272150379, 0.04455674619924638, 0.02400701985724511, 0.025225371618064183, 0.0600441137418872, 0.06992203228536152, 0.21504299474820016, 5.458393866016019, 15.235489876039567, 40.99132960842502, 44.913421292458814, 45.66093091041812, 35.4041172612098, 36.540310229024584, 32.369193146305705, 30.013725526871223, 28.436703258945098, 24.77486083584447, 31.122644293692808, 24.789861940568496, 38.484840931430945, 32.70339085209754, 30.89428782463074, 36.78966314561906, 41.91425154286046, 40.23599878434212, 34.36120217846286, 28.664930289791478, 18.794846650092833, 11.498976311376019, 5.606268202104877, 2.3254340310250563, 0.6688983942712508, 0.08457173247851672, 0.03496097783828455, 0.25057513326887165, 0.25131617011802815, 0.00943891664651493, 0.19834198688547458, 0.4656052577399439, 0.38231486094094097, 0.26362587006822713, 0.7084687354583895, 0.2450878446501109, 0.08147777148312138, 0.1865209897439326, 0.07832626962373335, 0.3428961132322589, 0.784742042662636, 1.3154656319848954, 3.228499701907558, 7.283704127034834, 12.583614626238424, 17.819031553883708, 24.001722451179262, 30.906490318236816, 35.60075744505852, 36.65731845363494, 36.480160682432114, 36.694808467741936, 23.10430180641913, 34.988440159828436, 48.31569302466608, 37.19974302476452, 49.935871170413115, 61.449749546666304, 44.286524557298236, 37.7554448189274, 43.442991395150464, 43.45143233576129, 45.51863516530683, 38.1601079048649, 21.267367601394657, 3.9653801869961525, 0.03873746954805909, 0.02808486757379386, 0.046298293877513184, 0.019176119202447515, 0.02642163323358663, 0.06324578286899675, 0.042413205374032266, 0.021263800726662722, 0.03054992783994925, 0.02852086161804055, 0.023781349506950187, 0.023110068793739044, 0.09837108273659984, 0.10256742893327629, 0.07002279583004213, 0.037312867765825604, 0.04940215655932984, 0.042007217078559825, 0.07079344963835132, 0.026335913740519076, 0.11027314730228917, 0.04567448380253008, 0.0015380662267899983, 0.05287794343706581, 0.021562100042619055, 0.029548988001601353, 0.025750984542913018, 0.022651390886054407, 0.0336524996636135, 0.04216056489836305, 0.06598522135567281, 0.011505967422929263, 0.058361991503906835, 0.04130116746490521, 0.046859200473033616, 0.02459457482121164, 0.02560762650964241, 0.026218047282928904, 0.04891545324015522, 0.03872127827977942, 0.040473348175686215, 0.05956604040317959, 0.0663103950360129, 0.08913842089954885, 0.03574352133117857, 0.03271781876983662, 0.03908228955321735, 0.009437200609564541, 0.03212950729404486, 0.005646532921556143, 0.04371055612160314, 0.02276399048916515, 0.028152132008765495, 0.029194568914751855, 0.018542711960992986, 0.04039627590006398, 0.010957110432847854, 0.037274276086639975, 0.01598292683822013, 0.031991548265420625, 0.06283506015015226, 0.05985152306816271, 0.07910237797806341, 0.022691012953498194, 0.04405009012008387, 0.029808994412662524, 0.09254570419509565, 0.04675003677426327, 0.04641016952753548, 0.039946678049501874, 0.018943437232425617, 0.031170685054554097, 0.01118393949112825, 0.07848324870029766, 0.029905444882329435, 0.04764574294489238, 0.04113933139090096, 0.04961136368013198, 0.08255532011389732, 0.048843149861861626, 0.04963294820739858, 0.012523102359996449, 0.10147626692008588, 0.058277959319492506, 0.10055074077700416, 0.041079522906652385, 0.0651294245354591, 0.018028270513299974, 0.028166335278881655, 0.021299841333060496, 0.03559680400235999, 0.09361767570578283, 0.0370904571196485, 0.020515947610199935, 0.08542073409884207, 0.0372299847132977, 0.0692935643957988, 0.019581613371208794, 0.008508966345670483, 0.09012359464841505, 0.031982924030613036, 0.03544198146330253, 0.01861239531858554, 0.04003206620954218, 0.044218208115067215, 0.054026470114026344, 0.05100876934105351, 0.004665252335760142, 1.5504930721175287, 15.809010997895273, 30.38392274610458, 51.81321951650804, 54.725547990491314, 49.45323136544997, 40.090980914331254, 38.31850105716337, 30.11195344309653, 25.03544742061246, 26.88494105492869, 25.105751983581055, 31.2757912758858, 37.84986803608556, 51.58184674478347, 53.47966594080771, 52.852090635607325, 57.16375212515555, 55.61547886940741, 44.97965835755871, 37.90832311876359, 24.7014222991082, 12.068178903672004, 8.541801418027571, 3.2623781936783947, 0.5374491671400686, 0.35411225331406443, 0.2317225215055289, 0.18902139347647468, 0.1851956423131689, 0.050942973879676674, 0.15532766679121604, 0.21408117135926602, 0.08891863027407278, 0.2120739903541342, 0.14986927500895916, 0.12371175441770785, 0.26435049731404553, 0.17816585098062793, 0.30679746801334046, 0.08867806334409023, 0.18134856326205118, 0.11999372287743515, 0.7008476315006134, 0.7513048175361849, 2.7680129533813846, 7.011651963956895, 13.357190355177849, 19.501887213799264, 29.890635667308686, 35.86954962822699, 48.74498075054538, 53.404517250676314, 53.67592173237955, 50.556794135801255, 45.01340250815115, 47.78825190759475, 48.798152400601296, 49.54501482748216, 67.22965225096672, 56.30376854250508, 22.093540353159753, 31.840814582763183, 44.48205471038819, 50.28964542573499, 49.176343410245835, 32.56888689533357, 8.648712481221846, 0.11783091111048577, 0.14742896321319765, 0.03678812435077083, 0.04178596322514838, 0.05574114342790939, 0.016651727341776414, 0.07849035033535573, 0.005977161626722063, 0.006180051873783551, 0.021359812610992984, 0.03598255991575218, 0.03146355280712728, 0.030250071450286818, 0.05413495199454408, 0.04866119248852615, 0.04576679739740588, 0.015589516748854471, 0.012468707244542819, 0.0229652360412142, 0.015314337008843019, 0.14195429972342907, 0.06674177914617524, 0.023305513144981478, 0.0373327860518569, 0.06784554330572005, 0.003299703962364865, 0.03401257247934419, 0.02900395666309182, 0.032570833310244546, 0.01427951022877448, 0.07032664162257025, 0.045672595395796725, 0.02834123698243451, 0.08696444723154269, 0.1385326139749058, 0.050291362473921436, 0.005746606029494996, 0.010485909860430947, 0.05812037120302839, 0.06374421882473173, 0.005221399131246032, 0.031052117626513207, 0.05972038413728437, 0.08965525445678542, 0.042710700297668096, 0.03398521931000775, 0.042596763871129484, 0.023335298643477505, 0.04244575261949532, 0.051043821694028955, 0.09257129919264587, 0.09650652432033131, 0.14409940719844835, 0.09034314778663459, 0.14046183787286282, 0.10007220395510236, 0.1667214166973868, 0.19258963184491282, 0.1105189695954323, 0.18496543289192263, 0.18586155658047046, 0.38425955981496845, 0.17161307195501943, 0.10627925516136232, 0.1219466265531317, 0.11489983572955094, 0.18137997286694665, 0.15162082779551708, 0.1281898217876592, 0.18724883455903302, 0.08950380653503442, 0.12261104694898091, 0.06411213255036743, 0.15730653318666643, 0.17789632592710758, 0.18291843063648672, 0.14970923924157697, 0.21334192715585235, 0.1924846624775279, 0.20183850410244158, 0.1498998878824134, 0.18076219956480688, 0.23797602062263798, 0.1614995009355968, 0.15329998527323047, 0.13658733287405583, 0.12749838913159986, 0.10861244488267169, 0.12495258702866494, 0.08933707515919402, 0.20640596627227722, 0.20606311128264476, 0.08434437290434876, 0.07733992376034299, 0.1752036341255711, 0.09635447118912013, 0.15774061392632224, 0.0990724515530371, 0.1278961573036448, 0.18293120898306373, 0.20297445927656468, 0.1825158820757943, 0.17166521189914596, 0.14240451427477022, 0.08154506464639018, 0.16062044568600195, 0.21674303578272944, 0.1424794836390403, 0.7291890849028865, 10.494595573794458, 28.05133431188522, 62.18632751895536, 66.33904672438099, 62.995320289365715, 53.4675968077875, 52.32073891547419, 46.90911539139287, 43.44793358156758, 39.69938716580791, 35.399520243367846, 43.795224158994614, 36.47632068203342, 50.8360747368105, 43.61167684678109, 42.18782117289882, 50.74975121405817, 54.85512741150395, 50.10018710167178, 43.92658825843565, 37.4643265047381, 25.257373163777014, 16.090207676733694, 8.819591518371336, 3.661547509893295, 1.1323165629179248, 0.4589642560289752, 0.21175396478464528, 0.49719958175574586, 0.8218790434541241, 0.9252931910657114, 0.7585004669043326, 1.2027745886195091, 1.302432944217036, 0.5680936647038306, 1.3129919647209107, 1.083391614017948, 0.7252925778588941, 0.38949270642572836, 0.36788449172050725, 0.691646792955937, 1.475680725228402, 2.0579301013100535, 4.462843364284885, 10.180485306247588, 16.006643541397587, 22.831579408337994, 32.05069668831364, 40.212409650125814, 45.64614357486848, 47.94515848159791, 47.31082885496078, 46.33129142945813, 30.690936465417188, 45.607665123478064, 60.8414017000506, 49.22860899279195, 60.572942918346776, 67.31828997212072, 56.21131043280325, 47.140260665647446, 55.443039709521884, 59.44485748967817, 64.84136027674522, 56.651482735910726, 33.9256465050482, 6.45164389764109, 0.14379778306090063, 0.22136055413753758, 0.14956458651971433, 0.11396153123989222, 0.23725027488845013, 0.1218744840533022, 0.1497777734672831, 0.13435472283632527, 0.15337199753811284, 0.1448151631461036, 0.1592533004980895, 0.1263747832948162, 0.18564961069533903, 0.1928946114475689, 0.09738993861021535, 0.14334358485235324, 0.09367346222842894, 0.20767594086787394, 0.11155692680228142, 0.13133530985684166, 0.2111278870894063, 0.16494138076180415, 0.10077534243464471, 0.09151442727494626, 0.1350662193351215, 0.12304622319436843, 0.1431779413213653, 0.13671819601328145, 0.1388426497578621, 0.09181825774571589, 0.19411543384194377, 0.11481430201280503, 0.17217418539427942, 0.14572342166737204, 0.21441327047444161, 0.1072477818196339, 0.14745068946673026, 0.0799103862335605, 0.1500787694127329, 0.08809488657261096, 0.18243463079054512, 0.13465594860815233, 0.15861997561108682, 0.16423506301737603, 0.19098418734727368, 0.1782814230048849, 0.09471069931262925, 0.13209798102897982, 0.145402982410404, 0.10552751606390362], [0.06482312726157327, 0.08366777171050349, 0.03844564367506293, 0.031356386682619496, 0.021494341480936256, 0.058895234664481495, 0.04386854260378788, 0.051899622344682296, 0.01387123037279854, 0.04219563640353661, 0.018947300230783802, 0.02702696909827571, 0.08523931681749322, 0.05668037105351687, 0.08679749369020424, 0.059237220144319924, 0.05942679243162275, 0.0721982020824667, 0.05260053150836499, 0.08115785316594186, 0.080864112073135, 0.03625039191495988, 0.08015463038557961, 0.03486470356884022, 0.023448907567428488, 0.040265623435017564, 0.028219137889062686, 0.01169696654899106, 0.10229012042644525, 0.02400557578150784, 0.0076137174337711794, 0.05608929208509865, 0.03712219614235144, 0.025554297214013436, 0.046401489751353386, 0.04871963733626951, 0.13143744469890672, 0.06831877113830659, 0.06619206509522854, 0.021017478561149012, 0.021706375466178984, 0.04930394025699747, 0.03552134434181837, 0.029527328780762134, 0.03902415497108333, 0.03241465479556111, 0.01284767657653579, 0.011991852943244721, 0.03727092062153163, 0.050113051679105534, 0.1033798958204927, 0.11162739923043598, 0.05770757621634872, 0.004521347986038534, 0.037518711760640144, 0.00957782275133556, 0.011577950959514466, 0.033883459851025574, 0.08787884977796385, 0.10968285357399334, 0.30595559867159017, 4.424483564592177, 8.06334727233456, 23.461565010009274, 39.4785185014048, 45.94977817227764, 49.9546044103561, 48.704949040566724, 43.66719799657022, 48.93350555050758, 35.67534523625528, 30.57694846583951, 23.074933059753914, 31.390295067141135, 36.56059280518563, 30.58446176590458, 28.150301594888013, 36.447248074316214, 30.71185250436106, 32.481635732035485, 52.97438621520997, 41.7073033701989, 35.83368347537133, 37.70039827592912, 32.58315451683537, 24.56049350000197, 18.61673770412322, 18.38513155137339, 12.09728681272076, 10.607096014484283, 10.413366229303422, 9.338593656016934, 9.586860076073679, 9.643675608019675, 13.7868320749652, 11.592687618347908, 14.797576858151345, 16.36806739914802, 15.530659998616866, 18.046725142386652, 27.200785990684267, 33.45683305494247, 41.237972167230424, 37.4189172252532, 36.20868559806578, 31.445522039167344, 36.11032039888444, 27.235206750131425, 39.58816835957189, 30.332378879670177, 20.892787133493734, 28.174741883431714, 25.53434741112494, 53.92407048133112, 36.878755861713046, 27.710466615615356, 33.65065697700747, 40.16668265865695, 43.622004447444795, 52.79799722856092, 42.31372533305999, 27.46746401632986, 16.110516728893405, 3.849661196431806, 0.056346352888090964, 0.04077150959581618, 0.044806827941248496, 0.04780108642373835, 0.05483368929896144, 0.02904492896050215, 0.06769829354579411, 0.04121266898789233, 0.010933879774153955, 0.025439221231687455, 0.10447424475944812, 0.017228842442554813, 0.0074936350668600256, 0.021003376797682816, 0.03793677360179924, 0.03857343480171215, 0.06170008173813263, 0.054577666545106526, 0.0818606162624013, 0.024523054767820626, 0.018225666473529512, 0.07561639447005526, 0.053931613107241934, 0.1530265378495378, 0.056012606683878176, 0.020853447645241698, 0.09533774993953206, 0.06198412798825772, 0.028732008856510925, 0.07667050081034822, 0.03585813574553017, 0.021186021734930335, 0.07591728316319567, 0.036629705028908874, 0.02961543655293363, 0.06465469517054097, 0.032589594803510175, 0.011213156169340497, 0.0455133410380973, 0.03202143144012699, 0.021308038473850297, 0.09199248146145575, 0.08602312435546229, 0.014958342653699221, 0.032791095079794046, 0.045532577505875985, 0.10397153786353527, 0.053487791559628906, 0.04265889360178863, 0.04988371942853255, 0.0568252727539549, 0.038549180458029436, 0.05363709060475231, 0.06553516768279576, 0.04702069180747194, 0.03744571507277508, 0.007190616649290126, 0.05141571907687092, 0.06858664910278975, 0.10466371362488117, 0.05332572182880775, 0.01794691772140082, 0.06199206848959289, 0.0182819509533264, 0.08003683670634225, 0.023659173804785938, 0.038505770085800084, 0.0823973910883069, 0.027584112286868117, 0.0659777213548941, 0.007256792760604332, 0.06718689921281992, 0.03786004606574293, 0.0310828281761778, 0.11983671315735388, 0.031364999426108216, 0.037114339910687945, 0.048954370506708665, 0.012257884635830359, 0.09477439186265392, 0.055864104370196024, 0.010334765501019937, 0.02128621645932717, 0.05100835948401401, 0.11245658981703943, 0.04267750570790903, 0.061379247945883585, 0.013573718212184407, 0.014550529153747185, 0.036708964485554926, 0.04594058061258928, 0.060766783633059075, 0.07327127675976484, 0.03206140207757633, 0.059942032525976824, 0.04791489644576946, 0.029406480325926698, 0.04058701264101171, 0.05167926864458188, 0.014945879360781083, 0.03809742223952086, 0.047051094006747014, 0.07686317958418401, 0.02969117392034781, 0.03332669396073588, 0.09993895828243225, 0.015779525706274136, 0.014976305500303787, 0.04240551768171211, 0.05562111660237274, 0.10031447926115605, 0.028537223340883374, 1.6107936299616292, 14.392064579071539, 26.942009579750803, 43.06769509469309, 50.90801885051113, 51.721287004409305, 52.973233038379306, 48.246639697782456, 38.918921793660815, 32.94354384945285, 33.480735978772564, 25.89146548701871, 26.93282142762215, 25.307102934006725, 26.894407695339574, 30.53134306784599, 39.034839599363266, 48.27822654478012, 48.670553776525686, 57.938216270939, 54.36494881106962, 51.444630469045336, 54.72260621286208, 43.91180484525619, 32.60005993227805, 22.8362823301746, 19.728311915551465, 11.089238659028085, 7.815262261898288, 5.479312846737524, 5.993099212646485, 6.335576551575815, 6.0589543369508565, 4.730698100982174, 6.244429003807807, 10.075867849011576, 12.081426708929001, 15.448787385417571, 22.66492182208646, 16.1444785710304, 26.292853393862327, 41.91926040957051, 53.24136234098866, 53.88196383753131, 54.55386192567887, 54.25553429511286, 57.32285130408503, 47.04462151373587, 57.19553509066182, 40.82497796704693, 27.44920538317773, 25.697525855033632, 15.725140917685726, 36.09229318557247, 42.76870458356796, 31.99070207534298, 39.4993031409479, 47.37040181313792, 47.54050716277092, 51.259863299708215, 51.67064528311453, 40.38923794223417, 28.67242397800569, 9.995462202256727, 0.9886215122476701, 0.046301059454919836, 0.03689569458665867, 0.0775748982484783, 0.02071341443356247, 0.02541109814398712, 0.032411414243641405, 0.0528634988492535, 0.0278620892054131, 0.03594808595915956, 0.0547591949092044, 0.059750418614355795, 0.03981604856709319, 0.03422831816058006, 0.04388396395370365, 0.02359015885890732, 0.07182458100179512, 0.0633789825763914, 0.0408489725762798, 0.06436114559971517, 0.0432945090916849, 0.05020124755138832, 0.06674397015763868, 0.06409022243573301, 0.025655574037603317, 0.059879427820804625, 0.06847387329945642, 0.06956799241203455, 0.009210025854108315, 0.011870144554714282, 0.016054357833889945, 0.07039713703336255, 0.01476462774594585, 0.02111514519539572, 0.04305560457249803, 0.025140596328363306, 0.04687849822784624, 0.04439939557003879, 0.052353874179384405, 0.019021442220095667, 0.041484480813866666, 0.048922558705652916, 0.0877176189134198, 0.018986282614810814, 0.1161430432130733, 0.015954582542631657, 0.06472009609663679, 0.04072713778324185, 0.10957558594283559, 0.06206375516710743, 0.019923997216767842, 0.1001915681145845, 0.17088243857987467, 0.15365531217427025, 0.11024637252933557, 0.09630295943709151, 0.12581607537163844, 0.13689102544899912, 0.1710108195942256, 0.13424166358045994, 0.14591057694727375, 0.11779558679629719, 0.13293027427167664, 0.13169170928097543, 0.24984206373412765, 0.20357142563068098, 0.24424134813729795, 0.15758762616784344, 0.08829682734945128, 0.25019002086933584, 0.10828750868958813, 0.2232115298149086, 0.2199577705393876, 0.12883021766620298, 0.25793245783255947, 0.20322061864839447, 0.1657925504109552, 0.2719204265984797, 0.10912067527251859, 0.16419567077630953, 0.21310427135998206, 0.06796088550359973, 0.2832900907003111, 0.18179349180671478, 0.2404900147549568, 0.1417919197269986, 0.19296665435596821, 0.1776944311155427, 0.2643402317358602, 0.15924450580871877, 0.1553652817082982, 0.15184132322188348, 0.10733060358512787, 0.14022255797059308, 0.1382868836123136, 0.09726906525752238, 0.1890849328089145, 0.20026166532789508, 0.1512732690260295, 0.09177367908940201, 0.08254341510755402, 0.15700785082674798, 0.1811407236081939, 0.15193895346695377, 0.10134803912331981, 0.2122574377684824, 0.14446833982102333, 0.13476698539189755, 0.12376558741614704, 0.1611172843484148, 0.29305299263327356, 0.2380506529082214, 0.8572188632622842, 9.903534593120698, 23.13825188144561, 43.83762890292753, 65.88670330662882, 67.03484381398847, 69.30928507158833, 63.207673488124726, 58.349186528113584, 61.028906683768, 51.386367582505756, 42.723463966000466, 38.16117871192194, 42.10270966252973, 45.760025670451505, 40.16332903215962, 39.27123300490841, 45.10921424435031, 39.25001690464635, 42.69259099037417, 67.8984869680097, 58.01507903683571, 53.125436690545854, 52.77476503003029, 45.95672861222298, 35.884662520500925, 27.80700791266657, 25.268434247662945, 18.866700549279493, 16.08544886112213, 14.11671321238241, 13.69587819422445, 14.057228507534152, 13.684649429013653, 17.66351349892155, 17.886725779502623, 21.7885878393727, 23.22566778429093, 23.855263110130068, 27.362991686790224, 38.29658677501064, 46.19799752389231, 53.89367603486585, 48.456639474438084, 48.10057847730575, 42.835012251330966, 46.676142292637984, 36.108641624450684, 51.14765997855894, 37.51763936012022, 30.2693405074458, 37.04780217139952, 33.10841675727598, 65.97284640035322, 46.59865586988388, 40.09129078157487, 47.62817213612218, 54.11554882603308, 58.115370119771654, 68.82972040484029, 64.7653486651759, 47.25087934924711, 28.27629008600789, 7.30014915427854, 0.559180630070548, 0.12263710159928569, 0.10288051374617124, 0.15496694663118932, 0.1524903682330924, 0.10881544286084753, 0.1700873772102979, 0.17533039103352255, 0.17569753101035473, 0.2344440182130183, 0.3206154878341383, 0.1024519028742948, 0.12840957410873907, 0.14149354380224982, 0.13650672510266304, 0.1394735997722995, 0.2240334961923861, 0.15385667072428813, 0.20590842280897403, 0.14330672070143685, 0.2103081730104262, 0.1646698179144052, 0.1883185537712228, 0.25102098111904436, 0.14282465221420412, 0.23811891134227478, 0.14799323293470568, 0.1280060832598998, 0.21830125862071592, 0.2165323769253108, 0.12636509228257403, 0.11474645726623074, 0.14100545386393226, 0.1485898928536523, 0.15432884135553915, 0.16662741770907757, 0.09223071182326925, 0.07777153003600337, 0.10780278187725814, 0.08992013701748464, 0.17736383353269872, 0.1346432162268508, 0.1416244069414754, 0.12915531473775066, 0.26349014993156156, 0.09342909550234195, 0.21817378159011566, 0.11896237700937257, 0.22717533002216972, 0.22384048800074288, 0.09204012446946676, 0.18184469712357368], [0.030639454790000475, 0.035654612997126196, 0.009214507468465355, 0.039692168319297415, 0.027118535757425333, 0.015576466441064354, 0.02713573251610562, 0.018952065297672828, 0.06812638347788204, 0.043420024937199014, 0.058826562542949, 0.026475044883667465, 0.08160779192563027, 0.027953724812475905, 0.055792433014439965, 0.02711868705979038, 0.035895222061944586, 0.06311167534741183, 0.06662695022720484, 0.025577182175531506, 0.07494372330726155, 0.06173755109850919, 0.0378152069395348, 0.03487625234429875, 0.039395941271176266, 0.0380873711659543, 0.008505457662977278, 0.049804525089360056, 0.03261217141463872, 0.035789651315539114, 0.03074962014873182, 0.0546532602710349, 0.03286798349431446, 0.028083111317227447, 0.06152396961565941, 0.022209861856554786, 0.015348942157992674, 0.10748024353937757, 0.017618296645401467, 0.034739122605852546, 0.04077171643955573, 0.043111747326028925, 0.03499371660572868, 0.04633477881490704, 0.07445250006933367, 0.038334089781968825, 0.016707860519208254, 0.015284392547102706, 0.008151844883668087, 0.02017784811135742, 0.01440882299756331, 0.1320784304651522, 0.07701669594333058, 0.017386913194411227, 0.08039100681461635, 0.03096414391972846, 0.07496917274810615, 0.038604181740553155, 0.06853125328498502, 0.04823624734736739, 0.07562958650411138, 0.08577619123482898, 0.5953292548656464, 3.723663879979042, 11.737807469983256, 22.393660506894513, 34.00478816801502, 46.6502115034288, 57.62747826114778, 57.10526566351614, 53.44387431298533, 50.54906314419162, 44.46772236977854, 41.93104320956815, 46.69853902632191, 47.154306673234515, 32.90958004613077, 42.213861788472826, 61.11305721344487, 20.5075535082048, 67.07188667789583, 71.4318129324144, 25.958147741133168, 23.114709815671368, 19.75974382892732, 26.11609962678725, 23.118141889572147, 18.273355768572902, 33.67765857327369, 42.4265326992158, 34.74128769290063, 34.20835917995822, 33.24027507535873, 42.62103126895043, 37.619373875279585, 37.1436256747092, 34.369933374466434, 35.17230518402592, 27.325878220219767, 53.952378226864724, 66.71065207450621, 32.83497264308314, 25.653765932206188, 25.21388976804672, 23.61243505631724, 27.981620065627563, 25.960989498323013, 28.92051781377485, 30.1063758327115, 43.59265335144536, 46.4611767953442, 57.06803452584052, 75.02521391837828, 50.85078754732686, 44.486722330893244, 49.21002872528569, 48.68979692459107, 47.01791409523257, 44.89870848194246, 31.22599090299299, 12.631458717007792, 2.133285941616182, 0.12345499238900601, 0.1269543517921721, 0.051108418227804285, 0.030543435244790973, 0.011736814612372509, 0.05228792933086234, 0.05593924610424907, 0.12595214790874912, 0.01254348412922193, 0.023758589034719814, 0.016570567987078143, 0.01109788962264335, 0.02003001995504864, 0.06149023493391372, 0.03565752413123846, 0.03786295336941558, 0.044955468150757016, 0.031596124322424014, 0.0619555605695613, 0.01785929641506124, 0.053539471851000865, 0.09289820423169483, 0.0321627306121011, 0.028807100794848897, 0.00789155118963531, 0.0322365929793206, 0.05822295803696879, 0.00875318464222214, 0.03007810386348396, 0.018045231699943542, 0.0487178293687682, 0.05388332275493492, 0.00510559105614741, 0.06806397795557015, 0.07260910100153378, 0.03048790153115988, 0.056986396366189566, 0.04033558641470248, 0.030949442692461516, 0.02673168242308161, 0.033370602290116014, 0.028074703502258467, 0.058108688362183115, 0.02099084168402178, 0.0243818762546946, 0.03631755867372117, 0.02985959452006125, 0.019434290832930037, 0.012093656452282543, 0.09340606689933809, 0.04112592102178643, 0.06568109977149195, 0.08098434957285082, 0.049236558993617376, 0.0550884671599394, 0.00544007653520713, 0.022072942792287758, 0.054447381802263765, 0.07149261212156666, 0.034427068181215756, 0.051260256854396676, 0.05434427402853485, 0.050343398996178186, 0.0865255018335677, 0.012275280577370958, 0.061851445390211965, 0.042041219891079014, 0.036338744835267146, 0.03886560158383462, 0.0624348481576289, 0.004261254432475976, 0.04486377891753951, 0.052862020299559644, 0.0371426813334467, 0.008784620102585084, 0.007880970078986138, 0.009818835927534008, 0.047814768754066005, 0.07555712990823292, 0.03617579410333307, 0.01349584250185158, 0.00397428052946775, 0.11670798709195469, 0.057688328257251176, 0.01092972853521426, 0.006653685732969955, 0.03543520541561227, 0.047668637482509504, 0.02677111105332452, 0.021649267441863497, 0.03645945730949602, 0.09358138612080967, 0.05700854779852014, 0.02282465699188892, 0.027354642140468764, 0.05105720908050576, 0.03638651041734604, 0.057708775143950224, 0.0586461220237036, 0.043434258850832144, 0.05087020318774928, 0.046889265593622005, 0.10914223298670785, 0.036239865866880265, 0.037997332852213614, 0.06733178942193908, 0.01079288799495947, 0.013128585696610953, 0.13850529527952596, 0.07505904252250349, 0.03525977128095204, 0.0377081461521166, 0.023776379511541417, 0.05702411853558114, 0.08463320337356099, 0.05723877254152491, 0.6306834158397491, 7.15236307151856, 21.666649195455737, 36.98411464691162, 49.20822051263625, 59.21148823153589, 61.210885047912605, 61.94801607439595, 54.937540331194484, 49.251684296515684, 41.957032834329915, 37.67491463691958, 41.2471426686933, 34.009196912088704, 23.495540580441876, 33.680317940250525, 35.08971183530746, 21.3914478594257, 65.0989423259612, 60.772207167840776, 36.33925345636184, 47.43308128849153, 45.176384833551225, 47.02759058244767, 45.708893652885195, 47.57376493946199, 52.37211804236136, 55.32743569343321, 49.40526470061272, 54.51375569066694, 54.690744799952355, 60.22799399591262, 59.38278598170127, 55.216209042456846, 51.226095614894746, 53.655658768069365, 38.0627703666687, 54.16813212056314, 62.92591002679641, 39.84551114420737, 35.306764033532914, 30.307662064029326, 26.58024153401775, 21.762054966342067, 22.230117282559796, 19.129030627589074, 25.954480325022054, 27.230550896736887, 28.08794375388853, 41.92282976642732, 48.05277262964557, 57.30088210874989, 46.28369738978725, 47.12099006099086, 49.05973918976323, 53.20964213340513, 55.08734349281558, 47.090124930104906, 23.896030264516032, 5.8089257920942, 0.736597890575086, 0.028180279994323373, 0.0296849264733253, 0.04156731790111911, 0.07775584821619334, 0.0758885625269144, 0.02443923900324491, 0.06871715984157017, 0.02878738743733735, 0.039189396305911006, 0.0815534456482818, 0.02013064751912269, 0.019052170006738558, 0.04017373118850012, 0.029047104650207108, 0.05112379744288422, 0.01862344996733291, 0.023059152675071554, 0.04706112592811546, 0.047241512821206165, 0.05296151596872557, 0.06108339628084533, 0.010994346136407507, 0.05740266173116623, 0.013794627326029926, 0.03993953044916834, 0.010531672122587842, 0.01869876215594911, 0.04677204648032785, 0.027708710742092905, 0.023320087967740915, 0.062494587693964286, 0.10182216327877776, 0.07804978849186052, 0.05557766409530755, 0.03759037162507734, 0.032316335071358955, 0.03929746066851001, 0.062407690340713154, 0.005310737432145904, 0.0286298108121921, 0.04543261069263663, 0.030506954137836734, 0.0570576157300703, 0.056305279084030664, 0.06718839308427227, 0.06321308623638845, 0.050575324454374855, 0.05366534392739977, 0.04904067414181848, 0.015673868774977184, 0.06197856618992745, 0.03824592072276339, 0.0312863375180431, 0.2087821258652595, 0.16273360729457872, 0.23782431989187197, 0.16115330580261447, 0.20160962767418356, 0.11974441488423657, 0.12034965498793511, 0.25163717628006016, 0.15405108851771201, 0.17505309784845, 0.11928778051608994, 0.133185412193979, 0.14961177753585, 0.17393660130760363, 0.1622175551470249, 0.18281965125952998, 0.19545988750553903, 0.13527782814156625, 0.22045326088705372, 0.09507149608144838, 0.10171177766976819, 0.13233975837788275, 0.13285541215971594, 0.09627466781004783, 0.14965968867463453, 0.22886938024913112, 0.11922428714892558, 0.150622186220942, 0.1774558253706463, 0.23117351225547253, 0.12884327180443272, 0.18981844667465458, 0.11288684777795308, 0.14906235459831454, 0.1571770183621876, 0.11881155727971947, 0.15170292177748296, 0.2978118695318699, 0.08342267720088845, 0.13153697484202925, 0.08430196993773983, 0.08092380564419493, 0.13035424233924958, 0.12202096006442463, 0.1451342694100834, 0.21781103895796886, 0.12368057463918963, 0.108602263574158, 0.230516116885889, 0.10272737277010757, 0.14002165907332975, 0.29544799798919313, 0.19168397802258694, 0.14387961657297227, 0.21560902647193403, 0.19256246636711782, 0.13152330783346008, 0.12445584795768223, 0.25967503206864484, 0.09586292619426405, 0.1323729146632456, 0.25225110382082006, 0.6748003356399075, 6.266778178753392, 18.4416058371144, 33.32428047733922, 51.007878472728116, 64.8329036466537, 74.19896664157991, 75.50311550017327, 72.45512793141027, 66.81349662042433, 61.58372986701227, 57.807138504520545, 62.879904547045314, 59.424437630561094, 47.21179293047997, 53.4120285895563, 73.29826493417063, 28.947472341599006, 71.99559873150241, 81.453335362096, 34.78457104775214, 34.412342040769516, 29.434703280848844, 39.653922973140595, 36.027001411684104, 31.80721752105221, 50.271473084726644, 59.10653737283523, 50.54736868027718, 50.28708019564229, 48.41426610946656, 57.56415159471574, 52.364187009872936, 51.53770439086422, 47.45659197530439, 48.687780826322495, 39.81188858709028, 70.50295645190825, 82.13207798619425, 42.34442572439871, 32.795464569522494, 33.59748532695155, 32.498974569382206, 36.52785670372748, 34.34901145196731, 37.99683924644224, 42.848438524430804, 56.247462918681485, 58.565054170547, 71.87700979171261, 90.69360010085568, 66.22472532333867, 60.325755150087424, 67.4355374613116, 66.81174724332749, 68.52798815696471, 64.1575695622352, 47.79498661718061, 22.00747178446862, 4.511795524627932, 0.346629872557617, 0.19890853954899698, 0.10851145151161379, 0.11005177087480984, 0.1511656336726681, 0.1434323131557434, 0.11873057412524378, 0.18835342609353606, 0.1302173271054222, 0.1653718915317328, 0.20170814658124603, 0.09325782122511057, 0.1892743403873136, 0.08282118326713962, 0.09909279884830599, 0.08694233793404796, 0.12071417494406625, 0.17092910865622182, 0.12589067701370488, 0.1617749555096511, 0.2508979014331295, 0.1430685899310535, 0.07983963035287396, 0.17884094298126238, 0.09485779585497034, 0.11649952690687873, 0.13972139857228727, 0.16932812279030202, 0.2160449305008496, 0.1585201237110361, 0.20201845815585506, 0.16621412859568674, 0.12177611070294535, 0.19371722133890276, 0.09217559945799651, 0.10092532712846033, 0.14437282397862405, 0.17836016152174244, 0.09125865349966673, 0.14867672125899023, 0.11809686619427898, 0.16880327595337746, 0.13764352297350285, 0.16697807147377924, 0.09447375597852854, 0.16387749913959734, 0.1524014407468419, 0.1864496669581821, 0.11653589310064433, 0.1611059922124109, 0.1405566182708548, 0.18480967189515793, 0.20168896373962203, 0.1648383572577469], [0.033488526204300505, 0.021818015544164567, 0.025834047626103127, 0.04245077049539935, 0.062086163238892635, 0.03111655711226406, 0.05064460944624678, 0.03309982851327908, 0.09315851324748609, 0.08173711522812806, 0.036398580132593075, 0.08692877817778819, 0.05493190177085419, 0.01584934408686334, 0.10109187464319891, 0.022626617517802986, 0.06480722327626522, 0.041054219022513404, 0.10249429818002448, 0.043377989692793745, 0.022956973782950835, 0.01067862981149266, 0.0734094330560296, 0.05397311975097945, 0.02293880409260671, 0.02531189741867204, 0.047166179565172044, 0.026061704059341745, 0.05919411237682066, 0.04137897518493476, 0.07643052376806736, 0.017854385791466604, 0.045275114506723425, 0.07071179232650227, 0.0052658633531762235, 0.03536019391650635, 0.03243387211114168, 0.06790888345529957, 0.009775662084951276, 0.05023657952645614, 0.021062993759950323, 0.10903083614163822, 0.031586027283582, 0.010710584296424304, 0.034572253334185774, 0.011209791128133095, 0.03855276957995469, 0.06169637004213949, 0.02395056683810488, 0.0614237078585692, 0.048811203995419127, 0.034497900670694734, 0.04066300473266071, 0.018489053247556574, 0.0398371696111656, 0.02878279857067091, 0.020337322719335076, 0.021160721681230975, 0.08280413014994514, 0.02134062785414919, 0.08800225122080696, 0.05539246617005237, 0.023597942312218012, 0.06367281176930954, 0.027914012729701017, 0.49012001002988514, 1.790187152162675, 5.387301396939063, 11.544405202711783, 24.209115812855384, 31.342669648508874, 37.275629120488325, 38.85940374866609, 41.534471973296135, 48.0477951418969, 59.60470191894039, 57.81884285711474, 56.876744454906834, 52.603177024472146, 48.39303824209398, 46.910711796053, 73.05384635925293, 39.576338491132184, 32.19727762283818, 30.91563532429357, 40.21548478834091, 42.52592948175246, 25.81228852272034, 19.57328219567576, 22.527789877307033, 26.443641070396673, 32.61486884086363, 27.163395997016664, 23.521869490223548, 29.988891040125203, 33.672100574739524, 30.996039990455877, 36.31983772400887, 48.04410811393492, 60.9244853450406, 79.97003616825228, 46.45775648855394, 52.76632016704929, 51.752152135295255, 53.279417176400464, 59.20629501342774, 55.54436237581315, 59.23578339238321, 61.44134390738703, 51.92792530982725, 57.4130226719764, 45.18111913434921, 45.53352056011077, 39.81163755539925, 34.63102594498665, 22.452360737708307, 15.33273425794417, 12.266450793512407, 4.108540814730429, 0.6697282207108314, 0.038216679146693605, 0.09284620984427391, 0.03690093462806075, 0.0601363392366517, 0.01609040705877687, 0.04572088191766412, 0.011058136362642532, 0.015285529230060357, 0.024023013857884273, 0.03720419053288718, 0.015049145140144375, 0.07392226763430142, 0.021186615453071652, 0.03933028753606543, 0.04417756715068414, 0.020063379253711433, 0.05940521939567501, 0.002292177443685491, 0.012414716240469248, 0.010823143679919022, 0.03221678577603833, 0.025891590405315645, 0.09135209324379122, 0.012567908927467803, 0.03365375987824894, 0.0278715752891355, 0.025522221112623814, 0.0329265509161257, 0.04165308144424231, 0.051379126887167656, 0.036695431542372516, 0.05672136441834512, 0.05829023204803948, 0.06285331602538786, 0.03552383029713266, 0.020887031024622343, 0.009013237976168674, 0.09727704023281414, 0.08058068252378896, 0.05108023002263039, 0.022271428512589588, 0.047326529428603194, 0.07451084532564686, 0.036077593122759176, 0.026200764339357138, 0.08376218438629182, 0.09710409588390782, 0.045401369627084465, 0.019761645948634516, 0.03333563037637261, 0.04488147171815077, 0.022020760713325396, 0.050653733553424965, 0.0605645134384113, 0.055917688390059825, 0.0385775065590297, 0.0121712870144796, 0.08998494039499953, 0.02875345931839078, 0.04195998009714869, 0.0322281277077573, 0.03221344180224884, 0.025800918153817617, 0.061907848613637115, 0.0070497091397673135, 0.010919012880373386, 0.03508946610494487, 0.1164730892126118, 0.027945255710472985, 0.06891480286515529, 0.017469371068141153, 0.04111623767042353, 0.02764824916788888, 0.03301780347922637, 0.02644365634618988, 0.12489492359060435, 0.008309255842299712, 0.043456257065577854, 0.039436896331608295, 0.03728181056137528, 0.07110683322553674, 0.01892964764978857, 0.06570993532096187, 0.02513378197627683, 0.061679420346814784, 0.0982034320552503, 0.06964486933523609, 0.0163061642313316, 0.025095720812978766, 0.0532592790231349, 0.005851295295982592, 0.012579329383199014, 0.029568641987298767, 0.04571873687147614, 0.038658497374384634, 0.0644919780954238, 0.0475604122414464, 0.09066315037348578, 0.027466278388014728, 0.055845576533747304, 0.04747800416343155, 0.0757017519865786, 0.04235086879963356, 0.027306656308111646, 0.038676025466092175, 0.04284386170066653, 0.024756290236367814, 0.01356876449614403, 0.012892238953481279, 0.017300080958633654, 0.04731614893722919, 0.06774140131329337, 0.03530966658746043, 0.04310648813242874, 0.055106148469231786, 0.045531114277940606, 0.046521298241831606, 0.12632671893844682, 0.02905489001873761, 0.04516052307500955, 0.22714929835450268, 1.6070508307987645, 5.727955814330809, 14.364768805042392, 24.026029379137103, 39.18863573381978, 45.27453430237309, 48.91286996103103, 52.00071665548509, 52.998653919466086, 60.61625372978949, 64.38860501012495, 55.24077092447589, 50.32170295715333, 56.35057026340116, 28.946297591732396, 59.23615601754958, 75.57516944023871, 23.42793853052201, 17.36810018939357, 15.74281511768218, 31.180465913588005, 24.390274401633974, 16.713566433998846, 24.276874757582142, 31.00009179884388, 29.948547501717847, 31.969199642058346, 25.132265244760823, 31.391430593306023, 32.10680031007336, 31.281767006843324, 25.966404330345895, 27.707061998305786, 31.591061584411133, 65.01251289921423, 82.2497961598058, 31.499125149942216, 26.868924056330037, 27.731145351163804, 33.204475602796, 38.62470088466522, 40.51954300172868, 48.5036765375445, 54.37471551279868, 57.935411776265795, 63.6985973388918, 61.40681136038996, 59.889391468417266, 51.04146180614349, 50.985862208950905, 38.99404302720101, 31.208253945073775, 25.186409642619473, 11.719055598781956, 3.836352594437138, 0.12420059512219123, 0.006114020840370007, 0.0971362179505729, 0.055877756057006706, 0.010447822841665438, 0.06194725234602248, 0.044500174436477885, 0.01705071933928036, 0.017192152576641213, 0.02200843435862372, 0.040937375292302146, 0.02037712864788069, 0.08113575152932637, 0.015709629759282594, 0.046589142988405885, 0.026205684539050828, 0.18504728172575274, 0.022067202878515088, 0.024182848527186343, 0.02907027880991659, 0.0183153294041873, 0.0430502649396658, 0.07174254064598391, 0.03175472175972837, 0.0420986496723227, 0.03440719586045992, 0.034855104487148986, 0.044035354418860334, 0.045021861160714785, 0.04511104145598027, 0.07887088152910433, 0.04857505739275967, 0.04691632764954721, 0.017734201917905482, 0.026953256118201444, 0.029688532832228852, 0.015564187966857948, 0.05717941604915166, 0.0478798249405959, 0.04168947062064563, 0.03995305190103189, 0.002709673576793003, 0.04513619978341364, 0.033667564782644474, 0.05937089482622762, 0.04544684077583013, 0.046685846267087806, 0.07324503824835824, 0.15148542941577975, 0.022660241116799658, 0.04114367127899201, 0.02424774958091157, 0.062018146122535395, 0.01837694394071737, 0.0094710549925484, 0.03237546556779454, 0.1863028385466145, 0.11251488910807718, 0.1130114519788373, 0.18562043806718243, 0.15631729917180154, 0.16209079823907346, 0.14060117394453095, 0.14714554132473084, 0.21663999695691372, 0.15616927566307207, 0.10464341995576698, 0.2440402653789328, 0.15802916860388172, 0.17179419046207783, 0.19173579620978526, 0.08089283270941627, 0.11916206548771552, 0.31718139146124164, 0.2573808438835606, 0.16135293299392348, 0.11592817853295034, 0.15846429122311456, 0.12388094493578519, 0.1682793024566866, 0.24035430994004975, 0.1078196358115923, 0.2756161879627936, 0.11910706037475217, 0.18442877297920568, 0.21262364311804696, 0.199219954290217, 0.10541258755350306, 0.13587218979674, 0.0920992664572212, 0.08927466963688213, 0.0892678284717183, 0.09230463164708308, 0.18267551947745586, 0.09538795934208939, 0.1056811626579973, 0.16291009863057446, 0.20525545542759283, 0.17355784743783936, 0.12480649406150465, 0.1255857510372035, 0.23255024886419698, 0.17341947663695584, 0.1998448215665356, 0.09318920272973277, 0.17006226484814, 0.10223769702978673, 0.1321243191318166, 0.12483273257291126, 0.14656761991641215, 0.2360040336967476, 0.1527853733709743, 0.12642157594523123, 0.21069867866894892, 0.18701850256371885, 0.12576770458009937, 0.1986767060213512, 0.13607011627285712, 0.20147196167419035, 0.12363518392967603, 0.11283900558708176, 0.8667602738545788, 2.959245904799431, 9.294713120306692, 17.26753257936047, 34.14948440367176, 44.54549512555523, 53.678608555947584, 56.61773466294812, 64.89040951575002, 70.68649199701125, 78.47051405137586, 72.79601327834591, 71.98602814828196, 66.85128473466443, 61.92103801235076, 59.83922043154317, 79.92641156719577, 53.27539282460367, 45.558564893661014, 42.98476834450999, 51.69610931027321, 52.40111612504529, 35.30324174511817, 30.22262311750843, 34.62391861023442, 38.09604383284046, 41.74680948257446, 35.604566066495835, 32.019021587987105, 41.84755163808023, 44.439069455669774, 41.42069970407794, 45.94052137867097, 64.6004443783914, 71.81658960157826, 89.41541733280306, 62.53816020104193, 64.8884444082937, 65.68392069109025, 63.618220129320704, 73.07356019173899, 70.12695020244968, 76.14484663932555, 79.29909906079693, 75.27865394469231, 78.0029518373551, 67.10879618121733, 63.91870114111132, 57.4023969711796, 53.57507367287913, 37.4928186016698, 27.48086871639375, 21.192544467987556, 7.901314650812457, 2.1926264993606077, 0.09558814577758314, 0.19384082196460617, 0.23324855332893712, 0.20420246757566932, 0.13960389600646111, 0.1445715471861824, 0.1773149877666466, 0.11879450416252499, 0.09940898631729427, 0.16156428133047399, 0.2534728914859795, 0.13817511138416108, 0.17391248485974728, 0.18121400757903056, 0.14839225749094642, 0.14773391217233675, 0.3211156819616595, 0.1880512350509244, 0.23446385989025717, 0.12780170632346025, 0.14222947850583062, 0.16159592076174675, 0.19457815094820916, 0.11746235387099367, 0.11794129671949534, 0.11978043633843623, 0.19404188940121284, 0.1504626101063144, 0.2394118685755999, 0.146575219508621, 0.13978196548358088, 0.13150623939450712, 0.11290723337761818, 0.10041886640171852, 0.17042721381350873, 0.11457935050730744, 0.12971534033215817, 0.20687986826223714, 0.12574534247358962, 0.11952959616938907, 0.11757862303526172, 0.13933234848082066, 0.2857412349793219, 0.16486386798562544, 0.12809864200291135, 0.20905816266613625, 0.28495605614396835, 0.17348771974925073, 0.2794713262588747, 0.11674069138544223, 0.1592359562674838, 0.14184212912955593, 0.13683021338956972, 0.2047853991990128, 0.10194215563035781, 0.18792624014519876], [0.03207678703831569, 0.0017642351327418922, 0.0243329270667727, 0.07023053589246928, 0.012596648715947185, 0.011701991128164434, 0.07375099335707004, 0.06957582949149994, 0.01635969654026051, 0.013662280849060945, 0.018579399911686778, 0.02574332366367021, 0.045021616012579015, 0.027222982269801924, 0.006030444957075581, 0.0428075069982198, 0.046228706280911164, 0.05631515395737464, 0.048155467206191634, 0.11766505307487904, 0.04303055732781368, 0.03688961184853989, 0.05097206989904085, 0.03417924256815064, 0.06958730548860566, 0.08473303995185322, 0.12473921621999434, 0.039898108075102495, 0.04115117894064996, 0.018913462127168334, 0.03273658026310225, 0.015857310443665954, 0.030535441117301106, 0.0633859807895797, 0.017994838436284376, 0.06538019575659307, 0.01569709847606118, 0.004182459416634013, 0.03818080707963917, 0.016501777121917378, 0.05960916732287696, 0.023571590802842574, 0.00030284251660040975, 0.04704326841860049, 0.06795488703515261, 0.005811262413889411, 0.07607318205578674, 0.03510766069314653, 0.015235915460864143, 0.07982597100518404, 0.03337774606000993, 0.03844808366510176, 0.02542050378847747, 0.020618544020239386, 0.03939687589844389, 0.031585753407149066, 0.0418948358105075, 0.03892125021065435, 0.03273340865909573, 0.031061373883858327, 0.07151832203230551, 0.04440672703147416, 0.07792283240104876, 0.036484385810552106, 0.035369892589627736, 0.054322042156972235, 0.021910108888762134, 0.026288090701845866, 0.04079107931184192, 0.05200348854545624, 0.45818143674442846, 1.3815652915546972, 3.918951581562719, 8.583270676674383, 6.790364096241613, 20.70943201741865, 38.68290885802239, 51.215203192926225, 55.02392661186957, 65.4491433020561, 60.38564582024852, 51.24065545297439, 49.58555252321305, 52.717380754409305, 59.39773805679814, 59.86140535723779, 55.208262320487734, 60.6023253933076, 52.822551265839614, 55.010131635973536, 48.899239724682225, 48.68423500368672, 57.05430230786724, 61.875695413158795, 59.26660929956744, 58.14701972469207, 62.31507931986163, 58.946108510417325, 57.6598927282518, 48.83003734773206, 55.292958059618556, 57.41528195719565, 59.2485507072941, 60.699686465724824, 53.39042025227701, 46.91978816063174, 44.18043228887743, 36.43493967671549, 30.85256165073764, 19.58372158388938, 15.006533284341137, 7.209457582043064, 7.794846815447654, 3.721035646815454, 0.7182106159387097, 0.7405225283676579, 0.05884808961362128, 0.15973665601303502, 0.0312933357312314, 0.03460453627931495, 0.022234439872385516, 0.013787601342154367, 0.019779047635834546, 0.033481662056498954, 0.05013609943430751, 0.008418253874556433, 0.015076530868217591, 0.07358256892691697, 0.06635114325270539, 0.07573612635174105, 0.0510330734804513, 0.03015152764536681, 0.03444039428065862, 0.06451167421595705, 0.019228339585806095, 0.06857376350390335, 0.05482479118772092, 0.04296786835296981, 0.025147454730505427, 0.010519273947143267, 0.042195601929580016, 0.03269439946199137, 0.03012740545185103, 0.036778490795123006, 0.04300425752937313, 0.07005419011317915, 0.06081663680473163, 0.06128738251244349, 0.11215770061338141, 0.05115758192034499, 0.02573062384110545, 0.05803423227682229, 0.04335139878094197, 0.02348562424641944, 0.04722603018425646, 0.03576345493896835, 0.09086105386696516, 0.05476882846485223, 0.021837596751509175, 0.03723759962726505, 0.07830163989696773, 0.06588608191739168, 0.03999733561349492, 0.10454283261130895, 0.026390399828913714, 0.05549299605791608, 0.07900887694690498, 0.007424555003507844, 0.01569826388731599, 0.05451100157393564, 0.06215809123410333, 0.050435505747314424, 0.03933502195943748, 0.06714304834003411, 0.0581968842344659, 0.05503856802299138, 0.044792915784543565, 0.07859621602561205, 0.025072230642000516, 0.027574333174514676, 0.04635819429231267, 0.004306822778627036, 0.017149412531345602, 0.01958419891795324, 0.07004579378952903, 0.08747878334214611, 0.06863472878091759, 0.002244732182119943, 0.04644461284061113, 0.024811132555647243, 0.05475842116040088, 0.025084189274498535, 0.06153963994415057, 0.056920754122397596, 0.029167035714753216, 0.05301598098970229, 0.043719155458553184, 0.02642278236547305, 0.03583187808192546, 0.007703618809295399, 0.06661299210522445, 0.01573956560253376, 0.04010822684053452, 0.032772406364881226, 0.0350529428631548, 0.07600391238567329, 0.040578306051752264, 0.053405356668536706, 0.006904635548351273, 0.027477932500562845, 0.0074903428040054305, 0.0033771729278903938, 0.038285190389762004, 0.028734467998747865, 0.025374979013577107, 0.07370880489507992, 0.013267812600749876, 0.02062712612021114, 0.03794006777987365, 0.050722129883304726, 0.08538363246066917, 0.05526750190784374, 0.024639521199729175, 0.032645147669339375, 0.09529285718716922, 0.028402246309504397, 0.02261010449259512, 0.025125157741469242, 0.027662006191789146, 0.07134337053303758, 0.07205010962582405, 0.045780318849269426, 0.056879013821843176, 0.07084411103278399, 0.01493207445638555, 0.046463933578061486, 0.02556191978886003, 0.035646768256781564, 0.09601905491323241, 0.05088855482397541, 0.042113710960914055, 0.035617484545875946, 0.055993626855554125, 0.048696355924250624, 0.12382092194691782, 0.7829511129567701, 2.975631606194281, 5.9389106881233955, 9.442456056994777, 17.367953100512107, 20.689694650711555, 35.591924267430464, 54.81827282136487, 64.10929303015432, 62.777868009382686, 68.13682586916032, 58.024445656807195, 58.899055757830226, 47.424173585830204, 42.5360962652391, 41.526038877425655, 48.49946391197943, 45.14839872237175, 40.42736730267925, 34.058348132717995, 39.04908172545895, 36.607735772286695, 35.46962868782782, 39.90343670691214, 37.18993709933373, 43.52822057662472, 43.783810061793176, 48.781894176237046, 50.1134878589261, 56.27055391188591, 58.14473690525178, 67.70461205513247, 60.219960981799716, 66.80504783507317, 70.3911453677762, 67.5060930559712, 59.83879289319439, 58.62667068358391, 53.153634609714636, 50.3629937479573, 33.33151725030715, 29.870096175901352, 18.707975956701464, 17.179445951215683, 11.794913257322005, 5.6816252681516834, 2.543236872842235, 0.6304393095835563, 0.18534374243069082, 0.02572455259430553, 0.18234604038298133, 0.06675142419314192, 0.04226613947520814, 0.017704646245786743, 0.028764240090705218, 0.03287691990995119, 0.03742418034122356, 0.08157403809168647, 0.020444270508784442, 0.03710394026711583, 0.029607444340663574, 0.016644512708749504, 0.04806010841181682, 0.05926945712417365, 0.05654304213221035, 0.02417647659087614, 0.011689133299965293, 0.03224317367459017, 0.023863443488916083, 0.04071658875252451, 0.03237386827447242, 0.04396315829287614, 0.017701126071774674, 0.0302591783204867, 0.12379035503873903, 0.013171530670426307, 0.01563183257296201, 0.07447628709938257, 0.020154034268231164, 0.022401427887680552, 0.043867707567950415, 0.012213731158314454, 0.053510735892961105, 0.05040695365037649, 0.0661931682618395, 0.03555123709262379, 0.06349821650092641, 0.06290939749188482, 0.09543265291159192, 0.04016178787776059, 0.015247862602043298, 0.03581533441320062, 0.0115441310504872, 0.04806376265121564, 0.03881253084288009, 0.005465445058014725, 0.02513942995949859, 0.06969196842082086, 0.08045831529964363, 0.051225771406485196, 0.07106554108641802, 0.04996030523832287, 0.04514903175614534, 0.014678582665510477, 0.06404497345248539, 0.043106886498149366, 0.03141855663289467, 0.15148932114243507, 0.1308491198165763, 0.1435598514733776, 0.13695773638544545, 0.12164900905542797, 0.09611607994884254, 0.19902909114476175, 0.11560780822389549, 0.14108790024634332, 0.1143589546723712, 0.15275882076351874, 0.14597307440013657, 0.1048162034262092, 0.13895396233326004, 0.08477943423654764, 0.09546499714375505, 0.09917128455614853, 0.21932521174030922, 0.12449327901366258, 0.1773942012580172, 0.13072415555436767, 0.1880731451655588, 0.21442129907588806, 0.11247076244363863, 0.13692235844510217, 0.15082411167602386, 0.2454727425450279, 0.1001847652538169, 0.17608388447232787, 0.0875556679262269, 0.07096312279182096, 0.1146034669551638, 0.12066879955631112, 0.15798963846698885, 0.10522584596108045, 0.12129377408493912, 0.1464677986598784, 0.11787949640664364, 0.13651225625747634, 0.14423315082826924, 0.15119829966175943, 0.12165230323350239, 0.11599649059315843, 0.09996524275911432, 0.2631299353895649, 0.07344248208908305, 0.14080648550823813, 0.1307797888594289, 0.11267463376204814, 0.12347934632411889, 0.12080128680193618, 0.1561591326589546, 0.11700152900190124, 0.13329926818128557, 0.16915742307901385, 0.10572315193712713, 0.18180472265568473, 0.14968996446940208, 0.07302628184157996, 0.12226231606496919, 0.10288745450276522, 0.1483718335868851, 0.16888475706500394, 0.14436061253711102, 0.0800952815540856, 0.16291743775288905, 0.13555421734288817, 0.1548149394652536, 0.1463299334770249, 0.26852304115891457, 1.22859297740844, 2.9800153451581157, 5.674453214291604, 14.127045716008833, 16.50198986453395, 31.734110424595496, 55.73418155793221, 70.34327676219326, 75.92404073284519, 83.85051542712797, 80.20582552879088, 67.8096374388664, 65.57424337633195, 69.21173572540283, 72.64644545893516, 74.67424023535945, 69.92767810821533, 74.32780865700015, 64.32101864968577, 67.32954717451527, 62.847101765294234, 64.01494041565927, 71.38392863735076, 75.82840550330378, 73.9317512512207, 74.67225551605225, 77.25054710142075, 75.77785399652298, 75.37397538461994, 67.13670776736352, 73.53456420283165, 77.01061571798017, 80.90393681680003, 81.97170795932894, 77.82629612953433, 69.43651891523793, 61.94629807626048, 51.92414414498114, 47.09469841372582, 31.265687250321914, 25.671495045385054, 14.802474917904025, 13.059298107700965, 7.3438291588137234, 3.2257738997859344, 1.3463231632786414, 0.39832845810920964, 0.3556718551103146, 0.15443661460472694, 0.24826520963782267, 0.11327336211839031, 0.10797169660368275, 0.16753374568877683, 0.22354874639741837, 0.13871480500505817, 0.10646962801054602, 0.1554110631226532, 0.17324154505566244, 0.1244667953541202, 0.1434750148966428, 0.14823015328616868, 0.14900183365229638, 0.15565780472130547, 0.18336962578037094, 0.10219534002845326, 0.19563297741115096, 0.22176794437391145, 0.15043713002195283, 0.1349089874495422, 0.11933072740512511, 0.1566015024699511, 0.07582509214238775, 0.1349393245313437, 0.18211970736663188, 0.09970676469346208, 0.09898605215693675, 0.16570213671413161, 0.23757661302243513, 0.17738197449474566, 0.1257220227571745, 0.09209466226879628, 0.17835173455457534, 0.13213478389286226, 0.24484651163220408, 0.12642771997038396, 0.1347520007120986, 0.12119356978444323, 0.1424451322565156, 0.20930260600101566, 0.14299149084235394, 0.18800537702777695, 0.16335323452949524, 0.16805672327116614, 0.16801818904857482, 0.1302966325273437, 0.1439512457938925, 0.14494656254687618, 0.09580732353271977, 0.08844724105250451, 0.20653074667338403, 0.17000062541375238, 0.18861956503843108, 0.13950035156261537, 0.1374637527811912, 0.30631176826934664, 0.1969985138144224], [0.0203570494833853, 0.025810687690072005, 0.03492249341140832, 0.013923875934955095, 0.01449448503403654, 0.03441757635183392, 0.019207890783887238, 0.03485749851191237, 0.07404301841292651, 0.02177502843551338, 0.03436054493631086, 0.01612007189842482, 0.06034974068883927, 0.0413338449453154, 0.0037549660755171175, 0.06833161077191753, 0.0616287742741406, 0.011367296890145349, 0.006262603593284205, 0.015477063660059246, 0.03723231745102713, 0.021820612582227877, 0.049730111138835076, 0.018484991066338077, 0.029643881397562164, 0.022591049970698454, 0.05784612704789447, 0.09282230024015711, 0.015478157250571157, 0.03540403712841292, 0.050822954715019276, 0.03355920547619462, 0.043474524432132323, 0.03970002072052129, 0.05157075612054718, 0.13651908976176094, 0.016394373510153066, 0.026887158052094524, 0.02542022799682473, 0.021835783038348443, 0.03420533552285164, 0.0717833961149858, 0.04243378632611806, 0.070080972547012, 0.011424423109049038, 0.034096286737269936, 0.04469164662183293, 0.07682973218540992, 0.03814842837351946, 0.044413116204762654, 0.050891649819189505, 0.04529327462096849, 0.02056381469892879, 0.028428379483821414, 0.0685264345919413, 0.06112496421161679, 0.03502046073516531, 0.03913050712717157, 0.11513929949292254, 0.035374060107935826, 0.030310617294162515, 0.048158650301517024, 0.013288589862866268, 0.027541801250810106, 0.07953517935088567, 0.0630052006172557, 0.03470150002789113, 0.04347278924298383, 0.10513284288707281, 0.12008022186496567, 0.03385526781541205, 0.06796679204149593, 0.06704397018878691, 0.027696773177012805, 0.23052218430224927, 0.12211183341400278, 0.7458825084951617, 3.699047084777586, 8.379281932307828, 20.117773855886153, 31.304434384069136, 47.4491943851594, 50.91171764558362, 53.15430141264393, 60.44191222037039, 63.071057335022964, 61.38707399368287, 61.35867211126513, 64.05284620100453, 59.48019020019039, 63.093861995204804, 61.5756223278661, 61.92709022952665, 60.92576403771678, 60.71041807051628, 56.122543273433564, 48.79475955040225, 52.24121286023048, 52.48885170105965, 52.377275959137954, 45.620287310692575, 35.68136215209961, 29.792809794026038, 12.876234227611175, 5.751700372465196, 5.498242695485392, 2.9707940980311367, 0.6295770623030201, 0.24156066859441422, 0.09132050743867313, 0.13108381851305886, 0.04321559437460477, 0.05417786824006227, 0.08160766935156238, 0.015700620565293057, 0.046802023500804944, 0.02941610047503585, 0.05750519876939155, 0.028926528156584794, 0.03135627368465066, 0.11583154420218161, 0.0468379530244537, 0.025321745478938666, 0.05564303437788641, 0.03759948424093666, 0.03393425531084499, 0.06665036953505009, 0.03718440631224263, 0.04565324784526902, 0.07053137095945497, 0.04707437924920552, 0.055169783562662146, 0.021280627847919543, 0.028938697463261987, 0.0548741847066389, 0.01306714736030347, 0.026690802056222197, 0.04292298709192584, 0.038934875084387685, 0.010958590897761527, 0.07669754371407532, 0.021959328122677344, 0.024991266639722932, 0.04373131327391152, 0.02938360111006806, 0.022378638687153018, 0.03477733890195528, 0.054408303657246214, 0.016471863303694035, 0.032240925206532406, 0.04500814052599092, 0.030444931659486987, 0.032905671189749436, 0.01616956692399277, 0.04496043240050635, 0.005761968486401583, 0.07913197195457836, 0.07785656579559849, 0.0345025125199989, 0.04881133806080588, 0.06829791822500768, 0.14624693551130835, 0.018857238934405388, 0.003251386318175543, 0.10328001327692501, 0.042226762555900126, 0.01497288779055159, 0.029800249519006863, 0.01852584078968052, 0.022243527590387294, 0.032546977332282456, 0.0832380423502576, 0.04535717784517235, 0.00673562218810642, 0.04092170113337137, 0.004080832107818776, 0.05081366206849775, 0.019551553996279836, 0.035627255997350143, 0.0363954889678186, 0.052125258221020626, 0.004438626769584634, 0.03113374237962548, 0.056391425671116005, 0.06942249699345521, 0.019636928749781464, 0.00861670895134129, 0.033518124011255084, 0.054797549101133505, 0.01845506575679587, 0.03245236547363382, 0.06284191280663495, 0.06195914203060731, 0.02937941443956187, 0.06269192045194007, 0.040007153030244574, 0.029357372174760508, 0.018672410646573673, 0.029782826764388915, 0.008572109227609492, 0.012702964482859019, 0.05420624796721724, 0.007184682819511622, 0.015146699734032156, 0.037031315131894046, 0.02399309237878169, 0.012509575162473465, 0.03171762012155547, 0.021273857545888713, 0.06497229224130993, 0.019750591299887148, 0.03490922093812016, 0.05115604208361718, 0.0196401922843389, 0.012307316459144556, 0.0585421217575429, 0.012329429587078913, 0.01198596459993672, 0.06389121577564268, 0.07379495148216525, 0.03293559841451145, 0.018375453899704644, 0.07353418281361943, 0.059595220692215435, 0.06128339502479761, 0.01797389742287417, 0.03429190345829533, 0.06424417929543604, 0.02519131134895067, 0.02906044798662826, 0.07460299038117932, 0.03507393367228008, 0.01444920828010166, 0.054523565415893836, 0.06676720560438211, 0.03929978191492058, 0.0504844319525986, 0.01814846587817996, 0.06560941692441702, 0.04454677556491187, 0.060485533603857604, 0.03728748344245457, 0.04435374439063092, 0.03920874385643871, 0.13384826210958342, 0.01540971687063575, 0.015123517913443428, 0.02361503947946814, 0.07485722431973105, 0.29246472903797704, 0.34618210948763356, 0.8479594343131589, 3.7167122142930187, 10.58495423486156, 20.469408458279027, 33.914793306781405, 48.73492379342356, 58.94623010389267, 62.34909803636613, 64.61172119263681, 68.0156167860954, 70.72484493255615, 71.021666372976, 69.9706280616022, 75.41435226317375, 72.51446554737707, 72.76167684985747, 69.78667674526092, 73.40002690592121, 75.77477101356753, 73.30330910221224, 71.20740629011586, 65.91392455562469, 68.9154085036247, 66.65754318237305, 63.79612315085627, 60.26531142573203, 53.08078050613404, 43.66481319550545, 27.442707976987286, 16.253864649803408, 12.318280992969392, 9.725981643123012, 4.387692712968396, 1.4796772527117885, 1.1197514952190462, 0.48130148000294165, 0.1793885119860211, 0.2077255220783334, 0.04948294053094522, 0.04418500203398928, 0.044141802335939104, 0.011874786089925517, 0.03488920689109833, 0.02822835201157197, 0.03379324150662269, 0.04408696576231911, 0.051000135530146866, 0.011803570556484405, 0.04951646836895136, 0.006329531907179063, 0.036814968071637616, 0.027936602747368238, 0.014504403957436162, 0.08463492707139061, 0.05215597068590503, 0.022912952455601866, 0.07736796257837165, 0.005159190876574646, 0.03762404501978909, 0.04422334090415989, 0.03806191789467008, 0.04998785376008, 0.005669410700999922, 0.03483573395398355, 0.03386981582509414, 0.05255694110547343, 0.044868065179475856, 0.019016707796723615, 0.03715148368369668, 0.029976813633355404, 0.01691979299780102, 0.08688182464890903, 0.01646321608624872, 0.020637897316426523, 0.06279796234241898, 0.01048822440357218, 0.07071454258215043, 0.057577785600217125, 0.025376287108707814, 0.04316315948662739, 0.019964619028952815, 0.06589394197949479, 0.05019350240247385, 0.0624198864604677, 0.050925897779844465, 0.023852789121109153, 0.04553044395100686, 0.018736066807421948, 0.007621360597230735, 0.07951856290380802, 0.023013949657099384, 0.009510938487496347, 0.05581296034037106, 0.03865061049920417, 0.010534391734719036, 0.08738962602951834, 0.011541150968461748, 0.079184525586184, 0.016470034268774813, 0.01814057708777968, 0.023135907024205215, 0.22088680536516253, 0.1335998964045317, 0.12522762791524011, 0.12887126465718593, 0.13448665849864483, 0.219174767393739, 0.136347072379243, 0.1730869944778181, 0.2015908585200387, 0.2295615713322355, 0.07477612625206671, 0.11695875831308866, 0.20298728358841714, 0.13930852314637554, 0.11830938664535362, 0.13309823138819588, 0.14517775256066554, 0.17023491042275585, 0.16073466939551218, 0.11028271574046343, 0.1216901786204788, 0.07622347318477209, 0.10677184203579541, 0.15249180847839003, 0.07996955886483192, 0.12455345522011481, 0.12611435170495702, 0.0898586891050781, 0.09386355162508066, 0.17183450200865347, 0.11602849774663487, 0.10283479361885017, 0.12021356712906592, 0.26001538961164417, 0.19301603638356735, 0.2632400988330764, 0.10762531760959856, 0.1682454260486749, 0.09296106174588205, 0.11437705733002194, 0.08517412273513694, 0.15208155307317936, 0.1358256729379777, 0.19570111327113646, 0.09239174350495301, 0.10088649413157856, 0.2202127705658636, 0.2289753302090591, 0.12803933147581356, 0.08333336667067583, 0.16270365325673936, 0.1252303092229751, 0.10278315929275367, 0.10682117043723983, 0.12881809815524087, 0.10121077148904724, 0.11211881399034493, 0.1597349706196016, 0.14306350310723628, 0.17276718341294797, 0.23921018826865384, 0.10804380079911602, 0.16771809708687568, 0.12286528854841187, 0.15287623139879397, 0.16822693268618277, 0.14761253320161374, 0.1496312974561607, 0.2975419001473535, 0.14826271202295058, 0.15715982734916673, 0.2504488973007087, 0.20260799345710587, 0.20681199287214588, 0.3428354697121728, 0.41626793903208553, 1.5721413685429482, 6.2084187038483165, 13.379880286032154, 27.824570325113115, 44.18349173761184, 63.22180578785559, 72.53172397613525, 74.52508818718695, 83.12617132740637, 83.14356311675041, 83.3367790714387, 84.24847910481115, 87.10996581662087, 84.41168892768123, 87.26171447384743, 85.86115375641855, 83.6417119733749, 82.90840133543938, 82.41583008919993, 76.59834323390838, 70.31931892518075, 73.89804240195983, 73.76011617722051, 72.1205654451924, 65.790558168965, 55.4237534153846, 42.996786486717966, 25.2357118745004, 13.41179955390192, 8.832916790439237, 5.481566248401519, 2.028667871509829, 0.46295842396155484, 0.3951023392859967, 0.2882121136832622, 0.13528135214601794, 0.18227657153000756, 0.29907309540337135, 0.167918459722592, 0.06397932737825379, 0.13891829327950556, 0.22534592738074644, 0.1167399712627934, 0.15785027175180374, 0.21910922091093757, 0.16644688142884165, 0.1370380683651855, 0.14431599557640093, 0.07107219839048001, 0.16940211156202903, 0.1524303222615873, 0.12452491078405611, 0.12179822766131933, 0.17952539657633151, 0.09973737756691634, 0.21606734623351406, 0.07019194038284403, 0.12904260788233052, 0.11428821411344314, 0.11269960056750045, 0.15863868347819776, 0.11047180156193434, 0.16121014952659607, 0.09955239031584033, 0.2594981883322039, 0.07599154006569617, 0.09864862873068742, 0.1464941980497491, 0.09699655246109733, 0.08339800150884737, 0.1553486576003413, 0.11630208306615392, 0.13030751097586848, 0.1603332393231892, 0.12392863390907166, 0.12530214528763486, 0.08110877757351245, 0.07970344290257463, 0.13339193417660652, 0.14013234345662978, 0.19036454479059867, 0.16236573187333925, 0.17002532408843118, 0.0960945069128948, 0.0996151865429936, 0.3767313057136151, 0.10984655124165359, 0.07318319963111032, 0.2305321740887819, 0.09275219553420622, 0.1515049493360904, 0.09474151902982304, 0.10951766203488074, 0.11541044099196313, 0.12998569276063673, 0.25823638023388, 0.2043249037477278, 0.1156081836069784, 0.06664581131190062, 0.07506100370758965], [0.08890440402131888, 0.041888232132600206, 0.059909849172277804, 0.037105606508351145, 0.07956482695355531, 0.10333520225099019, 0.015810187417833556, 0.02189540574627538, 0.025151537979141842, 0.011122270370833577, 0.05903506869330041, 0.018613783852948297, 0.01488317219134901, 0.08641006770513712, 0.05279259358142173, 0.07208590125364643, 0.025583297472387075, 0.01919564103797799, 0.049936181129587275, 0.041332714965627085, 0.04640740395012883, 0.0008961402073187093, 0.04056348991129668, 0.00787588564919368, 0.021693543493447286, 0.0318847153891599, 0.027985201450064782, 0.030094067220606154, 0.047038376947203954, 0.005993251867156717, 0.0943252728170445, 0.02573922126283569, 0.08277784567326307, 0.019294684715268594, 0.018202348672334227, 0.05090987122046852, 0.04221571939847162, 0.04492241911770356, 0.07787272258992158, 0.045855322687496106, 0.05632527780929401, 0.007379369222513972, 0.04116767281365972, 0.05780675395902607, 0.030644290720022498, 0.03782686296730273, 0.021922705289457115, 0.02732551547758762, 0.041889488516796025, 0.005509197775785241, 0.09629745892579518, 0.018770960197153113, 0.069831021039957, 0.00734712889102558, 0.06833478237592405, 0.018946792697533965, 0.03842033979092394, 0.058429763472128304, 0.05208691935085001, 0.04484276512577649, 0.042129997990184256, 0.014824444848683574, 0.03333855683224336, 0.0476707135807843, 0.039815562101261276, 0.04314959206948838, 0.017487339660405152, 0.03139262072621815, 0.007749825402448375, 0.027431591842023116, 0.03807745798821411, 0.08078268458766323, 0.0809632438505369, 0.08837201121834018, 0.0331118943980865, 0.03966407587511405, 0.025446820823896318, 0.057215908647424756, 0.09908155267757755, 0.08943626822362985, 0.1852990335394298, 1.2726322465365933, 2.4614981105250697, 4.70316110118743, 8.391867837598248, 10.882050241193465, 9.573540687561035, 13.405867949608835, 7.997944201192549, 9.733857762429023, 9.47397034014425, 11.55337272151824, 10.588726574374784, 7.4479680868887135, 7.6454300072885335, 4.484288923202023, 4.0749611585370955, 3.2888331096018515, 2.8502187228971914, 1.4586658511430988, 1.3119198093491218, 0.17943306765969724, 0.1080658105051806, 0.2486836008967892, 0.08362867824372747, 0.19116620983808272, 0.08371741420799687, 0.10438756957169502, 0.02465952758587176, 0.02974362221486386, 0.012188883096490417, 0.016530898039139087, 0.06272879992461493, 0.011511211294770963, 0.02601722882489764, 0.04652933450415731, 0.22519545239065925, 0.05398712766867492, 0.026375700516866583, 0.030759387769766396, 0.00703330576089361, 0.044929340722099434, 0.04555169139958678, 0.02155886523635878, 0.056219956041463924, 0.02605352224031043, 0.018451970761581775, 0.06111177217756068, 0.061159035972049164, 0.006416257369452187, 0.020128247748699882, 0.06432174569776943, 0.0352302156088333, 0.04631564193855851, 0.03442589223625199, 0.041552635826050274, 0.015937753506155027, 0.023832708041393952, 0.013498575520521451, 0.03618575324634871, 0.008456810122175563, 0.011539029862521397, 0.05489675748732783, 0.022269072792222424, 0.08398002914844022, 0.013915542813558734, 0.08112548595114101, 0.07498267887821121, 0.05386901223250935, 0.11356844386506466, 0.029611560148036772, 0.03440022446034897, 0.01566426490523642, 0.03214988714805053, 0.0798667498653935, 0.015328346841758298, 0.07177770408170839, 0.03141302164764174, 0.08316959239422314, 0.024920121969414816, 0.03627130228485312, 0.05933960779540001, 0.04745025262837449, 0.008057123857490238, 0.050166244994127945, 0.07193202483317546, 0.050926204215014176, 0.09423114359378816, 0.052272691842048406, 0.016808311883059722, 0.058376865100956736, 0.014763514045625927, 0.09313271140619632, 0.0069223403190863475, 0.04823405633590395, 0.034286494877549915, 0.0961944660652549, 0.005500837841311531, 0.02877668135859553, 0.09538562277392035, 0.0487197445885789, 0.05962601742677151, 0.036251847482016014, 0.034554637142366944, 0.024515213857915615, 0.045820228199684815, 0.0981024386841924, 0.025317748415193735, 0.00891613728937603, 0.04653531382040632, 0.031219038609114867, 0.03435703242317804, 0.006428745560227864, 0.029447820345540682, 0.06370851529702064, 0.030049737542867664, 0.0318029604011005, 0.09429207822728543, 0.04103482550671024, 0.021408321298358422, 0.03520139155068225, 0.046270986673452204, 0.08540772592588779, 0.03497784326393758, 0.039513681324258934, 0.006653545443118821, 0.02771022951140279, 0.04336636047810317, 0.04442239352952569, 0.030145036965428345, 0.03616669297879262, 0.03320835252863265, 0.04825344219082787, 0.018144053211736105, 0.021586898308728012, 0.024529104947202632, 0.04495277918214279, 0.10367480902782372, 0.04280517043005075, 0.06114559495941766, 0.060755380414306163, 0.04248851564742866, 0.0159293552672851, 0.03144871751447359, 0.04268579094881012, 0.032064324703007456, 0.03517190099603707, 0.06993054352220028, 0.041834341677566694, 0.00621482412586169, 0.017933978496359724, 0.03675610187553591, 0.01855575269268405, 0.0567160822421072, 0.022312868123633728, 0.012531320568204168, 0.0065321358288788515, 0.09806093970133413, 0.03398696216003549, 0.031126868655724876, 0.033345122205754446, 0.03953874772114139, 0.04684359909245565, 0.10190829454410462, 0.02843112207859034, 0.07518933109578586, 0.04259515891692812, 0.024228660585058313, 0.05426791038424258, 0.04064682878613953, 0.019179733222230308, 0.08449456444190395, 0.023578227039486654, 0.046300963693929297, 0.028536499387794928, 0.09861762515239178, 0.8324780843911633, 4.635410491497287, 7.608898032096125, 12.885265484932932, 19.573182175236365, 23.318147467028712, 22.43530038864382, 25.164001141825032, 20.17433051140078, 20.52014235527285, 22.85600204621592, 23.831715160800567, 20.778342177790982, 16.81889384023605, 16.458851637378817, 12.147326450194083, 10.275840086321677, 9.850201145295175, 8.883118225682168, 6.36498305105394, 4.814253901281665, 2.0474199878592647, 0.9044789498852146, 0.42152072813722397, 0.2806787114710577, 0.1779610297131923, 0.053945486959550655, 0.1551569057928939, 0.08513646951365857, 0.08299876244798784, 0.0310777988089549, 0.027412449220015157, 0.04675101353636673, 0.06495677129996401, 0.06601047927453634, 0.08421765430079353, 0.06395467466885044, 0.02450247190051502, 0.028543754240437865, 0.031249040527449503, 0.016334321792988528, 0.01639340632414866, 0.005788593872209952, 0.060460287176312945, 0.016110993756522096, 0.01839592951470085, 0.04377296547435465, 0.007316272784655373, 0.04891456074772343, 0.04662612971339015, 0.015463804593309762, 0.0342295247490608, 0.025300084342879635, 0.06385510622133171, 0.041392377893170046, 0.04103809670214692, 0.015124085776117301, 0.05805237706930888, 0.053364577808327256, 0.04205520099569713, 0.018361664317067594, 0.0097767939798594, 0.05625485900729414, 0.03181044699534053, 0.04071555836426635, 0.032455617516872384, 0.014189692165312028, 0.0459545808694055, 0.04216059554188002, 0.07627213508972237, 0.015625707700007384, 0.0716231458429848, 0.025829945225268606, 0.029084005190299887, 0.0818858665203856, 0.014157417838671997, 0.02012988526163803, 0.011112006707868029, 0.045347563441722624, 0.07276136097648452, 0.04320898686625785, 0.05042772995488298, 0.025322779697636445, 0.03789792528315898, 0.027566114966306957, 0.10835757509114281, 0.03023351820546293, 0.03085224145662881, 0.042799076200613094, 0.03281240381540791, 0.026360549212944125, 0.033174303750838005, 0.012440165681313845, 0.042903256497435996, 0.03109671160458557, 0.037940408688999956, 0.2030513898259209, 0.15046107793046584, 0.1755132562210483, 0.23120159703877666, 0.14049677148221001, 0.20598702343000522, 0.13643514184701827, 0.07739045491982853, 0.17237840911313412, 0.16038315761233532, 0.15048479601260156, 0.07768169090512299, 0.07689271227366502, 0.20686630850597737, 0.15942412278344556, 0.11359263692171344, 0.08944483308662331, 0.1593333720079353, 0.21980708104468163, 0.07535220904936714, 0.08375117570281991, 0.2729651253790625, 0.11640204987939327, 0.16358897510555484, 0.11248946264987031, 0.14194647030484292, 0.24433858001664763, 0.12525478573215584, 0.1698985058934458, 0.07248174654500139, 0.3116870088683021, 0.20123922416279394, 0.1704623925709917, 0.1023038027567729, 0.18187933961950964, 0.14596415713669794, 0.17555263314035632, 0.15138095034466637, 0.12182014543683299, 0.14108125060316057, 0.11297624257783737, 0.16146501165724572, 0.1183679617280441, 0.16781309198948646, 0.151144459002441, 0.1629572283596762, 0.06850892182199225, 0.06912818899558437, 0.2443710927881541, 0.15734591010597446, 0.16743767826307207, 0.09589918513572025, 0.18033397173689258, 0.10220932113307138, 0.1298646508686004, 0.17962875715907545, 0.10045134086882877, 0.17805725035648193, 0.0688511792630438, 0.1255121912747141, 0.11915232084931866, 0.11007871418710678, 0.10415934431817263, 0.17855445674109846, 0.10841605824328239, 0.15586536858351002, 0.09058601298038998, 0.14528581692326456, 0.13415837450133217, 0.1303091810475434, 0.17036991043677255, 0.13803050462757388, 0.160649664279434, 0.21337771878367473, 0.055644715940880204, 0.11832284681018322, 0.1465340346218117, 0.19542631753269704, 0.2420206431059107, 0.10477991384123603, 0.3180618716343757, 2.1462204475556654, 3.8053416004104004, 8.297963353895373, 13.129779177327311, 16.29738824982797, 15.936378202130719, 18.709833198978057, 14.360053135502724, 15.393497655468604, 16.581384520376883, 17.81113974509701, 14.476881911677701, 11.992156505584719, 10.862033405611593, 7.479755465061435, 6.926731178837438, 6.025248429467601, 5.413644525312609, 3.59172637904844, 2.833054185875001, 1.0398873806961122, 0.3833297742230277, 0.48215315527012276, 0.2356125627674403, 0.4359770830600493, 0.20577509286663226, 0.2549578609966463, 0.09986929024659819, 0.15508389761371, 0.1545341835627633, 0.15459084342564308, 0.24011201165135831, 0.1840698301431633, 0.13469693431210134, 0.17306940509907662, 0.3658408449301797, 0.1795687571528458, 0.12315378959981665, 0.11058575714067106, 0.11053442924974427, 0.1313739206882254, 0.07745114440519003, 0.17063332210865714, 0.13575690888589428, 0.13179500857668539, 0.2220358912863078, 0.13629491711335798, 0.1861133390376645, 0.10823228141112674, 0.17019643748719848, 0.08193594568799581, 0.13254459496707688, 0.11987869477560444, 0.09367057407695441, 0.10960327236041909, 0.12079506616799102, 0.08771761125254054, 0.27171419572926336, 0.1445832683314239, 0.1106815870791193, 0.093555492348969, 0.1385247385910442, 0.17572186196282988, 0.14259856434599047, 0.13818586725861798, 0.17045025773827108, 0.21178773394034756, 0.30701273872006324, 0.2064444545295931, 0.14749944330223147, 0.10590619332487546, 0.18068894623748719, 0.20967798908391308, 0.1683291134935233, 0.07107052831880509, 0.1407884211549836, 0.06194914841363507, 0.14853059764831297, 0.13967193993589572, 0.12272604440729465, 0.11665656727047698, 0.3044817680793424, 0.1517703681583366, 0.18576892122866648, 0.1643195012283902, 0.0674457986268305, 0.1370184718360824, 0.11015032042538929, 0.08557865546355325, 0.09919793675503424, 0.1423265878111124, 0.20192340196621036, 0.1432461078248678, 0.1002547627074584, 0.12464332499451215], [0.004564312590856947, 0.02434301452951566, 0.015472251670284858, 0.027302463891946023, 0.06151003447631675, 0.024674491198252768, 0.04806532164014155, 0.028750936973900087, 0.027333611111727454, 0.005621493816555989, 0.03055741443418928, 0.09700856471975004, 0.020244557132583954, 0.028958849406110185, 0.019074620213359594, 0.05666154444277768, 0.022467543190765767, 0.007661860792957728, 0.04018015866618484, 0.07027587297582819, 0.03596495521525222, 0.06217802101145349, 0.0626722205009672, 0.0231554844011102, 0.013579632410959852, 0.11320977682067503, 0.027816221606166616, 0.05671059705256935, 0.026718685741446195, 0.013529128064551662, 0.0532320024625909, 0.020751860556042483, 0.00979197784251864, 0.045096075928379456, 0.032158651193904306, 0.020529654838385123, 0.02472784539173928, 0.04932318055521577, 0.04473184708565955, 0.0034500999496348446, 0.06413119664836316, 0.042121057744107904, 0.034188167492468516, 0.047111779661668886, 0.06303591308214011, 0.032467227579364856, 0.05678529445562632, 0.027405058386765664, 0.03227909170692006, 0.04581220342867798, 0.0629481423886553, 0.041965143529758345, 0.027979798614978794, 0.020615491159861127, 0.01426774982152687, 0.02713745429871544, 0.040246455915152066, 0.03905633449434273, 0.02593651380119545, 0.07601718102852184, 0.02219729801459659, 0.08917768290566822, 0.022836667335321827, 0.018546312574237105, 0.056980049327736905, 0.010993802213981267, 0.06093414703143701, 0.01969526059955599, 0.014922973331845096, 0.038877035446104505, 0.019443238739885634, 0.0026677530061738988, 0.0024275080725220184, 0.041303327832851684, 0.04646522060577427, 0.06347977293414936, 0.057138824880483656, 0.03806159996818151, 0.009758885717019439, 0.09535893993151766, 0.03681968717325119, 0.051107724918232816, 0.03925009728259137, 0.1666282297622773, 0.23821022902284902, 0.27457939520958935, 0.19025767552516154, 0.21322301498824553, 0.05994889284333876, 0.16671430740144946, 0.20702665070852927, 0.15283325386624183, 0.08242878537144392, 0.0511784693076005, 0.13305920686933304, 0.11105048139729809, 0.23718750164393457, 0.05865086793839451, 0.08776820369906004, 0.018402692155852433, 0.008558198986124367, 0.03715727147796462, 0.057090637950046416, 0.07689867243771592, 0.09602717544522979, 0.09893429525677236, 0.0630966523632167, 0.05402042568030377, 0.04703286877502838, 0.03932977425715616, 0.01176788618097142, 0.04399266033884018, 0.11154950341029514, 0.011070201289840044, 0.08832888046820318, 0.00756444457370127, 0.03140753262766427, 0.0872512552286348, 0.04418404825452355, 0.06922072475595821, 0.017337054277079243, 0.018583626801808997, 0.01670314907847393, 0.02877766578157823, 0.04705229293434851, 0.08789155917662768, 0.11673928178366154, 0.02244073394385557, 0.05180029138442009, 0.04021513824080748, 0.06959292091309063, 0.01672850084310818, 0.07008899348757922, 0.04077733186404071, 0.10666052946039747, 0.051771930809463226, 0.021421386927907026, 0.024998433392254577, 0.06925906745656844, 0.01965756332802196, 0.010780237010499884, 0.012230611905725974, 0.07560157832959968, 0.011417143358548563, 0.10713022562765306, 0.022347558500064958, 0.032427643816317284, 0.02706714849468441, 0.028961379411480123, 0.05297449349816288, 0.05795760433219614, 0.04719828631007864, 0.007816392218603963, 0.03304011195958142, 0.0605370415254466, 0.05170073442822022, 0.05588886050146915, 0.05418948213299436, 0.04460380698043493, 0.02183891250751913, 0.019983196661116618, 0.029013804723358447, 0.07163207076730267, 0.0389554062407584, 0.017643573716463103, 0.047812799908100605, 0.06177561417702706, 0.03961226151835534, 0.07700983179552902, 0.04142543841754237, 0.03342953743413091, 0.014120531662727797, 0.02702784243850939, 0.032504049595445395, 0.054060557196217204, 0.03716770559549332, 0.07691511268457098, 0.021126408603102453, 0.04004677892812798, 0.0382175563173669, 0.04978193315647302, 0.027254790240418048, 0.07888309297061737, 0.03349229535688797, 0.013440183341322888, 0.026237505916205626, 0.029161085126801368, 0.03771788312963421, 0.03145992729602562, 0.010590498099073527, 0.037347740088138855, 0.052192072579336744, 0.026497161842041442, 0.009968841688767558, 0.015762064647259974, 0.044033584755755244, 0.01879438908109742, 0.05838756351881932, 0.02190434407713192, 0.017511304805896456, 0.03739913309653921, 0.05609083192182645, 0.030483349053669843, 0.040300790701181664, 0.03637926322558234, 0.017136965517795855, 0.12219339879530093, 0.04960413564056639, 0.022870520760695782, 0.025950586836364482, 0.0241613999805263, 0.02068446397090391, 0.015529416193584762, 0.025117023802933194, 0.024689573554262042, 0.01606228014063691, 0.047801825698585286, 0.03914919967252401, 0.060833011934113126, 0.06694961113915329, 0.010840694754264288, 0.09126785421563734, 0.03184133949088714, 0.03164143459270558, 0.036127120707063906, 0.041540907019929546, 0.054757444398297425, 0.0633472167406111, 0.036790288549156926, 0.015936201220498453, 0.016534054321387125, 0.042081481641939575, 0.035720316527952115, 0.051269124322120226, 0.06974418497373981, 0.06513009103195322, 0.04188606027333487, 0.07448183357595436, 0.023710718115551338, 0.06535951904351674, 0.0703079107728216, 0.021776487833009135, 0.020444329880598574, 0.04964142113984112, 0.02509193442341301, 0.039496903998717185, 0.04614299253350304, 0.048622914905389475, 0.01786845116575639, 0.016420594784581376, 0.033650366108744376, 0.04618048487651733, 0.11181096155797282, 0.03345024862116383, 0.022750861657362793, 0.013102725441116961, 0.0651788755109714, 0.07102082453427777, 0.037666011316281174, 0.1508455774596622, 0.07742387167508565, 0.11696846464708929, 0.10938404864000698, 0.24521755865745007, 0.1982826763583768, 0.253138049776035, 0.16286414867687612, 0.22005555400204277, 0.15433611919081983, 0.10449859103368175, 0.044775115731622905, 0.04061882061162784, 0.03723829676727614, 0.12512897111235127, 0.16602971591055396, 0.11414401338345583, 0.1344921130446657, 0.07690509991540063, 0.14603462190397326, 0.07883786313956784, 0.11000167638544114, 0.028747652371924733, 0.02937367835622882, 0.04241228223808351, 0.06063838729694967, 0.04796668398945082, 0.06092950453861587, 0.05340998000915974, 0.03923322419605909, 0.05805986940920834, 0.05694722246018149, 0.03593483646850913, 0.0367382750095379, 0.05921682688377558, 0.015436446635923801, 0.014004360174670095, 0.014714335031326742, 0.015279890822937653, 0.01607065922730873, 0.04923148366111902, 0.07648968873845954, 0.014923473204215689, 0.024460641584629496, 0.06427494538647514, 0.031296407743807764, 0.056552124104552695, 0.04308394599525679, 0.04073974376003589, 0.07184547988036949, 0.02719583019854561, 0.033341900806032845, 0.05078964521207156, 0.01952312447340979, 0.04342114342556846, 0.03364441360557272, 0.05125723080709577, 0.05747406878658841, 0.01999022934826151, 0.050920297677117976, 0.03820047638709507, 0.0824713032512415, 0.025238709208825906, 0.014413729790718326, 0.024321506611041488, 0.010638510744507996, 0.01912218469735836, 0.0683301552048614, 0.043918920545688564, 0.023296630355499448, 0.05032587473491027, 0.07546556707952293, 0.02738576829283228, 0.035757701618657, 0.06121632785746648, 0.03678291495288572, 0.029668991844500267, 0.043873096996497725, 0.028753286948607817, 0.007238996538123297, 0.0073305148379727006, 0.04034325112438491, 0.09469491790138906, 0.03007684939450795, 0.022226183359781583, 0.037196874393210295, 0.035764132926781336, 0.027498948207545667, 0.018011420409405426, 0.039167057182038986, 0.041058229492797006, 0.036014720286813476, 0.009163305982046071, 0.1355252132540749, 0.08686603557678961, 0.10157224241523974, 0.09112381436411413, 0.21309812733482933, 0.07824984469240712, 0.21681693262390553, 0.12543465551589766, 0.09900115941080356, 0.13068392061658446, 0.13509015192187604, 0.18757517269301802, 0.11287445247533823, 0.09286073487131827, 0.07867460980290368, 0.17902088171291738, 0.12433186428801668, 0.10537926272879686, 0.09990941027119275, 0.23082989117791577, 0.13603233281643162, 0.14253217516647232, 0.1567837854306544, 0.09179088542418135, 0.13925647513279993, 0.22803992153175418, 0.17748832282039428, 0.12514940267729183, 0.12242163170970256, 0.0829860300666863, 0.15093386143205628, 0.10049474741061849, 0.2437489681066044, 0.14132930987304257, 0.2126777902125351, 0.09508777544983933, 0.15442729897556767, 0.14849987752254934, 0.13601512648165226, 0.14913870292084833, 0.19881337610704286, 0.10462067480529509, 0.17081955808304972, 0.16737360266908524, 0.09813561795219299, 0.19645289067299138, 0.15440295270133406, 0.10794671447647196, 0.16411540008360342, 0.14627325829238663, 0.20011969391376744, 0.17327557468125898, 0.08833304798651127, 0.10895428863624412, 0.08616491956936737, 0.09025397515224834, 0.08354997037038689, 0.12064326584579484, 0.25385887722574896, 0.2984079165804771, 0.14432109772197663, 0.20989531290627297, 0.14819544950319877, 0.18463941651486582, 0.135931852724283, 0.14618102130630325, 0.18610889572770367, 0.2000403118830535, 0.21065141104402083, 0.13001495731934426, 0.11089439098272594, 0.11749819146409152, 0.1540945410247772, 0.20883380615663147, 0.2640105994238008, 0.1499398317067854, 0.17558039616673224, 0.12050271169432711, 0.1326516787371328, 0.2403946061648669, 0.23337820604924234, 0.12324812566681255, 0.16136016486392868, 0.3418764195615246, 0.2826610712274429, 0.46055600287452825, 0.2679296600962839, 0.2977368848458413, 0.17491039098991504, 0.25148674725524844, 0.2742014687147833, 0.24744207880670027, 0.33053215893526233, 0.19870957119330285, 0.23950327818672504, 0.21434646760744436, 0.33783518318687716, 0.42891507006941304, 0.22422414483322253, 0.2213778830463848, 0.18584865565982558, 0.17690850151402338, 0.1602437142883578, 0.26514398054249827, 0.3748101717041385, 0.16651354640001254, 0.12097708865880005, 0.12445456859084869, 0.09397362313804128, 0.23289851243457488, 0.1206227653329411, 0.17177093203269667, 0.37030398124648684, 0.16622488447014364, 0.1596347816408642, 0.08622114276213032, 0.10524320551344465, 0.20373690062232558, 0.1510642955620443, 0.19027813007273983, 0.1884033137391652, 0.14998660903544198, 0.09906123602582563, 0.09551900634241682, 0.107868941230399, 0.15511650231576737, 0.2201282404242985, 0.16315752970835856, 0.16977067646240035, 0.18515186804917552, 0.16541422555042853, 0.15854646181387289, 0.15687070576654327, 0.13022705642206053, 0.24660742601319668, 0.1896100707592503, 0.13947951397107494, 0.13089061113855532, 0.2313022609920271, 0.14248331407866172, 0.15397693120664166, 0.11114286394008707, 0.14873969368636608, 0.09509113091494768, 0.18295480449113155, 0.09835815117243799, 0.1800950289133095, 0.10183949984850423, 0.05279093883150528, 0.11649652384221555, 0.09517184593864987, 0.18676143409984727, 0.08754765464653892, 0.09522893481076726, 0.14537675155987664, 0.21635822981836336, 0.14195554078586642, 0.11745901372764381, 0.2086891840782858, 0.15478967388551082, 0.07903536060644735, 0.06811460870648585, 0.09633405494593805, 0.15286435703596762, 0.11596009375587588, 0.18297610173542656, 0.15572722760900376, 0.12224881759574338, 0.25618144130754855, 0.063252558916687, 0.10114482664052518, 0.05346266770615213, 0.08640406923669, 0.2147637556997999, 0.13283494229037918, 0.1257875769008552], [0.02939605578449705, 0.09613265043064471, 0.07624069484130991, 0.017853372640186743, 0.036675084247103626, 0.011797374820396786, 0.050273478151329105, 0.01975245672398277, 0.027342641373134913, 0.016953167618222294, 0.05988372557405984, 0.03984167420816037, 0.03286184713004097, 0.011225528489317627, 0.045769532331295555, 0.0400492150877272, 0.012319344997165665, 0.029416278590478247, 0.05387075125209747, 0.03984720153253406, 0.046851485967636115, 0.07617281945121866, 0.031421343277719234, 0.02952854686056174, 0.026132779781736677, 0.035434979419674606, 0.04311298455802664, 0.005366037488960091, 0.01423841248446655, 0.048478664379687085, 0.027895866021994623, 0.03584246541703901, 0.018275349190638914, 0.012005264269969156, 0.021586170525199944, 0.05009944978800993, 0.020055254891274438, 0.0663857780877621, 0.06633825765381898, 0.015194843572023657, 0.025355803832832365, 0.03881758319274072, 0.08640987618315606, 0.008143716690791471, 0.03640714882602615, 0.02169336154756527, 0.031416212403846365, 0.04059610993511254, 0.06068946620930107, 0.06827901883591568, 0.010766768227181128, 0.020182890885118997, 0.04279087522938367, 0.021249905806936083, 0.05159342849266626, 0.017777089435126514, 0.020464771021638187, 0.05335328950276298, 0.030312861931780656, 0.03607492713678268, 0.05234073194104338, 0.02661769045516849, 0.0562735362308881, 0.06436570382286465, 0.029725893025076198, 0.02321986451504692, 0.020903364019168, 0.1255528705434934, 0.0745625026343811, 0.005948366296868171, 0.028415242991139813, 0.03736809504428699, 0.03995154270782106, 0.02688626747488255, 0.032885488603384264, 0.0877655147304458, 0.0115025554588365, 0.04152892157435418, 0.038713410556797063, 0.0460014884330092, 0.03186058744998469, 0.0186157354619354, 0.029263045683863665, 0.025919050826961477, 0.010752769885584714, 0.0691364627451666, 0.05110394427432649, 0.05764563800767065, 0.024103809320818514, 0.04418030974545306, 0.08160338692006566, 0.07395587591153961, 0.056616766603603486, 0.11058976378051505, 0.042520959471021934, 0.02876667433508462, 0.026195815411366286, 0.04848275528920274, 0.04268510913055751, 0.015467274971606751, 0.027166904633744594, 0.0453307171682677, 0.04992202382474657, 0.0830156700084767, 0.07842385390352818, 0.023737990845655723, 0.05245717730553401, 0.10382209709214588, 0.06453107922307907, 0.043049464377784924, 0.044343647351788903, 0.07092785210378709, 0.025668982491498033, 0.03452700435093815, 0.01536885948641406, 0.043712371749983686, 0.05764864107233383, 0.039374908327215144, 0.05660361670438321, 0.01661880662845027, 0.01193840969203701, 0.05908529724805586, 0.02493797181805055, 0.054458038085290504, 0.018408954924633427, 0.03313606447209755, 0.02173441428420765, 0.007943141465676169, 0.059840663771836035, 0.04361901244509124, 0.023470260353097995, 0.06867893205414857, 0.03416709624411118, 0.03850572795096425, 0.006115452945983459, 0.059111397863636096, 0.04541789797405082, 0.033266100236364914, 0.07357442541228187, 0.027201572027538094, 0.06714580625656151, 0.03041174473060716, 0.016050516860559583, 0.06655004266048632, 0.023707293702529806, 0.008869790885176872, 0.09124582152693503, 0.08414131363913899, 0.028502017770323063, 0.09382321709586729, 0.019574770290825157, 0.036003845668728315, 0.02873497170155808, 0.046074121229110226, 0.027852750593616117, 0.0351025547171312, 0.02117448062035105, 0.014175940887071194, 0.013626153100161784, 0.0814575161184034, 0.017471477809932925, 0.01604098959961125, 0.030383183057570172, 0.057917461324963844, 0.020537417224277894, 0.04862638911412609, 0.042389931622892625, 0.04592688679094276, 0.02903856085463157, 0.08233802693505442, 0.054219171870499856, 0.02403075517635913, 0.010925740089958474, 0.01575815759884614, 0.02943510903165706, 0.026053734829709418, 0.007554370038692029, 0.04174280949237366, 0.08574282044484731, 0.06996558438385687, 0.022525629892404524, 0.03785521205094072, 0.06923585499246275, 0.06134968844332522, 0.009814248976087379, 0.009129368287000445, 0.07201478531163547, 0.0652682549890972, 0.09482684590282942, 0.03304359382919727, 0.031727211542367455, 0.037359648924921794, 0.00978629538534029, 0.05515509382671407, 0.05607450275772041, 0.03329809206808287, 0.01562770718948976, 0.04461372015817512, 0.07242221385240555, 0.022507247612661412, 0.026057561438891198, 0.03900480742055563, 0.04168532608497528, 0.05154028880379854, 0.0424235207479327, 0.03976817190226528, 0.0649940874427557, 0.04027677384475547, 0.02517986408014211, 0.02482237489593606, 0.017157046597511057, 0.02149090557659586, 0.023356775918434707, 0.058111519057063334, 0.0023949988920527, 0.03183921934255669, 0.05698441219846568, 0.08260759029297099, 0.07480627181188715, 0.03745146456264681, 0.02880729614726959, 0.01987421490822829, 0.0013130164077137447, 0.034752755140465115, 0.08850915627854486, 0.003176531388289145, 0.03945325996967093, 0.08299350708482728, 0.03653988888066623, 0.027532349641044295, 0.06788043094979179, 0.060205471010938774, 0.04004196023508426, 0.0591722482274617, 0.055651829067257144, 0.01312946765533378, 0.07551702520539684, 0.028820614585833206, 0.02171843752054678, 0.0385496937369387, 0.041213216740758195, 0.05404901991207754, 0.014797439291742782, 0.07992900983099976, 0.06936825796841614, 0.05359093380731441, 0.016728014377276265, 0.06920698879947586, 0.051773501289708, 0.002198100649571467, 0.03432073900776525, 0.08404503170881542, 0.01663975530273972, 0.08343763123717039, 0.009097821743888481, 0.03421137612613459, 0.08295411484376078, 0.03533731087020809, 0.06987451185141841, 0.06261099475405871, 0.024368567392230037, 0.07695197683548735, 0.059554997245751085, 0.07136732610242982, 0.04339332294259821, 0.045478878572823546, 0.026094747346735774, 0.04016016377136111, 0.04165597342615647, 0.016608937500765728, 0.02239208736066376, 0.08072212533724886, 0.06774119446955382, 0.014303205328272476, 0.061292139918453274, 0.010821621080169515, 0.019897159241560488, 0.016199607146723617, 0.077482852784376, 0.09193470311020652, 0.03724201612414853, 0.004242829060287125, 0.057950518018896544, 0.06704596967826928, 0.06171779369094199, 0.03159864858213452, 0.04484330138732349, 0.08227336911424514, 0.010345720558337147, 0.08386202096458405, 0.03303659561600897, 0.05691951689039988, 0.01722792505226549, 0.020529066865903237, 0.038298474354369026, 0.0184188470349557, 0.027967696340994972, 0.02181611181567273, 0.019830614929237676, 0.06013840001316802, 0.06568374277483072, 0.08105642312476713, 0.030127773174054684, 0.04772630092057009, 0.040354439838519024, 0.03975557741679011, 0.034057193270493905, 0.01964175127326481, 0.05392984727457647, 0.04877309878206542, 0.03645111844244023, 0.07208542627913338, 0.08464307824690497, 0.024569604185319716, 0.05179683632788159, 0.05542820034128043, 0.03253618698386896, 0.023639314890568777, 0.015598904198756623, 0.01773162977769971, 0.06397435546762521, 0.0069568501860504195, 0.019889178520609296, 0.04838603285832271, 0.06353262917048509, 0.04686966140363966, 0.03196211708258958, 0.04602621009032573, 0.009285947082624322, 0.12021367438137533, 0.03823718348998697, 0.014341622722455332, 0.044537115196186694, 0.039272888398338715, 0.00623733178907705, 0.024026384644751108, 0.022444328811440258, 0.02548430550603136, 0.029825637672817516, 0.0364620658388782, 0.03506001768513553, 0.02077288200868474, 0.009081027181368441, 0.031741759552049546, 0.037488336374442426, 0.0744605593142971, 0.026526866901305415, 0.01361123832588595, 0.03281972378552441, 0.02575083132532816, 0.019590955813445395, 0.05872256993766754, 0.10910814207407737, 0.1916227829191954, 0.2882661994907164, 0.1990310829733649, 0.15345511807789727, 0.10348936212399315, 0.1697094200719749, 0.11301101530872046, 0.07622207124387065, 0.09362096988385724, 0.1256943133569533, 0.19649474971717407, 0.16712318384839644, 0.18948265501568395, 0.11413297405646694, 0.11700935075960814, 0.07185523217964558, 0.11759194530426495, 0.18532262904749763, 0.18957423316615243, 0.10389625440321623, 0.13768723595046228, 0.12144431802293948, 0.16737957815489463, 0.10588000077874431, 0.14142465717609853, 0.1529471098535484, 0.2252095637302245, 0.09492959361523391, 0.10584137462560209, 0.0928840622486126, 0.12423652464583998, 0.13272016699756348, 0.1421105816599823, 0.14924826881577893, 0.20411285061028697, 0.09705606217105543, 0.17760844540692147, 0.15422143582855502, 0.12972056505180177, 0.14481059726207487, 0.15374785559552331, 0.19955268159749048, 0.10803460774402465, 0.14455699151562107, 0.07704716326007921, 0.14992147624011964, 0.11409105372525032, 0.2523651743127454, 0.1439506176017946, 0.11153173783133108, 0.19560447894036773, 0.08262894116342068, 0.16880402671954325, 0.13029203599979802, 0.16893922591642027, 0.1452755513450792, 0.24418989767230329, 0.08909381926059724, 0.11342451892673008, 0.14681463730671715, 0.13179677057891123, 0.22276663191376195, 0.19749742091423084, 0.14703579156869842, 0.24318823771130657, 0.13829397758649242, 0.20169405056343925, 0.23731444241298785, 0.11999268099785813, 0.08610352528311553, 0.11215134974448912, 0.18130573894708388, 0.14888826877840106, 0.09508433571505932, 0.28708225656901637, 0.11540628113453427, 0.21202796379164343, 0.2566271052966195, 0.14847899396573344, 0.19408915702614093, 0.09360040808396955, 0.1228215525888147, 0.12085806923888384, 0.0863110201974069, 0.2447249181568623, 0.17879016667364106, 0.287075208560113, 0.13084579499498492, 0.1613522588365501, 0.14828466810286045, 0.2092471872005732, 0.11647995336041336, 0.1810731699750308, 0.10638029449769568, 0.17480572805769984, 0.16414399048493755, 0.14957275301698716, 0.1361259487607787, 0.18132112199260345, 0.08641955953451895, 0.1170723078652255, 0.25051484214923075, 0.31892730584067686, 0.21231860222835697, 0.14760429009554848, 0.12806038357197277, 0.26404277511662055, 0.18562455962021507, 0.10271287072570094, 0.13148311886095232, 0.23052348665172057, 0.17099235687525044, 0.09337332430145434, 0.12427809257661143, 0.09998280149433883, 0.12519538327450716, 0.10736796569319502, 0.18843204203632571, 0.09271202188345695, 0.0981686593243672, 0.15859618092015867, 0.15262198213848377, 0.09634336291421806, 0.12050174642354251, 0.2288261575684432, 0.2798653099565737, 0.13291175026566754, 0.15242048569263952, 0.11672653408060152, 0.16156209031901053, 0.12167297228569947, 0.21834903186367405, 0.15076181340602138, 0.15891519525358755, 0.11989894247944317, 0.11345255774475875, 0.09943463494099918, 0.12772266903231222, 0.07695537826587116, 0.13513473823906916, 0.1352244318132439, 0.10602194921023424, 0.1586960481419679, 0.09603383274929178, 0.20651254442430314, 0.17855647921321854, 0.14882215539053564, 0.16849811248961957, 0.1657463246656041, 0.1411275223137871, 0.11201995034371653, 0.1439820272066901, 0.18754946278227916, 0.1753797424176047, 0.12541293692324432, 0.10882402304559947, 0.08075521267469853, 0.14903872844672975, 0.14548990274629287, 0.12144294672555501, 0.11476245318208972, 0.09225714951753618, 0.14078177151180085, 0.12552406563754046, 0.13308624977306013, 0.12037957072137825, 0.1861207854122885, 0.19085194524978438, 0.2146557985895103, 0.10804618333256054, 0.15514530722172032, 0.10891487341253989, 0.11154558104012283, 0.10828173238663905, 0.13412339492670952], [0.038141330568901, 0.016088625904352918, 0.029554358277950558, 0.031142851165045175, 0.020195989073404384, 0.011355387095752503, 0.04144466722444181, 0.004519807191700825, 0.04524325674039222, 0.05897203880933024, 0.030673430789442315, 0.042060693846114224, 0.07268487475812435, 0.09578778829065063, 0.03502497299303932, 0.03041499868906554, 0.025572510954413204, 0.03897935031883178, 0.012048938942532386, 0.05533805094479073, 0.08964642912389771, 0.01939006266184151, 0.029715667666506865, 0.013854887802153827, 0.019467437542193843, 0.008333980372445959, 0.10848482229536581, 0.020336414905144803, 0.02339876519756452, 0.06130172367838602, 0.08313068278854893, 0.04864097925864401, 0.05450477710955086, 0.08923576769208716, 0.036517856191963925, 0.037104736998557084, 0.039944077180998946, 0.03464677070658054, 0.033493471301851735, 0.04219595049958556, 0.06032220365840101, 0.03267774854095713, 0.013412168463541856, 0.04143194250401951, 0.03050371741635665, 0.014196077508160905, 0.01859885279930407, 0.040289670934960733, 0.024164138744855602, 0.026732708980900147, 0.059368106266183246, 0.0306100714876647, 0.03636296087455365, 0.012593306657377512, 0.04735361063672651, 0.01968166253890001, 0.06395319228871696, 0.08176104015400333, 0.016672974790356333, 0.026518087533693162, 0.01114179890963339, 0.012905876276143377, 0.058186817839140856, 0.006889818929090736, 0.04744632642776255, 0.00807944574438396, 0.05076213882515027, 0.014215423143468799, 0.01754458558054701, 0.07468446383192655, 0.018941659908441287, 0.11336277990091233, 0.019388214474724188, 0.02406741248353595, 0.016402022898077004, 0.03706980721964952, 0.06045215898343633, 0.04596035334191496, 0.06850819403846418, 0.026030597059176337, 0.06643921272048066, 0.029215247543047995, 0.06268476136028767, 0.05178448316010256, 0.050969112799653125, 0.03891663836135019, 0.054959576697118824, 0.05573351702262318, 0.015859676697742076, 0.030525070202026158, 0.07344147851390224, 0.11901060224420602, 0.009476183951201459, 0.09253615107867988, 0.0583466122888269, 0.016412016515049244, 0.03806164976389658, 0.07150767341015801, 0.026680825676228252, 0.03391746266354476, 0.07625842211587776, 0.011704280773448128, 0.008646341232252459, 0.083779291129641, 0.03714158582771498, 0.04465534937598052, 0.024760896340012554, 0.011433406447571133, 0.015797749022772957, 0.03655335287593546, 0.025395058178072496, 0.021007532824672038, 0.0743433861662784, 0.04729244234641233, 0.05755166200199916, 0.04575498815205309, 0.01364738043893369, 0.01967110776252324, 0.01275774838793422, 0.04005717474126047, 0.018076911350832354, 0.03931586976133047, 0.057536550917692726, 0.0634966575120005, 0.01331128042957355, 0.004879264743067324, 0.056030778289442106, 0.05587109492250508, 0.0109780763441156, 0.046538313054629875, 0.021232504119736054, 0.012927632215583037, 0.01591621111372426, 0.02876186904857957, 0.05563009132240569, 0.025071487536713965, 0.006132425623945893, 0.05406987665581608, 0.047322963289315664, 0.041923636886020826, 0.04182148289175765, 0.02960183466183803, 0.023253545570637912, 0.005597317039275603, 0.03474347781570208, 0.004474031523005256, 0.056044851324611136, 0.03656043152835581, 0.050891734088861176, 0.0387591996320313, 0.05164613917229637, 0.06221058740911465, 0.045754991982492714, 0.030643024759727622, 0.0403881362158685, 0.0801395767578675, 0.019248958842288104, 0.0685866414419105, 0.029419906016799714, 0.05847173359906001, 0.03364006222616281, 0.042718682933839104, 0.025193806880364017, 0.031602680119836045, 0.03862469757516538, 0.027874160835879947, 0.008807412175942332, 0.032519631823825265, 0.06094692537801401, 0.0697081558586609, 0.015338845119150657, 0.03976626434333382, 0.028107626130804423, 0.01583704837567864, 0.05513857697106658, 0.0473108705914309, 0.048210119918709805, 0.0549608254204354, 0.055924479759508566, 0.04675628422128578, 0.031243972855830388, 0.04329386174738888, 0.0644676931082241, 0.06281206219066536, 0.040804152602269765, 0.01447480136243206, 0.026179647125724344, 0.031089830219805725, 0.03843961073265922, 0.019759790100637945, 0.007939682099893089, 0.054564505154567386, 0.015508990374303635, 0.039924028660020525, 0.026291557249703237, 0.04457134017420392, 0.09133759886026384, 0.03378178083127545, 0.0206933754886831, 0.029122265536458265, 0.039056870755889726, 0.06454115327928336, 0.026173849755357352, 0.16795964460940133, 0.012852570920762037, 0.006814674801012922, 0.013052729585568511, 0.06738254274692267, 0.02772380458942104, 0.03250689944252372, 0.028781917569557988, 0.05563113320198271, 0.030817076105684526, 0.01114380127194548, 0.04679216394921945, 0.03127019604547851, 0.039377455569563374, 0.028926566460981008, 0.026754994478617466, 0.019267592015826417, 0.06022141330064305, 0.026614507359843102, 0.04075866613176562, 0.052705673245532866, 0.05791266561455785, 0.07423951230462521, 0.08655204678014403, 0.026859527175885536, 0.00633647553660276, 0.011558674272119759, 0.049608820268223365, 0.02356481667037212, 0.08239979660438915, 0.04311391535485464, 0.04705357613162168, 0.02864710716230254, 0.06107832860922622, 0.09279261433309124, 0.03254486676005106, 0.03815338113194993, 0.003616699654113261, 0.03189587154455724, 0.05243134865116689, 0.025590774490528052, 0.013221736242544028, 0.049709706386971864, 0.017373196390126983, 0.04760471893654716, 0.026292953444945238, 0.008224147304351772, 0.07786456375352799, 0.044549280672424266, 0.022064293659622633, 0.03300354658295551, 0.05010966174004059, 0.08545762889327542, 0.04344956911799889, 0.05841414676979185, 0.0726040218385958, 0.044013459625984394, 0.055036032271962014, 0.022626046782299396, 0.1396007090806961, 0.05988558716771584, 0.046920219376202554, 0.06336724610939141, 0.042121992371375525, 0.020526435353883335, 0.0712300661290365, 0.05689447347615516, 0.03033417066739452, 0.015185517409155446, 0.04826969474614148, 0.05811932549301175, 0.07629966062884178, 0.042757481456764286, 0.052565452342312184, 0.07123727501640398, 0.044618538851218845, 0.03672108782695667, 0.06325556581178982, 0.024807169965858904, 0.01255531061155301, 0.04358603235995097, 0.02987273292796266, 0.07218056673844976, 0.04472333967926041, 0.033189188839206775, 0.029399309742955432, 0.048113094883099686, 0.054073668791041266, 0.010366039125308877, 0.06863009394897569, 0.013527734742139377, 0.027842628656916564, 0.09687449933300096, 0.05527265767957415, 0.014288891933017201, 0.06137746679145963, 0.0519486787849136, 0.02576235520292915, 0.01686524753759225, 0.020472606185883768, 0.049995277152066274, 0.0640407523080226, 0.07017361555969523, 0.027665997509874647, 0.0588483079486797, 0.02322051568978256, 0.002047112141172552, 0.06148309116401981, 0.07412599339600533, 0.020904009448244207, 0.022150700716602228, 0.023255169677037387, 0.13278116291809466, 0.005494450583242842, 0.030850322406378486, 0.038558005790917144, 0.03428650253842916, 0.022927035066869952, 0.05650957941167778, 0.07837810313269016, 0.029337848424010222, 0.05449795892702476, 0.07961721970669686, 0.07862463788760286, 0.03908990829762432, 0.037754716637033614, 0.014211255625160712, 0.04278184688319603, 0.0590295720124437, 0.025768344095277212, 0.05354391516096169, 0.07032474172451804, 0.0453647046590284, 0.014852661782154634, 0.03430199283625811, 0.012067402619117451, 0.06269335303635848, 0.07211659839677234, 0.007874800198365966, 0.0076864148685408225, 0.04966216297039101, 0.05495404554230552, 0.08038106299335919, 0.02045928966253996, 0.0331849868469421, 0.06945980547536766, 0.04175872113856097, 0.03197886759505397, 0.011120064995221553, 0.12938869576300346, 0.12131824293324064, 0.1522612160131816, 0.1474286108127525, 0.10648092780742915, 0.1457838353610808, 0.22988081549204167, 0.13799443720809876, 0.13918896746491233, 0.15876646694396773, 0.0974297521996402, 0.16828132492880668, 0.0758944690648106, 0.16843262729385208, 0.10727693146515278, 0.15590364233620707, 0.16146465925680054, 0.10393065175101643, 0.12518383832948823, 0.15867992965204103, 0.22434218366059566, 0.11741095703215369, 0.1284789663529204, 0.10111102684130592, 0.15523702326801517, 0.1553439997857617, 0.14087885017356566, 0.2101586939346406, 0.06276201749701174, 0.1341891252706128, 0.20428888229352815, 0.10401754910426755, 0.16689796932041648, 0.20864006252058093, 0.1021768926312366, 0.14141621488717296, 0.1658732501128989, 0.08979496591153646, 0.14286274210579936, 0.12683121848010248, 0.11838569666349119, 0.10320633860124696, 0.1052413362589094, 0.1353953307073924, 0.13626476389265832, 0.08936457005479644, 0.13623162292905394, 0.21647675894200805, 0.16290619158216063, 0.20684364762517715, 0.14197921290272666, 0.1642792816123655, 0.16641898050663934, 0.11185354072480433, 0.08296875478399378, 0.1441937739089612, 0.27100366450125174, 0.1646869476403921, 0.17086638137698176, 0.13871368651668872, 0.10546147928483064, 0.1791464894889824, 0.11868827841094426, 0.15083678277029147, 0.17832859869926207, 0.1689247315328929, 0.12673449987966207, 0.17637060053886908, 0.11146769288086122, 0.13238699535929388, 0.13909696030520624, 0.20340112428511345, 0.11762410567532625, 0.1934489679913367, 0.18500700082269408, 0.21991047227094251, 0.1339592529280532, 0.15766107867802345, 0.20730768240267233, 0.143007900445692, 0.1403077009824976, 0.11292931969247519, 0.11440243016207412, 0.21225881672674612, 0.1965926557538971, 0.30711649766852783, 0.24201379427986763, 0.22845169379105493, 0.09032769579320185, 0.07733349628265827, 0.212225399971489, 0.23682166401657367, 0.19243589332026823, 0.1856564595213821, 0.16709526760443566, 0.13768046373321166, 0.16110780017991222, 0.12963378261173927, 0.14677584261423157, 0.16218628343795577, 0.12679616229668741, 0.1773527559013136, 0.14525471375353877, 0.15091616480100542, 0.17493208659993065, 0.1782971890943666, 0.10216061326284563, 0.16949249461533564, 0.09535433574309272, 0.1876831451250661, 0.20923638536084085, 0.17373139699620588, 0.17012180520161507, 0.284728589317491, 0.1789549215426368, 0.10759301168183166, 0.15441698743210686, 0.053647589839754574, 0.1231483197320373, 0.18031978378853492, 0.10341106793813168, 0.08522715900213489, 0.1847124859810837, 0.146346312436846, 0.13615991709934128, 0.08400128042745976, 0.13114953353520364, 0.13027102986891426, 0.1565093114491432, 0.12269636616110803, 0.18961416166876593, 0.13006407887704913, 0.16209685033367527, 0.11102410499006511, 0.19387258396994686, 0.23508256781966458, 0.09634026791900398, 0.1775481542872806, 0.11375095665214524, 0.2923841059448258, 0.15514330007135868, 0.1327164131667345, 0.131065554976944, 0.08804253978474487, 0.13671828794383234, 0.14023855388645204, 0.2039240252587103, 0.10057708654072016, 0.17470898647462169, 0.12954934440072507, 0.22048580430207715, 0.15949887764309684, 0.10928352258258289, 0.20108070524950183, 0.1535397095064963, 0.15462729388908034, 0.11882825033558954, 0.18492173523672167, 0.21606605920580127, 0.21716665176133956, 0.09403898575974089, 0.15438168610055603, 0.13850670488130662, 0.09199400597642507, 0.21771550779381107, 0.1507987082004547, 0.16762906234831582, 0.13293145404708, 0.10824609397640152, 0.17840580504027106, 0.1332590945305363, 0.16918688682058167, 0.20708475081670671, 0.1769542676066199, 0.17860757727776805, 0.14214842640344175], [0.01763037785196737, 0.07558836331290585, 0.019923884218799013, 0.06266732902957067, 0.005684811462302723, 0.03269428837924235, 0.11472181221770664, 0.02049387278666179, 0.04120429564687995, 0.04454611289885737, 0.03448197370274894, 0.028550424951038537, 0.020296894344350985, 0.0554109059063898, 0.014364530666611128, 0.0753964429661151, 0.010141548550417347, 0.044338690762918805, 0.039215811017540195, 0.017640580227898977, 0.04590522948532336, 0.023248449170721636, 0.02571896015245828, 0.039096914171691866, 0.09564664425148119, 0.0720373772445225, 0.04717739892282313, 0.03022838924680987, 0.05198334043304767, 0.00894674920522037, 0.0609866202238106, 0.0435667269442591, 0.006673769685514873, 0.0007360843301285059, 0.05898046577649732, 0.022075936280851884, 0.0024855890285013426, 0.04683771553719717, 0.08971934537253073, 0.012150602640524026, 0.0016035145545761373, 0.024455648606583, 0.03592776547696802, 0.01678074420910449, 0.01966666445256241, 0.026611427686387495, 0.07549902980005549, 0.0730614222946667, 0.04544594445295873, 0.07156477760403387, 0.008158432282206994, 0.03213321707481819, 0.08173044260230758, 0.036907055670575756, 0.06907054854016151, 0.079775171714925, 0.0029158433983778403, 0.03534918523303444, 0.020590495626111666, 0.06491773145934267, 0.010737620496882067, 0.044999790167616266, 0.039306619249644785, 0.05410630413661561, 0.02299313313297687, 0.03377668251613936, 0.054700098886725404, 0.07199067652465836, 0.048172083653269276, 0.01819361143955781, 0.07727141251727458, 0.03398289806359718, 0.043926236685365445, 0.041757296215021805, 0.02988661252593081, 0.08788874763394557, 0.03879201883870748, 0.03447132125016182, 0.027790517441087195, 0.0186048359459927, 0.04565269243152392, 0.0067968699600427385, 0.04624647569031485, 0.01838257468696083, 0.04059480758564126, 0.0733294687984932, 0.08138920405819532, 0.021463688387865984, 0.02026172324774727, 0.031733976098738854, 0.01097116431581878, 0.047095354736572316, 0.1726929494930852, 0.029137813290881536, 0.03338123559050503, 0.06530364059031972, 0.042456830250880415, 0.013942059031837891, 0.06366987765255956, 0.03180902973268061, 0.02622417981676277, 0.06305515721079803, 0.04781595619034864, 0.05755826951034608, 0.03085671924054623, 0.013085628273866832, 0.0572921956829246, 0.009197929325783926, 0.011978415761052841, 0.03321175778945608, 0.03989370306953788, 0.08824435032663808, 0.06663533122909647, 0.06052662656011601, 0.05497307899678427, 0.05651871501017482, 0.019994534762395967, 0.03146993623475634, 0.029755900689070264, 0.005331095261123753, 0.040280899228227716, 0.043803934578693686, 0.10067193588662533, 0.129829962407389, 0.012734650837017164, 0.015073449279542173, 0.05547100933448923, 0.018553992605678016, 0.02595842391582987, 0.041676140690763155, 0.015522290618279049, 0.02478134897237103, 0.06365637152245449, 0.042329054445989674, 0.02346156142471779, 0.016928120373537945, 0.013795356067167896, 0.04468738334253431, 0.025843355594383135, 0.0560290047958974, 0.009278924929188385, 0.005193082127539862, 0.04107845038355839, 0.04783782800058684, 0.0846305910137392, 0.04138639091604179, 0.013316789559359032, 0.03647023616659065, 0.07806321035229391, 0.010427441072439956, 0.009358686173424847, 0.016754078603680098, 0.08151308813643071, 0.06086810259148479, 0.09726975473665422, 0.031647509669945124, 0.0687958600540315, 0.04960521199410001, 0.03415342157466277, 0.021018112498906352, 0.03434776275929424, 0.05493205498843905, 0.056373874596770734, 0.028395828407918735, 0.03976870433337266, 0.025340522293962782, 0.04635226477177874, 0.022022865539897355, 0.06438477941217922, 0.04356229129517752, 0.039893312364696495, 0.029746571653372342, 0.03290843293671647, 0.05903563559836438, 0.016215164477245945, 0.01891047055382402, 0.07100857478836853, 0.03714618618570028, 0.06756146258163838, 0.04212130672268329, 0.0632795098898632, 0.06666470304011338, 0.01287888604096107, 0.006443077150071341, 0.08257693911512053, 0.06594398284270879, 0.0300131262009663, 0.07727600138394103, 0.07182771430140542, 0.02972264289705744, 0.0566120091975937, 0.005436303552180048, 0.01832766916542765, 0.045184823383967725, 0.03513070461790889, 0.05148042669339527, 0.06792588294633935, 0.0830686449884407, 0.033385165621556585, 0.0892433443016583, 0.02741796313785017, 0.05958773601319521, 0.026149553276838797, 0.00833867840664161, 0.05238367116919929, 0.04913203012678893, 0.06324170345079995, 0.03290363339587085, 0.011977162249686738, 0.03341179483780458, 0.024144281745858254, 0.02077005897468377, 0.026195947561533223, 0.051880110085250876, 0.07230622814066949, 0.022990635686343717, 0.08198813159739779, 0.03700707227953019, 0.018400976118902047, 0.04253996994286295, 0.04135814142383395, 0.03189703791342195, 0.056251779333838535, 0.0763033684943953, 0.06023714108572853, 0.025266152393493443, 0.03558940742345106, 0.09817670324757215, 0.03524515432335677, 0.05996231087333253, 0.06249510097287356, 0.08665583637212554, 0.033329451877263286, 0.02889669094715388, 0.04152133347346418, 0.06176295840451795, 0.010427356802768285, 0.1275210346906416, 0.03618998971256999, 0.05606339831325797, 0.05306491868630533, 0.05371662202261148, 0.04916942287837306, 0.07850775585299538, 0.030626563445454648, 0.09332801786161239, 0.05505452563445415, 0.006876553159071914, 0.00723029904615795, 0.021721597633234436, 0.02593459858138475, 0.033355200092398354, 0.04458940069701883, 0.04263995590830042, 0.026197508465678945, 0.023780060564017585, 0.026910853151592518, 0.08980615845611019, 0.021411061977907535, 0.06816502495278275, 0.014046039188190574, 0.05405645479538268, 0.03689314351387082, 0.021267158106990883, 0.024174367933864557, 0.052832778723489855, 0.01117117550869983, 0.030402038396606525, 0.04060824093739352, 0.04697748827898214, 0.03153427804429685, 0.016544329475671533, 0.03108057970812004, 0.008359028574740215, 0.05950363105042808, 0.02181214922588439, 0.05514755935197877, 0.057092549339417493, 0.02256266258266424, 0.02407230203971267, 0.036306588294645475, 0.035767197278478456, 0.04483062646261627, 0.020346624941955653, 0.010609540172041425, 0.011831787489955465, 0.037056929281642365, 0.07971275853173387, 0.04624120883583542, 0.05670714582647047, 0.07805250044311247, 0.04805889799289646, 0.013712865634701185, 0.02439061731791064, 0.09993935664815289, 0.04331619321038166, 0.03519424011990909, 0.05028959664125597, 0.09747766333842471, 0.018226110804525596, 0.04218299212234636, 0.05523878893244171, 0.00854162275866275, 0.025309124180386146, 0.027233188476173148, 0.03662073030887592, 0.03731447272002697, 0.024094012971486778, 0.09319062765327193, 0.07105109266816609, 0.038397809145070856, 0.034270602383560715, 0.050164103778379585, 0.007251510105561466, 0.07990452566093977, 0.018257403581012643, 0.048835140412613276, 0.10378450515770143, 0.03140615175418075, 0.02519147031219496, 0.017997808942210772, 0.015204635133305866, 0.01294094490848722, 0.030350664540404276, 0.0633857126588062, 0.030937936051838824, 0.014420335383845434, 0.0867863011456305, 0.08553236843116822, 0.01297421036137929, 0.07713465816191128, 0.02808683641975926, 0.016114163445308805, 0.0066306585663809415, 0.09290922057604598, 0.0498011504720536, 0.07768247231480577, 0.02681146473473599, 0.03644516593926857, 0.016690409036293145, 0.02635089075943876, 0.04003813362590248, 0.049341417278253266, 0.04863999866610093, 0.0759052632436637, 0.001972291326139032, 0.05294382699855393, 0.040048177038589795, 0.05118184392490695, 0.11191328026113972, 0.024591225101762725, 0.0413444054673516, 0.19475640428643073, 0.15771311136984056, 0.12889852206553185, 0.16253076253398774, 0.13678038703097453, 0.10765016950186222, 0.1310072250423893, 0.13256273592912382, 0.15287517419745847, 0.14485832453975755, 0.12857878760945413, 0.1335846512548385, 0.11681549221036897, 0.23459486092530915, 0.1271464636609439, 0.09077424844426495, 0.08512594346557895, 0.15421876984257854, 0.15809045563782417, 0.06885598263432903, 0.1683513760086029, 0.11604225668575495, 0.11099678629468526, 0.1593984128727067, 0.20546439824806106, 0.1355239415481206, 0.13987709828201803, 0.07936500824026524, 0.14839038823641118, 0.15267841217498626, 0.12879935964461298, 0.14610596001148224, 0.07225941250761671, 0.0869619268022718, 0.08707322405591127, 0.06527649809516246, 0.11011382399667656, 0.11803346475766552, 0.2775489052216853, 0.11594872501107956, 0.1481585547087654, 0.07114693026749358, 0.13073573880378278, 0.21319794859136307, 0.09250622768435748, 0.15570084354089153, 0.1295716528810801, 0.3032122071712248, 0.16055218725194856, 0.14795197143910394, 0.09213416942305143, 0.2018359453687745, 0.18233575948303749, 0.1338930016443614, 0.12983512583999865, 0.34007157769895374, 0.11176615307528166, 0.2511818289396263, 0.21359628366847194, 0.1540057514343531, 0.07853928037107953, 0.27198349095640645, 0.14600437675272265, 0.1472469713659056, 0.19499789052192243, 0.17411140725016597, 0.18529227664393766, 0.14735678240897196, 0.17314687190997988, 0.17156352138807698, 0.23089784317679946, 0.1859198711932667, 0.11672991252834759, 0.09662215763162221, 0.10409133103225501, 0.2818199066865829, 0.15532305494191187, 0.26292735109886817, 0.07444627177450927, 0.19550372305656635, 0.19718683354796904, 0.16139840797310875, 0.16683795399242835, 0.25825148748774684, 0.10731030225513444, 0.19412534701968395, 0.20785204915990754, 0.12748250812892953, 0.0916158419943625, 0.2320633540230413, 0.11437594650253174, 0.132589717545817, 0.22627572829444564, 0.12423215794467157, 0.14838583767414093, 0.16305852050502456, 0.1691860900891404, 0.12970173461062293, 0.23889183277083983, 0.18345181169288774, 0.11349883711626453, 0.15848581829378683, 0.13196091257756756, 0.21038006270124068, 0.10771587686312777, 0.1032825337061959, 0.12714064139271938, 0.12690108569879688, 0.08203382874208112, 0.11899275239557029, 0.1405387377787021, 0.19293432544556358, 0.18609498357099874, 0.14371239490086032, 0.20741378558018517, 0.10458633874452884, 0.08337503419287744, 0.09592704775352633, 0.12934407880229334, 0.16724932788600846, 0.20307071056337128, 0.22630609601976412, 0.2997674468544222, 0.14184979000879874, 0.14580813567003897, 0.13634215409476913, 0.20045609844307746, 0.1454971039727811, 0.1308655907069483, 0.15102439770294776, 0.14384011707959637, 0.09716909844428302, 0.2815986604940507, 0.07359407556753966, 0.09024064522236587, 0.13036677553769083, 0.09566997162877552, 0.09115841855565388, 0.15357991380076255, 0.14580007642507553, 0.1987936263603549, 0.1715110903305392, 0.1373466179375687, 0.09696616175314111, 0.22544570267200473, 0.13881822687483605, 0.1561761704543906, 0.15859238112405424, 0.16889460895571018, 0.12131442015449848, 0.1256049875049822, 0.1567646332325474, 0.2250037618702458, 0.1114895417084617, 0.26035145706226753, 0.09102197063546028, 0.1565417935771327, 0.27014828136851715, 0.12856804705675573, 0.1323255397860081, 0.16045817294188086, 0.1871539622304901, 0.22182704039639045, 0.07425035244875378, 0.18509318571417563, 0.16317871970034417, 0.15362685966876247, 0.1388417917393869, 0.2616152263456776, 0.08443230447629768, 0.12522266366549079, 0.26856385832352025, 0.12303828652347289, 0.17544361882873122, 0.13221799636319762, 0.07528978054441753], [0.03690737359706433, 0.0603765192922325, 0.03562154481187463, 0.07314482628698311, 0.021686244590748704, 0.004908844355433699, 0.06916884528172594, 0.05978354425620168, 0.018243826587774584, 0.015359259447112921, 0.023692548425207217, 0.014398832253420786, 0.07717719902434657, 0.012299391279567876, 0.06746064541080306, 0.037120763557933034, 0.03396897058513376, 0.06916686877488129, 0.01773154359280823, 0.05258679555188264, 0.0739858146276205, 0.042708497794885794, 0.042523234752157045, 0.020019786935600064, 0.05066978692587826, 0.04142445782499929, 0.027851565072553295, 0.006326588214330015, 0.05086929154311938, 0.01719676251072557, 0.03576611709450522, 0.043343224622789896, 0.003965246677023149, 0.022281370418626937, 0.03839859055475362, 0.026706504943450133, 0.0036223840265114226, 0.05988659840377589, 0.03306888622201739, 0.06049083876273325, 0.053643284425620115, 0.0037223699919488886, 0.03218409680430928, 0.01838841419216366, 0.03955330339170272, 0.03286551286075865, 0.017735027377643896, 0.019707849339371728, 0.02692362000685065, 0.012728931033052506, 0.02762705343024385, 0.04672615398322383, 0.03572089109389532, 0.024386647067243056, 0.017299918164949746, 0.05172483172387846, 0.022590260900136445, 0.02493711954523479, 0.020656155106881936, 0.03857254997015961, 0.07286505097703588, 0.03017202049734131, 0.025288275097526854, 0.011728710359743526, 0.02667750851551612, 0.03528391454188574, 0.026941485177244873, 0.044327360322518695, 0.10701384921107562, 0.049600872106008956, 0.09693174908358244, 0.044263441776556355, 0.0336582453230456, 0.039521039598771644, 0.02094381346157001, 0.005661812545205917, 0.012320708633670885, 0.021060105608475786, 0.05734261192922151, 0.022617064401387207, 0.018633035642485467, 0.02568383310591021, 0.05027913954108954, 0.03330643093513866, 0.04426990372819766, 0.02165938363290362, 0.06930046684799657, 0.035942390095442533, 0.07128735418401419, 0.05684082050837817, 0.12071404470911912, 0.027251036409589074, 0.06349722058662484, 0.08639638537480947, 0.01857090399660651, 0.03020689473487437, 0.06067183469572376, 0.04913086567314402, 0.02971366051614525, 0.06600857171560488, 0.0709044098133041, 0.03090364404112822, 0.08990568859923272, 0.04046613545787912, 0.04501356442849483, 0.04670057813787172, 0.015000844254128396, 0.06433702915185882, 0.04785203510114262, 0.01664723615132032, 0.05164453804853463, 0.05790869344867045, 0.03255114102015092, 0.027941542099260037, 0.00790258477096476, 0.08552376526377856, 0.019862001551495447, 0.012227553299688285, 0.04939913434246856, 0.007691036772748997, 0.010938396820077493, 0.012750493535291285, 0.019928609066072012, 0.04221173957170498, 0.14892338624885007, 0.03851906171128635, 0.028323509707866658, 0.02137047847011878, 0.03300454632769669, 0.10451104762333055, 0.008250106193666017, 0.17547234712589174, 0.09778452751737449, 0.011604869373953872, 0.027533895223431533, 0.07314346265047789, 0.022121552986303167, 0.0248758229351933, 0.04669262997565731, 0.04321123533431561, 0.05113938733214333, 0.05020785505973524, 0.008835089017426776, 0.014205261944763124, 0.07356687178534847, 0.03392236945669978, 0.018345317915983258, 0.019107387709100882, 0.07286934873029109, 0.006968289315174785, 0.02070580526525455, 0.013702162428789083, 0.051290812271256606, 0.03174002627812086, 0.04917380490129994, 0.11131694209912132, 0.034640845016486226, 0.054289230611175306, 0.09473811759943924, 0.06732394468159446, 0.07742890487274817, 0.012916843782389357, 0.04683617953090899, 0.057660293269662134, 0.03480268109049048, 0.0827636577249054, 0.009111791357187735, 0.016197768535705346, 0.05159228319121946, 0.0375983466003691, 0.03418964221172276, 0.0234136522011531, 0.012250159596723896, 0.035978281314695076, 0.050526915358439575, 0.038357459294099006, 0.03624537020861622, 0.0359184728304465, 0.04527601082959483, 0.016138904254823443, 0.050707654651975444, 0.05164224361520141, 0.06183079549021298, 0.08178690328232704, 0.035657037665406545, 0.01726725792151786, 0.08078014883663386, 0.026542265268583453, 0.0828433538516683, 0.03285867169559483, 0.043164040487740314, 0.01097298281702904, 0.04966595510561621, 0.03010151359523016, 0.012282255807921532, 0.029042839455688675, 0.009689301950857043, 0.02948359473638477, 0.04657843690966407, 0.01706653713969694, 0.031265000054132075, 0.03527511602207538, 0.07623648135772637, 0.10781208984553815, 0.02648000721819699, 0.054445083538490924, 0.02155595027180689, 0.04408031994957597, 0.02705802821794585, 0.011598523293111113, 0.03640695347360546, 0.031990797499254826, 0.03074915475031782, 0.00990921036235147, 0.04187281844356368, 0.04765440739931599, 0.04059994803561319, 0.053766153437355836, 0.011183468347054817, 0.032718699770949544, 0.02156523334222936, 0.037448637698206215, 0.022387594254987857, 0.08321522059099329, 0.010995702112033483, 0.05185304419888605, 0.004683949669162113, 0.021217567320432396, 0.05896115269992621, 0.028412182469882315, 0.046378032139111916, 0.08916398525358209, 0.04417820300366129, 0.08118280464963568, 0.059614817221318527, 0.026624110271973957, 0.02908368726381131, 0.02200430322949204, 0.0436084634143739, 0.012343894284699234, 0.0847450981757814, 0.04652158169436359, 0.017881576167119127, 0.02805343498626063, 0.06301629357039928, 0.1220026275803966, 0.07468211960287825, 0.014801819399449856, 0.03260469056605812, 0.0821080090357892, 0.007837040682188086, 0.01616656768976921, 0.04339276752885311, 0.015815268495991346, 0.013256533871284656, 0.03769941658021943, 0.0525325412050851, 0.02458228102524675, 0.07834911436563538, 0.10226468630735913, 0.04202959067638844, 0.03188802105855317, 0.07594831738500826, 0.011448595098279899, 0.04850804002114362, 0.0663995753312784, 0.01471207985999964, 0.04224139483525388, 0.025937588239509254, 0.04530308054639928, 0.09541447364514875, 0.031308623015760415, 0.09529166975088658, 0.08793886510595199, 0.013886612460708186, 0.022767391919548956, 0.04113536688589281, 0.06059675424870464, 0.030476800917137056, 0.02154575747197434, 0.09304450404259468, 0.04204495073927026, 0.023890988180233587, 0.021435649569837317, 0.022642021630740455, 0.05804184719078964, 0.04214675999396751, 0.020913612360375065, 0.037204895333777514, 0.03226801790597458, 0.057710893377060854, 0.035434067775044716, 0.06480379120236443, 0.009921741645572888, 0.03745748218329203, 0.05083252315319354, 0.02807524742468471, 0.01790029361032911, 0.07275267353942318, 0.04253669874742628, 0.08655280520718905, 0.03718007791547045, 0.0587871894540806, 0.010012534555918988, 0.0517803730983888, 0.07777803412248051, 0.04116252470280855, 0.1239371068415142, 0.09815575074284308, 0.06285542276717963, 0.0564223871145758, 0.027758787994483308, 0.10474091996589016, 0.006815310175185122, 0.0737532073511712, 0.044529584551891016, 0.027085492470031305, 0.020188816575213306, 0.05226389332223804, 0.026379402636760668, 0.07245779097560914, 0.020623535083066073, 0.07615035775327876, 0.018200697752857403, 0.02696833081333147, 0.03112606426340438, 0.058695638116689465, 0.032025989663276466, 0.06403628601542403, 0.04728932436856051, 0.051438851101744565, 0.013194923165194212, 0.0376827848113833, 0.02974416422207029, 0.056393187673341845, 0.08242032009988062, 0.023794351934245037, 0.033890124815966816, 0.036156952170835394, 0.03070674220760984, 0.03284990381930144, 0.07135270148395531, 0.039143254830231594, 0.05696215351382571, 0.08093116774914727, 0.07403846018977704, 0.03516379195535856, 0.018859270982624545, 0.025863005749640927, 0.033546009611698895, 0.04910056689573873, 0.05183229853789653, 0.11091528220042107, 0.11349622475644273, 0.08988403895449254, 0.15960649767469975, 0.13380254198226238, 0.17194281151938826, 0.21843115648915692, 0.1811511270822056, 0.10844972014667527, 0.09357738714184492, 0.13378536629100002, 0.08349928599331649, 0.2363019499687418, 0.1379033646756603, 0.16734006333976023, 0.10468032241107957, 0.14213195551306973, 0.21108670220259698, 0.14624923377508117, 0.19872582757905607, 0.18715262923750187, 0.21915615145717898, 0.16444172289582992, 0.08130812131228947, 0.1401041514210163, 0.08994541025810665, 0.10986740415495251, 0.10952965897177497, 0.12399524525408784, 0.09752487733719811, 0.10350705875504403, 0.12089396811901562, 0.06998575547890318, 0.11164376286849861, 0.22880472242832187, 0.15214469403989855, 0.1709775867000703, 0.1591854863950322, 0.08675912800695627, 0.13536398238953085, 0.17397579436580982, 0.15462170144723308, 0.1392676753382529, 0.10074332762028902, 0.12120698398399739, 0.12884705627877868, 0.11482181733534222, 0.19474174136356, 0.09553875608910477, 0.13531867594968888, 0.09819823031824443, 0.12549362896430877, 0.16495150844416312, 0.12122356212667881, 0.1262470534552009, 0.1851734104416063, 0.10531389244621801, 0.1774268978906255, 0.18321270032996134, 0.09194974907703939, 0.11069039709024853, 0.0932604029414154, 0.14841162419367224, 0.07831583550620465, 0.1954417925087675, 0.1780542166483018, 0.14786549543421115, 0.10893741938015146, 0.17980976841382443, 0.24147120484661674, 0.19126483599745459, 0.16961915959273616, 0.1293906569480896, 0.14242144481789681, 0.10749279972045653, 0.12195547486865714, 0.13630924295754204, 0.11104537159084313, 0.12662176238072495, 0.12391154248748096, 0.14235209853899095, 0.17160389422168656, 0.16488974643570764, 0.13522809371352196, 0.10640423474532944, 0.12981785821818537, 0.21505857697658, 0.10890511345238456, 0.13666689876587162, 0.14950185924047424, 0.23904086751562936, 0.16674487430962825, 0.32768194413473534, 0.19025119442132213, 0.2784131443308246, 0.13416315488997968, 0.20242765635973026, 0.21828586025343788, 0.12366656289105454, 0.10764895142206263, 0.14506533681865663, 0.10969649759992477, 0.12437153232073593, 0.19694490298148126, 0.22598155053152194, 0.16261271862012727, 0.17477539097589834, 0.10038743381418529, 0.12337836061394024, 0.12585972706156393, 0.16838770389797228, 0.1417775172740221, 0.16679200403872999, 0.10950923506771365, 0.1128179458300433, 0.13868911041607782, 0.1564328711960585, 0.0864604609687963, 0.12064776278191036, 0.18225718950552328, 0.11876770640693365, 0.08706629862107577, 0.15264340195684664, 0.11094398751494386, 0.34162483628719087, 0.14657624606643954, 0.13421655121830203, 0.1264607996469544, 0.13789679164126997, 0.22497587626980198, 0.13452105584644503, 0.4032559969252156, 0.1845575523592772, 0.09231656729694336, 0.07069226474531236, 0.26584731054402166, 0.15613095594509957, 0.1271724876677317, 0.13642645440995693, 0.17315828662005164, 0.11052623210895447, 0.10958565999903988, 0.11419377079413784, 0.1204741289538722, 0.22111840906643102, 0.12683738548789295, 0.1769309325684463, 0.11761184826853777, 0.16415220294748584, 0.11039786641636204, 0.1073963645725481, 0.09748217559629872, 0.14153555606401738, 0.1236858836285049, 0.1481855056819416, 0.18594312962264786, 0.10744705661049775, 0.14720569454854535, 0.20848535872515173, 0.1968734269781459, 0.20498931648269778, 0.14792855979213793, 0.10821448518864571, 0.1267747884436, 0.14737466290112466, 0.13286739377485168, 0.1396214087764102, 0.18409158704021286, 0.12165604174257287, 0.12120093188939557, 0.20594787633707448, 0.1219017414616481, 0.08697465918357335, 0.10707532776699913, 0.12728513323611793, 0.15929905126892752], [0.08468309101919014, 0.024179885682139187, 0.04615682808141555, 0.028965269222915657, 0.05434463025941964, 0.05700197859456944, 0.10220409641342779, 0.09176028021160634, 0.07974194648164896, 0.030699521828923496, 0.012716539560877269, 0.007576658888044017, 0.05478208944682152, 0.04271354248386718, 0.02134622987209549, 0.020849929386449438, 0.0504070264287293, 0.025989730098855593, 0.03902217846423869, 0.0623342301696539, 0.03602809618197141, 0.041216564544987296, 0.05520157621151978, 0.029887244548468344, 0.043576946557169004, 0.017011807818386345, 0.05148420733730159, 0.029482995272584023, 0.038014244243142106, 0.04397009138859088, 0.07432238003539463, 0.06075918787128984, 0.03622672362853924, 0.0274047251385186, 0.024736161276157347, 0.008540063769736839, 0.04532185353098377, 0.04776287395807524, 0.05935318287341826, 0.06056002416317502, 0.01262924575712532, 0.01314725908976529, 0.06992724934412588, 0.04056906703138544, 0.12398858795002585, 0.024242649350555676, 0.16091888289778464, 0.047897081071090315, 0.045086212546354344, 0.031188881557975567, 0.02219476992444646, 0.022503612525460702, 0.10910904605782802, 0.021904349822791356, 0.0921995780100265, 0.05042455835087646, 0.05980312929398591, 0.059861298350076524, 0.0202601355305242, 0.0847540997088917, 0.04049605119132227, 0.06915177684277296, 0.023863037462316217, 0.08542877036116778, 0.02493613512225209, 0.07736055450814386, 0.04013299829356613, 0.021898504571929094, 0.010970844474110392, 0.051371500481881445, 0.0652792789943276, 0.023159814713102196, 0.032798181393093644, 0.06826140647453648, 0.06295424044853257, 0.003907013221666397, 0.0351176236666018, 0.060465649791782906, 0.00687465709145932, 0.04121774432039069, 0.04005499522111589, 0.01021414399973207, 0.06809262964393824, 0.038677032871712605, 0.06770632214724057, 0.026898900264753934, 0.031086114693372965, 0.04973621302915197, 0.05893674513865864, 0.0697516083657261, 0.035944550463389006, 0.09914080191764141, 0.024604394153181105, 0.07273057190280768, 0.02633007806575587, 0.03536195974917181, 0.07542868760684807, 0.017733033633820953, 0.008020510121564111, 0.06934025745478369, 0.06185480851619955, 0.03015581773774278, 0.020076395087544958, 0.041622828632112474, 0.03943923673021697, 0.04434591497204477, 0.020336713679435275, 0.09996637656924226, 0.06021139670103308, 0.11028614015348497, 0.037637593284729993, 0.03382058701507988, 0.07984021257969641, 0.0738910342296285, 0.01226205119652854, 0.022226453405774893, 0.0401159183632943, 0.036464184071988835, 0.01998047513376561, 0.013651859180461015, 0.028295036134940964, 0.015212341977824128, 0.029506198160590667, 0.06541935817128228, 0.0415533023225444, 0.03341801547174973, 0.043850359506905086, 0.04122868405594941, 0.00946718720614069, 0.038806264243659475, 0.023282731605333187, 0.028062695074045373, 0.0661132193260616, 0.025619910729508248, 0.025347468796216195, 0.015262898992777113, 0.03493977252454047, 0.012911147918672332, 0.04867549535007246, 0.04652934216503655, 0.03291517451045013, 0.017225343335960663, 0.02310833551981036, 0.0620877145669393, 0.21226460835145367, 0.04951769794006983, 0.037194304168224335, 0.0520385408984317, 0.01712506242667235, 0.006391954666469247, 0.008827002959385996, 0.024187944927102616, 0.04922896706228776, 0.0936784111564198, 0.03646982630955116, 0.026402588287789016, 0.0357169495715249, 0.04250571049088913, 0.04429069535446264, 0.06712235630519929, 0.029598988645199328, 0.0164482869478243, 0.02677559841334099, 0.027449920495611527, 0.03317165308662, 0.013132486041755447, 0.015229963915302389, 0.025270584212135405, 0.026451447460379814, 0.030012628243815516, 0.03068650024943054, 0.1168972874180444, 0.05940372552422266, 0.0883194346040968, 0.03256791068481342, 0.033727051509964856, 0.10340387437252269, 0.048873437147948055, 0.05301791153127148, 0.05751380193678122, 0.08347229671574409, 0.06481762675027694, 0.08317418892176882, 0.03820595774619329, 0.054131462464048985, 0.08563232758352834, 0.025923053636365843, 0.020322039265245683, 0.020465753529401078, 0.024069664782033335, 0.05188433122971366, 0.048158171496564345, 0.051726390712804375, 0.029423952876259724, 0.03774000008800819, 0.0513011199842778, 0.02506219489019244, 0.04743390048163072, 0.07815911689953459, 0.02423440432927061, 0.041651671842461636, 0.028131292502005256, 0.04686982228210376, 0.031744394894509066, 0.011092297180796103, 0.017063980321249655, 0.008286079767370417, 0.06198624239092874, 0.05278673300880098, 0.013385894520568752, 0.014666278335836627, 0.024232192250389247, 0.00814809584088864, 0.029881985354868155, 0.11766912866263621, 0.013921449351454935, 0.03614197898235533, 0.014276640271888146, 0.10341934934859315, 0.0651188295394663, 0.0561684787633919, 0.006189545139580244, 0.052669437286714395, 0.03995235093058117, 0.0901221544031174, 0.07268651418628232, 0.05349372491060246, 0.0478259191638039, 0.0529459145881476, 0.07201744363673272, 0.10937159205035818, 0.049619078185529485, 0.013323872042219005, 0.021943516067920193, 0.024675391351563797, 0.018629362250888543, 0.06159245404565047, 0.06894309449219896, 0.037997267734740055, 0.015534852545017437, 0.05412478217734926, 0.0710014654924312, 0.016631142559250998, 0.025920226771925247, 0.004647214316778006, 0.021787146031255686, 0.022818028416124084, 0.0168901875299672, 0.03394826705898008, 0.03357984388487474, 0.032586040155541514, 0.0248753575367793, 0.11940184334713606, 0.09482784181713097, 0.018411954158856984, 0.041500783164895354, 0.02740182932616482, 0.03677303624910213, 0.016959397828266505, 0.03459171962834174, 0.04400659930862246, 0.04017164742934608, 0.09199824244264634, 0.042463119832738754, 0.01742063446961824, 0.016517623650631117, 0.038688397786069306, 0.09664049011565025, 0.07686291145341051, 0.06820783394599153, 0.10014755636333458, 0.018885386919963266, 0.11563149566251425, 0.03738035628151509, 0.022006141840510314, 0.024982358952383363, 0.04183605388407746, 0.04967788309459725, 0.014600674396440869, 0.04241341987865106, 0.03421879185724162, 0.023124226098579746, 0.013640073875355865, 0.07588497723542875, 0.017039919414767818, 0.038790256836481636, 0.009371110204336865, 0.06434757052169693, 0.062423916082949414, 0.05669593796013825, 0.01147556139321457, 0.05764998172620132, 0.04358622771237166, 0.014381748492709331, 0.05484902254876591, 0.05735162495365066, 0.03376155227963482, 0.043818019105181585, 0.05564345189580514, 0.0720296091129703, 0.05122855230565033, 0.04678349566435622, 0.05956544285459865, 0.03159148949048212, 0.007202208517194396, 0.029474164194036877, 0.08491311657933459, 0.03905518536245631, 0.018085604533553123, 0.027015969990902854, 0.07237444060944742, 0.02537923080155686, 0.023971820032344233, 0.017577241993539276, 0.04388495986800521, 0.037358859854359786, 0.05051168170006526, 0.07879772013233555, 0.01754840835928917, 0.055721171515723394, 0.036294495596760706, 0.01907119771555787, 0.14004254263014565, 0.03756163183659796, 0.043311022116892764, 0.03260279449844553, 0.0510569294584134, 0.09463053587223254, 0.028227380995127945, 0.09854182841316347, 0.03622850478296319, 0.03748447146086443, 0.08261277670821837, 0.12541881281762354, 0.03464927198365331, 0.034732189510137804, 0.03240876740986302, 0.02155280548087772, 0.03304611042802853, 0.012767330232647159, 0.05279872228481597, 0.04887123847560537, 0.011345833021726821, 0.015134985292060001, 0.014206686868302286, 0.05753398835358601, 0.006737789738127181, 0.06843271139528483, 0.0302184435103329, 0.005710390180484542, 0.07419294948058744, 0.011388126820806536, 0.16482659014722995, 0.10225035280229584, 0.13205641309820837, 0.12231971903313553, 0.07492502310102986, 0.21609645757463672, 0.25494897437672465, 0.10526475556675466, 0.16024728425808493, 0.10497741130811554, 0.11279346165998329, 0.08981140615839152, 0.10711527159137112, 0.1459006331260166, 0.09834461439881595, 0.14224645501423266, 0.1686876119985696, 0.1052220231823383, 0.11511979489437035, 0.16121804023221617, 0.14517890169255196, 0.1637940721646432, 0.19017535171681837, 0.14178884005354297, 0.12657798045585233, 0.1541752560484794, 0.14108379401506918, 0.11866408535429548, 0.18306594852718616, 0.11495370703238635, 0.1851860815358739, 0.1473205464501535, 0.12121628429139815, 0.07939275594488268, 0.07758450499104877, 0.11527832146854171, 0.09055023667432609, 0.12741952804067444, 0.17621431860231584, 0.0953675737424243, 0.09618989252034696, 0.11833307408397237, 0.11642101055551922, 0.19510051566025904, 0.14142882469440662, 0.14907504101434063, 0.2564662881195545, 0.16273664100275886, 0.13914143937008996, 0.1556379477223081, 0.09871462720536417, 0.1112862985821501, 0.13535382406365487, 0.11754983345106726, 0.21254275955500143, 0.09857307713959487, 0.13865630653116012, 0.14907197666264352, 0.11877300773536968, 0.15877881628130713, 0.20540586913064604, 0.16494583939352345, 0.10937219725981837, 0.08262039162218571, 0.12274465268297542, 0.19709131770556976, 0.1401536253791663, 0.16975075817636906, 0.13749275687000445, 0.1499713485639903, 0.1734078933875407, 0.13634978433049497, 0.09120609220718184, 0.1707350432632431, 0.1489329470261451, 0.22892368056120413, 0.1632359617900464, 0.2448784268551296, 0.1501097653301493, 0.17032558458947367, 0.16923470602881524, 0.17310343472467316, 0.13888633209130458, 0.1583455475948511, 0.17233377683066553, 0.12881040663248108, 0.16335940919816494, 0.29167587298058695, 0.19430441241110527, 0.16233027732420355, 0.11178703663209755, 0.2730381488800049, 0.15272273802228514, 0.2113779994749254, 0.21568725937076155, 0.11145935018336582, 0.321796519621726, 0.13727526450830121, 0.125681841445546, 0.22052963985310448, 0.11666504020291953, 0.14747633809043517, 0.1292691860468157, 0.10895843317191448, 0.07917048319453195, 0.1341915767519705, 0.09774417766640264, 0.15740820837597694, 0.16272171760999388, 0.2534509660495866, 0.08334452091085334, 0.15301230393590468, 0.17427358806373613, 0.1673579744754299, 0.068421074519715, 0.1695471473278538, 0.12560154777020216, 0.15926252419669784, 0.12972128517445058, 0.22353661156469778, 0.14025107176313478, 0.10403277127132302, 0.12737473487974177, 0.1767735781087991, 0.2028479321949905, 0.1616262118782728, 0.13963867639822347, 0.12771016647738795, 0.09550812789389203, 0.07051807933396871, 0.1518209759266146, 0.09579197879159644, 0.1335872253102641, 0.12358119005277274, 0.2038469414917692, 0.12115618469373834, 0.19821596542193046, 0.12637078431585144, 0.1493829930381429, 0.1459706995275713, 0.1142847513960254, 0.1990660931915045, 0.107445455486736, 0.12419255119898628, 0.4705034400666914, 0.17554057491642816, 0.2634313450224938, 0.15381137960620467, 0.2031257156763346, 0.08199345590847154, 0.13675807855061947, 0.14497662383702495, 0.16316090049522539, 0.1770777609800139, 0.10096196145299943, 0.14260070939217845, 0.16562764232437457, 0.1512742342968141, 0.12532533476910285, 0.143167614456146, 0.09157329347104796, 0.12570172142718108, 0.14477007121088045, 0.15153367763325093, 0.15268564404499146, 0.092503814507396, 0.09875327634114413, 0.07713421383091519, 0.08619426839774655, 0.12339515326124047, 0.09247053564796526, 0.22315868506989173, 0.11395534891034327, 0.1854820672662989, 0.14979963761664208, 0.0989364326420811], [0.014850122200685644, 0.026656577078204964, 0.06599334188767018, 0.03467466013746397, 0.026120658355554747, 0.017276180930615916, 0.02732906246467704, 0.011924268666564698, 0.08406328758405102, 0.01747112923992738, 0.09741907293397574, 0.0356586043152117, 0.048960054879106825, 0.0691210184126131, 0.03250796813517809, 0.018249871021497156, 0.0320264263333933, 0.017915841364752383, 0.02380304128652619, 0.04676404852239836, 0.050247128557173476, 0.044553023011934374, 0.06924239738333611, 0.031122647511262088, 0.051995107543564616, 0.05120888299819443, 0.039383002046135165, 0.05124475123480924, 0.060408423023839156, 0.003952397227910678, 0.042436655325394486, 0.035636901044316834, 0.005837730751673301, 0.0915760360658169, 0.015287787274217174, 0.014623156204188784, 0.04165090575453736, 0.014389503217722862, 0.033372678388390815, 0.03831198814535334, 0.04374477343874113, 0.035725840021886175, 0.03196872076049688, 0.050329253182656346, 0.04858162276627076, 0.09523776014365497, 0.060745896245803566, 0.020291840079270547, 0.0575505779875863, 0.017706770224556807, 0.0743298570535356, 0.08374561390448963, 0.06221671228206927, 0.04130371087681382, 0.04558334998305767, 0.0005398496514610617, 0.00586967183006627, 0.01760555277278106, 0.037463097607777, 0.05708498422116522, 0.03776323553475161, 0.02860727442067958, 0.05633201555258805, 0.035909984576245474, 0.03452431921276354, 0.05466400082373331, 0.03187124564823124, 0.07167409068994945, 0.024380912899129817, 0.02165657209022151, 0.0470465281227183, 0.06391613661581952, 0.02968312233626362, 0.07729783488978302, 0.03455065731560031, 0.030086097990973826, 0.03916465166595675, 0.03760882285273364, 0.04188631308234988, 0.030260260419679746, 0.020338716999357267, 0.05384334445660634, 0.09137618670900984, 0.049205900154887676, 0.09974421107120092, 0.060934097235721935, 0.027180786146932555, 0.03500736063166011, 0.07698845028156236, 0.06949638617375205, 0.03568757393006836, 0.06498073453023549, 0.03010315685382774, 0.06850845450835844, 0.014077960156775532, 0.05603848513396037, 0.019366739114986795, 0.058702885308453155, 0.05034244904715208, 0.01449586973795968, 0.012882705946873515, 0.06056094346868415, 0.04482576180429709, 0.022158158582545096, 0.03747051333888404, 0.0009794420944789666, 0.05488782490213072, 0.013258400252990186, 0.03284232720973031, 0.06407587743935085, 0.10546882606802449, 0.04872156404739907, 0.042808828499889186, 0.029589173143669486, 0.025145401614868355, 0.04215258992307129, 0.05817536865511249, 0.05594989089595695, 0.08547247567724797, 0.04280687114524265, 0.018455004469761928, 0.05763563672981917, 0.04725021174958637, 0.025927305424345598, 0.04949817418931954, 0.05583675886173883, 0.04358155074559393, 0.07722181598505667, 0.04651389783248306, 0.03142444976425219, 0.04500036473355947, 0.08137962795914182, 0.06237978175763161, 0.03940743642048009, 0.04193281078891408, 0.039036205534132264, 0.04521380832058288, 0.02694215741939843, 0.035547479431355195, 0.07551229078202479, 0.06266784230847994, 0.03819244395520899, 0.014521229163473173, 0.06324401703633128, 0.038091216927334186, 0.06509776212154858, 0.06700379653803765, 0.08620254214732878, 0.002836926047870469, 0.02328071679409233, 0.031087200623005632, 0.06184384962844272, 0.03255626231792473, 0.024226745365247614, 0.024152917471984704, 0.013219769311798437, 0.038753783390406644, 0.044926291692160794, 0.03194486669775459, 0.038928110528016285, 0.04508044773472413, 0.020796134692406463, 0.016072394416457223, 0.030804845511973388, 0.006018482494137941, 0.011229080264456572, 0.06373617873196641, 0.028208353286308628, 0.06556075501946673, 0.11812285955754981, 0.053607534932633566, 0.05230696278534109, 0.04167740473583822, 0.030614342427842563, 0.0064305583157786925, 0.051729581469009, 0.022304996570211746, 0.07103635313650293, 0.007840596287766653, 0.05583082168032566, 0.05873072111318189, 0.020548661479786522, 0.008286677315951356, 0.04271451924597064, 0.029308036112436847, 0.011992756926995373, 0.03268380446599857, 0.05913913407693467, 0.04132267155293976, 0.07856759498076094, 0.06621726938793737, 0.08729227923698003, 0.025187772022740498, 0.01617153576995817, 0.029574590660030806, 0.040834681206052346, 0.02917152690520931, 0.04067342735887055, 0.020741909073906082, 0.019825478309705373, 0.03913578930340948, 0.07630615705443967, 0.07296019909723152, 0.057630523092924595, 0.03673498849234274, 0.025483650500856103, 0.07167971377531368, 0.07964359611392983, 0.019816875142315706, 0.05347660284549479, 0.04771030883515074, 0.031033921123091734, 0.009967882163642396, 0.020938604063684904, 0.06767066841524455, 0.018127375477624517, 0.07748621591036359, 0.028387845771747734, 0.006584361000286957, 0.039073946855721936, 0.027046328140122276, 0.019768655653141683, 0.07219602639276175, 0.019770448298884497, 0.07385309755561814, 0.03781862752211671, 0.03361721748426076, 0.12683082011438188, 0.0564576271590927, 0.03070974527227302, 0.007708004662661904, 0.04505938414724604, 0.01665485489572729, 0.02058192310223897, 0.007162869902282593, 0.03147914078116658, 0.043138993243055965, 0.03412267080538216, 0.0680566311723763, 0.044077094719414754, 0.012713020344475105, 0.1615107164628083, 0.060459942436747016, 0.012808201981017427, 0.019241583330797094, 0.01697093128196655, 0.010072999002952731, 0.032649809314358624, 0.048391200121371984, 0.0544353963566884, 0.0557334672269081, 0.03402031379781904, 0.06900428193471125, 0.038421699596989545, 0.108834893833245, 0.03001323153805589, 0.017307770566173622, 0.09498291333476383, 0.06123390957532872, 0.06388700995293838, 0.007033877932812058, 0.014823010349045358, 0.011589238307468835, 0.017560573835526744, 0.05580943250547975, 0.053970691252259485, 0.05981003940706292, 0.04606682807207108, 0.035751354580204335, 0.04973261624634747, 0.07345305410243812, 0.07319203262487728, 0.02978896121344259, 0.022368574207047784, 0.02265336739289905, 0.003256251455299677, 0.09188860759980257, 0.021763673097255732, 0.09125172040395199, 0.014580868150768502, 0.02709241598964699, 0.017946691725463156, 0.04722726741625417, 0.013432529165349422, 0.05007241071472245, 0.03314228893648232, 0.02858591971979026, 0.051787210433113004, 0.011928680375398648, 0.01846074821397422, 0.018659107529768543, 0.028672462757376414, 0.013130767131975342, 0.01004109335612626, 0.045862347713761756, 0.04713548242204613, 0.061959337383028, 0.06395590807040853, 0.060155870648281234, 0.03517054885085072, 0.05801002389841503, 0.03525993598985576, 0.044451003083057945, 0.08454031521274198, 0.02152000159596003, 0.05766938673332334, 0.032346082265458764, 0.024035796034900893, 0.02369861775678733, 0.06061059362705677, 0.038188659480863044, 0.0136441245652555, 0.027087840529519226, 0.06855674869110508, 0.027583244692293868, 0.019890848592284228, 0.069728288649311, 0.05190447934212224, 0.021516435456672506, 0.05481733715221767, 0.02377523612531443, 0.031047394694460016, 0.02368744819485132, 0.0621148647229758, 0.011152213874963984, 0.07062238986573874, 0.026630240890588013, 0.06901840093515574, 0.030020735369274215, 0.0474057084460172, 0.062222500076337214, 0.10090380005778805, 0.04763771434344592, 0.08348013379520948, 0.03838744397545534, 0.050178670940259774, 0.07757785534786601, 0.028637554045886766, 0.036769577362124, 0.030414686508236394, 0.04608804487713403, 0.08756430939801278, 0.07084035720195501, 0.016133985970349565, 0.03524366811278366, 0.04487754934797845, 0.0431022210226905, 0.05450881439291182, 0.036005554044799465, 0.04256689027252217, 0.03315491406547447, 0.0374766803466745, 0.08459451593338482, 0.20659266189942438, 0.11586179701431144, 0.14421867176650033, 0.1597490206721329, 0.10344487539823018, 0.12033729798971646, 0.20308923456938038, 0.1724436951260413, 0.1900693711133734, 0.1329800240214794, 0.1683195220727113, 0.21774682546815566, 0.24769376933334336, 0.13564695994700157, 0.18246461547190146, 0.07552919068163441, 0.09569157530824024, 0.1055103480335205, 0.1540427075158204, 0.1082602819247592, 0.08281447233692293, 0.13638425828708758, 0.10338744178654687, 0.21095430688752284, 0.2752621021241911, 0.22288174428526433, 0.23884657229627335, 0.20172674719604755, 0.057454816997051246, 0.21150944484097345, 0.18708337488914692, 0.24682841173583464, 0.18849234847772509, 0.1169847516763595, 0.17294843981583274, 0.10236538090412656, 0.16990097269656199, 0.14719380486396053, 0.10904930652149263, 0.1917625939653766, 0.0799600134092954, 0.08135334348245975, 0.1655863042199804, 0.14257417210648138, 0.11629366375986608, 0.16247517519420193, 0.16613925116196757, 0.18354772590100768, 0.0815480906936911, 0.19904752322021993, 0.24913170104545934, 0.23630423291075617, 0.09614775768451153, 0.12689544729167415, 0.0904615236926944, 0.05602873283468428, 0.11024965904653074, 0.15073127714135956, 0.10924674270133819, 0.12079784706715616, 0.07074342409689581, 0.16558988951146603, 0.15528540938131272, 0.08879263179316636, 0.18198892083619872, 0.09896590404452817, 0.15356258489191532, 0.037003195874633334, 0.15407682907196785, 0.12625359584607426, 0.1301358766373127, 0.09679497940646065, 0.25080986260887117, 0.11787879160575329, 0.16966765295834313, 0.15280055723363353, 0.13381599448621273, 0.17253107511468474, 0.13772313483059406, 0.09963248480832386, 0.23640144946834735, 0.1785802739041467, 0.2167768202601902, 0.11355298421075267, 0.16361938879614876, 0.08670970767496095, 0.11106626280853826, 0.15335246229604368, 0.20204861137655475, 0.17919631584757761, 0.14761962717579258, 0.11523643178084206, 0.20572142074665717, 0.0744440041542534, 0.13314709247600648, 0.0946680588587638, 0.18272505472263983, 0.07957529171460098, 0.07405224977241409, 0.22120398108757314, 0.1334454071137213, 0.16030759069948428, 0.16677173335225354, 0.12038240524669809, 0.09482958849759833, 0.1457210161512898, 0.12966756708920002, 0.10371517420055405, 0.14715775276624388, 0.14802229831055289, 0.17211155004559026, 0.22208888924890952, 0.08713537676920814, 0.060984360264433976, 0.11348667164002696, 0.13057879803161468, 0.0891728105864698, 0.15118080221356886, 0.1267292981426562, 0.14818385093202516, 0.1431582528617113, 0.13046587667157575, 0.14277614352683868, 0.12569779905700876, 0.12390115433522772, 0.17765680087670205, 0.20062368783739307, 0.18014376742705224, 0.08150326688924144, 0.18629641872980904, 0.13928858953858578, 0.11380669720951589, 0.23392494767904284, 0.2215941190238922, 0.13483193432611806, 0.16258241218184272, 0.16441613555915896, 0.09358834986004139, 0.14686475477872357, 0.14137769598634015, 0.12136930269339394, 0.1573955985687433, 0.21299354101140655, 0.1642025042805941, 0.17372142253143175, 0.2514218749298204, 0.1405333291979567, 0.12835744182549177, 0.1259871121616133, 0.0951523949662524, 0.14982366213394752, 0.09929824830783952, 0.17518530930242232, 0.13932292559935203, 0.22536803667824115, 0.07332979821630063, 0.12201663932853168, 0.12061404725236279, 0.12722174712126294, 0.2402942026815107, 0.12197799019275174, 0.11340132178438288, 0.17099290845855591, 0.23209572889872138, 0.10015386126695142, 0.13799368644193297, 0.07106198643844935, 0.3233501459321668, 0.26898119238115126, 0.14454721623370725, 0.1794241503962586, 0.15403576675922642, 0.12620858818052277, 0.10583751354246371, 0.0975907379160485], [0.06342376424600521, 0.028983620859141794, 0.0367435188813796, 0.020226456390153018, 0.04100592867020638, 0.06558970548212528, 0.04448019869385227, 0.023882047934157234, 0.03274743189854968, 0.017668540521915403, 0.10802500100145418, 0.03306241660949684, 0.038026003692779815, 0.026659599295066252, 0.02401701921987678, 0.07357512255229297, 0.06071200068559378, 0.01197100577560524, 0.017502031311573043, 0.005127787017338579, 0.0618953537195921, 0.020830112607068112, 0.06400289607324428, 0.03876385744661093, 0.05518043218480964, 0.02536018394053944, 0.007499955292235339, 0.024825937204783963, 0.08724815257254147, 0.028846286192175843, 0.02542994582214423, 0.016248983428663304, 0.030869239032448783, 0.0577351170772266, 0.019211048981355085, 0.01515042483656397, 0.01146747150473417, 0.027837716118102113, 0.10117380008582147, 0.09745815873987253, 0.04374504539995425, 0.016809436117088603, 0.12992161716664993, 0.0035348038973977733, 0.04524727104111545, 0.040816540244005384, 0.01361956091357335, 0.03436228395589898, 0.04822403973629398, 0.04268592118375725, 0.016041006836589548, 0.03369293378425702, 0.04417362945875333, 0.03914816545382623, 0.058092883968305205, 0.04623382374824536, 0.07950120335144382, 0.0522528080299737, 0.01564562119798915, 0.06456608178033944, 0.012284526301007117, 0.07958689794665383, 0.00620046524413591, 0.07858294738276352, 0.04284868039371025, 0.02023995485937884, 0.06300567176132914, 0.019149692999499462, 0.09534668252472916, 0.03635997313164896, 0.04035424831653795, 0.020501887981569576, 0.04563791076502493, 0.04409843026810596, 0.021778330274467027, 0.03775209278589295, 0.035025344545682596, 0.036790487732017235, 0.060842660811519435, 0.031221892286632812, 0.11462104867302603, 0.04442418234482889, 0.08164050387999705, 0.030188981683984883, 0.03855129103026083, 0.019478241297146006, 0.0541802354517483, 0.1104467734694481, 0.031141024045345765, 0.018520169823821035, 0.008839389643511705, 0.02834426494495523, 0.052048779663539706, 0.04242118417976364, 0.09031685564907328, 0.04187587513438156, 0.044538789098301244, 0.04197047550171133, 0.059904743196262475, 0.006575707079572303, 0.05464046660269942, 0.05207811700060003, 0.028098327738623467, 0.03828635101296729, 0.05835234262650052, 0.09432593165265937, 0.025626382257248607, 0.03191694662335419, 0.022099692667383822, 0.01718564274450464, 0.02573291061355943, 0.07873968131119206, 0.060687439906741344, 0.05854203365743161, 0.04034759101247595, 0.05393275074780949, 0.007367006957440848, 0.02830539747411686, 0.025936793423287814, 0.030108304964678905, 0.0388201572481663, 0.06241819723659466, 0.015656243964669206, 0.08778747847123493, 0.034253886345052914, 0.03273441223427653, 0.010069708655317946, 0.03113352021412744, 0.03452588969300832, 0.05975575058630878, 0.015010288203014963, 0.05092395574695641, 0.03149185975592944, 0.07374610571611313, 0.04131432885544435, 0.03989924954610967, 0.036373153674386205, 0.0792008126154542, 0.06106359290800268, 0.06629233068275837, 0.035699662797513514, 0.01310890872827581, 0.02415361652721561, 0.03371187913862448, 0.027310004112340754, 0.024799532069253827, 0.044203614140109676, 0.08770671748225728, 0.016497783888612064, 0.04873721522369212, 0.06601639347331179, 0.06712205753090882, 0.07045063295311506, 0.07228328380733728, 0.01659220422527963, 0.023181734403835672, 0.010162850582761871, 0.03781229580542253, 0.043659465717932874, 0.050970365353409326, 0.033384943456058545, 0.03584241562132393, 0.055206360430606914, 0.05115582374855877, 0.03212899018469597, 0.041173200138033404, 0.0523744015053155, 0.03176404313454705, 0.07881601431196736, 0.015777007192223063, 0.007361450425965051, 0.04014081622083341, 0.022848840472438646, 0.09615829139347039, 0.044810654550430276, 0.0298076480131356, 0.035877812713865316, 0.03739444080800299, 0.0017969543888841967, 0.04716252915621285, 0.04048437601135623, 0.07987234230724075, 0.04051686196978535, 0.04565528946958723, 0.044533154521618164, 0.02133153630570779, 0.021157454316233917, 0.027158801338725516, 0.00291702461019609, 0.007612186694337476, 0.00854423033043502, 0.03823391995542953, 0.008511692661071017, 0.039106042109309666, 0.015117106715127107, 0.05922700053141002, 0.056186355425104986, 0.03289626746047889, 0.07443727790227822, 0.03376753542632346, 0.043335613539262165, 0.04274097609243566, 0.029873273019949277, 0.08042349660348508, 0.049221118491503506, 0.03930905157880437, 0.05622706150696163, 0.04323074759374704, 0.0628952938131988, 0.03359452212950395, 0.011096319142398576, 0.09828229314617573, 0.05005725749558018, 0.03875680943770755, 0.09159085220627247, 0.022039746287308877, 0.07715764846051894, 0.007694254820835927, 0.07718084560286614, 0.06154510215105069, 0.0312911351436689, 0.015009163011376177, 0.018064470082942038, 0.014566027112455379, 0.040762791515237866, 0.030263995098310615, 0.08526399250953429, 0.05853426169543978, 0.056711259718623855, 0.044826956901458964, 0.030870527975381385, 0.04914634831009373, 0.025771548258020513, 0.031423850300451445, 0.02698004429769372, 0.07313921086249814, 0.05493711499917892, 0.04033327282917115, 0.01715729940652607, 0.06885236669932643, 0.013078933623018525, 0.03233373675855898, 0.06558516258073431, 0.02583605286124493, 0.0599759970340998, 0.04904543537826789, 0.08391228399329609, 0.08817999128011927, 0.04818527568732539, 0.026177356522830746, 0.056009274201407555, 0.09808389935642482, 0.06340808625663481, 0.03517977254945905, 0.03404557937756181, 0.06650477452504058, 0.07472205576637099, 0.017002610932855357, 0.043113210553964304, 0.04517950673377322, 0.012361947146634902, 0.007121941176122956, 0.0611460124773364, 0.03207056831959034, 0.0911179920958896, 0.10198165512373371, 0.06100156659921331, 0.04932298520279508, 0.06727379656607105, 0.01796426195200653, 0.07089635056834068, 0.07928969413642922, 0.035646274130070404, 0.0274888243556263, 0.040844104087520997, 0.016402823459957878, 0.0344055985671378, 0.05946464483596145, 0.034716771990661664, 0.035144019226032885, 0.02978232497679851, 0.005896799482269994, 0.022288554408136877, 0.05580994578438902, 0.0434468686580658, 0.056229290822821285, 0.03233116653357302, 0.05227552253692862, 0.02513839574080081, 0.03936394943945831, 0.023271868478566892, 0.058412530324271614, 0.0261321573352982, 0.07192994107402141, 0.012855497376632788, 0.047320860377963514, 0.02459567032694336, 0.08599151556770648, 0.050475522350039215, 0.03630109927466801, 0.05141338250870186, 0.047587508771328196, 0.012210132460290147, 0.02309765625414589, 0.014579102318103035, 0.049082245903029564, 0.05258493778866626, 0.03048669877311876, 0.02851639724066181, 0.03155841555957112, 0.09297200148144076, 0.03855537810933687, 0.03376069043072001, 0.040538189857597315, 0.051571610308582747, 0.018050887344044544, 0.03259878402816192, 0.04098970675840974, 0.04806398481671368, 0.035464508278716, 0.023418009326222445, 0.06489228201849807, 0.038106714886042385, 0.038296800452254476, 0.07003498428891744, 0.006946406492422666, 0.08231243959838346, 0.025113042060946746, 0.041789035237724745, 0.07772024811035202, 0.038613370965204896, 0.03595146440690564, 0.05111745040443155, 0.08514704152701363, 0.010868795816936802, 0.09172014486525329, 0.04154102576355781, 0.011671943244554344, 0.0499776532993682, 0.04277035939477144, 0.0068468710824456675, 0.026088641625979257, 0.020080175731451284, 0.039464303127099434, 0.0028079655303079034, 0.048039546611929135, 0.013974252919245873, 0.022858069916706414, 0.06968937138275755, 0.06695341859613696, 0.08287254946246263, 0.052987693193098234, 0.16600088036108404, 0.18107133136401254, 0.07324086306917091, 0.2089609920738205, 0.1704084906246393, 0.1653255585340723, 0.15761604802983423, 0.05562840975941189, 0.15818424012151458, 0.06883156741218222, 0.12114204271065614, 0.11486136279399357, 0.1532870843525856, 0.14628078127580305, 0.07225696102625902, 0.17088659077642426, 0.18867979487103803, 0.14050066320886537, 0.10568599667279951, 0.11911383259200281, 0.14122712906570206, 0.10611217138507675, 0.16312691683490432, 0.13267196474536774, 0.10265198205747914, 0.1243964761435505, 0.09466920799065022, 0.2597687399435428, 0.21298365847718334, 0.1360857904317879, 0.12194604432630925, 0.1583690664941265, 0.15943564474582672, 0.16356131933148832, 0.1296565047795734, 0.12066313050567143, 0.10552177806535076, 0.14669166487311164, 0.21986902691423896, 0.19427985163225284, 0.22720157619445558, 0.10001807984325195, 0.3088406857944304, 0.13947568353145354, 0.1458041673345912, 0.135943558547766, 0.127204395229778, 0.05687047194148745, 0.12382751796394588, 0.08292967663897623, 0.10229679305226573, 0.10553529951721431, 0.1616912833865612, 0.14032116880820644, 0.09909578659121068, 0.17895818507719427, 0.15409015900185033, 0.13418459003010105, 0.11082817034255113, 0.2335889568372119, 0.10637916068756774, 0.24581267107878965, 0.1047205267053458, 0.23033804740876923, 0.1402275068985839, 0.10609750846220602, 0.16000400537685042, 0.08093103751420014, 0.14955016874497937, 0.12770454339202375, 0.14417733366210617, 0.12020920042789753, 0.1958871807061857, 0.1638045062821719, 0.08449539947774141, 0.23618532074314935, 0.19455018873897292, 0.15036216065768274, 0.16432225914491763, 0.19788568959601466, 0.2042814818841796, 0.13251716901938762, 0.1554981673196439, 0.1574745975554951, 0.10136082513077606, 0.114875826534004, 0.22995279711340705, 0.3110289393413452, 0.12686412961732957, 0.17905295015342776, 0.14094159277456422, 0.09755752800453095, 0.18403390061951455, 0.12459451753285625, 0.1499914507111234, 0.17574841457028545, 0.19430487206385982, 0.1365162705581996, 0.11949430249871747, 0.09247950653755858, 0.1537718341475533, 0.1725956410049431, 0.23516403360953256, 0.17203500254019616, 0.15878186531124577, 0.20252170131331493, 0.11862954244978967, 0.21553656987605557, 0.17128296466844697, 0.1456799231950314, 0.16820617170343477, 0.14527653193762227, 0.2164007783416779, 0.1002053500363423, 0.16131265209086482, 0.15639510306139148, 0.11208127568205518, 0.15653894373005436, 0.1539112008627384, 0.18947029035658608, 0.10972269780693517, 0.18600720521663466, 0.12001230050959896, 0.13064606055136652, 0.1664054820374135, 0.12028106713607428, 0.08819345144494888, 0.11519392922280297, 0.12475784747831284, 0.13134211271760926, 0.06472540508595205, 0.13389251134808988, 0.1300749573255739, 0.2617007217580273, 0.18062116277794685, 0.11356413079005097, 0.1700320350186479, 0.2403522261808957, 0.14995412690745247, 0.11212818324565889, 0.1620447563548242, 0.07113782914295312, 0.11531614322936344, 0.10658062648989501, 0.13174266944969856, 0.09666267602193741, 0.09176860758734327, 0.1655782143315, 0.1589497611407311, 0.1247026814868854, 0.15687407655341012, 0.17590032980567025, 0.15736058835060368, 0.20231648168015867, 0.12510217335675994, 0.11840420534774182, 0.15012782968340382, 0.21240599753875888, 0.08470294801818748, 0.24185237955422173, 0.1621784999846451, 0.11948153947389896, 0.18581675575865855, 0.19890918306285338, 0.15717525635996174, 0.11614086752336834, 0.18099741920107798, 0.11021840265922009, 0.20702090504909718, 0.18074315461900928, 0.11677597739523458, 0.1856417506332359, 0.08155058047944501, 0.19371305382059467, 0.19829603693177625, 0.16621327057721155], [0.07125080412914676, 0.05236052382256716, 0.05195778757033329, 0.054767851702748775, 0.018659582504281597, 0.03952030415436433, 0.0802395512319861, 0.019736734684556723, 0.0979793589982775, 0.0301267025661805, 0.02008049557315967, 0.0410921250530068, 0.03851125910577755, 0.05557698993793419, 0.040304073387937206, 0.03220675002423025, 0.03587435382688719, 0.017841530836097175, 0.02669250851707353, 0.017119286123723272, 0.03171710875786601, 0.09867831463775328, 0.05640609625486597, 0.013246441620492167, 0.026620609250159997, 0.011974659057394152, 0.024245428334501003, 0.01892008687249355, 0.010689784051670183, 0.06994283157250575, 0.05960650516734008, 0.03355901778465317, 0.018435363890603185, 0.06751736656071679, 0.01294787991942177, 0.024805953801279108, 0.04647752397783822, 0.11744078849592518, 0.026555265780658494, 0.03918992873701838, 0.06373818971276765, 0.05103929028395684, 0.024890842088948817, 0.06255988519819033, 0.06242858155840828, 0.034324458364637635, 0.040210112704024206, 0.06286617481119691, 0.05174388816099494, 0.03404443407611501, 0.04277114846533345, 0.06566144961623416, 0.026840949543721737, 0.023681867244322936, 0.016586376211395668, 0.004231524954159414, 0.09576744099538173, 0.05902558452479782, 0.047377409158094276, 0.017815414898758455, 0.032503026868066484, 0.02850119614102427, 0.04076070775608382, 0.020416658784773563, 0.03385330279988628, 0.05060520954430104, 0.017380305686064305, 0.05191094512420316, 0.10646811881733519, 0.003376313712402818, 0.01213722674536609, 0.04387603111324772, 0.05135665752834851, 0.03202959027652058, 0.02495558417942976, 0.04367966362605653, 0.05942830928571283, 0.02041558051602014, 0.017099381244230657, 0.049986467140937046, 0.05804273968322143, 0.05026013289968814, 0.0406776063684975, 0.07316302853606402, 0.06530436071296854, 0.04100395216336174, 0.0325231826413543, 0.02537742474927537, 0.057740096648734425, 0.012715962122104341, 0.037741390537590756, 0.04460525871705144, 0.044887339951650757, 0.016380061072507696, 0.13320476357494632, 0.023777819756839066, 0.07203886345509561, 0.02497216615255081, 0.020899705949329564, 0.06722221586612925, 0.028220961178322474, 0.020682724951315793, 0.033690271628720146, 0.043182162297589165, 0.07112728777311503, 0.05004262138578681, 0.05125320501505368, 0.04648061131217307, 0.07551595268230285, 0.0471025099977851, 0.09815630232614857, 0.07452600620566838, 0.04902113889974933, 0.05764496385029728, 0.03381028313249831, 0.03308807672452062, 0.011714065631461, 0.026361171659382603, 0.031041513054421356, 0.04163939911391466, 0.041154565049275275, 0.035590606351052566, 0.060265084142766656, 0.03453455031699231, 0.03446649106579923, 0.01782097478186892, 0.03689356869266879, 0.04761623706848872, 0.033909265522754965, 0.0694033830997444, 0.02528400990300842, 0.04413428318296229, 0.048656917717908664, 0.0759447091108849, 0.013320979102694941, 0.038987700677206444, 0.00899253923806452, 0.02882183266563281, 0.03055771512369956, 0.04832956068698437, 0.03393682553583095, 0.012617730498013478, 0.03549505220425706, 0.07351105461918539, 0.004855003217310315, 0.04005856519084304, 0.0352461081028225, 0.04576782778566403, 0.07747163725716454, 0.04726106721547343, 0.018057278432552854, 0.06873738456277118, 0.02124704829897852, 0.022941565839573744, 0.051434817648823225, 0.009022902175333471, 0.020345349405561725, 0.023812038989196864, 0.0254225664802136, 0.07255611836069054, 0.04198114710649656, 0.050191426304199045, 0.047239160931278626, 0.0517828245797465, 0.04558689313970747, 0.01254762387684276, 0.08629183735578291, 0.020104497107827378, 0.06969659559188351, 0.033265127304701075, 0.038729720568704995, 0.04321896133103198, 0.022273527593502117, 0.06117309751589933, 0.037930261854442864, 0.05486946943546495, 0.11756557655791122, 0.049356191283873016, 0.0655712197805124, 0.015801920371520665, 0.035132336385187604, 0.023627731641153657, 0.04727165455058698, 0.033370341820221756, 0.05703734504359384, 0.034367516336421815, 0.014963893918320538, 0.011640036640117967, 0.03275975825325136, 0.03917384472104811, 0.03667442924192837, 0.051843502573789134, 0.0428566170646058, 0.0432673780878465, 0.017114996031347304, 0.024151400617894628, 0.058047723085168874, 0.03869593609124422, 0.012762052844458771, 0.05176658734619137, 0.015181419796370452, 0.037140149412856954, 0.06755411579844452, 0.037222917552196214, 0.017902467384814255, 0.12311086569341922, 0.04740708357384128, 0.05736608103278184, 0.07860432123585094, 0.03350361430596921, 0.03217614481165525, 0.027018049919617274, 0.04900926453692298, 0.028341030138694955, 0.018823563624473832, 0.013017988455812297, 0.03133354768637688, 0.021226038337655125, 0.024881356005226413, 0.06261428127125387, 0.05191892776037416, 0.016681369198786638, 0.019500517218764273, 0.024501834132318056, 0.0064332123316313715, 0.06069579792599525, 0.051154686107991204, 0.004512072576495309, 0.03537129070008955, 0.0679470269730495, 0.02842343247105037, 0.049272331469241655, 0.06321949073143544, 0.06989577079131719, 0.02424115164866371, 0.04748343189637508, 0.021716962801292542, 0.09779015826361795, 0.04312490488612845, 0.038244361733837474, 0.03771625519279511, 0.03752527330371161, 0.03313722126486321, 0.06229661525257173, 0.025071792056663864, 0.05278392146611887, 0.031529329116306, 0.02050389321671138, 0.013024116201596636, 0.05491002613017636, 0.07310174916300081, 0.06869571704056955, 0.07039072487743632, 0.034246627661970355, 0.017055260325451533, 0.026999895551031636, 0.1006714302685953, 0.021899485164472175, 0.010754764587017558, 0.05134687841599507, 0.02465938394438596, 0.019062198097667387, 0.027904909689940756, 0.03150143585498295, 0.06693598243498033, 0.026672115256529183, 0.022081352522476547, 0.010035762341783173, 0.010577442045623978, 0.01024429530521194, 0.04147650200813528, 0.014211585042968154, 0.035779263163285877, 0.04222644079897193, 0.08069517436407267, 0.028693957269311916, 0.037324799585246274, 0.0781097042284185, 0.047884210793962406, 0.04184923442681471, 0.06467662826781312, 0.0173179327224892, 0.04146750430546461, 0.03033772531536318, 0.005268945420656594, 0.059421019959113294, 0.04516836015447494, 0.026638815329680522, 0.018152549126816374, 0.06328460054412004, 0.0521295483133966, 0.06461972325679756, 0.04754217934884852, 0.009694821614351486, 0.032927431917238625, 0.02475302670181038, 0.08189617806384641, 0.0411040262289105, 0.018275870130427422, 0.034839851676576564, 0.04993540738078375, 0.039748410664258466, 0.07174734401726915, 0.02535286397042294, 0.005006952926651725, 0.023471526313392867, 0.020709143493384607, 0.05445360243620892, 0.02739715810504652, 0.024826446653253613, 0.04908158706741468, 0.086762085106344, 0.026812060368097117, 0.06570565288946514, 0.02972127734533241, 0.0647099684142778, 0.04089041793298337, 0.025269737684979074, 0.058107769056673975, 0.02966118732377166, 0.05016906036724968, 0.08963245568015883, 0.05400111260373266, 0.07058886585817223, 0.03327226724415537, 0.04744144644768489, 0.13704163833491265, 0.057782671985126315, 0.012260759380766222, 0.06665234604189474, 0.04041825496261159, 0.01926678762350592, 0.029723610083061843, 0.03895174051004072, 0.055819587000916084, 0.04712679498498479, 0.027744146139030496, 0.03991486624844613, 0.038813227982891184, 0.03066143576776789, 0.0255086881694414, 0.04377223386038696, 0.07021018093632114, 0.029676930430615624, 0.048131672515263485, 0.04586225578321084, 0.09879482128927786, 0.05004637521661578, 0.021671765528979803, 0.02604764443071139, 0.04376989346177828, 0.024939354606753877, 0.20301993425574996, 0.11399348476721395, 0.10853703118740551, 0.12254059750346408, 0.12197672614767668, 0.12562800078622757, 0.12069978781284825, 0.0861233133341997, 0.2941450356475769, 0.10708411479549063, 0.11230810665555539, 0.11216189111432723, 0.1751149671092149, 0.18543433998861622, 0.1374291256070137, 0.12483042664825918, 0.11501314013355202, 0.11422609204366324, 0.12717086356133223, 0.11367591833996196, 0.15086705856505903, 0.18630299176419937, 0.13838688872994917, 0.07965344034375683, 0.11689703460902938, 0.1327799678209328, 0.07461963747177394, 0.12738924458502762, 0.12227093455411735, 0.2485176049653561, 0.22939562136607788, 0.09917171356538612, 0.16965602374365255, 0.09498192508134151, 0.1505764201283455, 0.10974997819791879, 0.09458958081180051, 0.24547300301492217, 0.09311218024982561, 0.14903937196058614, 0.25192376977253345, 0.23797614319670587, 0.10394129271228468, 0.19897783986262738, 0.2057379222805462, 0.2359552798612464, 0.09498078361033432, 0.17186036513697717, 0.13221090238901878, 0.1805094518368283, 0.2136653235122081, 0.12661379506631246, 0.09257061737439326, 0.14470907529034924, 0.06460167422530151, 0.19156200150328298, 0.20588605304158505, 0.1606751290420371, 0.09729197128645836, 0.1315336040551624, 0.1299813720247438, 0.15447626731568767, 0.23059418124537315, 0.11843887848719475, 0.08966553535672928, 0.11558283375756395, 0.1336546257258423, 0.20531698760967101, 0.15243660418256638, 0.25943129353465577, 0.09116388842343323, 0.08505479688005102, 0.15597188544850196, 0.25793972034608165, 0.22179953783990877, 0.10575250842638555, 0.2519739638533323, 0.19640859546920947, 0.10196641763491977, 0.17240516090344998, 0.1830668831544538, 0.11381566043822997, 0.1185601425447291, 0.19838444347823822, 0.0818468879667982, 0.09738092941622581, 0.1147774838271641, 0.13250730180692288, 0.13755192950127587, 0.180122209712863, 0.18567067811325674, 0.14386492300658457, 0.1635659311807925, 0.11587691958993675, 0.19110765007715072, 0.09869728297475847, 0.16530164126907626, 0.12106888131388735, 0.17205971653663343, 0.12123436396641117, 0.15149215566775492, 0.16310145207230123, 0.14803490811778655, 0.26753978262985906, 0.15653768734585854, 0.14060695024748004, 0.25413574140158396, 0.11926526519199533, 0.13446012121294776, 0.13684021849786082, 0.21760663137801234, 0.2356399121063371, 0.12812402249584276, 0.20091109338306612, 0.11729936100422375, 0.14828905012578736, 0.13183253156321664, 0.08006751852770967, 0.10701270774006845, 0.1258951892715789, 0.14070137824502685, 0.14174891155092947, 0.1243931666437176, 0.11713796160033635, 0.1360841050383545, 0.087404633691955, 0.16117161530400478, 0.08850466700330858, 0.093577578663826, 0.13107623424260847, 0.2232081283845248, 0.18526079043024973, 0.11695022409361218, 0.13637920210678733, 0.11743775478774503, 0.24569132275158362, 0.06991328356126625, 0.15953269276407459, 0.11143628327596573, 0.20852910234562813, 0.21705278045227452, 0.10112846300246255, 0.10468537859137982, 0.16772283151024775, 0.10543344812768121, 0.22577496726186047, 0.14254942746652713, 0.2334459741870242, 0.2550271153450012, 0.12063232611023611, 0.17149851116682255, 0.1811420719229406, 0.09140447833605352, 0.11766971088945867, 0.13790822167310024, 0.10811000611753234, 0.058569360013690695, 0.10921733258592506, 0.1373496056804734, 0.15326488312453995, 0.14050198088009513, 0.06786972104061036, 0.15456381584367446, 0.11577755032527833, 0.13656860968518642, 0.2054786321616942, 0.243280919028386, 0.06461775441083216, 0.14227858474177701, 0.15370441841021662, 0.12354485450252412, 0.13115132618094646, 0.1550155166055887, 0.18517416120777208, 0.15024612898067122, 0.09949425190326669], [0.04130315929350834, 0.0182209933371914, 0.10756384671455431, 0.0280123726735192, 0.03108424926927734, 0.17924621881496522, 0.015324156340812484, 0.025885229960324305, 0.05917861058767285, 0.04337448101010054, 0.039443166761268536, 0.026169299193087126, 0.040283074917932676, 0.11104840529902328, 0.02686163774811693, 0.03985282078745865, 0.033625135002958204, 0.009980710305934472, 0.062227399208612984, 0.053736298990946625, 0.05035521207197059, 0.08331946983572938, 0.020632341263755676, 0.05491713159567407, 0.08021209464077989, 0.046651954537317644, 0.02806534190782376, 0.02118226024322212, 0.0660911713156008, 0.06197119642409587, 0.09134306106716396, 0.0505769064259385, 0.0067466313503832835, 0.027256015981096896, 0.04727181542905108, 0.006854803444096639, 0.0157251650647771, 0.044174805403717106, 0.013325856209942892, 0.1411948154770559, 0.013671821516547954, 0.026099644563791734, 0.016680241134318135, 0.02447753956901931, 0.035681111978427056, 0.05218026333398396, 0.07641694102916988, 0.03327451571221313, 0.012592706235966856, 0.048498532870003296, 0.03293259534984827, 0.045695601016162865, 0.047297238056818326, 0.022492496589679393, 0.034861650708461964, 0.01156195312843568, 0.06713503506034613, 0.015897909273213197, 0.023807802522975593, 0.042229164241542744, 0.04727914689048644, 0.028074266832141627, 0.05603860770802825, 0.11434373250531574, 0.08508954662829639, 0.035412184473487644, 0.022249822917905067, 0.05183596426861421, 0.08128502376137242, 0.015500737692139324, 0.04225682767648851, 0.04651611948746347, 0.02389148422216456, 0.07155141703063442, 0.019814249375955235, 0.024424717806640173, 0.07501705324337368, 0.04635614500711522, 0.008603732379513883, 0.01828056050374383, 0.001318489507426538, 0.01164751461586885, 0.03065394151264862, 0.042594818007801814, 0.07692645078585034, 0.030278422449144627, 0.03548690102874272, 0.03825802874240664, 0.04199978219525468, 0.08457917885314073, 0.00837329887754975, 0.07336545194829665, 0.04985363132530644, 0.024494177083514874, 0.06041648609924221, 0.013492719735950233, 0.037776665056064244, 0.04857292383789055, 0.04256546151854339, 0.0531940236537447, 0.010382127929328671, 0.03306168499552915, 0.030347466123320406, 0.03572898098237572, 0.023844413864876957, 0.044371437191242175, 0.021996805143933144, 0.045421138525970524, 0.012632613671162437, 0.024544432451347672, 0.04417444151195307, 0.05781337295869186, 0.039843183401371204, 0.038604036183847536, 0.04765716148540378, 0.03527115151706723, 0.03902623106935813, 0.05028042273836271, 0.03356817636578795, 0.020042016891942873, 0.05359132068171617, 0.015968640256042204, 0.030365771794271086, 0.02015897362012296, 0.049378419324996016, 0.13458926831522297, 0.01719813572332984, 0.021618861412148804, 0.021675071198373072, 0.029640386121407635, 0.031011790758179083, 0.0864631116330143, 0.040528828263162606, 0.021167214276389252, 0.02686149602185094, 0.08119732967668003, 0.01484936951930004, 0.038790134262413754, 0.02477902772596046, 0.020083766768596346, 0.02709536925859509, 0.027411480118790944, 0.02893040264626184, 0.0259567461832757, 0.03336679866357196, 0.07010406243704981, 0.03658660492228885, 0.061281793901035865, 0.017181507784933332, 0.04135674714381176, 0.06172902837035157, 0.023932908511450215, 0.04420234626459499, 0.027437370060192003, 0.06708605139846764, 0.010839799389002786, 0.039581414988084186, 0.06216079935491566, 0.04108619553247287, 0.0339426861084517, 0.016851316228689208, 0.02245058391934201, 0.022570752471144644, 0.04789490921182498, 0.0630431947478604, 0.04359951550741831, 0.01313391479573423, 0.02938566380180419, 0.044246453776835434, 0.04076641128068009, 0.027841644233933864, 0.053672376614544666, 0.032960756741944826, 0.04918673263502218, 0.06821669758327546, 0.04637287636738151, 0.07918272527956194, 0.016754513358577125, 0.05759708335502975, 0.02586555490720897, 0.045971304568792545, 0.02859356527727458, 0.1048632029203638, 0.03438243589874718, 0.043517184038195884, 0.049910272035988114, 0.049527764335394873, 0.054258368759145664, 0.016404079844153697, 0.011164960620414105, 0.019111516923012755, 0.02930345490664965, 0.0359059089884883, 0.05165079315643638, 0.06413226917145715, 0.05544182138457414, 0.046370444038221915, 0.030348176669870174, 0.05827469578493507, 0.0815368368620834, 0.05383310569149833, 0.04654006356553686, 0.041323843667463916, 0.05137702780625513, 0.028005529593135563, 0.12185127925007574, 0.16738659552028104, 0.045418591283622294, 0.025083070786129084, 0.02404717244057646, 0.05201891755625125, 0.04805587577603517, 0.021991124601974603, 0.008851388495625749, 0.03263979271474866, 0.05446542700332019, 0.019196265399636283, 0.024058405204766223, 0.007253798793235253, 0.040302326707469846, 0.01957467261461481, 0.03668319711822175, 0.07949305217592947, 0.03585461940195772, 0.05157699590669044, 0.04768050418445661, 0.034122563553072756, 0.03316563163553515, 0.08176588949056403, 0.05063507165158949, 0.027701524837363153, 0.039371721401450135, 0.042243076398247675, 0.03344762093958355, 0.0249063917585919, 0.039740462502044056, 0.01651079780722578, 0.08110960494847068, 0.04216671658439502, 0.002583167323234281, 0.07517677491470691, 0.009081331701318343, 0.0364184869273055, 0.039150279856497244, 0.014469868713809599, 0.05788924247627297, 0.059518113942636605, 0.09583170811134963, 0.009716133222795062, 0.11249567562293623, 0.05348001193675784, 0.060993430745457454, 0.013864195770433834, 0.11446092097509293, 0.024705814618256786, 0.017267242599759373, 0.033973099799045635, 0.00966869610091371, 0.03805716814953954, 0.05984666607072277, 0.0980687537981618, 0.11407037701217398, 0.03282559967990364, 0.07645681590562867, 0.031108204838669593, 0.020992168931350596, 0.03233299748371205, 0.06261388673597286, 0.017064497430598544, 0.05451878885768595, 0.06899502759258594, 0.030524702479822502, 0.010336528460855686, 0.03563549527297578, 0.0340181227863556, 0.03273967142787672, 0.06581202419775148, 0.05357348998527854, 0.047627429613062454, 0.020602565341358705, 0.005878149071753386, 0.03935681716088326, 0.03349501496901916, 0.0452622059251993, 0.0473667643663864, 0.0268969256731291, 0.012560941357796472, 0.02564605539514413, 0.07533764571792657, 0.03484019258570287, 0.07587536283197903, 0.07411912158732453, 0.018747583024143692, 0.017504749008484425, 0.042816776662103595, 0.07648970406021803, 0.008419971826726632, 0.04769055142758354, 0.12344691016140485, 0.026040728571974946, 0.008274907332604692, 0.04924219740074008, 0.01756782485773006, 0.03767970513792769, 0.02740868198264751, 0.02479336123102375, 0.06062818300579825, 0.020712912645972064, 0.10210939262422825, 0.053579515266803004, 0.019432728013564503, 0.024234505835920576, 0.007907765919357658, 0.07126367440627468, 0.03884808498344595, 0.04834489393678885, 0.018792824346512076, 0.09513459874377136, 0.03651743867404519, 0.014503223224422865, 0.036834982118659446, 0.0176600388611757, 0.02696130004140639, 0.021701957054075696, 0.022719837011649244, 0.026027643790228233, 0.04693141575121591, 0.012760126133329205, 0.04316272664695017, 0.03197167977510441, 0.06193711317234463, 0.0391313536543279, 0.014870435979607848, 0.10305061590887847, 0.02147127265831636, 0.05041846029099919, 0.06942900107993234, 0.023251607368189483, 0.02158287251668592, 0.09632915964410191, 0.02331737410126915, 0.03357338576367305, 0.014820038885509056, 0.017715601303103953, 0.02128138244452496, 0.01126353602646099, 0.061902842229051944, 0.03485735295520675, 0.08342422469849549, 0.07975948989511498, 0.02048881469114173, 0.029054064558999195, 0.17570450241046567, 0.12260120271915391, 0.18634590800971756, 0.23495547383302645, 0.1041333509549018, 0.32656180101536936, 0.20492855038854385, 0.09182177408928834, 0.06648528524824689, 0.16906085003527904, 0.14411305888525902, 0.16137640592792343, 0.1377830582280313, 0.21184558890038924, 0.08419584377758926, 0.14736474972338448, 0.07941433664170966, 0.13497885466823656, 0.2329333081480957, 0.12102123830587634, 0.19146613326043854, 0.18417282300370355, 0.16844393475161445, 0.1503465324640274, 0.2071140153754142, 0.1857368374663976, 0.1293527509175962, 0.16019083889982394, 0.15376734487231702, 0.12805210982239054, 0.3898950251600435, 0.14831744134426117, 0.15030648138734604, 0.10257467612503998, 0.17103101367190962, 0.11735392944707025, 0.14427528566410466, 0.1363938037426241, 0.13752926862047565, 0.2029999853262017, 0.10878237850603559, 0.08354002654912972, 0.09265314036559674, 0.14915039342257286, 0.13831469260396498, 0.0989196093512639, 0.37501533005026083, 0.19100517815639897, 0.1358554890799907, 0.13012461514482576, 0.11971249966131103, 0.19883697161511069, 0.17982391039690665, 0.1433145347982645, 0.1184768841091183, 0.21904664684928235, 0.15782250872542783, 0.15056799316117842, 0.13045124439222197, 0.09875486980402663, 0.21687097246608428, 0.22127682072741373, 0.12898965588500425, 0.17422363913107305, 0.21930874084993718, 0.12646956369280815, 0.09544707834720613, 0.1348044011261194, 0.09237254534157054, 0.15563646151173502, 0.16479942466943495, 0.14587662393046966, 0.11290882684050069, 0.18530556060854467, 0.10521456914683504, 0.109195307558102, 0.1809070055042544, 0.2113301036578994, 0.182615764619362, 0.08640271326106402, 0.10476753386037965, 0.07931797044171442, 0.1309992270844598, 0.20429409169141324, 0.2478486569898744, 0.21965254578859578, 0.07531598075142792, 0.1319277716139632, 0.08113531485920952, 0.17145184109047537, 0.09721799783648984, 0.21351066568205435, 0.16613482317376524, 0.24380475462925053, 0.14090914129009172, 0.21907034960965957, 0.1236428754524358, 0.08368658682992382, 0.07973789387652952, 0.08279290696185443, 0.10751513884432855, 0.161179383435557, 0.11473327289305388, 0.09263207294767903, 0.17202694329523271, 0.16363805069798426, 0.1282835986104704, 0.17431828163323865, 0.15115688494857282, 0.13472144912567832, 0.13460920192301273, 0.13200732218402048, 0.16142768785357475, 0.0993404444307089, 0.22298266870840905, 0.14348791581728768, 0.19974870817555537, 0.1587421359914926, 0.10760502394048438, 0.123456601173647, 0.11693431244742487, 0.13845586728665138, 0.2257230724658697, 0.1210811157380381, 0.08121699515369632, 0.20847426577200814, 0.13109382362134997, 0.17564505398754152, 0.15607556778817408, 0.1305762392979476, 0.10191794725195055, 0.1649775247900717, 0.18205406895327955, 0.10189093499174041, 0.06998714975892537, 0.11995410847087061, 0.12520852168240856, 0.12785082022028585, 0.19923999515031615, 0.11541601811205188, 0.110057455247208, 0.13979367130706388, 0.10568289401670618, 0.1556400774467376, 0.1251346325021117, 0.1718917440983557, 0.13028291955349908, 0.11316737385406611, 0.12125012239501362, 0.14502456561932642, 0.23657360474669167, 0.06434710320806311, 0.07861233451553891, 0.13604385477881278, 0.14439523971128848, 0.11553856919729903, 0.06920156489697195, 0.13794366090047744, 0.15503235521816439, 0.08619456717203702, 0.12235829156012305, 0.09223268066923465, 0.09256913882469939, 0.1808594927311905, 0.13449422744733674, 0.27908717913012354, 0.22982075419877807, 0.15893597155809402, 0.08618402580219893, 0.11144759839460736, 0.09139936852959857, 0.19538144010209268, 0.13450305278022445, 0.12553552631288767, 0.15851771819495386, 0.11653212394805686], [0.04185690679737637, 0.04170570019332152, 0.035089538883297675, 0.052925938845521985, 0.005128771440321279, 0.08199293496868304, 0.014723660236585044, 0.06510013699411385, 0.024911907591646718, 0.021999158949080496, 0.03797087600574859, 0.0526643006671821, 0.02146037314237366, 0.06800164138117144, 0.04400661463038095, 0.0173704250670609, 0.11211289213069024, 0.03002132525697591, 0.049283501031177665, 0.041901902971608986, 0.06105505102764695, 0.01224540314832402, 0.04552093679986654, 0.04835681426489065, 0.035127942870941856, 0.0806876820241732, 0.06582231275857457, 0.024393047731850418, 0.04706689840062492, 0.062090380552915804, 0.030409532651725798, 0.025734785613754106, 0.0025636397420443716, 0.04016179170820021, 0.042014448948565035, 0.03322474681021225, 0.00467570752070676, 0.039641717599043926, 0.06330030917700741, 0.05850650249950348, 0.04395291952776813, 0.03466968439639576, 0.06191237236282999, 0.0805371304252936, 0.05139778495856351, 0.05533343909548656, 0.01834247764500399, 0.035873940139408075, 0.037834627268415306, 0.05020500904309654, 0.019986691937271147, 0.03201592326795142, 0.01991248483048572, 0.06116106993548813, 0.03614264164840983, 0.03909911284403455, 0.02498767177213825, 0.026628524853637623, 0.0645727314235222, 0.0402669717497643, 0.012262019595401663, 0.091503250052131, 0.044551973471478115, 0.053802282143864906, 0.04781538928528467, 0.012621631800767877, 0.07501835559284495, 0.03545644137287333, 0.04517107593616651, 0.011657451733856673, 0.04064930708057458, 0.02456065436314431, 0.049541837370563904, 0.04824258672494081, 0.03961714149843301, 0.02708974042757144, 0.08452228150300442, 0.06745748146767579, 0.034236714484230164, 0.03703552095459835, 0.06880254034073123, 0.02453202757263376, 0.07943528914643873, 0.0543866080472306, 0.03868380125852362, 0.06227182464734201, 0.1423443916944727, 0.0469013276479898, 0.04295279174261997, 0.06386654391404122, 0.038003932699681296, 0.06082712837885465, 0.05816551676440624, 0.027032507913968256, 0.09759664445394471, 0.06050150270663923, 0.07868885137741605, 0.045470578010163964, 0.04240700389228521, 0.051019747381008444, 0.08889511903567661, 0.031405115620263165, 0.0244541279220533, 0.04375179846500678, 0.026322447830030037, 0.0665776371475189, 0.03887921879668871, 0.092594588265544, 0.041372708585714145, 0.015562509276693868, 0.03101393580436707, 0.0633524759342113, 0.05276988673534605, 0.045307791987133604, 0.05105407578089545, 0.0724332838229114, 0.08746359181860763, 0.04374242537925321, 0.06530171770962977, 0.030768992597117063, 0.038571462125307134, 0.028627861118424806, 0.03520375110148903, 0.03914972827319176, 0.06273157316290083, 0.025588187028563796, 0.06594393687743334, 0.06396519305605082, 0.03890284877871314, 0.06898194281083923, 0.06239844365946709, 0.02803681662396318, 0.024091982838487434, 0.02544212662014029, 0.05270712115170975, 0.009963055809719429, 0.0181346743803231, 0.01039392376814278, 0.04990506263810301, 0.029193442765503164, 0.0881038421404458, 0.018771190023530396, 0.07323765316076818, 0.03334609130697866, 0.033820606167277986, 0.022927201690993482, 0.054691484228016875, 0.01903321890671167, 0.050948861265374776, 0.09395696838656742, 0.048632648052467455, 0.04455148700564619, 0.027573450258181944, 0.031763893747401815, 0.0698948055205326, 0.08312466899834334, 0.018700861236861637, 0.0507016332008906, 0.04673476481149274, 0.03237256975544076, 0.008908117306418717, 0.035510906393850045, 0.10035039346304633, 0.06334034876236994, 0.0750911875718063, 0.03351528565549562, 0.027914836274219618, 0.03409054107783783, 0.03154248093074608, 0.03501039050940064, 0.04747259558268613, 0.07631315143718835, 0.10749557295874243, 0.02927095554168186, 0.012679460905342093, 0.009646441246713362, 0.031110372867495305, 0.03669820478065841, 0.011615321686070774, 0.04061309793483346, 0.009228834270259306, 0.07059195319250708, 0.039812896115284775, 0.02705742300848567, 0.05452468390426329, 0.04415132097839829, 0.02903872939397491, 0.023967162217764605, 0.05229730241661591, 0.016528624673223784, 0.014840408205805768, 0.042821633659543536, 0.09536640162790015, 0.04918826864131036, 0.06663499415040978, 0.0340319583342681, 0.034850071289486466, 0.02788131801231254, 0.04431121884995411, 0.02688619278130993, 0.02891409454957372, 0.05903267083809741, 0.02934923823622446, 0.023512728437180483, 0.06251027717465354, 0.06543216716137625, 0.012435369970907849, 0.021081657577005607, 0.012191825831729558, 0.03622791489526149, 0.06657916166248821, 0.0696625889489247, 0.015014586913880083, 0.015320934941090885, 0.049415647367676424, 0.04220289125617954, 0.037430814662647825, 0.06482136525934742, 0.02015072285317846, 0.03165362496680069, 0.11286663837851056, 0.054585024819619236, 0.08556214626878501, 0.03160792399167774, 0.05843659314597326, 0.010720450551279131, 0.05124897237927203, 0.018069687141706387, 0.03625264038301764, 0.02228413599603359, 0.03172645503054223, 0.052265954098754355, 0.025439514260318492, 0.015026998495863331, 0.013402286886928544, 0.03714002300834945, 0.030064354500462933, 0.04752957337205449, 0.017919158525464517, 0.03454402682461566, 0.08708305296397979, 0.020966696507868268, 0.013981159201883262, 0.052212327944054726, 0.015824679886141134, 0.029156695442995238, 0.057447696209795056, 0.0329678392248048, 0.006728200232535, 0.011069435201915763, 0.03366364241247216, 0.006444595440576274, 0.023915018443198457, 0.023101976990038832, 0.04217151229480102, 0.05212153503370862, 0.08453282287284251, 0.013167595851325221, 0.038164703911470796, 0.09790847288264383, 0.08007479636299034, 0.08155930622090256, 0.012494434392259968, 0.04097662580710265, 0.019294382110538504, 0.039724642786407666, 0.024438821485326178, 0.05872401401340481, 0.10792904848893804, 0.013208396736562494, 0.09215626339878767, 0.08485130860560364, 0.05148449462027319, 0.04509349038163501, 0.016609251596814683, 0.028022446729723486, 0.021820702597558982, 0.03106081655489341, 0.06043762246507311, 0.04630637993555396, 0.04276405449115461, 0.07657184400745938, 0.01708518755021355, 0.055349105593538096, 0.02893747555302276, 0.015311024636180412, 0.0809022709126434, 0.0767084911105133, 0.04372999943312138, 0.04616748053400267, 0.08596643384906553, 0.03466050666306288, 0.0492770467404156, 0.022099075966604778, 0.026942668783087886, 0.03768921611950763, 0.06541475398285736, 0.011091769537738255, 0.02046318905007455, 0.017209039069712162, 0.056462959131045695, 0.08076148693479838, 0.08242749068285189, 0.04855801959732368, 0.04160426249126754, 0.018465923137902733, 0.007861216501858568, 0.03691966547780941, 0.005086747687234874, 0.07317064345003137, 0.02674836590285263, 0.029644367863394083, 0.07569946904456423, 0.022852935212393923, 0.04311267429241731, 0.0473667107402317, 0.04782426441388746, 0.00861299534012834, 0.01238589697036772, 0.06285057726105855, 0.06619370452338649, 0.031910540213087396, 0.051558544679034146, 0.030659698663399588, 0.016596741381011183, 0.058414311478695566, 0.02140571659941587, 0.009471800013054765, 0.031940128443942915, 0.03651358142134644, 0.086826229648244, 0.012203865861069533, 0.026078151967076045, 0.034578466307251685, 0.049252317422219825, 0.08002097868630964, 0.02990048254779991, 0.03421879951812087, 0.03807476518916027, 0.02519419950042521, 0.06512469011208703, 0.053066856888753754, 0.04032537446267182, 0.028469133446173325, 0.03156972876299293, 0.026322748519540317, 0.04553126366508584, 0.029568159351906473, 0.07142708862140294, 0.04266372761659084, 0.042707658928608706, 0.025428781368499322, 0.1822008207560547, 0.12646369545930816, 0.16888172335682378, 0.16653490493134146, 0.16672486409304604, 0.18502036139609354, 0.1122937731504921, 0.14112787471423227, 0.16143421492268964, 0.2776776692799984, 0.13504722035459935, 0.11881318904699818, 0.12188068936548888, 0.15945617590219746, 0.14384276774381438, 0.2127069628406917, 0.20178434168619497, 0.16104557851870216, 0.19359141437997743, 0.2663646650410468, 0.12545088891901318, 0.12501524535999184, 0.11764755562668848, 0.11972468045930709, 0.08809522365129764, 0.21895828626809583, 0.09674151413022511, 0.0984619943905742, 0.14978089910601416, 0.13897741994550153, 0.09741007140086544, 0.09111072192148817, 0.10684652794753352, 0.12461289598215973, 0.14419909055915572, 0.23829034649797026, 0.12751767156465402, 0.0608407570830276, 0.1518270433429749, 0.12446138677337479, 0.09595033682642445, 0.09986864673274179, 0.1281887645863237, 0.28179655632665085, 0.20672295813358602, 0.1966819816058682, 0.12050578370690347, 0.12880630040120694, 0.11423779786714625, 0.17466954826827974, 0.07855876198699398, 0.11456858697197131, 0.12255843203034132, 0.3407833346676442, 0.08694806061084233, 0.12612520717084408, 0.10946109410255186, 0.07973174219049754, 0.13164935994052118, 0.17446843486639763, 0.14451261970304674, 0.19655361591327578, 0.1057186550010116, 0.23617689377598225, 0.19103235895595244, 0.08485771310065063, 0.18788955985538422, 0.1414421393025306, 0.17653002343591184, 0.23489800191694693, 0.19918563355120922, 0.13472342563252296, 0.14817850363831367, 0.19142919250072973, 0.11835012720116686, 0.16988873061153198, 0.11528541544272054, 0.11720280328224744, 0.2198634344723917, 0.11188281294439109, 0.18356243478915385, 0.08528699046902119, 0.1284117268158063, 0.14294687388164384, 0.2097767837826283, 0.18419191391477663, 0.22791178566553902, 0.14324145001028815, 0.10063347827282645, 0.15259081768172403, 0.10935202616477206, 0.11425856651077348, 0.3249269080979209, 0.1288686293147264, 0.21818017076340415, 0.19952216065458714, 0.1343393397908057, 0.11710174862415561, 0.2297929452071267, 0.11427714414293728, 0.2076208438243597, 0.10786482733824562, 0.08988256806567793, 0.1763300132006407, 0.08975433260803262, 0.20446077710197819, 0.11625486906738051, 0.2895833804242073, 0.19584694576840248, 0.08525835410241159, 0.1342741763519664, 0.1515129319722614, 0.1950575534494654, 0.14711537278227269, 0.1553285554532082, 0.12079701969219793, 0.1480169510168414, 0.18879371214537852, 0.15012346298223542, 0.11667367401382617, 0.13544563204050064, 0.15051697170542133, 0.10833932687678646, 0.10455320544180371, 0.2979528603534545, 0.1280808840848265, 0.11804012972260676, 0.1710376479933339, 0.13871917170622658, 0.17976617801093286, 0.14627192529939836, 0.11002240672467217, 0.14216857451585033, 0.08006028665770447, 0.17226568693595548, 0.11203837475829548, 0.24390615402690827, 0.11388671509320698, 0.11943221873333378, 0.15230494431189953, 0.2282759378994665, 0.12024716008454563, 0.08588269277806244, 0.20794194191694262, 0.13483669939300708, 0.07258002796480734, 0.12225259440921007, 0.14581625620203634, 0.0922752828187039, 0.179924696924225, 0.10594314940634275, 0.1463149028319505, 0.2249185728930658, 0.06624455743980023, 0.2256391705164025, 0.1526234223837814, 0.16368226929297372, 0.15717447495027898, 0.13262915575215894, 0.18067330272207338, 0.16443838275248007, 0.15753767723518033, 0.1620012272389666, 0.23943980014131916, 0.22808050886998255, 0.17256426204356456, 0.12605536293478745, 0.19108900349707375, 0.12168495390083521, 0.11826949644713633, 0.15444583830333528, 0.0886013702819905, 0.27252906813256206, 0.15865356090568727, 0.13913998380303383, 0.14251362051694624], [0.09030237658730439, 0.062480491676157525, 0.045842371971136144, 0.02360728092401499, 0.022151039710508722, 0.04849191770077713, 0.05769595849297701, 0.028806147015383168, 0.0641891397085161, 0.05229786166080064, 0.025743938449229446, 0.06238097685479349, 0.031467496244717515, 0.03646164066008022, 0.03514258664161448, 0.04005307617086557, 0.07173743083952897, 0.025112806488910032, 0.054773463296794125, 0.07750549834341773, 0.06093009825675719, 0.02466288879663954, 0.07091377140773882, 0.030602249729957794, 0.043600047938525684, 0.0480370529957356, 0.029881797663326708, 0.025276868048334317, 0.024543834902766733, 0.03794983923134785, 0.034486608534690835, 0.03007783381749065, 0.004385601993905561, 0.08732497586958832, 0.028355859685689214, 0.10605663001056641, 0.06886247139904769, 0.029439699813543312, 0.0520144512636527, 0.014296894678996216, 0.03205684768486648, 0.016545424981403257, 0.051344878926512696, 0.02670936053618789, 0.04819719984586682, 0.06435382179915905, 0.0878070903220965, 0.07336135337790174, 0.04259648424903712, 0.053846274742916714, 0.021185629114869143, 0.027492580101675088, 0.023927000058334202, 0.05468836625016505, 0.0392279994764155, 0.03408319046420436, 0.02541792973305189, 0.027730398691229285, 0.042898740409122366, 0.02700347126641822, 0.04838275400200679, 0.04670732737248463, 0.07142744868272735, 0.0240529966240208, 0.017581593372949192, 0.028383419698765202, 0.053650137082102804, 0.04450138102495863, 0.0312551788069428, 0.0067178216563808105, 0.061943192080023794, 0.03419806534845022, 0.018344672486907052, 0.029545965784740065, 0.039915812367032615, 0.07527075858125765, 0.04800768501515831, 0.052984310914912534, 0.034017506085576556, 0.04673449668071924, 0.08176481696747004, 0.07493505885283794, 0.024578914068819537, 0.05067326113461487, 0.02796446344995451, 0.07600304670631886, 0.030468079006119125, 0.06775303052798395, 0.03983934147043094, 0.06485106648817178, 0.05753054861880599, 0.010834804495736476, 0.03333328231688469, 0.052508826953388994, 0.014436416526985987, 0.07011406754534091, 0.06803792330526537, 0.03972784503393116, 0.1353424093535831, 0.0420612990555744, 0.06709547427993628, 0.0953287024411463, 0.05008508563942967, 0.031017201254144314, 0.033048469978835315, 0.03582885203462455, 0.05455113692028869, 0.029371389668555032, 0.005947412996207394, 0.04385962917078887, 0.054034253567337036, 0.017958702068896066, 0.048226016243138624, 0.03094950972515489, 0.12707830481832066, 0.01858011045823655, 0.03966813997155236, 0.030890635868173935, 0.053151191677898176, 0.024474302847539226, 0.06851030078025595, 0.052927796608738364, 0.0678048870195785, 0.03124701039445016, 0.00928140992689277, 0.030469456049163016, 0.01588425758640252, 0.04837829153984786, 0.08678455446516314, 0.05914076967465301, 0.020873568944572922, 0.039675904272664944, 0.051950463769777175, 0.022603994941398985, 0.038651518313394445, 0.02913375302488285, 0.05596734620931168, 0.05727619976706563, 0.013528251851488267, 0.05198138307840113, 0.06381457250925802, 0.014334250083794037, 0.048230061187378825, 0.040723916383520256, 0.019809375141536998, 0.005719746029259818, 0.04028521996412066, 0.02737136967029543, 0.05115996828422912, 0.017306219238126953, 0.07969156853974828, 0.07766377210857407, 0.024418985553746744, 0.03724563972003037, 0.05552032624461478, 0.033286263670531974, 0.03326232342289821, 0.02991504396402067, 0.02641575925442721, 0.07571645321384554, 0.022784667202241482, 0.006732424728632455, 0.043256871191965, 0.027277883960895484, 0.0046226568895602425, 0.07158986698355406, 0.042377532489838145, 0.07447841682381208, 0.08916668954395479, 0.0899438780822581, 0.03286020004100377, 0.03953906947806959, 0.03584082981932067, 0.034595772233461185, 0.03385401526165586, 0.0336921064092988, 0.07893262055492209, 0.040973791281782815, 0.006976189596893927, 0.01862547818511244, 0.021782647179920348, 0.053261688369656765, 0.036396427425525846, 0.018264083867712368, 0.04152628623189465, 0.008689166504829642, 0.024642888156156388, 0.018801668831597895, 0.03098720891190873, 0.012643419341334413, 0.013018289145322577, 0.030008562232157397, 0.05898999974071499, 0.04661349309307914, 0.047068587624497955, 0.05520701543578217, 0.03432261975361936, 0.01950966239336037, 0.018822010381207354, 0.02713657521282233, 0.03285905856999659, 0.05081368888157511, 0.01895548396503493, 0.04655758399636515, 0.03269670921708307, 0.04624249969398783, 0.07014422842691984, 0.02108907139289283, 0.012702417687603064, 0.0656474455289783, 0.04141215828337497, 0.009540299764804302, 0.03190148122338278, 0.02750928273364421, 0.06991467018040919, 0.017694528139526808, 0.027755386564099503, 0.01565849243272697, 0.05072070112932594, 0.08025496492102262, 0.033301370924398783, 0.06894813535074074, 0.08720775675629416, 0.024358594842675715, 0.05685334604594016, 0.022282249504520048, 0.057205463038577195, 0.027872304987883376, 0.04418579876543053, 0.00798889080009934, 0.07215019901313129, 0.017048241044845314, 0.03180424168315386, 0.02918722979243725, 0.03091867085576298, 0.020701792879751133, 0.049644270986919446, 0.03553208106407716, 0.05096959926548505, 0.014109978801570834, 0.053636431769137426, 0.03228522807119354, 0.05277276722594135, 0.06437436061640901, 0.06185338359266039, 0.005275555323028276, 0.05430353730316124, 0.04639924128329562, 0.06818180993920372, 0.029358279988950783, 0.010915237982126494, 0.03382979539192973, 0.03182992286559555, 0.024656162544664358, 0.050497171994779384, 0.03981036036425541, 0.07397246937597952, 0.06981827333689698, 0.01166484448232598, 0.015420957295704755, 0.056727891487459985, 0.04618978518391809, 0.023854635393006668, 0.039997925501196616, 0.0747275332950296, 0.07340500506782725, 0.02314876772523407, 0.05482165405767099, 0.050104762607764815, 0.010099201125182934, 0.07050975195823178, 0.15043228834627137, 0.0577569505830686, 0.053516293860851764, 0.024869676994820757, 0.0797013821260583, 0.13705407960280297, 0.050562480990324295, 0.1219299105146239, 0.025365219053421772, 0.07247712703481798, 0.048236630391329534, 0.04183356792876317, 0.0158491401159535, 0.03625074431540505, 0.06822641157815534, 0.024740257931332436, 0.022917692624633352, 0.07010032392797932, 0.04617337941101963, 0.035568834132244515, 0.02807479160236976, 0.11971490517739328, 0.059177407829631726, 0.03400133013905537, 0.03873106888345173, 0.027027442157568953, 0.0073451131221748175, 0.01649359913332568, 0.019241016425733126, 0.026678711273557237, 0.06360037049518959, 0.055977600296178175, 0.051629365677194256, 0.029551533328729774, 0.049695867008619735, 0.013645581089921538, 0.06013150522184949, 0.08591447776604084, 0.003139853013694407, 0.05179849873867728, 0.05869841135497536, 0.017933786974378654, 0.024857191676874796, 0.053702357465461384, 0.028183533952781753, 0.05251153890464095, 0.010767430893235631, 0.045150893349801345, 0.09570142719894649, 0.007202227669392503, 0.01721481154222162, 0.08619408453664473, 0.019796001161598874, 0.007865586075856681, 0.031904706453544, 0.048177128342250665, 0.027232169579233856, 0.07713590688522785, 0.013614161908926984, 0.05873288531156798, 0.07041032906741866, 0.051141792848225565, 0.015388655198377468, 0.040333954647423766, 0.03086797690259353, 0.00930665922726715, 0.018006235909377857, 0.049210358786606984, 0.018625765468084046, 0.03489596761703011, 0.04121931480063547, 0.02833520212481099, 0.06912268082340879, 0.027473571545053876, 0.0365387205965817, 0.08072462278388201, 0.08693977920038086, 0.08235050650734095, 0.12440573048567581, 0.04574620495400122, 0.028527695122325135, 0.30506690603590786, 0.13704300197141786, 0.14855854453579073, 0.10083500536218767, 0.103452789086488, 0.10285306481584426, 0.13480617845010373, 0.13583679653463826, 0.12965039139793766, 0.15670696213360757, 0.13412364007484529, 0.1298972708924163, 0.12898358846864394, 0.11189915359981599, 0.10590180364106933, 0.14291351841342065, 0.16205342847012705, 0.10642654322568448, 0.14103205243666328, 0.21702176921309965, 0.1687529746202692, 0.21015610455745654, 0.08617474847743589, 0.08141811621645767, 0.19181589836314802, 0.12516919838925525, 0.19104608725155556, 0.13114099931572715, 0.09075977704337529, 0.08959594392968763, 0.08968512422495312, 0.12503281941697483, 0.11274201119498861, 0.14852027078309368, 0.18445246041782443, 0.0941973437945689, 0.1852082214768856, 0.1900350810178826, 0.22480396613959344, 0.08700830576520774, 0.17076121282673654, 0.1162747873534118, 0.15386215591382596, 0.15766063434702737, 0.1432329923996041, 0.13610241453974478, 0.11755493559664297, 0.18617834925891893, 0.1415698001942327, 0.11629728735574793, 0.18782482542578252, 0.09855653730130966, 0.10491152008574818, 0.20026908105900212, 0.13607825212661298, 0.15962879083329634, 0.1318105448397898, 0.06632072956211145, 0.15408534796968584, 0.13036738840803025, 0.1509864610289374, 0.1863290387536249, 0.14300848267251445, 0.10317510519657405, 0.1446888658909067, 0.18714870686732954, 0.10782040956039583, 0.1879153463749155, 0.14225881967333057, 0.04810941000018389, 0.13796198572362625, 0.11243527725098595, 0.1226049795326206, 0.09578626377568131, 0.19859940774979132, 0.15637550653228838, 0.11092338741065995, 0.15533830009160504, 0.11935223149315966, 0.10813118078775945, 0.30728690626640476, 0.1993433404113016, 0.15292758993323774, 0.1667162839082941, 0.1115377362997782, 0.14610444315739218, 0.1911263273007447, 0.1566674166749562, 0.17835113700599442, 0.22004977769909367, 0.12830763078865506, 0.10856831821823314, 0.16645601319689907, 0.2024928504420865, 0.08813904388056648, 0.2490711494559242, 0.21189826510606274, 0.16982007381175795, 0.1710488022335114, 0.1450027474352429, 0.2452953472252815, 0.2949170071271158, 0.25554393358047933, 0.17042739767461054, 0.20016818727937438, 0.1317218778234336, 0.15740636976495867, 0.16720941470515344, 0.07062923869178181, 0.11046991698564061, 0.15859320849901246, 0.14614878432644954, 0.11944541842826914, 0.1798617704621246, 0.3119091743663434, 0.09087681229556761, 0.1503455978367598, 0.19046592886649794, 0.09996311303468482, 0.10722105301195577, 0.13423230198602523, 0.17856167328934516, 0.09324510416556751, 0.10625556006186432, 0.11434097458878834, 0.15651303463645522, 0.1395402647434704, 0.195716496316656, 0.11485339547958105, 0.23903726690238525, 0.1461745861677393, 0.3041260581343405, 0.17172158064861454, 0.07475075342001454, 0.10855314201645314, 0.1344765767815613, 0.15954067540024558, 0.13957446290841027, 0.13728868636873462, 0.16186650301660263, 0.2415804796281361, 0.13969149049972335, 0.1295722044643856, 0.1020395866925678, 0.0981708579967099, 0.15802417371061542, 0.2037914920478098, 0.16999544665938424, 0.10303990599969703, 0.09303902651393607, 0.1618180709380296, 0.13807142904448894, 0.16129343860572384, 0.1207415702482385, 0.20930061417241252, 0.12722584569165785, 0.13154382366807232, 0.19259180753461777, 0.18197030489963872, 0.24276226218188965, 0.10627704116726115, 0.103219086304307, 0.09925361602537094, 0.060516441421162706, 0.1145866819687428, 0.1586593984956703, 0.13201115262364188, 0.16783825031691985, 0.16659573231252933, 0.15823376004494008, 0.15920774891011177, 0.11433967223931706, 0.16202185032588823, 0.20295650217561953, 0.09557557427474568, 0.09725437935201392], [0.0427916145042306, 0.08104169891486246, 0.039535292664602886, 0.015403247258115201, 0.05037951238092877, 0.07036490771438807, 0.028597560425799702, 0.04280050495459188, 0.020208483967449398, 0.043981938938339876, 0.049740989587359855, 0.059404166024779124, 0.02869555839307366, 0.02363954088650644, 0.03627810897606035, 0.051949073320194605, 0.02467950141327756, 0.12030125355287907, 0.052632446731290514, 0.04301642683605033, 0.046675216797138416, 0.02491800182108437, 0.02521523244438633, 0.02915503686263917, 0.02610239098900028, 0.06263621436852602, 0.020138492259467324, 0.005895722649931427, 0.040428654606183695, 0.05261749269500856, 0.028965106429231745, 0.033576507571964495, 0.049869887711059664, 0.015051638756337908, 0.04245987545037943, 0.04101520599496942, 0.02875083546725012, 0.07938602969290749, 0.0717856330917247, 0.03554530374165024, 0.052135765116902134, 0.05167453039077021, 0.051141076556016365, 0.05186971810255801, 0.013088566221056447, 0.07359889426058339, 0.01601835265905867, 0.04454910064176206, 0.03978694488684978, 0.07775170368052299, 0.04627060745992968, 0.07149522448138845, 0.05198845023950262, 0.05289680069132198, 0.008253727874328053, 0.027847638871941357, 0.044937890263334404, 0.0074412705632106915, 0.03313407264349442, 0.012943687503256146, 0.037983723300238775, 0.07539155532515819, 0.036772894522836136, 0.06299537937006643, 0.02906969466787433, 0.042161763825964545, 0.07609885366212937, 0.027106105980853883, 0.04409939936933018, 0.03482686265582039, 0.0778425004213087, 0.06231689359992743, 0.05873913658903011, 0.026442715973262827, 0.04413806765730824, 0.010342713663234346, 0.03698775537251946, 0.03922983042655453, 0.012272960288570294, 0.019211004931299437, 0.03995064255451003, 0.020651290448562756, 0.02510067931706867, 0.028587164612667217, 0.03374279461680882, 0.010905190738999556, 0.008818455333370835, 0.030216051400789333, 0.06497064515227272, 0.018718883455280336, 0.044253880999261336, 0.015257544995796297, 0.05035633822121928, 0.0258492372344218, 0.01248967219820066, 0.05166936695816056, 0.026123423932961402, 0.06195075336783644, 0.027133817296294917, 0.03822577644079443, 0.047768428095526276, 0.02401712647218618, 0.05472053428210559, 0.015675462237859688, 0.07001413137561853, 0.0695549535955633, 0.027209769168327895, 0.016764531873406905, 0.027616946815302777, 0.03087370724026715, 0.07699487009836782, 0.05437173828062031, 0.08938368394850724, 0.02888529921971983, 0.05418905695419639, 0.03924761132727708, 0.03992092217348757, 0.08286403056474463, 0.04502130191653006, 0.025874973958238, 0.023474381906130624, 0.02077771219304733, 0.0043757534548339826, 0.12657539107866828, 0.09036195524517568, 0.03810848071870785, 0.10764655356685962, 0.026260674330255678, 0.02546190317990559, 0.026347056489377737, 0.09306648310514228, 0.020621742437323256, 0.0756610727177993, 0.018999608714253675, 0.06346475761083346, 0.08106097368703735, 0.06187578017312673, 0.03778988007275808, 0.03825943451374769, 0.015200405370353933, 0.058275818103744145, 0.025636433330815167, 0.021306659515586593, 0.012444455773689815, 0.01666225147463622, 0.012053777745384122, 0.04550883644110253, 0.03857457627271933, 0.019024270999756072, 0.037720146919450456, 0.021802000476107485, 0.02505684185082153, 0.02568277015891527, 0.04077100014734653, 0.01174793629381325, 0.06952401896518084, 0.021042265335939104, 0.07824573080025374, 0.029453977777232087, 0.04815256756339823, 0.11071478166887838, 0.026591710498436328, 0.024439800162649444, 0.05389953317541269, 0.09507902672574406, 0.04828715005949621, 0.1063954936821134, 0.05078835435391915, 0.0644598177243625, 0.06284129993629552, 0.04006914486507735, 0.024749673151921843, 0.05260707389923835, 0.02297335274277195, 0.0914968072526878, 0.010709401648191195, 0.044019584498939016, 0.03426674513086196, 0.06802013474366359, 0.014211652075661527, 0.08706359433070307, 0.04607876372193137, 0.07020687909736749, 0.039199807440801974, 0.029997844662096713, 0.024732382547470833, 0.0558357514561184, 0.028603708281392054, 0.04033344519895412, 0.0593694047852149, 0.027980631735596447, 0.07172246914236777, 0.041181037217498793, 0.04709797092683373, 0.017309021204710007, 0.0470809446227166, 0.03055055794726697, 0.039533794962710915, 0.04336848637209304, 0.08052785310053057, 0.06719776233958621, 0.08487119624811797, 0.056115044130673336, 0.00634044147802577, 0.04396001733238659, 0.045492867338320905, 0.039550415240228176, 0.047156886918650526, 0.04160311718982074, 0.02911100787441096, 0.022139753320164258, 0.012562853704777457, 0.04379358473083666, 0.06526973353879106, 0.013365386346835765, 0.04021200494119718, 0.05860525123294323, 0.05912344842668503, 0.038181044566895694, 0.03521092934533954, 0.022791832039553313, 0.11364180444469375, 0.04573647180692323, 0.03587737604374847, 0.064950113995902, 0.032302679554108656, 0.025376181771618225, 0.013994142476980005, 0.023189933459845283, 0.020636483884206223, 0.016037942484892424, 0.02899452612074393, 0.01995619397700554, 0.07525889187931054, 0.031343878382035804, 0.057759371420909325, 0.019827318835943457, 0.01345601359066824, 0.02284956442552709, 0.03395513120678163, 0.04793265436385428, 0.02473997064836083, 0.03973179421718082, 0.02251475335909955, 0.08357329774768123, 0.03712672755242356, 0.03399972135441438, 0.041096890119895826, 0.06711420512968494, 0.028911978231682896, 0.031397228745082696, 0.007622335922919335, 0.038415429167329304, 0.05080084541752454, 0.08050915289429889, 0.023341915727923476, 0.029662876547644698, 0.0644222334507973, 0.03605238499961073, 0.06526733568358807, 0.03668367592317443, 0.04863462072887248, 0.02765063170133339, 0.03422235033564991, 0.02436054453644301, 0.0666015467516357, 0.04074160152325227, 0.031035997221366535, 0.06766956524863359, 0.056518197900825934, 0.04208422806714812, 0.05174717084775048, 0.03191011503428942, 0.07536229076645068, 0.04293405323199207, 0.06166678372650378, 0.03520062546275797, 0.02484064609293015, 0.002193156509630142, 0.052711901540357264, 0.14572372810254175, 0.05503282236355928, 0.046002882713031386, 0.014971023324065873, 0.01900724469563894, 0.09789485183935012, 0.03390227114000628, 0.031081397506979205, 0.09258302033788736, 0.03607851242826831, 0.04604086535231722, 0.04837433086527933, 0.023565044581529596, 0.08170278682824104, 0.05219485347850188, 0.02452456779147108, 0.03774484942456888, 0.008170861101168539, 0.019525964744389057, 0.015117898658518831, 0.04478920408855042, 0.07424703528804165, 0.05455443875924234, 0.05600319529372839, 0.06551010128591331, 0.0161834426915213, 0.1006635548847337, 0.010611346224322917, 0.008629991000728502, 0.034275068676159266, 0.006088343488367936, 0.09052698590582417, 0.17810916047423117, 0.05228918571505816, 0.061450865675484946, 0.03441251634109405, 0.03562483898994904, 0.026628084353081165, 0.014292033851116657, 0.047895050938090974, 0.010631505828050357, 0.004733736765751195, 0.023001611811078848, 0.05030926211827225, 0.03727354830311191, 0.01923802485238881, 0.028875552666103168, 0.03683231230224333, 0.020717829015226136, 0.04977671609770867, 0.05834783036862651, 0.08787277470072431, 0.07840028903897732, 0.05112146087471516, 0.02667800455744709, 0.05472365992083665, 0.04960200208569727, 0.05570444781633635, 0.02593585305036076, 0.009401350567537931, 0.02403004846024898, 0.03239378273006409, 0.0721222827691705, 0.023931066069992322, 0.08082724026133938, 0.12370158077007341, 0.09141118160539097, 0.017010643364741437, 0.03357575297535908, 0.051231494083279566, 0.037258096309679176, 0.02723827146955075, 0.2850961583035608, 0.19065461632224823, 0.1470786465271827, 0.07334498207895987, 0.10872958738717342, 0.1559012674636418, 0.18320663291360104, 0.2091264517437066, 0.10802451836606188, 0.12108454015105964, 0.17069094724232153, 0.12239747695745, 0.11998711153864862, 0.12073915707127703, 0.07777449479627033, 0.13111121381723112, 0.15917128312491602, 0.24100882481903801, 0.09873758686045486, 0.1804792986161286, 0.11460934284954302, 0.18806424322387866, 0.15230514349475985, 0.1587279786866519, 0.23039130584126521, 0.24630848318338397, 0.17453804161519776, 0.08585358909781902, 0.1596267990046932, 0.1797572301039773, 0.13240620884443485, 0.14615341149751218, 0.1268614483095946, 0.12514432351435387, 0.1019254549136085, 0.09711555655925505, 0.2227116574443156, 0.2458125944699972, 0.1837812754656038, 0.08690463874729411, 0.20602977113618007, 0.13443939087371673, 0.1092955501629941, 0.10450716355755445, 0.17725849644311015, 0.3834288140698787, 0.06459818086436679, 0.09551804873251146, 0.12055904980027869, 0.14852560275504667, 0.07069071724770531, 0.12118667499312472, 0.10343218132132485, 0.1626313039131703, 0.1589246028132977, 0.12396783462815708, 0.15667337683900712, 0.2042484788164016, 0.19307625089441577, 0.10185765613230968, 0.16342955220851207, 0.12723864702087256, 0.1004946937844638, 0.09582327348330329, 0.106511969690121, 0.1546746074792839, 0.42132666274424524, 0.11344488154375747, 0.21693048217604238, 0.14426443785909684, 0.14160117915561124, 0.15243936209909378, 0.14834632285900656, 0.11277849230194285, 0.1372932828962803, 0.1358871285112635, 0.15117551620689132, 0.12873514615479978, 0.15298947451576111, 0.09777610055020741, 0.12558753602206707, 0.11033252677730016, 0.196048672040624, 0.20111295755111402, 0.10113320508671385, 0.11198521591722967, 0.12594395842883857, 0.08659575975710347, 0.185343527926072, 0.18066567248634754, 0.0904809593433334, 0.06487728201694067, 0.1715551863514608, 0.11044622188614261, 0.12463459159217535, 0.15700510823197905, 0.16380999147170977, 0.18076138751160714, 0.13995735365296566, 0.10546350175695074, 0.19781916252067014, 0.1293099878896629, 0.12951238831925777, 0.10307112408261146, 0.20451521530987757, 0.13706667408827813, 0.09480166459275831, 0.09016328566377202, 0.16379240209296828, 0.2702508452198198, 0.08964852820481024, 0.13567368109380046, 0.19861961714923385, 0.21081737633193695, 0.1685960338481011, 0.1163153593698817, 0.1565301796842006, 0.1641262785321282, 0.11981897822190678, 0.10685415818325936, 0.11075679393064593, 0.11366665633695741, 0.1868933084751329, 0.301826844412473, 0.09821997189353551, 0.15837280500319698, 0.17768854756028424, 0.11038283577128766, 0.10449615487408255, 0.06593020092095099, 0.2008910984882424, 0.14495589349779392, 0.20546847383581823, 0.10145472452765512, 0.11676849271621435, 0.21556303055296022, 0.28591354347525105, 0.11969585257071642, 0.2015992701654473, 0.1629703131414229, 0.1301992014651337, 0.08875257305560574, 0.12298613125758788, 0.2276740379391178, 0.06659671273683349, 0.12902144853386188, 0.11487110743239043, 0.20731394900189293, 0.19283171562898546, 0.13301026917272998, 0.18100167864993696, 0.09726849069157917, 0.09231523430395512, 0.1618168298755923, 0.14240612305941122, 0.136215565726161, 0.20570049122456582, 0.2638023154389474, 0.11353363282978536, 0.14537877403199673, 0.1748221529827964, 0.15324871866933762, 0.11988411867810835, 0.18359382907229085, 0.1628595827928474, 0.16103738137791235, 0.18575157699806077, 0.1171190545503651, 0.21643765781435276, 0.23567070884089317, 0.15986329034691857, 0.14782918286660027, 0.1671026833355427, 0.12371622071030641, 0.22741015129272016, 0.13482899254848882], [0.03456686007519884, 0.04037207135209634, 0.04277347737262326, 0.03636367333632323, 0.06929966245567606, 0.05505881572683012, 0.018777163594119975, 0.02984187107593302, 0.04248558153067866, 0.0792022988260273, 0.006072604211963594, 0.03956292162559206, 0.09579479799515779, 0.049356769680255846, 0.06592360490392293, 0.07822519198300378, 0.007327893859661756, 0.026804592926055196, 0.012732245320934924, 0.007382821406222761, 0.01870791690664426, 0.06889131460939685, 0.032753143084025195, 0.016768655341659344, 0.02851615592296566, 0.03843745036471275, 0.06445408738668888, 0.02599037935837142, 0.035684567034965566, 0.06431534886360168, 0.05383479491537137, 0.03873802113136457, 0.04157492898464684, 0.04345416181510495, 0.04841802085960104, 0.017636152239696636, 0.024576441520043922, 0.02315545375759323, 0.03465221759172217, 0.030229823746448083, 0.03761112111650648, 0.0361953255149626, 0.05154678139895682, 0.018624327138006207, 0.055213469726544236, 0.05905202221906474, 0.026538419507203564, 0.015089952728650985, 0.02078377577896801, 0.029736227551174742, 0.05367285158905772, 0.014085577943572595, 0.009308383882706685, 0.06423788588313807, 0.0173130106075757, 0.0654791206902554, 0.07738374398961183, 0.011127341872892313, 0.027487416669065436, 0.04265791683968517, 0.05216796379235964, 0.03207878269735844, 0.056235576574240005, 0.015232744814467528, 0.0343307517769356, 0.05935839993218261, 0.011051194648438645, 0.04538444674483711, 0.027130174548214963, 0.06809835232073261, 0.020577855175361037, 0.03939357788992986, 0.032803927052525744, 0.04537224296420332, 0.06409694485726856, 0.07040641435812559, 0.05290377209143293, 0.0017948823604514944, 0.01665960655607764, 0.11129620409901105, 0.04187882840332966, 0.029225723795412533, 0.012183213088240837, 0.0419027456683257, 0.01757446109437414, 0.07804780432413663, 0.09295984366608244, 0.02099248877305898, 0.06142994764471247, 0.015231293077851015, 0.020574675910475276, 0.04415433936481995, 0.07727733437692927, 0.10315874155851142, 0.06317826754022991, 0.0384124567461831, 0.03571745518955492, 0.04823595623395616, 0.03897286155411313, 0.04536134536348043, 0.02631808495930126, 0.05798844703202767, 0.05784589722151718, 0.05480037979601372, 0.033953407508952003, 0.022977621767730005, 0.05533099144456848, 0.05526814542170014, 0.028782790909791668, 0.04100280303147532, 0.028989805103910547, 0.023129678729380813, 0.061327077358240084, 0.027607688642737847, 0.07208908817941143, 0.06922016551177348, 0.012512906687334182, 0.06408941038253327, 0.007950601725643802, 0.04238094158110119, 0.006319269201823421, 0.028701685181248094, 0.042587827455492756, 0.036092554819920374, 0.04997153608729282, 0.0855301620979463, 0.05288565411202369, 0.014565167178760373, 0.023711388442485083, 0.03291350060833558, 0.037580753391188, 0.04647771166937967, 0.045629648506761565, 0.026500724150889346, 0.0299413226950433, 0.04808342046735268, 0.058259546396232424, 0.043696996365343375, 0.09692380475180765, 0.035593609415715745, 0.0331828571225126, 0.05406725663511504, 0.03073205566784788, 0.01622711736408453, 0.023402903987575444, 0.05459300362535062, 0.04800344471849742, 0.08701832619525733, 0.012552168693453556, 0.028583313105627898, 0.07468271715145919, 0.037300307754307024, 0.008977177259962886, 0.052123944380230484, 0.014289535446873596, 0.022231042272441333, 0.03986711981856535, 0.07424024008815328, 0.021162960573189685, 0.03267222121658345, 0.034692735982037363, 0.019531335020738266, 0.10215111377258455, 0.04439191472145819, 0.04308442863064908, 0.01700985429417943, 0.0704129490881197, 0.0063539116977593835, 0.06087965902782256, 0.087482092841979, 0.08930859967104851, 0.012876296663777003, 0.022059789062627864, 0.03461554879322648, 0.005698038449120378, 0.037389809806500716, 0.03980690913815652, 0.07783865465992883, 0.03769407694738719, 0.02137718173945623, 0.03988679678690049, 0.050667132431220625, 0.04289178816120952, 0.04327155326703384, 0.025356129420200185, 0.10870651281889408, 0.013911304432117652, 0.06586493022980229, 0.031611304354643634, 0.01615702989511192, 0.021222943342441035, 0.05796482471088248, 0.0502465233477133, 0.03441311388967499, 0.031165556095901038, 0.06222616197661527, 0.06036223558288428, 0.07193547988971395, 0.04919422114448202, 0.028817711112600182, 0.005818062880632258, 0.0457678048030263, 0.0982057226581439, 0.06057842559511624, 0.04304023301829735, 0.04203846963543085, 0.051219991273096496, 0.09741887375111542, 0.036291369958029646, 0.056835948189179746, 0.018231617061481364, 0.01492659309728732, 0.030277872781058958, 0.06032867710136118, 0.09680257133779027, 0.017237510727418047, 0.05227832641873149, 0.015016569166384159, 0.06741789004374897, 0.028906604124894066, 0.08620271068667212, 0.06028948787359461, 0.032944052194755886, 0.05422633096215226, 0.06872493563400162, 0.009783693559227452, 0.044017772700998097, 0.07868605515649242, 0.011092503066925753, 0.009275361662730575, 0.053867062538742065, 0.05353064268767353, 0.05976947122103265, 0.03805942427847655, 0.05524764873928601, 0.013359424267565052, 0.02577115755317913, 0.022899865758635347, 0.059632299347750606, 0.07200903965220337, 0.030182303312504967, 0.06391544330624804, 0.0245416630435014, 0.05995576082157993, 0.039897184939153736, 0.06151999744977202, 0.032936314706720655, 0.03161116262837764, 0.08165962543458709, 0.04149526733184054, 0.024924515483660564, 0.07202398602760608, 0.022129112358896003, 0.06452581619903927, 0.029542541371718533, 0.1300903863363689, 0.0408169539314845, 0.03711737361886809, 0.016017079995494458, 0.03361771161097192, 0.026990989778911876, 0.09541851092850971, 0.060894743299051646, 0.014055206387814496, 0.07650714022137466, 0.08657034862065509, 0.056329721119254834, 0.05450681873386907, 0.039106314070522785, 0.02574418742780484, 0.047759932180446, 0.029792598215863112, 0.03004020166343018, 0.05217493902291021, 0.03937097829616359, 0.032649410948638, 0.03861368506125385, 0.06729064283952599, 0.030521527045376362, 0.056026373283877495, 0.03361032652338186, 0.01981572026476985, 0.019418011464539076, 0.0788856593651637, 0.035859844121601314, 0.03913057224464513, 0.039607726277843605, 0.012310161518173353, 0.01768429320485842, 0.03553902948155038, 0.029068890275553833, 0.051897791394543265, 0.06497738672600639, 0.05806966001288064, 0.05153350892566866, 0.07935027636948132, 0.0151622781319724, 0.05462633994137568, 0.03591751522054115, 0.06238242859141, 0.027822559068520224, 0.09762440748032063, 0.09220129404697688, 0.03436101224994467, 0.04595844961342312, 0.03159968471605211, 0.05773409434984769, 0.04334463805501019, 0.04318905708890769, 0.07302730839939849, 0.03236855162427791, 0.056095175640357126, 0.04475552303295943, 0.053974923888041135, 0.055563192694417896, 0.06808850809090561, 0.032177857018166015, 0.03134868175332104, 0.05548295647566838, 0.05558122640415546, 0.037211698194545124, 0.010772970666538083, 0.043480404156951175, 0.03459446605355029, 0.03447484525461351, 0.06746096716773126, 0.010764620308163426, 0.03189796296459052, 0.026351725795276226, 0.0642805761327186, 0.03799776952233046, 0.046471418257081704, 0.07873431869572209, 0.0673091515237766, 0.010607983098335324, 0.0453363364231923, 0.07084358243211623, 0.036545895009992585, 0.07032182292952653, 0.023461624626971544, 0.06429344640984651, 0.018766428787080992, 0.02993235946632922, 0.12145116684898255, 0.05801634795422997, 0.03646048769775418, 0.03455410854169919, 0.020353502496295882, 0.02221975971253649, 0.05714316476857471, 0.04047821666444502, 0.06501526211298282, 0.15749293770040237, 0.17295366453547634, 0.1525025949963639, 0.1429873846110798, 0.18432404875995653, 0.1846270978210434, 0.11172511374517796, 0.12436415489402511, 0.09634032154515867, 0.23414190377919908, 0.12350576869662731, 0.21149758579990557, 0.20077463780199328, 0.19360468302282596, 0.16265341321066504, 0.16737993055533978, 0.14673349327377735, 0.1361398762392421, 0.20052968884908384, 0.14262778293942252, 0.2168628672558454, 0.15566836141290205, 0.17279874623542832, 0.09072218510893085, 0.12334036265289593, 0.20427484756275532, 0.16424272389661881, 0.1824104836991718, 0.12007509673675222, 0.17742856796230042, 0.17873739853741663, 0.14791521454049697, 0.10463844038425915, 0.19615187940578308, 0.10752656887615882, 0.11764133499274332, 0.09630822246113131, 0.11182574705491144, 0.18694877324085082, 0.09030550222603545, 0.15201756940974345, 0.1306156162172556, 0.21403822447023085, 0.06554695777595043, 0.19584493861804086, 0.10374512823839342, 0.1248461467724654, 0.16758331157747777, 0.1260051152278339, 0.11011779233212433, 0.13051836901614744, 0.30890132931451647, 0.06759209843773036, 0.16226214146421802, 0.13439475859124816, 0.14708664448511216, 0.23764398279449633, 0.10444402259083525, 0.13840794082610838, 0.13666671490476978, 0.1319390484282086, 0.08849855362167282, 0.17690819507885366, 0.14716717564771253, 0.16714423594455566, 0.14535330926939366, 0.1455949487224702, 0.12432298532897428, 0.07485676466697648, 0.184220289811492, 0.12313111339725795, 0.1692566008216912, 0.1453377117192553, 0.15850402054286775, 0.15932529744121338, 0.16944853649024041, 0.15919566004266664, 0.09002197308525925, 0.16687190700923243, 0.17510065658678933, 0.09932301593043151, 0.14032751201621949, 0.06508185813624053, 0.21886405745340934, 0.11977900375401783, 0.20141072060552337, 0.19059668475341415, 0.1274823932157409, 0.15927678875384793, 0.11743467511428941, 0.12455689495489483, 0.21587734110653403, 0.23924426385952582, 0.20498651260089493, 0.18468984042204198, 0.13765149028791537, 0.18141525887673904, 0.13340469720142503, 0.12428839645919301, 0.14075120460362206, 0.19883597570080913, 0.14850476516350625, 0.13698347693970128, 0.27640780193671105, 0.11371805317579739, 0.11980652163225798, 0.1863064698033756, 0.16679725940189055, 0.13932959056429325, 0.10708873430567403, 0.07727321282389664, 0.049438392518148314, 0.14611956573301746, 0.11298912817672377, 0.19009390124870887, 0.18729060167266479, 0.10761966388071738, 0.1307111320596549, 0.1936781202112475, 0.1089783208144288, 0.16203124256383988, 0.30540131873661475, 0.1564367016356799, 0.1634041793764599, 0.14384345722294625, 0.23881431999466113, 0.2167431890003143, 0.17921284802498358, 0.08906194234206792, 0.1638697769733206, 0.19376851858631258, 0.12140707082806096, 0.16937707580866354, 0.20762628304862207, 0.1348589465863282, 0.2043466146795019, 0.2566503024389667, 0.12432981883325886, 0.19906517388599537, 0.20268487804118665, 0.15756930134469466, 0.176674124574469, 0.16978664173474237, 0.17362707114267736, 0.1303445436661282, 0.10773368074648804, 0.11180590537767257, 0.20688035855850867, 0.1612841076548061, 0.2020635500910782, 0.17263488002842473, 0.1890314905153167, 0.10142615710895869, 0.2008923855159552, 0.17562610097229484, 0.09974044191861346, 0.21137263685945543, 0.18047637216025786, 0.11372660271703236, 0.10592438791307712, 0.12429441791027786, 0.07313885846205297, 0.21859414935592683, 0.1164197541713234, 0.14038610242066846, 0.156480246073296, 0.13484085158955667, 0.1675655076941175, 0.14414229280044957, 0.14151235892167016, 0.13839735349099483, 0.12467085053363156, 0.1319507695734501, 0.19160839578797742, 0.13460549405745922, 0.1570937139613013], [0.025360147551363035, 0.02387141271854841, 0.04968955061368404, 0.05167389453779306, 0.0636927223944616, 0.05999198145863991, 0.015909452303012293, 0.017463395582331766, 0.04130656072389215, 0.010904596063248333, 0.06310117611240956, 0.02773956876368292, 0.05574510793291754, 0.038507110739667574, 0.022132057966964862, 0.046051709326885404, 0.006913624632532799, 0.019038401491519426, 0.06129428496464126, 0.0283435620592847, 0.024648369515254617, 0.0337446523800252, 0.04808372690252239, 0.01882989534116801, 0.04220038614866715, 0.04600544910757773, 0.04691646171493396, 0.025214889620040214, 0.017524673040175152, 0.04995593853715447, 0.09195591608482985, 0.007454012999416239, 0.046105331651145415, 0.01224580247165455, 0.020468823626757632, 0.021561500578818303, 0.08189242423301743, 0.03939319484596772, 0.06829772670302661, 0.008771243249817241, 0.04695844716362415, 0.024161495741516836, 0.05171224872972216, 0.024033825273715684, 0.025818643513165658, 0.08782418940456645, 0.08277574659235055, 0.046614952490574894, 0.03926596679394284, 0.032901488349682866, 0.0194225084006546, 0.04767457466392268, 0.011550382327949329, 0.016836321972791227, 0.05281654915081398, 0.012873556941837795, 0.08751682726846588, 0.04645973924667605, 0.026353102838320118, 0.05787859385412547, 0.06488089029106402, 0.0384710701332698, 0.017864335358383197, 0.059022037537708405, 0.011092360383049856, 0.03021994887310411, 0.03251178325304101, 0.08553077496828572, 0.021446187109235796, 0.022103210926176082, 0.02377111265706199, 0.04396402014179095, 0.010708464148093857, 0.019231419259261702, 0.025100223494753725, 0.07780633341040342, 0.03641864014489036, 0.010366259375587106, 0.025901974727129264, 0.046381219064876925, 0.006822723991072347, 0.06936635040948469, 0.035974236370454875, 0.029974865854807922, 0.029608147226334102, 0.013790783479869848, 0.0745697498261448, 0.020085398535875064, 0.0891899020080605, 0.020629382249148145, 0.029607775673690825, 0.15869531269756057, 0.05083257294890862, 0.03855786406465116, 0.043152882417123166, 0.03958026968663739, 0.012267704925409729, 0.008109540550879413, 0.02150574278446936, 0.020601149993918596, 0.06758334971363507, 0.026184927386742447, 0.04313081142402465, 0.0344182160352507, 0.006833590469473312, 0.02154058637848545, 0.1663824993996851, 0.005153556299891564, 0.024355478780043703, 0.026245718378753915, 0.06328547771479334, 0.11024199050640869, 0.05319047666665527, 0.032567117783811786, 0.08013504151735576, 0.0725466418530672, 0.06062431043134101, 0.058457626089934385, 0.07252221897004113, 0.07053453490258225, 0.008489366943737673, 0.04264032363050407, 0.007236993697006256, 0.0473278547607122, 0.03497961675748229, 0.09501458340955359, 0.010698616087827231, 0.08232783030478225, 0.049131884570083315, 0.02509106108317933, 0.018799876185855078, 0.049694878755197416, 0.06895556640360626, 0.07062858751704616, 0.019073559181584467, 0.015427846341363847, 0.043292750919898676, 0.025040893815457824, 0.0502009755901752, 0.04956109299054069, 0.03320834869819303, 0.07878533249059994, 0.03326994216730518, 0.05427359475664074, 0.03495180010495167, 0.0383259769108507, 0.00648614326153972, 0.050980259378951405, 0.06716761677976578, 0.012687376508819721, 0.016051495537882852, 0.01990074836348574, 0.05581254282245233, 0.07286955557403064, 0.0123832980170846, 0.023608516240792892, 0.1047736625637739, 0.06548739443983763, 0.03649225736397409, 0.11069807329124982, 0.03100165158450123, 0.03756333638222949, 0.04183270991028797, 0.04073642659932375, 0.01186240898189886, 0.062326473529420556, 0.04834502417173597, 0.017296514819346128, 0.07749251315310117, 0.008221702526263412, 0.03085876278008425, 0.021157034883095373, 0.06291042788014298, 0.057173701033236525, 0.02486629280141525, 0.01842032941508918, 0.07171758150141086, 0.02824768998600062, 0.028270212970974467, 0.032535233204403234, 0.053681531365239815, 0.05696388870297421, 0.037175174952755054, 0.039286026806240125, 0.07909676255357843, 0.04666782787910873, 0.0273832842527378, 0.02705294522456825, 0.04661312920131511, 0.008803791452890203, 0.0466722788499488, 0.025624009299903147, 0.020982039333771796, 0.03498289944423783, 0.02538490942829559, 0.044929735257380435, 0.0294378899308222, 0.015886529037098012, 0.027532332404066, 0.03165158334248249, 0.12446776828578404, 0.0314687832724303, 0.039101725203856345, 0.00576979790498773, 0.01630862528878835, 0.08691649778836197, 0.03650164960192577, 0.07058660589879559, 0.07395005364331507, 0.0069006092775042265, 0.036404375587740255, 0.05247796510135936, 0.062087637958146875, 0.03205091433389293, 0.03470216652438526, 0.04521892578791707, 0.04964268135447657, 0.025257777137261246, 0.046498024490691965, 0.009473869408060227, 0.02174556660916536, 0.09668967296038905, 0.07081519887452165, 0.050018845847056764, 0.01815885019999358, 0.0010943751535265737, 0.016492890501995722, 0.08763543300090298, 0.036627590626237855, 0.026419673963720282, 0.023328631763316454, 0.015167997935937058, 0.03192042466253042, 0.05458469923225142, 0.04466466883557939, 0.026827226993778062, 0.06694160552034456, 0.027231075988721945, 0.026038805691285, 0.032592421667950774, 0.03752399393687806, 0.06636899310134112, 0.012068975014582038, 0.06563310436303578, 0.01801791108934389, 0.05588273562851453, 0.03434215499568851, 0.0324551540336782, 0.06937713692745856, 0.07967369570847481, 0.05099985207761488, 0.019122996750558098, 0.04392552805403548, 0.014611254070675182, 0.010786130141857411, 0.03732489151579719, 0.029663288319904, 0.027593184683111407, 0.029474675557726336, 0.013727133064681004, 0.10378057512664988, 0.034655890983319095, 0.01488169938731458, 0.07443742345898383, 0.00669346341202336, 0.05708611037041392, 0.022549225400472363, 0.02515481108979833, 0.042828214354813106, 0.07196338081191625, 0.036054702415581674, 0.091005239275194, 0.05888361311067016, 0.015180867255455064, 0.049923939044557275, 0.021784054866481214, 0.02735672973006243, 0.01633921326438506, 0.018176782403081175, 0.077190590241263, 0.018964724900621562, 0.016197446778777148, 0.04063309282965718, 0.0617940194394079, 0.02377126970508647, 0.009570891570840633, 0.02798485288005923, 0.0893930532038212, 0.03943692314468565, 0.012164751326875582, 0.01867303692345177, 0.04775658820665652, 0.029131929735623063, 0.02802707198556633, 0.0572261895473686, 0.09709408311473747, 0.011324247536850313, 0.022726551772305564, 0.024885919974035314, 0.03955292034774058, 0.05590307143246455, 0.07182484147168937, 0.08242842531011951, 0.033675352066394784, 0.05610457170874842, 0.02932259944387742, 0.019076744192129663, 0.030314409429387703, 0.04983820614495105, 0.04238808152055548, 0.03448186645043954, 0.055012448255213044, 0.028821710091564926, 0.019042191711524804, 0.05893676812129636, 0.020291022280411377, 0.06754796411241255, 0.04446101968266791, 0.045730412051442175, 0.03551094469824626, 0.05743951439076374, 0.04043398657813668, 0.02424449562245319, 0.07959005422890186, 0.01621375679068508, 0.08596410494177573, 0.03298845848128681, 0.046485207839718753, 0.02925538097418124, 0.03925899922427151, 0.03605004077056243, 0.010907696804121859, 0.04804349962561842, 0.037202677509236726, 0.00822468548111858, 0.05513047559126731, 0.06526387296617031, 0.03841106246616091, 0.07585912942886353, 0.056335700435503844, 0.07430999239365901, 0.055803223362853455, 0.05210242113999782, 0.016782605802760493, 0.05696745867270136, 0.01342841623080594, 0.010159280613034723, 0.07114368971557387, 0.043468319119945656, 0.03553696870503407, 0.032310692833796624, 0.01440394780553517, 0.14771365680761878, 0.14798739534472266, 0.12805955619701456, 0.1067272557186023, 0.12593835066523285, 0.21127644685968278, 0.1515134682338084, 0.08653625004714535, 0.22343551860220973, 0.08526432958822097, 0.09047226424539283, 0.11671789260881564, 0.18730768543337623, 0.058622380958930145, 0.13092536088680068, 0.1794005548881908, 0.10465162475743603, 0.17863743938505652, 0.11617514229710064, 0.12385513543361619, 0.09811049026827659, 0.15719823899769014, 0.080330953182232, 0.1572283002878389, 0.2806839821559768, 0.1380627569291861, 0.15133878486531396, 0.10800089221447708, 0.12725666540885164, 0.216415579160375, 0.14626878433890883, 0.12194963727867413, 0.09999020956456663, 0.10264986765480812, 0.10273245193304555, 0.12358432335238304, 0.19926501558192317, 0.13401186784669278, 0.14997231383477488, 0.1123671490518797, 0.146949484103149, 0.07207702995548326, 0.17529389460480985, 0.09784363886161197, 0.1094859766383325, 0.24698694597088525, 0.11830237694084646, 0.1145218556085902, 0.10225741613295772, 0.10434939541042813, 0.15846036885294223, 0.31607972638260934, 0.18170035083688077, 0.07130053855719105, 0.11686478230741718, 0.09937875648780216, 0.22179167777780565, 0.23264107624849967, 0.14929573562356735, 0.12098170816898347, 0.18485289457584583, 0.1545403429096745, 0.0907685487501083, 0.13747271600990527, 0.14648780887646062, 0.10410549599797496, 0.10697339210779437, 0.20550910713932208, 0.12468791131170527, 0.21543319397155317, 0.18108781757614306, 0.1582997355369791, 0.1376596414634297, 0.2816027973688418, 0.11825571452537853, 0.16574733590166416, 0.1345419547250194, 0.11107706464827062, 0.08532195472188535, 0.13786339020777133, 0.1699468460414679, 0.15037219640949082, 0.16647398561960267, 0.2017444897923739, 0.24089700662561003, 0.1388061380073909, 0.1477515321945952, 0.26573711645699316, 0.17397786280320537, 0.14798324314817307, 0.10164613159553659, 0.300249990316168, 0.1200275379984129, 0.29553949953086917, 0.07730913468666616, 0.1484912820160389, 0.10733375986737591, 0.09475847255558738, 0.1615787450704844, 0.08023150730878115, 0.1196518408194665, 0.13576291501522064, 0.14095115355185925, 0.14520520915187177, 0.1256413766813855, 0.10423885658383371, 0.24374870763671017, 0.26589866907846543, 0.09220657239277517, 0.14382265027492278, 0.10285397646047416, 0.2225390425132167, 0.20115287073196905, 0.10634104015245553, 0.1557409099393314, 0.17013438436533176, 0.10208573582912646, 0.10758319043464239, 0.1461318691050814, 0.19753115942641614, 0.11740112812408518, 0.11995529590715324, 0.11540826530225816, 0.10261780687517698, 0.15575673731584705, 0.25122820790256223, 0.17290474216063179, 0.1647525247667105, 0.19634059750505034, 0.14962343739405756, 0.10962039442552675, 0.12523674436153906, 0.16881326573991007, 0.15676938297767795, 0.06714585988271622, 0.16261434272652672, 0.1309259890788986, 0.08243129047895632, 0.10323837639824038, 0.14748767619171452, 0.2441823287236114, 0.20787676315634482, 0.1469078548853436, 0.13670134207894727, 0.1610200831125821, 0.16133068580060236, 0.06556634746131397, 0.3275766223669052, 0.22051175936095177, 0.23795631684122548, 0.09430148578699558, 0.13696099992000288, 0.17926016161518712, 0.1468912460991452, 0.09802229056555418, 0.11267055051341174, 0.24858589404292647, 0.282756740287427, 0.15565092525174543, 0.1215652373409079, 0.11612841093371953, 0.20485820819533643, 0.14121401364043837, 0.11643710606280835, 0.14628315614836832, 0.2206188431310077, 0.09381786214127656, 0.11815009398325799, 0.16791381722977086, 0.108123404995328, 0.0914486816092845, 0.16534348499150048, 0.15785531261034552, 0.13854343113639664, 0.1578943064856914, 0.04651961284839819], [0.020768298887677734, 0.0563162571239856, 0.053554196060905536, 0.02605701751646496, 0.05251778635166345, 0.04610527419455109, 0.02487380812395244, 0.04658922342763794, 0.02429324562751478, 0.016171267639184674, 0.017179165471104846, 0.10943896182241941, 0.03161037547303544, 0.03267815073711738, 0.010590450218578261, 0.049407170604794264, 0.01884185397366603, 0.02436420452150126, 0.042058797778501626, 0.014573489766447775, 0.054824465600353096, 0.038169970765950224, 0.04390437253600648, 0.05840439447051576, 0.012352746430664294, 0.027870870488245162, 0.04386628264441125, 0.04325158518528746, 0.009735729751898157, 0.0415299098277765, 0.061488695097185915, 0.04359365493479756, 0.09269716743860515, 0.08886567827674652, 0.022398604853679577, 0.04508191479309913, 0.08286580022784971, 0.04537332697861618, 0.036732770667801944, 0.08974270339334205, 0.0632727108595352, 0.08116283273744969, 0.026491113577879248, 0.02952636350997754, 0.024017995981980237, 0.04887615292963963, 0.013256073260920183, 0.023736644446128802, 0.04239494949879666, 0.035508558334362124, 0.047999058865130916, 0.06318104843939505, 0.04243626845099273, 0.029855637675932342, 0.04652461157210412, 0.02033533663639138, 0.023693115330271186, 0.013722932987636136, 0.02360706450417638, 0.06349822416180564, 0.05538312755825539, 0.07253069956336292, 0.011171254990321976, 0.026984510590292277, 0.05997935249920815, 0.05105701372808507, 0.01692196294184654, 0.01233025408920742, 0.017765672809834925, 0.058373360248703154, 0.03252186497012454, 0.035010436474676096, 0.04234646379406895, 0.05978238746343602, 0.015957467821276477, 0.0599243818602014, 0.07881942340323041, 0.053501087015554796, 0.07559132041229356, 0.06060744500568798, 0.06429965172203318, 0.0354385034241263, 0.03880766235412129, 0.0830130729704134, 0.02694893729752831, 0.03200535891547559, 0.0199606430326258, 0.024546242334068786, 0.05614892436912464, 0.06195635730100255, 0.062115056244956876, 0.0417662977481321, 0.06654795890133228, 0.02019724354238039, 0.02372047041482743, 0.03593043912382376, 0.026535607964521455, 0.019501202867456505, 0.11360693212238052, 0.02726326125764078, 0.012847340455459011, 0.039186737980813756, 0.08085114220457693, 0.041888898629094326, 0.04846990416427294, 0.022644122626872796, 0.049770292450463584, 0.03891892896424379, 0.0718032454531039, 0.0874377593338009, 0.008437914563523186, 0.03147240112265272, 0.02888000172172343, 0.04512397302014213, 0.030926599865779284, 0.031219417822637388, 0.03061819010444226, 0.03752324700115189, 0.05655847497344498, 0.029821619541654666, 0.02299170246377828, 0.01285319624003023, 0.02147356709164958, 0.028778295888895952, 0.025780396573545954, 0.008719553382346227, 0.023944300238884265, 0.04664558068578763, 0.033734727710966146, 0.029159235024464228, 0.03993201512663115, 0.02910904094366537, 0.026133314128063863, 0.022289536915899768, 0.08615566522724206, 0.1086162600005346, 0.06791969295591116, 0.01090298823621725, 0.025510237582268256, 0.0635561672219586, 0.013444401612955958, 0.05490130038871881, 0.07478446894956213, 0.10432782237448039, 0.04053432877445894, 0.02154401079150698, 0.11187164338245509, 0.02818510826346615, 0.08882537439105012, 0.021541476955697424, 0.027966447617678393, 0.01854850167048074, 0.032436622366789854, 0.018861778005356752, 0.008933929681417443, 0.05012183104671779, 0.055351557074895794, 0.01489438484573076, 0.03470170687163069, 0.029009160315317493, 0.04071526725085513, 0.020006054809557337, 0.08120004928881124, 0.10548076171788479, 0.044970403034840865, 0.007173695682262581, 0.013252242821298782, 0.0695392564539948, 0.06925318390130997, 0.02673981636161766, 0.03855891743554704, 0.0019522699773416765, 0.009121649951163319, 0.01578500515015255, 0.041200855912099925, 0.004303346654670614, 0.043270277730639906, 0.06702516273024582, 0.01752546019551735, 0.0592964732148234, 0.026150342347400806, 0.04437011568957279, 0.02070066290006282, 0.05304321541541046, 0.05481081774398204, 0.03149098067003633, 0.033281510094961816, 0.07244693550972209, 0.006526958032120621, 0.041846901689085274, 0.010424790408221946, 0.036778249477426854, 0.04053024552582253, 0.07071893226595656, 0.10718251112848522, 0.03953662565759113, 0.023137661365551815, 0.04136145858454608, 0.0547118736581216, 0.10862236572129112, 0.017593873762375405, 0.0468196090491068, 0.043865198629998395, 0.05375140624481344, 0.05027232518900306, 0.0193675454225271, 0.01852537922170614, 0.028979520373527082, 0.10695980936889687, 0.03347799632578127, 0.016645960614926392, 0.045472880104376424, 0.038254952899390654, 0.03017654424653419, 0.054710946691733216, 0.0489743500797739, 0.04173597215764946, 0.06538912068091093, 0.020227124801866954, 0.04855413170110795, 0.08339450814791265, 0.030123762703771075, 0.015858004710847334, 0.03636060132374687, 0.05863014909048235, 0.07094220093060886, 0.013168121579163259, 0.023484810277999892, 0.0376619893546787, 0.038998035203304984, 0.06932465990464534, 0.034897817719367244, 0.035460099442711765, 0.01620220035434731, 0.033310200087726116, 0.04383741645142437, 0.02470128703862429, 0.05589328848967149, 0.048695616649403695, 0.0431261497790054, 0.04857934748513564, 0.038065985821548014, 0.07742723480107323, 0.014576497619160482, 0.05836228261731806, 0.04494895640340063, 0.011486841080289696, 0.06805075527799707, 0.04067640361045638, 0.002995919696273162, 0.06733731291587315, 0.024478968322998094, 0.02457925114750622, 0.11397721305970224, 0.034279902690961477, 0.07025220085896793, 0.015487475752560122, 0.0640330224808666, 0.025497984005919388, 0.0713455768662595, 0.053429959582224976, 0.055256941385807536, 0.05733225442048523, 0.008562413427317816, 0.06623694252583288, 0.03776610070358842, 0.008756388804965444, 0.020849590392542944, 0.03286870361696328, 0.05074851012097732, 0.017853073865896272, 0.041283807912541014, 0.08523527187325301, 0.02680941736475835, 0.031205285415654222, 0.01202624933343501, 0.024849076890536857, 0.007706447588955804, 0.06410348724814192, 0.031875602773300586, 0.016931106201222828, 0.019365685744090907, 0.039576324333827344, 0.022652402122114456, 0.006229106877599993, 0.05736837163567544, 0.048727934068489465, 0.028745708423816872, 0.008104448939012665, 0.022075526423812396, 0.0049425316354890746, 0.04309112040866767, 0.07121867440160244, 0.035168331026309924, 0.049037862599136374, 0.03315113342156814, 0.04848859670962538, 0.07386417518700324, 0.032815514132380486, 0.04969981236142978, 0.008283874391758395, 0.06139037537298376, 0.07153516830576044, 0.031166946545483607, 0.04260033384085663, 0.01773960666821128, 0.043076809886242115, 0.015691701386634622, 0.09524308445472872, 0.008169950414148551, 0.02834427069061466, 0.037402890757807804, 0.02475086824908372, 0.015818574165384618, 0.03056151491980399, 0.01132458365792709, 0.017257859937906746, 0.06688927405423696, 0.06347519172836216, 0.0792173677754979, 0.010701048416986821, 0.03666634318388758, 0.013270368461587257, 0.009896102597967032, 0.06586225658294655, 0.02740489176264213, 0.034403323286002686, 0.010231333097533114, 0.04231171404582359, 0.060042144895921794, 0.04886442412351889, 0.0403744806986182, 0.04886638147816543, 0.02309093766304995, 0.05118614167816216, 0.043805635293885585, 0.060932450146684726, 0.00993000677666597, 0.029772404138179078, 0.07364499743186659, 0.012400402845213971, 0.014648220685851431, 0.026660915051076203, 0.030197234366149194, 0.009505797079914521, 0.07031306654455201, 0.03669365421838818, 0.04639168382592259, 0.02716943655433434, 0.035895072674799355, 0.013161266049850854, 0.041404842143698085, 0.15218811590344677, 0.1862748456938613, 0.14467708345863128, 0.14717417769134045, 0.10739513883186926, 0.19179662359097313, 0.07241723428089773, 0.10186341711350026, 0.13397454404302184, 0.10712347639304017, 0.14181055098531709, 0.1957680387122016, 0.11186117862140942, 0.12944426778103077, 0.17406009468099765, 0.11367288463178182, 0.1283973550063468, 0.18570945748398382, 0.2181719429790974, 0.10995578771877675, 0.1441862356037863, 0.1466982225857435, 0.1847638904808029, 0.23599359957921892, 0.17530324087748606, 0.11498515494167806, 0.1959797088056803, 0.1061998578088899, 0.21499010403790783, 0.20864491951802086, 0.1596665283244464, 0.14357904963676008, 0.20648294278690893, 0.19252388617925106, 0.13376721000719455, 0.1272879601005585, 0.15221365727484226, 0.15964869379756913, 0.14773780389899208, 0.1307078378815805, 0.15370483209769573, 0.17250392495864825, 0.0695692717788681, 0.10984442917810333, 0.1519007256795322, 0.12222711432484851, 0.09230170519121232, 0.14610160863207233, 0.08698414335207594, 0.20395010289165283, 0.11489616616839364, 0.13046412999110837, 0.14298664916667247, 0.11439306856763941, 0.149180592608548, 0.23483072407543662, 0.0809437545737432, 0.19678966292450506, 0.2019973447726619, 0.12184732623638646, 0.10511111663354021, 0.1871044576288231, 0.11390870181663383, 0.10439906855143848, 0.1676366159752492, 0.13559552480376538, 0.14876454557862975, 0.08756145955093446, 0.10214081755088222, 0.16722128906797978, 0.11407273656298077, 0.1154024353731544, 0.09012488167612784, 0.07513244906740804, 0.13152252642377732, 0.16507046657704538, 0.09114216983077988, 0.2614101292865892, 0.1877837631130411, 0.10582602988447874, 0.17933955896765957, 0.22964444672388418, 0.11290457505252093, 0.28373163313634936, 0.143728191633859, 0.10958979687383098, 0.13877935557355806, 0.16259338256091843, 0.17584690283383095, 0.2313828687634199, 0.18092054993875567, 0.13507743486233298, 0.1990257510014119, 0.13025858860102393, 0.13399893628253093, 0.11701599274191166, 0.14463792104394207, 0.07785390747050125, 0.24598674157694464, 0.08744711326735635, 0.1971210572387903, 0.10076940525323154, 0.17448003343757124, 0.12608300338709547, 0.1146041487734164, 0.1894800503167414, 0.08644232766762858, 0.1814851260954334, 0.1238367416625542, 0.2962598366843116, 0.10586927554780438, 0.07274768630703611, 0.0832188212042374, 0.15801787646787782, 0.15304778912855735, 0.12190630734567681, 0.17193354185550444, 0.16793106952982564, 0.13738168944274226, 0.12190724197294443, 0.14422066359510347, 0.1092008387129153, 0.08350128548279886, 0.08714853049886805, 0.11081959015779919, 0.14284435599561662, 0.14536665452103462, 0.16898761202971782, 0.1284794183447957, 0.11203259845534641, 0.18816181218191502, 0.10469272537457366, 0.10281861384188938, 0.13050183683874148, 0.12416483413788582, 0.23526336456979477, 0.09213523428526618, 0.09940923912630928, 0.064635228876385, 0.08594139809570006, 0.12921047306829883, 0.1797770104941822, 0.1605047817311941, 0.25224534283962946, 0.10462677286517237, 0.1809207031563405, 0.1693417438335957, 0.08238049118869728, 0.2018592650851896, 0.12589216322427796, 0.0816063133759364, 0.25446704378531826, 0.1045946354767488, 0.17810260276159934, 0.15784742190472542, 0.1302581902353033, 0.09855544179557793, 0.06415740451625278, 0.11316167415990946, 0.1643973664050141, 0.2271319081586215, 0.07801867766125549, 0.18046135683694195, 0.307542166762775, 0.1425273947778248, 0.11377696533717456, 0.14279100563256972, 0.1958265984731336, 0.15407344296334252, 0.11791442235511158, 0.10799369864886808, 0.11586535932315935, 0.06825034416490985, 0.09746613371516429, 0.10899751897781126, 0.10857794794344133], [0.025539902421916207, 0.007861760903089758, 0.05434168082091117, 0.027607824623344407, 0.017010170305448196, 0.03228188409740406, 0.053884483378140204, 0.06108277958006628, 0.01647995893783387, 0.050710447042459444, 0.02833870314662495, 0.00560878872713675, 0.01612602631681629, 0.04328031348244798, 0.08952960837632419, 0.005632355985712381, 0.05902803983659514, 0.08665404372638272, 0.017957754035089767, 0.07068164676668183, 0.0106423057525629, 0.05220832513465036, 0.04438740246358418, 0.014875738265653773, 0.02837879635814217, 0.07612500024298507, 0.07548183878703464, 0.03128479959653511, 0.05326325501946192, 0.035157441086466276, 0.010796273145974885, 0.02665511193504978, 0.030695356225835222, 0.013843319874497191, 0.008055930675548172, 0.07893538613232874, 0.06515161044174625, 0.06227412291111485, 0.05463987671499772, 0.036885371551878994, 0.0434812315319094, 0.042329594537976294, 0.023213379580767888, 0.038747670008770885, 0.035292770518290426, 0.07587001553826755, 0.013583926333775444, 0.04583768734347917, 0.014577738681597816, 0.05211600004845569, 0.10643662494276801, 0.03085087207446416, 0.05035975114292195, 0.025291663121371984, 0.01885953336773861, 0.051740969366003434, 0.019464493849344795, 0.054833064937303146, 0.0454112368395492, 0.020835130482972152, 0.016287659377520605, 0.04775726619446951, 0.025483788396682472, 0.09145147783020813, 0.06611439910146498, 0.03941906563517067, 0.055114452862330986, 0.02403635910952524, 0.014148900856173808, 0.04360684313841405, 0.047243014353537754, 0.044664025321723, 0.035175735266098095, 0.03778010096040465, 0.03446816113747416, 0.04181184933610982, 0.04014334048054392, 0.03450699413435594, 0.0503984539048566, 0.05892831051061231, 0.060709066568843784, 0.01715704276707144, 0.021629515779955734, 0.03452065348204586, 0.006078017101953588, 0.024950650573197394, 0.02350067021325231, 0.0036344424898420735, 0.033410224357559797, 0.031234000306276065, 0.1020622092689718, 0.06378003343519184, 0.04706372296617878, 0.12492610336912256, 0.03784506521638363, 0.052930573677463885, 0.042482321826560844, 0.007148490910748801, 0.018338606985766562, 0.038927336779212764, 0.0774360141686855, 0.05322323841673713, 0.019442436262784947, 0.05176603576288589, 0.02310647584137417, 0.02700052565834936, 0.00414658734957958, 0.04591783546211739, 0.05940418134653761, 0.07788803668752795, 0.06625811719606, 0.07101834240940309, 0.05458316322596324, 0.030194177675331314, 0.010292430524714291, 0.07394184118076678, 0.020734096892298232, 0.01739396694897404, 0.008186992997634075, 0.06254547508433461, 0.0802667396924188, 0.0515022678601165, 0.05128705460998801, 0.01982322601120799, 0.04104245191199645, 0.07108805641051262, 0.053021397231326955, 0.040052765905256235, 0.05443426254656046, 0.024152214586314176, 0.09104725919784078, 0.05145002449412019, 0.0398952467367053, 0.021415733199025837, 0.021799562401288462, 0.023364942415707537, 0.05941910473930259, 0.024477164185936415, 0.044183025527144634, 0.0633391958000439, 0.0096217138437374, 0.08596521576926594, 0.05116509341244256, 0.06441176102887239, 0.01351076685222647, 0.04292191456883185, 0.016594724654550516, 0.04248844286907585, 0.074207260003013, 0.024276675145712592, 0.06782669754278275, 0.02203678152704191, 0.02813130590854393, 0.025100493540747032, 0.04106470293575718, 0.021458963540592985, 0.03560939082695592, 0.04319963293270238, 0.042913296079683694, 0.0439004386745153, 0.067083538630076, 0.04401896396772035, 0.05520520746828087, 0.026652424881655364, 0.07479300316903861, 0.02952835916902029, 0.05797286863408743, 0.028151367836061026, 0.02208212818649988, 0.030341130576186606, 0.07888140757718394, 0.0224684797332532, 0.07366169814861591, 0.04825046593924204, 0.02157675338939073, 0.021421814021924813, 0.04855682833060142, 0.046052061727330576, 0.01820073988769324, 0.07499233158605714, 0.05185089149181882, 0.03381440085509131, 0.027101501792428956, 0.10903791479405858, 0.01440805690963903, 0.01253978105171794, 0.026263196674746372, 0.014455851220015078, 0.022990628025464477, 0.062093912218246734, 0.076669420626375, 0.03640539831511917, 0.08010840464022853, 0.051464472912372126, 0.07867641777040497, 0.038742736402538516, 0.01807348885303063, 0.036778383542813604, 0.02178207452919695, 0.0338320093860309, 0.07635340169673005, 0.05412354494535154, 0.012809019779876597, 0.018970386290381995, 0.04012695002940394, 0.028194406655647104, 0.05781115513415106, 0.019327950168160662, 0.021317737146971688, 0.018804365461091363, 0.04110329461494281, 0.048680057403661554, 0.07035195316758848, 0.11451570392255822, 0.013805644627990983, 0.020870948923871886, 0.07489991073887195, 0.03408518612324711, 0.04784749603019126, 0.03471070457430136, 0.04270115867257119, 0.03360837682961457, 0.022555570523705215, 0.04841867969521592, 0.00861059173926591, 0.02551855346668632, 0.024926729477761735, 0.014117225993334526, 0.049078335024176106, 0.04205720814605875, 0.04238147784264819, 0.1164226882880734, 0.04763308334194365, 0.06056850858693642, 0.019786668295461326, 0.08872169205137799, 0.07378242594460327, 0.053435559684951464, 0.026720024480093873, 0.04634082707906923, 0.011329203168110502, 0.05433234220911419, 0.018683482532299334, 0.012135537521493052, 0.024596848187126943, 0.034792817708465366, 0.08546770294947971, 0.024275964599162824, 0.028010401912333987, 0.091396258212626, 0.02362181169671878, 0.037982899755720174, 0.04545603000048188, 0.015946618101048856, 0.022335958013671543, 0.07173224442428158, 0.036380757097034686, 0.07055373306596471, 0.04309448353465527, 0.07786980379493007, 0.014457356582786289, 0.00564838637552795, 0.012733540967136863, 0.015672603772292217, 0.007932550778927943, 0.052988072406620755, 0.018125027418136597, 0.048780376617346084, 0.03684039069940487, 0.07012216509470055, 0.07701377714833907, 0.03152264116872703, 0.04587780736807374, 0.05565183672813639, 0.04833614521269356, 0.04574853769173065, 0.020534816355774962, 0.03781467833886704, 0.03284359508524499, 0.04001630778093973, 0.045003973007682836, 0.061714419073635535, 0.030527523598603667, 0.043988952473286665, 0.03483907792777304, 0.021610779184547645, 0.0247918845965497, 0.028391032697512742, 0.04088284132341224, 0.07023257368634786, 0.04967353937606658, 0.045872915896677205, 0.04986712213365301, 0.02840689837842459, 0.029325206058039784, 0.058510842387594526, 0.12111829398500344, 0.03471200692377264, 0.048104104841308254, 0.06938253784732473, 0.051460121532962214, 0.008680480982988112, 0.06911693516397668, 0.042973047107337944, 0.031663427061791864, 0.018909566570073366, 0.014651974516680405, 0.06387648007441914, 0.02937574870884419, 0.05665276890560504, 0.05896278829764455, 0.04652030615796966, 0.012549965233061344, 0.039751130276389664, 0.05181071401062993, 0.028986708193476644, 0.01692188250261449, 0.04854616055625582, 0.04354897668705352, 0.027496159647501288, 0.05217424188289912, 0.026564357329099893, 0.00983980662685128, 0.054378862898316116, 0.057446849682638725, 0.026266954336014968, 0.011740375006000602, 0.022026939212434718, 0.01235950907181588, 0.0684217180335714, 0.025166133869319193, 0.0584045630098591, 0.028578042420708848, 0.05128279899156863, 0.06389268283401767, 0.01563391250167643, 0.012957287479131933, 0.028540291523020116, 0.015044977621836288, 0.06165538816863011, 0.04746210400856311, 0.027891099039885788, 0.03965766754962745, 0.058758327091533336, 0.02942538929111775, 0.05088018531340265, 0.02278169095065565, 0.02717993195889698, 0.08418033049712259, 0.01492809079917929, 0.019206898700025295, 0.0077977959130470075, 0.1266814176473887, 0.2276123065741793, 0.0978736388647268, 0.13362123961410216, 0.10924594596989694, 0.12351189740002157, 0.13313016193287988, 0.15364164516570109, 0.06712579603997931, 0.14644003563350247, 0.09653391196362435, 0.14546976995564279, 0.23916014740543984, 0.0959381024022737, 0.1935104235646225, 0.07771028896733638, 0.16250928142859092, 0.13840073959962015, 0.11325388050247585, 0.19811888676016562, 0.15762199287212666, 0.1492851329666953, 0.11195792020448755, 0.1397125272741241, 0.17348954303851052, 0.11967022692964924, 0.17438388940307403, 0.23511376291994127, 0.13635289464746753, 0.16143384720048598, 0.09548778825950238, 0.09964449706697658, 0.08476097151757249, 0.0961624818944162, 0.16250845405363268, 0.2154240162382203, 0.21432869436760105, 0.2728936953410026, 0.09025632704217589, 0.11798245862366692, 0.18166713326448397, 0.12332592189552323, 0.1336312140788763, 0.14111298196498426, 0.12188812807923365, 0.11560617645661678, 0.17667476808832538, 0.12129149880380401, 0.0867306218752938, 0.10682595082588735, 0.1877834260343544, 0.09265425885396619, 0.2476857560536554, 0.11401116607650635, 0.1619226112961769, 0.22736512064453096, 0.12820279165621729, 0.31234590577021726, 0.12322253833014159, 0.13092104015090775, 0.21964738235598613, 0.19500731340339109, 0.07574080714895841, 0.16883891436361498, 0.17771226564241996, 0.12985259264467225, 0.1283399213946635, 0.13816023395667154, 0.16316943471470188, 0.1188758320565666, 0.3098534540303292, 0.1748299364361071, 0.1390776242459974, 0.11791153420363704, 0.12582236495349677, 0.21156046629673053, 0.15960545579512275, 0.11941105172398592, 0.14767640961274026, 0.2215812487467643, 0.17469561057946376, 0.13633006522732397, 0.17086757647414363, 0.1720992619952848, 0.11462323202361023, 0.08119076430316895, 0.1041984454458279, 0.10366287337796343, 0.2758189254710751, 0.18307831318628404, 0.19890918306285338, 0.1420651220025555, 0.14956550582522346, 0.16827963953537328, 0.2131711048704963, 0.1412652036355388, 0.18125778184302394, 0.13451454409908864, 0.1265518415358759, 0.16874390413924573, 0.12229242332039342, 0.07844959445778402, 0.13625121945815702, 0.14897972435480164, 0.12732541413917658, 0.12032219073584965, 0.16326020081197062, 0.12078618720894861, 0.172909292722902, 0.1018703119048188, 0.09984979330892525, 0.1255815298927407, 0.1349028740679064, 0.13995782862747871, 0.17324027334970815, 0.20870442922797897, 0.11590071428086489, 0.11677837525043758, 0.10426173196925272, 0.2428200252113804, 0.23269920700019409, 0.14012224641778778, 0.14379574526702205, 0.1371266587727493, 0.16072665611582418, 0.09500704510437866, 0.15586149217861314, 0.15964953649428584, 0.2789989258012464, 0.17939752118001062, 0.15018193081261652, 0.12046548748208631, 0.12249275531259277, 0.14626003561481354, 0.08056202828283272, 0.10232493912260379, 0.14919770701277643, 0.07928967881467074, 0.16050514945339772, 0.17982073879290014, 0.12257052089778647, 0.18268624470839578, 0.13233238861205118, 0.1871800705069496, 0.14056699110134957, 0.11534969021956767, 0.10070884600281717, 0.2190987408281334, 0.12957022795754095, 0.1333092426460597, 0.11551393180965416, 0.1358544165568967, 0.11655007338812275, 0.1707257735993593, 0.15721346882562484, 0.15534609886667422, 0.16147294832814127, 0.14293927428943498, 0.15571437265363433, 0.06879870990110983, 0.14552996914473273, 0.13218868583921464, 0.14019882456669885, 0.10739546058879745, 0.13500009062549762, 0.11924029838654304, 0.11093450334644127, 0.10411717883882024, 0.15487873926758766, 0.19299921309275014, 0.2171681073283957, 0.14134878382807778, 0.2878237683926859, 0.15162606783691915, 0.16139843861662573, 0.10545116008049059], [0.010418174281385879, 0.03223549364314925, 0.031108928791758035, 0.019406702091556885, 0.09088815039684696, 0.03839888932904409, 0.024452798759504676, 0.03422315855841002, 0.06304957626026965, 0.05728673347602448, 0.024038119196531274, 0.03639403723120209, 0.012741165457203264, 0.05721390532750276, 0.03828833135025155, 0.032018378579748735, 0.04862548129993582, 0.028155431932499333, 0.038843289273039955, 0.05925957842039005, 0.03524755600899939, 0.05150388430563673, 0.05547669753732701, 0.03570884819172564, 0.02063502831715009, 0.164045027246879, 0.03407605818562931, 0.019344484260786447, 0.017593950371167833, 0.02768245307848819, 0.01779822771617722, 0.04119601423641847, 0.05117687201427837, 0.04301415538535484, 0.131797551988594, 0.027539432123904268, 0.02990466347264667, 0.041137944771758014, 0.031733041471471234, 0.0320695934727067, 0.031242471323498798, 0.033042291479725996, 0.03138047248695887, 0.03256791834569266, 0.03175460301610011, 0.026732523204578508, 0.02955436210839018, 0.040655228940229264, 0.03809425063551434, 0.048921244864862774, 0.04184920761373736, 0.043899212933836446, 0.04575061379000545, 0.0669788756978608, 0.016875319678576726, 0.023466136884845556, 0.04377399969305243, 0.02043915495667006, 0.057821309629587404, 0.03463580032750484, 0.02717083466479615, 0.04296365103894665, 0.035030255169277234, 0.01866699823538863, 0.027920888368821437, 0.032386834312590866, 0.01685372557521107, 0.045361314719963464, 0.05087925834701427, 0.1071979554610387, 0.06481447812890814, 0.014799509644358149, 0.018612000783304536, 0.025329820045660582, 0.05448968517744253, 0.07254044420175976, 0.04536028816214493, 0.05837876116856933, 0.04416708706787998, 0.07686544720443987, 0.026185325752463073, 0.02020378784847356, 0.050066787629358234, 0.012407949768878039, 0.0043255105359299535, 0.10045690266715904, 0.013762973530608562, 0.014405868771005303, 0.03283144110032628, 0.024130942239876718, 0.04803124987970918, 0.031407930993384896, 0.09245636302136606, 0.040725506015963135, 0.050712526971173864, 0.03001217816716, 0.006826657852563527, 0.02385102903410312, 0.0665019476606, 0.02972253564474804, 0.05483440942161026, 0.05397800356149674, 0.08065464831287823, 0.04405659420656101, 0.034801478332449357, 0.045367033566318216, 0.033010065991191134, 0.03176478240939398, 0.02883628108388474, 0.06086918660589765, 0.018661662432996017, 0.049788238060089855, 0.011785047508085207, 0.026577172064853292, 0.047858144652338765, 0.03323292862924357, 0.0908353056518301, 0.05452874033982235, 0.06972511704530447, 0.03479467164124212, 0.03791199831832801, 0.03473897321870731, 0.02648874445097341, 0.013694552302871262, 0.012199525015368577, 0.03761882413058512, 0.031023946658317602, 0.02798121013197928, 0.06364389195016797, 0.06444537696698982, 0.012768900712891933, 0.06004463468167571, 0.04143715190190462, 0.09137653144857577, 0.01647291475937011, 0.03997567830787551, 0.06076352775938088, 0.017368601777801113, 0.03486161240406575, 0.02013867995100877, 0.04978421226804776, 0.030441541720422047, 0.049591571798608194, 0.05542696693972234, 0.0030796861439387527, 0.058027620938035755, 0.07049856707453728, 0.03262663898508876, 0.025946599348718603, 0.006193874972767287, 0.03422235799652915, 0.05023936042562128, 0.03973251817026927, 0.0451598527480758, 0.03727910627100257, 0.028976013606053688, 0.024639911904570558, 0.09996019423969331, 0.06097991312403352, 0.028054038280501004, 0.019468017853796482, 0.033743698600559466, 0.07809576142819659, 0.03558359281610578, 0.08979583925177013, 0.030422715109682856, 0.01569034062295912, 0.09822584778791475, 0.03688783835499518, 0.017379380634895737, 0.10000163193551764, 0.07054287760007767, 0.05300397256148919, 0.0055312955819611116, 0.07471666250738405, 0.03504518239248184, 0.029592417526028814, 0.055311597928765326, 0.008532544616760026, 0.056298610288649804, 0.008695779758835993, 0.02797247098398305, 0.022169161520357576, 0.036857811538803006, 0.02866567138792767, 0.06703000440592728, 0.009618212821923438, 0.011272307733194003, 0.04138003621670989, 0.0500687143404878, 0.01964955579399342, 0.03914420860969732, 0.031661594196433024, 0.06158038816084305, 0.03729510984774079, 0.04348298204281638, 0.00767484741968914, 0.011065793411445715, 0.017231906794251937, 0.05005810785317614, 0.04564670928483529, 0.0873466255143285, 0.05757029326031766, 0.08539923767168676, 0.05146156560869948, 0.02163832196064534, 0.048802972380672736, 0.044678596314042814, 0.02889320333187859, 0.04553248174488545, 0.06720135529195109, 0.015313435897922084, 0.04540270262007271, 0.0226742624410338, 0.007297634344262582, 0.05071430046471858, 0.0404695330578233, 0.047395159415299856, 0.05543892940265998, 0.04082936455585784, 0.05540803307667375, 0.04728635577785392, 0.012445721733984689, 0.026578076048603943, 0.04262983588682067, 0.008900099238681217, 0.018667842847325148, 0.10320998517976654, 0.01708857748927849, 0.06488719519468085, 0.02690329186377987, 0.040581611721145536, 0.023209248451636206, 0.07157996146669311, 0.06062424531386745, 0.060581482285934116, 0.09882993109884763, 0.04576677058432852, 0.009451789796472558, 0.01776860692658492, 0.0372089555997762, 0.03312774475723986, 0.07108150635876002, 0.0318699318074411, 0.06798560716091626, 0.005393422259423401, 0.0900141436666731, 0.024386509171416684, 0.05707512466957974, 0.04466821199222919, 0.032356612143977996, 0.005184511040082021, 0.02377067407172534, 0.04003171763953663, 0.02290866619366552, 0.046782170332247214, 0.017006123445988182, 0.0521752761015969, 0.05729924752226761, 0.03169572149823991, 0.017523809276040525, 0.10254318225047282, 0.033172806048946034, 0.00496005398153718, 0.013244782082526194, 0.05062738012882972, 0.0474069073736187, 0.01972730605742864, 0.0334269940222223, 0.023783739701273943, 0.04121658369718541, 0.005460660838927593, 0.0381205887383511, 0.012486006467482977, 0.045504040730696534, 0.00932819683164839, 0.037093517640906, 0.03789692936885742, 0.06693571430420683, 0.08270254689118556, 0.0639803501056327, 0.025958138548078078, 0.014243118179541443, 0.012338632218269332, 0.017331053893412315, 0.128801443403767, 0.027410761911361933, 0.01076756495862238, 0.008536201728988559, 0.0445404093742611, 0.030366662371483062, 0.05889653318351316, 0.02391819770808422, 0.0811284736940457, 0.062443719455792066, 0.036952622580311956, 0.014143890641149015, 0.045099879554923505, 0.061802917550648415, 0.055192766200390556, 0.04149249792399426, 0.05684595329747085, 0.024240893093989264, 0.023116000229492787, 0.021167116600178906, 0.023095296703339107, 0.06125195094594552, 0.032504229626107606, 0.04050193857702036, 0.04035376951158528, 0.01213829352280065, 0.024535800555660844, 0.03907470145232735, 0.005335346570298557, 0.09633378681516457, 0.06037992455305592, 0.01234801009207243, 0.05354562736747246, 0.04997306060226214, 0.07780143044768803, 0.04405950534067327, 0.042247676756232984, 0.026582042468831907, 0.03942606384835897, 0.0310297267917063, 0.08055226066179814, 0.06166790987575247, 0.0348796078094071, 0.018824011785909534, 0.02905301693376274, 0.029235937662663, 0.016095124245170626, 0.030607384434270284, 0.03744601384706555, 0.013464792958280493, 0.012640165382876031, 0.02887997299342627, 0.005287893647853766, 0.1510260371311057, 0.0048087793871790414, 0.04924359934164151, 0.057846812696586696, 0.12784443104699736, 0.02005138040159739, 0.05090412939147604, 0.07414376663584864, 0.017748799723302646, 0.039230807188657985, 0.07394145813680465, 0.018481905647223035, 0.05585095064053613, 0.02920389986566959, 0.10149086089504343, 0.1628554305962978, 0.16916892971963654, 0.11632358715418847, 0.2771714690231508, 0.062072557517357414, 0.09483184845697495, 0.13845091835866052, 0.10714789927606622, 0.1982812820783546, 0.17523818469095617, 0.10125205596728672, 0.15746695199801078, 0.10847687030271178, 0.13135006471026328, 0.07270071745639847, 0.18966355901812354, 0.22237653994271833, 0.09321330385583063, 0.1202521856213289, 0.13451311917554948, 0.11137613771303047, 0.15797007258140272, 0.2527832744583007, 0.11501693226877721, 0.32176388427615166, 0.14625450446000024, 0.135921188780377, 0.11725880430951235, 0.10030461970957057, 0.08191239614520343, 0.09188830116463285, 0.18548713876835762, 0.13386497814809123, 0.1416064345187718, 0.16926338836070032, 0.11747622006242314, 0.10735199275997379, 0.08564384188503028, 0.20972593086621455, 0.145113401175026, 0.1620334488970618, 0.11449037705578151, 0.20888449053370187, 0.13164865513963084, 0.19673006128399603, 0.1470584064842232, 0.144921756619888, 0.13002965088573196, 0.10810105821057674, 0.10648810605127966, 0.1803713261840805, 0.1765480571456494, 0.13803903884705038, 0.1958504391293372, 0.09489492047578098, 0.1164706530530126, 0.0875415106213862, 0.11611940940060925, 0.15722306024643684, 0.1907247286890784, 0.26781002780602825, 0.1611443425739004, 0.11329904904649143, 0.15518152785878028, 0.15123836606019928, 0.1624953233066105, 0.11569869689523213, 0.16133485331891045, 0.15851249347531027, 0.15137840693275775, 0.16440924076784044, 0.15134883593888054, 0.14436295676615932, 0.2143889088784495, 0.10702789926360692, 0.09107604878203523, 0.11621584454851767, 0.09522476729245917, 0.2086060175732259, 0.0819926438552718, 0.13435398739191795, 0.14184756835381832, 0.12425579175713564, 0.18969452429202296, 0.13727328800145658, 0.11593569385548753, 0.15675999073972627, 0.1680963759821269, 0.15526644104430753, 0.10072776071366765, 0.13494605078331887, 0.22156991064548495, 0.15241270223932882, 0.15282473496852383, 0.1374866434883687, 0.1375498917073973, 0.07361339630499002, 0.08154362440109253, 0.1006988485554053, 0.21123576759090348, 0.107241285394036, 0.23673469771540936, 0.13622763927184767, 0.15480442873893246, 0.12646112906476184, 0.13327864509436393, 0.14002633220966787, 0.12293703268252074, 0.14681908061667798, 0.13671848712669266, 0.08642907434653851, 0.1508903169944402, 0.1161914369872501, 0.10896329016935442, 0.174022464442157, 0.2193881382024096, 0.1380362349652475, 0.16963757634643586, 0.14207255305542102, 0.11961178974278512, 0.18534582618984485, 0.16934382759274977, 0.163701115055911, 0.10794572622304964, 0.09501085256136234, 0.2071872840244924, 0.1844469599065281, 0.16483235112842054, 0.158508004200074, 0.09235969804708036, 0.11487050222293024, 0.09622866423019479, 0.19406050533777286, 0.13480231736696538, 0.09150839050210292, 0.16155406171756406, 0.22078275530328675, 0.21657084986086816, 0.12093308456842938, 0.15382261045517462, 0.158827937839012, 0.16576112548430122, 0.2258833227378707, 0.23165898217308908, 0.12669451775089388, 0.12383819722961034, 0.1836566942473573, 0.08454737854340384, 0.17017837313394393, 0.09981214774832611, 0.09973450473720029, 0.17229734168898675, 0.15897479689409658, 0.12855929833266044, 0.1310305294370459, 0.11198287168818136, 0.17678168331903799, 0.14238242029903397, 0.09349965986104743, 0.09367544639615283, 0.14886822791830187, 0.32985797091837854, 0.11256628594691716, 0.19163868690450347, 0.20216943876397228, 0.2243648138978789, 0.17253763282731657, 0.09712458873588233, 0.11224740184843542, 0.0919642664432045, 0.13216331300716247, 0.12375395820145646, 0.09259759133020717, 0.28050462565114426, 0.1371449682741396], [0.04166048951447011, 0.027873846739830992, 0.07063299252261078, 0.026883637878082456, 0.029566828274138035, 0.002039103170729152, 0.03692616956428655, 0.07683795230883746, 0.04390522672404205, 0.01905510795392817, 0.057453204381970636, 0.02731551611495595, 0.07089358499093402, 0.005023684765722964, 0.041885501029150146, 0.0749076329051487, 0.06938609249529339, 0.03515791606097933, 0.030060696430624496, 0.011307326569822768, 0.045871464160060695, 0.06679637057165946, 0.08523878821682546, 0.059819175005559964, 0.05446241244733815, 0.08925756289353294, 0.03094672308033032, 0.05986206826844043, 0.04661252399185493, 0.07381448672423441, 0.014536759680918148, 0.05822049123385261, 0.022552190160739328, 0.040168353251271674, 0.0722084753215313, 0.02718880517227996, 0.03551700445372732, 0.044694921647709225, 0.02742201574296961, 0.07145379444644337, 0.026739335641445174, 0.0919846673646281, 0.07458510988902661, 0.08978470033335109, 0.05204327149136413, 0.05704881337982032, 0.06086594222353832, 0.04301392938941718, 0.029861218626460725, 0.009323873222925732, 0.08345021806176632, 0.040750147234047615, 0.058359972862226356, 0.03964571657800867, 0.033478498113371676, 0.057516931405951904, 0.04176413738018563, 0.019171626096771612, 0.08413205929701367, 0.02221459244948722, 0.06601031839607224, 0.03269108996215848, 0.04548983363014075, 0.029591513542278163, 0.02382629397024791, 0.05955085271008073, 0.029198385947834582, 0.013781608619366684, 0.023054544656207005, 0.004113154793759027, 0.018848461482012947, 0.06516836478465027, 0.037754839211101496, 0.03999789868811927, 0.055272320600887465, 0.048881829641158545, 0.025830483402035413, 0.04119602572773734, 0.038405918185749365, 0.014046506501824386, 0.02454778791645602, 0.117355530570832, 0.02724295992764735, 0.06071295446505951, 0.03772919441783621, 0.02386875630867097, 0.026538231815662117, 0.024645713105377172, 0.03397489244478845, 0.02727099874567601, 0.03673962715472426, 0.006403203231222447, 0.0397021159709942, 0.04143425991999046, 0.03929675203718005, 0.022749385022888743, 0.0362061005416176, 0.015833505219028845, 0.05070777339560371, 0.02187077218907014, 0.045681907194516355, 0.022273083262506033, 0.043668444268405444, 0.014639677847885798, 0.028149582851197452, 0.0052003925215573085, 0.006647339652127196, 0.05134723464687986, 0.08721604582763488, 0.053462932006486004, 0.0044873312881757174, 0.046865562833244764, 0.07023400627076626, 0.017779498781648376, 0.008119984244507166, 0.022918824519541477, 0.051181993312052185, 0.056122352609470974, 0.018875395218210838, 0.04920470122728617, 0.034072200932930556, 0.04733268494507478, 0.021617557147457715, 0.0678355458583082, 0.04577232089133994, 0.03103576356454963, 0.04407216494362201, 0.02636892446917632, 0.022288293938242623, 0.040210116534463825, 0.017871756835149664, 0.029642330069515496, 0.07708411934154649, 0.04037010633657056, 0.017335037550618573, 0.02425866250339295, 0.045238717669440855, 0.03513666095152017, 0.036797964750158216, 0.053941097275744525, 0.05754421179693553, 0.09837839887627671, 0.012706621595087552, 0.03614302086193235, 0.036637737460794954, 0.08727685022618502, 0.06427463129042618, 0.03199370480292747, 0.07615428778433031, 0.05368782094709816, 0.010624702967282747, 0.06293251419499998, 0.06258895823491678, 0.03233058430675057, 0.025166153021517302, 0.06713509634738007, 0.03468069691030729, 0.06239311934839334, 0.09421333971042788, 0.028401281038719802, 0.04023156316590406, 0.0404268657908805, 0.03503291732481411, 0.015110752973405105, 0.028573150949312315, 0.060928094936835195, 0.08453755729621457, 0.03850832498902756, 0.028586007819901553, 0.050767233309846733, 0.016595979123526526, 0.05633714834168073, 0.019611686152676423, 0.044860649448368824, 0.029615346537602526, 0.022065086560624263, 0.026875745257242557, 0.021352797160826383, 0.031170958930987026, 0.027542371986313697, 0.04522050775948071, 0.036740063824841095, 0.034878209698945284, 0.011107765453597231, 0.0352333297562455, 0.0467922980146062, 0.019027423451564485, 0.013763550011771581, 0.06015471002507595, 0.06355719377977714, 0.03530615024388798, 0.034788933642689264, 0.09527257117893427, 0.019481110296422438, 0.013714055943813537, 0.06333486357283208, 0.059595124931224895, 0.04400093791886203, 0.0099000699758049, 0.09978119013530594, 0.08885656183044757, 0.01933861985772608, 0.04447731437281736, 0.047230833555541696, 0.09335447087763779, 0.059556989074354215, 0.04640579133504822, 0.04560684973013498, 0.01566457804367547, 0.04082809284990353, 0.044428579689514254, 0.03609412146972553, 0.025165021126609177, 0.017481281820143905, 0.026390327050560908, 0.03670975738655656, 0.035068364213070566, 0.05494152000474353, 0.024526540467876102, 0.033733831388094736, 0.031782902304023024, 0.035659879851605625, 0.08477833106993668, 0.025835129725296172, 0.03687667262349879, 0.05488405191910364, 0.04067784385575403, 0.05916812667442907, 0.056486665721862554, 0.05235125798912299, 0.05123724740359092, 0.06047348304080868, 0.04144010517085272, 0.030359028305317608, 0.021360743407820983, 0.05479997759985347, 0.13924620955461456, 0.039767061074775074, 0.01599914779240686, 0.048163495807638096, 0.01565048872913805, 0.06316592969420938, 0.06740963927680446, 0.05291616739404779, 0.011316127962462846, 0.025954817556926323, 0.05736845973578673, 0.018176506611428434, 0.07392195353825247, 0.04492605420490427, 0.04662571219547142, 0.008884065018426026, 0.03668438072406477, 0.04137206890229737, 0.023926381442335345, 0.08912103070366768, 0.041579487207796306, 0.11076997830382279, 0.06729962138999855, 0.15467518970610636, 0.013565432971283315, 0.04455301535105513, 0.025698781396532734, 0.014923463628116636, 0.047509727864376, 0.04412815447956805, 0.015464994902422112, 0.014806772157880328, 0.02106361812160861, 0.05608245091993482, 0.06478937342762947, 0.043322030800364675, 0.08051535820648556, 0.04439899720431817, 0.04447641038906671, 0.009482755070371975, 0.05242156187793421, 0.023532135359522317, 0.016754132229834795, 0.037997317530455134, 0.005719335214610422, 0.01629460396455421, 0.013489178494520247, 0.05088246442497738, 0.0106296346582953, 0.07952070028911676, 0.07303603414085603, 0.036488246893690485, 0.02568214196681736, 0.021556693377093445, 0.048337133466115886, 0.04409289528285304, 0.06311633699243108, 0.016077479325054635, 0.03668369507537254, 0.08824544583236979, 0.03130016540507636, 0.016629715720492027, 0.02076222955609762, 0.0819841249575538, 0.03270728889131739, 0.03726528987528817, 0.016889649353200392, 0.021436046020338134, 0.028695299838399215, 0.037466142807276025, 0.0262950410345389, 0.010267674393441168, 0.0476150343104476, 0.03352711022260689, 0.027481211356878765, 0.005586817325468386, 0.03667788046802725, 0.017117188958030556, 0.04203794103476309, 0.039862117264419794, 0.037170068976739724, 0.06706536702451206, 0.0481463162859361, 0.04102296646564238, 0.04501080651196741, 0.05307355249721197, 0.014710376271978022, 0.04069460585953728, 0.05749853380445031, 0.02122345470613049, 0.05988911883304677, 0.07109719583944929, 0.007133577094082871, 0.045455532043331096, 0.031990956462499116, 0.09193218268093564, 0.05918836671738856, 0.09238564544507573, 0.042835093824373144, 0.08147011826475782, 0.045533538946220954, 0.022150128065878828, 0.04333554076090936, 0.028138943805149006, 0.0716481279701956, 0.03454221885711436, 0.06319725885987282, 0.01129608039909433, 0.06355094250231501, 0.010760731454337797, 0.014696148104004323, 0.0191382457306909, 0.01544786134599558, 0.047385403285584146, 0.03239546429305788, 0.00871357789653684, 0.14259867159829986, 0.1365207445116774, 0.12557814378411541, 0.17240539072982727, 0.23384017238934196, 0.11390674829242692, 0.14803700719869908, 0.1407656377001155, 0.10709506985280784, 0.10748917612457469, 0.192430806496451, 0.11232382677976163, 0.15337187496404495, 0.1234884934139348, 0.16787324521330096, 0.200944249668429, 0.1236413739201042, 0.13486221012088562, 0.20839451601909054, 0.22786554459842945, 0.11283814756860656, 0.18528735835946378, 0.16310980243067588, 0.15112417299420605, 0.15938378059335295, 0.12654363673420685, 0.1381896670547224, 0.1263299901338835, 0.19990480625100676, 0.14043050487675976, 0.3183061923951872, 0.11021626527391135, 0.15971355080123872, 0.10714691868352313, 0.12775056229363527, 0.1679571165192512, 0.09259088806086972, 0.1103305119660593, 0.22015286249018487, 0.12570632561560602, 0.08297575682762169, 0.22626606026484122, 0.18200019765044415, 0.19259903940462297, 0.16975609014832205, 0.0935296138988868, 0.09892553887179784, 0.12112122810175344, 0.09187691709807805, 0.1479037845086667, 0.11505538222169685, 0.11168641864412254, 0.19607130227790726, 0.11654519340804509, 0.1581030654450578, 0.11013041746111647, 0.09297262201265943, 0.1013769589424614, 0.16904217281168507, 0.08930345156019734, 0.28498660773038864, 0.1314802843356325, 0.08590420452697624, 0.17054206571511685, 0.13679644423386744, 0.11130227917625059, 0.15621118067253023, 0.07096478520261665, 0.08357398722681307, 0.11504829590839726, 0.21149924054982203, 0.09912634583851022, 0.18057836910649655, 0.16213729977607727, 0.20873349460382618, 0.1572198886424303, 0.11247747337385533, 0.1626795521306415, 0.11167405398502467, 0.1170698717056263, 0.15034564380203524, 0.3225529548381606, 0.15948769275940236, 0.24726377950320322, 0.10324805208872403, 0.13670675065969268, 0.0909321851307346, 0.13630098452971828, 0.13120072353030407, 0.13051464582883543, 0.139139799941932, 0.11938308185387043, 0.14165958569895837, 0.10026270703923318, 0.12947055991859208, 0.07806079717533243, 0.11411851031645653, 0.10349928296261257, 0.16037937313798936, 0.10347413229605845, 0.18372361968842246, 0.0924148640385078, 0.22072707603295005, 0.13446266462485637, 0.16452951657195247, 0.16019564993198843, 0.1115944344670542, 0.2532873603124773, 0.11806389377001794, 0.19341218044921277, 0.19100277264031673, 0.1204179670481432, 0.14544732357946136, 0.13869611245970573, 0.17414180561900142, 0.13294395660200428, 0.177941142070678, 0.21191254498497133, 0.1580003483761703, 0.2580891381348333, 0.1137910383723436, 0.14142275727804632, 0.10364146888135903, 0.1594235405566231, 0.15463434189798372, 0.10850308583148065, 0.17309304657241992, 0.1205819251856977, 0.10901611193173355, 0.23177231722060712, 0.15910927596832478, 0.13791074976325035, 0.19158155206711064, 0.1285008381631586, 0.11090316268945895, 0.07413235192577686, 0.14096043853750154, 0.08791346929126209, 0.14422645521981103, 0.26683859767452367, 0.1351254226099099, 0.17406682093297282, 0.14273998417681263, 0.10423471970904259, 0.16771748421653626, 0.14508615908843858, 0.16709981816670588, 0.19244116400518727, 0.1895471442971499, 0.13100537110961255, 0.13789886007866553, 0.15122592479230898, 0.16549612034953412, 0.16923757119765206, 0.15029330467504842, 0.19153371753711856, 0.2484214609308589, 0.1589964771823537, 0.19039230781697458, 0.13187481961663694, 0.1287043494202437, 0.15894098177311883, 0.1277673549409355, 0.11456212118989038, 0.12697208672761917, 0.18217521809762527, 0.23537443199705696, 0.06480874013035529, 0.16932024740644042, 0.11267035133055142, 0.07662589917139662, 0.15471113455151358, 0.1124835714337326, 0.1186541568547968, 0.10926244750378594, 0.12732123895998926], [0.04527898325074104, 0.02468831142440679, 0.027420744037015304, 0.07280374096045572, 0.021568914394705527, 0.0690360209574142, 0.02932374283010441, 0.051219546942100416, 0.08652891858570999, 0.035926505262332584, 0.028541524924578208, 0.0343385735346425, 0.03550169035612095, 0.05259431470485945, 0.007496587378198222, 0.028140849448860656, 0.027406408616732207, 0.02239509425576656, 0.059343147121610186, 0.037803665824955514, 0.01629461354065326, 0.04900621933742397, 0.02541074382832214, 0.036518461401424104, 0.06300929152677137, 0.030717333373163017, 0.0565806340666548, 0.02723603257759204, 0.04219536444232349, 0.04944103552148708, 0.04526126746749205, 0.09091093385171506, 0.05217849367087887, 0.01376720233595059, 0.022640512437529625, 0.07388727273792028, 0.013003413633052862, 0.028346274010536653, 0.07071630458437628, 0.04766535479575396, 0.06999036732820735, 0.02089543692437151, 0.03851288704261665, 0.02990059171532912, 0.08141247014845572, 0.019787792529490207, 0.039069001758170706, 0.02412583434864158, 0.023764018682883154, 0.03170288250511212, 0.05059149274001679, 0.05648320683488443, 0.04209333302212819, 0.010005702009244312, 0.042870693930214455, 0.017865536201204506, 0.09546821471303703, 0.019659055284254497, 0.04810603155243782, 0.09670731596528523, 0.03388587302798706, 0.05191559527790354, 0.043394131165358334, 0.04687624592934886, 0.005862290572915828, 0.03120514560460804, 0.02306239322699126, 0.015770998190066988, 0.04267653277624519, 0.05428052785235548, 0.05315642405842101, 0.03101465401179608, 0.011518069696913083, 0.04834604689911489, 0.05793131985551408, 0.04737421457145003, 0.03899681712350538, 0.10505169119325378, 0.044349036780336214, 0.03595872692042782, 0.02006826497944853, 0.04913149003480231, 0.03812138546979235, 0.025500573383103457, 0.06069225476934545, 0.01189913236415915, 0.02447564733184634, 0.06788150347288578, 0.023909037211729635, 0.04678327349885818, 0.004773964042655163, 0.03902913454259115, 0.0673164370199365, 0.06275902592366742, 0.06997522176994432, 0.053044069603446035, 0.028016270145833976, 0.04148957912900275, 0.02086577783038299, 0.035705481235298424, 0.028389153866878444, 0.03994344132802179, 0.044289542392136595, 0.10055739042018691, 0.03802219623579614, 0.038325674306120605, 0.038758483339822104, 0.015276084323563885, 0.04745907413082258, 0.045302513641335314, 0.09067566825016853, 0.07343082989175474, 0.04418460366826865, 0.07240307697605702, 0.03640947007243672, 0.0213781604167795, 0.010600750270720211, 0.08227874705147359, 0.03434417363736899, 0.05009442425122665, 0.04358310590408022, 0.029781078168701743, 0.030401820061548106, 0.04760772583164996, 0.025571223926700415, 0.03239621505922368, 0.0740629903251125, 0.002468944571333968, 0.05162581869010484, 0.029698643277609543, 0.0449104719765244, 0.007203851775791977, 0.018683607021587032, 0.0943488453424746, 0.04711904600563069, 0.06526905172053846, 0.0632221490565327, 0.044768408631845835, 0.03449329265183018, 0.04580419014899, 0.011007668405410745, 0.03367511074869864, 0.01174037979405013, 0.03285387598518883, 0.032027872324350386, 0.026212690413118373, 0.010102434973833303, 0.0298976173789631, 0.06938583202539914, 0.06929820688861994, 0.05441157868312252, 0.01613149426937584, 0.03395588580338705, 0.05018268907142263, 0.03783676082328443, 0.05600558931849176, 0.10972545572346258, 0.0332517973748186, 0.09466561503828534, 0.01396981727016429, 0.0671530687700837, 0.01978244906621835, 0.03732762644968687, 0.05579676907209139, 0.02919237790328841, 0.02757194298019092, 0.03716582101919959, 0.033541976158777555, 0.011081406283342551, 0.0621243144175218, 0.05328135384667305, 0.023880789634741606, 0.023584909241406188, 0.10126711725587807, 0.03404724944923674, 0.011524624536715208, 0.014182184503654079, 0.027708360256867546, 0.04551583082385121, 0.047587202336158485, 0.022293987886739836, 0.0542230291231986, 0.012358806186145353, 0.05997285607361025, 0.04159111642248688, 0.06561409772163437, 0.026959674019787102, 0.01702570273811298, 0.024842279775428678, 0.08662528478570523, 0.03626521571629471, 0.05741993318341913, 0.023638349619784185, 0.012981063975471885, 0.024199277282722538, 0.07058230048466115, 0.017625884746291468, 0.05450455494405282, 0.0019716985656076202, 0.030871512398364085, 0.08145279701678984, 0.03675150917842984, 0.027457680966284488, 0.05204468109314481, 0.010307615344983437, 0.04039081752360348, 0.0346473376116445, 0.006190358629194839, 0.06150217058377401, 0.12766329721818048, 0.013955172541881762, 0.06112390317984166, 0.07715341965517691, 0.0644405582739461, 0.01400557633924989, 0.0077101918436857245, 0.03425813430259305, 0.03949776967807163, 0.01927473387050052, 0.030103767808947354, 0.005829837173223496, 0.023317925684574633, 0.06600852575032942, 0.04408097495475123, 0.07660305442949457, 0.05582930482623558, 0.053729974935131694, 0.06151780260786895, 0.018350527313868367, 0.09106851047686032, 0.04884007018840602, 0.05261592987564303, 0.02895733638245973, 0.05137782070725676, 0.04536413392352481, 0.045311997809837905, 0.02545007861279432, 0.0416582870116878, 0.016406805201944326, 0.033072800931310466, 0.04697517852389044, 0.04511090739059352, 0.013820465556496095, 0.05208455980004323, 0.05915726737810239, 0.019448541983541463, 0.03350590107842319, 0.014907805748554248, 0.015167716398624884, 0.031075625034469753, 0.0177353682867702, 0.012102940480314918, 0.05205224621139708, 0.03339564953480036, 0.08239387474473446, 0.011662814349326636, 0.01333737817232407, 0.01274486949231716, 0.03860770191456522, 0.009866932842640147, 0.05735054476967743, 0.027732426909008817, 0.021703131083819657, 0.012196691447658645, 0.033340759335025665, 0.029072879678419525, 0.04461469308983895, 0.08214786092961028, 0.06219774394506409, 0.0647112401202321, 0.07886341983272184, 0.046451833219297474, 0.039511149403669184, 0.04783189848005291, 0.031424317614085255, 0.015294105584372678, 0.06584390111628079, 0.08699106878691143, 0.020755633539069566, 0.10006704818337195, 0.061096626619297656, 0.048074644930180044, 0.03679837077675808, 0.04004937979663092, 0.11306088763259112, 0.04852778210695233, 0.029649111862865188, 0.006761164995916789, 0.023117909703644055, 0.023818560312652302, 0.03568367454253378, 0.056015498665792335, 0.04512706035447698, 0.018225049772750468, 0.040213452847374064, 0.04149474639205202, 0.04699822627909241, 0.0436112366526598, 0.08023287094528637, 0.02791467539575552, 0.09326826300351851, 0.04337366512646118, 0.016309586729133324, 0.019611199686844504, 0.01477807929228631, 0.06493447814136744, 0.031573427052447395, 0.042176311835646636, 0.08608967441344455, 0.014840038568382303, 0.0003537347847961956, 0.06459681722786158, 0.004505046113814798, 0.01540930509837645, 0.033890687890591166, 0.040299427064676444, 0.03749828019569959, 0.027069096273231893, 0.03391638631001115, 0.07603404262373525, 0.035188107586075226, 0.04970710551846893, 0.04152814016467141, 0.02807410403845772, 0.0186712883277646, 0.03940829826939491, 0.008593828777872748, 0.04523432798563473, 0.025186021511833516, 0.049278801081762205, 0.03137656543854504, 0.0373124196043899, 0.040309351733735496, 0.06509590052789258, 0.03421287765846618, 0.11250485335626911, 0.03968790120955917, 0.05983384558930994, 0.020067353334818638, 0.05753936246037484, 0.06894458836365132, 0.01006091109311749, 0.07650881029304958, 0.06922026510320364, 0.030486700688338572, 0.06005409203710095, 0.13830661803724306, 0.039733548558527426, 0.03342194550280129, 0.07097750992303895, 0.056738271978833986, 0.06996226722314473, 0.18509382922803203, 0.17314688723173835, 0.09435358742672591, 0.130446954299846, 0.10594326431953138, 0.13880716456520942, 0.0711642055501861, 0.11946662374201322, 0.21989948657010833, 0.11889674625689946, 0.13013314936430226, 0.10148027355992988, 0.18214511084220103, 0.1314767450094223, 0.15437397925603777, 0.1303805497985694, 0.10761839983564232, 0.1748845278615913, 0.10545940318655585, 0.1801171994978382, 0.07910505928579839, 0.12319078398568016, 0.11202807087571391, 0.10383279934044808, 0.18717182740088434, 0.113592307503906, 0.11915208336206214, 0.16526229499328524, 0.09530541336824817, 0.08062555229351406, 0.1814406163870327, 0.1218932761900848, 0.13854626566171646, 0.1515171914211204, 0.16864829636629552, 0.17061130474171332, 0.18471758812665942, 0.13313648981913445, 0.12338645050242064, 0.10208216585939932, 0.20555573125039378, 0.09198732568972534, 0.08669280011447207, 0.20850588988152244, 0.2436877730032129, 0.13363732746051205, 0.09843437692090388, 0.12920085100396989, 0.09708302080511086, 0.07920733202368983, 0.14490041341031754, 0.16527803043924993, 0.13905225141394523, 0.21552114086526059, 0.19783950981593904, 0.1373189468417437, 0.16218885749338136, 0.09052192206464468, 0.14424758392476267, 0.1740752785436569, 0.11112630878004337, 0.15332831520467036, 0.1227545811824741, 0.09210625317909064, 0.12286047751624739, 0.12151754836762145, 0.10732952340115463, 0.1804493752218062, 0.11524105129102546, 0.1845486350958386, 0.1566327128919863, 0.0929827267123807, 0.07838747238800411, 0.18069844572774826, 0.14002740473276185, 0.12976282246170506, 0.19751435145735743, 0.26637661601266555, 0.10890871406562867, 0.1397265773266554, 0.10955914569598053, 0.2074284638248144, 0.16222729978542175, 0.10191082263425474, 0.1449580385439819, 0.0861825702351428, 0.07864945913634955, 0.09382630443020214, 0.09733815872741323, 0.20673866293603377, 0.08587738378874718, 0.11206576240158851, 0.1531270485852034, 0.18524749114388422, 0.14979818204958595, 0.1963467108866861, 0.1499318337488559, 0.1672024433050425, 0.10605738077673221, 0.125077344447134, 0.15451090981162366, 0.173593363274009, 0.14374715997086418, 0.22708054962417773, 0.18842292559002677, 0.11764925634188038, 0.14459990776113926, 0.09934761501368015, 0.19170106178329838, 0.059075008687232776, 0.15902963346771656, 0.1114966280217613, 0.12907991636424296, 0.30327616019114373, 0.13315479932052474, 0.1056135630595588, 0.1422493967918619, 0.1494525078563921, 0.12584947680513706, 0.18718216958786213, 0.21157715169172134, 0.1543162009047885, 0.1428977063586635, 0.18999211880708897, 0.21989138135986946, 0.1363472868838618, 0.10865539177170686, 0.11520568867244067, 0.2136551038992982, 0.12380714768603926, 0.12919113700909, 0.12737458932303614, 0.11005914830152067, 0.20066884105965016, 0.1135794219050196, 0.1912394018783685, 0.11368989944458009, 0.14992883068419274, 0.13666919702964445, 0.13791579062179213, 0.1545962520063885, 0.16707821448724117, 0.11362097451403258, 0.1320619136095047, 0.21114555307694022, 0.09944283208178897, 0.290578130272127, 0.15036425973859527, 0.21662044639308609, 0.14361658794504983, 0.1721200229780328, 0.0961167004800612, 0.1779823116357288, 0.19899795733151898, 0.2473602606163871, 0.16434277497952984, 0.23547002444824866, 0.17136924149047944, 0.20384030717034496, 0.16260593108111815, 0.1333293601149513, 0.09708243857828841, 0.10855063690894073, 0.179980606020939, 0.09160991247382858, 0.1198438224532912, 0.1314522761611208, 0.1348734103263386, 0.11327285650036029, 0.2028541221854187, 0.18099640796501792, 0.10066779135095497, 0.1084604453776152, 0.13899759870142708, 0.07913662210827874, 0.16091811680986037], [0.027039241826822682, 0.033526279017209046, 0.04357753261443108, 0.02340046016709699, 0.04892407555974299, 0.02602776827951593, 0.029192412377245007, 0.06931946582851872, 0.09055651093442595, 0.0485085916044491, 0.018631777343069835, 0.023953416685183204, 0.02786851285265819, 0.039901873397250334, 0.0401347105000769, 0.02154013630182993, 0.04537544138128719, 0.045089238593655254, 0.053160641372444174, 0.04682737335021939, 0.01985570239353805, 0.02820715435870713, 0.05114717844633326, 0.017305818957186515, 0.04816975091553984, 0.06093281020800914, 0.04699269129383949, 0.08160002379407806, 0.07243994878785265, 0.13073607588246947, 0.02766303466482749, 0.03162370540291792, 0.09161431747939318, 0.07213501515047205, 0.0389587885189441, 0.04844817408030072, 0.0499451520191806, 0.08058258242184117, 0.028650449220872218, 0.012456599224899566, 0.01592117823630331, 0.01849366509686074, 0.04905592695239091, 0.028009147443357977, 0.037566971469430194, 0.05102978696325614, 0.0654702264094545, 0.04501551795270174, 0.08181204628800193, 0.03515804246548684, 0.037487156599039034, 0.032905636715792844, 0.023222476874868718, 0.046059201666784864, 0.008992297920368372, 0.09333701939472268, 0.02303453635484461, 0.03331319549151006, 0.06899144996197955, 0.014226833065491051, 0.02073925649446826, 0.09043703186175517, 0.05787075677466008, 0.026208850397397915, 0.023172820970836668, 0.02780869479231056, 0.04569021541805518, 0.031054952151833043, 0.06218502305508141, 0.005380423662568173, 0.06489834177397913, 0.03478271683918373, 0.026083474362929984, 0.03773079554159795, 0.01362072057916873, 0.0998858300848834, 0.009679383027457423, 0.054454207645669106, 0.024798382937367407, 0.07548866463043997, 0.031784890302186536, 0.03379239880990598, 0.0629822907578801, 0.025596033684128237, 0.052636652553994814, 0.020580967407553427, 0.03054593843708356, 0.03309067376258393, 0.03198057022546569, 0.023464277206409364, 0.076353462983764, 0.04832817406784143, 0.021736883002543644, 0.04533850062157839, 0.05416718131351856, 0.023401461827057986, 0.06426385243333156, 0.03254017064107522, 0.07274434616368625, 0.03126077699444948, 0.04526030219670746, 0.009510055571163615, 0.08513490669429304, 0.028853464436026353, 0.06140750892941029, 0.030646918401602777, 0.04026335198432207, 0.04223838410971146, 0.018822663471162803, 0.023989867148620468, 0.05822306145883857, 0.020606405357079163, 0.019696942162549785, 0.029688565390965635, 0.008436234915749201, 0.011198417595287245, 0.0847629786679341, 0.025451750599689064, 0.03292999065090572, 0.004071040546536566, 0.012322393069494397, 0.047728361697086406, 0.06474057362685282, 0.04612641056038199, 0.03947863663216272, 0.04857905637172442, 0.10574032762838949, 0.04098365466380793, 0.03296230423955187, 0.03677911515678129, 0.03669183859000764, 0.03084159283448131, 0.10757332322217765, 0.06864513991580856, 0.026338698470123836, 0.05379935185755453, 0.0383250116400661, 0.15786763130416795, 0.026721920547706467, 0.08027279944789988, 0.09168331901873313, 0.024099277910746397, 0.03679598824331357, 0.04135855511131306, 0.045700435030965075, 0.059353531443423806, 0.05174407585253639, 0.13115367040999476, 0.06204147349982973, 0.0710987893023318, 0.05799037757359686, 0.028498692948731686, 0.034131802573439576, 0.057347671939961375, 0.04977920588346259, 0.0299517740495503, 0.023512956348337957, 0.060896505301277486, 0.046589794163141525, 0.06734561730897234, 0.04985106876119972, 0.0913515723040027, 0.015070729667410977, 0.045697397492345304, 0.05037659358593726, 0.051431910345150586, 0.02250795049833194, 0.027217579434715936, 0.016694660824272903, 0.02258836483252385, 0.03636579539987349, 0.01164692951621668, 0.03194881396578445, 0.0867751315836945, 0.00836113244370227, 0.06056610307085419, 0.010011097183451056, 0.03229881081009104, 0.06871430999449185, 0.045922788220547864, 0.03815955963105925, 0.02254892662618189, 0.04453788128411097, 0.06417100257690876, 0.06672794359826273, 0.06509573964942848, 0.06908469818412297, 0.09616944563364792, 0.014932321519741129, 0.04960800821502363, 0.14691479564193757, 0.04049048556255237, 0.003632139438019705, 0.02118915120410102, 0.0605683247258346, 0.0842210480702981, 0.05874032785575237, 0.0024669860196750494, 0.04137288861637635, 0.015741387934183643, 0.10282714040048661, 0.059447427009863246, 0.06122739016709309, 0.041741472668945796, 0.08189784813552134, 0.12311121043298515, 0.056533680537775646, 0.025913580959182114, 0.027130149650357427, 0.028652806856459188, 0.05142810671860653, 0.0578628124428853, 0.03801211068827299, 0.047952511362851634, 0.015925456837360418, 0.05380865982583454, 0.04145111768476425, 0.018614272234000025, 0.04721324800723984, 0.0278992980958954, 0.0741323059605014, 0.08177098397526049, 0.09979530913575042, 0.011368641374452461, 0.039865560829639435, 0.026283134112975774, 0.011790697406526777, 0.05177155542638033, 0.03401984265374561, 0.01373158307791117, 0.009622245317234868, 0.03583402695855306, 0.02453696692452556, 0.028508958526917046, 0.11395937087194574, 0.043820888104458014, 0.06364384981533212, 0.03733675055686505, 0.044227604183458516, 0.08625189353141093, 0.025286947850198038, 0.05263908105271478, 0.010715935420575402, 0.03670698031783104, 0.020398875968831203, 0.02193682045946198, 0.027745274203499, 0.02235676304647519, 0.028080205928774613, 0.03418033041300313, 0.0228585506368789, 0.010443092248733006, 0.0703532784996975, 0.039404605725599874, 0.0673788808466446, 0.006915693069928356, 0.056369737721979625, 0.02949255221943942, 0.05882108501429039, 0.0350705360723359, 0.039369200972179254, 0.05077443453633497, 0.0494646463513134, 0.01920715725469974, 0.032498587388545275, 0.04576241537447899, 0.045789680443704135, 0.04243362927809358, 0.05186666141174013, 0.07200878684318836, 0.008372618016907045, 0.03123223255839079, 0.02380986712993153, 0.04934346656345072, 0.02242357357435169, 0.024012767431897022, 0.017245252045892903, 0.04093364827455052, 0.07556938731502141, 0.0038950521951436157, 0.04130925352294599, 0.0560488349818174, 0.031247977580454563, 0.008624532624268004, 0.04904657684927506, 0.011021386167304891, 0.04935795711653848, 0.013223394822900095, 0.03624586433532738, 0.011971107282255207, 0.12331030136274716, 0.008582976184815409, 0.12024194302578127, 0.10653270769023127, 0.059539346069458036, 0.0403149901408582, 0.042453283263791, 0.023534761125882788, 0.02929643754126324, 0.011368236305462498, 0.056047253010253754, 0.03224932153018252, 0.0408223778339884, 0.03590675168520501, 0.07088835261041118, 0.02335765691954763, 0.03667272852673646, 0.038838493562633955, 0.07161573777275701, 0.04393027013828678, 0.011742008688499131, 0.04668156000515146, 0.030835276439545617, 0.08414891323134785, 0.024587980719403397, 0.08534411764553479, 0.04190441957044025, 0.08186974036957949, 0.04187918846465407, 0.02860427901689564, 0.009277920396397672, 0.0661731580452573, 0.0638919550504896, 0.11529711360532431, 0.04677784576591465, 0.10410572582435224, 0.02111763498114963, 0.01899547566990218, 0.04013138950892514, 0.06589071674933357, 0.07797881044567594, 0.05670366012641499, 0.07038779842156558, 0.024096349539655833, 0.019240859377708648, 0.010426606994212396, 0.018807697943561984, 0.009085151607230788, 0.0390796848542748, 0.06593552523202474, 0.04071490718953071, 0.04204349134177451, 0.012896866124543934, 0.0709105844819738, 0.029798039355345314, 0.0017792641019989408, 0.008971912320703268, 0.046076928941352714, 0.02784084941771242, 0.007097701675393769, 0.044838049854602546, 0.032231441038029815, 0.05625711513623115, 0.16556845437134468, 0.13752372214390388, 0.20234580752590012, 0.12623950748914672, 0.11338054547987639, 0.14431850834479257, 0.14994766112537156, 0.20116119044682673, 0.1193992386481935, 0.1303508102653488, 0.21780869472892056, 0.12470770702366868, 0.21093809646704506, 0.189942583561905, 0.10743426294216227, 0.09218829353490184, 0.10133974239109986, 0.22750490104719517, 0.129982766304766, 0.10414097352974838, 0.09663777050351906, 0.13222646929564016, 0.1915959698418456, 0.14345515789764543, 0.12225403465450772, 0.127532311504887, 0.14483370247387117, 0.1480293003541808, 0.22671032997388996, 0.12503112636266217, 0.15251767160671373, 0.1642407320680157, 0.11374799955275752, 0.14487139399974577, 0.1400895191416625, 0.15593249320743546, 0.1753147015528333, 0.22308956861736315, 0.1427296113463179, 0.1197894685150635, 0.1070942041734534, 0.11047364017295261, 0.14798570995128926, 0.2619457779632461, 0.2430830078740274, 0.2164876373905328, 0.15463653290944715, 0.1314097889248402, 0.12449651956558229, 0.10689246257947338, 0.11014049151732076, 0.11551351046129582, 0.15634922971648557, 0.15486683426124437, 0.14953889193073397, 0.15317918852932993, 0.11710973892120585, 0.2213049514759933, 0.20930364788059266, 0.17383903234956727, 0.18863975911611514, 0.2390184671047234, 0.18339305274909545, 0.14006819125385056, 0.08127150997038811, 0.14792299799380765, 0.16338564004869233, 0.08857378345583716, 0.11854606184868083, 0.20040745185988568, 0.061234859524354826, 0.12379607005465416, 0.08782510871007558, 0.09927313594568161, 0.2595105376695433, 0.13984820144551416, 0.12858992652787318, 0.17137452749715698, 0.18221068796851944, 0.1361299630615019, 0.17489580467583674, 0.1511066449024985, 0.07806166285468687, 0.15640637987563688, 0.13299828755759424, 0.198721629417231, 0.11574283888142918, 0.16023807588123506, 0.15249879520025947, 0.07585530665012137, 0.1777067957746406, 0.09071513710002746, 0.1846489313268854, 0.31654042101675467, 0.07142363356486445, 0.1720994764999036, 0.1727896297891294, 0.13440456451667895, 0.14497242567519988, 0.05144994405488815, 0.11474735358910215, 0.1909361536344213, 0.11911426160124042, 0.14626378944564253, 0.13043390016161627, 0.1261640631503636, 0.12585744411954958, 0.15397906093107117, 0.10037294709153714, 0.2448555361479521, 0.12748113683154508, 0.10475873917100892, 0.09864073802506733, 0.19810621566589803, 0.1778828887449157, 0.23151793006447055, 0.14154579099868575, 0.12433873609669747, 0.15273904037331382, 0.15033668057332117, 0.08862246834342519, 0.11030725353667814, 0.10454528409266665, 0.09455788009349378, 0.15948182452590237, 0.2315471639796611, 0.11724017305119384, 0.15647286098570595, 0.12106757130353682, 0.1487417314802447, 0.1338885430126421, 0.1676711358971173, 0.23040207703748058, 0.24813354976715582, 0.21074577775453368, 0.12485653492471865, 0.30183634390273406, 0.13997842107088337, 0.3084498890224965, 0.20907634959345867, 0.17376470649915357, 0.11312620428901528, 0.1013831872372858, 0.094099284540261, 0.2430318025571685, 0.1749923164325376, 0.25894939358676633, 0.140283324064747, 0.16828305628751555, 0.10692595594352293, 0.08739707240414235, 0.10810112715848993, 0.17647936970235842, 0.22748185712243282, 0.1861491919525208, 0.1584203484197778, 0.17873687759762813, 0.13123565713965124, 0.11439228715795664, 0.1161495779430674, 0.18409040726480946, 0.11101023879863563, 0.22987595849460174, 0.15070417295059851, 0.24729736479780368, 0.15194348870746552, 0.23714332901422056, 0.08236817249487485, 0.15353105271295195, 0.09599257125369004, 0.12734198462097876, 0.12253252293674216, 0.16169837736074003, 0.14550098037767797, 0.1502592444059349], [0.017302266224437667, 0.09215678433857619, 0.0342477997764945, 0.05531876468129697, 0.024986141511509498, 0.022602610237475847, 0.016312022888732534, 0.06600256558627852, 0.044736730896176836, 0.03947244281129491, 0.1831720670264575, 0.07375455566591795, 0.00761251132409539, 0.023568788836259517, 0.05898934473553973, 0.03586533314157878, 0.11008533318677258, 0.04127249279389939, 0.08909265480695233, 0.010688526709864457, 0.04786665971961714, 0.015423297694313432, 0.061934654030107686, 0.05830597515488344, 0.04663315090921618, 0.015951906022946202, 0.007475953757567632, 0.03018780956946073, 0.023280408443702806, 0.050840314267383474, 0.06182763537752533, 0.031155981912067345, 0.06896541063343326, 0.016060297888132836, 0.014614418971412366, 0.08440224318614892, 0.01187558473658658, 0.02295398604004614, 0.0454387815308667, 0.04253577561147752, 0.06874919763856358, 0.062098589185024464, 0.026331435956601656, 0.029728174051870743, 0.051748557466893434, 0.07052914164359532, 0.042761871140570416, 0.09007242763595236, 0.014906758123317794, 0.02955791101069941, 0.04718620893395236, 0.021478144466997157, 0.0365520888308604, 0.09707414184606845, 0.037042404254598, 0.0380735547702399, 0.03780785632590133, 0.02389151869612115, 0.08865722575254979, 0.03836265720066525, 0.11069439606921327, 0.0392686442712382, 0.011784749691404644, 0.0806407361561733, 0.0904597310469516, 0.03479963206055184, 0.08777323689672255, 0.025217321949199806, 0.10907291735131895, 0.04863523742965153, 0.04394412866883701, 0.024308448642372124, 0.06423880901908682, 0.024916297275452845, 0.02425921983235786, 0.04242778785767094, 0.0165162964033023, 0.06905233863020135, 0.025607446478980205, 0.015302462646016672, 0.03064080501996702, 0.03769171739658041, 0.01777434492513778, 0.041037020348613305, 0.02866084694922451, 0.018017311625543143, 0.059760442874845, 0.01881075271916005, 0.014460682361987571, 0.09938460939954366, 0.012406769993474648, 0.047141890747532736, 0.06418044844101514, 0.06577885259063014, 0.07369904493492457, 0.039372089123653795, 0.058490054591769175, 0.0689676016448967, 0.023792641642954082, 0.06667624798513229, 0.0024952089382080183, 0.0016794608006509202, 0.03338313931899686, 0.03993535143954139, 0.02886891642945909, 0.03182953599119379, 0.032770326436166806, 0.023579161666754275, 0.050017221740657286, 0.06097840010038307, 0.047967836951776865, 0.04303602336515342, 0.044999215601673054, 0.12007328110837168, 0.02278622236072777, 0.028469162174470486, 0.0186138738682794, 0.04722600337117911, 0.023514132293301727, 0.02910116172936415, 0.024806465164968566, 0.019636419301311818, 0.03532301566954102, 0.01823960735853161, 0.03966797526264864, 0.03389544529660094, 0.019462641831787846, 0.021952525261909734, 0.02027371252376226, 0.012549507495526586, 0.029227119990654533, 0.01792372632471304, 0.052358302167586745, 0.014835609622570056, 0.03629263400310471, 0.019798816534720605, 0.06712689154571103, 0.028708798307625037, 0.02425099204805109, 0.041602688180583144, 0.05428323980360743, 0.05653917338819273, 0.06068595752660787, 0.043666601826947544, 0.0110712853042529, 0.06836864346217725, 0.06504483310686004, 0.03673147214877029, 0.04621812660667685, 0.01960719496222033, 0.06548554050706087, 0.10316749794348594, 0.04321827951277937, 0.05796921439468861, 0.019465721505243453, 0.06959233868626818, 0.048439275969060204, 0.02579179979229887, 0.023391619512450793, 0.04834565619427351, 0.04638011589826596, 0.04519705397767886, 0.01812142680489248, 0.027905262090385925, 0.06726393701448556, 0.041592441754595894, 0.040911887547061335, 0.08765855353445777, 0.05001115432429699, 0.060781469538567535, 0.025498702213348403, 0.01138973847827724, 0.05648957302553519, 0.03553067146229648, 0.02294871152468747, 0.02717283223905871, 0.06510634230630052, 0.021151524795699986, 0.036441281873492465, 0.038573488427866856, 0.05567638601566996, 0.027358570256300514, 0.03618465007973775, 0.05273163979572635, 0.059723383371507933, 0.031548356825125315, 0.048031514180043054, 0.11322696017281664, 0.043907321974514954, 0.018556225751977296, 0.05196884604952028, 0.04104020344393869, 0.06924985141883935, 0.040294922467681675, 0.051428777045540275, 0.030547074162431305, 0.00852814248402513, 0.06583453952184608, 0.07539177749065623, 0.10110623879177917, 0.020352050759679368, 0.09631474953024619, 0.07344286513304518, 0.03787619136874715, 0.08587660237906442, 0.007515351744293566, 0.07729891507375626, 0.10190889975356479, 0.08043918608417434, 0.04276705755581779, 0.04253750697018639, 0.07561495422475761, 0.06545711098419082, 0.01086905341400134, 0.05434313255752768, 0.05332585972463412, 0.009962018718191934, 0.010534421420626102, 0.025289159929079395, 0.04368362813106468, 0.004482401512382973, 0.048403143432111516, 0.06451781824110978, 0.08031452059625618, 0.039322929261552717, 0.023115350969976956, 0.052912532306847074, 0.03608084899643737, 0.0270974108829133, 0.08514826726769248, 0.04461727097570416, 0.04393338045525936, 0.024385773727009376, 0.09658793648404461, 0.031537654576823115, 0.05690584222095148, 0.061429066643599546, 0.04745041733727821, 0.017044454655279557, 0.061711833526891094, 0.044471488274153204, 0.043129543548509966, 0.05558740490326478, 0.03544862727604566, 0.02992082792784899, 0.013143907455096563, 0.08110998033155357, 0.033314800445711425, 0.004207298381163949, 0.014677551319642414, 0.026780367310669635, 0.018397986460777543, 0.08496213088473005, 0.027169471028290933, 0.046519758405103806, 0.00739154619007041, 0.03218068005216699, 0.024590464759497874, 0.014700800172924517, 0.04355862173402021, 0.036281495084685665, 0.03918194610084738, 0.019686615297330484, 0.052279004406544476, 0.039686012802825826, 0.1237437462494258, 0.0210592667421987, 0.033944915424311356, 0.026457300372121316, 0.013786279840484984, 0.04015945514003116, 0.057608934735218366, 0.016293376308655547, 0.011891024281090547, 0.02807052449263152, 0.06205762646371319, 0.03785676337898739, 0.03779184891872349, 0.02031048665934753, 0.028665680964026722, 0.03656173387782709, 0.04459646019724108, 0.035960025439459475, 0.06670535932625495, 0.025291092385868394, 0.08548224329828255, 0.03967184783710588, 0.009053649114174469, 0.07893822831852783, 0.09908289333144504, 0.007950428877055885, 0.019290371640254895, 0.026692665565098007, 0.014653342941235152, 0.031566871255035364, 0.02709965552053144, 0.05316310817556036, 0.04688562284554205, 0.05688223139112515, 0.046132703972679955, 0.026461713038565173, 0.07663695382014399, 0.0242546271352518, 0.024789009851613836, 0.04239404934548563, 0.034471612363573045, 0.036044049962994554, 0.05976456442787763, 0.04313784411116954, 0.017029671073560754, 0.025805026300311572, 0.04763949166743025, 0.045849431471358386, 0.01855713739660719, 0.05376481661392797, 0.010069105361077574, 0.03972958022307965, 0.03615431682837587, 0.023395494002127842, 0.034914817210407026, 0.09320314552995468, 0.1010981182597818, 0.016868648967976053, 0.008492871795991256, 0.01654256747344569, 0.06281546362104916, 0.016272228451505784, 0.030452027548885638, 0.016171026321488525, 0.0513500691721997, 0.00826967016403233, 0.027066388152419563, 0.012269678559424657, 0.04334558034315706, 0.06132043537593657, 0.02043090610494537, 0.021670589584016034, 0.013016392120100077, 0.007416139527659624, 0.06310675706293795, 0.04349199123680592, 0.012793031524896864, 0.11788832173953134, 0.03306746129847823, 0.0692669505013093, 0.0116587272702506, 0.04416138737372333, 0.04734270154468475, 0.024782996061408234, 0.03986589790832612, 0.030380235534281503, 0.02934923823622446, 0.19392860031897025, 0.19475168518481717, 0.2523020180242677, 0.2205547368935039, 0.09765353414320177, 0.11905629938888936, 0.11230381656317942, 0.17221218335532373, 0.1635335563051124, 0.1562297200002978, 0.2146466668214529, 0.18527068828623142, 0.13607164844870567, 0.12302824311078557, 0.11136285374842345, 0.11863849801762451, 0.139413982810032, 0.1408459083928216, 0.2100586275299711, 0.2037600824429143, 0.13840991733295305, 0.16887856707457574, 0.16784739740673574, 0.22344717846041728, 0.16870700934481236, 0.1351697178136918, 0.13451259823576098, 0.11942367685297806, 0.21636301020701088, 0.10898544543212461, 0.2041260120008261, 0.12835591731052245, 0.22249618755473247, 0.07880741880545694, 0.15723542490553472, 0.19755109303420593, 0.17542740840825344, 0.10760783548316649, 0.09084209319083922, 0.11992122031628125, 0.14812052610420412, 0.07987467887540979, 0.14174269091698433, 0.13098215864550683, 0.17302699447158845, 0.1379267916443848, 0.16284202405762288, 0.2423253622386725, 0.20996409228011487, 0.10013162939538879, 0.11826909042053646, 0.1459609855326914, 0.09335104646461626, 0.21447201409647543, 0.12210099326987421, 0.14415740005431638, 0.10232874657958747, 0.1005014966452314, 0.268417167807779, 0.1764929907456521, 0.21269176365627399, 0.1072803175737781, 0.11295470784628585, 0.14914391231873345, 0.19181694024272505, 0.1871830582498543, 0.1287048856817907, 0.09793245909555305, 0.2652544810646965, 0.1289658458723176, 0.21248277487053027, 0.13806192955422786, 0.10569690576484127, 0.100935539080491, 0.08654107640106833, 0.11837117163644684, 0.16180633447102963, 0.15308224776339147, 0.18277987597450135, 0.13383864004525448, 0.07951290151404758, 0.07476894800821621, 0.0611546577795619, 0.09297903416858566, 0.14861192554235458, 0.12185761479720955, 0.12787897395150316, 0.09318138097202586, 0.1298584149128968, 0.2850987936460203, 0.11954491792787468, 0.14003313507043547, 0.14896400423059541, 0.14400527031431276, 0.17231149899382747, 0.17152489523493475, 0.1189794760918425, 0.1812455550797524, 0.15888015439193096, 0.25432038391309403, 0.19129791567402502, 0.1322198196524574, 0.18255322120122372, 0.20652973543732397, 0.14804466807794187, 0.13201744986637948, 0.16402121723419236, 0.19004716988532774, 0.15531380059978656, 0.2574979327619076, 0.10134916527256851, 0.08967397764565484, 0.1776432257986838, 0.20279062881825433, 0.12590404524798357, 0.13167913011725874, 0.07229984662826024, 0.12321311544867293, 0.06605282861499057, 0.11827207050256192, 0.16380256041884422, 0.13577621430158615, 0.1547489180079391, 0.1397614956142441, 0.16759746888231847, 0.13050208198687724, 0.08898334172103675, 0.06975730039900349, 0.07201293137885871, 0.14079019847896793, 0.12854290405108085, 0.1265566066027649, 0.13924441690887177, 0.11812837539060463, 0.08403554754031282, 0.16252017519887418, 0.1083541353563628, 0.13628347175976924, 0.13351017218683997, 0.08944820387349015, 0.13074355290061043, 0.20732467423283285, 0.12106170307003683, 0.2008467113539096, 0.17002630468097427, 0.17727303679191297, 0.2977549032338204, 0.13721175581937836, 0.0834085658613232, 0.0878529406843647, 0.17118236200223047, 0.19068556627438915, 0.14105632210210448, 0.21083513425002176, 0.09239892940968276, 0.15045406056507943, 0.12734516388586453, 0.1078990791293402, 0.15398204867397586, 0.1396911227775197, 0.10342163995148675, 0.09556269633673853, 0.13023343027359055, 0.1009050947463801, 0.12881627486598107, 0.1598616815622776, 0.2543028251778695, 0.18306066252050862, 0.08622385471338227, 0.11766133754844628, 0.11307758834934044, 0.08531460027781226, 0.12384087853734532, 0.10908120642265967, 0.10580142314035086, 0.08470585915229975], [0.04191191957121895, 0.053255191944058866, 0.08973963904164492, 0.08594048645107016, 0.04186562104751507, 0.06802349786965117, 0.08176644873474875, 0.028042110291519956, 0.025213434052984082, 0.0728205259468767, 0.024967447050937244, 0.08392718440342335, 0.04280371486299461, 0.013802439507637775, 0.016960328625094508, 0.03940121195609531, 0.054190144799048864, 0.011010533574247553, 0.019119288885004578, 0.024434257516517274, 0.017552746332160408, 0.061217898337711255, 0.04659377782034778, 0.024117357585759416, 0.030546151026482546, 0.009432711334328258, 0.05045962985605002, 0.04321554840932931, 0.08499264416675414, 0.04784180016647424, 0.03511748194033581, 0.03311078357059629, 0.030728795963730064, 0.032361407854383996, 0.057280811616369796, 0.04693309348377009, 0.008625329355709255, 0.013019669061196188, 0.05103275938440235, 0.04961954932960291, 0.02743329447243483, 0.06277659998065041, 0.029519577886188225, 0.06673841602018764, 0.07837210466424305, 0.03300845720655015, 0.01109336491584057, 0.10612443645274448, 0.06143611082206331, 0.04524395004996369, 0.029610361220435272, 0.07739647637091338, 0.05088434517083149, 0.009302770373441521, 0.08806551476159404, 0.09302103110859472, 0.010242876127332209, 0.07652328169393925, 0.04872216159598001, 0.06285493247090809, 0.07374854953659159, 0.038534678413622805, 0.07299778337079672, 0.0420547298516237, 0.052907499109184554, 0.02857426177680252, 0.05927069818661098, 0.05521792069738431, 0.06261086068867196, 0.08420897452461143, 0.013337016195779847, 0.029670265465674382, 0.056162629682090015, 0.04453027786146249, 0.022083742716800303, 0.07465727537149384, 0.034782203560274456, 0.056328897574736234, 0.04332640516241232, 0.034622026066626274, 0.08341151529983168, 0.02311912395300404, 0.0493713291812568, 0.02167164870057135, 0.07221790586387919, 0.08701397481584743, 0.051212881977159175, 0.05192486111134772, 0.019224539789701664, 0.04479026512032555, 0.024385262363319917, 0.04368624815176572, 0.04722637492382238, 0.08908939893327414, 0.05465778402022777, 0.03360996263161783, 0.02521487238306192, 0.028628234586287892, 0.035319970470042, 0.05348815545139294, 0.10004228056077996, 0.07526012528086863, 0.03742231874756756, 0.058909759691525856, 0.059200819476597735, 0.014030177337718348, 0.08536701601359152, 0.023779838398519545, 0.05497713543234333, 0.07846520732968085, 0.004365854162437421, 0.10083623876374576, 0.038237409485924634, 0.05025252564660004, 0.03546662651182663, 0.0623358772586911, 0.026559772292873072, 0.0883246056975857, 0.031218946678563956, 0.05687001228873288, 0.05355788860470057, 0.10410552664149193, 0.0356108732070894, 0.04104047923559143, 0.0364146756398822, 0.014895856692155283, 0.02806930066717248, 0.027610385272231315, 0.027466088781253468, 0.0263431666779422, 0.04138328059906921, 0.05460264867231731, 0.0416563181657224, 0.04807038931176067, 0.021893622676631617, 0.03323754430898736, 0.06878387843889576, 0.03782805423402498, 0.029566721021828633, 0.006402737832808447, 0.05013233411215967, 0.023245034333799156, 0.0315129712239028, 0.06751275471141262, 0.09621525769151988, 0.046634533697919506, 0.04395391161163007, 0.0947148974744543, 0.04819793529027412, 0.036225854118745175, 0.03209108606942239, 0.027226466054637587, 0.0259308849701718, 0.02201916150478346, 0.028213447771005096, 0.035176091496982885, 0.01804228034621525, 0.03573659589634307, 0.021182432613005082, 0.05845547721330678, 0.03681567287252795, 0.00542704202798045, 0.015454288823680292, 0.04193547677489058, 0.04593135308354132, 0.02932164374919188, 0.029261423492684003, 0.07333237993260545, 0.07226706572598027, 0.039793766899815494, 0.021171590553656704, 0.03789082747854052, 0.020987344492647438, 0.03814994139716991, 0.07906445662581152, 0.05306388829804717, 0.03989267651171934, 0.04572237195867685, 0.07963146128120922, 0.059331766885495, 0.03475806029934076, 0.029364807058065653, 0.051342052062072104, 0.020405165550689545, 0.01653313884631761, 0.03652609546758956, 0.05563244704277285, 0.06003868983938329, 0.047276005929996895, 0.02631939496965178, 0.059984619353687575, 0.06921523190554112, 0.015614042096140405, 0.028359847173335093, 0.022645673954919465, 0.04840620012292939, 0.04018147250697498, 0.03309148581578367, 0.017820541942191702, 0.061962145095270496, 0.017186506508639263, 0.012636631802325288, 0.02022539535837789, 0.06983077589182124, 0.08553533319143519, 0.01967966496463745, 0.07923358585685492, 0.021636123288302653, 0.052103041671216495, 0.023667171762715426, 0.02992209388814386, 0.027363115072911306, 0.04990196381244929, 0.050401303751934926, 0.04923322268070714, 0.05795285841750522, 0.007392542583176927, 0.0680935872538436, 0.0405509835259328, 0.02430766914790917, 0.06157343208249058, 0.019095159030609557, 0.03316934716196791, 0.009598203562951137, 0.04069708032353271, 0.09735702747298826, 0.019501911498786464, 0.03577640565532831, 0.02035768150592283, 0.019038391915420373, 0.045819688107698195, 0.019505303353071213, 0.016650371366150437, 0.03258318264758395, 0.0379980989401379, 0.0982158886448991, 0.08225915818324975, 0.018179622674060446, 0.05822393862951187, 0.01182004431968615, 0.012187413165285703, 0.04565826189073344, 0.04838803234780508, 0.032515977584426446, 0.01931398630052084, 0.039120877401963364, 0.030301901128804012, 0.043850152663165526, 0.011335715873076791, 0.0477243512268028, 0.032414340699512156, 0.06252661399963884, 0.045183417612626675, 0.08258236301762444, 0.03247304218671015, 0.05785378026625803, 0.0344389425440421, 0.05404325893088695, 0.03237305622127268, 0.020061421899064895, 0.024039517306993087, 0.03613844348658477, 0.061654124123555046, 0.08636693695500013, 0.00616820719686427, 0.0254902005526087, 0.031044542932161884, 0.07157563306992093, 0.0025104971803469405, 0.07644297269683692, 0.02078851020234006, 0.01271721276064073, 0.06090822261607936, 0.05676103245106436, 0.03898821778655533, 0.056031333703187206, 0.029307917368808584, 0.008287378286402072, 0.060517847192503756, 0.0536866296803759, 0.02037024534788103, 0.06718211116329317, 0.026138209429900014, 0.030247778932173407, 0.05383127091091968, 0.019143658141875942, 0.03331330274381945, 0.06401797651403374, 0.014076301576419464, 0.032103297510935415, 0.024605108530170495, 0.03274449395136007, 0.02726716830605461, 0.035204670406998165, 0.019128868814497706, 0.03580465897797577, 0.05682316218172351, 0.18395347670922357, 0.08525325961771511, 0.03695104060874831, 0.03679323415722578, 0.05134462611749769, 0.08371473290026189, 0.04056761912520855, 0.0479313328621849, 0.024844104979908275, 0.014092667129701905, 0.0180045256180869, 0.029816722324598702, 0.06041134564927029, 0.059707487047079115, 0.04032135250106935, 0.09959717581589377, 0.06817036458561498, 0.1039931262212415, 0.01026113679061734, 0.022937061242578972, 0.09596430260928408, 0.01651685756270684, 0.0724947777005934, 0.034185034192858205, 0.05341558011188623, 0.0479882646862778, 0.12613851411808885, 0.04014744671181806, 0.016956189835083582, 0.05842320192905684, 0.021972382260907083, 0.0441125760816278, 0.018006967523345546, 0.009576505080105798, 0.03135415353632021, 0.009925851707286652, 0.017298468343553045, 0.047847580299862934, 0.023887098368798054, 0.06362570502284555, 0.022119367720499154, 0.015016044396156026, 0.06902703474606238, 0.028962032501435572, 0.007017947134426645, 0.028986740752213427, 0.07540524531636508, 0.0728952654847695, 0.009904067997159737, 0.054661331007317196, 0.028912914774170326, 0.07442236983127172, 0.06390261899439559, 0.08207404835810585, 0.047415801654419595, 0.1287378887495687, 0.18670929415572077, 0.1802452740770194, 0.18995790532039059, 0.11992648334032106, 0.12571679037665168, 0.1889301370829344, 0.13650867096599073, 0.16598241764210886, 0.212244015908049, 0.18731263436136708, 0.22169458379428233, 0.11994279335222899, 0.23194715380668643, 0.10173552639542088, 0.13025843538343906, 0.15538481695036735, 0.19205937642724286, 0.08001958440628745, 0.12013742565027169, 0.09793237482588138, 0.15833845362067223, 0.12599144821926472, 0.13373414565238262, 0.1096433847241344, 0.1406361535191536, 0.1358249528153289, 0.118836815198583, 0.22446985987405624, 0.205062018226712, 0.15007360598012326, 0.07900894589481816, 0.1213288302683542, 0.09820689477266804, 0.1797668981335817, 0.0919037914624618, 0.06460565788250777, 0.22396235726773742, 0.17375070241189775, 0.10585412998954136, 0.08965900062673515, 0.21853845476383166, 0.11668595440325238, 0.22215051336153863, 0.1618137042368612, 0.08413074928666316, 0.10106107024776359, 0.13495988633123138, 0.14548332971190253, 0.14777451483232362, 0.15173874404882232, 0.22459451770109518, 0.22812333318494984, 0.08440692398336627, 0.16564098757601556, 0.1927533141908146, 0.232405427602991, 0.14789497449753747, 0.13804351280052818, 0.16345942963755902, 0.22034763268405394, 0.3085715131413552, 0.18267892090783966, 0.1471987231484344, 0.2036561855986234, 0.15137235483815595, 0.2081461809575558, 0.12286266086683159, 0.09788554387107011, 0.31008518030566556, 0.16516814278739114, 0.1416352853900002, 0.164166942479149, 0.20820651804247212, 0.17545871076083955, 0.2086567938808472, 0.1395473740394077, 0.1491748469491159, 0.11381145461552566, 0.14805357001962202, 0.19365058701124885, 0.14104101566537736, 0.13088566221056447, 0.06684798191511823, 0.16725230030715468, 0.1986444690414975, 0.08629028985817587, 0.23211770030038975, 0.10589113969716335, 0.12933022793262236, 0.155403831252648, 0.14775669562720484, 0.17933007479915697, 0.21289231015309212, 0.13448483520938506, 0.134878313289054, 0.1652462531121508, 0.19453354930925756, 0.12728874151024128, 0.16611721847326527, 0.14329734378524367, 0.16011841294746246, 0.14041527504882506, 0.21699071200864933, 0.10336607559433869, 0.14857333003272935, 0.1256752377676387, 0.19056581141006565, 0.11147533843834555, 0.19645233908968587, 0.14242172060954955, 0.21750354658692114, 0.10835244996292938, 0.14116522916142019, 0.09832022215930686, 0.13354109149546395, 0.11470360996862573, 0.21763566611034257, 0.14036589302122593, 0.22267539084198015, 0.11023275148604186, 0.4305094216139086, 0.19747862111656897, 0.10818407149805177, 0.09406782897009004, 0.15293502098610326, 0.22457973220415656, 0.11200518016853642, 0.10766322364009197, 0.20540845850783013, 0.1558944492811157, 0.10563554212210641, 0.08271183953770707, 0.14779697653026352, 0.19607844221736156, 0.18010092779032646, 0.27027634062593986, 0.14822333510364258, 0.16343014975709302, 0.07162885319802069, 0.14576940226458734, 0.13621789463345083, 0.1116107598007206, 0.12445839136959085, 0.23661229218686783, 0.13526739402403756, 0.17665987533907737, 0.24337476479911038, 0.1488711850176896, 0.17991429345021326, 0.08431919925515691, 0.17132254077061532, 0.12733947185258712, 0.09449943524575043, 0.10161235477895507, 0.13408006499371222, 0.06280548915627503, 0.1906251832241974, 0.16599407750031642, 0.1595579123785419, 0.09010138575949016, 0.08984097715226874, 0.09793104183289314, 0.21839482859978754, 0.13320018236915912, 0.09919368496705448, 0.08316282783785174, 0.3033235044248643, 0.17181559495868223, 0.11639649574194225, 0.1706820299788829, 0.11845065325859094, 0.1519019973854865, 0.1620142966989548, 0.23643405417040472, 0.14627620007001585], [0.02197963711355002, 0.05511465587563092, 0.011356713385471414, 0.029518786900406404, 0.014200562952957569, 0.078043682771104, 0.019642306687009913, 0.04972071890088339, 0.06553879127867761, 0.01698895924604468, 0.06695252227326555, 0.041452680504129785, 0.03145791823044419, 0.01504814922584281, 0.06252735327448576, 0.047399552929545605, 0.014636015947607738, 0.07034738728355977, 0.06883000459281668, 0.024407226104109038, 0.06888403677411618, 0.03314072611711679, 0.02057340611974078, 0.03286980295313462, 0.08424926308854934, 0.027832152404552026, 0.0877707930762441, 0.013733078864583326, 0.026216088013062556, 0.02401369248306559, 0.031110981907395106, 0.02665762661866123, 0.04061847970250153, 0.049704784272058364, 0.050923484602882985, 0.06750059689605428, 0.010686209293893509, 0.1360432878737488, 0.07825355255796064, 0.07268018630002776, 0.044361190765254924, 0.03737431567823214, 0.032436388709972945, 0.01988460114526172, 0.09614539813370475, 0.03530567143893531, 0.033820939415525046, 0.04661258910932849, 0.04153614195304052, 0.04089214929169224, 0.08486784078300962, 0.04509891045369929, 0.059378923427674084, 0.03342067379684698, 0.037229670617248745, 0.08353478650772765, 0.02496558354206143, 0.05943650259606301, 0.029913437094599492, 0.06252845644109672, 0.0262876310490913, 0.001147107977885753, 0.015413498472151978, 0.05694174110108326, 0.06840390648933188, 0.0994687871406636, 0.004613803307180323, 0.07360204288195218, 0.08172586139652037, 0.11283149792542381, 0.022422506796917128, 0.019164405718085267, 0.03798217197219211, 0.04055321284179245, 0.08791818073199642, 0.05005898502384944, 0.024650803759634018, 0.08756373483206957, 0.023031167483197588, 0.04204993797165733, 0.06514447050229197, 0.027484651091658784, 0.03179231752461243, 0.038629045124135675, 0.07134152426114006, 0.04312486275129261, 0.022579930204477523, 0.020507721741112973, 0.02483143388564068, 0.025091428805382985, 0.035382724562359434, 0.04889451222674501, 0.02672604401595891, 0.03824147358236294, 0.02910990279258019, 0.04053151723177683, 0.017469430439955285, 0.03763691146647738, 0.013789174695228858, 0.030575157030515616, 0.07324657808508604, 0.018050021664690108, 0.07533078923100427, 0.050980550492362636, 0.06664869946337516, 0.02357440043030487, 0.04078585076175871, 0.04826689086433861, 0.018233126254692193, 0.026785800789272594, 0.031114871718830643, 0.07742667555688851, 0.0753222396897693, 0.014490441047406245, 0.022736608591531555, 0.0544824494769977, 0.058238842870078744, 0.028850591606310302, 0.03369232857479684, 0.04164841979922306, 0.04202030186030654, 0.032969555261755185, 0.02785731647764483, 0.04183772012531277, 0.01738018694243604, 0.0403800463273881, 0.05446912720799447, 0.019586426318593083, 0.02457466419605959, 0.05934859783719144, 0.0692735388574581, 0.03516769134289315, 0.04178358069170387, 0.07880773290150589, 0.06276540360563705, 0.08186370359673616, 0.06209706850049477, 0.03762647351850906, 0.06138685136853207, 0.04995777714817275, 0.014449574087085503, 0.026029635618831364, 0.02620801919200007, 0.07495974220575825, 0.055711070646441756, 0.026825980185681296, 0.04164197316934024, 0.028402499118519407, 0.059104782694409934, 0.060862847228324225, 0.07503741586040105, 0.03748760859091436, 0.05962006492359985, 0.0631596171297133, 0.030872134844802564, 0.09210469035972511, 0.012082826841862933, 0.0461885862563166, 0.017270634454044125, 0.03199433107980557, 0.041518460643748124, 0.02522623155175919, 0.02733307868062008, 0.04914432966841325, 0.055678236118007096, 0.04193001456799046, 0.08355152552887317, 0.0530984886591473, 0.05887723925914015, 0.011898781878933793, 0.023826657862011946, 0.037072304666282675, 0.03598741691319212, 0.009765473115558346, 0.029641722944835504, 0.015953013977606692, 0.048104032062955444, 0.024221373173678597, 0.07899635907022223, 0.05017722303408289, 0.0460751362956099, 0.12975749048975208, 0.0024520918340121788, 0.023093569175069852, 0.023863939530847054, 0.01569464890992329, 0.08322400761948479, 0.09283760667688425, 0.017916333576243733, 0.062283959480062615, 0.03686681690235292, 0.06800223126887314, 0.02994347540211053, 0.028659519701895696, 0.05993783819459139, 0.10827604801424089, 0.03181618307867358, 0.021357573719034274, 0.019400676810032418, 0.04639035466337397, 0.09489301291684951, 0.025447964210123308, 0.10773870628327133, 0.031119270978735823, 0.017277739919541825, 0.04913347803296582, 0.03436585775606575, 0.047699541469374974, 0.05568721083804004, 0.015523501037199412, 0.035666276685773365, 0.062055554195878014, 0.04891803495646004, 0.06883869202987802, 0.06364298030553807, 0.050165789171813, 0.04777626134455205, 0.07622954060113238, 0.06869639119794292, 0.03052952500330585, 0.06093983906471442, 0.022119245146431273, 0.06325442434078263, 0.056647080702767263, 0.01841684946069314, 0.006538166856062749, 0.022344949970682784, 0.01001991006741, 0.06131665090159063, 0.017325683617063107, 0.018707792417356567, 0.05803361940648287, 0.06224133817839527, 0.04138054183473991, 0.03435247803046819, 0.07321169810189355, 0.03669052091877788, 0.047256348113859856, 0.05907961670609732, 0.005671761633317557, 0.02097230235625419, 0.015712783168700915, 0.04166796653261108, 0.03507324036270861, 0.1188769582058153, 0.06366342336179749, 0.021051887400268067, 0.034229061265866605, 0.06357948310793408, 0.013798049823831648, 0.049934419127361435, 0.06674373267038215, 0.05492014615165611, 0.03486609018798317, 0.04486566732427286, 0.07371536260771175, 0.053563113324344165, 0.06153347293636011, 0.01253599370454228, 0.0497953167125102, 0.04330102083904128, 0.0319328046433868, 0.02022277150723723, 0.019819410893345074, 0.011222848139192549, 0.044873849143304174, 0.03205431959471636, 0.03379266694067948, 0.08075378775115936, 0.02158369797642433, 0.05179751048525495, 0.0442340967786168, 0.035330799122851704, 0.017679756049126867, 0.040963521873157833, 0.03577852005799932, 0.052047055965710076, 0.022981798862137144, 0.03675763788182409, 0.02230675091155835, 0.08890766755587633, 0.024459969342475938, 0.03727940121485341, 0.045737927373979366, 0.01389321709622539, 0.042322531207314426, 0.021661283530955835, 0.03634205433510004, 0.029207345346109043, 0.03840901701140308, 0.0723797342770042, 0.06944892702684288, 0.02898647836709936, 0.04028858309010825, 0.050161522062074755, 0.08889032332527061, 0.04918620403435442, 0.05763164924217328, 0.02876913922298099, 0.05374791671431834, 0.0778596607908126, 0.0598110736257607, 0.029416064085859447, 0.055794118407873385, 0.00892002135515213, 0.034770344519206596, 0.011583236966192002, 0.023959177666373795, 0.022301198689327128, 0.0786916705809774, 0.06836822977469814, 0.026688544012065378, 0.06070501396372434, 0.04305175498067852, 0.03326221234014919, 0.08720103816519822, 0.03878024406731129, 0.008238651263978212, 0.05257224371176093, 0.014255473262540275, 0.020296677924512375, 0.033711159015975656, 0.009913958192262198, 0.041372413641863295, 0.01997727863190155, 0.026468443120979977, 0.07508715794932458, 0.007339583882581323, 0.04695310370035229, 0.014787795202385996, 0.010804682876163674, 0.03566461044453806, 0.02821466776602451, 0.01815843842773428, 0.014051544487536436, 0.09462878919176518, 0.04149908628014307, 0.055306691135610306, 0.005202140159634573, 0.04456256080659167, 0.06837374560775296, 0.05779026774689556, 0.054093115932999127, 0.03283569671874566, 0.07529387911481243, 0.02461697140167798, 0.06236772353370344, 0.1223054851195024, 0.05053543425615757, 0.017566060940284404, 0.13633965664813597, 0.02138329129065237, 0.13235917104588402, 0.2761473626859727, 0.14261486669701917, 0.13271615269684023, 0.14510546450413045, 0.25991573689445374, 0.06772908261947094, 0.08054068507326227, 0.15132943859263775, 0.12846903019254247, 0.12878881827477487, 0.14832652714704314, 0.11304772624205198, 0.1141320164465616, 0.11046426325675943, 0.17909283269076579, 0.13655678128763554, 0.1346260711791054, 0.14474665956391444, 0.14214925377839996, 0.19640461181200322, 0.08542385973757313, 0.10283582783754795, 0.23128176047917337, 0.17090149884743078, 0.14588449931433126, 0.24097626608225609, 0.05373556737697894, 0.1343400905569715, 0.10449292198304208, 0.07615619534326178, 0.170637198513554, 0.12277007914118229, 0.16639084975805976, 0.18606342074851837, 0.1604668603789422, 0.14187454997051147, 0.28154570849672444, 0.1248603730252193, 0.15671898971401876, 0.26078585955885153, 0.20237433664020033, 0.16851090615795505, 0.12972591234551323, 0.2362885587518254, 0.15119428536103618, 0.08756973330051669, 0.17743887950576123, 0.18383074942375385, 0.07841610875461372, 0.14103104120060322, 0.10145097069682614, 0.14028934551583183, 0.13895618398824047, 0.12441619524672148, 0.17812665792242174, 0.11766238708890255, 0.17258960423209976, 0.14412546950963237, 0.16087529249489307, 0.07712626183826117, 0.1959046321891008, 0.16460695273933873, 0.1612685867134602, 0.21617651376272404, 0.15713310620236784, 0.09401159811644785, 0.12035889400830192, 0.2196874334326675, 0.2353992838893206, 0.0851579889234516, 0.11893355678166113, 0.14473311512941314, 0.12854302662514872, 0.16365862781963042, 0.1478830082041602, 0.09626448650153414, 0.1549372683850027, 0.09547165444781704, 0.21301614060517282, 0.16415454717653413, 0.1625137707038272, 0.09842368999436017, 0.10649819542924244, 0.194870566708907, 0.21954324036355943, 0.10433193626663378, 0.07420282435393141, 0.09298102599718878, 0.17187253061321475, 0.13429922742709038, 0.13561980979096505, 0.20119845296346373, 0.07377883299223839, 0.17668304183790762, 0.21457506824404965, 0.1338568116508184, 0.10338440041748748, 0.144467635020133, 0.12807194383875017, 0.16545838285838405, 0.09851722166903558, 0.17005946096633712, 0.15590469953754257, 0.1204911667493082, 0.1581064821972001, 0.13950425861102922, 0.1198951350224595, 0.07159714481883472, 0.1740289302242379, 0.14484597520241815, 0.17821429838095942, 0.23731816560029986, 0.10075931587526876, 0.15633701827497254, 0.1175028952439466, 0.13027567236173537, 0.10552272035349762, 0.12915012066162404, 0.26614632998262683, 0.1818865255242394, 0.1701462434063996, 0.09745561532796392, 0.18746657206887202, 0.23671363029749165, 0.10897497301019969, 0.21232471560999272, 0.21274692198682219, 0.12770209191066603, 0.14205013732275656, 0.17529588643341296, 0.12897146895768183, 0.1390593300663656, 0.17996978885944814, 0.1722221424983394, 0.18227030493078694, 0.12376963236038724, 0.21401200894146197, 0.22510984972600015, 0.2540688466040358, 0.11852382231623897, 0.07866923186567523, 0.14007395223504113, 0.1298610502553563, 0.2573692299906285, 0.11519515496348182, 0.12702875425137822, 0.12557118004488368, 0.27158650419404434, 0.13388721001965387, 0.2444025943236005, 0.13314926816571143, 0.11757363580287465, 0.23324525915086272, 0.0702142182196821, 0.22080544682760395, 0.10347480645343181, 0.10232048049088448, 0.09408021661182565, 0.17178574817315226, 0.1404276703514399, 0.23774700629855358, 0.1345133336801683, 0.16579952181106614, 0.2870516130520452, 0.12728255151981308, 0.16897967535882227, 0.17282975747460322, 0.18831104610956487, 0.1648495268196829, 0.1377665413723838, 0.15539250847312713, 0.09811222928786471, 0.11064268513432435, 0.27254644300668474, 0.12907420134832784], [0.03233135422511447, 0.01785792703289659, 0.059714473768948555, 0.03166511437044509, 0.024638318441688054, 0.043082049927644195, 0.023132951840037302, 0.013615031418721042, 0.03550625240971004, 0.07588654771567353, 0.05726009276845763, 0.0434694376083151, 0.05904305515991104, 0.035961998115864494, 0.0725653114157819, 0.035024697201386575, 0.038607330361921946, 0.031003877069921266, 0.08495827746247092, 0.08766845905131872, 0.052066284772609515, 0.029560147987438307, 0.04836882652354337, 0.02304521370528927, 0.029005071321021647, 0.05198883711390438, 0.030265351073936592, 0.07375034984321364, 0.02320522649003373, 0.05997598937322056, 0.04717251511230584, 0.03057830948232403, 0.02081734575180998, 0.042059460444556135, 0.030404763754397154, 0.022788643198568496, 0.019161607581941832, 0.03111101255091208, 0.022701833945428653, 0.03609310257278624, 0.102509459060046, 0.03475797986010871, 0.019557701851872188, 0.025246636303622397, 0.058387394979475975, 0.06519129379622399, 0.09636176434615928, 0.03927167414897873, 0.018651743509596395, 0.046014174849035284, 0.04504278302192689, 0.02135485410690308, 0.022748758746010643, 0.03511188949848856, 0.06830225428265911, 0.02911480000963615, 0.03846592968329787, 0.023156934222506902, 0.04063568220684125, 0.028676277875239332, 0.08382034578150319, 0.06406671119733684, 0.039742197691192555, 0.023779823076761058, 0.06166511748526847, 0.02978539124371544, 0.07492303127242673, 0.0787229193074088, 0.03576524758471116, 0.0979352246729597, 0.03818870927657812, 0.03955645967395075, 0.06880354391591204, 0.021274401468314955, 0.036357801272383625, 0.08514269780848296, 0.024492058850404237, 0.013112758320095319, 0.014282980607071472, 0.052694051691721526, 0.005462392197636467, 0.10940491687506439, 0.06425577403617001, 0.09893882283640486, 0.020392268460484284, 0.06994919776315651, 0.04073235101156658, 0.06642844918514453, 0.031106931217495474, 0.04787608643152541, 0.0657336917074938, 0.029287972269699942, 0.07591676988428639, 0.06448853836064378, 0.029552251536158786, 0.027155298401691744, 0.05183661161291023, 0.04503165176438709, 0.0467919571054799, 0.09173436345712793, 0.018402956456186313, 0.03925709549577967, 0.027034631892738324, 0.02429569710887248, 0.03823806066066027, 0.024828951760766008, 0.030325810732920806, 0.01916152139705035, 0.07839079720959549, 0.07702311576013604, 0.019708789712298783, 0.06114630742118724, 0.023392983148956013, 0.04765228533576574, 0.04913992083240901, 0.05807031884849553, 0.036633435877100114, 0.04875154489831579, 0.014828336575338918, 0.02659112252595444, 0.018611721161212173, 0.038496519574114395, 0.035682402836579474, 0.006057465356969906, 0.05092973971078473, 0.06834548462422625, 0.07999747510879271, 0.07678447171084343, 0.03226580774231303, 0.036043456244853236, 0.039870172678943605, 0.062098148684468, 0.06836696572962307, 0.0418062798769003, 0.05758544264902031, 0.03311047713542658, 0.08137880058418359, 0.0010492459912183544, 0.024795134724568457, 0.10775347645845144, 0.025811103292770927, 0.05839293762560814, 0.0755337335830254, 0.03673384319089594, 0.04488956160663117, 0.0671131938936249, 0.06550110741368224, 0.02296622237941671, 0.03455550282172138, 0.03641425046108423, 0.02333932826595922, 0.048673009394758174, 0.032940631612173976, 0.03029380166422456, 0.05999694953882887, 0.04818112349077579, 0.1257152198964069, 0.029289985165720987, 0.11229219500936809, 0.0537641424565546, 0.07886658377584913, 0.017591994931741108, 0.0862832954754272, 0.02977145610437278, 0.042540444917376005, 0.02736915950663388, 0.05232709174555156, 0.036204790531267086, 0.07007528051373459, 0.006331822031267709, 0.040700707749854174, 0.08026526114272495, 0.06739556624163544, 0.10145981901235158, 0.05499092118454076, 0.05443900846125138, 0.0344745579716419, 0.05803053207214802, 0.029562848447371396, 0.02735193210443662, 0.035754982006525805, 0.05366629387642588, 0.016685904439298377, 0.10175014335301616, 0.04186016650149419, 0.02069733233281201, 0.043733362559108965, 0.0193586147525498, 0.023309931557084766, 0.01995637783810737, 0.07361180284210751, 0.06236247966186174, 0.03171562446251271, 0.019720807716610934, 0.04459873547837619, 0.09407242549763573, 0.06668066831245538, 0.03276383767144815, 0.036974766351763284, 0.022590205358761935, 0.037300464802331505, 0.06635897267129152, 0.03111981107072244, 0.04586559209612109, 0.056652971918904976, 0.04367766413657416, 0.02763694362534631, 0.03820654763389499, 0.09471354149882832, 0.06254038443007777, 0.003438795604104657, 0.018340031909305724, 0.044803005162506335, 0.07872777630484874, 0.03571416484192014, 0.03808821003223139, 0.029317240658847075, 0.0586282798359471, 0.050454914584876075, 0.01872257791429518, 0.07901043210539126, 0.06237598196152718, 0.12018290062945698, 0.038307391617807655, 0.026260986511084824, 0.01761374033747181, 0.0257825167218764, 0.017850017175078392, 0.03336216766206968, 0.03899726528494109, 0.05227315149480297, 0.036244516020580646, 0.058465792587207216, 0.03289100060599946, 0.07770962247084226, 0.0334301081696345, 0.03514850850126917, 0.0232300266713625, 0.053853223160389936, 0.02000863461064235, 0.03811831345721599, 0.044770404290888584, 0.04297491636187319, 0.04169494814930424, 0.04546227744750438, 0.052815974584870765, 0.08483237091211543, 0.04908678880442054, 0.05945795688838248, 0.05531932009504207, 0.021974730320395004, 0.08660650797068112, 0.06692959326169183, 0.057298856817426226, 0.07298220114241685, 0.015689838835368716, 0.054125352912852844, 0.05367085976045459, 0.009689212893135846, 0.027197015719608437, 0.06319233674495932, 0.1407612556771886, 0.014072169489677877, 0.04855954411229299, 0.022660921019832456, 0.08374018234110649, 0.018879187353436026, 0.00831986137200147, 0.060026593311058904, 0.067829103058865, 0.020830147081024705, 0.037213490840287945, 0.04064671004251127, 0.036505790307156505, 0.07372661643931944, 0.04091885894717228, 0.05160292032204809, 0.03340303462239043, 0.04727898601202234, 0.05912283555634561, 0.04603608113323008, 0.043904108235672604, 0.047610146669490684, 0.043553680466908606, 0.05053010228420458, 0.047445449257089246, 0.043279440142214305, 0.025435783412127246, 0.06832969555210683, 0.034432530388115876, 0.042694459233673356, 0.08886468236244495, 0.023536352673545483, 0.021510425496906526, 0.07472993881111184, 0.07102487713939722, 0.010829291535511373, 0.06091039830578431, 0.004321906571051166, 0.01605505688912085, 0.001287001498220038, 0.0308458867572969, 0.07296629715710878, 0.02600649018741904, 0.07148449925044853, 0.016708289528445854, 0.07114992567127751, 0.061746537309860995, 0.008800402471435168, 0.015672342344788055, 0.034942875180633805, 0.03710370661029893, 0.05071583647100676, 0.010041862316880255, 0.05658112819336596, 0.0534146799585752, 0.037251519444849224, 0.013232089920840679, 0.021862283934869116, 0.09614591141261401, 0.08786875273912184, 0.07235792375379994, 0.0341041199862957, 0.0199953104264193, 0.022449597581139496, 0.005126290751861469, 0.04852637633561127, 0.030946048922956954, 0.05464455751221507, 0.01954916188673627, 0.06084965136382849, 0.15274541422484383, 0.06810825783759356, 0.053292197821241234, 0.06477803532635013, 0.009899762583025282, 0.03375546571107642, 0.01119579470175649, 0.05040467070836214, 0.011359634095682733, 0.08102928829048911, 0.052813293277135784, 0.09002266256439109, 0.049298003075584296, 0.07131698646492536, 0.014564880853398673, 0.019295092657088272, 0.09284319145785225, 0.03205301724524508, 0.03278392066638316, 0.02166916657569668, 0.057011650454613476, 0.14180972361035887, 0.09144760142531126, 0.14024953958728623, 0.14076481032515728, 0.11068231486264737, 0.20726052203005363, 0.12524724742698093, 0.2171322390917809, 0.08655393135643775, 0.10586498545542841, 0.14699017869368677, 0.07769829203044215, 0.11798130949178051, 0.16730929724872115, 0.16563911832148032, 0.10199054940453461, 0.1256981974227294, 0.16211819354324572, 0.18818300217390063, 0.16346895977133707, 0.09066939399006868, 0.11796737435243784, 0.094978470024803, 0.15211582784691166, 0.10533126732034069, 0.12283839120139038, 0.12228326090881902, 0.1513233098892435, 0.241483140496477, 0.22718191837831853, 0.15414589955922098, 0.08636486851760457, 0.1516377276951267, 0.19760931571645124, 0.09863757408194004, 0.14785939737433387, 0.11488138833233427, 0.1450341876836554, 0.13207887479614827, 0.08583508807444766, 0.18947937615936805, 0.1552282439004029, 0.16818066097555623, 0.12634672915502904, 0.1395915466691217, 0.14759964760272734, 0.16145712095162562, 0.12279841673350143, 0.14994870300494856, 0.12348492344420765, 0.17212190755432652, 0.14900626164049874, 0.1318440841691148, 0.14240583194599998, 0.21777163139514386, 0.16563734099749597, 0.16067284610002272, 0.13255921192467213, 0.21590544121159663, 0.13706675069707056, 0.2081670338708547, 0.15871575192338036, 0.16699775993343324, 0.10420625188177633, 0.1328925214587681, 0.12773887945279, 0.15638172716623353, 0.11340140605405455, 0.10419676005239449, 0.30724069584281216, 0.13432463090265953, 0.20067713013099087, 0.24243957062642424, 0.13142230680152295, 0.10313355258756107, 0.19582218580668975, 0.13803568338194203, 0.12226154231616568, 0.1183022237232616, 0.11200747077143001, 0.09720627669124834, 0.14288699644948208, 0.13305663281390745, 0.27105284734599056, 0.12900592759251595, 0.27513551375558304, 0.14472980562958027, 0.14327978505001915, 0.1830286553670322, 0.15663000094073434, 0.14066388590201256, 0.15287076153101462, 0.17653800607208284, 0.17070703508873142, 0.06313119909816212, 0.1418192843876539, 0.14539832459582439, 0.11017265188838206, 0.18454494255204357, 0.11064961056915984, 0.1446178801838429, 0.17590512551607626, 0.16776027788798656, 0.13364910989278747, 0.10322064146279328, 0.15662816232971608, 0.19016926897869957, 0.09629183584043095, 0.15267760012178652, 0.1823396665314513, 0.08045606300114624, 0.28292607636220996, 0.1645002060479695, 0.1106799399900821, 0.2292108716022584, 0.1921210465051474, 0.1003142187912618, 0.08155045024449788, 0.13265000866545787, 0.09620811009118635, 0.10330203064386884, 0.3001898370923535, 0.1169147925271142, 0.09885720382895201, 0.18925716469605125, 0.17826987039898673, 0.16508399568978818, 0.15977422496484173, 0.2522767064792495, 0.10323151991131807, 0.13999804824350343, 0.14958130255822213, 0.12683343247420367, 0.1694798694863435, 0.1835345032234346, 0.18631279768963016, 0.19637933091050197, 0.10188794724883572, 0.10301139220715531, 0.18513833893643272, 0.19386771165074843, 0.2780415610440316, 0.14700723181088127, 0.25351167085670656, 0.12565176483363877, 0.17640723486340817, 0.18895040776941086, 0.08579276171663115, 0.15313432642048405, 0.21309360741607605, 0.11474588270028753, 0.22434507947294946, 0.1333109280394931, 0.1637391436604723, 0.10276529412235945, 0.28803631182639833, 0.24642741067274926, 0.21408552273867593, 0.2342359946980592, 0.0825621153137857, 0.18611372208162663, 0.1362554942287745, 0.17070582466981105, 0.1062866249271939, 0.15404212528899794, 0.13631776185526004, 0.2200287868899684, 0.1476262002101829, 0.2260525055950688, 0.21218753990627107, 0.12633341454690503, 0.30677993992163294, 0.1588766150657208, 0.17730125947104347, 0.21540618171134304, 0.17417742870748046], [0.051343304615828304, 0.036723137112154115, 0.044776812616375186, 0.03865824456536963, 0.03315175012234719, 0.04417295530137997, 0.03444407533313479, 0.025892327764942765, 0.056303949921482035, 0.06798227467844564, 0.033242592828408364, 0.003116945787746039, 0.03548647584994474, 0.02598136633394226, 0.06990948376516182, 0.054932200545144666, 0.04080145214233668, 0.011803283273512799, 0.013197705021969253, 0.02264413603341147, 0.020486851590835763, 0.036856091671412995, 0.02356469984196367, 0.04862828518173868, 0.0321024892881753, 0.048406862788983894, 0.06396338891898913, 0.03715222678898323, 0.019552203255795667, 0.020845244758792465, 0.02479576674710599, 0.02427688198945215, 0.0070959832444186174, 0.081739038108818, 0.1005496222886347, 0.05243017270620312, 0.05800006092495977, 0.052027409640891906, 0.0523756540590717, 0.04229736904944143, 0.03996954960448127, 0.044272592696811885, 0.12514664476076443, 0.0468754836718642, 0.08892376306316546, 0.04533743958980326, 0.06779978487400279, 0.03599468325715392, 0.019053179327578797, 0.04692465502528414, 0.041462497920879436, 0.05002721918806915, 0.03793272865755904, 0.03212352223213642, 0.02617190389202968, 0.06748971078665027, 0.0016145352081718646, 0.01726647076617566, 0.021714815839884744, 0.01603273883266675, 0.034622037557945136, 0.05492078200463326, 0.017095227132461244, 0.04545663137950244, 0.04473119591092391, 0.07254835789001758, 0.034190580669429996, 0.04497023449549752, 0.02789850327967396, 0.04233550873675174, 0.01031468537891464, 0.026317745965394764, 0.05353197185022216, 0.09913649650350695, 0.05789498047482583, 0.07763508211580977, 0.041854639177120505, 0.02582843028639834, 0.0064763574459169426, 0.025146579475051938, 0.13416065744334651, 0.049662860110402114, 0.06741051261703815, 0.04709332077313335, 0.04858181811869145, 0.014220567423880342, 0.020800440106540922, 0.028314998471027905, 0.007932832316240116, 0.05195450871401737, 0.036206514229096716, 0.05259567834136467, 0.029502298773056077, 0.029291502019811063, 0.06020876135857356, 0.014269885291615802, 0.04363988451058826, 0.06236185913064307, 0.05504897915788236, 0.06506451390563481, 0.011120088935469188, 0.030430201703922886, 0.004472947987397352, 0.01101706734663176, 0.059783601712796, 0.051691637134119395, 0.019063690053899924, 0.017420452523736224, 0.04318149197065542, 0.01527747764597617, 0.03843041384712823, 0.03780998221989121, 0.09416093929640709, 0.06823414906619057, 0.005879675501942515, 0.04168483578870374, 0.0429067651801292, 0.018039392194740714, 0.058566016039901206, 0.05958405879115867, 0.007921132238416543, 0.07932333305718438, 0.12015721370135585, 0.03759325977655188, 0.05950703631125151, 0.10190306982446103, 0.017873861661721623, 0.05403618410890622, 0.0402796964701866, 0.05459941195083722, 0.12944866512571612, 0.015283396632801143, 0.027814570686689792, 0.02657095717656757, 0.01805286193566938, 0.01868990809476424, 0.031799285094283765, 0.05328944373515345, 0.03129943762154829, 0.03296828355580088, 0.009101294995015188, 0.0470449001858792, 0.011240941220744243, 0.08631630620408444, 0.030340230422875578, 0.0854649450329523, 0.024655040225855285, 0.042680964594887155, 0.004744488330963519, 0.010395038426072608, 0.06175350487953233, 0.059510499028669256, 0.05203331234834848, 0.019888414347904827, 0.07168344462350493, 0.08752257292789799, 0.013465382845982189, 0.05441200769236011, 0.022777441077895706, 0.044661681092674696, 0.09500106961856927, 0.046759559247162075, 0.06879910060595121, 0.031059466324926868, 0.04546125088968585, 0.05989502154050335, 0.07288595751648949, 0.04696459118877688, 0.030851456216506423, 0.020963825593372027, 0.0355335021571767, 0.0643148126020547, 0.07473979070181809, 0.01713896692249804, 0.02797779912549642, 0.05001206596892688, 0.07404850360246436, 0.008470419674150406, 0.09581850841641427, 0.029153598532561335, 0.03750884837861504, 0.01054405497627393, 0.00957547469184764, 0.024379417112457658, 0.05179992366221644, 0.05843049508609599, 0.06397296118760301, 0.012526842784286748, 0.08044115493013974, 0.08237247024813006, 0.0860790717565725, 0.03823341433739951, 0.006827765328419065, 0.06156034730074387, 0.07246178229369464, 0.03154949638091269, 0.06373546627019683, 0.020659790194082647, 0.06902067621629085, 0.03129894349483713, 0.052596635951270024, 0.12853125951463176, 0.1131189954016478, 0.08269175271233244, 0.03986630393492599, 0.04295037856565849, 0.03562115027659363, 0.007037159661957695, 0.02597898763093737, 0.034897607045188066, 0.10658935223135257, 0.0605436988295086, 0.06480569110041665, 0.0507011505654983, 0.060221991697025884, 0.03636300683982911, 0.030923079691767216, 0.07611273517531734, 0.08942217986670234, 0.038472590817799496, 0.06596940930091566, 0.05295292429265477, 0.05817300527386608, 0.04111107040737425, 0.012143737535112569, 0.053809494861672004, 0.014470471050440064, 0.010718235599568054, 0.029405287143984632, 0.04240885782506197, 0.00812748711811559, 0.03337517966546359, 0.058048508325291265, 0.022869505694196112, 0.040779377318798535, 0.05217230368045069, 0.0494737551367331, 0.008816484572185625, 0.05782654967098948, 0.06844227217257985, 0.006798368619544613, 0.031833598172412284, 0.05212248115229511, 0.012329605787301497, 0.015566452714284102, 0.04425209218395814, 0.028903344420776255, 0.07551554665570298, 0.112416600027392, 0.09685786756416483, 0.035767802487938635, 0.04034380270769039, 0.02462456716344722, 0.0270537055668331, 0.01019572054276303, 0.06684775974962019, 0.03469204650290551, 0.050530604071794986, 0.09998241078949745, 0.03915855360607948, 0.023195949165270697, 0.02737946338921545, 0.02648842269404521, 0.05642758885158166, 0.030717233781732863, 0.04935514174341675, 0.008427722721300539, 0.04996126667866784, 0.020573316104409677, 0.011796807915332818, 0.06929851332378965, 0.04080277747444568, 0.12694731910502718, 0.0580824843247331, 0.12918191331048168, 0.02412837967577, 0.024106073110634764, 0.011511033179328568, 0.023037474302034226, 0.04603285207262924, 0.048449771373622844, 0.022759135406945023, 0.019514318292720184, 0.04040247738181103, 0.032882926039277546, 0.04891017872479655, 0.024002082420573122, 0.05753478125458764, 0.03383405101034911, 0.030282704880641356, 0.040740417917409254, 0.03831040234335008, 0.02986940044549204, 0.04132304310558304, 0.02625736291520298, 0.0904503541307584, 0.09830017363832844, 0.05505062241647994, 0.050501737878808094, 0.02080016048444856, 0.082803747105983, 0.01817001784670978, 0.06275050702594942, 0.08216671435342682, 0.04254913618487697, 0.04764632517171483, 0.06922708328572974, 0.0184956090449686, 0.033295832108706236, 0.029681337351400047, 0.030889283722987583, 0.02458107826720563, 0.023101379441457893, 0.11987559211951111, 0.05749111807334328, 0.007695750128703133, 0.08427966911826404, 0.027884732849235018, 0.01890637964430836, 0.024914763184384476, 0.019948617367434408, 0.027409844521072604, 0.02887107105174613, 0.08039944910354192, 0.015597629619972601, 0.02430357249273408, 0.013542814225318932, 0.04299142938708106, 0.03123882666019903, 0.026774332453046116, 0.0102366641118762, 0.09928435147289308, 0.02053735019158452, 0.05271118524814806, 0.035372045296694965, 0.02523128773205944, 0.05715736803869086, 0.03130930291879321, 0.062142099148683974, 0.04239145613786194, 0.01180287341647331, 0.08889315785059045, 0.0019819100388333262, 0.05492670386428795, 0.020218006440348203, 0.06371318843335876, 0.0675221469493643, 0.033170676324516535, 0.026459993171175162, 0.01781556428590369, 0.02470529942412771, 0.019482864637769038, 0.21596515010441505, 0.13625926338136196, 0.1993611136511449, 0.11959858238697053, 0.081178744383637, 0.1163907424216309, 0.16083979198048193, 0.14628793653701583, 0.18718356386788432, 0.16585348504445246, 0.15209980128753572, 0.10648187009557601, 0.15202189014563638, 0.16362317327049472, 0.18580937067106848, 0.15700354541261352, 0.10822015423928538, 0.25630977635662405, 0.1831323683502213, 0.1369040029784364, 0.22154191779273175, 0.0761347602031404, 0.15417061355565825, 0.09582056919293058, 0.21033857137926165, 0.20817808085872283, 0.1257808276662423, 0.13795545865451136, 0.10317639988516608, 0.17553980882850387, 0.11084519281622865, 0.08883190912104423, 0.05788677567315679, 0.15836966404270741, 0.2168705434568467, 0.1230078268676035, 0.22683817472669388, 0.15249899438311978, 0.13685094372880074, 0.17502633073637563, 0.1876248917993038, 0.10999930917375511, 0.23466405398663015, 0.18342781781909928, 0.18637207757321098, 0.251247068987258, 0.23384594869229103, 0.1256182714695892, 0.12063863101385294, 0.16981941497614308, 0.2089409665354798, 0.11783117158038002, 0.15902155890099465, 0.14839245667380674, 0.08353802705964736, 0.13710338502160965, 0.19030843651102436, 0.12648691558429312, 0.12242791363068166, 0.12010291338928285, 0.19675040857926493, 0.08800622721713397, 0.1384635128441357, 0.21010857646263417, 0.1508380238327288, 0.1711626428990595, 0.15106558258975708, 0.10744026141060938, 0.14931573051839106, 0.12921344548944505, 0.22402828679450099, 0.11142234047574383, 0.2071929377533736, 0.25172455626870355, 0.23400278221214973, 0.13425603538991945, 0.12421663700332566, 0.12062457330044239, 0.21194095152520367, 0.18131752137935933, 0.20453539406580312, 0.1295640073235958, 0.20613231966572426, 0.09421893215227513, 0.10247763576767138, 0.10603297321546463, 0.09928674166721684, 0.2377337836209805, 0.14787574569063802, 0.28346249112679117, 0.08739822919690803, 0.11788731816435054, 0.15581592526887694, 0.11552770607053273, 0.3126126882289687, 0.16036106363659905, 0.20360108855510914, 0.19840241590094185, 0.24955813622763082, 0.1539560476498258, 0.08751475883107032, 0.1196299690092283, 0.07137148595985866, 0.0831665433642845, 0.13468115290086116, 0.06401088637029452, 0.10072910902841438, 0.10279623641362114, 0.11719716487512474, 0.16898600324507684, 0.1641308444161569, 0.11208966434482606, 0.219643276124712, 0.27016096778454324, 0.1423867563566854, 0.1628652211999701, 0.14504004059539688, 0.16557856673194518, 0.09602824030744453, 0.19931018412593873, 0.1496774006274439, 0.2897179361072279, 0.1494065119374183, 0.11475549710373725, 0.2230747065116321, 0.15004221169698626, 0.1270174084892196, 0.18606256273004318, 0.1529186726697991, 0.11830505824858144, 0.2391097081765052, 0.15274369818789346, 0.11870254296809436, 0.09044489958473752, 0.11500983829459838, 0.08487180145757814, 0.12123717550909328, 0.20033324858353985, 0.14879620033166102, 0.16241532840555714, 0.17910691338681406, 0.1677017794140885, 0.09408285961516442, 0.18481236852465138, 0.12238417767108449, 0.18484394666889023, 0.13219242434828513, 0.2594071770867994, 0.11955098534423499, 0.12059717799627012, 0.15768522576939675, 0.10107875921793523, 0.1741380671099309, 0.16261792801801236, 0.191368211901957, 0.30408622156227794, 0.1263055749117367, 0.14660275270861967, 0.10613330775090765, 0.11149640585626326, 0.20009073579022962, 0.10473934182476614, 0.22020959896185707, 0.10948704150054725, 0.1330823274028878, 0.14793674161116924, 0.1601649144844663, 0.16872036991821182, 0.12641526338073517, 0.10953472281295447, 0.17396657066720148, 0.1682772493410495, 0.15026834553047536, 0.06841383498883055, 0.0968664171053998, 0.08418649750491304], [0.0034068504558695902, 0.01870015452075149, 0.022379967849701646, 0.0269818484347554, 0.0995339505795029, 0.038120810903849146, 0.03740538054356172, 0.053422528529359456, 0.0883854024352566, 0.028392053509671843, 0.03149123347905134, 0.04939436927557953, 0.013686830136594514, 0.058126905933022506, 0.0806454092925114, 0.011675228804139601, 0.04713556286127818, 0.023398219359918468, 0.03548782416469148, 0.02597107011223993, 0.031880151420351, 0.049854263347843965, 0.021721268215426998, 0.0414208801943929, 0.06938251486468701, 0.013981833359256629, 0.08042301396809279, 0.038867386568698196, 0.004210789348073905, 0.058569643466222676, 0.03529115407277019, 0.02755622668642431, 0.015588395387655305, 0.014771330057673398, 0.07698708664505713, 0.15625650243413064, 0.027049164580661925, 0.10226431858515549, 0.03077963930404475, 0.04662163277727462, 0.024022063908858166, 0.031848883541721495, 0.012384240305231465, 0.0367239759784312, 0.05033505629868277, 0.07686609071829627, 0.02846319434954034, 0.04741219338029624, 0.03539076465512476, 0.044795976305801066, 0.05208273651078344, 0.06292865694230122, 0.006468186639399538, 0.05987236832058238, 0.028241216543040452, 0.027690675117135532, 0.06141238507904834, 0.02513195677179723, 0.04681235036602424, 0.06416372091118848, 0.07101335517701603, 0.016326620694129698, 0.08822435543181435, 0.011283792348788872, 0.07508787041109416, 0.02882559224212122, 0.047664420168486335, 0.054168502815187945, 0.08198898195499375, 0.014379393729952075, 0.015648839724881035, 0.029888403256453817, 0.04714502021670342, 0.06464249138990719, 0.02439810774259029, 0.06684717752279774, 0.055023751882535804, 0.04696922602071878, 0.06976919008358833, 0.09260778796047935, 0.025899324062911254, 0.03967089022720053, 0.054242621821862076, 0.023966574245282722, 0.012948961061004911, 0.07234971129125164, 0.03296725699798234, 0.05782819292958706, 0.035045561606004354, 0.06195955571808642, 0.05696640147136585, 0.04387922569989197, 0.06951825032311101, 0.08474106089242044, 0.004267195923133724, 0.011393262482728931, 0.0130126019000947, 0.05104477164305506, 0.0349715996473547, 0.04488059837791709, 0.06449787697244076, 0.038588511412061995, 0.05808816486669164, 0.035136247264041055, 0.05593926142600756, 0.013930047730795078, 0.016181736230669964, 0.040740046364765976, 0.04099456375584968, 0.07703525059285664, 0.053709600826785456, 0.05580903413975912, 0.0757658965284786, 0.024743128845828678, 0.09384095969219362, 0.014720280831229064, 0.06641017798815044, 0.017151563323193023, 0.10656581034943943, 0.038527186073723345, 0.026944430785313733, 0.04423818002725321, 0.022057885334136027, 0.09269319910315738, 0.012540373812249352, 0.01781586880585359, 0.043560425871081894, 0.10585216114357596, 0.023840169737776442, 0.012249756442953744, 0.03129506134428084, 0.01505299952001341, 0.08393871402668376, 0.041452630708414706, 0.03297586016537201, 0.023396574186101075, 0.007393298137392248, 0.025822577374656836, 0.03520277050894595, 0.09699947891696807, 0.013415330491449325, 0.025109657867541237, 0.021427858455647385, 0.044100418266269474, 0.008593210161873891, 0.05280290512488254, 0.013690539917367841, 0.05101720396909983, 0.016345056600027507, 0.07177998702372275, 0.027516836360577616, 0.03814452898598487, 0.021925024620647875, 0.02650344567824035, 0.028899985125228286, 0.046161351830608426, 0.06820325274020433, 0.025884088489317128, 0.005147925074843149, 0.012036023657738924, 0.011505433076602078, 0.04681818412556764, 0.037148714275850404, 0.06105640700327293, 0.05198468491735478, 0.019790904761682597, 0.004739596380762035, 0.0267859808199348, 0.07822692334171265, 0.011145137137763444, 0.01352947854977702, 0.0506878704313309, 0.04551346744260481, 0.048562439924646775, 0.0927587609077173, 0.05812766436006754, 0.08508301189830227, 0.045237043767326304, 0.00831789252603607, 0.04051206625937935, 0.07835625430508968, 0.052875085929108244, 0.03644479055618567, 0.07241564081801523, 0.025651048373190627, 0.04162524563951358, 0.026316242517843366, 0.044127361578566414, 0.020061603844946912, 0.006145076608405479, 0.07880647651731007, 0.023533820752955736, 0.01351053415301947, 0.08647088742544574, 0.012548335381002437, 0.01987406552108305, 0.0461853112304403, 0.022394192187235724, 0.023249559998211843, 0.095833707600832, 0.03700264812176747, 0.05240911677960427, 0.06225057719876209, 0.051439973420553634, 0.010824574349117617, 0.03585846516333761, 0.04905879212122771, 0.023038677060075348, 0.06469047913748412, 0.03464838332166115, 0.06523296897930485, 0.00851551256698346, 0.02717332062011044, 0.035962082385536165, 0.0052129147074846255, 0.0448330128265004, 0.08075410950808756, 0.0041328719817101955, 0.04893105079029356, 0.09380349799269631, 0.045014541190598285, 0.018510936549113646, 0.018868010130620772, 0.02295537648962871, 0.04449891039140282, 0.060070436522965474, 0.050427285623886896, 0.03770857133091458, 0.0904747846746637, 0.1076242680691423, 0.02266399494762863, 0.049189233912094954, 0.01577827027968822, 0.058108515992400155, 0.07003566610717005, 0.029503650918242433, 0.01090578732997059, 0.031036872476820025, 0.049066525778823325, 0.02680350699642253, 0.06747839566800864, 0.03501157411524365, 0.023941925366318995, 0.04051264465576218, 0.05551721209720258, 0.04555277541399964, 0.038948319927458806, 0.030891825219676382, 0.039878588154791825, 0.048976747934976896, 0.01756867521532601, 0.13605404374820573, 0.06919990248617626, 0.08054676781138105, 0.029360744876847155, 0.09137707537100201, 0.028081525515224186, 0.06645800485726326, 0.06425975769337627, 0.05208867752263623, 0.04443291191672606, 0.026387733842937217, 0.005289611121219013, 0.025443754556979385, 0.010220063944166947, 0.09061795118595324, 0.07625698187058011, 0.018606427493655396, 0.11356427634675657, 0.020232897274376407, 0.08633405646129001, 0.020816483902895165, 0.03219796682617838, 0.08996905173144995, 0.05744782644474218, 0.00739375300209729, 0.024618963230281107, 0.027753207043954925, 0.029001367285907752, 0.05421534143087845, 0.01589144732157189, 0.09003222334168612, 0.06697527508461668, 0.08124144868023934, 0.011550319125695575, 0.01280247738900324, 0.05790076060821453, 0.03401822620822537, 0.0172522674960595, 0.041502024227332686, 0.054902089459280816, 0.016701980794389403, 0.06956922581359264, 0.06548524939364965, 0.0491509065332432, 0.06655598750277873, 0.025883965915249243, 0.054186758690423546, 0.011552912333319265, 0.11519957529080492, 0.008034950400131845, 0.061600432851381844, 0.019839955456254464, 0.05117629361789554, 0.014318626678188243, 0.017291631008828842, 0.07472017119007726, 0.029586036013619556, 0.024179636703563795, 0.03902926477753828, 0.03448514530675546, 0.07074110285048524, 0.01346867415122688, 0.036230416172334266, 0.06721727459901763, 0.07543029639148906, 0.03355649735538229, 0.019459855186963276, 0.02009677111111101, 0.014524766574463537, 0.058388712650705735, 0.12358297503763631, 0.004090437413974395, 0.0365647254511714, 0.021371625686785387, 0.042423589695845886, 0.05081706349888156, 0.03625144911629539, 0.020195493031473413, 0.032457142031841704, 0.04008250160803718, 0.039057832196234696, 0.02140337237036757, 0.05009569978762058, 0.03832301215058373, 0.028723286945492994, 0.03447200689885405, 0.049677205106784264, 0.02457435967610969, 0.023206816122476614, 0.0062530365915248, 0.028062400130194523, 0.028121011602061412, 0.03933522497273741, 0.022626098493234287, 0.03985329959241133, 0.03572184104292143, 0.023190025390396198, 0.017481911927461624, 0.045123180119140495, 0.031096912702665697, 0.06816017561622205, 0.1599536734002252, 0.06748427156238787, 0.18637342588795772, 0.081671423188621, 0.14500535213418547, 0.16235589530439148, 0.10855458992263002, 0.2465592850480349, 0.16853840871443673, 0.09357616906204531, 0.11828734629577208, 0.11177664081896506, 0.07710650443069397, 0.12744542181251511, 0.18742146481189037, 0.18720875283883465, 0.1374073074229302, 0.14869349858453199, 0.11239054537708722, 0.16819359253971808, 0.15303989842293725, 0.1684451604922933, 0.09506414929825453, 0.17325715792755927, 0.16292267779429115, 0.1226078063970612, 0.20578034822979283, 0.1616458084073759, 0.11073246297817077, 0.11830366396855925, 0.16435585976127656, 0.17524846559090002, 0.20512244724217923, 0.18530211321288542, 0.16153875528083694, 0.13573617854666326, 0.14759652196399628, 0.13895932494873, 0.29374961170458025, 0.1079333539030725, 0.1678010337655583, 0.17368262783894617, 0.11747054335090423, 0.13733259852855437, 0.20280690052576605, 0.14746375892671848, 0.1564505678271094, 0.0917837531456063, 0.1267868007022527, 0.13022724028316238, 0.198785551793633, 0.2948274667705259, 0.28147219469951046, 0.1973814045589778, 0.10956732751501184, 0.18218468694436937, 0.12790260776396722, 0.16738872524471055, 0.1669519172320443, 0.2040152969740091, 0.11348418185427306, 0.18385034595285693, 0.3723099365109398, 0.09470491534880093, 0.2844374146192305, 0.12084119998279119, 0.16213261131798068, 0.17319737242594843, 0.1845660865787537, 0.09153001716420536, 0.07659610601202135, 0.15611693653608524, 0.1376153462596478, 0.10101525818989163, 0.18269850211518426, 0.2680688429503672, 0.205279219475004, 0.1337931497443107, 0.24778366209037844, 0.18900319122739379, 0.06465624266814801, 0.11872220844511064, 0.24583631255213292, 0.09219560967457872, 0.09952073556280906, 0.12722038348475773, 0.1333270005641445, 0.1352688342693352, 0.08494088726658976, 0.21147887793279466, 0.1829530424889057, 0.12016713453997528, 0.17671786819494542, 0.24777304411174791, 0.14571874853103392, 0.14062599519327765, 0.11629362545546987, 0.14008161311428394, 0.12021999460675063, 0.059434587376252304, 0.1411951372339841, 0.13339987084750207, 0.12145967042494206, 0.17607061582947933, 0.1326432670917242, 0.237484636506246, 0.13970770092020113, 0.16023341806665545, 0.15601325419641313, 0.27252385873467694, 0.1597395671471473, 0.14524417238370066, 0.23663608687779597, 0.12906946692495577, 0.1874921134402675, 0.13573107640108756, 0.12218153209335382, 0.1461622368303999, 0.10805811132154158, 0.13433534081184095, 0.09563477754953409, 0.14083522912715712, 0.12489535259984194, 0.26135043571552924, 0.07568507425246701, 0.11446680453035141, 0.14198296673355565, 0.25954709538528997, 0.1497093311721279, 0.13553572398039604, 0.10823450306610716, 0.1709620351152074, 0.14998700740116258, 0.08027653795697036, 0.12222558214899995, 0.1298705344238589, 0.11175174296142594, 0.15249308018434435, 0.20290462270138726, 0.18343422231414627, 0.09646212952511926, 0.07024080147065463, 0.1828537115286435, 0.13244043765289168, 0.09420406238566484, 0.17452694866205418, 0.14775150155107822, 0.1669598845464568, 0.08297748052545133, 0.23536370676611704, 0.22327206608268524, 0.1470928038320234, 0.08828411795078747, 0.09586520147539916, 0.08472388520115808, 0.21133045605834455, 0.10334060317085636, 0.1191827345399126, 0.14395271668270712, 0.12941852722677494, 0.10126448191341855, 0.12671572306463796, 0.1614950423038775, 0.1717946501148324, 0.10811719968314133, 0.15179632321721123, 0.12801493157542523, 0.09594804622353086, 0.11801251225293645, 0.2473223852294107, 0.129518011404622, 0.143615331560854, 0.20180750818502521, 0.11031585670406781, 0.26622140659920634, 0.1632441742525947], [0.028510735850901376, 0.03381919656549731, 0.02420704349905493, 0.047957111720836935, 0.059687499813134634, 0.024487843451600884, 0.03781786526463205, 0.06818086765105687, 0.0314196540538462, 0.05137685543647216, 0.06354201374755752, 0.031574089718501896, 0.01644715696813599, 0.05320291410410597, 0.030424025120033376, 0.07912571301623698, 0.029515236082877365, 0.07095521676444239, 0.015958009828482906, 0.018520206212997437, 0.07893384629560095, 0.04315456398011696, 0.005127973272465169, 0.05007638671104947, 0.07413933098676705, 0.05288445135398258, 0.012097821097760912, 0.05796379815306395, 0.059904007751855164, 0.03077868935501864, 0.04287032237757118, 0.10741106579981505, 0.04079537706509714, 0.02249986444029116, 0.0692687584688106, 0.06839075275967199, 0.0645052390773931, 0.06677442215262883, 0.04117204717570736, 0.02446868550783444, 0.007885160579931954, 0.018546055934782472, 0.01938718983212546, 0.03730090530288797, 0.04228547170397736, 0.03310313418267235, 0.011933562270696125, 0.017587181984356815, 0.08962320899891277, 0.025096709066401088, 0.01265392815243573, 0.06111927983921863, 0.02975717239502457, 0.0739141394414248, 0.04626504949203903, 0.031024025182329842, 0.016424090060735905, 0.026813230567401456, 0.017689454722248258, 0.044350300825411276, 0.036346853875945655, 0.06495661808237915, 0.0031484923308580035, 0.01598283586527912, 0.05763982723076498, 0.010172069493320682, 0.16570809687818253, 0.03930376174168722, 0.0547320256009698, 0.06279645314920815, 0.017329261247669498, 0.019530815996169563, 0.028807658123813813, 0.044904025346641584, 0.07142137360548781, 0.0167494973978929, 0.015993351379649776, 0.06602693484314988, 0.008690995539748862, 0.05262520336996644, 0.032422066696228526, 0.06295608288999047, 0.03473491295270863, 0.02676161347828325, 0.0452404796716667, 0.03629191005001626, 0.05267341328304141, 0.03427653956497389, 0.003156099105141156, 0.02696543308575788, 0.013999395924920758, 0.07114561259626381, 0.03500475976315718, 0.026992956709657467, 0.09398329882852494, 0.042917344854363514, 0.022623091598131487, 0.024248709106036735, 0.0150453376831607, 0.023706270975150892, 0.007643993707343697, 0.024451038672498638, 0.049670647394152424, 0.03236814176723842, 0.03809284486417328, 0.026144759481652614, 0.008855221808076867, 0.08707932977666778, 0.035041191074396336, 0.022415703936149518, 0.041543925406351205, 0.10526668610832385, 0.05503699754274661, 0.07561101653282681, 0.06700966477153764, 0.03056280194751678, 0.04060536427723785, 0.04988528224789808, 0.051045985892415054, 0.05418175613627799, 0.08524514674659699, 0.025777724841910026, 0.008338564451062873, 0.047547369594535524, 0.03810504864480707, 0.010645026322304001, 0.028341420843536337, 0.06224884584005322, 0.05104586714878679, 0.055622399799645915, 0.008933976604302805, 0.052268079992744236, 0.00585331202244326, 0.044547495687560695, 0.024076745349673495, 0.07923654295624265, 0.026549772930241404, 0.021927253936507532, 0.020368136690869447, 0.10733711533248426, 0.03841904893277153, 0.031676255204083945, 0.021937605699584372, 0.044245760467263966, 0.014900978947539004, 0.044135711936941074, 0.05482416299562301, 0.030240121883370226, 0.02059916199575509, 0.04642947494322735, 0.022403548036011, 0.007075464058171718, 0.06215310017127664, 0.058006867616166996, 0.0800169643855864, 0.019266986806366234, 0.10596502887746019, 0.04018337623546681, 0.030641075065960328, 0.0038674201219222482, 0.054280313347736676, 0.09083571167842996, 0.05192948062153113, 0.06608400839350878, 0.024626522602873947, 0.03996350900119832, 0.024964093501048706, 0.029760056716059486, 0.008098981944063019, 0.07066010437425106, 0.059228080715383255, 0.033502610730788404, 0.012266645808854412, 0.01827379211693281, 0.047750237337764234, 0.04432255695123346, 0.02698140218853951, 0.02202017848650294, 0.0231112600604613, 0.03242408150746938, 0.010401204476253161, 0.09437486168838317, 0.056006719298180074, 0.012869331009325483, 0.033200396705538995, 0.055595349235039566, 0.07546981886750267, 0.02289155178943709, 0.013333022962474536, 0.018507288055374257, 0.026510915035502087, 0.05055510356361347, 0.026436129532333826, 0.04293647790027242, 0.09810394787740323, 0.02653742742334162, 0.07312266336333367, 0.07283111328199025, 0.012742062737684579, 0.055044171956157496, 0.01822305985936715, 0.045827770335299355, 0.004982895371804555, 0.07002720083560675, 0.07591273260092543, 0.03704028219104775, 0.022689624419135433, 0.018858566181734204, 0.03756923908968607, 0.030775364533427264, 0.00807191988813781, 0.01068125366263332, 0.09218188137897561, 0.037097440011078314, 0.023288571110536015, 0.07620102680859066, 0.015468854070340675, 0.02086175969922014, 0.11210276444833125, 0.05562559055585054, 0.025655051182594993, 0.02606770252778886, 0.010891890495024141, 0.012831035231600606, 0.02753157206180115, 0.02111501113000897, 0.046660293404373436, 0.06846351579072014, 0.04155919736912174, 0.13459017229897363, 0.04450267188311104, 0.10641431646241296, 0.02461902068687543, 0.023131224311768048, 0.07296503311203373, 0.04407992541429497, 0.08279546569552153, 0.03296192119558973, 0.044212006633320165, 0.04218115351132808, 0.11664532109974854, 0.07051041079384666, 0.059279328167078, 0.0070494778769751715, 0.04380686869544368, 0.04133279923529875, 0.02296811078615006, 0.018459662284341552, 0.04970147860266509, 0.0448475991405787, 0.02877460334510092, 0.021201942957216696, 0.06221017755207516, 0.030449043636420564, 0.06177400922282569, 0.029424989010177316, 0.07011274987411115, 0.04632925532097298, 0.05505554836183306, 0.05425620839119919, 0.056177855679585095, 0.025598870124667886, 0.029150273710969957, 0.01928811934175751, 0.04113456632401194, 0.027925666842249133, 0.006189555194484251, 0.0004432919893353697, 0.011806232712021279, 0.03163704873933908, 0.048255820893832756, 0.040858904906218095, 0.02740704255448955, 0.01735272652079021, 0.03258935348581403, 0.043773034422267834, 0.0400145496091535, 0.05956188054575075, 0.044914677799228704, 0.019607193047000517, 0.03187274909578264, 0.055982901624614195, 0.019748279629575632, 0.044035499975565946, 0.008365001187719887, 0.0555490545417753, 0.02195869226970019, 0.11297801224094246, 0.009121654739212847, 0.02262335206802574, 0.03420741162112644, 0.028122825315222148, 0.042628943394388885, 0.0495300434469696, 0.028581936062584003, 0.06881322726727494, 0.03972808252118769, 0.045221848413348205, 0.010859782792507641, 0.036320737938606934, 0.020722967549978245, 0.02972512885237173, 0.04220319003047001, 0.029236989118339076, 0.01806163747284201, 0.06395645582327439, 0.06268811682539602, 0.01894276307505225, 0.008402957971538267, 0.06522045876350134, 0.06486143931866654, 0.06920180238422848, 0.03878993507955344, 0.040510867331777854, 0.0069479338802217, 0.04073730760043667, 0.05228892907560353, 0.01352475178728421, 0.009714091598476854, 0.04491868060863307, 0.013969965699699619, 0.0460062496694586, 0.05959731977312796, 0.01851922945089398, 0.014397553844197143, 0.053633777274479794, 0.03326554865305943, 0.028091166731751258, 0.0634872078174545, 0.018102847257508867, 0.05970411242977266, 0.02441509191187159, 0.013100764256030803, 0.02204942389301235, 0.028588327151092312, 0.04503914027384693, 0.08227515409910872, 0.03897690649835333, 0.04856457730995552, 0.04211944895946691, 0.10400983459887006, 0.017900705382588412, 0.03403906763020543, 0.014493349308688796, 0.016961270913241372, 0.0714085186501184, 0.07221062036771929, 0.0342347877731006, 0.05123061691260627, 0.010656765662133695, 0.021218195512530305, 0.06582666413798448, 0.14568729296086297, 0.15415795778314914, 0.09341559703311614, 0.14622479557029663, 0.13511454416138513, 0.17315517630307906, 0.1265103042486214, 0.19212172066252078, 0.08891381158102905, 0.10017062327073467, 0.1384804587090208, 0.19628311026721232, 0.09582343436176739, 0.22133196373620342, 0.10758339727838194, 0.17399707628834635, 0.1061442704691041, 0.13580990684849603, 0.19373084238219648, 0.07346272213204254, 0.24222529583400298, 0.21471366887131046, 0.06209775797962662, 0.19702250768821086, 0.1476375842767377, 0.1834076697066907, 0.09179659277921723, 0.16460876070684002, 0.20629083857901637, 0.16219238149783305, 0.19424992823793044, 0.2427896574860619, 0.1510883354011082, 0.16162176856831198, 0.11444425090186058, 0.07319282935631853, 0.15201087380128522, 0.20178158376966754, 0.1566663594736207, 0.10423920132339963, 0.12864177535858848, 0.08447310631914486, 0.33656203698727394, 0.11294501683404369, 0.12012030358516401, 0.07507121565962031, 0.1196864526718855, 0.07016392454745309, 0.11641016275051141, 0.0871149298825091, 0.10414209201811783, 0.12418960942135704, 0.12292191010689545, 0.23963564285828223, 0.1945994328707457, 0.15467158909286224, 0.1417265417835405, 0.11743554079364385, 0.10980152825434362, 0.1518849595900505, 0.14802876409263382, 0.08612718973909655, 0.07887062872008932, 0.12008882503235534, 0.19456978526807603, 0.1729150537040926, 0.1745049925821443, 0.10800149742393725, 0.1527957002361936, 0.18234231719566932, 0.16408052776129017, 0.12186886096793799, 0.14998991853527485, 0.18103584617135987, 0.16786518596833752, 0.09622608251388996, 0.1701163659773527, 0.14931450477771221, 0.12544937972580233, 0.15765593056717228, 0.20558634412384805, 0.23916512697694764, 0.17595340437706442, 0.11667469291076546, 0.15566675262826105, 0.13524756766855717, 0.16442500685732211, 0.12012504566941531, 0.157744612905287, 0.11151689870823776, 0.11037301452409838, 0.13017479390386613, 0.13095114740633196, 0.14597972404331933, 0.13662136249965237, 0.11415722073927043, 0.19110712913736222, 0.14989121576711056, 0.09059205741411255, 0.15888220750756804, 0.19889288071182468, 0.24883812083111656, 0.2130442866755109, 0.082004418626668, 0.13458445728305848, 0.1066888134265619, 0.12348107002194851, 0.21810369986680248, 0.0821270693033453, 0.1162854512973178, 0.17188432836724868, 0.2579237244302227, 0.1381917661356349, 0.2811886195934588, 0.12206037528812887, 0.1192197289257761, 0.11617235373705627, 0.20276344801870086, 0.19705422372827608, 0.19390462176694026, 0.11614560960761963, 0.1755395483586096, 0.041557565601843025, 0.0985831588566784, 0.12113821993191397, 0.11920308949606073, 0.06859205768353517, 0.15022535267616474, 0.10882914817381291, 0.16932332707989603, 0.1877934617861625, 0.14667736967244457, 0.12377416760089899, 0.1398321902078967, 0.17387888424338835, 0.14811675695161666, 0.11805096220585609, 0.1614341689574142, 0.09478335509136801, 0.28202632141690104, 0.15219634368775353, 0.12412914976237283, 0.09290636306808842, 0.12118931799646347, 0.08679068316855738, 0.12623203047100576, 0.1868694984624463, 0.17290766861650253, 0.061442994122062965, 0.15680561893649642, 0.12340320484532465, 0.2515536114092796, 0.15965545069306128, 0.1318062853909308, 0.18290586679452853, 0.09282579360109183, 0.18900421778521231, 0.1681550583171268, 0.10165809022803461, 0.12985587150098818, 0.14240699639964488, 0.1557255881808458, 0.19212922832417875, 0.16746112055355505, 0.158267896922846, 0.18056882365096003, 0.13443359924900916, 0.20185856028429924, 0.11291124001746217, 0.19957601663566407, 0.20100228848957247, 0.17356927746966963, 0.08830497086408638, 0.13439544807038, 0.14817263540481368, 0.11650606163687284], [0.011227543300558484, 0.032377821288161704, 0.04945600870996714, 0.02858700947986255, 0.12505301349465886, 0.05608306762071387, 0.05835027418910496, 0.020946893135025617, 0.03795191532962265, 0.025383695178935607, 0.014722471842692505, 0.016194133448504632, 0.018001016935393695, 0.041549977500953024, 0.06134464758478346, 0.02892704335071387, 0.11650607695863133, 0.06319900554034018, 0.025018328695648143, 0.031092718371280262, 0.05533986274273165, 0.003472948043171557, 0.013893509167246522, 0.06404600767118317, 0.01329334535365624, 0.09567934088408948, 0.033495375030343576, 0.013667665489558733, 0.0613368871141105, 0.03767241964176778, 0.026259454335236264, 0.06886817109320434, 0.0788394489415711, 0.03922548670802386, 0.011357607793123012, 0.0623715999386003, 0.05399451658670461, 0.05397057633907084, 0.08246954124901565, 0.041816246680795185, 0.07263243603970736, 0.04918923774253457, 0.05142681203001449, 0.02977726879649826, 0.05301665514707566, 0.014686187045768866, 0.021993208361128648, 0.054060223947970144, 0.02330696105115837, 0.036022312218143095, 0.01866929649916147, 0.029094651897227573, 0.03642150531372717, 0.06028126008928784, 0.017620096952023528, 0.03384280356488401, 0.065731079347672, 0.035066215336442955, 0.009432361806712804, 0.02391063067461214, 0.07447850875436299, 0.04215573854444008, 0.015745628230844536, 0.011412434790643954, 0.052639617314261776, 0.007498423116386778, 0.0443766312673688, 0.03225716244008753, 0.020387760033049894, 0.06505138315861264, 0.040323796321547804, 0.07158609017008735, 0.018488509325130333, 0.10894579272116385, 0.028327506771611593, 0.037671852736703815, 0.036035140360435175, 0.017095345876089508, 0.009021363296215574, 0.017378639444828998, 0.037899691115824446, 0.014342022045785862, 0.06469821662551935, 0.013151758898710533, 0.01812634508936636, 0.03929939887095844, 0.03691849336328526, 0.03198951621720147, 0.045466111717565406, 0.034052987447789604, 0.05251883589211972, 0.0653118147484718, 0.058273604109642975, 0.06118923132758468, 0.011641637763879713, 0.045959583423551054, 0.03853921365413455, 0.031175739319634535, 0.01833213162758658, 0.05512638085131204, 0.15757690093690352, 0.05987147199771097, 0.07552097055820689, 0.053542877111824295, 0.08968656447025077, 0.06843373795310337, 0.016511052531460603, 0.03981486113081056, 0.013389591852413311, 0.07862237792822623, 0.06378737255750645, 0.03561487218605415, 0.06479436832089579, 0.04289970951034658, 0.018754368647933006, 0.03488768237612901, 0.02497645241448716, 0.004623912316146157, 0.041455472894613786, 0.008383243656416815, 0.033101073406156034, 0.06187435524958757, 0.01321910951857365, 0.07764297282142986, 0.020414063661930062, 0.015770836353992984, 0.03601218070534449, 0.0221391519411437, 0.04362184313997146, 0.04561711147788071, 0.01462859447084127, 0.015958333500630913, 0.021175742750206304, 0.08304044529194794, 0.027838509019103744, 0.020777677719090736, 0.05087565007289091, 0.011236268084406132, 0.03794572150875484, 0.06806712657693895, 0.061682431072357206, 0.019534439592051412, 0.058606243316805175, 0.02972264864271687, 0.025533568790002216, 0.05694708456435511, 0.05930963077492291, 0.03545532288450388, 0.05125862891755758, 0.045788427889947934, 0.08576050941501895, 0.021800125475912806, 0.027690583186584617, 0.05541917965597203, 0.04099729485929974, 0.0860850855467781, 0.036180536187584364, 0.004216771058347678, 0.00535580542712142, 0.031725156511510574, 0.0651864291379048, 0.06785291307155164, 0.02325047930372098, 0.0756703270599246, 0.02192918830851634, 0.025183615995751276, 0.04376131710746596, 0.006576163380692203, 0.052393557533862135, 0.03505364766404514, 0.04142209061331326, 0.023991962399093375, 0.016949951964160128, 0.0499521502323689, 0.023758211736417106, 0.04043343116439158, 0.03282114104818433, 0.03435425918489214, 0.06157943821181694, 0.04888377550448622, 0.011854987505132393, 0.01671486064761637, 0.06079784849838865, 0.047277063131332404, 0.06321826116031697, 0.017516020077070402, 0.04992131136297699, 0.016831961017282262, 0.02315622367595713, 0.04005263950074873, 0.0071197477706347505, 0.04558110917587915, 0.14020306869379937, 0.00827625468974152, 0.06758531089872122, 0.018015306390401338, 0.08857494790948207, 0.035304434206937595, 0.04793420569190095, 0.03877847057376658, 0.10773863733535814, 0.06343329821022288, 0.028930082804553454, 0.026382208433783343, 0.06150390194248288, 0.03652162151411176, 0.08359642594211525, 0.03327472255595269, 0.034447626150663824, 0.01565760472834471, 0.022210813720800707, 0.05661218922825591, 0.03524743726537113, 0.08225245491391228, 0.0328301923770097, 0.047634366539216814, 0.03230840989178227, 0.07878331001847982, 0.04687325435600454, 0.0541057295706724, 0.03454264020547271, 0.05168581103545524, 0.0232847023665184, 0.05298270979115079, 0.06751429454814042, 0.04360605789829166, 0.030025381692534978, 0.07410063588571164, 0.008126970966376604, 0.055210616049026294, 0.0075200172197524345, 0.03196709090843797, 0.028818174595794374, 0.035961120945191195, 0.01854539326872797, 0.031231698212063605, 0.03140335553325713, 0.03244287364425198, 0.023487416892162254, 0.0350261872423993, 0.021867640804679647, 0.05180795992454214, 0.018326895416624123, 0.05662360393832769, 0.037860819814546455, 0.05515504403099899, 0.026250328312838273, 0.07293943045360428, 0.03074580120042928, 0.023645244411102707, 0.07126084754183408, 0.01221996041074876, 0.04436853754844877, 0.027747417334467176, 0.02237030939619628, 0.02164351220633234, 0.012817104880307472, 0.037562528159469366, 0.02600272869571082, 0.011120449954403505, 0.04193612028874698, 0.028478366720880714, 0.06514718245354391, 0.016208101146584077, 0.04404752755597715, 0.06527382444830672, 0.02785625736108951, 0.044743399691557696, 0.0238168595974604, 0.05048558491492464, 0.039689054171885216, 0.04112443481121333, 0.0566353289140088, 0.038364511133442004, 0.055581854596253366, 0.040743172003497044, 0.03089892493951465, 0.025840614914834022, 0.0663086406946663, 0.019296149858423782, 0.02589985266357901, 0.036926977787046664, 0.025898875901475552, 0.02845756551851669, 0.04714797731609114, 0.05664139249992948, 0.012808072703680205, 0.03297412880666314, 0.04437748545540437, 0.044168986965932196, 0.045802979730069644, 0.06707380931343764, 0.0961408092670383, 0.047610663778839574, 0.07253711938016838, 0.01756268440775814, 0.059442880278032635, 0.04575490771282104, 0.045830585708421086, 0.021208985220460642, 0.023544436816366452, 0.08789352036171383, 0.010011849864836662, 0.030355333846302766, 0.04478166195293588, 0.026326628754876798, 0.02727817890474633, 0.010564129352719795, 0.10144881032887967, 0.10123733175738205, 0.11640125314795202, 0.021571342893425497, 0.023483871820292646, 0.029056148318153237, 0.0063907313198151615, 0.06546116358931027, 0.031121709053554845, 0.1014820508839142, 0.07536141742621699, 0.08769975374302558, 0.007962965427131784, 0.01899448741647986, 0.026193440538801016, 0.029542123853799798, 0.07435559760779142, 0.04303973506114656, 0.05203048931434751, 0.04420629161740503, 0.0725646679019255, 0.062304567245225755, 0.06681460346425734, 0.047997021071252324, 0.012245031595680744, 0.01947472495357356, 0.03658032300130975, 0.06322124124234242, 0.04037706624536265, 0.08616742467687977, 0.04723798498631485, 0.03416028955290395, 0.004360779308744016, 0.006155853550280295, 0.01765861585285635, 0.04410320682631385, 0.047391616258650064, 0.07135810240382148, 0.07342739781785397, 0.017344989032754977, 0.031014577403003653, 0.05998594468579658, 0.023362460290832866, 0.012168968640898746, 0.10869222527910626, 0.10847866294845458, 0.15615793756179272, 0.1496146580264453, 0.2110686838146179, 0.22203996687406496, 0.12884796026252932, 0.11642440432502378, 0.24054007093992927, 0.1181677982751881, 0.1743644307697973, 0.13387889030479616, 0.08146916831573171, 0.12696986507263877, 0.1910359136039211, 0.20879386233225947, 0.29390767096511783, 0.0899551548965035, 0.16667995601892474, 0.10432727845205415, 0.11998772440898804, 0.1594703944940721, 0.0773658405148214, 0.16570012956377, 0.24922496458936125, 0.25300254414398826, 0.11158959279137273, 0.14407702210930087, 0.1821526031821005, 0.07839638965144273, 0.1432740853558625, 0.1788061013024661, 0.1361754380406872, 0.13325295050538358, 0.10223671643724365, 0.12278353930601191, 0.08225990128853629, 0.24778235974090718, 0.1242006257657082, 0.18162855307661718, 0.12579070253958627, 0.14104925877144261, 0.11051081841991794, 0.08676961575063967, 0.09652409071643507, 0.12357613387247249, 0.11966216768468581, 0.19378534187712979, 0.19360733368704397, 0.1295196048675045, 0.23504274656936047, 0.14459823768946434, 0.1346064746500023, 0.1042006824225668, 0.13841103582132247, 0.09859500257598777, 0.11034485313200182, 0.13536877809993683, 0.09998717585638647, 0.14234431508568027, 0.1843626289478233, 0.08875183761119844, 0.10526091746625402, 0.1370120826627939, 0.13643152591201568, 0.17558392017118393, 0.1114779584590466, 0.09040860999976436, 0.12636727563315822, 0.15356937243092447, 0.16798837290656182, 0.2803471792609461, 0.09119352836522365, 0.1296182003833594, 0.14094119440884362, 0.12375871560746625, 0.10657747020764698, 0.13578753708110702, 0.08993095417897548, 0.12788170122451362, 0.08451779988864738, 0.14659427977617712, 0.16639291819545532, 0.10473786327507227, 0.11989444554332765, 0.17581645849972002, 0.22140648876947744, 0.1589098326381176, 0.18180250100070433, 0.12640423937550477, 0.14641481601903517, 0.2793882823278827, 0.1830029760998103, 0.13580547886029368, 0.10350731922493828, 0.12228671596535753, 0.14547802838346652, 0.14185444782337836, 0.08117078473010371, 0.270152663391444, 0.2208640678755699, 0.09175101820860179, 0.1606760789910632, 0.11372554551569686, 0.23740035151281666, 0.12467682601944094, 0.1145691232335183, 0.17379358801389896, 0.09210219291309196, 0.2545299702474187, 0.16839764771922944, 0.1914741465401265, 0.18733586214723127, 0.12572643542361836, 0.20140148158515656, 0.12328721913358859, 0.21011202385829342, 0.11850778809598378, 0.22112891979275212, 0.1782904781641499, 0.17907286843945905, 0.1944303419440985, 0.09258636814211646, 0.2661038580681047, 0.10445077182544817, 0.1243574592855669, 0.0758177989853486, 0.09585895785881628, 0.1359306882706381, 0.16838943525668115, 0.10243080481286011, 0.14768302861240604, 0.2097039441427877, 0.16109316790055844, 0.19771278355150454, 0.09054230766430979, 0.16830190205045287, 0.09178433537242875, 0.09202450393669068, 0.22829093790102392, 0.22552946672564556, 0.15544166067434897, 0.12928415540485613, 0.185273262341657, 0.10886763643112876, 0.10304954338578448, 0.11652514488706667, 0.15603208463759194, 0.17784823092722124, 0.08429963336957079, 0.15675387735809052, 0.2705213661876417, 0.15771177837685232, 0.2050049446763531, 0.1269140708891134, 0.15695434724611623, 0.12014521676446162, 0.14060874289322284, 0.09403300261305225, 0.16083792272594669, 0.3497083815595796, 0.24589101122992657, 0.14903783978473756, 0.19463012235299235, 0.09162383229141274, 0.1494742341099247, 0.10791217923284539, 0.10017913450757343, 0.16956931791238247, 0.23514192431203781, 0.23120827732547639, 0.1072004758903096, 0.11317378600999234, 0.21719038516523378, 0.13999502985708176, 0.18047647941256725], [0.04463683303085066, 0.012615422658141584, 0.04006734838889491, 0.05083409363343831, 0.03168275354490165, 0.07872737027824887, 0.01331061297546952, 0.05412364836722132, 0.04029132568487718, 0.039673724752520366, 0.0627322473202742, 0.03324834997915933, 0.05858356328380685, 0.027949264265536785, 0.021952958101586952, 0.027644853483164505, 0.016852450038817142, 0.012114607999401708, 0.06204708126343547, 0.02839297089996117, 0.03904066416585157, 0.05454557895239803, 0.006535745060612118, 0.04325862170287198, 0.020387302295515136, 0.06216625390093654, 0.07711263313408821, 0.06471716964076604, 0.07832322825467394, 0.037089740827439294, 0.017155635080510573, 0.06198771711018297, 0.03930923160946658, 0.06367578036001613, 0.005898622771529782, 0.049441173417313446, 0.04172610877562435, 0.015548604780868178, 0.08064449764788151, 0.08638742214609539, 0.03043759445239219, 0.05199090555129994, 0.04171133860044422, 0.013749348656875233, 0.020623751502904682, 0.045341185759752996, 0.012445474670629108, 0.07319753313617361, 0.030237913634928486, 0.03603317534490939, 0.0386566472720475, 0.044245408066818794, 0.04487962544625325, 0.04733874087011622, 0.00684138062605334, 0.03435716648856479, 0.08560591287189916, 0.009967357393414264, 0.08619005491416301, 0.1072611500539126, 0.08471908949075208, 0.055407810911175706, 0.009637412900525716, 0.04093269832552441, 0.08999266256127628, 0.03429897444983644, 0.08275662503776052, 0.0556902636984183, 0.011406255333924727, 0.017258064866426493, 0.020684571223213308, 0.05527427029465476, 0.02459728102680416, 0.06818693506741716, 0.10248148918993051, 0.03296658284060898, 0.047746360932867375, 0.028100371278161486, 0.02580548978350576, 0.020543354405691067, 0.04377343661842808, 0.046663541617172385, 0.0170176339170505, 0.04149326784235816, 0.025609110804995703, 0.14504135826662665, 0.02556932594386801, 0.036263484357585835, 0.027037477909377026, 0.03129139178312354, 0.03481669283862557, 0.03079644727310346, 0.033924100815408656, 0.04061519701574599, 0.07297559746450956, 0.06459416656364357, 0.06186866704674979, 0.026961600730916666, 0.10334846323295947, 0.028706323843629613, 0.07548590671391257, 0.06117374869063497, 0.04831708877557709, 0.06995508131841499, 0.0846326517902555, 0.022238649525529435, 0.07509036785772732, 0.051140069150395935, 0.04006766631538349, 0.047945141597020055, 0.03493213845837501, 0.022835952958332437, 0.06689341858990731, 0.018182292490476565, 0.009531205343533187, 0.039755914495476795, 0.0584461922276645, 0.027130314359261144, 0.02709348085186174, 0.03774818573747912, 0.009677568356686784, 0.11242653618776992, 0.06213279884128321, 0.052172648420016614, 0.013467254973347149, 0.012656148849806238, 0.02351797230902218, 0.020288057520144412, 0.049013815099193205, 0.003668906630933165, 0.03643453646931918, 0.01390977225626909, 0.04125042180080087, 0.016643286968070655, 0.0036655559538743433, 0.04185891011729837, 0.032227874898742286, 0.052256776365421476, 0.015393284284659933, 0.08860788202934688, 0.033052909458356525, 0.044639870569470434, 0.09571059727140012, 0.021923873573541645, 0.040439456445916046, 0.03184249245321318, 0.05045564619884376, 0.025164301003960353, 0.08642735830958813, 0.011017058728142612, 0.05383369557920003, 0.04042447559655674, 0.07388191778332957, 0.011178376735188069, 0.02702970020172577, 0.03234664917052273, 0.014613675866125813, 0.02981414635395331, 0.04212058276959485, 0.03159738645227927, 0.012755972021559795, 0.055157499342796304, 0.04217016014961466, 0.042895001900051875, 0.04410306510004786, 0.05010346408873316, 0.024161924750754432, 0.014957781494294685, 0.0332462853722034, 0.025655575952823126, 0.005775969222022762, 0.027809644741336667, 0.04069076009815739, 0.05519630169616111, 0.05083679026293178, 0.03590978539338516, 0.08056539906969956, 0.04959807205464571, 0.023698002971228094, 0.052123377475166516, 0.045495981485733104, 0.027613309812882257, 0.018156659188530138, 0.04701183583106726, 0.010659603060283249, 0.08426955675766354, 0.0564917755283175, 0.028462114165567105, 0.05126043688505889, 0.02909371343952033, 0.06673083174973726, 0.05539459589448187, 0.015342261871292949, 0.030465920553392464, 0.08192154323501934, 0.04926761619806771, 0.0325277638471415, 0.04573297844598851, 0.012150324933651474, 0.044613226031463955, 0.08676991452493014, 0.02052887917436179, 0.029313025260043722, 0.10318950764955052, 0.07082602369689173, 0.039971081780329834, 0.01613883722213007, 0.06528324732977538, 0.06717324752600924, 0.03867497209519629, 0.049286136373637185, 0.05816451701966505, 0.051637708374689666, 0.018772666658004446, 0.041353150361007264, 0.09859766090108503, 0.042250852190679124, 0.003736892624968483, 0.06312173025141801, 0.06713307387525998, 0.010399802535351728, 0.026493702955063314, 0.029900223993125464, 0.07929625184906107, 0.04978800440327295, 0.06602957018560941, 0.02911406456522884, 0.0612426046732693, 0.013759923543060019, 0.013609859367622244, 0.007559336203661177, 0.0072122342140984634, 0.018017079883946047, 0.0341444774981468, 0.052806157168121114, 0.05500096459722808, 0.05388725661642609, 0.0745776252100064, 0.02384384504459318, 0.047962328779601285, 0.01948468984224864, 0.019405416979063905, 0.08235259792737423, 0.023701446536447734, 0.020262535300947005, 0.05518968269649533, 0.008066467257336745, 0.02965599707808466, 0.03385187021546787, 0.06667785676977327, 0.055743499148276546, 0.025319016290708415, 0.040672193957312454, 0.05093946902742309, 0.042493464575419505, 0.023708693728211428, 0.05723394618760194, 0.05617588300318007, 0.03912532837280343, 0.03396314448646961, 0.06568120702380134, 0.0546017523494459, 0.03161930422779293, 0.049836007472608364, 0.035573016972311085, 0.02332340704367286, 0.025684943933400418, 0.027950652799899542, 0.03456563816495961, 0.01507658257915248, 0.06735030576706895, 0.05190396223277335, 0.06421173547184275, 0.07364685902552259, 0.06872520376477512, 0.025756877674270543, 0.032684562893043605, 0.06491560173491318, 0.06097284979337166, 0.09339380949254959, 0.07494245926218648, 0.0560951181837628, 0.017084159077175202, 0.030192542077612974, 0.05011316659229417, 0.03471394895666069, 0.08571246038040808, 0.04919630873407568, 0.03304992554589145, 0.03656359930192271, 0.057727348945674405, 0.022235937574277484, 0.05219537058785077, 0.04691841523914088, 0.03264193776093664, 0.051437644513263825, 0.02861113167337833, 0.028577950490157933, 0.10263457653983947, 0.033298007798411196, 0.026634816350715778, 0.057816402836432385, 0.06015187933019573, 0.016283949596747276, 0.06350965419363591, 0.0537879103344054, 0.06699507079658008, 0.03783188084320676, 0.04171724896878005, 0.018832840949236866, 0.061056364868437095, 0.024457605961229534, 0.08103825151920319, 0.02336268820199034, 0.03428267592924737, 0.10533746497164811, 0.0738288585336939, 0.09128573470779004, 0.03708659603651013, 0.040547945987313025, 0.01932630307912346, 0.04341620598889647, 0.06886083197088973, 0.06642562998158318, 0.03288416327127526, 0.03799861221904716, 0.026950697384534344, 0.0486953676708283, 0.08206083334141201, 0.027612147274457162, 0.06900918489742665, 0.04556875600810013, 0.0435944669879973, 0.03242170663490411, 0.08840709804527222, 0.027159827896544052, 0.02185683130406805, 0.008484218832886508, 0.014688662467374197, 0.04491470461230605, 0.00800244433189472, 0.01624984910801774, 0.03101350487990966, 0.03299207058584979, 0.033933822471167774, 0.04736443928953621, 0.012332614597624109, 0.04317791050960941, 0.044684207908088164, 0.02433509701081822, 0.04932670072922784, 0.035704803247485435, 0.17974186238021622, 0.11171381394829481, 0.08390418644393645, 0.1658059722713886, 0.09691546971519148, 0.11690956014659136, 0.17474419587562162, 0.17499003349052322, 0.1556932286269242, 0.3193546296848405, 0.1862737884925258, 0.12391723452075837, 0.2567174883499261, 0.10577244203417532, 0.1432152191597608, 0.11939995877084233, 0.0898291947199933, 0.1256730544170545, 0.21727805626728844, 0.1310648042107782, 0.16309028251036523, 0.180935105609317, 0.10355677786132983, 0.15936692665901878, 0.1886824608570145, 0.20882848950643695, 0.12600539101948663, 0.27502403264084174, 0.25192019980280633, 0.20287929583461056, 0.08826691161600814, 0.09986728309623658, 0.11542412332229077, 0.11347819870758442, 0.13834430956311766, 0.1766035219113673, 0.1351273378297206, 0.14650009692676608, 0.14397193016784807, 0.16358356652480943, 0.16358906703610576, 0.07463249242714337, 0.10545294506535416, 0.1891154997170933, 0.07923900975935882, 0.199499438486753, 0.17214715781231082, 0.13787308888089272, 0.12790924208539148, 0.13565380877304462, 0.12005595219952446, 0.20943739151041355, 0.20171781461085045, 0.1262448011567035, 0.08506837961894852, 0.07447622581234864, 0.1645744093243153, 0.12454209413619773, 0.12963197464423795, 0.16513077301844475, 0.21779099809786967, 0.11875320436252702, 0.12690616486173484, 0.15116347330472163, 0.26056430693114957, 0.12011269633207591, 0.18697495812610274, 0.24886468876033063, 0.13693902851833453, 0.17822949756537715, 0.12412400165152167, 0.18204414045378087, 0.1412376244702647, 0.15873383159839338, 0.18874498895339428, 0.09988861864492779, 0.14002890626509346, 0.1585982646793127, 0.11986947873787535, 0.0636704215749858, 0.1574072890704678, 0.0938014755205762, 0.17916772544624346, 0.22903140784511644, 0.16676948105375614, 0.20407898952403378, 0.07813435693782184, 0.1415989575006308, 0.11838518338458193, 0.10838909194834771, 0.17074956829028745, 0.12031673618982877, 0.21079785641162627, 0.14514208350691105, 0.15234396883076237, 0.1374593707582643, 0.17959711772780265, 0.16006038944807746, 0.1601435099878619, 0.1485415527056302, 0.13436898739347536, 0.2284444925645667, 0.12993965087638748, 0.18413600481806264, 0.14547041346949918, 0.15470116008673945, 0.25700362218964484, 0.19710342189477337, 0.14802949953704111, 0.18440747573491068, 0.22389578422711742, 0.1711037613811993, 0.1811394365804811, 0.13935661814626188, 0.0936045679413984, 0.1178033932322456, 0.24437199677190474, 0.114709455219488, 0.1302907642938437, 0.17151639165897525, 0.11226485333135051, 0.30790072655485523, 0.26479424608330576, 0.12720168327852605, 0.18000276128370918, 0.1388536048151793, 0.07579811818657384, 0.17028144260327663, 0.17513056465935323, 0.1632711865128048, 0.24552073029260485, 0.15932499100604366, 0.10612255187645074, 0.12569818210097092, 0.09668634813879767, 0.08658413054241289, 0.26318077298422016, 0.08645139048777281, 0.12054133018659008, 0.28328546352924844, 0.13811943211382435, 0.18673786923529642, 0.13301086672131093, 0.16594359230610634, 0.15871598174975765, 0.0870154916699375, 0.1590863546176303, 0.12245911639183761, 0.20772009817582948, 0.13116539155523624, 0.1734136543687313, 0.1032684836536646, 0.165723571854253, 0.11520421012274681, 0.17920800634930212, 0.08152195177371464, 0.07267650141711197, 0.12865567219353494, 0.12510300073171818, 0.10111524032488947, 0.12599431338810152, 0.10168602945463312, 0.1704863251577462, 0.2323564745846295, 0.21133174308605734, 0.11960841129503905, 0.1659725810731611, 0.09271404435557705, 0.13135565715211053, 0.10574875459555658, 0.100182244824546, 0.13901295110342965, 0.2443597853303917, 0.1668748334651032, 0.1541458535939455, 0.197011721170237], [0.045750131154613155, 0.03149803633981895, 0.047429947467941436, 0.052057919092476375, 0.015159972207320314, 0.04036541787847396, 0.05824145522990054, 0.04145961743028414, 0.05862428468742198, 0.06216780905942283, 0.027115065379128344, 0.019147082554897474, 0.02955406524931952, 0.026484172821285266, 0.015836028521129444, 0.027842096225809188, 0.03254857462560458, 0.06159125894848859, 0.033990421047013615, 0.037648762846666003, 0.11609526230923592, 0.03308613086119294, 0.048051551209702614, 0.012669161810810048, 0.018277494236826897, 0.04027736373245716, 0.04930608530318545, 0.013118796050548555, 0.04808082342928937, 0.05303607930639579, 0.053319999152013374, 0.08564699050639907, 0.10574318513634706, 0.03267449649771856, 0.02803557173108622, 0.05514800751341447, 0.03439021935205787, 0.052579375990335984, 0.032263980622613625, 0.06268874118705431, 0.05660983733832837, 0.03412492310387954, 0.03392702727127941, 0.028569535014309713, 0.04118618532834996, 0.045557663054956545, 0.04729259939443681, 0.02572054212402192, 0.04913294560185844, 0.02978259502279182, 0.038245936044521874, 0.02013140594616773, 0.05717370486367614, 0.03191366776703827, 0.023641599747802944, 0.037297549837779616, 0.022071812812599446, 0.052693323908193465, 0.03374078363600758, 0.01754523292484303, 0.021499257850190325, 0.06251041890091955, 0.03259148704068315, 0.030760056181480328, 0.026008384339811823, 0.02506453720402093, 0.061586084024560075, 0.06330512787005113, 0.03952616089654546, 0.02266977891145695, 0.07361856739847891, 0.020044954839132486, 0.04148564143707195, 0.017756634887548226, 0.07055996902166836, 0.03470723036556475, 0.01981254483032371, 0.013468572644576913, 0.02082789286730751, 0.017989381975043687, 0.011334814762155856, 0.07617373109584855, 0.05693901765851244, 0.02055884470352002, 0.045522120405709555, 0.05279381166122133, 0.06592332145139095, 0.04104885257660382, 0.03291027154773474, 0.05461085347398635, 0.04410091239298063, 0.05339632449190944, 0.016058828914538026, 0.03258077713150171, 0.057087221197904124, 0.03820543297596517, 0.04833551702059565, 0.021671602735295895, 0.013175246196859067, 0.008212392642763595, 0.067959000927306, 0.034033601592865684, 0.040017721213160024, 0.01902262391071887, 0.045548554269536856, 0.028421442557667053, 0.00907931401724777, 0.04129943227575671, 0.025748282167760116, 0.05934127786707494, 0.08342111438152292, 0.05923624338221647, 0.058606760426154064, 0.03437673237415091, 0.13839551487997656, 0.012797331193371887, 0.02073524985462427, 0.01522808125422847, 0.02823285660856674, 0.04455247142862889, 0.05943908814280745, 0.043083624238328594, 0.0387370596910196, 0.0267684412369084, 0.07157974696207432, 0.04735215890010999, 0.059073200719731475, 0.05613914142633158, 0.024544415214369376, 0.047872355583334164, 0.04352519731788386, 0.032649020243796616, 0.013755670797470358, 0.09044481531506585, 0.055753538730524244, 0.06335870805947531, 0.02787905996815572, 0.08862310419640235, 0.10152911166510276, 0.029605802997285803, 0.027638933538729628, 0.0747042672047692, 0.07513390463446418, 0.02766548997662481, 0.022599576529295697, 0.013192621070981748, 0.08132460752441999, 0.0301411816279494, 0.06839971598838607, 0.0398147079132257, 0.06301821645108924, 0.01814352461106835, 0.04525780475007431, 0.040353099184651534, 0.02663968483947458, 0.08471276160449752, 0.09440360530730217, 0.1303186498942875, 0.07811494426982057, 0.03464493592600188, 0.010004964649617192, 0.03642216031890243, 0.030209890138658307, 0.029879660278017965, 0.032954264146786545, 0.02295226234221651, 0.08501916613069274, 0.01337261247118154, 0.04188875690282833, 0.0549059696946173, 0.060261935521397865, 0.051260524985170176, 0.07240671589369736, 0.009841018960991455, 0.03671949053363454, 0.10523667844432978, 0.028357527842144334, 0.03792661527592329, 0.04523859509537297, 0.08782284875069896, 0.04083738549642506, 0.06722085222962403, 0.06042264927659304, 0.0634374006110574, 0.025149821942191453, 0.023183921584859494, 0.06673272398691024, 0.05995312164868078, 0.0301209932959248, 0.04737018111852869, 0.029646346285458536, 0.0882434080384912, 0.003933836114517744, 0.020505913773611672, 0.04968881133883711, 0.01651560309373083, 0.09789069198192128, 0.04633124331913648, 0.05323770981762679, 0.00346732615481972, 0.03640059111339431, 0.030382376750029867, 0.02758267012635066, 0.0140783661833754, 0.047524363974169384, 0.016692473643249082, 0.02381932065491715, 0.020632781764312137, 0.0458971472577222, 0.03257824138047234, 0.046841879225065636, 0.03896618892829265, 0.10613213563638349, 0.022044609030408245, 0.032870599684575875, 0.04830349454536073, 0.038003507520883315, 0.04309766279954103, 0.061371433849055926, 0.015198948845687895, 0.0381368029892685, 0.11307003472240702, 0.008926059085605367, 0.03947283734657592, 0.031105240078402624, 0.04933926840162566, 0.04485804474942627, 0.05013185913764662, 0.05067824836700194, 0.017218092313757347, 0.03273568010979122, 0.029559343595117814, 0.024775708650028514, 0.024022106043694, 0.005861560395362998, 0.0483520798415186, 0.06211536268012659, 0.056253610283977566, 0.018591986736282706, 0.013511150853798516, 0.06582617384171294, 0.06488626056741323, 0.027177290870778026, 0.018905705486934994, 0.04721799775237038, 0.023797753364628842, 0.08843051735311748, 0.02178363351812286, 0.056732353949618924, 0.039040200682657386, 0.028164749476878394, 0.053410979753900925, 0.020858145679437348, 0.08104590473756676, 0.01981614544356783, 0.08292468174570992, 0.0534865198536746, 0.026227860869238936, 0.034225372552511193, 0.0484271947624943, 0.057553627017524936, 0.010732804676668059, 0.06847934316723578, 0.06864219813817932, 0.06788364851907377, 0.057305774591382475, 0.11384597453739374, 0.07757145085281904, 0.028689559924626545, 0.023400471658415856, 0.06990354658374864, 0.017365288447528597, 0.016477024821083874, 0.0023147916410028216, 0.061995741881189816, 0.0259077433691991, 0.0600268078156777, 0.06251871180269988, 0.05313446797851113, 0.05774228382975825, 0.04487692881675978, 0.029440237990310116, 0.053049888041230946, 0.0675576014985, 0.02604623482893071, 0.01953333642544045, 0.06614959318070643, 0.02975555403428453, 0.03382237199994345, 0.03355341002104744, 0.11359965428709985, 0.022569863809152477, 0.024754895956345627, 0.07951098629423688, 0.020981625646292683, 0.028622416148502982, 0.012810262757533742, 0.04499180753144526, 0.0186590462427346, 0.03633659978907916, 0.047234928295496977, 0.02105096426431931, 0.08879155160919314, 0.04207494691194546, 0.03184881650902812, 0.015699201387413327, 0.02346341535749455, 0.04374067486834623, 0.028598351411581523, 0.057223646135459987, 0.06186556056021683, 0.025292626476936766, 0.010152332195561501, 0.047529098397541436, 0.014860579300852073, 0.08356608886031375, 0.04133352701882682, 0.028918953462233467, 0.054348636899263635, 0.01781495907644351, 0.04766530116959926, 0.07227541608435493, 0.09702726492598172, 0.04854081709298396, 0.04823054382277112, 0.04682609015294621, 0.03795412166284458, 0.03807894419878721, 0.06131508425178547, 0.04276667834229527, 0.024669155395860155, 0.07762234207362899, 0.04880782554767305, 0.02383655954843327, 0.04301043985892208, 0.06027116688088544, 0.01732631372438083, 0.040708801468774196, 0.037050386890769005, 0.015281909464618132, 0.023041754818311142, 0.054579344277660695, 0.04073149299309139, 0.01399070178459008, 0.11048081841680313, 0.05165838125732638, 0.09222156473345335, 0.019239216119111068, 0.020430818004834077, 0.061787883075134414, 0.07670495178430312, 0.02141123243247069, 0.09810295196310168, 0.08169606057626587, 0.14488452474676794, 0.30180340212198997, 0.11126528479038708, 0.19039842119861036, 0.20237378505689485, 0.1419152905263247, 0.18439618359890678, 0.15238071040761086, 0.1701871678233147, 0.14665184362280756, 0.16487949617928074, 0.24327224691308316, 0.22573240341678744, 0.17574639209816534, 0.18094386965517076, 0.1771366271761156, 0.13823276716134242, 0.13281295556695233, 0.2989838921254681, 0.08660137518158845, 0.23034825169992065, 0.11144298654530319, 0.0668453618944172, 0.07275443554164902, 0.0996717774579602, 0.12881557006509076, 0.1334873427666964, 0.12438096286308382, 0.0615587423465425, 0.17347648890028078, 0.17195635595388953, 0.12898355782512697, 0.20157507710879852, 0.11734316591173412, 0.2385151779819881, 0.19431515296380367, 0.20957366323038457, 0.1905576295910343, 0.12325231616775836, 0.12036304620485153, 0.18624709798924385, 0.15317074624040436, 0.17264042650499653, 0.2248075361093206, 0.18267254705630964, 0.1395291564685683, 0.19398719072341922, 0.12131369237097041, 0.1457331509840104, 0.14021367135067142, 0.11239395446835027, 0.14314542854985884, 0.09439127129172126, 0.12294178242765127, 0.09243842124217942, 0.1304234354005706, 0.15111203816148544, 0.11482237657952694, 0.12738570525881746, 0.1813607593818057, 0.11202573430754485, 0.18277371662759012, 0.17748561086914233, 0.16127214136142887, 0.1584274117504397, 0.1035133176933854, 0.1534625338090043, 0.12059813560617548, 0.2007031924421749, 0.0710343766296583, 0.24698320746181474, 0.13195784822587045, 0.1519856848303349, 0.1611621158137437, 0.11320223085462086, 0.12232308982000237, 0.2362182778456519, 0.16993624338459584, 0.10220958926384488, 0.10353213281280572, 0.19209026509234983, 0.061836092988209385, 0.1362820315144716, 0.11145433996834102, 0.36106683013419955, 0.3281297991352697, 0.10474277389866692, 0.12750991109398105, 0.1800054885567196, 0.16014996044818433, 0.08598259830426785, 0.08319078238620874, 0.1316734304231021, 0.09506971109658481, 0.15656848408041463, 0.11506513452097294, 0.13262756228927644, 0.09190154682484367, 0.24072163377798375, 0.18016757743973888, 0.2049249804188167, 0.17263869514628766, 0.17271484428596112, 0.0543146800520199, 0.12001076833375039, 0.15567580778752604, 0.12970026372180832, 0.15299414765209923, 0.20453315708906422, 0.14406307930907897, 0.17020647323900656, 0.1311772505963041, 0.19339120496184597, 0.08381285344160373, 0.0879350882924853, 0.21922752020820496, 0.08790567817707216, 0.0753100359091355, 0.16753311749667893, 0.16072271842389338, 0.111626579516357, 0.21119479720871295, 0.11411536169508774, 0.1601240207110682, 0.17941791444055497, 0.14931402980319916, 0.09667331698320566, 0.12261974970780073, 0.1266079191719332, 0.14871724731018468, 0.06643934295542779, 0.18325388521677066, 0.10937820338914472, 0.09797929005036432, 0.13781524924260957, 0.14921214010926986, 0.1263592700143495, 0.12553978576174668, 0.11960010690193985, 0.1270886699879362, 0.1513412976337056, 0.11620126589531861, 0.13940229230830747, 0.31022650820593684, 0.2436868077324283, 0.15517434195405053, 0.2029062008425113, 0.12728383854752587, 0.1725687819623178, 0.1349247382172654, 0.1510973905603732, 0.10293884368072595, 0.09258225424996308, 0.23065995755455188, 0.21298514468775642, 0.26560032379723364, 0.14657587834423588, 0.1020008762697539, 0.07803117255530051, 0.1162384364814047, 0.22435868519448468, 0.08216499065559718, 0.10455598634096885, 0.24518530635583788, 0.11709293095214714, 0.16203366340168063, 0.152485970888407, 0.12212530123971163, 0.22272561556629597, 0.15921957730766267, 0.09031194502547865, 0.16401740211632945, 0.27309600384004656, 0.1623577952024437]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.005971279029073495, 0.0027716879154585546, 0.04458114993007434, 0.0671380381250093, 0.012433451878267431, 0.09112934551892743, 0.01834715844222134, 0.041112418722120986, 0.032669861665776664, 0.07051733622868216, 0.02040158025920391, 0.043632020618045525, 0.002703631297692717, 0.027165895312904354, 0.031166168966240464, 0.08310455919033097, 0.03103729190995857, 0.023857052400407773, 0.06374207377854375, 0.04332225679630234, 0.03326757878605877, 0.016989851738476468, 0.03812896590980311, 0.018467344231002273, 0.03421138761745345, 0.04566807547704347, 0.027234573180096287, 0.053059019809288364, 0.01963580260053277, 0.03721193185136203, 0.05062264187501804, 0.08333738097139905, 0.037646131334646095, 0.010752757436655944, 0.027886056266124212, 0.010927119048222179, 0.014333267576031148, 0.016989482101053, 0.03432579135762588, 0.0839910684754291, 0.0673317204740259, 0.04081788472831249, 0.031368356806436376, 0.04691465374743266, 0.021052701368687615, 0.006450433988169197, 0.011450408811440632, 0.015164779409045174, 0.07392155517253184, 0.021219373372713887, 0.031092471307924682, 0.03898555563101846, 0.02829461095614299, 0.06352460822991787, 0.0451754579590934, 0.019519523860165672, 0.030298105163139202, 0.07247441508356603, 0.08067626731410142, 0.07423032691041309, 0.069746651776856, 0.04067186836994464, 0.02840646362352756, 0.1033551971458139, 0.07372480847181813, 0.05873407274785061, 0.08290655610542144, 0.013259271678004055, 0.07043677442256482, 0.12841473754134872, 0.04763181546642896, 0.007959295387169527, 0.03840234821602222, 0.07565930305469422, 0.04638374715502705, 0.015238387052029853, 0.04772913927632955, 0.013573998791886675, 0.026539649078322035, 0.014221866900521903, 0.06877267057256353, 0.059718928570228244, 0.02188300852844071, 0.060905154433942614, 0.0224406669111622, 0.0470792094335681, 0.07964457670647292, 0.031301484991525935, 0.10078235980003111, 0.04430660317021032, 0.07685388693766249, 0.03120442739717903, 0.017851855786096667, 0.05631423082142588, 0.08445008537702023, 0.03521889665975206, 0.019430303345284155, 0.06766182776059836, 0.04882208627438353, 0.09205594418510314, 0.02688856190821577, 0.04594189445337942, 0.02600285701543814, 0.045504442926856785, 0.04054897254513156, 0.032983026917903654, 0.01715532673012105, 0.0280422788308633, 0.05002704681828619, 0.05336897898345225, 0.0544567127531815, 0.011882392385403716, 0.025658665202377785, 0.04310266152324696, 0.045325231978729855, 0.05598936740669513, 0.03523367832625105, 0.03195638099925653, 0.04134543202517014, 0.028630509867423007, 0.018709843617773825, 0.07354213480627345, 0.01837430859825784, 0.04177285163032432, 0.07799864446203555, 0.03729939227923751, 0.025697277948981332, 0.027638835862519282, 0.07773938498670056, 0.04889450839630539, 0.03210633887999481, 0.03598454791391569, 0.04222772016580548, 0.09482640157183332, 0.06306114418792629, 0.04555464083809526, 0.04248058280697273, 0.05342967612969299, 0.057104492650157025, 0.038932228250609296, 0.018598994525570064, 0.11105667904860551, 0.06343325607538705, 0.026576325537696965, 0.008813372339993235, 0.05492482694887346, 0.029369284841983073, 0.01584083189241468, 0.03474001126784471, 0.059761343028156035, 0.01383978150589692, 0.06151453907331152, 0.038656601306772044, 0.015062332386150958, 0.05260569494097464, 0.03785455321532585, 0.06572416157371576, 0.038239439618923975, 0.04949256259527418, 0.05460266016363617, 0.031979729443968784, 0.03380053849410146, 0.04044383846884293, 0.0881342864745567, 0.04713021939800632, 0.036126618919473504, 0.0863544727044721, 0.015256694638200346, 0.04276901491046433, 0.07866624412277053, 0.06265989414626552, 0.027819646019188148, 0.05231412953787273, 0.03375276908158295, 0.068026615847503, 0.05653448876053576, 0.06751359740812933, 0.04945371427663392, 0.005326845388363807, 0.032417654029784665, 0.06735557645198799, 0.10000447412171673, 0.021320699992018844, 0.02149946086349026, 0.019660583629663435, 0.04357598128638441, 0.02551180614729322, 0.016249274542074532, 0.09910789844129356, 0.07118654467405812, 0.041860641476007245, 0.04657017082096108, 0.050870226170387, 0.04294528791140165, 0.02487241001349063, 0.041033526987678585, 0.015253691573537167, 0.013898612270432134, 0.06037071617620607, 0.005561580952827729, 0.015324614078347242, 0.01837221909344437, 0.08455011347729353, 0.007147503136131432, 0.050173725842708544, 0.008049114408241886, 0.03390817767790249, 0.030180185079394333, 0.020441564303191922, 0.028018828879501072, 0.05318518682953812, 0.03176883501451343, 0.008386723610812859, 0.0557175747329189, 0.043535773161678545, 0.10641112953664796, 0.09409304858455736, 0.042821878807679306, 0.01378562962335925, 0.027830832818102454, 0.013082345587111289, 0.032550608589043545, 0.01642861380992878, 0.02023864867946794, 0.05325194373125992, 0.011934150243178012, 0.03481886086745128, 0.016349118781246005, 0.03264843801697416, 0.00799044978902525, 0.07981727590724345, 0.024026539777555776, 0.09198969290141137, 0.04025770974675975, 0.010108906501573662, 0.03377965110684595, 0.05059849861408434, 0.10615563155302118, 0.05944221761197813, 0.1193045961460279, 0.02714352363029555, 0.01625473866419446, 0.05114413324683424, 0.013281425025554435, 0.05554027134372343, 0.02381386419367646, 0.07192864638542937, 0.08074105536985783, 0.0454578417984228, 0.03754967703453956, 0.04558693144410368, 0.016621296414204182, 0.06053656655093355, 0.03153648437751878, 0.051392364886499224, 0.025530946854081367, 0.05267504888075975, 0.029088708970154968, 0.016983698137224685, 0.05633265906644445, 0.010579156167354557, 0.01506579031551918, 0.0698180818149159, 0.039392558992990566, 0.028996435594895197, 0.0533289700416067, 0.03545232748071994, 0.08362732992898073, 0.021142094253352093, 0.04800468578093475, 0.06345731506664908, 0.05336069374255115, 0.07280397844771225, 0.057542480438226656, 0.06368495043246977, 0.05926500232289395, 0.06014898734828157, 0.023719936068500244, 0.04723402814218595, 0.07522682343880016, 0.02183534445301179, 0.029488091672500296, 0.020558459744338068, 0.01238242467685092, 0.031889614521435676, 0.05153270453334816, 0.06505660787825623, 0.025558617949906378, 0.017150892996259274, 0.030434499457178098, 0.042996010592868256, 0.04304847229392298, 0.01079292534174578, 0.01289297822832821, 0.040807561693532814, 0.03953291396159799, 0.05837319553979944, 0.0570780894298467, 0.03870934262991913, 0.016855384155567137, 0.0038440324152038707, 0.048664275992421374, 0.02055922966270197, 0.023595653624544223, 0.05966311906494441, 0.022916420918679046, 0.02382011930157821, 0.04050134868931867, 0.02852232484597593, 0.08872458020285254, 0.02698566546783813, 0.03433360928489316, 0.023302341540974957, 0.007407662285972508, 0.028501990957245715, 0.010108013051531969, 0.034475844999354695, 0.06540806603527839, 0.03713864021964612, 0.013585272733302367, 0.037057063347029115, 0.0649036507632944, 0.03138612430062025, 0.057687700065153266, 0.022141381257003354, 0.0772402557213941, 0.02983100028828748, 0.02580475816953807, 0.07045568913341531, 0.04036570516144557, 0.029696875529724266, 0.061352036502813144, 0.048466548699164586, 0.010218739569667849, 0.061791797784427484, 0.027679158900413784, 0.015704925979427513, 0.04881167896993218, 0.06219233536431867, 0.06536442966711137, 0.02237938179243957, 0.01117316350686334, 0.01175935100388503, 0.03361161738153427, 0.03511547478997419, 0.023156696735250375, 0.07517971669233615, 0.03170752116749364, 0.018541909483892303, 0.03602782805119792, 0.040872954958749395, 0.03869273001328111, 0.13891979481183714, 0.109709030798366, 0.0927632348611951, 0.24999252340245634, 0.11369610475676675, 0.1250503168651654, 0.1203465753144795, 0.12298907303521711, 0.0971150279585873, 0.1451669507209332, 0.07009297714478548, 0.11069630362814474, 0.18054162752964806, 0.17666934418582148, 0.12209838857093167, 0.14718038300352712, 0.15042540887671133, 0.10618579243460011, 0.13964947823795582, 0.12695826650146516, 0.06378717337464614, 0.06784133748301575, 0.15171828950124402, 0.09050863810003766, 0.14418289546043644, 0.15901123203577536, 0.20587583342867516, 0.14557552073271046, 0.17614832778851833, 0.11305293563993708, 0.2075453535203011, 0.2647057169627759, 0.06740063774369418, 0.12040158808832208, 0.16238796374490186, 0.1416358216515472, 0.10731667610666445, 0.10495219169364822, 0.15629780989500786, 0.24458803356655184, 0.1863205198559069, 0.29227002013114195, 0.11304643921433918, 0.15001271731190144, 0.15511205900580655, 0.07041105685094673, 0.1080479836391826, 0.10103592724208871, 0.18317690870213896, 0.10945031524545724, 0.13997227704573062, 0.23021855301433997, 0.18704713893032845, 0.1832932468143202, 0.183900831147067, 0.1658415340728337, 0.1767145893386295, 0.10819036107991012, 0.090333127356585, 0.16481217237249499, 0.214897284825002, 0.14133690946525143, 0.14730758424247467, 0.3278525365937141, 0.14656739009003486, 0.12370067678632275, 0.1615609411871241, 0.13711829309261617, 0.18889344147136136, 0.27230059007002466, 0.10004259465682892, 0.149081047143667, 0.15019702274472485, 0.24150782384939734, 0.10571837154847961, 0.08950826516675373, 0.17594932878930725, 0.09951225496948728, 0.1195989884135704, 0.08095707684274643, 0.15962044047492166, 0.16618219805100273, 0.10350839174803227, 0.13498735824419608, 0.07497409869345927, 0.10669848145616632, 0.13512995785042164, 0.16495521630971663, 0.20331618045606922, 0.18572936044825664, 0.18617234312959258, 0.1698703904666247, 0.11712977978130502, 0.19391442769237105, 0.15033167035829637, 0.08536021315282391, 0.14622635838966216, 0.1675449612159883, 0.20465160960391646, 0.2241978680174197, 0.13598235324025154, 0.11735849533109896, 0.11392332643510834, 0.12892096844171325, 0.1940369251514635, 0.10458235508732258, 0.09297460618038332, 0.14143216483775647, 0.10440017171804944, 0.17457455336566896, 0.15059935680079847, 0.12261959649021588, 0.2527261089773909, 0.09892434377463595, 0.16082935786295324, 0.1381146210816599, 0.10957085151946354, 0.14480990778294303, 0.18490003962670604, 0.1675363197442024, 0.10039196905469704, 0.1800091351352392, 0.09491871516670912, 0.10521131327315685, 0.22555228082403062, 0.13765555055391404, 0.14298387592838657, 0.12912609614431858, 0.17987191346624207, 0.14794553630053997, 0.09272483853443016, 0.0895270343208986, 0.12343820740258503, 0.23035955915768302, 0.10485537350177766, 0.15482938788350553, 0.16110476647173205, 0.18971917700142632, 0.10347743413501209, 0.1855205861671317, 0.11363106389199534, 0.2623193837221592, 0.13980767539431974, 0.11613271634785399, 0.10857072373431538, 0.11758921037037527, 0.12057498442910372, 0.1371230428377467, 0.20751049651974635, 0.16641957805522029, 0.18511336447010118, 0.14740719099438962, 0.16892552826433413, 0.1997940299371558, 0.06882299488830952, 0.10859043517660712, 0.14664928488914045, 0.1680814832328789, 0.1999461903206764, 0.134040902579023, 0.13126740382323343, 0.18633021852902829, 0.13920485612846192, 0.19179861541957627, 0.16056220768199814, 0.10964384437688898, 0.13472748589852165, 0.06859331406773099, 0.0956036743798083, 0.1517554907308471, 0.11240867867825494, 0.10684326441297609, 0.09912278352966232, 0.0883187910902404, 0.13818277226340386, 0.17801796536772482], [0.022553910028129336, 0.07410972934937285, 0.09524815595678746, 0.028466955841248556, 0.04394537739215359, 0.025036370066264947, 0.04285387446983688, 0.04872968840983607, 0.02828694433124075, 0.05700942113875382, 0.07086635056522585, 0.005180327721210498, 0.10277281710577589, 0.060261123468198126, 0.025077388328950734, 0.03865179793548681, 0.06555989700099153, 0.017197197265622598, 0.07901914252509033, 0.033403003978873455, 0.04792203255478413, 0.033259626793404745, 0.037150556717308304, 0.06277887526178552, 0.0391827198496509, 0.05198040248585805, 0.03668489783341366, 0.03833169192676583, 0.03648086180610042, 0.06401997983395573, 0.06781583441601646, 0.06956930242238507, 0.04483495485938845, 0.03293348784228006, 0.06929334989118, 0.024197260556261868, 0.030813975364811, 0.024393976613458608, 0.053114239426870505, 0.028522795990049362, 0.015270153845420048, 0.04262700902238008, 0.06627164630880279, 0.04905295070080508, 0.020365560720224055, 0.056157129170793685, 0.04213878501867575, 0.017844338548339663, 0.004654136878783785, 0.036167665910456455, 0.07556908854073094, 0.044530814123009486, 0.016672001858692498, 0.03374693915247917, 0.06556268556103592, 0.013577392561391238, 0.03960811315224536, 0.03678734677152769, 0.09797870782354186, 0.030438368201195717, 0.054000538037789446, 0.010622297451200505, 0.017329012269094106, 0.028290996936360197, 0.045369680400096604, 0.040393671201121424, 0.01575817866626406, 0.050794184283022924, 0.03809969369021635, 0.04677746272195251, 0.06570870191940377, 0.017713462002575397, 0.05588118813090748, 0.035063101189030756, 0.06956983102305282, 0.027901902794837955, 0.056696052873326894, 0.038058493481648546, 0.07164219078878242, 0.0385008326491281, 0.02800707900596242, 0.04898261233803727, 0.038647423573439164, 0.032801146153360605, 0.06894256589153121, 0.04269382721113582, 0.055144740148417415, 0.02905860937560999, 0.030889678258268587, 0.08894971046116083, 0.005763904773630203, 0.04918925306429306, 0.04212508353615, 0.05622997647151352, 0.029248405743630666, 0.06775496106955313, 0.07639816421414576, 0.06260437958483255, 0.08845503982757369, 0.0632864008507421, 0.06362550583998523, 0.0662149481415268, 0.06971593931197159, 0.03361958086550717, 0.015337753443858557, 0.010369505673166244, 0.05390217617875146, 0.07615665499601634, 0.020446453859368642, 0.029603188722244198, 0.030905771850337906, 0.06916982587426901, 0.025704528971184647, 0.020040362142026424, 0.020277328458764864, 0.04729976997740808, 0.048118020828452804, 0.06410120047568794, 0.059534784015868945, 0.043657435584933534, 0.040604127045240135, 0.008155781617988984, 0.07119874079381266, 0.012573966767729051, 0.024077810211888245, 0.025747054511861458, 0.018697274030156193, 0.06860561743979493, 0.061035623037887204, 0.04087958928017367, 0.05461162722278988, 0.030021438254944743, 0.041462275755381396, 0.03222014124114667, 0.06439260116988613, 0.05151567439879141, 0.0428600529689462, 0.04525245362592321, 0.0910701192615013, 0.0477973900495037, 0.011901689182606437, 0.03676490805622551, 0.07001182545096644, 0.08613514173175059, 0.03886739422957744, 0.050218220229350755, 0.02771861625895385, 0.009152304959453402, 0.0345927155426433, 0.0393525117467488, 0.02323556548705505, 0.058112430701693224, 0.024019706273271192, 0.0629195060220457, 0.028384656930762916, 0.07632038330719357, 0.04630249203933824, 0.019812879993790583, 0.03752155394683923, 0.03967873496754516, 0.04920856997130379, 0.019930179546316786, 0.03709030007162402, 0.04517686756087407, 0.02972069894894958, 0.0676037046697832, 0.08039694399602952, 0.03444457712072519, 0.013259523529409161, 0.06650579342197988, 0.03036911768328038, 0.020926210676289855, 0.03351610153913498, 0.00698497758299533, 0.04814782930958656, 0.043583676639583804, 0.07994092249822232, 0.035392331304929914, 0.03795378841459751, 0.01712514478112421, 0.031168610871499105, 0.0374742097131187, 0.008597339375785763, 0.023327821625336524, 0.01640375425678588, 0.03283892960978612, 0.030509976354698022, 0.012284038877565295, 0.04141975404514421, 0.049845047310114875, 0.03598863882343135, 0.05949084121253222, 0.03265226462615594, 0.044697698716434746, 0.05493256826734832, 0.026249841847006353, 0.00717864221622867, 0.10500610896175909, 0.0420411815866828, 0.03320731064905563, 0.025847938715390144, 0.04920441011387495, 0.02434975610324933, 0.06874857710734492, 0.07812691822407708, 0.015114789299156158, 0.08680821892114417, 0.0803798678961973, 0.03217634782495518, 0.03202870544496804, 0.03623318174974092, 0.06071933980790838, 0.007018471425849825, 0.08052844298823227, 0.046232873799219254, 0.028228775275150136, 0.02123252135671435, 0.004687462182294939, 0.024705653739792686, 0.010269089740881277, 0.07902800616237425, 0.02631756976517218, 0.06240375647922197, 0.06472450876308065, 0.020973721534133922, 0.019649117208656766, 0.004580315209985261, 0.0454759712691509, 0.03698042008064447, 0.04921959014609457, 0.03260181390590245, 0.03242554856584438, 0.05129247085161267, 0.03147496751719906, 0.036883080948985396, 0.0027025068242613587, 0.03856569731367692, 0.061490131512043945, 0.015681511459631786, 0.0153099310456685, 0.026299587766369505, 0.05562249173019683, 0.0361867529910899, 0.03303769495218031, 0.01617427261906766, 0.0825506622993177, 0.02808825559763899, 0.013309675475372183, 0.031872074938409274, 0.08763596160157074, 0.07322994631624992, 0.029816122860797954, 0.054727222229684555, 0.04163225917446037, 0.05877552193499381, 0.022398428653456995, 0.028851742653416532, 0.05981213082709621, 0.0075378866993912295, 0.03690222931665279, 0.025617769513759884, 0.04504986550478686, 0.039659640226032467, 0.05308168452052821, 0.016831407518756968, 0.038255738139513044, 0.028278262639838844, 0.06238871817326835, 0.03799043423045547, 0.04544792479024299, 0.07780981144957966, 0.02005591564210913, 0.08086727601626227, 0.03989646481650491, 0.05009761500743128, 0.05763198249042035, 0.026631956927538402, 0.017247898879671292, 0.04299543985736467, 0.04145242769511477, 0.02528588873364272, 0.028496607274357832, 0.07796762556198143, 0.06936222885645206, 0.07207790329571694, 0.056682753586961385, 0.023181420307786717, 0.03015005292611257, 0.02416377485309157, 0.03444188432167134, 0.040294849689328865, 0.03842014443850325, 0.08925655931835214, 0.09879639943040187, 0.017783486269294255, 0.0622431691285343, 0.04754412904261582, 0.03453186134837809, 0.0302456836817005, 0.039772630533984596, 0.06150850996134743, 0.02354806615790773, 0.056982757448549234, 0.025106595431063927, 0.026510064677906134, 0.005941826778824532, 0.052650798367516655, 0.11587506565715998, 0.08748956986011998, 0.04882118995151213, 0.04032114182689017, 0.012235091604863205, 0.06563233061423225, 0.015442191337745999, 0.010323893755764492, 0.10336112666634784, 0.062343070824300094, 0.01089773191544678, 0.06845576298092643, 0.006198116227038085, 0.018749689765935464, 0.02169055383532278, 0.03075156601205949, 0.006807502781626799, 0.02989747948313673, 0.03234193006890916, 0.07191273473924206, 0.05063131399032089, 0.025691465256855856, 0.03941906180473105, 0.022188313718464588, 0.04568915055584043, 0.0398995942856756, 0.03182270248690921, 0.013930767853443903, 0.020189381565057465, 0.010494323421059357, 0.016357509359236688, 0.0571662163542163, 0.03271690712520673, 0.03347222385327182, 0.015723584050823365, 0.011879974420392706, 0.043993824792485085, 0.03385937787712582, 0.058036936567195004, 0.03893170731082078, 0.06826244835411349, 0.025439767069333506, 0.008679079999696583, 0.015100371524421199, 0.01102863431667849, 0.14776435650644765, 0.12636629504061517, 0.1422100045507954, 0.08752119396963427, 0.07130450689263883, 0.10354671912688403, 0.13779651073198165, 0.14026706767899377, 0.12143370004430895, 0.10010736739082683, 0.13898886529909027, 0.13469353288171754, 0.17291456340782105, 0.13142474296112217, 0.08487131882218585, 0.26046845401006363, 0.11593535677680086, 0.16623151879156792, 0.2349007904769913, 0.12252150659239101, 0.10694025114419, 0.1414308471665267, 0.1385040542170886, 0.20398641545926371, 0.12535468359748203, 0.13719594376462121, 0.17631899685628954, 0.15807683459453045, 0.17637895089724373, 0.13822657717091424, 0.19260686882320913, 0.15297951537274546, 0.10963751649063443, 0.12797814403330127, 0.1574941787628397, 0.17741323088205632, 0.17113049784975667, 0.19295980552992514, 0.1288505343179549, 0.07227688697316954, 0.14990946398146693, 0.1819762803854481, 0.15651234515732335, 0.15815779476636843, 0.24552004081347298, 0.10501414522408478, 0.14403761454647587, 0.16310326003980252, 0.09025120191396245, 0.12725580739037645, 0.10564621372689163, 0.19582007140401872, 0.07558723716365714, 0.15614059333118702, 0.14884242607701212, 0.20298204354701505, 0.11067649259442285, 0.16634699888527396, 0.16218043052621428, 0.22827546292495346, 0.11158007797935318, 0.1987757458682022, 0.14261285954665753, 0.08212784305214882, 0.11404659764300432, 0.2533331570485907, 0.10978799914160084, 0.1365473277626499, 0.12499619275331499, 0.16848908797387155, 0.16187433243518876, 0.06988607977907504, 0.16244307611017458, 0.14190303311953623, 0.17836612168579333, 0.18432352782016803, 0.08972686835594716, 0.13134214336112623, 0.09594556409865619, 0.14636105196850915, 0.09808918536310235, 0.13879524423710762, 0.1571746741331393, 0.10033597568831137, 0.13051898188648686, 0.10144510246332615, 0.21000680934277274, 0.11862563540137584, 0.10698329762465532, 0.21903723928957217, 0.1110990207281805, 0.17787603991887263, 0.05694521530981987, 0.18283290458062004, 0.14478462688144178, 0.20769268754989872, 0.2788613670535626, 0.23287971263691304, 0.22272892506612887, 0.1981295813475886, 0.21433899058930336, 0.1618269422361928, 0.24983273278320992, 0.12058734908820161, 0.09582393231891817, 0.13008010543642506, 0.1290240991980799, 0.18449631129061023, 0.12510563607417768, 0.11034630103817872, 0.13379829785516187, 0.09330027015699495, 0.10477767686449713, 0.10878883662723726, 0.10579027656105258, 0.1088561527731438, 0.20977699828724708, 0.14744379467541172, 0.12204486200766218, 0.09629013512523905, 0.16649925119934544, 0.1476848825451828, 0.20519491915981616, 0.1692964067502368, 0.17182077371305035, 0.07547756401641716, 0.13292379316783723, 0.19053907494150824, 0.09199499422984739, 0.1107472331533509, 0.17663565163891162, 0.22680209198546028, 0.21090365315396942, 0.23761939137212693, 0.23113157660249742, 0.10893111447653464, 0.10805713838987774, 0.13458012122540705, 0.1839778383052157, 0.2557009203179229, 0.11153122455242181, 0.14679280380087514, 0.14038015757837605, 0.2588684947019623, 0.09098333682143882, 0.3202295020943688, 0.17810545260867766, 0.10604762847745612, 0.1922094377298509, 0.13521660239465777, 0.1909574662004748, 0.20344517434075957, 0.10701167352137067, 0.12427433874578246, 0.16594411324589484, 0.20240047556017676, 0.17100044676373083, 0.1095239362949806, 0.12040210136723135, 0.16987509424647979, 0.15956211054036695, 0.07533889444124314, 0.17133334261034766, 0.12073754828663603, 0.2731203654360387, 0.19214879420976486, 0.16805862316921835, 0.14272311492071998, 0.1039930036471736, 0.18571114287741725, 0.1529102610243905, 0.20867102779448035, 0.1452903368420178, 0.12076070712458704, 0.14551673114540117, 0.07083447364669654], [0.035294544011835134, 0.00701959996912328, 0.030008104494622642, 0.013260923555090785, 0.037667263870037375, 0.022940315201037356, 0.05944531260719223, 0.009636700438756135, 0.05284246207485276, 0.03768739283024784, 0.0632356092213623, 0.040200088443534995, 0.011280511577253141, 0.005055236096884455, 0.026185484715707363, 0.0300474354486552, 0.043945281631163055, 0.055160582846691536, 0.03263181007857765, 0.042863155625039534, 0.04183840960444462, 0.022218646969826474, 0.07197949164096387, 0.05702789151860822, 0.07029507113921066, 0.033106976113612616, 0.033563993525721376, 0.10029870551079513, 0.07141047983520454, 0.0161969909564622, 0.03416955538634812, 0.04258722224603257, 0.0224805781767974, 0.037522312373884266, 0.05977643496026436, 0.04383429464313292, 0.04994612495084444, 0.03120065824459157, 0.026195650702462565, 0.053383224388404246, 0.030934124764415528, 0.07656095789805537, 0.04282730271018321, 0.09463389133734089, 0.03240295663295734, 0.03239210882794953, 0.009874154178936397, 0.0344590217085375, 0.009248259387189343, 0.03846537809999239, 0.038763355659020525, 0.0266167979627367, 0.024274298357927514, 0.04959074059321035, 0.02929313378708978, 0.05029792784743252, 0.07676372604985392, 0.024831073824316267, 0.024428170947958867, 0.045054224545076016, 0.029286095354285453, 0.050043977361412785, 0.04584698765087993, 0.03284469825185595, 0.055919852588445916, 0.08926693980972614, 0.04366976960051445, 0.06319160513099163, 0.047613329764816074, 0.029735622341714563, 0.02208086222620501, 0.0584124383937207, 0.032432067974080006, 0.004436407029824031, 0.03743117472397224, 0.017208889682566928, 0.025593093821718812, 0.005892597490005316, 0.06139953395411853, 0.029368225725427754, 0.009189367335620187, 0.10124168313679197, 0.023027689444021355, 0.04739753811830475, 0.05100774661367459, 0.04366038885388163, 0.008016336378791641, 0.020015619417291977, 0.01883683418254218, 0.021546132855057236, 0.03101063779585304, 0.04204133480426766, 0.02816287830712334, 0.032957719203325055, 0.026172932365068027, 0.049852639241444494, 0.06529734334758212, 0.06785063779041653, 0.06626557123156325, 0.046748592698526, 0.07761611377880459, 0.03685896833156867, 0.0383285011705612, 0.02997551511432375, 0.039294342690658186, 0.08227035072782347, 0.025429737063184864, 0.035246866529867533, 0.029612552231898712, 0.0223391181263592, 0.013467850606708277, 0.012257971778331746, 0.06452159505457648, 0.03544046077877283, 0.003149837772775021, 0.030550282155614228, 0.05262576261415117, 0.04435325026391976, 0.031069929170752728, 0.09904750006934328, 0.006839370602862009, 0.04500195436600236, 0.05790230044494233, 0.06278780784698264, 0.023535569348642905, 0.018585972946077105, 0.12175559486833312, 0.004140834986878139, 0.08169691859474106, 0.03345663013357309, 0.020716880981419838, 0.04391690956488733, 0.029522069587161946, 0.07705146867421366, 0.043857139385034966, 0.04574358493330018, 0.1025625259705609, 0.026048535007923364, 0.06131595759201915, 0.045886789748985926, 0.016447361896655733, 0.03057981484509524, 0.10012496443044755, 0.045466728418344454, 0.020094026601122274, 0.030986603702448552, 0.05723419133573771, 0.1025356286235394, 0.04090029280632734, 0.041279276502468897, 0.012695821670575008, 0.0656947821018196, 0.06253423657448542, 0.045835515484213836, 0.04749100467550659, 0.03847164086877339, 0.020249860376239787, 0.09368755058535645, 0.0031220596640430874, 0.0747918923415484, 0.02809497610395474, 0.02437980207163961, 0.02629138104948065, 0.040346552963338556, 0.11643252485702116, 0.0627611326654592, 0.015471851389344423, 0.09711079149236602, 0.08737921489462738, 0.04346817739367966, 0.019330323125506123, 0.029629576620796037, 0.0726157276620788, 0.09233199630773838, 0.03779173783597447, 0.02141879755072296, 0.01678655881644978, 0.02418841415595624, 0.036801484924170284, 0.005247692226417243, 0.05812736175533745, 0.03666185007821168, 0.06521520340034077, 0.03525288415051276, 0.03472736315621484, 0.08443723808253005, 0.043620517807862455, 0.05279053663534503, 0.004718593601512933, 0.029855844519671895, 0.08071395117909679, 0.019125021137898008, 0.027452318350814527, 0.08572123974802033, 0.028263597801748305, 0.07452585298808352, 0.058558362821537646, 0.056995719656228065, 0.06683023165791266, 0.061405574557401484, 0.024483656781094692, 0.03945175843733934, 0.039469592964216586, 0.06870297955409174, 0.10088668565355963, 0.03665258807520713, 0.028340926716825175, 0.02988352710681577, 0.01255574919688966, 0.012564428015461853, 0.026744014523442716, 0.020575579894225926, 0.04757944569592515, 0.03384712047033733, 0.021865124205848383, 0.01110117901266823, 0.07310531913272797, 0.04278133743472638, 0.057332453603345546, 0.0704966901591228, 0.030515658811876373, 0.01044157347942312, 0.011829266103074677, 0.017346429278052623, 0.04392391160851525, 0.029482131508449395, 0.0453662789697128, 0.049428785775577834, 0.04381629157691233, 0.046232663125040076, 0.00974938239631874, 0.04904643895344869, 0.09939865945207496, 0.03683113635727956, 0.030820414333814578, 0.046861958389561024, 0.06482423042818423, 0.02582345837576976, 0.046810086576208, 0.025185638467871377, 0.07340935644723716, 0.03142818252766325, 0.05435555850365951, 0.06661376585402796, 0.021788048099786527, 0.004972354001966456, 0.032118858671897364, 0.051913599618860794, 0.019958871454300902, 0.04178694764813108, 0.008270767584983862, 0.03789542017564659, 0.11039349971519363, 0.012914619254579228, 0.027167515588864207, 0.08743028997653916, 0.014887393335811796, 0.10910086423879671, 0.06110398106337075, 0.05618587278971269, 0.02832242186301418, 0.04752362469932245, 0.015555241975122163, 0.017453536030746276, 0.03113289393724934, 0.018358456323884668, 0.020266819647663546, 0.0387861697574056, 0.03834421746432781, 0.05720591120001289, 0.05272965945844209, 0.04344107703335824, 0.032317453559728405, 0.044651162705474326, 0.05446826535907965, 0.05165142517897391, 0.05184382433071733, 0.05191407459337385, 0.005676823080472288, 0.049054226237199, 0.020797934999028524, 0.06692868161706195, 0.04676993207765683, 0.009364174235792411, 0.032758467395098946, 0.010616391870914208, 0.00838563576596038, 0.04501256851419326, 0.04641730946698978, 0.0486918245141785, 0.09202631190419198, 0.021839864371765046, 0.0759338459841186, 0.03855774149058327, 0.04034213646645508, 0.05596192996768702, 0.021396720811965007, 0.029507536899238348, 0.044937139497168606, 0.03348801292539124, 0.0063166831762740214, 0.02207082264395731, 0.041825792136331724, 0.035036690307841185, 0.004153373452173847, 0.026351287209939574, 0.06311134209916477, 0.048698435852965044, 0.02939952616279404, 0.06738790536239263, 0.03991088259123987, 0.048009332104195515, 0.08910703427729108, 0.04386105792476766, 0.04405667081535344, 0.03160868050350297, 0.021426977454534462, 0.054447381802263765, 0.10519295780649109, 0.03996729730598388, 0.038491329328427394, 0.05346780815612405, 0.03239721480396486, 0.04900546474081855, 0.0429166094099562, 0.11759297186208349, 0.019359231453328844, 0.0854328536098042, 0.05755116404484838, 0.031946783832785104, 0.031447418995441935, 0.02490565439896478, 0.04456471734409852, 0.09472455784317949, 0.006354537017027578, 0.011099640133550331, 0.023463792655797257, 0.026604084733633265, 0.014027404099432452, 0.04801539185967657, 0.023171279218889052, 0.04030385122243916, 0.058931631501764066, 0.011170696703747157, 0.0334602843729719, 0.06499340562450309, 0.017477357534751777, 0.037258900701999664, 0.04008507566346277, 0.03725319334696378, 0.022812403415540056, 0.06422328041686166, 0.1183738299615441, 0.06550145215324818, 0.18670034624876516, 0.08702935020048773, 0.21663782126720876, 0.11116233023424303, 0.15221627729554332, 0.1043710833595645, 0.12733590188285998, 0.20723052202693878, 0.13058629037151415, 0.1313575110848873, 0.10057933883921755, 0.09422047964988217, 0.10998116821170816, 0.06989683565353194, 0.2143346851751689, 0.23580256789442033, 0.12432313088567988, 0.2147638782738678, 0.1938031151169731, 0.20285638980567458, 0.18818542301174135, 0.12970516668452373, 0.18493766986554672, 0.2714093540224337, 0.11990425146875844, 0.14738191009288834, 0.15478625713336855, 0.15299393314748042, 0.15233198721562663, 0.12675290897248254, 0.1200736411696961, 0.13407536121385713, 0.15781078758018632, 0.09725234155813534, 0.159694628429509, 0.16016718210472217, 0.13175679611102228, 0.14046594410413696, 0.2488285140885461, 0.22924726077866173, 0.17435205078894095, 0.1913898155814217, 0.18374920702509343, 0.07637973979956682, 0.08223702590311728, 0.13002831789274372, 0.16693641161245687, 0.20284894343105056, 0.15539719693122372, 0.11689276749929113, 0.09529048231460395, 0.12663425727476998, 0.09188999421894552, 0.12178491305319533, 0.19304750727549677, 0.07250242325807772, 0.08514409208850515, 0.09094215959550873, 0.14249221602034184, 0.06681181490421295, 0.1327189412568846, 0.12122643495639487, 0.12604163463918433, 0.16739968030202776, 0.12962782244768836, 0.14185901370740708, 0.12802243923708317, 0.10339118029561736, 0.1504196785390377, 0.11308412307933455, 0.17077362345110986, 0.14789609298590692, 0.17856277645595614, 0.11153151566583304, 0.12381974217151442, 0.17674711743189445, 0.10689512856544987, 0.09952102667622029, 0.15491718155962808, 0.24417269133752395, 0.18107433442867574, 0.18031771535113936, 0.11256027215671156, 0.12437975244416345, 0.06335876934650926, 0.13066377250417588, 0.08984221055382684, 0.08820408474533789, 0.09966178001054835, 0.10767292231321336, 0.15983499105899565, 0.12050434346160582, 0.12793155822662577, 0.10509479129987379, 0.16235670735759122, 0.16949437919162935, 0.30160804970129845, 0.19446392723869896, 0.22889020251891307, 0.14100770616242964, 0.1436443969367012, 0.1322082057595253, 0.11110001664248206, 0.14406569932978, 0.11853543620917106, 0.10738565466336666, 0.08664402329633314, 0.14015017798350704, 0.09768494374809727, 0.08892934018325421, 0.09822761745101984, 0.12015925915611368, 0.12206248202992064, 0.08800912302948775, 0.1524281618936408, 0.11122576231437345, 0.15127397382691984, 0.14473198131928522, 0.07848015370508356, 0.09215761171353441, 0.13815012159607104, 0.19285695056521124, 0.09263384261078413, 0.07387219612757046, 0.21721177434007968, 0.244946149027636, 0.1998613231004246, 0.16622324504198568, 0.22943253148226972, 0.11614337263088073, 0.13541146451907773, 0.08270194168172537, 0.06703212646947754, 0.21711138617848197, 0.32236189250984504, 0.12098147068172695, 0.11517912840410588, 0.1623379841687218, 0.11202418680993781, 0.16771345459405454, 0.18529616837059298, 0.14983193588352975, 0.133607572605533, 0.12825771249950896, 0.22880591752548374, 0.17912686231636232, 0.08961315026446696, 0.1390537835897938, 0.08454868855375437, 0.16218692695181217, 0.2673039194797316, 0.1545285298338821, 0.13930843121582462, 0.1314673987367461, 0.08560364525164328, 0.24279855942774206, 0.09187378379846774, 0.24480120519236212, 0.14454159314834303, 0.21074498102309244, 0.08804136000934147, 0.15889860178914764, 0.1876864393031405, 0.13446027443053263, 0.13624116838459047, 0.23649236878320096, 0.18459820098453955, 0.14141284410030613, 0.09124963664479795, 0.10632058560487725, 0.15646970470345792, 0.1656070958462454, 0.12195347537917477, 0.12275876402254067], [0.0429977189689394, 0.020372754285833048, 0.05115018917187568, 0.031102102948352698, 0.0742465986179248, 0.0407818402914751, 0.050285498070861065, 0.07091390164268595, 0.03007346520110244, 0.026594460754084493, 0.03337222256607587, 0.01783575261792829, 0.03374798486249582, 0.0035840137946164057, 0.020043753996311177, 0.042590351715203256, 0.005509139361581015, 0.03510103020216188, 0.009527914995898404, 0.03616552852514771, 0.0502503537873347, 0.008318758205390506, 0.02454666751286676, 0.04220048190965768, 0.04422304596030905, 0.020329198356898084, 0.0425641936430287, 0.04085658365980752, 0.09912099854479875, 0.04713677328019854, 0.10500640007517031, 0.024269161738395214, 0.04798569063085222, 0.01748072449117899, 0.05218300975919251, 0.0294592771904483, 0.10474700270400894, 0.08336668383450278, 0.0062186464257988966, 0.10066093486403266, 0.029191922080973466, 0.045176323638447834, 0.04823466920624337, 0.06250538570325702, 0.008682521649696415, 0.020326340848940517, 0.03272629553271878, 0.09851789582640895, 0.014555843888721881, 0.03229811367007994, 0.03471651918164665, 0.0564363107625996, 0.04618982348831431, 0.05169780797234947, 0.08068472492478548, 0.06855962918170037, 0.052804027443691615, 0.046450404465318694, 0.051750943830777565, 0.08654917395042797, 0.09488139902391741, 0.04969491322915401, 0.01913299611318977, 0.03887026705929349, 0.030837639820792025, 0.028724579718865217, 0.11244003465699573, 0.033491636521273085, 0.08667980726327627, 0.05604251092600246, 0.030209499433816924, 0.039916735502981374, 0.040703438853304234, 0.09975035509635365, 0.011086132088225457, 0.12422094241746011, 0.0781861444815032, 0.04581623305115969, 0.08767910001258697, 0.0194847549597222, 0.08664445996644997, 0.01972139951953244, 0.05621936615376223, 0.019780141226346457, 0.03959813485703161, 0.012615515546302402, 0.07321125377089747, 0.027674372766106844, 0.07192008918331516, 0.019854620294345003, 0.02048379106957826, 0.008157771531372301, 0.01061642442965099, 0.04762293650738655, 0.027207373228344708, 0.029464339116407983, 0.03615815109843689, 0.05177413714268515, 0.03003533892033081, 0.004718698459797569, 0.050842271622030005, 0.03272618061953014, 0.08296972771565761, 0.016841223020286813, 0.017985026765194152, 0.07432536011742008, 0.0567261218243549, 0.009885590914035998, 0.01429357177262465, 0.0594786680754154, 0.0665492152855281, 0.03562280885694969, 0.05295485100378433, 0.01903631581714557, 0.10252687989944413, 0.05309918962959802, 0.03066033068593712, 0.06287465157407908, 0.04054589670211558, 0.06667206514506571, 0.012988965214800932, 0.03391162890400137, 0.008369384168256676, 0.08220512600195024, 0.03599461813968036, 0.020561683059279478, 0.04325376087499242, 0.042080876432479396, 0.01659634684573018, 0.03994416145067062, 0.028924597615015604, 0.05409824106121256, 0.07254694062735766, 0.027804077197346958, 0.08082464322327607, 0.03775747838400064, 0.014449359582466705, 0.030235176785818996, 0.06606494046507344, 0.018198121782212008, 0.04608499201675577, 0.05744329886510969, 0.030770450079393004, 0.006797481393967305, 0.02708777158160604, 0.040969175602039026, 0.004883764073207614, 0.03128654244656284, 0.020789668910325538, 0.0620910776929269, 0.031368098251761935, 0.008505451917317847, 0.014378154582734552, 0.020137624664893074, 0.011087642239046194, 0.07148412386736563, 0.05922144639395899, 0.018924968767791026, 0.03058156727122203, 0.016218096678776127, 0.01892221468170324, 0.06373743511616223, 0.026200681984905275, 0.08004581525681481, 0.0314621604423249, 0.05839794784063294, 0.05588482704854781, 0.05871533806766233, 0.12075637106693561, 0.04056549323121867, 0.011754281417046104, 0.014686029040134482, 0.044781156334905856, 0.018472310395971425, 0.021861764910300414, 0.02074739426344393, 0.06556457013732965, 0.008372129635855315, 0.02966934999060487, 0.04414953216309509, 0.05251115969111843, 0.024089257480696808, 0.04607844196500317, 0.05813038397219874, 0.054861578729844866, 0.02628444220810648, 0.034444561798966704, 0.044686506171861005, 0.07186971124141447, 0.04744149624339996, 0.008684976003883828, 0.010632226908309086, 0.12211012503793164, 0.010369078579148459, 0.04647663914628568, 0.023126893999776053, 0.05919364889362647, 0.0047065425596590485, 0.04669493206986978, 0.10073237256297182, 0.04812116178894236, 0.04024515739612041, 0.01730673251703622, 0.056492143250521154, 0.04750691249125427, 0.05478481288939234, 0.0254394797863619, 0.022894079879587217, 0.014698353479616346, 0.04120543711788712, 0.04310898174862227, 0.11984530100298506, 0.05035058873134756, 0.07832059291221442, 0.015433179270926745, 0.09590267083577572, 0.06736684560535416, 0.04799227515656141, 0.013580821762462298, 0.06979879172098252, 0.04360949380263206, 0.031793035732041446, 0.019177992287422382, 0.03264507872142619, 0.04121909263513742, 0.032685386437562206, 0.02213808516370914, 0.031336987421156905, 0.025915176337284428, 0.02869074353046956, 0.04958291883550344, 0.03099700334602066, 0.05429695277745205, 0.05829686253902413, 0.03687585290941981, 0.048411597212355946, 0.027535193742463188, 0.04698239507213716, 0.029353039947548704, 0.043340654397803935, 0.03468219461219926, 0.04059907469537951, 0.02027477930119682, 0.023138615145017544, 0.05487797301142447, 0.06076580687095562, 0.040612787669224125, 0.04158028010879794, 0.03270322096443946, 0.050573466691158475, 0.06680547935707916, 0.06321870932175268, 0.039613989046624595, 0.02678150495123719, 0.05475921023096289, 0.0545410437118863, 0.030493403957676024, 0.07140099566670195, 0.0326261984845323, 0.019981223984711596, 0.08256629049297302, 0.02186902550860278, 0.017743465836129842, 0.02706853511382736, 0.03121843723009431, 0.04237942472701112, 0.038702547430030765, 0.04989234940899957, 0.011225674046023239, 0.10591960752442961, 0.057783261872828014, 0.03547491558316735, 0.03738618621061887, 0.03587515055832844, 0.026384659915141044, 0.03153511691057394, 0.05473585221015158, 0.028164642224568995, 0.07230392987689666, 0.028439273254104683, 0.030326509788151712, 0.012113776794003864, 0.034694222192610466, 0.025979899275567264, 0.017841097996419957, 0.06279130120791736, 0.031716800407476486, 0.07147978014883495, 0.05124969633236047, 0.01884625897923064, 0.050115595091014147, 0.04155269711308422, 0.015419286266419918, 0.019226428196435014, 0.09820063583432667, 0.04278699116360757, 0.0519320891509133, 0.008936158039667194, 0.05190178271262877, 0.03745750133549014, 0.022146132917353706, 0.06618082658537934, 0.0256806097909688, 0.025403634532384818, 0.05103459033454138, 0.07614409115405814, 0.03789164336217988, 0.05953987850056541, 0.034645349613480994, 0.036237356928928245, 0.03782551848299561, 0.040634525414075584, 0.02714439697052923, 0.036973130754044944, 0.012932302479091431, 0.018928871985765237, 0.03520879579047042, 0.018821043195202947, 0.011118174673268392, 0.05080893913644457, 0.03336174248327171, 0.037964900519939206, 0.06874396525804075, 0.011420909638306307, 0.06707717243942522, 0.041892357516072454, 0.048695183809726476, 0.02817489056577606, 0.01144171754393967, 0.04226217497019999, 0.021649997140611374, 0.042209640490792455, 0.06494211603797252, 0.07659425207924458, 0.024674349471986778, 0.05023595899523747, 0.014879482520383694, 0.047354652516303525, 0.054585503624571916, 0.10444203076223213, 0.01622946733879226, 0.004554636421568331, 0.06166738127508472, 0.04769802078484528, 0.04990705446670613, 0.03563769394531846, 0.05284958286210895, 0.057128371610756845, 0.029845511908793164, 0.015521452709611867, 0.087258517742157, 0.010982276421160468, 0.1790982719150282, 0.07726071792985163, 0.10177838135390513, 0.17057612598423036, 0.18027558051530393, 0.11698595443440062, 0.1373714545080739, 0.1556805422108981, 0.13139350189557, 0.09643991297531514, 0.10112195125510616, 0.11515422288568751, 0.2322777513895304, 0.12879248017505293, 0.21675377633542786, 0.15631552184781722, 0.16563214692136935, 0.11855838054250326, 0.1357975728329151, 0.14669275271796411, 0.1477867722391121, 0.11554432251761038, 0.12395300316594302, 0.1427247849923949, 0.11178518269932079, 0.13658538701072817, 0.14716856992773472, 0.1509071249634989, 0.2744568824287384, 0.13818248114999265, 0.2258187874911293, 0.0980354672778518, 0.144425040531543, 0.13993795630672287, 0.1742515706967923, 0.13038804213846886, 0.13264577986011583, 0.23432121431875616, 0.08776942943973888, 0.20579628285861787, 0.12845903274513062, 0.1901711382332348, 0.08516689852601098, 0.27914218424308684, 0.13216087684756325, 0.2062350214128533, 0.10171348604583934, 0.1480320735924667, 0.09584697624368053, 0.11425929429430155, 0.13214586152424737, 0.10936599194763169, 0.11737191719153237, 0.1812009381190423, 0.11494799201647121, 0.18945219535981456, 0.11263708779287916, 0.22562280687833988, 0.12477699967641985, 0.16606048200159304, 0.1583766047993014, 0.20444090478122237, 0.10659987827943218, 0.10251773280962821, 0.12578318721704906, 0.08779342331352734, 0.19046867146126686, 0.08373671196280949, 0.10846820584828816, 0.25109296274040976, 0.08926923807349899, 0.10961744498701827, 0.1580127896440606, 0.24329011208347737, 0.19138626093345304, 0.3431613941586787, 0.18296447252073597, 0.1499561034142971, 0.15896234030444778, 0.13795590298550744, 0.11940715999733056, 0.16501673317003637, 0.3103062732806129, 0.15819551693575998, 0.12549895327538252, 0.12133777817530979, 0.11205984054193383, 0.21786157011745438, 0.07926797554377588, 0.11788482071771739, 0.1831000854050921, 0.11871351334717005, 0.12337659095083514, 0.11923495109283155, 0.11065299667778516, 0.1868034616833733, 0.14615494367336074, 0.2579593934839772, 0.08770864802382647, 0.1814423324239831, 0.22814613196157643, 0.1340971487544237, 0.1581460889428854, 0.13087744974801618, 0.09968982648945625, 0.11450502465689376, 0.09357817621240694, 0.110286362318983, 0.1032357870210563, 0.16498130926441762, 0.15080951004018708, 0.1473419509467579, 0.22659331770433536, 0.1036645511105176, 0.1960173850097964, 0.1792890737734495, 0.10745178337299055, 0.25495862708457057, 0.19681327375433139, 0.1960523186191436, 0.14796307971400602, 0.11352917419806605, 0.14187350809093446, 0.16621457292668282, 0.12922155069968394, 0.19659742082078613, 0.13954011152588552, 0.1506635243253362, 0.1711453599554877, 0.13421800678535817, 0.10731038652480611, 0.1661378415601869, 0.10627188539553074, 0.15635021030902863, 0.11620059939882449, 0.12454828412662591, 0.12008090368321828, 0.18912991749182825, 0.1599689951587108, 0.10740407141706637, 0.08812425072274863, 0.08527742203084693, 0.1974179316312075, 0.11926598531464416, 0.11655830883330877, 0.17213943564603407, 0.1367760356515646, 0.09591875102130637, 0.3160639449713692, 0.1616913599953536, 0.1604297051146146, 0.13522559626688882, 0.14785164456454017, 0.15407456145171197, 0.1118956985432775, 0.18303357365150608, 0.1724379341448507, 0.173277152822383, 0.1428031557870488, 0.16763177429956777, 0.17381513040632973, 0.20961006772854637, 0.11586313766817893, 0.21724885299561486, 0.08956549193469748, 0.08382153321778582, 0.13767087231239966, 0.15844714617536915, 0.13575491705729117, 0.17938887970822473, 0.19118301780714145, 0.11253391873211631, 0.19293886068607533, 0.1213835442679063, 0.22502551876729537, 0.1524647962181799], [0.012603631607377002, 0.028479383702600197, 0.014613772584726254, 0.00983662065869618, 0.13165496770412694, 0.05073991461446689, 0.03871830968907283, 0.02000682664314105, 0.012553723851939844, 0.05598983472032894, 0.07427842191029942, 0.03413515803854793, 0.02262226230795345, 0.051991012803609335, 0.01603267467280309, 0.012088101357221605, 0.031017310421673522, 0.020101710463002808, 0.02846106845555046, 0.006494514687332295, 0.039921630804817525, 0.0174778803897601, 0.02751984517090023, 0.07060722898571722, 0.04647598797155004, 0.06621677143078658, 0.021564450017326785, 0.02225320902653039, 0.0944054898835959, 0.10412032746018902, 0.02123492112713716, 0.06529512935348096, 0.03971258073203987, 0.03318951059613497, 0.016263650181973656, 0.06980816863717572, 0.03891403366240763, 0.018701364939671852, 0.01934580193201621, 0.020981717576843598, 0.11034484547112258, 0.004916434371543508, 0.03772611091394098, 0.04933261492800328, 0.03999551998511438, 0.009435417539920778, 0.05905818539641558, 0.036314191717293956, 0.030605700956056678, 0.05594002368349222, 0.03927845785754823, 0.03155060337796327, 0.028438520572719075, 0.019901027985578103, 0.009001557050543207, 0.015048607920987472, 0.043245709290908235, 0.0410382001240167, 0.0116869872961674, 0.010238936520181596, 0.02621656873323504, 0.05949194054870356, 0.027955278055742386, 0.09465859767289893, 0.004339267081025267, 0.023077946727073962, 0.03396089218797223, 0.009400019489769495, 0.04365445550290808, 0.06146721016134947, 0.035554466153224634, 0.040577539963827985, 0.032299274293285225, 0.06441595919069744, 0.032592804711912914, 0.036710898857563734, 0.04477857844904066, 0.0373754533187997, 0.03755646457354869, 0.019176504161629467, 0.029841340560045455, 0.00914729474442861, 0.08472812932825859, 0.03542851363759368, 0.11053436030183109, 0.05567773049997707, 0.01672103723150588, 0.04021185172361232, 0.04820590643512626, 0.028420712858919176, 0.06110139168618668, 0.037304096059092594, 0.05597933548532667, 0.07071536995710866, 0.0610172254363856, 0.007643956360557387, 0.01649111126279158, 0.04714701970618579, 0.062349919650343165, 0.02602405275308317, 0.08430336421776204, 0.034503267116604314, 0.06562896748824466, 0.03360404843284238, 0.03639383804834178, 0.055739009873040264, 0.07538974735765688, 0.02770590877550985, 0.03413396294138605, 0.05337562096575576, 0.07849762050975716, 0.0266802798385822, 0.016555004910896384, 0.04707399237480375, 0.038251877056374665, 0.06409654266110833, 0.018538349090264212, 0.0921700836249417, 0.013079173983104769, 0.07753854737647119, 0.01011137617751956, 0.036583096239595644, 0.027362952279227398, 0.08020856297544895, 0.015804628492332995, 0.05086382550577964, 0.03340576955628011, 0.030097323094284343, 0.05737574906238625, 0.05304100142130929, 0.02676049882035342, 0.062180549101603616, 0.045454425046280514, 0.02579830770921563, 0.04821527952087983, 0.031173914115154938, 0.004127027209652889, 0.032872039929873524, 0.020969372069943818, 0.01166301736262657, 0.021172153628281048, 0.03091342315348166, 0.04322174989107636, 0.05830189190624703, 0.0421069004392672, 0.021749448759721655, 0.023614650689846566, 0.04627017845069209, 0.047341203842792785, 0.06678491755719147, 0.06747615869126974, 0.021910244869368694, 0.035581210282661264, 0.03816450089817086, 0.02971313766113693, 0.09750622309624188, 0.012042258655832661, 0.035882183245473334, 0.08317220475404494, 0.10136405802181653, 0.001203504138937851, 0.014040979177450702, 0.009007754701850636, 0.022251571513592236, 0.03218370992990752, 0.005614571733355162, 0.04335939290843183, 0.036317980022079525, 0.02270718123914013, 0.060369463622449875, 0.07846847852511753, 0.028204758418723944, 0.036240061219300956, 0.12077578373493687, 0.06484438620147205, 0.03842666384673888, 0.02869028004727537, 0.062280738080341014, 0.02531255625428692, 0.04898639681238321, 0.010004444667438587, 0.011884252063839907, 0.05638267694702072, 0.022113330947655826, 0.01862918796588577, 0.044836954348870826, 0.025762353287709337, 0.03005757079189343, 0.021121034496313622, 0.019221929345099677, 0.05169160649060242, 0.054820566212818514, 0.08686444211390712, 0.04219256822139986, 0.03440523850581339, 0.05615868432927997, 0.023116714606482177, 0.04161222980568006, 0.001559089474950827, 0.07360941264778376, 0.0404466423506458, 0.01944541442959059, 0.0743544637976635, 0.04825744883067185, 0.04750605447277908, 0.030194371112532196, 0.02359755352259644, 0.016028084848526747, 0.01619466587961201, 0.010414892552240242, 0.03850424174039114, 0.04583493325739138, 0.009967173532312436, 0.011033158065871367, 0.023505241842940453, 0.05736016300356677, 0.00764955502686902, 0.11805096220585609, 0.01905086574204747, 0.042496984749431574, 0.07066435616223082, 0.0391399989565534, 0.022614375432772983, 0.061875987016866286, 0.11463522129962522, 0.040123498803305055, 0.05087481120661382, 0.023916154168546203, 0.0557708369958545, 0.021720438925248962, 0.060325425058122606, 0.03241851587869948, 0.045131407903447274, 0.013507984995451427, 0.03361282780045464, 0.0186511536218947, 0.022226823043198358, 0.12719379257290594, 0.021620123542004058, 0.06536698073989923, 0.026421460863803665, 0.02529447274883428, 0.03650437304449659, 0.04736575313032635, 0.017078587702745875, 0.02057646472577847, 0.024181004170508637, 0.04735783178118929, 0.02883259237052933, 0.05608925378070243, 0.056210717021097104, 0.08043842765712932, 0.03075882277992224, 0.012971778032219699, 0.01125748488946908, 0.03186628714414134, 0.07270703002089456, 0.009733890183269978, 0.0724455948558546, 0.04919266215555611, 0.08577856610739425, 0.03871513042418707, 0.024263605685724367, 0.04968513028636094, 0.017711588917600534, 0.023834946933352662, 0.0654477110853599, 0.03520631366559575, 0.007790613838756878, 0.022600195145294554, 0.03178821703899772, 0.04129541031415424, 0.01995302428821883, 0.080227401077507, 0.05227054679586042, 0.06039992710875888, 0.00674134390729089, 0.05881998567811905, 0.05335417433431553, 0.08502557062573972, 0.036837222925837965, 0.0033819815660301117, 0.08603682200754843, 0.07797300349920988, 0.04088041665513189, 0.04016058128927985, 0.03031754847465744, 0.06294529254157698, 0.09905421099955998, 0.03812318194597479, 0.0441312418139029, 0.04121943354426373, 0.017721318234238895, 0.040605050181188894, 0.02582519931057769, 0.01920226195286359, 0.04025676745861288, 0.03617335411329423, 0.07164386086045735, 0.017138438321830287, 0.045005179596163576, 0.012612493329441116, 0.04307228613704924, 0.03469891448114668, 0.04196848750354783, 0.021352029157682292, 0.005784307131468649, 0.030203577574162237, 0.07287116435867164, 0.04050594904730397, 0.04222789253558844, 0.060077139792302926, 0.04028373375354756, 0.0415414356205973, 0.03805417274575561, 0.06135610059925145, 0.0047129044410652455, 0.061171898588297836, 0.05899369228451003, 0.04620988733105121, 0.03917278368927298, 0.07074972133963339, 0.029067806261140975, 0.03974686699709104, 0.05889061898473771, 0.10570062895215328, 0.06444025949965562, 0.021902842544800332, 0.04212461622251619, 0.04368203466818218, 0.018463082866923466, 0.0064336150065965715, 0.03536413160843715, 0.026876455803792325, 0.012353861088594122, 0.010460861658136691, 0.04960921097306475, 0.04352465722589724, 0.03889599995267007, 0.06370648133358167, 0.023039491028494896, 0.05563921542958387, 0.03596767482738342, 0.028100658561133092, 0.01036652846397051, 0.06157347038688679, 0.03309390665362439, 0.004308783484908242, 0.026448450141376065, 0.1228386440104054, 0.01787150211091484, 0.06057728029366943, 0.10537868050197441, 0.14581979552824653, 0.12584720918488118, 0.16052448551260656, 0.20478382105788878, 0.06884705771001116, 0.19155971856126863, 0.14481684853953702, 0.17462479341174328, 0.12717248000685247, 0.11048635723249567, 0.1874595547034856, 0.06917525743765217, 0.11863049239881578, 0.21451598754332912, 0.1401717203759378, 0.19504771688051764, 0.1351156320062376, 0.19121779819890378, 0.10515043226581429, 0.10215381806295726, 0.09101928166684606, 0.1048362136427914, 0.15629618578860838, 0.11073143642035224, 0.08359830285752974, 0.12457026318917352, 0.07352189476331396, 0.24947896870153569, 0.15430331530590213, 0.10260665263499945, 0.17733895099691807, 0.16167974610242153, 0.16376787195763282, 0.13865213901285203, 0.14372281369663056, 0.11633418981106051, 0.1483628856799295, 0.1512656081467867, 0.18306918141822662, 0.11258876296661555, 0.1903144732838677, 0.11529893689458409, 0.089154769215853, 0.1299419797836773, 0.10726237579459146, 0.19731558228452362, 0.24567361079877426, 0.1778420102932761, 0.15213254388541947, 0.2276477458015565, 0.11867094184121779, 0.13752142388013103, 0.10577809576305652, 0.10902023348476618, 0.10435653534988243, 0.10287784776019473, 0.13723509085755195, 0.11512595424128157, 0.1463364145808643, 0.09771279104414488, 0.23792133726660283, 0.09817553879392725, 0.2413248360878037, 0.06594698590737197, 0.13176500857357057, 0.08144568005997328, 0.2081246538868835, 0.12844033253889892, 0.2537772888618131, 0.14277235905249275, 0.18961736391628944, 0.13782693974433408, 0.12078777301095187, 0.22349867489068742, 0.22520755657986288, 0.1603218552566344, 0.1258827020384131, 0.0876745417894375, 0.16236392390583793, 0.16548928684524952, 0.08762270061960144, 0.18858028004967398, 0.15286051127458775, 0.3095195622694108, 0.19826465797039772, 0.15582314181712367, 0.22056417509673104, 0.19616871801835878, 0.0994921068570787, 0.12666637934143507, 0.16197079822661417, 0.12298904239170014, 0.12460312836112515, 0.10594454368636494, 0.12340841424320975, 0.13418618349298356, 0.11314080592485205, 0.15229680845814367, 0.11871539026258454, 0.1534079117400031, 0.15408694143256835, 0.12030432556545544, 0.1250284450549272, 0.20638967924300702, 0.1076410377338048, 0.1776923013911132, 0.2813617554643462, 0.09519248434732999, 0.21222846432318612, 0.1666319682713478, 0.29746458655403507, 0.2129905992337773, 0.13363360427320004, 0.14616677207091164, 0.13841627586272456, 0.1352310508129097, 0.182793558304829, 0.10960789187060249, 0.17391377188746007, 0.08581709266910631, 0.1743070661060272, 0.131823108681748, 0.16228489427556916, 0.1268649416705293, 0.15265003627827092, 0.12414944343148701, 0.12649897380822128, 0.11748533650872209, 0.10436090971193007, 0.06581164881466858, 0.13055489608837714, 0.16069349983046133, 0.20392488327718553, 0.21588625836997263, 0.2068139080919566, 0.08732327515439642, 0.1185205357990438, 0.13730469760635208, 0.18953281845296585, 0.11532750431328051, 0.22529030939744366, 0.10094834040970573, 0.17492476279937452, 0.18193255208673018, 0.13292367059376933, 0.18114498305705287, 0.12015558959495638, 0.22633169867819358, 0.20757608896782323, 0.20286452565943042, 0.16684561487167113, 0.14622989771587236, 0.15978897981826337, 0.12150267860101116, 0.14728834011381672, 0.1114321617229331, 0.19393201707111252, 0.13487485057163623, 0.17124881246878257, 0.08051659926892289, 0.17039511472948138, 0.13885262422263622, 0.15210476553728505, 0.04818170571759824, 0.15733087946090007, 0.12094276791979229, 0.1208522622924178, 0.1499183046361131, 0.25412228889763355, 0.10700422714674666, 0.12193803870750052, 0.17915657120606593, 0.3228492470037553, 0.14343370743576558, 0.15290990862394535], [0.0557877675389811, 0.06356441415846348, 0.0639191588326808, 0.05305252721413009, 0.057105860117101864, 0.06711129399557268, 0.07505692811983247, 0.04747188695135617, 0.026685098531625928, 0.010203134358650254, 0.04821857369895424, 0.035179056257249854, 0.021289562348336465, 0.02167893611195107, 0.07548894042209273, 0.03911153495972676, 0.07616037818332834, 0.11886142194271089, 0.02071215613414684, 0.1309762444467314, 0.00931407974642371, 0.043361223858570865, 0.0571718892352956, 0.021831801296361995, 0.10414210733987632, 0.019203409169530197, 0.03569595110152037, 0.031238836236298088, 0.005806720470108333, 0.03561498709924279, 0.007721801427373243, 0.05129911283391619, 0.0341053725400519, 0.03771853430436985, 0.03637963477822562, 0.03784287420492019, 0.03234117930274337, 0.09763389930970247, 0.034739061318818605, 0.027077971401834683, 0.003722509324190117, 0.04526599039954524, 0.06669852582197036, 0.026731877775502302, 0.055017094578473806, 0.036507353126522035, 0.027996491670848864, 0.032173685669418306, 0.04206089685941416, 0.013511346206219207, 0.003829355846391991, 0.01958781102251622, 0.05254409764142287, 0.05075546619932979, 0.011550686847899231, 0.019146417973623164, 0.03559701084609955, 0.04775229428384093, 0.07030119984260491, 0.023246229430961034, 0.022338568458273526, 0.032823952590866436, 0.03001091603730475, 0.02388741629528663, 0.04122555075633911, 0.058087850770642685, 0.04281378508875928, 0.029862877206816792, 0.04642685109208669, 0.07360696116642607, 0.05258602946395836, 0.05344855253614726, 0.03652247953258696, 0.05007645948940227, 0.03570109538193192, 0.009247387004565568, 0.10853521555902497, 0.009742643695414789, 0.06503388571042208, 0.038571496599263726, 0.0427314076542614, 0.025915758564106883, 0.014232109496069532, 0.03202788381566925, 0.019768098324176767, 0.03844772743421697, 0.04327456782301588, 0.05688368695818129, 0.08422028964325305, 0.007176173497892677, 0.0036615038275598522, 0.024844648902334517, 0.020160463661135688, 0.048694069151796644, 0.04304558414244845, 0.026108310933435158, 0.026400065943298322, 0.016938711539091125, 0.03866825350410035, 0.023772392023895538, 0.06103731609219986, 0.030625753307474718, 0.014048722411145367, 0.01969528741263334, 0.02346907483203517, 0.035626049408869404, 0.057076051635968114, 0.02243324926483535, 0.04492034684986838, 0.0063731936520085705, 0.06728831393223617, 0.027594998396272143, 0.11161354069988574, 0.026565994842038042, 0.04746114256821814, 0.01134008065902538, 0.044602975775037086, 0.014080980458417007, 0.08384223291349989, 0.0712089297632056, 0.041886179016963135, 0.016644252238855246, 0.02541412610650784, 0.13155690844981902, 0.010021972759146123, 0.06862357454074007, 0.049916458195976676, 0.022845992540580132, 0.04228369437999303, 0.030057913616239548, 0.03659408194042983, 0.029049626994697802, 0.03644243483581851, 0.08476375241673763, 0.023201373067774603, 0.04418010673215313, 0.02294431992566153, 0.02680553521420206, 0.026726967151907664, 0.059653581270287116, 0.010357636098389425, 0.04638473923888899, 0.022268680172161232, 0.012952938972551738, 0.020957051460901578, 0.06668621478902717, 0.02854710012944716, 0.032302472710369096, 0.043196675833314664, 0.06510515487001789, 0.04049304812665909, 0.04370723513045138, 0.02796599754102288, 0.05329165772925462, 0.051689373344303145, 0.06310486482576498, 0.024520026805299907, 0.07736860609222805, 0.01579869992940897, 0.021076838883961883, 0.027643208309347113, 0.08183519746507369, 0.007299038200383827, 0.014030051890820747, 0.057462987324763695, 0.04576910715249758, 0.01782347988938132, 0.020381857325593312, 0.012227043851218637, 0.04922409091264971, 0.060151366051286466, 0.057353785321597135, 0.0122088176618901, 0.059889340998544816, 0.023858425613012046, 0.058867421842390494, 0.011351153502360949, 0.05652555617533865, 0.026634601846096978, 0.04924492467375052, 0.027439197179891413, 0.06110863887795037, 0.07485173913019319, 0.03797595516868657, 0.03484251383211344, 0.007417524231582761, 0.030653083494173426, 0.05238326897303905, 0.051910251814631686, 0.0392359821125865, 0.022225013160477244, 0.06526786428425582, 0.05047280656834764, 0.12404179275636712, 0.04575610280998292, 0.056838813358016556, 0.02278507514406116, 0.04577740771515716, 0.05635009905804069, 0.04217480647287542, 0.06244321000732242, 0.00536177420966147, 0.015800114319239174, 0.038543365850684144, 0.02205092734056375, 0.02675051860991986, 0.02956468897360948, 0.016589961502881303, 0.04808392608538271, 0.014650472984348815, 0.11385611754151122, 0.03367716386433571, 0.040430317016979384, 0.06656685829042427, 0.024248197742347277, 0.036282379916238214, 0.08915622478290912, 0.11026436027379767, 0.07828817973213811, 0.011646753315994096, 0.06739916685487955, 0.03403815215513591, 0.042208361123958905, 0.08859480490847942, 0.032257855749659003, 0.031559748552559365, 0.01391799237969662, 0.04125261664270394, 0.020416451941034006, 0.024416237213318388, 0.08957670746190895, 0.016512015887025385, 0.0595529058257178, 0.07261466279986405, 0.03023270998270281, 0.046201173080912525, 0.021981787905397437, 0.08453137496666563, 0.05098717332246804, 0.025234020750729308, 0.0692484111735417, 0.02868398088931797, 0.033098905377330325, 0.019869890341895725, 0.055612570891577395, 0.10030996700328204, 0.020933775794542125, 0.04167869176355101, 0.019962606132931767, 0.0549876882935003, 0.04054690793817563, 0.036067419475124735, 0.09925439743505371, 0.015147909195342613, 0.06582079590448449, 0.01800318113377979, 0.0879423737886452, 0.037615587409105034, 0.00909430827314575, 0.03384148589365425, 0.008145382932026782, 0.016634574633151773, 0.05026500904932619, 0.04011531698427374, 0.016937891825012142, 0.010612519296456971, 0.02531870027943965, 0.035742609686548674, 0.06337627828601869, 0.09593136848941927, 0.06317264062442607, 0.06057420828109307, 0.07125305642764415, 0.0825757363570794, 0.021853544786872885, 0.04422721347861713, 0.04881241058389987, 0.026204317072105986, 0.04569852747203362, 0.0021590457265941248, 0.06211740047400517, 0.023370040730843623, 0.004227121385009659, 0.055432486603216785, 0.052404286595241684, 0.040188516685438734, 0.08270766435851974, 0.04222444513992917, 0.03282528941429431, 0.0960827474632571, 0.018445920582199772, 0.08165400234922286, 0.036462257360859264, 0.07313616949343875, 0.048279638567398635, 0.047210424973238865, 0.08738099987949095, 0.023154237593013435, 0.0296339011871286, 0.047906626526626854, 0.05343841719290903, 0.01674483000721422, 0.06900678704222364, 0.07397949440224517, 0.045722352806478746, 0.027952694424217748, 0.007849029479398122, 0.026293346065006433, 0.040612615299441164, 0.03481282792504757, 0.032855136199824275, 0.022004322381690148, 0.01110305497047281, 0.08772717202983557, 0.0328236959514118, 0.028023440728805242, 0.026638348016046712, 0.06979897558208435, 0.06312659107929756, 0.02415451859574645, 0.031003735343655272, 0.01603928218115001, 0.05266036297525129, 0.01989312770385896, 0.0759990094229579, 0.10233411685593667, 0.017821484230338566, 0.005870522187662221, 0.10156010758251914, 0.06746865869049104, 0.002445763229550193, 0.04748631621740999, 0.016323910658097556, 0.006231950979018885, 0.05904783171811893, 0.013118750085273098, 0.0833464820959395, 0.012862102012149991, 0.03775872710731722, 0.019830480863850926, 0.02691951760601613, 0.010546081278833651, 0.018793429555972258, 0.0499555861367093, 0.04812766970585912, 0.015266329151458077, 0.03271820181379876, 0.057222037350819, 0.04208211749491673, 0.07157102122061676, 0.07992039134185161, 0.026910489259828484, 0.15205657860684782, 0.22473446664310273, 0.1688515701361241, 0.25206980145265984, 0.22882407380928918, 0.1413743405212318, 0.19965886138379577, 0.20825139547307647, 0.17951459473659917, 0.09037553032319393, 0.13631387012860469, 0.172683036315345, 0.13581655649167879, 0.10572872905721588, 0.17372989546387427, 0.1830790026654159, 0.1849553358530806, 0.17007959375698722, 0.06653577810333622, 0.2322840333105095, 0.1468114963462276, 0.13523569330573082, 0.33942135291234143, 0.0955737509854859, 0.23527957499027255, 0.06436900566181829, 0.1462122776936139, 0.07036154458840048, 0.1316987572898788, 0.11829142188352924, 0.11366192957446461, 0.1484570225640651, 0.13204384925625018, 0.0849767784858423, 0.2597607726291303, 0.23886341090884902, 0.09041578824361486, 0.28357979450975696, 0.09129160294129003, 0.14689035743715304, 0.21532387322475835, 0.29997468895969853, 0.20901207481661152, 0.13597096917369675, 0.1862138344515716, 0.13598256774487036, 0.154540863849463, 0.13779012155869316, 0.18940635265842562, 0.11246942945065037, 0.08754524146957744, 0.12901561094387887, 0.12978735259704052, 0.08897264713361379, 0.15055740582606486, 0.08866008326050737, 0.14954719632383318, 0.18597680684779921, 0.09513266054132292, 0.06359418816564065, 0.0829754886968482, 0.20524522049292443, 0.1183062150413471, 0.08046541693470172, 0.17728170890721584, 0.22762834845531374, 0.16859056398032174, 0.14444509671340067, 0.15085323833890502, 0.3025662724769885, 0.18375194961986235, 0.24868930059094585, 0.1290927866413709, 0.20945590019466417, 0.1349535737667353, 0.2079100113722586, 0.2745912542506572, 0.10515645371689912, 0.17737923189997676, 0.22942290941794075, 0.08338100201780758, 0.1324772864820496, 0.07380894024766262, 0.11052240166933307, 0.13272732225877623, 0.09543575556768526, 0.12952680609399272, 0.08887625795098082, 0.13655316535263293, 0.09922603686009684, 0.10444404557347299, 0.10828287385764623, 0.09840862870576883, 0.16371835203420732, 0.13027322088037768, 0.1702115140975483, 0.22194509454552205, 0.12972643328530173, 0.15092578686533437, 0.07785887172025058, 0.21040031806595866, 0.19407598031384332, 0.1081358079588221, 0.0851807723783197, 0.13357119875088816, 0.11090503194399419, 0.08075574893624553, 0.09388396786826272, 0.13923269576363026, 0.15770589482159386, 0.11963300271740845, 0.18193431408895602, 0.2255063002268153, 0.1575086578246086, 0.08741398762551048, 0.23437773628580957, 0.10356364200913137, 0.17221929265126107, 0.19079140898200775, 0.19335127645923247, 0.14646920826165907, 0.15950257018689187, 0.1379916180045374, 0.1580126823917512, 0.13337201589057524, 0.2642809671740378, 0.12775044738044664, 0.1725136542752866, 0.11343811698738607, 0.054884840989665645, 0.12886774065273424, 0.10405074369402663, 0.13197758265079992, 0.1933049281398135, 0.15521869844486638, 0.1250345507756837, 0.12924946694364473, 0.1410211433446215, 0.0907789292414823, 0.12356707105232824, 0.14460450428868496, 0.18644897747905026, 0.16874770393535016, 0.146206823147593, 0.14414397819388297, 0.07771388958058051, 0.15835334636992024, 0.15131253869302813, 0.20876855078724124, 0.1604178767170637, 0.12105945077153946, 0.17298774012634832, 0.14954906557836842, 0.13804830851093416, 0.13211776141918477, 0.17237975742788086, 0.1495487591431987, 0.12491793687184974, 0.2057606904136558, 0.10374351945375243, 0.13565166372685664, 0.18200009039813475, 0.10369324876416115, 0.10403605012763893, 0.1255366218186194, 0.16422968508014757, 0.06307037554741388, 0.11734039267344822, 0.10824238611084801, 0.10443944138504806, 0.22316299048402619, 0.1507613537532668, 0.16430091593534718, 0.2280256110093286, 0.1295440890375645, 0.14681430022803046], [0.08097778419933974, 0.060111303483286214, 0.07100964731146252, 0.004485982494624031, 0.04461048726713465, 0.0631711429225341, 0.032689963812909784, 0.04104172412846838, 0.03747815889636836, 0.15340051133065455, 0.030633259053912856, 0.05539245467873351, 0.04431300000437806, 0.04623205791557989, 0.01884382856529086, 0.024430946101464575, 0.025885375517029918, 0.030674744630232457, 0.053400277505598726, 0.026233976166094505, 0.037041293427107796, 0.07837429567570649, 0.05182802376727905, 0.07856460723785624, 0.03857533469976437, 0.03278613083004471, 0.032111400805954496, 0.04135786563218121, 0.03949304291557881, 0.023142110421172073, 0.04489120486522875, 0.04767477767722261, 0.018905136666651216, 0.026666683693146034, 0.06037674911860978, 0.05992107236036851, 0.056683040869932984, 0.04569709488761522, 0.07223484406788504, 0.07702681596481031, 0.028016731713808356, 0.00300227367739764, 0.049099900399244605, 0.03947901201524562, 0.04587653566211943, 0.0021849541019858614, 0.0462195668519745, 0.03832374376455142, 0.02405301577621891, 0.009961627055740645, 0.04251961881715444, 0.0365493692187292, 0.015308470690562842, 0.013399065487206945, 0.01552584718146752, 0.020686601356212652, 0.02269982487984723, 0.05641155463132647, 0.04767879197794584, 0.03622521826576802, 0.006375266398648702, 0.01942911016334209, 0.026127555062093084, 0.03235814431982656, 0.05926864507097391, 0.024452833233461268, 0.04140172416584627, 0.019039519979888876, 0.023853852068104094, 0.02822040384935756, 0.06475348220837694, 0.05578091871293803, 0.03729396454629399, 0.013802194359502005, 0.06474757567048073, 0.07642144562616464, 0.03778067935678748, 0.05017828023541839, 0.08659062696801079, 0.09594100587550672, 0.06735515510362965, 0.06355767641516943, 0.0029425532932603553, 0.0447476782926148, 0.026302533374438365, 0.05360905178672364, 0.038606728982901385, 0.04474775490140723, 0.049044481598802155, 0.012931159092864443, 0.035648426837137634, 0.030814559506853263, 0.07553290620806717, 0.03141396585100841, 0.028981027651518106, 0.015507359564634822, 0.009536024036576912, 0.0495842173545351, 0.03454799516006343, 0.009858657177838107, 0.04807671719801523, 0.006607121951322282, 0.013588782373605477, 0.05125679413697893, 0.03138265583754307, 0.0507719868854169, 0.030417990262409857, 0.02228427389185996, 0.07104328623221767, 0.010329524502007952, 0.06857426912193337, 0.1002629062220935, 0.05587006453424693, 0.029944013578877337, 0.041700785739287254, 0.003109189147512699, 0.04845868480662185, 0.03282116786126168, 0.10369184682325971, 0.0551967460271572, 0.0928042205651441, 0.01196269276401689, 0.05795110407615862, 0.031983082993857326, 0.03237749187035426, 0.04664768359713978, 0.025987077519417773, 0.02223251699169557, 0.038548973614289876, 0.023423417906967864, 0.03412532530003979, 0.05919568285706544, 0.018792573452716874, 0.06357539219841843, 0.06336339268713229, 0.021416679317612323, 0.057608134173337495, 0.06595716721588565, 0.035753223834739584, 0.045197394886805166, 0.03515828761362261, 0.049117773230518066, 0.03480374978314485, 0.022146027580264117, 0.15563704373855747, 0.037053321007519, 0.022328490571629618, 0.03706054138620535, 0.03305593550565743, 0.038027811660281116, 0.008927111498891346, 0.0053091923285636215, 0.025695402948786656, 0.07080543125348707, 0.07243533693854848, 0.04697148598009541, 0.015821281328587043, 0.030266128653179736, 0.032046536141405665, 0.010562463111484484, 0.015500459985266772, 0.030876672000534115, 0.07022881985551889, 0.029922164751276858, 0.05863199153194024, 0.04552922587120726, 0.08413314714186615, 0.02164017972386172, 0.019754214895768993, 0.034261535732976856, 0.09659098551398325, 0.0075491520223177734, 0.02288144708971583, 0.053234120695701534, 0.020788209512829784, 0.03294697865062664, 0.06463151334995224, 0.05463826409991711, 0.13193455915297234, 0.013397778459494154, 0.0772916908646303, 0.06519951391965151, 0.07172470611910667, 0.015126808261078213, 0.005132319385020604, 0.007727265549493173, 0.06757922816060244, 0.0697717258346177, 0.011493477316933775, 0.011444261913458187, 0.024866446019000104, 0.05125137023447503, 0.05724149981453534, 0.028688037324877038, 0.10885965379495775, 0.044636354225897984, 0.05304560560973422, 0.018039120233527595, 0.02123708532552325, 0.0931117129361918, 0.027844279576393387, 0.060418290236303886, 0.015074698960468655, 0.026512747900860927, 0.030267157126218084, 0.04402759394818737, 0.02266478018775102, 0.005715611548493467, 0.009191427154526597, 0.02129089151088509, 0.021050565898598685, 0.04573679356385143, 0.019645332734310822, 0.041965338882179036, 0.11481358955103545, 0.035572365797575445, 0.048952845991739345, 0.02215084435808803, 0.07432924418319618, 0.04414552169281148, 0.04136052012683884, 0.03501719720060787, 0.008575633232061182, 0.02763167868608669, 0.02354508799110209, 0.06586104616402619, 0.05567640133742845, 0.04321575142262925, 0.01632927327356752, 0.026960173892157695, 0.05895273339363837, 0.008436142985198286, 0.051897235980798165, 0.030410708596689567, 0.08247930887005023, 0.02446535302536382, 0.02149943596563272, 0.024409911242283644, 0.008542586114227532, 0.02876001894624243, 0.010571599667591434, 0.02724193720026843, 0.002814232847735947, 0.02920092744452338, 0.04367947210407546, 0.054321475251908266, 0.08153629293965717, 0.024030341488880017, 0.020630556278892105, 0.015311178811375174, 0.01731757840682422, 0.04072741740533421, 0.0430182118209139, 0.04958842700767902, 0.06485279018600142, 0.052629244483767025, 0.03703817544925598, 0.0629182534682895, 0.013085108291688225, 0.04111596570921041, 0.054090683603839534, 0.017422995935644836, 0.04606986944113047, 0.048087951877424796, 0.010992994948831058, 0.07844023286334931, 0.001135744380242672, 0.024844014964577173, 0.04713863487385454, 0.011583218771603801, 0.014353434840637832, 0.044012387102890405, 0.008659768838345284, 0.030403840618448395, 0.03176437063713468, 0.07068723154764983, 0.029166135561442184, 0.009862888856009852, 0.03313332187732862, 0.025986096926874695, 0.01665250109057994, 0.011629957795864152, 0.004785307889593946, 0.011412475010259979, 0.10109703041492932, 0.09076182249813311, 0.0577865522204628, 0.0212500513636417, 0.0466959739494468, 0.042126853199255083, 0.011076110700565961, 0.07385932585044254, 0.005459679767579562, 0.01729020800050949, 0.09963612372596418, 0.02862636150131303, 0.0885109719069254, 0.06131401938957073, 0.03180835557530724, 0.03493759683483551, 0.025897154118865732, 0.03441577987565148, 0.006096040756787144, 0.060702298182032766, 0.06336425836648672, 0.006099760592464479, 0.03049538237974048, 0.039405931057708884, 0.07737407596000741, 0.03486641960579061, 0.07695115712140838, 0.055743276982778506, 0.07389286517976754, 0.01682035670044922, 0.04523139003844512, 0.03793643269267294, 0.032510048063892516, 0.007506078249970152, 0.052296314163193594, 0.04008922019913312, 0.05600910949250383, 0.024286023333608627, 0.0187911102247815, 0.02854342290741061, 0.0386669549850687, 0.04420859754205712, 0.038395043567664204, 0.05011490178144267, 0.04623395015275286, 0.042822434221424406, 0.03914377960045973, 0.06296406552616148, 0.04471248038293374, 0.05260997354203174, 0.009841914326252957, 0.04492613847457594, 0.08974847203541188, 0.024675908460912686, 0.02187363927312676, 0.02891385514709738, 0.061415560513494484, 0.02007187133835208, 0.03396083856181752, 0.061451899894182725, 0.029755768538903327, 0.012395190574499148, 0.037374422930541544, 0.026927287652788144, 0.03675900534876893, 0.04331751854249066, 0.017793589053795706, 0.022193490557612914, 0.18733782333231744, 0.15469679338557107, 0.20711547094247035, 0.059626959714918375, 0.20839292255620803, 0.1599759359153048, 0.21487148298371225, 0.11389927127428594, 0.08135428577060662, 0.24991047538576588, 0.15729553216407377, 0.19855728823571436, 0.14911440261189016, 0.15927462838590145, 0.15760100206300137, 0.10717983748162947, 0.18574370161419917, 0.10960635203387468, 0.11718918223895373, 0.12004400888878493, 0.17770458944141868, 0.09417150364888292, 0.08475449041373308, 0.15867594599483476, 0.10402838924839612, 0.17267801077856174, 0.19902959676279178, 0.09325612817079791, 0.12666852438762305, 0.1625476471118389, 0.17704785290744998, 0.07226152691028773, 0.08405906643958823, 0.1337333029556659, 0.13099852228356948, 0.13125735274966688, 0.1886475732129428, 0.17483487004233947, 0.17928231687795732, 0.12428087347577657, 0.16750242801443224, 0.12145912650251582, 0.14543233889966242, 0.17967230159669154, 0.24994200756472928, 0.16874600322015826, 0.10584745736372088, 0.12136299012889787, 0.14590495386190955, 0.24092634779310998, 0.12388175698898493, 0.07962006189289593, 0.12427083006308925, 0.11875107463809753, 0.15192789115732716, 0.14660820725464052, 0.11330289480787133, 0.1181410771283892, 0.1390598663279126, 0.1396642943784114, 0.12166144266243904, 0.08791801985353233, 0.1171371648688951, 0.15741237589428503, 0.12874060070082066, 0.2075452462679917, 0.08782528491029817, 0.140749120844468, 0.11825449644557892, 0.2277821176234753, 0.11628295385068464, 0.20011632312690059, 0.11304310673186857, 0.07541284490857394, 0.15349382083983193, 0.20076267150861604, 0.13741539731141061, 0.2541221816453242, 0.1435378034629168, 0.12542640474895317, 0.1334391405145007, 0.17845281219530493, 0.16321521612905687, 0.22727375699868127, 0.18069548862836055, 0.1593125037728779, 0.12375100876294798, 0.1319817348473495, 0.13909582649507832, 0.16359496591312273, 0.10537951553781187, 0.08713215919992617, 0.15172368276023096, 0.13886869674728763, 0.09297910311649885, 0.19706456591525387, 0.1874602901478929, 0.1543427381904856, 0.20595003670502096, 0.10768423743185498, 0.12311055159737026, 0.14149211887871066, 0.19462028578404458, 0.10054913199236316, 0.08992440412722288, 0.1457773389354829, 0.17607242379698063, 0.1465435034685558, 0.19508019900850712, 0.17817052411696604, 0.16371799963376216, 0.1253825232326504, 0.10501753899358934, 0.181157071924498, 0.1535878504716581, 0.18987636292173019, 0.11782731049724164, 0.13100964588023004, 0.16910882246109749, 0.09810387126861081, 0.2712866880239979, 0.12512309521797205, 0.18417191901995292, 0.05369674204097641, 0.1032083304298501, 0.26980360308962487, 0.20500997021313638, 0.11658917451577804, 0.10867582333664741, 0.09874134069128383, 0.09261852085229852, 0.13852426361653114, 0.12387306955192359, 0.17502495177811192, 0.16409575758922487, 0.1955476505381446, 0.12893333310081115, 0.0963339553545079, 0.13884058132046653, 0.1921604847114894, 0.13524533069181827, 0.14810918800292477, 0.16762008379784324, 0.1536193826506215, 0.2809596512346499, 0.10382354499832278, 0.11560111261543729, 0.10620330520454915, 0.12038393742254666, 0.10812891316750359, 0.05510947712126279, 0.07799499788351598, 0.10001611865816579, 0.10941702872514726, 0.15597033795089493, 0.13703025426835785, 0.10519693380281811, 0.13636343601730563, 0.10535221982506976, 0.13572338487832777, 0.1584455067472112, 0.05527733464635188, 0.1278292625060966, 0.14223170016081105, 0.13778008580688508, 0.18335310892472345, 0.2700236541849952, 0.1523096634135131, 0.18169192386971367, 0.07064667485293842, 0.2212556613789451, 0.10996999864977215, 0.19158518332387173, 0.13387262370557557, 0.137090775214376, 0.1109357980350333], [0.05854441619087612, 0.02034777215862226, 0.013049407636806851, 0.03023210285802282, 0.02590183108564346, 0.019511908946198323, 0.02880920562142086, 0.02077536796399903, 0.034038542859977296, 0.029076238973967494, 0.04635748183054309, 0.031081070004391576, 0.01831942605936239, 0.02382445535922964, 0.01812915663204847, 0.12160902692665979, 0.007719612331129611, 0.049195397089445786, 0.03273407898602947, 0.006781185746207954, 0.022661304063794595, 0.08243851468808229, 0.045769103322057955, 0.04108207780987986, 0.05025393907882033, 0.025132922042581825, 0.02771063170756304, 0.04409795912403253, 0.02944049271454494, 0.033228466167084636, 0.03950537310072011, 0.0619881499498602, 0.05892347266537048, 0.020407933043316007, 0.01901478491603367, 0.028243746548410387, 0.0643193784860834, 0.04099211610493161, 0.021020439490976355, 0.04602879563707017, 0.023462149397199674, 0.014632176889497188, 0.06907098521027835, 0.030569235170860926, 0.02889068673304733, 0.05269198325432597, 0.03358093939060646, 0.01300347779291652, 0.007373639842450259, 0.036847036512148, 0.08569607375970772, 0.03956753730533585, 0.02233598482674889, 0.09699862855937212, 0.03424202347354543, 0.07031118196825828, 0.02971960918887729, 0.061178149865759965, 0.04914372828939269, 0.07148360292757712, 0.015040603259788647, 0.030816336830837593, 0.005270307620746955, 0.03494997681569188, 0.01470220402904576, 0.03911314374436775, 0.044018377910458276, 0.04210724900927275, 0.015159443606652561, 0.017513733304616426, 0.009956008758425955, 0.0690205076769475, 0.06467640610231508, 0.04380850429316202, 0.006072559204298042, 0.03842775552203098, 0.006909037202281217, 0.013823198575165965, 0.022634584832215504, 0.0680814370993645, 0.02654493700021938, 0.054778163246209585, 0.011585497883178536, 0.012139564271145051, 0.10247102442888484, 0.008915945767394958, 0.09932955066042562, 0.03510851105074248, 0.02404207029500075, 0.0392520354850398, 0.023353322777116013, 0.030359449653675964, 0.012666297599583144, 0.012922201609809794, 0.0029253021902179406, 0.04152888326995796, 0.051617682836348974, 0.08478498071311943, 0.05595360642238971, 0.09571529339037596, 0.02105342149133644, 0.05120030664388211, 0.04394924996661083, 0.014866849730512308, 0.032803628278235276, 0.027920647051125288, 0.02675538709867866, 0.05397193997557606, 0.04832549276010645, 0.032942382123080954, 0.06918055876608818, 0.11389247607439758, 0.10146431594846711, 0.08817211589625767, 0.024209077462493896, 0.01474739459808916, 0.01941657504968105, 0.048876589599756465, 0.03177299104150265, 0.06054593963668712, 0.036404191726638425, 0.04697262745110258, 0.030250360648478233, 0.04810733390190909, 0.02808626185381605, 0.055427001413678935, 0.028613468241547386, 0.0064096556067646995, 0.04739516324573948, 0.017630079077676903, 0.0612331549787233, 0.011347995304893102, 0.017245895559749296, 0.02413341095821271, 0.07931274572207082, 0.02643701053344675, 0.04814212578499029, 0.02198611055651019, 0.022874975561975472, 0.01300092576251876, 0.04237266783151896, 0.014794064674436327, 0.026044524537639755, 0.00925318054449294, 0.010092437526421442, 0.024175815840041446, 0.04784759562162142, 0.020628016697423115, 0.0517780288693405, 0.011723420522626371, 0.09095080872817386, 0.1071393573957105, 0.020102601040214784, 0.04629102370311176, 0.005508732377371241, 0.05839636969950892, 0.06037665718805887, 0.011635583754058086, 0.07739981651426324, 0.007123113769452058, 0.01896018774489001, 0.03216697473920161, 0.0078103180989743245, 0.00821301125876245, 0.05671946068985328, 0.051160929724574096, 0.012504035389171013, 0.03856215798746675, 0.08588147469826284, 0.039088709370022824, 0.04702424262500098, 0.044120087573725375, 0.03635890060855496, 0.06178173904998168, 0.07966510786284363, 0.07905365478607916, 0.07742328178738395, 0.06232234814594831, 0.01910522159549498, 0.056772726783228505, 0.02762519758224728, 0.034230068671487035, 0.004670811740065655, 0.02964523545796833, 0.09345704238981971, 0.026243946800429015, 0.06756392172387532, 0.027715921544680194, 0.004900621359176453, 0.034880557758433205, 0.008989007572733588, 0.056472941256699064, 0.029547702889108372, 0.0640566639542099, 0.016094528611809496, 0.08398385192718237, 0.10063287306336627, 0.022486088264192787, 0.02663165623802812, 0.03918853445699619, 0.03877495039975451, 0.010348583811954146, 0.020589666335933635, 0.09264220829091727, 0.021260807238098596, 0.0307835137937218, 0.05669337922647115, 0.02383136738752646, 0.04235275337592729, 0.01762026932180649, 0.04503416836321835, 0.036782612348155636, 0.06017716406213661, 0.024654260731392333, 0.04178108324507072, 0.03450418259167383, 0.06275849732299967, 0.04477274851993688, 0.02091070888714204, 0.016139390720655362, 0.03207848775350759, 0.07425181567668915, 0.026496441719392617, 0.02554234624239466, 0.027728410693065777, 0.060381345646155465, 0.08376888765562927, 0.005568361309762564, 0.01294013381289739, 0.028129243216807806, 0.0419150069055538, 0.03551081063285951, 0.04899341417776962, 0.02282099509161086, 0.013479454923541316, 0.029526606742893497, 0.07901839941980378, 0.07682841451418015, 0.023229674270917332, 0.00722566900226558, 0.03389809213037934, 0.08869503219161304, 0.01419566669351151, 0.0299154078557847, 0.0025157056206221422, 0.05345846954432707, 0.049298290358555895, 0.05084014572804013, 0.050283111706976934, 0.02912170054661411, 0.06258050445467234, 0.06671105135953234, 0.04305373531796279, 0.03833105607378868, 0.012553980491394478, 0.05059486735732325, 0.026964224582057328, 0.06916131463743026, 0.04798647204053499, 0.046801211447605205, 0.026874875747448495, 0.03440190602334277, 0.08007388471836045, 0.005822786770295353, 0.04876035490944501, 0.09528135054654653, 0.01921229770467166, 0.007945851980513263, 0.01622305518286603, 0.03766236090732198, 0.03003889165307966, 0.022849133501069683, 0.054159390199328625, 0.045149529713296124, 0.05950666858904785, 0.05164755643495629, 0.06686471327538453, 0.034847550860215584, 0.005626077895172902, 0.020657984141801155, 0.052969988901168115, 0.06263359434782498, 0.029445995141061086, 0.010785058576373324, 0.10272184161529427, 0.015612581741034746, 0.012132818866971762, 0.04080211097795156, 0.034547968346986084, 0.02911469275732675, 0.022257139057581945, 0.07153426432200978, 0.020298472485475002, 0.06137288175523282, 0.03512345742614519, 0.0654796569518024, 0.04242782616206715, 0.02038214460856492, 0.007709760919228317, 0.014913023764928503, 0.01702903139014398, 0.03674936413224186, 0.019917914478649056, 0.02652171687523444, 0.07296192279506115, 0.044482493127185496, 0.03329738726719253, 0.02260786943107603, 0.03297340102313507, 0.02856775194466595, 0.042320255926179315, 0.015031917737947117, 0.0589249090802285, 0.062149993684743686, 0.014957220334890149, 0.03296855934745362, 0.04142107171637397, 0.05197703169899122, 0.04249008612767343, 0.035056260023866935, 0.07788251319359388, 0.01764272910452658, 0.06489414361215408, 0.03934435674079484, 0.025532823769495856, 0.03212272741591498, 0.08984338266835099, 0.04373143201753978, 0.04022800468749577, 0.03913783475816731, 0.026639211780181336, 0.008775330328893279, 0.03616759696254327, 0.01825507658894264, 0.027208985843425317, 0.027291077910171404, 0.0505066599937216, 0.023610588508628072, 0.06029860815033317, 0.0017025819327118959, 0.012290229825603386, 0.047217093768619725, 0.04776550930053477, 0.032051308869173935, 0.04270948604830811, 0.04087979612391322, 0.01881593913440743, 0.055050239372517795, 0.031121326009592706, 0.021935385959823767, 0.1104207494626603, 0.10311217873447365, 0.17188080436279699, 0.1810606367765896, 0.11858003018724343, 0.14550697118524583, 0.21790698380960574, 0.16933776017638946, 0.10999246800859129, 0.085646262722871, 0.2899416337811178, 0.0997665272124352, 0.16447244302159356, 0.13436906400226778, 0.04664299130860356, 0.090099171765389, 0.09532512481053991, 0.15009663458312714, 0.16952684599786036, 0.1876125577837229, 0.12590139458376554, 0.15813415329302513, 0.12336906796741871, 0.12873960478651908, 0.20311106807522236, 0.17343754099021036, 0.152486537793471, 0.14754513278603554, 0.16102124756622702, 0.21255538468399357, 0.149179520085454, 0.12669820263380968, 0.19066917199280956, 0.13762818589325876, 0.18051427819075125, 0.13132202589223463, 0.11755959341122259, 0.09185467756563619, 0.1298674700721618, 0.0988055695028555, 0.1892296314960526, 0.11443860483385863, 0.10622923728078605, 0.17336793424141023, 0.15119368781245526, 0.0813476437883031, 0.20308863702079943, 0.15205432630835042, 0.11238326754180655, 0.20217797298344875, 0.12586531950341118, 0.12158375368603777, 0.12633961219821246, 0.13844915635643468, 0.1224115270099813, 0.33533951387770716, 0.12086275769698045, 0.19952225258513806, 0.10260025580083171, 0.21494070668855023, 0.20102373895145234, 0.16459765243193797, 0.18783100009445222, 0.14056221071270206, 0.08350157659621009, 0.11027853290039687, 0.1035911905308885, 0.193393288721, 0.1303200594960682, 0.09376794385213046, 0.08529105073501987, 0.15508645634737708, 0.11652343651099552, 0.2526245716839068, 0.1692615957149575, 0.1330667911397834, 0.10387248269492581, 0.10313466341505129, 0.1027133840046102, 0.1738818260210176, 0.07949891274855023, 0.17835973251250484, 0.11004088476540581, 0.22020383798066648, 0.1426779616984629, 0.1429611690823109, 0.16662415417452014, 0.10273162455808732, 0.20748984278930774, 0.15762516447613317, 0.2546581061136338, 0.18514650543370556, 0.09776010463434844, 0.1358468476082048, 0.1585137192159891, 0.09867825335071934, 0.10540881840091561, 0.18868489701661373, 0.16548257591503282, 0.2120265082245873, 0.22853890524035503, 0.16958928216368924, 0.11490007321680747, 0.19613890187634578, 0.12852650976950122, 0.08212219698414688, 0.14088395231914136, 0.16859926673914158, 0.08577897213399412, 0.17363683110283268, 0.2264765812264335, 0.12948410435309335, 0.21648785189515163, 0.2086704302458994, 0.29697701755550604, 0.15141976035891042, 0.08191084864759639, 0.21486992016434672, 0.08082032248738312, 0.22168168287363746, 0.15154527620442454, 0.1961543308871408, 0.11213805811900286, 0.19251881467719234, 0.12720417306427995, 0.11863331160237713, 0.1298931186958667, 0.14768249235085903, 0.10937992708697435, 0.12588088641003256, 0.10825046067756992, 0.10816962307979984, 0.11594522398926559, 0.14362055628049758, 0.08304671189116855, 0.0659776677287394, 0.21342304054527514, 0.08001789901285403, 0.13378771052004831, 0.13654004992736926, 0.15963655896484852, 0.16108037423222296, 0.096894157149138, 0.18484816015247377, 0.159062713144287, 0.1620896950724625, 0.1334652334692017, 0.13559546351673143, 0.21867219839365254, 0.16643462402205314, 0.1370092328157156, 0.15596391813408944, 0.24213259919516503, 0.20283595057985476, 0.15077310554202528, 0.08245428843844323, 0.11901172839345471, 0.14926296238216663, 0.19506896815953717, 0.12454948688466703, 0.14995673160639503, 0.18409979950276115, 0.12505926477212098, 0.1844644267112017, 0.1263519845181896, 0.06040056679217566, 0.11835115375898539, 0.1615264672305315, 0.15579827460310153, 0.19608613374012132, 0.1956211949788755, 0.15498563917654176, 0.13442650527483033, 0.17936886949164255, 0.11578868924369735, 0.15468582300649536, 0.237966934819856, 0.24518153720325042], [0.06045302466279077, 0.006730407044561881, 0.027190871694455707, 0.02492709336952577, 0.056877179041264526, 0.022921149596391667, 0.05800514391833737, 0.05317862911690628, 0.06059933979544909, 0.12128844977386537, 0.07056294144281457, 0.04911855080976121, 0.08617664071460886, 0.062120813395707845, 0.05631217770578881, 0.008618572460217102, 0.03758769031734236, 0.07383785240592496, 0.02877935117501165, 0.029542296223582763, 0.024938565536191868, 0.04806239135383118, 0.05274015486300473, 0.033616708035791115, 0.04141080230774899, 0.052529442379431385, 0.015213644327295404, 0.027918097893557245, 0.06014272457950058, 0.0375986147311426, 0.026135568341781056, 0.027787889759506912, 0.03396078110522321, 0.01794732949366012, 0.0915132015342674, 0.0336246868415225, 0.038900565836698785, 0.05260032849506505, 0.030598505475227872, 0.027702120470724283, 0.020541375983626615, 0.008894141947460032, 0.03139700274914503, 0.09504860537427087, 0.07289747947887068, 0.03572446106362247, 0.04560210764588368, 0.006989841762509558, 0.008512406080450502, 0.013277569688075494, 0.07270538293185734, 0.016051579807554523, 0.04566468553797853, 0.03277121126771935, 0.047823934996080016, 0.01983385165071776, 0.04239862289039358, 0.006735514935797021, 0.0508810165188005, 0.04176669228341311, 0.04247680216306641, 0.05315582650984007, 0.004088481974547669, 0.009442639833826934, 0.02351244689986831, 0.0323036716379706, 0.031306650339355396, 0.03263038898547811, 0.06279413190279758, 0.05590892051376643, 0.022612130795154842, 0.04235593647125267, 0.007740611758744045, 0.023163103145517172, 0.017880622387653398, 0.02331283119987817, 0.015924314408743336, 0.05762122661596345, 0.07119835008897128, 0.05903855056291627, 0.021367599894743294, 0.05047542275860906, 0.060014845352740064, 0.051286177439314705, 0.028822717497185357, 0.043831379678581035, 0.039961597611827236, 0.07325384059860822, 0.03658124230681889, 0.0314984193837811, 0.03584087961503575, 0.020247594671203725, 0.01865143324398706, 0.04875868100733046, 0.022617807506673762, 0.029936590186891057, 0.0362069049339381, 0.012566489749588074, 0.03331721745311253, 0.056021738451935595, 0.038216472302954045, 0.029994868410510883, 0.027271582887718276, 0.06811408776669733, 0.07666725259754928, 0.03359500093445663, 0.04546922203453799, 0.04193130542614287, 0.09402414663664757, 0.009888366067541704, 0.05721176794219402, 0.06075633036333227, 0.07767904790178423, 0.014756594356449862, 0.022170132536801602, 0.020202828323348396, 0.048392023665890585, 0.0417795587301014, 0.04495402790545937, 0.004667391157483742, 0.061762544717038834, 0.035234697223190344, 0.043334380137704076, 0.006508980342562521, 0.026371724520539565, 0.02040848079618187, 0.04048459817685428, 0.0270475845243181, 0.025912198170478788, 0.013633466367008946, 0.09108046910935834, 0.005701591660674181, 0.05583377111883414, 0.020017668702489427, 0.012499511639978136, 0.06827433037781908, 0.014793131962388515, 0.021268422152065945, 0.020086660665730317, 0.05410192211368873, 0.05903026532201518, 0.00747458964225746, 0.05335240467121044, 0.009590101225541965, 0.040261770012758435, 0.057122070537579644, 0.03740569080917105, 0.026184540512340686, 0.05873290829420571, 0.0637644358850535, 0.020696876510497064, 0.06752385532543545, 0.04352685589823992, 0.026124959939249584, 0.023370735955634908, 0.0196046841090485, 0.042798877017752784, 0.0522965669722086, 0.10636921686631058, 0.07591917540036863, 0.004398649907670915, 0.019392033423026724, 0.05417796783149243, 0.07281326343335452, 0.06873592899571504, 0.09469427438753267, 0.0464969749502357, 0.11211537425556492, 0.03852410640026774, 0.06857384777357502, 0.024984002210980943, 0.0663077826761911, 0.03699684117530142, 0.025078397649790973, 0.03109798139532007, 0.007111329421956814, 0.07009465487733965, 0.018890301373997526, 0.016377193988451076, 0.08886141116700827, 0.02633488909792035, 0.06654483326260122, 0.05987000876977559, 0.05459316450381472, 0.0423944553720855, 0.05763845593338052, 0.0788011675279948, 0.039569211207450404, 0.025443653050329418, 0.05124087482991238, 0.0369341253873802, 0.024422216529567397, 0.02235849057474444, 0.018621525171423153, 0.05223960833503835, 0.037917579268856395, 0.042132560554290974, 0.060842281597996914, 0.05155856766167188, 0.011410857607129843, 0.039499684897882324, 0.0700622187146256, 0.02124940018890606, 0.041938253843616095, 0.05804397691521914, 0.10308891264421326, 0.024105977349644227, 0.00299377249546289, 0.028622370183227525, 0.003697575556279551, 0.04687515808449638, 0.04026229478298657, 0.018497775158574505, 0.05269646486868301, 0.029770523392324968, 0.03042630806204773, 0.025826352272903728, 0.0451764615342742, 0.01669493470070583, 0.09286368430982675, 0.038379974618193605, 0.0697497850764663, 0.04675688176986672, 0.04794787653090973, 0.04583333213362963, 0.031224165652548114, 0.10709428078224582, 0.11379722070189253, 0.057366111676298806, 0.06760617913377863, 0.023095432683945667, 0.06372561054905096, 0.029115274984149203, 0.08815148514845679, 0.04288447968241188, 0.03616113118046234, 0.060160448023628806, 0.05883181024523032, 0.01314302453876383, 0.04575054484209226, 0.04312530325184907, 0.040887935808108705, 0.018504466936593095, 0.01846760661611634, 0.10772446470875895, 0.02167828876765505, 0.0358204135761386, 0.04258419236829204, 0.03561004583213118, 0.026018707374591502, 0.02608375973068178, 0.061671782450209704, 0.10833258530305279, 0.05542412092308364, 0.04553210253136293, 0.003411612649928899, 0.022331880510694558, 0.025997057729851336, 0.029589393393947717, 0.04995195104950859, 0.03304206931422795, 0.006333595524812418, 0.02908920309686613, 0.02992728221861105, 0.030587699805055896, 0.06744727717652436, 0.05282646232855417, 0.04407275866176333, 0.024119596477718126, 0.03774759968021705, 0.016001075461146333, 0.025117763077780127, 0.01402689560857271, 0.05485470692116407, 0.04349746876546452, 0.0718695733455881, 0.02851646235813537, 0.008492944574344062, 0.03602281017529388, 0.08982767020502398, 0.11221712605366785, 0.02405952177791586, 0.041976795727086645, 0.025709140820488818, 0.06045981220179989, 0.0351091583950385, 0.025001241104497064, 0.012929904623888435, 0.07106626120906684, 0.04002601411494036, 0.017685204849488313, 0.013437161124461602, 0.04726736445821101, 0.030365656881082444, 0.03401775889459156, 0.027455871083563375, 0.06907105415819154, 0.020849130739788377, 0.04437196962234955, 0.02700020964708059, 0.07136966267059888, 0.05595827189784858, 0.026891398348755417, 0.021637138354802327, 0.07117211923844392, 0.012481584224940069, 0.05968725849543849, 0.03253827840390225, 0.01272265198490312, 0.11553234090247463, 0.02240153322477014, 0.02518613450980235, 0.009881454039244883, 0.02188392591873004, 0.03980356516436704, 0.03655342948472789, 0.09414000977431575, 0.007193075791527067, 0.006065220560788388, 0.0339011641429557, 0.06718586499412214, 0.0195008083321755, 0.04044749270824175, 0.022583103723703854, 0.06002212318802073, 0.032222462487557245, 0.03804168168215021, 0.02525349853620414, 0.04731357105136399, 0.05021301466190527, 0.047603585126419226, 0.08083293995549602, 0.022886641165842454, 0.036659865910487796, 0.04371330254681168, 0.036169968004668915, 0.09322207556256364, 0.05608448105293417, 0.04182396501663231, 0.07262915718339144, 0.017807315434179, 0.05221349622813925, 0.05871544915041136, 0.048914216008157506, 0.029533262131735686, 0.03540472660754477, 0.09030344911039838, 0.07537198177869282, 0.012832740734842037, 0.06947371763207259, 0.08974504762239034, 0.02994519718472035, 0.1304559328503186, 0.09882816909662179, 0.10505828721028183, 0.18369873715264184, 0.20862642615552873, 0.1833859587749166, 0.11845616909164576, 0.1637232703186812, 0.15266115987493148, 0.18022370104107166, 0.19799632801403924, 0.1542103735189284, 0.1971031920683961, 0.1690767540205871, 0.18446145429005548, 0.08660916629577838, 0.11741316336537562, 0.15950990930920647, 0.1368347179865645, 0.14758011236065818, 0.10371943364941305, 0.17724026355051226, 0.13128833334532478, 0.14701594989145958, 0.11525901605284984, 0.2704896807910935, 0.148956986865209, 0.15916964369675807, 0.20885372444266276, 0.12253337329433811, 0.08326738351775755, 0.08578778214512334, 0.14894667532174818, 0.0754754955790216, 0.18130293506528103, 0.12361470639946, 0.16516383737325668, 0.13060323623639922, 0.10100317698332573, 0.13127311883914855, 0.09868811290230482, 0.1076786909552832, 0.09777492843568326, 0.21214531313988472, 0.11534880155757551, 0.17529219388961795, 0.16687009904173114, 0.11707023176695071, 0.17443336336122406, 0.17663102446784898, 0.26711224428107666, 0.23137125487048782, 0.1654655687631138, 0.28619295106299464, 0.1073990841846793, 0.12361864409139081, 0.17685276095665273, 0.12798054188850427, 0.1433772773992631, 0.07126461669442154, 0.13732250148971237, 0.25161643061907063, 0.07210590380934939, 0.13216545805335045, 0.09074384241455025, 0.1290600746870041, 0.12427562577349525, 0.10424745209034413, 0.13575332359440867, 0.11851985398079119, 0.09652692524175491, 0.14936272235166642, 0.10499533010466446, 0.07828767411410809, 0.1349345288209377, 0.1111248302303495, 0.14704385081366186, 0.12475796239150148, 0.18579889058826432, 0.13723660771164203, 0.13997748644361574, 0.1180644070489272, 0.19196162360810465, 0.1364132930194178, 0.06407046502816581, 0.18337319575009808, 0.163059669636911, 0.14419617942504345, 0.09341261695109068, 0.1768001920032886, 0.11966088831785227, 0.15630422971181332, 0.13408403332916, 0.15705559342618913, 0.09573831433250059, 0.13208635181428927, 0.13235446726602892, 0.07726605756268387, 0.12040940218514974, 0.1471232328443758, 0.09160192217677833, 0.12689566179629297, 0.2407854795455933, 0.14756218590323003, 0.28367834406033643, 0.07673475260455763, 0.1552526514616705, 0.12136403200847488, 0.2165717691663773, 0.1232452528370965, 0.11584626075120703, 0.20126229873107326, 0.1506518185018532, 0.07686399929826299, 0.1206321805535305, 0.14680527571228244, 0.15549174750283842, 0.09915818445264332, 0.10446720441142399, 0.12565201764265377, 0.14825379475951195, 0.1475783810019493, 0.24004557650656472, 0.08750223329350834, 0.12303419561395723, 0.253839694384125, 0.14763442799448967, 0.19694300308342905, 0.18493537160177387, 0.13403563189410395, 0.1679380256081781, 0.11092471274276895, 0.13283696476249926, 0.1616739085124385, 0.11926821463050381, 0.28331616833325357, 0.05699630954392976, 0.11621021380227421, 0.12584331745822586, 0.1874758264109973, 0.18531086193698068, 0.09768213986629441, 0.08529820599623265, 0.05211335704511693, 0.15794644642981792, 0.07869249029505639, 0.12302982891278884, 0.12039530616734298, 0.17950756204945428, 0.13274385443618222, 0.11781066340664703, 0.17410553901666598, 0.08604444458239502, 0.18139469707685132, 0.17510306210287158, 0.1402464905573476, 0.06072580942042893, 0.10006964522143526, 0.13178235280417627, 0.19798270697074552, 0.1575032339221047, 0.15825654349980817, 0.1654246903114742, 0.15929445474138185, 0.13115923220832504, 0.17163971649302592, 0.20135061334698431, 0.21450448090270643, 0.13140666328610914, 0.17789021254547183, 0.22010614644856225, 0.1558697506064369, 0.17008213716889584, 0.11667148300236273, 0.19152787994713555, 0.1782247631420051], [0.042960632652524984, 0.03894309137737559, 0.042390866250160246, 0.007746151532046498, 0.015885030377596136, 0.06304317559566229, 0.03838060664073114, 0.03436664682662776, 0.05671648826870707, 0.038140288689323974, 0.0348117592323932, 0.045072223780856985, 0.03669497572005757, 0.05303330223767027, 0.07035425143136133, 0.02868093760503877, 0.0747764097045987, 0.0021585018041678857, 0.011673893895931544, 0.012844307704888766, 0.023033998178077802, 0.050780969266329086, 0.0036197204345596898, 0.04794134563135524, 0.06690110245178785, 0.024213965103450804, 0.040849681207609755, 0.030710118740136107, 0.0956969379237102, 0.024450073401714047, 0.06069170701647959, 0.024860026202194636, 0.06858597494541638, 0.049071516841650016, 0.05789208849291167, 0.04098197693125375, 0.04393158780951654, 0.10507858854027526, 0.008840355871906205, 0.017643690544871554, 0.042297315423286734, 0.027441801878833966, 0.042024860083456, 0.01629709375030812, 0.00865009123264181, 0.11714592891474886, 0.017516768928016388, 0.06531407470784842, 0.02231499976328304, 0.02271305138785993, 0.05194179548491394, 0.03581641076673423, 0.044470316159629056, 0.03517411499013824, 0.05165273901976405, 0.03565693424353677, 0.04071732802737144, 0.02349509883882298, 0.03699756512838987, 0.041350120483266736, 0.06265475752673323, 0.033201587972261255, 0.05900055260187196, 0.028597493393106327, 0.02902454719127667, 0.0723770682910277, 0.04225384376402344, 0.04745489512119563, 0.057040068486164656, 0.048393785668116425, 0.05145176351370831, 0.04270208180851994, 0.06432045867005665, 0.04152065548565119, 0.05768046053426881, 0.07270349835556361, 0.0613627310902361, 0.013349841465242209, 0.09199083437241855, 0.029042356820296378, 0.06569139599319428, 0.09247084208313497, 0.024217875982304255, 0.044974440318201823, 0.03429260825918567, 0.05094457500343842, 0.05641779441746974, 0.03985789228951739, 0.012427170914898237, 0.09534064575188583, 0.05935603272049658, 0.05219754244711611, 0.004702082491524879, 0.08316825174035565, 0.05479183408521837, 0.04358670651732434, 0.018912094660223495, 0.02841435624436746, 0.04023241352350001, 0.0407484082144595, 0.03042720821535876, 0.05059368758191986, 0.03951415246833236, 0.0513158671768202, 0.022884574643666708, 0.06715451667626059, 0.05015777589212503, 0.037995655119659445, 0.005040826461833692, 0.02635738718503666, 0.02735654012330117, 0.020866448157316735, 0.032773367805226196, 0.009222933478022536, 0.04139015623818963, 0.011597276485014347, 0.06733859994358594, 0.025145895741579515, 0.07566573819325817, 0.0806210323747608, 0.027067083377210845, 0.029319684479325533, 0.07751119803757438, 0.05545435075257575, 0.04025928022700452, 0.07013230043793879, 0.03988944362067888, 0.008529752226276024, 0.052509068271085146, 0.020912005490953886, 0.050899260902717236, 0.09214507851509318, 0.040790190649849754, 0.025492648203526775, 0.025600561263760733, 0.07194632769472177, 0.07328217053004811, 0.08437549139583304, 0.02848701968398546, 0.09091102578226598, 0.0629452963720166, 0.12353458126345951, 0.023551605484117905, 0.037367976300658724, 0.00533579090129464, 0.020792618348834016, 0.04527901772469763, 0.0584855308425763, 0.03308273709168838, 0.038699620974160014, 0.020253089436840628, 0.04403849154891026, 0.00516656160001613, 0.06855249690312533, 0.025738740542663202, 0.03959783608274114, 0.08988943987435873, 0.01420586428139359, 0.08219603253828903, 0.07936945155022607, 0.030203966363783807, 0.03388662379415285, 0.07480974219018414, 0.03339817762495049, 0.04268502486088584, 0.017208355336239742, 0.021591573360285932, 0.021687307537743644, 0.00846893825162683, 0.007848283980086806, 0.07429393519076609, 0.07556594758024139, 0.04152306483217305, 0.02896093891092366, 0.030339077460549535, 0.07479705577415806, 0.08628185523012954, 0.04865985566509828, 0.06661590323933671, 0.02066245426483933, 0.054604054443658366, 0.07003295415591809, 0.04512938160088755, 0.05077834541518843, 0.03997434914532689, 0.06968192500813354, 0.04442579112946988, 0.04806153716579561, 0.03621270804996452, 0.0796370230795395, 0.061837617503178705, 0.01736445341169113, 0.004930017110441001, 0.022920532895612623, 0.06465513950153705, 0.13790973852719032, 0.028633187344718366, 0.053230382186631044, 0.016399157729240197, 0.022440299188958544, 0.04699843695327159, 0.029670156298145175, 0.05064943963060937, 0.031083739820807695, 0.16168717715528705, 0.052119688761811105, 0.02268570779462255, 0.06860328853250512, 0.07783717611023495, 0.06434400821284902, 0.022425452404985988, 0.022396199337597338, 0.0348808067370086, 0.019048086758102142, 0.0255894051083634, 0.01722435508253834, 0.03838856629426441, 0.09615219333359311, 0.007154813051343926, 0.011552974577963112, 0.06006263391745668, 0.11241496059923403, 0.05086335053126659, 0.0919903057717508, 0.02176366926681611, 0.02806664234207523, 0.034384638401529485, 0.03227464456651961, 0.04332282753180593, 0.017932482709687565, 0.0577469646269756, 0.024763451243240028, 0.0799727381297177, 0.026995576730358507, 0.018136547465297966, 0.02176317130966533, 0.0533468313815613, 0.027795539147430853, 0.01482914575570894, 0.030280956284954186, 0.04701380467703266, 0.032670961001948, 0.0315997191900087, 0.03535750877833174, 0.015462732070215769, 0.02826415513071322, 0.09696011731941855, 0.018274456698207125, 0.057459815720757174, 0.04759532669859548, 0.05155525433139936, 0.04474452967124601, 0.04282250316933759, 0.02402077113548594, 0.09958140206553283, 0.010908183269953776, 0.04973053631763305, 0.052721730448425784, 0.013062180237724416, 0.04286504020133326, 0.0610670862689374, 0.025043268688023094, 0.02555149907787, 0.04272498783745593, 0.03009949495354968, 0.09559741544146692, 0.10076648645824003, 0.039224027310528105, 0.027424507443943334, 0.02203981715044187, 0.04941925947223941, 0.011354136457216116, 0.06963979783317736, 0.04646877525374294, 0.030459263249330466, 0.04203665783748992, 0.018565725242238373, 0.0016353288693578855, 0.06437979217979216, 0.02671690075658262, 0.08143991141790345, 0.020893808987532413, 0.02661993892322625, 0.01106882424679615, 0.029753956740962404, 0.013972832783756238, 0.01589243653260412, 0.007010415532521063, 0.04754391453799702, 0.006028214204801066, 0.040040634902975256, 0.06882143972982323, 0.016727466624410405, 0.018851500935852528, 0.08139304981957521, 0.0685927088582708, 0.009333856306189011, 0.02679955398273324, 0.02296457720559932, 0.036321251217516205, 0.06887184831524087, 0.010130083087020585, 0.009840276813314808, 0.08838233808355947, 0.021106974867683266, 0.023947607823497346, 0.04228099775049956, 0.017971535956847574, 0.013435794615126668, 0.044948492920206445, 0.03711911646889583, 0.051507607492948734, 0.03474277301481174, 0.032694269227044236, 0.015617788266090137, 0.051212257615500884, 0.04468317751983001, 0.03760722555941151, 0.012250206519609258, 0.07062075809846002, 0.06946308433168358, 0.029234032018951354, 0.0076497192569677875, 0.10810252143851212, 0.07882887692821604, 0.017190461437548363, 0.0718902960239399, 0.01692480512804562, 0.03026512699321874, 0.07551704052715533, 0.017461367364552234, 0.01657105636812987, 0.05532418092292163, 0.13130984509423857, 0.04832103412838713, 0.04165450636778147, 0.08901200873116333, 0.011717294692061843, 0.07875489581736826, 0.02721980300491616, 0.012185692340285789, 0.0756932867150153, 0.018774062853246447, 0.05464034785907115, 0.07924090965741104, 0.005877504121482132, 0.07988106038781904, 0.012917025728271374, 0.010121984580051034, 0.04215325641956541, 0.0630428729909322, 0.06228736474088604, 0.15032882051121804, 0.20299289135202286, 0.20422469944723193, 0.24430185376155764, 0.20530410201078464, 0.11692423839122058, 0.1722972957237113, 0.1494986110276753, 0.16145505251423006, 0.21583433293046492, 0.15704430129018523, 0.1537570180070977, 0.15419045523289712, 0.18693345148236523, 0.16770141169188485, 0.08145333327833684, 0.13550068311873945, 0.11693995085454757, 0.10473597869877854, 0.2699363201616272, 0.10066866469118865, 0.13683977416686474, 0.08767675578353867, 0.1623233978546435, 0.11144428889477447, 0.1447738403634679, 0.12320153219925782, 0.187759907135079, 0.21006593600876872, 0.09821533706159362, 0.13234766440526133, 0.14261123544025806, 0.21192936827578854, 0.11465296389595156, 0.10012753848587314, 0.102955283927581, 0.1213423440593385, 0.12975621878379776, 0.1047343775750168, 0.22392661160519048, 0.13064864992855058, 0.1319764335189135, 0.13533009065976068, 0.1904072005662226, 0.12820520483317877, 0.30937228952684714, 0.08479632647527803, 0.22550990084005942, 0.16093559893629245, 0.08484071360961085, 0.1197635364388266, 0.10977927340014328, 0.14514231333328834, 0.14020959576291425, 0.13563577506330707, 0.08127816727445011, 0.16652198868893808, 0.14196850299354524, 0.09624877403820715, 0.11158305040049939, 0.17635301116012758, 0.1289185782473895, 0.10960075959202745, 0.10387533254200414, 0.10951014671234355, 0.24827650177382657, 0.12548759219146546, 0.11168021333193588, 0.203595909800741, 0.10208352183502528, 0.1434182631032121, 0.1133853794946786, 0.18633121444332987, 0.1280965582437573, 0.15247693105090052, 0.12474172132750674, 0.16593200905669123, 0.14157378385143896, 0.2626732550561428, 0.10372725540711995, 0.11729150860299987, 0.4144918101449167, 0.09330757863579259, 0.23944409023369514, 0.197815592550943, 0.09994232140841985, 0.15345430602469753, 0.1372656118004553, 0.0776272833407406, 0.2173816007111342, 0.19612958624718652, 0.23190610681570348, 0.17487608557266576, 0.2444450815598811, 0.20356538885783768, 0.2025961497377965, 0.2246320560093849, 0.12694869040241166, 0.11956924888034982, 0.1704140371012111, 0.1298852279902466, 0.16841693781316283, 0.1851986300560736, 0.1501900360228554, 0.13984291543883665, 0.2648934085042246, 0.22872914019371235, 0.21424126841368216, 0.13463561663464194, 0.09622786749875355, 0.12744184418190874, 0.13636343601730563, 0.10852381617071168, 0.11044717949604797, 0.16510544615166803, 0.16264178399597445, 0.1372427977020702, 0.15108730884328966, 0.12810986519100206, 0.19484946864747232, 0.11269501170083401, 0.10202224246196209, 0.13800903884393556, 0.0783083125227882, 0.1457571908230743, 0.1362183389644469, 0.1226313942442498, 0.15394152262278143, 0.1219764809995409, 0.13526313457517855, 0.12740563886660722, 0.19882305945840575, 0.19218833966841622, 0.07860036822216165, 0.14347339079024332, 0.1259517495430285, 0.16528541552684, 0.11461285153223623, 0.12453938218494578, 0.21990054377144386, 0.10099177759501243, 0.2110117481600854, 0.16489135522034862, 0.1582211655594649, 0.12482700223523764, 0.12660657851806573, 0.09520401397059042, 0.20878575712202058, 0.19771440765790402, 0.10259758981485521, 0.15420447464191145, 0.08501204151299693, 0.12091107486236481, 0.15935119121305405, 0.12641154019342316, 0.17343084538175216, 0.1691115956993834, 0.16048414332251396, 0.14816917268739593, 0.14979220656377656, 0.12866765380867068, 0.10891697249345242, 0.1947291009128094, 0.19297181778857786, 0.1219837281913046, 0.14444215493577142, 0.15348668090037762, 0.1346332264403182, 0.17061885836864674, 0.06539253743305322, 0.17685280692192817, 0.18622837480037444, 0.10125227047190552, 0.2210337716725565, 0.1815380321274842, 0.12514577908140997], [0.011600908699385341, 0.01783981862958641, 0.03305200930504549, 0.019337476471499093, 0.057839209273938215, 0.08552101500813039, 0.028753083935307882, 0.10186202283347807, 0.04161218767084422, 0.09611067902897635, 0.11192602796419976, 0.04471891169105807, 0.1537877074893444, 0.07701249778150551, 0.04968372068458027, 0.01437233231451002, 0.058118850518498695, 0.06378047010530868, 0.0341857313328693, 0.034095934336824764, 0.029063814943055474, 0.04701663154147325, 0.044421098840933655, 0.039400518646523844, 0.03884956736357943, 0.0352273695921946, 0.06363081099886088, 0.04131329846718619, 0.05161245428626576, 0.02310978917164668, 0.04328068886553088, 0.02446710545149061, 0.02833086223671994, 0.022442440404706908, 0.0502887616054185, 0.06443279780327313, 0.041793892235164685, 0.03382697618836838, 0.047634167356356505, 0.03161090024326357, 0.06629311975332038, 0.040295232733291005, 0.04574556527058444, 0.03971862133532282, 0.01885428566545729, 0.02507344297614069, 0.03367277418052958, 0.03374997669109895, 0.03452415450385982, 0.05170654520512589, 0.08665536139761248, 0.11909124831999503, 0.024560807580729167, 0.06044580428410442, 0.058540218029051065, 0.0325817424022863, 0.014554518556612876, 0.031391151752623345, 0.015893982114991354, 0.08395831055578687, 0.030980323696689262, 0.007961660683635742, 0.07316787787262471, 0.06455531058412406, 0.029747550330695607, 0.042759389015695745, 0.02331000050499795, 0.04246118929116957, 0.04609193660378937, 0.006824385923063082, 0.04040723095738119, 0.048467644204896305, 0.021705643852211295, 0.05056752184886606, 0.05336629384527764, 0.030746777962532737, 0.022262595518822634, 0.0447229259917813, 0.031817969978756966, 0.04273204733767817, 0.038613018564759724, 0.03338395520263622, 0.05020336961493858, 0.03454197370897859, 0.029280504827658017, 0.04077491868707923, 0.02577178383005723, 0.014878752821635817, 0.021530554457116994, 0.03153209086327303, 0.02876295880865186, 0.02853516639480668, 0.13193247539381828, 0.044097832719525026, 0.050624786921206026, 0.033826746361991095, 0.03382271673950938, 0.04010335835177572, 0.04529564183265452, 0.035910559142188686, 0.04185607176153891, 0.10060207632881019, 0.03789452002233556, 0.05894258655908127, 0.054103933094489964, 0.09054115087154413, 0.022871394100929462, 0.014113745081328578, 0.041626701206569715, 0.004822062872981112, 0.06584181735712676, 0.004775962574527629, 0.07847083807592431, 0.006211262295818738, 0.039819392540882674, 0.04197555849508893, 0.06207687059237112, 0.04196824235541206, 0.030882544064473723, 0.031739622166740804, 0.020454664406697118, 0.03235031107080079, 0.10798612970017618, 0.06323779640238612, 0.0550809863113588, 0.019543224705323096, 0.04456879293185569, 0.03551332723169077, 0.13309274619865802, 0.026153174957500833, 0.025094981538131837, 0.04094012937838993, 0.03022983715298676, 0.016932121267722502, 0.08955953943152582, 0.01864091485678669, 0.0667112045771172, 0.036791851368522456, 0.01021692872933683, 0.03360702468442821, 0.046540638131480065, 0.0660897387311824, 0.017276943188100573, 0.025164875569903565, 0.02547227792562016, 0.03912340549211349, 0.035478221252560616, 0.057643588722473195, 0.040509921213191365, 0.025869496429579395, 0.033694883478024316, 0.03397620628557859, 0.01024711259355348, 0.01635235358750628, 0.021873436259826826, 0.05421589684462356, 0.06309659490662237, 0.05559180224795015, 0.03124815761111677, 0.04719024238687369, 0.026645323246597286, 0.07240345235913992, 0.014233989284313736, 0.020545336658195145, 0.02439180092375365, 0.04611243328620349, 0.06453666400404708, 0.08303322874370121, 0.03547153713542127, 0.03463507254397677, 0.10918506496255437, 0.001733723406833897, 0.033189905131415974, 0.08369895914990096, 0.044043892468776435, 0.04881595757098929, 0.03775964641282636, 0.04464916704643158, 0.0325775710535386, 0.01965142121808904, 0.03526555524478036, 0.051292938165246486, 0.0645946721816736, 0.06250315255695774, 0.036618596754006805, 0.080570524197913, 0.059237905793012156, 0.04303353740983913, 0.11595355902588177, 0.06268558873524589, 0.01900454423570585, 0.038338479465774955, 0.039601478830821095, 0.03934891113350469, 0.020970228173199202, 0.0044370586833646225, 0.030343231572318944, 0.03213124439841317, 0.0370454456236574, 0.018969599135039796, 0.042602601461112506, 0.023050997669117588, 0.06247004989774958, 0.04809185892583863, 0.050710381924985885, 0.1170241285956675, 0.04883379209786654, 0.05052246055715988, 0.02306788033174892, 0.027974388119013562, 0.03709294307496279, 0.037145328167225086, 0.01539039326035568, 0.01517475100098959, 0.0924449329895358, 0.01183603736271541, 0.021671242673971483, 0.0689144274820724, 0.04555164926475094, 0.018787591965989243, 0.030936191286591273, 0.026242874277335022, 0.03192227284964775, 0.012630408295550415, 0.035858070628056606, 0.05303125678291244, 0.029348163797910658, 0.04890395042997214, 0.0331594301537881, 0.07165884554025627, 0.03985028886686891, 0.035720059888497475, 0.036145411056256106, 0.03462332458565793, 0.019028999677468694, 0.05367768943429955, 0.009992526254556593, 0.07966212778081817, 0.05425041293605201, 0.0089149153791368, 0.05719143213824399, 0.015708970923667714, 0.03935388687457289, 0.0483061911748542, 0.06073261994207579, 0.0598411770507453, 0.03701481359800504, 0.02578727221266637, 0.01069089487916039, 0.0711596779705536, 0.011234541513746785, 0.03996357411867188, 0.07602713251065824, 0.05070275551969967, 0.0265947844262325, 0.04525074141941244, 0.062259440836046016, 0.03897589526229328, 0.022069619885916193, 0.015730587052061193, 0.029705072670514067, 0.06506811451887892, 0.034039171052075205, 0.021075747208669785, 0.05484777382544933, 0.02520728428217192, 0.02506814547814429, 0.03277006213583293, 0.0445797479891729, 0.07472718089458442, 0.03526023859458585, 0.04183479366944202, 0.10406336116213953, 0.031306987418042075, 0.09709291866109257, 0.07653601407524079, 0.04165665524440908, 0.03506562161830164, 0.039325058985982216, 0.07195329143395347, 0.019018538746862643, 0.07509091178015356, 0.027269043306249286, 0.01502289992546843, 0.00860791617719036, 0.07139092927137691, 0.03960274287589616, 0.005975917212650061, 0.07774825628486373, 0.02613254804013958, 0.01834110826283934, 0.04815566638905195, 0.04941884961519991, 0.05796423865362041, 0.021704839459890803, 0.028976775863538348, 0.0684874177339577, 0.010779689257634024, 0.026260992256744255, 0.040924106649453604, 0.07534807217457602, 0.05622205129193683, 0.05293677132877131, 0.00110882381118098, 0.030945577778883522, 0.03391007374551508, 0.04365426781136663, 0.042386070539754246, 0.06442654652581101, 0.04757136729876361, 0.06794021645140264, 0.058941437427194855, 0.028936969934992736, 0.06002784203437548, 0.01792422236664401, 0.06408837999427511, 0.11710610000356553, 0.06014329914544379, 0.023048234006930745, 0.00511398115533314, 0.018071104404366305, 0.03617414318385624, 0.04336180991583294, 0.023202192781853582, 0.02783778698123511, 0.04795378306880594, 0.01802514678978872, 0.02335571488665958, 0.057607777942452705, 0.04778860685145182, 0.03808258694686717, 0.006492853234146512, 0.028921433671888326, 0.016328242885309364, 0.016268865325518193, 0.026724718683849902, 0.049598707907622865, 0.04839400400317485, 0.030398213702644554, 0.03829585816410761, 0.04606210514001789, 0.051867638173843586, 0.04902255233196963, 0.04546135431155563, 0.00590462698563633, 0.026853482742162964, 0.029012598134877703, 0.035496660988898046, 0.01861611659067773, 0.14684517357137897, 0.030569727382352276, 0.042680313420151515, 0.14779702249553897, 0.12968881836821958, 0.08204358104135721, 0.16046699827476857, 0.15703317769352468, 0.17210718334442185, 0.16912420550661703, 0.21738802052793965, 0.18366349710812493, 0.2611704663403573, 0.30299571072382314, 0.12793627732823934, 0.3502097094972288, 0.18785735351904748, 0.09685474958631302, 0.08915785655018785, 0.16096366839783807, 0.17228649388397896, 0.08016905582119381, 0.12011406762946038, 0.09444349550551946, 0.08932209814027434, 0.09169994312669001, 0.12377339385209546, 0.14254513737415114, 0.0744535266271522, 0.24816014833988684, 0.25508967408489797, 0.2512144029981667, 0.1462652756562156, 0.11076982508623794, 0.16345478714473788, 0.10353224772599437, 0.11337248623491296, 0.1593774220635814, 0.1447014450546234, 0.15249082788584695, 0.15815002663481623, 0.2331058005051267, 0.14742429007685956, 0.1436869761035327, 0.14379404455183015, 0.24286476474615837, 0.18124541718392603, 0.10579944663350621, 0.10170461474767617, 0.12000158293953828, 0.1433721446101704, 0.19254276258570535, 0.15414493428843637, 0.2335954532628098, 0.18864377341683836, 0.07845248260925855, 0.22950679604564944, 0.1627311711349795, 0.09968277081967362, 0.13428137757845465, 0.1226381434788627, 0.21264765231359392, 0.1458840090180597, 0.06933671046769427, 0.10737844577599918, 0.14378656753368918, 0.10253546008419606, 0.18421290472390192, 0.11742953466431749, 0.11548627603558764, 0.15747334117129927, 0.16033167650382366, 0.08196796816323074, 0.11317700357927431, 0.21717892448988654, 0.07361200968584708, 0.18442436031276183, 0.1149797233782949, 0.14893599605608374, 0.1054161575232302, 0.09911981876939537, 0.19294072994061057, 0.1615177338281947, 0.10818163533845257, 0.18475802224730292, 0.09774561791170029, 0.1566116301523101, 0.24652983662822556, 0.1370191153499388, 0.13322858890939143, 0.13719801220201677, 0.13278585137619128, 0.0721793026933747, 0.10807966903573084, 0.08134274848646696, 0.2035391580073103, 0.23389237362050244, 0.11317587743002562, 0.18935609729059283, 0.13174211786639306, 0.1465537230814657, 0.16735593668155133, 0.13348243980398103, 0.12306247958012166, 0.12832636929928296, 0.11841191985313931, 0.1957740754850449, 0.21393953702382504, 0.26340257076005785, 0.11300991980298875, 0.11650560964499751, 0.1100099194915064, 0.28053431921908933, 0.252828213175939, 0.06535330607045083, 0.13286302707368328, 0.08946000162752406, 0.07933940558183579, 0.1712899820338334, 0.2250180264273959, 0.160553305740318, 0.14601645029840932, 0.16787281620406336, 0.11423425854093607, 0.07770668835409227, 0.23026935996547823, 0.10714437527161454, 0.19980259480014925, 0.10250094782320723, 0.2075063749667137, 0.17195788812973808, 0.2053108589062768, 0.12430797766653762, 0.11557013201977938, 0.08161043492896904, 0.12288567414807698, 0.203367002728966, 0.24057235388505846, 0.1480103626606926, 0.18375639292982318, 0.1430867002495835, 0.06997947355792408, 0.11180806574561905, 0.1773329908328672, 0.2509573958213291, 0.12916890513752738, 0.09330960110791268, 0.06071204665086924, 0.1326459177559422, 0.14029743540431225, 0.15554442370851196, 0.1386918989761222, 0.16091172763657186, 0.15261508734716525, 0.13381139795866706, 0.21272277489544886, 0.10300559292156851, 0.12673795493620058, 0.09377900616175706, 0.1246377861788196, 0.13964901858520123, 0.09859073546624954, 0.0632274657067272, 0.16264256540565722, 0.13721212354158202, 0.12474429538293232, 0.09108783121431067, 0.08156057026597761, 0.16725596220743272, 0.17679171907084604, 0.2206662180082452, 0.12171690742815695, 0.1746396708392328, 0.1571643319461615, 0.0844902590277695, 0.14893391229692968, 0.2636984952034489, 0.1273071122986655, 0.12885770490092616], [0.039405318187369455, 0.037937026410814256, 0.058440910051426584, 0.040036455893348304, 0.039763682627029, 0.08490828256453238, 0.06333346929280989, 0.046358006600771225, 0.013149157072597695, 0.0266141664507168, 0.08756191154280979, 0.05151104722772876, 0.016581421537745385, 0.004480717076559461, 0.0019729229895728492, 0.029894432368417902, 0.011784555296593857, 0.0030418136297920423, 0.015628331551148046, 0.028942834338053103, 0.05622114347774656, 0.05749668370211317, 0.04333259132240088, 0.018896803545254855, 0.005800793343599165, 0.032450036566344, 0.027790253140753316, 0.009649108190299764, 0.039367917774906086, 0.02702144943478127, 0.02492433928343798, 0.10644090737426475, 0.03076150983331665, 0.02885777368060043, 0.05761319418407737, 0.08714603305223488, 0.040965142149117686, 0.03985855112513227, 0.060133960533646814, 0.020474781875588724, 0.07044481834576977, 0.023811602319080024, 0.033007591527195713, 0.039151704780036406, 0.021687945305940606, 0.053614004545154116, 0.030311850695720607, 0.1259896555735219, 0.004291212779559917, 0.05389327423707132, 0.03846996313621921, 0.041921591431263, 0.008089339769926042, 0.053535966998747284, 0.04599023843184114, 0.046163136815471996, 0.009645803478516398, 0.007694438203132802, 0.13522291495915384, 0.1176693584890135, 0.07552120804546342, 0.07334514295742398, 0.06497105117887259, 0.0722836591904202, 0.06820783394599153, 0.05456275081322078, 0.039172301053880684, 0.026222643810474587, 0.029687512020069747, 0.03800442299595283, 0.042191212245773886, 0.06981396792276252, 0.05679453347599315, 0.022862773696561495, 0.021367281968254718, 0.017068463850826505, 0.057489903823983286, 0.030088968905470068, 0.051728371050088644, 0.04274178431519578, 0.054843089197792357, 0.04314792965869269, 0.0731348365004505, 0.06955403429005416, 0.059823725567830194, 0.003059382659323033, 0.025350037105982343, 0.03896473719167613, 0.04852900018675193, 0.0480121206642399, 0.01844567734928381, 0.020981924420583154, 0.05291646999877788, 0.005693683239270843, 0.013576880240091875, 0.038471943473503474, 0.04646222137155072, 0.023985686223773707, 0.042083634349006804, 0.02871746084682884, 0.03038468075946214, 0.004550695378002861, 0.16665861280935426, 0.030034013588221806, 0.011571294613062375, 0.03129928057352382, 0.03854703924228107, 0.05746395259554829, 0.04299618679309084, 0.025441486936723514, 0.03985035015390285, 0.011343478258969563, 0.01380028392774083, 0.08583441391707429, 0.01274141539338856, 0.08782776703517284, 0.011945390668247017, 0.018413794685095068, 0.02136498561970169, 0.03276456545497621, 0.07093058703767677, 0.02012057154769859, 0.027805944536662394, 0.023206398604557883, 0.03847355608858409, 0.06373290753652973, 0.015300236202986732, 0.057327041192160505, 0.05277779276272463, 0.10069104211945688, 0.03250152916617451, 0.03128197273209451, 0.044108228532657515, 0.045699611486446474, 0.09564942515064633, 0.050890971831376516, 0.05965024495737688, 0.0064270927255312285, 0.015685960515252045, 0.039278867714587724, 0.02734657331940628, 0.05258178150641823, 0.025848118746052348, 0.018329459895950653, 0.097195727660531, 0.027840797706777533, 0.08234955655831484, 0.05285160533422905, 0.032802670668329925, 0.053174465429037816, 0.03879277726575252, 0.015833371153642094, 0.017006010448019353, 0.008927220666420557, 0.02924948209716428, 0.026504248155341036, 0.030833403354570754, 0.025482269627372586, 0.027523777117171598, 0.0185229200794692, 0.04568794396735969, 0.033101808850563345, 0.022263361606746915, 0.04906536132517842, 0.02027838949053999, 0.036525130196804964, 0.03247573498576399, 0.03210917149009484, 0.02008292981753907, 0.03214223392968697, 0.04114952419073351, 0.04058677515375518, 0.06351351527677429, 0.05025182850658894, 0.008970081370564239, 0.0694930996565569, 0.028645672662664327, 0.03945128346282629, 0.036123405180631146, 0.02859846057911073, 0.05036537422828617, 0.045915188628339, 0.12929221464981958, 0.031467373670649626, 0.013030643270711505, 0.02934278969112183, 0.05570609490537355, 0.06947567881715876, 0.08787347950161466, 0.051405204520110166, 0.04146709444842512, 0.04882266467076637, 0.06786235893565802, 0.022450836728357022, 0.015310173320974556, 0.06563197821378708, 0.011012037979408858, 0.0605068308481526, 0.04811814340252069, 0.034269767347723246, 0.06586614064872265, 0.04574908161415689, 0.046153097233224305, 0.09662716018576777, 0.04115350401750015, 0.022972674754958962, 0.021795638115896333, 0.04206478475562988, 0.04707468568437523, 0.04227974136630374, 0.07139937922118172, 0.04157568358125226, 0.09282741770749131, 0.03966568849019466, 0.003878871460572907, 0.02152013566134678, 0.03570512117397401, 0.013290015744015336, 0.022141714505250418, 0.04745924650060554, 0.043520738686164545, 0.04610848793339345, 0.03071582992561162, 0.055890565047100674, 0.13865500418168886, 0.03083938075559995, 0.061923147389485, 0.035543384691399914, 0.02091395135428156, 0.05082396978151895, 0.02693955846611531, 0.07525845520919369, 0.03437197879858075, 0.0256015035519076, 0.05576486917092435, 0.0658976651668068, 0.06329317306799274, 0.03860633444762038, 0.027949511328892365, 0.07478889693776447, 0.016559298833711975, 0.050320335919217724, 0.06516618143406606, 0.01777369375040214, 0.046669229820010164, 0.022512610228131377, 0.08499331066324826, 0.005442164603605746, 0.06717494824120114, 0.047800082848557544, 0.055917883742480516, 0.022327734059804392, 0.05168295735793729, 0.018876234084487926, 0.013513426134933629, 0.04683365527119848, 0.0796470818139853, 0.03122448357903669, 0.026701172971497142, 0.03301767324427924, 0.03396436256626922, 0.0541688896895897, 0.024154633508935094, 0.016997259808704257, 0.03801122202628082, 0.03154908652387319, 0.04847122949638194, 0.015593837484747413, 0.09749904485239137, 0.01595987525257853, 0.043021191902939356, 0.03438921960731668, 0.0204521018425904, 0.03166683615305491, 0.11476976932176661, 0.055219383925319686, 0.07168368211076145, 0.0376948123917945, 0.11893312777242354, 0.03364669654758708, 0.06112539322085439, 0.0463856891879151, 0.027533489196831663, 0.037775887476821104, 0.03595553233378357, 0.04045947815381712, 0.027785543615238804, 0.032718849158094775, 0.05025901058087907, 0.02246829587215137, 0.10809373441002063, 0.08440478659805753, 0.006067981350145513, 0.036919336060001966, 0.10466754406450257, 0.019649791366030133, 0.02259540326532818, 0.03799674296451192, 0.06487709815583884, 0.05034245670803132, 0.038752381449505206, 0.023037669654454918, 0.01146513972461464, 0.0018995762952873786, 0.044762578702742056, 0.09768668276768538, 0.023392747576919296, 0.03994737135907335, 0.04376516286884585, 0.06863043102766238, 0.11584993031236435, 0.0633038676554157, 0.035684409986941085, 0.07728839668655589, 0.05659531231128401, 0.04018206239467667, 0.055560423286571625, 0.030505088713741114, 0.017407070882918856, 0.03791042783808324, 0.06421761136622199, 0.04142514730413114, 0.0506577670063463, 0.04570970469484887, 0.061151172079506426, 0.046761489788731264, 0.031117282980572314, 0.07700770207109951, 0.02300432567755061, 0.028811329600190925, 0.025278505561272466, 0.057568424005782416, 0.01906521265364943, 0.015596333016160757, 0.03654341671555754, 0.0384774593065583, 0.04108215824911191, 0.036280989466655644, 0.05174026073467347, 0.04059589926093336, 0.018117121390758023, 0.029498738379427986, 0.014978071332969254, 0.017511272247159676, 0.028948336764569246, 0.02087330655945886, 0.07102712943789459, 0.07962978354865506, 0.054897056261618296, 0.018118339470557628, 0.07476294953976909, 0.025501327979708874, 0.14955474995076656, 0.10368269207256456, 0.18550788442934715, 0.13425856348006956, 0.09409579117932627, 0.15468591493704628, 0.26185118142635594, 0.136396040719363, 0.12524111106270744, 0.16128825985135573, 0.1750876177703181, 0.12666907597092852, 0.17461287308364146, 0.08530562938821894, 0.11687523174670436, 0.18830171515864713, 0.17783267934235836, 0.07449543929748959, 0.097218633689467, 0.16733578856914275, 0.1425243304261277, 0.16559218777523887, 0.10745603516097031, 0.06960142448905014, 0.14445842664328315, 0.10440076926663037, 0.09292992027176004, 0.10824974821580034, 0.1762251510855652, 0.05463669745011195, 0.14271392186562862, 0.19884584291327387, 0.10043280920194042, 0.1428766542625043, 0.1604299196192334, 0.25900329553311874, 0.2176452268876376, 0.11599600795776614, 0.14277798213785695, 0.09757570727097412, 0.12171039568080057, 0.16850719829240154, 0.07831946676296574, 0.11651404427304385, 0.17806753125642577, 0.1410167919652116, 0.14441399354367487, 0.21640227987400948, 0.2692234906698427, 0.09793607503055565, 0.12922973251871525, 0.18052993702792353, 0.12634305959387174, 0.11468424326589993, 0.20184484731045463, 0.205682763949998, 0.14390721106000487, 0.10398201028546018, 0.17003796453918182, 0.2716280568030573, 0.2365709847259906, 0.14281619460352007, 0.19339135817943082, 0.16187149790986893, 0.15873429125114796, 0.12035041341498015, 0.13179389008831593, 0.1132660766222304, 0.141500806315772, 0.15134629252697193, 0.17099105452577915, 0.18280783818373758, 0.17001395534363486, 0.12409717325241336, 0.14715064347030657, 0.21572225426714267, 0.12151162650796676, 0.20657173237733303, 0.12546206614182842, 0.21136632429495936, 0.22267134589773996, 0.24813189501723937, 0.10481647155698269, 0.1167132884203907, 0.12756600405179686, 0.29015567874716175, 0.09342742543066702, 0.13415808338792096, 0.08850599999629682, 0.1328690638465266, 0.15210637432192603, 0.10856379063860064, 0.22534698458208194, 0.08685299676031837, 0.17847712782602157, 0.17121338856316384, 0.09212291559144374, 0.14203930483950725, 0.23717953432952207, 0.15025526074872864, 0.18151690342253257, 0.16421146750930818, 0.28802488179456803, 0.14978068460139538, 0.15281800871654866, 0.12834966603306033, 0.1439107657079735, 0.17210548262922995, 0.12213368990248251, 0.16342379122732148, 0.12025002525338244, 0.20097559798629056, 0.13805808379284798, 0.17921540675865066, 0.2370355557650328, 0.2228223877928911, 0.16293343366874805, 0.2860855455360105, 0.26478787223177574, 0.146338866062222, 0.10223712246384352, 0.10834237590672509, 0.18428582097253493, 0.1411279666447832, 0.09062935823514577, 0.14640799783650907, 0.07954663236535366, 0.19076263471957178, 0.09888092957196698, 0.2522936523441346, 0.14152512194648867, 0.1463801735230992, 0.14406084233234007, 0.16976364377525546, 0.14011742006386482, 0.20729358638486556, 0.14307842650000127, 0.1765843697132603, 0.13248042744253913, 0.13864113799025937, 0.10545512075505911, 0.11578104368621304, 0.11950652926198899, 0.09778694069433598, 0.2142220396067827, 0.09349755311925566, 0.17664317462232806, 0.15400572079083613, 0.16116942429254133, 0.17995422195282676, 0.15300366246411878, 0.16760620228465528, 0.10124705341314116, 0.1462295146719102, 0.13467670959090033, 0.145112328651932, 0.10549810594849049, 0.08918135246682553, 0.13982949357840324, 0.14656647078452573, 0.12147273988493028, 0.1426115418754278, 0.09884185908782868, 0.13990185824373078, 0.0740546323058586, 0.07074119478103615, 0.11155436040773509, 0.14167970316784997, 0.24896866221341396, 0.08327574153701145, 0.15420332551002502, 0.10416888211282993, 0.14597520412456605, 0.22664147399125562, 0.12886570285885565, 0.14418951446010222], [0.0642409693870333, 0.09654744107636715, 0.038971559204641855, 0.02725569805460832, 0.013757491213900429, 0.04139039372544616, 0.012095718186408764, 0.07916336623771537, 0.011446028703733558, 0.016675357323800846, 0.015789914816137285, 0.05931224313474471, 0.013395992517020675, 0.0556959365794976, 0.02745377966353009, 0.008494012309388529, 0.0701186640728866, 0.019050917452982357, 0.06210067294417851, 0.012075517405455392, 0.02184235990317839, 0.012857766912108468, 0.03787868498494068, 0.06399312462177008, 0.09942571767756056, 0.01435998872283005, 0.022017945340203664, 0.029298276152281515, 0.023314349969188054, 0.04986842448312429, 0.0385490310708842, 0.0927130177977585, 0.05258939642038557, 0.02565512779138742, 0.02272244745625123, 0.01246858562808484, 0.06278116586467912, 0.028499506917151234, 0.03614343071897184, 0.04291854378196501, 0.009337134204895027, 0.06343329437978326, 0.010971293593156002, 0.07702074854845002, 0.07883764863494905, 0.0822358308059554, 0.05325852825696911, 0.02330237984537117, 0.09312976962856709, 0.07216692271251833, 0.045151261072005, 0.002848171260989001, 0.0212825890330057, 0.0049865285437854555, 0.022819451424443436, 0.0764949057972239, 0.04531220082313784, 0.05286550599961512, 0.05011815382468124, 0.04960795075842931, 0.013088555687347488, 0.056796900687679175, 0.03893934903786548, 0.03192076940209635, 0.08736048404487871, 0.06320565901396256, 0.08574912534846414, 0.02007948433709962, 0.03344452594436946, 0.05920928857860066, 0.015914704793343143, 0.07079213962800081, 0.0287074844668349, 0.038751140387067874, 0.017153888400043213, 0.09011686839643987, 0.046044228478304805, 0.03866521596548058, 0.010832650831059344, 0.023171683330269113, 0.027737234110733675, 0.055163474828605695, 0.07565640724234043, 0.04283293345642667, 0.06765562244841168, 0.021892329903259393, 0.01262406317231756, 0.038664832921518434, 0.06033252669318069, 0.04862209519131049, 0.03621330942898508, 0.032096935150724266, 0.07244095236303345, 0.05807712170926314, 0.05532916049442946, 0.022064850988587546, 0.04911909856262708, 0.018117270777903257, 0.06450990455285197, 0.08864078550569474, 0.012916943373819514, 0.01888769092939554, 0.013250074792473067, 0.046256212667832454, 0.014825251156223879, 0.0384858364780103, 0.07026047460855016, 0.07795611126047951, 0.04626893738825475, 0.04750523092826048, 0.029341688439730677, 0.03441863355316943, 0.04410485391535106, 0.04966192931357411, 0.06695748652301489, 0.0375280273897994, 0.028783689147882888, 0.022708617653998158, 0.0549104972742498, 0.0758919486355397, 0.10199432621800131, 0.014444213386835351, 0.023012373431195176, 0.01869265068953316, 0.047739052454069744, 0.02768717601054138, 0.05907518105701574, 0.02147938361421468, 0.08871289736200726, 0.034525357261900945, 0.0402245189874403, 0.04632029592269852, 0.02327126518432652, 0.054942990893558155, 0.0292422732097968, 0.06149160240085856, 0.03140836574828192, 0.08132221733009623, 0.050244382131964936, 0.0721756867583721, 0.02162554552928815, 0.05375111513140221, 0.049062450191066156, 0.038967537243039384, 0.028578410142912503, 0.03931170990390163, 0.03353110537113201, 0.03198528358141982, 0.028918445928983634, 0.04480642957552787, 0.0530743990243683, 0.032676235517306675, 0.020471474290975643, 0.07232395541523734, 0.04003567448366554, 0.029325252023315238, 0.016569533768380364, 0.044118478789084384, 0.04701301560647065, 0.01857507917579384, 0.01640537261752592, 0.03144237430646055, 0.044128219597041614, 0.08267541971778677, 0.07472527333565297, 0.06568535922035094, 0.028616007823016376, 0.010499925439005658, 0.02087476021129518, 0.03956723853104538, 0.014644491752879995, 0.027195349478373126, 0.048257912313866044, 0.03398423488702505, 0.07684972708023365, 0.04682473800775986, 0.05239366095573191, 0.029120036220598607, 0.046466316111506, 0.05050417786884693, 0.0452139921816847, 0.11575749414342067, 0.02017418238063974, 0.08109451301636235, 0.029133486809329163, 0.009954525420682566, 0.05515272661502804, 0.024864540375288458, 0.060542266245090195, 0.02506013985933556, 0.07121081433949933, 0.03928077527351918, 0.059417465311144634, 0.02626326179221994, 0.005838908133051929, 0.0277264284405617, 0.04257376591164259, 0.004952742629909828, 0.02439146767550659, 0.035243602995310104, 0.06265376544287128, 0.029051886954074426, 0.02582823876441727, 0.05760465996460088, 0.029388285737725037, 0.05738961525381573, 0.04577486430324855, 0.007547866909824793, 0.03768170845784968, 0.042778433961493355, 0.018602962861017838, 0.019721374621674902, 0.03971590555363125, 0.04317609105078925, 0.021295311838208188, 0.034813685943522764, 0.017259089509025216, 0.019233307665995052, 0.02921878495403836, 0.054225817683242986, 0.036095810693598566, 0.05634248797451297, 0.028841482820890607, 0.045916253490553754, 0.039690172660254666, 0.031189594019745148, 0.03396016823488378, 0.05270884484953938, 0.00919947107773154, 0.03314541840565301, 0.027742071955975507, 0.04273022787885801, 0.04826312171175115, 0.08079078213702287, 0.04316782496208626, 0.03529720999781163, 0.0573068700971142, 0.07712479094944655, 0.027914066355855718, 0.026989719988177382, 0.02671764194664936, 0.07987266406416893, 0.03822976009800069, 0.01598437474439702, 0.026056000534745476, 0.0535477647527812, 0.02376668275363984, 0.0097202384964593, 0.022992110405597958, 0.07647204573356337, 0.029580299930286505, 0.042210893044548656, 0.028773603600359736, 0.026563709984803875, 0.04665831689752879, 0.06527144191486221, 0.05021110327253419, 0.018757699215183818, 0.049144643764462204, 0.040920314514228416, 0.06229084278006227, 0.026264654157022317, 0.08111591751296675, 0.022644367775008566, 0.057752445986073826, 0.0946913249490242, 0.020682899236318567, 0.08325922468136396, 0.06367645834782912, 0.019392330282097383, 0.03834939238825633, 0.008025425533208275, 0.03287101337205499, 0.03552363111427234, 0.031189111384352854, 0.02481945227050493, 0.05128610083052228, 0.06188238002059441, 0.02364451854279445, 0.018411672621544813, 0.04158789502276529, 0.037556008751233744, 0.020062130530394857, 0.03358319551954347, 0.06847529822299558, 0.016482167186275605, 0.03387330535558924, 0.0689791082855194, 0.023486210303681514, 0.028439504995701775, 0.07400714251543246, 0.04501714205910121, 0.05046270952950563, 0.01878655200163203, 0.039567587101050926, 0.0407342700618169, 0.05593060463246319, 0.01775369119469918, 0.01733656015036808, 0.019249950926150047, 0.008863202529028058, 0.10127238794079713, 0.017411133064137354, 0.049632105510681875, 0.03331475831087559, 0.033230572908876405, 0.08587634190917016, 0.052215024573548194, 0.04871045960293663, 0.01933727920385859, 0.031116633721056487, 0.06382533604459417, 0.058880824550625786, 0.003962799504910026, 0.05030548147436592, 0.020386245094179627, 0.029462075326591734, 0.010626412300963797, 0.07227415203927987, 0.02185172532805272, 0.029970889858480905, 0.03639008804795243, 0.052291552926744186, 0.0339883066443426, 0.03199510865904872, 0.057906954429082336, 0.028268598440674045, 0.05380359215421542, 0.03282830013983673, 0.09277937633375968, 0.10764705918488965, 0.028848067346599796, 0.020593328236211694, 0.11262838503405934, 0.05480559685477807, 0.009326978751848783, 0.01732700128829287, 0.05292401596483204, 0.05535722995597509, 0.0213402179971097, 0.0554654743492363, 0.08203238849678347, 0.029407836301552675, 0.040048334086614276, 0.0485966457504659, 0.0418815020501854, 0.03232690708471402, 0.016738209092328628, 0.0348132454429663, 0.048655634520635496, 0.07459793420087907, 0.06057245010930685, 0.1474185750609444, 0.1726907278381048, 0.1502921402214035, 0.13868376312236633, 0.1634549710058397, 0.3548192298941074, 0.08431982744725482, 0.17080206063485917, 0.07173822757097022, 0.11209016996285609, 0.13028180106512963, 0.18887692461571387, 0.23647776714736418, 0.09302437891282382, 0.1287787978447253, 0.14752484677780062, 0.14283271145916757, 0.14809884581594698, 0.18268883408557984, 0.10384170894300747, 0.109896699357177, 0.06788135025530093, 0.07725177768377528, 0.1222051352623009, 0.21241231010325495, 0.08207560351659214, 0.10246673433650887, 0.11568741242010748, 0.1891901320026767, 0.12908095824382, 0.1219498134788967, 0.13546052478974865, 0.1552436882329564, 0.1313960759509956, 0.13039600945288135, 0.06865391928342081, 0.1074540816367634, 0.07900109349359428, 0.12970001857367255, 0.13225902803242207, 0.16889359771965012, 0.11724313781146081, 0.16062619134543404, 0.1467230131909732, 0.15716892847370717, 0.34561848327998196, 0.17702177527450746, 0.11800564810513489, 0.12477911407909087, 0.09651620767169422, 0.1902362097415232, 0.18857191436954085, 0.0879024452860317, 0.10146852177117141, 0.0900842636943825, 0.12312671605257258, 0.12790109090987714, 0.17974872652801777, 0.20172496987206323, 0.10733425016364745, 0.12298396322876216, 0.10017405534463544, 0.1316987266463618, 0.10880777432072548, 0.1316693854788619, 0.14711137380330794, 0.2841007036547507, 0.10928407416588838, 0.21907528321589195, 0.1219714324801199, 0.15419191079995326, 0.13515324692331976, 0.08957267017854799, 0.32461553932197634, 0.1506209298367462, 0.175825008040955, 0.15409408137202263, 0.08600787154488987, 0.1609489441879334, 0.17419501808622193, 0.18851955992079553, 0.08010706398636103, 0.16061819338750455, 0.09741703514009716, 0.12532466061172948, 0.07360572010398873, 0.270961866744103, 0.15040285524822053, 0.31528985908915924, 0.13792613280876992, 0.0828965433362511, 0.1652144144980177, 0.15804265175134907, 0.21564517050020157, 0.13690506017977191, 0.11181011886125612, 0.09855356488016345, 0.17345208133901321, 0.13466596903820194, 0.14471109776246935, 0.14030434551738924, 0.1725980771645423, 0.12027002014820615, 0.10285536307961711, 0.1677444811549879, 0.14135361018200077, 0.19021252230290445, 0.2228103295689629, 0.13479275658967035, 0.1525908636469995, 0.10871987339229354, 0.12896481931449907, 0.12386683359621994, 0.23721489694810685, 0.17517901205968472, 0.10365264610417428, 0.16914444554957653, 0.1812014743805893, 0.14544900897289478, 0.158080006198537, 0.17278112621316988, 0.08771569603272984, 0.08056569018311079, 0.07201660094001601, 0.1628528871843892, 0.1607726367130395, 0.2216787410960082, 0.16011629854479145, 0.2638232756045557, 0.1770082461617647, 0.2206546194370716, 0.1487958938964913, 0.21668924108868648, 0.13588691400664468, 0.13506821116372464, 0.2299648093720598, 0.21529375064757564, 0.17900375198693047, 0.15559717652297791, 0.11269798412198022, 0.13784402350504554, 0.18097209233430125, 0.17267316910288028, 0.11131724853429104, 0.16703329109136136, 0.0826279758926361, 0.16137266741885295, 0.19646177729291303, 0.11602581643889989, 0.18303564208890163, 0.12096291603220087, 0.07162897577208859, 0.09236623277707447, 0.2565086987470427, 0.16033383687177014, 0.16691981814801696, 0.17959786849396844, 0.19696897346406214, 0.24087279824720276, 0.09007965950595756, 0.09322692489912433, 0.15182613935922423, 0.15716630845300614, 0.10078206868661989, 0.18673007046022724, 0.20765004709603327, 0.1575175904098057, 0.08906922783822784, 0.12578735473535715, 0.22478914999913788, 0.22580455357749618, 0.07435753581023986, 0.14603229299668344, 0.10125570254580629, 0.2127427391467556, 0.1398824762192465], [0.013620276248172648, 0.06496568856340262, 0.07841341212512025, 0.07874409397763592, 0.0543614267371595, 0.027016682452672434, 0.03721626407857384, 0.022624062614575512, 0.009793419045426193, 0.02652968993530639, 0.03767199446296981, 0.028253734419723193, 0.04584045675132544, 0.04134314525271616, 0.05522286579493554, 0.03799531804097276, 0.06811378133152762, 0.08335767464051325, 0.054047468584030874, 0.025372847373927795, 0.0161959529073248, 0.08425531518315116, 0.007535295885792303, 0.037532968656911005, 0.05030418678577389, 0.033244435269866264, 0.07149406768862279, 0.021679139125251004, 0.04179855388018393, 0.008423161625321354, 0.05765465486253943, 0.004512854464983027, 0.11493792562114616, 0.01918563592968689, 0.058268413863955974, 0.029876954072425445, 0.009994622462639406, 0.020767641967282664, 0.04232003759112089, 0.038170242727163343, 0.09092577297480837, 0.042292431612769445, 0.03484440606928641, 0.06426009094162334, 0.02263555776387934, 0.024553571880284338, 0.08788752189326672, 0.01580239534603372, 0.02260319054907849, 0.04616561510990705, 0.03538559356163587, 0.02382003120146692, 0.06708988183808905, 0.047152730891661304, 0.05173523902832981, 0.035864900301901564, 0.01803759571855828, 0.03423684088873767, 0.028721411945298318, 0.0261995941400528, 0.04551173225345631, 0.02238927007232222, 0.016392923688756365, 0.029180390542493235, 0.01047204366900147, 0.09155846966971314, 0.05055231500356909, 0.06151301838878182, 0.08500605070542905, 0.04880182324878631, 0.11183082621784941, 0.07330925939905067, 0.05781693526753976, 0.07097625353884313, 0.07163839865355723, 0.015050917676079177, 0.05467178044660438, 0.06556857677717363, 0.008825985977666513, 0.04369732578315082, 0.04530846231406735, 0.035671076226618983, 0.02838515105747408, 0.069137895329585, 0.016320742884530656, 0.025634763259140235, 0.049239071762009014, 0.009503408800810575, 0.017516686573564526, 0.06808168990837951, 0.06533069115492605, 0.033721148802508275, 0.04716264406940149, 0.023895931362565008, 0.06597877089535037, 0.0332102945615207, 0.04992583128173025, 0.025242263856794567, 0.05589732577303245, 0.006846914653696361, 0.02536464257225875, 0.05585240237715264, 0.06926728757999598, 0.03842598585892589, 0.045475940625633926, 0.03448619484721172, 0.02965212258840761, 0.009473700868716885, 0.019202005313408953, 0.061268517597308086, 0.04142076911164388, 0.009494210000059778, 0.05433898802185732, 0.048496567854477514, 0.02095962743154697, 0.017034077994345177, 0.03899283729673874, 0.020624609521379875, 0.03655427601188421, 0.05771677310187971, 0.00657519284305313, 0.029552626919241685, 0.017726180977338267, 0.028619989565002824, 0.03429946091566836, 0.00992471981237853, 0.03958929037194579, 0.03428147317120626, 0.023552316030667677, 0.01152042254445053, 0.04376229770000904, 0.06540860229682538, 0.016396727315300418, 0.06196862619910991, 0.043638628126392444, 0.08200645642054659, 0.07210895283928803, 0.05721837928098056, 0.0593886450834332, 0.055519655917681036, 0.017077609025422606, 0.032177573565634034, 0.017640185692617973, 0.020144322188571095, 0.02844704713131632, 0.02365011673030113, 0.01754883736852677, 0.01896882347101646, 0.06420895457267761, 0.005874174033036275, 0.008476051378003772, 0.02668775494150337, 0.03915698695627432, 0.07393133045444567, 0.039968105528744004, 0.03559899118338381, 0.04053083924396385, 0.03155245731074003, 0.05408510265331115, 0.02778465878368626, 0.048440015243907134, 0.058237747364347024, 0.013327664177444194, 0.048196563992889664, 0.05123607528906676, 0.040563750381190936, 0.029443066769970522, 0.06091680663127092, 0.06936537747782084, 0.03570196872216559, 0.02422466543653319, 0.049669973236779054, 0.011794813213899974, 0.029517865679677457, 0.09360118183277308, 0.019265918113711863, 0.062367807803375114, 0.013754684459267846, 0.03048410365027526, 0.03475057562032054, 0.06598371982334122, 0.0912955329723416, 0.04127423564392713, 0.02731325040991989, 0.012172670760792832, 0.05451401229947806, 0.049352441283483664, 0.08036181120382202, 0.04358969809066865, 0.01492966223703397, 0.036716085272811116, 0.0320940776427667, 0.037677142573820974, 0.014630490538453864, 0.05395838788019554, 0.04868381123449053, 0.03467542239494863, 0.05707810092116556, 0.009356641676276922, 0.01746539507181414, 0.04470574647007931, 0.08880045355087327, 0.023844128497125163, 0.021884167236426187, 0.052254719419344786, 0.0431583293022648, 0.06932831414404415, 0.02755688552203919, 0.02549727920502905, 0.056586912157194275, 0.026433342887509256, 0.03505106211730069, 0.00708627260117341, 0.058182661812151634, 0.05498411449333353, 0.0844213187754635, 0.05082245675786849, 0.02509059759998514, 0.09610393745524269, 0.051161829877885125, 0.017584282341563416, 0.019562007266006643, 0.019191140271422845, 0.08002500064791211, 0.022654520355225093, 0.05436519972018657, 0.01128299753256743, 0.03882522875022504, 0.08259448252858655, 0.06479655167147999, 0.02161709940992296, 0.08105865244062678, 0.024273672081049413, 0.036190093134439764, 0.032269527099185416, 0.03264820052971763, 0.07931138974644485, 0.016118288828781056, 0.03914054287897964, 0.005454467975669691, 0.0339697826383335, 0.06258002564971966, 0.06576332398840497, 0.08838942439685907, 0.014269672702216815, 0.07317206071269128, 0.040377395663170085, 0.029076003401930776, 0.06800201676425434, 0.008949289744299267, 0.0558821763843298, 0.052918867853980874, 0.01723453830627184, 0.023956967502712243, 0.033749834964832956, 0.033386667153888175, 0.020701162772433414, 0.02388703133610468, 0.031241806742224484, 0.03917347699884446, 0.06686247629864563, 0.042191043706430544, 0.02544423336193206, 0.015912872885594207, 0.02252119615854275, 0.06864318639160165, 0.04643102627127402, 0.06892830899526035, 0.037693429603091175, 0.04122826270759106, 0.052684885449707515, 0.02468600166931508, 0.07348684624077813, 0.023689872863131668, 0.03493083993934336, 0.0437140571434171, 0.06856991008164422, 0.030700747569602345, 0.07756978844202335, 0.052332293482557427, 0.008246625281660067, 0.01213667899250023, 0.05002918420359493, 0.057938076751006234, 0.10187576645083966, 0.042500313401462576, 0.02196633974240432, 0.023825562356280226, 0.1038442753375538, 0.06444047400427443, 0.013262807173774609, 0.04920341419957338, 0.04135747492733983, 0.006043684871626959, 0.02331111324770797, 0.053880411620822646, 0.05252180831326593, 0.03408877907561199, 0.0315836466653573, 0.05006383052997051, 0.0173066214342872, 0.09730681807043091, 0.020575363474387317, 0.013041113777416609, 0.02684200482983743, 0.042463545011536735, 0.06195583253077442, 0.05068120929682928, 0.0193366012160456, 0.0878580045255442, 0.04484778300168053, 0.05710021404909992, 0.022257962602100546, 0.0037898905875702062, 0.0641618823001702, 0.07545140977468222, 0.009958214134037977, 0.026340659655209993, 0.010219288280143613, 0.08462284586482471, 0.03328902158705938, 0.11213778232735012, 0.023492339007075758, 0.007601471997106509, 0.05106223461728904, 0.10196915256880945, 0.024305313427542007, 0.04028553022972999, 0.0223667336808097, 0.01871280646282098, 0.03637284340877687, 0.025544908806501378, 0.11373506032771642, 0.026414633105178515, 0.015872357368108728, 0.04367161204197234, 0.036974766351763284, 0.10459720187129513, 0.03173462152781506, 0.05305026342431384, 0.03607301191697198, 0.04035637804096745, 0.01702138583265966, 0.032291575109646205, 0.032926930129648216, 0.05089353822592286, 0.006730541588753583, 0.02425405256930859, 0.02054082056988151, 0.02587432086828255, 0.08382747806007824, 0.015386814672139384, 0.1684623208617972, 0.17592441561000963, 0.2192744354326879, 0.22180594233495576, 0.11939702465409234, 0.19035637829332583, 0.14530164429978018, 0.18075050906308238, 0.14580899368851416, 0.10875148218004935, 0.10326607047670311, 0.15518669129138993, 0.20943454166333522, 0.22058852137096469, 0.1253239481499599, 0.111409378268065, 0.22327335311039803, 0.1909768175814421, 0.14597256878210654, 0.19416916724895278, 0.11187404889853732, 0.1798560248026925, 0.09314544378749787, 0.13300999338107725, 0.18605690900116198, 0.19435577094554904, 0.1347075369689734, 0.1891066897059641, 0.18620479461406508, 0.1266606566646407, 0.15586317757204657, 0.052836049918926535, 0.21668636059809118, 0.12115393239524096, 0.129844349538607, 0.1314438798374707, 0.13368510070347017, 0.13364535606195851, 0.14387200165900493, 0.21204480240421913, 0.15789487339075536, 0.23100676555787367, 0.13421812935942604, 0.19935466319082246, 0.16448235619933377, 0.1982653321277711, 0.09476580401702274, 0.25957026188412025, 0.1608306602124245, 0.14917746696981693, 0.08942948068462073, 0.1150704435102882, 0.1932935593950172, 0.18715505007534258, 0.08727503459780447, 0.20977903608112566, 0.060319595129018834, 0.1193595246501988, 0.15136308517427216, 0.14354253788628887, 0.13244691875673112, 0.14032884500920773, 0.1493867009036964, 0.13204323638591076, 0.12556960956463892, 0.12432220391929151, 0.1415111485027498, 0.191103114836639, 0.24708633821818138, 0.15911198791957673, 0.15574938287177395, 0.20110048563970676, 0.23272215899440551, 0.1344246053767781, 0.16158047642919326, 0.19372638375047715, 0.09791798003378416, 0.22739985507101784, 0.0956770349594374, 0.2411588554781291, 0.108829845313824, 0.13880512677133083, 0.07023717021389354, 0.22800555482747095, 0.15704169659124267, 0.13435107625780568, 0.09868353169651763, 0.14194472362437557, 0.09079588276724662, 0.22620573850168338, 0.17301507414348666, 0.13882896742753445, 0.20960698805509076, 0.10540780716485555, 0.14664398356070443, 0.1410126550904205, 0.19550329404732875, 0.15291199238309938, 0.21406800996872688, 0.10717402287428418, 0.1471639121131551, 0.14532425921530495, 0.21326207015062534, 0.1673951297397575, 0.09605476227138313, 0.13952512684608662, 0.12084398088195633, 0.16311614563868893, 0.23593562204510937, 0.11893074523897902, 0.2243862183944833, 0.11870572989385937, 0.21202945000221654, 0.15189274304336117, 0.10450438265838932, 0.1446969711011456, 0.16380052262496564, 0.2213238891694815, 0.18162901272937176, 0.12802384883886384, 0.13437710792547272, 0.1350387474221568, 0.07442145818664182, 0.12624992628491696, 0.09725051826887554, 0.19645276809892348, 0.23301953900485273, 0.12047389146661568, 0.15341785556126028, 0.16968256102934962, 0.17670628494553028, 0.23237665334055502, 0.13772676608735515, 0.21472509890314073, 0.1196830895458979, 0.21268235609656383, 0.22055233137742167, 0.21654199898963977, 0.2527863234882393, 0.14370623555394912, 0.09990829178282332, 0.2079532340529465, 0.12109669796641796, 0.22520053921447647, 0.08594639298896636, 0.2570949398702191, 0.15655754434485591, 0.10536935721193591, 0.13075951817295245, 0.1948808016435754, 0.1497471299503119, 0.12801661696885863, 0.10342856538632225, 0.13224822619268972, 0.15240960724411473, 0.16812772429998846, 0.27376933383845514, 0.12406717324929854, 0.11689239211620824, 0.11105411265405918, 0.16801658026393385, 0.17291903736129885, 0.10925550674719196, 0.2386129154793678, 0.21133971040046987, 0.09946766099141491, 0.16115865309632596, 0.16100902080295548, 0.1881311533431853, 0.1672732451510045, 0.1053159302400966, 0.15600744724994706, 0.06817569655756797, 0.12773820529541663, 0.2866050757227406, 0.1069889513535365], [0.03183969814750937, 0.03037591671360837, 0.04148503239717215, 0.06630199871236278, 0.019651844481667204, 0.07278297231682847, 0.07893556233255133, 0.034511789844761935, 0.02066313225265232, 0.015584948949605949, 0.04236115736045665, 0.04063141509710301, 0.053369055592244675, 0.1113528409792531, 0.011436558899379546, 0.018381479181229107, 0.028026731076440024, 0.01946953279266675, 0.01417934423267481, 0.06659094409476365, 0.045048927047079614, 0.06745787217251717, 0.08350403573844703, 0.044492237765582344, 0.023527021722627744, 0.01312853302806616, 0.06355088504572069, 0.05232942448328099, 0.030724042388159904, 0.03057746678560732, 0.05254120565950871, 0.042821648981302016, 0.07249693040766063, 0.11978291846331089, 0.009869637133012856, 0.0076705467936042104, 0.05773197228629744, 0.11291118639130747, 0.03544065613119352, 0.011792995670299617, 0.06588287966986818, 0.04131796011220544, 0.07337033192837432, 0.07146356206747793, 0.02352075703862694, 0.05088503464996334, 0.02250548944087519, 0.035972424572513956, 0.005911081276398393, 0.060024658939050096, 0.028426012272135388, 0.06821803057626372, 0.058604603888647216, 0.037567706913837505, 0.0947004720388401, 0.0700423157503528, 0.024527584262672934, 0.05224744541450374, 0.04360323103385107, 0.05146765217725789, 0.07323140954418529, 0.01787458944524969, 0.026882203378444238, 0.08702126031200733, 0.06293241077313019, 0.011892489424245733, 0.042733250095719294, 0.03083096719497154, 0.05541842122892699, 0.03463777683434948, 0.05865337304590691, 0.02934306356755476, 0.024482415718657356, 0.0543592089126187, 0.04212382715195418, 0.006780086888841564, 0.017385268020593835, 0.0427219579597154, 0.015361882340643677, 0.029279591267808314, 0.016246001431418043, 0.03633014932875672, 0.018791499014403072, 0.032600726061049974, 0.02868973804006894, 0.02556316085129736, 0.014426091576986497, 0.03361422974135607, 0.03324484895734537, 0.032495139992886016, 0.06223454680894652, 0.04282081777590417, 0.023801775326231317, 0.082401022345068, 0.03825550831313576, 0.01739395162721555, 0.01794848054076635, 0.0690088018534645, 0.04531519239648216, 0.07459236474166955, 0.032385608571912014, 0.06400439760557587, 0.10776697492767727, 0.03755652586058263, 0.044826512570462884, 0.04150114705665939, 0.008508183978377812, 0.007890765949512922, 0.028848318240394997, 0.07042563550414578, 0.06538645469493444, 0.06169101891798839, 0.042324055722283746, 0.03700556308631936, 0.07422699442794246, 0.02897763388201354, 0.046677086051673665, 0.0274431865827571, 0.030490642210708994, 0.012469612185903376, 0.06385558502628438, 0.008528275591801972, 0.03571825958187542, 0.03500770920166566, 0.09009022385843339, 0.06478298425434098, 0.0037135666840890005, 0.03504422095213686, 0.05799335382518269, 0.06357618126898043, 0.050493567551095644, 0.03831811684874758, 0.03273289921062608, 0.027719755814741218, 0.04154985875732476, 0.03683909601081283, 0.016332054172732657, 0.0722928599063908, 0.018369484159554687, 0.02297373004107466, 0.016111692811753002, 0.04967685653677872, 0.02864920624321507, 0.05031869266062014, 0.03716849849649495, 0.040444853535342606, 0.023276011099017436, 0.02841894319581409, 0.046952138429567705, 0.05388934037558014, 0.062023692599107186, 0.0250946885095008, 0.02297269007671745, 0.11987697873865405, 0.01031826492474084, 0.053746756091113054, 0.044037024490535266, 0.05746186500595463, 0.022835217513925126, 0.08080461002405613, 0.0407950131733331, 0.03712411136216214, 0.053085503468830744, 0.009192333053497058, 0.019700349338593024, 0.09918764053333191, 0.08727527974594025, 0.025755954538321784, 0.02403766337421633, 0.021803369858272133, 0.050196616549886046, 0.05374265369027854, 0.025123706004852732, 0.05568760920376067, 0.02357337961814577, 0.021685834733709212, 0.08799242997361768, 0.011953934463822554, 0.04613688298230691, 0.044178141716627345, 0.03216587157259065, 0.03297643473131522, 0.017655865597208182, 0.043519999411317616, 0.029071837798842502, 0.05173082636188596, 0.06365442948956644, 0.08122330005731314, 0.042703552697334564, 0.07679122094545635, 0.025423809457870743, 0.10307304696330141, 0.05327884490872103, 0.06710486651788797, 0.06608053801521178, 0.08476923760627547, 0.07383320991310381, 0.07507454814209093, 0.040085328472477776, 0.02266082908928154, 0.007537605162079056, 0.0248584806198074, 0.026425932902061654, 0.05678624057421281, 0.07465617986576212, 0.04471977737041251, 0.03698338484091144, 0.040157785068356225, 0.06526604099499603, 0.048096597179650306, 0.05716231696668172, 0.048206649540412816, 0.013677065388389654, 0.08943219263587268, 0.05675987948873832, 0.08809517768602218, 0.024390931413959593, 0.019566523354320277, 0.015550335181967146, 0.044401452516115485, 0.03806472560691257, 0.03604971135275499, 0.018419295196391402, 0.026196497229618892, 0.02716678780533614, 0.056207112577413364, 0.01634035856583186, 0.02892741873379677, 0.05047771719194228, 0.02254206439360015, 0.051294861045936425, 0.03187066725184841, 0.01941815510602488, 0.046766166755508994, 0.05684560855790492, 0.06978043625431676, 0.04928684117452753, 0.07376639172434807, 0.03920779007697298, 0.09636355699190209, 0.05417421783110308, 0.016238104980138522, 0.009657615596698898, 0.014943306262965405, 0.03697737105070584, 0.04179945786393458, 0.04163347342382035, 0.02395884058768711, 0.010410877293907108, 0.04571667609495982, 0.08067599918332793, 0.02384101243449315, 0.011118129665602841, 0.005470391591980813, 0.01321991103806443, 0.05922958990859409, 0.039637289610841585, 0.06292188472505059, 0.026378333944106297, 0.06554535665218869, 0.03575026290491223, 0.02358422359271396, 0.01077220936666333, 0.02777015865449944, 0.0792007053631448, 0.036886390448818286, 0.0761881105661873, 0.018652842845767736, 0.0033815343622043133, 0.08933202663977301, 0.026543355028655742, 0.04907979442167187, 0.006096239939647457, 0.02906771241537025, 0.03213409424549149, 0.08241466637099944, 0.04600335385710482, 0.026121196532321554, 0.033183688327910445, 0.03790321512027614, 0.06039286760853664, 0.019453705416151115, 0.06813899328511569, 0.022237992605134364, 0.026738826192975528, 0.06749710353511958, 0.018901097468070446, 0.01784102521806715, 0.04971256772536905, 0.03367855431391828, 0.041026406200422395, 0.04238028274548631, 0.04687294025995559, 0.07330657043043645, 0.030626115284018943, 0.07259687423826226, 0.06447908483565816, 0.030602023734020132, 0.04105919093314198, 0.02691817886736845, 0.013553791307663966, 0.04710008532950475, 0.0499737692335921, 0.050524211068066864, 0.013953971699060453, 0.06290007803228594, 0.039315636104513565, 0.027109664459262165, 0.04427666062368982, 0.01497490643223207, 0.030222321830449567, 0.019582276037263296, 0.030690882272357424, 0.01997042406019905, 0.045364084127809734, 0.039398243365388726, 0.013028275101415574, 0.027175084537556096, 0.06944088310363793, 0.022926274724605105, 0.03630312557722773, 0.03262026896399837, 0.05428705875190997, 0.07109369481763533, 0.07698624394834042, 0.04332935843136042, 0.06492431981549149, 0.09618904982363025, 0.021173758582482417, 0.04544291840565782, 0.03560367581104079, 0.012520708335233072, 0.05091872336643358, 0.07375185903642448, 0.026953342303092924, 0.02144805636377104, 0.03407096370093284, 0.029838668828409527, 0.05999690357355341, 0.04815558211938028, 0.01890564803034067, 0.049805647408169125, 0.046749963995910464, 0.02159174956050852, 0.07766003359950359, 0.05726653173746121, 0.06401674311247564, 0.0740604315914454, 0.0306518615839342, 0.01492338031605487, 0.019972320127811645, 0.004573284438060176, 0.14267727221933105, 0.07214878175047136, 0.16351774425035523, 0.1652607168521612, 0.206890118518664, 0.23589717975306898, 0.09932125392820566, 0.15422181887251718, 0.07925111394856246, 0.1367533594490059, 0.13433302722630963, 0.1635006451678853, 0.14497253292750928, 0.21151488406523583, 0.07855650968849659, 0.27925890539923026, 0.2298405192672245, 0.13696153618154988, 0.21538327568240706, 0.3000565990805626, 0.1143614597798836, 0.18708311441925266, 0.23832894200759552, 0.09540665954832109, 0.19103959082595764, 0.07445788566744135, 0.18206983504276122, 0.23507430939184082, 0.13010642821750334, 0.2466010368399082, 0.12320334782763837, 0.15766086417340464, 0.41267471087555735, 0.29663996951233956, 0.10850694691461903, 0.20895421985656987, 0.11876048219780769, 0.1775765608275129, 0.1683708499636381, 0.26343321427702904, 0.12300925179114267, 0.11129052738749212, 0.21603031354325436, 0.19894031687609612, 0.12427287551784709, 0.10606576943950308, 0.091875622409486, 0.10273013068663497, 0.20708435245098608, 0.16288699341877816, 0.09909686677518392, 0.10254408623422347, 0.13575353809902746, 0.12136541862761784, 0.1792887366947628, 0.17891104002633404, 0.16552933792193092, 0.1619672435786455, 0.10424431112985458, 0.21608150353835476, 0.19231809964103086, 0.15557044005442053, 0.08062644095550622, 0.33525668445133394, 0.17030189715085492, 0.10861417624138056, 0.12641107287978934, 0.14688618991884494, 0.13325595357004674, 0.07565555688474448, 0.12868240866209232, 0.15663908674351631, 0.10621119591016924, 0.1627325807367602, 0.1615109003239101, 0.061756588383427555, 0.2014401690253327, 0.13040892569528473, 0.1999805723467181, 0.16215177883784618, 0.15315614460456758, 0.10080024795306307, 0.14897589391518026, 0.18396096904912304, 0.17770040660135208, 0.06490569621805223, 0.08401851740575607, 0.1287284199028246, 0.24052174611678048, 0.1362711377441883, 0.18441487614425922, 0.09882969361159111, 0.21154188100368748, 0.17711382839948903, 0.17345971157473905, 0.2696134907103354, 0.106090881801661, 0.2183752780359599, 0.10191364949869533, 0.15581316735234954, 0.12986632094027536, 0.11956187145363902, 0.20767774883537524, 0.11538675355334437, 0.24336229288770309, 0.18523978429936594, 0.1299989307599683, 0.08688118113505264, 0.08673458254986233, 0.18128467152916616, 0.11843500208229789, 0.2019515480365484, 0.07153329905122519, 0.10155135119754462, 0.1428875020675121, 0.06966127127769493, 0.1313015100576224, 0.1445721907000388, 0.12658598607466107, 0.14684413169180194, 0.19275824779704695, 0.06434988410722825, 0.10362767163784274, 0.09308852345472382, 0.204949158153707, 0.12561408862952264, 0.11831274977134121, 0.17056985938500974, 0.14190811994335345, 0.23802506557155043, 0.18287502409469697, 0.12409187958485658, 0.12386205320757245, 0.12738183651479984, 0.13521980464218125, 0.11502394197328437, 0.14987751811502442, 0.18367561661908705, 0.129565907221648, 0.11721074761402224, 0.14160743043307336, 0.18347051955999868, 0.28282289964056784, 0.101315641265002, 0.1586894138205436, 0.1287117038643168, 0.1760803298243592, 0.2002836980165974, 0.11377925594006816, 0.13508704160490345, 0.16365462884066567, 0.18140343047918814, 0.08897489943211118, 0.3377706479401358, 0.12955274583110887, 0.14444947873632755, 0.17321623351064422, 0.17464837359805263, 0.1422404642066648, 0.18207781767893225, 0.10799814195882891, 0.11837105672325819, 0.15307910680290193, 0.17882142306095172, 0.19150734879076484, 0.15290011802027303, 0.19224539789701664, 0.13298310369493502, 0.1824160914627775, 0.2659053187216482, 0.1794611217994844, 0.2307543702303402, 0.11809992288509685, 0.1738838331713792, 0.11742185080243696, 0.22436083024067266], [0.02922596319788887, 0.03439165959735552, 0.09056071675713025, 0.019627071113415787, 0.028543784883954836, 0.0315212219908473, 0.022787957549876264, 0.01797058026216203, 0.060037310881119584, 0.05462225669273927, 0.028074601995608503, 0.03660636616029567, 0.040121261826566154, 0.05232582003959725, 0.030560434735830755, 0.01413136510358703, 0.07199640686233198, 0.018588296107707486, 0.002895861910092795, 0.01779666106637207, 0.03153245667025688, 0.07560130253794693, 0.0072962424582651555, 0.013211825937633554, 0.06217572274768065, 0.034099117432150154, 0.05728791325142788, 0.0432841822264656, 0.031925994121739944, 0.029647081729865847, 0.014207406990951108, 0.06876555361574696, 0.036143013201053106, 0.03649065240977272, 0.03226968031677027, 0.04474780086668269, 0.047986180927123756, 0.004726421583684221, 0.043338084172817974, 0.027655484868333708, 0.037892271554277795, 0.08997585459221756, 0.04927407431926939, 0.05107184902073876, 0.07788697948619243, 0.006430623912057209, 0.005004437764235322, 0.04619913528703394, 0.00925999393896951, 0.07450309251585314, 0.017304778992829305, 0.03180316916005987, 0.05681823623637038, 0.011470384554066246, 0.06558624276470754, 0.03950991983255071, 0.12295040857767868, 0.04130786307336342, 0.04689681155967617, 0.10907086423568188, 0.05295714160667793, 0.010180529019224548, 0.0363823160859606, 0.03215547192901854, 0.016666945678392248, 0.03498966783104885, 0.07556601652815458, 0.058777827859645894, 0.049018522709487915, 0.02725116855975601, 0.028592220792967468, 0.043166560917011196, 0.05673063025178929, 0.04770261731239096, 0.026434020875322244, 0.054463630527137756, 0.041382326819603486, 0.07436081466655578, 0.056607125387076414, 0.05161089529733985, 0.009301072531079334, 0.03592498457780288, 0.047024277098957575, 0.06694440174126817, 0.03753233280393385, 0.04795647969829941, 0.046684651169925935, 0.07439677483372151, 0.04317709079553043, 0.011016390316428678, 0.10065901964422196, 0.04585880455711196, 0.060835589819978324, 0.04564080274693909, 0.04685950307776371, 0.015791065863243515, 0.01177936026285733, 0.04175107558107665, 0.014810623664919649, 0.029323664306092168, 0.024487992838746118, 0.024716924808378664, 0.03087338739855876, 0.0076309146712564176, 0.1372340796214919, 0.04185174336476673, 0.050694267265498645, 0.08491715386269555, 0.04558465233252895, 0.022790192611395352, 0.013932941627929048, 0.0694859597171026, 0.04482213437797562, 0.025222192353178418, 0.04576388243285399, 0.019558318552651235, 0.08239780477578602, 0.03962549568724729, 0.09473267837517685, 0.04465681643435552, 0.03144756072170792, 0.04368075147090901, 0.014376658796062394, 0.04220888589418704, 0.015093651018105449, 0.09125576534819219, 0.09450719571642338, 0.03515078378240428, 0.02318394265227741, 0.04180554060205337, 0.04313920391723514, 0.03423047086764728, 0.06357327013486816, 0.04447009016369139, 0.021603422825254744, 0.05487361780157494, 0.03684376914715094, 0.04456478246157208, 0.03655311538867893, 0.015548728312545968, 0.02564239157964626, 0.10668184202645095, 0.00596007642959575, 0.06457802509107897, 0.005870778348311903, 0.09123845176110346, 0.03874978058100228, 0.018414583755657077, 0.05302513190995782, 0.05509236271703436, 0.006926570082038281, 0.039100346245592645, 0.07169055391944225, 0.028209533061712023, 0.028068601611941576, 0.03750883688729617, 0.02053983806211862, 0.07204636345587431, 0.019914553267881274, 0.044995117031278155, 0.0464608577350455, 0.015744097970215785, 0.05933308838716438, 0.06080045702777082, 0.045922627342083765, 0.047163042435122114, 0.047030834811589414, 0.0269465011379291, 0.025690228024858142, 0.035135496497875264, 0.03703625639900565, 0.05045889441164271, 0.030394666715555137, 0.015019146094639457, 0.027112207871170777, 0.02068783284255093, 0.04119690289841064, 0.059492354236182675, 0.07784590185169252, 0.012602468111342, 0.02831766637222421, 0.030649339239443504, 0.020525560098429842, 0.06512337244085728, 0.004302787410485889, 0.01147024570062997, 0.020456604524365356, 0.03586726751358759, 0.03466780748098128, 0.0745851252107851, 0.012598375286606532, 0.013111498105459878, 0.12602412953011452, 0.042746223794716987, 0.04363815315187939, 0.04653660850899835, 0.05404413993199987, 0.0690558702955323, 0.03697718335916439, 0.04166816188503177, 0.06394981384097088, 0.0557697453205624, 0.04145752217981123, 0.04667076199585873, 0.024176733230330774, 0.023081162381136132, 0.03420389144711437, 0.06091624355664658, 0.07383808223230225, 0.005534831077731665, 0.04072807241050948, 0.05973187162570896, 0.06247001542379299, 0.03747019924283509, 0.03393931532158487, 0.030853905782644308, 0.03729971403616571, 0.044918171160163424, 0.03603305660128113, 0.02325348811404359, 0.042356189280267686, 0.01376300034368591, 0.041119811470590295, 0.011359642714171881, 0.05068926854179271, 0.11224599990753398, 0.017763441578755458, 0.011145066274630447, 0.03643894530532341, 0.021578844809424014, 0.04315895749436271, 0.01679453570696135, 0.14522719587529861, 0.04264567092421555, 0.0644835128238605, 0.015719112012565376, 0.011777029440347708, 0.012022067450978344, 0.05864269761068206, 0.011690244127455498, 0.04096963525479359, 0.07498720645784371, 0.09303583958817106, 0.056372939969503114, 0.01486140380298058, 0.006359093324957236, 0.053740248174196294, 0.07456084022358542, 0.08909759607406394, 0.03145934506920317, 0.023515718095304988, 0.040450514925103036, 0.0821895131300534, 0.03948964914607425, 0.023466023886876724, 0.06517977183384281, 0.04521120362164033, 0.034714741857662317, 0.046337598018468394, 0.04239620588299248, 0.08753896720947758, 0.0306155126271469, 0.07584395322708354, 0.03048390638263476, 0.06356147621127387, 0.010634931198681795, 0.11216878590564575, 0.039188082465120865, 0.020802027823763992, 0.03478889150785343, 0.029368394264771096, 0.00511486167764111, 0.05961434224680547, 0.029205412889320045, 0.0695238504258375, 0.03843690261184689, 0.017950181255958254, 0.0335760785627269, 0.030215019097311363, 0.025462213445514924, 0.054376181590581135, 0.025426188160875635, 0.04312426520271167, 0.005422226207766442, 0.07029307931060753, 0.06627651862800121, 0.009297845385698302, 0.02915948591825943, 0.0865042045892727, 0.014003221576492635, 0.05591652776685454, 0.013639839260929055, 0.02887064204250853, 0.06412815910974337, 0.04537528050282309, 0.05792093936414008, 0.06074821366177452, 0.023767642278765, 0.028512101402626406, 0.06442200362442002, 0.02714220404384598, 0.037705928327575806, 0.028988343791194984, 0.05579137198266484, 0.019464062924887386, 0.009185557963416703, 0.04381854004497009, 0.04168088277501445, 0.036002577793213635, 0.004057778606957366, 0.0701437764350445, 0.05136811437325613, 0.015535506592582793, 0.013521031472801924, 0.004175672835234794, 0.01778330623863205, 0.03969974109842893, 0.04231235372924036, 0.012558715872376437, 0.041918580705720576, 0.06143165985122324, 0.0782293135360364, 0.024273181784777872, 0.060067923754573836, 0.024666882029944853, 0.06429431208920094, 0.08072126731877366, 0.017650901347458843, 0.02188638506096698, 0.012397262842334326, 0.043141429402655175, 0.04774786629563859, 0.01670658881325395, 0.04243551002394769, 0.02500346084425767, 0.034258609277106104, 0.06458183254806266, 0.02026241081165931, 0.04962421480506178, 0.0619962934644953, 0.02112618643760441, 0.056959518171366186, 0.03159029056288062, 0.02806829517677186, 0.007845926344499835, 0.06570513194967663, 0.01982084347776348, 0.05667808428106289, 0.05722231314247174, 0.06613273924637227, 0.06184642368386831, 0.0397641844146194, 0.12081582715073902, 0.1818166736273035, 0.2272985322821525, 0.07555020447339743, 0.11799674616345476, 0.09696202487835, 0.14005977960844196, 0.18594994780517396, 0.10158614691106543, 0.13365989641076134, 0.058663236427932024, 0.11925997152443855, 0.12818816703774277, 0.17096617198999853, 0.09764253312060911, 0.1019912082401495, 0.2482154292445029, 0.06985342145086297, 0.10212397893830653, 0.07638292672533183, 0.1341036145365046, 0.18124425273028114, 0.11130827764469771, 0.0978997318194278, 0.16110044573583912, 0.15266595558533747, 0.1800617040886033, 0.18607347182208495, 0.1467868896020997, 0.1280675464940648, 0.1327615663889916, 0.15160253361588524, 0.19435508146641717, 0.26141772887879805, 0.21363235108794706, 0.15024047525179002, 0.13338317013075277, 0.1479108325175701, 0.18781672021554363, 0.08311531506478788, 0.1363840131389518, 0.12512971421763783, 0.14700566899151574, 0.17231010471380528, 0.173904272397199, 0.07124239248373816, 0.10050867488908191, 0.14728958117625407, 0.06866877372827261, 0.31992640706800646, 0.13322212312731052, 0.13405426315242244, 0.10990554767270243, 0.0784143697350256, 0.14656431041657925, 0.08497212833214192, 0.30008920378262, 0.15705367820637842, 0.19527935122530307, 0.10983347412078612, 0.09429766300825343, 0.09229573736628217, 0.12027110799305862, 0.09008539750451043, 0.18250592293277865, 0.16432241236250247, 0.2640804053554612, 0.08789708267056173, 0.15425125197056802, 0.0671776065662984, 0.09573916469009654, 0.20014160402840186, 0.16154080839647403, 0.1569387037307024, 0.2061339744156407, 0.2287396202765165, 0.15640926036623218, 0.1680530307273711, 0.13487688836551484, 0.24899132309421418, 0.15495988330052746, 0.135213170320757, 0.14626742070240362, 0.2070458029066363, 0.21651441982436567, 0.20302197204962855, 0.11838484630589524, 0.15370023557015006, 0.14007788992697193, 0.10964774376442356, 0.2051282388668868, 0.15612919394287372, 0.11412796384144215, 0.11597674084647049, 0.0914198843642108, 0.23149379829485572, 0.14136220568851118, 0.06480350774983246, 0.11911125087569799, 0.09836755873214814, 0.15109549066232097, 0.20571400501555015, 0.13546342060210245, 0.12106678989385405, 0.20421700792447214, 0.10399036830471409, 0.1748947627962597, 0.18756043316135484, 0.12571991601538274, 0.1971338509071258, 0.0830909075035203, 0.13706993762283556, 0.26540408271454996, 0.10047310542675758, 0.1715269789940888, 0.11530269838629231, 0.16826755066792812, 0.1919276093042666, 0.16427834698509786, 0.11215583901972541, 0.1862583441599723, 0.1214330105651771, 0.11420580603542829, 0.11299305054689608, 0.06696061216174595, 0.11187960303598836, 0.13193495751869294, 0.18413802729018275, 0.10753955406647538, 0.09654521942138673, 0.0979869126252109, 0.10849196989569934, 0.09954062320532338, 0.14258814555022026, 0.17230638152649327, 0.14264574004036767, 0.1688631840290562, 0.0695452012962872, 0.07979441584358293, 0.13739308883105555, 0.0919662352891699, 0.21693009913208025, 0.1154846749118259, 0.19005369695444263, 0.10852684987889183, 0.14307773702086943, 0.14654601623694744, 0.22048543657987352, 0.1598946846300556, 0.1595688674358591, 0.1717233120073234, 0.1330290076833579, 0.10360703322916262, 0.14944254871337645, 0.10364067214991778, 0.10571754417352139, 0.07400846784754146, 0.22546992637217048, 0.09255197845519551, 0.10848335140655119, 0.12046076071959351, 0.11055571117228079, 0.1696235875809385, 0.18216081564464878, 0.11026101246956857, 0.1996151484068363, 0.1918540342200187, 0.13183522819271012, 0.15286552148961252, 0.1662898640478811, 0.12971321060772867, 0.15124670109681546, 0.1398740645738379, 0.19869988784193995, 0.197940127803914, 0.13523917134490707], [0.015920333624366793, 0.0331727102879555, 0.03712121171936874, 0.060547678656275236, 0.04623157528018759, 0.019627800812163664, 0.03609029869098337, 0.08002787347762816, 0.07406022474770585, 0.03259496124941976, 0.09913066657440317, 0.08391209247131502, 0.02588524336686298, 0.0516403092431926, 0.09475959104395683, 0.030354169392657858, 0.03028790470242741, 0.05194450743616589, 0.05439226177611178, 0.04292037090166442, 0.07058545676690918, 0.02042249637475658, 0.042606244209192456, 0.035349890033924775, 0.0471821524983933, 0.06407614557012435, 0.022732050368382085, 0.013689155213444704, 0.015246015372535875, 0.02093701634646183, 0.06977838313867969, 0.023296890825393702, 0.01265411775919699, 0.05881649614762395, 0.04494060221458635, 0.0411200987535619, 0.029019584856747143, 0.040595650282357974, 0.04107126447882864, 0.02457982762866924, 0.04096935180226161, 0.005126380288387619, 0.04501622275359208, 0.04188920889470366, 0.03373875733344786, 0.022017026034694527, 0.03762749624588797, 0.006121738218597227, 0.04769493345051043, 0.031301352841358994, 0.01662429373320793, 0.021388742006233624, 0.028177753819393057, 0.08737196770286368, 0.019367784825003436, 0.02249970164660725, 0.09781070474174716, 0.013862798617581927, 0.011888890726221426, 0.05388161820930339, 0.04668768487810608, 0.09948333515034569, 0.03581499350407431, 0.022662186980127327, 0.06430959554329034, 0.022100274894206275, 0.024751008060129902, 0.0706666774086414, 0.02155865073173998, 0.07502518909712953, 0.02396793213612851, 0.020622447238213593, 0.08514960026068073, 0.0013248200271083344, 0.016631019985183113, 0.019637049408629537, 0.027223210180959394, 0.04960082997117312, 0.06996087294312255, 0.01847247127443552, 0.007910463506461032, 0.04092240210382208, 0.042114561318510005, 0.05928438051693863, 0.029868603714050788, 0.06301305684891921, 0.024595593718150933, 0.0008928658397992202, 0.04988846917366309, 0.04922800179150316, 0.08238311887027756, 0.027790458069273064, 0.03680171092010794, 0.017747698471911492, 0.018073582698801355, 0.004623794530127799, 0.0462773758467407, 0.00228117402706806, 0.09451389898576083, 0.06586887558261234, 0.018031580013132865, 0.07559976270121914, 0.06478751183397348, 0.04611342920050506, 0.022491376186090133, 0.01614653449054928, 0.027008598309851466, 0.02070852679260556, 0.028615917807685274, 0.042235706632416097, 0.03659129721082507, 0.08268055250687946, 0.05589201295327756, 0.11227242228004242, 0.0872060637019815, 0.02109296503476799, 0.06058217559550559, 0.030489426046129198, 0.026489885921980587, 0.03449403575711674, 0.028513710187267394, 0.026838446351429148, 0.012484367996934923, 0.01278667203751543, 0.07182995893902357, 0.030121226952741706, 0.08641864788988907, 0.09912833000623411, 0.029942368405059944, 0.06449680444934676, 0.0860857290606345, 0.023091634803061045, 0.05053923788270162, 0.015699551872638686, 0.03431167235718139, 0.030536235933522546, 0.032900480944062435, 0.05782935355279235, 0.026977713475184097, 0.04826678744246883, 0.05489948859077789, 0.022453332259770364, 0.04791377029652077, 0.05768245236287194, 0.02683861106033287, 0.011009556812144095, 0.030782422118429697, 0.019683277069200433, 0.07110539298023909, 0.06853687637034925, 0.02279092422536304, 0.057457624709293734, 0.03535775775690714, 0.029547647347733862, 0.05559861660003663, 0.022749503766517007, 0.027484781326605912, 0.06458981518423365, 0.03438175408049457, 0.03909321396701759, 0.059650160687705206, 0.010460907623412148, 0.009389822859497321, 0.10365127480678982, 0.02555723707642286, 0.05562750960610086, 0.05768657391590457, 0.051093939166035385, 0.028547887284789356, 0.03991000542056657, 0.04163356918481089, 0.042700725832893964, 0.03378658420256069, 0.038627141395643834, 0.036269352591085824, 0.02120848151765043, 0.039076689450490865, 0.0449958409843666, 0.003992597212932343, 0.07249172100977552, 0.079095360612677, 0.021498706266884843, 0.045221124460259755, 0.05929856080441706, 0.012251939793537942, 0.07990376723389472, 0.04072184411568507, 0.04184192594801707, 0.03485128553884645, 0.011382646419318214, 0.06769800243238289, 0.06412340553417321, 0.01808435964067617, 0.04746857362108366, 0.04543102106019374, 0.014658616498983918, 0.0436660923784779, 0.06439901332581235, 0.016156248485429153, 0.04323255173080871, 0.07706371075924366, 0.06411975895565364, 0.08332595860044803, 0.08936613287416198, 0.05771234894411699, 0.020376364475176222, 0.03668489783341366, 0.016234232405681285, 0.05347593634900066, 0.0698849995951018, 0.01705623708755499, 0.023855686848682743, 0.05218111369157991, 0.009013725399610498, 0.02826002974724097, 0.0260574541865818, 0.02019196711180191, 0.024159559454288215, 0.07708883078228082, 0.02405711626183362, 0.035614339754946774, 0.054624206386506564, 0.029756978957823692, 0.005719552592058937, 0.056888111115944, 0.06241680678701209, 0.04927276047847925, 0.03394072492336554, 0.02833684538340857, 0.021165071145421075, 0.060473475379929434, 0.04720973166366739, 0.039024913398128365, 0.013622811999202017, 0.01801547684496449, 0.026079956104137728, 0.0885787094011903, 0.03923086464525231, 0.05251470284776823, 0.022807732194421754, 0.012956518518377938, 0.04264136167964147, 0.04563540182707291, 0.02001193836481581, 0.019413307684683995, 0.030349976976492235, 0.02935953828836641, 0.0627015195336313, 0.06158224209361981, 0.017531451003085223, 0.03632821878718753, 0.02313139093589158, 0.07314305662387803, 0.04184899693955818, 0.0553391196374451, 0.026223639724776152, 0.029863539872871294, 0.10028901449855297, 0.0451042998822466, 0.05777480426214396, 0.014270258759478889, 0.07177860806545905, 0.06216594746576683, 0.06034815488683601, 0.09363854394084023, 0.021233572812390425, 0.0022532364762868854, 0.006478990394351704, 0.06536518043327717, 0.009458162690392666, 0.024530912914703933, 0.003734973335315684, 0.04872108907288602, 0.01274990939324902, 0.026953844090683327, 0.05504662726795482, 0.012330480085145082, 0.055710737398194696, 0.10039267385558737, 0.03334781500480829, 0.016316144441765164, 0.016488087130710483, 0.04176037971891704, 0.03735588743321357, 0.02715480427498058, 0.020538757878145384, 0.016123519294084083, 0.04158013455209233, 0.06572396239085544, 0.01943760990886198, 0.055820571423898784, 0.02479352593992747, 0.07111147571835788, 0.0502370200270126, 0.060956673846850475, 0.05796209360743242, 0.029766692952703566, 0.011313586465774045, 0.044777314403965596, 0.06560590824172383, 0.024268541207176544, 0.05850218942448978, 0.04120244554454281, 0.046461056917905814, 0.033946861287639025, 0.008503147907885573, 0.019272284304362633, 0.004133025199295052, 0.09388468799091156, 0.12508672902420645, 0.04213129650921591, 0.09045603850315656, 0.009985686047002673, 0.04156660543934953, 0.0746128652545233, 0.05494207924892826, 0.09507914929981194, 0.031963009575021364, 0.02485809949106507, 0.07920977584416829, 0.05602418227241405, 0.02685959420857891, 0.046248459858038736, 0.02572756523506776, 0.06562437862157822, 0.0754289633985008, 0.014541970036413162, 0.025146522018457615, 0.014922030086088327, 0.008048228619079436, 0.013522450650681653, 0.02628157703926967, 0.01188310005912377, 0.04116718251738818, 0.05351524815083512, 0.08675838490166972, 0.04118153517464957, 0.0168586170466076, 0.08081522034180742, 0.05559423840754936, 0.04581365516529449, 0.024263986814466697, 0.008730391611254985, 0.06498520082283406, 0.06434199340160816, 0.036533691229358796, 0.041524574025383884, 0.026600713946766434, 0.0610121232908099, 0.026579477989505378, 0.014426102110695456, 0.010999979755480685, 0.10414792960810085, 0.16450356151307785, 0.17245596785458828, 0.13043328729127684, 0.17232784731013162, 0.13734986615036765, 0.18606547386415545, 0.24567629210650924, 0.11783709344003471, 0.2019345408846294, 0.18369927341418882, 0.17896002368821254, 0.1278548191992506, 0.10442695415188229, 0.13925030046413023, 0.10022830203055375, 0.07335563070110737, 0.16739062514276276, 0.17418436946407442, 0.1283193059686211, 0.17910288376433237, 0.10001049557280156, 0.07093840879538367, 0.15836443932306382, 0.11899764769740644, 0.11881307413380955, 0.147393447377028, 0.17325829173768723, 0.14826520946958374, 0.06361619787170522, 0.12523609318680343, 0.05722692882221553, 0.14031966727587486, 0.18450377298699272, 0.09118445788420017, 0.1099284690233969, 0.1460901632784836, 0.2097677439451218, 0.14221720577728364, 0.13069127506065753, 0.16593081395952933, 0.11390124778113059, 0.3547828866829795, 0.12590511777107755, 0.10879691885483843, 0.09355952963232995, 0.1304583536881593, 0.092092034587216, 0.1431821854484658, 0.2059187803177103, 0.13203781248340685, 0.16803243828396644, 0.13442350221016716, 0.17631067714143187, 0.13525866062170075, 0.26479243811580444, 0.18999884505906414, 0.0843923989563219, 0.0979417747247123, 0.18716070380422378, 0.12075948138390818, 0.20618119607529334, 0.17925645374963362, 0.14072811471358423, 0.15668178848441572, 0.13556956974489076, 0.10000753847341384, 0.1973397600194139, 0.13392241942065378, 0.21543918477912105, 0.11552114069702164, 0.11824986927451626, 0.2894699687678968, 0.05605189167263527, 0.13128954376424515, 0.11829163638814805, 0.13698968225188796, 0.1350808209709583, 0.19154361539310027, 0.18810345160384334, 0.10649462545951528, 0.24535930024520045, 0.1972378856472431, 0.19725884581285139, 0.146711521872109, 0.14237244583425984, 0.1932275379377027, 0.10415073348990372, 0.14384981575271777, 0.13194484005291618, 0.19714371811959053, 0.10507724022552853, 0.14901433620722065, 0.1584773147178273, 0.08947274933058409, 0.07605787561905962, 0.1284595843284361, 0.08529622182850877, 0.20133264092428071, 0.185289258257516, 0.09764357500018613, 0.16856578869685052, 0.11749124304661829, 0.12841748779699688, 0.09841352400760497, 0.11866454500705005, 0.1075494212789401, 0.11790113839050455, 0.12446830454733103, 0.13390620900017602, 0.10254447693906485, 0.09324651376734819, 0.16084636501487226, 0.20951599213144473, 0.12797689530998468, 0.08361407660789068, 0.2672645732039406, 0.10403309302825121, 0.1350334307719623, 0.1583195618924595, 0.08098010544575031, 0.09782464754196907, 0.13688788448850955, 0.1766197170100866, 0.15980442415081686, 0.09059768816035602, 0.21496975674263893, 0.12515550839804834, 0.1653910437298398, 0.10500424736810308, 0.35223163003402375, 0.13030979391788283, 0.22064902699522435, 0.21216487902547085, 0.19119322209829287, 0.21046385739839849, 0.10891701079784863, 0.19157150099354406, 0.09517710130181044, 0.18090728129590714, 0.2315554530510018, 0.09748557702668252, 0.16434839806489407, 0.22596932376825044, 0.13939953439178007, 0.10599979394746405, 0.09452415690306695, 0.09581484651613621, 0.16648904690819402, 0.2364591971760796, 0.10266237020973237, 0.1312349676605194, 0.0845145823193654, 0.08428183714708976, 0.07908831260377362, 0.12402957365397485, 0.12265726503345276, 0.17970481436819802, 0.1104220211686146, 0.18798985608643104, 0.1786174291684743, 0.06981733870962936, 0.1819141046895135, 0.24161362059174046, 0.1416170678191608, 0.1274600234483519, 0.1284412058791326, 0.15319481672298524, 0.11127519796812728, 0.06770807648858718, 0.1555081877496935, 0.08968407468449685, 0.10682204377747352, 0.1319000851963797, 0.16231558375781582, 0.13501351248593102], [0.02997306554818586, 0.008246764135096342, 0.043030285366600564, 0.024726071898194573, 0.04993893138523545, 0.061573010734132225, 0.07091491287874599, 0.06641539504691478, 0.00562213302116781, 0.009957092772838811, 0.051330683317275784, 0.054723774834025296, 0.04321262578389818, 0.10518769478245128, 0.032761719438337514, 0.053908718569624814, 0.052873335418201266, 0.07802834569085991, 0.03675898619657082, 0.036537207572931246, 0.01903013731803625, 0.026684355426339373, 0.06399006027007295, 0.005306835650586554, 0.02292921075657491, 0.08347955156838702, 0.05007241071472245, 0.11949159054746551, 0.008078509201896528, 0.026222147768543615, 0.05683999313341995, 0.0540615952453546, 0.034808959181029955, 0.05809122538794914, 0.03307673096236202, 0.049776379019021995, 0.01691884304877491, 0.042439520494231296, 0.03782990816680174, 0.007276791485867674, 0.016606459206330682, 0.005021052774898107, 0.019011994440769477, 0.03523850468017402, 0.05920839991660849, 0.0219719915560657, 0.04583248177603368, 0.017564283616300073, 0.0427869605200906, 0.11056130361412803, 0.11649267041995642, 0.011672128063266077, 0.04216242266157943, 0.04548527157655166, 0.00891925526722785, 0.02907663733968812, 0.040420059099673264, 0.07481695107755161, 0.04044112651759098, 0.029877836988758177, 0.04708263001615002, 0.030586052716018695, 0.023514875398588278, 0.034452789583273476, 0.038352786157760894, 0.06194765071174311, 0.035537133413937785, 0.021564206784410823, 0.02856971887541154, 0.10967389034527926, 0.057664882136328574, 0.029267684346245184, 0.02378034401654957, 0.025528876501466, 0.03361551676906886, 0.019115784032750997, 0.0805111064185058, 0.0065923771528046465, 0.025372268977544965, 0.04298613571952428, 0.029540672117183288, 0.0338285734816905, 0.03549366175467449, 0.03814410380718689, 0.015919437301495386, 0.057528729159985824, 0.010183724563478703, 0.08403714866407457, 0.02317678739106463, 0.04872276297500057, 0.05770619725808502, 0.008556732885359276, 0.0845679173606538, 0.016702153164172368, 0.038769063014056415, 0.02770438809098015, 0.03968856004517406, 0.008900819361330041, 0.05283677004157536, 0.034708934911196275, 0.07358057709831385, 0.024759396722900773, 0.028840144082242926, 0.014306469820439817, 0.03417461922752761, 0.008846828357256468, 0.042714572872125336, 0.06455701896019521, 0.0620876417885865, 0.06202127559170608, 0.03202582686959255, 0.04723426945988209, 0.029187036355236368, 0.023382750129507437, 0.021072581350322694, 0.045524273112776785, 0.03846822028619148, 0.05593540034286919, 0.038390849236278765, 0.022805271136965004, 0.011610200388296958, 0.03436055642762973, 0.03628661638245948, 0.09162882718467906, 0.031828835020743074, 0.03233793108994442, 0.050728270078017834, 0.06595032605072183, 0.0451451936556447, 0.021046415617268895, 0.03948567698018686, 0.029343680268333807, 0.029724858806378422, 0.024559874868681355, 0.041608839866615115, 0.06404355618982546, 0.01974343986911399, 0.031126788216492826, 0.0569156902812181, 0.05622505435660001, 0.029660166511612556, 0.012609260438400651, 0.025292404311438723, 0.04911726378204842, 0.027581639738092502, 0.023225008795458465, 0.0081285807086275, 0.0646637579906852, 0.03351820062004751, 0.02895132067703432, 0.028139164055427237, 0.025088126966429335, 0.016998127403278506, 0.035487176820395455, 0.0976831587632337, 0.08603926582802689, 0.03511740533154338, 0.0248807450501068, 0.03902510108966981, 0.006011741878014179, 0.08857426609122947, 0.02440119124648552, 0.02714802056641108, 0.026416651746858994, 0.023498446643052083, 0.033792766532109636, 0.02026128657763043, 0.06427840810389289, 0.04962112747072693, 0.04559329380431483, 0.052587592283323895, 0.0300519994174641, 0.022211438082458995, 0.0785446812909457, 0.054290816413178566, 0.03529956571817879, 0.026303762945556836, 0.03345125985722388, 0.03501956824273352, 0.036861308730177345, 0.03884019427782586, 0.11126749878448826, 0.04347083571877691, 0.07263866433453176, 0.05673128525696455, 0.02106107279448019, 0.06471448067215181, 0.03286875724311798, 0.06921159298790079, 0.06538418707467857, 0.031388692610386404, 0.041981530150458704, 0.04762289054211109, 0.014259071960564584, 0.030056592114570162, 0.07251769139040863, 0.03298928968668465, 0.08860854852584102, 0.049472383839348634, 0.04993839895412807, 0.06414432356494569, 0.10460994191347592, 0.026672278050213095, 0.03447302196535372, 0.020891876530743415, 0.0203753589847756, 0.07917982946720817, 0.03513360809114191, 0.0105919249378325, 0.03228901254553949, 0.03389113988246649, 0.09950097049436263, 0.008101404697123555, 0.03805976901804248, 0.0445169824055366, 0.010220291855324422, 0.14093554067996242, 0.04943820482660686, 0.11467808391898872, 0.08872510880352029, 0.09554610287229862, 0.07024041842669249, 0.021946170562577826, 0.030319004041713574, 0.12675459436591596, 0.06627450381676037, 0.06900107202630851, 0.016155566667176543, 0.024814539731690483, 0.0359889337672822, 0.04334515133391946, 0.021046425193367947, 0.05869175788135298, 0.05000271586581104, 0.07327035745425571, 0.01633197756394023, 0.014604236705288773, 0.08404983508010065, 0.03813460048648619, 0.02606501930483407, 0.049790540154302315, 0.06444340812102442, 0.03897905920542056, 0.018884044350875963, 0.014379054736045581, 0.13282389530251104, 0.036663252019113114, 0.026783751504075144, 0.04729846379749718, 0.07449183868424547, 0.04712426306439504, 0.03479327353078031, 0.012691029790608634, 0.059937052954469, 0.06192363768575653, 0.047866150271147496, 0.04610717026216369, 0.023371998085490158, 0.047207965831001925, 0.022346309776748383, 0.01386855481072299, 0.032743042214743556, 0.01400692752682634, 0.05350671776179826, 0.044629524552053025, 0.05518176900823751, 0.09746446364348936, 0.08995975142404919, 0.03304650879374916, 0.037648261059075594, 0.07578779898223377, 0.019991520206413923, 0.034172792107828205, 0.009390491271211256, 0.050176568028907624, 0.042101656567425504, 0.04246485885232688, 0.03709456718136226, 0.08383941370993854, 0.040328086413923776, 0.032315844775087414, 0.049655000048298994, 0.033017029730422844, 0.05868988862681774, 0.0843366660598305, 0.027453109336596344, 0.009744528271708517, 0.09010489444218336, 0.06006812676787377, 0.03869790493720963, 0.16057061932740674, 0.006252058393006484, 0.035278073121463104, 0.04072444115374838, 0.04673307941805932, 0.029600214385878176, 0.00716533383256906, 0.027733348129737764, 0.036880288558501395, 0.04991250135184777, 0.03286913262620088, 0.011403536679403437, 0.027108976895350124, 0.0010060184027796853, 0.0912941923184741, 0.01772911892452788, 0.03901271727837382, 0.015724196921162788, 0.02497541436534976, 0.007010675523610365, 0.015993752618200116, 0.0767431412673285, 0.06434816040939863, 0.009082556484387288, 0.022991292606738788, 0.05271885761870973, 0.04838797489121076, 0.04171214299276472, 0.0052566717344997155, 0.04182745454712741, 0.040264478133570765, 0.021294135893244418, 0.028926173840919812, 0.02401619759057799, 0.0325679604805285, 0.0438902382138035, 0.04311315309736998, 0.014992351211877841, 0.0030642346293109682, 0.0644335255868012, 0.060590660019266995, 0.08322347901881703, 0.018621069349108205, 0.045727389834580884, 0.032910865265876055, 0.0281358641316934, 0.041202441714103186, 0.04367204488164956, 0.03777000775200225, 0.010400968904216445, 0.0376985164269084, 0.056498402188862526, 0.03908583270986715, 0.008356002527439307, 0.011566576469058712, 0.08200665560340689, 0.017785836244001985, 0.00911394502186487, 0.03615402954540426, 0.12235811535990047, 0.06786343911963125, 0.03290292476454089, 0.19561551060647736, 0.14306342649844386, 0.09084317337481246, 0.10412571305829672, 0.10572571067079421, 0.2784667091984903, 0.16957852628923234, 0.2645942358480346, 0.11389494287751376, 0.14504782404870759, 0.16418661561704453, 0.22531107038019166, 0.16951256611895177, 0.17340495160991148, 0.13475431429762996, 0.09581990269643646, 0.1327834611818675, 0.14999472956743934, 0.1920277063524531, 0.10628471736826244, 0.13700095906613335, 0.24454508667751668, 0.11558728472840403, 0.21233801489635823, 0.1577752564222582, 0.20596039421375723, 0.16941521166553422, 0.15503336645422444, 0.08390133659685813, 0.1579899295804001, 0.13997685825151784, 0.20258378507869862, 0.07061348026317936, 0.1777074239667385, 0.14380726722940324, 0.28297158198491223, 0.09793664959649886, 0.16432847977886278, 0.2106891332134124, 0.1318290688457989, 0.18959500947065894, 0.2144720447399924, 0.2429957964247273, 0.17414365955177816, 0.16873481833646375, 0.14285521912238291, 0.14635843194780812, 0.11053606867790224, 0.14181091870752074, 0.12317905517955943, 0.2913108474064258, 0.14320686880138614, 0.08908749137434269, 0.20205084835329365, 0.14441128159242292, 0.13643244521752482, 0.16199555818832692, 0.21721584992783688, 0.1735746554068981, 0.08387712821845086, 0.10368966347267551, 0.14610277308571726, 0.15454723770099302, 0.1470169611275196, 0.13591502943346578, 0.13381605577324668, 0.11578062233785469, 0.09248875321880465, 0.09771332730569186, 0.25822206971145445, 0.08496303486848071, 0.13948421775093003, 0.26143997607211916, 0.11309838763648465, 0.16899194808736925, 0.08548490162337981, 0.19332832446502102, 0.1253038460028268, 0.13397416099905968, 0.11312228191884295, 0.20453767700781747, 0.15716842285567717, 0.17296529375016692, 0.17883279180574804, 0.24321531125855064, 0.07007807673465821, 0.1901476193339594, 0.18958987668156627, 0.18373126524590677, 0.16734237692529158, 0.1712878369876454, 0.14870872841246668, 0.16823588059313838, 0.10530427038188904, 0.16294069618227022, 0.15048749264209502, 0.10863567266853587, 0.1511764814776759, 0.11746036204239053, 0.1518553426308978, 0.18868100528995838, 0.13260608118387962, 0.16309379119305842, 0.21644682022592715, 0.10038633830845357, 0.13589069848099064, 0.11030084904163115, 0.16039728427365904, 0.2338973072267348, 0.1896906785306431, 0.0775044564638407, 0.2182802065245567, 0.09941934382603054, 0.12560966830219955, 0.164758913939999, 0.21561867917977998, 0.10306429823920613, 0.12531210443065052, 0.1312786040286864, 0.08886946275109246, 0.07184112850095957, 0.13556826739541947, 0.09089628625060282, 0.120708582502219, 0.1385069347076839, 0.14605956572678783, 0.10636171686553186, 0.1938515625173046, 0.37149291906145315, 0.11413834433281615, 0.1686302166912825, 0.230887133267618, 0.14096491249097934, 0.10184170618172615, 0.11685912857853598, 0.18396936537277314, 0.0975534370950153, 0.11546527756558311, 0.16180192180458577, 0.2253486393319984, 0.11961695317539478, 0.15019034245802512, 0.1108675932271346, 0.1635635716299857, 0.10379804959220272, 0.10008082244425051, 0.10917521307184812, 0.09150249928596521, 0.16540432769444682, 0.1914769044566539, 0.14649724707968775, 0.09674017347635762, 0.08347638762525975, 0.13253534062495156, 0.24074458577219518, 0.18163688811323336, 0.1076891633772081, 0.13548024389291966, 0.1334440281554576, 0.13481043789896274, 0.16752815324692957, 0.13262842030775163, 0.22520705096183286, 0.10467319013250452, 0.13235039167827176, 0.1589813699284869, 0.13415956959849404, 0.15159081247064377, 0.15255770736163662, 0.18858288474861654, 0.24117100563260818, 0.16737485905328106, 0.15164371850269456, 0.2160119427548301, 0.09386272425012243, 0.1234880644046972], [0.07232118217695145, 0.04037928023946382, 0.054968310099455624, 0.036350075275667255, 0.02823367823786553, 0.041476310486154216, 0.03684175433591008, 0.03178613519506349, 0.03948131027901846, 0.06659547933527539, 0.033752102585088824, 0.0338001707718978, 0.03818021336149785, 0.06386588890886595, 0.0828970106498849, 0.040860900565260844, 0.010738135691011145, 0.022484789745161132, 0.04859396061229129, 0.0445248041632435, 0.02493567546949752, 0.01778269911395206, 0.04748985171318055, 0.045401614775220235, 0.041429602105410836, 0.05360204208221647, 0.0328448323172427, 0.05638463047122764, 0.0948076247568092, 0.02068574908339689, 0.022436407462303198, 0.02037748104832586, 0.0466560454468333, 0.04361781734792937, 0.06916470074605557, 0.0794956338922343, 0.031367263215924465, 0.03804378459350236, 0.034951895865942204, 0.05119184903319805, 0.09744665209924984, 0.03842907319326074, 0.06640335214474509, 0.03881645321305241, 0.03602732243316789, 0.15851218704014056, 0.05316924453983384, 0.002678532581475954, 0.0496748493864171, 0.039575646346014355, 0.022131437435746196, 0.04614579641530591, 0.042543582047425935, 0.026182466329285697, 0.03057350419581898, 0.024309245373813376, 0.04015979221871784, 0.04007025952300718, 0.03850686176109218, 0.02073226402693939, 0.012859090328997663, 0.022983064822432016, 0.04684972779584989, 0.023479654506269484, 0.01734729304218725, 0.04590632116061546, 0.007435895498811959, 0.030000602578624126, 0.013512022278812385, 0.016670327956577944, 0.05099370039158291, 0.027621531851529598, 0.0321182572928768, 0.057654559101548895, 0.04517915816376767, 0.05716536599662035, 0.00818383480016623, 0.10417250570871177, 0.056319202732054464, 0.028433081348456686, 0.019248518341731642, 0.03530397455418303, 0.018246594080401045, 0.004285536546845951, 0.021356267539123376, 0.04164041034997471, 0.04331135919557945, 0.022640688637752208, 0.0244009192852724, 0.02292374854967479, 0.05283554430089651, 0.09535506352662079, 0.08868270583691136, 0.053864197369905255, 0.023476254991105488, 0.058288132967126954, 0.029259977501726923, 0.04109186841355216, 0.04590144884141703, 0.04557564696897903, 0.06717992015182972, 0.04581334873012478, 0.0766925258381713, 0.0582036487908373, 0.020522528305469502, 0.03207053193041394, 0.012380824510699079, 0.08054188017042414, 0.06118637381962711, 0.050993286704103795, 0.06294779764908938, 0.06541973355436517, 0.047364270750192866, 0.09475293373989482, 0.0590544315655866, 0.020239866759267547, 0.014143196373967635, 0.06450520077299687, 0.024481837322274526, 0.05307861250795184, 0.012762546013560028, 0.12062973673305205, 0.008627483977996295, 0.01775916297769835, 0.020341631963909156, 0.02320320401791363, 0.08921227943632873, 0.04341662733725483, 0.07653551611809001, 0.011119540224993422, 0.03379062148592165, 0.020022410786740726, 0.03395374075719907, 0.0458529784584478, 0.015922222988710048, 0.0571459916330153, 0.051354573769194466, 0.03764559124265948, 0.039453907313966946, 0.010415283257081624, 0.01563041052225256, 0.018535570106318882, 0.04306084844433973, 0.03347089469072319, 0.04527503406749137, 0.10314888200692593, 0.011174797189361867, 0.05618256712031942, 0.03943220021263246, 0.02029632935450683, 0.04365741643273542, 0.029845822174402497, 0.019514894773883205, 0.054115075843348626, 0.047516442625032324, 0.0020281555348887078, 0.06202988258953537, 0.029188972642464988, 0.0556725096107731, 0.07141855440192646, 0.07122255846737854, 0.043311110217004054, 0.04305619829063935, 0.04915995403162895, 0.01414631147898974, 0.054412494158192035, 0.04236409147720664, 0.029000614604522145, 0.09193141659301135, 0.036843114141975684, 0.009574552513508788, 0.021339656837705164, 0.03783408717642869, 0.039453869009570736, 0.017157588604717486, 0.03559867708733486, 0.020679938306491223, 0.01260556789460562, 0.029328661114578287, 0.06372237382757087, 0.04167530948536531, 0.006870566181943662, 0.050169110162964756, 0.05186009220778943, 0.08352216903961475, 0.0427307986143616, 0.05250400826034527, 0.03977343875674471, 0.050833362019470626, 0.012485336140549232, 0.005740744978069298, 0.05208662057655954, 0.050367783574808034, 0.04658074283431615, 0.0172040882265015, 0.05109224994216235, 0.04664844585462444, 0.07059473409167222, 0.07325697389821853, 0.03555056293525043, 0.02023741336269004, 0.041823796477288976, 0.0227948006302599, 0.09319543102455717, 0.02130301485228683, 0.09725359794233115, 0.03916009344280728, 0.020943334656617334, 0.01111244529320468, 0.04990197530376816, 0.05545675626865799, 0.04050154021129974, 0.03886135745673411, 0.0390833007892774, 0.013951192715115125, 0.055601573699424346, 0.023407376025833433, 0.09691516328002177, 0.024437093957056923, 0.04949815120668181, 0.027732266030544718, 0.045446354309998216, 0.08803085694389959, 0.023261118349769426, 0.02171303468546079, 0.0585488863139143, 0.03608239649404441, 0.06166382662711605, 0.0375329495047129, 0.018651278111182393, 0.08429657667875291, 0.08853026966173803, 0.017275198422853025, 0.06835570423713616, 0.03885016108172075, 0.04790732366663795, 0.03522964487332971, 0.03823170979176799, 0.04695021554887776, 0.04249808791604254, 0.0351587510968168, 0.07204165201513998, 0.01923114538282877, 0.0349401364163045, 0.06638006307184696, 0.07717558257882634, 0.050402671218879765, 0.010267028964364962, 0.005329822597559542, 0.043793688152706435, 0.047327552155982104, 0.061587194852050275, 0.0582444544641241, 0.036496807926244317, 0.046271538256757686, 0.06886483094985447, 0.05053464518559556, 0.034421793665857084, 0.046633982114614024, 0.025982134337086352, 0.0052068142535825895, 0.06507759102650228, 0.03792342451971866, 0.050200355058956536, 0.08343215370851179, 0.05468527508539058, 0.018228569946762536, 0.03000837454061595, 0.03891373105767754, 0.04442652657387718, 0.05098900810304669, 0.03269016682620972, 0.030690393891305696, 0.030263997013530428, 0.024269550528016784, 0.09600641446248179, 0.02228389467833744, 0.05274251441381151, 0.009724101494817484, 0.07844994685822919, 0.011902723401304216, 0.039552150429376674, 0.015656415376842262, 0.02888303542990358, 0.05400762818152866, 0.011887440904824725, 0.037806396928405574, 0.07354216544979042, 0.05168553907424212, 0.032215831996572596, 0.050732747861935254, 0.044335599598144336, 0.04195377478496202, 0.05198123752169552, 0.035818410256216605, 0.07110681024289901, 0.04001621201994919, 0.03518267602269207, 0.056299138889317556, 0.032250275309648246, 0.08632846401944276, 0.03198412678865416, 0.05390036821125015, 0.04492755190679624, 0.07535644551558841, 0.0618406780244362, 0.05943099825432705, 0.05979561397144872, 0.04428503779514183, 0.028457339522579027, 0.04087588524505977, 0.051045579865815184, 0.036380561744613994, 0.06260829429412562, 0.03010511420847428, 0.024703874500588547, 0.12856744950817478, 0.02848663089436389, 0.03894597952885013, 0.02467616701558713, 0.057135408128341364, 0.04891602014521918, 0.04065589543672339, 0.044804713538577484, 0.07684528377027282, 0.03964604599581611, 0.04632868458546939, 0.1098125292769363, 0.02483527007092151, 0.00902036929713382, 0.035527599449720115, 0.10843567009414397, 0.04248074751587645, 0.046702037535367474, 0.0605920926036854, 0.004043569112376821, 0.054991315719821764, 0.05443346198467959, 0.02053685989531298, 0.10048173923766422, 0.08700410760338269, 0.041881950211621104, 0.056653745667708505, 0.0274039552201547, 0.05150220274264294, 0.04821189724269414, 0.02397995397088028, 0.005766561662312598, 0.012561908543800876, 0.03732140964618133, 0.07293919296634775, 0.05808763626602389, 0.18415688837487854, 0.06982047967011891, 0.18494389049949186, 0.11724358214245689, 0.21072354588297107, 0.10903273603969044, 0.1573539693509379, 0.08115781486154565, 0.10541077958600176, 0.1149392739358929, 0.11639141657900427, 0.10717464340550285, 0.19772200725011288, 0.1546021968486809, 0.30262235011304583, 0.12141781904163862, 0.16016080825319215, 0.15966294303296075, 0.1497418899089098, 0.1459326862447685, 0.11968010180299321, 0.09967400677381985, 0.15096475009716329, 0.09696407033310783, 0.12664143551862048, 0.1434009801596403, 0.18799197048910204, 0.18168833857822805, 0.26008213119160745, 0.13083130061145753, 0.09383930494227717, 0.09320522928910871, 0.18387567281963366, 0.19426800791294346, 0.17789516147346268, 0.1634332447523071, 0.11534276478473218, 0.1682145680270849, 0.1948240651719032, 0.1883754128169629, 0.12273223439772284, 0.18892750174047487, 0.17797376209449384, 0.12017065088354772, 0.15138562348100448, 0.3125189497105537, 0.18440189861482192, 0.10734251625235043, 0.1534664868226936, 0.15911954154651012, 0.1006601917587461, 0.14535707842198112, 0.09469869471485577, 0.10287329719792451, 0.10119099875972157, 0.1695092412973604, 0.14030950894999888, 0.18369043275954264, 0.12083807434406012, 0.12382509712610515, 0.09256913116382015, 0.13351406391349532, 0.1219548773200762, 0.08752176853557748, 0.17696836362442664, 0.1720187614762014, 0.07953211499918854, 0.1528375746021348, 0.14818310016585937, 0.1607722077038019, 0.10258425988497273, 0.14608843191977472, 0.20577659439896384, 0.10548656100347158, 0.16313261652906097, 0.19441368719262464, 0.22669824110644482, 0.2197260902293267, 0.26710256092971374, 0.1870583697792984, 0.11199799426380666, 0.15057585322328154, 0.15396331016334797, 0.12721822311681125, 0.1620891588109155, 0.14271376864804378, 0.147302420809865, 0.12863667321301278, 0.16481174336325738, 0.15183202291448272, 0.09251363575458528, 0.17352610075425717, 0.19145401374947643, 0.15221304440450284, 0.06672455748963742, 0.1952219405962575, 0.1123179508853824, 0.23743815029100065, 0.17645257194676708, 0.18769987648533237, 0.13362068803079669, 0.2191357888401516, 0.20514679351641288, 0.14424759924652117, 0.08746460305466768, 0.1588436886067352, 0.08782408215225705, 0.1265662669714901, 0.13633427871090753, 0.09307916186028913, 0.13770408988479646, 0.30654190108180046, 0.15979429646845789, 0.16075729963279542, 0.1993480288693982, 0.12709546518782455, 0.17544764845121294, 0.1897241872164511, 0.09820938455842196, 0.18117686763646143, 0.08691459022943052, 0.20521733489248062, 0.15893791742142171, 0.1392451063880036, 0.16126896975742233, 0.16117918425269667, 0.18575700090056468, 0.21752047713004777, 0.20561459744649552, 0.15222787586671693, 0.1733561671308933, 0.1476957456719491, 0.13226865009675104, 0.11119224596768619, 0.13283422216773033, 0.1578491532634343, 0.13833343111459287, 0.12718416284769773, 0.14312042344001033, 0.12480051857569527, 0.17374120292163667, 0.20580012861999775, 0.1385192840450233, 0.06349400684778249, 0.1435563274689259, 0.15694008268896611, 0.11764724153063952, 0.13274219968626577, 0.1414686459447107, 0.08623050435656503, 0.11425050726581006, 0.1325711782180494, 0.09541166976334588, 0.08755686302338878, 0.11799155974820738, 0.20918888790953546, 0.10083106767025687, 0.12301633044356301, 0.1374042277494746, 0.1669018610470718, 0.2209435724803517, 0.20942490427724778, 0.06870817363021836, 0.2242325718003896, 0.13527920709982996, 0.15867157929366635, 0.14479648592250963, 0.1026971506014947, 0.11110589253686129, 0.16647222361737685, 0.08483952617332821, 0.170553618321015, 0.12970027904356682, 0.08939601796408815, 0.11773860517648921, 0.17561833284074263], [0.026231019066706784, 0.037152108045354966, 0.04074884488457634, 0.028196457856064363, 0.06245205449240823, 0.05603021904525738, 0.03663781023914776, 0.006968460727347843, 0.036453209862473517, 0.022659124543650017, 0.0767781668072266, 0.028751867770728086, 0.0352086847077214, 0.021111770578089262, 0.05789941995434704, 0.0281209732976652, 0.06755367146744844, 0.00887889871298666, 0.02560784292948102, 0.036892296986714486, 0.03466209629550576, 0.034639883576141256, 0.04432375204839534, 0.012853439472946189, 0.05111246317204449, 0.04491316860601787, 0.08665320869054526, 0.0752437080166513, 0.029227677319619446, 0.042730775631723866, 0.029622819725303885, 0.033442614554998376, 0.004100345803665057, 0.015741046067447435, 0.03706018132488093, 0.08811244530783546, 0.052146034525527116, 0.02460468143615271, 0.03990339025134041, 0.036021929174180956, 0.018687734320279092, 0.04867885847606006, 0.007428873824180976, 0.034960001076181094, 0.052251953841938134, 0.01495157905493773, 0.03656234674816651, 0.09820313328095982, 0.0765137515601612, 0.06655820915775915, 0.052948722300390084, 0.011767368114012624, 0.02070035646489311, 0.02758314127042409, 0.049568592991319396, 0.07108519124167581, 0.05341767919279876, 0.0820221382403566, 0.02237468758868354, 0.047547702842782584, 0.050175223544600515, 0.07770208416566735, 0.03056601951679876, 0.03678723568877867, 0.023176421584080786, 0.014851977091072308, 0.013570156860946408, 0.014940459288716798, 0.021735004171909347, 0.002914866636274383, 0.039113005848541375, 0.07637106768426395, 0.017499914993682218, 0.08135505951941013, 0.040664318573450854, 0.03756168163231304, 0.06717762954893612, 0.03117523944726394, 0.04210332663910043, 0.02861604229697297, 0.025459599170473315, 0.04068807879042241, 0.05902363483103053, 0.04497886447596454, 0.034046134791306915, 0.030972578547774788, 0.015742984269895864, 0.016027300566014265, 0.029262132124013962, 0.014626563380232022, 0.010976711750000475, 0.052782071363781734, 0.05824030609801412, 0.010056440012469407, 0.03187236413660069, 0.0316018125252618, 0.032836068271388935, 0.06838204233997291, 0.0243502521451803, 0.059746078726264744, 0.03116643709701396, 0.03460039557408422, 0.025095042825165777, 0.025650927714342554, 0.03256681900952132, 0.022392121834620353, 0.025713978665730646, 0.059088874878662254, 0.03810995926840171, 0.020057453563617125, 0.03717928501446882, 0.02305162969165512, 0.046058424087541724, 0.09515602622301349, 0.01715000050382749, 0.015151778896970135, 0.03205437896653049, 0.0246059684638655, 0.05133730614738119, 0.047777594337540294, 0.043406480502697735, 0.048111313728675734, 0.06844133754531223, 0.021996230577989932, 0.029175602492966482, 0.03182956663471076, 0.02644031811805983, 0.052426120101083676, 0.10525082042741199, 0.024955787192729693, 0.04373922313172971, 0.051930943849466504, 0.047753022067369, 0.05930797602500647, 0.0089776091420302, 0.0565239550515769, 0.013342196865367794, 0.015057551039893542, 0.027510429950310823, 0.030732858144948562, 0.015598122789073857, 0.021042340029511723, 0.01684181290798851, 0.0217847500912725, 0.06270577515205068, 0.014478917169805258, 0.052524987578151695, 0.07794000043143189, 0.01398556324983797, 0.031591363085974614, 0.039422206595660224, 0.04940026432215687, 0.04992800697143521, 0.048034467448991154, 0.12592350388126028, 0.025911072021230094, 0.011070224272477771, 0.017620612146152605, 0.02233338587346577, 0.05845223283094745, 0.0611386044071086, 0.08028350935708131, 0.05659173851111724, 0.003371336534919758, 0.08385596886998223, 0.07738509230435857, 0.08399993977359227, 0.04680789556474455, 0.0366810750546715, 0.04807886224420321, 0.028116562546441154, 0.08199839717558316, 0.03807055170557672, 0.078064443753852, 0.040083298339478435, 0.0365585852564583, 0.02269021430683713, 0.023863426251937787, 0.03765149011967644, 0.028478772747480584, 0.06277289977597614, 0.09901665736951175, 0.03369483751274886, 0.010405456264232917, 0.0931120883192747, 0.022351946268651276, 0.0303202431889311, 0.06848744071659542, 0.04937713612772284, 0.01470416042608239, 0.021473281723897786, 0.0565858243123418, 0.028894243296235803, 0.03123589828910847, 0.029888893552725355, 0.029646170085235953, 0.061028785703162995, 0.0706196625927283, 0.018998444260608767, 0.09803028852348367, 0.03506142345647659, 0.018277724063204184, 0.07300182065415768, 0.03624523614322947, 0.03938998493756499, 0.01090285225561069, 0.06660733837634325, 0.07572127190688926, 0.07992056754207419, 0.03839684387428626, 0.06761603868536412, 0.04923717952483604, 0.029722688862332897, 0.030403356067836288, 0.04415721985541525, 0.005521001275478592, 0.045001084856208295, 0.011137646713083791, 0.02246788409989207, 0.020287214823427702, 0.023106720989509937, 0.024903561063711683, 0.002963362874711053, 0.06961140661470352, 0.013811849940177656, 0.06674133481517916, 0.019305400370109468, 0.016043725491110838, 0.05711488463284989, 0.03221040809406869, 0.05488362674030566, 0.05734265406405734, 0.03533108257538369, 0.02839759232536439, 0.006150116509337339, 0.01343110807224988, 0.01602972140385499, 0.10809538149905783, 0.034897273796941006, 0.08124760802715056, 0.052272940820623795, 0.04167829722827, 0.03157198297671013, 0.022544368403032426, 0.03824535764813904, 0.04009809149729629, 0.018356150399232586, 0.07362302603019823, 0.08809005255780875, 0.07343020936053607, 0.04260975289188566, 0.010020388872362673, 0.04443548597215165, 0.014610417119617906, 0.02380913360074403, 0.01938598324364472, 0.02386665531253863, 0.06927489483308408, 0.02710763241104301, 0.04876243483815943, 0.004916831779654228, 0.01727266650226328, 0.03239775106551186, 0.012774276734900572, 0.03392811894657151, 0.039673862648346735, 0.033587416664006255, 0.029007641546007608, 0.037551419884567304, 0.052406845328908776, 0.02938815933321753, 0.026131326129900354, 0.029605452512060444, 0.007532373260361173, 0.09796429004880691, 0.027573099772956584, 0.01954393333665306, 0.06621502475031922, 0.0560294529573331, 0.020794669549251278, 0.011383056276357703, 0.028495303009666746, 0.035887411795556545, 0.014308915556138082, 0.01644879256585433, 0.018594334795770627, 0.042347444386612025, 0.02605870865555781, 0.04368328722193838, 0.060249046092071844, 0.052695491937019175, 0.015560748232077929, 0.024624117086791707, 0.04699998828131826, 0.003609502258064646, 0.029200550146220677, 0.02556235645897687, 0.024638703400870005, 0.057927435789737976, 0.018241271684547106, 0.09527679998427631, 0.025937517376376257, 0.020534718679564617, 0.01698436463371881, 0.031010247091011658, 0.018253412262927142, 0.021273323199561527, 0.06036474835127593, 0.03795562319517617, 0.04193563765335468, 0.015732688048193534, 0.012888827946998421, 0.047893733266861215, 0.048623343914627075, 0.01973109053177459, 0.0258083070718473, 0.026162685939080776, 0.08655099723968776, 0.07509198430324755, 0.00744756110267894, 0.015044624263781213, 0.04410902143365914, 0.032609853998667775, 0.06871711387629471, 0.02597732138970206, 0.006576012078327157, 0.026115205724753683, 0.06569151856726216, 0.031061287698966843, 0.03361123816801175, 0.01765075196031361, 0.060131355834704255, 0.048237714405742385, 0.02263047668572155, 0.016485840577872533, 0.051304938932580334, 0.06213716937289123, 0.05987824804540123, 0.017141382014679334, 0.024832678778517633, 0.045806105368800705, 0.08570699817350796, 0.01582348383136935, 0.04801441892801274, 0.037330173692035104, 0.04477359121665359, 0.010979601816694823, 0.061415437939426595, 0.020960274775842988, 0.029741528879610762, 0.02346499732905819, 0.0475674104546347, 0.1396653362579884, 0.08927787954528486, 0.24667709404903077, 0.15048332512378693, 0.19032538237590946, 0.24103989734524683, 0.12658836860810557, 0.08160995995445598, 0.2480580747848557, 0.09202365357909473, 0.11587603858882382, 0.24179316095767484, 0.11638445283977256, 0.09224230273356361, 0.09576567133227665, 0.14206313017395236, 0.14302319156066065, 0.14818259454782934, 0.10109999517519629, 0.16959694304293202, 0.09473796438185439, 0.14543811520261152, 0.13846121458036287, 0.1788097172374687, 0.21207907717795144, 0.09419822479568182, 0.15031489303275464, 0.17220482891125066, 0.09587180515330646, 0.09266375068334803, 0.13421676572292082, 0.12969723001362818, 0.1325021996613472, 0.14752513789121183, 0.18371168403856217, 0.1840431243181229, 0.12973930356242966, 0.16645654945844607, 0.07021679993598692, 0.08431500109333186, 0.11568964173596714, 0.12471647873040169, 0.08436449803411962, 0.1340625062584877, 0.23003556525274632, 0.2101180146658613, 0.07448331212564822, 0.28888961119997886, 0.08558384953967987, 0.12666598097571444, 0.14192854384741477, 0.08830068843258966, 0.09221997893145008, 0.17092428230229886, 0.17275659607783442, 0.3021626973584775, 0.12277755615932327, 0.14373410583263443, 0.08372825435212544, 0.10669167093451946, 0.15990321884953207, 0.17974445175740028, 0.11842502761752376, 0.18241512619199293, 0.16922529846910508, 0.15649285588052966, 0.09013693990005602, 0.060425265466854464, 0.11444522383352441, 0.19039881956433097, 0.10070729850521011, 0.20272799346956516, 0.08750438600057557, 0.18969663869469397, 0.16084991966284093, 0.0893011532964245, 0.15046618007604154, 0.10672436756712776, 0.07032895520810159, 0.1092647304458003, 0.10376110883249391, 0.13630591813595067, 0.18672354339111238, 0.13478509571042754, 0.11915733106434347, 0.12027066366206254, 0.0905199915230755, 0.09519728771861523, 0.12659600650471065, 0.13990432504684697, 0.08143565196904444, 0.17236889430111454, 0.1858881245096845, 0.11002988374281315, 0.08660194974753165, 0.09972862118194181, 0.10800881356361414, 0.11691129150530023, 0.3036430243763232, 0.1430465725641097, 0.10783508780502504, 0.19848058751273542, 0.15724156893068747, 0.18080545288901176, 0.14902910638240077, 0.12287544687428784, 0.1712853088974953, 0.15247048059057805, 0.17692802143433403, 0.19750773245769163, 0.15553550644507333, 0.10304542949363109, 0.11029551706967816, 0.19077231807093467, 0.08691901821763286, 0.15727259549162081, 0.10032091439972002, 0.12376833001091597, 0.15189752343200869, 0.10599809323227215, 0.13381216404659133, 0.10624750847778014, 0.1335401568681963, 0.1539013183285152, 0.18091298099006378, 0.14756250766015824, 0.1038307998509657, 0.13129315969924774, 0.17059590637443528, 0.08253025371701488, 0.18494719999932474, 0.22713183154982908, 0.1383603514442521, 0.14407905990317946, 0.08519138269607099, 0.17607239315346365, 0.11202231755540257, 0.12291317670455865, 0.1035040480295016, 0.08853042287932289, 0.11482783878642706, 0.09940253585697183, 0.2723426023317922, 0.10514590468618179, 0.17727705109263622, 0.20552626750882597, 0.12101187671144163, 0.1650961152007503, 0.12308403729431092, 0.10874307053464075, 0.12449450475434143, 0.2920828495294817, 0.06475414104399181, 0.18517802229091046, 0.15685660974873653, 0.2246482511081042, 0.20721889281224823, 0.11022449305821812, 0.08965671002384155, 0.19189445301890376, 0.22049754076907713, 0.17379910384695377, 0.1774642523378134, 0.13751161795470024, 0.18981878375334127, 0.17340007929071305, 0.21122461335072595, 0.15385452567810012, 0.09301582937158885, 0.12886556496302928, 0.11027372186823238, 0.11195454175674147, 0.08635522347063788, 0.16556483843634207, 0.08421256747697631, 0.15988717696839766], [0.052713510324998256, 0.01998473649784442, 0.13249438556451953, 0.036621350840094595, 0.03198290296319512, 0.024958481907003352, 0.02696053969914154, 0.03854688985513584, 0.04834679383484106, 0.02688605488548356, 0.01291557016121524, 0.04023387675143538, 0.03424276657883198, 0.022363311183007977, 0.006312556356386913, 0.034823285025214, 0.013896768871364335, 0.036785148099185004, 0.13910187858968012, 0.06482085964131741, 0.03748573167549987, 0.015827124664229492, 0.01853302477919046, 0.02648527598789623, 0.0376768974256852, 0.04547474169803243, 0.09880994386490315, 0.015212535415025008, 0.02087299054819009, 0.00939495181815038, 0.04129948207147179, 0.0284303100253906, 0.038644129395364754, 0.04588614240468991, 0.058863346254633325, 0.013557662924511299, 0.0396117712220838, 0.06393926864069316, 0.03506219720528011, 0.02316900393775394, 0.05835100580307265, 0.016796245998252305, 0.05524516278397172, 0.05335385257738733, 0.03598210026299761, 0.0706101401198295, 0.01849032686873069, 0.06751975675504054, 0.062006505416525956, 0.03878720397610338, 0.08389431157059248, 0.018632102930437655, 0.010874282921694461, 0.05519979505709583, 0.05478133485021611, 0.028078865274907123, 0.009743815809938937, 0.008832576249035136, 0.023168829652751168, 0.03984324085796553, 0.040457195211802764, 0.024668820232393283, 0.032469514351818836, 0.06622134497569454, 0.05433566703070557, 0.01982022677698443, 0.04408603113505148, 0.027613470691346356, 0.0451737763960996, 0.010444700075764089, 0.03839870163750264, 0.025336280082082076, 0.03896488274838175, 0.025996429537753427, 0.08022236021896524, 0.0498726494580267, 0.0422099699085999, 0.06266855860068914, 0.02068315779099301, 0.03500975465642349, 0.02921823145551307, 0.04878708371712316, 0.027636736781606754, 0.07059077341710368, 0.021726933435627052, 0.006255307084610385, 0.03696467697380051, 0.015207737789399203, 0.06835160566674126, 0.03606910486855815, 0.08872140859884602, 0.024329184727262587, 0.06292041000579635, 0.019883794837721416, 0.04861459519053179, 0.020855362865052397, 0.03294749575997553, 0.018103008135972966, 0.03216077708789418, 0.09849003320860286, 0.02255864445150139, 0.047637538143223336, 0.013774004239108295, 0.03505245256688326, 0.031850829405049165, 0.014342813031567682, 0.017719943106414813, 0.03159728877606892, 0.045617199577992006, 0.028844179450384075, 0.042358725031297055, 0.08099620861391868, 0.053253188624136874, 0.03841727543922682, 0.08094919379800558, 0.06165684373568624, 0.07576372849965289, 0.06925964202251166, 0.023937598884766622, 0.03664989527615328, 0.04411511183265717, 0.09969950984081916, 0.07380304903152489, 0.07450901437550783, 0.07691799317516627, 0.018802727948153214, 0.07981201288320365, 0.05330677647444029, 0.040989059414113724, 0.05067906042020168, 0.025011891641864376, 0.029729231253206253, 0.027746597620388194, 0.034466199952388005, 0.05911792493275097, 0.03390911613560973, 0.025759859671515804, 0.061240237461583275, 0.01944414080841647, 0.04185934295697559, 0.05640253777645769, 0.052842347161664124, 0.05378955742344261, 0.026347935575270848, 0.07220244620956721, 0.04172786311697095, 0.0190304322618871, 0.038508439902216196, 0.03422038148968451, 0.02852167367124029, 0.06029492326741738, 0.06201454550929128, 0.02569030080321095, 0.01893278669505831, 0.009625260830826817, 0.079252676767928, 0.023641080723234245, 0.03860864420271209, 0.0244600880861042, 0.013126492361357857, 0.013016143141524687, 0.045775300973365386, 0.05182795481936586, 0.0960411182454517, 0.00393410113305905, 0.043535060699908965, 0.024347375485024626, 0.08179588183279961, 0.05466088667632111, 0.11985319170860514, 0.010206681345739673, 0.09374693006036744, 0.014956653429826182, 0.011159168038096641, 0.04168151479755198, 0.03443564453552808, 0.045236576453692494, 0.05864144505692586, 0.04637313300683614, 0.003186570252329412, 0.06197760474958247, 0.04991038694917675, 0.04926894536061634, 0.015599067950050439, 0.041057394456959544, 0.05080508571418543, 0.012152691187727596, 0.0897039316834942, 0.04579177186373742, 0.011401084240435833, 0.03530843701634196, 0.022029369626374497, 0.04807998073257266, 0.013356025710010962, 0.02473857445311883, 0.029047782638020096, 0.06548798432753933, 0.03429015677782797, 0.04527136067589445, 0.11628601820238176, 0.08538885718031276, 0.03758732642557833, 0.05934550667241697, 0.08242322357311364, 0.013151563546289841, 0.06089034595436627, 0.03318412116758766, 0.031334285046004, 0.02338956065115429, 0.010389405764609335, 0.02960729878395796, 0.04015289742739932, 0.024603515067287994, 0.08933495309564377, 0.0441150275629855, 0.06849112559951122, 0.04352477979996512, 0.04193956768440624, 0.038541764726922396, 0.05784320442246334, 0.05614925378693208, 0.0427076934025653, 0.05618464321859422, 0.0624153052546805, 0.01800635273778631, 0.003865153219873807, 0.021934991424542763, 0.006862149748485536, 0.006936531140273738, 0.07991939542755004, 0.03822740054719391, 0.03366881350596105, 0.04447080262546097, 0.03480325565643368, 0.025421172200191407, 0.04983382029158454, 0.03151347492671302, 0.04505154323734103, 0.020813542125265927, 0.0559543380363574, 0.0424105087445388, 0.04042329582115335, 0.03865699967249267, 0.03441117568722656, 0.04929373979628567, 0.02983502224988995, 0.061669051346759644, 0.04342840976953026, 0.04713851613022628, 0.021193619411919388, 0.05560656476225104, 0.06618558399138913, 0.04852796596805415, 0.03959807740043729, 0.05345866489674776, 0.03851053898312873, 0.012238982373908644, 0.03336404840792379, 0.0320587475829187, 0.04963185270166686, 0.02495233213619119, 0.04173136030834529, 0.0510926521383226, 0.013694024659813413, 0.04664781766252653, 0.030201873028530713, 0.07612764324632383, 0.05387796013946495, 0.03792193447870593, 0.030355850955651655, 0.08092447214068905, 0.039669633843004704, 0.020331780073202906, 0.03980593620649269, 0.02519220958704189, 0.03991084811728328, 0.04667353906458424, 0.02785890802530752, 0.04510541837061605, 0.041750876398216334, 0.029910384234221234, 0.045819492755277504, 0.019058919241351467, 0.05974550799076116, 0.045710976400803176, 0.03524330039058001, 0.04094307115601917, 0.05285890998258706, 0.03964186698618916, 0.012644570388440645, 0.021616218408810037, 0.13162086146973795, 0.08691312700149514, 0.04024721051175748, 0.009878996812227753, 0.02875149238764519, 0.03125032563994248, 0.03968795100527425, 0.024277531248967976, 0.026555110647853826, 0.029588747964871508, 0.046512480569823135, 0.08931726412547213, 0.02705228830417318, 0.019541087320014354, 0.03913681586122802, 0.07990144598748415, 0.06832580382545149, 0.05317181859525943, 0.021969555396466486, 0.021642974029565533, 0.0423460615979087, 0.05665407508551594, 0.04989560145223814, 0.04847605201986529, 0.005890024870994591, 0.03420254313236764, 0.0207869244003368, 0.01258021996041099, 0.02977219729443952, 0.01682187930019873, 0.0338649396754561, 0.020764372687065796, 0.038903630188395905, 0.0253049815599356, 0.04465830647536824, 0.037267434921476154, 0.028656076136676055, 0.03671129339284474, 0.006189846307895477, 0.054175194593206535, 0.09133450386504974, 0.010585183364098832, 0.035243062903323484, 0.02858113358548332, 0.0275504446378158, 0.014139007788241632, 0.04923668539812488, 0.0891016716618211, 0.07518335560997648, 0.03033710095370489, 0.016414404794153188, 0.047589979404884006, 0.04190758734400715, 0.013735804222373953, 0.06546169985085726, 0.011101214444234727, 0.0461899996885369, 0.009046207527599989, 0.012952893964886185, 0.035966349495274406, 0.03338411608110032, 0.18728022884217002, 0.14641665463005343, 0.25354855032938145, 0.08483871412012847, 0.21630700917974596, 0.10989985563942503, 0.12192612604027796, 0.16864077338287908, 0.16900091131608333, 0.11308288967777645, 0.18227753680079214, 0.14889370800266344, 0.1543600670993328, 0.08630599466062362, 0.08723962601394424, 0.13280101991709203, 0.08228109894140113, 0.10651756979284749, 0.18441539708404772, 0.1746721376454638, 0.14009627603715466, 0.07839694889562746, 0.13404056550033633, 0.18927110749627316, 0.16094888290089948, 0.16350678919303804, 0.18915706764786475, 0.13616822149244048, 0.06550987912041527, 0.1396411891666151, 0.20132756942222196, 0.07450827893110053, 0.11976900630660596, 0.19294079122764451, 0.1453180079378428, 0.11510296394267391, 0.2497992087756434, 0.17434518664113938, 0.09690102129693955, 0.09792183345604329, 0.18232607613167456, 0.13351729680453578, 0.08463507262809623, 0.22081529871831018, 0.1549350160865053, 0.12470871825972873, 0.0962205743417144, 0.14717374868210287, 0.1475669050048436, 0.09256078846632473, 0.09657236957742323, 0.10238120061976295, 0.15322590457095256, 0.1843712397760922, 0.12126473169172965, 0.10264695652069585, 0.09685513263027515, 0.1126466868745704, 0.1665310132046861, 0.13100777662569477, 0.10226703819728668, 0.08573221778797527, 0.16541813259884236, 0.19671970377525977, 0.16182421496318233, 0.12674850396691792, 0.10223008977669863, 0.17437527857480511, 0.1739920201080461, 0.10227391766684671, 0.17257259708018075, 0.07012555120332588, 0.1267050821033697, 0.1203109598868797, 0.1803902791993272, 0.2082656293867096, 0.11611996098391472, 0.14616740026300953, 0.14633978536773115, 0.11396731520372053, 0.13047427299522585, 0.14798783967571874, 0.08873149031592954, 0.10301062611923104, 0.1750211519820075, 0.16530226946117418, 0.13962637302615952, 0.11427767274360504, 0.1567035147379483, 0.15083040891876145, 0.2042839333655373, 0.1570422175310312, 0.08273437018356017, 0.18254687799321068, 0.10836049388613432, 0.11549782098060656, 0.08297178083129468, 0.12238623078672156, 0.15969213098287582, 0.12633581240210803, 0.11319710572640743, 0.20980764180421832, 0.09728382777182326, 0.15148637936480586, 0.19387609265264005, 0.16837157008628692, 0.3047492246954672, 0.10967741434973095, 0.11015064984319672, 0.24577312562013828, 0.11631453199492348, 0.20328847871672726, 0.10992090773558426, 0.16351858694707194, 0.08887061954385812, 0.21864379185342023, 0.1407679819291638, 0.0929154871752666, 0.13214500350577216, 0.16290213131616194, 0.13608667909378006, 0.1839346309462863, 0.21760212678101756, 0.2693152680031715, 0.19325418247570916, 0.10359880544485585, 0.21079211075219417, 0.09620966524967263, 0.16665545652710623, 0.1498793567260427, 0.18459236339455654, 0.25016795753711657, 0.1016283966600895, 0.10927839745436946, 0.19192045404305383, 0.0929449815603514, 0.20166268692381922, 0.20078439776214863, 0.14810667523453314, 0.12649513570772064, 0.14403992813200722, 0.12121968572178196, 0.1601599195912, 0.07326926194852398, 0.1401867510210122, 0.10062539604522529, 0.12693925986006377, 0.272772898597102, 0.14468935618717826, 0.12905630553441663, 0.1635214061506333, 0.11817768847029056, 0.13825768034064, 0.11164940893650056, 0.20165144075309077, 0.13546392622013248, 0.13059867035237052, 0.12078696095775213, 0.1888115313504973, 0.14725535236779722, 0.0761246478425399, 0.2827582418197586, 0.1495055364625108, 0.17054471637933485, 0.05492784533529513, 0.1547063235193491, 0.18724765478362962, 0.1664045320883874, 0.14823645052890624, 0.24233198123833827, 0.1239315603649424, 0.17963928320715505, 0.1174031199526883, 0.1312964998425976, 0.18389485566125763, 0.1805888491893007], [0.08513991690931783, 0.08343868077762666, 0.054668493929409215, 0.0464435862827926, 0.034348004076990395, 0.026892465126189976, 0.041622912901784145, 0.0181023339785996, 0.03947936824613041, 0.023504468094136928, 0.04293230272108509, 0.04358777520997871, 0.03907822162633942, 0.10768079003619571, 0.0645299377520719, 0.01722460214589392, 0.01497046791032077, 0.0225374736117139, 0.020225454730192022, 0.02696717785100543, 0.004340303693747809, 0.025791617846416853, 0.05334274813292488, 0.01058544766443271, 0.019131092384697932, 0.018122150757980925, 0.02788099625538434, 0.04205006820660445, 0.07972067988087093, 0.022689061344511086, 0.03298991021790332, 0.01736624414221414, 0.02243881489360525, 0.024068088556129127, 0.0429363668175234, 0.04462273318260428, 0.07376987742440355, 0.06029679252195263, 0.06641017032727119, 0.008206480359207959, 0.05661599668523958, 0.010382557896176174, 0.02857597781375291, 0.05100108930961259, 0.03505276283249259, 0.0744611492019988, 0.060647197308078896, 0.01078299971507682, 0.029196761841435107, 0.022646828832465316, 0.0740560265858808, 0.024551158703322855, 0.03316894879624729, 0.05159546245610522, 0.01634315095631586, 0.01573149199342175, 0.056254533419926325, 0.008549009761472624, 0.016681135541969733, 0.012024987203579758, 0.007104384356118258, 0.026003083011375803, 0.13668605096397862, 0.038074634954213135, 0.031084383334664088, 0.0539944438083518, 0.06514178153367774, 0.033510398014538714, 0.049726066194594874, 0.049540508208015276, 0.06637964172348862, 0.029602156418766228, 0.019384684724613063, 0.04111878491277176, 0.03778236475022089, 0.038619710342778314, 0.054728547561793565, 0.025512558828678825, 0.014575131109825548, 0.02343684359784088, 0.02718579444673754, 0.09589028319404011, 0.027782414146068118, 0.10234098866461747, 0.03404233499520248, 0.010934993474473877, 0.05394931739917206, 0.03601699556794859, 0.04233466987047465, 0.09705879710494511, 0.010126321595312368, 0.0529788640297709, 0.06162622320135275, 0.04059458542014322, 0.01771278018432279, 0.018616451754144604, 0.05667408913253777, 0.019522950188407016, 0.016799691478691755, 0.033064707212390444, 0.025295545271928274, 0.03160746050848356, 0.050573439878081126, 0.014233312254110652, 0.014298818517296065, 0.03485015555915814, 0.07949522020475519, 0.04535225573025885, 0.04886854950699115, 0.05163633707730521, 0.04622734264440594, 0.06137152577960684, 0.03398369862547806, 0.04152357811108232, 0.06825780586129235, 0.05256542169879522, 0.08679283587562461, 0.08927884481606946, 0.035758318319436044, 0.022920544386931488, 0.01752696364306875, 0.04443120737109454, 0.046037820152818196, 0.12261598055521328, 0.06568300733042341, 0.029404277823144392, 0.03407089475301966, 0.08130200793065372, 0.06992122789304103, 0.07362085034049327, 0.006921321900952007, 0.06258246947019812, 0.02958178805607942, 0.09672167245298625, 0.008601448479889622, 0.12971068251757853, 0.05342374660915906, 0.05483957668465953, 0.03960265477578487, 0.06316412555714769, 0.05529924093054668, 0.0795736139820468, 0.021628334089332533, 0.03477346249705842, 0.029580491452267575, 0.04340766793898037, 0.02234124593556889, 0.0493680005292258, 0.07951772786797055, 0.07524590668899399, 0.07222051056282175, 0.02829043386173585, 0.012215125438336645, 0.047562940331596526, 0.025533913529568145, 0.034393839117500095, 0.028772347216163913, 0.06473818343252906, 0.03995799699858312, 0.01676222977919444, 0.03979903758473454, 0.03846402212436642, 0.017542756545627793, 0.018758570640197685, 0.04159123899655477, 0.07191402176695486, 0.03567600983285135, 0.06322309517511918, 0.02834121016935716, 0.047878319577824686, 0.04271103354591516, 0.041848242342952764, 0.05450612925473721, 0.07034992303458915, 0.04748047862742697, 0.04609605432638238, 0.031287906083068064, 0.021313743913666378, 0.06295109948804302, 0.02654978633678008, 0.04375072211147316, 0.020171365092298197, 0.04540218551072382, 0.022957241913724332, 0.008760596542889553, 0.015708911551853583, 0.055976144729122046, 0.06063814597925352, 0.05201560805641836, 0.076832038110062, 0.040018173205035354, 0.04883602524416582, 0.03657237100865572, 0.03592407676361261, 0.021087960565402623, 0.07408192801860071, 0.03895498106196042, 0.0443019645078288, 0.016152483163281314, 0.02722182356181645, 0.0336171178928306, 0.04504793879365729, 0.04590788781042061, 0.031381410944666115, 0.02096908095653259, 0.025234890260523366, 0.010647740188775765, 0.01795685771221836, 0.05983456571195876, 0.029769253601590474, 0.03868881147354841, 0.03492355444318345, 0.028894884894872387, 0.04966722298113089, 0.03318917734788791, 0.0065236035246221775, 0.02912306992877876, 0.01938409292169156, 0.04720609274602706, 0.09129508864134551, 0.05184432228786811, 0.021006785888945865, 0.026397618292380246, 0.03492740786544258, 0.031141439648044687, 0.003877368970631412, 0.040866519820185444, 0.07134579903175754, 0.009231506001895234, 0.03765933486002107, 0.048474581131050666, 0.02201419150937469, 0.061072674880345026, 0.024852288714159402, 0.059621252359882485, 0.028951916310395447, 0.05040116202566893, 0.027218378081376997, 0.030058227712288502, 0.0679920576212387, 0.0874986480020227, 0.06265372713847507, 0.048849267073937004, 0.04625351986877861, 0.03736634836381963, 0.11614188642030764, 0.025696630604685317, 0.032173329438533516, 0.03502574291140322, 0.08619105082846458, 0.08890325488943247, 0.03398352625569509, 0.02903673565015197, 0.011246208075223672, 0.07912124672363843, 0.025631587824694095, 0.018433538686123588, 0.02900581059586858, 0.013268973223955162, 0.10447219930469029, 0.03792673784999117, 0.026674679735855713, 0.05570278540554066, 0.02138056401764193, 0.05988382516548999, 0.07948598118438836, 0.04470561623513218, 0.026434237295160853, 0.05002031673587138, 0.012600918698515142, 0.025216837398587696, 0.02310262816477447, 0.05282739695582179, 0.07762606526094099, 0.053045264700607914, 0.017957453345579487, 0.10746965620426402, 0.02880368787314623, 0.022959739360357487, 0.027461409899255926, 0.010965191702839109, 0.0623346247049349, 0.10143431594535228, 0.0655294296842429, 0.05341933011227558, 0.011694331206531535, 0.014809150860885219, 0.025148615353710713, 0.04957541117384549, 0.06306021339109828, 0.04847294170289271, 0.05408493028352818, 0.03957721682625913, 0.02633414790785361, 0.04985568061050388, 0.026213512042417165, 0.02503258367669919, 0.05705867293140581, 0.01257468784798778, 0.039047769631349274, 0.036134184037725774, 0.06387960954358982, 0.032990898471325636, 0.05790894242724585, 0.05911739250164359, 0.06069882397329616, 0.05340943991717312, 0.05874607734562409, 0.051126735390073834, 0.03069925752858962, 0.025139669361974926, 0.05389164630023222, 0.08043917842329511, 0.051509032416487896, 0.026224599249901313, 0.031062927127124804, 0.0018395274509525588, 0.01071196708512763, 0.05059868630562579, 0.021048932216100154, 0.05587872898867054, 0.032461481919932755, 0.012281055922710128, 0.029430799787082983, 0.06272875395933948, 0.06486707006491, 0.06565658495791497, 0.02983400909861009, 0.028729340955314618, 0.04099095548172632, 0.046835788826067606, 0.03935434652732746, 0.0219185856516443, 0.059074024264250076, 0.05582582295661973, 0.028356752178121, 0.04459899594827045, 0.028618985989822016, 0.08195973271804471, 0.014344054094005017, 0.10912861960429339, 0.018961034272046342, 0.061890416282920115, 0.07034402415757218, 0.017057416862958384, 0.040779706736605977, 0.02138791080083578, 0.043634456777644735, 0.049687451532771515, 0.06026178996469225, 0.02762647694908083, 0.07817764856642292, 0.2097560994086727, 0.1764918416137657, 0.2611774530622267, 0.1288961012276911, 0.13644284869153656, 0.06015667887104135, 0.3201415552006614, 0.12050195326728207, 0.16916309212965353, 0.13289365526889602, 0.10956733517589108, 0.21662122780276885, 0.16346169725781487, 0.15742651787736725, 0.14511836542477533, 0.1271618160629465, 0.12084087056498374, 0.16128867353883483, 0.09962660891394462, 0.09246619192943459, 0.20795755478883945, 0.11118528222845447, 0.1502880952771633, 0.06406935420067561, 0.093628692050134, 0.10491977851357191, 0.11950627645297397, 0.19442856462011415, 0.1844498403971234, 0.16466968001857882, 0.24118281870840058, 0.1499085446759578, 0.12310287539636898, 0.10756333343564503, 0.11552202169813457, 0.19454238996390374, 0.1629472079296266, 0.17691548823589281, 0.12643424703949882, 0.061642575348096515, 0.17444669329110654, 0.1117446489872471, 0.11811666956712162, 0.14326362059481684, 0.17141577367100025, 0.15136621081300322, 0.12851612161724799, 0.14395814058521103, 0.19657042388233448, 0.19650083245529285, 0.1808703558579568, 0.16947649869947665, 0.0964186616962956, 0.11548898032596035, 0.17117922104174094, 0.136912445267362, 0.23744358951526306, 0.1258606693497108, 0.14505957583746604, 0.13781687334900902, 0.09970571515300583, 0.12026699410090524, 0.27183263292235715, 0.14649946873466815, 0.10385746737160992, 0.1560602153861715, 0.20008376439011868, 0.12643825367934283, 0.12895487549324192, 0.1943206534751, 0.11374098218737111, 0.10586542212554526, 0.10663785325783877, 0.18027846100589923, 0.2385310513237792, 0.1520902405102407, 0.13186147436499596, 0.12199525781456502, 0.21097843865713767, 0.13994445273232076, 0.060438108930905024, 0.2685103547428885, 0.17440857275599436, 0.16327752972081785, 0.1458307812290807, 0.12445708902011957, 0.12271803878848592, 0.17489571274528581, 0.07779935434941324, 0.2207892210853677, 0.11982439446353144, 0.13597585681465366, 0.2432227116678992, 0.18660518280681104, 0.0909600860529369, 0.07115208603922399, 0.1277897783344792, 0.1634810333170237, 0.1942358168983652, 0.10614786342146898, 0.21636054340389468, 0.11146871177780052, 0.20352956658649832, 0.08211867297969519, 0.0849147100422171, 0.17910006456077102, 0.13000443127126465, 0.14469885567743934, 0.16328626312315464, 0.1719621475785971, 0.10991608138166128, 0.148279857070696, 0.14471489755857378, 0.10042552370578052, 0.19228083712439384, 0.21877011975213406, 0.21396193743473102, 0.125572451750838, 0.1781433126738956, 0.11849262721596227, 0.1120073252147244, 0.1351264798112454, 0.11396045105591898, 0.25904788185031186, 0.15068580216217428, 0.12921641791059127, 0.14331851845547078, 0.13921086225778828, 0.1650854665786028, 0.20151529160718765, 0.11103240172228507, 0.2168517743027018, 0.1703641034903065, 0.19634327881278532, 0.07258918271550248, 0.20136644072349996, 0.14297177173918293, 0.15255876456297215, 0.11846608226938594, 0.22982789413823237, 0.13826353325238153, 0.14441388629136548, 0.11949964979242896, 0.09905786523895879, 0.1537799393577922, 0.17934841494406425, 0.11044986846466219, 0.15086341198653946, 0.2089162831825595, 0.23202498833979332, 0.17490849109186282, 0.21290035407629707, 0.14621068423073139, 0.15910190620249318, 0.18513951871183612, 0.08986490973902327, 0.1360370212745282, 0.16588967503799548, 0.13571039202713198, 0.10251813883622808, 0.13843556595665796, 0.13595822147063671, 0.16791413898669905, 0.16900909313511464, 0.13300011084685404, 0.1377441716049948, 0.125415388404602, 0.12589702788259716, 0.10663042220497325, 0.17705951276565754, 0.13342970231127355, 0.18682725637430148, 0.13502995273278606, 0.17393437965262323, 0.2564941430764814, 0.21868482352264468], [0.034266691504707264, 0.029530607637078054, 0.08013039902453462, 0.025939643270366138, 0.046523661623078014, 0.023873084705443155, 0.08552653850206444, 0.01827897853218019, 0.009695764860108255, 0.013232063107763328, 0.014661156080452906, 0.010785912764408897, 0.08048116770242492, 0.04118074610408756, 0.04343528540865068, 0.05181859705537077, 0.02616487886576403, 0.008408843442016553, 0.034991778403280244, 0.0472116851878743, 0.04430286466113983, 0.03631682705975348, 0.010304014731739319, 0.07664004115447884, 0.051222369976101384, 0.061152650629200285, 0.04178239708586086, 0.03659804644543798, 0.02767034888928456, 0.0683953722698554, 0.026714734642976717, 0.03457527172060744, 0.06897051277900897, 0.01583416309703382, 0.015610386899131683, 0.06537167685887506, 0.05975040329259731, 0.060229384445495186, 0.04031955219444729, 0.021286281576800733, 0.02861827927371187, 0.05762542477778851, 0.039305439474241394, 0.04077192328329529, 0.020456133380291924, 0.024279279844655145, 0.02957071808557357, 0.05769221232302728, 0.08274357089953077, 0.04206099262040469, 0.024307740011042165, 0.061749440783094016, 0.018770634609785293, 0.05423920506971979, 0.055260572642568624, 0.03036629656449922, 0.00723912773068033, 0.06283328282616793, 0.037383489581125404, 0.011872522300109269, 0.039239352899453336, 0.022213694211396, 0.020630824409665603, 0.031697598413654396, 0.045345862726530725, 0.023364042262396505, 0.08446854809599538, 0.057709587197149956, 0.0867587756065111, 0.039719169088188684, 0.033014222018180356, 0.03371248051764504, 0.0318355325444211, 0.07931874419051795, 0.062057645615911296, 0.017661917691809997, 0.056570123340333664, 0.08658079039906302, 0.019523222149620136, 0.036584620754564964, 0.053688027790837714, 0.034982466604560614, 0.027356482666706847, 0.017605449350911285, 0.03220703347676224, 0.06653832917612407, 0.007526493056737368, 0.022505100651253617, 0.0296707519315063, 0.044662688498295126, 0.030649944448903687, 0.038579712892251636, 0.028489021088687644, 0.015417333699822908, 0.0020566276713995446, 0.0062594664632342764, 0.02026787493377924, 0.04796802081287869, 0.05506488697363004, 0.041403968803464405, 0.012206617074327604, 0.04777043524588789, 0.03424638634427421, 0.08209074141397592, 0.058012134470646425, 0.04235653018939399, 0.06329211203621761, 0.0416405329240426, 0.0714246831053207, 0.03388153313989601, 0.01941206470702685, 0.04235565684916031, 0.05045870672010126, 0.025592888893199064, 0.008281721684691167, 0.023723739695044297, 0.019744196380939216, 0.030068259633656953, 0.07497277336135026, 0.046125529559269074, 0.0580271459635227, 0.01630389852629554, 0.10913421204614063, 0.08899834938347341, 0.03552662651805628, 0.039756764853072744, 0.0514157880247841, 0.010689376109850504, 0.03190426595298754, 0.09284988706631046, 0.07708562853475733, 0.12186667761735379, 0.07194969082070936, 0.019865581097321647, 0.025535277166073362, 0.011949749708536172, 0.015162608507389744, 0.05705107716963657, 0.04546537244271848, 0.020947320229043404, 0.10677080781709765, 0.04444309705567937, 0.05307591204801875, 0.015238389924859569, 0.06691874545668403, 0.05211473600338063, 0.08532324941047738, 0.050318623712706956, 0.036398518845559134, 0.017231217315120083, 0.01137582153352278, 0.023521345011108828, 0.02438450202105507, 0.04500719440740444, 0.006748200873018153, 0.09725173634867515, 0.03800367222978704, 0.03243980163167561, 0.007921013973593231, 0.008876271031406379, 0.039559370808063016, 0.0627590412454259, 0.017749922042111718, 0.10957129585045962, 0.009686976874006853, 0.027246231123084025, 0.046696514041433414, 0.04176867645113699, 0.010409227332040187, 0.03449796961860792, 0.0687113682168626, 0.03994306211449927, 0.07010485916849106, 0.06953391682116256, 0.028149557953339913, 0.07916402507333026, 0.028629527359660116, 0.07900589686487952, 0.09042882706008612, 0.040149530470972104, 0.017956712155512745, 0.016534412467491724, 0.03192141866161218, 0.03365335768208869, 0.01371015847149876, 0.01817110569156226, 0.037405016651797685, 0.014791075016311822, 0.10315353216062631, 0.050556957496390234, 0.03642073156492364, 0.048894117691464005, 0.005348142153853852, 0.04470113079033552, 0.021937956184809728, 0.038376665118360714, 0.03125982896064318, 0.029816400567670504, 0.05162138687146287, 0.07719571536947643, 0.005663468252732269, 0.05747580780617653, 0.0708158347274988, 0.009828023236965942, 0.02104011837453131, 0.0268874759785831, 0.0056931187282316395, 0.021134657454827142, 0.04299877233983528, 0.00884458755007795, 0.05801677696346756, 0.040601618107288115, 0.039364068183086576, 0.031759316372054244, 0.043715439932120424, 0.026083166012540463, 0.018874257577643282, 0.02711991663090885, 0.03747283075485499, 0.06247496052134422, 0.01795768125673696, 0.021275631039433425, 0.04022241990652777, 0.09214844930196002, 0.0260672447902541, 0.03843940771935928, 0.043704255048425934, 0.04509026898191341, 0.03558166993541583, 0.03356621901114141, 0.022944279706045505, 0.07799100656543048, 0.05420530950951, 0.06459687085401628, 0.018755130905417666, 0.050428737360503406, 0.04475758380947575, 0.03879624381360989, 0.0347442860384622, 0.03193483094594652, 0.0366288508408733, 0.00568495606139843, 0.025259939420427528, 0.041633542371733535, 0.04033601542394008, 0.03889115061610937, 0.05595167588082053, 0.05218256925863605, 0.035815330582761, 0.03565502285416569, 0.021294645341714064, 0.04472926919979434, 0.022674139866965915, 0.03435705157537614, 0.053964271435454014, 0.025613400897371675, 0.025864415351421605, 0.012876200902786468, 0.024647494259801124, 0.03220701815500375, 0.026294861003876697, 0.0172831044502316, 0.04281455117668356, 0.0365843411324726, 0.026805090883205977, 0.041383560221161575, 0.0316714154436223, 0.036626701964245695, 0.026482209720979297, 0.02460967824463883, 0.02451356293843879, 0.06520703690306795, 0.05411630158402747, 0.058257723106972636, 0.05794326699669323, 0.03061108080850494, 0.005566291914757101, 0.007704545296878825, 0.050011008767591375, 0.04754721254651104, 0.034743822555268006, 0.023185398219333544, 0.025413296816329804, 0.0741192594831509, 0.0062737674095607815, 0.03982387415523972, 0.07090320705526298, 0.020651001250371337, 0.038454177894539414, 0.03752519669491918, 0.05464777891193667, 0.025359764507400896, 0.03675104569523566, 0.03703735190473738, 0.03358632881915377, 0.03232816346890984, 0.04464551663747238, 0.017783382847424478, 0.015168305328716675, 0.046701344225796006, 0.0430657820505721, 0.039718272765317274, 0.02790631546128181, 0.06212565890182892, 0.020624745501986435, 0.03453291854971359, 0.011110539649493031, 0.061709692311142726, 0.12151364131920761, 0.06292073176272454, 0.12444380505551254, 0.03396950684668076, 0.023536649532616142, 0.07449950722436752, 0.009877586252837172, 0.059695628006011255, 0.08761733800413148, 0.016483996221194827, 0.033276001922786236, 0.03150197594696957, 0.04020303405160385, 0.09347001225837777, 0.08236755962453543, 0.0334105116405314, 0.014891322409253449, 0.006623784363675382, 0.01196921600269214, 0.05487770871109059, 0.011447774426591013, 0.024812731764189182, 0.020238878505845225, 0.02985408443266586, 0.019261710375787753, 0.05774403051022561, 0.03170494711206805, 0.06033037398611346, 0.05031330323207283, 0.009297837724819059, 0.013603915482939733, 0.036117391390425545, 0.020990998732046257, 0.060622349246254856, 0.03966706744845837, 0.03186426658724104, 0.037235623120420405, 0.04227970306190752, 0.09536585004459466, 0.05350188757743567, 0.012402855284181575, 0.02606551917720466, 0.03245560602555352, 0.056935382571311734, 0.08845231255456325, 0.15166886150836945, 0.16041239152752584, 0.14206124559765862, 0.1524491373810076, 0.09950178254756237, 0.14690515825585013, 0.20272390256004952, 0.08345758016671866, 0.11720174608091194, 0.10949742965280049, 0.12909718398605624, 0.18095424248566552, 0.09606319689942945, 0.11423443474115864, 0.13656988139114073, 0.13762191929403814, 0.10846031514266807, 0.12589739560480082, 0.12002121777303758, 0.12051134550523375, 0.10756344834883368, 0.15343861654400826, 0.12560317187660164, 0.1654501397523188, 0.20263076159021548, 0.12729363681207742, 0.1193016620292779, 0.20767574168501363, 0.1845438547071911, 0.10835660982035822, 0.1268239176621841, 0.11986750989190995, 0.114255617072265, 0.19675869765060564, 0.1287175567760583, 0.13070310345820843, 0.12841950260823773, 0.12561557484009575, 0.0810859864577651, 0.1168033267341314, 0.16528109479094708, 0.23095290957679673, 0.17773344031264707, 0.11094956463503261, 0.09430039794214311, 0.11084962846531023, 0.2132729485991501, 0.12228604180798416, 0.1425326194974684, 0.17450012026294587, 0.14797677736609213, 0.1150507014244795, 0.1611690259268207, 0.1269519539369691, 0.18185091775751885, 0.08733765462473517, 0.12432448686130586, 0.18722793568045865, 0.09438099805265666, 0.17256610065458283, 0.14506225714520102, 0.17949243947382898, 0.10935722024089868, 0.1621613396151412, 0.11437914108917599, 0.1978089888730357, 0.1434142181589719, 0.22880269995620175, 0.13660041765580255, 0.20652446475240493, 0.12693365209645804, 0.157156870249779, 0.195643580068023, 0.14798595509942503, 0.13032459473657992, 0.17577913469604908, 0.12009317641176524, 0.10383773294668044, 0.13163659691570267, 0.14666526548324094, 0.1260131361684011, 0.08160928579708261, 0.11167850495586473, 0.12859173449537448, 0.13960309927501988, 0.1613848328950905, 0.11374717983867853, 0.14495618461120516, 0.1747118516434585, 0.10498838934807048, 0.11849366909553928, 0.11197705708083608, 0.1511048216132387, 0.09816617719949254, 0.18922339554034895, 0.12251727012616974, 0.34109268097146866, 0.17107366944753355, 0.15334005167167034, 0.163727208010612, 0.10684373938748915, 0.12532062332836852, 0.3178646499591489, 0.1888289828334124, 0.11232122208081907, 0.1343914184478983, 0.13926335460235997, 0.18369645421062747, 0.10185899678617717, 0.14609469851899534, 0.16663373027357364, 0.17169974714277253, 0.22389587615766834, 0.09673287265843923, 0.11184441661762615, 0.10731451573871797, 0.10730135434817885, 0.16775903682554924, 0.14270480541932967, 0.1470484013759321, 0.10158356519476061, 0.22037565618032412, 0.17495061060593975, 0.12791108069640975, 0.10102042162250127, 0.14626388137619342, 0.20483347887714065, 0.1279562415795461, 0.1097853254947451, 0.14162361021003417, 0.17388035513220296, 0.2476200869967861, 0.18048018727812076, 0.18118501881197577, 0.09464370492365091, 0.1362553869764651, 0.18068287882112688, 0.18582484564713894, 0.16828507875963566, 0.2558456802920949, 0.11392288976499151, 0.11885507873469785, 0.06458708791122322, 0.1967003983595679, 0.16866297461092475, 0.2108805785856901, 0.15921827495819138, 0.10161308256248314, 0.16487900588300922, 0.12432612628946382, 0.09729354176670314, 0.08470542248218291, 0.13584551461521657, 0.11332801483090847, 0.16805742807205648, 0.09104482303824156, 0.14525506615398392, 0.2122348688182331, 0.1982656385629408, 0.1804388491737266, 0.15038230877009132, 0.056027629668073314, 0.2604875449211367, 0.1302341503962394, 0.14619271180802776, 0.09893574316294924, 0.1282424213845403, 0.12431183108879675, 0.169242428195092, 0.1778430828163701, 0.13421086684590386, 0.07486978050081, 0.13386571359249855, 0.1667778314121308, 0.1594821003175551], [0.0560284685343504, 0.04141074868159429, 0.07560884084312186, 0.0777520637418474, 0.09133569896221162, 0.05749702078079986, 0.035127498539945776, 0.014910326177825131, 0.004735662040465902, 0.027383667296699943, 0.01844384448392497, 0.007153239698269435, 0.0273451445654275, 0.04491575415276232, 0.03900972570502951, 0.051304356705757885, 0.07855311591899203, 0.04227856925177959, 0.06705035170119616, 0.05437478731055895, 0.05745480167529276, 0.02698725510028101, 0.04944383557285032, 0.021209925593387698, 0.049047113110822056, 0.039627265350352374, 0.04048072943283666, 0.04429478626397829, 0.019194262079714287, 0.02086847829031608, 0.06515531830729977, 0.017014437415186438, 0.06992070695325252, 0.014428648395433783, 0.004420380949253036, 0.018778059916991382, 0.05359233574821584, 0.05329350783159176, 0.02152764332300473, 0.044551571275317864, 0.022894095201345704, 0.02654421879279037, 0.06856231048943535, 0.04678784704376613, 0.07483877692251437, 0.05295036555898767, 0.0186615877394234, 0.048545980525593606, 0.05188220150528416, 0.05930881106084394, 0.022021951980047652, 0.016896819936171655, 0.02036341950447569, 0.021414494051808314, 0.03156246050381132, 0.021625574257585312, 0.03388002394668518, 0.042134514078497894, 0.055723496592573585, 0.058120903634135766, 0.023280454408978263, 0.09885512773067721, 0.038576663862312996, 0.06447801231256416, 0.026370134888096686, 0.08395839482545854, 0.09468469828847917, 0.03076896578403971, 0.06472942704755454, 0.04245880292728544, 0.033438565780318556, 0.0495654252177525, 0.029589054400041222, 0.026237057754769925, 0.06098727139854624, 0.044394385355014, 0.03444152042990731, 0.06304201497245701, 0.10374800872898872, 0.030589998068828738, 0.10095761007358951, 0.04180754392197536, 0.005404218353496324, 0.03443771297292363, 0.007961045419271555, 0.015194987213509458, 0.009520812403230418, 0.01881705953799669, 0.045351263646396904, 0.06599822186774786, 0.016174439243191195, 0.03196557213912808, 0.04047936579633144, 0.02410581647118013, 0.026589239864880522, 0.016119005120990258, 0.04209229880343041, 0.035417190858072815, 0.060098938824188326, 0.02271987723126527, 0.004110030591442821, 0.008760830199706459, 0.011922501876289326, 0.02284785030379651, 0.05879536361223268, 0.027670931116107012, 0.028258581841064077, 0.030041004140530864, 0.05600113834765169, 0.027020242846300526, 0.04244775593941731, 0.07390850869518134, 0.02501818505416234, 0.025683283437824538, 0.10178808768790576, 0.0439529501712851, 0.0593080181598423, 0.0445423782202265, 0.15651950041853613, 0.011005721584473167, 0.04402279057690213, 0.004186712162223675, 0.03930149412143134, 0.04680322242840644, 0.06130299155390071, 0.034395003571145, 0.034129443022632794, 0.04342297054526787, 0.03672958757247656, 0.04754549267912104, 0.009241289902298201, 0.06633549973729157, 0.017563391123868285, 0.022486383208043637, 0.05921531769056475, 0.053106540243231484, 0.006711330497637392, 0.017874434312445023, 0.03988575490732347, 0.040601112489258094, 0.08777260870462464, 0.006533677580826466, 0.0536359261511074, 0.030572424011845744, 0.0780158354750564, 0.04518366276076244, 0.04931083121787637, 0.03661107377059037, 0.021974760963911974, 0.11746220831428805, 0.10288553928295452, 0.04710659324642151, 0.04535260046982477, 0.06575335718451009, 0.046676461690015374, 0.0168533731747659, 0.011210351329927724, 0.05849311511302668, 0.03577719472589032, 0.01773783317466657, 0.04199971707778112, 0.11039179133912248, 0.06580431735323322, 0.0707687279810348, 0.06481100775061116, 0.04083190796776645, 0.014780958825271698, 0.0015734496733902264, 0.07367894278779145, 0.006071382301724366, 0.028316226126926563, 0.026048379875118696, 0.02865733826653131, 0.021161187079644973, 0.07471804146564777, 0.020408392696070577, 0.05847947874797448, 0.009515847195871174, 0.07488353943993008, 0.04708757511370125, 0.0320002414481414, 0.014619434932096591, 0.014995096679476481, 0.057389251362051696, 0.017023092293510997, 0.029694774533591928, 0.007251982686049756, 0.005670446356112559, 0.08052944656341307, 0.04435367927315735, 0.013678490311928816, 0.034349812044491695, 0.037802681401972814, 0.08325036104408004, 0.08132686748379662, 0.09658584506401131, 0.041595467801896796, 0.042992505740614674, 0.023660303784474254, 0.04122444375928852, 0.05446791295863448, 0.012002768738555812, 0.05603936230463367, 0.04413762332631215, 0.014722260210903422, 0.026173587370243286, 0.03244017318431889, 0.05415134244568406, 0.027884769238411423, 0.011316066675428903, 0.025310104772929224, 0.01725898417193563, 0.05881055130533153, 0.04141565930518893, 0.019631573795190742, 0.054224503842452844, 0.044193111074667786, 0.010907967807725074, 0.08213397175554307, 0.047471465602997816, 0.03494404729515795, 0.022641360879905766, 0.0352981714381566, 0.053972575828553214, 0.015275381437893358, 0.028838558280239665, 0.134232041516131, 0.016112575728085735, 0.05223666655740911, 0.021373742004676212, 0.02653619593700334, 0.012501209482340323, 0.030215231686710354, 0.09146180469542743, 0.06880490755241725, 0.06066605073189544, 0.023901406976003802, 0.030372996003397053, 0.08202130320451914, 0.03064990422928766, 0.035066215336442955, 0.08100676530551526, 0.108094661376409, 0.006977015535437292, 0.09007094142537925, 0.018215540706390337, 0.036918868746368155, 0.054428317704268044, 0.035644205692674846, 0.05079459030962279, 0.044532020711490226, 0.09223108720635215, 0.021223789869597363, 0.04083519065452199, 0.028453440135044437, 0.008588017043357175, 0.07805235488640686, 0.03285961781418131, 0.03134851895963713, 0.06183739533768066, 0.028668712756987062, 0.035930404649867166, 0.04025306725393861, 0.05421145353466273, 0.016585579479954416, 0.05843890290106497, 0.0433730062908463, 0.054243839901661685, 0.024971850141282045, 0.006572901282549626, 0.04608992562298814, 0.041150454987561515, 0.034594420088274826, 0.01651820396223376, 0.11612533126026393, 0.02858812222257257, 0.025856932587621194, 0.022469996587343277, 0.030975999130356698, 0.047987506259232766, 0.0448496560866554, 0.04260248271748424, 0.025842784858879544, 0.021983431163995017, 0.057801356869599516, 0.007236594852480678, 0.05135723209429172, 0.06279346540630346, 0.02285055267894941, 0.03907828674381299, 0.037264914492205266, 0.05456621353063853, 0.019648240037983464, 0.022807406607053937, 0.09127120968074569, 0.01480977043449398, 0.02907374535777396, 0.04495796942782979, 0.07715793957393016, 0.024037757219987053, 0.02782328110638886, 0.015098141250951637, 0.057897443447502396, 0.004170668844674384, 0.03466780748098128, 0.05873498439248051, 0.025195145619011698, 0.014587434481889492, 0.018915923184625084, 0.02012190645590665, 0.03019241375788566, 0.040624746301722144, 0.004701904854887436, 0.01583292299220639, 0.007513045819641482, 0.043257817310551484, 0.04308564671044869, 0.05145638685433134, 0.020032649551848733, 0.05893050918295499, 0.08448037649354628, 0.024033011305296136, 0.049178543155111616, 0.026970140696052584, 0.05692262337693284, 0.054525656835927125, 0.05958596635009012, 0.030576338721138817, 0.03873399533932248, 0.06885984371746741, 0.07732248759918636, 0.06282598200824953, 0.009509977047151376, 0.042766686003174514, 0.07678787314122723, 0.04039542171202841, 0.05507200776088623, 0.028877182518162077, 0.05325317330237839, 0.025158128250510465, 0.03431325815918465, 0.08615738892507169, 0.012691009680800622, 0.021643722880511515, 0.017297683103430658, 0.045778487899130395, 0.04021303915989496, 0.04629722518485881, 0.12564132305523082, 0.07767300346806165, 0.038032871671020985, 0.013973129642826897, 0.19446784960887126, 0.09197526746579716, 0.16384066563219796, 0.25511752904182483, 0.20315018452463612, 0.10888874215344269, 0.09455178969449575, 0.2216436236255592, 0.0908067075896167, 0.1662324840623525, 0.09397690965523643, 0.11062180157750846, 0.17426771983023615, 0.11061565755235572, 0.10977703642340438, 0.12454358034677084, 0.1142211814200686, 0.17504068722407665, 0.18397190878468175, 0.14426354919710468, 0.1724054673386197, 0.14641699170874012, 0.11766433295223022, 0.10726545546804706, 0.12688391766841375, 0.0965076657913385, 0.15590324397048644, 0.18921397265888032, 0.1332744316107804, 0.13013154057966125, 0.1692005691509093, 0.14260443257949046, 0.20507556266121327, 0.09901466554090863, 0.10856468696147205, 0.10252370829543761, 0.1198927371672565, 0.08499681168506223, 0.08098935978787561, 0.13659868629709368, 0.10602309834212066, 0.13444734286637078, 0.16304908230179743, 0.14150652133168715, 0.1945124206043059, 0.16791176411413378, 0.10710725831168313, 0.13736013172855302, 0.10318941571899962, 0.15615787627475877, 0.3671183731527098, 0.08745528742550843, 0.11618577559748966, 0.10334506180257567, 0.12305183095797417, 0.14073536190534794, 0.17998094309962567, 0.2542635861543879, 0.1683770399540663, 0.19748620538701936, 0.1340106727495309, 0.19844805941947047, 0.25919840280567447, 0.15557278428346882, 0.1524105112278654, 0.14855681317708186, 0.35907325485060293, 0.09033741744896097, 0.25954403103359286, 0.12322510472468792, 0.13290301686333073, 0.15290322833724562, 0.19091868682974772, 0.16538085476044687, 0.17307864411944346, 0.14917103183125296, 0.1274150464263174, 0.14633702745120372, 0.16511117648934165, 0.09083836234264797, 0.33882947338204233, 0.1763766219899539, 0.10204728587620682, 0.15006401455931126, 0.1576933922666696, 0.07144590374082327, 0.20134025583824805, 0.11935584742816226, 0.12338616704988865, 0.2061250265086851, 0.13881729224756842, 0.19953665503811455, 0.12384473195960446, 0.168793669210807, 0.10544348387948929, 0.11286917412953992, 0.16911982348369015, 0.17280076870754843, 0.17103947128259367, 0.14738318179884266, 0.08445629835008614, 0.11817142953194919, 0.17403850632329143, 0.1534897758955917, 0.10661807286763385, 0.18055630577427728, 0.13546821631250844, 0.15354585353164904, 0.22672202047561446, 0.1095335123940341, 0.13186962554051032, 0.17477958913772337, 0.0988850664467581, 0.12208092176625807, 0.1681503545372717, 0.19851313092775885, 0.14327900364033638, 0.12483317690390734, 0.3195175612645765, 0.15458514373148644, 0.12511810798558498, 0.1460442439683022, 0.24341631740812333, 0.14499476479907192, 0.14243174103959916, 0.13673374759814433, 0.2468317518791845, 0.09535550785761687, 0.11883599548450402, 0.15882331066794936, 0.09064885517281872, 0.18678127577708614, 0.08867389582578214, 0.06916857715095244, 0.18929710852042322, 0.11003547618466039, 0.06733415663362512, 0.1545231059313782, 0.08630943439540364, 0.13646937065547513, 0.182859028178838, 0.16213045095003423, 0.12431517889302586, 0.07231046460689076, 0.1573172277740894, 0.15109703815992803, 0.16544607948632012, 0.23884370712743652, 0.14519145021275168, 0.19692838612583377, 0.18891836997241745, 0.18286514156047376, 0.08574972289704508, 0.1379556425156132, 0.2174285465791341, 0.28836186855070056, 0.08388958480809966, 0.1370972716399739, 0.143981046614147, 0.13898906448195059, 0.2390848869277585, 0.230467117902252, 0.1107185967867413, 0.09035318353844267, 0.2143359875246402, 0.12408645568235267, 0.0596422125254908, 0.1024854958297745, 0.15067254884108422, 0.11498050478797768, 0.09353561236733392, 0.1032032129625159, 0.23612588764198367, 0.12673514339351846, 0.10978199301227447, 0.13356767474643647], [0.021670080135546384, 0.057433021795605464, 0.05071680174179135, 0.029431180915825313, 0.013874550406340391, 0.008401072437634632, 0.053686392193119374, 0.02217321795591664, 0.02851820520816311, 0.02433241761830305, 0.05093257806654419, 0.031827318166653, 0.07021782649380547, 0.05933871530296822, 0.04231168723274623, 0.0452649983156833, 0.004797550453428901, 0.03584147716361669, 0.04663872419886532, 0.02187073963033336, 0.041689505094602224, 0.04519363722553657, 0.01844220122532739, 0.02943117325494607, 0.029794572807487943, 0.01850372191608673, 0.05351796393252669, 0.08118481946087654, 0.07418030136895758, 0.0416855444200337, 0.11311965423726267, 0.022400322805849776, 0.038729318372544744, 0.08721142631745146, 0.15427294758058366, 0.026444435840652838, 0.07341015317867841, 0.011026684622911197, 0.11117957487341859, 0.06391111490947586, 0.09779120014319498, 0.09321447597035477, 0.024015063780450055, 0.05765203101139876, 0.024085702832728147, 0.0684934315241633, 0.06565080099408666, 0.005890541980343481, 0.016759443134369872, 0.010454608465454752, 0.048610588550687804, 0.09219085992944819, 0.03564694062656453, 0.03163917080288933, 0.053139731002550934, 0.04432547191578535, 0.026080147626118797, 0.03049388084740889, 0.04076835714400776, 0.020679896171655388, 0.03741848064706691, 0.054752709974925366, 0.014413612004699967, 0.029848300468837543, 0.007815406359206405, 0.08420729679205725, 0.07825153774671978, 0.033254214382219704, 0.07617553140247062, 0.027488125300395395, 0.03494728784707766, 0.0835364795620403, 0.06940030342628879, 0.026256910923327652, 0.04711426561698318, 0.0953064016216705, 0.01356674393924374, 0.08902139330823576, 0.01751062298764385, 0.01557673074139823, 0.006135078203383714, 0.07404700973101201, 0.09545915189289278, 0.024236532138480295, 0.02933770478252442, 0.03256377764046192, 0.03461932560669319, 0.030299011062109665, 0.04440322600966019, 0.030259266420597994, 0.02594188790798428, 0.07184863616261752, 0.022740529046484062, 0.055936082161121795, 0.04286656854674221, 0.04350223383235355, 0.032635207678521835, 0.08149922960588048, 0.05760615766649285, 0.04870690112452834, 0.0859985329330929, 0.042804871655760274, 0.014083744120603849, 0.03326868578310936, 0.06761096718330538, 0.03526435248673924, 0.028508031560528665, 0.03235936239962617, 0.04201993413810288, 0.013174877517045507, 0.027169836835274776, 0.06292125653295268, 0.04396957810968161, 0.0529924122947118, 0.04551650498122458, 0.012771483386806663, 0.03961957765803222, 0.026681421309589382, 0.09199537727380953, 0.009585708668906122, 0.011506448143101748, 0.053282219526027484, 0.04583622411554379, 0.020820000246467612, 0.046104592376298485, 0.0021946525357047757, 0.0215824396770087, 0.04588782779812332, 0.024230380452448325, 0.06326316157355905, 0.08932281826292315, 0.023715412319307367, 0.012596253223056275, 0.0495446642350045, 0.10930718703856392, 0.02503253005054449, 0.07283057702044327, 0.009824008936242712, 0.031898127673494245, 0.06667342112069169, 0.014133132851472305, 0.04653493843732342, 0.018203199029930176, 0.10727654842119064, 0.03323256856791916, 0.08739929405912276, 0.024145277660159815, 0.0402595445273384, 0.06252889694165319, 0.0754945558465777, 0.04739484148881128, 0.02890669605544498, 0.031579113340065364, 0.058328793083708134, 0.025157044236097607, 0.03888214525255946, 0.09827730591378867, 0.029429995394762487, 0.04178909269431907, 0.11240835692132674, 0.06038627542194821, 0.04099998765835359, 0.02370451471858448, 0.03340450934164467, 0.0697311155137516, 0.032118697793433265, 0.04255200135371378, 0.057294160698450385, 0.05123586461488759, 0.0037041133985058557, 0.06459996584923038, 0.01661342103034258, 0.043150396461808876, 0.0251343316443625, 0.059075008687232776, 0.033560082646867925, 0.024030186356075352, 0.0034979409434937785, 0.03191075663292601, 0.05098065774467203, 0.013789515604355164, 0.03051876912884895, 0.04561843680998972, 0.0491935201740313, 0.030635225984658447, 0.007447939358591553, 0.04480975056667963, 0.07855574360057231, 0.020970247325397307, 0.054568542437928344, 0.007838196996148796, 0.030898823432864684, 0.029559094616542422, 0.018315473045673103, 0.05246211091176637, 0.04690509680057726, 0.02567806446384038, 0.044357919569818244, 0.03930106894263337, 0.027800210368549152, 0.038797921546164064, 0.04819199427842133, 0.016392931349635605, 0.07234061782759044, 0.10212176494420537, 0.04613086153122206, 0.05622167207841432, 0.02488109553533216, 0.02773410847200261, 0.056254778568062096, 0.06960874062872703, 0.06474636525156037, 0.030960340293184407, 0.019655835799752705, 0.028258066646935, 0.027008454668365663, 0.007350973694795563, 0.06369726529585258, 0.01985641294008782, 0.053009603307732654, 0.04078211608312784, 0.051986803150465416, 0.03601729434223906, 0.030477814068416917, 0.03267746125798553, 0.013659048915630388, 0.048622313526368914, 0.04969377941902607, 0.00806610336557271, 0.03214650870030446, 0.07125205285246335, 0.0029736576599985244, 0.03408491799247361, 0.02321532161365594, 0.05524040154752232, 0.040619751408455834, 0.04482350184492046, 0.02101734449576226, 0.0731435699027873, 0.007531626803439952, 0.06787989468824479, 0.008475201020407821, 0.021032825217492158, 0.02875021302081164, 0.034018957822193066, 0.07428602916338752, 0.06741684816417194, 0.027518408756042202, 0.07098578367262118, 0.011048756573619622, 0.01556715559995463, 0.05692011826942044, 0.024818841315385316, 0.05615490751581327, 0.07761201520840968, 0.020786323021316243, 0.055635158994024804, 0.02133910333917987, 0.04805003052517291, 0.04771941379013081, 0.03782448426429783, 0.02590027401193736, 0.022402117366812403, 0.02664341951810545, 0.05823627647553241, 0.040256801932569475, 0.02641893277365354, 0.07360273236108404, 0.025725054381895932, 0.02533260286004553, 0.023061623308627356, 0.011505194631735645, 0.016246146988123655, 0.02998385015093992, 0.05059998099421782, 0.0801265839066717, 0.059574260526607116, 0.030046408890836665, 0.05671139761445023, 0.043989925404950496, 0.030543222655391986, 0.03074775855507582, 0.01608454074049669, 0.0405797616188084, 0.034944855517918066, 0.020892056561405623, 0.016109273889132084, 0.013908884551886831, 0.11251931709627952, 0.08100788379388471, 0.016683657886460423, 0.05704200668861309, 0.040137954882436225, 0.025809262766532844, 0.009005332906400005, 0.02936758604201098, 0.04702746402472258, 0.08671987366171614, 0.022237667017766548, 0.04632248310372234, 0.041369977482264085, 0.02415916491900721, 0.035320797845000224, 0.0645602212077187, 0.068797989778461, 0.007531307440536518, 0.08724632162240245, 0.0353713711393216, 0.04858751398240847, 0.03879079309802863, 0.06849245859249946, 0.024834427374204802, 0.03258255828592566, 0.06689244565824348, 0.029975381048937, 0.07287511737236092, 0.10349918337118241, 0.026834179241690907, 0.018719021351106705, 0.04096350655139935, 0.028607684277719068, 0.02266519579044994, 0.02640669260384335, 0.06154106103725011, 0.014149513726513234, 0.016293889587564815, 0.023388403858388626, 0.036570471110603506, 0.044749367516487844, 0.04289152003043602, 0.04270593523077908, 0.017161901679731185, 0.036267027514235634, 0.12512720911012543, 0.08298401525544544, 0.0494164134556007, 0.1081064361478052, 0.028650813112636248, 0.03542360684443866, 0.025127691577278802, 0.05386209062811348, 0.023257241944872567, 0.030402999836951498, 0.04867627675975523, 0.06331352419370125, 0.05238808383564315, 0.04813073022711662, 0.03557688188588908, 0.06798107192040452, 0.010437306369684879, 0.06048358007965069, 0.030160887324581706, 0.17086950701571282, 0.2379961534132881, 0.15764992443784592, 0.1695984598970221, 0.19412519380209908, 0.11122454423457385, 0.10096684909395634, 0.1850882367861848, 0.08745434513736157, 0.12435529125674118, 0.10263459952247721, 0.16854452209607249, 0.11643057899369348, 0.1461092235460397, 0.16063979706696926, 0.16733716752740646, 0.14760027579482526, 0.08172539408288657, 0.12483637149055159, 0.1198217744428304, 0.15745645659344812, 0.13905390616386168, 0.08222024091669629, 0.07370192542551987, 0.08058499559880265, 0.12678580478795115, 0.15059258458354782, 0.18590479458291687, 0.21099636511456585, 0.14340237443966253, 0.18668084165021298, 0.10351065936828814, 0.0608731511109058, 0.1979340910310707, 0.22896739353816356, 0.11254650555671224, 0.1286894413492372, 0.10049684649153103, 0.24875541397881126, 0.11498856403294111, 0.21832468558944043, 0.19449023469801874, 0.16110292786071378, 0.16069389819618196, 0.21152476659945904, 0.09319556125950429, 0.11368596175264929, 0.14214459596382034, 0.14696696622958108, 0.09514490262635293, 0.17802556495993369, 0.23303090774964905, 0.1433839883294798, 0.15089707388993234, 0.21590890392901438, 0.20641785595686207, 0.11632481289486732, 0.08157808303592667, 0.20499336142693797, 0.15205619556288566, 0.17885229640430023, 0.1171355560842541, 0.3579860535119811, 0.10118333788047876, 0.1255152862699282, 0.21207713131462375, 0.1342024245569783, 0.12143171587658506, 0.2800738697330798, 0.17012456311814247, 0.2025719720029062, 0.20239434685678254, 0.20475072605955988, 0.08442310376032706, 0.1561053686084286, 0.18592111225570404, 0.13924031067759762, 0.2911044020325907, 0.21304312222186597, 0.15729206944665602, 0.0973401045907409, 0.1774704116847246, 0.2503550668517428, 0.15021684910020522, 0.09434162113334864, 0.13757040754200953, 0.13875628100527873, 0.12470370804470395, 0.10170147378718662, 0.17271128963799248, 0.10573668104986991, 0.2076328560830124, 0.09574306407763113, 0.13932192968505044, 0.15250136925568505, 0.14086800236855784, 0.12519038838124083, 0.10227865975109801, 0.07253009435390273, 0.10893476871593345, 0.16480950638651848, 0.12470707883157077, 0.16459585978619515, 0.19098702187259353, 0.1648143787057169, 0.13020381331443787, 0.08950621205111665, 0.09143773421284654, 0.11812150358192383, 0.08351021806799597, 0.16349704455464117, 0.10800735033567875, 0.20714433713545724, 0.11116876537280698, 0.15462779950711036, 0.12103316629485739, 0.10621649723860527, 0.10584378014168433, 0.2428085185707577, 0.09742157038060889, 0.11479808393144801, 0.1618534182348559, 0.24581809498129353, 0.1895326499136225, 0.18203304750063729, 0.10764181148260833, 0.17884511049957047, 0.16689524204740602, 0.18296759815946703, 0.1261985677504732, 0.3149936894976324, 0.1419957910454081, 0.1738076074229133, 0.18289920182958727, 0.13035715347336185, 0.09867111341126504, 0.15407721211592998, 0.12385852920312075, 0.08998110995537813, 0.18722560677316882, 0.13650790487806644, 0.1404413067164921, 0.09746970368489143, 0.127215028530167, 0.1018828604250185, 0.31740475205644486, 0.0754421018064022, 0.10636182411784127, 0.1276555673910245, 0.16376148278434433, 0.10254083036054527, 0.1177590060979128, 0.07714429554799873, 0.16313908231114188, 0.15556549112642967, 0.10777669658343639, 0.24675866709120814, 0.24752130761982935, 0.1784465455960843, 0.18900064781548517, 0.20739995003227266, 0.10819124208102304, 0.15628777414319978, 0.12593706363752005, 0.14930423919952687, 0.15838181419718653, 0.10882014664070261, 0.09600076073360059, 0.1628909923977429, 0.1143724684633555, 0.1323816787090994, 0.08441126770189694, 0.14762949438825732, 0.1149662095873106, 0.16919942001902288, 0.10585947728325283], [0.0425103951185461, 0.01785628760473863, 0.05086129358518989, 0.030033818235801115, 0.022923976460832263, 0.03862293940337916, 0.03077958184745043, 0.015381591867715603, 0.039888623906599904, 0.010720966703018114, 0.052040364187691486, 0.020354272414659782, 0.04524510684272936, 0.04684699669239983, 0.015496564428171804, 0.03354482217541626, 0.05171779903673357, 0.1193953545824174, 0.10173620055279425, 0.0550540161859845, 0.0503089135482667, 0.09021554818196643, 0.04014689129807296, 0.030959629746634635, 0.023748145341092063, 0.017321383948588086, 0.028223630994738593, 0.13158122408053569, 0.011874580203795866, 0.0428239549059541, 0.036343988707108844, 0.023094687663439303, 0.05697599289217784, 0.022821466235684294, 0.059830099419360204, 0.037042404254598, 0.03343465873190472, 0.035850467205408125, 0.05922052325801023, 0.019517126004962672, 0.09730953768256212, 0.021284107802315586, 0.03086333249455258, 0.07002316355224579, 0.016442667692899704, 0.012513851848310761, 0.11655045643208489, 0.01600875070453772, 0.030226705768596263, 0.06518741739132712, 0.04457083838661352, 0.027514436590154807, 0.0413739534785911, 0.014428676166121038, 0.029935033113184958, 0.03791144673502253, 0.05190502709498809, 0.03126744387461053, 0.047979489149105166, 0.029115736552123583, 0.09585596245503235, 0.02893201143090283, 0.040852274415233446, 0.07113969839748836, 0.034483436930684314, 0.06234345386826223, 0.01030673530148042, 0.04741615022442514, 0.05028447151304253, 0.05577424991755717, 0.06785537221378858, 0.09567455283456272, 0.013402994560648598, 0.10094444868305039, 0.05852171317524007, 0.02044224803666434, 0.088091638359812, 0.011445206116824862, 0.04454214073296997, 0.030097190944117405, 0.037389702554191315, 0.056030360771523374, 0.09404813284955679, 0.08007193885503278, 0.029637678000595302, 0.01645571608547001, 0.052996621947855725, 0.05167030924630742, 0.05192434017155921, 0.051158754034869136, 0.031925559366842916, 0.09432171816907584, 0.08226790690734502, 0.0195795564251321, 0.012625018867003101, 0.03530697378840658, 0.0670882653925688, 0.03937951251564007, 0.06522217480045173, 0.008158460052894249, 0.03337057930747828, 0.0443994147222369, 0.022803143327755314, 0.034940132585864876, 0.02239871402120879, 0.06400729341792964, 0.021037839262956576, 0.0254114524596521, 0.024556889040996472, 0.04797906397030719, 0.0779054958313223, 0.07297228796467667, 0.04513028941507782, 0.035273901772715395, 0.05734887086756288, 0.058360616376082745, 0.06363690905873814, 0.05320498254150153, 0.02741573573721032, 0.023869813510006475, 0.07056800528399407, 0.0417917471889767, 0.028924300755944946, 0.04206609093554078, 0.05042954558326353, 0.12239593712072219, 0.051777898634393374, 0.02956848493927429, 0.03694206205827575, 0.019264150365826585, 0.06011596895874508, 0.040576486592932094, 0.0311184436037776, 0.0329136116910846, 0.03666252040514543, 0.07524502568788106, 0.08028529434194488, 0.012318065630332118, 0.0655979409273113, 0.057665621411175504, 0.048339707521541465, 0.024491396184349735, 0.07434708637095268, 0.08526691896540504, 0.004420883694453346, 0.06493954964342617, 0.02038133830102461, 0.013085681900021531, 0.03744188463315368, 0.02558587727347209, 0.0035423323870711633, 0.02381022336081632, 0.0032821208080877702, 0.0719189323905495, 0.053056449584302404, 0.016250879496275898, 0.060872626340677666, 0.014698487545003094, 0.05281054685192724, 0.047604814697537697, 0.035478600466083136, 0.06515191687691597, 0.07180812543318157, 0.0684637226344597, 0.05321727059180698, 0.018418944711166046, 0.012525817184078117, 0.03417778317065489, 0.021043763037831075, 0.0501995621579549, 0.05425640757405951, 0.03058191775644739, 0.039358655771901535, 0.04654862842853031, 0.03259256339421676, 0.05494699753340214, 0.016511711367075483, 0.013752499193463837, 0.04378857451581186, 0.018960660804183255, 0.05196433762208589, 0.07922676767432883, 0.015240702552780991, 0.008238634026999916, 0.09304407503335707, 0.05917195711405047, 0.05650803957494998, 0.02651789218127247, 0.03546727002568303, 0.0642577045777392, 0.09213747126200507, 0.06154361211003796, 0.02954687934458977, 0.013114324969900473, 0.020212601690042405, 0.03344217788488154, 0.044364339386623715, 0.08918931978123804, 0.022511405554870446, 0.03252161982198877, 0.030794943825552062, 0.00902707543930099, 0.04629919403082421, 0.032726303193598025, 0.05413243922615244, 0.026817547472854777, 0.02227493144962336, 0.03922672777046119, 0.024187910453146024, 0.017814767554462436, 0.0814807975304223, 0.021831977496584578, 0.06002202359659057, 0.05171499515493071, 0.0067073908904867795, 0.006050112828116624, 0.016211527474825422, 0.025697982749871673, 0.02251127915036294, 0.03362050400145593, 0.007544091053967996, 0.05279042555259601, 0.033889362558482156, 0.012043764976213777, 0.048383489446414095, 0.027321097065484332, 0.03152178698069146, 0.03986155418979545, 0.029725829822822448, 0.01752513460814953, 0.016563864717740687, 0.10591947728948248, 0.03362172208125553, 0.025890935400140383, 0.04208970559580673, 0.07391096017653905, 0.048252082384762265, 0.04564916842707223, 0.03967955468162414, 0.09322711642110541, 0.020871065752280336, 0.04440523699046143, 0.0189579488529313, 0.018993139101733125, 0.01773988054464421, 0.03491938309443574, 0.047537873934714064, 0.08847082123881386, 0.0015867544660126912, 0.015729246398193703, 0.16233694228914478, 0.041421117681649425, 0.0612103178977005, 0.07781166538235643, 0.09336446066417041, 0.08153978630059189, 0.009218665410674388, 0.04290036068508222, 0.030025760906057495, 0.07531543682900167, 0.060705891134397644, 0.04193565297511317, 0.08254987322875569, 0.04289682518931166, 0.006673937746053261, 0.08991983824319418, 0.02426568178399917, 0.043965506352364056, 0.06375322418828165, 0.048161821905523546, 0.04140006175505058, 0.030779329038435416, 0.053683032897571405, 0.03813285380601883, 0.03163988517987872, 0.03206181959549506, 0.04136187993290444, 0.06429125539838307, 0.03273715865948508, 0.02470420966405542, 0.008902017331321635, 0.06599401604504355, 0.02709571399816102, 0.07073652930557728, 0.10062374129530885, 0.04308944650655312, 0.05405680336538823, 0.06120988505802328, 0.03322069803553243, 0.022987508132392843, 0.010770436830728525, 0.053372843897030245, 0.0791840965769464, 0.04308808670048753, 0.013216030802727948, 0.019725647477072575, 0.07953566198627796, 0.04211189533253351, 0.04678534576669336, 0.04936677478854695, 0.017046176437889377, 0.06744543090462685, 0.0066591321393066364, 0.07838567208138206, 0.05822146033507682, 0.0650008519991271, 0.08924641631423466, 0.014232282823462401, 0.05421400460745058, 0.016530290914459095, 0.06951110272277748, 0.10379385143037766, 0.016360755656815825, 0.012638714603869425, 0.03463336416790563, 0.01649850975692032, 0.02561199895647024, 0.08019137196242809, 0.06712286958410855, 0.08585155896481969, 0.037465575902212056, 0.03962349236732529, 0.023457807593888814, 0.0940123565434929, 0.012150890881105537, 0.06888556894996474, 0.00956581911117199, 0.023116389019114357, 0.05904592798962709, 0.08647084912104953, 0.019838268147601236, 0.049045240025847196, 0.02892097593435357, 0.03643620654099411, 0.05407873263222076, 0.037288176752026045, 0.015788103018196362, 0.07468762011417458, 0.0998265348795441, 0.034041300776504704, 0.023386268388299693, 0.04139736895599673, 0.04903692797186875, 0.042135192066310875, 0.0595396984699032, 0.0213228756817238, 0.015401768708421339, 0.061731024029394316, 0.021212392396503882, 0.03601055659894501, 0.03784303508338429, 0.05926666090325002, 0.19512437163822113, 0.06847172059238919, 0.15010109321484644, 0.08729116074861058, 0.17796309815058786, 0.20604072619349728, 0.15733026659056065, 0.08686603557678961, 0.1175706557208492, 0.15913662530722159, 0.10481955889131754, 0.10847579011873854, 0.11999571470603829, 0.126672814479999, 0.13019797572445485, 0.11268418687846392, 0.15304765123273098, 0.15945991441126794, 0.21961552842009455, 0.1542338158094114, 0.14358527027070522, 0.23449874753432892, 0.08751019294704161, 0.07746566943223439, 0.10304391263954102, 0.08619193949045674, 0.11022221011620377, 0.21010869903670204, 0.12802492136195784, 0.1184310490686086, 0.12333700718778758, 0.11504559161802454, 0.11620098244278662, 0.09633035474126378, 0.22161218337714675, 0.11489225145910056, 0.11447941433758506, 0.13145330271893932, 0.1811294161504315, 0.12315906794561494, 0.170453536594587, 0.09461931268414182, 0.15769512362537846, 0.14252195555356242, 0.13143454888655295, 0.10552723261137163, 0.39234871285096296, 0.04274754912682599, 0.11389072173305097, 0.18700170991641862, 0.09284729002824715, 0.1115977286451286, 0.09396813028762419, 0.12398468856249126, 0.1469454238371503, 0.20470932666813174, 0.1309701770303711, 0.08713103305067747, 0.14141577055617688, 0.15398143580363644, 0.13834636267875472, 0.1499167111732306, 0.2158048691888971, 0.23996925882754788, 0.12561038076396913, 0.11105087210213947, 0.06448291527527956, 0.13043550894625727, 0.15469935211923816, 0.11247575733690493, 0.18240778706967833, 0.15866485304169117, 0.1015614788799036, 0.15554785578241273, 0.22013435380593424, 0.16072308614609704, 0.12047648850467899, 0.15336537853844706, 0.17681306228041652, 0.16018962848090357, 0.15323453072097995, 0.16993423623423423, 0.12788269713881517, 0.22622813891258933, 0.15231609855207706, 0.17480231130555754, 0.13138407901410135, 0.0991692774057869, 0.12439515847232073, 0.21060806578926503, 0.08315699024786873, 0.305887661994465, 0.2706109678312656, 0.11881971611611306, 0.09003058391352815, 0.12268962458737435, 0.11702308671609049, 0.12099686904900497, 0.12314499491044592, 0.222978439903067, 0.15453133371568498, 0.08780175068926427, 0.1956587026436483, 0.10160468623883302, 0.1328103049027343, 0.2148374840016327, 0.07502095263090826, 0.10550749818644217, 0.24144572476225518, 0.08240822357155624, 0.14231250711506413, 0.17233412923111072, 0.09386208073626603, 0.17089783694715271, 0.16114224349298786, 0.17639563629223456, 0.1712888941889809, 0.14176864597585895, 0.17633465569346182, 0.07417181311475654, 0.20670097141015917, 0.1006463179064374, 0.19208101075022452, 0.1186348820826219, 0.11097342827387395, 0.18877103594281983, 0.10058483168963464, 0.17013075310857068, 0.253706073328372, 0.1272028247495332, 0.18960982561111453, 0.09241833441680478, 0.1563666658776422, 0.0410666028338094, 0.12858707668079486, 0.21601508371531966, 0.16539714178971707, 0.09566127653083495, 0.1110914671012471, 0.17499758711745664, 0.09134867649164893, 0.19916185418203955, 0.13311153067456138, 0.12716535538915666, 0.16071157950547435, 0.11951533161223897, 0.13443172999447392, 0.17671567718348197, 0.14404798737697064, 0.11605559427651668, 0.10912180908264653, 0.07220642986677347, 0.07650463511386225, 0.1916951935497984, 0.1410205304742821, 0.1433346675889146, 0.09221521386456105, 0.11179393142341607, 0.15471216110933214, 0.20605583344736408, 0.13229996777109562, 0.2172859776164255, 0.13802990707899296, 0.19371742052176308, 0.26221727952361107, 0.16469679953109834, 0.11536959318384049, 0.14101809431468287, 0.1459258680622424, 0.111666239888197, 0.10523215852557652, 0.08522766462016491, 0.19857153747110598, 0.19601139420222854, 0.14721041365015894, 0.20527266176237216], [0.04991178122919895, 0.028090785603008928, 0.05797965234265693, 0.04847818940517403, 0.030252568896919973, 0.016826759280276396, 0.014801179716033081, 0.02257839611340915, 0.039107126123722524, 0.017620807498573296, 0.05907206690960354, 0.008662865748779188, 0.04881762764266422, 0.03344133135772521, 0.03466789558109257, 0.0677449329786243, 0.012716893876542248, 0.0821803660402375, 0.03690961440424285, 0.030605091916156874, 0.03033156022279253, 0.026556074003418608, 0.03166726899273213, 0.03627186152903784, 0.07781843759960706, 0.02801145145279025, 0.05153971040741571, 0.07962275086151016, 0.056250189701395656, 0.015936692474379895, 0.0701535823604753, 0.025226283262694077, 0.054304697926366524, 0.020045586861670017, 0.09493445061267385, 0.06531048941636278, 0.023507059386540807, 0.01666433523379026, 0.07878231410417827, 0.060770204215640986, 0.015290536572255436, 0.08855931971582676, 0.015198347466667334, 0.022544423944406936, 0.03558481089590538, 0.0681687404792155, 0.013444968518019925, 0.03886978442390119, 0.04421372267027055, 0.030362378024766525, 0.040334314708748174, 0.055180301949862516, 0.02728697167889726, 0.029017872650236375, 0.07637567953356812, 0.022393920226022605, 0.021985311909849127, 0.05003953022101233, 0.0613307124454408, 0.030183575018459273, 0.04852957475269514, 0.026355217240991134, 0.022709337776646982, 0.027990234647727305, 0.049021092934473876, 0.05072415618586445, 0.04159220426733937, 0.03495512492654305, 0.0749082074710919, 0.04289034408547225, 0.04000541018021684, 0.023997501214785923, 0.044433854204872926, 0.034480924162292675, 0.006934940071415998, 0.01633531004641085, 0.11950705786265674, 0.05014713110041715, 0.019833097054112344, 0.0559309455415895, 0.05167188738743144, 0.054548244938374534, 0.05628726452649121, 0.10558128777530887, 0.047268042446024, 0.03978036802201983, 0.02271137940096519, 0.014166647282939766, 0.04093590823392715, 0.09638919795472776, 0.04041821282777575, 0.005888224564372532, 0.033045210274717504, 0.03103857893767136, 0.010267682054320411, 0.04550623174215998, 0.029216773973237124, 0.02482594678088302, 0.09547950684904091, 0.02018986803088938, 0.037208227816248135, 0.04950293159532932, 0.030162197334932226, 0.06710874292278482, 0.020387518715353745, 0.029791004752980608, 0.009489207445914227, 0.012268674026633944, 0.02681206802897636, 0.03545192145412007, 0.07116428215897853, 0.08543931173100587, 0.04869580434094514, 0.06247188467832823, 0.03783954172244957, 0.045033191601114894, 0.01266681758176175, 0.021631612945648453, 0.0501645902442115, 0.031207794353606242, 0.025568249590334394, 0.03323353383870375, 0.06345532323804594, 0.023018980939542095, 0.04326414136636642, 0.024697540868674556, 0.04963326996432678, 0.03328319165795561, 0.09611245635296069, 0.05707456925583463, 0.0545149507571853, 0.03466699925822116, 0.04118414753447137, 0.08221489362298481, 0.025666310759862105, 0.12301118999359109, 0.006830338905039694, 0.048733028553185925, 0.021678459222218203, 0.05955416220991362, 0.007562484346225017, 0.02348717557446611, 0.04395407249009417, 0.041701923379854816, 0.043836263489098325, 0.05222499137744308, 0.10308633858878767, 0.030058650975866668, 0.03696213739233152, 0.0648777723132122, 0.04704172858187268, 0.02974525972780201, 0.03354791334019073, 0.02847375870201617, 0.03571920187002228, 0.06360626554176693, 0.016055714767125827, 0.014092923769156539, 0.0325064129766918, 0.09816009446137375, 0.028611792424213023, 0.006508265007963225, 0.03713277198614613, 0.11841767317345066, 0.02404473628097725, 0.03244959606578754, 0.013937796710149176, 0.07925542702357616, 0.011216229139526766, 0.02315655500898438, 0.09159636803932729, 0.03827484054190498, 0.03634360949358633, 0.055981055352716684, 0.04782486579290802, 0.03269135043205273, 0.01236095889321258, 0.011357994667524773, 0.043474604871364377, 0.03459194945471902, 0.039961597611827236, 0.010601849606891554, 0.012362815698819056, 0.0834865995772904, 0.060156694192799835, 0.028330078911817366, 0.07758075882109904, 0.033088118859356454, 0.06683053043220313, 0.0533022144208512, 0.08115380822170166, 0.012513356763989696, 0.022180001664486144, 0.08121827452052986, 0.01329557179668618, 0.004321800755156625, 0.03659418536229961, 0.029085175389604225, 0.07083487967329641, 0.048909703750283494, 0.053843555130785516, 0.021414712386866732, 0.0881368988343785, 0.045905329076753515, 0.02890999406395901, 0.04768115535919224, 0.0041297468217840845, 0.01964041253461713, 0.07682911165419125, 0.028995211769436157, 0.0649720547540534, 0.029245243715723197, 0.023252019140448783, 0.02290042691803988, 0.04266910172337967, 0.07720745183647641, 0.017671790649934162, 0.05567545521884196, 0.04482213820841524, 0.030879927874212305, 0.06357566032919192, 0.0825904835496218, 0.017797335223745436, 0.0083872321016726, 0.02760242370347823, 0.07718460709457436, 0.1072585376940908, 0.03158102472943645, 0.04622192257234166, 0.022015991815996748, 0.045488301454292196, 0.05029995414999224, 0.06706954986457864, 0.06824023180430935, 0.0718538762040196, 0.028371480218465292, 0.020233330114053625, 0.06904827836420267, 0.03632836817433277, 0.01768229946103548, 0.026935906141936302, 0.026821272575386593, 0.04280445413784154, 0.04478267701943556, 0.02550891608059887, 0.042015793432872144, 0.04565389518956504, 0.07271840642657011, 0.05988954401184475, 0.008006269983466595, 0.037866994483216156, 0.028192221389843092, 0.035924524925048315, 0.08049137965445557, 0.01427369849425891, 0.006548579906173532, 0.013338442076928915, 0.016180389831143043, 0.04124473742840271, 0.010876062160898602, 0.008692251923944681, 0.05140602423418915, 0.010284949676133692, 0.012010131801118054, 0.06919110779680553, 0.03151260350169915, 0.04870765955157338, 0.06306390976533294, 0.04944264047568844, 0.0372743526954324, 0.0105822425440795, 0.020739206698753183, 0.02698679353230663, 0.03894873744537754, 0.07245230578607129, 0.15017327401907216, 0.01189768254276245, 0.023459673017984437, 0.04380513733673481, 0.03752194082124099, 0.01338569342248863, 0.03332529968071369, 0.07993198991302522, 0.07048598024994135, 0.05689363844031769, 0.005625571798337925, 0.026314365602428877, 0.03309406753208849, 0.030714698030703494, 0.08014631067072192, 0.02667079758529942, 0.028518553778168657, 0.026203028129173384, 0.014046541933390885, 0.010875523984131795, 0.062942074972295, 0.03482031643450741, 0.0279450258840957, 0.032274326640031034, 0.027435688497198206, 0.061745886135125355, 0.038699004273380966, 0.013339243596419694, 0.05900788789374694, 0.06482708027526256, 0.010343878116879252, 0.04535143218574025, 0.05027774143062773, 0.05226930573342308, 0.04586791334253165, 0.04281940434368388, 0.029870080348524838, 0.015034533928208535, 0.015276954790967849, 0.03370540952610393, 0.04362415672550279, 0.056767525046222636, 0.016006866128243986, 0.02538739538360988, 0.04172870581368766, 0.05531694139203718, 0.01895559887822357, 0.029154469957575205, 0.015058800720820024, 0.020636866928168365, 0.023893824620773236, 0.03907423413869354, 0.0047652727751542005, 0.006593367800251731, 0.052864257276298544, 0.026185444496091337, 0.07815336357922324, 0.02222128997316524, 0.02894897453276621, 0.017801295898313967, 0.014255047126132396, 0.04831938703934993, 0.03152547952448649, 0.0365942734624109, 0.01931459150998102, 0.023545396341491612, 0.05164640347263025, 0.0006294243623063179, 0.008719771717404647, 0.07824910158712058, 0.12259946369956579, 0.04778507901656051, 0.05742137342871678, 0.06223394926036559, 0.07567123104367526, 0.10363018440623438, 0.025914019544518767, 0.08399548114187295, 0.15469889246648358, 0.15607976594999914, 0.1347150752741483, 0.11289271601145306, 0.19663636873085655, 0.1028011700198535, 0.1576069162617768, 0.12836448217351593, 0.09867367214493214, 0.14182057141536666, 0.14787534732491742, 0.1696748082195559, 0.1686522493799848, 0.25674790204052006, 0.07496570236980915, 0.10443515895355134, 0.16733143718973284, 0.11435642658222107, 0.16336461859605006, 0.1761811776387115, 0.17836239849848134, 0.11980587811840158, 0.1871426854162447, 0.18466823674257726, 0.1644817892942698, 0.18857035155017532, 0.17880064675644522, 0.18584035126672638, 0.08642361980051765, 0.14318301282342405, 0.15999271324084652, 0.20591795294275209, 0.07031459872040056, 0.13564666883359033, 0.15269517417876952, 0.22458587622930928, 0.14455415699030125, 0.09696489004718681, 0.1128081399046125, 0.11058276173688712, 0.1616114417030927, 0.10281636920427123, 0.14733738506272917, 0.169798745923946, 0.13907803793347653, 0.1651507372697515, 0.19710912158893001, 0.1351278587695091, 0.1335906573841649, 0.1799249114288438, 0.09432627639222531, 0.10896903582878652, 0.10014745677190443, 0.13644507034651696, 0.15875413292838683, 0.13293706181068576, 0.16441820399655452, 0.24063111282885077, 0.19406727755502348, 0.258788974775422, 0.1653193838654026, 0.13970623003138652, 0.11080373213776659, 0.10951832087049562, 0.16109966432615636, 0.1349460354615604, 0.10886469465349952, 0.10202226544459982, 0.1526425899036469, 0.20426508760259998, 0.1594063955088777, 0.1613430044944248, 0.08831901325573845, 0.14995423415976186, 0.16364270851256388, 0.31753409834158036, 0.16167899533625574, 0.08209632619494393, 0.15777130340856893, 0.1315834304137576, 0.09466452719343287, 0.14044608710513962, 0.11986730304817039, 0.1561631776031948, 0.10284672160783123, 0.10915642859594477, 0.10524868304210325, 0.23745518808643665, 0.18933358962737745, 0.16455383220266911, 0.14935631785661946, 0.10047538070789269, 0.09665681544931666, 0.09783255356934764, 0.2170315138514965, 0.13016262842762855, 0.1486342953097436, 0.37245662702668103, 0.23940495846252288, 0.16639186099411982, 0.08208350954397071, 0.1301265916516704, 0.10420523298483703, 0.08380439583091967, 0.1272657282289959, 0.1960186720375092, 0.10144429807100566, 0.1304372862702416, 0.08613705695156129, 0.0916358675327032, 0.1356343348180094, 0.14083794107840908, 0.18999267039039444, 0.10195343244460323, 0.11705257344029604, 0.11611632972715363, 0.10625572094032842, 0.15257249285857524, 0.12307942544500675, 0.12590881031487258, 0.09184021382562577, 0.19818777338631693, 0.10943497816521315, 0.13216463067839224, 0.0946313172819153, 0.13183135178781327, 0.10564399207191122, 0.1379603156519513, 0.09853024516374835, 0.10162524037784147, 0.17367433876760546, 0.1351277668389582, 0.24061994326691474, 0.13075470714078796, 0.22934158152389914, 0.1544280190982165, 0.11953433059276113, 0.1520350821796925, 0.14007242005919257, 0.14901294192719847, 0.08058288885701088, 0.07239314847655835, 0.15166826395978852, 0.16336130909621716, 0.1940567208634269, 0.17219332227062795, 0.19162644481947347, 0.11121042523412936, 0.1715146296567494, 0.18825100013805976, 0.0867046897990569, 0.18644548411811554, 0.17738008991845194, 0.1380387936989146, 0.13477964116440666, 0.08517897973257689, 0.16565866888530795, 0.10109969640090581, 0.11372450363611984, 0.12534241086893505, 0.1478132788812922, 0.103323680288609, 0.16662574763740265, 0.1488523239329938, 0.30218960236637826, 0.0886793120674068, 0.09503952723236815, 0.12875880294990155, 0.24539541362995104, 0.18554536145060294, 0.15949599715250154, 0.1503662515671984, 0.1375928998834664, 0.17017442012025466, 0.09641228784476558], [0.02098482789381618, 0.03258015276984342, 0.01222575395067613, 0.014242732262749587, 0.03584749861470154, 0.036390524718069264, 0.09105018565371152, 0.08138466115680434, 0.09631388385089175, 0.056569027834601944, 0.05250742884292718, 0.06166457356284223, 0.04078640234506419, 0.05163468615782838, 0.07771406578080309, 0.09664478020802622, 0.030302364611998204, 0.01820634190563954, 0.023712817196463867, 0.014033767417253507, 0.017653038732767586, 0.051901012794264866, 0.11272432222481697, 0.03770041249452099, 0.03064516980591561, 0.020772430016809416, 0.09011064776249471, 0.079455774337534, 0.07622810035583473, 0.024551518764647267, 0.0667394655606439, 0.07184279091175526, 0.02142503542164641, 0.053223847456636934, 0.028980753775085175, 0.02070289796158191, 0.04268737675081338, 0.042943215643566464, 0.019074689161272782, 0.02915991684271684, 0.019306509282379862, 0.021446478222647024, 0.04152165139995275, 0.0066236033754032714, 0.03883082885295153, 0.054539534518675464, 0.012936480531108477, 0.018746004883019675, 0.0641140439397385, 0.10481683161830711, 0.029602660121576443, 0.023308705816405918, 0.07486717580186744, 0.012166579404184896, 0.012694832459542782, 0.052932542523429285, 0.04752121152236097, 0.028201644271311742, 0.10847018235513281, 0.10639237570426158, 0.029572671609780485, 0.05009427103364179, 0.04880961436297625, 0.034383657808986404, 0.037312013577790036, 0.08937895718601443, 0.06424550079710542, 0.01486834455957456, 0.1091183310434703, 0.05430124670026764, 0.04294620721691078, 0.008094890076937455, 0.06789048202335835, 0.033935791317133174, 0.026078646093787208, 0.029904042941428004, 0.04992497709369467, 0.05737052051230304, 0.0314889888414332, 0.028059324287178538, 0.011700275091214046, 0.012051236248695323, 0.06772240999365045, 0.04384033141597625, 0.09563602627285066, 0.025737085792746757, 0.04512963824034218, 0.038964212421448007, 0.06944299750630895, 0.057925938087846005, 0.017621655940949436, 0.014182767688086437, 0.026709540566850095, 0.0593242860369144, 0.02714961019885396, 0.08503896950353539, 0.04181892798853017, 0.023574567054428404, 0.015376926392256735, 0.05063313727958068, 0.039930096076380824, 0.033390581863181244, 0.016167563604070775, 0.0249024368296828, 0.014458406123242553, 0.02079088315968552, 0.03389207834017373, 0.028054465374518788, 0.038728000701314984, 0.028935500961397926, 0.05899030617588471, 0.0370395046118046, 0.009206201160146345, 0.051224296687230955, 0.10652583588155047, 0.020905853804921912, 0.03851968990338426, 0.015136027171637024, 0.03430831306163342, 0.026154304937189145, 0.0586643970511373, 0.031036665633080468, 0.03110279242748455, 0.10881103785528291, 0.09651284454570663, 0.022670665658229304, 0.0715896218354183, 0.025836658070705114, 0.01485161415691818, 0.014838962214848688, 0.03447415194504204, 0.04929051456612445, 0.015764668388592622, 0.05172774285799073, 0.04723529218726101, 0.015913753886707127, 0.020655038533732295, 0.04280545005214311, 0.00853202271936161, 0.03146203020737777, 0.040472654866114746, 0.006403021285340431, 0.03980950617621984, 0.022934086906212955, 0.0524985192403678, 0.050939243031485434, 0.05627926656856172, 0.03663598311944835, 0.05693593032417759, 0.030725365805049098, 0.043793998418315765, 0.056511429514014916, 0.05215788207527611, 0.04517482593655587, 0.014224344237347045, 0.05502267935944181, 0.012660119100473823, 0.03745002431734916, 0.019225794258677674, 0.05442142291294952, 0.008097742796845494, 0.009014187925194782, 0.03515442270004461, 0.054109969867333296, 0.046878490566966996, 0.05991742195140931, 0.05509765255415151, 0.05722091503200993, 0.028696002724069743, 0.023726217989479343, 0.044944260284424796, 0.035321376241383054, 0.015922002738431817, 0.042002984442778175, 0.032138748229631496, 0.04414017056866039, 0.023371138151795156, 0.02337104813646405, 0.012759805334010913, 0.06227681954060832, 0.05270376568660141, 0.03462388766028228, 0.024201985403534867, 0.05897092415140041, 0.03684749999534219, 0.032523079219484524, 0.029595453149428772, 0.004836614234297867, 0.03871079819697527, 0.05281827667908323, 0.05835646800997277, 0.013217878989845276, 0.004583894277006509, 0.039092558961842334, 0.022102216927094326, 0.023897856158474763, 0.008719571576934428, 0.03512312800833776, 0.03216626227743203, 0.03395631098218503, 0.026788780871298046, 0.06942065838243693, 0.07362981356920735, 0.01600287002210896, 0.03759339001149901, 0.024859346299161835, 0.04338871492373367, 0.03675648108905843, 0.0611286529249722, 0.07094338070601225, 0.043184422256965796, 0.01917299356371645, 0.06569518812841947, 0.038217100495051955, 0.028169225345576004, 0.07347913173538062, 0.011982627329416575, 0.030451887737839457, 0.03796612626061805, 0.01357979137420414, 0.026443208184754177, 0.03679244508666377, 0.03155173144243177, 0.008710074001893161, 0.013318409835318885, 0.048774481570768746, 0.04605364752933384, 0.029529161646120974, 0.026219091077725735, 0.0105700722797924, 0.022358800840353774, 0.0847149066506855, 0.04234469030052424, 0.027828402404162674, 0.05782258516598133, 0.021120844889552366, 0.04156429185381821, 0.0923042409422417, 0.045733070376539425, 0.019864112123726838, 0.0386590642794486, 0.058843876130037734, 0.03299843677650056, 0.051099581403597716, 0.04367702445315738, 0.019718496046299418, 0.03776834151076694, 0.04297731421707619, 0.023460839386849154, 0.054188003583300504, 0.054491619549451344, 0.04593872667981252, 0.01390043843252164, 0.06010942656787173, 0.059527130797505386, 0.05965159327212361, 0.03114685205922973, 0.037097191032502926, 0.018818164619827465, 0.014810374686344257, 0.06439734325413743, 0.01833079097371909, 0.01590721819910311, 0.038273243248582854, 0.02895189332775772, 0.07784025578369057, 0.038933438669529655, 0.02826170364935552, 0.004162566507265213, 0.04654298236052837, 0.03670370146151512, 0.08589542515936398, 0.043419569114884066, 0.05047839517975527, 0.024591257660499504, 0.02582078855935364, 0.007999471431943558, 0.10860997807955551, 0.11644783129374828, 0.03771851898261136, 0.0631386416423465, 0.0013631991168949755, 0.03743376410115631, 0.05251499396117945, 0.030297536342855425, 0.019165574002169797, 0.026861218314978386, 0.019094785562746467, 0.036976007414200616, 0.05617150481069281, 0.09363518081485264, 0.002893975418579254, 0.04748710911841162, 0.13103861932552632, 0.03869719247544005, 0.02237504190434852, 0.019075993425963868, 0.01390444411475572, 0.020690154088961504, 0.018952061467233206, 0.07333805664412438, 0.041425480552378206, 0.05893690218668311, 0.049342371057719, 0.01635314074284848, 0.03393822747673239, 0.024527892613062457, 0.03536918395829778, 0.07270685382067196, 0.01044051915091733, 0.0768467316764497, 0.0312607808248891, 0.0006276980310494471, 0.06919460115774025, 0.07276347537915553, 0.03991711854694351, 0.05422211747856871, 0.021901398469063065, 0.029199215238012617, 0.04657218563220194, 0.028331727916074377, 0.016509916806112857, 0.11492343123761878, 0.0486161541794577, 0.013710427559882164, 0.02067515217218428, 0.0429605637046118, 0.017095776800546917, 0.04866770806632215, 0.009327236348913323, 0.014308069986591657, 0.006104755964535739, 0.0551611842257121, 0.1015662056423964, 0.06355792156330521, 0.017609578564823154, 0.056006826550489476, 0.052264341483673746, 0.014876878779051046, 0.023788029793649915, 0.016840006855707017, 0.024144205137065822, 0.02100201699161722, 0.01725322319074504, 0.06385055182862186, 0.09558666722788926, 0.07638243642906029, 0.025410406749635458, 0.06109394914200229, 0.012239826028235258, 0.016476473237778393, 0.02127321786247194, 0.09951996181400553, 0.12362449700313231, 0.12594357538487644, 0.11995789294521655, 0.14881765079354087, 0.1312128123977492, 0.24982226802216423, 0.2620845930951257, 0.16370097716008464, 0.13999049461657, 0.20628385185714693, 0.1431785848352217, 0.14649360050116816, 0.12425202260454818, 0.23442318062147788, 0.2492669462076118, 0.16720860265195372, 0.12895858335879543, 0.07113904722275273, 0.060364507033579776, 0.09468095211852944, 0.16852432801838846, 0.19757182337343696, 0.15954061411321163, 0.16517592624070185, 0.21890202477093668, 0.16272004753831895, 0.13563683226464257, 0.11031930409972707, 0.14697815111327558, 0.10855464354878473, 0.15600465868990268, 0.11732625069036601, 0.1294545333592161, 0.15552674239921957, 0.05953443927630302, 0.10961330811222715, 0.15209995450512057, 0.19307364619547324, 0.14599558206335192, 0.08985735611208985, 0.10100538331654765, 0.19185398825474326, 0.1560667271335279, 0.12925818502422304, 0.07057118454887983, 0.15820490917371166, 0.08369510572764181, 0.08378596375546149, 0.23005796566365228, 0.20547326954622425, 0.0637691090213916, 0.14054178680864074, 0.14585950952624122, 0.09498633008690612, 0.21836139652277195, 0.1406121902888821, 0.21916672347053406, 0.12667461478662106, 0.19705805416789748, 0.14844671102060428, 0.2057207465892838, 0.14778448929709775, 0.11702667966845537, 0.14313690965214085, 0.31231342364222775, 0.11715869960044661, 0.07045332958260853, 0.2272276385056396, 0.123316859075379, 0.24892445894018297, 0.11932356448303308, 0.2690953088383521, 0.19536902947771936, 0.14013646500966243, 0.10253886151457987, 0.1164710284360955, 0.19657108271794935, 0.12262438453974263, 0.1201758526205536, 0.07024198124605803, 0.08373319561923705, 0.14267598519161825, 0.1724706460992175, 0.18571036146773448, 0.10817388252865885, 0.2513125082177501, 0.1242182917532421, 0.11223253208182513, 0.3272261524633054, 0.21412699873889648, 0.13362997301643895, 0.12687568222322773, 0.13069810856494213, 0.14559248191935403, 0.12405028101056816, 0.15716992438800875, 0.1529509402931698, 0.05580207423096704, 0.17803020745275483, 0.1249782816176453, 0.20611094581263684, 0.18867093889463335, 0.11088545839752882, 0.08383530747866438, 0.15871596642799918, 0.08890948318425687, 0.1885449174310892, 0.18926111770974052, 0.10557484497586567, 0.19588374863228492, 0.1668754616572011, 0.14704875377637727, 0.1869841665029526, 0.24634084273730558, 0.12625827664329162, 0.15976694712956108, 0.18416886999001428, 0.11400701387995675, 0.1559517220143349, 0.1168650734208284, 0.14254176658728432, 0.173668960830377, 0.1863523431482815, 0.3968646479470115, 0.1316198655554364, 0.14555376383566088, 0.13435129076242447, 0.15169588909033807, 0.15633931653874536, 0.17888149967597378, 0.18036458461034685, 0.13633749628018949, 0.20150499538548533, 0.1428232732559404, 0.11489232806789298, 0.11387873245703597, 0.11953263753844846, 0.18756628607309636, 0.105531629956057, 0.20724950568570247, 0.1115614850254309, 0.12124130472300515, 0.12450259464282183, 0.10645137213531042, 0.1465282736406211, 0.22520525831609006, 0.13774037180889037, 0.07457920335113041, 0.1837284766858624, 0.15968178879589806, 0.11140866580629542, 0.17939248032146887, 0.11846678707027629, 0.09927384074657195, 0.1274991782021619, 0.1853383491717039, 0.167036876382847, 0.1544694338114031, 0.2305664488625142, 0.10779752651409757, 0.13429827747806428, 0.11955589596782962, 0.09600956308385057, 0.16530983840986607, 0.08920288719837705, 0.16467835213388168, 0.18857945267471576, 0.10504435207093916, 0.14960687457313462, 0.12192409590727861, 0.22218840407027354, 0.07541296748264183, 0.21690524723981658, 0.10007708393518003, 0.13344326206753332], [0.07396955824186725, 0.037297833290311604, 0.03444245122673531, 0.027082972040760423, 0.030296551919872725, 0.024498645291333238, 0.057250463043249426, 0.05298022000539688, 0.04973851512336443, 0.018935942977306344, 0.013812429294170392, 0.03190144674942619, 0.022206552356721896, 0.004593690147533292, 0.027993590112835653, 0.03068513661292532, 0.01928489028115667, 0.030497176940703107, 0.07424220893411868, 0.09858038561839251, 0.024061584469651984, 0.08077356048048505, 0.06273331601292857, 0.09074369685784464, 0.06926206286035239, 0.061887501318368225, 0.04510516173116142, 0.04120230381827682, 0.06374714145016286, 0.056216703998225356, 0.023443512393221743, 0.042726891565947764, 0.027752262840588248, 0.085931615152907, 0.05437438894483832, 0.030055473626200712, 0.06779018579231155, 0.023882180084324172, 0.0869417940116217, 0.007259983995613913, 0.09577048236444112, 0.028723239064997727, 0.02789446025065357, 0.03603930787874326, 0.051105832681059844, 0.031161084057643052, 0.027780956663792173, 0.030892217839737574, 0.05099574967678036, 0.05663408402113184, 0.0950354746272487, 0.015325085222420674, 0.03441379187748798, 0.0042714807486552145, 0.06299615694930957, 0.047517733483184735, 0.025787444582449335, 0.03615399124100804, 0.01091460021392953, 0.09991352416334615, 0.05155360724236216, 0.02056950290176657, 0.061383587833974636, 0.06790242533409788, 0.03694287411147549, 0.07444625645275078, 0.05851889397167872, 0.0600466380015977, 0.08196249063457213, 0.04646982096375958, 0.03146376539652627, 0.019019142041103016, 0.04576190209556972, 0.021556614853081205, 0.08319797595181773, 0.06320897617467469, 0.07632353192856235, 0.01799883933046893, 0.012503388044874997, 0.025150917447923173, 0.014036429572790382, 0.04396899205241953, 0.020720284327023455, 0.0663758802317804, 0.027859051666793325, 0.047389095829379176, 0.03350893861704296, 0.04073818477110998, 0.062066156852750055, 0.0655834082393877, 0.018864273536770094, 0.019357473281542623, 0.02707714977253589, 0.044993431637844736, 0.0035925408320186003, 0.034444278346434716, 0.10049084036220467, 0.030177511432538592, 0.015315370269930892, 0.04831283698759733, 0.019355219067825426, 0.020035847968932603, 0.06795686354199726, 0.03125856300034831, 0.020666899490019968, 0.031992973188959786, 0.02812345733775968, 0.06200586573310918, 0.04667104544839071, 0.040318889528392785, 0.05093487249987741, 0.07274395545884486, 0.06550997871184541, 0.026997350223903215, 0.051535837832958474, 0.0325890087462481, 0.06535421771508071, 0.04710978783306576, 0.07566547006248467, 0.04242583816390365, 0.029422771185636524, 0.015821717041093978, 0.03480775259254921, 0.06458847453036616, 0.005732311307632875, 0.011746771840168344, 0.03086756513033423, 0.04965054141657968, 0.07532381783089331, 0.00624636444450927, 0.015269104304963784, 0.04047235226138465, 0.07265679763569947, 0.034957492138229074, 0.0639570840153723, 0.04431619842146193, 0.023416641859277602, 0.053530305608986854, 0.030686287660031553, 0.06082931555987847, 0.036536407011050376, 0.10783612968460207, 0.025699187423132604, 0.02775660655911892, 0.02936348938683589, 0.09201322712244527, 0.07874881307924948, 0.033816070926766244, 0.0577594020644263, 0.054684275340649395, 0.03790007032934697, 0.013771088316946501, 0.0429489306594816, 0.060459884980152694, 0.05700678962673392, 0.005168668341807901, 0.049143904489615274, 0.006307989514748296, 0.023192693291592504, 0.021476095181799704, 0.008996683773734878, 0.024712425957043326, 0.0773835065023553, 0.024913543189365058, 0.022022327363130548, 0.05632280334529858, 0.016812425775213108, 0.009310280907929186, 0.051146638354346644, 0.07795156835908852, 0.05057940387257165, 0.04157317081286062, 0.04133689397525403, 0.039662470920912685, 0.06588985873085838, 0.024302984520252195, 0.022448473347110615, 0.00530112925316057, 0.04557538266864516, 0.040387653580476204, 0.01901156734675169, 0.022755486913205638, 0.05127171369930429, 0.04884868101667493, 0.03692051966584498, 0.02023604972618482, 0.05700942113875382, 0.009225574566141493, 0.018997563259495844, 0.008442109852518526, 0.027747672058702, 0.029853603712493376, 0.031861211811642975, 0.0408909963293662, 0.04684318923541615, 0.0426969375281084, 0.03704585931113651, 0.04156937101675619, 0.015676869924420554, 0.0616763981299535, 0.0666265671832427, 0.020625425405019236, 0.03337566613129551, 0.0027792152081195626, 0.022189648626672647, 0.04982690251762829, 0.05189534374362519, 0.03810972561158481, 0.030524327096739606, 0.03050964502167077, 0.024128123036315365, 0.06488891123163124, 0.019128882221036383, 0.060652257318818764, 0.024481557700182163, 0.03550106982490228, 0.05068873994112496, 0.020049953562838417, 0.00610110316155178, 0.0483661835202046, 0.06082952623405765, 0.02290083102941994, 0.03570467684297793, 0.04250823092016001, 0.04658205284466667, 0.07300400400474187, 0.009829513277978668, 0.034332195852672866, 0.024392494233325127, 0.018825023021969586, 0.026288772520098477, 0.07321523742810374, 0.05032825343791516, 0.08182405854665464, 0.02848015553618391, 0.02913512623748712, 0.062485325690959735, 0.0731735852276606, 0.011268716696048937, 0.03138751858064244, 0.02906251642402382, 0.03724418415297424, 0.04415686362453046, 0.019203192749691587, 0.07198666222393513, 0.06464599241172114, 0.0278626618561365, 0.007110165925921813, 0.06407318847073663, 0.05116140852952677, 0.015980816265988736, 0.0544261803189593, 0.09870076867481394, 0.050222747808983254, 0.02963925997215894, 0.03761820742980607, 0.03837450858085387, 0.03929623109739154, 0.034098328361588146, 0.03579328640273983, 0.018047100954478788, 0.02040848079618187, 0.009394425132702435, 0.029922381171115467, 0.061420099584445845, 0.032309620310702634, 0.03928263686717518, 0.03767848705812808, 0.044563453299023455, 0.05135266237982339, 0.03813580324452731, 0.03829383186154789, 0.006231679017805765, 0.030473845732969143, 0.06687262696364234, 0.029267988866195086, 0.06722965457987401, 0.014401829572424535, 0.07086216772515928, 0.03029795769121378, 0.02096657010336076, 0.07054176677258746, 0.04158006560417914, 0.023870539378314733, 0.052081798053076195, 0.08729396463041345, 0.03183701109411496, 0.049945477606548425, 0.03204100881703198, 0.07580927242675135, 0.01227213099839226, 0.0738480260535594, 0.04607611305771336, 0.05435108455018171, 0.06277850370914226, 0.0544846864537366, 0.03147704936113329, 0.04658355437699826, 0.032974956181621363, 0.017395705968562155, 0.047520552686746084, 0.05371292947881645, 0.0475574053463436, 0.014582414690765643, 0.021734925647897106, 0.027340358431120555, 0.04491171686940136, 0.006933598938743554, 0.06061486073679501, 0.048601288243287036, 0.07589060032079298, 0.09033357934846033, 0.04761434483131574, 0.032725675001500115, 0.05383924971665106, 0.035457207460797606, 0.0482999628800298, 0.010059433501033534, 0.05896622037154533, 0.038083586691608357, 0.06589824739362925, 0.02809194048055478, 0.030624065998821493, 0.03379412633817523, 0.04068234079186955, 0.13934812989206086, 0.017753650975083152, 0.017027759684189674, 0.020720008535370715, 0.009298160439357162, 0.06638262946639331, 0.005394684868083606, 0.02895951590260431, 0.08720532059669496, 0.043015768000435446, 0.018672117617942633, 0.02877038986151738, 0.01633361124643876, 0.050974931237438036, 0.030789956593164997, 0.0644760128230818, 0.03509853275552873, 0.054603813125962214, 0.022946114486624158, 0.009115511671670023, 0.028782576405172868, 0.01988796618646912, 0.02941175675650518, 0.05298872358135639, 0.02523741068979425, 0.052842312687707525, 0.04253057387447165, 0.2082868193786952, 0.14088991248319227, 0.07303933597980969, 0.15257226303219795, 0.07476346281867835, 0.07696463260799646, 0.1665905535581612, 0.16020161009603934, 0.16265011903259063, 0.09903412417418535, 0.11878881212924758, 0.13238088197765813, 0.23049443659763183, 0.07284630480552874, 0.09330535698081217, 0.09964497204148963, 0.12308413688574107, 0.11343086213474313, 0.2768137366060288, 0.15547636445731888, 0.2048934635616118, 0.17672787330323653, 0.17970277657431943, 0.1464216801668367, 0.14038659271694, 0.13130644366385477, 0.12308617467961966, 0.11797969304626027, 0.14617516839456174, 0.14025554571661258, 0.10172176745630081, 0.08312071598465405, 0.0859645645945303, 0.11350250667742184, 0.11326630644860769, 0.21449933279185526, 0.11326728704115076, 0.14905739034856522, 0.22941552433035067, 0.12290406791913895, 0.19897799308021225, 0.09823427475508183, 0.0642280110097941, 0.16506200896636133, 0.12538483681818172, 0.13214734773482048, 0.1633445624141924, 0.07686594516159066, 0.20911831588995075, 0.11585071172204711, 0.2530737137121539, 0.10697552949310311, 0.08667709531202432, 0.11123639561476246, 0.1796359277420467, 0.16899890416572172, 0.08855020326952781, 0.1230039964279821, 0.11664118422495744, 0.1196485466413921, 0.1426881659896143, 0.11951740004963453, 0.12578360090452817, 0.14348141939168976, 0.11782744073218877, 0.13617027460807754, 0.21635331153388948, 0.11326893413018797, 0.16140482778991425, 0.10557690575238197, 0.11150049676577892, 0.1738123724898023, 0.2241721121414054, 0.19659665473286184, 0.11175251671022947, 0.1024932639613267, 0.30248828472629674, 0.1683709572159475, 0.17408364422379002, 0.06274535125421901, 0.07283256884904639, 0.23740399809133625, 0.12687547537948818, 0.12222177469201627, 0.13911648022551693, 0.07491216814566044, 0.19981491349397168, 0.1226783554340082, 0.230019431441061, 0.11447517787136378, 0.15812718189291416, 0.19711267623689868, 0.1401542688930227, 0.1757209886225962, 0.21072020573962122, 0.15716918894360143, 0.20546190080142793, 0.17407923155734617, 0.18767412060931807, 0.14417981578698083, 0.12303611849464717, 0.2095885406578741, 0.18388269018502007, 0.07622693590218983, 0.13008448745935194, 0.1728776839351462, 0.12637869034323002, 0.18991779295667527, 0.1800353046987326, 0.15511803449161593, 0.1242508275073863, 0.19240289025249022, 0.1054837188172725, 0.11305417670237441, 0.08858922012751141, 0.15608223275311534, 0.22222825596409462, 0.12939422691781677, 0.23359700076041684, 0.16063918419662984, 0.07167368466334958, 0.18110851727185712, 0.17044857234483765, 0.2257731133290837, 0.13323951332319167, 0.09208625062338768, 0.124212009832263, 0.14251748160008462, 0.13096083075769488, 0.1298693546484555, 0.17706473748530113, 0.1440123642884916, 0.21836583983273278, 0.11702965208960157, 0.13858976413405713, 0.227277250359616, 0.16368625295017997, 0.18419798133113693, 0.20334035819095952, 0.11869711140471122, 0.16514906719807657, 0.259177626501168, 0.1419878084092371, 0.1102596947983388, 0.16207141621458918, 0.12176410610517188, 0.22449613668985907, 0.1601144292902562, 0.152915608318102, 0.2485100666601812, 0.1314458869878323, 0.10444293474598278, 0.17117565107201377, 0.16622169754437863, 0.1934571957756435, 0.13933876829762615, 0.15061895332990155, 0.2987471403133485, 0.13970627599666197, 0.08829256023971305, 0.16029743237360833, 0.11637169747583329, 0.12166917248959504, 0.07480527589758558, 0.17805246996783441, 0.16104787678247498, 0.21723069671180942, 0.18516481493509587, 0.1610538522682844, 0.10447027642400035, 0.12750012049030873, 0.19384509673522365, 0.17995691858232024, 0.07169033175394421, 0.11575870456234102, 0.19068726698958105], [0.05372740087970611, 0.052770813701734434, 0.05511232696834111, 0.010835465246571169, 0.029238737714026245, 0.007385096687357874, 0.01895969170295904, 0.07259019395156253, 0.021856009674769257, 0.0602908630014187, 0.06693530827760696, 0.049302542146535656, 0.017843608849591786, 0.05254117118555212, 0.023163264023981268, 0.053663738973198406, 0.0800998091337181, 0.02846803027956236, 0.028834867651664445, 0.034171501249675794, 0.007076283293445745, 0.06398495429405762, 0.030210131456354455, 0.07399670839790376, 0.04095031068690362, 0.011599848625220118, 0.043832835245637164, 0.03743335424411682, 0.025126801000066826, 0.07000199654289792, 0.017629517918272365, 0.007862957436666495, 0.06753371487702094, 0.020865392871201042, 0.09569115395988188, 0.04589299889161222, 0.032339796514040044, 0.0413458725257266, 0.03426418639719486, 0.009714783950438424, 0.04058575242637627, 0.019403844583599318, 0.05868298617461997, 0.05482923449768175, 0.013947384300521545, 0.09008792559466056, 0.0871608185491735, 0.024535233650596875, 0.06385922394392472, 0.04783337319930715, 0.013916255275328315, 0.05271870057068525, 0.053300567331814, 0.025241442227495775, 0.06322936943521903, 0.04200247882474815, 0.04980595384333884, 0.07740090435911572, 0.07680183126320762, 0.0192079195121844, 0.03830104457935499, 0.07477394290148251, 0.03457536748159797, 0.0544696519782226, 0.020716564970151074, 0.028430216179619876, 0.022044664571782755, 0.03309332442680194, 0.0791912365164007, 0.02272591783454822, 0.03322924374632778, 0.09538791337681395, 0.06614294353752367, 0.026365297042854854, 0.03871628338651311, 0.07386127937464945, 0.06768267301301803, 0.03752288693982748, 0.028027537383980332, 0.029074421430367137, 0.07065736177948213, 0.002393397050083525, 0.03323464083575434, 0.1326568728132594, 0.014824735004484895, 0.04487757999149542, 0.06683479754194137, 0.02293415393890633, 0.04725527176032624, 0.03368153439594373, 0.03134841170732773, 0.03357351216818056, 0.08780444731875774, 0.026447921540708314, 0.07495211197003242, 0.07540441028052762, 0.06081374865325709, 0.13092658662747952, 0.030042831260230274, 0.06364301094905504, 0.05698192241271177, 0.125417249998258, 0.030888636378691565, 0.02087606830642589, 0.02175766122226994, 0.022062746162015586, 0.01756541934164782, 0.025104408250040105, 0.02572726263033767, 0.04042700751714649, 0.07597280155506826, 0.025874385985756115, 0.043708303823105754, 0.043910949400836424, 0.04223758737827021, 0.07891209705943063, 0.04261066836695518, 0.08663494515443042, 0.013547022920852948, 0.031631082829628746, 0.04117875427548443, 0.012938518324987063, 0.03698520813017123, 0.07184809990107052, 0.031979013151759585, 0.018454180925243327, 0.016242100128663645, 0.058685675143234195, 0.09601792876398373, 0.04540441482658348, 0.0546952303979666, 0.030662318684100628, 0.022529213268670346, 0.03373682296143905, 0.03337635561042736, 0.01783015059998199, 0.03198572599719609, 0.022056435512739326, 0.03984878733453732, 0.04544782902925246, 0.0731276965609962, 0.07913750310939166, 0.05371915394320123, 0.08562678110695655, 0.02456432009386199, 0.02179289552112741, 0.059073656542046424, 0.07965515638070722, 0.03047438007929633, 0.04718389917886065, 0.0803054501152327, 0.06467533357922109, 0.03386050019593489, 0.06396160776456518, 0.007765314263862468, 0.011521321740151655, 0.06701798448639532, 0.04155389604068572, 0.027925889007747177, 0.04682891318694719, 0.03414284573086808, 0.07174093952222217, 0.03387772951335196, 0.04128624790257985, 0.05252221817030542, 0.04200138331901643, 0.016289777610631242, 0.019511839998285138, 0.06560629128568596, 0.0400820036508864, 0.08805898769247918, 0.019660472546914415, 0.04474916833362753, 0.024608630619402376, 0.019783305169473735, 0.025603380467322086, 0.06024186401778172, 0.02423023681096252, 0.02860752722969459, 0.004018046893179417, 0.03921287307035058, 0.054324612381958196, 0.07612043435895637, 0.06548324990416728, 0.058580054601113644, 0.039759269960585146, 0.022951622658799735, 0.09069079082579383, 0.03097182203594956, 0.006789753960836078, 0.003266108612860403, 0.06050750500552597, 0.04166881689020703, 0.0647244091716505, 0.055926303048768354, 0.010601705965405751, 0.02849772001706785, 0.04142193356528878, 0.03378485667429144, 0.04577903182155663, 0.045690395448717384, 0.037688473014221076, 0.044473441798360124, 0.03058267809871224, 0.04267927537101411, 0.04757861066008768, 0.011745393839514544, 0.10795049128993865, 0.0074573785194285945, 0.014033411186368716, 0.02821983311385397, 0.028877351057505416, 0.07745494420129447, 0.019529228278946494, 0.06412689889510793, 0.03950728449009119, 0.03579984794581129, 0.03555541227181112, 0.05035576748571569, 0.027963207065758687, 0.04434905593253432, 0.04766648094500265, 0.025467409436861356, 0.0353755424880693, 0.09890101639734161, 0.04479103886912908, 0.01916758306775122, 0.048871667484842965, 0.035305418629920295, 0.03609198025397716, 0.050301118603637146, 0.0430782922663756, 0.13111225569680815, 0.030549422221919222, 0.05744808308419682, 0.04028026337525056, 0.06964035707736208, 0.017524851155617548, 0.050583161533840244, 0.04889262765045128, 0.01214721365906899, 0.04572205403218827, 0.02320664183747384, 0.05049747076906985, 0.035176202579731905, 0.01630698586063039, 0.022951262597475323, 0.03368239241441892, 0.03686239657502982, 0.04721625107190302, 0.06343216440009494, 0.012848855394329275, 0.04342007090247447, 0.049487893289375695, 0.010873717931850303, 0.03120513985894861, 0.11472384235070598, 0.050861550224644524, 0.014829107451312726, 0.022765428819242987, 0.039762855252070774, 0.0245438463940856, 0.039831140499201514, 0.058175560177093556, 0.03149239793269625, 0.026018580970083995, 0.026918335915392926, 0.05412893820433848, 0.09065612534722013, 0.029065998293639674, 0.12396658590484051, 0.027737220704195, 0.005460152826872805, 0.0738751225834412, 0.09712340129959969, 0.08261666077399447, 0.03077778345604818, 0.07529502824669884, 0.006263257162044606, 0.04999100621188841, 0.05873288531156798, 0.02662895194765541, 0.018306896691360784, 0.019511478021740913, 0.016566220438107848, 0.019356391182349577, 0.059077299290126374, 0.018645411792902217, 0.03854587861907579, 0.08823171753676669, 0.043400279020950686, 0.04567681270981989, 0.04845432193589307, 0.02898287583863543, 0.03317062652880146, 0.08447813185592813, 0.06250257799101454, 0.0377671349222862, 0.025516896801550063, 0.014967286730215195, 0.017336297765254013, 0.00046128580863531233, 0.03093574504037538, 0.051013951925861264, 0.027881333334071022, 0.03883934775066953, 0.02501700527875895, 0.02791874523785326, 0.018694297778570367, 0.08749308620369242, 0.07296348561442668, 0.028984927039052692, 0.04176560443856063, 0.060946534673172625, 0.02587196514791539, 0.03071575906247862, 0.06640178932537956, 0.08728869394549439, 0.024025689419959823, 0.09204611527703463, 0.04152179695665837, 0.016920662507595077, 0.079526039921949, 0.05028909102322594, 0.027312574337326714, 0.019657821882696404, 0.025224061607713663, 0.04418482583376669, 0.029871246717389555, 0.018614515466915987, 0.03710845635542947, 0.026842713461167393, 0.025383656874539393, 0.06738183028515309, 0.014121774640384943, 0.03356899607986693, 0.021048032062789126, 0.042317769970865025, 0.013713017894676136, 0.04037168064725496, 0.053161553017074065, 0.06784160561378925, 0.037175010243851336, 0.01603026341106142, 0.039938162982223496, 0.04104009619162929, 0.041381258126949115, 0.06066613500156711, 0.012357050887188845, 0.01575920426647269, 0.03615394144529297, 0.08446583614474343, 0.23974485635276765, 0.13565549416647804, 0.1751092061280243, 0.09330155718470774, 0.12473615952917647, 0.15946657937620917, 0.20061573584473905, 0.2894498359772467, 0.1041782207246269, 0.16890380201080155, 0.1245223137459928, 0.1486698264676717, 0.15006733938090264, 0.10669296562311151, 0.14128674602796956, 0.11339328552205717, 0.30844480219867926, 0.15584900494544737, 0.1565165586409069, 0.16343707519192852, 0.13899359972246234, 0.13159199527675106, 0.18193898722529414, 0.1730889096976288, 0.139287808128903, 0.10888711804704321, 0.1523436317520757, 0.06806507346130188, 0.11692167965755348, 0.1525979729429368, 0.1049278837238108, 0.14856864157463276, 0.17008956822176136, 0.11341610728132148, 0.16206312714324844, 0.14334582182909214, 0.10748211279391282, 0.18806237396934342, 0.13110575927121024, 0.11607623268519679, 0.09301731558216196, 0.11144636499304926, 0.12868381826387298, 0.13563761367432534, 0.20097691565752032, 0.1715994662334842, 0.15231949998246086, 0.08910822937445295, 0.13875883973894582, 0.10246874914774973, 0.1002429879360622, 0.18978918211594706, 0.08602799667466073, 0.12548545480615672, 0.15249832022574641, 0.17785282745476694, 0.2154494656790649, 0.318369256753114, 0.2016090454473611, 0.12992236793281572, 0.14865318703795635, 0.17516191297721478, 0.1530234581760822, 0.1581200113099429, 0.13384559612360694, 0.11485908751285846, 0.08544728670629763, 0.14603639922795758, 0.1452920375572097, 0.18360277697924646, 0.10276497236543125, 0.17524316426246397, 0.18878635770130545, 0.10042470399170153, 0.1741667034765405, 0.1373785791257697, 0.12607304424407983, 0.13308646427767892, 0.07829840700592726, 0.06804483341834239, 0.1705831127060998, 0.20922699312288917, 0.09189976183998008, 0.2468147140837485, 0.09090121985683519, 0.11009777445466289, 0.14910139443893589, 0.10558304211665547, 0.11589909783534466, 0.11265451629315654, 0.11136974853974198, 0.09704699169003195, 0.16257948572597197, 0.09426842909306289, 0.207294168611688, 0.16161433751544646, 0.1963845096648701, 0.26254691183567047, 0.16468676377929028, 0.143186261036223, 0.0912103439951616, 0.2388602699483595, 0.09540710387931717, 0.12963306248909043, 0.19154684828414073, 0.09619869487059694, 0.14615448402060618, 0.12965823613828228, 0.11378828045581618, 0.16168601270164215, 0.15024761519124433, 0.12366262519912374, 0.15970284089205727, 0.18136241413172216, 0.12075058710310729, 0.10174042169725704, 0.11718473126811367, 0.19161346729003614, 0.22686500312580218, 0.09212057136239545, 0.0819904758264461, 0.1349406881678489, 0.18452189862728122, 0.14603275264943802, 0.10432981420308353, 0.16477100280744417, 0.154082513444366, 0.14251126096613947, 0.14684690493008784, 0.09689191251151985, 0.20151526096367067, 0.149809290324488, 0.13252293000057822, 0.1799890789533815, 0.15003239044979697, 0.13821471812984637, 0.2072936476718995, 0.13710286408182115, 0.11940891433867717, 0.09043045882736483, 0.13601696509267056, 0.19142409035515404, 0.1372964851438038, 0.1949464094134108, 0.11807715475198724, 0.11885786729474222, 0.18940301251507577, 0.1442830231521399, 0.08509363753781204, 0.1973022676763996, 0.16790159046649936, 0.13323847144361467, 0.07512799809656798, 0.0964920605803209, 0.10785098412945386, 0.17858352211694564, 0.13702602546301582, 0.11186095645591138, 0.10108482663429554, 0.1349953255586086, 0.2045278404388697, 0.21455898039763976, 0.11067267747655993, 0.11534392157749784, 0.11510320142993044, 0.1485813586341758, 0.1136483621573256, 0.1235999055807629, 0.2134585563814448, 0.13758496321257085, 0.17873673970180173, 0.22769464570428097, 0.11160922762487205, 0.09779429513840907, 0.15931900019847578, 0.13366864513485663], [0.02344465960988835, 0.038915738208039154, 0.03216620482083771, 0.04060336095731586, 0.050709818850361535, 0.07339624102197348, 0.05684647423725936, 0.01709502411916131, 0.1358533746773197, 0.020464903171805125, 0.014357042157151287, 0.07484310531928655, 0.05009190765239539, 0.021679633251962163, 0.06922287746302544, 0.04961206082014307, 0.037131661158655925, 0.025267094681640307, 0.02611419448869363, 0.03122131580546979, 0.019773750137838147, 0.03868053389352657, 0.06993032135670224, 0.04999582490493214, 0.03441368079473896, 0.008624226189098291, 0.023904477073360356, 0.0498593348499027, 0.07131587563743515, 0.07514481372650593, 0.028868797685830828, 0.015984081715765982, 0.022097888530322143, 0.01938374818212563, 0.02253023025038983, 0.03691696501787632, 0.04705723420146012, 0.002823170939190013, 0.0073214237683362545, 0.007956272691503287, 0.01611059347558166, 0.06103936920783693, 0.051601652446533405, 0.04196732688034254, 0.022975283284341137, 0.01689628558984447, 0.022127532302552176, 0.05773692504472791, 0.07232241557850953, 0.021794513881867452, 0.05264288084881921, 0.12134084252700691, 0.031164100528844906, 0.030368135175517494, 0.02364503182170372, 0.04206556999575227, 0.10380288360700493, 0.031442316849866224, 0.029206240264278267, 0.017071953381321604, 0.0266853800689381, 0.02323089043549713, 0.03995812340309063, 0.0069143854536026, 0.053006761121533574, 0.05956137492772072, 0.026217696797703544, 0.059468540393056414, 0.11941439952821502, 0.017015331822838035, 0.017763541170185613, 0.02051161346776832, 0.033547978457664294, 0.022907160830894308, 0.07121295172480807, 0.016405301754392924, 0.0440939448233093, 0.05231527866975916, 0.05105283854889774, 0.09712478025786339, 0.017315613391298442, 0.03406410338357091, 0.02635026256734085, 0.03602253438364114, 0.054677744441094904, 0.033678757327218214, 0.067598587202449, 0.04328582165462356, 0.03598011226483411, 0.0443852574173962, 0.006256634810744155, 0.030640015949405013, 0.012328223956208076, 0.017992930877352917, 0.03144965597218083, 0.02909712061556357, 0.01276827922406336, 0.008191561754492503, 0.0060864502935850575, 0.03271891427556834, 0.020571291717069767, 0.02842459500947547, 0.07441704552019797, 0.05281679429894975, 0.057981628849501574, 0.018046633640844977, 0.03414236309547578, 0.02151098665631106, 0.04492828735120354, 0.08599134702836314, 0.028674628870982318, 0.08315466134057892, 0.011525616620577151, 0.07041004561488667, 0.0636534910318592, 0.011849478375346912, 0.05758523580528075, 0.03108926522996157, 0.028693488040458293, 0.027226730354971466, 0.014619614962758798, 0.047710243717677174, 0.010795144123896476, 0.06654241242476049, 0.03443485163452645, 0.038526917942949844, 0.018268737851852374, 0.05120874510236806, 0.021619707939305136, 0.031344531471991254, 0.10127057997329582, 0.025247804587706927, 0.05415110495842753, 0.03014696942221734, 0.042782846627937215, 0.04163781714235102, 0.021160340552488645, 0.026013337098242297, 0.01975532380803939, 0.021827538017063372, 0.02647831416388433, 0.02855207012485593, 0.029180622284090327, 0.053867912896338015, 0.021123575993002425, 0.041519958345640096, 0.0536307359054204, 0.008750407573496623, 0.06191796480467724, 0.019540457212696635, 0.00856747918371712, 0.010132524034669323, 0.03047266021190632, 0.07937898168400412, 0.045703878596184716, 0.032561287854708014, 0.04388329745720952, 0.038257706985478444, 0.02075963826369374, 0.0590447137402671, 0.10638099929858601, 0.028530860980672222, 0.018569854456150246, 0.09093274437491933, 0.03414669149224797, 0.013868800916468665, 0.06108284086710023, 0.02181028763222839, 0.13353467167865846, 0.028702989445939183, 0.02807320963080612, 0.03301756216153022, 0.043436534131967255, 0.008197822608053684, 0.025088609601821632, 0.019358057423584887, 0.046613807189128095, 0.021176269435654246, 0.039691034509169484, 0.02601238714921619, 0.06088896699610257, 0.042840839483805244, 0.07419404498631917, 0.12115951717620897, 0.07459907567188626, 0.011656920260359204, 0.0456387113269058, 0.09207004786378915, 0.03028088542182119, 0.06748672304374558, 0.0030258502726698477, 0.010388794809489722, 0.0441029999825743, 0.1004942111490715, 0.030928243124376864, 0.04750637622970728, 0.08692564487817787, 0.03932226276505859, 0.05174664224708273, 0.02071538519474768, 0.04751852255374674, 0.006871021046648704, 0.05003037547031718, 0.03899815011649363, 0.041714954535446824, 0.03952639455336236, 0.03444291087948988, 0.0343899205777674, 0.023330196497901794, 0.05504683794213399, 0.05009645055378637, 0.04986063336893436, 0.03315343168534098, 0.018088416076235233, 0.016799902152870933, 0.03741187696915962, 0.020880668664411194, 0.08994773916539647, 0.060908559694766044, 0.06111305537483385, 0.0696976681149775, 0.0648741027520549, 0.0340646741190745, 0.06536708799220863, 0.010818032915854167, 0.07058848281421008, 0.08125831027545276, 0.045347364258862315, 0.07619918819757239, 0.06689207027516057, 0.07088403953539749, 0.024700434765808528, 0.08307405356918612, 0.024669101769705454, 0.011305306970532383, 0.052246246486902244, 0.06773456014812955, 0.0509837833834031, 0.013857922467943883, 0.056977157345822746, 0.044266034984180046, 0.03389000607233855, 0.021304997104790904, 0.06061224837697322, 0.029942188374397737, 0.023390991320352883, 0.02425329222704374, 0.0103170765308483, 0.041027045883839174, 0.058029061183333404, 0.014666815554993528, 0.0515547602046882, 0.04156708424430221, 0.019886548923809203, 0.054236581218579126, 0.027244455714319504, 0.031139141384271846, 0.029866307365497755, 0.07238606216325875, 0.02860793708673408, 0.020816836303340334, 0.08486673761639865, 0.010764687340856801, 0.04197535165134938, 0.03190374884363865, 0.02770927381671725, 0.05240668062000506, 0.03220641677598319, 0.07690921380755401, 0.013544675818974934, 0.008388397512927411, 0.04379195296355794, 0.02619782639216752, 0.005733582055977276, 0.016349607162297736, 0.05002744135356719, 0.02238926815710241, 0.05559580888779414, 0.03217421810052568, 0.054440900698424353, 0.11701132726645279, 0.03682159473218265, 0.040118369844651995, 0.04171504646599774, 0.07696975007533066, 0.044565100388060656, 0.027003988375767108, 0.021523692224535252, 0.04225783508210894, 0.03974965555713542, 0.05149250789996117, 0.06208695230945464, 0.048799199397645654, 0.060738748645470034, 0.02421001592020114, 0.03604802212888195, 0.06390960954670465, 0.054728869318721764, 0.03239520765360325, 0.06351039346848285, 0.05765659689542748, 0.033239968977267706, 0.025924754351557746, 0.058977248207215345, 0.01351681990443819, 0.01527630744667183, 0.0756400436042778, 0.025988266870920217, 0.03812743756439417, 0.04635287381167855, 0.022387596170207667, 0.018199795684326562, 0.020065606654351278, 0.046418232602938536, 0.022892386825274558, 0.05129504873747787, 0.04159765498292062, 0.011547584191805894, 0.0451198514671095, 0.01802517168764626, 0.010533684060998983, 0.07444326870984609, 0.013649879800786656, 0.03865982653693326, 0.06794548713632169, 0.0335659662021264, 0.023594732403815277, 0.030272931513947346, 0.022269227925027092, 0.08929087239648066, 0.02356978666578089, 0.04285277896410516, 0.047164321801955664, 0.05729128786873433, 0.0468278598160513, 0.05357818610425438, 0.12157310506389027, 0.017942568257210717, 0.012991114091428538, 0.06881819917790352, 0.049475283482142036, 0.012320195354761617, 0.05692328221254772, 0.0424921928694652, 0.030993607661296285, 0.06261082621471536, 0.03323909180659441, 0.018142316107367797, 0.05945623319055285, 0.03792812446913412, 0.026906225980529865, 0.022737585353635015, 0.06995114362648419, 0.1329324499613816, 0.10618384657127243, 0.1273146429429612, 0.14220016798184765, 0.1718936899616834, 0.11582087259739639, 0.15579147174233393, 0.22981122406500004, 0.09677322250941107, 0.08479590512691967, 0.15282425999401078, 0.12793715066847303, 0.25135732436132047, 0.20693698777787148, 0.0993617263532454, 0.17702133094351138, 0.13764723083905636, 0.11409256291846115, 0.1495470584280068, 0.14959248744191664, 0.07741265614787418, 0.1931892948285226, 0.17740137184098845, 0.13839905420618673, 0.06414226278842938, 0.15370152259786285, 0.15453943892592384, 0.15490716112957847, 0.13914721567303906, 0.1723204009355076, 0.11797910315855858, 0.10289818739458438, 0.13864352818458311, 0.1328327666006742, 0.16956999206975584, 0.17967400231188346, 0.09284220320442993, 0.10784349178955441, 0.23413297119400195, 0.08063031736040309, 0.1879578642547131, 0.12021703750736291, 0.19877588376402858, 0.16835431778623214, 0.14446639395769567, 0.06563530303537846, 0.09885917267491741, 0.2117968503866465, 0.17073272967771178, 0.198999535472643, 0.14152556627748475, 0.1157861381709095, 0.18611367611635118, 0.19836601140278004, 0.10277240341829677, 0.21274578817669423, 0.13549532050326948, 0.14469787508489626, 0.1857414339939433, 0.09242372001491247, 0.1129528922179053, 0.1181997977677853, 0.17304666760948398, 0.12468627188354732, 0.18101765924403745, 0.10945521820817264, 0.17891847107919956, 0.17073574806413344, 0.10757844068951185, 0.06725809942450255, 0.07428935398497889, 0.11763152140643328, 0.19692621043612882, 0.1867967660749151, 0.11394983307728845, 0.16619122256675076, 0.14625873326534225, 0.09417206289306765, 0.2730193950476185, 0.10713220979537695, 0.13295998316138022, 0.13823190914286723, 0.09778546980552136, 0.14353126107204345, 0.15237540907917485, 0.13095275619097296, 0.15823195207743876, 0.08544423001547975, 0.12572605237965623, 0.12586356516206457, 0.11341825232750948, 0.1382717457149298, 0.1289794822373698, 0.13771711337950923, 0.1154063730650852, 0.11291483296982704, 0.0496206027004988, 0.11190240181261495, 0.1279802584359723, 0.09756024761666214, 0.2023407360238414, 0.11054111719732324, 0.1360898353760281, 0.16364721310955865, 0.09342103625737852, 0.11567569127486599, 0.10614404830360606, 0.1408511331124652, 0.13085319540433346, 0.10572061618609775, 0.19650856994332808, 0.13883884996175766, 0.13529203141168242, 0.11561630413897576, 0.0837775367882944, 0.2638749099306522, 0.12613577152331992, 0.10292329209586305, 0.11009448027658848, 0.1382666588911126, 0.16799902152870932, 0.13866033615364184, 0.18744394183158877, 0.07497072790659244, 0.14180486661291894, 0.09800568944023502, 0.15049542931299056, 0.12366860068493313, 0.09756983903747413, 0.17233897090679215, 0.07756828690969175, 0.13584001410392024, 0.10377995459543121, 0.21145626301726989, 0.14949327905572232, 0.09905398883406194, 0.15079113925176282, 0.0872009615564058, 0.11371451384958722, 0.20492176284953473, 0.09333999947674813, 0.10274954335463625, 0.10489625961429651, 0.12208869755868951, 0.1321423068762787, 0.1312459227178366, 0.07270096260453425, 0.1945990804703005, 0.16801880191891425, 0.09633197884766326, 0.11141384456066356, 0.14073781338670563, 0.1446201171605818, 0.16005213102025373, 0.22112262255001455, 0.16895946595937977, 0.11508191950739392, 0.2311940127683263, 0.10327100408293548, 0.2796336143247543, 0.09404200414616255, 0.09365283148062807, 0.27287466571696345, 0.07645902989972984, 0.15657383137412612, 0.11273317054034242, 0.09694288034112224, 0.31194321931369845, 0.1109125855709276, 0.16236579316037317, 0.09318734113607677, 0.08513533570353063, 0.11964139138017932, 0.08970263699490218, 0.15242261541706903], [0.01398228822396167, 0.013753878151727541, 0.0016900566345523864, 0.019713353681107684, 0.023610025434003725, 0.10842276151261984, 0.0032083989701218786, 0.0373262360001043, 0.07277184105928867, 0.021526408006226825, 0.04688704393864159, 0.02811763889997477, 0.024303344581576607, 0.002045817452580518, 0.07634423928515566, 0.008287297847170022, 0.005919757700945822, 0.007666168122311995, 0.03405795935841818, 0.017944688405541163, 0.04159292438998819, 0.02125526842240605, 0.06233164462290945, 0.0448673565481459, 0.0508838816876373, 0.04521677308084984, 0.05121975378583997, 0.06184371173261635, 0.08245506218724674, 0.014432227941259984, 0.02226177005908422, 0.1261936111616031, 0.06096688962932076, 0.033325219241481636, 0.0282017802519183, 0.05428770226576636, 0.02969109922677519, 0.04143764219817616, 0.0426118366510397, 0.03278231954262142, 0.04904755744181814, 0.023102969073900775, 0.01630324352112028, 0.05766244980716898, 0.019367809722860976, 0.0036640436484313183, 0.01589226512043106, 0.015817909584110303, 0.03026611524664106, 0.059423957906302914, 0.04496708587412873, 0.028545257687989264, 0.017508922272451946, 0.10105342469027928, 0.05528080119420925, 0.05909652809702581, 0.05218020204695002, 0.020203893185563145, 0.006735708851802855, 0.054007463472624945, 0.08083742923073231, 0.03886003595506472, 0.04127238554159, 0.041474651905798146, 0.04871025275919707, 0.04544815461662027, 0.08669626283188982, 0.04360927163713402, 0.055547978188241684, 0.06029055656624898, 0.00890946370594564, 0.05360746598472038, 0.025843746299224517, 0.0720250815333378, 0.04498292091152361, 0.07874886670540418, 0.004763669736172644, 0.00489417951734316, 0.06315472182787715, 0.044219265316402724, 0.028237322901165294, 0.042737567001172615, 0.03218377504738108, 0.004675794184403194, 0.07938819006085396, 0.024716668168924028, 0.04100857167354515, 0.055024992944973136, 0.06263373607409096, 0.06306241206344097, 0.024370614762207674, 0.010627326818423407, 0.08433225339338665, 0.02868470675762623, 0.02954892288412779, 0.032656344044352734, 0.07062582193963951, 0.058276078573638396, 0.034103606707386436, 0.03992471047827313, 0.03948619408953575, 0.013783472128242496, 0.0377255784828336, 0.05257009866557295, 0.04191886415825256, 0.024736615183252483, 0.013683322411511215, 0.05038594751949272, 0.0642507599907056, 0.035636395426286806, 0.03608282933372163, 0.048310883463390415, 0.028446281043392037, 0.033276936550053864, 0.022062884057841955, 0.05008453405612419, 0.09345931001007558, 0.014769921413502626, 0.030261070557659676, 0.12837353733278092, 0.020876512637421973, 0.052798714623936725, 0.03641360694722783, 0.05773098786331474, 0.04593623689405861, 0.052983322661490216, 0.056169593421321724, 0.013644279698060166, 0.04072880019403754, 0.012155601364229957, 0.032659182400112195, 0.0667556070332085, 0.022206588745898297, 0.0173776914110227, 0.04386080894619227, 0.05405409141413627, 0.1073896689640899, 0.05284844139110177, 0.09498737962736238, 0.07635330210529989, 0.012233767230364104, 0.057820390324078264, 0.02554389565522152, 0.0017556878658304474, 0.039223265053043445, 0.021637538635742762, 0.02769455152203239, 0.03571511862138587, 0.008096362880971885, 0.014963854656314418, 0.028365378328148397, 0.02140509415297739, 0.07444770435892767, 0.022834934061393145, 0.0724304722802293, 0.05878331687962336, 0.012516372277581645, 0.01939428955196373, 0.03362478643295265, 0.029559644284628095, 0.03604824046394037, 0.027666888087086623, 0.044300738767149954, 0.01937325852322242, 0.031489333580999125, 0.039391317930553234, 0.029712227931726846, 0.034633969377365806, 0.040444807570067146, 0.028570699467954618, 0.05416687487834885, 0.056855923931805365, 0.11607996353338804, 0.1630913703552177, 0.05698794003335699, 0.06194768901613932, 0.048056128585050185, 0.045195426040839766, 0.036646620250276984, 0.06429934528686347, 0.007237135902077201, 0.04250118291125663, 0.05178944357941228, 0.019968905290889166, 0.04639285211000712, 0.015889470814727247, 0.06389645198660512, 0.07048263244571225, 0.07425952252120742, 0.05834294655810922, 0.06104618739036303, 0.018499134964640104, 0.03362994220468306, 0.01730386160253998, 0.024827898389870123, 0.062428171701368794, 0.010920289374377218, 0.08335952091241076, 0.042288447955563184, 0.03447817773708413, 0.08459329019270598, 0.04456117418744872, 0.022127181817326817, 0.03848635358735919, 0.0585722251825275, 0.03324813547454054, 0.03901000915756149, 0.031220427143477628, 0.04597573638743451, 0.08046172439090668, 0.012402861987450912, 0.028549327530087005, 0.014516998442911334, 0.024826919712546854, 0.035038582545014164, 0.012757699549829048, 0.018971207919680787, 0.04015243011376551, 0.04776168269135299, 0.03565204660257986, 0.05741572736071483, 0.006113077115808284, 0.03780322149395943, 0.07850911182862136, 0.03477169666439295, 0.048879389651119716, 0.04018304298721975, 0.00919007117890062, 0.02763169975350461, 0.02265850975809078, 0.07203333996116154, 0.060672738679474404, 0.04156831381542068, 0.08046331785378918, 0.023434035885598392, 0.007519929119641142, 0.06547791793221427, 0.040070761310597586, 0.05767377258668985, 0.020465207691755027, 0.02849564200357324, 0.060745042057768, 0.017685815804607926, 0.014681415275610505, 0.03110689674353888, 0.02350561722602335, 0.025993832499690117, 0.035988581366837025, 0.0562654463424077, 0.03533337700871691, 0.054608080235700455, 0.07356819711745748, 0.1002170711815838, 0.054987044779643904, 0.06537021363093969, 0.17390988016080472, 0.053265966970713875, 0.00994562922466186, 0.019637223693632314, 0.024594457992803187, 0.03627681045702869, 0.07023248175579695, 0.01231914198386573, 0.046736465526684645, 0.01661434799673096, 0.05474813643001741, 0.04422553957650258, 0.034744990839352535, 0.07654689252376556, 0.04871342436320359, 0.11125166374709337, 0.04307626213337626, 0.06830350300597568, 0.022647593005169785, 0.031218691954329133, 0.015792927456899516, 0.03616127673716795, 0.06925462414660762, 0.061947091467558384, 0.06704976181349448, 0.02494713806006457, 0.029126973146752968, 0.028753285033388004, 0.050203580289117755, 0.07731753101031627, 0.051998945644065264, 0.040480062936342535, 0.038155725360998226, 0.03446746016702345, 0.06908977734706095, 0.1341358974816338, 0.07990920645815712, 0.04665591904232579, 0.0053410098752788, 0.02155556722784475, 0.11427725139524668, 0.0010134370067164363, 0.02003624633465323, 0.058815136341558355, 0.0365547203428803, 0.05840508394964761, 0.06385664605805952, 0.040824473084461306, 0.028633694877968203, 0.01886373919044291, 0.05659164275012671, 0.007868147682353494, 0.03786512905912053, 0.02273495958727454, 0.03816018782315716, 0.01921467066201712, 0.019882034750715382, 0.0731689120913225, 0.018393232885207382, 0.0414225617573867, 0.09581531382977002, 0.024432309737969792, 0.0464864680543542, 0.02648437774980501, 0.04886086947555023, 0.013554855212268811, 0.04193563765335468, 0.0841341583779262, 0.012516692119290032, 0.0123466981665021, 0.026105570253886046, 0.03906801350474839, 0.041834146325146, 0.014989253343834032, 0.08115845837540205, 0.03471818542288196, 0.07576326884689831, 0.049664078190201716, 0.01910798717290163, 0.002501302928243193, 0.06609680206184426, 0.029002983731427984, 0.02995680916243263, 0.048220971554157235, 0.028469895703657985, 0.0433205139462746, 0.03255729270618289, 0.05356206761432752, 0.061757434910583886, 0.04479811369110981, 0.04702026279823435, 0.02903086167099255, 0.058802158812121044, 0.09359212667350808, 0.05820014776902334, 0.06050333748721789, 0.03291723145652683, 0.14949104207898342, 0.12694276854275696, 0.1090895874245513, 0.18356683213383923, 0.07303195089221963, 0.14224070935480057, 0.1113501903150351, 0.1174332578516295, 0.10776294530519556, 0.1191397263638435, 0.12406705067523065, 0.16060405140442235, 0.1448825635616818, 0.16771795919104932, 0.1393084618593416, 0.1501861902614755, 0.12447939750047461, 0.09918371050228035, 0.12568503603219025, 0.13354024879874724, 0.1558743164904656, 0.17458492619616373, 0.15176149686017346, 0.2292673935693118, 0.22096876145130206, 0.13661636760638607, 0.17586649936293403, 0.1850151826417254, 0.3463108429024297, 0.09082223619184188, 0.1909213681374827, 0.3385612813215102, 0.18409613760248308, 0.19743532182708864, 0.06845268330747081, 0.13678588754227086, 0.11397431724734845, 0.11590290529232834, 0.17416176987030815, 0.07565882041930191, 0.1869916128775766, 0.12082975462920244, 0.14314860015386535, 0.19527907543365033, 0.11707357191030057, 0.07970319009355961, 0.19606308981535897, 0.15973789707547234, 0.1275832257083347, 0.12517563352781919, 0.18867656197999755, 0.14012068359842225, 0.1642289189922233, 0.15818770283893233, 0.12292747190522572, 0.15468272801128127, 0.12309719102397082, 0.22207384328207663, 0.1609065795257207, 0.14201253772743289, 0.15057125669573584, 0.13281651021492097, 0.17304458385032995, 0.09841346272057104, 0.20660611440337476, 0.18298077487176467, 0.1900099686557247, 0.09038357424639887, 0.16717428191294595, 0.14384295160491622, 0.1298551054130639, 0.07618863150597581, 0.19833374377940932, 0.17994649978655, 0.18228329778198274, 0.1965124923135004, 0.18847552518690788, 0.10340261798832687, 0.19880337099875175, 0.20987401566197797, 0.18159355818023606, 0.11376656952404207, 0.11732140135380531, 0.06143959269167916, 0.09525885820508966, 0.09977510739718715, 0.10741101983453959, 0.15660432167351246, 0.16311773910157143, 0.09848209653770733, 0.11414267272958833, 0.12331305927927456, 0.2227819230287306, 0.17930059573583065, 0.14783160370444098, 0.13176427312916325, 0.37396379776539346, 0.175893695484246, 0.17583412448725394, 0.08599483272841862, 0.12607613923929392, 0.16878521160012291, 0.15270908633547445, 0.16297402100697642, 0.1580370746312603, 0.11769702192395927, 0.12548612130265083, 0.15892809617423242, 0.15907435768073605, 0.10802208986734191, 0.1780858254360576, 0.13417553487083606, 0.11373584173739919, 0.14984483680417462, 0.18167689322463929, 0.1480036670522344, 0.252606246860758, 0.16086574703935655, 0.1725362232255359, 0.2696159728352101, 0.070860865375688, 0.11998343431661207, 0.14231897289714507, 0.18788560684169495, 0.16516028272528804, 0.16831284178601158, 0.22385285265984076, 0.10671487573774592, 0.23215612727067164, 0.14650694575280915, 0.1495978347356281, 0.201783774781131, 0.16331850010300838, 0.12957448740639996, 0.156216727149102, 0.10737415568362321, 0.1948023542401291, 0.13673060663765477, 0.15068270716696017, 0.2142325043678284, 0.1687903290674571, 0.1622044397217612, 0.06944398575973126, 0.060177719475881714, 0.18965441192830765, 0.14564944821740353, 0.17334557979577975, 0.14925825860231154, 0.11674127361226468, 0.11229243249662461, 0.10788227882116072, 0.13749666391841828, 0.12752170884801498, 0.19886441288455842, 0.24717952515329086, 0.25613837184444554, 0.10144377713121715, 0.14585872811655845, 0.15319728352610143, 0.16140914852580718, 0.1337276492267847, 0.14073675618537013, 0.17757581006134712, 0.07400288306657346, 0.11845697348396625, 0.06519078051731472, 0.1824266634761326, 0.0891712554279835, 0.19200932024227035, 0.1177055484825565, 0.139725428194769, 0.18822973353728173, 0.18586521848074852, 0.2855349428230717, 0.16704047699609112, 0.17334747969383196], [0.054326382045063286, 0.07673340428981089, 0.03887341185022266, 0.03663210288411187, 0.02494638537867896, 0.046260736417025335, 0.02679229146921106, 0.017830541304823373, 0.06717007592200272, 0.038024099964287975, 0.0030273503685865795, 0.05114147875217661, 0.05059476393545347, 0.052095625940109455, 0.08494895417243244, 0.03727889942726301, 0.01919552995522897, 0.02437437242347627, 0.08432398730468366, 0.042985430918633945, 0.01711815614403496, 0.035046676263934186, 0.025389032896548033, 0.03902655665672595, 0.035549804508205385, 0.04965885347055812, 0.022690279424310695, 0.048023048908479755, 0.03474975973668118, 0.013193377582806975, 0.056572532686855526, 0.023302111714597673, 0.04767644391845792, 0.03480051689210438, 0.04816522333590735, 0.030817131647059036, 0.04641751631072933, 0.03309897432524351, 0.014998813163519148, 0.04134437482383463, 0.008506966856188111, 0.03358154076962702, 0.06373922776190505, 0.03750966043181477, 0.024088428190518773, 0.01321934030256084, 0.02953871284731694, 0.0097596125429376, 0.01754826471780337, 0.0076009726035408684, 0.053190093622693134, 0.0341968089642544, 0.028598002841575976, 0.02298607554797444, 0.01442339494749303, 0.043167706218457995, 0.0680505101298613, 0.01747681744276516, 0.07788164751423944, 0.03474594844925789, 0.05236802765378549, 0.04190429699637237, 0.021666969818573807, 0.07927172171372561, 0.06416097831641955, 0.0343104389556233, 0.003631477011367679, 0.029873238545992685, 0.034077146030481786, 0.041303638098461014, 0.02721363216668608, 0.1159643761873726, 0.04128302650285825, 0.013596319721170492, 0.0422899533183344, 0.026942224452091802, 0.0024437383634053293, 0.045025281743296695, 0.060041980187018076, 0.010986033124819158, 0.05517841354312916, 0.11044726376571964, 0.057570392851747816, 0.023562985720233093, 0.0923032756714571, 0.030093419876310135, 0.06299576241402857, 0.06483873247259087, 0.04901033322957735, 0.11160473834963576, 0.06894048979325641, 0.037003490818484176, 0.030708678494838458, 0.015145594652201382, 0.002918234071506548, 0.05694728374721543, 0.014715210286780231, 0.04273451031035474, 0.009515832831722595, 0.03813832367379819, 0.03476209758270172, 0.03803596283579546, 0.08777677622293273, 0.020685279854543267, 0.025653524752405864, 0.028847222734663277, 0.061946122366334164, 0.01625919155025434, 0.031628462808927706, 0.07883325129026368, 0.04708066117018462, 0.02051528302892562, 0.05682505058845686, 0.018109770777124553, 0.09980512272206046, 0.030375215743157654, 0.0990907074282727, 0.019426968947593725, 0.06350547901444858, 0.023268415337248195, 0.09315025481966235, 0.022124209396180608, 0.030422872157707333, 0.058552973392990336, 0.04613217920245183, 0.032360599631623875, 0.02430182772748653, 0.048675418741280035, 0.053613318896461884, 0.04096458290493296, 0.09572490013294643, 0.01221375031051256, 0.03222707050642179, 0.027636822966498234, 0.05707322477152752, 0.028791328959707773, 0.029492253445148952, 0.07629512538833004, 0.017768635654882077, 0.036983492093220834, 0.0356332621266765, 0.034459642239756165, 0.027063758555619467, 0.038631481283734885, 0.05656464964211468, 0.0415705009964445, 0.03943712232754596, 0.03764192934238142, 0.07261999477181705, 0.029380061783857887, 0.04940411008353676, 0.06408844128130906, 0.03238395382199557, 0.025741801063920704, 0.007077165252168573, 0.03111880558032182, 0.048995972911436717, 0.0336874524251588, 0.06964466249149653, 0.06323285513527452, 0.06602616109434636, 0.11900298733023867, 0.0293834651294615, 0.039770148409109925, 0.02316533437659664, 0.02295448208197711, 0.04263479247569077, 0.030858515716728666, 0.02381464751857904, 0.05141699844370446, 0.03211652976460755, 0.018859491232902776, 0.017526187979045416, 0.047626935486351295, 0.06489159253936622, 0.08914192958224205, 0.012034126632516424, 0.03599035486038174, 0.04645995758173447, 0.016137709157661568, 0.036335485131149335, 0.09946183872319038, 0.04969444208508057, 0.07464487240799973, 0.0333140803230626, 0.05893431280949905, 0.03432278063208346, 0.051140413889961864, 0.037147162947803736, 0.06900894741017012, 0.05817839853285302, 0.06083428747050705, 0.020894822138812275, 0.0867386045114648, 0.05372433652800899, 0.07012807163259677, 0.0200904700379338, 0.0639584782953945, 0.019586349709800655, 0.009723752924811938, 0.0022168030104254403, 0.06772191203649967, 0.018315145543085474, 0.02186792808765125, 0.011103437056825047, 0.0684011715554422, 0.05527842632164398, 0.060720592361664584, 0.05413357303628037, 0.006476165923935872, 0.08956779019847032, 0.13172940080685, 0.02951386287027309, 0.053447690687232444, 0.07420967317997448, 0.04349631580313848, 0.02282167690986347, 0.002790668940794985, 0.026379710987150192, 0.05028010098143451, 0.03467226994314021, 0.01929871433775031, 0.016375071924900817, 0.02552494072475501, 0.0852773990482092, 0.005753736392850237, 0.012669845544282469, 0.05415721067918405, 0.05140878215071656, 0.0712181304791762, 0.022542054817501097, 0.010502776243693886, 0.058617907005452344, 0.027126979961570714, 0.012401090409126014, 0.04449660063631112, 0.02139716897340071, 0.025457141943456187, 0.06457657718490209, 0.027943124070823677, 0.04745576846142931, 0.022684999163292592, 0.018024826948080334, 0.04775181930932788, 0.07140328626959555, 0.02419609610261696, 0.039590014325034235, 0.05047220518932708, 0.07586712738679302, 0.022466685172290574, 0.02324679250558538, 0.04572911736285014, 0.07993112423367078, 0.017132150655191754, 0.037715446970034996, 0.059238633576540224, 0.03345148968360117, 0.0018240682754455317, 0.02575719560075912, 0.03860758700137658, 0.04441518464215821, 0.09092216470068501, 0.07407476509650869, 0.11827717264813763, 0.02389255291481893, 0.03715304650306221, 0.10699585380573427, 0.05893726607844715, 0.07174844718388013, 0.027074386110349048, 0.014614540587870345, 0.04447871248327917, 0.01799179515200517, 0.029744206356906125, 0.03520200442102167, 0.05300485739304174, 0.03913991468688173, 0.020030148274775957, 0.05438050232647408, 0.08543640825777285, 0.050658851020759156, 0.004589300463727165, 0.028091620638846394, 0.038224171486593066, 0.022270959283735965, 0.03290582823777392, 0.08790295090406172, 0.04277916557546105, 0.032904108370383905, 0.0853813112142586, 0.042843080290983764, 0.010553738327636834, 0.010547322341270987, 0.007270053742573627, 0.0445704055469363, 0.0356273555887803, 0.014453878543610054, 0.052496558055281646, 0.06243650673798496, 0.06624014477335638, 0.05626366901842337, 0.013865423426332494, 0.07066574278137377, 0.03148764244190628, 0.002295029924191054, 0.011806444343810361, 0.0439675901115181, 0.015803085782775478, 0.014283458454414241, 0.033940081409509146, 0.10620430877972996, 0.10038691287439677, 0.01656931160288232, 0.08855522880631109, 0.017353971413667166, 0.04217802021171778, 0.040579459014078306, 0.016146480864394578, 0.040087170913935675, 0.038661745587183584, 0.0450485669857552, 0.03262423346900652, 0.04621256097790696, 0.04889495272730147, 0.045912220037632415, 0.06255133565695536, 0.03926634217702574, 0.02323711873032153, 0.05828694936128394, 0.029300978527434414, 0.018354445853601062, 0.08230309332570723, 0.02745613346867744, 0.06583720550782259, 0.017405642128940073, 0.06750685583439565, 0.06002363621167118, 0.05697589330074768, 0.013350303990826493, 0.015884536250884977, 0.012270700329193666, 0.030558247554806933, 0.0349676083292692, 0.03220796810402986, 0.12283105207907578, 0.024335047215103142, 0.05271798427847605, 0.05000668803169843, 0.04712095356456215, 0.055292311665271564, 0.10219186198927703, 0.060148071873212056, 0.13622865050790772, 0.1978941472066987, 0.12816546019166708, 0.13660020315118376, 0.16122496566705166, 0.19253710885682415, 0.1411547950438915, 0.1695448950293564, 0.13263025891876992, 0.1776998550180466, 0.09599211926181471, 0.2265440735725626, 0.13936696033323967, 0.22139230082111977, 0.17867202059395854, 0.15179338143958201, 0.13886126569442211, 0.12099561266480915, 0.18405309878289702, 0.18306340511527755, 0.12180929763182519, 0.1769225056012792, 0.08392777429112504, 0.1511958941456772, 0.0952880921202802, 0.20615041466249576, 0.0888602696960011, 0.17843125448111566, 0.0846804173723344, 0.1329946103355577, 0.12691742635422176, 0.1520231465298322, 0.09867109808950655, 0.19546485175528835, 0.26227087503479374, 0.2578945518020661, 0.13446559108072711, 0.17312175954782194, 0.11359064509311032, 0.20534825931874015, 0.17598155044740246, 0.13571010091372077, 0.12218210665929703, 0.14740303879784, 0.13565636750671173, 0.15654156375075542, 0.10589531487635068, 0.11066829545363305, 0.11042274129126342, 0.06628088532916962, 0.07862984728548797, 0.18005736803095188, 0.09665136856417503, 0.21454857692362803, 0.11494986127100645, 0.15335158895581, 0.12348144540503142, 0.17669163734441803, 0.17863555480876278, 0.09562023720073123, 0.13779730746342292, 0.16571401107695796, 0.15750796834547676, 0.11505481531663288, 0.14607188442061025, 0.07614064375839888, 0.06664092367094371, 0.14140670007515338, 0.15332842245697975, 0.08095575151063743, 0.08479759818123234, 0.1694764527342012, 0.20732361703149735, 0.12168783439143051, 0.1083064387221971, 0.2576559000918942, 0.14082194516255012, 0.16287294336624686, 0.19206424874644126, 0.13114427817204308, 0.15058369796362617, 0.2505797451181758, 0.16276334682779928, 0.17566394571575428, 0.24597221654990029, 0.21030674808688704, 0.18122701575198483, 0.2134026626064893, 0.1381887017839378, 0.23349486591835178, 0.1862787833857921, 0.1356511581088266, 0.1637772641955845, 0.09458149858419934, 0.10280663222675362, 0.19738722682720233, 0.132701505095728, 0.163272580792827, 0.1667402318168071, 0.17635366999574248, 0.15321468904374108, 0.11809815322199177, 0.1873263473352117, 0.14702380995356268, 0.0569497122459354, 0.09018326523683726, 0.13272762869394597, 0.10163311576170307, 0.07185545434514362, 0.30501793769578783, 0.14919767636925946, 0.0691019045189023, 0.1403005457212848, 0.15231194635552747, 0.3236863359568581, 0.1251939430292095, 0.23807798692535972, 0.11545570146652961, 0.10324630540825668, 0.12222485436547188, 0.1668480050659949, 0.15485489861138407, 0.10860638512719063, 0.2168087967701497, 0.1580306854579718, 0.1734130261766334, 0.26244922030356627, 0.23813124535785568, 0.1508833915596047, 0.07896665018051863, 0.22986071334490854, 0.11667223376852852, 0.1080599575934391, 0.0817308945941829, 0.18848761405435302, 0.15790501639487284, 0.17982041703597193, 0.24421292627530716, 0.1630025807647936, 0.14530110803823318, 0.049698414250967965, 0.08274259030698769, 0.11454055581482188, 0.11168710046237516, 0.1040810731149489, 0.19242927432060244, 0.11234600502516955, 0.16095596155331982, 0.16117199834796692, 0.15184611893228947, 0.13971323207501443, 0.22313026320790091, 0.21469569644860684, 0.20561473534232189, 0.08589987613020406, 0.20253527639133317, 0.16303714665193714, 0.12319940247482832, 0.20274155322582493, 0.19631717053632583, 0.13960502981658907, 0.3517709353998784, 0.1268586750713087, 0.10473220188531185, 0.11350189380708242, 0.17006036495008778, 0.22172377174419744, 0.08507747308260973, 0.16332559407718722, 0.1034412824458653, 0.1686942003547184, 0.0873643834324133, 0.18534692935645583, 0.15898543019448558, 0.16657418992009856, 0.23250379329246862], [0.024426414691392454, 0.038488950625422506, 0.06105584392864859, 0.06948631977842701, 0.029067497910751455, 0.0046442313619228385, 0.03207459985729187, 0.06569479742357809, 0.01968535125225542, 0.037658737311440135, 0.02592323175180824, 0.014232059700354455, 0.0733767747278175, 0.07174709120825415, 0.025103341472605546, 0.02657940521115257, 0.1023602864194301, 0.026913455935315262, 0.052319281479163524, 0.06469267014894756, 0.08208314182176706, 0.029052438537379908, 0.003739538740539443, 0.043573414891838066, 0.048745255316457445, 0.0058168998634022095, 0.03970526459236299, 0.052815319579695506, 0.06826845448343985, 0.015047312274785533, 0.021674019742696997, 0.02878516961279656, 0.04477550260602467, 0.05203541525970063, 0.017067123196959015, 0.04183782737762217, 0.005866082708141016, 0.025800366570512136, 0.04420813788930255, 0.01604570391317529, 0.038126594867677464, 0.07369293155328882, 0.06524642914413445, 0.018350996542721987, 0.012405380501501985, 0.015378745851076901, 0.07956349396056707, 0.01559651783487249, 0.029344224190760045, 0.016169892511360588, 0.0388255619984721, 0.05665182661745818, 0.014115223631022439, 0.0364294036802265, 0.020345835871393644, 0.05653162359169895, 0.07173688691710273, 0.0030999508453533058, 0.051486494109755566, 0.022996674374406858, 0.07377329417654584, 0.0265071229002769, 0.020639061770071427, 0.030031721070108396, 0.057625750365156325, 0.03260346482537928, 0.05661381333465538, 0.046423897823138584, 0.07491579174154228, 0.09592736951045452, 0.026678355042672446, 0.04127811587926361, 0.06749372508737349, 0.159250634512113, 0.033217013152616645, 0.03879230612167909, 0.17198951223925238, 0.9505824888906172, 1.5836580602392074, 4.9819617021468385, 8.436045492849043, 4.512607455253601, 6.785981828166593, 6.587459887227705, 5.380673571940392, 2.631146013736725, 0.9138234452374521, 0.5395761949400748, 0.31787090123661105, 0.17772833816707137, 0.30718235058649895, 0.3271827918867911, 0.29699549559623967, 0.3166515650528093, 0.3645640521520569, 0.10644404067387504, 0.11220870674738001, 0.13349793010180996, 0.10511379028039594, 0.054033269144354336, 0.0734060546082835, 0.05887871780883401, 0.13014787357420693, 0.057944557854845646, 0.06078178363461649, 0.05253944748772248, 0.06335101270627591, 0.06115735823949499, 0.07648594256850981, 0.09918671356694353, 0.035717110449989, 0.06717491759768418, 0.026005436816523154, 0.025026828441168034, 0.025238755174101363, 0.023636357791181055, 0.015649309911344562, 0.06282683236584549, 0.033408550455445246, 0.06291129355949741, 0.014048047296162096, 0.0058725709940547184, 0.019429613866152304, 0.04439730031956588, 0.050162996781328996, 0.07633035011108845, 0.0676608854724515, 0.05655666700594368, 0.04272216097301534, 0.031543854143350356, 0.013178461850921233, 0.029777197933365262, 0.027459833673351718, 0.04995220385852361, 0.040485709004344485, 0.08037331018356547, 0.03601200833556152, 0.038367387793597676, 0.051121518331309485, 0.04321948610126011, 0.012274846780083835, 0.02179721434180054, 0.003037480684372807, 0.05239766376513628, 0.031894511738491636, 0.03158219301352098, 0.048667030078509164, 0.040963878104042624, 0.03905311309462113, 0.0429426142645459, 0.03634097798156642, 0.012820065810134815, 0.03644993866703684, 0.04281584586527559, 0.0690868891955864, 0.03486508278236274, 0.031350472483844045, 0.0317555682868847, 0.05915063688711775, 0.02382874928204523, 0.033362520062514854, 0.02676543817224522, 0.04789138903781291, 0.02878942714643575, 0.03150792845014123, 0.08506661761672267, 0.015299125375496525, 0.0627121298513826, 0.044417000270538756, 0.02771359072217057, 0.045450563963142135, 0.09379739993281903, 0.04996403991695374, 0.05404261541703055, 0.023762643555059068, 0.061373314594910036, 0.06007613621712212, 0.04983949700310346, 0.054256104969329415, 0.08090634650040059, 0.04505427051035147, 0.033589580862392346, 0.009178647850339693, 0.05973664818391685, 0.026191877719435482, 0.013732767641364087, 0.044517618258513754, 0.031923569453459595, 0.028594448193607312, 0.05351723997943825, 0.029610175444113634, 0.014516141382046046, 0.03236993058254162, 0.027218544705500527, 0.044161249477896965, 0.08226416839827454, 0.03116015134559524, 0.002454838019818248, 0.0150370869162162, 0.011319577273341918, 0.04848626014145632, 0.030617874093173496, 0.02449780450983634, 0.0221119481589525, 0.06502991737497431, 0.030183222618014104, 0.029182640925770807, 0.029583274266652526, 0.030446640035558133, 0.025692742708469593, 0.03632924151456645, 0.006769364051926401, 0.05059021720362287, 0.05155070376912913, 0.0873953793498297, 0.013215100005899948, 0.03222891677831931, 0.015380854508088482, 0.050505376796448426, 0.03485002915465063, 0.038758199887290117, 0.07245353918762938, 0.029538285753299153, 0.04089473483843669, 0.02403931046325353, 0.03451302324632003, 0.031586025368362185, 0.07225351363059974, 0.09565508654040676, 0.08824222826308782, 0.05694575540180649, 0.026464729509767027, 0.021078101013817137, 0.03067033579422822, 0.04130235107074823, 0.03231645381498722, 0.01668232680869199, 0.055049511588989734, 0.04462456413274331, 0.03713255748152733, 0.026565267058509975, 0.027174404634523298, 0.0660236636477132, 0.010529651565687552, 0.12560671886369107, 0.10289836359480697, 0.1233602962606857, 0.03316157519997608, 0.06632623007340778, 0.04942119767468783, 0.031022182740871946, 0.039235687168735656, 0.16122262143800337, 1.1270687993495696, 1.6663415008975615, 4.680011762726692, 8.32376862725904, 4.9036280474355145, 6.8696307847576765, 6.696917058960085, 4.575268789645165, 2.6168636833467795, 1.0052103801600396, 0.8228680323208533, 0.1579409459185216, 0.21783711659091137, 0.3970053016899094, 0.6252846410197597, 0.29640159359382046, 0.24050506072178965, 0.3458606283510885, 0.06589076271460903, 0.06962462163139736, 0.19059222612169482, 0.07419934631475518, 0.0531309018392236, 0.04446647039824917, 0.06403582253222985, 0.0915716004167353, 0.039815654031812184, 0.03655420323353141, 0.046101662089988116, 0.05313633723304637, 0.03509370257116614, 0.05047733797841976, 0.05740789411168906, 0.05992745770321739, 0.05675637080604511, 0.050800504508398237, 0.02631603950454343, 0.032818245235830545, 0.03979111240515786, 0.026850472016620542, 0.05474697580681213, 0.026766730945617444, 0.05117699458834626, 0.08559224586332999, 0.014754441649382635, 0.04530709101668289, 0.04979370792786922, 0.047430196446516824, 0.05050664084152349, 0.01291604417811839, 0.02451738954762057, 0.05630738582582243, 0.025297219174042828, 0.07533890976300163, 0.025768736715338407, 0.031368578971934416, 0.03731484044223063, 0.022616777118415605, 0.034395919046214515, 0.008199010044336319, 0.03748159863114838, 0.011433381549713593, 0.02757125733149869, 0.02512937888593203, 0.026525602856230353, 0.06407310803150458, 0.034159960135096507, 0.06533455989894367, 0.01935456789308979, 0.03752312059664438, 0.018440245785900665, 0.05972186651741786, 0.009537813809490012, 0.048467299465330384, 0.019433781384460388, 0.012734988873313754, 0.06596317334521203, 0.04356301141782634, 0.0222657747837084, 0.028228417129045533, 0.10823647957295181, 0.015737130400544454, 0.024249758646492998, 0.04363935974036013, 0.028986085747038166, 0.023565475505987005, 0.05466549852562528, 0.020996889948183974, 0.12479789855499422, 0.0496105094920964, 0.020274693116305337, 0.051242269109934575, 0.054300426986188664, 0.06334432858913656, 0.041235015772643595, 0.03176174870121383, 0.013054457113837764, 0.013542345954075217, 0.024568047111613617, 0.15122750293343298, 0.1384950297013406, 0.20097860105095372, 0.23531830839572415, 0.1285479449096226, 0.13929465695494606, 0.14454847261790307, 0.10446313648454605, 0.11948799759510065, 0.11917202463073116, 0.23371932968016595, 0.10411203072796907, 0.1973590194698303, 0.1436303622059284, 0.12211425425184351, 0.1831754684568413, 0.22413088128932063, 0.1325873579950102, 0.14591140432223199, 0.1828476441122832, 0.08262341766948662, 0.1736580977036107, 0.13060404828959896, 0.05135205717036321, 0.23883557127368069, 0.09351199387662834, 0.09445687906155664, 0.11021496292444007, 0.17198251019562447, 0.13666821643710136, 0.14657475985586643, 0.10294144071878926, 0.07446884838563782, 0.12455984439340331, 0.08856372472139136, 0.1383005046556073, 0.10589516931964506, 0.11619295384134017, 0.12193509692987128, 0.10258561586059871, 0.1219712716016558, 0.19571631245555418, 0.1167261893410356, 0.11228767509061484, 0.057825714635152015, 0.11278156431451922, 0.28421236863059385, 0.12467842714320268, 0.13751972316493913, 0.11170911782931899, 0.07134517083965963, 0.1819833283943515, 0.15127968884283496, 0.16683467513611241, 0.13179954381719713, 0.21132449589429364, 0.12944967636177618, 0.11951576828235581, 0.15966361719033412, 0.10651036090548001, 0.11423273402596675, 0.1890655661061887, 0.17192094737002928, 0.13777844637872713, 0.14681773230193124, 0.08331921702671437, 0.15417651243267522, 0.1634691283106804, 0.3547339796298935, 0.189015188164288, 0.25007886151152275, 0.12053250485370237, 0.21561218275418206, 0.2876070574406655, 0.14271125587965214, 0.21132783603764352, 0.4160900534160676, 2.16849779409747, 3.207329199198754, 8.279658632893717, 13.646047422962805, 9.188256071459863, 11.608664412652294, 12.23222811375895, 9.437454054432532, 4.675777564125677, 2.059939580578958, 1.7637035539073331, 0.5825827162592643, 0.49753954093302455, 0.7520054509082149, 1.3132270617831139, 0.503450276991052, 0.622769421146762, 0.9168769491295662, 0.13703014701604843, 0.2325900241492256, 0.3944435649581494, 0.19573250755427346, 0.18412793025134072, 0.09302565827965738, 0.20535993449870618, 0.22426372093539085, 0.1470945964777662, 0.12246161383847076, 0.1386057600499161, 0.1344903357206814, 0.16363700881840723, 0.21560314291667557, 0.18465703653712429, 0.1634058800916518, 0.15074119031909974, 0.1237742978358461, 0.11999065086485879, 0.11894153941783214, 0.11191779251901374, 0.1448078087020305, 0.29230866160604263, 0.13882601032814673, 0.16132236608574468, 0.22152371554365083, 0.07803286560961316, 0.14947798794075368, 0.14111072966648688, 0.18390610183198608, 0.3036292654372031, 0.13166348660184493, 0.1576194954254935, 0.18560562192672686, 0.1886552340921856, 0.18392569836108916, 0.13667347180026193, 0.07880962513867887, 0.060392519038531094, 0.12638533232553353, 0.1777651103874368, 0.10336051379600841, 0.16313486882755834, 0.08858611747141808, 0.10663844314554047, 0.19920040372638934, 0.051404936389336665, 0.16755852097224805, 0.09620924390131429, 0.11657881700704176, 0.10191837626118815, 0.1680466262323241, 0.09311173591882953, 0.10594923980534078, 0.14180187887001422, 0.17163800045607552, 0.19540158821450127, 0.08581867081023033, 0.1379508468052072, 0.1756345279394619, 0.17060514539480212, 0.1547761907380435, 0.14648457598542014, 0.1524126409522949, 0.16082679912928613, 0.14665133800477753, 0.11297064247511088, 0.07253337321021865, 0.12743209954351187, 0.165748561642343, 0.18365218965036256, 0.14034543847364767, 0.16121191152882192, 0.1278018595410451, 0.1395347182668986, 0.15411675757458135, 0.1787123168187757, 0.17702027374217588, 0.18058440587933988, 0.08995487910485075, 0.14616669546211922], [0.063352529560366, 0.03995261523091505, 0.047659302701152144, 0.06792895495891571, 0.061105938418017286, 0.030847043550062566, 0.08037658903988139, 0.021129260365400585, 0.05785091509742122, 0.06521210840512669, 0.03575054635744422, 0.047320121103116584, 0.03898911410942674, 0.026682302310702302, 0.041586217290211114, 0.041093818107319456, 0.041479784694890824, 0.017332275803651542, 0.04512411474640812, 0.04376047824118887, 0.06373569992701374, 0.03462615145009852, 0.01839005936598105, 0.040213008516377984, 0.020540826315540942, 0.04509076310862457, 0.02493968785500094, 0.0030930725728056485, 0.02763913846724937, 0.011906114297979062, 0.02692314886277722, 0.04032813237919923, 0.05374053928760752, 0.022386732406073043, 0.040777002446233265, 0.009461949079958423, 0.08634643644214639, 0.023793775453082016, 0.002318150697148315, 0.02722450678477124, 0.09070273413653336, 0.03337003155461243, 0.08448948527896598, 0.04004264971421611, 0.027357873116289417, 0.021986240791457317, 0.04562447741327267, 0.07491290359006775, 0.04689165578794576, 0.07074627394397413, 0.03138229386099885, 0.01690090126958826, 0.0320145232422698, 0.03724371683934043, 0.05267880271158872, 0.07569474994295067, 0.08649816781642937, 0.06126283322490993, 0.005909680293106865, 0.04321990744961847, 0.020635292617483966, 0.023674794337562016, 0.05517510404329627, 0.031145134107059533, 0.025921946639315258, 0.070155497580286, 0.05151532582878586, 0.05312416026548994, 0.041011532603372494, 0.09612363357577594, 0.20626549639048117, 0.22316217843082645, 0.5274354173771797, 2.818027340596722, 8.757684749941673, 19.12231945222424, 29.333772851574807, 41.35667485575522, 50.247581928007065, 59.29003369423651, 66.39469731238582, 75.21273459157636, 65.4871000782136, 64.58426852380076, 59.73292027750323, 46.22283004945325, 36.87563365505588, 35.57801554279943, 30.6796282722104, 29.343549359229307, 36.902419520962624, 37.33702598079559, 29.255470575824862, 27.547931440414924, 20.707663028470932, 17.877423878638975, 12.348304775453384, 6.744755756470465, 6.925166153138684, 3.2844263267132545, 0.7726959535671819, 0.26368256057462386, 0.21271226416912772, 0.06015960149647248, 0.014651852900222426, 0.03259937774630324, 0.06623071423100849, 0.046173417715415846, 0.023191434992176872, 0.020018838901793765, 0.05508584330879873, 0.05505055346856675, 0.00329686273377569, 0.02385545127664603, 0.06287321132878143, 0.010285974318732419, 0.040695195747238976, 0.03172689170065907, 0.027970764523131714, 0.027397495183733203, 0.07117844712469848, 0.07676223983928081, 0.0583908193924975, 0.05236049700948981, 0.014083994056789145, 0.07068389906517922, 0.05864419914301365, 0.07463932593142794, 0.08447892858736938, 0.033360083902915644, 0.09609849057010106, 0.08514128054582304, 0.03396330919537333, 0.041120060449165684, 0.0517211161974457, 0.041796906791146726, 0.04110411049858217, 0.012771775457827796, 0.06628196551314285, 0.03920931076150268, 0.03658905640364655, 0.004148742929476524, 0.07649081488770824, 0.06616509880029386, 0.04305547433755091, 0.017729103602769396, 0.024928583410538496, 0.06129012510721242, 0.01603749911150625, 0.018424496933397268, 0.08448559355231063, 0.03286472762063627, 0.06135407429669173, 0.024598349719458533, 0.06273477157998471, 0.007603951249151461, 0.027384109712476214, 0.034123869732983654, 0.068728260455593, 0.03248450286205738, 0.02460339632365973, 0.06308074071702939, 0.09173955753325455, 0.08450395667985564, 0.029163021414029985, 0.024248764647411245, 0.06293703411375323, 0.09999944858493344, 0.036974337342525684, 0.10559379033023313, 0.04637549638808255, 0.0932529412450329, 0.041502617945474, 0.10194718882802034, 0.02842173367107828, 0.03275095207256175, 0.052078710718741344, 0.07547392509877682, 0.09095676123134552, 0.08757898764264199, 0.06482453686335395, 0.026236138449260787, 0.06516814261915223, 0.029466643125840256, 0.10836685241590585, 0.13127864999396185, 0.008131355862133205, 0.04308487679208479, 0.03765337469597017, 0.03588148610546224, 0.03324579507593186, 0.0034172544086862717, 0.062189914526477943, 0.027096474340425867, 0.0422605125594043, 0.049518808767560034, 0.033771928940569206, 0.023024196083086635, 0.05878260824829341, 0.11572377861387308, 0.024380462822474303, 0.07001216252965313, 0.030661698152881958, 0.02404466350262444, 0.032411008217041536, 0.038616645991081194, 0.01425653142148569, 0.09926300826332263, 0.049855615493030324, 0.026437169496691035, 0.030754314352487846, 0.018410228545807542, 0.03098393005559281, 0.026293899563531724, 0.03280806009687724, 0.05433229624383873, 0.04512891428725374, 0.012441868311725559, 0.015670336152036345, 0.06715260145644988, 0.012881887190404439, 0.030298128145776933, 0.017044178863626816, 0.04621829131558057, 0.029533041881457455, 0.0578237611109451, 0.04919942288148788, 0.008334242757560026, 0.04799983261393444, 0.02593235968942604, 0.019904448568160017, 0.03690660750914005, 0.027958671825246948, 0.028261276555337736, 0.027414192070042896, 0.0253473270699502, 0.05106853952090587, 0.02795083857622118, 0.042534377501015706, 0.02685306330902442, 0.0658153030540674, 0.11288312459064108, 0.02107904521718381, 0.0212996268284417, 0.02539552549170631, 0.04274939539872351, 0.2895914396691707, 0.3351233238654752, 0.912212576837309, 3.1397916232385947, 10.018190376220211, 21.336311101913456, 34.1722184611905, 46.307831733457505, 56.47423867256411, 68.28436974556216, 74.56826563804381, 81.67221930719192, 74.44460115125104, 71.3539852634553, 66.61842146227437, 52.165566029087195, 40.553973567101266, 39.86258914393764, 34.120960927778675, 32.15978760873118, 41.15235467110911, 44.99406914557181, 36.5054952713751, 32.278152973421165, 24.67108668819551, 21.44494898857609, 13.90708508030061, 9.048133319424046, 8.058118262598592, 4.060374844458796, 1.292382851243019, 0.6494242553749393, 0.26118051741392384, 0.1316217501317301, 0.06198285628230341, 0.058605998168669404, 0.00995654501997295, 0.11641465968662694, 0.02778646483596775, 0.020648007761807214, 0.022123757404305285, 0.07000018857539662, 0.03246032895760671, 0.05805087553697729, 0.05427869690221645, 0.01091359089308929, 0.02329040589111467, 0.13727414601993176, 0.0766084093840853, 0.0917650529393746, 0.04772010326926266, 0.02066654134391537, 0.02689615766998501, 0.0682698947287375, 0.02652056965856783, 0.0356776837349659, 0.026705200678759047, 0.0682415264929014, 0.05431527760060084, 0.018186387230431842, 0.07385709653458289, 0.0034363141974374173, 0.09891351129138663, 0.07252433337271214, 0.018690712487084732, 0.031006144690177137, 0.01073840669461436, 0.08080569786890861, 0.06818736407665477, 0.05370813376841046, 0.0737680234916268, 0.07268290591215895, 0.015843553419765687, 0.04216516142590873, 0.020528072866821484, 0.053406524952621236, 0.04707784579706289, 0.022658490605892676, 0.08530660998076202, 0.05437259246865588, 0.04613775249210097, 0.04168791929259897, 0.05480531723268571, 0.09318266799973865, 0.09643776026824791, 0.04676181537609908, 0.027734005050132834, 0.04775974065846494, 0.08183820052973687, 0.031523112312800465, 0.035869473846809524, 0.04681048494192862, 0.11601065555887839, 0.03546314464221078, 0.008995730951879053, 0.0876620851997887, 0.03385087813160593, 0.05419060062136381, 0.07521065132271859, 0.06579271112118038, 0.05188392903355341, 0.0014446572458837183, 0.06826096214354038, 0.042584387720712734, 0.05627001605687603, 0.052058095292698954, 0.18553537166407033, 0.16413035411988536, 0.15024677249452761, 0.35601221265331395, 0.22242757672023392, 0.18363790977145397, 0.1862005198434476, 0.11949694550205624, 0.21991531394662397, 0.180216928823821, 0.14190087275158975, 0.3031237393377289, 0.10103798801860503, 0.16327144698269908, 0.18165023336487432, 0.16445436334658056, 0.1538752253738142, 0.17991751101949524, 0.09548015036289731, 0.11265138299354624, 0.08988229227402518, 0.14950967333730192, 0.12523741851891243, 0.16236741726677265, 0.11513006047255571, 0.150588677535134, 0.12424045467689154, 0.11079118361756687, 0.0869289773606485, 0.14385882494670732, 0.22937797070030244, 0.184587613649426, 0.10596606309615797, 0.20604950556110954, 0.1561393369469912, 0.14303436112259665, 0.19065308414639967, 0.10892044287174941, 0.1678787610463558, 0.14588920309418632, 0.17883222490068407, 0.1875145138511735, 0.1869405148130271, 0.20901886235562064, 0.13546997831473429, 0.2258862951590169, 0.1513294998796717, 0.16602659027182287, 0.1485608121560466, 0.1779243953886532, 0.17868073867453685, 0.09999473714419913, 0.1330260046186947, 0.10376191322481441, 0.16187799433546682, 0.12389255882871729, 0.2536588976339948, 0.20899754978956717, 0.1755010294577768, 0.1493592289907317, 0.13225009544722496, 0.13095811880644292, 0.12466845267842855, 0.1344672151871266, 0.25475006730806443, 0.18535659738606025, 0.10375100413277265, 0.13258764910842144, 0.14345457567082298, 0.16751756591181602, 0.6029569165360543, 0.7234186655090702, 1.5779344641393231, 5.022177273227323, 14.814904908980093, 30.02933067660178, 47.594220099910615, 64.19231783959174, 74.31954814541724, 87.93781342044954, 93.77360989970546, 103.77948207239952, 97.52280742891374, 92.84052510415354, 83.4562623116278, 70.4672707280805, 56.28889883718183, 55.29072623099051, 47.15411839946624, 47.072462497218964, 59.596712050899384, 58.340325893894324, 51.93774300236856, 46.43555979574881, 37.239335429283884, 32.38597500708796, 21.234315749137632, 13.68118303437387, 11.17523270268594, 6.5162222904543725, 3.004089137238841, 1.4570510603727833, 0.42407167835101006, 0.3103535562272995, 0.29277438177697124, 0.14829565380369464, 0.11962331170516631, 0.1641091181626243, 0.27867747530821835, 0.1324774703431514, 0.20401073108998038, 0.19922151710958252, 0.0945389117564886, 0.1770910755881379, 0.19216652148433272, 0.1659308599248048, 0.07435831721992263, 0.1647813756379389, 0.09136101050722985, 0.17362673406399068, 0.15936369376797832, 0.16595810201139222, 0.16101450599249334, 0.15570208460332888, 0.12610685936505758, 0.19664689477893615, 0.10673512344158466, 0.229594053460225, 0.3104844346882836, 0.0852088341789861, 0.14213030076315328, 0.14473006609947453, 0.1813572813426295, 0.1433623540064981, 0.17232159603266947, 0.06558640364317164, 0.08471041737544922, 0.15352067988245718, 0.19176974922658938, 0.13588835425194234, 0.18189774105145087, 0.10807398466333266, 0.11926811503907365, 0.15895998075364098, 0.09250480276081832, 0.242120924015199, 0.11662075266001687, 0.10929414822209267, 0.22557953823237653, 0.15781564457762629, 0.14105860504411882, 0.12087247935273956, 0.1820062037797705, 0.20684062923875549, 0.18108987069178015, 0.11984600580387539, 0.20996692680543472, 0.15414763091792985, 0.13590225108688878, 0.12784779417298495, 0.06715675365299949, 0.14707621036758348, 0.32227474234757886, 0.15408107319906836, 0.12567035778756105, 0.23607733298934278, 0.11799714452917538, 0.1715359115792859, 0.21789590617822063, 0.15212135900172497, 0.29574738515000193, 0.2123112324625254, 0.17460380260261799, 0.20270170133200385, 0.1957129723122043, 0.14721453520319155], [0.060925007602500345, 0.08900336725937744, 0.11066258043771791, 0.04000074853519759, 0.03532952358645778, 0.052566927061566425, 0.02925685760865529, 0.04498239231085585, 0.07684065659921016, 0.07004334996905058, 0.07279710663903145, 0.06352736614644527, 0.05390902883523414, 0.044644765871306585, 0.025846820227020693, 0.03185830259275052, 0.033855275476291295, 0.050729993775847464, 0.005506156406725847, 0.04639160721713016, 0.06075365671647653, 0.04653141826331135, 0.0664794170147469, 0.014098075710447326, 0.015188472593323359, 0.026547315703224272, 0.06664859221106575, 0.023137624976375414, 0.046537661879894235, 0.025179818114866654, 0.07480325342546548, 0.013831793124066486, 0.0379431359620104, 0.02625252890040077, 0.08484700319146918, 0.05777418756136491, 0.024021671288796974, 0.04874810133309615, 0.04464943134676545, 0.03124515071601397, 0.09585338073872751, 0.03236317368704946, 0.033332144676317135, 0.06980610019978016, 0.02234949478729358, 0.027204464009452253, 0.04470645510140927, 0.022541445777601293, 0.031429965597307014, 0.037985803228953195, 0.08042947975017371, 0.01605206244294682, 0.0449076259598857, 0.09047592614567088, 0.05271040383846529, 0.03415460901094541, 0.01562714698769513, 0.08186429348443786, 0.015150889277368065, 0.0449424714691216, 0.011900754555338814, 0.07005288776370787, 0.053210253226420576, 0.14077257845670949, 0.15960824435516713, 0.6870552296600034, 2.8027016597409404, 3.8267984361417837, 12.32401647875386, 12.578503777903896, 23.413086475864535, 31.19542387224013, 47.26882419278545, 61.46790227582378, 77.64603968589537, 87.31854177290394, 86.96865850879301, 91.06146350983651, 97.53503737911102, 90.76011565423782, 92.02031827742054, 92.9934504724318, 92.16261402253183, 90.48280408305507, 90.27284745247134, 94.0756167134931, 97.08321955896194, 92.10399812267673, 99.27500863229075, 93.29931689846902, 96.43554995136877, 97.86523818969728, 98.99675569226666, 92.15719330695369, 88.74380557767807, 81.13660397068148, 73.73255760438981, 65.76532556164649, 70.30664966952416, 59.12330942769205, 38.26741610803912, 32.119475449285204, 14.444933226031644, 4.157642760584432, 1.486333269746073, 0.25679014412866485, 0.18293937548033654, 0.1361261326218805, 0.023813383473503976, 0.05445789252858489, 0.042627001361500834, 0.035669816011983546, 0.12338996684599308, 0.013829813744392128, 0.01624498444969856, 0.016427125684135867, 0.017572517146266276, 0.036030685559155486, 0.03630042128685502, 0.08051109875762656, 0.06333683241879748, 0.04870973181940856, 0.0943927651631736, 0.02101638114019748, 0.07357980334951032, 0.05620741518214346, 0.02915325570821522, 0.047522383636885115, 0.046160034159378666, 0.07123878420961481, 0.03911211335610959, 0.05294857674368447, 0.05211110474661954, 0.03137201679149463, 0.038579283883014036, 0.045155286864047094, 0.07081142972193419, 0.011486397706903519, 0.037830199280212966, 0.045992820148145964, 0.03089337654772305, 0.034361364650389845, 0.06995412370850963, 0.007737950082012122, 0.033444705975031665, 0.027623734354311903, 0.06619319124447723, 0.04898495656708556, 0.055641444745443525, 0.04006164103385903, 0.048748855929701566, 0.08513370393625191, 0.020412104392063715, 0.07112168767038854, 0.02992886802061431, 0.03637999483955003, 0.031205693357473904, 0.03718369385047305, 0.019293093167605902, 0.10816382379421305, 0.03579460790440921, 0.03141099917552164, 0.04048615716578018, 0.024312566364965132, 0.03185612115738613, 0.019100872131304878, 0.09512106197014933, 0.04748083102787214, 0.012931144728715862, 0.025153876462530707, 0.08593778216069745, 0.021823316872600588, 0.04704709502778227, 0.005998050450392429, 0.05804530224732815, 0.006408022403071124, 0.09527752776780436, 0.04903715013736679, 0.07274398610236184, 0.005386404894036992, 0.05482466478321341, 0.02706154647673811, 0.0098733315920277, 0.056177748427275694, 0.049497898397666794, 0.06451972580004124, 0.06422276330751277, 0.01859704866224239, 0.054506765107714364, 0.04848378950790052, 0.07130175663699066, 0.04435403550404214, 0.026341102070986267, 0.04319960995006465, 0.022129277067799723, 0.0412523944772059, 0.1191502141075269, 0.04759469084561833, 0.01951331471753938, 0.03225765273635907, 0.025997130508204142, 0.03608456452287013, 0.11236923281103374, 0.027022037407263156, 0.012034925279177487, 0.038695499421127384, 0.07069290825916875, 0.055072061387040926, 0.07884584577573885, 0.06586280050537278, 0.047767604551007675, 0.06587315035322983, 0.1043011395320777, 0.04004691682395436, 0.09821486208708056, 0.0030386393923582814, 0.0529392036579309, 0.06422352939543706, 0.047148352699174036, 0.03364505328898949, 0.0445197020176678, 0.030555955036693526, 0.04110070523775874, 0.026296877730337363, 0.04461008507097441, 0.02166146164639823, 0.024427232490251624, 0.005769671979285176, 0.027841874060311148, 0.009962563598228079, 0.04905007021020978, 0.03256968417835813, 0.003574107320145554, 0.016626927160447644, 0.012003730178900785, 0.04940728934842253, 0.07404715528771763, 0.0879880479506908, 0.015577895195043136, 0.03678355846674212, 0.15091667041903542, 0.7948735861047622, 2.4201987395363473, 4.18594217108142, 13.033554611667512, 14.814490118334371, 27.25811339193775, 36.361120670072495, 55.57164638273178, 71.81878612887475, 90.88498038630333, 102.31326087828606, 103.23039731671734, 106.6797374909924, 113.14901244255805, 101.96412286450787, 103.8286764391007, 111.3080087784798, 106.52247398130356, 110.69619747900195, 104.42351956521313, 108.91202111398022, 110.68301831522297, 105.205914743485, 116.30990151436099, 108.98009777069093, 113.53835475060248, 112.41527818864392, 111.87679167716735, 108.80446187911495, 103.29142155185824, 94.59001987211167, 88.36079397509175, 78.55612370275682, 84.5987153822376, 71.25663988051876, 49.72350620454358, 39.715092335977864, 18.96287706590468, 5.12803468973406, 1.600468235631143, 0.2541847557069794, 0.1657274942244253, 0.0715651223435998, 0.13341736829569265, 0.08552376526377856, 0.042947639801329186, 0.016705102602680846, 0.06582632705929779, 0.04524016557561775, 0.03002768761718706, 0.051238408026796196, 0.04127045116958119, 0.04893027704149004, 0.015265271950122571, 0.04438923341372321, 0.04795073020842768, 0.052707140303907864, 0.0275036788004781, 0.06152090909440191, 0.08240475319325924, 0.04314065565385165, 0.04391603622465365, 0.14532128679415873, 0.02978882714805584, 0.053459733589402134, 0.029208670678218047, 0.039366370277299036, 0.03063935902900994, 0.09527085514198388, 0.06236920591383692, 0.04046853331308212, 0.0331561551279118, 0.023275953642423117, 0.02210560686615927, 0.05569194909185172, 0.027042311924179236, 0.07349178750788973, 0.027324326126085176, 0.04296341738212974, 0.028293417774200923, 0.041425997661727096, 0.03150829617234488, 0.07418017113401044, 0.08467533820939642, 0.03630964881590298, 0.031040396481271715, 0.10691957443111366, 0.09566729032104054, 0.03314485916146829, 0.04373617027135145, 0.08914579832625967, 0.10048978316086916, 0.06700306875450958, 0.11490992510751372, 0.0737050434033717, 0.03417262356848486, 0.028021699793997313, 0.13520160239310036, 0.03247136062371635, 0.03554507008483333, 0.056175729785595215, 0.04981524265942074, 0.058909380478003336, 0.028717148665999694, 0.022119417516214233, 0.10790158423685259, 0.03192997394850658, 0.06327390595669709, 0.04452890273363841, 0.09286514753776212, 0.0518341716228714, 0.13048895123985507, 0.2552011245561223, 0.20445201305612443, 0.15790999596638067, 0.11120602022856475, 0.13965355382571298, 0.12253361844247389, 0.13876881420371995, 0.08797120933811511, 0.22773887962102893, 0.17044255089375282, 0.14438302826977548, 0.24227110789187495, 0.12331073803286399, 0.20706858636150438, 0.14425089342459557, 0.1492295762704265, 0.1201637714139877, 0.08125191344128502, 0.09333361796433888, 0.2294184967514969, 0.19354436125966812, 0.11892762726112721, 0.18182356841862204, 0.24909497479036932, 0.1376059999869716, 0.30138637449952865, 0.08147932664160767, 0.142941388692106, 0.09892510220168099, 0.3492411598563195, 0.2026970588391827, 0.2019106849066673, 0.30712179899696385, 0.1890281963372423, 0.16700413378496326, 0.2007244743647114, 0.17006505340818437, 0.2588668093085289, 0.10928886221541513, 0.13262655105321638, 0.1499812310982135, 0.07756848609255207, 0.16433917436628573, 0.14544415197545482, 0.10383712773722026, 0.20661153830587867, 0.1480119561235751, 0.12231993353775433, 0.1725685827794575, 0.24619764558249907, 0.06815550247988394, 0.2316405347758724, 0.1870906374026691, 0.1988736825484422, 0.16815986934929125, 0.16094306063267494, 0.18503608152029977, 0.08117365755981977, 0.14545582715542088, 0.20637208986426556, 0.1930084980783924, 0.17794912470684898, 0.2910679668909119, 0.4623243176648694, 1.760891582215986, 3.5526340767260525, 6.876596423887438, 18.556743091152562, 22.70130180543469, 37.21024713208599, 48.66080276427731, 71.30558321552893, 87.46151216568487, 106.96662749013593, 117.79674653084048, 119.18081760406496, 119.44713084928452, 127.80240689554523, 118.66886984917426, 120.97510583939092, 123.15092302137806, 122.20294890865203, 121.21560988887664, 120.64153963519682, 126.23950712142454, 126.99596758811705, 124.30155031142698, 131.45066615073912, 124.06118746726744, 128.9110726694907, 129.5188125487297, 131.06311244349328, 124.0577357815158, 122.86358587203489, 110.65426734185989, 106.51285632964104, 96.24039634581536, 103.25142122084095, 86.86523345208938, 67.5569740418465, 53.82281057296261, 27.55797859161131, 8.725471304308984, 3.3733905851840977, 0.6190307282151715, 0.49675399437546736, 0.13612869135554762, 0.2956828805467775, 0.20168435189031786, 0.1923644632822083, 0.08113142313255418, 0.1944086310123244, 0.2919694991602052, 0.07427986215559707, 0.20308851444673157, 0.21285097204869796, 0.1400487479423323, 0.08405571863535913, 0.10772284826323872, 0.1822634407829854, 0.14035936595211107, 0.17674808270267903, 0.15719129824109618, 0.21096821904422777, 0.20324168606631218, 0.08866188356712942, 0.230386219017448, 0.12720316948909915, 0.1944294532821063, 0.09587761209977251, 0.1540086319249484, 0.14025726175356296, 0.23970799220185127, 0.18620309389887318, 0.12053189198336295, 0.1388202033816807, 0.16225146219855355, 0.18257257258219106, 0.12039336796489455, 0.07223996919609847, 0.1626000015605842, 0.11795021398293397, 0.10906726362243777, 0.1104067913406799, 0.19663175688155238, 0.15453658907884552, 0.14536824798391712, 0.20688225845656089, 0.16384117125022798, 0.2172741338971161, 0.28741492258925594, 0.14230599536770774, 0.16790669261207505, 0.15245400970020603, 0.2519924878593414, 0.16508065554643833, 0.15766546070095033, 0.2045174216430995, 0.27657551390509455, 0.12925558032528048, 0.10528275097209601, 0.21439990990104216, 0.09988660383368693, 0.09621172602618895, 0.15314200262148536, 0.14906580199397382, 0.29168564826250076, 0.09562788275821556, 0.13346875747365336, 0.19971518416798886, 0.12015755078004253, 0.11399669467561668, 0.11600149314730399, 0.3247555495510179, 0.16809824523666214], [0.02775272249334282, 0.04350906733663813, 0.014083739332554322, 0.013196311699556968, 0.01858765642429071, 0.03684212205811374, 0.05696580009234529, 0.020751833742965135, 0.053443013720454714, 0.04739153964985763, 0.044755519202519814, 0.08363204136971505, 0.06467540252713427, 0.008936028762329972, 0.014966044710167955, 0.08344257250428201, 0.05741462419410387, 0.015956153980486335, 0.055083575688542864, 0.0645049173204649, 0.05410380285954284, 0.04506615253405706, 0.004064764850021851, 0.035117179335605715, 0.017325367605794343, 0.03597227135492909, 0.05600991005438471, 0.015420402839569556, 0.04010565278510894, 0.03995472197270682, 0.020298591229103265, 0.012980360132191452, 0.010889373896192881, 0.007769143267069013, 0.05159953038298315, 0.026392954732141188, 0.011043101887128527, 0.09792227012616012, 0.09760087325928674, 0.04594459491331251, 0.0281900208022806, 0.039275914445639624, 0.03406905614200138, 0.026103252837915095, 0.10036258958280088, 0.055487292533319806, 0.06257156037815637, 0.11837920789877254, 0.038925563285668055, 0.023025542482613556, 0.03818456857134739, 0.047803943931695916, 0.04621571726015499, 0.036291546158252225, 0.03051986080414105, 0.033010383917679714, 0.0869685841063338, 0.04848812173511233, 0.054609493667920755, 0.013298662961460652, 0.07870299336049827, 1.011100002834874, 3.4927139887886667, 6.435259176838783, 11.49198272535878, 17.100759283188854, 21.75689901075056, 49.03435753237817, 80.27888359562044, 83.66151209800475, 87.9122317221857, 85.50611649790119, 83.88446746333953, 85.27503398156936, 82.3620230151761, 79.64022759468325, 79.16241230503206, 56.66239476973011, 68.86298210390153, 69.83930710823306, 64.64827376027262, 55.519557306843424, 62.345360017591915, 55.64834440908125, 64.58490394776868, 64.48273797189036, 77.19476315283006, 87.82500605429374, 80.5869387042138, 89.8371897974322, 79.06920894499748, 86.62093254827684, 84.46487626721783, 86.42054650091356, 87.85354521966751, 89.45172279111802, 103.90821426145493, 97.08762830303561, 88.45210675270327, 100.47901153564455, 85.62876901318951, 98.480665914474, 77.95167861446258, 57.88157724565076, 31.091649724591164, 17.824299297025128, 7.121683762919519, 3.129529477127137, 0.7375930694322432, 0.1288522503549053, 0.08194946713985936, 0.05925282535533752, 0.06749103611875927, 0.12931007982021378, 0.07523980862911671, 0.056342652683416684, 0.08127003142069425, 0.06328416770444283, 0.03998636523441922, 0.02631928963256219, 0.08657008048988159, 0.029058191857691255, 0.016726761823520064, 0.04463991270430627, 0.032225821783105214, 0.013418687871777484, 0.04966859427851535, 0.024021328464450858, 0.03786457364537543, 0.026812753677668593, 0.07796432372302779, 0.07673851409626585, 0.019421577603826602, 0.04085882829742567, 0.027610856416304747, 0.09333350305115024, 0.04447825666096422, 0.02197649615306047, 0.05019076746858416, 0.049333300576695514, 0.04337246619885968, 0.02875709440559149, 0.01678353276914887, 0.02349996349714216, 0.023356392874472567, 0.017663246854358626, 0.010189904020197931, 0.05412345301480063, 0.016455769711624713, 0.03268718674418426, 0.031441554592381564, 0.011400987521835394, 0.09596350587784283, 0.07538358801074567, 0.036094604105117827, 0.011058269470419374, 0.017642897643869924, 0.017811180347756996, 0.05519804071574923, 0.022287156297675064, 0.013540919115316245, 0.014209585553485782, 0.017075910225450512, 0.03329397051505024, 0.058064121197188096, 0.05350380662768599, 0.006144519758245518, 0.01646384810878625, 0.08687991708997758, 0.04611546316394403, 0.06182130366083115, 0.007772365624400517, 0.09874604447113891, 0.08433248321976393, 0.03638485949786921, 0.049731256440281875, 0.03716798138714606, 0.04188226813810968, 0.013855501630103156, 0.083538394781851, 0.03141911970751901, 0.04900574053247129, 0.022972027410662944, 0.030140589825027896, 0.027623046790399862, 0.0913011177533096, 0.011060019023716451, 0.056345456565219554, 0.048330847714697166, 0.03788194085861887, 0.016103443960028312, 0.051485536499850215, 0.04107275451984137, 0.04590848918944117, 0.03010400338098407, 0.04391055486555542, 0.035552401546268694, 0.06283899784208306, 0.02317261412709711, 0.027727893583716887, 0.02226706181142119, 0.02832096821117786, 0.07268901929379472, 0.05885249461918589, 0.06902173341762635, 0.018601488141763597, 0.05229118903498015, 0.006974014385993923, 0.02833320838098805, 0.024987576011147712, 0.04542185864861935, 0.015274491818291287, 0.02763960003522375, 0.13006401759001518, 0.12885559049825515, 0.059080654755234725, 0.04416400356398475, 0.04181749157367214, 0.08723973326625363, 0.007445243207903038, 0.03832352925993262, 0.05106634084856318, 0.025103000563479243, 0.031502728628355174, 0.017581298429098342, 0.06326302367773268, 0.037778273840705236, 0.030023897397181684, 0.011677213929473393, 0.057018882324618686, 0.06325031810950849, 0.016857479406040043, 0.08209110147530034, 0.01460461208837167, 0.05371450378950085, 0.00825294167659576, 0.050765260633441715, 0.6985550674219286, 3.029899803861495, 6.771931898209357, 12.572599630202017, 19.24709593096087, 29.076794847365353, 56.54161714738416, 89.9484125260384, 96.37995427654636, 100.43361402327015, 100.27431088109171, 98.85513459482502, 97.88706225733604, 96.31064599560153, 91.95698768861833, 93.81305325415828, 72.42148968481249, 89.62936693622221, 92.66861546424128, 87.35893434093845, 76.2054080347861, 87.28073796918316, 72.37994393994732, 82.8011166664862, 80.91011062745126, 94.0983586157522, 108.27317683927475, 95.66942476457166, 103.77449281754033, 91.53910621520012, 103.36480909778227, 101.61109385951873, 97.2337209024737, 97.35727556290166, 104.79338338298183, 117.96161943866362, 111.97125019565706, 102.30117997815533, 113.28409102655228, 99.02187455085017, 112.69121693026636, 89.24380579302388, 65.42414603694793, 37.868452225961995, 20.888545090152373, 8.787520258657395, 3.126487679058506, 0.8111910137438005, 0.17999493186512303, 0.05047012909105228, 0.06875727986616474, 0.07316269145737733, 0.02439441136835564, 0.01774105074394855, 0.01884480724261413, 0.0692809852320821, 0.03207806257470962, 0.06367869915500765, 0.049695732943232984, 0.01835602590994489, 0.07737451263012425, 0.045451261103153236, 0.019107657755094192, 0.03203857457265258, 0.040745140849462444, 0.050490012903126984, 0.0585395093977211, 0.045051976077018246, 0.07190552585187458, 0.06090346137962996, 0.0406543939043918, 0.04175042823678063, 0.0315290973747089, 0.07839535543274495, 0.03757690379936849, 0.03216007611744347, 0.010347051636105584, 0.05380169608660283, 0.06167369767002041, 0.0038761633397605753, 0.061324587572486176, 0.08742897996618863, 0.0633804496347664, 0.02874799711149066, 0.01573321186081176, 0.03561845747753978, 0.0196792800054555, 0.0204824561613702, 0.06222308230315966, 0.012260589883812975, 0.0064257611689578385, 0.0420646085554073, 0.07884816702214942, 0.054272353694203405, 0.01625426752012103, 0.047399158394264604, 0.025473011454807657, 0.031365688905240066, 0.029754263176132115, 0.04004337366730456, 0.04388894735565109, 0.0758843413824516, 0.02546660312932105, 0.07134619739747818, 0.03888821649935938, 0.04671299259268469, 0.005185385816730559, 0.050142833347161936, 0.03987949213854248, 0.030216175890077027, 0.025664839871047486, 0.06455333407727942, 0.024414304756529392, 0.06165027070129591, 0.0982152451310427, 0.11363742242176687, 0.16699339323226484, 0.15021815144967648, 0.14254830897815768, 0.0808389307630639, 0.08375722779742173, 0.13121604528878966, 0.08490170953014205, 0.10599951049493206, 0.1786021840187811, 0.10598108608035312, 0.4251182463861281, 0.15454921420783768, 0.09253515516437831, 0.1500293873851338, 0.23608427374593674, 0.14525206308932076, 0.10841323903972104, 0.15325876974290417, 0.20030792171676315, 0.20449460754471444, 0.12379024778642964, 0.08951829325768257, 0.08245458721273369, 0.09972971668767353, 0.13605739921331406, 0.11320540245862738, 0.13343963081077223, 0.16063205957893403, 0.1804672403922004, 0.1144474761320218, 0.06805068633008389, 0.07641987514591987, 0.14403882496539624, 0.21510788239538672, 0.09750757907186786, 0.08585956458362841, 0.34999762571627097, 0.19794872331042446, 0.24456102130634172, 0.12590253605477272, 0.1408807347498594, 0.12340584018778418, 0.11807276506818111, 0.14545965759504229, 0.1627680199641374, 0.08168834607086836, 0.22361565651672505, 0.12891700010626547, 0.1540817626782002, 0.16637321441404282, 0.1284492421414583, 0.2042903072170673, 0.11441255018355385, 0.17908489601987024, 0.12996597365746576, 0.1975225945634227, 0.24014083187906976, 0.18598656680795456, 0.16006762131808266, 0.19782927488127064, 2.3167351945754024, 4.797733368412142, 10.462450769639785, 18.755034592843828, 28.10961484909058, 39.764239634236986, 68.95700131693195, 104.658336177949, 113.95553019738968, 118.1008557350405, 114.58827910884735, 112.70186224291402, 112.5879095446679, 108.27323959719752, 104.93669894433792, 104.31136331250592, 80.51238229197841, 94.68239953441005, 97.77677305283086, 92.7243523443899, 80.07776014266476, 89.41428769019343, 82.4096013653663, 92.46280870129986, 90.02107051111038, 101.37442588806154, 114.3660140806629, 105.95543261497252, 115.25388179286834, 105.92531665678948, 113.30694275517618, 113.59607635005828, 113.40165230535693, 112.92466855818226, 118.66644582440777, 130.35496773258333, 127.64427261967813, 117.79144348636751, 129.3857422182637, 116.77195672065982, 129.28544721295756, 106.09142118884672, 80.82738784051712, 50.47969602769422, 30.767118700088997, 14.466189530587966, 7.664077445383995, 2.3399215504046413, 0.5754396511662392, 0.17443511004169143, 0.17890408394798157, 0.23588706739246848, 0.18868195523898448, 0.13029146909473405, 0.1342208566324365, 0.1737129342772307, 0.20777280502501996, 0.10879416093831101, 0.10290832273782262, 0.1639811508357525, 0.11100161264860824, 0.08097588430128752, 0.10301173694672124, 0.22154263791538056, 0.09633629192267695, 0.1605707725449916, 0.16137957753192994, 0.1589878663540848, 0.12625116734735428, 0.13741835441079833, 0.17655011026128647, 0.10051258193749575, 0.12837421149015427, 0.13818484070079942, 0.17764785296974644, 0.0847578612005999, 0.26724686125113123, 0.2311231956006058, 0.2690710085293939, 0.1623301087848602, 0.14442358496448687, 0.12708026600340683, 0.17842181627788853, 0.1176912302992517, 0.16651608981192115, 0.1075489539653063, 0.11588434298192302, 0.09401034939313128, 0.09620954267560475, 0.14043431999462266, 0.09554303085972225, 0.25352526125648334, 0.18999311472139052, 0.22769554968803163, 0.12606231135226068, 0.23953147022233856, 0.1171430714067913, 0.10168533231462203, 0.08782456478764934, 0.11229928898354692, 0.08478038418557375, 0.15631846362544646, 0.15862962831893276, 0.11370676870067274, 0.1251229803047834, 0.14303039278714888, 0.16053804526886634, 0.3061747917484853, 0.15759147192922332, 0.11973812530237822, 0.12612768929571877, 0.16300277994765391, 0.1415910821167692, 0.2095681780408467, 0.20021358564976724], [0.060415302493399194, 0.043751319660054105, 0.07276591153875475, 0.07324924407106254, 0.04312342633643458, 0.04737883791207306, 0.028088901026715195, 0.07598882811444421, 0.08542404359867496, 0.010495842190369243, 0.03718256387078474, 0.033329302490118055, 0.033032623450121576, 0.014214535439086538, 0.035607598181213104, 0.08553373972855269, 0.047828891584950115, 0.06818697337181338, 0.031454618306710355, 0.075486519584252, 0.057611654347349564, 0.025936117350694635, 0.0443769185503404, 0.07750059538070234, 0.027511854873849984, 0.03470191371537024, 0.06243013288645495, 0.03291641557288747, 0.038056107117764415, 0.022315896086154446, 0.03189989733659933, 0.07325325837178577, 0.04213238052362877, 0.044926693888321045, 0.08342044022414954, 0.05617430486205605, 0.0188220908204394, 0.034692663203684554, 0.08441921203367173, 0.01462815588550462, 0.04467981822428204, 0.023814126578790527, 0.016905578236365994, 0.04385546165248079, 0.06569316565629936, 0.04655862587594217, 0.07677600643928013, 0.02955296591314818, 0.0249860342592001, 0.015619905541590868, 0.029818647120508458, 0.06170888408838261, 0.04159736003906977, 0.05421487411724464, 0.008811030983774653, 0.11573508607163546, 0.0629702095513142, 0.028543468872686068, 0.594100940131372, 2.2943225262626528, 10.58266160949584, 15.181049339232908, 26.918959771433187, 46.9450560692818, 63.425639598600334, 68.09178921484178, 68.22249827846404, 77.64765570240637, 89.27462777783795, 79.66665652490433, 68.40036992103823, 60.72856687730359, 58.78029815612301, 65.38353381618377, 52.5272556274168, 57.183222770690925, 38.76930298343782, 44.80720743056267, 32.22470283508301, 31.743861436843876, 27.120238158010668, 20.25193656644514, 16.2792061028942, 21.05804051122358, 25.322627675148752, 27.558649316910778, 25.659221949115878, 33.66010988912275, 45.7163736128038, 42.91600135064895, 38.5506739924031, 37.38062312526088, 48.639088523003366, 50.707260177981475, 57.135267872964185, 48.79719141990908, 62.47619851942986, 65.35253532471197, 69.90754065975067, 66.82324763267272, 82.40630657442155, 91.78921222686769, 78.80262113386586, 85.23093085135184, 79.29746735480525, 79.19867069490495, 49.40455475161153, 43.36792507479268, 30.193366158393125, 16.739595282462336, 5.84883394741243, 1.5314541324492426, 0.08797664090149826, 0.08963592605845583, 0.09194443242684489, 0.06228313210510439, 0.009748716857434522, 0.05908373059825071, 0.050981255293252974, 0.20307686991028248, 0.006321670408661087, 0.08993800218787887, 0.038100605334846244, 0.0234062249787272, 0.10408743164472042, 0.01701338787473017, 0.06158662411654669, 0.01011396746992344, 0.06899937131111661, 0.08152382102824988, 0.03638824943693415, 0.06686084453136691, 0.05631623031090825, 0.021889144892714197, 0.05699103885901071, 0.06956031621103326, 0.08436350978069729, 0.023512919959161552, 0.023638759476823673, 0.0503051367348, 0.011516007962786864, 0.05814856323864191, 0.0222092374948965, 0.014600892731499289, 0.04441282892179105, 0.045726129619945446, 0.03438344330436761, 0.05064021210156141, 0.07530991333506762, 0.027434453180420305, 0.03140299355671291, 0.04285775087473374, 0.05434649185307565, 0.03091845060548475, 0.03488523472521094, 0.029388963725538026, 0.045779039482435877, 0.029263135699194767, 0.035826982780089306, 0.06330163450911641, 0.05047660636445207, 0.028314297500577186, 0.028531441292274865, 0.006255976932739178, 0.08041398179146551, 0.03146630880843488, 0.026042915752998767, 0.03406014270900238, 0.021782806143164638, 0.022856413251570156, 0.01809618229256763, 0.05463482436513709, 0.028154188954842188, 0.05834754691609453, 0.06570317076459047, 0.0836156930534109, 0.026617219311095057, 0.011632463860986455, 0.07338763785458381, 0.05173590935526356, 0.04051614950801577, 0.04284682263049387, 0.026132168826617064, 0.04586618198382278, 0.051879903241511316, 0.023036604792240168, 0.0193008957731147, 0.029820359327019225, 0.05554134769725704, 0.01381738301021077, 0.03991989178522941, 0.0761127275144381, 0.07298132014130393, 0.08321545041737058, 0.020024404530563665, 0.06181003067702536, 0.029875236120255246, 0.03135723320977583, 0.07819293202051232, 0.11766155971394432, 0.0630257968911, 0.05454839815595939, 0.009205331650352287, 0.009858207101182593, 0.006468291497684174, 0.031323950519905455, 0.047783232744663, 0.0724156178353775, 0.0845755399355004, 0.07850416290063052, 0.041570864888208534, 0.0540783649100171, 0.04919803243190531, 0.022829617411198638, 0.13835059148409676, 0.024633403987653797, 0.05490531851988166, 0.04651742949781399, 0.05760157263026603, 0.05643527654390182, 0.09289092639641416, 0.050148651784946846, 0.010014839522961167, 0.026837157408496546, 0.014589198399335148, 0.1059902101875313, 0.07996457929332411, 0.021883531383449034, 0.051312523203030716, 0.08768459286300406, 0.029929210844960426, 0.09665712188448637, 0.0343130704676432, 0.014582860936981537, 0.35156191597061776, 2.0948273472247587, 9.197516787436701, 17.553275285228608, 33.41260440887944, 55.79888889866491, 74.62864660447644, 81.37630001191171, 82.23775448337679, 90.62161676345333, 104.59858279074393, 92.52256993324526, 85.70250957242905, 80.5350535915744, 79.11686574259113, 85.90532748929917, 75.46746115530692, 78.76160883134412, 66.59340458531534, 56.91727038352721, 52.232191408834154, 53.61192041827787, 50.92040177314512, 40.819168936821725, 40.91867554572321, 42.12141544588151, 44.616152701839326, 49.349433683579974, 45.19341576483942, 56.71858272244854, 77.79415622834237, 78.40017810944589, 64.97418742026052, 55.984499377589074, 62.0086363054091, 73.5466843266641, 78.5692479533534, 74.16476357367732, 81.60635486725839, 81.5499198052191, 86.29021398482784, 81.22655960821336, 94.21955200933641, 105.6388424288842, 93.71141679825323, 100.84075604715656, 89.33482831524265, 92.38840133913102, 57.64190473864156, 50.9174443060352, 35.40442320608324, 18.458607350626302, 7.730513570770142, 1.9167757659189164, 0.04969079167612138, 0.0860396258893513, 0.03351982855688661, 0.013480057260171782, 0.032879015160424095, 0.04246361395944992, 0.033247254473427613, 0.05196111622236429, 0.036661122294683615, 0.029320019642792405, 0.028451210819184784, 0.08864586466863271, 0.005564054938018202, 0.033407887789390744, 0.054160554652973536, 0.020912267876067953, 0.06659964685358348, 0.03923326250045531, 0.029523548136855808, 0.005644503746166705, 0.01944749818874463, 0.04139815802655874, 0.07766262297668765, 0.08220334867796592, 0.05086642254384295, 0.036902823034794106, 0.041702773737450766, 0.08882840809923026, 0.04478173856172831, 0.03993869541333087, 0.03178056956629359, 0.015939265572195573, 0.009318731815343904, 0.026033544582465006, 0.04468192496607381, 0.048273797146976, 0.025105934680229234, 0.03324971744610417, 0.01676998450420797, 0.005726364550120648, 0.07241177207399761, 0.032640597107069146, 0.054324711973388354, 0.052318714574099555, 0.013237835580272781, 0.02844809667177258, 0.02709601660289111, 0.049541810557486556, 0.07206480319221174, 0.027378570896783666, 0.0626147179413707, 0.030264592646891554, 0.09120062233940249, 0.01945673146345202, 0.02858384170629565, 0.015054381351106831, 0.0455412955864543, 0.026995214753814285, 0.021160005389021772, 0.027967954895669417, 0.05918830159991499, 0.011839155340567233, 0.057674726366155574, 0.03842228182381199, 0.1839977412694885, 0.17364466052141883, 0.21519106422220508, 0.17579698454468481, 0.15672911739637777, 0.10519992920660204, 0.13206528439637155, 0.2292945590471068, 0.2349886301183893, 0.08861997855767127, 0.20627712560517175, 0.22427374136544045, 0.12932291945382474, 0.12683006934821606, 0.15920445473203737, 0.19761162930198256, 0.14185873791575432, 0.2037766912291127, 0.14185935078609374, 0.2125241589401999, 0.12315457100949942, 0.0890567482659413, 0.14936336586552282, 0.24519503567247625, 0.155649239858312, 0.14123883488918507, 0.10280955868262438, 0.12738358319526719, 0.17853081526775516, 0.22907823113904846, 0.2071445976053515, 0.12756992642196918, 0.14756171092871698, 0.16955113098506006, 0.11812690450179002, 0.16141077263220666, 0.13924656195505974, 0.25717813701879594, 0.18791574474063613, 0.09051451399441689, 0.23578042795340862, 0.13835751691893225, 0.16329715689343793, 0.1419901373165269, 0.21544054841562627, 0.12046073007607654, 0.15824574166007582, 0.20856316261474164, 0.1304734609420261, 0.17767088157275032, 0.3727020203105865, 0.16088987880897138, 0.14683043403971582, 0.24580925432664735, 0.12838892037830046, 0.2756235730503836, 0.23144539685979967, 0.14151257342628895, 1.1201697179386694, 4.512223062976714, 15.558832422379526, 25.99972486495972, 47.149599829027736, 69.5758258142779, 89.92265039874663, 100.52494249036236, 102.00577843573787, 109.40901679377403, 116.09182557752057, 102.32778933740433, 91.25011382564422, 82.49967467400336, 79.12026251516035, 87.02054362143241, 71.09720337775447, 80.94058744369015, 59.02870970387613, 67.32007072817895, 48.894497579143895, 50.039453121923636, 44.74218630021618, 33.21981599253993, 32.26022578054859, 38.7186534174027, 43.96673763951948, 48.84239281377485, 43.106126477641446, 48.38211051879391, 67.36731175453433, 61.53156626609064, 61.6197842936362, 60.1264516768917, 70.4088980151761, 76.7590819635699, 79.8601156665433, 69.82226833220452, 87.96559949075022, 92.24340700334119, 98.80091174956291, 93.19781380314981, 108.81728802957844, 117.03698342846288, 104.6853534636959, 116.69905554863715, 105.70249465204056, 109.06099273312478, 78.30168739441903, 68.25043339883128, 51.28782587666666, 30.403615005554695, 13.471890264941802, 3.9174179348253437, 0.39871867265432115, 0.32677762330539767, 0.21892686134144185, 0.15038388691121532, 0.1086263723611351, 0.13842255778370366, 0.15905921978335227, 0.4310077158433776, 0.10185584816480837, 0.12029176938437647, 0.19840400936382435, 0.1548064205675356, 0.18660089271443506, 0.13990898286142658, 0.19660718078094144, 0.09036423052631079, 0.22704029936463604, 0.2550582338364855, 0.11582471835877627, 0.16063533843524996, 0.15281986264932543, 0.15061628734392507, 0.22102191263148863, 0.3267381238120218, 0.26092498112590085, 0.15658423484813783, 0.10073209677131907, 0.14954518917347157, 0.1595490717238957, 0.16242513433098793, 0.14492020912228093, 0.09611640936664997, 0.13179001368341908, 0.062055393317413915, 0.12085529600059795, 0.1649675043600221, 0.22094119760778644, 0.06966739232020994, 0.24912137418024002, 0.13113997275790862, 0.1258270227680764, 0.12599075107925362, 0.1635337554879727, 0.1314067245731431, 0.206188504554091, 0.0743884168144676, 0.07889850665965388, 0.17741721453926257, 0.13574079039596743, 0.07480226517204316, 0.2890884569816051, 0.08714092324577993, 0.3174284394950636, 0.1297235987599819, 0.10808747547167925, 0.09216479761826415, 0.25114995968197623, 0.1243138075956414, 0.11112613257982078, 0.10543186232567796, 0.285645259484168, 0.15888720240083434, 0.14094212903611122, 0.15704134419079752], [0.06423931080667723, 0.11433025701872765, 0.0863139006880022, 0.07636898392510992, 0.06307887529293377, 0.0406831719972674, 0.04284812497996515, 0.047590707188412074, 0.03390952599264922, 0.05402615984841701, 0.043092813462980335, 0.012563756730918203, 0.04001566043664371, 0.04770192400281949, 0.03394537507706592, 0.023686735733081738, 0.06986068396438515, 0.011752946508838045, 0.12065753040294494, 0.02816964477871455, 0.04866709902642235, 0.06890821450900647, 0.05115003595429082, 0.07695947683626607, 0.036226972607114626, 0.02158465558632968, 0.0344906649702499, 0.029349952613213853, 0.05318566946493042, 0.07413799033289956, 0.03793694597158221, 0.019680270174097632, 0.035946615070344946, 0.04291067222854303, 0.01625609655504025, 0.0364777974544033, 0.0786919923379056, 0.03071597356709742, 0.025390388872174006, 0.058388555602681254, 0.10469279432248686, 0.033524716197843515, 0.04044921640607138, 0.05845272695765861, 0.04147988428632098, 0.03568019267291792, 0.1066025825698049, 0.08177372657002942, 0.03384738094023159, 0.07186015046411945, 0.057032986003304684, 0.0689531762092825, 0.04376059315437752, 0.14414462170773937, 0.051310178973982414, 0.30595449550497916, 2.079482299666251, 5.1485124038111785, 15.787045724930303, 34.919751613370835, 45.52442850605134, 54.771471100468794, 77.1608111166185, 82.31366803569179, 75.38358519154211, 70.56753435442525, 62.005447418459006, 40.1571120754365, 49.00695977672454, 52.937472789518296, 35.39723350155738, 20.78030336287714, 17.67346259086363, 21.8101942154669, 22.346682279340683, 22.11863175515206, 29.09726961966484, 42.486992113051876, 54.748505623109885, 30.85029059840787, 41.712610337042044, 39.38127902246291, 36.53015913501863, 33.3784209528277, 37.39799530275407, 20.84460081592683, 22.45456510974515, 37.38583203284971, 24.926717358250773, 16.75191740835867, 19.404259420210316, 24.108452104753066, 26.69172706142549, 15.640018620798665, 16.099920445872893, 15.811498761177065, 31.13113622511587, 31.03426544897018, 32.749531653619584, 32.568984954587876, 60.48115161157424, 84.51161523019114, 84.19165965049498, 85.07061573766893, 80.07360243028211, 79.95607253043883, 88.5510132389684, 91.93415164947511, 82.83881064384215, 76.692503652265, 50.07688037810787, 30.23983055545438, 15.21250282564471, 2.6615441374240385, 0.9647618570635397, 0.23997249171858837, 0.01681199676597551, 0.036136214170725114, 0.04806540974025284, 0.08150240887076625, 0.05019108539507274, 0.0579458563738773, 0.014702621546964494, 0.014351675711241702, 0.02621186878381958, 0.05414752349738152, 0.03749258433198256, 0.0379932496035772, 0.043146707748453465, 0.012522357339490087, 0.08012246235363907, 0.09715764542981502, 0.012647604096620794, 0.013554409923662823, 0.08042536585802033, 0.04917928626039817, 0.07807465570588266, 0.008337497673628312, 0.016020948739512073, 0.06721866887903984, 0.06990399857562396, 0.03852586840249358, 0.10575807788559508, 0.031036571787309744, 0.014823568635620179, 0.03505864255731145, 0.017469405542097746, 0.032033570103287216, 0.07818418329641705, 0.024449165587523775, 0.036086648282024174, 0.07652442316494643, 0.053254038981732824, 0.02860904599900448, 0.025357224925931905, 0.11141037418236656, 0.044636955604918545, 0.016701913761696028, 0.022857661974886735, 0.02813859906558308, 0.04786269521460899, 0.0248793488548648, 0.05397550611486358, 0.08556344861825628, 0.029682482652846846, 0.10151392780244352, 0.0373645901920334, 0.08116198237985373, 0.06319827009593287, 0.057330411979027336, 0.017445371448693257, 0.013347745257159396, 0.044861089948925285, 0.03966185422013364, 0.007846384560839545, 0.11527464424650516, 0.04835779485743373, 0.049047507646103064, 0.06666707025179941, 0.07349364910154574, 0.027835973268074375, 0.03445224566084724, 0.06878988456822212, 0.09791902191336117, 0.07293003055477336, 0.04767013135396185, 0.013429050168563283, 0.03354681783445901, 0.027739873283632824, 0.04294460609314903, 0.0019281504172531348, 0.022153098571805224, 0.05943015938804996, 0.02643368762707518, 0.07429267114569103, 0.033941705515908624, 0.010716577976821892, 0.02934463787823916, 0.03542763263648076, 0.05966688821753187, 0.026370328325297565, 0.055632895204208554, 0.05701741143580406, 0.050930015502437476, 0.06393570633184525, 0.048848995112723885, 0.03414428597616573, 0.018194743334465933, 0.10262939778547134, 0.028381897099015695, 0.04521965740188476, 0.060184644910717205, 0.0631376572193638, 0.04007629629585051, 0.04485555879411198, 0.012292613316657803, 0.0368510278302335, 0.06038554763842014, 0.049199694842701, 0.010761965813505794, 0.020751839488624566, 0.016999288026483792, 0.07903408890049304, 0.14811093468339215, 0.052422025361128395, 0.01789559557613346, 0.05740332056678111, 0.022448584429859635, 0.04444470967075998, 0.05287875549026555, 0.028829390123005838, 0.34459103679945396, 1.8455245634240491, 4.154060656024564, 15.59512709417651, 38.38471458804223, 55.882003922616285, 66.81885457807972, 90.87567652425459, 96.20741705740653, 89.8200019713371, 86.88415496580063, 75.60643857525241, 52.91696271588726, 63.04440875207225, 75.35419879421111, 49.37732565787531, 38.02009497919391, 38.179641308323035, 40.955910605769006, 37.82008940173734, 36.57902794499552, 39.167945231160815, 52.90969848632813, 44.19202681510679, 32.974809062096384, 46.40547913889731, 32.85568079640789, 35.417778876519975, 32.16158797664027, 38.00757869597405, 30.106091460874005, 28.754156366471324, 33.885465745002996, 34.58658156856414, 21.27294521177969, 28.868705264983642, 35.00057205077141, 42.248896398851954, 24.97902020331352, 30.640967430606967, 33.37448681554487, 53.15721181131179, 55.13018361983761, 55.65500851600401, 51.21633675790603, 77.05860983940863, 97.10874634404337, 86.23330039362754, 94.54941549608785, 90.8376766020252, 92.86922900907456, 101.17858194535779, 102.271330741144, 93.63263207097208, 86.83285036394673, 57.22917725962978, 35.4240938924974, 17.357448993190644, 3.600955470915764, 1.5718824921115753, 0.23151785345567813, 0.10977650016185739, 0.0479716559000794, 0.06369879364126152, 0.062487639276491064, 0.0433822414807735, 0.02593787743770067, 0.022224997838718757, 0.04174965831841673, 0.030418133903895656, 0.05543761939230946, 0.02018196583395043, 0.11409377333738151, 0.020450370483881524, 0.0429900044635419, 0.09583254314718709, 0.07434347809682931, 0.06979659304863985, 0.03594017610134136, 0.06357924179023793, 0.024637776434481628, 0.06419164098558888, 0.02688941418103153, 0.027938542865036477, 0.06872094431591612, 0.07168438691165178, 0.02998010206577038, 0.1175915775820613, 0.06338874253654672, 0.05492527511030917, 0.08790229206844684, 0.009261187120911576, 0.0059176150487826, 0.01651405176568416, 0.038836340855566726, 0.02663274791332022, 0.03447950689963276, 0.0418305303901434, 0.07427066143962645, 0.032853106066824934, 0.06563570140109909, 0.04117792690052621, 0.057886768012277545, 0.026885966785372268, 0.08127986032876276, 0.07582870807739035, 0.047618091001265475, 0.06713391657197668, 0.09883663436818509, 0.03096655135103051, 0.1619961097716324, 0.03459197626779637, 0.08454878048430528, 0.07266206065973929, 0.020099243659886624, 0.03810694854285929, 0.0312202969085305, 0.03519029093665942, 0.047271328963219165, 0.028432173534266414, 0.03107108404829858, 0.3522893930635145, 0.17069756624198731, 0.15298219668048044, 0.18777504503246278, 0.13789513689135352, 0.16061899011894581, 0.16170985335784574, 0.22689609097376948, 0.11815174107229519, 0.1347578842673571, 0.12853098372297903, 0.07320644273873299, 0.16282650311627697, 0.11453585969584604, 0.12568820763619679, 0.12004707324048204, 0.1732606666102525, 0.059471087635404644, 0.2792381903817577, 0.1520798983232629, 0.12740348615954, 0.15014240067572365, 0.11365714152493786, 0.20686834629985595, 0.12958191845926548, 0.21270445007230007, 0.14143740487915857, 0.21596492027803776, 0.14744612358270154, 0.1526221506778271, 0.21040626290825107, 0.12060693795642546, 0.19988193086558775, 0.12151177972555162, 0.09330901888109024, 0.0821151489752435, 0.3165045068148644, 0.18748387033420225, 0.19426702732040038, 0.14754058222376532, 0.13886092861573543, 0.1650732244935728, 0.164821196888243, 0.07815114192424283, 0.1066291275163812, 0.12284719355164037, 0.2866041870607484, 0.21022805553530494, 0.22889882866894046, 0.18139701066238267, 0.2504922731989815, 0.1302331698036963, 0.1823062344544357, 0.1709255080429777, 0.1502073036446687, 1.2258062559750773, 3.937711052356228, 9.191198829681642, 25.12335950328458, 51.53075787328905, 72.1709914361277, 87.26461702777495, 108.7821985060169, 111.89234779727076, 101.46473453890894, 102.01388989725422, 87.78774353765672, 63.738432930361846, 71.60835096913, 76.68159946318596, 53.20076973207536, 32.85507871258643, 25.88178311624835, 33.493264029102946, 33.835298630499075, 36.27061982308665, 42.5944846676242, 60.60517695642287, 74.18396749804097, 45.947165873742875, 57.92037340902514, 57.11447146631057, 53.170787134478175, 48.70142675215199, 54.4213132704458, 32.73499731094607, 36.84241902443671, 55.36328615680818, 38.55477286923317, 26.948471684609693, 33.62900549365629, 41.21942327868554, 45.75606799894764, 28.67273580643439, 28.48684095567273, 26.02897397933468, 49.098735394016394, 50.404590483634706, 51.86711680504584, 53.72178208443427, 81.88366643844113, 103.4427465931062, 101.87706978090348, 108.06020782839869, 104.05114543053412, 104.37768274737944, 112.61650362322408, 116.41511517186319, 110.10596706021218, 101.88354169168781, 76.56305759183823, 51.2655193574967, 28.59099949559858, 9.005501078021142, 3.621973981780391, 0.665231284595305, 0.16793172836544054, 0.1323951925000837, 0.1877094372626274, 0.13210619349152813, 0.1161423460730622, 0.1065118088116569, 0.1029834529805568, 0.13711519809740205, 0.15665339726594188, 0.14289660319205255, 0.17175991568834553, 0.1873828693022651, 0.1756342215042922, 0.17657260260274335, 0.17133429255937377, 0.2252530162372897, 0.26899884304692673, 0.12507828673528087, 0.22206400671312887, 0.1635468709132364, 0.17737941576107857, 0.0685510413360692, 0.1489934066851293, 0.23807945781417433, 0.253844459451014, 0.17122540082181656, 0.2510464152381305, 0.14662726752219662, 0.09677938951720154, 0.2513592549028897, 0.06821263731727678, 0.11704505811775885, 0.2045585145993579, 0.20227961752924228, 0.1187860235692032, 0.1523354346112859, 0.20821742713451388, 0.15344423962937248, 0.10733490133838308, 0.20724002151719986, 0.2033934021188367, 0.12477290110602496, 0.10284193355830447, 0.1377377977534648, 0.17270629474472615, 0.09086684549167272, 0.1269559835594508, 0.1621086480877092, 0.09347546680439865, 0.25632370383508746, 0.1124718119840949, 0.17752181618444382, 0.20346732960352976, 0.1297498142887508, 0.1536868596749921, 0.19828808493912223, 0.16340166660806826, 0.2546807363509171, 0.14469730817983228, 0.17814677539131335], [0.033649205485539097, 0.040343909959999785, 0.05044393271448151, 0.03413528061261581, 0.12262401681753898, 0.006350849261282073, 0.10369108073533544, 0.013291732738575628, 0.043334269054955056, 0.01566285051540622, 0.060868037474011226, 0.03398166083159947, 0.07166288282361723, 0.04599108878943709, 0.015771845674833224, 0.02556507415588825, 0.04050271998670313, 0.02842709054088881, 0.03265270895715202, 0.036990107262446996, 0.03594058595838086, 0.07320732373984591, 0.04992083638846394, 0.04339385537370559, 0.024797316159932845, 0.06410333403055707, 0.0733560826929827, 0.029807412441098885, 0.015282225475886898, 0.02632888296859399, 0.047395197719696074, 0.0770748113732665, 0.01901057526288975, 0.04604096494374737, 0.0047554754682125585, 0.04741392856944473, 0.06401035393918715, 0.12051629443322459, 0.014720164960430515, 0.04314000830955563, 0.018670501172422402, 0.077909272644789, 0.023988863573439663, 0.1409527010494663, 0.02785941555855736, 0.018405723948812774, 0.021742280091970198, 0.02592190641969923, 0.047848511096690936, 0.048827491024689335, 0.03569409716874361, 0.061080182542002974, 0.10949776673148717, 0.8870106743228052, 9.518040130215308, 14.483938255617696, 27.221956983689342, 50.987180125328806, 63.13866722968317, 72.60032623044907, 81.21020332459481, 65.98277784162953, 81.85803767173522, 48.52423367961761, 55.985315230584916, 60.96506226447321, 51.39821706279632, 37.122644916657485, 39.20357211943596, 30.18904370646323, 33.03461344011369, 46.10729271365751, 47.10648513609364, 54.57027312247984, 57.101747297471576, 68.29309309682539, 85.81293998226043, 57.844506925152196, 74.1373932746149, 80.80746220004174, 93.40307927900746, 114.04475627406951, 106.30647690065446, 104.15773191759664, 84.13768783692392, 98.16356582026329, 92.4641344624181, 85.7566539702877, 95.22510651619204, 113.74802897053381, 81.2197111498925, 60.891690408029866, 43.95239353179932, 68.15665737275155, 61.59740324943297, 52.20559773906585, 31.523110443545928, 24.191831888691073, 31.4674186706543, 24.101678171465476, 29.47106169116113, 38.129172171315844, 64.2298980682127, 57.8281702533845, 60.098414574899984, 63.83604895684027, 74.39233164633475, 66.40380505592593, 79.63865080187398, 84.71880266743322, 74.98956741825228, 84.31939555752663, 65.91284982619747, 47.36802093444332, 25.713986081461755, 9.89877969987931, 1.6697255257637271, 0.06904882228662891, 0.13535131129526323, 0.028031467415031888, 0.044832097351430886, 0.0528984516107988, 0.1325156828088145, 0.05485257336629495, 0.003917163407858161, 0.09678679758742934, 0.09053206506876216, 0.02238571733957337, 0.03047910301134952, 0.03782286015789836, 0.045832860989556204, 0.04297046922147275, 0.08231071590055382, 0.017797201158358686, 0.03996428658044146, 0.03265532514741344, 0.06757322969215532, 0.047614486557581735, 0.028210714752335223, 0.043216383445166776, 0.0845881420818548, 0.005779012027497013, 0.07230563825296779, 0.10535302421739025, 0.06206636752692923, 0.013188071466321427, 0.01927815062264281, 0.04724422477245812, 0.041418386578199365, 0.032369306220883326, 0.022919954499229792, 0.07600031177242918, 0.04985388413432145, 0.15210657350478635, 0.061213014527193965, 0.03077933861453447, 0.054810614730682106, 0.013266017082177345, 0.056133054857773174, 0.04368699891793151, 0.01858254087217633, 0.03182247840619135, 0.024425300033462626, 0.015249369880034318, 0.024876995049717448, 0.0145494221566966, 0.04355333189690306, 0.08703987624856734, 0.014462939448534481, 0.01744549019232152, 0.04400133245414303, 0.03685919815794595, 0.035813955454936916, 0.08215251108331066, 0.07928292191917859, 0.05528568883516616, 0.029525779367935275, 0.03387373436482684, 0.016400280048049266, 0.05188824593900673, 0.019437014275500854, 0.12548625153759796, 0.06708066580035994, 0.04519458717456268, 0.008971651850809014, 0.020512371894813353, 0.013016281994960964, 0.07723284765116631, 0.07193569439433276, 0.06307416002175982, 0.09204302028182054, 0.008822175647853123, 0.05438950769002399, 0.03123254090878031, 0.08231349679971896, 0.01790316069438573, 0.016285374520286437, 0.05672074388712645, 0.08143128526787605, 0.05724001360396224, 0.006434242719889529, 0.04925390705466271, 0.06434195509721195, 0.05261515229639988, 0.025644243597203208, 0.016291700491321184, 0.05141513301960884, 0.0411379600935165, 0.01635544092184113, 0.026617648320332653, 0.0352565422203512, 0.05304818349559942, 0.010090142135478316, 0.10626819285173571, 0.07275503309022996, 0.010085263113010555, 0.03316761580325904, 0.029447406658061573, 0.03676977654498431, 0.03877444478172449, 0.015722989375072143, 0.05583849788132695, 0.03119831784598289, 0.01328867413253794, 0.029200362454679225, 0.041434957060001554, 0.048679946320912534, 0.0288494099156871, 0.09255923330783845, 1.0740328387868021, 8.729977127044432, 15.212386135132084, 29.012136536259806, 54.70377099129462, 71.85072991155809, 87.77555281116118, 93.50789285475209, 83.81643003033054, 97.60135681398454, 62.9391872498297, 69.99703345760223, 75.43285800564674, 63.58969273105745, 50.97313804011191, 45.560475087934925, 37.37603395215927, 42.665169700499504, 41.09246792331819, 31.48627938762788, 42.768249588627974, 45.107531547546394, 57.362863402212824, 57.16604278933618, 56.75944205253356, 71.69822815925845, 58.51724047814646, 61.601466824931485, 76.06428900072652, 63.69318054568384, 68.13074619539323, 67.08490110212757, 61.493174106844016, 71.48725955717026, 69.85325505656581, 58.32060421666792, 62.72618293762208, 57.952756497167776, 59.267672261884144, 43.356377617005386, 54.674859200754476, 46.67522445801766, 39.79308082211403, 40.37711389603154, 27.741416077460013, 35.28729731036771, 32.133431242358306, 45.98047071887601, 52.58510666508829, 80.03306081218105, 78.88193145875009, 76.34492674181539, 79.90401483351185, 85.15296197706654, 80.29905242304649, 89.6285040147843, 95.42317836515366, 83.68779197815927, 96.58152487970169, 75.74570625059067, 54.583130651904696, 31.011629450705748, 11.371976829344227, 2.6028122825007287, 0.08803693968201838, 0.16851646795628533, 0.02929684931352254, 0.04854345243544348, 0.017187092565901337, 0.07416899391119519, 0.033733632205234426, 0.14315040812136667, 0.06492337752734462, 0.046812354196463866, 0.09085867133352066, 0.024272239496631008, 0.019277976337640036, 0.029442928874144153, 0.031710872802162365, 0.04319016408595828, 0.03322022306101938, 0.021919037643519622, 0.03152719173099726, 0.05324636661117116, 0.016538846201353496, 0.05213230239948438, 0.10301058015395557, 0.08447525902621209, 0.04940265068604101, 0.02506027775516193, 0.02781002970051862, 0.010790431725552246, 0.027219938985522718, 0.04140787585187824, 0.01436915017679454, 0.008096844558754276, 0.026676562396929632, 0.005067352735016856, 0.03273173475698118, 0.07381201992111822, 0.07042594960019474, 0.0607437358778571, 0.040980594142550425, 0.056242923357433854, 0.011363415697198963, 0.06025866049552157, 0.06619886795599615, 0.03929191802237784, 0.05734961397284943, 0.04888006380849308, 0.02462364019705884, 0.03855422897745044, 0.04057943220100096, 0.013646317491938752, 0.04386727089783357, 0.039299448666673516, 0.06466755778678963, 0.02875220484941477, 0.0714590268269662, 0.0417391475920956, 0.0719429492469757, 0.081578787836817, 0.08668810399549623, 0.13309518235825724, 0.13289671962059316, 0.13929171517731684, 0.10623893595390743, 0.1921852599949606, 0.28782609729997577, 0.18766797658416534, 0.1994863230614893, 0.13642631651413056, 0.10758904334638389, 0.13767416649047406, 0.17450511515621217, 0.2631397413149957, 0.14405546439511163, 0.178168976619359, 0.07264456321154872, 0.15009789096732296, 0.10145676232153371, 0.13215341515118076, 0.11746292077605763, 0.18167637228485078, 0.16809587036409687, 0.17159721393498684, 0.1180714550578306, 0.09059352064204794, 0.15259780440359347, 0.14751255872749514, 0.12279355207518225, 0.06470979221405522, 0.22784743427989945, 0.25064921397114953, 0.14210115877851365, 0.1328402436188152, 0.15873698788064142, 0.1250845916388977, 0.19976323320259973, 0.17038265813983258, 0.28660516765329147, 0.15634403564035892, 0.10510976065791423, 0.1483065628957364, 0.1280015633411465, 0.10493768964924159, 0.20200856029987338, 0.07719177767754563, 0.12333269411277388, 0.14248571959474396, 0.08314544530284983, 0.14277333964503583, 0.15805510834099787, 0.13373036117803666, 0.1844934614435319, 0.25423642067659286, 2.915848065768519, 16.439391778361415, 25.540176053201, 42.69982776334209, 68.63867744322746, 86.45744815949472, 102.67957102867865, 111.04388421581639, 93.49630617326306, 106.75938513971145, 68.82910067035307, 80.87808839736446, 82.54387194110502, 74.4066482974637, 59.37402732910649, 58.250738959158625, 44.51752470385644, 48.596318998644435, 62.785842187943004, 64.5302535641578, 72.84997724717664, 77.00874866977816, 89.55107642758279, 111.44217737259405, 81.51356727846208, 102.5997978641141, 106.69962390776604, 121.671781539917, 145.6309364688012, 135.18012631324032, 135.43508037444084, 109.23034498768469, 130.06024868257586, 124.55008737502561, 118.3425678745393, 124.53508038674633, 150.2533869589529, 106.40649734004852, 86.62005393735825, 64.16607326076877, 93.26489417783677, 81.87757107519334, 71.12719382009199, 45.73202386979134, 37.180303758190526, 44.1695555563896, 39.47175241285755, 44.92929904691635, 54.256130495379054, 84.7795601814024, 79.40594442429082, 83.04037340225713, 88.08278422201835, 97.13072730648904, 89.27466700153967, 101.00968468573787, 106.74929680362825, 98.02995420271351, 114.03530336195423, 92.033826920294, 75.8797493288594, 48.12895290313229, 23.791720713338545, 5.261874295050099, 0.45450602267538354, 0.24168292090537088, 0.19701262515398765, 0.17239569205670588, 0.12355833764999144, 0.2643892613630141, 0.13662097945569024, 0.2275504526351729, 0.20385576682465695, 0.20156055208175414, 0.17792778149727853, 0.12415199450427487, 0.2224317289167835, 0.13046615246322849, 0.1798833588198308, 0.15120180834445263, 0.0890277901424035, 0.14425731324140104, 0.1250144869329468, 0.11907422584631752, 0.12097069948551156, 0.16125893400561425, 0.25131667573605815, 0.17587890998730737, 0.10191125930437159, 0.13897499910766078, 0.22118636106531467, 0.14256373798895267, 0.10266335080227545, 0.12092630469029951, 0.0700597289288717, 0.12392737752487584, 0.1582481012108826, 0.10621456669703608, 0.14239882990237207, 0.15942689602173146, 0.20482195691475946, 0.1491359756478379, 0.09053472339385941, 0.1228536440119628, 0.10927086681007378, 0.2688764834836606, 0.1261646530380653, 0.2133272642329816, 0.1602026826191333, 0.13846817065871533, 0.12806767672901193, 0.1553586014215985, 0.19098786456931025, 0.21606811232143835, 0.13334572375301393, 0.18659081099735153, 0.07395565374604157, 0.06570727699586461, 0.08849578804426617, 0.1550663082349685, 0.1276707665754422, 0.19074545902830942, 0.22423116219860895], [0.056490319961261366, 0.012466789151902401, 0.06179977275971925, 0.023485522739769473, 0.029839917551726106, 0.03093519537228971, 0.05617414781403157, 0.05506169238698579, 0.03805755119350168, 0.050952726178952766, 0.022582333805339954, 0.050449724339189074, 0.0637740311363051, 0.05661355286476113, 0.08462437804067328, 0.029603514309612014, 0.04057628357963216, 0.046885182344985586, 0.06541630914134365, 0.09107245582967036, 0.07622110597308605, 0.07514009462489236, 0.0647202033489462, 0.04167469661502589, 0.010593952198002127, 0.03460149874069518, 0.139882460897488, 0.030457026272591566, 0.049566723736784155, 0.07353874103676888, 0.0864418143887193, 0.020024414106662718, 0.01877608724058636, 0.0032948163214079557, 0.07051837810825917, 0.05112516874026868, 0.06317977290300113, 0.0276398949790746, 0.0034794870824102434, 0.024149102354121786, 0.004016369639430195, 0.05552782241495387, 0.04884099332435478, 0.05688578603909381, 0.07129535980282292, 0.01690605895653848, 0.012358064996078612, 0.08621437054487967, 0.030696465138105616, 0.07444873091674621, 0.08169578478461312, 1.6332521409757677, 10.250596692485194, 33.970526264559844, 57.32925653457642, 64.33444884515578, 70.93766489336568, 74.15367895557036, 76.59524456147226, 65.17421653193813, 56.2898676626144, 37.572968313770915, 34.50070519601145, 35.78741127444852, 26.78199060501591, 27.095191863275346, 27.934426107714255, 25.023454773810602, 38.07905996999433, 65.55285861415248, 75.08968199453047, 79.21945925681823, 106.57424926757814, 79.72023610145816, 81.40490977994858, 76.29232775780463, 71.87080460210001, 62.119639381285644, 44.3554013775241, 53.05559888962777, 55.841477993995916, 41.96192795230497, 47.580327064760276, 39.13527188762542, 38.34368267366963, 60.583635299436516, 43.574226056375814, 37.72113192465998, 51.535256831876694, 48.35071194556452, 57.8717517083691, 68.84271913959135, 69.36242534268287, 60.658015205014145, 86.89353727525281, 121.17196175359912, 105.07408388199346, 101.5444371008104, 89.19994584975704, 84.6208610842305, 37.94125533873035, 29.290112949186756, 23.699425381998864, 17.045475436795144, 23.56177176198652, 21.132390999024917, 37.49878060433173, 48.31732473065777, 46.57217987122075, 56.82975053787232, 62.451868057250984, 66.04519059581142, 73.25621712592341, 74.15860545250678, 69.07491560905211, 56.820529045597205, 38.35582633172312, 14.64466521816869, 3.4188751251466813, 0.6324254997795629, 0.23026513116013622, 0.013775757622844992, 0.08076990624108622, 0.036429273445279374, 0.074163876443861, 0.042509245986659686, 0.020817539189010862, 0.03428143486681004, 0.021258627717954018, 0.04066739441646684, 0.053659326306754546, 0.040821056332319014, 0.010825752209301197, 0.03323338445155852, 0.008008981455913595, 0.03862947030293365, 0.05012603686942209, 0.04992022734856413, 0.06714501718599951, 0.028879402257922678, 0.06319584925809214, 0.028760061081078266, 0.14172234362171543, 0.011986424252691289, 0.02128826957496424, 0.015444301909977391, 0.04048960839187907, 0.08715989924366437, 0.042205568733474905, 0.030359148964165684, 0.04583533928399125, 0.03463803347380411, 0.05784226213431647, 0.09638708355205675, 0.061148663141554406, 0.030336735146721045, 0.04506409941841999, 0.04592548485004133, 0.018065531114717166, 0.015944587010439607, 0.012341656350350429, 0.0307782526849018, 0.07934104500999374, 0.0344383679780989, 0.04374992538003191, 0.04417780463794067, 0.041815200970778545, 0.08121317237495415, 0.07908794488156996, 0.06888024463889099, 0.04967105725119191, 0.051117741517842784, 0.044592974497185606, 0.055454128587077704, 0.06754100803406009, 0.11971426932441613, 0.04006743648900621, 0.09527084748110465, 0.01661303224072101, 0.04134877599895962, 0.035115187507002585, 0.07426000515659971, 0.045491354314670454, 0.06793954229402928, 0.023639257433974457, 0.05852120755721004, 0.04209314916102637, 0.027972863604044242, 0.08132576431718566, 0.007843718096058095, 0.11125086701565212, 0.043127873476835034, 0.029150223915254878, 0.037599775354347886, 0.008274003348854041, 0.038566333166654074, 0.025534181660341642, 0.01825165792158054, 0.04863152956409801, 0.01593239376351478, 0.08734498608617053, 0.03519510579926353, 0.04129954718894536, 0.03673149896184764, 0.019697708250474066, 0.03255724674090743, 0.11220133698154842, 0.06541683008113215, 0.0352400406864622, 0.056697259461807634, 0.05076728693600144, 0.0643796389622073, 0.011795900101142546, 0.042225398919394905, 0.03675043665533585, 0.046913527598183964, 0.03389543380528208, 0.07285707600174413, 0.013765556204523292, 0.005688823369001189, 0.0507047473483028, 0.042569575410696774, 0.03732252047367154, 0.11231672514470355, 0.06017826722874757, 0.031652192382382295, 0.019558270672155965, 1.6342114056310348, 11.62621799976595, 38.65032965137113, 62.049750589555316, 73.5311282065607, 83.40041560511436, 85.22852251606604, 87.34517466637396, 79.24440553111415, 73.60449221826369, 48.80494986810992, 55.473292950660955, 45.01886244743101, 42.754129056007635, 42.57787342994444, 46.9359169467803, 44.12118096505442, 42.00484652673045, 45.60187570510372, 54.912684271412516, 64.87088787940242, 72.31564060334237, 67.29104518890381, 60.72393848050026, 65.25258156561083, 59.131342441804954, 57.456937528425655, 46.7997165649168, 51.607047973140595, 48.35027656247539, 44.309952874337476, 44.40209327205535, 43.6150187061679, 39.21625314220306, 51.55822623160578, 39.071600052618216, 35.44540020727342, 45.24025278706705, 48.0288226373734, 47.96034589890511, 49.498067978889715, 51.02155969988916, 57.31922703404581, 72.65983643070345, 79.745817799722, 62.10374593734742, 72.34130859375, 70.13959592388522, 71.22800657826086, 33.71095165129631, 35.1323676109314, 37.44570701353012, 24.492930673783828, 37.45467355174404, 38.78292537504627, 55.54715118100567, 61.019465538763235, 62.897515989119015, 70.44830214592719, 74.92359315195392, 79.70042813208796, 85.26558891419442, 84.82279254544167, 81.24085272512129, 65.64981960481214, 42.525517632884366, 17.969987892335464, 4.834627672549217, 0.8427937953702865, 0.20519625215280443, 0.063355969295146, 0.08685622199047958, 0.017718535419853947, 0.07592094506347373, 0.01939813339812381, 0.04019646867809277, 0.029871790639815793, 0.01963817747309804, 0.04752354809053002, 0.039519993888755, 0.018232168644786845, 0.015702506099196694, 0.020541963956108498, 0.055864805340646743, 0.055120010830221645, 0.04024175979617623, 0.025745319322712963, 0.03570906652678405, 0.05274322687558109, 0.02328478855140988, 0.06545822181168102, 0.085723721872895, 0.05310520725024324, 0.036875626913482146, 0.024078294762500355, 0.03910561310007207, 0.03830395571346726, 0.07853164247447446, 0.07329355459660292, 0.03097061927790844, 0.056813226021345586, 0.04871352778507337, 0.017711372497761925, 0.03844909873160143, 0.09136114074217697, 0.05207527098396132, 0.029891511658206586, 0.005470393986005577, 0.019492377534568794, 0.044400690258630825, 0.05275816942054418, 0.023002067633393793, 0.06341441031244975, 0.03963486111212162, 0.029422374735135707, 0.0552777866382272, 0.0592942553902826, 0.029159204380947257, 0.051109486920458656, 0.02939508668327284, 0.07692681084717475, 0.04336993810870955, 0.040051597621171706, 0.06385887154347955, 0.17170115674455322, 0.17274582488161905, 0.18460593847257478, 0.1053617116544516, 0.15669953108074205, 0.10496024327773242, 0.19911167542299918, 0.15034844768383812, 0.19594417764775215, 0.16885916972833295, 0.1773982308804989, 0.15350468396659822, 0.15949863249496107, 0.14645310509349072, 0.13402988623467185, 0.2603972691201395, 0.2285395793977284, 0.20586408163991668, 0.12032782914297235, 0.1358220876464921, 0.1835216942333406, 0.1882270062642713, 0.14093912597144806, 0.2576041738352468, 0.232432562437269, 0.20928354573345956, 0.12687521490959391, 0.24004776751802814, 0.11654047430643152, 0.11891577588093859, 0.15963472035383025, 0.20503289156383087, 0.1366033594334318, 0.15358280961311635, 0.17431933883457415, 0.15467473005335178, 0.19942137412726882, 0.14272233351103722, 0.1716900944349266, 0.10682411221486908, 0.0922900683156425, 0.24188890662645143, 0.14390742556462366, 0.13993624026977247, 0.1446270272736588, 0.18622239931456505, 0.17865659158316352, 0.07433868238642331, 0.4232170306626828, 0.09319550763334959, 0.12243400402967969, 0.24093479008203555, 3.91423198965288, 20.35800530064491, 51.94380306428479, 79.66428741332024, 87.33801241843932, 93.28930700978925, 97.19156326786165, 99.90728685932775, 90.44441192380845, 79.84493609397643, 55.588351757295676, 55.15017986297608, 57.063276690821496, 42.49192253235848, 42.59284903926235, 47.7662827122596, 45.12553130426715, 59.46971354946014, 89.26123680606966, 99.18430774442612, 105.22492254934004, 138.41313208303146, 106.82013480894028, 107.09110782992457, 100.00932339699038, 95.0940679734753, 82.80281897514098, 62.70219764401836, 70.77386671496977, 71.86674102660149, 55.280979141112304, 64.1173731127093, 54.72142165707004, 53.356005376385106, 80.78352789725028, 59.487976104982444, 52.27833417154128, 69.84854821235903, 66.85167697168166, 75.98321360926475, 90.57657226439446, 88.8685683281191, 81.79804894231981, 110.47716448383947, 151.50148514778385, 130.9389929617605, 126.60388746569235, 110.32816148573353, 107.199263265056, 50.13233092523391, 45.601926695915964, 43.3162360806619, 29.877125063250144, 40.10602320394209, 35.40689037692162, 57.31601069050451, 69.08206216750607, 68.97316148204189, 79.84899966947495, 83.5755729675293, 92.1410958997665, 95.32418558674475, 97.20571517944337, 95.53756252411874, 83.6872350015948, 60.483501111307454, 30.2761693539158, 9.333895637143044, 1.9696397550644416, 0.6388855821663334, 0.2589571463965601, 0.3526808946363388, 0.18552683744459383, 0.16724796424950325, 0.2020580342580234, 0.10061498491033431, 0.19358576065109623, 0.21183926101413467, 0.1541101079313986, 0.1939605768289297, 0.12109135833358574, 0.1886505303123305, 0.12749516390143864, 0.12188993604673494, 0.12686032982122514, 0.21903726993308914, 0.14456616924895396, 0.20980465406131363, 0.12532513558624253, 0.20833005738114158, 0.12887552410604494, 0.23426559633545338, 0.09706078893354825, 0.11067282303326553, 0.1532769719919851, 0.13155635686651354, 0.19630312048379453, 0.14332398832325013, 0.18176799640059474, 0.22027490029652275, 0.11109524391471379, 0.11360972068242489, 0.24242187399537335, 0.11693071183418074, 0.23279308341443541, 0.15678767715730976, 0.1337072253227234, 0.06294202900701953, 0.043333794080442, 0.13555924287967144, 0.10168111117015924, 0.17424778622244635, 0.1164300427321465, 0.10357010013033306, 0.18365303234707925, 0.17522836344376688, 0.25264248281957646, 0.1902070524351251, 0.15059806977308568, 0.13705620932723248, 0.13219325172324337, 0.1510771658391722, 0.25001156834825394, 0.2058660887902783, 0.31790807182269715], [0.017211858273273515, 0.08426543520463091, 0.05393283118704154, 0.02638143468497982, 0.07382062308850788, 0.10171645846698554, 0.10616876996092259, 0.01793509506950936, 0.04404103113037925, 0.021254628738989274, 0.03227240758978071, 0.019653288557404475, 0.06463722836586737, 0.027767952321277514, 0.11298044073966243, 0.08815571395379883, 0.07126184345613565, 0.015097430704401867, 0.013624300124994932, 0.17085020160002096, 0.05065009463578463, 0.04624018610845651, 0.07015710636492699, 0.033252034862075126, 0.034133204514341015, 0.06598329847498287, 0.06810665671383181, 0.06532791025576092, 0.013051315195738308, 0.05479128250191289, 0.159044602825757, 0.01831186477154974, 0.03436616802167508, 0.02767141949715874, 0.028097971507738677, 0.06867519354507809, 0.028255358526122668, 0.058742813811066656, 0.02873491616018357, 0.08112101199766321, 0.028901239594204292, 0.03710877428191804, 0.03679145683324145, 0.07227753814790519, 0.08029621875574512, 0.053575110261238394, 0.021294779407100815, 0.007991367658119529, 0.2517046073391553, 2.848742440823586, 14.209471383402425, 41.57910070111675, 61.31293727505592, 64.7540012482674, 74.10141729539441, 79.68432288016044, 62.5258949495131, 54.91297844917544, 44.1859471413397, 37.55488226490636, 29.98709067221611, 28.787316083908085, 26.85574293136597, 29.86040792157573, 34.98470214105422, 38.03425865788614, 20.055747455166234, 39.06166861134191, 42.39306311453543, 38.96203648659491, 58.21622994638259, 58.035514585433475, 44.667547518207186, 39.992517655895604, 36.88258409500122, 22.39854189657396, 16.543967070118075, 13.08222436135815, 9.13586889543841, 4.29426871961163, 1.6057389205501926, 2.5131775438785553, 2.012868809603876, 1.6062750595231212, 1.5067528837150144, 0.9012095930595553, 1.4586971075304094, 1.590988970091266, 1.5664117663137376, 2.09036270937612, 4.929704454637343, 6.838058646648162, 11.167889045130822, 18.761286850898497, 26.964812278747562, 42.06278385654573, 62.260091612415934, 62.43371140572333, 73.64646157910748, 72.24386907392933, 82.26459918483611, 62.85379725117838, 40.34934351521154, 61.68553890720491, 49.99973912392893, 34.058975711945564, 25.91395635758677, 18.80604305574971, 15.425319844676604, 25.253423337013494, 34.60376939465923, 62.469357905849336, 74.8675189479705, 74.90219270029377, 71.4286122783538, 81.76081780464419, 79.77625539225917, 71.88275214164489, 46.436693360728604, 30.17916717836934, 9.198072783408627, 1.7940223721727249, 0.42895098427130335, 0.038525232549516425, 0.057638172480848536, 0.07751937985660569, 0.03137356620432148, 0.028780519459096175, 0.026006250784942703, 0.05318226420410699, 0.049507861371122064, 0.019920011644341776, 0.033995327840168635, 0.05554391409180338, 0.016888770267307278, 0.023953416685183204, 0.027297089785157193, 0.03778074830470066, 0.029319263130967176, 0.05553383620515947, 0.029375610813017816, 0.10597315707033682, 0.08259851215106827, 0.030349565204232935, 0.0791988437694888, 0.019434332967765873, 0.02532492665904424, 0.04947627173556436, 0.03496106210795622, 0.09837307456520297, 0.07958332797692669, 0.05088685410878351, 0.05284810814285471, 0.03221203986134741, 0.0450027319452455, 0.02232739889633752, 0.016161605355239684, 0.050714258329882744, 0.037331196419414014, 0.02149350261465917, 0.023791203312876246, 0.0801537340627082, 0.09786405510479405, 0.05895361056431167, 0.12075598802297347, 0.05053388675855053, 0.06626328062866965, 0.07885556743149796, 0.03293780474773338, 0.03707461059093475, 0.0570659201231695, 0.05820263755477725, 0.02733682485056981, 0.010494433546198473, 0.030137619319101496, 0.04857306173371692, 0.013917754892440093, 0.03641206328006041, 0.047410044503668626, 0.09014093121814151, 0.0547651895472119, 0.07091318918091637, 0.06354215930426313, 0.10936321104846655, 0.059978973285685626, 0.07497510992951932, 0.07929468902969554, 0.028015726223407734, 0.04585718811159173, 0.03250634402877862, 0.05917565348828512, 0.07102463965214069, 0.010733950935724762, 0.04384862048731696, 0.04306275600327119, 0.16741428193786453, 0.029868157467834895, 0.0678785540343773, 0.050431430159557256, 0.02168719453977481, 0.05981807566938862, 0.09370755314105943, 0.053322102063365524, 0.03438662639969299, 0.03830738012648879, 0.08847852808333213, 0.09489063804428424, 0.023747367761848916, 0.023856880030624812, 0.018885779540024458, 0.03498230955653614, 0.048147714396397916, 0.014212420078805618, 0.06557531069002806, 0.01953735838704292, 0.06717975161248638, 0.031146403897794026, 0.03648949561700706, 0.0321864984899519, 0.03684294177219272, 0.06164367468426786, 0.06382484574832263, 0.034157355436153954, 0.013485360503827613, 0.37623344049338375, 3.1184865342032526, 15.623139681354647, 45.329172918873454, 70.07843048341813, 76.25821098204582, 83.05726312821912, 89.28018185400194, 72.88589831321471, 65.98844174415835, 59.0938602724383, 53.24667715257215, 45.0919597379623, 43.472813175570586, 39.922468046988214, 41.225542176154356, 34.10516162072459, 35.681456288983746, 26.627064827949773, 35.61927103227185, 44.32048443825015, 44.74466916053526, 57.63986510615195, 54.153105520433, 45.48453800139889, 39.82634252117526, 32.69763869623984, 22.34500938846219, 19.008239276947517, 14.394153241188297, 12.190254830544996, 6.68635166460468, 3.0147104253692016, 2.966018367198206, 2.646529059256277, 2.1478396509924242, 1.992746682897691, 1.5398873508937898, 1.8007163871680538, 2.4168286881139203, 2.036527688464811, 2.7456588754730844, 4.886983959905563, 6.956273000086508, 9.503608749758813, 14.57602079837553, 23.05917101521646, 38.21465238448113, 53.38951026239703, 56.10882674494098, 62.50770691902407, 63.029519434898134, 61.98233289103355, 57.55440058246736, 38.85850552589663, 51.814584501328014, 48.18029280631773, 35.43727305627639, 37.21377726524107, 34.75447862379013, 24.570581836085168, 36.72866636706937, 46.71449915055306, 71.12896673140988, 88.82295116301506, 83.77282896349507, 83.92398142045545, 93.31551628728067, 93.39544634665214, 84.00655515732305, 55.955010998633604, 35.96179985230969, 12.77745129600648, 2.384128623431729, 0.29981666034267795, 0.04660657148868327, 0.032425169352321856, 0.0743630746259324, 0.09134037209854973, 0.005063125366089685, 0.017780615354798013, 0.039021224684772954, 0.030818924292801853, 0.002739774368350364, 0.03616276677818068, 0.030692408702546553, 0.07977015383902096, 0.05081420216048437, 0.01741763332017487, 0.06301943836132846, 0.027364610859583464, 0.04465144232756669, 0.02634291386892719, 0.12146831189672794, 0.016775852737707958, 0.02028650427687793, 0.030786928630644278, 0.05203994283933313, 0.007157854899208272, 0.046939360082990704, 0.016831727360465357, 0.01601769765388341, 0.08190727867786923, 0.037379885137441664, 0.07008320186287165, 0.03870825095462703, 0.05836116795938823, 0.021307680327745698, 0.03613578899192714, 0.014762995021057226, 0.023722755272061597, 0.03485608507969207, 0.031116821412597934, 0.025875893263747136, 0.06205951104000692, 0.028449280277615594, 0.05753098528892283, 0.07721774039729949, 0.10129176230440218, 0.03078007405894178, 0.07795634874773603, 0.04987713873326298, 0.025611497168879838, 0.02383581644314672, 0.024556402575164556, 0.004170067465653823, 0.04250029807970409, 0.04630088708513687, 0.14342828353326167, 0.2041184736956512, 0.17825215844617737, 0.18629919196809494, 0.2256898548934729, 0.14317510679604548, 0.19744194082675443, 0.14283455007018583, 0.12636111628624702, 0.13965700122137226, 0.22006281651556495, 0.09880900923763553, 0.14079870205492745, 0.1108995390935771, 0.20856936792692832, 0.18932085724607592, 0.24149135295902532, 0.14422930506688936, 0.15727213583886623, 0.2745934299403622, 0.15962082351888382, 0.2781029400085249, 0.12524494150232884, 0.22480430321828013, 0.1643710589456943, 0.1639537861750972, 0.19443996400842745, 0.09420579374437371, 0.09378462158624204, 0.26213543068978096, 0.258915716361615, 0.1981074107630599, 0.09996387146172986, 0.1329172048116884, 0.14175683290006655, 0.22972356828470386, 0.1265065657395509, 0.12635697175057667, 0.06225685528930157, 0.1952236566332079, 0.12697171900541554, 0.17992720969261664, 0.09404924367704699, 0.1322481342621388, 0.2236841447771557, 0.14946304922623022, 0.1465285034669984, 0.10275231659292214, 0.8002153639831852, 5.619300767298668, 24.38908592347176, 59.305378006350615, 87.9225318662582, 89.43273067474367, 94.94826562942998, 99.27290624187839, 84.81392014411189, 76.67121302696967, 65.35845418130198, 52.27744771588234, 48.07681675880186, 45.143205504263605, 43.16344799533967, 49.28517741541709, 50.82606092576058, 56.93765101894256, 32.6999254380503, 57.99081133257959, 64.2049204149554, 58.66636899209792, 82.01430489940029, 77.61594726193336, 58.73319833509384, 53.38645081366263, 47.17831157868909, 29.159331321716312, 23.238815569108535, 18.228293618848248, 13.562613706434927, 7.444964041632991, 2.8125938773155217, 3.9299648615621754, 2.8989291671783697, 2.7250183830338144, 2.6042628240200782, 1.5949407580398745, 2.222286727159254, 2.732898669858133, 2.137089414942649, 3.1381160357306084, 6.953390548306127, 9.89007596046694, 14.472733024627933, 25.27040327748945, 36.3639957674088, 56.764584279829464, 82.26156327032274, 80.80703858406314, 95.63692400532385, 96.61798723282354, 106.21619962876844, 85.71923455884381, 65.67825286619126, 88.5435450461603, 67.4407071451987, 48.80533033801664, 40.93940919445407, 32.08071654842746, 29.82976048223434, 40.469575928103545, 53.796036474166385, 85.33516391631096, 94.60534065000473, 96.74890025969475, 93.50771242572416, 106.4284469235328, 102.15132190335183, 100.23132954874347, 75.4460842378678, 50.897451985266905, 21.930432511914162, 3.743908948475315, 0.5259139054725247, 0.18235918645176197, 0.17443750023601517, 0.20158034779371756, 0.13383180654096988, 0.11153580575820901, 0.05930061775049376, 0.18908246600579834, 0.15943795833135807, 0.09882002558198669, 0.16984563050491197, 0.13075429345330886, 0.1422149228352693, 0.14364790561939442, 0.11849805877934541, 0.12496228570178633, 0.1476087487272678, 0.11108533839785284, 0.11382480752804588, 0.26602608482203177, 0.15076512290585428, 0.1441153265055149, 0.14083711370345087, 0.12938006961297605, 0.09589248186638279, 0.12602656568971374, 0.11098468210548164, 0.2148958139361874, 0.21345294861783906, 0.229991193440172, 0.13547091294200192, 0.12258011231859847, 0.11265728187056319, 0.16489602835668674, 0.09213558668571134, 0.11360495561553587, 0.1229277553577577, 0.13047647932844778, 0.1524450924367674, 0.17251976765692237, 0.30932350504782896, 0.11729853362926554, 0.20156278905849304, 0.11061211822614556, 0.17523584046190785, 0.19426661363292128, 0.1362247281377354, 0.11014353288638015, 0.16673250965053038, 0.16254936314878926, 0.1751342418813898, 0.13890859460638416, 0.19933083785637734, 0.14041463153496866], [0.05594645882205618, 0.05280107417474351, 0.021781576572046168, 0.07943328199607712, 0.058315233327448375, 0.03328347511048759, 0.1155358802286848, 0.04851626780545039, 0.10459341739694919, 0.06605308908488482, 0.06256508310475657, 0.056983826141203606, 0.052808777188822154, 0.07285768887208355, 0.01476914862230901, 0.04254820538804897, 0.09329152909377891, 0.08245026647684076, 0.06718302280792306, 0.05896869100510113, 0.05932321351382041, 0.02369738627044905, 0.08872828040752681, 0.028254289833468296, 0.03508692652347588, 0.0037184842503554523, 0.0899028387521544, 0.024537518507831042, 0.03748861216609517, 0.05745943650723465, 0.10779718943541089, 0.06030649502551364, 0.06855562254185639, 0.03328888752167264, 0.03808830579322192, 0.04442769868840133, 0.0458090394855507, 0.0570861793183271, 0.04241606671242945, 0.03735598702464373, 0.07615627961293345, 0.05021620924854952, 0.07177270918844209, 0.04561582828060754, 0.045796644182935844, 0.04493190711664577, 0.4202022908195373, 2.3548324406147003, 12.37802065187885, 41.43783653936079, 61.74352330546226, 72.2298191439721, 76.88468410122779, 87.48247331188571, 70.18885304850917, 45.04908038723854, 36.730356908613636, 31.516338471443426, 25.205544925505116, 33.663510584062145, 28.709368782658732, 23.69245336901757, 55.923667338586625, 47.234911380275605, 67.56637988551971, 64.04966515879478, 72.86090497047671, 69.56648272852745, 40.973792691384595, 31.33174780876406, 19.576806445275587, 17.521029480041996, 12.558135890191602, 7.512017450025005, 2.3482144215414604, 2.1491722762584686, 0.7432386471379189, 0.39348402451122966, 0.10529333830720956, 0.08898705724746951, 0.11858160832836745, 0.056531543152466904, 0.026443097102005157, 0.037798398970476085, 0.011287240702058039, 0.10837751635981184, 0.042293527118501165, 0.07158629701382692, 0.08684777970155401, 0.05546923967138414, 0.06681335474094076, 0.06404895710969163, 0.07219414181646801, 0.5890306638133141, 2.002967521548271, 3.0796364382390053, 4.062108777223095, 9.381967225382406, 18.57329353209465, 27.766381963606808, 44.073288825250444, 56.70057119861726, 51.95325597640007, 49.84497416403986, 64.65423184056436, 80.58513441393453, 57.85549348400485, 30.660255685929332, 29.96658648214033, 22.339092493057255, 22.59852590099458, 25.88489747816517, 35.310219641654726, 43.91791982035483, 54.894684514691754, 64.57686308891543, 76.58520329383113, 76.8795536410424, 74.91984336606919, 80.9809329432826, 67.36452687171199, 47.25398586642358, 20.452410867137296, 1.0497749404561136, 0.23973871232761493, 0.03310613724733553, 0.015818187290982857, 0.09955332494310795, 0.02257729869245762, 0.06996900113599916, 0.08279799378567165, 0.019203271273703828, 0.1067858154795343, 0.020835494374736183, 0.02498452889642889, 0.012755843701832479, 0.06462750671010825, 0.017760340837881933, 0.021872991928830746, 0.05703596991576976, 0.01968507546060268, 0.011005501334194936, 0.023028560869035222, 0.07411014303685197, 0.05359031710653536, 0.037103258448863224, 0.025371024084668008, 0.08004848890367054, 0.021869017847723538, 0.021328619425936092, 0.03897346293313369, 0.05437217878117677, 0.07453196636971927, 0.04819294422744744, 0.05156239044041403, 0.01798972096895018, 0.015976007149044066, 0.03653668280270311, 0.03075483720749617, 0.0419342625255306, 0.048788236679449204, 0.015385887705751005, 0.03609704026471704, 0.031382282369679985, 0.03334486939673943, 0.03214665425701007, 0.005747511449660505, 0.032654965086089026, 0.055639893417396856, 0.08758125526289787, 0.012361047950933778, 0.030392017966556936, 0.02649312264346067, 0.06484005780469987, 0.04008464282378554, 0.010415742909836193, 0.05304958926694048, 0.019777191787837975, 0.028850798450049855, 0.057848927099257715, 0.05714511063190238, 0.0344232454024736, 0.05759127257812408, 0.06975391429037818, 0.0585765918836959, 0.03976783865401822, 0.04143675353618399, 0.05590721596813491, 0.013812098918753046, 0.09087914886373667, 0.01903942421889834, 0.03763692678823587, 0.03233701178443528, 0.06994048734345744, 0.09787570730212236, 0.012647733373958017, 0.048707019868156606, 0.011643616185944167, 0.03422003291967896, 0.031048285271671992, 0.04789996539212523, 0.04914137639946515, 0.07917111904750909, 0.031390414392996224, 0.07460544952341626, 0.06962209354124724, 0.05712188284603819, 0.03553069444493421, 0.043545563765350855, 0.05590987429323216, 0.03594398355832504, 0.017701263967601043, 0.05100050708279014, 0.07697905804361067, 0.043490524178430925, 0.02570895504416718, 0.02077402731013154, 0.06024747561182707, 0.015399524070803198, 0.040905506034652074, 0.017416516747025233, 0.04888558347198752, 0.33062580552312637, 2.6440074655317494, 14.626294797466649, 47.34803645841537, 70.86071583532518, 83.27453105680405, 85.96619482963317, 93.68586647895076, 76.57804104589647, 60.756266655460486, 51.7711599411503, 45.1277905894864, 40.515659855258086, 42.4633284538023, 31.392664178725216, 29.804086608271447, 46.271157572346354, 42.910804210170625, 56.71864548037129, 61.1203920456671, 50.13454314201109, 58.08416374268071, 45.93276293047013, 37.57987168527419, 25.950069619763283, 21.62985344086924, 16.398754062191134, 9.534226771323912, 3.0649729024979377, 2.4373213562273213, 1.0163058460720125, 0.8142749160047501, 0.10422466863547603, 0.09190243548683583, 0.08371996528078472, 0.04145750302761313, 0.08789871443784045, 0.03052195605461396, 0.047868084643156304, 0.1250556871415146, 0.09323025738159496, 0.12290743870600579, 0.027328384476864052, 0.056433204276066636, 0.052770580044917526, 0.10500991641874276, 0.03278137725447455, 0.5060707573448459, 1.6353249910377687, 3.070072964314492, 4.1092019792526004, 8.778820441615197, 17.855091864062896, 27.803334613000196, 43.86028451304282, 51.422527913124334, 51.896699320885446, 58.22653009045509, 63.49190412029144, 64.01377154934791, 53.02772652718329, 27.914596565308113, 40.183741046536355, 33.77376448723578, 31.877524045205888, 38.950371357702444, 46.27694699072069, 60.29623931454074, 66.32464378110825, 73.09678846789946, 84.4158701742849, 86.78497391362345, 86.70599306783369, 94.07953123892509, 79.11424559931602, 56.40388311878328, 25.639739536469985, 1.8600759438930021, 0.19698561289377753, 0.02507182844584027, 0.01948376479108007, 0.040456808337401, 0.06221190508034441, 0.04488709097307536, 0.026057119023114927, 0.06921112567426697, 0.07752957648687786, 0.04653532148128556, 0.06697912850687582, 0.07724085326997504, 0.053177518289416074, 0.03680068819272903, 0.010954050869200259, 0.016778794515337196, 0.01995220457413985, 0.011983341706405965, 0.0019239512978181726, 0.01493870207454048, 0.008575025149771284, 0.022960779324714697, 0.016233983427105893, 0.041000006810551694, 0.05863960644590759, 0.059334440532350735, 0.01618456884076999, 0.03250498805315264, 0.09052091082858463, 0.02970829790067529, 0.06340723589903886, 0.023606867236535878, 0.03169535186081644, 0.04144756686723521, 0.02351805274825423, 0.07466240816058652, 0.034287873835813616, 0.020915782304420587, 0.06965360273757289, 0.036074283622926286, 0.012945439929382936, 0.022356946907577016, 0.03445883784743567, 0.08878100257847579, 0.04152893306567304, 0.02376029741079096, 0.024322774486556172, 0.004332460389818035, 0.08770628081214044, 0.02780178084879393, 0.035145608858475764, 0.0389006232932931, 0.19864367231005625, 0.10062897367583168, 0.08424935501910026, 0.1971839683791322, 0.20192258991301062, 0.17944825152235647, 0.21303595163889472, 0.2096527388259288, 0.21957710144981263, 0.2533369262011782, 0.15686468431545844, 0.10976269525746185, 0.13094697988802387, 0.14372226211332506, 0.12666116994354995, 0.23732815538683247, 0.24587109294389528, 0.19323691485389588, 0.13873239438379967, 0.1313873272269003, 0.13245195961527287, 0.11533776989146588, 0.2174114168531472, 0.08187693393518848, 0.2092342096711359, 0.18513725109158025, 0.29408197128965013, 0.17779653531409081, 0.19404006611195304, 0.15641207956979353, 0.2043676054886272, 0.21171020584241038, 0.28497713888364457, 0.10675885684547887, 0.21720707056022462, 0.1781282054200288, 0.3109540465858675, 0.20071258468012657, 0.1481700613493881, 0.1559893369314171, 0.16466727450249657, 0.1328380066420763, 0.13570087721511243, 0.14841796740168525, 0.13945274685900058, 0.20557451572629715, 0.8906417472227928, 5.822968857903635, 25.124422465601278, 63.337817730442175, 85.00692429081087, 96.1284597458378, 96.72932763253489, 104.42447662353517, 89.22854777305358, 63.24941927386869, 55.049453396951, 46.990645777794626, 40.22698517768614, 47.23705691675986, 42.23546228101177, 38.36795430029593, 71.104750017966, 68.3589889157203, 94.58954134295064, 87.98231663242464, 98.11930579523887, 91.56633530893635, 56.763799805794996, 47.54581020724389, 29.9948706934529, 26.256946056119858, 20.00468800144811, 12.103275291381344, 3.9780183088394905, 3.775390626922731, 1.4617748198009308, 1.156773766682994, 0.2626763500513569, 0.3380587582866992, 0.4155052218946719, 0.20731900518219318, 0.1915405970066786, 0.22039051828605516, 0.1464258630069033, 0.23908215965474808, 0.14770366702108614, 0.18188805770008795, 0.2823086401387569, 0.19420990780476602, 0.20561689571026834, 0.15433683931346864, 0.18564947279951266, 1.1341735600463807, 3.2586585610143604, 4.396905379910623, 6.438470127121096, 14.86487884675303, 25.807762107541485, 38.1299291887591, 57.23437832247827, 75.60063346739739, 75.37503442456646, 75.26311351406959, 90.57539555334276, 102.88635838416316, 76.7430708485265, 47.74157178017401, 50.85223490192045, 37.37274700595487, 36.79999074628277, 42.8176086948764, 54.412338887491536, 66.20282280829646, 76.65499794867732, 85.50266481214955, 98.13537966820502, 96.92914101385303, 98.02026594838789, 108.3508554581673, 97.37822101962183, 73.72909807389783, 36.712529736180464, 3.7509309716763037, 0.3598571773017607, 0.142329698128085, 0.12422642760699797, 0.18053099422925906, 0.16835079378178044, 0.18167802703476724, 0.13872568345358297, 0.19834739546622002, 0.2996557512350621, 0.11487064011875661, 0.23150892087048103, 0.11128361727441512, 0.19858880509291926, 0.11255634212566, 0.0832994672800264, 0.20058493911018296, 0.12767390753593177, 0.13500323158598718, 0.13230376756720005, 0.10367074110094579, 0.12818884885599538, 0.21831345474047048, 0.12032068920351806, 0.21015648760141867, 0.1351882264979424, 0.1474437180666193, 0.14927356503903866, 0.1639760640119353, 0.2046561295226697, 0.1250392545555388, 0.1882453004439031, 0.12759555206303635, 0.12888186731405799, 0.10595621120545173, 0.14669696620154768, 0.15276565426780334, 0.09219781600780065, 0.1444665778187975, 0.17722019204689612, 0.19337026011799613, 0.1246270303043627, 0.1659917639147851, 0.21588487941170895, 0.22097040087946002, 0.18802269061486568, 0.1108174987377659, 0.13764372215636317, 0.12622870564941438, 0.20797157419785378, 0.16672687124340765, 0.183186438835917, 0.0867584538495829], [0.05606710234837187, 0.0565408855947035, 0.07366283961962308, 0.0283283667053066, 0.04760329784344762, 0.06398298927853185, 0.04252640252572395, 0.08395291729679993, 0.08024310587995476, 0.06075725732972065, 0.026010422133690408, 0.0624148762454429, 0.07059812786117678, 0.07450692295547455, 0.07504675447219804, 0.05058648635543162, 0.044720053162065246, 0.05099081607054799, 0.02258556861160023, 0.034859632066781485, 0.04229102967186801, 0.02041345653725007, 0.028207552724427758, 0.1437621752941801, 0.05741226081285746, 0.06599483575912253, 0.021095496955357736, 0.02640912876344256, 0.08569978928614048, 0.07329157042887903, 0.01906014689725013, 0.024983215055638747, 0.07206260451986905, 0.021288307879360455, 0.08132469945497091, 0.028817548318916274, 0.03233079881136937, 0.06973316096850941, 0.027498427267757156, 0.016585795899793025, 0.01995619780744516, 0.06630163099015914, 0.015823334444224114, 0.13151267453307106, 0.6710981084935127, 3.071253352588223, 13.09961909247983, 32.12137976000386, 63.72625004860663, 74.45912176562895, 80.67931052177184, 73.68758370799404, 70.34384942823841, 62.5042042424602, 41.13327626259097, 26.332506595119355, 21.093565417874245, 22.260195978226204, 27.80781395973698, 51.309226328326815, 63.12744925099035, 73.84560031275596, 72.18093856688469, 46.63140373845255, 29.88921969167648, 28.03513296188847, 25.10031753970731, 11.899079641988202, 9.395397420852415, 6.643760117792315, 3.4525045464115762, 1.0072942006011163, 0.47717061134115346, 0.14949494912739725, 0.14532243592604516, 0.032883443148626436, 0.010080958656486004, 0.10177885632841818, 0.14827251794838137, 0.0507497052181392, 0.06364149409496496, 0.01291832616252284, 0.08812239678997187, 0.08821700098774127, 0.04671644764922319, 0.18301483514087816, 0.03544313825606819, 0.11646757337955699, 0.057077786825116605, 0.09712080426153638, 0.06059093964135936, 0.10121994922238012, 0.0635803985830036, 0.02948026225391415, 0.027213940517075604, 0.036604117692237904, 0.21404921017106504, 0.14878428000355923, 0.49968290172757646, 1.6201651528958352, 5.86783734060103, 13.425919105929713, 25.93953021111027, 38.879823607783166, 58.043253421783454, 74.22160656221452, 84.75093472388484, 78.95676243689753, 52.402841967921105, 44.441062019717315, 37.34090520489601, 28.407562009749878, 32.045774113747385, 23.44199630521959, 35.95065247627997, 53.24059747880506, 60.75962812669816, 59.49123167222547, 72.30523847764539, 75.05872664913055, 78.60534944841939, 76.56909019716325, 85.0091600418091, 48.76138410260601, 15.236784258196431, 1.3175770928782802, 0.2976769767701626, 0.05638135927579096, 0.07456542909025185, 0.026726689445035114, 0.06644406205704136, 0.019307030222168373, 0.0485696756250916, 0.03940553652242788, 0.0361146985913717, 0.042945624990088326, 0.02647184646658359, 0.08877642903356783, 0.027163246563906153, 0.05642739349916097, 0.045295672476171486, 0.031159729997236884, 0.06736333692266096, 0.04120227700519947, 0.0681303671350883, 0.014062678617905947, 0.04670232098789946, 0.07761877976478108, 0.023749382573089773, 0.027758278546013662, 0.034586433621664206, 0.06403893667964206, 0.05526683924178924, 0.074002837101298, 0.044658260510092786, 0.07100027039526932, 0.049430509473407463, 0.11174628841540507, 0.043456969527347435, 0.06491649805778457, 0.03303862574900831, 0.04121564523947816, 0.05288961861703185, 0.04692703755872865, 0.03387350836888917, 0.06987844188246997, 0.06316066283972994, 0.06547367380511376, 0.02113647691364731, 0.09233091612376514, 0.023574909878774516, 0.01902961829346755, 0.02258387172684795, 0.059688725553813486, 0.03714031412176067, 0.03196524272132064, 0.053036772615967266, 0.051562003566012274, 0.047408592767052116, 0.004117334760995883, 0.034212651662528515, 0.05327222207861562, 0.02616909234934757, 0.03809491330156884, 0.11998933319362903, 0.05554105275340619, 0.06126300559469289, 0.054005644013804775, 0.08846969508956518, 0.047401632858260025, 0.02627182090955396, 0.07780145343032577, 0.03061015767255618, 0.04351813398722199, 0.017014454652164734, 0.04835927340712759, 0.0224113697937179, 0.022028818043069016, 0.0176665889129283, 0.017258890326164903, 0.06575419222034755, 0.04847669170328206, 0.049269627178868944, 0.050670476405010115, 0.0651617840893807, 0.08188415048343521, 0.012911738763983934, 0.024279168761906125, 0.10977208749541353, 0.05168829699076953, 0.02399456901325574, 0.06680247629241598, 0.04466511699701509, 0.12212831196525406, 0.053319554821017294, 0.03146521904836259, 0.06196289203099667, 0.05799091000470424, 0.03876828160437365, 0.187986163542636, 0.755086656539671, 3.286787103260717, 16.546367560663533, 39.50994453122539, 75.10293960571289, 86.415298369623, 90.93085642783873, 83.60684210254301, 79.01872019613944, 77.12241111263153, 52.97878319217313, 33.46382271858954, 27.266630818766934, 27.967030809771632, 37.20438318867838, 48.863867790468284, 53.90977344205303, 53.06047439575196, 54.37200123263944, 51.22440899572065, 37.71546017739081, 31.594932963771207, 29.304239365362353, 15.918386290150305, 13.411598532430588, 9.14553753791317, 4.266138951624594, 1.8831360484323196, 0.8108654570194983, 0.0910417510256652, 0.056115994079699444, 0.0826031010177347, 0.04654427321868078, 0.02501378962469678, 0.14217139371941168, 0.04503595334808192, 0.06525363037062269, 0.12786644075306194, 0.16518251459685065, 0.18272985043304582, 0.02059250277647328, 0.17787440049071468, 0.2777702739882854, 0.3966978859276541, 0.10104331232967878, 0.06196130239855378, 0.17768700006267718, 0.03899505129083991, 0.13407661759805295, 0.012556499963055455, 0.02063688033470704, 0.1192209623273342, 0.11034348183461737, 0.26878470615033184, 0.47801621919197423, 2.0433240528068235, 5.550787256610009, 13.34241282555365, 25.18268927451103, 33.823786474043324, 50.18472986836588, 59.53762154425345, 61.52270170950121, 61.614583230787716, 47.59312575863254, 39.59820570484285, 37.41289638703869, 31.488140552274643, 38.3387993228051, 34.08388668490995, 49.74584018030475, 64.86476505956342, 72.82859248499717, 69.14369829239385, 81.68144472183721, 83.35315888927829, 89.32111570912024, 87.84657124550112, 98.21627463063886, 56.86322012255269, 17.573704950271114, 1.8368146953082856, 0.2658362175908781, 0.04553816611728361, 0.05543379278312768, 0.0686894964066244, 0.0722707046436206, 0.02266661496832967, 0.03223964200925923, 0.10377115990606048, 0.07614663456596675, 0.031749081437385855, 0.04557005835757141, 0.06859489986973424, 0.03136386178554066, 0.07268218578951013, 0.050184428091010744, 0.0689460362698282, 0.05028023887726088, 0.06574863808289652, 0.02005949518793533, 0.03043450711805734, 0.060093120386403416, 0.044349538567926616, 0.04929422626211759, 0.055355579036498265, 0.03678911260419315, 0.04267117016077523, 0.025429296562628403, 0.032534221968343185, 0.021016624373113437, 0.03209427299518739, 0.032828786605668646, 0.06911728756442186, 0.03145394797977661, 0.012942622641041394, 0.04318998788573569, 0.027333373624470927, 0.03879621700053254, 0.04746528710388849, 0.028919014749267412, 0.08062153799279083, 0.05477928556501866, 0.022003579276403593, 0.062253821581121416, 0.0530311954958785, 0.021086288578507882, 0.07325652956722245, 0.014897958645897528, 0.03765012648317122, 0.02045721930992459, 0.021962741044380014, 0.1816531598207451, 0.10796829517329894, 0.12616978582715796, 0.09302548207943478, 0.16852595212478794, 0.24045756327048426, 0.11800409294664861, 0.14540423879459982, 0.28490350251236274, 0.235721500470273, 0.15883478666505507, 0.16904372030929213, 0.2728939098456214, 0.2626995778372211, 0.1659962378682629, 0.18553397738404814, 0.1660825759773293, 0.17698445147083652, 0.08109423722470961, 0.1597469828782543, 0.1968070684421447, 0.13101438030360207, 0.18726829319230973, 0.1976130695472802, 0.21263528765449602, 0.23653713896149592, 0.28899723123158183, 0.16326302001553197, 0.21519897024958365, 0.1320430831683259, 0.09405906492423627, 0.1335539158073164, 0.22328993125307947, 0.13889731779213876, 0.09740752032807759, 0.10317790141749768, 0.16109872969888872, 0.19112070421538047, 0.20753003176181548, 0.20697152302149804, 0.19138538759321938, 0.09571171575976957, 0.11523100787833815, 0.4619817231451312, 1.714284876661916, 6.586705811562077, 26.115668166068296, 53.3694944074077, 89.47889697167182, 96.2114727881647, 101.11204285775462, 95.1450195620137, 89.79234141688194, 80.61870205786921, 58.833379591664965, 38.26454885544316, 33.13924658683039, 35.39364845521989, 39.285486898114605, 67.61433478324645, 84.13806438446045, 96.94753692996119, 94.0249789145685, 66.08253940459221, 45.344489774396344, 39.24070912022745, 37.772554197619044, 18.351612937065866, 15.056454270116745, 10.422970152670338, 6.569533184651406, 2.723071171391395, 1.2672245238096485, 0.1689834904766852, 0.3674916724764532, 0.11591143951180483, 0.22527245954880792, 0.2313014182953104, 0.42494933932058276, 0.13408110687328925, 0.22771594294857597, 0.230860534694887, 0.36201653401217154, 0.31229329085157764, 0.2901772824266265, 0.2915942386513756, 0.5177305542653607, 0.9679477409489694, 0.23324602523878699, 0.2000548981971318, 0.2319495286792517, 0.22579123896937217, 0.27965941616604406, 0.16836888877855194, 0.149708672336513, 0.40376955162613626, 0.544258585620311, 0.7113106765093342, 1.1480578924379041, 3.355334689540248, 8.670012912442608, 18.5360663167892, 34.07068006453976, 51.851611675754675, 74.89255935915055, 95.2882174522646, 111.36087448366227, 107.88503477650305, 72.42104253461285, 61.12074505898261, 54.87927352228473, 44.02707153751005, 48.33348489576771, 37.896124547527684, 48.89766685424313, 74.34906005859375, 79.84471644124677, 81.53390084543537, 93.6389627764302, 93.66405810079267, 99.88365850140973, 101.98866905704622, 113.94590470098682, 75.46077743653329, 27.653174515693422, 3.1583343830800827, 0.5706561368799979, 0.19432028575289637, 0.2076527743690437, 0.17378016615346556, 0.19855669068713344, 0.12255268637090923, 0.1399960564149003, 0.1850048557765061, 0.24777941796327793, 0.12902586120030574, 0.18820586223756114, 0.19041342120016777, 0.14656978028435863, 0.1803863261856379, 0.14253203727064595, 0.18082466637415273, 0.18911588276105543, 0.10214736760263482, 0.11855179218635445, 0.09987083008332599, 0.13957843124385805, 0.1574075035750866, 0.12741036562910005, 0.13023591239846524, 0.11443518808171635, 0.15686060872770127, 0.12508373362042252, 0.12478583267018681, 0.1089239668762011, 0.12357092447458737, 0.14468724178450723, 0.335143763091295, 0.11092426841177287, 0.2559111808096209, 0.15845990920018765, 0.12437217583459233, 0.20248407107447425, 0.2321567248192526, 0.07704609839786446, 0.15464302933504506, 0.2200284804547987, 0.0946826451728421, 0.21294680964802543, 0.17859843018795216, 0.06635427655231568, 0.15331319262904508, 0.20732874982059005, 0.150295342468927, 0.0735046654458969, 0.11202018017009382], [0.016689294378363317, 0.09132256821518944, 0.032769529704725554, 0.030668209900238344, 0.016420094912210782, 0.05126669965383988, 0.04894120145529028, 0.01667800990323867, 0.0409931350018709, 0.010631126614527838, 0.040031212021506606, 0.041379055624166806, 0.05618557784586184, 0.04188273928218311, 0.05997561015969804, 0.02420417641499831, 0.030033599900742693, 0.02568132416795819, 0.03518308204929194, 0.04616551934891651, 0.055736520087286356, 0.019379084621886575, 0.020014158104576414, 0.040798629108335704, 0.00938751406201552, 0.05434362285379922, 0.04850283445369813, 0.07509852669412091, 0.03328481959479471, 0.03373316106116099, 0.052858071116309975, 0.06396623493562784, 0.05885891443599136, 0.02088413712748837, 0.033562875037351926, 0.019908723338777502, 0.013733779835034043, 0.11106787159317925, 0.03248214714169022, 0.023077787763829676, 0.031554987316109964, 0.06885589836465736, 0.20933904114269444, 2.4644796021523017, 26.63363087561823, 41.98866282739947, 66.88088293998473, 71.389647453062, 71.47519434652021, 69.12023467402305, 70.31506707591396, 52.18839422349007, 30.72297242379958, 23.709566670079386, 18.087051030128233, 19.609067939942886, 30.319764537196008, 55.17939367601949, 73.55312485848704, 69.1557321240825, 50.9213117630251, 50.15556312376454, 24.760944266473096, 10.656046213642245, 7.559877720571334, 4.785907422342609, 1.0435190051794052, 1.05117351057068, 0.6038985918125799, 0.05762394622809464, 0.04414614605446977, 0.042143887164251465, 0.053573091619557915, 0.12018758142667434, 0.10485718146927896, 0.09928894033955951, 0.06519130145710322, 0.016225577527356726, 0.06575783879886712, 0.08945034891967812, 0.10316598108939587, 0.0016933980946158692, 0.05518291814012393, 0.11941656755704073, 0.04749840508485514, 0.16524309682990276, 0.31686910337978796, 0.3226523930507322, 0.14145913113269115, 0.18714069358764157, 0.12959282755130722, 0.07278223687242116, 0.029476286257587136, 0.07874811593923839, 0.026927092300367453, 0.07895471453065835, 0.090809588080212, 0.09054291287376996, 0.03606387248803531, 0.07799364190789, 0.051702672630668654, 0.07529837605092796, 1.2962581529732675, 4.462181464318307, 9.021287637372172, 17.4359905335211, 30.025229838586625, 48.13461680566111, 84.52177416893744, 83.7436386846727, 59.98253207052908, 36.69434955043178, 20.331407708506433, 24.796943779914614, 26.196339553402318, 26.552251500468103, 32.54843173488494, 40.880091190338135, 47.147803383488814, 58.947175395104196, 70.1156851553148, 74.86371424890335, 73.43896035225161, 78.89269444250291, 78.65011153682586, 44.2681247188199, 12.042209871353643, 1.0892600926660723, 0.02878718825447704, 0.05690532128116297, 0.12794880286580132, 0.002625900425858075, 0.03409086283476603, 0.10746604793014065, 0.057639900009117784, 0.06976706802003807, 0.030773993236042803, 0.010920706892295951, 0.019923265602800156, 0.05982918011385107, 0.06859737433372967, 0.04463817751515777, 0.045549737875379866, 0.04096500425329132, 0.023023326573292577, 0.010953547166390045, 0.0891149326437904, 0.022047589112433697, 0.0776630060206498, 0.047214006434284875, 0.043389714668474855, 0.03876357016363933, 0.058999353674270456, 0.07047703234298576, 0.0607730885366759, 0.06638171782176341, 0.05775823761078139, 0.08243371897767629, 0.15830508283069059, 0.04601094195799482, 0.019634848821067044, 0.03155461576346669, 0.029947420754920573, 0.059279427758508155, 0.0593987574440337, 0.004747659456165087, 0.03187625203281641, 0.050400258041918285, 0.0214305455090418, 0.04232547681538328, 0.06939804346691217, 0.02280272772505639, 0.02670190841590445, 0.035453101229523463, 0.01579944973796486, 0.09143100796087135, 0.04110020728060796, 0.06031130988811774, 0.04912127425233203, 0.04637238607110997, 0.013691868122306564, 0.019399324664846063, 0.07358222418735105, 0.024451628560200337, 0.032736350436724966, 0.02349871285860577, 0.0321782668752055, 0.028690534771510193, 0.04443082815757202, 0.02055917220610765, 0.021590479769774025, 0.10807409191564207, 0.043495151349493576, 0.07628801609239272, 0.04636265292403199, 0.037437345562202316, 0.05326035920710814, 0.0717702960114806, 0.045322883919241934, 0.028523523773577426, 0.04112458802879818, 0.012428753844071782, 0.0371823417052867, 0.04116720166958628, 0.04389789143216707, 0.0698148412629962, 0.014667982881468151, 0.028749707402781616, 0.07193082973601357, 0.025604339992447246, 0.044321036266703764, 0.11065831332797967, 0.055748428924069296, 0.04845501524546454, 0.03353595470769271, 0.025632959122078556, 0.030683847669992718, 0.050720716451084426, 0.3457855210909921, 4.007827831852821, 31.37910846740969, 48.65062813605032, 77.16498451848184, 81.25261199089789, 83.00082806617984, 75.59076478404384, 79.6751602234379, 63.13527830185429, 45.25526762008668, 41.51230665945238, 26.73505356234889, 30.254915991137107, 35.13441901053152, 43.07541824156239, 47.39977644335839, 56.03515678836454, 52.62419700622559, 51.45766842749811, 29.840911780634237, 13.031354162000842, 9.125119639981179, 6.340803600126698, 1.3851992449452801, 1.0962582139238235, 0.7925078453075501, 0.08627481488210541, 0.030744960418932384, 0.029856219902754794, 0.043086382154856, 0.20658553728172857, 0.06579436587109681, 0.4173244968537362, 0.06887181767172391, 0.16256997091395242, 0.17041009940928029, 0.11283939629192315, 0.1879643453585525, 0.20024530168983246, 0.22229250009742477, 0.09918558741769484, 0.2621399659302927, 1.6102554072295467, 0.954341161395273, 0.7351651835826136, 0.33849270113052865, 0.1657382347771237, 0.32776026896411375, 0.4577139086059986, 0.15695908166948827, 0.2986414814668317, 0.033671119430613135, 0.08990386530997292, 0.02959779163281764, 0.09521735156135214, 0.01956213175529434, 0.04319723507749938, 0.11885009150231078, 0.04518595336365604, 1.408561371987866, 3.870456622492883, 9.53523580105074, 16.570148891018285, 30.310039020353752, 38.47948297377556, 57.2032739270118, 57.2329701915864, 54.46267466391287, 44.73477694296068, 29.638099747319377, 32.73375784197162, 29.83014487451123, 38.222626563041445, 46.34025404530187, 55.513105007909964, 59.44126067623016, 69.86851307653612, 78.29570185753607, 86.83146184490573, 83.89745050860991, 92.71590355903872, 91.78546244098295, 51.82113878188595, 14.467366241639661, 1.4070947732656234, 0.04871109162547416, 0.09838373084822971, 0.04022063875210382, 0.016605402004995173, 0.02658098909793602, 0.05057180044992317, 0.019486942140746023, 0.022214335810032584, 0.03266798475036218, 0.012976578530675222, 0.04853539702091967, 0.04929569715093221, 0.03722066142325921, 0.10118040376372876, 0.020745854426716125, 0.054707342248049476, 0.015083026336205584, 0.0528424505835339, 0.056040718280259645, 0.030122452693420555, 0.12415004098006796, 0.054289920090307156, 0.03570282291020117, 0.010949123008627324, 0.058847947887355284, 0.09851460164833455, 0.06628465448175708, 0.04961822782793353, 0.03906836590519355, 0.0609025382436812, 0.03901751681921944, 0.0692280255738766, 0.07575078927461179, 0.03190298275571437, 0.02520217447571697, 0.08850234575689801, 0.019834673280016552, 0.02199742184471219, 0.0313544542258305, 0.03720196121702752, 0.0583809215365158, 0.0475984791504039, 0.026119989943840814, 0.05978435247896179, 0.09167591094850533, 0.016777513233283838, 0.03302321589041141, 0.06810245855200676, 0.15691388248195573, 0.21353199356986632, 0.08722262652290445, 0.18008798090440614, 0.12085468313025853, 0.2039310732676137, 0.18911110237240794, 0.08318078493879688, 0.08504920443820377, 0.08255338957232815, 0.165465890520042, 0.09223621233456558, 0.20045802898464665, 0.15390900985127495, 0.2113591537119881, 0.13447475349230154, 0.15800494490371597, 0.18237447756673061, 0.15121020466810273, 0.13519731230072438, 0.15078044466433987, 0.1102498122641156, 0.21798491027326355, 0.20050848353533976, 0.16238090041424, 0.17209823543746627, 0.21441111010649513, 0.1510461699217558, 0.13029313916640897, 0.1661081173487248, 0.27269135619844165, 0.2733416116285709, 0.1469321092290263, 0.08176031237047526, 0.21880739759052956, 0.1940019762203578, 0.12786246475673493, 0.1939177678357209, 0.16052120665629066, 0.06851554848253727, 0.10269130535063245, 0.2606324274693766, 0.5392355003183888, 7.976724178560319, 39.9243547070411, 65.46229500924387, 93.38763298526888, 91.80947519117787, 91.31222847969302, 86.89318426193731, 88.94393274860998, 71.85797060689619, 47.58156653373472, 40.1098043687882, 32.678550481796265, 33.17677974700928, 47.24551746922155, 76.12617615730532, 96.60778907037552, 91.25998250899777, 70.89655845395981, 66.84654651149627, 34.70685712752804, 15.882469146482407, 12.041670545454949, 7.870144555645605, 1.7453711311663351, 2.1244363390630294, 1.2760178648656415, 0.2970620839586181, 0.08954492247393055, 0.30614488367592135, 0.14500950433073506, 0.45146278436145476, 0.17460708145893392, 0.5303112501578947, 0.225130258308303, 0.22599294991983523, 0.2040746075011069, 0.1814758717533081, 0.2525083255022764, 0.16850076315383758, 0.23869183785732717, 0.3923026556449552, 0.16861837297197313, 2.068021869467151, 1.1581897423152, 0.5335847132148281, 0.25847889302719024, 0.32104376162732806, 0.28743811973160316, 0.24753033213557737, 0.11385641631580169, 0.3078011044811818, 0.2311753661882493, 0.1925019454210997, 0.2003535345917748, 0.23126751124378175, 0.10634152278784784, 0.2376051421367353, 0.1586998632598308, 0.34957633864495063, 2.4005398202326993, 6.728957430008919, 13.345380098589006, 24.71244808166258, 44.23119168127737, 63.04876258296352, 106.12756975235479, 106.55620636478548, 83.7467138228878, 59.36203272111955, 34.30724997674265, 40.79459136532199, 39.25381768134333, 44.32978830029888, 49.97984486241495, 60.761063714181226, 65.85767776735368, 79.35305518488731, 93.1851210132722, 96.79456449324086, 93.76371768213089, 101.86806401898785, 105.07561360636066, 69.9848113521453, 23.75730191507647, 2.9024134576320653, 0.12214990032296028, 0.19420869738584567, 0.17721357304723034, 0.06864734624903049, 0.08541549405743999, 0.2259165403102675, 0.12804915272300282, 0.19085759897866558, 0.15459447468240417, 0.10709505453104935, 0.11133764945571462, 0.12291655515230472, 0.10354458174157528, 0.20390704875030827, 0.11570138586384636, 0.11094161264237859, 0.1291461982914517, 0.15078995947635945, 0.21429043593666247, 0.07804234977811575, 0.2652637354068218, 0.22113100355190618, 0.1312293292533967, 0.11018043534169275, 0.1228145735278245, 0.26854960908812864, 0.16082912803657595, 0.22567119299163743, 0.14637732367602088, 0.12028938685093196, 0.31150633469223976, 0.12235367971081888, 0.29685272745067076, 0.10497413245179962, 0.08685400033549917, 0.24341414171841838, 0.1290343034892313, 0.1394689419577199, 0.10216986760497095, 0.11176795338190372, 0.12152317911386491, 0.12425132546453707, 0.1211567132944061, 0.19614742077406377, 0.1255704829048726, 0.12189602644573297, 0.13427256756732542, 0.19756054655919153], [0.017088502795705875, 0.022063765058954878, 0.10919601235899234, 0.03917256535421457, 0.016269708022234902, 0.0469931586074733, 0.025051958040304245, 0.012578635116017634, 0.026825564582982374, 0.027354450618487694, 0.020429680364266522, 0.05827482985032182, 0.020365258115493966, 0.05388981535009319, 0.14042377862478458, 0.022169544564319715, 0.017050456954166293, 0.0732619994350018, 0.08244154073538319, 0.0216110932805966, 0.015729079774070173, 0.07366008936397492, 0.01896712658626418, 0.10468358594563701, 0.0007171040828501236, 0.04458743568149306, 0.07028482854366302, 0.04349941845923182, 0.015286683149996306, 0.046849938470029065, 0.020619903826304985, 0.08063312124220595, 0.016733419127582062, 0.03767563338061014, 0.05380818102088186, 0.000702947256814373, 0.07010399348913662, 0.06305215414613485, 0.025691248837017247, 0.019028928814335697, 0.07005456549626204, 0.5281757647472044, 5.432839134047109, 34.63541507720947, 45.76492471079673, 73.35104434720932, 75.07680877562493, 70.81149008966261, 54.37427228496921, 100.37375080970027, 64.5807501577562, 25.323096398384344, 21.54965469914098, 19.696289685464677, 22.36489188286566, 35.006683103499874, 44.726292856277965, 56.78544736677601, 72.32115545580464, 49.45155259101622, 24.89485594534105, 7.093741288108211, 1.321877726624089, 0.46656387888135453, 0.21651383759754322, 0.08482215896008477, 0.13736235338353342, 0.07499495160675819, 0.08757987630463417, 0.21942313309879075, 0.11512373258630115, 0.5172991548334399, 0.3756187008994241, 0.12756245706470745, 0.14187108725309372, 0.11810301788031094, 0.03443368718088154, 0.07498963495656367, 0.13126548860342274, 0.1575151542502065, 0.051464009429177934, 0.060296206464690555, 0.11014593074158316, 0.2677716621227803, 0.14985023006316156, 0.8266004739749817, 0.18392349202786723, 0.2374064036074185, 0.2144756759967535, 0.10215875166918963, 0.20917624745878483, 0.541027165468662, 0.4068070289588744, 0.023181385833830125, 0.129074553748773, 0.10989761866268613, 0.13565868109224305, 0.0261691517211617, 0.057735063451071905, 0.05704098396123417, 0.05922276789562837, 0.10459317224881343, 0.0663588960624991, 0.04658407148634715, 0.10084799055250422, 0.1895102801462335, 0.56644614665739, 4.164785396668219, 12.666961070029968, 34.50925204061693, 53.30035086601011, 70.32046425727107, 58.52996856935563, 57.91666284684212, 37.96494645457114, 26.00168016649062, 18.49874104222944, 20.32896407188908, 25.92093425412332, 35.027950194574174, 47.85487728734171, 51.63658342053814, 72.12717071656259, 67.78578158347838, 75.66290501625308, 79.21097909250568, 80.60931190367668, 37.274899559636275, 6.237148594471717, 0.6695865863753904, 0.09343605158069442, 0.06044870775733745, 0.012473972183802437, 0.0387281654102187, 0.050364546853327946, 0.08216613212660437, 0.023882459706416535, 0.026448777643963698, 0.04904995146658152, 0.020003137929785638, 0.0233606044428363, 0.031002220404785008, 0.0632979802697176, 0.02709713892170018, 0.02387862160591589, 0.04623635183839549, 0.02761178912835256, 0.042228976550001296, 0.04537877769419744, 0.08793082118274705, 0.0259903755279318, 0.029916850016302163, 0.05570499939964183, 0.020287337397495588, 0.07786351421307172, 0.04372349151620462, 0.030838584024158698, 0.014386363214843217, 0.03291670285585908, 0.07897864711741287, 0.005434740254009564, 0.052292843784896605, 0.013545988702155171, 0.031158182499629837, 0.021366881687314283, 0.0258320021713453, 0.02610684387506016, 0.036038829073790586, 0.026600198752637354, 0.011060609869028052, 0.011005155637019105, 0.07716794468222127, 0.0869398404874148, 0.01737062808036083, 0.030440938426181677, 0.023191789307841854, 0.03716206335793099, 0.015595416583481337, 0.07117708348819325, 0.04969803503744545, 0.02054024408871849, 0.05836875989071785, 0.01695083105005324, 0.02188772954527409, 0.025081758860558755, 0.02986312235495256, 0.018875914242779537, 0.022330963120405233, 0.08538593838532126, 0.02768105688324619, 0.044646907087054946, 0.06677456770933445, 0.02793704707836432, 0.02565501096297897, 0.018378200324913187, 0.03571840513858103, 0.039409757666890664, 0.020712615786901405, 0.025028167179815715, 0.08981641637341631, 0.031035863155979785, 0.03817770059310621, 0.047580621640888915, 0.04580629306034215, 0.05948579269311121, 0.03780350111605179, 0.06484037190074883, 0.08219211016811671, 0.01628056923378139, 0.0404023471468639, 0.08256145647817081, 0.07491175445818132, 0.023294582985521808, 0.013442311150532578, 0.05668114097188077, 0.06885790551501898, 0.03852858418418515, 0.4578009668377138, 6.877958466929774, 40.45490626365908, 57.88759023912492, 85.58081411546277, 83.54843801067722, 81.35257751710954, 67.2467694743987, 100.9806356122417, 75.07972701903313, 39.76778153450259, 28.446491533710113, 22.031390397779404, 25.001926845119847, 25.79392790794373, 40.12170876226118, 54.76497173309327, 61.20736275949786, 49.18465883501115, 28.43543044982418, 9.306774408586564, 1.782361533372633, 0.8927828710406058, 0.3264797989639544, 0.05194541525035616, 0.20788704405628866, 0.036991237242135315, 0.05723230292900436, 0.15894940874028593, 0.16629006323074141, 0.4456086775227901, 0.19515811015040646, 0.16392182498689623, 0.8441596994957618, 0.8186355497567885, 0.31125974631117237, 0.22692446687048484, 0.3002645766302463, 0.7793303975655187, 0.44078780878936097, 0.5825023689577656, 0.4737660246751001, 1.1556485367398108, 1.4270736108864508, 1.7052142730643673, 1.290906324021278, 1.8145865009677027, 0.7110804824098464, 0.6976448323938155, 0.4056898276171377, 3.1568460887478245, 3.2348002541449765, 1.0136332410958506, 0.2203227654700318, 0.13759850764707213, 0.37400231666622624, 0.030154595827503555, 0.3023054042170125, 0.07424911138631644, 0.06232164717549759, 0.04695197372066398, 0.047670583345837174, 0.051083581657299114, 0.07979373402533033, 0.23120705158479754, 0.9845633300081377, 4.9472016576797735, 14.53365331695926, 31.459766126448113, 49.651687606688476, 51.49942990272276, 39.15374232876686, 52.17643099446451, 45.299362905563854, 39.21958715684953, 31.330694652372795, 34.20670001737533, 39.374163842970326, 45.82141076364825, 60.50151655750891, 59.554099421347345, 82.18992510149556, 78.30121670999836, 85.7224665918658, 91.40449047088624, 92.82976212040072, 44.21185439632785, 7.986851738345239, 0.4253566223046472, 0.02221118527344398, 0.06405046630290247, 0.031297932258777084, 0.022115318945819334, 0.05554599019007818, 0.09229019088971038, 0.07875235240545966, 0.060744624539849267, 0.09434296178721613, 0.021637824003494555, 0.02575022803108779, 0.18303956445907393, 0.08062383625656366, 0.02547138543318837, 0.01378029956662607, 0.12451584796391188, 0.06247076618995878, 0.12486054922544187, 0.025930048019114523, 0.025838715016781807, 0.032399486254660353, 0.03112549735834041, 0.09491564315413276, 0.021569973511260845, 0.02521514817471466, 0.04600127775883002, 0.040782265470273076, 0.04128408370419376, 0.08166678835667911, 0.04233503376223868, 0.02019489165245285, 0.016631253642000018, 0.017096585023307034, 0.038250019293158286, 0.006930155852328867, 0.10596656105330876, 0.02268737403585786, 0.0012477791132104975, 0.01390158564918825, 0.0584655934043469, 0.06568561202936596, 0.10202961988867291, 0.04442774848411641, 0.0466855934580728, 0.04441204751210828, 0.015857569955950303, 0.14678396314622896, 0.15040444871110303, 0.20470738080480408, 0.16845383260759617, 0.12475190263602043, 0.10949681678246106, 0.08112679596149153, 0.09861141217932587, 0.10822927068558433, 0.10935037907573486, 0.09447240000290257, 0.21653105925408103, 0.19279904963989414, 0.18361480455965767, 0.2802634305290638, 0.18667717974993492, 0.13349250619930605, 0.11453078819378731, 0.1518559861447542, 0.15228563889620766, 0.1828032416561919, 0.14039675104281596, 0.11172989413382546, 0.1335564745409835, 0.21030887781131655, 0.11371023907896974, 0.12545014581372663, 0.1203273005423046, 0.16304850007497496, 0.10597698750995821, 0.117304164375509, 0.18055642834834515, 0.10224450755143359, 0.09463992044930497, 0.1796903353064291, 0.1541462826031831, 0.18310241431238192, 0.16281979218606027, 0.11649319902062417, 0.25908652332521254, 0.2780168623693528, 0.9174454476564162, 13.673367711805529, 56.64685433910739, 70.34572432118078, 95.96367313015847, 93.22285421432989, 90.12921810150148, 71.54664424157912, 115.45127899416032, 79.42725858380719, 40.21206055918048, 35.86935350971837, 33.77437245461249, 38.22790999566355, 52.56999377281436, 63.831797107573486, 78.12383144132554, 93.06109566842356, 64.16488478260656, 35.82610545619842, 11.080793796047088, 2.565491665755549, 1.2059067237761714, 0.6122231483459473, 0.2619056962430477, 0.5686514992867747, 0.21619416442849945, 0.15884503692148194, 0.5361464499465881, 0.3251081338572887, 1.6147977570372245, 0.9278650401580719, 0.1819331496353111, 0.6678319998806523, 0.3302409842370018, 0.19826661915548388, 0.34621802368952387, 0.4099192151859884, 0.586748150808196, 0.2555139335773645, 0.8215499320818532, 0.42024215803511683, 1.1977657219094615, 2.069949714406844, 2.7762989603704025, 1.5455038172583428, 1.390503760307066, 0.43590553044792146, 0.4489623959506712, 0.5387710671751731, 1.6214270529247101, 1.2003988580357645, 0.34334222155232585, 0.36014826006947026, 0.2628140313731086, 0.611951953220752, 0.4928182329862349, 0.4853337071835995, 0.20776848428912703, 0.23978821692928193, 0.3442515679184468, 0.24302190470118679, 0.18331413037113606, 0.2186361462959359, 0.46741307202366095, 1.5894716257049193, 7.3462169016561205, 18.341561863499305, 47.418286108201556, 70.08214889034149, 88.62402423735588, 79.01387214660645, 74.02643726718041, 60.77283866943852, 44.456445555533136, 34.054261022998446, 34.79624402138495, 40.45885216805243, 52.343531808545514, 68.07709601617628, 72.19766355329945, 94.321086483617, 91.28441103043096, 95.80418955895209, 99.92860886358447, 107.52023081625663, 59.458236694335945, 11.977579997431848, 0.9290511281259599, 0.29343269645206393, 0.1696141187341944, 0.08724969240926927, 0.1359827209624552, 0.17242587592092254, 0.35885927117159294, 0.15397993427130485, 0.1874470981138368, 0.24525520421804922, 0.13712394682149734, 0.09918210937851861, 0.27970482985819545, 0.18683018283017222, 0.08785611228837122, 0.13483691389762587, 0.17683376197613057, 0.2737259426184239, 0.15740552706824196, 0.12224298000576035, 0.15814900007699767, 0.12176252796404785, 0.2284156263715798, 0.16050763157827241, 0.10226965821798771, 0.33108640822672075, 0.123923470476462, 0.16224069100233818, 0.07889266906967086, 0.19636238504561687, 0.205050312403229, 0.192198712498911, 0.12894917579908527, 0.08032260282385735, 0.1563476056100861, 0.08240851468496746, 0.258275787796705, 0.10171239054010761, 0.18152661741741244, 0.11414637293426261, 0.1955286975228979, 0.1728699924123864, 0.19050970313049134, 0.15294960730018156, 0.11077509577115698, 0.09743247947265064, 0.08754522614781896], [0.05731110656333547, 0.020520017452297673, 0.05741381214090413, 0.026655129172028075, 0.0738734218682493, 0.03252361548103152, 0.033020902304880084, 0.05659496374127846, 0.021554255302274422, 0.04919600612934559, 0.011505036626101263, 0.05471268954176096, 0.041223796414992506, 0.010531594556185507, 0.03719627684462936, 0.040836075486074534, 0.0599242018295392, 0.01706087574993651, 0.03771368496780915, 0.012921448928424189, 0.08215998044057239, 0.017499897756703922, 0.05224737263615093, 0.0484020670785779, 0.08367262104706419, 0.010476190119891638, 0.02317260455099806, 0.022570815673398397, 0.007377000095608134, 0.06746938647401911, 0.02551700405385946, 0.02174643611895942, 0.029370709765522234, 0.03545885071939519, 0.0859969241484519, 0.050611541260995214, 0.009747702748544756, 0.018068909562463244, 0.07790732678146133, 0.046593892733536424, 4.228237088649504, 20.64591903840342, 57.57776614158385, 76.11047883187571, 71.74051130971601, 73.52851590802594, 66.02399410740023, 56.35273933410645, 42.301522839453916, 87.23256341872677, 39.86214199373799, 28.299430108839466, 49.42941865613384, 58.70170562498031, 59.49626015078638, 78.60400799782046, 71.72833627270114, 46.340579602026175, 21.419041733587942, 9.142831102494272, 1.6985160905507304, 0.2940289580052899, 0.10774754693791752, 0.09052081889803372, 0.04953567036277345, 0.05409627221524716, 0.05778563291495366, 0.08040829741906735, 0.1460567158797095, 0.13523463610439532, 0.40443329020373286, 0.9830450050292477, 0.6757811733311223, 0.4699242163089014, 0.4542442963969323, 0.2956167824806706, 0.40623849978850735, 0.3538171562456316, 0.7357433654608265, 1.184074321100789, 0.8220973478690271, 0.5481053275927421, 0.5959403478810864, 0.24309220092911876, 1.268287608700414, 1.5346872686378419, 1.6575502436007223, 2.2995235891111436, 1.1918048224141522, 0.515860625572743, 0.8015800423679814, 6.896386252295587, 8.122692733041703, 1.4366001900165313, 0.31817044161500474, 0.5452898625404604, 0.6554418453766454, 0.3144621776957666, 0.136064937518489, 0.11666189158155073, 0.09768225477948304, 0.14506786490880674, 0.04942654879883893, 0.05510968779544196, 0.10139420358163696, 0.0439350888313305, 0.08626152325661914, 0.09028072694256421, 0.23388382407926747, 0.5428814046805905, 11.273261558625007, 44.383477703217544, 84.01345852882632, 90.56521308037543, 50.04057491979292, 36.16214667597125, 33.73569788471345, 37.917552455779045, 24.45678407146085, 25.808528930910175, 25.876562441548995, 49.90063259678502, 58.69844613536712, 61.94030077226701, 72.90967572119929, 74.19116896967735, 81.38506258687666, 80.5841459766511, 57.066634239689, 24.170882509600734, 1.2783135545830573, 0.11737180993922296, 0.05796629176925748, 0.06805798714800228, 0.0716262255164404, 0.04974372452124954, 0.06572151090949774, 0.04912651812417373, 0.05453532486553154, 0.035874974358105854, 0.021603177677118973, 0.020650039810026367, 0.028150270415109493, 0.007984413016181921, 0.02757231644805401, 0.024256954127321803, 0.05077652595636826, 0.03571287015332811, 0.04458959987987915, 0.023430299291747714, 0.04423285188573984, 0.05217704576470199, 0.026826575819042422, 0.073615288542163, 0.03910218868705054, 0.03387048998246751, 0.035193324644839576, 0.013883205284664949, 0.006321619655336104, 0.03931549437824757, 0.029993158119219928, 0.01723421080368421, 0.03229639763312955, 0.04639280231429204, 0.022153826355333292, 0.04912251531476936, 0.03498788284618528, 0.03174273248371338, 0.031085005781102567, 0.03244312645326699, 0.04835865670634855, 0.07475008692352042, 0.019139268458069816, 0.02187316812905333, 0.023845066954832406, 0.05734469951881517, 0.04103526983770632, 0.01704028522175166, 0.011065190117205343, 0.08370755465641137, 0.04141829081720883, 0.06145320990453325, 0.032352233951490734, 0.04430288764377756, 0.0133764888760784, 0.023635813868754817, 0.014249173146972974, 0.01203481132359875, 0.05526419623845047, 0.02578420786096925, 0.019347081298849756, 0.02520245218258952, 0.06553184286120438, 0.017325968984814904, 0.038357018793542544, 0.036649106205591274, 0.1027943135329312, 0.03927379621252899, 0.01890214700852671, 0.13105944159530825, 0.006750177858667749, 0.005950801020052525, 0.04955096913862133, 0.023168534708900318, 0.02947686656918978, 0.03413177576036223, 0.005560800021949915, 0.04169369176510842, 0.06162728040268826, 0.03636954156982322, 0.06429390606260107, 0.04790158949852471, 0.0158991982161458, 0.07773687221830891, 0.0354039260456639, 0.1353642275376666, 4.314004125133637, 25.349270374544208, 65.76489802329772, 89.31061160179877, 81.16225627160843, 83.65249849134877, 78.60532591419836, 68.60587858384656, 44.911032569023874, 95.04499127787929, 50.19572427195888, 35.87384854593585, 54.68975636266894, 51.16627162502658, 45.066617304278964, 63.30882749249859, 55.332950545895486, 49.165733398929724, 24.209813994746057, 12.017356753349306, 2.460526098166743, 0.21486084968332322, 0.08853658988711335, 0.10772272568917084, 0.0654274174162457, 0.0935713350472431, 0.0890130582716196, 0.09034796647967831, 0.16404625298755784, 0.18798407978348194, 0.35581122182549973, 0.8019226368877196, 1.4855096945839545, 2.110714662459589, 3.2769142523888624, 3.728929907083512, 3.2526372325035835, 1.9968402890428423, 2.285617070813333, 2.153773951915003, 2.197154630576411, 2.9359377103467144, 2.6713434438551626, 2.031151712421448, 3.613221212740868, 4.429413983898779, 4.478393600833032, 4.643887223735933, 2.007863620115865, 3.2002471147045015, 2.04948217397736, 4.766675551091471, 10.92346948962058, 3.724970029246423, 0.6983511041729682, 0.3941484985332335, 1.0776257298646437, 0.5517848172495442, 0.6272174502092024, 0.060913048970002326, 0.11452659003196225, 0.06996197610973351, 0.05196619155486265, 0.052728177078308604, 0.03784017757542672, 0.05241276718856347, 0.004200298252755836, 0.06811677673531157, 0.07416597552477353, 0.7123729033816246, 9.947876007326188, 40.97390251774942, 72.07206141564154, 74.2898165795111, 45.42594563576483, 35.13553296366046, 31.04326140496039, 32.17855222763554, 25.394844393576346, 37.51290898169241, 41.025477763145204, 61.65430507352276, 73.00465199255174, 71.82352435204291, 84.7254079388034, 81.74868983607139, 92.49117528238605, 94.08304568259948, 68.96119825301632, 27.7585195725964, 1.441323581722475, 0.20895356102095497, 0.06761174859298814, 0.057678131626979004, 0.054713390512211676, 0.03751896456965516, 0.04029915893390294, 0.025065759114260157, 0.029206801423682805, 0.003424821202755876, 0.07151728015272849, 0.006923460722675608, 0.1022580060206594, 0.10832370634401038, 0.01799334648005184, 0.029676422897365787, 0.06569893429836919, 0.0330236257474509, 0.0534135346571284, 0.021885452348919168, 0.03866039727243685, 0.08034843530866408, 0.14132932519480107, 0.033376455201857516, 0.052721707465788054, 0.01083025201824644, 0.05527094164262376, 0.040955033618956804, 0.03000012760411107, 0.04784469597882802, 0.03214474669807861, 0.04077933135352308, 0.03544670439535572, 0.048341726163221944, 0.04148025966940388, 0.022683702559480746, 0.05532830247595426, 0.016255508582558365, 0.06696074239669308, 0.03006603606345673, 0.007525242897005933, 0.027110246686084617, 0.033938874821028406, 0.044022254315355135, 0.07317134059004246, 0.039394577634671045, 0.11068354060332622, 0.11347636775744539, 0.09174114333525782, 0.16344314260828882, 0.12573927505722932, 0.15424408138759677, 0.07396009705600239, 0.22667256183922294, 0.11638341096019554, 0.12533429799781692, 0.14507364121175584, 0.12369506902271703, 0.2551861705198403, 0.0906375783585733, 0.08704936041706994, 0.08645276178515728, 0.24130488715825543, 0.1105912040258127, 0.09199308667091594, 0.09546312022834055, 0.21526280069543471, 0.10681058310212628, 0.13717604080034843, 0.13982426885875965, 0.11885470335161495, 0.1676662329344019, 0.13553380876058532, 0.1302800084193868, 0.15125638444817838, 0.1855300856573928, 0.08015802415508418, 0.24534226244976445, 0.20217729882607538, 0.12307239275786186, 0.30763296350356073, 0.2072544852572103, 0.11975212172875482, 0.21815781631777365, 0.20321315695201198, 0.2161050837246641, 8.540038312635115, 37.990249664552756, 81.71901318334764, 99.65414493314682, 92.64957627942486, 94.86278149389452, 85.45316450057491, 72.86829471588135, 56.51640415191651, 98.54311789235761, 52.30213903611707, 40.974133937589585, 63.823920988267474, 79.91411101433539, 78.78546468673214, 106.53880673070108, 92.73892002720987, 63.622319006150775, 30.95240950584412, 14.096342382892487, 2.9388878230125677, 0.5421097396362213, 0.3710369435289214, 0.3058965486143866, 0.2858506016913922, 0.20964130879409854, 0.12808695150118682, 0.35920676865404655, 0.5456977890383813, 0.5887378956521712, 0.8755306935598774, 2.498038175605959, 1.8703827069651697, 1.9816028615159376, 3.2976138255288525, 4.807523604362242, 2.048118414898073, 1.7040683281037117, 2.141099548147571, 3.510835584132902, 2.5421408155272087, 1.7820439439627433, 1.5353012421438772, 1.3289013432879604, 3.669189512729645, 4.67107464228907, 4.40865925242824, 4.809794166395742, 1.8413775149853, 2.7433941969948434, 0.9315922111272813, 14.190824435603234, 18.756836921938007, 2.0244451948711952, 1.8188658068256995, 1.3046543540493136, 2.0889759063720703, 2.6779357223741473, 1.0699192530685857, 0.609691626121921, 0.4842945855231055, 0.2874806529331592, 0.33679878879939357, 0.22371400688444415, 0.46700581968311344, 0.13054732713968525, 0.16067411780597704, 0.2069696690887213, 0.4122497465822005, 1.1196572357608428, 15.97886629642979, 57.30555757399529, 106.57013077889721, 111.14700332764657, 63.87817521249095, 51.77010874594412, 47.689278741036695, 51.4694590722361, 39.59575814585532, 43.81694232263873, 41.30620179637786, 67.49947993986069, 79.71175593714561, 79.38872521923435, 95.19966602325441, 94.26566339308216, 100.26639553808398, 105.59066003368747, 83.86351416187902, 38.76212896839265, 3.1872503411385322, 0.5255829554892356, 0.21157152860635714, 0.12145125111865422, 0.14387010176095272, 0.2357218988359936, 0.08689179145280393, 0.10850623445284945, 0.14289274210891417, 0.23551226653639348, 0.23441757285787215, 0.11000968200424988, 0.19658292643725875, 0.16056337213564306, 0.0734145198798468, 0.0800864562211979, 0.14290786468453948, 0.11109333635578234, 0.1255130875975855, 0.11238180431387118, 0.2192559114266788, 0.16713135034566926, 0.2523045920796933, 0.13005772034727758, 0.14216215469904486, 0.13597634711092518, 0.09465495109437935, 0.138922062432093, 0.13714619401481845, 0.10101128985444385, 0.11597016015120092, 0.11551520351560847, 0.18454518770017933, 0.17236840400484302, 0.09395531363665097, 0.14955882553852376, 0.11697951163495741, 0.14875199705843004, 0.14809636369107232, 0.11255526960256601, 0.12752677268919446, 0.11202332879146261, 0.09239642430217036, 0.1336767809886125, 0.1939613275950955, 0.19346045931020092], [0.021033932214542743, 0.06884920275619916, 0.05932520534242353, 0.05558861149174552, 0.01314284929615115, 0.1158419936414688, 0.05568205506630963, 0.040775267257084774, 0.04343475680798293, 0.041038276732809124, 0.059583583816645615, 0.07938476564783244, 0.051271625599193, 0.07147418770698771, 0.0330509904081062, 0.0348554645484734, 0.058808839098820766, 0.006032843769888484, 0.04172429697768342, 0.019908681203941667, 0.031388018453013034, 0.04139353085549609, 0.0739416649805442, 0.062249232714454976, 0.014578310374711311, 0.04781500624132253, 0.0332652039134935, 0.03954798291106859, 0.0746358632140102, 0.07306228797402113, 0.03140517307685749, 0.11717955251374554, 0.06132820350748878, 0.021521930222309405, 0.010757397056647367, 0.04077339417210991, 0.045790086470304, 0.23308038170779907, 2.577673076621948, 20.069809152233987, 62.09442246344782, 84.58199039582284, 74.46538186842396, 75.64504254248835, 86.2544184346353, 70.70739038528936, 32.64101536043229, 31.585680092534712, 71.19476841342065, 76.83501120536559, 47.23063991915795, 40.44646140067808, 44.02491423391527, 75.84073743512555, 71.10788791410386, 46.92128650603756, 25.490897355541108, 10.4570928119844, 2.582171299765187, 0.3045852818796712, 0.05697992675366902, 0.14806481619035045, 0.09820420580405383, 0.06763519088347113, 0.08421181671081052, 0.07594165242006702, 0.08188068010513821, 0.13272574411765223, 0.046656964752342434, 0.4099993786263851, 0.8214871128720622, 0.2623690262196526, 0.5872002039705554, 1.1731374047456251, 3.7158872908161538, 5.281757770046111, 4.171199452492499, 0.5356001986130592, 0.7769712144809385, 1.3479723973620323, 2.702653028311268, 2.3541901524989837, 1.3146413213783696, 2.953005413855276, 1.145979649116916, 1.8869815646640717, 2.6305348594342512, 3.660040339154582, 2.367707865853464, 3.0949493713917273, 1.736488311040786, 6.6544848584359695, 13.099146446874066, 7.2132985630343045, 0.3627924278618828, 0.6851186206744564, 1.0428204555665295, 1.1407461041404356, 0.5914161390354556, 0.2633817638120344, 0.07486052615868469, 0.08524796595015834, 0.14357158794037758, 0.04323188906475421, 0.06737619953890962, 0.01731334577104257, 0.09174802280481785, 0.030232742541439594, 0.07752029150123559, 0.02200777360778903, 0.054998275628613855, 0.3516344798188056, 6.827626122582344, 32.870024904128044, 74.26257179629418, 80.54048215189289, 66.86011006755214, 68.72409882084017, 50.87435314732214, 34.06836194376792, 31.09561524083538, 27.74373615941694, 29.502772092819217, 40.410975717729144, 53.41147945773218, 59.5663058373236, 72.80939640537386, 71.11379500358336, 73.58851248218168, 68.90433957499843, 38.419129463934134, 2.869600134511148, 0.23935093394210263, 0.03843222181462953, 0.1253381590809553, 0.056918995950611374, 0.04820716281932208, 0.013954642025994198, 0.016268129881110885, 0.035095403286358046, 0.04519936756321019, 0.04975586318440976, 0.061456956074482975, 0.02595464901758298, 0.0334665471417529, 0.012369693253159285, 0.0191417180242077, 0.026094804803330093, 0.08631330313942126, 0.049564076903005766, 0.008987687986284014, 0.11869603122073798, 0.059806971224926175, 0.029981888965853763, 0.0331492641670329, 0.008168157768405734, 0.02399450964144161, 0.03176861093379557, 0.05419294101997249, 0.011833952645951462, 0.04794335661215648, 0.09062832401644799, 0.04377016159255178, 0.03122633559659364, 0.06967427945064922, 0.02724534629153148, 0.09008176624774934, 0.04416175126548737, 0.033831235637227376, 0.019531425036069368, 0.02208979672662193, 0.03421861182657942, 0.00906743199354218, 0.08353759805040975, 0.11190917402986558, 0.0266525206426459, 0.019610272720456123, 0.020885862740537813, 0.033828014237505775, 0.028018780999005805, 0.06308751676471964, 0.06550258596337612, 0.007638187239682603, 0.055077680641965526, 0.0077137110600878885, 0.08090278419155268, 0.03311963188612173, 0.030142505044838598, 0.01585195165863561, 0.05145670478081992, 0.0232355386739777, 0.019288787753471447, 0.024284552444794008, 0.06298158978742939, 0.044519621578435746, 0.08912656951936022, 0.04669644126308061, 0.07027892200576683, 0.04702000232834009, 0.05499018190969383, 0.0374483848891912, 0.034115676422633474, 0.04704785345482731, 0.011011855075916937, 0.034554748225115964, 0.1054313873511649, 0.03159758180469996, 0.03084104508161545, 0.08739359436496612, 0.021054961328064243, 0.01089645925188257, 0.04845653209955462, 0.041511470091439066, 0.04609665953584256, 2.6824390936282376, 24.308192922223, 70.97852030108052, 94.96209590665757, 86.29799596724972, 84.1385664478425, 95.29733304054507, 80.02917766571045, 43.48479209407684, 47.24144212661251, 69.30282885028471, 81.62813971119543, 40.05383606879942, 36.36981264237435, 45.94710311582012, 70.90083383744764, 72.6146899500201, 49.389583064663796, 30.13088280154813, 12.020566232742803, 2.937693706443233, 0.14887605733688802, 0.08241026902631407, 0.0673732424395219, 0.08608638789624938, 0.04270532619087927, 0.13390165843790577, 0.030651005480678815, 0.14249572470303506, 0.21471055855433788, 0.056704184896643126, 0.185823206218981, 1.5492571577910454, 0.580138405484538, 0.6469588005735029, 0.9401654091573531, 1.2819933506750292, 7.960114411769375, 4.3214247592033885, 2.1779911556551537, 3.904971028527906, 3.417154920677985, 5.798637905428487, 6.534063191183153, 5.442558767334108, 4.903734441726439, 5.998970020201899, 6.3132435564071905, 5.895776383338436, 12.251320250572698, 7.917557185696018, 3.0320803965291674, 5.1149187741741065, 3.178190891781161, 3.0448195194044425, 1.5530402838222443, 0.6067554868998066, 0.515641340565297, 3.0438592741566324, 2.0708530852871556, 0.7371870428323747, 0.24324692004630644, 0.19930413203133693, 0.05891393870115281, 0.17032607488574522, 0.06047090515494347, 0.06800404689725369, 0.006759188010267193, 0.03382138757696075, 0.045803018034465855, 0.056616831721077045, 0.048973461417781736, 0.024175668368116025, 0.5816000399570311, 8.165621113392616, 29.339603454835956, 54.28104931308378, 58.59876694217805, 50.8454688133732, 53.856762609174176, 44.50751873754686, 35.48512205000847, 33.22466404207292, 40.77458335507301, 42.61680687627485, 52.29728706421391, 64.16775987994286, 69.32813598263648, 81.58239703024589, 82.27522880800309, 85.77339464618315, 82.1138075859316, 49.606497979933216, 5.435651473460659, 0.3202078677713871, 0.03639807834500267, 0.11522299459865017, 0.022573514218111674, 0.005179035905448179, 0.05004178634994934, 0.040853887030314055, 0.10132891756872978, 0.03222944537898706, 0.07011869471640357, 0.010057929095872229, 0.06742276236294739, 0.024247318656454166, 0.06527925601168987, 0.05839263119043843, 0.1144712784838292, 0.032205991597185214, 0.09274025222346668, 0.03800858285338168, 0.09743838601054684, 0.02929810378249855, 0.04413350560371915, 0.05029632289323115, 0.04844951473416821, 0.05001236857365697, 0.049962197475495844, 0.054251090923865, 0.05648738201407175, 0.013186257753160693, 0.029155149860608003, 0.08716563724221722, 0.023921587647149162, 0.03757771202212861, 0.08098216622226662, 0.025161518189575405, 0.034345824556845816, 0.01539736944851616, 0.03935564887679873, 0.011146953723753893, 0.03425557556892595, 0.010855242763946374, 0.017804984611669378, 0.09853618234516152, 0.025802605462470846, 0.08965730757242249, 0.09397501741806347, 0.19295150113682594, 0.13954910539811657, 0.07761337118403566, 0.22918739866825844, 0.19907946908666244, 0.11531022903058799, 0.17793375698308792, 0.15037377455061482, 0.11359764713673823, 0.14630603153378735, 0.11068223825385494, 0.22259216304988633, 0.11457258595093606, 0.15228030692425468, 0.239214800117958, 0.14265605158382846, 0.1655475401710118, 0.2027667268750168, 0.12463888168455133, 0.14304709350389821, 0.15854646181387289, 0.18970471326141589, 0.08833808884505304, 0.10490688525380627, 0.1565065535326158, 0.18811619930690338, 0.19789794700280314, 0.25375177813393457, 0.16963857226073745, 0.22282353692477752, 0.20760659458896807, 0.12073544920572352, 0.16511074748010407, 0.1735789914645495, 0.11093387515434336, 0.24340312537406725, 5.918580062927739, 34.370255008820564, 86.2298487078759, 108.15796113783314, 94.59073374348303, 93.2244388518795, 103.5931851786952, 90.3417948753603, 48.11101198196412, 48.70893024629163, 82.83088745609408, 87.6868131083827, 60.78449595359064, 57.237014155234064, 55.49235959206858, 89.99074274493803, 88.98543926977342, 63.87310358785815, 36.366482550098056, 16.5822180240385, 4.330118692690327, 0.7642656156132299, 0.18606743504924161, 0.48581386045102154, 0.18758612775033523, 0.25099504138192824, 0.2949543922178207, 0.31980015577808507, 0.32602860382007015, 0.64213655288181, 0.10087145582562494, 1.2579206617609149, 1.8100609438073252, 1.9389174229675725, 0.980718304072657, 2.3307669835705913, 15.650163831249362, 31.376037251564767, 14.552792522215075, 2.287275007655544, 4.851462485328798, 6.266543817135596, 8.409506736263152, 6.944498044829215, 6.04631498936684, 8.441803532262004, 7.3185141817215955, 7.023349452403284, 11.525730798321387, 14.726442713891307, 8.437041774872812, 11.228139592755227, 7.518135366901276, 14.324775338172914, 30.124244190031487, 11.3634584219225, 2.091800993488681, 1.5762824108523708, 4.8059433794790705, 3.1657155482999744, 0.9268590134959068, 0.8583920196660104, 0.7724671690694748, 0.42262285286861084, 0.436254161740503, 0.4382040087253817, 0.11698097486289279, 0.16695881202336282, 0.27948287886477285, 0.12401078151719225, 0.1788419695390809, 0.17851360893297583, 0.16034204933431842, 0.8127420047117818, 11.639729584417037, 47.76688675726614, 98.233030996015, 104.92613207909369, 86.77793718153431, 88.23577234821936, 71.04796194261121, 52.47468409999725, 44.55756033620527, 42.408583933307284, 43.50237607955933, 58.63203648597964, 72.64403712364935, 78.40209222608998, 94.23328030493953, 90.67732226464057, 96.85292151666458, 92.70372852202385, 61.37922140859789, 9.775152475603166, 0.4698209476567084, 0.12022909573129109, 0.20910777452011264, 0.09598535470544331, 0.09018430711641427, 0.18904226171153207, 0.10459630554842372, 0.2013700106932271, 0.171487923831709, 0.20395181892860323, 0.095002165124301, 0.23462873733332082, 0.09348212410846064, 0.25063888710593024, 0.12449657319173699, 0.17843614212207257, 0.13053082560579624, 0.14984912689655058, 0.10309861897821389, 0.3373645906967502, 0.19329999453358113, 0.16223528242159277, 0.113462409635465, 0.09353039530856956, 0.07860879518932874, 0.13807198062779444, 0.12590114943562977, 0.13798463128266797, 0.1976066803739917, 0.16249127836237032, 0.09751048254510088, 0.15658630328553338, 0.19944461723489149, 0.16574733590166416, 0.15057645077186246, 0.17248673394562739, 0.0945078085867628, 0.12948870088063902, 0.132154242526139, 0.22805715851005048, 0.07883570277162137, 0.1735941140401748, 0.22408919078448128, 0.13239312406268813], [0.04818390055950131, 0.03996850389446463, 0.018925353726972977, 0.04846087964852491, 0.014555923370344025, 0.061705107274915905, 0.03925571270707635, 0.041038632963693915, 0.06658779547339486, 0.017015117318219235, 0.06892335240639026, 0.07617825101460181, 0.03783725111955597, 0.07661193338853699, 0.039773132321575, 0.05427189404144884, 0.004259615961927921, 0.04633536104172949, 0.039458373606565504, 0.029079188412475972, 0.05994442272030058, 0.03309653433520467, 0.04458181259612884, 0.05427175997606209, 0.05061775040362151, 0.07521124887129954, 0.07935475798383837, 0.06631672292226745, 0.09819391724323073, 0.03736048396075926, 0.050838433521529364, 0.05018264693658679, 0.08612559627621405, 0.03588708620818873, 0.04778036757582619, 0.020209761419063135, 0.6022259460822229, 16.004445052916004, 50.09841419035389, 74.20925894091206, 83.53827122719058, 68.58861231034803, 77.71355936604162, 55.36364309249386, 58.07708778688985, 49.999825416072724, 39.363502840841974, 23.36218587813839, 37.45640331699003, 49.34149088398103, 38.69757460009667, 47.69431506433795, 63.570139715748454, 57.800093927691066, 24.483722909804314, 12.531315703545848, 2.348490458342337, 0.5794862501563565, 0.08087738071598354, 0.04634548106320924, 0.04499965227178989, 0.02370998267114403, 0.03250039535604658, 0.11957495623538572, 0.03290377129169722, 0.1737616881127319, 0.1668969734061149, 0.23423568826288949, 0.36406205005703435, 0.1706644559218999, 0.3485656541682059, 0.38682754782419054, 2.1749135659587, 3.484120075741122, 3.3232854931585254, 4.837289491007406, 8.027163897791217, 6.077571376677483, 5.897199223118444, 1.740401365583943, 4.2871000978254505, 8.668778346430871, 7.475031460485152, 5.187783664272678, 5.493165677593601, 7.633578075516609, 5.565890833254784, 10.724972063495267, 5.844362935712261, 4.222196638584137, 8.779519604098413, 2.519641855070668, 7.591475354086969, 7.400921708153141, 1.0009323000427217, 0.3426577679572567, 0.6204253146725317, 0.7079428314201294, 1.0820307967162903, 1.1046936387015929, 0.2813807544448684, 0.033864843914465564, 0.15225904032347665, 0.015815584507260113, 0.19388641951785934, 0.07986982187796986, 0.08533093327235791, 0.13729011129227378, 0.04132683907124785, 0.06101619887856707, 0.01793847543247525, 0.14850073554102453, 0.22161601381676815, 1.4999142313195815, 9.351114842199511, 32.224555746201546, 56.16851345185311, 75.39371275132703, 86.28192993902391, 79.1278640685543, 59.15299000278596, 43.143891057660504, 23.725222810622185, 27.99842546063085, 21.525645871316236, 32.15449240899856, 51.22433839305755, 59.612523125063994, 63.679479706671934, 78.67963913948306, 89.78057430636498, 72.47856801556003, 31.41062863411442, 2.162448028402944, 0.298648652049803, 0.029895956883387222, 0.07420555162694185, 0.057955865312608025, 0.01417648768232715, 0.03752085680682813, 0.0655092049630419, 0.058665266560931364, 0.04290799475124767, 0.020085373638017524, 0.04911447905244366, 0.04598331299700564, 0.06523041024563775, 0.03845192176560241, 0.05284110992966641, 0.01685520220968512, 0.04978154245163164, 0.015769548368670287, 0.035606575453834194, 0.05262721435076768, 0.006828017658629125, 0.017671447825588046, 0.02711688675316832, 0.10238613422599532, 0.004563772977675282, 0.06433975642486926, 0.009769854180875325, 0.05632766800361776, 0.044771511287939166, 0.020749818931724277, 0.05732615253016834, 0.029827920614831874, 0.038434604348074046, 0.03142030331336203, 0.04725791859410463, 0.016962033170726032, 0.08212583590178721, 0.01173113790085359, 0.07767805198748266, 0.061922243405734344, 0.00667376202463563, 0.005643972272669236, 0.05278711605276312, 0.07310751014419141, 0.04452121504131825, 0.07434825848547683, 0.05444801382480129, 0.022817802420186422, 0.01467464593118958, 0.06372655666763745, 0.03699227912171233, 0.027189697664711746, 0.09841510980960824, 0.055296494505338134, 0.03683328140346754, 0.022284268146200527, 0.060608153637017936, 0.05837185488593194, 0.02847633658788137, 0.04717283686923404, 0.04923586185360628, 0.013248698707039078, 0.01805221650659317, 0.013520882085656688, 0.07852261795872643, 0.02618597309675909, 0.03553193167693192, 0.03604914827813064, 0.11768679465017012, 0.036045574477963874, 0.05279714414369195, 0.016075916505689104, 0.035841427367901614, 0.07432628708380846, 0.04989684251467547, 0.05588263603708437, 0.022836272800040823, 0.022209549675725644, 0.7977733821157487, 17.677088822087935, 60.383370845548576, 87.47213394411149, 94.4889953059535, 77.52806263585245, 84.11510282947172, 64.7655761626459, 71.41937117422782, 63.59722368178829, 39.229863766700994, 23.06299532613447, 54.60326417799919, 64.02729195933189, 41.93874674458658, 43.94934192780526, 43.80578317949849, 53.752141229568, 29.146352198816118, 14.477093719667005, 2.0970912902585925, 0.2841737577992101, 0.043539105644149166, 0.05343433394427261, 0.056335895787924535, 0.09237467506600004, 0.09636255341672129, 0.2472560573369265, 0.1331047891008277, 0.261299567477357, 0.44797107817665227, 1.1760159341558334, 1.6777893059676694, 0.5169386032127565, 1.209577081664916, 0.6041962016494044, 2.773246866080069, 1.2131810044088673, 0.8918901641042003, 0.26103496070831056, 1.0738334107783534, 1.2003626986857385, 0.8297161229195134, 0.5829504997499528, 5.030119582529991, 11.24227777604134, 11.233569133666254, 8.554941358104829, 8.306068931856464, 7.438093029683636, 6.529440187638806, 8.98950957482861, 7.301921085003884, 1.0050467437794133, 1.5048830163094307, 0.3225806872210195, 0.9432709457412843, 0.5438887796575024, 0.7599021013705962, 0.7911499697835215, 0.4512150928137764, 0.4390098719346908, 1.8363467075171012, 2.3924281135682137, 1.1687738905029914, 0.09107791037569124, 0.1775713667513863, 0.08764465669951133, 0.39407195102783943, 0.08550114268737455, 0.2555194187669024, 0.6165967749491815, 0.15154129254721826, 0.10531788376430351, 0.04509634022871333, 0.08256170162630659, 0.2392338757072726, 1.6178905459180957, 11.084285686092993, 32.748229426722375, 48.6140481118233, 72.89549243065619, 92.96516233874907, 74.21242037127095, 46.39852869895197, 41.67681870921966, 36.53565045325987, 48.70236812099334, 42.39208644436252, 45.57812183134018, 61.78542206364294, 68.19416307633924, 71.59099840348767, 88.84363774330386, 102.21541343196746, 87.03329132449242, 43.141784744877974, 3.066547488973987, 0.34544396845083086, 0.06656557892359073, 0.058967174151011055, 0.03091952504379855, 0.04645069174829029, 0.040667294825036684, 0.06418315273138785, 0.08887910013717991, 0.05438664252118719, 0.10131788590262014, 0.024761894169533928, 0.01415029705141581, 0.005656275644733181, 0.05585372387882202, 0.017023168902303425, 0.014481592731880806, 0.065726819898813, 0.03395679744801695, 0.03058827820143873, 0.018560180680886395, 0.011565035674721004, 0.012296259895177379, 0.07812260514906338, 0.024743075219673977, 0.03498014918858967, 0.045847045107474255, 0.027630851311128468, 0.03699764556762192, 0.028149887371147354, 0.009465142708992767, 0.03834310280639799, 0.055587661542719415, 0.024237099043544263, 0.04978934888758006, 0.02043895960424937, 0.046025210345584544, 0.04032194238877104, 0.0810420130109114, 0.015338422813182397, 0.050265112471195965, 0.04491910961787066, 0.035942635243578304, 0.13301960012364772, 0.16867772946434637, 0.09899889179054769, 0.19748666503977394, 0.18137836408230568, 0.13059393592899846, 0.13624415612749516, 0.1562936117331828, 0.14366017834794137, 0.14823634327659685, 0.1332205449861865, 0.18348092303401042, 0.11428547151867421, 0.16865920545833726, 0.18559155655243706, 0.1955710621851106, 0.1683185721236852, 0.08485926825913691, 0.09699331957005686, 0.13859633716844744, 0.1458049947095494, 0.09217508617908725, 0.1526975643730933, 0.16597147790655015, 0.15770825437240063, 0.12335146326691875, 0.1582667477909596, 0.10979467942830055, 0.13699057091388012, 0.12330200463052719, 0.12652328943893795, 0.1994766550318849, 0.16387608953781668, 0.19817877951408588, 0.12665940028044487, 0.10147995946388091, 2.005868114290699, 27.20890529694096, 74.43936870944115, 104.05761734131845, 103.26784026238226, 87.51036136381089, 95.44668120722618, 75.77775985963883, 78.38554766870315, 71.66640989242062, 55.67019593331122, 35.85323649068033, 49.124191576434725, 62.65849851792859, 53.575430608564815, 64.69505586931783, 80.93047557338592, 78.16666372360723, 36.41339017498878, 19.31103644832488, 3.9702696665640804, 0.8065719325696269, 0.1955425177490519, 0.20635529721696533, 0.17024275516310047, 0.15172901473218395, 0.24666282949188065, 0.4821754637504778, 0.3120913500747373, 0.6015048428408561, 0.34894741110263333, 0.7345160313190953, 1.5509333581693712, 1.2060408198064374, 0.7013394599480014, 1.472202318329965, 4.439796988041171, 9.045373932007822, 14.687495539265296, 15.11476226391331, 18.886488906798824, 12.81568067689096, 14.875214292157082, 9.134410754326852, 15.587376490716013, 21.524998680237804, 19.285072318969235, 19.490779061471265, 20.148103583243586, 21.820663021456813, 21.101013998831473, 22.06116314857237, 17.562790955266646, 14.403833650773572, 16.75686743951613, 7.739688975195731, 18.278366596468036, 18.907648132693385, 2.581789113821522, 1.1957339341602018, 0.9660545844704875, 1.4401026214322736, 3.337316546709307, 2.120504653261554, 1.1765725429980987, 0.17143707091529525, 0.2743089661723183, 0.14602576592756858, 0.31466834727794896, 0.10008708138259188, 0.46489834244693484, 0.6772960662361115, 0.3288851924721272, 0.2507016603504458, 0.1474113431909392, 0.43337915633474633, 0.7944854553188048, 2.7365530931180526, 15.785447359085085, 46.69461665614959, 74.55154065162905, 94.4285515815981, 99.72508492008333, 95.25905855240362, 79.65303021092569, 59.81632555684736, 40.160720655995036, 43.63531697180964, 37.65261204011979, 50.98816464024206, 69.46861174798781, 80.45859875217562, 85.47097990589758, 97.39518919298726, 111.92196169207173, 102.65294597994898, 53.88160297947546, 5.395911980059839, 0.7662999161308812, 0.1872911992212457, 0.22766027899999774, 0.1864943911712016, 0.16418203441125734, 0.10273642792937257, 0.2063585147862473, 0.278770447738709, 0.17071503304666089, 0.2447027628940921, 0.2154793737516288, 0.16653937888481926, 0.13189245496065388, 0.17216084014263847, 0.15578609380510547, 0.06761619956382821, 0.18847535664756454, 0.11101303501955925, 0.11441385253302513, 0.2406499126265126, 0.07860691061303501, 0.13249076962951692, 0.09900715787925067, 0.13553287413331772, 0.1171660157401235, 0.11520080869236302, 0.1255787183500586, 0.11335579317904289, 0.07151356462629573, 0.08076716364631731, 0.1641585308337404, 0.17939041188407331, 0.2051161193559247, 0.11426020593893145, 0.10958119370644132, 0.19719671608219225, 0.15371394854399467, 0.15909904103365638, 0.1608782802377978, 0.15106467860600642, 0.16779312773817973, 0.12179841152242116], [0.07669245689025811, 0.021644211261563247, 0.04516005576137574, 0.045932000427837336, 0.0341507057929712, 0.03682123467085823, 0.07326570730055533, 0.03972345535012503, 0.07475076874177303, 0.08263998049040956, 0.0245885361331485, 0.01703451849490164, 0.019762155397104162, 0.07341605971657461, 0.012128791159709856, 0.021494094417580677, 0.025414495743931304, 0.021710552560586124, 0.02631360717538384, 0.01814303623001662, 0.023645669589900685, 0.06037835024237152, 0.06444745306526461, 0.014651460280161233, 0.0326434699367852, 0.05933760447547801, 0.029658082752458514, 0.03964780033716271, 0.04642203239904297, 0.04417149207344459, 0.03325741662974319, 0.02487880493243856, 0.025280060719758756, 0.05301386275659165, 0.0736296603516225, 2.1665518081957296, 41.20253747509372, 72.9978584474133, 77.80118511569115, 72.79630353373867, 72.6087514815792, 70.79217633893414, 56.0403617735832, 42.036115661744155, 23.73827841974074, 22.501000089030114, 42.668539016477524, 48.5802137467169, 16.635968223694835, 28.560936489412864, 39.644685791384795, 62.77333767183366, 57.48019326117731, 16.90588612710276, 3.580230892665925, 0.03101478616196302, 0.028376239539694884, 0.07865897394836911, 0.011333368771198777, 0.04317540157165739, 0.08193905600496838, 0.1897956325762695, 0.06548264469470709, 0.05403103982849468, 0.1470200714444922, 0.050325932191504594, 0.386037037016884, 0.6091339141130447, 2.9937056428001774, 0.7073973768180417, 0.9248389315701301, 0.4092354970353265, 0.984008192054687, 0.41224220827702557, 0.07081008140718745, 0.6134995121148326, 1.7652334008486041, 1.5418990364959164, 2.255363339377988, 2.7384152383573594, 5.687852521096507, 6.3690284855904125, 7.023971148075597, 4.27097229226943, 6.672930784763829, 6.591443544433964, 2.0845485310400687, 9.562183464727095, 10.771313886488638, 0.9084390728704391, 1.6459262995950639, 0.5199479191533981, 0.25322953599595255, 0.8722536145679413, 0.3370596877028865, 0.18808695006995432, 0.348156655147191, 0.5885355258660933, 0.705432698370949, 0.2379812300205231, 0.1375661787366675, 0.019592026421319575, 0.04148803163139571, 0.13770445760700012, 0.027860241018295772, 0.24654626155332213, 0.05725222121503565, 0.10973893121005067, 0.016562131443812002, 0.16317329579784026, 0.041571948902621385, 0.03813466943439938, 0.03214455134565792, 0.029213138886036414, 0.11635950135607874, 1.765108007577158, 13.835110568231153, 31.297044638664495, 51.311246348965554, 38.55894234872634, 31.459697484970096, 34.17933364068308, 28.661482526410012, 32.77206567025954, 14.522286288199888, 21.229663818113266, 22.60998118308283, 37.580867967297955, 55.22919601009738, 67.3380587177892, 68.3814327178463, 75.24261520754906, 83.80856960050522, 50.44067236684984, 14.906204938888552, 0.3128192561768717, 0.03854181069219786, 0.043044086440556475, 0.05887011847188396, 0.07694936447566555, 0.03848499761173322, 0.04026317578409949, 0.03143939422443509, 0.04218735882351476, 0.0437202318120868, 0.06745439413334094, 0.03857819986860118, 0.051208342906207814, 0.01945603815388055, 0.022020211045239723, 0.03252234760551684, 0.04512829375603507, 0.06775912858786122, 0.05746962547662759, 0.10568380566133607, 0.051170256845052206, 0.05866367309804886, 0.06808496110381619, 0.03564044803140625, 0.026393330115224087, 0.020899901301750255, 0.013214870179522664, 0.04183424591657616, 0.05269391762633478, 0.0510796592871268, 0.10220250295054528, 0.0223935256907416, 0.05876147571290213, 0.021068750910701293, 0.02392713029328133, 0.04454633889479503, 0.06459903888284199, 0.06940817881015039, 0.06992862064151034, 0.04930602018571189, 0.03449466011877503, 0.02818596053628191, 0.054181296483523426, 0.06821544885995888, 0.026082491855167096, 0.010484004216719299, 0.009628128872493343, 0.11154018778113589, 0.01608868527616705, 0.06445747349531421, 0.06292190387724869, 0.020619631865091866, 0.02117660459912112, 0.04605724431213833, 0.06124885595073143, 0.008597413111748475, 0.0710324997142438, 0.014131419687351633, 0.014135296092248492, 0.030588848936942317, 0.018057312906509446, 0.03899356891070643, 0.03281321969904727, 0.03220771912545447, 0.02103228129506592, 0.03776173400242002, 0.06926912619101425, 0.053697596229011976, 0.053856877399788755, 0.021421681871757876, 0.005262719041052005, 0.07219306163249478, 0.05129533602044948, 0.1169129309334582, 0.08294995498633193, 0.08584883169180925, 3.447917824791324, 49.61848474317982, 84.5800841239191, 89.20876333790441, 82.32666677044284, 81.83848073405605, 79.58263935581331, 67.34020817664363, 53.60022391042402, 39.91238363327519, 40.02109996734127, 49.59198128792548, 41.251523956175774, 24.57217235719004, 38.71646865721672, 40.78118470407302, 58.9978131940288, 49.648573244771654, 20.408729391713297, 3.4263462597324006, 0.008435679502004098, 0.05244417296301934, 0.055326731995709484, 0.042262010261296265, 0.10599108352776497, 0.05796459105406558, 0.20708384683295605, 0.21375737663718963, 0.06563369425073748, 0.6964178046872539, 0.8312166133715261, 1.378403493473607, 1.572767599455772, 4.378618309574743, 4.379898473139733, 1.8810249552611384, 0.27095978298494894, 1.6789940864809099, 0.23966237932683962, 0.12681138446374288, 0.6341943048661756, 0.5554958084417928, 0.9686898656429784, 0.7413337848359539, 0.25179549601049195, 3.2518534939135275, 8.644151745303985, 5.913302513860888, 8.482387315842415, 5.467867370574705, 5.706641164518172, 4.501590007735837, 5.113872481930641, 4.514370560646057, 0.5607253084740331, 0.3021538720255898, 0.19602829410183817, 0.4834107652066216, 0.12541163457377305, 0.4622827650558564, 0.5097946188142223, 0.9162835067799016, 2.116360914322638, 0.9176519849608022, 0.9372027326495418, 1.0693458515790202, 1.1100359068762873, 0.326553680483372, 1.446735594541796, 0.6437238870609192, 0.9890877840019042, 0.35298929099113713, 0.6086730356177976, 0.26238159006161077, 0.09112022907262848, 0.1356353154105525, 0.007275779771002671, 0.025472998048268983, 0.06585599764460517, 0.009464205208895429, 2.35416024442642, 17.419263585921257, 37.81673969761018, 54.49805052049699, 43.48552557729906, 36.385796300826534, 37.68248873372232, 23.189413316788215, 24.300624708975516, 16.41243725053726, 33.384888941241854, 38.499357623438684, 47.86186695098878, 61.85180033406904, 77.44683819432413, 78.74022406916465, 85.18956553551459, 96.68787602455386, 64.98211453037878, 21.47250952259187, 0.38840090855956083, 0.02601998291098543, 0.04425304213298425, 0.09117524184647108, 0.0072490107437085, 0.07321164447573886, 0.016915765290539113, 0.03249146660128909, 0.02895290839425739, 0.026151319109504263, 0.034815003614752524, 0.04236166680892629, 0.08622454419251412, 0.015162703310770374, 0.04085575245440968, 0.046262226458038055, 0.028984823617182916, 0.05589475171760686, 0.039490262016413674, 0.03531599447371499, 0.0767363230848024, 0.05039761886901913, 0.027205373738862337, 0.033591871465285944, 0.04849502035687047, 0.015667988092548425, 0.027967163909887596, 0.018844719142502835, 0.020069358569960442, 0.12702339163590826, 0.10010498485738233, 0.07796622362108001, 0.049329581219823136, 0.03052548005906565, 0.019635511487121546, 0.018099913140758872, 0.03668883169490484, 0.09622316371889846, 0.05211323064060942, 0.09786351118236782, 0.04267569774040773, 0.13497693944842587, 0.1260834170745746, 0.14652579151574643, 0.19394467284362163, 0.10378429065308264, 0.0910762403040163, 0.18186430897443526, 0.1360362858301209, 0.12500783728976406, 0.12699654791504145, 0.118359818213409, 0.14444998435435757, 0.1683847008333091, 0.15593560352440805, 0.18811768551747646, 0.16524934810736489, 0.14453371776448143, 0.11827779317935629, 0.11004743481715841, 0.21685580392518353, 0.14363302819190488, 0.11689731806156137, 0.19635665470794325, 0.10935619368308014, 0.1105381371152978, 0.15988556818375665, 0.10421448732696234, 0.11416894954539115, 0.11677406217542388, 0.20109711485283993, 0.17001872041052388, 0.23776240466583162, 0.26909092681542524, 0.16291506288032379, 0.12731758472059043, 8.088655385278887, 62.265245606822354, 97.9251955401513, 99.41535888179656, 91.29253033668765, 90.93862272077992, 91.31392294360747, 75.40277342642509, 60.36906988390031, 39.00770856488136, 36.09559189888739, 59.75132403835174, 73.1394717001146, 31.030821607958888, 46.2987083004367, 55.92018427387361, 81.91407265201693, 72.9972622471471, 26.861836333428663, 5.32741415885187, 0.23997633747996824, 0.28209146953398184, 0.24291610795884366, 0.22839417590969996, 0.19484053606227522, 0.2756693851082556, 0.6403097089740538, 0.3150550378186088, 0.17816488570984335, 0.6872727986304992, 0.7053192560711216, 1.1019590112470812, 2.146247658998736, 7.448620180929861, 5.307447333489695, 3.767795202232177, 0.5869097647167022, 2.3341029594021463, 1.804846397811367, 0.5723347274526474, 1.1899796945433463, 5.772420292900455, 5.38184194795547, 7.650625186581766, 9.184032659376822, 17.891381632897165, 19.537663152140958, 23.386900732594153, 18.849583325847505, 25.092347283517164, 18.421601749235585, 12.879689835732984, 22.298233162972238, 31.10734508883569, 10.602027331629108, 7.98013516972142, 3.583070443522546, 1.7470098238798881, 2.2763257113195237, 0.8122536696253285, 0.8197053149342538, 2.2048081553751424, 4.123537751936143, 2.9944386357261292, 1.0665099779444358, 0.5116254770227018, 0.6489389846401831, 0.3848506426138263, 0.6510836631059647, 0.25753038424638014, 0.6067345267341984, 0.19898643536913782, 0.7148738433757137, 0.27673011044821433, 0.4248302586136326, 0.19568249733457643, 0.12789538355484126, 0.07878436721981534, 0.1724154877686693, 0.2024259862880553, 3.220525278199104, 20.951442257050548, 46.58404896336217, 67.52690515210553, 52.59880358173002, 47.94547227121169, 49.949670068679325, 45.492316061450595, 45.33789627013668, 25.396291748169933, 35.703190142108554, 38.65253402340797, 55.184296638734885, 76.05488315705331, 89.95589640832718, 87.91493031286424, 93.29600641804358, 108.33691535457488, 80.08019985691195, 29.042113250301732, 1.0539585159670923, 0.11677898045989776, 0.17177468586352565, 0.20179646119715708, 0.1365069855725573, 0.14731472418192895, 0.13850862010111734, 0.29096629170160143, 0.16837972126180129, 0.10367494692365009, 0.1812997634612745, 0.31657155482999744, 0.1764402992182201, 0.25760095626596485, 0.13577644412796344, 0.20480527151976863, 0.14058792062344092, 0.22863212281898146, 0.14647115412498676, 0.17261997195741824, 0.10445937499283783, 0.22968782262215692, 0.20711896430340507, 0.11643603353971436, 0.14902299300076502, 0.1428674918509299, 0.09203011170029642, 0.14485404976914007, 0.1254365247704329, 0.28884965205384844, 0.32234494664495994, 0.12751777115608418, 0.16954538532562796, 0.09772298767441705, 0.16646027264575805, 0.1029358635987005, 0.1382392789086988, 0.13634629096956025, 0.2366681093530309, 0.19020817092349454, 0.15606539414053963], [0.07753772766239221, 0.021967749344184998, 0.019036714182866198, 0.03201649974911444, 0.012252733652149479, 0.05373089424064083, 0.0776557052027314, 0.027180426085608143, 0.053544872770867044, 0.01957854518907205, 0.038383896988365925, 0.05731995870930053, 0.07182759172733753, 0.1000892494114176, 0.004609319777603472, 0.06475427127893894, 0.05235009353547808, 0.03593341537540959, 0.0022285009336267267, 0.06296506527090265, 0.01639873638088184, 0.018681458144959424, 0.07811748002084994, 0.03226884911137243, 0.03188853050702282, 0.18262675032019618, 0.049827653283794085, 0.02580491330234274, 0.05637605411691531, 0.011753169631945991, 0.05457503886352624, 0.09347765781586209, 0.08160120356948146, 0.058887026032372836, 5.428155824061363, 55.50288331124091, 84.85580321281188, 72.68721457450621, 71.4163823281565, 75.35891348315825, 74.55551793498378, 57.38720955387239, 33.495907706599084, 21.43158547339901, 22.21589869068515, 24.442186970864576, 40.78109448955905, 41.854839401860396, 61.65048076260475, 56.62277098624938, 54.95166870855517, 34.1728852641198, 6.18799590295361, 0.18121152545415586, 0.024242764263744318, 0.0617831907865982, 0.020945592700774153, 0.135867960991398, 0.03724257536833325, 0.08315106838821404, 0.038175789203735135, 0.10939518755842602, 0.25324809064547865, 0.22610185697915094, 0.2279617499199606, 0.6054932191487282, 1.629554203921749, 3.975369728380634, 4.381752773638695, 2.439691448403943, 1.3689026548977823, 0.10031105484813453, 0.5124781941694598, 0.4519715893172449, 0.03965012924445253, 0.2750635934212516, 0.3880696827846189, 0.170787857364743, 0.19749624113882744, 0.0207012853465013, 0.8201866020118037, 9.149883524064096, 8.23007595154547, 5.400449672052938, 5.77929767870134, 3.6065115082648496, 4.4569539254711525, 7.31230850181272, 5.871730783293325, 1.3551688434616214, 0.5751514795326418, 0.1387417253347174, 0.10636606824494178, 0.07594277090843647, 1.2199300551606764, 3.5403045963856483, 0.5397528854589309, 0.913459277681766, 0.30602589489952214, 2.4157046839114162, 3.453015925422792, 0.43019704160190403, 0.131547883934071, 0.47790663797528515, 1.485898867249489, 1.280460316807993, 0.5566005072286052, 1.3071022807590424, 0.29415220623054816, 0.05104029768957727, 0.1330715868501894, 0.042450582803857904, 0.1397643761048394, 0.01098307315260172, 0.06683980775696617, 0.05254717348443885, 0.19367180764675143, 2.2894923725435814, 22.360377234797326, 52.28012277233986, 48.17626060978059, 48.616342698374105, 74.23674691107966, 177.79948665249734, 102.92042024673955, 20.670469153311945, 17.608466955923266, 22.990172601515248, 38.81315508196431, 67.7002425347605, 66.37859206045827, 70.14060789538969, 74.5236369102232, 81.09638398693454, 81.49121761322021, 26.883442709522864, 1.4993533323849402, 0.15777021556371645, 0.10648038388500292, 0.014005803292797459, 0.013735147301978884, 0.0283217630273993, 0.03072820799124818, 0.02417172493052579, 0.061328969595413056, 0.017698921653772556, 0.03557184102734731, 0.021974789692209135, 0.05434078066760013, 0.007521343030666392, 0.018301551312869115, 0.08084474537040919, 0.08134509271551525, 0.044940820549644774, 0.02178672085245771, 0.012225858330155813, 0.007608841762938087, 0.04577883263869632, 0.06435020586415645, 0.011969328043051066, 0.04401873031090345, 0.01902344745523747, 0.06655228729810446, 0.03697652069310989, 0.07779543197924092, 0.05911253933464328, 0.02377316385747925, 0.04823450832777927, 0.005103775906571818, 0.018095215106563225, 0.05326624659280624, 0.09545525250535819, 0.0689743662012681, 0.028482494019572775, 0.018379238374050588, 0.10442421921799261, 0.031186776731403607, 0.013628009905768259, 0.025913760989844322, 0.017596453563460422, 0.03238640147291365, 0.02293707656433746, 0.09728362858896294, 0.045251089989417986, 0.03714502939293462, 0.04505482592409657, 0.0755313357278224, 0.037143026073012626, 0.04979016477121942, 0.04917365551415471, 0.05204678017405733, 0.0967124640761364, 0.026402628507405042, 0.014087185770603678, 0.052001711221471916, 0.08489925804878436, 0.02238473100137086, 0.050422168156552705, 0.0293726364766518, 0.0482690895366813, 0.04286951798525068, 0.05647355029659887, 0.057460294525709846, 0.0750190450719768, 0.034299265563247666, 0.1935841059011798, 0.01862883748066041, 0.11830353373361212, 0.10044618509709836, 0.007453182272823348, 6.727077634103837, 66.10374373774376, 97.55366079268917, 85.56423817911457, 82.23420081600067, 85.36349911843577, 83.05428212688815, 71.0430040667134, 42.41859382198703, 36.262014142928585, 36.22333565065938, 30.383312817542787, 47.79295090706118, 44.921352324947236, 47.01505860974712, 51.87429866483135, 56.666583861074145, 33.73332092838903, 8.015356092683732, 0.130906407871554, 0.033281119390120434, 0.12212417509046294, 0.06996679480277723, 0.18099000346997093, 0.030109452181345517, 0.0810894568360621, 0.11941463701547154, 0.6111521574278033, 1.3692450042693847, 1.0977769066249172, 2.100845733957906, 2.5517766081517745, 6.193202359061088, 8.35853063291119, 5.367572365268584, 3.2519684683892036, 2.338951008935129, 0.45515342825843447, 0.4057476212901454, 0.8767284260642144, 0.378389211912309, 0.8650734095323471, 0.42573513102627575, 0.2623676166178719, 0.12892296027031638, 0.10132353197062209, 1.0578650740846511, 5.941089564754117, 5.884696177897915, 6.410663954673275, 2.0668127988615344, 1.1799360979949276, 1.838957535163049, 2.709349985084226, 4.274512231349945, 1.0175793293503024, 0.25686822380990754, 0.08268887988261639, 0.2181926886400869, 0.30082274829187705, 1.6826650572399942, 4.016341826608104, 0.7378474719101383, 1.23014084273769, 2.7837423932167793, 3.6587878773289346, 3.8958912318752663, 1.6710910008799646, 2.9558243722684923, 2.3650683558756307, 3.980143252880343, 2.7181017735312065, 2.2362221729370857, 1.0967873661748826, 0.6098279897724429, 0.25909691147746583, 0.24994039878008828, 0.1287256466645387, 0.057524768485417294, 0.024557635976722645, 0.024596763917455272, 0.08739876545845501, 0.18029981953722818, 2.545461101878074, 22.258224987214614, 42.75005763576877, 42.7130030047509, 33.32408828120078, 48.48990117349933, 134.79661264727193, 78.09038146849602, 27.087245141306234, 25.335873519220662, 35.59931401283511, 54.77602889460903, 75.67050656964703, 73.66079391971712, 80.92238764609061, 84.16897266141831, 93.04400197921261, 96.93868806285244, 35.07510885115593, 1.39475426125911, 0.12116477253936953, 0.11172574193727587, 0.03987049826631143, 0.047358682138785246, 0.060779186596553174, 0.02592332176713934, 0.07218769901702482, 0.028699754639678908, 0.06491253738321605, 0.04188712130511, 0.03552960660008173, 0.02701506409193239, 0.014467293700774111, 0.027750276757644552, 0.04494455139783602, 0.060384364032577124, 0.010022336650910157, 0.031388640899451516, 0.05619763223935039, 0.04087854740059665, 0.04956946250111346, 0.052016688240391594, 0.03823743629900198, 0.022284258570101474, 0.016662077189633445, 0.04881577370988746, 0.05135310288037985, 0.042957395931044896, 0.02667248680917246, 0.07685253096203651, 0.03372379180584704, 0.04235698218126932, 0.021608940573529373, 0.022348588888323116, 0.07151023214382511, 0.09487748431462435, 0.026177954071411685, 0.06273102541003497, 0.011938770710971328, 0.1531941425656119, 0.056815451506765625, 0.2114035561680794, 0.12044122547752435, 0.25475423482637255, 0.13395526927084694, 0.2489786519999466, 0.11197631397554952, 0.17390091693209064, 0.15145207394755658, 0.2131203132411165, 0.13064442112320854, 0.21581297439913597, 0.15457565956298383, 0.09436890918521151, 0.26784517591999424, 0.08592392363014721, 0.16155459797911106, 0.19184815066476024, 0.11470729485154153, 0.0771933481577904, 0.15401735000552672, 0.1464049947718459, 0.2043678353150045, 0.15350851440621963, 0.2801182415456541, 0.16413731019823782, 0.13973802268024416, 0.22506642786245193, 0.29170354407641197, 0.1431292028076226, 0.20247127740613877, 0.20889031280192638, 0.19029408002332335, 10.858728808741416, 83.3031722038023, 108.3172329010502, 94.50043293737596, 92.19527167658653, 97.61108429201188, 92.71677432521697, 75.39116321071502, 47.83120970572195, 35.758848574853715, 35.59061419579291, 39.87320307762393, 59.62735360668552, 59.97045117039835, 87.74868457548081, 77.16765173019903, 74.75496261350571, 48.27075835197203, 10.39239037421442, 0.764296381704269, 0.13103943137872603, 0.32714886951350397, 0.35918087488220585, 0.382697077528123, 0.08702171996476189, 0.1735122498845862, 0.1835394981167009, 0.6450899750474961, 0.9600736441150789, 0.875518313579021, 1.6309788823127749, 1.9144889015343882, 3.7456203276111237, 10.14577821377785, 11.284586421905026, 4.992316269105481, 8.541805340397744, 0.962116769965618, 1.1045162740253633, 2.1672661698633626, 0.5640886183227263, 1.3248054082355192, 1.271842624391279, 0.4724942574337606, 1.186565639030549, 0.18495411011240176, 5.982404380075394, 20.38306140130566, 21.465743434044626, 23.004575544787993, 13.566073236926911, 11.947764100566989, 10.958963017309866, 19.396591186523438, 13.697200032972521, 2.3671979577310625, 1.0194519546724137, 0.25707548123694235, 0.30985277987295584, 0.6239913007424724, 2.5952011683294853, 6.976073124716359, 1.373910173293083, 2.395732955586526, 2.7812352632322623, 5.68175470636737, 7.204079522240547, 0.6697284658589672, 1.4450694452370367, 1.4229198208739682, 4.110856974317182, 3.2656121878854694, 3.017100864841092, 3.03915782320884, 0.9717715002836721, 0.30790805035541136, 0.3697155644336055, 0.29113032644794834, 0.2765237876484471, 0.23424347171620016, 0.2365917916740141, 0.30371203357654236, 0.4553780758813505, 4.174434427292117, 32.96703100204468, 74.40464788867583, 65.3037763410999, 66.53761279198432, 90.30574044873639, 180.42893378965317, 116.60222007382302, 33.53685332882789, 30.418341544366655, 35.403160202887754, 57.23023237720613, 83.44495019605084, 84.12759950084072, 91.58116971292804, 93.67967697881883, 103.33005689805555, 111.01440368160125, 45.280202127272084, 1.9073401367472065, 0.2429998720124845, 0.2207312895165336, 0.17836095825318368, 0.10811067261402646, 0.16209185544040897, 0.15572284558607688, 0.09461335252009093, 0.20814034336757278, 0.2823298760960179, 0.1400945140349288, 0.07210307694490879, 0.1518062823602269, 0.09495777032908895, 0.16128001674529047, 0.1266745305169494, 0.12016552575533429, 0.09064006814432722, 0.14213181761724336, 0.3184453139622366, 0.12218081963158424, 0.17055124344844974, 0.14955680306640365, 0.1113470416936663, 0.16620859744087343, 0.09983516102957149, 0.13331255214589258, 0.13196509541763415, 0.14976850380339932, 0.14255672062356628, 0.13217920167071204, 0.12561188995717995, 0.19122561229573143, 0.08678203403589227, 0.2007215019435652, 0.19759138925902306, 0.18593471797723926, 0.16139420981128372, 0.15416381069489066, 0.18768254757648517], [0.04278337139816534, 0.014070119246870521, 0.0030161911009570527, 0.07242811272942251, 0.047324732952420755, 0.02064256853754482, 0.07112320452447861, 0.054292727802549644, 0.06733370464174979, 0.06337969886860059, 0.03430084753481131, 0.1320699115674342, 0.03634389677655794, 0.054938601209752025, 0.07601589400080905, 0.015606886834927626, 0.02009044514007626, 0.043496675864462896, 0.04992023500944338, 0.09079038991682953, 0.035087876472501986, 0.11206007802919035, 0.03494158815292101, 0.14800881516308556, 0.16150912299992579, 0.2427531610573492, 0.06712633996240555, 0.07654118516872968, 0.18122096365738302, 0.06396454188131517, 0.1155279129142723, 0.07658413205776485, 0.013511948542849673, 6.789735046125228, 65.24239124790316, 76.03252564707111, 68.12266611283826, 68.93524785195628, 61.72999897310811, 57.24517268519248, 52.94685902134065, 20.086440001764608, 22.77683488784298, 23.923824179557062, 37.86558497336603, 42.2215025655685, 37.05855338804184, 37.65546752560524, 52.71259546279908, 42.94575252840596, 15.612507116410042, 3.3073498837409483, 0.16480924591662424, 0.05787265284227268, 0.09384076817021256, 0.09080227960141436, 0.07051134542111429, 0.17355795469014876, 0.12776500305100796, 0.08003161198669866, 0.23500125524738144, 0.3147006455448366, 0.7995347714712544, 1.6511945330327558, 1.4345719569152402, 1.8775790304906907, 6.362162376603773, 2.84646182771652, 2.466494964976465, 3.1657483981501673, 0.7206150288543394, 1.5914312173281948, 0.05664936364478162, 0.3803572305027516, 0.07329002293127199, 1.167282531819036, 0.688589918276956, 0.03981655418512322, 0.22169898113896772, 0.15398385664147718, 1.2358102610995694, 3.766656489141526, 2.670274352835071, 4.929027845782619, 5.4503922308644945, 9.814882163078556, 21.274204292605003, 32.29900821562737, 40.83008881538145, 42.20151808954055, 25.944713623292987, 6.5753873221335875, 1.6468956153238974, 0.3422191366553307, 0.35328472513825665, 1.1545063915752596, 0.5514702309043177, 0.3947603269930809, 0.8102679084385596, 2.4828159472634717, 2.402465949135442, 3.360790216153668, 2.3891958353980898, 6.0558752763655885, 5.274426369897781, 3.398495960620142, 1.281472778608722, 0.6831530229218545, 0.27648352206714694, 0.06822393711415992, 0.14408714979165985, 0.023542862505682056, 0.10132080469761165, 0.04413952322436437, 0.15721569048060527, 0.27980359391339366, 0.2691634600200961, 0.05620000711191566, 0.15086083793111388, 6.6775351570498565, 26.972278510370565, 62.61002586733911, 59.10315236737652, 57.69727291599397, 50.32154213997626, 33.85167844833867, 29.93952212795135, 22.116044952023415, 16.082752231628664, 25.469959743561287, 34.89071430698518, 64.06123615080311, 62.259130631723714, 69.01474645060878, 78.31329761012908, 79.83455750250047, 27.615031426952733, 0.7565884340193965, 0.015485755885170113, 0.10509512837856047, 0.05242115585133434, 0.09591162640361056, 0.029485444838721907, 0.007752571348851968, 0.05505059177296297, 0.020475750976812937, 0.06939265786880447, 0.07269938446341023, 0.1165667281395966, 0.07597356764299255, 0.09120347218648081, 0.11258112507001047, 0.18595216946015436, 0.10334124668471276, 0.13614675570880214, 0.010990932257094932, 0.02175621140087324, 0.09258613065485993, 0.0759266141141134, 0.03755140456280882, 0.07590167795217807, 0.10187411170092323, 0.0667227112177399, 0.01762616628360364, 0.043331871199752056, 0.030782326357439164, 0.07036799504872292, 0.11131661268131388, 0.041850222680237026, 0.050177441369141304, 0.028987688786019723, 0.07876129265153602, 0.06356081354521936, 0.022996454124128627, 0.007483426466464035, 0.022214718853994724, 0.03882666899552269, 0.02361441128737023, 0.02537195105105639, 0.040324286617819345, 0.06613391902177565, 0.03645741568517782, 0.012184224324300887, 0.05815696339273165, 0.021914450692072995, 0.038196557847362374, 0.04187631946537764, 0.027512544352981835, 0.08573515956560451, 0.10310618026602654, 0.10788750354080431, 0.02172633205660649, 0.017247234298396977, 0.11755752497382703, 0.07801716846804466, 0.06491514974303784, 0.027800915169439493, 0.02499041436690717, 0.08357528191540511, 0.09040779028568538, 0.13062447219366027, 0.14800633303821087, 0.07342581967672995, 0.03505835527433984, 0.03148975301413767, 0.07919025592385762, 0.021177657970017003, 0.0474889132554733, 0.017343002949811278, 8.734971284866333, 76.46315482354935, 89.60849208216514, 80.82861946475121, 79.68134972356981, 72.65613371326079, 71.16986920756679, 67.37077128502631, 33.97288753140357, 34.603549741929584, 28.156151810000022, 38.459459274045884, 51.317694725528845, 48.338666346765336, 46.953312658494525, 56.05801243935862, 42.57484143780124, 20.596002955590528, 3.6935827328312785, 0.11567061211192801, 0.013359218381435401, 0.047288355267336296, 0.08673074444936169, 0.16582158514328543, 0.2517402304276343, 0.49132537276994803, 0.3931882839289404, 0.5791046770830309, 1.0537205997013277, 3.168707581297044, 2.8822816475745174, 4.568622823684446, 4.204593041250783, 8.4782874584198, 7.126060637735552, 5.211618436921028, 3.879962241457355, 1.0757496111815976, 1.0411745309829712, 0.7764614902196393, 1.1087847933653863, 0.5188764992260164, 1.1716579357462547, 0.5468646328776114, 0.4945710728005056, 0.29669322794483555, 0.16537164638359703, 0.3278830881801344, 1.198955670960488, 1.7172447952532, 1.7063218523417751, 4.279690740569945, 11.274442192046873, 21.209944102071947, 33.29120705204625, 40.27880753240278, 40.390775511341715, 23.55131668429221, 6.721357347503786, 1.4510703038784767, 0.7291291461836907, 1.0451671360961854, 2.2309007423539318, 1.6383996389565931, 3.4521995821306786, 2.7870874395293574, 3.5071887604651915, 4.89734293953065, 5.754858861046453, 5.015362155052924, 8.187602566134546, 6.612008040951145, 3.4939576252814266, 2.259608324496977, 1.671863707803911, 0.7907360984433083, 0.5317209745126387, 0.4175638227212814, 0.06373840804782606, 0.202728177330667, 0.0936855894002703, 0.05316477824723529, 0.11263648258341898, 0.21851596242237478, 0.0848246870502349, 0.21026076748967173, 7.251844185013925, 28.386965643975046, 59.686561784436634, 62.62692736041162, 72.24248839962867, 55.12609651011806, 34.947365099383944, 31.5909811758226, 34.08846801327121, 29.7106243718055, 48.78256097916634, 51.6253536747348, 72.30750560760498, 71.76140969799411, 78.41732671183925, 87.5039992793914, 95.50511667805334, 40.79421481778545, 0.9634723165823568, 0.04143097723323492, 0.1046450517230457, 0.07232945592653367, 0.021654787105357936, 0.04788141457303878, 0.015567727293068124, 0.022913182281979153, 0.01016679689318182, 0.013493849715638547, 0.06617013965883563, 0.06229057464928878, 0.07075902164703415, 0.06086742077323218, 0.043026937562371456, 0.06825888604526559, 0.1323704938254049, 0.1185696113914732, 0.014198214893469648, 0.0468214170166081, 0.06706244056864132, 0.053095566033716166, 0.09817445860995401, 0.045094490126376195, 0.039120260701184316, 0.032330752846093914, 0.027856310987244212, 0.016773594693551143, 0.03469575436845903, 0.08462560378135213, 0.04904537409123394, 0.028768227578351097, 0.05553241894249955, 0.05288698327457232, 0.1766137415242772, 0.026286336360499266, 0.0929149509137196, 0.04798628434899354, 0.012832658380390176, 0.17210079417113336, 0.1009785625783186, 0.078503641960842, 0.16607945033859822, 0.12087267853559987, 0.21506799985804867, 0.1856915003830387, 0.11552739197448378, 0.1483285036538878, 0.15409639495755398, 0.23001020774245265, 0.20203048573626628, 0.1405081861922818, 0.18399159724433578, 0.2392987939979761, 0.08934259865312807, 0.11834317878369363, 0.23273426318360915, 0.1687460645071922, 0.20085218122168896, 0.07545806707874422, 0.14072215454953332, 0.23671841068613916, 0.18748120434822577, 0.18903006559177754, 0.28106868086803344, 0.2643443379671343, 0.16740487437815438, 0.2425264909623131, 0.1472025842315728, 0.21000757543069704, 0.1183172926727322, 0.14497553599217247, 15.817491162207821, 90.18217794356808, 100.55920047144737, 88.07016203480383, 89.60181620813186, 82.65530647770052, 75.95094819222727, 71.31845643443447, 34.50234866911365, 39.383291198361306, 37.180554789881555, 53.32151205308976, 59.20427891515917, 53.59894521774785, 55.791361870304236, 71.28825418410763, 57.79506152675998, 25.20404265772912, 5.389046851665744, 0.34786790128677125, 0.21286056346950993, 0.2642149916819988, 0.20140670630480015, 0.24133959094122534, 0.4685016829640635, 0.43675542839111825, 0.2519344337164395, 0.5114743431969997, 0.7505990360533038, 2.770116569534425, 4.05426477232287, 6.90936831697341, 6.2826069035837735, 19.062352295844786, 11.78198806701168, 7.305022699217643, 8.450539631228294, 5.10481769038785, 2.6420009280404737, 0.8579492821328102, 1.5876200218354504, 0.4669747778004216, 2.4663471406505955, 1.4135936503448796, 1.0296074613448114, 0.5751291710522868, 0.49308112371833096, 2.331203837548533, 12.811648480353817, 8.483427724530621, 11.129185057455494, 8.078584209565195, 11.485206830886103, 20.629286227687714, 30.002395760628488, 37.38345115415512, 39.591592588732325, 24.434881556418635, 7.730202232637714, 2.842585300245593, 1.1803426761781017, 1.5025167239289132, 3.0784781132974937, 2.1094965213729493, 4.009215125153142, 5.626006059108242, 8.56319010257721, 10.211518118458411, 10.207734011834669, 7.554937005043031, 18.13075800095835, 12.64888188531322, 7.361743113686962, 3.531520203236611, 1.4394021106343118, 0.6508347764611244, 0.473241223803451, 0.3926273237072653, 0.1685728213839954, 0.3373499430956379, 0.18416326222640855, 0.2999141067266464, 0.6475919569211622, 0.6418280339529437, 0.1517574059506578, 0.3696498340897022, 9.494015612909871, 39.107579954208866, 82.20031153771185, 74.11515343573787, 71.71764389161142, 63.359916363993, 49.627517961686664, 46.44194541438934, 34.42353256287114, 29.00517236801886, 41.62777731495519, 53.9888798036883, 80.67980474041354, 84.42242053247269, 91.36001079313218, 96.47573855615433, 106.79270175195511, 50.98020222879226, 1.581273749470711, 0.16068240687731775, 0.14430882499342965, 0.13924610230230516, 0.1431894632837465, 0.16762926153117613, 0.16095125777346475, 0.1737886390859081, 0.10141877202136863, 0.20172876966816766, 0.09428968037208242, 0.11660266532412461, 0.23045867561332642, 0.1881733341442962, 0.19694278857881026, 0.1653763501634521, 0.25666303482026825, 0.20579306528933589, 0.08021525092302792, 0.1497235804075195, 0.22969994213311906, 0.2052470591039427, 0.16764963946996198, 0.2624217330688431, 0.1452249435768012, 0.17671782222966995, 0.16920482859976832, 0.1306560963031746, 0.11369082641096846, 0.07659753093556051, 0.18985903401288295, 0.1227567109069036, 0.12338600617142455, 0.17407319478450284, 0.22042609540925873, 0.11753428952708361, 0.20123471956579916, 0.16599960865512972, 0.18412302728862534], [0.19721101128285934, 0.05131669455177842, 0.03052739910931597, 0.005803129911768221, 0.028531519816287106, 0.015423494961953934, 0.05493859354887278, 0.1682116722147311, 0.08182376743324342, 0.12342915224332003, 0.02268221443368783, 0.1359606882737529, 0.05226699214789176, 0.025538130843591307, 0.015889271631866934, 0.11026590011052548, 0.12769049333949245, 0.21365035415416767, 0.11491109722203786, 0.31976212717352376, 0.16418146750619336, 0.18115915568365207, 0.07564697669999254, 0.3486099953372633, 0.660527382166155, 0.5078928208639545, 0.2708560240364844, 0.4097631477540539, 0.14366704249574294, 0.12406354965341669, 0.15319889231074243, 0.08435755727752563, 10.188343774887825, 64.57167771554762, 71.24620637586041, 77.5853370851086, 75.24156401234289, 62.7432805492032, 54.08336577876922, 23.49674474808478, 25.005531503308205, 29.841829615254557, 21.848904086697488, 34.465003782703036, 51.33652994709631, 47.776888801205544, 42.00145759890157, 41.068831720659816, 34.57232375298777, 11.898389304837874, 0.9349987896219377, 0.08096110646522815, 0.11949639391875076, 0.13997311974244733, 0.14666739520767044, 0.13150806268376689, 0.0434733216740912, 0.13911784386202214, 0.1523316041716645, 0.3089834845835163, 1.049450854620626, 2.2770903283549897, 3.843361869935067, 2.77990484429944, 5.286410681663021, 6.732340474282542, 7.952718292513202, 11.309487588943975, 2.548363410657452, 1.1342185447292945, 0.6424637030689948, 1.9427332762748966, 0.3611507627271837, 2.2377501812673386, 6.157177840509723, 6.81757701020087, 5.029028673325816, 6.732440985018208, 7.409876479256538, 10.2446807776728, 6.701226272890645, 5.878445390732058, 5.434038889023566, 13.60520770472865, 52.54355307548277, 82.47263385403542, 90.30425779281124, 90.58471510487219, 96.14208605981644, 94.71046801536315, 83.38278062881963, 65.27659431580575, 27.646612390395138, 12.272798169043757, 5.3373995327180435, 1.934760200881189, 4.379240985839598, 6.482605616892538, 2.5158040610051926, 4.271390024692782, 3.5408605923575744, 7.085431256601888, 6.13740272098972, 6.484050029708493, 4.291709373074194, 2.5969400040565, 1.8935511669804974, 0.8322524255321873, 0.5786965667240082, 0.7100149460377232, 0.2717604980834069, 0.37039465541320465, 0.3633899457993046, 0.17606402747333053, 0.015220207785586677, 0.10502671672692222, 0.2690470146556055, 0.07058125860508412, 0.12229040850915256, 0.055150397707738226, 0.3454259194193348, 6.815300564612112, 25.776245863206928, 35.15146955367058, 40.35590171813965, 43.94969886349094, 32.365888549435525, 26.56816847862736, 21.615436769300892, 10.691911385905359, 15.98048427412587, 25.743560752561017, 33.62887997781077, 51.12882867936165, 66.21411138965239, 67.91605134164134, 82.72545414586222, 40.790057105402795, 2.669223402777026, 0.009009662260782094, 0.07491438980064086, 0.23129234781428692, 0.43036637767668695, 0.10372144846065391, 0.21334235616508992, 0.043276303012164376, 0.10064264834528008, 0.1319675928642673, 0.1993474772860927, 0.1613617276832942, 0.26229394960307306, 0.31566910325519504, 0.35844601270171905, 0.13474737354103597, 0.1537162774512845, 0.45336504196447713, 0.11360910781208547, 0.18296192910882736, 0.1020823420596219, 0.04683048366719196, 0.02468984360025535, 0.2008872833703795, 0.1847809435979974, 0.034864527368617636, 0.08743022868950522, 0.04113553159479653, 0.024340457711068374, 0.07646979343506598, 0.08897783354886117, 0.02992794296944574, 0.06298297257613271, 0.07084023462788713, 0.036678037516051726, 0.02453582545351838, 0.018586892251586242, 0.06587351807543347, 0.08667142626138465, 0.044447754870258996, 0.027853562646815856, 0.009082273989465208, 0.031701608883938005, 0.05495357822867171, 0.09354782380884694, 0.10283274816409235, 0.05357634749323611, 0.05894737843904765, 0.03439460903586399, 0.09357190195230708, 0.0385704355674886, 0.04047327922777303, 0.014222842705015455, 0.10555749308438071, 0.08658005495465572, 0.23298624482366348, 0.14158124554782145, 0.1462663635010681, 0.1630322896544972, 0.15504537871287716, 0.06358862636731037, 0.3051216047137015, 0.4485955930525257, 0.32369914494695207, 0.2901450454467728, 0.251892329524121, 0.06965691989828503, 0.18895607682005053, 0.12118985425801047, 0.06385283477063622, 11.932747306362277, 77.64308221878545, 84.53356481367543, 86.9012878787133, 83.1174244419221, 75.28119564056396, 65.17215336522749, 37.53541161937099, 43.1432399442119, 35.5871585876711, 23.154651311136064, 31.772773227384015, 39.575000962903424, 34.54949163621472, 45.083055957671135, 45.79059662357454, 39.57441652974775, 14.632087157618615, 1.2860230957308125, 0.09056856915835412, 0.04470974927948368, 0.15867167122421727, 0.27695209208515387, 0.18012599418720893, 0.8389099747423203, 1.3183151113410152, 1.1554069432520098, 1.7283447351186507, 2.1870356509762425, 4.384619535938386, 5.403094820437893, 4.201910140052918, 2.729253071931101, 9.297993202363292, 7.297538326632592, 8.493140493669818, 5.779979680815051, 2.020302804247026, 0.4770386603570754, 1.4967966824769976, 1.9710911546022662, 3.24551813064083, 8.084660941554654, 7.049520977081792, 6.518198184428677, 8.103171586990356, 8.287693608191706, 11.682651100620149, 7.898508194954165, 6.620042525952862, 8.3928592166593, 18.50520314708833, 57.21504103752875, 86.60292886918592, 98.6661155762211, 102.19083586046773, 108.12840215621456, 105.99545648021083, 91.12714752074211, 64.04074176665276, 29.033509531328757, 14.712680097549194, 7.4443810793661305, 3.0549007461917017, 7.5625782724349735, 7.654605411714123, 5.569209648716835, 4.930915486428046, 4.22520705769139, 5.951426971343256, 3.385472465907374, 7.347552958996066, 3.278601852155501, 2.4890853656876475, 1.5997028831512698, 1.774304985038696, 1.4113191659412077, 1.6477486082623083, 1.120049595352142, 1.042299025481747, 0.45097785070538526, 0.47701996781172296, 0.03405892079876315, 0.24288224687259047, 0.32515854244270637, 0.07683484965274412, 0.06977629171864641, 0.10908424013083982, 0.4344767458256214, 7.951752899154541, 26.7587839018914, 38.10420236279888, 38.925982059970984, 38.25137753640452, 30.00419612853758, 20.622222039007372, 25.54409253981806, 16.3330739736557, 26.0612609694081, 44.51401026018205, 44.44570610600133, 59.03455403543288, 76.45215649758616, 76.10816463347405, 98.9401480459398, 55.62171543798139, 2.9963152447054466, 0.05711173984192072, 0.08693449319370332, 0.22360539093853968, 0.24566804900044398, 0.10313192848116161, 0.06994120746610627, 0.04824778463150706, 0.04873073411985271, 0.10271074866215069, 0.21694439433274731, 0.1164254615263593, 0.2707118462891348, 0.25458166586054914, 0.3164918816858723, 0.20334012836458223, 0.10039807477545354, 0.2757808355794799, 0.029652241332035874, 0.12404631267512038, 0.09027471315235862, 0.039113300792392225, 0.014929763743683938, 0.12736675990444998, 0.10948785355374699, 0.02623912619216548, 0.06996305629370675, 0.014663318363619188, 0.07886667570640003, 0.029153782393663164, 0.047246998010744015, 0.01352972369791279, 0.08143831795502095, 0.050216228400747624, 0.07889952555659317, 0.020414751225842104, 0.030348094315418316, 0.08371234270593814, 0.29207524993727285, 0.21784269371100012, 0.11877905216909225, 0.06957635043128844, 0.1500090400898649, 0.13716554539578577, 0.16221643665865546, 0.2744178425881171, 0.3012769465004244, 0.20349915289590437, 0.11528782095880279, 0.24022035180561005, 0.18659874766824708, 0.14773616447083412, 0.08809667155747453, 0.18504024903860786, 0.24871338639528523, 0.2819514899484573, 0.3365457039927283, 0.30232256458651635, 0.3214832203042123, 0.30374577208872766, 0.28541561696798573, 0.6511821513695102, 0.7732140128650974, 0.5990460070390856, 0.6193781031235572, 0.46709600355355974, 0.28099758790866025, 0.2472719919657515, 0.20272788621725576, 0.12618762801491445, 21.350782686664214, 95.76276932993244, 92.06282108060776, 96.50577606693392, 96.5532995039417, 82.95614442517682, 74.22505824796616, 39.21159336643834, 40.68632218145555, 46.456336590551565, 36.7788609381645, 52.20428374505813, 72.76026479659542, 64.02859810859927, 57.62595245915075, 55.90282778586111, 50.510259136076904, 18.57511155066952, 1.6133776138867102, 0.17336652463962957, 0.22503222969751205, 0.5273152947906525, 0.41350613077802045, 0.436988870703405, 0.8035633520733926, 1.0122363870182345, 0.9454645925471861, 1.2168701161299984, 3.655678173226695, 4.812608957290649, 12.936796603664277, 9.888746276978525, 11.547428369522097, 18.43583603059092, 23.507962726777603, 25.454670344629598, 12.272508894243549, 5.238894108803042, 0.8714956165321412, 2.4921320667189937, 2.0927149057388306, 4.881116094127779, 15.14999887635631, 13.138984980121737, 8.52591876060732, 12.263705134391786, 12.040277123451235, 14.943177200132801, 10.067648522315487, 9.489646092537912, 10.55974712294917, 20.005545039330762, 61.38980788569297, 81.73493800624725, 92.86996641466695, 97.86193555401218, 103.36616623786189, 98.46616883431712, 84.89224987645304, 67.34401287571077, 33.70008276354882, 17.872828821982107, 9.618371417445521, 3.831310877876897, 9.16357651833565, 13.224980004372137, 7.400046039012171, 11.16292920804793, 13.077752859361711, 21.118829404154134, 18.792620705020045, 17.364364131804436, 13.913031393481841, 9.6132242871869, 8.663277222264199, 7.041515419560095, 5.127720409824002, 3.2517368034009015, 0.8506378002705113, 0.6736018676911631, 0.3544845414017478, 0.3835696516738784, 0.16783549240039242, 0.33716295635507953, 0.7861364452588944, 0.2576104863997429, 0.3912752091644272, 0.14335037239136236, 0.6091898078880003, 10.501422459079373, 39.07174910268476, 54.33100069722822, 61.0997486114502, 64.96338129043579, 51.315717850961995, 40.95195685663531, 34.828576118715354, 18.455418463676207, 28.98337967934147, 42.50078316657774, 52.38377924888365, 69.38585758209229, 88.35936623234903, 86.89672223983273, 109.11734934776061, 62.98347473144532, 3.935148518893027, 0.12011839602623256, 0.25071056229212596, 0.5307944371334968, 0.46609674910864524, 0.3334465412603271, 0.2569322687603774, 0.14159685841971828, 0.22583570271249742, 0.275098251238946, 0.27182028358501775, 0.2967487846411044, 0.4647517745052615, 0.42118603964486434, 0.6631831332079826, 0.46625661633668414, 0.4282279504883674, 0.515314374239214, 0.2142383419578114, 0.30331158409676245, 0.18921830871653175, 0.2537409762942022, 0.21465521636268786, 0.4850591719150544, 0.30714456713007343, 0.13787333402902852, 0.20357367792917838, 0.16983439965594202, 0.16605108976364139, 0.2350865821203878, 0.15128189517605692, 0.1398067560888106, 0.22375591189390232, 0.10558456663162478, 0.11733016539965907, 0.19333013243252234, 0.1999558736720393, 0.17831597357026993], [0.06470444492034375, 0.031119801494623386, 0.014871240371928341, 0.1554977229886478, 0.022638363560902017, 0.055187549141626206, 0.13891309920337894, 0.07768719141641933, 0.07038972896313475, 0.05046636376890445, 0.04610209109922571, 0.023409942420379772, 0.06041674656913646, 0.023958718013619224, 0.018195898212011785, 0.10726811379314431, 0.10084960699802446, 0.21374214680925493, 0.08211501874029636, 0.18087873685984843, 0.12300067160639072, 0.16685955767189303, 0.11422044597566129, 0.12780489324922525, 0.4229827916189548, 0.2546298527909864, 0.06799023433197891, 0.3250648039242914, 0.10496618045914559, 0.1953203216074936, 0.3462023954958685, 7.283965945243836, 66.13243195318407, 67.83794126202984, 78.07839470524942, 68.80569980990502, 56.004872168264086, 42.72730396639916, 34.02769480982135, 26.423193754688388, 16.97439032216226, 42.92334010524135, 55.323446642967966, 34.805720467721265, 47.36205108704106, 74.0089984093943, 53.6447585013605, 28.756101862076793, 10.507808077719904, 0.5075351190903495, 0.047391003388310635, 0.06384742235945118, 0.12300418794996316, 0.24045904948105737, 0.30167561865622, 0.05246832388483229, 0.6459158791169044, 0.7571289856587687, 1.3646497024643807, 3.395626746839093, 1.0342199235193192, 4.300753378099011, 4.830094883518835, 2.8695699812904483, 2.549804146251371, 4.5398277236569315, 5.998992083534119, 4.4833039179925, 4.79679984431113, 1.7558859024317035, 1.5161760103318, 5.476489720805999, 12.1037067521003, 14.723404838192849, 23.318027834738455, 27.69721684917327, 29.74126396640655, 33.60619691110427, 45.188936418102635, 56.23631162028159, 52.37821732797931, 45.91401400104646, 48.56117063953031, 59.30879046840053, 81.1641154750701, 76.2580462424986, 55.98877083870673, 56.49829064646075, 53.15066929786436, 63.854801808634114, 61.82537532621815, 77.24404381167504, 59.596959160220244, 39.978695223408366, 28.65389862368184, 29.129578182774207, 24.053229055097027, 25.85543263343073, 21.01340982221788, 16.376216123181006, 12.142124406753048, 11.934945794843859, 6.555614163798671, 7.686062820496098, 3.71436222426353, 1.5355253075399709, 2.6420906522581658, 3.3681554467447343, 2.512923325261762, 0.554929209812995, 1.0575414785454351, 1.0807130029124599, 0.3409155001563411, 0.4370332425159793, 0.2291152638293082, 0.1573113901841064, 0.0722190166913694, 0.03395731072692621, 0.1163816489579697, 0.05045343603518221, 0.13299746018263603, 0.19775577640581518, 4.0389496328369265, 18.79976922465909, 45.82619605525848, 60.013977712200536, 54.03835265867172, 56.09871095226657, 35.98684026348975, 46.668517205023, 20.756068998767486, 9.5412419303771, 31.667506617884484, 60.325362913070194, 70.31766368496802, 77.59274251999395, 67.01036037937288, 75.71234256990495, 43.95698270490093, 7.252929210662843, 0.23496118884894157, 0.1395663270546544, 0.09055936078150427, 0.18460342570418314, 0.07142269893759681, 0.0604585251740871, 0.11723192228424935, 0.11037594097996913, 0.1459364094320805, 0.06764167198731054, 0.19269248680962672, 0.18640848207137278, 0.23000135176604797, 0.03202009270147931, 0.05503697456010888, 0.26698109002843984, 0.0563170615163061, 0.09266303822157845, 0.01839123722616463, 0.14323772682297614, 0.10915315740050809, 0.14901669575802742, 0.059713933676961935, 0.0488476008327017, 0.10011095268231246, 0.03023004974238575, 0.08001841995264254, 0.04684333479212177, 0.036557516563803925, 0.07796004129153106, 0.1452032326450271, 0.18805691942332253, 0.14509244100941768, 0.02997879397063967, 0.056956526598021875, 0.0363169189903044, 0.05433535293465661, 0.015258513139410606, 0.03601449046043619, 0.10813295045086455, 0.073618475467928, 0.045036918618866516, 0.14534180262877097, 0.058299156972357345, 0.02647467907668362, 0.04981566400777909, 0.05409043462526414, 0.08666025669944864, 0.02093452464548811, 0.012029181534965194, 0.06785134259130686, 0.04964670714651866, 0.019277290688947808, 0.0937590572322088, 0.09452035710696252, 0.13252904338221397, 0.20427800384500336, 0.1099006906752625, 0.010849902173504235, 0.09408231569273819, 0.4217979600352626, 0.41013117639287827, 0.14211956021045485, 0.2204241342241726, 0.12592352686389802, 0.2176290471106768, 0.4771763110353101, 8.424907922744751, 79.1177757324711, 79.14804074072069, 86.81519185343097, 76.5461443316552, 65.11962106150966, 53.27755797293879, 47.820172156057055, 29.21243040792404, 27.660599562429613, 50.60861256814773, 54.93474368126162, 30.642008819887717, 45.72543036553168, 57.39788624548144, 45.37544511979627, 29.08394728937457, 11.222515894520669, 0.6071748127860408, 0.07942861652061825, 0.24197014258994212, 0.079999030267279, 0.29009681255106007, 0.8228810251720491, 1.0836895915769762, 1.9904254977741551, 2.144553440232431, 2.9086120282450034, 3.4883069607519337, 4.730459326697934, 3.714207535789859, 4.2522679798064695, 7.34103201858459, 5.259868002706959, 5.420733719102798, 4.251971350562188, 5.7192682546954, 3.0112810480979184, 1.7617948305222297, 2.2032313625658713, 6.195944586107808, 11.532041891928642, 15.459799439676347, 24.277721989539362, 32.38672221860578, 31.78839602778035, 37.690882605891076, 52.66891594856016, 61.452761926958644, 55.989633760144635, 49.12217155579598, 53.97426113005608, 67.7095385520689, 93.82412218278455, 93.41149668539725, 68.72915867836245, 66.87026116155809, 63.06801749813942, 75.40957481630387, 77.64682415992984, 91.3016067012664, 69.92170826081308, 46.316613920273326, 33.63418302228374, 31.423005673193167, 25.969236281610307, 24.508194577309396, 21.736398743044948, 18.415702504496423, 14.263554984523406, 11.684990794427934, 7.382600807374524, 2.4392543492778658, 2.1010178279492164, 1.1761673131296713, 1.7149405253510324, 2.0745055473619893, 1.9910552833349475, 2.8055929368542087, 2.238027934105166, 3.2672735568015807, 1.223767849226152, 1.287903872228438, 0.4592294143813272, 0.611516508844591, 0.7549846136281568, 0.21708596738115435, 0.4155096958481497, 0.19045338034629825, 0.057382766427772666, 0.11737924099208848, 3.5874458474497644, 19.911767052065944, 46.55931841942572, 48.14119854281026, 41.94341828746181, 39.9500697658908, 26.10696050428575, 33.097536102417976, 30.18786503422645, 18.139006745430734, 42.05873989289807, 66.80082736476776, 84.31980348402455, 88.19954533730784, 73.652847197748, 87.85822068491291, 63.168379183738466, 8.712754980210336, 0.23712365587632503, 0.11826774976666897, 0.17605579968902374, 0.06614082147397342, 0.03554793525367014, 0.03366865262749695, 0.0913362505455171, 0.028043713330501513, 0.13889356396130978, 0.0372946655167447, 0.10915999090479267, 0.195750571907528, 0.15288701791676784, 0.045055569029383125, 0.0446465585170494, 0.18915656202983475, 0.05485237418343464, 0.07624437206334646, 0.026475192355592887, 0.011159830704151143, 0.1508421607075199, 0.11738360003237763, 0.09236756577006272, 0.07571664473582661, 0.09117155696355528, 0.01542251532702076, 0.1134616741910577, 0.02086124258987125, 0.022311596417679422, 0.025618696480148265, 0.14841893267246986, 0.1817083947600857, 0.0977979340560494, 0.006649914186357731, 0.040951563240659815, 0.05518744571975643, 0.20426815195429712, 0.07631010240724972, 0.09512195829302074, 0.22026993604677342, 0.21921572245417104, 0.23586036156742807, 0.2909650353174056, 0.23191229680613165, 0.2103881219462041, 0.18791422788654605, 0.1691839910082279, 0.27438005913169156, 0.15981884192555182, 0.08735343603597534, 0.22261811810876095, 0.20457014381404848, 0.23147214865011556, 0.3766161473768373, 0.17283608536085776, 0.3407387483504511, 0.35726495027061433, 0.41066103344482763, 0.21899469076625763, 0.2585183618770492, 0.9115371324362294, 0.7394325384689916, 0.4762461883646827, 0.5748321127987678, 0.26685352106728866, 0.3626295269256638, 0.8440952255360542, 14.369467804508826, 93.8391762395059, 86.50980395655479, 98.14313811640586, 89.7999429702759, 77.03401657842821, 59.10165009960052, 48.40964555740357, 38.2752686931241, 26.8776572135187, 60.21919219724594, 76.16454478233092, 50.122250433891054, 62.261127118141424, 92.01309327156314, 71.73706746870472, 41.7204943010884, 16.559858552871212, 1.0521156148564432, 0.2988642598352125, 0.2703804366530911, 0.3172815651182206, 0.673769181293826, 1.0287398820923221, 1.4120957952353264, 2.4998645292174433, 3.7964608640440054, 5.02589617044695, 9.353855598357416, 4.587174163710687, 13.357613971156459, 13.76885683305802, 14.903130781265999, 14.070044852072193, 15.765856100666909, 14.655513513472773, 14.721697626575349, 12.85341387794864, 9.317323623165008, 4.296677545193703, 7.932794122926651, 17.164713528848466, 22.22031527949918, 34.820217547878144, 43.16851177523213, 36.90565547635479, 43.56458487049226, 57.774406325432565, 70.54197619038244, 61.43873553122244, 54.008887813937285, 56.687654833639826, 73.08070675019296, 98.87407179801696, 94.84954741693313, 71.38749799420758, 72.73448697982296, 68.9774525550104, 82.17779713292276, 80.26793233809933, 90.03307296383767, 75.2652237492223, 51.15714819200578, 38.83403778076172, 37.57648667981548, 32.99376587713919, 33.003689473675145, 28.838391227106897, 23.978298056510187, 18.42372767386898, 17.752192404962358, 14.889088696049107, 17.80285962166325, 11.799293564211938, 6.685524534794593, 7.998475192054626, 10.068480064792018, 12.401594096614469, 6.595690000441767, 5.124677140866557, 3.89391950541927, 1.3535661875240266, 1.0938927795617812, 0.36611654465236976, 0.6612238480198769, 0.8325884623392936, 0.3962963026377463, 1.1192484512444467, 0.48550659790635114, 0.45481199819234114, 0.3734935729974701, 5.7544524054373465, 26.380585047506518, 66.16619571562737, 83.9953685575916, 79.7871909602996, 78.74394247608801, 52.77410607184134, 65.29009119156869, 32.224028187413374, 17.601218415844826, 48.138550942943944, 79.49858296302058, 90.51145307479366, 96.63796778648131, 82.78341108752836, 98.43568417333789, 72.52536189171576, 10.71336086719267, 0.4559470340609551, 0.3724216014867829, 0.3106036379693016, 0.43284847190783876, 0.09947253331061333, 0.237602828551204, 0.4237336497153006, 0.27426563623932104, 0.3566131013776026, 0.2015082435982843, 0.31979653984308243, 0.6421500973163113, 0.5851144836314264, 0.1394087887339054, 0.3082845059614028, 0.5008425443403183, 0.19036590842710388, 0.220802198614805, 0.08421339485193453, 0.1777210603317907, 0.445928166830732, 0.500071001870017, 0.19119078593869365, 0.16831897048940583, 0.196182860001441, 0.1398935232071146, 0.2891738911069209, 0.12628096050672954, 0.09491033416481749, 0.22221658078412856, 0.23632827274982007, 0.37397047805209316, 0.17534888439601468, 0.11611567089153875, 0.08387175794210165, 0.14637490283818017], [0.04240966987826171, 0.04888365676085796, 0.0634627772735492, 0.08187189307664672, 0.09197188135717185, 0.03975081234990109, 0.04085717354750922, 0.07955684431738431, 0.029306561393182606, 0.0816758971420988, 0.04004685553692041, 0.05585585743369115, 0.03408200302792173, 0.018198083477815794, 0.04196967877027008, 0.03609478413578003, 0.054647897655564937, 0.04286600547211786, 0.11079210292307601, 0.049659600406284296, 0.21228942960020036, 0.1416069707803188, 0.10153508715091214, 0.1335646563600148, 0.1332644265024893, 0.20226685450442378, 0.06668494308307286, 0.19316410585757227, 0.17495300080026352, 0.3130697362845944, 4.487462610967698, 60.13001318900817, 66.62338718291252, 79.89130635415354, 67.85591356215939, 66.30711863117834, 49.444990465717936, 33.708327585651034, 27.44630871280547, 34.56755807322841, 36.79528390207599, 33.62647556489514, 37.121185794953384, 56.20413249538791, 55.65496929230229, 34.56878185272217, 24.577753889945246, 8.116479698688753, 0.5371589730343511, 0.021321872106542992, 0.024754903617224867, 0.17205639171504206, 0.06740477461848529, 0.19471676689722847, 0.7261809947029237, 0.3291272149691659, 0.8524110793106018, 2.0013196357796272, 2.7959279716014867, 3.342463431819793, 3.7830387584624754, 5.668564756070414, 4.033553186924228, 4.675515255620403, 2.9334234710662597, 10.053188704675245, 7.5583107336874935, 11.045013935335222, 10.542649511368046, 14.422753203299738, 23.749133579192623, 30.63327370151397, 43.39888826493294, 44.53528127362652, 53.92205830543272, 56.413547838887865, 56.67445605800998, 61.43705675678869, 59.177191026749156, 57.483346846795854, 65.7022185479441, 60.38067225487002, 55.3813761280429, 43.05337844356414, 60.915475660754794, 46.43188061252717, 51.61663032347157, 53.724814076577466, 53.60027097886609, 58.952858909483886, 55.15385512382754, 40.89390970045521, 37.73655468417753, 49.936565429933616, 47.43455609967632, 58.39264638962285, 55.05029278416788, 50.77616837716872, 47.181390639274355, 40.48885829987065, 38.781984006204915, 37.099451941828576, 27.38875577526708, 15.014896758141058, 5.245563608984794, 2.202556960044369, 0.9823395299815363, 1.214092587751727, 0.33605402876292506, 2.3938732618285767, 1.2137036602343283, 3.200947012632124, 1.0943866304812895, 1.1450323967203018, 0.4553037347091783, 0.9303056737107616, 0.23703305831839963, 0.06246043166386024, 0.15056011777731682, 0.11896164156496526, 0.10570013865588174, 0.02992028209020294, 0.04240585476039879, 0.25522879565194734, 4.987460865128425, 30.263443223891723, 48.845146317635816, 36.291074983535275, 48.52840315911078, 30.195866669377974, 15.937142083721778, 28.237892043206003, 18.612972228757798, 38.92109086436611, 35.466165234965665, 41.4288660787767, 59.7096606223814, 69.71936887310397, 74.35320992623606, 49.30692303565241, 6.5530347151141015, 0.2920084164267586, 0.22522562093311743, 0.10241733698715126, 0.03434009038873258, 0.05421269459710006, 0.1023177455569948, 0.04588690849261419, 0.15387196183925675, 0.04178755285759126, 0.1419820780715635, 0.09185840075294818, 0.09439697864675715, 0.051348088834915435, 0.02252149876327284, 0.11495585207857432, 0.0866402771263834, 0.09769851882611552, 0.04599366284486267, 0.04034180321820802, 0.10527098386157906, 0.061945344787091024, 0.0799936063647751, 0.021335180969007557, 0.03965128603721819, 0.010496874493847211, 0.056127960373076706, 0.045287172730651595, 0.0674604002626673, 0.08068802676373914, 0.04532659178479545, 0.066671222448349, 0.07119022189609467, 0.029385052846684575, 0.049839868555746736, 0.0884195163305248, 0.04469935729679081, 0.07218909329704701, 0.01598414012997021, 0.02080862958645148, 0.044895403027053804, 0.039710263316068924, 0.026239453694753112, 0.056991774303418015, 0.029350866173063556, 0.03281898068023786, 0.05194744921379513, 0.059789021784860286, 0.034295821998028025, 0.0645930787187911, 0.012316447269592074, 0.09461592657551651, 0.05791134028244884, 0.07063285462678441, 0.04933714250763578, 0.08263263370721571, 0.05047965922483033, 0.05378231023167891, 0.07198712187668971, 0.04482902916929415, 0.13483991696228906, 0.118104029116371, 0.061099223657360965, 0.018818769829287645, 0.05198165120917463, 0.22735356803863283, 6.0403108212255665, 73.63635755354359, 79.81778544764366, 87.8715253645374, 79.7857318385955, 71.69539620799404, 61.44838456184634, 45.67721659137357, 41.403186321258545, 38.37421048072077, 26.4545040745889, 34.04049742606379, 41.91419662967805, 52.98963639043993, 50.944088966615745, 40.436220092158166, 24.714509287188132, 10.187118034208975, 0.34328225218961317, 0.008731381779897117, 0.11495595933088373, 0.18599565261073653, 0.3914339425823381, 1.3553677811737985, 2.8895309230973645, 2.3705209407114216, 2.830313184568959, 2.641714595017895, 2.651207221131171, 4.614687629284398, 5.338720390873571, 3.5909700970495906, 4.031972471744784, 3.521134012168454, 5.9011054135137995, 5.151661576763277, 5.821716641226123, 7.677458611226852, 9.938138723373413, 14.711762262928872, 23.739455130792436, 31.951705871089814, 41.985736739250925, 47.610494013755556, 55.19079600611041, 57.6913893607355, 56.939318026265795, 64.32298767951228, 64.16322562002367, 66.17275391855549, 70.05768114520659, 63.86214840796686, 59.2227493563006, 50.611362149638516, 67.34165160886704, 53.17967914765882, 56.90674274198471, 60.45176913661342, 61.50105807089037, 67.56193976248464, 62.45708088720999, 49.76697391079318, 45.789796460059385, 56.8385797931302, 53.55689740950062, 61.372729885962706, 57.345659886637044, 52.35095685528171, 51.61457500150127, 44.75459667944139, 41.54807475305373, 37.038478697499926, 30.869425881293516, 16.043926650477996, 6.344468074460184, 2.3835294813879075, 1.4229815982041822, 1.505424671115414, 2.096414191107596, 4.1765726093323, 4.318230478994308, 4.411827546934928, 3.136658630063457, 3.110778831666516, 0.8468576773039757, 2.6583042596617057, 0.8001950779749502, 0.9137440172414627, 0.6733016225118792, 0.36672524747348606, 0.14986527602999442, 0.0141947521760519, 0.05274919470051124, 0.17359036020934585, 5.597535044916215, 33.62145885344475, 48.74672228290189, 40.82042409527687, 45.264116487195416, 33.74276599576397, 12.281731367111208, 24.960071233011064, 29.67561721801758, 53.950024804761334, 51.142105902394945, 53.34283797971664, 65.77465688028644, 78.2814165853685, 86.13335055689659, 69.1414390071746, 10.015231928517743, 0.3788517451574726, 0.08999537451252823, 0.09854899899613473, 0.06793362043437458, 0.09080132199150902, 0.05007652077643622, 0.03487019258881769, 0.10677094571292402, 0.1136295163943883, 0.0877526980794726, 0.15351818243582405, 0.06645460342687946, 0.032784047070890665, 0.05323580608913495, 0.040558548644185066, 0.0765899236824724, 0.08389705416536139, 0.14170849275204445, 0.06491218498277088, 0.09425748169662491, 0.019827223074952924, 0.06967038772399388, 0.0267272237913623, 0.017585172918775392, 0.05825208086941031, 0.04274694391736581, 0.060423886508590756, 0.08003401750278089, 0.08060602471232414, 0.05695760678199511, 0.04302979890076865, 0.05035804659729043, 0.027543601557432164, 0.04153652499700266, 0.053003574195768566, 0.0957090191302761, 0.25116014865136915, 0.18164289424255972, 0.28836174597663267, 0.23658255265364725, 0.15938578774371456, 0.10843972269926341, 0.1986467826270288, 0.09728368987599689, 0.19882742615957416, 0.21661425640265788, 0.17738868542496236, 0.11580321427074172, 0.1594771054242888, 0.12064635318012969, 0.11247110718320455, 0.13722202139756373, 0.3084874273307862, 0.23342784854673573, 0.27540762818628745, 0.3056037498097266, 0.1647087811462341, 0.2116489800955019, 0.2415939934191204, 0.520303690385434, 0.3491846838545415, 0.36166707534463177, 0.3294091659688181, 0.2289603455292602, 0.4569102823734284, 12.935273743444874, 88.53323705734746, 86.83979295915174, 102.6699298427951, 88.41526785204488, 83.79144453233289, 67.33283412071967, 48.015800368401315, 43.11430069708055, 49.50187267795686, 50.927524797378055, 46.30524296914378, 51.24067506482525, 74.51794947347334, 73.719268614246, 47.37737970967447, 36.28437165291079, 13.142645532085051, 1.015141331140072, 0.118243234953092, 0.40132303451818807, 0.3620798435182341, 0.5188584808380373, 2.084266855832069, 4.546541350503122, 2.6835094103890085, 6.248429331087298, 7.396433045787196, 9.469421371336907, 8.406068778807118, 10.854614242430657, 15.426614226833468, 10.881576614995158, 11.446928420374471, 11.285812162583875, 21.735018068744292, 17.12300108325097, 20.034550966755038, 17.466757605152747, 22.473872976918376, 32.26169078580795, 39.16323446458386, 49.650656023333156, 49.91667901315997, 61.123008266572036, 57.37499137078562, 61.464364297928356, 66.21657463812059, 63.863819337660274, 69.51484080283873, 78.42711694778936, 67.94546911793371, 63.383156407263975, 58.05146686492428, 75.2817447723881, 61.62178078005391, 65.65877437591553, 65.89923920169954, 67.40554701897406, 73.40570649793072, 68.38561396444997, 58.19704171149962, 51.351513401154556, 64.73365983655377, 58.62563910022859, 66.12668175851145, 63.458728713373986, 58.037671889028246, 56.987025814671675, 47.26044601009738, 47.011544166072724, 47.20328530957622, 33.79700060813658, 20.573951390481767, 9.587059136359922, 4.76135338506391, 3.7141744407915303, 5.166661210598485, 5.071318687931185, 11.48599228551311, 9.155115965873964, 10.562753619686251, 8.7773750482067, 5.102108803487593, 2.904027512957973, 3.310922182375385, 1.169833420745788, 0.9339542747024567, 0.7458972173833078, 0.4298381140876201, 0.21027244266963777, 0.09836178242919907, 0.15281580238332673, 0.5224085322791531, 9.289427726499497, 45.50113747196813, 67.71466901225429, 55.46465196917134, 70.01807305120653, 48.18983985531715, 24.502879765725908, 42.1271970195155, 30.349162701637518, 53.63324634490475, 53.62421704876808, 56.464217016773844, 79.51830464024698, 89.89546837345247, 96.32567651810186, 79.95462125347507, 12.139461117406046, 0.609721411620417, 0.3035598272277463, 0.25076328446307494, 0.24525292127603487, 0.18668586718699626, 0.4194761007543533, 0.149225837761356, 0.41023619172553866, 0.20851122185347543, 0.5713849010006075, 0.4333774709413129, 0.3352375935402609, 0.20770093065596398, 0.21229201897738442, 0.32371838907560996, 0.2163908651639377, 0.309031686835712, 0.1773855597862313, 0.22555139216203846, 0.24833860086096873, 0.12808298316573904, 0.16442603341514067, 0.12912376723702879, 0.10526505434104513, 0.10848592546197677, 0.09649008407347626, 0.20709112466823673, 0.19877432094466305, 0.2075997610846835, 0.1822614183108653, 0.19459186392205377, 0.16052653862824365, 0.21755839848229963, 0.22777215848045967, 0.1714805693876359], [0.04698684604297723, 0.06365241467832558, 0.10981413806157728, 0.056294438939902096, 0.020857289576181964, 0.03416163786765068, 0.040601246554644844, 0.0712353291530763, 0.06566438373298415, 0.004001371074287642, 0.04290630169693501, 0.042442818502745325, 0.05647570683410572, 0.05717039919428288, 0.0048579928754348195, 0.08188544517202724, 0.03858551983871768, 0.21050730990546368, 0.059038791880612417, 0.10897371662600387, 0.17013959376321686, 0.0655979026229151, 0.19061989721751985, 0.09375402403454627, 0.15000524029376047, 0.06093213605063577, 0.0592706483908959, 0.027304949847260312, 0.04191911696726757, 9.533247159373376, 64.84896967487951, 72.34311288402927, 79.87942941727178, 70.14742497474917, 61.9561275359123, 45.20360216017693, 21.70586113006838, 23.68170411356034, 30.05604397866034, 18.07206169251473, 49.58320694585001, 62.585687560419885, 54.234145610563225, 43.75069741279849, 30.16507214115512, 7.757703931100908, 2.307138135356288, 0.2923751886813872, 0.077035671941215, 0.012971211127155732, 0.06177628833440043, 0.2404699892166161, 0.4561582598234377, 0.23456495285274523, 0.6133948338608588, 1.1146831800860744, 1.4617961476887427, 1.1467317635974577, 1.7258670229104258, 4.9558539159836315, 13.533180240661869, 5.8290200944869754, 10.449998224935225, 12.265937943612377, 18.69984096096408, 14.469297028356984, 21.88492125080478, 34.01298199930499, 47.76595323316513, 53.08620122171218, 58.293433958484286, 65.04289557856899, 64.43560284952964, 70.69479173229587, 72.52328303552443, 72.16072267101657, 75.98710460047569, 79.61445762265114, 85.17810436987108, 80.1987652624807, 81.69674981024959, 76.92562580108643, 76.6709541505383, 49.024386867400146, 37.96369521848617, 50.914655500842684, 47.383718259872936, 48.33511660175939, 52.01187579862533, 50.55511928373768, 44.45226430892945, 28.203600721974528, 30.33401450803203, 47.45397575439946, 59.64823630548293, 78.4421710045107, 74.1871524626209, 78.18521653452228, 71.23095620063044, 72.18821848592451, 63.204970975076, 60.41271409680767, 56.27531959164528, 35.82350492477417, 25.005143188661147, 12.446240475100856, 6.598648448144236, 3.559322208166123, 1.8312471359968188, 2.171573667756973, 1.3869929938547074, 3.283529819980745, 2.817807442718937, 2.587124272700279, 0.9822627986150404, 0.6396933452736947, 1.5342598528631273, 0.15396421414709863, 0.22941619848772404, 0.05138016493630506, 0.062427742692131194, 0.047467654315574516, 0.10523264116096882, 0.01230699853265598, 0.07983914771748167, 2.2563059339600224, 17.9832866884047, 41.380165930717226, 38.70390530555479, 40.65602971661476, 53.36306956506545, 28.29139905591165, 21.437469028657485, 40.07230650994086, 46.24823916342951, 36.78539952924175, 50.84284867009809, 60.18119619738672, 73.18817184817406, 75.62662309215915, 59.14760458853937, 4.432918131351471, 0.1323609790133853, 0.02314968703074321, 0.03225175768978173, 0.11847951179069859, 0.02175861883217529, 0.044987061616754344, 0.021356560567754413, 0.04700083480847459, 0.10145038080912444, 0.0891700909743386, 0.12176801315358571, 0.08407739126273701, 0.09494034182881156, 0.06380742873936411, 0.13501636233300934, 0.03104414265122145, 0.06911967775874561, 0.11120986598994463, 0.04579387477508957, 0.11848554090266267, 0.04345102851549464, 0.0691225199449447, 0.005255582932037332, 0.06330917281429134, 0.005446120011319797, 0.031981522089711605, 0.031186255791615096, 0.0772946096596218, 0.08175894107309081, 0.056500443813180735, 0.06107743611679443, 0.031237872880733306, 0.03924959932544059, 0.0795998678152119, 0.03752886625607649, 0.021712203480062947, 0.03883622211193846, 0.04438939046174769, 0.057361044004679694, 0.0621673570675475, 0.0636814992063709, 0.07624159882506056, 0.010662716250085543, 0.006234349791831788, 0.052171476305492466, 0.09356342901986453, 0.006445275343609073, 0.029039912999817924, 0.03934868513756702, 0.0579625187862304, 0.08286431401727662, 0.016051622900000263, 0.041796060263990395, 0.09494677696737552, 0.2460985904138896, 0.00908845248857453, 0.1257810268491026, 0.07463326617594689, 0.16474310188524185, 0.10298161436953854, 0.013263117439383942, 0.026512108217444152, 0.10141458152042282, 12.199416506674982, 77.06457184207055, 85.52375147419592, 86.75249668859666, 78.63563799089002, 70.47833965670678, 61.28321355389011, 40.472396112257435, 36.34392107686689, 26.890277439548125, 19.652904348988688, 40.10199492977512, 52.325308476724935, 49.14531353981265, 46.865490790336366, 32.6322723973182, 8.975077213779572, 2.909471517609012, 0.2953529417995484, 0.13068169896160403, 0.12592119029572896, 0.30013991880320734, 1.0836985394839318, 1.766534769727338, 2.258287956637721, 1.4065918518650917, 2.445447281483681, 2.8143229071171056, 1.4679623587477593, 2.5118826714254197, 3.587087195727133, 8.01419948377917, 8.189339195528339, 10.857972771890703, 12.51072031836356, 14.62471898524992, 15.081313271676342, 23.103472225127682, 34.742056477454405, 49.680128712807935, 56.889613751442205, 64.2497334941741, 70.28078556060791, 67.76503224526682, 72.85319359071794, 73.86519647413685, 75.12938422541465, 79.55751265248945, 81.71669898494598, 88.35365526137814, 84.6261013707807, 86.15602970123292, 79.07235468587568, 77.03838609880017, 53.62305602719707, 45.507954551327614, 58.20691823959351, 54.26918806568269, 56.64899987559165, 57.94023236920757, 59.37385866718908, 54.164547074225645, 36.43005632585095, 39.09045096366636, 53.63208140096357, 64.29174600108978, 80.82011576621764, 77.76951589891988, 81.49440257780014, 75.62570525753883, 73.71070215778967, 65.90011781261813, 65.1803550412578, 59.27951389743436, 38.35935646487821, 28.667595540323568, 14.716413213360696, 7.9244100566833255, 3.6289729610566175, 2.5264702112443986, 2.180030788144758, 1.9047891252463864, 6.157506339011654, 4.101091498328794, 3.1853744676036224, 3.4432999693578292, 3.2249452990870324, 2.566247457458127, 1.7986434145319847, 0.9090440371824849, 0.5015349652497999, 0.38219847686348424, 0.09106589045615927, 0.1158484900670667, 0.020398107965687112, 0.04734765813355485, 2.111427798386543, 18.866198485897435, 39.289283752441406, 39.318168086390344, 33.295341230207875, 31.036359994642197, 21.7870718433011, 11.461990321836165, 41.14753407816733, 46.510194655387636, 42.83897776757517, 59.32346797758534, 67.84810020077613, 82.23238868098106, 86.77986698765909, 79.09510443287512, 8.262532584128842, 0.080482684556515, 0.054381594001766176, 0.006712075518143754, 0.07295566385671978, 0.023265291613736944, 0.051256012727296164, 0.04213140759196493, 0.04860097414723808, 0.10779357350040829, 0.07564863144990898, 0.07799473741362173, 0.042090747475383744, 0.029529272728869994, 0.06504065026679347, 0.12711110104235912, 0.07750823327730741, 0.023440988133511236, 0.05519052156277242, 0.030495694560569622, 0.09258252238073657, 0.04220779804933456, 0.02101420353527271, 0.02054322417074394, 0.02468839760929827, 0.014674035933679871, 0.016001998597095092, 0.09129364073516862, 0.10391749036047729, 0.06763690692042151, 0.13132040178583515, 0.05068353437367947, 0.06890107456955218, 0.07165873062706764, 0.02784885312130134, 0.1997175896840711, 0.20034688494859204, 0.2768087417127625, 0.1309892372979272, 0.2034860221488822, 0.13173255708909806, 0.1329374295328894, 0.14553061265858913, 0.11700539774591885, 0.14408324274324602, 0.11183120160093231, 0.21317989955986702, 0.15862187550913903, 0.1933723438771502, 0.14949864167119228, 0.22765267940778888, 0.20042364695860496, 0.3480280136629459, 0.17887797567152208, 0.18985221583035686, 0.40912220795308396, 0.19690486722655837, 0.2771783944579863, 0.3443360827382534, 0.29455455560838023, 0.38374716956769267, 0.15650244730134166, 0.15798527176582045, 0.4025623502750551, 17.64840845138796, 94.32342421623969, 93.28849900153376, 100.9784233954645, 89.74907767388129, 80.25468257165726, 62.5888450684086, 35.83771567190848, 35.66445673665693, 46.08848494868125, 29.027926037388465, 68.96134730308287, 80.8651916442379, 71.10670335831182, 59.21801505550262, 42.49727264527352, 13.986617019099574, 3.862971269315289, 0.7930314204385205, 0.27955780226376753, 0.3020004399361149, 0.47913862993159606, 1.2552571272657764, 2.421242335150319, 3.8674001155361055, 3.6986484739088246, 3.9139738486659144, 4.992881580706566, 6.238670964394847, 5.633728225384989, 11.580699874508767, 21.407362876399873, 9.96120814354189, 17.62034389280504, 19.305976590802594, 28.582835082084905, 19.102903719871275, 29.25376238361482, 40.949599512161754, 54.6147684897146, 60.4847131236907, 63.80939645151939, 69.8930278901131, 67.20509036894768, 71.05247266830938, 73.88698916281425, 75.04007970133136, 82.99384624727311, 82.7487922483875, 89.48569051681027, 83.63574997071298, 86.1316482482418, 84.90124779362833, 80.09126094079788, 60.81343127835182, 53.57110815663492, 66.63047882818407, 58.63020866147934, 62.96435709922545, 66.76099961803806, 67.96501036613219, 60.86434756555865, 40.42980701692643, 44.59189284232355, 62.940516933318115, 68.33543900520571, 85.91232499768658, 79.30845783602807, 84.667035225899, 76.7521942815473, 77.40410789366692, 68.07279709846743, 65.3499073366965, 60.517406079076956, 39.256622176016535, 30.69736130775944, 17.860092886032596, 9.624661918609373, 6.7586301603624905, 5.951472568896509, 7.610606224306169, 8.369131818894418, 14.594537327366492, 11.335439951189104, 9.848414505681685, 7.168574717737014, 6.096346291803545, 4.811572961268887, 2.2652609502115557, 0.7694742167668959, 0.3829359130993966, 0.26289204976731734, 0.36587063042867574, 0.22751642300957636, 0.12795129265155525, 0.22741882340802302, 3.921996811705251, 29.082615644701068, 59.88175069132159, 55.35775561486521, 60.27746292852587, 76.90530792359384, 44.25692635197794, 33.97917901315997, 53.14523289280554, 57.01755754409298, 50.659234677591634, 66.03622405759751, 80.77573807008805, 91.99631337196597, 97.20967677331741, 89.19369359170237, 11.83022733657591, 0.24098524463272866, 0.16105700855053243, 0.1622931527033929, 0.27169669828107285, 0.10739267202875308, 0.08962690920358704, 0.20030432110351903, 0.18488670969682355, 0.20208962772402073, 0.245244785422279, 0.2632888833120946, 0.2604358186644893, 0.2679728674552133, 0.16765682537469173, 0.39152878426736404, 0.24151314049959186, 0.18229645917252188, 0.1971945403924873, 0.12113471124922076, 0.19769490305935183, 0.22431535526148735, 0.21279936836611843, 0.09706531651318075, 0.16308833664703756, 0.07274921848288468, 0.19204379419886297, 0.19151818127401415, 0.13897290002674828, 0.1853614237399832, 0.18062145389135809, 0.19622258932119419, 0.16504271887242794, 0.13516827756839414, 0.1470084422298016], [0.06445912824523065, 0.03523546331111462, 0.11804255056044749, 0.04697938434659474, 0.03999853454109642, 0.08078360389317236, 0.03173801912775925, 0.04255509634892787, 0.03605938704323865, 0.030369458592406688, 0.030452025633665825, 0.02189436961235779, 0.035128038631932396, 0.04008876437681817, 0.10582504163105642, 0.0848777003345951, 0.02764033164919144, 0.03424367056258264, 0.08676641350311619, 0.09168902637376901, 0.08633326739072801, 0.03049111527000224, 0.08764860971320061, 0.06045805786045329, 0.09003957012487997, 0.021869663276799747, 0.05381914373907832, 0.07515610586250983, 5.735007745604362, 61.38330459594727, 68.36706899827527, 81.75447925444573, 72.72399071724185, 61.141859177620184, 40.231770469296364, 21.556656129898567, 24.585682961248583, 29.382400435786096, 33.43010602458831, 28.00630157993686, 48.13326358795167, 56.250973439985714, 36.83501358955137, 21.572210288816883, 3.662166999232385, 0.2479966498550869, 0.03154179145161423, 0.06796412605551944, 0.01712810188051193, 0.04430539658172958, 0.371321652445101, 1.4236180027646403, 0.7061450988534959, 1.1063530464326183, 0.8697131444369594, 2.165433197252212, 1.4522342672271114, 2.5816638431241437, 9.4036598936204, 32.414476909945094, 36.88716542336249, 39.98017395696333, 39.539448599661554, 45.886765295459384, 46.54572348440848, 57.2863575720018, 66.15882165970342, 72.95227266127064, 74.46939837548041, 79.41891962482084, 78.16373763545867, 77.02837621012043, 80.00551792883104, 73.9607689457555, 73.12662986017042, 75.49843219018753, 74.72563112935713, 72.4367633942635, 75.4929957851287, 78.9853016022713, 77.59131477725121, 78.8015385596983, 76.19715536794355, 81.48730308778825, 38.2100789008602, 39.462589756135024, 58.32209079496322, 50.195394792864406, 57.17849239226311, 53.8783944806745, 32.79318959482255, 36.967150395916356, 57.97274881793607, 65.41661508621709, 75.68559200532975, 73.87388060169836, 71.04410233036165, 74.89586199483564, 78.6070203781128, 73.86623197986235, 74.02205205732777, 66.62425794909078, 68.49321242301696, 66.10569707808956, 59.240105844313106, 45.3551233199335, 29.586549997329715, 10.480294612146194, 7.166081070899964, 2.9571425337945265, 5.459288166415307, 1.814885336545206, 3.116317708646098, 3.3896277268086714, 1.0596075870337025, 2.0243012929154984, 0.602764597823543, 1.4196876652779118, 1.1602900489684076, 0.2602191996430197, 0.29331861063838005, 0.09269270880688583, 0.14139053561995107, 0.07315109288620372, 0.07355069200838767, 0.07648934399889362, 0.3794206726935602, 10.403081774711609, 38.325529944512155, 55.375810284768384, 59.352446448418405, 46.87981920857584, 62.45773984539894, 125.18293826810776, 137.90926441069573, 79.89408339223554, 40.55438541596936, 52.16196137089884, 55.271459548704094, 68.2138769088253, 80.18236191042008, 58.057122922712765, 4.637962483590649, 0.10802289425966241, 0.043101857130926464, 0.028688586992962707, 0.0163939502465749, 0.09304797442089166, 0.13453490671611604, 0.115427601361467, 0.025454466381380637, 0.047836004711327054, 0.14113251720705342, 0.08293619604721185, 0.19756734941995915, 0.06143849718594744, 0.02552437381969104, 0.07877221706533626, 0.03391865393026702, 0.06304953795587344, 0.03161139820041436, 0.08629095635466999, 0.05580259134031593, 0.10592706155993285, 0.048508595434888724, 0.05094606504445115, 0.033129230967812964, 0.058496547186927456, 0.09666479042460842, 0.056961287834471276, 0.02195147763667328, 0.021549404050493916, 0.029969905435498205, 0.06828140903023944, 0.018826447945508747, 0.05659258120783395, 0.08885155161542278, 0.061745081742804866, 0.10694647943901439, 0.03194063406197294, 0.02355656015776819, 0.05998633539063796, 0.017522775057342746, 0.03954162821173668, 0.09331664145593682, 0.03822589901486232, 0.0030404674696675954, 0.01622452415646084, 0.029587757796229377, 0.0669667255433817, 0.04526276899982364, 0.033869111024203806, 0.0816566913178371, 0.01076106661780467, 0.043118783843613444, 0.07445740303204906, 0.05220990327577438, 0.038338211335001454, 0.048862045420514005, 0.021564095701661803, 0.15617791713485796, 0.06240673656124742, 0.042906320849133116, 0.1131029075552379, 7.257905717818969, 74.53132475576093, 80.96150936618929, 90.80476007153912, 84.26574537830969, 75.32812287730556, 61.04548262011621, 35.73467108511156, 24.97244042734946, 34.12301624974897, 43.07191948736868, 25.42141845149379, 45.36534109423238, 56.782662483953665, 41.553315039603945, 24.42421663192011, 4.404526054859161, 0.18914867132421465, 0.10810799896717073, 0.0435758548818769, 0.08820512662491492, 0.15148575117270793, 1.7374443887702882, 3.049363094952799, 2.1836577548134715, 1.2313831309157035, 2.042653940377697, 1.7071967860383375, 1.7531798347350092, 3.895131762950651, 11.632063311915244, 30.31692670237634, 37.49474448542441, 41.64725188286074, 43.33597736973917, 46.621727251237445, 47.97366234564012, 58.057264128038966, 68.0303256742416, 76.3737718520626, 77.98909802590647, 83.10979935430711, 81.04489111131238, 81.29730347664126, 81.36182646597587, 76.4748199524418, 73.83267218066801, 77.54347755062965, 76.86580965595861, 74.35342957896572, 76.26083112532093, 81.05468919200283, 81.21056418265067, 82.10381338673254, 77.56903571467247, 82.23465581094065, 43.49130715093305, 45.315464235121205, 63.74098639334402, 56.13646768754529, 62.409757491080995, 61.24248758439095, 40.383111200025006, 39.62650952800628, 59.07002010653096, 68.26927646513909, 75.52050728951731, 75.65321676192745, 74.59500835787865, 78.65648931072604, 80.42809055697533, 74.88957835781959, 74.37030361544701, 66.5011582836028, 68.51302039238715, 68.78386005278557, 61.587487497637355, 48.105426526838734, 31.773116434774092, 12.203417324250745, 6.73458505061365, 3.329061918681668, 2.580950216900918, 1.626423784802037, 2.426178638012179, 2.1906155492028883, 1.08469077656346, 1.6151173076322003, 0.7241176441311837, 1.8766316555200087, 2.1613105410529725, 2.449211040812154, 0.8879863639031688, 0.6122133424205165, 0.6405261747779385, 0.12217180277671545, 0.015038145075161612, 0.11605441450111328, 0.2980435958072063, 11.68529183633866, 36.61862427188505, 49.783589070843114, 55.468923430288996, 30.29917601616152, 48.02001299396638, 114.23976867429673, 124.03658636154668, 81.80191639930972, 50.5889654159546, 60.678164420589326, 62.37655070520217, 77.49466757620536, 90.19971093823834, 78.41203935684698, 7.722482027546053, 0.026436784537509087, 0.0724261592052156, 0.04466391423897398, 0.020595894630758033, 0.050886593638889255, 0.12357045716095356, 0.07169296709640373, 0.08603555030159413, 0.07686596048334915, 0.07997559563767526, 0.02983110562537707, 0.16540682514108, 0.04628844964768618, 0.006203642593801863, 0.06923187899613573, 0.01065893752139903, 0.09160487927616605, 0.016094722049010378, 0.06906075027560996, 0.005445676159128668, 0.0739062104314085, 0.05876926299665244, 0.0676150504319418, 0.0660855329084781, 0.08960845414549114, 0.04922899004492549, 0.11142588746283325, 0.14082061216956185, 0.028018484139935147, 0.06683230775618745, 0.009528532654287354, 0.08642689865683356, 0.024946929301105203, 0.2098155325098384, 0.14272170531893932, 0.19125478492388803, 0.13671326240704906, 0.19227755826807794, 0.1651263450302424, 0.13714394171632108, 0.09636619999524086, 0.2189590676777786, 0.12886391021311283, 0.14403694038910253, 0.1156472540911167, 0.2159568916765913, 0.18706607662381666, 0.2012430086371399, 0.1916856174507449, 0.1399823281192972, 0.16412090059489975, 0.19042266022053458, 0.20350523563402317, 0.1738897014048792, 0.2559513238168532, 0.1263682945300975, 0.11701747895248475, 0.16059668163859075, 0.10173047021512063, 0.22406295993395392, 0.2833283950965251, 9.485861005321626, 90.14914374197684, 90.35822960638231, 104.23727758469121, 94.00176632788875, 81.61940067045151, 57.68883589775332, 38.05565126480595, 36.93879165957051, 47.35903478437855, 54.027201360271825, 42.379562316402314, 65.37890541938044, 76.7074243484005, 53.213823380008826, 31.796807550614883, 5.983079027745032, 0.6332355305071801, 0.2164332451479089, 0.21802384286157547, 0.1742099414789869, 0.5215370306564916, 2.3497279661317028, 5.561226154527357, 3.6345111025917918, 4.369479187073247, 3.500165266375388, 7.870520612885875, 7.088618672663166, 6.12205840887562, 12.901711983065452, 37.99356014497819, 40.61046746469314, 47.04314670255108, 49.64900862786078, 49.78377734461139, 51.40346519408688, 62.02734993350122, 72.13267772428452, 78.47281256029683, 80.2786482534101, 86.71331221057524, 83.28059504109045, 82.22117854702859, 82.75651147288661, 75.54566537180256, 74.2642427259876, 77.13271125670403, 77.93260805068478, 78.5942256066107, 80.71690251750331, 85.25939941406251, 84.40138093886837, 81.504255571673, 82.53181457519531, 84.90043194063249, 49.690181747559585, 49.921327021814164, 71.04367871438303, 61.747245634755785, 70.12775821070518, 66.86539742254442, 46.99713730042981, 46.091968013394265, 67.11853150398501, 73.42070564146965, 78.82687707101145, 79.83904469397761, 76.76060384319675, 81.92840499262657, 85.5371581354449, 80.21378009550034, 77.45363958420293, 67.55671516541513, 69.89598535722303, 72.6755416008734, 65.01252466632475, 51.59386488699144, 36.01994899011428, 14.778032668175237, 11.563002140291276, 8.27297491412009, 13.159142040437269, 8.546120928179834, 9.5755293292384, 10.356271228482647, 5.409343156122393, 7.269900816102182, 2.6194764721778134, 6.656774542024059, 4.222914922621943, 2.1215411395795885, 0.6672038690697762, 0.36258564540936106, 0.5425871043435989, 0.2237372959573423, 0.13429357369820918, 0.26246389854819546, 0.9837576506599304, 18.15812045528043, 56.67685654855544, 77.4994214888542, 81.88565900248867, 67.2160259369881, 73.74259887203094, 129.53557675884616, 138.98804172392815, 86.64650640180035, 55.729109933299405, 70.00017135374009, 76.2565714313138, 90.07270459205874, 98.38940805004489, 88.863171146762, 9.07892196409164, 0.16428482808893727, 0.1334365971025921, 0.11455478972845501, 0.19651515829947688, 0.3200394510021133, 0.26018873998715036, 0.17745682128494789, 0.1471545351969619, 0.11232827008972246, 0.29592710937703814, 0.2750340837144083, 0.3912568230542445, 0.170923087205137, 0.09130354625202956, 0.3116791334844405, 0.19127799738799373, 0.15883843324357466, 0.1321538901256938, 0.16115768782554135, 0.14973589910134194, 0.25062515881032715, 0.12773420631645188, 0.1808216173442141, 0.152255455031991, 0.17209759192360988, 0.13424987604300823, 0.2355827313036688, 0.21001788697415785, 0.17359120290606253, 0.15352601185441017, 0.13460054512946837, 0.11913777283963659, 0.11416246078067249], [0.014963402664439093, 0.03289624447784117, 0.06300214009599821, 0.016782262978414376, 0.06177529242009886, 0.14507407022099342, 0.058620032899442225, 0.03045734036864052, 0.06482462113302562, 0.06400210317224264, 0.04677339096463496, 0.04382644224190905, 0.06500474372578245, 0.024517607882678993, 0.05629618178992983, 0.08339263123249815, 0.09680164437140189, 0.043889529582473545, 0.02209539108368899, 0.10205984971816502, 0.040729826751856074, 0.10290883601673188, 0.21265094649166832, 0.06306335052114821, 0.03688824438159505, 0.05544723379575918, 0.02232243081614856, 0.371988179582742, 35.958807083868216, 72.80621144079393, 80.90621179149997, 75.06911308534684, 47.36323172046293, 22.354436805171353, 13.790287683087012, 27.38894993259061, 33.880335284817605, 23.174490659467637, 22.310265033475815, 46.499196329424464, 55.527131403646166, 43.83572263102378, 18.70915659012333, 2.3594360774563206, 0.1392166998477713, 0.028806091474008658, 0.0756012948770677, 0.040596071630716324, 0.3711253194318664, 0.17520698959067946, 0.7860993053163252, 0.6848949230005664, 1.0621818876074207, 2.0722570486607093, 1.2124070717442421, 3.139603594618459, 13.631958269303846, 31.624980280476233, 55.77720603635235, 60.407246312787464, 64.7728874606471, 66.48845764898485, 71.58406365302302, 68.09731975678476, 71.61020232785133, 74.32827149668049, 74.77579039912071, 73.07996149986022, 70.49280535790228, 67.95940137678578, 67.24043876894059, 69.07803781570928, 73.20774447533393, 78.26613503117716, 71.95333127052554, 71.47539046502882, 70.71954188808319, 68.74139647330009, 73.0188980410176, 77.42234691496819, 70.95687666246968, 71.51574380936162, 74.85875637300553, 81.07948641623221, 70.98894596099854, 26.552541755860855, 47.50438605585406, 53.633552289778194, 57.72781249015563, 45.444325862392304, 31.36480162220617, 49.84497024166969, 63.05125328802294, 75.17424045070526, 77.26607968730312, 69.58492571307768, 68.86789291135727, 71.07991357003489, 73.34602371338876, 62.1513831230902, 63.94398081687189, 66.0704271255001, 64.88952698246126, 61.339891802880075, 64.42438487083682, 60.7398711481402, 60.57585723938481, 48.53897786909535, 31.090625985976192, 12.325492270531194, 5.26336528601185, 3.454859929700052, 1.9707640044150816, 2.089996212913144, 2.3934430268503006, 1.7638668225657557, 1.7428148489805961, 2.2487340434905025, 2.2748300625431925, 1.69904058498721, 0.9110270404527265, 0.3249437007452211, 0.15145195137348869, 0.07950347863257894, 0.024212367810128678, 0.019132034672844796, 0.12241086051348718, 0.0768796274919183, 2.8892423837415637, 22.099031671400994, 41.91323564898583, 55.08462921265633, 58.74244336158999, 87.5148799342494, 103.40740603785362, 60.581748639383626, 35.30151197987218, 29.148360452344342, 53.59872164264802, 68.57409169597011, 73.77175777189194, 81.34932979460686, 42.93096127048616, 1.5535245739644574, 0.05137307862300546, 0.04696985804325631, 0.06645156205782006, 0.05611759520346119, 0.02835694561532188, 0.06935675132779345, 0.04999639947087534, 0.0551531671155845, 0.09498862068979971, 0.0669665799866761, 0.12072353653850094, 0.04844161636766888, 0.060338241709095825, 0.005580722617225782, 0.016042069783584488, 0.041930133311618725, 0.05989004579943515, 0.03833955581930857, 0.09554258652872617, 0.02868490977092616, 0.07707317960598777, 0.04673593309557727, 0.05440459962213232, 0.06254897610614858, 0.03507500236493445, 0.03588355071241817, 0.07358262255307167, 0.13729581098643043, 0.014939658726835925, 0.01689508474702316, 0.05366711742094448, 0.04128312609428841, 0.07557402214696331, 0.12203690235412891, 0.06350869275329095, 0.024382431668439702, 0.044210642996814944, 0.09155432513404278, 0.06374333399317919, 0.020495906750100757, 0.08121236032175441, 0.04029934279500477, 0.04712459248220248, 0.023869374924669826, 0.039605489301104704, 0.15820777434254849, 0.08104044253066664, 0.03265079756778094, 0.03310760047527091, 0.08193746254208588, 0.06926694284043006, 0.027535124794550003, 0.06119996804984347, 0.08213908156199802, 0.13473173002562217, 0.02104913331418028, 0.15858046079595245, 0.022227493370132103, 0.0863617045744773, 0.5106132910136254, 44.600000381469734, 85.77903501449093, 86.93803264248757, 81.69771471331197, 56.324533570197325, 38.46390724182129, 25.123424222392423, 21.87677448795688, 31.012768899240804, 26.495222199347715, 26.191632709195538, 48.87500732175766, 56.94665285848803, 44.73414936373311, 20.267675076761556, 2.2041756731848565, 0.03421832454360781, 0.06033302081989185, 0.03260100568314234, 0.10521138222107004, 0.4834727876849713, 0.9274436917997176, 2.2877307380399396, 2.305387777666892, 2.289991003851737, 1.9762018803627261, 1.5431637557283526, 4.228118927248063, 15.837951225619163, 36.059019719400716, 59.72738189081992, 64.30041051680043, 66.91947906248032, 68.96908221706268, 73.1232487770819, 67.31852531433105, 72.54316945229807, 78.36399032223609, 78.5041444532333, 77.83647075776132, 75.61163963810091, 73.57800053011987, 71.18756694178428, 71.85588390596452, 75.67078113555908, 79.51136988978233, 74.23075352945636, 73.4838322670229, 74.50336610117267, 71.79909583060973, 75.15063562700826, 79.57084086633499, 74.47702346309539, 72.44640458014705, 75.19035354737314, 82.66660290379679, 70.22600573878135, 30.468842060335223, 54.708215036699855, 58.276073548101614, 62.07463410592849, 51.48787852256529, 35.74359839962375, 53.44567468089443, 71.15714503872779, 80.2445314776513, 78.89423985635081, 73.93276322272517, 71.91446842685824, 75.2847336184594, 76.75921532415575, 68.04446974108296, 64.18809736928633, 65.95874155721357, 66.26221533744567, 62.735118096874615, 66.81689339299356, 64.3103458804469, 65.40911551444762, 53.588609772343794, 34.781586124051, 15.543464576044391, 6.181653920681247, 2.67401457794251, 0.9864920942533402, 1.4929593787077935, 0.4870185183901941, 1.0761606020312156, 1.8044762241263546, 1.3084398089878022, 3.3721111570635154, 3.07464252556524, 2.6850288385345094, 1.5172305150378136, 0.6626054416260412, 0.5113086843442533, 0.05415890373349671, 0.015237431357344313, 0.1133291639627949, 0.01575706209311442, 4.037776844155404, 24.792178100155247, 42.750387114863244, 53.557521066358014, 61.62763295635101, 96.14827555994835, 118.05339505595546, 73.51856877726894, 50.59723377227784, 43.653559915481075, 62.52192158852855, 76.4783343961162, 82.10535880058043, 91.8233290026265, 60.6995491827688, 2.64120664808058, 0.07187188693111943, 0.06865394992693778, 0.029794147628689968, 0.02116453679909389, 0.044653709947822556, 0.0390554343410317, 0.07313305917646616, 0.012609413655985509, 0.0978904085293893, 0.06007922738189659, 0.06225775927305222, 0.047089379250762925, 0.09377882230065523, 0.08004652005770514, 0.05644600560528137, 0.056903436704869234, 0.03321425523608923, 0.07389658836707955, 0.07136557942196246, 0.02636177112318335, 0.03502503428007326, 0.025308407888176943, 0.06293922512521667, 0.029108797710749413, 0.041461697358998566, 0.038906250209096944, 0.12924669370535882, 0.04155528649026829, 0.04628572620511536, 0.0388487744625778, 0.03803538826985225, 0.024805668433527314, 0.13801211851739115, 0.24089412613501474, 0.11137501922466102, 0.10333700255761225, 0.14835216044898958, 0.30322575160572607, 0.16944657530515425, 0.13394809868787566, 0.1517921250553862, 0.15388665540564447, 0.2174665292184199, 0.11266085184029034, 0.20864980715897777, 0.24690050060950944, 0.13727843611230775, 0.16942484905162167, 0.1412468634906315, 0.20723868852421162, 0.19736934633504963, 0.1464351173490286, 0.17196098312495217, 0.1772681338291976, 0.3454591676352486, 0.16084083386005896, 0.2641395166996987, 0.10083564121516482, 0.1415083905862224, 0.8539116923366824, 55.730423927307136, 98.18178130734353, 102.05303515157392, 94.03605568793513, 66.24677688844743, 36.92798945211595, 27.65812650803597, 41.631809511492335, 53.10874308309248, 33.47769614188902, 33.196623017711026, 67.34830394867929, 75.06262548508184, 59.923574924469, 27.937426720896077, 4.460394334408545, 0.3173683782018, 0.13889714925279542, 0.26046116085302445, 0.17358478308925707, 0.9338975229090261, 1.5142248763192085, 2.817667953429684, 2.9533667622074007, 5.1835783931516834, 7.135649852214321, 4.670539238760549, 7.021488778052792, 18.779655310415453, 35.951982159768384, 60.989961470327074, 64.31509979309575, 70.27045403757404, 71.29164311193651, 72.62070686586442, 68.69100186132616, 75.01768296764743, 81.31511888196393, 80.3671447692379, 79.95022035414173, 78.60099561752813, 75.45655696622788, 72.91741847991943, 75.78711863486998, 78.00082591272171, 82.15416877500473, 74.746137280618, 74.26360730201968, 75.74239577016523, 73.41923867502521, 78.04003392496418, 82.00574628768429, 77.01768382903069, 75.27145247305594, 77.81743941768524, 85.41978513040851, 75.65931212517523, 39.329750845509196, 58.769911719906716, 65.15379275045088, 68.85430582108037, 58.471274222097094, 43.47938706797939, 58.987897442233184, 73.51543872587143, 83.25758641765964, 83.01792175539079, 76.57341264909314, 75.14616412501182, 78.23651329163583, 76.96342176006686, 69.31920082338395, 66.08103321444604, 66.14721928873371, 65.17715046482702, 63.94869158344885, 69.2099000561622, 66.85814888246598, 68.52323424431586, 57.45365450459143, 39.72709871107532, 17.70042496342813, 8.839131785977273, 8.17918319855967, 5.33562122814117, 6.500928969152513, 7.3957373153778825, 6.145333263181872, 9.167095864972762, 7.551051897387351, 6.049739708823543, 6.172984992304157, 4.050356620742429, 1.057478843196746, 0.3560266457498074, 0.4865764550143673, 0.15839040970369694, 0.1669439192741148, 0.21810832703786515, 0.20004987266034852, 5.606518743499633, 34.69413688105922, 57.89915730876308, 72.28159443024667, 69.32386844388901, 95.47437314064273, 106.22017691212316, 69.21215934138145, 47.94420534564603, 42.92556016675888, 69.35867555679815, 85.54413995435162, 93.14753686228107, 101.39999189684468, 68.75345383920978, 3.874489799622567, 0.1833146206674076, 0.15219027627139323, 0.2041102918766199, 0.18680743001882108, 0.1632787707832552, 0.11494208547857501, 0.14170916690941782, 0.13829161803568565, 0.18686036669438888, 0.30910578285974843, 0.3404627728366083, 0.21136070120959513, 0.13972939653021677, 0.16307863797391617, 0.13116767449725059, 0.16546330114285793, 0.10026367997089702, 0.14096094415553156, 0.18442728676863257, 0.16242206997929082, 0.14487314068021315, 0.1191438249342384, 0.13453334389675048, 0.21034212602723032, 0.13025910954081243, 0.3506860629685464, 0.38683343137944903, 0.20545175779731045, 0.17428359317202724, 0.0939745041391542, 0.21864046703182885, 0.06305025424808264], [0.00801445706935239, 0.12263102652204615, 0.07991436222988753, 0.007323022019268284, 0.021628127245592977, 0.06270479838994723, 0.0270201126113534, 0.038004748583320654, 0.04201859731467501, 0.05149116724609368, 0.10657189308755821, 0.0544756657684282, 0.07126669279269635, 0.056006569911034844, 0.045161499837113005, 0.026413596971260927, 0.11139174292404806, 0.073874800826513, 0.029802446276129737, 0.021763481575274662, 0.1048237187487464, 0.07221301822292228, 0.06513843372944864, 0.05284621590568174, 0.008625739212748746, 0.08593674028112043, 0.0774244922063043, 25.685964668950728, 76.2905470017464, 78.56169346840151, 71.20248763791977, 66.23504115689185, 42.294572399508574, 37.25454638081212, 88.43139663819345, 77.42775194106564, 22.725240030596336, 42.72841399715793, 53.67239552159464, 47.05806739868657, 39.24499627082579, 16.42108509617467, 1.7031963361847786, 0.03729436291201461, 0.10644631595501017, 0.10211968118505133, 0.1492222218263534, 0.08918906697222302, 0.1269013768122081, 0.9310598719504573, 1.3219819145817913, 1.4544837465209346, 1.2760069557735998, 1.178320449206137, 5.369923826186888, 27.202084295211304, 49.168173113176906, 63.71446332623882, 70.5389638100901, 78.71374022576117, 77.79210875111242, 82.50626425589286, 77.64203886831962, 73.91544203604423, 75.82993522767099, 71.75551045325496, 67.77388111237558, 63.38075983908869, 60.46636035365444, 57.38709972750757, 62.63819240754651, 67.25438671727335, 69.1677894899922, 71.86159487693541, 77.05023165672057, 72.3658783205094, 73.42623618341261, 73.41321391444053, 65.11604778228268, 62.650845973722404, 63.424623704725704, 66.51455710011145, 73.27173402232509, 76.10251642042591, 63.08921006418044, 37.72419137339438, 28.1398190606025, 45.94410642500847, 45.57114001243345, 35.40646283857284, 48.75285686985139, 59.371254213394664, 71.87015348865141, 70.40601899546962, 69.69301839028635, 63.95938396453858, 65.17196509145921, 68.14989520657447, 70.81249421642673, 65.8786153793335, 61.66470719921974, 69.58816559084, 67.07289864940029, 72.1264176214895, 69.15275896749189, 71.93397045135498, 67.72712645992156, 68.1175591868739, 68.41828730798537, 63.42120732030561, 51.37602429236136, 33.312152508766424, 22.11286390981367, 11.63450792912514, 4.610165626771988, 3.160977570279952, 1.7603908671486763, 0.8385895048418354, 1.6699133092357268, 3.347454647864065, 2.5410300493240356, 2.0899631179148153, 1.735392866596099, 0.1492079419474448, 0.06802107703181044, 0.03033646893116736, 0.06266381651643785, 0.10843430645763875, 0.15138916280721465, 1.979684822501675, 11.023485026051922, 28.85010930799669, 40.61329941595755, 38.140472519782286, 33.24694702702184, 29.256515887475786, 22.150981503148234, 16.06239316924926, 32.16950331964801, 57.30116451940229, 68.24575008884554, 75.20379943232383, 84.6078545047391, 26.94923850797838, 0.5623323157910378, 0.09879224723385227, 0.04743646304573744, 0.04860165596549069, 0.03258193009382775, 0.05281761784346835, 0.015605830591202024, 0.041473311251930656, 0.13701534619735134, 0.13104667857048974, 0.008401625936159925, 0.05558397665980363, 0.0943703034652337, 0.08281601983452998, 0.09584974948196642, 0.043214414599201376, 0.021739309586043802, 0.010120860346022153, 0.08573033321168154, 0.03918481893056343, 0.033283088236085834, 0.058028076760350704, 0.1222381383300789, 0.08096583322772095, 0.03461046579984888, 0.028048125996945367, 0.04710096250017805, 0.045811919976146, 0.07633486236896246, 0.08340986054991523, 0.04972954040333148, 0.00711878297865511, 0.04083248253370966, 0.05178458275153272, 0.08023171415252071, 0.012120750109334628, 0.02341780248248289, 0.06872334217111911, 0.01785779488272965, 0.03431949411488829, 0.10092507431944532, 0.05834476601692939, 0.032434948464675296, 0.00874607917672444, 0.055331527706115484, 0.044730801375642906, 0.02707083529282001, 0.09665892985198768, 0.11976509925819213, 0.04612398972254127, 0.07319092945826632, 0.05093463884306051, 0.032142785512992454, 0.015443917908405345, 0.022097947902136275, 0.09352870991513615, 0.01247589314927257, 0.06097586817979332, 0.11881569415451058, 30.12202020614378, 90.24386898163827, 88.28193864514752, 81.78696432421285, 73.66035461425781, 51.09085229135329, 37.422055121391054, 65.60504182692497, 71.6603066844325, 27.122536666931648, 30.452648555078817, 40.786577963059955, 45.62855958938599, 43.50200737676313, 20.458586638973607, 1.6356564313173296, 0.0443475658915216, 0.03884165750576123, 0.1529478606197142, 0.3136117588127813, 0.1623328667013876, 0.9960191023926582, 3.0909299225576463, 2.9793796760420648, 1.774007742924075, 1.8458106512984924, 0.7202840175840163, 6.004395148446483, 27.994620761563702, 53.43775933788669, 68.8045701672954, 76.36933957376789, 81.32427369394611, 82.24013143970122, 86.1746217358497, 75.35116287969774, 71.9796895980835, 79.07296657562256, 74.52438216055594, 71.17072428426435, 68.97998640614172, 65.63321228950255, 62.26710088791386, 66.06022111831173, 69.80979519505655, 71.02808337057792, 74.28919684502387, 76.78085896276659, 70.22055364424183, 75.5336001611525, 76.45549835697298, 66.42979468068769, 64.9600668876402, 65.83247261662638, 70.35217269774407, 75.73349198987408, 75.2479104072817, 69.81809493034118, 43.03417844157065, 33.11050345820765, 53.703025310270256, 52.689445634042066, 42.538939983614036, 51.99735126187725, 64.47969813500681, 74.86719731361636, 74.10632810285016, 72.924282627721, 65.41066877303585, 67.95824035521477, 71.19727088559058, 73.02386376165575, 65.90085521821054, 63.10789623568135, 68.75164170419016, 67.47175662748276, 75.45590585277927, 71.53757572174072, 73.78857689519083, 70.08757745065998, 73.58355460628387, 73.5285472869873, 68.56534481048584, 54.00129802765385, 36.31176548619425, 25.186142921447757, 14.922784797606932, 6.776498517682476, 4.261986632500926, 0.907586386367198, 0.2828598250785182, 1.5177091667729041, 2.558937140049473, 3.3663678265387014, 3.2924473285675053, 3.9822897699571427, 1.178318120298847, 0.6091511970566166, 0.016954713200609532, 0.06347009341322607, 0.1315703609537694, 0.021462709710542715, 2.109064325209587, 13.287295679892264, 30.989507282933882, 46.368946183112364, 46.032006740570075, 38.900718073691095, 26.288397581346576, 28.85249803143163, 24.532644671778527, 43.653006861286784, 64.75449938927927, 75.51756551188808, 83.6999434809531, 95.70343955870598, 42.03042038025395, 0.3271216274269166, 0.08637695738504972, 0.06742093141280836, 0.01991274146994035, 0.04951918415064293, 0.0024843185195594186, 0.005444129619131526, 0.06530049962983017, 0.09945279122480463, 0.04575326062378384, 0.031784449801630074, 0.011931242939505366, 0.01190598502064184, 0.047889132908875906, 0.02675068331882358, 0.04541284945462981, 0.007684821405658319, 0.10901621152316371, 0.03773353047548764, 0.02053322863855189, 0.061900666539346984, 0.06685990990409929, 0.08951607926358139, 0.06488315025044065, 0.07922165786787387, 0.04808255478799824, 0.026232168198593205, 0.06244928125412234, 0.07105804874651855, 0.05209289100621978, 0.04958015325809679, 0.0953105538182201, 0.17630248000064205, 0.2101194855546759, 0.1472728344942293, 0.12694270725572301, 0.06188560142031601, 0.24364200691061638, 0.18130327214396771, 0.17948136184244387, 0.10361164507846679, 0.13536566778296424, 0.18823963139326344, 0.14210903416237525, 0.1468679263827301, 0.1329010403564861, 0.14460994351294734, 0.17605437476548458, 0.2040244593855835, 0.2411742078801317, 0.2788735631733172, 0.15234887179347778, 0.16400667688538953, 0.17309931317164054, 0.13393230195487701, 0.24599141471328276, 0.1570118651274712, 0.26389553301757385, 0.3393450811986001, 40.72689517851799, 103.4393576652773, 99.22892862750639, 91.67999775178971, 85.14556438692155, 60.435542291210545, 50.02675248730568, 101.90389094814178, 85.83641144537157, 34.75003850075507, 57.493490096061464, 72.92878550867881, 66.40211843675183, 56.481879449659786, 26.148629803811353, 3.1828261527322956, 0.21858149358341772, 0.3440875025285829, 0.42564914531765446, 0.35538680911544834, 0.16858644242728912, 0.8482864006392418, 3.2610813600401727, 4.987258372768279, 5.3285639036086305, 5.723803004910869, 3.724807250884272, 8.908404765590545, 35.527746446671024, 55.05395235553865, 70.06772241284771, 77.16312531502017, 86.38693178853681, 86.42829710437407, 87.73377172408566, 76.4480144746842, 72.89114644450527, 80.57905474016744, 76.43490591356831, 73.93751713537401, 70.05036200246504, 66.50515910117858, 65.01805913063788, 68.50843121928554, 72.58873954896005, 75.04946985552388, 76.60719210101713, 78.91771131946196, 70.20395417367259, 76.17314261774864, 78.11036986689415, 69.10872643993747, 67.05679339747276, 68.57985758012342, 72.53609349650722, 79.2239699825164, 82.6855714859501, 74.21254588711646, 48.459953877233694, 41.629530614422215, 60.09550025386196, 57.662124556879846, 46.45313201412078, 54.92088202507266, 64.62145651540449, 77.85851447812973, 75.07071341237715, 75.50308412121188, 69.35038366625386, 70.5490521461733, 73.91144121846845, 75.97073262737644, 67.73840719653715, 62.728430455730816, 70.51247996668663, 69.35200752750521, 76.15643332081457, 76.18068925796017, 77.56994570455244, 73.62399424276045, 76.91717701573526, 76.1587396744759, 75.59320449829102, 63.31057294722527, 39.441306975580034, 26.86958693688916, 15.922164513218789, 6.4987618596323085, 5.171354816805932, 4.734624393524663, 4.3058215706579155, 8.241398853640403, 9.083608215855016, 7.029998850437903, 5.62084274907266, 3.951229991451387, 0.8255261122699707, 0.3586002415226352, 0.1683296497550703, 0.2732114992555111, 0.2512747860483585, 0.5164842211431073, 3.1207217949052013, 19.899876386888568, 42.12186259608115, 60.00492880421301, 52.990401252623535, 47.07056014768539, 38.9245621619686, 33.915511100522934, 25.968228232476022, 45.295742557894805, 75.47973032920592, 87.861295823128, 94.29195896271737, 104.10037117619669, 51.214524622886415, 0.8948360479647114, 0.1808902741439881, 0.11457744294837599, 0.09098696041732066, 0.11410587752658514, 0.14611801823541043, 0.09838818947994903, 0.09867063843675199, 0.2943859549780046, 0.2501585346556479, 0.08992823456684429, 0.14681626141311663, 0.10818836159042775, 0.1925946727034546, 0.15861433720396412, 0.24379733889814348, 0.038782695548668984, 0.16397673816930863, 0.27502378749270595, 0.23006743451039638, 0.13772146475891914, 0.12253667513329176, 0.3123044144482382, 0.16984609015766652, 0.2219876583905951, 0.11245056836595459, 0.22610345044203345, 0.14957554157703154, 0.17828675497683788, 0.25738608392496265, 0.17743711750353539, 0.1095561885965928], [0.05401810826433282, 0.10037322288318988, 0.03641999229007671, 0.02468848187896994, 0.012233724137918364, 0.032076269928966804, 0.07148190987326446, 0.013824137032873208, 0.05977679885202839, 0.014125285238297957, 0.034862830483865355, 0.06840650352739519, 0.02996595625224854, 0.05519782238069081, 0.060930642179183425, 0.029549983915902918, 0.04198587386898937, 0.05008160760025344, 0.0925407016409501, 0.07698693342747227, 0.038676971584678664, 0.02749384989240958, 0.037392395353245164, 0.044337484174438065, 0.10584951047935795, 0.014734421856701376, 8.340223950724448, 73.12165629479193, 79.85555002766272, 74.78286635491156, 76.04273949899982, 53.20177385883947, 29.629460727014852, 46.34438037872315, 91.00421259480139, 70.84759158472862, 34.18166745093561, 50.13648863761656, 54.5411769805416, 48.06863469462241, 21.52332578935931, 1.506239053222441, 0.09231999937084415, 0.019870489805696473, 0.14407978002582827, 0.05730501616433744, 0.03391042614596025, 0.1499789021909237, 0.3513612622214902, 1.442751447039266, 2.7255800174128626, 1.7170876552981718, 1.321379340464069, 7.544846217478476, 30.975790754441295, 58.08281052497126, 71.32626979581772, 73.78637252315399, 75.74313317575763, 75.05824027522918, 77.08273241596838, 78.08822416490125, 69.94830977532172, 72.57977301074614, 71.45551189299553, 71.08882519506639, 62.49808534499138, 57.099236980561294, 53.08613061904908, 54.381442377644206, 53.09441858722318, 53.18033026110742, 61.78640265618602, 67.68488253316572, 70.92881602625694, 72.99048439148935, 72.69861298222696, 71.73072107376592, 66.33363385354319, 61.365544103807025, 56.94935144916658, 61.64748799416327, 64.23511482054188, 69.80174649146296, 68.25884296048072, 69.127381232477, 36.5412712097168, 25.587213116307414, 38.29562187194824, 46.90291020178026, 71.63303836699455, 71.88164603325629, 71.38529362217074, 67.30393409729004, 62.16497413573727, 60.1012033800925, 63.48198444612565, 67.34925316226098, 69.54941257353752, 66.98266844595632, 65.27924583804223, 73.00267511798491, 70.62342028464042, 64.5054171162267, 64.98309512292185, 63.53493644345192, 66.57897026308122, 65.52521767154818, 66.82262005344515, 65.1367304402013, 67.84316585909936, 69.15983492328276, 66.64430910541166, 57.269762023802734, 50.6469694260628, 37.254326728082475, 22.05287910276844, 4.676766982001643, 1.3923938524338508, 2.1114775634581044, 2.2365810698078525, 2.872832412681272, 3.3236669436577833, 0.8346552449849345, 0.2649538681632088, 0.07692296508579485, 0.06292576112994744, 0.01075140912190921, 0.05729438669438805, 0.014170715209817695, 0.26036380639960693, 4.947137428868202, 15.459013985049342, 33.432400611139116, 53.43257396451889, 57.19811993260538, 38.400835529450454, 28.38042313052762, 13.6387655427379, 40.36871217912243, 60.21555223772603, 67.14966727841285, 74.96494277831047, 82.12782613692745, 13.040078493856615, 0.10205329200553317, 0.08940861244956333, 0.0059847123808257525, 0.01410529991957329, 0.10504085871000444, 0.05586119706652338, 0.07612679288872788, 0.007517353148995749, 0.010220013190841964, 0.06264276442027862, 0.0382705849234856, 0.058377914641413, 0.022844935339244626, 0.09824103165057399, 0.02272312735928403, 0.039001735407979264, 0.05886708093326419, 0.07370170326002183, 0.037760102235141306, 0.029390658695070498, 0.04961977532554058, 0.017261067931089672, 0.029112009534371958, 0.012645729096426118, 0.10215482163813808, 0.040627094361210064, 0.04420472496759988, 0.030182766795699156, 0.05198285013677613, 0.07041021415423002, 0.0387761301751579, 0.07823311333214084, 0.1280981670283983, 0.01432885969763682, 0.009148348115324494, 0.035264134151680816, 0.012478273767497272, 0.12952400221218988, 0.054933989360447855, 0.07111143741396166, 0.023355184370772015, 0.01747640758572567, 0.044046749976734, 0.04467333712044262, 0.0580505920844453, 0.06094410617445266, 0.019196246247438174, 0.030874737628525308, 0.057785832097813974, 0.07850884369784787, 0.008713488838815642, 0.01903843405025621, 0.051856602677294326, 0.08338716902559803, 0.09114898801330598, 0.10669023835010107, 0.03143055740022852, 11.767040894877526, 89.15313628412063, 88.55095832578598, 84.67690390925254, 83.76137564259191, 64.7788376961985, 42.77210920087753, 54.283355666745095, 102.91740002170687, 88.65843126850744, 42.98324254251296, 49.475428058255105, 53.69178379735639, 49.499742830953295, 23.21513229800809, 1.3986035772869665, 0.22519330734447127, 0.09875558992667545, 0.425978685699163, 0.599866456562473, 0.4538851237345127, 1.3013762331778005, 2.8137740204411172, 3.220787096408106, 1.8969463460868405, 0.8534311407035398, 0.753770640059825, 8.171597824942681, 34.031464207556944, 61.59741109417331, 75.22973414390319, 76.79681516462757, 79.48465854890885, 77.98563065067415, 80.21743574450093, 76.70832649354013, 70.48077152621362, 73.31614309741606, 75.35470870233353, 75.0845907580468, 66.9897993149296, 58.89838895490093, 57.02147599189513, 56.93417579896989, 56.703132506339784, 57.39515235347133, 65.48184017981252, 68.66942098063808, 74.4393059515184, 74.91778804409888, 74.76607861057406, 74.95013975328015, 69.34676724095499, 64.59597287639495, 60.23892171921269, 64.54515464844243, 68.04264191658267, 73.49171623106926, 71.47841853480186, 73.3814819397465, 41.609420622548754, 30.78337888563833, 43.047079117067405, 47.86844868813792, 74.25406025302026, 74.55892255229335, 76.28416138310587, 69.45925297275667, 64.90966050855576, 63.08942579453992, 67.4779696618357, 70.28721040295017, 71.51262160270446, 68.45897013141264, 66.20745120509979, 74.53825166148525, 74.95594486113518, 68.1624860148276, 69.48810592774423, 68.1167511786184, 70.92854930508521, 69.58875394636586, 70.4371077014554, 70.21781582986155, 75.08335913381269, 75.12437143633443, 69.41371425505608, 61.580697874869074, 52.09128418276387, 40.69124083365164, 24.907213372568933, 6.530889013121206, 1.2744583549999422, 0.30250231945706957, 0.4113728210570351, 2.1545961787623744, 3.7750491355696036, 2.8492749025744777, 1.381568723628598, 0.45495243743062025, 0.09418854144431892, 0.1412492077196798, 0.01824936348824732, 0.06336762915335356, 0.19367721622749684, 5.7379402076044395, 16.435805751431374, 36.642942966953406, 42.986862890182, 38.56523383048273, 22.645229562636345, 26.102977337375766, 21.722646913220807, 49.58477197154876, 65.65327913530412, 75.93758075468003, 80.43930069092782, 97.2587142452117, 23.530820338956772, 0.17286151947994388, 0.07842648924598772, 0.07795179052458656, 0.030347787880248604, 0.1699092770896612, 0.05434469920733283, 0.028955742919577226, 0.025712276035318934, 0.05175796119616397, 0.024187412495995243, 0.04877514423682325, 0.043255576503372965, 0.0916428848980896, 0.05970749853839798, 0.050900172547347126, 0.0444178851020913, 0.020293739977322763, 0.026484720574151126, 0.04436728116425295, 0.017719544740694187, 0.06827238451449141, 0.0545984045452168, 0.011680731230655746, 0.012984031608568565, 0.06192517752248434, 0.04695009297480987, 0.12476227546651518, 0.047492234246625055, 0.07474739795490619, 0.08513661507036417, 0.039726010253352505, 0.21433290785118458, 0.22809912480654257, 0.13166111172927966, 0.1889791054230544, 0.09545561256668261, 0.21532080887306124, 0.24147410065897051, 0.15559916835158102, 0.13168729661453155, 0.18134422720439974, 0.08391300411594492, 0.13414210279382047, 0.18238595356383633, 0.21295327543010636, 0.18520786907644043, 0.10454799604391861, 0.0921071035366866, 0.23804374279514437, 0.16900167740400762, 0.16954143231193866, 0.16246186058607795, 0.14779898368062513, 0.1373572818814747, 0.18908542310518606, 0.11217174300503348, 0.15826302460364758, 17.669151906044252, 101.39603030297064, 98.4435602926439, 95.73560299411898, 96.68513821017359, 71.58427546101233, 43.61854099458264, 57.64302653651084, 97.96066161124938, 81.39247586650234, 48.10829770180487, 70.42798426843459, 76.73055064293646, 66.79730507635301, 33.1371481187882, 2.384513996301159, 0.4061479175523405, 0.22434092727639984, 0.7016439952196614, 0.6581102828344991, 0.21042693196044815, 1.6251308735339873, 1.7936765907272216, 4.703661693680671, 6.299250500817453, 6.667635094734931, 3.4984867370897725, 10.312186729523445, 37.81717508069931, 62.782547396998254, 77.50901560629569, 80.91943017898068, 82.21447129403391, 81.6534076198455, 81.42236432721539, 81.95039379981257, 70.7968282699585, 72.53501092233967, 76.63169122511341, 78.01879036811091, 69.48789411975493, 61.18679385031424, 59.299600355086795, 59.91737757959674, 58.813269599791504, 58.91061498272804, 68.04962373548939, 73.273530467864, 77.62297614928215, 75.18035150343373, 76.11829219325897, 77.86551983125749, 71.80804667934295, 66.76204296850389, 62.845744625214614, 68.71335152656802, 72.0355284598566, 76.81819992680704, 74.49802383299797, 77.02463426897603, 45.87064043168099, 37.265132857907204, 49.929207063490345, 51.75832986831666, 74.51700025989165, 78.7233578774237, 80.2451982805806, 73.44919773840135, 68.54468176441809, 66.8066010936614, 68.73408517529889, 74.00913176998016, 75.84641702713506, 70.42633687296222, 67.22719684723886, 75.96455097198486, 76.87089304770194, 70.78092698127993, 73.71094534474035, 71.42911434173584, 75.64673700640279, 72.52416949118339, 74.45789014139484, 73.77638616869527, 78.20598156221452, 77.6839376265003, 72.30562286992227, 63.53290857807283, 53.90842022434358, 42.50185005126461, 24.734838931791245, 6.796716865031951, 5.259111965856245, 7.165957025943264, 10.005167126655579, 8.750399927939139, 8.40662085240887, 3.850023280228338, 1.2003680919447255, 0.33024757259315063, 0.17747698471911494, 0.1743940324071915, 0.15790598166565742, 0.13198859899515106, 0.6118893791590968, 9.388415601945693, 24.840688013261367, 52.07953276172761, 80.31134513116653, 82.18320215902021, 55.08930075553156, 42.47108690200314, 23.41674800842039, 57.53361986529443, 75.41090842216246, 89.13713301381758, 88.45692342327487, 109.84137181312808, 30.390820234052597, 0.3100816256576969, 0.31044055317198077, 0.2099143272085536, 0.09649763003953042, 0.29635372842031144, 0.16234438866376877, 0.20378462790000826, 0.12309967314884548, 0.21913232612273387, 0.1701643690466881, 0.2084631574971061, 0.1338117810026292, 0.18964800743326066, 0.16861077337976427, 0.14221096982158002, 0.16103748863022174, 0.14976285007451812, 0.21903363867632805, 0.06865179721987055, 0.11537052015022886, 0.17011967547718557, 0.11128477406718078, 0.14023400332418182, 0.13069763359042907, 0.1609448992436932, 0.15797842293977737, 0.14244419762924795, 0.09458870747156682, 0.20789421463925994, 0.18932074999376652, 0.1909479973537307], [0.04055301748937176, 0.05233423551544548, 0.012512155921168387, 0.012790009308035576, 0.029701879999089627, 0.059760063661322485, 0.04637641186315206, 0.026398016658100872, 0.08612339760387137, 0.038319495807011286, 0.04667757251750558, 0.025458639645348155, 0.03054774065892543, 0.032784342014741515, 0.04987931825340756, 0.01794587775704361, 0.06287427236055655, 0.08380529981467032, 0.09282754794243844, 0.0406021160644389, 0.029307455800834204, 0.047613934974276254, 0.08099861413000092, 0.04075488548785929, 0.03267262341274369, 2.994016980932605, 52.09349639954106, 78.36874423488494, 78.85594967872866, 63.111775459781775, 45.909585645121915, 35.27252566429877, 23.214583166183967, 27.275664037273778, 21.25174480099832, 35.001595789386386, 36.869914839344645, 48.595589437792384, 44.589409982004476, 16.6240854032578, 1.2243667461218373, 0.07612024283697529, 0.028058381999031674, 0.21457635527176244, 0.1460134931990216, 0.06336665622168972, 0.6393940806869538, 0.49773238058532443, 1.080532819032669, 3.3340229815052402, 2.0995547838749427, 1.5687811230459523, 17.289397831886046, 44.03637147718861, 68.05736649420955, 74.46163208253923, 67.6507108442245, 73.86525138731926, 70.69870625772785, 68.67146061312768, 69.83269399212253, 74.40849181144469, 70.6214669442946, 69.06861628255537, 74.07541198115196, 68.48449691649407, 56.21679782867432, 54.85083241616526, 58.97806798258136, 61.29502773284913, 61.09295898868192, 55.16920335831181, 51.854914311439764, 57.57898992107761, 64.68454391725602, 68.6343942149993, 71.2501444355134, 69.89707577613093, 61.6344774923017, 58.13773155212403, 58.25654406701365, 57.85314398427164, 63.70184506139448, 67.20248591515326, 70.23144998858052, 70.33833457577613, 67.1212693183653, 25.860043379568285, 21.445458896698494, 64.60167208025533, 68.27299487206244, 66.31244520987234, 64.86167030949747, 60.45105526524206, 56.11488680685721, 57.769609266711825, 60.7703479643791, 65.22085743565714, 70.2300928485009, 67.46162906769784, 66.04945028981855, 71.27232151646768, 63.65562777365408, 65.63935864356257, 59.75924330372965, 61.00876531293316, 59.20041930290961, 62.65012033524052, 63.83218934459072, 65.25242859317412, 65.43566211577385, 67.7935714106406, 61.74864984327748, 64.41800317456646, 67.79736042022705, 72.713455230959, 64.63896205348354, 47.021224575658, 26.663642890991706, 2.9160579125727377, 1.6432581072853458, 1.8740268340033872, 3.962189093712838, 2.1412074133273094, 1.7321540920003768, 0.38224649525457816, 0.08097547827468765, 0.12267287024447035, 0.01302909960354408, 0.058620438926042094, 0.049586615209738095, 0.06471315534004281, 0.7081885924262386, 10.219736464561956, 38.406734774189616, 61.80442594712781, 62.046169465587994, 40.08172412072459, 28.83457083855906, 31.57880221643756, 42.82470426251812, 58.40082453143213, 65.73153042024182, 83.27019291539347, 55.563574144917155, 0.6234161219289226, 0.07434276563505973, 0.057600706950911594, 0.08094243690251343, 0.05141530921983142, 0.13378798631170105, 0.08259724044511396, 0.04990551846041795, 0.008149090797580298, 0.022680004270026283, 0.0054985386199287835, 0.009994740248657763, 0.02594353499702148, 0.021301536302592967, 0.025301583959991415, 0.05006655397254133, 0.012619253097762986, 0.017456391623484033, 0.048847210127860315, 0.032603679329998074, 0.03152646203224938, 0.09867182587303462, 0.06075158444864135, 0.021148780285711252, 0.08033892049664453, 0.05260088773924978, 0.04479988718465452, 0.040463212832447984, 0.08418232232572571, 0.007764844077398941, 0.027960621519014243, 0.06761328842971595, 0.018881947185183247, 0.009716500944998718, 0.024966529660647916, 0.01931608729665318, 0.03563380987954236, 0.03872468737104247, 0.014209704297114045, 0.027695143324953896, 0.05774352106175596, 0.0383745507156897, 0.06408384475376337, 0.011680668028401993, 0.052125668078060114, 0.019914775433379318, 0.016497044613765135, 0.023364082482012532, 0.017759061471048384, 0.0641590899096862, 0.04777802717721751, 0.04214063512101289, 0.08488135457399391, 0.040994678669038324, 0.02346754648662623, 0.014104727268849891, 3.6857328443757953, 61.198105965891195, 89.22468816080402, 87.93118461485832, 73.06335418455063, 58.29252004623414, 53.79856640292753, 33.857048173104566, 27.74868226820423, 34.4704911785741, 41.989804237119614, 34.52265870186591, 41.6760342351852, 42.497029458322835, 19.00041610963883, 1.5801965685621386, 0.07757748762566237, 0.14038188893708492, 0.038844836770647, 0.9120707586407663, 0.7739751978266625, 1.9085031195032982, 1.2575497526314952, 3.453884240119688, 2.142052438951308, 0.10045736998079285, 2.064657211303711, 19.072448476668328, 47.661877063012895, 69.79720438680341, 76.22563962013491, 71.71737717043969, 76.05028613921135, 74.98948897084883, 70.22451523811587, 73.06519769853162, 77.5478078472999, 70.46261879705614, 70.22398964051278, 76.65812015533447, 71.82099834565194, 61.10183923475204, 57.52362566609537, 61.3051474478937, 64.00022760514291, 62.6024047020943, 59.910305546176055, 55.87236273673273, 59.58104218206098, 67.04988218122914, 71.95575529529204, 73.01361853076567, 72.78130439019972, 65.47301092455464, 61.03503734834733, 61.89210268758959, 61.96162277652372, 65.62286507698798, 70.41522872063422, 73.3581438372212, 73.15942871955134, 69.15137044845089, 29.963103417427313, 24.78464322705423, 67.38326011165496, 71.99945049901163, 68.81235214971727, 68.25971372665899, 63.34099877265192, 59.38240551179456, 59.62845579270394, 63.132599323026604, 69.29062243430846, 72.79805291083552, 68.02615227237825, 66.8829696409164, 73.80397612048735, 67.38595870233351, 67.0516864715084, 63.9487268847804, 65.25196183112361, 61.545271027472715, 65.09656536963679, 69.16794638479911, 68.64428643257388, 69.78467633647304, 71.60560531000938, 64.82999717035602, 64.76263438501667, 71.37919825892295, 74.86419277806436, 69.92240644270375, 53.1008904980075, 30.978905116358114, 5.1389344661466545, 0.5485013644060781, 1.1852273753573819, 0.7897772627972788, 2.0142828240509956, 2.7043371960040066, 2.5853947526024235, 0.5425430389661943, 0.18450302222082693, 0.13534810904773975, 0.029194051805402965, 0.029775397626743205, 0.054944898452489614, 0.48907932555002553, 9.764817030199113, 43.60825261762066, 57.7055569617979, 54.73908016758581, 36.85560995532621, 27.937079591135827, 47.06449616339899, 55.39927782550935, 66.27457864822881, 74.74983999806066, 88.68017688874276, 71.48962866875434, 1.9384510286392707, 0.080134260107673, 0.012207554574424942, 0.1536735603886266, 0.018697281691035437, 0.15197031710657383, 0.020721481339405143, 0.033273293801973906, 0.01583975266605135, 0.054395961980786056, 0.05000913185217688, 0.05552856935068004, 0.08495346643030645, 0.029318878171785228, 0.012334394794438156, 0.04945783199922693, 0.07001688929214593, 0.029854306598163904, 0.0380088739667929, 0.009494072104233408, 0.020622774740801226, 0.03471792112254808, 0.08252984002953576, 0.0635771235571273, 0.04075064902163802, 0.08305140801014439, 0.036914697397620454, 0.08112008503127484, 0.060332622454171224, 0.01199186347695368, 0.012888950521066304, 0.22927767446925565, 0.18260484020556175, 0.09776682322544437, 0.09379720074995872, 0.1327607083705164, 0.16034492982491372, 0.12647052896359276, 0.07692741605663493, 0.15653163525125674, 0.1351301110680065, 0.11301269304127463, 0.13394333362098665, 0.18127489624725235, 0.15290227838821951, 0.1624764928654317, 0.20004506162818403, 0.14646868732187057, 0.1575994852089113, 0.17977704113769918, 0.14315194029721523, 0.16780664152916402, 0.12088328119247191, 0.13141142835299816, 0.09960313597994466, 0.21493630934386485, 6.155977595236994, 76.93329011240314, 98.76378259351178, 99.32379507249402, 85.27894066226098, 63.56973178925053, 51.26351110396847, 34.54055255459201, 37.15227057856899, 28.617846158242997, 53.436194312187936, 53.955116041245006, 67.05422032263972, 61.3062104102104, 27.56984180019748, 2.0856313503557637, 0.4077194090331755, 0.31065481264264355, 0.5530590359722415, 0.7866097650220318, 0.8978711657466427, 2.1578083547853657, 1.896816049852679, 2.125277932613127, 8.968167958721038, 6.051825429162672, 3.938770827747161, 21.542786628969257, 51.03670397112447, 74.28978520054972, 79.85663260183027, 76.0193229490711, 80.17214021375104, 77.76807246669647, 74.29070303517004, 76.50931327573716, 80.51738723631829, 70.56346293418639, 68.208111024672, 80.21761617352887, 75.61091007724886, 63.86518432248024, 60.10097588262251, 64.87676358992054, 65.56469632733253, 67.55829980296474, 62.869274923878336, 58.24235293173022, 61.87535024458363, 69.20027455975934, 74.24766678963938, 76.70264690153061, 76.21377837273383, 66.59231416640743, 64.50742536975493, 64.76650968674691, 64.38234490732994, 68.37856154288015, 72.66493551192745, 76.13512700603854, 76.9464300524804, 69.85958576202393, 35.73031725422029, 30.058354254691835, 68.73944313295426, 75.0916196453956, 72.10547216476934, 72.04782116797664, 66.69896341139271, 63.452182277556396, 61.79710680438627, 67.06485779054704, 72.45691653220885, 74.30752215846893, 70.65468157491377, 69.04103417550364, 77.62501578177176, 69.63652841506466, 72.10417778261247, 66.73173873655259, 68.34082834182247, 65.72856118602138, 67.57977870202834, 74.42542860584875, 73.64428858603202, 72.49894080623504, 74.566084800228, 67.29888208450811, 65.18949024138912, 73.87024064217844, 75.57651873557799, 77.2710689421623, 58.34708413770122, 31.45950725001674, 5.299595238700991, 6.020753883546399, 8.092403700274806, 10.542538704410678, 7.1741822361946115, 4.526223963306797, 2.6090275231868993, 0.2372769194264566, 0.2623750629924959, 0.14131781855417838, 0.19701861596155554, 0.1651483930407032, 0.2224028780455551, 1.5190085744665516, 15.525203001114631, 55.7799046270309, 79.87612678158669, 83.01830614766767, 58.25466132933094, 39.261419234737275, 44.78883897104571, 61.354381038296616, 75.44308754705614, 86.6434234188449, 96.06631371282764, 85.60538384222215, 3.039578987706092, 0.24621319716736195, 0.11711219040256356, 0.24590576608334822, 0.14693708880053413, 0.42703925782153684, 0.12718196417535507, 0.21839606966222488, 0.09976894805027593, 0.17414923667186694, 0.23322831328597762, 0.13052314940479495, 0.1640859056985186, 0.1326569953873273, 0.08169772298706156, 0.16019135983961244, 0.17312678508460524, 0.12488271980997055, 0.11037129082626874, 0.10060687203921619, 0.08039040926603541, 0.17468903754507342, 0.2398617307264959, 0.14644253308013563, 0.21850488479098967, 0.13923370699969032, 0.12748544990655877, 0.1809935581179396, 0.11867314817443972, 0.12396456343272041, 0.16727822472251233], [0.06508888316250618, 0.06713168725611703, 0.09170004271812017, 0.0781704856443309, 0.029764002068869533, 0.00869995302280351, 0.06780554585519337, 0.02029136893519711, 0.03683065372188726, 0.03706612616717335, 0.07955053941376748, 0.00786193662450739, 0.062161684186468204, 0.08364639019653683, 0.06599911819061925, 0.01281599501042717, 0.10374970944418062, 0.03251556006650771, 0.02426685964418275, 0.09063338785762749, 0.040736430429763375, 0.008008370500793982, 0.03797737243134649, 0.020407235903304913, 0.06454385756965607, 26.190663883762976, 74.98876725473713, 79.57044862931775, 70.1428436463879, 67.64607460268083, 35.96477693127048, 18.552820720980247, 36.19585552523213, 39.61897073253509, 49.39638837691277, 49.626180433457904, 64.5482337090277, 45.778174477238814, 15.099280668843178, 1.6496177402234848, 0.1797528480810504, 0.006907651540748174, 0.15276698726079158, 0.19642042386676037, 0.2894629514025104, 0.8959604811764533, 2.1600519505239304, 1.7735082535974442, 9.861458347689721, 1.4825967218606704, 4.34672208562974, 26.35439342068088, 53.65675310934744, 69.73452491144981, 73.46691116209954, 67.16155990477532, 71.83389509877851, 72.59568998890539, 70.92770991786834, 65.0706777264995, 67.28894279849145, 71.09015095618464, 69.39128614241078, 67.2580345215336, 70.40267713608281, 65.75113050399288, 56.44264790319628, 53.075065612792976, 61.931906900098255, 62.950287557417354, 66.38359700479816, 57.81923509413197, 54.70508106293217, 47.26075195497083, 55.02691545794087, 57.247318221676736, 61.48142268580776, 59.4503644974001, 59.1671536814782, 55.37695953922888, 58.6663572249874, 57.39352849221999, 63.03554027311264, 60.67891359329224, 70.23920059204102, 62.86657633319978, 81.26906241140058, 34.224166331752656, 21.212813315852998, 76.96742257764264, 61.02443518177156, 67.31305753031086, 58.477797123693655, 55.11658084008002, 50.08114007211501, 58.16362704000166, 60.83996611256754, 67.73481430545931, 64.54045564897599, 64.9320690093502, 64.98285585834135, 64.8779599128231, 59.29877273498043, 54.15943622589112, 50.73574050780266, 50.06186946745842, 49.772959447676136, 52.336773564738614, 55.20713267787811, 59.967905552156516, 63.4181635610519, 66.2409011779293, 66.71785354614258, 62.89936734784035, 63.4215211099194, 68.82025964798467, 70.22016925196495, 71.84674478346302, 79.57790897738549, 63.97313579436272, 20.911910649268858, 0.5788861888070261, 2.2819854463300397, 2.8424247282166637, 2.177156671400993, 1.186073504147991, 0.5356693916743802, 0.037733250853395274, 0.07033925142980392, 0.10753791463831741, 0.03709006641480712, 0.03490597655576083, 0.06907987183020001, 0.03258962927746677, 5.0074997640425165, 32.20439868588602, 43.258561549648164, 55.57119138779179, 39.937639774814734, 15.89852144641261, 22.40468432826381, 56.83060561456988, 60.41591867323845, 69.11355095524942, 67.93014834004065, 22.559457132893225, 0.15614862193263349, 0.09032585718218358, 0.1505255212466563, 0.008793700159707618, 0.04561464084432491, 0.06975146280902048, 0.02853142597051638, 0.01390361003652816, 0.0558186408823296, 0.02152660527386733, 0.04214030187276583, 0.03488573268236172, 0.03380709237629368, 0.014581326845913165, 0.027792922957169435, 0.0676549099866421, 0.08116728370828975, 0.06390851787141254, 0.03877337608907012, 0.024895103453027628, 0.04660879314366368, 0.011977668825326668, 0.07642475512599753, 0.03584729177096198, 0.04599057551052782, 0.05581252750069384, 0.0560074394208289, 0.041887607770941915, 0.10318619814971763, 0.07724309790759318, 0.030347132875073343, 0.048863056656574054, 0.028251313581882466, 0.052997299935668714, 0.03085338867329542, 0.04492303198804298, 0.10020037812571372, 0.04681756359434897, 0.026721420675335873, 0.0414322987349043, 0.02432766787317251, 0.10559207429328274, 0.017940049743159645, 0.12244413937291793, 0.030074928429037816, 0.021728957822966962, 0.1102084894814799, 0.009938071767288831, 0.02240142022680131, 0.02458184627034972, 0.018637162941177527, 0.016454754645125042, 0.033000593314007405, 0.00220330837163924, 0.026112945765377055, 31.605954823955415, 90.7381582260132, 86.23803077205535, 81.32257138529133, 77.36949689926641, 48.92179727554322, 28.511608762125817, 37.30121866349251, 31.700707520208052, 34.0278713164791, 49.41797317997102, 53.35608382378855, 47.194938505849535, 18.222792494681574, 1.6585487319577126, 0.06458059148562532, 0.05729108102499478, 0.60094713083198, 0.7776249019849686, 1.2353553887336486, 2.671452779923716, 3.2306275877260395, 2.637404155346655, 4.756150851326605, 1.136363345769144, 5.421789817271694, 29.27601791197254, 59.41397666931153, 70.98823993436753, 76.64196783496489, 71.39793934360628, 76.76779747009277, 77.10409364392682, 73.54836310109785, 67.61057715262136, 70.86240245449927, 73.04349914673837, 67.55391459311208, 68.33145387711065, 72.37808473648565, 68.49699358786306, 57.02319006766043, 54.64862246667185, 64.98662525607695, 67.00229598629859, 68.35887124461513, 60.04694915586903, 56.164473410575624, 50.632758678928504, 57.83284179625973, 60.210461001242365, 65.88682882247433, 62.565632481728834, 60.76042436784314, 58.093691179829264, 60.92258299550703, 60.56956575762842, 65.5699444586231, 64.71783307290846, 74.05010484880017, 66.1299059467931, 81.74590495324905, 35.873946605190156, 23.552154110324, 77.57307575594994, 65.1282581206291, 70.60263956746748, 62.96507489296698, 56.74701990619783, 53.48535337755757, 62.56156890623031, 64.47948632701751, 70.94015952079528, 65.3373832087363, 66.30289031613258, 68.78890422082716, 68.65533182697912, 63.48079204559327, 58.099488442943944, 52.814204462112926, 53.49020534946073, 52.95651589670489, 54.75067469381518, 58.16592554892264, 65.59835810815134, 67.20185049118535, 70.55586138079244, 68.36814372770249, 66.05366291538363, 66.86637017034715, 69.95719786613219, 75.33005268343034, 78.61202532245268, 82.3319149017334, 71.25631824616464, 25.050124929797267, 2.0500219901723247, 1.1066839964159074, 1.559106229293731, 3.082610085125893, 2.8744209726010603, 1.9166766034979976, 0.5933016959217288, 0.08015727338891837, 0.24428982618114642, 0.05843968431074774, 0.08144888230749676, 0.025156237928557302, 0.03871637148662441, 5.353344948061052, 32.50477575486706, 44.599486550977154, 45.64117000948998, 28.91939013235031, 24.485285974317982, 32.710102027462376, 65.75666496830603, 67.03456924807641, 73.7925620232859, 80.5600312448317, 34.30272748393398, 0.10617623165730508, 0.06599641390024655, 0.15444842768051933, 0.03768925059346422, 0.07731651211337698, 0.08364015424083318, 0.02135819233503313, 0.01652341527533868, 0.06155558606429447, 0.02093288521733015, 0.02976356348353288, 0.08308836409161169, 0.01543734870445464, 0.040562769788647854, 0.04762004069503277, 0.06351887406180463, 0.0677972644447319, 0.05547734871206265, 0.0198958549768694, 0.06257499245205714, 0.09328644993084093, 0.05816629051320976, 0.029843114053590164, 0.04998581213576179, 0.060209607885729884, 0.041894065892143596, 0.08647582869255736, 0.017608350908924496, 0.07332453519226083, 0.04960771327117278, 0.18206451839256674, 0.13668710816531413, 0.13509237357685644, 0.14126465205223332, 0.12154952487758092, 0.1291586548811005, 0.2165828467977624, 0.12939081016567447, 0.07644934654836694, 0.11719641410895895, 0.11838789533583388, 0.18245217420401114, 0.1710334651532673, 0.22565824610571708, 0.12841068493622926, 0.09736608263225326, 0.27576971198281935, 0.14399615386801382, 0.1530657155859855, 0.1501989992515695, 0.15376020493286272, 0.10502182908596532, 0.222220380580233, 0.16605024706692467, 0.2742086392977546, 40.8257467516007, 101.43996084890058, 98.65454458421277, 91.3484319563835, 87.95567589421427, 51.84195480039043, 28.461100401416903, 50.27845490363337, 54.39462546379336, 67.68302332970404, 67.49595765144595, 84.08988983400407, 63.42835780112975, 23.685308771748698, 2.480000420924156, 0.5789965054681224, 0.16715991010348644, 0.9394058176586706, 0.8956821767553207, 1.6327233564469124, 2.7481895396786356, 5.556576674984348, 6.508982575708821, 21.222066187089492, 7.298411544292205, 7.024926245212556, 33.45450708943029, 60.6619885659987, 74.9246286576794, 79.7792128593691, 73.11984415977233, 77.12187767028809, 79.41091798966931, 78.8555888206728, 71.08724055751678, 73.46125510431105, 73.65224315274146, 68.22856226275044, 68.54652527839907, 75.39065330259263, 72.62753178996425, 61.5984897459707, 58.274096673534764, 68.85439211322416, 68.86745360589796, 70.64311842764579, 63.052320172709805, 59.010556974718654, 52.23145400324176, 60.602658794772246, 63.443643277691265, 67.03635000413465, 65.69736265367078, 64.33847319695258, 62.08030193082748, 64.56488417040917, 63.74350455499465, 68.9356557784542, 68.79391700990739, 78.19577555502616, 70.41862549320345, 82.70654832163166, 41.213598558979655, 27.939407517833097, 79.63780356991677, 69.5165038877918, 71.19765527786748, 64.6658459786446, 59.34225220834056, 57.92989300143335, 64.54626860157137, 66.82943713280463, 74.92096516393846, 68.39060321930917, 66.91055959270847, 68.95925275741085, 70.6315552803778, 67.00802264675018, 60.54074810397241, 56.49690212741975, 56.80378444733159, 56.138370037078865, 57.71428815780148, 60.131958684613636, 67.40903008368709, 71.33102370846656, 73.86108583019626, 71.93502164656117, 66.67473885320848, 69.06831818242227, 72.50788381022792, 80.10072954239385, 79.26747691246771, 86.27977263542914, 74.1570443491782, 25.71394293538986, 2.250826382829297, 6.8174995433899666, 10.878420087598986, 5.621448755264283, 4.234872758388519, 1.3879245567706324, 0.2882260871270011, 0.2380972770192931, 0.2820633081418853, 0.2489444385132482, 0.16368962373704682, 0.22121720376514623, 0.10816326455002832, 9.722393655007886, 48.85434035331973, 58.758623138550796, 71.14063970504269, 54.03588941020351, 25.15586614608765, 34.84883908302554, 73.55118720762192, 79.59746591506466, 86.26377720986643, 90.68023266330843, 39.158978692946896, 0.27411827156620644, 0.2062331981235935, 0.23153723548016242, 0.135846663747103, 0.2552870489777096, 0.17651672414954633, 0.13096553453754994, 0.1110310840510553, 0.1007491039232381, 0.10799008271386547, 0.2452579927780936, 0.19586537784386068, 0.131518067792058, 0.10756407654093159, 0.1400654639808401, 0.14903996950916706, 0.22859496755465386, 0.15896679893616708, 0.17395412939931118, 0.20712267216895858, 0.18941303294512535, 0.15756171707424427, 0.14274831921342881, 0.1550807872967374, 0.12251426706150656, 0.21769122280661138, 0.16114679405525809, 0.08810123744150324, 0.20348344809345661, 0.21403929699332486], [0.05875481457840051, 0.02709519880403194, 0.028632168447779074, 0.00903397693388885, 0.03420639272418714, 0.014484706879293006, 0.035473938821063894, 0.0317185202748665, 0.04405128138680612, 0.05422424720299821, 0.055075616035009586, 0.02575831408912857, 0.03867092715095609, 0.047124967865285375, 0.08088043740680141, 0.012836954218425579, 0.07205372556082665, 0.05159841955549294, 0.02340041037138191, 0.00745404890978769, 0.035019752103835344, 0.04533059076376019, 0.10200178025350456, 0.03751765455930464, 4.485752457572568, 69.84076622993716, 80.90898882958197, 72.84935751268941, 56.73863387876942, 40.00735598225748, 22.29544828014989, 30.453185919792425, 31.56741753701241, 36.102542338832734, 61.06823236711564, 54.156741557582734, 33.33226642301006, 6.126552464500551, 0.4698913358151913, 0.0814130753579159, 0.03110175054790753, 0.031286553937881705, 0.23373010087638135, 0.24958455093926002, 0.6439808635942398, 2.3385933378050408, 2.761352033384385, 1.9486887825112191, 2.996953610450991, 9.206915766962114, 34.2146388946041, 60.24231064704157, 72.38203848561933, 66.37349297923427, 67.88034992833292, 73.61153679509317, 74.05094423601705, 71.89100480848744, 65.774009689208, 62.89669229138283, 68.76822548527872, 71.57829776886972, 70.14468716036889, 67.83849039385396, 70.11075081363802, 65.91030028558546, 52.257259276605424, 51.0528523691239, 62.95744588298183, 69.2684845770559, 70.73283872296734, 65.9994871385636, 59.89014456349035, 49.996201146033506, 48.82702888980989, 47.84247083048667, 52.24009890710154, 51.209107829678445, 53.74320999268563, 57.05693814062304, 62.142173397925596, 60.57203685083697, 65.33532004202566, 59.92479478159259, 68.7236830496019, 63.10003188348586, 77.55317364969562, 39.63005927301223, 39.20909089426841, 79.14019600037606, 60.48324223487609, 64.67113725600704, 47.66920797286495, 54.1420405141769, 49.28761712966427, 54.484922347530244, 61.32865028996622, 68.96046869216427, 68.16802440151092, 67.53458515290292, 69.51057326409125, 67.78342816137499, 55.334550872925796, 51.75056749774564, 48.87230480870893, 51.09731635739727, 50.307033292708866, 49.31674465056389, 49.34543678837438, 52.39712707458004, 61.360503858135594, 67.46938751589867, 68.05022778049593, 62.90763570416359, 65.99631786346436, 73.21591869477304, 70.86104531441966, 71.49177812760877, 68.66906796732258, 73.96984531033424, 83.36065846104776, 54.58603320583221, 5.381892448471439, 0.7099477141614884, 1.8123690135055974, 3.4635205230405255, 1.9036374193045402, 0.4878192028451351, 0.05347650708450426, 0.17901824637045785, 0.055978791562900435, 0.04766384560254313, 0.1017859273199593, 0.07964424728866547, 0.10377348115247104, 7.493416099779068, 43.431722425645404, 51.51987721843105, 59.439609358387614, 38.74095601420249, 32.14426482877424, 43.823728023036836, 45.72164527831539, 64.91262189803585, 73.06465641144784, 59.11361332862609, 3.0218834598218245, 0.08299348410218954, 0.07044291844771755, 0.09942158080276944, 0.017493623496604063, 0.056474917763543714, 0.04698110804442437, 0.046687313325462804, 0.031096100649465958, 0.039255789315868775, 0.01992366205330097, 0.048801275495920456, 0.0072680020633514135, 0.05216887926742916, 0.046425912634379445, 0.09388319411945921, 0.03442474693480519, 0.05660878396743248, 0.04295593653354914, 0.07162062541371392, 0.049781730143173095, 0.042273091723120985, 0.02157788145385923, 0.029661834668067676, 0.05556320801617638, 0.03632083753003709, 0.05244532975578501, 0.022943730037959836, 0.04632184725074519, 0.053350788225690206, 0.06054940235410487, 0.020478043494926348, 0.05392179186005266, 0.04916369254069944, 0.038439943980906284, 0.03459902427669975, 0.009920842449871764, 0.030811148500370405, 0.025263400222625465, 0.08239601979092245, 0.06794629918952143, 0.07888912208258145, 0.020836015314524694, 0.017793096842304353, 0.15561321840411232, 0.03930727042438042, 0.09240072971630482, 0.022907846479586536, 0.05906212308834638, 0.04902650151521929, 0.03928433375192746, 0.06836389371704671, 0.040513081325879025, 0.0856889644637704, 5.992835433252397, 81.83742169410952, 90.42923235124158, 80.85065534037929, 65.36650288489558, 53.01560640335084, 29.350768481531453, 34.83904884707543, 37.41166476280459, 35.25476909452869, 50.01576985082319, 51.273320951769435, 36.10414658823321, 7.722675694573311, 0.4117525555193425, 0.15090695642415555, 0.10092121323630696, 0.3093494294631866, 1.0161396969229946, 1.4454305484410257, 2.8064436008853297, 3.0023159807728184, 4.357937122544935, 1.678178601207272, 2.922598219686939, 10.617152971606101, 37.5346310677067, 60.691445565992794, 73.76009264299947, 71.11059434952276, 71.17038696042954, 75.56193536327731, 76.27708542731501, 72.92526322026407, 70.62786040767547, 65.10846976310977, 72.52127478199621, 73.09307006097609, 70.21009660536244, 69.37023085932579, 73.60019330055484, 69.76485267762216, 55.33400958584201, 53.78207675872311, 67.14530560278124, 69.75758844806303, 72.71595770312895, 68.39426671305011, 62.716577053070075, 52.580780290788226, 50.58562747893795, 49.90311153473393, 53.896586433533706, 53.49139382762294, 56.531983806240945, 59.43753442456646, 65.98803381766042, 64.2016452358615, 68.13580605291551, 61.82922709372736, 70.8970840515629, 64.24593271747713, 78.83494930882608, 42.986623625601496, 41.012298599366225, 79.05540220199093, 63.72133924115089, 67.30147084882184, 51.821378046466464, 56.26741993811823, 51.77232488509148, 58.46490037056708, 64.73016892710041, 69.84732443286528, 69.96152816280242, 69.03147928176388, 70.4961472172891, 70.84081372907086, 57.73804987630537, 54.214749490061116, 51.25385030623406, 53.96167816654329, 52.288387206292924, 52.147024985282656, 51.794439208122995, 55.66045668817336, 63.81038096643264, 70.17872548872425, 71.203334869877, 64.52620567813997, 65.9420322602795, 74.6705061389554, 72.87499412413567, 73.44435753360872, 73.05553297842704, 77.32766089900848, 87.30584113828598, 60.20241622001895, 6.956596595625724, 0.13938367637174745, 0.6806514087703921, 1.5336900060215306, 2.9995274207284375, 1.1478475553374137, 1.0407992091871079, 0.2763551870180715, 0.27850614740483226, 0.1588653382514754, 0.09887627175738735, 0.07412971658331734, 0.08468633923198908, 7.300582576182581, 42.306268907362416, 44.77531071632139, 56.83625774998819, 28.47921782924283, 35.42272890767744, 56.1766759041817, 52.549032626613496, 74.59610662152691, 78.84185268032935, 73.20841912300357, 6.539178942480396, 0.17048293904912087, 0.016143244142914494, 0.03817783082805334, 0.015437716426658294, 0.047553053966933684, 0.0403888525080777, 0.02313780883747724, 0.02815585711129731, 0.03064514490805807, 0.05713391425688902, 0.014201498537835096, 0.010791528188893873, 0.020931644154892817, 0.07115757122876183, 0.11292682990672127, 0.018934066061891856, 0.005178220021808821, 0.08698644927672802, 0.05185659884685471, 0.03206806704251757, 0.06824292077292358, 0.04972219745057726, 0.11116080571927371, 0.06924732332868923, 0.017030835527205662, 0.021255172661415512, 0.0977766904379091, 0.08440499344179708, 0.027494133344941565, 0.08428644899639391, 0.11225724607826242, 0.10715640285202574, 0.09579069942476288, 0.11884287495406405, 0.14783871300037832, 0.18416263403431063, 0.07950227587453781, 0.15845534331615896, 0.15525076688537676, 0.21081014446193175, 0.13254140804131187, 0.1840668730437756, 0.09240542583528066, 0.2427613735198975, 0.10782201068415757, 0.14778137898012517, 0.10918958488130763, 0.1578546844182476, 0.18406803749742048, 0.13679123483598232, 0.2085351084749545, 0.18370477392548518, 0.23019121899720163, 9.073223740823808, 94.9508700832244, 100.64066809992637, 91.68497131716822, 77.09555072169151, 57.257622288119414, 35.846764579896, 42.48791387004238, 46.43224147058303, 54.641911291307025, 81.59580369149485, 74.31575129109045, 46.87410823760494, 9.768936499472588, 0.9945621870217786, 0.2388482270461898, 0.25342228371770154, 0.7600968102774313, 1.3350910885680107, 1.3563372194767, 3.658015415553124, 7.612750780197882, 8.910569913925665, 9.218119036766792, 7.691252116234073, 12.72128099395383, 41.240039256311235, 65.5026875772784, 77.22837786520682, 74.89787809310421, 70.34698732437627, 79.43936301815894, 80.09256316769509, 76.9225977313134, 72.31551508749686, 68.97021970441266, 77.13358986762263, 76.84189888738817, 70.3614765597928, 68.11258562149541, 76.37720784833355, 74.32049735899895, 57.262403657359464, 56.84269435944096, 68.06654484041276, 73.79373088959726, 74.68137894907306, 71.74297455818423, 66.13672302615258, 56.15220815904679, 52.06889529382029, 51.93398929411366, 57.11299273275561, 57.23649248000115, 58.626254912345644, 63.9557400826485, 67.61410728577646, 67.02147637644123, 69.74218137802617, 65.27683750275644, 74.7953159578385, 69.54230523878529, 80.50790294524163, 45.55681943893433, 45.189846407982614, 82.41750886363369, 68.28367156367149, 70.23082240935295, 53.77830343861734, 58.07706425266882, 54.60580195150068, 58.86966936049923, 69.33670243909283, 73.18269621941351, 73.4629495682255, 70.27172488550987, 74.13656957687871, 75.66797271851571, 61.153818484275575, 58.09724876957556, 53.79102368508616, 57.05150565793438, 56.20944338460123, 54.549833651511904, 55.11630627416796, 58.68548270194762, 67.36638607517366, 75.43099095744472, 74.00940633589222, 66.77297069180396, 67.97433776240196, 77.68767172290434, 75.14967856868621, 77.36889285425987, 75.57236886793568, 81.05980396270752, 92.89605017631285, 61.04928339681318, 6.382661663716839, 3.279732475357671, 10.55672787850903, 9.683388625421832, 8.845949845929301, 2.156498283147812, 0.7445517831271695, 0.49380167537639225, 0.22823873666986344, 0.3708612642461254, 0.2730036136363783, 0.2913503468998017, 0.39715223735378635, 11.801760735050326, 61.95548818957422, 67.68620044954362, 78.8904586915047, 56.13720117076751, 45.001384365943174, 57.738285218515706, 63.443109835347826, 82.26233989961686, 88.85648742798837, 83.7894598130257, 7.440607268964091, 0.3474254395452238, 0.16618760663174814, 0.20572931145227727, 0.08269432676775802, 0.14394249706979723, 0.1635829383327115, 0.22370049309345985, 0.1294693341779132, 0.17890465085304555, 0.0957025227046782, 0.14801007154728138, 0.16392254510954504, 0.2240828935417437, 0.1168222108014649, 0.2513763539853596, 0.12800791421003882, 0.15459778418223705, 0.22174781158326135, 0.19616965264562639, 0.1254617214022625, 0.18866749149897408, 0.13397673505448526, 0.18503044311317707, 0.1069388568641678, 0.061346463213164004, 0.12547793182274028, 0.20983229451362165, 0.1394728796496507, 0.1190047263498268], [0.021208470026331565, 0.033996695307113474, 0.06327327393415956, 0.015119542874726317, 0.04837040466466739, 0.05313593503688613, 0.028814686980519085, 0.003815139169737156, 0.04027866608192844, 0.022635241752610575, 0.0032000699185676155, 0.029552686291055816, 0.008527484606020153, 0.01935599281662895, 0.014386358426793689, 0.05174915501547437, 0.07633860087803296, 0.040995100017396674, 0.03944927631246467, 0.012773908055087012, 0.011242758764344598, 0.06741032109505708, 0.021672738460643638, 0.27482010003539825, 40.57347166922785, 83.19235740169403, 76.62294433962914, 78.21521482160016, 65.82836197268578, 56.67593086919477, 68.90235485569124, 30.05351797226937, 31.6970597159478, 49.06208476712627, 47.15381637696297, 27.692549228668216, 5.121686333610166, 0.5301347435001404, 0.030442349943182165, 0.09899845512043084, 0.05344278389407743, 0.10011501294831116, 0.15462206916943674, 1.306752454369299, 2.3769401446465523, 3.063708918709909, 2.889601770908602, 2.9522682534110163, 15.603141477031095, 41.227397457245864, 64.2325064443773, 69.05136569853752, 62.84197914984919, 68.91646754357123, 73.49961588459631, 69.09682596883466, 73.49461094025644, 65.98258172312092, 64.03336771072881, 60.73161848129765, 68.92196670655282, 70.54225075629451, 68.81078320164835, 67.77133157176357, 68.383542952999, 65.28474892339399, 53.53036649765507, 47.30592589224539, 63.864321401042325, 65.63417719256493, 68.63683392924648, 64.9713005558137, 65.76630223181941, 55.67934290055306, 50.0106393906378, 52.00873790248748, 56.220932006835945, 55.627646061681936, 60.96441899576495, 62.938806779922984, 67.9775619506836, 67.68536890706709, 68.44727362355879, 62.882732575939556, 67.98074691526352, 61.27174846587643, 76.13133015171175, 40.99180421521587, 41.53320504773048, 74.03634517423569, 59.83172870451405, 59.09781009920182, 47.74461553942773, 51.735909600411695, 47.12654413715486, 49.61595481441867, 53.28266097653297, 59.28255765668808, 63.23107434857277, 69.69250063742362, 63.302465408079094, 59.439428929359686, 53.88444277548022, 48.966657423204, 48.55931928080898, 50.86279000005415, 50.561140121952185, 50.263424381133056, 49.85842004899056, 51.39362004495437, 57.94647286015173, 65.28188167079803, 66.70984406625071, 64.75047503748249, 61.79871889852709, 70.25063037872314, 67.60914940987864, 66.37950205033826, 66.74446290539157, 68.54975731142106, 67.72035644900414, 78.7085077839513, 75.39770572416245, 21.373369655301495, 0.6798086507666496, 2.0259105678527587, 2.110659504129041, 1.6371770852035092, 0.6350598616465446, 1.0325499744184556, 0.18130111177602123, 0.048409333422539697, 0.06003957850137546, 0.0438874994494742, 0.06506103586645857, 0.1480882891243504, 11.581414726472671, 51.26439363725724, 41.613197865024695, 47.27144825843073, 21.131228016268825, 20.287847826557776, 51.29887519344207, 62.00553763297297, 63.29488346653601, 65.96515071007514, 24.424314691174416, 0.9466232239238678, 0.01889405712004631, 0.08420224827263625, 0.09360134271123717, 0.03391456302075136, 0.060859487932776256, 0.03514130727478093, 0.056692302872937535, 0.02775876692706539, 0.04742176947934974, 0.03193643206970827, 0.013917571031338265, 0.05673965859797694, 0.09000841332899948, 0.08801966439932586, 0.07470279631595458, 0.01895609300493473, 0.0190824783602429, 0.02062174435254307, 0.01010419218800962, 0.02042151386699369, 0.08577293536115078, 0.04456346862078194, 0.05767743831740753, 0.06197984555676099, 0.06330276065836511, 0.06109247442274805, 0.014148167326986311, 0.06427178144334786, 0.01090050036568315, 0.03396665699960243, 0.015569462482216618, 0.04852994630533842, 0.034375537276989034, 0.060879835228045145, 0.008151738588968593, 0.02310571932954894, 0.020680078117537404, 0.047927724588061535, 0.028366437444703716, 0.024483641459336205, 0.02777441427291882, 0.0343019200579053, 0.017635064394844156, 0.049837371109113585, 0.06253867988444625, 0.0257549011674259, 0.018138250095709678, 0.054735499809706406, 0.04830096262477098, 0.02093138176977875, 0.081054967557711, 0.33438404901854457, 52.176356469431234, 94.13863351268154, 86.11743357873733, 85.76710316442674, 76.16968308725666, 61.06015620693084, 64.84125829512074, 34.87741354973086, 30.090672623726633, 47.05934216899257, 49.584301287128085, 32.861466292412054, 5.777556636641103, 0.4992917065899219, 0.06699051257343062, 0.09995033468810782, 0.14683346774789596, 0.5956433509146014, 1.2596577814509793, 2.194617102223058, 4.0922602818858245, 3.1752010651173133, 1.9120625478606073, 1.7211430183341427, 15.839506445392487, 44.73234899582402, 64.67646383470105, 71.11977269572597, 68.67717942883893, 72.37562148801743, 72.45595162914645, 72.48992719957906, 76.58703111833142, 70.34017024501678, 66.73442163775044, 63.79615060744747, 71.84275965536796, 71.33650718196746, 69.04055564634263, 68.82520183440178, 70.45180874486124, 67.65180910787275, 55.343713529648326, 50.624784500368186, 66.03709482377576, 68.94281018164851, 69.09834000372118, 68.25966665821691, 68.23510477619787, 57.18195192275509, 53.65085778697845, 55.94820176401446, 58.855380165961485, 59.07206758376091, 63.90508659424321, 64.52785307361235, 70.59185304949361, 68.75190058062154, 71.90137555522304, 65.44622113627773, 70.88610141508042, 64.4772348865386, 77.66154089281636, 41.80690411598452, 43.82040969787106, 75.0702662621775, 63.62473518617692, 61.57486138805267, 48.923303465689386, 54.39404495300786, 49.5691962395945, 52.30473564517114, 55.611297622803725, 63.31193400967506, 64.7782414959323, 71.58771930202361, 67.09292627150013, 62.772968969037464, 56.95583904943159, 49.62506648032896, 50.02489720621417, 54.35757867751583, 52.44374444407802, 53.73163115593695, 52.02382333817021, 53.75468684780983, 61.85113353113975, 66.4666178918654, 69.33667890487179, 66.4685869216919, 64.5073861460532, 70.33768346232753, 71.22671219610399, 70.70095769820675, 72.23909162705945, 71.41318951883625, 72.85523322320753, 83.62739532224595, 83.40615011030629, 26.153160141360377, 1.6216991673554144, 1.396214853852026, 0.7734576288250186, 2.8228089549849114, 1.7131623433482264, 1.3720206940366377, 0.7338768075550757, 0.16035700337060038, 0.5013982645205913, 0.1655354206600497, 0.0513775947113191, 0.06592004259507503, 11.410220919116853, 53.18670019026726, 43.649794440115656, 44.387631493230025, 26.472460685237763, 28.1613685623292, 59.44770905279345, 70.24693550602083, 71.17239521395776, 77.45425147394981, 39.75079374928629, 1.2221775732694136, 0.018865941693225217, 0.05253777358560793, 0.038501954967937166, 0.07827125684989077, 0.017435456355733257, 0.024105063789794524, 0.032985156642333154, 0.024919790636387565, 0.09149318365680595, 0.024319238990785617, 0.037541613959136515, 0.055285370908677585, 0.02116568210054069, 0.03071474591119876, 0.09197147533057198, 0.05763877002942947, 0.012440459667554787, 0.019670981358015732, 0.018045404069726507, 0.054675158894350456, 0.05080322029008981, 0.034076567634098956, 0.051703967319260684, 0.03600382651653021, 0.08230667095631361, 0.0352327207163457, 0.029837368394158063, 0.036050174835949175, 0.12356079679222838, 0.20724098678798447, 0.09798443050033624, 0.18823428409955195, 0.12926543221598671, 0.11677676646579659, 0.10280002088796708, 0.07943041682724031, 0.141934166932779, 0.11927016815471074, 0.15386802414732595, 0.13291971758008003, 0.07564980356443314, 0.19335892201671678, 0.10122669845699303, 0.11446288982105833, 0.3239814330252909, 0.1263959579650433, 0.2163649101050631, 0.1649614216219033, 0.10934290971847312, 0.1827045388880276, 0.19566746668950205, 0.7836960568543404, 66.69981848809027, 105.740290611021, 96.43334557933193, 96.8571969001524, 85.11059253446518, 69.55539026568013, 78.41787584366338, 41.82548830586095, 45.08627622358261, 68.84136984425207, 63.73407909947058, 41.06530158750473, 8.147064380107388, 1.0732342687345322, 0.21757174373394061, 0.2721375052727038, 0.4049321666600243, 0.35154383629560476, 0.9488039391656077, 4.400286953295431, 9.73850969345339, 11.097079477002545, 11.242358184629872, 5.988673798499569, 20.227211906063943, 47.542515416299146, 69.14300011050317, 75.16845103233092, 71.21243476867676, 73.29866501592821, 75.61731923011043, 74.93791764782321, 79.25348974043324, 72.0329632297639, 69.85511426002749, 67.66050892491495, 74.47332859039307, 75.28256847012427, 68.94533618803948, 68.94460662718743, 73.77698236896147, 72.53170044191423, 58.448559776429214, 51.967906028993674, 68.54383453246086, 72.1723799551687, 71.52190193053215, 70.19580348845452, 71.17836506136003, 61.13950967788697, 54.96161583931216, 57.13063555379068, 61.65248117139263, 61.220694895713564, 67.03360434501403, 68.46412412581905, 73.52770789977043, 74.19966482347058, 73.38560042842742, 68.74054139660251, 73.45366139565745, 68.66533387091853, 78.2568625480898, 44.88829066676479, 47.92160464871315, 79.24540181313792, 66.48440191822668, 63.988809585571296, 51.8118662987986, 56.925122968612186, 52.960755978861165, 55.50124376050888, 59.60504316514539, 65.35923473296627, 69.22828028278967, 76.11647221349901, 69.0606774053266, 65.92835103311847, 61.639635409078295, 52.76714778715565, 53.65761210841518, 58.182846653846006, 56.7674829113868, 55.50646443520823, 54.65916579769504, 57.18103801050494, 64.35104831572502, 71.20961850689304, 71.961285837235, 70.03881454467773, 64.42397302196872, 72.96886428709954, 76.05573038901053, 72.78918050950574, 73.17743239864227, 74.77662978633758, 74.59412974696006, 86.63049528675695, 86.66832262469877, 27.069219889179355, 3.652251982881177, 9.089064232764706, 10.481429157718535, 5.771809874042388, 1.851310304576351, 2.29459390524895, 0.7236731905610331, 0.2745629396409758, 0.6846592130680239, 0.5379260415511747, 0.16519529294342766, 0.28846155191140793, 18.532753875178678, 71.53214716142224, 54.27681707566785, 69.97592326133483, 32.53549968042682, 31.079421735578972, 67.27707370635002, 82.87254302732407, 79.28494714921521, 88.46982017640146, 44.421520771518836, 1.48737772337852, 0.14682300298685028, 0.2289384047711088, 0.19239447860708161, 0.17757588667013954, 0.14586770666703103, 0.1417484672199334, 0.16478621731362036, 0.12814486008738318, 0.20073590439654168, 0.14338745104689754, 0.11042439604117987, 0.2208493743091822, 0.169340395518849, 0.18712062208402544, 0.18943230771730024, 0.1952679365152313, 0.18580766995587658, 0.13811261393129826, 0.16520914381309865, 0.1784529347693728, 0.27601982436833844, 0.11066183733243136, 0.19970380010143404, 0.12627915253922825, 0.2774738592486228, 0.15456818254484286, 0.19258158792170788, 0.14874546998931518], [0.01764719731234495, 0.00977108279438389, 0.10176900443771195, 0.0483442236098551, 0.09336586260507185, 0.024522240799401077, 0.06399036670524268, 0.03532212317710923, 0.032911589218964504, 0.053829777039467334, 0.026269700761223515, 0.03157401310970947, 0.030841290229751222, 0.03574658951331531, 0.10643533791505522, 0.006940011094669782, 0.02786977306729363, 0.0901627264195873, 0.050184600460793705, 0.01612684794611508, 0.03868115825518485, 0.2014687134613914, 0.24397127150047213, 5.535454711606426, 66.5209819424537, 75.48209159604966, 76.58587009676042, 64.13864804852393, 48.97040720908873, 29.824261319252756, 38.17529924454228, 39.31168440849551, 62.114324569702156, 45.22806206057149, 34.03396275735671, 5.02292154296752, 0.10626741144205294, 0.07220759432041837, 0.05223228453448223, 0.07711260249057124, 0.032758149468610366, 0.23537354333506477, 0.7884635139376887, 1.511780871979652, 1.9180359499108408, 1.8954038740165773, 7.213401525251328, 18.841864101348385, 51.37063103337442, 59.6242117881775, 66.77539471657046, 61.97964214509534, 68.3240484422253, 71.87818650276431, 68.35043814874464, 68.89966410975303, 69.85285497480824, 61.196360511164514, 55.50095350511613, 61.622094569667695, 66.77895622868692, 68.58719241234564, 66.86696637061335, 66.58441451288039, 69.8656968147524, 61.8784136156882, 50.84927351244035, 47.56052694013042, 63.42225459314162, 65.36665585733229, 65.1144709894734, 67.21634757134223, 67.72741671531432, 60.266903908021995, 57.13684074340328, 55.79944587522938, 63.612815103223255, 63.981627725785785, 66.30529865141838, 64.80303087542134, 68.55356985522856, 64.2902280438331, 69.70163975992511, 62.062286484626036, 67.2785092938331, 57.680700902015936, 73.13849895231186, 36.30044552587694, 43.612229900975386, 71.91476652699133, 57.10510876870925, 54.75993148742184, 47.34736573311591, 49.37176373697097, 45.69365524476575, 47.466390055994836, 44.52246296790339, 49.88820652807913, 51.571425007235625, 53.923921431264574, 52.60228272407286, 52.22402111176522, 47.84614609133813, 48.8161325454712, 52.276192557427194, 55.28157534137849, 56.28851052253478, 52.56468680597121, 48.65675487825948, 48.448543702402425, 53.59869026368665, 62.19064212614491, 64.07900841005387, 65.50416631083336, 62.57096690516319, 68.06499942656487, 70.1319080783475, 67.83520344764956, 63.39673173043036, 59.78123603328582, 70.20522502160841, 70.7417268137778, 70.18492283359652, 80.21052452825731, 47.02290335009175, 5.486308393939849, 1.2588432767698843, 0.26206403129523803, 1.7632581197446393, 0.7908861903894333, 0.4943639532692971, 0.21598940444809778, 0.09953135354143959, 0.03387543508001874, 0.10086453805166869, 0.09141410806126173, 0.31334543600678444, 18.9865779876709, 47.56968175211261, 29.725803944372363, 28.28443684885579, 28.005187626807924, 34.35557357726559, 46.80627476784491, 65.02454280853271, 66.71449599727508, 66.30172929456158, 8.99817212935417, 0.3842389367280468, 0.08574862739131336, 0.029211261970621925, 0.016447754516716928, 0.07666107792887958, 0.052049630021135655, 0.023131164939953916, 0.0334707529644572, 0.02645457501433069, 0.0492259142019095, 0.06895608734339476, 0.034383201986671455, 0.0031513802429300646, 0.09265340849637024, 0.017159934748985597, 0.048406173309852044, 0.05275026722360523, 0.04298495977456051, 0.06521413853812603, 0.10810540192910742, 0.015887073917134155, 0.07327338350155661, 0.02719552759381552, 0.057765484802545085, 0.09972130504226494, 0.032868584873335015, 0.11478413347034686, 0.03869472184188424, 0.02438418026412687, 0.035469449545827605, 0.06829729003290977, 0.0042691178462137625, 0.04029869545070876, 0.015934746611052226, 0.01421352803346611, 0.02438715460049289, 0.03546400649112559, 0.0275993938257377, 0.020131333167814923, 0.07256233133375645, 0.12133378685722429, 0.05492730524330851, 0.08488497816987577, 0.008661846851839895, 0.019601619757351377, 0.04182213406649329, 0.031094465051747622, 0.03291443906604283, 0.13009217898211173, 0.046931385107698946, 0.1730090680141603, 7.829878484049152, 80.88051242213096, 86.02921947356194, 82.76799617275115, 73.26749001779865, 57.26727916348366, 47.40569922231859, 45.468942657593765, 31.943106074487012, 47.98452338864727, 48.16938469486852, 37.733118687906575, 5.008908875526921, 0.057399819544967146, 0.054988986812531955, 0.02586685725668025, 0.07786615721641049, 0.3493504039943219, 1.4404392098226857, 2.0393439502485338, 2.9775614123190604, 2.786855284244784, 1.5756160982193486, 6.589342134614145, 22.65565718373945, 55.50498570165327, 65.51865946862006, 70.74418221750568, 67.07236520705685, 72.59558800728091, 72.37380150825747, 71.63917295394405, 71.72548863195604, 71.02572994847452, 64.7645406569204, 58.71207244934575, 63.86276029771375, 71.43596280005671, 72.61916929675688, 67.48675577102169, 67.62746687858336, 72.39793192955756, 65.2065800082299, 54.24219823652699, 49.48672056198121, 66.21953210523053, 68.54450133539015, 68.35270527870425, 67.89124627267161, 69.86971332180885, 62.374601287226525, 58.96091153544765, 58.055055833631954, 66.7243254569269, 66.2554531712686, 67.94442576746788, 67.49958192148517, 71.31778178676483, 65.64470483410743, 69.7913129868046, 64.5031068401952, 69.97459750021659, 59.683604317326704, 73.4069695011262, 37.633494407899924, 47.95365433539114, 75.37643863308814, 60.02899254522016, 57.70042650161251, 49.41227397611065, 53.87292277428412, 46.83721442376414, 50.139912866776996, 47.32978959237376, 52.133473196337306, 54.51721129878875, 57.02840681998961, 54.66653593124882, 55.02789605048395, 49.952796197706654, 52.212669772486535, 55.71918241439327, 58.50005265205138, 58.333583339568115, 55.5737409284038, 51.147365800796024, 50.97756247366629, 55.30149705948369, 64.60360973112046, 67.5739186809909, 69.69717610266902, 62.868706180203354, 69.93091798597767, 73.61524735727619, 69.98596452897596, 68.19140957247826, 62.72990918928578, 71.7475558865455, 72.59006531007829, 73.95761536013696, 83.5651316181306, 52.124420365979596, 6.434636010277656, 0.4400101069721484, 1.3845154042205503, 1.4646180478795883, 3.809118597738205, 2.158263840021626, 1.8721758430042577, 0.7191959275834022, 0.25864672756964163, 0.18174528955451905, 0.03894780281810992, 0.497304842236542, 21.14736072478756, 49.430003089289514, 31.883348764911776, 28.8023466064084, 32.40691654143795, 45.06390302411972, 53.40790617850519, 73.81684149465254, 72.34010834847727, 80.28097814129245, 18.00795251323331, 0.583988395669768, 0.10247875425604083, 0.029002983731427984, 0.11173560148886136, 0.02340704660802599, 0.04900223184977809, 0.02701244407123135, 0.04093454459742193, 0.03603123331202134, 0.07197670308091948, 0.10648442116836387, 0.04971183228096174, 0.008147355608431803, 0.032925700558529745, 0.03183184000062606, 0.07205723424351985, 0.034199099567148, 0.06047125755538864, 0.020643541469208656, 0.02525942805673807, 0.03153724855022325, 0.0596122891311684, 0.13017254160536876, 0.026709103896733255, 0.059789807024982676, 0.0617544663198773, 0.013267483182942436, 0.05675568515735288, 0.14031769076903022, 0.11009717690608195, 0.1974272932256422, 0.15617696718583185, 0.15804734020944566, 0.1638782805492801, 0.12653861119742357, 0.20059869804930305, 0.10893179629478725, 0.11754597236792888, 0.0893843734276391, 0.12599769949672684, 0.22247429276185654, 0.09993104459417444, 0.1969555209601118, 0.09658622044709422, 0.29595922378282397, 0.1738404879166234, 0.18104128539562228, 0.13848510120184193, 0.2747533890989519, 0.27392491097411803, 0.37650573878519, 12.519425038368473, 95.06377158626434, 93.1522358617475, 98.47072662845736, 84.39133967122724, 65.91667805948566, 44.06698557638353, 47.04698670294977, 55.420466469180205, 81.8048660216793, 64.58581786001882, 49.42797130154025, 7.566058395370361, 0.4052074986600107, 0.11808749693896502, 0.25078003114509967, 0.3353842227689682, 0.31844221896702246, 1.3557203041930355, 2.78586684696136, 8.480512422900047, 6.977159130957819, 8.367766834074452, 11.909255250807732, 24.431053323130456, 61.4345189832872, 67.42423319047498, 75.47301523147091, 69.63598712798088, 74.52899486787858, 73.76472103980281, 73.97460706772344, 75.15223595403856, 75.05482781317927, 66.70494894827566, 60.1579483093754, 66.12817225917694, 74.84276094744283, 74.24694507352768, 67.28240028504403, 68.61545701180735, 74.73944571710403, 69.7622246896067, 57.40863353975358, 52.949969460887296, 68.23646976101783, 72.41708094073881, 69.32852821965372, 68.61908912658691, 73.40413754986179, 66.82914687741187, 63.876390534062544, 60.105486608320675, 69.91995888371622, 68.47482435164913, 72.55683498997843, 68.52653688000095, 73.65039179402014, 67.7318960620511, 73.58778292132963, 66.98923449362478, 71.4983755542386, 63.55415213492609, 73.83258588852422, 41.848814641275716, 51.075425609465576, 77.14747505803263, 63.582048031591604, 58.94199394410657, 52.808164012047556, 53.91110704791162, 50.28490328019666, 53.165652751922615, 50.013671382781006, 55.287702083587654, 57.45212870259439, 59.36544518316946, 59.41679685346542, 58.12572517702657, 52.60625216268724, 53.757459963521654, 58.662160288903024, 60.39602048935429, 62.73065443961852, 58.28409087273383, 56.10011908315844, 54.71549887810984, 58.23133891628635, 66.44266789959323, 70.23081456461261, 71.11263398201235, 63.787074242868734, 72.85663743172923, 75.41130065917969, 74.8010818419918, 72.09642717915197, 65.95585469276675, 75.62917263277116, 76.06347314773068, 76.01009753442581, 87.70692702262633, 56.080875935093054, 7.610493456163715, 4.585795940891389, 4.641431820008063, 6.9831417260631445, 4.81955498456955, 2.148296852265635, 1.3023357429812032, 0.5960624929397338, 0.7156539660307669, 0.27851797580238313, 0.22914233737655226, 0.936541322979235, 29.821511737761963, 68.44569683074951, 40.9849283003038, 42.357953979123025, 40.332834259156265, 49.70209790814308, 63.08003171797722, 85.0202368151757, 84.54020930874734, 89.07180986096783, 18.741804438252604, 0.8921884480983981, 0.14159667455861646, 0.156690000946964, 0.17528122351054223, 0.27794812896078636, 0.13356010579774458, 0.15652149224713927, 0.24618166498839858, 0.13086180623260238, 0.11834540043867404, 0.24903707386505222, 0.22632301124113224, 0.18648038708394576, 0.13368801183758244, 0.10907231214185877, 0.17951560597265923, 0.1027601306897498, 0.08996755019911835, 0.13245968178154963, 0.19871642001934592, 0.10951727133003936, 0.14118059688518125, 0.23696132184517002, 0.22988245492019962, 0.2400534825339433, 0.15832254963536418, 0.17207729059361643, 0.1489436875788435], [0.03518997301017085, 0.004010409954184246, 0.03464966268849469, 0.03420112586970772, 0.027009199688872023, 0.0034756779496092354, 0.037065789088486664, 0.046974910393116937, 0.022586997365579013, 0.05175926737607487, 0.008119033337871154, 0.1085580219965308, 0.048624971851466164, 0.050505388287767294, 0.0367042338926225, 0.07406279114225219, 0.055651679680111914, 0.06970928966878884, 0.03645933090498851, 0.05949507767875349, 0.07745567198482252, 0.08523886482561789, 0.12927243425961465, 32.85861669048187, 81.275832422318, 73.71244369014617, 69.2916500952936, 54.826376438140876, 38.62504997561055, 14.251872204965162, 18.281847699995964, 49.051721865131015, 51.66980981826783, 45.627453480997396, 10.842081289137564, 0.021276128996584206, 0.14404674631453332, 0.09546577855343781, 0.060787464176575025, 0.07548764573350068, 0.08354722777561796, 1.8088117914815105, 2.311429208324802, 1.3235249995223939, 2.134110374796775, 6.301366619525417, 25.83849976139684, 49.999178224994296, 60.360236706272254, 67.1026772837485, 65.68674087524414, 69.22686038478729, 68.0959390824841, 67.90608852140366, 71.8468624545682, 64.13361956996303, 64.71922159194946, 54.76719963935114, 56.84737374705654, 62.88240309684508, 66.60911760022564, 66.33078621279809, 63.584805457822746, 64.48191427415418, 67.36519367464128, 59.55894747088033, 49.29658759024836, 46.54951249399493, 56.59827186215309, 64.85363337301439, 66.95676511333835, 63.20020921768681, 68.29463851067328, 61.06838141718219, 61.63195933065107, 60.75226191551455, 66.5897254020937, 66.28477681067683, 69.28046349556216, 66.08033503255537, 67.32793900274461, 63.17527078813123, 67.48257452441801, 60.71102211552282, 64.5975535915744, 56.42984920932401, 68.19604581402194, 34.0899859705279, 44.474296262187345, 69.37030930672923, 53.694972684306485, 56.1348516710343, 52.77741655226677, 57.94728871314757, 56.95995753811252, 56.63455770861719, 48.90796307594546, 47.71487220641106, 41.67671672759518, 46.359936498826556, 45.10727267111502, 47.61099215476744, 46.90243951735958, 49.377011868261526, 54.907855833730395, 56.91236349844164, 55.17356111157326, 54.35977520481233, 47.21440915138491, 48.670079169734834, 50.58314854098905, 54.928463966615745, 59.75008849174746, 68.13085602175805, 65.3620784513412, 62.819747155712506, 67.13612725657802, 68.41980134287189, 68.9681722271827, 62.87520554757888, 53.5575799019106, 67.83723523539882, 72.70664599633986, 69.64063905900525, 76.27983893117597, 58.37533304768225, 9.006096297694791, 2.1854083576510033, 3.042320724456541, 1.1216668376038152, 0.9216042019186482, 0.4134805434413495, 0.2068409509956837, 0.17095975217319306, 0.2028608331156354, 0.11192731499191254, 0.0923267945707325, 3.0398221746567757, 33.196925040214296, 48.77270406292331, 46.534583953119096, 22.675292568822062, 29.372021844310147, 54.10340124560941, 53.03863071626233, 59.91593022500316, 65.25051055415985, 52.81421230685327, 2.3022484106402246, 0.13259794533012376, 0.021345777880220164, 0.0923951066309406, 0.031735772574921293, 0.039989387451280514, 0.03234069666735107, 0.045503458503874085, 0.06373930820113709, 0.08730853562273326, 0.051730424165725715, 0.0496539619991616, 0.019040203713361296, 0.08605573671839892, 0.04102232295178598, 0.028316743236275452, 0.06766757342003046, 0.008513716090801022, 0.02591484691947699, 0.028901898429819176, 0.037866462052108786, 0.04831061916305654, 0.08720332876809182, 0.04022762547397325, 0.029802413717392954, 0.028377821511258523, 0.015583343037794677, 0.039126806922497294, 0.02797205921172375, 0.09960351136302757, 0.011948397563349818, 0.03602716155470379, 0.028128913799000364, 0.011289030474971139, 0.02808456688428358, 0.05371395986707461, 0.02230986314375074, 0.025402102356536255, 0.01957652654739157, 0.029795716193714933, 0.05305467992119732, 0.022156668541532372, 0.0328708180196343, 0.030547763641563155, 0.021838165571792953, 0.034118357730368455, 0.026812322753211184, 0.057905602283895984, 0.04211675616041307, 0.07482502564427353, 0.04069210075202488, 42.9593631529039, 91.89422976586127, 81.47592036954819, 79.77702417681294, 64.6115093846475, 49.95713433911724, 23.228701737619218, 24.64879389732115, 40.08918839116251, 49.910897439525975, 44.89149916556574, 10.908135964024453, 0.07015112321823835, 0.04078810306025609, 0.012109862084710791, 0.11715183545264507, 0.33315453918710836, 1.1746096418749903, 3.9926021714364333, 2.9372963213151504, 1.4896875091137425, 1.21390002389108, 6.035097010674016, 29.251271678555398, 53.64017325062906, 66.76618499140586, 70.16379694784843, 68.50618762354698, 71.8328046798706, 70.37453805246662, 71.28416707438808, 73.01486584448045, 67.11733125871228, 67.74026639999883, 57.95792618105489, 58.97495362066454, 66.53569867534023, 70.69792962843373, 68.37303100093719, 62.91853204850228, 67.1083882547194, 69.80088357002505, 61.56733435969199, 52.09913676784885, 49.13052620426301, 61.1085896338186, 67.29887423976776, 69.13832464525777, 65.96995169116606, 69.46863528220885, 63.78786263927337, 65.41818403428601, 63.46992315784578, 69.18432620263869, 67.69659473050025, 70.86175134105068, 66.78252558554372, 69.65603043956142, 64.6497054253855, 66.6148050369755, 63.09027302649714, 66.8249656308082, 58.52563827268539, 68.03673482710316, 37.19869575192852, 46.02196939529912, 71.94910295547979, 56.29427640668808, 58.74647163575696, 55.877226475746404, 59.99531507492066, 58.49314143580776, 59.860228646186094, 52.38849393783077, 48.65806102752686, 44.609037522346746, 48.46901847470192, 47.985205881057254, 50.33709041533932, 48.32981355728642, 52.74834002217939, 58.05254943909184, 59.556452843450735, 58.08281052497126, 55.54289933173887, 49.928187247245546, 52.10725607410554, 53.2432686128924, 60.56537666628438, 63.70774038376347, 70.07476698967719, 64.89381021068942, 64.49179472461825, 70.42521507509294, 71.05648133062547, 70.91935526940131, 67.57726838511806, 57.49060715398481, 70.86989418152841, 76.76187469113258, 72.08480911870157, 79.84384567506852, 65.49752573813161, 11.507394698358352, 0.20019038850742005, 1.0181693396260663, 1.5804641477523313, 3.7515117276099423, 2.5060003419076247, 1.1065905949761792, 0.4986274777160537, 0.661959415001254, 0.06221179399759539, 0.15560998551307187, 2.7764818408796867, 35.42042255401611, 47.53044236090876, 38.09687537531699, 23.43748557952143, 38.090270103946814, 60.05703749195222, 59.395443470247336, 68.94474783251363, 73.22434394590317, 69.00804704235446, 9.52139179552755, 0.12159206574001621, 0.03243999698409631, 0.04818365158092591, 0.031108551493455327, 0.05882895656771237, 0.08166088181878291, 0.009162149189280407, 0.014538255467590307, 0.05925130850124744, 0.020655306664505796, 0.021495865995905573, 0.05213504499425331, 0.013115963440448528, 0.04415307531974489, 0.07764127210623796, 0.08638568312650727, 0.015262680657718693, 0.08273533545434475, 0.08675051717868737, 0.05090524787984548, 0.04676013381310529, 0.040955680963252826, 0.0017276869930942815, 0.025463084870528792, 0.010206687091399106, 0.023898361776504787, 0.061681607527838606, 0.16847877643041073, 0.17804303176460728, 0.07643044715927494, 0.11691666178164944, 0.14276837539528647, 0.1537377432349228, 0.18703555568091332, 0.22110114144461773, 0.12959978362965968, 0.12324702250020159, 0.20020358054147613, 0.20741510325141493, 0.14380673096785623, 0.13302966651897277, 0.17365878718274255, 0.1508842342563214, 0.13760246066076143, 0.1591448071262529, 0.0826579912175094, 0.15303498013846337, 0.14216440699754224, 0.1788010910874413, 0.3882482119144932, 50.26719770123882, 105.8019345806491, 91.37497855770974, 89.00266631957024, 73.25330672725555, 53.77489097656743, 25.407064537848196, 29.815318315259873, 69.94677220621418, 68.49033340331047, 63.94074093910956, 15.3860951623609, 0.19280657262331058, 0.2538651285032111, 0.27489419605943466, 0.33458862513784443, 0.493994606959243, 1.2653492631450778, 7.620950004746837, 8.211926654461893, 5.322658775314208, 7.153176963329316, 11.176439812106471, 32.93861343014625, 56.80315686810402, 67.22297637693345, 72.29376946726154, 68.1437998433267, 74.18581101202196, 71.46721624558973, 71.79241995657645, 75.70561178268926, 69.10246633714246, 68.84046769911244, 60.82308423134589, 62.16222455424648, 69.05833967270391, 72.51461459744361, 69.41494587929019, 64.04819034760999, 70.13159428873371, 72.06821749287268, 64.15497687555128, 53.75616950373496, 53.05397502837643, 64.58874787053755, 71.0233373026694, 71.58360081334268, 67.33106905414213, 71.44553338327717, 66.16800785064697, 67.1819091612293, 66.13572674412882, 71.28279424482777, 70.51671612647273, 73.31156176905479, 69.46039046010664, 71.66262088283416, 66.48601793473767, 69.00930220080961, 63.85334660930019, 67.85702751528832, 59.87085826935307, 69.23650941541119, 40.6817251636136, 50.93257681015999, 75.354355689018, 59.838604619426114, 62.60705663311867, 59.176822323952955, 62.15607427781629, 62.22779481641708, 62.52999382634317, 54.80350117529593, 53.209030243658255, 46.85406492602441, 51.092311413057395, 51.860009470293605, 53.003698087507686, 52.42641541265672, 55.025036642628336, 60.606687068939216, 62.32560696140413, 61.76602986551101, 58.57950025989164, 52.32237454383604, 54.55930225310787, 56.35026431852772, 61.94282677865798, 66.02399410740023, 74.10121333214545, 67.53868010736281, 65.22789809011644, 72.53392050343176, 74.1476934186874, 73.27768818024667, 70.47007130038354, 61.61182972692675, 74.07236037715789, 80.65048110100531, 75.44192652548514, 82.95322618176861, 69.25143795628702, 12.469277535715412, 6.417279522265158, 10.106807504930805, 8.490760595567766, 4.831802095136335, 2.3531639624026517, 1.257037883324008, 0.806800717067334, 0.5515725802510016, 0.23387524389451553, 0.2589692505857637, 4.718228886204382, 50.00009605961461, 69.40038604121055, 66.76008178341773, 32.55082830306023, 43.05817157991471, 68.05349903721964, 71.21498430928877, 78.66377707450621, 83.4325868852677, 80.4788460270051, 10.794364675398796, 0.5735312342163056, 0.11420104096853927, 0.21108919964923015, 0.13291118336060356, 0.16676151373934361, 0.21538906730711463, 0.10816337946321695, 0.1874100347800601, 0.21193958788869843, 0.1602079226605354, 0.13218548359169116, 0.1635278872544727, 0.20324597615868817, 0.12453598841544121, 0.13207277673627102, 0.22984323121847647, 0.13606763414798245, 0.21341605382340573, 0.1762179958243524, 0.1686417386536637, 0.12768012816987692, 0.17093816381548682, 0.0928313170950259, 0.19848565901479415, 0.18817740973205338, 0.1314725008823218, 0.12023998184069512], [0.05205017777400152, 0.06472339793559044, 0.0322718330238375, 0.018498663820566672, 0.053408555085620577, 0.01817873209684847, 0.07936633357237424, 0.030932387660047224, 0.022145445353441665, 0.10180068983426017, 0.021251926363836375, 0.028347945997431397, 0.07412162669483693, 0.032065812828800375, 0.05754974295174884, 0.0056631249495812, 0.07459889181078443, 0.07181551052077163, 0.06700859990932288, 0.02665738530096508, 0.04826828131392118, 0.10285774561306162, 3.0817959481670014, 67.46169182562059, 78.39941716963246, 67.63137355927499, 66.00171504482147, 48.04207240381549, 24.30753396403405, 30.956029853513165, 30.696435628398774, 42.07608461380005, 48.009614790639574, 20.207511801873487, 0.1626760128044313, 0.06620055334942956, 0.02513528542382823, 0.08708948044166451, 0.04837429256088311, 0.23309103032994657, 1.6408161867049433, 1.748109680991019, 1.836880149860536, 2.404130259829183, 3.7957013951193903, 25.107175803953602, 61.34804641046832, 69.27728637572258, 77.98945103922199, 72.77360869992164, 74.07259571936824, 59.83985977788126, 58.7219254432186, 72.01201777304374, 65.96258547998244, 65.39955669833769, 55.05480350986604, 51.75272872371059, 58.21177021149666, 63.54074939604729, 66.82081576316588, 69.56744763158983, 64.57978133232363, 66.09645597396359, 65.65047856300109, 58.02528504402407, 49.39316026626095, 47.03241509775962, 54.88774584185693, 62.743680630960775, 66.74804795172908, 63.18218592674502, 62.979705333709724, 64.64927788703673, 63.937018609816036, 65.0795187488679, 66.18809038592924, 63.86308977680822, 65.44141231044647, 61.58729922386908, 63.190560187062914, 59.37338406039823, 64.75583691750803, 60.52636085018035, 62.77365538381762, 55.23449513220019, 62.795467684345866, 34.195285920173895, 44.59954146415957, 67.59511516940209, 53.6463588283908, 56.781752494073686, 56.54046004818332, 64.92243959057716, 62.03659888236754, 66.53613798079952, 58.720937005935184, 57.4862729349444, 48.93683956515405, 43.87731544433102, 44.20881848181448, 46.939870695913996, 46.92343204252182, 56.96209522985644, 58.52009596363191, 63.14808876283708, 59.34266797957882, 54.051390617124504, 45.79798636897918, 48.29336297127509, 46.8631765919347, 54.08220475719821, 59.251021800502656, 66.73755168914795, 66.21073815130418, 62.550386228869044, 66.56004874936997, 67.53871148632419, 68.97361647698187, 66.40256558695148, 62.516547941392474, 52.64904129889704, 65.17251030091317, 72.06253005612281, 73.1280497581728, 71.7005737366215, 62.56727595483104, 7.135573856292233, 0.815999962149128, 3.6867406483619445, 2.8966328645906145, 2.657304055267765, 1.274222399919264, 0.06926415428038567, 0.19726566399537748, 0.04545809460743781, 0.07844388710274812, 0.06661483837712197, 8.183997907946187, 38.94445642348259, 38.895532700323294, 34.44345035860616, 20.207123487226426, 49.346138892635224, 50.954659754230136, 56.92865702413744, 64.35004026659074, 67.89352124737155, 56.543068424347915, 3.3147462481452576, 0.10731194934417164, 0.06273981243852647, 0.05240961090631543, 0.006048924913029037, 0.02449545453512861, 0.01436623808507237, 0.06799357447532878, 0.07834264858355446, 0.04696080671443094, 0.04147362151753999, 0.053931942525049376, 0.08044891540081271, 0.09272359747199282, 0.01549409187939619, 0.04636166467060966, 0.02806413914978264, 0.05685895763998551, 0.03340184335566817, 0.036921956080703006, 0.054575425737928, 0.015186628236645653, 0.00187499109738236, 0.06182655519355209, 0.05365870194509626, 0.017633924839056788, 0.02522050504452519, 0.01349361605882164, 0.019931265475949454, 0.07414599595170829, 0.03513376513916639, 0.06458999904533548, 0.03681161643696889, 0.04013626565856319, 0.027492241107768593, 0.08825063224761717, 0.059565599902623126, 0.02601234309916054, 0.05030415997269654, 0.089591033306093, 0.04400044379215087, 0.01952583642466174, 0.037120146857153986, 0.018773842602968216, 0.04183162589587512, 0.0765306821032878, 0.010693114618920993, 0.0825550826266408, 0.16573160045569943, 4.844993516322106, 82.4437181411251, 86.29901578349453, 78.47636622767295, 71.9964224292386, 58.431622982025154, 34.64998276002946, 33.14861712917205, 31.410303077390118, 47.420627763194425, 51.13371987496653, 23.347626040058753, 0.11936424375181237, 0.011598407422312567, 0.0717121116336315, 0.18816550472571006, 0.3179479083947597, 1.2377808843889546, 2.9756514631932784, 3.160920450764318, 2.249885259136077, 0.22684718392068343, 5.473292989115562, 29.16115522384644, 64.69052945413898, 75.32215302990329, 80.16320505449849, 74.79325279112786, 75.75846964313139, 62.02375704242338, 61.20673518027029, 73.81714743952598, 69.02842767776983, 68.56914166481265, 59.30558196959957, 53.73589477231426, 61.10376511850665, 65.4885591999177, 69.02827862770327, 70.88617986248386, 66.79055859965663, 68.86532768126457, 69.37731465985699, 60.54947145523564, 50.661568487844164, 49.635025378196474, 58.01365521646316, 65.4013531438766, 69.29259930887531, 63.487667960505334, 65.09875797456311, 67.68130533156857, 65.11947201144311, 67.47591433986541, 68.93809549270138, 63.88613762394075, 64.52149098919284, 63.743120162717766, 64.74995336224957, 60.30295048990558, 65.00967702557965, 61.963984043367454, 65.2375667325912, 57.20143041303081, 64.66327290381155, 35.68185244837115, 48.65183230369322, 70.44364237016248, 57.53539669898249, 59.60831834423927, 58.551168980137, 65.80682816043978, 64.62358636240806, 68.96938816193612, 62.89966937034362, 59.16293713354296, 50.904257297515876, 46.12201336891421, 45.97231218891759, 48.67719434922742, 49.7005368048145, 59.787272560981016, 62.17863967341762, 65.35526921672206, 62.033813999545195, 57.56272385197302, 50.55289922222015, 50.829724419501524, 49.786636752467004, 56.05552957903955, 63.19192124951271, 68.88395109484273, 66.8841463519681, 64.16950141229938, 66.71906163615566, 68.62051686932965, 71.61523080641224, 68.66946804908015, 65.31008743470716, 56.576608611691384, 67.5994925345144, 75.80684815683674, 75.51392555236816, 75.45054789512389, 67.15812390850436, 10.297639639146867, 0.6676699569629085, 1.5070448551447162, 2.4981833033023344, 2.3031777672229277, 2.4237099962849773, 0.7897786723990595, 0.5643609779015665, 0.631796081940974, 0.14542317648808803, 0.06322636254011624, 8.68247232129497, 43.86616414593112, 38.22475248767484, 29.49067158083762, 33.22943756657262, 62.98122721333658, 58.20761249911401, 64.21701308219664, 70.91284413491526, 75.67862587590372, 76.24532991839995, 9.41509654445033, 0.11296065268857826, 0.008138615502825668, 0.05843725964246739, 0.04087401982096415, 0.052846062688096884, 0.07664714278953691, 0.026536500456953244, 0.026638642959897558, 0.05516547814852769, 0.07560365442787448, 0.03969065146520734, 0.040395551946975534, 0.01205891723774614, 0.004996710809909048, 0.015232274628004, 0.06422943976377288, 0.07132499974461333, 0.055520900810557994, 0.11871008893414853, 0.049341110843083555, 0.057094146632739616, 0.0159141963024834, 0.024413684225310723, 0.021725562138242588, 0.03789702896028757, 0.01200788141784048, 0.17538789359311904, 0.132855350872682, 0.10684684204358248, 0.10982703898222217, 0.14806630240092356, 0.09775644273407037, 0.1846656320436347, 0.12701156323835736, 0.15601331548344705, 0.2583234078220783, 0.11933536989794624, 0.13236359903408637, 0.16926993075157368, 0.19026971842733123, 0.2632303541946796, 0.0954707887684626, 0.16961889912284192, 0.12022224690524802, 0.23481448301144187, 0.19139884009716973, 0.2057713390358033, 0.3554955323136622, 6.778965688520863, 97.43814699111446, 96.6871621531825, 88.35066641530683, 84.25919502012192, 65.69946112171297, 34.99129172294371, 41.38440209050333, 43.64690365329866, 57.50333524519398, 64.83040509685394, 29.80124681226669, 0.4071746592319781, 0.15082418828481628, 0.252867084477217, 0.324335886586097, 0.32909531506799883, 1.0165536908372756, 5.077786676345333, 7.89372633541784, 7.394297805524642, 6.973212736268198, 8.007006837475686, 30.750768300025697, 67.24032109783542, 76.26323161586639, 83.13320021475516, 78.06923989326724, 77.89101523737754, 66.22871045143374, 61.86243780197636, 76.29837605261034, 70.18249880883002, 71.44331332175963, 62.79438903254848, 55.85557499239522, 63.23272566641531, 68.43155276390814, 71.4171354232296, 72.80663505677255, 67.54267308019823, 69.87225501768052, 70.29560427511893, 66.01864399448519, 54.62484505868728, 52.58209036242578, 59.98316357212683, 68.89798533531928, 72.27267496047482, 64.00202405068183, 64.98805692118984, 70.19927086368685, 68.3653510001398, 70.96863592824629, 71.25646729623118, 65.77567669653124, 66.18681169325306, 64.89897989457654, 64.53463092927011, 61.42775289473995, 66.45738463247976, 64.23655433039512, 66.67566453256916, 61.234584008493734, 64.94097671201153, 38.7805837200534, 52.78860315199822, 72.55645844244188, 60.441798471635394, 62.09715243308776, 62.088938989946925, 69.20036869664347, 66.67827683110391, 71.91152664922899, 63.93518294057539, 61.83465957641602, 54.89948941815285, 47.51132865105906, 48.39181446260022, 52.09031927970148, 51.38253934921757, 63.23374156028994, 64.62091522832071, 69.51573510323801, 65.09806763741278, 60.50062617947979, 52.58440848319761, 54.15599238487982, 52.67198716440509, 58.84397783587056, 65.1749853164919, 72.4314054366081, 67.99906438396823, 64.77395434533396, 68.49876649918096, 73.55570577806043, 77.44825809232651, 71.17266977986982, 68.71110793082946, 59.21683442208075, 70.82628526995259, 78.15891312014672, 78.49541325722971, 77.25111976746591, 70.98702399961411, 9.635585719539273, 3.138152807950974, 14.737559691552194, 7.584720542353969, 6.126904987519787, 3.4503641580381705, 0.706222688238467, 0.9689632671013956, 1.104890492654616, 0.569914992778532, 0.2136213500653544, 13.30255860282529, 59.31527806866554, 54.033939992227864, 49.62984784956902, 31.79963754069421, 65.88954310263357, 68.45820919159921, 75.06020146031534, 79.60262775421143, 83.91247318636987, 85.83081814550584, 9.938787875636931, 0.24767507678799092, 0.19166384523193683, 0.22227635096398093, 0.21939386854008322, 0.1937444327819732, 0.1414750657615162, 0.12284901684090016, 0.1600081575734, 0.16842881217598918, 0.10074132046992741, 0.1302676590820474, 0.25926214132097464, 0.17036457846481956, 0.1261760371046201, 0.14039132714031205, 0.08996518298743233, 0.20397230411969847, 0.12979691337433555, 0.2713190475779195, 0.17282972683108624, 0.10879463591282407, 0.12038705540039848, 0.24100591368492574, 0.16118123736833373, 0.10773392589462381, 0.13958360999822617], [0.07826228596029744, 0.03114376664011469, 0.14591891198388993, 0.07351460160627481, 0.03383098282821236, 0.03984464662930658, 0.04912252680608823, 0.09164860757488398, 0.0958669251732288, 0.042033961207996455, 0.012902902897387263, 0.04512446331641367, 0.07985063137546664, 0.016043397030913304, 0.061930471190041116, 0.013270615524942837, 0.03570541611782486, 0.05376348745137934, 0.0192169938236475, 0.0456005180134408, 0.1817786909880177, 0.08522196492600827, 27.042965504430956, 81.8969475838446, 73.5870219815162, 65.81340989758893, 47.84420059573266, 28.268710105649888, 22.72731496441749, 36.54454638881069, 38.59230210704189, 38.46213825287358, 41.686793296567856, 1.3728339729770538, 0.1273406133235943, 0.02329571296521012, 0.05412224642631989, 0.13748201631730603, 0.3183326683938503, 1.0478280965358981, 1.5150349683338598, 2.673842238803064, 1.5048767650319685, 3.018379802665403, 35.05463015648627, 67.95929155042096, 71.24072290235951, 70.50788294884467, 70.33989567910471, 69.43520099886003, 70.00515276385893, 65.72650586405109, 65.83368070663946, 66.91881225955102, 65.87312406109226, 56.99938912545481, 50.185843821494814, 55.377128201146284, 63.731392275902536, 63.801724295462336, 67.8708734819966, 65.14954482355427, 64.3369670068064, 63.28776436467325, 61.517175089928415, 53.00476497219455, 46.7685180325662, 46.80506275546166, 52.56260794977988, 61.65579165181806, 65.51265824225642, 62.51390426389633, 60.15440248673963, 60.94965911680653, 63.77024335245933, 63.89066011674943, 64.62679878357919, 61.002187498154186, 61.50173271856001, 60.53417028919343, 59.91851506694671, 60.35936986246417, 63.951143064806544, 58.865237082204516, 65.54825767394036, 52.8627202587743, 67.0673131942749, 32.36667694584016, 43.09475944888207, 68.05491893522202, 53.32402629237021, 58.80549938448014, 56.494419267100675, 63.369977243484996, 62.42647463275541, 64.67222375254478, 62.93334684064312, 65.89748982460269, 55.66019388937182, 52.65873347559283, 45.731357066862046, 47.94837874750937, 53.78140603342364, 59.85815371236494, 63.26827018491684, 64.73527977543493, 63.049194043682476, 56.01922412072459, 44.828964817908506, 49.3284607702686, 47.16395178148824, 55.351562192363126, 59.117971081887525, 65.80158787388956, 66.02808906186011, 62.89739831801384, 62.243935369676166, 63.11602338667839, 67.48045644452496, 67.5320513017716, 61.74812816804456, 55.040479013996745, 58.106278065712225, 64.96115730654809, 70.80945045717301, 74.22410118964412, 75.2508835638723, 69.70961001611525, 11.116932553629722, 1.6674688145998986, 2.3915926487215105, 3.292651782112737, 0.6562928771299701, 0.41621753044666787, 0.8676002126547598, 0.2921365369712153, 0.3805751671954509, 0.047031746456219305, 0.10921865791803408, 20.752770285452566, 43.2197496967931, 40.16498035000217, 20.69380529465214, 14.971012300060643, 34.365810963415335, 42.01900628305251, 56.54835970171037, 61.024207684301565, 63.30495219076834, 48.56068034325877, 1.1783711948702413, 0.03945394561836316, 0.019799341304948734, 0.09342209345871404, 0.08646241449300321, 0.051081256580448924, 0.07840405053068554, 0.06041851240180193, 0.03396671062575714, 0.034168743333148385, 0.014465156315465369, 0.06564338526297962, 0.023856939402438944, 0.08369010317349627, 0.05242899676123935, 0.035172598136048165, 0.048845279586291125, 0.05236841069774763, 0.03104657689560085, 0.016724197344193538, 0.04384269479722266, 0.028634227309075576, 0.03212002312554227, 0.036350098258304986, 0.06114621932107595, 0.011982726920846731, 0.015575076949091689, 0.06391373876061651, 0.09068788735256081, 0.02965107879361078, 0.09596339862553344, 0.037095578417422316, 0.009828078778340452, 0.007083647313617891, 0.0476129045860181, 0.047668070577445536, 0.021381146244464383, 0.05770712039403378, 0.017098011862066005, 0.017019143110261332, 0.0534319858847847, 0.05909532150854507, 0.012578142904526284, 0.02803510441745241, 0.06495541532433803, 0.03539446485979903, 0.19800326877063323, 0.07756917557168393, 34.184891639217255, 95.10917694337907, 82.06295013427734, 74.92613484782558, 60.97463677006384, 42.61489275963076, 31.39107757999051, 33.751450123325476, 30.03621247506911, 40.43466291119976, 42.500265413715, 2.4146203937069064, 0.050657855106457594, 0.03229693389467655, 0.21399445020623747, 0.47480324643754196, 0.7600531126222303, 3.7933962671987476, 3.8500914314100823, 2.3523079051125437, 1.2140806980671421, 4.204191488604392, 38.533317504390595, 71.71740070466073, 73.56776314397013, 73.17314132567375, 73.53110467233967, 73.08132648468018, 71.94252906307098, 69.46126907102524, 66.62053169742708, 71.09201800438666, 68.45739333860337, 59.72713478149907, 53.57787032281199, 59.06298337444183, 67.63363284449424, 66.3217882956228, 69.25790986707135, 63.93901117386357, 64.68920369302073, 66.78971136769941, 64.77276978954193, 55.81419398707729, 48.80937822403447, 49.945645716882524, 55.91176686748382, 64.08262091298258, 67.08537178654825, 63.083091166711625, 59.80092240918068, 64.3219913974885, 66.31883867325323, 65.92238903045654, 65.13240406590124, 61.974856853485115, 62.900567593113074, 61.93489182379938, 61.44577618568175, 60.83714592841364, 64.11192101816978, 61.03377434515185, 67.670503124114, 56.582680440718136, 66.24388217926025, 35.93255073793473, 46.3223131241337, 69.65212375886979, 57.34920963164299, 61.390596282097604, 59.69243357258459, 65.30416857811713, 63.8093101593756, 67.42122081018263, 67.00325304462065, 66.68979290992984, 58.253680736787864, 55.67789946832965, 47.63959800043414, 49.96138226601386, 56.3581443602039, 62.652218803282715, 64.87211950363653, 68.22305525502851, 65.26370148504934, 59.69416333783058, 47.98691211208221, 51.05130303290583, 49.24258439771591, 56.980200890571844, 62.1963530971158, 68.42309613381663, 65.87721901555216, 61.96759654629616, 61.00367799881966, 65.34726758157053, 70.20761766741353, 70.51568846548759, 64.88096052600493, 56.73393095693281, 59.7799494958693, 66.99004250188028, 72.68020137663811, 77.03719369826779, 77.16494529478013, 74.60675193417457, 13.952878752062398, 0.4184655694951935, 0.6056237605310256, 4.198734981398429, 3.0585524728221283, 1.974175976168725, 1.5928224329986882, 1.1340053884252426, 0.5181914940476418, 0.05359503620814893, 0.050279886476815715, 22.237950255793912, 43.48316038808515, 33.38754830821868, 16.10777303095787, 24.853943663258708, 51.11370009760703, 52.89564071163055, 63.732302265782515, 66.6891731754426, 67.91398817493071, 67.5408217214769, 4.046763239368316, 0.13785199081945804, 0.08879937336690004, 0.06868794890901736, 0.0586863378092887, 0.04563464723046749, 0.06728698093924793, 0.04455218797609691, 0.0033400863720734995, 0.025896428250557473, 0.022042094346796794, 0.03212818579237548, 0.07425099596261017, 0.07489504608055277, 0.03783394928060232, 0.04030717221359092, 0.034158830155408194, 0.08168717395634421, 0.025639656645756577, 0.02251868530537092, 0.026065473211929206, 0.0323630549434212, 0.060365158208315416, 0.04132749024598349, 0.05592945550057677, 0.03295121128640829, 0.16082649269411642, 0.14343565329909325, 0.2181619225490478, 0.17024652431568793, 0.21554243810955556, 0.12601911931508972, 0.24639364151704699, 0.19731084786115155, 0.09354087539137372, 0.11051464119866011, 0.08402135959195514, 0.17868075399629532, 0.12395647354424001, 0.10728795547038318, 0.16106451621219037, 0.1627451139352014, 0.17340297510306682, 0.15041652225678967, 0.14471924893798369, 0.11246271852043369, 0.250380378396761, 0.22870845581975677, 44.66490384071104, 106.4106942761329, 90.15416437579741, 86.52386957599272, 67.1970259758734, 44.58041206482918, 35.28443790251209, 52.857370145859264, 54.63550606081563, 53.23551408706173, 59.93698943045832, 3.1450735849718896, 0.3401487993617212, 0.20869826988106777, 0.5499466965275427, 0.877272961360793, 1.051415226632549, 4.426622236928632, 7.087720449893706, 9.901264521383471, 6.072817954324908, 5.06238696075255, 41.241412085871545, 74.47669398400092, 76.4813232421875, 75.0265867479386, 75.77290396536551, 76.53071372739731, 75.44525269539126, 70.20390710523053, 69.29959681726271, 72.85893594065021, 71.44442727488857, 62.14810402162614, 55.54046353986187, 61.900335742581284, 69.4394136244251, 69.57008346434563, 72.3556487791, 66.45194038268059, 68.26723683264949, 68.37572959161574, 67.46857950764318, 57.68925559136176, 50.107078706064534, 52.36682284262873, 58.892195532398844, 68.5755821966356, 72.21235675196495, 65.12484565857919, 60.54788681768603, 64.49737233500328, 70.33410626073038, 67.80318121756277, 66.4209379688386, 62.42176386617846, 64.5677435782648, 63.37376233070128, 62.173803390995154, 62.79425174959245, 66.56561851501465, 62.98572617192423, 69.65534794715144, 58.49018396869783, 69.4844110550419, 41.99124766934303, 48.876897904180716, 71.61625846739739, 59.09773165179838, 63.25779353418658, 62.856833165691754, 69.19256318000056, 66.8158971109698, 69.71801173302435, 70.13390064239502, 70.44761180877686, 59.92967028771678, 59.330061481845, 49.96032714843751, 53.43910863322597, 60.03909264841388, 66.37961972144343, 67.93321563351539, 70.46441524259507, 70.50828303060224, 62.66155404429283, 49.41583156585694, 54.976528690707305, 53.50360024359919, 60.726064405133656, 64.51730189784881, 71.3177582525438, 68.73869788262152, 64.06137735612931, 63.22553203951929, 68.59092650874969, 74.13879748313659, 73.89650483285227, 67.22693012606713, 60.82198596769764, 62.9093340904482, 69.28508404762515, 76.64228946931901, 80.23993445980935, 81.14225218372961, 79.12144707095239, 14.195174344124334, 4.12471152121021, 10.00099176360715, 11.266670996142972, 5.742570075296587, 2.4183385554821264, 2.1664689481258392, 1.591215854690921, 0.8013663344806241, 0.2132360384829583, 0.30318753914006297, 32.257333032546505, 59.93382800009943, 57.16218317708662, 31.15868106965096, 26.723625736851847, 49.64100307033908, 60.29487432972078, 76.23994058178317, 76.76340441549979, 78.25508179203158, 76.56059434337001, 4.146783678762374, 0.20945919437273858, 0.2218165603135863, 0.23665346175191865, 0.12915261810825718, 0.14268182278160127, 0.22053927723919192, 0.16201149281715194, 0.16201639577986734, 0.13518051965342415, 0.08220517962810495, 0.1288531083733805, 0.12896593780286852, 0.17144220370438792, 0.15465450533215078, 0.21477809686574245, 0.10473611659460491, 0.2446862460384446, 0.1468565116726583, 0.10008456095332101, 0.12277793154240617, 0.10041730358235298, 0.13527741445408714, 0.10260096826260129, 0.1693108858120057, 0.12280856739849814], [0.06344301220510276, 0.033025847402431315, 0.00819026898112028, 0.044368889948893944, 0.056976395088338086, 0.049803073352743546, 0.011182592133991422, 0.07895509757462048, 0.03150660120281241, 0.03773745284565995, 0.027099391220197565, 0.02978944767927451, 0.021416008990678578, 0.1243489403878489, 0.08737328537409345, 0.01646705227152955, 0.007487286591992504, 0.026736857347010125, 0.1892527367078489, 0.002683339543798338, 0.05482818495722548, 0.33440237384169336, 50.50964724633002, 86.25037054861747, 63.98429493750296, 58.242376465951246, 36.23968801190777, 23.515275985963886, 21.194258543752856, 40.96510464145292, 49.04488909629084, 64.81618258260912, 18.355609832271455, 0.02120026330944271, 0.07189744362427343, 0.024371913281239332, 0.13337377789280108, 0.05638020248302529, 0.29466058217710067, 1.9821663345060043, 1.9639822263871471, 1.3815803681650471, 4.2800766037356475, 37.57520014239896, 72.95944275394564, 65.83579094179215, 68.38668084913685, 66.83868608167096, 69.61591243743896, 63.999956961601015, 68.8627467616912, 66.69744153176585, 71.34088454707977, 70.0912566338816, 59.35696894122709, 49.70634191266952, 53.67103838151502, 60.65326129236529, 63.987154345358576, 66.18544670843309, 65.92522098172095, 62.8613321242794, 63.99608165987077, 60.413435812919374, 56.86811916289791, 46.50478962929019, 48.398015729842655, 45.281637714755156, 54.50731908121417, 59.36704943256994, 66.6457211586737, 62.95044445222425, 63.55154768113167, 60.12882078847578, 64.02593481925227, 63.9334531753294, 66.65585656319895, 62.64751980381628, 61.85773488013976, 57.10832118988038, 61.21418768359769, 59.81139905991093, 62.110029574363466, 61.35102348942911, 63.591296980457926, 60.007862737101895, 64.23051388032975, 30.22581396564361, 37.35368036454724, 65.51166588260283, 53.30422224537019, 57.24174453366188, 53.19969108027797, 62.60197324137535, 58.8770277269425, 63.31213797292402, 62.042588341620664, 62.72477088436004, 60.765719567575765, 59.10745520745555, 54.3780142261136, 54.61070883658625, 57.425868434290734, 64.742041941612, 65.69406786272603, 59.68081943450436, 67.2858755050167, 55.978094147097686, 44.2924238020374, 44.62091053685835, 49.492686487013295, 57.23595511528754, 59.56369353878883, 63.93413174536921, 64.14922668087867, 58.23847762999996, 56.747933818447976, 61.27245449250745, 65.17971177254954, 66.40581330945416, 64.23806052054128, 53.15271285272414, 52.461226447936035, 60.79161897782357, 64.87141739937567, 67.4172435268279, 71.29583220328055, 71.78064500131916, 68.66268234868204, 11.86666125251401, 1.152885594675618, 0.3246065301279868, 1.1904981828504995, 0.9537067180199008, 0.34739902483359464, 0.22016318935540416, 0.06759382979643923, 0.014125450904811583, 0.0664591386673912, 2.250656004874937, 36.25272989273071, 45.88261935018724, 47.532552596061464, 30.193621112454323, 16.828154556212887, 32.41374931027813, 40.83133612909625, 59.013761551149436, 65.27509204802975, 65.38469483775478, 39.38971211833339, 0.1517908380276734, 0.05728046304636425, 0.06115345502152078, 0.04853776806304532, 0.04348075655739635, 0.023705353584861564, 0.027729688144679514, 0.021814600707242088, 0.019900936055027192, 0.019397767591139963, 0.05705741654720999, 0.029611169443195386, 0.04689209628850222, 0.06085132909638267, 0.024612717698478413, 0.06388049054470274, 0.05476359225388977, 0.022587047161294088, 0.0865301902916643, 0.11161493497990793, 0.028481019300318537, 0.04311078205524434, 0.043470464166133635, 0.06359168305812825, 0.09075444507142229, 0.05528299220567269, 0.02380834644540183, 0.034953504650583195, 0.014866183234018185, 0.03202349604708293, 0.005255917137894299, 0.010679424627714101, 0.023372490296981508, 0.06428835192515005, 0.0721126530439623, 0.0577795195333179, 0.021657184960560936, 0.057810821885904, 0.07964613952583845, 0.035021629019249836, 0.05571892687810525, 0.03787256011198606, 0.0380146541001816, 0.031545560604201696, 0.03660094225779176, 0.15749116037641803, 0.2936514911632384, 66.39823529028124, 94.41351321435745, 70.8243005506454, 67.6106869789862, 43.692356078855454, 32.44533615727579, 27.455139929248443, 36.44641260946951, 44.47039742623606, 54.378732019855136, 19.0653823268029, 0.02445769789178045, 0.008540021634901003, 0.15184008215944614, 0.46120527771211445, 0.7461155217982108, 1.8873615442745149, 3.8902126204582954, 3.1968780438746176, 1.293702115935664, 5.164362701677508, 40.77126110753706, 76.745039878353, 70.07618688767957, 70.74911655918245, 68.90293536647674, 72.3690083719069, 67.95862474749165, 72.25489877885389, 69.92070413404896, 72.4671382288779, 70.73931847849201, 63.43369614693427, 51.895220587330485, 55.460745288479714, 63.3355898241843, 67.67597875287457, 66.41836489400556, 66.17921013985911, 63.62527255089053, 68.1087887671686, 61.716364814389145, 61.0266395538084, 48.45894190572923, 50.05955526905675, 46.53752180837816, 56.20119071775868, 63.04442836392311, 67.4287203819521, 62.64504086586737, 63.2236022333945, 60.919574537584865, 65.50021648406982, 63.919697423135084, 68.3239229263798, 64.7720637629109, 61.63874503104918, 58.47544762396044, 62.350529701479026, 62.71005807384368, 66.30143119442847, 61.860896310498646, 69.53970862973121, 60.27786301028345, 67.95521228544175, 35.36594475469282, 39.7555515843053, 69.2320457581551, 55.73207916751985, 60.43389881810835, 54.35916331506545, 63.45553198168355, 60.999430071923044, 67.47357660724272, 63.753930214912664, 65.34641250487297, 64.55482721328735, 62.90356820629489, 56.7293849299031, 56.90509534651234, 58.76143155559417, 66.51944437334615, 66.76168995518839, 62.94657307286417, 70.87508739963656, 58.88589620590211, 47.32572209450507, 47.65899804330642, 51.96780012499902, 59.862703661764826, 64.23136503465714, 66.65635078184067, 65.55298805236816, 59.26733101567915, 59.08383469427786, 63.56791965423092, 66.29991715954196, 68.03913531764861, 68.2436163194718, 54.393299702675115, 54.193839334672504, 63.48573423201039, 68.34011447045111, 70.31262736166678, 73.53304232320478, 74.90810763451361, 73.30589002178561, 15.149137916103488, 0.20290261555102565, 0.3674519584784585, 1.6485426430740666, 2.3582502959236025, 2.0313311608568316, 1.7945995734583948, 0.21687051281332972, 0.21484707542244466, 0.10047040113638486, 2.624630466584237, 38.614145786531516, 41.28493862767374, 33.4185742562817, 25.1118375409034, 24.146495173054358, 42.874216341203265, 50.44526153995145, 66.3021921342419, 73.08186777176397, 71.9493696766515, 57.89402292620752, 0.5179713510217205, 0.0417442842116279, 0.09619558455362436, 0.003439013699760601, 0.033513975645145105, 0.054169981364881804, 0.00892657715256416, 0.047604734258305643, 0.04182334065497403, 0.03239534171899, 0.040191960250658375, 0.050341763398459846, 0.04437676916319517, 0.03215807279752147, 0.032761225311626355, 0.04545223786525669, 0.023242609665518808, 0.04530558182347206, 0.018236269130401554, 0.027147030397768945, 0.04549256473359081, 0.05077076497517767, 0.11248622975882985, 0.036436160575718655, 0.057868646202428695, 0.12148004836372792, 0.21261926109512008, 0.10118504625654991, 0.09595260444668033, 0.08024626982308204, 0.07946242398071675, 0.08978456243752472, 0.21118705972067772, 0.18354041742221003, 0.2535136933288267, 0.13210533547305292, 0.11080763152530117, 0.17652194886918993, 0.20617862201986775, 0.21670054854644885, 0.2159649049562793, 0.10814397445609493, 0.12137016837274837, 0.30183738578231106, 0.11871795665713088, 0.26877808715066603, 1.7562745848009664, 79.26477832178917, 105.1671068130001, 83.3307150871523, 76.35266950053554, 52.905756504304954, 35.14535457857194, 29.939214221892822, 60.30446452479209, 64.11444310219058, 88.1674603492983, 26.396880534387407, 0.21733971102343452, 0.30179981683050433, 0.21220306084761698, 0.6109924434173493, 0.6081455994036891, 2.1563690900802612, 9.78038982037575, 11.190897668561629, 6.861142285408513, 6.5867455255600715, 42.83263137263637, 80.66355043841948, 71.07168443741338, 73.75431891410582, 69.98404256759152, 76.44282125657605, 69.44346151044293, 75.16020621022871, 73.01895295420002, 74.53193664550781, 74.2982888990833, 66.15620936116865, 54.16936374479725, 59.79010451224543, 65.8302603998492, 69.42811719832882, 70.19406195609801, 66.87781564650997, 66.24534914570471, 69.83918159238755, 65.28832220262098, 62.39220880693006, 50.771230113121774, 52.65971014576574, 50.31188918698219, 60.48834916084044, 65.81158991782897, 72.11263441270398, 63.65147790601177, 64.19323175184189, 61.973503635775664, 69.4752876220211, 67.38100082643571, 69.48500725530809, 67.17624525870046, 63.306458380914506, 58.60467010928739, 63.41359399980115, 64.12742614746094, 68.01050201539071, 66.98720270587553, 71.86543879970428, 63.5206707831352, 72.00977417730516, 40.62106570889873, 44.219424570760424, 70.3147768205212, 59.31989862072853, 61.273231121801565, 57.749338457661295, 67.00175469921481, 63.90675360156644, 67.2935555058141, 65.92922964403706, 67.20921670236896, 66.46279750331756, 65.03535286072763, 58.90480595250284, 59.38789290766562, 61.709394762592936, 71.15503480357509, 68.34767680014333, 65.57976607353457, 73.49290863160165, 60.867960068487356, 50.544615176416215, 49.29219061328519, 54.44625170000138, 60.62169013484832, 67.25991725921631, 68.66116046905518, 66.05965629700692, 59.165353313569106, 58.26815820509388, 66.52365699891122, 72.14890064731722, 70.89378926061815, 70.68150274215206, 57.51361185504545, 56.98308775501867, 66.62808618237896, 72.42027375005907, 73.56655505395705, 78.04091253588277, 77.83327794844105, 76.324522572179, 15.487720831747978, 4.64252321950851, 6.969579150599818, 8.601174335325918, 5.637503016379572, 2.4275747566453876, 2.2569803364815253, 0.5177588075880082, 0.3336004023590396, 0.1941485135185142, 4.226828957757642, 54.50795842755226, 63.07088475073538, 67.75229238694715, 42.61694023686071, 26.643754513032977, 48.826817081820586, 56.60458687813052, 76.25519860175349, 80.68764163601784, 80.98578883755593, 62.80273191390499, 0.6188319743640962, 0.20176978601563364, 0.19630760975903083, 0.1214471678700178, 0.12232337327253436, 0.1489587029021594, 0.12049539555465022, 0.26170669724383666, 0.1335157799504457, 0.16458436846733093, 0.1858804789522002, 0.17141364394657074, 0.21154060929773316, 0.17813284791284995, 0.14963600123601575, 0.15214818740083327, 0.2347796413326456, 0.1489600971821816, 0.09996103693641002, 0.1731397013270086, 0.07998642046004534, 0.13707877827748177, 0.25410782515762315, 0.21320390875541398, 0.21792190720237073], [0.024868541269473014, 0.05496425366389656, 0.015222671715873144, 0.026303713149841756, 0.01822133807675733, 0.07027914417126487, 0.02350857241019126, 0.048083140845260317, 0.024462989644117417, 0.022976744597056703, 0.026653713824587966, 0.06689149570921737, 0.04194570404867973, 0.11503559417061268, 0.021314146109826623, 0.10206619292617806, 0.05626937637345926, 0.03412843944745199, 0.03720146709031636, 0.12812753117853595, 0.1437315011336919, 13.418023374772842, 83.90782910008585, 71.16841793060303, 73.97922761978643, 48.67447222432783, 40.80536219381517, 24.196032747145622, 44.818680363316695, 59.12576875379009, 51.48106144320581, 39.14786269587856, 1.3552823470484827, 0.008148352480343273, 0.0858980221974273, 0.13553552479753572, 0.0963962383027519, 0.5118409009470094, 1.2861390507990316, 3.495155909369069, 2.5912420259368036, 2.4799629132593832, 44.65110886481501, 70.13297496303436, 68.96194350334906, 66.67378179488644, 66.83211218926215, 63.811816553915705, 62.66666881499752, 59.44197454760152, 62.82166127235659, 67.73904262050506, 71.02805199161654, 63.264830266275716, 54.036556213132805, 48.68568628065048, 62.87548795823128, 63.33159292897871, 70.88832932133829, 62.28528499603272, 60.151221444529874, 62.79096872575822, 60.81598866370417, 56.16667386024229, 51.47520142216837, 45.7441439936238, 46.49902766750705, 45.476912913783906, 55.39161351419265, 61.93074587852725, 66.29745391107375, 58.47247446736982, 61.51124446622787, 61.596650154359885, 62.692207367189475, 58.82060050964356, 62.303378889637614, 63.03264556392547, 62.07639525013586, 60.14158025864632, 63.00645982065509, 59.17151143473964, 65.85934869704708, 56.479941798794655, 64.0337795595969, 56.45213611664311, 67.17282495191021, 39.31339456189064, 34.37830371241416, 71.31573430953488, 55.81426066737021, 60.00766269622311, 49.47703623002576, 54.44680475419568, 55.12659465112994, 61.12485570292319, 62.99810909455823, 61.14074914686142, 58.874705683800485, 61.76096216324837, 57.58027253612396, 60.76404863788236, 58.3182978630066, 63.90822056801089, 55.48379705798242, 57.73305277670584, 65.53429403612691, 53.450761995007916, 46.296617677134854, 46.87208037222586, 53.877260915694706, 59.044752197880904, 60.830399451717255, 63.97848198490759, 59.410870152135054, 57.659594628118704, 60.16363182375508, 60.85249024052774, 64.21154137580626, 65.16363397721322, 62.343061508670935, 52.85263584506128, 52.89015723812965, 52.414001111061346, 56.35809336939166, 61.13834473394579, 68.88237430203345, 71.69159935366723, 70.42279889506679, 72.56145554204141, 13.909399278702276, 3.2023181261554843, 2.0441468925245347, 2.498289942741394, 1.1000820345455602, 1.00079765242915, 0.5561326420114887, 0.01777899507883816, 0.04351549098388322, 0.026949571235285654, 12.06738462371211, 33.18818599947038, 38.13810733056838, 37.78800833609797, 18.901650828699914, 20.722371916617117, 39.83661913102673, 50.258188016953014, 55.981196741903986, 57.39752930979575, 62.31642861520091, 18.320806641732496, 0.5494599549039718, 0.12433953282813873, 0.14220162354890378, 0.06626956254964875, 0.03384877522025378, 0.09866457102039168, 0.011836507549178938, 0.0569203787393147, 0.04128840827052632, 0.023959997380452774, 0.018314718449067686, 0.022908082051623254, 0.12315672371656665, 0.052647810624611956, 0.03574819063707706, 0.026995490545467026, 0.04593825553573909, 0.08035664777121238, 0.025252228745469646, 0.06787198099998698, 0.0438914907675597, 0.03751655905357292, 0.10845774108724249, 0.05789753537805331, 0.07192932054280274, 0.03377940595871018, 0.0035593869406805047, 0.025577199412509802, 0.04870285234984852, 0.027345355239606677, 0.03735987492085945, 0.013859435491594336, 0.09323286974141676, 0.021093643022580974, 0.018148209238725326, 0.029938984211654435, 0.04311322587572279, 0.0926595371997645, 0.05021433999401428, 0.005771296085684651, 0.046597554633814486, 0.06983897303261104, 0.06657998903744644, 0.0833077869948841, 0.19606598562771277, 17.480613377786455, 96.10805557620142, 80.43772389811855, 83.20250065095964, 58.46755189280356, 51.06989114515243, 29.248857459714337, 28.68010593998817, 48.92830841002926, 54.198059804977916, 43.14882147696711, 1.8177976963981506, 0.11034682963884647, 0.11899207823819692, 0.5183642009092916, 0.9411910476703799, 2.382969808193945, 2.89929713453016, 2.856809775675497, 0.22024171336764292, 3.118999629251419, 47.124339765118016, 73.03778817576747, 72.193647046243, 67.94013469449936, 69.55531966301703, 64.7036615494759, 64.11758884306877, 61.694831002143125, 66.31857979682185, 72.15579617408015, 73.10261710997551, 64.52445237867295, 56.49376815365207, 50.891623343190844, 63.94991928531278, 66.18809038592924, 71.0035607122606, 63.6124110990955, 61.634199004019464, 65.26818083178613, 64.39547700266685, 58.66468237292383, 53.507008783278934, 47.72803175833918, 49.449375675570586, 46.473791137818374, 59.28521310129474, 64.98582117019161, 68.85629054038756, 58.779219504325624, 63.801300679483724, 64.39599083315942, 65.2341817271325, 61.993527335505334, 65.08809305006459, 65.11536921224287, 64.05961228955177, 60.535680401709776, 65.16608545857092, 61.07926599441036, 69.39332577490038, 59.29260676906955, 67.94505334669545, 58.46773624420167, 69.26851595601728, 42.01053004111014, 35.81644073609383, 73.55354847446566, 58.12008480871878, 63.082785221838186, 53.6745685146701, 55.140777941673036, 57.14898832382695, 63.783610790006584, 65.41046480978689, 62.07386924374489, 61.706649103472316, 65.37292380486765, 61.34031149648852, 63.40771828928302, 63.33340898636849, 65.79906971223893, 54.523530237136356, 60.59065241967479, 68.25849779190557, 54.65811068011869, 48.77594394068564, 50.866304443728545, 55.50489548713931, 62.54833875163909, 65.04790444527903, 66.19510358379733, 59.90628511674943, 57.24688283858761, 61.88323028625981, 64.01881571738951, 66.8288173983174, 66.25635531640822, 62.991366540232015, 56.85383389073034, 55.11475301557972, 55.446197217510594, 59.219697752306544, 64.11445879167127, 71.26369230208859, 73.43086458021595, 74.66639549501481, 77.5276860883159, 17.542412281036377, 1.061693920243171, 0.6493799448493989, 0.7746760763468281, 2.2310363092730126, 2.435721519493288, 1.7091942530485893, 0.294019274653927, 0.06170845890958464, 0.015305391017107234, 12.719485529007452, 35.33524044098393, 37.971912583997174, 33.024740834389966, 21.78932720615018, 34.37473043318718, 51.31213672699467, 56.17910385131837, 62.14339325504919, 63.77757818468156, 70.5477342297954, 31.277434748988, 0.4775867503016226, 0.06396294841843267, 0.23723519827810027, 0.09328828854185921, 0.06162165731732404, 0.04508105294418432, 0.027989805638489705, 0.06622447827530485, 0.010832202669623639, 0.025545209496011658, 0.037434691067544684, 0.017965079750865698, 0.09197285428883568, 0.041556370504681146, 0.04565334743669918, 0.08228000343566941, 0.016564161576811346, 0.08597706714945455, 0.11385584174985848, 0.0014500309935688313, 0.04719611062037368, 0.03878336204516311, 0.06954066605577547, 0.027314005006525307, 0.10264204589710121, 0.13565993747643887, 0.09675070718531648, 0.05923743464893872, 0.1105396616302671, 0.10599975564306784, 0.25656944951943816, 0.11182501927138337, 0.19436880976202028, 0.09344607967162326, 0.11171173018914078, 0.18176968179402814, 0.11711230531575219, 0.21293689647028524, 0.23660461598586655, 0.1425029259295233, 0.17855539136836607, 0.16175116081872296, 0.1432643866827411, 0.16158488909563712, 0.3330084002546726, 23.399054196573076, 108.56435791138681, 89.96647111831173, 94.29104897283739, 67.6107418921686, 57.09172171931113, 33.31378421475811, 62.843457883404156, 76.21458638098933, 68.54956903765279, 56.71685687957272, 1.9705350360562726, 0.30402324913490203, 0.3870826857464929, 0.662097739836862, 0.9565698030975558, 2.6525067513988865, 6.0839589565031, 13.538630374016302, 7.936142356164995, 4.970875613151058, 49.46134282696632, 76.01405912829985, 74.24229314250331, 72.60923001074022, 73.50829216741747, 68.20011723426082, 67.67255844608431, 64.15502002162319, 68.46695607708347, 74.92364022039598, 76.60812562511813, 68.18774607873732, 59.724557784295854, 52.10613035386609, 68.23287686994, 70.53171527001166, 74.6706630337623, 66.91760416953795, 62.55741903858801, 67.44563364213514, 66.4685163190288, 61.44164200752013, 55.847467453249045, 50.53782947601811, 50.85063065251997, 49.0456735703253, 61.43534660339356, 68.8026011374689, 69.06136774247693, 59.700270468188876, 64.58690435655656, 66.2957202234576, 68.719588095142, 63.65497666020548, 67.74152155845397, 68.4677170168969, 64.97903154742333, 60.89876636382073, 66.46320542981549, 62.49792845018449, 72.6669829891574, 63.67498074808429, 69.72876687203684, 62.828596022821245, 70.0862830685031, 45.74121790547525, 41.17431602170391, 75.17314218705701, 60.97825711773288, 66.31453191080402, 57.109152732356904, 58.07837432430637, 61.54744794291835, 65.89575613698652, 69.39089390539354, 63.97122952245898, 61.662043909872736, 68.45774635191887, 64.26990624397033, 67.15133820810627, 64.25738211601012, 67.39575678302397, 58.45634568122126, 64.0526932285678, 71.99856404335269, 58.26621663185858, 51.78985003502139, 52.38496380467569, 60.22482472081339, 64.44554213554629, 67.67548453423285, 67.26345523711174, 59.88901099851055, 57.855791584137954, 63.01795236525997, 67.36364041605304, 72.61435262618527, 68.90152331321471, 69.97161649888562, 59.52689778420233, 59.22617750783121, 58.12141841457736, 62.57628563911685, 66.5995470170052, 76.24192530109038, 78.03208720299506, 78.9090742603425, 78.87396904730028, 17.357343089195993, 5.553971240597387, 9.744987487792969, 8.111110464219125, 5.987613287664229, 2.8695356605514406, 2.04448850645173, 0.1818387369595228, 0.21117065011733965, 0.1243794383481145, 18.871195585496967, 49.44852059887302, 55.59853815263318, 55.028947245690134, 31.446655604147146, 30.973513818556267, 55.700598224516845, 65.0890540307568, 73.68615596525132, 71.70204070306593, 81.99013525439848, 34.33533022480626, 0.8388472168195633, 0.23656582129338097, 0.42954390568117945, 0.1859715055193632, 0.10166084048368278, 0.1818915204175057, 0.14731146064737152, 0.16774009913206103, 0.11292346678073369, 0.1521045203891493, 0.10532596599190466, 0.1214239554059121, 0.18371051958491727, 0.12275226759694277, 0.12623047531251946, 0.19819924938342265, 0.1436910363695314, 0.14420042355214396, 0.27515647392119136, 0.2514540353008817, 0.14437097004584729, 0.20337536840909914, 0.14979824333661987, 0.1258118082619002], [0.10600291958619511, 0.04836349072115076, 0.10626786343392827, 0.018554076875349688, 0.019999558383959438, 0.016588438903131796, 0.0652743224054575, 0.034633996190443155, 0.043459413347825895, 0.0485249858860287, 0.07745657596857318, 0.06610631687386383, 0.03799606880713855, 0.037488987549178066, 0.07578385362942373, 0.12251589116790604, 0.061927211485923304, 0.06363385619835989, 0.06224319977205127, 0.0576518586416158, 0.05012377691004546, 32.155467117986376, 80.33851146697998, 68.99905696991952, 57.87818831782187, 50.826115838943, 30.85751756545036, 23.892609957725774, 63.252204156691036, 52.91358555516889, 51.32716724949499, 16.427395209189385, 0.02109370430961492, 0.15494396399346091, 0.028888212269051906, 0.19540206318901432, 0.6476032337354076, 1.9375351552040347, 2.893348615015707, 1.772827232076276, 1.0431485863462573, 35.7146591524924, 74.14689325517224, 66.6611909866333, 69.77905165764594, 63.92629484976492, 62.4171668483365, 59.986787842166045, 58.4450061090531, 54.31043963278494, 60.824857142663774, 63.847596414627574, 64.68348879967967, 56.54288407294982, 48.95068160949215, 60.801087579419544, 65.21612313485915, 67.33767432551231, 64.6443239335091, 61.2027108284735, 66.58655612699448, 60.918217397505245, 60.41930760106733, 55.08052641345609, 50.577845496516076, 45.6126190770057, 44.916468974082704, 45.71108233544135, 56.52530400983749, 62.054049507264175, 65.74793769467261, 59.14887543647521, 62.47315868254631, 60.86603026236258, 60.65437132312406, 55.90712670356997, 57.50820290657782, 60.03951626439249, 63.318099975585945, 56.39316720347251, 59.26605624537314, 60.53162859332178, 60.835020003780244, 56.972567958216516, 60.265656594307195, 54.01592454602642, 67.87675703725508, 42.63351617320892, 33.288939922086655, 69.66709152344735, 56.04517059941446, 60.999194729712706, 55.430735234291326, 53.43467243256108, 49.02964284343105, 58.45541215712025, 59.04325385247508, 62.31167470255206, 56.365463502945445, 60.65451252845026, 59.89503183672505, 63.2425315918461, 62.06072145892728, 58.27686586687642, 59.091569608257664, 62.238871589783706, 60.574437341382435, 50.50444226111136, 44.935453245716715, 46.94942558965376, 56.606163670939786, 61.507616273818485, 62.170536056641616, 59.464759595932506, 56.800862281553215, 60.0734761453444, 61.18072986602784, 63.7124119266387, 63.15298388081213, 63.04093353209957, 58.43623176697762, 50.89105852188603, 48.49153680186118, 55.173388527285674, 53.618078539448405, 53.64436626434327, 59.16559650051979, 65.23440922460249, 68.22813864677184, 70.39279276324858, 78.63783451818651, 23.44200218877485, 0.07392798265021655, 1.6391403540488214, 2.2555511228499876, 2.0238677484373895, 0.4661798543266712, 0.47574985532029984, 0.05717066732505637, 0.0669420958166161, 0.29415655760995807, 22.088633468074185, 38.46574291106194, 33.90183771810224, 19.487762758808753, 11.833808460543233, 15.673425447556282, 37.648952468749016, 52.201789117628536, 62.211689564489554, 63.625672632648104, 68.35913796578684, 4.678667370350131, 0.529324957920659, 0.15394107829178535, 0.00868361428259842, 0.034122134543835156, 0.02821859779707607, 0.07235851364150163, 0.039774043966204896, 0.03125800375616358, 0.04752776923499281, 0.024157376103704015, 0.024952755399769353, 0.027570885778855414, 0.036596663656734654, 0.022807770498817968, 0.025840228040432258, 0.03341277926078728, 0.03754764690154022, 0.01659992830677619, 0.08831941162145908, 0.05722968290830332, 0.02398697516670631, 0.07943088414087411, 0.022583448463269783, 0.04961658456933595, 0.027093354447354234, 0.03654568050537379, 0.08325012355682351, 0.10902117577291305, 0.03352184336812746, 0.06008888392018215, 0.01394591053887721, 0.02341297612855992, 0.03117132856841049, 0.02822441048920155, 0.03619188194974296, 0.015153673049362918, 0.09541333983502082, 0.0678101500436183, 0.14744407046706448, 0.02139241156739093, 0.03264580267451463, 0.06385606383123706, 0.043311906948445306, 0.08815418177795026, 41.15059744927191, 91.78827870276668, 76.86152642773044, 67.27586561633696, 57.157852880416385, 38.50644534634006, 26.028179699374785, 63.479215252783995, 65.08491985259518, 57.51497291749524, 17.166884560738843, 0.015529623037324318, 0.10598622653032504, 0.3601495164536661, 0.6145334856644754, 1.2579338997602463, 3.8743603614068802, 3.118881467849978, 0.6218574700816986, 2.1144972981945163, 39.640979151571955, 75.75602208414386, 70.57035061620897, 72.8019517467868, 67.73018590865597, 66.36623659441548, 64.5602753854567, 62.075069489017615, 57.738838272710005, 63.001470565795906, 68.0786963432066, 66.8092369264172, 59.57871229417863, 51.49248730751776, 64.6138902633421, 66.18601152973791, 67.75644225458946, 66.6351229144681, 64.51709793459985, 65.13478102222567, 62.74156255106773, 64.36476876658779, 55.559796902441214, 51.8050649089198, 46.906032408437426, 46.692824132980846, 48.38879815993771, 57.67604897099157, 64.98200078164378, 66.93771023904124, 60.2759841949709, 62.23897749377836, 63.60485269177345, 63.22557518559118, 59.17716749252812, 59.32133028584143, 62.01260182165331, 63.13640009972357, 59.05890018709245, 63.60547634863085, 61.909608225668634, 65.01478002917382, 60.21952167634041, 63.708591538090865, 60.187730866093794, 70.02474108049947, 46.43349662903817, 36.166598566116825, 70.7447862625122, 57.087473792414514, 63.46603216663484, 57.43843963069301, 56.05713382844002, 52.774878778765284, 60.9993516245196, 63.232600150569795, 63.73040776098929, 56.00250697905018, 60.52735320983395, 62.70731241472306, 65.85252377294725, 63.339429824583, 58.59593499091364, 60.743358135223396, 64.68207282404747, 62.988495365265884, 52.26899500816099, 46.963208798439275, 50.483947876961004, 58.133464013376546, 65.10592806723811, 64.7524283778283, 62.05371610579952, 58.24020739524596, 60.38643029428298, 62.45949314486597, 65.39070390885877, 66.06981523575323, 65.11761673035161, 62.024616041491115, 53.91779468905542, 49.88016566922588, 57.957357437379905, 55.5401183712867, 56.40148262823782, 62.283888632251376, 68.4539730318131, 70.64381660953646, 73.35539033336025, 84.22685900042134, 28.299802734005837, 0.6034594089273484, 0.498855067116599, 0.5818150961591352, 3.583634284234816, 2.356801960737475, 1.5747579571700867, 0.18542450341966846, 0.09254686098786132, 0.2766986701998019, 24.124788776520763, 41.156814405995036, 37.24130838148056, 23.847086929505874, 18.499360776716664, 28.136098692494055, 52.43388752783499, 56.98576281147619, 70.9619051410306, 68.36852027523902, 82.19310222133514, 10.30264066111657, 0.6031892556817301, 0.211816017906512, 0.056698833772492026, 0.004808337929012675, 0.07495221156146258, 0.012712659325540788, 0.018640482017109473, 0.07282853156568543, 0.06395185163484947, 0.016427834315465826, 0.024859888306368264, 0.03965597066487517, 0.08500297869285268, 0.019771116710598433, 0.04641781125458018, 0.02555335684108638, 0.06107411129520305, 0.0424811688642348, 0.05852253288931905, 0.03989587492880322, 0.05389667949789474, 0.08715963111289086, 0.028461953287103006, 0.1431901834063953, 0.1287641042783376, 0.18140105560662287, 0.23271210792083896, 0.228526693798842, 0.07215451974902423, 0.12332992853536723, 0.09796036001775535, 0.1857737782261064, 0.1173873691849651, 0.20188263076688015, 0.12123987213858675, 0.08791172261079473, 0.13271887996985068, 0.1959545658000054, 0.203556532881433, 0.09364781360472403, 0.14757122574073656, 0.18141023333995573, 0.12924327695321652, 0.11124456977291454, 50.85696920271843, 103.80587177891886, 87.05673925338253, 77.55818643877583, 66.52561818399738, 43.49595908195742, 37.84754599294355, 80.78227273879513, 60.40319450439946, 72.19173292959891, 24.55542972010951, 0.13210584109108295, 0.34926215066544475, 0.46938587100275103, 1.03020500992575, 2.3823522800399415, 6.5586133060916785, 9.899893653008247, 7.029098176187085, 2.9688351192782005, 39.476565161058986, 79.48632163386192, 73.76152038574219, 74.3843770796253, 68.12592168008128, 70.46010848014586, 67.17664534045805, 64.26949047273206, 59.95596977972216, 67.12960827735164, 70.2490928096156, 68.72910376518004, 61.23358772646997, 53.76442217057752, 67.64553331559705, 70.57930930968254, 71.21870271621212, 70.20341288658881, 67.16016354099398, 67.38030264454504, 65.31151909982005, 68.71996464267855, 59.39180351072743, 54.485291050326445, 51.455864137218846, 50.20993894146335, 50.81771804440407, 60.42348492530085, 67.60668616141042, 69.88130784803822, 60.08805951764507, 64.43559108241912, 66.66723143669867, 65.96683732924923, 62.05617935426774, 62.338892029177764, 66.18630178513067, 66.57300041567895, 58.75214338302613, 63.199491423945275, 65.81392765045166, 66.26000312066847, 62.16051440085135, 66.2111068541004, 62.063227853467396, 71.50300395104193, 51.684726592033144, 39.53562428874355, 71.78482624792284, 60.71004936772009, 65.88551875083678, 62.08161984720538, 58.6774653773154, 55.24157501036122, 65.4193332887465, 65.22455623072963, 64.78079103654431, 56.22894148672781, 62.019591485300374, 64.24144160362982, 66.51642414831346, 66.18046529831426, 60.1540377063136, 61.702248204138975, 68.055373930162, 67.76742489107194, 55.552803316423976, 49.89010495524253, 53.45179357836324, 60.56679656428676, 67.8803107046312, 67.52155503919049, 62.48847553806921, 57.93367416627946, 62.19571375077771, 64.48275758374122, 68.51395391648816, 70.07302545732068, 67.99377702897596, 65.71118116378784, 55.44693854547317, 52.43335408549155, 61.94229333631454, 58.27879175063103, 58.962704058616396, 65.33709295334356, 72.49391232767414, 74.73347586970176, 77.22268258371662, 87.05531151063981, 27.21702656438274, 1.3358505574926254, 7.508866315887821, 8.27974884740768, 6.174006279437773, 2.511656399696104, 2.093339543188772, 0.2467244076392343, 0.17779396125866523, 0.6874800100922586, 33.64157276768839, 55.283783635785504, 48.50094656790457, 27.878710800601592, 18.841048248352546, 26.054628241446714, 55.60907363891602, 65.90031393112676, 80.64466814840995, 77.40639855784755, 92.58750869381814, 11.931357806728734, 0.8898453835037448, 0.3881896521535612, 0.14431818658786436, 0.1559993267179497, 0.12184927976059338, 0.27639980397878156, 0.10262191310645112, 0.19024978481954147, 0.17446385366061043, 0.20370086384636743, 0.09564761718314502, 0.10171314896715265, 0.18754382437515646, 0.13604331851726578, 0.15961123209807182, 0.22386086593952872, 0.09776843201008537, 0.18358990670211855, 0.180625269009221, 0.08161065709446708, 0.09224371999622354, 0.14957865189400413, 0.12941743938192246], [0.05095279512686595, 0.01525876594842562, 0.07008361555035077, 0.08745928640447317, 0.02075438864619261, 0.08174486037704252, 0.04671184346079827, 0.09834528855618932, 0.04825082983100607, 0.07824612150509512, 0.008590526938919098, 0.025237946951341246, 0.045120950803280845, 0.03726697526872158, 0.04850716285047032, 0.03294517068312534, 0.07618186694960441, 0.05299505529805057, 0.027885839846285603, 0.09986346031749442, 2.4020597386744718, 56.584610246842914, 70.1634596240136, 70.26060888844152, 69.05662951930877, 51.757584617983916, 27.62048940504751, 40.57640952448691, 32.6675796124243, 31.965753839861964, 43.182734289476954, 1.9007785017451935, 0.017936410825519312, 0.170306064669163, 0.039406448167057774, 0.1278721251254601, 0.8302200249125882, 2.6683499399692785, 1.498720972768722, 0.843165010934876, 27.66624777547775, 72.26652468404463, 69.15372387055429, 69.0607480079897, 64.02316562591061, 63.09930232263381, 64.36856954328476, 59.147043689604736, 55.19393390224826, 53.972394081854056, 55.04577813609954, 59.29908652459422, 57.677900329712905, 49.791343596673784, 53.818750919834265, 63.97748178051364, 66.41084963275541, 65.70323051944857, 58.05355356585596, 67.49008978566816, 62.38070057284448, 60.63110382326188, 61.73672191558346, 56.03514109888385, 52.198011875152595, 46.35882254569761, 45.240280243658255, 45.278770462159194, 54.970649057819, 61.295427814606704, 65.48369546090403, 59.53390313733009, 60.2194393065668, 59.56791008672407, 57.60634845302951, 51.713281446887606, 54.71214525161251, 62.23714966927806, 61.86978440130911, 59.485320660375784, 62.08860951085245, 61.232991526203776, 59.99209088663901, 54.83902608194659, 55.27649194963517, 52.83098043933992, 64.27543286354312, 47.83733252556094, 31.22753239447071, 61.822049156312026, 57.97441190288913, 63.28010005335655, 56.89721138246598, 58.29456752346408, 48.1008412761073, 54.47752867975543, 56.211588921085486, 60.734411208860344, 54.525993485604566, 54.637082853624904, 50.90446126076483, 49.904766774946644, 48.61573080862723, 60.51406029731997, 60.54826336522257, 61.301330981716035, 55.36963647411716, 46.40568310214628, 45.78511315007364, 47.37579114975468, 56.597911004097234, 63.964977264404304, 61.36880359342022, 58.66564727598622, 56.930633898704286, 57.66896517046037, 61.50761235144831, 62.23843620669458, 60.77500774014381, 60.52488211662539, 54.66253511367306, 52.199725950917895, 49.71474362957863, 53.404070100476666, 54.41994436325566, 54.830891086209206, 52.903136361029844, 57.62343037512995, 61.45714321444112, 70.58342779836347, 64.49493654312627, 77.09310316270398, 30.795612758205785, 0.35082432651712053, 1.433615143741331, 2.315614377298663, 1.479590470271726, 0.538423018109414, 0.15393550117169658, 0.11739518328179276, 0.09516194042178894, 2.9968837432322966, 26.214054938285585, 36.27328703480382, 37.618683538129254, 28.596698699458955, 18.10324453538464, 26.425737411745136, 41.07950841226886, 48.301356761686264, 62.00836958423738, 63.7262971170487, 51.378009011668546, 0.921505345932899, 0.15583536858039518, 0.008615142301536136, 0.027067468336392796, 0.03212632994437891, 0.031478826685117624, 0.0553859199487394, 0.04919034473958516, 0.029354598936474616, 0.03526795693042298, 0.006176791212055833, 0.013277025765649254, 0.07517932598749477, 0.08294556530252581, 0.03428256484649835, 0.0479500177466581, 0.03654267361027099, 0.09250694014612706, 0.0471046397222146, 0.01929609240182946, 0.077777765991707, 0.014058213282917297, 0.06782902645007258, 0.017560571920306935, 0.050603125785146995, 0.02251745573425245, 0.07824992896207879, 0.031960521704487266, 0.015923258165017735, 0.04163212893951324, 0.03425122418951604, 0.005311887521642231, 0.08125339965185813, 0.03861233674650712, 0.01841257277485584, 0.05112208140593383, 0.04434495736213942, 0.08255414033849394, 0.052912628067837614, 0.07585015853927021, 0.06931854652300959, 0.0885252900902302, 0.046885255123338396, 3.608294225508167, 68.78804129938926, 80.64741380753057, 78.98138707683933, 76.42393896656652, 58.75704634574152, 37.21186314859698, 36.4380971847042, 34.80084496159708, 33.4702044148599, 43.95845751608572, 2.511374234191833, 0.11168625776565845, 0.08582057836916178, 0.6341287277398572, 0.9962576928157961, 3.2961468590844065, 3.5487720129951357, 1.2951871007680893, 1.0665267705917358, 29.404903073464673, 74.85923490216656, 70.5966854095459, 72.95537133370676, 66.05349817583638, 66.32445550733998, 64.4529083467299, 60.770081243207386, 55.645708576325454, 56.80351772615987, 56.491438265769716, 62.402661923439275, 59.0985788837556, 52.46723944141019, 55.26513668798632, 67.36626055932814, 68.60042648930704, 69.76483698814147, 60.37566338815997, 66.99861680307697, 61.78333928508144, 63.872056315022135, 62.866568488459436, 58.51479291915894, 53.561011975811375, 49.63936351960706, 46.69327912792083, 47.68830599323396, 55.350652202483154, 62.964157058346665, 67.15702564485612, 59.43716964414043, 61.45882591124504, 62.41498993289087, 59.50209271523261, 54.82765120844687, 56.82583993481052, 64.71314584055256, 63.276546385980424, 61.03698676632297, 63.14645313447522, 62.938343940242646, 61.926850964946134, 57.33164918038153, 58.18374879898564, 57.27277832646524, 67.268491560413, 50.08156761046379, 33.65070012307937, 64.36140337297994, 61.44202247742684, 66.21624515902612, 59.652864702286266, 59.299227729920425, 52.552064618756695, 57.049313053008056, 58.2366733397207, 63.187367377742646, 56.78953055412539, 55.09090892730221, 50.67907010355304, 50.2675546369245, 47.810154422636955, 61.155563939002256, 61.21052418985675, 63.57895328152565, 56.477090235679384, 49.996008949895064, 47.70635674076696, 50.34257388884022, 60.26630378538563, 66.52961900157314, 62.01526903337049, 60.016684147619436, 56.69134970634215, 59.49477357249106, 64.44074507682555, 63.524444103240974, 64.56324854204732, 61.915970310088134, 58.18530597994405, 55.00173384143461, 54.02400462858139, 54.575697760428156, 57.01898920920588, 56.79734391550864, 54.81161655918245, 60.5825605700093, 65.19637400104155, 73.96119256173411, 68.12583538793749, 81.5054322827247, 38.385734404287035, 0.6222148960636509, 0.06507975139444874, 2.692549002747382, 3.8279592125646533, 3.1498863331733213, 0.5527913342079809, 0.17077601364543363, 0.11351594385961372, 3.0908786865972706, 32.37814203385384, 43.73421561333441, 34.344061420809844, 19.844814154409594, 20.793225611409834, 38.17221626158684, 51.41646000646776, 55.97432474936209, 66.91566651867282, 68.65873644428869, 66.35959994408393, 2.144222490249142, 0.16483722344761895, 0.06444128605747415, 0.0390414034406985, 0.03801906293618583, 0.05467508228555803, 0.06808995599708251, 0.03845928004011512, 0.011205186939708168, 0.05955610041236205, 0.029160916587458025, 0.05150230999495234, 0.04530896793209738, 0.0533535614639761, 0.07369802603798528, 0.04592092279645224, 0.05304262552770877, 0.067568771060436, 0.0807787085913362, 0.054643163232192885, 0.010799337497672007, 0.022570154922563705, 0.05207843109664898, 0.14316398319938492, 0.09373543108062399, 0.14592303353692257, 0.1969700000218807, 0.17076352641226786, 0.11467016256985166, 0.12716583802454895, 0.1455631101083371, 0.12057354418380607, 0.22492536043207492, 0.0995054061434442, 0.09848237232936007, 0.07658610856460948, 0.16573037471502058, 0.2454961848355109, 0.16431971573300902, 0.14377947355951035, 0.22847778674575592, 0.1851318731543518, 0.24501543401950793, 4.535795527119791, 81.72757963980399, 89.66344448827928, 90.07620334625246, 87.41223150683989, 68.51900592927011, 39.26921690663984, 55.0657900687187, 42.199192124028365, 40.21416294959284, 63.58244811334918, 3.241346689962572, 0.26781192770408047, 0.42655064694343076, 0.9586157481516562, 1.397890809082216, 4.909334605739963, 8.80064941221668, 7.637753438565039, 3.5966884224645557, 31.21372369027907, 75.88876293551537, 73.94632677878104, 74.12022898274084, 68.66472982591199, 68.71350842137491, 69.10629457043063, 63.8817092680162, 58.52386928373768, 60.14403958474437, 59.239984250837765, 63.797931363505704, 61.359503653741655, 54.76292817823349, 59.96553251820227, 67.9828179267145, 71.67594909667969, 70.81485548327046, 62.42655700252902, 66.30907197152415, 61.57275507527014, 65.06986971824401, 67.18560403393161, 61.72706504021922, 55.6472892915049, 53.29951147879324, 49.606678408961145, 49.46384529913626, 59.715230388026086, 67.65792800534156, 69.33976188782724, 60.801640633613836, 62.68167972564698, 64.54648040956067, 63.14405264392976, 57.51915416409893, 58.6176335427069, 69.04898089747276, 66.14939228180917, 62.63251673790717, 65.78389013967207, 66.62177901114187, 65.23115365735947, 60.147224549324285, 61.154728474155554, 59.131911185479936, 67.59480137978831, 54.07352062963671, 37.603813832806004, 65.05597276072349, 64.54219325896233, 69.34087584095617, 60.632402127788914, 63.00691481559508, 54.49246506537161, 61.38634443283082, 61.16967270451208, 66.26952663544687, 58.15504097169446, 57.43318365466211, 52.58192562287854, 52.05300969462241, 49.021252893632465, 62.95728506580476, 65.15256504858694, 68.60031666294222, 60.551511087725245, 51.97998692912441, 51.56339983786307, 53.56369487700924, 62.462850693733465, 69.54978127633372, 63.96014882672218, 62.819041129081484, 57.45031264520461, 60.46981203940607, 66.52547697867116, 65.60159798591368, 67.13436219000047, 65.32186631233462, 60.335435559672696, 57.72145040573613, 55.56162080457134, 57.23479017134636, 60.64309843124882, 60.36171936219739, 57.26222715070171, 64.56435857280609, 67.15508799399099, 78.04399551883822, 69.29925164868756, 84.02568063428326, 38.955737160098174, 0.6816633189878156, 5.099129273045448, 9.717242602379093, 4.590057596083611, 3.2688000942430193, 0.5493932133240085, 0.5209364177238557, 0.12957721467941039, 5.226467059504602, 42.61664998146796, 51.11486111917804, 51.955711380127944, 42.551903417033536, 26.90048540792158, 37.231635816635624, 57.31948983284735, 63.07397557843117, 76.5819320371074, 77.93362002218925, 75.30582028050577, 2.0721185399639994, 0.28042685240507126, 0.18244834376438973, 0.07445356493154842, 0.14564695077077036, 0.13602902331659872, 0.2697303037970297, 0.17498951255073472, 0.10025175198191598, 0.14998870811635448, 0.13151494215332693, 0.12060267084668722, 0.19571691000413513, 0.2724026329815388, 0.1613531168550253, 0.09716686146754412, 0.10897528710624865, 0.12770003113414974, 0.14816270690531502, 0.15506423979757294, 0.16034247834355603, 0.12920435968666308, 0.3034011550968693], [0.04809265565727988, 0.0604681548992953, 0.032341504890111186, 0.028175876903978568, 0.08244874196187144, 0.05583180993374798, 0.03492838845798566, 0.03634107374255696, 0.03384423231886279, 0.05964218188197382, 0.06359723719557928, 0.04369676270852647, 0.04675113611043461, 0.043947694808124535, 0.09518903695167073, 0.056063390652378725, 0.028589313489294825, 0.02553594940822692, 0.07576203544534023, 0.1296668622883097, 12.441221802465378, 76.4907761543028, 68.59437819450133, 71.04058004194691, 45.02444398018622, 33.69854519444127, 15.972852322363085, 52.86872148513795, 52.85454603933519, 69.16996248306768, 20.700659636528265, 0.03123928248251398, 0.10622935985485393, 0.07885811084340658, 0.2631171570429879, 0.7726175674507696, 1.4298792087262677, 2.275298050334377, 1.7560731956074316, 9.86785279166314, 64.40028582849811, 69.49393456982028, 73.50034544544836, 66.71908517037669, 67.46785779153147, 57.98306072911909, 60.15941135344967, 55.02178499775549, 54.78023759780392, 49.642760292176284, 50.59766523299679, 50.71148064828689, 50.96838804983324, 46.908762378077355, 51.80037767656388, 63.24692856880927, 63.5027769304091, 60.31950289203275, 62.653968180379565, 61.04755755393737, 58.091282844543464, 62.2282458889869, 63.5777412691424, 59.99487184709119, 59.78664105938327, 55.0847194271703, 46.13214092869913, 42.09252326719223, 51.476331064777995, 59.95471069889685, 62.16143615784184, 57.99904438757128, 63.022847483235026, 60.463512712909335, 52.593904541384795, 47.62350059324696, 53.12408739520658, 58.20644755517283, 62.51540260930216, 57.64832565861364, 59.67677939322687, 56.915336655032256, 60.44717996351181, 52.62899014257616, 52.51492369559504, 52.606063888918975, 67.21670058465773, 43.82573235419489, 32.00694461022654, 58.477424498527284, 48.51778138068415, 60.0668591068637, 59.854325479076756, 58.970780218801195, 52.522984166299146, 53.05563419095932, 56.34244311240412, 62.39266380187004, 60.294431101891306, 57.60936475569203, 53.551774794055575, 52.8948405481154, 53.83069845937914, 61.30576326001076, 56.939925993642504, 58.48290404965801, 47.943256132064334, 43.634854132129306, 45.02608745328842, 45.65990717180314, 57.33678356293709, 60.16440060830886, 60.83338045304822, 60.97691958950412, 58.60037119157853, 60.454012732351984, 62.586754445106756, 62.01913256799022, 57.34660910021875, 55.05209707444715, 53.647653210547666, 50.86324891736431, 51.18889977855068, 54.50974310598066, 57.82938618813792, 54.71823669249012, 56.39281026778683, 53.14931215778474, 56.320485684179495, 60.60520441301408, 69.92067275508758, 65.44874322029852, 73.539898626266, 31.091655608146425, 0.6524954099328287, 2.814948770307726, 3.5889292388193073, 7.1407391275129015, 1.0152908102158578, 0.056354078884807327, 0.1204480359991712, 0.040178760555723024, 15.28575603039034, 33.43889605614447, 46.36430209682834, 47.61997046009187, 30.210844239880963, 16.695700037863947, 26.6943177869243, 51.38447307771253, 58.0763150799659, 56.05436855746854, 67.87898494351295, 22.98561480737502, 0.3850136354805962, 0.1167645090590081, 0.07262406269869498, 0.046854588623729446, 0.11909237446924371, 0.04554102362524118, 0.05635861029487945, 0.01624978207532437, 0.059834577203277624, 0.07047255838950796, 0.009776361140182183, 0.03314520007059459, 0.03640474714038353, 0.031538267447162545, 0.04546092147187841, 0.03200211261789645, 0.06013884817460372, 0.05285595671363896, 0.06281262143485009, 0.010813202731491578, 0.029519708121135354, 0.08247802950321667, 0.05786838573253444, 0.036383216239271626, 0.01471227329720052, 0.027684429585332834, 0.1444659496266996, 0.040280075683709116, 0.03667639808789377, 0.03820196259766817, 0.029036888867736827, 0.031201797800378937, 0.08299131607336384, 0.045827165125839175, 0.03966420227962156, 0.038293222821648085, 0.02568994648754597, 0.0865896080710715, 0.10530375710297978, 0.02985462260943267, 0.05516352079388115, 0.09479154457127857, 18.43322177087107, 90.35306776723554, 76.31670921079575, 79.78954438240298, 58.77734853375343, 49.142732620239265, 19.62647737995271, 43.10099993982623, 46.24079058247228, 56.37886231945407, 23.202202204735052, 0.09721835789781424, 0.0476781944293649, 0.3677195376686512, 0.8346144278203288, 1.7812279683928338, 3.70751180475758, 2.223359985697654, 0.7614468410611154, 12.385567292090386, 66.7922922872728, 71.8178996732158, 76.88406436674057, 70.6804358574652, 68.45870341024091, 60.11842650751914, 62.649402541498986, 58.64709446507116, 58.3686375617981, 52.54602416869133, 54.372028689230646, 52.110656769044944, 52.12943707742999, 50.177924556116906, 53.806269937945956, 64.98881786100327, 65.26249731740644, 62.75737362523233, 63.08300879693801, 60.83796570377966, 59.38246042497697, 62.774843861979825, 67.11864133034983, 60.428336897204005, 63.35318165440714, 58.1879771140314, 47.56766957621421, 44.402195253679835, 53.34772525295135, 62.429757656589636, 64.3989129989378, 58.34870015421222, 64.92959791614165, 64.62833635268673, 55.52680192455169, 50.34070291826802, 55.807855436878825, 61.42365401790988, 62.418190586951475, 58.88451553160145, 60.91552272919686, 61.00748269788681, 62.65933006040512, 55.55670607474543, 54.552277288129254, 56.235162365821104, 69.58240755142705, 47.60561458526119, 36.146680770381806, 57.279728766410585, 49.93758916854859, 61.703546508666015, 62.97832858177924, 61.76040910905408, 55.406169429902114, 56.12743839140862, 58.94787357699487, 64.67060773603379, 62.85785690430672, 60.148522853851325, 56.05292512524513, 53.03186462771509, 53.58700944531349, 62.637313796627915, 60.810948418032744, 60.10829894773422, 50.20942903334095, 46.94841754051947, 46.95796458951889, 48.67575876174435, 59.92688148252426, 63.52869203013759, 63.722049190152084, 60.71115155373851, 58.472501923961026, 63.290451188241285, 64.75280100299467, 64.83386070497575, 59.29552501247775, 58.63515477026663, 56.24991832240936, 51.28329946148781, 53.404034799145116, 57.64856884556433, 60.09832436038602, 58.955859522665705, 58.4191341553965, 56.276433544774214, 59.047352729305146, 63.65608276859407, 73.52586438578945, 67.06919593195762, 78.64536546891736, 38.102821688498224, 1.1470855123573735, 0.4211465707950054, 5.65218738971218, 10.943122525368969, 2.5246499863363083, 0.09604209883799476, 0.08762504484864973, 0.043267845401480313, 15.705478076011905, 39.24269383953464, 40.94172731522591, 40.72052524935815, 20.855501082635698, 21.410153642777477, 37.509002301000784, 56.95245012160271, 67.0841480070545, 60.73632140313426, 75.48008334252143, 29.811190020653513, 0.2496195918009166, 0.08011740617333882, 0.06370738914777195, 0.03921576505226474, 0.10956723558446092, 0.036358762712728594, 0.025017032091836297, 0.04038569239539005, 0.03499355572726458, 0.04921125127903877, 0.011860371188020274, 0.08553512634769564, 0.06453467217544395, 0.05923199925511595, 0.07000290818752782, 0.02796957325640946, 0.03235730545354947, 0.019152542846577785, 0.03789885224954736, 0.04789687805779038, 0.048631732577397946, 0.02505295012416619, 0.1636666410993184, 0.12347218340202687, 0.17824152514578837, 0.2300623170430622, 0.18789879887575106, 0.13832347197157724, 0.22545737785197076, 0.18732686827500022, 0.12245206838293422, 0.15833522072963177, 0.14783707357222034, 0.12687693094654431, 0.13721379361325695, 0.1825617860642172, 0.14829084277153015, 0.15482155846491938, 0.17644771494932715, 0.16092870414497393, 0.143152185445351, 0.22899981437911912, 22.031757139390518, 104.0456933359946, 85.09890387135168, 92.1042726885888, 60.94379517339892, 48.4203104819021, 24.747565061815326, 70.04621213482272, 66.04463361924695, 90.99434391144784, 31.585678131349628, 0.30658486329259416, 0.18396849203253948, 0.5130789909631975, 1.4227488300492688, 2.9595133614155555, 5.355397818549987, 7.022429656597876, 5.350756674043594, 12.820345355618386, 68.51977471382388, 72.74033131137972, 80.39558195298719, 72.19479237833332, 73.7004804611206, 64.62348830315375, 66.86869221348917, 60.544776378139375, 61.06387853622437, 54.148555571033114, 57.33833682152533, 54.23591852188111, 55.757986422508, 51.81166625791981, 55.96125541194793, 69.71059845339867, 69.15660289026076, 65.4116689774298, 65.2645722512276, 62.169881020822835, 61.30824219795966, 64.37875986099243, 69.23246152939336, 63.501427635069824, 67.14919659399217, 63.32636048716884, 51.92303803659255, 46.359799215870524, 57.003303650886785, 64.59542374457082, 68.79685094279628, 59.51526403427125, 68.14307028247465, 68.05096518608832, 57.994247328850534, 51.451369101001376, 58.512988628879675, 63.78729389559839, 65.97298760567942, 61.21738441528813, 64.80382711656632, 62.17026149072955, 65.04841827577161, 58.56380293446203, 57.36570319821758, 59.71131194022394, 74.16907818086686, 51.81439622755974, 39.600759167825025, 59.809845801322695, 50.26262029524773, 63.15143454459406, 66.10913307436051, 64.96409908417733, 58.250829173672585, 57.85525029705417, 62.020195530306914, 67.3102177343061, 63.961074506082845, 61.99507274935323, 58.01586351087017, 52.46207760226343, 53.46150536690989, 64.15337654852098, 64.3295027363685, 62.06734241977815, 53.67955384715911, 47.5539138240199, 50.49952360891527, 51.21471681902486, 62.75593019300892, 66.90567231947377, 66.09080776091545, 61.75927162170411, 59.921554903830256, 65.38198840233588, 66.04137805200392, 68.14716523693454, 62.447620130354366, 61.98595323870259, 59.82402909186579, 55.82187398787468, 56.038353520054976, 60.03644504854756, 62.65287383910149, 60.67708576879194, 61.24780239597444, 58.835964433608524, 62.97453957219278, 67.17544509518531, 77.46705409019225, 70.685393733363, 81.66236631331905, 39.56751315824447, 1.2943614418468168, 7.0761514190704595, 10.305638332520763, 11.878700967757933, 2.845541051318569, 0.09254176650316485, 0.2686724589476662, 0.1670605025344318, 22.18967764608322, 51.29920075016638, 62.84199483932988, 64.0009650107353, 46.25103973573255, 28.62180579093195, 40.159830277965916, 65.94310698970672, 75.20504674603863, 69.37336875546363, 86.84756709683327, 36.61266226922312, 0.710692351623889, 0.3779871383261296, 0.24393076077103618, 0.18774996331382185, 0.15433438783211095, 0.17118133544441194, 0.2524150006713406, 0.18125087172994692, 0.15089014845509685, 0.15005203294417552, 0.08162281490982541, 0.12929321056412113, 0.15207874919137648, 0.1345934817988065, 0.2615660741444557, 0.10334995710441183, 0.2539159201325909, 0.193426322432295, 0.18075749578495182, 0.18603921237011112, 0.14099911065591922, 0.16647493556862877], [0.055218514415525624, 0.04575563932678873, 0.044700506428677234, 0.0542376499112335, 0.06697218775028183, 0.0644999607315948, 0.05051899017886289, 0.029312623063883478, 0.022306053771547252, 0.058804813306778676, 0.025667925290162527, 0.015203936078074961, 0.09320313786907543, 0.050367373717768546, 0.08965454965589509, 0.026282180333510045, 0.04181261159359448, 0.02075130514229738, 0.047384445675678795, 0.04039804173272945, 40.949705416156405, 72.17377631895005, 70.33383169481831, 61.97415474922427, 34.86083369101248, 21.386048716883508, 34.49535508309641, 55.92454594950522, 62.4671535338125, 50.78635477250623, 2.9282981589917214, 0.06776377108068236, 0.12320350104522322, 0.13888170492024193, 0.5575625910874337, 1.0769574560465351, 2.9234577090509477, 1.9790153229428877, 3.1086330500341233, 54.72444972684307, 72.20413546408378, 71.3534204421505, 70.01833977237825, 67.33418341605895, 61.689590715592914, 55.4822555665047, 51.79671026045277, 50.42171555180704, 48.08216294934673, 49.27714832367436, 47.177982099594615, 47.279143948708814, 48.21240132854831, 48.36563264170001, 48.96399413385699, 55.588406670478086, 61.318962035640595, 62.89543321055751, 62.614105132318315, 60.20198083692982, 59.26056884950208, 61.42703117862825, 61.16470698387393, 60.35277243583434, 61.519971739861276, 59.31711766027636, 51.774882270443825, 44.56724466816072, 45.78287739907542, 52.52748704725697, 64.07924767463439, 59.465371485679384, 63.24797584164528, 59.89202337880289, 52.34820727379092, 42.98254828299246, 50.07779429035802, 56.50995577535322, 64.02569947704193, 58.121912633219075, 57.02672412318569, 56.51585502009238, 59.45549887995566, 52.652842075594016, 49.57189875264322, 52.14220046997071, 64.03218315493676, 46.21923323600523, 35.78409687165291, 56.537329996785815, 56.384804710265136, 55.73485228323168, 59.00914099908645, 61.0418858066682, 56.55000709718274, 56.22221462188229, 56.4159797083947, 59.7076053004111, 56.99876939096759, 57.91429373525805, 58.02601068250595, 55.9415376570917, 54.03163363856655, 60.89656983652423, 56.66343812019595, 51.102870433561264, 43.722495571259536, 44.35245175515452, 43.534088442402506, 45.280821861759314, 53.844481668164654, 63.26996072646111, 61.64800574702602, 57.85228106283373, 54.8006143108491, 63.136768802519775, 62.07646585279896, 57.50112302841679, 55.655012438374186, 52.75280367943549, 50.01835077039657, 50.42900723795737, 54.51302612981489, 56.34099183544036, 60.803174280351215, 63.03650125380486, 61.35905258117184, 58.73441819221743, 56.248333684859745, 57.80966058854134, 60.22040028725902, 67.29636392285748, 68.62778894362911, 64.88771092507147, 22.435602411147087, 0.7601814476713058, 3.5067523967835212, 4.256391371450117, 1.976228846657661, 0.2609592712213916, 0.07838391774003545, 0.06146852017169999, 0.9245769295000261, 30.973784462098156, 41.92305726389731, 34.807681652807425, 64.707442714322, 51.848920929816465, 23.570732416645175, 31.49198839741369, 35.841379165649414, 52.40281058895973, 58.868163170353064, 46.112505543616514, 3.330645085342469, 0.18920896244385552, 0.08336493715403542, 0.019913509473084443, 0.007822159424258937, 0.04596018863301124, 0.11330593617693072, 0.08757470521114527, 0.024854033479406953, 0.042884709508789164, 0.030727627679645538, 0.0383192123544793, 0.028733039244769082, 0.0312607099617561, 0.008710357454425145, 0.03124307653295898, 0.06267643398455074, 0.03619258292019367, 0.06457887544867492, 0.0500491522853413, 0.10273259748975117, 0.039293519146139586, 0.03749000261567774, 0.09781489524269298, 0.034922049080412236, 0.04506699140033415, 0.04153611897040279, 0.030618232239278096, 0.030675753951072696, 0.025604724951629198, 0.02615278042221983, 0.021985231470617077, 0.0632453078944837, 0.04975751410388658, 0.036129334701165076, 0.03139845448576155, 0.03842547258001663, 0.040426773860329585, 0.019779838621616364, 0.02522063336425251, 0.03385689192181153, 0.42926005478347506, 52.80821108048963, 83.0517404310165, 77.3401967940792, 70.33077224608391, 40.68673403032365, 30.132237980442664, 33.221514378824544, 54.27452248911704, 53.508256096993726, 49.62993414171281, 3.9112291701378363, 0.05922231590375305, 0.10913140050345853, 0.6982425648358561, 1.2908831575224478, 4.097443448920404, 3.2718509627926737, 1.0869303273577844, 4.399252428162483, 55.76447402277301, 75.40474245625158, 75.99159179195281, 71.56314173052388, 69.97504465041622, 64.62965034669446, 57.5098777586414, 54.876402347318596, 53.457771270505845, 51.000959411744155, 52.92803556688371, 49.747448352075395, 50.30620959497268, 49.87759651676301, 51.59221749151907, 51.57804596808649, 57.178449246191214, 63.07368924540859, 64.81861837448614, 68.52214382540795, 62.87064775343865, 58.55984918532833, 61.0090281117347, 62.1424714980587, 63.97839177039362, 63.2205427846601, 63.17524725391019, 52.612535799703295, 45.957681748174856, 47.05345076899375, 57.31018989316879, 65.80006207189253, 61.874126465089866, 62.93683775009648, 60.01615462764617, 54.72765822564402, 46.310361662218654, 53.682311273390255, 58.87799655237506, 65.46356193480953, 57.688490729178156, 59.755038522904925, 58.84955544625559, 62.327477931976325, 55.384898416457645, 51.40620693083733, 55.4191916988742, 66.7709545935354, 49.726820607339185, 38.8820436693007, 57.25271540303385, 56.34687539069884, 56.18465792748236, 60.68171808796545, 64.48217707295572, 59.30209498251639, 59.1702837328757, 59.7524497585912, 62.717953805000555, 59.73283006298927, 59.46523420272335, 60.76096565492692, 56.832864899789136, 54.5433303617662, 63.79786860558295, 59.8873322240768, 55.6658774037515, 46.20648553294521, 47.40314575933641, 44.96028577127765, 47.51008133734427, 56.28822811188237, 66.44033801171088, 65.63163157432311, 57.00867729802286, 55.84491791263704, 64.1790210047076, 64.40658123262467, 61.740134377633375, 58.225690703238214, 56.01858869675667, 50.95651503532164, 53.33715838770713, 57.54515555597121, 58.88852811628773, 63.436316290209376, 66.4217616665748, 63.96864468051542, 61.142659341135335, 59.02426958084107, 60.445203088944965, 61.58325133785125, 70.23211679150982, 70.14814669086088, 70.97357026992306, 25.016884803771976, 0.33875047439529055, 1.4391059716863017, 5.29828320587835, 2.186771381285883, 0.8089510952272724, 0.1931941824694795, 0.07644307994914633, 0.9263823229459025, 35.396507863075506, 38.11094491712509, 31.76785065281776, 56.02396234389275, 47.010508660347234, 29.927052913173554, 43.6307317210782, 41.8705092706988, 59.38408428622831, 66.03653784721129, 58.18557270111577, 4.543739797607545, 0.13068009017696305, 0.03661497315812496, 0.01919745666635854, 0.030875911658269264, 0.032301978583657937, 0.03718737873338884, 0.09486265285241027, 0.015180053287035516, 0.039769321034151706, 0.0443129885130592, 0.03797077641431843, 0.02365535677170321, 0.016337261655397953, 0.009273480916876466, 0.008223016367053554, 0.10163767398485254, 0.06041299273830749, 0.0435749240850489, 0.021898560113303607, 0.02639416132062193, 0.02693710315431799, 0.14442733879531586, 0.14050648547708988, 0.08541851244386166, 0.2033905369499999, 0.2208276327338911, 0.2132194296967599, 0.15864868858648887, 0.12191231347500317, 0.13827312467319353, 0.1836637575780192, 0.1274997374463466, 0.0704670348955739, 0.20807052211415386, 0.1554092704769104, 0.14860303892243296, 0.15702288147182236, 0.1813962292526999, 0.10193462498606214, 0.14036364072272856, 0.7345630997611631, 66.3483819653911, 90.971311753796, 85.67185232716223, 77.82108722194549, 50.76634676225724, 30.38558386987256, 50.30724117832799, 71.74421402715868, 74.34909928229548, 70.932801154352, 5.248170514260569, 0.41461205530551176, 0.31555771407100464, 0.9033010743798748, 2.5946147739887238, 5.984663665294648, 9.497379045332632, 8.608263038819837, 4.809522051965037, 59.91962902007565, 76.13587225637129, 78.31391734461631, 73.48277322707638, 73.81299757188367, 67.77059416617116, 60.23543080975933, 56.27912036834225, 55.475677751725726, 53.29010171274985, 55.004981563937285, 53.557834855971805, 51.85550266696561, 53.630398704159646, 53.52276102189095, 53.65655699083882, 58.736677477436686, 67.07216908854824, 67.98851320820471, 69.00658792065036, 62.39038490479993, 59.508137087668146, 63.32858054868637, 64.11227795385545, 66.7393873583886, 65.89828998811784, 65.4827933157644, 55.821564120631066, 49.276034370545425, 49.55040416409893, 59.58409378605505, 69.51228341748639, 63.27205527213312, 65.77073058774396, 64.88546340696274, 59.422386230960974, 49.97283950928719, 55.89661475150816, 62.178223902179354, 69.15037416642713, 59.5451368055036, 61.70934769415087, 61.412361514183786, 65.02397014248756, 59.12976172662551, 54.2944206730012, 59.86704572554558, 68.53236552207701, 55.23294579598212, 43.48368598568825, 58.84472700857348, 59.02384596486246, 58.54783496549053, 62.936221937979425, 66.00866548476681, 62.13858442921793, 61.37805254228654, 62.75886020352764, 64.35243291239586, 60.538590800377634, 61.38885082737092, 63.009836981373454, 59.56056348739132, 55.925769728998986, 65.08581023062429, 61.9243053467043, 56.48815131956532, 47.50143643348448, 49.177963349127005, 46.79429977170883, 50.55808459558795, 61.97937150155345, 69.99718250766878, 68.5156483804026, 59.47703661457185, 55.92470676668229, 65.71784134834044, 68.48542259585473, 63.989743109672304, 59.50850971283452, 61.03095808336812, 56.01418387505316, 56.25662165303385, 61.209174894517474, 61.27583949796615, 66.32453395474342, 68.67561048076999, 68.43939750425278, 65.58829330628919, 61.52203882894209, 64.06731974694037, 65.22066916188886, 74.7454704776887, 75.08375921557027, 72.5334184400497, 28.237784178026264, 3.3097324784724944, 9.792095153562485, 10.92337143036627, 4.753448338277878, 0.8061027803247975, 0.2874802239239216, 0.12057792620673297, 1.6745251585398953, 49.93193703313028, 56.99931460042154, 42.78620619927683, 73.8137585116971, 60.21966680403679, 36.35867311108497, 47.314068732723115, 49.57930026515838, 70.96459588696881, 74.41544225139003, 70.80799133546891, 6.026579583844831, 0.4829086405375312, 0.17948457941172585, 0.12676271489791333, 0.14005276224305555, 0.24378417750760434, 0.25797658449699806, 0.1771026741593115, 0.11747130943882851, 0.13168489109844933, 0.16705492541434305, 0.1673389295296323, 0.25169516913592815, 0.067644115807789, 0.049788728356361396, 0.10259420370622989, 0.17640371085895648, 0.09977009718216236, 0.1647536892203554, 0.11419733310298574, 0.16771918493172816, 0.11696893962160235], [0.06804160052730192, 0.04260221075627112, 0.030138793348845457, 0.039666025568881345, 0.06762375319076162, 0.014038615796204298, 0.07742531958126253, 0.04089005021077972, 0.036168960599048484, 0.03126789778170567, 0.04400502882837769, 0.08005345315341988, 0.05044122459366918, 0.025753698409384778, 0.07933149189357797, 0.013540393387478207, 0.03152567679212699, 0.05255268548705405, 0.09952334026175161, 3.3928080335740125, 62.46978936656829, 73.07057919040804, 63.045863951406176, 52.918876832531346, 41.42857974575412, 25.142785041562973, 44.39070663144512, 30.511970481564923, 72.26158249762751, 30.7965031362349, 0.26538057913703306, 0.05533095314017227, 0.054828659931738535, 0.4034261297314398, 0.6081769170780337, 1.6698559445719567, 2.843221704806051, 0.832128196714386, 34.18224796172112, 74.38119211504537, 68.53013761581914, 70.23723156221452, 69.91618556361045, 64.35704561971849, 55.72645841106292, 49.74049006738971, 50.526697789469075, 49.24923281515799, 50.91124303879277, 47.391551233107045, 46.45015885753017, 47.690882990437174, 47.84561657136487, 46.611925248176824, 47.227062717560806, 49.47403953921411, 58.7631417089893, 62.28969766247658, 64.69881349994291, 60.619830931386645, 60.901049183261016, 60.82320582482123, 56.895477694849816, 56.40290644861037, 61.6861076508799, 60.1854911927254, 52.96558441654329, 43.947223847912205, 44.40420350720806, 46.056360736969985, 56.567783278803674, 61.18369910024828, 62.14700968034806, 56.2589515409162, 49.22739305803853, 45.336801928858605, 52.1759367758228, 58.552584955769206, 59.60672586194931, 55.73663696166008, 56.82673815757998, 57.28966020768689, 57.680897020524554, 50.3150898410428, 46.440772625707815, 51.18387129998977, 63.876159114222375, 47.25595097387991, 37.837677309590006, 61.49587269752257, 56.543464583735314, 61.362445431370894, 55.25800581901304, 58.49770707468833, 60.14938185291906, 61.321613557877086, 60.149452455582164, 59.44299828621649, 58.37033987045289, 60.29728658737675, 56.98004791813513, 61.06967972170923, 52.68184800301829, 57.40709597064603, 61.420061126832046, 54.32608596740231, 44.10330672417918, 43.38593659862396, 43.462975871178415, 44.03315905601748, 48.18487021230882, 58.37676079042497, 60.92146512000792, 61.64935504236529, 52.604428260557114, 60.29645504490022, 62.472762523158906, 59.96039421327653, 55.287505965079035, 49.6200458465084, 48.007579080520145, 49.57453850776919, 53.87236972008982, 60.447591812379905, 62.20318586595597, 66.64186939116448, 62.43839471570907, 62.04354147757254, 60.0647057256391, 57.00345270095333, 61.91135760276549, 63.60575091454291, 66.1176367728941, 71.35761737823486, 56.442965615180235, 5.988233512447727, 4.64206136042072, 6.342697124327383, 1.4578199675006251, 0.5731248398942332, 0.18879674585355868, 0.025185992783536355, 0.09779179003089668, 8.017036828302569, 37.91459498866912, 84.74339592841365, 92.26749820093956, 101.10940702499883, 38.21508776757025, 16.81878205268614, 33.29956562288346, 49.42450392630793, 55.73535434661373, 61.11133137056905, 14.801582578689823, 0.3312349067099633, 0.05438211494155469, 0.07561673154874195, 0.04148155818843553, 0.027410438239213922, 0.03642972160671507, 0.0826185989764429, 0.019482004704074036, 0.01760030698571955, 0.012533743321264704, 0.01322809381470565, 0.04651359522775297, 0.042932919421864134, 0.0303749016471087, 0.1153717458909077, 0.041358919003077095, 0.015209828251822582, 0.05100079436576174, 0.012754269391148081, 0.04273005550907504, 0.07121351862987203, 0.07523832241854361, 0.05114029897677322, 0.016476913738334854, 0.009199422239626368, 0.009918643777529079, 0.013650110584773846, 0.05295846693878693, 0.0236603478345299, 0.04764069442547137, 0.04582554484987932, 0.06983596230706862, 0.09100775970446487, 0.0011420756181318974, 0.06392958528933025, 0.03304435608668193, 0.026080005899852803, 0.030572278455140132, 0.10382255674490046, 0.08336644634724626, 6.2901765877200715, 77.22967224736368, 79.95803371552499, 71.48619267248338, 64.20874080350323, 52.7097438996838, 28.32732992787515, 45.14728084687264, 39.63794323705858, 71.84930216881537, 32.81837905606916, 0.345931476162326, 0.10373405826788756, 0.23787872745625435, 2.0430231334701663, 2.246417638755614, 4.222528078863698, 1.3095836701893038, 1.199867867173687, 35.552292639209384, 75.19200878758585, 71.86399536748087, 73.94142381606564, 73.6832534113238, 67.59406397419592, 57.80388293727752, 52.52666334952078, 52.29235272253714, 51.54080698567053, 53.363116633507516, 50.01011771540488, 49.46099373602098, 49.61357785809425, 51.1211722127853, 48.944574479133856, 49.641422763947524, 51.50623521497173, 60.41086273808634, 64.08173053495346, 65.03465467883696, 62.09089625266291, 60.673885114731334, 61.064714001071074, 57.03149372531522, 59.389987453337646, 64.24077087833037, 63.428526463047156, 57.26141129770587, 46.25898645770165, 46.75682152471235, 49.1964534021193, 59.137865343401515, 62.51610863593317, 64.85843827647548, 58.63809654789587, 51.823107811712454, 46.46831158668765, 54.86274073200842, 61.43355015785464, 62.93759868990991, 56.86947238060736, 59.85096008546891, 60.29893006047895, 60.55138557187973, 53.301362837514574, 49.22981316043485, 55.47418725106024, 66.91728253518382, 49.642913264613, 40.71716770049065, 63.16159740571053, 58.003441364534446, 62.2744357201361, 56.185705200318374, 58.961652863410215, 60.75390538861675, 62.991021371656856, 61.736745449804495, 60.56584735070506, 59.44978006424443, 63.31589952591927, 60.68115326666064, 61.76440208188949, 55.01253212651899, 59.27379115935295, 61.230300780265566, 57.43218345026816, 46.43414774248677, 45.59581956555767, 44.824881630559126, 46.7634738645246, 49.327966551626886, 61.13978424379903, 62.172999305109826, 64.01048852551368, 53.93029136042441, 61.66527594289472, 62.81088259912307, 61.76582982463222, 57.0302503339706, 53.32967842778852, 50.62492570569439, 52.986745603622936, 55.794268346601925, 64.59808311154767, 63.91613198864845, 67.66702790414134, 66.36816640054026, 65.04029112477457, 61.515872863031205, 60.849493549716094, 65.0977969938709, 63.60703352958926, 68.12134035172002, 72.85513124158307, 59.76335787004041, 8.736217617988586, 1.6303341427157003, 3.732432338499254, 4.438948285195136, 3.1052982999432475, 0.4682752273736462, 0.07529783978938095, 0.12028854415421525, 9.512333081614587, 43.089793728243926, 78.58667896639916, 93.16610536267682, 94.45659652833017, 48.58654445217502, 23.577349455125873, 40.655853209957, 56.04479797424809, 61.03244073929326, 72.33795888962285, 20.27678870385693, 0.3060850062437596, 0.00843722795722105, 0.14455421827733517, 0.03070130106812764, 0.05137935288310532, 0.04164818614240616, 0.03400363989414708, 0.02632715735554455, 0.009886411585724883, 0.039288685131337375, 0.013029766100038205, 0.0388469856472746, 0.05364015495644943, 0.06910047959536314, 0.057877528991910725, 0.048346387808241194, 0.008387304880025407, 0.05551346592725285, 0.0339672239046664, 0.04914038814604283, 0.02173021420716278, 0.1276586853688763, 0.15732651275973167, 0.09516214726552849, 0.13730077523617976, 0.15476140524110488, 0.11476280558253489, 0.17687419609677407, 0.09304730792439754, 0.11695514237808606, 0.17098886351431572, 0.17489686187717224, 0.22496764848549522, 0.12436418553754208, 0.19731075593060066, 0.14561727252458373, 0.11432988163564475, 0.16696317872453123, 0.18132869094129533, 0.28276957992103796, 8.330534715806285, 89.5107936859131, 89.09645019039031, 83.34494544613747, 69.55894393305626, 57.10814076085245, 35.52944875532581, 57.15324801783408, 39.67350736741097, 90.2022369446293, 44.606829227939734, 0.44607090433278396, 0.2295880932961741, 0.40439786629811414, 2.3756450270452807, 2.656788508738241, 7.366775024321772, 11.021706231178777, 2.799167604215684, 39.59586797222015, 75.7998820274107, 74.28298381067093, 75.15896674125426, 76.79519914811658, 68.18563584358462, 60.86520264225622, 54.031908204478604, 54.74653267091321, 54.72846231152935, 57.50453941283688, 54.5198824328761, 50.710684407141905, 51.426999415120775, 53.113202817978404, 50.92517922001501, 51.37508292352, 54.482439487211174, 63.572740247172696, 66.42649988974294, 67.35321475613502, 63.79148298694242, 63.199844437260786, 62.68227984828334, 58.33944336060555, 60.70703698742775, 67.2120878773351, 65.48353856609714, 59.3301320845081, 49.40983818423364, 49.241274326078354, 51.432988874373905, 61.973468334444114, 64.71587188782232, 66.56037822846444, 61.201079122481815, 56.417148574706054, 49.807315488015455, 58.94841878644882, 63.74194737403624, 65.58696362280077, 59.680576247553674, 62.263457006023785, 61.553688433862504, 63.52203576795517, 56.952544258486846, 51.2850998293969, 57.79155100545576, 67.6165234658026, 53.40655688316592, 43.717741658610684, 64.93909789669898, 63.05008442171159, 64.16753630484304, 58.715657495683246, 60.49238920211793, 63.93810510635377, 65.44671143254926, 64.97736846247028, 63.15362322715021, 63.60974388737833, 65.50513513626592, 62.825952345325106, 66.12878414892381, 55.75603700453236, 61.5577990778031, 66.24444700056507, 59.80175787402738, 49.28439294138263, 46.93395183932397, 47.46460145519626, 49.04726213024509, 52.976637655688876, 64.77495454972791, 66.04487680619764, 65.8806707013038, 53.340347274657226, 63.48779347635085, 67.66254071266421, 64.27022003358411, 61.27782813964352, 55.11520016577936, 52.914385718684045, 55.60710068671934, 59.62958935768374, 66.73212312882947, 67.66694161199754, 68.06976118395406, 67.51979781735328, 68.01419688809302, 65.5220405517086, 63.74400661837671, 68.76986503601074, 67.5824772927069, 71.57845466367661, 77.39616901643815, 64.10812416384297, 7.869182104064573, 9.57775233253356, 14.38095054318828, 6.58866209368552, 2.8637131471787733, 0.3334702899859798, 0.17631990084004018, 0.19624837584072546, 14.579311666950105, 52.34793663024903, 88.4811636709398, 94.27485742876607, 104.0033160486529, 48.63087900223271, 26.838304073579852, 48.59660925403718, 65.74890652010518, 69.79708671569824, 80.46123458493142, 26.09777431334219, 0.49394784495234495, 0.14249339579574524, 0.22528917558731573, 0.12437424427198789, 0.1320305193263677, 0.12159557442270941, 0.18654101528227332, 0.11902658283830651, 0.06217347427962288, 0.19918685929188806, 0.12580587108048702, 0.17462494662932812, 0.21383911821871035, 0.1375584872139077, 0.16822677946859793, 0.09942521972040977, 0.12226175682078447, 0.14703563835111358, 0.1140666385031035, 0.13887165384667535, 0.13460842051332997], [0.04582798100947853, 0.02240136277020699, 0.041232529817329305, 0.01814335798694482, 0.054525411687791354, 0.1279775924499958, 0.01788906467657897, 0.03826056832387563, 0.030473514399941892, 0.031216914630344803, 0.08261440847549709, 0.007115392560785216, 0.016372427006342238, 0.047773744745720784, 0.057104910168075756, 0.05820834107937352, 0.046776731107984824, 0.10587065450606808, 0.13126035581433004, 28.25929249486616, 85.85574088558074, 75.42943769885649, 65.51669436116373, 43.62231431468841, 26.28760918494194, 28.204985318645356, 45.42852263296805, 39.82092965033747, 42.6817338697372, 7.161665462678479, 0.07014551545463263, 0.08838518026975856, 0.22017586044967177, 0.8216444366881925, 0.6915550462661252, 2.641842072048495, 2.352868804047185, 13.48206881553896, 76.7560225148355, 69.21125719624182, 72.95624209988502, 65.12155086763444, 64.90023113066151, 55.77675104141236, 52.603428056163175, 53.02380807938115, 56.39324957324613, 51.00977689989152, 53.12385597536641, 47.01914571946668, 47.16709752236643, 48.9646452473056, 47.776225920646425, 44.79316926771595, 46.31031459377658, 46.283297308029674, 56.96596268684634, 60.60549074603666, 64.41632047776254, 64.33391148044218, 64.14684972455426, 62.090327508987926, 59.48827420511554, 55.36919716865786, 59.68185886260002, 57.151808507980846, 55.14922280465403, 43.95939496255691, 44.37709208457701, 42.577857740463756, 47.876705277350645, 52.666946918733665, 54.791204544805716, 50.314117093240064, 46.12292335879418, 43.23984792155605, 52.26158565090549, 58.93772248298892, 61.47235024359919, 52.76941491711525, 55.551822723880896, 55.09723178801998, 58.68462370287988, 47.47336795253139, 47.968445593310946, 54.28503444117885, 66.94768874875962, 44.63192455230221, 41.339557632323235, 62.961485924259314, 54.26198659404632, 59.20261190783594, 58.018189476382354, 59.805440979619185, 54.605060623538115, 56.55945608692785, 55.505754486207046, 61.066941907328946, 58.30902145754907, 58.23689691482052, 55.35585326533164, 59.75640350772489, 56.27901838671777, 56.487574731149984, 58.68032870754119, 58.73041737464167, 46.890668484472464, 43.97215835509762, 42.88188849726031, 44.64737476841096, 43.33927608305409, 53.927310359093454, 57.50822644079886, 61.29611422938686, 56.096812525103175, 58.0117646340401, 62.424466379227184, 59.29157126334406, 52.620313859755, 48.76286283616097, 48.21168353480678, 47.92112219718195, 54.76618766784669, 58.83831001097157, 63.54495025450184, 71.38451699287661, 65.0034639912267, 64.35899111532396, 61.176760427413456, 59.42779125705842, 57.47066190165859, 64.832295679277, 62.327779954479595, 67.83150857494724, 70.05775174786969, 39.95814984844577, 0.36048570647835737, 3.4013257055513324, 7.526634652768412, 0.9218925574133474, 0.6370907300902952, 0.03816139058119828, 0.06382817056991401, 1.6042920562528795, 18.34436047461725, 38.18996890898674, 59.82517834632628, 54.63892244523572, 37.56106784266811, 32.71661512313351, 27.391438676464944, 46.00109454124205, 55.727662578705825, 60.43876255712202, 38.819136696477095, 1.901985120869452, 0.033106324938876976, 0.08170740633842447, 0.10387912467722932, 0.06362470144766473, 0.042141883844329465, 0.02340157865546644, 0.04991848832897602, 0.03177426849311638, 0.15485129799813996, 0.018481859681947578, 0.06749291303417376, 0.034939381819699085, 0.030313007488486268, 0.09336682021497719, 0.017076358386886217, 0.058726059468162645, 0.03726666883355187, 0.022442135884757006, 0.06536825244585354, 0.017732355646007968, 0.018939746603850397, 0.008656607768047721, 0.011123048907686627, 0.04187530056843835, 0.018747312978150386, 0.1302169134179431, 0.03615890186460268, 0.045680478440537575, 0.019349345088666006, 0.0393115796689545, 0.08077469429061299, 0.01681370897248628, 0.012977822465942273, 0.04564881985706668, 0.054020578897888624, 0.029133881344610167, 0.07571089141551526, 0.06662775461952533, 0.06252416251828113, 34.859915856392156, 91.88120749688919, 80.85648398245536, 72.99788198163434, 51.08125032917146, 31.44228216140501, 37.984519081731, 48.03099955281904, 36.47205706565611, 51.7603773455466, 8.502677736743804, 0.1438488045166577, 0.11582804318036764, 0.9857233096995662, 1.5144478385486912, 3.323444349150504, 1.4944048946903599, 0.7363633450961883, 16.16103783730538, 80.46153268506451, 71.48641232521304, 75.56617152306342, 68.05387558475618, 66.91833373039, 58.113338332022394, 54.41444912264424, 55.29341697692872, 58.00734020048573, 54.16848121150848, 55.39702638503044, 50.061881234568936, 49.46793240885581, 49.8992048540423, 48.284667076603064, 46.607575339655725, 48.50792446444112, 48.62691740835867, 58.98848579775903, 63.4534139017905, 65.71803746684905, 64.52528784351965, 65.01361900760283, 62.66266407505159, 59.36779468290268, 54.732957347746826, 62.293463137842, 60.401864820911044, 57.39927084215226, 44.61688226269138, 45.337711918738584, 45.803524755662494, 49.542763387003255, 54.842854315234774, 56.532583928877315, 51.91731922088131, 49.66899310388873, 45.808157074836, 54.68068392046037, 62.000870012467914, 63.18910106535881, 53.17767873887093, 58.78830371364471, 58.55200836735388, 60.19517160231068, 49.196308274422925, 50.19181759126725, 56.50851626549998, 68.44659113114881, 46.663822127926736, 44.04835431806503, 65.60948194996004, 55.7848350463375, 62.20286815397201, 60.00644676146969, 61.18615058160598, 54.693647353879875, 58.38151470307381, 57.39319509075534, 63.14066371610088, 59.46735620498658, 61.90067698878627, 58.25204903079618, 63.290200156550256, 58.21300575810095, 57.3690725141956, 61.623306582050944, 61.03150329282207, 48.77646953828874, 47.55591423280778, 44.25656941629226, 47.10271573835804, 44.80992171072191, 57.57830350629745, 59.58727090589462, 63.568229521474535, 54.84311711403632, 58.70489843430058, 65.057373046875, 62.66163641406644, 55.19904867295296, 50.700858869860255, 50.89600463067332, 50.19825420072002, 57.51125058820171, 62.69456863403321, 65.61331802798857, 71.48195651269728, 65.82301185977074, 66.1368485419981, 63.67542397591376, 61.382092583564024, 61.31131733617475, 66.85224963772681, 65.29762998703988, 71.63039468949842, 70.16007854092506, 43.6468408953759, 1.0148948959765896, 1.2524530003147742, 10.545136294057293, 4.1985746545176355, 1.3440827544658416, 0.11571611007375103, 0.09343677170334325, 0.5280234051808235, 23.6440219033149, 43.8965311358052, 72.08853537036528, 68.76151038754371, 41.13803409760998, 41.36163665402321, 34.519493349136845, 52.483297624895656, 63.199083497447354, 67.43629840112501, 51.1740614521888, 2.0972273474739445, 0.038248690130609664, 0.028402813214568362, 0.059571935449756926, 0.05029108285182907, 0.02519127687499408, 0.013025510481618827, 0.11502882195336205, 0.04359280840764123, 0.09294971598372345, 0.020264956138787732, 0.04696949032105265, 0.05206929549815194, 0.021318901600616596, 0.0428097976011134, 0.025604960523665916, 0.008849512537821166, 0.018016422963550976, 0.021673577326920726, 0.058168780298963677, 0.04484304857830848, 0.13390104556756635, 0.14340464205991837, 0.1517495305667962, 0.13484120399000185, 0.2374789980991233, 0.3030679374933243, 0.10208151468466367, 0.1332885889156211, 0.12179337832475863, 0.16164992996040853, 0.15519689558254135, 0.1608304610295642, 0.11687540794692694, 0.21645319407745717, 0.18068828740187232, 0.17238945610100226, 0.12095206056631382, 0.154924719864803, 0.2123836277713699, 42.362048933582926, 106.61561458341538, 91.91945060606926, 84.04664178048411, 59.185239730342744, 36.8663650943387, 39.21015385658511, 60.098394963049124, 52.50898522715415, 61.29249780408798, 10.641970788278888, 0.26757542104009663, 0.29716504617564143, 1.3426088012995259, 2.8912663267504786, 5.670285695983518, 11.915337866352452, 6.438270576538579, 17.950772200861287, 83.83486517014043, 76.07087858261602, 77.76494241529896, 71.04658126831055, 69.00697231292725, 60.87320035503757, 56.58081339251611, 57.79758753315095, 60.950969188444084, 55.509680778749534, 57.542284381005075, 52.143534075829294, 52.41689974261869, 52.55412778546734, 50.63112305056665, 49.58343836569017, 51.16018018414898, 50.04059453164378, 62.63400723857265, 66.36505203862345, 67.84382481728831, 68.47061172608407, 69.28086357731974, 64.89229617580291, 60.742714866515136, 57.0857479495387, 63.23855823086154, 62.824387319626354, 59.664082680979085, 48.31201776381462, 48.1130398473432, 47.81274318695069, 53.61373647566765, 57.941616965878396, 59.7193802556684, 56.821188003786155, 52.24249155290666, 49.15997143714659, 57.75926205419726, 64.06982614148048, 64.2228848703446, 55.35850478756813, 61.70017327031782, 61.32984661286878, 63.94671078651183, 53.13097115485899, 52.493389883349025, 60.29361524889546, 71.13881188054239, 50.30069866488057, 49.09713506698609, 68.3765297551309, 58.482186255916474, 63.54125930416969, 62.90813776754565, 63.816217453249045, 56.31108376287646, 58.43045803808398, 58.842150011370265, 65.32669475001674, 61.71965960533389, 64.30948295900899, 62.13431689047045, 66.19461720989597, 59.511882951182706, 57.38606422178207, 64.79546070098877, 66.13126308687272, 51.60329818725587, 48.611706456830426, 46.140209244143584, 49.757909313324966, 47.904448201579434, 61.048043927838734, 62.07313576052266, 66.65480536799278, 56.45565448268768, 60.470376860710886, 68.58125394390476, 64.56129127933134, 57.59702105675974, 54.84022632721932, 55.223724303707, 54.37208752478323, 60.418817304795795, 65.28740436800065, 69.81034432688068, 72.33118103396508, 67.99616183004072, 69.71557201877718, 66.87827064144996, 65.7775672789543, 62.23082288619011, 71.20160118226083, 66.43096354699904, 74.8170929570352, 72.86499992493661, 51.291579584921564, 0.5771715614584185, 9.252625107765198, 18.22260618209839, 5.522271625457272, 1.6252319971399924, 0.2944120326109471, 0.18168718944634163, 2.4023115058099074, 31.235753682351884, 49.56091611616073, 67.36010243815761, 62.08919394400812, 47.91791762075117, 45.0064952142777, 40.47854638868763, 62.40956921731273, 72.74710132229713, 74.46792356429562, 60.76313472563221, 3.2435586615916225, 0.17300174421360417, 0.1064839768373678, 0.2454062307914419, 0.14046891652528318, 0.11242233802594485, 0.1325915255133183, 0.12903062626719475, 0.11868044133147887, 0.24758041896406682, 0.1053012366737089, 0.09931832747233492, 0.17578739312387284, 0.09355834985692656, 0.23092762867529548, 0.17134431298942338, 0.1480157865631965, 0.1329085939834195, 0.1940717361867428, 0.14050153654909905, 0.0993024847740608], [0.0370693207538176, 0.058457564802900444, 0.011521739258070388, 0.10849910983515364, 0.0486102131676049, 0.007613208942911438, 0.023035252647053812, 0.025966402721561255, 0.04663427705846487, 0.015401804139987837, 0.08423906645827717, 0.04784153203570074, 0.032555526873517426, 0.1436763274813852, 0.02054592846111665, 0.05255949983914053, 0.008298758522517258, 0.04287750445186131, 1.0987554154088421, 47.057859513067434, 70.16414996116393, 63.25293371754309, 59.441731360650834, 43.57448101043702, 33.33705955936063, 31.089266884711485, 39.35225740555794, 49.55796257142098, 28.762169768733365, 0.7511160534716422, 0.0322298820491039, 0.07358827628195286, 0.23345967183911034, 1.7932511361375933, 1.4974963352564843, 2.409970423867626, 1.0383169617383712, 57.46631591550766, 70.86641896155574, 66.81492436316707, 65.02955951998311, 61.710767592153246, 57.13387150918284, 53.55558341549289, 55.5682849114941, 58.06239458822436, 58.32153774076893, 59.94733664297289, 57.28981318012361, 51.45795083815052, 47.20461107069447, 47.469363212585456, 45.68913275195707, 46.90305140710647, 46.81011084587344, 47.484205461317494, 54.66905409289945, 59.61582576074908, 61.71261502850441, 60.58810287906278, 58.9634257747281, 59.88421001741963, 60.60896596600933, 57.93869872247019, 59.925779296505844, 56.89518351708689, 51.44706233855217, 44.79446364987282, 44.78637964494767, 43.68897107339675, 44.68855573285011, 43.16738997736285, 46.19890359140212, 43.775357354071836, 44.36646638378021, 44.06498124522548, 52.277898788452156, 59.390646411526596, 58.927453717877796, 53.74949755207185, 55.5114850690288, 56.586763628067516, 56.21818242534515, 44.351388792837824, 47.620264637854795, 54.78730963122461, 64.66880736812469, 44.48467877603347, 44.607488186128684, 64.12174263308125, 51.52233262215891, 57.49042672495688, 52.08218036159393, 61.08841296165221, 57.14260662755659, 57.51268225331461, 48.91573721362699, 55.39278630287417, 59.13169545512046, 56.469406312511815, 52.106785389684866, 56.75099718955256, 57.527912816693714, 56.569615025674146, 58.88227585823306, 61.12644818521316, 48.274947443316066, 45.6880227211983, 44.19808687702302, 43.31686365988947, 45.56994761190107, 46.254310992456254, 55.10903027749831, 57.49497667435677, 59.145102116369436, 56.90584059684508, 60.08740840419647, 61.06461201944659, 53.584169649308734, 46.7794418334961, 47.82516925565658, 45.534069691934896, 53.67485877006285, 63.874715681998964, 60.57899513552266, 66.06772853482154, 65.08459821824106, 63.187245784267304, 64.87005633692588, 62.7013425673208, 63.988758594759055, 65.07299976964151, 68.13981471523162, 65.06193476338541, 59.77685866817352, 57.37487369968046, 15.761923924569162, 0.1380331706135504, 3.97178394659873, 4.087663018895734, 0.8430686677175184, 0.21341695780715636, 0.22020677975829572, 0.08389378296992472, 7.703397245176378, 27.01774270303788, 28.123966801551084, 28.490635848814442, 45.583366040260564, 16.8587137422254, 21.156299806410267, 37.15856206032538, 52.808768057054095, 51.765413668847856, 57.77172734660488, 10.755121361824775, 0.15954660492077952, 0.1158032449142587, 0.06104906022007908, 0.03024737099035373, 0.07318156020295236, 0.04967558866126403, 0.04175352323199472, 0.05781933312274276, 0.018408437815284538, 0.035313048865646124, 0.04874641593966273, 0.03745497707577963, 0.05580326549768929, 0.03124047757967586, 0.051655125383648186, 0.015756014467877968, 0.032341286555052765, 0.059226900939979864, 0.013170520391976161, 0.055025218940910794, 0.006499601032344565, 0.014013799335507136, 0.022762703461452358, 0.07277529611582718, 0.013630317745640153, 0.10149443086477057, 0.057871105344665635, 0.019324050780626077, 0.0321011639560663, 0.01572816525661056, 0.07900403527122352, 0.04201023546498149, 0.053360866112334114, 0.05779907392758516, 0.01740498137810538, 0.05870988352164146, 0.06835720576946774, 0.0545396494318641, 1.172359059414556, 59.9696784634744, 79.54863240641933, 71.24142892899053, 67.57368333878057, 47.27095011741885, 36.428797245025635, 27.291549636471657, 37.39545752925258, 49.04510482665032, 29.187276248008978, 1.040898003885823, 0.0876371183943364, 0.6062384694814682, 1.3818388768742162, 2.1872160800041693, 3.7610676019422473, 2.633774001752177, 1.723191353582567, 60.749351516846694, 74.2139736298592, 70.38190426365023, 68.37888317723429, 64.26018268831315, 59.79509376710462, 55.461490538812455, 58.726267506999356, 61.18879033673195, 60.63892110701531, 62.42612946418024, 59.386371028038766, 55.98204789623138, 49.19856363727201, 49.70587515061902, 48.015816057882006, 50.04090439888739, 49.993741819935465, 48.800415608190725, 57.729350059263176, 62.7424450843565, 62.98454161613219, 63.376045150141564, 61.664930774319565, 62.51435925883632, 62.33977064009636, 60.29679236873504, 62.05124893496114, 60.49054961050711, 54.07735278529506, 47.24197556895595, 47.310307179727864, 46.966150576068515, 46.177299176493, 46.09347812591061, 48.610137508761504, 46.87871702255742, 45.823258199999415, 46.112862479302194, 54.28951771028581, 62.1848487854004, 60.03107924615184, 55.869828885601414, 59.02088849775253, 59.74950798096196, 58.33605443277667, 46.90884474785098, 49.880322564032774, 58.08794490752682, 65.86877807494133, 47.661037675796024, 47.3455104520244, 66.65069472405219, 54.88606314505301, 58.60082226414835, 55.32386633657641, 62.81690343733757, 59.27106903445337, 57.83488927348968, 47.37069206853067, 55.678334851418775, 59.99129464549404, 58.13864938674435, 56.123202231622514, 60.03227556905439, 61.02829479402112, 56.947562848368, 60.87154119245468, 64.06943390446325, 51.2511517155555, 46.97379135316419, 45.94732276854977, 46.35339398537913, 46.90209827115459, 49.66421565701885, 57.974384446297925, 61.23523512194234, 62.38446997058008, 55.971535944169574, 62.020552465992594, 63.42117594134424, 56.328922702420144, 49.452678311255674, 49.94466904670962, 48.21821428114369, 55.44523623681838, 65.55015217873358, 63.09542309853339, 66.84225543852776, 67.0737615708382, 65.77075412196498, 66.64101431446691, 65.55969138299265, 67.73268053608557, 67.56608963012695, 69.13235479785551, 68.4396485359438, 63.955916589306256, 61.93884165056291, 19.615994845667196, 0.12837352967190166, 0.4235058458101365, 1.418881495633433, 3.688313273652908, 1.3341225082835844, 0.05754761705775896, 0.1807963517644713, 6.930169136293474, 36.835778451734974, 25.36310261295688, 31.215973169572894, 41.393321560275176, 20.74082862946295, 30.739313017937448, 42.55187596044233, 59.276999658153905, 57.69664925913657, 68.22820924943494, 15.410961028068298, 0.1519076204708507, 0.017427500532639605, 0.0375026315751095, 0.06212986472453322, 0.0012235933583372484, 0.005519376690274165, 0.10677403304725887, 0.08372135956080691, 0.023157826714938688, 0.046154683035227566, 0.029587035758360743, 0.04558882751171628, 0.060769135522986614, 0.04172449616054374, 0.04453233097709956, 0.01578113161808541, 0.0237153108126574, 0.023874536442059665, 0.09329720580529782, 0.03907996064592754, 0.1280179729444846, 0.145829402270817, 0.09773529104648099, 0.22939609634059094, 0.18052760812063373, 0.17750744437498434, 0.2017596889767916, 0.16461962383360634, 0.14520251252237829, 0.11939824273389195, 0.16185934775538985, 0.12032592924492014, 0.20871045067906382, 0.23703580091316856, 0.10598284808257896, 0.1668633268244805, 0.18286526413454166, 0.20308751853242998, 1.7376183213726168, 71.71521986684492, 87.95346367743709, 79.71934964579921, 77.59022435834332, 59.56326600044005, 45.87316251570179, 41.36868123085269, 53.09224559414772, 67.75977626923593, 41.93931941063174, 1.5022285522953158, 0.23396646964453885, 0.5733050850610579, 2.3044451830848574, 6.253585286678807, 9.463174996837493, 10.204717709172158, 1.8511033995497612, 66.60819192086497, 75.48545698965751, 73.43229232295867, 70.1156851553148, 68.77187328953897, 61.04323510200747, 58.70436891432732, 61.22058506934874, 64.94218872439477, 63.27700138092042, 66.38971590226697, 62.68045202378304, 58.300509914275146, 52.31508678005588, 53.13510141065044, 50.34090295914681, 52.661777234846554, 52.66794320075743, 52.93082437207622, 60.20526386076405, 64.63526325841104, 66.3506490953507, 67.13370323181152, 64.92493814037692, 65.19668386828515, 64.34181897870957, 60.79669060245637, 64.43654814074117, 63.376092218583636, 56.55175255190942, 49.41530596825385, 51.05056954968361, 49.41751426266086, 49.554259853978316, 47.95301891142323, 49.82875908574751, 48.065665460401966, 49.21853634618944, 49.311386692908506, 55.57606297154581, 65.04183653862246, 63.97176296480241, 57.89730595004175, 61.39423624161751, 62.59667411927254, 62.077709244143584, 49.50911729566513, 52.90854138712729, 60.884787036526596, 69.76176184992637, 51.05502143982918, 51.03076158031341, 70.70241681991085, 58.00792071127123, 63.22925829118299, 56.41551686871437, 67.08883131704023, 61.794243474160474, 59.55564483519524, 50.53558980264972, 59.04535232051727, 62.320598094694084, 61.58538118485482, 59.213347434997566, 63.5065031820728, 64.74061027649911, 58.13071050951558, 63.53901570843112, 68.93135686074534, 54.77162407290552, 48.52611641730032, 50.16843634267008, 49.079209835298606, 50.157473318038456, 51.36953276972617, 60.59860698638424, 63.31958655388125, 64.14179771177231, 57.41191264121764, 65.0314030339641, 67.4407071451987, 58.27340633638444, 51.98975755322365, 51.21516004685433, 49.941025164819536, 58.86736692920808, 69.55228374850365, 65.4232870378802, 73.23312221034881, 68.08250104227375, 67.87261501435312, 71.91966948970672, 69.27214022605651, 70.66960227104926, 71.3122747790429, 71.99315901725524, 71.45896357874717, 66.23689251561319, 64.70550506345688, 22.101736145634806, 0.6203393289639104, 9.164664976058468, 12.02072803051241, 5.176158739674476, 1.3186534157683774, 0.5185445686501842, 0.3023707668387121, 10.547267121653404, 43.101705966457246, 38.16735644494334, 38.29540614158877, 59.19561439944852, 24.00187150124581, 32.918303397394, 51.32266436853717, 70.04711427996236, 64.66791306772541, 75.11614230371292, 16.644328755717126, 0.29545118491495814, 0.28389465664663627, 0.12767850406347744, 0.15078455089561402, 0.20501289666900713, 0.1643680712027896, 0.28959652649298795, 0.1589704148711697, 0.0552142856101836, 0.1291267243364165, 0.12711164496478536, 0.10452156601053093, 0.12453198943647648, 0.12481923410368544, 0.15530993951664818, 0.13136365511004003, 0.16274042547710482, 0.07341844991089837, 0.1197307478756674, 0.14229900864583833], [0.041756273487642895, 0.036235460861315655, 0.045204259034606724, 0.03839208646827648, 0.017434774537480647, 0.02518911650704761, 0.03843593734106229, 0.06412150946656062, 0.011697511429027205, 0.03793913698304565, 0.036167083683634, 0.021321693991100597, 0.026946233007155602, 0.08148806770482371, 0.10645073628233326, 0.009577381293169193, 0.11979198128345514, 0.27588281720396013, 9.707103275483655, 71.73527102316581, 67.6597793640629, 69.44706224626111, 53.800868834218676, 34.84682690712714, 24.190967006068078, 51.25907098093341, 39.40103992339104, 42.93350688872799, 7.6256205670295225, 0.1897797592344784, 0.06918199901138583, 0.4632277804757319, 0.6828204181886489, 0.9439667374376328, 2.0734994594127905, 1.701129247103968, 23.430001697232647, 79.61638742877592, 66.33231593716529, 69.53067933359455, 61.667605830777084, 58.63525675189111, 54.22939169791437, 58.89874981295679, 58.645360777455, 60.327092678316184, 59.52070436170025, 58.35766277005596, 55.094709703999186, 56.513638880945024, 47.62899583385837, 46.784854704333895, 46.250796548781864, 47.43303814241963, 49.89436072687949, 46.4876724058582, 51.39270613270422, 56.56737535230575, 58.03007425800447, 56.42346751305365, 57.02712028257309, 58.47797755272158, 59.94566963564966, 57.69369963676699, 57.791503937013694, 58.06019806092786, 50.60448623472645, 46.660291994771654, 47.65844498911212, 44.44858120333764, 42.994331082990094, 43.9269216599003, 45.00271012706142, 42.99624127726401, 43.75709479854953, 43.31841691847771, 53.28705403112596, 56.820172109911525, 58.266585334654785, 51.60044270177042, 56.100256366114465, 57.815038158047585, 53.509507333078695, 41.718172257946385, 48.63779021847633, 53.32422241087883, 65.64043729535996, 45.47560284214635, 46.74780791805637, 63.7458069862858, 54.45172732876193, 51.932126168281805, 48.85601128301313, 57.108866399334325, 55.912347378269324, 63.25905653738207, 54.43075049308039, 53.96099567413331, 57.54120965157786, 54.588516066151286, 50.50470898228307, 53.83106716217534, 59.85898525484147, 55.45280641125095, 54.67961311340333, 60.877926811095215, 50.39934627471432, 43.68196964263917, 42.89203566889609, 40.278372149313654, 42.67345374630344, 45.21044669612762, 51.23054358267015, 56.71378958609797, 60.76444479726977, 57.47818893001926, 58.122869691541126, 60.573139036855395, 55.2339969911883, 50.21366519312705, 44.849380754655414, 46.95298710177022, 52.92268937633884, 63.84781606735722, 61.51996389512093, 59.677199086835316, 58.91666719990393, 58.64208559836111, 63.06411473981796, 63.339170948151626, 62.79389089153659, 63.58918674530522, 69.66465180920017, 64.00146315174719, 68.49718186163133, 56.84414563640472, 55.42479676585044, 8.459788580094616, 0.633911649065633, 3.8288417458534245, 1.6360528358528692, 1.0094333019468094, 0.007406322589714922, 0.03862518787143692, 0.8384308939979923, 18.186257577711537, 37.12490027950656, 43.001367815079234, 70.90892176474296, 32.76749807019388, 13.518740034872486, 33.645216649578465, 48.212711195791925, 53.23695359691497, 60.38028394022296, 29.851294294480358, 0.367155421164728, 0.05041100625549594, 0.09212260149539479, 0.03808562065504732, 0.06113126145435437, 0.027822591627257007, 0.028704471826072664, 0.018541411526741523, 0.053365217491744034, 0.013841754182301944, 0.03257802304541392, 0.029861063493656057, 0.05037793423980475, 0.058341019846979654, 0.057236206146978566, 0.06645959065926653, 0.08588575712975957, 0.034623339907416416, 0.0627170174923395, 0.031182837124252995, 0.048629484109340176, 0.0288663768479901, 0.05875978265858947, 0.018800272636355895, 0.04202645737677813, 0.03387494095330758, 0.057040386412653236, 0.07889659143984318, 0.056717062834650285, 0.018177402934299845, 0.033192636234866034, 0.041799270172393134, 0.05720260553061963, 0.04706012235293466, 0.07383560776830682, 0.014495719393204539, 0.10954722536787873, 0.2547001796624353, 13.80939256760382, 83.63371033822337, 75.89146937093427, 76.48942685896351, 63.563758019478094, 49.886472840462964, 35.117948978177964, 39.33581090742542, 37.09582374941918, 49.41865567238101, 9.906304767054896, 0.10092728065266725, 0.072666626543768, 0.5730060656224528, 1.8742216041972561, 4.016746811328396, 1.660837434953259, 0.9964919318595241, 26.382791380728445, 81.682464538082, 69.77931837881766, 72.05681908515193, 62.92263092533235, 63.20713220104095, 57.385232679305545, 60.99424469855524, 60.32047171746532, 63.666304465263124, 61.076551714251124, 61.3579386280429, 58.48093109746134, 57.90544094577913, 50.53688026243641, 49.49659316770492, 48.60597587400868, 50.16658106157857, 52.21207749459052, 49.204670767630304, 53.15001033967542, 59.37476081232871, 59.87968360224078, 60.20348702707599, 58.860141923350675, 59.89715383898828, 62.11601511124642, 59.428587498203406, 60.58715758785125, 60.943555908818404, 53.065565632235625, 47.37758367292343, 49.11833155539728, 45.19447872715612, 46.18923102655719, 46.9457071827304, 47.558310800983065, 45.4298327046056, 46.63067025523032, 46.04713924469487, 54.66068375495173, 59.595264696305804, 60.026031155740064, 53.91067950956283, 58.9774247138731, 59.68630683037543, 54.74896846279022, 44.785877581565614, 50.96565808019331, 56.00296981873051, 67.51781309804609, 47.4912461157768, 46.671874753890506, 67.56993355289583, 56.20728608100645, 55.605578807092485, 48.976718302695986, 58.05081967384585, 59.06337168908889, 64.79683353054908, 56.948806239712624, 54.54422073979532, 60.46175156870196, 56.85921930497693, 52.59948999651017, 57.383240115258005, 61.500893331343136, 56.285023535451586, 57.08603428256128, 63.88527862487301, 52.28237029044859, 46.27889248632616, 45.255883432203724, 43.360162704221665, 45.494296858387614, 45.97379484484273, 53.51958782442155, 58.80773121310819, 62.833193040663204, 57.51803236622965, 60.71250477144795, 62.56178855895997, 56.084653177568995, 51.82986605551935, 46.31873592253655, 49.955141775069706, 54.668956033645145, 64.26061807140228, 63.2557225227356, 62.210065703238214, 58.92117008086174, 61.553900241851814, 66.31071936699652, 66.42795901144704, 63.739699855927505, 66.41022205352783, 69.54450961082213, 65.3505741396258, 68.0826187133789, 61.70237764235466, 59.968835153887355, 12.320631473295151, 0.5243141300255253, 1.0156756927890163, 1.1039881023668474, 3.6812390338989998, 0.05721001360084742, 0.06299254101430697, 0.2730439405047125, 22.642836916831232, 41.63285678432834, 36.032547643107755, 63.57402678458922, 31.752090569465395, 20.883628399141376, 40.19487665545556, 54.651666225925574, 59.4733456642397, 68.13332711496662, 36.43820308869885, 0.28852575007946263, 0.10527580255462278, 0.022814136689468738, 0.015309430215688003, 0.05377523924013781, 0.04041902105053587, 0.02933975406772187, 0.07525735204258273, 0.01577666628309676, 0.010353885140390167, 0.008130287169478834, 0.032024984172875845, 0.044023978013184764, 0.13364192398805774, 0.04294608847328252, 0.05194908098107384, 0.030381901775516813, 0.027363978837045933, 0.0580305282417084, 0.04027795745059848, 0.18734919207711376, 0.13653882418669042, 0.1741147780370328, 0.17886527393373752, 0.14696659850737742, 0.1225236899429752, 0.14354215484232674, 0.1854749426486031, 0.1591032851607569, 0.10654265151148844, 0.13694039215483975, 0.15031765094928204, 0.1135865618444739, 0.33432070886896503, 0.16035786138907557, 0.12209289572051457, 0.293778661758669, 0.3611354409686981, 15.701940098116475, 95.76838616401919, 84.27048360147785, 89.67456833008798, 69.62316097751741, 50.88236262721401, 34.6593140786694, 69.63804244995117, 57.099468400401456, 61.520505182204715, 12.183268108675557, 0.2624725093764644, 0.18773104094209211, 1.6363710381330985, 4.319256669090641, 4.136059918711263, 11.578282713890077, 4.881536768328759, 29.718000388914543, 85.42799857354935, 71.57531676753875, 73.61872257724886, 66.87123390936083, 63.814401395859264, 60.70866084867909, 62.8955626487732, 63.110739954056285, 65.84328266882127, 64.9464915644738, 64.43253947842506, 60.922924241712025, 61.94837301008163, 52.98313310069423, 52.85387139166556, 51.36746568064536, 52.08761676665276, 55.34987949555921, 51.89091382488128, 55.375378824049434, 63.0997141715019, 64.01672509408766, 62.07284942750008, 62.50175668347267, 63.43315093748031, 64.72861959088233, 61.13694837016445, 63.296530862008375, 63.5680922385185, 54.90354907128119, 51.03574691280242, 51.81487083435059, 49.62465463146087, 48.91859662148261, 48.90142056249803, 50.36070308377666, 47.62635215636223, 48.53077227069486, 48.87702342002623, 59.45434178075483, 62.30315139216762, 61.8867878760061, 57.48015011510542, 62.87308354531566, 62.8861685722105, 58.7668405040618, 46.24745076702487, 53.66400949416622, 59.2791687288592, 70.7136583328247, 51.15014283887802, 52.86332822615101, 71.22282120489305, 59.661478227184666, 56.93681163172568, 52.63108468824818, 60.862966891258, 60.89211010163831, 67.72116445725965, 59.55660189351728, 55.93002550063595, 62.853679580073205, 59.72874687563989, 56.75460969248126, 59.764275704660726, 66.43054777576079, 56.82247846357284, 57.465762861313365, 67.56753306235036, 56.09667131977697, 47.44378543669178, 48.74541221126434, 46.316868874334524, 48.117260317648615, 49.044339964466715, 57.26857746801069, 61.53217031109718, 67.13217350744432, 56.75421745546403, 61.59175111401466, 66.4027460159794, 59.55733929910968, 55.176828445926795, 49.21768911423222, 52.543254975349676, 57.77561049307547, 67.34731551139586, 68.4956992057062, 66.98864613809894, 61.515782648517245, 63.50627176223263, 69.00414036166283, 69.18540877680626, 66.50061699651903, 68.88067983811902, 71.3174758418914, 66.54044474324873, 72.59708635268673, 64.21051763719129, 62.94901278711135, 12.23355975843245, 2.009383661131705, 10.698234246623132, 5.331337509616729, 2.557017630146396, 0.13396723556422419, 0.30661115543015544, 1.2550407840359596, 27.95283575211802, 56.00023984909058, 58.103497105260054, 79.00074005126953, 42.272391396184126, 22.865790320980935, 48.07079199821719, 63.697342180436664, 67.06050395965576, 76.17298572294175, 44.2584050855329, 0.76428038578841, 0.1653460284034091, 0.22381998748788912, 0.14373641941816578, 0.14666943300154903, 0.15884511353027436, 0.1784748602057657, 0.1809207031563405, 0.10528686486424939, 0.12599619796439526, 0.11164816787406323, 0.148565684475245, 0.1133116435319666, 0.16022083890293876, 0.15482500586057865, 0.31595111554188116, 0.11678566074659748, 0.13607903353629575, 0.1637355124037112, 0.11205543553636921], [0.04368444784514366, 0.03519869109074916, 0.04663431153242146, 0.08305503926690548, 0.0730716955337313, 0.03470386340913754, 0.060335365048940146, 0.019524993727945035, 0.03158376732420537, 0.0445372416006942, 0.02509199379522714, 0.025509145906976154, 0.052939406671230836, 0.018942692211919257, 0.09496425143292836, 0.068968084280289, 0.08817642131039212, 0.07790061585124462, 27.801077288966027, 74.28978520054972, 65.84918975830078, 63.49870551017023, 39.677312066478116, 21.22819685166882, 27.553442370507028, 41.55658629632766, 41.11239356379355, 33.44150443230906, 1.1428270440909172, 0.16192555307380616, 0.16276455724671965, 0.7467302307486535, 1.0172537726260003, 2.4171277688395594, 1.3312899441488328, 1.5087995029264882, 66.94686505102342, 69.59544550987982, 65.96245211939659, 62.39619393502513, 60.460108095599765, 60.06315246705086, 59.75110438562209, 57.393453967186716, 60.07775937357257, 57.27216643671836, 56.057733951076386, 56.53771046669253, 58.78887637968987, 56.71367975973315, 50.73967464508549, 46.132293901135846, 49.42084827730733, 52.81273749566848, 55.06204420520414, 49.69735968497492, 49.85291304126863, 48.65104390728859, 51.71019454156199, 48.19243646437123, 53.337268214071955, 54.5432597591031, 58.83589775331559, 61.13515976936587, 59.712967180436664, 55.86999754751883, 52.66805694949243, 52.991064133182654, 50.052934308205884, 48.026284863871915, 44.52527922968711, 43.48443908076133, 42.25512904505576, 43.762472368055775, 42.248041322154386, 45.160193289479906, 52.19963181403376, 54.42160352583855, 55.51997307808169, 53.53012331070439, 57.93392127560031, 53.835264098259714, 48.10590113362959, 40.743294608208444, 50.61946576641452, 52.73864000074325, 62.92727501161637, 43.52360394693191, 44.619435725673554, 61.84020973020985, 53.93228392447195, 51.797326072569824, 44.86859644612959, 50.79811011591266, 53.874177932739265, 55.68110796713061, 58.11747643255419, 58.20955799471948, 55.280728109421275, 54.43019743888609, 44.4521152588629, 51.64598534184118, 58.19690835091376, 56.492010931814875, 53.69751830254832, 59.81212077602264, 50.51071413101689, 45.13589812863258, 40.89515701417, 43.30394337254186, 43.38667792658652, 44.25654588207122, 47.72326215620964, 57.98876385534964, 58.493878841400154, 58.10478756504675, 55.42655398768764, 60.29401140828287, 56.23743341815088, 51.257439274941724, 44.784128204468765, 46.80435672883065, 49.41522359848023, 64.39357465313327, 59.2391997768033, 57.02037772824688, 58.89954605410176, 58.37506632651053, 61.12826816497311, 63.8343309587048, 63.54777828339608, 61.292482114607296, 58.34712728377312, 65.8982821433775, 64.85349216768819, 69.01284802344539, 66.57351032380136, 66.70603152244323, 6.561202560701679, 0.3855181503440104, 3.975704110437824, 1.878659643473164, 0.048353654152202996, 0.06808007346285928, 0.06174733021086263, 6.280223083111548, 30.432373823658114, 38.28767514997913, 36.302018396316036, 23.375537626204952, 22.965887246593354, 24.49171473903041, 41.39818922165902, 52.5465811452558, 56.91876480656286, 40.86799460072672, 1.426724274792979, 0.0592521243848868, 0.05899748058929559, 0.044471633830858816, 0.020369718662433086, 0.04360876218866437, 0.0834044519691698, 0.03815616586155469, 0.036559378157459924, 0.02878419093547329, 0.02178140037182358, 0.06021492070548477, 0.04750957464679115, 0.07988892044992217, 0.055248100731161334, 0.007283346325669799, 0.05375624792049489, 0.10958395928384797, 0.02712904265330684, 0.03633099968635267, 0.029737495426689426, 0.025840701099725503, 0.04895502934232355, 0.11082634705329135, 0.08472210787717374, 0.05892651020399025, 0.08144315196982316, 0.006719338510470886, 0.09669863618910314, 0.04123756684543144, 0.018043881469977, 0.0024925068024575954, 0.03544604939018046, 0.04620028058848074, 0.05699923216936089, 0.08478260584055416, 0.15206908116177206, 0.05520232697768558, 35.45952466226394, 83.94972001352619, 73.59339975541639, 71.43850449592837, 47.45965534640897, 31.299350992325817, 27.2407078742981, 38.616432528341974, 38.41358715488065, 38.199037428825136, 1.5278814660926021, 0.06989282901368796, 0.13632586706549893, 1.6733695302278766, 3.0196678109707373, 5.46517123137751, 1.3350011192021833, 2.387201310165467, 69.93549931433894, 72.86856143705307, 69.51578217168009, 64.55405842873358, 62.61173994310441, 62.74284516611407, 63.49034301696285, 59.56803168019941, 62.34574833223897, 60.36488471492645, 59.714536128505586, 59.13227988827614, 60.95839815755045, 58.34948462824668, 53.90755730290567, 48.926943425209295, 50.47819768228839, 54.50988038893669, 55.6443985046879, 52.85905284266318, 51.38444954349149, 50.75417172524237, 54.31023566953598, 50.07533496425998, 55.059251477641446, 59.44489279100972, 61.77676539267264, 63.137396381747344, 62.14334618660712, 57.36320857078799, 54.98682883477981, 55.57091289950956, 52.743790072779504, 49.98945074696695, 47.87101391823062, 45.07022196246732, 46.31181686155258, 45.19860898294757, 45.27367922567552, 46.16655580459103, 54.00633827332528, 57.71122870906707, 57.11638950532483, 57.640743717070556, 59.67923087458457, 55.44771517476728, 50.73927064095774, 42.38080178537677, 52.684632885840635, 56.053921407268895, 66.72287417996314, 45.6572203482351, 47.9986596107483, 63.15874584259526, 57.430230109922356, 54.67458463484242, 48.799117303663685, 52.54778923526887, 55.09860069521012, 58.96137437512798, 60.27637643198813, 60.894290939454116, 58.013337504479196, 56.045201978375836, 46.888369975551484, 56.27778284011349, 61.0245567752469, 57.92871236801148, 53.813702829422496, 61.59674429124402, 53.58378917940202, 45.0846484399611, 42.763648648415845, 44.98502023758427, 44.25968770057925, 45.55954156383392, 51.39642846199774, 57.58297897154286, 60.36165268190446, 59.41494157237392, 56.66784294189946, 63.510645204974765, 58.54842332101638, 51.02350519549463, 47.110399661525605, 48.90126366769114, 51.19614831862911, 67.05085492903187, 61.1468445101092, 59.12695330958213, 59.542567653040734, 59.42160567929668, 63.20354323233328, 64.44445171663838, 63.59046543798139, 60.617532422465665, 60.429925457123794, 66.77319818927397, 67.31955297531621, 71.63384637525006, 69.46135536316903, 71.69395277577063, 8.949998559490327, 0.6923316755602438, 1.9920695837466948, 2.8273638073475134, 1.2347229065433627, 0.06630105642421592, 0.11576526227497286, 5.3747252975740745, 38.7059449380444, 36.02385174843573, 37.0085863144167, 19.49359924562516, 28.87995070026767, 34.004611661357266, 45.681221331319506, 58.94484942959201, 62.889745773807654, 49.91801261901856, 2.8905754993038797, 0.06684322450910846, 0.0989705618591078, 0.07275501010759224, 0.008973258720230191, 0.046660381504484726, 0.08904190914284799, 0.027711658265381574, 0.014151858913171438, 0.05811559847526013, 0.0813034558368306, 0.020803845367364345, 0.029559399136492324, 0.02833266445856181, 0.07794321033983462, 0.030797784096531333, 0.08794742230806621, 0.10813244483283452, 0.0448365559831502, 0.06020373199135066, 0.16406201907703954, 0.09988331731649176, 0.11551981536491264, 0.24436908563779247, 0.26236853592338105, 0.14929241080197597, 0.13562937056826008, 0.16247742749269933, 0.20620122161363402, 0.16795786728541698, 0.09071522903057838, 0.13656412040995014, 0.0909500809446458, 0.1314499319320725, 0.18358140312615903, 0.220800620473681, 0.17605043707355378, 0.20070417303471796, 42.03793171913394, 95.59546455260246, 80.90468991187312, 82.30365030227169, 55.56411935437111, 30.233280197266613, 39.462224975709, 55.69522457738077, 55.25218109930716, 50.623435205028905, 2.1509022866525958, 0.34047849296081456, 0.535857971877821, 3.5437253934721795, 4.218879784307172, 10.350037601686294, 7.900561065443101, 2.0747749651632, 76.20304676794237, 73.63949544968145, 73.84737322407385, 67.13926515271588, 64.19093716529109, 65.62711692625477, 65.80102697495492, 61.76968159214143, 66.08446921071699, 61.89179282034598, 62.12011398807649, 61.405246334691206, 64.42480848681542, 60.43778196457894, 55.1939848930605, 50.77387379061792, 53.34042964443084, 56.86132169538929, 59.46523812509353, 55.995995844564135, 55.300771421001805, 51.15425740518878, 56.10961906371578, 54.71861716239683, 59.04430504768126, 62.176011685402166, 63.94628717053322, 63.05357140879478, 64.59482362193447, 60.94183791068293, 57.477545661311, 59.353764364796305, 53.323324188109375, 52.0391401936931, 51.57701830710135, 46.883019862636445, 47.46445240512971, 49.05285150774064, 47.511673819634225, 50.41722836032991, 57.584732271009884, 59.61644157286614, 60.689931531106275, 60.92313604970133, 62.57221421887798, 58.43266633249099, 53.51242165411673, 44.11395988156719, 55.69859389335879, 59.46104118900915, 66.16003759445684, 49.617833629731216, 51.6978665321104, 64.63208613857147, 59.916369530462454, 56.31791260934646, 50.92105288659373, 53.861430229679236, 57.496302435475016, 58.91235651508455, 63.32411689143028, 62.90563921774588, 60.44068059613628, 59.94907425295923, 49.38928888690088, 59.50048062109179, 64.23720544384372, 60.47885310265326, 55.64325317259758, 65.45580740897887, 54.608222053897, 50.598383026738325, 44.50671072929136, 48.1442109231026, 46.63875818252564, 47.796802674570394, 54.07694878116731, 61.53159372268185, 64.45488522129675, 61.78302157309748, 58.174311576351045, 67.73089193528699, 61.48181884519516, 55.94453434790335, 50.60287414058563, 52.55925432328255, 53.8358328419347, 69.96428951140373, 64.56759060582807, 63.13795335831181, 60.716136886227524, 61.92019862513389, 66.57094509370866, 68.68988006345688, 64.84869510896745, 61.98545117532054, 63.480639073156546, 70.48826325324275, 70.43391489213514, 76.18738866621449, 71.79392614672261, 75.67642150386688, 8.813778565775964, 1.7224979520805421, 15.378653445551473, 7.51171640811428, 0.5796479866389306, 0.11782823746363003, 0.46936674944816104, 9.887894142058588, 46.02656641314107, 53.08262009774485, 48.43201091212612, 32.84650048901958, 32.651244901841686, 36.43844235327936, 57.25181325789421, 68.36787700653076, 71.7649398311492, 61.619062577524495, 3.3392515009449375, 0.28382463621035703, 0.21218689639241467, 0.15017878985212696, 0.2093250217336801, 0.20184849388897422, 0.25815014937712305, 0.08769957754280298, 0.09531695831326709, 0.13968916159243355, 0.19743971917177403, 0.2151222695266047, 0.10155260758174044, 0.2163752216485239, 0.1796820462350884, 0.13596168418805446, 0.21346326016129988, 0.2169810439790449, 0.16683801527946227, 0.1820362191046438], [0.04517640407767989, 0.12516185926694062, 0.012009888568202095, 0.10002801600362986, 0.021517285814268455, 0.0606177565491488, 0.1313440892244539, 0.037595324383507815, 0.01409475280407576, 0.0664733495983866, 0.027004725735394225, 0.04481379934135945, 0.04068309921891459, 0.03065085800875339, 0.021429555340399666, 0.013027045530297104, 0.035561598431799686, 1.4106962445282167, 50.49298894020819, 67.05113733968427, 65.93128496600737, 60.40244925406672, 47.359372108213364, 23.69370068273237, 41.269829657769975, 39.77979575434039, 46.70645829169981, 17.373752324811875, 0.06429769053694702, 0.07531394295754933, 0.21235964921933992, 0.46885153999732393, 2.6074269510084584, 5.3853078522989835, 0.8226496666189164, 26.232968607256492, 80.36199861957182, 65.38053320300195, 68.36006364514752, 61.987475118329456, 64.24102975476173, 60.33321157578499, 61.40086504720873, 60.133017724560155, 59.55680193439607, 54.9898333703318, 52.17293616264097, 54.80652140032861, 59.43513001165083, 56.8638986925925, 51.045031163000296, 46.811993583556145, 52.17461493707473, 56.76151306398454, 57.04183701545962, 50.56662751782326, 47.05107381266933, 46.26465820497083, 47.039208642898075, 47.04542167725102, 52.75292135054066, 57.26733407666607, 60.25655669550742, 55.99935731580181, 59.77278332556448, 59.51125537195514, 59.05274991066226, 56.42338122090986, 53.917912360160585, 49.111232065385394, 46.01056706520819, 43.850455053391, 42.148832813386, 43.62668775743054, 43.46756112190985, 42.915828766361365, 51.4112118751772, 54.2046925329393, 55.7932093066554, 54.685222102749734, 57.471932749594416, 50.26529927407542, 47.32867171687465, 39.73635550468199, 51.21734872941048, 52.14188275798675, 64.7247285996714, 43.709320329850726, 42.49017315526163, 62.926451313880186, 53.851545856845, 55.66531258244669, 47.60437511628675, 46.20010383667485, 45.62220534970684, 53.26404148532499, 54.299606046369, 56.668278324988584, 57.72038352104926, 52.41868049867692, 44.247285166094386, 47.086029975645005, 59.19007209039504, 55.97999257426108, 51.23648205111104, 59.49128266303771, 53.12493854953397, 44.56152193007931, 41.46690130233765, 42.011871491709066, 43.97233878412555, 48.91568230044458, 51.37170968517181, 55.36171720873926, 58.76305541684551, 57.559079970082934, 54.650112967337336, 59.565952824008086, 56.631674766540534, 49.807382168308386, 42.68607201114778, 44.854279795000636, 48.63894339530699, 58.26814251561319, 60.85333747248496, 58.395144939422615, 60.509259316229056, 63.62894388937182, 58.38853574568226, 61.98383908117972, 59.040861206669966, 60.51408775391118, 63.74169241997504, 65.36039967690745, 62.13166929060414, 62.019230627244525, 61.80543007389192, 67.47721656676262, 60.66763677904683, 3.7968494238392, 0.5010485300613988, 6.935456981582027, 1.4430216002848841, 0.059657691332000884, 0.07665596812242463, 0.6539393937395466, 20.379966651239705, 35.84812171997563, 29.391141437715103, 39.2358140022524, 16.399852325839383, 18.50524433197514, 36.05635250768354, 49.12380718415784, 53.3238301738616, 52.83366726290796, 12.153352191371303, 0.16300838771125964, 0.07741604991737874, 0.08386859399897438, 0.01892189483999485, 0.07191800542416112, 0.04693940604826616, 0.026237632320713133, 0.05315546644851566, 0.05579504154382214, 0.027787414784993858, 0.06205758049843773, 0.02553185849871126, 0.03371570574780626, 0.03743291374356036, 0.05214209300315669, 0.10622989611640092, 0.05560573738729281, 0.013829391438423867, 0.013112703736330713, 0.04440960369162983, 0.06335187072475111, 0.026855219846531272, 0.04429636823554193, 0.02453341802221633, 0.0028740461200340503, 0.0810262775649467, 0.0503342021106472, 0.04900836055317233, 0.06165119383724467, 0.04431137206753896, 0.06110521829536846, 0.037010121309468826, 0.03543596001221769, 0.028912432138778033, 0.026924140946639162, 0.14682136355869232, 2.060332307892461, 62.75840913095782, 73.85241739211544, 74.4148225169028, 66.7973207658337, 58.23776768099878, 29.713091542643888, 40.58887481689453, 35.620769377677675, 51.10701245646323, 22.59185983288673, 0.030020572575590307, 0.026463515260407043, 0.3659195987687957, 1.1260285132354306, 4.193116186126586, 2.3291546442816338, 0.3720356770340474, 28.9183997338818, 82.0669823308145, 66.95496866779943, 70.0569123606528, 63.69600072983773, 66.47422728999969, 62.032088156669374, 60.955566206286036, 62.81205538780459, 62.14185568594164, 57.1379154728305, 56.513795775751916, 57.00571983091293, 62.15878071323518, 60.27384258085682, 54.837362996993534, 50.34405262239518, 53.71180749708607, 57.04108784275671, 61.36035480806905, 52.81389067249914, 50.506980034612845, 48.28283532973259, 50.04858832205496, 50.361146311606134, 56.288392851429606, 59.871191670817716, 64.40354139574113, 57.52645369498961, 60.780267638544885, 60.14397682682161, 60.71400311685378, 56.25317388965238, 57.37525809195734, 51.49377776730446, 47.32511804949853, 45.85404488348192, 45.190842690006384, 45.69256874822801, 46.30762384783837, 44.74209608570222, 55.35912452205535, 56.90434225143925, 59.79760016164472, 57.48789679619574, 57.627093868870894, 52.00970280554987, 49.492878683151744, 43.7294146322435, 52.82135102056688, 55.189807568826986, 66.19429557554184, 44.887125722823605, 44.30716014677479, 65.83410432261806, 55.69818204449069, 56.96825727339714, 48.99945236021473, 48.589188129671165, 47.22457593487155, 55.33635124083489, 58.794763857318515, 60.07545694228142, 57.20097149572065, 53.418418130567, 45.69834639949184, 49.75746216312532, 61.35448301992109, 56.19976297501595, 50.5971396353937, 60.4923499784162, 54.5595532847989, 45.91568885311004, 43.859186249394575, 44.548742848057906, 45.29094549917406, 50.18638510857859, 52.946384414549804, 57.346016822322724, 61.04943244687973, 59.562532517217825, 54.9768542474316, 61.81529875724547, 57.47787906277565, 53.189186972956506, 46.36166626407255, 47.241967724215606, 50.704620422855506, 61.6844210317058, 63.163229111702215, 61.399739326969275, 64.77651173068632, 63.039446953804266, 61.25781620702436, 63.40949904534125, 56.76783592470231, 61.59997632426601, 65.72281491371893, 67.15882209039503, 65.64907043210923, 64.45527745831397, 65.69746071292509, 69.0625052298269, 67.30733086985927, 5.514898550125861, 0.16807717781874443, 1.1377990558262796, 2.83169876183233, 0.9242857548017657, 0.17759470178955988, 0.07564723716988679, 22.776540710080056, 43.292592033263176, 30.59182993827328, 33.99963809597877, 16.81352411547015, 24.45129079203452, 41.25141805218112, 55.80208955272552, 59.00490876167052, 64.03279112231347, 14.988337409111763, 0.22555480891418075, 0.024651384071236657, 0.07198452483862638, 0.06102566389487155, 0.02129399991263786, 0.05320285281707203, 0.07397893515806045, 0.10188197176302634, 0.07432644796227256, 0.09766274252005162, 0.015708645336299894, 0.043239044325966994, 0.058069545099692005, 0.04712980954096683, 0.02887927585341517, 0.07009022688913731, 0.015550700031341085, 0.04098224506202725, 0.03848690517066467, 0.1299077969404959, 0.2861832983551487, 0.1442662917918736, 0.19456419282622878, 0.10244701523333789, 0.16692064552297517, 0.21725622276144646, 0.16210126300011912, 0.1306855600447424, 0.23610492747637535, 0.09162108203576458, 0.1306458460467477, 0.14719363632461718, 0.1450976350855443, 0.24110824770985112, 0.11466108442794894, 0.2736734502738522, 4.0072105488469525, 77.08430920877765, 84.3703785250264, 83.47688613399383, 74.54631605455953, 62.22101696075932, 33.91541304126863, 57.735080642084924, 53.64797092253163, 66.50297826336276, 27.378528195042765, 0.13608425825593934, 0.2454888457131963, 0.5534474731933686, 3.0393063829791163, 6.805236253046221, 15.347915791696119, 2.4960441406696074, 31.19206436218754, 84.58981944668679, 70.57188034057617, 72.25817788031794, 66.60186121540686, 69.93161616786834, 65.15188647854713, 65.23837866321688, 66.66024177305161, 65.6607630175929, 60.273054184452185, 57.994298319662775, 58.95571439496933, 65.75368004460489, 61.82419077042611, 56.64721519716325, 53.50059570804719, 56.76624736478252, 60.253356041446814, 64.5733957136831, 54.33897487578854, 52.761275999007694, 50.66289817133258, 51.67843511027675, 53.279523080395116, 58.610616422468624, 63.820516370957904, 66.54149593845491, 59.00778385900683, 61.60157272892614, 63.744818549002375, 63.03453222397835, 59.762067410253714, 60.74613125093522, 53.21363510624055, 49.65251522679483, 49.05875859722015, 46.58140920823621, 48.195813625089585, 48.55535768693494, 46.725670060803814, 56.94760991681007, 60.862096125079745, 61.176850641927416, 59.95340062725929, 60.98722757831697, 55.92005483565792, 52.611515983458496, 45.45269620034003, 55.27496222526797, 58.80021202948786, 69.37769120739353, 48.19435842575566, 49.000342738243845, 68.6386146853047, 59.04372845926593, 62.15480342988045, 50.97492271854032, 50.59258184125347, 50.1999996554467, 57.804141813708895, 60.42760341398178, 62.79357317955264, 62.27074084743377, 57.406197747876575, 49.9489365854571, 51.141717587747884, 64.70559135560067, 57.78561645938505, 53.4196222982099, 64.6253514289856, 57.65003973437894, 49.92482577600787, 45.171944710516165, 47.313052838848485, 48.24620431469333, 52.58532631781794, 54.304889478991115, 60.751065592611994, 64.02554258223503, 61.52916185317501, 56.44373439973401, 64.19550280417165, 62.28481038924187, 56.8789174479823, 48.194115238804976, 50.047246871456025, 53.79787998814737, 64.16348841882521, 66.50806165510609, 64.09993425492318, 67.87190114298176, 66.45659231370496, 62.33212594063052, 65.60835622972058, 58.76858988115865, 65.29334283644154, 67.41065394493842, 69.13816775045088, 67.36985345040598, 67.11379328081685, 67.94259009822723, 72.9133156807192, 69.99351901392784, 4.957472383975983, 2.420221293164838, 19.90453420146819, 5.201644830165371, 0.5952503171659286, 0.33956130185434896, 1.3298435701477913, 29.71672954097871, 53.06021159695041, 42.36664202905471, 55.26636438985025, 23.530987039689098, 30.06725803498299, 50.18814625278596, 64.1432999795483, 66.66275993470224, 71.44070886796521, 17.404482133926884, 0.4083175091974197, 0.12897470184872228, 0.20776077744460877, 0.16782856696555692, 0.1405861279776981, 0.21243575239373794, 0.23980367658359392, 0.18682819100156908, 0.12767329466559235, 0.1844190436625673, 0.16203924052176938, 0.1142296466916319, 0.1641965594383017, 0.1701259267546477, 0.22408572806706353, 0.2895799789938235, 0.13976226170216838, 0.1468848416040982, 0.10497009516843867], [0.011946075359329343, 0.04476628656829557, 0.009796778340974163, 0.07738401212038533, 0.07916711240766511, 0.022749059435520923, 0.07846899946490604, 0.04352995089345402, 0.07443275798352496, 0.02915959317056883, 0.11736317612831632, 0.0451979196570333, 0.07110733118268751, 0.058116724624508814, 0.07582196650365669, 0.021741607849816644, 0.06833908779005851, 17.22421980673267, 68.23568528698337, 63.879457827537294, 62.18363677301715, 53.34408921580161, 31.703531626732122, 25.272121275624922, 37.88897798907372, 40.453368694551536, 41.26977082221739, 6.40203474029418, 0.10752897439224106, 0.10727125475363386, 0.12733725019760672, 1.0226554279365847, 3.1200692105677823, 2.9105445309992763, 0.6168711570001418, 58.31489324569703, 73.25336164043796, 67.26237266294419, 62.62280887173068, 57.25955209424419, 58.996436442098315, 60.786951357318515, 57.920914696108916, 56.986013843167214, 53.99516736307452, 48.161940036281464, 47.11796983595818, 54.96179626834009, 57.47475685611848, 54.586856903568396, 53.60316176568308, 48.716198398220925, 53.5693823137591, 58.29141786021572, 59.38571599221999, 54.309917957552024, 46.85557111617058, 41.951933753105905, 46.79345253975161, 47.33508086973622, 57.13976683155183, 56.81039756344211, 63.00577732824511, 60.93921384503765, 57.60616802400159, 57.17161255498087, 59.30103594256986, 60.60309417786137, 57.27961501767559, 50.84622190844629, 43.52272141364313, 42.581034860303326, 42.75702768756498, 41.7235968958947, 43.037453620664536, 41.680823449165594, 47.70658031586678, 51.83350993740944, 54.74245732830417, 51.834996515704745, 55.658024818666526, 43.59694834678404, 44.42434880041307, 45.10762568443052, 50.27096709897442, 53.20827714858517, 63.20655561262562, 41.93855454844814, 39.04843061201034, 62.65182264389531, 54.71342394428869, 55.292938447767696, 46.24947471003379, 48.43923984035369, 42.74757085307952, 47.211141817031375, 53.865768371089814, 58.77983531644268, 56.81173509167087, 49.57067889551963, 43.002862238114886, 49.15344461317986, 56.58348844897363, 56.22696068979079, 50.42416311079457, 57.40285588848976, 51.6565522070854, 43.510644435882575, 43.100458652742454, 43.10617746845369, 44.38107721267208, 51.28431927773261, 53.17064985152214, 57.535224114694905, 58.72873467783774, 55.70485791852398, 54.67946798570695, 59.61554335009668, 58.02584594295871, 51.73642343090427, 44.077066067726385, 44.031386144699596, 47.193173439271995, 58.63849270728327, 59.99904524895453, 59.40483362443986, 59.11034599427254, 58.86351516169887, 64.02719782244775, 59.62399213544784, 62.16090663786858, 67.85087723885813, 65.37640294721051, 59.82827309639224, 62.246590814282825, 61.13043331330823, 65.01785516738892, 65.10162914952924, 69.22119648225846, 53.12673891744306, 2.7670507469484886, 3.1158602622247513, 5.817794271053807, 0.46829591174760177, 0.0731341393604394, 0.1083299039953178, 7.574334596433948, 39.963080267752375, 30.889967333885934, 34.029554013283025, 33.97659417121641, 21.161630307474447, 32.905167379686915, 50.89270199498823, 50.89390224026096, 57.455192073698974, 31.610326305512462, 0.5876603470213952, 0.014526271937234748, 0.0572781264781952, 0.0585799205357269, 0.06140390065528693, 0.0579319863520082, 0.012309185713679801, 0.016659790417179465, 0.05122422007843853, 0.037656155595135306, 0.021299674708936966, 0.02843967545026493, 0.05760859765653169, 0.0765407408377336, 0.0500423341028152, 0.028512214400595235, 0.055291595373062365, 0.052531656373532555, 0.008020464156288654, 0.029611627180730144, 0.04520847251819027, 0.0034605491495195537, 0.055478114799986926, 0.060722645477301655, 0.047279828708739056, 0.0389706552208912, 0.05102971418490333, 0.10333156333334985, 0.04128122619623619, 0.01226621967244653, 0.07875062870763003, 0.03354360026517703, 0.01965614798058185, 0.06428615325280736, 0.013013708897145286, 0.09672191760112202, 22.370730330867154, 79.2368745803833, 72.29970009096208, 68.90944650096279, 62.739240507925714, 39.576730728149414, 23.316717763100904, 39.906245123955514, 42.809716886089696, 48.72614945134809, 8.37480454675613, 0.38253282827715723, 0.016663831530980045, 0.5724508050949343, 1.8922140064739414, 4.613872756881099, 1.1241623230518833, 1.314923119160437, 62.32018624582599, 73.54143619537354, 69.60516514316683, 63.52905681056362, 60.92523844011369, 62.039324929637296, 63.314126614601385, 61.568962143313506, 59.10492135632423, 57.23113452234576, 50.836302234280495, 49.85176770917831, 58.51405159119637, 61.338805306342344, 58.61092628971223, 55.68435568963328, 50.65043287892496, 56.47435242129911, 60.44230445738762, 62.05391222430814, 56.54396664711737, 49.78093362623646, 46.097047482767415, 48.826746479157485, 49.148898586150146, 59.65309612212643, 59.82633152315694, 63.753961593874045, 61.1541832647016, 59.289672836180664, 59.96610126187725, 60.57026393951909, 60.92696820535968, 59.654523864869155, 53.20164049825361, 48.222838755576845, 44.946647690188506, 45.01719544010778, 43.035351230252175, 45.44465534148678, 44.44968338935606, 50.40914435540476, 53.60186738352622, 57.3759013606656, 53.82885102302798, 56.640539323129964, 46.05113221753029, 48.29906609750564, 45.183425488010535, 53.77936640093404, 55.21058828599992, 66.70013227770406, 44.51586161890338, 42.07997952738116, 64.55931440476449, 55.684018365798465, 58.313724379385675, 49.13041637789819, 49.881440439531886, 45.021729700026974, 50.15482571817214, 55.72585828842656, 60.06771418356127, 57.4003847952812, 52.12797795572589, 44.841771356521114, 51.2682532495068, 58.32493059096798, 58.34795882624965, 51.736925494286325, 59.55163225050896, 55.54571951589277, 45.16897939866589, 45.14184444181381, 45.591206858235026, 46.18778759433378, 52.82373582163165, 56.127673733618956, 57.845526741397, 61.62279275155837, 56.675797508608916, 55.12324886937296, 62.70120136199459, 61.10592242210143, 52.90357174411897, 46.834810010848514, 46.144257130161414, 47.70737263464159, 61.72240918682468, 62.06548321631647, 61.91556238359021, 60.05284840060819, 60.236293731197236, 64.86855014677971, 61.18424430970223, 64.79760231510286, 68.56968295189643, 65.52146396329327, 62.98407485408168, 64.67931539781632, 63.81478971050632, 66.78434556530368, 66.2750336431688, 71.57899595076039, 60.64663248677408, 4.208091305148217, 1.3459939293323027, 2.6010553058116668, 1.6673558013093088, 0.3736535015125429, 0.17886410948009263, 6.4239769693343876, 47.34274518105292, 35.91469610891035, 31.877318120771843, 28.309261529676377, 25.71843404923716, 37.743210946359945, 58.219520814957164, 57.506198575419766, 66.03948746958088, 41.81397222703503, 0.8252154482949166, 0.03740808483393442, 0.07012809461523449, 0.04933325844185968, 0.05495668854564429, 0.042934133671224124, 0.0191806084776838, 0.04165943997401384, 0.02716419076727283, 0.018319355196229393, 0.016035207551002743, 0.08606679136714629, 0.09303727983346871, 0.014375013622245001, 0.07961165024748734, 0.027317197677949746, 0.03923708144875784, 0.0653555047427935, 0.08515488626735826, 0.118371807489424, 0.12964789395130452, 0.10384632079231162, 0.17760470689785096, 0.17127099837506973, 0.17980719435839884, 0.19135230791664895, 0.11106789457581698, 0.15485267695640365, 0.14214004540155012, 0.24906897376621925, 0.1568501133231386, 0.149304622243489, 0.15909183980716815, 0.2369812248094428, 0.1845473327463673, 0.16396455737131257, 27.879004978364517, 89.5827534890944, 81.16174636348602, 79.19259886587821, 70.8818103421119, 44.0436121725267, 37.00809601814517, 52.15801546650549, 55.8777795299407, 57.2334957891895, 9.869141290264746, 0.7574448590317081, 0.1769004729125769, 1.339324184002415, 3.9853945710966667, 9.973025264278537, 8.506379473593928, 1.6834609306627706, 68.33369747284921, 76.21355087526383, 72.35404060732934, 66.74366274187642, 63.39829675612911, 63.99638368237404, 66.0606212000693, 64.0163367794406, 63.07222227896414, 59.19257848493515, 54.01961941872874, 51.08479615180723, 60.90449694664248, 64.05698822390649, 61.33080367119082, 58.058923290621856, 54.119157406591604, 58.76478910446168, 62.55306520769673, 64.88032902440717, 61.8624613361974, 51.1679974679024, 48.175915441205426, 50.241000190857925, 51.589412996845866, 62.59102198385424, 63.27656992020146, 66.40792354460686, 62.82783508300782, 59.78231468508321, 61.0161982044097, 60.65863886187154, 63.62002441959997, 62.99372780707575, 54.68529662778301, 49.24251379505281, 46.28944366208969, 46.25482482294883, 46.22142191856138, 47.87191998574042, 46.46088261758128, 52.37955877857824, 56.71651563336773, 60.78738281803747, 55.23094930956441, 61.5822393663468, 47.78816561545096, 49.891517008504565, 47.69655866007651, 54.899156016688195, 57.379439338561035, 68.43243921956709, 47.50435075452251, 45.39045210807554, 68.34499389894548, 59.47029406024564, 60.458378330353774, 50.899927000845636, 53.716208396419404, 47.81372770186394, 52.569483864691954, 58.964057276325846, 65.08759098668253, 62.36276749641665, 55.84721249918784, 48.434046622245546, 54.26518332573676, 60.90392820296749, 60.348163650881865, 53.67178755421793, 62.01510429382325, 57.71146405127741, 48.19386420711395, 48.34110606101252, 47.835022249529445, 49.007077447829715, 56.75534317570349, 59.42168412670013, 61.832212017428496, 63.42438444014519, 59.310735964006, 55.275629028197265, 65.29362132472377, 64.3096790775176, 55.79451153355261, 49.115315252734774, 48.24933436609084, 51.31848312193348, 64.80128542069467, 65.16552455963628, 65.33345299382364, 64.32424283796742, 64.45230037935319, 68.48964306616014, 63.66247230960477, 67.00679886725642, 72.74774459100539, 67.81474436483076, 67.05050191571637, 67.07920582063737, 67.03489872717088, 69.96095549675726, 70.91122811840427, 73.85735957853257, 63.98165518237699, 3.883233007884795, 6.312533607406001, 18.273755850330478, 2.2532006425242272, 0.26766278570698154, 0.2847527976958983, 10.111205462486515, 54.660903407681374, 45.809816237418886, 49.118668879232104, 48.78640097956504, 30.658355297580844, 46.85759113680932, 66.16050827887751, 67.56501490069975, 74.49380336269256, 45.5585099804786, 1.2207519142858445, 0.21236991479752526, 0.26082021094137625, 0.16630365363051816, 0.16285815786930824, 0.14915445368857155, 0.1739078883322016, 0.21471920002612377, 0.22742987039589116, 0.14787560779481165, 0.05408985239844169, 0.21193797910405746, 0.2053933665757218, 0.14288975436600948, 0.22869072854518893, 0.14375509664175973, 0.17828269471083918, 0.1724829801147984, 0.1890186049164303], [0.028996726708306424, 0.04070495570739431, 0.05854808575203342, 0.0347863634177033, 0.03257095971475205, 0.039627100641448657, 0.03291382236526378, 0.010751853452905292, 0.0334039960627354, 0.038300899022649375, 0.028712331888175784, 0.042477231172304, 0.08221966635075309, 0.041565146041853775, 0.02534423973561535, 0.10072330974282757, 0.15097354478653402, 30.561449220103604, 76.56713685681744, 66.28637713770713, 59.879177616488555, 38.07442765082083, 37.68251619031353, 36.695914576130534, 51.733516954606586, 33.91686824060256, 44.989350534254505, 2.8267828062657387, 0.0566502561372134, 0.04030134994536638, 0.3157487763993202, 0.08811885746376169, 1.9744222274711056, 0.957432050378092, 3.2550060989395266, 70.57629692939021, 69.29168147425499, 67.84060847374701, 62.15458769952098, 57.90377393845589, 53.20654738333918, 51.37799724455803, 47.61731501548521, 49.51855451829972, 48.48286051904002, 53.015127874189815, 48.86593095717892, 53.04594985900387, 57.17615465964041, 56.19814695850496, 51.21579939319242, 53.38075160980225, 58.11131438901348, 60.40133922330795, 58.05524410740022, 53.77835050705941, 50.263443992983916, 48.050654549752515, 47.2038697427319, 50.490133454722745, 59.74882548855197, 62.27889937739219, 67.39360732416954, 59.28777048664709, 59.407712644146336, 59.557758992718114, 54.75065900433449, 56.8419098854065, 59.04552490480485, 53.25396099398213, 46.709082357345096, 42.24222052481867, 44.049217239502944, 43.6722029409101, 42.296698324141964, 43.35924486960135, 48.969748250899784, 49.16422720878355, 51.53465670924033, 51.195587419694476, 47.54987378274241, 40.839886896071896, 43.77232536192864, 42.79094834481516, 51.50524285531814, 53.29489484910042, 63.121169536344475, 39.35919607839277, 38.40779773650631, 60.61828551753875, 52.99849310228902, 56.02148340594385, 47.66198688937772, 49.86560190877607, 44.116356449742476, 46.1257984561305, 47.89937657694663, 52.29579264117826, 48.84303608248311, 45.30880797293879, 42.13536339421427, 50.09879073789043, 57.060370214523815, 56.30940891081288, 52.53833240078342, 58.032839528975956, 52.31775399177305, 43.331337205825314, 42.31998543585501, 43.96388607640421, 45.92887978399954, 51.893510433935354, 54.95919573691584, 58.25744621215328, 58.5229592938577, 58.165823567298155, 56.54701040637109, 58.43070514740483, 56.92158891308693, 54.78917667942663, 42.76399381699101, 44.87611955212009, 45.099223967521425, 56.014611413401944, 58.88912431655392, 60.88330045823128, 57.91343473619031, 54.95355536860805, 59.908003114884906, 63.99095904442572, 64.47683480478102, 60.82660651976063, 58.785762017773045, 59.533134352776315, 54.326211483247825, 55.89183730463828, 58.32675057072794, 66.39905114327708, 64.7104747064652, 71.76876021969703, 40.07293016679826, 0.21216455726854264, 1.985270155052985, 1.8147703620695301, 0.22187092191269323, 0.015292612670530236, 0.22763600933455655, 29.35847790010514, 33.651923902573124, 31.426021975855676, 30.37061414410991, 12.459804031156725, 25.17698222591031, 32.01359106648353, 49.08009629095755, 53.35326363963466, 53.24396679478308, 5.426661891321983, 0.15708134930220344, 0.03481310371670031, 0.03810684129054989, 0.04569774223191123, 0.03634966158818814, 0.07825498514237904, 0.026910824423295357, 0.05834647056256091, 0.06448837748217968, 0.0255388452205807, 0.02659768023858628, 0.011792027526685308, 0.0373516854409489, 0.06723351566301239, 0.07083452727285124, 0.00473672833909551, 0.0706726222509338, 0.07258820978383865, 0.05029699705060452, 0.01881285371529239, 0.04204719154644878, 0.036764865921389674, 0.04686345226101337, 0.03697062947697217, 0.05723975696450761, 0.04624904208486119, 0.03779131648761611, 0.08204624702733371, 0.03201096093342189, 0.013830295422174519, 0.030919948307376717, 0.050308021055834914, 0.0647472309309148, 0.06452238412513848, 0.16609147791900944, 42.1047963634614, 85.95079560433665, 72.46922492980957, 70.53962276827905, 47.19172608467841, 45.06814310627599, 36.17406283655475, 42.73529383444017, 38.156997465318256, 48.77147636105938, 2.2112371652357043, 0.05300162067156165, 0.18552611732194502, 0.9004226675437343, 2.482529614240893, 3.1194852677083786, 0.33189466163035364, 4.133276016481461, 74.57078379969444, 69.71215955672726, 71.32892916279455, 65.3958696703757, 61.722589615852606, 56.658970540569676, 53.974374878791075, 49.63334268139255, 53.13328535326066, 50.56373673100626, 54.2939813675419, 49.236618472683816, 55.67712283903553, 57.95954219756588, 60.00082992738294, 54.301967313212735, 55.372131101546756, 60.42622273968112, 62.157933481277965, 60.34166428350634, 55.68701113423994, 51.669978480185236, 48.80915857130482, 48.67025567639259, 53.86197936150336, 60.43674645885345, 64.41813261278214, 68.14333700364637, 60.490894779082275, 58.58832559277935, 60.17945074266004, 56.71971628742834, 57.91159906694966, 60.702424280105106, 54.335017204284675, 47.94327966628536, 43.85960202063284, 46.095623662394864, 46.35248007312898, 44.806289595942346, 45.9462558838629, 51.48517993188674, 51.18723277122744, 54.67693021220546, 54.56501714644894, 50.40718709268878, 43.02861652066631, 46.37943067858296, 44.474311951668035, 52.62451471820955, 55.44137270219865, 64.22261814917287, 40.44057784541961, 40.801820293549575, 64.44070193075365, 56.00111846000918, 57.52541426689395, 50.6434981284603, 51.51879464426349, 47.168501730888124, 47.89908632155388, 49.341106491704146, 54.605954923937404, 52.117897464383034, 47.29955988545572, 43.617529023078184, 53.06505572411322, 59.30802560621693, 58.89798102840301, 53.72795589508549, 60.36564957711005, 52.94870253532164, 45.77735862424297, 43.61635623439666, 44.98411417007447, 49.58173213466522, 55.493905005916474, 57.062351011460834, 60.48949449293075, 61.589876221072295, 58.64274063417989, 56.26856134783838, 59.47647179326704, 59.98524242831815, 56.00659408876973, 44.17609022509667, 47.40185137717955, 48.853277391003026, 58.22183109098866, 61.153108535274384, 62.50184689798663, 59.68380043583532, 58.832685332144464, 62.20854382361136, 65.55552974823983, 66.27654767805531, 63.512312212298, 61.511381749183904, 61.35678545121224, 56.271797303230535, 58.71078198955905, 60.05457424348401, 67.4426918645059, 67.55569534917032, 74.28605110414567, 47.609352604035415, 0.42815379317729707, 1.757647536935345, 4.008623337553394, 0.6269184920576312, 0.043766982327666015, 0.10357386928292052, 34.24895571124169, 39.19910061743952, 35.93245267868042, 31.80146340400942, 16.6792574621016, 37.772644412133005, 36.99290467846778, 55.98174587372811, 57.498600944395996, 63.45097418754332, 7.630042058806266, 0.10415241888333714, 0.07566512532291875, 0.034921030183472944, 0.021160917033651666, 0.019679025281220675, 0.09011686073556062, 0.051692709657213384, 0.057272357836125366, 0.058363864588881695, 0.023512330071459857, 0.08067252114415169, 0.017215571884486466, 0.034672779391609856, 0.14083840073116366, 0.06998775496838555, 0.02666076949437059, 0.018008193264024395, 0.03829552874630017, 0.16656991514948108, 0.10255861892214707, 0.15959702882795565, 0.18374099456254514, 0.17717056487116123, 0.1341810507038909, 0.1751698802916273, 0.1677495833005636, 0.10659929605260973, 0.181865121027635, 0.21032856627097055, 0.1033506159400267, 0.12270094736689523, 0.17177254081733767, 0.1254527888170654, 0.21671481310359894, 0.875395923372238, 53.66173451946628, 97.28864977436682, 81.01463394780313, 79.46467015051073, 54.98748779296876, 50.960457017344815, 49.93247832021406, 67.80729186150336, 47.20288915018882, 58.279066316543094, 4.003006503466637, 0.1757692215183089, 0.33427875789423145, 2.7451869653117273, 3.3304163621317957, 9.249530357699241, 3.57546815468419, 4.525961654801523, 77.60276025341403, 71.8718557973062, 74.30246230094664, 66.75390797276651, 62.973962983777454, 59.87152507228237, 54.87828900737148, 51.072028836896344, 55.0769688237098, 53.0243532888351, 57.94111098012617, 53.00785187752017, 58.124371959317116, 62.613999228323664, 62.893597541316865, 56.13968403108659, 57.63744108138546, 63.54582494305026, 65.58670082399922, 63.03650125380486, 57.71529228456559, 54.815181993669086, 51.875075294125466, 52.39145924968105, 57.60663478605209, 64.48381270131758, 67.9177144265944, 69.71245765686035, 64.63476903976934, 61.01145605887137, 61.51162101376442, 57.779701525165194, 59.1528723316808, 62.52366704325523, 58.07785264907345, 51.1915316889363, 47.27950872913484, 48.48664952862648, 49.48538303375245, 47.06619847205378, 47.71008691480083, 55.19023510717577, 54.40591404514929, 55.74137518482824, 58.720097618718306, 51.67364197392618, 46.23877448420371, 49.56558765903596, 47.76195633795954, 54.94132541841077, 59.197893296518636, 65.801438823823, 43.53833244692895, 44.919869669022106, 63.96947622299195, 59.24001562979914, 60.781122715242454, 53.47079353947794, 54.72140204521918, 49.250950813293464, 51.15136661837178, 54.58658233765633, 57.87553287321522, 53.93401761208811, 50.08408969448459, 46.31063230576054, 54.704512319257184, 63.25285527013964, 62.675537293957134, 54.970143072066776, 62.504423895189845, 56.13417310099448, 48.3942110307755, 47.3794154197939, 47.40120810847129, 52.592284602503625, 57.17462885764338, 59.973738116602746, 63.540455218284364, 65.44276552815592, 62.22731236488589, 59.397996933229514, 61.725194069647024, 61.61472051374374, 59.354815560002486, 46.26334028859293, 48.11149443349531, 50.954393033058416, 59.553656193517874, 64.5575140368554, 66.47058733047979, 63.060341419712195, 61.751254297071895, 65.36925246638637, 70.09277851350846, 69.05313860985541, 66.27768516540527, 64.60221728970929, 63.70439460200649, 59.3296927790488, 62.1466645117729, 63.554073687522646, 72.81976715210946, 68.70908398782053, 77.121352072685, 49.4094184906252, 0.4204133327209181, 8.558431286965648, 10.5179532881706, 0.42328861391832756, 0.153882886253057, 0.5187254879743822, 38.1164127011453, 49.549823653313425, 46.939427468084524, 43.57052726130332, 20.444775973596883, 39.57251025784401, 46.8204737478687, 64.02709976319345, 67.6764415925549, 72.60910449489471, 9.071166457668427, 0.40894505778147333, 0.3084970187515982, 0.267237514978455, 0.12188605198095884, 0.08878158480529824, 0.23318545832749338, 0.17575025318130372, 0.14356334483431232, 0.14919386125139653, 0.15287546531086968, 0.11330919205060891, 0.11802974157035352, 0.13654536657756375, 0.3060977845903366, 0.11590131182944584, 0.0686316874118582, 0.24245383518357433, 0.1607846642934507], [0.04548265538629025, 0.03222905467414568, 0.018673071397408363, 0.028785056614827727, 0.02107071209578745, 0.010319422675116409, 0.09022027494445925, 0.07418176459689295, 0.04842414956299528, 0.034291983897527384, 0.06255176083575334, 0.027788117670664386, 0.06516950625565744, 0.0673847337583861, 0.05324985614166625, 0.10834563944128253, 2.0775480808750277, 49.41699258742794, 66.01267414708292, 69.01473860586844, 54.92165080962643, 26.525548004334976, 19.8228665321104, 40.23355907009494, 43.002564137981786, 53.474527635881984, 33.73847884516562, 0.057720412019520044, 0.14845133819166692, 0.19085196057154288, 0.29235340114082065, 2.0241065227216293, 2.7967183291912083, 0.865394063293934, 19.534972406202748, 76.86862591774234, 65.36098411006313, 74.36380817044166, 63.35412694561867, 62.82003348873508, 60.64703256853166, 58.803981427223455, 55.29425244177542, 51.845175066301906, 46.1817196876772, 49.42904603096747, 48.829888297665505, 50.17210375878119, 54.830067388473026, 54.07575245826475, 51.298157399700536, 55.528614059571304, 58.60592134537236, 61.14271425431775, 61.45060854573404, 54.68383358370874, 52.423469712657315, 48.90895935796922, 49.07591896672403, 55.58844981654998, 58.79021390791863, 61.80416314832626, 55.707430993357015, 57.75121335060366, 58.59535448012814, 57.454497814178474, 60.15496730804444, 54.54564848253804, 57.59369096448345, 53.67401153810563, 45.88675352834886, 43.09544586366223, 43.763005810399214, 40.41004219362813, 41.73042181999453, 40.23330411603374, 47.448939431098204, 48.360223693232385, 49.61003595782865, 46.12331559581142, 43.10777779548399, 41.63244101309007, 44.341904501761164, 42.808359746010076, 54.455359443541504, 50.111087368380645, 66.27330780029297, 36.15548649141866, 37.83444919893819, 62.590872933787686, 51.48730585652014, 57.421157667713786, 48.662732570402085, 50.49103167749221, 45.300237594112275, 44.09800760207638, 40.585266236336004, 46.9359600928522, 45.46285513908633, 44.619098401838734, 42.92449720444218, 49.49904072669245, 55.05718046619047, 54.61974205509309, 53.204711714098536, 57.174256232477006, 48.595389396913596, 42.79442748715801, 41.94953326256045, 42.85137245731969, 46.56374285298009, 56.11153710273005, 56.67704482232371, 57.03165846486246, 56.8001837115134, 57.588313394977206, 58.55022761129565, 57.490367889404304, 61.3633514988807, 52.05716740700507, 41.992816617411954, 45.052979223189816, 44.94382358366444, 54.22696767314788, 57.325616575056515, 57.33944292991393, 54.59441138852028, 54.68237838437481, 59.76203210892216, 60.535519584532715, 59.84976768493653, 61.626711199360514, 59.15593962515555, 53.14965340398973, 52.3894823751142, 50.31476036194832, 57.811864960578184, 60.04348962537704, 66.40164775233116, 63.24342981461556, 68.95813880428192, 16.90680003935291, 0.3591515490364644, 3.7427643518294063, 1.7659141772216367, 0.1762745484349228, 0.08929415125279658, 8.573513780870746, 44.968973821209325, 23.001133664961785, 43.41081619262696, 21.48541804282896, 17.10145550389444, 46.08999113882742, 52.372176877913944, 51.542242573153594, 54.798566833619155, 15.633967384215325, 0.16134913319781904, 0.052384272548219854, 0.0735723722966448, 0.11094765707610116, 0.04740312672971238, 0.07116032914528925, 0.036073693735224586, 0.033583900320433804, 0.02294158307655204, 0.01608432432065808, 0.036410511952013745, 0.037895286110259836, 0.07440474980901327, 0.05915586926764058, 0.06539724887378755, 0.04242000057392063, 0.05326969015802588, 0.04544102616848485, 0.08959324730019416, 0.014097911001543605, 0.04585009030697327, 0.053363175867425824, 0.042170152488735416, 0.04464694922189078, 0.03228188409740406, 0.08383421963381191, 0.030355337676742387, 0.0626932496144887, 0.08659865556945724, 0.049006345741931474, 0.04490432029049243, 0.08756747334114007, 0.08174534301243483, 0.1035041016556563, 4.626163994112323, 63.38056372058008, 73.37795965133175, 78.44525398746615, 59.992851826452444, 38.68066133991365, 29.60693455511524, 40.25018207488522, 39.85854125791981, 56.142523827091345, 37.72623100588399, 0.04064603205469828, 0.11831984374552004, 0.42125002330830025, 1.6635272002989248, 3.8234305910525785, 1.0479472385298823, 0.8755596823269322, 21.953796109845563, 80.07603429978894, 67.50789734625047, 74.78618468007734, 66.68550183696132, 65.40702881351595, 62.595203230457926, 60.376530231968054, 56.448045084553385, 54.522871278947406, 48.32873098311886, 51.94151240010416, 51.01518192598897, 52.45453096205189, 57.45479591431157, 56.6108234467045, 54.50221607761999, 57.780858624366026, 60.78878310418899, 62.31761709336312, 62.54117258133427, 58.045716670251664, 54.98860566846786, 50.758352971846065, 51.08877343516196, 57.42472702457059, 61.32237057532034, 63.77607591690556, 59.573601445844105, 58.57581323192966, 61.70726883795954, 59.87256057800786, 60.72962591725012, 56.03706306026828, 59.79717654566611, 54.955830343307994, 47.68976903730824, 45.103644478705625, 44.346627035448634, 42.80359406625071, 44.86436813108383, 44.02340412139893, 50.38312335168162, 51.2731130661503, 52.533805985604566, 49.92966205843034, 45.26654051196191, 43.91810417175294, 46.83517871364471, 46.196761977288034, 55.82244665391984, 52.89990040563768, 69.89510674630442, 38.859415515776604, 38.883483179153934, 65.46608794120051, 53.72852856113065, 58.55259672287972, 51.11253907603603, 52.70266794389295, 48.774355380765854, 46.18056258847637, 44.143099169577326, 49.74704827031782, 47.32964054230721, 46.45720735672982, 44.66756320768788, 53.424839050539084, 57.79816019919611, 57.44570386025214, 56.033509392892164, 60.3836218772396, 51.785260861919774, 44.65153248079362, 44.02371791101272, 43.607456376475675, 48.74278422324888, 58.39355245713265, 60.02427785627304, 59.20135282701062, 57.61491098711568, 60.943995214277706, 60.97401703557661, 60.188087801779474, 61.481610959576024, 55.06774733143469, 44.39664509988601, 46.26091626382644, 47.07771062850953, 57.68990278244019, 61.00183840720885, 59.98497962951661, 57.79509682809153, 56.2057916579708, 61.081399763784106, 61.584012277664684, 62.512213722352065, 62.61824323285011, 61.55976026288925, 57.071709786691976, 55.257746942581676, 52.70626867971113, 59.73418328069872, 61.90885513059555, 67.2891624512211, 65.79288805684736, 72.03938022736581, 21.318927157309748, 0.2837420212886026, 0.7173643032869985, 2.374175363971341, 0.5806002032852943, 0.23423360450373543, 7.774815270977636, 52.487008187078665, 27.29093186316952, 37.39897589529715, 26.05203163239264, 23.463218289036906, 49.094389407865464, 58.96071149456886, 57.24056782261018, 66.3757130407518, 23.309367241397982, 0.13218876244800706, 0.010752731581188498, 0.03763076744132465, 0.05850242691174631, 0.07226606215079946, 0.06703267039190378, 0.03393559596471248, 0.02585765079505021, 0.027107460041260047, 0.03818568322927721, 0.09737448661678261, 0.056366416730827866, 0.037035708646139795, 0.02532328914610609, 0.04753407796904926, 0.036817009695955825, 0.09586355438636196, 0.014278660828788436, 0.34626984187672216, 0.16846702464165228, 0.09512812530081119, 0.09021641386132087, 0.19978799316431248, 0.1534627483136231, 0.16657549226956983, 0.15560123678897658, 0.16572407747228302, 0.19677847804081058, 0.22298426217129155, 0.13116399727521405, 0.21846287252922214, 0.24639898881075845, 0.1803029604977177, 0.372594001913263, 8.742620887294892, 80.30886619321763, 80.8418692311933, 87.64798164367677, 69.15453187880978, 39.061460725722775, 29.30081121383175, 52.800585992874645, 56.68097503723637, 71.57987456167899, 40.63494697693856, 0.45147206934709705, 0.3482381669023345, 0.7913490300697665, 3.2357073022473246, 5.752361291839231, 9.71667483929665, 1.6827497559209026, 23.80800835547909, 80.72045618487944, 70.42837650545182, 78.56702004709553, 68.97400871399911, 66.93905953438052, 64.29180091427219, 64.93902337166571, 61.12383196430822, 56.80930714453421, 49.57404428912748, 54.68346488091254, 54.205155372619636, 55.28963973445278, 58.237991256098596, 58.7425414208443, 56.095141595409764, 60.03396611059866, 64.09710622602894, 64.92914684357183, 66.58495579996418, 60.98239914063485, 57.67127936886203, 54.20395904971708, 51.8747732716222, 60.62673430288992, 64.29719417325913, 62.854942583268695, 61.63983937232726, 63.245861684122396, 63.87246031914989, 63.919101222868896, 63.14894383953464, 58.75226889887164, 62.09511280059815, 58.46291957363006, 49.88516276882541, 46.3686716172003, 47.369562425921046, 46.227744779279156, 46.478392078030495, 46.56759854285948, 53.733411911995184, 54.571810691587395, 54.48474191850232, 53.16785320158928, 47.17549923927554, 47.44201252537389, 48.1079956793016, 48.162967697266616, 58.373948451011415, 55.273918874802135, 71.98222344921481, 43.672100959285615, 42.72156553883707, 66.76001118075463, 55.426224508593165, 61.50981672348515, 54.93717947313863, 55.83738303953602, 49.69320981733261, 49.441087707396484, 45.95897220796155, 50.897326469421394, 49.334669882251376, 49.287338641382036, 48.08640695387318, 55.3679733891641, 61.19172426962084, 60.48186156057543, 57.41874148768764, 63.25505964217648, 54.565554511162546, 46.563856601715095, 47.996243430722146, 47.553945202981275, 52.69752571659704, 62.084840113116854, 63.47258252482261, 59.85069728666737, 59.570867553834, 61.84443020051526, 62.46904803860573, 63.021388361530924, 66.2876558303833, 56.78790277050388, 46.34574144117294, 49.495357621100645, 49.65939898644724, 59.03388331013342, 64.37534739894252, 62.46157984579764, 60.14546732748709, 59.38324097664126, 65.16829375297793, 66.2674242450345, 65.647881953947, 65.96744921899611, 64.28890228271484, 59.68165489935107, 58.844075895124874, 54.331381167134936, 63.224076840185354, 65.1576288284794, 72.43113087069604, 67.61119688710859, 76.55906461900281, 22.620712787874286, 1.1014622185499439, 12.472928281753296, 3.939075056583651, 0.41863325082006, 0.18214710267080417, 10.678637104649699, 60.112366445602916, 34.352600420674975, 58.24743240110336, 32.569859643136304, 27.902903979824437, 60.73932593868625, 68.429136583882, 65.75278574420561, 72.98275732224988, 29.012307159362305, 0.3719225718129066, 0.14180443760368133, 0.13102718929369606, 0.1567572021796819, 0.16557381698681464, 0.09638357486936355, 0.2381254996984236, 0.1064187061462191, 0.12413026058986304, 0.09567510441786821, 0.1582941124516149, 0.1546774726481207, 0.20486894874803482, 0.1274582691070053, 0.14214490239899005, 0.1676992360021799, 0.16618739212712935, 0.20048286555515182], [0.004132755153301743, 0.026139008076561075, 0.04213809170910428, 0.006696488501714363, 0.06110668918418308, 0.10451380553985797, 0.031045232411293738, 0.08746695494459522, 0.008954540319410304, 0.06237340024522236, 0.050307457981210564, 0.05461495204438126, 0.04526429734523258, 0.03421637484984052, 0.11855016807995497, 0.0684408319272822, 20.740036310688144, 70.53506497413882, 65.80638101024013, 60.095025647071104, 41.46688561285696, 24.881484585423625, 26.354316934462517, 51.39465162830969, 35.899528303454005, 58.579719912621286, 13.651622091570209, 0.12522886897767746, 0.05480886421977513, 0.12674394574376846, 0.2836929916614487, 2.2573399687966993, 1.8413511615607048, 1.7148713935767452, 61.11440650878414, 60.832646969825994, 62.433272100264034, 56.53999328613282, 66.53796580529982, 64.08919480539137, 67.00754411758916, 64.13201139819238, 60.9526950313199, 57.860015976813536, 55.67436933517457, 46.075831382505356, 47.35352777665662, 48.41528200334119, 53.26155470263574, 52.91683327767157, 52.60530294910554, 55.70892541639267, 60.47014936324089, 55.28779622047178, 57.73372742437548, 59.53367171748992, 57.86189479212607, 53.406027363192656, 53.86238728800128, 55.004950184975904, 62.59823130023096, 56.112427480759166, 56.67928057332193, 60.574653071741906, 59.088412100268954, 53.29722081461261, 59.98713301074121, 58.93985232999248, 57.53670677062004, 53.542290502978915, 45.581655886865434, 43.70754741853283, 42.130229011658706, 42.70282837652391, 42.3050098265371, 40.75916844029581, 44.23701640098326, 43.35612266294418, 46.09752993429861, 40.985575491382235, 43.47975969314576, 40.61679032541091, 45.670383822533395, 45.56216170710903, 56.421518095078014, 51.29242681687879, 63.12040859653104, 37.41945458996681, 35.648582904569565, 63.683810003342174, 51.6674054053522, 54.53213983966459, 49.03404374276438, 53.45504522323609, 49.16026953727969, 47.92672334178802, 42.85331795292516, 42.88379869153423, 44.26651262467907, 43.910286887999504, 41.172770607856016, 49.73757966872185, 55.975689734182055, 57.08364555912634, 55.3347901375063, 55.18575183806881, 47.39428904748733, 44.92426664598527, 40.527552481620546, 42.5365787167703, 45.5066248678392, 54.51678376043997, 56.51855361077094, 55.05068502118511, 56.278877181391564, 58.13190683241814, 54.95548125236265, 56.777688918575166, 58.34158889708981, 49.53375370271745, 43.226896255247055, 45.03492847565682, 46.3077336742032, 50.293877663150916, 56.14064108940863, 55.21186697867609, 53.44754172909645, 50.88621047235305, 54.258001465951246, 58.29280637925672, 56.96651966341081, 58.648137815537, 53.056669696684814, 51.975142801961596, 46.64887397520004, 50.394411933037546, 51.428442847344186, 57.244074421544234, 61.065996616117424, 63.852460153641246, 70.39533445912024, 55.611729083522675, 1.0973420138320615, 1.9653481917996563, 2.491457909345627, 0.1439513377244434, 0.08447027945470426, 0.68556405483715, 35.70514740482454, 39.60643483746437, 30.654189740457845, 23.649528911036832, 25.13038839063337, 39.3840011473625, 41.936012852576475, 48.281674308161584, 56.01692168943344, 45.77915506978189, 2.437915840456563, 0.06339381020816584, 0.005907360004306201, 0.05784929099102175, 0.04789205553430704, 0.04317324503415054, 0.011721690121527401, 0.03530206316481194, 0.08643903348955416, 0.04177644075224957, 0.055267854308288906, 0.05888824411217244, 0.10294108831834409, 0.021693459223775614, 0.08150788639942486, 0.022627406588364995, 0.040842250154744235, 0.011364098473061478, 0.04290775343355152, 0.03689787027636363, 0.07658224748147112, 0.04158030692187529, 0.07823021751978705, 0.052878192415641206, 0.07592466058990649, 0.067531255734784, 0.052820425555710836, 0.07004060737428165, 0.03711720507952475, 0.1510475488800195, 0.04170166290996056, 0.08163838181644678, 0.038322782324206446, 0.04669678983308616, 27.631876045657744, 82.90314535940848, 72.21008962200534, 69.13942290890601, 50.908913150910415, 29.710510623070505, 27.67205288333278, 43.26787717880742, 35.05952527446132, 67.65801429748535, 15.687758768758467, 0.20824915849633757, 0.08508449810887538, 0.680337374008471, 2.2464916734926166, 3.9132222244816446, 0.9389951945312562, 1.9784513596565494, 63.44279212336387, 61.53451588846023, 67.03609897244361, 58.86053416036791, 70.46500359812092, 66.36511479654621, 70.84612461828416, 65.75597070878553, 65.94897485548451, 61.90328928732104, 58.05024700780069, 48.863652060108805, 49.839600516903786, 48.50646142036685, 56.17559333001414, 56.59160775523032, 56.13688738115373, 57.33311222445581, 62.83086315278084, 56.87865857155093, 60.007093952548125, 61.256007994374926, 60.43089036018618, 54.666316278519176, 56.249063245711795, 58.26604012520083, 65.01925153117027, 58.09593477556783, 59.31355222578972, 61.80700294433102, 59.656806684309444, 55.97181051008163, 61.12388295512046, 61.622949646365264, 59.84920286363172, 56.812472497263265, 48.22910670311221, 44.657423880792436, 44.55027257242511, 44.23119168127737, 43.83653848401962, 42.2483943354699, 47.38633448077787, 46.541624607578406, 48.33468906341061, 43.26062079398863, 45.610155828537486, 42.68589550449003, 47.488625972501694, 48.306377395506836, 57.54885827341388, 53.53938010431106, 64.44855451583862, 40.20951101856847, 35.82571714155136, 64.51693319505262, 53.482050741872484, 58.47145857349519, 52.419080580434496, 56.28767505768807, 50.272610572076616, 49.08882356459095, 46.09730243682862, 46.63451810036936, 45.957218908494525, 45.238907414097945, 44.00022291368054, 51.06472930600567, 59.02154745594148, 57.94604139943277, 57.07498104341569, 59.64489052372595, 49.998754609015684, 45.8688400637719, 44.133634490351525, 44.81466385626024, 46.535744974690104, 57.17610759119834, 58.43821256391464, 59.01540894662181, 57.6973121396957, 58.72050554521623, 58.557240809163744, 58.933878560220045, 60.018041287699056, 52.08958579647926, 44.32479512306952, 46.74301085933563, 47.703862113337365, 52.748598898610766, 58.576884038986705, 58.11491120246149, 56.27264845755793, 54.40590620040894, 58.12619978381742, 61.04813806472286, 57.89629005616712, 59.184129699583984, 56.98381339350055, 53.373871772520005, 49.11869241345314, 52.798624807788485, 54.80194791670769, 58.31879992638865, 63.86828299491637, 67.29827019476122, 70.28073849216585, 59.96215927985407, 2.2904955187151512, 1.4997568462164172, 4.934258326407402, 0.5640344405847212, 0.03114843594601318, 0.25964126291294254, 40.32402461574924, 42.75636872937603, 32.71061193558478, 25.172718609533003, 27.86912060553028, 47.3676130079454, 48.58652091795399, 57.512066441197554, 62.99480253650297, 56.81635956610403, 4.098214930103672, 0.11495354615392224, 0.052768549911918185, 0.07544410129588458, 0.08629690885784165, 0.03334856577097409, 0.03250261318058737, 0.028970300505358367, 0.006438193818359006, 0.037010393270681945, 0.06028099195851434, 0.05871666339977134, 0.02860989827182024, 0.08557628825186722, 0.0492642683938386, 0.03800236604987614, 0.04177073722765331, 0.04349617790731211, 0.12764380028050754, 0.14294368695587883, 0.12305137130521959, 0.13745760875603846, 0.11771326298795401, 0.15458664526381802, 0.17356751546744378, 0.23605264963642245, 0.1391628285449359, 0.24416594976379027, 0.1424710719936317, 0.3204721374617469, 0.1480510266077134, 0.1649103235573538, 0.348093866580917, 0.3082506448751496, 33.43164751606603, 91.67400437016641, 80.07502232828449, 77.77743124192762, 55.54246002627958, 34.03498257360151, 36.661417330465014, 68.23683846381404, 52.18532693001532, 75.10370839026668, 16.718587067819414, 0.371942398168387, 0.17566043703306108, 1.267258109104249, 3.32282044714497, 8.163301521731961, 6.816326754708444, 2.3669422682254546, 63.35144796679097, 61.0216659884299, 69.13817559519123, 62.81109832948255, 72.24608129070651, 68.88227232040899, 72.90912658937516, 68.71115499927153, 68.37625518921884, 63.33087513523718, 62.07046070406514, 51.21571310104863, 52.023050631246264, 52.309262060349994, 56.84372986516645, 59.562818850240404, 59.0125338492855, 61.193093176810976, 65.44403637609174, 60.842417593925234, 61.55323343892252, 64.58678276308122, 62.39168320932696, 57.34726413603752, 59.053628521580855, 60.35177615381057, 68.31027307818013, 60.53394671409362, 63.73887223582115, 64.29627241626864, 64.25807245316045, 57.75736754940402, 63.869918623278224, 63.722551253534135, 60.865179108035186, 59.30388358331496, 50.61476284457792, 47.14798381251674, 47.25659816495834, 47.43364610979634, 46.248266620020715, 45.35147159330307, 50.58222678399856, 48.99860120588734, 50.904849575411895, 45.10954764581496, 49.37335621926093, 45.646331848636756, 50.627408566013465, 50.62968746308358, 61.043552813991425, 57.03780481892248, 66.01072865147745, 42.380307566735056, 40.4755183189146, 67.27934868104997, 55.75521330679617, 59.041398571383574, 54.07543082391062, 58.20085033293694, 54.40810665007561, 51.98133622446368, 49.04683851426648, 48.57921354232296, 47.632420063018806, 48.606234750440045, 46.558063260970584, 56.07439617956839, 62.459175432882006, 60.6055417368489, 58.36493092198526, 61.590998018941576, 52.89964152920631, 50.61069142433905, 44.740201580908995, 46.84325487382951, 49.3513987910363, 60.79523148075227, 60.32875576326924, 59.27536795216223, 59.45309446704004, 62.49262932808169, 59.316521460010165, 62.687410308468735, 62.22438627673734, 55.84307439865605, 48.45423898389263, 49.857564972293, 50.99934339523316, 54.56062801422612, 62.387454894281205, 61.40429319873933, 59.770728003594186, 56.595502668811434, 61.39351060313564, 64.72833325785976, 61.455911590207016, 63.738432930361846, 60.05552737943588, 58.439534402662716, 51.741306781768806, 56.05059523736277, 57.325102744563935, 63.26588930622224, 66.99879723210489, 73.42288647928547, 74.18046089910692, 64.72180251152285, 2.111430004719765, 7.200685201152679, 9.773409962654114, 0.31968913431609836, 0.2119016205711711, 1.0553639502294603, 46.54880254499374, 54.63399202592912, 44.71369812565465, 31.851461856595932, 34.84952942017586, 51.79662789067915, 57.04870508563135, 65.34372568130493, 73.11372526230352, 64.18052327248358, 4.281943651937669, 0.3394151016348793, 0.20900041495840396, 0.16163958777343074, 0.12403625394067458, 0.1096123121979256, 0.08329580537974836, 0.1260590248350655, 0.1754861060650118, 0.1545136064411171, 0.09670920054157896, 0.15493872395205885, 0.20554502134121236, 0.1545161804965427, 0.21839951705788413, 0.13602294057847994, 0.13458894655829476, 0.16227298926922584], [0.009714598174116785, 0.011851615760655654, 0.018389015571184216, 0.06176886877285377, 0.027784804340391874, 0.03516985171083962, 0.0789692931838574, 0.038534594143951134, 0.03832817941363301, 0.005093388233123528, 0.04916350101871837, 0.03411925022280024, 0.03750107258618359, 0.06459160016909724, 0.005051055650842647, 0.37265323583156834, 44.956206506298436, 66.30128998910227, 63.3581316855646, 51.75626277923585, 28.276501893997196, 21.12521698397975, 25.877652860456898, 37.48353827384211, 40.277015009234034, 49.360024083045225, 1.1458768094739606, 0.05474473116919399, 0.14245363583247508, 0.5655701097942168, 2.0727696534126037, 3.3256989765551785, 0.28358509583819297, 34.4086746246584, 65.87256708452779, 67.24503578678255, 74.24555655448668, 62.771760879024384, 54.779300151332734, 61.679906383637466, 64.70700733123287, 61.8326081768159, 66.60885087905392, 61.58719331987443, 61.82614411077192, 51.30457047493228, 45.187116438342684, 44.64712765909011, 47.377269883309644, 51.14259619866648, 54.38669835367511, 56.98041269856115, 62.20792016675396, 62.52252171116491, 57.67484872571884, 57.25570424910515, 55.68595209429341, 55.91263763366207, 53.604475759690814, 58.081849544279045, 59.350751984503965, 55.073905452605224, 59.21430841568978, 54.738468277838926, 51.44006090779459, 50.65840705748528, 58.454082473631836, 55.414014170246745, 57.997365613137525, 54.18189963986797, 44.76135884561847, 42.428588021186094, 42.1327236390883, 39.3634557723999, 41.41380417731501, 39.963990257632354, 41.78053794368621, 42.07120910767586, 43.957261193183164, 40.26599314904983, 43.42700773669828, 44.38807079868932, 49.842114756184245, 49.06145326552853, 54.72079407784247, 50.51631527562296, 66.5600016809279, 34.21041057955834, 35.06052547885526, 63.91699098771619, 53.18468801436886, 57.315261517801595, 50.390972014396425, 53.33938237159483, 51.79899700226323, 52.51528063128072, 45.51277514426939, 44.624460281864295, 42.78269567797261, 44.47777932690036, 40.23663813068021, 45.656137774067545, 53.04792281120054, 58.80041207036665, 54.10563307423746, 52.605742254564845, 42.872557178620376, 41.40714791513259, 40.537625128223056, 43.86785468747539, 42.5101968549913, 54.046401362265314, 56.40049811332457, 58.70365896532613, 57.59291041281916, 57.184309267228656, 51.8352436250256, 52.88746256982127, 51.67450489536409, 47.09961706592191, 43.894416978282315, 43.82601868721747, 44.177208100595784, 48.884173900850364, 52.65904334283645, 51.05164427911082, 50.09382501725228, 50.478327120504076, 50.64640460475799, 53.378433489030414, 53.47784596104776, 52.27545122946463, 49.012482473927165, 48.02147996041083, 47.032595526787546, 50.487368183751265, 52.17686637755364, 56.354233757142104, 56.55420011089694, 63.383454507397076, 61.63702311054353, 70.8172873527773, 17.733255201770415, 1.04326490913668, 3.1589872125656377, 1.9689462309883488, 0.23463523375891873, 0.15702216134917352, 13.872264239095873, 47.970748024602095, 32.54214417549872, 49.10444244261711, 17.21540427977039, 33.06671411760392, 37.45709365414035, 47.75981472384545, 48.97214481907506, 46.82652988741475, 14.064274064956175, 0.13066781744841607, 0.10978969985679274, 0.07804439523287358, 0.025953212602724953, 0.04303407750182575, 0.07056681784771143, 0.01266518198404341, 0.056338983122259385, 0.08588928113421125, 0.039262975220598524, 0.03190241202021078, 0.00517707615677688, 0.022261103562590097, 0.028531581103321046, 0.08317764397830733, 0.07750397382844841, 0.05710350439673471, 0.05304620698875478, 0.06631217235999723, 0.03265710247139777, 0.04833528336377875, 0.006527028895253617, 0.01620286876606124, 0.047767688820679347, 0.06278037679411712, 0.029485467821359638, 0.06293619524747615, 0.039160871022050424, 0.056077153421938426, 0.014295825986341845, 0.06340712098585022, 0.09423751744531816, 0.5928880697296512, 52.769552200071274, 75.99669871791717, 68.58094015429097, 59.20838563672958, 32.02274391728063, 26.786607234708725, 32.74070043717661, 42.7640801091348, 44.29439675423407, 56.43224185512912, 1.2529819074176973, 0.0996491012554015, 0.4471700259995076, 1.3632841047740754, 1.729693417587588, 1.3271383604695721, 0.35285479659515046, 38.133008249344364, 69.19366144364881, 66.12979612042828, 73.95266532897949, 64.50685662607994, 59.46534795145835, 63.792310607048776, 68.91530652200022, 64.08630009620421, 67.40608830605784, 62.974108111473825, 63.97530878743818, 54.792455780890684, 47.06633575500981, 46.617342041384795, 49.66726333864274, 53.60142023332658, 56.96471145076137, 59.27887455109627, 65.05583155539729, 64.34953820320868, 60.74568802310575, 57.89097132221345, 59.20913088706232, 57.843361593061886, 55.9473466873169, 58.801557402456964, 62.65715314495949, 59.179160056575654, 62.30794452851819, 56.19775079911756, 54.30958847845755, 53.68816737205752, 60.36419830014629, 58.35002591533046, 61.38780355453492, 56.770518825900176, 46.364678644364886, 43.10276892877395, 44.491064394674, 43.18644877403013, 44.717542048423525, 43.15736047683224, 45.68125271028089, 44.658314258821555, 45.02263968990695, 42.93971600071077, 45.33694313418481, 46.613364758030066, 51.57211534438595, 51.07955586525702, 57.12137091544367, 55.78324648641772, 68.7577292226976, 36.299115842388524, 36.448620903876524, 66.00227986612629, 55.37368436013499, 58.09581710446266, 52.9194926446484, 54.55968272301459, 54.6045664048964, 55.54730807581256, 48.62729395589521, 46.45256719281597, 44.69565914523217, 46.96820982040898, 42.72607626453523, 47.02156189949282, 56.16979998926963, 59.73304971571892, 56.397681851540845, 54.53201432381907, 44.7276186173962, 43.9663807038338, 43.4074664884998, 44.16529194001229, 46.15968381204913, 56.15843688288043, 58.31200245888003, 59.34357404708863, 60.320016722525324, 58.48299818654215, 53.55705822667768, 55.28592917226977, 54.05956483656361, 49.15357012902537, 46.07635698010845, 45.43498277664185, 46.62721464710851, 51.23323040623819, 54.72328478290189, 53.44629441538165, 53.520595873555834, 52.57879557148103, 53.28905836228402, 56.363996536501, 55.15611440904679, 54.16369591989825, 51.720933991093794, 49.64984801507766, 49.02387695927774, 50.968584168341856, 54.60982630329748, 58.54935684511739, 59.38100522564304, 64.34294469894903, 64.2336243198764, 72.20160161295246, 24.471965605212798, 0.381170264295032, 2.907287002571168, 2.282867244174404, 0.21541989468518766, 0.13834397248443098, 12.830103232014565, 57.407056746944306, 27.97508735810557, 34.423771827451645, 21.263035343539332, 40.6757749280622, 42.88542255278557, 55.61344708165815, 55.026680115730535, 58.31353218324723, 17.97438486929863, 0.13672015719836758, 0.03255617421781344, 0.0182699597620916, 0.01939570872984346, 0.031565725953588565, 0.057783403599094, 0.03586191638943649, 0.020604907655187195, 0.02129610665442963, 0.015536031362810924, 0.053031536405004805, 0.06986499703939884, 0.061519422883828806, 0.07922300618262061, 0.006254895312351085, 0.08497177593169675, 0.009456009983325438, 0.18244157154713908, 0.1616558288374255, 0.09496383774544924, 0.10514039651400621, 0.1359410917446498, 0.08887566806327912, 0.14443481581345682, 0.1810812905070282, 0.16932513504739732, 0.20345116514832745, 0.14616018371476283, 0.14897184897094004, 0.1401330942227956, 0.22933206671187956, 0.19025902383990828, 1.0703963113407935, 63.34458774135959, 83.23409926506781, 79.14184339584844, 67.70389033902076, 39.09041566233481, 31.26212181583528, 37.88466730425435, 53.64964577459521, 53.71257628163984, 61.22674319051928, 1.7043432617379775, 0.1437630026691383, 0.8294831709034982, 2.551415504947786, 4.957468951902082, 8.975959747068345, 1.8095387782781356, 37.744724981246456, 71.61243807884955, 68.7766585811492, 70.90476405236029, 63.02101965873473, 60.573084123672984, 66.6934250247094, 69.5246075045678, 66.6832503964824, 72.37409176365023, 65.37390047504057, 65.04921451691659, 56.67726447505336, 48.343910555685724, 48.54524973900088, 51.482104793671645, 57.72929514608076, 59.29404235655262, 62.289882013874674, 65.21047099944084, 65.6069951672708, 63.56978670243294, 59.907720704232496, 63.232098087187744, 59.33881621206961, 57.810903979885964, 60.3698504355646, 63.93045648451775, 61.58943691561299, 63.15021860984064, 58.99409086473527, 57.02537875021658, 55.132988114510816, 64.73414228808495, 58.54389298346735, 61.41990030965498, 60.410780368312714, 48.761533152672556, 46.8946300783465, 47.37648540927518, 44.10775861432476, 46.00399709516957, 45.47545771444998, 46.70723492099393, 47.17828019972771, 48.59543254298549, 46.517953103588475, 47.36911135335123, 49.45438061991046, 54.48455364473405, 54.229438766356445, 59.008999793760246, 56.91827451029132, 72.78941585171607, 39.58522265957248, 39.146674217716345, 67.04836030160227, 59.10530574860112, 61.28009134723295, 55.485111051990145, 57.09208649973716, 58.05361632377871, 56.88905285250757, 49.984383044704316, 50.07349929501934, 47.4116063117981, 50.60021869597897, 44.908890954909786, 50.34267194809453, 59.73528938908731, 63.77063558947656, 60.664169403814505, 57.70374090440812, 47.386801242828376, 46.7601869183202, 45.92870719971196, 48.08439870034495, 47.77229178336359, 58.26545961441533, 60.12734205492082, 63.017289484700854, 62.60655456973661, 64.03468170473653, 56.99266226060929, 58.4686383893413, 57.24091299118535, 52.8812103117666, 49.16702385871641, 47.99454112206736, 49.24785214085733, 54.21103500550794, 58.14093612855481, 55.62805791055003, 56.32960127245996, 54.91581432281002, 55.42238843056464, 59.14910685631537, 59.40150353216357, 57.31245702312839, 53.25034849105343, 54.30546214503627, 52.743539041088475, 55.054615236097774, 56.57330989837647, 62.80927834972259, 63.280017683582926, 69.50429747181555, 66.7877031141712, 76.34990815193423, 25.45952231653275, 1.6504453603298435, 8.406240382502157, 3.137698058159121, 0.3059332901912351, 0.24526752291187165, 17.155058614669308, 62.59327734670332, 45.73409488124233, 62.350106085500414, 25.34932136535645, 45.994179402628255, 51.013585521328835, 63.23371410369874, 62.68533929701775, 66.10374373774376, 19.9829266917321, 0.35522154862842253, 0.19118470320057487, 0.11709650092187429, 0.0841536476547199, 0.20421294765847348, 0.24372134297605486, 0.0759578628405448, 0.2666373923420906, 0.19798258439667765, 0.14700641975768153, 0.15162421390414238, 0.2728978935028276, 0.13335091782914055, 0.16795149343388696, 0.10608931898229546, 0.2571774015743887, 0.14534161876766913], [0.060493232787496624, 0.07785680328285502, 0.01594331147404568, 0.016955488864632867, 0.08630146708099112, 0.06869885034017986, 0.07041460383803615, 0.018688877706506082, 0.10001035001609596, 0.03426791341494649, 0.0776517138846459, 0.04476747017413859, 0.021513087652443398, 0.021592077063096148, 0.056847979600030574, 3.219947954339366, 61.77248216444447, 58.14718446423931, 61.64666821879726, 40.112730456936745, 33.779816704411665, 19.345321886001095, 45.765446386029645, 37.45330072218372, 48.9258098602295, 30.293941613166567, 0.3831225014742344, 0.07650912438909854, 0.14127310966291737, 1.1485153388592506, 1.9169356025034383, 3.409819353011347, 9.097924866983968, 68.85836155183854, 62.69712601938556, 76.71740285811886, 62.96707922412504, 75.95665916319817, 66.82914687741187, 54.882148619621034, 61.73349772730182, 66.2794110082811, 60.25190476448306, 63.36709430140834, 59.592291539715184, 58.7630711063262, 49.715053496822236, 46.83550034799884, 44.78064906212592, 48.19016933441163, 53.36490523430609, 60.73199110646402, 56.32232527579031, 64.01855291858797, 65.5337449043028, 62.01121330261231, 59.360495152012, 57.78039186231552, 60.438731178160644, 59.69572051878899, 58.35190080827283, 59.57235020975913, 59.02408915181314, 47.97020673751832, 44.65969493312221, 52.99554740228961, 56.914658084992446, 58.463908010913485, 58.99047836180657, 52.61270838399088, 44.588197969621234, 44.319315571938795, 41.87496900558472, 41.66116845223212, 41.71646602692143, 41.5327343633098, 40.09455027118806, 39.87773341517295, 40.877090577156316, 42.321848561686856, 46.981377217077444, 47.52384493427892, 52.989048034914084, 53.75183528469455, 57.301764642038655, 53.13674096138247, 61.11016642662787, 36.95827799458658, 33.038794686717374, 61.19901987814135, 51.44325371711485, 56.047104327909416, 51.44250454441194, 56.12420243601645, 52.949824333190925, 53.96283526574412, 51.06857715114471, 48.22333689658873, 40.72045856906522, 44.50316098428542, 41.547109849991344, 41.21215904912641, 47.49163050805369, 52.034617700884425, 50.524666001719815, 48.977738118940785, 41.65913274211269, 42.99092646568052, 40.49783660519508, 43.549887749456595, 42.82653600938859, 51.09593960546678, 56.597644282925515, 57.24598853818832, 55.04548003596645, 55.610819093642704, 48.653534612348004, 47.87692885245047, 46.091873876510135, 44.2025819132405, 43.85901366510699, 42.041238277189194, 44.495547663780954, 44.00143492606379, 47.80432970293107, 49.457989200468994, 47.45456803229548, 48.39979256353071, 49.256853980402795, 49.80649963501961, 50.08935351525584, 46.947303587390536, 43.130068625173266, 44.64010269411149, 46.725007180244695, 49.54491284585769, 54.20024064279372, 56.10910523322321, 59.53397766236336, 58.97631468311433, 63.38438018675774, 68.27852541400541, 47.09280783130277, 0.8421505879490607, 2.4083227832471175, 2.6362784351072004, 0.019558180656824863, 0.14401788012154643, 1.2739461179702514, 43.14845277417091, 44.69674956414008, 47.184791334213756, 23.450380371462916, 32.063730724396244, 28.364421821409657, 42.73439953404088, 51.72655474755072, 58.163505446526315, 25.135287430978593, 0.7766994064854038, 0.04925649260140715, 0.06811177418116601, 0.04634335133877974, 0.07016853639675726, 0.049763623655082724, 0.07171837823285211, 0.057435346872455655, 0.04038942324358129, 0.029652762271824385, 0.02732777926740387, 0.1403135385724806, 0.05714680368621504, 0.034697075870128415, 0.03379687276338378, 0.03992084556469514, 0.06555591334378527, 0.02620085435468824, 0.03684292645043424, 0.03184822087566699, 0.02169011716520594, 0.0856760252387293, 0.032898918124696905, 0.02120422015357162, 0.023301707603217616, 0.009812215970258319, 0.015421076996942923, 0.03224786979356601, 0.03134896329063321, 0.04505116785425813, 0.07200864128648274, 0.1407973537401807, 5.445477991334854, 73.68245324780865, 68.19445333173199, 70.1311549832744, 46.11224666718514, 41.10854179628434, 25.239520495937718, 38.422659597089215, 34.56412207695746, 57.0684620641893, 33.82155072304511, 0.36730263262025775, 0.03968070764395018, 0.811984864694457, 4.070978727071516, 5.167284867455883, 3.1570206342204927, 10.732505956003743, 71.40104586078276, 64.81971271576421, 75.65820601678665, 63.954531992635424, 71.75188618321573, 69.27550561966436, 57.686086316262525, 63.16241718107655, 68.40562589706914, 60.82076611057405, 67.38547232843214, 61.91775891088671, 61.205076017687404, 50.43986435859434, 49.15626087496358, 46.07068915520945, 50.572001164959325, 55.58066783412811, 63.55639965303483, 60.6555127328442, 65.04471163595876, 66.22801226954307, 61.77003460545694, 61.08091338988274, 62.161302797255985, 63.06591118535688, 59.828135813436205, 60.36310003649805, 61.42871779780234, 60.56997760649651, 51.180345089204856, 46.47037083102811, 55.942898719541496, 60.157885551452644, 60.510847876148844, 60.06079120020713, 55.314138858549065, 45.35218154230426, 45.16653576204854, 42.90421070591096, 44.04179611513692, 43.015025508019235, 44.12630750286964, 42.20179657782278, 42.90574435264834, 43.984702094908684, 45.014218361146995, 48.475321723568825, 48.763921876107496, 55.276699835254306, 56.53667496096704, 59.893098108230106, 56.27401344237789, 62.04596157996886, 36.2887490180231, 36.419862085773104, 64.71527176518595, 52.342637508146225, 57.91898096761396, 52.91200091761928, 59.70899774182228, 54.926769502701305, 57.3082051738616, 53.23909521102906, 50.522826410109, 42.69120247133317, 46.466605355662686, 44.24543772974322, 44.64744929344424, 48.97759691361458, 54.92578498778805, 53.75756978988648, 52.59316321342222, 42.9970649750002, 45.15175627123925, 42.51477426098239, 45.97901944191226, 45.285901331132465, 54.07745868928971, 58.88307994411838, 60.07850462390531, 57.02550426606209, 57.31768946493826, 50.856604422292406, 49.145462589879195, 47.48740611537811, 47.453818859592566, 45.15630622063914, 45.819210313981586, 46.10193083363195, 43.94202670743389, 49.48634009207449, 51.5018186261577, 51.940006209957986, 50.35026565674813, 50.81001843175581, 52.70960661672777, 51.25090068386447, 49.510890206983014, 45.61657282613939, 46.42640498376662, 49.294681318344615, 53.309223267339895, 56.389676294019154, 59.11027539160944, 61.32786973830193, 62.77696978661322, 65.77712012875465, 72.29808407445108, 51.28504099384431, 1.8923778880027033, 2.652235862708861, 5.73810592774422, 0.11608849009198528, 0.14945286025683727, 1.0937252208109827, 46.32880072439871, 51.34093084642964, 40.77177101565946, 26.199236223774573, 40.8559254677065, 32.71932351973749, 48.34174932972078, 56.807298891005985, 66.62954530408307, 33.22603294926305, 1.0201046002968666, 0.11387955217111496, 0.07135794918623663, 0.06059370521876601, 0.08081466875850193, 0.057035713276315125, 0.043961997669670856, 0.034398221140426975, 0.024502491052713127, 0.03060073862152715, 0.024426207847652898, 0.07053473408544256, 0.04649032913749257, 0.02973802211213737, 0.03994191298261285, 0.023489318705434283, 0.04035457773434539, 0.2026857054161449, 0.14456319682780774, 0.12948464061464035, 0.15325251846544205, 0.16666146265643259, 0.1695705742965783, 0.14001749155502166, 0.0910315314127553, 0.1333385072047672, 0.16202060926345088, 0.14744367210134385, 0.15269442341260372, 0.11152748604335132, 0.16553479246795177, 0.24990457650874895, 6.871171295642854, 83.81390402393957, 72.34984367124497, 82.1507720024355, 52.22378184718471, 47.438917775307935, 28.320099038462487, 58.49797379586005, 51.55280159365747, 65.77063645085981, 37.24233996483588, 1.032727339094685, 0.15673245753972762, 0.9241446720496301, 2.110395234438681, 5.649054886833315, 7.131423988649923, 9.149522666008242, 75.49113658166702, 65.51039503466698, 82.5265899781258, 67.03234918655889, 72.3596574414161, 65.05552561052384, 59.560496807098396, 63.86549811209402, 69.488647214828, 62.148876728550086, 71.2945770448254, 66.13445589619299, 65.04033034847629, 52.95591185169836, 52.091135132697325, 48.87761569792225, 53.54474590670679, 57.271279981059415, 65.69076522704094, 62.47815185977567, 68.29656831679806, 67.66579627990723, 65.35821883909165, 64.68648549049132, 63.91369619677144, 67.03336900280368, 62.65716883444018, 64.38305485633113, 65.2868866151379, 64.3747551210465, 52.704531069724794, 49.58346189991121, 57.644826904419936, 61.5885151586225, 61.035100106270086, 61.856871958701845, 57.268208765214496, 47.983299609153505, 49.25809344937725, 44.90424294625559, 47.36123523404522, 46.85880707156274, 46.87764621550038, 42.849226920835434, 44.837974502194314, 47.05020696886125, 47.123982829432336, 50.83909496184319, 53.246810513158, 57.47399591630506, 58.80879025305472, 61.38608163402927, 58.86360929858301, 63.50965284532117, 38.6923147016956, 39.330088169344016, 63.898120464817175, 54.92909939058366, 60.344064774051795, 56.21908064811461, 60.571907412621286, 57.21865746282763, 59.105439109186975, 55.23668381475634, 52.78888556265062, 44.520203682684134, 48.2723351447813, 47.395253950549716, 45.51958830125871, 52.08739711392311, 57.394595376906864, 57.969928633782175, 56.04618649328909, 45.327176432455744, 47.6510238647461, 44.80202597956504, 48.283047137721894, 48.397058671520604, 56.24785123332855, 60.585063042179236, 61.62826838031892, 57.16026906044253, 61.014099736367505, 55.27851589264409, 51.70732728896603, 50.50959233314761, 49.20623579332906, 47.56830107781195, 46.83543366770591, 50.7775451290992, 46.7380843623992, 52.35600102332331, 54.3884987215842, 53.893503450578265, 52.22168337914252, 54.787089978494954, 54.67027395002304, 55.553093571816724, 50.687577724456794, 48.35498340668217, 48.77159403216455, 53.009369834776855, 56.79802248554846, 59.82779064486104, 61.440029913379306, 65.63195320867723, 64.07922021804318, 70.32640272571196, 73.95803897611557, 57.70864778949369, 1.7452636337088, 9.69174131270378, 9.943490797473538, 0.1440505767541547, 0.2671071881007764, 1.4146116279786634, 55.48096902908818, 61.945105675728094, 63.16728092009022, 31.533524336353427, 43.399362871723795, 38.66913349397721, 59.509635433073974, 66.97348225501277, 75.97588662178286, 41.58871835277927, 1.2132058869446478, 0.22651068746082245, 0.1929121395392764, 0.07881641267768799, 0.15914882142697612, 0.08801346674801842, 0.10641355037448869, 0.21722344952004574, 0.1449305819527757, 0.1002767034656098, 0.11204234309374325, 0.18347088728220234, 0.11277836206699572, 0.13632540741274435, 0.07928499801745338, 0.08958871972056166, 0.15844159969879737], [0.048262945511528564, 0.02517090468186765, 0.039458201236782536, 0.015315638400704391, 0.045071388745019515, 0.023488353434649688, 0.021928991040875836, 0.029063970075860143, 0.027165514184162024, 0.12084319947227357, 0.082641918692858, 0.034106904715900464, 0.03305697738523445, 0.04327750577020549, 0.168102121641559, 16.848054701282134, 75.50201723652502, 60.3289754159989, 59.226934525274466, 43.17588975352626, 25.682791471481327, 37.06509197911909, 57.57795833772229, 42.733842557476414, 61.060077759527395, 14.996077226054284, 0.22925913514148807, 0.03472909451492372, 0.6540307727071547, 2.5896644976831253, 1.7846461914239393, 0.16082286143735533, 45.596396153973, 65.29804575827815, 67.88148741568288, 65.5753416399802, 67.51789154544954, 64.02243214268839, 67.8129243850708, 69.26284420874812, 53.45157392563359, 62.80057461031022, 63.50712291656002, 60.50128513766874, 62.14221262162732, 60.6520139786505, 56.082017344813195, 44.86060657808858, 44.86522713015157, 46.29104006674982, 53.11465409494216, 56.25554692360663, 58.71994464628158, 56.71558210926672, 57.61622890349358, 59.45840143388318, 60.40173538269536, 59.50616413547147, 57.105422558323035, 54.54427173060756, 58.37308552957351, 58.24455730376705, 52.791925399534165, 41.76936703343546, 45.794609208260816, 55.02433061599732, 57.16317161437004, 60.77490575851933, 58.76455376225134, 48.87694105025261, 43.031303344234345, 40.35430531347952, 41.00442640243038, 41.147761575637325, 39.921628659771336, 39.834501051133685, 42.39700901892878, 39.73425311426963, 42.45291063862462, 43.964160642316266, 50.946924840250325, 47.69326779150194, 55.60201337260585, 52.221475493523386, 60.12412571137952, 53.82226536350866, 55.313464210879424, 35.77987247897733, 33.24542906976516, 62.11342242456252, 52.25745147274387, 55.791044158320275, 53.983804256685325, 57.204991925147276, 53.642252106820386, 56.75812805852583, 53.09122970027309, 52.485686348330596, 44.63714130463139, 41.95156897267988, 43.73192102678361, 42.577559640330655, 42.21405790698144, 47.032238591101866, 46.57802028040732, 45.68463771573959, 41.02272033691406, 42.071617034173784, 39.98769314058366, 42.67689366494456, 42.7560470950219, 49.17239750585249, 56.5752750058328, 57.622598832653416, 55.40928379181893, 54.674215932046216, 48.014039224193944, 42.665824736318285, 43.20806495604977, 43.3719180476281, 42.83178414067915, 44.0587446766515, 43.07918371692781, 41.90605378920033, 44.24918359325778, 48.18365819992558, 44.55841541290284, 45.10780219108828, 46.08283281326295, 46.37018172971664, 46.52110276683685, 43.90547413979807, 44.787160196611964, 47.176056215840006, 53.199847975084865, 56.27043231841057, 55.989610225923606, 56.97537245288972, 56.42541300865912, 60.36000920880226, 63.05370476938064, 64.13003844599571, 60.977762899091175, 8.313939167607217, 1.3982552217860378, 3.4078579227770533, 0.8060846393627505, 0.16182419964142386, 0.21426576790550064, 20.57323555792532, 47.22814136935819, 29.376836553696666, 30.649339729739776, 29.152069053342267, 27.113201425921535, 33.49403673602689, 47.21984163407357, 54.674717995428274, 36.52202021691107, 3.9008951956225983, 0.21109943458389854, 0.03637052599280592, 0.03380832960829139, 0.02108336212263713, 0.03766357898712158, 0.04224563896235439, 0.041845733405000744, 0.023143186774705688, 0.07152261978556072, 0.04515738211452, 0.03084598634872706, 0.04162046525086607, 0.017948848262970007, 0.0429766898554179, 0.09141105137044385, 0.07799079972169093, 0.07562956352147364, 0.044730104235631805, 0.027170660379793377, 0.02966886352477295, 0.031374989212640834, 0.02772287187737323, 0.07419504090062073, 0.03836412042860062, 0.039946566966752854, 0.05946662134280609, 0.02672919838298713, 0.05033465793296214, 0.09574431280094771, 0.09668571994669976, 0.13059448751230396, 21.314298760506418, 85.27726188782724, 65.55876962600216, 67.38235012177499, 48.92443310829901, 31.34875716701631, 33.92329308294481, 52.19782360138432, 41.99140848652009, 68.07158900845435, 15.943118795271843, 0.38802010157415945, 0.08800625786065094, 2.1823062531409727, 6.828485121650081, 4.45015989003643, 0.07949225544448822, 50.08798853043587, 69.18873494671237, 71.528044362222, 68.55266771008893, 71.19981258146225, 67.5362168588946, 67.92591218025454, 71.69870668841948, 55.89082141076365, 63.67801666259766, 65.9111867412444, 62.20306035011046, 64.96141618297946, 62.403234589484434, 58.42349583102811, 47.862070914237734, 47.525096170363895, 47.71724131799514, 55.91713266987955, 58.32384409443025, 61.529208921617084, 60.43642482449932, 59.413254953199825, 60.42463417976134, 62.84288129498882, 61.68337375886979, 58.51911144871866, 56.90444031069356, 59.71005285939863, 59.924261339249156, 55.782556149267386, 44.96079567940005, 48.21985383187571, 57.032631212665194, 59.669087625318966, 61.69624697777533, 60.43875863475185, 51.56614157461351, 46.76058700007778, 42.12999366944836, 43.154834470441266, 42.35711851427632, 41.40831285907377, 42.60109778373472, 44.04112931220762, 42.24769615357922, 46.90064307182066, 47.651086622668856, 53.469624673166585, 50.513804958712676, 59.086113591347974, 55.13228993262015, 61.696988305737904, 54.55385408093853, 56.14862703507947, 36.77723707691316, 36.87778311391031, 62.97380608897056, 55.46095709646902, 58.13258540245795, 54.94936235489384, 58.4578557937376, 54.65771452073128, 59.43556931711013, 56.010206591698434, 54.025487284506525, 46.796323714717744, 42.76963026292863, 47.6278583465084, 44.94423151016236, 44.94203106049569, 48.98881881467758, 47.33984262712541, 46.1489482848875, 44.44622778123425, 44.86347775305472, 42.05752395814465, 43.94689044644756, 43.686252870867335, 51.18565597841817, 58.508230793860655, 60.5465296776064, 56.958592553292554, 57.89081442740656, 48.85795285624843, 44.88958112655148, 44.15533696451495, 43.99497086001981, 45.17796554873067, 46.19350248767484, 44.535175369631865, 44.03070365228961, 46.52077328774237, 49.78696623156148, 46.68504607292914, 47.97947922060567, 49.203278326219134, 47.65361655143, 48.943397768082164, 46.151156579294515, 46.96564851268646, 49.206078898522165, 54.82106554892756, 59.11542546364569, 58.89820068113266, 60.497637333408484, 58.589188514217255, 63.17043842807893, 64.59072082273423, 66.71436263668922, 64.40536529787126, 11.360638237768605, 1.5339277997132272, 2.7659708694104226, 2.2029629253572036, 0.28561578042084174, 0.09256752237917916, 20.942091326559744, 54.92848750083677, 30.44597660341571, 31.420097235710394, 33.1561480799029, 35.68588072253812, 40.87767501031199, 53.50196069286716, 59.15335478321199, 50.566878549514286, 6.56023814793556, 0.3346821491516406, 0.11362383968286938, 0.01875934438900121, 0.09736923125362205, 0.08380591268500975, 0.01873197972834591, 0.04785641712406951, 0.025670397838938142, 0.04610517843356056, 0.05456689534889114, 0.045245478395372636, 0.03784791889390157, 0.07798463271390046, 0.02882824482155904, 0.05054387271464352, 0.07535005634229991, 0.24804293688747192, 0.1052017984611373, 0.15175630278404684, 0.17080290333157586, 0.11471032855972169, 0.0753240859616668, 0.07940559557849362, 0.1968106077683549, 0.17847479891873178, 0.34880642028104875, 0.14769686416031855, 0.1400193761313154, 0.2270672809813292, 0.23598100509374376, 0.40990870445966726, 26.91903625765155, 95.40985799604847, 75.80032133287, 75.41450131324031, 57.39766659275178, 36.62400184139129, 48.19988112295828, 74.92626820841144, 60.373800262328125, 76.66321923655849, 18.969974594731486, 0.5577117637280495, 0.2815601109497009, 2.5864510959194553, 5.936608256832247, 6.526698941184629, 1.023782619064854, 49.628020025068714, 70.49282104738298, 73.78983205364597, 71.88967120262885, 72.49767780303955, 69.30507244602327, 68.92251583837694, 68.39132493542087, 60.54230136256064, 66.73777918661794, 67.54217101681617, 63.56605652839907, 68.16830681216332, 65.07854600106516, 61.84356727907735, 48.642422537649836, 48.686066750557195, 50.1204304541311, 57.51914631935858, 60.09522176557972, 65.97081461260396, 62.588931360552394, 63.04177684168663, 62.33750351013676, 64.26847457885742, 65.36451816558838, 60.57158185589699, 59.49210243840372, 63.451444871964, 63.62192284676337, 59.0095018571423, 47.00929664796399, 52.731677793687396, 59.878801068952015, 62.83307536955803, 64.12381756690242, 62.91622569484096, 54.203182420422955, 48.41526239149032, 44.562345627815496, 46.50019261144823, 46.367640033844985, 43.00613741720877, 43.93424080264184, 46.48053369214458, 44.30686204664169, 49.20423538454118, 48.856897738672075, 55.611356458356305, 52.27986781827865, 61.24932035323113, 57.53719314452141, 64.45496759107037, 57.296222332985174, 58.01210588024509, 37.6572286698126, 40.197214388078265, 63.199954263625614, 57.70215626685851, 59.25847038145989, 56.55182707694269, 60.02952990993377, 58.12230879260648, 60.72648409874209, 56.55922074471751, 57.11894689067718, 49.66479224543418, 46.34414111414264, 51.29453312966132, 46.81893225639097, 47.68952192798738, 51.427591693016794, 50.65162527945734, 49.859373184942434, 47.96329159890452, 47.978557463615175, 44.719679740167436, 47.13585192157377, 47.218009887203095, 53.44432930792532, 61.601321697235115, 62.67117561832551, 59.55158125969672, 61.835836287467714, 52.2903170124177, 47.674177615873276, 46.67342801247874, 47.55187026916012, 46.89586562495078, 48.383134257408884, 48.2888836245383, 45.46233738622358, 48.43086950240597, 52.249732248244754, 49.38057338037799, 49.764400835960146, 51.92673290929487, 49.57675464691655, 52.769865989685066, 49.24743636961907, 50.26868427953413, 51.60209794198313, 58.510992142461966, 60.65904286599929, 62.07214340086907, 64.38178400839529, 61.7182828534034, 65.4204668537263, 68.01640910487022, 70.11537136570101, 66.75259790112896, 14.228153632533166, 6.069994828393383, 11.789200325166027, 2.2693286932283834, 0.5302301674119888, 0.2722550538038054, 25.90073404773589, 63.23280803618893, 43.43199306918729, 43.42074371153309, 35.7224529020248, 38.10132726546257, 47.63881744876985, 62.34025701399773, 68.36291128589262, 59.76808824846822, 9.00939501100971, 0.31319013466277434, 0.2405561128210637, 0.21788096746369717, 0.10273832016654554, 0.17806647405509027, 0.12115659838121746, 0.20221063897254007, 0.18189299130632033, 0.10232810306573108, 0.18064984510983192, 0.13384173504046856, 0.13252990140068915, 0.07717274039262727, 0.21367007325733864, 0.13680739929118466, 0.19326087808416736], [0.08257843298657287, 0.04019360733969558, 0.08973724118644193, 0.00182376507220925, 0.03584374095343294, 0.05354969529435039, 0.055332362741952947, 0.038019729432679956, 0.04290401109404141, 0.01757050616546504, 0.05857376118881568, 0.03493858508825783, 0.05225119924533272, 0.027383194237406698, 0.17438287816701398, 39.80933120173793, 65.83285700890326, 62.33983339801912, 58.87508223133703, 42.787343686626805, 25.670030040125695, 42.95965340829665, 40.3728542020244, 41.0595670823128, 55.47386953907629, 4.089653376610049, 0.12499611614452255, 0.9461476365404745, 1.9898279491932163, 16.843312555743804, 6.336598819301975, 4.695901284294744, 71.73338828548309, 58.85966731655983, 73.52540154610911, 57.43644706664547, 66.08685401178175, 65.51099123493319, 66.57443600316202, 61.60975871547576, 72.59267760861304, 56.172565260241115, 69.37567510912496, 59.02535999974897, 63.63232889483052, 59.603501673667665, 60.890603911492136, 49.79040222783243, 43.9055839661629, 42.09467272604666, 48.46664544074766, 52.45011045086769, 51.77524312849968, 45.56420918433897, 49.734857543822265, 50.39063861293178, 56.839089701252604, 53.74317469135408, 58.148580828020656, 56.07742817171159, 57.82121981343916, 50.74806459488408, 44.16964184853339, 42.11789707983694, 46.11978154028616, 53.04708734635384, 55.825847348859234, 55.2063403591033, 57.950885526595584, 43.715152894296956, 44.74580272551506, 42.08756146892425, 42.76612758636475, 40.42631610747307, 42.66429108958091, 39.82061978309385, 40.1356331763729, 43.15799197842998, 46.11170538010136, 48.31794446514499, 51.411506052940126, 50.86517087874874, 55.33308390648135, 56.09491802030995, 59.63046796860234, 50.4667482837554, 55.30734531341061, 38.24098325544788, 34.65688613153274, 59.99032582006147, 54.12862993055775, 55.71154163729761, 53.29553027306834, 53.35064349635955, 51.82972877256332, 54.77507575865715, 57.32328668717415, 57.753511859524636, 49.85512525804582, 43.83035290625788, 42.47758234700849, 43.762166423182336, 39.98905420303345, 42.36999173318186, 44.254670989128854, 42.21378726343955, 42.04201490648332, 42.198548855320105, 40.65080511954523, 41.734728582443736, 41.26261641902309, 45.67613401720601, 53.241566304237615, 55.08696302290886, 55.27198906867735, 53.297381631789676, 44.83100837276828, 42.188385994203635, 42.64322796175557, 42.66430285669143, 42.78743782351094, 44.406047021189046, 42.940880944651944, 41.754003109470496, 43.72209941187213, 43.76427273596487, 42.48086144847255, 43.78982305526734, 44.094697121650945, 44.84086921138149, 42.55312327415713, 43.70730423158215, 45.069378652880275, 50.82423702363045, 51.26468781502017, 56.33438264170001, 56.19156129898564, 58.49285510278518, 58.67609254775509, 62.08684836664508, 61.2053309717486, 63.696698911728404, 63.96908790834489, 24.62669526377032, 2.010550933980173, 3.4257343699855194, 2.449136760927016, 0.02377017994501418, 0.07393875384643193, 3.317069762176083, 54.33579775594897, 45.17378430212698, 39.61032975104548, 29.28554338793601, 17.675929761702015, 29.614600827617032, 50.2208274410617, 50.26568366635231, 51.989941904621745, 15.878600708899961, 0.9368677377220124, 0.061149942508387956, 0.12074673368084816, 0.09503587299296934, 0.009079078445211053, 0.01133057733832468, 0.07128907788184381, 0.0616253919959549, 0.04045906063589839, 0.0637839251618472, 0.09921775544963538, 0.07211296714001125, 0.03854899276648799, 0.0738538406609047, 0.07808518941484152, 0.04864836434623407, 0.03443868207414785, 0.040957465948116396, 0.05363335209568182, 0.023505303129974394, 0.038169514943635276, 0.056175239489323674, 0.0492605643587247, 0.021371650584642927, 0.054084125891207695, 0.03113980979598578, 0.04923623723668918, 0.08104267184652629, 0.052800288934621124, 0.011568216854826579, 0.1854132725706985, 48.31846221800774, 72.22434351521154, 69.1052512199648, 65.5186398567692, 48.20352500484836, 33.24737064300045, 39.27469253540039, 36.52398140199723, 43.49078155332997, 63.694843630636896, 3.6244114896943493, 0.02724774989239391, 0.47284049853201837, 2.546038180589676, 14.599130422838273, 6.276842000023012, 6.704458305912634, 73.78379160358061, 64.25593476141653, 72.3620657767019, 60.65324952525478, 67.36267551299065, 68.11333871656849, 68.44672449173467, 61.664879783507324, 74.78745552801317, 57.97403143298242, 69.0868474591163, 61.731320811856186, 63.45051919260333, 62.27252552586218, 62.052374655200595, 52.150770848797215, 46.346890695633434, 44.67570212579543, 51.14289429879958, 54.384082132770175, 52.85589533467447, 48.979303144639545, 52.65782740808303, 52.90906306236021, 57.84933928520449, 56.635122529922, 59.52262632308468, 58.52873694512152, 58.853399369024466, 52.59819169198313, 46.92549520923246, 44.073269213399584, 49.11750001292075, 57.13363224460233, 57.84303211396741, 57.80023513301727, 58.84772369938513, 47.600868517352694, 45.56827275983749, 43.40431290288126, 45.59651382507817, 44.18866142149895, 44.88376425158593, 41.99167913006198, 41.50102200046663, 44.71339610315139, 48.34167088231733, 53.97033875988376, 52.464062321570616, 52.92614106209048, 59.34269543617003, 58.205345369154415, 61.229928155099195, 51.98237957492952, 57.192746285469305, 37.84773034434165, 36.27860576875749, 59.58836916954287, 55.099753872040786, 58.76708761338265, 52.99277036420761, 53.73409048203499, 52.05814799954815, 56.40325161718554, 57.522621539331254, 60.17480665637601, 51.22442860757151, 45.324234654826505, 44.99380242440009, 45.87854792994838, 42.09866962125225, 44.56160429985293, 46.3806583804469, 44.23767535917221, 43.31451416015626, 44.00804019743397, 42.38448489096857, 44.09065708037346, 44.27059581202846, 47.128564157793605, 55.6660617551496, 57.88753140357233, 57.56133141056184, 56.578691390252885, 47.204760120761016, 44.155293818443056, 44.249622898717085, 44.824740425232925, 44.58202808134018, 45.68237843052034, 45.4235412228492, 43.79209802996728, 45.85282110398816, 46.80569425705941, 45.10696672624157, 47.395559895423155, 46.88748744226272, 47.31863437160369, 45.09383070853449, 47.70820025474795, 46.126908486889256, 53.408957373711374, 54.73051371112947, 57.20296798213836, 58.749550696342226, 61.41678594773816, 61.44297953574889, 63.099784774165, 64.11558451191073, 65.37397107770367, 67.85771785243865, 28.76445454935874, 1.0335887896437799, 4.776051486692121, 4.852503874609548, 0.5018119519997029, 0.18079639772974676, 3.078499686333441, 59.703894738228094, 45.44902486185874, 29.640786570887414, 31.125205601415328, 22.032682818751184, 35.303339804372484, 58.35643114582185, 55.319488971464104, 61.80575170824605, 27.40684770768689, 0.9585769534591706, 0.06819114855100071, 0.020568773203018694, 0.03246397553612629, 0.010394370971968579, 0.021935874340875496, 0.049174004084160255, 0.039899582794356736, 0.03526700315095725, 0.07289515823246011, 0.06531966714969566, 0.026025176987112052, 0.09828600867260849, 0.07508891229067119, 0.06395328038882825, 0.007591155186791214, 0.13929769066312622, 0.1527597247472694, 0.11782877372517703, 0.11697161326845808, 0.10779465368438153, 0.2837102746050204, 0.17032357743911206, 0.12809412974503734, 0.20487118572477372, 0.21759756089698887, 0.1381327926872238, 0.18821079584379352, 0.16750774466462676, 0.19913042925538557, 0.5800536455165956, 57.85410104259368, 80.64867681072604, 78.67770148861793, 74.05893802642822, 55.13898541850429, 36.561047800125614, 59.75723112783125, 53.64569202546151, 54.8007986622472, 66.77730883321455, 5.646421995855147, 0.19760877945490424, 1.644462274928247, 2.6591169257317824, 32.60935202721627, 15.39717781928278, 4.699219609460523, 78.77285818899833, 64.33699838576779, 79.51468821494811, 62.40606261837868, 72.01391620020713, 69.86034670183736, 71.7713725182318, 60.688237067191835, 71.3352834024737, 60.18409875131423, 70.86155522254207, 63.83642158200664, 67.34330684907975, 64.95572090148926, 65.2944097211284, 54.82554097329417, 48.597958549376465, 45.118514184028875, 54.276597422938195, 56.69367567185433, 56.52209551103654, 50.485709021168375, 55.17849153087985, 54.47622253048805, 62.73067405146938, 60.90147279923963, 61.96882032578992, 59.25219066681401, 62.08822119620539, 54.70663432152041, 47.43277534361809, 47.795535749004735, 51.14653425831949, 58.82437382974933, 60.10918932576334, 58.94939545662173, 62.27107817126859, 48.99209399377146, 48.59356157241329, 45.87277420105473, 48.77005254068683, 45.743335985368304, 47.36998211952948, 44.874946763438565, 44.7733691430861, 48.9342821798017, 50.60252897201046, 55.439133028830256, 55.362937065862845, 54.82711776610344, 62.076387405395515, 60.74665292616814, 63.51657190630513, 53.10337335832658, 57.51835400058378, 41.43130971539406, 39.188945601063395, 62.574771604230335, 58.062704455467966, 60.207083840524, 56.179747120026626, 55.91806619398056, 53.46243104627056, 57.87706259758242, 61.76027967083839, 63.095819257920795, 55.921349217814786, 48.852453693266845, 45.96528722393898, 49.314952127395145, 44.19039510911511, 48.957718341581284, 49.22876588759884, 46.62020537161058, 45.73145512611636, 46.515972306651456, 45.83610788468392, 46.416046004141535, 46.8350100517273, 51.103847103734175, 58.34309900960615, 61.87871563819147, 59.37109731858777, 59.50714472801455, 50.197104946259536, 46.361493679784964, 46.74598401592624, 47.138923137418686, 49.01003099256947, 49.60773744890767, 48.502256639542125, 46.677707318336736, 48.27614376621862, 49.87640411623063, 47.66769786034861, 50.98436778591525, 49.59615076741865, 49.71972896206764, 48.35641507179507, 49.17280543235041, 49.587262676608184, 56.44964541158369, 55.84802442981351, 61.320350554681596, 62.0988037509303, 64.83458634345763, 63.537509518284956, 66.6418223227224, 66.50273507641208, 70.85026664118614, 67.35014746266027, 33.37206671314855, 3.109654582315876, 12.558534991356636, 10.519635984974524, 0.3244225158085746, 0.30634008287902803, 4.123688272891506, 69.73856495272729, 61.85183171303042, 56.01481537665091, 33.34844227760069, 25.411028092907323, 40.039939111278905, 68.8768437600905, 62.23779686035649, 70.81441617781117, 31.689975915416596, 1.4136414542313547, 0.16850624834337544, 0.16669685591853436, 0.18561403357213546, 0.12312221911645706, 0.07122517848807959, 0.15506163509863038, 0.2355913727754547, 0.21258702411526637, 0.1356863215445511, 0.11723834976193406, 0.21869197878385746, 0.1466427118547501, 0.18364368607440304, 0.19575170571765593, 0.075431146749085], [0.0541499711482996, 0.027732227726148504, 0.015417010985284805, 0.010378406657236479, 0.05220704576781681, 0.03638894657694525, 0.06821672056591319, 0.07176292624564902, 0.02528452892757712, 0.03452890041855074, 0.054588039375601284, 0.05469314280837294, 0.03971030545090476, 0.03927480361814942, 3.0791027507474347, 58.72180384974326, 62.80927834972259, 62.91947733971381, 47.38497341832807, 29.76172697159552, 13.24865641132478, 31.1832860977419, 43.36202975242369, 54.7800140227041, 41.79467416578724, 0.160829603011089, 0.035177543233599395, 0.11595540529777927, 3.26279862273124, 5.8795725818603275, 0.40645996048565836, 27.690790045645933, 72.37296996578094, 65.6183700407705, 70.03774765999087, 54.17139553254651, 59.21926236921742, 62.62705287625713, 67.23624967759656, 58.352642136235396, 66.4959179970526, 66.16419530683949, 62.93934414463659, 61.06654574794155, 62.138396155449655, 60.071452202335486, 59.81605491330547, 55.46520894573581, 47.495431284750666, 43.73480396886026, 44.45724571904829, 44.039787861608694, 45.72417912944671, 42.353223600695216, 42.875145942934104, 44.07803489315895, 44.21789484639322, 46.390946757408884, 47.72901627325243, 48.777026514853205, 47.91789408653013, 44.902634774484945, 42.82024845000237, 41.370057982783166, 43.20508395471881, 49.018189522527884, 55.03318340547624, 53.17912217109434, 49.53674254878875, 42.27809452241467, 43.3572954516257, 40.3554702574207, 42.37639304130308, 40.245032002848966, 40.88876355078913, 40.408728199620406, 39.96937174950877, 44.12258909594628, 49.05976664635443, 50.40473168896091, 56.541479864428126, 54.14029505945022, 58.10172419394217, 56.39984307750579, 57.49304294586182, 51.619560333990286, 57.94021667972688, 36.9739596305355, 34.41064365448491, 57.92309945629489, 54.06870003669493, 56.1389740820854, 50.67380236041162, 53.24624961422336, 51.79201910572668, 53.2373889800041, 54.36368580787413, 56.94602527926045, 53.55417136223086, 47.755904120783654, 41.70777013224941, 43.58022728273946, 41.93290241302983, 42.129020921645626, 41.24518540597732, 41.97045126268941, 42.47317360293481, 42.25498783972956, 41.69890557565997, 41.61959525077574, 43.303923760691, 44.093928337097175, 47.96624514364427, 52.48762399919572, 51.315306002093905, 47.68743130468553, 43.154030384555945, 43.65684686168548, 43.36594035548549, 44.08048245214647, 41.2648247134301, 43.2861711132911, 41.05684495741322, 44.06121969223023, 44.275012400842485, 43.36432041660432, 42.23509357821557, 42.89025491283786, 43.66304812892791, 45.63700837473716, 43.41923359901675, 44.258075606438425, 49.894294046586566, 52.94456051241968, 57.32327099769347, 59.650142577386674, 59.831434526751124, 59.31692154176774, 60.81858919512842, 57.341219763601984, 61.5926532591543, 61.8264304437945, 64.08374663322203, 45.514959904455374, 2.8847466120796823, 2.9030351533043772, 3.0262186594547766, 0.3291071741090667, 0.045370515435934074, 0.051829820243461486, 27.171858510663434, 47.97671002726401, 42.05379770648095, 20.415648452697262, 15.817620600423506, 23.496766321120724, 33.847532503066525, 50.11504503988451, 48.79387701711347, 48.36467558337797, 5.205211735540821, 0.13899004507449367, 0.02296225978962837, 0.05225175848951744, 0.019751840023203723, 0.010798166340757764, 0.02080062971330218, 0.04048219649121165, 0.019279334228485823, 0.009064957529546754, 0.018223753168938622, 0.05346374789012536, 0.028111586805372953, 0.024293940852306063, 0.03836189494318059, 0.04165889222114798, 0.027856219056693297, 0.018331348302684004, 0.037515436734763846, 0.02710916458689157, 0.03513145538407468, 0.030228519481756998, 0.027152728176705783, 0.027443171260998617, 0.07083277293150464, 0.070980382752755, 0.08045087658589886, 0.03385114626237943, 0.09079822699629492, 0.12315201993671157, 4.7526687672061305, 68.03795860659692, 70.7223738393476, 67.59268329989526, 55.79598634473739, 37.76532919176164, 19.149264174122965, 33.84166071491857, 38.79813240420434, 62.34695642225204, 47.845895059647106, 0.2550908385385429, 0.009686493281004651, 0.36960135604585376, 5.054437297005808, 3.27853296552935, 0.2345644625564737, 30.356215123207342, 76.01957398076212, 67.26132931247835, 72.20468459590789, 55.02388738816785, 62.335609005343535, 64.89586553265973, 69.84120553539645, 61.56567127473893, 64.818069242662, 68.51945307946974, 65.30373711739817, 62.7853322798206, 64.5970005373801, 62.912209187784505, 62.18405646662559, 59.06901205739668, 47.322854841909106, 46.068061167194, 47.8684800670993, 46.56917141329858, 46.915716740392874, 44.17674133854528, 45.16874405645555, 45.79110653169694, 47.14191198349, 48.00149156201271, 51.60977794278053, 51.07833208576326, 51.06438805980068, 47.447366560659106, 43.814812475635165, 44.43555501199538, 44.88952621336907, 52.151606313643924, 58.88749653293241, 54.64901470368909, 51.775756958992254, 43.673807190310576, 45.9663894099574, 42.72109877678656, 45.65230169603902, 41.87459245804818, 43.11457134062245, 43.014884302693034, 42.29035585157333, 45.32422681008616, 52.30274700349378, 54.283763593243016, 57.27073869397564, 55.50134181976319, 60.719988653736735, 58.55016877574306, 57.8517044744184, 51.51196187542331, 57.722921294550744, 37.91445378334292, 36.77048275547643, 58.12576832309846, 55.8151549677695, 57.55283947913878, 52.72018917145268, 55.386628181703635, 51.93507971302156, 56.169945116966005, 55.946970139780355, 58.82500925371724, 57.48160531443935, 51.00068092346192, 43.73661610387987, 45.2695450475139, 44.0088717399105, 44.07208073523737, 44.45320960014097, 43.52301559140606, 42.47596240812733, 45.167488898000414, 43.020497214409616, 44.340633653825336, 44.42574516419442, 46.342219152758204, 49.66939710801648, 54.80747845865066, 52.994468750492224, 48.83741532602618, 46.0106925810537, 45.08882184182444, 44.91300552122055, 44.569696149518414, 43.803582729831824, 45.195992762042636, 43.906305682274606, 46.49850991464431, 47.09941310267295, 43.99522581408101, 45.77254979841171, 45.3782731486905, 44.9989995648784, 46.86011322083012, 45.61086577753867, 45.8990893825408, 52.13259458541871, 54.404192124643636, 58.789433356254335, 62.33906069109517, 62.05093906771753, 62.26694399310697, 61.82393581636491, 61.183930520088445, 62.917202365013864, 65.12318257362612, 64.17576543746456, 48.620747520077614, 4.962211097440412, 1.2529170657357862, 5.3613534473603774, 0.6112055384343671, 0.06906255824311126, 0.032990270279227726, 26.66460191049884, 56.634796973197695, 37.36967971248012, 23.116629815870716, 20.85835264575097, 30.708461615347094, 40.98002925995858, 56.55978164365215, 55.804109573364265, 60.92885094304239, 9.973234130490212, 0.11754895244995434, 0.058885501517403516, 0.01936151631056301, 0.01578071314255677, 0.027121536906868703, 0.023457043421184345, 0.03387809723555561, 0.03381239753516932, 0.027747084086220113, 0.01992652530691797, 0.044979347111356836, 0.04116778772684836, 0.04607843813456355, 0.0393006092898788, 0.07200939205264853, 0.11300791265262712, 0.10663261321643669, 0.09776522976256187, 0.12407082748869736, 0.18861202673325617, 0.1455107556595918, 0.19282760939771132, 0.19072230785123764, 0.23610649029574088, 0.1485951022515374, 0.131549492718712, 0.14195515774190426, 0.19499864128808822, 0.23277610690603334, 6.1263146708088545, 76.22667512586041, 76.93245856992661, 79.09792853939918, 62.995736060603974, 42.99226791627946, 20.058963798707534, 44.28441432214553, 59.53264797887495, 71.24530423072078, 52.48006951424384, 0.677031428823548, 0.05717507616106061, 0.854513592297031, 8.189692699140119, 21.0014917004493, 3.426912797074164, 30.12583471113636, 79.9332364912956, 71.18082830982824, 75.76901297415458, 58.274128052496145, 64.56549213778588, 67.65479010920372, 71.74499850119315, 62.257734267942375, 65.40422039647257, 65.17288292607954, 67.31641507917836, 64.5763139570913, 65.11513387003254, 65.17790748227027, 63.761433709052305, 60.27795714716758, 51.335470907149784, 47.233589541527536, 50.4068301570031, 47.2653175938514, 49.59263240137408, 46.31200905769102, 46.47239477403703, 48.12927453748642, 49.72754232345089, 51.09723006525348, 53.051500012797696, 54.935575223738155, 52.80259816877304, 50.55047127508348, 47.006033235980624, 46.44094128762522, 48.17534669753044, 53.69877346100346, 61.876056271214644, 56.396650268185525, 55.102876078697946, 44.43399783103697, 48.305400725333925, 44.85259709819671, 48.023907907547496, 44.18379768248528, 44.35122013092042, 46.37653204702562, 44.574791308372255, 48.51738522129674, 53.70355090787334, 56.350613409473056, 61.6678294058769, 59.300977107017275, 63.88028544764366, 60.4135456392842, 59.68909955793812, 54.2349418517082, 57.985488676255756, 40.97086268086588, 39.52394347037039, 62.42810633874709, 59.65233910468317, 58.854309358904445, 55.327725948825965, 57.94176993831512, 56.45836876284692, 57.72408231612175, 57.69794756366361, 60.39969967257593, 58.07178474241688, 53.78590106964112, 44.64039294950424, 46.5393300210276, 46.15548295359458, 46.7175821335085, 47.473309116978804, 46.646422493842344, 46.6345416345904, 47.92313437308035, 45.82574498268866, 46.65818568198912, 48.37492081426805, 49.452160558392926, 52.72257789488762, 57.126795553391986, 55.43160600046958, 51.572515426143525, 47.75765349788051, 47.98555889437276, 47.714703544493645, 48.330041054756414, 45.453237487423806, 48.65041632806101, 46.37833633730489, 49.886774862966234, 49.74237280507242, 46.8797956743548, 48.04447681673112, 47.95241094404652, 48.45371730865971, 50.1839610838121, 48.86567992548789, 48.40690382065312, 55.13458451917095, 58.318395922260905, 62.124130495132945, 66.12625814253285, 63.848059254307906, 63.08727241331532, 65.96559786027478, 64.50138099731939, 67.33530521392822, 68.66236071432792, 66.52597904205322, 51.2106022527141, 6.470715442011434, 7.517934835726216, 13.425454305064294, 0.5038145364772889, 0.24486829917277061, 0.11118629346451453, 32.6182303121013, 64.94337328018682, 58.62194814989644, 27.759190297895863, 22.155356907075454, 35.086958331446496, 46.998404225995465, 66.64324222072479, 61.971613053352606, 71.49188010923325, 11.073226563392147, 0.3445186874558849, 0.18964695023192515, 0.1039804015008192, 0.08493665846124773, 0.10045059010266297, 0.09162344158657136, 0.11311239172374049, 0.12527366213861013, 0.11990064319463507, 0.0910485155820366, 0.19384331941123933, 0.131703844113696, 0.18796206241653812, 0.12135486959690049, 0.18682431459667223], [0.01471370683922883, 0.04265168471442115, 0.026884380983369007, 0.06964330651587056, 0.02771718942019488, 0.05253242246145683, 0.06934154448249648, 0.0520641167437838, 0.07316868992582445, 0.06162568693980575, 0.07122374590366118, 0.03624211050449841, 0.0771355927891789, 0.10738164036264343, 13.171259222492097, 64.51634483952677, 63.96491450648155, 65.3617528946169, 46.14082113389046, 30.525528154065533, 28.92918036830041, 36.22577928727673, 36.22883873601114, 61.72272689880864, 21.529797700143632, 0.10741861942674845, 0.7805889268075267, 0.5816270062519658, 4.294929148689393, 4.044255619087528, 0.45518986340011325, 56.448013705592004, 61.65520721866239, 69.96542699875371, 62.12123970831595, 57.36669948024135, 48.8785296101724, 65.1269402042512, 61.896499664552756, 63.95282968398064, 60.29916540268929, 61.13384577535815, 59.0207943608684, 61.812105947925204, 63.38729843016594, 62.22462161894768, 60.148864100056315, 60.98989871240432, 49.10676056338895, 46.109861866120376, 45.043491009742986, 44.245237688864435, 44.10551109621602, 45.35043608757758, 45.77178493622811, 43.69181086940151, 42.13089973695817, 42.964897617217034, 41.862240914375555, 43.34013115975165, 40.89510602335776, 42.93495424332158, 42.444489309864665, 43.98367443392354, 42.65281031208654, 40.17996772643059, 46.804137076101, 41.72091007232666, 44.06808384003178, 41.71438324835993, 40.78282425480504, 43.17077890519173, 42.02745899077385, 41.859616848730276, 43.61301045263968, 40.34006710975401, 41.594088077545166, 45.47035863322597, 53.66755923917217, 52.82141770085981, 55.713440064461004, 56.69114182072302, 55.87896408573274, 53.47934822882376, 57.668063025320734, 52.63447753844723, 56.405738399874785, 36.78242637265113, 30.971213348450203, 54.384490059268096, 47.98469597293485, 56.120813508187574, 51.49713923854213, 55.897818919151064, 53.811745566706506, 54.92676558033113, 50.93071368432815, 52.52180353287728, 54.710337038963075, 55.61134861361597, 44.504722087614, 41.282612662161554, 43.13009608176447, 42.25366992335166, 41.067137256745376, 40.90268404253068, 40.162740676633774, 41.59757898699853, 40.88812420445104, 42.19413618887625, 42.2355721073766, 42.59492789545367, 44.19057946051321, 47.5098067714322, 45.24378292022213, 42.35121926953716, 41.400883889967396, 43.93144023033881, 41.30318157134518, 43.189618049129365, 42.498955342077444, 42.712159695163855, 42.85409850458945, 42.295678507897165, 41.125757078970636, 42.08335276572935, 42.639368349506015, 43.33461630728937, 42.160395960653986, 41.45801321152718, 44.042231498226045, 48.489175535017445, 52.272909533592966, 56.31786946327456, 57.936447281991285, 56.520765827548125, 56.593823894377685, 58.054949929637296, 58.85515659086166, 61.828026848454634, 63.20819516335765, 61.499791145324714, 58.51207471662953, 61.92397194523966, 24.433418512344364, 2.70346250745558, 3.3625315033620407, 1.513038236768015, 0.118194266612972, 0.03878528109541343, 6.173098250742882, 53.423305403801706, 38.64807428852205, 39.29970156761908, 15.87415470230964, 12.105007998404965, 34.180522118845296, 52.70326806652931, 52.32546144916166, 52.510648312107215, 21.52850724035694, 0.8858337794100085, 0.022870601199927832, 0.06280298404876264, 0.014103447902016343, 0.04164281203561733, 0.05759413774696089, 0.020042434409861604, 0.07742384103156867, 0.0034533934095018217, 0.027453685817759366, 0.01495162214738347, 0.056819657329469926, 0.07034988473019294, 0.026217451649567774, 0.027796328217992862, 0.040613082613074974, 0.06035825575611765, 0.055937936093898556, 0.06218716427082978, 0.030370132749780055, 0.0431032590718279, 0.035444107357292406, 0.07520324325249081, 0.1390692126005888, 0.04044710200340037, 0.016560643318019087, 0.11336039736746781, 0.06074772336550298, 0.12531689248017727, 18.20244912178286, 76.77107657155683, 69.62307468537362, 73.00211814142042, 52.423861949674546, 33.09282141347086, 22.035836404369725, 35.591049578882036, 39.16693718202653, 70.50666701409125, 24.60976435292152, 0.21621109497162605, 0.6730887113559632, 1.4734104083430384, 8.835027025591943, 4.012006872123288, 0.8990777848709015, 58.4959263186301, 65.53915385277041, 70.93243245155581, 64.82926760950397, 58.67985410075034, 51.24134579012471, 66.36451075153967, 64.55382308652325, 66.79068411550215, 62.05390045719763, 63.08378150386196, 59.648016652753284, 63.0828401350206, 63.07964340333016, 65.07146612290414, 63.44968372775663, 62.615705459348625, 51.876926652846805, 46.7329264456226, 46.27650768526139, 46.05587436306862, 47.02356623065087, 47.23633912301833, 47.299732469743304, 44.88424670311713, 44.41106373263944, 45.32540744350803, 44.89585299645701, 44.1025104830342, 43.52483557116601, 44.496594936616965, 44.02813449982674, 45.014104612412, 43.584012369955744, 43.8055556820285, 48.58469309345369, 44.9204933258795, 45.391907307409475, 43.782084218917355, 42.10683599595101, 43.985412043909875, 44.775287182100364, 43.643969720409764, 45.110704745015795, 42.64402028053038, 43.629421649440644, 47.58970545184228, 54.29621711854012, 56.03303870847149, 57.1132908328887, 57.936459049101806, 59.42532408622004, 56.868217222152225, 59.8214207157012, 55.87550455524076, 58.65557070701354, 37.67730728272469, 35.510142849337676, 57.70019900414252, 50.74618577957154, 59.22257677201302, 54.33146745927873, 57.634291418137096, 56.12745408088931, 56.119119044273134, 54.534677613166075, 53.57112384611561, 56.91244194584509, 56.513387849253995, 45.30691739051573, 43.31560850143433, 45.384796050287065, 44.57661521050238, 43.18012591331236, 42.58567502421718, 41.81610599640877, 43.27873822181456, 43.254137116093794, 44.27088998979138, 44.83080048714915, 45.89969734991751, 47.1539262033278, 49.75988226552164, 47.9448329248736, 44.07753675214706, 44.80923921831193, 43.64964146767893, 43.54650666636806, 44.07627767132175, 45.01821917872275, 44.72357465374855, 45.00019981015114, 44.232988126816295, 44.639632009690814, 44.659318385585664, 45.56545649805377, 45.09152827724334, 44.46097981545233, 43.352521927126, 45.932511898779104, 51.254015045781294, 55.30056745775285, 57.82482839399769, 60.40481444328063, 58.920358150236076, 60.80644553707492, 60.21646222760601, 61.81577336403632, 62.51145670490881, 65.29836739263227, 61.92225786947436, 60.280773408951305, 62.45566883394795, 31.108455119594453, 2.0682331871601844, 3.5633649460731016, 4.893372520323723, 0.29981160416237773, 0.07762139212460288, 6.527494692033337, 61.49423314679054, 40.126898057999156, 34.580141036741196, 20.242973950601396, 21.822126065531087, 41.33203844870291, 61.15256332582044, 57.080036978567804, 61.36767787318076, 29.653440137063306, 0.9585235111655729, 0.07293946109712124, 0.0702952933047087, 0.08777556580401237, 0.027615353352420276, 0.013934909516284543, 0.031705768741366845, 0.06450229729976385, 0.053805752522161895, 0.008595698990017898, 0.026704790821719556, 0.013765386707570045, 0.0401083302624043, 0.02827690857943268, 0.021783918885874654, 0.14951782451281626, 0.1932796778818292, 0.12427246183036797, 0.20316143069536458, 0.09655658816618305, 0.14979242106839535, 0.1960021705036202, 0.1458399436406551, 0.39020299250560425, 0.21285820391870316, 0.1493021554403728, 0.16869659054904215, 0.1840583388242991, 0.19142756839433026, 22.90816172476738, 86.31010824634184, 78.17853281574865, 80.59120624296128, 59.20758155084426, 41.366853406352384, 43.11282196352559, 53.03159790654337, 51.5042701075154, 75.47717294385357, 28.913475198130456, 0.3300730271204826, 0.9821060876692496, 1.47391332974357, 16.081050903566425, 16.704007617888912, 0.8238719752238644, 62.89146377194313, 67.02358661159393, 74.43622296856296, 65.44253803068592, 61.916040912751235, 52.62582871221727, 69.85896602753671, 67.76387122369582, 67.05770338735273, 64.54014578173238, 65.43070423987605, 60.52316019611975, 64.48974332501813, 65.23650377027451, 66.15405990231422, 64.74089268715151, 65.26325041247954, 52.51263695378458, 49.33746653218424, 48.2545118947183, 48.26936591056086, 48.76136449075515, 49.50699137103174, 49.93661642074586, 47.03797309629379, 45.954135925539084, 47.53774973653978, 47.822223555657175, 46.09830264122256, 44.524996819034705, 46.998435604956846, 45.33628025362569, 49.3902773241843, 45.8325267607166, 46.95350093226279, 50.992545927724535, 47.40295356319797, 49.334265878123624, 45.523534205652055, 42.663475236585064, 45.697518779385476, 46.38773825860793, 46.42433397231564, 49.00952892918741, 45.126751161390736, 44.76269245147706, 50.109734150671194, 55.928570301302024, 57.43410933402277, 59.26045510076708, 60.76668839300833, 59.373372293287716, 58.772888798867505, 62.581353341379476, 57.409931844280614, 57.6953274203885, 41.35609042259955, 39.358156650297104, 58.88606486781951, 51.71919245873728, 61.79083101211056, 57.09186292463734, 59.65623009589411, 57.42904555413031, 58.58485821754702, 56.89011973719443, 56.362380519990005, 58.81328528927219, 59.27771352952527, 48.359564735043435, 46.748678684234626, 47.98353887373402, 46.672094406620154, 47.176734785879816, 45.801438054730816, 42.33827544796852, 46.12821855852681, 45.57095173866519, 47.034646926387666, 47.21115750651206, 47.60170005982923, 49.535938462903424, 51.82928554473385, 50.43708732051235, 47.00110281667402, 47.06925007604784, 47.25767289438556, 45.24189233779908, 46.42413393143685, 47.2048895589767, 46.90933896649269, 48.297595208691014, 47.75879882997083, 47.529571594730506, 46.71285175508069, 48.25978748260006, 46.28913379484608, 45.684680861811486, 46.05353270807574, 50.3224991982983, 54.785085647336906, 57.40194589860978, 60.41165897923132, 63.57868656035393, 60.96119088511313, 63.525938526276626, 62.891083302036414, 64.56317401701405, 64.67303568317045, 68.23196688006001, 64.84105825424194, 62.98875031932708, 65.72026145073676, 31.668130274741884, 5.691024737973367, 10.715419130940592, 6.796587426816264, 0.47696609650888755, 0.14167909029751055, 8.41718477587546, 66.55917013845136, 53.23078763100409, 51.04681191905853, 23.4501705246587, 22.554730676835586, 47.57864829032652, 68.98627004315777, 65.46462489712623, 69.25303043857699, 37.58058555664555, 1.6881147002981556, 0.13972362022726767, 0.24085888609049783, 0.1583310378895652, 0.12097277558378636, 0.10807450560312118, 0.12437411403704075, 0.17008573778213995, 0.2100078205788328, 0.15213119557067273, 0.1530786011848719, 0.2143681478957015, 0.13863081112504005, 0.1134332906334631, 0.18014448754970105], [0.10474275091602918, 0.05884290702881352, 0.043576268569356015, 0.0858063521164079, 0.09956179021467125, 0.07453218087433808, 0.03791860582667493, 0.019278100826927734, 0.09340638865626628, 0.00956454836282759, 0.00708012666080087, 0.023681059021562822, 0.048925362587455785, 0.1608217123054689, 26.156235279575473, 65.8848362584268, 59.891427178536695, 57.616338729858406, 36.722123853621945, 28.41560090741804, 43.77174485114313, 47.3883270448254, 41.33822402646465, 65.97414862725043, 8.499645744600604, 0.14888272230182925, 0.14803469361316773, 0.6900606232304728, 5.317950950514886, 1.9608938501727198, 13.184370725385605, 65.56068374264625, 65.8650988917197, 68.58341909223988, 59.83705528320805, 55.69060794768795, 49.54304187528549, 54.090845738687825, 61.693438560731956, 62.27771089922998, 64.05440730433311, 64.31529983397454, 62.32090403956752, 63.102644182020626, 57.3875625671879, 60.404198631163574, 59.849014589863444, 58.25943093146048, 52.64388730449062, 44.40752575474401, 43.72292310960832, 43.74025998576995, 45.0269974431684, 43.10687957271453, 44.50796981011668, 43.679839795635594, 42.00068489197762, 43.078548292959894, 44.110829830169685, 43.613747858232074, 42.9364094426555, 43.237980873354026, 42.27994980350618, 42.02997715242448, 42.44334005540417, 41.04111625302223, 41.87793823980516, 42.01665286094912, 41.362232854289395, 42.46439141611899, 42.60519666056479, 42.96283837287657, 40.064183281313994, 40.080531720192205, 42.23854918633738, 42.31303499590966, 41.440339011530725, 45.512692774495775, 54.87859495224492, 53.159004334480535, 56.686282004079516, 54.525475732741825, 56.1523062183011, 55.63548295728622, 57.47173270871563, 52.68198528597432, 57.04628106086486, 33.20092978016023, 35.007302837987105, 55.80530197389665, 51.16452224792973, 57.960922871866536, 54.23106654997795, 53.31282008078791, 53.774381068445024, 55.69636990947109, 50.76827264601185, 51.569954118421, 50.77410521045808, 57.019436359405525, 48.881891081410075, 42.56388233553979, 41.21350834446569, 45.14608844634026, 40.88261719672911, 40.691954705023, 39.18061056444722, 40.52239456484395, 41.23836832661783, 41.433474863729174, 42.411258989764804, 44.69398037079842, 42.905614914432654, 43.6306611184151, 42.57153487974598, 40.96682263958839, 42.54707890172159, 42.59044070397654, 42.25048495877174, 42.66886457320183, 42.12920527304373, 42.95155763626099, 41.48350469527706, 42.947368544916955, 42.837330372102805, 41.479664694878366, 42.91065516010408, 42.537657368567686, 41.774595552875155, 42.187444625362275, 46.188732885545306, 51.42909396079279, 56.0157802797133, 56.42003151678271, 56.676782023522165, 57.939812675599136, 59.632597815605905, 58.27771702120381, 62.50084277122252, 59.089086747938595, 61.86367334858064, 61.024780350346724, 64.94938627366098, 64.42243153049101, 61.496170797655665, 12.263258964784685, 2.932512990890011, 5.061460791095611, 0.1643727290173692, 0.11850916705424748, 0.09537076066818931, 32.00728585643153, 49.947673582261615, 50.60944803299443, 35.75462025980796, 19.471349600822695, 24.82540842025511, 38.126512804339015, 49.02270809296639, 56.147842561045, 40.60008887321719, 5.423993208715993, 0.19440018872339881, 0.08715572406447704, 0.07694572555802523, 0.03370915952649328, 0.05433982305769479, 0.07200688694513614, 0.07979731931681595, 0.03881207502056514, 0.07138698391856686, 0.0752606768641741, 0.024043451168484265, 0.07608155539679913, 0.04182884116627036, 0.028385664336383346, 0.027369661294224284, 0.08126155848825171, 0.03580470111281161, 0.10476890515776412, 0.04187769842364135, 0.062152345574671225, 0.048644775224308816, 0.024287463578906272, 0.05237020717393007, 0.019370481454496904, 0.032388090696786685, 0.07408134579177826, 0.05782697868022708, 0.15981991444864582, 36.016038387052475, 77.79776480890091, 66.21358579204929, 63.83200107082244, 44.10509924734793, 36.54023178162114, 40.04818393338112, 50.95393803811843, 44.72038184442828, 73.43999585797711, 8.541180702947802, 0.38452073451011415, 0.24751691027514397, 3.0346345949557523, 4.951807500854616, 1.1153263262202664, 14.76979765199846, 65.83907788799655, 66.29879536167269, 71.27263530608147, 63.05651710879419, 56.45442285845357, 50.651707649230964, 55.743155940886474, 65.5238683762089, 64.24670934677124, 66.09462814946329, 66.39763124527471, 63.298511658945394, 65.20448546255788, 59.22772684404927, 62.85281273626513, 61.340425245223514, 61.90500336308634, 56.42334199720814, 46.13683208342522, 46.090661864126886, 45.892954795591294, 45.45059380992767, 45.541879130947976, 45.26128845830118, 44.84445425771898, 44.40146961519795, 45.78971409028577, 46.35982667246173, 44.59430509997953, 44.49689695912023, 46.17596164826424, 44.479481635555146, 44.79337323096491, 43.27449029491794, 42.84062908541772, 42.260432089528734, 45.035203041568884, 44.02043096480831, 45.33976724070888, 44.676412074796616, 44.96190571015881, 43.359856759348226, 43.45671184601323, 43.26177397081929, 43.909227848052986, 43.67107722067064, 47.99253679090931, 58.76963323162448, 56.221292864891794, 58.73506538329586, 56.85476741483135, 56.60315521301762, 56.36902893743208, 59.37003435627107, 55.01114752984817, 56.770307017910866, 35.51817978582075, 38.04251132472869, 56.60728939117924, 50.65473179663382, 57.78143521278136, 56.20566221975512, 55.80778091184555, 53.97930529809768, 57.196700034603, 53.39801788330079, 51.32546101847003, 53.15425434420186, 60.145526163039676, 52.60861735190115, 42.80109943882112, 42.36621449070592, 44.78016268822455, 43.76763420720255, 42.75868685014787, 42.003352103694795, 43.40192025707614, 42.507223698400686, 42.58116429851901, 44.61892581755116, 46.49180266164964, 46.90140401163409, 45.91151545124669, 45.68356690868255, 43.46545088675715, 44.917500557438025, 45.78233218962147, 44.45492759827645, 44.305779472474136, 45.347600213943, 43.422312659602014, 44.19746322016562, 46.49088090465915, 42.97587240895918, 43.01465680522304, 45.77169079934397, 43.8184485127849, 44.216408268097915, 45.12344852570565, 48.40512698696506, 52.722142511798495, 57.42333066078925, 57.69466453982938, 59.39802046745055, 60.002638140032374, 62.57521090968963, 60.755533172238266, 63.24054295016874, 60.79576884546588, 63.336515503544966, 61.82715608227638, 66.48052661649643, 63.6882265921562, 66.48529621862596, 13.826990281381915, 2.5147099648752524, 5.543741208891715, 0.8356463176108176, 0.08191086396935486, 0.07969850929634226, 34.67144989198254, 58.12698425785188, 37.15214506272347, 29.942646295793597, 23.90586364653803, 30.74424735961422, 44.46323125593124, 53.936218061754786, 63.75016081717707, 52.56512611143051, 8.846623513006396, 0.12333407307103758, 0.0491558822743114, 0.040294470475806345, 0.07458134073643916, 0.02472742404338093, 0.0727657966255661, 0.1070857389018901, 0.05148683118844225, 0.02315687485069277, 0.025686987472938436, 0.05848042486656097, 0.08855880643691748, 0.03703303116884443, 0.06421483046705685, 0.1862623891042125, 0.1450913531645652, 0.14801869769730877, 0.17220072267997652, 0.17119512502704898, 0.25202207417497713, 0.25949965922101853, 0.067292757242197, 0.2350554942724205, 0.0882349044625317, 0.10995251652334007, 0.153623626777722, 0.16248104342770192, 0.26643379681533386, 44.07382226759388, 88.95477417976626, 73.969680570787, 74.1643399576987, 49.30371061448128, 41.581375675816695, 57.823130007713075, 64.6771502494812, 55.253436257762296, 76.69019729860368, 11.557933457436102, 0.6940426869738487, 0.2898106940330998, 2.7164742350578313, 16.548836692687004, 5.247094804240811, 16.01012856729569, 71.86981616481658, 68.00041367930751, 73.17225487001481, 64.02920999834615, 60.346704529177764, 54.144582210048554, 58.84340909219558, 67.68336065353887, 66.69914384042063, 68.38165237057594, 68.61320557132845, 65.22252444298037, 66.85569347873812, 59.886077065621656, 64.33143646486344, 63.20794413166662, 64.00339295787197, 57.501527032544544, 48.15123196571104, 47.84986842063166, 46.697923214204856, 49.0570092201233, 47.015960754886756, 48.03249789822487, 48.19019286863266, 45.951162768948464, 49.47880521897347, 49.263231754302986, 48.050211321923044, 47.08161338683098, 48.12630530326597, 47.96852796308456, 46.47973352862943, 44.6503165460402, 45.383101586372625, 46.12693202111029, 46.45403415926042, 45.92443966096448, 48.08666583030455, 45.67879338418284, 46.275593773011245, 45.3358684047576, 44.96245091961276, 45.707967973524525, 48.02043268757482, 46.76550565227386, 50.455224360189135, 62.438210364310976, 57.55673047034972, 60.27153230482533, 57.89952993392945, 58.790053090741566, 59.3005770252597, 61.232567910225164, 57.98934828850531, 59.39593376651887, 38.69130273019114, 41.91876226855863, 59.650354385375984, 51.567392810698486, 61.70385637590962, 59.493236003383515, 56.341062438103464, 57.611188657822154, 58.777756460251354, 54.47487715751895, 53.425462707396484, 55.365592510469504, 62.292337417602546, 52.67444256813296, 44.960842747842115, 45.46878576278687, 48.8803848912639, 47.06175050427837, 44.45020506458898, 43.58004685371153, 44.73623214229461, 45.28976094338202, 44.97692838791878, 47.01723552519276, 49.06079430733958, 49.106207509194654, 48.09735821139429, 47.336708653357725, 46.15152135972054, 48.06090370301278, 48.42460547724078, 45.87088754100185, 45.18814017695766, 46.443212339955, 45.54469147036153, 46.865400575822406, 48.41637242224909, 45.876335713171194, 45.31231457187284, 50.77660376025785, 45.139087015582675, 47.41940006133049, 47.69203616726784, 51.09998749148462, 55.45482643188969, 60.364763121451105, 61.4774493248232, 61.94384267253261, 61.538140158499445, 65.27919876960017, 63.889244141117224, 66.19158129538259, 62.86898466848559, 65.17893122088525, 65.0265000712487, 68.7448638485324, 66.81452428140949, 68.63220553244315, 15.71744522740764, 7.471719999467173, 11.565279076176306, 0.43426184284110225, 0.30157709974915753, 0.185267961013221, 40.804605176371915, 67.2577521108812, 67.62877695022091, 48.29728141907723, 28.253946304321293, 37.23866470398442, 53.411146056267526, 64.31369950694423, 70.60393394962435, 62.947349702158284, 10.602488210124354, 0.2956952298841169, 0.19498348806894597, 0.17804767425742843, 0.26175897508378954, 0.19530804887894662, 0.22323570754979888, 0.15718469456318887, 0.1468722624403815, 0.15614111427097552, 0.1440972315087434, 0.21629105922916245, 0.24665241069611044, 0.12123675416073493, 0.20511667093923017], [0.03246480291108451, 0.01682262049026547, 0.027483427266199744, 0.08349295044618268, 0.05998960275563502, 0.04200480773203796, 0.03399864883132039, 0.06836482068343509, 0.034431423391065294, 0.03673866188393966, 0.03322765028344528, 0.12673598609023518, 0.03843776063032208, 2.6999554182252576, 45.03150816886656, 63.226391038587025, 58.9646730884429, 55.656279363939845, 31.04787018991286, 15.197578207139047, 39.849209939279866, 28.548431973303522, 52.37341634688839, 49.5406453071102, 1.9393467999273732, 0.1663994299428117, 3.394392671123628, 8.303175203261837, 3.364686355475457, 4.056116131044203, 37.66891733292611, 63.4306602324209, 67.42453129060807, 63.24863479983423, 59.08738836165398, 53.34895687718546, 51.45002765040244, 48.81766619220857, 49.21226839865408, 58.90932452294135, 60.29891437099826, 59.99107499276439, 60.67010002751505, 61.06154080360167, 59.99769203124508, 54.304975771134906, 60.00821182804724, 58.735998907396876, 56.2737153422448, 45.54859422868299, 44.873091482347064, 45.5670254461227, 44.89165606037263, 43.014652882852864, 41.72215738604146, 42.48135174474409, 41.94973722580941, 40.22337659712761, 43.063713888968195, 42.110283759332475, 43.199490654853086, 42.67736434936524, 43.38026485135479, 41.347594568806315, 41.76114966792446, 42.14123125999205, 41.93561669318907, 41.25679562168737, 42.690143431386645, 41.52829424027474, 42.259773131339784, 40.91122304239581, 41.52741562935614, 40.31317926222279, 41.861648636479536, 39.62123001775434, 43.34975273378434, 44.79735051431964, 54.86685529831917, 53.54740135131344, 56.62727778957736, 52.58162752274544, 56.49096365897887, 53.77016844287996, 57.64307752732308, 51.125224021173295, 58.49404750331756, 27.702113928333407, 36.75982567571825, 52.91512312427644, 48.796603064383234, 56.94959855848744, 52.83979400511711, 55.888797467754735, 51.5638901341346, 54.74566582710513, 54.938803334389966, 53.03565363730154, 51.17285336217573, 54.45925435712261, 55.404349450142156, 47.48815528808102, 40.24921717182283, 42.314953034923924, 43.200314352589274, 41.083042467794115, 40.43864411692466, 39.147678344480454, 41.376372998760594, 42.53677091290874, 42.35764018950924, 41.979963010357274, 41.533361942537375, 41.10214441053329, 42.78828113309799, 43.381378804483724, 42.127526498609974, 42.99925757992653, 42.15070378395819, 42.66005885216498, 42.045945121395974, 42.93603289511896, 44.92130917887534, 42.80015022523942, 40.4928316608552, 41.974271651237245, 43.07811683224094, 42.8702155236275, 41.44988213815997, 42.09531599475492, 46.32156002906061, 52.74544923536239, 53.74092717324534, 55.93831346881006, 57.010258013202304, 57.72973837391023, 58.29717589962868, 58.80339699406778, 59.965661956417954, 60.08811050845731, 64.81832027435303, 60.48157522755285, 62.88246193239766, 59.51163584186185, 72.81832371988605, 29.92074574193647, 0.5429707611760786, 2.8677117584213137, 0.8798995397744641, 0.027549347216864268, 0.15106302385608997, 11.03370083916572, 48.009367681318714, 49.37192455414803, 43.860649293468846, 20.623547800125618, 20.775833822065785, 27.396302415478615, 41.92718359731859, 47.50117755705311, 56.551858455904075, 17.008787547388387, 0.43471438629973325, 0.054727513343095786, 0.0151398710177971, 0.07778063116054382, 0.025420149472812494, 0.07539938474374433, 0.11048505488302439, 0.057080395354498784, 0.034123976985293056, 0.03786260862984965, 0.03247562773345459, 0.021987778712965308, 0.029576059633625612, 0.05719135169901195, 0.04139504004870692, 0.0453315407127863, 0.06753199884007055, 0.048752663386685234, 0.08253006985591305, 0.015562672070377778, 0.055595889327026186, 0.061664263297232895, 0.042434157878761335, 0.009266342892641983, 0.006656135777912795, 0.1296032923123529, 0.0718257071510438, 3.3795124244305397, 58.80787241843439, 71.33227102218136, 65.56928550043415, 63.61953020095826, 41.1951594967996, 21.066497141315093, 33.573476499126805, 32.570614699394476, 57.77517903235651, 55.709070544089045, 1.9636336257380826, 0.1208195656598095, 5.178672488658659, 10.080846317352789, 4.4738456126182315, 3.373001535092631, 42.5122796335528, 67.76528327695786, 71.14769212661251, 66.01065804881435, 60.607903003692634, 56.818548248660186, 53.70653583157448, 49.88463324885215, 53.44953821551416, 59.8039936250256, 61.94379560409054, 62.927329924798784, 63.8468276300738, 63.078968755660526, 64.3018735608747, 58.959248450494584, 61.35995864868165, 59.782298995602524, 58.287711220402876, 45.99823121101626, 45.74384981586088, 47.79368831265358, 45.73387915088285, 45.1871988081163, 44.02986034270256, 44.24234690204744, 43.93837498080346, 44.0513627759872, 44.93096605423958, 42.65916062939552, 44.9330605999116, 44.95829320723011, 45.52154164160452, 42.901727845591886, 44.43814769867928, 44.155811571305804, 44.04523603377804, 43.9847570080911, 43.80674808256088, 43.346218678259085, 44.13055542976626, 44.25047405304448, 44.23476496050435, 43.0711938488868, 44.456253359394694, 44.24159380697435, 45.100973344618275, 47.0522544460912, 57.25104447334044, 55.07289348110076, 57.50642607288977, 55.05821989428613, 58.10376382643177, 55.13137209799982, 60.33746342505179, 52.63659561834028, 59.947281729790475, 29.78074262219091, 36.93373180204822, 52.51773603500859, 50.38228004209457, 60.00378347212269, 55.41327676465435, 56.87343005211123, 54.651736828588675, 57.46899489433535, 56.551572122881495, 56.44825689254269, 52.878405817093395, 56.33141732984974, 56.144806646531634, 51.334262817136704, 41.84078947190316, 43.90155569199593, 44.88087738713911, 42.520030237013295, 40.88394295784735, 41.4816572589259, 42.45788812637329, 44.34561506394417, 43.15796452183878, 45.11173240600094, 43.48637673162645, 43.9245839272776, 44.66972835602299, 44.64273068212694, 44.35520918138566, 45.40148573537027, 43.54191357089628, 44.82360686025312, 43.73128168044552, 45.24689335976878, 45.569049389131614, 44.73468280607655, 43.80209222916634, 44.665503963347405, 44.81686038355674, 44.54192576869842, 44.342673286314934, 44.525961722097094, 49.92673597028179, 55.78288170599169, 56.461628252460116, 59.565027144647416, 58.71193908875989, 58.458863842871885, 58.87273273160381, 60.07926948608891, 62.02047401858915, 60.39511834421466, 65.76477642982238, 63.79012976923297, 63.8085727537832, 63.25025081634522, 72.16011862601005, 34.93649621163645, 0.8690869748111695, 4.095513887943761, 1.5708574051818542, 0.30339753916186674, 0.11578608454475481, 10.378113927379733, 56.940655554494555, 50.013302679984804, 35.62122045024749, 21.264202248665597, 28.532365945077714, 35.13914938895933, 48.96295470576133, 51.88816816576066, 64.4556147821488, 24.087832204757202, 0.4486212723197476, 0.026648006469552076, 0.033797259637785536, 0.05172159117195876, 0.047038511012590704, 0.11000411254504036, 0.09748690235879152, 0.06786540030471741, 0.03849149020689149, 0.04411975815591793, 0.043182530019792824, 0.0671698767391424, 0.008121739543463674, 0.008339613991519137, 0.10985867075261571, 0.10524147415473577, 0.17982904318599932, 0.21149147241826982, 0.1444640037633719, 0.04210509630220552, 0.15467201810209982, 0.1696110390607388, 0.1880275629340641, 0.14033169485628605, 0.042184777107209935, 0.2850842992624929, 0.15396580760998113, 4.1396993879349, 69.47924137115479, 82.1865047947053, 74.33520624714514, 73.82086584644934, 43.82193549986809, 24.97424275644364, 51.993809361611646, 41.144051013454316, 66.87799607553791, 60.99367987725043, 3.305034214450467, 0.3036963440958531, 5.326706661332039, 14.228579209696862, 12.85049073157772, 5.2006098147361515, 48.538220851652085, 67.73230398854902, 73.98331472950598, 69.02178318269792, 63.78892560159007, 58.822326352519376, 56.2049130470522, 53.41037334934358, 56.919690485923525, 64.06901421085482, 66.6863961373606, 65.72164212503742, 65.62917617059523, 65.86129419265255, 67.0578210584579, 60.203361511230476, 63.20572407014909, 61.5618783427823, 60.478507934078095, 48.01789883644351, 47.8879467902645, 50.941735544512355, 49.463566810854026, 46.177911066239886, 45.77795090213899, 47.59811501349173, 45.70763064968971, 44.99819547899308, 47.38878988450574, 44.37665277911771, 48.337575927857436, 47.16344971810618, 47.72163437258813, 46.18956050565166, 46.65327095216321, 46.47483841065438, 46.1001383104632, 44.5462207640371, 47.628678121874415, 45.86574531370594, 45.84650216564056, 46.51605859879525, 46.087633794353856, 44.35633882399529, 46.58169946362896, 46.26805105516988, 47.142398357391365, 48.16195964813233, 59.485030404983036, 56.910935755698915, 60.32508442478796, 56.721512732967255, 60.34029145394603, 58.96454757259738, 61.75623962956091, 55.51585851177093, 61.63205346753521, 33.023603347039995, 41.460017542685236, 54.95513216141732, 52.27454123958465, 61.053319515720496, 59.120697129157286, 60.24291861441828, 56.35078207139046, 59.69899569788287, 59.991918302351436, 56.320073835311405, 55.178844544195364, 59.48891355145363, 59.17223707322152, 54.01201394296462, 43.5930298989819, 46.584221547649754, 47.59741290923088, 45.03132381746846, 43.406709471056544, 43.043513682580766, 44.91464507195258, 45.758794046217396, 46.035450581581365, 46.63541632313883, 46.49779212090277, 47.4746701794286, 46.3187712238681, 48.769876034029075, 46.94562089058661, 48.140971045340265, 45.06762535341325, 47.28777708545808, 45.93524579078921, 46.791954194345784, 50.259972695381414, 46.27284026915028, 46.14597120592671, 45.73478914076283, 48.673887791172156, 47.841121535147394, 46.10335073163433, 46.51326979360273, 53.2166317970522, 58.07690735786193, 60.125918234548266, 59.45551849180653, 59.697226708935155, 61.960967740704945, 62.73418849514377, 61.63185342665642, 66.00042850740495, 63.210595653903106, 69.04179511531707, 65.63655022651919, 68.72161203815092, 64.33392324755269, 76.68416469327866, 35.281449056440785, 4.014213940789623, 14.61381773794851, 1.4220983294710037, 0.5554888830069573, 0.3590204254273446, 14.066439213291293, 63.023541742755526, 64.56167174923804, 57.00002062705256, 27.876357378498202, 30.771131284775276, 40.85558814387168, 58.126207628557765, 61.80751285245342, 73.94147088450771, 28.993789649778797, 0.7420510882812162, 0.1529383611294531, 0.14117017808941104, 0.10425902767888001, 0.17658588656735036, 0.21041950090758263, 0.17148260718151448, 0.12058627656510762, 0.1136084872808668, 0.17367682089248013, 0.17805642298152372, 0.11646352077443754, 0.16685479260500402, 0.14946170091148347], [0.012402238583402529, 0.06917331157432449, 0.01326772928868811, 0.046694430282279376, 0.0021124134758382196, 0.032644358598777366, 0.025216724400618867, 0.04441603499975416, 0.04031574473746362, 0.018711255134774313, 0.10992591028972981, 0.0323730600517123, 0.046898994910260366, 6.982015515527418, 62.75227062163815, 58.326758415468284, 59.409654217381636, 35.387058873330396, 21.241046536353327, 35.87825729000953, 64.84485903093892, 35.567001527355565, 64.48573074033185, 30.235153129023892, 0.3984887237029691, 0.1820537012310759, 7.860610254349248, 17.320959183477587, 1.421985193606346, 4.925545271365873, 43.096183269254624, 70.62655818077826, 63.355040857868815, 62.1946390213505, 56.22376003573018, 61.419280575167754, 56.676495690499586, 48.057232364531494, 45.71347890361663, 47.995549171201645, 53.732141064059356, 57.254731501302416, 59.11293475858627, 59.93370640662409, 59.92033112433649, 58.664835345360544, 59.896436045246745, 59.739760891083755, 53.98191759663244, 42.65155123126122, 44.85002794573384, 42.29112855849728, 44.203605651855476, 43.34131179317352, 43.43200483629781, 42.83666356917351, 42.26498203892862, 42.07934410341325, 41.89039568747244, 41.54600766397292, 43.44339147690804, 42.124741615787634, 42.558787176685954, 42.422849593623994, 42.393910346492646, 43.04451780934488, 43.55159005811138, 41.86087985192576, 44.164083849999216, 42.13613610113821, 43.900422127016135, 41.168008850466826, 42.85775415359005, 42.17919588088989, 42.25316393759943, 43.057171375520774, 43.775647609464585, 42.77282699461907, 54.8627289648979, 53.02781674169725, 52.78979163016043, 53.63816107473066, 57.03269397058795, 51.61179796341927, 59.77068485752229, 47.652800698434156, 54.821140073960834, 27.373291830862723, 30.451887615265388, 53.4266786421499, 51.60578496994511, 57.9266688131517, 51.99063224177207, 56.33424535874398, 51.68717807339084, 55.104841186154275, 53.16732368161602, 55.42907607170844, 54.5919716742731, 54.66140939343361, 52.72880269635109, 48.58784667907223, 41.33075583365656, 40.29693280496905, 41.225777518364694, 42.45179668549569, 41.95502850317186, 41.890411376953125, 41.79372495220554, 43.30027987880092, 41.58912235690702, 42.59797557707756, 41.845288430490804, 43.22851227175805, 42.12320404668009, 39.88790804339994, 44.44412539082189, 44.162746321770456, 41.48978440992294, 43.418370677578835, 42.11307648689517, 41.8674066758925, 42.02765903165264, 44.69437260781565, 43.056849741166644, 45.23451043713478, 44.89324069792225, 44.16550767037177, 44.18180119606757, 43.68522913225236, 48.98628496354627, 53.7958364332876, 53.65579997339557, 52.47635110732048, 54.65575333564512, 54.01550877478815, 58.95014462932464, 59.8790011098308, 58.945284812681145, 59.704942011064105, 61.11741104433614, 59.69675602451448, 58.82817068407613, 59.94725819556945, 68.33138327444753, 57.74498070439985, 3.4750547428284926, 4.1738906887269795, 2.169030255848362, 0.042478541182654525, 0.10003183878237203, 0.9165881646256294, 39.08839956406624, 43.81429864514259, 40.78608766678841, 29.158058512595396, 15.603397411684837, 21.948261645532426, 32.81815155859917, 49.563442122551706, 49.722184365795506, 35.434578387968, 1.4743451581847284, 0.054617326916946526, 0.030349816098028136, 0.06402183759717212, 0.01610199030819199, 0.01965849795528958, 0.07091761716911871, 0.06230524523303874, 0.03767946382023154, 0.0491080975400344, 0.02949495582030185, 0.044030037768665826, 0.030210930103015517, 0.03652928239335457, 0.04263748910518424, 0.04093488550654823, 0.015687326066977075, 0.09651433841715898, 0.04578156374214638, 0.009077443805102621, 0.017755458942584453, 0.03257325031764565, 0.013817367688452285, 0.12600364433901926, 0.02483876534707604, 0.08727449833625749, 0.08588696754867993, 9.426126249374883, 74.15275327620968, 67.40273075719034, 66.45738463247976, 44.726402682642785, 26.67196616049736, 37.681633657024754, 73.11599239226311, 35.231278019566695, 73.38671438155636, 34.10253363270914, 0.630811260592553, 0.40895884736411037, 7.491260267073109, 16.105417647669395, 2.906573376347942, 6.908684353674612, 46.24298318739861, 72.06592682869204, 65.6620103313077, 64.82953433067568, 60.59529650595881, 61.00712183983096, 59.96964708451302, 51.03228345994027, 46.84425900059362, 49.63344074064686, 55.394382707534305, 58.92810875369657, 61.54571033293202, 61.55868945583221, 62.88179512946837, 61.11098620199389, 61.07195861877934, 62.095642320571415, 56.776296477163996, 45.32896895562449, 46.34998936806956, 45.31249500090077, 44.82645842336839, 45.05514044915476, 45.27859787787161, 44.54599326656711, 43.93810825963175, 43.1632597215714, 44.81115333495602, 43.7476065851027, 46.81965397250268, 44.38146160494897, 45.27950786775159, 43.83012148641771, 45.189987613308816, 43.412683240828976, 43.69947518071821, 43.00224642599783, 45.19550638814127, 43.25466663606706, 44.45754774155156, 43.82544209880214, 43.59303774372224, 44.55572074459445, 43.920057512098744, 44.447016177638886, 45.15663962210379, 45.79768434647591, 57.725898373511534, 54.65985613484537, 56.54464129478701, 54.59578029571041, 57.959534352825536, 53.25239596828338, 61.2222206977106, 49.13326009627312, 55.9527164120828, 28.413708363809896, 32.23950389892825, 54.50846833567466, 51.77264259707544, 59.00544612638412, 54.222402034267304, 57.93289361461517, 53.6729250415679, 55.578153594847656, 56.005570350154755, 56.3031997988301, 55.428915254531375, 55.646422447696814, 54.59427018319407, 51.27520761182232, 43.33590676707607, 43.21983206656672, 42.88156294053601, 44.57904708000922, 43.8054850793654, 42.98791800775836, 43.40564258636967, 44.53854076323971, 44.80106107650265, 45.05001391133955, 43.87121615871307, 43.75547093729819, 43.011993515876036, 42.508172911982385, 45.188453966571444, 44.75526348237069, 43.161588791877996, 44.966581175404215, 44.82469727916103, 43.49922641631096, 45.00501255835257, 46.19664430618287, 46.1017817835654, 47.107328445680686, 46.78153637916812, 46.486966379227184, 46.52785708827358, 45.93705008106847, 51.44314389075003, 55.23957067920316, 55.36531794455744, 53.63016336194931, 55.91413990143807, 55.52489957501812, 59.85854594938217, 61.91854730729134, 61.345865572652514, 62.24286064024895, 62.311627634109996, 62.10872734746626, 60.14878957502304, 62.572155383325395, 68.38377829520934, 63.05144156179121, 3.3641288886147165, 3.034251428419544, 3.515787331327316, 0.30808363770765645, 0.024834187971728466, 0.23335310900884293, 42.14454174041748, 49.251080251509144, 36.395578692036295, 23.153251024984545, 24.593810112245624, 33.46543481273036, 39.39132421247421, 57.602457461818574, 59.185180894790165, 46.15108989900159, 2.527312295090768, 0.03342679100892237, 0.031199859597930507, 0.029965477447295864, 0.015352364655794397, 0.051296718809152805, 0.20195309553415547, 0.06744059688982464, 0.02794376375424045, 0.11800566342689338, 0.03295961910137727, 0.04599683444886919, 0.025907155396717212, 0.03134019732955964, 0.12731956888831433, 0.15021425972302116, 0.08279563423486487, 0.14733180794264042, 0.13994901861634948, 0.09946781420899976, 0.08200726081286708, 0.20691559860302558, 0.13024170402317278, 0.23885581131664016, 0.23006374196660137, 0.18265734787189192, 0.27402551364033456, 13.173457710973679, 84.01299568914598, 74.27667663943383, 77.3861748172391, 51.42066478729249, 31.608549471824404, 45.620518730532744, 79.93863367265271, 50.061469385700846, 78.42262975631222, 39.77239424182523, 0.78465256359308, 0.41361914406861033, 14.722983183399325, 25.91356215938445, 7.496326498446926, 8.16663847815606, 50.91995854531565, 73.4796823993806, 68.90952494836623, 66.13051783653998, 63.741590438350556, 65.97747479715656, 61.58764439244425, 53.71230171572778, 49.25259428639566, 51.6146848278661, 57.03258414422312, 61.0955830543272, 64.04052603629329, 63.959270215803585, 63.038344767785844, 63.27553833684614, 65.00946913996052, 64.8073572497214, 59.05316175953035, 47.97027341781124, 49.23775203766362, 46.102005358665224, 49.48766585319273, 47.39978821046891, 48.03488269928963, 47.30636127533452, 47.247408051644605, 45.62839092746858, 45.28937262873496, 45.58468003426829, 49.48923087889149, 46.15548295359458, 47.197095809444306, 45.69083113824168, 47.185826839939246, 46.74823153403498, 48.17775503281624, 45.87593563141362, 48.350366776989354, 44.626527370945105, 47.03677677339124, 45.672415610282656, 45.88752623527281, 47.86858597109395, 47.10701857843707, 47.43670555853075, 48.073647483702636, 47.844259431285245, 58.88125604198825, 56.4551131956039, 57.96667698890933, 56.90542090323664, 61.65901976246988, 53.62746084890058, 64.89643819870489, 50.727048535500806, 57.914230977335286, 31.642515236331572, 34.45719042131978, 55.43347697104178, 56.29177001214797, 60.140748716169796, 55.93999616561398, 59.91893083818498, 55.45555991511191, 59.269758962815814, 57.95544332073581, 58.105952508987926, 59.58594514477638, 58.552675170283166, 56.7590537378865, 53.65478800189111, 45.14262891584828, 45.05653681293611, 46.74679986892208, 47.598232684596894, 47.917956844452895, 45.44078788449688, 45.48520872669835, 47.38298085428054, 46.48902954593782, 45.217659934874504, 46.56864581569549, 46.3193517346536, 45.54030233813871, 45.565091717627745, 48.13137692789878, 46.40787178470243, 45.17015610971759, 47.42760958210115, 46.82929123601606, 45.81673137603268, 45.9354026855961, 47.745168593622026, 50.47694644620342, 49.00473579283684, 50.50538362995271, 48.59139250170801, 48.92992834891043, 48.12324585453157, 53.84090838893768, 58.95063884796635, 59.11502145951795, 59.60443519776868, 58.481433160843395, 57.45263468834662, 63.48042726516724, 64.33297011160082, 62.72093480633151, 63.42291747370074, 64.96471097392421, 65.99399582032235, 62.957457650092344, 65.15002727508545, 72.01156277810374, 66.54941128146264, 6.049696072455376, 11.330522279585562, 5.230852759653523, 0.2782622556532583, 0.1666415443704013, 1.240118617011655, 47.810009294940585, 58.587474438451956, 56.384828244486165, 37.75145969083233, 24.268004317437452, 31.743092652290102, 47.802878425967315, 67.085662041941, 65.93775687679168, 55.15207436776931, 2.7872176131894513, 0.23210490663205427, 0.13688696518300042, 0.10990510334170635, 0.07212070462804648, 0.23101517720328224, 0.26324733070308165, 0.19741373346938243, 0.1674839652954571, 0.2915798055548822, 0.14375354914415267, 0.11381303275664968, 0.1466733860152383, 0.12976433931579515], [0.018909951529255318, 0.028488793177530173, 0.01708166163054205, 0.02708648838433287, 0.002092852857106576, 0.03660602525116936, 0.012917215335032633, 0.018313816380536845, 0.05816694551838502, 0.024379304114488826, 0.0818286320915626, 0.041023636792576125, 0.09248378130817607, 16.509254094093077, 65.2568922504302, 60.15690103653939, 59.82536662009455, 33.2628640051811, 28.541901226966615, 44.32971769763578, 28.773089647293094, 40.790374817386756, 67.6092984599452, 17.71594774338507, 0.12857792959097894, 0.17921597366371464, 7.099610134478539, 3.7364147699648336, 1.7486469231305586, 9.452503208191166, 61.86134738306846, 66.34630310919978, 62.85136145930137, 57.68452129056377, 59.70446740427325, 65.25884951314619, 64.3690598395563, 58.02261390993672, 47.274527319016, 45.54906491310366, 45.81214220293107, 49.32026301660846, 47.914195291457645, 52.38377140414331, 54.27620910829114, 56.106583149202415, 54.050229595553496, 54.049358829375244, 46.980663345706084, 43.72830460148473, 45.75362828470046, 44.22439421376875, 45.166845629292155, 42.44803121013027, 42.51450753981068, 41.40554758810228, 43.187154800661155, 41.42599490381057, 40.19920302975563, 41.84416663262152, 43.43770796252836, 42.01606450542327, 41.82173851997622, 42.47605654501146, 42.050024386375185, 41.46417133269772, 44.57786644658735, 41.81165018389302, 43.02086591720582, 40.566599676685954, 43.02979715408818, 41.941453180005475, 42.67054334763558, 42.26540173253706, 42.71170077785369, 40.76526772591376, 43.98579251381659, 42.29800055103917, 50.89332172947546, 52.184801332412235, 55.49554847901868, 52.4304711434149, 55.44780146691107, 50.066748895952784, 56.13749142616026, 47.30540813938264, 57.02834406206685, 26.576140696002593, 30.562467075163323, 60.13127619220365, 52.28757919803743, 57.375395374913374, 50.917405082333474, 54.487648394800004, 50.275034596843106, 54.4427921695094, 52.449569163783906, 53.713635321586366, 53.55693663320234, 52.89959838313442, 52.04801651739305, 49.05052946459863, 43.18695475978237, 41.70573442212997, 40.29625815729941, 40.985253857028106, 39.65329539391303, 40.94730492561094, 42.41804076779274, 45.31488372433571, 41.24866062594999, 44.6527680273979, 42.22950420072002, 42.733089462403335, 41.90098608693769, 42.35645955608737, 40.47221176085934, 43.53877567475842, 41.082403121456025, 42.444724652075, 40.560304272559385, 41.95688378426337, 43.58539696662657, 46.61417276628556, 48.29720689404396, 48.48322922183622, 45.561973433340754, 47.59506733186784, 42.38504186753304, 43.055571048490464, 46.36397654010404, 53.589660967549975, 52.198227605512066, 46.05452114535917, 46.822062307788485, 52.766712404066524, 55.22379490637011, 59.669091547689135, 58.56061404751193, 59.0667566945476, 57.376466181970414, 59.17132316097137, 52.02196413470853, 62.516669534867816, 62.13723905624882, 66.46981070118566, 10.422971133262882, 1.4048744665999569, 2.0121397390480964, 0.49030341147895784, 0.4332768376315794, 0.04534697355402093, 13.426770260257106, 54.80511719180692, 35.01180179657475, 59.34808085041662, 42.57671240837344, 14.11959517386652, 33.12186656459686, 51.96386598771619, 54.120475322969504, 52.60594229544363, 6.147243947752061, 0.2213693794704253, 0.0621888151903066, 0.0324766313086354, 0.01568337113806798, 0.034134755842387676, 0.03639407170515868, 0.061258275001760454, 0.02759700746185357, 0.04697199159812543, 0.04871243227934165, 0.04190880925424638, 0.039788342997311585, 0.06868197342320796, 0.013692177430305992, 0.05233653377921832, 0.03423120631205459, 0.034997508740953864, 0.03352200424659156, 0.04390204745915629, 0.012539386516436936, 0.06447689382419472, 0.033974440452913125, 0.05136855870425221, 0.012247417001954973, 0.05201279268329663, 0.05729418751152773, 24.290442236008186, 78.39916613794144, 68.0116081237793, 64.83400583267212, 41.72172200295233, 31.85380155040372, 44.41892416246476, 36.9155006254873, 41.60798111269551, 74.28700031772738, 17.496963777849754, 0.09173856927983223, 0.46917280662925015, 12.311197192438188, 5.060558645955978, 2.187017019717924, 10.133957170671033, 66.03920505892846, 70.13627759871945, 64.73596619021508, 59.91965255429668, 62.31978224169824, 66.42456223887783, 66.61326746786794, 59.343923138033965, 48.95946771867814, 47.28150129318238, 49.081441663926654, 50.85003837462395, 51.67626211720129, 55.37990131685811, 57.28219593724897, 57.29831295628702, 56.87078245224492, 56.01595286400088, 49.349876911409446, 47.22140273740215, 47.802560713983354, 48.64842768638365, 46.11395682058027, 43.5883544337365, 44.99654808352071, 43.27745952913838, 45.06047095021894, 42.60976229944537, 42.74909273270638, 45.32482693272252, 44.78861147357572, 44.249552296053984, 43.98378426028837, 43.276847639391505, 43.614618624410326, 43.579658539064475, 46.36390593744094, 44.39804146366735, 44.75898581166422, 42.686491704756214, 45.57590569219282, 45.54731945837698, 45.24157070344494, 43.48055985666091, 44.17263461697487, 43.050040506547504, 45.79260487710276, 45.04179262345837, 54.530931749651515, 55.819461730218705, 57.37588959355509, 54.58549191874843, 57.55631077674128, 52.76180159661078, 58.63269936653876, 48.90442117567986, 58.06267699887676, 28.207907484423732, 31.805089635233728, 60.24157716381935, 54.73813879874445, 60.638528869998076, 53.94994243498772, 56.888507643053615, 51.52662369512743, 57.08507330186906, 54.34883179203157, 57.024857074983665, 56.79102889953121, 57.44259342070549, 52.68100077106107, 52.941340246508204, 44.650508742178644, 42.70345203338131, 42.567043765898674, 42.6561874728049, 42.07299378610427, 43.36621492139755, 44.59501897135089, 46.18341022922147, 44.39458977791571, 46.489425705325225, 45.1120501179849, 44.994394702296105, 44.223825470093765, 43.49721816278274, 43.505965048267, 44.422289556072606, 42.22531510937599, 45.56904546676144, 43.20733147282755, 44.67880472060173, 46.309216330128336, 49.16429388907648, 50.468117190945534, 50.561704943257, 47.824643658053496, 49.30551882713072, 44.702656653619584, 45.820975380559126, 49.72572234369094, 56.830370272359545, 54.81336201390913, 48.81147669207666, 49.195970950588105, 53.77638932197325, 57.72044627897201, 61.717153210793775, 62.18522141056677, 60.50676076642929, 59.76274598029352, 61.37509507517661, 53.96569467359974, 64.17041140217935, 65.30518447199177, 67.59273036833733, 12.773751520341444, 1.1540080054152397, 2.11403347792164, 1.747986371478727, 0.22358038582869116, 0.12775829212079126, 13.033643845588932, 63.05780364621071, 41.159136449137044, 47.439490441353094, 35.67421167127548, 17.229644444680986, 40.00946229504001, 57.472591707783366, 59.91516536281955, 62.851200642124304, 9.058879633103649, 0.22747606549772525, 0.09140453962308746, 0.10130858559521938, 0.07618629493780675, 0.03477006489711423, 0.0480875764943419, 0.09025426626565958, 0.03927895964513864, 0.02791929107549931, 0.04146132580635529, 0.002894605525896975, 0.0642968784837473, 0.04130505919156056, 0.09373150871045167, 0.1153714930818927, 0.13109864997527293, 0.1689466569692858, 0.07670869029337361, 0.12935507982488603, 0.094462348929336, 0.18693190398475817, 0.11660746869540985, 0.1120625218496688, 0.13751794584095478, 0.15654459745893556, 0.25952506269658765, 29.555935898134788, 90.03507337262555, 76.44288401449882, 76.54010388158983, 43.77233320666898, 39.8726107997279, 54.59277183778825, 39.363589132985766, 55.955152203959805, 76.98299438722673, 22.33805306496159, 0.30376078741204354, 0.5212114739321894, 16.24211911232241, 9.870548440564065, 6.9636220509006135, 13.015416591398179, 67.59354622133317, 72.01940751844838, 67.66447051878899, 61.31203512991629, 64.8736806069651, 69.36226844787598, 69.99406814575195, 62.96139178737518, 52.32918377845518, 49.40738278050577, 51.07124436286188, 54.231776498979144, 54.4922532573823, 57.91506251981182, 61.761009231690444, 61.215988051506784, 59.3084688340464, 58.26185495622697, 51.49791586783625, 49.248828811030236, 49.97895056201566, 50.7979767553268, 49.63085197633313, 45.82647846591088, 46.75902589674919, 43.85548353195191, 46.711529916332616, 45.75566791719007, 44.569048958439986, 47.37868193657168, 47.737304241426536, 46.512457862977065, 44.73113698344077, 46.58045214991416, 47.5558828538464, 47.35519478397985, 49.618943660489975, 46.74883165667134, 46.0458880086099, 45.56433862255466, 46.99635674876552, 48.350664877122455, 48.27597510430121, 44.84357172443021, 46.04187542392362, 43.944317371614524, 47.74756908416749, 46.479227542877204, 56.01275613231044, 57.032611600814334, 60.06032443815663, 58.411383551936, 58.811308414705344, 56.4015140071992, 60.937437011349594, 51.26006726295718, 58.02980361446258, 30.476718179641235, 35.502376556396484, 64.23902542360368, 56.822611824158706, 61.82695996376776, 56.28467836687642, 58.3460957004178, 55.52168715384699, 58.89259561415642, 55.63585166008242, 56.89139058513027, 58.25396706981044, 60.096127833089525, 55.51968674505911, 55.88400433140417, 48.39079072398525, 45.39218579569171, 44.15794534067954, 44.59005717308291, 43.67542320682157, 45.87101305684736, 46.79843002750028, 49.04524210960635, 47.01648635248984, 49.35265394949144, 47.44493076878209, 47.64644253638483, 46.101040455602835, 46.87863857515397, 46.004930619270574, 47.82415728415213, 43.775592696282175, 47.79329607563634, 45.10273056645548, 46.40645973144039, 48.52985835844471, 52.44456814181421, 53.693933256210826, 53.75821698096491, 50.52854130345006, 53.67441946460355, 46.5964005070348, 47.96939872926282, 50.883829593658454, 60.26092229350921, 55.81324869586576, 52.40693300001083, 55.40065849981001, 60.218839183930434, 60.52900060530632, 64.8354688767464, 63.978580044161895, 63.777586029421904, 64.48985315138295, 64.21555003812237, 58.00007989329677, 69.12276068041402, 67.91554927825928, 73.41642241324149, 13.138588820734332, 4.333768948431938, 8.321874122465811, 1.481728407163774, 0.670481315783916, 0.32710440577037875, 17.238575681563347, 68.86732809005245, 49.12223823608891, 72.66480999608194, 52.676290004484116, 23.779131866270497, 49.01751879722842, 65.8212624826739, 68.01787607131466, 70.92245394183745, 12.500046568532145, 0.36035721821169703, 0.201152395757456, 0.28841947836260645, 0.11839016295608976, 0.22245610583453412, 0.09372031616587793, 0.1914887175324463, 0.07533714776077578, 0.11658527512824345, 0.13795781820531816, 0.1754150131056386, 0.12611890226722727, 0.1679714730069522], [0.05498637828314978, 0.014745136553932343, 0.06574877597872289, 0.028339882922028343, 0.01763848689264588, 0.01691586296674946, 0.03971334681996415, 0.004528215006669803, 0.031285519719183925, 0.06005667375340577, 0.039475399910682635, 0.013023255310291726, 0.7587989960466662, 41.5045246770305, 70.7508659362793, 54.18091512495472, 52.88504246742495, 24.197005494948357, 25.423175673330984, 58.74383188063099, 46.00449915855162, 47.15845654087682, 65.02532728256719, 3.58175007566329, 0.05644053956794162, 0.08534230201715425, 8.18340955242034, 8.785801279929377, 1.7482105594488884, 27.432186219000048, 69.35818918289678, 65.5879952061561, 63.153262369094364, 61.15889010890838, 63.218279577070675, 65.62031553637597, 63.767030931288204, 60.60215280902002, 49.37376414575885, 44.85635865119196, 44.37661747778616, 46.19123535771524, 46.14044458635392, 45.47495957343809, 48.7995409196423, 47.804502287218654, 49.93643599171793, 45.03931368550947, 44.45814786418792, 41.824943096407004, 43.21032424126902, 42.96485447114514, 42.584047240595666, 42.24609974891909, 39.99138409091581, 42.9257131391956, 42.987533615481475, 40.95169798020394, 42.954675920547984, 41.21280624020485, 42.74490756373252, 41.48926273469002, 42.30349971402077, 41.88931311330488, 43.28018949877831, 42.02538013458252, 43.12041174980902, 40.818062828433135, 43.25812224418887, 43.43877092484505, 41.25589739891791, 42.116324209397845, 44.175188079957046, 40.17314672470093, 41.448430861196215, 41.10859278709658, 43.367344564007176, 40.977679760225364, 45.894766930610906, 52.89254203919442, 54.89284492308094, 52.034029345358576, 55.403604199809415, 50.92579110976189, 56.10587712257139, 47.302976269875806, 55.360332612068426, 21.836880060934252, 30.94438433647156, 59.69521845540693, 49.46069171351772, 55.759163133559696, 52.06046219794981, 53.99996442179526, 48.29421020323231, 53.32435577146469, 51.27063805057157, 54.2151064257468, 50.34794753597629, 55.18069198054653, 50.58814171821841, 49.77343013209682, 43.620843425873794, 41.00357132573282, 40.160650053331935, 43.38581108277844, 41.89590661756454, 42.91771150404408, 42.11453168622909, 44.41931247711182, 42.059795010474424, 41.852862527293546, 42.56345479719101, 41.865327819701164, 41.652115621874415, 42.51829262702696, 42.419782300149244, 42.728119819395005, 43.01558640695388, 43.06686355221657, 41.11242102038476, 44.442525063791585, 46.08149136266401, 51.251057578671364, 52.17419916583646, 50.73548947611163, 48.786848129764685, 47.75707298709501, 42.39215312465545, 43.04636132332587, 45.6591619214704, 50.53293435804306, 53.28338269264468, 53.86893372381888, 51.626087157957016, 51.65399874410322, 54.108351276766875, 59.39231734122, 58.77507355905349, 58.08353224108296, 56.4050559074648, 56.62758373445081, 49.44479042483915, 60.49300893660515, 59.55216961522257, 69.87851512047553, 27.21628131405, 0.4378524662986879, 3.0375913266212713, 1.278741950950315, 0.1535397554717718, 0.09014221058497507, 3.319367535652653, 47.4326890514743, 34.24392331031061, 60.14367872668851, 88.7675045382592, 25.91833176151399, 29.895974013113207, 49.44965416385282, 51.76379765233686, 58.36333059495496, 15.598811180360856, 0.5251226898643279, 0.07924695409113362, 0.07081351348108823, 0.029418182318970084, 0.020074311328390916, 0.05925264915511493, 0.06654241242476049, 0.021932827226156672, 0.010606843542547957, 0.025753732883341374, 0.06201319336410492, 0.012519946077748412, 0.044674673943870494, 0.03681630489506549, 0.0898319679582792, 0.040472386735341245, 0.03140760540601707, 0.012263279810037104, 0.03769840534415938, 0.08888500667507611, 0.035082808800882874, 0.014066859542752707, 0.08132990119197676, 0.041131007845603654, 0.054227947407672485, 1.0154419440415599, 52.099709433894006, 79.81382385376962, 61.665574043027824, 59.30323639223653, 33.5403089369497, 31.27973718027915, 53.72853248350082, 40.0334789676051, 54.283944022270944, 70.87598954477619, 3.811397739956456, 0.03679492338109882, 0.1800896203325641, 11.834452709844037, 12.564992193252811, 2.001179533620035, 31.484537855271373, 72.64334678649902, 68.18241165530297, 63.367164904071444, 64.50407174325758, 67.4403541318832, 67.34479734974524, 66.1918087928526, 61.629860862608886, 51.955891809155865, 46.65844848079067, 47.06721828829858, 47.93158315843152, 48.11422440313524, 47.1923654310165, 52.06144279049289, 49.34586432672317, 50.64827949770036, 46.44344375979516, 47.02342502532467, 45.88220357894898, 46.140621093011674, 45.129014368980165, 44.515120290940814, 45.40731437744633, 43.01856348591466, 44.43312314248855, 44.263547312828806, 43.20245988907353, 43.51024043175482, 42.95065549112136, 45.35496250275643, 42.9831091819271, 43.05090342798541, 43.755984767790764, 42.492267700933645, 43.324520126465835, 43.0295814237287, 42.97425639244818, 47.161155131555375, 45.48970376291583, 43.03557088298183, 44.93351951722176, 45.13417228575676, 42.412074842760646, 43.95172280649985, 42.024685875062026, 46.44479305513444, 42.801499520578695, 47.938568899708415, 54.06082391738892, 56.34201949642551, 53.44009314813922, 58.975557665671076, 54.33894741919733, 57.84451476989254, 50.68493012459048, 57.7410073434153, 23.934304752657493, 32.113150627382346, 61.987479040699625, 52.145887497932684, 58.43382343169182, 51.24288335923226, 56.61615394776868, 50.68762871526903, 55.614761075665875, 53.64250706088159, 56.82782465411771, 52.34160984716108, 57.184419093593476, 52.20675876063686, 52.32445340002737, 44.21283891124111, 43.7403384331734, 42.35699299843081, 45.03793693357899, 45.239656586800855, 44.22249970897552, 43.85921762835595, 45.78503078030002, 44.96087020443332, 43.62012955450243, 44.3741463845776, 44.15414848635274, 43.097269765792355, 43.98067382074172, 44.05090385867704, 44.42788285593833, 45.171356354990316, 44.81303215026856, 41.81134031664941, 47.258104355104514, 49.45524746371854, 53.10495407350602, 53.87302867827877, 54.62548832739554, 50.7050597283148, 50.452855248605054, 45.53617208234726, 45.87167593740648, 47.17674655299033, 53.78554413395544, 56.55043463553152, 56.9421656670109, 55.40653813269831, 57.52475138633483, 55.047629494820875, 60.578489149770434, 61.344990884104085, 60.30738669057047, 59.13828895938013, 60.62076053311748, 52.59726601262247, 62.302786611741595, 61.79576535378734, 72.112885444395, 30.278189374554543, 0.6257218014328711, 2.9955699943727065, 2.7613383050887816, 0.2993616041156554, 0.030083500952910514, 2.273958806068667, 52.75727518143193, 36.74095515281924, 54.68620661766299, 73.94711909755584, 27.317501998716786, 38.72269345868019, 55.009939439835094, 58.43810273754982, 66.61504037918584, 23.646651852515436, 0.4786190078143151, 0.05030740052461625, 0.03076603741294915, 0.017994202583307223, 0.09554915190223726, 0.0752369434602799, 0.027981204386319847, 0.02781929553396279, 0.03154752561972747, 0.06904620226592788, 0.07028548737927791, 0.04979671865341164, 0.008631947397765134, 0.11118709785683502, 0.15246822829208068, 0.08037530967304785, 0.14667271185786496, 0.11482383980746232, 0.19985818213993506, 0.16376955735106624, 0.18750326768044503, 0.15897481221585505, 0.24761585819144405, 0.14917352927788613, 0.24037274201550793, 1.3474227752416366, 61.19796868293517, 90.08436972095122, 68.49760547760995, 69.76675110478556, 35.63831806182861, 37.36811468678136, 66.90374251334899, 61.53420994358679, 62.112669329489435, 74.79912065690564, 5.494295320203228, 0.22109821498874696, 0.10319665524988406, 13.024447848719936, 18.443969065143218, 4.555645171673068, 33.52558043695266, 76.22887949789725, 72.30711337058776, 66.37993351105722, 66.72649060526203, 69.10940108760711, 70.05099742643296, 69.35044642417662, 65.73028310652703, 54.763167442814, 48.627184129530384, 49.87614131742909, 50.2594510201485, 51.65860360668552, 50.434949628768436, 54.462686431023386, 52.8859563796751, 54.55377563353508, 46.924251817887836, 49.5735030020437, 47.67635845368909, 47.63644049244542, 48.49492180731989, 47.77804590040638, 48.07639314282326, 43.27433732248122, 46.41594402251705, 47.59968788393083, 44.78538728529408, 46.61261166295698, 45.541722236141084, 46.370852455016106, 45.82829844567084, 45.38754955414803, 44.797479952535326, 45.131654124106134, 46.49759992476433, 45.078564843823834, 45.577890411500015, 48.901377416426136, 48.47573749480709, 45.32987894550447, 46.65606760209607, 47.34608311806956, 44.868796487008375, 46.425177281902684, 42.95162039418375, 48.83734472336308, 45.71973900641165, 48.58622281782089, 59.16996209852157, 59.44051934826759, 57.12022558335335, 60.77291711684197, 55.846416258042865, 60.93069053465321, 53.3025356261961, 58.914050978998986, 26.284400686140984, 35.61915336116668, 63.84081071422946, 54.39205631133049, 59.91946428052841, 55.52746480511081, 59.07773540865991, 52.580803825009255, 57.43946336930799, 54.338547337439756, 59.238309398774184, 54.45701468375422, 61.06676932304137, 53.08700922996768, 54.19394131629698, 46.991951927062004, 44.45442553489439, 44.8114396679786, 48.42693144275297, 47.97289748345652, 47.49659622869184, 46.884906522689334, 48.28733821069041, 47.35646563191568, 45.84410951983544, 47.17637392782396, 47.3711274516198, 45.559047345192205, 46.19846428594282, 46.27694306835052, 47.208788394927986, 48.677190426857244, 48.70926364775627, 44.22058559233143, 50.126490516047326, 52.008282907547496, 55.61587895116499, 58.10943949607111, 56.75776720046998, 54.02963715214884, 52.6853036111401, 47.68523477738904, 48.138994170773415, 50.9101761541059, 58.21054250963273, 57.94046771141791, 58.813002878619784, 55.079145739155436, 57.663407171926195, 60.16966442908011, 62.94942855834962, 62.72387266159058, 62.24876380735829, 61.55905815862841, 63.63128162199452, 55.7768726348877, 65.57528672679778, 65.22502299278014, 76.00500629794213, 32.052322510750066, 2.1249950316644486, 8.79699670499371, 3.6495151490934434, 0.28138152053279264, 0.29615715025894107, 4.47478452997823, 59.69930556512649, 46.09978529714769, 68.87911873479044, 94.44695534244661, 40.02787390062886, 42.91138079858596, 64.2188605185478, 66.2787442053518, 76.94951303543584, 28.509814277771984, 0.7087115546868694, 0.18763069874576985, 0.14157347741626924, 0.13350615788611675, 0.21554245343131406, 0.21244954197637497, 0.12912638725772982, 0.0844619290963296, 0.13534291497161313, 0.14933099098984273, 0.15114159383360418, 0.14575014281417095, 0.18435616316574235], [0.07550766361096213, 0.0832756266238228, 0.05227592473308887, 0.07150883020292367, 0.0813757055889695, 0.013198068913733287, 0.01658157092489062, 0.05442265248406799, 0.08906405674473894, 0.06869390907306826, 0.1636868658205194, 0.10137554167980149, 2.0482465047990126, 60.62971530422088, 67.26471039556688, 55.74097510307066, 43.60593057447865, 22.432476282119755, 30.520044680564638, 48.25447267101657, 39.999950547372144, 59.9399390528279, 44.006749737647276, 0.3725415708557252, 0.1606209053387565, 0.9216434256203714, 4.207735840351352, 3.692652885952304, 2.1511104174198645, 45.7520358024105, 65.67160052637901, 63.81066337708504, 60.798506659846154, 62.45018928281723, 64.20517144664642, 65.9570941617412, 59.914992778531975, 61.598470134119836, 57.074365231298636, 50.357102347958474, 44.9582657506389, 45.00093721574353, 43.55739908833658, 43.16158486950783, 43.086283206939704, 45.08737448723086, 43.3011035765371, 41.68758169297249, 42.60581247268185, 42.541901373094134, 43.25233282581453, 44.01439443711312, 42.73885534655663, 42.987894473537324, 42.12232151339131, 41.60453727168422, 42.102760653341974, 40.09229098596881, 41.89917002954791, 42.32390780602732, 44.07958815174718, 42.976056760357274, 41.67874459297427, 41.741831994825795, 42.389438844496205, 41.68860543158747, 42.00369727226996, 42.69024541301113, 43.72377818630588, 41.68104310189524, 41.385586646295366, 42.809320726702296, 41.66088211920954, 41.5095688450721, 43.33250999450684, 40.747534690364716, 41.37331747239636, 39.61579753506569, 42.02979280102638, 45.08763336366223, 54.666269210077104, 50.94739944704118, 55.1344354691044, 52.477147348465465, 58.66692596866239, 50.741400487961315, 59.704745892555486, 23.782134440637407, 29.198292224637925, 61.16680152954594, 47.21400122488699, 55.77500950905585, 47.5615781353366, 53.38361101765787, 52.40933741292646, 54.495042062574825, 51.588632445181574, 52.2693911675484, 52.480657869769686, 51.623537617345015, 48.97640843545237, 49.15467231504379, 44.940893573145715, 40.896702428017896, 39.89609010757939, 41.52272055225988, 39.95545125776722, 41.68474974170808, 41.609757946383574, 43.12992349747689, 41.207930734080655, 43.006521809485655, 41.56464676703177, 43.71373691866475, 41.60912252241566, 42.03053020661877, 41.03871576247677, 42.871243184612645, 42.52458018641318, 41.4533769699835, 42.40144521959367, 49.71003678537185, 53.294000548701135, 50.57018902993972, 52.49287605285645, 52.85840957395492, 48.679896862276145, 44.86553699739518, 43.5217486658404, 42.83730683788177, 41.776717555138376, 48.40046721120035, 54.57914552380962, 58.04956059302054, 58.234869049441436, 56.13872305039437, 56.50333873687252, 58.03536553536692, 59.931611860952074, 58.82329517795194, 56.84573027395434, 54.68310010048651, 50.59033824551491, 59.01092567751485, 61.79131346364176, 61.221471525007686, 49.854917372426684, 3.4345837273905357, 0.8536575350069231, 3.0902944985897314, 0.2077096487365423, 0.04731221890617763, 0.2746932358751374, 34.811764840156805, 55.334766603285274, 50.12788687982867, 45.14255046844483, 17.330669010839156, 20.263350663646577, 43.12778188336281, 51.168134750858435, 55.80838103448191, 34.50933833276072, 0.2679911003478112, 0.03518436141612549, 0.05898540704360893, 0.02404261421742699, 0.05787898455896686, 0.01960241457357282, 0.028512976658079895, 0.07951791938995162, 0.02464262002538289, 0.07545535512749227, 0.02922558589958616, 0.01640280622297958, 0.05726514894875789, 0.07662013819020602, 0.12214978540977164, 0.012462335308232616, 0.0294755278305421, 0.0605558872883839, 0.0756620916147386, 0.03599831834435463, 0.04706499084169346, 0.059835668878569725, 0.02837616867656189, 0.07716032210737467, 0.07815330995306854, 3.306122672173285, 70.44439546523556, 74.90739376314225, 62.23187408139629, 50.67008395348826, 27.356521737190988, 30.59563071497025, 45.586664753575484, 39.9111206300797, 66.4929291509813, 48.72825576413063, 0.4135181123931562, 0.09835167006859857, 2.9542122781276707, 13.628054530389848, 6.211493351767141, 2.5304293536370803, 49.90420195364183, 66.64001803244314, 68.31460337485036, 62.61943955575267, 64.47748591822963, 66.68028508463215, 66.99016017298545, 63.47635584492838, 62.71330971871654, 58.90862634105068, 52.5933789437817, 47.64872535582512, 46.63342768146146, 46.131101500603464, 46.61250183659215, 44.433287882035785, 47.30571800662626, 46.14410023535452, 45.39518640887353, 43.428353109667384, 46.22969811962497, 46.635369254696755, 45.50978237582792, 44.72456309103197, 44.76339063336773, 43.78769320826377, 43.130249054201194, 43.186923380820986, 44.2111248354758, 44.913899821619836, 43.76805390081098, 44.31473424357753, 44.050001713537405, 42.84159791085028, 42.908003637867594, 44.11458353842459, 42.841393947601325, 44.08576196239841, 44.72840309143067, 44.53106472569127, 43.39359698757049, 44.0961915446866, 44.68474711141279, 44.54296127442391, 44.90340355903872, 43.846277729157485, 43.44592140566918, 43.71576478404384, 42.99624127726401, 45.48210613189205, 47.137048244476325, 56.01676087225638, 53.47972085399013, 58.3070759619436, 55.17198824113416, 61.139466531815074, 52.78936801418182, 61.074519926501864, 24.545561036755963, 31.78975512904506, 62.515853681871974, 49.274375207962535, 55.913363272143954, 51.20272613340809, 54.501647333945, 54.359430036237164, 55.12633577469857, 53.95104462100614, 54.83775131164059, 53.295636177062995, 54.10887295199979, 50.794226969442065, 50.40217430360856, 45.59053613293556, 43.269932500777706, 41.97212611475299, 42.47626835300077, 41.87139180398757, 44.989154415745894, 45.610430394449544, 43.93747283566383, 44.163424891810266, 45.070520062600416, 42.224008960108605, 45.04125133637459, 44.171163728160245, 44.790015682097405, 42.55478243674002, 44.61845905550065, 44.07460281925817, 44.90558047448435, 43.856907352324455, 50.72295750341108, 55.66213546260711, 53.173215081614835, 54.63195239343951, 54.43000916511782, 51.71557995580858, 47.53124252442391, 46.089147829240375, 45.83329946764054, 43.91427201609458, 49.94253135496571, 55.96095338944466, 60.072381804066325, 60.791120836811686, 59.20118024272304, 60.81529440418367, 60.89961359577795, 61.48789067422191, 60.8545651743489, 59.60795356381325, 57.31608129316761, 52.2057036430605, 61.04099150626891, 65.60311594317037, 64.32506261333343, 53.51070757835142, 3.9063056149790367, 1.5534010193040295, 3.608201559512846, 0.3672326121839785, 0.05770083081217543, 0.10797337433623691, 38.186364250798384, 59.37812620593656, 53.48767934306976, 47.79872463595483, 20.872565354070357, 28.08064030062768, 49.120520237953436, 57.75557110386511, 62.749701469175285, 44.48938169787007, 0.3532819672217292, 0.0879165489647177, 0.0077435224140513575, 0.022958569161053148, 0.06272764313184927, 0.05532468271051204, 0.039821974257187503, 0.09833106230343543, 0.028522340167734413, 0.07980645874575262, 0.05988888517622987, 0.08855806333163092, 0.038835808424459356, 0.2198199053565341, 0.19438797728188578, 0.14582148092167993, 0.1369538599805486, 0.08238396156699428, 0.13806102557047722, 0.12461014572651156, 0.09917850876527448, 0.33255533585625313, 0.33961937131900943, 0.24164309965506678, 0.30012704852607947, 4.9884934290762875, 80.29031338230257, 84.31439061318675, 71.32693659874701, 56.45264210239534, 32.53488190712468, 41.445543996749386, 59.78988878188595, 53.22269970370878, 73.46708374638712, 52.57171177094983, 0.813736202976396, 0.1802635989001682, 1.6181329974243719, 12.111099439282572, 7.874736180228572, 5.097176913292178, 53.73885616179436, 70.28691230281707, 69.72183996631254, 65.96189514283212, 66.19936327780447, 68.76820979579803, 70.88744286567935, 64.8816155618237, 67.31873712232037, 62.18327983733147, 54.91558290296986, 49.406359041890795, 49.65066779044367, 47.39321824043028, 47.83496733634703, 47.4533324856912, 50.14415687130344, 48.74341572484663, 45.96903308745354, 44.9274084644933, 47.93377576335784, 47.069736449949204, 47.65662500935216, 47.08949735087734, 47.26146190397201, 45.47193542603524, 45.26555207467849, 46.76279921685496, 44.457626188955004, 47.36771891194005, 47.50348391071443, 47.17406757416264, 46.43664629228654, 45.295158124739125, 44.880975446393414, 46.11081892444242, 44.76415157318116, 46.444126252205145, 46.49914533861222, 46.99539184570313, 44.64220508452385, 45.72554803663685, 46.78684726838143, 46.23734281909081, 46.51618019227059, 46.28155577567316, 45.456724474507, 46.80290152949672, 43.82628540838919, 46.90651878233879, 49.8543054826798, 59.781745941408225, 55.70390870494228, 60.65723465334985, 57.833257567497995, 62.274102318671446, 56.6203587285934, 61.958257382915875, 27.850869817118493, 35.2463516881389, 64.18141757288288, 51.23924339971235, 57.462060143870694, 52.575077164557676, 56.51621980051841, 58.17082851163803, 57.83486966163882, 56.14124513441517, 57.01056395807574, 56.40294959468227, 56.17969220684421, 52.40405005793418, 54.42924822530439, 47.80010138788531, 44.80259080086985, 43.55731279619279, 45.7562013595335, 43.428764958535474, 44.45936379894134, 48.67186384816324, 47.035909929583156, 45.89866576656219, 47.1518002786944, 45.3264037255318, 46.9282094893917, 46.45406553822179, 46.93819192148025, 45.17553367922383, 47.18106116017988, 47.16079035112935, 46.61796177587202, 46.23751148100823, 53.14057703941099, 60.19450872175155, 52.588911364155436, 56.79410403774631, 56.89653281242617, 53.84885903327696, 50.483335987214126, 48.786063655730224, 48.48533161224858, 45.49919197636266, 53.27277268132856, 60.81108570098878, 63.26495185975106, 64.93691313651301, 58.933254903362645, 60.93866471321353, 64.34050498470184, 64.39730090479698, 63.09303045272828, 63.026487442754934, 59.7038515921562, 55.03997302824452, 63.93175478904479, 69.75749431117889, 66.39926295126638, 57.77623022756269, 4.847699951741004, 4.97962789189431, 10.7055426028467, 0.7553372592214616, 0.11908244596974504, 0.7329495347315266, 42.685401285848315, 72.73984493747835, 60.32042857139342, 53.66150309962612, 26.14696279648812, 29.68645472680369, 56.53425878094089, 65.40043530925628, 70.98246620547387, 51.06936162517917, 0.6472353889576851, 0.14249895759407552, 0.23840340575383556, 0.14107841607784072, 0.13943796136206196, 0.12654716073865854, 0.1426504744637397, 0.2549691378108917, 0.15313647146667206, 0.20861130357990343, 0.1372545494908287, 0.25915062956271634, 0.18122102494441694], [0.091656306758523, 0.04411013992202859, 0.026130623244229826, 0.04904420580714942, 0.0031963737837354383, 0.02698490321035347, 0.16123144677089107, 0.04736315226182342, 0.08391629829401932, 0.016051132603728726, 0.08840032582802158, 0.25262467893621615, 7.023706878385236, 67.31395967545049, 60.28857108085387, 55.03761960614113, 41.36236621487526, 26.62517228434163, 31.4569910495512, 45.41991303043981, 37.15141157950125, 68.4511959937311, 28.316782674481793, 0.048891302318342274, 0.07320006888720297, 2.6314563712766095, 6.638843426781317, 2.911643775240068, 9.296935143009309, 61.0250666833693, 64.58394688944664, 65.27295435628584, 61.39393814148442, 66.22769847992929, 63.118890639274355, 61.40632498648859, 60.504677987867794, 62.13204583814068, 58.14883578208185, 59.03622104275612, 52.41962186751827, 49.79604259614022, 45.90369816749327, 43.26260943566599, 43.50744770419213, 43.40940413936492, 44.63722759677518, 43.689335853822776, 44.53730521663543, 43.84312414353894, 41.87068577735655, 42.727296121658824, 41.56898098607218, 41.06344238404305, 40.49824845406317, 41.52501513881069, 43.00217582333473, 42.64024696042461, 43.23199925884124, 43.25167778999575, 41.30396604537964, 41.76609969908192, 43.399739419260335, 40.68338432619649, 43.637211476602864, 41.3721642955657, 42.94662721695439, 42.15240609261298, 42.99082056168587, 42.587969610767985, 42.16946448049238, 41.91525566962458, 41.67961928152269, 42.227342974755075, 42.712877488905384, 40.339702329327984, 43.60093739724929, 40.995401028663885, 42.21425010311989, 40.02761502419749, 44.212093660908366, 47.75949308949132, 53.28749725895544, 52.494052763908144, 60.745017297806285, 49.441605460259225, 64.23610718019548, 28.41643637226474, 27.764426662075905, 60.190723634535274, 50.44114305127052, 56.60566945229807, 49.05711904648812, 53.96686353991109, 52.0134682809153, 58.92340583185996, 51.573829420151256, 54.55628987281553, 51.86199811197097, 54.10798257397067, 48.566724715694306, 48.13837051391602, 42.4662898432824, 41.44013504828177, 38.58626165697652, 42.02698046161283, 41.17322168042583, 42.28464488060244, 42.171774756523874, 42.44599942238101, 40.38326025009155, 40.83112824347712, 40.33114763998216, 43.69398778484714, 42.45560922930318, 43.10178441386069, 40.68969934217392, 42.187393634550034, 41.55921820671328, 41.34346431301486, 46.211717974755075, 52.24225228832614, 53.48601233574652, 55.51408167808287, 52.80114689180928, 50.92124508273218, 47.591046902441214, 42.98613725170013, 41.21997633287984, 44.155293818443056, 43.92059879918253, 44.060168497024044, 47.17180044420304, 55.439701772505245, 57.38040031925325, 58.79355576730544, 59.02639550547446, 59.311438068266845, 57.28513771487821, 58.14094397329516, 55.72833722637546, 48.93150121934953, 49.84402887282833, 58.590561343777566, 61.958759446297925, 62.07180215466408, 58.481613589871316, 12.609653280627343, 1.7231634066950892, 2.640171877799496, 1.0279476858915821, 0.17074725470475613, 0.08810008064873757, 20.888207766317553, 54.538525458305116, 32.7566703673332, 30.625022995856504, 16.467292577989642, 16.97191530658353, 39.45048139941308, 52.31939354250508, 59.27520713498516, 45.35406427998697, 0.8827525124915185, 0.0773558200847718, 0.020389112178236246, 0.05461520868383589, 0.06233581597165716, 0.009128894270097297, 0.056930621334862326, 0.06758907239042944, 0.02351474133320153, 0.041405221357220606, 0.03911014451014419, 0.06780794371039638, 0.034374231097078135, 0.12490617742221202, 0.049381571776804425, 0.05933603016479362, 0.01969919829148679, 0.017624279792090098, 0.055868693236862464, 0.047428139500440135, 0.03898935925756251, 0.08836109446541918, 0.10651599165172347, 0.12422413700410437, 0.32433392540101086, 10.936649633992104, 79.15244164005404, 65.79697908893709, 61.48115596463604, 48.724149042560214, 34.62254185830393, 29.277741793663274, 43.59540685530632, 38.308287205234656, 76.77018227115755, 30.54349457063983, 0.05222540506492219, 0.06420318976104741, 2.1643467007144808, 9.841191461009364, 4.099453663633716, 11.379210660534522, 61.55115850510136, 68.47575003100981, 66.40974352436682, 63.67327451705933, 66.08545764800041, 64.4119627245011, 63.92178412406676, 64.5004710074394, 61.837581742194395, 62.051354838955795, 61.349980138963275, 54.87178571762578, 52.33606361573743, 47.345173128189586, 44.7979937830279, 45.69460838071762, 44.57813709012924, 45.82373672916044, 45.355750899161066, 46.77160493789181, 45.31819812713131, 41.62010515889814, 44.93958350150816, 43.310101493712395, 44.10246341459213, 42.83039954400832, 44.99363376248268, 44.68120128877702, 44.09459906239664, 45.540329794729914, 43.82867413182413, 43.207496212374785, 43.80453194341352, 44.64229137666764, 43.85197301064768, 44.66571184896654, 44.862677589539565, 45.88363916643205, 44.23850297927857, 46.08291518303656, 44.27823266675396, 43.58741306489514, 44.2703918487795, 44.028361997296734, 42.73067328237718, 44.13706264188213, 42.076465083706765, 45.43060148915937, 43.825242057923354, 44.935347341722064, 42.48083399188134, 47.38000769768992, 49.13484865619291, 56.085723984626036, 54.288646944107555, 62.05694421645134, 52.15778404666532, 64.41427692290276, 29.64682309858261, 29.29581999778748, 61.51609643813103, 54.866529741594874, 59.937138480524865, 51.96071632446782, 58.17601388500583, 54.93492411028955, 59.722894699342795, 54.36014390760853, 56.53348999638712, 54.196282971289854, 56.12024868688276, 51.27014775430003, 50.484351881088756, 45.23510663740097, 43.614618624410326, 41.38114260089013, 43.645373928931456, 43.628013518548784, 43.87990813101492, 42.9179625357351, 45.315872161619126, 41.52749015438942, 43.6048597674216, 42.10068179715065, 44.90435669499059, 45.51708975145894, 44.4045369086727, 42.506498059918805, 44.493049113981186, 44.176298110715805, 42.99969688538582, 47.58370814784881, 56.786157315777196, 56.13591463335099, 57.35433616945821, 55.570352000574914, 53.60600156168784, 48.238367419089045, 45.10497416219404, 44.30268864477835, 46.11800078422793, 45.17789886843774, 45.8306126440725, 49.59780600763137, 57.27719491527927, 58.8629581851344, 60.55580608306393, 61.06325487936697, 60.44861555099488, 60.310301011608495, 60.36660271306192, 56.54422160117858, 51.20989622608308, 52.42518378842262, 60.39513795606552, 64.41993690306141, 65.44660160618444, 61.42629377303585, 15.304392191671557, 0.6776139620811709, 2.3400936443959517, 1.2154285225176042, 0.11940896030395262, 0.04558734896202241, 21.975812373622773, 62.001117121788766, 38.736378608211396, 35.63348962414649, 20.664287497920377, 24.837683477709373, 43.624377481399044, 59.59209542120657, 64.2409199283969, 56.91008460137152, 2.639368772506714, 0.08818673285385294, 0.020438413766603318, 0.09194077818744606, 0.0390066115576173, 0.01964931639151708, 0.049929895378168554, 0.05286030043216963, 0.06291035127135054, 0.05148917924793017, 0.04633118586254217, 0.038361224616246845, 0.04041166277602315, 0.2498658737468143, 0.18965560702546952, 0.22444111625513724, 0.19148862560189542, 0.1295383586998909, 0.12405529122559295, 0.23445529502726373, 0.39927221714488925, 0.33991695051231696, 0.173048751368638, 0.3812029609276403, 0.6887859142115039, 15.417205441382626, 88.37463994180003, 73.25034141540527, 70.54264299331173, 53.81614646603985, 38.669184484789454, 41.351014875596576, 58.49638523594026, 50.01828016773347, 82.3152526732414, 35.821335854068884, 0.27853550389409065, 0.1891556274025671, 4.660822056954907, 11.587120794480848, 6.415272249329475, 12.911816008629339, 66.5629905269992, 68.47229050051781, 70.2242563616845, 66.27694775981288, 69.19020975789716, 65.79559449226626, 68.54544270423152, 65.07940107776274, 65.20497183645925, 64.54721781515306, 64.03327357384467, 55.67534992771765, 56.26697278791859, 51.2137479935923, 47.869252774023245, 48.34461658231674, 47.90234581116707, 48.00539824270433, 48.99703618018858, 47.9270802774737, 48.58181799611738, 44.16395441178353, 45.296781985990464, 45.18670851184476, 46.250631809234626, 44.55296331836332, 46.710059027518, 46.53601169586182, 46.486040699866514, 48.71493147265527, 47.156648328227384, 47.340787918336936, 47.15016857270272, 48.51160757003292, 46.927409325876546, 48.33062156554192, 46.65432999210973, 48.3175326162769, 47.68559955781507, 47.54339794958792, 47.904071654042895, 44.221915275819846, 45.144950958990286, 46.81040502363636, 45.63780069351197, 47.29798309264645, 43.41839421179987, 49.35955339862455, 46.554093822356194, 46.96949243545533, 45.093411014926055, 49.18322716989825, 51.30452732886038, 58.576170167615345, 56.62990969996299, 66.60138268624583, 54.35840237525202, 66.23054612067439, 32.96631320830315, 32.8809702780939, 63.20836774764523, 56.91826666555097, 60.409693871774984, 55.14060927975563, 60.70225954055787, 55.71891569322156, 62.163620918027824, 56.92351871921171, 57.12860768841159, 57.09103922690115, 58.188502711634484, 54.616490410220244, 53.79861347136959, 46.74856493549962, 46.18173145478772, 42.8531139896762, 45.153615474700935, 45.985942425266394, 46.23383622015677, 46.27379732747232, 46.744952432570926, 44.24240181522985, 45.31922578811646, 43.30170369917347, 48.78738549447829, 47.350558542436175, 46.643155159488806, 44.64838673991542, 46.30991058964884, 45.199703324225645, 45.452790337224165, 50.45429083608812, 59.186236012366514, 59.237371952303, 61.093539499467425, 60.92583464037988, 56.9841036488933, 51.793670423569225, 48.12111992989817, 46.37858344662575, 49.06135520627422, 48.7740808148538, 49.428645949209894, 51.78157775632797, 60.11942278954291, 62.98653810254989, 64.17966427341585, 64.12662206157562, 62.730411252667835, 63.01760327431464, 65.48009080271568, 60.533275988794145, 55.08642565819525, 55.51992600963962, 63.63682785341817, 69.02361100719821, 67.87874960130262, 66.04491602989935, 16.058605140255345, 4.351976590771829, 7.736948219037826, 1.6231964095946283, 0.4853960973841529, 0.14949782961799254, 26.055897128197458, 67.5621437257336, 44.0281972577495, 43.85859397149856, 21.4196143996331, 27.32855719904746, 53.0970936436807, 69.64741691466301, 72.89521786474413, 69.14445138746693, 4.477106082823969, 0.45603694213974866, 0.24085462664163884, 0.3019435042815824, 0.16921480306454245, 0.1706567797208986, 0.1435558065291374, 0.22869101965860014, 0.23257936020531964, 0.17550553405477157, 0.1876588601378664, 0.19804100626178328, 0.09490658799486776], [0.004642705889343615, 0.03361647820941383, 0.05061439876895278, 0.06901436365179478, 0.06761720313900901, 0.03690417901042008, 0.07805696673571103, 0.012644174895549734, 0.05964694694886285, 0.01211426996310512, 0.16950266826297009, 0.10113834553668577, 17.506783431576146, 70.12004683094641, 57.39325392630793, 56.63576972100043, 30.67118144804432, 16.652306856647616, 29.151039431172034, 42.80044048063217, 41.306696015019575, 64.67078032032137, 12.864037617560356, 0.08197421944069286, 0.06786983595379899, 8.69973369183079, 15.13447609639937, 3.763825273321521, 19.28607644573335, 57.22131290743428, 66.86591517540717, 62.378927661526596, 64.21841729071834, 62.73213317317348, 63.38569418076546, 59.04812151385892, 60.09681424786968, 60.27871808698101, 62.59166133019232, 61.80557127921813, 58.88433510257352, 55.24508945403561, 50.98263802066926, 46.82086598488593, 42.890674606446304, 42.66963728012578, 41.798255289754565, 42.34400603079027, 43.37986476959721, 43.45888483908869, 41.59827324651903, 42.76260529795001, 42.75963998609974, 41.72274966393748, 43.19725098148469, 41.31355231808078, 40.41547859868696, 41.965767952703665, 42.37637342945222, 43.34615592033633, 42.52311714233891, 41.72292617059524, 41.16358441691245, 41.938028950845045, 43.189331716106786, 42.20902550605036, 43.56030948700444, 43.04456095541678, 42.2010434827497, 42.34074261880691, 42.57049545165032, 40.83010842723232, 39.64149298206453, 43.75859706632553, 44.1885555175043, 42.087573236034764, 43.68201671108123, 41.69354761800459, 42.64848786015665, 40.59078501116845, 42.336039696970296, 42.157363968510786, 48.64382282380135, 46.42671092864006, 54.00597349289925, 49.474302338015654, 63.535356137060354, 36.311989061294064, 26.243031447933568, 62.70608471285913, 47.59189413439843, 55.95637598345357, 50.52137121077507, 55.5304418840716, 52.850125528151, 57.197198175614886, 52.584169218617106, 54.149999003256525, 53.2128349427254, 55.342344622458185, 50.263467527204945, 47.697817740901826, 42.80186430100472, 39.74815007179014, 39.01142697180472, 40.94110758073869, 41.15744982996295, 44.37311087885211, 41.520210235349595, 44.13724699328023, 40.79034736079555, 42.698772645765736, 39.962440921414284, 43.81416528455673, 43.18059267536287, 42.72595467105989, 42.228378480480565, 43.20873568134923, 42.14455742989817, 43.34378680875225, 49.751672744750984, 53.7057670470207, 54.45841496990573, 55.01109261666575, 54.29696629124304, 47.98452338864727, 43.590550961032996, 42.58206252128848, 42.659137095174486, 43.220424344462735, 41.93539311808925, 43.96965196055751, 44.982521687784505, 46.44573834634597, 53.01319414569486, 54.79806084786692, 54.88597685290922, 55.1516507517907, 56.30677307805708, 50.694171228716456, 48.62261456827964, 46.307510099103375, 49.81893354846586, 55.60858334264448, 60.440158920903365, 57.18478779638968, 64.88034471388787, 28.119187393496116, 1.9794150369782604, 1.5056994821756118, 0.7437222018357247, 0.11012578262917458, 0.04275039131302507, 6.109717161424699, 59.97841358184815, 42.3110032081604, 36.33019278126378, 29.356332363620883, 21.22410189720892, 37.68841543505269, 46.69055308065107, 54.01344168570734, 49.459593449869466, 5.098814993135391, 0.14502933068621546, 0.0764731795436913, 0.044516940270700765, 0.017299808997420535, 0.009709839810497098, 0.03644514678707046, 0.0327286435922067, 0.027320419077671347, 0.02302387624137825, 0.0031457279504637325, 0.04720984274641641, 0.031087068472838694, 0.05217727942151889, 0.0396205046244206, 0.057848988386291655, 0.029517208759282387, 0.05397292439855876, 0.041097989456067165, 0.10502289394818007, 0.025060339042195873, 0.07746639721576246, 0.029154067761414958, 0.0790983330338232, 0.0930569299887265, 24.27601379732932, 77.59031065048711, 63.76015109400596, 62.27645181840467, 39.81183367390787, 24.509273229106782, 29.043378214682306, 46.37688898271131, 45.53286160192182, 70.24276210415748, 13.35010459346156, 0.10124640223840553, 0.04556201060392684, 6.787133534108439, 11.938726959689973, 3.9990784948871987, 21.570633496007613, 60.97017311280774, 66.52212727454402, 64.33700623050814, 66.04723022830102, 65.03393296272525, 63.498681975949204, 60.27639996620917, 62.071684483558904, 62.62181651207709, 63.53530514624811, 63.23395729064942, 61.81809148480816, 58.32544834383073, 52.40133970014511, 48.276963541584635, 43.928875000246116, 45.543251960508286, 44.01723815548805, 44.9523429716787, 45.5902890236147, 45.38672585641184, 42.78455095906412, 44.28143724318474, 44.40957323197396, 43.18463663901053, 43.64307149764031, 43.71213659163445, 43.4996735665106, 43.28917564884309, 45.28825867560602, 46.14864626238423, 45.01856826966809, 44.26439454478603, 44.62502902553928, 44.724319904081284, 44.62030256948164, 44.02070553072038, 44.94370591255927, 44.06504792551841, 43.73823996513121, 43.67521532120244, 43.61814091282506, 42.026062626992505, 41.9327651300738, 44.88636086064, 46.021208455485684, 43.90810997255387, 44.70599459063622, 44.07457536266696, 44.67534519010975, 41.951149279071444, 43.88688602755147, 44.03548502152966, 51.29629427386869, 48.736802608736106, 56.76768295226559, 51.43860178609049, 65.41105708768292, 37.47030419688071, 27.9979645821356, 63.32814908796742, 49.310712045238866, 56.643230069068174, 52.28583766568092, 58.86875544824908, 55.875210377477835, 59.358239789162916, 55.607449777664684, 56.11749910539197, 53.846866469229425, 56.54616317441387, 51.986321556952696, 49.63973614477342, 44.707414488638605, 42.579520825416814, 40.47895039281538, 43.534767012442316, 41.037154659148186, 44.26562616902013, 43.37525598464474, 45.97111978838521, 42.984360418012066, 43.05063278444352, 42.29443511655254, 44.63384651368664, 45.037948700689505, 43.296890950972035, 42.98377990722657, 44.080113749350275, 43.35047444989605, 46.2303178541122, 51.787359329961966, 56.44031409294375, 56.29642978791268, 57.52002885264736, 58.362075436499815, 52.00876535907869, 45.73642476912468, 43.885164107045824, 43.675501654225016, 43.949843991187315, 44.769384014991026, 45.23706782248713, 46.36041502798758, 47.64407342480075, 53.06143929881435, 56.82834240698046, 57.18726281196841, 57.31466139516523, 58.866433405107074, 52.41414623875772, 51.007647052887954, 48.890073145589525, 52.561046846451305, 57.972329124327636, 63.36164220686882, 61.65035916912941, 66.91169708005845, 30.755730098293675, 2.126693908245333, 1.478694944131759, 2.7963655610238356, 0.3516307413097351, 0.12384890713879179, 6.504681206518605, 66.74067389580512, 47.18147300904798, 42.3282184908467, 26.360602532663655, 22.936224322165213, 41.11954404461769, 53.09722308189639, 59.79713339959422, 60.499437701317575, 9.430641878035761, 0.5237388899249416, 0.08616131895612325, 0.05653995096743588, 0.037852944430684855, 0.04932125001364658, 0.027505896625018893, 0.06526832393701039, 0.04595639649778605, 0.031643434082187956, 0.06674667444801138, 0.050344594093340064, 0.047504767445066286, 0.15230981663109797, 0.13065761315726465, 0.23403598446278806, 0.11182487371467775, 0.1718287103839459, 0.1436470629226777, 0.24442042885047777, 0.1124571720438619, 0.16629420010553253, 0.26110905673234697, 0.198183958268454, 0.23044960513230295, 30.026128061356086, 88.32496704593783, 70.39789184447258, 73.16459055869811, 43.32634402859596, 26.25864640358956, 40.69533971048171, 60.77197182563044, 52.17953358927081, 75.04181338894752, 16.55693050353758, 0.34821607292659823, 0.26951261225246614, 17.129139592570645, 28.9318593471281, 8.573893270184918, 23.429493750295332, 61.05075036325763, 68.65320590234572, 64.699339097546, 67.30577761127104, 65.89600716867756, 64.79422907675466, 62.051413674508375, 64.80593342934885, 64.4986431829391, 67.87704729264783, 66.29066821067565, 64.82568648553664, 60.37744806658838, 56.957560969937234, 50.779945619644664, 46.879972181012555, 47.78589456312118, 45.72956846606347, 47.87207688054731, 48.458647727966316, 47.50404480964907, 44.1358349400182, 47.65559734836702, 46.73849621126729, 46.22912545357981, 48.88594288979807, 45.00331417206795, 45.49506956531156, 47.15488326164984, 47.679080578588675, 48.008312563742365, 47.117408937023534, 46.27837081109324, 45.84276806923651, 45.96455374071675, 46.14764605799029, 47.07213301812449, 47.13402801944364, 47.02701007166217, 45.46132149234895, 46.479478574568226, 46.74006123696604, 45.91695185630552, 41.802373778435495, 49.163148556986165, 46.80161891445037, 46.95428148392708, 47.318704974266794, 45.55079860071982, 47.21245188866892, 45.73282795567667, 46.26294412920552, 48.493093982819595, 52.35691493557346, 50.900585959034586, 58.50091165111911, 54.774287362252515, 68.25313983425018, 41.488654767313314, 31.039782262617546, 67.33803518356817, 51.65421055209253, 60.09519430898852, 55.14922672702421, 62.45613167362829, 57.57931155543174, 62.26741075515748, 57.766918520773615, 58.457459634350194, 58.177978992462165, 58.26466729564052, 54.214569061033195, 53.18552740158574, 46.12208789394748, 43.81119997270646, 44.0114644265944, 45.69729128191548, 44.64107151954405, 46.60009930210729, 46.39613605314686, 48.80010181857694, 45.9911552552254, 46.37216252665366, 43.54603598194738, 46.372205672725556, 48.33273964543497, 46.52001627029912, 45.62114630976031, 47.89199075391216, 46.1562595828887, 48.45031661372031, 54.912648970080966, 60.250088707093276, 57.940118620472575, 59.445720411116085, 59.77144971970589, 53.92148171701739, 48.9877244733995, 46.2147185879369, 46.6544202066237, 46.72383439156317, 46.72486989728866, 47.17262414193923, 50.11382910513109, 51.21188879013062, 58.89077955676664, 60.316784689503336, 59.82155015391689, 60.55646111888271, 62.7725806543904, 55.34551389755742, 52.90300300044399, 51.66674644716325, 54.887388906171246, 60.91482846967636, 66.4266332503288, 63.46047809047084, 71.43405652815296, 32.870493627363636, 4.309260999002765, 6.674642409047773, 4.4311917981793805, 0.4849488858974749, 0.18613328796721276, 7.842632070664437, 73.42704419166812, 54.25050581655195, 52.71618050913657, 38.165575688885106, 31.02135300636292, 50.32225208897745, 63.48909570324806, 68.52892952580606, 70.42388146923435, 13.155515809212963, 0.6578716311243273, 0.25253438781346044, 0.15188745703668366, 0.18098228130369418, 0.12541862895652173, 0.12946971722187536, 0.17678758219605495, 0.1179055663787069, 0.09308926656001038, 0.1643689138995063, 0.131382332333634, 0.15289454090018428], [0.034578466307251685, 0.034652926223052126, 0.06865280845593061, 0.04096689649046429, 0.049232326357835726, 0.03480184605465301, 0.08003381065904133, 0.03597712069148979, 0.029061078093945984, 0.05555536327583175, 0.03388742435603373, 0.08534831580735984, 26.686563261093635, 65.49681186676025, 53.58770370483399, 41.82821827550089, 21.201569841754054, 23.81043238024558, 42.74477812551683, 40.23471616929577, 52.383073222252634, 56.84887209246236, 4.123790254515987, 0.03471460779227557, 0.03743902712519612, 0.5677705594608861, 5.204171326852614, 7.731242151029649, 34.3123725921877, 63.708768044748616, 63.53059045730099, 62.5995139152773, 66.4671277999878, 65.85619511142855, 64.38891487736856, 64.31122056899532, 65.37511640979399, 58.772535785552, 60.202400530538256, 60.53835938053747, 57.23136594218593, 58.78087082216817, 59.27076308957992, 51.08776538602768, 46.874139616566325, 43.24178557242117, 42.702655792236335, 42.92208102441604, 42.43181613183791, 43.12873894168485, 44.85389932509392, 42.77989902803975, 43.152406523304606, 43.24350357055665, 43.14885285592849, 41.17782262063796, 42.08033646306684, 40.105921222317605, 42.85964473601311, 44.08362034828433, 43.76203698496665, 42.803315577968476, 43.40492871499831, 41.19286883261896, 41.232214127817464, 41.714732339305264, 42.022230471334154, 40.69584177386376, 43.05269987352433, 41.654112108292125, 43.84017452116936, 39.762509868990996, 42.773415350144916, 46.749039542290475, 48.35763885128883, 47.459027767181404, 48.77155873083299, 47.40175331792524, 46.66062147386613, 44.372153820530066, 48.16548978128741, 49.76800941651868, 50.71894099635463, 48.582202388394265, 50.55958294099378, 49.34287940302203, 60.661490424986816, 42.09708106133246, 32.2719987746208, 60.04948300700034, 49.81076325139692, 57.121751385350386, 52.02628266426825, 54.75561295786212, 50.822091487146196, 50.34550782172911, 50.80933201697565, 52.29806369350803, 52.88469337647962, 53.83705269905829, 49.775983595079, 47.668596083118075, 40.83725498568627, 42.44272816565729, 40.28355360031128, 42.586126096787, 43.37691122485746, 43.59974891908708, 41.36425679729831, 41.837208347935835, 40.45297253516413, 41.486619057193884, 41.95255348759313, 42.469592478967485, 41.99052595323132, 42.236917480345696, 41.64112906302176, 43.009106651429214, 42.8511724164409, 46.9569290837934, 51.70136528630411, 54.911652688057195, 51.12685572716498, 56.52291136403238, 52.83425169606363, 48.19486833387806, 42.587314574949204, 42.56299980225102, 41.83399200439453, 42.571499578414425, 43.59671692694388, 41.64560840975854, 42.52059113594794, 45.02092561414165, 45.23149805684244, 46.27148312907065, 46.27767655157274, 47.00623719922958, 44.93761839405183, 42.01436219676849, 43.36179441021335, 46.095568749212454, 47.55047390537877, 54.61343096148584, 59.77217928055794, 62.506173272286695, 62.16548796622985, 45.545942706446496, 5.977558291727497, 0.7750119292928327, 2.097177092106112, 0.21873978267033256, 0.0648635613822168, 0.8226966124869163, 39.854811083885934, 51.560622799781065, 37.01557990043394, 41.026297538511216, 20.174571737166374, 32.01560324238193, 49.86012628001552, 49.30392242247059, 57.29678715428999, 13.442535246572188, 0.2490959707046709, 0.04208786315434883, 0.11596194768865263, 0.057804321629866484, 0.08802053773955953, 0.04170173951875299, 0.1270082230950075, 0.03654172366124488, 0.02507840914110984, 0.04630768611546486, 0.0654429153749539, 0.055635492242271864, 0.040592329291206215, 0.04974863131440455, 0.015470699384628285, 0.02576320939096472, 0.0919951934127077, 0.01465387441473262, 0.039042441489835905, 0.009614906194920262, 0.045946418202572295, 0.028737524689565745, 0.05364184034988285, 0.06491115842495235, 34.67025749145016, 74.93470130428192, 57.7546650363553, 50.91386710443805, 28.796151222721225, 19.29145597642468, 45.480282229761926, 46.51356004899549, 55.81922638800837, 65.64696804169687, 4.721772257358798, 0.13270561132700215, 0.04527785327105273, 4.018566300792079, 9.461821779128044, 4.655215028793582, 37.66661490163496, 66.07418475612518, 64.85997192321285, 62.77427904067501, 66.83317122920867, 65.26456832885742, 65.2965513352425, 65.26338769543555, 64.93599922426286, 59.930003689181426, 62.46429020358671, 61.77281556590911, 59.79479566697152, 60.60427873365341, 61.50130125784106, 54.86468622761389, 48.8077582851533, 45.08259704036098, 46.44009013329783, 44.64269145842522, 44.2369967891324, 44.91959902548021, 46.070253772120324, 44.24163303067608, 44.65529403378887, 44.98834248512022, 43.24663754432432, 42.966533245578894, 43.76293128536594, 42.78494711845152, 44.44860865992885, 46.575768839928415, 46.77923002550679, 45.24583824219243, 45.84199928468274, 42.57399028347385, 43.418923731773134, 44.26605370736892, 44.543969323558194, 43.567871816696666, 44.49646549840128, 43.65089662613408, 44.941281887792776, 41.85399216990317, 45.212898177485314, 48.90678244252359, 49.15478214140862, 47.693346238905384, 49.3264485943702, 48.61133775403423, 48.672926810479936, 47.312354656957815, 50.209248604313025, 50.31262267020441, 53.06018806272938, 50.69093135095412, 53.951032853895626, 52.46897705139653, 60.57331554351315, 43.257628025547156, 33.43990410527876, 63.25780922366727, 52.05324503683275, 57.889465132067286, 54.24974095436835, 56.373167037963874, 50.822981865175315, 52.65432473151915, 51.91851554378387, 54.879791275147475, 54.562149893852975, 56.43978065060031, 52.481034417306226, 50.917758095648985, 43.384002870129, 43.32928972859537, 41.82937537470172, 44.38567815288421, 44.81507178275816, 44.427514153142134, 43.17423843568371, 43.215964609576815, 41.36816740036011, 43.44747466425742, 44.53256699346727, 44.41288763476957, 44.0055416476342, 46.19059601137715, 43.68965356580673, 43.735925766729544, 44.87125189073625, 49.984226149897424, 54.90655752920336, 57.4252643892842, 53.38417191659251, 58.04121771166402, 56.554262868819706, 48.573930109700854, 45.054854116132184, 44.182675884615996, 44.741221397153794, 45.32456413392098, 44.83274990512479, 44.73732648357269, 46.8800937744879, 46.785156726837165, 47.45784321138936, 48.39418749655447, 48.492274207453576, 48.966771171938994, 46.76063799089002, 44.36373641414028, 44.79390275093817, 46.36540428284676, 49.222929400782434, 56.07669861085954, 63.7829282975966, 64.7417869875508, 63.486487327083466, 49.5961860687502, 7.1526989244645645, 1.2030522188832684, 2.9517630031031947, 0.42454030965605094, 0.08215329249299343, 0.7733422866271389, 44.0047061827875, 56.77826942936067, 40.33371679244503, 37.27604489172659, 25.59069618102043, 41.90563801796206, 55.02162810294859, 55.143645194269, 66.16308135371055, 20.50295452917776, 0.290487639966511, 0.048518730778126955, 0.1449157811340786, 0.07360478547672111, 0.06142480719474055, 0.08400157920175022, 0.08574101247734602, 0.008335443600381335, 0.03447769510169183, 0.019955820509142453, 0.032888288654747515, 0.04743724828585983, 0.16336353075119758, 0.13810624007976827, 0.17123606476572253, 0.11457356654347912, 0.230516622503919, 0.1192967207621663, 0.16357716202976244, 0.1341299066740659, 0.09598815092636694, 0.23699893676225217, 0.15637636455076356, 0.19486073013995925, 41.110432378707394, 86.59466835760301, 66.77588109047183, 57.97317635628485, 29.70539781355089, 35.32164158359651, 54.39295453409995, 55.74414437816989, 63.064373616249334, 70.86358701029133, 6.191301480416329, 0.21224173296603466, 0.22961921178765837, 5.6065726760895025, 15.788354815975314, 12.263800251868464, 38.92743725930491, 65.43862350525396, 66.10632465731713, 63.34434063203874, 68.86855186954622, 69.61862671759822, 67.00400613969373, 64.70232009887695, 66.37281048682429, 60.50676076642929, 63.70392783995598, 63.687014579772956, 61.49318587395453, 61.60949983904439, 64.23496184810516, 57.47341148314938, 51.35882862152592, 47.51586291097826, 48.40125952997516, 45.56085948021182, 45.12880648336103, 47.56573584771926, 48.50209974473523, 47.51724750764909, 46.65171769357497, 48.08993316465809, 47.294672612221014, 45.57840031962241, 46.539847773890344, 44.770721543219786, 47.30145831261912, 49.4750750449396, 48.24941281349429, 48.63241264897008, 47.57183905570738, 43.85616210199172, 45.54743712948215, 46.91818391123126, 46.703559660142474, 45.17801653954291, 46.67061959543536, 44.92200736076602, 47.7377200126648, 43.639882610690215, 45.66071518005864, 53.228214556171054, 53.77144713555613, 50.649499354823945, 52.64839410781861, 52.25052848938973, 52.123082837750836, 50.56107344165925, 54.00192560688142, 54.240546918684444, 54.68726173523934, 53.21389398267193, 56.151721785145426, 54.76017075200235, 62.96146239003828, 46.437493524243756, 37.00563669204712, 62.992111790564756, 55.53126165943762, 61.47521357382498, 57.27515920515984, 59.08986729960288, 54.821634292602546, 53.643111105888124, 54.074501222179784, 57.4320226330911, 57.06939951066048, 57.81727783141598, 54.69408665933917, 53.623852268342056, 46.17783261883644, 46.585594377210064, 44.040878280516594, 48.00600621008104, 47.242293280939904, 47.96819063924974, 46.53657259479646, 46.08294656199794, 44.13943959820656, 45.86962061543619, 47.02149521919989, 46.079824355340776, 47.46411115892472, 47.58750500217561, 44.975696763684674, 45.241794278544766, 47.67160061867007, 53.05320624382266, 58.127011714443086, 59.21491638306649, 54.9461381666122, 61.27134838411885, 59.168302935938684, 52.113543633491766, 46.76110475294052, 46.63119193046324, 47.416309233634706, 46.353433209080855, 48.943468370745265, 46.449954894281205, 48.86327159020209, 50.17763822309433, 50.93383981335548, 51.00934543917256, 52.3754834359692, 51.871615763633486, 49.218987418759255, 45.85823397482596, 47.461220372107725, 49.50756403707689, 51.13592816937355, 58.157496375422326, 67.04584213995165, 66.6064582332488, 67.23761466241652, 53.87608812701318, 8.306618063680588, 4.55354425214952, 7.069413277410693, 0.3760400186142614, 0.2525322427672725, 1.2984386230668714, 49.98969001154746, 63.81462497095909, 50.80289148515271, 58.45367062476374, 32.0105767250061, 46.30630985383065, 68.12542746143957, 63.66984244315856, 77.63273500627088, 25.349792049777125, 0.6748093448338971, 0.1493843566746481, 0.20447452071933978, 0.2129029894187566, 0.3008659556508064, 0.14862759970128536, 0.16219058885209023, 0.18460961569461132, 0.11382457004078936, 0.12388086066611352, 0.12706722718693558, 0.1315014590058596], [0.028155845619978446, 0.06102346522252887, 0.020013671638744495, 0.05005856367549108, 0.00806306582695294, 0.02393409594773285, 0.08463354045224768, 0.06736404172355129, 0.045439218200983546, 0.02317280181863856, 0.061203346497589545, 0.6530376776091514, 39.807444541685044, 64.4139749003995, 52.64037286081622, 32.206512843408895, 18.698175914825935, 38.00944182180589, 58.678685234438994, 38.66369316654821, 58.604948597569624, 42.5298204729634, 0.8116445377949746, 0.07071209110079274, 0.126588192407883, 3.5086206707262226, 7.2826612668652695, 10.63240118565098, 51.898695807303156, 61.01127562984344, 64.79386821869882, 66.02075422963789, 65.13704030744492, 64.10379778954291, 62.440744215442294, 60.41392610919092, 60.24639775676113, 66.65399735973728, 61.746563142345806, 60.2448288086922, 60.335863098021484, 58.07460492657077, 56.878631114959724, 54.487275769633634, 47.96701392819805, 42.21013161443895, 43.946443296247914, 45.35424863138507, 44.20724953374555, 42.01549968411846, 42.236027102316584, 41.0050618263983, 41.691056912945164, 41.78774726006293, 43.79065852011404, 44.2567616124307, 44.933088056502804, 43.76952086725543, 46.060769481043664, 46.48506402969361, 45.612446492718114, 47.504491959848714, 43.749191222652314, 40.750817714198945, 41.02664662945656, 40.32107499337966, 43.29001111368979, 39.987128319278845, 43.15817632982808, 41.16685175126599, 39.31592449065178, 38.76989918370401, 47.864812650988185, 54.20439835517637, 57.02718696286602, 52.633249836583296, 55.36579647371846, 53.30910559623472, 54.781379007524066, 50.506944733281294, 53.51014275704661, 51.729398465925655, 55.13035228175502, 54.36063420388007, 59.054734629969445, 50.08570963336576, 62.55770144924041, 41.86788520505352, 30.605477825287853, 58.87439581655688, 51.94501899903821, 54.86131691163587, 52.35826815328291, 53.34621514043501, 50.741188679972005, 52.96700039217549, 51.21225357055665, 52.60928807720062, 52.05963850021363, 51.75107348349787, 48.71156607904742, 46.2083565035174, 41.51227920286117, 40.444864996017955, 40.30119642134636, 42.14618129114951, 42.31864790762625, 43.04598477578933, 41.15368435459752, 41.30987313485915, 40.3119162590273, 39.98330008599066, 40.50358287749752, 40.702396054421705, 41.12290159348519, 41.41753827371905, 42.60683621129682, 44.322292650899584, 46.227972276749156, 50.89967204678444, 54.16681420418524, 52.070115150943884, 53.38001420420986, 55.439882201533166, 51.15937217589348, 46.110862070514315, 43.375008875323886, 41.18547124247397, 41.31106161302136, 42.78489612763928, 42.011424341509425, 41.39316074309811, 42.1308095224442, 41.96059042407621, 44.42774949535247, 41.444704609532515, 40.95098803120275, 43.281578017819314, 44.27584786568919, 46.73898258516866, 49.22203902275332, 48.524045405849336, 48.7453612204521, 50.725856134968424, 58.151271573958866, 59.08053990333312, 62.55347705656483, 56.99018332266039, 17.09416970129936, 0.42612010552998514, 2.312107288068341, 0.4656723363985939, 0.03954023010127487, 0.014115398873635119, 25.617729156248032, 62.62247154789587, 34.27938153666835, 41.58764362335205, 15.753366293445712, 18.590218559388195, 36.86198380685622, 49.324597235648866, 53.70794788483651, 26.220142456793017, 0.10627967650972067, 0.0753364352990062, 0.02651453097050469, 0.006977740924940595, 0.07762643298314464, 0.02714873877384009, 0.01330755245421202, 0.128209471942917, 0.039258382523492466, 0.033628567076858976, 0.015023738791745518, 0.029796543568673155, 0.05187695380300284, 0.04841235563940099, 0.062431259035703644, 0.0321156621700333, 0.04894655257944138, 0.035642853547488494, 0.019155388863216487, 0.036291408262425856, 0.03557527310124809, 0.05650143589704268, 0.015075463133173124, 1.302177254711428, 51.28127944084906, 72.34967893169772, 61.234811505963734, 40.31824696448542, 21.534124074443696, 32.5586671598496, 61.97112667945124, 44.67223082819293, 65.74630206631076, 45.45060165466801, 0.9110185215550085, 0.02720977682920714, 0.11238551217942469, 3.816633858988362, 2.495731576796501, 10.592025287689703, 54.09547021312099, 61.94290522606143, 66.20435253266366, 67.54479116009128, 66.23297014544087, 66.50659468866164, 65.19810376628753, 61.52374113759687, 61.52525517248339, 67.0284503506076, 63.88764381408692, 62.267469590710064, 62.68897533416749, 60.54337609198786, 58.69300580793812, 58.33288123530727, 50.247456412161554, 44.77069800899875, 46.519843686011534, 45.15452938695108, 44.27343168566304, 44.12169871791717, 42.903940062369074, 42.50074786524619, 43.608436969018754, 43.31147432327271, 45.78047690852996, 46.51980053993964, 46.87116645997571, 46.00318516454389, 47.20514843540807, 49.63198161894276, 49.99407522140011, 49.10403059374902, 45.39906563297395, 42.861076401126006, 43.402143832175966, 42.13662639740975, 43.232603303847775, 42.7811816430861, 43.75672217338316, 44.468393095078014, 39.937549560300766, 40.34624876514558, 49.55715456316548, 54.64930495908184, 59.87531015949865, 56.10359822550128, 57.77427296484671, 55.38415708849507, 55.2984062317879, 52.54516909199377, 55.70747413942891, 52.852004343463534, 57.30019177159956, 55.12360188268847, 60.484513082811915, 54.10529575040264, 63.33228326612904, 43.224079993463334, 32.89635773627989, 60.07575896478469, 52.55672439452141, 59.12273283927672, 54.65929131354056, 56.27333487233808, 52.049503095688365, 54.776479967178844, 52.860327612969186, 54.42614563049809, 53.98767955841557, 53.11741936591364, 49.76243180613364, 48.31484187033869, 42.1216860894234, 41.970867033927675, 42.31934216714675, 41.08559200840612, 43.63684277380667, 44.6242759304662, 44.514908482951505, 42.93913548992526, 43.148896002000384, 43.12211798083398, 43.64092596115605, 42.78633563749252, 44.52953500132407, 44.131492876237445, 44.75663238956083, 47.224654382275, 48.6087489897205, 53.022925546092374, 56.90808027021347, 54.41819890852898, 54.92201559005245, 56.62435562379899, 54.07943948622673, 46.97382273212556, 44.125130791817945, 43.663593338381865, 45.34911424882951, 44.24635164199337, 43.589233044655096, 44.043690619930146, 44.61229701195994, 43.870259100391024, 46.21453031416863, 44.37589576167446, 44.525000741404874, 45.0862919130633, 47.18756444992558, 48.436953098543235, 53.40680399248677, 51.19506182209138, 50.67108023551203, 52.474170269504675, 60.206216996715916, 61.14544422395768, 64.34520790653845, 59.739172535557906, 20.011438400514667, 0.6216615354341846, 3.415297188105122, 1.097579072079351, 0.05225455471044106, 0.06579671776102436, 25.35025881182763, 68.89620457926105, 39.993937553897986, 42.57803424712151, 21.024665063427342, 25.35624827108076, 41.10012438989455, 55.145704438609464, 62.26567706754131, 34.896590017503314, 0.1340731702023937, 0.04429944790899754, 0.14823055165188928, 0.04687971247720623, 0.05649311618218499, 0.01310822882524301, 0.028518703165313894, 0.05996813314155706, 0.04233141016635684, 0.0384146056228107, 0.029934016131465475, 0.009302791440859437, 0.09956439491361381, 0.15624767710124293, 0.14513482099338887, 0.15391740617492508, 0.1312276132164463, 0.10789488862839439, 0.1520562568499196, 0.15998754980823687, 0.12361128198643848, 0.1289355087905161, 0.21242291276012698, 1.554842000046084, 62.115430678090746, 80.80987053532755, 68.39876959400793, 45.542734207645545, 28.749688786845056, 49.294971573737364, 70.12191387914842, 53.316726761479536, 70.04956183894988, 53.489534624161266, 1.163413358792182, 0.26929914951324463, 0.21842476731586843, 8.903458656803254, 15.80800687113116, 15.130252684316329, 53.33654257559007, 63.266752227660156, 67.92503356933594, 68.6903585926179, 69.16413384099161, 69.7063466041319, 67.59506810096003, 66.82363986968994, 63.856166793454086, 71.16080853246874, 66.70508230886152, 63.39808494813981, 65.5006871684905, 62.06708746571695, 60.33806354768815, 60.0778260538655, 53.373848238298976, 45.61175615556779, 48.525935988272394, 48.472862397470784, 48.82572666291268, 45.945381195314475, 45.060306210671705, 44.98474567167221, 45.02690722865444, 44.87070668128229, 48.06620674748575, 48.426417612260394, 48.944535255432136, 47.656883885783536, 50.28998667193998, 52.72042059129285, 51.44452064268051, 52.98230548058787, 49.16652179533436, 46.60746943566107, 45.48069407863002, 43.39313807026033, 47.03070886673466, 43.002387631324034, 46.89718354132868, 44.88645891989432, 41.05539760281963, 42.79271733376288, 51.79152096471479, 58.23907775263633, 62.1710341976535, 56.63720923085367, 60.78540594347062, 57.76714209587344, 56.81973280445222, 54.556587972948634, 57.37931382271552, 55.67901734382876, 58.787040710449226, 58.97021931986655, 65.31435497345464, 56.38267486326156, 68.84997552441013, 46.40469858723302, 36.11660795827066, 61.63290069949243, 55.06865339894449, 60.026705803409705, 56.857073768492675, 57.86793131982127, 52.75289389394945, 57.70784762597854, 54.03118256599673, 56.098832545741914, 57.15415408534389, 55.29715107333276, 53.13881197283345, 50.72527562418292, 46.299379025736165, 43.99205653898178, 44.85888073521276, 44.54556572821833, 45.96874675443096, 47.22652143047702, 45.89893641010408, 45.10771589894449, 44.51171175126107, 46.43607362624138, 45.959274230464814, 45.92141551356162, 45.99563460196219, 47.2936684854569, 46.13245079594274, 49.92201343659432, 49.279921439386186, 56.82424353015039, 59.68583614595475, 55.832225122759425, 57.91702370489798, 61.82929769639046, 55.95185349064489, 49.37456038690383, 47.63800944051435, 45.21646753434212, 45.66306467979185, 46.98904937313449, 47.07392554129324, 46.478607808389974, 46.90112944572203, 46.781199055333296, 49.47624783362112, 45.71118039469565, 46.972712701366795, 48.541747062437, 50.9913182258606, 51.110911292414514, 54.54012578533542, 54.223629736131244, 52.89086718713084, 55.8192930683013, 63.96757779582855, 65.56681440722558, 68.98190836752616, 62.9201166860519, 20.800617317999563, 2.8295750435321563, 8.534626422389861, 1.5364941329725328, 0.2909758831224134, 0.1503888051956892, 31.287948662234893, 75.28837357797931, 49.18579632236112, 54.34325025927637, 23.884437699471754, 29.06108379364014, 52.76981107650265, 64.76678817502915, 69.4338595482611, 44.155850795007524, 0.5692469028215255, 0.20466420408939162, 0.22368694865895858, 0.24587806434400622, 0.26747582960994015, 0.13159602489923278, 0.1096519725697656, 0.1895405099757256, 0.1081639233856432, 0.1621780403318905, 0.12311278857410916, 0.16849146284643682], [0.07514222434932187, 0.04688920813702768, 0.04177929442976752, 0.0323974714434195, 0.05764692886582306, 0.024870314763017723, 0.06477951387604398, 0.0264727964156097, 0.09031483317695319, 0.09877370024520545, 0.27351336854119457, 4.987243663880133, 55.43643051578153, 57.3238750427, 45.530304216569476, 36.04833518305133, 25.907741362048736, 26.940530846195838, 44.78761519155195, 39.597036838531494, 63.596682394704516, 30.611988959773896, 0.20968756518296658, 0.09198681241081608, 0.14497821729990745, 3.382695918121646, 6.487367864578001, 24.11460434236834, 67.28145107146233, 62.26686946807369, 66.63374224016744, 59.77296767696258, 61.15636410251741, 59.08632932170745, 60.345472904943655, 58.357725527978715, 59.01076093796761, 55.24280271222515, 61.89063179877497, 58.615076157354544, 62.31232973837084, 61.1252793189018, 59.61913231880435, 53.90920862074822, 46.04681368797056, 44.20927347675447, 44.41409572478264, 45.09375618350121, 45.03816050867881, 42.81455316851216, 41.08896132438414, 42.07500988437284, 43.897394057243105, 45.455088846145145, 46.369393333312004, 49.521712026288434, 51.063697722650346, 48.275967259560865, 50.24496570710213, 50.32018892226681, 50.286786017879365, 46.30001052733391, 46.67783675655242, 42.515158653259284, 41.70833887592439, 40.66836557080669, 41.892137219828946, 40.925284739463564, 43.3610217032894, 42.08124645294682, 39.65010258459276, 45.94653044977496, 54.05870583749587, 58.13445245065997, 56.62267684936524, 53.18950468494047, 56.56646536242578, 52.87342440697455, 55.87335117401616, 51.25541140956264, 55.94948045669064, 56.96970070562055, 57.11298881038543, 53.84975333367625, 58.20016391815678, 52.968133957155295, 58.77188074973322, 41.16612219041394, 31.043337891178748, 59.03420886685772, 52.08117623482981, 55.87235881436256, 51.29873791048604, 53.488471661844564, 51.80418237563103, 53.44497257663358, 49.79944721344979, 52.51948148973527, 49.254857493985085, 49.46892869087958, 48.415736998281176, 44.62406412247689, 40.791429934963105, 39.098056439430486, 40.000362396240234, 39.57526768407514, 42.874204574092744, 43.190171103323664, 41.714728416935095, 40.51246312356765, 41.85430988188713, 40.26826812374977, 41.98794111128777, 42.95609189618019, 44.18118930632069, 45.59063419218987, 46.60030718772642, 50.572585598115005, 50.890587837465354, 53.90866341129426, 52.82997631257581, 51.00065346687071, 54.195012123354026, 53.0710530281067, 50.32956730934882, 41.73434811253702, 42.61258640596944, 42.719059144296956, 40.420856168193204, 42.387720846360736, 42.69613681300994, 43.877997936741004, 42.73641955467963, 41.751135856874534, 44.3354953488996, 47.56256265024985, 49.62791804344424, 50.56016737414945, 54.39171114275533, 55.90967624418197, 56.873331992856926, 55.6653243495572, 55.86133303180818, 49.81434437536424, 50.58849473153391, 60.94716841174711, 61.41276159594136, 64.36249771425801, 38.95466243067096, 1.1440381984556875, 0.6472414563740454, 1.2079820253195301, 0.06082144400645649, 0.05180790629838744, 12.633150239144603, 60.488631571492846, 41.68769544170749, 41.238399705579205, 22.24236684460794, 20.3359321625002, 41.646930248506614, 48.94517067940005, 62.55996465682984, 36.96019211123067, 0.5363641414911516, 0.14006629135579834, 0.07014189185875078, 0.10126408354769792, 0.023695482541957212, 0.03763616836119083, 0.05460773932657415, 0.037210131544739976, 0.022710337521388166, 0.0864843552511546, 0.02984730263931617, 0.06556859975981136, 0.015254733453114188, 0.09304639627976764, 0.06251261757326222, 0.0768458200318198, 0.0174990531447674, 0.019154050124568806, 0.03892407707509495, 0.047300965074569955, 0.07571002573616083, 0.05910322370548403, 0.28462832372996116, 7.787645343811282, 67.44530416304066, 63.408667502864716, 53.7029900089387, 36.74801149675923, 21.698998943451915, 23.363974478936967, 47.9982477618802, 43.481924841480875, 71.27425916733281, 32.55349747596249, 0.283428538109987, 0.06308610716293897, 0.9803857606264853, 4.7096643909331295, 1.593526498444619, 25.987002657305812, 69.39879355892059, 65.49279928207397, 68.26763691440706, 61.733407512787856, 65.43878824480119, 61.01750043130691, 63.19826372208134, 61.235595979998195, 61.105949878692634, 57.69579418243901, 64.01411671792307, 61.29870299370059, 63.878704732464215, 61.27552570835237, 61.53344508140319, 56.18146904053227, 47.84442024846231, 45.96712289317962, 46.454304802802305, 47.77731633955433, 46.93301439285279, 44.73235291819419, 45.531928077820815, 45.16427255445912, 47.63425573225945, 47.64015497699861, 48.84014529566611, 49.41059127930672, 52.156725006718794, 50.71092367172242, 52.849344976486705, 51.88319460038216, 52.15856852069978, 48.21926155397969, 48.49757725192655, 43.96587471808157, 44.40379950308031, 42.745370403412856, 44.87322484293292, 43.30712441475161, 44.920191303376235, 43.85372631011471, 41.76429933117282, 46.87635967808385, 55.00069441333894, 59.44488886863955, 58.68575726785968, 55.268572684257265, 57.92649230649395, 55.25291066015921, 58.27137847100535, 54.02016855055287, 58.237850050772394, 58.23768138885499, 59.953357481187396, 56.3182185542199, 61.42981213908042, 53.73370216738794, 60.483960028617616, 41.91758947987711, 33.350748631262014, 60.82259393507435, 53.640134026927335, 58.099484520573775, 54.73801328289894, 54.21293735504151, 53.33340467945222, 55.16212740252095, 53.66539801320722, 53.817487916638775, 52.188939432944025, 51.77361534487817, 49.81428946218183, 47.12048407523863, 41.37826358118365, 40.487171680696555, 42.45282042411066, 42.97350721974527, 43.4306320067375, 43.824959647270944, 44.14049863815308, 41.73929422132431, 45.72555195900702, 42.022638397832075, 43.26698287840813, 45.008601527060236, 46.815307986351755, 47.57337662481493, 49.15665311198081, 53.3653719963566, 52.854408756379165, 56.600029083990286, 53.144064026494185, 52.162569338275546, 57.0571695604632, 56.55322344072404, 53.086620915320616, 43.70360543650966, 44.375523136508086, 44.55100213327716, 43.9685340850584, 44.24166048726728, 44.871110685410045, 45.25127072488108, 44.96179980616416, 43.91711573446951, 47.47878866810953, 48.859251160775464, 51.826924277890114, 54.57714119265157, 55.31208745894894, 57.82772310318486, 60.701745710065296, 58.97694226234191, 57.78121948242188, 54.21446707940871, 53.58253794331705, 63.40797716571439, 61.843673183072006, 68.16935016262916, 42.69193987692557, 2.592880350928153, 1.0447849501525204, 2.366343861626041, 0.2419903979546601, 0.08135532765018363, 13.301325017406096, 67.74141957682949, 47.95777282407207, 43.806273475770034, 25.827020945087558, 25.808681903346894, 47.56798336582799, 55.679382124254786, 67.1744566579019, 46.51266182622602, 1.402723536856713, 0.10015144042911069, 0.027562803551254254, 0.017222501149761583, 0.022087705306588643, 0.028123367322428573, 0.03417083475318167, 0.08495400269185344, 0.0310714996509975, 0.05245762929740933, 0.03892757426646929, 0.0865799093979501, 0.10831178601590857, 0.2316460659306857, 0.13706082117653665, 0.2362686404657941, 0.1351291304754634, 0.12112510450665029, 0.1500671861633178, 0.22387801098727414, 0.24603816139842236, 0.27142835300295587, 0.5451842036939437, 9.672787439438606, 76.78898611376363, 72.33635856259254, 61.2244446815983, 46.198166185809725, 34.89752746397449, 34.64859424098846, 57.99753035268476, 51.69309300761069, 74.52418604204732, 36.20798349380493, 0.5399564196986537, 0.20052080222916221, 1.032792180776596, 13.745714849041356, 17.54929800187388, 27.640909264164588, 71.79874281729423, 68.37646699720814, 70.38681507110596, 63.84624711928829, 67.78207886603572, 63.112383427158484, 66.46147958693966, 63.2122116704141, 63.83693149012905, 59.33169711020685, 67.571212245572, 66.79401813014861, 66.8766938486407, 63.3251053287137, 65.40085892523489, 60.04982425320534, 50.56810625137822, 49.12932203662012, 48.12110424041749, 48.88807273680165, 48.223925252114576, 47.49604709686772, 47.53818904199908, 48.525202505050174, 48.75687729927802, 50.524007043530865, 50.97631123758132, 52.77513373282648, 54.28792915036602, 53.29409860795545, 55.356284726050596, 55.19589116496425, 55.139981700528054, 50.30342078978016, 51.811054368172925, 47.784251090018984, 46.337214208418324, 44.74412787345148, 46.810495238150324, 44.719287503150206, 49.12862385472944, 46.34256824370354, 43.87233795658235, 50.05136536013696, 56.75767306358584, 62.64859061087332, 59.92805819357596, 57.1756604409987, 60.481379109044234, 57.83193180637976, 60.40526159348027, 55.44059607290453, 60.779887168638176, 61.39986876518496, 61.01454688656715, 57.03024641160042, 63.55794506688272, 56.205105243190644, 62.00073272951188, 43.90568202541721, 36.78663115347586, 62.1263897803522, 56.76834975519488, 60.430976652329974, 58.39232475526872, 57.06535554701283, 55.270992786653586, 58.229750356366566, 53.85136935018725, 56.1959308193576, 52.704154522188254, 54.760453162654755, 53.37905714588781, 49.695563239436, 45.49089616344821, 42.375918434512236, 44.50706766497704, 45.000741097234915, 45.300112078266764, 46.649289746438306, 46.43490475993003, 43.422383262265114, 47.26728270130773, 44.38004955168694, 46.97552504078035, 48.369331436772505, 48.90130289139287, 50.795690013516335, 51.35243123577487, 56.98493519136983, 54.78894525958646, 60.57673585030341, 56.478157120366255, 53.16169115804857, 59.11479003967778, 57.407503897143954, 55.957250672002, 46.31437032453476, 47.09773040586903, 47.708247323190015, 45.14134237843175, 46.68162184376871, 47.07039933050833, 49.213547091330256, 47.54405690777687, 46.50093786178097, 50.47839772316718, 52.191383069561375, 54.782932266112304, 56.46492304340486, 58.23594770123882, 58.90063255063949, 63.65767132851386, 61.59000565928798, 61.851129608769575, 56.44625648375481, 55.22444994218888, 66.28083090628347, 67.38999089887066, 71.12494237961309, 45.59988706342636, 3.273945018168419, 6.311608908637878, 5.081691395851874, 0.26625940456025066, 0.18209493208316066, 16.10977638152338, 73.95248489995157, 55.435034152000185, 54.86791041589553, 31.801204527578047, 32.64350018193645, 57.865099368556855, 65.34310986918788, 75.07397682436051, 56.97726303531278, 2.313127104313143, 0.3294196766951392, 0.20066193094657314, 0.26039135492136406, 0.19104282371699813, 0.10942117326081761, 0.15537355545788042, 0.19490176180918373, 0.09173837009697192, 0.15984501148904526, 0.14144975421649797, 0.21363058908572122], [0.040016686994462244, 0.021637598007556894, 0.02618319411281376, 0.05990263262403108, 0.07369842440370591, 0.06744985889282919, 0.07630225766690509, 0.04735028198469551, 0.06221367091300988, 0.06083440238369569, 0.13432311404856945, 6.901394628709363, 61.199153238727206, 54.03169247411913, 53.2362985610962, 58.04896047038417, 42.08057572764736, 26.305555989665372, 39.164595527033654, 46.315241090713016, 68.92890145701747, 19.664896995790546, 0.11066367594344963, 0.02956239262505645, 0.46615690233245977, 2.2943737622230285, 3.5077182804384544, 56.16553245052215, 63.154866618494836, 64.71951576971239, 59.88169970050935, 61.81487514126686, 56.26729442227272, 56.29765748977662, 52.81448295039516, 51.12051325459635, 50.564725168289684, 52.014935247359745, 49.492560971167784, 52.21558017115439, 52.120909844675374, 50.570644024879705, 49.24886018999162, 45.377041524456395, 42.75775724841703, 42.645271516615345, 41.596512102311664, 41.69914484024048, 41.27718802421324, 42.24210677608367, 41.9767427444458, 44.963498192448775, 46.14777549620598, 48.323922157287605, 49.476706750931285, 50.06402677105319, 51.72841002864223, 51.74775515833209, 51.97017708132344, 52.153696936945764, 51.310850189578154, 49.21033467015913, 47.73548033929641, 43.55752460418209, 40.03992734416839, 40.32495421748008, 42.72858265907534, 41.753097041960686, 39.88868859506423, 41.686079425196496, 39.55663250338647, 46.906871795654304, 55.02638986033779, 54.18391966050672, 51.27610975696195, 52.35225515980875, 54.18063663667249, 54.73432233256679, 53.61808638418875, 54.448193273236676, 53.088582100406775, 53.42475275839529, 52.873844100582986, 55.065668475243356, 57.382667449212846, 52.477637644737, 56.934983807225386, 46.72811369742117, 34.956602281139745, 57.48225250551778, 52.089421056932025, 55.177895330613666, 50.617963498638524, 52.64476591540922, 50.829096840273955, 49.822844151527654, 49.62406235356485, 51.01136153744113, 49.25737957800589, 47.68110452159759, 45.46868770353256, 42.49691570958784, 39.39960825827814, 39.88136945232269, 40.86738663335001, 42.14760903389224, 41.11817513742755, 43.32409651048722, 42.02486630408995, 41.48925488994968, 41.96089244657948, 42.25523887142059, 43.238373110371256, 45.828337669372566, 47.95761592926518, 50.957319121206964, 53.77566760586154, 54.11051642510199, 55.0763451668524, 54.44625562237155, 53.00916979389807, 53.64144017619472, 55.4325669811618, 52.17873342575566, 46.245218938396825, 40.342714709620324, 43.38106501486994, 42.39447516779746, 41.24281237202306, 43.21183435378536, 42.018892534317516, 41.877930395064816, 46.92590313573038, 50.912462895916356, 53.86330904499177, 55.79280922489782, 56.14478703468077, 57.961852473597375, 59.07988094514417, 61.23779642966486, 61.203573749911406, 60.141321382214954, 59.44461430272749, 56.94727651534542, 55.32812995295371, 54.12980271923927, 62.972754893764375, 61.63258298750847, 60.06522740087202, 7.804206080975072, 1.1685776494203077, 1.0266461331517467, 0.047848920953730424, 0.010640071648653718, 4.951028910375411, 55.9676920214007, 49.22356482475035, 45.05082584196522, 32.39379817439664, 22.25906437443149, 32.48642494601588, 49.68564356527021, 48.76038782058224, 46.85579076890023, 5.783324972275765, 0.25270038374489356, 0.030528986826539043, 0.050897629135438514, 0.03563074169740562, 0.058009759598081155, 0.07617321015606004, 0.051400447114100384, 0.011519376834433888, 0.11229832371276234, 0.019719693058681105, 0.038918358228740194, 0.039806388198368015, 0.08445067526472193, 0.025523872032100638, 0.04426346092875447, 0.015371367466756174, 0.07781435435097064, 0.009867097551543868, 0.03955959297356106, 0.05125700481115811, 0.04847950324596417, 0.10341401737664016, 10.48015340681999, 72.33033380200787, 60.73533296585084, 59.39894614681121, 63.46180777395926, 50.022928176387666, 31.832161834163053, 44.07788192072223, 50.47420470945297, 74.90296932958788, 21.082288603628836, 0.02009776511019276, 0.12087087056809857, 1.5246007711656633, 0.8323961436267823, 4.820407609785757, 59.91434558745354, 65.47425431589927, 66.44791603088379, 62.38134776392291, 65.41921169527116, 59.806864799991736, 58.888147646381015, 55.461867086349, 55.39389633363294, 53.011766402952134, 54.111508784755586, 53.21334092847763, 55.06028698336694, 54.297527190177675, 53.86076734912012, 50.59881448745728, 49.027885621593846, 44.739577924051595, 44.87714721310524, 43.418994334436235, 44.93578664718136, 43.83043919840167, 44.54018031397174, 43.584028059436434, 47.71140483117873, 48.41383072637743, 50.74424812870642, 52.16743307728922, 52.48203854407034, 54.351667665666156, 53.86500743127639, 54.913276549308534, 54.57239904711324, 51.85841306563347, 50.36709654715754, 49.456902703931256, 44.55876842621834, 41.83263878668509, 43.28768514817761, 44.78244158529466, 43.962752511424405, 42.2640916608995, 42.78371157184724, 41.41321189941899, 50.81146186397922, 58.62754537213234, 56.963366077792266, 55.15067015924762, 53.91799080756403, 55.59796156421785, 57.23961860902848, 57.04619084635089, 56.202426264362956, 53.540756856241536, 55.80166593674691, 54.21692248313658, 57.07034872424219, 60.34066407911239, 55.49634864253383, 60.44423034114223, 48.99320402453023, 38.59907604032947, 59.38972073216593, 54.97403014090754, 59.33305425028647, 53.21423915124709, 53.83477772435835, 52.704621284238755, 52.54598886735978, 51.04199132611675, 53.04979378177274, 51.16263558787685, 50.24758977274741, 48.981656566742934, 45.18885797069919, 42.400405791498, 43.08404353357131, 43.21029286230765, 43.11945469148698, 43.2413423445917, 45.69740110828031, 44.77389081831902, 43.51475900219333, 43.279255974677305, 43.329799636717766, 43.56818560631045, 48.58469701582386, 50.35420371640114, 53.86194406017181, 56.14039790245795, 56.28219942892752, 55.25052193672427, 56.912610607762495, 54.98108648484754, 55.768384625834805, 56.84041154000067, 54.304960081654215, 48.05336882991176, 43.514139267706106, 46.80428220379738, 43.916699963231245, 43.296600695579286, 45.62562957886727, 43.21024971623575, 44.23336075198266, 49.296717028464045, 55.1649828880064, 57.467280818570046, 56.89514429338517, 57.345871694626354, 59.30617816986577, 60.158826920294, 62.227033876603656, 64.60339792313115, 62.858935556104115, 61.92224217999367, 59.516248549184496, 57.15319310465167, 56.63338099756549, 62.760009457988126, 64.50784114099318, 62.05614797530636, 10.312689773498043, 2.808334428456522, 2.221218861879841, 0.0483690640107999, 0.024433158180345933, 4.977679454511212, 60.0413990020752, 55.445051885420284, 40.27097848153884, 28.199417514185754, 29.990869875877138, 40.333030377664876, 57.80835443927396, 54.567837330602835, 58.3828208523412, 8.174454781316943, 0.22823032502445484, 0.023717840818027337, 0.06007009561383917, 0.03689717696679216, 0.04901933859312727, 0.00793928852222199, 0.06595061716413306, 0.04718312926049675, 0.061811907592439846, 0.06237564105240088, 0.014998199335569817, 0.15013720659959703, 0.16789287238592104, 0.18839349249197593, 0.14512173621164215, 0.24037602087182386, 0.2509074928539415, 0.16710678956681685, 0.1574333973469273, 0.19989084812902636, 0.20715169157953034, 0.2632571672720294, 13.660133634844135, 81.52032159989881, 68.20980548858643, 69.02918861758324, 71.12019631170458, 55.126857449931485, 37.109952126779866, 54.12618629394039, 57.52049169232769, 79.48723162374189, 24.137936561338364, 0.34441459142873365, 0.24428256366762424, 2.951698774291623, 9.779493558791376, 5.960811241980522, 60.807645782347656, 66.54352772620418, 69.42751315332228, 64.57009307799801, 67.60237939896123, 60.942979320403076, 62.651614758276175, 57.87058284205776, 56.2609637168146, 55.22458330277474, 57.12598754513649, 55.31406825588596, 56.61692273232245, 58.30922149842786, 55.580954167150686, 52.901245778606786, 51.0652627483491, 46.15944846983879, 48.45489794208158, 46.71203590208485, 47.42899417877198, 43.847419138877626, 46.10936764747866, 45.27866848053471, 49.397859265727384, 49.70123890907534, 52.99795573757541, 56.29361352612896, 55.397144056135616, 57.568654475673554, 56.884444067555094, 56.591509695976015, 54.76903923096196, 54.4338805444779, 54.03660328157487, 51.89178459105953, 47.42147499515165, 43.97265649610951, 44.75327091832315, 47.51289367675782, 47.00689223504836, 42.85175292722641, 45.05037084702523, 44.35091418604697, 52.26662197420674, 59.87285867814095, 60.229374670213275, 55.851127024619814, 55.39464550633585, 55.53868278380364, 59.223584821147305, 56.54575524791595, 58.48263732848629, 55.6423157261264, 56.78893827622937, 54.41723008309641, 57.784443670703524, 61.24262878971716, 58.05636198289933, 62.18768073666481, 49.77188471824893, 43.04356075102284, 60.834568931210434, 58.82629579113376, 61.44761969966274, 55.95323416494555, 57.008206613602184, 56.7826154155116, 54.30593282945695, 53.77695806564824, 55.21228667228453, 52.91656263412968, 51.55458627208587, 51.017539270462535, 46.07355640780541, 45.293193017282796, 45.601263815356845, 45.199114968699796, 44.00957384417134, 46.764242649078376, 47.15572264886672, 46.35078560921454, 46.097600536961714, 46.31659038605229, 47.50297008022186, 47.35468879822762, 51.11264890240085, 53.8443051615069, 55.89903485390448, 59.72618949028754, 59.69368873103973, 59.68749138616747, 61.11334354646745, 57.93222681168587, 58.51140006895989, 59.26872737946049, 55.25193006761613, 51.13824629014539, 44.84220673961025, 50.152197730156686, 47.2155584058454, 45.29258897227626, 48.673805421398534, 45.58397793000745, 47.13079206405148, 52.715046944156775, 56.49467422116188, 59.74156910373319, 60.68555416599397, 61.179459018092004, 61.94334453152072, 63.52628761722196, 66.89484657779818, 67.19904991888231, 64.99075158949822, 64.46262405764672, 61.902261626335886, 62.40682748056228, 59.729260706132465, 67.31965495694068, 65.89458727067517, 65.9624913430983, 9.607674133393074, 6.757648587226869, 5.16628417276567, 0.14541254318769903, 0.18925672036505517, 6.834067144701558, 68.09351505771761, 62.2351610276007, 61.02720829748339, 43.84955290825137, 34.29837757541288, 46.526382277088786, 68.57932413777998, 60.98739624023438, 68.03424804441391, 10.753359237024862, 0.37042894550869543, 0.20292510789248253, 0.12948931375097844, 0.12238518890714455, 0.20780075191249772, 0.15928167639480484, 0.25713112986376213, 0.11569143438170995, 0.23666824724885727, 0.13340385450470832, 0.1389104791826779], [0.05032855604264525, 0.038818908524849725, 0.025739562171961994, 0.0300574577939246, 0.07312945856322205, 0.03116220063079269, 0.041757434110848174, 0.04476886445416078, 0.03771094237304023, 0.03563631881749438, 0.15422879027262812, 11.210319284469852, 60.08401947636759, 53.173548483079486, 47.962832681594364, 18.52708016672442, 12.025089706144026, 17.60089874267578, 42.037868961211174, 52.04361561805972, 64.23100417660129, 11.834150687340768, 0.00539649858124434, 0.06062952749010536, 1.1750610821670102, 2.0052075626388675, 17.947093017639652, 66.2629762772591, 62.41506053555397, 64.51480334804904, 57.30942110861502, 59.01551877298663, 52.52625542302286, 50.73774091659054, 43.958332000240205, 44.6776907674728, 42.33758511081819, 42.00736861075125, 42.46381090533349, 42.974342684591974, 42.260467390860285, 43.04216830961166, 41.68618532919115, 41.39797349129954, 44.79860959514495, 42.03731590701688, 44.88687861350275, 44.51403379440308, 42.87860939579625, 42.63668152593797, 42.13342966571931, 43.72909299788937, 45.928228670550936, 50.23037056769095, 50.91459274291993, 49.70967592731599, 52.41112601372504, 51.837491143134336, 52.879904162499216, 53.35364410954138, 54.55034355963431, 51.47225572216896, 44.74439851699337, 42.790410980101555, 40.33163401388353, 41.73616809229697, 41.11402134741507, 42.232045896591686, 41.861044591473, 42.849795664510424, 40.526199263911096, 49.12752166871102, 55.05522320347448, 53.38001420420986, 55.580954167150686, 53.95262925855575, 54.69789528077649, 58.148635741203066, 54.642821281187004, 55.12112686710974, 52.474531127560525, 51.43996284854028, 54.11594498542048, 56.824204306448664, 56.47270894819691, 53.250317112092056, 56.201782995654696, 50.70548726666359, 36.28382644345684, 54.28814095835532, 54.8690204466543, 55.815680565372595, 50.92696782081358, 51.580823006168494, 48.90212266675888, 48.09737390087497, 47.507268997930716, 47.44413845000729, 45.23687954871885, 47.2598772664224, 43.37921757851878, 40.98647763652187, 41.136833852337254, 39.923464329011985, 40.00460640076668, 40.35976525275938, 41.65522998379123, 42.45244387657412, 42.56127003700503, 41.33077544550742, 41.00448131561279, 40.50723852649812, 42.38525367552235, 44.97612822440363, 49.84438973088419, 54.436496765382834, 54.960054735983576, 54.378037760334635, 54.677424430847175, 52.69392890314902, 54.32007689629832, 53.64873578471523, 53.024384667796475, 48.3222786841854, 40.628588814889234, 42.071703326317575, 43.20474663088399, 40.84463688635057, 40.4829002195789, 41.90044087748374, 42.54090116870019, 48.574412561232045, 57.17083984805692, 58.90209951708394, 60.05799847264444, 58.45013656923848, 57.39287737877139, 57.908363111557506, 56.35058595288185, 56.69851979901714, 55.90227865403699, 56.4708536671054, 60.09537473801644, 62.04294919967652, 60.85345122121996, 60.02990253510014, 60.54709842128139, 61.31772256666615, 65.74080290332918, 21.127025196629187, 0.20508155346878115, 1.1051898185283908, 0.02939326530923286, 0.04078189008719018, 0.5796858007388731, 43.85778988561323, 59.415255361987704, 43.86584643394717, 37.48884524068525, 14.715740526876143, 27.098280729786044, 51.2163406802762, 53.508467904983036, 52.74270749861195, 10.084714754935234, 0.4037188059620319, 0.04887540216347383, 0.01769590901301032, 0.024376149747460604, 0.026316278907019767, 0.05251174957882013, 0.07643455339054908, 0.007169431924159008, 0.034029575800823594, 0.046094836246582775, 0.012453693836446733, 0.0335751477658989, 0.03719496683427884, 0.05845307935810378, 0.033792448605621056, 0.024502843453158295, 0.021561504409257925, 0.06803644475557151, 0.021699105291777564, 0.029259527425071406, 0.005767718933883214, 0.11112537415277575, 15.292935928990765, 71.17601163925664, 58.20617691163094, 54.35713544968636, 30.051005694174, 26.099553108215336, 23.524566119717015, 44.904662639864036, 56.62476355029691, 70.08560842083347, 13.04075510271134, 0.015252550102529988, 0.033329528486055714, 3.1475532583652006, 2.093695253133774, 19.6246789732287, 70.42602308334844, 64.72991789540937, 67.23470426374867, 59.335862667329856, 61.18136136762558, 53.649312373130556, 53.37459348863172, 47.495701928292554, 48.54312381436748, 45.54219292056176, 45.361257906883, 44.53235910784814, 44.588609818489324, 44.98278448658605, 45.138734002267164, 43.64854712640086, 44.16452707782869, 46.38216457059307, 44.14405622789937, 45.817660977763516, 46.64238637493503, 43.95741024324971, 43.5603997015184, 45.10514282411145, 46.54345635444888, 47.68430909802837, 51.43636603509226, 53.41873584255096, 52.14858216624106, 54.314534587244836, 55.18079003980083, 55.210753025547156, 55.81593944180397, 55.97860013284991, 52.08222350766582, 48.59178081635506, 44.51885830971503, 43.75650252065351, 43.101906007336034, 42.885520612039876, 43.67298349257439, 44.70084451859997, 43.38910195135301, 41.606549447582616, 50.508996132881414, 57.21398199758222, 55.142990158450225, 56.54129551303003, 55.549386932003884, 55.98885713085052, 59.92865439384215, 56.050783511131044, 56.38360838736258, 54.79476605692218, 54.043973415128654, 54.72803477318057, 57.82572661676715, 58.011643040564756, 56.20092399658696, 59.03940992970621, 54.72230026798864, 38.63749173379714, 56.682234118061686, 54.705343861733716, 56.954525055423865, 53.48489446024741, 52.444776027433335, 50.22171781909082, 49.60896907314178, 50.486689613711455, 49.60964372081142, 46.491532018107755, 50.34085196833457, 45.710619495761016, 44.629684878933816, 42.96616454278269, 44.47208012303999, 41.51336962176908, 41.98462670849216, 43.502179961050714, 45.26184151249547, 43.50783601883919, 44.607986327140566, 43.22111468161307, 42.47551133555751, 43.66210676008656, 48.028030318598596, 51.48545057542863, 55.38076816066619, 57.05174492251489, 55.813331065639375, 56.72210893323345, 55.65217264236943, 56.17380865158574, 53.932425129798155, 55.03995733876383, 51.29840058665122, 43.169919906123994, 43.94558429718018, 43.51147205598893, 44.321629770340465, 42.00783929517193, 43.83440079227571, 44.40889073956398, 51.23158693313599, 59.70452231745566, 61.59044104237711, 61.607542576328406, 60.425485334088734, 59.9706276770561, 60.87433392001737, 58.842879572222316, 57.65621354503017, 57.073976916651574, 58.35277549682125, 62.325465756077925, 65.18085318226969, 62.56859387120893, 62.36697619961154, 62.91203660349693, 65.3948930002028, 67.80716634565785, 23.269262967571137, 0.7060009517496633, 1.8725413588746902, 1.0111242725003151, 0.07621925970118854, 0.8984191331171221, 46.87844245664535, 65.91128087812855, 44.80740747144146, 30.138658900414747, 18.840689351481778, 32.21120792050516, 58.02566551393079, 60.359934683768984, 60.44381849227413, 15.513778117395217, 0.427221157738278, 0.05764604403427052, 0.03593552594764098, 0.1055621815424773, 0.009230522536522439, 0.03739637901045142, 0.05473157743953409, 0.022212365048847372, 0.006875068863718621, 0.019553434742133946, 0.03717121810862615, 0.10228740081431405, 0.12451839137582049, 0.11071105848156637, 0.0737363304341993, 0.17268755623409826, 0.1578108335454618, 0.2747293339381295, 0.14684914190682674, 0.15403058800485828, 0.10363909400879376, 0.23911085730839163, 20.37946851022782, 80.07846616929578, 66.26057578671363, 64.49926291742634, 31.024345774804395, 21.91867912969282, 24.485325198019705, 55.30508995056153, 63.100969329957046, 75.61589933210804, 15.57408553938712, 0.18842399811312077, 0.16551553301753538, 6.137868012151411, 9.35115602708632, 20.8325905184592, 72.67712623842301, 68.91268637872511, 69.12148198773785, 60.65295926986202, 63.81091440877607, 57.58044119804137, 56.23983390869633, 47.78702028336064, 48.983782491376324, 46.06036547691592, 46.78197568462741, 46.342842809615604, 46.81386847649851, 47.53391758088143, 47.81271573035948, 45.58349940084642, 45.866368970563336, 50.17867765118999, 45.31548384697207, 48.6587631317877, 48.89519576103457, 46.83637111417709, 46.18957227276218, 47.48928885306082, 49.4382792903531, 50.069620070918916, 55.02904138257427, 55.73287540866483, 52.33627542372673, 57.53608311376264, 56.862208151048236, 57.138229262444284, 57.16453659919001, 59.489133204183275, 55.82844003554314, 49.32629562193348, 46.63987213565458, 45.35558223724366, 46.030065167334776, 43.49027948994791, 46.58566497987317, 46.69641310168851, 45.8616425145057, 43.68406418831118, 52.66523284296836, 58.85991050351051, 56.235817401639885, 58.3686375617981, 56.57269408625942, 58.27301017699703, 62.572739816481075, 59.180172028080115, 59.39283901645292, 54.606951205961174, 54.376311917458814, 56.55467864005797, 59.4180049434785, 61.3661285369627, 57.45812208421769, 61.932993396635986, 55.46022753561697, 41.48190829061693, 57.54244519818214, 56.74433700499996, 61.33496138357348, 55.13121520319293, 56.66162206280617, 52.021156126453036, 52.449227917578916, 54.05936871805499, 52.68385625654652, 47.945825284527196, 52.3540751395687, 47.946609758561664, 46.24745468939505, 45.66386876567718, 46.00889613551479, 44.00216448691584, 43.36577169356808, 47.09320006832, 47.387766145890765, 45.23139215284779, 46.616024125006895, 45.31715869903565, 45.181205426493, 46.895445931342344, 50.68467909289945, 54.56363254977811, 58.60727848545198, 59.45621275132703, 58.51337694352674, 60.10588669007825, 56.984319379252774, 57.68855740947109, 57.31239426520563, 58.23260976422218, 52.78911698249079, 45.09316782797537, 47.3164653008984, 45.36435657931913, 45.85249162489369, 45.20669691024288, 46.59037574645012, 46.897564011235396, 54.3639878303774, 62.813867522824204, 65.27939488810878, 63.643680234109205, 63.542377179668804, 60.318726262738636, 60.91600125835788, 59.30795108118365, 59.81557246177428, 57.1650621967931, 60.27616070162866, 65.53826739711147, 68.46350439133184, 65.77350762582594, 65.22880807999643, 65.31353519808862, 69.25949450462096, 71.32478713989258, 25.767600959347142, 1.492063607419691, 5.350617920198749, 1.3892210226866508, 0.11123403606395568, 1.7045093495999615, 54.203892369424146, 72.17956573732438, 60.18754259232552, 47.6647953064211, 23.467717247624552, 39.96288807161393, 67.60375222852154, 69.08594531397667, 69.9367230938327, 20.81202357046066, 0.6478225800298876, 0.1680211001826871, 0.10598235012542818, 0.3187360596512595, 0.1680269377726701, 0.13932320139100476, 0.18714394180044053, 0.11689559436373173, 0.12630034253121386, 0.17550705090886162, 0.15589129299886767], [0.0734376250916431, 0.00976104608496591, 0.04431196578568028, 0.04708952863790816, 0.030287209477636124, 0.036594449662633484, 0.0347352845053519, 0.03550856982568099, 0.058715556402720755, 0.023726869164214983, 0.08915323704000443, 19.946481989276027, 61.18804508639921, 55.151564459646906, 40.74554212631718, 14.753967946575536, 25.406990012814923, 29.417072226924283, 42.41326724329303, 53.07682283463017, 64.51571333792903, 7.375474841363969, 0.20186790655697548, 0.09531967026451904, 0.9448090051451038, 1.095492371147679, 33.93930419798821, 70.27623561120802, 60.07531965932539, 61.744554888817575, 56.10252349607406, 56.46954359546785, 49.79363033848424, 48.0080379978303, 44.91048735956992, 44.93363326595676, 42.25625476529522, 46.40406316326511, 42.389807547292406, 44.63180688119704, 44.546263910109, 44.531162784945586, 42.19779183787685, 43.64636628858505, 41.76975927045269, 42.49436224660566, 43.32726186321628, 43.23111672555247, 42.849489719636985, 42.94126141455866, 42.40305339136432, 43.40394027771489, 44.80458728728756, 48.47450979294316, 49.834697554188395, 50.90026040231028, 49.714037602947606, 51.81122695246051, 53.76405739015149, 55.028068634771536, 52.4323421139871, 51.014562191501746, 43.83229840186335, 43.72321728737124, 41.18212546071699, 40.86434287409629, 41.2681116596345, 43.26781834325483, 41.33653740729056, 41.33221495536066, 41.92976843926215, 49.10272444448164, 52.034692225917695, 53.581176880867254, 55.55381528792843, 52.48584324313749, 54.37464491013558, 52.52589848733718, 55.47701135758431, 56.036302120454856, 55.45722300006498, 54.506244351786954, 57.33862707691809, 53.73416500706827, 53.75850331398749, 51.814407994670255, 54.30337936647477, 55.34155230368338, 36.850659924168745, 52.74808506811819, 52.908337423878336, 52.46232863395445, 52.94683940948979, 51.36099376986104, 50.058974758271255, 50.4637594376841, 48.336563956352975, 46.9361012981784, 44.58120438360399, 44.571759316229056, 42.092774298883256, 42.82088779634045, 41.37724768730902, 40.70263139663204, 39.67443304677164, 41.32746104271182, 42.82845012603268, 42.38957612745224, 41.07849251839423, 40.71105664776218, 40.34830800948605, 41.75045336446455, 40.958244416021536, 45.5641778053776, 51.1418431035934, 53.99253153031873, 52.90207732108332, 55.26144966002434, 54.98406356380832, 51.29638056601248, 51.62689516621252, 48.27752836288945, 46.63770698731946, 42.44007664342081, 43.02066587632702, 42.644447818879165, 42.132017612457275, 41.783758209597686, 42.81319602843254, 42.12986815360285, 46.644014158556544, 54.495077363906375, 56.121397941343254, 57.75921106338502, 55.598122381394916, 54.6119483055607, 53.73731467031664, 54.497501388672866, 55.397151900875954, 58.66534525348295, 59.90674795642976, 57.60603466341573, 58.88443316182783, 62.63139886240806, 63.08089071704496, 59.47571085345361, 66.77250785212364, 63.80522697202621, 66.9008791831232, 30.874977996272428, 0.8187911575359683, 1.6247995558284944, 0.36034333669850904, 0.012157938890008917, 0.3007841068169763, 34.19076342736521, 64.42150192876016, 38.0593422151381, 39.30525172141291, 23.564495848071193, 27.00519111848647, 45.01531662479524, 50.24087467501241, 56.89807430390389, 25.200789051671183, 0.20792147204760583, 0.025993740569139202, 0.07998751596577706, 0.034000407003106616, 0.06153879724743386, 0.02082724169257187, 0.11193592582018146, 0.06423365324735641, 0.011606964624426779, 0.00945949855621063, 0.03157800442779497, 0.0568836716364228, 0.0198747722371932, 0.044697568481487614, 0.049914562128364086, 0.03811653613323166, 0.03968956745079449, 0.02430767680878841, 0.02012204818217264, 0.07812858063487277, 0.0663271110745207, 0.09784263528643117, 27.98237708307082, 69.99544882005262, 62.2252413534349, 47.07912268177156, 19.009149266827492, 25.512095805137392, 26.14160091646256, 49.428967583564024, 57.66032811134093, 69.3876697171119, 7.909360902924692, 0.14362314565768167, 0.20585999073040104, 3.493836031806085, 0.4590313653311422, 38.010206683989495, 73.06933972143358, 62.440744215442294, 62.338872417326904, 57.51583583893315, 58.4076847568635, 51.89171006602626, 50.22776219152635, 46.833456793139064, 46.17704030006163, 44.66053039796891, 48.79244927437075, 44.047899323125044, 46.21762506423458, 45.94218838599421, 45.62315848565871, 43.56058797528667, 44.86258345265543, 43.2780949531063, 42.85317674759896, 45.67910717379662, 44.79590708209623, 44.69441967625772, 45.20006810465167, 43.57788170537641, 44.56645234938591, 46.864314079284675, 51.43926074427944, 52.4978417734946, 51.46579950086532, 51.706440833307084, 53.247665589855565, 55.66147258204799, 57.406844938955004, 54.53279879785354, 53.2551847734759, 46.875281026286466, 46.04638222725161, 42.17646983362014, 42.9014140559781, 43.44181468409877, 44.049397668530865, 43.81400838974984, 43.103576937029445, 43.490679571705485, 51.08112089095577, 54.57916121329031, 54.84457231337025, 55.49837258554275, 53.82286548614503, 57.3025373489626, 55.91390063685756, 57.94221708851477, 57.01490209948633, 58.764436091146166, 58.65829675428329, 60.0319068662582, 55.901823659097, 55.23851948399698, 53.807501562180065, 56.002040216999674, 56.67891187052573, 38.95598426941903, 56.50339365005494, 55.10884200373004, 54.60720616002237, 53.20500589186146, 53.13306570053101, 51.13452788322203, 52.35692670268398, 50.204184824420565, 50.6832552725269, 46.08894386599141, 46.185638135479344, 45.14928125566052, 42.96766681055869, 43.22651578534035, 43.134347931031265, 41.64550642813406, 42.63879176109068, 45.09265007511262, 44.800743364518695, 43.67677642453102, 43.97169159304711, 42.558230200121486, 43.68107534223988, 43.02567474303707, 49.08301845673592, 52.86880385491156, 56.33828932239164, 53.7087284365008, 56.11931516278175, 56.56194679198727, 53.909781286793375, 54.91786180003997, 50.77973773402553, 48.259371711361794, 43.94019103819325, 42.413090736635276, 44.96836977620279, 45.59432122015184, 43.34408098651517, 44.18701794839675, 44.1329872992731, 47.69613504409791, 56.23176951562205, 58.11924934387208, 59.20519674977949, 56.67696245255009, 54.33301679549679, 53.305481326195505, 54.373350527978715, 58.04164132764263, 59.633613709480535, 59.777380343406435, 58.78764083308559, 61.5364182379938, 64.02152215280842, 65.37580282457414, 60.95431497020107, 65.47418763560634, 66.71657485346641, 68.98188483330512, 34.11760337891118, 1.5541772808759444, 2.003281801458328, 0.8282508725120176, 0.07318586561708681, 0.14722809495945133, 38.33340214144799, 68.68624010393697, 44.649277117944536, 39.176217509854226, 24.29693179745828, 33.92036699479626, 50.396498633969216, 57.32533808677428, 64.51792947707638, 33.12223918976323, 0.2585234793443834, 0.026875197504376693, 0.015243605068404109, 0.06460217984333154, 0.01269633207665456, 0.05260599754570473, 0.0444530715204535, 0.031684239755474755, 0.0250378294637607, 0.02996929064993897, 0.021162393668125716, 0.15209526604702397, 0.10837202350939475, 0.12897326160342465, 0.17645033497002818, 0.22684499290921997, 0.11183102540070973, 0.12390637139399206, 0.16554548705537475, 0.14036396247965677, 0.1051323219472843, 0.14238180742869455, 32.99840604105304, 79.39528342216246, 67.51141963466522, 56.2338875955151, 21.848211788362075, 37.49167719194966, 41.08281497032412, 58.627517915541134, 64.4200937978683, 74.878752616144, 9.627791970006882, 0.22839448234486967, 0.37737822100039453, 8.31240846264747, 4.8086875677108765, 37.13371384528376, 78.31683558802452, 63.51040594039425, 68.37979316711426, 60.03973199475197, 60.79300749686457, 53.38852574748378, 52.38295947351764, 50.55009472754694, 48.92841431402391, 45.94522430050758, 51.81382748388475, 45.7127885664663, 50.05726852724629, 48.81759951191564, 49.968105208489206, 45.789298319047504, 46.3982266764487, 44.65741603605209, 44.53052736097767, 46.672557246300485, 47.04243283117972, 48.38702524861982, 48.05160768570439, 45.170356150596376, 47.408766515793346, 50.01924114842569, 54.44519266005486, 54.601389285056825, 55.59754187060941, 52.39998256006549, 55.85107603380757, 57.296057593437936, 60.77530976264708, 56.51717293647028, 54.8241053858111, 48.53865623474122, 48.56129223300565, 44.104965886762066, 44.690830707550056, 45.1470455046623, 45.6783462339832, 44.21513349779191, 46.333142788179465, 45.95641874497937, 54.00598918237994, 56.76202689447711, 57.05540841625583, 59.37727897397934, 55.1692190477925, 58.010144695158935, 57.81185711583784, 62.365258201476074, 61.00444286100326, 61.51025210657428, 58.63998320794875, 61.45690394986061, 58.339808141031575, 57.31441428584438, 58.12791385958272, 57.998969862538004, 61.259381232723115, 41.65048391588273, 59.019186189097745, 57.871426151644805, 55.2551503335276, 57.571274618948664, 55.40111741712017, 53.64283261760589, 54.92836198499126, 52.86454416090443, 52.886199566625784, 48.80396927556684, 49.88860268746653, 46.822077997269176, 45.539776740535615, 44.94453353266562, 45.62677883332776, 44.8485178332175, 45.899026624618045, 48.73488456972184, 45.82309346045218, 46.66527732726067, 44.102169236829205, 46.18812099579842, 46.96979445795859, 45.26355558826078, 52.44053202290689, 55.414320115120184, 59.489796084742395, 57.073988683762096, 59.43216862217073, 58.35832565061508, 56.714668197016564, 58.603626758821555, 54.119977181957616, 52.13484210352744, 47.24656866442773, 47.130384137553555, 48.26914625783121, 46.19924875997728, 46.39904645181472, 46.421804043554495, 47.19027873008482, 51.56332531282979, 59.47040780898064, 59.25268880782589, 64.40749122250465, 59.87167804471908, 56.24922014051869, 55.73800586885022, 56.91607798299482, 58.010168229379964, 62.17901229858399, 64.10379778954291, 60.64212568344609, 62.32866248776836, 67.29167276813139, 69.05219724101406, 64.62534358424526, 68.72453812629946, 68.92912110974713, 70.8419276821998, 36.418242146891934, 2.329804777137695, 4.299667371857551, 1.5477475355709753, 0.1277339228639199, 0.5462349086038528, 42.64481652167536, 76.72465139819731, 52.91571540217246, 52.10474967956544, 34.68646472500217, 40.381330443966775, 60.34574747085572, 66.95382333570912, 73.96431476839128, 40.916851643593084, 0.5721444312122561, 0.15215883602298078, 0.13486221012088562, 0.2222013356344354, 0.11205006526002001, 0.1704518205576366, 0.14300027020996617, 0.17017327098836824, 0.10621082818796558, 0.2359479407389318, 0.10514569018156299], [0.01668834442933721, 0.04359157883652276, 0.06707939409440564, 0.018613889190037886, 0.04193183785725025, 0.019046862932643103, 0.03978348983031127, 0.06050468580196462, 0.07754784768387195, 0.08321574919166104, 0.13694431452501205, 31.20753222896207, 59.350038113132605, 52.060736763861875, 41.058331535708525, 20.471108805748727, 47.40688377811063, 47.08632415340793, 36.62168764298962, 59.95734653165264, 51.27773754058346, 6.255280731185791, 0.2115113907043011, 0.1589701697230339, 2.2424435423266504, 5.310948539164759, 54.59345040782806, 65.94929648983863, 62.89490369058425, 62.51865817654518, 58.36313055407617, 54.511731747658025, 49.774901020911436, 46.76584297610868, 42.61596748905797, 43.376366015403505, 42.15030370220062, 41.91623233979748, 42.38764239895729, 44.00430217865975, 44.75866417731009, 45.89652807481828, 42.43598953370125, 41.499833522304414, 41.660352599236276, 42.97744920176845, 41.33942034936721, 41.32654320809149, 41.644772944911836, 40.44405306539228, 41.700486290839414, 41.29866692327684, 42.88013127542312, 46.304654613617934, 46.72265768051148, 50.40693606099775, 52.189402272624356, 53.88649025271016, 52.53826964286066, 53.63099098205567, 51.524199670360936, 48.08100977251607, 42.075178546290246, 43.813118011720725, 40.94770500736852, 42.62295323033487, 39.11642489894744, 42.705013136709894, 41.054875927586714, 42.79913433136479, 40.909116729613274, 44.79852722537133, 53.76556358029766, 48.14418738888156, 54.56684497094924, 53.50266671949818, 50.668342421131754, 52.80653230605587, 52.35491844915575, 54.32574079882715, 53.276440097439675, 54.367608178046446, 52.284088288584066, 50.16167809886318, 46.246481941592315, 51.569040206170854, 53.99053504390102, 54.80904740671958, 34.167221361590975, 50.49168671331098, 55.97561128677861, 56.25125977300829, 54.662233091169796, 50.93878592214277, 51.802621272302446, 52.123188741745494, 49.23062509106052, 49.289746976667836, 45.83493117363223, 45.956454046310924, 42.91129842881234, 40.6058116112986, 39.405432977984034, 43.08208627085532, 38.315618115086714, 41.424006262133204, 41.08801211080244, 43.318389461886504, 42.16937034360824, 42.06004996453562, 41.53882972655758, 39.4030717111403, 42.043940790237926, 42.50306206364786, 47.658896061681936, 55.447189577164195, 52.835169530683956, 55.42982916678152, 53.36326960594424, 51.48070450752012, 45.09653714395339, 42.64772299797305, 42.39319255275112, 40.845680236816406, 41.534381758782175, 41.906347966963246, 41.08741983290642, 42.99437422906199, 45.47299446598176, 45.992057400365034, 50.95365562746602, 54.80513680365778, 56.19414221855902, 54.76959228515626, 50.94529313425864, 53.49462586064493, 58.48046433541083, 58.22481209231962, 60.289649732651256, 59.431925435220045, 58.523010284669944, 60.56325858639133, 61.00301904063071, 59.10212862876154, 59.12530983647993, 70.82255117354855, 68.32553109815045, 61.51570812348397, 63.59964770655479, 34.068440391171364, 1.0394597197732618, 1.5781894182005238, 1.0030057016880283, 0.14689210411762038, 0.021436838921339765, 17.788617495567568, 66.82715431336435, 45.146629733424035, 44.862022553720784, 34.28727334545505, 26.80086897265527, 50.69299059529459, 57.52455526782621, 57.130400211580344, 34.46730229162401, 0.7189783586129066, 0.07677232155636435, 0.039846492901204095, 0.08885804038014143, 0.05905214479313262, 0.04902670069807961, 0.06746957799600017, 0.09886143263429405, 0.05928780109952054, 0.06301024913667672, 0.0782609376455507, 0.029388735814380552, 0.10594665042815671, 0.04900065753909369, 0.04577146670330436, 0.04423820300989094, 0.027481613553039012, 0.060449412558227784, 0.1116762603182466, 0.023213841148742267, 0.04040395976194451, 0.2504353375444489, 39.68199537646386, 66.32372594648793, 58.91491782280707, 44.15822382896177, 25.716635642513154, 42.438570453274636, 40.2001836222987, 44.58882947121897, 63.68590847138436, 60.19912535144437, 6.608029286707602, 0.2683769635135128, 0.26350850539822734, 2.7223957882773493, 5.820453638030637, 58.00064863697175, 66.3216314008159, 65.66577188430294, 64.34603160427463, 60.4546756129111, 56.54587684139129, 52.93360925489857, 50.294324813350556, 45.811243980161606, 44.974461217080396, 44.30900758312595, 43.36856834350094, 43.399343259872936, 46.23353027528333, 46.23690351363152, 47.41981975493893, 45.49310445785523, 44.09566594708351, 42.855106553723736, 45.324234654826505, 43.98332142060803, 44.36314805861443, 43.92363079132573, 43.108730931435865, 43.08238829335859, 42.045956888506495, 45.832369865909705, 48.34967643983903, 48.01102684390161, 53.50443570844589, 53.88511350077968, 54.611140297305205, 55.45149241724322, 56.06870874281853, 55.30947516041418, 51.48172040139475, 44.448891070581254, 44.4019599114695, 42.582552817560014, 44.02936220169068, 42.21026889739498, 44.46465115393362, 42.46986312250937, 44.816699566379675, 43.092186374049035, 47.64113556954169, 55.65752275528447, 52.79259220246346, 58.463641289741766, 55.715397327176994, 51.81259193728047, 54.11484672177223, 52.741487641488355, 54.52090617149107, 56.012862036305094, 56.269373278464045, 54.35089103637203, 51.34237820102323, 48.30966434171123, 53.6305477542262, 56.10329620299801, 57.061084085895175, 36.45060170081354, 50.91811895370484, 58.185702139331454, 58.8349759963251, 56.29016576274749, 54.01470468890283, 53.40342290939824, 53.790333347935835, 52.60591483885243, 49.9380833871903, 48.825052015243045, 48.34195329296974, 45.55954940857426, 43.618846939456084, 41.50729387037216, 44.82759983308854, 40.85421531431137, 42.541281638606904, 42.99729247247019, 44.69372149436705, 43.98860877560031, 44.53962725977744, 41.9423278685539, 41.64616930869318, 42.716187969330825, 44.61965145603303, 49.775081449939364, 58.44024042929373, 54.13234441511093, 57.004672558076926, 56.39236311758719, 52.936719694445216, 48.11883711045789, 44.49803052410003, 43.74288012904506, 43.01041280069659, 43.69940065568493, 44.406635376714895, 43.52702425372216, 46.33889298285208, 46.95332050323487, 48.439557552337654, 53.415656781965694, 57.82032551303987, 59.78727648335119, 55.693898816262525, 51.2541131050356, 54.90714980709938, 57.79077829853181, 59.92248842793127, 60.84407675650812, 60.70595049089002, 61.93712757479761, 63.040447158198205, 62.390467274573545, 61.587844433323035, 60.12892669247043, 68.75863136783724, 68.39774193302279, 65.09083478681504, 65.96289142485588, 35.853977818642896, 1.9832093172496366, 2.775467172745736, 1.887828674047224, 0.0515093196994595, 0.05597706020419156, 19.618273742737312, 72.75132179260254, 52.25585506808374, 45.51283005745181, 35.97861505323841, 36.05904325362175, 58.18076779765468, 64.5351565268732, 65.01472511599141, 44.01446111740605, 1.2765608679863716, 0.09826845759826322, 0.055787606660517, 0.041813822012514844, 0.030147231807331407, 0.04973404500032625, 0.06109928111395529, 0.03457808709372917, 0.036993255883815794, 0.039797850148451906, 0.024358705925424735, 0.10441290409935099, 0.24534453007002033, 0.18404802728083827, 0.11696532368659975, 0.131158726590295, 0.11502871470105265, 0.13219435488985432, 0.3231609222148696, 0.14213232323527336, 0.1457823491505077, 0.5754082109178267, 47.58797568659629, 76.81266938486408, 67.02746191332417, 53.28505362233808, 28.95594466117121, 60.227629215486594, 57.07180392357611, 49.36648422671903, 70.20395417367259, 65.471289004049, 8.6311500687753, 0.42102341450029807, 0.5874375686530144, 7.7980126584729845, 7.92470766652015, 59.63688496620425, 69.6054946222613, 69.01801770733249, 66.86993168246362, 62.36641137830673, 61.55349623772406, 54.36656482758061, 51.14701670985068, 47.67609565488754, 48.32413004290674, 46.848538306451616, 46.426279467921105, 47.13001543475736, 48.32726793904459, 49.761980733563824, 52.263637050505615, 47.293189956295876, 45.301610423672585, 45.70275122119535, 47.96957523592057, 45.76026101266184, 46.08070296625937, 45.340524258152136, 45.10710008682744, 44.780900093816946, 44.61949063885597, 47.80709497390255, 50.70666397771528, 51.19818010637837, 55.91584613246303, 56.19778217807893, 56.9031733851279, 58.12806683201944, 60.30132270628407, 55.34641996506722, 54.41247617044757, 46.39956812704764, 47.50065980419036, 44.86494864186933, 46.640633075468, 42.87640110138924, 45.82247764833512, 43.64609956741334, 46.382101812670314, 44.00734986028364, 48.95764773891818, 58.21147603373374, 54.218762074747396, 58.18703182281987, 57.89897295736498, 54.26685817780034, 57.084206458060976, 56.56936399398312, 59.2084680065032, 59.32979083830311, 60.1760265134996, 54.87814780204527, 54.376323684569336, 50.254536290322584, 56.19355386303317, 59.58024201854583, 60.45150633781188, 38.89841564239995, 53.847564651120095, 60.0537819247092, 60.840899636668546, 58.9756400354447, 56.092074301935014, 55.20422227921025, 56.10435132057437, 55.42157649993897, 52.37788784888483, 53.24616332207957, 50.5608694784103, 47.85016259839458, 46.88493005691036, 43.87121223634289, 48.88111445211595, 43.62582875836281, 46.1318898970081, 44.90328196556338, 47.66906284516858, 45.86395279053719, 46.9738737229378, 45.7517808483493, 43.48136394254623, 45.323536472935835, 47.44333436412197, 50.977711523732836, 60.112997947200654, 56.477211829154726, 60.21503448486329, 59.071671424373505, 55.59567090003721, 51.28134219877182, 46.67889187412877, 47.73876336313064, 46.08625704242338, 45.02532259110482, 47.33373549676711, 47.23548796869094, 48.35743488803987, 50.090102687958755, 51.10631427457256, 57.07052523089994, 61.14581292675388, 62.86572517887239, 55.874155259901485, 52.14100414706815, 55.25305578785559, 61.41926488568706, 62.57995305522796, 67.04964683901879, 64.61654570794875, 65.18395185470581, 65.96435054655998, 64.29091838098341, 63.68672040201003, 62.5938186337871, 69.68150231146043, 69.98922009621897, 65.49620782175373, 70.40943145751953, 39.71495505302183, 3.0853221589519135, 5.7044872929973, 3.124968005764869, 0.3978806950392262, 0.21540598252848273, 23.738460809953754, 77.7200940347487, 58.94290393398654, 61.71495276112711, 47.653479268473966, 39.839655045540106, 65.76614141464233, 73.13839697068738, 73.46205526782622, 53.50271771031042, 1.9946240273214157, 0.19695195099038465, 0.11555351557270174, 0.1483464760765914, 0.21669440452129612, 0.08616180925239479, 0.15267098112212074, 0.12140597532232925, 0.1945940855770342, 0.135396801596207, 0.1235948417395834], [0.04955674927201002, 0.007841963754711493, 0.011128016987875586, 0.020554142838884747, 0.06467151080047892, 0.04346114853697439, 0.06687415913949091, 0.06806454486063412, 0.045159933187307856, 0.039814642795752135, 0.08362618845797355, 36.444039575515255, 58.94989359763361, 53.256530146445, 36.67822468665339, 14.653812185410532, 51.63483796581146, 55.51123795970794, 39.069191717332416, 63.665555292560214, 42.99437030669182, 3.2477100001227472, 0.2610818759327935, 1.1207415259653524, 1.7860654765559782, 10.048579919722773, 68.27901963264712, 62.66057345174975, 64.46598160651423, 57.35126887598346, 57.40245188436201, 54.05376757344892, 50.472070940079234, 45.79127911598452, 42.66668373538602, 43.4712952183139, 43.59403402574601, 47.59415341961769, 49.179391091869725, 50.66624787545974, 54.85526861683015, 49.631812957025346, 50.509686470031745, 46.644708418077045, 42.81788326078846, 41.66018001494869, 40.40469600308327, 41.57868885224865, 40.425327670189645, 41.2592274911942, 41.569839985139915, 40.460891800542036, 41.679325103759766, 41.9008997947939, 47.73545680507537, 48.68668648504442, 51.911529802506976, 52.366505130644775, 53.52800130844117, 52.50265059932586, 52.92093607687181, 43.38089635295253, 40.494875215714984, 42.22228703960296, 40.47191758309641, 40.806833082629794, 42.66893517586493, 40.896988761040475, 42.82093878715269, 42.39276501440233, 39.47620430300313, 41.52650563947616, 54.57315214218632, 51.980084988378714, 49.13515852343652, 55.211109961232836, 53.52584792721657, 50.138136033088934, 48.37304592132569, 48.070301701945645, 45.95705024657711, 46.449174342616914, 43.55119389872397, 44.18461745785129, 50.84306440045757, 54.32956118737498, 55.93289667560209, 56.83622637102681, 33.96456033952775, 46.67862907532723, 50.50278309852847, 51.88631288466915, 54.280621774734996, 54.171603418165645, 55.25658984338084, 52.63370090915311, 53.580106073810214, 50.9391075564969, 50.287354761554354, 46.85680274040469, 45.73797802771292, 41.399758169727946, 39.21125604260353, 40.10364232524749, 39.705247186845355, 40.69646150835099, 43.123883047411525, 42.74642159861904, 44.278613136660674, 42.865571437343476, 42.020108469070934, 41.127326027039565, 42.32073460855792, 42.45282434648083, 44.69082286280971, 53.59397949710969, 54.00426333950412, 54.6833001413653, 54.706916732172814, 50.23660713626493, 43.966086526070875, 43.07399049881966, 42.64606775776033, 41.98799210210001, 41.92337889825144, 42.08245062058972, 41.89357280731201, 45.0294332350454, 45.498733059052505, 47.31448842633156, 52.248947774210286, 55.565437270749, 58.157637580748535, 53.729097304805634, 58.316007198825965, 59.094291733157256, 55.8554651660304, 54.489378160045995, 55.73655066951629, 56.127387400596376, 55.423961301003736, 56.99525102492302, 60.36661448017244, 59.22075679225307, 65.07778898362191, 48.51080740651777, 49.648749751429406, 60.20486377900647, 62.52695006708946, 36.41064843823833, 3.32042706589545, 0.992995567860142, 0.44921609362767595, 0.10046726783677455, 0.06596557120041502, 9.03329989602489, 65.66401466246575, 48.751727227241766, 46.18229235372236, 30.260603427886966, 13.999055835508532, 30.941226828482847, 45.86638466004403, 57.69231896246634, 46.965522996840946, 2.5201887805615706, 0.2286013260844254, 0.029195777418452407, 0.032345749017211704, 0.015282030123466206, 0.05165506792705386, 0.016634796798649817, 0.09688331700500943, 0.00942319556469879, 0.0761336493756502, 0.04893531023915257, 0.03115095062962463, 0.05555853487983827, 0.018725711213905486, 0.03473156897891914, 0.04050020721831149, 0.03723442802325853, 0.06063858264937036, 0.0513307752478267, 0.050351864267741485, 0.06964818649594823, 0.6693007436490829, 46.97226162879698, 66.63027486493512, 58.458471605854655, 42.837012660118845, 16.07569981005884, 41.37425491886754, 56.969430062078665, 43.1976471408721, 70.26365264769524, 49.441821190618704, 4.403291979143697, 0.31519259656629256, 1.2114093188316593, 2.188036345666455, 12.059574204106486, 70.94776107418922, 63.726171601203184, 67.45312536916425, 59.406853645078606, 58.196876971952385, 55.798461360316125, 53.69857734249484, 48.53235690824447, 45.52734282708938, 44.53572450145599, 45.870718879084436, 49.741674623181744, 50.50921578561106, 52.97069134250764, 54.92319230110415, 53.106895646741314, 52.352565027052364, 48.82487943095546, 45.5224516314845, 41.84187204607072, 42.43017265873571, 42.79535708888885, 43.140215796809045, 43.490659959854625, 42.68357738371819, 42.83042307822935, 42.64076863565753, 43.56497318513932, 48.639335632324226, 51.015829117067405, 54.6770243490896, 54.06193394814768, 56.09320786691482, 54.8818701313388, 53.91213078652659, 44.79751525386688, 42.0121499799913, 43.35996266334288, 42.016095884384654, 42.31203086914555, 43.78493185966246, 44.641593194776966, 45.8344957905431, 43.70745720401887, 41.2473976227545, 43.03632397805491, 56.57003864165276, 54.03680724482383, 51.107985204265965, 58.386503957933, 53.78631684087939, 51.715583878178755, 50.690025283444314, 51.42030392923663, 48.217508254512666, 48.23557861389653, 46.8925904458569, 46.696483704351614, 52.62185927360289, 56.863475076613895, 56.93829428765082, 58.41841243928479, 35.81500122624059, 46.5447703484566, 52.63833715069679, 55.4027138217803, 56.40782902317663, 57.29309228158767, 56.497517939536806, 54.00562047958375, 55.578102604035415, 53.63192058378651, 51.21242615484422, 49.29113157333867, 47.938015845514116, 43.577042318159535, 41.35109332300002, 41.081081282707956, 40.79987087557393, 42.044654661609286, 44.42072453037385, 45.16878328015728, 45.682166622531035, 43.44487805520335, 43.59585400550596, 43.345579331920995, 42.30812811082409, 44.971272330130304, 48.3160303485009, 56.36113712864538, 55.36201530887235, 54.917124394447576, 57.38202025813442, 52.42225770027407, 47.428754914191465, 44.903309422154585, 44.28408092068088, 42.843429657720755, 43.825387185619725, 43.350086135248986, 44.30169628512475, 46.49799608415174, 48.528752250056115, 49.728158135567945, 54.148500657850704, 58.03804451419462, 58.4717841302195, 55.57589823199857, 59.15406865458335, 58.726871552005896, 58.592040077332534, 57.32580484882478, 58.09107495892433, 57.46462537396339, 58.03666776226413, 59.05943362943588, 62.342100527978715, 61.83769941329957, 64.7199668422822, 50.29088881707961, 51.796133672037435, 60.09808117343534, 63.03301818909184, 40.26696589685256, 4.088968677866844, 3.145545004836975, 5.157327930773459, 0.3252374801424242, 0.08369183453220515, 9.248060449477165, 70.72292297117173, 54.68124481939501, 46.72674086786086, 35.833314772575136, 22.28181019906075, 38.219629872229795, 53.848078481612674, 62.356432868588364, 58.07114147370862, 4.994024461315525, 0.3160849970675284, 0.016886701829911723, 0.037455344797983285, 0.038073098947924953, 0.029393230835276268, 0.05248589411137566, 0.013830499393084358, 0.025214441458604513, 0.04939746810123325, 0.027030569711519827, 0.17200187689835028, 0.11971215492174511, 0.12671308772217843, 0.1380938447771534, 0.1502530697372652, 0.11745631709815034, 0.15906662019270082, 0.2036669414730803, 0.1954860877125494, 0.176848731334171, 1.404497306193075, 57.43617642310358, 75.41002196650352, 70.57526926840507, 49.907704630205714, 24.284713614371515, 63.88791837999898, 66.65779421406408, 50.472482788947325, 75.90767660448628, 54.73713467198034, 5.728686846071675, 0.4901160570161958, 2.532593031083384, 7.258999078504502, 12.438302578464633, 74.89908618311729, 66.3426160812378, 70.185730841852, 61.22902600995956, 61.517100564895145, 59.116633553658765, 56.21533870697022, 49.910736622348914, 47.86623254899056, 48.16004553148824, 47.576957748782256, 52.47467233288673, 52.78037794174687, 54.32734112585745, 58.8528698490512, 54.67094859769268, 54.58867688332835, 51.31385472513015, 47.67824903611214, 44.29829166781518, 45.66942676421135, 46.26732933905817, 45.62168367447392, 47.115549733561856, 45.02752304077149, 43.86725456483903, 45.92733829252182, 46.172764916573804, 51.427646606199204, 54.6779029600082, 56.926550711354906, 56.82128606304046, 59.80224817029892, 57.972297745366255, 58.950811432253936, 46.889295654912154, 45.02056867845597, 46.00010610395863, 44.51245307922364, 44.550955064835094, 46.80809082523469, 45.31433067014141, 47.66614460176038, 45.370891248026204, 42.47904931345294, 44.684649052158484, 59.13958726390716, 57.38111026825444, 53.548123067425145, 58.300890384181855, 56.181798519626746, 55.24319102687221, 51.782852526633974, 53.36223410021875, 49.39406241140058, 51.575225783932595, 48.75056620567076, 50.21150004479193, 56.35391996752832, 58.841530276883034, 61.77364318601547, 59.59751613678471, 38.34780900709091, 49.42831647011542, 54.50682486257246, 57.326279455615634, 58.6554491135382, 58.34881782531739, 59.42109184880411, 57.252597731928674, 59.032428110799486, 55.65265117153045, 55.81622969719672, 52.458319971638346, 52.29907174264231, 45.21866406163862, 43.90392872595018, 44.72867765734273, 42.82875999327629, 44.53444188640964, 47.74552160693754, 46.522946280817834, 48.27785391961375, 46.398505164730935, 45.39913623563705, 45.11012423423029, 45.72089218324231, 47.33379040994952, 49.21013070691017, 59.105380273634395, 58.269672239980395, 60.19338692388227, 59.884719925542036, 54.56668415377217, 49.30250252446821, 47.327224362281065, 45.6176632450473, 45.53619561656829, 46.28458776781636, 46.15248626278293, 46.97394824797108, 50.115558870377086, 51.046439293892156, 51.99220903458134, 56.12439855452507, 60.22160837727209, 61.10792675325948, 56.87055103240475, 61.31429441513554, 62.7481129092555, 61.01152666153447, 60.80946968447778, 60.6653892609381, 61.12648348654471, 61.07764997789937, 62.827595818427305, 65.98448015028431, 65.21480521848126, 65.96544096546789, 51.43080019181775, 58.00452786107218, 61.11972132036763, 65.6730047349007, 41.318714157227554, 5.931729808930428, 5.507117548296529, 7.0878606746273665, 0.35781114031710937, 0.19128734366066996, 11.028065373820644, 76.61788448210686, 59.64828729629517, 59.599759732523275, 41.565580291132775, 25.909896704458422, 46.53847886670021, 63.72981940546344, 72.30770957085394, 69.19950577520555, 7.144004500681355, 0.5253250596504058, 0.13755027475135942, 0.11012104054492329, 0.14388583720691744, 0.11422615333069717, 0.0967714911507022, 0.2581665743022196, 0.17584092734802156, 0.22787744960477277, 0.13274400765376707], [0.026307857685512113, 0.026472828974346482, 0.07142169536241601, 0.05135166646552183, 0.02050572608207022, 0.08107151505687545, 0.02897555395329912, 0.03864887147961605, 0.010788459049147225, 0.059164296234807665, 0.991321818963174, 46.71465604535995, 59.39310181525446, 51.97150284244169, 30.867296034289947, 30.4932293968816, 50.59956758253036, 49.56225364438949, 46.32855361507785, 58.452089909584295, 44.241636953046246, 2.1033565411644597, 0.08318299893289806, 0.21971469084101342, 1.0627464637640984, 27.957419041664373, 69.41101566437753, 61.78374721157936, 61.92164990209765, 58.52342605590821, 58.48238629679526, 53.794487137948316, 51.44945106198711, 45.39477063763527, 43.885964270560976, 44.64331511528262, 52.5399366501839, 52.13760737449893, 56.88628758153608, 55.37673988649922, 53.25156442580685, 54.64682602113294, 52.60693465509723, 50.54931025351248, 44.590731820752545, 41.81911837670111, 42.09483354322372, 40.72245505548293, 40.726020489969564, 40.154358571575536, 42.82939541724421, 41.963685174142164, 40.997699537584865, 43.15102584900395, 44.12522492870208, 47.54129948154573, 50.24025101815501, 51.86613621250276, 52.37404000374579, 51.77747103475755, 45.32229700396138, 41.85153676617531, 40.86073821590793, 41.06082616313812, 42.57123677961288, 39.42863379755328, 40.964665335993615, 43.18516615898379, 42.501093033821356, 43.619737317485196, 42.523058306786325, 40.44587304515224, 45.53782732255998, 55.118973485885135, 54.03606591686126, 49.37837685308149, 53.4084435432188, 55.895818510363185, 49.86187957948255, 49.9119996255444, 47.7662552556684, 45.10959079188686, 46.289271077802105, 47.748004467256614, 53.190434286671305, 55.41494377197758, 54.60284840676093, 52.29527488831551, 36.92825617328767, 46.174133823763945, 48.481311182821955, 51.50759235505135, 52.55304913366995, 49.95170185642858, 52.6638247120765, 54.06461292697538, 53.14734312795824, 52.49420573634487, 52.73800457677534, 47.647670238248764, 44.94819702640657, 41.7117238813831, 39.19522923807944, 39.18697657123689, 40.390469566468276, 41.0113807647459, 43.268775401576875, 43.19993780505273, 42.74106756333382, 42.10922471938595, 40.96401030017484, 41.88307262236073, 41.0801830599385, 41.75696057658042, 41.97584452167634, 54.29243595369401, 53.18611183474141, 51.709986655942856, 54.31709197259719, 51.76755920533211, 47.159837215177475, 44.052731683177335, 42.354831772465865, 41.72641315767842, 40.39408206939697, 42.01355811088316, 42.426787653277, 45.330420232588246, 48.37318712665189, 53.402536453739295, 53.62606056274907, 56.79033464001071, 56.36485161319856, 58.465229849661554, 56.852763083673295, 56.35488879296088, 53.896464840058364, 54.630430513812655, 52.90911797554263, 53.002846933180294, 51.43930389035133, 58.74934673309327, 57.981942853619984, 63.17378420983592, 54.1307480104508, 46.229282348386704, 56.7061056629304, 57.018832314398985, 59.563779830932624, 40.91486692428589, 3.3738080724593136, 1.9576211225601936, 2.671857519495872, 0.08763804536072478, 0.0802287953575292, 2.875956580523522, 54.02447531300207, 59.58589807633431, 47.32645557772729, 35.652881822278424, 21.15264807977984, 27.753549929588075, 48.8976433200221, 52.9698048868487, 52.14451466837237, 6.4860327878306, 0.2750995382666588, 0.1135304382431411, 0.09395772681361246, 0.1000537948622819, 0.05753974167389735, 0.13599978940140817, 0.032625784797053185, 0.005428864359630333, 0.008172802176446685, 0.09156814536019679, 0.025297075532557025, 0.04057254124012205, 0.07045801037982588, 0.08305241924620445, 0.07112620758914179, 0.05448105519697551, 0.01907369707741084, 0.01306771809580706, 0.024366732611651384, 0.061894664240460244, 2.2352334905055264, 59.603360468341464, 66.46136191583449, 58.39179915766562, 38.673287283989694, 36.65558476601878, 57.6081645104193, 51.737388333966656, 50.34135403171663, 64.74685468981343, 47.3388228108806, 1.8968602990911854, 0.18779782848733087, 0.6402074209144039, 0.7318163374739309, 30.208757538949293, 73.6105562025501, 65.19445988439745, 64.98455816699614, 60.37093693210233, 61.134900892934496, 56.46919450452251, 53.651920749295144, 46.91742297141783, 46.57907539798368, 47.29234664670883, 54.24796804305046, 54.24900354877595, 59.37459999515165, 57.59921758405624, 55.63677341707292, 56.314052997096894, 53.24860303632675, 51.437499600072066, 47.55521997328728, 43.13972942290768, 43.318820922605454, 42.345437695903165, 41.93559708133821, 43.59647766236336, 43.676517548099646, 43.30473569131667, 41.55155781776675, 43.98083463791878, 47.645403108289166, 49.89951864365609, 52.60142372500513, 54.588233655498875, 54.22013098193754, 53.88058708560083, 49.43388231338994, 41.997629365613385, 42.93966108752836, 42.60072515856835, 43.035300239439934, 41.48476769847255, 42.98279931468349, 45.492316061450595, 43.610162811894575, 43.69749830615136, 42.53161299613215, 42.330921003895426, 47.32067792646347, 57.137048629022416, 56.396936601208104, 51.234709139793154, 55.03714892172045, 56.80912671550628, 51.849917211840236, 51.50673727835379, 48.57431450197774, 47.87744660531321, 47.89850188839821, 48.819725436549035, 55.39971320859848, 58.3555603796436, 58.11273428701586, 54.40124642464423, 37.486397681697724, 45.44766379940895, 49.8063741191741, 52.35529891906246, 53.49426892495925, 53.045957703744214, 54.60162854963734, 55.357747770124874, 54.752879065852014, 55.79475472050329, 53.7729964717742, 48.73633192431543, 47.48583716730918, 44.42134818723125, 40.280505918687396, 40.66975016747752, 41.75960033170639, 44.34003745355914, 44.06589515747563, 45.423337259600245, 44.344273613345244, 43.24471558293989, 42.23547797049246, 43.46781999834123, 43.81382403835174, 43.24718667614845, 45.59379170017858, 55.32190122912007, 55.50546815318447, 54.00734632245956, 56.03732585906983, 54.35756691040532, 50.06207343070738, 44.375809469530665, 44.71424725747878, 43.099297631171446, 42.47074565579815, 43.65719987500099, 45.08404439495456, 47.177001507051536, 49.68727134889173, 56.2060897581039, 55.78438397376768, 58.48001718521119, 58.260611564882346, 59.349041831108835, 58.27158243425431, 57.06328453556184, 57.28998576441119, 56.856897261834916, 54.758919515917384, 54.162762395797245, 54.48186289879584, 58.10539945479363, 59.47004302855461, 63.02619326499201, 56.108344293409786, 49.16014402143417, 59.32753547545403, 58.43111307390275, 60.327912453682195, 43.02382730668591, 3.4206524491310124, 3.1866396771323298, 3.968883844152574, 0.3396337737719859, 0.038785346212887, 2.6493384568921985, 59.50415195957307, 64.4285386608493, 48.24771834957985, 35.58412267315772, 27.00166294651647, 33.680890606295684, 56.89657595849807, 58.02233149928432, 61.4444661140442, 9.798186594440091, 0.18787592349033203, 0.05296825371201962, 0.06590832911071277, 0.0036926587082205284, 0.0295018372050817, 0.05753211909905077, 0.11521880409770435, 0.04461188920803609, 0.015679281186162224, 0.01611116995674468, 0.22522859335426362, 0.11305996832708198, 0.198002441395675, 0.15949884699957986, 0.09756132780063538, 0.11319546629824948, 0.07441635604106611, 0.15183761535632997, 0.16799356698268847, 0.21185214661302107, 3.3788353252795438, 74.03248556198614, 74.04846529806815, 69.59260571387507, 41.86290771730485, 42.56034828001454, 61.2540703435098, 60.26365618551932, 58.57404816535212, 69.03851601385301, 54.951554959820164, 2.580930114753785, 0.16599959333337125, 2.1106224867605397, 4.563661515712738, 33.30520991356143, 75.03493355166528, 67.46469636117259, 67.12568590717932, 63.674125671386726, 63.21026225243846, 58.26249430256506, 57.17584871476697, 49.585285802041334, 49.82351095445695, 49.52011562162831, 58.07565612177695, 56.73067146731962, 62.696753394219186, 59.52901978646556, 57.38683300633585, 59.50224568766933, 55.27952786414854, 55.066437259797134, 48.572659261765025, 44.15029671884353, 45.81674706551337, 45.22534385804207, 43.55656362348988, 45.09846302770799, 47.66414811534267, 46.53339547495688, 43.49571197263656, 47.49696100911787, 49.56923938566639, 52.53213897828133, 52.7442450677195, 55.20937627361667, 56.5864537608239, 55.80580011490853, 51.16948012382754, 45.56911214705437, 44.62122824884231, 43.65834912946148, 47.48681383748209, 42.80036203322872, 45.250121470420595, 48.16377570552211, 44.994088757422666, 47.35820324190202, 46.38330598031321, 44.07423411646197, 49.12213625446443, 59.73160628349551, 57.290570197566865, 53.072355255003906, 56.61666777826125, 61.44117524546962, 54.50649538347798, 54.86739266303278, 51.05311516792544, 49.60629401668426, 51.638034697501894, 51.132390191478116, 58.13407590312343, 59.913015903965125, 59.328006159874704, 54.51559920464793, 40.15648449620893, 47.28788691182291, 52.17041015625001, 54.20837171616093, 55.464196974231356, 54.952284520672215, 57.44557834440663, 58.38315817617602, 56.58637923579062, 56.11494956477996, 56.28168167606477, 51.52537245904246, 49.43497665466801, 46.32578834410637, 43.83332214047832, 44.474970909856985, 42.81891876651395, 47.42619752883912, 46.54202861170615, 48.55739731942454, 46.337225975528845, 45.18802250585249, 45.50036476504418, 45.47462224960328, 45.3747743944968, 45.509629403391195, 47.99598455429078, 59.95538534656648, 57.88720584684803, 56.2373588931176, 58.22088187740695, 57.29510445748606, 52.186958636007006, 46.89259436822707, 47.41963540354083, 44.988620973402455, 45.065958346090014, 46.48988070026521, 49.149796808919604, 50.367010255013746, 53.478446083684126, 57.99383155761227, 59.517868488065666, 59.80081650518603, 60.36796377551172, 61.26010294883483, 60.18682479858399, 60.8368399835402, 60.43959017722838, 59.46142165891586, 58.025712582372854, 57.00723778816962, 56.99179149443104, 64.52023975310787, 63.232239292513945, 67.40112258541969, 61.061732999740116, 53.09484220320179, 60.71742734601421, 60.70435016385971, 62.50538095351189, 45.78570935033983, 5.409675576994497, 7.692427356396952, 8.58710479351782, 0.6019029021263123, 0.1475870224737352, 3.6950989740510143, 66.1919499981788, 69.92409306187784, 61.08155273622083, 48.29948971348424, 32.66366508699233, 40.273696684068256, 68.3203378800423, 66.80812297328826, 72.13973799059468, 14.043676718588799, 0.3423137944792548, 0.2963309602872018, 0.15069547019177867, 0.17949440065891514, 0.06609224383869479, 0.18276542755624942, 0.14768831461908358, 0.07647070507969587, 0.05580655201488445, 0.2136145318828283], [0.036037086223762844, 0.04872028468056552, 0.031792566503187826, 0.02163267014698396, 0.03988077916625527, 0.011685128575341116, 0.03785087216284968, 0.12710684925437937, 0.07889477581146263, 0.19692446375566144, 2.9770586134925967, 47.28507065003919, 55.05218728896111, 53.53664621230095, 27.142995749750447, 16.438016007023474, 17.804803156083633, 42.59286080637286, 47.59269429791359, 62.88154017540717, 40.829280807125954, 0.9891463131193192, 0.034290003560243115, 0.31955175942951636, 0.6876606229812868, 40.865719626026774, 65.46801382495512, 61.89058080796273, 60.87522429804648, 56.789507019904356, 57.78087039147654, 55.20808581382998, 48.61886478239491, 43.12613448789043, 46.03990247172695, 50.554742736201135, 55.81242892049975, 58.345075884173, 56.86614621070124, 53.465310065977036, 53.42707087916713, 54.81751580392161, 51.916291559896166, 49.9414409360578, 46.559632209039506, 41.82182873449018, 39.97774208745649, 39.571717939069195, 40.80116918010097, 42.39142748617357, 41.61371169551727, 40.75929003377115, 42.11472780473771, 41.83277999201129, 41.70334177632486, 45.56780599778699, 49.60173622254403, 54.07416389834497, 51.793741026232325, 48.76798152923585, 43.24724551170103, 40.367068706020234, 40.773583150679066, 40.15738271897839, 42.090687597951586, 40.3489944242662, 41.658873865681315, 43.05753223357662, 42.739631975850756, 43.008553597234915, 42.636999237921934, 41.591165911766794, 38.889201994865175, 49.064022417991396, 56.19643288273966, 54.249478155566806, 50.807759146536554, 53.3909458498801, 51.45970805998772, 50.048239231109626, 47.967719954829064, 48.44883788016535, 45.48784455945415, 47.06857935074837, 50.570090970685406, 53.64233839896418, 53.182291446193574, 56.39708957364483, 32.74253806760235, 48.73221735800467, 56.08762241178944, 54.960290078193914, 55.6636534198638, 52.644126569071126, 53.017661725321126, 51.222028117026056, 53.142314649397335, 54.37755138643327, 53.77283957696731, 50.139865798334924, 48.050258390365116, 40.883103570630475, 41.163913896006925, 40.32594657713368, 40.963865172478464, 42.82430418076054, 43.50698094214163, 43.93653146682247, 42.39800530095255, 41.693488782452, 40.172919227230935, 40.95335714278683, 40.35188128871303, 41.079335827981275, 43.63543856528498, 46.945252187790416, 55.20453999119421, 50.93583629977319, 52.21667451243247, 50.549608353645574, 49.51629523308047, 43.431687124313854, 41.99385996787779, 42.98765128658664, 40.486206777634166, 40.18875775798675, 40.48129204780825, 44.212403528151974, 48.13591903255832, 53.2454925967801, 56.7838195831545, 54.18430797515377, 55.96577006001627, 58.470756469234345, 55.25833529810752, 56.27351922373618, 50.94420663772091, 48.98938363598239, 44.93393528846003, 48.994831808151744, 50.440393878567605, 54.46149010812083, 57.1807046090403, 58.28638938165481, 57.69706895274501, 65.91223009171026, 58.513349486935525, 61.786645843136704, 64.49446585870558, 48.082280620451904, 5.015661235778563, 1.2248000454518104, 3.406659393541275, 0.7142518412682318, 0.06101040725385951, 0.673834145549805, 42.26720210044615, 65.15583630531066, 47.03395658923734, 49.56849805770382, 20.980773741199126, 29.462385408339966, 49.36159695348432, 48.80094512816399, 61.073892347274295, 12.042202026613298, 0.36387662613584154, 0.057884531035538644, 0.038190023117368264, 0.04789903076485761, 0.05732781494096403, 0.030964770196606557, 0.016888617049722422, 0.010713590233917198, 0.06612841851047932, 0.03203414658445024, 0.057552543003112085, 0.014463627012446524, 0.06198480214563109, 0.07836491875951329, 0.039910656595302206, 0.08076410695549943, 0.03047170643244059, 0.1073650239155658, 0.10024127189911182, 0.13070284298831417, 6.46341149845431, 61.45572331643874, 61.111692228624904, 61.96106972232942, 29.27134244672714, 18.968948894931426, 28.118518629381736, 48.58746228679534, 51.51506839259979, 68.85552175583379, 42.49365229760447, 0.884273534099902, 0.011291096997146886, 0.9299505766360991, 1.6310828251223413, 42.37687941520445, 68.159285360767, 63.228226707827666, 63.54661726182508, 58.1799009538466, 59.72271427031487, 56.976827652223655, 50.867893003648334, 45.60147170097598, 47.78534150892689, 53.89210708679692, 56.826875440536014, 59.80288359426684, 58.72617337011523, 54.18712815930767, 54.887232011364354, 56.974776252623535, 54.87060508420391, 53.05156277072046, 48.09480474841211, 43.67399546407884, 41.98905898678688, 41.25961972821144, 43.416068246287686, 44.07535983670143, 44.01112710275958, 42.76167569621917, 43.519112833084606, 42.637458155232096, 43.99770867440009, 47.61207080656483, 53.13914929666827, 55.55124613546557, 52.69496440887452, 49.867394431944824, 45.74394787511518, 43.56998205184937, 41.43041933736494, 43.06254894502702, 44.3482038282579, 42.91975898127402, 43.50616508914579, 45.78252830813008, 43.925756715959125, 44.87544882682062, 43.02410579496815, 43.16645645326184, 43.08600471865746, 51.58827158712572, 58.139543687143636, 57.02546896473054, 53.34945109582717, 55.74487786139212, 53.468836276761955, 50.244051794851984, 49.1927702965275, 50.70935472365349, 47.24082631449546, 49.47667929434007, 52.91929652613979, 56.48995168747441, 56.13736198794458, 56.55242719957906, 36.60391146136869, 51.25997312607304, 57.53100756675967, 57.15364809959166, 58.85966339418965, 54.84690612362277, 53.97830901607391, 53.7923925922763, 55.28633709876768, 55.78379561824184, 55.63886011800459, 52.733270275977354, 49.33164573484852, 42.28142461469097, 43.30220576255552, 40.026905075196304, 41.046176110544515, 45.42254101845526, 47.02314261467227, 45.71497724902245, 43.61880771575436, 44.06269842578519, 42.25017509152813, 42.612390287460826, 40.893603755581765, 44.79746034068447, 45.80279519481044, 49.03463209829023, 54.91273133985458, 52.93382498525804, 55.095066639684866, 54.739362578238214, 51.29250134191206, 45.20725388680735, 45.1361923063955, 43.746771120256, 42.41898213663409, 42.22323625318466, 44.296385395911436, 46.40120375540949, 51.70006698177707, 56.81570060791508, 58.08917260939076, 55.76942797630064, 57.18433672381986, 59.194735788529925, 58.08982372283936, 57.77088011464765, 54.29316943691623, 50.80322488661736, 47.788346044478885, 52.01173459329913, 54.68342173484064, 56.25005952773556, 60.07311920965872, 60.44805857443041, 60.68476576958934, 65.71306390147056, 61.06684384807464, 63.13835344006939, 63.396739575170706, 50.328986798563314, 5.4773580355028955, 2.8272583936491325, 6.463515441263876, 2.4736957011684297, 0.09955100369669738, 0.5370604234837717, 44.6877202680034, 70.29461583783551, 49.78046294181578, 50.455581295874815, 27.88254099507486, 34.85193383309149, 59.13243678308303, 57.54954076582386, 70.45868073740314, 18.015999255641816, 0.15442251858692016, 0.12675409640876517, 0.05652224667550576, 0.0418745038369971, 0.07268130478839721, 0.0169670567922895, 0.02107713382781273, 0.0032561619187735265, 0.032051557847749323, 0.08423829270947365, 0.13129676031249185, 0.07472129733932596, 0.15905158954762644, 0.16933278060488163, 0.1296110451221466, 0.2423799536641567, 0.22760839952576548, 0.28098971252479865, 0.16981867953173577, 0.3875529718014502, 9.75994642703764, 74.83074280523485, 66.57428695309547, 69.9270740632088, 38.478710266851614, 26.36832175716277, 23.879311161656535, 57.88325209771433, 59.25848607094058, 75.15065131648895, 49.364107270394605, 1.510890984246808, 0.12302771451011782, 1.8966261826215254, 2.5368044309077726, 45.175776866174516, 69.92004517586001, 67.4041820341541, 66.72365080925726, 62.883003219481445, 61.259969588248964, 60.10626323761479, 54.51683867362238, 46.25635062494586, 49.69159772319179, 57.505316042131, 60.83239986050514, 62.17268551549604, 60.835926071290054, 57.07660490466703, 54.48768761850173, 59.29688215255738, 56.37834456659133, 55.25959045656266, 50.25254372627505, 46.38487100601197, 43.51309983961044, 44.12537005639846, 45.96557355696156, 47.47073211977559, 46.42962524967809, 44.99866616341376, 47.11762466738301, 44.55558346163842, 46.7425048735834, 51.41271022058303, 55.50152224879111, 59.328076762537805, 56.73674721871653, 54.52705252555109, 48.129862893012266, 45.06892758031046, 42.31140721228815, 45.297507624472345, 45.667798980589836, 44.73338057917934, 46.065668521388886, 46.97136732839769, 46.44229450533467, 45.75215347351567, 44.98091351601386, 45.218279669361735, 43.29221940809681, 53.52291399432767, 60.73506624467912, 58.88421743146835, 54.50257301330567, 57.812233663374386, 54.87800659671907, 54.31968073691092, 53.33795462885211, 53.27221570476409, 51.14616163315312, 51.56585131922076, 54.96559312266689, 59.66066237418883, 58.30244364277009, 57.3424356983554, 39.44817896812193, 51.82942675006006, 60.62782472179782, 60.04820823669434, 60.02226175800447, 55.27984165376233, 54.632870228059836, 56.735323398343986, 55.54777483786307, 59.31326981513732, 57.028975563664595, 56.81984263081705, 52.46340728575184, 43.94598045656758, 46.453284986557506, 44.44698872104768, 43.88998862235777, 48.770287882897165, 49.57584465703657, 47.49985964067521, 46.22637587208902, 47.70840421799691, 44.763288651743245, 45.167237866309385, 44.56411069439304, 47.2214811848056, 49.82913563328405, 50.63240566561299, 59.1871028561746, 54.335393751821215, 57.240905146445, 57.53776973293674, 53.355950463202696, 48.92271118779337, 47.63840952227193, 46.36893441600185, 45.88688296656455, 44.595368062296224, 45.48788770552605, 49.758195646347545, 53.05086851119996, 58.046104984898726, 61.74386847403742, 57.62322641188099, 58.04019397304904, 62.003992219125074, 59.90686170516476, 61.54846383679298, 57.73305277670584, 53.918622309161776, 50.18296480178834, 55.40190189115463, 56.981212862076305, 59.15258992102839, 63.12101264153758, 63.72898001824657, 63.80594084339758, 68.36500583156463, 64.23083551468389, 66.93010084090695, 66.83856056582543, 53.71304696606052, 6.80732197338535, 7.58730048133481, 12.244313916852398, 2.4944501874908327, 0.23254981985495937, 0.7019895315170289, 50.73451280593873, 77.86693188451952, 61.20167140037783, 60.73734906411941, 28.912928027491418, 40.550129644332394, 67.36618995666504, 66.6964295602614, 80.66460163362565, 24.59475148108698, 0.5093151397041736, 0.20930536391754306, 0.266212182900598, 0.09208066584241968, 0.2198766418282063, 0.10884379577492515, 0.09579706561541367, 0.0864439977393035, 0.18551810404225705, 0.09439272685877739], [0.01841593207040381, 0.035989922020704515, 0.017216468207357873, 0.0556928952104382, 0.03578580555415923, 0.09613025257544172, 0.054881803451045874, 0.09725157547021106, 0.004055088201928283, 0.3423643256387403, 9.681962843864195, 55.024361994958696, 53.47783027156707, 48.70181898916922, 33.97557827734178, 34.12293387997535, 28.786763029713786, 33.93331081636491, 50.91898187514275, 63.101008553658765, 39.497906777166556, 0.3525897608168664, 0.07229276031496064, 0.2223584602677053, 2.096207776377278, 49.64799665635633, 67.72798938135948, 61.28180934536842, 61.02603550880187, 59.355031290361964, 56.38089410720333, 49.70411792878182, 43.81403976871122, 46.88927996543146, 49.091741807999156, 53.70863429961666, 57.71571982291437, 58.30805655448668, 51.52162267315773, 51.759122187091464, 51.19806243527321, 55.056129270984286, 57.37807827611124, 51.87649911449802, 44.99798759337395, 39.92554710757348, 39.04063294010778, 39.5224961157768, 40.10723129395516, 41.220337190935695, 41.44845439541725, 41.89490249080043, 40.88888514426447, 40.37497228191745, 41.33045773352347, 43.03803413145004, 46.9630636707429, 48.99621640482257, 49.22150165803971, 46.235801327613096, 42.787661398610766, 38.630713878139375, 40.68437668585008, 40.52126884460449, 42.2718854104319, 40.37937318125079, 41.7800437250445, 43.51095822549636, 42.70079658877465, 44.076713054410874, 42.07162487891413, 42.63544990170387, 38.28048936782345, 42.18322415505686, 50.9058968482479, 57.00147190401631, 53.542663128145286, 51.73367384941348, 51.894667533136186, 49.92084457028297, 48.83298304773147, 46.9723439985706, 48.185627229752086, 48.329378174197295, 48.895117313631125, 51.45563663974885, 54.53185742901218, 56.478423841537975, 39.06502616020941, 50.53406792302286, 57.09660507017567, 52.90866690297281, 53.312502368803955, 53.07171198629564, 55.90615003339706, 52.63769388198853, 51.68271441613474, 53.14633900119413, 53.46788314081008, 50.901174314560436, 43.79125472038023, 39.345354034054665, 38.74292896639916, 39.609925746917725, 39.69572367206697, 42.37159598258234, 42.57723016123618, 42.41818197311894, 43.107036467521425, 45.22801891449959, 41.687652295635594, 41.119912747413885, 40.91802050990444, 41.5488866836794, 40.66746342566706, 42.59178999931582, 49.18288592369326, 52.1902181256202, 51.32224467492873, 51.35640459675943, 47.73754350600704, 46.02766467678932, 44.13246562404018, 42.241565488999896, 39.701685674728886, 41.51664872323313, 39.66725903172647, 43.76266064182405, 52.547228336334236, 57.22204639065651, 54.40019522943805, 53.46606316105012, 57.69203655181393, 57.25639850862565, 53.6931997729886, 50.87508270817419, 46.15876597742881, 42.97145582014515, 45.2080265937313, 48.027908725123254, 54.94651471414874, 54.54032190384404, 54.50302800824566, 58.17413114732312, 58.91139161202216, 60.0182334838375, 64.1653750788781, 57.981495703420336, 65.16138645910448, 54.98726029549876, 8.113356511439047, 1.7846034130742474, 2.3328485363914124, 0.43589364076333664, 0.09175872505312005, 0.012553837807518581, 32.76309128730528, 69.80502559292701, 50.73372833190426, 39.26198013367192, 21.641465617764382, 16.236700357929355, 40.962900269416075, 55.67436933517457, 54.503530071627715, 25.38219278858554, 0.4326457650430741, 0.03474891703996447, 0.024889848089867064, 0.046260468286251834, 0.027978249202151934, 0.042350914764909015, 0.016041240493406453, 0.051786314110241594, 0.06172120278220504, 0.034555299808421445, 0.007091610797590787, 0.025714465131562565, 0.06799629408745997, 0.09853666498055381, 0.042052607788073446, 0.03520784967188393, 0.044156354176060814, 0.05758075036048409, 0.14759313585537095, 0.22931011063196968, 14.576059041484712, 65.97547438836867, 57.62574457353162, 57.131219986946356, 38.30796164851035, 33.485744845482614, 27.654098233869, 40.59264029225996, 55.75649984421269, 68.18114080736714, 42.43003537577968, 0.3573188828604837, 0.04677743590887516, 1.1044062025124028, 2.9514590194148402, 54.0896454934151, 68.0300275741085, 65.63049016460296, 61.904167898239635, 62.47950899985529, 58.66724760301652, 54.11790224813647, 46.049324004880845, 49.512882771030554, 51.868179767362534, 55.95327338864727, 60.8572284636959, 58.38508405993062, 52.31764416540823, 52.090209453336655, 50.88640266849149, 56.862855342126664, 59.456506929089954, 54.69300016280144, 46.658224905690844, 42.46459537936796, 41.40563388024607, 41.96322233446183, 42.049973395562944, 43.21351705058929, 42.9382098105646, 45.2789391240766, 42.67048451208299, 43.86842735352055, 42.520936304523104, 44.72245677824944, 47.592164777940326, 50.371218958208644, 49.355619261341715, 48.2516917105644, 43.7774165984123, 41.90311201157109, 41.666612702031294, 41.28852759638141, 43.125597123176824, 43.99738704004596, 42.738247379179924, 42.979814390982355, 43.280824922746234, 46.152635312849476, 43.98360383126044, 44.216800505115145, 41.710362818933305, 44.09692110553865, 52.6036790878542, 56.78793807183543, 55.30967520129297, 53.73085060427266, 54.057187880239184, 50.91136463226811, 50.703659442163286, 50.685993086907175, 50.22216104692029, 48.884734799785, 49.52309270058909, 53.95908940222956, 56.0424876982166, 58.49216476563485, 41.562603212171986, 52.651241748563706, 58.68132891193513, 53.17393679772654, 55.99325803018386, 55.4156772551998, 54.30313617952409, 54.13401926717451, 53.29231392952704, 55.73501702277891, 54.94304341654624, 52.678804243764574, 46.36788714316584, 41.028258723597375, 42.37874646340647, 40.78486388729465, 41.72114149216683, 44.1986281641068, 44.6744312778596, 43.1803612555227, 44.41078132198703, 47.74530979894823, 42.529957755919426, 43.21435643780617, 41.560069361040675, 42.50534488308815, 42.979763400170114, 44.83406782150269, 51.500736051990145, 52.96441555023194, 52.38883518403577, 52.85143952215872, 50.320216378858014, 48.08950954867948, 44.88014782628706, 43.96882434045115, 42.95288339737923, 42.945477962493904, 41.616174943985484, 45.11146568482922, 54.67816183643957, 57.61982179457142, 57.77459459920084, 57.05350214435209, 59.43090169660507, 58.6021048791947, 56.90846466249036, 52.371231586702415, 47.791503552467596, 45.37680618224606, 48.14256352763022, 51.351446720861624, 56.58525351555117, 55.990273106482725, 56.01778853324152, 60.27192454184256, 62.356287740891986, 61.64384018990302, 67.12667434446274, 59.153091984410445, 65.81181741529896, 56.08497088955295, 10.177501363139, 2.6990189523466173, 3.7969406189457064, 2.3468771384608362, 0.24042575529986815, 0.04438221987877642, 34.20268743268905, 75.61952360214727, 57.33628934429538, 39.92503327708091, 23.182325593886837, 22.42446287985771, 47.24900837867491, 62.69784773549726, 60.2177252308015, 35.83585254607662, 0.8518627442179189, 0.047347604507400144, 0.015947432069468404, 0.08892940147028816, 0.054552450761078834, 0.01965745799093237, 0.011098304267732367, 0.04120950504476505, 0.06165617340875249, 0.05780226851422941, 0.14252013226430263, 0.10133078682326502, 0.16093094112171283, 0.20836989395320418, 0.12964406351168312, 0.1486272626225987, 0.19795137397464246, 0.10541563658344169, 0.26737773971211526, 0.3916732684498833, 19.27080273628235, 78.17205306022399, 65.1115409789547, 66.52153891901817, 45.20566532688756, 47.28543935283538, 37.79996764275336, 47.78619658562445, 61.48592556676557, 72.86098341788016, 46.37481404889015, 0.720061852085975, 0.1479546987121144, 2.0437884859500395, 4.5278448827805065, 56.2594339924474, 70.73930278901132, 68.36124820093956, 63.564573872473936, 64.58326831940683, 60.26593508258943, 56.755794248273304, 47.99312906880533, 52.99400591081189, 54.53942368107458, 58.69435902564757, 61.84812507321758, 61.384159672644834, 55.16251571716801, 51.915259976540845, 50.3938235775117, 58.2309074555674, 60.20993932600945, 57.659237692433024, 48.51889925618326, 44.58834701968778, 42.642557236456106, 44.9709036273341, 45.2977115877213, 46.35524142173029, 43.858743021565104, 47.85661489732804, 45.42824022231564, 46.4638832307631, 45.11783169161889, 47.95019872726933, 50.11124034081736, 53.60169479923864, 52.783633508989894, 51.96925140196278, 45.40734183403754, 42.48888661784511, 44.77087451565651, 43.88170849892401, 44.769258499145515, 44.71985232445502, 43.86372443168394, 47.11616946804909, 46.52582137815414, 49.41141497704291, 45.902741109171224, 46.296280353300034, 42.538979207315755, 45.743677231573294, 53.41850442271079, 61.466419619898645, 57.1880433636327, 54.942137349036436, 55.58091494344897, 55.53132833973054, 53.84146928787232, 53.32932541447302, 53.59283808738955, 52.23644718047112, 51.91482459345172, 57.27526510915449, 58.90264472653789, 61.66540538111041, 46.166363608452585, 56.55220754684941, 60.552472068417465, 56.01229721500028, 59.45735808341735, 57.43106165239888, 57.27848145269579, 55.25546020077121, 55.93050795216715, 55.08941058189639, 58.09671140486195, 56.96794740615353, 47.9755215491018, 43.646052498971265, 43.30402966468565, 42.59753627161826, 42.810301319245376, 47.12996444394512, 46.34861261613908, 44.79650720473259, 46.38008963677191, 49.89551390371015, 45.18733609107233, 46.7494474687884, 44.174427140143614, 45.706795184843, 43.75905598363569, 48.10879976518693, 54.00538905974358, 56.15331818980556, 55.113999920506636, 56.15116873095113, 54.036360094624186, 51.10274884008592, 50.15965807822443, 46.143986486619525, 44.452668313057195, 46.780257686491936, 43.57342197049049, 48.48184462516539, 57.83190827215872, 61.55599478752383, 60.380719323312086, 58.00333153816962, 61.53244879937942, 62.492303771357385, 59.67333162984541, 56.696323271720644, 49.6091926482416, 49.52077457981725, 50.71531672631541, 53.35986498863467, 60.896063850772, 61.59170012320242, 60.79696516836844, 64.51221066136515, 64.03833735373713, 65.39360254041611, 68.97836254489037, 62.85093784332276, 67.3886808272331, 59.11082844580374, 10.203186023619867, 4.319436117526024, 7.851343654817152, 2.321368249193315, 0.4099320548195993, 0.08518394398232622, 38.860392185949514, 81.06347530118882, 65.66384600054833, 52.67659987172773, 30.309607559634795, 28.7005748287324, 56.7821329639804, 72.7352479196364, 70.92460340069186, 45.26082561862084, 1.4632006013585677, 0.1854627771723655, 0.09391181516431032, 0.1069372634012853, 0.2031232795167354, 0.11420702411522789, 0.07841579465856476, 0.16580185071835596, 0.17781403276228136, 0.08416811139473031], [0.02295978341041313, 0.021613588812009945, 0.10485855276666342, 0.058775242312901446, 0.0499760789886838, 0.04786728408127543, 0.0350225713073967, 0.10135374647835571, 0.03642617078918604, 0.16637341359690314, 13.628193774530965, 55.6544436946992, 52.5548691134299, 44.22378232402187, 27.082314721999634, 19.6289014047192, 44.985122219208755, 36.39196618910759, 49.27996458545808, 66.1467093806113, 33.530424564115464, 0.10593328219387801, 0.06472027995773862, 0.12346996940792569, 5.3091285594048045, 48.32138438378611, 64.13531403387746, 60.99221683317616, 63.86166987880584, 57.13152985418997, 52.134422409919004, 46.751412576244725, 49.03924872798305, 49.54797621696226, 58.80399319433398, 54.00547142951719, 60.916652371806485, 55.49668988873882, 52.03366848730272, 54.580263399308734, 52.395248259267504, 55.34168958663941, 53.937449685988895, 48.88936711895851, 41.718866517466886, 40.37987524463285, 40.013537637649044, 42.68958645482218, 40.23077810964277, 40.64358795842817, 40.517056219039425, 41.851128839677386, 41.67060959723688, 41.39284695348432, 39.359509868006555, 39.04088789416898, 41.58100697302049, 44.633289537122174, 43.23368195564517, 41.34704543698219, 39.67549993145851, 40.81652133695541, 39.841063176431966, 41.358110443238296, 39.222230834345666, 42.02685102339714, 42.42274761199951, 41.977676268546816, 41.96932946482013, 41.087572805343136, 43.860629681617986, 42.489129804795795, 42.05500579649403, 41.73592490534629, 43.17026899706933, 52.528942246590894, 51.92430496215821, 51.40677959688249, 49.02231585594916, 48.65958682952389, 51.74812386112829, 51.199246991065245, 50.047745012467914, 51.34730469795966, 49.79194371931015, 51.18959796044135, 51.15420249200637, 57.22495286695419, 44.159631959853634, 51.609064071409165, 53.811871082552024, 50.01994717505671, 49.64800842346684, 51.068961543421594, 53.888176871884255, 56.906534856365575, 55.478019406718595, 52.861096397522964, 53.44799280166627, 47.79267634114912, 38.84866822150446, 39.44841431033227, 39.42904956879155, 41.22170609812583, 40.37038703118601, 42.94146145543745, 43.03132687845538, 43.269806984932195, 42.589503257505356, 44.19479208607828, 42.37467112079744, 40.51430271517846, 43.5204307494625, 41.41219992791453, 42.83502009607131, 40.55748408840549, 43.41813925773867, 46.599103020083525, 48.51827167695569, 48.744564979307114, 46.55802011489869, 45.446996996479655, 40.58594872874599, 40.83551345332977, 41.46548924907562, 40.278207409766416, 41.117845658333074, 43.7843591936173, 52.70036551260179, 56.02456246652911, 51.78593943195959, 56.27336232892929, 56.99088542692123, 53.23506693686209, 49.2367479108995, 46.07866333376977, 44.29884079963931, 42.840201547068936, 50.112526878233886, 52.44191661957772, 50.894133660101126, 53.835883832746944, 54.01745034802345, 55.460478567308, 53.13250872396654, 59.61375867166827, 58.60417589064568, 59.94184924710182, 70.02236412417504, 64.28374828830843, 16.368031117223925, 2.170182942382751, 3.1827959995115958, 3.0823629758050366, 0.22445761778902626, 0.1422241771773946, 19.555545237756547, 70.0346411428144, 49.8852490609692, 53.34930989050096, 34.240232359978464, 25.142090782042473, 39.10940385633899, 53.299899793440304, 57.13887645352272, 43.66409147939375, 2.5271105381750294, 0.33295189360937766, 0.04283989719565838, 0.02308295694209876, 0.011232560218852616, 0.013580528733831261, 0.04226361521549764, 0.061535637134746204, 0.046818482899858106, 0.06269542913463327, 0.05047833389272133, 0.04625615904167776, 0.05331272897761195, 0.01691939271686058, 0.01495285171850194, 0.04823251649917615, 0.07149495635061495, 0.03764319338745648, 0.051694073293718605, 0.18142653569098444, 17.900083411124445, 66.11221605731596, 57.39164967690745, 51.909572539790986, 32.405163241970925, 25.10455369949341, 39.86889239280455, 40.1767082368174, 56.10377080978886, 71.30448495188068, 37.50467592670072, 0.1316621229653397, 0.12578216832010977, 2.612411548053065, 6.566077576529596, 51.99014979024088, 65.30787914030014, 60.55177388652679, 64.55023411781558, 59.76458949427451, 53.631983341709265, 50.55517419692009, 50.2640401932501, 53.09348898549234, 59.63987381227555, 57.5610254656884, 63.55238706834855, 58.788029147732644, 53.04191374009656, 53.784881253396314, 53.92649058372744, 58.03261595387613, 54.87682988566738, 51.04584701599614, 42.318287049570394, 42.4137104711225, 42.204240214440134, 44.052159017132176, 41.58391737168835, 42.500022226764315, 41.884221876821215, 43.81529884953653, 43.65438361321726, 43.549852448125044, 43.28022872248004, 40.86164820578791, 43.51869313947616, 46.02069462499311, 46.02981805801392, 44.78918806199105, 41.60907153160342, 42.87677764892579, 42.66378902619885, 41.82750440412953, 42.81262728475755, 41.319604535256666, 42.433490983901486, 43.481265883291925, 44.1038990020752, 42.82363345546108, 45.47105289274647, 44.21206620431716, 42.92109258713261, 43.99387259637156, 46.078933977311664, 54.33103599855977, 53.21532172541465, 54.1671750622411, 50.53011417388917, 50.81937328461678, 51.146777445270175, 54.12812786717569, 52.20544476662913, 52.55286870464202, 51.23166538053944, 54.05030804295694, 52.287367390048125, 59.453333731620546, 46.86452980964415, 54.26141000563099, 56.680041513135365, 53.1452799612476, 51.42850168289677, 53.6614481864437, 56.051779793154815, 58.913945075004335, 55.842391906246064, 56.6481565660046, 55.19790726323282, 50.00297115695093, 41.465689289954405, 40.651993597707445, 42.314505884724284, 42.72472304682578, 42.821821320441465, 44.679942207951704, 44.98415731614636, 44.47210757963119, 45.11368574634675, 45.39298595920686, 43.54476121164138, 42.53779072915354, 44.0748538509492, 41.348610462680945, 44.737475533639234, 41.93013321968817, 45.98649155709052, 49.00322960269067, 52.89924929218908, 52.117073766646854, 48.73222128037484, 47.64988245502595, 43.60149437381376, 41.89252553447601, 43.76155453343546, 41.575813754912346, 45.10304435606926, 46.62708520889283, 54.957289465012096, 60.201243431337424, 54.197334166496034, 59.92499874484155, 58.94075447513212, 56.01336802205732, 50.838953756516986, 48.65018883059102, 46.401784266194994, 44.470232686688824, 52.81477320578791, 56.127979678492395, 53.60345202107584, 55.64684214130525, 55.86096040664181, 58.43387834487423, 57.04065638203775, 63.44780491244409, 63.773342024895456, 62.731536972907286, 70.13798775211458, 67.96377874189808, 16.96544339579921, 1.6729346374350211, 8.41172875896577, 5.8100034632990445, 0.3749155854025195, 0.05775717657900626, 21.25584367782839, 75.83002936455512, 55.28723139916697, 55.0945096631204, 32.31624311016452, 27.405578820936142, 45.318186360020796, 61.50617676396524, 65.013395432503, 52.49616299906085, 3.6325991922809235, 0.36566706554543593, 0.0360580004240957, 0.047936274129296505, 0.06994325292086409, 0.07047162376224034, 0.05248032848260576, 0.06512996845788534, 0.049288545720159053, 0.10124356005220644, 0.08666257028497996, 0.10806410978998869, 0.23707018293921026, 0.1617820801273469, 0.1566384891949354, 0.12158178484007237, 0.10718901521496235, 0.14122953458178428, 0.1755399007590548, 0.23835287459435003, 22.5302452810349, 78.57306049716088, 64.65651858237483, 62.82387741150395, 40.85684722469699, 31.57752548494647, 58.25488490443076, 53.82688983794182, 58.061672872112645, 78.46827830037763, 40.590843846721036, 0.32335042172381956, 0.1860544728415628, 2.0121083600867182, 9.117448464516672, 55.86115260278025, 65.82392184965073, 64.08303276185067, 66.36278490866384, 62.054120109927275, 55.60902657047395, 53.71713799815024, 52.46011249480709, 56.13098421404439, 61.59132749803605, 58.87549015783495, 64.5724465001014, 59.16310579546037, 53.22133864125898, 55.865318159903254, 55.427491434158824, 60.53301711236278, 56.64210042645855, 53.58076895436933, 44.5072167150436, 45.33593508505052, 45.59976939232119, 48.05279224149643, 44.64548810835808, 45.00973901441021, 43.836028575897224, 47.2434425354004, 46.62927781381915, 47.73650800028155, 43.810109553798554, 44.44661609588131, 47.103661029569565, 48.985775055423865, 47.69956319562851, 46.38973866739581, 44.35045134636664, 45.26640322900588, 44.57000601676203, 44.75762474921442, 44.17098329913232, 45.89926588919855, 45.251368784135394, 46.984299382855816, 46.84532196291032, 46.03173217465801, 47.7212421355709, 46.46342039108277, 45.89078964725618, 45.371334475855676, 47.55468260857367, 58.79712512416225, 55.96726448305192, 55.43746209913685, 53.81136117442962, 53.776036308657744, 56.642480896365264, 56.43052777936382, 55.658401366203066, 55.28369342127154, 53.61763531161893, 55.28519568904754, 54.380340191625784, 62.60846084164035, 50.312367716143214, 56.288663494971495, 57.927927893977014, 54.89856373879218, 52.82658738474692, 55.85635946642969, 57.79215897283247, 61.55478277514058, 58.793567534415956, 58.53827614938059, 57.28870314936484, 52.51817926283806, 42.65609725829094, 44.11932568396292, 44.82858042563162, 45.841803166174124, 44.84077899686752, 47.58909748446557, 47.23555857135404, 47.53896174892303, 46.66875646960351, 49.24749520517165, 46.16686567183464, 45.09046531492665, 46.8696092790173, 45.37983425201909, 46.44752302477437, 42.91977859312489, 48.32825245395784, 51.03935941573113, 55.115251156591604, 56.39404189202094, 50.560445862431685, 51.320103060814645, 44.48754602862943, 44.695490483314764, 46.24957669165827, 43.745410057806204, 45.81542130439512, 49.523810494330625, 58.00037014868952, 63.65112489269626, 56.97689041014641, 61.697133433434274, 62.485784792131, 58.066466008463216, 53.513445392731704, 50.60703577533845, 51.09803022876863, 47.74764360920076, 56.69297748996366, 58.62239137772591, 55.200131247120524, 60.315160828252, 60.286923685381495, 61.614355733317716, 59.84785749066261, 65.4820284535808, 66.55454174164804, 65.43292430139357, 73.09272489240094, 69.36775976611723, 20.376154107432214, 5.0234373346451795, 13.415039431664253, 12.255687809759571, 0.5876110722461055, 0.2504397655326513, 24.472614757476318, 82.20555182426207, 61.880170837525405, 69.45575421856296, 44.529154531417355, 36.80717652843845, 51.83660468747539, 71.7843947872039, 73.00000006152739, 62.358574482702444, 5.07690022068639, 0.5671983224249656, 0.14421674122493114, 0.09946996691606699, 0.1875936047684762, 0.2020966757329241, 0.1419901526382854, 0.15043287057309382, 0.2533323603171495, 0.1757013767717346], [0.04268953328832023, 0.043356006799806515, 0.039143243338912725, 0.06947442243296294, 0.08861221808699832, 0.03467726483640652, 0.06609289501343044, 0.06052383033919239, 0.03836829560778795, 0.22775915030750538, 10.765941219945109, 59.207659998247706, 54.335268235975704, 44.529762498794064, 23.193604369317335, 22.34123410717134, 33.40995288664295, 38.85393596464588, 56.160813839204856, 62.86951811082902, 29.900331766374652, 0.1035953427274381, 0.2878775784084874, 0.5225425057353512, 4.529736936092377, 52.239271286995184, 60.71401096159413, 61.19466996962025, 62.33899008843207, 62.757405004193714, 55.04615468363608, 49.60666664185063, 52.9706834977673, 55.38002683270363, 54.10729615919052, 55.36028554362636, 55.01984342452019, 49.21798329199515, 53.54925663240495, 54.224826059033795, 56.84608328726984, 55.07513315446916, 56.85768958060973, 46.08603738969373, 39.524990743206395, 39.77303751053349, 39.27322949132612, 40.83643128795009, 40.61917904884585, 39.55316512815414, 40.18756535745437, 42.275894072748, 40.37181869629891, 40.14759640539847, 40.57054950344948, 40.62654133765928, 40.78842932178129, 39.7987800259744, 39.014643315346014, 40.966002864222375, 41.78947310293875, 42.78640231778545, 41.03739000135853, 40.11740592218215, 40.723749437639796, 39.24138769026726, 40.9297287848688, 42.66057268265755, 42.045333231649096, 42.06481172192482, 42.37803259203511, 42.573048914632494, 42.93773520377375, 42.90976085970479, 39.48775176079043, 46.692184786642756, 49.99455767293131, 49.595464352638494, 49.21803820517756, 49.74175307058519, 53.53435162575015, 54.28213973199168, 55.54884956729028, 52.801676411782545, 49.72119592851209, 51.441261153067316, 52.44396409680767, 58.03711491246378, 46.37507292532152, 50.84522954879269, 54.01998812152494, 48.19855928421021, 46.233345923885224, 44.97428078805247, 46.957756703899754, 50.50003351703767, 52.954852811751834, 49.29380662979619, 46.14242930566111, 42.13718337397422, 39.78092147457985, 39.7862558980142, 38.89562683720743, 39.544633973029356, 41.93123148333642, 42.430564895752944, 42.64507147573656, 43.80181374088411, 42.736548992895315, 42.21501496530349, 42.04168542738884, 41.21435949879308, 41.15164079973775, 42.53805352795509, 41.324044658291726, 42.824194354395715, 40.83613318781699, 43.8887373862728, 45.7481251993487, 46.60840688213226, 47.04506866393551, 43.249496952179946, 43.34237475549021, 40.28846048539685, 41.76537406060004, 39.7618862121336, 40.80883741378784, 41.95481277281239, 48.229200839996345, 55.387393043887236, 55.2707221431117, 56.415634539819536, 53.577450629203554, 50.85684760924309, 43.75407849588702, 43.82654036245039, 40.53867240105906, 46.516435146331794, 50.958723329728656, 54.395225586429724, 54.10565268608832, 52.697360977049804, 50.16079948794458, 52.85338109539401, 54.63104240355953, 57.46550398488199, 57.66466233038134, 58.08550519327964, 62.41757477483442, 73.247831098495, 26.05313381841106, 1.5054187875601555, 3.263572065099593, 3.013934776667626, 0.19423307430359626, 0.09211768321092091, 10.138863075164057, 66.89550553598713, 58.324420682845584, 46.16396311790713, 35.889832204388036, 23.37117595057334, 37.04806104783089, 54.01301806972873, 61.66888452345326, 51.778804640616144, 4.663364733419111, 0.27449141767236496, 0.03472472398331569, 0.08268076701149826, 0.08374441114644851, 0.02483499044882915, 0.01587733502439674, 0.04082323968290322, 0.03811663955510144, 0.025978558621699774, 0.029251046831749623, 0.09452316864964463, 0.034391709393070596, 0.0872294370445513, 0.030406031629911838, 0.040304249588159785, 0.08924569619158584, 0.11241785641158782, 0.09652990532378036, 0.28150970236428324, 16.01465596306709, 69.57235843904557, 59.75010025885798, 52.13227295106458, 28.737888336181644, 24.44356176160997, 37.66528521814654, 44.66937926507766, 59.81610590411771, 68.33123422438099, 30.794759642693307, 0.06854027013985381, 0.803205251934067, 2.0554998252661, 7.850956320762635, 53.979615165341286, 60.55327223193262, 63.95345726320821, 62.13952579805928, 64.85420603905955, 57.14287334872831, 53.116034769242816, 56.03358391792544, 58.05458907158145, 57.29094674510341, 58.043931991823264, 55.890723351509344, 50.157924390608265, 53.32825460741597, 54.965816697766705, 59.286068177992306, 57.39663500939646, 58.023143429909986, 48.69829277838431, 41.86451196670532, 42.00185768065914, 42.1090756693194, 42.05269159809236, 41.48313599248087, 41.957974203171275, 42.42643071759132, 43.743413571388494, 42.44889805393834, 43.207409920230994, 42.22722922602008, 42.6639380762654, 42.60615371888684, 42.423845875647764, 41.978339149105935, 41.9984216843882, 42.58234885431106, 44.518313100261075, 42.248111924817486, 41.11076185780187, 41.98209285736084, 43.16047876111923, 42.475401509192686, 43.731058105345696, 45.12305236631825, 43.12837023888865, 45.18144076870334, 45.95841915376725, 45.140848159790046, 44.77525188076881, 41.848332189744525, 48.41861994035783, 52.41884523822416, 53.144773975495376, 51.084505896414484, 53.94776551954208, 55.810510881485484, 56.64002549263739, 57.160155311707534, 55.48417360551896, 52.86631314985214, 52.59270037374189, 53.75910735899403, 59.29222629916284, 49.643152529193515, 52.61099823059575, 54.887867435332275, 50.47806039933236, 48.26831471535468, 47.648646908421675, 51.25798840676585, 52.60504407267417, 53.21939314565351, 50.08068507717502, 48.13568761271816, 44.90645516303278, 41.151483904930856, 42.619760421014604, 41.5691614151001, 40.18328212922619, 42.984505545708444, 44.5064087067881, 44.37122029642905, 45.643837221207164, 45.632019119877974, 43.844214562446844, 44.568605730610514, 43.95172280649985, 42.597528426877915, 42.96807473705661, 42.66317713645197, 45.27203575257332, 43.04050914702877, 45.83524496324601, 47.6619751222672, 48.68146581034507, 50.04224584948633, 45.81030261132025, 43.560831162237356, 42.73545465161724, 43.67595272679483, 41.623756885528564, 43.16268705552624, 44.45335472783735, 50.92262575703283, 59.10994983488514, 57.30690686933456, 57.39975329368346, 56.05163074308827, 53.83817841929775, 47.20006504366475, 45.270517795316636, 43.258216381073005, 47.682771528920824, 52.93852398472448, 55.46991186757242, 55.40975839860978, 54.32645467019851, 53.47040130246071, 55.008496007611676, 56.974066303622344, 59.7095468736464, 62.011228992093, 62.544408536726436, 64.19295326355966, 73.578322164474, 28.69479717746858, 0.6002031062399188, 2.847116618387161, 5.605506281698904, 0.5245649165684177, 0.09798354949922332, 10.317519191772709, 73.34942833069833, 62.61053577546151, 52.19859238593809, 39.16533685499622, 30.59602687435766, 41.17672435698971, 60.61188420941753, 69.25979260475405, 61.60112165635633, 8.099994957447052, 0.26444417454542657, 0.06124404874900657, 0.06004513646926611, 0.013951398601244776, 0.05889679748384703, 0.07500043679629603, 0.03620354180795051, 0.07878812105064431, 0.03994337238010861, 0.1516060882638539, 0.17637977827220194, 0.09705169546988704, 0.1519193569378507, 0.32715570301778857, 0.1083712650823497, 0.1492294690181171, 0.1678789449074576, 0.16673580382860478, 0.25684191635058773, 23.13668489456177, 82.36709071743874, 67.97811892724806, 62.82842736090384, 34.8613553662454, 34.29605945464104, 45.87096206603512, 53.4622976856847, 64.78925943374634, 74.5014362950479, 35.36048481541295, 0.19971035781406588, 0.592660510972623, 0.9089016674026367, 8.017181955998945, 62.2164434771384, 60.390117322244954, 67.61270307725476, 65.83248830610707, 69.56195631334859, 60.13680673414662, 55.72558764488467, 57.06888175779774, 60.25974950482769, 57.07321205446797, 60.625357550959436, 56.17159643480855, 52.52229382914882, 53.670567697094334, 57.61550718738187, 59.53719008353449, 59.68627152904388, 62.44864779133951, 52.44389741651474, 43.40197909262873, 43.0659653294471, 44.637710048306374, 44.852997179954286, 44.23218404093097, 44.46779689481182, 44.97965443518854, 46.22376749592443, 45.00030179177561, 45.590638114560036, 46.00736248877741, 44.60568389584942, 45.031994542767926, 44.4036739872348, 43.98662013392295, 45.1203812322309, 45.67320400668729, 46.552701380945024, 43.86845481011176, 43.91695491729244, 44.78544612084666, 42.806473085957194, 44.52041156830327, 46.22644255238195, 45.901740904777284, 45.2676191637593, 47.49583921124859, 48.09291808835922, 46.42809552531089, 46.52602141903293, 43.75270566632671, 49.998523189175515, 55.03186548909834, 55.68312406539918, 53.97131935242684, 56.89962364012196, 58.77459502989247, 59.383182141088675, 62.50427092275312, 56.732632652405776, 53.32403021474039, 53.94782435509467, 56.80913063787646, 62.3315336627345, 52.17903152588875, 54.31427963318364, 57.78808363022343, 53.93700645815942, 49.402723004741055, 51.939664963752996, 53.767638514118815, 55.88955840756817, 56.58570458812099, 53.69298012025895, 51.60436899431291, 47.628411400702696, 43.673724820536954, 44.836613439744525, 44.0770072321738, 43.39723302472023, 45.15265057163854, 46.501228117173724, 47.060981719724595, 48.42694713223366, 48.67433101900163, 46.82598860033097, 47.89885490171371, 45.688587542503114, 46.49747833128899, 47.221234075484745, 45.59293270111085, 47.781717238887666, 44.84796870139338, 48.296379273937596, 49.52531276210662, 51.33265856773623, 51.03022029322963, 49.02204521240727, 46.515203522097686, 44.84048089673443, 45.97247300609466, 43.21356411903135, 43.665323103627856, 46.071269665994954, 54.0584469610645, 61.68311488243842, 59.306484114739206, 60.987592358742994, 59.49763298034669, 57.095942189616544, 50.7183644079393, 48.284686688453924, 45.26596000117641, 49.629459534921956, 54.911154547045314, 60.492946178682395, 60.117987202059844, 57.77191562037314, 57.31655589995846, 57.40240089354977, 60.70500519967849, 62.546746269349136, 64.21606779098511, 65.5957144306552, 68.199552412956, 74.26557633184618, 30.783857414799353, 4.257382260214898, 9.650372074496362, 10.585111129668451, 0.865628241050628, 0.18940875817450786, 12.014521860307264, 80.20594319989605, 69.41915066011491, 61.643236144896484, 49.574318855039536, 33.131107668722834, 49.590702595249304, 70.17519535556917, 76.53250232819589, 73.51077895010673, 11.338016948392315, 0.41994574329545425, 0.11560896501666117, 0.3023930753190672, 0.20209039381194502, 0.17301102919924646, 0.18826796132470333, 0.16389133468750985, 0.11953554867256073, 0.07533853437991873], [0.06346400684466766, 0.06721784916496085, 0.02473894983620173, 0.06336112506687641, 0.03855918939676016, 0.03019220116848667, 0.033899754541175026, 0.052190237798758095, 0.055490590541833834, 0.20068834565820234, 12.906514925341453, 64.67220414069392, 46.2386489683582, 50.0868510430859, 24.28478421703462, 24.15789161959002, 35.4691501586668, 37.450668811798096, 59.43636555825511, 60.81900888873685, 23.87319422537281, 0.6742806828791096, 6.868900733609354, 34.18978675719231, 2.022879311153966, 43.77435322730772, 61.484458600321126, 58.949815150230165, 61.95073427692537, 58.96384939070671, 58.38904173143449, 54.02772303550474, 57.16026906044253, 57.532796167558246, 56.55845196016374, 57.34181988623835, 53.342151564936486, 54.11178335066765, 56.299163679922785, 57.95610227892476, 57.632334155421105, 56.54437457361529, 50.37645140001851, 42.554217615435206, 40.101551701945645, 41.21488509639617, 39.528430661847516, 37.2069444964009, 40.2083029285554, 40.88523341763405, 41.62134070550242, 42.21015907103016, 43.85398910891625, 41.92205705950337, 42.19993345199093, 41.64553780709544, 40.59406803500268, 40.78735851472424, 40.24769921456614, 38.739681243896484, 38.6771115949077, 40.091302548685384, 39.12067282584406, 39.83487367630005, 40.26675016649308, 41.36416658278435, 41.66034867686611, 41.94589722541071, 41.36397046427573, 42.37696570734824, 42.1100954855642, 42.57200948653683, 41.3982480572116, 41.094593847951586, 40.52486565805251, 42.36866204969345, 50.507321280817834, 48.78863673056326, 50.602842761624245, 50.85652597488896, 54.39448818083733, 55.331789524324485, 56.83194314279864, 54.090771213654556, 52.89664091602449, 52.57634016775316, 53.95119759344286, 56.08393538382746, 50.1103852641198, 53.2006363714895, 55.98482885668355, 48.99340406540902, 44.12585250792965, 40.33110841628044, 40.548117468434, 41.1122602032077, 41.68238455249418, 40.466277214788626, 42.48396012090868, 40.742384618328465, 40.49812293821766, 42.35072505089545, 41.15502580519646, 39.506202590081, 40.98196298845353, 41.40848936573152, 41.76504458150556, 40.95037221908569, 43.05301366313812, 42.25406216036889, 39.3186701497724, 41.491753439749445, 41.057923609210604, 40.543387090006185, 40.095401425515455, 40.07180052418863, 40.65450391461773, 41.11204055047805, 43.17219095845377, 46.03918467798541, 45.29624462127686, 44.83673503321987, 44.58170644698605, 42.60998195217502, 41.61811259485061, 42.05700620528191, 41.053201075523134, 41.22999406629994, 44.417798442225305, 52.01424491020941, 53.65516454942765, 52.04717713017618, 47.28573353059831, 41.74260077937957, 41.728617529715265, 44.78906254614554, 43.15951385805684, 51.21380682914488, 51.61146063958445, 52.568499349778705, 51.725429027311264, 53.27711866747949, 52.21552918034216, 56.41815662384034, 54.36233651253485, 60.83853444745464, 58.970403671264656, 62.853585443189075, 57.46875170738467, 69.6945716488746, 42.588467751779866, 0.8664596609530911, 6.20587847886547, 4.941834874691502, 0.5511043473116813, 0.06521339543283948, 4.719551705544995, 57.100645111453154, 62.3146870828444, 53.635505630124, 37.442376921253825, 13.451823419140233, 23.52587030779931, 48.92691989098826, 58.46059753048805, 55.9251029260697, 12.149074846698392, 0.3696797115187491, 0.07245440486698382, 0.03633328262836703, 0.02937733642606726, 0.03159666824485025, 0.0477056127161749, 0.05613462533801795, 0.006953597664006896, 0.02241778578008375, 0.022594754005812352, 0.043778998416758357, 0.04966531542219943, 0.031141816946347396, 0.025513596877816225, 0.02916600532649506, 0.05356780561288038, 0.0247162870401817, 0.10407728097972371, 0.1623949504667713, 18.73533841102354, 74.96645681319698, 53.796715044206195, 59.62214469909669, 30.96319602381799, 22.37442324238439, 35.34868632593463, 46.5864259196866, 62.59979240355953, 66.99163498417025, 24.889325403398086, 0.4318565106199634, 3.842011839151383, 23.317661093127345, 4.508926310846883, 45.908283418224705, 61.44170084307271, 60.06788676784885, 64.16831685650733, 60.0712521614567, 60.73014367011286, 56.80482387542725, 58.11448758648288, 59.0954605994686, 60.72273823522753, 59.39857352164484, 54.44521227190572, 53.194823418894124, 58.15551557848531, 57.95516091008341, 59.93212961381482, 57.73034634128694, 53.467624264378706, 45.69873863650907, 43.502552586217085, 43.77906399388468, 41.869940527023815, 41.94344182168284, 41.604764769154215, 43.00150117566509, 44.16837100059756, 43.99723798997941, 45.9383640750762, 45.23021936416627, 44.025004448429236, 43.49466862217073, 42.92097099365727, 42.75987925068025, 42.78815953962265, 41.18190580798734, 41.86465317203153, 42.03015758145241, 41.083332723186864, 41.3924821730583, 42.80519831565119, 43.48818102190572, 42.313489990849654, 43.66415031494633, 43.641616298306374, 45.91546920038039, 45.31477782034105, 44.429989168720866, 43.8926911354065, 42.73647054549187, 42.70294212525891, 44.86652543467861, 52.78408458155971, 50.6390776172761, 52.628472389713416, 52.68786491886262, 56.13457710512223, 57.43826312403525, 56.79300969646823, 55.99810607971684, 54.30015517819313, 53.33276533311414, 54.94056447859734, 56.457851009984175, 52.288371516812234, 55.015109123722205, 57.04037789375552, 50.93363192773635, 46.79253470513129, 42.53925377322782, 42.53093442609234, 44.53971355192123, 44.18370354560114, 43.647672437852435, 43.363512408348825, 42.639474253500666, 45.01682673731158, 44.06074900780955, 43.45065962883734, 41.373646951490834, 43.011852310549834, 43.996018132855816, 42.838440402861565, 43.217710064303496, 43.84448128361856, 43.22004387455602, 41.82673169720558, 43.595830471284934, 42.490592848870065, 42.96722358272922, 42.29169337980209, 43.87258898827338, 42.61547327041627, 41.60579243013936, 45.65571808045911, 49.34154579716344, 47.18705454180318, 47.12524191025765, 46.23996296236592, 44.592975416491115, 42.74187557158932, 43.71764359935638, 41.57183647155762, 43.76864225633683, 46.202198382346864, 54.396312082967455, 54.73823685799876, 55.28754518878076, 49.79868627363636, 43.81915061704574, 43.84506179440407, 47.075274836632516, 45.621232601904104, 54.69860915214785, 53.73467883756084, 55.797319950595984, 54.68146447212466, 56.64923129543182, 56.31866962678971, 58.576923262688425, 57.71534327537783, 63.83357001889137, 62.92225830016598, 67.44921084373229, 60.440923783086966, 69.89837800302814, 44.562400540997906, 0.9665170564286172, 2.644954227632092, 7.6173031810791265, 1.3156572152529995, 0.13132594826240696, 5.753719902807667, 61.580999897372344, 65.26475268025553, 56.581080113687825, 38.648270407030665, 17.884015421713553, 29.051052331924442, 55.56597463546261, 64.50305584938296, 65.39190023176133, 16.174647481210773, 0.39709147125963246, 0.06534900065631637, 0.01603435527818698, 0.06295006909978486, 0.07247308975145703, 0.029133605552957426, 0.009265104703034365, 0.025233898176661423, 0.04889853035790786, 0.18533626541254983, 0.18129738858870922, 0.13007359368906868, 0.1675531736785366, 0.23396188843875165, 0.21061131400206398, 0.14383365129751546, 0.1771778427064419, 0.24338663916193673, 0.3250494515222888, 24.285188221162368, 85.58927859029463, 60.880064502839126, 66.19431910976287, 37.55416447116483, 37.48417369781002, 48.13096115666051, 51.31454506228047, 67.7877192343435, 71.6638760412893, 29.710453748703006, 0.9048858957905924, 9.318213020601581, 42.784307772113436, 3.688638585229074, 49.328488226859804, 62.543467167885076, 62.14680179472893, 66.05948371271934, 62.79196500778199, 64.13885985651325, 59.4753578401381, 61.786288907451016, 61.88581905057354, 63.28313204549975, 61.29096415735061, 56.013003241631296, 54.882929171285326, 57.727698741420625, 59.62529043997488, 62.70109938037012, 62.40846703129431, 54.78964344147713, 46.045578141366285, 44.37700971480339, 46.369479625455796, 45.07457971572877, 44.25831879338911, 44.59592896123087, 45.369196784111764, 47.425224781036384, 46.92661308473157, 50.74834700553648, 47.027425842900435, 47.168231087346236, 47.39705824082898, 47.24691775537307, 46.62915229797364, 45.64175836501583, 44.37350703823952, 43.494707845872455, 43.24721413273966, 41.95700930010888, 42.400405791498, 44.749081826979115, 44.958093166351325, 44.987926713881954, 45.125962764986106, 44.96042305423368, 47.242736508769376, 46.445530460726836, 47.23327575191375, 45.236820713166274, 46.50826484926286, 45.16333118561776, 47.20378737295828, 54.891005331470126, 53.49659096810126, 54.92638118805424, 54.00077243005076, 57.88216167880643, 60.872506095517075, 61.03446468230217, 58.05103148183515, 55.62015433465281, 56.06016582058322, 57.857909664031006, 59.359106632971, 54.03868606013637, 57.54761880443942, 61.274317618339296, 55.732424336095015, 49.97390639397406, 44.9115385547761, 43.628452824008086, 46.48654276324857, 46.941882871812396, 45.012971047432195, 46.43930958163354, 47.5591423434596, 46.25173399525304, 47.47558409167875, 47.02611969363305, 44.13265782017862, 45.36899674323298, 46.030684901822, 47.095047504671165, 44.67954212619413, 48.099127200342, 44.615721241120376, 44.29683254611108, 46.368428430249615, 45.00152164889921, 44.73068983324113, 44.30946650043611, 44.933903909498646, 45.75518938802904, 46.00331852512975, 48.257461517087876, 51.91512269358481, 50.229927339861476, 49.86287586150631, 50.48182195232761, 48.19624116343837, 44.893134793927594, 46.80196800539571, 44.71582405028805, 45.46187846891342, 48.81955285226145, 56.29666905249319, 58.15909278008246, 59.70471843596428, 52.936562799638324, 46.078824150946836, 45.196047675225046, 50.9424376487732, 47.24223444538732, 56.81345701217652, 56.86581673160676, 58.974557461277136, 57.17324818334272, 57.72785171385735, 58.29826631853658, 61.724923426105136, 61.35116469475531, 66.36521677817068, 64.96980613277805, 68.69770911432082, 63.747815239814024, 71.62582905061784, 47.660539534784135, 2.435364583807607, 16.53840514921373, 11.218523902277793, 1.788651911962417, 0.25010095548725897, 6.757948158248779, 67.69547293263098, 70.89870791281425, 66.98634762917796, 49.901377847117764, 23.280539781816547, 35.5313354153787, 65.16066082062261, 74.86556560762467, 75.04289596311509, 21.911707116711526, 0.5223834658822706, 0.24266486176319663, 0.16073574191860615, 0.1439147187216628, 0.10706019753049459, 0.2803166276745258, 0.13883633719336602, 0.14373226722161617, 0.1761531694641998], [0.06511776467725154, 0.07428229065431703, 0.1135530225151489, 0.013221721878395447, 0.08691931699192332, 0.07299408316612244, 0.050047309843883406, 0.08448672736243856, 0.11314416905083965, 0.01896261241317036, 16.59087665619389, 58.933768733855224, 55.217440666690955, 49.86250323633994, 26.25053494207321, 36.56192641104422, 37.83971694207961, 44.515814550461315, 59.66189399842293, 62.62196163977347, 15.554870828505486, 0.5155492261532815, 8.474779878893207, 34.39949235608501, 2.071928550158778, 9.987633151392783, 65.51268569884762, 60.97194602412563, 62.954155014407256, 57.942825055891475, 62.05679124401462, 56.38600103316769, 58.87346621482604, 57.55796993932417, 60.04867499874484, 53.07119815580307, 54.49004496297529, 55.99512900075605, 57.346138415798066, 56.01758064762239, 56.19717421070222, 54.0665231212493, 50.122925081560695, 41.88704206097511, 41.84140920639038, 40.308233153435495, 42.20959424972534, 38.78457277051864, 40.56206149439658, 39.310248821012436, 40.38184819682952, 43.21446626417099, 44.242633235070016, 44.03895239676199, 43.6907204504936, 41.891368435275176, 40.95601650976366, 39.290585979338616, 39.11788009828137, 37.6340356949837, 39.89920839186638, 40.202297779821585, 41.47072169088548, 39.78200797111758, 41.247456458307084, 40.47224706219089, 42.156669708990286, 41.17180178242345, 43.06641247964675, 41.00025300056704, 43.194948550193544, 41.42148025574223, 41.945191198779696, 40.71170383884061, 41.18744811704082, 38.907746961039884, 44.8855959984564, 46.88628719698998, 49.845197739139685, 49.33949047519315, 51.68151809323219, 53.341296488238925, 53.78126875046761, 52.92741191002631, 53.2089674857355, 52.6374153937063, 52.22319349165886, 55.55632560483871, 50.2224003115008, 52.4908717216984, 54.29412649523828, 50.25002164225425, 49.86196587162633, 47.232895282007036, 42.68036104017689, 40.38316611320742, 42.303095709893014, 41.26247521369688, 40.912623328547326, 41.315380142581084, 42.712304822860226, 39.906566758309644, 39.913058280944824, 40.73812100195116, 42.2825111112287, 43.12006658123386, 41.59710830257785, 43.52822057662472, 41.4748284124559, 42.99997145129789, 41.90326890637798, 42.06433319276379, 40.520621653526064, 39.95314098173573, 40.287322998046875, 41.74495420148296, 39.179461309986735, 41.34542942047119, 42.17310444001229, 44.14444454254643, 44.17858485252627, 42.38980362492223, 41.179870097867905, 40.48689711478449, 42.377224583779615, 40.40194642159247, 41.617763503905266, 40.492415889616936, 41.24096101330173, 42.38001731134231, 42.93130643906132, 41.63295876595282, 41.80120491212414, 41.896039978150405, 43.09983107351488, 42.93354219005954, 49.45471794374528, 54.75305949487994, 55.22142187241585, 54.19912668966479, 53.34861955335064, 59.18682829026253, 53.55611293546615, 55.444106594208755, 59.04964339348578, 61.603494690310576, 62.844709119489124, 64.9934305683259, 47.9214124525747, 44.69091307732367, 54.277095563950084, 1.5210380333085216, 1.797530687143726, 3.0204515495607933, 0.7365021602280679, 0.11579175359539448, 2.4206431931064976, 49.21858341463151, 65.73377401598039, 52.99437853597826, 37.562201407647905, 29.614973452783403, 29.429623811475693, 49.68841275861187, 51.594602292583836, 61.781531072432, 17.80114358471286, 0.17820110634690334, 0.0020624252811690135, 0.07134887870521316, 0.021087083394729325, 0.1156775911729182, 0.082745723606598, 0.08180015660341709, 0.009264199761673808, 0.017543765866468032, 0.02140044591449682, 0.08308906123162278, 0.024571419813700264, 0.01344016035868516, 0.07889907356471786, 0.04867341542135804, 0.05319503105936512, 0.03345474938771898, 0.04204970431484042, 0.047868138269311, 21.597258544737294, 71.05841113675025, 60.13086434333556, 56.46546433048864, 32.54043794447376, 36.90288236064296, 39.85940810172789, 51.188691892931544, 63.528593970883286, 67.60245000162433, 17.16049894209831, 0.5520038571088546, 8.262159958962473, 37.19507932662964, 2.1602622876244206, 10.389792784567803, 66.62409320954355, 57.72100325553649, 64.91048420629194, 59.77209298841415, 63.684845509067664, 58.95909155568769, 61.24736701288531, 58.93299602693128, 62.629327850957075, 53.81989625192458, 55.295621348965554, 57.01566303929975, 57.72294482877178, 58.1397476503926, 58.00396696213753, 56.74093238769039, 52.863555723621005, 45.156823973501886, 41.85594943261916, 41.56667071004068, 43.851400344602524, 41.47811928103047, 42.16794652323569, 41.23457931703137, 43.76586914062501, 45.96393008385935, 46.84747534413492, 44.68417444536763, 45.58524093320293, 43.6753055357164, 42.8754008969953, 41.455565652539654, 42.279757607367735, 41.31951039837253, 41.13391560892905, 41.402362623522365, 42.75843974082701, 41.31649409571002, 41.90459466749623, 42.89738970418131, 43.749273592425936, 43.73009320228331, 42.76601383762975, 44.072963268526145, 45.1505599483367, 43.27289781262798, 44.861842124692856, 42.89271031656573, 42.90402243214269, 40.60169704498784, 46.98624880083146, 49.19886958214545, 52.64624072659401, 51.66771527259581, 54.23485555956441, 55.373131305940696, 54.12553518049179, 55.572685810827444, 55.85594369519142, 55.15433365298856, 54.82958493694183, 56.590387898106734, 52.36387714262932, 53.07819958656065, 56.37333177751111, 52.79148217170469, 51.98684323218561, 49.227671546320764, 44.42349372371551, 42.97754333865258, 44.535602907980646, 42.53705724593132, 44.003349042707875, 42.22825688700522, 43.57699917208764, 41.876251620631066, 43.07611250108288, 42.185091203258885, 43.281970254836544, 45.546229039469075, 43.78383751838438, 44.40607840015043, 43.464991969446984, 44.26536337021859, 42.38819937552176, 43.47540586225448, 41.08825529775312, 41.26063562208607, 43.01622575329196, 44.1287785960782, 41.7845779849637, 42.18906064187327, 44.1690025021953, 46.06972817451724, 46.31136971135294, 45.956167713288345, 43.49079724281065, 42.57093475710961, 43.69385834663145, 43.45016933256581, 43.46776508515881, 42.52121087043516, 44.56198084738947, 44.52313369320285, 46.56202093247445, 45.46109791724913, 44.393907285505726, 42.16562840246385, 44.24119764758695, 45.474292770508804, 51.717329332905436, 56.14566956796954, 56.525421680942664, 55.73155356991676, 55.591779908826275, 60.82049546703216, 55.10344090000276, 55.83177012781943, 59.37092473430019, 64.55192858173002, 65.28713764682894, 66.03657707091301, 55.02870405873945, 44.07341434109596, 55.233145836860906, 1.9505987316370013, 1.397199736487481, 5.186200007315605, 3.1647209823131566, 0.09689377410517586, 2.70863930063863, 54.254200689254276, 71.30245316413142, 55.149442457383685, 44.1667353722357, 30.450075480245776, 32.66740506695163, 57.29497501927038, 59.33227762099236, 70.62790747611754, 23.313173901650217, 0.2922706330014814, 0.014460964856909649, 0.11084871682068033, 0.038523374786300045, 0.08090807019823021, 0.02984645994259946, 0.014399512156453586, 0.03389532272253306, 0.0744364888317162, 0.0773119155858313, 0.11988832450081265, 0.220193694976549, 0.13027176531332155, 0.17255580443288052, 0.1887061023303578, 0.15764721248659397, 0.13173480938759544, 0.22559505917372244, 0.17789525340401358, 29.100923307480354, 80.46529031568959, 69.47265963400565, 65.61099990721672, 35.02446320749099, 48.747412620052216, 51.83016807802262, 57.93097949797108, 68.43362377535912, 73.56251501267957, 19.46785673018425, 0.8153861725041944, 11.259299881996649, 39.05015253251599, 3.016439945467057, 13.169345105848006, 69.19621098426082, 60.59237041781026, 66.95769079269903, 63.72093523702314, 67.02266093223326, 61.96083438011908, 63.7379426340903, 61.428835468907515, 64.3764417402206, 54.862497545057735, 55.670309682046216, 56.324298227986986, 60.13872477316088, 60.338730350617446, 59.60094036594514, 59.20826404325424, 53.98231767839002, 46.91964303293536, 44.81556600139987, 45.195388717036096, 48.36712314236549, 43.66440134663736, 46.16761876690773, 43.43823748250162, 46.487233100398896, 49.032039411606334, 50.70921351832729, 47.68198313251619, 48.159406185150154, 47.47667058821648, 46.900313592726185, 45.0520182424976, 44.86166954040528, 43.37855862032983, 43.51259777622838, 44.44809482943627, 45.03144933331398, 43.080187843691924, 43.11364958363195, 45.69394157778832, 45.431095707801084, 44.09509328103835, 44.50767170998358, 44.6333287608239, 47.86797408134707, 45.21099190558157, 47.70847482066001, 45.989794192775605, 44.54074513527655, 41.97642503246185, 49.70007004276399, 51.24003571848716, 55.121707377895234, 54.25071370217108, 55.64701864796301, 56.054756872115604, 57.912720864818944, 58.00877971033896, 58.02799540181314, 58.01836990541028, 55.65173333691013, 58.93620060336206, 52.882649821619836, 57.71116595114432, 58.57233801195699, 54.45222939214399, 54.54245959558795, 52.62479320649178, 46.37308820601433, 45.135698087753795, 47.29580617720082, 44.65108533059397, 45.292730177602465, 46.21335360311693, 48.198896608045025, 43.813800504130704, 45.40541202791276, 44.84019064134167, 46.00439717692714, 49.299784321938795, 46.290769423207934, 47.591756851442405, 45.88000312928231, 47.24827097308251, 44.116270157598684, 46.14253128728559, 43.50345865372689, 45.19259991184358, 44.819696257191325, 46.677048360147786, 43.533484397395966, 46.14902280992078, 47.692271509478175, 47.833578817306034, 49.155907861648075, 48.84919812602382, 47.09721657537645, 45.47352006358486, 45.873660656713675, 45.42352945573869, 44.88170892961564, 46.43514402451054, 47.20395211250552, 46.74471316799041, 49.00386894902876, 47.525864954917665, 47.48024778981363, 45.4659616562628, 47.61091370736399, 48.10501860034082, 53.80123753701487, 59.97406367332705, 60.531510922216604, 61.43368744081067, 58.372544242489724, 63.47292769339777, 57.26273313645394, 58.73743057250977, 62.10846847103488, 67.46337844479469, 66.71130318795481, 68.44234712662237, 58.275736224266794, 47.12881126711446, 59.054656182566, 2.591753895244291, 4.106022162783531, 10.548477172851562, 3.187821536294876, 0.19938585829109917, 3.1818190841905536, 59.923461175734005, 74.75470373707434, 67.30637381153723, 51.613378678598714, 40.65182885816021, 42.881080489004816, 66.76140754453598, 69.50964758473059, 79.67996120452881, 30.044514171538818, 0.5508553380927732, 0.17444128471036113, 0.24730977542217703, 0.11293763940733288, 0.27123627943858025, 0.19903512791760508, 0.18398497824467, 0.16826946588773883, 0.1755262643940026], [0.06021338852963621, 0.03182914911679203, 0.07167573011810742, 0.02965509692477363, 0.033475939379704577, 0.018552515971203967, 0.032366184412591884, 0.056171853380698356, 0.024850319868194002, 0.20543259027744495, 21.037624574476673, 57.974188327789314, 51.034907525585545, 43.11570882797242, 22.022788639991514, 30.058354254691835, 30.08317893551242, 48.776755871311316, 60.609417038579146, 62.539917422879135, 11.60450375849201, 0.7210223424819209, 7.592276988490936, 9.325894982584062, 0.886042032751345, 0.95861813834598, 40.01096848518618, 58.89698082400907, 60.127612698462706, 57.37700354668402, 61.42943166917371, 59.79403864952826, 57.095702925036036, 56.98120893970613, 51.35027000980993, 52.73325850886684, 56.74159134587934, 55.225567817687995, 58.73061349315029, 56.068359651873195, 57.23156206069454, 53.71196831426313, 42.22606820444907, 39.76281189149426, 40.643156497709214, 40.184419616576164, 41.24154544645741, 39.15041223649056, 39.87808642848846, 40.15684927663496, 40.58043387628371, 41.578826135204686, 44.3598650347802, 45.11765910733131, 43.962626995578894, 43.77809516845211, 39.94575908107143, 40.1255879863616, 39.355159959485455, 39.82589537097562, 39.82179649414555, 39.78106267990605, 41.95240443752658, 41.334082003562685, 41.78310709614908, 40.67220949357556, 40.29189255929763, 40.60254427694505, 40.80416194854244, 41.56385837062713, 39.90917513447423, 40.4546630767084, 42.0890284353687, 40.52131983541673, 40.52359873248685, 40.62197569877871, 40.42051099961804, 42.031679461079264, 43.30221360729587, 46.14408454587383, 47.394540079178356, 47.303960784789055, 51.17545781597015, 52.02805165321597, 50.38513160520985, 52.567926683733546, 51.12448269321073, 58.02528896639424, 45.93911324777911, 49.08516007085001, 57.887186234997166, 51.98638431487545, 54.23335329178841, 53.53258655917261, 51.333635237909135, 42.27789448153588, 41.21213943727555, 40.37458004490022, 43.60109429205618, 40.671409330060406, 41.46411641951531, 41.630813229468565, 41.12986380054105, 41.18419647216797, 41.339451728328584, 40.74954294389294, 41.499186331225985, 39.916976728746974, 40.841879460119436, 43.21608228068198, 40.264639931340376, 40.86718659247122, 40.33184974424301, 41.90900733394008, 41.83361937922817, 41.251500421954745, 43.82364957563339, 39.90751597189134, 41.62868730483517, 43.78293929561492, 42.45425208922356, 41.927171830208074, 42.47509164194907, 39.66116366847869, 40.90632792442076, 39.30776203832319, 40.38815929043678, 40.34866494517173, 42.107628314725815, 40.71809337985131, 39.6830387269297, 41.39652221433578, 41.09777489016133, 42.010875209685295, 41.805280254733184, 48.466088464183194, 54.24594410004155, 55.305372361213934, 55.27140071315151, 54.902509643185525, 57.00532367152553, 54.5853546357924, 57.573714333195845, 55.00099643584221, 61.356165716725016, 62.679440052278586, 66.51392167614353, 60.43923716391287, 63.50675421376383, 32.8418505191803, 42.94429340670186, 8.426820078203756, 1.7154504334734333, 10.01730097878364, 0.6639288738369942, 0.09405420792679633, 1.1884872326927802, 46.10621406186012, 60.90897629337927, 56.69989262857745, 38.01853387586532, 22.465828195694957, 25.70242685656394, 37.780685270986254, 55.7723815210404, 60.40942715060327, 25.649543500715687, 0.3636974841356278, 0.02875460461983758, 0.032235907330628366, 0.040083938022895206, 0.009685658245167185, 0.05134824205250029, 0.03549177334794114, 0.09419352867670598, 0.05030741201593511, 0.06945998933646949, 0.028048878678330974, 0.02466051009363465, 0.0223617043135868, 0.04198259118223383, 0.023592702270815932, 0.0330961819347595, 0.027623607949804396, 0.03410981968045235, 0.1612131219477423, 29.43316375055621, 67.75210411317887, 58.55863717294509, 48.45500384607623, 25.8191801271131, 32.86286657856357, 38.21637430498677, 52.83476944892637, 65.69709201012888, 66.58042154004498, 13.218545356104451, 0.8474774730782356, 10.660804048661264, 12.113446977830703, 3.0778647526617977, 0.9149423013291053, 44.490997714381066, 56.84965264412665, 60.68966873230473, 59.20944075430594, 63.86346632434476, 62.08578932669855, 59.40255472736975, 58.35623894968341, 51.81544350039575, 51.88319460038216, 56.36052916126867, 56.71140870740337, 59.989874747491655, 59.43014860153199, 58.6778340801116, 54.68686165348176, 46.1353611946106, 43.25442737148654, 42.401613881511075, 42.9106237811427, 42.791477864788426, 41.09444479788504, 43.49968533362112, 43.319974099436116, 45.13298772996472, 44.82614071138444, 47.183116482150176, 47.10981130599976, 46.42831910041071, 44.71577305947581, 43.58822891789098, 42.45311460187359, 40.92339807941068, 40.00405726894256, 40.04248865189091, 40.48985458189442, 42.90352036876064, 42.852149086613814, 43.596026589793546, 42.13662247503958, 41.570624459174375, 42.229480666498986, 42.86863088607789, 42.86727374599826, 42.16363976078649, 43.19286577163204, 44.068295648021085, 43.99008750915528, 42.902641757842034, 42.321405333857385, 42.391682440234774, 43.13396746112455, 46.23571895783948, 48.85881185531617, 48.90887698819561, 50.58808288266582, 52.30278230482533, 53.129959183354536, 54.67850308264456, 54.53417554978402, 54.25756608286212, 58.46393938987487, 47.07546311040079, 49.887222013165875, 59.35639235281176, 54.025255864666356, 57.052741204538655, 55.72817248682822, 53.096960283094845, 44.270874300310695, 45.10950842211324, 40.68231744150962, 45.7398372311746, 43.803920053666644, 43.40072785654376, 42.951341905901515, 43.22571562182519, 43.442991395150464, 44.20254661190895, 42.02076742725988, 42.865771478222264, 42.65978820862309, 41.500563083156464, 42.8868346060476, 42.227342974755075, 42.85252955652053, 42.783240887426565, 41.75794901386384, 43.41045925694127, 42.336612363015455, 44.898833997787975, 42.30520202267555, 44.625048637390144, 44.492213649134484, 45.605652947579664, 45.658157794706284, 45.00120001454508, 42.86962324573148, 43.76581030507242, 44.55240634179885, 43.263495891324936, 43.32688531567974, 44.02234115908223, 41.79575281758463, 43.94156386775356, 43.921497021951986, 44.23789893427203, 44.093006580106675, 44.27016827367967, 48.9287987063008, 57.66558408737183, 57.15264789519772, 57.25873624124835, 56.61065870715726, 59.062202822777536, 57.77419843981343, 60.7812011626459, 57.77878369054487, 64.53874157321069, 63.27002740675404, 67.43920095505254, 60.550907042718705, 64.82055210298108, 34.802351151743245, 46.74228914322392, 8.374334842927995, 1.6818150060792125, 9.531925320625305, 5.795032266647586, 0.035279168627194823, 1.2883388875953614, 50.931341263555716, 67.31890970660795, 62.34281832172025, 41.34229544670352, 29.90074557642783, 33.7747960705911, 48.96612005849039, 62.48929139106505, 69.84959940756522, 31.21802260798793, 0.37512920135932587, 0.04352915799245239, 0.04182330235057781, 0.004075567168559158, 0.05969059097790911, 0.04246434174297799, 0.017016879320445082, 0.05578343914220891, 0.029703590290380583, 0.15619785074264775, 0.16532627865672112, 0.19709649645993788, 0.14469295680042238, 0.22517970162293605, 0.13126570310804153, 0.07591188990420873, 0.13475071368438585, 0.14612276798054097, 0.3870196826756001, 37.3057686128924, 79.56821287831953, 66.91787089070966, 57.841423942196755, 32.67761695769526, 40.701948904222064, 41.55266784852551, 59.32830033763763, 70.46569393527123, 73.84109743179815, 14.821641579751047, 0.9743495393664607, 9.942974025203336, 12.769441816114611, 3.0027918133043476, 1.707764671694848, 48.776277342150294, 57.899898636725645, 60.63140976813532, 60.879480069683446, 64.95610529376616, 63.533340038791785, 59.902445116350734, 59.33284636466735, 51.21391273313954, 52.01383306134132, 57.41208130313505, 57.71540603330059, 62.41363279281124, 60.438550749132716, 62.57572866255238, 57.642351888841205, 46.28330907514019, 44.79414593788886, 44.437374991755334, 44.29370249471357, 45.18499443607946, 44.39057719322943, 45.50101980086296, 46.84409033867621, 46.96885308911724, 46.4581879492729, 49.332249779855054, 51.47867664214104, 49.07185931359568, 48.148086224832845, 46.06503309742097, 45.04828806846373, 43.955974655766646, 42.25826301882344, 41.44417508955925, 42.63928205736222, 45.86674551809988, 46.79242487876646, 45.857222003321496, 44.294549726670795, 44.1013769180544, 44.65483511647871, 45.14521375779183, 45.40490604216053, 43.71160314929101, 45.46685203429192, 48.22780055384482, 44.95873251268941, 44.25330992667906, 43.77285880427207, 44.9348178217488, 46.670545070402085, 48.11975886744838, 49.70895028883412, 51.77344668296076, 52.811839272899014, 56.98043231041201, 55.64272365262432, 56.94287561601209, 56.40986865566623, 53.72689685513897, 61.07375506431826, 50.72207104775214, 54.64724571474137, 62.719307022710005, 56.60791697040681, 58.57840591861356, 58.40433505273635, 55.228513517687404, 47.87735639079925, 45.95376722274288, 43.3524787810541, 48.89260307435067, 47.39082951699534, 46.20377125278596, 45.454822124973425, 46.16591253588277, 45.12364464421427, 46.41241781173214, 44.553810550320534, 45.588731842656294, 43.73637683929936, 43.676913707487046, 45.55370115464734, 44.297922965018984, 46.483204826231926, 44.83478169287405, 46.46166316924557, 44.877923842399355, 45.01137072040189, 47.778171416251894, 43.69707076780258, 47.52254270738172, 47.22336784485848, 47.426668213259795, 47.474426992477916, 47.64888617300218, 44.41812399894961, 46.0211496199331, 46.91700720017957, 44.241405533206084, 45.47331610033589, 47.724897784571496, 42.85758941404281, 44.22941876995949, 46.56784565218034, 49.28629921328638, 47.292578066549, 47.1178953109249, 53.098427249539284, 59.260647296905525, 60.19973724119125, 61.644075532113355, 59.6200030849826, 60.8264260907327, 59.71212387084962, 62.47986593554097, 60.476774246461936, 67.27758361447242, 65.61146666926723, 72.66495120140814, 64.21986072294175, 65.69718222464284, 37.213071238610056, 50.597975100240404, 9.688284723989426, 3.739352625223898, 26.123520751153272, 5.0989802229789, 0.20917661518098848, 1.6630130020841476, 56.610478278129335, 72.25189424330189, 71.39826882270076, 48.86344417448967, 32.35531187826587, 37.82903632810039, 55.19967625218054, 71.36703106664842, 77.45992322121897, 40.69624185562134, 0.6820699584580238, 0.0875489033698555, 0.10201359332929696, 0.07830488044888743, 0.1809378788476029, 0.11954120240144192, 0.14096753251168037, 0.13216789421294967, 0.20597963834241514], [0.05023408207982298, 0.03179112434267037, 0.024843003728517124, 0.07287533187697973, 0.04079185306064544, 0.03365929869394149, 0.041878146585077054, 0.021254435301788395, 0.017539496841509978, 0.4879115930488033, 32.34402133572486, 61.00818872451783, 51.834784707715436, 45.69485941240865, 27.9105035720333, 30.64423280377542, 32.5783319627085, 47.679523806418146, 61.615406928523896, 58.44377448481899, 10.482832385647683, 0.5703786904773405, 2.977824946565013, 7.829796604571804, 3.2968872064544312, 0.1774825618392037, 39.243019396258944, 42.42366152424967, 36.62259371049943, 62.93706916993665, 56.14935659593152, 60.06677673709009, 56.51562752262239, 55.49050431097708, 53.49772453308106, 51.92007664711245, 52.003952610877256, 56.80327846157936, 56.9008787985771, 56.1626769650367, 52.33126655701668, 46.382011598156346, 41.89935045857584, 41.09449971106745, 38.57260396403652, 38.89813715411771, 39.4448959442877, 41.582140538000296, 41.306393992516306, 41.226169755381925, 41.37491779942667, 45.17097196271343, 43.0124092871143, 45.23041156030471, 44.993912250764915, 42.83330994267618, 41.06959266047324, 38.7001633644104, 40.861067695002404, 41.26766450943486, 38.43633297950991, 39.0464537374435, 39.13401672917028, 40.601363643523186, 39.35724666041713, 40.16265438448998, 39.348707660551995, 41.16754601078649, 40.646663096643266, 42.836922445604884, 39.130219874843476, 41.522026292739376, 41.689358526660556, 40.64228180916079, 40.295732559696326, 42.1227765083313, 41.442727734965665, 39.37673691780337, 38.34418473705169, 40.75648161672777, 40.68163887146981, 40.916565310570505, 44.89467236303514, 51.035135023055545, 49.37879654668993, 54.11806306531353, 53.95020523378926, 57.36373024602091, 49.76985293049967, 42.43218875700428, 56.58006814218337, 52.18245575504919, 57.47243873534664, 54.78770579061201, 55.57116393120059, 45.322822601564475, 43.069597444226666, 40.25436724385908, 40.93582414811657, 42.16231399966825, 40.60101063020768, 40.2823886563701, 41.83985987017232, 39.968626499176025, 41.52211258488317, 40.26092544678719, 42.68043556521016, 41.179462171369984, 41.86697521517354, 42.60024662940733, 42.265994010433076, 41.423508121121316, 40.36338560042843, 39.0651555984251, 40.45830695859848, 39.574800922024636, 40.309586371144945, 41.85570624566848, 39.55445166557066, 39.425491979045255, 42.09487276692545, 42.80983847956504, 41.2774625901253, 40.98341426541729, 40.77964713496547, 40.020629282920595, 40.263553434802645, 41.17515540892079, 39.45010485187654, 40.81519557583717, 42.51217765192832, 40.15461744800691, 41.59586098886306, 41.094597770321755, 43.92587046469412, 53.131316323434156, 57.175115231544744, 60.631256795698604, 57.300356511146795, 56.82475736064296, 60.22660939924179, 59.092597269242816, 60.166871701517415, 59.49003142695273, 59.58277979204732, 63.24386127533452, 64.2116080560992, 61.75549045685799, 61.633661639305856, 37.119683527177386, 46.79579811711466, 12.638128707485816, 0.6047148738176592, 4.566516020605642, 5.034269940468573, 0.05614404438904697, 0.46001542059163897, 43.218423935674856, 61.15082963820427, 55.39024068463234, 51.05248758869787, 40.430642481773134, 15.074870778668313, 32.96666622161865, 61.67401890600882, 63.06502080732777, 29.304264860768473, 0.6437224161721046, 0.028450287683236024, 0.08855912053296644, 0.014520215054583407, 0.0446397403345233, 0.04384063019026672, 0.03542154989836197, 0.010934146947317548, 0.038969050266689835, 0.015798396367068975, 0.027351907206579085, 0.02636569157813586, 0.005015005468345818, 0.05737662623305956, 0.01122302721224485, 0.009568103010796252, 0.013781279201559244, 0.015851451786265017, 0.568460590176044, 42.25927106795773, 69.35682419807681, 58.874666460098766, 51.54998925424392, 32.52686262130737, 35.94630256775887, 39.16858065512873, 50.49242804127355, 65.40599723016062, 61.30893253510999, 11.756151414686634, 1.0701836453330134, 5.054630473736794, 13.404241146579867, 3.71472210172684, 0.04442463050626459, 40.3784514242603, 43.3738164747915, 37.350416952563876, 65.44320483361521, 56.654153869998076, 59.403197996078006, 57.50940315185055, 56.142147279554806, 53.09502655459989, 51.907379934864665, 53.95346864577263, 61.234921332328554, 58.907469241849846, 58.545136374811975, 56.208199993256606, 50.293093189116455, 43.781044790821696, 42.522289522232555, 41.032004587111935, 40.62574117414413, 39.668027816280244, 43.82653644008022, 43.3054534850582, 43.312490217147335, 44.25016026343069, 48.15444438688217, 44.48055636498236, 47.798222572572776, 45.65842843824818, 43.64250667633549, 41.31590574018417, 41.520759367173724, 42.22382460871051, 42.207927242402114, 40.54771346430625, 40.61502918120354, 41.36466080142606, 43.3780526345776, 41.40950525960615, 42.79356064334993, 40.7498606558769, 42.347685214011904, 42.13331199461415, 44.05689331793016, 41.445685202075595, 42.01056142007151, 42.9519812522396, 42.507902268440496, 41.87779311210879, 42.99358191028718, 42.214861992866766, 40.14090484188449, 40.86021654067501, 41.19388472649359, 43.34469679863223, 43.812208021840746, 46.568351637932565, 52.30836383758053, 53.298672091576364, 56.724740843619074, 55.58136601601878, 59.13241717123217, 50.19741873587332, 45.152940827031294, 56.42485995446482, 52.9468943226722, 58.10011209980134, 55.0875670679154, 57.45841626198062, 47.70771388084658, 44.25722837448121, 42.32847736727807, 43.74955600307834, 42.98914570962229, 43.09606559814946, 41.57656684998543, 43.33955457133632, 42.86733258155085, 44.0731397751839, 41.933624129141535, 43.905540820091005, 42.965889976870635, 43.3268343248675, 44.516638248197495, 44.32006866701188, 43.59961555850121, 41.63852068685716, 40.442907733301965, 41.39618881287114, 40.3256170980392, 41.23689351543304, 44.09504621259628, 42.08852244961647, 41.58118740204842, 44.11210460047568, 45.88059148480816, 43.311595916748054, 43.727543661671305, 42.31511385210099, 41.276764408234634, 43.26622586096487, 43.18489943781207, 42.08374500274658, 43.50156022656349, 45.25965282993932, 41.829136110121205, 43.3403076664094, 41.76269115940217, 46.5783497595018, 54.996407262740604, 60.06686695160405, 63.12313072143063, 60.358165694821274, 60.4892473836099, 62.57901168638661, 60.70329504628336, 61.71555288376347, 60.66970779049782, 63.64216619922269, 62.81515406024072, 67.94058968943935, 61.255152917677364, 58.08784292590234, 42.442065285098174, 49.97080379916776, 14.28698035978502, 0.5464356849270483, 9.79739623685037, 12.85442683004564, 0.25376852481595935, 0.5620865547849286, 49.02892112731934, 65.46213026969664, 63.687018502143125, 44.80097086198869, 39.19939871757261, 22.08444437673015, 40.256799113365915, 65.7927978423334, 71.7674187690981, 37.539985102991906, 1.0770132272474229, 0.054306850633433754, 0.0632760203593681, 0.0035574149824829115, 0.03983959044900633, 0.018895788478755185, 0.08826740191227968, 0.022302531682315375, 0.03974497092947845, 0.15721601223753345, 0.18785514718582555, 0.119881835736094, 0.13715091311643202, 0.13306686774857585, 0.12303770429665044, 0.1264779983208545, 0.1660261612625853, 0.14680012760143127, 1.0145993086118852, 53.465541485817205, 78.71414030751875, 69.33598856772147, 60.813745067965606, 40.03821326840309, 43.43852773789437, 45.924184706903276, 58.07657787876745, 69.8225821218183, 68.05788424707228, 13.101495946607283, 1.1095415656605074, 4.333319346750937, 15.754856794111191, 9.123310446739197, 0.36393739222999544, 43.83765635951873, 49.103175517051454, 41.849995274697584, 65.32638096040296, 58.13430732296359, 59.05065536499024, 59.6090792840527, 56.26114414584253, 54.888596996184326, 51.65006852919056, 54.94094102613388, 62.679655782638065, 61.99298997079173, 61.86984715923187, 56.79699090219314, 50.869712983408284, 47.02456251267464, 44.41384861546178, 43.47078923256167, 42.16381234507407, 41.510345474366225, 45.91471218293714, 46.17166273055538, 46.84120347422939, 47.06454715421123, 51.23195563593219, 47.40923720021402, 50.79124204574093, 48.245816000046275, 46.268215794717115, 46.36583574356572, 42.686181837512606, 45.45084091924852, 45.7814065102608, 42.880284247859834, 41.54233632549163, 42.86550475705055, 45.148430101333126, 43.84414003741357, 43.024851045300885, 43.47587262430499, 44.35257727100004, 44.32768198751634, 46.77123231272544, 42.684150049763346, 45.64012665902415, 46.47203391598117, 44.31686801295127, 44.177008059717, 45.56151059366042, 44.716275122857866, 42.80333518981934, 40.93483178846298, 43.841268862447436, 45.9172107327369, 43.49505693681779, 51.07957547710788, 54.60838679344424, 55.70763887897615, 58.785958136281664, 60.4004253110578, 58.804444266903786, 54.495775545797045, 47.69517014103551, 57.72956971199282, 56.79405696930424, 62.112881137478745, 58.590082814616544, 59.826386436339355, 50.15115437969085, 47.70329336966238, 44.88965172921458, 47.29070317360663, 47.500263644802956, 44.387419685240715, 44.53192764712919, 45.07292055314587, 45.6912665213308, 46.57823208839663, 45.1546117567247, 47.296096432593565, 44.26806980563749, 45.075477938498224, 45.79793930053712, 46.822866393673806, 45.14539418681976, 43.282001633797925, 42.84657539859895, 43.297189051105136, 41.93051368959489, 44.791208082629794, 46.5667748451233, 42.86969384839458, 43.092080470054384, 46.35613179975941, 48.759807309796734, 45.26316727361372, 46.46821744980351, 45.23968404339206, 45.095427113194624, 45.41280961805775, 46.50222439919749, 45.45089191006076, 45.43787748582902, 46.982071476597945, 44.79050990073912, 46.79182867850027, 45.25472633300289, 49.09290675194033, 57.60320663452149, 61.95604124376851, 64.850460175545, 62.7128037329643, 62.33513439855268, 67.07826445179602, 64.26775678511589, 64.9023570552949, 65.03609026632002, 65.50977530017977, 67.04294743076449, 70.68443667504096, 64.6648810755822, 60.335078623987016, 46.119938435093054, 53.42104611858245, 16.841066998820153, 2.274742299510587, 10.617759958390268, 11.138847816374994, 0.1826021282543098, 0.8748501010479466, 53.19319171290244, 71.39159294866747, 70.22476626980689, 61.224044599840724, 51.117375358458496, 25.116534579184748, 47.78077587004631, 78.52339544603902, 81.1205614766767, 45.20762258960355, 1.439036472189811, 0.1621294090704572, 0.17680642795899223, 0.1444021498243655, 0.1653055636392486, 0.09497374326231019, 0.14099627613059937, 0.14997835060761822, 0.14138356421984014], [0.0905039726245788, 0.057580298368608764, 0.035669892620775974, 0.05618852728437032, 0.06205311037539955, 0.018507900925713684, 0.05573755047554451, 0.05893394125685577, 0.04696728781827035, 0.3809162908263745, 38.49749057523666, 58.36861402757707, 50.8960360096347, 47.77967760639806, 17.667598647456018, 19.58780477123876, 39.62330102920532, 51.85747169679212, 58.635986312743164, 63.15717689452633, 6.483865188014123, 0.1983380338717853, 0.9546092308817372, 9.286259431992809, 4.664290412779778, 1.6562156571495918, 55.52545262921242, 53.33763691686815, 61.73878115992393, 57.71537465433921, 60.97627239842569, 57.49023060644827, 62.15177143773725, 57.512097820158935, 56.630956972799, 53.88619999731741, 59.004316483774495, 57.613345961416925, 58.203776421085486, 52.56929559092368, 46.775621444948264, 38.211945949062226, 40.189907012447236, 39.00042864584154, 40.55551505857899, 39.83510117377005, 39.64048493293024, 37.583523411904615, 43.21996542715257, 39.52833260259321, 41.00972552453318, 39.90049100691273, 42.88459885504938, 42.391415719063055, 43.14958633915071, 41.54331691803471, 40.171687602996826, 37.67514605675974, 39.7501112568763, 39.55288271750174, 40.71370816999867, 39.958946089590754, 40.71791687319356, 39.18733350692257, 39.76053691679432, 40.91135640298167, 40.45507100320632, 40.484877094145745, 39.366283801294145, 40.16522745932303, 39.619782663160755, 40.02270813911192, 40.07467562152494, 40.6744844682755, 41.336486416478316, 40.029474227659165, 40.171173772504254, 39.699598973797215, 41.507623349466634, 40.88171897395965, 43.95151099851055, 41.75345790001654, 45.08695479362242, 51.72634686193159, 54.40189753809283, 53.06524007551132, 54.683900264001664, 51.90596003686228, 33.218160752327215, 41.13805370946085, 51.210766992261334, 51.877656213698856, 54.645676766672445, 52.55962694844892, 52.982670261013894, 41.98198695336619, 40.087556685170824, 42.080936585703206, 41.209978211310606, 40.20480417436169, 41.93111773460142, 39.95924026735368, 41.75563481546218, 39.732009518531065, 40.52592077562886, 39.16150469933787, 42.51684527243338, 40.302722223343395, 42.12114480233962, 41.813607446609005, 41.67794050708894, 42.647891659890455, 42.387171714536606, 40.326523165549006, 42.545713916901626, 43.77082701652281, 39.83174754727272, 39.36640931713966, 42.190833553191155, 40.6243997235452, 39.71754381733556, 39.58104533533896, 40.75424586572955, 37.69283594623689, 39.35221425948605, 38.495631371774984, 38.064633492500555, 39.197876837945756, 39.67238949191186, 39.02565340841971, 39.29848171049549, 40.84808464973204, 41.89149395112069, 41.892423552851525, 47.21201258320963, 56.257178629598315, 58.11895908847932, 55.92203955496512, 53.94414124950286, 59.96564626693726, 57.7713272648473, 60.42062551744523, 59.67461032252158, 61.219427970147905, 60.34861864582185, 56.18879602801416, 61.99073068557247, 51.19736817575271, 38.44826875194427, 51.20185928960001, 58.71566926279376, 28.134880796555553, 1.0955306142568588, 7.392355741993074, 16.6537542112412, 0.2378739011023314, 0.02827145594863161, 38.48849265806137, 66.3215764876335, 56.46053783355221, 49.53032162881667, 52.75955800087222, 23.46231810508236, 29.217405934487623, 46.697887912873306, 57.888402169750584, 47.09441992544359, 2.105083119484686, 0.11179640588741149, 0.04066397766432455, 0.04854106990199897, 0.08996621720613011, 0.03770717705089239, 0.1176745678868986, 0.0394566192652189, 0.05774015793576837, 0.017661775965544007, 0.0830267476398618, 0.1349408107419168, 0.1422346112949233, 0.01886062887347033, 0.026563198621114417, 0.07454852152976298, 0.0650680915362412, 0.024063275608744834, 0.7349463888714391, 47.08214290680424, 65.24535655975342, 58.596566492511386, 54.2903688646132, 22.14813582358822, 31.37392701641206, 40.96057038153372, 56.15196497209611, 63.45606150165681, 67.3703476690477, 6.992744178541246, 0.354831426013862, 0.905794476068789, 16.450360686548297, 1.8381367792044918, 1.641097616764807, 57.76423169720558, 54.8738645738171, 63.974928317531464, 58.86339356822353, 61.481893370228434, 59.42725781471499, 65.97086952578637, 58.89481175330378, 57.280905477462284, 56.193640155176965, 59.83505487442017, 59.51435012202109, 58.71943081578901, 55.900262555768414, 49.59988878619287, 41.424806425648356, 42.017684444304436, 39.74082700667843, 40.799804195281, 40.71945836467128, 41.500437567310954, 40.25452806103615, 45.27757021688646, 42.97995951867873, 43.23281903420725, 43.023760626392985, 45.70305716606879, 44.37733919389787, 45.48782494760329, 43.415232781440984, 43.062858812270626, 41.11533534142279, 42.47204788269536, 40.079484447356194, 42.30381742600472, 41.011321929193315, 41.716497405882805, 41.36233875828405, 42.88164531030963, 42.06313294749106, 42.91323215730729, 42.09793221565985, 42.64297693006454, 40.90848130564536, 43.60476955290764, 40.82815900925667, 43.12473027936874, 43.388395924722, 42.35282744130781, 42.7374864393665, 42.159097656126946, 42.14220008542461, 42.92737622414866, 42.236219298455026, 43.94204239691458, 44.015861403557565, 47.40016475800545, 53.56142382467947, 56.55216832314768, 55.6831632891009, 57.176178193861446, 52.01933222432291, 33.99495478599302, 45.18021306683941, 53.80601890625493, 55.579816679800714, 57.28943271021689, 55.32634527452531, 54.95525375489266, 43.711410953152566, 43.4698360966098, 43.412522423651914, 42.813321544278054, 41.88801088640767, 44.06669924336095, 42.183753675030125, 43.649331600435325, 42.47068682024556, 42.42486961426274, 40.73777191100582, 42.56743992528608, 42.36152333597983, 43.10758559934555, 43.45941435906195, 43.674470070869695, 44.831981120571015, 43.36670914003926, 44.88623142242432, 44.479324740748254, 45.425423960531916, 42.318589072073664, 41.31729425922517, 43.390537538836085, 42.242232291929184, 42.81722822496968, 42.58998963140672, 42.170472529626664, 41.2908378724129, 43.31699702047533, 40.925084698584776, 40.95134496688843, 41.386637841501546, 41.994079620607444, 42.09513164335682, 41.705244125858435, 42.013864055756606, 44.626637197309925, 44.31016075995661, 48.87256368514031, 58.45085436298002, 60.94048469297348, 57.72247022198093, 56.98835157578992, 61.81425148440946, 59.4148592026003, 61.547855869416274, 61.51914804212509, 63.557764637854795, 61.63433236460532, 58.69226055760538, 63.722410048207934, 52.81637745518839, 41.16948758402179, 52.106981508193485, 60.210923840922696, 31.365927342445623, 1.0614486495333335, 8.302771199134089, 15.728198405235046, 0.3254268264337894, 0.08996166664385989, 41.25430491662795, 72.19584357353949, 61.89855890889322, 51.04083814928609, 48.6250150588251, 25.216311831628126, 33.37831897120322, 57.088752485090694, 65.9223968751969, 58.216547658366544, 2.954466496744464, 0.06556096952408552, 0.05723532514586564, 0.022918571710526463, 0.09014397258720092, 0.017362465413527626, 0.1762649570141108, 0.03587635331636956, 0.05141532071115029, 0.14897603181100663, 0.16947502781066204, 0.25489401522903676, 0.1591945415542972, 0.2467791522823034, 0.10735496518111999, 0.1155006401841679, 0.19264163389321298, 0.27328568721009844, 1.0846229931039195, 57.5983311283973, 72.39273871144941, 67.34162022990566, 63.81131841290382, 26.175682390889815, 28.767692465935987, 52.79445140592514, 64.37919524408156, 66.42067124766689, 73.8619016831921, 7.946998005913151, 0.42876102510959874, 2.5468319702532987, 18.472702387840517, 9.20937313187507, 2.8589871814174037, 60.68768009062737, 56.67873536386798, 66.55589888172766, 61.52821263959331, 66.13652690764397, 62.78619127888834, 69.48733714319044, 61.17935311409735, 59.5389747619629, 56.044150783169655, 62.10810369060886, 62.688159481171645, 62.20579816449074, 56.44848831238286, 51.83438462595786, 41.9474151826674, 44.49250390452724, 42.04553719489805, 44.81649168076054, 43.48343103162704, 43.905289788399976, 42.94005724691576, 48.34209842066611, 43.54429444959087, 46.08051469249111, 44.12594272244362, 46.924361644252656, 46.81117773056031, 48.7592464108621, 47.27084029105402, 45.372707305415986, 42.73199119875508, 44.64787683179302, 42.563831344727554, 44.37102417792044, 43.76723804781514, 43.20292665112404, 42.88253568833874, 44.438104552607385, 44.34811753611411, 45.18752044247043, 44.895111668494444, 45.88091311916229, 43.591300133735906, 44.19630612096479, 43.51251148408459, 44.51516735938288, 44.83235766810756, 45.59722769644953, 44.806168002467004, 45.7802023426179, 42.524537040341286, 46.099079270516675, 45.375417663205056, 47.46396995359852, 45.75108266645863, 50.48891359759916, 56.22829821801955, 58.98740714596164, 57.71393906685614, 59.17598685910625, 53.92822819371378, 39.52149198901269, 46.95528168832102, 54.55454834045903, 55.606202463949884, 58.40360941425447, 57.97257231127832, 57.554318212693744, 45.76422652890606, 44.03346892326109, 46.86744805305235, 45.82918097895961, 43.967565259625836, 46.11753402217742, 43.9671455660174, 48.091929651075795, 44.529401640738214, 45.221543081345104, 42.09086018223917, 45.43396296039705, 44.80190046371953, 45.529025523893296, 46.43213948895855, 44.68564533418225, 46.598338157899924, 46.22093162228985, 44.69537673457977, 46.19669921936528, 47.257143374412294, 42.97903776168824, 43.49109926531392, 46.37288816513554, 44.78025682510869, 45.97696411994196, 45.16191128761538, 44.11519542817147, 43.07270396140314, 45.149198885886904, 43.3571542462995, 44.15022219381025, 44.62926126295521, 44.34799594263877, 44.45789291012672, 43.65720379737116, 45.04086302172753, 47.33840703964234, 47.554961096855905, 51.600846705898164, 60.79412537236368, 62.96316469869306, 60.26325610376174, 58.93192914224441, 64.70847037530714, 60.894722400173066, 64.07341118781798, 63.17749477201893, 65.22869825363159, 63.49051167888027, 60.282828730921594, 65.04184046099263, 54.88401566782306, 45.21935832115912, 53.89876727134951, 60.75786306012062, 35.08119244729319, 2.106298318793697, 14.256543747840391, 24.669531468422186, 0.6471809660715442, 0.22326975249715392, 46.95876475303404, 78.48088479811146, 69.03480545167001, 65.3959559625195, 60.99850439256238, 32.959719704043486, 41.91761693646831, 68.46747382994621, 76.366405640879, 68.52054349837765, 4.096922754280029, 0.2659284239334445, 0.1770973268656, 0.10823156128847793, 0.2182219838423114, 0.15328288619076053, 0.23960141404982538, 0.13162254686317137, 0.11405769825702715], [0.062103534282575694, 0.10147178530572884, 0.042561504674414476, 0.040463592045970505, 0.039932823349391265, 0.05895128548746148, 0.022007298633275975, 0.0990238969003962, 0.10038227038157564, 1.6148624761450676, 47.68463465475267, 59.592970109755, 52.264370533727835, 50.16668696557322, 23.704063584727628, 30.409478948962306, 45.655784760752034, 55.5147014125701, 59.360165672917525, 62.02895418290169, 6.823582649230958, 0.13035461006145324, 0.8635150028332588, 16.9428172034602, 1.801433935761452, 10.831155527022577, 26.95094866137351, 19.938388178425452, 64.5738075625512, 55.28780406521213, 58.4031230403531, 54.585860621544626, 63.20534360024237, 56.50421342542095, 59.514499172087646, 57.901004745114236, 59.887677392651966, 51.7562980805674, 50.783087438152684, 42.009035618074485, 40.38481350867979, 39.750444658340946, 40.163446703264796, 39.97203896122594, 40.582873590530895, 38.96108335064304, 40.13280122510849, 38.02784950502458, 41.625729837725245, 39.07708744848929, 41.145015916516705, 40.279846960498446, 40.537232891205825, 39.4030011084772, 41.71987848897135, 38.57040743674002, 40.56157512049521, 39.85677619134226, 40.21578681084418, 39.95340770290744, 40.40325257085985, 39.78533806339387, 39.18542723501883, 39.89295221144154, 41.04757247432586, 40.843256212049916, 40.46653609122, 41.17226854447396, 43.401771207009595, 41.70371440149123, 38.62608940370622, 40.42338217458418, 40.73845832578598, 38.92829233600248, 39.73945025474795, 39.01502378525273, 42.45319304927703, 40.29277901495657, 39.39061034110285, 39.24354891623221, 42.20148671057917, 41.66945249803605, 46.42289838483257, 54.38430178549982, 52.38987461213143, 56.26308179670765, 54.51952549719042, 56.14073522629277, 36.863890078759965, 44.98684021734422, 56.51085792049285, 52.936707927334695, 57.45856923441733, 51.74446036738735, 45.42839319475236, 40.55523264792658, 39.184309359519716, 38.965346967020345, 40.67829701208299, 40.143093524440644, 41.32781405602732, 39.52303740286058, 39.990548626069106, 38.92213813720211, 39.01738112972629, 40.0952249188577, 41.2057851975964, 39.533086515242054, 41.56638829938827, 41.07021631733064, 43.58408689498902, 41.15304893062961, 41.31504674111643, 41.88618698427754, 41.677560037182225, 39.82080413449196, 42.79276832457512, 41.92714045124669, 42.72014956320486, 39.89660393807196, 40.152719020843506, 38.47190887697282, 40.69432773897725, 38.9446956880631, 39.399412139769524, 39.01860098684988, 40.268173986865634, 39.5197190776948, 41.519829765442886, 39.98061326242263, 41.486940691548014, 39.858251002527055, 40.42823022411716, 42.696399611811486, 52.28219378379084, 54.23798561096192, 57.29571634723295, 51.38809342538157, 55.153470731550655, 57.94606493365381, 58.17408407888105, 60.44963144486951, 56.486299960843986, 56.91552100643035, 53.965588769605084, 57.668153239834695, 65.61527136833438, 60.859813305639456, 67.44626906610304, 66.86621327554026, 73.16095844391855, 47.25123236256261, 0.06471418955874059, 9.122630896106843, 20.518016430639452, 0.32772959480362557, 0.04366753262377555, 28.08884393784308, 66.46875166123914, 51.58398835889755, 54.31518177832327, 63.423607810851074, 30.61462675371478, 26.94782449353126, 39.24323120424825, 57.117887850730654, 46.711475003150206, 2.3411382206024665, 0.035092070803887425, 0.05560584463960221, 0.044136673377286044, 0.10057734701061442, 0.03267449266727894, 0.12041795172638471, 0.010379809555747818, 0.03057479505397139, 0.05169908733918302, 0.09972584794365591, 0.05533316713427344, 0.033389298665908076, 0.09209608719233545, 0.03767815380988102, 0.09200749678477164, 0.1597817326264997, 0.13490719480379937, 2.674941728191991, 55.03726659282562, 67.51845636675435, 60.893239744247936, 58.49847193687194, 29.414646240972704, 25.69440364837647, 39.49532977996334, 59.477970138672866, 62.401999042880156, 67.91958931953677, 7.189377007945892, 0.13136465102434158, 0.9232251826793918, 8.639849885817497, 1.797219594159434, 13.49400164619569, 30.197341480562766, 22.936059582617975, 68.42002884034189, 56.73480956785141, 61.52205059605261, 56.269694912818174, 63.60149514290595, 57.31763847412602, 60.727174435892415, 57.231377709296446, 60.55595905550065, 55.31031454763105, 52.86278301669706, 44.68255058411629, 42.238125570358775, 41.36767710408857, 42.27518804611699, 41.87385505245578, 43.248790925548924, 41.56666286530034, 41.108463348880896, 39.916368761370265, 43.713121106547696, 42.12967203509423, 45.13923606564922, 42.44738009668166, 42.416907202812936, 40.722349151488274, 43.25235636003556, 40.150491114585634, 43.21004183061662, 40.91088571856099, 41.78834346032912, 41.52048872363183, 42.24649590830649, 41.98483851648147, 40.37623528511294, 40.90441773014684, 41.96233195643271, 42.108961920584406, 41.840628654726096, 42.09191529981552, 43.86800765991212, 42.655308861886304, 41.30834733286212, 42.70194976560531, 42.188782153591035, 40.36283646860431, 42.067588760006814, 41.34303285229591, 44.00932673485049, 42.386520601088, 42.290967741320216, 41.85470996364471, 44.251638996985655, 44.28600680443549, 48.371402448223485, 56.35292760787472, 55.77968497430125, 56.221288942521625, 56.40729558083319, 56.92909240722657, 38.74622375734391, 46.73851582311815, 59.62543949004143, 55.5524738373295, 58.303259495765936, 55.83073069972377, 49.27814460569813, 41.39150158051522, 41.976252448174264, 40.799380579302394, 43.747406544223914, 41.334011400899584, 43.56831504452614, 41.52719989899666, 41.47685627783499, 41.205451796131754, 40.82608407543552, 43.01923421121413, 43.58318082747921, 41.8635666754938, 43.176458497201246, 42.999014392975845, 45.93029183726157, 42.63353186268961, 43.303162820877574, 42.43646021812193, 43.32149597906297, 41.25037077934512, 46.12013847597184, 44.189453740273755, 43.566432306843424, 42.06497646147206, 41.91851515923777, 40.67480610262963, 41.89227842515515, 42.07177000661051, 42.39095680175289, 41.50435209274292, 42.645306817946896, 41.308339488121774, 42.79489424920852, 41.338808459620324, 44.235718096456225, 41.689060426527455, 43.97655925443096, 44.575736599583784, 55.927605398239635, 57.94431163418678, 59.22006645510274, 54.05566207824215, 56.70432882924234, 59.06601144421486, 60.1205720440034, 60.733128593813994, 58.54086491369433, 56.8542222053774, 55.45384583934661, 58.703054920319595, 68.78976714226508, 64.94575415888141, 69.16958593553113, 69.41818575705253, 73.65178815780148, 49.70445525261664, 0.0819742807277268, 0.9048777446150781, 6.423616111278535, 0.7575050428990395, 0.07705566683603872, 31.83987125273674, 71.55761903332126, 57.963703832318714, 52.191241864235174, 54.43234689774052, 33.009055276070875, 33.786539646887014, 49.031345152085834, 64.19692270217404, 57.53791878300329, 3.373167990676819, 0.05112260234572234, 0.05910389786285739, 0.013772877132249697, 0.14445876372196984, 0.04139541543178982, 0.026134417294674826, 0.02631781299808814, 0.042287498006537076, 0.18457915603874192, 0.2706261363721663, 0.1515625591479963, 0.18328017735433194, 0.19102659797476185, 0.08568882656794402, 0.2555011858743045, 0.2987068440885313, 0.3572136530232045, 3.8798847746464515, 65.20980811888172, 74.14360630896785, 68.37904007204118, 63.680848613862075, 34.563470963508856, 41.312136342448575, 54.3443367558141, 66.00858703736337, 67.19033441235943, 72.69521620965773, 9.053770745954207, 0.3093175295620196, 2.853653738575597, 31.556572183485958, 4.929765741671286, 14.822807504284768, 32.49944133143271, 23.82278588510329, 70.59954089503135, 58.57851182260821, 64.84377645677137, 57.667082432777654, 66.91692952186831, 59.893372674142164, 62.009173670122706, 60.29856135768276, 65.59008190708776, 54.72500278103737, 56.78688687662925, 47.18455599200341, 44.79278095306889, 45.0460680069462, 44.127076287423414, 43.486651297538515, 44.39211476233698, 44.58580532381612, 44.87497814239995, 43.246417891594675, 47.21243619918824, 43.51727324147379, 48.8588353895372, 45.23934671955724, 44.542918128352014, 42.656093335920765, 46.01896485974712, 42.52884772516067, 44.86918087928526, 43.575971511102495, 44.36189290015928, 43.158898045939786, 44.26441023426671, 42.99512340176491, 42.75705514415618, 43.967408364818944, 44.30196300629647, 44.54040388907156, 42.68702906946982, 44.9424546764743, 46.91430076476067, 45.57032415943761, 42.35265093465006, 46.321250161817, 45.77431878735943, 42.64547547986431, 44.70479826773367, 44.6683672935732, 49.483111981422674, 45.24990966243129, 43.905219185736875, 43.764092306936945, 46.872554979016705, 45.79584867723527, 49.86479782289075, 58.876105969952, 57.54053108153805, 59.878569649111846, 58.60561540049892, 59.71022544368621, 42.8003659555989, 50.41847175167453, 60.0695380856914, 57.48527273055046, 61.229908543248335, 57.84550712954614, 49.33382657266433, 44.31826829910279, 42.18230239806637, 43.110766641555294, 45.3048110777332, 44.52425941344231, 46.200268576222086, 44.130959433894006, 42.95019265144102, 44.11184572404431, 43.574653594724595, 44.37800991919733, 45.24122161249961, 44.883219042131984, 45.47757579434303, 44.990633149300855, 48.7494130288401, 45.59638438686248, 46.36345878724129, 45.64233495343117, 45.550559336139315, 43.71696110694639, 47.5714821200217, 46.16760699979721, 46.13946791618101, 44.308493752633375, 43.84826637083485, 42.66850763751615, 45.03637190788023, 43.858221346332186, 45.47967034001505, 44.97702252480292, 46.03225384989093, 44.79282409914079, 47.49866724014283, 43.3957346793144, 47.61365936648461, 45.61387815783101, 46.973246143710234, 48.33124914476949, 60.68260062125422, 59.20265505390783, 61.42999649047852, 57.75036219627627, 59.33040272804999, 61.521811331472094, 62.60255767453102, 63.57529763252505, 59.293450078656605, 57.452838651595584, 57.04096232691119, 63.812546114767756, 70.05957957236998, 67.0769779143795, 69.07553534353934, 72.25104701134467, 75.23582166241061, 54.72504200473909, 0.22985740384507566, 15.262461073936956, 33.735803788708104, 1.778991727098342, 0.20888706458912742, 34.30490047700944, 76.92776741520052, 65.8385601351338, 67.52477138273179, 69.67764269921088, 45.113093468450735, 41.48938825053554, 58.32518162265901, 74.0029187356272, 69.11631230385073, 6.115162391816416, 0.17592495187155663, 0.2312774703867974, 0.10602744206065133, 0.41363924621574344, 0.13831927380975217, 0.20779846897048337, 0.1412573129299187, 0.18837777236776967], [0.04095273918562359, 0.09101233324937283, 0.02668363147325093, 0.04830978412721907, 0.03557608515444783, 0.2215769739761468, 0.03220845456986177, 0.1853402490697561, 0.11313681460676656, 4.031598620837735, 54.52444807175667, 58.528321173883256, 52.41115739268642, 30.863163817313414, 17.570539597542055, 48.713397825917895, 40.40652382758356, 54.51793301490046, 58.216896749311886, 60.848901271820075, 6.419414272231441, 0.3314340282832423, 0.970146842300892, 11.747851679402014, 0.6771060764308899, 23.350002996383175, 33.024277994709635, 28.35721250503294, 67.08921570931712, 54.84616479566021, 57.28360014577066, 50.73105327544674, 55.85857168320687, 53.72102114462084, 56.30638868578019, 52.8353185807505, 50.43742072197699, 43.174446321302845, 40.5262698665742, 40.653080094245176, 40.516875790011504, 39.835269835687455, 42.04721596933181, 38.86827614999587, 39.47891073842203, 39.39451702179448, 39.68545098458567, 38.7360530514871, 39.55999789699432, 40.83622340233096, 41.1604465207746, 41.049490513340125, 40.58525839159566, 39.53222359380415, 40.34259311614498, 38.262328793925626, 38.7785009414919, 39.81579919015208, 38.86434593508321, 38.52127190559141, 39.11758592051845, 38.10899549914945, 39.37221442499469, 41.13031095074069, 39.99120758425805, 39.61812742294804, 41.173966930758574, 40.17957548941336, 40.27866632707658, 39.57511471163842, 40.84715112563103, 42.003583523534964, 40.52030786391228, 40.91208204146355, 40.8668492686364, 40.075401260006814, 41.99253420675955, 38.92919448114211, 39.72560428803967, 42.24293439619003, 40.60604303113876, 40.97617749244937, 42.78995598516157, 53.218855780939904, 52.44685488362467, 56.33876392918249, 52.569319125144716, 58.47231365019276, 51.80926184500418, 49.04712484728906, 57.792539442739184, 51.774117408260224, 52.530758303980676, 42.91242022668162, 40.978091609093454, 40.914839467694684, 40.41652587152297, 39.85492091025076, 41.051557602420935, 40.85449772496378, 41.684671294304636, 43.17099855792138, 44.232666492462165, 42.9592925502408, 40.11719803656302, 39.10417925926947, 40.384111404418945, 40.914639426815896, 40.94822276023127, 42.20531886623752, 42.47140069161692, 41.3452019230012, 40.57898259931996, 39.74788335061843, 40.042021889840406, 41.18469461317986, 40.455369103339414, 42.27727474704866, 40.78108664481871, 41.959939310627604, 39.77280216832315, 39.40905724802325, 39.29776783912413, 40.60891028373472, 38.376018693370206, 39.64257555623209, 38.50873601052069, 39.916725697055945, 38.93802373639999, 43.40356765254852, 39.67439774544009, 41.93834274045883, 37.78473707937425, 46.49198309067757, 51.02897297951483, 58.67488053537185, 55.034952394423954, 48.60224177760463, 52.93214228845412, 53.6588554997598, 51.530491152117335, 55.31911242392756, 55.793629000263834, 60.441480759651434, 61.23697665429885, 60.765394010851466, 60.72433463988766, 65.31585331886046, 59.23586576215683, 67.24896600169521, 65.36721283389677, 70.04864400432956, 1.554404533197803, 3.7391959755651416, 7.542433959822501, 0.5967198576658004, 0.02405735949474958, 19.56346450313445, 65.6191349029541, 52.92098706768405, 62.45288787349578, 67.13578208800286, 44.076140388365715, 31.909408992336644, 47.19257331663563, 57.32929575827814, 53.31868010182535, 3.396090812260105, 0.04856353926081811, 0.009999783980029245, 0.03153061997445841, 0.0428851270267079, 0.027825975820662516, 0.0409821646227952, 0.048515620461154374, 0.043464580610875166, 0.03875975504577641, 0.08215401261564224, 0.06416917545720935, 0.11451350525021554, 0.0027630179547779867, 0.05106077905023291, 0.09823836566459748, 0.16598678434327727, 0.16179075224264977, 5.500316648714004, 63.46615376011018, 65.41917639393961, 60.08621992603425, 40.72671867186024, 27.75307140042705, 43.14252607284054, 41.006611162616366, 59.38110328489735, 62.98053295381608, 65.15297297508486, 6.699976017398219, 0.25821070096665816, 1.3007349256546268, 5.6675459204181555, 0.5069055480341758, 26.30143357861427, 36.63254868599677, 32.53964562569895, 69.1984938037011, 54.587182460292695, 61.40543853082965, 52.671975397294574, 57.31710503178259, 55.486825127755445, 59.37338406039823, 56.27724547539988, 53.44034025746008, 45.412393846819484, 42.98271694490987, 40.91409813973212, 41.90420243047899, 41.68218843398556, 44.55503040744413, 40.05028632379348, 42.346559493772446, 41.56277579645957, 42.49619399347613, 41.85051302756033, 42.61159796868601, 42.702428294766335, 43.27564739411877, 42.16741308089226, 42.06760837185768, 42.86439080392161, 43.70352306673604, 39.475694394880726, 41.630460216153054, 41.54439164746193, 41.47943719740837, 38.92927685091573, 41.00182587100614, 39.05169402399371, 40.58280691023796, 42.70800982752154, 41.97706437879994, 42.34534355901903, 42.42439108510172, 41.56465853414228, 42.41482834662161, 41.65036624477756, 43.11726208656065, 42.96952993639054, 43.06932287831461, 43.06431008923439, 42.200937578755045, 41.610558109898726, 43.05454338750532, 43.121866949142955, 40.692072376128166, 42.95477790217246, 42.197160336279104, 43.657180263150124, 44.96548683412614, 54.78312446225075, 55.07154810813166, 56.139491834948146, 53.814703033816436, 59.62723593558035, 55.03324616339899, 50.221819800715295, 59.170401403980875, 53.88000265244515, 55.49861577249343, 45.89324897335422, 43.1963998271573, 43.134740168048495, 43.3003387143535, 41.98485812833233, 44.29083916448778, 43.23438405990601, 44.32481473492038, 43.66006320522678, 46.59034436748874, 44.820127717910275, 41.93212970610588, 41.49724868036086, 41.86950122156451, 42.72645281207177, 45.02967249962592, 44.052429660674065, 43.97291929491105, 43.25959705537365, 42.064945082510675, 42.72225587598739, 42.77124627943962, 42.93055334398824, 42.72817865494759, 42.69719585295647, 42.180721682886926, 42.60106640477335, 41.13107973529447, 41.09011057884463, 42.56180740171864, 43.633481302568995, 41.33594120702436, 42.242444099918494, 41.02867057246547, 43.27430202114967, 39.91123830118487, 44.12760972976685, 42.47742937457177, 45.06935119628907, 40.33315197114022, 47.88204754552534, 55.35033449049919, 60.485889834742395, 57.1140556950723, 51.91094144698113, 53.14952788814422, 55.22070407867432, 53.07935276339131, 57.52173900604249, 55.27715483019429, 60.2496180226726, 62.428424050731046, 62.27766383078791, 62.386721411058986, 66.57946448172292, 60.49349531050652, 70.38909789054625, 68.75008060086158, 71.47891275344357, 2.1636698467116204, 1.8256331211136234, 5.6330648545295965, 0.11105714636223932, 0.04751255855925622, 22.7889177491588, 71.28352380567982, 57.57314951189103, 65.70895325752997, 63.21850707454067, 45.07777252504903, 41.69124518671344, 54.948115041179044, 64.87091533599362, 62.535481222214244, 5.186062234063303, 0.051936735474174066, 0.03970881924033165, 0.03859067178000847, 0.06362608806680768, 0.0988434755333489, 0.014438874711613021, 0.052229614718066114, 0.05346826014799937, 0.17303957363530514, 0.19171670529871218, 0.1897884007062643, 0.13669622461161307, 0.1375052594249287, 0.19930845276722986, 0.22705408894727308, 0.36156564530345703, 0.32297197428922503, 6.874826944643452, 73.91184130022603, 73.44058421350294, 66.92314255622126, 43.816220606527025, 28.15369248390198, 60.8375342430607, 53.318691868935865, 64.99309716686126, 67.38346407490393, 69.78576675538095, 8.068661593621778, 0.5432821605955401, 2.383581452792691, 26.930854358980735, 2.359405924235621, 28.636942217426917, 39.64653322773595, 35.26601452981272, 71.55794851241573, 57.493219452519575, 62.088644812184, 55.68595601666359, 60.64232572432488, 57.88950827813918, 61.80191563021753, 59.42482202283798, 54.639597092905355, 46.36747137192757, 43.14108264061713, 42.78720640367077, 44.73367867931243, 45.02343200868176, 47.83416325046171, 43.035276705218905, 44.17837304453696, 43.738369403346894, 44.89164821563229, 44.53902321477091, 43.51516300632108, 44.94842844624674, 45.289003925938765, 45.03095511467227, 44.34688198950983, 44.909871547452866, 46.07514104535503, 41.935408807569935, 44.147574593943936, 45.85014212516047, 43.78728135939568, 41.00699163252308, 41.90799144006545, 40.91518071389968, 43.49461763135849, 46.92679351375949, 43.95774756708453, 44.472652789085146, 45.08619777617916, 43.61915680669969, 44.81618965825727, 43.28067195030951, 46.1650731486659, 45.2841951001075, 45.497932895537346, 43.86065321583902, 44.64231883325885, 44.388306140899665, 47.15522450785483, 44.45341356338994, 43.79305116591915, 46.40416122251942, 46.254899347982104, 44.84331284799884, 47.740622566592315, 58.51405551356655, 57.24571789464643, 58.84579389326034, 57.72378029361848, 63.11665096590596, 58.69508858649962, 55.113360574168546, 61.82561459079866, 55.588069346643266, 57.20506252781038, 46.79868498156148, 44.687379021798414, 46.27474261868385, 45.025161773927756, 43.896464455512266, 46.35788509922643, 45.60418990350539, 45.99673286561043, 47.18228493967364, 49.54821155917261, 47.091003541023504, 44.928428280738096, 44.02415721647201, 42.86934083507907, 46.198060281815074, 46.22480692402009, 46.00615047639417, 47.29703780143492, 44.814632477298865, 44.86294431071128, 44.91932445956815, 43.432538278641246, 44.25059564651982, 45.68543787925474, 45.33759817000359, 46.00351464363837, 46.35750462931972, 44.26643025490546, 41.98728607546899, 44.302053220810436, 46.63740496481619, 44.83706451231434, 44.10775076958441, 44.129747421510764, 45.1529682836225, 43.30632425123646, 48.00723391194498, 44.80448530566308, 47.3858206502853, 42.74586069968439, 49.068925380706794, 56.311354406418346, 64.16729311789236, 60.652971036972545, 55.598855864617136, 55.32221109636369, 58.21941491096251, 55.73360496951688, 57.552768876475675, 55.33616296706661, 63.714118157663655, 64.89563411281955, 62.98110954223141, 64.27467584609985, 71.68022448016752, 63.67563186153289, 74.68552097197502, 69.5650000726023, 77.89468657585883, 2.6490369246852015, 8.049086514980562, 19.095559081723614, 0.8992452210476323, 0.10412634125039463, 26.34301462481099, 82.12926956915086, 66.56764245802357, 74.96207160334434, 70.3709137824274, 56.73134219261908, 44.34232027299943, 63.602977798831084, 73.03789015739196, 75.93960469768894, 8.41076679768101, 0.1843076698001354, 0.12477842459995901, 0.12646766379475594, 0.32242691805285795, 0.13135999320976197, 0.10585180874313078, 0.16847799502072797, 0.19425544407098524], [0.09648554883296452, 0.029989099768441052, 0.04118383726886204, 0.014909429854953722, 0.03693677222115859, 0.12065176942175436, 0.09964266611683754, 0.020872381508290287, 0.11971639138796639, 5.244889941907698, 53.54274942028908, 58.42782612769835, 50.487976151127974, 31.46974659735157, 14.890177153771925, 30.8106432807061, 37.81684560160483, 55.09230921345373, 56.70737651086623, 60.57604551315308, 5.218208018810519, 0.08797361485419736, 0.5925323597846494, 3.334826086798022, 0.11636113312335745, 30.148711935166393, 59.11751608694754, 59.96874101700322, 62.91201306927589, 57.78208632622996, 56.43188099707327, 45.15789478055893, 44.63930253059634, 43.246774827280355, 43.71044212772001, 41.08587049668835, 39.182779635152514, 39.51877378648327, 41.26451876855666, 39.88131453914028, 42.08846361406388, 41.484387228565836, 42.10296461659093, 40.40439398058, 40.85002230059716, 39.75650079788701, 39.22466662622268, 37.47488944761215, 39.30357294697916, 41.42936029741841, 39.455231389691754, 39.224564644598196, 40.084293273187455, 38.587446212768555, 38.03277992433117, 39.15063973396055, 40.92300584239345, 39.08939976846018, 39.120111926909416, 38.49134422117664, 38.42458940321399, 36.900791737341116, 39.194703640476355, 40.92758717075471, 38.354073032256096, 41.02147302319927, 41.191621518904164, 39.78036449801537, 41.40364523856871, 39.98790494857296, 41.490486514183786, 41.54660386423911, 40.570804457510675, 39.53320418634723, 38.269322379942864, 37.51490546811012, 36.51548947057417, 37.64839549218455, 37.50972793948266, 40.88242892296084, 39.268193168024865, 39.83390877323766, 37.707356560614805, 43.69927906220959, 48.18718048834032, 48.623650074005134, 49.4641512440097, 55.07603529960879, 46.826855444139056, 50.091534353071644, 54.66137016973188, 49.79454032836422, 46.59005803446616, 41.40066423723775, 41.88087609506423, 39.2060039889428, 42.39960955035302, 39.53817382935555, 41.64217633585776, 45.08988480414114, 44.636348985856586, 44.272584453705825, 46.465036407593765, 45.208544346594046, 43.082184330109634, 40.01104301021945, 39.83004131624776, 40.36600182133336, 40.34387573119133, 41.68440849550309, 41.45747584681357, 41.42157831499654, 42.29003813958938, 40.748213260404526, 40.85327002309984, 40.94786190217541, 38.75873219582343, 39.43222276626095, 41.27488559292209, 41.08633725873886, 42.092919426579634, 40.40041277485509, 39.571949358909364, 40.078197909939675, 38.852406240278675, 40.668251822071696, 38.72289349955898, 40.55592690744708, 39.3314217752026, 40.25541451669509, 40.19053851404498, 40.78003544961253, 42.411772820257376, 49.73280614422214, 55.268906085721916, 56.75266419687579, 45.47342984907089, 52.22834748606528, 54.364438902947214, 55.72316754248835, 55.83178581730012, 58.859726152112415, 59.011051193360366, 60.76230710552585, 60.67278292871291, 62.05896423709009, 57.62426583997665, 60.42848594727055, 60.35278812531502, 65.59028194796655, 60.89437330922773, 77.97383216119583, 9.010761957014761, 2.1830985719157807, 1.1640259839834706, 0.7549267586681151, 0.09098517543245709, 17.64892816543579, 64.31735515594482, 54.81433083934169, 46.77227566319127, 56.49942028907038, 56.634808740308216, 19.481575219861924, 42.97280119311425, 57.705305930106874, 60.675277556142504, 7.703255059257631, 0.10990619118655882, 0.044234813070825996, 0.022438640608602477, 0.0384363318763433, 0.05236517397626754, 0.06607106150758844, 0.04580450041459934, 0.08837605616258037, 0.045999523417483416, 0.02353314659558237, 0.04451753781928171, 0.02086044968886962, 0.03277773067595498, 0.1615251955245772, 0.07214610044273638, 0.11221448305032908, 0.16947036999608242, 6.715055079229417, 62.7844262123108, 66.72666318954961, 57.98603388570971, 42.97652744477795, 23.154741525650028, 29.867625082692793, 40.887057319764175, 58.838102125352435, 60.8467439682253, 63.284387203954886, 6.014269715355289, 0.14139471846001764, 0.7596471473093956, 4.379386603832245, 0.1449915778733069, 32.921143193398755, 61.98789481193789, 60.20359293107064, 64.7523577751652, 58.525810856972974, 59.54903956382506, 47.479690813249164, 47.312943012483665, 45.11927512384231, 46.334731348099254, 43.604730329205914, 41.07131850334906, 40.53446369786417, 42.89005487195907, 42.97519383891937, 43.53926597102996, 41.898236505446896, 43.2869359754747, 42.0669533360389, 41.66686765609249, 42.23908262868082, 41.929737060300766, 40.69346089516917, 41.401738966664965, 43.68011828391783, 41.716391501888154, 40.377066827589466, 41.38530815801313, 40.26213353680026, 40.56505818520823, 41.05370313890519, 43.259502918489524, 39.97099168838994, 41.858153804656, 41.55567630644768, 40.191636777693226, 38.065935719397764, 42.47359329654325, 42.58625161263251, 41.33484294337612, 43.848737055255526, 43.25257601276521, 41.29505834271831, 43.61550115769909, 40.67957962712934, 43.24307603220786, 43.05862265248453, 42.17574027276809, 42.00185375828897, 39.37999640741656, 39.9722154678837, 39.10293979029502, 40.30466771894886, 40.83872195213072, 43.310980104631, 41.280671088926255, 41.7453032924283, 41.573425031477406, 46.740249510734316, 49.60587040070565, 50.835874695931714, 52.786414469442065, 56.849856607375614, 48.81555987942604, 52.535288641529704, 57.68894964648832, 53.37527990341187, 48.164305225495376, 42.9033987752853, 44.171093125497144, 42.497296179494555, 42.57702619798722, 42.36257845355619, 43.857134849794456, 45.40535711473035, 46.82096796651041, 47.58592428699617, 49.00858363797588, 45.86430972622287, 44.38142630361742, 41.63504154451432, 41.81701990865892, 41.33810243298931, 42.641400137255275, 43.56388668860159, 44.43850855673514, 45.26599530250796, 43.39103567984797, 46.032936342300914, 44.472954811588416, 41.93753080983316, 41.19135479773245, 41.05945333357781, 43.409510043359575, 42.60377676256242, 43.58564015357725, 42.67508152992495, 41.97065522593837, 41.89523589226508, 41.21592452449184, 40.617139416356245, 41.23783880664457, 43.064961202682994, 40.98974104850523, 43.10594604861352, 42.72011818424348, 43.37018828238211, 45.48052149434244, 51.73876116352697, 55.96284004949755, 58.41640810812674, 49.03528713410901, 53.65169717419533, 55.59157202320715, 58.51351030411259, 58.930795577264604, 60.522430635267696, 60.25893757420202, 63.66502185021678, 61.28036983551518, 64.98903359136274, 59.69531259229107, 64.16025246343305, 61.14764467362435, 68.86857540376725, 60.87885249045588, 82.30699216165851, 9.618952908823568, 0.8081281329354932, 1.567004289357893, 0.6621262383076453, 0.018948640884651292, 17.70678900903271, 75.28858538596862, 60.818793158377375, 55.979647405685924, 58.83113991829657, 62.91979505169777, 29.154122414127475, 49.4639394360204, 66.01405482138357, 68.96177876380183, 12.319293945066391, 0.19081452951556255, 0.03559470875188708, 0.0027405734938163793, 0.0677083139758437, 0.07058933317180603, 0.05142246065060458, 0.08068408907180832, 0.039952703331026344, 0.24363725716548584, 0.1658462225309303, 0.23535086713250608, 0.1338924807045729, 0.20963780011140534, 0.2782454630059581, 0.15620928077447802, 0.21470046151549588, 0.44368647099021946, 9.382300626847053, 74.40069413954213, 71.87958286654565, 67.56016685116676, 45.499129218439904, 23.72425594637471, 39.91258367415398, 51.28461345549553, 65.67984534848121, 67.22136820516279, 70.43145948840727, 7.299049419741477, 0.17244318950801127, 2.6589134527790934, 7.790377764932572, 0.7410172985926752, 36.016269806892645, 63.59692165928503, 63.84493312528057, 66.91323464916599, 62.02957783975909, 61.51552769445605, 49.971403921804125, 48.86469933294481, 46.74342270820372, 47.457549033626435, 46.22438330804148, 43.13795258921962, 42.21097884639617, 46.04169499489569, 44.017516643770286, 45.34317578038862, 44.817342835087935, 46.022848006217714, 44.07858794735324, 44.34606221414382, 44.55105704645957, 44.01574765482257, 42.365280966604914, 43.654897443709835, 46.44919395446778, 43.110798020516675, 43.940057677607385, 44.95436299231745, 42.243958134805005, 43.772631306802076, 42.619615293318226, 47.147622954460886, 42.324860941979196, 43.887854852984034, 43.7565182101342, 41.543830748527284, 39.762396120256, 44.09081005281018, 44.53738366403888, 42.02307770329137, 45.63432155116912, 46.81779084667083, 41.74499734755486, 46.01246157000142, 43.82357505060012, 45.91062507321758, 45.5995418948512, 42.97653136714813, 44.32013926967498, 41.346684578926336, 41.35649834909747, 40.24522419898741, 42.08707509502288, 41.64425911441926, 46.57463919731879, 44.23130543001237, 43.993041053895034, 43.39487960261684, 48.81816041085028, 52.14208279886554, 52.86343020777549, 54.604719377333126, 60.33592977831441, 51.37389444535779, 56.2612186708758, 61.43477001497823, 55.48733895824802, 50.44592834288075, 44.730521171323716, 46.76591750114195, 44.382049960474816, 46.49213214074412, 43.792490266984515, 46.133505913519095, 48.65881804497012, 49.84615479746173, 48.71431566053822, 52.93311111388668, 49.27696789464643, 46.14252344254525, 45.01237092479583, 44.91542170124669, 43.67291681228146, 45.33734321594239, 45.52501686157719, 45.538364687273585, 48.0379343032837, 45.543820704183275, 47.148191698135875, 46.52450738414642, 45.82211679027927, 42.45180060786586, 42.066694459607525, 46.22310461536531, 45.73410664835284, 45.880167868829545, 43.641631987787065, 43.97505698665496, 43.428494314993586, 43.72610415181806, 45.97024509983678, 42.53099326164492, 45.77637803169989, 44.28491246315741, 45.72355547258931, 46.21502453281034, 45.798013825570386, 48.842275142669685, 55.511516447990175, 58.93067790615944, 62.076101072372936, 52.82562248168453, 56.100934936154275, 58.35705872504943, 61.28069146986931, 61.28368816068096, 63.975191116333015, 61.97996377944947, 66.40878646604477, 65.50857897727721, 68.63324888290899, 63.056595556197635, 66.15729978007656, 64.27529950295725, 71.29033304029896, 63.702743284163944, 83.46526807354343, 11.655032711644328, 2.8867092680546547, 4.599312918801462, 1.6141569398103224, 0.2418373948744228, 21.08856635708963, 80.63465825973019, 66.31741877525084, 63.67227823503556, 66.29634780268516, 65.55054441575082, 32.46895667045347, 60.69871371792209, 73.18839934564406, 82.63777348303026, 17.53203368956043, 0.23152778195517681, 0.19529428993982656, 0.12133737980958917, 0.1439465573357959, 0.2061827435729004, 0.1726852732920839, 0.13385105066962782, 0.22838302166952243], [0.028332721915156133, 0.040724165362095645, 0.1665221878717984, 0.01303591682846027, 0.041090152376601775, 0.059464836357942516, 0.053055599226706454, 0.04794706830814962, 0.1373257650242698, 8.614290741182144, 58.58110843166229, 52.5606506870639, 40.85177167769402, 20.19880610127603, 39.079962545825595, 50.193276712971354, 44.91402925983552, 52.46592936977264, 55.61248610096594, 57.204866409301765, 4.507111724345915, 0.1236675741271146, 0.5049691229097305, 2.2916638947302297, 0.1864323074058179, 41.936424701444565, 64.94574631414106, 59.89847960010652, 56.70605859448833, 55.43966647117369, 49.95417687200731, 46.86063881843321, 43.9622151467108, 44.39153817392165, 41.346260962947724, 41.639285549040764, 44.23685166143602, 43.11093922584288, 44.85593503521335, 43.945333265489154, 46.11090913895638, 45.46609501684866, 46.73359717092207, 43.908678716228856, 43.2536821211538, 40.92350398340533, 38.96967334132041, 39.1781198593878, 40.52795256337812, 40.06352824549521, 38.19018856171639, 40.026387322333555, 38.904075622558594, 39.01372548072569, 39.76855031905636, 38.66739980636105, 38.933630681806996, 38.64662693392846, 38.07103872299194, 39.129364798145915, 37.42272584669052, 36.93954867701377, 37.60645751030215, 40.14356420886132, 39.22058343887329, 38.647230978935, 39.953933300510535, 41.935334282536665, 38.3203092698128, 40.56895702115951, 40.961829462359034, 41.59235438992901, 41.28178896442537, 40.72647156253938, 37.67190225662724, 38.79228415027742, 38.304549186460434, 37.17444373715309, 38.995062843445815, 38.97691011428833, 38.5684972424661, 40.023465156555176, 39.39811383524249, 42.22642906250493, 40.754096815663004, 47.73961059508785, 51.2138185962554, 57.90832388785578, 51.99195015814997, 52.88443842241841, 56.05591004894626, 50.03981790234966, 47.94638618346184, 39.83850971344979, 42.46658402104532, 40.612346280005674, 42.33447467127154, 39.248440111837084, 43.04841272292599, 44.167829713513775, 44.82301850472727, 43.5914138824709, 47.63746030869023, 44.2011933941995, 43.71210913504324, 40.34458568019252, 39.355375689844934, 41.38797929210048, 40.816156556529386, 40.69090743218699, 41.03649570095924, 40.402848566732104, 42.77877723017047, 40.75663066679432, 41.10623544262302, 39.20002629680019, 39.87663907389487, 38.961997262893185, 41.201137188942205, 42.35173310002973, 39.063131655416186, 40.501468719974646, 40.59224805524273, 39.74024257352276, 39.13534249028852, 40.46513580506848, 39.348935158021995, 40.84988109527096, 39.53084684187366, 40.156417815916, 40.58508188493791, 39.79088429481753, 40.55558958361226, 49.66912646447459, 52.94462327034243, 50.346276606282885, 48.71249960314844, 55.74921992517287, 53.2430136588312, 60.74786493855139, 55.5116694204269, 60.000461224586736, 57.35568546479749, 60.24472290469755, 55.321665886909734, 59.88259007853847, 50.38766545634116, 54.22090761123165, 48.92003613133585, 65.94773538651006, 60.85126646103398, 84.1260305527718, 19.50150086033729, 0.6691563513971145, 1.870603708009566, 0.19525946358278876, 0.08706146460627356, 13.628113365942433, 67.87947916215467, 58.48293935098956, 55.131489769104995, 53.50157630059027, 34.02687503445533, 16.91996939720646, 49.43538065879576, 54.75849982230894, 55.957431101029925, 11.93452904301305, 0.07866220683940957, 0.061835158360941764, 0.027694425117524884, 0.06740596971564716, 0.019103273816947496, 0.03961952786231714, 0.05614450404180154, 0.03365898076745291, 0.053598184829517725, 0.055743855379161336, 0.10391580496704388, 0.04738448781051463, 0.05126386512852004, 0.04831127033779218, 0.06799539776458856, 0.15177395344982225, 0.28095891579024257, 10.653094630087576, 67.24461217080393, 58.56603868546025, 47.71861806992562, 29.457194151416903, 32.26133777249244, 44.14050648289342, 50.63310384750367, 55.86297258254021, 61.84644629878383, 63.17424312714608, 5.34172639731438, 0.2652451960790542, 0.6329657449837655, 1.8767438107921233, 0.3361063985334289, 43.274494217288115, 64.97260278271091, 61.39072964268347, 58.862150176878906, 58.33308127618606, 51.967658919672814, 47.80271368642008, 45.70463788124823, 45.54262045891055, 43.74706137564875, 42.02935741793725, 45.05114747631935, 42.513091564178474, 47.53814589592719, 47.38825251979213, 47.91766658906014, 47.16649739973007, 47.944436765486195, 45.38802808330905, 46.06881033989691, 42.355953570335146, 40.289570516155614, 41.26074544845089, 42.740330157741425, 41.01014914051179, 41.23375169692501, 40.16833005412933, 41.29050054857808, 41.28911202953708, 42.313258571009484, 39.33772110169934, 42.764182090759284, 42.33132500802317, 41.36480592912243, 41.19748938468195, 39.72247815901233, 37.58891667089155, 38.67118489357733, 42.37395724942608, 41.276638892389116, 41.02130436128186, 42.85048600166075, 43.205484036476385, 40.290276542786636, 42.202310408315356, 42.93450317075176, 42.47898263316001, 43.09659904049289, 42.92612106569352, 41.260788594522786, 40.090035623119725, 40.69295883178711, 38.87703088022048, 41.48864692257297, 40.18454905479185, 41.56431728793729, 41.64651447726835, 39.50179776837749, 44.94065430856521, 43.32637148518717, 49.53280448913575, 54.895304249178984, 59.22087054098807, 55.47326549406975, 55.800045997865745, 56.81048777795608, 54.66975227479012, 49.821773344470614, 43.99821858252249, 43.017986897499334, 41.6119780079011, 43.69870639616444, 41.78148323489774, 44.98695396607922, 45.84094024473622, 48.50448062342983, 45.04253395142094, 49.20380392382222, 46.10345663562898, 45.69808360069029, 42.6879822054217, 41.39152119236608, 43.828434867243615, 44.50204703115648, 42.05188358983686, 42.79562381006057, 44.02078790049399, 44.87791207528884, 43.417990207672126, 41.7079976297194, 40.27895658246933, 42.51583330092892, 40.395913816267445, 41.9981510408463, 44.92690247874106, 41.80922223675636, 42.51897119706677, 43.212312882946385, 40.723325821661184, 41.27418741103142, 42.62812291422198, 41.06308937072754, 42.13496331245669, 41.531400757451216, 41.77845516512471, 41.78757075340518, 41.83246228002733, 43.63597592999859, 51.01077710428546, 55.90648343486171, 52.668084406083636, 50.823374102192545, 57.21805341782109, 57.2845297475015, 60.867175594452895, 58.46589665259085, 62.08903312683106, 59.62718494476811, 63.27945286227811, 58.127611837079456, 62.10993543747933, 54.49527348241499, 55.23188283366542, 50.81336813588297, 68.56105373751733, 61.96289362445955, 84.79456716968168, 22.212835319580574, 1.1109424646823638, 2.7444904994580055, 0.3297507186089793, 0.12369010477296769, 14.79668059656697, 72.43983853247859, 64.33161689389136, 62.67392519981631, 60.49591933527301, 43.398754904347086, 20.30756558141401, 58.21205654451924, 62.74963086651218, 66.21053418805523, 15.269232065446916, 0.14694631249914247, 0.04279711501552694, 0.04682278065311332, 0.11637285426859895, 0.02540822914471069, 0.01759519526404479, 0.029309641066638213, 0.03901093229351025, 0.1797666836289629, 0.15100366736371673, 0.2770054730917177, 0.16324127844024092, 0.12721029410679496, 0.2083296130501455, 0.19758913696052569, 0.19323948890932147, 0.4664970453708403, 12.60480130872419, 80.79848781708749, 65.50221297048753, 57.849445189199145, 31.591442054317845, 51.72433468603319, 61.05801459281676, 58.142893391270796, 62.96956600681428, 65.68485813756143, 68.90896012706142, 6.626462465332401, 0.6092176934884441, 2.2241645618792507, 7.363098292581498, 0.4128928927163924, 46.38571039322884, 66.44215799147084, 67.08501877323275, 60.97757854769307, 59.90430431981241, 56.02293860527777, 51.21065324352634, 48.761172294616706, 48.900518417358406, 45.50915871897052, 46.78496845306889, 48.13501296504852, 46.55889088107694, 51.01201657325991, 49.98355542459796, 52.46585092236919, 50.06932589315599, 51.067890736364554, 48.61861375070388, 48.23639446689237, 44.622412804634344, 41.98083377653553, 44.70383728704145, 46.463130135690015, 44.259483737330285, 43.70749250535042, 44.102082944685414, 43.95559418585993, 42.85747958767799, 43.96756918199601, 42.63308079011979, 44.99133917593187, 45.665959388979026, 42.33201926754367, 43.191983238343276, 41.572001211104855, 39.931058037665586, 41.31436817107662, 45.520486524028165, 42.98674914144701, 41.200423317570845, 44.250015135734316, 46.92907633319978, 41.320243881594756, 44.38186953144689, 44.92323898500012, 45.7992729063957, 44.633677851769235, 45.280574752438454, 43.7195106475584, 43.04241934130269, 43.17479148987801, 40.933451114162324, 43.526816368103034, 42.106129969319994, 43.085643860601614, 43.863751888275154, 41.70171791507352, 47.82165481198219, 44.83176539021154, 53.088189863389545, 56.0909289698447, 64.59269769730108, 58.864079983003684, 59.58704340842463, 60.24589569337907, 57.47605908301569, 52.81767575971542, 44.83515039567025, 46.55700814339423, 43.888286313702984, 47.65420490695585, 43.11521068696053, 46.855473056916274, 49.47995839580413, 51.446842685822524, 47.96052632793304, 52.87143968766736, 48.9625899253353, 47.147501360985544, 46.099451895683046, 44.14603702483639, 45.6668262327871, 44.44087766831921, 44.07009601593018, 44.755443911398615, 44.39134597778321, 47.656436735583895, 46.115619905533336, 43.490691338816, 41.898664043795684, 45.279594159895375, 42.610272207567775, 44.661381552296305, 47.07742037311677, 42.449623692420225, 44.26212741482643, 44.36417571959957, 43.38949811074042, 44.16211089780254, 45.24619125550794, 44.860383002988755, 44.6216675543016, 43.434840709932395, 45.43281762830673, 45.380195110074936, 43.841500282287605, 45.86782809226744, 55.786517743141424, 57.46712784613333, 54.54833530610608, 54.505255914503536, 58.87456840084445, 57.95616503684752, 64.13246639313238, 61.79836588521158, 65.57720868818222, 62.479501155114946, 66.8370073072372, 61.82433982049266, 65.51885558712867, 56.79146428262034, 57.91656478758782, 55.23299286442419, 71.86434838079637, 64.8520016670227, 87.30256988156228, 24.796027906479377, 1.9466784452238393, 9.118595757792074, 0.5009198272901197, 0.20554728896146823, 16.880249515656505, 81.48764041162308, 70.10528302961781, 72.07557585931593, 66.77242155997985, 43.27057576948597, 27.80296002664874, 69.05524884500812, 69.6632319111978, 79.3047708080661, 20.08840314803585, 0.2911650761961937, 0.10179839157048734, 0.1507160166699079, 0.23097483501318963, 0.12320848061673104, 0.15424929078548186, 0.1695706968706462, 0.10070613405156521], [0.02207529659743511, 0.010998367140400074, 0.04706111826723622, 0.054905877764066385, 0.047662478135598284, 0.062351543756742636, 0.014538317712234154, 0.12904064669724435, 0.24719069471522687, 10.777826001567226, 63.41098170126639, 52.487349433283654, 49.26404368492865, 23.480598311270438, 56.668097895960656, 77.28165934162756, 45.06217325887373, 49.45299210086946, 58.31006480801491, 55.68941554715557, 3.980692629852603, 0.31325362802993867, 0.5812651063165357, 3.449556149782673, 0.8687987418905382, 59.2567406162139, 63.70182544954362, 59.36314667424848, 58.753563281028505, 49.26099600330476, 46.783415194480654, 47.115212409727036, 48.67872015122445, 48.21883401563091, 49.12862385472944, 49.34113394829535, 47.82356500625611, 48.147046796737186, 49.069443133569536, 47.453461923906886, 47.8271225960024, 48.947912416150494, 49.032412036772705, 46.43157074528356, 45.758939173913774, 44.174587957320675, 41.39142705548195, 38.93179893493652, 39.1305571986783, 39.433015085035755, 38.15706022324101, 38.679131615546446, 37.57670241017496, 37.84419628881639, 39.87667437522642, 38.72596079303373, 38.52324093541792, 38.53152105885167, 39.58659156676262, 36.82196778635825, 37.73192628737419, 37.05903191720286, 39.52684994666807, 38.630945297979544, 39.95041493446597, 38.34835421654486, 40.28800549045686, 41.14285469055176, 40.2103151044538, 40.209679680485884, 40.10014749342396, 39.47960499794253, 40.54002561876851, 40.004374980926514, 37.83501794261318, 38.55708314526466, 38.79923459022276, 38.33135466421805, 37.40815424150036, 39.331398240981564, 38.26725921323223, 37.31557846069336, 40.608886749513694, 40.5562642312819, 46.64359838731828, 52.85118064572735, 55.38807945866739, 53.40178335866621, 53.87776690144693, 52.37207489628946, 53.271321404364805, 51.038151325718054, 46.0979417831667, 40.25392401602961, 41.60820076542516, 38.86901747795844, 40.57455816576558, 39.50413157863002, 41.24386356722924, 43.66517013119113, 44.35039251081405, 44.945812225341804, 48.40767260520689, 44.40019484489195, 42.270041896450905, 40.73506547558693, 40.95868372148083, 40.460377970049464, 43.12225526379001, 41.44127253563174, 40.538291931152344, 39.84091020399525, 41.200529221565496, 42.71077509849302, 39.68213658179007, 40.10446994535385, 38.848197537083784, 39.25584162435224, 37.5671475164352, 40.89972265305058, 39.95758110477079, 40.421621030376805, 41.95094531582248, 39.64831398379418, 41.54417983947262, 38.499338011587824, 38.80751863602669, 39.32537740276706, 38.53329397016956, 38.875332493935865, 41.22048624100224, 39.66730217779837, 39.94130719092585, 48.273527545313684, 49.37987519848732, 50.671107692103234, 56.08304108342817, 55.35511585973925, 52.448800379230136, 56.38122750866798, 54.05281443749705, 56.909613916950846, 53.16582533621019, 53.69108953783589, 48.53386309839065, 48.37809793410763, 43.72611591892858, 51.84193518853957, 50.978982371668664, 65.97101073111257, 57.84430296190324, 79.11447309678601, 34.48968725819742, 0.4230506363655291, 1.2251448463047705, 0.19474641449989813, 0.16209902602338022, 13.905344528536643, 67.28119219503095, 57.804055521565104, 54.50045885578279, 40.97084306901501, 58.731209693416474, 35.517583585554554, 42.16472233495405, 51.85472211530132, 57.85925895937028, 14.018548054079856, 0.21132415881560696, 0.05135276197125355, 0.029657925704434037, 0.05517114719916737, 0.03237469181899102, 0.06411346937379529, 0.048924133016337315, 0.049069390947660135, 0.04628355434585003, 0.07254330170971733, 0.06298103437368428, 0.06436318339359376, 0.01108041802992023, 0.029830276335199035, 0.04599602239566945, 0.10833899745897901, 0.24528256887870453, 13.344921181278846, 72.30482270640712, 58.0317844113996, 56.902734079668605, 28.444202830714566, 55.01557980814288, 78.0596536205661, 50.0642817251144, 55.86487493207378, 62.82319884146414, 61.04813021998252, 4.570904662532191, 0.2290360350161791, 0.6695714484780066, 1.9729437390642783, 1.1455609361010215, 61.19001803859588, 66.5317213919855, 61.021818960866625, 61.88927465869535, 51.618493449303415, 48.76706761698569, 46.97173603119389, 49.69985039003434, 50.35446651520268, 51.1673463544538, 51.56460792787614, 51.33729873165008, 49.06747802611321, 50.22331422375095, 50.04496797438591, 50.039362907409675, 51.320263877991714, 51.9897928545552, 48.68184628025178, 47.628344720409764, 46.052312850952156, 42.59639878426829, 42.56584744299612, 40.89207010884439, 41.01903723132226, 39.02231939377324, 38.84993906944029, 40.54041393341557, 38.96986161508868, 41.31746292114258, 40.902766412304295, 40.082936133107836, 41.08767478696762, 39.89696871849799, 39.06608520015594, 39.634993614689, 38.511195336618734, 40.687561650430005, 40.050811921396566, 41.52743916357718, 38.99072077966506, 41.683671089910696, 40.54858815285468, 41.50245758794969, 41.37785173231556, 40.788664663991625, 42.823390268510394, 43.94068525683495, 42.930129728009625, 40.33574858019429, 40.90559836356871, 41.07182448910129, 40.5777156737543, 40.715233971995694, 40.01412599317489, 41.396663419661984, 39.410571282909764, 41.61091112321423, 43.338515143240656, 51.10471002517208, 54.62906945136286, 56.34033287725141, 54.76557970046998, 55.732514550608975, 55.86835015204645, 55.604794333058024, 53.47080530658845, 47.45129285320159, 42.365371181118874, 44.78406936891618, 41.27639962780861, 43.42750980008034, 43.15121020040205, 44.09306933802944, 45.440454483032234, 45.85136198228406, 48.304706465813425, 49.20840878640452, 47.316653574666674, 45.123342621711, 42.21062583308066, 42.50256392263597, 41.57865747328728, 42.51173442409885, 43.570833206176765, 42.289916546114036, 42.125365272645034, 42.9987084481024, 43.21249331197431, 42.08707901739305, 41.28886099784605, 40.795811222445586, 39.402722620194965, 39.87363846071305, 42.79983251325546, 41.661231210154874, 43.23302299745622, 41.72445981733261, 41.235669735939275, 41.50557587223668, 41.77337177338139, 41.295183858563824, 41.93581281169769, 42.06030099622665, 41.737658592962454, 42.35091332466372, 41.9631988002408, 43.05890898550711, 50.722537809802645, 52.43911212490451, 55.58955984730875, 56.8635731358682, 57.01744771772816, 55.0031380499563, 57.713417391623224, 54.201786056641616, 59.53471114558559, 54.96480472626225, 56.257268844112275, 50.258344911759906, 51.56712608952677, 45.98520894204417, 54.12654322962607, 52.31869143824424, 67.74167845326086, 60.251461536653586, 81.10332658213954, 35.69114846567954, 0.15004098595630738, 2.0045646616528114, 0.8776392739626669, 0.1908138093929137, 15.370781248615636, 73.33020087211364, 64.12116604466593, 57.943181991577156, 50.614241169345, 57.96508058424919, 34.251944557312996, 52.02294864962178, 57.99427478544174, 70.85942145316832, 17.90736725253444, 0.43069506003972025, 0.036982013543526975, 0.04029956879094243, 0.14321741017122425, 0.04195360241517906, 0.04787238239641151, 0.03415267080849698, 0.03673125381371187, 0.15731181919334397, 0.12070846758903035, 0.12195231092552986, 0.23518418172194114, 0.09515170548712054, 0.12502921114285148, 0.34775160913986547, 0.23989075013706762, 0.4133520245311722, 16.958942067238592, 81.09437573340632, 65.03034399401757, 64.00351455134731, 33.0801050893722, 68.98627788789811, 82.02439323548349, 55.51861593800207, 61.12556957429456, 69.02872577790292, 66.52594766309186, 6.08085391021544, 0.4276376950644678, 3.156398203103773, 9.202936522422299, 1.130981241022387, 61.785308314907944, 67.92672803325038, 65.57674192613172, 63.50738963773174, 56.84555376729658, 50.74910402297974, 50.77774909234817, 52.35569900082004, 53.84910614259782, 54.10162048955118, 53.73294122757451, 52.692081466797866, 52.21026928194108, 53.677302406680205, 50.8692148423964, 53.37972002644693, 53.66116185342112, 53.698322388433645, 51.631401969540505, 48.770303572377856, 49.15448796364569, 44.77792693722633, 44.84505830272552, 43.558462050653276, 42.64752295709426, 41.60932256329445, 42.17668948634979, 42.727547153349846, 41.40001704615932, 42.77432141765472, 42.94473663453133, 42.051181485576016, 42.93956695064422, 42.134174916052054, 41.64567509005147, 41.145745477368756, 41.977233040717344, 43.06385901666457, 42.77383504375335, 42.839381771702925, 42.161325562384825, 44.95939147087836, 43.198529674160866, 42.25553304918351, 44.03113511300857, 42.444222588692945, 45.027142570864775, 44.38311684516169, 45.38461954362931, 43.69450553770989, 43.876123043798636, 42.83402773641771, 43.404120706742816, 42.485725187486224, 42.84873270219372, 42.90526974585749, 40.67241345682452, 43.2328268789476, 46.08387616372878, 53.52700894878757, 57.18573308760121, 57.87951407894012, 57.412320567715554, 57.15211053048411, 56.61506745123095, 60.208413524012414, 56.0854454963438, 50.831807198063025, 44.71350200714604, 47.380780404613866, 42.99816323864845, 46.301591242513354, 45.809439689882346, 45.605433294850016, 47.91087304392169, 49.15024788148942, 50.31261482546407, 54.028127039632494, 49.63139326341691, 47.57837372441446, 44.58402064538772, 44.013135356287805, 44.348800028524096, 45.72497929296186, 45.35821414762928, 43.90888660184799, 42.9842858929788, 44.92463927115164, 45.656016180592204, 43.714031096427675, 43.11622658083516, 43.60571484411917, 42.15891330472885, 41.395325891433224, 44.9792504310608, 44.76426139954598, 43.81279245499642, 45.69157246620425, 43.610198113226126, 46.22181807794879, 43.58600101163311, 45.292498757762296, 43.41006309755387, 46.14294313615369, 43.98711435256466, 47.26246210836595, 43.15329297896355, 47.85683847242787, 53.939575610622285, 56.74631387956681, 55.62751270109608, 59.249719573605454, 59.28105146654191, 58.62922414656609, 60.94763125142744, 57.04674390054519, 62.02305493816253, 58.432850683889086, 57.38300869541784, 54.52200835750949, 54.831428450922814, 48.158213784617764, 57.0205307006836, 56.82698918927101, 68.38549629334481, 64.34314866219798, 82.27810782770958, 40.61094991622433, 0.7575264933609194, 7.57333537263255, 1.6118044982994757, 0.45847671767396314, 17.92666531378223, 81.5806947215911, 69.68176118789181, 67.010909511197, 58.883405500842684, 71.13863145151447, 49.768382041685044, 60.36078976046655, 68.39447067629906, 82.76922779698526, 26.67308403599647, 0.6394852757934602, 0.12816740605499477, 0.22284992099288972, 0.20656235546113985, 0.16526367395154892, 0.12443429024349298, 0.10790448771008562, 0.08906823192392627], [0.03616617203900411, 0.07026242813275707, 0.03295378151139425, 0.07772555709966729, 0.050147069813383204, 0.03166349409448524, 0.06072650656044003, 0.1597060124960638, 0.17680426759104576, 15.751461982727053, 59.9147339021006, 55.919242905032256, 41.95990008692588, 24.300942420959476, 51.523148475154755, 72.7356009329519, 46.32825159257459, 47.29544139677479, 62.796428665038086, 56.74835743442659, 4.96898748220936, 0.4553356039668284, 0.7036785408854486, 1.4689644017527181, 7.147614061832429, 66.11303975505214, 56.70794917691139, 59.990498404349054, 53.50491423760691, 49.15227966923868, 53.039909408938506, 53.49757156064434, 56.366604912665586, 54.96614225449101, 54.749572507796756, 53.989715268535, 52.47298963608281, 53.44372918528896, 52.46512528388731, 51.41360844335249, 50.287319460222804, 49.11061625326834, 49.05406744249406, 46.8124250442751, 47.47282274307744, 43.20492705991192, 43.76286460507301, 40.16392915479599, 39.64772955063851, 37.141244796014604, 38.57156845831102, 37.07553332851779, 38.49411733688847, 36.61188563992901, 38.38528333171722, 39.05627927472515, 38.31728120003977, 37.82772625646284, 38.479228019714355, 37.53837300885109, 38.18331264680432, 39.370312075461115, 39.13723699508175, 38.39519123877249, 39.110078504008634, 39.00546889151297, 39.197931751128166, 40.11574675959926, 40.17416261857556, 39.2794386033089, 39.74738913197672, 39.32956257174092, 38.90014540764594, 39.518071682222434, 40.076734865865404, 38.76251336066954, 40.0719887979569, 39.364020593704716, 39.7078045721977, 39.90782583913496, 40.51886835405904, 38.96581765144102, 40.153625088353316, 38.89332832828645, 46.06373479289394, 53.42759255440005, 51.979543701294936, 53.59090043652443, 51.86169216709753, 50.569624208634906, 53.46001094387424, 51.7643742407522, 48.67680603458036, 41.73611317911456, 39.69325650122858, 40.01393379703645, 41.115813870583814, 39.46557467983615, 41.85310179187406, 41.409995555877686, 43.12806429401521, 43.2208126591098, 46.24167311576105, 43.9391908337993, 42.13093503828972, 39.446813983301965, 41.0821795463562, 39.38771955428585, 42.161788402065156, 41.374729525658395, 41.29524661648659, 40.10997695307578, 42.06317609356296, 39.893054193066014, 41.429803525247884, 39.64111251215781, 40.8369255065918, 40.05699749915831, 40.16808294480847, 41.01668380921887, 41.1931473209012, 39.175774282024754, 42.925975937997144, 39.969144252038774, 38.6626890397841, 38.83863479860368, 40.21808924213533, 39.34816245109805, 39.947998754439816, 40.27575592840872, 40.66851462087324, 41.75308919722035, 41.40663016226984, 41.714799019598196, 48.708051635373025, 50.06645864056003, 48.70103059276458, 50.65042111181444, 49.8223695447368, 48.61845293352681, 48.42198533396567, 47.42396962258124, 45.03107670814761, 42.0765317639997, 43.77545933569632, 45.201127144598196, 47.267361148711174, 55.98039265601866, 57.30895042419434, 66.61562088997134, 64.52983779291954, 75.04203304167717, 43.654132581526234, 0.02317132901460413, 0.9007728003686475, 0.19536872304254965, 0.08701316276264769, 12.108194924169972, 70.20323245756089, 54.904149193917554, 65.8273970696234, 38.25258170404742, 43.76965030547112, 26.843714983232562, 32.609124529746275, 59.79321495179207, 57.21073819744972, 14.517622590065004, 0.19555705809785476, 0.1193155665251036, 0.0853421334778109, 0.07904172679709812, 0.03433119610793168, 0.03652361334271489, 0.08046320294060054, 0.073960242612708, 0.012030725202132619, 0.024764539088092508, 0.05442243414900957, 0.0820922046419113, 0.03717867597456902, 0.035680077759729284, 0.07949778659930153, 0.14321655215274903, 0.16225893921669454, 16.567993548608598, 69.20381253765476, 59.277031037115286, 51.59844229298254, 24.075539496637163, 54.73117266931842, 85.44758689018988, 52.57779144471692, 52.15903136038011, 65.48115376503237, 61.95195805641913, 5.154357225664201, 0.6097889499318215, 1.321756378296883, 2.014395347045314, 8.27522929637663, 69.14596542235344, 58.52430858919698, 60.38656365486884, 55.358265522987615, 52.200384909106845, 53.95262925855575, 57.13408331717215, 57.588599727999785, 57.1601317774865, 56.67254586373606, 55.33670817652057, 55.107480941280244, 55.24832933179794, 53.3408179590779, 53.069990065789995, 51.17879575298679, 51.55114635344475, 51.48294025851835, 49.21802643806704, 47.87451267242432, 45.51679949606619, 43.84954114114085, 42.91416175903813, 40.79035520553589, 39.60667017967471, 38.388358469932314, 39.00245258885045, 40.828833656926314, 38.05357240861462, 41.451482465190274, 40.63597071555353, 41.69106083531534, 38.92433466449861, 39.850351349000015, 39.456353187561035, 39.821039476702296, 39.77473981918828, 41.86929725831555, 38.8264048484064, 41.747197797221524, 41.65062512120893, 39.9464572629621, 42.01273833551715, 42.69769007159818, 40.996518904163, 41.60790658766224, 41.96645828985399, 40.889857892067205, 41.99411884430916, 42.751450077179946, 41.05215380268712, 41.557343313770915, 42.30968529178251, 41.51577403468471, 41.31776102127568, 42.73734915641047, 40.82966127703267, 41.33901634523946, 40.5642697888036, 48.616413301037205, 54.02804859222905, 54.5761880566997, 55.127763517441295, 52.2022754915299, 52.72849675147764, 56.29185630429176, 52.86173574386105, 51.7096689439589, 44.98847976807625, 41.956679821014404, 42.35433755382415, 42.92824699032692, 41.76374627697853, 43.639666880330736, 44.21503151616743, 45.677051851826334, 45.32639588079145, 49.3293393811872, 45.86203082915276, 46.16656757170155, 42.474295400804095, 43.70730423158215, 41.009325442775605, 44.67709848957677, 43.118748664855964, 43.07211952824747, 42.70561718171643, 42.95728429671257, 42.32321354650682, 43.75944822065292, 41.05240483437815, 41.655967389383626, 41.621666262226725, 41.18790311198081, 42.05169139369842, 42.023709204889116, 42.88740727209276, 44.323787073935236, 42.48254414527647, 41.58630609512329, 41.589953899383545, 41.34774754124303, 41.9371150385949, 42.40753666047127, 43.168225442209554, 42.60025839651785, 43.79966428202968, 42.885073461840236, 44.88600392495432, 50.12911850406278, 52.02574529955464, 51.18165516084241, 53.017214575121486, 52.563721902908824, 51.12871100825649, 50.87708703933224, 50.41949156791934, 47.70671759882281, 45.42084263217065, 45.79111045406711, 46.63007405496413, 49.19446868281211, 56.15068235704976, 59.59581382812993, 67.88228757919805, 67.12574866510207, 75.42444059925695, 48.70854977638491, 0.12787625433937197, 1.6658581913478914, 1.1937815744069316, 0.07742911937736696, 12.918077092016897, 76.59886883151147, 61.266084563347604, 69.63819934475806, 46.19626383627615, 62.82387348913378, 36.32540356728339, 42.57271551316784, 65.66566598030829, 68.568467017143, 19.728302109626032, 0.23542574456622525, 0.10782536614926592, 0.025605452735157266, 0.06301326369265876, 0.054481556984565915, 0.03830565259821954, 0.08798833140322278, 0.03707119766923209, 0.13917341588004944, 0.1888781809999097, 0.1494800870216662, 0.19817687961603367, 0.11055318308213066, 0.1351896360997231, 0.18686693972877919, 0.4611103134530206, 0.47519753657041064, 21.43647078544863, 76.67578651059058, 69.62532612585252, 58.136405791005785, 33.24352279786141, 61.097591307855424, 77.28255364202684, 56.219700382601836, 59.89940135709701, 72.18856365449967, 68.48624629359092, 5.86331190601472, 0.6053032906305406, 2.696106347345537, 3.6888555413292305, 8.391352045920588, 70.72085980446109, 60.97600959962415, 63.46756189100204, 58.42305260319864, 55.05596845380722, 58.14192456583823, 59.29132807639338, 59.64577697938489, 59.8805033776068, 59.31264615827992, 57.76285886764527, 57.45927918341852, 55.679299754481164, 56.890166805636504, 57.84212212408743, 53.28699519557338, 55.235071720615515, 54.51444602781727, 50.452443399736964, 52.62419700622559, 47.97332109943513, 47.88362041596444, 44.771972779304754, 44.96727151255454, 41.66946818751674, 41.565886236006214, 41.05626052425754, 44.46480020400017, 39.26141138999693, 42.47723717843333, 43.5051295834203, 43.095234055672925, 42.27145394971294, 42.542595632614635, 40.60331306149883, 42.56314885231757, 42.28706498299876, 43.564667240265884, 39.88667641916583, 43.04758510281963, 45.13616877217447, 42.037845426990145, 44.26957991815383, 44.42789462304885, 44.56849590424569, 43.6175407901887, 42.870474400058875, 41.89624394139936, 44.66113836534562, 46.19607556250788, 43.537371466236735, 45.825027188947125, 44.622177462424006, 43.555983112704375, 43.56571451310189, 45.82892210252824, 43.91649992235246, 43.30546132979855, 42.72279716307118, 51.51212269260038, 55.7721540235704, 56.7448704473434, 55.979090429121456, 56.1463834393409, 54.36981647245346, 58.30618950628466, 56.52170719638948, 52.7450805325662, 48.43849066765078, 44.10499726572345, 44.704366807014715, 46.08944985174364, 42.884057567965606, 47.11414944741034, 45.78503078030002, 47.24376024738435, 47.59466725011026, 51.791975959654785, 48.9046133718183, 48.18829444146926, 44.594438460565385, 45.693011976057484, 42.44296743023781, 48.49169761903825, 45.63868714917091, 46.184367287543516, 44.51077822716006, 44.902901495656664, 43.221616744995124, 46.51710979400143, 43.993221482922955, 44.21911078114664, 45.3612147608111, 43.7579498752471, 44.90827514279274, 46.51841594326881, 45.49152374267579, 48.52348842928487, 44.958152001903905, 44.60448757294686, 44.150179047738355, 45.149002767378285, 44.47812449547553, 45.69207452958631, 46.02628008011849, 44.18175020525533, 46.203586901387865, 46.01525821993428, 47.30948740436185, 53.076869903072236, 55.216209042456846, 53.22514334032613, 57.035659282438225, 56.535957167225504, 53.77425555259951, 55.07649421691895, 52.806649977161044, 49.98204923445179, 47.98337805655695, 47.86031761477071, 49.66466672958867, 53.16648429439914, 61.26366838332146, 63.62904587099629, 72.03853299540859, 70.47025957415181, 78.3951888545867, 51.45884513854981, 0.1679327242797421, 7.017123670347276, 2.564724842386861, 0.1657078976953222, 14.720979832833814, 82.57942430434689, 65.53656116608651, 79.28355078543387, 52.846583627885394, 62.12161233348232, 39.908724061904415, 51.884539973351266, 72.64468039235761, 80.22481764516523, 26.46672421886075, 0.41553080923134283, 0.21053907191080434, 0.1905107143665514, 0.1729788381846682, 0.1543405012137467, 0.14354396280982804, 0.18317085660753712, 0.11376980241508254], [0.02584489926155056, 0.07619574846279237, 0.04322936863548333, 0.03888087737704477, 0.04952771837011941, 0.015525113652280022, 0.0082288951342625, 0.0838390306659764, 0.1073700188088321, 13.889385384898032, 64.56981458971578, 53.438175109124955, 38.227086297927364, 33.48564286385813, 45.42868345014511, 49.81897277216758, 34.75987188277706, 51.46279496531333, 59.80694324739518, 55.627132231189364, 3.9510355889797215, 0.2254707537471287, 0.18760995308478035, 1.3374349498941054, 18.02006086995525, 71.2425507268598, 56.27014598538799, 58.10931790259577, 52.19958082322152, 56.121539146669456, 57.41303836145709, 57.62243017073601, 55.78368186950684, 57.00699852358911, 54.18634760764338, 57.05782459628198, 54.46128614487187, 54.827972842801, 52.30809711640882, 50.844931448659594, 48.4199692356971, 49.76909983542658, 46.97789415236443, 45.759453004406346, 45.06160059282857, 42.91557381230016, 41.685298873532204, 39.9553688879936, 40.860118481420706, 37.57454510658018, 37.77093818110805, 37.78950275913362, 35.90073639346708, 36.76741546200168, 39.75344527152277, 37.90349860345164, 38.97093242214572, 39.49259981032341, 38.27442930590722, 36.391907353555005, 37.582134892863614, 37.06844560561642, 39.560860818432225, 39.5887331808767, 37.89522240238805, 37.550755931485085, 39.46797909275178, 38.10293151486305, 39.5721572445285, 40.190228646801366, 38.44071426699239, 39.564587070095925, 39.43261108090801, 39.226102213705744, 37.83405303955078, 38.51460387629848, 39.430897005142704, 40.908826474220525, 39.07150591573408, 37.98396994990688, 38.5073749480709, 39.51155662536621, 39.39173213897213, 40.51920960026403, 42.99521361627887, 49.765063716519265, 53.58760564557968, 54.503035852986, 54.184084400053955, 51.38519087145406, 55.1258494007972, 52.797824644273334, 50.75612114321802, 44.08769961326353, 40.6858907207366, 40.85989098395071, 39.280921259234034, 39.88906514260077, 42.01136550595684, 41.87716945525139, 42.765723582237, 45.79329913662326, 44.95874427979992, 44.28544982787102, 43.28129952953708, 41.22102752808602, 39.00495506102039, 39.47982465067218, 40.92393936649446, 43.15585428668607, 41.33491354603922, 41.15288419108237, 40.892874194729714, 40.334010970207956, 42.36630078284971, 41.42358656852476, 40.0052692813258, 39.99378850383144, 39.98892476481777, 40.53060800798478, 41.834160666311945, 38.689922055890484, 39.93964018360261, 39.50052299807149, 40.127847271580855, 39.625128853705625, 40.000982130727465, 39.198096490675404, 38.72625104842648, 40.36791986034763, 40.19129553148824, 40.8194984159162, 40.58179886110368, 41.252465325017134, 43.04546702292658, 44.58724875603953, 46.37710471307078, 44.771717825243556, 43.87525619999055, 42.540654059379335, 42.73341894149781, 43.6008511051055, 41.65843063785184, 42.30773195143669, 44.02922884110482, 47.229918203046246, 49.33933358038626, 54.95084501081898, 58.24462790643015, 65.39382219314575, 62.39014171784925, 71.72344899946644, 53.77064697204098, 0.3584511608125702, 1.5037512899406495, 0.7169750080473962, 0.03845089137734425, 9.394984591391779, 67.74218836138326, 57.30849542925435, 60.50487802874658, 34.71099130568966, 14.57565111498679, 16.461773803157193, 41.23210822382281, 52.57589693992369, 61.578018896041385, 10.097967463154948, 0.19644832478896265, 0.007138101800885653, 0.03611224327957438, 0.02617289023023219, 0.010012553708117095, 0.009638042050233532, 0.04635542105402678, 0.018317334639329105, 0.03827728053194381, 0.027053651940678398, 0.047200339425715714, 0.04304701289642723, 0.04753217807099704, 0.033652568611526684, 0.0452920412194104, 0.09409500976964351, 0.07605567694671693, 17.35151444711993, 74.71270299726918, 59.51768413666756, 45.35551555695073, 31.556923235616377, 48.76095656425723, 54.63579239383821, 45.038611581248624, 57.131059169769294, 63.071073024503654, 59.07112621491956, 3.9465155476523988, 0.5013126158906568, 0.5459970536251222, 1.324837767789441, 19.1183441300546, 74.66295949874386, 58.55473441462363, 60.6562069923647, 54.32714892971901, 58.326868241833104, 59.61775164450369, 60.27201083398635, 57.30093309956213, 59.3212910621397, 56.15802503401234, 57.76295692689958, 56.31788515275525, 56.629074235116285, 54.530692485071, 52.70038512445266, 50.681552963872115, 51.26298550636538, 49.5841287028405, 47.159715621702134, 47.038388867532056, 45.49867814587009, 43.071895953147646, 42.16082349900277, 41.356780759749874, 40.023680886914654, 40.237850143063454, 40.22525541244015, 38.81640280446699, 39.401883232978086, 41.646502710157826, 40.87543925931377, 40.726322512472834, 40.420514921988214, 39.85039841744208, 38.677331247637355, 39.123018403207105, 39.58015887968002, 41.63907374105146, 41.02482272732643, 39.83957267576649, 39.264819929676676, 40.96343371175951, 40.01309440981957, 40.91765965184858, 40.81222634161673, 41.16609865619291, 40.96287673519504, 41.366351342970326, 39.550635199393, 40.85757678554904, 41.548270871562345, 40.82805310526202, 42.568463663901056, 43.539352263173754, 41.76280490813717, 40.74055679382817, 40.99134922027588, 41.13456280000749, 42.68880198078771, 44.62204802420832, 52.05071510807161, 55.09989115499682, 55.967225259350194, 55.5898501027015, 54.05462265014649, 57.26102298305881, 54.320273014806936, 52.07267253629623, 44.77109024601598, 42.13028000247094, 42.416789531707764, 40.864362485947154, 42.32316255569458, 44.26361007075156, 43.65741560536046, 45.440666291021536, 46.15002301431472, 46.11237610540083, 46.78435656332201, 46.55337210624449, 43.07372377764794, 41.60383516742338, 40.88117768687587, 42.29758870217108, 43.46420357304235, 42.94764311082902, 42.36181751374276, 41.73258304595947, 42.60721275883336, 42.806237743746856, 43.24774757508309, 41.24536583500524, 42.54907931050947, 41.4055318986216, 41.334580144574566, 42.67687013072353, 41.61807337114888, 41.00974121401387, 41.1881306094508, 41.868767738342285, 41.407712736437404, 41.59449208167292, 41.57179332548573, 42.028933801958644, 42.65360655323152, 41.66048595982213, 44.53186488920643, 44.28227663040162, 44.19643948155065, 46.26527793945805, 47.37195899409633, 48.534706407977694, 47.86800153793828, 46.592489903973, 45.026820936510646, 44.066671786769746, 44.35397755715155, 43.96882434045115, 45.77361276072841, 47.276198248709406, 49.34361680861443, 52.064780727509536, 56.640284369068766, 60.87342393013739, 67.50620288233604, 67.54924697260704, 71.6831584130564, 60.082148505795395, 0.5321236916126744, 1.089911941559084, 0.42608017702737166, 0.08913678913227013, 10.131382134652908, 73.03588190386373, 62.78652860272316, 67.65839868976225, 42.48947889574113, 18.08358169371082, 21.28411808321553, 45.82025758681759, 61.640706216135335, 70.37076473236084, 14.470527671998548, 0.27802774081787757, 0.07119430514473109, 0.10026606250434153, 0.049352747718653375, 0.08676373985626044, 0.058862361831650625, 0.008287262415603526, 0.03770069594705298, 0.114698538466567, 0.16546069644391537, 0.16759740759528455, 0.1747525309122378, 0.11602308916588945, 0.16078518523323923, 0.18328667377992985, 0.1875898815811642, 0.21543760663799702, 20.087697121404833, 84.13892730589836, 65.93228909277147, 53.59631722973239, 43.99087198318974, 54.304924780322665, 52.67351296640212, 48.1506004641133, 61.667499926782426, 69.04601558562248, 66.22496851028936, 5.480650374966284, 0.49894555742221497, 2.0079345905011703, 2.784694548576109, 20.327469648853427, 74.8955717394429, 62.069021194211906, 62.48449825471448, 55.79730818348547, 60.216968213358236, 62.71056013722574, 61.33518888104347, 59.80895542329358, 62.53206876016433, 58.376898073381, 60.07831635013704, 58.70821283709619, 57.992176317399554, 56.43092001638105, 55.868099120355424, 54.11568218661893, 55.149909219434186, 51.78091095339868, 49.21635943074381, 50.05410709688741, 46.83138970405825, 46.954348164220015, 45.03612872092955, 44.682829072398526, 42.943556001109464, 42.25292859538909, 42.4853172609883, 40.23593210404919, 41.71819579216742, 44.83922181590911, 43.31496523272607, 43.10309056312808, 43.583490694722826, 42.214579582214355, 40.29553644118771, 40.298411538524014, 40.676986940445445, 43.35120793311827, 45.95649327001264, 41.78232654448479, 41.93329857241723, 44.14528000739313, 41.459217379170084, 43.526569258782175, 44.59455613167056, 41.983987362154075, 41.529623923763154, 43.59059802947506, 41.42870526159964, 42.159595797138834, 43.35866043644567, 43.165460171238074, 45.928926852441606, 44.31260439657396, 44.19160712149836, 41.99084758758545, 44.17632556730702, 43.90669007455149, 45.770380727706424, 47.00575474769839, 55.73574658363096, 57.12957259147399, 58.45115246311311, 59.17103290557862, 55.134204049264234, 60.85662834105953, 57.44624906970609, 54.463580731422674, 46.59000312128375, 45.644178467412154, 45.079200267791755, 41.99578192926223, 43.88836868347661, 46.75186364881454, 46.7871492908847, 48.52088005312028, 51.38167642777967, 48.760070108598285, 51.57933250550301, 49.288334923405806, 45.57718830723917, 43.17354025379304, 43.32629696015389, 44.64125587094215, 47.843137633415964, 45.31855898518717, 43.81963306857694, 43.20988101343955, 44.98643621321648, 46.200931456781205, 44.905007808439194, 43.11915266898371, 44.22009137368972, 42.379201458346465, 44.30705424278013, 45.27405577321207, 45.43427282764066, 43.94955373579457, 43.63260661402057, 44.96370215569773, 43.35766807679207, 45.32947494137672, 43.52168198554747, 43.623624386325965, 44.35414621906896, 44.70348035135577, 46.39622626766082, 47.1341888366207, 45.3397358617475, 48.62075144244779, 49.44967377570368, 49.7702451675169, 49.09118483143468, 49.37304242964714, 48.3670368502217, 46.45213573209701, 49.810720105325025, 46.59614163060343, 48.34969605168989, 48.566457994522594, 52.26177000230359, 54.995803217734064, 59.31319921247421, 62.11485408967542, 68.43624391863423, 69.56001081774312, 74.41980392702165, 62.59901969663559, 1.0855546785939125, 4.886595154962232, 1.2834795612481333, 0.17719121860159984, 10.80427062126898, 78.7942429511778, 66.69332304308492, 72.3576021194458, 47.07512186419579, 23.106698374594412, 28.150203535633704, 59.32720207398938, 70.59772876001173, 82.89009955621536, 19.628285592602147, 0.5422861237199076, 0.13686433494571718, 0.13919206246012641, 0.1330291149356673, 0.16066729962345094, 0.11312488661778551, 0.11223329050887017, 0.13617836449655796], [0.026132256926728353, 0.006883219081623059, 0.016991433710040107, 0.07327824049899656, 0.04012947428911444, 0.012372587150293253, 0.06624301760307243, 0.09166926130532257, 0.18394895679047032, 14.256790857161246, 63.6879010354319, 50.030576798223684, 47.247659083335634, 34.97923435703401, 54.55138298772997, 77.19100552220499, 39.8929718232924, 53.45970107663063, 58.18936171070222, 54.54800190464143, 3.597099290740106, 0.4038346690997001, 0.3828813676391879, 1.1038959266677981, 28.200821722707442, 66.87557989551176, 56.60781498878234, 58.93039549550703, 55.93254758465675, 58.07254175986014, 57.9605737809212, 58.83100263534054, 55.87090753739881, 53.85142034099948, 54.347980637704175, 53.92583554790866, 53.48087403082079, 53.96769508238762, 51.06324272771036, 50.181238958912516, 49.98175505668887, 47.691310528785955, 45.58392693919521, 43.2262098404669, 42.25250497941048, 40.55305181011077, 39.45438415773454, 37.27582131662677, 37.665979477667044, 37.55831041643697, 40.25769733613537, 38.815449668515114, 39.51490632949337, 39.25612403500465, 37.32429004484607, 37.52198534627115, 38.3290796895181, 37.91436356882895, 35.012562736388176, 36.752282957876886, 37.10663380161409, 37.648807341052645, 38.45966715966502, 37.14335110879714, 37.93857635990266, 40.64284270809543, 39.19034196484474, 38.676656599967714, 39.95119548613026, 38.234695696061664, 40.75399483403852, 39.13492279668009, 40.151059858260616, 38.84536950818954, 38.34657346048663, 38.94410733253726, 39.5120547663781, 41.83621991065241, 40.409410692030384, 38.534600119436945, 37.95852945696923, 39.12853325566938, 38.83583814867082, 40.2240865461288, 42.12229797917028, 44.11930999448223, 51.33010118238388, 55.35728100807437, 54.45895233461934, 49.339392415938846, 54.260696134259625, 52.06076029808291, 50.42600662477555, 44.10763702084942, 42.05705327372397, 39.84643682356804, 41.79384654568088, 39.76073695767311, 40.810061193281605, 40.607102071085286, 41.88458665724724, 42.59361782381612, 42.75543912764519, 43.27389409465175, 42.549499004117905, 38.88913923694242, 41.03340095089328, 41.96124545989498, 41.11846147045013, 40.841455844140825, 40.81152031498571, 40.248366017495435, 41.25589739891791, 41.396322173456994, 41.636963505898755, 38.94709617860856, 39.94422543433405, 38.5006441608552, 39.52246081444525, 38.316347675938765, 40.26561267914311, 40.50361817882907, 41.21494393194876, 37.77788077631305, 39.4764357228433, 39.24452558640511, 41.68723652439733, 40.142073708195845, 41.232904464967795, 40.871563957583525, 41.14249775486608, 39.583504661437004, 40.98282590989144, 39.5367068629111, 40.92661050058181, 40.287730924544796, 40.99792311268468, 39.78698938123642, 41.127682962725245, 41.27019836056618, 42.76119716705815, 42.66915482859458, 44.02226663404896, 45.01069607273225, 46.876798983543154, 48.070870445620635, 50.225153815361764, 54.468691579757206, 56.65624841567009, 59.38600624761274, 65.26180305788594, 65.44417758141795, 62.375546578438055, 4.356095569749033, 1.1446943374410754, 0.7103211973463336, 0.16524191705449937, 6.204551737154684, 64.18479473360124, 60.615783045368815, 62.83901776036909, 42.914636365828976, 36.87716730179326, 30.618845262835105, 47.844592832749896, 54.68934451380084, 60.32995600854198, 13.763919549603617, 0.16531443493741174, 0.04919086567937367, 0.052550747284605626, 0.055304377550078984, 0.01741531398898411, 0.029525675946065498, 0.0794636343996371, 0.0548828108566663, 0.07482380756447393, 0.04139338146835085, 0.026995743354482037, 0.09078198593230018, 0.040075978369361935, 0.0642157536030056, 0.04261499676372736, 0.07583266109107964, 0.14127617401461448, 16.800907811810895, 71.34526975693242, 56.79201733681464, 55.0318851009492, 47.18829401077763, 53.879006370421386, 61.278863645369015, 39.48137398689024, 58.0569895621269, 63.787768502389234, 58.78947257995606, 3.9114846144953086, 0.4873929208805485, 0.9544194862246514, 1.0489268504804181, 32.066748988243845, 70.11453197848412, 57.54428478979296, 61.38948232896867, 57.69426445807181, 59.8593500352675, 57.7826472251646, 60.34683396739345, 57.86191048160676, 56.751126627768244, 55.35773208064418, 55.34248582778439, 55.17527910970873, 54.24043316994944, 54.26487738086332, 52.39564834102508, 52.153030134016475, 50.66116840608659, 46.435689233964496, 44.923615532536665, 44.45640633183141, 44.15241479873658, 41.903872951384514, 39.94371160384148, 39.01290962772985, 39.30256882021504, 41.394627709542554, 39.42507620780699, 41.63050336222495, 40.806244727103945, 38.38674637579149, 40.346758673267985, 41.26782532661192, 40.069513782378166, 36.77937476865707, 38.64582677041331, 39.712880119200676, 39.45487837637625, 39.03516515608757, 37.78605499575215, 39.81172776991322, 40.90040122309039, 40.31764291947888, 40.79332443975633, 41.61628869272048, 40.34397379044564, 42.13311195373535, 41.370626726458156, 40.87875758447955, 39.78382795087753, 39.40876307026033, 42.29219544318415, 43.70610398630942, 44.22116610311693, 42.309814729998195, 40.50042929187898, 40.231837149589296, 42.197834983948745, 40.52251223594912, 41.09713554382324, 44.38938871506722, 46.54360148214525, 54.85663752402029, 56.66985119542768, 55.4054202571992, 52.69196379569269, 55.084209519047896, 54.69580073510447, 53.02334131733064, 46.04992020514704, 43.64313033319289, 41.48947454267933, 45.48993910512617, 41.402064523389264, 41.95480885044221, 43.41406391512963, 44.297671933327955, 45.51664652362947, 45.424725778641246, 46.074348726580226, 42.88017834386518, 41.55359745025635, 42.690590581586285, 43.061340855013945, 42.62701680583339, 42.39267479988837, 43.50993840925155, 43.07040545248216, 42.26636663559945, 41.97720166175596, 42.0577161542831, 41.04023764210363, 41.71284175688221, 39.543245453988355, 41.49916279700495, 38.974760655433904, 40.71404157146331, 42.145761597541075, 42.62708348612632, 40.76181996253229, 41.62343917354461, 42.33871083105765, 43.07848161266696, 42.228378480480565, 43.11688946139428, 42.750116471321356, 43.474868497540875, 41.56190110791115, 42.18029022216797, 41.614519703772764, 44.77670708010274, 42.681871152693226, 41.83271331171836, 42.87934287901848, 43.271175892122336, 43.4329265932883, 45.907891181207475, 44.557834902117335, 47.52695537382557, 48.37963158084501, 48.547669841397195, 50.10505476305562, 53.74518686725248, 57.31077432632447, 58.85237955277967, 62.739224818445024, 68.05364024254584, 68.06763525932067, 68.3328345514113, 4.949599696743873, 1.2497184954343306, 1.5938315852995844, 0.1384833085560991, 7.325599453141613, 69.60465523504442, 65.85724630663472, 67.5368836618239, 50.24251030337427, 31.7238946114817, 30.185407669313495, 54.520839491198146, 59.56692557181082, 70.80137037461805, 17.86158142551299, 0.20679231973425036, 0.06390762154854114, 0.030663264802687114, 0.04508271152454038, 0.030888034999671004, 0.0268776681379325, 0.06415655798909646, 0.04734413795954278, 0.21517926646817118, 0.09960920339630497, 0.08613953141555672, 0.15418927545749372, 0.2622634593036867, 0.12347622068538783, 0.13259360927247232, 0.2717145021644331, 0.281497169165842, 20.032619199445172, 80.66855538275935, 63.405835551600305, 62.5933087256647, 46.19463997502481, 64.4596665905368, 80.653273828568, 52.956888521871264, 63.70782667590726, 68.85876947833647, 65.89442253112793, 4.737891727878202, 0.8082067029130074, 2.7824573266890744, 2.2029791051341645, 35.482282254003714, 70.84216302441013, 61.316549777984626, 63.564432667147734, 59.31949461660078, 62.6561450958252, 60.75983993468746, 63.079380604528616, 60.906473821209325, 58.72869153176585, 58.62016739383821, 57.62414424650131, 57.15175359479843, 58.898879251172474, 55.82843219080279, 54.539349156041304, 55.90826811329011, 53.22958346336119, 49.32260467160133, 47.79431981425132, 46.66970176081504, 45.989331353095274, 43.72770840121854, 41.17939156870688, 40.918761837867, 40.97795432613742, 44.50522022862589, 41.95718580676664, 43.40316757079094, 44.41646875873689, 40.25431233067667, 40.88764959766019, 43.67721965236049, 42.51814749933059, 39.040103420134514, 42.96131649324971, 42.38993698550809, 43.20468387296123, 39.91583139665666, 40.6795286363171, 40.31488941561791, 43.94119516495736, 41.75899236432968, 42.2390002589072, 43.47058134694254, 42.91268302548317, 44.093575323781664, 43.3225550190095, 43.67295211361301, 41.48581497130856, 40.55715853168119, 44.78164534414969, 44.85447591350925, 48.89590963240593, 46.12045226558563, 42.41733866353189, 42.62289047241212, 44.323449750100416, 44.41803770680582, 44.348372490175315, 47.334625874796224, 47.78219184567852, 56.7142524257783, 59.58569411308535, 58.94759901108281, 53.64261688724641, 59.67457502119003, 56.2568256162828, 55.90893099384924, 46.9471388478433, 46.70003737172773, 45.68837965688398, 48.21212676263625, 44.816613274235884, 44.77226695706768, 44.56508344219577, 47.14299848002773, 47.978753582123794, 48.92541762321226, 48.658006114344445, 45.59991844238774, 43.71890268018169, 44.75185102032077, 45.194282608647505, 44.628774889053844, 43.24051864685551, 44.3534598042888, 45.58562140310965, 44.30268864477835, 45.613831089388945, 44.20178959446569, 42.6607923353872, 43.827277768042784, 42.25760013826432, 43.13395177164386, 41.504858078495154, 42.61839151382447, 45.33123608558409, 46.33231124570293, 41.994597373470185, 44.78415173868979, 44.61550158839072, 47.46882192550167, 45.3361939614819, 44.889545825219926, 45.15719267629808, 47.581276278341974, 44.05065282698601, 45.87359397642074, 43.70884964543004, 46.48563277336859, 43.17254789413945, 43.20704121743479, 44.93746149924494, 46.56093835830689, 45.85417039932744, 48.375003184041674, 47.26117557094943, 49.766577751405784, 50.964096976864724, 51.90059815683673, 51.89847223220333, 55.86619677082185, 59.70032145900112, 62.470675822227236, 65.01570963090467, 72.26786613464355, 69.88881526454803, 71.57303394809847, 6.470460978246505, 2.3878681130947608, 2.8481616848899476, 0.21181157459655117, 7.831516073596093, 76.04180597489881, 72.22435135995188, 76.02183326598137, 56.66277523963683, 50.265016863423014, 43.43498975999894, 66.29757942691927, 69.71946300998812, 83.56522575501474, 25.419622005954867, 0.4315231397988335, 0.19878481634922568, 0.13404055017857783, 0.19980941298267535, 0.12523038583176752, 0.11289833143593804, 0.14286568388342857, 0.12241304386407138], [0.10913992706205576, 0.12729636408508788, 0.05019703023736516, 0.04362702955521884, 0.029357014028655908, 0.10081881792434763, 0.034508503327566775, 0.11422636017443673, 0.11348612771760072, 11.099101458826373, 59.83836143247543, 56.06886171525525, 36.40199176726803, 28.608852163437877, 65.1581387366018, 92.75383287860502, 53.99013888451361, 50.14781644267421, 57.69009105620846, 55.63270591920423, 4.164693711265441, 0.28000994735667784, 0.22709547301694272, 0.5924074568094746, 34.58458115977626, 70.36477135073754, 56.815214234013716, 56.88027458806192, 56.33857957778439, 57.85282627228768, 56.836591151452836, 54.495810847128595, 52.82917222669048, 50.61542572513704, 48.98683801774056, 46.92140417714273, 47.57690283559984, 50.15736349167363, 47.37601472485451, 44.41753564342376, 42.488576750601496, 41.72122778431062, 38.982903495911636, 40.43294883543446, 39.089054599885024, 38.13330242710729, 38.818101190751605, 38.66267335030341, 38.96298177780644, 37.628112916023504, 39.016835920272335, 38.529752069903964, 37.65958601428617, 37.830766093346384, 37.51235592749811, 37.20118645698794, 38.85430858981225, 39.38759403844034, 37.09990693676857, 36.88077980472196, 37.902486631947184, 39.05305508644351, 38.591129318360366, 37.87860331996795, 38.50699447816418, 37.49375212577082, 37.72914140455185, 38.46069482065017, 38.60454382434968, 40.48298258935252, 39.293829779471125, 39.71577875075802, 40.567027215034734, 41.04529357725575, 40.204011855586884, 38.32631834091679, 42.23863547848117, 40.80818237796907, 41.274591415159165, 38.06355876307334, 40.41063447152415, 38.36933889696675, 37.98868856122417, 38.45686266499181, 40.28485582720849, 43.603906631469734, 51.343582368666134, 53.18352699279786, 55.694451870456824, 51.43162388955393, 51.45724873388968, 50.43188233529368, 46.34668673238447, 44.92097185504052, 42.16963706477996, 39.18335622356784, 41.1075847379623, 42.08028939462478, 40.78764484774682, 39.99720881062169, 39.83791743555377, 42.092919426579634, 43.00884777499784, 42.78168370646816, 41.95875475483556, 39.70791439856253, 40.60212066096645, 39.31517531794887, 40.76549914575393, 41.78896319481635, 42.211171042534616, 39.3766192466982, 39.13098081465691, 40.06194753031577, 39.31306116042599, 39.854207038879395, 39.32829564617526, 38.26984013280561, 38.48606471092471, 38.034862702892674, 40.24949173773489, 38.58016629372874, 40.47950344700968, 40.02650107106855, 39.55766408674179, 38.309503139988074, 40.44045625194427, 40.801216248543035, 39.861282994670255, 38.520020669506444, 41.69317891520839, 40.79548566572128, 43.05073084369783, 40.16334864401048, 40.731472584509085, 41.60552178659747, 40.81682335945868, 41.750939738365915, 44.14887289847098, 41.73302627378895, 42.051365836974114, 42.66183568585304, 48.694480234576815, 52.513268455382324, 55.233965612226925, 56.027512088898696, 55.66697174502958, 52.44553696724677, 55.07183444115424, 57.92768470702633, 64.8962224683454, 66.74616521404636, 67.19387239025485, 7.562897455307746, 0.5810379765687451, 0.55956385789379, 0.15417740109466738, 4.9737105061930995, 62.80106098421159, 61.19446992874146, 66.22903208578786, 46.54448401543402, 27.07861592692714, 20.7897307795863, 40.4757732729758, 55.62128789963261, 67.06893705552625, 17.106860529991888, 0.18140093303255497, 0.10223121592594732, 0.08179809582690079, 0.04497030727385033, 0.028702723230385495, 0.03759930421027445, 0.05404063891018591, 0.1300537673335883, 0.040077257736195485, 0.07664905800934761, 0.03598740542187326, 0.03931504238637225, 0.023459228686988357, 0.05429024567767497, 0.06254104326569265, 0.11413992247394017, 0.06589417180587208, 13.832664970428715, 69.12051708467546, 62.05031541086013, 41.90003295098582, 29.521252339886082, 66.01607876439249, 88.43208697534378, 53.33504030781408, 55.62397080083048, 61.82626962661744, 61.032836898680664, 4.428774637560691, 0.374891683459282, 0.4188545582996261, 0.690687467013636, 37.46191424708213, 70.39531876963954, 59.10610591211627, 58.67473933004565, 59.18352957694762, 59.783244286814046, 58.71542999821325, 57.56472033839072, 54.71990762218353, 52.18166343627438, 51.524713500853515, 49.4801898156443, 50.01777025961107, 50.64431790382632, 48.864346319629306, 46.76655292510987, 45.839516424363666, 43.66004359337592, 42.111495771715724, 41.359098880521714, 42.30094232866841, 40.487281507061375, 40.3134891294664, 39.72774197978359, 40.53598165512085, 39.06730113490936, 40.93185470950219, 39.99676166042205, 40.21902668860651, 40.75107659063032, 40.69918755562075, 39.322619976535925, 40.998911549968106, 40.28832712481099, 37.907228777485514, 39.02744985395862, 39.16870224860407, 39.58471667382025, 40.84611954227571, 39.88758640904581, 42.1837301408091, 38.5582677010567, 40.105297565460205, 39.947959530738096, 40.64531772367416, 40.336740939847886, 40.73775229915496, 41.275246450977946, 41.85028160772016, 42.22963756130588, 41.44549692830732, 41.33456053272371, 44.346823153957246, 42.99416242107269, 44.003470636183216, 40.37497228191745, 42.003583523534964, 40.74959785707536, 41.32571558798514, 40.69445325482277, 41.96274380530081, 45.3284433580214, 52.5588934652267, 55.244610924874586, 57.0175418546123, 53.84313237282538, 54.76673287730063, 52.91305211282546, 51.49312665385585, 45.765156130636896, 43.89344423047958, 41.89529865018783, 44.67912635495586, 43.142529995210715, 42.55066787042926, 41.620116926008656, 43.05770089549404, 44.198153557315955, 44.69228982925416, 44.79545993189658, 43.687288376592825, 40.90549638194423, 42.915099205509314, 40.31479920110395, 42.409725343027425, 43.19098303394933, 43.14602090466408, 41.317074606495524, 41.612150592188684, 40.649946120477495, 41.88221362329299, 40.33491703771776, 42.055370576920055, 40.930823126146876, 41.95444799238636, 39.3288290885187, 41.43855041073215, 41.52907086956886, 41.80183249135172, 42.513201390543294, 42.3107482540992, 40.99393406221944, 41.68078814783404, 42.8368636100523, 43.13077857417446, 40.76593845121322, 44.17298763029037, 42.38472415554909, 44.494492546204604, 42.893173156246064, 42.22234195278537, 43.96323888532577, 42.96145769857591, 44.41213846206666, 45.17516105405746, 43.0266906369117, 44.8683964052508, 44.521325480553415, 50.439056350338845, 55.108120287618334, 56.9728817478303, 57.03260767844416, 57.38148289342081, 55.130101250063994, 58.10259103775025, 60.87684815929782, 66.71793983828637, 66.76128202869047, 71.35726436491936, 10.223529396518584, 1.0422648273168071, 1.3606602842769315, 0.17706584065191208, 5.914006579306818, 65.23391500596078, 66.3543753470144, 68.77566229912543, 55.368961826447524, 35.1431502065351, 22.95326113700867, 50.41052110733525, 60.87280419565017, 76.03898186837473, 23.49316558530254, 0.11977724175179198, 0.016490433274978594, 0.07001627642180651, 0.05505009764625181, 0.019925774540752172, 0.048927932812441746, 0.04423079493966314, 0.07033147563737246, 0.20473825414815258, 0.17893010029389014, 0.11000257270831255, 0.1325420055898928, 0.10721702338947404, 0.21100655408395877, 0.20511443396249127, 0.2825811835786989, 0.21898402682235166, 16.97708695165573, 79.3644614373484, 69.24644870142784, 49.484449509651434, 38.18650153375442, 75.69768075020083, 91.12648071781283, 62.933158566874845, 61.786500715440326, 65.58863455249418, 67.0877722770937, 5.394457271022182, 0.667579987597081, 1.5294015071084424, 1.3132366225604089, 40.19326456131474, 72.60635883577409, 61.975198099690104, 61.05786554275021, 62.51805413153864, 62.914492007224794, 61.0559828050675, 60.06331328422793, 57.21826914818057, 54.79255384014499, 54.302485066075484, 50.674618213407456, 53.24277047188052, 54.76308115067021, 51.20471085271528, 49.49702070605371, 46.861674324158706, 44.26168026462678, 43.009549879258685, 43.42426599994783, 43.664734748102006, 42.780569753339215, 43.51998359926286, 41.68331023185484, 41.98425016095562, 40.717387353220296, 42.51869663115471, 41.796702031166326, 42.91795861336493, 42.58329022315241, 42.41092166592998, 42.27227764744913, 44.0300956849129, 43.46956545306791, 40.1172137260437, 39.92292696429838, 41.935993240725615, 42.76677477744318, 42.59805402448101, 42.226699706046816, 43.135756061923125, 40.411011019060695, 41.752292956075365, 41.546525416835664, 41.2862761559025, 43.7743571496779, 43.57504583174183, 43.230069452716464, 44.864623085145034, 45.588163098981305, 44.77319655879852, 43.83951556298041, 47.43384222830496, 45.247391500780665, 46.21699748500701, 41.491325901400664, 44.50079971744169, 42.90501871416646, 43.823712333556145, 45.09068104528612, 44.18276609912996, 48.38737826193533, 54.95828574703586, 58.09121224188036, 61.59438302440029, 55.32827900302026, 56.166536577286266, 56.1323138975328, 52.793541416045166, 49.76826829295005, 46.977023386186175, 44.549460641799435, 45.44288243016889, 46.58715548053865, 46.506860640741166, 42.79798899927447, 46.422823859799294, 48.14383829793623, 46.607908741120376, 48.19824157222625, 46.07995771592664, 44.36038278764294, 43.809999727433734, 42.3254414527647, 45.06490715088383, 45.96059999158306, 44.65277587213824, 43.764755187496064, 42.66212594124579, 43.213544507180494, 42.816067203398674, 42.165498964248165, 44.67325064443773, 42.15988997490176, 43.45635491032755, 41.8644452864124, 43.47388006025746, 43.022352495501124, 44.27589101176108, 45.828004267907914, 44.10234966585713, 44.12434239541331, 45.74262603636711, 45.16571598668253, 43.83441255938622, 43.31218819464407, 47.679668934114524, 45.773628450209095, 48.55372205857308, 44.274675077007664, 44.18713169713175, 46.05967513976559, 46.4724261529984, 46.60395891435685, 48.877882419093964, 46.111987790753766, 47.4203335854315, 45.83936345192694, 53.77727185526202, 58.3294334719258, 60.95359717645953, 60.050110586227916, 62.44311724939654, 58.21567296981812, 62.181110766626176, 62.60741356880435, 72.588716014739, 67.77426550465246, 76.82451494278448, 11.39878034591675, 1.3999439247192875, 3.175359675961156, 0.3004072222017473, 6.146578615711582, 73.1924472316619, 71.30574795507616, 77.90112710768177, 57.688580943692116, 38.70697652139972, 33.92268903793828, 56.75972446318596, 72.40838896843695, 84.15242025929113, 32.4580995498165, 0.4174244560060963, 0.25847919946236, 0.37340951783041804, 0.20498856571653198, 0.08451373962264869, 0.19068331397589178, 0.17990007485833862, 0.23594843103520333], [0.06734740229383593, 0.03413744098056228, 0.04212368542568819, 0.1298568214500143, 0.07910965581334407, 0.028974107962342042, 0.04845093199682813, 0.11761202446876035, 0.14364286476085264, 6.701585660057684, 56.19553465997019, 56.58597523166288, 45.52027471603886, 41.40459445215041, 32.27203799832252, 50.35427039669406, 46.726807548153786, 52.76704188316099, 56.894030340256236, 56.14446147795647, 6.274251274524197, 0.2217543692958932, 0.524283486508554, 0.23739771617035713, 39.87906702103154, 65.71093405446699, 58.120806524830485, 57.538930754507746, 55.83572387695313, 55.96815093871086, 53.96635755415886, 48.62425804138184, 47.02489199176912, 43.72232298697195, 41.398742275853316, 41.37425491886754, 41.58616096742692, 41.930988296385735, 40.10243031286424, 41.35518435508975, 39.38248319010581, 38.807977553336855, 41.08795719762003, 39.150937834093654, 40.834701522704094, 40.7550185726535, 39.85321860159598, 40.00285310129966, 38.7268707829137, 38.05745947745539, 38.60173932967648, 38.06162503457839, 39.09350256766043, 39.13568373649351, 37.790259776576875, 37.949927699181345, 37.620762394320586, 39.15385607750186, 38.19999056477701, 35.78407333743188, 37.671470795908284, 38.24549790351622, 36.068041170797045, 37.863941500263834, 37.62126445770264, 37.40329442485687, 40.352791278593, 37.96319707747429, 39.576781718961655, 39.368280287711855, 40.42811647538216, 40.52406941690753, 38.90323231297155, 39.67279349603961, 38.851904176896625, 39.464052800209295, 40.50124514487482, 39.50288818728539, 40.27850158752934, 38.646579865486395, 38.822309893946496, 38.090678030444735, 37.90090591676774, 38.25838288953228, 39.24609845684421, 43.35751510435536, 50.3944040882972, 53.65422710295647, 52.33054091853481, 45.006091210149954, 54.43482583568942, 49.79314788695305, 48.52428467042985, 40.90975999832153, 41.25366164791969, 40.15254643655593, 39.44831232870779, 39.34409103085918, 40.89569437888361, 40.21626141763503, 43.08916222664618, 39.38393838943974, 40.20981304107174, 39.68855750176215, 40.381938411343484, 41.3114813066298, 40.656061095576135, 39.66976542626658, 40.03552252246488, 39.5743812284162, 39.14980034674368, 39.060797845163655, 38.0808642602736, 39.39044560155561, 39.77844253663094, 38.01539990209764, 38.807385275440836, 39.975435733795166, 37.458980314193234, 36.91925041137203, 38.72569799423218, 39.96683005363711, 38.73413109010266, 39.25395496429936, 39.090603936103086, 37.76249331812705, 39.95189366802093, 39.18270118774907, 41.34590794963222, 37.77963407578007, 40.8935566871397, 40.15441348475795, 40.508729027163604, 39.73989348257742, 41.7119082327812, 41.06071241440312, 40.345778080724905, 40.34467981707665, 42.27843184624949, 42.25746677767846, 44.731537065198346, 47.40610322644634, 56.064417669850016, 58.29802705395607, 61.577006924536924, 56.672785128316576, 61.798193300924, 63.63051283744074, 60.61894839809787, 60.60110161381384, 63.49168054519161, 62.48942082928073, 59.61786539323869, 7.648281080107536, 0.4014962010325924, 1.6995363970918043, 0.09586349309932801, 4.012582479946075, 60.88636775170604, 60.09021682123984, 67.94616729982438, 48.57527156029978, 46.22642294053109, 36.88612599526682, 34.555022178157685, 53.78360648309031, 64.72258306318714, 17.012847200516735, 0.19832474990717827, 0.07581059775886036, 0.044045711927596605, 0.10814381357763084, 0.039513842202723026, 0.020847795831580317, 0.06248907186090947, 0.08968199092534282, 0.02594243374563033, 0.05522109230139083, 0.03454235675294073, 0.024805904005564032, 0.07324922108842481, 0.02956736836612465, 0.02160666337717445, 0.04124535412918176, 0.10315887945433778, 8.452233114550191, 65.10143303102063, 60.60534561834028, 52.32578700588596, 40.59570758573471, 51.62934272520004, 69.38694015625985, 52.32504960029356, 59.75679182237195, 62.62591538890716, 62.4024461930798, 6.671158854038485, 0.2700873007697444, 0.49651206380897955, 0.4276145285656376, 43.100282146084695, 68.74575030419135, 59.903300193048295, 57.82660130531558, 58.71777165320612, 57.58299466102355, 54.511747437138716, 50.79205789873677, 50.25201028393161, 46.15690677396713, 44.921673959301366, 44.31662874837076, 43.7078219844449, 44.18819858181862, 43.30235873499225, 42.58478856855824, 40.67122497866231, 41.12788300360403, 42.08536101925758, 39.896862814503336, 41.88902285791213, 43.0628627346408, 41.19496337829098, 41.05554273051601, 39.85456789693525, 40.426002317859286, 40.05558544589628, 39.274068878543, 42.01873171714045, 40.983935940650206, 40.06441077878399, 39.894191680415986, 40.78703295799994, 40.8624993601153, 39.16142625193442, 39.09988818630096, 38.898803957047, 38.66537586335213, 39.194742864178075, 38.89906675584855, 38.704913354689076, 39.37015125828405, 41.63379423079952, 39.12616806645548, 41.665918442510794, 40.423029161268666, 41.50459920206378, 42.76236211099933, 40.89777715744511, 41.0215397034922, 41.68513805635514, 40.72216087772001, 42.95557022094727, 42.88333977422407, 41.49091797490274, 41.39982877239105, 41.15673988096176, 39.336367883989894, 41.09726498203893, 41.55122049393193, 41.67052330509309, 45.12311904661117, 51.78870470293107, 55.96218501367877, 55.88082328919442, 48.54876810504545, 55.457944716176684, 53.547118940661036, 50.59977939051967, 43.94870650383734, 43.35138051740585, 42.15343375359812, 41.608851878873764, 40.783569505137784, 42.59043678160637, 43.44654898489676, 42.66257701381561, 41.619367753305745, 44.02032113844349, 42.07467256053802, 42.2935055148217, 44.009318890110144, 43.10754637564383, 41.057084221993726, 40.96215501908333, 40.93787947008687, 40.91265470750871, 41.075448759140514, 39.7694799207872, 41.038990328388834, 42.311203249039195, 40.69364916893744, 40.06866655042095, 40.769092036831765, 40.555009072826756, 39.323267167614354, 41.799930141818145, 40.87998920871366, 42.26874359192387, 41.82661794847058, 41.363158533650065, 40.388190669398156, 42.85684808608025, 40.066572004748934, 42.84666561311291, 41.22095692542292, 42.735658614866196, 41.26538168999457, 43.52401187342983, 43.323825866945334, 43.580945076480994, 43.49261722257061, 43.327356000100416, 41.15639471238659, 43.98147398425687, 43.90474457894602, 45.3145581676114, 50.20573023826846, 57.57225913386191, 58.86929281296269, 64.0745682870188, 58.02116263297297, 64.04160468809067, 64.1896741620956, 62.41151079054802, 61.321189941898474, 67.25425335668749, 65.16232782794584, 65.50278171416252, 8.542646688799705, 0.80587865364167, 1.1639965662071783, 0.15053195638522027, 4.7471019433390715, 66.23072654970231, 65.06749276191958, 75.97660833789458, 52.00281904589746, 47.08923455207579, 42.453298953271684, 43.31821687759892, 61.81584004432925, 74.76563930511475, 22.052835956696544, 0.24506706834560443, 0.11221351011866525, 0.055434394162148244, 0.05221168443019833, 0.028511584293277516, 0.022394605874714833, 0.016770396276467273, 0.032008045968870004, 0.11126683994887338, 0.131386024877429, 0.13256010058666431, 0.27756677039207955, 0.2992774263745354, 0.1033556797812062, 0.29478147085155215, 0.1465390448368365, 0.5680618567332145, 10.418020121512875, 74.0277159598566, 68.13800258021202, 60.847551976480794, 52.33777376913255, 42.55763792222546, 57.94068736414756, 58.08467365080311, 64.9357678044227, 67.31333209622291, 67.53332999444777, 8.07337579227263, 0.47880700579093355, 1.5738411031423079, 0.5399112511546381, 47.1728124157075, 72.32682720307382, 65.16586972821143, 60.735462404066524, 61.87112585190804, 59.66624782931421, 59.741169021975615, 52.45595478242444, 51.951094750435125, 48.45801622636857, 47.237566824882265, 45.47203348528954, 46.46210639707504, 45.96933903232698, 44.73610662644909, 43.01458620255993, 43.53922282495807, 42.254709351447325, 44.589464895186886, 42.47284804621051, 44.69105428264987, 45.33348360369283, 44.632979669878566, 44.326497431724306, 43.766179007868615, 41.75651734875095, 43.283394075209095, 41.20679716910086, 42.09332343070738, 43.9346291172889, 43.3226256216726, 42.90179452588482, 43.6700770162767, 43.782813779769405, 43.68057327885782, 40.16761226038779, 41.80322101039272, 40.407692693894916, 40.431728978310865, 41.05477786833241, 40.80811177530597, 41.54157146330803, 44.10400882844002, 39.94083650650517, 43.74135040467785, 42.462088984827844, 43.50639258661578, 43.65090054850425, 42.70604079769504, 43.73573749296127, 42.96305802560622, 43.23854961702901, 45.09402682704311, 44.86001822256273, 44.71070535721318, 43.536606604053134, 43.084592665395434, 42.42630912411598, 40.41559626979213, 43.930914632735714, 44.249587597385535, 48.66453293831118, 53.41698254308393, 57.37888236199656, 57.85469724285988, 53.14417777522918, 59.03121217604607, 54.6688775862417, 53.362210565997714, 44.75586752737723, 45.38897337452058, 45.78951797177715, 44.21001872708721, 42.08453339915122, 45.62562957886727, 45.23654222488404, 46.45210043076546, 43.26721037587812, 45.27901757148005, 44.91707694145941, 44.55731714925459, 45.95871333153018, 44.146115472239835, 42.47972396112258, 44.25847961056618, 42.513287682687086, 43.46103822031329, 44.50938578574888, 40.90781842508624, 42.955550609096406, 43.2806170371271, 40.55111808161582, 43.47708463668824, 44.31001955463041, 43.0067414622153, 41.01896662865916, 43.00827903132285, 44.50276090252785, 44.9678716351909, 45.43605750606906, 44.79553053455968, 43.14469514354583, 45.35240903977425, 42.30376643519248, 45.79750391744798, 43.68072232892437, 45.55749800897414, 43.165213061917214, 45.674074772865545, 44.95086031575357, 46.889095614033366, 47.89038650451168, 45.96758573285995, 42.34291168951219, 46.1498974984692, 46.2278663727545, 48.59730743592786, 52.87458542854556, 60.74377782883183, 62.21902047434161, 67.58170850815313, 58.99057642106087, 68.83125797394784, 68.8154665116341, 65.02413095966463, 63.73786810905703, 71.0997921420682, 66.01691815160936, 70.99267221266224, 11.965795236249125, 1.370227435423482, 5.116283268697801, 0.29946232935593975, 5.522707008546399, 73.46845657594743, 71.30939575933641, 82.82782016261932, 60.645487154683764, 57.49535322189332, 51.777894650736165, 51.722091090294626, 72.48635784272226, 85.37509364466514, 30.029185548905406, 0.42977590774816854, 0.27317610599340936, 0.1229980209421727, 0.2755641859144934, 0.18194451838010745, 0.09882699698209764, 0.16146508826603814, 0.1452737433775779], [0.03600565746666924, 0.09933225495079834, 0.006052418273963756, 0.06294544192872221, 0.018973824109942205, 0.021163920098314845, 0.10869716654621786, 0.08104050381770057, 0.18996476946819216, 4.850118092952236, 55.09981662996354, 56.83740700444868, 49.22268229146158, 27.51351264215285, 15.027951386667068, 18.048537277406265, 33.51673549221408, 56.085065026437086, 52.10679323442521, 58.316419047694055, 7.866130009774239, 0.18382630611379303, 0.2356860305993788, 0.24318739501458986, 33.76173850028746, 67.54442245729508, 56.478447375759, 53.24875993113364, 50.74373429821384, 50.606674917282604, 47.64060212719826, 43.39695061406782, 43.759738476045676, 40.32032974304692, 41.966160189720895, 42.68667213378414, 42.2315046095079, 40.24601651776222, 42.283166147047474, 39.976753650173066, 42.87511848634289, 41.67439076208299, 41.427144158271055, 41.79381908908967, 39.924997975749356, 39.6660509417134, 38.95428980550459, 38.96548424997638, 40.60355232607934, 39.07059200348393, 41.05368352705433, 38.620853039526175, 39.58306927834788, 37.88513014393468, 38.872284812311975, 36.932888492461174, 36.45044872837682, 36.27789189738613, 37.41967816506663, 36.851342416578724, 36.186422224967714, 37.7469293532833, 38.57172535311791, 37.97337955044162, 37.19480476071758, 35.714490490574995, 38.259708650650516, 38.79689685760006, 38.64253982420891, 38.07725960208524, 39.33087264337848, 40.37303463105233, 39.77435934928156, 39.59036880923856, 39.04861104103827, 38.924664143593084, 39.411140026584754, 40.1544487860895, 40.695033765608265, 41.46221014761156, 37.095674699352635, 38.02950474523729, 37.93567380597515, 39.05851894809354, 38.8735282036566, 42.04858487652194, 49.38877113403813, 54.38956560627107, 51.213881354178156, 50.70551080088462, 53.41187561711958, 50.31029278232206, 45.79679789081697, 41.25261829745385, 41.17790106804141, 39.13584847604075, 40.100394602744814, 39.29686569398449, 40.25765811243365, 39.09243568297356, 39.21654339759581, 39.1290117848304, 40.011305809020996, 40.05790356666812, 39.407233345893125, 40.25840728513656, 40.1362136871584, 41.48283004760742, 40.58251665484521, 39.568631033743586, 40.54312429120464, 39.44932822258242, 38.84025473748484, 36.832832751735566, 39.6041912417258, 39.96981105496807, 39.554757610444106, 38.72845149809314, 36.40644365741361, 39.50586918861636, 39.94981873419977, 38.36289052040347, 38.62867424564977, 39.42680597305298, 39.35459513818064, 38.259904769159135, 38.35046445169757, 40.46735194421584, 38.77384508809736, 40.085148349885024, 41.99268717919627, 41.48361452164189, 42.04104215868058, 42.84476326357934, 43.469624288620494, 42.87798573893886, 43.29885998079854, 43.19036722183228, 44.09423820434078, 44.53059796364077, 43.19306189014066, 51.54120314505793, 59.328112063869355, 61.34950160980225, 60.51317384166103, 60.08998932376985, 59.460947052125015, 61.109550614510816, 60.97568404289984, 66.21682566981163, 62.42305040359498, 67.27451632099768, 59.987125166000865, 1.863749488707512, 1.8251550822488725, 1.1105681234790434, 0.04646218689759413, 4.040351389877258, 59.51961394279235, 63.098282506389005, 65.13833468960178, 58.43996978575184, 43.47963809967042, 29.23461533361866, 29.644471637664306, 47.03923609948928, 58.634735076658195, 14.185570420757418, 0.18851939138145218, 0.06790946568212203, 0.10174437471094633, 0.029426059618051496, 0.009955578791578452, 0.02882343953505399, 0.04288372891624609, 0.09409808178221989, 0.030747455950345726, 0.030397786608626767, 0.06488425341705162, 0.06708099521816739, 0.03194464836269617, 0.014939523703839271, 0.06234030524689344, 0.05953881363835066, 0.21281082904146564, 4.922275975827248, 62.90541956501623, 63.28655235229, 55.421819686889656, 34.95848501882246, 18.258229148003366, 32.36333900882352, 42.346379064744525, 60.60844036840624, 57.30165089330366, 63.081714414781146, 8.824417014275829, 0.446329566259538, 0.48261764970037246, 0.3611370957186145, 36.29558963160361, 71.16903766509026, 58.85934960457587, 56.82344336663523, 54.19294111190304, 53.141302677892874, 49.7721435946803, 46.4970939390121, 45.0019609543585, 43.29687918386152, 44.12073381485478, 44.432366125045284, 42.651649290515536, 41.04725083997173, 43.424124794621626, 43.50056394453972, 44.97463772373815, 43.134979432629, 42.44963153716057, 43.49468823402159, 42.89225139925557, 41.21423398294757, 41.34650414989841, 40.72598911100819, 42.17000968994633, 40.89405090578141, 41.53144390352311, 39.54090379899548, 40.865554886479536, 39.27882279119184, 41.68408686114896, 39.91929877188898, 37.83020519441174, 38.76181910114904, 39.137138935827444, 39.07601664143224, 38.36988018405053, 39.622136085264145, 39.70454900495468, 40.268048471020116, 39.33678757759833, 38.695746775596376, 40.334422819076046, 40.059900053085826, 41.139555977236846, 40.51100400186355, 41.21615202196183, 41.137990951538086, 42.502022635552194, 41.87400410252233, 40.19404119060886, 40.165035263184585, 40.95723636688725, 42.5503501584453, 42.723232546160304, 43.18917874367007, 40.5016020805605, 40.323157771941155, 39.48850485586351, 41.78582137630832, 42.45496203822475, 43.298102963355284, 51.84155471863286, 55.62635952426542, 53.54283571243287, 53.52513405584521, 56.12695593987742, 53.511805841999674, 46.90901733213856, 42.21972965425061, 42.35972689044091, 40.1561628618548, 42.51351518015708, 41.87456500145697, 42.61255110463789, 41.03887265728366, 40.88854782042965, 40.730189969462735, 42.581583992127456, 41.19313555379068, 41.499594257723906, 42.73669019822152, 42.49353854886947, 42.76394674854894, 41.90074289998701, 40.00457894417548, 42.10319211406093, 40.55698202502343, 42.41735827538275, 39.06264920388499, 41.93166686642555, 42.450643508665024, 41.95547957574168, 41.344601800364835, 39.20320341663976, 41.307625616750414, 41.95311830889794, 41.309018058161584, 39.622830344784646, 41.95616206815166, 41.224867528484715, 39.711048372330204, 42.19950199127197, 42.31323503678845, 40.695677034316525, 41.865394499994096, 44.795965917648815, 42.63559895177042, 44.10549540673533, 42.728386540566724, 45.998866634984175, 44.27993105303857, 45.7616691435537, 46.38073290548017, 45.5207218662385, 46.55750628440611, 44.98120769377678, 54.75903326465238, 60.843166766628144, 62.56348694524458, 63.878845937790416, 62.05723839421427, 62.25439633092573, 63.772181003324455, 63.36210504654915, 67.9205620673395, 65.64131590627855, 68.78216558887114, 61.95881828185051, 2.303876194261736, 2.227773142437781, 1.291928591747438, 0.06325397234890731, 3.7464908486412423, 65.54379401668426, 66.95444307019635, 72.17906367394232, 57.94991670116302, 46.885012426683986, 37.250584786938084, 34.3137611112287, 56.62025282459875, 66.7265925868865, 21.2162983417511, 0.18574264441286364, 0.04919659601704729, 0.042699385179026474, 0.04400978240394785, 0.08229817504123335, 0.051143256076160944, 0.04119243660581209, 0.09707191253020879, 0.168984777504398, 0.18819597970333793, 0.10270510259414874, 0.19143740496327802, 0.1819964897848906, 0.09614139915474, 0.17948759779814752, 0.1753926280164911, 0.3479146326501524, 6.372972919094948, 73.66726583050144, 69.32708478743031, 63.56287548618933, 39.446798293821274, 23.30033402289114, 26.74547726108182, 46.15523192190355, 68.47716208427184, 62.30292389469763, 70.48456838054042, 10.937354680030577, 0.5426454495999121, 1.1868790609221305, 0.5335861228166089, 38.278853739461596, 71.60490712811871, 61.23282286428637, 58.78999817755915, 54.94663630762408, 54.47409268348448, 51.54631791576263, 48.35643076127576, 47.65286737872709, 44.518011077757805, 45.36994987918485, 46.49662325459142, 45.64684567912933, 42.92341070790445, 45.88955802302207, 45.87089146337202, 47.271424724209695, 45.41457860700546, 45.949287876006096, 45.56096146183629, 44.12679779914118, 43.72550010681153, 43.23632955551148, 42.23471703067903, 44.06851137838056, 42.40327696646414, 44.912330873550914, 40.801930119914395, 42.5142212067881, 42.31424700829291, 44.867086333613244, 42.95703718739171, 41.50331266464726, 40.578774713700824, 40.48827386671498, 42.000551531391764, 39.06666178857127, 41.82800646751158, 43.18032595419115, 41.925442064962084, 41.21541069399926, 40.13520171565395, 42.4983944431428, 41.422762870788574, 42.10322741539248, 42.90596400537799, 41.68467913904498, 42.88430467728646, 44.98607143279045, 42.259416195654104, 42.3113719109566, 42.13737164774249, 43.300330869613155, 45.48949979966687, 44.3270936319905, 45.90088975044989, 42.70616239117038, 41.54506237276139, 42.43148273037326, 43.9120166532455, 44.23203499086442, 46.04609589422903, 53.51569683321061, 58.03896234881494, 55.55701594198904, 55.04066336539484, 58.474820044732866, 55.66116663717455, 51.6903434261199, 45.984993211684696, 45.65057977553337, 43.02512168884278, 46.27366396688646, 43.673046250497144, 44.291321616018976, 43.94826327600787, 43.67376796660885, 43.45253844414988, 44.64930065216557, 45.33616258252052, 43.36174341940111, 44.682491748563706, 44.124146276904696, 46.35404902119791, 43.36172380755025, 43.5802782735517, 44.53746603381249, 42.99017729297761, 43.78164883582823, 39.61382458286901, 46.44384384155274, 44.468604903067316, 43.90539177002446, 42.06237593004781, 40.199034367838216, 44.3296863186744, 44.37128697672198, 44.18547253454886, 42.10249785454043, 44.78676403722456, 43.180879008385446, 42.25725104731899, 43.39560916346889, 46.07556858370381, 42.40281020441363, 44.07375558730095, 47.721779500284505, 45.99063750236265, 45.70821116047521, 46.79003615533152, 47.91579954085812, 46.8218897235009, 48.04602615294918, 47.868276103850334, 47.805251459921564, 50.082434454271876, 47.02066367672336, 57.26063859078192, 64.44720914286953, 65.25646078971126, 64.92256510642268, 65.14805824525895, 64.53523105190646, 66.32764047191989, 66.34921350786763, 70.70571945559594, 67.65163652358517, 71.77986837202504, 66.40647226764311, 3.3820646616720387, 3.2047534277362213, 3.1139745827644103, 0.26621978249280687, 5.207794126003019, 72.42354500678279, 74.50589210756364, 77.51806059191304, 74.63817011925482, 52.979987359816036, 41.34008322992633, 44.768383810597086, 64.56331522234025, 78.5111576511014, 28.084462650360603, 0.3097180403288334, 0.27333750539729673, 0.23833560697253675, 0.10001641743245626, 0.101228337885151, 0.10053634598490693, 0.10352276355749178, 0.24797650174267832], [0.008472467044128046, 0.05561282753103203, 0.02325679569865667, 0.040701270824478525, 0.09024327290394614, 0.040695823939336885, 0.11039819583416947, 0.017251078144557053, 0.050329241691337484, 0.6972625851631166, 41.19729326617333, 57.313869076390425, 46.49594076218144, 36.1605110476094, 39.25830487282046, 35.072712282980646, 32.275562247922345, 44.900995223752915, 51.686154334775864, 62.36652512704173, 11.247683782731334, 0.3284193803706477, 0.35270850444512986, 0.6686982921054286, 24.14167065774241, 69.45833513813635, 53.23692221795359, 56.016964835505334, 47.597785534397254, 46.484793386151715, 48.111557191418065, 45.533783358912316, 46.178291536146595, 45.606429576873786, 43.32360229184551, 43.444666247214045, 41.02710946913689, 40.29850567540815, 39.67901829750308, 39.50335102696573, 40.50581470612557, 39.92131879252773, 38.43856873050813, 40.00527712606615, 38.146607106731786, 39.79504592957036, 39.14905901878111, 39.49267041298651, 39.19034588721491, 39.06346505688083, 36.80201861166185, 37.86070946724185, 37.63327475517027, 36.87822634173978, 34.66751575469971, 37.05836903664374, 36.04554637785881, 36.52125535472747, 37.983087416618105, 36.19664392163677, 36.72785051407353, 36.56310312209591, 37.80177977777297, 37.63106646076326, 36.70059788611628, 35.37025936188237, 37.49414044041788, 36.80483879581575, 39.31739145709623, 38.197397878093106, 38.66189672100929, 39.46411555813205, 40.47851893209642, 39.13404026339131, 39.03424732146725, 38.73320148837182, 38.05676129556472, 37.68051970389582, 40.698006922198886, 39.0055630283971, 40.281494355970814, 38.45515251159668, 38.79046024814729, 38.440451468190844, 37.91150416097334, 39.97757734790925, 49.528870351852916, 52.36089614129836, 56.30196425222582, 57.72444709654778, 53.15142239293745, 50.25298695410452, 43.74428825993692, 41.38850488970357, 40.818243257461056, 39.56504990977626, 37.54982240738408, 38.65251048918694, 39.37081413884317, 40.126882368518466, 39.38688408943915, 40.379310423328036, 40.57808437655049, 40.129596648677705, 40.525877629556966, 41.10859670946675, 41.17943471477878, 41.40200961020685, 41.87314510345459, 38.7527427365703, 41.05645272039598, 40.597139250847604, 38.39077072758829, 38.20867469233852, 38.67461696747811, 40.06470495654691, 38.965095935329316, 38.574926007178526, 38.12388873869373, 37.552446473029356, 37.23786061809909, 38.553925637275945, 39.03515338897705, 37.7073997066867, 38.77951291299636, 39.39041030022406, 38.88263986956689, 39.270797621819284, 40.076734865865404, 38.783949113661244, 37.77634712957567, 41.66167836035452, 41.446093128573516, 42.17643453228859, 42.49671566870905, 43.74499036419777, 43.75604752571353, 43.350266564276914, 43.563541520026426, 41.74158488550494, 43.57049195997177, 54.4875071894738, 58.18081094372658, 61.115167448597575, 57.59374587766586, 60.69762329901419, 57.83522267495432, 60.892157170080374, 60.24646443705405, 62.82947071136967, 63.26081375921927, 70.58127833950904, 52.73023043909381, 0.7634736032735917, 1.750274339029866, 0.23805892665780362, 0.14169154688715935, 2.5590793259682196, 56.876418898182536, 64.32082253117716, 63.929911275063795, 55.28914159344089, 31.849343776702884, 42.84895235492338, 45.89897171143563, 44.364379682848536, 61.99681820407991, 15.379785049346188, 0.22072653977140305, 0.02501865428301596, 0.036242141148015376, 0.0584703010146416, 0.07276309999607264, 0.07673642267623255, 0.02305517859396435, 0.1424855663771591, 0.05839640034302589, 0.04628901272231052, 0.018925259881202253, 0.026029193203055093, 0.05910844076424838, 0.05696819794754829, 0.07443255880066464, 0.0009157686368017759, 0.015026787821684155, 1.2214440900471903, 47.313119519141416, 64.35828901106312, 52.663879625258915, 39.078660318928385, 27.610512856514227, 28.695363959958478, 37.82423142463931, 52.61264562606812, 60.241643844112275, 64.65132536426668, 12.453121292975641, 0.28440735332908174, 0.3581469932631139, 0.8123455388892082, 26.392648296971476, 70.50851837281259, 55.97659187932169, 57.67739434396067, 49.157088495069935, 48.06366112924392, 48.61202024644422, 47.675801477124615, 47.687850998293975, 46.74662336226433, 45.17582785698676, 45.08313440507458, 43.11858000293855, 41.24815856256793, 41.92915654951527, 41.31378766029112, 41.237646610506125, 41.969655021544426, 41.70478913091844, 42.462834235160585, 39.81567367430657, 41.959296041919345, 42.37068599270236, 42.728186499687936, 41.81782007217407, 40.19614358102122, 40.48532424434539, 38.6129573083693, 39.54491638368176, 39.89874555218605, 37.25695079372775, 37.99544680503107, 38.47051251319147, 37.90622072835123, 38.60898394738474, 37.208564435282064, 38.933987617492676, 38.994654916947894, 41.03316560868294, 38.96489589445053, 38.00613134138046, 38.239155430947584, 39.16959654900336, 39.93509807894307, 41.97879414404593, 40.174111627763324, 41.12718089934319, 42.29619233838974, 41.61265265557074, 40.99751126381659, 40.80539357277655, 41.46622665466801, 42.14532229208177, 41.145282637688425, 41.89823258307673, 40.54110819293607, 41.113829151276626, 40.43352542384979, 41.34547256654309, 41.37869504190261, 40.17872041271579, 42.78646507570821, 51.04444672984462, 55.30533705988238, 57.36401265667331, 59.8247782645687, 55.163064848992136, 54.14237783801172, 44.74444950780561, 41.93388300557291, 42.683118466408025, 42.51368776444466, 39.52421803628245, 41.35234455908499, 40.892583939336966, 41.8271396237035, 41.06195972811791, 42.786661194216826, 41.680607718806115, 43.401645691164084, 42.16429479660527, 42.896005107510476, 44.68935981873543, 43.04678493930448, 41.97200059890747, 41.63244101309007, 41.99555050942206, 41.700219569667695, 39.41924756573093, 39.46284863256639, 41.17658707403368, 41.14302727483934, 41.32790819291146, 40.838741563981586, 39.972599860160585, 38.8244201290992, 39.269565997585175, 42.24516230244791, 42.47553094740837, 40.06242213710662, 40.826264504463445, 41.15418249560941, 41.57013808527301, 40.62344266522316, 42.53866934007214, 42.202988978355165, 42.00856101128363, 43.58943700790406, 44.13310497037826, 44.40733748097574, 44.95444928446124, 45.34935743578019, 45.75036487271709, 46.78051656292331, 45.30384617467081, 44.15745896677817, 46.242896895254816, 55.778425893475934, 62.0102797785113, 61.98271336094026, 59.972934030717425, 62.90852215982253, 62.11098271031534, 64.04022793616018, 63.08611139174431, 64.6840928446862, 65.76359579640051, 72.70650479101366, 55.8972893991778, 1.010381167213763, 2.180602473597373, 0.34873869810854236, 0.11309897752418635, 2.998416654525265, 61.48885949965447, 67.84056925004529, 69.92467357266334, 61.20617428133565, 36.97288490110828, 43.691053851958245, 49.912556602108864, 52.45299339294434, 72.49665798679476, 20.824951702548613, 0.10580529188436848, 0.0725624845513413, 0.024776769681803645, 0.07263114135111533, 0.024050194657437747, 0.07795060308830393, 0.01721385776275589, 0.055379480979735815, 0.10174416786720676, 0.1361238956451416, 0.09529946852595576, 0.12261091671403378, 0.19374798742994187, 0.14804704295050714, 0.2536031111113487, 0.13285951839099008, 0.07480734433498114, 1.2842836471334582, 56.36451036699357, 73.9471269422962, 58.821847823358354, 49.766715034361816, 48.27521024211761, 44.980183955161806, 43.85090220359064, 60.163004244527514, 64.70797223429527, 71.91340154217136, 14.76978196251777, 0.5801879866949974, 2.0324319985605057, 1.0803663634484815, 29.269016481214955, 72.88687890575778, 58.781321894737985, 59.65577902332429, 51.76688455766248, 48.74182324255667, 53.23784397494409, 48.21543332069151, 49.02853281267228, 50.247597617487756, 47.855952016768924, 47.73555486432968, 44.99916822679582, 43.794204342749815, 43.03176226154451, 43.40252430208268, 43.82767784980036, 42.703691297961825, 43.18545249200637, 45.30095538785381, 42.906791625484345, 43.642416461821526, 43.444897667054214, 44.17980078727969, 43.318762087052875, 41.70352220535278, 42.144730014185754, 40.88633952602264, 42.029396641638975, 43.045086553019864, 39.82816250093522, 40.662493782658736, 42.98333667939709, 39.61450315290882, 40.81390511605048, 38.5768283567121, 40.32833137819844, 41.48741529833886, 42.623804384662265, 40.68352553152269, 41.17533191557854, 40.4527215034731, 39.907578729814105, 42.819452208857385, 43.01564524250646, 41.98934924217963, 42.86010757569344, 42.606545955904075, 44.38756481293709, 41.98044546188847, 44.10843718436457, 44.677282840974875, 43.782562748078384, 42.62547531435567, 45.99947067999071, 42.48175967124201, 44.8219947661123, 43.21869850158692, 43.928129749913374, 43.04557684929141, 42.27998510483773, 45.71232572678597, 54.423984404533144, 57.26292533259238, 60.34049149482482, 62.44485093701271, 58.51314552368657, 55.49614467928487, 47.55819312987789, 45.34274431966966, 45.026114909879624, 44.4045800547446, 42.317981104696955, 43.89893554872082, 43.13437930999264, 44.029001343634825, 43.20294234060472, 44.69668680621732, 45.05419908031341, 44.96877378033054, 44.80867047463694, 44.3085329763351, 45.4797762440097, 44.01522597958965, 44.72284117052632, 44.14127134507702, 44.54214934379824, 44.96987596634896, 41.899166107177734, 40.8865003431997, 43.87326363594302, 43.836758136749275, 42.23838052441997, 45.25900956123106, 42.151856960788855, 41.901546985872336, 41.34619820502497, 44.184017335214925, 45.30176731847948, 42.89136494359663, 44.41789650147961, 43.999246243507635, 45.05199470827657, 44.32305359071301, 44.71109759423041, 44.00344317959201, 44.05573229635916, 46.93920781535488, 45.36020671167682, 46.03092024403234, 47.1935539091787, 47.486911896736395, 48.89562329938335, 49.8954511457874, 48.98098976381364, 46.21675037568616, 48.35650136393886, 58.06658367956839, 65.08190747230285, 65.84543997241606, 62.890812658494525, 64.79517044559603, 64.30812581892937, 64.90842888432165, 67.84068692115046, 66.78706769020327, 68.2878920339769, 74.65251814934516, 60.598293196770456, 1.8407167181853326, 3.994763887697651, 1.7698477016341303, 0.17253648369543015, 3.479885631991971, 70.37900170972271, 74.87385749816895, 75.57690312785488, 71.15601539611816, 45.76374015500469, 54.69934263537007, 62.79629530445222, 60.7676846750321, 81.77884501795616, 29.297210478013564, 0.3107634439103065, 0.16511298445684297, 0.14944268660920282, 0.16534481798448872, 0.20644790192525234, 0.13531417135269413, 0.12166807698386332, 0.1898123486147773], [0.01420245327491073, 0.008101697725754592, 0.10363539380411949, 0.0420025056378255, 0.07164972909395734, 0.06453101027516589, 0.08976744037241706, 0.06727345182650513, 0.04314978742190907, 0.018159761844623475, 30.186464748074933, 58.1035755526635, 46.08533920780305, 40.37828668471306, 19.151276350021362, 33.2352073730961, 32.68263170796056, 43.90812958440473, 53.065942179772165, 62.507420586001494, 13.696725426181672, 0.3223160498084561, 0.37511568756834157, 0.7370362767288763, 13.683596272622387, 66.98670848723381, 54.711317631506155, 57.23088741302491, 47.61646386115782, 49.62114411015665, 50.72061584841821, 50.02960012805078, 47.03004206380537, 47.74289754129226, 44.58932761223086, 47.35860724602976, 44.187331738010535, 44.04812289822487, 42.35540443851102, 39.57315352655227, 40.61936732261412, 39.72317241853283, 39.681626673667665, 38.50970483595325, 39.07252573197888, 38.756794544958304, 37.946323040992986, 37.1973386118489, 37.95606620850102, 37.67505976461595, 38.16507362550305, 37.68721911215013, 37.01773328165854, 36.2969938401253, 36.69259232859458, 36.51193580319805, 35.73270205528506, 36.80917301485616, 37.70558364929692, 35.32270846828338, 36.366074623600134, 36.78634874282345, 36.72233958398142, 38.076486895161295, 36.92305118806901, 37.87928581237793, 37.63100762521067, 37.384223861079064, 38.43719982331799, 38.84238850685858, 39.42054587025797, 40.47609098495976, 39.46686513962285, 38.45548591306133, 38.18884711111746, 37.943851947784424, 37.32618847200948, 38.84980178648426, 42.050683344564135, 37.01325393492176, 38.53075619666807, 37.489159030299035, 39.3199606095591, 39.56270041004304, 39.392649973592455, 39.80694247830299, 45.95060971475417, 52.87391862561626, 53.6030323274674, 55.00798609948928, 52.02894203124508, 52.027510366132184, 42.598163850845836, 41.35840854337139, 38.81162535759711, 39.82129835313366, 36.97193960989676, 37.79529609987813, 40.20567886291012, 40.24678530231599, 40.879032150391616, 39.39514067865188, 39.54956439233596, 38.202642087013494, 38.699316132453184, 40.83786295306298, 40.06876853204543, 39.98455132207563, 39.05932303397886, 40.43034830401021, 39.150114136357466, 41.41846003070955, 38.15737009048462, 39.9072100270179, 39.3810672144736, 38.240991100188225, 38.95014778260262, 37.51235592749811, 37.556157035212365, 37.38370610821632, 37.14113496964978, 38.06002862991826, 36.846686563184186, 38.35488104051159, 36.62402145324215, 37.38184298238447, 38.8016233136577, 38.462271613459436, 38.54480612662531, 37.787223862063506, 39.660520399770434, 40.08776849316013, 40.16893017676569, 41.22011753820604, 41.71940780455067, 41.71329282945202, 42.07177785135085, 42.45294986232635, 41.98313620782668, 43.08525946832473, 46.29043994411346, 55.1684973316808, 56.92702531814576, 59.14013247336111, 59.36588448862876, 59.59987348125827, 58.12705878288516, 58.24686365742838, 62.76957611883841, 65.82717741689375, 60.55893613446144, 68.4864345673592, 49.111985160458474, 0.5301457138792162, 0.1877125475796, 0.46411392969950555, 0.07044696339195775, 2.566560266479369, 58.847657019092196, 66.09539693401706, 65.75202872676235, 54.597682645243985, 31.742931835113037, 31.101341901286958, 50.66796195122504, 47.032615138638405, 68.14482750431185, 14.125072763812158, 0.21677475182279465, 0.037693739868700504, 0.059604187751369136, 0.061460043408817826, 0.017697843385019132, 0.05089278362931744, 0.015524856055215483, 0.05939821735204709, 0.0378460266567286, 0.04608462046411249, 0.04378980791736995, 0.048809419010555556, 0.08619029240141954, 0.04975695485970186, 0.027080547372480075, 0.07862455361793119, 0.05165267007185086, 0.057367502125881376, 35.69601612706339, 65.4510417292195, 51.22165941422986, 46.50008278508341, 23.322440501182314, 40.88641012868574, 41.86137407056747, 50.96850964330858, 56.300979737312566, 66.45298373314643, 15.47828458970593, 0.4416680438143592, 0.4391482274138159, 1.0102986748660765, 15.265526406226622, 68.26738588271603, 57.448276935085175, 57.43858868075956, 50.80195403868153, 49.63352311042048, 52.451883362185576, 52.297475337982185, 50.30730001388058, 49.90824591728949, 46.53573712994976, 47.8730417836097, 47.67142803438249, 44.842038077692834, 42.71370118664157, 40.78506000580327, 42.97902599457772, 41.41523976479807, 40.41299573836788, 41.41841688463765, 41.56997726809594, 40.75106090114963, 40.70127817892259, 39.128313602939734, 39.69728477539555, 39.336599303830056, 40.17658272097188, 40.89193282588836, 39.79549307977, 38.71389166001351, 39.48899907450522, 37.35232322446762, 38.59550668347267, 39.9220444310096, 39.68090495755596, 38.18670549700337, 38.63859784218573, 38.82470646212178, 39.036377168470814, 39.564300737073346, 39.02201737126997, 39.94561787574522, 39.486516214186146, 38.857446485950106, 39.911807044859856, 39.94501383073869, 39.848962829959014, 42.4449796061362, 40.56778815484817, 41.90881513780163, 39.899235848457586, 39.8671430157077, 40.261203935069425, 40.164858756526826, 43.33779342712895, 41.31726288026379, 41.011216025198664, 42.02211280022898, 40.10361094628611, 42.63973312993204, 42.330783720939394, 42.8382089830214, 47.82135671184909, 54.96145502213509, 55.79426442423175, 56.72269336638912, 53.948306806625865, 52.76591616292154, 46.399215113732126, 43.20933188161543, 41.90368467761625, 40.477455969779726, 39.68795345675561, 41.162270422904726, 43.012064118539136, 41.526607621100645, 42.42333988989554, 42.35862078205232, 41.88424933341242, 40.45460031878564, 41.52499160458965, 41.01808801774056, 42.54355269093668, 41.685400855156686, 41.86714779946112, 41.41365904961863, 40.90670054958713, 41.81501949987104, 41.79742374727803, 40.59363265191355, 40.365715488310784, 40.384162395231186, 40.79460705480268, 38.74758874216388, 38.56293532156175, 40.16758872616676, 40.42720256313201, 40.77175532617877, 38.94127145890267, 39.82828409441056, 38.12603035280782, 38.99474120909168, 40.00630086468112, 38.3958698088123, 39.95916181995023, 41.21608141929873, 41.90940741569766, 42.57166824033184, 41.34398991061796, 42.648942855096635, 43.238090699718846, 43.36845459476594, 43.877695914237734, 43.420598583836714, 44.657388579460886, 43.95393110090687, 47.85367704206898, 57.90955158971972, 59.82953217721755, 61.46723939526466, 61.47713945757959, 60.388116913457075, 61.53422955543765, 61.58477321747811, 65.38383976105722, 66.28242338857343, 63.37979885839648, 69.33171318423364, 53.36822748184205, 0.5468652457479508, 1.835607831035891, 0.6716743291866395, 0.014522638765253849, 2.6212055019793974, 64.60491588038784, 70.12079208127915, 71.75522804260254, 59.815611685476, 37.63098409098964, 37.803756652339814, 57.72067377644201, 54.67743227558752, 76.32129053915702, 20.16039433017854, 0.28272039707629915, 0.021859416850812493, 0.05429536314500917, 0.10615177813076204, 0.015062781505196568, 0.038316389320478324, 0.035800487629228064, 0.0382975205749033, 0.10804310365910492, 0.10211962755889663, 0.16222866342192696, 0.18322995263001612, 0.23692090304628496, 0.09615448393648672, 0.2635891284913786, 0.17534430319022748, 0.22803753133743043, 0.18631523384922938, 40.207698883548865, 73.64624192637783, 60.64265520341935, 54.94091749191285, 28.88449868848247, 43.95452730117306, 47.30707906907605, 58.64034798837478, 61.219376979335664, 74.10520630498087, 18.21618330094122, 0.614596733883504, 0.9039295729129546, 1.2597766782968276, 17.256508757991178, 72.05424601031889, 60.548412415289114, 59.73184947044619, 53.03500644622311, 52.78788535825668, 56.34130170268398, 55.624441485251154, 52.15013150245913, 53.439206692480276, 48.39638402385097, 52.55848553872878, 50.30508387473322, 47.59818561615483, 45.18153098321731, 42.61532814271989, 44.59862362953925, 44.81142005612774, 42.335827888980994, 43.82406142450149, 44.05828183697116, 42.09531991712509, 43.132386745945105, 41.26368330370995, 42.433773394553896, 42.34225665369342, 43.91242850211359, 43.76284107085198, 41.55351115811256, 40.502417933556345, 41.933945763495664, 41.08364651280065, 40.376694202423096, 42.69677615934803, 42.67152001780849, 39.77949373183712, 40.094334540828584, 39.60083761522847, 40.37777285422049, 42.40612068483907, 39.502060567179036, 42.76340938383534, 41.38589651353898, 40.02741106094853, 42.22182027755245, 41.7223927282518, 42.81059549700829, 43.02386260801747, 43.05092303983627, 43.60320452720889, 42.59761864139188, 42.61336695763373, 43.26792032487931, 42.10328625094506, 45.164582421702725, 42.667589802895826, 43.84183760612242, 44.97067220749394, 43.15155929134738, 44.42014401958835, 45.167755619172134, 45.90313726855863, 48.807777897004165, 57.45502341178156, 57.0229390359694, 61.256863071072495, 57.36110618037563, 56.25320919098393, 49.208004782276774, 47.259532097847234, 43.62063946262483, 43.18285196058212, 41.99223610662645, 43.06984063117735, 44.97211171734718, 45.651666272071104, 45.139518476301625, 44.180204791407434, 45.42936202018492, 41.63038176874961, 43.440422242687596, 43.9449292613614, 44.095716937895745, 43.83837023089009, 43.053892274056714, 44.947255657565215, 42.53019309812977, 45.70009577658869, 43.67449360509073, 42.64917035256663, 43.74759089562201, 42.57308029359387, 41.938989931537265, 39.721419119065814, 42.5025600002658, 42.152198206993845, 42.558877391199914, 42.30233477007958, 41.76276960680562, 43.3704157798521, 41.04869034982497, 40.964269176606216, 42.90348506742909, 41.56067340604721, 42.98596074504238, 43.33581263019193, 42.93507975916709, 44.73119189662319, 44.03790512392598, 45.617898587257635, 47.10129191798549, 46.445565762058386, 47.305631714482466, 45.5655231783467, 45.84880459693171, 46.5715915156949, 51.28313472194057, 59.735767918248335, 62.760562512182425, 63.602350219603515, 64.05360714081796, 63.431844788212935, 64.96157700015654, 64.7595396349507, 68.45121952795213, 69.54433702653455, 65.96692362139302, 70.78314704279747, 55.95918440049695, 0.8436811703347391, 3.253894597291947, 1.2021926069451918, 0.1263356974889194, 2.975882883033445, 70.16655829644972, 76.50007217161118, 77.78382470530849, 67.12832958467546, 44.43383701385991, 40.48295121039114, 68.17657516848656, 62.99532813410606, 86.86495104143697, 26.743922041308497, 0.4546413138028114, 0.12620767653589288, 0.16638894986000755, 0.19336886583797394, 0.10044007937634185, 0.11629112800883672, 0.11266442181001748, 0.15661492433038451], [0.10919526925370579, 0.03889067564159632, 0.0479750381782651, 0.02934221512517862, 0.01849952949992111, 0.014165423457480729, 0.036914214762228156, 0.026155693471551906, 0.08924640865335542, 0.06777170775157791, 14.48987280168841, 54.85616683959962, 51.811391692007746, 44.5112253773597, 22.242955200133785, 24.295300091466597, 29.256178563640965, 50.24117277514551, 56.94932791494555, 61.241691343245975, 18.70313379072374, 0.19182277783270807, 0.24788483166165892, 0.6182012694977945, 7.978372064328964, 64.95243787765503, 57.74558867177656, 58.5699845898536, 51.86983892994543, 53.391498904074396, 52.74648866345806, 53.95432372247019, 52.4607636082557, 51.82643398161858, 51.19857626576578, 52.084694600874386, 51.358255955480764, 51.32254277506183, 49.95290602407148, 44.044832029650294, 41.219497803718816, 40.60815326629147, 40.071137643629505, 40.49490659467636, 39.4116852360387, 37.740767309742594, 37.903577050855084, 38.337673602565644, 38.33281770829232, 38.86186307476413, 35.52092544494137, 36.96624040603638, 38.166811235489384, 37.24771361197195, 36.114434965195194, 37.38101536227811, 37.13702824807937, 37.1591817948126, 38.08443753950058, 37.019549339048325, 36.783877649614894, 36.42146633517358, 36.990719918281805, 37.74093597166, 38.03907140608757, 37.96367168426514, 37.40205495588241, 36.74439507146036, 38.71414269170454, 38.72506649263444, 39.86252638601488, 40.35447005302676, 38.574176834475615, 38.80489849275158, 39.88919850318663, 38.366126475795625, 39.55835442389212, 38.58541834738947, 39.44722975454023, 38.31351964704452, 37.72137903398083, 38.05231332778931, 38.424032426649525, 40.57538970824211, 39.95150535337387, 40.88963039459721, 43.61801539697955, 52.975696286847516, 53.96467877972511, 53.15667836896835, 51.41766025174049, 51.31284275362569, 43.24787309092861, 39.598566562898704, 38.97216796875, 40.25868969578897, 38.788291177442, 38.85859574041059, 39.58303005464616, 40.60888282714352, 38.19484441511093, 38.818818984493134, 39.100982527579035, 38.55615746590399, 40.642222973608206, 39.096381587366906, 39.33385756707961, 39.8935954801498, 40.886774909111764, 38.884369634812884, 38.22987902549006, 39.998683621806485, 39.135248353404386, 38.62319469451904, 38.06483745574951, 38.455230959000126, 38.91106920857584, 37.72484248684299, 38.60812887068718, 38.182081022570216, 38.99626308871854, 38.20197136171403, 37.57216815025576, 37.935685573085664, 37.960423961762466, 37.59099944945305, 37.75045948643839, 38.74558441100582, 39.00110329351118, 38.98906553945234, 40.63866538386191, 38.30890301735171, 39.850425874033284, 41.31055954963931, 41.08512524635562, 41.733269460739635, 43.09910935740317, 43.57244530031758, 42.21255956157562, 41.87665562475882, 45.46751099248087, 55.144057043137096, 57.55396912174841, 59.54819233186784, 56.43326167137393, 58.07196909381498, 55.34569040421517, 57.77855227070471, 59.676438147021884, 65.68324604342061, 63.366596160396455, 62.239016717480084, 43.59533625264322, 0.6720927970543985, 0.7092598284925185, 0.029089024981423735, 0.06889467773538444, 1.8647506736939954, 54.09390518742224, 65.19638576815206, 62.09106491458032, 60.451388666706706, 27.039096086255967, 26.17732390280693, 51.71199490947109, 42.480378996941354, 64.26630158578196, 10.478371670169215, 0.23991396260117334, 0.06298074709071268, 0.034955239839731686, 0.014252170465976722, 0.06292806705459952, 0.07311193813239375, 0.055911797173922105, 0.03375055508748178, 0.03928885750112034, 0.02507798204709205, 0.053984779609187, 0.08769097437541332, 0.047362374682580276, 0.0543548230592522, 0.06544673049281682, 0.050768842094487725, 0.08420660731292541, 0.08113892313333289, 18.45879758557966, 67.55229857660109, 58.06689746918217, 50.27078666994649, 23.591554318704915, 30.145022946019328, 37.81302913542717, 54.30526994889783, 59.83056376057287, 64.76718041204637, 19.67974905044802, 0.28880071435724536, 0.20253348374559035, 0.8654932870018868, 9.065180920785474, 68.24663654450448, 60.630382107150176, 60.53506066722255, 53.704029437034364, 53.92969123778805, 55.668744656347464, 56.31817933051818, 53.659706654087195, 54.159451915371804, 52.792851078894834, 53.70383724089592, 51.69850587844849, 52.698039547089614, 50.853435147193174, 46.67163548930999, 41.747962659405125, 42.68382057066887, 42.15504192536877, 42.32193093146048, 39.81705827097739, 39.3465111332555, 39.88062027961978, 39.78092539695002, 39.611027932936146, 40.62987927467593, 37.81919902370822, 39.679810616277884, 39.83372442183956, 39.2675655887973, 36.354986083122995, 39.12277913862659, 39.03073680016303, 39.20164231331118, 39.613200926011615, 39.075683239967596, 38.11221184269075, 36.663464807694965, 38.75515891659645, 41.030647447032315, 39.49270963668823, 39.482986081031065, 39.24900101077172, 38.41601902438749, 39.72843623930408, 41.61016195051132, 41.150915161255874, 42.196164054255334, 40.80855108076527, 41.27811762594408, 40.24079192069269, 39.97967189358127, 40.62290530050955, 41.03584066514046, 41.35978529530187, 40.142395342549975, 40.60723150930097, 40.841043995272734, 40.82847279887046, 41.628746140387754, 42.606616558567175, 43.576948181275405, 45.51936864852906, 55.55162268300211, 56.26720420775875, 53.94530227107387, 53.73653411865235, 52.88820782015401, 45.22191570651147, 42.76307990474086, 41.13264476099322, 42.63717182220952, 40.58521916789394, 41.20156080492082, 42.146404866249334, 42.92145736755864, 40.729938937771706, 39.678206366877404, 42.35590650189308, 41.860224816106985, 41.42355911193356, 41.32758655855733, 42.83349429407428, 42.03220898105253, 41.12383119521603, 39.991537063352524, 41.066356705081084, 41.339110482123594, 41.03178885675246, 40.9828023756704, 39.65584493452503, 39.658241502700314, 39.89671376443679, 40.03341620968234, 39.03081524756647, 41.324633013817575, 39.087811208540394, 41.01772715968471, 39.824789262587025, 39.95700843872563, 40.491913826234885, 39.740834851418775, 40.371453915872884, 41.092385553544574, 41.99440517733174, 41.607847752109656, 41.85283114833217, 41.00399101934126, 43.2964712573636, 42.855428188077866, 42.146863783559496, 43.48369775279876, 44.840414216441495, 44.67214453604914, 43.78710093036775, 44.453597914788034, 45.94693053153254, 56.85315139832036, 59.76661343728343, 61.56368263306157, 58.49346307016189, 60.15448093414307, 60.0002258823764, 62.46813412635558, 61.784770950194336, 68.79752559046592, 65.70027305233863, 64.5527522794662, 46.46028249494491, 0.8799327573468609, 1.6792913285955307, 0.5346622618456041, 0.04643491033705012, 2.2544212350922246, 59.94690125988376, 68.6433058400308, 68.73659549220916, 65.09928749453637, 31.38931251341297, 29.334182739257816, 56.695162250149636, 50.12714555186611, 73.14897952541229, 14.918524123007252, 0.3570751136829776, 0.07367041622919422, 0.0293283412728699, 0.0116836758811147, 0.015551867357815708, 0.02591905848784072, 0.036453520128082846, 0.053327342104767604, 0.13678591818578784, 0.10532372901516576, 0.2510925337311722, 0.20663542492735773, 0.26750202981695054, 0.10985578260114116, 0.22360624895701486, 0.13433149505046107, 0.24476601111312069, 0.2224218463825603, 22.176975050280173, 75.47438806103122, 62.89371521242204, 56.87751716183078, 30.88815716005141, 31.801598725780366, 40.87214446836903, 62.853299110166496, 65.83460638600012, 72.81501323946061, 22.847302229173724, 0.2628813245363774, 0.3777537879443938, 1.2489924892302484, 10.582917544149584, 70.7133759221723, 62.69766730646934, 63.72936441052345, 55.67620500441521, 58.026744165728175, 58.77406943228937, 59.36677486665788, 56.918243131329945, 56.53434507308468, 56.738767239355276, 58.10574462336879, 54.394943175777314, 55.869134626080914, 53.52069393281014, 47.850696040738015, 43.78627331026139, 44.46568273728894, 43.47054212324081, 43.93571953619681, 42.737815918460974, 40.45965233156758, 42.15340629700692, 43.116803169250495, 41.9520906479128, 43.879049131947184, 40.86720620432208, 40.65908524297899, 42.12912290327011, 41.55373081084221, 40.344103228661325, 42.49986925432759, 41.985791652433335, 42.67546592220184, 42.90137483227638, 41.3844766155366, 41.02947858072097, 38.212267583416356, 39.982052772275864, 41.500131622437515, 41.751367276714696, 41.60386654638475, 42.932820473947835, 40.10056326466222, 41.527246967438735, 43.13876059747512, 44.07782308516964, 44.148143337618926, 41.609812859565984, 42.71164978704145, 42.8889173846091, 43.06941309282857, 43.28701834524832, 43.76861479974563, 43.222762077085434, 42.534307664440526, 41.76760196685791, 43.99829310755576, 44.008997255756015, 44.60037692900627, 46.234342205908995, 45.843030868038056, 48.08156674908054, 57.594483283258256, 57.27930907280215, 55.110171687218454, 55.056027289359804, 57.14894910012522, 49.0456304242534, 44.128072569447184, 43.108746620916556, 44.91397434665311, 43.11175507883872, 43.76941888563095, 44.68950886880198, 45.11732962823684, 42.66556585988691, 41.75677622518232, 45.04392247046194, 43.406478051216375, 44.497187214512984, 43.13109628615841, 45.02422432745657, 43.92548607241723, 44.58722129944832, 42.543348727687714, 42.46211644141905, 43.5261260309527, 41.85550620478969, 42.875518568100475, 42.151892262120406, 42.07726916959209, 42.29554906968148, 42.16477724813646, 41.08153627764794, 43.156795655527425, 43.0131741492979, 43.724848993362926, 43.41178109568935, 43.103345517189275, 43.70384077872, 43.60212979778167, 43.289258018616714, 42.84320608262093, 45.592544386463786, 44.42257981146536, 42.93181634718373, 42.75554895401002, 45.6307404272018, 45.36115984762869, 45.32105753498693, 45.58673927860875, 48.34989609256868, 47.95970655256703, 46.33473919283959, 48.10614824295045, 49.62522337513585, 59.902123481996604, 62.986553792030584, 64.02007087584465, 60.169276114433046, 62.545263613424, 62.60416976867184, 65.10093881237891, 65.12416708853938, 72.05989422336702, 66.28924046793293, 65.60375921187863, 50.16837358474732, 1.4336216401669288, 3.573214262723923, 2.3665470894305938, 0.23881263460122773, 2.6373007028333606, 65.48877885264736, 75.76288623194542, 74.51490571421962, 73.712781013981, 40.01393379703645, 36.689285770539314, 68.00328485427364, 57.94630027586415, 83.96162832936933, 22.005283101912468, 0.7159135166195132, 0.15343619570616754, 0.14329169005636247, 0.08966673811477038, 0.18256521813811796, 0.1636900680680429, 0.10391771252597533, 0.12234674661510414], [0.004323293668999067, 0.025193151875188755, 0.009138553681212568, 0.034175661107104634, 0.09455388111452903, 0.03309239362997394, 0.05557141664828505, 0.038134615808244676, 0.0954079695586716, 0.04140630920207308, 6.397405853194575, 53.13474447496476, 46.16533594746744, 47.9773493736021, 37.01630161654565, 32.05414052932493, 35.437445640563965, 53.3860585766454, 54.38323097844278, 62.91431942293721, 24.309559868228053, 0.09061499408656552, 0.41161821434094065, 0.41978192305372614, 3.8197151259068525, 61.54661247807165, 56.9211966760697, 56.81171547982001, 56.46773146044824, 55.52954366130214, 54.92159589644402, 55.63173709377166, 54.05773308969314, 54.34247755235242, 52.72977544415382, 54.59449768066407, 54.2073989683582, 53.682813336772305, 51.79214069920202, 51.91467554338517, 40.26399274026194, 40.66940892127253, 39.79517929015621, 38.536435788677586, 37.617812771951, 37.63861702334496, 39.459079234830796, 39.68100693918044, 39.79714439761254, 39.960813137792776, 39.623097065956365, 38.02195810502575, 37.030657491376324, 35.63495266822077, 35.20465297083701, 35.20781832356607, 37.253718760705766, 39.19282874753399, 38.02020088318856, 36.48976264461395, 36.55166941304361, 37.77402508643366, 37.29677461808728, 36.70551261594219, 36.95645801482662, 38.75488042831421, 39.102374968990205, 37.91767404925439, 36.787392093289284, 39.391547787574034, 39.00566893239176, 41.10435662731048, 40.37099499856272, 38.545421938742365, 37.09619637458555, 37.19343193115727, 39.36445205442367, 38.40525604063465, 37.72248121999925, 39.45284658862699, 37.436618881840865, 37.839301170841345, 37.456960293554495, 39.54436332948747, 39.732954809742594, 38.75999127664874, 42.127149951073434, 52.256384588057, 53.18452327482162, 53.89258169358777, 52.15829003241755, 49.07196521759034, 40.35914944064233, 38.337363735322036, 40.38677077139578, 37.362168373600134, 37.87439853914323, 39.05917006154215, 39.55997828514346, 41.175767298667665, 39.75373160454535, 39.7717470507468, 38.68107318878174, 39.48807731751473, 40.68498857559697, 39.494113845209924, 39.71528060974614, 40.88198177276119, 40.29053934158818, 40.07635831832886, 40.43621224741782, 38.92158508300781, 38.68805108531829, 37.74187734050136, 38.34757366488057, 38.434069771920484, 39.796281476174634, 36.3577905777962, 37.67135704717329, 36.757687983974336, 36.8193829444147, 37.42256110714328, 36.92423966623122, 36.286207322151434, 35.37679795295962, 35.40281503431259, 38.27448029671946, 38.223050179020056, 36.86589833228819, 38.18834897010557, 40.02395153045654, 40.05568350515058, 42.31986776474984, 42.934922864360196, 41.784456391488355, 41.37627886187646, 40.7614512597361, 42.26442898473432, 42.745997982640425, 42.64975870809248, 45.67518480362431, 51.89514606229721, 54.43799903315883, 58.08748599021666, 57.17840217774915, 54.22618319911342, 54.96298474650229, 61.65701150894166, 61.397421206197436, 64.89824641135432, 59.97797427638885, 65.77751236577188, 42.67861950782038, 0.5927535446901476, 1.0158436192620186, 0.6613646856238765, 0.042109210194358905, 1.8745725337536105, 55.86286275617538, 62.65935751699633, 62.57125323818576, 57.38975124974405, 33.46186153350338, 24.6474975539792, 44.04744040581488, 46.6276696420485, 62.71814992350917, 9.676462700290065, 0.22605503368521893, 0.04201783122675073, 0.09588232354050684, 0.024574378828307795, 0.007908110658923585, 0.04280458820322829, 0.048542042833662806, 0.07931322069658388, 0.019029738952315623, 0.023735704073201747, 0.027685735765243732, 0.017946170785674648, 0.02195369163077445, 0.02951263329915462, 0.03355277799850991, 0.00313674389373421, 0.05852990648559025, 0.0756026202091767, 7.4494855538491285, 61.35697372498051, 50.53073390837639, 52.914048394849225, 36.3225676936488, 29.830217438359416, 40.80113780113959, 58.217041877008256, 59.32241678237916, 66.84930786009758, 26.120120056213874, 0.05717712544625806, 0.2628579128894114, 0.41257793864896225, 4.55978621398249, 63.59013595888692, 58.64821234057027, 58.197504551179954, 58.3125594354445, 57.1687178457937, 57.05519268589636, 59.237705353767645, 56.19657016569569, 57.71008729934693, 55.58040111295639, 57.11291820772233, 55.407918806998964, 55.468389987945564, 55.90203154471613, 53.22038942767728, 40.90822635158416, 40.6846434070218, 42.13351988023327, 39.333229987852036, 40.22383943680794, 41.15300578455771, 40.08657217025757, 40.832504995407604, 40.68210171115014, 40.89149352042906, 40.24678530231599, 40.2745125370641, 39.311068596378455, 39.31597548146402, 37.15009758549352, 39.12561501226118, 38.14857613655829, 40.03908403458134, 38.544727679221864, 38.33856005822459, 38.81173126159176, 38.8383053195092, 39.0920473683265, 38.932901120954945, 38.99233287380588, 41.04869034982497, 39.554333994465495, 40.981868851569395, 37.6637045029671, 40.82777853934996, 42.07011868876796, 42.20884115465226, 41.10389378763015, 40.683105837914255, 38.79093877730831, 40.09727631845782, 41.52185763082197, 40.85601175985029, 40.355207458619155, 42.37427496141003, 38.617252303707986, 40.56916882914882, 39.49645942257297, 42.75972627824353, 42.61599886801935, 40.45546324022355, 45.193941362442516, 53.777283622372536, 56.130278187413374, 55.05484273356777, 53.22775563886089, 51.2668215843939, 43.22611570358277, 41.49344005892354, 42.54691023980418, 39.190106622634396, 39.242466342064645, 40.313849987522254, 42.335078716278076, 41.78243244847944, 41.36095416161322, 41.00958824157715, 41.319247599570986, 40.575848625552275, 41.01537765995149, 42.02241482273225, 42.0376532308517, 43.308348194245376, 41.81828683422458, 42.55915195711198, 42.04203059596401, 41.70800155208957, 40.03174920235911, 40.713861142435384, 39.19433886005033, 40.26206293413716, 40.49734238655337, 40.21866975292083, 38.23471923028269, 37.66156681122319, 37.786564903874556, 37.86324331837316, 38.9939881140186, 38.51901262037216, 38.540111049529045, 38.10784624468896, 41.876914501190186, 41.46945868769, 39.94918723260203, 40.5527497876075, 41.91801309585571, 41.38333912818663, 43.13989808482509, 44.67861644683346, 44.08287117558141, 43.17096325658983, 43.80203731598393, 44.295997081264375, 45.662523392708074, 43.275227700510335, 48.31715606874036, 55.229419585197206, 56.4212356844256, 59.12225431011569, 58.83335605744393, 57.95685145162768, 58.77846640925254, 64.02316954828078, 63.35988498503163, 67.58265772173482, 61.97909693564139, 67.22562005442958, 44.98443972679877, 0.9049263452329944, 0.7467297404523819, 0.8392323445408576, 0.12655851416169636, 2.0862167641039817, 61.576332276867284, 67.96504958983391, 67.6316402804467, 63.39616690912555, 31.62896933094148, 26.29867026882787, 51.803248851530014, 52.17166923707532, 73.73916287575999, 12.370239650049518, 0.22250833770921155, 0.05981865406577146, 0.051195181515668674, 0.06662836748986475, 0.05560036328050399, 0.09369328858390932, 0.09407172835762463, 0.06098953518836249, 0.1128207573727254, 0.15010680823076158, 0.178091800921867, 0.08104562894591401, 0.172842244707769, 0.12274144277457269, 0.22562058522335945, 0.1489634986125654, 0.1988862617121589, 0.19808022996350644, 8.867641533574751, 71.75719707242905, 58.32908830335064, 62.43472337722779, 47.318701051896625, 43.02939314996043, 47.4632639269675, 65.63209833637362, 62.699710861329116, 73.62126427312052, 30.42143237206244, 0.20609430638292145, 0.5044236683076428, 0.9513797106281404, 5.905455322034898, 65.67505221213064, 61.04774582770563, 61.76561801664291, 61.00809458763369, 60.766711927229366, 57.26681240143315, 61.32717155641126, 57.67894368017874, 59.41075640340006, 58.14351312575802, 59.40929335932578, 59.438985701530214, 57.46586484293784, 55.088528048607614, 54.77764491112002, 42.68168680129513, 42.997821992443455, 44.9053333651635, 41.613448896715724, 43.325987092910275, 42.00606638385404, 41.87214489906065, 45.06524055234848, 43.019320503357925, 44.58474628386959, 43.516531913511216, 43.25019121170045, 42.264142651711744, 42.4925148102545, 39.75373552691552, 42.732752138568515, 41.324636936187744, 44.41702573530136, 42.97814346128895, 38.910563222823605, 39.88501725658294, 41.79579988602669, 39.972670462823686, 40.42812039775234, 41.086090149418006, 41.98760378745295, 43.24804959758636, 44.234631599918494, 39.4770162336288, 44.21192499899095, 43.764735575645204, 44.03705004722842, 43.676984310150154, 42.94687432627524, 41.53189105372275, 40.91091709752237, 43.9471257886579, 43.62894312027962, 42.88619525970952, 45.09550948296824, 42.34196639830067, 43.2394439174283, 40.28083932015204, 44.29867998246224, 44.577572268824426, 42.853164980488444, 46.98377378525273, 56.29300163638208, 57.409178749207534, 56.02261697092364, 56.346192898288855, 54.10463679221369, 45.58501735810311, 42.542670157647905, 44.72548484802247, 42.79242707837013, 43.858597893868726, 43.047475276454804, 44.72562213097849, 43.93356223260203, 45.405435562133796, 42.966635227203376, 42.435397255805235, 44.416492292957926, 44.25357664785078, 44.87097340245401, 44.058878037237356, 44.720534816865005, 43.969808855364406, 44.37028677232804, 44.226606430545935, 43.29489446455433, 43.40275964429302, 42.18302803654825, 40.96282182201263, 42.08314095774005, 43.25352130397674, 40.41171704569171, 39.22143851557086, 39.86857860319076, 40.87744359047183, 41.036401564075106, 40.268962383270264, 40.0332240135439, 40.8451860181747, 39.89006142462454, 43.25364681982225, 44.64629611661358, 43.14465984221428, 43.330191873735004, 44.5529515512528, 44.86093997955323, 48.427253077107096, 47.96704530715943, 46.78037143522694, 44.691246478788315, 45.48285922696514, 47.21916306403376, 48.06870529728551, 46.85935228101669, 51.814996350196104, 57.15577794659523, 58.58055145509782, 61.37771521845172, 60.707095822980335, 60.157065776086625, 61.96968324722783, 68.1478085056428, 65.98956354202764, 69.7604674677695, 64.99061430654218, 67.29051174656038, 47.84952325205649, 1.1686152796591482, 3.1918787379418654, 3.1254659016286177, 0.26561681000936416, 2.4721203792479733, 67.59364820295765, 73.84120725816297, 73.67474971279022, 70.40506193714758, 49.2787015822626, 34.49419798389558, 61.357397340959125, 61.4818698360074, 85.11993562021564, 19.63576751370584, 0.5702874953708341, 0.17580493653733886, 0.24150858993732163, 0.1295428326533687, 0.20175104750500572, 0.23365015194060343, 0.17043156519291863, 0.16938513505362696], [0.015399048138680238, 0.05791065080331699, 0.05733232336839842, 0.030559484786804647, 0.06366436948038398, 0.028982387457583702, 0.02453077501887756, 0.06885779826270957, 0.07044288014332134, 0.05821874838382487, 1.792865885842231, 47.852743517967966, 56.378411246884255, 53.49659096810126, 30.681238405166138, 24.160684347152714, 30.478671519987046, 45.64855583252446, 56.8419530314784, 58.63558230861541, 34.42116345128706, 0.12334313589118182, 0.18571046872004388, 0.26463992533183867, 2.4257540414410257, 53.13751759067659, 61.51050706063548, 58.8087784859442, 55.998706202353205, 58.15542536397135, 56.10810502882927, 53.07661887138121, 55.44174140499484, 55.84157213088005, 55.98497398437993, 54.67616535002186, 52.60722883286015, 56.152988710711085, 54.24708158739152, 51.47240084986533, 41.82040099174746, 39.40630374416229, 38.83147255066903, 37.190788253661125, 37.966382042054214, 40.77730155760243, 41.49606412456882, 42.70189877479307, 44.96882477114278, 45.60364077168126, 44.25782849711757, 39.613863806570734, 38.83117052816576, 34.50543949680944, 35.94909921769173, 34.84872925666071, 35.70742630189465, 36.33486432413901, 36.359998872203214, 35.96928373459847, 37.384470970399924, 35.924631472556825, 36.98637785450105, 37.03153217992475, 35.97762661595499, 37.466840744018555, 37.48408348329606, 37.133525571515484, 39.36087485282652, 38.54426091717136, 41.255971923951186, 38.752499549619614, 40.98637173252721, 39.01355681880828, 38.24131665691253, 38.44001608510172, 37.55844377702282, 38.579385742064446, 40.50199823994791, 38.30674963612711, 38.53091701384514, 38.37199826394358, 39.61699385796824, 40.268330881672526, 40.7612237622661, 41.33043027693226, 44.23016402029222, 52.01419391939717, 51.527247351984826, 54.090398588488185, 53.72473170680385, 49.40307601805657, 41.58789465504308, 39.731244656347464, 38.60445360983572, 36.673647280662294, 36.47852113170009, 36.888334289673836, 39.63004358353154, 40.02912513671383, 37.86959755805231, 40.86929682762393, 38.26944789578838, 38.71417407066592, 39.4405891818385, 39.233323297192975, 40.14203448449412, 40.67800283432007, 40.04479108318206, 40.973631874207534, 39.086438378980084, 38.868915496333955, 37.86727943728047, 37.44702100753784, 37.254416942596436, 38.715323325126406, 38.1857092149796, 37.74990250987392, 38.46235398323306, 37.83146427523705, 37.47857255320395, 37.086814065133375, 37.736448780182876, 36.89492387156333, 37.6349143059023, 37.228921536476385, 37.225426704652854, 38.664869877599905, 38.52520996524442, 40.172185744008715, 39.193068012114495, 38.90636628673923, 38.139723347079375, 42.47033380693005, 44.41733952491514, 44.94514542241251, 41.555076183811316, 40.06907447691887, 39.65438581282093, 40.87426647063225, 45.156212083755, 49.1937469667004, 51.51949674852433, 55.496007396328835, 51.890196031139745, 57.27679875589187, 56.17757020458099, 59.219466332466375, 60.54987938173356, 65.84212164725027, 60.605600572401485, 65.59025056900518, 41.279600281869214, 0.3731409274041653, 0.34903011795493866, 0.5126635261601018, 0.0525725424860514, 2.1407389352398534, 59.285397452692834, 62.65183441100582, 64.80875361350276, 50.96089632280412, 38.42653489881946, 36.98615427940123, 55.07736106072703, 52.96068929856824, 59.8547020266133, 6.336260024578341, 0.18997825261565948, 0.013287583414855744, 0.04678868974048284, 0.061590527334520896, 0.04552171820954931, 0.007886960407749059, 0.027314200358945998, 0.05232425722023172, 0.03072498084586715, 0.0221182837060863, 0.08316098922683347, 0.04159209318459035, 0.02181744672388079, 0.06261344240497678, 0.03225031744448408, 0.019166039400583795, 0.07915176766654176, 0.010314999474963595, 2.0705128196747076, 55.621319278593994, 62.47799888733895, 60.16477323347523, 35.36043774697089, 23.926365875428726, 34.99869715782904, 52.22808076489357, 60.92153964504119, 64.68823486758818, 36.387149518535985, 0.06684930724722725, 0.16504031335634572, 0.6349758371230095, 2.876077928850728, 56.022220811536236, 61.67096337964458, 60.300808875791496, 57.54312376822195, 60.37684402158184, 56.986637500024614, 55.784231001330966, 56.69966120873728, 57.70223079189178, 56.23043198739329, 56.66892551606702, 54.29758602573026, 58.27058222986037, 56.68488564029817, 55.696499347686775, 43.96774961102394, 40.934769030540224, 40.1746529148471, 38.94122831283077, 39.8095194755062, 42.780424625642844, 44.069652788100704, 44.28928198352937, 47.55169376250237, 46.783285756264966, 45.99827043471798, 42.585012143658055, 38.88805666277486, 37.24361473514188, 37.39663816267444, 38.00486049344463, 37.654333960625436, 38.268569284869784, 37.93950203926333, 37.94069051742554, 37.73815501120783, 37.483828529234856, 39.06820720241916, 38.743670294361735, 37.301622667620265, 38.260885361702215, 41.1075415918904, 39.431928588498025, 39.294237705969046, 40.14081462737053, 41.32944183964884, 40.61203641276206, 42.59560646549348, 41.046921360877256, 39.48617889035133, 39.74114864103256, 41.46170023948916, 40.14668249314831, 40.83872195213072, 40.66570620382986, 40.7133355448323, 41.164161005327784, 40.96962713426159, 42.913424353445734, 42.37411414423297, 44.24344908806586, 46.312554267144975, 53.46837735945179, 55.037698053544574, 56.77748887769638, 54.930103517347774, 52.581050934330115, 43.373569365470644, 42.646522752700314, 41.3365452520309, 39.06885047112742, 39.846750613181825, 39.24691038746988, 41.83658076870827, 41.82680229986868, 40.97827596049155, 42.11824617078228, 42.15450456065517, 40.97109017833587, 43.40415600807437, 42.34293130136306, 40.29241031216037, 41.1889386177063, 41.62405106329149, 43.67799235928444, 39.96846960436913, 39.54788954027238, 41.207146260046194, 40.00018981195266, 39.60772137488089, 40.825601623904326, 40.99758578884987, 41.084485900017526, 40.80800194894114, 39.74813045993928, 39.32036069131667, 38.268071143857895, 40.42002854808685, 37.638699393118586, 39.19234629600279, 40.58769810584284, 39.70427836141279, 40.370383108815844, 40.59254223300565, 41.829453822105165, 40.47581249667753, 41.69016653491605, 41.39379616706602, 43.50378028808102, 46.43958806991578, 45.14273481984293, 43.78838746778427, 43.33308658292217, 42.51275031797348, 42.88446549446353, 46.00016101714104, 52.054637478243926, 55.09320351385302, 56.85686588287354, 55.428558318845695, 57.83237503420923, 58.89353698299777, 63.16104827388641, 63.627363174192375, 66.33754053423482, 64.26706644796556, 66.72199556904455, 44.03177053697648, 0.48303856904948916, 0.969325902481233, 0.8825029516893049, 0.18352999862643982, 2.2662359043475124, 63.95521448504541, 66.89116739457654, 70.74802614027455, 56.40793884954145, 39.61870401136337, 39.97954637773576, 60.82188006370299, 59.03404020494031, 70.04929511777817, 9.506676043233565, 0.3073711759380756, 0.08590591290304739, 0.07979682135966518, 0.016591026365096052, 0.09050461613843519, 0.029329396558985598, 0.03742948166965958, 0.03145183932276503, 0.09965397357459992, 0.15865628817869773, 0.1492606334748768, 0.12905601442100542, 0.28227514677470733, 0.11436425600080721, 0.1231460827552984, 0.16415667690096364, 0.18556380884781962, 0.20245586371710225, 2.839042174239313, 64.91279055995327, 71.52369837607108, 70.3247239512782, 43.084110213864236, 34.233933033481726, 42.03697858318206, 57.66420341307118, 66.98808916153448, 68.34523708589616, 41.9697295465777, 0.15479774845223274, 0.9973307062060603, 1.6878485919967776, 3.5890831918485704, 60.66317704416091, 64.04979851938063, 63.173403739929206, 59.167636133009395, 62.497716642195186, 58.55531884777931, 59.64419626420545, 58.63415848824286, 59.317200030049975, 58.37102628523304, 57.535220192324736, 56.11691074986612, 61.138030944332, 58.30360858671127, 56.25695113212832, 47.09659291851906, 43.65527399124638, 43.349054551893666, 40.21076225465344, 41.72176514902423, 46.62883066361951, 45.65631820309547, 47.19129462395945, 49.4432528557316, 50.51906877948392, 49.45206249913862, 44.55236711809712, 41.949203783465975, 38.72259147705571, 39.88946130198818, 41.865017952457556, 40.8345877739691, 42.609503423014, 39.0423862395748, 39.16922784620716, 40.50943505379462, 38.56138598534369, 41.4014644007529, 40.80140452231131, 38.658900030197636, 41.561905030281316, 42.412521992960286, 41.40055441087292, 42.752595409270256, 42.90646606876005, 44.194180196331395, 41.21919970358572, 45.273957713957756, 44.727438188368275, 41.569981190466116, 42.00613698651714, 44.8238931932757, 42.455832804403, 43.508953894338305, 43.28825781422277, 43.34133532739455, 42.51788470052904, 43.210583117700395, 46.516897986012125, 45.19756171011156, 46.03694500461702, 49.20085037908247, 55.13778909560173, 56.108756142277876, 57.15322448361305, 58.58532497959753, 56.13653044546805, 45.64251146008892, 45.28951775643134, 44.3604886916376, 39.616327055038944, 41.71055109270158, 41.334635057756984, 44.85612330898162, 44.17387800831949, 42.61377880650182, 46.95437954318139, 42.45308714528238, 44.47811665073518, 43.661063409620716, 42.60321978599795, 43.623749902171475, 42.55277026084162, 43.96526282833469, 44.683291912078865, 42.95733136515464, 42.42373212691277, 42.328108664481874, 41.83231322996078, 40.01844452273461, 43.7349687084075, 42.83269020818895, 42.88885070431618, 42.737866909273215, 43.323147296905525, 41.16875410079956, 40.72395732325893, 42.239184610305294, 41.20853085671702, 43.35241602313134, 43.15836068122618, 41.97469526721586, 42.77682781219483, 43.886929173623365, 44.25610657661192, 43.68881810096003, 44.221970189002256, 42.78697890620078, 46.98195380549277, 48.23786927807716, 48.783925963986306, 47.19095337775446, 44.930746401509936, 43.32630872726441, 44.9135938767464, 49.35397578823952, 53.10562087643532, 58.028579834968816, 60.27115183491861, 58.41718865979103, 60.92887447726343, 60.8643122642271, 65.37611269181775, 66.30342375847601, 67.98659124682027, 65.29155423564296, 67.54551287620299, 46.98642530748921, 0.8879883863752889, 2.5976636813532923, 2.328408658504486, 0.3172828827894503, 2.7041628956794743, 70.82766594425325, 72.48353373619818, 78.72918651949975, 63.68677923756262, 52.267112270478286, 47.912967589593705, 71.43593926583567, 67.7215959179786, 82.74232818234353, 14.57502059398159, 0.39686179809993316, 0.1414935744457668, 0.20941376535882875, 0.13487743994882032, 0.19144644480078452, 0.1346670875265714, 0.1416559391204388, 0.09470188930150002], [0.00988050121738906, 0.0330139960222427, 0.02706730937314851, 0.04240475542422745, 0.04131771496406967, 0.03054105654178608, 0.01914922760108546, 0.12622233179788436, 0.015160604229857846, 0.09207189413568667, 0.3941856384758027, 36.4744104877595, 51.99002035202519, 43.09401812091951, 31.50657569208453, 26.580863229690063, 30.89267965286009, 44.383587529582364, 57.731083746879335, 59.494091080081084, 44.199028245864376, 0.6311711993428969, 0.09015221569326617, 0.15055942829818497, 2.7073937029607835, 47.33466509849795, 52.671830269598196, 55.897779695449344, 56.42749970959079, 58.458491217705514, 54.02631098224271, 51.482751984750074, 51.786359125568026, 49.54132779952019, 56.27479791641236, 53.359982659739835, 55.72785477484427, 52.814526096467056, 53.20178954832016, 44.77853490460304, 38.69545652020363, 39.01201532733056, 39.08634816446612, 40.13097340060819, 43.432667716856926, 46.21052165185252, 44.36414826300837, 44.86616457662275, 46.43313577098232, 44.92492560417422, 46.11429806678526, 42.25503490817162, 36.45492415274344, 35.30313191875335, 35.56810763574416, 34.949738133338194, 35.288878025547156, 35.34451292407128, 35.74899558098086, 37.907248389336374, 36.763120466663, 36.03027659077799, 37.81502954421505, 36.45465743157172, 38.15453421685004, 37.34480011847712, 37.82558071997858, 38.54570434939477, 38.27888511842297, 37.66393984517744, 39.317917054699315, 41.12505889707997, 38.953238610298406, 38.84232182656565, 38.430378821588334, 38.0874812987543, 38.42373432651643, 38.15282014108474, 38.7858122394931, 39.227953572427076, 38.09835018650178, 37.557137627755445, 37.30580391422395, 40.59727653380364, 41.75004543796663, 41.00358701521351, 44.77377706958402, 52.27800077007663, 52.472228696269376, 53.99887792525753, 50.689789941233975, 50.325915582718395, 41.56173636836391, 40.218218680351015, 39.91833779119676, 38.62708176335981, 39.087811208540394, 38.36887605728642, 39.99542413219329, 39.76852678483532, 40.85644322056925, 37.811577858463416, 40.71476720994519, 39.01040715555991, 40.64002644631171, 40.06521094229914, 39.53797771084694, 40.47088207737092, 39.62770585090884, 38.14353196851669, 39.400082865068995, 38.34122726994176, 37.39120567998579, 37.56770449299967, 36.949554643323346, 37.95819213313442, 37.534117237214126, 38.4299591279799, 38.533266513578354, 37.46054533989199, 39.736410417864406, 36.66313925097066, 36.95191591016708, 36.770439609404534, 36.70401034816619, 36.84367810526202, 39.75867771333264, 39.07263948071388, 38.42229089429302, 38.49305437457177, 39.87056724486813, 40.41319577924667, 40.521672848732244, 41.26815872807657, 40.78310274308728, 42.493358119841545, 41.46801917783676, 42.0586653678648, 45.76942759175455, 44.48303530293126, 43.52323916650588, 47.84513804220384, 49.86743757801671, 52.59307299890826, 55.588551798174464, 57.1060226809594, 57.96990117719097, 61.06159963915425, 62.363634340224735, 62.66411927438552, 61.74413127283897, 63.52567964984525, 37.87307670039516, 0.24579335034133928, 0.17587308771908286, 0.4149775098889105, 0.11946146797028281, 2.5219484538801256, 58.54901167654223, 62.703382199810406, 64.91742287912678, 56.26210904890492, 33.941147711969194, 26.170952012462003, 51.21837639039563, 52.37928813503635, 64.4593135772213, 5.526912769963665, 0.17068621281894947, 0.08505829024098574, 0.04103321672206925, 0.01264523880015458, 0.05010621051394171, 0.03851561814606671, 0.09092050995076857, 0.06798242023515125, 0.06937902150375229, 0.02834405044033643, 0.03841404637862598, 0.030239505182591178, 0.023988829099483067, 0.0547032475080942, 0.01597548716686546, 0.026730376243170713, 0.0857533235102892, 0.04680766190792765, 0.5545360534902543, 44.458426352470156, 59.994291336305686, 49.67678685342112, 37.58550813121181, 24.91507576357934, 33.590695704183275, 50.07644107264858, 63.67599664195892, 63.32161834163051, 47.5800681883289, 0.41415681521738734, 0.09939972431428971, 0.34069400881567313, 3.7381675791355873, 51.2288648082364, 53.578945052239206, 60.05034200606808, 58.90282907793599, 60.42078241225212, 54.61040681408298, 54.8771946660934, 50.221784499383745, 48.98961897819273, 54.930723251835, 53.21521974379017, 57.50861083307574, 54.521894608774495, 55.624139462747884, 46.96911588791878, 40.78267128236833, 40.58969066989037, 41.26724089345625, 42.22272242269209, 45.930264380670366, 47.3023683024991, 45.48554997290335, 45.60502144598192, 48.33737196460847, 47.305561111819365, 47.240967519821666, 43.501752422701934, 38.889986468899636, 36.63562382421186, 37.42701299728886, 36.4022231871082, 38.281866119753936, 38.490940217048895, 37.238064581348056, 38.64323408372941, 39.242399661771714, 37.83599853515625, 39.013698024134484, 38.236178351986794, 39.407092140566924, 39.637539232930834, 39.45926750859907, 39.363483228991115, 40.404295921325684, 40.27867024944675, 39.48372740899363, 42.12559277011503, 42.3580285041563, 41.73062186087332, 40.617410059898134, 40.481696051936, 39.84013357470113, 39.977055672676336, 42.29101873213246, 40.742792544826386, 39.277355824747396, 39.19361322156845, 40.76333791978898, 44.27822482201361, 43.91313452874461, 44.15925933468727, 46.94189071655274, 53.17613332502304, 55.8699308672259, 54.61305441394929, 53.14412678441694, 51.57464919551727, 43.09972124715006, 41.87431396976594, 42.06197192592006, 40.82375810992333, 40.0029315487031, 39.145893666052054, 42.14443191405266, 40.73408880541402, 42.97016536035846, 38.86697392309866, 41.835211861518125, 40.64476074710969, 41.96976484790925, 42.63725026961296, 40.47635770613148, 42.02780023697884, 42.77626299089001, 41.93549117734356, 40.70125856707173, 39.67151088099326, 40.45427868443151, 40.25016246303436, 38.934827004709554, 38.36503213451755, 38.83149608489006, 41.649585693113266, 39.78264731745566, 39.812735819047504, 41.16669877882927, 39.290621280670166, 39.32989989557574, 39.52970543215352, 38.67590350489463, 40.71279818011869, 42.177313143207186, 41.30000837387578, 40.09690761566162, 41.315556649238836, 42.21026497502481, 41.55214225092242, 43.368129038041644, 42.327912545973255, 43.35742488984139, 45.408012559337, 43.74761050747287, 45.135792224637925, 47.406436627910985, 48.3088327992347, 46.37538671493531, 48.752244980104514, 52.15803507835635, 55.167136269231, 57.929598823670425, 60.14332179100283, 60.84472394758656, 63.21620072087934, 62.25557304197743, 65.7275099908152, 64.12973642349243, 66.94169536713632, 41.1647532832238, 0.3263168060971845, 0.648623907998685, 1.50131905271161, 0.10282393815296312, 2.7329798138910726, 65.28438806533813, 65.71110663875457, 70.50949112061532, 58.00225288637223, 43.22254634672596, 35.64137358819285, 59.567243283794774, 59.81633732395788, 72.6747335926179, 8.960435005926318, 0.24771238526990338, 0.12346477533179907, 0.017305727026635603, 0.05073023126310399, 0.020448596990336815, 0.05262366353323864, 0.06291624631792789, 0.057484514395435976, 0.1254737643044322, 0.12426188215613367, 0.21175502198598078, 0.09929381265875795, 0.10539330512044892, 0.12933266409222158, 0.11456743784008488, 0.18628817562374378, 0.1566802256650502, 0.13442118862463584, 0.8293568583265428, 50.87647907195553, 68.3030951407648, 56.04250731006746, 43.471977710723884, 37.21502065658569, 42.43005498763054, 57.07729524181735, 67.9634649522843, 69.57563754050963, 53.61988675209784, 0.8204725673121791, 0.5001157720483119, 1.0854381106553541, 4.195039618399836, 54.129367336150146, 52.796251773834236, 59.40309209208335, 60.43585608082434, 61.079564094543464, 55.83044044433102, 53.967616634984175, 51.93060036628477, 50.191954874223285, 56.60628134204496, 54.546585929009225, 58.81031997742192, 57.1306747774924, 57.40472685906195, 48.05626353909893, 41.00770550389444, 42.40330050068517, 43.414307102080315, 44.78834083003383, 48.56420263167351, 48.82357720405825, 47.91178303380167, 48.21452333081154, 51.89399288546655, 49.76900569854244, 49.91841662314631, 47.592953174344956, 40.09360497997653, 39.1918638444716, 40.3703321180036, 40.42314683237384, 41.09440949655349, 40.19206039367184, 38.52080906591108, 43.301597795178814, 41.24862140224826, 39.52606155026344, 41.032518417604514, 40.16247787783223, 42.188833144403276, 42.09097000860399, 41.89733828267744, 43.552256861040675, 43.34140985242782, 42.323774445441465, 40.9281559144297, 44.22735168087868, 42.6738420609505, 42.05969695122012, 43.239051680411066, 43.251462059636275, 40.603681764295025, 43.585130245454856, 43.77080348230178, 43.03322138324861, 42.208680337475194, 41.58577265277986, 43.91843757321758, 45.69516927965226, 46.340328570335146, 47.540091391532656, 49.296128672938195, 56.03063037318569, 57.619802182720555, 58.954773026127974, 54.84567842175884, 56.14999986463978, 45.78519551984726, 43.65244596235214, 44.00776170915173, 44.1188471548019, 42.821001545075454, 43.50884406797348, 44.83316175399288, 43.99144857160507, 43.662616668208955, 42.179666565310576, 44.640863633924916, 44.13098296811504, 43.110315568985484, 43.26020502275036, 42.72191070741223, 43.254580343923266, 44.93994043719384, 43.43620569475236, 42.94616045490388, 41.95000002461095, 43.159482479095466, 42.617206958032426, 41.72108657898442, 42.45107104701381, 41.8250999912139, 43.09232757937524, 42.23883159698979, 42.93904919778147, 44.05133531939599, 41.53958282163067, 41.96704664537984, 42.55303698201334, 42.38632840494956, 42.948706073145715, 45.466055793146936, 44.95627710896154, 43.087051991493475, 43.06852271479946, 45.65140347326956, 45.06828823397237, 45.49175124014578, 45.379751882245465, 44.69686723524525, 47.55482773627005, 45.58022422175254, 46.44332608868999, 50.884939624417214, 50.30145568232383, 50.44294341917961, 52.276600483925115, 55.76396803702078, 58.12741964094101, 61.089883850466826, 64.14646533227736, 63.69660477484427, 67.15211483740038, 67.30212196227043, 67.65063239682105, 67.65078929162794, 66.56657557333669, 43.901763577615064, 0.8007634539277324, 1.0913133308772118, 3.6177665043261746, 0.22022856729886225, 2.9161912731585966, 71.12085526989353, 72.39964992769303, 77.28429517438336, 67.81942767481651, 47.37458698211178, 37.5064919840905, 69.19570892087876, 68.17866971415859, 87.58037567138673, 12.781981633555505, 0.49644480128922774, 0.23110255719192568, 0.13459513654872296, 0.13286359397874725, 0.08273284566859085, 0.1853980427427638, 0.10355584323406221, 0.19532177717454974], [0.044807689790163314, 0.056207419012583075, 0.02714125026438025, 0.025301986156151663, 0.04489657514157795, 0.06008333744361036, 0.013681473266783983, 0.059037478039822275, 0.03183239732959098, 0.038580455997538184, 0.036796773483435956, 24.636520801051972, 58.41765934421171, 48.92605304718018, 43.96973433033113, 22.824821164531095, 25.087367834583407, 45.430146494219386, 59.20240009984663, 57.61504434770154, 51.51238549140192, 2.6407188032903983, 0.31923692793615405, 0.08080092514114035, 5.112133891351762, 30.57255541124652, 54.49828194033716, 50.85749480032152, 54.214804403243534, 51.496903896331794, 52.13423805852091, 55.29966923498339, 54.872001447985255, 52.03624940687611, 52.81946828288417, 55.900846988924094, 53.62295796794277, 52.74102087943785, 46.98432683944703, 37.848844297470585, 38.41403038271012, 39.235747321959465, 40.37691385515275, 42.28036165237427, 44.31642086275163, 47.98569225495862, 49.91109748040476, 46.76602340513661, 49.20372939878895, 46.65205501740979, 46.08009892125284, 40.81753723083004, 37.485417089154645, 35.99128430889499, 36.56018095631754, 35.31349482074861, 36.506985772040586, 36.890687711777225, 37.0981457925612, 37.03826296714045, 36.30020626129643, 37.74479950627973, 38.34124295942245, 38.473058131433305, 37.23313023967128, 37.45750550300845, 36.33987319084906, 36.694737865078835, 39.73762243024765, 36.904537600855676, 37.40881319968931, 39.92060884352654, 39.730942633844194, 38.72285035348708, 40.36651957419611, 38.60241397734612, 38.477247222777336, 38.54974046830208, 38.611470730074, 40.261133332406324, 36.70524589477047, 35.76368877964635, 39.59687602135443, 40.82249902909802, 42.18271424693447, 40.866213844668486, 44.17269345252745, 51.256901910228116, 55.701708255275605, 53.59763122374012, 50.31434851308023, 49.462841172372144, 42.37551835275466, 41.92641481276482, 39.66443100283223, 38.41663875887471, 38.48811611052483, 37.92804087361982, 41.27775284551805, 38.35940745569045, 39.80195714581398, 39.33443807786511, 38.4071897691296, 38.97333683506135, 39.59035704212804, 42.090330662265906, 40.88178957662275, 40.88966569592876, 40.11876306226177, 38.84065089687225, 38.01197567293721, 38.20686255731891, 37.94582097761093, 37.78055583277057, 38.04645722912204, 37.165665472707445, 37.04335812599429, 37.15262359188449, 39.20954981157857, 37.22732905418643, 38.35848962107013, 36.058639249494, 37.80318790866483, 38.86997845865066, 35.38882393990794, 38.01924774723668, 38.55160359413394, 38.498816336354906, 39.89323854446411, 38.092623526050204, 38.67687233032719, 39.37283415948191, 37.90835842009514, 41.00432049843573, 42.619595681467366, 39.77816012597854, 42.65362224271221, 52.856264037470666, 54.721531483434866, 53.86737654286047, 52.731414994885846, 49.98160600662232, 53.77903692183956, 54.07521901592132, 53.19313287734986, 56.77741435266311, 61.38134341086111, 62.97908952159267, 60.63046447692379, 64.21797798525903, 62.24034247859832, 60.457880189341886, 30.402861910481608, 0.36009371460926154, 0.48714228755524086, 0.7567329488454327, 0.11908632237464191, 2.231141232675122, 59.937012964679354, 61.06865206072408, 64.94643272892122, 52.72599820167788, 31.460309374716978, 22.50531469621966, 56.442734195340066, 57.8346029404671, 54.44139580572806, 3.8703899421999535, 0.31297259633579566, 0.032953953881177216, 0.00889125858403502, 0.12228985692584708, 0.04709151280563205, 0.07627334550864275, 0.05015420592239788, 0.028681914367142226, 0.01610849630988894, 0.026255441949732845, 0.02384245459501061, 0.04498438796989861, 0.05312052134784961, 0.0181537710370556, 0.026677941355193337, 0.04396419634201354, 0.03458501252856466, 0.0037691312806395396, 0.07624689249261733, 30.598213595728723, 64.7732993095152, 53.8860313354, 46.000168861881384, 26.57775082895833, 31.047366165345718, 49.65965001813827, 64.57219546841037, 62.34640729042792, 54.71182753962856, 2.3125438968981467, 0.2180058397953549, 0.05403764350640197, 5.524457366235795, 36.17006594134916, 55.03243031040315, 51.26925345390074, 54.91365701921525, 53.87835917934295, 52.31260784210698, 56.04032254988148, 53.88438393992763, 53.213360540328495, 53.51771293147918, 58.685529770389685, 56.29919113651399, 54.349726092430856, 49.75583830187398, 40.43250560760498, 41.30101642301006, 40.7021136437693, 41.724142105348655, 44.99007617273639, 47.71315813064576, 50.205953813368275, 50.54465440011794, 49.00856402612502, 49.58742741615542, 48.93026959511542, 48.22664737701417, 41.9648697299342, 38.18090038914835, 38.24882015105217, 39.15632717071041, 37.985801696777344, 38.79782253696073, 38.60492821662657, 38.71853574629753, 38.67841382180491, 39.05084679203649, 39.860216109983384, 40.10265781033424, 40.582269545524355, 38.31317055609919, 39.96434327094786, 38.73818289849066, 39.329664553365404, 40.02470070315946, 39.41598023137739, 40.12366210260699, 40.617821908766224, 42.17932531910558, 41.489027392479684, 40.85070479300715, 42.10067003004013, 40.224329733079486, 40.855968613778394, 40.95744033013621, 41.520331828824936, 39.99746768705307, 38.06034241953204, 42.14880143442462, 43.21002614113593, 44.706504498758626, 44.32805853505289, 46.57538444765153, 52.467110003194506, 57.66757665141937, 55.00134944915772, 52.75181131978189, 50.47361635392713, 45.566193903646166, 45.15149739480788, 41.94666600996449, 40.82577813056208, 41.03585243225098, 41.11088737364739, 42.22715862335698, 41.04366971600441, 42.018927835649066, 40.11427587078464, 40.86312693934287, 41.596280682471495, 41.41951907065607, 44.08549131885652, 41.43884458849507, 42.57790480890582, 41.620634678871404, 40.775563947616085, 39.46907343402986, 41.36830076094597, 39.0858696353051, 38.66614464790591, 38.85475181764172, 37.840964255794404, 38.88349102389428, 39.87185770465482, 40.36184410895071, 38.595216428079915, 41.62080334078881, 39.691079585782944, 40.258775987932765, 40.72286298198085, 37.63014078140259, 39.66482323984946, 40.02229236787365, 41.06503094396284, 41.2020864025239, 41.041112330652055, 41.587796595788774, 40.744734118061686, 41.510419999399495, 44.29571467061197, 44.29978216848066, 42.33948746035176, 44.67904398518224, 54.71840535440753, 57.9340075677441, 55.205889286533484, 54.30403832466372, 51.74971242104807, 56.527159290929, 53.62966129856726, 56.62407713551676, 60.1915551770118, 62.464439253653254, 64.00001971952378, 63.683272638628566, 66.23630416008734, 63.824026892262125, 62.506149738065666, 33.985231230335856, 0.27075214251395197, 0.9204136399972824, 1.1262843253151065, 0.21425001713777744, 2.6386095487302352, 67.28929581180697, 66.1659917523784, 70.03363701605028, 57.88139681662283, 32.34769659657633, 23.98166148893295, 62.48662417934787, 63.161585638600016, 65.29391158011653, 6.046294887219706, 0.2475611748354089, 0.01728225600785546, 0.038264080837008455, 0.0010989515712642442, 0.028196643632386, 0.009647306926067798, 0.017096320722973155, 0.09819688966437694, 0.19265726208686831, 0.16852558440258428, 0.11423624270865995, 0.10037898386438047, 0.13127314948266552, 0.1458732684653613, 0.13312391065541776, 0.12516768153516517, 0.10306946933269502, 0.18326441126485027, 0.2048829375135322, 34.87214188421927, 74.44660940477925, 60.716136886227524, 57.750605383226954, 34.08098413098243, 37.10616703956358, 56.51315642941383, 69.69269675593223, 66.86418933253135, 61.40093564987183, 3.257575006254258, 0.4161188889655375, 0.14867309000222914, 6.88629154236086, 41.33565487400178, 57.80243950505411, 52.66387178051857, 55.19968801929105, 54.317405762210974, 54.68417482991373, 56.706784232970215, 55.34926368344215, 54.09340704641035, 58.292418064609656, 60.928741116677564, 58.717351959597686, 57.495863130015714, 51.44881956038937, 41.73342635554653, 43.67445830375918, 44.103863700743645, 43.96560015216951, 46.860999676489065, 49.31974134137554, 51.79776537802912, 51.61868172307169, 50.94500680123606, 51.924301039788034, 50.364193993230025, 49.343816849493216, 45.23786798600228, 40.86737486623949, 39.93014412541544, 43.68093805928385, 41.132091706798924, 40.43412946885632, 40.8705755203001, 42.17883502283404, 41.91275711982481, 41.03539351494082, 41.44665402750815, 42.848795460116484, 44.274937875809215, 40.89995407289074, 41.07184410095215, 39.827656515182994, 40.965485111359634, 42.577857740463756, 39.76099191173431, 41.41510248184204, 45.174027489077666, 44.05452028397591, 42.97575473785401, 43.97845375922419, 43.66342467646445, 42.40463410654376, 43.46973803735549, 42.37035259123772, 44.356201541039255, 42.25590959672005, 40.03357702685941, 45.05436381986065, 45.97967447773103, 48.176821508715236, 45.326050712216286, 49.20821266789591, 54.77235363375757, 61.244131057493156, 57.383526448280584, 54.63707893125473, 52.715046944156775, 48.17056140592022, 45.83348774140882, 44.45633572916831, 43.46170110087241, 44.771023565723056, 44.532861171230195, 45.60353879005679, 42.64109419238183, 44.16555866118401, 42.91828024771906, 42.71333640621555, 43.480253911787464, 43.02503539669899, 46.7943899862228, 44.17698060312579, 45.710517514136534, 43.535767216836255, 42.57453157055763, 41.54811789912563, 43.023901831719186, 40.39394478644095, 41.96186911675238, 42.31415679377895, 41.12487454568186, 41.04663110548451, 40.23963482149186, 43.04114849336686, 42.642823957627826, 43.437252967588364, 42.014170000630045, 44.17748266650785, 44.80761927943076, 40.41406654542492, 43.35758962938863, 43.329654509021395, 43.8143261017338, 43.91249126003635, 42.52472531410956, 44.11465806345786, 43.50385089074412, 43.067369537968794, 45.34620385016165, 45.331290998766505, 43.97606503578925, 47.260936306368926, 57.9842492072813, 59.15959135178597, 59.304679824459946, 56.039302733636674, 55.0114260181304, 57.6771786136012, 57.58401447726835, 59.99463650488085, 62.117160443336736, 65.09714980279246, 65.59444358271938, 64.44308673181843, 67.63653539842176, 67.06450477723153, 65.41557173575124, 35.266630341929776, 0.78826408592924, 1.7617525424688094, 1.7196831611856338, 0.3418516902433288, 3.294992946809338, 72.86819273425688, 70.65762335254301, 74.93004937325755, 65.88769174391224, 45.04180831293906, 32.28860608993038, 73.50062001136043, 69.79776136336788, 77.13118937707718, 9.062110685533094, 0.4967888666977806, 0.09147922553482557, 0.11025147467491128, 0.16544614077335404, 0.12348257155428011, 0.19458501509601073, 0.14824120027403678, 0.2844952389357552], [0.07064538016434639, 0.055820923824343956, 0.015201950952741168, 0.07519179789890205, 0.09788984162432533, 0.06309765976883712, 0.006566988998993992, 0.05139779261944275, 0.04500151003500627, 0.053318447823966705, 0.08904383202353794, 14.373286231871575, 53.27803650209981, 51.85005841716644, 38.936603838397616, 23.30131265424913, 36.31567216688587, 43.84646992529593, 63.114148493736025, 51.27493304591025, 59.34036554828767, 5.067774336184225, 0.013821142586699177, 0.09820885595775421, 1.5173986866589517, 21.289709421896166, 48.90484871402864, 53.70498649535641, 53.45902642896099, 50.84062076384022, 53.751858818915586, 55.6349338254621, 55.26785489051573, 55.99374440408523, 56.958447425596184, 54.59996938705445, 48.81340649820144, 43.61220636675435, 38.71023601101291, 39.59397346742692, 40.25935649871826, 42.48265004927113, 44.07919199235978, 46.559294885204686, 52.175156224158506, 46.99557227473105, 52.07215478343349, 50.71866643044257, 46.35600628391389, 49.41520790899954, 44.97096246288669, 40.786719168386156, 35.3803712321866, 37.18737186924104, 36.20900331004974, 37.385326047097486, 34.85589542696553, 37.269231734737275, 36.90704399539579, 36.93704228247366, 36.86187005812122, 36.69548311541158, 37.39257458717593, 35.9526881863994, 36.13900076958441, 37.57421954985588, 37.85404928268925, 39.57082756104008, 37.372060591174716, 37.86188225592337, 38.3953599006899, 37.82796944341352, 40.69996418491487, 41.21312787455898, 38.5821549354061, 38.402486847293, 39.029309057420306, 38.23508008833855, 39.74148204249721, 37.34351750343077, 36.73604042299333, 36.627277020485174, 37.78387023556618, 40.122018629504794, 42.16159620592671, 41.148275406129905, 42.93623685836793, 51.956154607957416, 53.88973013047249, 51.25464654737904, 54.355970505745184, 48.665439005820986, 42.91564441496327, 41.496621101133286, 39.81708180519843, 39.996828340714984, 37.33219362074329, 37.669489998971265, 39.96675945097401, 38.327918667947095, 39.13091413436398, 38.719265307149584, 40.23773639432846, 39.79681884088824, 39.70390181387625, 42.17662672842703, 41.04944344489805, 39.655511533060384, 39.94661808013916, 40.16352907303841, 37.66411635183519, 38.89074348634289, 36.894394351590066, 38.10494761313162, 37.2395746938644, 36.78919638356855, 37.34422353006179, 37.316688491452126, 38.17003542377103, 37.61471802188505, 38.57234900997531, 36.78350894681869, 37.90447135125437, 38.813896409926876, 37.0735211526194, 37.21171017616026, 39.622398884065696, 40.40289563517417, 40.1805756938073, 41.648997337587424, 39.99377281435075, 38.841937434288766, 38.48509588549214, 37.89627359759423, 41.12352917271276, 40.95704417074881, 43.17989057110202, 55.02979055527718, 55.81002058521394, 57.053580591755534, 56.26438794597503, 56.28970292306716, 53.254043363755756, 58.02178628983037, 59.59759066181799, 61.53248017834079, 56.58845024724161, 57.3867545589324, 55.627006715343846, 57.20682367201775, 56.867201328277595, 64.72054735306772, 33.24134588241577, 0.06532735867245544, 0.3780481802119363, 0.4265289819769321, 0.1661268865028697, 2.152772031484112, 62.83991206076838, 60.28730807765838, 64.45786230025753, 51.26913578279557, 49.77910580173616, 34.2685361831419, 56.042330803409705, 57.218347595584014, 52.726476730838904, 3.8777534567540695, 0.09506083979842164, 0.07218895540122064, 0.007496908177516514, 0.09098650842544534, 0.05490472480174034, 0.03191746181748327, 0.0179367306672277, 0.10480573866516353, 0.007306311247614964, 0.05980724701657892, 0.08493712577488154, 0.07749821284725782, 0.09243613830016506, 0.07043576318650477, 0.02266915263457885, 0.008820026771225517, 0.0334177588322951, 0.05576374302167566, 0.06382888303168359, 18.42628113685116, 63.00510268057547, 58.1310478333504, 48.58282996762184, 23.647654018094464, 42.06616886200444, 50.10042244388212, 66.36767218189856, 56.3666166797761, 64.26275184077602, 5.153989993756817, 0.15580357593153754, 0.015083287763709744, 2.019730751072207, 22.76683480508866, 53.93550026801325, 56.030277359870176, 56.19996301589474, 50.74810774095597, 55.22538346628989, 55.790345976429606, 57.295057389044, 58.8603929550417, 59.1796072067753, 56.425938606262214, 51.47391096238167, 47.534349041600386, 40.094008984104285, 39.62737244944419, 41.07632737005911, 43.888909970560384, 47.28511771848125, 48.63312652034145, 52.32624592319612, 49.37606657705, 52.661310472796046, 53.258024569480654, 50.48532462889149, 50.38982275993594, 49.01942899150234, 42.163839801665276, 37.18086857949534, 39.52624982403171, 39.07130195248512, 39.19225608148883, 37.54446444972869, 38.14256314308413, 38.75541387065765, 39.7086831831163, 38.52715546084989, 37.6370676871269, 38.6963665100836, 37.66221792467179, 37.56649248061642, 38.526578872434555, 39.466672943484404, 40.21284503321494, 40.14166970406809, 39.05450636340726, 40.48261780892649, 40.122477546814956, 42.008164851896225, 42.76266021113242, 40.43937367777671, 39.96051503765968, 40.76009411965647, 40.66101897147394, 40.24381606809555, 38.8422865252341, 39.87423858334942, 37.996674506895005, 40.18321544893327, 42.93170259844872, 43.37799379902501, 43.17306172463202, 43.79951130959296, 54.751572916584635, 56.063637118185724, 54.999384341701386, 56.07435695586666, 51.53971656676262, 44.37146740574991, 42.02326989942982, 42.56918145764259, 41.559626133211204, 40.35302269843317, 40.255516498319565, 41.75563873783235, 41.115362798014, 39.811900354200795, 40.54222606843518, 41.76070251772481, 41.802354166584635, 41.23482250398205, 43.52757338554629, 43.44904361232635, 40.892481957712484, 41.16810298735096, 41.58225036436512, 40.66045415016913, 40.15256604840679, 39.23927353274438, 39.50077402976252, 39.10193174116073, 40.20694186610561, 38.51401552077263, 40.227451939736646, 40.42178969229422, 39.464394046414284, 40.16260731604792, 40.22890713907058, 39.922130723153394, 41.5051208772967, 40.46486516152659, 40.43157208350397, 43.23720816643008, 43.48922045000138, 43.058650109075735, 42.986270612285985, 44.02560064869542, 40.88013433641003, 39.42134995614329, 40.12981630140736, 43.160435615047334, 43.3879566192627, 44.71439630754533, 56.667317344296364, 59.04493262690883, 59.77986320372551, 59.00451652465328, 58.5666976436492, 56.71480155760243, 59.901625340984715, 60.834066867828376, 64.71971581059118, 59.40776363495858, 60.289579129988155, 57.513101946923044, 60.82118580418249, 58.13286389074018, 64.80074413361089, 34.20488788235572, 0.2970907662905032, 1.7969469894324581, 1.6244280338287356, 0.2840485177453487, 2.5795599818229675, 68.51012568319997, 64.52174594325405, 71.44249746876379, 54.617918152962964, 46.56591584605556, 34.680761598771625, 64.27265974783128, 63.88567478426042, 62.10276534480434, 4.935759613590856, 0.17763996226412637, 0.029283856462326743, 0.002166685538419012, 0.08519217942751224, 0.024377662771111055, 0.011279197736463, 0.005950652111712243, 0.08306031761270377, 0.19803749757909006, 0.18492305290795144, 0.20865326987639551, 0.29516246169805527, 0.21890706562947845, 0.29307447373867035, 0.18616514190310435, 0.10669864999550967, 0.1759490529976545, 0.1490802810557427, 0.19162405462514973, 21.372161565288422, 69.38811686731154, 62.955115995099476, 55.041259565661036, 32.044552295438706, 49.242909954440215, 55.07003407324515, 72.56493076201409, 59.03769585394091, 71.27512208877071, 6.288362001219104, 0.20319316205718826, 0.16826486936019314, 2.1229404451385623, 26.08246530255964, 55.42220800153671, 58.747428694079005, 55.71073362904211, 54.25274548992034, 55.868879672019716, 58.471788052589666, 59.232602350173465, 60.793407578622144, 61.37903705719979, 58.90307618725685, 53.820751328622144, 49.67249185808244, 40.542979163508264, 43.26760261289535, 44.61845905550065, 46.83218202283306, 49.04548529655703, 51.808340088013686, 55.248301875206735, 51.41878597197994, 53.472248738811864, 56.42662894341254, 51.93188298133112, 54.19277244998563, 50.52430122129379, 44.654713523003366, 38.43487385780581, 42.601945015691946, 41.50964337010538, 42.14864061724755, 38.73148741260652, 39.38424041194301, 40.8132932263036, 41.57708852521835, 40.783012528573316, 40.02606176560925, 41.466669882497484, 39.358439060949514, 40.03331422805786, 41.655594764217255, 42.555719883211204, 43.422359728044086, 42.12363550739904, 40.17886161804199, 43.444325001009055, 41.62533367833784, 45.45499078689083, 44.474915996674575, 42.01442495469124, 41.791818680301795, 43.96313690370129, 42.30096978525962, 42.73095961539976, 40.72285513724051, 41.88771278627458, 42.9667450535682, 42.35066229297269, 46.31959099923411, 48.75967394921088, 46.01224976201212, 47.052403496157744, 55.61889917619767, 58.7471737400178, 56.664265740302305, 58.88529608326574, 52.8772565626329, 47.08214290680424, 44.86718047049738, 44.13441111964565, 45.22689711663031, 43.85227503315095, 41.76431894302368, 44.7796174787706, 42.28867707713958, 42.961167443183164, 40.825338825102776, 44.711799698491255, 44.58005905151368, 42.836475295405236, 46.84160747835713, 46.29102045489896, 42.53738280265562, 43.406478051216375, 45.40003053603634, 42.41014895900604, 43.48293681298533, 42.01841008278632, 41.577955369026434, 40.391136369397564, 41.95647585776545, 41.5126439832872, 41.70725237938666, 42.426626836099935, 41.58627079379174, 42.48467791465021, 41.873772682682166, 43.31570263831846, 44.87802582402384, 43.12767597936815, 41.64192922653691, 45.85971663075109, 45.04424802718624, 45.07955328110726, 46.37800685821041, 46.09983236558976, 43.25071680930353, 42.37848366460493, 42.571711386403734, 46.35096603824247, 45.56923374052971, 47.00919858870968, 60.400276260991255, 62.874464219616314, 63.781633915439734, 62.76488104174214, 61.14679744166713, 60.76352696264944, 63.17412545604091, 62.97079370867822, 65.4015806413466, 62.42762780958607, 63.42732229540425, 60.752077564116455, 62.818091915499785, 58.87514498925979, 65.7414932404795, 37.125712210132235, 0.592588069698503, 2.5096167672065, 4.11918931430386, 0.34116064829211085, 2.7221825093992296, 75.2132837234005, 69.24855893658054, 76.60312068077826, 65.00650382811024, 66.26254481654014, 44.735475124851355, 71.6249425949589, 74.122190167827, 73.49730953093498, 7.507955835711572, 0.38169616833329206, 0.17094870518532493, 0.12481879743356859, 0.18599258825903942, 0.21543278028407406, 0.1561108997632419, 0.18069369598261772, 0.154478611544736], [0.12743124152503668, 0.040076656357174924, 0.04150511539210716, 0.03346657395483025, 0.055748356145716486, 0.07196293648092017, 0.04686266702089099, 0.062214651505552956, 0.02894003620190967, 0.11249731505109418, 0.1321624243451703, 5.805663850999648, 50.98054739736742, 48.809511584620324, 38.59176866469845, 27.36133448539242, 23.75949844237297, 36.25290639938847, 62.06167067250898, 53.2090380883986, 60.61945046147993, 11.982520222663881, 0.3257757028745067, 0.010909073847165753, 0.453921007292886, 14.451401214445792, 44.811282773171705, 52.355028275520574, 51.67880773544312, 56.70787857424829, 57.098597634223204, 57.02864608457012, 55.80987545751757, 52.947580737452355, 50.83632184613136, 46.79116579794115, 40.40200133477488, 36.78961215480682, 40.1408891524038, 40.8736075124433, 45.64348813026182, 47.321125076663115, 51.57333912387971, 49.825287788145005, 51.92459129518079, 47.86097265058949, 47.68603101853402, 52.41905312384329, 50.078727814459036, 49.510905896463704, 44.96230971428656, 37.86900135778612, 36.560439832748905, 36.46325134461926, 36.51535610998831, 35.16062044328259, 37.06519788311374, 36.864513735617365, 34.60976277628253, 36.191858630026545, 36.73613455987746, 37.45366942497992, 37.88709132902084, 38.312644958496094, 36.27416172335225, 35.55208475359025, 37.60809706103417, 36.599337977747766, 36.14358602031585, 37.42777001473212, 39.96510421076129, 39.12857247937111, 40.726981470661784, 42.34088382413311, 40.878373192202666, 38.803270709130075, 39.3588940558895, 37.31347214791083, 39.87311286310996, 38.35628917140346, 36.902988264637614, 36.01895663046068, 39.31053907640519, 39.722776259145434, 39.48691629594372, 41.96892938306255, 43.177529304258286, 51.83625167415988, 55.08864179734261, 52.70122058929936, 53.76463005619665, 51.04209330774123, 41.853647001328014, 43.47222482004474, 41.1298010426183, 39.069160338371034, 38.4682414608617, 38.232573693798436, 41.192009833551225, 39.20977730904856, 38.16097082630281, 40.603022806106075, 39.15024357457315, 39.31907807627032, 40.17304474307645, 42.89886059299592, 41.287441099843676, 40.839494659054665, 40.68568283511747, 40.489917339817175, 38.18435991964033, 38.15338496238955, 38.28228973573254, 36.392244677389826, 36.040266867606874, 38.19298521164925, 38.95636866169591, 38.43961992571431, 38.019632139513575, 39.592165254777484, 37.531642221635394, 38.74844381886144, 38.3656479466346, 37.91248083114624, 38.44790789388841, 39.26727925577472, 38.936164532938314, 41.697046372198294, 41.74701344582343, 41.23016665058751, 39.586924968227265, 39.24853424872122, 38.13582451112809, 40.100822141093595, 39.340168660686864, 38.75421754775509, 40.65120520130281, 51.72060058962915, 56.7744686526637, 56.01263846120527, 56.93885910895563, 57.94973627213509, 59.96441072033298, 59.12660029626662, 52.21763941549486, 52.597599414087114, 53.58007861721901, 56.583449225271906, 57.0951263366207, 59.827370951252604, 55.40722846984864, 55.762963910256666, 33.6777997785999, 0.6005615741014481, 1.3866097047444315, 0.814436836348426, 0.20405539401596595, 3.349923044443131, 61.09665778375442, 59.30723328744212, 64.08481744027907, 48.80164331005466, 32.40633406946736, 18.497013238168535, 44.8707341378735, 59.00143354169784, 40.49809155925628, 1.4507489146724826, 0.10655981188099231, 0.017660532987886862, 0.05292632571992375, 0.01287246430893579, 0.048170225890052897, 0.0077002791447504885, 0.02826402298054628, 0.028321908584104914, 0.03468224057747472, 0.02837871591891012, 0.05967783944440946, 0.0407733750199118, 0.049916569278725696, 0.048798567375108126, 0.08819183499942865, 0.007990601570195249, 0.03677703905850649, 0.026970196237427094, 0.04723622681452863, 7.485350726112244, 59.21632059158818, 54.35588421360139, 42.59432777281731, 26.310611924817486, 32.956923054110625, 43.108656406402595, 65.80580049945463, 56.17995892801593, 65.83539870477492, 12.07467729045499, 0.23525803259784178, 0.02002914661481496, 0.513117969516785, 15.33253715884301, 46.72798033683531, 53.26563004524478, 53.292714011284616, 56.95599986660866, 57.16673704885668, 58.55049041009719, 57.61138869870094, 54.128979021503085, 54.68812465667725, 50.539535707043065, 41.72229466899749, 40.34813934756864, 40.637269020080566, 41.91042330957229, 45.626363062089496, 50.90546538752895, 52.47642563235376, 51.77145019654305, 52.23782785477177, 50.48967845978276, 50.03529148717081, 52.353439715600786, 51.55963436249764, 52.35822500721101, 48.123626324438284, 40.96626566302392, 38.7909270101978, 37.79075007284842, 39.539789845866544, 38.47096358576129, 37.222626132349816, 39.17137338269142, 37.450311876112416, 38.057251591836255, 38.66384221661476, 40.24290607821557, 37.89037435285507, 39.60724284571987, 40.19769291723929, 38.423640189632295, 38.91345793201078, 39.39150071913196, 38.543727474827925, 40.040966772264056, 41.45125889009045, 40.565152322092366, 41.52392471990278, 43.25873805630592, 41.26540130184543, 40.69122514417095, 41.18325118095645, 40.65473141208772, 41.33875746880808, 40.90309589139877, 39.27517106456142, 37.604186457972375, 42.8338590745003, 43.49762216691048, 42.42526577365014, 44.23423544053109, 44.849929886479536, 54.640267818204826, 58.30291432719077, 54.66743415401828, 55.23737807427683, 53.60593095902474, 44.294263393648215, 46.28052811468802, 42.988835842378684, 40.91948355397871, 40.14343869301581, 39.64122626089281, 42.97333463545769, 40.831681297671416, 40.110659445485766, 42.39538908004761, 41.243173230078916, 41.60048154092605, 43.49935977689682, 44.91634738060736, 42.61937602873772, 41.381930997294766, 41.686099037047356, 42.519418347266416, 40.3520970190725, 39.7766774700534, 39.66337980762605, 39.23486086630052, 37.8011090524735, 39.95456872447845, 40.85348967582949, 39.83373226657991, 39.56140602788618, 40.32669182746641, 40.19100527609549, 41.61985020483694, 39.8792984408717, 39.76447105407715, 40.47377678655809, 40.678026368541104, 41.689786065009336, 44.95495527021347, 43.21855729626071, 43.31160376148839, 40.85586270978374, 40.89352530817832, 41.41989561819261, 43.0932689482166, 42.04472526427239, 41.73428535461426, 43.35352605389011, 53.258416806497884, 58.45561612036921, 58.22952678126674, 59.86975608333465, 60.02723924575314, 62.97599084915654, 60.15937212974795, 56.64086880222444, 55.09780837643532, 56.502546418097715, 57.57458902174427, 56.318665704419544, 61.19863156349429, 59.469395837476185, 58.12546237822502, 34.86014335386215, 0.42575961519633576, 1.6050867039349772, 2.2503444215943738, 0.1781934761111775, 3.3620132602030233, 67.17340546269571, 64.88174892240956, 69.98237163789811, 54.94776595023371, 40.51502443129017, 25.446364725789717, 50.877149797255, 66.7338175927439, 51.39482813496744, 2.3894652531993006, 0.1929781763183494, 0.04339393198249802, 0.03173950533833235, 0.05711478121098011, 0.030639508416155176, 0.0725978854743223, 0.05513909024997585, 0.041760322262322715, 0.2234805952156744, 0.1573035760872787, 0.10622541450204388, 0.12143029861392514, 0.19435754826953336, 0.11713463677874497, 0.19552597024988747, 0.22941863464732326, 0.15215716595130582, 0.25702996029248165, 0.2840901009978787, 9.109999883559443, 69.265550644167, 60.37702445060977, 52.26494712214316, 38.309950290187714, 35.015520203498106, 47.95019872726933, 72.99389685353925, 60.776415871035674, 69.70812736019012, 14.853570653546242, 0.5400468180737188, 0.2107082854115194, 0.8789383752211448, 17.224151165254657, 51.013816941169004, 55.67681689416209, 55.68127270667784, 58.526430591460205, 58.622932664809696, 60.051840351473906, 59.274622701829486, 56.35775996792702, 55.682072870193, 50.60768296641689, 44.39835917565131, 42.1389288287009, 44.59050824565273, 44.405121341828384, 48.930363731999556, 52.53927769199495, 56.71442108769571, 53.64244430295883, 54.95114703332224, 51.26988495549848, 52.551421350048436, 55.54848086449408, 54.722476774646395, 54.71997038010628, 50.665294739507864, 42.38477122399115, 39.98959549011723, 40.168887030693796, 41.816156987221014, 41.24074136057208, 43.0435372168018, 42.78273097930416, 39.33802704657278, 40.79094356106174, 42.31843217726677, 41.130444311326556, 40.11710389967888, 42.70418943897371, 41.200690038742565, 39.7433255564782, 41.91853869345881, 41.55022421190816, 40.25643041056972, 42.8123801754367, 44.39158524236372, 41.69507342000162, 43.16097690213112, 47.50025187769244, 44.09845082990585, 42.82200567183956, 44.09010794854934, 42.79818904015326, 43.55630082468833, 43.81102738841888, 42.40814462784798, 40.27967437621086, 47.10232742371098, 44.693635202223255, 44.447106392152854, 46.27003577447707, 45.02683662599133, 56.451343797868304, 59.78334234606836, 56.33204883144748, 58.431320959521884, 55.41503790886172, 45.55798830524568, 49.13363664380966, 45.541098579283684, 44.748972000614295, 43.77527890666839, 42.10014443243704, 45.36492532299411, 42.06536477611911, 42.34570049470471, 44.5350145524548, 43.08280014222668, 44.32333600136542, 44.24939932361726, 47.243681799980905, 46.09181504095755, 44.30475965622933, 44.13825896478469, 45.43272741379277, 41.092083531041304, 40.46842275127288, 42.32767328139275, 40.45163892930554, 40.993133898704286, 42.008772819272934, 42.94746268180109, 41.6861500278596, 41.022963523864746, 43.51484137196695, 41.817208182427194, 45.025326513474994, 42.532828930885564, 42.93090243493357, 41.526639000062026, 44.576379868292044, 43.664660223068736, 49.86913596430133, 47.319967977462284, 47.163222220636186, 44.4286241839009, 43.6454523763349, 42.92956882907499, 44.39952804196266, 43.886627151120095, 43.26664947694348, 44.288328847577496, 56.88711127927227, 61.922814846038825, 60.5097496125006, 61.98469023550711, 65.52814375969672, 64.90576167260447, 61.66986119362616, 58.931540827597345, 58.55749576322494, 58.63708065402124, 61.21599589624713, 58.98168048551006, 62.13779211044312, 60.56447844351492, 60.011016322720444, 36.92738148473924, 1.0903562725551668, 3.8673138233923146, 5.136175569026701, 0.4242761012527251, 4.493175543123677, 72.68122119288292, 70.80421801536315, 75.7385753816174, 61.75477658548663, 46.500710364310976, 28.537331665715865, 60.99685307471984, 74.46618203193911, 61.70537433316631, 3.6156842160609464, 0.36582297975978545, 0.13114715866263837, 0.2359977517757685, 0.07886369562437458, 0.1347911018397539, 0.13339233254232716, 0.12682216332083748, 0.1625392354664303], [0.0828661373065364, 0.021425406974289688, 0.00787163673404364, 0.05770833081295414, 0.0424698920499894, 0.0305701966112059, 0.12397331981769494, 0.038297528235782544, 0.03219297959379131, 0.03226091244047688, 0.10238198202944572, 2.992258288206593, 50.825119556919226, 48.85679967941777, 45.01221402998894, 32.773307100419075, 30.208149571572584, 38.524260751662716, 57.71516676872008, 54.33290304676179, 62.20215820497083, 19.743048260288855, 0.00245341022344937, 0.16675998156349506, 0.19042013213038447, 7.335191609398012, 36.483612368183756, 54.42480417989916, 52.67930630714663, 54.948307237317486, 56.67869221779608, 57.480601187675234, 52.43069079614455, 49.17038925232426, 43.21062234140212, 39.31814455216931, 38.631353224477465, 40.705428046564904, 45.467554138552764, 50.88149186103575, 52.88431682894307, 52.94598433279222, 53.43926552803286, 52.05657905147922, 50.07781782457906, 50.21721101576283, 46.820869907256096, 49.9173693503103, 51.77552946152226, 44.542878904650294, 39.46541778502926, 38.357010887515166, 36.26094725824172, 35.90963232901789, 37.33561784990373, 36.18862659700456, 38.78926392524473, 37.750996851151996, 37.48203992843628, 36.79232643496606, 37.18240222623272, 36.500764892947295, 37.32672191435291, 35.98475748492826, 36.88127794573384, 38.09028187105733, 38.225372222162065, 37.284117129541215, 37.16223339880667, 37.39354341260849, 39.321356973340436, 39.60024141496228, 41.09649619748516, 40.222745095529866, 39.273005916226296, 39.01321949497346, 40.40646106966081, 37.080393145161295, 38.68631347533196, 37.59565922521776, 38.65562485110375, 37.07628642359088, 39.08696397658318, 40.77712505094467, 42.79314094974149, 40.9754204750061, 45.39721427425262, 51.27590971608316, 55.26804708665418, 54.10074580100275, 50.76024747663929, 49.53981768700385, 41.482630006728634, 42.41520097178798, 41.261392639529326, 38.4857823002723, 38.17642104241156, 37.6558832968435, 39.09327507019043, 38.8150260525365, 39.39185765481765, 40.019487873200454, 38.41845481626449, 41.65486912573538, 39.125658158333074, 40.76475389542119, 40.04855263617731, 40.029737026460715, 39.22650621783349, 37.760857689765196, 38.22377581750193, 38.15755444188272, 38.41972174183015, 36.35665309044623, 37.785160695352864, 37.43286909595613, 38.276445404175796, 37.957686147382184, 37.09516479123024, 38.34975058032621, 36.76054346945978, 37.624512180205315, 37.664587036255874, 37.934128392127256, 37.02234991135136, 41.313046332328554, 40.861710963710664, 41.9796335312628, 43.463117076504616, 40.86836330352291, 40.33441105196553, 39.320482284792014, 40.068089962005615, 38.54292731131277, 38.3596977110832, 39.05658129722842, 41.06226959536153, 46.503401110249186, 53.50098794506442, 55.0487591374305, 54.44764414141255, 57.992941179583156, 51.365100491431456, 50.83072462389546, 55.73835888216573, 59.0802300360895, 61.77669086763936, 61.96863205202165, 60.0614619255066, 65.4053774956734, 64.4109703648475, 60.35745574582008, 30.828741096681167, 0.732382752241627, 0.7740686605534246, 0.7850291111296224, 0.1862605811367112, 3.747411870187329, 59.9935382412326, 61.92505059703704, 61.288132206086196, 53.22820671143071, 58.144842809246434, 28.691435706230905, 46.12101316452027, 58.587976501834014, 39.247279090266076, 1.23491718644096, 0.12797900205177645, 0.04924016726774074, 0.022802277648400877, 0.0723361898393881, 0.028202354817861514, 0.04905954671783313, 0.03781432593842188, 0.03253894106995675, 0.0468881739183299, 0.026437271003341003, 0.021693736930648168, 0.06208420205380648, 0.12499029387629802, 0.0282359630950997, 0.07310484415821492, 0.04728335271319074, 0.037278114187140624, 0.02615240312391712, 0.1054130778497746, 4.136180531594062, 58.12195970166115, 55.43889376424975, 50.58123050197479, 34.108342662934334, 33.502018759327555, 45.60226794212095, 62.76294339087702, 58.21875987514373, 66.81676787714805, 21.491974284571988, 0.07590354720671331, 0.16597389874439086, 0.3286965509816524, 8.263325883496194, 39.022966584851666, 55.20326129851803, 53.2011462796119, 57.17107519026726, 57.489583415369836, 58.6676045387022, 53.60018860909247, 51.92818026388846, 45.251545290793146, 42.20753892775505, 41.560759698191, 40.67701831940682, 45.877382986007206, 52.08997411112632, 54.38891841519264, 56.56972877440914, 54.511343433010964, 54.11873379061299, 51.82327647362986, 52.01706901673348, 48.11170231911444, 51.02610964928904, 53.36977289568994, 48.143128348935036, 41.56664717581965, 39.74202725195116, 39.190036019971295, 38.72009684962612, 38.46335026525682, 38.83211189700712, 41.09688843450239, 40.42672403397099, 38.93638418566796, 40.01329445069836, 39.787522823579856, 39.70571787126603, 38.10744616293138, 37.94167895470896, 40.121018425110854, 39.77425736765708, 39.93078347175352, 39.285769308767016, 39.22596885311989, 40.77653277304865, 41.399052143096924, 42.459088371646025, 42.78149935507005, 41.3084218578954, 40.8195690185793, 40.96656768552719, 41.71042949922624, 39.14237530000749, 40.190354162646884, 40.2696801770118, 40.01766004870015, 38.14028816838419, 41.65373556075558, 42.62764438506096, 44.90218370191513, 44.78602663163216, 47.152882852861964, 53.2086693856024, 55.312911156685125, 56.52442539891889, 55.44118835080055, 51.935777894912235, 42.90690145184917, 43.96507847693659, 42.879797873958466, 41.37302721700361, 40.60592143766342, 40.72791499476279, 42.4075052815099, 41.16452578575381, 41.61338613879296, 42.615139868951616, 39.46376254481655, 43.152496737818566, 42.7086256396386, 42.31691814238026, 41.4228020944903, 40.68520038358627, 41.61559835557015, 39.497016399137436, 40.52562659786594, 38.566512523158906, 40.20958554360175, 38.709690801558956, 40.03329853857718, 40.046999377589074, 40.154786109924316, 40.267271841726, 40.000699720075055, 39.972941106365575, 38.75908128676876, 40.65076197347334, 40.918863819491484, 39.390743701688706, 38.91442283507317, 42.86583423614503, 43.99946197386711, 44.58945312807637, 45.446604759462424, 43.210190880683164, 42.1979683445346, 43.179082562846524, 42.18408707649478, 40.181007154526256, 40.02532436001686, 40.895384511639996, 41.861636869369015, 48.76880522697203, 54.798515842806914, 58.63137360542052, 57.517185134272424, 58.436471031558135, 52.75608278089955, 53.007055636375185, 55.9573212746651, 59.06187334368306, 60.78795548408263, 64.34871058310232, 63.550206230532744, 67.10077885658511, 64.00188284535562, 60.69548560727028, 34.02106208185996, 1.1148334558933013, 1.349032172752965, 1.7989586750345847, 0.24630604702378475, 3.4894613633232736, 66.8722458808653, 66.17663706502607, 67.14366605204921, 56.91388145569832, 56.78070522123768, 29.720116507622507, 54.95637947513212, 65.27869670621811, 48.3758778725901, 1.9956719130277636, 0.08718400036976223, 0.06755835226466579, 0.03206791957059214, 0.09507821467254432, 0.03886339525061269, 0.015494539083221988, 0.026662866660063306, 0.04612729922237416, 0.27914938546957513, 0.14426497412064385, 0.18483493747490068, 0.1610827950700637, 0.17905498794730634, 0.09873283711532432, 0.22236909356809434, 0.19213987694632625, 0.24672820743533874, 0.1320740637639838, 0.1492525742299134, 4.883413622456213, 66.86098867847075, 62.19608245357391, 59.43419648754982, 45.32101438891503, 43.84660720825196, 50.013086949625325, 68.46516747628489, 62.159718159706365, 71.5615806271953, 26.055230325268163, 0.22690491630665718, 0.4391403213864373, 0.5565857983404591, 8.384078991028572, 41.25317135164815, 58.41612569747433, 54.054654029107866, 58.68230558210804, 59.85970697095318, 61.438947339211744, 55.47295954919631, 53.52567926529915, 46.70153963950373, 44.36883157299411, 44.460316934893214, 45.17244285152805, 49.185247190537, 56.705532996885246, 57.04399431905439, 57.85116318733462, 55.97485034696518, 55.28763540329472, 54.29630341068391, 53.233011614891794, 51.20488343700286, 52.654556151359316, 56.22185376382644, 49.6991482857735, 42.20201623055243, 43.110601902008064, 41.76226362105339, 41.386975165336366, 41.92503806083433, 40.26623633600051, 43.696631462343284, 43.18975140971523, 41.81076372823408, 41.8657906593815, 42.6220706970461, 40.05090998065087, 41.293308965621456, 39.26962091076759, 43.15792137576688, 42.409670429845015, 42.22016503733974, 40.984167360490375, 41.23858797934748, 43.35317696294477, 42.61812479265275, 44.842002776361284, 43.83006265086513, 44.487169481092884, 42.26437799392208, 43.18522499453637, 44.24478661629462, 40.044410613275346, 43.54816975132112, 41.50761158235612, 42.19401459540091, 42.74864166013656, 42.87902516703452, 43.968918477335286, 46.27040447727327, 46.45266917444045, 49.768695831298835, 57.75464150213427, 58.29650517432921, 56.47154400425573, 57.69908505101358, 54.31591526154549, 43.97722213499008, 46.88174116996027, 45.04485207219278, 44.76350830447289, 43.64014933186193, 44.30218658139629, 43.65226161095404, 42.61356307614235, 44.252674502711145, 45.25995485244259, 41.00910971241613, 46.059843801683, 42.806990838819935, 44.76552048037129, 43.177745034617764, 43.517461515242054, 43.6692690080212, 40.986293285123764, 42.2263192361401, 42.2777650433202, 43.146903437952844, 40.24167053161129, 40.98641095622894, 41.62383533293202, 41.80997925419962, 42.28053815903203, 41.338216181724306, 42.890125474622174, 41.130750256199995, 42.60509075657014, 42.88193556570238, 43.6290176453129, 40.72005848730765, 45.85212684446766, 46.78727088436004, 47.17002361051498, 48.13785668342344, 47.20107701516921, 44.338974491242446, 46.069449686235004, 43.583490694722826, 42.25470542907715, 41.6028114288084, 43.72746913663803, 43.727261251018895, 52.65864326107887, 55.99730199383151, 60.913636069143976, 56.65923333937123, 60.27154799430602, 55.49507387222783, 55.97806669050648, 57.71372333649666, 59.70713069362026, 62.27999764104044, 65.6820732547391, 65.00586840414232, 68.56422301261657, 68.21228442653533, 64.84203884678503, 37.09396846832768, 1.3579004065644358, 3.480450453296785, 3.9390485805849877, 0.7168869998666548, 4.610519130383769, 73.41877583534487, 71.41160488128662, 70.91971612745716, 65.03669823369673, 71.20192281661495, 41.35094427293347, 65.67647603250319, 72.57401497133317, 60.677395636035556, 3.4555730656270063, 0.3699713458697642, 0.16384431221071752, 0.13411489135075, 0.1646361560110123, 0.10981201599802702, 0.2427368587063205, 0.16383993018779064, 0.11347629880953221], [0.044166355453912294, 0.04839692662860598, 0.03422527679152066, 0.055515905917291684, 0.07881831257574021, 0.0048401368023347, 0.04302196565174288, 0.009911289333455987, 0.058998135594470855, 0.019525215893443075, 0.0714931943483891, 1.4317555725574496, 44.75447116359588, 54.366415777514064, 40.80129469594648, 31.338625684861217, 28.679594070680682, 34.38057084237376, 58.685780802080714, 53.46361952443277, 61.11459086018225, 31.20698113595286, 0.043739847493388, 0.1193782248564305, 0.09244382982292483, 3.477637133290691, 26.791588644827566, 51.437789855464814, 51.309512661349395, 57.536130182204715, 56.79872066743913, 53.795714839812256, 50.31431713411885, 42.11753622178109, 39.44472336000012, 42.95905328566029, 47.61581667007939, 51.58798133173297, 52.090436950806655, 53.345363986107614, 52.36048821480044, 53.66029108724287, 51.61062125236758, 51.492604978622936, 48.84543657302857, 50.70342017758278, 48.982088027461884, 46.01456003804361, 50.82768478701192, 43.01987747992239, 37.649646728269516, 37.31172277081398, 38.544335442204634, 38.04814777066631, 38.97218758060087, 37.49720773389263, 38.356638262348795, 39.051086056617, 37.714824753422896, 36.51648575259794, 37.99892986974409, 37.78168939775036, 36.30872957168087, 36.21986435305688, 37.056686339839814, 37.44232200807141, 36.6427311589641, 36.917893271292414, 37.847377331026145, 37.79290345407302, 37.854472898667865, 38.23785712642055, 39.118597892022905, 39.39611342645461, 38.54389613674533, 38.33833648312477, 39.307432559228715, 38.22724319273426, 39.00395093425628, 38.00595091235253, 36.910581973291215, 35.65160705197242, 37.98680190117129, 41.891619466966205, 43.22016939040154, 42.88101773108206, 47.310001234854425, 50.97562090043099, 52.48949889213809, 54.26430863718833, 53.632308898433564, 50.60459606109127, 43.52502384493428, 41.86321366217829, 43.00758084943218, 38.7384613867729, 36.00108631195561, 38.69862579530285, 39.098915438498224, 38.71289145561957, 38.22566639992499, 40.803856003669004, 38.03859679929672, 40.08272432511853, 39.41612535907377, 39.02869324530325, 39.394434652020855, 39.80319269241826, 38.9882496864565, 39.67352697926183, 37.503977744810044, 38.09856591686126, 36.16415885186965, 37.44024707425026, 37.44902926106607, 38.30893831868326, 38.46704513795915, 38.30648291495539, 38.40366355834469, 38.12543415254162, 37.67136489191363, 36.22554786743657, 37.90633055471605, 36.61336437348397, 39.130561121048466, 40.56519154579409, 42.61269230996409, 43.60550695850004, 43.710073424923806, 42.313599817214474, 38.725129250557195, 36.924063159573464, 37.841101538750436, 38.50939889107981, 39.814677392282796, 39.89416030145461, 38.93672543187296, 45.080129869522594, 48.12828217783282, 53.9518722411125, 58.35952589588781, 47.13657756005564, 51.17959199413177, 59.727601543549575, 57.575083240385986, 57.743956965784875, 59.57563323359336, 59.447152076228974, 56.34699306180401, 60.49083594352969, 61.06360004794214, 64.11319186610561, 46.413351335833156, 1.924244203875142, 0.48005484044551855, 0.9389782793098881, 0.26685710635877424, 3.585870525529308, 59.626443616805545, 61.84286125244633, 59.64121526287448, 51.201635714500185, 40.21298623854115, 29.174108851340513, 44.505902721035866, 57.751087834758145, 37.94703298999418, 0.8872880594384287, 0.04109456504304563, 0.01004821127055273, 0.006764493647947788, 0.039056675403469035, 0.024372058837944945, 0.010156448002934698, 0.05687910575239409, 0.021807939572740468, 0.07589325864589022, 0.016678957937044964, 0.07321866184112526, 0.06437164866515706, 0.06828941464904817, 0.00869303907928688, 0.006595683779807822, 0.04390315445620687, 0.007235366238972113, 0.07249067913019851, 0.07908563129603863, 2.223915736521444, 50.41118398789437, 58.79219078248548, 49.28076867134341, 35.564361772229596, 34.37058056554487, 40.151236364918375, 63.70091545966364, 59.469811608714444, 66.80293759992047, 33.67240651961296, 0.05869086921936082, 0.1623917635410063, 0.2704673416672215, 4.809280335903168, 30.488291132834654, 52.83719739606304, 52.3686977355711, 59.00405368497295, 58.866233364228286, 56.60073118825113, 53.2654417714765, 44.479069786687056, 40.411367954746375, 43.89615066589848, 48.91707866422592, 51.746656894683845, 53.90656886562225, 55.546452999115, 53.96800102726106, 55.62679882972471, 54.27085115063576, 53.43392325985817, 51.52823578926825, 51.816365257386245, 49.195488499056914, 50.150381672766905, 53.568429177807225, 44.19831045212285, 39.477851698475504, 39.676617806957616, 39.42580576865904, 41.01307915103051, 40.62114807867235, 39.02841083465084, 39.65355819271457, 40.97471052600492, 39.76085070640811, 38.798544253072436, 39.94068353406845, 38.80087414095479, 38.712867921398534, 37.04296588897705, 38.793876632567375, 40.296054194050456, 38.604661495454856, 39.55653836650234, 40.30893525769634, 38.96195019445112, 40.91638095917241, 39.3495862714706, 41.026477967539144, 41.24603656030471, 40.78097289608371, 41.05564863451066, 42.846445960383264, 40.101857646819084, 41.03782146207748, 40.93037205357706, 39.69149535702121, 36.9448438767464, 39.79408102650797, 42.70760190102362, 45.83801023421749, 45.92184697428058, 49.46871688289028, 53.06781707271453, 54.56187140557074, 57.59789574530817, 54.240335110695135, 53.084322406399636, 46.83206827409806, 44.894488011637044, 44.48703612050703, 42.48361102996334, 37.244167789336174, 39.934003737664995, 40.86101670419016, 41.725216834775864, 40.74048226879489, 42.039112352555804, 39.81799963981875, 42.02357192193308, 40.934588601512296, 41.91165493380639, 40.27910955490605, 42.474366003467196, 41.93314559998051, 41.3446920148788, 39.70231717632663, 39.61606817860758, 38.15405176531884, 37.91492839013377, 38.39239458883963, 39.16711368868428, 39.93358796642673, 40.67541407000634, 40.22389434999035, 40.75620705081571, 40.48577531691521, 40.31665448219546, 39.62926303186725, 37.5181100445409, 39.50451204853673, 43.08543989735265, 45.46453783589025, 45.93125674032396, 44.402587490697066, 44.87025953108265, 42.175144072501894, 39.21160121117869, 40.55061994060394, 42.060195092232, 41.05786869602819, 40.411367954746375, 41.11211507551132, 47.84510666324247, 51.73449362477949, 56.13237273308539, 61.50586689672163, 49.02491246500323, 52.14775062376454, 60.95694688058669, 56.32039154729536, 58.49314143580776, 60.216521063158595, 62.2664301626144, 59.50390485025222, 63.36844359674762, 63.74121781318419, 68.35996950826338, 46.990484960617565, 2.5734307881324523, 0.7143747830583204, 0.6444464611911005, 0.32499012567343255, 4.0098267697518875, 65.56921489777105, 67.19142483126733, 65.33470815227878, 60.91232599750642, 53.34308901140767, 37.50437782656762, 53.65688254756313, 65.70092808815741, 46.3332369250636, 1.2184199426443347, 0.017329301467285525, 0.017766722350291187, 0.03979419590905309, 0.0815490406427172, 0.010821558835525668, 0.009625126765440068, 0.08290507755572758, 0.04521311118057178, 0.19767627180103334, 0.11747977471039181, 0.11565314530725442, 0.1363097179320551, 0.1625395265798415, 0.12748154285814495, 0.13883420746893654, 0.12475606249344927, 0.12941638218058696, 0.24273007116731138, 0.1705687562183988, 2.491506938972781, 57.120735491475756, 66.63527980927499, 54.177722315634455, 42.21319890791371, 41.62133678313225, 45.753212513462195, 70.83902512827228, 62.88319541561989, 71.22382533165717, 38.38474204463344, 0.13082872655603195, 0.29664845776654064, 0.366495267878617, 4.835448428507775, 32.4070930480957, 54.53015512035739, 53.73007005260837, 61.37605605586883, 60.83648697022469, 58.24848751867972, 56.0709797951483, 47.17356943315076, 45.00536949403825, 47.87388509319675, 53.7335374278407, 56.47556835605253, 55.63673027100102, 58.58315198652206, 54.97063729070849, 57.29109971754013, 55.623747225730654, 55.02096522238947, 53.2915255331224, 54.724473261064105, 54.25287100576586, 52.64683300449003, 56.39985876698648, 47.67417369350311, 40.831289060654186, 41.30813160250264, 41.23211214619298, 43.28912073566068, 42.90559922495196, 42.11142909142279, 42.322401615881155, 42.7019379984948, 42.49302079600673, 40.74230617092502, 42.18577761803904, 40.90275856756395, 39.79759547018236, 38.68570158558507, 41.0744014863045, 42.48744710799187, 41.10483907884167, 40.96002124970959, 42.01533886694139, 40.36427990082772, 41.69357507459579, 40.948422801110056, 40.87775738008561, 42.06745147705078, 42.2420597076416, 42.35477293691328, 44.757511000479425, 41.738352852482954, 42.69374024483466, 43.25233282581453, 41.8160314713755, 39.514647453062, 42.258737625614295, 45.925792878673924, 47.18573270305511, 48.46062460253316, 50.30078103465419, 56.708600290359996, 55.34263880022111, 57.44160498342207, 57.46459791737219, 53.84403844033518, 50.85914611816407, 48.30409457606655, 47.32897766174809, 44.564954003980084, 40.09332256932413, 43.72377034156553, 42.89872331003989, 43.11604615180723, 43.00977737672868, 45.19108587695707, 42.300032338788434, 43.89989260704287, 42.660337340447214, 44.183966344402684, 41.69999991693805, 44.76637555706886, 43.74548850520965, 42.66615813778293, 40.41949118337324, 42.06449400994086, 38.527987003326416, 42.034103485845755, 40.96752082147906, 41.177803008787095, 41.9351734653596, 42.71641938917099, 43.078261959937315, 42.780883542953, 41.686742305755615, 42.167134592610026, 43.50476480299427, 40.07618965641145, 42.6862681296564, 44.29822106515208, 46.49075538881364, 48.4453312812313, 47.2074822456606, 47.651443558354536, 44.33085910735592, 40.63628058279715, 42.93450709312193, 43.106985476709184, 43.848223224762954, 43.7383968599381, 42.211029837208415, 49.43883626691757, 52.957649461684696, 59.33924767278857, 65.19291447054955, 53.51844249233123, 55.147716614507864, 59.4205270274993, 56.31830092399352, 58.40438996591876, 62.86994172680763, 64.99250488896524, 61.92095172020697, 65.52500194118869, 65.27537053631198, 70.21759617713191, 50.32269531680692, 3.067466059038716, 2.0842869579792023, 4.889657545474268, 0.7252113112518865, 4.609902337674172, 71.5087619904549, 73.15680857627623, 71.34662689701204, 65.46091433494323, 50.04591718796761, 41.57797890324747, 61.20855908240042, 73.74033958681169, 54.44855020892236, 2.0746058129495193, 0.11691581908493273, 0.06761975421179688, 0.130128598802032, 0.13993020349692914, 0.0824098629997142, 0.09235038241792111, 0.1679857528858608, 0.17527176998555663], [0.017757094540302793, 0.023307338349461075, 0.022825417334153768, 0.06381099104821202, 0.06902787744277908, 0.09165446048662548, 0.05894401914349968, 0.0031316534788798423, 0.006371972699379248, 0.042867694695990895, 0.07683714791651695, 0.12024347520162983, 29.179302069448656, 54.97851341001449, 47.061389646222516, 35.274349566428896, 23.98944543253991, 35.89926942702263, 52.17905898247996, 58.51916636190107, 56.86809562867688, 41.24490691769508, 0.22881779188831008, 0.07351425686670889, 0.33789046409149326, 0.9709677821205509, 16.08882700243304, 44.27132537288051, 53.97536723844467, 58.225710315089074, 53.16755510145619, 50.63413543085898, 43.29769111448719, 42.32469228006179, 46.655961698101414, 51.639584033719956, 53.73699695833268, 54.377610221985854, 52.68007116933023, 53.68058150814426, 53.42502732430735, 52.196854775951756, 49.42750453948975, 47.280603070412916, 48.00024032592774, 47.31070333911527, 46.88138815664476, 47.39285738237443, 45.368961441901426, 37.45765063070482, 38.4844643838944, 39.53016434946368, 39.241772082544145, 39.051364544899236, 35.320700214755156, 37.22197501890121, 37.37312747586159, 37.86765990718719, 38.324765082328554, 35.92895784685689, 37.12967772637644, 38.04042462379702, 38.530877790143414, 36.63271734791417, 37.631607747847035, 36.129657683833955, 36.310698601507376, 37.98096933672505, 37.36685560595605, 36.336727449970866, 38.65457365589757, 38.43190070121519, 38.81905824907365, 40.770370729507945, 38.97706700909523, 37.959784615424375, 40.42837142944336, 37.97161056149391, 39.19180108654884, 38.52522957709528, 37.38503971407491, 34.32644605636597, 36.33648426302018, 40.963398410427956, 43.168296044872655, 43.23443112834808, 46.13724000992314, 53.383924807271654, 53.57626607341152, 51.97693924750052, 54.98047851747083, 48.29224901814615, 44.88294447621992, 43.273513624745036, 42.75519201832433, 37.7502594455596, 36.42934245447959, 37.49131241152364, 40.225580969164454, 40.478667982162975, 40.98879967966388, 39.47374889927526, 38.33531233572191, 40.31863920150265, 41.7082525837806, 39.59702114905081, 38.96851624211958, 39.272292044854936, 39.29813654192033, 37.008386273537916, 37.597212483806, 39.212707319567286, 38.22281483680972, 36.704775210349794, 38.034823479190955, 37.18403785459457, 38.544084410513605, 39.24347439119893, 38.31778718579201, 38.15421258249591, 37.0158976124179, 37.592078101250436, 37.424443844825994, 37.875838048996464, 38.73287593164752, 42.90018243174399, 44.92410190643803, 47.05223483424033, 46.07456053456953, 45.31578979184551, 43.91031434459072, 41.3626290136768, 39.39281863550986, 40.18283890139672, 39.48718693948562, 38.2487730826101, 36.987656547177224, 42.52626680558728, 45.986726899300855, 50.64220374630344, 49.71085263836769, 55.922184682661495, 63.26605012339931, 54.53885101502942, 54.45591642010597, 59.213225841522224, 60.19953720031246, 56.25752379817348, 55.39260979621641, 59.58701595183342, 58.501131303848766, 64.08763762443297, 52.19388161936114, 2.7470758316978334, 1.450150017776797, 0.6685847272315334, 0.23477970261967954, 2.3971283387753273, 57.84691133806783, 61.37213760806669, 60.729418031630985, 40.82073396252048, 29.477972907404748, 20.49743575434531, 39.52967013082197, 60.95195370335733, 29.670765246114424, 0.23379766983130287, 0.04662568538239406, 0.04118521239668612, 0.08711481496932046, 0.05221991604494472, 0.03024510145487805, 0.009477294778691666, 0.01853176647977483, 0.0637343707644651, 0.03601876523105368, 0.032169579438144164, 0.04647837433543417, 0.08132686748379662, 0.13923631169863288, 0.03505329143316035, 0.03579226367536091, 0.08969526722907059, 0.03353605429912287, 0.0360625816298829, 0.06314007039632528, 0.23719326262512516, 37.42585589808803, 61.79181160465364, 51.01664104769307, 38.6599826043652, 28.82291159322185, 47.10889739374961, 57.07521246325586, 61.391502349607414, 61.809572096793886, 44.692497714873284, 0.4963674876959094, 0.1303014282377497, 0.8812600506409523, 1.4606710403196275, 18.62066988022097, 47.72148924489176, 55.70205734622095, 60.58238014098137, 55.628214805356926, 53.759597655265566, 46.263367745184134, 43.709092832380726, 48.13654268941572, 51.8974563383287, 55.48395787515948, 56.83636365398284, 53.23239188040457, 55.864137526481386, 55.10801046125351, 52.68802965840986, 52.145903187413374, 52.28715165968865, 50.2927597876518, 49.48415140951834, 48.67832399183705, 48.43405054461572, 48.55765227348574, 40.1761826392143, 40.20380396996775, 40.618959396116196, 41.78542521692092, 39.63047112188032, 38.382153280319706, 39.555420491003225, 38.936658751580026, 40.66516099437591, 37.91668168960079, 38.338332560754594, 38.94656273626512, 40.10869433802944, 39.89616463261266, 39.12853717803955, 38.541444655387636, 38.612972997849994, 38.52084828961281, 40.42510409508982, 40.17777904387444, 38.96720617048202, 41.20769146950015, 40.537307416239095, 41.5205357920739, 41.0705340293146, 41.50787438115766, 40.84230307609805, 40.84976734653596, 40.30036487886983, 39.539750622164824, 41.05946117831815, 39.303957339256044, 36.425345559274, 38.38351826513968, 44.73095655441285, 45.16536297336702, 46.79176199820734, 49.28032936588411, 54.615921666545255, 53.937841923006125, 53.28566551208497, 57.20395249705161, 51.091099400674146, 47.96967329517488, 47.43090829541607, 45.42384716772264, 41.95446760423722, 38.343376728796194, 39.67560583545316, 42.26405243719778, 42.978802419477894, 41.32656281994235, 41.81327796751454, 41.47832324427944, 42.079779486502375, 42.544988278419744, 41.163678553796586, 41.01217308352071, 41.72539334143362, 40.76992750167847, 39.28021523260301, 39.4245231536127, 40.269244793922674, 39.452411205537864, 38.138444654403195, 38.841815840813425, 39.01836172226937, 40.04844673218266, 41.57701792255525, 40.192436941208385, 40.93438856063351, 40.014318189313336, 40.00705003738403, 39.02989741294615, 39.62563483945785, 40.284663631070046, 47.12051153182984, 48.34671505035893, 49.82233424340525, 47.99016767932523, 46.913488834134995, 46.47953348775064, 42.790489427505, 41.09481742305141, 42.192826117238695, 41.31230108199581, 40.16876935958862, 40.00741089543989, 45.74864687458162, 47.929939685329316, 53.414440847212276, 52.16395785731655, 58.667937940166844, 62.29081553797569, 55.044295480174405, 55.04464457111975, 60.56247803472704, 61.16992373620311, 58.954255273265225, 57.263184209023755, 62.832981232673895, 61.09250007137176, 66.21945365782707, 52.55404541569372, 3.652197805143172, 1.3399571564889725, 0.7182310245210125, 0.3406861640753285, 3.236418967285464, 63.41562970992058, 66.24918522373324, 64.27729598937496, 49.51843292482438, 32.94454405384679, 23.141985977849654, 47.7795873918841, 68.48594034871748, 36.49886254341372, 0.43377219008341916, 0.03807564619027319, 0.060757521630054524, 0.017246046862114343, 0.03862886509347347, 0.048112198560228275, 0.015745429047984223, 0.03623582858351931, 0.046644178744886196, 0.19454928475522226, 0.14339593930109856, 0.1138603923121287, 0.2070847354949482, 0.22963681648815834, 0.23665317063850744, 0.11159838748074348, 0.14401359002917044, 0.15885740158057984, 0.2204436081792078, 0.09863565886212934, 0.42223233188832965, 42.539285152189194, 71.40197938488376, 60.29263857872256, 46.79167570606355, 34.21406230618877, 48.38702917099, 61.60886833744665, 66.28206253051758, 65.75174239373976, 51.273948530997004, 0.5966282948370903, 0.4262453762273635, 1.1679409997117136, 1.5714283551900619, 19.63484967908552, 49.86899083660495, 57.86919040064658, 63.7767505645752, 57.70082658337009, 55.88221180823542, 48.473768464980594, 46.84745573228406, 51.56148572121897, 54.588876924207135, 57.346365913268066, 58.68811068996307, 55.13907563301825, 57.679610483108036, 56.23903374518118, 55.98652332059799, 54.34332870667981, 51.12016808602118, 52.128040713648645, 51.33444716853481, 49.888128080675685, 50.6352101602862, 49.70962101413358, 41.42860327997516, 42.55187203807216, 42.374459312808135, 42.28431932387814, 43.19956125751619, 37.808859655934, 42.46097110932873, 41.77965541039744, 43.32344931940879, 40.911109293660815, 39.802023826106904, 39.86569566111411, 43.666911663547644, 42.988588733057824, 39.73810095940867, 41.08778069096227, 40.55417753035023, 39.70573748311689, 42.73354837971349, 41.99597412540067, 40.54959620198896, 44.731497841496626, 42.54949115937756, 44.9325938378611, 46.33515496407786, 42.218427427353404, 42.692975382651056, 44.22574350910802, 41.98730176494968, 42.084858955875525, 43.02664749083981, 42.1737830100521, 39.33560694417646, 39.063825914936686, 47.51691410618444, 48.40513875407558, 49.407822085965066, 50.87224291216943, 56.64395178517988, 55.94885287746307, 53.68783397059287, 58.304612713475386, 52.98674168125276, 50.64064656534503, 49.93063480623307, 49.679987507481734, 45.26520690610332, 41.72339293264574, 41.956781802638886, 46.14819126744425, 45.04389501387074, 43.06690669828846, 42.87172171377367, 44.13732936305385, 44.78375950167256, 46.27695875783121, 43.14036876924577, 42.78952452444261, 41.925838224349484, 42.8704979342799, 40.360361453025575, 42.27810628952519, 42.06677682938115, 42.30193861069218, 39.94794776362758, 41.879318914105816, 41.33378390342959, 42.44332044355331, 43.56094883334252, 43.32992123019311, 43.635548391649806, 41.412278375317975, 42.62094497680665, 41.697740631718794, 43.17876877323274, 43.81765227163992, 49.6919075904354, 50.234959740792554, 53.60704883452385, 52.59311222260999, 50.604521536058, 49.145089964712824, 46.65466339357438, 44.01672432499547, 44.534626237807736, 43.24349964818647, 42.771312959732555, 40.55573863367881, 47.613137691251694, 51.28615494697325, 56.738006299541844, 54.635819850429414, 60.47252631956532, 61.615336325860795, 57.271950706358886, 58.388406307466575, 63.83915939638692, 64.4539438524554, 60.23765087127686, 60.753238585687455, 66.46583341783094, 63.02366725860104, 68.34919083502986, 56.205422955174605, 4.180525868169723, 3.0268621733111725, 3.5130929081670703, 0.5861175685159622, 3.3193547879495933, 70.1295389667634, 70.89390693172332, 68.52408932101342, 55.29276194110994, 43.208088490270804, 32.808816317589056, 56.89532864478327, 80.02753811497843, 46.83215064387168, 1.1217248151379249, 0.16989194818081396, 0.21722055370769194, 0.18399524382285534, 0.24157134786007867, 0.14939281428533216, 0.08910249903677933, 0.11722257601157313, 0.16763289278793722], [0.05022588110859356, 0.03676548645260834, 0.035187126993532145, 0.03111322654501325, 0.02215677196340215, 0.058390899831729556, 0.1067698885115885, 0.025645197376668937, 0.0907614624368087, 0.05407066572637809, 0.030115624934795405, 0.03398979668535533, 17.519117324582993, 56.524382252847, 44.59933750091061, 39.734986597491854, 22.814693604746175, 35.10464822092364, 51.61451224357852, 58.92896775276431, 53.28816406188473, 52.44260695672805, 1.6670301220109387, 0.1606178409870594, 0.2408782068279482, 0.5383886360833722, 5.8126530243504435, 36.386486637976866, 54.39822227724137, 56.47682743687784, 52.43882186951176, 46.71847251153762, 43.276243594384965, 44.55410080571329, 52.118485819908884, 55.6738123586101, 52.3561579181302, 55.75571537017823, 55.4923439025879, 51.40279054641724, 49.61122835836103, 49.08358720041091, 48.16754118088753, 45.666622269538145, 46.102005358665224, 46.59551797374603, 46.30688644224598, 45.199315009578584, 38.56246855951125, 35.5684135806176, 40.423597904943655, 37.737472518797844, 36.381101223730276, 38.64332429824337, 37.59519246316726, 37.43642668570242, 37.53641182376493, 37.68548934690414, 38.19307542616321, 37.6753931660806, 36.337033394844305, 36.41882265767744, 36.237624845197125, 37.42467134229599, 37.94096116096743, 37.891025466303674, 38.04478237705846, 38.0916037098054, 37.9595688850649, 39.44302105134533, 38.51747112889444, 39.38676641833398, 38.249384972356985, 38.202622475162634, 41.75443849255962, 41.540837980085804, 38.761995607806796, 38.599566336601015, 39.76008192185433, 39.01460016927412, 36.70084499543713, 35.801920121715916, 36.93977617448376, 41.08890248883156, 44.83566422616282, 43.694081921731275, 45.85289562902143, 52.692461936704575, 51.922963511559274, 48.09245917104906, 53.17564695112167, 48.66726290795111, 44.444219527706025, 43.27300763899281, 42.446113171116004, 39.533972970901, 36.13022250513877, 37.03683130202755, 37.53316410126225, 39.402722620194965, 40.75242980833977, 40.27423797115203, 38.21855122043241, 38.11439660287673, 39.53428676051479, 40.14183052124516, 40.89909899619318, 40.1466275799659, 40.078107695425714, 38.96318181868523, 37.56561386969782, 38.84517338968093, 37.88323956151163, 37.80891849148659, 36.683115882258264, 36.05677220129198, 37.53969092522898, 36.333930800038004, 38.19958656064926, 36.87251537076889, 36.76030420487927, 36.63641614298667, 37.95632116256222, 37.95029247960737, 38.563715873226045, 43.48917730392949, 48.2402580015121, 48.51378448547856, 49.205047315166844, 52.402500721716116, 50.58568631449054, 49.49185886690694, 46.53071257375902, 46.15609876571163, 44.926431794320386, 42.89340065371606, 41.04012389336863, 37.58026392229142, 43.84906653435, 45.11952223316316, 50.554848640195786, 54.89445309485159, 53.757189319979766, 57.9841786046182, 57.403224591285955, 59.81782782462336, 57.16474056243897, 54.381054062997144, 52.91977505530081, 55.713028215592914, 59.662529422390854, 62.25851089723649, 59.66865224222983, 7.224813661267681, 0.7081613809831682, 0.27340985474086577, 0.12118369491109926, 2.28542659071184, 55.96407559610183, 61.337554070257376, 58.44928541491109, 48.49314105126166, 36.6437941212808, 31.98635805037714, 49.445378780365, 66.68831809874504, 28.729174790843842, 0.1705074232191809, 0.0566271853993737, 0.056067450918377414, 0.05736949012404489, 0.03668582096936242, 0.040169042730403524, 0.028590866732561303, 0.04048531063862386, 0.026860362211723002, 0.08408242446039954, 0.062393506222795096, 0.03728203272687332, 0.035998138313692425, 0.0739029162533341, 0.11570002222734115, 0.03939451251719748, 0.015322107055615035, 0.03768012265584642, 0.04079543835213108, 0.015153987145411874, 0.07628246961582093, 22.086754652761645, 65.6610454282453, 51.61657148791898, 45.281520043649984, 25.60288102396073, 37.72617609270158, 56.93111242786531, 62.81482458114625, 57.770323138083185, 55.0143168049474, 1.9645895808935168, 0.25308924997525833, 1.6451756560033368, 1.4058912184930619, 5.67857317386135, 40.02924673018917, 53.33182004190261, 58.20379211056618, 54.28694463545277, 49.334705183582926, 45.265720736595895, 46.94703294384865, 53.53443399552376, 56.78353717250209, 54.62899884869976, 54.94702069990097, 57.39729788995559, 53.34869015601374, 51.30613550063103, 51.61580662573538, 49.48024865119688, 48.309515291644686, 48.79832498488888, 48.049815162535644, 48.44036556059315, 48.29499467726677, 40.892976176354196, 38.03373306028305, 42.05696698158018, 40.31926678073022, 38.69299719410558, 39.24131708760416, 39.97845595882785, 39.127635032899924, 39.212048361378336, 39.51802461378036, 41.1066198348999, 39.42859849622173, 37.43095497931204, 39.307648289588194, 40.74845252498504, 39.44049112258419, 38.881478847995886, 39.588474304445334, 40.57631930997295, 38.21341683787685, 40.75308484415854, 40.48344150666268, 40.71455932432606, 41.41953868250693, 39.201818819968935, 39.56037444453086, 41.03442861187843, 43.30795595722814, 39.245800356711115, 40.31380291908018, 39.35742708944505, 41.65366495809248, 39.75488478137601, 37.962302777075, 39.060087896162464, 42.85378471497567, 46.809173399402255, 46.52735502489152, 48.49070918175482, 53.99762668917256, 54.36640008803337, 48.985116097234915, 55.28231274697089, 51.71704299988286, 48.182508945465095, 45.858539919699396, 43.84715241770591, 41.527537222831484, 38.90193400844451, 38.70559976946923, 41.94022547814154, 41.11104819082445, 41.9784019070287, 42.19064527942289, 40.726157772925596, 40.159387050136445, 41.92282584405715, 41.7770823355644, 42.71387769329933, 41.554652567832704, 41.15597109640799, 41.10057938483454, 38.81579875946045, 41.06326979975547, 39.456957232567575, 38.39342224982477, 40.1142954826355, 37.751675421191806, 39.968210727937766, 38.957910153173636, 39.380184681184836, 40.592306890795314, 38.40230641826507, 38.55550243008522, 39.65681768232776, 40.371042067004794, 41.223812410908366, 45.23601662728095, 48.990183799497544, 50.78766092177361, 52.43823743635609, 53.78867026298277, 52.5331352603051, 49.46746172443513, 49.22281957441761, 50.811787420703524, 46.622441122608805, 45.385451086105846, 41.91494972475114, 41.3571455401759, 45.45217060273694, 47.073494080574285, 53.05878385420769, 59.135421706784165, 56.675475874254786, 59.34449188170895, 59.42885029700495, 60.640478287973714, 59.13106003115254, 59.57892802453811, 55.65267470575149, 57.38264391499182, 62.24577103891681, 66.26959723810997, 62.61962390715077, 6.966383889798196, 0.8727017453601285, 0.4710090887402335, 0.20889728420203735, 2.6869194209575658, 60.044729094351496, 66.08281397050428, 63.99394396812686, 54.36916928137503, 42.002724524467226, 35.458693119787405, 54.57836104977516, 73.8163080523091, 35.86258349880096, 0.12385906546466774, 0.04296681498207393, 0.05923857995038552, 0.05654013482853771, 0.02495200271838375, 0.021861086922487425, 0.03675145938271477, 0.08367982227355243, 0.05499078328871439, 0.20399683425503395, 0.09752972667375881, 0.141298497816728, 0.111104337378375, 0.1415665060161583, 0.18727584681924314, 0.29234292105801646, 0.17431500277692275, 0.1534065174599809, 0.16030400540799866, 0.11186990436286696, 0.18789728202166098, 27.510064878771384, 75.14690937534456, 57.31817583883963, 55.00775075727894, 33.855353709190126, 47.17676224247102, 62.373863881634136, 68.03027860579952, 63.254330081324426, 62.73193705466486, 2.279940175433313, 0.29720037815070927, 1.7636904384820693, 2.702002405158935, 6.47761243966318, 41.75957679748535, 58.852579593658454, 61.80821495671427, 58.87630208846062, 51.60928764650899, 48.02331562965147, 47.42585236026395, 54.31634672226445, 58.43257611797702, 55.70497558962915, 59.16913840078539, 60.76454677889424, 56.575482891451934, 53.73471413889239, 52.93924177846601, 52.031977945758456, 50.25847434997559, 52.032676127649125, 51.06028918297061, 49.90298994125859, 51.10761650146977, 42.11794414827901, 38.262489611102694, 45.7790687776381, 43.08040749642157, 40.86071860405707, 42.97458979391283, 43.57592052029025, 41.75068086193454, 41.0611399527519, 42.24812761429818, 43.71484694942352, 42.067992764134566, 40.253963239731334, 41.09355441985592, 42.334258940912065, 41.55701383467644, 42.413090736635276, 42.41196109402565, 42.5545863182314, 40.07749188330866, 43.09810130826889, 42.67135920063142, 44.46811852916595, 43.6965020241276, 41.075005531311035, 41.747923435703406, 44.48867959360923, 45.851726762710086, 41.565760720160704, 42.75495667611399, 41.944587153773156, 43.91495058613439, 40.27533231243011, 40.58861201809299, 42.058437870394805, 46.51159101916898, 49.5565152168274, 48.877113634540194, 50.088482749077585, 56.54031492048695, 54.94051741015527, 49.189483350323094, 58.64314856067781, 53.390432019387525, 49.08262621971869, 47.47841604294316, 47.392441611136164, 44.63429758625646, 41.2650090648282, 41.43558902125205, 42.31504717180806, 42.68967274696597, 43.699177080585116, 45.129532121842914, 42.12766378156601, 41.33090488372311, 44.89426051416705, 42.64423993326003, 45.091736162862475, 42.95813152866979, 44.743590508737874, 43.331466644041, 40.75134331180204, 42.855428188077866, 41.65441020842522, 42.757537595687374, 40.92668502561508, 39.6690829338566, 42.17472437889346, 39.97956206721645, 41.96364987281061, 43.319119022738555, 40.869857726558564, 40.62495670010967, 43.437300036030436, 43.221385325154955, 43.7678813165234, 48.770664430433705, 52.83135306450629, 53.56478137354697, 56.14759545172415, 58.32655445221932, 53.74421019707957, 54.03497942032353, 51.197336796791326, 51.924030396246145, 49.89309772368401, 47.75581782863986, 45.44087025427049, 42.55173083274595, 46.91822313493299, 49.049117411336596, 55.88020747707736, 57.18050849053168, 59.4419353238998, 62.413805377098825, 62.05757571804909, 62.28747760095904, 60.79272116384199, 61.26599827120381, 58.617927720469815, 61.277651632985766, 64.64795997065883, 69.09364884899509, 65.74680412969282, 9.13055016148475, 1.4350734074269573, 1.6607508976613323, 0.3232352633870417, 3.0412229511045643, 67.35431301978328, 70.45217744765743, 68.0127691453503, 63.60815140508837, 50.68049000155542, 43.66392281747634, 64.3682949773727, 81.4183242859379, 45.64569642466884, 0.34188515296386135, 0.1128129356150185, 0.10593819281747265, 0.2677721217755349, 0.12297552093983659, 0.07300077111370142, 0.16082368881231354, 0.23664483560189126, 0.11498667179576813], [0.041612555393047874, 0.07596048286124583, 0.025450670415715828, 0.05357319121098807, 0.02622965159976194, 0.053747518348597714, 0.024168930624821977, 0.06737993038710087, 0.07401943056573791, 0.008214136450401237, 0.029200935105402625, 0.037468372123135675, 11.841759104882518, 52.69363080301593, 51.48641940086119, 34.90934948767386, 27.984483395853353, 47.44828047290925, 44.42073629748437, 61.33195292565131, 51.618454225601695, 57.879129686663234, 4.48839956714261, 0.25921038442081024, 1.7216691062335046, 0.9906881723192431, 0.8172197579856842, 24.526394374908943, 56.06179360420474, 53.73465138096964, 51.365155404613866, 44.37314225781349, 44.756942256804436, 52.561529297982496, 56.34946415501257, 51.737192215458045, 55.359140211536044, 54.2599351944462, 50.142003490078835, 48.68217183697609, 47.47154405040126, 46.87298643973566, 46.041424351353804, 43.455825390354285, 42.54813794166812, 41.630495517484604, 40.44172317750993, 37.90941353767149, 37.53780818754627, 37.201841492806714, 36.81021636532199, 36.74417934110088, 37.19982147216797, 36.452327543689364, 36.37835164223948, 37.42574214935303, 36.87978744506836, 36.69538897852744, 39.50923065985403, 38.40695834928943, 36.132685753606985, 34.655854548177416, 37.221810279353974, 38.28200732508014, 36.19855411591069, 37.04875530735139, 37.44572270301081, 37.39577916360671, 41.2114804790866, 38.063919621129195, 38.971728663290705, 39.15060051025883, 39.590062864365116, 38.2275216810165, 38.83697171365061, 36.76887458370578, 38.26447433040988, 37.68541482187087, 38.38870363850748, 38.39402629483131, 38.02934392806023, 35.8612459705722, 35.05236694889684, 42.97025165250225, 44.19935380258868, 42.72264026826428, 47.10268043702649, 52.7994445831545, 52.582776777205936, 45.883093956978094, 53.12144764008061, 49.52244943188083, 45.73779367631482, 44.572406507307484, 44.521576512244444, 38.388111360611454, 35.35610352793048, 36.857437779826505, 37.80067366938437, 39.875113271897845, 39.03449443078811, 41.75626239468975, 39.71855971121019, 38.342105880860366, 40.76885669462143, 39.835924871506236, 40.113263899280184, 39.80754260093936, 40.828888570108724, 38.587034363900464, 39.06097435182141, 37.41507330248433, 37.25340889346215, 38.32077995423348, 37.78243857045328, 37.16906616764684, 38.095796723519605, 38.82214515439926, 38.205674079156694, 36.802865843619074, 38.45179888509935, 36.31462881642003, 36.01244549597464, 36.27767616702665, 38.23908875065465, 44.84707047862392, 48.24334490683771, 51.26920638545867, 49.767130805600075, 55.15383943434685, 55.82233682755501, 51.336294604885964, 51.32826159077307, 50.81885553175404, 48.959495175269346, 48.308554310952466, 46.492442007987734, 44.761884443221554, 40.89263493014921, 40.94481422055153, 45.0107313740638, 46.803093725635165, 50.57666486309421, 51.88959983087356, 55.01783124862179, 58.38292283396567, 58.32495804755919, 56.72826313203382, 54.001737333113155, 54.83023212802026, 59.66044272145918, 61.71199137164701, 60.19542263400171, 6.4618268609046945, 0.9834115014922236, 0.22842780716957586, 0.19721534734051074, 3.0229584343971747, 57.02934426646079, 62.42567054687008, 58.82675078607375, 48.30002315582768, 30.920098981549664, 28.745691891639467, 50.10387412963375, 63.94197648571384, 19.315454998323997, 0.15598143090403851, 0.10347329726022098, 0.06108776681245335, 0.037959993726784186, 0.05231312596269193, 0.03299322354817583, 0.023042637734643878, 0.04281999040094595, 0.052237758232701215, 0.07677672656192895, 0.09431914411365025, 0.03357276523245439, 0.034010324011286425, 0.042079980109607985, 0.02591564556613805, 0.028355562826618556, 0.10071933374650056, 0.04639526145652898, 0.0220479836477147, 0.07785677263933806, 0.07373227782907986, 14.753175627800728, 62.14419734093451, 57.39831770620039, 41.487654562919374, 27.063981563814227, 49.806311361251346, 51.21499922967727, 64.20920364318356, 56.421710291216456, 62.51435141409598, 5.029688612107308, 0.4502715789262326, 2.172951155131863, 1.3052595022224611, 1.004657448539811, 29.64920593846229, 57.64471707805511, 56.3069260504938, 52.28878336568033, 47.445268092616914, 45.597541486063314, 54.40422350360502, 56.95256779270788, 53.641769655289195, 55.30341509849795, 56.037890680374645, 52.852820196459376, 50.878483403113584, 49.81297154580393, 48.37867844489313, 48.635009258024155, 44.21870285464872, 43.61332424225346, 44.08504416865688, 41.70022741440804, 40.216206504452614, 39.918828087468306, 40.1784497691739, 37.87725402462868, 39.36556600755261, 39.49190947317308, 39.07650301533361, 37.63532223240022, 39.201461884283255, 39.219775430617794, 39.656527426935014, 41.279600281869214, 40.23933672135876, 39.18756100439256, 37.54375842309768, 39.23516681117397, 40.3342737690095, 37.86656164353894, 38.197288051728286, 38.634973572146514, 40.21694391004501, 41.83745153488652, 38.276841563563195, 40.47403958535964, 40.72051740461781, 41.224204647925596, 40.53899403541319, 40.64510199331468, 38.84116472736482, 38.981609113754764, 39.53331009034188, 40.32662122480331, 41.145870993214274, 38.893281259844386, 38.054258823394775, 38.22827085371941, 44.953358865553334, 45.7726360905555, 46.22543842561784, 49.48029964200912, 54.75896266198928, 53.85675868680401, 48.95137586901265, 53.730748622648186, 51.05770041865688, 46.32065788392098, 45.65734978645079, 44.52413781996697, 40.923052910835516, 38.721026451356956, 38.07350589383034, 40.664921729795395, 42.6500528858554, 40.35346984863281, 41.37314488810878, 41.26495807401596, 39.12867838336576, 41.49390289860387, 42.281471683133034, 41.99645265456169, 41.04889431307393, 41.71830561853225, 39.6093766150936, 41.51455025519095, 39.16214012330578, 40.17452739900158, 39.75626153330649, 40.06407345494917, 39.01363526621173, 39.89778064912365, 41.70849184836111, 39.12942755606867, 37.57381554572813, 38.90263611270536, 38.73925762791788, 41.16463561211863, 40.556295610243275, 41.55238151550293, 46.18129214932842, 50.09002424055531, 52.35314946020804, 52.42156344075357, 56.781007243740945, 58.67554733830114, 53.982078413809504, 53.69498445141701, 52.7460297461479, 51.26864156415386, 50.73221037464758, 48.325738214677386, 44.94443939578149, 43.03607294636388, 43.23929094499157, 46.78503905573199, 48.367711497891335, 51.9181429186175, 52.44927106365081, 57.096687439949285, 60.41985673289145, 61.182542001047445, 59.07731571505147, 57.2304637970463, 58.109969016044374, 61.13194342582457, 64.31022820934173, 62.277008794969134, 6.889609867526639, 1.0251442330979532, 0.43241587737875603, 0.26821715757250786, 2.869879113089654, 60.71955327064761, 68.63990122272124, 62.525906716623616, 54.08679393029983, 31.820598686895064, 32.61944232448455, 54.56802952674128, 70.21113211108793, 24.95340124253304, 0.10796400508092296, 0.11159136245447783, 0.07392007662283798, 0.029331838464244243, 0.06110004337143995, 0.034235289560691, 0.028193006629965482, 0.07748011018960707, 0.05929172730013248, 0.18102190337113797, 0.22490993142127993, 0.17832300625741485, 0.15847438826195656, 0.1584301696669671, 0.07367630744533193, 0.10919867834496884, 0.17853977849646924, 0.1640390824045866, 0.0854869777216546, 0.17366798023783392, 0.18657495297731894, 17.71774418892399, 69.75372099107312, 65.91659961208221, 47.96444085336501, 39.096542404543975, 59.801801020099276, 55.10386451598137, 69.74045553515035, 61.18643691462856, 70.41858626950172, 5.56637034300835, 0.8005949145843907, 3.1313112137779116, 1.9809636377519177, 1.5167179102859192, 31.25187070138993, 61.80751285245342, 57.8134927441997, 56.27626096048663, 48.249832507102724, 49.081449508667, 55.743587401605424, 58.792477115508056, 56.28152085888771, 59.62536496500815, 57.416752846010276, 54.33415036047659, 52.59647369384766, 53.10581699494393, 51.672884956482925, 50.564223104907626, 46.31125988498811, 45.37155412858533, 45.637902675136445, 44.70821857452393, 43.356059905021425, 42.55537471463604, 42.41185126766082, 39.805781456731985, 40.66645929890294, 42.238074579546534, 41.02937659909649, 40.52273581104894, 41.389987545628706, 42.018519909151145, 42.54035988161641, 43.26614741356143, 43.55435532908286, 40.26212176968975, 39.484339298740515, 41.11027940627068, 42.845837993006555, 40.63779461768366, 41.52226555731989, 41.88634780145461, 42.48141842503702, 45.03153954782794, 41.36342133245161, 41.996323216346006, 43.885285700521166, 43.40295968517181, 40.79229285640102, 42.47519362357355, 39.19056161757439, 41.188122764710464, 41.2325632187628, 42.6838872509618, 43.621380790587395, 41.37123077146469, 41.6870992414413, 39.246282808242306, 46.15075257516677, 48.72861662218648, 47.51458814067226, 51.070314761131044, 57.613581303627264, 55.19215314619003, 46.822760489679155, 56.12905440791961, 52.83211792668989, 50.32346802373087, 48.34151006514027, 48.58586588213521, 43.455664573177216, 40.60141463433543, 40.749048725251235, 42.042822914738814, 44.802508431096236, 41.80712769108434, 44.94782832361037, 43.37614244030368, 40.37570968750985, 44.05039002818447, 43.552617719096524, 44.9137625386638, 42.753132773983864, 45.01727388751122, 43.231924733807965, 42.13581054441391, 41.0590571741904, 40.93830700843565, 42.13608511032597, 41.63133490470148, 40.486210700004335, 41.164521863383634, 46.33572370775285, 43.512589931488044, 39.865852555921, 41.54152439486596, 40.609329977343165, 43.468325984093454, 41.019162747167776, 43.205680154985004, 49.67434321680377, 53.156917633548865, 54.79715085798695, 54.69292563776816, 60.74311887064288, 61.48317206290461, 57.11755837163618, 57.267459592511585, 55.78676093009211, 54.01022141979587, 54.27863313305763, 50.12205823775261, 48.39836482078799, 44.75358470793694, 47.133933882559504, 48.09113340993082, 50.68734238224645, 54.75438133362801, 55.317990626058275, 61.49103249272993, 64.07891427316974, 63.1155409351472, 63.25980178771481, 58.99257290747858, 60.851744990195, 65.23015345296552, 66.60664650701708, 63.144331132211995, 8.399359564627371, 2.2344568612114077, 1.1744846163257476, 0.5283786248295538, 3.66489157561333, 66.8513318031065, 73.61716931866061, 68.57495461740803, 60.83919732801376, 41.050294599225445, 40.75804664242653, 63.81871992541898, 78.26669200774163, 32.2577880274865, 0.2946226148595733, 0.17377212223026062, 0.1712093742624406, 0.1519298983076888, 0.14085235885314404, 0.08658999877591288, 0.16245804546821505, 0.17454787818414552, 0.18771026463758564], [0.06552710843783233, 0.04225925617520848, 0.09167056365479385, 0.10490395879793553, 0.03498918519565656, 0.05477230267358884, 0.05534529047567518, 0.04957023241947736, 0.03627260080388477, 0.024358736568941705, 0.03523475084934504, 0.03680411260575056, 6.999897110846735, 52.55772067654518, 48.80996265719014, 32.5106083193133, 19.42277692979382, 29.28061100744432, 45.17314887815907, 58.31644650428527, 53.085518729302194, 58.3734267757785, 9.007488739105964, 0.5171355184528136, 1.6254391473147178, 1.0978247105113923, 0.1656099303715652, 13.040288340660835, 55.01890990041918, 53.45594736837572, 51.32339392938922, 43.78390812104748, 49.23568887095298, 55.272263634589414, 52.72038136759112, 54.97853302186536, 53.96066619503883, 49.069407832237985, 50.62149755416378, 46.474771730361454, 43.67625867166827, 40.831736210853826, 40.204258964907744, 38.46684117471018, 39.018918698833836, 36.44146257831205, 36.569743694797644, 35.33018450583182, 36.81763748968802, 36.563487514372795, 37.3178534353933, 35.951950780807, 36.827270830831225, 36.93346508087651, 37.26157526816092, 37.55863597316127, 38.40036484502977, 37.948299915559836, 36.43710874742077, 37.75060461413476, 36.61564719292426, 36.93135876809397, 36.87383328714679, 36.17411382736699, 35.75919374342888, 36.98055313479516, 36.758225348687944, 37.276915657904844, 38.72587450088994, 38.8474718986019, 40.03029008065501, 37.91366930930845, 41.42351596586166, 37.98457399491341, 38.61444388666461, 39.397050872925796, 38.82154895413307, 38.60242182208646, 39.25292730331421, 39.04344135715116, 37.95569750570482, 34.786394949882265, 36.75269480674498, 41.79141075380387, 44.80947848289244, 45.04316937538886, 47.297080947506814, 53.788246647004165, 52.686056706213186, 46.882694305912146, 54.29995905968451, 50.48386158481721, 48.102014064788825, 43.24881053739979, 43.552276472891535, 39.58918033107635, 35.85889254846881, 38.71885738065166, 39.08252385354812, 38.00974776667934, 40.62439187880486, 39.836807404795, 39.44788871272918, 39.059836864471436, 39.580841372090006, 40.38987336620208, 41.36717504070651, 39.89236777828586, 39.40153414203275, 40.44090340214391, 38.479031901205744, 38.218206051857244, 37.91686604099889, 37.377853931919226, 38.05768697492538, 37.04622537859025, 38.5040173992034, 38.513329105992476, 37.40529091127458, 38.403796918930546, 37.51439555998772, 36.67072903725409, 35.89795151064473, 36.32825120802849, 38.05159945641795, 43.1415258684466, 45.33232258212182, 48.8251853758289, 52.20429943453882, 49.07259279681791, 49.302812391711825, 48.258351895116995, 48.2721939394551, 49.69949345434866, 52.32290798617948, 52.74324878569573, 50.43116454155215, 47.463542415249734, 43.61272804198727, 42.70651540448589, 41.54760406863305, 43.08360030574184, 43.47393497343987, 43.913346336733916, 48.48461774087722, 54.86480389871905, 53.145738878557765, 52.53274694565804, 49.26709528892271, 52.45975948149159, 58.3402866701926, 64.9319395711345, 55.81754369120444, 3.1721550995303742, 0.48064092835111005, 0.18240899748859868, 0.11282742999854589, 4.351365681617491, 63.02147073130455, 59.02879991839009, 59.749692332360056, 44.01510830848448, 39.09183163796702, 36.797590255737305, 48.134161810721125, 58.98179423424506, 11.93851613229321, 0.2821577208176736, 0.039356012768562765, 0.04339433417865827, 0.06234126668723841, 0.03473307434169035, 0.02545332682559327, 0.02663547710155047, 0.028861146382687074, 0.008412071545007489, 0.02216299451256712, 0.05363707528299382, 0.020171824745052767, 0.09497494602035131, 0.08914223601741177, 0.07467761500588349, 0.11181975624734357, 0.02284994746948923, 0.06909107969653222, 0.048234404905909495, 0.0038433458089017344, 0.04219646760893445, 9.102239474173516, 59.359847960933564, 56.603629819808475, 36.75439711539976, 28.667497481069258, 43.48705530166627, 51.6714846703314, 64.2320945955092, 56.029508575316406, 64.64842281033917, 8.29284171904287, 0.24154761445618447, 1.8714086519133661, 1.4832683051786115, 0.328761882959835, 15.256437293944822, 58.60812963977937, 54.55254400930097, 52.832714126956084, 45.77067882783952, 51.63898783345377, 57.66728247365644, 53.96116825842089, 55.07826320586666, 56.5200323443259, 51.98157156667402, 53.257722546977384, 49.1728917244942, 46.793005389551965, 42.16620106850901, 42.89201213467506, 39.69562561281266, 40.04656007212978, 38.039267524596184, 38.21098104599984, 37.90998620371665, 39.25201731343424, 37.221096407982614, 38.55237237868771, 39.19651577549596, 38.656758416083555, 39.48084446691698, 39.77833663263629, 39.22670233634211, 39.91038714685748, 40.307217259560865, 39.61262433759628, 40.15011848941926, 40.30836259165118, 38.361505923732636, 38.90106324226626, 38.44745289894843, 37.7584768110706, 38.81819925000591, 40.278034825478834, 39.899490802518784, 41.34862222979146, 40.97239632760325, 41.33961646787582, 40.252519807507916, 44.985192821871856, 40.14133238023327, 40.69326085429038, 41.788182643152055, 39.892422691468276, 39.92604917095554, 40.834732901665475, 40.174558777962964, 41.01482460575719, 37.836324091880556, 39.16741571118755, 44.261762634400405, 46.605272908364576, 47.06184071879233, 47.90609951942198, 54.78062983482115, 55.36123475720806, 50.05698611659389, 55.14602999533377, 53.77498903582173, 47.77985411305582, 46.109132305268325, 45.226034195192405, 42.05609621540193, 39.717481059412805, 40.25075866330055, 40.00956819903466, 40.71270796560472, 41.211351040870916, 41.16679683808358, 41.95469117933705, 40.931737038397024, 41.87195270292221, 40.51120012037216, 42.179564583686094, 42.057084652685354, 41.50213595359556, 42.42172387338454, 40.479366164053644, 39.640249590719904, 39.914693909306685, 38.14404579900926, 39.32832310276647, 38.552894053920625, 39.17009076764507, 40.43824795753726, 40.22683612761959, 40.613036617156, 39.61844121256183, 38.57800506776379, 38.84427908928164, 37.28625482128513, 39.88679801264117, 45.879363782944225, 48.88990448367212, 51.07047950067828, 52.4857138049218, 50.96025697646603, 50.80855538768154, 49.728193436899495, 51.57574353679534, 53.13943955206102, 53.499344471962225, 55.65848373597669, 51.586224109895774, 49.7803335036001, 47.18432064979307, 45.98937842153734, 43.91786098480225, 44.3931463456923, 46.61858935509959, 46.90959392055389, 51.913565512626406, 57.378086120851584, 55.43227672576905, 54.364485971389286, 53.69256827139086, 56.2759393261325, 60.81801652908326, 67.13238531543364, 57.95936176853796, 3.3918230283644895, 0.8993569473105093, 0.345712129867846, 0.3261428428513389, 4.448447775456214, 67.78236127668812, 63.017426767656886, 66.50318222661173, 51.81473355139456, 43.1315512810984, 42.35753820788476, 53.01775586220526, 67.32618178090742, 16.858549002678163, 0.3112201855307625, 0.13702792536106803, 0.08222230935409185, 0.03274033409393123, 0.04136731532672721, 0.050667810419033614, 0.03185063979828791, 0.0216246951716922, 0.01490554578917762, 0.1533886369678282, 0.25239276879977796, 0.11594828834096271, 0.2024640148926166, 0.12085800795184991, 0.15285323343930707, 0.17756099392089153, 0.09490618962914714, 0.14967422902343736, 0.11757833958272973, 0.14841704809617612, 0.1217010953733998, 9.971901505224167, 67.31476768370598, 62.44764758694557, 45.15277608748406, 29.39798401248071, 39.544029928022816, 58.76751122936126, 68.8283005068379, 62.07619520925707, 69.23067292859479, 11.496416964838582, 0.8809354132221592, 5.544062843245845, 3.348719367096501, 0.697888141918567, 16.471783691836944, 61.337636440031, 58.25782275968983, 55.92621295682846, 46.95813717380647, 55.15228225338844, 58.777434825897224, 55.92248278279459, 57.2549746882531, 58.78758984227335, 53.14386006324522, 57.24470984551215, 51.5704365699522, 47.99503926307925, 45.426694808467744, 44.51641467309768, 41.81723171664823, 42.07338994549167, 40.08964730847267, 40.617123726875555, 38.70589786960233, 41.42237455614152, 39.599154918424546, 41.43727956279632, 40.59443673779888, 40.94220584438693, 42.46491309135191, 42.60655380064442, 42.78530013176703, 41.39037193790559, 42.69955319743003, 40.152699408992646, 42.17951359287385, 42.34229587739514, 41.156708502000384, 40.903998036538404, 40.40635124329598, 39.23504521769863, 41.90310024446057, 41.709366536909535, 42.01316195149576, 44.05682271526706, 42.66536974137829, 45.13852611664803, 42.456989903603834, 46.100789423911806, 43.63725070030459, 42.094719794488725, 43.66002005915488, 42.65446162992909, 42.25186955544257, 42.569040252316384, 42.041234354819025, 42.90894500670895, 40.2574816057759, 42.43738197511242, 49.15189135459162, 50.05376585068242, 49.47176456451417, 50.69058618237896, 57.71925387843963, 56.96043998964372, 51.00159091334189, 58.88297404012373, 57.24940884497858, 52.9235601425171, 49.0233866630062, 47.791821264451556, 43.41807257744574, 40.95616948220038, 42.90126108354138, 41.49258890459615, 41.376671098893695, 43.502658490211736, 44.22442559273013, 44.32419107806298, 43.8758877015883, 43.74398623743365, 44.19883997209611, 43.72712789043304, 45.18370005392259, 42.98263457513625, 45.056540735306285, 42.013189408086966, 40.541724005053126, 41.42275110367806, 40.5283526451357, 42.86265319393527, 40.82614683335827, 41.677791457022394, 41.845978767641135, 41.45230616292646, 42.6557207107544, 42.04217572366038, 39.88204409999233, 40.83416808036066, 39.60636815717144, 42.8193933733048, 48.64555258904734, 51.37980545720747, 53.93825769424439, 54.96391434823313, 52.22351904838316, 52.30529654410578, 51.984274079722745, 53.51817969352969, 54.57552909851075, 55.95723498252131, 57.96972467053322, 55.24403041408908, 52.9791283607483, 48.9018363337363, 47.47975749354209, 45.24657957015499, 47.561005469291445, 48.44629226192352, 48.84258893228347, 53.29978212233513, 60.545184304637296, 58.68228989262735, 56.78693786744149, 56.60111165815785, 57.56739147247807, 62.869239622546786, 69.77960078947007, 57.968002750027566, 4.074890555873994, 0.7954229630770222, 1.8675739221995877, 0.4870353110374943, 4.990849302661035, 73.85042482806791, 70.00629809594923, 73.11282311716388, 57.876309502509336, 53.370820168525945, 51.011408605883204, 61.2831586407077, 76.6808149891515, 23.603550887876942, 0.3964146172567722, 0.19682666497124782, 0.11254432220612803, 0.11172907441974649, 0.2749725515323301, 0.17926886437400696, 0.2265857181121265, 0.09249210102303375, 0.13725625020602059], [0.04373792078225844, 0.1173370065648229, 0.029169820444357973, 0.05870979159109055, 0.0494982929329478, 0.03934473595431736, 0.01502044078323149, 0.006497741832713327, 0.0012621265036174127, 0.04891361079869732, 0.031408070804431074, 0.05863332452492849, 2.4460930016732987, 45.79483670573081, 52.7575340578633, 41.47615025120397, 21.98499660338125, 32.62858144698605, 39.01118378485403, 58.30697398031912, 52.38680731865668, 60.14462401790004, 18.97730158221337, 0.2972099082844873, 1.2882605627659829, 0.44328828913069546, 0.04287114592208978, 4.087466900387119, 51.73708238909322, 53.66211891174317, 51.39479283363589, 44.842999058385054, 52.85131792868338, 53.616046751699145, 57.44637850792178, 52.2019499348056, 51.704083488833525, 47.876364031145656, 46.34878520042666, 42.2977848206797, 39.799011445814564, 38.835183112852036, 39.68828293585008, 36.03344978824739, 36.671435063885106, 36.929821198986424, 39.20652174180554, 34.73340372885428, 35.100702316530295, 36.28584646409558, 35.91524524073447, 37.7306358275875, 39.69859484703311, 38.27223277861072, 39.02237038458548, 38.89683100485033, 39.751331113999896, 38.75306044855426, 37.8616508360832, 37.632407911362186, 38.29687310803322, 37.30805143233269, 37.58750461762951, 36.43864631652832, 35.99147650503343, 36.85933620698991, 36.60202087894563, 37.91781133221042, 39.338615402098625, 37.043134550894464, 37.19999797882573, 38.441110426379794, 38.748737996624364, 38.78958948196904, 38.87911758115215, 39.09304365035027, 38.976702228669204, 40.31649758738857, 38.072690040834495, 37.92102767575172, 37.64350821894985, 34.23221503534625, 36.35064794171241, 41.40857958024548, 43.54947197821833, 43.43048295667095, 46.80702001817765, 53.395158475445164, 54.34497610215218, 45.137855391348566, 53.73973085034279, 51.67577182092975, 46.656330400897616, 43.60199251482564, 44.182624893803755, 38.7043014649422, 36.83326813482469, 37.90744450784499, 40.62277978466403, 40.81895712883242, 39.12400684049053, 39.76800903197258, 40.09703705387731, 38.47395243183259, 39.3978431917006, 41.36711620515393, 40.42234666885869, 39.714005839440134, 39.443742767457046, 38.47390536339053, 38.654459907162575, 37.10235449575609, 37.529469228559925, 36.745760056280325, 37.48650750806255, 37.50522898089501, 38.139425246946274, 38.06425302259384, 37.04273054676671, 37.42877021912606, 38.5243901898784, 36.36346624743554, 35.76710124169627, 36.718432903289795, 37.25212627841581, 38.117208942290276, 44.89862611216884, 49.81903945246051, 53.05263750014767, 51.96138312739711, 50.45109802676786, 48.17271870951499, 49.63708070016677, 49.136209718642704, 46.398077626382154, 49.52526961603473, 52.5100834908024, 54.581840192118, 47.98071084483978, 44.389376947956706, 42.84379836051695, 41.44521059528474, 42.864092703788515, 43.19015541384297, 40.95480057501024, 44.54183947655463, 46.24071605743901, 49.878784994925226, 47.78804009960544, 55.07078324594806, 55.65245113065166, 65.63061568044847, 44.16151077516618, 0.5680390579565879, 0.18113295547664168, 0.0936255434287652, 0.35610665597261926, 7.637947105592297, 63.66292338217459, 59.26388325229768, 54.41193488336379, 44.93702219378564, 29.451561627849458, 14.760252564184128, 48.238116387398016, 51.04343083596999, 10.839878878285809, 0.22050157039155885, 0.13552892111962841, 0.08115458197050518, 0.0019233712256180064, 0.04396913760912515, 0.043486494555949204, 0.015043833277999394, 0.07324680791146333, 0.052941341043239644, 0.07308295702621823, 0.060664507064728014, 0.013387736004416742, 0.039011774990226955, 0.022252709154159795, 0.023820557886914864, 0.08368482482769797, 0.0316635055858041, 0.045980827041691354, 0.024951156191227418, 0.05535389364306485, 0.0981337946629332, 3.0971981152411434, 52.96467442666331, 56.60821507053991, 47.14394377123925, 24.832739330107167, 36.50810756990987, 46.84865205518661, 62.344838342359, 56.80809513215096, 65.39053132457119, 19.371821418885265, 0.239516117820336, 1.4625167606338378, 3.0579297965572727, 0.8047904410669882, 4.809272000866552, 58.35056720241424, 54.86222297914567, 52.838166221495605, 46.01765478810957, 55.81773980971306, 55.51605070790937, 58.439165699866514, 54.59884758918516, 53.99068017159739, 49.47341980472688, 48.07420053789693, 45.64207607699979, 41.8563259801557, 40.63909684458087, 40.254018152913744, 38.17782525093325, 39.6285609276064, 37.86146256231493, 39.279509205972, 37.5393065329521, 37.16710498256069, 37.20840754047517, 38.15756620899324, 39.092925979245095, 40.863523098730276, 40.24184703826904, 40.38513514303392, 40.90756739339521, 40.65933235229985, 40.44569261612431, 39.18805130066411, 38.59477712262062, 38.642567280800115, 38.58151166669784, 39.239363747258345, 37.98222841755037, 38.40647982012841, 38.11050561166579, 39.24154850744432, 40.677653743374734, 40.98656785103583, 39.42180887345345, 40.09790782005557, 40.36878278178554, 40.60962807747626, 40.18047371218282, 40.67438248665103, 42.23503082029281, 40.18552572496476, 40.246067508574455, 39.783835795617875, 40.060296212473226, 40.64506669198313, 36.316495864622055, 40.60501144778344, 44.76657952031782, 45.24004097907774, 44.89993618380639, 49.47323545332878, 55.46907640272572, 56.7341309978116, 48.694715576787154, 55.612693986585064, 52.23652955024473, 48.17538592123216, 44.87176572122882, 44.3552327156067, 41.282542059498454, 39.86437382236604, 40.94823844971196, 42.10226251233009, 42.80519831565119, 41.23068440345026, 40.18529822749477, 42.024226957751864, 41.83065406737789, 42.075711988633685, 42.073021242695475, 43.169257025564875, 42.73076349689115, 42.15076654188095, 40.23525745637956, 40.934925925347116, 39.57469894040016, 39.89897697202621, 39.4685713706478, 39.76551440454299, 39.64962797780191, 40.29779572640696, 40.93525932681176, 38.538593092272365, 39.448151511530725, 40.788111609797326, 38.887923302189, 38.05776149995866, 39.502613621373335, 38.87382238141952, 40.0666896758541, 48.39288526965726, 51.00909832985171, 53.442113168777965, 53.058881913461995, 50.71290054628926, 48.609655057230306, 50.76139280872961, 49.805711238614975, 50.225797084070024, 52.347685598558, 55.62390019816738, 55.24529341728457, 50.17058972389468, 46.473649932492165, 44.539297780682965, 43.205252616636216, 44.41509985154675, 44.33978249949794, 42.63182170929448, 47.76475691026258, 48.81272792816163, 51.62167449151316, 50.43045459255096, 56.929884726001376, 58.53804472954043, 67.09434616950251, 47.3953559321742, 0.85497900603279, 0.5662289454090981, 0.2016138564795256, 0.42522755181116445, 7.813761465011105, 70.08514558115314, 63.47752471123973, 60.27286198831374, 46.037835382646136, 29.352504130332704, 21.33716029505576, 54.019784158275975, 58.540390306903475, 13.73134328472999, 0.30065047043946486, 0.04464789534047727, 0.08554953646155135, 0.03084992021021824, 0.03635799279436469, 0.03558965640202646, 0.02411212712045639, 0.04379489091074756, 0.08145982970393474, 0.13837369669589306, 0.18932595939165164, 0.08378772575768732, 0.09713860048401741, 0.1839186503521858, 0.21911550283191666, 0.1320682108522423, 0.17011331694741405, 0.15897107370678457, 0.10810335647434959, 0.07925400976091623, 0.28016849691348694, 3.335907925521174, 60.03851998236872, 65.6762485350332, 54.65137597053282, 31.97580687461361, 45.1329053601911, 52.309367964344645, 66.10171979473483, 62.42185015832225, 70.11906623840332, 23.517976537827526, 0.5559351751881262, 4.101612192969169, 4.047302320118874, 0.741790495812893, 6.513016243134776, 58.97415737951956, 56.94516235782255, 55.36290960927164, 49.497687508983, 59.14883229040331, 58.41408606498473, 60.18799366489534, 55.60938350615963, 56.72479967917166, 51.94457577120874, 51.33574155069167, 47.793519650736165, 43.879100122759425, 44.84320694400419, 43.400488591963246, 40.13573515799738, 39.993976777599705, 39.78081949295537, 42.903351706843225, 39.083065140631895, 38.924056176216375, 40.501578546339466, 40.29156700257332, 41.395051325521166, 43.50773795958489, 42.629205488389545, 43.685935158883375, 43.682495240242254, 42.34377068857993, 42.30876745716218, 41.27771362181633, 40.79070429648123, 42.730830177184075, 40.34598596634404, 41.16783626617924, 41.54905926796698, 39.2932100449839, 41.67608914836761, 41.96961579784271, 43.736729852614864, 43.48847519966864, 42.15337491804554, 40.55623285232052, 42.33548272040583, 42.634484998641476, 42.048333844830914, 42.35210964756627, 43.51598278168709, 43.14721722756663, 43.28238994844499, 42.736086153214984, 42.37669114143618, 42.437734988427934, 38.42001591959308, 42.07466863816784, 46.95965513106316, 46.902561110834924, 48.17793546184417, 52.768803027368364, 58.943358928926536, 57.564657580467966, 48.881942072222316, 60.41325146152128, 54.82289729579803, 52.689716277583955, 49.29294763072845, 48.16902775918284, 43.515355202459524, 41.99494646441552, 42.892204330813506, 44.85372674080634, 43.80723445646225, 43.15607001704555, 42.5848787830722, 44.27065464758104, 43.91173032022292, 44.061698221391254, 44.95012291016118, 45.072234138365715, 42.76073040500764, 43.129091955000355, 41.224114433411636, 43.057865635041274, 40.61133430850121, 42.57696736243464, 41.56154024985529, 40.882993744265654, 41.18774229480375, 42.191876903657, 42.80961882683539, 41.53337763201806, 40.838741563981586, 42.59062113300447, 40.07433829769012, 39.625038639191665, 41.426912738430886, 41.38506889343262, 41.6987879045548, 51.32324487932267, 54.2058967005822, 56.501812934875495, 53.71081513743247, 52.14634249287268, 49.738568106005275, 52.7798915678455, 51.56594153373472, 50.871705547455825, 53.7602879924159, 57.19258939066241, 58.705122009400405, 52.32003681121334, 48.36356163024903, 47.61500473945372, 45.57769037062123, 46.15731077809488, 46.985578075532, 44.66329566894039, 49.101943892817346, 51.83591827269524, 53.87001237561626, 54.44010142357119, 60.20156114332138, 59.90308838505899, 68.2245300662133, 50.089804587825654, 0.9123166422209433, 1.5536355034958933, 2.3558397543045784, 0.7431700056599033, 9.607643735024238, 76.82297737367692, 69.91151009836506, 65.98413498170915, 58.0387270066046, 40.63905762087914, 25.44506642126268, 62.65631375774261, 69.12130940345027, 18.953457493935865, 0.44195832985062755, 0.23086768995609977, 0.23990619446962114, 0.14516711926027653, 0.162421349856642, 0.1359327873515506, 0.18877146495205743, 0.13905395212913715, 0.2086066304435653], [0.010833452350550122, 0.05900978013091992, 0.048961062284727255, 0.028209251524399848, 0.12975877751746487, 0.04060992250038732, 0.02523872261536458, 0.08622989148622559, 0.06481473859880241, 0.04330209336213527, 0.05474715200703471, 0.03805065640218316, 0.7625644101250557, 40.11691170354044, 54.80321484227335, 39.99134094484391, 34.09972521566576, 40.79724288755848, 40.17013042203842, 54.895747477008456, 53.95630059703704, 59.570996992049686, 32.15047394075702, 0.0747214122525146, 0.8525581681920636, 0.9647443289718322, 0.30984784626672346, 1.1972200221592382, 43.10694233063729, 58.07780950300155, 52.94136770309941, 46.78768665559831, 53.005643583113155, 50.76576625147174, 57.25942657839868, 54.50990000078755, 51.06541179841565, 46.854257122162856, 45.56187929645662, 39.56475180964316, 37.286364647649954, 37.619087542257006, 37.54164818794497, 36.179130538817375, 38.47352881585398, 36.065032712874874, 36.51453633462229, 35.5423298189717, 36.16775958768783, 36.859042029226984, 35.87771992529593, 38.42587594063052, 38.10593605041504, 36.782700938563195, 37.100734556874926, 36.90302748833933, 37.87685786524127, 37.856539987748675, 36.757527166797274, 38.914822916830744, 39.19397015725413, 37.58339397368893, 37.89193937855382, 37.373029416607274, 37.07820054023497, 36.37068733092278, 36.68613218492077, 38.107187286500015, 38.5039742531315, 37.31054605976228, 39.003766582858184, 37.345447309555546, 40.14810631352086, 38.619233100645005, 37.85808540159656, 38.61152172088623, 38.3683975281254, 39.52515548275363, 37.83012674700829, 38.49079901172269, 38.28820466995239, 35.835385784026116, 37.03049667419926, 39.7660086231847, 42.701357487709295, 42.80530421964584, 47.205207270960656, 55.16857970145441, 51.91185928160145, 44.72044460235104, 55.320379349493216, 52.53572402461883, 46.61072108053392, 44.2423233678264, 44.16491147010557, 39.58579140324747, 35.55199846144646, 38.59486733713458, 38.321376154499674, 40.11543296998547, 39.71723395009195, 42.03532726533952, 42.27476050776821, 39.09745239442395, 40.72476140914425, 41.38295473590974, 39.6269174545042, 40.21953267435874, 39.10013529562181, 39.22272113061721, 38.70654506068076, 38.93657638180641, 36.96723668806015, 38.16725838568903, 36.78613693483415, 36.69254918252268, 37.71622896194458, 37.64550470536755, 37.27761776216569, 38.6114981866652, 37.99714126894551, 39.562531748125636, 36.43905424302624, 37.26951022301951, 37.86855420758648, 37.1041666307757, 39.52503781164847, 44.06823289009833, 47.28993438905286, 50.82278182429653, 53.21193671995594, 52.27644358911822, 51.705746573786584, 52.44412491398474, 51.707025266462765, 53.075355868185724, 47.334049286380896, 49.91466683726157, 52.534566925418, 54.791220234286406, 49.70280001240392, 51.176046171496, 48.469559761785696, 48.06266092484998, 45.238911336468114, 42.26450743213777, 39.6565156598245, 46.061510809006236, 46.23329493307298, 57.839623574287664, 56.31957961666969, 69.87341603925152, 27.894614050465247, 0.1301314946143858, 0.5157479187173228, 0.3710259731498457, 0.46769637133805986, 9.568498480704523, 64.75353840858706, 54.894912012161754, 54.70152347318588, 35.71097212453043, 36.507507447273504, 33.48527416106194, 48.658268913145996, 46.422035463394664, 7.615839646708581, 0.3038589385969024, 0.06573369936837305, 0.1502171708571334, 0.041554267593328996, 0.04012069109106257, 0.0153782268265082, 0.09975676725227987, 0.03871786918851637, 0.018636935030020053, 0.10439506957247373, 0.02694967082671581, 0.08255576444489342, 0.06359182095395462, 0.037857284318775906, 0.03542197124672032, 0.058617635044239225, 0.14023820148600688, 0.058215515492784406, 0.022348292029252457, 0.026919015818425727, 0.012940042839956381, 0.8171863565521856, 48.74886781938615, 62.340547269390484, 46.900596003378595, 29.68539764804225, 38.89269290431854, 46.117659538022934, 59.939025140577755, 58.85425052335186, 65.06028344554286, 34.31222354212115, 0.076856522280122, 0.6833120014879012, 3.72214739361117, 1.2829440351455443, 1.3268847547231184, 46.13304307383876, 59.61238976447814, 55.70888227032077, 48.51162718188379, 55.951531856290764, 53.57323015889814, 59.499833430013354, 56.65393421726843, 52.42114374714514, 49.62097937060941, 47.32134472939276, 42.14176077996531, 40.28912728832614, 39.37410500741775, 40.444119745685214, 38.35634800695604, 39.85135547576412, 38.499530207726266, 38.245662643063454, 35.54634632602815, 36.87316648421749, 37.728968820264264, 38.85446548461914, 40.098825654675885, 39.098327082972375, 38.32362367260841, 38.929512193126065, 39.28011325097854, 39.59639749219341, 38.634389138990834, 39.38422472246232, 40.2809726807379, 41.31875730329945, 38.077793044428674, 39.420781212468306, 39.26257633393811, 38.92706463413854, 38.83770911924301, 37.99479569158247, 38.46739422890448, 40.43247030627343, 38.897258543199115, 40.14761601724933, 40.110235829507154, 41.987517495309156, 40.18337234374016, 39.52505742349933, 41.45935073975594, 41.20278458441458, 40.47354536671793, 40.29646212054838, 40.61333863965927, 39.58832917674896, 37.20771328095467, 39.897580608244866, 41.21858389146867, 46.43863885633407, 43.439351435630556, 50.14613374587029, 55.74545837217762, 53.32388900941419, 47.11356109188449, 56.30135628484911, 53.50060355278754, 49.45452182523666, 47.115463441418065, 46.14492393309071, 41.6903155849826, 38.1152085335024, 39.94978735523839, 41.62451390297183, 42.3094734837932, 40.90769290924072, 42.28440169365176, 44.01190765442387, 41.177155817708666, 43.09351605753745, 40.05549130901214, 41.31642349304692, 41.30085560583299, 42.87154912948609, 42.248057011635076, 39.8413416647142, 40.51957830306023, 38.78379614122453, 38.5174201380822, 37.68958430136404, 39.29615966735348, 39.883616970431426, 38.998400780462454, 39.47603564108572, 39.888704284544914, 42.65591682926301, 40.865092046799205, 38.3519902536946, 39.4431112658593, 39.33534022300474, 39.59499328367172, 42.000661357756584, 48.1126005418839, 51.19430480464813, 53.61967102173836, 54.189913042130016, 54.609732166413345, 54.320916283515196, 53.78800346005348, 52.708276933239354, 54.953104296038234, 50.385319878978116, 54.316264352490826, 55.66368479882517, 54.42980127949869, 52.95984206661102, 53.14851591663977, 50.56008108200566, 50.9940246612795, 46.20963911856375, 43.6321202401192, 43.49898715173045, 47.86465575618129, 47.50444096903647, 58.95069768351894, 59.43016429101268, 70.9665649167953, 31.621932598852347, 0.08890523139627711, 0.7706191811350085, 0.45927556351788584, 0.6163879087375057, 11.284667811086102, 70.50317610463789, 61.30379030781408, 57.124853980156686, 44.31853894264468, 39.71755950681625, 32.27372265631153, 54.25101964704452, 57.182257867628536, 11.0387332400968, 0.4317012092759533, 0.11326062973708877, 0.1244215502013122, 0.0775361878256644, 0.020389047060762683, 0.06181284988058671, 0.14335349803009342, 0.036518472892742966, 0.10861065223692887, 0.14756359550501072, 0.12002664167554149, 0.22044500245923, 0.24150596991662057, 0.3406021395517934, 0.09291629922846634, 0.2225410956288538, 0.1988669716182255, 0.1237640935446947, 0.0860396258893513, 0.14679045957182685, 0.0997405032056474, 0.9944511349162749, 52.555786948050226, 68.7696453832811, 52.56705983992546, 44.2939535264046, 54.306026966341086, 52.54438069558913, 64.80838491070655, 61.74668081345097, 70.01237776971632, 39.46233480207382, 0.2411315980697832, 2.354788559098398, 6.642053886767357, 1.8116768377442516, 1.8331053588659534, 48.924574313625214, 62.783257345999445, 59.64768325128863, 50.281451594445016, 57.607889944507235, 55.549386932003884, 61.909941627133286, 58.982994479517785, 56.44746065139771, 51.85353363713911, 51.031122438369266, 44.21290166916386, 40.65960299584174, 42.62909566202472, 43.44130477597637, 40.1416265579962, 42.10547493350121, 40.258866202446725, 41.36145622499528, 37.62422976955291, 39.29118217960481, 40.46421797044816, 41.209217271497174, 42.21731347422446, 41.124603902139974, 40.80238903722456, 39.805852059395086, 39.607944949980705, 41.89994273647186, 41.281949781602435, 39.84000413648544, 42.44392448855985, 42.64662865669497, 40.415823767262125, 41.7163993466285, 41.42618709994901, 41.068427716532064, 40.149173198207734, 40.36618617273147, 40.59406411263251, 44.21088164852512, 41.95990008692588, 42.38069588138212, 40.810002357729026, 44.790282403269124, 41.94408116802093, 40.472286285892615, 43.159506013316495, 42.90907836729481, 42.40699145101732, 42.57459040611021, 41.26152207774501, 42.00234013219034, 40.44782246312788, 42.22129467994937, 42.026635293037664, 48.52611641730032, 46.05704715175014, 51.49247946277742, 59.75166528455673, 52.369572424119525, 47.02937526087607, 59.52599171669253, 55.62364524410617, 51.416781640821895, 49.21792837881273, 48.571965002244525, 44.07228077611616, 39.62234397088328, 43.36566578957343, 43.57366515744118, 45.65021107273717, 43.64192224317982, 46.95081803106493, 47.12214323782152, 43.63852547061059, 46.23997865184661, 42.26710011882167, 43.34139808531731, 44.18793578301707, 43.47912034680767, 43.63104551069198, 42.48527019254623, 42.96678427726992, 40.40482544129895, 41.859118707718395, 39.859639521568056, 41.74859416100287, 42.32471189191265, 41.813517232095045, 41.31558018345987, 42.11730087957075, 44.44057564581595, 44.19867523254887, 40.958601351707216, 41.47122767663772, 43.250159832739065, 41.74067489562496, 44.279040675009455, 49.27567351248957, 52.39953148749567, 56.99654932945006, 57.783176745137865, 57.606732845306404, 55.75031818882112, 56.54670838386782, 55.47813707782377, 58.10503859673777, 52.86293991150395, 55.981443851224846, 54.09069276625111, 57.018189045690725, 53.77691884194651, 55.57438811948223, 53.07559121039606, 52.3612726888349, 48.676492244966575, 47.29749279637491, 45.736134513731926, 50.65442585176038, 50.66826397372831, 63.41433140539355, 62.21775747114613, 74.2863021358367, 31.277248436404815, 0.4345935589123157, 1.0800237689287433, 0.7629298034214205, 0.8541972899148542, 12.355742569892639, 78.05326800192557, 64.82653371749386, 65.48684120178223, 49.57921397301459, 49.319713884784335, 45.826364717175885, 63.5839190021638, 67.32258888982958, 14.6579610724603, 0.5228724751260974, 0.2985521862583776, 0.3607364623777328, 0.1102022075605008, 0.2452150765325754, 0.15574930626298153, 0.15479333578578888, 0.12561423418622825, 0.23611189887648631], [0.023445486984846574, 0.08927503735908578, 0.02928191059899907, 0.09640115658722578, 0.030727451479422952, 0.1360249017635661, 0.054548884621791305, 0.05302799707879463, 0.03950898137484347, 0.03566035482611868, 0.09680410351363883, 0.033899440445126064, 0.06717384507459018, 22.996346412166474, 57.41341490899363, 45.34764728238506, 35.77775832145445, 29.443099114202685, 35.391946146565104, 50.26162401322396, 55.371013226047644, 53.44007353628836, 45.47796018661992, 0.689596067513189, 0.30563332080360384, 3.832861439835641, 1.1631690686748875, 0.3868576091143393, 31.724135837247296, 60.554794111559474, 54.335805600689305, 50.598135917417466, 51.460425853729255, 55.275809457225186, 53.86319529625678, 54.37100495061567, 50.57248361649052, 43.4933271715718, 41.71558349363266, 38.33555552267259, 36.11218744708646, 37.37747738438268, 37.061389261676425, 36.02435773418796, 34.00812218266149, 35.22410008215135, 36.50106691545056, 36.18235080472885, 36.89057396304223, 36.69347878425352, 36.34818077087402, 38.82435344880627, 38.33124876022339, 36.684504401299264, 35.63828276049706, 37.677632839449, 37.536706001527854, 37.68114728312339, 38.58618320957307, 37.36907174510341, 38.2865886534414, 38.70784728757797, 39.59642102641445, 36.72546571300876, 37.24164570531538, 37.46828809861214, 37.931920097720244, 38.78169375081217, 38.99588261881183, 37.51192838914933, 37.81746141372189, 38.799187521780695, 40.05702887811969, 38.6832893279291, 38.02499401953913, 36.97334381841844, 38.35580671987226, 37.14094669588151, 39.209734162976666, 39.49844021950999, 37.68347717100574, 35.15833762384231, 36.997886088586625, 41.10420757724393, 42.808540175038004, 43.1806162095839, 48.0801978418904, 54.1045779566611, 50.759851317251886, 42.8598447768919, 55.097369070976015, 52.132767169706284, 46.5764944784103, 44.16855142962548, 44.85737454506659, 37.90178452768634, 36.37557068178731, 37.89286505791449, 41.22837804978894, 38.65218885483281, 41.299212132730794, 39.662246242646255, 41.296909701439645, 38.41612492838214, 41.600395248782256, 39.644403380732385, 38.79996022870464, 39.49579654201385, 40.46647333329724, 39.8529322685734, 38.936854870088645, 38.50536669454267, 37.775723472718276, 39.39434051513672, 37.8388540206417, 36.85116983229114, 36.74266530621436, 39.82032168296076, 37.69808799989762, 37.994607417814194, 37.83482182410456, 38.43563871998941, 38.0868576418969, 37.801669951408144, 38.084386548688336, 37.53531748248685, 36.92088211736372, 39.34513045895485, 43.24699448001, 46.541538315434615, 47.43665849008868, 47.32663992912539, 50.28008660962505, 52.951185395640714, 54.10171462643532, 54.794232614578746, 53.59565827154345, 49.1586103746968, 45.68172731707173, 53.04407104369133, 52.039414759605165, 48.1640894951359, 47.436882065188506, 53.79349085592455, 49.20447857149186, 48.72665543710032, 43.57511643440493, 46.39500248816706, 45.17801653954291, 59.518123442126864, 55.68546964276222, 68.40133482410063, 17.717414709829516, 0.14519385572883392, 0.891638151820629, 0.33142005483950343, 0.4252745589661983, 11.0579244167574, 64.46227104433122, 56.2800774266643, 54.66653593124882, 37.49513672244164, 23.537649185426776, 28.321754278675204, 49.80831961477957, 47.14607754061299, 3.4231885065955505, 0.44843701285219967, 0.1610092199858158, 0.10367181362403978, 0.12307342697655964, 0.056337374337618394, 0.04187134372430944, 0.031244865348262173, 0.12487108293440073, 0.048362425858936006, 0.05268764719667454, 0.11042333117896512, 0.01985064429801799, 0.12279725227985652, 0.035605606352609974, 0.08605789708634538, 0.0543890250546317, 0.011632652510137809, 0.01123033473343258, 0.02587049808954039, 0.10514278670832997, 0.0057153075073485176, 0.05788385304772566, 28.78458611426815, 64.08000861444782, 51.14608710811984, 37.239009872559585, 37.19629526138306, 45.980717828196866, 53.708842185235795, 60.93529539723551, 58.95517310788555, 49.129557378830455, 0.5700454728737955, 0.23038755201043623, 2.627511447475803, 2.110650433648017, 0.6385383298320155, 35.253223680680804, 62.99721871652911, 55.83202115951046, 53.73662825553648, 54.520682596391254, 56.016690269593276, 55.35786151885987, 56.165775637472834, 50.90216275184385, 46.584288227942686, 43.28491595483596, 40.47473384488014, 38.074204075721006, 37.714220708416356, 37.86420037669521, 38.2839959667575, 37.28891811063213, 35.72866201400757, 37.21860962529337, 37.692808489645685, 38.5529685789539, 38.828334654531176, 38.53814201970255, 39.698281057419315, 40.562339982678814, 39.896792211840236, 39.26792252448298, 38.38023131893527, 39.25543762022449, 39.55384762056413, 40.11617429794804, 38.61496163952736, 40.732970929914906, 40.05296530262117, 41.05214595794678, 38.56167624073644, 40.90942267448672, 37.53583915771977, 39.525630089544485, 39.44036560673868, 39.34042361474807, 39.87252058521394, 40.0214216016954, 39.9221581797446, 42.63621476388747, 40.57455424339541, 39.375964210879424, 39.83125332863101, 40.096115296886815, 39.29271582634219, 41.40502983523954, 41.23459108414189, 39.74500433091195, 38.281175782603604, 39.22003430704917, 42.41497347431798, 46.22080218407416, 44.40589404875233, 49.375960673055346, 55.19334946909259, 52.343543575656035, 44.944651203770796, 56.245431130932225, 54.30126128658172, 48.162563693138864, 45.40555323323896, 45.91708521689139, 40.067591820993734, 37.70896473238545, 40.059939276787546, 42.99617459697109, 40.86426442669284, 43.31431019690729, 39.973258818349535, 42.66197296880907, 41.12001080666819, 42.49418573994791, 40.708063879320704, 41.4060261172633, 41.293536463091456, 42.22013758074853, 39.549003493401315, 39.640732042251095, 40.83818850978729, 38.96810047088131, 39.523582612314534, 40.11917491112986, 38.704505428191155, 38.75797910075034, 40.18439215998496, 39.192279615709865, 39.26629866323164, 40.02508117306618, 41.24729956350019, 40.52695235898418, 39.86670763261857, 39.349401920072495, 39.799752773777136, 39.17489959347633, 41.31729425922517, 46.139267875302224, 49.62635301774549, 49.191495526221495, 51.367449991164676, 51.944030561754786, 55.22422244471889, 54.5042831667008, 56.70652927890901, 54.92263924690985, 50.52912965897591, 50.71821535787275, 55.229011658699285, 54.129763495537546, 50.63466887320242, 50.80263653109151, 54.4861186704328, 51.99719436707036, 50.65104084630167, 45.05792140960694, 47.87663859705771, 47.04278584449522, 61.90335204524379, 57.61300079284176, 68.23544210003269, 19.12478662306263, 0.19331200679223384, 2.7533322572708134, 0.26275044607539333, 0.7000331268195183, 12.187614094826484, 70.98031674661945, 61.796255650058875, 61.71936542757096, 41.999857271871264, 30.560968729757494, 36.21616948035456, 56.966449060747706, 56.546473041657485, 5.4669603224723575, 0.39717788597749126, 0.08096259267580125, 0.06587970040498242, 0.08989978972221575, 0.09294824509490883, 0.013147605744551026, 0.043636548197678024, 0.11732878644139537, 0.03454460522099849, 0.15020946401261515, 0.3172101044366437, 0.17531180574047953, 0.36877673900415825, 0.1450232019828212, 0.20080358060377262, 0.11177256523120789, 0.10290481405512941, 0.1294468878017318, 0.14520455031625687, 0.24047241005445683, 0.06981595975136565, 0.3258556824538016, 32.14788909881346, 71.90304648491644, 58.48135079106977, 46.998329700962195, 41.789488792419434, 48.40529957125264, 61.439335653858805, 63.87739858319683, 64.47569339506089, 53.72159381066599, 1.011605559577865, 1.5899921977712264, 11.374582263731188, 4.189883172512054, 0.790890786916979, 38.43508958816528, 65.32356077624907, 58.940793698833836, 54.69634594455842, 56.3492327351724, 58.63283272712462, 58.399655665120775, 59.36334671512727, 55.45549323481899, 47.57093691056775, 44.838292214178274, 42.210088468367054, 41.22441253354473, 40.11480146838773, 41.78839052877119, 41.0021004369182, 39.055322216403106, 38.14876048795639, 41.31744330929172, 40.8235502243042, 40.80796272523942, 40.545414955385276, 40.31088467567198, 42.51155007270075, 43.732215204546534, 41.74756257764755, 40.85929870605469, 41.38085234549738, 40.94554378140358, 40.31719576927924, 43.35826819942844, 41.402127281312026, 42.31922057367141, 42.305515812289336, 42.85382786104756, 40.429716802412464, 42.73147344589234, 40.78989236585556, 42.1885036653088, 42.23999654093097, 41.298160937524614, 40.94087616089852, 41.91687953087592, 41.507372317775605, 44.27671470949727, 43.2341016492536, 40.53236522982198, 40.74089411766299, 41.8188791121206, 42.31607875516338, 43.77203902890606, 42.86534393987348, 42.714587642300515, 39.29961919784546, 42.04442716413929, 44.4930334245005, 47.981236442442864, 46.696213060809725, 51.337275197429044, 58.55193776469077, 53.290843040712424, 47.34837378225019, 58.27812887007191, 56.9933408306491, 51.171829623560754, 48.3867585274481, 48.686298170397365, 42.03530373111848, 41.056923404816665, 42.032444323262865, 45.373456478118904, 42.9092784081736, 45.43697141831922, 43.08118804808586, 45.25436939731721, 43.31349434391145, 45.86336051264117, 43.588946711632516, 42.2892693550356, 41.760886869122906, 43.9828860375189, 43.188939479089555, 42.47470332730202, 42.87857801683488, 41.46962734960741, 42.61599886801935, 41.83335265805645, 40.92675562827818, 41.50185746531333, 42.30080504571238, 41.61648088885892, 40.64862035935925, 42.58696548400387, 43.6329557049659, 43.21281886869862, 41.838224241810465, 41.43502027757707, 42.441637746749386, 39.89070861570297, 43.68815914277108, 48.02928939942391, 52.589127094514915, 51.701682998288064, 52.28263308925014, 54.89959924451767, 57.47255248408164, 58.28510676660846, 60.36553190600488, 57.842224105711914, 53.83339705005769, 52.748532218317834, 55.00096113451066, 54.53153579465805, 52.831447201390425, 53.55435179125879, 58.93930712053853, 55.44027836092057, 53.016857639435806, 48.58370857854044, 50.97274580309468, 50.56603131755706, 66.09647166344428, 60.98345033584103, 70.62499707744968, 21.727281193579397, 0.29732650686656276, 2.706805347434936, 1.72790261045579, 1.2070661518842944, 14.00454225078706, 77.4605586451869, 65.10764606537359, 65.2375824220719, 51.50696477582378, 35.85661365139869, 42.334153036917414, 63.95709330035795, 67.95130560475012, 8.220421037366314, 0.5932865580243449, 0.27641650469553086, 0.16734709602690515, 0.3393020577007725, 0.31712485417242975, 0.12586017905343927, 0.14031730772506806, 0.20520530731206943, 0.1703667847980415], [0.05686604012284548, 0.06048782420675121, 0.03551411630225278, 0.05488476055043359, 0.035176374949514866, 0.02122437975729906, 0.014125535174483254, 0.047411434953251196, 0.1640334286757054, 0.04527968805163138, 0.02732223279083208, 0.0466369851792772, 0.04249822581186891, 11.730724650044596, 52.34991350481587, 47.79165260253414, 31.72686580688723, 21.4214422241334, 36.0317474795926, 51.190009809309444, 59.54880029924455, 50.734391212463386, 58.732527609794374, 4.328731644538141, 0.5784718271705412, 2.0487649931061656, 0.8298592894308029, 0.18965743031472931, 17.657594642331524, 57.3281268919668, 52.32125274596676, 56.01072042219101, 52.556375303576075, 57.236315973343395, 52.92569391189083, 52.201365501649924, 47.745451004274436, 44.43062851505895, 38.91354814652474, 38.48919868469238, 36.39149158231674, 38.026056981855824, 36.89818336117652, 36.43376296566379, 37.656561866883315, 37.58120921350295, 35.5693627941993, 36.56868073248094, 36.45834838190387, 37.535725408984774, 37.584221593795284, 37.024522904426824, 38.27706513866302, 39.090286224119126, 39.35657201274749, 40.47834634780884, 39.72947174502958, 38.0351137345837, 36.92834638780163, 37.553109353588475, 37.37606925349082, 36.56478189652966, 38.74735732232371, 37.82900102676884, 35.94916589798466, 35.726387039307625, 36.50216517909881, 38.30854608166603, 37.95994151023127, 40.38260129190261, 40.49085478628836, 39.08563821546493, 41.06882387591947, 38.495466632227746, 37.30730225962978, 38.96086762028356, 39.89395241583548, 40.78641322351272, 38.92464060937205, 38.92129874998523, 35.79524032531246, 34.33134509671119, 35.27728742168796, 40.73741497532014, 42.69354020395587, 44.124008993948664, 46.21020393986856, 55.57299175570088, 50.459574268710234, 44.44030892464423, 55.681959121458, 52.140247129624896, 46.737754883304724, 44.64094992606871, 42.36820705475346, 38.05321155055877, 37.272047996520996, 36.56568404166929, 40.785263969052224, 40.7441653743867, 41.545489911110174, 39.93755348267094, 40.57185173034668, 39.44853198143744, 38.47210107311126, 39.68529408977878, 40.6885540100836, 39.958055711561634, 39.81366542077834, 40.24985259579074, 41.31547427946522, 38.518357584553385, 37.36010520688949, 37.699656947966545, 38.40769575488183, 36.76694869995117, 37.939694235401774, 37.26581927268736, 39.467155395015595, 38.33962302054129, 36.783650152144894, 37.24144566443659, 39.58836447808051, 37.08927731360159, 37.16576745433193, 37.461420028440415, 36.39273105129119, 36.5883671083758, 38.35537918152348, 40.39161097618842, 41.93356529358895, 45.49987054640248, 46.14025239021548, 47.54981886956, 48.82056874613608, 52.89850404185634, 51.720733950215006, 54.733945785030244, 51.507815930151175, 50.945748129198634, 46.93462648699361, 52.79524764707012, 53.00405110082319, 57.867091932604396, 55.20580299438969, 54.68690479955366, 48.35045699150332, 44.61624291635329, 43.036951557282485, 56.23188718672722, 57.49025806303948, 64.24672895862211, 9.381862301980297, 0.08277604536664102, 1.0556409676228802, 0.5362486154321702, 0.28369106111987946, 13.152216115305501, 66.00836738463371, 44.58389120717203, 51.5257921526509, 40.267299298317205, 34.67856114910495, 34.91273449313256, 48.06274721699376, 43.122318021712765, 1.7578407136663314, 0.20012776848048935, 0.07430327380256307, 0.011624736906660181, 0.03282002255981488, 0.07105152167740368, 0.025403487060459393, 0.036482895769539385, 0.0702911947343138, 0.0351990741347113, 0.044814726307747826, 0.0373270940185795, 0.07583165751589883, 0.020916105976568598, 0.028289056818691954, 0.01461440364965388, 0.018700497345097603, 0.009547711665471716, 0.03495094974735572, 0.06989963187445557, 0.0068419690773401775, 0.04262237035999856, 0.036230442985411615, 15.984463518665684, 60.43911557043753, 52.558050155639656, 38.3465773828568, 22.9852206091727, 41.6594426093563, 57.48665340485112, 64.8072317338759, 56.56447279837824, 60.58933058092671, 4.577209382287918, 0.27255539091364034, 1.338689495478907, 2.314811517154017, 0.6199586751960939, 18.63258800198955, 60.62012118677939, 54.36596470494425, 57.78691476391208, 53.43884191205425, 56.932559782458895, 55.79616285139515, 55.04184007644654, 49.81772153608261, 46.38673805421399, 41.966870138722086, 40.515718690810665, 37.91040981969526, 41.109789109999134, 39.78709528523107, 38.332998137320246, 38.837128608457505, 38.37984300428821, 37.47183784361809, 40.33692921361616, 39.863601115442094, 39.61958262228197, 38.22656854506462, 37.944220650580625, 40.095970169190444, 39.75469258523757, 41.39841279675884, 41.567576777550485, 40.4910469824268, 39.70937352026663, 39.30697756428873, 38.907762650520574, 38.311746735726636, 38.83395933335827, 40.43187410600724, 37.855633920238866, 37.32043827733686, 37.443216308470696, 38.451575309999534, 41.22227484180082, 40.23539866170576, 42.152896388884514, 40.746965946689734, 39.33603448252524, 41.436004792490316, 39.843349918242424, 39.791660924111646, 40.78457755427207, 41.93191789811657, 41.858040055921, 40.4029623154671, 41.104344860199966, 39.58199454892067, 37.23469134299986, 36.862623153194306, 42.544294018899244, 45.71870742305633, 46.09517258982505, 47.885087382408884, 57.5183932242855, 52.07977202630813, 47.269781251107496, 59.48551285651423, 52.96747107659617, 48.95234077207504, 46.59862841329267, 45.15856942822857, 40.77054331379552, 38.877379971165816, 38.575196650720414, 42.493675831825506, 42.00821976507864, 42.48611350213328, 41.36700245641893, 41.80600197084489, 42.010428059485655, 39.61071806569254, 42.8034685504052, 42.210708202854285, 40.214853286743164, 41.35443126001666, 40.05332223830685, 41.81944393342541, 39.65094981654998, 39.28071729598507, 39.88586056616999, 38.5645866394043, 38.269071348251835, 40.69364916893744, 38.47553314701204, 40.71940737385904, 40.90345674945463, 39.06640683451007, 40.12467407411145, 41.34604131021808, 38.77158580287811, 39.27652428227086, 40.60343857734434, 38.488653475238436, 38.76017562804684, 40.663709717412154, 44.038591538706136, 44.57526983753328, 49.01703634569722, 48.208573095260135, 48.677225728188795, 51.670672739705736, 54.008836823125044, 53.62667637486612, 57.682681698952955, 53.51632833480836, 52.28315084211288, 49.29574428066131, 55.16138215218821, 54.65723991394044, 58.52870948853032, 58.00349235534669, 55.08337013183102, 48.67427218344904, 47.50129522815828, 46.040855607678814, 58.2644005744688, 61.14409492861841, 65.77521385685091, 10.592058627836167, 0.06137840141872726, 7.641707677995005, 1.1417404249791177, 0.41910675444429923, 14.809686195465828, 72.57985145814958, 52.02501966107277, 57.03318034448932, 50.948846801634765, 35.35862953432145, 34.21019877156904, 58.26502815369637, 51.126832192943944, 3.319387637799786, 0.3261660399936861, 0.12046852885114571, 0.030241265269597212, 0.016841228765946244, 0.05747342910317164, 0.03252873294836572, 0.04587561252617067, 0.032397333547593124, 0.008497000052293223, 0.11656725674026436, 0.183001198775826, 0.17729629522129414, 0.14678633801879423, 0.17289367985100518, 0.16668154948180722, 0.12057741292782369, 0.08091235262972694, 0.16523362798315866, 0.15758411748515022, 0.08070504923741664, 0.13308439584028336, 0.28577834427837406, 18.494577446291526, 68.0427360534668, 59.407877383693574, 45.5637228104376, 32.41619294689548, 47.053156591230824, 61.713301443284564, 69.12101914805751, 60.516860869623, 67.90839487506499, 6.029326223557995, 1.2536505489580094, 5.83861077985456, 3.17800899186442, 0.6249039259649093, 20.737478925335793, 61.11233157496299, 55.745619189354684, 60.627389338708696, 54.527652648187455, 58.7144729398912, 56.04076577771095, 56.99156399696105, 52.28722226235175, 48.9735137262652, 43.87188688401253, 42.88565789499591, 41.08286988350653, 43.0943162210526, 42.689464861346835, 40.35863953251993, 42.896844494727354, 40.67342150595881, 38.96096567953787, 42.09357054002824, 40.93258819272442, 41.6242628712808, 40.424668712000695, 40.08770573523737, 43.25918520650556, 41.69983909976098, 44.81459325359714, 43.4453526619942, 43.172469446736, 42.18276916011688, 42.08675738303892, 41.95395377374465, 40.76797416133266, 38.52537078242148, 42.626142117284964, 41.476189474905695, 38.930029945988814, 39.29033887001776, 38.45522311425979, 42.4481253470144, 42.854251477026175, 43.83156491864113, 44.562577047655665, 41.3364315032959, 44.679047907552416, 42.1851892625132, 42.084270600349676, 42.036386305286044, 44.964588611356675, 46.17104691843833, 43.77343147031723, 43.46756112190985, 42.649550822473344, 37.974779836593136, 39.01492572599842, 43.71411346620129, 47.06689273157428, 47.957788513552764, 50.44996838415823, 59.06601536658503, 54.4414742531315, 50.26933147061256, 61.413961841214096, 56.62068036294753, 49.59744907194569, 49.12381502889818, 46.0577610231215, 42.76139328556676, 42.55636315191946, 41.641062382728826, 45.7894826704456, 44.57893333127422, 45.32577222393405, 43.225664631012954, 44.441116932899725, 44.977010757692405, 41.25696820597495, 44.89547644892047, 44.37218519949144, 43.29804805017287, 43.0346255917703, 42.88156686290618, 43.71125405834567, 41.810948079632176, 40.28485582720849, 42.23715282255604, 41.64844036102295, 40.70853848611155, 42.22076123760593, 40.779290199279785, 44.206374845197125, 42.83283141351516, 39.70439995488813, 41.42446125707319, 44.110229707533314, 39.593663600183305, 42.78168762883833, 44.03334732978575, 40.04952538398005, 40.99702881228539, 43.10995471092963, 45.077243005075765, 46.87295898314446, 50.73000208024056, 51.17989401663504, 51.44728199128182, 54.83499388540945, 58.25725009364467, 56.70093990141346, 60.42266122756466, 55.78593330998575, 56.85731695544336, 51.18145904233379, 56.74683163242956, 56.59658132060882, 61.415750442012666, 59.82377806017476, 58.28158447819372, 52.44053986764724, 50.301530207357104, 47.825181022767104, 62.027291097948634, 61.9460548893098, 70.43131043834072, 11.982967372863524, 0.06667547423632876, 7.927278289871832, 2.7396750546270803, 0.6979217885002014, 15.49076262981661, 79.05999137509254, 58.50748554352791, 68.59804953298261, 54.9114683366591, 46.15975049234206, 46.75008289275631, 65.75145606071719, 60.99993998004545, 4.260628511828761, 0.5100965493869397, 0.25709922996259504, 0.13470684748984155, 0.1233361185257954, 0.2820378127357652, 0.09873019411198555, 0.07635278882639063, 0.1915224100793562, 0.11933437398364467], [0.07380858784721744, 0.09938529121779627, 0.038703041556741924, 0.01844652579165995, 0.07210728276761309, 0.020703780877914642, 0.07604232403419672, 0.019503449420294455, 0.08031780711345135, 0.06590055331828133, 0.06865805615821192, 0.09026430201746764, 0.09534022440352748, 7.129241189649028, 55.366337760802246, 50.128063386486424, 35.77540097698089, 28.498164838360204, 36.978615483930035, 43.46546265386766, 61.83479293700188, 48.853183254118896, 62.36489734342022, 12.880665525313347, 0.04158269328575942, 0.7182783381112161, 1.6444880154825028, 0.8092585722765615, 7.646194869472136, 48.82860568261916, 54.54642903420233, 57.82447145831201, 52.367207234905614, 54.57825906815068, 51.813725502260276, 51.53938316529798, 47.76036777803975, 44.8169231414795, 41.17250780905447, 39.30973891289004, 37.54586473588021, 39.27898360836891, 36.76891772977768, 35.974727984397646, 34.34335539417882, 35.81728012331071, 35.06429487659086, 36.41149567019555, 36.73505590808007, 39.227239701055716, 40.24245108327558, 44.800053027368364, 47.79001305180211, 48.736826142957135, 48.56510477681314, 48.04126831793016, 46.616773297709805, 42.02033596654093, 40.2112643180355, 39.02378243784751, 36.0290410441737, 37.81124837936894, 38.22085365172356, 38.873010450793856, 36.77915119355725, 37.97878457653908, 36.87338613694714, 38.729283040569676, 36.81289534414969, 38.86824084866432, 38.56554762009652, 38.69015739810082, 38.917850986603774, 38.76272516865885, 38.119578053874356, 38.2566648913968, 39.48757525413267, 38.294598133333274, 38.233056145329634, 40.29773689085438, 37.08473913131222, 35.69100726035334, 36.248430975021854, 39.63037698499618, 43.17790585179483, 44.92147391842258, 46.89645398047663, 53.77886433755198, 49.83387385645221, 47.988716402361476, 55.70618367964222, 52.0126602726598, 46.679491996765144, 45.65458451547931, 42.79120722124654, 38.44918266419442, 35.715329877791866, 37.097918295091205, 39.49105047410534, 39.46657488423009, 41.163929585487615, 40.614609487595104, 39.77272372091971, 39.58432835917319, 40.15691987929806, 37.81648474354898, 39.762262759670136, 37.66668550429806, 40.186059167308194, 38.31246452946817, 38.32296079204929, 37.68169249257734, 38.391441452887754, 38.648184114886874, 37.80563154528218, 36.8193397983428, 37.84932674900178, 38.667741052566036, 39.09572655154813, 37.64994482840262, 38.24634513547344, 37.99149305589738, 37.42763665414626, 37.97546232900312, 38.101605753744806, 38.16665434068249, 36.15215247677219, 37.05401912812264, 36.26947841336651, 37.49805888822002, 37.122256602010424, 39.125944491355654, 40.640104893715154, 44.483655037418494, 45.396543548953154, 47.43305775427049, 52.687676645094356, 49.235904601312455, 52.19496027115853, 56.63494602326424, 54.30762729337139, 54.136129502327215, 56.8853501350649, 54.206088896720644, 55.73651929055491, 55.81545699027277, 53.65674134223692, 49.29551286082114, 46.821030724433164, 56.1338593113807, 58.895957085394095, 53.154850544468054, 3.1874873993858217, 0.10090985215238987, 6.743814877925381, 0.7971388774533427, 0.46897221416715656, 17.824989634175456, 64.48100428427419, 50.88741071762578, 50.53378159000028, 33.747315945163855, 21.491136858540198, 38.791840922447946, 47.39041374575707, 32.72618570635396, 0.5342788501612602, 0.07917635142803192, 0.07694269951072431, 0.026269710337322567, 0.06965671305454547, 0.030392703615249168, 0.03459430134464656, 0.01329820809675561, 0.040619314738339, 0.0472613123636092, 0.02043659622300296, 0.026888697888822328, 0.040407928097392284, 0.02675860658318045, 0.044243079159528985, 0.047967162794403495, 0.042990793534103906, 0.024925277741145224, 0.02571385034600333, 0.03408318663376474, 0.0681752369048134, 0.059864581036832065, 0.054440663211167827, 8.693824641166195, 63.20830498972247, 53.59355195876091, 40.57066717455464, 32.539863317243515, 43.956563011292495, 49.4421898934149, 65.76594921850389, 53.78009596178609, 65.82295694658833, 13.192007580111104, 0.2395810361110395, 0.7362334165842302, 5.118747007462287, 1.7289812622531768, 9.751896742851505, 51.232210589993386, 56.10677142297068, 58.41568246964486, 54.21231762055428, 56.29025597726145, 53.063141607469134, 53.05944281239664, 48.81535983854725, 46.16273541604319, 42.50379162449991, 41.32110680303266, 39.43108527891098, 41.547541310710294, 38.196291769704516, 38.50843398801742, 36.83837506078905, 38.8094876658532, 38.900110106314386, 38.2424972903344, 39.30875832034696, 40.19590431644071, 41.67740706474551, 45.52764484959264, 49.95937401248563, 49.598935650240996, 51.116861527965916, 49.97332196081839, 47.150976580958215, 44.01841486653974, 41.50857648541851, 40.94582619205598, 37.4186191251201, 39.52470833255399, 40.06174748943698, 41.07313456073884, 37.41035076879686, 38.83008010925786, 38.4345639905622, 41.89459262355682, 39.38600547852055, 42.16064306997484, 41.85308218002319, 40.45265090081, 41.05379727578933, 40.857765059317316, 39.19125587709489, 39.94378220650458, 40.566991913703184, 41.977946912088704, 41.46888209927467, 42.77148554402013, 38.696303752160844, 37.37545736374394, 38.79459834867908, 42.06181895348334, 46.08095792032058, 47.97914974151119, 49.384283942561, 57.471097284747714, 51.74085963156916, 49.13474275219826, 58.2713000236019, 54.21228231922273, 48.47030501211844, 45.716487361538796, 45.36605496560374, 39.882193150058875, 37.988151196510564, 39.45998137997043, 41.04492487445955, 41.85093664353894, 41.37897745255501, 41.73117883743779, 41.615927834664625, 42.66525991501347, 41.3081943604254, 39.99622821807861, 41.241498378015336, 40.448269613327525, 42.5752728985202, 40.97704041388727, 40.50570880213092, 39.804926380034416, 39.70697302972117, 40.50847015073223, 39.000609074869466, 38.30904422267791, 39.28085065657093, 38.81604194641113, 39.13289100893083, 40.02460264390515, 40.94416310710292, 38.64424997760404, 40.36795123930901, 39.49381574507683, 38.52091889227591, 40.880067656117106, 37.79806137084961, 38.874457805387436, 38.50705331371677, 39.165576119576734, 39.44694342151765, 40.742545435505534, 42.34046805289484, 46.097545623779304, 48.275641702836566, 51.48477592775899, 53.38244999608686, 52.65767051327614, 54.091877322043146, 56.947480478594386, 54.75813896425309, 56.06920688383041, 59.51192217488443, 57.425546799936605, 56.833221835474816, 59.41475722097582, 53.28881909770351, 51.816490773231756, 48.26652219218593, 60.351870290694706, 60.153696460108605, 56.51035977948097, 3.1870245597054883, 0.07238484408345915, 6.650310475980082, 0.1770661624088403, 0.37312339931245775, 18.132487766204342, 70.3960483304916, 53.57796053732596, 59.421119305395315, 39.44426052031979, 28.668438849910615, 42.291626699509166, 54.78461496291622, 42.356149688843765, 0.9469717632858985, 0.12087190478679635, 0.07471458640910926, 0.010506935143512825, 0.08456483002631895, 0.007427879346294269, 0.039482229584527594, 0.0301124743982068, 0.022665502225619652, 0.037447496227199034, 0.21126176861505355, 0.24165279832818817, 0.09567856713528596, 0.10305354236474923, 0.16837570696107804, 0.10339737794692479, 0.28985724153537906, 0.09060562483125156, 0.13938177647369523, 0.15156632830058375, 0.20318285051372745, 0.24637490300641907, 0.1788415405298433, 10.531371716530094, 73.1350080428585, 61.489467467031176, 50.895455498849195, 39.7298796715275, 48.46863408242503, 53.75407888043312, 73.00163961225941, 57.97656920648391, 73.41132333201747, 16.23173365669866, 0.2723463101973457, 3.4139839295418035, 8.1127681559132, 2.117389065604056, 9.745699397979244, 52.36753671400009, 57.11397332529868, 61.26016178438741, 55.306384332718395, 59.95768385548746, 55.31502139183783, 55.52278933986541, 51.5045956642397, 48.00930100102579, 44.64792782260526, 43.68593908125355, 41.84273104513846, 44.83011014999882, 40.33735282959477, 41.32884563938264, 38.57911509852256, 41.92243752941009, 39.99738923964962, 40.26251008433681, 40.75323781659527, 43.150712059390166, 44.551880744195756, 48.12515997117566, 51.983556285981216, 53.0965405894864, 53.55125311882266, 52.79501622722995, 50.12929501072053, 46.94829202467396, 45.02212193704421, 44.10686823629564, 39.43616082591396, 41.328037631127145, 42.98657655715943, 42.86213544107253, 40.40103643171249, 41.61579447407877, 42.32535908299108, 44.33246727912657, 40.883366369432025, 43.94257976162819, 43.282629213025494, 41.528407989009736, 42.19302615811748, 40.96433585689914, 41.97780962913267, 42.5672673409985, 43.03013840029317, 44.16193439114479, 43.79648323981993, 47.23120866283294, 41.56256006610009, 40.03197277745893, 40.95467505916473, 45.48988811431393, 49.299176354562086, 49.01083507845479, 52.28516694038145, 58.84814731536373, 53.267575540850245, 52.03695935587729, 59.46594415172454, 57.80919382649084, 50.33999689163701, 49.93479251861573, 48.82256523255379, 42.28544112174742, 40.40683761719735, 41.06649006566694, 42.4663172998736, 43.85871164260372, 45.39582575521162, 44.80978835013605, 44.41885355980166, 44.026322364807136, 42.9920208069586, 42.442845836762466, 42.715583924324285, 40.879749944133145, 45.20397870771347, 42.507490419572406, 43.014664649963386, 42.077763388233805, 42.817432188218646, 43.558160028150006, 41.023822522932484, 40.305181549441436, 42.92522284292406, 41.97406376561811, 42.1856128784918, 42.36519859683129, 43.91512317042197, 43.48276030632758, 42.536821903720984, 42.76348390886861, 41.323993667479485, 41.75021802225421, 40.018601417541504, 40.517926985217684, 40.96028797088131, 42.267668862496656, 42.29103834398332, 44.00594172939178, 44.00538867519748, 49.78680933675459, 51.378593444824226, 51.170503862442516, 57.58873701095582, 54.53494825670796, 56.15982147955126, 58.404578239687034, 55.661731458479366, 58.6380494794538, 62.695306039625606, 58.301478739707704, 59.1760653065097, 61.170414032474646, 58.681481884371856, 55.66903491174021, 51.41251410207441, 64.4695705752219, 61.48290141936272, 59.87665945483793, 4.478631884821, 0.13153486043935822, 16.05075353576291, 1.4633400906478207, 0.80597659032191, 22.191864367454283, 76.69677119101249, 60.18963321562737, 65.04442138056602, 46.524370101190385, 33.64855850896528, 50.59788096335627, 63.186296570685606, 51.22230660530829, 1.9016768470887218, 0.27092818951895165, 0.19142543866990075, 0.0987235980949575, 0.13009170400759867, 0.21397126838564876, 0.16419567077630953, 0.1601619114198031, 0.10566949513891052, 0.1652757474972356], [0.02970538102090359, 0.08387505212017606, 0.015095249269037478, 0.04494114230657297, 0.07720552895578646, 0.012422612691748769, 0.018796062983211972, 0.013802783289593796, 0.015341364590811635, 0.04541815078306583, 0.039234522715090744, 0.05310394703560779, 0.09602672345335446, 3.774159247836759, 40.14263460713048, 53.072429780037176, 36.35362109830303, 17.92581808182501, 34.63598382088446, 46.25239687581217, 58.39363874927644, 51.96042214670489, 59.517193840396025, 24.028755426406864, 0.05977859915865045, 0.22932757743664328, 3.1503729522228245, 0.6970890815700255, 2.1483495591148256, 35.54744851204657, 54.266026635323804, 53.905733400775546, 53.18311514392976, 53.7193972833695, 53.17529001543599, 52.68372681833083, 46.25826474158995, 44.29706788832142, 38.25460564705634, 37.28619206336237, 37.17919372743176, 37.83669671704693, 36.57565470664732, 36.817590421245946, 36.33486040176884, 37.02307947220341, 37.62496325277513, 39.39957295694659, 41.02188879443754, 45.56331096156951, 46.09965978130218, 47.660449320270175, 50.63727332699684, 49.62273659244661, 50.11546473349295, 53.70491197032314, 49.36222061034172, 49.81594470239455, 44.80118659234817, 42.79991880539925, 37.816857368715354, 37.50756279114754, 38.33927000722578, 37.16574784248106, 36.429758225717855, 37.363462755757, 36.54887668548092, 37.4857073445474, 37.73493866766653, 37.642370731599875, 37.00445605862525, 40.278172108434866, 39.48253893083142, 39.48276642830142, 39.44900658822829, 37.2020140770943, 40.056267938306256, 38.87459508834347, 40.783867605270885, 39.20997342755718, 36.744438217532256, 34.080701720330026, 35.355252373603086, 39.53183135678692, 41.16407863555416, 43.24936751396426, 45.36091666067801, 54.92296480363416, 45.77782538629348, 46.710474798756266, 54.01997243204425, 50.49726824606619, 46.47133965646067, 44.28359846914969, 43.537512671562936, 39.004123518543864, 37.16760312357257, 36.66691257107642, 38.88262025771603, 37.84086227416992, 40.3443621050927, 41.223443708112164, 41.58225820910546, 41.88519462462395, 39.62639185690111, 40.46523386432279, 39.575393199920654, 39.926264901315015, 38.93202251003635, 40.30299286688528, 39.69694745156073, 37.27693919212588, 37.152580445812596, 38.14094712657314, 37.274577925282145, 37.371656587046964, 37.964973911162346, 37.40507910328527, 37.91454792022705, 36.95399084398824, 37.472473267586004, 37.81308404860958, 37.25167912821616, 35.94671833899714, 37.063848587774466, 39.74364326846215, 36.54014548947735, 35.90469406497094, 39.35043742579799, 35.611995035602206, 36.4760539608617, 36.682131367345015, 36.150265816719305, 38.127120771715724, 40.4519134952176, 42.07538250953921, 44.09659162644417, 46.43830545486943, 46.94843323000016, 49.38130686360021, 51.42869780140539, 53.269073886256066, 54.32698419017177, 56.286914117874645, 54.79918264573621, 55.81633560119137, 53.75349052490727, 52.147680021101436, 49.669240213209584, 54.37506852611419, 61.70116955234159, 39.31812494031845, 0.37558983470643725, 0.30419157397362495, 3.6744751516849767, 0.906013822363269, 0.2987773548210821, 29.813606200679658, 61.710053720781886, 53.88485070197813, 42.93623293599775, 34.98879317314395, 28.058882913281842, 33.161035353137606, 52.104737912454915, 28.148467886832456, 0.19720885091491286, 0.029057971607413025, 0.03948416778697603, 0.08773905405354115, 0.07163495125789797, 0.006229625423363741, 0.03365382882616213, 0.024602536389964725, 0.031116880784412066, 0.06163565374370064, 0.040572142874401425, 0.04125709442662136, 0.03288842272013426, 0.08737684768294135, 0.0908107678556154, 0.029030107074387135, 0.036166746604947314, 0.021054886634491628, 0.05166866598770984, 0.020418953218106783, 0.09205703202995563, 0.05420120710867548, 0.09225810712744152, 5.210872205995745, 51.11460616511684, 58.73187649634577, 42.966231223075624, 21.957147775157807, 39.16481125739313, 50.08330129807996, 63.49906244585591, 53.60736654650781, 65.78570227469167, 23.603762695866248, 0.10962708237310571, 0.2269256772894052, 3.8098184956658274, 2.100958992396632, 2.640976453981092, 39.157433279099, 54.42128189148442, 55.67928406500048, 54.080573051206535, 58.03525963137227, 52.61343794484293, 55.43178250712734, 51.14258835392614, 46.432410132500436, 41.5747154912641, 39.19334650039673, 40.00022903565438, 40.50586177456764, 39.153738406396684, 38.09047798956595, 37.23641718587568, 39.21150707429455, 38.501581607326386, 40.36435050349082, 43.304629787322014, 47.88069432781589, 49.74827989455193, 51.44579933535669, 51.74618621026316, 53.3404492562817, 53.25017590676585, 53.745386908131266, 51.563282166757894, 51.563227253575484, 47.05408227059149, 44.40817294582244, 39.36180053218719, 39.889363242733864, 39.43615298117361, 39.07210211600027, 37.59701244292721, 38.81390033229705, 38.97304265729843, 39.84626816165063, 39.43776507531443, 39.4781772551998, 38.86550303428404, 40.60928290890109, 40.612632613028254, 40.958915141321, 41.06121447778518, 39.55905260578279, 41.84843024899883, 40.300498239455685, 40.113314890092425, 41.424402421520604, 38.45186948776245, 38.227721721895286, 38.254609569426506, 42.27712569698211, 44.486847846738755, 46.32343884437315, 47.90784105177849, 56.7303341434848, 46.69515794323337, 48.773657198875185, 57.00475885022072, 54.07095932191419, 50.20421228101177, 45.83125983515094, 46.50775886351063, 42.52258369999547, 39.19857109746626, 37.97819622101323, 40.68363143551735, 40.45918949188725, 42.44295958549746, 42.17958811790713, 42.44754875859907, 42.5702993331417, 41.899695627151, 42.31825567060902, 40.21399428767543, 41.87088581823534, 40.28940185423821, 42.54215632715533, 40.80259300047352, 39.850139541010705, 37.70650932865758, 39.86070248388475, 40.24935445477886, 39.085116540232015, 41.53236173814343, 39.38636241420623, 40.10225772857666, 38.92418561443206, 39.89894951543501, 40.05910773431101, 38.174601062651604, 39.18507029933315, 38.46646462717364, 40.87710626663701, 38.650290427669404, 38.86327512802617, 41.04374031866751, 38.320042548641084, 37.96065538160263, 39.968175426606216, 39.7277262903029, 40.46642626485517, 42.444006858333466, 44.78431647823703, 48.47290162117251, 50.242514225744436, 49.15085192649595, 51.53343685211674, 55.60656724437591, 55.28871013272194, 56.45019454340781, 57.63240083571404, 55.89411227933822, 57.03538471652616, 55.607822402831054, 55.90397311795143, 51.6917319451609, 57.93443510609289, 63.23875434937016, 41.722220143964215, 1.0015670498532634, 0.36789705556246544, 5.879901080362259, 1.3211653261415421, 0.4054749246326185, 30.99882683446331, 68.03128273256364, 58.693966788630334, 50.87203894892047, 42.903673341197354, 29.092700058414092, 38.36250220575641, 57.29727745056153, 35.636941309898134, 0.3320354685908364, 0.010651804285214074, 0.01748511609020493, 0.10691807289878208, 0.07451811550004829, 0.03153862942370676, 0.04523785965096566, 0.0287860716813274, 0.040644955701164664, 0.030319795027495395, 0.11486509364218482, 0.11027372186823238, 0.10349706896851141, 0.26801586030952396, 0.15468635926804236, 0.18699122983361446, 0.16115938854073325, 0.11569976941832613, 0.15468490370098623, 0.16183339269651523, 0.18919904926611533, 0.1897373792505072, 0.22197042141229878, 5.468323346107237, 57.645917323327836, 67.90458233125749, 49.681572145031346, 27.406814367540424, 46.96680561188729, 58.16449780617991, 66.38242029374646, 60.665848178248254, 70.28204071906306, 28.52792189967248, 0.29936377980536033, 1.5314198117102347, 5.296781428398625, 1.6227372471363315, 3.4100083622240254, 38.7671103785115, 55.8182301059846, 56.55359998826058, 54.72079407784247, 59.39445503296391, 56.119883906456735, 57.73861861998036, 50.5031753355457, 49.93438066974763, 43.37647584176833, 41.12603948962304, 41.89196855791154, 42.455487635827836, 41.06601545887609, 40.93092510777135, 40.528819407186205, 41.296411560427764, 41.01047077486592, 43.59093143093971, 43.991703525666274, 50.51704091410483, 51.65210423930999, 53.50165082562355, 54.72372408836119, 54.820838051457564, 55.48231047968711, 56.90979826834894, 53.622193105759166, 54.005145872792895, 48.96269975170013, 47.722509061136556, 42.39695410574637, 40.83190879514141, 41.16100741970924, 40.52232788455102, 39.04263334889566, 41.63362164651194, 41.152025192014634, 42.61127633433188, 40.25293950111636, 40.787617391155614, 41.081704939565356, 43.24901842301892, 43.108409297081735, 43.2270178487224, 45.45368071525328, 40.448771676709576, 43.45036545107442, 41.77069671692387, 44.28176279990904, 43.27226238866007, 41.948635039790986, 38.9103239582431, 40.544438285212365, 45.01812896420879, 46.2140949310795, 49.50305331137873, 49.72383568363805, 59.91724421901088, 49.975145862948516, 49.850045788672666, 55.99941222898422, 57.01479619549167, 51.87181580451227, 48.39634872251942, 49.1652980158406, 44.622110782131074, 42.620062443517874, 38.844204564248365, 42.597704933535674, 41.5560136302825, 44.745657597818685, 45.86822817402501, 44.787713250806256, 45.70945062944966, 44.95620258392827, 44.63012418439312, 43.336059739512784, 42.919625620688166, 42.98882407526816, 43.93137747241605, 43.22756698054653, 41.30057319518059, 39.646470469813195, 40.10919640141149, 42.38899561666673, 41.28967685084189, 44.260821265559045, 42.400452859940074, 41.85291351810579, 41.028576435581336, 42.87886827222763, 43.27525907947172, 41.39115248956988, 39.654550552368164, 40.38825734969109, 44.353918721598966, 40.6927627132785, 41.07923776872697, 43.96243479944045, 40.58748237548336, 39.3995572674659, 42.66849587040563, 41.82539416897682, 43.63368918818813, 45.52407941510601, 46.64635581354941, 50.04835297984462, 51.25155179731308, 51.59796768619169, 55.97427768092002, 57.1047047645815, 56.791805528825336, 59.16675359972062, 59.43361205439414, 57.80625989360195, 59.40529646412019, 56.656495524990945, 59.03784490400746, 53.607382235988496, 59.71849772237963, 64.86160362920454, 43.91660582634711, 1.2048110341833485, 0.7840490701698488, 15.05322910124256, 2.166707967558215, 0.5712049622689525, 35.06021168924148, 75.1558994477795, 61.731732660724276, 53.80416362516342, 47.593502306169086, 39.740493605213786, 46.24819993972779, 67.23916007626441, 44.21428626583469, 0.4535644086858919, 0.10394202049581275, 0.13387147457368914, 0.27818481948587204, 0.2599221720330177, 0.13587744515990058, 0.19275942757245035, 0.0868581218885318, 0.1186380307039907, 0.1192349051275561], [0.01371003685504078, 0.042343510525120844, 0.053924044158550045, 0.03275598143978465, 0.046269998420029886, 0.057523289935723435, 0.06794387069080146, 0.03236618058215226, 0.054890663257890174, 0.04903594737932567, 0.06256184638327648, 0.02416541045080991, 0.03075249106322806, 0.5767443295448058, 23.442314017203547, 53.76109992304156, 37.99917305669477, 32.08017526134368, 35.21121901850547, 46.06587248463785, 57.47980102416008, 52.88256745184622, 56.075980817118, 34.99108775969475, 0.08767215159511374, 0.07311823537513133, 1.6183759392269197, 2.3921430062863136, 0.3246320868211408, 14.93380077423588, 48.209302656112186, 50.14336455252863, 51.52580784213159, 51.1971563677634, 51.05340542331819, 52.3027862271955, 49.573016628142334, 45.36567449569703, 40.4230958415616, 36.707163933784734, 37.356124001164595, 37.68403022520004, 37.617447991524976, 35.83229495633033, 35.46691833003875, 38.263007363965436, 41.008697863548036, 44.806964243611986, 47.934948552039366, 49.721113558738466, 50.34626483917237, 51.33496099902738, 52.466451045005556, 53.60059261322022, 52.24739059325188, 54.81338162575999, 53.33278102259482, 50.42132723715998, 48.714480400085456, 48.5963660670865, 41.76041618470223, 39.27488865390901, 39.65659018485777, 36.70242571061657, 36.828588747209125, 37.69505993012459, 37.63758151761947, 38.54194279639952, 38.3725199391765, 39.61582891402706, 37.6087167955214, 39.90628434765724, 39.2982110669536, 38.588140472289055, 40.18804780898556, 37.93657987348495, 38.24108915944254, 39.09511466180125, 38.55780878374654, 39.634648446113836, 36.275169772486535, 35.27038012781451, 34.82502245133923, 38.13322397970384, 41.50929035678987, 42.510310603726296, 47.315421950432565, 54.82599596823416, 46.28307373292985, 46.17978203681208, 56.404691127038774, 51.26736287147769, 45.973284936720326, 44.25812267488049, 41.94161399718254, 38.10470050381076, 35.78319080414311, 37.23822539852512, 38.51774177243633, 39.20514106750488, 40.42419410520985, 39.99079573538996, 38.989128297375096, 41.10334073343585, 39.63538585170623, 38.825220292614354, 38.475058540221184, 38.359940898033884, 39.216382580418745, 38.90086320138747, 38.74608647438788, 38.705521322065785, 38.18847840832126, 38.05274871087844, 38.039922560414965, 36.98534627114573, 37.98092619065316, 37.94570722887593, 36.494457721710205, 38.678119644041985, 38.27820262601299, 39.08186097298899, 38.084206119660415, 36.980576669016195, 37.73961413291193, 37.035254509218284, 38.02155410089801, 37.139228697746034, 38.08252734522666, 36.90444346397154, 37.05548217219692, 35.88326223434941, 36.41806564023418, 36.410789643564534, 38.74556872152513, 38.08459443430747, 41.51732337090277, 42.4663604459455, 45.96332603885282, 48.17868071217691, 50.525058238737046, 51.19813696030648, 53.77046654301306, 53.25789905363514, 58.23174684278427, 53.61692144024757, 57.26876181940879, 53.83197322968514, 55.953261621536754, 55.76958879347771, 62.93830079417076, 17.688891233936435, 0.0635404700803901, 0.5077541283061427, 1.9656547495434362, 0.36695513513780414, 0.020801493477436806, 34.42591344156573, 62.62271865721672, 52.9304164455783, 38.61261606216431, 22.960309636208322, 26.57251838714846, 42.900268723887784, 49.64357222280195, 12.501848897626324, 0.27752215343136943, 0.01813363824640551, 0.01681139347173514, 0.03856090160327093, 0.028133416480775324, 0.0994991931703783, 0.05677753398495336, 0.030544668646349065, 0.041720527825095964, 0.0153272733610544, 0.027899319163313317, 0.019098137197415196, 0.053910809989658096, 0.02840129636047829, 0.07131294152068515, 0.04053440155281175, 0.03125260475151722, 0.03031688006294351, 0.020104196418317098, 0.0834682364497454, 0.061659184134294914, 0.03747571890632953, 0.08049494196330348, 0.9482750320626844, 31.513020146277647, 60.970992888173754, 43.06336872039303, 32.031920302298765, 43.57658732321955, 52.753733281166326, 62.7083832217801, 57.446441265844534, 62.22502562307543, 36.503510552067915, 0.06603483320964922, 0.38699863057944084, 3.5216221021067713, 4.318717343191947, 0.6775484462418865, 18.68478690424273, 50.20298457914784, 52.57010359917918, 52.744213688758116, 51.889121301712535, 52.244080112826445, 54.281994604295306, 52.241479581402196, 47.47729816744405, 42.33403144344207, 38.57766774392898, 39.43228944655388, 39.179853547003965, 39.88373071916642, 37.75655484968616, 36.7015588668085, 40.33444243092691, 42.988388692179036, 46.2814655611592, 49.92934042407621, 52.2030834997854, 51.20108658267606, 53.192179741397986, 54.405478662060155, 54.14319369100756, 54.21866009312292, 56.06125623949113, 54.85737492961269, 52.666413476390225, 50.36022455461564, 50.404896428508145, 42.379691754618, 41.07383274262951, 39.970925008097005, 39.16164590466408, 38.93575268407022, 38.929065042926425, 39.60504631842337, 39.71871660601708, 39.83375972317111, 41.89669501396918, 39.16176749813942, 40.7111390175358, 40.28340062787456, 40.285805040790194, 41.247934987468106, 40.90831656609812, 41.09162853610131, 40.95249422134892, 40.52195918175482, 41.39690660661267, 38.416148462603175, 37.52029480472688, 36.94933891296387, 40.80702135639806, 44.12161634814355, 44.62836304018575, 48.84248302828882, 58.165231289402136, 48.133196907658736, 48.06497512325164, 58.38149509122295, 51.79685931051932, 48.04248033031341, 45.93134695483793, 42.300703064087905, 40.96793659271733, 37.53295229327294, 39.53735013161936, 40.012533510884936, 40.6038700380633, 43.36781917079803, 42.38414756713375, 41.00610517686413, 43.364496923262074, 41.387955757879446, 40.43278409588722, 41.26256150584067, 40.3758861941676, 41.08871029269311, 41.70160024396835, 40.3066877395876, 40.6771909036944, 39.86948859307074, 39.7184028164033, 39.37531701980099, 37.90030579413138, 40.22437680152155, 38.798477572779504, 38.72089701314127, 40.52494018308578, 41.135206068715746, 40.21537496197609, 40.74258858157743, 39.8617732909418, 40.276732598581624, 39.38004347585863, 40.73302192072715, 39.2671537399292, 39.73826177658574, 39.76509078856438, 38.677033147504254, 39.606376001911784, 37.94340871995495, 37.34764383685204, 41.37593761567147, 41.07023200681133, 43.820535213716575, 45.19776567336052, 48.28656550376646, 51.19511281290362, 52.84753284146709, 53.278746451101, 55.002381032513036, 55.93084919837214, 59.83042647761684, 55.975725035513605, 58.638410337509654, 56.307365355953095, 57.920510691981164, 58.61073017120362, 63.66853629389117, 21.155536905411754, 0.04095771492669179, 1.7226592595538788, 3.42976485048571, 0.489702798546322, 0.07664803911240832, 37.461133695417836, 67.60332076780259, 56.47167344247141, 45.26441458732852, 29.401753410216305, 29.46324048503753, 46.9677391359883, 59.48757602322487, 19.486366395027407, 0.1790173577084657, 0.03068660558652013, 0.015915519719372596, 0.044351434635539214, 0.04168324232582123, 0.07864411184263807, 0.04574197231821957, 0.009714188317077295, 0.025047865215568774, 0.048408103851421226, 0.12920972230213304, 0.15600225317382044, 0.1527426869518334, 0.08609322140053396, 0.1954384064001422, 0.10617240887856293, 0.1530604142575495, 0.14935628721310248, 0.11756088809981463, 0.18404819582018161, 0.15441001603199592, 0.16200776962983995, 0.1426191874329121, 1.228902844652053, 40.3409888667445, 70.42092400212442, 52.068401075178585, 46.4239574247791, 47.17870381570632, 57.28048186148367, 67.61400530415197, 61.914362138317486, 65.74672960465955, 41.90047617881529, 0.22780301650204968, 1.6248333862712308, 10.099001988287895, 7.359451959210058, 0.6404696681326436, 19.158940661338068, 51.7817856419471, 52.754360860393895, 54.839771332279334, 55.69830756033621, 56.27515877446821, 56.83296295904345, 55.95296352140365, 49.37598812964655, 45.33324041674214, 40.84125580326204, 42.25160283427085, 41.56330139406266, 44.31584819670647, 39.46411555813205, 39.84414615938741, 42.74407994362616, 46.386930250352435, 48.8967215630316, 53.51971334026706, 54.788811899000606, 53.42640407623784, 55.30252864283901, 55.79449584407192, 54.39970885553668, 54.93573211854505, 59.15955212808425, 57.58592074917209, 55.499317876754276, 51.3956557550738, 54.02758575254872, 45.24067640304566, 42.9117573461225, 45.552006690732895, 40.033635862412, 40.83168914241176, 40.08552881979173, 40.88063639979209, 44.426196236764234, 41.58538041576263, 43.89020435271725, 41.85279976937079, 43.175301398000414, 41.957585888524214, 42.02447798944289, 45.546746792331824, 41.135209991085915, 42.70748422991845, 43.32130378292453, 42.440084488161155, 43.19279124659877, 40.563799104382916, 40.970317471411924, 38.69793153578235, 44.55908221583213, 46.28209706275694, 46.1930121914033, 51.402221802742254, 58.33594852878202, 51.66043535355599, 47.47337187490156, 61.86864299158897, 53.607896066481075, 49.90512371063233, 48.618998142980764, 45.19108979932724, 43.70043223904025, 40.620653860030636, 42.98305426874469, 41.83762804154427, 43.84181799427156, 46.38948371333461, 42.96231277527348, 42.58314901782621, 46.0254289257911, 44.42789462304885, 43.01623359803231, 41.610954269286125, 42.90425385198286, 43.22642557082638, 42.55466868800502, 42.35157620522284, 43.234348758574455, 42.92628188287058, 42.03398581474058, 41.43141169701853, 40.44103676272977, 41.56542339632588, 41.43071351512786, 39.522547106589045, 43.65090839324459, 42.23166542668497, 43.71983228191253, 41.26444032115322, 42.16784454161122, 41.98388538052959, 40.56810586683212, 43.43440924921344, 41.847959564578154, 42.21850979712702, 42.07746921047088, 41.64245090176983, 42.3745769839133, 38.50483325219924, 40.39830646207256, 43.32585373232442, 42.932071301244925, 45.79904540892571, 46.41832097884148, 50.96466964290988, 54.27899006874331, 55.88063893779632, 56.66927068464218, 59.31125763923892, 56.88228284159015, 62.32357909602504, 56.85059401296801, 62.44856149919572, 59.252178899703495, 61.36678749515165, 61.215058449775945, 65.50663348167174, 22.36986937061433, 0.2055639283911836, 2.145769129837713, 10.949616009189237, 2.2145682381045435, 0.1471800765683574, 41.13270751891598, 73.71893913515153, 63.109080791473396, 50.1553983842173, 33.43929221553187, 39.43049692338513, 55.81506867562571, 68.61504908530944, 26.799845234040294, 0.39740195137358486, 0.11929217786077531, 0.23982716483935235, 0.18647304796163114, 0.16968807686240445, 0.23470006011907132, 0.26558766802472455, 0.13811327276691315, 0.24397271174576976, 0.10965038676776233], [0.02302163734941954, 0.048848255837876955, 0.03901627192634248, 0.018994420383786483, 0.026372708943522265, 0.022721401746234587, 0.04972955572508997, 0.030327886831195607, 0.04333081016797693, 0.03879855739914122, 0.11083734041500477, 0.0482758196190961, 0.15203172671458415, 0.02486563205058056, 23.065542905561387, 50.75444236878426, 44.25012888446931, 21.57286728582075, 27.866784834092666, 47.89489330783967, 54.157149484080655, 53.913487926606216, 52.67094381393925, 39.831508282692205, 0.42355600924741843, 0.23911582155814096, 2.92277374575215, 3.2827257340954197, 0.14076890123467292, 2.4946928841452447, 28.0146268106276, 48.699226302485314, 48.01309393298242, 52.29891092546525, 53.1276685191739, 54.070825961328325, 48.91380740750221, 45.53565040711434, 37.947962591725016, 37.5436132954013, 37.83220168082945, 38.2639055867349, 34.84080214654246, 37.931045409171816, 41.80523318629111, 45.002882711348995, 48.24816549977949, 48.235959083803245, 48.4838411115831, 51.9404298259366, 52.42227731212493, 52.49808496044528, 50.70744845174974, 49.604360288189305, 50.43436127324259, 51.73761190906648, 50.966144454094675, 52.88490518446892, 51.36172725308327, 50.05409532977689, 46.61281170383577, 38.98022059471377, 37.887436497596006, 38.02545293684929, 36.80295998050321, 37.55087752496043, 35.73382777552451, 37.773644616526944, 36.64748507161295, 39.32415754564347, 36.55709405099192, 38.94132244971491, 37.79805744847944, 38.5104343968053, 38.070038518598004, 39.79319064847885, 39.527359854790475, 39.087058113467315, 39.65040068472586, 40.04424195135794, 35.506491122707246, 35.531413862782145, 34.97493543932515, 37.86425136750744, 38.733813378118704, 43.60121980790169, 45.23849556522985, 54.311737937311975, 50.594315528869636, 50.69943112711753, 55.778920112117646, 51.730685003342174, 46.41978010054558, 43.60999807234734, 41.72217307552215, 37.095227549152995, 36.147661362924886, 36.66852074284708, 38.03616885216006, 40.43128967285156, 39.68813780815371, 39.20720815658569, 39.74268228776994, 42.01389935708816, 40.225726096860825, 37.47224577011601, 38.84842895692395, 38.68302260675738, 39.06256683411137, 39.119150946217204, 39.59848419312508, 38.10684211792485, 37.35232322446762, 38.680222034454346, 38.408382169661984, 39.02035820868708, 38.33217051721389, 37.03215975915232, 37.40885634576121, 37.34749870915567, 38.01035573405605, 37.681261031858384, 36.89238217569167, 37.45716033443328, 38.95537630204232, 36.619055732604, 38.572592196925996, 38.12416722697597, 40.06706622339065, 38.55511411543816, 37.71693891094577, 36.72640315947994, 36.07904734150056, 36.546942956985966, 37.19398890772174, 35.86639604260845, 37.79231509854717, 39.368229296899614, 41.25881564232611, 41.934086968821866, 45.351240173462905, 47.91047688453428, 48.55997823899793, 50.86961884652415, 54.51188079772457, 56.913893222808845, 58.18326242508427, 56.17676219632549, 58.170459808841834, 55.56433116236041, 52.44617239121468, 4.624941195211103, 0.06278042275939258, 1.1913048427912498, 1.8229206795653992, 1.2012377549563686, 0.10835490144428708, 37.546245205786924, 61.79962104366672, 55.60485709098078, 44.21867147568734, 28.016880212291596, 23.815933504412254, 41.68031746341337, 47.608038610027684, 8.538732163367733, 0.061012678704555, 0.0393575411139717, 0.02236608250607406, 0.025619594718239484, 0.047744258021515225, 0.060997318641673175, 0.04453375973107834, 0.03039912917771407, 0.03587599708548477, 0.03272457183488915, 0.06355687968372818, 0.040701186554806854, 0.08740653359000722, 0.012883126337621963, 0.05884458093092807, 0.03147701680239651, 0.05696430239045332, 0.06428410013717029, 0.02140924634952699, 0.0668270523930269, 0.05410029417684963, 0.03867210692635948, 0.10435516405249796, 0.15120756932564322, 29.227702156189952, 59.67952897471767, 50.68652260688044, 27.19454942211028, 31.83392886192568, 52.60058041541807, 58.97235701161047, 60.14307860405215, 56.08147213535925, 42.93618194518551, 0.29619517886350233, 0.3119510334105261, 1.7783173245768396, 5.809438151697959, 0.41917594750562026, 3.640657456651811, 31.10391497612, 50.03427559329618, 51.630970508821555, 54.62713964523808, 55.842799832743985, 55.82513739985805, 51.85347480158652, 48.37463840361565, 40.461790023311494, 38.93903570790445, 39.671801136386016, 40.60094787228493, 38.140798076506584, 38.83934474760486, 42.852239301127774, 47.16323398774671, 50.433117881897964, 49.97864461714222, 50.23787406183059, 54.99290458617672, 52.77663207823231, 54.459262201862956, 51.69284197591966, 49.11890422144244, 50.922496318817146, 51.859099480413626, 52.23108137807539, 52.31057997672789, 52.6196902028976, 52.78567706384967, 49.89762413886286, 39.87551335365542, 38.98676703053136, 40.15388396478469, 38.62821140596944, 38.293794047447946, 38.36953893784554, 38.827287381695164, 39.56132758048273, 40.9874935303965, 38.94430345104587, 41.497884104328776, 41.01383616847377, 40.30177300976169, 40.27107261842297, 42.29966755836241, 41.909933013300744, 41.58946752548218, 40.572624437270626, 40.776842640292266, 38.368727007219874, 37.62253530563847, 37.850817249667266, 40.23573990791075, 41.7727049704521, 45.522918393535, 45.94243157294489, 55.97873349343577, 50.73264183536653, 52.9825839688701, 55.142672446466264, 52.86845476396623, 47.83302184074156, 45.8857141002532, 44.32027263026084, 39.65319733465872, 37.480388610593735, 38.688262893307595, 40.78583271272721, 42.08777327691355, 41.189354388944565, 41.70691113318167, 40.80789212257632, 43.680781164476954, 42.30960684437906, 39.69184837033672, 41.92392018533523, 40.90180935398225, 40.44637118616412, 40.86603341564056, 40.54219861184397, 40.11590757677632, 40.46783831811721, 38.23455841310563, 39.51660079340781, 39.99239998479044, 39.64594879458028, 39.60479528673234, 38.307239932398645, 37.93938044578799, 39.921326637268066, 39.9511327282075, 38.17902549620598, 38.34878175489364, 41.12054032664145, 38.80324325253887, 42.11725773349885, 39.18079491584532, 41.543152178487475, 40.25842689698742, 39.25359802861368, 39.58133951310189, 39.056526384046, 38.81528492896788, 38.90734295691214, 37.31773576428814, 39.994549443644864, 39.88969272182834, 42.96114390896213, 44.330561007222826, 48.108183953069876, 49.230181863231046, 52.19495242641818, 54.375366626247285, 57.88398558093656, 57.96290759117373, 59.41581233855217, 57.03415701466223, 61.19401493380147, 57.458690827892674, 55.474650090740575, 5.86093298850521, 0.30711309623814403, 2.8710136586619965, 5.025486282763943, 0.8588234190979313, 0.19687402452672684, 40.683447084119244, 67.77411645458591, 59.291849751626295, 52.7839865223054, 34.87893935172789, 24.890296190015732, 47.98847321541079, 56.434728637818374, 12.442536777065648, 0.19271822736388255, 0.024675797378163666, 0.016381124019502633, 0.016829241405151064, 0.039203139923272595, 0.028005857095723192, 0.032651421929439234, 0.022787348509976463, 0.1304901923022924, 0.008341827985620307, 0.1938199230860318, 0.10924071358937411, 0.2209477399986598, 0.1513596071350959, 0.12732718380228167, 0.09411981569663172, 0.11151698297790943, 0.1306821432926001, 0.11255733037908232, 0.12818214558665791, 0.19379286486054623, 0.17991763359356314, 0.2685710595500085, 0.14954970909222481, 35.22751254420127, 67.36417385839647, 57.541927445319395, 32.128914633104884, 38.99158370110297, 59.79368171384258, 64.31903000800841, 64.9206353002979, 62.76945452536307, 50.7798554051307, 0.6837789473995086, 0.6121443945073313, 10.755649901205494, 6.9749184769968835, 0.6386438661044644, 3.958834976919236, 31.31994539691556, 52.77442378382529, 53.53828968540315, 55.67534992771765, 59.48229259060275, 58.482609871895086, 54.300233625596576, 50.241965093920314, 43.39960605867448, 41.090585185635476, 40.75600700993692, 43.541615470763176, 38.783607867456254, 42.51735910292595, 46.37806961613317, 48.969591356092884, 55.095298059525035, 53.53631281083631, 53.1695515878739, 57.79063317083544, 55.38709494375414, 54.29723693478493, 53.50119190831339, 49.883687957640625, 51.73394057058519, 54.73154137211462, 53.89833188826039, 54.944690812018614, 55.448119178895034, 53.280786083590606, 54.396920050344164, 44.001901688114295, 41.640046488854196, 43.08995062305082, 41.24801735724173, 40.33448165462863, 41.83071682530065, 40.991710078331735, 41.00448131561279, 42.96920045729607, 41.57436247794859, 42.88024894652828, 41.73559150388164, 41.025889612013295, 42.227625385407485, 44.92167788167154, 44.58947273992723, 44.159322092610026, 43.285331726074226, 42.4498825688516, 40.609098557502996, 40.061614128851126, 40.986936553832024, 43.09401812091951, 43.00108932679699, 48.26924823945569, 49.82411892183366, 58.84247949046474, 53.7055552390314, 55.50102410777923, 57.47935779633061, 55.786251021969704, 51.101352476304584, 47.43408149288547, 46.38448269136491, 42.39986058204405, 40.194849198864354, 40.96582635756462, 42.422735844889, 43.023152659016276, 42.94729009751351, 42.558947993863015, 42.811646692214474, 47.23184800917103, 45.05968647618448, 40.849049552794426, 43.70331910348708, 42.662224000500096, 42.45863729907621, 44.158259130293324, 42.610754659098966, 43.229210453648726, 41.65260591814595, 42.83277650033274, 41.644898460757354, 41.5852705893978, 42.67723098877938, 42.025046733117875, 40.641458111424605, 40.59062811636156, 41.79277181625366, 41.65230781801286, 40.47996628669001, 40.03667177692537, 41.96804684977378, 40.3957922227921, 42.829611147603686, 42.25421121043544, 44.15204609594038, 42.50030071504655, 42.14538112763436, 41.70169045848232, 42.2198159463944, 42.00512501501268, 41.98155157027706, 40.00093506228539, 41.87161145671722, 43.637580179399066, 45.136200151135846, 46.24490514878304, 49.48097428967876, 50.43563604354859, 54.4620470846853, 56.699135611134196, 60.21323411695419, 60.89499304371496, 60.58518071328441, 58.20296449045981, 60.57297037493799, 57.79413192502914, 57.69884578643307, 7.2815958530672145, 0.32537053429311324, 3.6759438341663735, 11.484238986046085, 3.3285738287433504, 0.3160220859271865, 44.92040311136554, 73.58946169576338, 64.83219762002268, 58.0798295236403, 40.68427862659578, 36.66696748425884, 55.98227539370137, 66.10297495318999, 17.65861249739124, 0.4141596037774317, 0.12591126945710954, 0.14655082726911192, 0.09816587842520207, 0.16340676875364396, 0.13799284374521625, 0.13822389586317924, 0.10486226063221694, 0.20339836636858605, 0.10146971686833328], [0.029296422219504754, 0.05067076751842134, 0.037732032773595665, 0.02304863237265137, 0.058821717036827925, 0.030956550073179028, 0.05784899987761052, 0.0320288050363982, 0.05080297131151442, 0.026700067889666366, 0.08724499629029343, 0.05824128286011758, 0.06339359187310742, 0.005715436305880788, 16.007988914366692, 54.16574731949837, 43.386834821393414, 26.16119315547328, 28.56038147403348, 38.27065206343128, 51.0065213326485, 55.9666016024928, 50.48188078788019, 48.56081370384463, 1.6798229323279474, 0.07290660358604885, 1.2464157371751725, 3.314701876332683, 2.1720936269529405, 0.31059306595594655, 12.333474293831857, 45.54837457595333, 52.25805159538023, 51.816082846733835, 53.67645517472298, 52.66250287332843, 49.51034107515889, 42.04865940155522, 35.9617135601659, 37.60847360857072, 37.909044834875296, 38.00080084031628, 38.683053985718765, 46.70369302072833, 48.919133986196215, 51.70264790135046, 49.808864824233524, 52.72670815067907, 51.04363479921895, 51.92655640263712, 45.583401341592115, 43.780366220781886, 51.70564851453228, 53.82061796803629, 52.47625304806618, 51.830591694001235, 49.64504703398674, 52.685915500886985, 49.459060007526034, 53.0030861977608, 48.91704336289437, 38.76757321819183, 38.209757266506074, 38.281850430273245, 37.59777338274064, 38.297504609630955, 37.44197291712607, 37.71051799097369, 39.35904310595605, 37.87699907056747, 38.61695812594506, 38.16997658821845, 38.597620840995546, 39.0267595168083, 38.80928370260423, 38.57267848906979, 39.81945091678251, 38.36187854889901, 40.933411890460604, 37.21997068774316, 37.224446112109774, 34.582639586540964, 35.86865925019787, 38.54768906870196, 42.0000220114185, 41.75292445767311, 43.458555359994214, 54.19849911043721, 54.351903007876494, 50.98756451760569, 55.499733647992535, 52.20003974053168, 43.82960765592514, 43.52303912562709, 41.478954745877175, 37.34600820849019, 35.64969685769851, 36.45078997458182, 38.81625767677061, 39.62041024238833, 38.753158507808564, 39.95155242181594, 41.018621460084, 42.34143295595723, 39.33643064191265, 39.408264929248446, 36.93207263946533, 40.70859339929397, 39.00987371321648, 37.848130426099225, 40.06346940994263, 39.08325733677034, 39.2053371860135, 37.081075637571274, 37.89431633487825, 38.627007238326534, 38.19710762270036, 37.00148290203464, 37.313319175474106, 39.471309185028076, 40.8038991497409, 42.0751707015499, 41.71300649642944, 44.39689220920686, 43.55212350045481, 44.067530785837484, 42.7965965578633, 39.77102141226492, 40.87697682842132, 38.238135614702784, 36.62827722487911, 36.63480797121602, 36.6261395331352, 36.7605826931615, 36.44374539775234, 37.21380864420245, 37.804380309197214, 36.1286457123295, 36.31233422986923, 39.160528029164965, 40.80386384840935, 42.85964473601311, 45.79247936125725, 48.856933040003625, 50.69054303630706, 54.40941279934299, 55.88755015403994, 58.99028224329795, 55.89361806069651, 57.92876728119389, 35.51863870313091, 0.6638674642289839, 0.10896852254987725, 1.080389284799176, 1.6439419480100756, 0.4640141544082473, 0.2040055983008877, 35.31875471914969, 62.57184159371161, 50.97380484304121, 43.01551972666095, 21.16386409728758, 29.134526252746586, 40.96745414118613, 43.26917548333445, 4.785955961673491, 0.1857448201025686, 0.08837595657115022, 0.0857850012459582, 0.01806131188547419, 0.07428274264619236, 0.013815169973719506, 0.054821857070970925, 0.05702576945505797, 0.0681896623404276, 0.093511036266723, 0.041969081221689145, 0.00681701184798693, 0.015480840473525949, 0.012252742270638627, 0.09603318157455615, 0.008733922318976012, 0.08386911493876288, 0.06773225422347746, 0.02863756745242544, 0.07140956052969541, 0.012161828701444452, 0.051246072736478625, 0.0699096982697806, 0.0230699353626058, 21.43514502433039, 60.84247642947782, 48.16490927050191, 29.131949255543372, 33.45376968383789, 46.59286645150954, 56.00659016639956, 60.440174610384055, 55.8946261098308, 51.796722027563284, 1.560670274399942, 0.21148123748360143, 0.679790203369433, 5.0293002974602485, 3.138894626209813, 0.9135866321382985, 15.062342728337935, 47.574714153043686, 52.52925211383451, 55.06882990560224, 57.9464767825219, 55.28732945842128, 52.61796043765161, 44.54210227535617, 37.975709438323975, 39.65988889817269, 37.941082754442775, 39.19250319080968, 40.595786033138154, 46.15120364773659, 51.1553595912072, 54.595239008626635, 51.681690677519775, 53.3837914466858, 53.31840161354312, 54.22051145184425, 48.294492613884714, 44.76551263563095, 52.58801706375615, 54.841124549988784, 52.5754850910556, 52.5151982615071, 51.81780084486931, 52.99071504223732, 52.41472282717305, 54.30610541374453, 49.54732902588383, 39.00897941281719, 39.195366521035474, 39.97247826668524, 39.34643660822223, 40.000680108224195, 39.10385762491534, 40.07667603031282, 40.11773147890645, 41.02519927486297, 42.4097724114695, 41.63609666209067, 40.9301249442562, 39.04153116287724, 40.775760066124704, 40.45819320986348, 41.919735016361365, 41.40128397172497, 42.795474759994015, 40.90557482934768, 39.34439305336245, 37.689670593507834, 37.015105293643096, 41.45138440593597, 43.802351105597715, 44.55611690398186, 46.01270867932228, 54.81072225878316, 56.28934598738148, 52.04787138969668, 55.818516439007176, 53.08303194661295, 47.242881636465754, 45.89422564352713, 41.801644217583444, 40.11426018130395, 37.99132831635014, 39.03654190801805, 41.07379744129796, 42.103219570652136, 40.75529313856556, 40.933090256106475, 40.98346133385935, 44.35582107113254, 42.04614908464494, 40.21148397076515, 38.59172944099673, 43.65158304091423, 40.424362767127256, 40.663388083058024, 41.578971262901064, 39.42184809715518, 39.84653880519252, 39.37388927705827, 39.20395258934268, 39.902805205314394, 38.836752060920965, 38.72321121154293, 39.11234171159806, 41.48540312244047, 42.018790552693034, 43.40633292352, 44.25801284851567, 45.56590364825341, 45.80181852463753, 45.46925252483737, 43.779405240089666, 41.84968540745397, 41.59090703533542, 39.914176156443936, 39.37160645761798, 38.10311194389097, 38.672965649635564, 38.225407523493615, 37.664355616415705, 39.51010927077263, 38.45330899761569, 38.09211754029797, 38.849044769041, 41.91917019505655, 43.384481399290024, 44.95778722147788, 49.61144016635034, 50.55906518813103, 54.40526685407085, 56.96096950961698, 57.96913631500737, 57.42062814774052, 58.87461154691635, 57.82586782209335, 38.877615313376154, 1.4157504636433818, 0.8041894604121486, 5.753382578972848, 3.8102717745688657, 0.4018265381455422, 0.29744267643940064, 39.51970731058429, 68.36706899827527, 55.27642134697207, 48.562908249516646, 23.477660456011375, 30.27442389918912, 47.76945983209918, 53.03019762039185, 5.954484458892576, 0.15034716065612533, 0.12421561810638636, 0.12268783194163155, 0.02631104269605731, 0.03659783960169843, 0.032682777908180034, 0.030504387743290395, 0.028938994322332646, 0.11502876832720735, 0.04576356450636541, 0.15981806051586905, 0.1470881000521683, 0.1843575268022476, 0.12175528843316341, 0.12924413497169174, 0.10062398644344461, 0.14997658860539237, 0.17173817411305445, 0.15155889724771823, 0.10467430095999472, 0.36487986423796226, 0.13009737305823835, 0.28602634226122214, 0.09411450670731646, 24.592929540141938, 72.33340894022297, 56.626383489178075, 38.638899864689, 42.04550973830685, 50.29973376181818, 60.53711598919284, 66.99582407551428, 59.09108715672647, 58.16117555864396, 2.279906099842441, 0.6196953860982772, 4.292734092281711, 10.085459024675432, 3.398848728787515, 0.786758631227478, 17.805803360477572, 48.92546076928416, 52.5220271079771, 55.94488736121885, 60.63734039183586, 56.49387405764673, 53.926435670545025, 46.28086936089301, 41.64399631561772, 40.57842170038531, 40.4005539801813, 40.33881587366904, 42.06932244762298, 50.14035217223629, 55.27996716960784, 59.29563483884258, 54.10665289048226, 57.23383311302432, 55.58471179777577, 54.85506073121102, 47.45475630606375, 45.220083959641, 56.68069654895414, 57.80556563408145, 56.296829869670255, 55.31091859263759, 53.66892814636231, 53.889012336730964, 53.689838301750925, 57.67001636566655, 52.35130986859722, 41.34414680542485, 41.86517484726445, 41.65847378392374, 43.45769636092648, 41.619206936128684, 41.64681649977162, 41.25036685697494, 43.05945811733123, 42.31221522054365, 43.810195845942346, 42.460818136892016, 43.38969815161921, 42.01179304430562, 42.48024955872567, 41.37596899463285, 43.604636192321784, 44.27373763053648, 45.72402615700999, 42.10902467850716, 41.586208035868985, 41.58338000697475, 40.12536833363195, 43.22888489692442, 47.18138279453401, 47.58575562507876, 48.95280753412555, 58.790374725095695, 58.215833786995184, 53.99142542193013, 58.78987658408381, 56.34033679962159, 47.714252471923835, 49.01562821480536, 45.41209574668638, 42.09332343070738, 39.083316172322924, 41.81798088935114, 42.585937823018725, 43.843696809584095, 41.56917318221062, 42.483779691880756, 43.108656406402595, 46.102499577306936, 44.69683585628387, 42.009482768274125, 40.39051271254017, 45.85204447469404, 41.65827766541512, 41.86644961757045, 45.102754100676506, 42.554154857512444, 42.0988892739819, 41.897024493063654, 41.48786244853851, 41.872046839806345, 42.180666769704516, 40.9003149309466, 41.06879249695809, 44.06736212392008, 45.139820498804895, 47.00276197925691, 46.485079719174294, 47.76920487803798, 48.99461215542209, 49.02417113704067, 46.564609696788175, 44.25505145903557, 45.55246168567289, 42.40058622052593, 41.075284019593276, 40.02958797639416, 40.80985330766247, 41.21970176696777, 39.61110245796942, 42.37152930228941, 41.001837638116655, 40.632013044049664, 39.69382916727374, 43.98333711008872, 45.68421017739081, 46.23015703693513, 51.17245720278833, 51.32428038504816, 56.463663962579545, 59.71764264568206, 61.88944724298293, 61.35727182511361, 59.727817273909054, 57.451967885417325, 41.758427543024865, 2.194874507765616, 0.4243835987102601, 7.8494687618747845, 7.9640054029803125, 0.7565599968356471, 0.36341185591393904, 44.585617050047844, 74.82561234504946, 60.33443535527876, 55.95882746481127, 30.860402468712103, 39.23226033487628, 54.67537303124705, 60.278423909218084, 8.16231357474481, 0.28928350296712696, 0.3550354811933733, 0.20240956136295873, 0.16345377590867782, 0.21887012486976964, 0.12534916010354796, 0.13850696535120088, 0.14570094464767366, 0.21136877577631705, 0.23420921226422634], [0.012493127254739165, 0.033082338725967754, 0.04105276345545727, 0.07735962754175549, 0.0754412208052893, 0.03068090014670405, 0.03264426283778683, 0.04144082529350154, 0.03993249776202344, 0.04070220162130652, 0.03549348172401229, 0.05062209412215218, 0.05112655918985125, 0.05863271165458907, 8.230304429608008, 50.587172892785844, 46.91044507488128, 30.084202674127397, 19.48902968437441, 35.930444425152196, 48.70916558850197, 56.80071323148666, 49.421605294750584, 53.21519228719896, 4.7407423104009325, 0.42963433469976153, 1.2582085882463765, 3.6571056708212826, 1.5268346835528652, 0.5206929856250363, 8.204626633274941, 46.471488706527225, 53.3509337517523, 54.35980658377371, 51.57047579365393, 50.89762849192466, 47.77771249894173, 39.54735609792894, 38.65569545376686, 38.17874308555357, 38.71124798251737, 41.608706751177394, 47.99714165349161, 52.82099016251103, 52.508632213838645, 53.26411208798809, 50.36196216460198, 50.16922866144488, 47.52378609872634, 51.09181719441568, 51.265495823275664, 52.87045909512428, 52.02309769968833, 49.45625159048265, 50.339608576989946, 48.98344516754151, 50.64531418585008, 50.58287789744716, 50.314878033053496, 52.368964456742816, 48.4004319098688, 39.355650255757, 37.810330544748616, 36.81046739701302, 38.27105214518886, 37.994250482128514, 37.078377046892726, 38.111219483037154, 39.740744636904815, 39.58236325171686, 38.54227227549399, 39.89465059772615, 38.65589157227547, 38.97248175836379, 39.91071270358178, 41.16429044354347, 41.616904504837535, 40.78418531725484, 38.29932851176108, 39.79876825886388, 39.701364040374756, 36.05976496973346, 35.60025930404663, 37.56586097901867, 38.885581647196126, 39.97164672420871, 41.11065595380722, 51.038739681243904, 53.28366902566726, 52.104722222974225, 53.74255103449668, 53.19597659572479, 46.91521075464065, 43.65574075329689, 41.33348188092632, 37.03451318125571, 36.69861708917926, 37.34876563472133, 39.68381927859399, 40.046964076257524, 39.24862838560535, 39.67573919603902, 38.60066460024926, 40.26825635663925, 39.49035229221467, 39.33666990649316, 39.4367491814398, 40.11555064109064, 39.76975448669926, 39.72547484982399, 39.7189833271888, 38.65017667893441, 38.38526371986636, 37.26278335817399, 35.5270561095207, 38.63022358186784, 37.67227880416378, 36.85698278488652, 39.08561860361407, 41.11976761971751, 46.207281774090184, 49.007830542902795, 50.30234213798277, 49.9246375022396, 50.039096186237956, 49.50050377076673, 50.24304766808787, 51.16989197269563, 48.28365902746878, 40.833666016978604, 39.943433115559245, 39.10466563317084, 37.7194845291876, 34.865285581158055, 35.93344896070419, 35.55600712376256, 37.096851410404334, 37.90912720464891, 38.02832411181542, 35.954955316359, 38.10118998250654, 37.226587726223855, 41.12118751771989, 42.45018459135487, 48.11538542470625, 51.52230124319754, 51.57358623320057, 54.36940070121519, 58.20190937288346, 54.17143475624823, 28.407893450029437, 0.0866368603742411, 2.0390919379649626, 3.3203434703811525, 2.952348171703277, 0.20801763140386154, 0.6954411345143473, 41.81152466804751, 61.50807126875847, 48.50563772263066, 42.73673726666359, 36.345642997372536, 28.0060976166879, 46.42811121479158, 33.926368221159905, 1.5110776645521966, 0.08815477166565196, 0.03580217302266148, 0.07104455793817198, 0.02882565927481459, 0.04917466291977514, 0.04161059037752209, 0.01203146639219936, 0.035355735284787033, 0.09117049976221978, 0.026902328508215088, 0.04553533925284301, 0.025746502928555976, 0.013766788648471478, 0.026599921045764804, 0.02303262879591315, 0.11545608451049175, 0.051995463774449406, 0.054202926976065484, 0.008860766369428848, 0.05100081734839947, 0.04933180670524317, 0.019554436402094942, 0.054843089197792357, 0.06999213699131243, 12.123643179093639, 59.556790167285556, 52.85324381243799, 33.963787632603804, 22.6823293009112, 46.73595059302546, 55.35018544043265, 63.91353537959438, 53.34446184096798, 56.70725491739089, 4.6128725524871586, 0.19097477978756353, 0.7569587302784767, 5.512338222995882, 4.459299993130469, 0.6300281961598705, 9.111066768246314, 47.17940591996717, 54.483620120633034, 56.26269740443076, 54.68434741420131, 53.073324080436464, 50.63655945562547, 41.14270956285539, 42.29860067367554, 40.84057723322223, 40.12532518756005, 42.20893136916622, 49.59474263652679, 53.69338020201653, 53.57446178313225, 53.29450653445337, 53.12067885552683, 52.79625961857458, 49.42673967730615, 51.339965943367254, 49.8567569640375, 54.254098707629794, 53.38585853576661, 52.81446726091447, 52.55672047215124, 52.17152803174911, 52.44013586351949, 52.518759773623565, 53.546459982472086, 54.244382996712964, 49.471772409254505, 41.098979057804236, 40.5116904166437, 37.95440704591813, 39.78075673503261, 39.119754991223736, 39.669004486453154, 39.96737918546123, 42.3580716502282, 42.102403717656294, 40.75102167744791, 41.942539676543205, 39.571270788869555, 40.74283961326846, 43.52673399832941, 42.25377582734631, 41.65380616341868, 42.48663125499603, 38.837536534955426, 41.21662270638251, 40.61717079531762, 37.707929226659964, 39.21580991437359, 39.4470493255123, 41.77876110999815, 42.1788271780937, 44.31212586741294, 52.67053588744133, 55.381497721518244, 54.37753569695258, 55.358904869325706, 55.15970337775446, 48.12119837730162, 44.870134015237134, 42.29917726209087, 39.812947627036806, 39.03695767925632, 39.566975793530865, 41.450572475310295, 41.35625908451696, 41.985109160023356, 40.66077578452326, 41.179513162182225, 41.370595347496774, 42.1745478722357, 39.93877333979453, 42.86434765784971, 41.280580874412294, 41.43893872537921, 41.62580828512869, 41.6979798962993, 41.135919940087106, 39.96277040050876, 39.023198004691835, 38.632373040722264, 40.321765330529985, 39.734111908943426, 38.7371003243231, 41.01687600535732, 42.90022557781589, 47.6819948996267, 49.74083915833504, 51.39203540740475, 53.38310110953547, 53.964176716343054, 52.183483416034335, 52.6813930080783, 52.36683460973924, 49.71570853264102, 42.662882958689046, 42.149809483558904, 41.188852325562515, 39.20394474460233, 38.67272246268488, 38.54616326670493, 38.543998118369814, 39.875121116638184, 38.824275001402825, 39.92230330744098, 38.7644313996838, 41.11746518842636, 39.13140835300569, 43.89517399572557, 45.13896149973716, 51.38612831792524, 53.158004130086596, 54.67321572765228, 56.40334575406967, 61.101760787348596, 58.444119653394154, 31.680348457828647, 0.3837934412783192, 3.4537381318307694, 6.134596265131428, 6.064650599033603, 0.5344135590618657, 0.6003568141210465, 44.85476224653183, 67.80808418027817, 53.221828937530525, 49.30714268838206, 32.730010017271965, 31.494006456867343, 53.32221415735061, 42.40226499495968, 2.279724935370107, 0.13365586678827965, 0.0056457644396071, 0.08020648687717416, 0.0722746959617061, 0.04784308336374741, 0.05735318777301619, 0.05355013962534647, 0.06015141201656192, 0.010164708345978251, 0.07244923377349492, 0.1375627773062837, 0.11835426407595796, 0.16702472622836792, 0.07772957140039052, 0.15519487311042127, 0.204915082562835, 0.20319552160799506, 0.11297586719475447, 0.10628211266931989, 0.1324793855629621, 0.18873981019902616, 0.1618309412151575, 0.20634570579615333, 0.16064335171493793, 14.002632056513141, 65.60175880309075, 59.752351699336884, 41.35482741940407, 30.01190358592618, 49.81803924806657, 59.81709826377131, 67.65442925114786, 57.659896650621974, 63.99994911686067, 6.363930384958945, 1.2392536118145914, 3.018493796548536, 13.263968363884958, 3.8842035493543072, 1.617865663382315, 11.218534688795767, 50.80944184334048, 57.29984268065422, 58.48395916723437, 55.593525363552956, 56.83298649326448, 52.765751423374304, 45.14097367563556, 43.65086916954287, 42.022975721666896, 41.844892271103404, 44.96672238073042, 53.41057339022237, 57.54127240950062, 57.474603883681766, 56.78241929700298, 55.34686711526687, 53.36061808370775, 50.48451662063599, 52.03642199116369, 53.00392558497768, 56.023417134438795, 57.44609609726937, 53.43415467969833, 54.41238987830378, 55.80103051277899, 55.35134253963348, 54.11287769194573, 55.92645614377914, 58.16082254532845, 52.897484225611535, 43.670516321736, 42.22735474186559, 40.25654415930472, 41.57033028141145, 41.66434164970152, 40.90890884399414, 40.724020081181685, 43.906180166429095, 45.230705738067634, 42.832003793408795, 43.4099885725206, 41.677187412015854, 41.35618063711351, 45.585488042523785, 43.374742154152166, 44.56502852901336, 44.96090550576487, 40.44835590547131, 43.796130226504424, 44.802492741615545, 40.111322326044885, 40.12108118303361, 43.02695735808342, 44.629461303834, 45.313036287984545, 45.964620421009684, 54.62626887905983, 55.84878144725677, 55.33356635801254, 57.707369096817516, 58.61392690289406, 53.08023529668009, 46.752142137096776, 45.45458286039291, 41.881013378020256, 42.24301676596365, 42.24066334386026, 44.17472524027671, 43.51260169859856, 43.21605090172061, 43.29289013339628, 42.812301728033255, 43.16609167283581, 43.39061598623953, 43.057991150886785, 44.3514633178711, 43.50081889860092, 43.61992166888329, 44.55380270558019, 43.30397867387341, 41.891011499589496, 42.398742706544944, 40.25552434305991, 40.0247948400436, 42.90698382162279, 41.93751512035247, 39.48345676545174, 44.31678172080748, 45.546958600321126, 50.23277498060658, 52.853643894195564, 54.98717400335497, 54.57602331715246, 53.45353903308992, 53.13341479147635, 55.062871825310495, 55.870805555774325, 53.831161299059474, 44.644127045908284, 43.83749946471184, 43.42069272072085, 41.51786465798655, 39.752013606409875, 41.47370269221645, 41.71865470947758, 42.736764723254794, 41.16735773701822, 43.20269130891369, 39.6560332082933, 42.83611051497921, 40.676684917942175, 44.85095754746468, 46.796386472640506, 53.70900692478303, 55.44120796265141, 55.92174537720219, 59.0601828021388, 65.0328621556682, 57.6661410639363, 36.345890106693396, 0.75299872986732, 5.973877147320779, 11.011200162672228, 9.048007803578532, 2.180458816789812, 0.9591528677171277, 51.51062826956473, 72.58404839423396, 57.894160209163545, 56.27362512773084, 49.44715561405305, 38.99270157660208, 61.44958480711907, 50.279082482860936, 3.5884784113976265, 0.27632105014016556, 0.10395947197872786, 0.18091932419807683, 0.09927132797818031, 0.19364870243495513, 0.18079088189669196, 0.06429266500016374, 0.21294077287518212, 0.2213133477996434, 0.19648526554867146], [0.09121831897045336, 0.060127245772990494, 0.024898050976316297, 0.025310520375628146, 0.012349111343463583, 0.032774585885025805, 0.0336523924113041, 0.10758244732935583, 0.030945236869757215, 0.0321076967708406, 0.036293231551685644, 0.03183277845833331, 0.01120860943750989, 0.06903270379670205, 4.064332761110799, 42.624180932198804, 53.75222359934161, 31.213294190745202, 22.14078922425547, 31.53799387716478, 36.795448641623224, 52.837420971162864, 51.37178028783491, 59.21380635230773, 11.748130167684248, 0.21233487393586867, 0.3146107068225261, 1.8709540246955811, 3.562121064432206, 0.7365880846496552, 14.513979688767465, 51.873557336868785, 54.9064947712806, 53.80779966231316, 50.22556566422986, 53.00937767951719, 43.04801264116841, 39.37961201513968, 40.000927217545055, 38.50768481531451, 41.90105668960079, 46.621531132728826, 51.46051214587305, 51.98028895162767, 50.14617296957201, 51.445783645876, 48.438914283629394, 48.26899328539449, 51.637018803627264, 53.441971963451756, 50.44886619813981, 50.80644515252883, 48.949014602168916, 49.35551727971723, 48.26445510310512, 47.35484177066434, 49.251362662161554, 50.282043872341035, 48.64871401940623, 47.92259308599657, 43.08083111240018, 38.52883815765381, 37.63402000550301, 37.6946480812565, 37.84018762650029, 38.256394247854914, 37.22667794073782, 37.706501483917236, 38.9612167112289, 38.33910919004871, 39.84374215525966, 38.61180020916847, 39.65769237087619, 39.340968824202015, 40.698152049895256, 38.85111970286216, 39.54617938687725, 39.9189143796121, 40.038193656552224, 39.50444144587363, 34.51876771065497, 34.285904438264915, 36.05878045482021, 36.69557332992554, 39.48922264960505, 39.210624541005785, 41.436573536165305, 51.466117212849284, 56.321889892701186, 54.365807810137355, 54.15082270099271, 50.942802429199226, 43.763790284433675, 41.8192478149168, 39.79892907604095, 37.68339087886196, 36.48875851784983, 35.658118186458466, 39.64409351348877, 39.737857772457986, 38.25502534066477, 39.284824017555486, 40.22987204213297, 39.488281280763694, 39.23379790398383, 38.46062421798706, 40.23234313534152, 38.93791391003517, 40.08575631726173, 38.23124008793985, 38.983013322276456, 37.86623608681464, 38.34868761800951, 38.4708341475456, 38.28538840816867, 37.564264574358546, 36.71647171820364, 38.47043406578803, 41.43377296386227, 46.70141020128804, 49.75333975207422, 51.101226960459066, 52.12177668848346, 46.98528782013924, 46.72138291020548, 48.482789916376916, 52.71762786373016, 51.38544582551526, 49.453870711788056, 51.07661408762778, 46.47264188335788, 43.70075779576456, 42.0218970698695, 38.60761111782443, 38.51995791158369, 37.26739214312646, 38.116530372250466, 37.34177204870409, 37.261830222222116, 39.1188253894929, 39.330021489051084, 36.84476460179975, 37.71091807273127, 39.03898162226523, 41.58598446076916, 43.13525399854107, 50.574958632069254, 52.36524604981946, 59.07430333475913, 53.5317510943259, 21.122343847828528, 0.2681653700288265, 1.9037477359656367, 5.2565565416889815, 3.0725124334135367, 0.4230216169549573, 1.514967675170591, 46.81539035612538, 56.55532975350657, 49.598210011759114, 30.112355486039196, 20.638293950788437, 29.336196876341297, 46.94644851069297, 27.951853198389855, 0.2862714597534749, 0.06921733098645365, 0.0500225039168952, 0.055760153899750406, 0.019980839025529645, 0.04124387940992752, 0.0242571858689189, 0.019971774290165594, 0.007249505828029567, 0.043349648270034985, 0.04262582541653707, 0.08273346619980951, 0.09982396082411851, 0.08114827706688836, 0.04513680499287383, 0.056411933844848994, 0.048361196287817536, 0.05590162735672728, 0.07581665751434143, 0.02321491750227588, 0.0788633432239294, 0.016778254423350576, 0.006367585888402838, 0.04456141933558449, 0.06028046718828621, 6.12857150454675, 52.93352296275478, 56.60257470223212, 36.502957497873616, 22.94121946057966, 37.506688102599114, 45.11130094528199, 60.14537319060295, 55.008017478450654, 62.51220979998189, 12.100390388119607, 0.20748916863193437, 0.6572355329990387, 3.7745125063004035, 5.4462477564811715, 1.7581254532260282, 14.332496523857118, 53.9144959757405, 57.834289150853316, 55.82429801264117, 52.4326245246395, 53.005663194964015, 45.081679205740656, 41.84783012636247, 40.33527397340344, 40.76961763443486, 42.26159703346991, 48.795245924303615, 53.33587185029061, 53.880257606506355, 52.27835378339214, 52.32430042759065, 52.97704165981662, 49.32929231274513, 51.781891545941754, 53.598878537454915, 53.28227658425608, 52.40381079335367, 52.47373488641555, 49.858745605714866, 49.750531335030836, 49.78147883569041, 50.66438867199806, 51.937523349638916, 50.93812696395382, 51.78720243515507, 45.70840727898383, 39.81189250946045, 39.30977813659176, 38.71340136374197, 38.61318088346912, 40.908100835738644, 38.75983438184185, 38.89806655145461, 39.90066751357048, 41.114135096150065, 41.66968784024639, 40.69691650329098, 41.0845604250508, 39.249189284539995, 43.307889276935214, 40.536240531552224, 40.8508106970018, 42.057759300354995, 41.51725669060984, 41.709652869932114, 38.3509272913779, 36.27797818952991, 37.4456677898284, 39.189196632754424, 42.13614394587856, 42.077465288100704, 43.68772768205212, 54.375900068590724, 55.90896237281061, 55.030688778046645, 55.6466224885756, 54.107386373704486, 46.85728519193588, 43.957959375073834, 43.08367090840494, 39.06703441373764, 38.30972279271772, 38.39519123877249, 39.9153999359377, 41.50577591311547, 40.427732083105276, 39.335983491713, 40.02306115242743, 41.7982788239756, 41.770210343022505, 39.35768204350626, 40.67761844204318, 41.02389704796576, 41.43978203496626, 39.435741132305516, 41.03818624250351, 40.11213033430038, 40.303275277537686, 40.44796366845408, 39.1763626375506, 40.03755823258431, 39.067587467931936, 40.340749602163996, 42.29511760896252, 47.52391553694203, 52.017002336440555, 53.449922607791045, 54.48492626990042, 50.66601645561957, 48.77299039594589, 50.3280964205342, 55.88012118493357, 53.24724589624713, 54.06761746252737, 53.26821096481816, 48.26051312108194, 44.087193627511304, 43.048793192832704, 39.62559561575613, 40.49983701398296, 38.48941441505186, 40.872866184480735, 39.084794905877885, 39.78912707298033, 40.53592674193844, 41.31618815083658, 39.17631949147871, 39.80787992477417, 41.29630957880328, 44.84356387968987, 47.29196617680211, 53.482776380354366, 55.803199583484286, 61.581713768743704, 54.642303528324256, 23.716087610490863, 0.4355861024270135, 4.43789856087777, 7.577381297465294, 5.9200720344820335, 0.4412413941275689, 1.3443913959687757, 51.02608611506801, 62.57363803925053, 54.023239766397786, 36.460901844886045, 27.98653675663856, 33.38580677586217, 55.274636668543664, 35.40246202099708, 0.6966683460820107, 0.06953940967157965, 0.014107208436114654, 0.04402007862565018, 0.005178141497796582, 0.024349482226816398, 0.01562875672994602, 0.1965060724966949, 0.051152269100590106, 0.0833151950651119, 0.0345835148266727, 0.18413834904711093, 0.21287715693394985, 0.1439298566190466, 0.15112447942937576, 0.10709798098692011, 0.13964567844185138, 0.13499544813267647, 0.20096203823003078, 0.06771058159609956, 0.17903952829299435, 0.1496316038913304, 0.19121294120146384, 0.09016798178274786, 0.4273038339470664, 9.064130706171836, 61.039163681768606, 65.47242649139898, 44.95146043838994, 32.05789619876493, 45.097474590424575, 48.48064437989266, 65.87918020063832, 58.79159065984911, 69.40508504067698, 15.604280925566151, 0.5229577866773452, 1.8451308555180028, 7.220060238915106, 9.871453527481327, 4.010821580886841, 17.630069409647298, 56.75703371724775, 60.44212795072987, 57.9331721028974, 53.79098446138444, 56.22175570457213, 48.0765147362986, 42.68892357426305, 43.62566401881557, 42.30954016408613, 45.43744994748024, 51.70640945434571, 55.59285463825349, 56.09640067623508, 55.83655149705949, 58.0168794047448, 53.26571241501839, 50.088733780768614, 53.56529520403955, 55.68624627205634, 54.31396192119968, 54.3083058634112, 53.75693436591856, 53.47692812642744, 52.621004196905325, 51.760918632630386, 53.42836133895382, 55.93361839171379, 52.75734578409503, 54.04771535627304, 48.22003426090364, 42.63621868625764, 40.18686325319352, 40.95436911429129, 40.47654597989975, 43.01815555941674, 40.71370424762849, 40.23492013254474, 42.36320603278376, 43.043356787773874, 44.398810248221125, 42.471639956197436, 42.62582832767118, 42.753226910868, 45.090790871650945, 42.52039109506915, 43.28658688452936, 42.83250585679085, 43.935209628074404, 44.153442459721724, 38.46732754861155, 38.22008486716978, 40.21693998767484, 41.40823441167032, 46.380885877916896, 43.63984338698849, 46.04715101180538, 56.25278557500532, 58.375674293887236, 56.126234223765714, 59.013800774851155, 56.43760765752485, 49.136331312118045, 46.68589330488636, 45.389377378648334, 41.80069108163157, 40.88214258993826, 40.117401999811975, 43.181914514110936, 45.055811174454234, 41.29925527880269, 41.67724624756844, 43.84085309120917, 43.414267878378595, 44.38915337285688, 41.598312470220755, 43.63294393785539, 42.461124081765455, 43.92834548027285, 42.025721380787516, 42.15320233375796, 43.62282422281081, 42.95892776981477, 42.48748633169359, 41.93154527295021, 43.3374168795924, 43.06509848563902, 42.824194354395715, 45.419791436964466, 51.57703399658204, 53.412769917518865, 55.329149769198516, 58.20710651336178, 52.32387681161204, 51.154939897598766, 51.755466538090865, 57.35484999995078, 55.398948346414876, 54.14171103508242, 56.473630705187404, 50.298572740247174, 47.81491618002615, 45.09593309894685, 42.73072427318942, 42.87817401270713, 40.78322041419245, 43.72304862545383, 40.92293916210052, 41.98961204098117, 41.6856401197372, 43.863092930086204, 41.443704405138575, 40.95349050337269, 42.83481221045218, 46.67949591913531, 49.54798013933244, 55.06815525793261, 58.71290399182228, 64.72993358489006, 57.027316401081706, 28.30202279552337, 0.8944626873539341, 5.208105464135447, 15.882012190357333, 12.501630225489217, 1.1032152728688334, 2.0503715714139323, 58.94349621188257, 66.63950812432074, 59.229484065886474, 40.2301936764871, 30.845475889021355, 43.39756642618487, 63.02765630906629, 43.77019551492507, 1.4662788039253605, 0.15809620129725627, 0.08285721238221853, 0.1473336312319002, 0.0906672336221222, 0.14198008624296035, 0.13454671979190844, 0.2764364229815622, 0.21119770834282522, 0.1835762396935494, 0.19775943830609324], [0.13084490633299276, 0.11080642876726006, 0.07546689241163193, 0.01912538119922242, 0.08216132109443988, 0.00921808414146184, 0.0456642335461032, 0.13057104522182097, 0.09291305101566738, 0.04174300867523398, 0.03036804324496658, 0.044960221726327174, 0.061593821512595306, 0.11844309197077829, 4.877318259208433, 40.7756620068704, 55.98652332059799, 29.28566105904118, 46.89711686103575, 52.97882241587485, 29.68073591109245, 60.46669375511908, 47.29146411342006, 58.332034003350046, 25.789048479449367, 0.05105510616915361, 0.3715702326547715, 3.148177895815142, 3.8932181366028327, 0.8515870751392457, 25.072757005691532, 54.71123918410271, 55.924596940317464, 52.891314337330485, 50.87891486383254, 46.94246730496807, 40.13722958103303, 40.2192267294853, 38.80098396731962, 41.26012179159349, 45.754318621850786, 49.03332202665268, 53.302108087847316, 49.99460474137337, 51.23763915031187, 50.6225016809279, 49.97483207333473, 52.96204643864786, 51.10188199627785, 50.36411554582658, 50.797329564248365, 47.037321982845185, 47.349205324726725, 45.875174691600186, 45.42534159075829, 43.62391464171871, 42.575559231542776, 45.81663723914854, 44.66993624164213, 40.95481234212076, 38.127301200743645, 37.42038811406782, 37.13609864634853, 37.348494991179436, 38.361403942108154, 37.73034557219475, 36.149638237491736, 38.13760134481615, 40.14183052124516, 38.82651075240105, 38.90008264972318, 38.42308321306783, 38.832755165715376, 38.19658594746744, 40.68628295775383, 38.3202818132216, 39.33459105030183, 38.76596896879135, 39.26415312674738, 38.32411396887995, 36.66044850503245, 36.88432562735773, 36.40531793717415, 36.372813255556174, 36.22848180032546, 39.04741471813571, 43.20193429147044, 53.88655693300309, 55.01951786779589, 54.179146136007006, 54.143295672632036, 52.03428822178995, 46.30860051801128, 43.88707822368991, 39.58333992188977, 39.574369461305686, 38.670004260155466, 37.1274027516765, 36.84876149700534, 41.19743839386971, 39.44058525946833, 39.64085363572644, 40.175182434820364, 38.97895759151828, 39.85357553728166, 37.971638018085116, 37.425636245358376, 40.22395318554294, 39.77113908337009, 39.343910601831254, 39.03962096860332, 39.47019130952897, 38.100946795555856, 37.13498861558976, 39.029603235183224, 38.53034434779998, 37.757402081643384, 38.23084000618228, 44.12285973948818, 48.802090460254306, 49.07459320560579, 49.923413722745835, 51.747747313591745, 47.536757376886186, 50.48006473049041, 48.46518631904356, 48.31100186993999, 50.61361359011743, 53.824454046064815, 51.46046899980115, 49.76755049920852, 48.3662719880381, 47.07198396805794, 44.94741255237211, 40.62388589305263, 38.62878014964443, 37.45228090593892, 36.88642801777009, 37.61179585610667, 36.84006952470349, 39.5190679642462, 38.748075116065245, 38.23457410258632, 39.76604784688642, 40.35682347513015, 42.7529445002156, 49.18635722129576, 53.63096352546446, 54.56503283592963, 52.9988500379747, 12.101934821374956, 0.05995967936131263, 3.0501117773594397, 3.953940839536729, 5.568257493357505, 0.1514190249145031, 4.828808346102315, 57.95986775429019, 53.395099639892585, 45.06699777418568, 30.868859098803615, 27.668354088260283, 37.47836466758482, 48.44946545939292, 17.3408495226214, 0.07347380742430687, 0.0535242650057039, 0.00843653177481986, 0.02501753770986632, 0.008464275648997677, 0.04635077856120564, 0.09031746085853347, 0.09955032187844477, 0.03031495335181394, 0.023587050457154552, 0.04228222732161803, 0.08195106826362111, 0.09844907814817083, 0.06369749512222987, 0.03532434100165002, 0.02839444561921541, 0.06186846403344985, 0.04843629205659513, 0.06660785931613177, 0.09020112274635224, 0.03634726756342477, 0.02664823246548974, 0.033481991474306395, 0.06502937345254807, 0.05642227220138716, 5.962956778464779, 49.95260400156821, 62.72850890313426, 35.507118701934814, 43.629743283794774, 49.941990067881925, 36.45392002597932, 63.98661698064497, 53.74051924674742, 63.14553922222507, 26.878700563984534, 0.015641708403915888, 0.3498625490934618, 4.996578414593974, 3.963983087770401, 1.0246235384575784, 26.104560013740297, 56.11172929886849, 57.90620188559256, 56.747180723374896, 52.22724137767669, 49.99928020661878, 42.20040021404144, 41.16286662317092, 40.93168604758478, 42.33214478338919, 46.840552360780784, 52.36878402771489, 54.08476998729091, 51.10644763515842, 53.400610569984686, 50.718509535635675, 49.777399570711204, 54.3491808829769, 53.41730025506789, 52.576434304637296, 53.10615039640858, 49.40240921512727, 48.6067368138221, 47.67178104769799, 46.91907821163055, 44.42798091519264, 45.410448351214015, 47.36354551007671, 48.1471291665108, 43.72869291613179, 39.86125553807905, 39.789060392687404, 38.49525874660861, 40.01213735149753, 38.197593996601725, 39.685349002961196, 39.0651555984251, 39.219108627688506, 41.73483840880856, 41.29781576894945, 40.26178444585493, 40.54461871424029, 40.891175808445105, 40.397925992165845, 41.23539124765704, 41.90211572954732, 39.706388596565496, 40.99518137593424, 39.55060382043162, 39.32827995669457, 38.82037616545154, 38.5439863512593, 39.65378569018456, 40.342357773934644, 38.36337297193466, 40.867359176758804, 42.62620487520772, 54.33699015648135, 58.00377476599909, 56.33522595128706, 56.87452047101913, 52.849333209376184, 48.095173451208304, 45.53543467675486, 41.93788382314867, 40.80573874135172, 39.7390462506202, 39.27040930717222, 39.58704263933244, 43.33895444869996, 40.86158152549498, 39.79222182304629, 41.44700311845349, 40.4454533515438, 40.84888481324719, 38.84401629048009, 38.91433654292938, 40.771108135100334, 42.5369042734946, 39.84544446391445, 41.372968381451024, 41.242996723421165, 39.74936600654356, 38.99597675569596, 40.2723866124307, 41.15695561132124, 39.1102118645945, 39.95489428120275, 45.61106581841746, 50.22186686915737, 51.80252713541831, 51.16039199213828, 51.43862924268169, 50.52654089466218, 52.259981401505016, 50.04621528810071, 50.30442883891445, 54.34128122944986, 56.206242730540616, 55.66645399216683, 52.071848838560044, 50.06882382977394, 49.41558053416591, 46.456356202402425, 42.38852493224606, 39.95355283060382, 39.679791004427024, 39.26720080837127, 39.67589609084591, 39.27674785737069, 40.03946058211788, 40.24867588473905, 40.145584229500066, 40.65554726508356, 42.3805272194647, 44.958136312423214, 51.10214871744956, 56.82995450112128, 57.049956321716316, 55.40168223842498, 13.63457743198641, 0.07983949245704759, 6.042872619244361, 5.539311872374627, 6.172503521365504, 0.6234218216230792, 5.021466833929862, 61.95329166227772, 57.508108769693685, 52.63343811035157, 38.96692375982962, 26.916623999995572, 40.84071059380808, 54.63322716374552, 24.081464236782445, 0.09969104456925586, 0.04803644778627542, 0.010063660391155752, 0.030537452098102342, 0.05487033128437977, 0.07314208369221419, 0.03560742964186976, 0.012283843525144602, 0.050868226680904634, 0.004616241381999346, 0.010787661360096066, 0.23993786454441088, 0.17170789831828687, 0.11616138335798057, 0.2654090776078163, 0.18617055048384976, 0.1074237981811166, 0.1421014039266494, 0.19214323241143458, 0.2950653830362905, 0.19057590844890765, 0.1509819717537011, 0.15862166100452024, 0.18242321608047332, 0.18146050402954703, 6.9876651994643675, 58.59515443924935, 69.99950455081078, 41.86846571583902, 54.06260859581732, 65.24465445549258, 41.581057963832734, 71.42679229859384, 58.31164552319435, 69.01011805380546, 32.523544296141594, 0.31720768359880297, 1.3586598754890504, 10.647836692871588, 9.924906607597105, 2.937488517453594, 29.922526497994703, 57.83435190877607, 60.98671767019457, 59.349681177446925, 54.53244186216786, 50.957730970075055, 44.5825772131643, 44.12338925946144, 43.07246077445246, 45.794985755797356, 49.88881841782601, 53.986565605286636, 56.42400487776726, 52.409972836894376, 53.82834503727575, 51.677682015203665, 52.25685919484785, 56.52170719638948, 54.085374032297445, 54.18194278593987, 54.4282127195789, 51.96912588611726, 50.594982331798924, 49.12186168855237, 50.27483063359415, 47.04623360787669, 46.6417391838566, 50.479343014378706, 48.881855780078524, 46.50731171331098, 41.961472957364975, 42.12357274947628, 40.56764694952196, 43.41294211726035, 40.29427736036239, 39.773245396152625, 40.37283459017354, 40.55009826537102, 43.97826940782609, 43.173144094405636, 42.453581363924094, 42.94126141455866, 43.00327408698298, 43.31686758225964, 44.49167236205071, 42.94001410084386, 42.89784862149147, 43.233489759506725, 41.74764886979134, 40.79694870979556, 41.78553112091557, 41.85262326271304, 42.17778382762786, 41.84080123901367, 40.975698963288345, 43.97786148132817, 45.11654515420237, 56.936482152631214, 59.55776291508829, 56.51621980051841, 58.23455525982765, 54.30276355435772, 50.387551707606164, 49.298874332058816, 42.46708608442738, 43.706507990437174, 41.934306621551514, 40.776775959999334, 41.67229621641098, 45.949680113023334, 43.82111572450207, 42.15680306957614, 42.42324967538157, 42.26958297914074, 42.012726568406634, 41.88313930265365, 40.275736316557854, 43.82226105659239, 43.95967737320931, 41.41615367704823, 42.92480314931562, 44.56262019372756, 41.25683484538909, 39.43875743496803, 42.79679659874209, 42.92290079978205, 41.54678037089687, 42.6218157429849, 48.39423064262637, 52.707896463332645, 53.25651445696431, 52.01451163138113, 56.045166677044286, 51.119893520109116, 54.20605751775927, 51.817726319836034, 50.57248361649052, 55.64725006780317, 57.8168502930672, 55.722210484166304, 55.21373794924829, 53.54831134119342, 50.94870559630856, 49.80990817469936, 47.09874237737348, 41.881138893865774, 42.53358202595865, 41.53261276983446, 43.5738024403972, 40.527128865641934, 42.49796690479402, 42.923869625214614, 42.64993521475023, 43.3534985972989, 45.02449497099846, 47.15900175033077, 52.67326977945144, 58.77474800232918, 59.49468728034728, 57.71086785101122, 18.09788657772926, 0.18760907974454666, 9.011348351355522, 10.571021976009494, 15.244791776903215, 1.3943474379278, 6.476221959437094, 70.1807180527718, 62.453060457783366, 55.35498642152356, 43.342974878126576, 38.62338689065749, 50.93951156062465, 63.597019718539336, 29.28583952688402, 0.2585891790447697, 0.14599195080659083, 0.08836843358773379, 0.1621688013115237, 0.17793597863806834, 0.11574146758404472, 0.1165754232375372, 0.19714895816099262, 0.09159861267694543, 0.10892745257625658, 0.15671846877423026], [0.02718173226551904, 0.03676924794431656, 0.03058849845171696, 0.019200319919975537, 0.035163297828647404, 0.024059661588962042, 0.05572117534616301, 0.03754889179441718, 0.03268850824585365, 0.032273085577593695, 0.020226856671093453, 0.023317305153355967, 0.03595745904491313, 0.06635524182310028, 1.323702731920827, 36.32708234171714, 50.163176444269, 50.40826966685634, 59.753418584023755, 74.85751690403109, 49.955808577998994, 42.93366770590506, 54.53620733753328, 53.65431339510026, 44.98488295462824, 1.5819629834544275, 0.25207763087124596, 2.8280661567564938, 3.059670348321238, 0.23226576977439467, 22.16823600953625, 57.169514086938676, 53.922705496511156, 52.4556056914791, 50.457581704662694, 44.11559943229922, 40.16315644787204, 40.3458918294599, 38.80846392723822, 42.44010017764184, 48.74189776758994, 51.05898303370322, 51.53151881310248, 51.90523047601023, 50.61374695070329, 51.87880939052951, 51.81287434793288, 51.75536847883656, 49.51953903321297, 50.75687031592093, 45.99855284537039, 44.97206464890511, 42.46605842344223, 42.21308908154888, 43.48132471884451, 40.84326797916044, 40.07760170967349, 42.4907575884173, 39.06553606833182, 38.172545740681315, 39.06486926540252, 37.991646028334095, 37.86728728202082, 38.10908179129324, 37.54799850525395, 37.57929117448869, 37.37532400315808, 39.45757304468463, 38.84498511591266, 40.56184968640728, 40.038028917004986, 40.00881510396158, 39.48518653069773, 39.01914619630383, 39.87885129067206, 41.13973640626477, 37.952598833268695, 39.86086330106182, 39.61909232601043, 39.926123695988814, 38.92294614545761, 35.86345818734939, 36.32573696874803, 35.67098748299384, 36.68130766960883, 38.038514429523104, 41.35377622419789, 52.65554851101291, 54.769219659989886, 52.876570147852746, 53.23410595616987, 52.62364002966112, 44.66126780356131, 41.942520064692346, 39.34263190915508, 39.35395579184256, 37.872841358184814, 36.81058114574802, 37.54409574693249, 38.73546077359108, 38.052564359480336, 39.931968027545565, 39.277536253775324, 39.996600843244984, 39.118578280172045, 38.64776049890826, 38.80197632697321, 39.10188859508884, 39.37692126920147, 39.97403544764365, 39.21897918947282, 37.376112399562714, 38.310660239188906, 38.21939453001946, 38.074882645760816, 37.850017086152114, 37.93934122208626, 39.39362272139519, 44.18867711097964, 48.64932983152328, 51.626318577797186, 48.63513869623984, 50.97840186088316, 52.919982940919944, 52.25917339324952, 52.009141906615234, 50.40618688829484, 48.51080740651777, 50.284985649970274, 51.899107656171246, 51.30160124071183, 50.31930638897804, 50.35070496220743, 49.87245036709694, 46.889048545591294, 42.732450116065245, 41.12298788562898, 39.392720576255556, 39.07965267858198, 37.26041424658991, 37.132560668453095, 39.44810444308866, 41.535393730286636, 39.696692497499534, 39.704266594302275, 44.616615541519664, 50.53545644206386, 54.55758033260223, 55.61730277153754, 52.88388536822412, 8.317661496900744, 0.1810236960168808, 5.709508907410407, 4.322414177079355, 3.1893490543288574, 0.24779441796483534, 6.971936004777109, 58.965324201891505, 50.72947648263747, 46.8404503791563, 24.191070948877645, 23.323823136668054, 33.69002188405683, 43.79365913329586, 9.476695406821467, 0.04975414331701975, 0.07468385096158713, 0.038719535429751685, 0.06537309412153498, 0.04082795112363754, 0.08223046819048543, 0.03589902568848864, 0.052234421919790976, 0.023815020986442125, 0.005140744915772831, 0.04725947375259092, 0.018184673108701265, 0.049522114436953306, 0.027971362071712653, 0.060570044593224605, 0.015916304001885078, 0.05983028711090165, 0.02874490977715581, 0.09875071760747703, 0.04373317869800714, 0.030036955365851045, 0.01831125956208956, 0.04972813463199043, 0.04828780889511109, 0.007407454963427999, 2.4176719977009684, 43.59880362787555, 57.81720722875288, 48.09915857930338, 60.901280603101185, 69.79354873780282, 46.519878987343084, 53.08491468429566, 56.910186582996005, 58.746820726702296, 46.968625591647246, 1.3488848387233674, 0.24438092935710187, 5.857001302703734, 5.796477169759813, 0.20075917814768132, 25.104088898627992, 58.73173921338974, 55.65352586007888, 54.64500604137298, 53.144048337013494, 45.8429681101153, 42.49617830399544, 41.285358321282175, 40.90883431896087, 44.8660586726281, 50.43816597230973, 52.058277437763834, 52.385818881373254, 53.32625812099826, 53.34153183044926, 50.32498205861738, 52.69079885175152, 54.37470766805834, 50.78972016611407, 50.601183599041356, 48.25784198699459, 46.270086765289314, 44.283731829735544, 44.63074784125052, 45.37629627412366, 44.834852295537154, 42.3484226196043, 44.77443995014314, 41.91461240091632, 38.83527724973617, 40.87780444852768, 39.95816161555629, 41.25081792954476, 40.74320831606465, 39.509697421904534, 40.085630801416215, 39.225725666169204, 40.50013903648623, 40.571785050053755, 41.10362706645843, 41.954553896381015, 41.697203267005186, 38.92458177381946, 41.65730099524222, 42.1256241490764, 41.756913508138354, 39.17639009414181, 41.28362463366601, 41.21415945791429, 41.66645972959457, 39.426876575716086, 38.88325175931377, 36.83780239474389, 38.41130433544036, 39.35583068478493, 40.45990336325861, 44.355130733982215, 53.0153279150686, 56.3350925907012, 54.5901007037009, 55.838273417565134, 55.37295479928294, 48.18679217369326, 44.598376520218395, 42.90172000085154, 41.50615638302219, 39.25146425923994, 39.21129526630525, 40.16600408861714, 41.25964326243247, 40.53118459640011, 41.83896164740286, 41.41520446346652, 42.21837251417099, 41.84965010612242, 40.72517325801235, 41.682835625063994, 41.55531544839182, 39.909987065099905, 41.14416083981914, 40.994118413617535, 39.27183704991495, 38.6628302451103, 41.176677288547644, 40.46767357856997, 39.66285813239313, 39.73595934529459, 40.07797433483986, 46.142060602864916, 49.928814826473115, 52.24886932680684, 50.33922418471306, 54.07974150873, 54.07969051791776, 53.42370156318911, 53.113383247006325, 52.98759675795033, 50.43742072197699, 52.25609041029408, 53.85984166975945, 54.383442786432084, 52.70211096732847, 52.58594997467534, 51.72447196898922, 49.40516664135841, 44.573434168292636, 42.90792126809397, 42.42885081998764, 40.97010958579279, 40.47110173010057, 38.83015071192096, 42.33534935981997, 44.519576103456565, 42.899550930146255, 41.5830466055101, 47.384043816597234, 53.88978504365491, 56.562719498911214, 56.77810076744326, 55.509147336406095, 9.463806498435236, 0.21855880205910053, 8.652336751261066, 7.5688040544909825, 6.186443624957916, 0.5424715169975834, 7.746567341589159, 63.05653672064505, 54.37375060973629, 52.209496575017134, 31.357278516215665, 27.558598326098537, 39.078303383242705, 53.431342340284786, 13.44578100788978, 0.08381141319630608, 0.03445548238232732, 0.10347453832265832, 0.03142620793603842, 0.006583461325780879, 0.09708802335925641, 0.014311625592170224, 0.019189857074149677, 0.011141191784953399, 0.02445076671128552, 0.025413089972590248, 0.09488607216025553, 0.17983498802829176, 0.11538364323637179, 0.1022423088790909, 0.18081481448344647, 0.1046337595870418, 0.16706197342324644, 0.1979258938902809, 0.22222084023298758, 0.13346619873998627, 0.15349838672386062, 0.14072947835008945, 0.10972434489597237, 0.11852890147917694, 3.121021365927112, 49.120324119444824, 61.80249221863286, 60.652974959342714, 68.17771265583654, 75.72477648335119, 60.03455838849468, 54.9986743927002, 61.61029608018937, 62.244810058224594, 53.072947532899924, 2.591684518321868, 1.0280961843748246, 9.200189882709134, 9.67455348660869, 0.5540743169765319, 27.223455329095167, 61.89797447573755, 58.77148459034582, 56.29705344477008, 55.27771180675876, 46.09942443909184, 43.79809925633092, 44.38293641613376, 43.09748549615183, 46.61562404324932, 53.59202615676388, 55.35067965907436, 55.25743315296789, 54.86138751429897, 53.33554629356631, 52.5285735437947, 55.45166107916064, 56.00413084030152, 51.992707175593225, 53.404572163858724, 50.00845463045182, 48.02774006320585, 47.568795296453665, 47.11900534168367, 49.22918950357745, 47.892539885736284, 43.284088334729596, 47.53070908208048, 44.78331627384309, 41.874043326224054, 43.78838746778427, 42.23934150511219, 43.787854025440836, 41.72344000108781, 41.84313112689603, 43.16946883355418, 42.3127604299976, 44.98969570282967, 43.12476558070029, 45.02619335728307, 44.228924551317775, 42.652739709423436, 42.29284655663275, 42.99367996954149, 46.126053410191695, 45.66768523185484, 41.768409975113414, 44.253388374082505, 43.27819693473078, 44.13105749314831, 42.65071184404435, 40.76706809382285, 41.26722912634573, 39.75018578190958, 41.77260691119779, 43.77337263476464, 45.924773062429125, 54.483651499594416, 58.498766114634854, 56.51182282355524, 58.30824090588478, 58.11773138661539, 50.05837463563489, 46.412268761665594, 44.749681949615486, 42.333992219740345, 41.52007295239357, 42.368414940372595, 41.05463274063603, 41.699540999627885, 42.85211378528226, 44.093002657736506, 42.95125561375772, 44.309737143978, 44.08216907132057, 42.916632852246686, 43.12330253662602, 45.25400853926136, 42.776804277973795, 43.77688707843904, 43.174446321302845, 41.618332247580256, 41.010447240644886, 42.78237404361848, 43.08398077564855, 42.45247133316533, 41.71644641507057, 43.39364797838273, 48.5096699191678, 52.786324254928104, 55.427028594478486, 51.294054600500296, 55.16275498174853, 56.237656993250695, 55.56934002907046, 53.343402801021455, 55.25083572633805, 51.42786625892886, 53.36116721553188, 53.54633446662657, 57.088858389085345, 55.69793885754001, 53.94380000329787, 53.85193809386223, 52.146028703258885, 46.29253841215565, 45.21964857655187, 44.89071469153128, 43.84138261118243, 42.7701440934212, 42.345437695903165, 43.75932662717758, 45.65660061374788, 45.02148651307629, 43.86927458547777, 48.96975609564012, 57.177166631144864, 59.407583205930656, 58.59020833046206, 55.761485176701704, 11.66895124220079, 0.511237652671914, 10.866316633839762, 16.752841126534246, 11.74836943226476, 0.6169762642633531, 8.54464807818013, 71.0367831876201, 59.09444862796415, 58.38934767630793, 34.83331041951334, 35.62608811163133, 46.4908456033276, 61.22433485523347, 17.343100963100312, 0.34799406064614175, 0.14963142003022856, 0.15462072085469, 0.14646317148881574, 0.14227608729514385, 0.20747223808880777, 0.14911441793364866, 0.1323193497955799, 0.1341899373238125, 0.08806654131941258, 0.10592265655436825], [0.08435243981019144, 0.030219479644250487, 0.05635343154051131, 0.0331331380162268, 0.030870654379888892, 0.02055575928440498, 0.029350996408010685, 0.06567320906587186, 0.04654701198301008, 0.025004226932181947, 0.008687996305525303, 0.0669181862124993, 0.023140411621199983, 0.08919930190689142, 0.9958501340400789, 27.470554844025646, 54.872997730009025, 37.44834676865609, 63.566158510023556, 79.25356034309634, 57.84689957095731, 45.035187352088194, 54.963267157154704, 49.72301198590187, 54.92499659138342, 7.7778462825282935, 0.1420782067843022, 4.87599543986782, 3.7419906643129166, 0.1359878384297894, 24.665116840793242, 57.861890869755904, 52.959061514946725, 54.30730173664709, 47.786353480431345, 45.64979922386908, 40.4769499840275, 41.02514828405073, 41.19110768841159, 47.709655454081876, 47.78389023196313, 52.76906190379974, 50.714002732307684, 51.315376604757006, 51.39063512125323, 52.59969003738896, 52.92221476954799, 51.390540984369096, 48.150012108587454, 46.52960254300026, 43.83257296777541, 44.79756232230894, 43.473150499405406, 42.13098602910196, 41.41414934589017, 40.37752574489963, 38.196633015909505, 40.478314968847464, 39.31130001621862, 37.454285237096975, 37.407220717399355, 37.16724618788689, 38.08320591526647, 37.568657628951534, 37.373029416607274, 37.57463139872397, 35.624083780473285, 38.83565771964289, 38.834312346673784, 39.39460331393827, 39.0191932647459, 38.96788081815166, 38.46288350320632, 40.886488576089185, 38.54189965032762, 41.10232091719105, 37.31923410969396, 39.691110964744325, 38.25984201123638, 39.22913420584894, 35.83376976751512, 35.80472461638912, 35.82624666152462, 37.377214585581136, 37.3236350090273, 40.62638444285239, 41.452212026042325, 51.81241543062272, 55.21329079904864, 53.50373360418505, 55.21569913433444, 52.66180469143776, 47.01973015262235, 44.42546667591218, 43.71500384423041, 41.92410061436315, 39.14973366645075, 37.12565337457965, 37.891680502122455, 40.553546028752486, 39.73125250108781, 39.51260782057239, 40.56824707215832, 39.52568892509707, 39.574710707510675, 39.200834305055686, 37.984766191051854, 38.788616734166304, 39.479295130698915, 39.540872420034106, 38.73322894496303, 39.04237447246429, 38.07834609862297, 38.63574627907046, 38.4547249732479, 38.351633318008915, 38.3176459804658, 38.08582213617141, 42.76376631952102, 46.637342206893436, 48.11860961298789, 49.5850779164222, 48.99070547473047, 49.041704131710915, 48.93582367127942, 48.58776038692844, 51.74736684368503, 53.223005648582216, 50.83053242775702, 51.510239954917665, 51.84805800837856, 53.2323448119625, 51.65075102160054, 50.534742570692494, 47.44485232137865, 48.688580989837654, 45.20634389692738, 47.05918527418568, 42.04099509023851, 38.53236044606855, 39.371755507684526, 38.41229277272379, 38.096012453879084, 41.45100785839943, 40.88225241630308, 46.00728796374413, 53.71455707857686, 55.02766855301396, 55.79949686604162, 46.237695832406324, 4.9099881706699255, 0.09205818882272129, 4.64455206548014, 4.491298688996223, 3.4150503239324017, 0.241220724738894, 12.5464403629303, 60.976233174723966, 50.073703258268296, 45.404427512999504, 29.999026444650468, 29.29763605517726, 38.31743025010632, 38.904142302851525, 3.763751974028926, 0.06955802560813966, 0.02333720620240896, 0.06979876107746555, 0.020059552644529653, 0.05113415495162049, 0.07991832290445605, 0.046219796678351785, 0.09378696581529034, 0.03755587851628661, 0.05298221949487925, 0.025602085778730053, 0.01755883290071882, 0.05857357349727423, 0.017634643046485803, 0.003359351568149343, 0.037063192050423355, 0.0742581435629437, 0.06562810946976946, 0.018156383396877397, 0.018815370314123652, 0.04604344706862204, 0.04653967286069547, 0.053180950363316846, 0.03180468984458956, 0.07218219084484924, 1.4093378787079167, 35.52238456664547, 61.191379101045676, 46.013826554821385, 66.41495243195565, 81.19696924763342, 61.71751406884963, 47.341144854022616, 59.88894039584745, 54.810047611113525, 60.03177742804251, 7.70969117841413, 0.13221271035652007, 4.739434690244736, 6.171732285330373, 0.25898530778865664, 26.454027506612963, 59.60725930429275, 55.46862925252607, 55.67272586207236, 50.255246239323775, 46.80303881245275, 42.09683002964143, 41.65632824743948, 40.92043668993058, 49.04827017937937, 49.616872649038996, 53.87869650317777, 53.01548088750532, 51.87549891010408, 52.65275186108005, 53.04562430227957, 54.41435890813028, 53.123506884421076, 49.816176122234715, 49.92827746175951, 46.777492415520456, 46.42511060160976, 45.4728336488047, 44.37245192066316, 43.17041020239554, 42.369199414407056, 41.4486740481469, 41.801997230898955, 40.6548765397841, 40.195131609516764, 39.92036173420568, 40.011305809020996, 40.61301700530514, 39.5454066799533, 38.04662981340962, 39.89948295777844, 38.51737306964013, 40.281863058767016, 39.82697402277301, 41.250539441262525, 41.583481988599225, 42.90059820298226, 41.21816027549006, 42.27138726942001, 40.85203055412539, 42.9465409248106, 38.6871999309909, 41.866598667637, 40.52719162356469, 40.70158804616621, 37.932579055909194, 38.33372377580212, 38.48526062503938, 39.598958799915934, 39.93427438120688, 41.341106968541304, 42.933122496451105, 54.15865175185665, 57.212071803308305, 54.81049868368334, 54.87115029365786, 56.28948327033751, 48.96135437873102, 47.066720147286695, 46.19535384639617, 43.02862044303648, 41.40773627065843, 40.650212841649214, 40.61128724005915, 41.607082889926055, 42.207448713241085, 41.16620456018756, 41.51862559779998, 42.072950640032374, 40.65407245389877, 41.98072002780053, 41.066733252617624, 40.92698312574818, 40.74865256586383, 40.891889679816465, 41.374352978121856, 40.1216773832998, 39.09515780787314, 40.67879907546505, 41.255230595988614, 39.34930778318836, 38.90424820684618, 40.17146795026718, 44.90398014745405, 48.645223109952866, 49.9745810416437, 50.56707074565273, 52.121906126699145, 50.688664220994525, 51.54865172601516, 51.11209584820656, 54.04158076932354, 55.93290059797226, 51.70661733996484, 52.88483850417599, 54.15605122043241, 53.917645638988866, 53.760225234493134, 53.15928282276277, 49.40465673323601, 49.837090199993504, 48.47610227523312, 47.767047574443204, 42.54276429453204, 40.45566720347251, 40.89156412309216, 40.34825309630364, 40.75979601952338, 43.7793581716476, 42.35149383544922, 49.56172412441623, 54.85872814732214, 56.15979402296005, 57.462695567838615, 50.09877112603957, 6.693543820611893, 0.2770540737096341, 9.765060217149797, 6.634963712384624, 4.477533621172752, 0.313008387963618, 12.799071400396286, 67.00065643556657, 52.736729806469334, 54.02229055281609, 32.85115045885886, 27.910205471900206, 42.41128644635601, 45.52570719872752, 5.860815807696312, 0.10436601185750577, 0.0673930534732438, 0.148332012336581, 0.03852183111913262, 0.03217231054159422, 0.020469603121220585, 0.005720255477729464, 0.024780678645437284, 0.01981355989682338, 0.07079617691136177, 0.015312167064797495, 0.1363595136471333, 0.24740955071343532, 0.14247873287287452, 0.09997216053307058, 0.14910769168167345, 0.17882510028298826, 0.09465246130862544, 0.12942275603211698, 0.11071125766442669, 0.12095582971890127, 0.2114605224661289, 0.10672160965060035, 0.1638174991333677, 0.16252598214534023, 2.0068174504464675, 39.78692270094349, 71.65996151585733, 51.23292053899458, 73.01113959281676, 84.0847985975204, 62.67043821273312, 56.14174719779722, 65.0403146589956, 58.749393801535334, 66.49436473846436, 10.515744013171043, 0.44737037331346546, 8.671285721563525, 6.776069998741151, 0.8845056893844759, 29.7532428849128, 62.36012381892051, 57.786102833286414, 57.75095055180212, 52.62299283858269, 49.41300745933287, 44.17229337076987, 43.935562641389915, 44.72940329582461, 52.468094518107755, 51.39902114868165, 57.33225322538807, 53.90314463646182, 54.556658575611735, 53.43624530300018, 54.8050348220333, 56.09089759088332, 54.58934368625764, 51.01461318231399, 52.07651253669493, 48.23726523307062, 50.12182289554227, 49.12523884927073, 45.69236086260888, 45.31760584923529, 44.383693433577015, 43.79266677364227, 43.07461023330689, 42.469490497343, 42.21105729379962, 40.16337217823152, 40.3417262723369, 42.98033606621527, 43.25236420477591, 39.91456054872082, 42.054856746427475, 40.61385247015184, 41.86672810585269, 43.60456951202885, 42.9938917775308, 42.916868194457024, 43.34740323405112, 42.836475295405236, 45.8185278215716, 42.322507519875806, 45.409110822985255, 40.507568005592596, 43.88410898946947, 42.775486361595895, 43.224221198789536, 41.3986167600078, 41.411886138300744, 40.83608219700475, 41.53406796916839, 42.39456145994125, 43.758922623049834, 44.774043790755734, 56.22814524558283, 59.95619727719215, 57.17230289213119, 58.5507296746777, 58.92375884517547, 50.50074346603886, 49.188749867100874, 49.39905951100011, 46.39401797325381, 42.164086910986136, 41.95955099598054, 43.24380559305991, 44.181236374762754, 44.90032057608328, 43.32510455962151, 44.74448480913716, 43.60180816342754, 43.70809262798679, 43.024525488576586, 42.8439474105835, 41.57935565517795, 42.4503493309021, 41.24781731636294, 42.78086000873197, 42.10793425959926, 41.28462091568978, 42.03496640728366, 43.14056488775438, 41.119716628905266, 41.93371826602567, 42.62618526335686, 46.88702460258238, 48.973651009221236, 53.04771492558142, 53.006502582180886, 55.615969165678955, 52.43435036751532, 53.672830904683764, 52.683224754948775, 56.90295373239825, 59.363519299414854, 52.529350173088815, 54.11702755958804, 55.40714217770485, 55.52327571376678, 57.198516091992786, 54.58701772074546, 51.72691952797675, 53.91411942820395, 50.56990269691714, 53.028785567129816, 45.05366563796998, 44.430616747948434, 43.02965594876198, 42.89400077635243, 41.94321824658302, 46.33063247126918, 45.35245610821632, 51.45546797783145, 59.478703621895086, 59.14464712142945, 58.78949611417709, 51.91886855709938, 7.872680858258279, 0.9459425088378691, 15.02360147814597, 12.845552467530775, 13.73668751408977, 0.6187850897831302, 16.026836883637213, 72.13885153493574, 59.961115929388235, 58.13253048927554, 40.9863874220079, 40.174911791278475, 49.85030466510404, 55.479407925759595, 8.095051790437392, 0.21304624786059703, 0.2077914975703724, 0.21547594167772802, 0.13239536103942703, 0.1474344484027355, 0.21631079365409192, 0.20455445433335923, 0.2521887136202666, 0.1942022622472817, 0.11952540566844326, 0.12807843260346882], [0.05517789643378027, 0.03749901947054652, 0.027934932675693306, 0.059738119072731466, 0.04154947571336262, 0.02415378315133914, 0.02618824454745458, 0.04632669275686626, 0.04867414320488611, 0.01840543666584117, 0.07258391203058344, 0.02509008240585606, 0.048199088252600164, 0.03950977810628472, 0.1448756228050878, 16.57392809467931, 48.92001259711481, 36.5100295312943, 38.5214013438071, 54.313785414541925, 61.96121092765563, 49.738160179507354, 54.81200487382951, 51.88800734858359, 56.76791437210576, 17.7398173270687, 0.186267736397924, 5.027079745646446, 4.156799941293655, 0.05001235708233811, 23.27777058847489, 56.86850747754497, 51.829379681617986, 52.15814490472117, 48.224176283805605, 42.825551494475334, 41.51345983628304, 41.135508091219016, 43.173269610251154, 48.439200616651966, 51.39816214961391, 53.288293500100416, 49.904374537929414, 50.61918727813229, 47.69932785341817, 51.35847953058059, 52.27350573385916, 49.665243318003995, 46.48722525565855, 45.17976591663976, 43.96123063179755, 43.41738224029542, 41.03386771294379, 41.92896435337682, 40.82133016278667, 38.7430231032833, 37.8947909416691, 41.166604641945135, 35.914613739136726, 37.170266412919574, 38.655471878667036, 39.184207377895234, 38.16315558648879, 38.10002503856536, 38.566281103318744, 37.96895903925742, 36.45265310041366, 40.14099113402828, 38.53665936377741, 40.04721903031872, 39.06481435222011, 38.69684111687445, 40.20929136583882, 39.81663465499878, 38.72107744216919, 39.890088881215746, 39.58637975877331, 37.98676659983974, 39.68206990149714, 36.78458759861608, 37.259374818494244, 37.16455936431885, 35.909338151254964, 37.9023571937315, 39.086791392295595, 41.74148290388046, 44.7803117382911, 51.11617119081559, 55.54062043466876, 54.0904809582618, 53.36715275241483, 52.61221024297899, 47.766082671380815, 47.520746261842795, 46.675247992238695, 44.67104235003072, 43.493103596471975, 39.61819802561114, 38.87217106357698, 39.033768792306226, 39.50467678808397, 39.51088982243692, 40.50693650399485, 39.35783893831315, 39.93252108173986, 39.6798498399796, 38.542695891472604, 39.40799036333638, 38.23004768740746, 39.10781921878938, 38.9556626350649, 40.92693605730611, 38.98703767407326, 36.316437029069476, 37.5468296389426, 37.53799646131454, 38.43489346965667, 38.2561549832744, 40.02131177533058, 45.466910869844504, 46.30869465489542, 46.25053374998031, 46.67635017825712, 46.327494575131325, 47.09605555380545, 48.31537139031195, 47.055561004146455, 49.791269071640514, 53.197157229146654, 53.36049649023241, 50.645078843639745, 51.42922732137865, 48.52404932821951, 51.35073677186043, 48.951317033460064, 49.99314561966927, 48.71155823430708, 47.45559177091045, 49.21020915431362, 48.73591223070699, 45.12025571638539, 43.05796761666575, 39.48761055546422, 37.24973363261069, 42.52339170825097, 46.571720953910585, 53.407725749477265, 57.18364246429936, 56.912967543448175, 42.520901003191554, 3.31519290804863, 0.23258348175835228, 8.392980810134642, 5.824708429075057, 3.3858612708507048, 0.38058117332477726, 18.17358636086987, 59.876396656036384, 46.524727036876065, 40.12234810859927, 21.640898835274484, 27.14979910081433, 41.95023536682129, 35.62853567061886, 1.0793545145180918, 0.08237517453850278, 0.11699811224975895, 0.10369196173644836, 0.010814319304641216, 0.06661722857144571, 0.045797751179986426, 0.033854068887810555, 0.05656371884528668, 0.04044653126789678, 0.03008447196935454, 0.006112517392818606, 0.06357171114594226, 0.09956165997972412, 0.09683422609082154, 0.049103236712154844, 0.03663836948333248, 0.06848764756033499, 0.022053901676929766, 0.01958465857070781, 0.02618287618632519, 0.059375096818492304, 0.026141949854190313, 0.04067827286499162, 0.036794061532184, 0.02661291581218041, 0.18284876260065264, 21.634579896926883, 59.276226951229965, 40.186859330823346, 51.062932860466745, 62.80543050458355, 64.12124449206938, 56.688604047221524, 60.08610225492909, 56.54142102887554, 61.11045275965045, 19.12423945242359, 0.20754356087455827, 2.232361334946848, 4.274496541869256, 0.24917054170322037, 25.820376450015655, 59.646024088705744, 54.27995889417587, 53.65658052505986, 49.27387314458048, 44.760542992622625, 42.697682226857836, 42.90589732508506, 44.066973809273016, 50.05242440008348, 52.4970063086479, 54.36236396912606, 50.8532900194968, 51.60173708392728, 49.94548882207563, 52.95588439510715, 52.97812423398418, 52.773968788885306, 47.2347427183582, 47.87261816763109, 46.332232798299486, 45.284634405566806, 43.90451315910586, 43.64384420456425, 41.83220732596613, 42.30777509750859, 41.029270695101836, 41.859856113310784, 38.587410911437004, 39.31241396934756, 40.824875985422445, 40.936545864228286, 40.00837579850228, 39.12354007844002, 39.86409141171364, 40.78198878995834, 39.43534497291812, 40.83676076704457, 40.96912507087954, 42.41839770347842, 39.68592951374669, 40.997734838916415, 42.46152024115286, 42.65768581821073, 40.72451037745322, 41.92668545630671, 39.52690093748031, 42.00938470901982, 42.68166326707409, 39.68910663358627, 39.856807570303644, 39.888398339671475, 38.295276703373084, 40.55081605911255, 41.820326466714185, 43.624212741851814, 45.51654061963482, 53.33378907172911, 55.83912064952236, 56.32505132306007, 55.69564819335938, 53.04792281120054, 50.02044531606859, 48.74145453976047, 47.99844780275899, 46.84217622203212, 45.32812172366727, 39.9748787572307, 41.521151604190955, 40.02737968198715, 41.998892368808875, 41.046191800025206, 41.11495879388625, 41.70170222559283, 41.31268155190253, 41.88428855711415, 41.03678203398182, 41.383182233379735, 40.4238175576733, 40.64307805030577, 40.43665155287712, 41.9454304633602, 40.61160102967293, 39.72685552412464, 38.95180302281534, 40.034447793037664, 39.93962057175175, 40.33777644557338, 41.95993538825743, 48.958710701234885, 48.77254324574625, 49.74489488909322, 49.06013142678046, 49.18479611796718, 48.5961111130253, 50.06401108157251, 49.6614307741965, 51.04974585194742, 55.028249063799464, 55.94889994590513, 52.03812822218865, 51.23407763819541, 51.16414962276336, 53.36911785987116, 52.49157382595924, 51.46649376038582, 50.856820152651885, 49.49374552695982, 51.95942586468112, 50.55675098972936, 47.157695601063395, 45.04726432984875, 41.076856890032374, 40.320659222141394, 46.099043969185125, 49.38338571979154, 53.38491324455508, 57.14513263394756, 58.293845807352376, 45.34265018278553, 4.770189994765866, 0.577306147784956, 12.481748711678291, 8.95834340203193, 5.432472882732268, 0.3046909713697049, 19.35283322488108, 68.59342113617929, 51.017221558478575, 49.16490970119354, 30.370439598637244, 33.09084846127418, 48.084508526709776, 43.25301924059468, 1.8046605755244534, 0.07728099627720733, 0.03284012853738762, 0.07782772258524934, 0.0780013181088913, 0.017294155268539346, 0.021266928280613596, 0.02346836237026559, 0.07270251776302054, 0.02458962972366041, 0.049139166235803604, 0.029945942205226714, 0.17623576906419572, 0.27812583071570246, 0.17735880799591544, 0.11186157698713003, 0.12244078390780957, 0.12156874602360111, 0.11486655687012019, 0.10844444180087698, 0.2121095674773378, 0.1620184642172629, 0.11320495046675207, 0.14186417714001673, 0.11295919712152212, 0.17417972697125328, 0.2311147839551972, 24.440078696896954, 66.41173608841436, 50.349626310410045, 50.97474228951239, 61.024901943822066, 70.20378943412535, 59.417342062919374, 64.70407339834398, 59.755721015314904, 66.63874718450731, 22.681913529672933, 0.30372177821493923, 11.69449960031817, 11.228618121916249, 0.36108791287387576, 27.013667360428844, 61.06089753489341, 56.58244117613762, 56.42405979094967, 52.14444406570927, 46.790491150271514, 46.12859118369318, 44.989562342243815, 46.775001710461034, 52.48101480545537, 54.941388176333525, 57.74451786471952, 54.02260826480005, 52.52412165364912, 50.53762943513932, 55.19527143047702, 54.83943400844451, 54.854746941597234, 50.33990275475287, 49.35156353058354, 49.07546004941387, 48.46206803475657, 45.635137404164965, 46.19690710498441, 44.73433371513121, 44.49715191318143, 43.10911532371275, 46.18139020858273, 41.50269293016003, 41.05818248564198, 43.08067813996346, 43.544416043066214, 41.51830396344585, 39.48420593815465, 41.74635448763448, 42.38415933424427, 42.316427846108716, 43.40719584495791, 43.22262871649958, 44.244272785802046, 42.84001719567084, 42.88068040724724, 44.815150230161606, 44.8085057350897, 42.896844494727354, 43.65843542160527, 42.434130330239576, 41.95929211954917, 44.23857750431184, 41.11268381918631, 42.543027093333585, 42.14156858382687, 40.663850922738355, 43.03860287512503, 43.3540947975651, 46.74532505773729, 48.01454520994618, 54.562789240191066, 58.65717887878419, 59.90685386042441, 56.76175625093522, 56.529504868292044, 52.07471609115601, 51.38754037118728, 50.97447556834067, 49.0948522475458, 49.13925740026659, 42.739349565198346, 43.15891373542048, 41.88671258188064, 44.20705733760711, 42.7908581303012, 45.95453600729666, 42.66300455216439, 44.66310347280195, 44.701374038573235, 43.45077337757234, 43.049542365535615, 42.3960284263857, 42.066015889567716, 42.71656059449719, 45.136415881495324, 43.019767653557565, 40.632295454702074, 40.488368003599106, 41.615300255437056, 41.84968540745397, 42.63511257786905, 43.3000131576292, 51.94964739584154, 51.42952542151175, 50.954004718411355, 50.53706853620468, 50.00505393551242, 50.29420714224539, 52.407172264591345, 50.83762799539874, 54.30883538338446, 58.44610045033117, 58.558668551906464, 52.51479425737935, 52.227249222417036, 51.708613826382546, 56.286663086183616, 53.031711655278365, 55.98331874416721, 52.64864513950964, 51.93841372766803, 54.782288997404045, 53.27193721648186, 49.131557787618334, 47.705838987904215, 42.724570074389064, 41.945265723812966, 47.01797293078515, 52.05032287105438, 57.43547824121291, 61.63168084236884, 58.92830094983501, 48.13678979873658, 7.157529813628043, 1.1153282874053525, 19.207446652074015, 14.578600737356371, 10.971318483352663, 0.5523712728773394, 22.528003646481423, 73.14319010703795, 56.30475697978851, 52.9569120560923, 31.335064172744755, 38.98113058459374, 54.6342352128798, 51.5636077234822, 2.333231212631349, 0.2825092019573335, 0.13854099497679742, 0.17883565697458484, 0.14661668018708307, 0.1680248233699991, 0.13529615296471503, 0.09826782940616531, 0.1513985090798909, 0.06838948105371769, 0.11406772634795598, 0.07610323568505627], [0.05899521679947934, 0.021307394959993904, 0.022887378525469574, 0.0695154387804289, 0.02380265632734424, 0.04374120346901398, 0.02957878116097662, 0.05416824234529369, 0.03264715481970099, 0.05182214404246019, 0.021254000546891364, 0.030635381117463115, 0.031006981641234412, 0.08830828036391929, 0.0642234298040069, 4.803705176999492, 47.61180800776328, 48.62361869504375, 27.98615432554676, 37.307047305568574, 53.80551684287287, 47.319822849765906, 55.10192686511625, 48.24389011629167, 58.09391083255891, 23.23361254507496, 0.0993307457575875, 0.4557538879734855, 2.491037480292782, 0.14384584741727, 15.490317440802052, 55.96577398238644, 54.44037598948325, 55.10857528255832, 48.31225310602496, 44.27689906089537, 41.03705659989388, 41.16989158814953, 43.97066785443214, 51.43562078475953, 52.31586340935, 51.38033889955091, 51.52210120231875, 51.092954681765654, 49.82128304819907, 52.617348547904726, 49.62975371268488, 48.33291615209272, 46.290518391516905, 44.09108461872224, 44.985514456225985, 45.83695903901131, 41.21029592329457, 41.19146854646745, 40.276838502576275, 39.918828087468306, 36.436536081375614, 36.62596302647745, 37.93743887255269, 37.725548513474, 37.15235687071277, 38.85166883468628, 38.29374697900588, 38.08699492485293, 36.21777372975504, 36.77618980407715, 37.78757295300884, 40.20917369473366, 39.08277096286897, 40.76701318064044, 40.36917501880277, 40.26958604012766, 39.4637547000762, 38.52162099653675, 39.18951434473838, 38.357175627062404, 40.924339448252034, 39.94947356562461, 39.450163687429125, 39.50078187450286, 37.39915632432507, 38.637181866553526, 37.604649297652706, 38.62990194751371, 39.664281952765684, 43.41395801113498, 47.4573136914161, 51.27726293379261, 52.486666940873675, 55.10637875526182, 55.82634548987112, 52.385901251146876, 48.72385486479729, 51.048416168459006, 49.201709378150206, 49.0787430732481, 46.82801254333989, 42.14079587690292, 38.96120102174821, 37.59547879618984, 38.89475999339935, 39.02584168218797, 38.44436599362282, 40.01837392007151, 37.82307432543847, 39.40327175201909, 37.90743274073447, 38.99911857420398, 40.29552859644736, 39.08160209655762, 39.55898592548986, 40.37258355848251, 39.35316739543792, 37.00952768325806, 37.54205219207272, 39.9620133830655, 39.42774734189434, 37.72580738990538, 37.09376450507872, 42.573849078147646, 45.78032393609324, 44.15579980419528, 45.08657432371571, 42.6768309070218, 40.86387218967561, 41.681549087647475, 45.18658691836942, 49.346742937641764, 50.260698333863296, 50.57728851995161, 52.95273473185878, 51.44545024441135, 50.48022554766748, 50.76927285040579, 51.43283590193718, 53.54487534492247, 52.52627503487372, 52.618584094509, 51.170849031017674, 48.371414215334006, 53.28974477706417, 48.64264219037948, 46.356998643567486, 40.442931267523, 41.45017239355272, 44.935221825876546, 51.38162151459725, 53.21576103087395, 56.317363477522335, 38.35853276714202, 2.3254994855773066, 0.2307864233490921, 9.241448313959184, 4.484142324616832, 2.177214526361035, 0.0644021696080604, 25.916582384417136, 57.76409833661972, 41.88954453314505, 39.59507565344534, 28.637832595456032, 27.019543070946973, 43.483623227765484, 20.326796962368874, 0.06660576789609848, 0.08176100951048636, 0.003771977536680718, 0.09580898594351546, 0.04273639488664847, 0.04245549725789217, 0.10807616035303763, 0.0175514918631844, 0.07719682619696663, 0.05502076030919149, 0.021323549839097167, 0.01745097155141975, 0.020210221071817705, 0.0404920292297198, 0.04546572867360327, 0.03184656229531092, 0.05278428918832252, 0.041772319199216944, 0.04578260179128378, 0.014575147389193938, 0.041244132218942534, 0.06214644669765427, 0.05898297471444934, 0.02610548023855494, 0.05176363024680365, 0.012005454834340321, 0.06822399840119385, 7.533182069178551, 55.3559866259175, 52.916990172478464, 31.755508915070568, 51.670213822395574, 63.152670091198345, 52.46341120812201, 58.21106418486565, 52.52336463620586, 61.26698670848724, 25.20686676425319, 0.18297646945763021, 1.0421451950265517, 6.447060117798467, 0.3314672458556391, 18.314538694197132, 58.135707609115116, 56.094870951867875, 56.180798315232806, 50.05615457411736, 45.253616302244126, 43.28903836588706, 43.206197907847745, 47.73449582438315, 51.887697481339984, 53.622161726797785, 55.03087312944474, 51.947297896108324, 51.29858101567915, 51.16809160478654, 55.23995899385022, 51.57692417021721, 50.55965746602705, 49.23999955577236, 46.982852028262236, 46.69825269329933, 45.70475947472357, 45.10754331465691, 43.061842918396, 42.58809904898367, 41.89831495285034, 38.66789010263259, 39.21517449040567, 39.924158588532485, 40.13925352404195, 38.78206637597854, 41.40110746506722, 40.77432840101181, 40.972188441984116, 37.77746500507478, 38.749181224453835, 39.490477808060184, 42.011051716343054, 40.91166234785511, 42.33499242413429, 42.332293833455736, 41.13056982717207, 40.81739602550384, 40.306483776338645, 42.304841164619695, 41.44529688742853, 42.97866121415169, 41.28238908706173, 41.12479217590825, 41.03634272852252, 39.6665608498358, 41.382699781848544, 39.21470380598499, 40.06945102445541, 41.49174951737927, 44.895770626683394, 49.49137249300557, 53.43573931724795, 55.228278175477065, 55.5836723696801, 55.82168179173624, 55.259037402368364, 51.06889094075849, 50.86755567981351, 50.93800144810831, 50.621987850435325, 49.48937992895804, 43.70414672359344, 39.412206911271625, 40.28745243626256, 40.36709616261144, 41.767237186431885, 41.282377319951216, 41.75692527524887, 38.58206472089214, 41.88140953740766, 40.00839148798297, 41.52314024586832, 41.274893437662435, 39.973886397577104, 40.17089136185185, 42.62481243379655, 41.69046071267898, 38.302564467153246, 38.614381128741854, 40.34655471001902, 40.79175549168741, 39.238296862571474, 39.30647550090667, 45.68377871667185, 46.7298944534794, 47.425405210064305, 45.89251156776182, 45.55871786609773, 43.66260490109844, 45.883129258309644, 47.67764891347578, 51.561332748782256, 49.727122629842455, 52.75976588649135, 53.94303906348444, 52.04492568969727, 50.840028485944195, 51.79886364167737, 52.842574965569284, 53.950624927397705, 55.256770272408765, 55.91253172966742, 52.1376818995322, 51.02547030295096, 54.15723185385428, 51.60575751335391, 47.73861431306409, 43.18697437163323, 41.26112591835761, 48.40683714036019, 52.75268600833032, 57.94196605682374, 55.90734635629962, 42.730488930979085, 3.2040714256225096, 0.984568355544921, 10.84147822472357, 8.177805956332914, 3.7193350541976193, 0.08733115053825802, 27.467558153213997, 64.09097948381978, 49.61126365969258, 45.74573647591376, 24.192047619050552, 26.470795639099617, 51.06930671199676, 26.35533675070732, 0.09440453227369056, 0.03317986554916828, 0.02281102254205654, 0.05337551371344636, 0.09529790570659023, 0.06639182252148468, 0.01363564492954362, 0.04004129756902976, 0.06762271897206384, 0.03998565277264964, 0.0234170172423605, 0.03387136332270119, 0.2806662702031674, 0.1338882365774724, 0.16752245355277293, 0.13857145463266682, 0.1297657489175758, 0.14850614412176996, 0.09119270099026543, 0.11855322477077285, 0.18534662292128612, 0.16280471557571044, 0.1571257977235702, 0.14873931064240395, 0.1254045559213527, 0.2474940195679665, 0.24450733386460813, 8.449314871141988, 62.57455195150068, 61.76328812876056, 40.785044316322576, 50.065089733369895, 63.02237287644417, 57.37626221872146, 64.9364463744625, 56.76317222656743, 67.68340772198093, 29.453069779180712, 0.2453452042273937, 2.4424317142655774, 6.94503148717265, 0.6386490755023495, 20.22634113988569, 60.347253661001886, 59.149436335409845, 60.463532324760195, 52.92241481042678, 50.12034808435748, 45.303159759890654, 45.75881365806826, 48.45056764541134, 53.85192240438154, 55.44142761538106, 55.354472591030984, 53.330580572928156, 52.70877507425124, 53.71152508643366, 57.092263006394916, 53.1938349816107, 52.811874574230565, 50.94017444118377, 49.568753011765025, 49.50234336237754, 49.15420947536346, 46.6317645965084, 45.39097378330846, 45.66752441467778, 44.89818288433937, 42.01371108331988, 41.311708804099794, 43.08709905993554, 41.769249362330285, 41.84457063674927, 43.125632424508375, 44.934476575543805, 43.3808728187315, 38.7244624476279, 40.75544218863211, 40.95675783772623, 44.98672646860923, 43.93373089451944, 45.754267631038545, 43.40468160567745, 43.11258269894508, 43.28849315643311, 42.49798651664488, 44.705374856149, 41.824460644875806, 46.647132442843535, 43.02676516194498, 43.55484954772457, 43.33358080156388, 41.825390246606645, 45.070692646888, 41.67259431654408, 43.8661680683013, 43.019536233717396, 46.91801132694368, 51.825512224628085, 55.36909126466321, 56.550022786663426, 56.8675111955212, 57.778685631290564, 57.69550784941643, 52.355671544228834, 54.008354371593846, 53.67770248843778, 54.311396691106985, 53.66563335541756, 47.46365224161456, 42.89886059299592, 42.82874038142543, 43.67767072493031, 42.36551238644508, 42.85149797316521, 43.31989565203267, 40.27556373227028, 43.143279167913626, 41.68391427686138, 43.56637739366101, 43.34599118078909, 41.21215904912641, 42.68526400289228, 44.61437586815127, 44.289701677137806, 40.20544352069978, 41.18023095592376, 42.394588916532456, 43.60250242294804, 42.35735777885684, 40.67819895282869, 47.68741169283467, 48.78680106132261, 49.17280150998024, 48.041452669328265, 47.56941110857072, 44.965851614552165, 46.85013471111175, 49.896400359369096, 54.312985251026774, 53.02037992785054, 54.05585427438059, 57.45172077609647, 54.937183395508804, 51.81483945538921, 53.96345500023135, 54.48856622942033, 58.10638789207705, 57.527755921886815, 56.7010340382976, 55.72481493796072, 53.95801075043217, 56.2897539138794, 52.89444046635782, 52.088817011925485, 43.917323620088645, 45.172713495069935, 49.88449596589612, 55.37617506519441, 59.35826724575412, 57.567348326406176, 44.36566229789488, 3.973360739408001, 1.0667622353761428, 21.22581401178914, 15.870184283102713, 6.984353248150119, 0.16488931742647003, 31.350939966017204, 68.7206942035306, 54.24964681748421, 52.046777048418605, 41.83456467043969, 37.383902226724935, 58.602701079460886, 33.691426092578524, 0.3136916464615253, 0.1055150747960133, 0.09194814795327765, 0.275361233901593, 0.2007205673162976, 0.20879295834850883, 0.2652664013927983, 0.10960369370877744, 0.15218428546382537, 0.1659568303054379, 0.11266194734602206, 0.10122703553567972], [0.06004013391512056, 0.012579625284659767, 0.02833845033760994, 0.04335845828116421, 0.030016119689530427, 0.057725985309169184, 0.0043387882760725915, 0.07824968381394302, 0.05735267066366731, 0.02645703798700725, 0.032375285537132335, 0.0452803009219708, 0.03940203933105354, 0.020078030685263298, 0.026391060579748406, 0.6268985737715999, 26.012137205370014, 54.03656405787314, 37.383419775193744, 27.322830538595877, 41.64826777673537, 37.92746820757466, 56.0170981960912, 52.89870016036495, 54.30757630255915, 37.72708216021138, 0.34030949396471827, 1.4425814368071095, 6.022019828519514, 0.1074855448678136, 6.569319905773287, 50.89785206702448, 56.47714907123197, 50.39058762211954, 49.5300627523853, 43.905258409438595, 42.77282307224889, 43.92783949452062, 49.97674618997882, 53.04626757098783, 54.76978840366487, 53.73354135021087, 49.78248688482469, 49.728475847551906, 52.56702453859391, 50.58423895989695, 50.0236891162011, 46.570634457372854, 44.1652331044597, 42.1434199425482, 38.565084780416186, 40.078770575984834, 40.735234137504335, 38.75161701633085, 38.48200505779636, 37.8406112424789, 37.10452356646138, 37.12380986059866, 36.58308759812386, 37.111630901213616, 36.83215025932559, 38.749130233641594, 37.57288986636747, 39.46995204494846, 39.7901233550041, 37.2128241292892, 39.42138525747484, 39.64157927420832, 38.76539630274619, 39.44873202231623, 41.10627074395457, 41.04492879682972, 40.21677132575743, 38.40962163863644, 39.925535340462964, 38.58017806083926, 38.13662075227307, 38.85193163348783, 38.97186202387656, 38.81816787104453, 37.49617615053731, 36.860218740278675, 36.70839555801884, 40.685796583852465, 42.253854274749756, 49.289743054297666, 52.186546787138916, 54.428510819711995, 57.038479466592115, 54.242904263158, 55.82662005578318, 52.72402917185138, 50.870105220425515, 49.64308584890058, 52.05647706985474, 53.043635660602206, 51.744327006801484, 46.21398902708485, 40.80883741378784, 38.327063591249534, 38.85708562789425, 40.60266979279057, 39.53151756717313, 38.52507660465856, 41.36096985109391, 39.04220973291705, 39.62250086569017, 39.14241060133904, 39.45985586412492, 38.11939370247626, 39.95978547680763, 39.69837911667363, 37.42106276173746, 40.00495549171202, 37.02606047353437, 38.68697243352091, 37.997047132061375, 38.819085705664854, 36.78176741446219, 38.50263280253257, 43.42428561179869, 43.89761370997275, 42.50687460745535, 43.700961759013516, 42.57676339918568, 39.3239692718752, 39.22867528853878, 43.37616205215455, 45.56319721283452, 47.94767272087836, 50.50896475392003, 50.59204055416969, 49.88332709958477, 48.39858055114747, 49.470309365180235, 49.16381928228563, 51.02867880175191, 50.35104620841242, 55.21272205537366, 55.23044724618235, 50.944375299638324, 50.58946355696648, 51.64191392160232, 46.735095516327895, 43.687876732118674, 44.3618772106786, 53.160718410245835, 53.45943435545891, 58.456902657785726, 32.03484442926223, 0.5319614648338288, 8.082033934131745, 10.147082401860146, 5.326618408003162, 4.545860328981954, 0.25145766655764273, 30.18337392037915, 55.09122271691599, 35.30891349238735, 35.084534306680005, 36.808357161860314, 38.78339998183712, 43.30958766321982, 11.702277660369875, 0.08285450809184583, 0.04313469165936113, 0.02895370321047883, 0.027938537119377046, 0.036587914932639375, 0.03880540239474466, 0.03634957731851647, 0.04751085018318507, 0.049308670849929896, 0.02026918494412976, 0.043429869167026014, 0.01251474625596236, 0.05110728058723673, 0.01262779976616824, 0.03831762655247604, 0.09709771437149856, 0.03880644427432168, 0.01403277820622128, 0.09243996107890722, 0.012872887572513954, 0.03415574665151296, 0.05666813279892649, 0.009004031514538633, 0.04132948973546586, 0.0235501365105231, 0.034090249964426604, 0.09275833955935894, 0.7444767065105901, 36.626794568953976, 58.35427776459725, 37.26164194845384, 30.79427326879194, 53.09818014021843, 50.27513265609742, 61.566255707894605, 58.504892856844016, 61.76288412463281, 37.001608417880156, 0.4891679772446233, 1.1233253873163656, 6.3339958363963715, 0.16442531329249183, 8.355047568198174, 54.89067585237565, 56.789899256921586, 54.53974923779888, 51.036919701483946, 45.869651994397564, 44.07412821246732, 44.60706457015007, 49.656076738911295, 53.40009673949211, 55.26569366455079, 54.09914939634262, 50.793709216579316, 52.483956583084606, 55.016176008409076, 53.77052537856564, 53.27116843192808, 47.98815942579701, 45.46081942896689, 43.80630485473141, 43.445395808066095, 42.90355567009219, 44.40343080028411, 40.520727557520715, 40.3437384482353, 39.99068590902513, 39.64217939684468, 38.937976667957926, 38.054596147229596, 38.90074945265247, 39.20880456124583, 39.858356906521706, 38.51134830905546, 41.32009090915803, 40.58424249772103, 38.94347975330968, 40.74278862245622, 40.4375615427571, 40.56828629586005, 41.58968717821183, 42.15246885053573, 43.496798469174294, 42.11412768210135, 40.85567443601547, 41.52334813148745, 40.18794974973125, 40.88570802442489, 40.9201935029799, 41.292791212758715, 39.985080842048895, 37.980271154834384, 39.10145321199971, 39.440789222717285, 42.208464607115715, 45.55432873387491, 48.5562833662956, 51.809340292407626, 56.78396863322104, 55.345643335773104, 55.7179743243802, 56.05072075320829, 53.67108544995708, 50.931235359561065, 51.3571733813132, 55.672859222658225, 52.952895549035844, 51.93113380862821, 48.1679138060539, 41.88844234712663, 40.192295735882176, 40.59477798400387, 41.87467875019197, 40.221995922826956, 40.57536617402108, 41.27935317254836, 40.832289265048125, 39.79548915739983, 41.6968894773914, 40.57658603114467, 41.115511848080544, 42.39007034609395, 40.841204812449796, 39.18105771464687, 40.213617740138886, 38.606701127944454, 40.497605185354914, 40.21972487049718, 40.2194816835465, 39.540303676359116, 40.698987514741965, 46.23852737488286, 46.47950603115944, 45.94785621089321, 44.738526728845414, 43.86002171424128, 40.413101642362534, 41.29587027334398, 44.18666493508124, 49.21266063567131, 50.78758247437016, 51.487576500062026, 52.43294223662346, 51.45020023469002, 49.44159761551888, 50.948780121341834, 50.937028700305575, 53.217177006506155, 52.35356915381647, 57.03896976286366, 54.85735139539165, 52.66183999276931, 54.62198957320183, 53.37150266093593, 47.308753921139626, 45.66701842892555, 47.0174708674031, 53.8185901026572, 55.28274028531967, 59.141677887209006, 33.56675747902163, 1.1862351793435313, 10.846099757379102, 10.453979430660125, 6.313160206041029, 1.03414454046757, 0.11759158524294054, 32.493126315455285, 60.84867769672025, 40.450591656469534, 42.86196285678495, 38.6890983581543, 41.26801360038019, 49.31070027812835, 14.344405820292813, 0.08092600431653761, 0.07685032462881458, 0.04618072236377386, 0.06733188135249, 0.11275835951129276, 0.08931427638256743, 0.07967288365527507, 0.07002303331729866, 0.03210155657612749, 0.018434921474826914, 0.028650363035980734, 0.017453775433222615, 0.10030573053706078, 0.1521784938391178, 0.10948976877355769, 0.21397045633244902, 0.08713770567649796, 0.0935382936750689, 0.15733245760202408, 0.19003915660563978, 0.12880446179018867, 0.16594284153994054, 0.11285091825430432, 0.24685484176922232, 0.06233415356086147, 0.09574861055420292, 0.15462369327583622, 1.0702515513666215, 41.8313757834896, 66.912552156756, 47.799560100801536, 37.871394003591234, 53.828913780950735, 50.70783284402663, 63.38120698928834, 61.60932333238664, 65.05056381225586, 45.98276138305665, 0.7784852493674524, 3.5100653286903136, 15.235089794281992, 0.3815550549376396, 9.461550154993612, 55.30803957293111, 60.655504888103856, 55.946342560552786, 55.80481952236545, 48.497785137545684, 47.436140737225934, 46.64660684524044, 53.446910227498705, 54.959788014811856, 58.582359667747255, 56.398274129436864, 52.409831631568174, 53.64315032958985, 55.92205524444581, 54.80674105305826, 55.07789842544064, 50.25192399178782, 48.14830979993267, 45.98221225123252, 44.32433228338919, 43.556002724555235, 48.88553104092998, 43.61297515130813, 43.43987703323365, 41.94850167920513, 41.32575088931669, 40.86596281297746, 39.78433001425959, 39.959083372546786, 40.611114655771566, 43.9840627485706, 39.82611502370527, 42.922214385001894, 42.416495353944846, 40.488568044477894, 41.87518865831437, 45.42700467571136, 42.994558580460094, 44.43557854621641, 43.04013259949223, 46.12155445160405, 43.2016989492601, 41.67093907633136, 43.86916868148312, 41.85640834992932, 41.680678321469216, 41.89218428827102, 43.76071514621858, 42.19737214426841, 39.551643248527284, 40.94570067621047, 41.237309286671305, 43.946435451507575, 48.08120589102469, 51.76371136019307, 55.87675186895556, 58.22234492148123, 57.44629221577799, 59.06148502903601, 56.13213346850488, 55.09163456578409, 54.42583184088431, 53.44843995186591, 58.33141819123299, 56.768200705128336, 54.97632864982852, 49.22417671449723, 43.341441231389204, 42.11355501605619, 42.4197744554089, 45.125162601470954, 42.69070825269146, 42.693195035380704, 44.534128096795854, 43.254297933270855, 42.09887750687138, 43.436358667189076, 42.506533361250355, 40.521009968173125, 44.67918126813827, 42.31142682413901, 39.896348984010764, 44.574202952846406, 41.0853684333063, 43.32870137306952, 42.530134262577185, 42.67575225522442, 40.892529026154556, 42.28768471748599, 49.035408727584354, 48.32685609017649, 47.75870469308669, 48.15944933122205, 46.725670060803814, 43.33945258971184, 43.40412855148316, 47.08177420400804, 51.03074589083272, 52.87330281349921, 53.22581406562559, 53.49177037515948, 51.47593098302042, 49.3775531553453, 51.28449186202019, 51.831646811577585, 52.733803718320786, 54.36629810640889, 57.32474973124843, 56.77614742709745, 56.92201252906554, 56.42218097563713, 56.515737348987216, 51.03433485954039, 48.272237085526996, 49.178994932482325, 58.174291964500185, 59.00508526832827, 61.56321587101106, 37.14918759561355, 2.7827159579723113, 15.671423077583315, 19.891005946743874, 15.91707229614258, 7.758387404103433, 0.4295441814728322, 36.0439185942373, 66.99901688483455, 47.529304873558786, 47.58470835224275, 49.361644021926395, 50.287515578731416, 57.25472757893225, 18.0381606471154, 0.16364805580627534, 0.13821283355355263, 0.21163503729528, 0.1528560832863854, 0.25279442869847824, 0.22339983422669674, 0.1327435480010125, 0.11916047968571225, 0.08272710767003798, 0.09298884009401645, 0.11831299491947699, 0.09519779333664526], [0.027981190979781172, 0.023488108286513917, 0.012714447183234077, 0.10881237084827117, 0.018499056440627864, 0.057474218173733646, 0.08984096183051025, 0.09135121990355755, 0.06597849510369763, 0.054692445668361844, 0.027593018058987877, 0.09175225927103912, 0.0603977820625709, 0.03072424731667965, 0.05591815187325401, 0.05820172207970774, 7.087718979004891, 52.31820506434287, 42.647660240050286, 39.70507460255777, 31.933241313503636, 30.289613277681415, 39.54510465745003, 47.89284583060972, 51.18829573354414, 47.10203324594806, 3.192986562367409, 0.5815889470038876, 6.332201352042537, 0.03858844246414881, 2.5109949900257975, 48.36208681906424, 57.05883264541627, 55.12759877789406, 50.665718355486476, 47.460522190217056, 44.53666194792717, 46.17246681644071, 51.02901612558673, 54.447781424368586, 49.85142646297332, 51.77515291398572, 49.421942618585405, 50.98425011481009, 53.40015165267452, 49.06979614688505, 49.13216967736521, 44.86354835571782, 42.56681626842868, 40.52839579120759, 37.6848578453064, 38.16179060166882, 37.58319001043997, 37.68218278884888, 39.08803086127005, 36.82059495679794, 35.81784102224535, 37.08660225714407, 35.8668275033274, 38.72556071127615, 39.14728610746322, 38.74727103017992, 39.301533314489554, 39.26210564951743, 39.30322777840399, 39.53964864054034, 37.82450991292154, 38.83572832230599, 38.69209897133612, 40.11241274495279, 40.32596226661436, 41.262106510900686, 39.824326422906694, 38.893587204717825, 39.45492936718849, 39.96989734711186, 38.326561527867476, 38.40307520281884, 38.776186743090236, 38.65283212354107, 37.34182303951633, 38.64975698532597, 38.30474922733922, 41.49271049807149, 48.90058117528116, 51.721416442624985, 49.90348808227047, 52.73827522031723, 54.4537159704393, 53.946631954562285, 57.43807092789681, 59.02828216552735, 50.89132916542792, 53.89813576975177, 53.154513220633234, 52.93127936701621, 51.56801254518571, 53.61596045955535, 42.83743235372728, 37.90716994193293, 37.17612643395701, 39.11058056739069, 39.36438537413074, 39.676562893775206, 38.38634629403391, 38.79848149514968, 39.43615690354378, 38.404973629982244, 38.827267769844305, 39.75152723250851, 39.84367547496673, 38.882035824560354, 38.83300227503623, 40.0197781285932, 37.57422347222605, 36.785407373982096, 38.47893776432161, 37.02094962519985, 38.34408275542721, 38.54923056017968, 41.3349723815918, 43.9065331797446, 41.48035110965852, 43.28190749691379, 38.647599681731194, 39.55185113414642, 38.122610046017556, 40.49045862690095, 40.92174676156814, 46.28481918765653, 49.72224712371827, 49.60033985876268, 50.771230113121774, 53.230046303041526, 49.1811090900052, 51.19708184273013, 48.69129919236707, 51.65459102199924, 43.785767324509166, 52.14960590485604, 55.25997484883955, 51.90252404059134, 51.691108288303504, 53.51255893707276, 48.23603753120669, 48.941883733195645, 49.7914691125193, 53.96115649131037, 50.17899144080378, 27.55747848941434, 5.202376352202508, 6.399095414146301, 8.994506674428141, 3.2501359860743246, 1.9523796102693005, 0.2615720496302651, 25.614187255982433, 60.414377181760734, 39.68075590748941, 30.909769419700872, 26.390187009688347, 31.455671171988214, 42.648993845908876, 4.164099472184335, 0.13220953875251357, 0.03260429603077712, 0.04980379730583199, 0.11951490260300138, 0.03427558195506854, 0.054055439728883006, 0.04041906701581132, 0.03901364807520182, 0.05652451046532201, 0.011924310801400533, 0.110704010472663, 0.03126839956929607, 0.06220413694879221, 0.02858338013832127, 0.01069413064303057, 0.0647519883369246, 0.028781557508233576, 0.06732564539678636, 0.044072973166382125, 0.04318061863042174, 0.07875797549082388, 0.08736862755951383, 0.030622800038526618, 0.03653920706241362, 0.0683404820700807, 0.08325910976817531, 0.10058398133203869, 0.13214172464945625, 11.768268596741462, 62.822728157043464, 44.34476390961678, 36.63241924778108, 44.0755049643978, 37.04189508192001, 47.71840233956614, 54.67424338863742, 57.129349016374164, 50.30989270056448, 2.7998108729239437, 1.1065594611629364, 6.787218845659687, 0.5317245291606073, 2.686366366763269, 50.82587657436248, 58.1561117787515, 57.71799871998449, 52.68952800381569, 48.33133151454311, 44.49300989027947, 49.955377117280044, 52.12064312350366, 55.16150766803373, 52.611414001834014, 53.857099933008996, 48.79635595506238, 51.54854189965033, 52.688712150819846, 51.38974866559429, 50.161666331752656, 46.37390405901017, 44.53072740185646, 42.1558734678453, 40.340325986185384, 41.981637862420854, 40.48639897377261, 39.943182083868216, 39.692130780989125, 39.9156548899989, 36.73613063750729, 39.438400499282345, 37.175134074303415, 39.5447555665047, 40.405358883642386, 41.503340121238466, 40.7775172879619, 40.58244212981194, 41.31194414631013, 40.84016538435414, 39.794532099077784, 39.99218817680113, 40.4904664716413, 42.15024094427786, 42.75364660447644, 43.281323063758116, 42.06825164056594, 40.55054541557066, 40.488313090416696, 40.9605154683513, 39.72953450295233, 41.47771527690273, 41.070439892430464, 40.27664630643783, 39.83262615819132, 40.30831552320912, 40.03702871261105, 43.92265412115282, 50.73445789275631, 53.28100573632025, 52.99561800495271, 55.49377949007096, 54.99630528111612, 54.597431613552956, 57.655617344763975, 57.046998854606386, 52.913581632798724, 56.339826891499186, 53.72246065447408, 57.04181740360876, 53.99453193910661, 54.16277416290776, 45.00925656287901, 41.182560843806115, 38.78543961432673, 40.812928445877574, 39.63224795556838, 42.69649767106579, 39.466818071180775, 39.63922585210493, 39.83454419720558, 40.87205425385506, 40.7730967767777, 42.377491304951334, 41.39438452259187, 42.57852846576322, 39.506022161053075, 40.86165997289842, 39.29569682767315, 38.72183445961245, 41.47707593056464, 38.55153299147083, 39.810382396944114, 40.07839795081846, 43.20656268827377, 46.32659635236187, 45.121506952470355, 45.48852312949396, 41.751579084704005, 43.09902306525938, 39.89876908640708, 43.245437299051595, 42.84895235492338, 49.151628555790076, 50.52827065990817, 51.84258630198818, 52.22000852707894, 52.64482082859163, 51.226307422884055, 52.30256265209567, 50.26247516755135, 53.26846591887936, 47.05972263889928, 54.61004595602713, 57.34907234868696, 52.88658395890267, 54.17208194732667, 54.768815655862134, 52.42182231718495, 50.13663768768311, 53.09062173289638, 57.513149015365116, 53.004376657547496, 29.64395780717173, 8.70701753324078, 10.669462680816652, 13.930873274803163, 6.719026969325158, 1.2888692655870992, 0.1689563403206487, 29.467606083039318, 61.64071013850551, 45.155455066311745, 40.57593491769607, 29.416325015406457, 38.082370450419766, 49.529160607245664, 5.694491132613152, 0.23460603048724515, 0.036588481837703336, 0.05578202187954899, 0.06829683804103444, 0.07204624854268567, 0.020051577669237892, 0.0290256446122282, 0.039484592965774, 0.03226007357419979, 0.023699619416748325, 0.03593493605993929, 0.07631775562561328, 0.18256982998742213, 0.14713256379529355, 0.160689577460289, 0.20900658962707366, 0.11239364037230132, 0.13960918201313866, 0.13233608115584622, 0.12675808006597142, 0.18530887010837757, 0.13965070397863466, 0.16678123284251462, 0.18037733231340686, 0.1935005257086408, 0.20623327473238592, 0.299374780827953, 0.2739318364089535, 13.854640049319114, 69.71217524620795, 52.69234818796958, 52.824477149594216, 40.87108935079267, 43.47289946771438, 52.97361743065619, 59.018668436235004, 61.42537201604536, 56.291354240909705, 3.879575642847246, 2.1753031063464383, 21.24775378934799, 0.8653856056832498, 3.7863970427743854, 54.7581232747724, 59.544540605237415, 64.53732167520832, 55.8223250604445, 51.687774273657034, 46.860179901123054, 50.36032653624012, 55.462777076228974, 57.80263170119255, 53.930424721010276, 55.25379711581815, 50.89791874731741, 51.51110679872575, 56.64079427719117, 53.19615310238254, 53.56096490736931, 49.40329959315639, 47.861568850855676, 44.18575494520126, 41.515734810982984, 43.57873678207398, 43.28627701728575, 41.77478382664342, 42.878923185410045, 41.66745993398851, 37.708301851826334, 41.44818767424553, 38.6584097339261, 42.15756793175974, 42.87480469672911, 42.67084929250902, 42.89733871336907, 43.29618100197085, 43.55208427675309, 43.21032031889885, 40.77583851352815, 42.845410454657774, 42.3388167350523, 43.26400579944734, 45.99248886108399, 45.79442093449254, 43.76933259348716, 41.86041308987526, 42.29456063239805, 43.74215841293336, 41.22192967322565, 42.58762444219282, 42.441975070584206, 43.83497345832087, 41.00408515622539, 43.45228741245885, 43.6702182216029, 46.643747437384825, 53.19328977215675, 53.91509217600669, 54.03266522192187, 57.303329667737415, 55.47748988674533, 56.30318803171958, 58.96144497779108, 59.94472434443813, 54.541788870288485, 59.608294810018236, 55.3049095215336, 59.12959698707827, 54.61714544603902, 55.9707240135439, 46.74306969488821, 43.695439061810895, 40.92192719059606, 43.2696500901253, 43.0168023417073, 44.204856887940444, 38.409233323989376, 41.878122591203265, 41.57815148753505, 42.74759830967073, 41.01290264437276, 45.60713952587497, 43.16396574820242, 43.67967505608836, 39.90680210051998, 43.354581171466464, 41.691645268471014, 41.28071031262798, 44.21025799166772, 41.30248338945451, 42.39869563810287, 41.98740374657416, 45.44873852883616, 48.44071072916831, 45.698711179917865, 47.76595323316513, 42.748763253611905, 44.81029433588828, 41.987678312486224, 46.263559941322576, 45.02385562466037, 50.78082423056326, 53.09962357244184, 53.59945904824042, 54.56594282580961, 57.37770957331504, 52.867478093793316, 54.40565124634774, 50.94567360416536, 55.3777204790423, 48.92363294478386, 53.66300144503194, 58.18549817608249, 56.56016995829921, 56.59738932886432, 56.69495436453051, 54.3591280137339, 53.95507289517311, 54.394637230903875, 60.11817155345794, 52.32920731267622, 35.527636620306204, 11.385648250579836, 16.671644141597135, 21.412771824867498, 13.873051654907966, 6.9443656648359, 0.3001694897970846, 34.827650439354684, 68.34667267337923, 51.5502755872665, 41.0454700839135, 36.04546793045537, 44.104110810064505, 59.83564715231619, 7.667670826758108, 0.2612617227338976, 0.18563268015221243, 0.15327726310539633, 0.17860397666452393, 0.20281304455091878, 0.2512857411056757, 0.09542372798727405, 0.16877444040390754, 0.13357505983402654, 0.15980263150507407, 0.16770112057847364, 0.16465880157005403], [0.05122036665617939, 0.07993700778892926, 0.04841829282081416, 0.04568923099507247, 0.02963448149873124, 0.018083735279017882, 0.055579112001484444, 0.05285853076906455, 0.003431638667074543, 0.07658721173122045, 0.024016126727444992, 0.046515050794809096, 0.00852948122267281, 0.10340031206367478, 0.06684651868718286, 0.1357920416781018, 0.5667980568062875, 25.394367825600412, 52.50824782156175, 27.303230454844815, 24.758508474596088, 39.408947421658425, 39.64146944784349, 51.220498392658854, 49.19019722169446, 52.762719431231105, 5.105275627105467, 0.7483685557400027, 3.8392803986226363, 4.579096532637074, 0.7909740759961067, 34.660600616085915, 57.15232233847342, 52.7858574928776, 53.318405535913286, 51.585918165022335, 50.704086980512066, 51.52348187661941, 49.854364318232385, 52.81710309367026, 50.80125977916103, 48.0488855608048, 47.972030639648445, 50.25587381855134, 51.770316631563254, 50.764205148143155, 46.62118204178349, 42.72903765401533, 40.029380090775035, 39.73229977392381, 37.43288870780699, 35.7310664269232, 37.47766648569415, 38.80454940180625, 36.73504021859939, 37.463365524045884, 36.95856824997933, 35.787266146752145, 37.85068781145158, 38.14567358263078, 37.13670661372524, 36.37586093718006, 40.0800924147329, 39.19832791051557, 37.42234145441363, 37.4948739236401, 38.088630553214784, 39.36436576227988, 38.80349036185972, 38.435760313464755, 37.07767494263188, 38.65550325762841, 39.90906923047958, 38.97197577261156, 37.630889954105506, 39.30211774764523, 38.93477993626749, 38.67479739650604, 37.919866654180716, 41.577045379146455, 38.38865657006541, 38.85248076531195, 36.51679954221172, 44.52472225312264, 52.216458782073, 55.02959835913874, 50.413933569385165, 65.71899844754127, 68.33293653303578, 43.19575263607887, 55.48472665971326, 59.26030605070053, 53.13016706897367, 54.65035615428802, 56.51464693007931, 54.802116578625096, 52.65088089050786, 53.4401951297637, 48.333406448364265, 38.26886346263271, 35.915896354183076, 38.33832471601425, 37.78252878496724, 40.211464358914284, 40.14649029700987, 40.593467912366314, 39.8223848496714, 39.19677857429751, 38.69602918624878, 40.54466578268236, 38.780964189960116, 37.73157719642886, 38.002456080529, 38.450559416124904, 40.33086915169993, 38.554533604652654, 40.072067245360344, 39.2503228495198, 37.05441136513987, 38.35750902852705, 39.23481379785846, 41.92452423034176, 40.84808072736187, 42.03288362872216, 40.72137640368554, 38.99795755263298, 38.18132792749713, 35.94318820584205, 37.37818733338387, 40.39627859669347, 43.831411946204405, 49.029705601353804, 48.59518543366463, 46.204998954649895, 46.89051158966557, 49.38631573031026, 50.15764197995586, 51.09631223063315, 51.15809348321731, 44.55683077535322, 48.743776582902484, 56.2011867953885, 55.151262437143636, 50.72550704402309, 50.561089131139944, 52.6607927199333, 49.116723383626635, 53.47410401990337, 43.92341113859608, 28.178874100408247, 7.824490618321204, 0.6239501771426971, 11.22709624228939, 2.636613552608798, 0.693069265013741, 0.21870262740600496, 30.526467561721805, 56.9205298731404, 36.75216920914189, 31.152399393819998, 26.348311785728704, 43.03459029043875, 23.953987206182173, 0.6518439900490546, 0.15528936239500202, 0.01873153731256964, 0.02825650765800909, 0.08328916339744484, 0.07462054911640383, 0.05112766235646221, 0.04006804552890601, 0.07148657534872332, 0.04876023233537713, 0.044055307178848216, 0.04094419730526786, 0.07374298007738206, 0.054939436245589494, 0.055242217175902865, 0.08134278679086317, 0.01597771169467559, 0.02719674758883494, 0.07375814861828282, 0.023838695018522205, 0.028587672145917054, 0.014572890302647027, 0.03333872154114708, 0.04866574305079637, 0.0221179083230034, 0.054499245954737555, 0.1214614860533226, 0.06058540082566681, 0.014913657702685846, 1.0371631720373709, 34.644891523545795, 55.64160185475504, 33.135688997084095, 28.00725667707382, 43.72681802318942, 43.40770575308031, 55.083550560858946, 53.685343265533454, 56.815786900058875, 5.790214615483438, 0.7576122339214049, 4.698455727869465, 4.515431561777669, 1.0132466424857418, 39.42835138690087, 57.522656840662805, 55.38266266545942, 55.7694907342234, 54.44283139321112, 51.03808464542512, 53.66603343717514, 51.360730971059496, 55.776888324368386, 52.54190960238057, 49.565497444522, 49.1718719082494, 52.16023945039319, 53.12910410665697, 51.70944536885908, 47.42234968370008, 45.712368872857866, 41.93211009425502, 41.19797968095349, 38.641963235793575, 39.542315852257516, 38.45940828323364, 40.84831214720204, 40.48031537763534, 39.61017677860875, 40.054487182248025, 40.06435586560158, 38.99572180163476, 39.13415008975614, 38.318705020412324, 38.33310011894473, 41.16303136271816, 39.639037578336655, 40.032133594636, 39.72221536021079, 39.50369227317072, 39.885993926755845, 40.00979961887483, 40.00255892353673, 41.03564454663185, 39.83579935566072, 41.64196452786846, 39.642402971944506, 39.153130439019975, 40.55603281144173, 41.03552687552668, 38.96127554678148, 40.03332207279821, 41.218019070163855, 39.87414836883545, 40.21494350125713, 38.66361079677459, 47.36267866626863, 53.491299690738806, 55.85972093766736, 53.89339362421344, 61.29606323857462, 60.93729188365322, 47.210471091731904, 57.98765774696105, 58.92494340096751, 52.83674632349322, 55.84698107934768, 56.014219176384714, 57.13633083528089, 53.86734516389909, 54.44313733808456, 50.31001037166965, 40.157998531095444, 37.11746346565985, 40.4799113735076, 39.61121228433425, 40.92077793613557, 40.00424162034066, 41.427250062265706, 40.651032617015225, 39.43885549422234, 40.60370922088623, 41.47878216158959, 40.74422813230946, 39.5987509142968, 38.66801954084827, 40.993137821074455, 41.92246890837147, 40.38420161893291, 40.97526358019921, 40.71497509556432, 39.55393783507809, 39.266051553910785, 41.154763006394916, 44.14244413375855, 43.28388044911046, 43.449832008730986, 41.38423735095609, 40.61179714818155, 39.856144689744525, 38.099397459337794, 40.84236191165063, 42.19176315492199, 45.027432826257524, 49.62392899297899, 49.681799642501346, 49.785722840216856, 48.7192343127343, 51.21526987321916, 52.348215118531265, 53.79255733182354, 51.2338383736149, 47.02488806939895, 51.3513368944968, 57.46875170738467, 56.62246504137593, 54.941745112019206, 51.84282948893886, 55.04975934182444, 51.89212191489435, 55.43886238528837, 46.62573199118338, 33.95262064472322, 8.190515416283763, 2.44385774097135, 12.180789170726655, 6.882337793227165, 0.2689415396701905, 0.07527003079772958, 36.18468461498138, 60.159936951052764, 45.52227904719692, 34.52718511704476, 28.93056888734141, 46.76240697983773, 33.27052047175746, 0.817500084878937, 0.05103651704567094, 0.01747681552754535, 0.023995674095086517, 0.082481415611842, 0.06376349742734624, 0.02188781189972595, 0.04320725933798859, 0.04760189973298581, 0.024470794164846023, 0.0318524994767241, 0.034359997183445005, 0.13084276128680478, 0.12285444074340406, 0.16486130925195833, 0.22520751061458744, 0.1734135317946634, 0.122570222123496, 0.1396080788465277, 0.13939487657720043, 0.20887733527248908, 0.09523851857070001, 0.1693982964441661, 0.18804714414140872, 0.2098163905283136, 0.11287088250561107, 0.2275847274089052, 0.26308997624343444, 0.2766896610058123, 1.3051488178391613, 42.46024154847668, 65.64817220933976, 39.36643677373087, 34.84400280060307, 51.58303522294568, 53.998407240836855, 64.42672260345952, 57.116495409319484, 62.49739500784106, 6.9746620520468685, 1.2360338361993914, 9.537596087301932, 6.897747314745381, 1.7555770157806336, 42.64124324244838, 58.578990351769235, 58.09824112922915, 56.67853532298919, 57.98830101566931, 54.94550274264429, 54.94831508205783, 53.58849994597897, 58.58379133286015, 53.050389982038936, 48.8941288763477, 51.78848505020142, 53.828148918767134, 53.88294835244456, 54.74113156718593, 49.53979807515299, 46.85539460951283, 43.749759966327304, 44.6809345676053, 41.143639164586226, 40.44472771306192, 41.94711316016413, 44.110990647346746, 41.556056776354396, 42.12052114548222, 43.1462719363551, 41.323244494776574, 42.039186877589074, 41.06558007578696, 40.49988016005486, 40.509901815845126, 43.14829587936402, 41.48789382749989, 41.3335838625508, 41.47334967890094, 40.90304097821636, 42.493977854328776, 41.9544558371267, 41.28030238613006, 43.043709801089385, 42.47323636085757, 43.828807492409986, 42.01088305442564, 42.33318028911468, 43.309815160689816, 42.55858321343699, 40.8464607884807, 41.73998063610446, 45.02242788191765, 42.75303471472956, 41.567078636538604, 41.478221262654955, 47.95292869690926, 55.928695817147535, 57.40569568449452, 56.86434584279215, 62.731748780896595, 63.112826654987956, 46.68921163005214, 60.05543324255175, 59.8060332575152, 53.806928896134906, 59.47329859579764, 58.14839647662256, 58.71811682178129, 55.30106167639456, 56.93446605436264, 52.1845934467931, 41.60129347155171, 39.74988375940631, 44.14247159034976, 41.71183370774792, 42.55300560305196, 43.857397648596, 43.053625552884995, 43.876676097992934, 40.644541094380045, 43.26449217334871, 44.765179234166304, 43.715368624656435, 41.05174195381903, 40.8390082851533, 40.72052132698798, 44.8566645960654, 43.17175557536464, 43.65317944557437, 43.33576556174986, 40.713323777721776, 42.05690030128726, 43.512272219504084, 46.47893336511428, 43.72111881932905, 46.633659101301625, 43.89217730491392, 41.7466212088062, 41.03797835688437, 40.18052078062489, 42.43669556033227, 43.523768686479144, 47.07860100653864, 52.311882203625096, 53.79492252103744, 51.56758108446675, 50.473494760451786, 54.66725764736053, 54.97737592266452, 56.29096592626264, 53.60001602480489, 49.1359116185096, 52.28843035236482, 54.9491701587554, 58.674923681443744, 57.23263679012176, 53.86394446895969, 57.916674613952644, 54.871609210968025, 56.06837141898371, 49.267028608629786, 37.80384686685378, 9.263979388821511, 3.2897161331868943, 21.26430226910499, 13.825827298625825, 1.625337778560577, 0.27200745418667793, 39.72216436939855, 66.9747531029486, 46.5063742668398, 41.346170748433764, 38.85282985625729, 54.69727946865944, 41.19075467509609, 1.3872322584352186, 0.19897169583747465, 0.09104023417157513, 0.09956871564950674, 0.16002162539910886, 0.24001563779048382, 0.15060257437008043, 0.10960296592524937, 0.13287412002682686, 0.1809480984605128, 0.16100902080295548, 0.2062194391844734, 0.3411725992637296], [0.087694781832397, 0.05015936169412829, 0.053104728445290565, 0.01854020302304097, 0.040143256210872245, 0.04835487606244222, 0.04720158814903229, 0.037466319007498604, 0.013449992139583394, 0.04678489377481803, 0.08660712084102054, 0.11033757529672115, 0.05212546506476018, 0.02329704787341818, 0.02137534695887758, 0.1698306611468715, 0.06577892919942256, 10.942135068678088, 48.616056365351525, 40.907222224820046, 28.13561624096286, 22.17574146486098, 46.40702847511538, 54.099922103266564, 52.9580730776633, 51.635304727861964, 12.387850111530675, 0.40300220731765996, 1.4751063431462934, 11.572269720415916, 12.154296501990288, 31.06305172366481, 50.71076677691553, 56.13289440831831, 53.01376681174002, 54.285297239980395, 51.48521915558846, 51.39376125028057, 53.490876074760195, 53.883575931672134, 52.814600621500325, 50.157151683684326, 49.96045266428302, 50.57123630277572, 49.94935627906553, 46.34962851001371, 42.72170674416327, 42.593119682804236, 39.80274161984844, 38.2692321654289, 37.72234393704323, 38.652800744579686, 37.366643797966745, 37.3652042881135, 38.842882725500296, 36.90260387236072, 36.63130137228197, 37.405867499689904, 37.646171508296845, 37.51364246491463, 40.091604571188654, 37.73612714582874, 38.08909731526529, 40.531600367638376, 39.87140270971483, 39.06453586393787, 38.84118433921568, 37.53248945359261, 38.61583632807578, 40.01813073312083, 38.489249675504624, 40.59387976123441, 36.89963071577011, 39.846640786817, 37.37898357452885, 40.08694479542394, 36.99301450483261, 38.111309697551114, 37.94671527801022, 39.433658353744015, 39.053953309212964, 38.99355273092947, 39.05184307406026, 46.30461146754604, 54.191215269027225, 54.90378441349153, 52.83053328914028, 54.95630102772867, 66.60641116480674, 47.39216312285393, 43.2034561710973, 52.3672660704582, 62.27991919363699, 52.4592613404797, 55.24384998506116, 52.3978409459514, 51.20881365191553, 50.35792996806484, 48.32616575302617, 40.0681919436301, 37.77865740560716, 36.09436811939363, 37.52249525439355, 41.46347315080705, 38.57595366816367, 39.334814625401656, 38.02714740076373, 37.74551337765109, 38.396183598426084, 38.90973168034708, 38.725486186242875, 38.22212449965939, 37.29979876549014, 38.55254104060512, 38.86422826397804, 36.90220771297332, 38.42220067977905, 37.39586937812067, 38.22297173161661, 37.34913041514736, 35.529185956524266, 39.39389728730725, 39.8353482830909, 39.989481741382235, 37.43871734988305, 37.58258596543343, 35.724586671398534, 36.96161200923305, 36.127802402742454, 36.10619014309299, 38.17983350446148, 39.73315877299155, 41.176108544872655, 44.68937943058629, 43.520473895534394, 45.83663348228701, 48.855862232946585, 47.89304979385869, 50.03180057771745, 51.54015979459209, 44.009781729790475, 44.51188041317848, 52.95169138139295, 55.316476591171764, 54.65785572605749, 51.58325095330515, 52.000336185578384, 51.603619821609996, 39.62406589138893, 5.285567862372245, 2.1727091939218584, 5.910731400212934, 4.8439609523742435, 6.0377779506867935, 0.43058468209158995, 0.22494949220168978, 36.133489839492306, 51.570820962229085, 31.903307745533606, 36.374939180189564, 27.706355971674768, 44.9546101016383, 13.305707285481116, 0.005529299444113408, 0.015149562987649154, 0.06016704404065686, 0.011036697392081542, 0.07071600581008582, 0.07955430856635494, 0.05302314008135469, 0.03166983730249828, 0.06734773171164336, 0.12761399946025304, 0.03340131092456079, 0.04071508722019292, 0.0220342745043097, 0.08970949348182448, 0.04175926123054759, 0.03284271791457169, 0.03214012335745558, 0.03724257919877287, 0.02957149183437709, 0.042300379774983854, 0.02101496004709794, 0.0892746466542444, 0.03455636850107582, 0.015405094487622622, 0.0811202765532559, 0.05444986009669881, 0.057908260608993234, 0.08216097635487396, 0.07219879963104764, 0.07697442321166878, 16.54690100300697, 57.26135246215328, 38.94709617860856, 28.576680883284542, 33.92818035617952, 52.47619813488376, 57.410975194746456, 55.835719954582956, 56.376661869787405, 11.909919111959397, 0.45346092552908007, 2.636220580147159, 13.116658849100913, 10.655127398429379, 35.0477110955023, 54.46149795286117, 58.57126720489995, 55.70962359828334, 56.39391245380525, 54.601640316747854, 54.5173603488553, 55.389734698880105, 55.12928539706815, 52.74882639608076, 50.1925471521193, 52.13315940672352, 52.42989847736975, 50.330034071399325, 48.88374244013141, 45.78076324155254, 45.27788400650025, 43.85619740332327, 40.46331582530853, 38.86403606783959, 41.34645315908617, 41.58510977222074, 39.662979725868475, 40.963166990587794, 39.7517547299785, 38.830691999004735, 38.634734307566, 41.55215401803294, 39.94227993872858, 40.09325196666103, 39.63701363532774, 41.1375359565981, 41.60024619871571, 41.35603943178731, 39.98031123991936, 41.50705460579165, 38.54267235725157, 39.653617028267156, 42.09955999928136, 40.30840966009325, 42.166726666112105, 39.15628010226835, 40.471074273509366, 39.98798339597641, 40.97232572494015, 40.12680392111502, 39.70294083318403, 40.84873184081047, 39.72267035515078, 40.71131160182338, 39.55154911164315, 41.14479626378706, 46.12653978409306, 59.25170821528281, 57.34958225680936, 54.551151567889804, 57.27458261674451, 63.74250827297088, 48.45459199720814, 45.262586762828214, 55.726074018786036, 59.02636020414291, 54.92469849125032, 57.61189860682334, 53.32784668091805, 53.304073195303644, 52.67207345654888, 50.73324980274324, 42.33255270988711, 38.64133565656601, 37.01987489577263, 38.63025496082921, 42.20936675225535, 38.98445675449987, 42.54599240518386, 39.376411361079064, 39.16409738602177, 40.31445795489896, 41.18460439866589, 39.97037979864305, 39.73435509589411, 37.68355954077936, 39.215013673228604, 40.43501592451527, 38.783980492622625, 39.07248258590698, 38.59857397694742, 40.04290834549935, 40.38355442785448, 38.22483093507829, 41.15582596871161, 41.699576300959436, 41.398797189035726, 39.87993778720979, 40.21580250032487, 37.94505611542733, 37.65903296009187, 37.41610880820982, 37.98175773312969, 39.619817964492306, 41.70916257366058, 44.33383618631671, 46.21867625944076, 46.70262613604146, 47.95540371248799, 49.92986994404947, 51.50491729859383, 52.09169603163197, 51.60888756475141, 46.580240341924856, 46.36265862372614, 53.184570343263694, 56.53177984299199, 55.792930818373165, 53.420563667051255, 55.36333714762042, 53.93428825563001, 43.43344826852122, 7.903400371151586, 5.555537246888684, 15.137712051791532, 10.903645830769694, 5.614612064053936, 0.23735340564481675, 0.352086563624682, 40.71501431926605, 55.97547792619275, 36.72006068691131, 36.53999251704062, 29.204028691014937, 51.3405542988931, 17.54663863489705, 0.02966064723178504, 0.026707437655497945, 0.058742273719080036, 0.007910558788646615, 0.02051356699197523, 0.13739181712510126, 0.047412576424258376, 0.03889774663313743, 0.04953739406060308, 0.07670295995569999, 0.017528371329629616, 0.031149182881739353, 0.05008520821349756, 0.17383923153242758, 0.1415108114240631, 0.15218650711880577, 0.09761270165683762, 0.14558603145903157, 0.21047853564302768, 0.20267386169683552, 0.1416479411625093, 0.17379334286576317, 0.16995398598092218, 0.2164230102132405, 0.2339256065146577, 0.12952106043456063, 0.12964026371557869, 0.21155082891064309, 0.2512288667381771, 0.17370300577773204, 19.141595940436087, 64.95245356713572, 50.134245041877996, 40.52535203195388, 32.81728079242091, 55.88219219638456, 63.07914918468845, 61.97062461606918, 61.953464246565304, 15.525474625249064, 0.6980991531764308, 9.461772749500891, 16.067252005300215, 15.16311332102745, 40.49133331544938, 52.55471221862301, 60.582960651766875, 56.64288097812284, 59.56404262973417, 56.90599749165197, 57.012627124786384, 56.592843301834606, 56.08651630340084, 51.17814856190836, 52.13989803867956, 55.61478853225709, 53.24259004285259, 53.60136139777399, 50.875169000317975, 48.08474779129029, 48.502970510913485, 46.918838947050034, 42.83147427343553, 42.23006117728449, 44.686449420067575, 42.67954518718105, 42.485172133291925, 43.2817506021069, 41.903900407975726, 40.94804233120334, 40.635127405966486, 42.035794027390025, 42.313223269677934, 43.689108356352776, 40.65924998252623, 43.25512555337722, 43.15368129361061, 42.44483447843983, 43.2423621608365, 44.87680988927042, 39.099558707206484, 41.58667479791949, 44.98612634597286, 43.270469865491314, 45.06555826433244, 40.12956526971633, 42.55462554193313, 43.7068021682001, 43.44483098676128, 40.537378018902196, 42.36432783065304, 43.4796537891511, 41.75785095460954, 44.25851491189773, 41.84240941078433, 42.001991041245006, 48.862761682079686, 59.37088158822829, 59.28784108931019, 54.31225176780455, 61.71094017644083, 67.29352412685272, 46.88726386716289, 46.20051176317277, 55.280037772270944, 58.22061907860541, 56.03964397984167, 60.10842446357974, 55.74512889308315, 55.81169151490735, 55.03412085194742, 51.422829935627604, 45.83403687323294, 42.953856145181966, 40.20860495105867, 39.93427438120688, 44.99458689843455, 42.63363776668426, 44.19647086051203, 40.746824741363525, 41.57933212095692, 41.16527495845672, 43.346948239111136, 41.93521661143149, 41.351285519138465, 39.70931076234387, 42.637387552568995, 41.59343304172639, 40.65540998212753, 41.900817425020286, 41.18553400039673, 42.54441953474476, 43.34380249823294, 39.29648130170761, 43.276380877341, 45.35553516880159, 43.21674516124111, 41.83716520186394, 42.4110746383667, 39.97669089225031, 40.25445745837304, 40.34015732426798, 39.514274827895626, 41.33419182992751, 44.366431082448656, 44.27902890789894, 48.80434582310338, 48.12453631431826, 51.82482188747775, 52.96380758285523, 53.34397546706661, 55.438831006326986, 54.741841516187115, 50.31902005595546, 47.105633981766246, 52.27416861441828, 56.45256757736207, 60.12938953215077, 54.647849759747906, 56.0490615906254, 53.980485931519546, 47.434850277439246, 8.70686161902643, 4.397866850899113, 16.39785485882913, 18.606884710250363, 15.74361724238242, 1.5669631044710837, 0.7314174201699996, 46.89615195797336, 60.83015626476657, 41.15561808309248, 47.81010343182472, 38.198609890476355, 60.52951835816907, 25.9849924425925, 0.16450376069593817, 0.0844800930410143, 0.10805107863439668, 0.2543386780927258, 0.21315662580872738, 0.25840969996586927, 0.18964072959797998, 0.1288395486171207, 0.12806490349072602, 0.3160113606962466, 0.18014885425086946, 0.14934502572061556, 0.15227534267450535], [0.03930853446945548, 0.046674776296581955, 0.03930047522449205, 0.037296772258536476, 0.063041367628161, 0.08245511581340144, 0.039472745416025, 0.021041817174503402, 0.06656964685046865, 0.005376332274247562, 0.008049647796959167, 0.010345086620579804, 0.05221394822001458, 0.02039586524328878, 0.014797570484299815, 0.04405829492175291, 0.061576527077704675, 2.8764870810893277, 37.34096011807842, 44.15152834307763, 21.457257386176817, 30.60326364732558, 41.30622925296907, 50.853556740668516, 52.95863005422777, 56.151584502189394, 20.978202627551173, 0.07294598816623611, 1.5778283149965349, 2.999041782271478, 15.06346844857739, 21.590398319305915, 32.01185345649719, 58.67120135215021, 56.83358661590084, 55.9574624799913, 53.19428997655069, 56.15032542136408, 52.334933973127804, 48.8502924673019, 53.11437168428975, 49.20216829546037, 49.54180240631104, 51.347092889970355, 49.27115494205106, 47.027778856215946, 42.901904352249645, 40.59584094632057, 38.42619757498465, 37.97874143046718, 37.33116988212832, 38.3656479466346, 39.08162563077865, 37.481565321645434, 38.28920879671651, 38.911504591664965, 36.73250636746807, 38.44434638177195, 39.40973581806306, 39.07726395514704, 41.231217845793694, 37.45914505374047, 38.90128289499591, 38.84727578009329, 39.15194980559811, 37.840462192412346, 40.1332248410871, 37.25762936376756, 40.2694958256137, 38.02162078119094, 40.53000004060807, 38.028069157754224, 38.306153435860914, 38.519820628627656, 38.199684619903564, 38.24075183560772, 40.336866455693404, 36.144809799809615, 38.25940270577708, 37.639789812026486, 38.63615812793855, 37.180248845008116, 39.66801604916973, 42.49586451438166, 54.66812449116861, 51.84962303407731, 56.42906473528955, 41.745177776582786, 31.57289904932822, 48.399784718790364, 45.289345172143754, 38.71844945415374, 59.714430224510934, 59.63881084995886, 51.925995503702474, 55.75924942570349, 49.27637953912058, 49.565709252511304, 46.869075836673865, 43.73212499003257, 36.27224368433799, 36.69362783432007, 37.579012686206454, 39.79456347803916, 36.391283696697606, 37.780473462996945, 37.83868928109446, 40.02890548398418, 38.8876683481278, 39.30615386655254, 37.54487629859678, 39.76462402651387, 37.5691165462617, 38.63866844484883, 37.75648032465289, 36.72004107506045, 35.775448045422955, 37.95177905790268, 39.74088191986084, 38.83870932363695, 37.71354606074672, 38.14424191751788, 38.99904012680054, 39.3018235698823, 37.958380406902684, 36.916037990200905, 34.767728390232215, 38.06255463630923, 37.967884309830204, 34.569319217435776, 35.103200866330056, 36.32718824571179, 35.15262273050124, 35.42023035787767, 36.278076248784224, 39.00309193518854, 38.61918603220294, 43.56041931336926, 44.70932860528269, 47.44265187171198, 49.98472821327948, 50.93591474717664, 45.05952958137759, 48.51108981717018, 55.219417541257805, 54.95197465342861, 51.50281490818147, 48.40100065354378, 16.26912266977372, 3.4837327416866057, 5.326139878842139, 7.338637901890663, 9.322388383650011, 4.586760843953779, 0.2551433155613561, 0.9575507633628385, 45.65659669137771, 45.41830093629899, 31.283377139799057, 32.04618007906022, 38.09283141166934, 50.18320798873902, 6.21742299487514, 0.31662845984101295, 0.021429187618196014, 0.040983348228638215, 0.0706550098895546, 0.0688786511760085, 0.014601834062036249, 0.048097485841642466, 0.0576078124164093, 0.10181606521890049, 0.03585067404914768, 0.06738284152121314, 0.02440078138944603, 0.028609689512860872, 0.031949022724743814, 0.023800028645763957, 0.022487551492128163, 0.022984999194440824, 0.025742073025133823, 0.033801714439065225, 0.017596627848463196, 0.020923998597408497, 0.10219267404247677, 0.03343224172450362, 0.04428180107366174, 0.06317160640572829, 0.06335162557661533, 0.045253943666935935, 0.0685955357227114, 0.16809511959793108, 0.11263760873266768, 4.016250631501598, 45.834185923299486, 52.68635088397611, 25.246794531422278, 28.22685057117093, 52.16818224999213, 55.579444054634344, 57.44801021391346, 59.5975749723373, 21.81423425674439, 0.04448996631488685, 4.360737204551697, 5.863494786524004, 19.904955856261715, 25.741264204825125, 36.805952748944684, 59.7558779101218, 58.036687374115, 59.06760000413465, 55.779422175499704, 57.285879042840776, 53.77015667576944, 51.8963384628296, 52.891761487530125, 49.21280968573786, 50.44848965060327, 51.203753794393236, 50.5047050599129, 48.489920785350186, 44.972303913485625, 42.50556061344762, 40.117096054938536, 39.68729057619649, 38.876007141605506, 40.84577437370054, 40.81362270539807, 39.8461740247665, 39.9063745621712, 40.39820448044808, 39.281101688261955, 40.32166727127568, 41.08803956739364, 40.22391003947104, 41.884829844197924, 39.193389646468624, 40.27512050444081, 40.84158528235651, 41.55551941164079, 41.22376926483647, 39.54250412602579, 38.756559202747965, 43.342935654424856, 41.02354011228008, 41.37528650222286, 40.62675706801876, 40.39871831094065, 40.67263310955417, 40.48978005686114, 39.76985254595357, 42.10199579115837, 38.679770961884536, 42.46500330586588, 39.5747067851405, 41.01005108125749, 38.12113915720294, 40.18067767543178, 45.67486316927018, 55.905090993450536, 54.36192858603693, 57.0667048423521, 42.17392029300813, 34.39042383624662, 49.7729084568639, 45.24488902861073, 42.02530560954925, 59.76255378415508, 56.27697875422817, 54.74160617397678, 55.53605871815836, 51.18826043221259, 51.63928593358686, 47.10137821012928, 44.67510592552924, 37.19433015392673, 39.48711241445234, 38.663944198239236, 41.17656353981265, 38.89193588687528, 39.94586890743625, 39.92058923167568, 40.25673243307298, 40.583928708107244, 40.56651730691233, 40.137009928303385, 41.02710554676671, 39.0429392937691, 39.97481992167812, 39.654189694312315, 37.70051986940446, 39.021491773666874, 38.10335120847149, 40.710538894899436, 40.73102935667961, 39.70840861720424, 39.29302177121563, 41.17311577643118, 41.524877855854655, 40.0048731219384, 38.53836951717254, 36.91007598753899, 39.31403390822872, 40.10194001659271, 38.924444490863436, 37.030692792707875, 38.613239719021706, 37.128763814126295, 38.10471227092128, 38.33258628845215, 40.486085184158824, 43.33816997466549, 46.78663153802195, 47.05869105554397, 50.06866301259687, 52.77162713389243, 51.69792929003316, 46.43704245167394, 48.881228200850956, 56.78487470073085, 55.71540124954716, 55.109579409322436, 50.44084495113742, 20.312952956845685, 4.625870796941943, 8.961141032557334, 6.386782113582858, 6.3478138562171695, 3.8262904892044687, 0.2489636060331137, 0.9521402214323321, 48.16898853548112, 51.46544648754982, 36.53133584607032, 32.622052661834225, 39.14987487177695, 58.44203687483265, 8.137011345355742, 0.18135435488675872, 0.0432954398885129, 0.012492556519235575, 0.04066389339465288, 0.03305882365713197, 0.08427649751425752, 0.006453554838850734, 0.10887337442968162, 0.11630302535430079, 0.08700652078034417, 0.0897061839819916, 0.005094509594322693, 0.03255243187830333, 0.20951351000657006, 0.16417820397163593, 0.1830574755947436, 0.19899863148889235, 0.11847581158602431, 0.17928669890088422, 0.12888755168645613, 0.07335130996521443, 0.17678231151113588, 0.25282890265507085, 0.1458499487489462, 0.09258118172686908, 0.13491039705132285, 0.1390521748051528, 0.1855570213088105, 0.24470979558123698, 0.17561889974580658, 4.635509041047865, 52.67508191447104, 56.89939222028179, 31.683137263021163, 40.475392803069084, 53.8621715576418, 59.47161589899371, 60.742295172906694, 65.89136308239353, 26.084289204689767, 0.22808187250648776, 8.055883492192915, 6.236258706738872, 16.907970866849347, 27.720315687118042, 36.39885779350035, 60.7926348716982, 61.594010399233916, 60.844449381674494, 59.06597614288331, 60.27221479723531, 54.997458457946784, 50.27903933678904, 51.769085007329146, 49.409069399679865, 54.022741625385905, 54.158106542402706, 53.017838231978885, 51.38743054482245, 46.27557416116038, 45.43364524841309, 43.77385900866601, 43.31842868558822, 42.19788205239081, 43.26860281728929, 43.089813340094786, 42.52946745964789, 43.34502235535653, 44.156239109654585, 40.521064881355535, 44.11072000380486, 43.29609078745688, 42.00059859983383, 45.47897608049455, 40.148992769179806, 42.54540797202818, 42.57695951769429, 42.01849245255993, 40.77132778782999, 44.2712979162893, 40.73522237039382, 46.10057369355233, 42.068031987836285, 44.25751470750378, 43.14879794274607, 41.87345889306838, 42.75021453057566, 41.586513980742424, 42.218031267966, 45.00426338564965, 40.3532031274611, 42.632790534727036, 42.09861863044001, 43.33447902433334, 40.44735962344755, 42.42349678470243, 46.598750006768014, 55.57426652600689, 56.41701521412019, 59.088623908258256, 48.72303901180145, 39.84827249280868, 49.604262228935, 45.90481604299238, 45.76454424089002, 60.93203982999248, 57.41539178356048, 58.079198022042554, 57.19902207774501, 52.82439870219077, 53.12154177696475, 49.876341358307876, 46.67717779836347, 41.0596102283847, 39.79613634847826, 40.773104621518044, 42.52016751996933, 40.18332527529809, 42.354157124796224, 42.33305085089899, 42.17670517583048, 43.43835123123662, 42.16722872949416, 40.759537143092004, 43.82765431557932, 40.872870106850904, 42.49041634221231, 41.301832276005904, 39.06703441373764, 41.63984252560524, 40.20463943481445, 44.22680647142472, 42.25194015810567, 40.734308458143666, 41.26429911582701, 42.89784469912129, 42.274034869286325, 41.814584116781916, 40.856145120436146, 39.285024058434274, 41.91897407654793, 42.39600881453484, 39.03754211241199, 37.97703519944222, 40.51124718881423, 38.039871569602724, 39.92805350211359, 40.348841451829486, 43.03808119989211, 44.0626121336414, 49.794708990281634, 47.884106789865804, 52.561188051777506, 54.4431883288968, 54.850718667430264, 49.27703849730953, 48.20235613853701, 55.23567576562205, 59.70971161319364, 56.46451511690694, 51.52998516636511, 22.226485167780233, 7.23420528634902, 11.047550728244167, 18.522383128443074, 19.343235185069425, 13.48969586433903, 0.6404184934593017, 1.5760974465839326, 57.515753469159534, 56.16597567835162, 44.159000458255896, 45.029193970464895, 49.265247852571555, 65.8398074488486, 10.925665036324533, 0.45364398989946614, 0.12526987000338494, 0.14258457558049312, 0.16254349491528927, 0.15943671726892072, 0.13462836944287823, 0.15070064894614682, 0.19511044415975773, 0.20248099140101866, 0.22482667298566913, 0.14191408010740436, 0.05979071483917295, 0.11532454721389279], [0.026180058897983645, 0.0396535076921986, 0.07067301295577519, 0.07161170048939605, 0.035366433702649615, 0.0787901971489191, 0.022664303298018152, 0.045352987344226534, 0.05110564498951839, 0.020525456676560066, 0.03560226620926011, 0.018957766907049284, 0.07251998199330223, 0.02933868729028731, 0.0631934245898118, 0.14425883009549112, 0.06804025987343443, 0.1931155052396559, 16.11163950735523, 48.992819632253344, 35.030609561551, 34.04273709943218, 36.68193132646623, 47.78115633995303, 52.917786413623446, 55.6690231446297, 25.33940561356083, 0.1111322766049735, 2.798319881962192, 3.372257020204298, 0.8199649880970679, 2.440596535321205, 27.019521497911025, 56.65079632113057, 52.525247373888575, 55.936732753630615, 53.799762725830085, 53.88608232621224, 51.1243728668459, 52.46958501877324, 48.512423423028764, 45.93497514724732, 52.34387305475051, 52.15138666091427, 48.25164071975216, 47.22185773234214, 43.33467906521213, 40.92186835504348, 40.58983579758675, 38.482828755532545, 36.43257840987175, 37.55225035452074, 38.162669212587424, 37.94222024179275, 39.44189925347605, 39.005570873137444, 40.705067188509055, 39.844381501597745, 41.49944520765736, 38.78999740846696, 39.34631109237671, 39.709761834913685, 38.782839082902484, 38.327899056096236, 38.6227200877282, 38.880662995000044, 38.71573125162433, 38.373884923996464, 39.20164623568135, 39.80730725872902, 40.63394285017445, 38.07709878490817, 38.201002536281464, 38.493932985490375, 36.49189641398769, 38.889272597528276, 38.8230747561301, 39.58807814505793, 40.22878554559524, 40.481582303201, 40.294077319483605, 41.94057849145705, 40.06283790834489, 39.23601796550136, 47.45591732763475, 55.39827762111541, 52.65619177972117, 54.75037659368208, 40.69806968012164, 46.58604937215006, 48.94428030137093, 63.875335416486195, 45.51949808674474, 57.278049991976836, 53.95179379370905, 51.408548585830204, 52.884308984202725, 48.6501496068893, 46.251953647982695, 42.68690355362431, 38.020597042575965, 36.74018244589529, 36.60722194179412, 37.14717149734497, 39.515255420438706, 38.20860408967541, 37.84058378588769, 39.199500699197095, 38.17308702776509, 41.394804216200306, 39.06408479136806, 39.17637048229095, 37.73058091440509, 36.85534715652466, 37.66584611708118, 38.555231786543324, 36.29384025450676, 35.56374203774237, 37.01850206621232, 37.15339237643827, 37.43078239502446, 38.71267964763027, 37.41133136133994, 36.959999915092226, 37.966668375076786, 37.75462504356138, 35.33704473126319, 35.38982806667205, 35.84760396711288, 36.16189956665039, 34.433201205345895, 34.205429169439505, 35.61077125610844, 35.09894901706327, 35.19612966045257, 35.77383595128214, 35.308203543386156, 33.99307204831031, 35.82182615034042, 40.51908016204834, 43.90597228080996, 49.2164025768157, 51.222565481739665, 46.37393543797155, 42.89029021416941, 46.123488180099, 47.118169876836966, 32.21484788002507, 3.4292328790310895, 0.6044381015723752, 13.699327918791003, 12.073118148311494, 4.6546771737837025, 1.2298509550671424, 0.2571213545818483, 3.990277186516793, 49.816674263246604, 35.82708997111167, 25.38237321761347, 26.15645689349021, 40.10402671752438, 31.958397434603786, 0.7950741172798219, 0.02924402180548397, 0.02573198173195124, 0.04090644449235932, 0.08525577238610677, 0.041212408517998074, 0.12505926477212098, 0.059180694346826886, 0.023452456469737717, 0.034389587329520334, 0.0362495185747262, 0.024171493188928694, 0.0190354980182864, 0.04356257091726988, 0.04364956786195117, 0.059038236466867317, 0.061160020395031864, 0.08216559586505737, 0.01500985440572784, 0.031275863180898374, 0.01572523497030019, 0.0936162201387267, 0.05256310428282427, 0.045610622713162054, 0.013340083420306686, 0.08175846609857776, 0.05286954328297608, 0.017943977858991395, 0.059521856282146714, 0.06615810441754519, 0.06839634520151923, 0.3015958842250609, 23.027201737126997, 54.14968913601291, 34.761684017796675, 35.73422393491192, 41.26764097521382, 54.95154319270965, 55.615361198302246, 62.913119177664484, 26.196945559593942, 0.21702653427998866, 0.5617293739511121, 5.786602602851007, 2.7927851725009183, 3.2424844224606795, 30.74538092459402, 55.84654961862872, 55.16310799506403, 56.19698201456378, 55.5401615173586, 54.71209426080027, 51.83462781290854, 50.67736779489825, 49.75952140746578, 48.344353783515196, 53.70618674062914, 54.33919845088836, 50.906951965824256, 49.876329591197354, 46.085511792090635, 42.269202509234034, 40.784385358133626, 38.57026230904364, 38.43938850587414, 40.53899403541319, 39.608195981671734, 38.99187787886589, 41.526501717105994, 40.11676265347389, 42.20946481150966, 41.46759948422832, 42.52573728561402, 40.266232413630334, 39.93986375870244, 39.87847866550569, 40.40023234582717, 40.01853473724858, 40.53908032755698, 40.17164053455476, 40.248526834672504, 38.737292520461544, 43.329693732723115, 41.08014383623677, 42.99658644583918, 39.43240711765905, 41.12000688429802, 38.82924072204098, 39.14609762930101, 40.61619020277455, 40.88961078274635, 41.30766876282231, 43.343155307154504, 41.27779991396012, 42.32337436368389, 42.799895271178215, 42.2225929844764, 43.01070697845952, 52.1470759760949, 56.54936775084465, 53.98015645242507, 53.9445609431113, 42.26100867794406, 47.70976135807653, 49.56463452308409, 55.4681860246966, 50.14379993561776, 60.241604620410556, 55.325156796363096, 55.56133054917859, 54.07445023136755, 52.1506178763605, 48.22543536463092, 46.54552736589986, 38.80416893189953, 37.542589556786325, 39.0533531865766, 37.63480840190765, 41.437181503542014, 40.045712840172556, 40.98543428605603, 40.163007397805494, 38.825945931096236, 42.58803629106091, 41.222439581348056, 40.7602745486844, 40.163411401933246, 38.418984336237756, 39.22723185631537, 39.440608793689364, 38.918388351317375, 37.8630825011961, 38.30052875703381, 39.49210166931152, 39.498263712852236, 40.96652846182547, 38.87074724320443, 39.48719086185579, 39.46402926598826, 39.791715837294056, 36.67702444138066, 37.53490171124859, 38.39211217818722, 38.456748916256814, 35.47980723842498, 37.53328569473759, 38.002679655628825, 36.58183636203889, 36.66679097760108, 36.50809972516952, 37.36636530968451, 36.929923180610906, 39.109756869654504, 43.66811583119054, 44.8499769549216, 52.06826771459272, 51.768269154333304, 47.830138898664906, 44.95796765050581, 48.89241872295257, 49.34830796334052, 37.716593742370605, 4.661786960017297, 2.290842893623537, 13.10369541568141, 3.331342531788734, 0.8047280508664347, 1.2448386992177656, 0.30603928611643855, 3.94705732503245, 56.433799036087535, 39.28762066748835, 34.16596228076566, 29.861596399737945, 44.21229762415732, 40.94404151362758, 1.6064427408479875, 0.08046885666948173, 0.04977035756793715, 0.06488129631766389, 0.02642810859176661, 0.03992834173503422, 0.015400776624559395, 0.03719811162520801, 0.038735676902316274, 0.003515676357745824, 0.05084772233761126, 0.027788728625784, 0.07555940518936805, 0.04387703851886815, 0.21380453700980834, 0.18041211270516921, 0.15984312691275152, 0.21381461872689186, 0.11591084196322388, 0.17184888913987145, 0.10946463342876205, 0.18828498379838085, 0.1073205525115613, 0.19630181813432326, 0.25991527724169916, 0.17118542635392758, 0.1738398597245255, 0.11747507859141597, 0.14817865685589854, 0.14981744150000234, 0.21640805617695857, 0.36425872014895566, 28.030167241250318, 64.45584227961879, 45.769164792953006, 46.306580497372536, 45.0564112970906, 58.95574577393071, 61.85242399092644, 65.72275215579619, 31.105172095760224, 0.4316374401171362, 6.648788596353223, 5.743664906870935, 1.3815266807233135, 3.887955051275992, 34.03146028518677, 58.322922337439756, 55.4549519477352, 56.763423258258456, 55.19234926469865, 53.50517703640846, 52.835424484745154, 50.73785858769571, 48.00862635335615, 49.970391950299664, 53.81132979546824, 57.52572805650773, 52.73565115467195, 51.34675164376536, 47.23695493513539, 43.28109556628812, 44.77593829554897, 42.10137213430097, 40.51237683142386, 42.75825931179909, 41.37654950541835, 41.095899997218964, 43.07060549336095, 44.73693032418528, 43.792835435559674, 44.09516388370145, 45.52728791390696, 41.02591706860451, 43.034351025858236, 42.64554608252741, 42.63196291462068, 42.77918907903856, 43.916009626080914, 42.113029418453095, 42.44318316059728, 41.05607617285944, 45.77665259761196, 44.226947676750925, 45.878367500920454, 43.481567905795195, 42.0713738472231, 41.399044298356586, 40.71927401327318, 43.34792098691387, 43.96223083619149, 42.89236514799057, 46.16249222909251, 42.615712534996774, 45.291694671876975, 45.890989688134965, 44.17469386131533, 43.86503842569167, 53.37649976053546, 57.923413245908684, 57.2872793289923, 56.15923704639558, 46.14629676265102, 47.54697515118507, 50.18932688620783, 58.100606318443056, 54.08081231578704, 58.4941416402017, 57.09526754194691, 57.815269577887754, 56.48939863328011, 53.29274146787582, 50.29119868432322, 48.0470577363045, 41.15661436511625, 40.19480213042229, 41.064536725321126, 39.610906339460804, 43.40167314775529, 41.9336005949205, 43.172947975897024, 42.58358047854516, 41.15708897190709, 45.906106502779075, 43.25546679958221, 43.55699116183866, 42.696454524993904, 39.30006634804511, 40.90245654506069, 42.41860951146772, 40.62023808879238, 40.71627732246153, 40.056911207014515, 40.47306683755691, 40.46981127031388, 44.03473584882675, 40.81354033562445, 40.93823640577255, 41.42731674255864, 41.207911122229795, 39.32703656534995, 38.819140618847264, 40.23095461630052, 40.06592089130033, 38.22611355012463, 39.07457320920883, 39.647058825339045, 39.79300237471058, 39.88371502968573, 40.04191206347558, 39.08133145301573, 38.858446690344046, 40.64601982793501, 44.517705132884366, 47.729765445955344, 53.7658263790992, 56.54771643300211, 51.272234455231704, 45.09420333370086, 48.91511355676959, 51.979371117007354, 38.419910015598425, 7.749974900676359, 2.2459881392217453, 29.56336682842624, 25.924213355587376, 12.24502778822376, 7.759977434912036, 0.9186371740314269, 5.90650063368582, 62.14304024173368, 43.679443636248195, 38.10053102431759, 37.97886694631269, 50.51063176124327, 48.42819052357828, 2.3950494825839996, 0.23666207258018757, 0.1765397527525502, 0.22058974711164353, 0.22680763846203206, 0.07934099138383904, 0.19979163974283204, 0.15967873976595942, 0.15488941853325214, 0.0899842738985054, 0.08786236356583335, 0.1385887069327216, 0.12912439542912668, 0.15988290219778017], [0.08012542711390604, 0.020855759315553214, 0.05287086861508508, 0.04076005275090856, 0.052006993397709825, 0.0747796502565184, 0.05424973494823902, 0.010310562868272106, 0.10581891292766218, 0.021351569504927725, 0.028971733089776772, 0.05181061441919977, 0.05757787753076804, 0.0517863332624397, 0.011571253435836445, 0.04406422061184722, 0.043147607901764494, 0.045962237918208686, 5.918606538926402, 38.60622259878343, 33.131284175380586, 27.471760972853634, 33.88685034167382, 42.654308657492365, 50.33998512452649, 53.66473905501827, 46.09966370367235, 3.5324164648209853, 3.8695637929824094, 9.092012874541744, 0.9881010014683971, 0.345702507803517, 10.965150556256695, 46.963546122274096, 48.03053671313871, 48.888382604045255, 49.46475921138641, 50.83498824027277, 49.06037069136097, 52.16203589593211, 41.51589955053022, 43.38562280901017, 47.54233498727122, 49.387119816195586, 48.6953470783849, 47.6296861710087, 44.683040880387836, 42.363688484314956, 38.46273445313977, 37.6875642807253, 39.12573660573652, 38.629019414224935, 38.212463701924975, 41.668734704294515, 42.67402248997843, 44.09852143256895, 44.021709657484486, 44.5837107781441, 44.11454823709304, 44.17848287090179, 40.645866855498284, 38.19132212669619, 40.61062043712985, 40.92748911150041, 39.69154634783345, 39.88884941224129, 38.80852276279081, 39.11707209002587, 41.534091503389426, 39.41555661539878, 40.39204635927754, 38.885938582881806, 38.140727473843484, 38.555208252322295, 38.52511190599011, 37.462541826309696, 39.46864981805125, 41.96521882087954, 43.850733541673236, 46.94670738712434, 44.92275261109875, 45.360473432848536, 42.29773775223763, 40.319251091249534, 42.5490753881393, 49.821133998132524, 52.96465089244228, 53.28118616534818, 51.30611196640999, 48.472525073635964, 46.474202986686464, 55.992963852420935, 37.57800071470199, 41.74369512065765, 57.27440218771658, 50.09546849035448, 54.33887289416406, 49.026477490701986, 47.317438048701135, 43.187158723031324, 40.381079412275746, 35.67670629870507, 37.58740263600504, 37.96414629105599, 39.277626468289284, 37.537153151727495, 39.61200068073888, 38.9596006947179, 37.54878297928841, 37.22866658241519, 39.120594378440614, 38.04310752499489, 38.479828142350726, 37.66155896648284, 36.5663351551179, 36.79872774308728, 36.503565465250325, 35.935115968027425, 38.04818699436803, 35.65236799178585, 38.36487131734049, 39.5203858806241, 39.46256622191399, 36.78330106119956, 36.9924065374559, 36.48159234754501, 36.419681656745176, 36.86584341910578, 37.326796439386186, 35.65173256781794, 35.11626235900387, 35.77811133476996, 35.90627870252056, 36.333718992048695, 42.0393398500258, 43.309724946175855, 45.83653150066253, 44.55201802715179, 42.12292948076802, 38.521640608387614, 43.16444819973361, 48.684995943500155, 46.80731811831075, 51.15726978548112, 48.74859717584426, 48.510175904920025, 47.77805374514672, 12.651030363575106, 0.34066287500243037, 9.023526330148021, 1.8920377449643229, 1.2087916270379098, 1.977060266560124, 1.1541499461858504, 0.2885223792925958, 4.1301155667151175, 54.21083496462915, 29.37122364198008, 24.631154998656243, 19.058167126870927, 49.27096666828279, 19.509059267659342, 0.08351043257261477, 0.004843104914236333, 0.051580420319711974, 0.02429026554548933, 0.034399255359124754, 0.03609648102053231, 0.06293116971069286, 0.043123591045338305, 0.0525320049435381, 0.05516901364429824, 0.016780066221291502, 0.02629771276617483, 0.06899318132068842, 0.05714242549372777, 0.05424272907417148, 0.026762751118850805, 0.029802988283336166, 0.05192631284796423, 0.03719803884685521, 0.07706783997315554, 0.01121599165227024, 0.015565279642150048, 0.030739864019016107, 0.033290615049941887, 0.04238943749618146, 0.027185725498824354, 0.0515992354391323, 0.023731084563018336, 0.07793521238190514, 0.049849946442390644, 0.023491892760859865, 0.14360639897565688, 9.364965711870502, 51.36450429116526, 40.74136087971349, 31.179832450805176, 39.710416870732466, 50.456185340881355, 57.04310786339545, 57.75286859081638, 47.860447052986395, 2.663810286791094, 1.1395602000336493, 8.171946425591747, 4.878004183692317, 0.9569540728003749, 14.593198818545188, 50.044395308340754, 49.488156149464274, 50.94038624917307, 49.8307438050547, 52.156156263043805, 50.49211817402994, 53.09028440906156, 43.81578914580807, 45.7248184757848, 50.179136568500155, 52.787802988483065, 52.15197501644012, 50.94989407447077, 47.408429191958525, 44.25859728167134, 40.777148585165705, 40.87008522402856, 40.40524905727756, 40.09794312138712, 40.91319991696266, 43.243099566428896, 44.82985519593762, 45.39154252698345, 45.76830579388527, 46.29584104784074, 46.08463710354221, 45.07750188150714, 42.74573518383888, 40.50044890372984, 41.1871539392779, 41.92837992022115, 40.71848953923872, 40.63553533246441, 41.11495879388625, 41.00810558565202, 41.069223957677046, 42.07881066106981, 41.44988213815997, 40.0534987449646, 40.85667464040941, 40.46380612158006, 39.09670714409121, 39.271813515693914, 40.33013959084788, 42.77694940567017, 45.09124194422076, 47.518000602722175, 45.18864224033971, 46.40413376592821, 43.51752427316482, 42.46881977204354, 44.08667979701873, 52.58304349837765, 52.999352101356756, 55.18317876323577, 53.42266605746362, 47.981330579327, 45.68273144383585, 58.69709684002785, 38.07303913177983, 45.17284293328562, 57.88009851209579, 52.000799025258715, 55.91347309850878, 51.355455383177734, 50.190009378617816, 44.282484516020745, 40.578864928214784, 36.8921939019234, 38.99685928898473, 39.516557647335915, 40.94265299458658, 39.364981574396936, 40.616841316223145, 39.33940772087344, 39.95255654858005, 39.37880792925435, 40.70987601434031, 39.58293984013219, 40.5958644805416, 38.996443517746464, 38.81754029181696, 38.402726111873505, 37.04102823811193, 36.73887237425774, 39.42033013989849, 36.36290927087107, 39.42755122338572, 41.95068251702094, 41.78752760733328, 38.78455708103795, 37.639982008164935, 38.822631528300626, 38.97667869444817, 37.995387969478486, 38.217221536943995, 37.263705115164484, 37.083405525453635, 36.6210247624305, 36.97768980456937, 38.57440825431578, 42.409721420657256, 45.217389291332616, 46.10414697277931, 45.10811598070207, 43.140964969511955, 40.391112835176536, 45.17518066590832, 50.384927641960886, 49.9680071492349, 53.058654415992, 48.90619800936792, 49.94747354138283, 48.152879361183416, 15.235243747311255, 1.1254097593407477, 8.176793004235915, 3.977819983997653, 0.39690037828779995, 0.23943718012061813, 0.3413557555646666, 0.45204268227661815, 5.286244471226969, 58.419196913319254, 36.05619561287665, 30.01382358612553, 22.09232637959142, 56.3659655663275, 24.474213123321537, 0.03273017193761564, 0.018726852684912663, 0.05163577017224124, 0.020786736708795352, 0.0236652163232887, 0.04106131299669224, 0.005253027550004904, 0.07310454538392444, 0.008676409225670562, 0.02062779453192507, 0.006118125156424339, 0.037938493469189254, 0.06257257544465604, 0.07161740784443195, 0.11009591286100688, 0.128643338177954, 0.10344210982082352, 0.11983833726375334, 0.11540350789624838, 0.22950688797620036, 0.13428176062241678, 0.12542607533114572, 0.21729943012037586, 0.08170969694131806, 0.1284952916865868, 0.10565711515805415, 0.09095121475477373, 0.11904806394370333, 0.1497368950156435, 0.12419498735858549, 0.13779185291740204, 0.29369405500831147, 11.04444323047515, 58.1561117787515, 44.930248260498054, 39.30660493912236, 46.04475836600027, 53.09013535899501, 60.46912170225575, 62.62703326440627, 56.551199497715125, 4.357507623011067, 6.684789090387284, 19.826239770458592, 4.487488596670089, 1.2117352432781652, 18.26047274374193, 51.293007327664284, 50.774975976636334, 49.24463187494586, 49.7966270292959, 51.63832887526482, 52.155101145467455, 53.15263048295052, 45.68432784849598, 47.045755078715665, 52.094629964520855, 54.19543966170281, 52.435001480963926, 52.854177336538996, 50.4629514294286, 45.96562062540362, 43.66759415595762, 43.94829073259908, 44.385564404149214, 43.694756569400916, 43.0192381335843, 46.54511551703177, 47.63829577353693, 48.550466491330056, 48.51064658934071, 49.890838438464755, 49.33049648038803, 48.37235558417536, 44.00747929849933, 43.089189683237386, 43.72639832958099, 44.21409799206642, 43.4403790966157, 42.693351930187596, 43.20329535392023, 42.711685088373, 44.15805516704437, 44.403913251815304, 45.032190661276545, 42.09793221565985, 41.79408973263156, 42.220620032279726, 43.71061471200759, 43.19718430119176, 44.07656400434433, 44.72743034362794, 47.68194783118464, 50.916883407100556, 47.998832195035874, 47.711934351151996, 47.72745516992385, 44.16594697583107, 45.23640101955783, 53.127146843940984, 56.157946586608894, 55.92430276255454, 56.41911368216238, 49.84702556363998, 47.53508644719278, 59.76675072023946, 42.374835860344675, 48.38644866020449, 57.3424356983554, 54.236891269683845, 58.172491596591094, 52.40474039508451, 51.02846307139243, 47.25529593806113, 43.61974516222554, 39.78733454981158, 41.72999820401592, 41.112813257401996, 42.26201672707835, 40.7920261352293, 42.999732186717374, 43.11630895060878, 41.51163593415291, 40.70321975215789, 42.764378209267896, 40.89104244785924, 42.27417215224236, 40.598778801579634, 39.00376266048801, 39.6425598667514, 38.86602863188713, 39.016439760884936, 40.305220773143155, 37.88545177828881, 41.51492680272749, 44.047259976786954, 44.98632638685165, 42.20614256397371, 39.92386441076956, 41.33740817346881, 41.24731525298088, 41.252539850050404, 41.57964198820053, 38.183296957323634, 39.60666233493436, 38.20842366064749, 39.26846773393693, 40.380663641037486, 44.086299327112016, 48.52339821477091, 49.59185577207997, 49.69097798870456, 46.94346750936201, 42.734250483974336, 48.97582007992653, 53.59295183612455, 51.87548322062339, 52.09233537797005, 49.41292901192942, 50.122305347073464, 49.6826272626077, 18.368783112495176, 2.3145950513501323, 14.887187327108077, 6.242724733967935, 6.0527339481538345, 5.733383394056752, 2.656186179768655, 0.7295032422388754, 6.360620885126053, 66.16778035317698, 39.13267135620117, 36.502831982028106, 29.268171210442823, 63.49467723600326, 32.985772086728005, 0.23277281272795894, 0.062245206922412886, 0.2215561363846064, 0.14428561252932395, 0.1082527282978258, 0.12773817465189966, 0.19327644499078875, 0.10834240655024206, 0.18319880349501488, 0.18066337422257472, 0.10253395089098524, 0.10636438285150837, 0.1570542604332009, 0.23097230692303952], [0.09471408542125456, 0.04322391025902283, 0.0227532078016309, 0.046809749497521314, 0.03262519873979111, 0.015197454016625643, 0.06403583402354872, 0.05132628214215079, 0.03774430167170302, 0.027428257444332686, 0.02522353300704591, 0.015742225842850826, 0.017535335068861325, 0.04261022786639872, 0.00776497814278569, 0.014898729521871336, 0.03518017091517968, 0.12308527069586901, 0.5353297389322712, 20.661826210637248, 49.78662890772666, 21.052019673009074, 17.67218585937254, 31.15501169235476, 45.399395112068426, 51.865551779347086, 52.90116733120334, 4.84387073786028, 0.46803090661283464, 4.880951354580541, 5.581283194403495, 0.6204710347998528, 4.995608118272597, 38.90937866703157, 53.996516658413796, 54.41548462836973, 53.59428544198313, 48.65074580715549, 52.45465255552723, 46.52233046870078, 50.09237374028852, 54.996528856215946, 50.360789375920454, 49.03266306846373, 51.65888209496775, 51.7376668222489, 47.04981080947384, 42.656144326733006, 39.34579726188414, 39.28853065736833, 38.21022795092675, 40.87454888128465, 40.86283668395012, 43.629402037589784, 44.052708148956306, 45.95592844870783, 45.851679694268014, 47.44362854188489, 48.218182902182306, 45.25314169545328, 45.25082357468144, 38.84101959966844, 39.380831872263265, 42.12562807144658, 39.74500040854178, 40.98132756448562, 39.962401697712565, 39.57391838873587, 38.660876904764486, 38.14499893496114, 39.89371707362514, 38.10235492644772, 38.97856535450105, 39.00175440695978, 38.96869274877733, 37.07867906939599, 41.66720890229748, 49.081512266589755, 50.39943256685811, 50.931023551571755, 50.27941196195541, 51.86832097268874, 49.039566439967004, 44.03653229436567, 41.95936272221227, 42.958849322411325, 49.93281172167871, 52.91595858912314, 54.869436217892556, 49.39430952072144, 49.87760436150336, 41.63677915450066, 46.56556283274005, 40.72793852898383, 49.197198652452045, 56.32888740108859, 51.87136865431263, 50.48856450665382, 47.013003287776826, 43.17614078521729, 37.40872690754552, 38.250797025619015, 36.76768610554357, 38.80475336505521, 37.63679704358501, 38.563727640336566, 37.282085341791955, 39.58299867568478, 36.35217374370944, 39.77257859322333, 39.36153381101547, 38.51565899387483, 37.4347439888985, 35.908926302386874, 37.38980931620444, 37.90454587628765, 37.407860063737445, 37.72492877898678, 37.24532096616684, 38.858434923233524, 41.15230368029687, 44.35334213318364, 44.52406329493369, 43.82457917736423, 44.36366581147717, 40.5851956336729, 39.43366227611419, 37.59787144199495, 35.3972452686679, 35.983823960827245, 37.043954326260476, 36.408773545295965, 39.05594195089033, 42.5412541820157, 46.23279286969093, 48.23169154505576, 48.51153696736982, 47.78029734088529, 50.9817554873805, 48.756449760929236, 46.940619868616906, 48.09891931472286, 49.44144856545233, 52.71758079528809, 51.08556885873118, 48.87807853760258, 28.476817338697373, 1.511794845423391, 2.0581196008190035, 8.523469240434709, 3.5626155282220537, 1.4204628236832157, 0.16166650810308997, 0.38741121489194136, 0.3142792358994484, 7.055828148318875, 48.597072093717514, 26.561188620905725, 32.49480312870395, 26.623983806179417, 45.02555008857481, 9.921558864655035, 0.08138313664183502, 0.09825275279581548, 0.03149946700901755, 0.016487981793620897, 0.1529630751258904, 0.04290547432197679, 0.04942592443718065, 0.023397529880786617, 0.0299073888304373, 0.12997364985846704, 0.016991648214658903, 0.04050768806689209, 0.025943906549664757, 0.028419320494116797, 0.0325364972494783, 0.037734698759572166, 0.027599646634752714, 0.026473240746605783, 0.08401603528088139, 0.01520049059763551, 0.05998100724912459, 0.03755138541061071, 0.03429807429652541, 0.02937556484774236, 0.024233822102448153, 0.04656311898161808, 0.008740819983124253, 0.07420862363951822, 0.07124672088051034, 0.013039564364589753, 0.034797138444358305, 0.0770040478317007, 1.1728059644660642, 27.075570206488333, 53.31481656720562, 23.53651954281715, 28.41938207226415, 41.15634372157436, 50.65782654669977, 55.71827634688347, 59.48577565531577, 4.996828955988731, 0.4599027750232528, 2.2691823397913287, 7.4995026376939595, 3.3001481669564403, 6.329223292489206, 43.015974721600934, 51.91323995590211, 55.0724777098625, 52.25211312693935, 50.52117901463663, 50.44688540120279, 49.1264900853557, 48.85467375478437, 53.20930088720014, 49.01539287259502, 51.258164913423606, 51.28504491621449, 54.188277413768155, 49.13309927909605, 45.57223043134136, 41.49076500246602, 42.04420358903947, 39.29091545843309, 43.153355736886304, 42.425038276180146, 45.29466390609742, 44.468196976569395, 47.71917112411992, 47.975494092510594, 49.78587973502375, 48.305075168609626, 48.16132422416441, 46.00929229490219, 41.45069799115581, 40.14222668063256, 43.389647160806966, 40.69922677932247, 43.64864126328499, 41.89353358361029, 41.329069214482466, 40.400244112937685, 40.48471627696868, 41.66223533691899, 40.60887890477335, 41.58429784159507, 40.97659326368763, 41.056695907346665, 39.471826937890825, 41.53043193201865, 50.221015714829974, 52.30846581920501, 51.94636044963714, 52.24670810084189, 51.93769593392649, 50.62205453072825, 45.641256301633774, 43.486937630561094, 44.63930253059634, 51.077837867121545, 55.275632950567434, 55.19434575111636, 52.92086547420871, 48.311194066078436, 44.547299415834495, 46.23897844745267, 42.443238073779696, 54.62562953272174, 56.602221688916615, 53.58608376595282, 53.251925283862704, 49.45219978209465, 44.80817233362506, 40.05247500634963, 39.653067896443034, 38.743050559874504, 40.13609209368306, 39.77569295514015, 39.060460521328835, 39.40424842219199, 40.28338886076405, 39.4530858532075, 42.49232653648623, 40.14119509727725, 39.421714736569314, 39.375022842038064, 37.90454195391747, 39.88019274127099, 39.8150029490071, 39.09696602052258, 38.583951380945024, 39.62965919125465, 39.49098771618259, 43.96416848705661, 46.727042890364125, 46.58053844205795, 45.5376115922005, 45.33805708731375, 43.41686448743267, 40.52077070359261, 40.12088114215482, 38.115796889028246, 38.48196583409464, 38.32594571575042, 40.06674458903652, 40.197857656786525, 43.90435626429897, 48.13434223974905, 50.97205938831453, 50.16073280765165, 52.94645109484273, 53.04899361825759, 51.222228157904844, 49.2675228272715, 49.89789086003458, 52.6094606614882, 52.72040097944198, 51.67645431333973, 49.4176358561362, 31.805224957004672, 2.6015554080086374, 2.838754370327919, 10.200296217395413, 1.32283270118698, 0.32251645840944787, 0.16994837821731645, 0.1873507395747208, 0.38204421739905114, 7.133620025650148, 53.78721898601901, 32.68686982893175, 38.48830830666327, 29.204295412186656, 53.84559169892342, 14.255550407594251, 0.0497406218651562, 0.04036348733690478, 0.06441445765836586, 0.02773352816039997, 0.1859796107296021, 0.03722592061685939, 0.08413471762211093, 0.0587258909288193, 0.03546781011766965, 0.03492170434084631, 0.054905881594506004, 0.044514059780105475, 0.022206477663149277, 0.015222016710697886, 0.19260279323545196, 0.1372585637915519, 0.11465368401860038, 0.09984406297125163, 0.21809668250141606, 0.11164341046805344, 0.15639547078359514, 0.11638053813047948, 0.10905594850379614, 0.0746266471762811, 0.08283992177776753, 0.2175960133993818, 0.10506493685346459, 0.13884048938991564, 0.13444078515373892, 0.0707168102024063, 0.13784521860220741, 0.2166642666223549, 1.2158172048868672, 34.73517271780199, 62.47310769173407, 31.535616920840358, 27.354256568416474, 42.691853584781775, 56.06379009062245, 60.36302551146477, 65.49625096782562, 6.177137801724096, 1.2348643570177018, 13.709017153709167, 13.492245404951035, 1.8592526138790193, 9.444645720143473, 44.97057022586946, 53.38501914854973, 55.25254195736301, 53.5397566518476, 49.7435652056048, 51.40142948396745, 50.01965299729378, 51.35273325827814, 54.3254780000256, 52.13526179713588, 52.22795917141823, 54.64896763524702, 54.753679229367165, 51.29685125043316, 47.047018081911155, 44.491817489747085, 43.824959647270944, 41.7906694258413, 46.60972087613998, 44.359586546497965, 48.458239801468395, 47.8434435782894, 50.50824303780833, 50.662992308216715, 51.35884038863644, 52.071468368653335, 48.98248418684929, 49.244196491856734, 44.57909807082146, 42.940931935464185, 45.57974961496169, 43.793153147543634, 44.86418377968573, 44.3927776428961, 44.28115091016216, 41.277854827142534, 42.696262328855454, 43.617548634929044, 43.42841194521996, 43.850768843004786, 42.67305366454586, 43.33844061820738, 42.40280235967329, 44.08290647691296, 54.67210569689351, 54.90171340204055, 54.295848415743926, 54.0955957289665, 55.70732901173254, 52.2642763968437, 48.04728915614467, 45.84658845778435, 45.50175720645536, 53.300256729125984, 56.90010609165315, 57.64587025488577, 54.58635091781617, 48.85637606343916, 46.233698937200735, 46.05810226932649, 46.31283275542721, 55.97199093910956, 58.63959097093152, 56.14746209113829, 56.586320400238044, 52.188743314435406, 47.48875541071738, 40.63724548585954, 41.351360044171734, 40.52959211411015, 44.24812847568143, 41.45885259874406, 41.383166543899044, 41.0023553909794, 42.64085492780132, 40.67811658305507, 45.80645868855138, 42.18695432909074, 42.01473089956468, 40.76755054535405, 38.89239088181527, 42.677752664012296, 41.486281733359064, 41.730723842497795, 41.438891656937145, 41.195822377358716, 43.39128278916882, 45.829945841143214, 49.185376628752685, 49.537393662237356, 47.14634426178471, 48.69237392179428, 44.745367342425936, 43.54398458234726, 41.65024072893205, 38.877454496199086, 39.42312678983135, 40.94119387288248, 41.7872412743107, 42.554574551120886, 47.42240067451231, 51.05851627165272, 50.75311660766602, 52.284323630794404, 51.809340292407626, 54.75914701338738, 53.137662718372965, 53.114257935554754, 52.293176420273326, 55.21025880690544, 55.678672175253595, 52.81738550432267, 49.428998962525405, 35.626833361964074, 3.6103103237767376, 4.425433758766421, 17.727467744581162, 11.227648315891143, 2.7105431210610176, 0.8564380664498576, 0.4793692836838384, 0.7423559299880459, 8.574536538893177, 60.03810028876028, 35.959183631404755, 44.96907188046364, 36.30477974491735, 61.01726508909657, 18.676879405975342, 0.2733277607588999, 0.2769728071026264, 0.1888353873284594, 0.06013862600910568, 0.3558475343931106, 0.1186871216181786, 0.21087930687973577, 0.21409391906232605, 0.11241667663618443, 0.281385381615931, 0.2035113796591759, 0.15787175285720056, 0.1336461068281243, 0.08305109391409544], [0.0146777993406079, 0.03242740249862114, 0.030126499552880565, 0.027506616747667714, 0.0159891321504068, 0.05490893445488426, 0.030552532538891803, 0.06533744805041822, 0.06834026756546191, 0.022205975875558875, 0.01731418463731966, 0.010935081574585169, 0.0845780297212543, 0.03327360406758324, 0.03800187192316498, 0.04545193143008698, 0.0005123087307325595, 0.016461978854251005, 0.013161961274642139, 7.985853985432656, 41.97911185602988, 30.869370968111102, 27.008209382334066, 29.385705032656272, 45.27416167720672, 45.14074225579539, 55.78909474034464, 5.945549789936313, 0.5246531086102609, 2.418536144879557, 7.2676047586625625, 3.4331476496111963, 1.20673434388253, 23.82051483277352, 47.35683041234171, 54.25663255876111, 53.27130963725429, 53.765591036888864, 49.339557155486084, 53.52798561896048, 53.27807180343136, 47.773127248210294, 52.82199036690497, 54.557156716623616, 52.65795292392854, 49.129235744476325, 48.184274012042636, 42.92850978912846, 40.66391760303129, 38.00492325136739, 41.685993133052705, 41.13190343303066, 42.25926714558756, 45.22610087548533, 47.1223864247722, 48.95934220283262, 47.584323959965865, 49.29862722273796, 48.795963718045144, 47.99281135682137, 44.90552556130194, 42.24362865571053, 39.85760381144863, 38.18649368901407, 38.00267181088848, 39.97175262820336, 38.95396032641011, 39.01373724783621, 38.039961784116684, 39.676833537317094, 39.826852429297666, 38.09191357704901, 39.01383530709052, 37.73769609389767, 39.021130915611025, 37.488092145612164, 45.350279192770685, 50.92064103772564, 52.85266722402265, 51.67912936979725, 52.322935442770685, 54.14506858394992, 51.92764289917485, 52.212559946121715, 46.43923113423009, 41.93336917508034, 47.154949941942775, 50.34976751573625, 54.62676702007171, 52.95546077912854, 51.41872321405719, 46.57775748160578, 48.367068229183076, 51.08358413942399, 48.87799616782896, 52.66686847133022, 52.48311327349756, 49.547446696989, 46.503118699596776, 41.91564790664181, 38.660967119278446, 36.974481305768414, 37.2461054402013, 37.61724795064619, 39.663266058891054, 39.476600462390536, 38.12100187424691, 38.55113290971325, 37.563629150390625, 39.13312242877099, 40.228667874490064, 38.74767111193749, 38.18661920485958, 38.21610758381505, 38.38281616087883, 39.22192096710205, 37.91238669426211, 38.682791186917214, 36.94364755384384, 37.67315349271221, 42.33427070802258, 46.29675496009089, 48.62472872580252, 48.62877268945017, 46.50621737203291, 46.774750678770005, 45.17889122809134, 41.274532579606586, 39.837215331292924, 36.79324034721621, 36.166951579432336, 34.77949942311933, 35.73979762292678, 41.66325123079362, 45.01502636940249, 47.607681674342004, 50.335815645033314, 48.132004507126354, 49.46795986544702, 49.605411483395486, 50.57726890810075, 51.163463207983206, 51.90036281462639, 53.799319498000614, 50.01520110714821, 43.36284560541953, 10.393931865692139, 0.10176577920755071, 0.5506681062040791, 1.4543965963586685, 3.9980466663837437, 0.380813573757487, 0.18725811954467528, 0.16597478740638302, 0.4130952012154364, 14.046112510465807, 43.864893297995295, 23.982098833207164, 21.886505888354396, 24.00222843693149, 45.168771513046764, 1.9263733154343021, 0.02642671622696423, 0.07112115906972079, 0.02110607854481186, 0.0998067238458222, 0.05120239040303615, 0.053720846997513894, 0.01569068440491514, 0.030825832490659053, 0.03793208897414227, 0.050960252992808826, 0.08935477945112413, 0.05223919464755924, 0.05402107302459979, 0.019509068675219052, 0.02985636737468022, 0.022485793320341937, 0.06757861529026302, 0.009196307134604263, 0.054578938251060825, 0.04426626481055733, 0.03479749084480348, 0.04121954845745237, 0.0610024590916451, 0.019299853893537677, 0.029507659473306233, 0.03472447117430068, 0.06609954465661319, 0.03971179549191748, 0.06864793613673219, 0.05778011708189884, 0.02690326505070252, 0.026246756427891316, 0.09892587595048452, 12.316481605652841, 53.02608697645126, 31.961609855774913, 23.274440496198594, 35.30122956921978, 50.54403466563071, 50.839671550258515, 60.526231411964666, 5.659989474281188, 0.378585115916306, 0.3321577055800346, 2.563734689066487, 4.101650681226484, 2.6992594426678074, 27.671399808699086, 49.66835767992082, 54.980200029188595, 53.6451546607479, 53.448996928430375, 51.13198618735037, 56.15107851643717, 53.55974505024572, 50.92024880070841, 51.655042094569055, 53.06418888030514, 53.93977565150107, 50.470062686551, 49.00299426048033, 46.3374299387778, 42.97024773013207, 41.06482698071388, 43.93718258027108, 44.08455779475551, 42.376298904418945, 47.197025206781205, 49.510011596064416, 51.473671697801166, 50.740780753474084, 51.19296727641937, 49.24541634898032, 48.93800058672505, 48.363910721194365, 43.356377617005386, 41.31091256295481, 39.81463032384073, 40.03360056108044, 42.04387018757482, 41.65023680656187, 40.170259860254106, 40.56115542688678, 40.978248503900346, 40.950670319218794, 39.56147270817911, 42.0704677797133, 38.73651589116743, 40.64829480263495, 39.72029339882636, 46.978968881791644, 52.04736148157428, 54.27472252999583, 54.58561743459394, 54.00010562712147, 54.71092147211875, 52.53284500491235, 52.287653723070704, 47.73062444502308, 44.54162374619515, 48.65631949517035, 52.0813762757086, 54.96385551268055, 55.812632883748705, 51.21733696229997, 48.99693027619393, 50.12691413202594, 51.87253359825381, 49.12920828788511, 55.00103565954394, 53.05541453822967, 51.95673119637274, 48.92042836835308, 42.82497490606001, 40.40206409269764, 38.70603123018819, 38.34424357260428, 38.76185440248059, 41.053659992833296, 41.289386595449145, 38.52205637962588, 40.00382192673222, 40.831289060654186, 40.054467570397165, 40.574173773488695, 39.697865286181056, 38.97994210643154, 39.184293670039025, 38.401745519330426, 39.0870306568761, 38.47288554714572, 39.90101268214565, 37.46528748543032, 39.32482827094294, 42.750724438698064, 47.6815281375762, 50.58890658040201, 51.43758196984568, 48.281313450105735, 49.69705374010148, 46.461117959791615, 43.53165657289567, 40.310872908561464, 38.18905891910676, 38.35048406354843, 36.049158880787516, 36.77846477877709, 43.950895186393495, 46.79597462377241, 50.66660088877524, 52.45837096245059, 50.47361635392713, 50.45205900746007, 51.09079345580071, 50.852787956114746, 53.85375807362219, 54.67400020168674, 53.25665566229051, 50.561567660300966, 45.76124160520492, 12.160680159445732, 0.7041541895558757, 1.7792170182351144, 2.422392815351486, 2.2533202748144827, 0.5305761327185939, 0.19214617418906382, 0.22046303616896754, 0.5001825749153092, 14.75070551518471, 47.22620764086324, 31.91280576490587, 29.19430905772794, 29.019671409360825, 52.51451969146729, 3.728285657782709, 0.015096951899449191, 0.033400322671138474, 0.07009010431506942, 0.047407681122422225, 0.037465637189246, 0.013412309232197944, 0.05743544646388581, 0.027794213815321846, 0.10079470147649128, 0.011430362205682023, 0.05519512958163696, 0.01960034805139707, 0.02819472458213568, 0.016586314924361727, 0.15897665082687334, 0.1199209062202323, 0.17709466087962353, 0.17776189281815485, 0.22784793989792948, 0.1199663658776591, 0.1117344446960957, 0.13697178643797675, 0.18653061180826158, 0.1977616139957982, 0.1100409000871643, 0.16188758575627882, 0.1592519062180673, 0.129051678363354, 0.17042516069787164, 0.1273763896296582, 0.14784678756710024, 0.15018042928028494, 0.21886267849514562, 13.886978030204775, 57.64063389070573, 41.06184990175309, 38.43402270347842, 40.496369638750636, 54.50783683407692, 52.99163679922781, 66.24519225089782, 7.6185975632359915, 1.0727119806312746, 7.211476131792992, 17.024561359036355, 6.862981386723058, 2.953335628394158, 32.018025305963334, 48.0914903456165, 54.760111916449766, 53.946847684921764, 55.26787057999642, 49.988913382253344, 56.49974192342451, 54.98666017286239, 52.85762902229063, 52.06431004308885, 55.925969769877774, 55.439474275035245, 53.11829405446207, 50.872792043993556, 48.82653074879801, 45.341740192905554, 42.63986256814773, 46.33410376887168, 46.57208181196644, 42.83554177130423, 49.77529718029884, 51.7186943177254, 52.88856083346952, 52.380700188298384, 53.15218333275088, 52.556441983869, 51.57098570177632, 48.9017931876644, 45.73280834382581, 43.99317441448089, 42.02749821447557, 40.89886365398284, 44.21738101590065, 43.82785435645811, 41.66737364184472, 42.15807783988215, 42.35197628698042, 43.2096613607099, 41.16433358961537, 43.28586909078783, 41.294787699176425, 43.16685653501942, 43.317710891846694, 51.30836732925908, 53.25966804258285, 57.136389670833466, 56.809491495932306, 54.47164512449696, 56.40994318069951, 56.012846346824404, 55.49596032788677, 51.468556927096465, 46.68866642059819, 50.7795573049976, 55.10584139054822, 57.02169564462478, 57.234037076273275, 52.55593599811677, 49.549890333606356, 52.0388146369688, 52.825775454121256, 51.40685804428593, 56.630443142306426, 55.07452126472227, 53.9453258052949, 52.20770012947821, 46.07821226119996, 41.53464063521355, 41.59444501323085, 40.995757964349565, 40.938334465026855, 43.689445680187596, 42.17015481764271, 40.909520733741026, 41.85325084194061, 41.64579276115664, 41.6417174185476, 42.30344480083835, 42.70758621154293, 41.3351567329899, 40.785299270383774, 41.12421558749291, 41.71989025608186, 40.72613031633439, 41.602430958901685, 39.980515203168316, 41.83765942050565, 46.430292052607385, 48.889629917760054, 52.35079603810465, 53.11896870213171, 49.70259997152513, 51.50030459127119, 49.521119748392415, 47.30879706721152, 43.06663605474657, 40.90183288820329, 39.40049079156692, 38.46393862078267, 38.88728395585091, 46.90436540111419, 49.47121543269004, 51.66564033877466, 56.07644365679834, 51.82088775019492, 52.113669149337284, 53.27368659357871, 51.769853791882916, 55.54263261056716, 55.28740398345455, 55.2521183413844, 50.65856787466234, 47.028049499757834, 15.055824729704089, 0.8950083258171236, 1.4041163459900887, 6.671840856152197, 11.502372103352702, 1.434286727059272, 0.4690329496177935, 0.35897393921209925, 0.4607877597933816, 18.01502650783908, 54.5081231670995, 32.65599096975019, 33.09957573490758, 33.99346428532755, 64.08066757263677, 5.182110936410966, 0.10076355234149004, 0.18787892655499522, 0.13729184265098265, 0.16136214137077332, 0.17572078943973587, 0.1542261396084101, 0.18742970791795563, 0.12046602374363331, 0.15593675265629448, 0.0964157275795456, 0.16209974614602907, 0.11232116079378514, 0.1320359432288716, 0.1713673875577027], [0.01393379390074481, 0.03611246544507242, 0.038398081106283975, 0.053914437415979566, 0.0027323545674012317, 0.053999894523933056, 0.013231633140915825, 0.05330455098902026, 0.06824708063035242, 0.0020456611227634694, 0.07003643219509433, 0.01810208116958459, 0.04540630706375645, 0.009810200201407557, 0.05086862887706488, 0.11799089325171326, 0.07762869294252127, 0.07754766382277012, 0.0457591058746461, 1.3550150130064258, 38.96191097074939, 39.54238645492062, 30.181053838422223, 33.764982300419966, 42.118661942020545, 37.55017542069958, 63.143915360973736, 13.257228751336376, 0.25203267683184916, 0.3267823730505282, 3.1224890678159656, 4.588158188327666, 0.916384140089635, 11.74620722570727, 40.597103949516054, 55.77888088841593, 52.97348014770016, 54.354919310539, 54.75175334561256, 48.57878600397418, 51.02171659469605, 53.69961677059051, 50.80369949340821, 49.16933805711808, 48.62583091182094, 50.97035707965974, 45.35456242099885, 44.13712539980489, 39.93463523926274, 39.727655687639796, 38.554141367635424, 41.86533566444151, 43.58897416822372, 45.903129423818285, 47.60428490177278, 49.08335578057074, 49.62792196581441, 51.64569116407826, 48.18473685172297, 48.745271005938136, 44.73334920021796, 44.701389728053925, 38.474391737291896, 39.71706136580437, 38.64582284804314, 39.6379550041691, 40.49347885193364, 39.709400976857836, 39.30114107747232, 38.44080055913618, 39.383236285178896, 38.946715708701845, 38.91727047581827, 38.74653362458752, 38.14420661618633, 37.475587629502826, 41.92601865337741, 52.09622244681082, 52.162588950126406, 51.623894553030695, 47.64414794983403, 55.07155987524218, 68.13920282548474, 50.61158964710851, 50.459750775367986, 45.29760568372665, 47.171674928357525, 50.499970759114916, 51.16485172702421, 52.93779442387243, 50.760780918982725, 47.95890638905187, 49.8598321022526, 51.55736723253804, 51.735905678041526, 53.408686730169485, 50.28230274877241, 45.406133744024466, 42.59931310530632, 41.6887427145435, 37.95147311302924, 37.67826826341691, 37.79098149268858, 38.26537255317935, 39.33197875176707, 37.235624867100874, 36.78241068317045, 36.73552267013058, 36.93694422321935, 38.3273224676809, 37.432912242028024, 38.06435500421832, 38.597228603978316, 39.38077303671068, 37.091873922655665, 37.72137118924049, 38.069391327519575, 35.2718980850712, 38.09819329169489, 36.42598490561209, 40.84934765292753, 48.20807495424825, 48.1250266105898, 51.45680158369003, 47.24088907241822, 49.729550576979115, 47.1261558225078, 45.64175836501583, 42.55771244725874, 39.42111069156278, 38.98131493599185, 36.53935317070254, 36.272816350383145, 37.53524687982375, 42.60992703899261, 47.323156864412375, 49.634044785653394, 49.29751326960903, 49.04723075128371, 50.89067020723897, 50.54807078453803, 51.55245250271213, 52.959755774467226, 50.755913257598884, 51.65293185941635, 28.489378729174216, 1.225509749304864, 0.1263593772666589, 2.176001533385246, 0.9080392975480327, 0.3206566420774306, 0.04095262427243494, 0.07177937415338333, 0.21648345455046625, 0.6064195726667682, 21.633609110309234, 42.702624413274954, 23.275940802789506, 22.08485230322807, 39.22518437908542, 29.985772755838212, 0.18217226099823752, 0.029291865911575097, 0.03038566518244484, 0.07207593444975154, 0.03852037555207649, 0.02331422739512017, 0.03764491325484649, 0.042835427072620204, 0.05407658375559315, 0.007868280311325386, 0.047079979351932005, 0.06770347230016224, 0.0370930886316684, 0.03720683353622595, 0.037128734702785174, 0.047718387232312275, 0.034274846510661226, 0.020289871233305144, 0.07184806159667431, 0.05531681115709006, 0.018114687146378622, 0.093533911652142, 0.024481291484628475, 0.02740772820318178, 0.06426196785703783, 0.08180784046529763, 0.06703570410008393, 0.03262463566516677, 0.07779040644245763, 0.02291708358473355, 0.06823565059852216, 0.016830446078411995, 0.07436657564774637, 0.046660442791518666, 2.5143782794475555, 44.29460071748303, 44.526350036744155, 30.975276923948723, 38.95111268566501, 50.41177234342022, 43.38126505574873, 66.52886590650006, 12.811179757118227, 0.2805633386296611, 0.26441297944514985, 0.6063490312907004, 2.2160393720672977, 0.9359104955388654, 13.372070847019074, 43.716133486840036, 54.85026759486045, 52.71629425787157, 53.237808673612534, 53.54303183094148, 51.028808239967596, 52.5389168339391, 51.9193902323323, 50.97403626288138, 51.22711543113955, 50.830842295000636, 53.35601322112545, 48.03458852152671, 46.571026694390085, 42.15921532723212, 42.22047490458335, 40.65896757187382, 44.1547486089891, 44.63355625829389, 46.57816148573353, 49.824930852459325, 51.5879774093628, 51.580607275809015, 52.76455117810158, 49.91440403846003, 50.37895779455862, 47.4306062729128, 45.77879813409621, 40.91507088753485, 41.17124480585898, 39.79677569481635, 43.31298443578905, 41.03495028711135, 40.90997965105119, 41.665832150367, 40.88559819806007, 40.25179809139621, 41.17121734926778, 41.37110917798935, 39.680304834919596, 40.246581339067035, 39.086524671123875, 44.32111201747772, 53.04285903130808, 54.412107467651374, 52.668460953620176, 50.045069956010394, 56.15214540112404, 66.94994803397887, 52.368580064465924, 51.82466499267086, 46.24912561908845, 47.597216790722264, 51.86663827588482, 54.3409360608747, 55.342340700088016, 51.58732237354402, 48.78970361525013, 51.75330923449609, 52.24118540363928, 52.119482101932654, 52.8563307177636, 52.70275031366656, 47.994690172133915, 44.31258086235293, 45.163817559519124, 40.919718896189046, 39.56999209619338, 39.39852568411058, 39.320996115284586, 39.37512090129238, 37.52946138381958, 38.54275864939536, 38.99461569324617, 39.88112234300183, 40.09774308050833, 40.01616170329433, 39.22250540025773, 40.37092439589962, 40.55580923634191, 39.958710747380415, 39.01889516461281, 39.43841226639287, 37.19684047083701, 39.89932606297155, 38.23335424546273, 43.9538840324648, 49.438910791950846, 49.148137646336714, 53.5953954727419, 49.51584023814048, 51.58655358899025, 48.45694541931153, 47.855469565237726, 43.95708860889558, 41.57327205904069, 39.733684370594645, 39.27517498693159, 37.69475790762132, 39.64273245103898, 44.95026019311721, 49.310657132056456, 50.57756308586367, 52.18654286476874, 49.949866187187936, 54.4726453288909, 52.21987516649308, 52.33631464742845, 52.030997353215376, 51.489949534016276, 51.19961177149127, 33.013228677934215, 2.2983753152431983, 2.5963509130862454, 6.079119242006733, 2.100953353989509, 0.13808540248822782, 0.062185363964207714, 0.1328209535248818, 0.08935950621361695, 1.0296368791211037, 23.408722839047833, 49.32419323152112, 29.052576172736387, 22.265834385348906, 39.516114419506444, 39.21455083354827, 0.29804859070047257, 0.05118639065673755, 0.0658658265526737, 0.03144090533286574, 0.07900178297272614, 0.041445310738298206, 0.008626338676549494, 0.047338928561657674, 0.02944354749014301, 0.04395332172392838, 0.038500936070997874, 0.08161805750381562, 0.02998706580500209, 0.032203949972867005, 0.013966698334702562, 0.20193262566481868, 0.1665882246508714, 0.1106176570418381, 0.32135451753293315, 0.18618562709419959, 0.10331400459812534, 0.26664618703146137, 0.12796292186624583, 0.12433760994744879, 0.1517392037015769, 0.1564015841652309, 0.18088114237593067, 0.1785198142451625, 0.18831555070655961, 0.2432844430328377, 0.26395305089892884, 0.14128630169697348, 0.18983361521555533, 0.1408482679436284, 3.227417127739999, 54.42092887816891, 50.93254150882844, 40.74253759076519, 44.3715262413025, 53.37949252897694, 47.79921493222637, 73.04891986231651, 15.823321765468968, 0.34791046513184426, 1.5159306170478946, 10.093383193016052, 12.295125280657123, 1.7233487386857311, 18.052871496446674, 43.156458331692605, 57.7834552334201, 52.21447798513597, 55.330934447626916, 54.30382651667441, 51.521524613903416, 53.675521650621974, 56.46566437136743, 54.956920762215894, 54.34444265980875, 52.11866624893681, 54.84703556183846, 48.424832974710775, 48.55011347801455, 44.37002789589667, 44.5987295335339, 43.043713723459554, 45.05847446380123, 46.38214495874221, 49.57514255277572, 51.58813822653986, 52.95840647912795, 54.419681564454116, 54.67188604416386, 52.444454393079205, 51.67419502812048, 49.184737282414595, 48.31961931720857, 44.26230784385435, 43.636513294712195, 41.263444039129446, 44.11657610247212, 44.305908910689816, 43.67553695555657, 42.77890274601598, 42.33237228085918, 43.135916879100186, 43.755945544089045, 43.2400950308769, 42.73369350740987, 42.36590070109214, 41.641172209093654, 45.528900008047785, 55.86530639279274, 56.76091686371834, 53.46226630672332, 50.04431686093731, 58.767432781957815, 65.80481990691155, 54.18272725997433, 54.095838915917184, 48.41756482278147, 51.0126127735261, 53.4215638714452, 53.95520625575897, 57.42769233642086, 52.07377472231465, 51.156971685348026, 53.15299918574672, 53.81071398335119, 55.80035978747953, 56.11142335399505, 54.82267764306838, 48.370633663669715, 46.149799439214895, 47.3598074913025, 42.32232709084788, 42.44264971825385, 42.39846421826271, 41.79503502384309, 43.24552751356556, 41.090263551281346, 40.07943737891413, 39.75781871426491, 40.70836982419414, 42.13644204601165, 41.93793089159074, 41.65810115875737, 40.73028802871704, 43.76577892611104, 40.06446961433657, 40.03137657719274, 42.358934571666104, 38.466123380968654, 43.14767222250662, 40.40140513450869, 43.86061006976713, 51.88998030078027, 52.10184320326775, 57.7345315102608, 52.47992438654746, 54.4355240175801, 49.905798358301965, 51.78543344620736, 45.80592132383778, 42.86240608461442, 43.007678908686486, 40.715889007814475, 39.80034112930298, 42.363017759015484, 47.415438467456454, 51.43263193868822, 53.66073431507234, 54.73420466146162, 53.58891571721723, 55.84851472608505, 53.69915393091018, 53.81971974526682, 52.917166679136216, 52.057724383569536, 52.31637723984257, 35.79042365474086, 3.1920508319331757, 1.8323565538852447, 7.384961093625716, 3.643658560129904, 1.2254739576770415, 0.25339628269355147, 0.25471622154356977, 0.5915273750020612, 3.0081590865888908, 26.320886573483868, 54.10249125572943, 33.47081238223661, 30.53130776651444, 50.88580254585513, 47.37517141526746, 0.7383144791087797, 0.1632854663917134, 0.24104389632421158, 0.16563648297902078, 0.1378162604786696, 0.19347156758510298, 0.10816304238453027, 0.09450587804519361, 0.14647910611764078, 0.1603860534246891, 0.21349834698823192, 0.262883898591803, 0.1835846360171995, 0.16241891369704278, 0.0820589181216013], [0.06200657436443914, 0.0022323952937093115, 0.050498018521935716, 0.0799422248476936, 0.11092584655289689, 0.059356312342588945, 0.030380149349390023, 0.006702422810297821, 0.06686089815752161, 0.03567592173274006, 0.10805377526389015, 0.11432809665078118, 0.047234169868451935, 0.04197832790293521, 0.06291652210958062, 0.023277269398433068, 0.03337624069723872, 0.039470282443348444, 0.032333660149766554, 0.08295825937943113, 19.530646031902684, 45.58870830843526, 33.70533873957972, 31.412719257416267, 34.05847364856351, 34.29745189605221, 61.194607211697495, 19.65916837415388, 0.1800036652674598, 0.11221905659523704, 0.28588522886556966, 1.5155217099574305, 0.6833623181427679, 3.267984731543449, 25.859876678835963, 48.55578522528372, 55.48458545438705, 53.31048627053538, 51.83593003980575, 55.75258531878072, 50.60924799211564, 52.41896290932932, 56.266392277133086, 52.575453712094216, 49.079551081503595, 48.43397209721227, 46.05765119675667, 43.166852612649244, 39.433925074915734, 38.75531973377351, 38.48974781651651, 40.82540550539571, 42.07748489995157, 44.21771833973546, 44.421948309867616, 45.08439740827007, 45.49359475412677, 44.99720704170966, 45.5924855509112, 45.6066962980455, 43.26994426788823, 43.27480408453172, 41.318823983592374, 38.97440764211839, 39.50684585878926, 38.63978239797777, 40.004975103562884, 39.835924871506236, 40.48668138442501, 39.58841154652257, 41.05984164822487, 38.87632093121929, 38.527453560982984, 37.861235064844934, 37.19767201331354, 38.053493961211174, 40.091569269857104, 50.78095366877895, 52.74775951139389, 55.04671166020056, 49.41879687770721, 53.77746797377064, 48.09555392111502, 51.98498795109411, 51.59464936102591, 47.363051291435, 48.210091052516816, 48.12259866345314, 53.71562396326373, 55.39169980633644, 50.752594932433105, 48.268208811360026, 51.4554601330911, 50.766182022710005, 49.821216367906146, 49.059515614663404, 46.6090815298019, 43.31831493685323, 42.30495883572487, 39.82148270453177, 38.38600897019909, 36.16573564467892, 37.003663739850445, 36.780186699282744, 36.246363885941044, 38.02723369290752, 37.27309919172718, 36.869918761714814, 38.8593174565223, 37.35268800489364, 38.37341031720562, 37.80906361918296, 37.825431669912035, 38.28181120657152, 37.14398261039488, 37.15354927124516, 36.82146572297619, 36.082216616599794, 36.3944294375758, 37.24210462262554, 36.02325162579937, 47.245427254707586, 49.146156849399695, 48.4212165494119, 48.00491971354331, 47.481098944141024, 48.973941264613984, 47.739124221186486, 45.281198409295854, 43.26007558453468, 40.70508287798974, 37.9703083345967, 35.625123208568944, 35.56686816676971, 34.730897334314164, 40.074487347756666, 44.141322335889264, 47.35588904350035, 47.39703078423777, 46.39115464302802, 50.19355520125359, 52.02626697478756, 49.23525348786385, 49.745679363127685, 47.639570543842936, 11.522205568129017, 0.07318539064257376, 1.6102410660636042, 3.735914177471592, 0.3193428012872896, 0.33276941146581407, 0.044083763514795614, 0.06260036528410931, 0.31703062535774323, 0.30230963302235453, 26.077440746368904, 32.99465233279813, 24.032922944714947, 27.640477803445634, 45.20388849319951, 19.290638162243752, 0.023219929632520484, 0.009353366650400624, 0.07864470939121901, 0.03921198823879804, 0.05040322663262487, 0.03156484112203602, 0.06903848776053037, 0.031788385578341065, 0.042393490101300904, 0.041634867703842546, 0.04252783511014235, 0.05856246905281179, 0.05642583067979544, 0.051371328112098484, 0.007318362289468848, 0.04099278643186535, 0.011427209753873608, 0.030559580547795184, 0.19134262456528603, 0.06678173063142646, 0.05843858880501601, 0.030982137409849998, 0.04327089826185857, 0.05737794390428932, 0.039951895108266224, 0.06607026477614719, 0.09859160114560397, 0.008625338931808309, 0.01790893125167537, 0.08740379099523829, 0.031515608481582136, 0.03719731872420638, 0.0769569257634782, 0.02991466475049815, 0.11514858447856481, 27.773563823392315, 49.473462950798776, 35.1706499438132, 35.0930497723241, 45.30633687973023, 36.9765954632913, 65.9223968751969, 20.257827966443955, 0.22344924689781284, 0.13176271030979772, 0.16836242299647103, 0.46075156979983856, 0.5857055357867672, 5.137159593643681, 30.06138820802012, 49.18895383034983, 54.915539756897964, 52.124902817510794, 54.41632401558661, 54.82564295491865, 53.80537955991684, 55.39832468955748, 56.462451950196304, 54.65817736041162, 52.06521611059866, 49.51961748061642, 48.7342805247153, 45.472060941880756, 41.94739557081654, 41.54780803188201, 40.41826348150931, 42.18870370618759, 45.37735531407018, 45.64950896847633, 45.747474085900095, 49.21302933846751, 46.915783420685806, 49.37134012099236, 47.28250149757632, 48.996757691906346, 47.315457251764116, 45.25847611888763, 42.96621945596511, 40.13589205280427, 39.94346057215045, 42.344704212680945, 42.996409939181426, 40.687722467607074, 42.231712495127034, 41.28622908746043, 41.52285783521591, 39.892873764038086, 40.05194548637637, 41.13493150280368, 40.79055916878485, 40.35619589590257, 42.49115767017488, 52.103027759059785, 53.19944789332729, 56.74361528888826, 49.711754783507324, 55.37166433949625, 54.42363139121763, 53.28117439823767, 54.345270279915106, 49.46132713748563, 49.87924783460556, 51.577273261162546, 54.446659626499304, 55.69204745754119, 52.096928473441835, 50.944928353832616, 51.357808805281124, 52.30585744304042, 51.5520602656949, 51.606224275404415, 46.15970734627017, 46.56510391542989, 45.75076495447467, 41.8239232801622, 39.068269960341915, 37.32593744031845, 39.18884361943891, 37.283352267357614, 39.00716727779758, 38.47121461745232, 38.725470496762185, 39.44869672098468, 40.07333809329618, 39.46490787690686, 39.64129686355591, 39.0499524916372, 38.75476667957921, 40.1185747884935, 39.63332268499559, 39.43550579009518, 39.44147171512727, 38.23597046636766, 38.19782933881206, 40.9168634107036, 38.71938297825475, 48.5931928696171, 51.11320587896532, 50.85973055131974, 49.378922062535445, 49.405237244021514, 51.741185188293464, 50.76296567916871, 47.053595896690126, 45.96654630476429, 41.92106469984978, 40.208142111378336, 37.8432745318259, 38.16647391165457, 37.954097178674516, 42.37147831147717, 46.705414941233975, 47.99042263338643, 49.08371271625642, 50.26859014264999, 51.728845411731356, 54.34852192478796, 49.01161563011908, 50.232316063296416, 47.85488120971188, 14.141908557184282, 0.5688212643707953, 4.93779924608046, 9.438763145477543, 1.5860119726388686, 0.09315230793529942, 0.2202851658747081, 0.05939229166195278, 0.2440413379020268, 2.423772263911463, 30.575916882484194, 41.28460522620909, 26.85767665986092, 27.17103285174216, 51.33748308304818, 24.50156577171818, 0.05796368707031493, 0.0026654114105528403, 0.01851321566068838, 0.05450631311583904, 0.027518177014445106, 0.03994512289101559, 0.031795533178674604, 0.010400424981790205, 0.04442959092557431, 0.05160600765638294, 0.008113169892420693, 0.04234627227208788, 0.024967403000881596, 0.06250240179079194, 0.03172710620527787, 0.2229314021045162, 0.10070762026213831, 0.12780422675273112, 0.2353243145250505, 0.1493415630031978, 0.09639323523808872, 0.1286615557487934, 0.11061324437539424, 0.1445669813021537, 0.15466276375997454, 0.18516722045117812, 0.3195757839468218, 0.13038061108560334, 0.1626427033014836, 0.27645542196208434, 0.08145405340098566, 0.15657113474463263, 0.19834885103327615, 0.14403232853979836, 0.19218191985161076, 29.81224906060004, 58.03019585147981, 45.91675966016708, 41.62180746755293, 46.80554520699286, 42.581211366961085, 71.07944288561421, 24.118969940370132, 0.3952417060011818, 0.5717092319842308, 1.3323466551880683, 6.069365778276998, 2.370745496403787, 6.301281798270441, 31.314648235997847, 50.522900935142275, 54.367286543692316, 52.46838869587068, 53.00767537086241, 56.757720132027906, 55.768921990548414, 54.86771429738691, 58.36464066659251, 57.41512898475894, 54.44060348695325, 53.83770773487707, 50.31171660269461, 48.42733936925089, 43.458696565320416, 44.90356437621578, 42.033036601158884, 44.597756785731164, 46.52683727202877, 49.942323469346576, 47.93471320982903, 51.35478465787826, 50.480217702927135, 48.71240938863447, 49.66087772000221, 50.27790184943907, 49.18836547482399, 46.93803110430318, 46.84480813241775, 42.20100425904797, 41.84244471211588, 43.87457762995074, 43.56720501376737, 44.10955505986368, 44.51064878894437, 43.516053384350194, 44.76611668063749, 43.08918576086722, 42.243726714964836, 42.14205888009841, 40.58763927029025, 42.66200042540028, 44.70403732792024, 55.30835728491507, 56.962581603757805, 59.47141585811492, 52.60662478785361, 54.285312929461085, 51.793439003729056, 54.41726930679814, 56.47556835605253, 51.17863101343955, 52.50750649359919, 54.75833508276171, 57.16932581317041, 60.03173035960044, 53.10251828162901, 51.429670549208126, 54.044424487698464, 53.03748146180184, 54.209870061566754, 54.13700811324581, 48.926923813358435, 48.72683586612825, 47.51492938687725, 43.50035998129076, 41.78425635060957, 38.97125797887003, 40.74431442445324, 40.36482903265184, 40.7756620068704, 41.65432391628143, 41.26902949425482, 40.45149380160917, 43.53244104693013, 40.5832540604376, 41.77658027218234, 41.18200386724165, 40.92343338074223, 42.023658214076875, 40.06349294416366, 41.01530313491821, 41.074362262602776, 40.347150910285215, 40.91708306343325, 42.70407176786854, 40.11222447118452, 51.6770818925673, 53.378268749483176, 51.95354230942265, 51.04606274635562, 51.04901629109537, 52.43228720080469, 52.82058615838328, 48.54509676656416, 47.07691046499437, 44.48833050266389, 42.12021912297895, 39.60566213054042, 40.59256968959686, 39.04987796660393, 45.15145424873599, 47.743152495353456, 51.37824827624906, 51.10954238522438, 52.89405215171076, 55.01764297485352, 57.50403342708465, 50.370720817196755, 50.14802040592317, 48.3763171780494, 16.524298344888997, 0.37098184648540716, 3.4963625284933277, 7.335713774927202, 1.8622339829321832, 0.9322162969939171, 0.5134235466680219, 0.26296424589330153, 1.3215536407886015, 3.862210084353724, 33.86592057443435, 45.4829494414791, 35.852997226099816, 37.6758599281311, 56.24008494038736, 31.404566611013106, 0.28409184767834605, 0.05686426279886116, 0.31529666194992684, 0.10462755427485514, 0.23680785911217814, 0.08498282291956487, 0.2041127127144606, 0.2863502442356079, 0.2282790175729221, 0.1606731831787094, 0.1383012401000146, 0.11093462592050915, 0.08560933728492068, 0.17586286810617294, 0.06028658056992197], [0.027966767459386782, 0.05044149272444268, 0.046547452483566544, 0.036755638392341715, 0.010834226099353646, 0.027165631012570475, 0.02028543558422356, 0.04158007326505838, 0.04565266178800695, 0.055754247361854206, 0.02408204859332933, 0.040025887710432854, 0.01196833021352969, 0.07660732153923282, 0.04719441756606103, 0.038332232018752445, 0.03919105105582745, 0.05320414367522444, 0.0694401783027476, 0.1714914171926437, 4.590973959815118, 45.538415678085826, 39.563088724690104, 25.319638829077444, 36.98589540296985, 32.47362036858836, 55.919242905032256, 23.111405218801192, 0.3516833562283747, 0.07021520647310442, 0.20400798849521146, 0.22197670333327787, 0.8405242752163642, 0.7569929897304505, 7.854782592865729, 32.84088561611791, 48.31461045049852, 54.27229850522934, 52.903473684864665, 57.299697552957845, 56.2154406885947, 52.08777758382982, 48.9632135821927, 49.42382535626812, 46.93572867301203, 45.70387301906463, 40.048336905817834, 38.235127156780614, 37.98231470969416, 39.63739018286429, 37.69664849004438, 37.12629664328791, 39.151082961790024, 38.57641650784401, 40.4576950688516, 40.61045177521245, 41.76295003583355, 42.118501124843476, 43.01985394570136, 41.85434518321868, 43.51256639726701, 42.954570016553326, 41.10407421665807, 40.650671758959376, 37.884012268435576, 40.716818609545314, 39.69836734956311, 43.02603167872275, 39.015439556490996, 39.31619905656384, 39.30625192580685, 38.296437724944084, 39.75290006206882, 38.21215383468136, 37.517215744141616, 37.217079900926166, 39.11079629775017, 47.48773951684275, 52.04046203244118, 52.4607636082557, 53.437778949737556, 48.67468403231714, 36.50271431092293, 50.148365574498335, 54.305371930522305, 50.88453562028947, 50.61433530622914, 51.15999583275088, 52.35824461906187, 54.19956991749426, 52.11844267383699, 46.17651862482871, 52.60959009970389, 51.99525279383506, 51.363002023389264, 45.52725261257541, 45.86047364819435, 40.68960520528978, 40.647306365351525, 38.269322379942864, 38.5830335463247, 36.863639047068936, 36.54800199693249, 37.11261541612687, 37.34177989344443, 37.826808421842514, 36.51944321970786, 39.89653725777903, 37.51627829767043, 38.67491898998138, 37.066131407214755, 39.13429521745251, 38.99116400749453, 38.42136913730253, 38.223124704053326, 38.37151581241239, 36.7027904910426, 36.79355021445982, 36.36635703425254, 36.56818259146906, 38.518553703062, 41.47086681858186, 49.74117648216986, 48.71933629435878, 49.74147850467313, 48.61274196255592, 48.27051908739152, 50.884272821487926, 47.71174215501355, 44.69951091274139, 45.35678248251639, 42.66287119157853, 38.49039500759494, 36.157749699008086, 34.189935807258856, 36.60995583380423, 35.974069026208696, 40.54112780478693, 40.91516894678916, 46.27233820576822, 46.85417867475941, 51.45548366731214, 50.384531482573486, 51.74363666965116, 29.118503370592673, 2.0141148975779934, 0.6130082965377839, 8.93771271551809, 11.59340148971927, 0.7931972018653347, 0.18935833426733173, 0.05808106706207318, 0.10250749787495983, 0.3382557654573072, 2.633587444020856, 29.12923497538413, 27.92823268521217, 17.269085837948708, 22.246051911384832, 40.44858340294131, 5.734242393124489, 0.1447845962379248, 0.09748583749657679, 0.01995419448752317, 0.0775001970149817, 0.05336330227193333, 0.05423292697918031, 0.018311389797036687, 0.06329728696014612, 0.04239063259334334, 0.024987574095927903, 0.06594540010536871, 0.04051079838386467, 0.0850233489707593, 0.020430320047683293, 0.02945357175063222, 0.05176176482270803, 0.036828646571525646, 0.10299930333971016, 0.057672979685688214, 0.017715342748429508, 0.020752490663360205, 0.05946479039266706, 0.050465138028225595, 0.08025978361406634, 0.04534144239920763, 0.03492659198180322, 0.016925935107733936, 0.031018656821200447, 0.05140808501070546, 0.012713600656077748, 0.03314877387076136, 0.012393302167765798, 0.03540985556619783, 0.07124385571167355, 0.1577812012645506, 8.22728910753804, 53.590304236258234, 44.94864025423604, 26.488158010667373, 39.3170698227421, 38.948978916291274, 60.7359330884872, 26.923927453256425, 0.4579747462224576, 0.2100353997441069, 0.3135616873060504, 0.052670015683097225, 0.6445308534368392, 0.9126695329623838, 9.071722453640355, 37.096580766862445, 50.15126812842585, 55.242528146313084, 52.44260303435787, 56.78385488448605, 57.06068792650777, 53.44729461977559, 50.71526573550317, 52.03852045920588, 49.95505940529608, 49.280082256563254, 43.07226465594384, 40.59666464405675, 39.675178297104374, 41.51366772190217, 40.26922125970164, 40.38286801307432, 41.02537578152072, 41.596959252511304, 42.58244691356536, 41.03383241161224, 43.99865396561162, 44.04690696347145, 45.20664591943064, 43.30049953153057, 45.77587989068801, 45.6443981201418, 43.43735102684268, 42.92012768407022, 39.250597415431855, 41.32572343272548, 40.85265813335296, 42.44653286472444, 41.34257393498575, 40.747781799685576, 40.95525556995023, 41.35387428345219, 40.283753641190074, 39.630533879803075, 39.49998955572806, 40.05805261673466, 40.672480137117454, 50.447858149005526, 54.43770485539591, 54.84804753334292, 53.98574975229079, 49.999750891039454, 40.56502288387668, 51.74040463662917, 55.16868560544906, 52.790227013249556, 51.79210932024064, 52.98729473544706, 52.875001199783824, 54.93812084197999, 54.77446779128044, 52.03442550474598, 53.06251402824156, 54.59414074497839, 53.28701088505407, 48.196421592466294, 48.547359974153586, 43.11049992038358, 43.60964113666166, 42.026705895700765, 40.456832147413685, 39.029293367939616, 38.76508643550258, 39.54674813055223, 40.039566486112534, 39.602081006573094, 39.27763431302963, 40.39935765727874, 38.42826466406546, 41.2955839403214, 39.346009069873446, 42.833784549467026, 39.85212818268807, 39.15093391172348, 39.72396081493747, 39.056075311476185, 38.6767860381834, 39.0433079965653, 38.0685793968939, 37.38257646560669, 39.726306392300515, 44.48791080905546, 52.11148831152147, 50.95687589337749, 52.61083349104851, 50.247899639991026, 50.86382158340947, 52.57115087201519, 48.964456973537324, 48.0480775525493, 48.03718513058078, 44.48690275992117, 40.23917198181152, 38.165756117913034, 36.16746148755474, 37.57631801789807, 38.77200941885672, 42.617869838591545, 44.59464242381435, 49.53949213027955, 49.260525318884085, 52.745158979969645, 52.510664001587905, 50.7206589944901, 34.17425809368011, 2.3972749373605176, 1.1570184245224924, 12.791289417974411, 11.207233359736781, 3.165010992557772, 0.1630461098806512, 0.056443967811402776, 0.06499243269283926, 0.9157477355291768, 3.2686750686937764, 33.735156597629675, 36.887102665439734, 20.53692617724019, 23.837881126711448, 47.41303405454082, 8.74496058110268, 0.14932383572862995, 0.07892904292431571, 0.03224203603402261, 0.042819484782915924, 0.018627448946297653, 0.029900199095267924, 0.022536805199999965, 0.047566115766042666, 0.03796633693479723, 0.04114258343413953, 0.03797757544464642, 0.05495599906651243, 0.035762884203464754, 0.05665987820154237, 0.06622008093061947, 0.1942603010684252, 0.145537139727704, 0.2759880163977223, 0.1302363873729783, 0.07887072831151948, 0.17132395037239598, 0.13311519257483945, 0.12058066880150188, 0.1863317200613599, 0.17947694917600002, 0.09748993606697168, 0.11208283850142073, 0.07034741792707674, 0.15803013387466633, 0.2695673722172937, 0.14923492356413795, 0.1623647053155207, 0.1012164022352907, 0.20942809120301278, 0.23941484099674612, 9.322965952657885, 60.40936047031034, 50.31995358005647, 34.64448751941804, 46.41072727018788, 41.214206526356364, 65.41463821165024, 30.05499278345416, 0.5331192994790693, 0.6563032959257403, 0.5744822864090243, 0.36041948583818256, 2.6800400739715946, 2.1221446942898536, 11.070324009464635, 40.42652791546237, 48.84011391670474, 57.09152167843234, 52.49544912768949, 59.94891343578216, 60.392466821978175, 56.52275446922549, 53.24308033912413, 53.151214507318315, 51.13790112157022, 50.95287507580173, 43.93246396895378, 41.6197011547704, 41.05372667312622, 46.42216882398052, 41.238027080412834, 41.57815148753505, 43.69646280042587, 44.07135117438532, 43.63889417340679, 43.04892263104839, 45.817570763249556, 44.86158324826149, 47.55414916623024, 45.30775677773261, 49.321427960549634, 48.359148963805175, 46.75051435347527, 44.525749914107784, 40.962598246912805, 43.91986923833048, 43.86985901863345, 45.20628898374496, 42.66075311168548, 42.75755720753824, 41.84625333355319, 43.41427572311894, 44.16899857982513, 41.90849742581768, 40.816034963054044, 42.70706845868019, 41.361503293437345, 53.122043840346805, 55.07221098869078, 55.78099896830898, 57.47194451670493, 48.76498091605402, 41.03783715155817, 52.34412408644154, 57.06954463835686, 54.88702412574522, 54.14603740938249, 54.803952247865745, 54.84266211909633, 57.745008160991055, 55.15645565525178, 50.39317638643327, 55.71795863489951, 56.483577835944395, 56.555192470550544, 48.605536568549375, 50.18213718168197, 42.917256509104085, 45.667065497367616, 43.140482517980764, 41.97258895443332, 41.84166023808141, 40.556668235409646, 41.47807221258841, 42.396475576585345, 41.61440987740794, 41.45850743016889, 42.60003482141803, 40.34122028658467, 45.112112875907656, 40.812089058660696, 43.46444283762286, 41.83696908335532, 41.59996771043347, 40.55578570212088, 41.411474289432654, 40.355925252360684, 41.02408139936386, 39.8886219147713, 38.70913382499449, 43.62001188339726, 46.946985875406575, 54.895319938659675, 51.88586573446951, 54.24669327274446, 52.75023452697262, 52.259965712024325, 53.72022490347586, 51.52387411363664, 49.2628748186173, 50.991118184981815, 46.857328338007775, 42.48708624993601, 40.91006986556515, 37.95761554471908, 39.62153596262778, 40.25409660031719, 44.57981194219282, 45.350922461478945, 51.051040234104285, 51.264232820080174, 55.26161439957158, 53.34848619276478, 52.16641718341459, 35.536975783686486, 3.3803498504623293, 0.8940320846534545, 16.97059739020563, 23.415771338247485, 4.524587354352398, 0.2915838504991224, 0.2662357171216319, 0.34423397853970533, 2.2039182676422984, 7.548389588632892, 38.18633679420718, 41.73870586579846, 28.07835355881722, 31.53469712503495, 55.47905491244409, 10.734764260630454, 0.23799036178858052, 0.18511488132419127, 0.22427318978213498, 0.189939365992623, 0.13373164820574945, 0.14768295200361362, 0.1678683116070686, 0.1789798653654514, 0.1726975460206309, 0.13139789924025536, 0.16433260133189542, 0.14936194094198366, 0.14058228221631822, 0.0861755375479979, 0.15423668097824822], [0.04054509997067433, 0.00613501308591015, 0.005406361484464499, 0.02020273064713805, 0.04331800117788296, 0.008933817641058517, 0.025185368421878067, 0.036354863325194005, 0.08996712885076001, 0.023934605396202496, 0.03007029742753554, 0.03516401795129623, 0.09758758163380046, 0.007230380442999905, 0.07178371021103475, 0.06752213928848505, 0.046484491547509554, 0.0351637804640397, 0.092557578557922, 0.1279838743709749, 0.4504070232712454, 26.11276561214078, 44.98648328165854, 32.20018802150604, 36.99405785529844, 32.48973542644132, 47.22958087921143, 22.305652326153172, 0.21168213638086475, 0.24635322271816193, 0.2630775656190611, 0.1657345115898117, 0.18707664863717172, 0.14509441751626231, 0.6246943855958601, 11.083696349974602, 37.95756847627702, 53.523443514300936, 55.11546296458091, 55.4227061425486, 51.111601629564845, 50.29081821441651, 47.514686199926565, 45.08038874595396, 42.24887678700109, 39.63352272587438, 39.41501925068517, 38.6186957359314, 38.90023169978973, 38.556992930750695, 37.96129080557054, 38.441130038230654, 39.34637777266964, 39.01666333598476, 37.61481215876918, 37.750769353681996, 38.70065758305211, 38.1054182975523, 39.155609376968876, 40.18949124120897, 41.59089134585473, 41.8014245648538, 41.73458737711753, 39.47693386385518, 39.74495726246988, 37.89994493607552, 39.36830774430306, 38.66033561768071, 39.74096821200463, 41.30087914005403, 41.011282705491595, 38.93270108007616, 39.777418798015965, 38.01076366055397, 35.98142739265196, 35.54891940086119, 39.98461407999839, 45.03239070215533, 51.159419244335545, 50.244836268886445, 54.75610717650383, 49.87768673127698, 42.322385926400464, 52.95551176994078, 51.687895867132376, 55.82333310957878, 50.51096908507809, 50.07704904002529, 50.50936091330744, 53.884870313829, 49.02862694955642, 49.88926164565548, 52.83111772229595, 50.30822961561142, 48.50618293208461, 44.430299035964474, 44.25279217381632, 40.88322908647599, 39.07916630468061, 38.177680123236875, 38.884389246663744, 37.503691411787464, 37.86366693435177, 37.20725044127434, 36.46690307124969, 37.5679123786188, 36.683935657624275, 37.16015062024517, 37.57226620951007, 38.25169917075865, 37.369707169071326, 37.04467604237218, 37.89028021597093, 38.68439543631769, 37.42336127065843, 37.05232074183803, 36.95740330603815, 36.76920798517043, 37.773997629842455, 35.70396677140267, 36.02760545669064, 36.2786881385311, 40.57236948320943, 46.83430010272611, 47.670686706419914, 45.798998340483635, 48.970834747437515, 47.51712199180357, 49.87260726190383, 47.491026463047156, 46.552018888535045, 44.66866147133612, 40.318360713220414, 39.46393120673395, 38.25156973254296, 38.51217592916181, 36.68239024377639, 39.24944423860119, 37.07263469696045, 42.36525743238388, 47.32293721168272, 50.207165825751524, 50.236312958502005, 48.63211062646682, 10.654655733416158, 0.01336318958971289, 1.666580520329937, 8.723777820987086, 8.332712611844464, 1.8993434045583972, 0.12774450253815423, 0.07731815154153494, 0.20471384658688502, 0.5417065322399139, 9.76258029860835, 33.852698264583466, 27.925069293668194, 26.614593651986894, 30.64871607288238, 29.85699545952582, 0.8726114695591312, 0.10855080544828408, 0.06014973811444737, 0.06769454737584438, 0.029411747180406126, 0.04905992593135565, 0.02671546242650478, 0.08160010806374973, 0.06260246436502184, 0.005833637926937832, 0.029550173522664175, 0.01621759297596591, 0.04838677596360926, 0.00914649322493783, 0.047155561586541515, 0.04208638077421535, 0.03377762863472585, 0.012369569721481493, 0.006611446996459798, 0.03453620506690876, 0.06514545109483504, 0.051164756333755876, 0.049272580447817044, 0.014027218323110813, 0.07474835556481155, 0.058957801065257484, 0.05393024180985747, 0.046467503547788634, 0.04735944056583028, 0.025527606710731506, 0.04611468558470088, 0.05568626088901393, 0.07874374157719075, 0.04088157344789755, 0.07177565096607132, 0.06813642689056935, 0.991468723983534, 35.11410897777927, 50.00332417026643, 31.447210619526526, 40.55883730611494, 36.607359224750155, 52.71188159142771, 24.84668531725484, 0.1818304325664236, 0.35774023121883797, 0.655796758590206, 0.08138394103415551, 0.4910542389317867, 0.15054701767381162, 1.3519594866421916, 14.597471260255384, 42.1484641105898, 54.6971853317753, 54.250105734794374, 57.98762244562949, 54.59729433059693, 54.58597437027962, 49.331249575461115, 46.73203998996366, 44.85902978527931, 42.41141196220152, 40.257461993925034, 40.733508294628514, 40.62535678186725, 40.459079665522424, 39.42301696346652, 39.047124462742964, 39.66139508831886, 40.793395042419434, 39.315489107562655, 41.59331144825105, 39.8809144573827, 41.21950564845916, 41.382182028985795, 43.55418274479528, 43.987106507824315, 44.00318430316064, 44.19401153441399, 41.6090872210841, 40.24990750897316, 40.89617290804463, 40.87823198687646, 40.5756328951928, 41.34062059463994, 41.46926649155156, 40.9817119567625, 41.48487752483737, 41.60837727208292, 40.10813343909479, 39.423444501815304, 38.05325469663067, 41.11475483063729, 47.01398780269008, 52.333329723727324, 51.43883320593065, 55.24906281502017, 52.8119687111147, 44.335860129325624, 52.98321939283802, 53.752164763789025, 55.43184918742026, 52.49496275378812, 52.65332452712521, 53.37295001552951, 55.499019776621175, 50.90658718539823, 52.650351370534594, 53.83772734672793, 52.716223655208466, 50.064128752677675, 47.238229705441384, 44.71745967864991, 42.922924334003085, 41.22526368787212, 40.70223523724464, 40.68705958704795, 38.04040893431633, 39.32735427733391, 39.20807500039378, 38.104727960401966, 38.0595265665362, 38.87701911310996, 39.20706695125949, 39.33523431901009, 39.211711037543516, 39.26967582395, 40.11810410407282, 40.56395207681964, 40.43534148123957, 39.54760712961997, 39.113208555406146, 38.67680565003426, 37.71432661241101, 38.593874977480986, 38.32156835063812, 37.95354804685039, 37.77963407578007, 44.070111705410866, 49.435168850806456, 50.10374861378824, 49.049286073254, 49.15212277443179, 49.64033234503962, 50.66950344270276, 49.22967587747882, 49.28207482061079, 46.21741717861545, 44.01737151607391, 40.7649500139298, 39.161826333692, 39.304114234062936, 37.67205130669379, 39.59678972921064, 39.40908470461446, 45.198240280151374, 49.378906373054754, 52.03151118370795, 51.47191839833414, 50.88930914478918, 12.110362033690176, 0.41184917452835273, 4.202700007346369, 12.392368681969183, 11.345459645794286, 4.289008821210554, 0.13931042304442776, 0.03224770891510191, 0.5202359069258936, 1.3962380203508562, 12.1778356259869, 37.99416418998472, 33.604318095791726, 25.678198376009544, 35.34685457906416, 39.62808239844538, 1.0837288152786995, 0.025205083694609425, 0.022850010671742985, 0.04524342144929594, 0.03863969374628317, 0.06966595207491229, 0.024136153552981637, 0.06601132963213228, 0.025801889170261643, 0.040056642310153094, 0.03119076996470892, 0.007666603356013976, 0.024426820717992324, 0.013584518136696951, 0.04303255681729606, 0.02027254040923811, 0.14352592910009046, 0.22079662149471624, 0.10830875230772842, 0.11216302492445517, 0.11777410569090037, 0.10503060079269833, 0.177844247270015, 0.1239934143039488, 0.3175254875133115, 0.17108382777340952, 0.18913183271163897, 0.12661794726286205, 0.1612300218473519, 0.20886045069463793, 0.20493576693679058, 0.15481326939357867, 0.18833962118914052, 0.18031057541168508, 0.17399205075156304, 0.2284794108521554, 1.1025440572730958, 37.932367247919885, 59.272308503427816, 41.52953763161936, 47.098059884963504, 41.21375545378655, 55.00636223823794, 29.37320051654693, 0.3562287397442326, 1.3740065165104405, 1.491542912779316, 0.430142741289831, 0.82648727682329, 0.6524669727490795, 1.5118560098832654, 15.449830735883406, 42.64501264018398, 54.440293619709635, 57.13607195884951, 58.77326534640405, 55.82266630664949, 55.68730923437304, 49.88839087947723, 49.705102443695075, 48.80521658928164, 44.117305663324174, 41.95606400889736, 41.321208784657145, 42.495617405060806, 43.88111229865782, 41.16875017842939, 42.37813065128942, 43.93014977055211, 43.8346714358176, 41.150915161255874, 42.42770156552715, 41.567631690732895, 43.256757259368904, 42.082509456142304, 45.70219424463088, 47.16742307909074, 45.48513812403525, 46.37152710268575, 43.3735889773215, 43.24881445976996, 42.72530747998146, 43.80415539587698, 41.3522151208693, 42.26236974039386, 45.51529330592002, 42.79029330899639, 43.78534763090072, 44.310862864217455, 41.56912219139838, 40.46921114767752, 39.38142415015928, 43.7589696914919, 50.3319638775241, 54.65495317212997, 54.14537452882337, 57.68818478430472, 53.19980482901297, 44.76470070500528, 54.77194570725965, 55.10326831571518, 58.37942800214214, 56.27907329990018, 54.15148950392201, 53.674325327719416, 57.97458448717671, 49.516448205517186, 54.16572770764751, 57.41105756452007, 53.707751766327895, 51.730841898149066, 48.747981363727206, 48.668741641506074, 44.92345863772977, 43.82058228215864, 41.54681567222842, 43.63345384597779, 41.74556216885967, 41.87588684020504, 41.26740955537365, 39.599135306573686, 39.69448812546269, 39.90442514419556, 40.0600451807822, 40.487552150603264, 40.97669524531211, 41.731704435040875, 40.81923561711466, 42.54386648055046, 41.833180073768865, 41.76968866778959, 40.60481140690465, 41.43213341313024, 39.03793434942923, 40.779180372914965, 39.26401584379135, 40.40085600268456, 39.54229231803648, 45.4030115373673, 50.17328439220306, 51.48441114733296, 48.71428035920667, 52.13506960099744, 50.51597402941797, 52.04200352391889, 50.86048364639283, 50.43753054834182, 48.148796173834036, 45.40229374362577, 42.69513268624583, 42.10719293163669, 42.60610665044477, 42.16619714613884, 42.71125755002422, 40.05939406733359, 46.45666606964604, 51.67185729549777, 54.89844606768701, 55.421396070911044, 50.22389865690663, 14.492205631348396, 0.3859831350705316, 6.19103083687444, 17.705729969086185, 18.173517719391857, 6.86278477791817, 0.3396515470118292, 0.16272055315634898, 1.0402115891056678, 3.0148018656238436, 17.692760652111424, 43.629347124407374, 39.53928386011432, 34.72698280888219, 43.600678520817915, 44.305230340650006, 1.3294726610183718, 0.20762213085207248, 0.15300945408882635, 0.13596522351426465, 0.17055974702440924, 0.19476832461453256, 0.22419321020284008, 0.18125900758370278, 0.1624156961277608, 0.2571639184269213, 0.12094058456920809, 0.12376741836628607, 0.17454945632526953, 0.07686822810360501, 0.09293024968956748, 0.16561530830879367], [0.009136011226913862, 0.001467515394324437, 0.039248775780921986, 0.049566133849082455, 0.04575903309629329, 0.035248142066261465, 0.04774505475295648, 0.04345147284649072, 0.025850771325490168, 0.08341784318608624, 0.0511025499943043, 0.023984357061225082, 0.053946448399895625, 0.03855328285886395, 0.09404188923297391, 0.06598361257103182, 0.029584858153435974, 0.03967526841968779, 0.05549028793710375, 0.024108773570567853, 0.024236336786059604, 7.347078842501487, 42.753521088630926, 34.416601734776656, 28.058125895838586, 35.149163200009255, 39.28790307814075, 34.64316960304014, 0.19751004604322298, 0.36180147781006755, 0.19463664942210723, 0.07279656271660521, 0.06821498920720431, 0.24518426447626085, 0.4095371518163912, 1.2929522077883444, 14.995373160608354, 43.21689028893748, 58.07068647876863, 54.79269896784137, 55.85157809718963, 48.794245719909675, 45.19924832928566, 42.25029276263329, 41.88078588055026, 39.733064636107414, 39.910312621824204, 39.229236187473425, 41.226522768697436, 41.28864918985675, 45.61041862733903, 46.74047308583414, 51.009176777255156, 48.9237976843311, 46.376147654748735, 41.35783587732623, 40.14267383083221, 38.65145144924041, 39.71939125368672, 40.2056396392084, 42.62820136162543, 42.83161940113191, 43.585918641859486, 39.4567415022081, 40.54732907202936, 38.67418550675915, 38.55404330838112, 41.355404007819395, 39.753406047821045, 40.6912604455025, 40.520099978293146, 40.45659680520335, 38.752162225784794, 36.76971789329283, 36.93206087235482, 36.25261222162555, 39.82923723036244, 44.41046361000308, 49.025657715335974, 50.914620199511134, 54.90381971482308, 49.07886074435327, 45.727823011336795, 51.79553354940107, 49.9026486950536, 53.280095746440274, 51.94827456628123, 54.019282094893924, 52.37209450814032, 53.761005786157426, 48.844648176623934, 51.337694891037486, 52.92054383985458, 50.494251943403675, 48.028583372792895, 44.342920395635794, 40.733504372258345, 39.02397071161578, 38.361274503892474, 37.457427055605, 38.320501465951246, 36.88219578035417, 38.99459608139531, 36.71179625295824, 35.28270029252575, 36.940372374749955, 36.81368374055432, 36.64149168998965, 37.48560928529309, 39.740124902417584, 37.39450439330071, 38.03434495002993, 37.246266257378366, 37.6974251193385, 38.941546024814734, 37.05285810655163, 37.54846134493428, 36.395457098560954, 36.371656156355336, 36.16364894374725, 37.244203090667725, 35.41304849809216, 37.93847045590801, 45.231580426616055, 46.11034431765157, 48.74246651126493, 47.31078963125906, 48.30943684424124, 46.20498326516921, 47.84844852262928, 44.836703654258486, 46.199307595529866, 44.95391584211781, 43.19015541384297, 41.59807712801042, 41.55893579606087, 36.69982125682216, 37.53025762496456, 38.7937040482798, 42.64833096534976, 47.860141108112956, 47.93074769358481, 53.53668935837285, 36.97863901815107, 2.1176476968872935, 0.06536096694969362, 1.5429811203672041, 12.941632886086742, 6.507621513259027, 3.764751688126595, 0.4153625150361369, 0.059921340491142006, 0.16861278053012588, 0.07941011549724687, 18.055691680600567, 34.95160518154022, 33.92066509492936, 35.68342531881025, 29.91718815219018, 11.199298404878187, 0.007666665600657824, 0.06294102926227836, 0.08682154119014741, 0.045919145472467914, 0.017721103729620095, 0.04127129769673751, 0.03553174781583009, 0.08780983291686544, 0.11420613545323573, 0.0961582224455572, 0.0693014397796604, 0.01576963455356177, 0.06868008884691423, 0.03618772975319336, 0.027743707553693847, 0.08268739367204328, 0.02681004364163645, 0.06026118858567169, 0.011318289288019222, 0.06265661912038922, 0.027987390546308413, 0.06446542548796823, 0.028177349708013, 0.015313454092510287, 0.06511041789405769, 0.09092893691793566, 0.030767525538742065, 0.017801971970907143, 0.013907589863294796, 0.07334167257912698, 0.037956216913317485, 0.07724047788689214, 0.058854819696036086, 0.08034652008885339, 0.04306901877205219, 0.023579330206097617, 0.052049396364318753, 12.533692659870272, 50.66946029663087, 36.92039966583252, 32.199291759921664, 45.38343498783727, 44.05778369595928, 37.65822887420654, 0.3045020847310943, 0.7980934230069961, 0.8165461521956229, 0.07372470888038797, 0.09415631978622369, 0.4001616452249789, 0.2649031837861384, 1.8090281347113273, 17.809680623392907, 45.958983975072066, 57.30418474443498, 56.65566790488459, 56.92183994477796, 51.284946856960175, 45.33551146907192, 43.796538153002345, 41.90837583234234, 41.350093118606075, 40.68869521540981, 40.37108521307669, 42.59085255284464, 42.539657777355565, 46.40578900614093, 48.01341948970672, 51.530781407510084, 51.35446302352413, 47.58290406196348, 41.69231599377048, 40.738317120459776, 41.235669735939275, 41.07968491892661, 42.23790591762912, 44.01872473378336, 44.14842182590116, 45.21957797388877, 41.04183012439359, 41.69262586101409, 40.35083401587702, 40.272021832004675, 42.962571651704856, 42.95914742254442, 41.075358544626546, 42.02933780608639, 42.151805969976614, 40.893568454250214, 37.838657902133086, 38.39266915475169, 37.449868648282944, 41.08274829003119, 45.71244339789114, 49.73900741146457, 51.99311117972098, 55.951810344573, 52.69656473590482, 45.89187222142374, 52.94621575263239, 53.494920038407855, 55.95701140742148, 54.308188192306034, 53.85811190451346, 54.75347134374804, 55.681688477916104, 50.7190586674598, 52.769920902867476, 54.738025050009455, 50.10565488569198, 49.61357785809425, 47.93547807201263, 42.83356097436721, 41.115488313859515, 40.46198614182011, 39.93512945790445, 38.6356835211477, 40.32368729191442, 39.3467660873167, 38.44105159082721, 39.020828893107755, 39.99236468345889, 38.50608841065438, 39.31727770836123, 38.29291935889952, 40.93570255464123, 39.02267632945892, 40.411669977249645, 39.78134901292863, 39.17713534447455, 38.815892896344586, 39.278638439793745, 38.967292462625814, 38.53706729027533, 39.36260461807251, 38.71540177252985, 39.32015280569754, 38.53166618654805, 38.67119273831768, 46.08292302777691, 47.689063010677216, 50.888677643191436, 49.62119902333906, 50.0551426026129, 48.904891860100534, 49.47844828328779, 45.90544362221995, 47.97235619637274, 46.262826458100356, 45.21570267215852, 42.240502526683194, 43.36848989609749, 39.06917210548155, 39.46318987877139, 39.40699408131261, 45.5356700189652, 48.99769121600736, 50.871085812968595, 52.49629243727654, 40.110624144154215, 2.519444020525102, 0.46078451158058265, 6.79387265636075, 10.293529975798823, 9.752895966652902, 4.5080246560035215, 0.3083231474363035, 0.09456422330150682, 0.4957312669965529, 0.7267296975178104, 19.976366527618904, 40.751476672387895, 36.20962304453696, 39.4190239906311, 37.333358564684474, 16.746298613086825, 0.04064254252420318, 0.05790844063965544, 0.05597362046941154, 0.03187221666467527, 0.026241434032037377, 0.018712306590450388, 0.05014007543063453, 0.03647015955779822, 0.020837926703895775, 0.018189392210314834, 0.03410503929180484, 0.030408021543295156, 0.043936463959154584, 0.005191092692961496, 0.031073740458176024, 0.04835894781975977, 0.141584922769858, 0.1536508995078264, 0.12858464052119564, 0.13780449336815265, 0.13423939596020407, 0.1738703040586364, 0.19899651708622135, 0.11662978483664414, 0.17864064163258, 0.2514533304999913, 0.1641260487057509, 0.09051134239041037, 0.16588800496632056, 0.13222148972413234, 0.18813720543778714, 0.11984240519063127, 0.15896989393138117, 0.1419173436419618, 0.1880472667154766, 0.1187327804584657, 0.11090375257716065, 13.726954152507167, 56.9383962692753, 44.47643003156109, 38.080895639234974, 48.262399781134825, 47.68396000708304, 44.1623148610515, 0.4819885382969534, 1.3351721100268827, 1.9963502379194384, 0.22971622916238926, 0.31931653979324526, 1.0825426660237776, 1.39290559916727, 1.937343204213727, 18.83020485601118, 47.695750651821015, 60.144514191535215, 58.487634428085826, 59.557092189788825, 53.76313563316099, 48.41787076765492, 44.84399926277899, 43.746229833172215, 43.1725125928079, 44.19796528354768, 41.87699294859364, 46.36121126913255, 45.18659084073959, 50.84308793467861, 51.62741684144544, 56.40913125007384, 53.975088750162435, 49.35719605415098, 44.18955964426841, 44.37436995967742, 41.688417157819195, 43.126256081365774, 43.77082701652281, 46.3472633207998, 46.93969026688607, 47.04945387378816, 42.36280987339635, 45.303905010223396, 42.35232930029593, 41.421476333372055, 45.397543753347094, 44.27517321801955, 42.58113291955764, 45.48480864494078, 45.01428504143992, 43.87119262449203, 40.327040918411754, 41.450431269984094, 40.45234887830673, 43.6065032405238, 48.378478404014345, 51.2609419515056, 54.90660067527525, 58.01193721832768, 53.09984322517149, 48.534149431413226, 53.404909487693544, 55.478462634548066, 56.62250426507766, 54.9686800279925, 56.723721027374275, 56.45026514607092, 56.2912130355835, 50.53330698320943, 54.09046134641094, 56.89592876741963, 52.67317956493747, 51.48294025851835, 48.86498566596739, 45.979223405161214, 43.23309752248949, 42.651209985056234, 40.848225855058246, 42.38247663744035, 42.73490551979312, 44.03021727838824, 39.423828894092196, 41.284734664424775, 41.178905194805516, 40.79400300979614, 39.789130995350504, 39.55392606796757, 43.37733876320624, 40.738015097956506, 43.63884318259455, 42.9226811470524, 40.347488234120036, 41.7393805134681, 40.611828527142926, 39.840851368442664, 40.21354321510562, 41.24642879732194, 40.15285630379954, 41.47209452044579, 39.95612982780703, 40.92491995903754, 48.43449769481536, 50.525572069229625, 54.815452637210974, 51.691904529448486, 52.225896004707586, 50.8662965989882, 51.818722601859804, 47.80502396245157, 50.11836336505029, 48.29223332866546, 47.35570469210225, 46.48844119041197, 46.30801216248543, 40.98066076155632, 41.69455958950905, 40.706032091571444, 47.32293721168272, 51.84774814113494, 52.91848067314395, 55.212125855107466, 40.7645107084705, 4.3303888459359445, 0.40771729463050443, 6.6365949280800365, 21.47512378231172, 14.385319082967698, 11.256728768348696, 1.253719067861957, 0.22955512087191307, 1.5058379908723216, 2.6458514698090094, 26.60494854373317, 46.52755114340013, 45.28721140277001, 42.90994521110289, 44.92298010856875, 20.677186212232037, 0.1609617225345104, 0.18068336911739843, 0.19920017390001207, 0.20177357048997957, 0.07753690028743399, 0.14724150149812623, 0.1625398330150112, 0.18372426320227886, 0.16647202443451653, 0.2765267907131103, 0.12048519126349881, 0.17642563629534938, 0.12128173118276943, 0.06540399810840046, 0.12528543691000632, 0.18526106622190247], [0.019274657261708093, 0.013319087823131874, 0.03939056333394782, 0.05599887455783545, 0.03587504330601904, 0.06105209775869885, 0.02136646225417574, 0.022665234094846155, 0.04822039698821403, 0.03235298854809615, 0.03354567253301221, 0.06068758163300734, 0.04317484615791229, 0.017370465286676923, 0.03809940257680513, 0.09093714938048394, 0.03555253944209507, 0.03418015804322016, 0.02591594817086814, 0.027242982910285075, 0.07579790368195503, 0.9877117675158286, 27.490804080040228, 44.10208686705559, 29.007476760495095, 31.07398140814997, 37.60882662188622, 36.49381053063178, 3.371567418498378, 0.21246685556346373, 0.6300717099539695, 0.0744032865810779, 0.14076217498269775, 0.07643455339054908, 0.11466820904564475, 0.16580791813471626, 2.4437518369766975, 25.73047572566617, 55.980753514074514, 54.95790919949932, 52.95696304690454, 50.38919518070836, 47.84944872702322, 42.44281053543091, 42.069404817396595, 42.23202236237065, 45.49644631724204, 47.673302927324855, 49.41373702018492, 50.448823052067915, 53.346752505148615, 51.9113140721475, 54.97033134583504, 51.82235863900954, 52.577807134197606, 46.178236622964185, 40.29444209990963, 40.50317887336978, 38.94260898713143, 41.86177022995488, 45.324124828461684, 43.736121885238155, 45.00129022905904, 39.78934672570998, 38.61513814618511, 37.661272633460264, 39.47085811245827, 41.07276585794265, 38.72337595109017, 40.308786207629794, 39.36112196214738, 38.9909561218754, 38.62192776895339, 37.60964639725224, 38.80744803336359, 37.28947900956677, 38.72472916879962, 42.33538466115152, 47.235676242459206, 50.444739864718535, 52.35864077844928, 47.87555210051998, 50.24527557434575, 50.231288402311264, 50.796062638682706, 53.98716180555282, 53.20693177561606, 53.11348130626064, 51.92532870077318, 53.371765459737475, 45.099223967521425, 51.04154417591711, 53.72514355567194, 49.78839005193403, 46.70281440980973, 42.34866580655498, 40.81430912017822, 38.598122904377604, 38.064292246295565, 40.57819420291532, 40.84287574214321, 38.170584555595156, 38.23366803507651, 38.4518341864309, 37.35880690236246, 37.17427115286551, 36.717413087044996, 37.58790469938709, 36.65281165030695, 39.11035699229087, 38.20974942176573, 34.93922618127639, 39.31890549198274, 36.30809022534278, 39.81071579840876, 36.23943698021674, 38.4412790882972, 42.26465255983415, 40.09729985267886, 37.25472288746988, 37.01515236208516, 37.010743618011475, 36.0049694584262, 42.52452527323077, 46.756743077308904, 47.63330259630757, 49.70514558976697, 47.49667075372512, 48.52403363873882, 46.74576436319659, 45.45021334002095, 45.731945422387895, 45.00411825795328, 44.955139621611565, 45.88939720584501, 43.64169866808, 40.246942197122884, 38.89415202602264, 42.67644651474492, 45.055348334773896, 50.081634290756725, 50.70963713430589, 51.33540814922702, 22.256789399731545, 0.10399731672218732, 1.306797071330009, 5.787296372075235, 7.9303573504571, 9.484086132818653, 3.0133123455509065, 0.25035195653477027, 0.24041884518679113, 0.33101914570696894, 1.1908453126107494, 22.486885439965036, 28.017662725140973, 35.13726272890645, 37.17284733249296, 31.088264719132457, 3.5277662498335687, 0.17385155022625, 0.10159605242792638, 0.007435068602658689, 0.010893834443132003, 0.08609715143158551, 0.03205058108564587, 0.10097862386535253, 0.06973018854736321, 0.06253454684009475, 0.037380180081292506, 0.057516253418138916, 0.04740075185714711, 0.08443592041130028, 0.02609902786301269, 0.0447396956564438, 0.009952755757577477, 0.01752010907136625, 0.024614014302290255, 0.04976740812942867, 0.05271874653596071, 0.056106483098119504, 0.10514942102975423, 0.032449220682704644, 0.04734345997172979, 0.04954799671747512, 0.08923143163443574, 0.003456554479799384, 0.08238992939192442, 0.042449031475811236, 0.03228082306562893, 0.02710348212971322, 0.009433068522822954, 0.00575328057053529, 0.01589475777901469, 0.032659860387925184, 0.10301042693637072, 0.07288832472817552, 2.062078498063549, 36.92250205624488, 48.903303300180745, 30.393342318073397, 39.052043114939046, 44.0906374685226, 40.095048412199944, 3.1512724007329638, 0.23524318581386922, 0.5034633617727987, 0.16031482256948948, 0.07072699917179924, 0.3049145464695269, 0.19135739474046617, 0.27642496230621494, 3.910886698192166, 29.081191824328517, 57.820811886941236, 57.52859923147387, 55.63821684929633, 51.21905103806527, 48.776669579167525, 44.49212735699069, 43.158450895740145, 43.238573151250044, 46.54952033873528, 48.31350041973976, 50.905830167954974, 52.95302890962171, 56.14503022163145, 54.645390433649865, 56.74805148955315, 53.58833520643173, 55.76951819081461, 46.774072108730195, 40.036605096632435, 43.24156199732135, 41.76660568483415, 43.096567661531516, 47.49448207116897, 45.82020267363518, 46.51211661677207, 42.784935351341005, 41.11984998949113, 39.78594995314076, 40.26335731629403, 42.48601544287897, 41.003120253163004, 41.4522159484125, 40.941452749313854, 41.42947012378324, 41.10250919095932, 37.91353202635242, 40.012411917409594, 39.989109116215865, 39.78655399814729, 44.25093689272481, 48.610580736590975, 51.08467848070207, 55.11913822543237, 49.86895945764358, 51.56057965370917, 52.03288401326826, 54.58265996748402, 54.3300828626079, 54.48544010039299, 53.72391193143783, 54.4066200717803, 53.52198047022666, 47.542460503116736, 53.53814848007695, 56.64564232672415, 52.086730310993815, 49.16376436910322, 44.81943345838978, 43.619592189788825, 40.58520740078342, 40.086058339764996, 41.083470006142896, 42.18668368554885, 40.28488720616987, 39.993670832726266, 39.054914289905184, 38.91627027142433, 38.99427444704118, 38.96770823386408, 38.85902327875937, 39.63542115303778, 39.71041294836229, 39.59988055690643, 36.775821101280954, 41.13493542517386, 38.18034733495405, 40.676994785185784, 38.14784657570624, 41.01982955009707, 43.989565833922356, 40.48433580706197, 39.23642981436945, 38.92536232548375, 38.73747687185965, 38.42882164062993, 43.65032788245909, 47.96956346881005, 49.38724140967093, 49.49791500645299, 49.90289580437445, 49.447645910324596, 49.33422273205173, 48.496981051660356, 48.54488103620468, 47.285635471344, 48.483629303593794, 47.5591423434596, 44.983537581659135, 41.07697456113754, 40.96750513199837, 44.20796732748709, 46.608983470547585, 50.99537395661878, 51.92857642327586, 52.94322690656109, 24.90574052256923, 0.10382500822625815, 4.098615747305655, 10.539732248552385, 9.717678966060761, 8.739369242422043, 4.1580477453047235, 0.08235931651847017, 0.008547248716856684, 0.38705847736808563, 2.656543850898743, 28.27061833873872, 35.554057705786924, 38.81717158902077, 40.22111338953818, 38.14562259181854, 5.622219010706871, 0.15049293186635743, 0.06513210584319408, 0.023974681370741418, 0.054921919645200816, 0.06758835226778062, 0.05613204745215274, 0.023695174191567688, 0.03214125333714389, 0.025538879694537293, 0.03958051100433354, 0.03434587052212127, 0.03365425783539972, 0.10328049591231732, 0.015885128053806482, 0.01148611712720125, 0.02808710646575257, 0.08412154857069255, 0.18922031586689336, 0.16537999674197168, 0.2508431261465434, 0.1155119859463265, 0.19343432039022448, 0.24368455543393092, 0.1823512804243834, 0.13835232284280563, 0.27697651496817993, 0.1746258199695618, 0.12494409111358466, 0.20569952595378124, 0.12270951989076792, 0.2168942921824994, 0.18481826740166835, 0.2103215948708596, 0.08734830324688266, 0.12022863607853652, 0.13800381412429197, 0.21890731077761422, 2.554792175369878, 41.86406873887585, 57.9733254063514, 38.89818030018961, 41.278937401310095, 49.33675266081288, 45.42272536985336, 4.787482253966793, 1.053102826399188, 2.4183363491489045, 0.3453612922420425, 0.2597494958148849, 0.824818859898275, 1.1208442430342398, 0.693456782929359, 4.271625366903121, 31.534255858390566, 57.89195583712671, 59.19257064019481, 58.896631733063735, 54.02090987851543, 51.16819358641102, 46.14934052190473, 46.03084571899907, 44.81781351950861, 49.35976520661385, 51.64294942732781, 56.50642564219814, 55.00300861174061, 59.58707086501583, 55.70369689695297, 59.81862798813851, 54.949503560220045, 56.323784397494414, 50.24660918020433, 42.87431832282774, 45.14111488096176, 44.21171319100165, 45.752357436764626, 50.26207900816395, 48.71315463896721, 49.98591276907152, 43.688892625993304, 42.576830079478604, 39.93455679185929, 41.70803293105095, 43.572723788599816, 43.66663317526541, 44.85813940725019, 43.151927994143584, 44.67451757000339, 43.112790584564216, 39.559699796861224, 43.13515986165693, 42.396797210939475, 42.24634293586978, 47.344431800227014, 51.010176981649096, 53.69836161213537, 57.33084901686638, 52.359515466997706, 51.88430070877076, 53.240550410362985, 55.11333703994752, 56.62552056774017, 57.06014663942399, 55.509806294595045, 55.97011604616719, 54.64511586773781, 47.25368776629048, 54.756832814985714, 58.18117964652277, 54.26106483705583, 50.18610662029636, 46.93677594584804, 46.00242814710064, 42.978386648239635, 43.073394298553474, 44.11620347730575, 46.15175670193088, 43.34742284590199, 42.05892816666634, 41.48299478715466, 42.360519209215724, 40.70805211221018, 41.32845340236541, 40.00013882114042, 40.49775031305129, 42.41892722345168, 42.27541946595715, 38.609387951512495, 43.741770098286295, 39.71492367406046, 43.32853663352228, 40.02240219423848, 42.653987023138235, 48.340953088575795, 44.0886252926242, 42.08542769955051, 41.023496966208185, 40.43912264608568, 39.51141542004001, 46.303677943445024, 49.448057759192686, 51.408670179305545, 52.65133196307767, 50.909913355304354, 51.6240357583569, 51.14905241997012, 49.68550235994401, 50.42771285580051, 49.49887206477504, 49.229432690528135, 49.58551329951133, 47.44669975772981, 43.05924238697175, 43.67532122519709, 45.80558007763278, 49.1537505580533, 53.712639039562596, 56.072207497012236, 53.92760061448621, 25.74639270382543, 0.3209755491585501, 4.742694179857931, 14.86708910234513, 16.17781675631, 19.80482166813266, 7.26945415619881, 0.29477687432400645, 0.8905465684590802, 1.3362996688773556, 4.958527991848608, 34.88228905585505, 38.78693403736238, 44.040537034311605, 43.99427660049931, 49.41295646852063, 7.4035305746140025, 0.2915954950355715, 0.3151097364964024, 0.10207268935177596, 0.11521852064517238, 0.1756029191517061, 0.14795561801762352, 0.1711505999968898, 0.17693595810522958, 0.16492527759363576, 0.13639855348775465, 0.1563286372730809, 0.13703066795583696, 0.28152312422471665, 0.11697454738520807, 0.13193253668085222, 0.09863460166079384], [0.022062548894375082, 0.00946255524702851, 0.03955168694618248, 0.006138450905470359, 0.019920909882432992, 0.08932566044912224, 0.03208739544084716, 0.035902047905349926, 0.056299629185589097, 0.06184828910796393, 0.05620826170929978, 0.010850557178679493, 0.026296412331923365, 0.04750267985547262, 0.05062534999583037, 0.06990438928046534, 0.0340104274331562, 0.021109953034488906, 0.10298293204076829, 0.00566054945774076, 0.05788740003481508, 0.0245641247414413, 8.711148769624772, 46.17241582562847, 33.64818980616908, 33.83641650599818, 33.2222007936047, 38.541766289741766, 7.063988149166108, 0.6251905041356242, 1.1462602211583046, 0.3345812094067374, 0.06897306385179681, 0.045879213139414794, 0.13486338989628902, 0.10263256172859862, 0.03346427186061779, 6.662496789809197, 46.66282584590297, 57.039189415593306, 54.475806759249785, 50.41540053582961, 48.421247928373276, 46.24860786622571, 47.431712381301395, 48.61480512926656, 53.147025415974284, 51.99422905522009, 51.68744087219239, 51.800212937016646, 53.849882771891934, 53.49208416477327, 53.13601532290059, 54.015355802351436, 53.82802340292162, 44.910801149183705, 40.81013571831488, 41.07699025061823, 42.08803999808527, 45.78490918682468, 45.80578011851157, 46.219598016431256, 44.42649433689733, 42.01264027626284, 40.74736995081748, 39.54475164413452, 38.858270183686294, 41.44017819435366, 39.25966201290008, 40.06772125920942, 39.29234320117582, 38.51046577576668, 37.703955865675404, 37.25138102808307, 38.38532255541894, 37.56970097941738, 38.560966291735255, 41.26124358946278, 46.29450351961198, 50.29800399657219, 52.532060530877885, 46.32465477912657, 49.69423747831776, 51.59580253785657, 50.6086439471091, 53.605883890582675, 53.743374732232866, 52.630131552296305, 53.00597306220762, 50.52645460251839, 47.21564077561902, 52.36833687751524, 52.61209257187382, 48.43610586658601, 45.23634610637542, 42.164051609654585, 40.4309170476852, 40.30427155956146, 42.396907037304295, 43.62956285476685, 42.29472144957512, 39.0623354142712, 38.506810126766084, 38.190302310451386, 37.13270579614947, 36.603048539930775, 37.68191214530699, 38.12476342724216, 37.92602869772142, 37.40744429249918, 38.34703237779679, 37.60323724439068, 39.73975227725121, 36.29013753706409, 38.80920525520079, 38.45742748629662, 47.21809617934689, 50.15933252150013, 49.123960156594556, 39.91367409306188, 38.23909267302483, 35.84090063648839, 37.907550411839644, 45.88021493727162, 48.07783265267649, 48.61444819358088, 49.70326677445443, 47.891559293193204, 47.67473459243775, 46.75277363869452, 46.165810554258286, 45.37175024709394, 44.27972316741944, 44.18853982802361, 43.564145565032966, 43.11931348616078, 42.7249191653344, 41.46825844241727, 43.7300657456921, 47.75074228163689, 49.58554467847271, 49.37768259356099, 47.24519975723759, 8.735503746617226, 0.18696389581647613, 2.28738532431664, 9.35221016407013, 7.370597374054694, 8.588592352405671, 2.350007680154616, 0.08056660948861992, 0.09542761205305016, 0.060794167445912484, 4.621294861839664, 34.332902277669604, 28.95358535551256, 42.552782027952134, 38.577836405846384, 18.247862323637932, 0.17418565649178722, 0.04842182448614509, 0.035838696264451554, 0.017008912006032564, 0.017637073460425583, 0.030905245164889964, 0.01353730318031364, 0.0637376266381433, 0.038078350480645895, 0.0504718681106404, 0.043861149855318575, 0.005884349595890531, 0.03905636130742008, 0.02364581897704592, 0.025769056557046793, 0.054617464812772895, 0.07379616190108561, 0.008468949742945693, 0.08002218144435076, 0.029125733999535445, 0.06747154684196557, 0.05461620459813745, 0.016356791151807677, 0.02828600587353351, 0.05121756660481615, 0.08056863196074002, 0.029095969568457336, 0.05228399163893154, 0.03137921035710362, 0.04224618288478063, 0.02525037864313251, 0.045733415116105354, 0.07416826612766712, 0.044215277828756845, 0.018563155017252413, 0.01874757344804464, 0.054717550369640516, 0.017641449737693035, 0.04182581128852983, 13.80808347655881, 53.9140841268724, 33.34475132726854, 37.10941476206626, 40.99015289737333, 41.9007585894677, 9.529216924021322, 0.618235896671972, 2.591020166873932, 0.580304432059488, 0.047166424713307814, 0.2876392637770022, 0.6444513641538159, 0.7755858823657037, 0.21016001160587036, 9.297401905059814, 48.27678703492688, 57.19259723540276, 56.62623051674136, 52.67496424336588, 49.30877439437374, 47.010563573529645, 48.50753222742389, 51.513734786741196, 53.986498924993704, 53.298683858686886, 56.0140936605392, 53.86465049559071, 55.960074778526064, 55.481306352923, 56.08141329980666, 55.74483471532022, 55.3347195348432, 46.20445374519595, 42.05020481540311, 42.48116739334599, 42.593088303842855, 47.681167279520345, 49.19001287029636, 47.64404596820955, 46.319096780592396, 43.147562396141794, 41.73468935874201, 40.26205901176699, 40.02988607652726, 42.3012561182822, 41.89960933500721, 40.62454485124157, 41.973950016883116, 40.17364486571282, 40.85149711178195, 39.265482810235795, 40.4973227747025, 39.82100025300057, 40.970348850373306, 44.181255986613614, 47.61513810003958, 51.13709311331473, 52.63451283977878, 49.547862468227265, 51.81087786151517, 52.53488855977213, 53.16524874779486, 54.65394904536586, 53.0934105380889, 54.67376093710623, 54.18302143773725, 52.58560480610017, 48.64013971820955, 53.4261255879556, 55.876602818889005, 50.58097162554341, 46.23347143973074, 44.314392997372536, 42.117218509797134, 41.48197104853969, 43.38204560741302, 44.660114626730646, 45.20088395764751, 40.9529649057696, 40.100174950015166, 39.12499135540378, 39.26915022634691, 38.35968202160251, 39.44525680234356, 39.19226784859934, 39.61316562468006, 39.27132714179255, 39.49628291591522, 38.53221924074235, 40.274359564627375, 38.367389478991115, 40.44844611998528, 39.10739560281077, 48.41206173742972, 50.92031155863116, 50.726891640693914, 43.095751808535674, 40.21527298035161, 38.75571197079074, 39.011466195506436, 46.57757705257785, 49.64681210056428, 51.36587712072557, 51.08581989042221, 49.581947865024695, 50.71448910620905, 48.61296161528557, 47.49796905825215, 47.516702298195135, 46.75730397624355, 46.621440918214866, 47.20383051903018, 44.772651349344564, 45.44693031618672, 43.46305431858186, 45.78493664341588, 48.69437040821199, 52.31903268444923, 49.80713113661736, 50.592573996513124, 9.521837965134653, 0.21947239255232198, 6.445128840784873, 14.074580092583934, 10.269107337920897, 8.57769993043715, 2.865327692800953, 0.2732721734191141, 0.05280797279650166, 0.06208222937740146, 5.386349241579733, 36.51622687616656, 33.5557238517269, 41.825088224103375, 42.43280064675116, 26.115846633911136, 0.7209552331797539, 0.0441646738909185, 0.04651756356320074, 0.06018088341900899, 0.05233668316636355, 0.09895475746522989, 0.023350335034211318, 0.10689296819750341, 0.0801687493860241, 0.023473698172658205, 0.03724215018953528, 0.02120815784550242, 0.024063164525995814, 0.05591252112701055, 0.02049869722536495, 0.04981354577466846, 0.06633828829733596, 0.09260040287288929, 0.2207996398811379, 0.10612698752553233, 0.10313821806301994, 0.14876240053244177, 0.23195651540112114, 0.10814706945130903, 0.11498238936427141, 0.2514576359141258, 0.17627575885384314, 0.2802532568814293, 0.1322872200680356, 0.13873389591613125, 0.1385855353287151, 0.15901071109598683, 0.14004723108824224, 0.20429442877009993, 0.11507140112019355, 0.19674987231771793, 0.1898787990813294, 0.17028312799671005, 0.10697487065748823, 15.45663800931746, 61.1663975254182, 42.07059329555881, 43.78983090000768, 45.02510686074534, 48.407962860599646, 11.860162865731025, 3.1641659669337736, 4.205429976986301, 1.1092468976013123, 0.14953925965293763, 0.5667753193166949, 0.8416772681859233, 0.9174103914730011, 0.36672417495039206, 9.736671082435116, 50.84062076384022, 60.53248367001934, 58.701309465592914, 54.23169020683535, 52.81991935545399, 50.12710240579421, 51.68173382359167, 53.244916008364775, 56.89049628473098, 55.18471633234332, 57.44411137796218, 55.62200569337415, 56.44011012969479, 56.39778383316533, 57.55238056182862, 58.546128734465576, 58.72154889568206, 48.722968409138346, 44.683397816073516, 44.36966703784081, 46.14800299367597, 50.85431768048195, 51.30273088332146, 51.54111293054397, 48.285451550637525, 44.54347902728666, 44.570974842194595, 42.315713974737356, 43.25876551289713, 44.2779424113612, 43.353369159083215, 43.35738958850984, 45.041263103485115, 41.33490962366904, 42.41535002185453, 40.27112360923521, 44.210709064237534, 41.00055894544048, 41.797651244748025, 45.47728553895028, 49.97462026534542, 54.698801348286295, 55.81282115751698, 51.97438578451834, 54.13691005399151, 53.90150900809996, 54.39723383995795, 57.32860542112782, 54.877547679408906, 55.884890787063114, 57.158445158312404, 52.24833980683358, 51.13264906790949, 56.46575458588139, 57.55014873320057, 52.91769619910948, 49.09460906059512, 47.887189772821245, 44.51984282462828, 44.46150149068525, 46.704324522326075, 46.65464770409369, 46.122021213654556, 42.35171348817887, 40.94873659072384, 42.41639729469053, 41.47745247810118, 39.66910646807763, 41.25932162807834, 42.626228409428755, 40.44643002171671, 40.93616539432157, 42.89170618980162, 42.03290324057303, 41.82562558881698, 40.44305678336851, 42.47833936445175, 40.27401439605221, 50.73235550234395, 53.24663400650025, 54.27429106927688, 45.23090970131659, 41.43922505840179, 40.622850387327134, 41.857604672831876, 48.15410314067718, 50.1991641906, 53.25323535550026, 53.50465143880537, 51.673081074991536, 52.58373775789815, 50.605196183727635, 48.680649957349225, 50.316270474464666, 49.157441508385446, 49.701097703749134, 48.39987493330433, 47.300803276800345, 45.5955881457175, 45.74494023476878, 47.867024867765366, 50.646322234984375, 53.87915542048793, 52.25705531335647, 49.31567384350685, 11.219302492756999, 0.2868267509245104, 10.001336932182312, 17.780486422200358, 14.704521567590776, 14.612828320072545, 8.705838861003999, 0.616002229432906, 0.29223413657276864, 0.26835710651451544, 9.259751073775753, 44.3614379052193, 40.489293682959776, 48.19729235864455, 48.91844757141606, 31.77551692531955, 1.0340811696744736, 0.2224418565991425, 0.17150169809258756, 0.15168268173452348, 0.16114639568953745, 0.16815616148373774, 0.16735943004248605, 0.13253699537486802, 0.19626536767088598, 0.08743231244865926, 0.15532827966155546, 0.10633547069324602, 0.12604398652911186, 0.09303759392951766, 0.13904287449775204, 0.09822548772659033, 0.1300188490459996], [0.07613435417654053, 0.08416798115978319, 0.038904070688952366, 0.02951464619517567, 0.08491259563954608, 0.059594875952649506, 0.01270146678096705, 0.011658658322337414, 0.04239072835433387, 0.007188578376606588, 0.06540992762893438, 0.024556822008303097, 0.02702314631953355, 0.04737762366271308, 0.09834128957722457, 0.06239222302552193, 0.0335581099704629, 0.0630935765202007, 0.04003876181800039, 0.07865141266055646, 0.08541416106445175, 0.062024213538895694, 1.882868346668059, 25.54012506238876, 38.383431972995886, 27.5135479434844, 38.22976919912523, 39.343592889847294, 9.694342824720568, 0.5663579546155468, 1.2294480541060049, 0.30228753904661826, 0.06253612115077915, 0.014773704930238668, 0.3490144284742494, 0.2790906112040243, 0.2118411455904284, 0.2332549731457426, 20.48281708071309, 58.09734290645969, 54.17143867861841, 53.07354765553629, 51.30966563378611, 50.190993893531065, 51.288869227132494, 53.616827303363436, 53.45925000406081, 54.600283176668235, 55.1591032551181, 53.88046156975531, 50.85098758820565, 55.135980882952296, 52.92790220629785, 51.92622300117247, 47.43570535413681, 41.576366809106645, 40.56628196470199, 40.200850425228, 42.6448675124876, 45.31795494018063, 46.678727134581536, 45.260390235531716, 45.16137784527194, 41.858263631020826, 38.727890599158506, 39.89334444845877, 38.530889557253936, 40.055463852420935, 40.26721692854359, 40.16263477263912, 40.80245179514731, 40.80780583043253, 38.99151309843987, 37.10415094129501, 35.96383164005895, 37.9261306793459, 37.91420667402206, 40.842773760518725, 43.16169861824282, 48.671502990107385, 50.47330648668351, 49.29581096095424, 50.211194099918494, 48.68103042725594, 51.68100818510979, 52.440979173106534, 52.82093917169879, 50.36428813011416, 51.8386011738931, 47.03531765168714, 47.42622106306015, 52.84922730538153, 52.10518506265456, 47.98700232659617, 44.06364371699672, 41.842613374033284, 43.263672397982695, 41.97668783126339, 44.97329627313922, 46.41708935460737, 45.8555785302193, 45.37086771380517, 39.20945567469443, 37.79142864288823, 37.650541028668805, 36.44674208856399, 37.47523069381714, 38.18566214653754, 36.969841141854566, 37.02888065768827, 37.10628078829858, 37.76359942651565, 37.66435169404553, 36.61303881675967, 36.05630543924148, 41.21783471876576, 50.85166223587529, 50.88243715224728, 50.96506972466746, 47.80587903914913, 39.139508047411525, 36.45871316232989, 38.36151376847298, 45.47692468089443, 49.21330390437957, 46.76454467158164, 48.16476022043536, 50.11006755213584, 48.415952728640654, 45.104056327573716, 43.53868153787429, 40.50869372583205, 40.406967055413034, 39.81848993609029, 42.72053003311158, 42.133351218315866, 42.5591911808137, 42.060810904349054, 46.776421608463416, 48.56948998666579, 50.341569762076105, 50.86921876476657, 34.57036256790161, 0.9186947225562988, 0.28355843597842806, 4.704909987988011, 11.953159320739008, 7.4693675579563275, 6.6001335555507294, 2.2437406211130084, 0.4503317015065301, 0.07334923386693963, 0.05540620212653472, 20.32563594079787, 31.802914680973178, 28.008149016288023, 45.07262245301278, 38.2221362667699, 7.1118038027517265, 0.04652431662825327, 0.04306737934389422, 0.009790398743784717, 0.013188655608363692, 0.06118191901834742, 0.012656283872802893, 0.012850852968591838, 0.049342367227279374, 0.0012489269283832982, 0.1179238222539425, 0.02214262614988031, 0.04986098576937953, 0.0983860903990365, 0.039847634372211276, 0.03444028702834922, 0.00477562980508552, 0.04717254575582282, 0.09983205837347817, 0.04115176116747241, 0.03276065074568314, 0.020107617000899008, 0.018802281701937318, 0.026599739099882787, 0.04888958245095226, 0.06655994817734727, 0.044269371297090285, 0.02873914879596522, 0.10570826684875835, 0.026698449528926325, 0.050126178595688076, 0.02887448780388842, 0.03419743715635231, 0.04206039124138413, 0.0390143605369714, 0.05046978435148636, 0.033374463373254386, 0.03810383056500747, 0.10711811377757019, 0.07908000821067442, 3.665043567457507, 37.22138666337536, 43.64844514477638, 29.655787675611435, 45.36949096187469, 44.28407307594053, 11.269849096575092, 1.4829616248607638, 2.548421020469358, 0.6245408615758342, 0.1263312618398378, 0.09519196340754148, 0.6522767377957222, 1.5604433898002872, 1.0540162483530662, 0.3245023728138016, 25.260228649262462, 60.27865925142842, 56.26797299231253, 56.04215429675195, 53.57876462321128, 51.72514269428869, 53.732537223446755, 55.614655171671224, 56.06883425866404, 55.35945792352, 55.098353585889264, 54.77342444081461, 52.70945364429105, 55.507880410840436, 55.64093897419592, 55.39430033776068, 51.15816800825058, 43.660494665945734, 42.36524566527336, 43.992060461351954, 46.10101299901163, 46.73036906027025, 49.649518535983184, 47.51120313521355, 48.70978532298919, 43.251156114762836, 39.83546987656624, 41.16161538708595, 39.8279663824266, 40.10449740194505, 43.157364399202415, 42.44114745047785, 41.913725945257376, 40.65488046215427, 39.1513692948126, 37.45119048703102, 39.94797129784861, 40.6541391341917, 38.762442758006436, 41.93607953286941, 46.72164178663685, 50.113852639352125, 53.07570495913106, 51.47664877676195, 51.455362073836795, 50.50308904340191, 53.805948303591826, 54.327066559945386, 53.72117411705756, 51.89272203753072, 50.35946361480221, 49.659481356220866, 49.85766695391748, 54.29407550442604, 53.554489074214814, 48.94674747220932, 46.98330702320222, 43.49899891884097, 44.29152950163811, 44.072198406342544, 47.91787447467927, 47.24416032914193, 49.02353963544292, 46.72906291100287, 39.809189996411725, 39.32892714777301, 39.35942749823294, 37.853551141677364, 39.47268593695856, 39.50183306970904, 38.89947860471664, 39.168141349669426, 39.9738589409859, 38.48650793875418, 40.27748961602488, 38.6528556577621, 37.64411226395638, 43.61744273093439, 52.796542029226984, 51.111213314917784, 53.4521818930103, 48.6305259889172, 41.29496420583418, 39.191961903725904, 40.09964935241207, 46.49333238601685, 50.21246494785432, 49.541818095791726, 48.43313663236557, 49.69982293344314, 49.27648936548541, 46.02712731207571, 46.71399316480083, 43.12726020812989, 42.74812390727382, 42.68539344110797, 45.06826469975133, 45.09226568283574, 43.97084043871972, 43.84519515498992, 49.29931363751812, 49.90397053380167, 52.76124069767614, 52.013260395296165, 37.88648728401431, 1.2807923699578931, 1.6451635211706164, 8.473985598933313, 12.726051576675909, 9.894975981404706, 8.122639781044375, 3.7375289682419073, 0.8797401934862138, 0.00811906302377822, 0.24467328383076578, 21.04033297108066, 43.37872728224724, 29.748385029454386, 47.861466869231194, 43.89346776470062, 11.016700306246358, 0.023553543686566335, 0.15878679891747816, 0.04015026208493979, 0.07024424120543465, 0.01927478558143541, 0.03150678697913405, 0.07874717365109152, 0.05171365067062359, 0.0025335853945674196, 0.04874441645018036, 0.04185672293627455, 0.005044395473950933, 0.04487408280012108, 0.032576973504957654, 0.017836719803932696, 0.03973852813003525, 0.0037372794993702444, 0.268613071811776, 0.15122624654923716, 0.12892764872841297, 0.2651501092458925, 0.16420287200279776, 0.1452132377533182, 0.17978687770664695, 0.1250078832550395, 0.09774583241631908, 0.13006299103219665, 0.2350232572925668, 0.12738415010033116, 0.15217120068207865, 0.2432642949204291, 0.22136918028756497, 0.1115774502977729, 0.21961968061664414, 0.16616575780414766, 0.15395364213374355, 0.14381574016184578, 0.1591507672903038, 0.24957629251143626, 4.216297393844974, 41.33378390342959, 52.295569066078436, 37.7950450681871, 50.85357243014921, 51.457044770640714, 16.996063378549394, 2.355668395757675, 4.918852236963088, 1.5234287179285482, 0.1439042999258926, 0.2289436294907524, 1.072735024556037, 1.517382384307923, 0.8149229038146235, 0.6170915451741988, 25.17443464648339, 60.31079915262038, 60.02016721233245, 57.26097983698691, 56.54075814831642, 53.06208256752261, 57.645827108813876, 57.680202761004054, 55.841674112504535, 57.19685692940989, 57.490689523758434, 55.154827871630275, 53.7650615169156, 57.71397829055787, 56.065688517785844, 57.53389050883632, 51.78647679667319, 44.70484141380557, 45.52999434932586, 44.75260803776403, 49.16991072316324, 49.446171099139804, 51.94201054111604, 50.133087942677165, 50.03329107838292, 45.77920213822396, 41.52838053241853, 43.37280842565721, 43.06986808776856, 42.418797785235995, 46.14139379993562, 43.340170383453376, 45.499160597401286, 44.543322132479766, 42.642878870810236, 39.31644224351452, 40.16630218875024, 42.88939591377012, 42.57890109092959, 45.03070800535141, 49.02156276087607, 51.69297141413535, 54.36936147751347, 55.1523450113112, 53.06999791053034, 51.77137567150978, 54.640240361613614, 56.00001235162058, 56.07156422830398, 53.821143565639375, 53.75859352850146, 49.04076668523973, 52.24634332041587, 56.63138058877761, 55.165634001455004, 50.186628295529275, 50.13055016917568, 45.948538703303186, 46.75414254588466, 46.55470571210308, 49.9518979749372, 50.302134252363636, 50.66391406520721, 49.87274062248969, 43.5831965169599, 40.24451817235639, 41.047031187242084, 40.81597612750146, 42.68746445255895, 42.58029353234076, 39.67271112626599, 41.46312405986171, 41.34238566121748, 40.75838788863152, 41.84621410985147, 40.11146745374126, 39.453980153606786, 45.806270414783114, 53.83513466004403, 53.253419706898356, 54.60111864151494, 51.051146138098936, 42.951290915089274, 40.49763264194612, 43.10033705926711, 47.74495286326255, 53.319033115140854, 50.16898155212403, 51.235419088794345, 51.303880137781945, 51.28100095256683, 49.024033854084635, 48.71370769316151, 44.51273941224621, 44.11824310979536, 43.75852646366243, 46.45810557949928, 47.30137986521567, 47.39362224455803, 45.21725985311693, 50.62522772819766, 52.95666102440127, 53.99577140808106, 53.248944282531745, 37.56435478887251, 1.6288653376602358, 1.2813668746140696, 11.872759557539418, 23.780869476256832, 19.234705163586526, 14.343336974420856, 6.718915181775247, 1.0342076661125308, 0.17216261746662279, 0.3128984390247253, 29.778691222590787, 45.14204056032243, 39.212424908914876, 52.22897114292268, 52.05195457704606, 13.263841867446901, 0.2124516410572875, 0.22208325084178682, 0.05927282791104048, 0.123967390297161, 0.13508299666066326, 0.10238297794374729, 0.13286506486756186, 0.14928709415178146, 0.0941805741299064, 0.18536919187153542, 0.19229816603324107, 0.13351676054298878, 0.2842849937658156, 0.09376580646682171, 0.08397249084326529, 0.10688798862599558, 0.1198412637196241], [0.036218691196653156, 0.011166711131321087, 0.013396200318370136, 0.05777339082992366, 0.08905126307640346, 0.036628904467027996, 0.03309781753247784, 0.03389904974028468, 0.03048820222067016, 0.019395522953521822, 0.02637829180927046, 0.024968760891727386, 0.042104487262305715, 0.05783955784394376, 0.07272619754076004, 0.058531729774850036, 0.10859895407432511, 0.017299422123018774, 0.03547226491894934, 0.04680142978266363, 0.026313511414393306, 0.057575855058647936, 0.2122470036509537, 9.20630681899286, 39.23654356310445, 32.89793256790408, 26.159131949947728, 36.532163466176684, 25.175923185963786, 2.0643748006513043, 1.2317471758973215, 0.4142069786546692, 0.11986360284349612, 0.22834392054186714, 0.4647055334381519, 1.2630932874256566, 1.558914768599695, 0.06780880172887156, 3.427457516231845, 40.518299610384055, 54.33884151520268, 53.69640827178956, 53.43985780592888, 52.20906511429818, 53.492582305785156, 56.66207705774615, 53.09684261198967, 53.377507809669744, 51.354188457612075, 54.43857562157416, 54.10536243069557, 55.46477748501686, 51.635088997502486, 51.421241375707815, 43.39684078770299, 42.329250074202015, 41.29888265363632, 42.4276662641956, 42.015558519671046, 44.83612314347298, 44.79287508995303, 46.54241692635321, 44.35692325715096, 41.590930569556456, 38.783035201411096, 38.92309911789433, 40.65585713232718, 39.648768978734175, 38.445727056072606, 40.94875228020453, 38.430645542760054, 41.07439364156416, 38.83119406238679, 39.890198707580566, 39.190357654325425, 39.83068458495602, 37.89936442529002, 38.85180219527214, 41.51937477050289, 48.622402760290335, 50.24680137634278, 51.53380555491294, 51.57897556981733, 50.846602378353, 51.265154577070675, 52.93192263572447, 51.7823386961414, 53.1881397001205, 52.78553193615329, 49.920130698911606, 49.86451148986817, 54.26105699231548, 48.957855624537316, 47.538687183010964, 44.71108190474972, 43.15628574740502, 42.39618532119259, 47.80411397257159, 47.62073924464565, 50.548035483206476, 49.4676931442753, 47.17550316164571, 38.60922713433543, 37.04374251827117, 36.24443800218644, 37.465660110596694, 37.372707782253144, 37.007029133458296, 37.54753566557361, 36.93738745104882, 35.07749757459087, 36.921207674088016, 37.06323277565741, 38.24426235691194, 34.86074739886869, 42.918911749316806, 48.79905454574093, 51.37550261712844, 50.89443176023422, 49.56486594292426, 45.568445344125074, 37.99141068612376, 36.71178840821789, 44.01115063698062, 49.7986235157136, 49.94076236601799, 49.214990523553666, 48.251668176343365, 46.73632321819183, 44.763951532302364, 41.89582424779093, 39.27035047161964, 37.956733011430316, 39.57076088074715, 39.52365713734781, 41.823727161653586, 42.88075100991034, 45.09741967724216, 47.99964412566155, 49.268566177737334, 48.55434571543048, 51.20659359039799, 15.599453468476574, 0.04636683193365893, 1.3979954873361897, 5.270516747428525, 12.47820386963506, 9.571909962161895, 5.745150504573699, 2.261661194985913, 0.8415847860517041, 0.03180515907344318, 1.48882765202753, 31.02473605063654, 36.60186398413874, 32.283714894325506, 45.127967096144154, 25.332521853908418, 0.4618356148562124, 0.014842360772402778, 0.08385845865573614, 0.02098361364445619, 0.017979382612412016, 0.019095176267587853, 0.15695920424355617, 0.12504966569042977, 0.026923489771903526, 0.04134509494648345, 0.09577352373350052, 0.08824834164472357, 0.055072701070457704, 0.02016883125648864, 0.022793774072441365, 0.06211774904401072, 0.06596353340653643, 0.07882611135080939, 0.0663439879914926, 0.04742879450561539, 0.04427451174706221, 0.021654925001184308, 0.02271665391632386, 0.018238871914124297, 0.1286286446115663, 0.028787092493486502, 0.018206317007782, 0.012615605561633506, 0.07830670373814722, 0.06335882680310358, 0.021809270650508906, 0.06573318608946378, 0.07203026028770594, 0.043294807865975365, 0.029099905345168327, 0.04407615243126789, 0.025867912542795943, 0.015368441010885423, 0.0988838330452, 0.0237656198066449, 0.33592397767689924, 15.033010263596813, 47.99506279730028, 33.27121473127796, 34.4827054392907, 44.31547949391027, 27.19410227191064, 2.744924656806454, 2.0700896939923688, 0.8793767000879011, 0.14404264008325918, 0.28961601576978163, 1.1054022393880354, 3.5665334857279256, 2.0602847491541216, 0.36537435867132684, 4.313604043376062, 45.32680772965955, 54.985444238108975, 57.21709243712887, 53.300311642308394, 55.27745293032739, 55.29571156347952, 59.625466946632635, 53.30668941620858, 55.17196470691312, 53.25794219970704, 53.933546927667436, 54.840245939070186, 56.47551344287012, 54.31167517938922, 53.91166402447609, 46.22201027408723, 43.26733981409381, 42.828505039215095, 43.34815632912421, 44.02340412139893, 46.248286231871575, 46.05105377012684, 47.62342606821368, 46.42425944728237, 43.064302244494044, 40.20266648261778, 40.584030689731726, 42.04309748065087, 41.452529738026286, 41.382589955483716, 43.42142620394307, 40.65669259717388, 42.70011409636467, 40.455278888825454, 42.262624694455056, 40.62985966282506, 42.18417336863857, 39.26694977668024, 41.41094869182956, 43.278436199311294, 49.66687110162551, 51.881402077213416, 52.72777503536594, 52.443524791348366, 51.93291848705661, 52.0773676133925, 54.451762630093484, 55.33565305894422, 54.18359018141224, 53.88997331742318, 51.31877337732623, 50.62465898452267, 55.505385783410844, 50.27825486275458, 50.26378916155908, 46.75418961432673, 45.02146690122543, 45.86933428241361, 48.89858861123362, 49.122877582427, 49.782031889884706, 52.227927792456846, 50.05476213270619, 40.13518210380308, 41.16137220013527, 38.683787468940984, 39.18488987030522, 38.505554968310946, 39.01763216141732, 38.55821671024446, 38.08844620181669, 37.21185530385664, 39.729601183245265, 37.54440953654628, 39.63318147966939, 37.95881186762164, 44.438069251275834, 50.774364086889456, 52.989514796964585, 52.08084283336517, 50.97946482319986, 47.939706387058386, 38.3425255744688, 38.0830882441613, 45.436892970915764, 50.64404726028443, 50.99690368098598, 50.92493603306433, 48.22625121762676, 49.00104876487486, 46.097208299944484, 43.43371498969294, 40.92535926449684, 40.8254917975395, 40.56689385444888, 40.935408376878314, 42.83486320126442, 44.17460756917154, 46.77224036185972, 49.17176208188457, 52.00728270315355, 50.36627284942135, 51.86872105444632, 18.40153294224893, 0.2733687617846074, 5.4521656324786525, 8.0859332603793, 14.177062799853665, 8.980429287879698, 7.656066984899583, 7.453804083408849, 0.8198271535577313, 0.022412769819399523, 1.9303315998085084, 38.406079738370835, 39.48404512097759, 33.54974223721412, 49.760482388158, 32.344752857762, 1.6108136095346945, 0.042921278715854695, 0.03300492937165884, 0.048144316796453736, 0.013000985134332892, 0.023209830678458658, 0.0770056949207379, 0.02360813128161094, 0.01696631751744257, 0.013428273546930044, 0.06031938828527928, 0.05137903495661674, 0.016700247520460718, 0.034474577123840014, 0.046752128194296555, 0.06440826766793767, 0.07085164167707966, 0.03479659452193207, 0.10899157413551885, 0.15602987830437, 0.1318811168593745, 0.18030911984462894, 0.162829659398525, 0.17911892564546678, 0.23477522866620174, 0.07700485222402119, 0.111745560631877, 0.09365699133805691, 0.19097914648873193, 0.18362162274218377, 0.13495311411398073, 0.18524159226686726, 0.2531259455868314, 0.17740127991043753, 0.1505341473966837, 0.16575799984557016, 0.14184758367557682, 0.11909400623652244, 0.10025278620061376, 0.14177287478120099, 0.41051054313298196, 18.586413860321045, 54.54413444765153, 41.513557895537346, 37.55076377622543, 45.275259940854966, 40.27156683706468, 3.802037738984631, 4.660136132471023, 1.6308011499143418, 0.3735931950711435, 0.5809287630742597, 1.3281825689538833, 3.77022952322037, 2.869878132497111, 0.3203812181468933, 4.611441377670535, 44.76058613869452, 56.93859238778391, 57.26350976574806, 57.62724684130762, 57.45249740539059, 58.34386779415993, 61.224240718349336, 54.696714647354625, 56.81506910631734, 53.91037748705957, 56.851958997787975, 56.85160990684264, 59.31368950874575, 56.42657403023013, 56.18932947035759, 49.17745736337478, 45.255899121684415, 45.118600476172666, 45.655925966078236, 47.114071000006895, 49.66773402306342, 48.744886613661244, 51.30284855442663, 48.16580749327137, 45.869306825822406, 43.222687552052165, 43.00363494503883, 43.73072470388105, 43.05133488870437, 42.23451698980024, 44.00376873631632, 43.170986790810865, 45.65436486274966, 41.950957082933, 43.86954915138983, 43.45540961911602, 44.59488561076503, 41.94425375230851, 44.22634363174439, 45.49384186344762, 51.74182453463155, 56.14002135492141, 56.58577911315426, 55.619554212016446, 55.09998529188095, 55.62997202719412, 55.25058861701719, 56.82560067023001, 55.509143414035925, 56.53828705510786, 52.629421603295114, 52.987836022530836, 57.9091436632218, 51.60689500070388, 51.699451169660016, 48.612043780665246, 48.86357753507553, 47.99115611660866, 51.39383185294367, 51.25259122540874, 52.80087624826739, 54.175686605515025, 51.76191099228398, 43.3051004717427, 42.67781934430523, 39.72873433943718, 41.66517711454823, 40.13589205280427, 39.90530767748433, 41.13017759015484, 39.31596763672368, 38.31170751202492, 41.485105022307366, 40.29098649178782, 42.24100851243542, 38.553105861909934, 47.13003112423805, 52.90921995716711, 53.77752288695305, 54.78992977449971, 54.70506537345148, 50.70956260927262, 40.56648592795096, 39.47073259661275, 47.044166518795876, 53.25870706189064, 53.49887770991172, 52.55153509878343, 51.58358043239963, 50.28944930722637, 48.25608084278722, 45.63945593372468, 42.988635801499896, 42.58877761902348, 43.059289455413825, 42.85210986291209, 46.735052370256, 45.94459279890984, 49.5672115202873, 51.706919362468106, 53.245916212758715, 51.739490724379024, 53.8117612561872, 18.553075675041445, 0.2152244962992207, 4.9137139320373535, 15.191388707007132, 22.999011662698564, 21.956318193866363, 12.58151125523352, 10.209263736201871, 4.033776026579642, 0.14710665470169437, 3.9535569375561135, 44.46594553609049, 44.742998230841856, 42.64207478492491, 54.22808162627682, 39.44932822258242, 1.6637734516013054, 0.19759187955529461, 0.21719917985460452, 0.1682859980651448, 0.16782842906973056, 0.18791169979639594, 0.2188311922814577, 0.2304350647835001, 0.14978146601107814, 0.1480260061761064, 0.17278495665279128, 0.25845529751912244, 0.17664141262010222, 0.13421655121830203, 0.14896352925608236, 0.20805760587175048, 0.16096726901108221, 0.1381384310943465], [0.01568743427689638, 0.07262769395545607, 0.03847249505680896, 0.026465922691709092, 0.07595723464844689, 0.02783863350839144, 0.09061075762034425, 0.03376608368970695, 0.054886120356499195, 0.01677666862134732, 0.01911702126474871, 0.006044159367335059, 0.04147074485738431, 0.027414835583899292, 0.02993351625909488, 0.07340161895920193, 0.09388351587638741, 0.06974213185810274, 0.025026010642308864, 0.010698415947357013, 0.021652938918240612, 0.07452041376382113, 0.11908079888070784, 0.8266645189254516, 23.877477453600978, 38.82451426598334, 30.298148355176373, 38.77356267744495, 33.77670626486502, 8.743254350077722, 1.3192059796664024, 0.24578542899220224, 0.16737292851171187, 0.07997387960072487, 0.5383875942037952, 2.366825822860964, 0.8101560596016146, 0.24376076586063833, 0.09268978235101508, 13.272594636486424, 48.52364532409176, 55.784521256723714, 57.40777454068584, 56.382329694686405, 53.64743355781802, 54.99015500468593, 51.59834423372823, 52.41470713769236, 52.77570247650147, 53.76614016871299, 54.08761370566584, 51.594837634794175, 47.8298996340844, 47.07446290600685, 42.099014789827415, 41.34284457852764, 40.172224967710434, 40.030062583185014, 41.58901645291237, 46.36658099389846, 44.638490599970666, 44.756730448815134, 43.46041456345589, 41.750673017194195, 40.093491231241536, 38.77505710048061, 39.67971255702358, 40.049297886510054, 38.95094010137743, 40.84677850046466, 39.272880400380785, 39.10417141452913, 38.78802053390011, 39.51503969007923, 38.676138847104966, 38.494340911988296, 37.18024492263794, 38.313496112823486, 40.161665947206565, 44.43175031292824, 47.788067556196644, 48.588031030470326, 51.462940093009706, 52.298616747702326, 49.812822495737386, 49.5901220844638, 51.35252537265901, 52.01104033377863, 50.83781234679684, 50.55367977388444, 51.258843483463416, 53.69172103943364, 49.849606483213364, 46.58775560317501, 45.514795164908136, 44.55190427841679, 47.27305643020138, 46.72833335015082, 47.02461742585706, 53.46656130206201, 50.868963810705374, 51.737298119452696, 42.5700443790805, 36.70042922419887, 36.62690831768897, 36.33621361947829, 39.14658400320238, 38.346283205093876, 37.50893169833768, 36.55857670691706, 36.38933427872197, 37.38709111367503, 37.076776719862416, 37.06261696354036, 37.68421065422797, 39.5061751334898, 48.581111969486365, 49.04159038297592, 51.46995329087781, 50.10727874694332, 49.0030413289224, 42.01011426987187, 36.61218766243228, 36.687893329128144, 42.36696366340884, 43.68864943904262, 45.79635074061733, 44.38346593610702, 44.437441672048266, 42.248684590862645, 39.790578349944084, 36.49707002024497, 35.8904323270244, 36.4814668316995, 38.98443714264901, 40.90349205078618, 43.93817493992467, 46.30478405183362, 50.16616136797013, 50.302385284054665, 52.45131069614042, 35.70596325782038, 3.230867832899094, 0.22211576361329327, 6.575510876794016, 6.999163627624513, 9.779474927533059, 5.175599801924921, 7.262998915487721, 5.147169482323432, 0.4161259063309239, 0.06316608674223385, 7.765795780766395, 34.985051231999556, 30.408227712877338, 32.97046699831563, 37.47301455466978, 8.477795200963175, 0.15337196689459587, 0.04093664750877408, 0.06562864573131647, 0.03108780583246581, 0.016338498887395667, 0.013676135549171558, 0.04745924650060554, 0.04558584742969082, 0.020029809280869462, 0.06378669840013308, 0.028765280055062428, 0.004998671516190253, 0.041211067864130584, 0.038531173561369224, 0.060957053060372995, 0.10571732966890258, 0.009435070885135042, 0.07204987213856752, 0.08750853053624592, 0.08393194947031238, 0.027759052294817184, 0.032015658967617544, 0.08736788445422727, 0.014235726388682042, 0.1208609956947546, 0.040578022599220276, 0.05549202312625224, 0.025630886854243376, 0.025791372698281082, 0.031100896359871955, 0.0672902521346846, 0.03219913127982328, 0.1435134571886832, 0.09262019858485268, 0.05405196168970677, 0.044612785530907494, 0.030405123815721566, 0.04231929065539472, 0.06783081909581538, 0.07665826638619747, 0.09347666190156052, 3.7150197115636643, 37.697566324664706, 42.57688891503119, 28.392170629193707, 43.49611205439414, 41.33202275922222, 10.789254807656812, 2.614092773968174, 0.7411220994207167, 0.15860969471114297, 0.5935065784761983, 1.6992488383285462, 5.105297690437687, 3.4937531717361945, 3.1876651317842546, 0.28852142934356967, 17.330006130280033, 51.699000097090206, 57.70885567511282, 56.15948415571644, 56.86166294159428, 56.499769380015714, 56.67956690634451, 52.09477901458741, 52.28323713425667, 52.67608604123516, 54.69607922338671, 56.114157246005156, 52.917504002971036, 50.34528816899946, 48.404487640626975, 43.35680123298399, 43.39244381073983, 43.093543514128655, 42.6325120464448, 43.68230304410381, 46.65238841887444, 46.7913148480077, 47.06202507019044, 47.435548459329915, 43.83666792223531, 40.395721620129, 42.10364710900092, 41.11487250174246, 42.0673220388351, 41.515413176628854, 42.74447610301357, 41.274195255771765, 40.802961703269716, 39.98662233352661, 41.57881436809417, 40.523112358585486, 40.05264759063721, 39.939655873083304, 40.0341732271256, 42.59253132727839, 47.13431827483639, 50.20465550884124, 50.44152352117723, 52.47504888042327, 52.14100806943832, 50.698136744960664, 52.37937050480997, 53.70202118350614, 52.77624768595542, 53.708077323052194, 49.3625500894362, 52.679859361340924, 56.00976728623914, 53.409345688358435, 50.06694893683157, 47.24988306722334, 45.56320897994503, 48.85904719752651, 47.937819727005504, 50.07549970380722, 55.15267449040567, 52.996429935578384, 53.48578091590635, 43.61671709245251, 38.18437168675084, 38.90855496929538, 38.362345310949514, 39.66245805063556, 39.879200381617395, 38.2253957563831, 38.7144172576166, 38.311358421079575, 38.430092488565755, 37.798712484298214, 38.574894628217145, 38.1153497388286, 40.21799510525119, 50.50599159732942, 50.306374334519916, 52.48914195645241, 53.10849205140145, 51.16796216657085, 43.618238972079375, 38.259602746655865, 38.259441929478804, 46.201304081947576, 45.8883773896002, 46.58431176216372, 46.60350391941686, 45.92314527880761, 44.722656819128225, 42.538571280817834, 38.563127517700195, 37.867436332087365, 38.228153182614236, 40.36930445701846, 42.02479962379702, 45.39528446812784, 46.84740474147182, 51.361319326585345, 53.51266876343758, 53.32074719090616, 38.7733861707872, 4.5410436584103495, 0.602249296442155, 7.924124213957018, 7.607757112672252, 10.104271692614402, 8.610800812321326, 8.712783417394085, 5.762868340938322, 0.298063054440483, 0.09953206600320917, 8.781883812719776, 43.8801238613744, 40.20678104892854, 34.4093414275877, 43.832055214912664, 14.4566140444048, 0.18962841090415755, 0.029967630154363094, 0.07552912939460048, 0.03049564859529417, 0.018485027455514478, 0.03412231074405774, 0.0436300824155971, 0.016069891224164638, 0.021647262206721692, 0.030514304751470208, 0.0716636106071453, 0.04199471452363557, 0.03660130997999542, 0.04719907538064065, 0.09402030087526768, 0.04020466964932219, 0.04335964188700722, 0.02714524158246575, 0.17146051320577824, 0.20385247264658252, 0.13532851251863665, 0.11967986431573668, 0.20843415340829283, 0.13242664807025464, 0.24015744066526815, 0.11055242465508562, 0.1308250646557539, 0.13764085698752634, 0.08015623917022059, 0.18572422765916397, 0.15739448008037385, 0.12058948647351035, 0.2980421862054256, 0.15377217122623998, 0.19160238965865106, 0.19903066928588575, 0.10234830480429435, 0.16367652363354163, 0.11077723315646572, 0.14603273732767952, 0.217964731517338, 3.642538968593844, 42.8252730061931, 49.99979403711135, 40.83643521032026, 48.28434151987876, 48.66058703391783, 15.45466015415807, 5.380171018262064, 1.460079497868015, 0.28381850750696275, 0.7536264929559924, 1.3711342383776943, 4.539416855381382, 3.249109305681721, 2.3035280839089425, 0.344140638387011, 18.095688089247673, 51.24801381941765, 58.58898062859812, 58.93155259470786, 59.75794892157278, 57.61277329537177, 59.734022463521654, 52.40227714661629, 53.92813013445947, 54.39013042757588, 56.896744620415475, 56.89274380283972, 55.059482897481615, 52.07463372138239, 51.80680644127631, 45.943098375874186, 44.375064219197924, 43.801033189219815, 43.336055817142615, 45.600283222813765, 51.434130284094046, 48.34862132226267, 49.001378243969334, 49.51771905345302, 46.75848068729524, 43.2110498797509, 45.459246558527795, 43.81987233315745, 43.61418716369137, 42.800052165985115, 43.927255061364946, 44.3219082586227, 43.36086088611234, 42.30720243146343, 44.82551705452704, 41.7108452704645, 42.81726744867141, 40.89984816889609, 42.14423971791422, 45.66652421028384, 48.200175300721206, 52.838240746528875, 52.79289030259656, 53.35543663271012, 55.84209772848315, 52.77130157716813, 54.355056593495036, 56.418235071243785, 54.86185427634947, 54.11929468954764, 50.65173902819234, 53.42109318702452, 58.93204681334957, 54.462345184818396, 52.83194926477248, 49.73991347897438, 48.06359052658082, 52.1656640883415, 47.987935850697184, 50.838475227355964, 57.74724783435945, 54.430150370444025, 55.44539313162527, 45.75518938802904, 39.44537447344872, 40.26224728553526, 39.16525840759277, 42.5614151647014, 41.614237293120354, 40.19829696224582, 39.32012142673616, 40.599437759768584, 40.559986560575425, 40.11227546199676, 40.151114771443034, 40.07526789942096, 41.51103581151655, 53.12955910159696, 51.75365832544143, 53.813404729289395, 54.700138876515055, 52.904987719751176, 46.783607390619096, 40.28672287541051, 39.73521017259167, 47.329919030589444, 47.34614979836249, 49.69901884755781, 48.04950137292185, 49.12295210746027, 46.09444695134317, 43.63244187447333, 39.82357725020378, 39.40881406107257, 39.77264527351626, 42.92449720444218, 43.53491998487904, 47.150851065112704, 49.19479031716624, 55.33819475481587, 54.24950953452818, 54.73252980939804, 39.56369669206681, 5.1508555296928655, 0.9214465716673482, 12.6578886278214, 15.959848684649314, 19.07850657739947, 11.807827661114356, 16.339162472755678, 12.145069126159916, 3.543346639602415, 0.21395075255103652, 12.864277862733411, 47.348581667869325, 37.789577284166896, 42.69301852872295, 49.94272747347432, 16.459969512877926, 0.319347704250005, 0.196416562783622, 0.17438971167129858, 0.16293735603892034, 0.15336634380923164, 0.13106797581478474, 0.25002358060690666, 0.07879603473890213, 0.08909072426538314, 0.21871071729448535, 0.1663436434201656, 0.133225861636381, 0.17392590672018068, 0.16720336261055163, 0.19018534150335098, 0.1908200913138928, 0.08677916886705546, 0.1639273867852265], [0.0226191385844422, 0.026894433972155376, 0.0471931611818652, 0.06555077289381335, 0.053896959119987105, 0.031858995902321996, 0.02897437034745611, 0.027664409792651574, 0.04874945730872212, 0.029108809202068278, 0.05045463496278371, 0.010372016526338075, 0.06365567438244339, 0.08552037915515323, 0.022309188986377373, 0.04961378451797271, 0.05984447505925933, 0.019133049739344467, 0.022807732194421754, 0.06900633505034832, 0.0447253966253371, 0.053460334968422694, 0.0836686680333749, 0.14493496397570257, 5.402614330091785, 37.118173414661044, 39.176715650866115, 35.603958099119126, 43.72514317112584, 18.644780689670196, 2.4683286730320226, 0.0827935811192278, 0.0865426468813131, 0.3788554836665431, 1.4075513616684945, 4.904491459169696, 4.05590015553659, 4.01567968149339, 0.10949457980572216, 0.794214750489881, 26.98948398713143, 54.868526228012584, 54.14589228168611, 54.96172174330681, 55.79891243288594, 54.05434416186426, 53.58198488912275, 53.05059786765806, 53.35309497771725, 54.12453105372768, 53.516457773024044, 50.90339045370779, 47.16251619400517, 44.169665382754424, 41.073562099087624, 41.46561084255096, 41.29573691275812, 37.80857332291142, 41.38837152911771, 42.83393752190375, 43.1119276631263, 42.250320219224506, 40.696367371466856, 39.86167915405766, 39.5502233505249, 39.802392528903106, 40.964720249176025, 40.44173494462044, 39.760501615462765, 40.07752718464021, 39.44410754788307, 38.74807119369507, 37.314335069348736, 39.07137255514822, 38.65051400276923, 37.60624962468302, 38.47497224807739, 35.4988895693133, 38.2999207896571, 42.14976241511684, 44.79435382350799, 47.30550227626678, 49.23739510197794, 50.1532450029927, 49.814764068972686, 48.78400833375993, 50.22808774825066, 51.34064843577724, 52.56614200530514, 50.34548820987825, 53.80150033581642, 52.442383381628225, 51.29197574430897, 50.14484720845377, 47.307024155893636, 47.4420399819651, 50.02733692046135, 51.24244797614313, 50.190174118165054, 53.811945607585294, 50.97911573225453, 50.147636013646284, 43.45767674907562, 35.60769611789335, 37.283191450180546, 37.50351490512971, 37.03221859470491, 37.37796375828405, 35.47885410247311, 37.61188214825046, 36.322555926538286, 37.11214080933602, 36.08739414522725, 37.43928217118786, 36.04960210861699, 37.130634784698486, 43.82703850346227, 49.645545174998624, 50.61643377427132, 52.08294522377753, 48.532513803051366, 48.604465761492335, 45.75080025580622, 38.10776779728551, 35.33347537440639, 36.81568022697203, 41.29241466522217, 41.906936322489095, 42.56658877095869, 40.16640417037472, 38.14359864880962, 37.86257651544387, 37.64767377607284, 37.25050633953464, 35.5972743803455, 40.271955151711744, 43.70309160601708, 47.22735689532372, 48.511866446464296, 51.18118055405156, 47.35587727638983, 18.220199807997673, 0.7899077428925423, 0.29936224762951175, 6.60544591565286, 5.45641012730137, 9.097271792350277, 8.100183231215324, 5.116303861141205, 7.838867085595285, 0.17337709665298465, 0.11440586223597489, 19.795139297362297, 37.81660241465415, 27.212180476034842, 37.03977700202696, 30.311957059368012, 2.128737217956974, 0.02667000851473741, 0.07095326324023547, 0.08483552719436346, 0.03319074782813269, 0.04509604528486248, 0.08788507807278827, 0.06245098196931424, 0.06280252439600807, 0.027203724734605323, 0.038192409481252396, 0.027137461959594683, 0.1535853070597495, 0.058084135244209925, 0.019674158707681685, 0.02401590073150733, 0.058542175383697596, 0.042948206706393155, 0.010161804872745228, 0.05443590197471842, 0.014504335009522978, 0.055944827054777456, 0.05716679092015951, 0.06746856675994012, 0.053890252020210035, 0.044325858790187106, 0.016651260028142604, 0.10195003867509866, 0.0487981690093875, 0.06768664900934504, 0.011897092655060754, 0.10545642310453039, 0.05337695012830439, 0.018285543905691277, 0.01818498528953041, 0.04858111331780111, 0.05224840685484871, 0.014055692853646414, 0.04638500353922287, 0.01474313514923016, 0.05600421036022806, 0.06546327799198128, 0.05145489681331862, 12.911375722577496, 45.435677036162346, 41.981010283193285, 38.53728302063481, 49.549874644125666, 21.795987390702773, 3.3485710524743606, 0.0745290169312108, 0.18342934999494784, 0.9594266981847825, 3.458255231380463, 8.709634734738259, 8.005956622862048, 7.138259208971455, 0.8592589247611262, 1.276124872026905, 31.884519592408214, 54.75543645120437, 55.484612910978264, 55.8625764231528, 58.32006685195431, 55.80691406803747, 54.58465645390173, 53.29320822992633, 54.89204475956579, 55.344184214069, 54.25077646009384, 51.46493265705725, 48.90790816276304, 46.59301942394626, 43.34628143618184, 42.32617493598692, 42.88757985638034, 41.310849805032056, 43.75382746419599, 45.35353476001371, 44.24107213174143, 46.14456307503485, 43.91265992195376, 42.24070648993216, 40.76167875720609, 41.04464638617731, 41.57311124186362, 42.36522213105233, 41.198497433816236, 41.75514844156081, 41.37575718664354, 41.77428960800171, 39.993317819410755, 41.33845544630482, 41.15158980892551, 39.004033304029896, 40.526822920768495, 37.97108496389082, 39.69700236474314, 44.69265460968018, 46.890421375151604, 50.29397572240522, 51.64827600602181, 52.271823037055235, 50.835870773561545, 50.04894918011081, 51.63746595382691, 53.854213068562174, 53.96099175176313, 51.31410575682118, 53.694913848753906, 53.60519355343234, 53.27641264084847, 51.92746247014692, 47.66875297792497, 50.325397829855646, 52.58690703299738, 51.69408928963446, 51.70937084382581, 54.51510498600622, 52.76485320060484, 52.17679185252036, 44.901956204445135, 38.06249580075664, 38.04239365362352, 38.73412716773249, 38.100483955875525, 38.83825825106713, 39.257030102514456, 38.01559602060626, 37.59287434239542, 39.15738621065694, 38.38150216687111, 39.09450277205437, 39.03538480881722, 39.2233879335465, 44.95725377913445, 50.8143840297576, 53.58508356155888, 52.30180563465242, 50.01468727665563, 50.26789980549967, 47.65952756327968, 39.55396921403947, 37.584256895126835, 40.76394588716569, 42.66029419437532, 45.62439795463316, 44.89681005477906, 43.3176245997029, 40.65610031927786, 38.24038705518169, 39.34188273645217, 39.32292199903919, 36.70132352459815, 41.849885448332756, 46.23726437168737, 50.13767711577877, 49.92594757387715, 54.09977305320002, 49.01096451667048, 21.823422408873036, 1.6447237254150453, 2.5739078464046603, 7.739435492023346, 7.170096107067601, 10.912551572245937, 8.752602338790894, 6.802992657307656, 2.085051820162804, 0.2675243382973056, 0.08635197525783893, 23.272867625759496, 41.28589960836595, 25.663281602244226, 41.55715504000264, 34.848297795941754, 3.2821908208631703, 0.07733793193173986, 0.058265832147651145, 0.08314124714102476, 0.05340329972246001, 0.12303899898524247, 0.07125414427249663, 0.05138775686763468, 0.05825737453696709, 0.033394454437638485, 0.019354994987107573, 0.04696746401849294, 0.06913807919068683, 0.02522553058130847, 0.004392746242604429, 0.02346210917758365, 0.068776692534166, 0.005661761791880934, 0.038030630863842466, 0.12185088088435513, 0.1368585433210096, 0.1304595181418042, 0.1407854487338374, 0.11700624044263556, 0.11326105108544712, 0.2463716701153786, 0.11526586487889291, 0.1467446168704379, 0.10139445639065198, 0.13971557630406273, 0.05952949034831217, 0.16381406705946694, 0.2511947298602712, 0.15174543965728055, 0.1457198363758864, 0.21634819406655528, 0.11119323422110851, 0.084940358665922, 0.18124443659138295, 0.13823595408710743, 0.1307811831394511, 0.2128348535587711, 0.2125686686486006, 15.461918500161941, 51.9046970336668, 51.250696720615515, 46.39721078257407, 55.46862925252607, 30.64564289585237, 4.602566524859398, 0.36479387852934103, 0.3111072948142406, 1.716731700205034, 3.868304712157096, 12.011919367697931, 11.24773967650629, 9.83421846743553, 0.556280282476256, 2.0783722689074855, 31.064300998564693, 57.0221035711227, 56.43029243715348, 57.59243972839848, 60.829218818295395, 57.74641629188292, 55.856739936336396, 55.23880973938973, 56.873281002044685, 58.03837791565926, 57.07507518029983, 55.018192106677645, 50.84657492176179, 48.8993142497155, 45.734294922121116, 44.20497455904561, 45.9376698155557, 42.290226413357644, 44.967620603499874, 47.661269095636186, 47.346796989440925, 48.37010806606662, 44.71332942285846, 43.376260111408854, 44.137984398872625, 43.2069980713629, 44.10783313935803, 44.827203673701135, 43.46078326625209, 43.077497097753714, 44.09392049235683, 45.15207006085304, 40.41965200055031, 44.619125858429946, 42.600827140192834, 40.1405361390883, 43.39546403577251, 39.89872594033518, 42.331780002963164, 45.524499108714444, 49.30198084923529, 51.707119403346894, 54.76227706478488, 54.08513084534676, 54.73250627517701, 51.93904915163594, 53.478736339076875, 56.6563033288525, 56.96355042919036, 51.46829412829492, 57.569992003902314, 55.79262487349972, 54.96245914889921, 53.70357444209438, 50.152060447200654, 52.23881236968502, 56.15838589206819, 54.0767526626587, 52.9341152406508, 56.89246139218731, 53.60685663838541, 52.22575087701121, 46.70795271473546, 40.90430790378202, 39.73003656633439, 40.69681059929633, 40.896918158377375, 41.56519982122606, 39.43313275614093, 40.671550535386615, 39.97547887986706, 40.61302877241566, 38.783537264793154, 42.27999294957807, 39.33138255150088, 41.193633694802564, 47.38737390887353, 52.466733455657966, 55.72453644967849, 54.80509757995606, 53.080858953537486, 53.502074441602154, 50.071616557336625, 43.55073498141381, 38.646685769481046, 40.264322219356416, 43.219745774422925, 46.22942355371291, 47.02696692559027, 45.37765733657345, 42.324723659023164, 41.554044600455995, 41.07818265115061, 41.80400548442718, 38.70496042313115, 44.131210465585035, 48.34443223091864, 51.69652900388164, 52.12411442110616, 55.9257540395183, 50.52644675777805, 22.188959852341686, 1.3850206545283719, 3.331500897484441, 14.507939238702098, 12.681442460706158, 21.80513239675953, 17.88270142770583, 15.25354160416511, 18.231786489486694, 0.7299939062326186, 0.17492978833615783, 28.06728659137603, 48.216864985804406, 34.95049515078145, 47.25378190317462, 43.05541415368357, 4.08283360062107, 0.26706637093617075, 0.1773324086060447, 0.16248265221234293, 0.1577337497785207, 0.18384211816855017, 0.1680030051859156, 0.1544217371772374, 0.16386884234605298, 0.1334025061899616, 0.15789946991830103, 0.1536136063476724, 0.29930350400747796, 0.13612622455243142, 0.11454775704131012, 0.13392531523300757, 0.18785778252828508, 0.14803625643253326, 0.07437477278853617], [0.03387997032053048, 0.00804360815128612, 0.02284088273412518, 0.04225616117999439, 0.02642652853542278, 0.01503247315169222, 0.045734261643261685, 0.010387537467683996, 0.013770029200391184, 0.04300927157483755, 0.05600881071821336, 0.07106832198558316, 0.0392359284864318, 0.05575012580882158, 0.058747590369274544, 0.017852750193748265, 0.01827611144812357, 0.02550724217848432, 0.02216188560029672, 0.0422765659318576, 0.018980734223019213, 0.014727709968874772, 0.05611325148493052, 0.10804622163695675, 1.9335643682749042, 20.362733717887632, 31.893452790475664, 30.784149631377193, 39.15133791585123, 29.05612199537216, 3.9393233916451855, 0.07963811858527123, 0.2847739417226084, 0.7094422187055311, 4.895652888282653, 6.465606064565721, 8.342101785444445, 7.517859330100398, 0.6477448067838146, 0.10290228596497929, 6.170595778572944, 39.23948141836351, 54.46761292795981, 56.74763964068506, 54.91479450656522, 55.414477009927076, 53.36594466240176, 53.843053925421934, 51.544411643858886, 54.831479441735056, 52.58788762554046, 51.85349833580756, 48.15902179287326, 45.56877482321955, 42.99814754916776, 42.08944420660696, 40.534114606918834, 42.669515686650435, 41.51000422816123, 39.98894437666863, 41.13966972597184, 41.17249604194395, 39.949226456303755, 40.85581564134167, 40.803730487823486, 38.92939844439107, 40.04368497479347, 39.36031787626205, 40.299160711226925, 38.37235912199944, 39.07697369975429, 40.15194239154939, 39.679241872602894, 39.93957350330968, 39.2055215374116, 38.59769536602882, 36.306901747180575, 37.256272223687944, 40.312904696310724, 38.556926250457764, 41.34775146361321, 43.43672736998528, 47.33885418984198, 46.176895172365256, 48.01532968398064, 46.77861421338974, 49.339055092104026, 52.23918499485139, 53.93137785696215, 54.29058851734285, 50.181760634145434, 54.774573695275095, 51.16831125751619, 51.739933952208496, 48.578421223548155, 46.97309317127351, 50.02609352911673, 47.41808998969294, 51.82132705565422, 53.46540420286117, 50.81289745146229, 51.041520641696074, 45.85733182968632, 37.54606085438883, 38.76313309515677, 37.32705923818773, 37.27176950823876, 38.1501333175167, 37.65070969058622, 36.56007112995271, 40.03747194044052, 39.772264803609545, 40.47438083156463, 36.385486433582926, 39.018400945971095, 37.279998640860285, 38.04544133524741, 46.52732364593014, 49.990015568271765, 49.804499226231734, 47.83930940012778, 48.514090430352, 48.06439069009597, 44.602922547248106, 40.89732216250512, 33.76005188111336, 35.49542611645114, 35.17887123169438, 38.28985206542477, 34.98455309098767, 38.152992725372314, 38.75578257345384, 37.64901914904195, 38.39472839909215, 40.49754634980233, 40.12614496292607, 46.10432740180723, 47.893893103445734, 48.69969306453582, 50.37387048044513, 35.3136948616274, 5.149314528511417, 0.147858738538719, 1.62885871866057, 6.134904661486226, 5.901497650531031, 5.876404777649911, 7.038977646058606, 5.517779040721155, 0.8508756552492419, 0.1537563898149998, 2.0393634395253275, 29.47616469475531, 49.99261217732584, 45.23713842515023, 34.83158065426734, 12.302869019969819, 0.7454419160081495, 0.04418017568006631, 0.09868003067470367, 0.008478681932413771, 0.034769249013474876, 0.0335025915785903, 0.04784206446680812, 0.012390497328353026, 0.05475073729852035, 0.07720198962957629, 0.015083019632936246, 0.06565894450872176, 0.08935472582496944, 0.017210023492694865, 0.05412946680500623, 0.02948400267820445, 0.05635329747512456, 0.0436657706215497, 0.04735489383399968, 0.06123574052546775, 0.033564928152989, 0.022564939779019164, 0.02757743008494858, 0.0446533958517736, 0.015051587045403018, 0.0312921904297846, 0.03480337056962233, 0.01881202825555398, 0.03620886994946388, 0.03520585018240156, 0.06529541280601295, 0.020765291992574934, 0.029588357260030125, 0.048912162892520435, 0.005343774016270595, 0.003822744028800498, 0.025108529803072734, 0.027381202408803568, 0.025307693511187553, 0.012544419714099458, 0.021071652468714504, 0.04047596053550801, 0.09032734339275668, 2.876886917698768, 30.67630406348936, 37.33118949397918, 34.17575643908593, 49.97758165482552, 34.17149282270862, 5.598025831484026, 0.022551920114746018, 0.5155798083832187, 1.4700381505873896, 4.087820403998898, 8.258152277238908, 10.17227186310676, 6.2148004001186745, 3.7988240920728256, 0.39120819179281113, 8.134224991644583, 42.95502501149332, 54.02808781593077, 57.555075230137, 56.283246701763524, 55.26214784191501, 55.278719855893044, 55.25008655363514, 52.929004392316266, 56.82068201803393, 53.65750620442053, 52.673132496495406, 50.94858792520339, 47.39342612604941, 46.221217955312426, 43.365579497429636, 42.423630145288286, 42.75376427558161, 42.901068887402936, 42.60456123659688, 43.10847597737467, 42.88501070391747, 41.123387967386556, 42.468505982429754, 42.676340610750266, 42.00610560755576, 41.30150279691143, 41.87366285631734, 41.38628875055621, 42.52720425205846, 40.271045161831765, 41.16138004487561, 41.320161511821134, 42.84730103708083, 39.7248355034859, 41.59275447168658, 39.49928745146721, 39.10044516286543, 41.57398200804188, 41.17399830971995, 45.87184852169406, 46.454963760991255, 48.96784982373638, 47.70167735315139, 50.56262277787732, 48.900471348916334, 51.31379196720739, 52.834800827887754, 55.8411681267523, 55.08165605606572, 51.787967297338675, 56.097581309656945, 50.902068614959724, 52.630257068141816, 49.871709039134366, 49.262898352838334, 51.78653563222578, 49.29458718146048, 53.96973471487723, 54.904572809896166, 50.826174674495576, 52.37531085168162, 47.63522848006218, 37.673184871673584, 39.74902476033857, 40.13634704774426, 38.18327734547277, 38.81048787024714, 38.613741782403764, 38.3906412893726, 41.93041955271075, 41.02113177699428, 40.922056628811745, 38.73049113058275, 40.49720902596751, 38.64311249025407, 41.53931217808878, 49.251107708100356, 50.85335669978973, 50.6181517724068, 49.34739405109037, 49.587756895249896, 50.63620251993979, 46.8607957132401, 42.40693653783491, 36.2133022277586, 37.499608224438084, 38.44411888430196, 40.875686368634625, 37.58504529153147, 40.272453292723625, 41.19936427762432, 38.87507753987467, 39.67807692866172, 42.707456773327245, 43.12594229175199, 46.601923204237416, 48.89892985743862, 50.646467362680745, 51.4446775374874, 38.458062910264545, 7.154716983918221, 1.5525300079776396, 4.154040063581159, 7.359463236024303, 10.124486607889976, 8.591640034029561, 9.085830238557632, 6.173176207850057, 0.8371112615831438, 0.20711945459967662, 2.368283473676251, 33.25909068507533, 47.17718193607946, 41.5189354650436, 42.00567414683681, 21.083996795838882, 0.9815686003815745, 0.04629140291663428, 0.09832235188373635, 0.02083750535553742, 0.04841743480233897, 0.025596094971162178, 0.044114629197264874, 0.017476725512214245, 0.046731937947052146, 0.09667888644241518, 0.026889437163669257, 0.03453716267681411, 0.013830891055535647, 0.05745720336093538, 0.05874476350483395, 0.02868320139485502, 0.060159176317674506, 0.014470737265993752, 0.025182736909858165, 0.22529732676283007, 0.15320138975737557, 0.2101233466378143, 0.18309746538439106, 0.13362471765327838, 0.12635124141290305, 0.08995889340557399, 0.21708449649233974, 0.08330963326678162, 0.13737444225097858, 0.21707148831938544, 0.1582625802726515, 0.07626990577386272, 0.27499387942014203, 0.15190702292226976, 0.12252167513173436, 0.15745369867692072, 0.26500826040583275, 0.10508162224845541, 0.10725302952191523, 0.10451186733740954, 0.14805185398267162, 0.1508435703093006, 0.21341588528406238, 3.1224189554491355, 33.79695353969451, 45.34620777253182, 41.83886358814855, 51.21838815750615, 41.26060816549486, 10.278959351201213, 0.19227781873797217, 1.128644243844094, 3.5809185331867592, 12.212700593856074, 16.928186762717463, 14.484046120797435, 13.364019201647851, 4.199370405366344, 0.3238537108465549, 7.897893363429655, 42.92405397661271, 53.48924436876851, 59.28116521527691, 58.97112930974653, 57.55434174691477, 56.69007101366597, 57.406205592616914, 54.209081665162124, 59.64651046260711, 55.49991407702046, 56.16845069393035, 53.68656704502722, 49.85846711743263, 49.3023770086227, 47.17625233434862, 45.13904386951078, 47.35004863431377, 46.88202750298285, 45.23543219412527, 45.37323682538925, 44.75932705786921, 42.68106314443773, 44.72899536932669, 43.98126217626756, 43.15573269321073, 44.249638588197776, 41.766413488695704, 45.02156103810957, 43.76477479934693, 44.36697629190261, 44.441187535562825, 43.223683834075935, 43.952177801439845, 42.9229361011136, 43.40284593643681, 40.746412892495435, 40.85636869553597, 44.668888968806115, 43.16775868015905, 47.123500377901145, 46.44726807071317, 50.29588199430897, 49.1544448175738, 51.87207075857347, 51.80198977070471, 52.85247110551404, 55.55285038486604, 57.85878435257943, 57.51438063959922, 52.62632685322916, 58.85428190231324, 52.97105612293367, 53.91544126695203, 51.04932223596881, 50.429156288023925, 53.99508499330091, 51.56376854065926, 55.960835718339496, 57.02920306113459, 53.219918743256606, 54.20600260457685, 49.68473357539023, 40.20926783161779, 41.4978095792955, 42.341064253161036, 40.797721416719504, 40.983579004964525, 41.25331647934453, 40.41099925195017, 44.27952704891082, 43.9033168362033, 44.33490699337375, 40.42171124489077, 43.19888268747638, 41.28830402128158, 41.49862150992117, 50.60739271102413, 54.37806521692584, 52.10770322430519, 50.40816768523186, 53.43122859154978, 53.03857972545009, 48.45932237563595, 44.98003490509526, 39.41445050701019, 39.29309237387873, 39.55211001057779, 42.2521205871336, 38.10851696998843, 42.39593036713139, 42.487156852599114, 41.2249263640373, 41.250268797720636, 44.97595564011605, 44.51666178241853, 49.49079198222007, 51.36990539489254, 54.07534060939666, 52.18557796170635, 37.93437157907794, 7.230633478010855, 1.3176087169877946, 5.690463839038726, 13.603328889416112, 16.828560521525723, 12.240051281067634, 15.517657341495639, 12.066760966854712, 5.1525009639801524, 0.510050430893898, 3.4267934099320447, 42.18558149953043, 59.37468236492526, 49.8381688517909, 49.42872047424317, 25.25932650412283, 0.9598430210063535, 0.1312084456965808, 0.22207719874718498, 0.131801811437453, 0.12243339115934027, 0.14557170561484753, 0.19542607238456128, 0.16887842917874937, 0.13608389053373568, 0.128577868303945, 0.071292333755522, 0.17159986459920484, 0.17558254121292025, 0.13712264447202607, 0.16850514517676446, 0.16768661087318776, 0.21462972095656782, 0.23928083689703097, 0.09704545951418339], [0.020471217651521007, 0.0067323174763230555, 0.04144861257725185, 0.035816441410251205, 0.05477207667765118, 0.022380624770096714, 0.04049944113038721, 0.02618042278974768, 0.034690544970573924, 0.019095953846830997, 0.07788183137534127, 0.042265143560906576, 0.015349943817953671, 0.05784648710921888, 0.07835119812478943, 0.0168329167119678, 0.016810744212219314, 0.024626361724409847, 0.06720922301493346, 0.010609056579039223, 0.11758846726508872, 0.030941055944910457, 0.12337367215584363, 0.07444863132531605, 0.05392592107396453, 6.045217216014863, 32.5546996824203, 29.603518170695153, 32.570296987410515, 39.178516018775206, 11.591986494679606, 0.41305701939329026, 0.30146966357865645, 0.49296691533057924, 4.0653133536538775, 7.812830882687723, 8.054840632023351, 3.8503267736204214, 2.6355488742551496, 0.28240173514331546, 0.3926671909228448, 18.175792694091797, 50.10250130007344, 53.7293012680546, 54.22493196302845, 54.42385888868763, 55.18155882435461, 53.49297062043221, 53.33358510848015, 53.68307221320368, 54.68109576932846, 52.8132591709014, 49.05240827991117, 48.098954616054414, 47.320450428993475, 42.56278407189154, 40.138669090886275, 39.88236965671663, 40.49727178389027, 40.36404455861738, 39.97238805217128, 40.869320361844956, 39.66886720349712, 41.59664546289752, 41.38905794389787, 41.21669330904561, 42.51942619200676, 39.18669023821431, 39.86213414899765, 39.72035223437894, 40.88866941390499, 38.51037948362289, 40.481186143813595, 39.424064236302534, 40.57407179186421, 38.820760557728434, 36.530916152461884, 38.11024673523442, 39.75690087964458, 40.20551412336288, 41.20231782236407, 43.9725152907833, 42.346559493772446, 45.79773533728815, 46.69737016001056, 46.044240613137525, 51.06527451545962, 51.260804668549575, 53.603867792314105, 53.89143243912728, 51.5262589147014, 52.99506495075842, 50.0126515665362, 56.466288028224824, 51.16758561903431, 50.189303351986794, 49.834003294667895, 50.09482129927605, 49.68122305408601, 53.500717301522535, 53.035477130643784, 49.724055336367705, 48.380796524786184, 40.536303289474986, 36.24222970777942, 36.617204373882664, 38.347228496305405, 37.980059346845074, 37.71666826740388, 37.919599933008996, 42.75704729941584, 43.61935684757848, 43.96281919171734, 40.23158611789827, 35.39827685202322, 36.56638614593014, 34.98846369404947, 40.585046583606356, 47.851068665904386, 49.0932087744436, 49.461464420441665, 50.297819645174094, 50.36020886513495, 48.72921282245267, 47.92866491502332, 43.922995367357814, 38.05287030435378, 34.86945506065123, 33.68813522400395, 35.69615733238959, 36.23442419113652, 41.12760059295162, 41.45237284321939, 44.424945000679266, 43.253564450048636, 42.772297474645804, 42.246307634538226, 47.869841129549094, 50.462872982025154, 48.154840546269575, 20.82754242804743, 0.6964097760858075, 1.6130328130337501, 2.919350252036126, 5.242296274631254, 5.105455075540851, 9.077133363293065, 5.867575032095756, 4.440232861426569, 0.21426434298196148, 0.060657631425607594, 6.7147555082075066, 42.83176452882829, 40.24406709978658, 32.01415981015852, 30.767089282312703, 2.503853334534553, 0.14246665932718786, 0.04153124665120437, 0.09849685905200821, 0.05898202476542323, 0.006831024074926973, 0.11893679733358084, 0.048882974942605344, 0.016521251076952587, 0.03389947491908266, 0.01855136875453736, 0.07914785295724869, 0.06632470555843846, 0.06644656716455376, 0.045053435474514, 0.03003572387951276, 0.06291793554180092, 0.019519115918345993, 0.026053459038056677, 0.05480740865271899, 0.03290619595997757, 0.051285694803922414, 0.047566360914178436, 0.006319653682200419, 0.05442266397538686, 0.05633357837195358, 0.025915023119699572, 0.023165788283691775, 0.023580701503482078, 0.03864373486008375, 0.05215524673281659, 0.03284567118351979, 0.05976618853427711, 0.06519045109950727, 0.048046376285774094, 0.040884331364424965, 0.023249563828651464, 0.011341699019765422, 0.05522496487584807, 0.01889697783025763, 0.062862754228615, 0.03702822013667995, 0.042624676284650644, 0.0651828668290569, 0.04813955172956471, 9.947407284090596, 39.379812056018466, 29.593080743666622, 36.411734934776064, 45.53605441124209, 14.346001244360401, 0.3099578871361671, 0.062260498037381526, 0.20424356053192771, 2.182375139767124, 6.830850801160259, 9.219948822452176, 11.584736974008623, 4.998721499596873, 1.680690266432301, 1.3341291272832503, 20.286198469900317, 51.55774378007459, 55.13643587789228, 56.07141517823743, 55.50060049180062, 54.795126914978034, 53.673148616667724, 54.53596415058259, 53.90022247068344, 56.02185995348039, 52.37020784808744, 50.90067617354855, 49.628533855561294, 47.62617957207465, 43.2039660792197, 42.004364075199256, 43.03307625555223, 41.970780741783884, 42.28076565650202, 41.61864211482387, 42.66931172340147, 41.50204966145177, 43.191861644867934, 42.772419068121145, 40.97514198672387, 42.702695015938055, 42.74367593949841, 39.74072502505395, 41.94243769491873, 41.4910513354886, 41.78882983423049, 41.09400157005557, 41.53672733614522, 40.67282138332244, 40.13313854894331, 38.855634350930494, 39.61054155903478, 41.59622969165925, 41.31130479997204, 40.56687424259801, 46.11108564561414, 45.45254715027348, 47.64944707193683, 49.59078104265275, 48.984351235051314, 52.65802744896182, 53.75494964661137, 54.898442145316835, 55.01840391466695, 51.161666762444284, 53.62065553665162, 50.24359287754182, 56.663979407279726, 52.46742771517847, 50.974287294572406, 51.57275076835386, 54.45464949454031, 51.83356877296202, 54.98206315502044, 54.19579659738849, 51.93625250170308, 49.19430786563505, 42.23212434399513, 39.191228420503684, 37.92338894259545, 38.57345511836391, 38.34601256155199, 40.512902429026944, 39.092765162068034, 43.759797311598255, 46.771467654935776, 44.66670028624996, 41.32410741621449, 37.3687187317879, 39.37900797013314, 37.36465123391921, 43.92062233340356, 49.2593054617605, 49.98192764097645, 49.77541485140401, 52.712924941893554, 50.60962846202236, 50.65877576028147, 48.64636059730284, 45.022761283382295, 39.43348969182661, 36.38618853784377, 36.41229191134053, 35.74821895168674, 37.747258832377774, 43.56010944612565, 43.140588421975416, 45.477626785155266, 45.98388318092593, 43.85802522782357, 45.15992264593802, 48.91243850031207, 52.66829229170277, 50.107506244413315, 23.07144803385581, 1.4504999667406084, 2.1599472722699566, 3.666753475704501, 5.553340719592187, 7.459520937934999, 8.993743773429625, 7.683758918316134, 4.46941823728623, 0.40921398528641273, 0.07173353911287363, 7.730487094771478, 45.84510972422939, 47.60328077500867, 36.62769671409361, 39.86284409799884, 4.948704415752042, 0.23176163795494267, 0.040485341282140826, 0.01876590210163305, 0.04514904707790383, 0.07671681848625023, 0.0468550099720878, 0.03962692061078645, 0.030635084258392457, 0.015581166390479814, 0.015049603835289038, 0.039784968380005135, 0.024885950617552288, 0.023828833551716902, 0.05073377441975379, 0.037670561878551403, 0.02373858264857723, 0.03099525475033349, 0.04162128496494505, 0.03664386999462882, 0.09332362817780626, 0.12306267876298198, 0.09741914954276816, 0.14011480004316376, 0.17496714278334574, 0.16790785706571995, 0.10380301384195205, 0.09348592390456507, 0.0971813022249168, 0.1417497695694047, 0.12776978343965548, 0.1674029285148267, 0.08753516741337315, 0.1837229455310491, 0.25925634969626704, 0.13924754254760283, 0.08345940345597845, 0.10570460494848029, 0.09435257619066585, 0.08742331857642821, 0.19989302381873134, 0.10990268250386562, 0.2181914016123741, 0.1064734201457712, 0.10327054443018091, 10.120071980261034, 47.34769128984021, 39.52036234640306, 43.72428417205811, 52.04705161433066, 23.83433726526076, 0.5161534550209199, 1.5999020660115828, 3.4020670335139003, 8.910545399112086, 17.447473272200554, 13.629075327227193, 14.850737721689287, 7.781691185889706, 1.1924462525113937, 0.792528253889853, 20.141468894097116, 52.74540216692033, 55.235126633797925, 57.434403511785696, 57.674656529580396, 57.03090929215955, 55.19704826416508, 57.03186635048159, 57.97136422126525, 57.15615449413177, 55.85382561529837, 52.783790403796786, 51.402578738427934, 53.30283764869937, 45.44160765986289, 44.330192304426625, 44.42425858589911, 44.748062010734316, 44.74906613749843, 43.307583332061775, 45.28716825669812, 45.32939649397328, 45.94613821275773, 45.34143032566194, 44.8411359325532, 45.25707583273611, 43.99683006348149, 42.787484891953014, 44.473813810656154, 46.33645719097507, 43.228516194128225, 45.0120218338505, 44.51367293634723, 44.85320506557342, 43.238216215564364, 41.3476534043589, 42.42645817418253, 44.54199637136152, 41.33870647799584, 44.6679711341858, 50.090761646147705, 46.80362324560843, 50.26864113346223, 52.944152585921756, 51.29929488705051, 54.51257897961525, 54.278542918543664, 57.89572915723247, 55.780559662849676, 53.86503881023776, 56.4945016368743, 52.05707719249111, 59.609973584451986, 56.34031326540055, 52.51795568773824, 52.84523825491629, 54.70863473030829, 54.51457154366278, 56.28020686487998, 57.185952740330855, 54.17290172269268, 52.97415871773997, 44.94671829285161, 41.967246686258626, 39.54264533135199, 41.49789194906912, 40.93261957168579, 41.312406985990464, 40.94035056329543, 46.94569933799006, 48.1831600589137, 46.6729808622791, 43.89676255564536, 38.332182284324404, 40.358333587646484, 39.25884615990424, 45.80157533768685, 51.39504778769709, 52.30808927166847, 53.23907952154837, 53.601820315084154, 53.13776469999745, 53.04948391452913, 50.120234335622484, 48.4592439282325, 41.73521103397493, 38.93705491096743, 37.784642942490116, 38.998400780462454, 39.79679138429704, 46.00012179343931, 45.94661281954858, 48.22090110471172, 48.22833399618826, 46.36716542705413, 47.996937690242646, 50.769268928035615, 54.73855064761255, 52.175069932014715, 24.61871716283983, 1.335232293894214, 4.2163537779162015, 8.210618053713153, 12.61015828578703, 13.146276666272072, 18.526462393422282, 15.451086874931091, 12.475772000128224, 1.8448428064584734, 0.2161408753524865, 11.729143934865153, 54.6810761574776, 47.319913064279866, 41.30572326721684, 50.234316472084295, 7.3205170419908345, 0.530984855947956, 0.11521852830605162, 0.13543303755502548, 0.12883752614500063, 0.24219422330779417, 0.28298466676665895, 0.24154196072730327, 0.16385885255952037, 0.15001075612681528, 0.18036812393655702, 0.15121922918385075, 0.19748363133159377, 0.22301038576950952, 0.13935885512300078, 0.2082516712647292, 0.19964255903276706, 0.14948967844247818, 0.1295077917917121, 0.12211547999252235], [0.027948199403322035, 0.07830484214449122, 0.039158917497843504, 0.10182044724182737, 0.11103809375556246, 0.03216394486146108, 0.045999979239798365, 0.06580263962067905, 0.015537387338436901, 0.045598602793630094, 0.031260411187465635, 0.05803206041755696, 0.055632515990686034, 0.02286710209333368, 0.03854549940555327, 0.05273124909088497, 0.005725458651150187, 0.024527120779478745, 0.007040524224360144, 0.0671145192257339, 0.06565491488624005, 0.0284476523407765, 0.004946931853004161, 0.02696657264154525, 0.021130409497287006, 0.12544103702830692, 17.518048478711037, 39.78234921732257, 30.578897883815152, 39.95766739691458, 25.353273153305057, 1.4123611680922972, 0.051398980055725386, 0.8920803377705236, 1.4657989264495912, 3.9062847773874965, 9.271782944279334, 7.092739122529184, 14.379408071118018, 4.1003690467726805, 0.2824411733496574, 4.108706044573938, 33.57362947156353, 50.50381075951361, 56.6910869075406, 52.474260484018636, 55.365019844424346, 52.89587213147072, 52.18119667422388, 53.36779994349326, 54.15529812535932, 51.67414795967841, 52.11034690180133, 49.501437294867735, 47.4109551983495, 42.84994863694714, 40.66460794018161, 39.85204973528462, 37.517164753329375, 39.531745064643125, 41.016472001229566, 40.299482345581055, 42.15821904520835, 40.24727167621736, 39.58390474319458, 40.387657227054724, 41.16009350745909, 39.761391993491884, 39.18748255698912, 39.19371520319293, 41.5104474559907, 38.712224652690274, 40.5046340727037, 39.928241775881865, 39.84365978548604, 38.525759097068544, 37.05257177352905, 38.45992995846657, 39.14015523848995, 39.21136194659818, 43.26234271449428, 44.00743615242743, 45.56092616050474, 44.70148386493806, 46.66753661247992, 48.17393072189824, 51.09219374195222, 49.99191399543516, 54.39277018270185, 48.959389271274695, 50.41692241545647, 52.83270235984556, 52.43506423888668, 51.41879381672029, 52.44161459707445, 52.16814302629041, 50.40704980973275, 51.58112895104193, 48.42635877670781, 52.00120302938646, 51.91736628932338, 51.88211202621461, 50.14454126358033, 44.50193720479166, 36.093520887436405, 38.029798923000214, 37.471582889556885, 37.5568473723627, 37.99532521155573, 39.54877599593132, 44.06738173577094, 48.68980084696124, 48.507410633948545, 42.73176762365526, 39.919832214232414, 37.253255921025435, 36.57472902728666, 36.52047480306318, 42.74453886093632, 48.88204013147662, 49.32941390622047, 49.87453706802861, 49.937530332996005, 49.66464711773781, 49.29789766188591, 47.7395478371651, 46.31988909936721, 41.88064075285389, 34.92271692522111, 34.20034577769618, 37.15296091571931, 41.507423308587846, 45.60931251895043, 42.9282352232164, 43.98476485283145, 43.81316508016279, 44.47223309547671, 48.637076347104966, 48.12243784627607, 42.976998129198634, 9.36222887808277, 0.5075683366627463, 2.5896284609071674, 3.259438132086108, 5.059010780626728, 7.4809875795918135, 6.934456286891815, 4.166564191541364, 3.865225161275556, 0.10985601242751845, 0.054921191861672755, 23.781436258746734, 41.26101216962261, 27.576643190076275, 36.688552287317094, 13.87655923443456, 0.7743906626297582, 0.04054927898030128, 0.04248853479962676, 0.053522958825793, 0.014613480513705122, 0.012969745026390641, 0.06234610453248025, 0.014715287853182565, 0.017909752880974163, 0.025006617126505704, 0.0969893359128506, 0.036811068684103034, 0.05919152299963659, 0.033466256028341676, 0.06521221565743608, 0.039472756907343864, 0.035788061683096235, 0.05407784013978897, 0.06653943234273503, 0.023888599901129643, 0.009932938020586247, 0.04466834605761594, 0.07508672127920775, 0.07282821746963648, 0.0997147856340293, 0.011134849534550262, 0.00917095153953039, 0.051720660375130754, 0.04505921177746308, 0.06673922041250814, 0.047513060346846624, 0.025744509184733037, 0.03294178840493964, 0.02606120418697115, 0.012481932794945616, 0.01765198153143208, 0.009828796985769465, 0.05472392805161015, 0.046800916503754356, 0.016110553255965634, 0.06162167263908252, 0.06620554058181663, 0.10664764386151107, 0.06333585182625441, 0.043567412592951334, 0.8432269108391578, 24.86973708675754, 43.126683619714555, 31.230274131221158, 50.10567841991302, 29.159452915191654, 1.86051880400027, 0.15607080272128507, 0.3288984611149757, 1.555784472054051, 8.173470266403692, 8.95522217596731, 11.099257373040723, 14.893261117319907, 2.648148262693036, 1.216308359176882, 5.93186709188646, 37.286078314627375, 51.5452588758161, 58.317827178585915, 52.82761896810224, 55.94778207040603, 54.496771827820815, 53.663432905750895, 54.87964222508093, 55.923043681729226, 53.99212360382081, 52.84298681443738, 50.93591474717664, 49.423366438957956, 44.4539430833632, 42.97493496248799, 42.44265756299419, 39.59743692028908, 41.59233085570797, 41.40845798677014, 41.59311925211261, 41.933710421285326, 43.04817345834548, 41.54033983907392, 42.7263782870385, 42.68848034643358, 42.29340353319722, 41.564901721092966, 41.34180907280215, 43.20065559879426, 40.39741216167327, 42.200972880086596, 41.04159478218325, 40.27308479432137, 40.441887917057166, 37.953650028474875, 40.87528236450688, 41.62618483266523, 41.97637011927944, 45.46513795852662, 45.74559134821738, 47.276096267084924, 47.59883280723326, 49.756877729969645, 49.63859865742345, 54.038376192892756, 51.57335873573057, 56.175350143063454, 50.696442281046224, 54.04727997318391, 53.55263379312331, 50.608420372009284, 55.34128558251166, 53.57369299857847, 53.35851177092522, 51.86635586523241, 52.476182445403076, 52.38777222171907, 54.96513028298655, 52.55445726456181, 51.57046794891358, 51.5215128467929, 45.262284740324944, 38.36052140881939, 39.01631032266925, 38.35613619896674, 39.23138564632785, 38.568469785874896, 41.85405492782593, 46.21386743360951, 48.46609630892354, 49.58390512774068, 44.97931711135372, 41.34039701954011, 37.659578169545824, 38.494364446209325, 38.996172874204575, 45.67931505941576, 50.78704903202673, 51.23098681049963, 51.20854693074381, 49.7131746815097, 50.561818691991995, 51.475330860384055, 50.13382927063973, 47.426742738293065, 41.164643456858975, 36.127998521251065, 37.02983379364014, 39.09363200587612, 44.6268254710782, 47.04028729469546, 44.7697840967486, 45.70124895341935, 46.8128368931432, 45.825599854992284, 50.57586469957906, 49.14875738082394, 43.765786770851385, 10.755913680599583, 1.4479615803687804, 4.942434997327866, 3.194853855717567, 4.630250123239333, 6.2422069811051895, 8.86774645697686, 6.677153706550599, 1.6473765959662776, 0.09171213924644456, 0.0620158555196418, 22.152150369459584, 47.352001974659586, 30.307516936332952, 42.51770034913094, 22.984030169825402, 1.6128267660256357, 0.11642268062719416, 0.04456962030681391, 0.027367516248036298, 0.07980061349489036, 0.008775676983679015, 0.059953159953077, 0.026622539791729183, 0.027196462221083142, 0.0533539904732137, 0.09205713162138578, 0.06595465444749402, 0.023696419084444646, 0.011575097281996523, 0.0810932336495288, 0.006572391355275027, 0.028683314392823848, 0.02882463846265549, 0.09249689673343975, 0.005446709899021494, 0.1473755822066338, 0.16147697795062296, 0.16521924085194067, 0.21138941418499718, 0.17469435419526794, 0.19819092966856497, 0.1233572012654716, 0.1357671131770457, 0.16688859240422327, 0.17917431380239227, 0.09371215732948435, 0.1262371939036154, 0.2056615586362539, 0.16325401082154245, 0.062170340980012576, 0.1716126889110573, 0.0886906961339616, 0.1311215713259674, 0.09777065366506578, 0.14040709322979375, 0.25125004140840423, 0.12051142977490542, 0.16642503260124117, 0.10430015893953462, 0.10945400012837303, 0.48644833446991065, 25.908386591942083, 54.156776858914284, 41.2256637696297, 51.54539223640196, 40.171009032957016, 2.95565644579549, 0.38951072481370747, 3.649070450375157, 5.129462922773054, 16.641516416303574, 17.879506657200476, 17.386080334263465, 27.837878927107784, 8.22252195688986, 0.8339315064011082, 6.355657615969259, 37.0404516496966, 53.348039042565134, 61.554967126538685, 55.477948804055494, 56.65195342033141, 57.197041280807994, 54.1800678929975, 56.987010125190984, 59.03573859122492, 56.0201301882344, 54.8359077976596, 53.04340031839187, 52.27211329244798, 47.181676972296934, 45.5198157987287, 44.05864661739719, 40.99129430709347, 43.684330909482895, 44.00340395589029, 43.601608122548754, 45.62923423705563, 44.93348421589021, 42.521057897998446, 44.08338892844416, 45.1698854661757, 44.15043792416973, 43.03661031107749, 42.87058814879387, 46.6523648846534, 43.066420324387096, 44.80480694001721, 44.13193610406692, 41.834090063648844, 42.40465371839462, 40.72461628144787, 45.177028102259484, 43.94008513419859, 44.68039720289169, 48.56513615577452, 47.967021772938395, 48.75890908702728, 49.012839409612845, 51.83340011104461, 52.03490011153683, 56.21650757328157, 53.27866015895721, 59.23690519025249, 51.657270000826934, 54.80893365798458, 57.947233799965154, 55.04535059775076, 55.307741472798014, 55.291785270937034, 55.193016067627944, 54.06353819754816, 55.85797548294068, 53.9448590432444, 56.473414974827925, 54.27972355196553, 54.84317202721873, 55.15274901543894, 47.6748404964324, 40.04314368770969, 41.344954813680346, 40.95167836835308, 40.86367214879682, 40.06987856280419, 44.68312325016145, 48.360235460342906, 51.78526478428995, 55.24260659371653, 47.92145952101677, 43.14266335579657, 40.74291021593156, 40.431834882305516, 40.859353619237105, 47.06413138297297, 52.91711568832398, 54.49460667948569, 52.06504744868125, 52.74310365799935, 52.18202429433023, 53.67473325421734, 52.030197189700225, 48.6962531458947, 44.333828341576364, 38.83210797463694, 37.42828384522469, 40.4772049380887, 46.18865443814186, 49.17471170425416, 45.787070412789625, 46.65892700995169, 48.626023107959384, 47.37502628757108, 54.217655966358805, 50.94637963079637, 46.40201176366499, 11.16791650172203, 2.1087230790045957, 7.227064121154047, 8.34294411443895, 12.745608514355077, 15.13192165282465, 15.906435808827801, 15.522133746454793, 7.692793607711793, 0.3464259399521736, 0.1510376510240378, 33.935189631677446, 49.170153910113925, 35.73990352692143, 51.40745032218195, 27.821367709867417, 1.860812859189126, 0.13073832818096684, 0.15654868836845123, 0.16629035434415265, 0.2363981093249975, 0.08655933227630393, 0.15005911159659588, 0.07279078641365613, 0.12163754838008074, 0.1327577053058532, 0.17636137684026074, 0.15425361152137482, 0.0632013535998281, 0.1455098823193581, 0.19744123602586408, 0.16754790299361752, 0.1319418216664945, 0.20094748255946945, 0.24520599072979343, 0.1381857293627916], [0.0670584645723143, 0.07648769690985642, 0.042960877800660754, 0.03765342066124563, 0.015003442249801612, 0.08041219680660194, 0.024330199793762258, 0.057581060626093424, 0.023039981324766434, 0.06767432265464338, 0.009336776058790425, 0.02954808210263089, 0.03635174534734219, 0.027382502843055035, 0.015729112332806956, 0.053383117136094844, 0.0464603214734985, 0.04580292610391494, 0.08313184724219384, 0.05696903298338575, 0.04800314594420695, 0.06935407768093771, 0.007899484508896187, 0.05860528570689982, 0.021907718694438378, 0.053010116586641925, 2.57656378130759, 32.82818890387012, 29.595951918632757, 28.103539097693663, 44.08941368902884, 5.738674181122934, 0.05133368638193896, 0.09483934845775367, 0.48017983535124414, 4.884729087352753, 7.761210039738686, 11.519088264434568, 11.97668275525493, 3.068832269599361, 1.7475437565195946, 0.4219862031600168, 13.689975027115116, 43.82364565326322, 55.683324106277965, 54.45139000492712, 54.91155462880289, 53.76680304927211, 52.371965069924634, 53.80712501464352, 56.611082323135875, 52.9238425531695, 51.992381618868926, 52.56258441555885, 47.23666860211281, 43.889262983875895, 43.59348881629206, 40.420781643159934, 39.58428913547147, 43.115595079237416, 49.70654195354831, 50.45696589254564, 46.71238891540035, 44.49035444567281, 43.393287120326875, 40.29577570576822, 41.47762114001859, 40.095350434703214, 39.90626865817655, 40.1334797951483, 40.834501481825306, 41.47418122137747, 38.783674547749186, 38.9305555435919, 39.41926717758179, 38.91361482681767, 37.769949743824625, 38.226674449059274, 41.67525368352091, 41.733736222790135, 44.60433460051014, 44.67243479144189, 45.79868455086985, 46.84430606903569, 48.117672166516705, 48.53691862475488, 50.33537633957402, 51.478700176362075, 53.866101772554465, 53.170179167101466, 51.75588230932913, 54.494116383214156, 53.94007375163417, 51.19581491716447, 51.86718740770894, 51.22767633007419, 51.73342281772245, 51.720914379242934, 49.90321743872858, 52.0386028289795, 52.80614006903864, 52.07557901259392, 50.726675910334436, 46.49714100745417, 38.65024728159751, 37.79251513942596, 37.00436976648147, 39.16202245220062, 37.73474647152809, 40.13854357504076, 47.31981500502556, 49.56765867048695, 50.320875337046964, 46.503079475895056, 44.82051211018717, 40.01311794404061, 34.538458008919996, 35.628217958634906, 37.628254121349705, 45.7801317399548, 50.38448833650159, 50.20805620378064, 50.21116664332729, 46.18250416171166, 47.54343717328964, 50.3528622658022, 47.81861497509865, 46.2521929125632, 43.68116947912401, 34.52985232876193, 38.50631590812437, 44.976175292845696, 48.0033350759937, 45.97941167892949, 44.0218783194019, 47.76681615460304, 45.88010903327696, 48.93531768552719, 48.98431593371976, 31.889612790076967, 2.50460397812628, 0.812863169177886, 3.605911630776621, 1.5613930936782592, 2.400204457582966, 5.042330901468954, 7.197800788187212, 6.230832107605473, 0.8361664606678871, 0.07892770993132746, 2.864247570114751, 38.55076420691706, 36.035846356422674, 34.74761447598858, 27.326331253974672, 2.7011112916854123, 0.32599026878033915, 0.11519267283860715, 0.05737974421091138, 0.04257528659617228, 0.05405185060695775, 0.06187376536188587, 0.018266866682097316, 0.10146910399799386, 0.02833045046446064, 0.04647758143443254, 0.06825988962044639, 0.03341409310157741, 0.071052257121811, 0.0549784722557712, 0.03327544267860151, 0.05119291006497318, 0.03781599601009681, 0.0022155882822605033, 0.06292911276461617, 0.030898361864890304, 0.07623226021326358, 0.07730630016134632, 0.05123752702568328, 0.030281934962277452, 0.06413890349288141, 0.04892851120882458, 0.03955630262592628, 0.030984157966750286, 0.044591526591008714, 0.04070700882303138, 0.03676009702406103, 0.037105093229441874, 0.12051768105236754, 0.10770633140759123, 0.031796937034795844, 0.024014403029615362, 0.06558557626821342, 0.08731761376463598, 0.05166098595626893, 0.03969873752324812, 0.01579607224782869, 0.012009235478246645, 0.027634118676125526, 0.043436139596686255, 0.024078905717619968, 0.11361765735332044, 5.302016321689853, 41.648962036255874, 29.629031227480983, 36.21450639540149, 51.48332465079523, 6.335447113360129, 0.05739932924869561, 0.07937721202089902, 0.635042394841871, 4.373509422425301, 8.458575587118826, 9.920018353769857, 12.284090672769855, 10.1864129881705, 4.16904067800891, 1.2704179460002532, 16.55298067677406, 44.13934938369259, 56.853406352381555, 54.61209735562725, 55.78789449507191, 55.40579288236557, 53.20905770024946, 55.520290790065644, 55.848004817962654, 53.62982996048466, 53.881952070420795, 52.60717391967774, 48.31240215609151, 45.472406110455914, 44.35025130548785, 41.115915852208296, 42.40153543410763, 43.18138891650785, 50.00396351660452, 49.81717632662866, 48.30833465822282, 45.71782096739739, 43.767481234765825, 42.68697415628741, 43.6669038188073, 42.280848026275635, 40.73720316733084, 40.991266850502264, 42.03277772472751, 43.13814086298789, 40.015977351896225, 42.518084741407826, 41.45706792031565, 40.44645747830791, 38.8555480587867, 40.758889952013575, 43.63901576688213, 42.44266933010471, 46.32568244011172, 45.41874808649863, 47.0523250487543, 49.07761343063847, 51.134657321437714, 50.87610252441899, 51.17502243288102, 53.93321352620279, 54.728772178772964, 53.601961520410356, 51.68262812399095, 55.94264376548029, 54.977203338376945, 54.58327970197124, 53.56499318153628, 53.427937722975216, 52.273176254764685, 51.547431868891564, 51.99872409143756, 53.68840271426786, 54.748560536292295, 52.39783702358123, 52.069475804605794, 48.99395319723314, 39.31737968998571, 38.72713358171525, 37.79032253449963, 39.169263147538715, 38.61357312048636, 42.76458609488703, 48.88487208274103, 50.54095560504545, 51.887124815294825, 50.084952615922504, 46.028445228453606, 41.51342453495149, 37.198895792807306, 37.254001171358176, 40.22589475877824, 47.741050104941095, 50.79916131111884, 51.03234229549285, 50.65873653657975, 48.46157381611486, 47.927476436861106, 50.09268752990231, 49.30819388358824, 47.50675516743814, 44.44934214315107, 36.87550029447002, 39.91721991569766, 46.20850163121378, 49.81944737895843, 47.07234874848397, 45.51320660498835, 49.980550889045965, 48.42648429255332, 50.68804840887747, 49.23198615351031, 33.30978731955252, 4.4827258586883545, 1.148123101842019, 4.633876844759911, 4.672942671083636, 6.332033180421399, 7.392618050498347, 9.371984793293862, 1.7724802248900937, 1.1286466953254517, 0.10409481673231048, 2.2176622527260936, 44.06884477984521, 41.57570000617735, 35.654713569148896, 37.15157631904849, 6.7863716137024666, 0.5291138240887273, 0.14076608203111157, 0.03235684963123452, 0.023712259867498954, 0.042120467856406205, 0.06643601047295718, 0.014730917962057697, 0.11368288974007291, 0.05164642645526798, 0.07412263027001774, 0.02777337813900123, 0.10476005684223869, 0.03554390946162805, 0.042522077959391384, 0.05184844001046112, 0.05102437838251072, 0.06363692055005701, 0.026628306518579205, 0.04483865506406273, 0.029833172147552815, 0.11365837492649594, 0.20087740083615627, 0.18629710820894088, 0.20163772777924616, 0.22307619272220522, 0.17138683086922094, 0.12550211721850982, 0.11131230726717942, 0.16933978264850957, 0.10513334850510282, 0.11326177886897519, 0.0976606970652938, 0.2836240743917804, 0.2586842352344144, 0.09678683589182555, 0.1442692642130198, 0.15366479634277283, 0.19285610786849455, 0.18459694460034373, 0.0815238593326461, 0.13182796567918795, 0.17579821028536366, 0.10393782233398768, 0.0943870884516547, 0.15187375938459752, 0.2541424063665252, 5.0629218739847985, 47.09328243809362, 40.65263294404553, 37.97853354484805, 59.08183820786015, 10.100527790284927, 0.37152880261982646, 0.43327944233052196, 2.1135738251670717, 9.83593156260829, 19.502916835969497, 22.849408541956258, 19.96255978461235, 9.563317029706894, 3.4672286337421787, 1.258017372700476, 15.20647414268986, 46.25120055290961, 60.15765805398265, 58.19201323293871, 56.82567127289311, 59.22698159371654, 54.786176066244806, 58.28023518285444, 57.9234250130192, 56.19869216795891, 56.389515476842085, 57.37735263762936, 51.851544995461744, 48.996922431453584, 46.611301591319425, 43.262660426478234, 43.939002560031035, 46.69934703457741, 53.57973737101401, 55.396755741488555, 49.849029894798036, 49.1993441889363, 47.84168243408204, 43.83844083355319, 46.66903495788575, 44.76033902937367, 44.32593261041949, 43.89273428147839, 43.94919287773871, 46.10864593136696, 42.35935426527455, 44.02309817652549, 43.64303227393858, 42.85640485825078, 41.77856891385971, 42.21084156344014, 46.599836503305745, 45.77774693889003, 48.6889418478935, 48.6866472613427, 49.49566748834426, 52.269167592448575, 52.79007796318301, 53.66355057685606, 54.5196549354061, 55.78964387216876, 57.31531643098401, 57.47936171870078, 55.144723846066384, 56.83161366370417, 54.46076054726878, 56.11214899247693, 57.165003361240515, 55.67534992771765, 55.18485361529935, 51.99582938225039, 55.22795261875276, 55.609571779927904, 57.17818644738967, 55.04549572544714, 55.235754213025494, 52.09378665493381, 42.74074200660952, 41.02336360562233, 39.85353631357993, 42.043995703420336, 40.29738387753887, 44.574787386002086, 51.71217141612884, 53.52511836636452, 54.726650176509736, 52.156846600194136, 49.873583932076734, 43.11403005353866, 37.59552978700207, 38.921114398587136, 41.762832364728375, 49.43461579661216, 54.05135531579295, 53.23967572181456, 53.65372896194459, 47.69149488018405, 48.92568434438398, 51.22733116149903, 52.46706685712261, 51.10519639907345, 47.47059483681956, 37.71079255688576, 41.887359772959066, 47.44607610087241, 52.42986317603819, 49.72658526512885, 47.473822947471376, 52.23195214425364, 50.15753607596121, 51.98674517293131, 52.58127450942994, 32.570785322496974, 4.386051691347554, 1.6480881384303494, 10.74764826605397, 8.388795641160781, 8.549920724284265, 13.653879415604377, 18.033316519952592, 12.815564966970875, 2.8065389635101443, 0.5265951721418289, 5.456639095660179, 49.673743094167406, 45.13596480892551, 44.50309038162232, 45.32974950728878, 8.961134168409533, 0.7172153145074845, 0.24552348820913225, 0.2810394775963599, 0.13321133660933665, 0.22048794934826516, 0.15172622617213957, 0.22791342509369697, 0.1279199673163314, 0.19538897840726763, 0.12365169312444427, 0.08915548167762258, 0.1269645560833235, 0.1644367586460806, 0.1599169165016182, 0.11145058613751205, 0.13207735794205822, 0.14557647068173657, 0.08028442866259045, 0.14495445325249626, 0.18237789431887289], [0.04303998403972195, 0.044955878007796504, 0.0337330729610497, 0.01899149009747611, 0.035535214363687465, 0.022014114900582263, 0.07014645008190025, 0.06963890917118519, 0.013604896075482811, 0.0627946183686295, 0.07694770972574912, 0.03502533688480335, 0.037968616046371965, 0.04150673949850663, 0.06294264187735897, 0.04035004249383365, 0.03533380601795451, 0.05519900598653382, 0.04068823583844689, 0.04722770025593139, 0.03485035857245807, 0.11085025665740814, 0.10207600651248809, 0.06131650534488502, 0.05518212906956192, 0.0299615646532226, 0.030380022944882516, 14.505050413070188, 43.6575803449077, 24.974132930078817, 37.89441439413255, 27.06808436301447, 0.18122441105304227, 0.1900760667218316, 0.43756662357238035, 6.030103343148386, 5.906920817590529, 4.901696280125649, 3.2765411369262205, 3.839456414984119, 5.199127158811016, 0.9816822878295376, 3.146135076399773, 24.012689398181056, 49.50246495585288, 53.89404866003222, 51.8957148059722, 53.29302387852823, 51.260788979068884, 52.87977472428353, 49.7522375660558, 49.974063288780954, 54.94822486754387, 52.03879502511794, 50.311798972468225, 43.175834840343846, 39.381459451490834, 41.57411144625756, 45.62726128485895, 53.16659412076397, 54.81986530365483, 54.11235601671281, 52.72566087784306, 48.99794617006856, 43.99608873551892, 41.97406376561811, 39.59135332415181, 40.67357447839553, 40.77993739035822, 39.86385999187347, 41.6370850993741, 42.31682400549612, 40.98547743212792, 38.40004321067564, 38.83083712670111, 38.50854381438225, 36.99156322786885, 40.09874720727244, 40.26570289365707, 42.565972958841634, 46.35086797898816, 47.17971970958095, 47.71959474009853, 48.40169491306428, 48.86622513494184, 49.38761795720747, 51.026364603350245, 50.69623047305692, 50.75519938622752, 51.368454117928785, 48.71793993057744, 53.63351306607647, 51.99116960648568, 48.776975524040964, 55.10206807044245, 52.83060389180338, 52.55620271928849, 50.42999959761097, 49.32567588744625, 52.8299057099127, 51.94380698665496, 51.61523395969022, 50.35772992718605, 48.482268241144, 42.13160968595936, 37.0234207184084, 37.3879030443007, 39.484821750271706, 38.22919653308007, 39.593981312167266, 46.55345839838828, 51.29743568358883, 50.51695462196104, 51.80621416338029, 48.22232884745444, 44.47708898975004, 38.82382392883301, 36.24181001417099, 35.933707837135564, 39.72057580947876, 46.112576146279615, 48.65735500089584, 50.296356601099816, 48.305083013349964, 48.57965284778226, 47.975741201831454, 50.231445297118164, 47.99587865029612, 47.525096170363895, 39.09443609176144, 38.394775467534224, 45.988276235518924, 45.09155965620472, 48.10597173629269, 42.955425093250895, 45.88383528494066, 50.20371021762971, 48.986026087114894, 45.76951388389834, 16.68621966915746, 1.0488827238159797, 1.187136098742485, 3.403296941711057, 2.3335582402444657, 5.655944530040988, 5.445755989320817, 5.958336226401791, 2.08690244343973, 0.284167506521748, 0.054263696900659034, 10.745829266886558, 41.888089333811116, 20.083959102630615, 32.16847761984795, 20.270983596001905, 0.2688535621329662, 0.05079518402776411, 0.06125284726881693, 0.05679736417087336, 0.05978170947562303, 0.042033505385681506, 0.02803010569374648, 0.03809358413902022, 0.14681226243415188, 0.05347824227365275, 0.09731349835713064, 0.05674713561611791, 0.09491817890516213, 0.030678808726670764, 0.023731580604949308, 0.07586253085924734, 0.010980765312729825, 0.06051016716106285, 0.06895113841540391, 0.051547057190609556, 0.03731042394534715, 0.032834593552134694, 0.060277249619004235, 0.036303566077784184, 0.01744119626950593, 0.02080057225670786, 0.007609003599012091, 0.042443036837803746, 0.06405057355521188, 0.007194374310558723, 0.06731480525265779, 0.01999380314842828, 0.001878743252394, 0.023967650598816337, 0.06039920315567044, 0.0939617257925772, 0.021510609358008352, 0.026643473144260146, 0.029401686530740514, 0.049693292953194156, 0.06477770590854269, 0.08072368049573514, 0.09323213429700944, 0.16170577777008857, 0.09781188451715055, 0.11748395755045837, 0.112715772683582, 0.08272593555551383, 20.151219906345492, 45.8461138509935, 25.417474508285526, 49.43396076079338, 26.65282499405646, 0.08786619400545474, 0.2666676681368582, 0.19442035215756587, 3.1511071708894547, 5.223438989731574, 8.845165371894836, 7.208721157043212, 11.683294369328408, 10.26165287340841, 1.450930692015156, 4.743716937880363, 27.123062264534738, 48.42191865367275, 56.41523445806196, 52.786143825900176, 54.697805066262525, 52.308046125596576, 56.163849753718225, 52.811501949064194, 53.609947466081195, 55.01051210588025, 55.07354851691954, 52.17696051443777, 45.06530331027123, 42.4410415464832, 44.240409251182314, 47.733566222652314, 52.91895920230497, 55.95074345988613, 56.27946945928759, 54.240868553038574, 51.04754932465092, 44.53582648308047, 43.02055997233237, 42.715587846694454, 43.14689167084233, 42.12290986891716, 43.37804871220743, 44.13063387716971, 44.887176713635846, 41.905634095591886, 40.41021477791571, 40.33916104224421, 40.52355950878513, 38.782839082902484, 41.43205888809697, 43.02436074902935, 44.06766022405317, 46.89406525704169, 49.885402033405924, 48.56748565550774, 51.709880751948205, 51.859546630613266, 50.117880913519095, 53.48666344919513, 52.84739555851106, 53.181950199988584, 53.469801179824344, 50.96358706874233, 55.037482323185095, 55.462667249864154, 50.35404289922407, 55.318527990771884, 54.75361254907424, 53.0470363555416, 52.488381016638975, 52.626636720472774, 54.85800250884026, 52.71485474801833, 54.29493450349378, 52.2419188868615, 49.19761442369031, 42.096696669055575, 38.95971836582307, 39.09031368071033, 40.757697551481186, 38.27131886636057, 41.341016754027336, 49.626662884989095, 53.587272244115034, 52.16506396570514, 52.720910887564386, 49.99985287266393, 45.13260726005801, 41.76009062797793, 37.69411856128324, 37.91546967721755, 41.28378545084308, 49.08470899828019, 50.3660963427636, 51.752116833963704, 50.28548771335233, 48.3919164442247, 49.02229232172812, 51.28980667360368, 48.81230038981284, 48.82907244466966, 40.10794516532652, 39.79851330480268, 47.31883441248248, 46.4219727054719, 49.6015126474442, 45.11090870826475, 47.82298449547061, 53.02015635275072, 49.96804245056645, 46.67942531647221, 18.52119661146595, 1.1511050837655221, 1.7770377738821892, 3.7182765045473656, 5.5161179169531795, 6.766360661675853, 6.833736194718269, 5.541994773572491, 1.3775975689772637, 0.18878732297209003, 0.10417103481989715, 11.014836199821966, 50.01846451913157, 26.64380550384522, 36.441666541561005, 29.0510013411122, 0.9354237539152946, 0.12867280191952182, 0.08400697246073716, 0.05099686050427057, 0.05802013242857591, 0.01916403033500237, 0.05182507049833095, 0.06657603602375715, 0.1038907002657652, 0.06141165729552027, 0.04542264771918136, 0.07679823064996351, 0.05544144983193087, 0.04066078690811992, 0.03445791471148691, 0.008230852488909037, 0.05689709349685619, 0.06325402597506201, 0.1274775285574217, 0.04218876076441619, 0.03637809111105819, 0.13331000873398396, 0.13976839040556263, 0.31216158501563535, 0.09567863608319914, 0.19584319193757352, 0.11767589321900761, 0.158258305502034, 0.21266312728966438, 0.11221406936284997, 0.24167187391750275, 0.13820065275555657, 0.11965981579475826, 0.09924832235781417, 0.218350165673802, 0.15480816724800295, 0.16609898558066738, 0.12844284530729055, 0.2385619093453692, 0.11809434576500809, 0.1715884039238576, 0.13150288392939877, 0.2218640117996162, 0.18945394204028193, 0.21954472657413254, 0.22194693315654035, 0.3023638107603596, 0.18324876774943646, 22.750941361150435, 55.395151492088075, 35.454433425780266, 47.74398011545981, 38.81530061844857, 0.3337299631487939, 0.8878431361048453, 1.2191647026808032, 14.151951786010498, 13.025335284971423, 13.111158705526783, 10.957079299034612, 11.986436709280937, 12.50822961330414, 1.796927867877868, 5.046896050053259, 26.210860167780233, 51.801519086284024, 56.31681826806838, 53.956241761484456, 56.6326004459012, 53.374048279177764, 57.15589954007057, 55.31483311806956, 54.62816338385306, 58.20785176369452, 55.07920457470802, 55.0266565815095, 46.73929637478244, 44.72553976120488, 46.29782576714793, 52.463615171370975, 56.16959602602067, 59.60628655649001, 59.29605061008085, 57.445421449599735, 53.559592077809, 47.20320686217278, 45.86231716217534, 44.076081552813136, 44.00493760262766, 45.69088997379426, 44.312165091114665, 47.537275129748934, 48.088430896882095, 44.71540043430944, 41.63374323998728, 41.473745838288345, 42.447234968985285, 41.041398663674634, 44.18857512935516, 45.24194332861131, 45.73750342092207, 49.76218469681279, 52.51513158121417, 51.82861874180456, 53.40224227597637, 54.338472812406486, 54.6695718457622, 55.41167251525387, 55.65846020175565, 56.022365939232614, 53.67603155874438, 50.296537030127745, 56.9109239885884, 54.98103157166512, 51.65253177765877, 56.864490970488525, 55.623123568873254, 54.37611972132037, 54.86880863866499, 54.45886604247555, 56.64997262339438, 56.61639321234919, 55.28059867120559, 55.519659288467906, 51.507619811642556, 45.463184618180804, 40.0944326000829, 41.858495050860995, 42.68902947825771, 40.16582758195939, 43.19939651796895, 51.75795724315029, 53.896892378407145, 54.19623590284779, 55.671219671926195, 53.33292222792103, 47.877383847390455, 43.52512190418859, 40.10822757597893, 40.81638405399938, 44.898783006975734, 51.09472759308354, 53.638082627327215, 53.72020136925482, 51.844590633146225, 50.04740768863309, 48.89085369725382, 52.1757524244247, 50.41273724648261, 52.091739177703865, 42.28799066235943, 41.488258607925914, 50.55403278719995, 48.92979891069474, 51.85633028707197, 46.73754699768559, 49.80051409813666, 55.48681336064493, 51.9557035353876, 49.08554838549707, 19.995401790065152, 1.7726168949757855, 4.229778580127224, 7.49405054315444, 6.267122857032284, 13.35360138647018, 11.683551284574694, 15.954453464477295, 8.31199465259429, 1.5357259612890983, 0.2381449736534588, 16.299019955819656, 53.63206178911271, 30.197831776834306, 45.72851334848712, 35.19359580932125, 1.533848126569102, 0.22248981370320245, 0.22638970685582008, 0.13898759359313598, 0.2028242907216472, 0.07554321009064875, 0.08846707506886414, 0.09508393734933869, 0.31759771428281264, 0.15006425970744702, 0.18862115850131358, 0.11893629171555081, 0.22539635128792257, 0.1488412616233672, 0.15559935221268287, 0.1111913190012978, 0.1463612205078525, 0.18676762409027547, 0.3382982067283123, 0.16721382737159732, 0.10474338676900634], [0.015549104653238771, 0.04695843567230529, 0.05244184022528991, 0.03245259913045072, 0.023419047375359846, 0.07835489066858446, 0.03385392333110494, 0.014779225551343013, 0.029163841128108964, 0.07289589367686741, 0.041753963732551184, 0.01849213483623199, 0.008131037935644628, 0.03237607843813396, 0.054250481883965196, 0.033976470585912466, 0.005424538835687864, 0.05072039086371661, 0.09831149641784931, 0.05712242293802481, 0.020600596495393305, 0.03954112259370666, 0.01594369834844744, 0.04600682806584143, 0.043763511949369026, 0.015591736488615074, 0.04015209686551844, 1.3855772633706371, 35.22627699759699, 30.552327748267885, 30.59880783480983, 41.546203782481534, 4.458627796942189, 0.15251647650955186, 0.0566184519970369, 1.8297116506484248, 2.6724968658339594, 7.6042103094439355, 3.4189881384372716, 18.806647100756248, 8.6172580142175, 1.370180489555482, 0.4521174218145109, 8.965411513082444, 34.14525216625583, 50.3911171420928, 51.76302102304275, 51.800534571370775, 51.89911942328177, 51.96212445535968, 51.66574232039913, 56.723917145882886, 52.52070134685886, 50.255477659163944, 45.70002125155541, 42.5510444179658, 41.89671462582004, 48.31311602746287, 53.074661608665224, 53.10986095859159, 54.334413159278135, 53.1045461470081, 50.82162472509569, 45.57451325078165, 42.19474415625296, 41.487795768245576, 41.2585332316737, 43.34000172153596, 40.53743685445478, 42.01344828451834, 44.771239296082534, 46.67332603085426, 44.54501267402403, 40.60482709638534, 37.90176491583548, 40.08908248716786, 39.315920568281605, 39.97101522261097, 39.680308757289765, 42.78850863056798, 44.564314657642, 47.3656871241908, 46.956415253300825, 46.9233928188201, 49.63108731854347, 48.51663604859383, 49.855078189603745, 53.24164082927089, 53.361708502615656, 49.59605270816434, 45.19178013647757, 53.885019363895545, 48.536455785074544, 52.064714047216604, 51.48213617263302, 51.21253990357923, 53.97506129357123, 59.9605550304536, 51.22412266269807, 52.89290289725027, 50.96604639484037, 52.311364450762355, 52.011652223525516, 47.277269055766446, 40.25978795943722, 35.64542147421068, 37.369087434584095, 38.20219885918402, 37.82993455086985, 41.4608294733109, 46.915485320552705, 50.273963789786066, 51.591429095114435, 49.84455054806125, 50.322883590575195, 47.45626641858009, 45.90750678893059, 40.93007003107379, 37.434692998086255, 36.014524352165964, 38.38166298404817, 46.35976783690914, 48.430696918118386, 49.495326242139264, 49.29704258518834, 47.341862647764145, 47.17784481663858, 48.882942276616255, 46.92449500483852, 43.738188974318966, 38.12721883097003, 44.34217122293288, 48.27875606475338, 45.73020781240156, 46.241775097385535, 46.284474019081365, 47.56342164931759, 49.43227021924911, 31.1332856839703, 7.464187577847512, 0.5524470236512923, 0.3515593112716752, 2.164022369730857, 3.9588048236985363, 5.1012846154551355, 5.167281435381982, 4.664425244254451, 0.42733389523721516, 0.09208670261526301, 0.41156115611234023, 25.12306336433657, 36.49115508602512, 22.32777057155486, 31.696443903830748, 5.268988493950137, 0.12342558227359288, 0.050069357854344194, 0.009447222954833941, 0.05603817869879066, 0.05685493184794342, 0.09073336999262534, 0.06058603284820434, 0.011696707994316616, 0.04383906354046157, 0.03599958238942969, 0.014543184285773145, 0.01055102063072545, 0.02723226150978477, 0.00830623266782852, 0.018538804912579157, 0.05773765282825597, 0.023148095483080517, 0.04712059350323774, 0.09906528097006584, 0.08868259092372272, 0.020827136355482286, 0.02925532543280673, 0.045688403620114254, 0.04920658197314028, 0.08400468185784356, 0.004627621618114533, 0.010572281485844043, 0.022640462641814546, 0.07113408297300339, 0.035556346899078745, 0.03364919016378061, 0.014637027183667788, 0.038791291055179415, 0.05134944481054141, 0.0427628172591569, 0.060629152107022466, 0.048805592401373776, 0.033396063222279476, 0.025438177436890624, 0.07753147638493008, 0.03417981330365424, 0.013802806272231525, 0.0391705313907756, 0.08166083585350745, 0.03316890666141145, 0.05224412825379161, 0.05121024663469965, 0.033601049198618824, 2.2903628935736995, 44.75467120447467, 30.426035273459654, 35.57674861723377, 50.8143840297576, 3.81206454288575, 0.2675273107184518, 0.062474734525406556, 1.2322222729844432, 2.9693440468080583, 9.588974233596556, 6.105009826921648, 8.996535520399771, 9.072848173879809, 2.671459398923382, 1.026374386443246, 11.052248747118059, 33.87441642822758, 54.46399258029077, 52.48543531663957, 52.87538166969053, 53.79664836391326, 55.311212770400516, 54.29422063212241, 58.31096695315454, 53.64864949257144, 53.72956406685614, 47.92826875563591, 45.19235280252273, 43.38035506586875, 49.35111245801372, 54.762077023906095, 56.358387547154585, 56.154714553586906, 56.4272722121208, 53.16699420252154, 47.98808490076373, 43.025384487644324, 42.6229767645559, 44.441901406934186, 44.8787396953952, 40.938491359833755, 44.208669431747936, 47.62047252347393, 48.929955805501635, 45.959944955764286, 42.073060466397195, 39.5604960380062, 41.984414900502856, 39.77766198496665, 40.64347813206334, 42.04764350768059, 45.596823692321784, 47.307934145773615, 49.69900315807712, 48.24973444784842, 49.54121405078519, 50.89373750071372, 50.428783662857555, 51.203314488933934, 54.929515161821925, 53.68559429722448, 51.46897269833473, 49.04570887165685, 54.101043901135846, 52.71408988583473, 53.64310326114778, 53.1344973656439, 53.911852298244355, 54.98656211360809, 58.2807647028277, 52.14746821311213, 54.36294447991156, 54.16961869885845, 55.62834816594278, 52.533347068294404, 49.50664620245657, 43.24253866749425, 38.19980229100874, 38.747325943362334, 39.27460232088643, 38.556294748860026, 42.69519544416859, 47.4325753027393, 52.91740202134656, 51.96608212686355, 51.33422751580515, 51.035797903614665, 49.94181748359434, 46.888954408707164, 43.08423965207992, 38.538667617305634, 37.83307244700771, 41.404500315266276, 49.335619095833074, 50.22328676715974, 52.53586915231521, 49.874968528747566, 48.63982200622559, 47.888896003846206, 49.01809930801392, 48.53897394672517, 45.20394340638192, 40.35307761161558, 46.999239690842174, 50.320549780322665, 47.187882161909535, 47.749844058867424, 47.35550857359364, 49.40950478276899, 50.312744263679754, 36.28812143879552, 7.988806059283595, 1.9076830989891485, 1.6929780715896239, 4.807556454212436, 8.508987849758517, 8.7242151652613, 8.293243761985533, 3.1172284339704825, 0.4315061326469145, 0.03395618840811714, 0.1442511692162483, 28.003430404970725, 46.329863686715406, 22.11060070222424, 39.227027893066406, 9.428604206731244, 0.13476712328772392, 0.06474014461761521, 0.05544030836092369, 0.05717049495527341, 0.061299567140879176, 0.06983050776104774, 0.048428857173289985, 0.06623832914497584, 0.06860721856355667, 0.06845365623913466, 0.016434662074090976, 0.04787048632879892, 0.028167011351474834, 0.02939357174440257, 0.015963813902119237, 0.0883712987565706, 0.043671041306468754, 0.050208418134359584, 0.030365647304983392, 0.011306999067235137, 0.03180811617283091, 0.19802194599422718, 0.1830673887724838, 0.10887004960809024, 0.14840681316150775, 0.11168514693816824, 0.14302368185693218, 0.09356196579192916, 0.16545082923145066, 0.21142738150252452, 0.19621284468279732, 0.105580345487162, 0.07619892006679889, 0.07255491560264941, 0.12559170354037516, 0.1817448299017645, 0.10383381823738737, 0.09493787502569538, 0.13492159725677583, 0.28517187843399666, 0.21077317305870596, 0.06484133717153343, 0.09187097991666487, 0.14090581646850034, 0.1614520341278084, 0.12183033440622593, 0.14627624603529132, 0.11629712647728382, 2.960868295161955, 49.30444409770351, 40.927155710035755, 40.59628809652021, 54.82889852216167, 8.03105341811334, 0.6195267241808676, 0.5150192771707812, 3.720619385280917, 9.46179824490701, 17.728007070479855, 8.381765773219447, 27.891158442343436, 19.133855142901023, 3.5355720116246134, 1.297092146931156, 10.351936028849694, 36.87587684200656, 55.311055875593624, 54.384368465792754, 54.59540767054404, 55.15822856656967, 59.389383408331106, 57.09737385472944, 60.26504470456032, 56.453838425297896, 55.69129828483828, 49.29096291142125, 46.912151305906235, 46.821262144273334, 53.7058807957557, 58.35137521066974, 57.57596969604493, 58.186125755310066, 60.167601262369466, 56.2951942413084, 49.32428736840525, 45.556015353049006, 45.28435983965474, 47.2194690089072, 47.19475415445144, 44.43526475660263, 46.58130330424155, 49.85802781197333, 51.330587556285245, 48.95080320296749, 44.81014528582173, 42.80965412816694, 43.23820444845384, 44.22981100697672, 44.89835939099712, 43.12838592836934, 47.49618830219392, 50.02140237439064, 52.789783785420084, 50.081081236562426, 51.0521581096034, 53.12581716045257, 54.43639478375835, 53.12329507643177, 56.95843958085584, 57.886382149111846, 51.91560906748618, 49.37258351233698, 55.10748486365042, 52.42529753715762, 55.49744690618208, 56.32833826926447, 57.8458954441932, 56.88619736702212, 59.913055127666844, 55.0731994259742, 55.87906998972739, 55.933614469343624, 56.026233396222516, 54.72065679488644, 50.16961305372177, 44.21896173108009, 39.04952495328842, 40.634291941119784, 41.852485979757006, 40.772457430439616, 44.91635914771788, 49.894529388796904, 54.52282813287551, 52.58321216029506, 54.157522109247026, 53.34871761260494, 51.18489503860474, 49.07126311332949, 45.093591443953976, 41.26120828813122, 40.10145756506151, 41.335046906625074, 51.958100103562884, 52.157685987411014, 54.91976807194372, 52.43033778282904, 51.34567691433815, 48.234696080607755, 51.897523018621634, 50.38942267817836, 48.83729373255084, 41.88196651397213, 48.4497517924155, 52.63742323844664, 49.87072452422112, 49.177335769899436, 49.7232630175929, 50.26725653679141, 50.62220750316497, 38.25114611656436, 9.502958616902752, 1.8517757183121097, 3.597391997614215, 7.207416478664645, 10.879382048883746, 12.563723306502066, 11.815185046965077, 12.47715953857668, 2.4951243448641995, 0.3344752134815339, 0.9889896634605624, 34.05369620169363, 47.928959092786236, 31.496899204869425, 47.90901384046001, 12.441860168210923, 0.2289012341850227, 0.27373056978948657, 0.13177769498959666, 0.13651049425525053, 0.1637109209813418, 0.324795876419352, 0.2072696997633865, 0.13219243967004363, 0.17129535997106185, 0.1057594798264965, 0.11251072925064834, 0.13979563249215005, 0.12247017870146422, 0.16638732575360807, 0.25036609851785246, 0.2404845602089359, 0.1565812011399577, 0.27174704557945656, 0.21748356701385593, 0.13028958451844033, 0.12173120262882403], [0.018677168052583452, 0.012032680641559344, 0.07154791600882046, 0.05285329072766247, 0.029743331101452632, 0.059608374421875325, 0.056127876103405035, 0.04716139534608491, 0.029275858504397255, 0.0449606200920478, 0.03218482841827697, 0.07179225209139048, 0.03853448689164173, 0.0567812993071012, 0.008460675993363464, 0.037427666041279034, 0.018190321091923024, 0.041859005878288905, 0.10156614435536247, 0.038204885223099304, 0.055778536179493514, 0.04965189739220566, 0.05905839224015513, 0.020322041180465492, 0.04238163872111229, 0.02982018695723626, 0.04017402613235097, 0.0761813460098159, 10.244255200509103, 42.9728796405177, 27.232215942875033, 43.63696436728201, 21.677757347783736, 0.023563010618090633, 0.14957777855377044, 0.6164685624741739, 3.843390307118816, 5.137045354612413, 8.32104257998928, 14.200949053610525, 6.645779157838514, 2.301664467780821, 0.24291521929685148, 1.6068739564188066, 14.435316554961668, 37.728537359545314, 45.07397567072223, 50.48013925552369, 50.17248422868791, 52.98198384623374, 55.2576018148853, 53.800033369371974, 52.305037667674405, 49.575119018554695, 43.39508748823597, 42.99899478112498, 43.3433828046245, 49.76019213276525, 55.054736829573116, 57.159598335143066, 54.16981873973724, 54.54495030064737, 47.720689081376605, 43.651473214549405, 43.607883914824455, 40.30797035463395, 40.68702036334623, 41.44903098383258, 40.778541026576875, 44.68499422073365, 47.42719773323306, 49.216131933273815, 45.65690263625115, 41.14453738735568, 39.04151547339655, 39.83466186831075, 37.749341610939275, 38.27665328979492, 38.49988714341195, 40.072973312870154, 44.35154176527455, 46.31851234743672, 45.88923246629777, 47.04126788723854, 49.46472391005486, 49.40599033909459, 50.185804597793094, 52.62721723125827, 52.73163856998567, 51.87964877774639, 44.56400871276856, 52.29093674690493, 45.28610137201125, 45.75256140001359, 50.90104879871492, 52.76677908435945, 52.15732120698499, 54.76772131458406, 55.785748958587654, 49.67409218511274, 49.969462348568825, 51.866481381077925, 51.14406316511093, 46.11300760699857, 39.201658002791866, 36.67694207160704, 35.99754441169001, 38.33491617633451, 37.52013790991999, 40.65007555869318, 48.26533763639389, 49.73310032198506, 50.22498123107418, 50.323974009483095, 48.68505870142291, 48.820023536682136, 47.114980989886874, 43.692732626392, 41.25077478347286, 38.26243469792028, 35.95116238440237, 35.743335600822206, 40.03772689450172, 46.6524786333884, 46.52746877362652, 47.43274396465671, 48.615075772808446, 48.05423567371984, 46.770294866254254, 45.7251440325091, 43.1419651739059, 40.35639201441119, 47.12668534248106, 45.845968723297126, 47.08771267244893, 45.024812682982414, 49.587976547979544, 39.07771110534668, 19.574425566580988, 1.748434624844982, 0.18890496343374255, 1.999512894019004, 3.0126553485470438, 8.692503783010668, 6.899736937015288, 6.634005183173764, 1.8891849561083702, 0.1267477302181144, 0.07283156527386558, 2.7555753627131065, 38.035788382253344, 24.665058005240656, 29.621519888600996, 25.30016622235698, 0.9473264926383573, 0.06715727459278799, 0.023477969112836068, 0.06053626394620346, 0.03656998847521121, 0.028969819785185882, 0.028372250136829195, 0.052381353753228346, 0.01635732932857448, 0.018157139908702626, 0.031563770514161836, 0.05765264771217781, 0.03203773187593587, 0.09236273941613975, 0.055911992526342796, 0.0249227496509951, 0.03472777684369395, 0.016383152237282168, 0.005259662350234126, 0.05293852567011791, 0.048568836758814515, 0.02992517547681928, 0.05504953074118784, 0.021382008093379198, 0.03308022815373636, 0.06513281830496366, 0.044652714033520995, 0.013727516108643145, 0.03887299433230393, 0.06996909306655008, 0.019618416235091227, 0.032116976010823445, 0.028982747518908114, 0.02391379844817904, 0.02674659432452773, 0.0498617327051057, 0.0738679443395907, 0.06323146851613157, 0.05120117998411579, 0.06314108163238534, 0.03203171425529065, 0.037322485999714945, 0.03591705556778658, 0.07096985670467539, 0.04495779322760721, 0.03654385338567438, 0.10790467923206669, 0.09366257611902491, 0.07007176417016214, 0.14638830937685507, 15.268708429028912, 46.77827688955492, 28.87899560313071, 52.14944508767898, 22.03750145050787, 0.042820112975013834, 0.0952333091728149, 0.43838416196165547, 0.6971492654373569, 7.251401447480725, 10.356597765799492, 14.27742938841543, 6.065636584835668, 3.081186264753342, 0.5700829805385682, 1.6686338811151444, 18.081006657692697, 40.50287685086651, 48.64767066894039, 52.43031817097818, 53.309203655489036, 56.19587590617519, 57.96963053364908, 56.41519523436024, 54.41471976618613, 50.633362723935036, 44.902689687667355, 45.51751728980772, 46.90012139658774, 51.47931598847913, 57.56488115556779, 58.85024970577609, 55.93634836135372, 55.8609329500506, 49.83698821836903, 45.50762507223314, 45.273530175608975, 41.59115414465628, 43.46084602417485, 44.238836380743216, 42.830662342809866, 45.82473693355438, 50.73158279542, 51.73540361465947, 48.09215322617562, 41.16017979960288, 40.46482986019504, 41.34168747932681, 40.05239263657601, 40.27423404878186, 42.07744959862002, 42.5161902366146, 46.250922064627375, 48.041899819527906, 47.77925006804928, 48.57766812847507, 50.80456241484612, 51.46029249314339, 52.228198435998735, 55.63771478591427, 54.61096771301762, 51.81549841357816, 46.43625797763948, 53.01064460508285, 47.34770305695073, 49.782231930763494, 51.6081383920485, 53.88192461382959, 53.3730088510821, 57.87938464072443, 57.27202915376233, 52.55634784698487, 50.756270193284564, 54.528899961902255, 54.231921626675515, 48.799309499802135, 41.36441761447538, 37.394778959212765, 38.31029545876288, 40.366350912278705, 39.605446400180945, 42.90546194199593, 48.42013789761452, 51.21839207987632, 50.488101666973485, 50.912019668086884, 50.17262543401411, 50.31914949417115, 47.61834267647036, 44.45866953942084, 43.561333225619414, 39.400051486107614, 38.53184661557598, 38.57665969479469, 44.15772176557972, 48.547897338867195, 48.487888997600926, 48.70243872365644, 49.093047957266535, 48.71596305601059, 48.200265515235166, 47.963691680662095, 42.475632929032855, 41.49691920126639, 48.88924552548317, 48.36610724849086, 48.39114373730075, 47.8027097640499, 49.29191212500296, 41.61884607807283, 22.42966982626146, 2.2874797063489116, 1.2227070932426762, 3.188284375975209, 4.7354981014805455, 7.689409582845627, 10.12108297117295, 8.127279454661954, 0.9158518621998449, 0.09314740497258403, 0.02206666661696809, 2.0089677673193718, 45.49230429434007, 30.65477417361352, 31.37565678165805, 32.937707362636445, 2.0307021107404464, 0.01639542113538952, 0.08746801980680997, 0.011937392710317529, 0.03986394055367958, 0.03748990302424758, 0.040552174792655056, 0.08624417902601343, 0.03190899654591997, 0.05529583183928363, 0.0158899457892403, 0.06556810946353982, 0.01825927666598751, 0.07440673397673715, 0.013507666111352944, 0.013890785724675704, 0.07183971123829966, 0.03975940402597189, 0.05090434772653445, 0.010305924205890587, 0.05942673497502843, 0.01871178756588169, 0.06952941222416778, 0.098677012288282, 0.2873752392347782, 0.15545641552777062, 0.13428957471924444, 0.10754183700848972, 0.17553982415026234, 0.15671869860060755, 0.0744114147739545, 0.10762001628116255, 0.2537628710870781, 0.1377163013263095, 0.13927766512478554, 0.13884053535519109, 0.22486015102796017, 0.11275897238163218, 0.08467083361240164, 0.12502223208186128, 0.16156109440470898, 0.07038246644961257, 0.1487502503779627, 0.13905667940214758, 0.1429246420100812, 0.09509666206976099, 0.23387338996173876, 0.19129593916718038, 0.1733009934785866, 0.20015504121059374, 18.138106561476185, 57.331590344828946, 37.4705042377595, 54.88046200044694, 30.28213135657772, 0.19752665482942136, 0.5586640416614471, 0.9938649244366154, 8.010339871529611, 14.334899956180205, 18.381358231267622, 23.688246627007764, 13.607645457790746, 5.724734567826794, 0.8292050503434674, 2.8841464894433178, 16.88734704448331, 42.13199407823625, 48.425260513059555, 53.113096913983746, 54.57099483859155, 59.24621689704157, 59.29188897532802, 58.27406921694356, 55.88156069478681, 54.39950096991755, 47.73963412930889, 47.72773758057625, 47.70592528004801, 55.03359133197416, 59.80976343154908, 61.25705134484076, 59.13236225804975, 59.465850014840406, 52.281146510954834, 47.74123837870937, 46.89639514492404, 43.37510301220802, 45.5061581057887, 45.648045924402055, 44.349764931586485, 47.743850677244126, 53.31136095908381, 54.592567874539284, 51.87079991063764, 43.676270438778786, 42.103101899546964, 44.46758508682252, 41.80338182756978, 43.117042433831, 44.886050993396395, 44.23990326543009, 50.151785881288596, 50.027278084908765, 49.4522350834262, 51.735889988560835, 53.41473894734537, 53.352510544561575, 54.8104476928711, 58.608635625531605, 55.07541556512156, 53.28528504217825, 48.257638023745635, 53.93127195296749, 49.40038919448853, 51.75224627217939, 55.01947079935382, 53.93297426162228, 54.285905207357104, 57.57111772414177, 57.044257117855935, 54.53383038120886, 52.843359439603745, 55.19737382088938, 56.18679954159645, 50.32642549084079, 43.4031165799787, 39.73080535088816, 39.06772867325814, 42.74317779848653, 40.67615539796891, 44.942941050375666, 51.497280443868334, 53.48738516530683, 51.57262525250835, 55.29987319823235, 52.72673952964045, 52.593280884527395, 51.508761221362704, 46.14855997024044, 46.52078113248272, 42.87165895585091, 40.64947151368664, 40.71668524895945, 44.844513093271566, 50.52800786110663, 48.867986279149214, 50.118222159724084, 49.48234711923907, 49.62443890110139, 50.281098581129505, 50.12641206864388, 46.376822302418375, 43.84823499187347, 51.700306246357584, 49.90397445617184, 49.541461160106046, 48.53383564179944, 49.78257709933866, 45.478552464515936, 22.07386182200524, 2.7942879305731867, 1.0649135732843031, 4.562770647387351, 8.99615897286323, 16.045250450411153, 10.44659262703311, 14.297114783717742, 4.5640434565082675, 0.45071603249638315, 0.14635777311219325, 4.718312236570544, 50.211990341063476, 33.728131632651056, 40.279121322016564, 41.48680340859198, 2.245289957331073, 0.17900839447975161, 0.2606249198077187, 0.09570935620896279, 0.10926682952671282, 0.13811094385962333, 0.11372487901920274, 0.10955510841261958, 0.07404048266189714, 0.12129334507570153, 0.1120182955938001, 0.2053363849559138, 0.1517432486458171, 0.18182260314783744, 0.29611489284903775, 0.15161374914309672, 0.1137773483811367, 0.12969116259726787, 0.11102945994465582, 0.10210009231682747, 0.19877896343748416, 0.18848808902886607], [0.022709437368077137, 0.04843516207690682, 0.009856271771563879, 0.05302107164395913, 0.012638502972080343, 0.04371887583646082, 0.03909293817536485, 0.05571457932913496, 0.019896059905389146, 0.057147512317544995, 0.016367548941484383, 0.043176393655519334, 0.06734725673713031, 0.05101309390738607, 0.020800625882862557, 0.04313233593899397, 0.05940035856779545, 0.047487373418745496, 0.0337597941078486, 0.030066434429177356, 0.03130710041601091, 0.018527374880748893, 0.0644898330492358, 0.03379118839098561, 0.00923993296906232, 0.014313467076018214, 0.030121901110115073, 0.05472219669290128, 0.806161922312552, 32.7871746401633, 32.82641795373733, 27.899220874232633, 42.22304013467605, 3.553013320892088, 0.14477262994454754, 0.13988056099943577, 0.9906957106244181, 5.212293084590666, 7.8015771123670765, 17.79240062159877, 6.346635183980388, 2.1665699491577763, 0.6996038724337855, 0.18117810869889875, 3.3600084387486984, 21.472650727918072, 38.01203843085997, 48.95980504251296, 49.27152364484726, 55.7147305242477, 55.13442762436406, 58.14028893747638, 52.45408381185224, 47.010912664474986, 41.875804470431426, 42.62847984990766, 46.08386439661826, 52.30412375542426, 56.932932407625266, 55.7677766584581, 53.4152017870257, 52.85222007382301, 49.00009562892299, 45.61471754504789, 48.41581152331445, 45.17566703980969, 41.5063250449396, 40.553942188139885, 41.75201446779313, 47.933258010495095, 49.55045515491117, 48.47272511451475, 47.0362433310478, 42.08154847545009, 38.59832686762656, 38.46607631252658, 39.95839695776663, 38.59260805191533, 38.56514753833894, 39.19760619440387, 42.10428253296883, 41.29507795456917, 43.37845663870535, 46.918195678341775, 47.6836815188008, 47.94875921741609, 49.6286319148156, 52.115912745075846, 56.403475192285356, 51.67912936979725, 45.5305983943324, 50.290524036653586, 47.35024867519256, 54.917410727470156, 54.79376585252824, 50.26821751748362, 47.675777942903586, 37.125735744353264, 37.69187888791485, 50.954216526400664, 50.507725284945586, 51.643235760350386, 47.08382560360817, 41.81902031744681, 35.74939174036826, 36.99566210469892, 37.204893096800774, 37.899972392666726, 38.935874277545565, 43.08674212424986, 46.69183569569742, 47.881498413701216, 47.168878278424664, 44.37833547592164, 44.48221944993542, 47.91068869252359, 45.65853434224283, 43.01494313824562, 42.817451800069506, 40.94281381176364, 37.550230333882, 37.69531880655597, 35.96081925976661, 40.12387783296647, 45.46524778489144, 49.1446820382149, 49.54156314173053, 46.56329962515062, 50.71955680847169, 49.720725244091405, 45.60405654291953, 45.90536125244633, 46.102821211661066, 46.49115154820104, 45.86732210651521, 49.327272292106386, 44.09543452724334, 29.038012412286577, 8.414386164757515, 0.5231099623826243, 2.132650762796402, 1.1861846788275627, 4.415110080472885, 7.279908253300575, 13.542499792191292, 7.603755804800219, 1.48656640562319, 0.022741929072165684, 0.044789418593169227, 11.382972213529772, 45.22674022182342, 24.210718101070775, 36.14557073962304, 11.925537009393016, 0.13238123437810329, 0.021382184293601784, 0.07878413739343805, 0.06106031788212638, 0.048910504312164364, 0.07395946120302524, 0.051354267334024754, 0.05021347814509946, 0.020007069876057007, 0.02269666093671995, 0.05700774723663927, 0.059981532019352725, 0.05897898339636384, 0.027722498409510143, 0.02799847775379256, 0.04365759646339763, 0.12497608294530262, 0.07435050312309496, 0.07422203017819314, 0.02335713981019874, 0.016723753013197454, 0.02028035259084596, 0.011910891813796856, 0.046195170782025785, 0.026928438699894378, 0.04199612412541624, 0.03424285467894327, 0.03712245278180607, 0.10122233941670387, 0.01816163109915872, 0.016828772176297444, 0.07471338365106814, 0.02754173421811673, 0.062097011043900446, 0.06882782124223248, 0.0820217781790322, 0.030339818650616274, 0.06362427626886676, 0.05909486951666975, 0.019707031540512558, 0.02633267510381918, 0.05162756537057219, 0.03165183998193712, 0.0662516360922206, 0.03746566017188373, 0.010647110081458045, 0.04971021966588113, 0.05746726209538118, 0.023040530992852106, 0.046513622040830316, 1.551914195860586, 40.7160262907705, 32.70103742999415, 38.49592162716774, 49.93293331515405, 2.2878209525539033, 0.05587825784459711, 0.2790224600222803, 0.6469815380630956, 1.4845599907059825, 10.15348861294408, 17.33508756083827, 5.693454646295117, 2.564339469517431, 1.294998214129479, 0.7241262243159357, 4.529654566318759, 24.698458948443015, 40.909022592729144, 50.483324220103604, 50.7025101877028, 55.36636913976362, 56.50002041170674, 57.58630514144898, 54.428495130231305, 48.44623342637093, 43.196066425692656, 45.6041036113616, 46.438399591753566, 55.18109598467427, 58.015479118593284, 58.7935479225651, 56.27444882546702, 53.8532599326103, 50.8157019461355, 47.34902881806897, 51.72190673889653, 44.89520972774875, 43.205946876156716, 42.25707454066123, 43.53690078181606, 49.09049449428436, 50.36497454489432, 51.204271547255985, 49.79967863328996, 45.02150220255698, 40.97860151721586, 39.879321975092736, 41.48842726984332, 39.854363933686294, 40.95410631548974, 40.87911059779506, 45.55268918314288, 44.14684895546206, 47.00554293970908, 48.97958555529195, 49.26630689251808, 50.667699152423495, 53.15394447695825, 54.075497504203554, 55.47212800671978, 52.74100126758699, 47.45272844068466, 50.96929019497287, 49.28750730329945, 53.463796031090524, 56.01989092365388, 50.62328223259219, 50.640905441776404, 39.774276979507945, 42.353086317739184, 51.83719696537141, 52.62890777280254, 53.431899316849254, 49.961723512218846, 44.08603652831047, 37.2474939592423, 38.369848805089156, 38.11350230247744, 40.13259726185953, 40.02655990662114, 44.26848165450558, 47.86211013793946, 50.6736768445661, 48.27375896515385, 47.10026033463017, 46.899866442526545, 49.87118736390145, 47.713985750752116, 44.6084491668209, 43.220636152452045, 42.93730766542497, 38.85410854893346, 38.29706530417166, 38.47124599641369, 42.17757201963856, 49.01879356753442, 49.71265692864695, 51.51186773853918, 46.125037516317065, 51.73510943689654, 49.9589817754684, 47.41374792591218, 47.46825318182669, 48.40150663929601, 49.12099484474429, 47.966170618611, 49.39420753909696, 48.142379176232126, 32.988745243318625, 11.5003461991587, 1.3683475169443315, 3.790081374106869, 3.4172549411173794, 4.069792945538798, 6.614522770527871, 11.177728310708078, 5.038173189086299, 0.8152490121222312, 0.05304082905152633, 0.03539269519669395, 11.371736584171174, 53.56968825863254, 23.613074402655325, 38.78522388396725, 18.484455770061864, 0.14842403481804556, 0.014459744861890233, 0.05952678988837908, 0.042110684913613146, 0.04378192487262911, 0.007037362675257629, 0.03904164475839465, 0.049412238276413376, 0.04255666299873302, 0.01820784726841075, 0.05050853307869646, 0.029920881554003687, 0.04560120366213303, 0.019645840267560655, 0.00594373242253618, 0.030381656627381043, 0.10221800857013273, 0.05125971676241006, 0.0228472929748316, 0.01776809173245584, 0.026654738467186693, 0.031704045043537216, 0.17715306742297066, 0.11988923614544254, 0.07670766373555507, 0.12457892764359714, 0.17597905300076933, 0.16073689105049258, 0.16365933262052076, 0.19005665405383035, 0.1231034882667084, 0.13714910514893072, 0.13432375756242584, 0.17810856292565025, 0.0816864385119369, 0.2165255587427847, 0.12238446112361648, 0.20752626260922802, 0.1782212697810704, 0.13967475913945707, 0.1145815951449256, 0.09185181239679938, 0.10302884369007043, 0.1942993715525635, 0.13336994745317968, 0.18340265949166593, 0.13337785348055825, 0.13505918664797661, 0.15660000093761953, 0.1601030452237014, 1.9673400204027853, 45.566123300983065, 44.18915564014066, 38.21038484573364, 55.832334949124245, 5.779907116966863, 0.3942455465514814, 1.6641674046554875, 2.6490553107953843, 10.909340131667353, 20.619637197063817, 30.93608067881677, 15.433849038616305, 6.566571795171307, 2.2508651162347486, 0.5609190367883252, 4.461026816598831, 23.92812898082118, 41.631915415486986, 51.964544557756, 53.09178275446738, 61.15626212089293, 58.25679117633451, 60.88915263452838, 54.86367033373926, 50.40713610187654, 44.44169744368523, 48.31605780509211, 49.18794578121555, 57.16180662955008, 59.49637389952137, 60.65353978064753, 57.71308791252875, 56.171066914835286, 52.84669737662039, 50.090032085295654, 55.022204691363925, 49.207840042729536, 44.30681105582945, 44.14870423655356, 45.98440485615885, 51.75729828496134, 52.44655678349157, 53.8524519243548, 52.005807891968765, 47.363537665336366, 42.8966679880696, 42.30402923399403, 43.6311710265375, 42.43474221998646, 42.713869848558986, 44.68510404709847, 47.73118142158755, 44.58926093193793, 48.68822797652214, 52.234242808434274, 51.58320388486309, 54.08365603416197, 54.11340721191899, 55.544213325746604, 58.65967350621378, 55.12140535539197, 49.06319087551486, 52.0855143762404, 52.05281749848397, 55.50467583440966, 53.69288990574499, 51.85926814233103, 50.68866029862435, 45.7560876107985, 46.43861139974287, 55.39173903003816, 53.484423775826734, 56.01132054482737, 52.37298880853961, 45.85999119666315, 39.121786778973, 40.02609314457063, 40.59380915857131, 42.08539239821896, 42.75251696186681, 46.454857856996604, 49.957126494376894, 52.405834736362586, 50.11664536691482, 48.52057803061701, 49.16736118255123, 51.12530639094692, 49.91842839025682, 46.318582950099824, 46.67591479516799, 45.06436194142988, 40.870618666371996, 41.71990986793272, 40.487297196542066, 44.15994182709725, 50.86454329952117, 52.81974677116641, 52.14352230871878, 46.56315449745425, 54.53344991130214, 52.24487635397142, 51.03557825088502, 49.468920846139234, 50.59534318985478, 50.66282756866948, 49.739568310399214, 50.90645774718254, 50.07879449475197, 33.998853621944306, 9.673018859278772, 1.4466517538793626, 6.8251363981154665, 4.180496450393431, 10.265138879899057, 15.87575993230266, 24.49005557644752, 14.394433690655617, 3.2580628510444396, 0.22462212750988625, 0.1661931071430445, 16.163291238969375, 56.953544462880785, 32.17478479108503, 48.91562346489199, 21.071170645375407, 0.2776238592641969, 0.09880720127013423, 0.19566331449295246, 0.1258213996827122, 0.13237593304966727, 0.19078440693837984, 0.09766910104982315, 0.18682238405510304, 0.14494991801198454, 0.10354400717563207, 0.22260255120213956, 0.0853430298006823, 0.12036786489789525, 0.09483871260477651, 0.13414299145581263, 0.10704217148163628, 0.24041809442062534, 0.16417392920101845, 0.15695834622508095, 0.18444489146913254, 0.15394907624971482, 0.08791637276449511], [0.03662959011572023, 0.061915402240570516, 0.047574627002881426, 0.03958919461095526, 0.07799777112180188, 0.03858154384239066, 0.09309583959440071, 0.026751738604939273, 0.022551606018697063, 0.09325350815009686, 0.03545621920737528, 0.05179780925954542, 0.07780038090723176, 0.03871370167020829, 0.017449902858765378, 0.05378050609461723, 0.06497392400858865, 0.0354953279959098, 0.05330862657677743, 0.0310588457937082, 0.08926838771590302, 0.0214066703788816, 0.01898089127104369, 0.014996193142818108, 0.06590246087721278, 0.07449722428235316, 0.008206678584458367, 0.13756119916515966, 0.04671241036586223, 10.137390225164353, 40.05686413857245, 22.430352318671442, 46.66650110675443, 21.20096971911769, 0.11825381462732631, 0.1634580506792953, 0.43138276184758834, 2.687944140165083, 5.764159781317558, 17.013351225083877, 8.24837576958441, 1.324966347986652, 1.528462712322512, 0.4112229129720119, 0.600936466888074, 6.784598212088309, 24.17369681019937, 40.74706792831421, 49.84615087509156, 52.39469912744338, 55.71185542691139, 55.74625069095243, 54.336091933711884, 46.060443924319365, 42.20849206370693, 46.13832650646087, 49.63189140442879, 54.87060508420391, 57.10350844167895, 56.13261984240625, 56.24563509418119, 51.781919002532966, 48.47683183608517, 52.16179270898142, 51.656309020134714, 46.718574493162095, 39.95806355630198, 40.68972287639495, 42.79622393269693, 49.885845261235396, 51.561670072617076, 50.75070435001005, 47.8290916258289, 42.86034291790378, 39.7917942846975, 39.49205067849929, 39.65129498512515, 38.25998713893276, 39.03181545196041, 41.05206358817316, 36.893660868367846, 40.16383501791185, 40.79219087477654, 43.24679836150139, 43.71867910508187, 45.84485869253836, 51.32304876081405, 50.7856644353559, 53.828647059779016, 53.69405877205634, 46.70241040568198, 46.39024465314804, 50.15925407409669, 52.66115750035932, 44.228999076351045, 46.756884282635106, 46.172749227093114, 50.578127907168486, 45.63765556581559, 55.33910082232568, 51.91330663619503, 50.0957626681174, 44.835421039212136, 37.64633624784408, 37.25900219332787, 36.63917356921781, 38.80569865626674, 37.81585324195124, 40.02399075415827, 42.0092591931743, 44.68955985961422, 44.03734030262117, 42.049361505816066, 39.8158109572626, 39.573463393795876, 42.461178994947865, 41.80449970306889, 42.67515605495822, 42.98271694490987, 41.51397366677561, 39.42534685134888, 37.93604643114152, 38.77455895946872, 39.94263295204409, 42.679286310749674, 48.37752526806247, 48.453623171775575, 50.026889770261704, 49.09557004128733, 47.39426551326629, 48.962742897772024, 45.66925810229394, 47.31291947826263, 50.8760868349383, 49.21804997228807, 40.455051391355454, 38.882051514041045, 15.831971572291469, 1.6110690538921666, 0.9545075556924267, 2.531531539655501, 2.8115480753683277, 2.191331381759336, 4.991830875796657, 7.551857454161491, 4.171805458684122, 0.3412226707704606, 0.11320553269357451, 0.09170208051199875, 27.05562495416211, 31.021374579398866, 20.064531603167136, 35.225233647131155, 2.5606338102971358, 0.039004688676927364, 0.04068178154768483, 0.05590361918533041, 0.049626727573453426, 0.022611717107675733, 0.02243764660952072, 0.029475631252411875, 0.0035408222362504254, 0.06511240206178158, 0.06568296136514795, 0.04697432816629449, 0.05741393471497202, 0.024103539274825204, 0.04856920448101817, 0.021247578814866084, 0.0689676399492929, 0.04683209245183295, 0.04291662090127507, 0.0375978984389334, 0.05430809552631071, 0.018336866050958633, 0.03834012272437254, 0.030289166832282662, 0.10223383594664837, 0.030454503928100875, 0.08443402051324807, 0.021422861647161267, 0.006332246731260732, 0.046905897362458135, 0.01246216772649918, 0.09176470819980868, 0.023059821086785486, 0.053777028055441, 0.06437245305747756, 0.04371328339461358, 0.03898252575327793, 0.08014819524701565, 0.02043819734676471, 0.010802235225245599, 0.0322889435976263, 0.059827701564157204, 0.03669627423908922, 0.03356202084931635, 0.058950814343388044, 0.11258455714391125, 0.0025415469633205045, 0.002084911158759027, 0.03905605870268999, 0.07441867728747668, 0.15464007223565734, 0.0585911781977742, 15.04836634282143, 44.78092362803798, 23.104792102690666, 53.59599951774844, 20.27556492436317, 0.08859771604259169, 0.12986172441272967, 0.26324156972189106, 0.49600699736225995, 7.090845598328499, 20.377611267951227, 9.476753261781509, 4.228762195956323, 4.49908459378827, 1.6391126523094794, 1.6480324898035297, 8.356946975954118, 27.114691926587014, 45.042690846227835, 52.844924465302505, 57.175758500253, 58.08877252763318, 58.897329914954405, 56.53020305018271, 48.22122666143602, 44.21791838061425, 47.25472719438615, 50.71091974935224, 55.68547356513239, 58.150491022294574, 56.38002334102508, 56.60375925802416, 54.32967493610998, 49.51116477289508, 52.97116202692832, 53.39316591139763, 48.05108993284164, 42.14885242523686, 43.91642931968936, 44.67401158425116, 51.90624636988486, 53.342994874523534, 51.80193093515212, 50.63344509370866, 44.32366940283006, 40.38630793171544, 41.98358335802632, 40.61929279758085, 41.151448603599306, 41.394090344828946, 42.54871845245362, 40.39143054716049, 42.92329303679928, 44.60579764458441, 44.860559509646514, 46.230933666229255, 47.715750817329656, 52.26646115702968, 52.63275954031175, 55.28355613831551, 52.41646043715939, 49.47602033615113, 47.27449201768445, 51.09215059588033, 54.55456010756954, 46.03835313550888, 48.04047992152553, 47.79372361398513, 51.710488719324914, 44.50975056617491, 56.79323719393823, 55.04075750227898, 51.16729536364156, 47.284294020745065, 38.955737160098174, 38.223360046263664, 39.181548010918405, 40.18995800325948, 39.192675775097264, 40.93851881642496, 44.27762469937725, 46.5499282652332, 44.917661374615086, 44.891169686471265, 41.484622570776175, 40.67825778838127, 44.50833851291288, 43.773239274178785, 45.43875609674762, 43.23236011689709, 42.18778587156727, 39.78433393662976, 40.26287094239266, 39.20721207895587, 41.73328122785015, 44.856743043468846, 49.83283835072672, 49.86631578014743, 51.278776968679125, 49.602057856898156, 49.911521096383375, 51.65760340229158, 48.99838547552786, 47.654510851829286, 49.36478976280459, 50.19196271896363, 44.34023749443793, 43.00978129909885, 18.648573621626824, 1.8534680984673964, 2.6632564971523904, 3.713839078141797, 3.18530680671815, 4.422240459149884, 8.077819347381592, 6.310795997419666, 1.371170765449924, 0.5011161603033543, 0.17366122334234177, 0.05013467834120797, 28.299394807507916, 41.352305335383264, 21.121755492302682, 42.45303615447014, 4.388989056310346, 0.08615804776068657, 0.05008412036864508, 0.10803374972554947, 0.05640406995230625, 0.035839075477974075, 0.03256489612883137, 0.026170475138050896, 0.04998584660971838, 0.051023436094363855, 0.046534509428085825, 0.03722310907417729, 0.04013115585210823, 0.12237562812984952, 0.029820554679439917, 0.039454474219030915, 0.052150060317569205, 0.012819366754903909, 0.04676136338422376, 0.008764832051500918, 0.02887427138404981, 0.021743873554852702, 0.022157009450658675, 0.17623794475390067, 0.18199676557654337, 0.21455766272641, 0.16764754038904944, 0.14375514260703517, 0.09581969585269691, 0.2043393981312552, 0.148589126765728, 0.1606627797046977, 0.3008210322549266, 0.26510702446103096, 0.16553387316244264, 0.16732953729168062, 0.1551811907800936, 0.1754695892093643, 0.1836118934255454, 0.09443025750618789, 0.11519703953977554, 0.164395849550924, 0.13218779717722248, 0.1579995976100045, 0.1387094423895882, 0.15528318772633232, 0.10893715891025721, 0.19349928464620345, 0.12506661155531484, 0.2049908946238218, 0.23389998853446978, 0.1274489304952083, 18.041006326675415, 55.63115266061599, 29.638943056906427, 57.06021724208709, 27.964047847255586, 0.23570194990644533, 0.3708057075498566, 1.0635927151287756, 7.0636390582207715, 16.981134837673558, 26.725408454095167, 16.985218025022938, 7.1931601339770905, 5.496459978242075, 1.5426321519959358, 1.1562177707110683, 7.606295539486793, 26.625178167896888, 44.04684420554869, 55.27178118305822, 57.62838825102776, 60.126486978223255, 61.239353610623276, 60.79695732362809, 50.9002721694208, 45.383654640566924, 51.240549548979736, 54.46902890359202, 58.61325617759459, 60.3860733585973, 59.13256229892854, 60.861084153575284, 58.28975085289248, 51.83254503434705, 55.96976303285169, 54.63292121887208, 51.33663977346113, 44.75443586226433, 46.62810110276746, 47.17338115938249, 53.569425459830995, 56.390872616921705, 54.616223689048525, 52.42077896671911, 46.346996599628085, 41.89316880318427, 44.79624048356087, 43.6838916040236, 43.46264639208394, 42.3654104048206, 46.21444009965467, 42.46473658469416, 44.177988652260076, 45.13925959987026, 46.81812032576531, 48.08588527864026, 50.221423641327895, 55.97965917279644, 55.40161948050223, 57.12636017030286, 55.84082688054731, 50.71821535787275, 48.607513443116225, 50.81764351937079, 51.75332884634695, 49.03174915621358, 50.710633416329664, 52.1003762368233, 52.509828536741196, 47.28298394910751, 58.397608187890825, 55.92046668452602, 52.765484702202585, 50.06759612791, 42.09503358410251, 41.29167725962978, 40.233441398989775, 42.56727518573884, 40.73746596613238, 43.87761354446412, 46.48034541837631, 48.0946635430859, 46.95723502866684, 46.64074290183283, 42.30895180856028, 42.11257442351311, 45.94936632340955, 46.17663629593388, 48.15313823761479, 45.847004229022616, 45.29199669438024, 42.27718061016452, 42.02565862286476, 42.895526578349454, 44.251976320820475, 46.65029779557259, 52.06263519102528, 51.45589159381006, 52.84408115571546, 50.278988345976806, 50.38561405674104, 54.366592284171816, 49.293759561354115, 49.77768982610395, 52.47262877802695, 48.750625041223344, 47.977470967077444, 44.995371372469016, 17.85853962744436, 2.769546109822489, 3.322950375656928, 5.802767180627392, 7.899064190926091, 8.545348221255887, 12.086166893282245, 19.714003109162856, 9.103716246543392, 0.8339059497079542, 0.4398544379059346, 0.4831487018494837, 35.6879242773979, 41.72497364782518, 28.46779000374579, 49.40126780540713, 5.386500743127638, 0.16673185081491548, 0.13401306294385465, 0.23694750161901598, 0.23328206201474513, 0.11341548675010282, 0.14280724669656447, 0.13848808894474662, 0.15384960739362627, 0.14539758915141707, 0.11653768574638713, 0.11930253536951159, 0.1572384126484394, 0.29494017362594604, 0.21280853077769282, 0.06943328351142906, 0.150212298537935, 0.13922664366902845, 0.1563697302293393, 0.1533027278679994, 0.21855405231397, 0.12606319235337357, 0.11780893204793816], [0.042708831043132854, 0.010271913732492156, 0.06120064603765646, 0.02374426127531596, 0.038148639047698635, 0.01916520627996614, 0.08747215668160109, 0.05167852170885571, 0.04213700003381218, 0.07756336862521787, 0.05069606374168108, 0.00409379766713227, 0.06517320646033173, 0.03486327864530106, 0.07338229822175157, 0.007151364219269806, 0.0208669959101826, 0.015052129052609447, 0.026913329530807755, 0.011997444427482063, 0.016263950871483936, 0.03574190105521872, 0.02789003800811066, 0.025424924115800572, 0.03056380360747778, 0.06201576741953051, 0.08435900518370253, 0.013145359191713075, 0.0358892465761352, 1.2783356179152767, 33.51862999700731, 32.42804242718604, 41.580485297787575, 41.195469364043205, 2.0259257670371764, 0.1740139302226805, 0.15203514346672645, 0.06482273655673189, 2.014577737258327, 5.9889390487824725, 10.472778370303493, 2.1009805654325793, 1.8915183986386948, 1.409597368009629, 1.2572147577039658, 1.612376183752091, 9.950146079063416, 26.95108006077428, 48.96228790283204, 52.85389492588659, 57.512168422822036, 54.83607253720684, 54.87527270470896, 46.125159109792406, 47.155322567109145, 46.07856527451546, 53.19869872062437, 55.28161848745039, 55.64748541001351, 53.39023982324908, 55.64624986340923, 53.66036168990597, 56.31008355848251, 56.39100205513739, 54.82136364906065, 45.96132955243511, 41.22063921343896, 42.09551603563371, 43.87826073554255, 49.401958142557454, 53.129531645005756, 52.861610228015536, 50.055911387166674, 47.11599296139133, 39.89056348800659, 39.350990479992284, 42.936048584599654, 39.09323584648871, 39.36010606827275, 37.64827782107938, 38.99853021867814, 37.675801092578524, 41.039335496964, 41.07295805408109, 41.69987440109253, 45.49690131218203, 47.00568022266511, 52.50366649320049, 54.99979226819931, 54.31016114450271, 46.61536908918812, 52.12374964068013, 51.42269265267157, 47.80145068322459, 53.15302664233793, 53.268199197707645, 54.34615281320388, 54.52335765284877, 55.79564902090258, 53.063573068188084, 50.359647966200306, 47.430096364790394, 39.91181096723003, 37.10795956273233, 37.25141632941462, 36.5266211571232, 37.17294539174726, 38.300516989923295, 39.506233969042384, 41.65575165902415, 41.61922262560937, 41.668695480592795, 38.798473650409335, 39.109290107604, 38.49346622343987, 39.30253744125366, 38.15918614787441, 38.691259584119244, 40.08171235361407, 39.85029251344743, 39.48905791005781, 39.643367875006895, 41.39782836360317, 40.190189423099646, 42.795741481165734, 45.528562684212964, 47.53836947102701, 48.87041814865605, 48.16854138528147, 46.57832622528077, 49.02695209749284, 49.95181952753375, 51.21478349931779, 50.70432624509258, 44.49336290359498, 42.91338512974401, 23.834484354142223, 3.11306827010647, 0.6198412492390603, 1.6667269963410594, 1.4767579061369744, 2.7410643091124873, 2.358216710629002, 4.726485475417107, 3.308981834880768, 0.4021039845481996, 0.2917009700209864, 0.02556189872144211, 2.5084790347083925, 37.50500148342502, 29.785716187569406, 31.569590530087872, 20.47726300454909, 0.5102434850508167, 0.03495870638758906, 0.03207822345317372, 0.05700546812506453, 0.03868639446614731, 0.08884346938782162, 0.014105406214272784, 0.03186323619898289, 0.01969301213149823, 0.04543605425785627, 0.07957804197024915, 0.08379956947699671, 0.04540361426470261, 0.054585212511160684, 0.05340700375757391, 0.03209487245898814, 0.09007541537885705, 0.060634307878752874, 0.010739560614550307, 0.09056450123147619, 0.01983743119654396, 0.04267911832298964, 0.033025514154184255, 0.050883774435327905, 0.057707001650405515, 0.016722255311305487, 0.043499579337695916, 0.013941692267244142, 0.014691591796074665, 0.023892177531736034, 0.04831868606889921, 0.019138801144436002, 0.036305331910449656, 0.03252789408208863, 0.05719942626573386, 0.0432321725172862, 0.02063486169302656, 0.08676257540261553, 0.027276713761591145, 0.038989186887779546, 0.04318633364633687, 0.023834268945539673, 0.01897222681662008, 0.044598769952332785, 0.044860772022436705, 0.012939127364886865, 0.02277975083298741, 0.07505175702634358, 0.023288573025755828, 0.08912799444289939, 0.0573281328674526, 0.07282117712161235, 2.5437156471513935, 43.4558371574648, 28.581778003323464, 48.42804147351173, 47.18721143661007, 1.0849768644379032, 0.1712011617998923, 0.12389921613277928, 0.3876422976534213, 1.4668644628217145, 8.195342383077069, 14.476822095532572, 4.238503892575541, 4.960426419012008, 2.0883343537007613, 1.690201156081692, 3.6260363315382316, 12.445329504628337, 28.634265199784313, 50.965752217077444, 54.41503747817009, 59.0312082536759, 55.76042613675518, 57.023609761268865, 47.82949955232682, 48.28120362374091, 46.025244574393, 54.06731936239428, 55.50367955238589, 57.50852454093195, 56.06384108143469, 56.61961347826066, 55.93677982207268, 57.66127340255245, 56.85992140923777, 57.75087994913901, 47.421996670384566, 43.077979549284905, 43.45559789288429, 45.494077205657966, 51.523109251453036, 55.10541777456961, 54.44067801198652, 52.30956408285326, 48.36171027152769, 41.814941052467596, 41.4175029723875, 42.9770451976407, 41.00235146860923, 40.3105983426494, 39.73774010135282, 39.80291420413602, 39.77897597897438, 43.36978427825436, 44.21598857448947, 44.451028762325166, 47.866809137405895, 48.522649042068, 54.56895520610195, 56.75846538236065, 56.55118773060461, 48.659182825396144, 51.40200999475295, 52.98594936247795, 49.25486141635526, 52.91483286888369, 54.983388916138686, 53.52189810045304, 56.569881746845866, 58.161097111240515, 54.912950992584236, 52.65201445548765, 50.051275145622995, 43.01638657046903, 39.511423264780355, 37.81690051478725, 39.00533945329728, 38.11931917744298, 39.96191924618137, 41.18219214100992, 42.70822555788102, 44.88205409819081, 43.16535034487325, 41.627032064622455, 40.36085174929711, 41.040755394966375, 40.34227540416103, 40.861867858517556, 41.07435049549226, 42.71767454762613, 42.95902975143925, 42.25588214012885, 41.75181834928451, 42.45713895367038, 42.334666867409986, 44.509181822499926, 48.35543840162216, 50.19610474186559, 51.234477719952984, 49.63792400975382, 47.03968324968892, 48.50779110385526, 50.26953151149135, 51.537947577814904, 50.40428061639109, 44.937363439990634, 44.91159739032869, 28.017035145913404, 4.151842065395848, 1.3211667970303567, 4.805085361003876, 2.3239391176931323, 3.6160786594114, 3.9682190024083663, 7.144279066593417, 1.4835102663886164, 0.6318098102365771, 0.1709743078437544, 0.07000045670617012, 1.6253130185988642, 44.857919754520545, 30.454776440897298, 29.864408739151497, 28.666738502440918, 0.7386747242942934, 0.08852585699529418, 0.04390467131029695, 0.039379876407404105, 0.024669128582782807, 0.06573878619219027, 0.01185715074590858, 0.03979208916726132, 0.05264329070585871, 0.05300445136644187, 0.05704393723018228, 0.11257186306700592, 0.013276657085835695, 0.03964507306415228, 0.06343193074327803, 0.01307050665585144, 0.0371725702538125, 0.031964361720207723, 0.04737821355041477, 0.113002450445727, 0.028570548165589574, 0.07149926176474941, 0.04897945988622885, 0.156094306298802, 0.09385936112413484, 0.1406226397281693, 0.1488689480409507, 0.14915103693642925, 0.09302191977058688, 0.13881960583309974, 0.23004757751139904, 0.19094386047893958, 0.22098150915436207, 0.13312729676404308, 0.12000637864994428, 0.2117045367917707, 0.10716391051368368, 0.1647088883985435, 0.1944787740226715, 0.12214210920877035, 0.1070628481947126, 0.09321837535788936, 0.11465945266067021, 0.14907139443582104, 0.16388626318545113, 0.1419311638681158, 0.11259390341658747, 0.1427799586447016, 0.19097265006313402, 0.21698118187487128, 0.13623779759772364, 0.24332758910473318, 3.573826642767076, 50.738368495818115, 42.605208427675315, 51.69302240494759, 54.368981007606756, 2.6086362667622107, 0.32206085059911976, 0.5289478588008112, 0.9040327189910797, 7.74680023231814, 16.984478658245457, 21.545889223775557, 9.745326772812875, 6.96740762841317, 3.5685748342544805, 2.7261134597562977, 2.315663652073953, 12.708833352211984, 28.897942612248084, 54.70024870287988, 59.2960859114124, 61.57428479963734, 58.78822526624126, 60.757215869042184, 48.676888404353974, 52.10702857663555, 48.21570004186323, 57.80424771770355, 59.849885356041696, 58.92516305369716, 57.184968225417606, 60.01694302405081, 58.76192969660605, 60.18197674905101, 59.81366618987053, 61.97535107212683, 49.79036692650088, 47.96583721714635, 47.28551387786866, 46.782913131098596, 54.300880816675004, 57.86694680490802, 57.145391510378936, 55.332220985043435, 51.45651525066745, 43.316145866147934, 44.026024264674035, 46.90926444145941, 43.19075945884951, 43.20953584486439, 41.33361131914201, 43.1473780447437, 40.73187266626666, 46.52007902822187, 46.69707205987746, 47.40828014189198, 49.34941407172911, 49.84823757602323, 57.06937989880962, 58.13948485159106, 58.82405611776537, 52.07376687757431, 51.26500160463395, 50.918381752506384, 52.95200517100673, 55.387914719120154, 55.54602546076621, 54.83566068833875, 59.013781163000296, 61.26913616734167, 57.52446505331225, 54.62662973711568, 51.61707355130104, 44.00414136148269, 41.582391569691325, 40.90874410444691, 40.260172351714104, 39.9425898059722, 42.14099199541154, 43.64707623758624, 46.089434162262954, 45.78543478442777, 44.48045046098771, 42.419441053944254, 42.708453055351015, 42.85741290738506, 42.6114018501774, 41.07041243583926, 41.05982595874418, 44.58249876576085, 44.858261000725534, 44.22101313068021, 44.8248424068574, 46.2905615375888, 44.35697817033337, 46.55549018613754, 49.340463222995886, 53.254439523143155, 51.93695068359376, 50.58160312714116, 48.3385722098812, 50.682929715802594, 51.99533516360868, 51.914514726208104, 51.676364098825765, 50.74809989621563, 47.153004446337306, 26.08209267739327, 4.640592432791188, 1.7625638602241394, 5.5392574494884865, 6.201511409974867, 7.117625090383715, 8.503943681716919, 12.738493334862495, 8.44420696458509, 2.9340924803287756, 0.6079735054123787, 0.19059521386459952, 3.6543100014809644, 48.78721291019071, 38.33168414331252, 41.00365761787661, 31.868051521239746, 1.0221626188966537, 0.19484778325403893, 0.16948886335857455, 0.1472056485832699, 0.09382491781105919, 0.21773746387372095, 0.07752533235977735, 0.2047345156390821, 0.20398972495909662, 0.12847243162292626, 0.30441527164751486, 0.1635602774519113, 0.10509718915507679, 0.2250565759717457, 0.13266546831976983, 0.16245884219965628, 0.13132050903814455, 0.1492371145756014, 0.1096181114835124, 0.29375411630157505, 0.14060573982855967, 0.28161680145609763, 0.22065000758776743], [0.08648345892828319, 0.04741086804818723, 0.020996430295429403, 0.08366351992252373, 0.01290113227667227, 0.04420172573337632, 0.029228056533141967, 0.062049046278961247, 0.04505027536182635, 0.05608178825388032, 0.016315602434558735, 0.030994484831969586, 0.08110829493812016, 0.02030630956494039, 0.02699280349207261, 0.025276203467060002, 0.024550340904463685, 0.06316582244189997, 0.04488606058481721, 0.0397605684796168, 0.019765212087922042, 0.04522758641190106, 0.04265917705432062, 0.03274086269459898, 0.054421599113172105, 0.06001822763092576, 0.016501685191366463, 0.045040323879689946, 0.07547538066583295, 0.10510964574472559, 14.338893909608165, 39.6039088310734, 21.148935556411743, 45.38519613204464, 16.137711501890614, 0.06537825755414463, 0.1261932894046749, 0.022581598360932643, 1.4016702578913782, 3.186821577049071, 5.693009947576831, 4.311711499767919, 5.121199469412527, 1.6440290981723418, 1.4985183578345085, 1.1003917792151052, 3.182930340689998, 15.20906977115139, 39.66047725369854, 52.858542934540786, 57.991533048691295, 54.92703622387302, 54.80658415825137, 49.0238965711286, 47.99855370675364, 49.51169037049817, 54.29185152053834, 56.22599186435823, 57.30439655242428, 55.92647183325983, 55.16785014060236, 55.00224767192718, 56.086116221643266, 55.56252687208114, 56.674428601418775, 48.11372626212336, 40.446559459932395, 40.45825204541607, 43.13524615380072, 49.8928153130316, 52.131319815112704, 54.390946280571725, 51.70256553157684, 51.25673324831071, 47.122629611722886, 40.8489122698384, 39.99197244644165, 40.15555881684826, 39.92783777175411, 38.3099385230772, 40.73477914256435, 39.378090135512814, 43.089456404409106, 41.31246189917288, 40.81024162230953, 43.334773202096265, 46.934344076341205, 52.3932086267779, 54.03029218796761, 55.20473610970282, 48.366640690834295, 54.6017893668144, 53.1357878254306, 54.95723062945951, 54.3795870965527, 52.136218855457926, 50.23669342840872, 54.41986591585221, 50.696489349488296, 50.33727084436725, 51.82888938534645, 42.415397090296594, 37.00344016475063, 36.41660651853008, 37.30414475164106, 37.92146698121102, 38.23883771896362, 40.089996399418006, 38.96084408606253, 39.83979232849614, 39.08688552917973, 38.49690614208099, 37.55488618727654, 37.49390902057771, 36.71424773431594, 35.88875355259065, 35.95746563326928, 35.85820221131848, 36.876724073963786, 36.01978425056704, 37.26399144818706, 39.00406076062111, 41.85899319187288, 42.72095757146036, 44.34132399097566, 46.690470710877456, 50.9855797982985, 48.55874661476382, 46.69396162033082, 46.48307146564607, 46.66684235295942, 45.1041151631263, 46.392405879112985, 44.377096006947184, 49.1819445548519, 26.22484341744454, 4.009276902483356, 0.2546253481939916, 1.3109268368251863, 2.5951913624040546, 1.9832479280810205, 1.9395560338612527, 1.6280436011091357, 6.059937871271565, 0.48354547410722704, 0.1482768540060328, 0.05359422032450957, 0.08063093789162175, 9.547798172120126, 42.84589290618897, 21.17464473170619, 38.17405977556783, 7.289630338068932, 0.05983116428157496, 0.008287019182687566, 0.011634460477639112, 0.06579126321500348, 0.038034331068516745, 0.027782358604693608, 0.011230847054731943, 0.08328458985253688, 0.028229340264994292, 0.031393653029696114, 0.07595157325868646, 0.023297930789750912, 0.0299387811983545, 0.03997883459012355, 0.023312879080373435, 0.015453938338454935, 0.039505871057870894, 0.028355807974754323, 0.039756186456689914, 0.09296858472929848, 0.03213772550225258, 0.0226501191801001, 0.023708107670949354, 0.0474536004326036, 0.05393531331191621, 0.01588745025782696, 0.07019325805407378, 0.0316427790770127, 0.013257782594601234, 0.024709149015947215, 0.059026197395137245, 0.032424613938576756, 0.06648924592281542, 0.016326168702254375, 0.07926381568634704, 0.03848213627333603, 0.06711577560992972, 0.028698756810157534, 0.025767156658994577, 0.017253943313393864, 0.10408732439241103, 0.08265888754038081, 0.01714664503871914, 0.062481767212551456, 0.029684007167816166, 0.0439332808638292, 0.0497707789162955, 0.020533046692669876, 0.01504917291083163, 0.05560930735701996, 0.04973712850422148, 0.04550051289580522, 0.09725906014923127, 21.79987838191371, 42.33852647965954, 30.529468174903627, 60.64755816613475, 15.001539126519235, 0.05396301505125819, 0.27370973219794614, 0.10064047265557513, 0.283474350167859, 1.9034703508500133, 13.942510947104424, 6.702441717347791, 4.60818532013124, 3.1111916611271524, 2.3664593263979885, 2.091046427526782, 4.096875440689826, 17.139480921529955, 42.9077761403976, 55.30904369969522, 59.574174111889256, 57.897156899975194, 55.0443817723182, 50.83020687103272, 49.10675664101878, 50.12480389687323, 56.70495640846991, 57.26665550662626, 58.413136851403024, 55.81956763421336, 56.64671313378119, 59.042234036230276, 57.24841648532499, 57.69977931053408, 57.49133279246669, 49.57298524918095, 42.54328989213513, 42.405963790032175, 45.73812315540929, 52.12818191897485, 53.667355275923214, 56.55512579025761, 52.47138146431216, 53.344042147359545, 47.148156396804325, 42.393427894961455, 42.43043545753726, 42.93435804305538, 41.55413089259979, 40.60026145750477, 41.55613522375784, 41.41540842671549, 43.24230724765409, 43.107640512527965, 41.7446796355709, 45.15055602596652, 48.64556435615786, 53.24385696841825, 56.50141677548809, 55.112842821305804, 48.62148100329984, 54.04352234255884, 52.50121108947262, 57.8006273700345, 57.39593290513562, 54.2837243695413, 53.3680352857036, 54.03540303630214, 53.79846834367322, 52.448070818378085, 53.731195772847826, 44.61901603206512, 39.52244904733474, 39.89397595005651, 38.72962820914484, 40.24844838726906, 39.11844491958618, 42.53194639759679, 42.00292848771618, 42.3676775347802, 40.222678415236935, 39.9730940788023, 39.94417052115164, 39.839247119042184, 37.42461642911358, 37.558153521630075, 37.28086548466837, 37.246270179748535, 38.84134907876292, 39.2378967808139, 39.15359720107048, 40.90885393081173, 44.0376893935665, 44.64084794444423, 45.41184863736553, 47.46592329394433, 52.694046574254195, 51.306531660018436, 46.026680161876065, 46.14125651697959, 49.20217614020071, 46.719778660805, 47.154365508787095, 45.64117785423033, 49.58775297287972, 30.26834618660712, 6.551883499468527, 0.675143726891087, 2.7494221445052855, 6.04864978021191, 4.565285376964077, 3.4540521665926907, 4.490797606206709, 5.317097835002407, 0.7427194233863585, 0.2039497045259322, 0.09827647853883044, 0.07096253290411926, 9.680644927486297, 49.82882184367026, 25.125430514735562, 42.414106630509906, 12.061105889658775, 0.054750212528292215, 0.06950806135371809, 0.03598247181564089, 0.08388790707554548, 0.03323964722033951, 0.051952141502331343, 0.018458063075799617, 0.0761847627619582, 0.04270623783550916, 0.04457417469952376, 0.02390123077578122, 0.03506138515208037, 0.00473943981154251, 0.05359477573825468, 0.05561330633598471, 0.02844145277424926, 0.03215196707676495, 0.009612114762046165, 0.02183093561700756, 0.033908786717802286, 0.08307319555071094, 0.03346727109484134, 0.05023506267236606, 0.16934713709258264, 0.20656446986381086, 0.07263634308812118, 0.16456700891496676, 0.08443344594730486, 0.11647277511656286, 0.1377899683411083, 0.20114304948477976, 0.116406868572437, 0.17216773493395698, 0.06383653241960753, 0.1906037327623175, 0.18016396150473626, 0.13999881433142772, 0.11639504017488611, 0.10680206420440828, 0.10347214046745531, 0.1669539397041644, 0.1812537522205422, 0.08377949797338055, 0.12079013256175865, 0.1431630179286003, 0.1570656291779972, 0.1374897078400658, 0.1102356396375164, 0.10760702342996675, 0.12403688213277249, 0.14828874369061765, 0.17382040109124877, 0.3475985754161112, 25.842373101942, 56.526080639131614, 31.982390572947843, 58.180673660770545, 22.19174277397894, 0.27756413504962, 0.5851525428795046, 0.249104903289868, 3.5528745670472426, 12.658184766769411, 19.819450147690315, 11.835429380016944, 12.986595995964544, 5.939501004834329, 5.226893126964569, 2.2386072191499897, 4.572052446103865, 15.876799360398325, 44.242880344390876, 57.823773276421335, 61.67358744528986, 61.090115270306995, 57.45414872323313, 53.318009376525886, 51.60477692081083, 53.413338661193855, 60.221208295514515, 59.01793103064261, 61.0879893456736, 58.33292045900899, 58.85927115717242, 60.34751253743326, 59.6909156153279, 58.98036256913216, 62.266575290310776, 51.770779471243586, 45.79569178242838, 44.55158264406266, 48.503900112644324, 53.984518128056685, 56.23895137540756, 58.5055322031821, 54.678550151086625, 55.8527587306115, 50.5913737512404, 44.465541531962735, 44.05441045761109, 44.856009560246626, 43.35262783112065, 42.81025817317348, 43.40319110501198, 45.27904110570108, 45.816162632357695, 45.827431601862756, 44.36562699656333, 47.182069209314164, 50.985003209883175, 57.4536858835528, 59.056762495348536, 58.56721147414177, 51.52734541123914, 51.81442760652112, 56.47896905099192, 58.2088323562376, 59.964042017536784, 57.44551950885404, 54.23941727607481, 56.812076337875865, 54.72642660140992, 54.619255681191724, 56.10756766411566, 46.54440164566041, 42.633786816750806, 40.88963431696738, 40.93050149179275, 42.6543753377853, 41.78524478789299, 43.77228221585674, 43.8221747644486, 43.39789198290917, 41.83161504807011, 42.06042258970199, 40.82866107263873, 40.38651189496441, 39.50552402004119, 39.60125730883691, 39.0779072238553, 39.20089706297844, 41.435275231638265, 39.9642530564339, 40.70949946680377, 42.60472597614412, 46.00626030275899, 46.76528599954421, 48.260187564357636, 49.82809228281821, 55.15370607376099, 52.40803126365908, 47.86446748241302, 46.604468822479255, 50.909595643320394, 49.28838199184787, 48.895835107372655, 48.45041859534479, 50.934067310825476, 27.731298323600527, 5.716119081743303, 0.6543322436271176, 2.614051098785093, 6.996825895001812, 5.017185076590508, 5.923115303439479, 8.075174198996637, 15.317888086841954, 3.7974157160328286, 0.6417105467088762, 0.6132568154604204, 0.2915804490687386, 13.548204879606924, 55.96027874177503, 28.701459323206258, 50.80245610206358, 13.706818665227583, 0.14120048452769557, 0.13307667367400663, 0.1256084961876754, 0.10865117062724407, 0.11714225935359156, 0.09346533146116043, 0.07199741043751279, 0.21927132511571532, 0.08780706733945878, 0.1351312755216514, 0.11807301021631687, 0.09714623071974325, 0.14292318644302507, 0.18334606091582006, 0.11629712647728382, 0.12678169089579774, 0.14885964773354993, 0.11885644237120306, 0.15710776401383264, 0.25191908131443685, 0.21285558389800213, 0.18988299724315444, 0.09488562782925945], [0.0701289909381059, 0.050090034567420526, 0.04813368349606472, 0.022663820662625858, 0.03815963240941206, 0.03993668060209002, 0.02820146807108916, 0.02342793591050131, 0.030208511180394602, 0.03557685890325135, 0.019422161745868867, 0.0366648952777107, 0.06574346698940763, 0.03102071568249695, 0.030532665963795398, 0.03982870817004193, 0.027597055342348836, 0.05892138124533719, 0.028173647588118914, 0.054316763811173945, 0.017988675258933537, 0.04285763979198472, 0.10856726867777687, 0.048158895449652794, 0.03991961599357667, 0.04528556394601061, 0.03458553346835318, 0.02214376762088749, 0.033503970536854, 0.13282378805020165, 3.713057791033099, 39.57418118753741, 27.149440203943563, 33.85003497523646, 40.525932542739376, 2.932710335139306, 0.03566808082283505, 0.06759129404540985, 0.07910184171651641, 0.7590617948482115, 5.196017209560641, 4.456209655730955, 2.298039952593465, 0.7637400180101396, 0.9216170721957762, 1.788958469706197, 0.7824540751114969, 6.058493458455609, 26.830569159600046, 51.88743860490861, 59.08727853528915, 57.18878469159527, 55.0186941700597, 51.76789652916693, 51.495974294600956, 54.651419116604714, 56.940008363416126, 55.83123276310583, 56.48980263740786, 51.60844433692194, 53.84086916523596, 54.60342891754643, 55.43174720579579, 57.15069847722208, 53.497700998860026, 49.80956692849436, 43.558818986338956, 42.00618797732938, 43.52607896251064, 47.70144985568139, 51.625263460220836, 52.41450709681357, 53.66340937152986, 54.32131636527277, 51.38708929861746, 45.6834610046879, 39.90641378587292, 41.40289998823597, 39.713448862875666, 39.49477672576904, 39.786063701875754, 41.18805608441753, 43.41983372165311, 44.08132576173352, 47.280230445246545, 45.957273821676935, 51.0802815037389, 53.33131797852055, 54.81694313787646, 51.516178423358554, 47.717370756210826, 54.03407335281373, 54.57291287760581, 53.49086823001985, 50.67497907146331, 51.789073405727265, 51.10340779827487, 51.60147820749591, 51.260220235393895, 48.007010336845156, 41.286429128339215, 37.608873690328295, 38.26606681269985, 37.52499772656349, 37.607218450115575, 37.0881555157323, 37.47520715959611, 38.32867176302018, 37.60402171842514, 37.90062350611533, 39.93057166376422, 41.57901833134313, 43.333078738181825, 43.339676164811664, 43.799252433161584, 43.0288871642082, 40.6400421357924, 38.13609515466998, 36.32419155490014, 34.68982619623984, 37.092948652082875, 39.26097992927798, 41.51462085785405, 44.69820476347401, 46.06567636612923, 46.54990473101216, 49.881550265896706, 47.98280931288197, 48.044182638968195, 47.07031696073471, 46.334503850629254, 44.897284661569905, 46.416085227843254, 46.28170090336954, 25.20012224874189, 3.820258374175718, 1.1466279433619593, 0.6137058042710828, 3.70598943483445, 7.391372207672366, 0.7096030358825961, 2.3802768559225145, 3.3512019822674417, 2.7518596524192445, 0.7125907787872899, 0.1721996808003995, 0.08025809822063293, 0.4142527907125412, 26.381542105828565, 36.577498220628314, 21.581194477696574, 29.601282419696933, 1.5204271241541834, 0.016662686229533246, 0.04327811864054492, 0.03737218212336302, 0.04738593954713114, 0.05664473264327934, 0.04251085094086105, 0.008526087453168248, 0.015264044294223912, 0.05068962094223788, 0.017355882803038243, 0.003993707561617597, 0.023446389053377415, 0.03327888624382115, 0.03271189307974231, 0.027491540137317874, 0.002160425642467735, 0.07579032707238391, 0.037942515430791725, 0.07379871297387347, 0.016968675153029543, 0.18046866531573957, 0.02304950188244543, 0.02084009281750168, 0.045782854600298795, 0.01653696928593901, 0.031190067079038392, 0.049385777599508726, 0.011376986944777592, 0.03013421022783845, 0.01426828129502434, 0.010818477246850249, 0.033346294320278594, 0.0351152794375535, 0.011184355093827172, 0.08350373696415656, 0.12605661931898327, 0.026598455902609616, 0.011673960928624917, 0.056289382759601846, 0.029639171872047648, 0.08485575191556446, 0.01334632129123014, 0.06061894398543143, 0.08901372476811371, 0.020931760983301267, 0.011525943165554876, 0.0232810155683828, 0.01570172373190402, 0.01889152519945656, 0.021215483561278354, 0.03939848468308488, 0.026132571022777308, 0.12068202989476344, 5.936802904452048, 48.30392983651931, 25.00641795896715, 44.009158072933076, 44.83812355226086, 1.6709707557193696, 0.08922707259414658, 0.04596627903200927, 0.10587621630439836, 0.46614158057397415, 3.39760190536899, 2.859290429661351, 5.883630273803588, 5.63239069715623, 2.4709598479732393, 3.6807411380352515, 1.5748909500337418, 7.392686201680092, 28.65825245457311, 52.65470912379604, 59.94515188278691, 58.69644964894941, 54.85874383680282, 53.77114511305287, 53.02216852864912, 57.64790204263503, 57.15196932515791, 56.6427162385756, 57.305439902890114, 53.581298474342596, 55.90751501821703, 56.8335787711605, 56.14073914866294, 59.71559909082229, 55.89233152327999, 51.685083527718824, 44.39478589642433, 44.37630761054255, 44.34954527885684, 49.966414666944935, 52.819880131752264, 54.55932186495874, 56.101589971973056, 56.398642832233065, 52.46111269920103, 45.13021853662307, 42.18660916051557, 42.091938834036554, 41.492985063983554, 41.23909788746988, 42.22820589619298, 43.09197456605973, 44.17505864174136, 46.62642625070388, 49.56172412441623, 48.21919487368677, 52.99158973078574, 55.75976717856623, 56.15045485957977, 53.07259451958441, 48.727765467859086, 53.9629372473686, 57.56206097141389, 55.46697401231336, 53.94611027932937, 54.48822890558551, 53.34909808251166, 54.2490388501075, 53.57291244691419, 49.78811548602197, 44.20629247542351, 39.439663502477835, 38.68090060449416, 39.257245832873934, 38.78468651925364, 39.24463933514011, 38.9096571553138, 39.76806786752517, 39.23561788374378, 40.14272874401462, 41.669982018009314, 42.399507568728545, 42.58405116296584, 44.52311800372216, 44.53119024153679, 44.054457526053156, 41.26793515297675, 38.644261744714555, 36.783650152144894, 37.18106469800396, 36.95557155916768, 42.662745675733014, 42.720329992232784, 47.328652105023785, 48.27098584944203, 48.88293835424608, 52.81942513681228, 49.89820857201853, 47.805106332225186, 47.74104226020075, 46.15934256584414, 45.9597017688136, 47.608175892983716, 49.2153827605709, 30.184738905199115, 5.446273742183562, 1.9495347887277605, 1.8605788652935338, 3.2870133749900328, 6.623889880795633, 6.907873403641486, 6.564636595787541, 4.641854945690402, 1.5076343138371746, 0.3722530314999242, 0.13136544775578285, 0.06686434555318087, 0.41651382261226255, 26.027275593050067, 43.36636789383427, 20.43603693285296, 36.75043552152572, 2.8638384178761513, 0.032861425781682614, 0.021346781455400973, 0.02121118580802314, 0.024540429641943307, 0.03966732025747338, 0.04947948930484634, 0.0026616216693524154, 0.051304283927405075, 0.04272298451753394, 0.011148022416408264, 0.0892297079366061, 0.045212686001773805, 0.035385145400200164, 0.06693310194438504, 0.028982810721161868, 0.056199007367174474, 0.025983919321949926, 0.08800847185475212, 0.056351642725208116, 0.023287808853051355, 0.0503536032873296, 0.028868602333410136, 0.022856982071853937, 0.26141205982815835, 0.09356290041919678, 0.15900283571212523, 0.10734706681462065, 0.13859022378681168, 0.14352718548428628, 0.09326300764035794, 0.09496985153565485, 0.11785415421810844, 0.14822828403163343, 0.05760942886192953, 0.11635391657511074, 0.20060188497506803, 0.15998800946099145, 0.2570021972661057, 0.12008661103825416, 0.13960368150184232, 0.2247084349754357, 0.1304726182453094, 0.2085048480019454, 0.12510369787172926, 0.08087559573111996, 0.12451461456235378, 0.14956893789912426, 0.22457078429720095, 0.14559393748641014, 0.10082559014159827, 0.1000745558450299, 0.0661305099305126, 0.3019723091875353, 8.4461465766353, 57.290891831920995, 34.904952510710686, 44.16253843615132, 50.355439263005415, 4.603436310445109, 0.17647527879284275, 0.3315805349378817, 0.2617581170653143, 1.8172271141121465, 13.015788235972005, 12.348129249388172, 6.126248480812197, 5.262082670965503, 5.268372681833083, 6.236183201113056, 2.0969299827852557, 6.974323747619507, 29.62132573127747, 55.19052928493869, 63.60656676753875, 61.349230966260365, 57.03137213183988, 56.195063975549516, 55.34551389755742, 60.36389627764302, 61.24145207866546, 58.001358585972945, 57.925143011154674, 52.953621187517726, 57.82010586031022, 59.355243098351266, 57.492454590335974, 61.58006245090116, 57.88158116802093, 54.04619739901636, 46.886706890598425, 47.26565099531605, 46.45107669215049, 51.8993273089009, 55.19462423939859, 57.82322022222704, 58.78582477569581, 59.89354525842975, 55.36535324588899, 48.44999105699601, 44.82319501138503, 43.11358290333902, 42.948490342786236, 43.56836603533837, 45.13763573861892, 45.94207463725921, 47.35415927825436, 49.14450553155715, 51.75929084900887, 50.569302574280776, 55.48752723201629, 57.75371190040343, 58.700273959867424, 53.8321497363429, 49.93151341715167, 55.9754857709331, 56.850711684073175, 57.124516656321866, 54.70039383057625, 56.47821595591884, 55.30333272872433, 55.00846855102047, 55.62897966754053, 50.71323394775391, 44.53796417482438, 41.36773593964116, 40.618496556435865, 40.15924584481024, 41.44866228103638, 40.52485389094199, 41.58186204971806, 41.70966071467246, 42.92081409885038, 40.24915441390007, 43.10704823463194, 46.17168626477642, 46.42816220560382, 46.739876885567945, 47.17305560265818, 46.85639873627694, 43.504572606855824, 41.53954752029912, 38.58645385311496, 38.76425881539622, 39.736826189102665, 43.43544083256876, 44.16531155186315, 49.8026910135823, 49.18314480012464, 50.06285398237167, 53.37595847345168, 50.89471024851645, 48.413207069520034, 48.406197794022106, 48.14823527489939, 47.54311553893551, 47.38465962871429, 49.522743609643754, 26.93346469633041, 5.955146849155427, 2.420684377993307, 1.9580659438525478, 8.344306157481286, 14.082957294679458, 6.171906830803041, 6.656829455206472, 10.006394828519515, 8.457933299003109, 1.8113396364835002, 0.5259995234589423, 0.16302138056245544, 1.233626849228336, 33.708468790977236, 46.39326487818072, 29.560532915976744, 41.62809502693915, 3.5584708086905943, 0.20449595585946115, 0.13051901253000384, 0.2481201738719979, 0.11534787459118713, 0.10567109626267226, 0.1746687208933215, 0.07512786020074161, 0.1642167841595027, 0.20440866780136863, 0.15408651242333074, 0.2418160976301278, 0.08372789429080102, 0.16851700421783233, 0.1309769645693802, 0.15851951084069668, 0.15123838138195778, 0.1812461985936088, 0.15399300373129307, 0.15512230926223342, 0.16794383255464418, 0.14497170555255107, 0.10462125703211754, 0.1313595182352489], [0.035216429856635874, 0.05917226354922018, 0.012150766391817842, 0.0420172528303679, 0.06567755278440253, 0.0565213771657117, 0.10107440017764607, 0.01889536904561664, 0.03562620262645426, 0.05124213887498744, 0.010814109588071946, 0.03819369650896519, 0.03827081091942326, 0.08937587751255882, 0.04706774875822087, 0.03357044781648344, 0.0317404629482377, 0.02263189777882109, 0.018520365176241727, 0.047726576712222836, 0.007999794625286615, 0.0675071852522031, 0.032781833076789495, 0.03715350232537716, 0.05092681325491398, 0.046448228775613734, 0.11075996553465245, 0.043729470832453626, 0.07280159591426773, 0.03907651325026828, 0.31830907288578253, 22.228189437620102, 41.86608483714443, 33.15310432064918, 51.11685760559575, 19.60342953282018, 1.0026295218736896, 0.06421499134552094, 0.14774431564634846, 0.10777996777887307, 2.0455166577331485, 1.4812366400034198, 6.442969576005013, 4.90736851769109, 2.4730933721988433, 1.8347816818183469, 0.7601147060913425, 1.7709171603764258, 13.739361589954747, 38.58764233127717, 57.972709594234345, 54.61371337213824, 56.14158638062016, 53.97182533817907, 56.34743628963348, 56.98184828604422, 57.036302551146484, 58.43726727270312, 56.05203866958619, 54.49264157202936, 57.81142957748906, 53.25239596828338, 53.045008490162516, 57.43647060086651, 57.02411574702109, 52.00113242672336, 46.751361585432484, 42.71951806160712, 42.4730755436805, 43.62014524398312, 47.85147659240231, 53.1787887696297, 53.711462328510905, 54.43535143329252, 53.02415717032648, 49.59774717207878, 43.67057907965876, 40.54401859160393, 41.898193359375, 41.43804834735009, 42.48778835419686, 41.07605672651722, 45.7055635606089, 50.75244195999638, 51.80872840266074, 51.6988157456921, 55.09221115419942, 54.141460003391394, 53.92642390343451, 51.60069373346145, 45.51150037396339, 56.79571613188713, 53.466718196868904, 52.5034389957305, 49.57194189871512, 47.50118147942328, 46.3481419317184, 44.894519390598425, 43.845355972166985, 39.97351769478091, 38.70190881913708, 38.01474094390869, 38.32677333585678, 37.20101387270036, 37.35472371501308, 38.69309525335989, 38.42617796313378, 39.655617437055035, 38.476513739555116, 40.516267822634795, 46.66150008478473, 50.08120283003777, 50.27740370842719, 51.83563586204283, 51.61799138592136, 49.58348935650241, 50.386979041561005, 43.797840379899554, 39.269601298916726, 36.22306892948766, 37.74068886233915, 38.50177380346483, 44.32465784011349, 46.33635128698042, 48.806832605792636, 48.65478977080315, 50.02267714469664, 49.04953710494503, 48.50663400465443, 44.73603994615617, 47.986060957754816, 47.96546066960981, 44.11624270100748, 21.910983439414732, 5.806052165646707, 0.41539536488633005, 1.2716235845319688, 1.4625098964860364, 2.2149898928980676, 4.674039463843069, 12.586697609193864, 9.66912002332749, 3.152469704228063, 0.7873307456893306, 0.09952669572685996, 0.09724442020899828, 0.13067515657073067, 5.321129541243277, 38.353535667542495, 25.60075313814225, 31.641301262763243, 14.111583732789564, 0.07888119307256515, 0.03428113609251957, 0.06438953681818901, 0.0772892240615141, 0.03174718920021288, 0.039465950216136636, 0.08302323895716861, 0.05667883887766831, 0.03881919580782133, 0.029056962286572785, 0.06348703544767154, 0.007044629976829335, 0.022998924757684433, 0.053793832194060094, 0.04965340275497687, 0.0556892256492809, 0.002923694123784381, 0.0531301663948163, 0.0043954208470700735, 0.0847687396491247, 0.008443444760726585, 0.044936660692215934, 0.010079928268227848, 0.06802762708356304, 0.035271749065648166, 0.09230365871541923, 0.04245293469378545, 0.02297117513784718, 0.0609826825318798, 0.06864513991580856, 0.05243529400397694, 0.05061063727724457, 0.011888050902334434, 0.03513392601763049, 0.019774238518889875, 0.027516334572987213, 0.03614492842086381, 0.046026428425384146, 0.022278959156885263, 0.0580345731859486, 0.0635915145187849, 0.012163506433998626, 0.007940245653322388, 0.0673977802357366, 0.047788334890238704, 0.021131560544393236, 0.026064471551968206, 0.04302188904295045, 0.06859353623322903, 0.02430789131340721, 0.031023264840064995, 0.014260904825923425, 0.023697589283748984, 0.06456919975819127, 0.4209964482053634, 31.985379419019146, 42.30086780363514, 30.393410959551414, 58.49681669665922, 19.020632005506947, 0.7303631606121218, 0.06964468547413427, 0.03696779495165233, 0.11756017563804505, 1.0004589802795842, 1.6938591339895803, 4.291344102351896, 8.727318740660145, 4.407535983670143, 2.7564176917076115, 1.364251091595619, 3.0918668787325583, 16.461054048230572, 41.435471350146884, 58.52806621982206, 56.958914187646684, 57.71057759561847, 55.05293253929385, 56.885848276076786, 57.84426373820151, 59.00735632065804, 59.98155540035617, 56.76757704827094, 55.32762396720148, 58.67106406919418, 55.00677800947621, 55.15590652342766, 58.27237083065895, 58.383060116921705, 55.10166798868487, 48.167607861180464, 45.79708030146938, 42.541720944066206, 46.72009637278896, 50.116241362787065, 54.4804233889426, 55.12543755192911, 56.674055976252404, 55.26631732140818, 51.750006598811, 44.65907127626481, 42.51872016537575, 44.20779474319951, 41.91721293234056, 44.08868412817679, 42.835388798867505, 47.60784641388924, 52.187978452251805, 53.70953252238613, 53.99049189782912, 56.503903558177335, 56.7625956381521, 56.08222523043233, 52.61173171381797, 46.54788078800325, 56.95377196035078, 55.71666817511282, 54.467326594937234, 49.959534829662694, 51.563439061564786, 48.25251148593042, 46.04895137971448, 47.37623829995432, 42.895950194328066, 39.55860153321297, 38.2091728333504, 39.58188864492601, 38.34313746421568, 38.151008006065126, 38.97050096142677, 40.484731966449374, 40.903358690200314, 41.234191002384314, 41.54570564146965, 46.50915522729197, 49.66050509483584, 51.12782063022737, 52.61028043685421, 52.9465413093567, 50.661223319269, 51.203561598254794, 44.53229242755521, 40.53658570012739, 38.17785662989463, 40.268978072750954, 40.566364334475615, 47.059871688965835, 47.87601886257049, 49.907010370685214, 50.47981369879938, 51.449035290748846, 48.95556103798651, 49.632919065413944, 46.33890867233277, 48.662054000362275, 48.04810108677034, 47.02593141986478, 27.890803467842844, 7.922136552872197, 0.9923937904738611, 3.1157516616006053, 3.5559962834081347, 4.186052978038788, 6.877900611969733, 13.642496697364317, 8.863531870226707, 2.137664777617301, 0.5726648194174613, 0.10034554412648564, 0.05241844006964276, 0.10687903305816074, 4.345471339841043, 45.424231559999534, 29.791856658074167, 32.62760477681314, 21.946975108115904, 0.2576294240932311, 0.045853146997791146, 0.04206057893292558, 0.01381867865641271, 0.01450562395245558, 0.04260584201303221, 0.035404301428746794, 0.05449202174561159, 0.041221314290117834, 0.049342623866734006, 0.08571018509927296, 0.005383517221367408, 0.0325183677787502, 0.010703723021452467, 0.042037243894752, 0.07030255581823087, 0.06360461845272972, 0.040751809644843304, 0.019760686423509352, 0.07979474526139037, 0.0673397184319554, 0.05474880292651154, 0.04102144195067306, 0.018465902070484815, 0.10892327739706925, 0.11557891138739164, 0.08738008823486106, 0.09073130155522978, 0.21363598234470815, 0.31213201402175816, 0.20351824380697744, 0.11057087971318154, 0.10792121140947265, 0.1710081689300076, 0.12941811353929583, 0.1537974980930167, 0.1218096576931496, 0.21737633002621515, 0.1721157788509323, 0.1600991994623215, 0.2522171661257744, 0.10821490653700407, 0.16783111037746554, 0.14230749690003935, 0.19213171044905342, 0.14651417762281435, 0.13728537686890172, 0.17385893531384009, 0.12669400447198462, 0.11877866146425087, 0.24460602131101394, 0.12925222486017213, 0.16269351025262188, 0.13774718999141647, 0.7035007471999815, 36.19143893641811, 53.97332760595507, 43.392145710606734, 64.09019500978532, 26.450403236573745, 1.5779671914154485, 0.21271785661097498, 0.3505917728668259, 0.7958136066313714, 7.308014487066577, 9.36345265757653, 16.45529208644744, 13.526946613865515, 6.600157580068035, 5.676488924411036, 1.9342132753902868, 2.791394692274832, 15.324936586041606, 41.79879265446817, 60.28424078418363, 59.07717450972527, 59.74075325073735, 58.15043610911216, 60.76674722856092, 60.25303832946285, 61.253207422071895, 61.66809220467845, 57.668737672990375, 56.8635731358682, 61.6113551201359, 56.41266138322892, 55.90571857267811, 62.289595680852095, 61.78822263594597, 56.416866164053644, 50.838655656383885, 48.38023562585154, 44.685739471066384, 46.75855128995834, 51.37630278064359, 58.78824487809212, 57.62414424650131, 59.31033980461859, 57.901824520480254, 55.64794432732367, 47.156660095337905, 44.11374807357789, 46.46893132117487, 45.21021527628745, 45.98440093378867, 45.30773716588175, 48.187423675291, 54.038646836434644, 56.68400702937957, 55.59291739617625, 60.389830989222375, 60.030059429907034, 56.28762406687583, 55.08186786405502, 49.390826456008426, 59.777666676429014, 59.57114211974606, 56.95240697553081, 52.98224664503529, 53.56668764545072, 49.8152151415425, 46.91627763932752, 48.47121500199842, 42.58203506469727, 41.64604379284767, 40.122155912460826, 42.206625015504905, 39.169302371240434, 40.121340059464984, 42.074288168261134, 40.93538876502745, 43.00714938871322, 42.446897645150464, 43.87290670025734, 50.863311675287065, 52.98504329496815, 55.27018085602791, 55.19129414712229, 54.40946379015523, 52.38368511199952, 55.39181355507144, 47.161010003859, 42.05497441753265, 40.57947289559149, 43.375938477054724, 42.23220671376875, 49.271668772543634, 50.68671088064871, 52.7937061555924, 51.773258409192486, 54.882450642124304, 50.69473605002127, 51.80040513315509, 47.5871519888601, 50.41139971825385, 49.57100052987376, 47.974223244574766, 25.613853854517785, 7.183290960327272, 0.8897526562213899, 3.790106869512989, 4.422241439742427, 6.050279034722236, 13.500745181114445, 22.951266611776045, 19.328422354113673, 7.623167614783011, 4.433299581850729, 0.35384084368425034, 0.2959236160161034, 0.2168777753268519, 8.130488934055451, 50.10303866478705, 34.37575417180216, 42.68907654669977, 24.923604957519043, 0.4654893333152418, 0.16760252506261872, 0.1354091662553049, 0.10323984728705499, 0.18260560629348602, 0.13149416584882045, 0.17807609611941924, 0.1894045753344413, 0.1425434979459932, 0.1539406952478232, 0.20497476081213645, 0.10642343290871191, 0.13741216442037013, 0.13647439619225843, 0.13127112701054544, 0.25354183939916475, 0.18408746548718025, 0.12395989795726155, 0.1366591612778364, 0.24793378468002045, 0.13135173478193823, 0.11320682738216654, 0.1506273036882762, 0.15987916368870966], [0.043138897482065425, 0.03960164737016444, 0.05989184993649683, 0.05822085129517702, 0.03023093074349867, 0.05353098742723946, 0.037700703607932214, 0.04879364526019462, 0.004754294256394309, 0.01900017561931764, 0.04438554086992818, 0.012948733149847437, 0.022890937003877856, 0.01206954479247572, 0.038605522394420645, 0.03562850472066672, 0.04491754679850513, 0.008564454094026118, 0.11799142951326025, 0.06349585311968, 0.05836124073774104, 0.021707654833012534, 0.0472913276884825, 0.07618579698065597, 0.018791412829511592, 0.01814994251265401, 0.017604248508089976, 0.011426401531113493, 0.026295801376803752, 0.03872423154872753, 0.04879389806920963, 4.278371843599504, 37.48247531152541, 35.62265211536039, 38.315406307097405, 39.92035388946533, 9.079453445249989, 0.7853438200489168, 0.07152671069507638, 0.08833635748634416, 0.11378158484735798, 0.5367323539910779, 2.9543463741579368, 8.86285133900181, 2.5740684184335896, 2.267157171041735, 0.9939006547774039, 0.32340864440606487, 5.37405163049698, 24.912961606056463, 48.8669390063132, 58.19648081256498, 56.57383549597956, 57.307793324993504, 56.7090670524105, 56.46926902955579, 59.5016259531821, 54.47130387829196, 56.70979661326255, 55.995603607546904, 56.58157433232954, 54.431483976302616, 56.25137352174329, 58.394183958730395, 58.02880733243881, 54.21198029671946, 49.854093674690496, 44.18608834666591, 42.78210340007659, 41.94676799158896, 47.20320686217278, 51.424324358663256, 54.63429404843239, 55.67936251240393, 57.31935254989132, 54.67345499223279, 48.77796788369456, 40.85264244387227, 40.261094108704604, 40.14477622124457, 43.70768862385904, 40.76881747091971, 48.975204267809474, 56.296237591774236, 56.4395845320917, 54.695341817794315, 56.47471327935496, 56.57019161408948, 52.50275258095034, 48.51344716164374, 48.73064840993574, 55.69811144182759, 54.06373823842695, 54.483274952057876, 49.314614803560325, 44.17348969367243, 43.28145642434397, 39.000412956360854, 39.43953406426215, 39.11201223250359, 39.1641209202428, 37.95004537028652, 39.04355118351598, 36.675322132725874, 37.82448245633034, 37.86008188801427, 38.58495943007931, 38.04531974177207, 38.23797087515555, 45.55039851896225, 52.08244708276565, 52.59115103752383, 51.770010686689815, 52.43575849840718, 51.295729452563876, 51.004293426390625, 48.93379580590033, 47.60099795556838, 42.22076123760593, 37.25369522648473, 38.85208852829472, 40.68067004603725, 41.05798636713336, 45.03817227578933, 47.07228206819104, 49.05367128310665, 48.47865966058547, 49.259580027672556, 47.6041829201483, 49.75102555367255, 46.409232847152225, 44.66409975482572, 23.421882390975956, 7.115498675454048, 0.4998719415837719, 0.1971248110696193, 2.9498780590872613, 4.052674496366132, 2.6008077061945394, 3.9859878295852296, 9.298725704992972, 16.51474148996415, 7.10326039022015, 0.31287815301649036, 0.11306464912429934, 0.04477826818343132, 0.9818896831523989, 20.89845495839273, 37.271973471487726, 21.02494747407975, 30.78338476919359, 5.536630442065578, 0.04695029215767019, 0.06520420237774811, 0.05939000871993842, 0.06293274019093764, 0.050842857679292086, 0.10275896623610489, 0.01152030092799255, 0.038159172756657485, 0.10641538898550695, 0.024474107495118535, 0.05702305750380601, 0.038509941434547786, 0.024194274728576985, 0.002113748384046278, 0.057377357847027244, 0.03313144879235375, 0.08698328533360074, 0.01333870254682317, 0.018793469775588285, 0.03620552214523477, 0.07458677996070155, 0.040930331113838384, 0.06045427721654696, 0.02314504645314188, 0.03323899604560387, 0.04514376107122629, 0.005657092007177492, 0.019198739863631707, 0.045961242003907124, 0.07688197938184585, 0.028449349225528782, 0.0226021544151609, 0.03974126689436455, 0.023841454850269422, 0.08384315221900902, 0.06404885368782186, 0.12526960953349067, 0.04281992911391201, 0.040062778674426584, 0.03134029117533036, 0.02978767610094961, 0.00970212434748969, 0.08880043822911479, 0.06384975126674099, 0.027889934586240884, 0.01562754056536623, 0.07513806449189302, 0.05749160836961481, 0.012338510601811353, 0.016137435281228636, 0.10374058533700244, 0.02568713494486386, 0.0348058182205404, 0.03197516930559951, 0.07615842465912143, 8.040941713317748, 45.37149137066257, 35.18784561464864, 48.30658135875579, 46.502640170435754, 8.869051625651698, 0.5114614116328379, 0.0419417433741112, 0.04934071247736293, 0.18692500919343966, 1.000988316391745, 2.553218814634508, 9.296725296205091, 7.07514827289889, 3.8410675285323976, 3.139038773313646, 1.2474457270676091, 6.839257911328347, 27.944645843198224, 51.495460464108376, 59.17029942235639, 58.27877213878017, 59.60768292027136, 59.94627368065619, 59.33805527225618, 61.173073399451475, 56.81606146597094, 56.80633006557342, 58.91758895689442, 57.971623097696614, 55.10729658988215, 58.616092051229174, 59.85285459026214, 59.05096130986368, 55.492881267301506, 49.8674964135693, 45.58709621429444, 43.79667935832855, 44.66727295229512, 50.30060845036661, 52.44087719148206, 56.15050977276218, 57.49575330365089, 57.856630971354825, 56.186113126816295, 50.05988082578106, 42.01259320782077, 41.76837859615203, 40.744683127249445, 46.36565139216762, 44.27307474997736, 50.96150036781065, 58.840122145991174, 58.555934659896366, 57.852222227281146, 56.0586674751774, 57.81135897482596, 54.588771020212484, 49.452066421508796, 49.83210094513432, 58.250452626136045, 55.22076683659708, 55.76440734248008, 51.10020714421427, 45.77573476299163, 45.67792654037476, 41.92455953167331, 41.1072160351661, 40.80356182590608, 40.286981751841886, 39.21260141557263, 40.960029094449936, 39.785514570051625, 38.96671195184031, 39.24210156163862, 39.82797422716695, 39.748306966597035, 40.00937600289622, 44.91292315144693, 54.046256234568936, 54.47288851584158, 53.70862645487632, 53.20995984538909, 53.27813456135412, 52.29500032240345, 50.610648278267156, 48.3062401125508, 43.76571224581811, 39.78532629628336, 39.704909863010535, 42.34921101600894, 44.1614362501329, 48.18898870098976, 48.371453439035726, 50.049239435503566, 51.26466820316931, 49.94385319371378, 49.031843293097715, 49.37436034602504, 47.400643287166474, 45.63765948818576, 28.57522176158044, 8.45966600602673, 1.4836115125686893, 1.8857756809842203, 2.7905283387630218, 3.7841132427415545, 3.273116662617653, 7.356466054916383, 11.855853161504193, 19.009341462965935, 4.528200837873644, 0.1509644130184766, 0.04228179831238043, 0.09120961621163354, 0.6158003499430995, 20.67075156396435, 43.48197190992294, 23.84302531519244, 37.03783150642149, 8.652731930055927, 0.02342941829063479, 0.05054361990562851, 0.05981509175692355, 0.008337761016352283, 0.053486071692238894, 0.03234719309294897, 0.009839900472622004, 0.03973922910048597, 0.132320330388123, 0.026583237565993786, 0.14695579666764508, 0.011182319215168397, 0.02362378054268418, 0.07978533004080096, 0.08712849729964811, 0.07062318659717999, 0.02834145914793255, 0.09137666168352289, 0.045660418428240285, 0.03236797322789508, 0.03445255592645657, 0.04550029456074681, 0.04017465432444888, 0.0498526047674879, 0.20129585338215675, 0.20083071543805062, 0.101068623874697, 0.14716291619885355, 0.19659132276090885, 0.1406001780302294, 0.10104694358643987, 0.19812884590318128, 0.11764754796580923, 0.21521743296855883, 0.18239988104229976, 0.1808494876228994, 0.2182289092771469, 0.17179648872585068, 0.13512868614446732, 0.21850408805954843, 0.14807820740726688, 0.12886185709747577, 0.13025241393235423, 0.17142823026064904, 0.1575320694715746, 0.1262930340524162, 0.19466439712672465, 0.2153081837440691, 0.11086854317616071, 0.17000350590434768, 0.20671650767326358, 0.20923051712734086, 0.14398172077152038, 0.23412943186779178, 0.253552227551418, 8.91876276462309, 50.5411321117032, 46.73421298303912, 49.858478884543146, 51.24006317507837, 13.902223302472024, 1.3319971965205286, 0.3441103319487264, 0.39154281899813687, 1.335868085584333, 4.869877032695278, 10.977735480954571, 16.01607389988438, 7.733423969437999, 7.420916480402793, 3.660124915261423, 1.3648195901224691, 6.957361948105597, 27.35435070530061, 52.426195759927076, 61.55649292853571, 61.0826902235708, 62.47865392315773, 63.35047129661807, 59.41145458529073, 62.92972649297407, 56.57913069571219, 57.521260476881466, 60.31753778457642, 58.67908531619657, 57.85899223819856, 59.18393750344554, 63.69573008629584, 63.0546304487413, 58.45097203408518, 53.19429389892086, 48.00026778251895, 46.20901938407652, 46.40364346965667, 52.23474487181633, 55.4525161558582, 58.34944148217478, 60.02363458756478, 60.80049137915335, 59.19319821942238, 52.791160537350564, 44.24697922122094, 43.39141614975468, 42.02115181953677, 48.529054272559385, 46.124021622442434, 52.53944635391236, 60.81339597702027, 61.9842940761197, 61.38655624082012, 58.751833515782515, 58.46510433381604, 54.25519304890787, 50.5528913774798, 52.22162846596011, 60.090067771173295, 59.37421952524493, 58.78871164014263, 54.45501035259616, 47.70161067285846, 47.73280920520906, 44.837095891275716, 43.53488860591766, 43.27635734311996, 42.82484154547415, 41.54792570298718, 41.78606848562918, 41.67008007726362, 42.37341203997212, 40.15218950087025, 41.76098100600704, 41.105670621318204, 41.566200025620006, 48.152667553194114, 56.014638869993156, 55.65279237685665, 55.6305407708691, 55.7970767636453, 54.72701103456559, 54.286297444374334, 52.12823290978709, 51.45124358515586, 47.34058395508797, 41.4293759868991, 42.81456885799285, 43.37884103098224, 44.36075541280931, 50.27750569005167, 51.11585740120181, 52.149645128557765, 52.823053329221665, 52.639227528725904, 50.143215502462084, 51.17642271903254, 47.83888578414918, 46.65101558931413, 25.386199489716564, 9.026346514301917, 0.9056272237531601, 1.9751960375616628, 5.695720305365901, 10.57879219132085, 8.079036262727554, 13.386964086563358, 15.968584783615606, 26.310009840996038, 13.772370296139872, 0.38549844656259785, 0.5240505957795728, 0.18875582143664363, 1.71166988149766, 28.25066916404232, 46.0455193058137, 28.634096537866903, 44.727524480512066, 9.745553289690326, 0.20461469948772462, 0.17019956312592954, 0.2730846657387672, 0.13086637211663107, 0.1789093852764176, 0.2411287175791879, 0.07674379244206414, 0.1578235965702803, 0.2300213160173547, 0.12062078116521721, 0.23871094409015872, 0.15105432109727016, 0.08673362493995698, 0.1347728076601221, 0.25245210997039275, 0.16854148838789235, 0.14912227799575176, 0.15358567478195315, 0.17199847546796646, 0.1580979632994821, 0.22880109117156078, 0.09266385793565743, 0.11811267058815687, 0.10516752368740498], [0.01234402068920674, 0.019092236405178424, 0.028493989168876604, 0.09337513226895564, 0.03984546251294594, 0.047215749284312616, 0.01581245886852905, 0.023368989275167548, 0.05317745700238213, 0.03698437309433376, 0.06641617645659754, 0.035495320335030556, 0.04347213423780857, 0.039153045433903896, 0.028334529882657434, 0.02585419382329189, 0.01698070847910018, 0.032165591950498285, 0.0503360637043032, 0.05842984008092073, 0.014945382361240206, 0.048088580069522706, 0.02452049794937334, 0.05722143597179844, 0.06514022637519144, 0.08381509807922187, 0.03405124842820149, 0.0029847518101544872, 0.03442825178705877, 0.08140443388613001, 0.026280381942107797, 0.15103460199409915, 19.998257275550596, 38.37373979630009, 25.642795062834217, 43.57050372708229, 29.081219280919722, 9.245759979371103, 0.7990809409849106, 0.009909202701472228, 0.060234758552284016, 1.011286315418059, 1.093423320881782, 7.678452441769262, 6.824632373548324, 2.253942951079338, 1.182127844902777, 1.6583312855612848, 0.6157169995769378, 7.442533152718698, 26.594464048262566, 49.78648770240046, 58.316670079385084, 59.40434332816832, 60.84509657275293, 59.694084890427135, 57.281030993307795, 58.22058377727386, 57.88542901315997, 56.88559724438576, 56.05066976239605, 54.269999996308364, 59.1847651235519, 55.91068429331626, 58.38531155740061, 53.04462409788563, 49.27297492181101, 46.15492597703011, 42.923422475014966, 42.848846450928725, 45.76731735660184, 50.186714587673066, 54.34892985128588, 55.62192332360053, 57.49481193480953, 55.46456175465738, 51.43408713802215, 42.87274545238864, 40.9315840659603, 40.55359309719455, 40.86660608168572, 42.3543022524926, 48.08011154974661, 56.25182067194293, 56.22653707381218, 53.37304415241365, 54.20101334971767, 55.265701509291134, 51.5029521911375, 53.43982250459733, 45.48881338488671, 52.04182701726114, 56.923110792713786, 52.879013784470104, 53.2423900019738, 47.995082409151145, 43.3671288336477, 41.20867206204323, 39.54270808927475, 39.86404826564174, 41.210158640338534, 40.471164488023334, 39.42152646280105, 38.87377139060728, 38.04900284736387, 37.417438491698235, 38.65038456455354, 38.268906608704604, 40.72809934616089, 48.1227594806302, 52.44466227869834, 51.885685305441584, 51.775913853799146, 50.95738187912972, 54.193678517495435, 51.9305964439146, 49.4360553064654, 46.99177149803408, 43.043317564072154, 39.281674354307114, 38.92488379632273, 40.023288649897424, 44.290627356498476, 44.96275294211603, 47.74998134182346, 47.7651216906886, 50.064858313529726, 49.179461694532826, 52.072343057201756, 47.71149504569269, 44.91730051655924, 28.086502282850205, 7.6951176120388896, 1.095792555039929, 0.6729690177786736, 1.7786249854872305, 2.0881453444880824, 1.7483371784610136, 2.458413656680815, 4.365494058978173, 11.449368134621652, 6.635345162883882, 0.7474410990553518, 0.029786473342908487, 0.08737989671287999, 0.5076322896826653, 10.259924088754962, 40.23703821243779, 30.42489190255442, 26.747681633118663, 20.3658127784729, 0.36972772990984304, 0.028551763689686215, 0.0834815357361109, 0.07076963196478545, 0.023205613364435496, 0.07460761755224198, 0.020579858495283033, 0.04918776302328033, 0.005983161052779085, 0.030734281153267914, 0.035357344069428025, 0.023630838127686613, 0.0536472910654641, 0.026965005991740093, 0.03001478861176199, 0.028196791104311426, 0.02503746748721648, 0.013885561005032111, 0.05636837791591402, 0.036578507372929205, 0.0360333553755716, 0.049368421877584154, 0.10082430311388547, 0.08264275372869546, 0.03746524265396499, 0.015252412206703618, 0.10757298614349096, 0.02119179037700017, 0.03252571839238367, 0.03164078724840957, 0.021003505117410136, 0.03565021948288045, 0.03472588077608136, 0.040788662304440816, 0.07635381538420916, 0.04031309790368523, 0.04562486811811405, 0.0400811992585659, 0.05961236573996083, 0.04967075464646182, 0.041796106229265856, 0.031143065669663975, 0.05647916955152347, 0.0445116312813855, 0.03833905020127854, 0.02984307000353452, 0.013841733114884026, 0.02399235118871495, 0.07501588878972877, 0.020270064030022874, 0.04320675371995857, 0.02982472028252819, 0.03302399346965455, 0.042119667294525334, 0.07866478089483515, 0.009486707126451357, 0.1929718024668194, 26.96773248334085, 41.858510740341686, 30.251925183880715, 50.40381777671076, 35.08294182439005, 9.710529465829174, 0.7046953540655875, 0.033006622425971494, 0.06851887330412865, 0.42284949232012997, 0.651784970635368, 5.8118386422434165, 8.978396519537895, 3.4025911602281758, 2.4269589445283337, 2.6512417870183147, 1.8948688382102599, 10.553329144754718, 30.199471327566332, 55.36980513603457, 60.973361999757834, 60.632076571064616, 61.62487945249004, 60.585117955361646, 58.478063844865375, 58.49250601183984, 57.83242602502146, 57.738128323708814, 57.52977594252556, 56.517733835404925, 59.01425184742097, 58.736932431497884, 58.58818438745315, 55.49579951070971, 51.18184343461068, 47.49695316437752, 46.35486487419375, 43.97800660902455, 47.62947828538957, 52.47922620465679, 56.765313840681515, 57.1110237029291, 59.36199349741782, 56.496647173358554, 53.281468576000584, 45.50455777875839, 41.92302196256576, 42.80949723336005, 42.760632345753336, 43.29121135896252, 49.37061840488065, 57.43974577996039, 56.31725365115751, 55.24943544018654, 56.31724580641716, 57.363553739363155, 51.73829047910629, 54.82955748035062, 46.62715581155593, 53.46907161897229, 57.21868099704866, 55.039569024116766, 54.30443448405112, 48.606980000772786, 44.03659112991826, 41.91414956123599, 42.32947364930184, 41.50546604587186, 41.011318006823146, 42.46662324474704, 40.525716812379905, 40.36497416034822, 39.212048361378336, 40.05861743803948, 39.784510443287516, 40.75768578437067, 41.98285379717427, 50.06934550500686, 52.986518106152936, 53.772043335822325, 53.120298385620124, 53.322394586378536, 54.983392838508856, 54.50033333993728, 49.48062127636325, 47.97294847426876, 44.88750619273032, 40.3725992479632, 40.09919043510191, 42.442563426110056, 45.89413935138334, 48.24623961602488, 49.58454839644894, 50.1705151988614, 51.04782781293316, 49.758964430901315, 51.38117044202743, 48.8556190459959, 45.53534838461107, 33.32051892434397, 9.640873074531555, 3.077383281723146, 2.2418480775048657, 3.3181243894561647, 3.576961351979164, 3.2688755998688364, 5.506714524761324, 6.406258642673493, 6.424606019450772, 3.6162889965118903, 1.4673173740025491, 0.04753583231039586, 0.052211420129864454, 0.5942601638455546, 8.587025365521832, 44.07254749728788, 33.97221288373394, 26.874315354131884, 28.28292085278419, 1.0324157558141216, 0.017406461843019052, 0.045978513456160025, 0.0955075150235526, 0.04411657506059255, 0.04986590788429303, 0.03451165960981481, 0.029808205342100515, 0.019218939686975172, 0.055684705730527646, 0.04558463318033084, 0.014485667362028073, 0.09940655015769506, 0.03853922514545341, 0.03297088825474343, 0.052013168066379525, 0.11535480002602262, 0.008323790445443123, 0.06005737472385649, 0.05610893840991682, 0.01274240843486041, 0.025729712196475556, 0.04568382241432706, 0.08947405168005536, 0.02527969874321453, 0.1305925263272178, 0.09221005809283064, 0.23087548873116895, 0.18320104047175378, 0.07582747467583226, 0.10180161680064856, 0.07267558211160284, 0.06782492787967767, 0.09810172622242282, 0.10779715879189392, 0.1752487873478282, 0.11021837967658236, 0.08125438790528045, 0.16033443442035109, 0.11662442988205342, 0.10210301111181898, 0.28827778274013155, 0.21184244793989968, 0.15703435746892808, 0.24777938731976096, 0.11361198830268077, 0.14910858034366561, 0.17740762311845057, 0.10947626264345263, 0.20690148726346033, 0.2844820928669745, 0.10510973767527651, 0.1315455397050227, 0.09060338785451266, 0.2051996689049467, 0.16187882171042506, 0.2575647662724218, 29.553247113381666, 51.66012940868255, 36.07259896493728, 52.614281254429976, 39.10484606219877, 13.444676860686272, 1.6005729138851168, 0.19462722654063858, 0.21873438941134563, 1.8948103703798789, 5.038762034908419, 15.479331862541938, 15.243649386590528, 6.70812915409765, 5.45819039306333, 4.8617562555497695, 1.6441509367958194, 8.904039167588758, 28.486389883102913, 56.068022328038374, 63.67056023690009, 63.73855060146701, 66.58935669929751, 60.98128518750591, 58.486547931548095, 61.080352490948094, 58.52207676056893, 59.1782618338062, 61.20563299425187, 58.44240557762885, 62.63374051740093, 60.84424149605536, 62.40148129001741, 57.308769995166415, 52.38145328337147, 50.02392053604127, 48.36620923011534, 47.11732656724992, 50.5718638820033, 55.37136231699298, 58.94623402626284, 58.92417461641374, 61.018783046353256, 60.29693357406124, 56.04424492005379, 47.771785797611365, 44.015237746700166, 44.64058122327251, 43.828450556724306, 45.9194347166246, 52.169900248127604, 59.847159308771936, 59.118057374031316, 56.411782772310325, 57.55607151216077, 57.1207433362161, 53.58086309125347, 55.75149489987282, 47.75210726645685, 56.390229348213445, 61.10966828561599, 58.3287117558141, 57.16978865285074, 51.57703399658204, 47.68010823957382, 44.80178671498453, 44.38683132971487, 44.3163110363868, 44.26298641389416, 45.05216729256415, 43.19896505724999, 41.81772593528994, 40.79574846452282, 41.655900709090695, 41.850065877360684, 41.12571393289874, 45.15906364687028, 51.65139821267898, 56.10756766411566, 53.91581781448857, 52.79600074214321, 52.9949394349129, 57.5002718740894, 55.73489542930357, 51.74434661865235, 51.0919701668524, 47.44807258729012, 42.59066820144654, 41.66627930056664, 43.78339036818474, 48.611722146311116, 50.36536285954137, 51.47440910339356, 51.790712956459295, 53.64703347606044, 51.28300528372488, 52.53095050011912, 49.91311750104351, 47.84672267975346, 32.068739591106294, 9.025766003516413, 2.29028174954076, 2.3395185268694356, 4.134223268878076, 6.0107503687181785, 6.192260009627189, 7.667222695965921, 11.441633220641844, 22.69122523646201, 13.656353450590565, 1.6613596004824487, 0.18676382429417104, 0.236896388232708, 0.9500319474647123, 14.621383009418366, 50.20340819512644, 40.199536431220274, 36.15754181338895, 32.845741510391235, 1.1593180366100804, 0.14256058170670463, 0.1751726535299132, 0.23171999341537877, 0.1451719456141995, 0.14966200226016585, 0.0948982912626478, 0.16252083403448905, 0.09561706559672471, 0.13991095936827122, 0.10749414803520327, 0.07923724775713298, 0.2776672198407112, 0.13293525384318444, 0.09070730768144132, 0.16209732530818832, 0.17212293411214508, 0.09112500180039676, 0.12995376221595273, 0.12361641477553115, 0.19809863139544764, 0.10069668052657958, 0.27270321523950947, 0.17595777107823282, 0.14584469338578565], [0.017611110740671718, 0.023505772358828017, 0.04520916965820136, 0.025440092656701326, 0.06965047709884183, 0.03474178859182904, 0.02565977028420856, 0.06970181265064786, 0.1120080606591317, 0.0425592179019605, 0.02935125304746532, 0.04767870770827417, 0.042172649935368574, 0.061483723186557336, 0.03286884534322927, 0.022710927409089865, 0.041476180251207084, 0.05072668810645419, 0.01840155260006507, 0.050077095342379425, 0.014131139107649366, 0.04947630237908133, 0.05520514235080731, 0.01883669245627619, 0.0516076470845409, 0.09430060478588266, 0.02850542877680592, 0.04793737346546785, 0.018744913207727577, 0.006243747296637946, 0.03017198602338472, 0.05800657650275577, 2.9274484755531436, 31.8859806752974, 37.809546070714156, 29.56400029120907, 42.91394210630848, 30.330811892786336, 10.641572667706399, 0.62000120839765, 0.043659910048928954, 0.04337570675077938, 0.3965131974508686, 5.88366606543141, 7.246291579738741, 1.9333563600817036, 1.6165601269852732, 1.3142754377857333, 0.41232782626344316, 0.9281200555063064, 6.614709083111056, 25.736267105225597, 43.86704275684972, 57.599119524801935, 56.90675058672505, 58.21650058992448, 58.805338567303075, 59.05704490600094, 56.59365523246027, 57.56170403572821, 52.951860043310354, 57.81297499133695, 55.50207922535559, 56.55239582061768, 56.22085748180267, 56.33212335648076, 50.78060850020378, 48.12281439381261, 42.59110358453567, 43.872365413173554, 43.36653263338151, 51.20518545950613, 55.83588861650037, 60.59812845722322, 57.8780863361974, 59.50456773081134, 54.02374575215002, 45.87363320012247, 41.5368999204328, 40.25101753973192, 40.436773146352465, 42.998018110952074, 42.949953386860514, 55.372295841093994, 55.98970436280774, 55.433288697273504, 53.18038909666, 57.18281876656317, 53.40930254228654, 54.894076547315045, 41.46373987197876, 44.81382054667319, 57.30499667506064, 53.26057411009266, 54.14042842003607, 52.17473653055007, 49.54295166077153, 40.908045922556234, 40.03145894696636, 42.69380692512759, 41.59266817954279, 38.65493451395343, 37.674930326400265, 37.28678041888822, 39.5244376890121, 38.97497246342321, 39.27365310730473, 38.70730600049419, 42.238788450917895, 50.76141242058047, 53.016202603617025, 52.74247607877178, 52.544004148052586, 52.07628896159511, 53.47357449993011, 49.526144304583156, 48.44238165886172, 45.34982812020087, 41.848457705590036, 40.203776513376546, 39.92093047788067, 40.85899276118125, 43.51972864520165, 46.839897324962, 47.69396205102244, 47.71464078657089, 50.116253129897586, 48.588568395183934, 49.545744388334214, 48.60895295296946, 33.13918382890763, 11.450315387018266, 1.448206973652686, 1.2328450718233663, 2.0161379825684334, 2.9229490266692255, 2.386784803482794, 2.425854307028555, 3.162007192450185, 4.799048833308682, 5.632669675734736, 2.552334810456922, 0.07015545161501055, 0.05304785024735236, 0.2380350860016, 6.841638299726672, 31.875717793741536, 38.180606211385424, 20.721550180066018, 33.26801799958752, 6.503167661928362, 0.11663523938266501, 0.07770190030456552, 0.009169300620053566, 0.025380471863994197, 0.02441558220814313, 0.08950190663698221, 0.028940013219271938, 0.023549611740294966, 0.04489944031041476, 0.05044994267424749, 0.1224686005603402, 0.04905162919913569, 0.007681449661181579, 0.07490855987153708, 0.020310226189453277, 0.07379307456675076, 0.0373897715021045, 0.05690003144404581, 0.04950274773422749, 0.020508631470523054, 0.023790561714239662, 0.034347130736756715, 0.04917766598443832, 0.033591549708357746, 0.0056320189070256975, 0.02821223735208473, 0.08068457936807986, 0.024227517198831327, 0.07483339898528592, 0.05570763857254098, 0.039225011733510805, 0.040055347621561065, 0.008026720700605262, 0.050438753960113374, 0.04245648168087487, 0.008477550037505647, 0.07236139413209693, 0.0036491722060036998, 0.05833539293117582, 0.024066845578471982, 0.014301083264722219, 0.009067276860737513, 0.056409892220530784, 0.04332542840030886, 0.0544365608103333, 0.01301933485533922, 0.022171009707474904, 0.14384357979701412, 0.020186571937595165, 0.05579655839791221, 0.044245086309890595, 0.05865818024763177, 0.005584512358426207, 0.07952072327175448, 0.06662260650867416, 0.04661255846581152, 0.04406302551468534, 5.658619586498507, 40.36573510016165, 35.35391484537433, 33.36542614044682, 48.24234862481394, 36.27518153959705, 10.19272800414793, 0.5101054972938953, 0.07861637945977912, 0.04228251077415001, 0.16721566598261559, 0.775904881377374, 6.210065609024418, 6.303622472670771, 4.812612879660822, 4.4047001100355585, 1.3768502348853697, 1.345620691295593, 8.767598540552202, 30.843132272843395, 48.316901114679155, 57.86314995058122, 57.81626193754135, 59.52038272734612, 59.22666388173258, 60.14359635691489, 57.69553922837781, 59.047223291089466, 55.771934370840754, 58.78216912669521, 58.10786662563201, 59.20674608599756, 59.99373435974122, 58.24745201295423, 54.354703580179525, 50.0084860094132, 44.13615657437233, 45.192286122229795, 45.524569711377545, 53.750348706399244, 57.23395470649966, 62.15071239779073, 59.95622081141318, 59.322189284909165, 56.95625874304003, 46.986762631324034, 42.94492098592943, 41.8536626908087, 42.154979167446015, 44.920893407637074, 45.3721111051498, 57.887668686528365, 56.36001533077609, 56.83055854612782, 55.81447639772969, 56.82047021004462, 53.31708369716522, 54.52396954259565, 45.142185688018806, 46.598483285596295, 58.882742620283565, 53.88185008879631, 55.878332584135, 53.02889539349464, 51.167099245132945, 43.913099227413056, 41.405857455345895, 42.9740838081606, 43.76596719987931, 40.254775170357, 39.55026257422663, 40.413364441164084, 41.9260068862669, 40.660838542446015, 40.89328996596798, 41.38606517545639, 44.47897564980292, 51.986713793969926, 55.449174296471384, 53.637121646635, 52.69838863803495, 53.589268730532744, 55.99937692765267, 52.5554221676242, 48.14706248621787, 48.29200583119547, 43.97109931515109, 41.07156953504009, 42.04858879889212, 43.77312160307362, 44.801135601535925, 50.21777583706764, 48.73031108610092, 49.12194013595582, 51.973091402361476, 48.558456359371064, 50.1925196955281, 49.8730936358052, 36.6390755099635, 13.533087084370276, 2.4660073653344186, 1.8477996606980602, 3.1862751418544404, 4.186229974992814, 3.7670928528231964, 3.8914724367280162, 6.759869629336942, 6.236526408503133, 3.9236596515101776, 0.3919415217974494, 0.04806443680858901, 0.05995273860471864, 0.2391542178849059, 5.950089443114496, 33.54501185878631, 44.50927988175423, 24.768412459281183, 37.898936886941236, 10.934447223140348, 0.13055327198197766, 0.05741134916822757, 0.04069293578786235, 0.024542965392972675, 0.027106117472172748, 0.08790295856494097, 0.06149242594537716, 0.02588465156394147, 0.06906337795719024, 0.03595452875860276, 0.048368788219147155, 0.022640788229182366, 0.03147525288495085, 0.03577688829072061, 0.05335294859363668, 0.06260609945222255, 0.06486251950263977, 0.023496131142300945, 0.08572072646911107, 0.0064095957561456154, 0.03494874724457341, 0.04309636428050938, 0.01400591629076629, 0.053385062999422514, 0.02941348236955462, 0.11680665921660201, 0.17974098903998253, 0.09792954030056154, 0.09851251022830125, 0.2669636232237662, 0.24037805866570244, 0.12590854218409908, 0.20632302959359464, 0.278705514126247, 0.19508021433026562, 0.07630733682984307, 0.23633581105499502, 0.0943657758856012, 0.14476368203759193, 0.12145053865688464, 0.10975797615584829, 0.15947085414682666, 0.09475810483338372, 0.0676099865907623, 0.14450483624973606, 0.10336191573690984, 0.09642661368894963, 0.2381118633333714, 0.14051970815466297, 0.17430410900663945, 0.2403951271046554, 0.2179311002574621, 0.127114157733177, 0.21947199418660135, 0.24860789608811182, 0.0731855208775209, 0.26340489966734765, 5.9292768566839165, 47.611831541984316, 48.53155674472932, 40.28412234398627, 52.606707157627234, 40.28647576608966, 15.486128349458019, 1.0838065272377384, 0.19863682348401318, 0.17216807201264367, 1.794497224111711, 12.431870871974576, 13.640392345766868, 5.665936768054963, 2.9653559769353564, 3.1509389992683166, 1.8118599634016714, 2.1365873515605927, 7.937302887439729, 30.332041555835357, 47.05860084103, 58.32233005954374, 58.52192771050238, 60.37303540014452, 59.02142194009597, 62.63014370395292, 57.95695735562233, 61.6151519744627, 55.03657625567529, 63.32778430754139, 59.99314600421537, 59.415592685822524, 61.87156515736734, 61.11498701956965, 56.29608461933752, 53.13075934686969, 45.11155982171336, 48.12761537490353, 47.14131970559397, 56.423373376169515, 58.33408148058, 64.73006694547593, 61.58834649670509, 61.92555658278927, 60.121905649861986, 50.332638525193744, 45.24997634272422, 43.025898318136896, 45.35565676227693, 46.95423833785519, 47.25613532527801, 60.20913131775395, 58.641532544166814, 60.20283199125721, 57.42396216238699, 60.481873327685946, 55.389283626310295, 56.63690328598023, 45.25303186908845, 47.86694249799175, 62.102169144538145, 56.306290626525886, 56.39437921585576, 54.70004473963092, 52.77592212923112, 45.66349614051081, 43.698875058081846, 46.09341144561768, 44.5115940801559, 42.45396575620098, 41.65116640829271, 41.62905600763137, 45.255502962297015, 42.90261430125083, 43.4957355068576, 43.25733384778423, 48.132486958657545, 55.821207184945386, 57.392649881301395, 53.95595935083205, 52.20426805557744, 54.3400574499561, 57.39363831858481, 53.412161950142156, 50.83476466517295, 50.69897613217754, 45.365431308746345, 44.4679420225082, 44.51723052609352, 45.77911192371, 46.61437280716435, 52.16969236250847, 50.45977823195919, 51.664969613475186, 53.68866159069923, 49.87581968307496, 52.261267938921534, 50.64710278664866, 35.355201382790845, 12.781501143209397, 2.1527394267820545, 2.526983306292565, 4.748564987413345, 6.941461640019571, 5.177848790922473, 5.674987637227582, 10.770055786255869, 13.036631711067693, 13.346759792297119, 6.006215128206438, 0.13281747548570558, 0.3733705699203476, 0.5400105361496249, 10.348748122492145, 41.089710497087054, 47.67724098697786, 30.888241491010113, 45.66759893971105, 11.287403664281292, 0.22842601452383304, 0.23948098502812848, 0.12782550867526762, 0.11573855644993244, 0.09462314312376323, 0.22913744973559536, 0.17067982364566098, 0.15415636432026664, 0.27094158073586805, 0.1802059890882623, 0.2479208531158586, 0.10424138467398383, 0.15091336091920254, 0.24252592405724913, 0.11571643183067923, 0.1401435436620828, 0.22064636100924787, 0.13126294519151413, 0.07802859849987492, 0.0791747732869079, 0.11978543123170254, 0.11920014005755225, 0.16505391907788095, 0.146015714854002, 0.08389081820965776], [0.05699612568282793, 0.013354501195041644, 0.067243788902077, 0.06532394192031314, 0.05134918051020754, 0.04844191897239897, 0.048889015545888294, 0.05068037809143144, 0.08778113526322188, 0.039283268889712716, 0.03270255446794533, 0.01672490980596312, 0.09411241528728316, 0.02684872150571356, 0.037949502152661165, 0.013606394734984685, 0.06230749753153613, 0.02811876313400365, 0.046485246144114964, 0.0629702440252708, 0.012972186931649284, 0.08018070035764287, 0.0205763804561068, 0.029114755959580504, 0.050025587420790434, 0.019387398591084827, 0.06292263549121638, 0.03981303784155077, 0.05257602818610688, 0.032583872126715804, 0.02425325775308715, 0.04261678174859093, 0.034826774555709095, 8.80251253804853, 39.131145554204146, 31.27867617914754, 34.38461480602142, 40.99796625875658, 35.916841645394605, 13.875793391658416, 0.9895364050903629, 0.08538836688404122, 0.049537087625433365, 0.8005246183564587, 2.95629971450375, 4.5112885582831606, 11.932997357460762, 7.845845962724379, 1.1002050989097165, 0.6556469730792508, 0.19395303852375478, 2.884747837820361, 14.908700546910687, 33.51351130393244, 51.66642873517929, 55.07739243968841, 59.979115686109, 60.989620224122085, 58.18834581682759, 57.91019878079815, 56.81364528594479, 55.89893287228, 59.34142066586403, 57.63979058111868, 57.46518235052786, 53.83918646843203, 52.49855564486597, 45.89549649146296, 43.828023018375525, 45.12909673875378, 46.408934747019124, 53.9585167361844, 56.74021067157869, 55.16850909879131, 56.190878806575654, 58.98301801373882, 56.44747241850823, 46.99805513505013, 42.53688466164374, 42.18841737316501, 41.52476410711966, 42.21731347422446, 42.20721729340092, 46.29890049657514, 53.09085315273654, 56.17822524039976, 55.37863046892228, 57.8359914595081, 57.69673555128036, 56.38847212637625, 53.6975065354378, 48.74567108769571, 56.844647699786776, 57.402514642284764, 54.60044791621547, 53.602855820809644, 53.71015225687335, 48.87869042734946, 43.07481811892602, 41.43223147238455, 39.981833119546216, 38.49936546817903, 38.61456548013995, 39.14998862051195, 38.77297432191911, 40.10524657464797, 40.41494123397335, 41.65447688871815, 43.498453709387014, 51.28906926801128, 52.89830792334772, 53.501427250523726, 54.054865837097175, 54.84751409099948, 54.122244311917214, 50.38313904116231, 47.26925565350441, 43.24250728853288, 41.516146659851074, 38.39494805182181, 38.06742229769307, 42.03933592765562, 46.022330253354966, 48.30442797753119, 48.034341412205855, 48.04119379289689, 50.27745077686925, 50.7755054966096, 50.88144479259368, 39.78157651039862, 15.302684980054057, 2.4326799665727923, 0.1338692835622257, 2.473605976950738, 3.941301491952712, 3.4357062607042255, 2.0752878150632306, 2.5168741326178274, 5.981350243091584, 4.677682365140607, 2.0709555572079075, 0.17357396592776622, 0.0631071592590982, 0.2206703855265533, 6.022487080866291, 26.53903703535757, 41.65433568339194, 28.14186065427719, 30.0522667361844, 15.955102616740813, 0.20182258479537504, 0.02099615067333704, 0.02604383122806828, 0.02945859345697588, 0.05810665822918377, 0.06090797746794359, 0.024645485194219698, 0.009272766539887076, 0.04533899091784993, 0.04636278698941873, 0.07547027852025724, 0.04691746912055439, 0.09621307434093568, 0.0546966974563416, 0.041999368507775574, 0.08364504954266934, 0.027910504047007813, 0.021982839361073512, 0.02089571463124406, 0.043820271403678966, 0.06668583174506504, 0.07569550836999571, 0.01754245777133732, 0.018320713087075183, 0.045859482544924945, 0.05100465544890012, 0.0386170405263622, 0.0797643239099172, 0.0192059870553954, 0.05053466816823329, 0.052191199239103064, 0.07037761711305188, 0.030700659469491055, 0.06813960615545511, 0.05901188304227206, 0.033768929706345645, 0.12898740358650684, 0.032398501831677654, 0.05438485753632361, 0.10577435725398603, 0.024614631003069303, 0.0127469704884495, 0.04379128646706382, 0.06239557849063028, 0.03039304069393585, 0.017292297505322966, 0.05058532190178672, 0.07571511255997805, 0.022809775733959772, 0.04356078976284593, 0.0343051414576269, 0.05817723790964773, 0.07368366188940502, 0.009624205544711122, 0.017078242963179946, 0.04273664003478424, 0.020373945552555305, 0.04860642869325896, 0.06747782876294467, 14.435223398670075, 45.98846450928719, 29.623396742728453, 37.75522516619775, 48.24669461096487, 43.37581688357938, 10.895253919786024, 0.8821224817825902, 0.09126120457245458, 0.07133095990866423, 0.28321302225512845, 6.080708292222792, 8.349091449091512, 10.768178932128414, 7.529606338470214, 3.1483392032884785, 1.3318600361385655, 0.6043727695941925, 5.236870656090399, 20.157007363534746, 39.190710667640936, 53.46030119926699, 58.09895107823034, 60.75684716624599, 61.38805458622595, 60.821574118829545, 60.17559897515082, 57.43002222430322, 56.653035994498964, 58.058872299809615, 60.64984490794521, 58.36851989069293, 55.36996987558181, 54.11657648701822, 48.57831139718333, 44.38072419935658, 46.26330890963155, 47.32443163471837, 55.78264244141118, 60.494672021558216, 56.95392885515767, 57.053062838892785, 61.20365611968502, 56.9263820494375, 48.75263329475157, 43.983576374669234, 43.22046749053463, 42.399221235705966, 43.99097788718439, 44.04245507332587, 50.2353362883291, 55.686748335438395, 59.48896454226587, 55.50120845917733, 59.14876953248055, 60.09354691351614, 55.23546003526258, 56.01557631646433, 50.016079718066806, 56.92626045596216, 59.94908994243991, 56.04546085480721, 56.255488088054044, 53.7832966158467, 50.838549752389234, 44.60215376269433, 44.218816603383715, 40.6949160945031, 40.09951206945604, 40.08230463151009, 40.47908767577141, 41.44859952311362, 40.91529446263468, 41.59608848633305, 42.59866591422789, 43.881120143398164, 52.09455151711741, 54.90532982733942, 53.942462475069114, 53.44741229088076, 54.85503719698999, 54.581691142051454, 52.62359688358923, 50.27843136941233, 43.71267003397788, 43.15768211118637, 40.32369905902494, 40.3919953684653, 43.76896781306113, 47.660143375396736, 49.642866196170935, 50.626396594509, 51.79286241531373, 51.69216340587985, 50.05133790354575, 51.18782897149363, 42.963324746777936, 18.833744795091693, 3.2512526358327563, 0.9788268023440916, 4.38312364201392, 3.6354174152497327, 3.4997431212855927, 2.402017573195119, 4.182389484297845, 7.460480447738402, 4.569579882006492, 0.639734591447538, 0.05178018923728697, 0.10193799577292897, 0.17540491606679656, 4.977386747637103, 28.329085188527262, 51.32697897572672, 33.2402083950658, 30.83611515260512, 24.320120849917014, 0.772304084272154, 0.06655770353972912, 0.05857242819582743, 0.03419416979135525, 0.03565052591805016, 0.0628429623470912, 0.021362859725711808, 0.07647696401803725, 0.009205925368493604, 0.03423704007159799, 0.04876824178462548, 0.06974154197040104, 0.04928404112316428, 0.05779210252747421, 0.1070450213287146, 0.02518057271147207, 0.04550139006647853, 0.05283118143016773, 0.06048630352222151, 0.040095019484719926, 0.07046492049290289, 0.06093694325236063, 0.023282090006696603, 0.04010951003780769, 0.015892895227748782, 0.06338718737806044, 0.083550920319413, 0.18441752680847723, 0.15049562849585088, 0.2157652317996948, 0.12019685875143736, 0.24409263514943663, 0.16094316788498433, 0.0922926806754643, 0.1793067091174664, 0.11744101066142322, 0.28101183714405187, 0.14526802836166275, 0.18395165341996378, 0.16088417911481473, 0.0726351096865631, 0.0875366612848255, 0.1718635367409837, 0.11665882722985361, 0.11761101323270029, 0.13792594894766808, 0.19803786530129372, 0.20754832594144731, 0.12916130554531852, 0.1313231290588456, 0.1036724801205339, 0.126129275097722, 0.16222520070450921, 0.20533931141178455, 0.11176301977567135, 0.12144368983084157, 0.1145189214918402, 0.14562186905212943, 0.1502459297978109, 15.136798139541382, 52.5322291927953, 42.355455429323264, 45.702723764604144, 50.55607241968955, 46.29028304930657, 17.033227835932088, 1.6235738151496457, 0.31877889928798525, 0.16576936859036648, 2.25174936556047, 8.324926707052416, 14.540431172617021, 20.7070158373925, 20.131670813406668, 3.9042081275293907, 1.4391198225559727, 0.740153948145528, 3.783337594039979, 17.692346842058246, 36.41398637525497, 53.065314600544596, 56.07341166465513, 62.57028049038303, 63.11575666550667, 61.98458825388263, 60.76699433788177, 60.58582398199267, 59.60802808884652, 62.12644077116444, 61.62584043318226, 62.989868194826194, 57.533172715094786, 56.64097862858927, 50.058029467059725, 47.221716527015936, 49.61358962520477, 51.235183746584006, 57.72968346072782, 61.50272115584343, 57.46949695771741, 58.859996795654304, 64.44873494486656, 59.32872787598641, 50.96694069523966, 45.660040532389, 46.77138920753233, 45.26947836722098, 45.59806316129623, 45.78918457031251, 50.42426901478922, 58.143466057315955, 61.27677302206717, 60.162055030945815, 62.56979019411149, 62.57566198225945, 57.536471428409705, 55.467805554789884, 48.56773668719877, 57.92611968132758, 62.44533731091408, 58.69049549102784, 59.24243965456563, 56.79629664267264, 53.44802810299782, 47.31885402433334, 44.74821106080086, 44.03026434683031, 41.248825365497225, 42.46065731971495, 43.154442233424035, 43.56517714838828, 42.99551956115231, 44.02150569423553, 45.25048625084662, 46.97788630762408, 54.38874190853488, 57.81763476710166, 55.95278309237573, 53.43848889873874, 55.62463760375977, 57.681238266729544, 54.33724903291272, 53.06251402824156, 46.64322183978173, 44.131583090751406, 42.37858564622941, 41.28537008839269, 45.9012427637654, 49.60557622294272, 51.80362932143673, 53.16233050438666, 52.93005166515228, 53.65712965688398, 52.27471382387223, 51.29529406947475, 43.58727578193911, 17.88696308289805, 3.2710270199083515, 0.7911497859224197, 6.128345968261843, 9.8253745032895, 7.17902587306115, 6.516920962641317, 7.374172124170489, 11.320348631951118, 12.467554634617223, 5.423019970616987, 0.39805248259536685, 0.18350323151436546, 0.6319496672480338, 8.999758728088873, 34.92973796782955, 51.187550483211396, 37.74464653384301, 41.49139258169359, 27.446618580049087, 0.7729193448059021, 0.2417208116141058, 0.19706568440362332, 0.1540811344861023, 0.11689311223885707, 0.10029390213950988, 0.20833247821898232, 0.11923079889628196, 0.14005654671740148, 0.10182328176714721, 0.1562728507504348, 0.10229926751626116, 0.18609846161017496, 0.14398657776896032, 0.2023732947606233, 0.130918113695037, 0.2017796225845814, 0.19329997921182265, 0.1321002486492357, 0.3122763143431756, 0.36654690220471353, 0.22892717392213885, 0.16659240749093795, 0.08568872697651388, 0.12881868038206332, 0.1818048758732696], [0.027569740477408615, 0.018750540123531417, 0.07625420863229422, 0.011518228660157372, 0.014160720635235552, 0.05943824927653036, 0.025910355729020895, 0.08057027138889798, 0.04582682038627325, 0.03398470220065886, 0.04072113165391549, 0.0288587887471001, 0.046914607782157204, 0.00917860092745433, 0.05199154140427709, 0.0526329638406394, 0.03331281627798754, 0.10470459207652077, 0.05686744206374692, 0.025480465490310907, 0.02390929002074465, 0.09291832936146567, 0.10465162475743603, 0.04879718841684442, 0.032351149937077876, 0.05451270995000678, 0.0393309616934388, 0.030568053480237726, 0.027060715271340265, 0.053080336205781474, 0.04788339874076267, 0.057108380546372746, 0.06978729274123907, 0.273734400229108, 15.908546043980508, 41.32973601741176, 28.515878262058383, 28.327896710365053, 41.28513866855253, 36.64746938213226, 16.702399446118264, 1.5076824854458533, 0.15167995446151303, 0.051633330182202404, 7.5236963072130765, 9.721590549715105, 8.094224170331033, 5.927399512260191, 4.0004638270024335, 1.0507585973508897, 0.22355910390615466, 0.17469213254028754, 0.7234770720524173, 9.0849918319333, 26.360981041385283, 46.17446330285842, 59.63540623264929, 60.49108697522072, 59.811575566568685, 56.206689880740264, 55.11418427190473, 56.726160741621456, 58.87548231309461, 59.621705393637384, 57.92314260236679, 52.25856934824298, 52.57335524405203, 44.560655086271225, 43.33387890169698, 46.614294359760905, 50.23241412255072, 55.96291065216065, 57.73406867058047, 58.27980764450566, 58.35163408710111, 58.6995679332364, 57.47769471137755, 47.14545780612577, 41.55063213840608, 42.674669681056855, 41.59266425717262, 40.86419382402974, 41.67985462373303, 40.547148643001435, 45.38372132085985, 48.682022786909535, 52.53903842741444, 57.58026861375379, 56.3841575191867, 54.906463392319225, 49.136747083356305, 57.804534050726126, 54.510927661772705, 55.57257206209245, 55.28248925362864, 52.939720307627034, 52.68285997452275, 48.97412561601209, 42.3816764739252, 40.34701754969936, 40.27703069871472, 41.11798294128911, 37.26522699479134, 39.69752011760589, 40.582336225817286, 41.38703007851878, 40.87498426437378, 43.62993155756305, 43.93642948519799, 50.88983474239227, 53.885784226079146, 53.69576108071112, 53.79789567762806, 55.85046022169052, 52.31363158072195, 50.61730846281975, 46.86879734839163, 42.31573750895839, 39.72418831240746, 39.784565356469926, 41.88466118228051, 43.8792021043839, 48.374807065533055, 48.324420298299486, 49.6115303808643, 50.83734950711651, 49.74935070160897, 48.65623320302656, 45.484506622437515, 24.44545234403303, 5.616331042781954, 0.6951164358085202, 0.8769905507083863, 2.2716691224805774, 1.9737506441531645, 2.7359250235942105, 2.990223313531568, 3.9429645769057737, 7.72154163929724, 3.2894844681985917, 0.33870380431894337, 0.1430167257785797, 0.11504507833911527, 5.123607804698329, 27.037917414019187, 39.036459538244436, 24.45996315248551, 24.229757285887196, 30.8026808692563, 3.221284011679311, 0.05428145098830423, 0.05753347890511636, 0.030868564875075416, 0.011944367940868101, 0.027358710067346696, 0.03682764682678446, 0.06894107202007886, 0.022547752596437935, 0.03886184775300565, 0.06287467072627718, 0.06588588273453136, 0.05724627254230361, 0.07845137178176835, 0.05486687239740164, 0.028642472330360647, 0.10816250612298328, 0.02939061847545447, 0.020347479129991224, 0.04533805629058231, 0.06496078560068723, 0.021352741619451873, 0.023171813565216238, 0.02547425060202518, 0.03861056325296241, 0.05122155792290165, 0.005226045933311745, 0.022379061950731183, 0.04374388860718858, 0.07844012561103991, 0.05495519850463156, 0.03992858688316999, 0.040628323932328535, 0.014319372656304511, 0.007902217527566058, 0.032910861435436436, 0.01310164238431401, 0.041284485900354, 0.048787558691636215, 0.0720223619212066, 0.010484141154935765, 0.050353955687774773, 0.020349490110792463, 0.04617600326216029, 0.04228298957910269, 0.029910405301639152, 0.009309455448190772, 0.0148442616280649, 0.06943987952845712, 0.057620020027482705, 0.06163802861626591, 0.03405736180983725, 0.11160305295620235, 0.06235435912986437, 0.06192105213901209, 0.022837908397759163, 0.020646073389798403, 0.0265000538239556, 0.067767609181183, 0.021100555050877795, 0.9873455774880225, 25.506826100810883, 44.41213453969648, 31.61880646982501, 31.19286648688778, 48.272684235726636, 42.91163575264716, 14.031611507938756, 0.9897057411651459, 0.05708917472211104, 0.07814801628551177, 1.1666495593324786, 1.4713492028174864, 3.8332752498888203, 6.088294646432323, 7.956877966080943, 2.887786939259499, 0.9537624892207884, 0.42847564203604577, 1.643820109386598, 12.17093127389108, 30.358627380863314, 49.893140869755904, 60.710845608865064, 62.11179464094101, 60.488564891199914, 57.77718336351457, 56.22374434624949, 56.99322315954394, 60.39716582144461, 60.1152729219006, 58.87685514265492, 54.327623536509854, 53.95254688878214, 45.41878731020036, 45.66872073758034, 48.358493927986395, 53.248630492917954, 58.267993465546645, 60.84363745104883, 57.58131588658979, 59.509027465697265, 59.52799212548041, 58.06006862271217, 49.72777374329106, 42.530510810113725, 45.38398804203157, 43.31592621341829, 44.41289940188008, 42.91471481323243, 44.46076800746303, 48.447778840218824, 52.39613079255628, 54.747062190886474, 58.6835725076737, 58.22765581069454, 57.55931531229327, 52.37247105567686, 58.906100334659705, 56.120166317109145, 58.49743250877627, 55.27247936494889, 55.86487493207378, 55.05900044595042, 51.34961497399115, 45.60224833027009, 40.97834264078448, 42.31471377034342, 42.21197120604977, 39.87689402795608, 42.3948948614059, 42.5783754933265, 42.52470962462887, 42.31044230922576, 45.28344592740459, 45.27758982873733, 51.1005562351596, 54.17139553254651, 54.809459255587676, 53.39475839368759, 58.417557362587225, 54.255597053035615, 52.13127666904081, 48.74437278316867, 43.9816975593567, 43.17691741451141, 40.40825751519973, 42.64539311009069, 46.8557240886073, 49.44308027144402, 51.38779924761865, 51.92422259238459, 50.666549897963, 50.472192533554576, 49.42325661259313, 48.04743428384104, 27.635494432141705, 7.269584084710768, 1.3132776848731504, 1.9058790538580188, 3.284909268540721, 3.948229623417701, 4.570089790128893, 3.4811589314091593, 5.010620009514594, 6.750535859215645, 0.47103007954935877, 0.268023276040631, 0.10288747748540295, 0.1241069868387234, 4.631480276584625, 27.32513296988703, 43.01517455808578, 31.682156670478086, 26.821369240360877, 36.03104537533176, 5.914662595718138, 0.17595452286543387, 0.04338727467843602, 0.07574014065246429, 0.10862258022590991, 0.03349367431515167, 0.00881954413583322, 0.16759636571570752, 0.06042017481259762, 0.0019369494158684487, 0.03287793114601124, 0.09683837828737113, 0.1398100349451265, 0.033099901291631886, 0.11229424046412592, 0.04978666757984508, 0.03552646180915256, 0.02136086406666906, 0.04913380745077326, 0.03433784575111443, 0.01994368184598223, 0.02790650506804307, 0.005216046570680075, 0.09580992823166233, 0.06231438083153579, 0.03645871420420947, 0.032986294282900716, 0.1732363816230528, 0.12785688763664615, 0.20917876022717646, 0.19476374340874536, 0.09352716241752909, 0.09558387866784489, 0.09955877948912883, 0.14965153749912016, 0.16879466512510855, 0.09756828387898785, 0.15478840217955653, 0.14329352866738074, 0.13208124966871354, 0.12120926692601174, 0.1438377422070311, 0.175159584069925, 0.15349297814311522, 0.18204213330341926, 0.14961514832271686, 0.08577635211329307, 0.12298607763143317, 0.1011903782285029, 0.17653131046362464, 0.13018332812334263, 0.09128251713850806, 0.14824688464643496, 0.1222668819489979, 0.2358989723988118, 0.1830918882643023, 0.13260499333902714, 0.17692416035119565, 0.18229599951976733, 0.13284038151464156, 0.9006452620510133, 26.24618503355211, 54.63329776640862, 39.82285553409208, 36.418238224521765, 49.8613618266198, 47.07597694089336, 21.212187697810513, 2.209499800397504, 0.314610798753077, 0.21737082951491882, 12.760486064418672, 19.541407054470433, 16.661585223290228, 15.462524506353564, 10.446164108091786, 3.120781611050329, 0.43068963613721634, 0.8619654214670582, 1.5439012838948158, 10.970606573166387, 27.65798334152468, 48.69542160341817, 63.48101954306326, 64.02500129515126, 62.66714734415855, 60.036099879972404, 58.02839156120055, 59.87156037361392, 64.80240329619377, 63.00271395714053, 62.85245972294962, 58.367425549414854, 57.117044541143606, 47.744972475113414, 46.51374832276375, 52.26195043133151, 55.82432546923238, 62.564698957627826, 62.44853012023434, 60.23910214824062, 59.01697004995039, 61.8761896318005, 60.23388931828161, 51.79803602157101, 44.563306608507716, 47.45688223069715, 46.54284446470199, 46.15426309647099, 45.46655001178865, 45.96353392447195, 48.46961859733828, 53.71201930507537, 57.110431425033084, 62.43057350958548, 61.25610213125906, 59.1724802601722, 52.80082133508498, 58.91999729218022, 57.686655059937515, 59.576276502301624, 57.989324754284276, 58.229738589256044, 58.25217454664169, 53.045922402412664, 48.28138013039866, 43.51406082030266, 44.053637750687145, 45.29610733832083, 42.689766883850105, 45.04597779243223, 45.407989025115974, 45.57987905317738, 45.23969973287275, 48.62597211714714, 46.71232223510743, 54.33254611107611, 57.03255276526175, 57.020954316662205, 54.70132343230709, 58.05167475054341, 56.17632289086619, 53.74900333343014, 51.08813408882388, 47.08089951545962, 44.75247467717817, 41.858781383883574, 45.78472091305641, 48.860835798325084, 52.55780696868897, 53.721891910799094, 53.60022391042402, 53.91253479065434, 51.97182055442564, 49.44211536838163, 48.69875169569447, 26.97128026716171, 6.986273738645739, 1.6455537970027618, 3.0510553525340174, 4.881437238185637, 5.627602954064646, 8.211748676915324, 7.987938234882971, 10.939978745675857, 15.387552322879916, 8.434670702103647, 0.8632536749205283, 0.23669109199075933, 0.4336575526864298, 7.392217968740772, 35.80492857963809, 48.616413301037205, 33.524450794343025, 33.95031821343207, 43.06033672824983, 6.627014538934154, 0.21664447091039152, 0.1359695136066406, 0.1684915088117123, 0.20466567497820626, 0.1430371956479165, 0.09305059444159271, 0.2926082939149872, 0.1447236003173936, 0.04963488640984701, 0.20431289148907508, 0.18547223069735114, 0.2186271064584294, 0.11527151094689486, 0.1963897037409967, 0.11434105119758076, 0.18108406374531408, 0.15668782525725905, 0.13667397741829196, 0.1179303186795404, 0.14304989738570106, 0.1505271300312973, 0.0678894707872983, 0.12952112172159458, 0.11927327081080406, 0.12523164221596333, 0.08841508834232246], [0.07050385308121482, 0.03880851654215686, 0.07663031183784047, 0.028715681607624697, 0.03136831658682035, 0.0281434886217598, 0.040191037114709616, 0.06829548972628771, 0.018109016180519136, 0.05134091442150455, 0.007827599606131235, 0.042203389213330327, 0.04503623680061391, 0.020735937418536316, 0.021827492051787918, 0.052140775331926924, 0.030377263113135294, 0.01684094339819445, 0.009159651742647252, 0.022271361479896213, 0.021444924979380543, 0.06321549558291031, 0.01462492012163444, 0.03261752636922944, 0.004105059159619193, 0.054950375981148214, 0.046999363919659976, 0.025136775464840957, 0.12331671351867339, 0.009994163767494743, 0.047083940026500536, 0.021862586539599205, 0.0648006349201164, 0.04182567722314308, 1.16087521756849, 23.97519938407406, 40.17123260805684, 32.948835126815304, 30.850098402269428, 39.38697038158294, 41.47052557237687, 17.998328978015532, 2.1441163411063533, 0.11504898538752911, 0.9629518670901176, 0.3989646788085661, 2.376884250871597, 3.9616973265524837, 4.411901091375659, 2.959330971202543, 0.9696190383645796, 0.4040595925142689, 0.08719082621316757, 1.262201683655862, 10.498391447528716, 27.77613493704027, 50.47821729413925, 59.52710566982147, 58.068168317118, 55.69538147218766, 56.66176326813237, 57.5448731453188, 55.90526357773812, 59.689734981906035, 54.99557572026407, 53.31203560675345, 48.03848343510782, 44.42120698190505, 47.29834787307247, 54.57406605443647, 58.39650992424258, 57.11301234460647, 58.83666261549919, 55.91021753126576, 55.77893187922817, 57.003589983909364, 55.09720040905861, 51.74930057217998, 44.08185135933661, 43.031162138908144, 43.769905259532315, 44.412573845155784, 40.54499918414701, 43.54627916889806, 42.28909284837785, 46.373221566600186, 51.742220694018954, 54.36881626805952, 55.170693858977295, 59.66929943330827, 47.08525334635089, 59.63317440402124, 55.576094350507184, 54.741057042152654, 52.814530018837225, 52.027133818595644, 52.13272010126422, 47.742493537164506, 41.29556825084072, 41.031718254089355, 41.40371584123181, 40.42626119429066, 37.89405745844687, 39.82046681065714, 39.78710705234159, 42.23209296503375, 44.526048014240885, 46.29688832067674, 47.78325873036539, 51.067961339027654, 53.4791011195029, 54.45684602183681, 54.214376864894746, 55.06626859787972, 54.42495322996571, 51.69472079123221, 48.79481446358466, 42.59488082701161, 40.788578371847834, 42.286547230136016, 45.423607903142134, 46.26732149431783, 48.44965765553136, 49.34244009756273, 50.1529469028596, 52.47072250612321, 50.8801817893982, 47.55315288420647, 27.999549219685218, 9.347358192166975, 1.6142377161210584, 0.11308334166965178, 1.7426548898220064, 4.004915471999876, 2.613446318334149, 2.954182124906971, 2.070645199668023, 2.8455763526501197, 4.762644335146874, 0.4696626738915521, 0.06043189978827873, 0.37304758725147097, 4.707373236456226, 24.52798881838399, 32.51973763588936, 48.52031523181547, 29.83447320999638, 29.057600728927124, 13.354548638866795, 0.10865271812485111, 0.032184782453001506, 0.007088554585577861, 0.02877342165447772, 0.050630053775685455, 0.06250248989090323, 0.03260760553061001, 0.0542359491960416, 0.06196481491168661, 0.08443081060484534, 0.02901822313546173, 0.039572815651134144, 0.07509671106574035, 0.052086287328312476, 0.03456163152511563, 0.03346819806122973, 0.06014157544761416, 0.001978368318598387, 0.02624307920585477, 0.1344058975096672, 0.055934795133409, 0.018385351755686345, 0.0524985000881697, 0.06118909343175831, 0.03192108924380474, 0.01350283305416064, 0.015745341905482834, 0.051280393475486394, 0.033462050205637375, 0.03724921352019714, 0.023619364045800704, 0.01422828288688775, 0.020288256703004725, 0.08063836894448727, 0.04325503258094673, 0.0429372439881967, 0.05044796233696323, 0.03430948517615757, 0.03810656549889715, 0.049080759692456455, 0.03853435665669461, 0.007164641001802539, 0.029734865829889334, 0.029552617343142632, 0.06917754037966652, 0.07061413909879423, 0.02258530431126635, 0.06197290480016701, 0.0736311465621956, 0.12847251589259795, 0.03890491338566907, 0.011313822037810761, 0.0195512073414941, 0.1250896554800772, 0.025648311524081136, 0.026208714416791356, 0.04756742577639319, 0.018480923139460145, 0.027350740837714365, 0.06539356399087176, 0.08482009818356845, 3.0107510378283844, 33.17769365925943, 40.0597196240579, 30.86801382803148, 33.99180512274466, 48.6005041676183, 48.74712628702964, 17.47059956673653, 1.786270297823414, 0.09801689730656725, 0.13453478414204814, 0.4511643471496721, 1.4693143507165294, 2.7937162451205717, 6.3533473399377645, 6.758853735462313, 3.2106884641032067, 1.6006595737511113, 0.2149013450910007, 1.8989715148364346, 13.4213730789, 30.35960993459148, 52.991028831851104, 61.62472648005332, 60.18187084505635, 55.21290640677176, 56.33382174276537, 58.462429277358524, 58.56887455909484, 60.34820679695376, 56.90434617380942, 55.07585487058086, 50.96214363651892, 46.157699092741936, 49.13584886058685, 55.722512506669574, 60.87349061043032, 60.51791990956953, 62.27465145049557, 56.661163145496005, 57.10502639893563, 57.68962037178778, 57.97636916560512, 53.160659574693256, 44.265904657302364, 44.94483947753907, 44.89717091283491, 45.34493692459599, 43.15247320359753, 44.543412346993726, 43.72194251706524, 46.087559269320586, 54.49489301250827, 56.249957546111084, 58.17316232189056, 58.628812297698, 49.19601409666, 59.798290498795055, 57.80535774846231, 56.80662816570651, 54.07583875040854, 53.472029086082216, 53.417084524708415, 48.90740609938099, 42.7719287718496, 43.523788298330004, 42.803048856796764, 42.81856967556862, 40.74187863257624, 41.72425585408365, 42.099838487563595, 42.632076663355676, 45.63325466648225, 47.77432357111285, 50.026634816200506, 53.34107683550928, 54.42606326072447, 56.00623715308405, 53.510950765302105, 55.888114975344756, 54.9493113640816, 53.319978406352384, 49.51121576370732, 44.36779606726862, 42.79860481139153, 43.881437855382124, 46.349867774594216, 47.04490784675845, 50.155017914310584, 52.09536344774308, 52.46346612130442, 53.83988857269288, 50.16413350259104, 50.254391162626206, 30.35917651268744, 12.109470675068518, 1.6887068556201075, 0.9944278458433767, 2.8046969204179706, 3.770344987992318, 3.398841864639713, 3.238464728478463, 4.182047257500311, 3.824361173375961, 2.0196643159274132, 0.4441357662360515, 0.09062008091038273, 0.2747119590640068, 4.622646608660299, 26.91389010798547, 44.33725649310697, 46.12739486079062, 24.66670147834286, 32.72692507313144, 18.48570308377666, 0.23220737855280602, 0.06538685306065506, 0.050535552999785835, 0.022254153229897062, 0.0895868274833887, 0.015887962579126322, 0.03248021276968141, 0.061416560258235664, 0.02384875949862744, 0.03894450097915627, 0.01686514220050266, 0.03151893330317351, 0.06783102593955494, 0.017196731867208596, 0.05639409548753212, 0.06391007686033845, 0.037383907099044135, 0.011451796388193484, 0.03263631850601204, 0.07195980318130986, 0.02582690385620921, 0.023392134706579873, 0.05900503038578938, 0.027057034218864098, 0.03930339018904394, 0.03662273745923754, 0.02574484434819991, 0.15619774349033833, 0.1315787572774195, 0.16353574731657583, 0.22497524807770408, 0.059677115491321014, 0.2060912726747413, 0.19686029623112372, 0.20904671731254748, 0.10534291185678975, 0.17982892061193145, 0.09912045462237251, 0.11919092401982316, 0.18004719438331743, 0.14574079654149472, 0.0910563373397435, 0.4044269776392368, 0.19207983097482115, 0.16037903605930268, 0.14589356979535473, 0.09004631169861363, 0.1211038991929062, 0.12145109024019012, 0.16150003719714381, 0.1365973992693809, 0.07808375683042311, 0.11946702210773384, 0.18024268469983534, 0.10826488611318412, 0.18899577549628674, 0.12334016347003561, 0.20875938837566685, 0.17939992669609287, 0.19234987696813, 0.12209632779441534, 2.7284835519329196, 35.08488731999552, 50.47436552663004, 44.12524061818277, 42.68725264456965, 49.00364929629911, 52.97147581654211, 22.93300013388357, 3.4720298599812294, 0.3587083518505097, 1.6275497501896274, 3.1787589000117396, 7.6993067033829234, 10.51716685295105, 6.6548643477501415, 7.29860128894929, 3.122356442674514, 1.3248810364354042, 0.24947185940559835, 1.9002842831034816, 12.488489304819415, 29.444305243030673, 52.81446333854429, 62.9461573016259, 60.127149858782374, 57.02355092571628, 57.3078364710654, 61.59037828445435, 60.4732794146384, 63.081718337151315, 57.696284478710545, 57.11064323302239, 52.1683430671692, 47.930798684397054, 52.30085249870054, 60.09442160206457, 62.96098778324743, 62.422881741677564, 64.4774192379367, 56.71372682817521, 56.271299162218654, 60.473404930483916, 58.64815742738786, 57.0362437155939, 46.98531919910062, 47.598032643718106, 48.358493927986395, 49.370720386505134, 44.130547585025916, 46.277970729335664, 46.30658834211288, 49.125905652200025, 57.870449481471894, 57.770217234088534, 60.86412006808866, 61.799409235677416, 50.59206016602055, 60.76198547117172, 60.55165229305145, 58.739030899540076, 57.88609189371909, 56.30072870562154, 58.67192306826192, 52.42321475859612, 44.79186311844857, 44.612622568684245, 45.308560863617934, 45.275632566021336, 41.70542847725653, 44.19671404746271, 43.82996066924065, 45.88498846177132, 48.85735273361207, 50.6399993742666, 51.99888490861463, 54.674463041367076, 57.73900693462741, 57.67637845008605, 54.24121764398391, 55.74846290772962, 57.328381846027995, 55.69540892877887, 52.36565397631738, 46.420270396817116, 45.415441528443374, 45.61647868925526, 50.313795458885934, 49.71208034023162, 52.44992217709942, 54.301661368339296, 56.273166210420676, 55.28054375802317, 51.57591219871275, 49.10799218762306, 29.470322324383645, 11.207534401647507, 2.525381998669717, 1.0893738414010694, 3.7144958299975244, 8.746253002074457, 7.315355693140338, 7.855466065868256, 6.929603334396117, 9.827330785412943, 9.973190984418316, 1.9734572018346481, 0.2935033297586826, 0.6008137089590873, 7.0695407544412925, 32.52143994454415, 41.748174467394435, 55.57643951908235, 37.222555529686716, 40.805232755599484, 20.40308117866516, 0.34078765540353717, 0.2222014582085033, 0.11421063238935125, 0.11098076739618856, 0.17285493112379507, 0.15074987775616108, 0.20959871430550853, 0.20517043498975618, 0.14948762532684112, 0.09430940713613264, 0.09131876075820577, 0.10871228912184316, 0.19025142424769942, 0.20149921908253626, 0.21644179468914387, 0.17421274536078976, 0.15491367287693486, 0.1001024567672322, 0.1259122653714111, 0.37919866041310374, 0.2238122193563369, 0.06308508826599968, 0.1254384016858474, 0.09988068197403224, 0.11113518007820654, 0.1358464339207257, 0.07481308999441325], [0.03162549230300131, 0.04599245625638193, 0.0876861939867658, 0.048279439384538325, 0.020287843015525612, 0.01683924651344217, 0.06005876900387868, 0.05153258195928028, 0.0441099445696079, 0.015216384049234612, 0.04068668834083984, 0.025006563500351003, 0.026046907071084268, 0.03310887601166483, 0.0021255025668295044, 0.08024274581863035, 0.041933063597929095, 0.06379032199601493, 0.03608503949738318, 0.020539006856720776, 0.018865909134488434, 0.021792998942997188, 0.012028260314236245, 0.03484468186093915, 0.08557904616839464, 0.04362867281381642, 0.029454929641478007, 0.03506895027033264, 0.06930871761494106, 0.04243813770552797, 0.026433522918171463, 0.055232978155536044, 0.024884881924897916, 0.018276689844506405, 0.061743584040912895, 2.1297678207197497, 24.613084639272383, 35.32320660929526, 31.621834539598037, 21.843552012597364, 35.20145623914657, 42.91874308739939, 21.46657301533607, 2.3510346056953555, 0.10215691305817136, 0.13011994200848764, 0.9180334967470939, 2.4249810893689436, 3.9820036820826994, 4.306088782125904, 3.533085228935365, 1.04908668706494, 0.3502045000993437, 0.2444626556168641, 3.605317391695515, 17.036599113095193, 34.949753822818884, 52.437213697741115, 58.12040252070273, 57.83441074432866, 56.486500001722774, 57.18835323087631, 60.70968066492389, 60.709453167453894, 56.47685097109888, 51.43098062084567, 46.7247090801116, 50.294489552897794, 57.043864880838704, 58.51768762834611, 59.972914418866566, 57.6401279049535, 56.609050535386615, 57.23553149930893, 54.484349681485085, 60.045690075043716, 58.77335948328818, 57.85080625164894, 54.27109825995661, 47.5688894333378, 41.32921826454901, 43.805057541016616, 44.12617021991361, 44.70426874776041, 52.24803386196014, 56.09148594640917, 55.21395367960776, 56.803556949861594, 55.923361393713186, 51.37840909342612, 43.76261749575215, 58.27690116820797, 56.523495797188055, 56.07633383043351, 56.20164963506884, 55.49555240138885, 51.855569347258545, 49.81727830825314, 45.04284381866456, 40.94075064505301, 42.7651705280427, 40.38160500987884, 40.11651162178286, 41.5434463562504, 40.956302842786236, 45.96424387347314, 46.47310864540839, 47.57562806529384, 48.09164331805322, 52.58549890210552, 53.612626444908884, 54.14162474293863, 54.7219237204521, 56.35996826233403, 53.635321278725904, 51.44489326784688, 48.25862646102906, 43.20821792848649, 41.33012040968865, 46.148979663848884, 48.37736445088541, 50.20470257728331, 49.831524356718994, 50.32481339669997, 51.26349149211761, 54.04361647944297, 46.70724276573428, 31.011129348508774, 10.641644250962043, 2.372152646703105, 0.03824750269432703, 1.1777909292328743, 2.5666495004007897, 2.31104162912215, 3.174253812720699, 3.0326010911695422, 2.616746992834153, 3.0749300843284977, 2.021726134323305, 0.05922783939768711, 0.2758241042254433, 5.98118991621079, 24.47725688257525, 39.094922465662805, 27.654717968356227, 48.45570595033708, 39.3862957339133, 21.865966396947062, 2.346086290574843, 0.07161185370698091, 0.13422833365057746, 0.035774321896174265, 0.019092351318367066, 0.055377251663876165, 0.048438463915860465, 0.023632006411771142, 0.08970403127492436, 0.020204504140682762, 0.04170131817039463, 0.046063698602900396, 0.06147846399295715, 0.008029282307102075, 0.027841703605747996, 0.03932679417513071, 0.014882331409852111, 0.011600992011447108, 0.0360553152859211, 0.016037727022663723, 0.009270260474764773, 0.07707958410103476, 0.031592950803197684, 0.02733084170388118, 0.06566575503036862, 0.030554706313376947, 0.06734197073045277, 0.09019400578953567, 0.03420674895507193, 0.0385352146751698, 0.025192075521655144, 0.02406181238080946, 0.010608608417603518, 0.026669106446206573, 0.03887300582362279, 0.019125256709934726, 0.04475178835432857, 0.03992163846569677, 0.054176968086751244, 0.009466760112122904, 0.062242173214232734, 0.04202463025707872, 0.126302587168832, 0.03716068823010691, 0.01785618226764904, 0.01910068060932381, 0.051201222118951624, 0.01173012666479354, 0.024820773772174315, 0.20729513388247262, 0.025278047823737708, 0.05907613483648147, 0.09702043908257639, 0.032814640792146806, 0.01295477758357001, 0.03995334684488274, 0.06116457478774171, 0.05319029280555345, 0.05709150362940085, 0.04770472405418273, 0.05700798855433541, 0.019276103252665173, 0.012861298577439402, 5.078249516025667, 33.388364161214525, 40.02734045828543, 30.527303026568507, 26.494604426045573, 45.95483802979993, 51.865269368694676, 20.019585163362567, 1.8631118584063746, 0.08538894911086367, 0.11376954960606753, 0.23204175034357657, 1.7886337710003701, 4.447424036841239, 9.160453331085945, 5.561264887932809, 2.814522702847758, 1.597571197536684, 0.9752337886921822, 5.850581853620469, 18.74163185396502, 38.61720523526592, 52.08724414148639, 59.28389518491684, 58.16828681576637, 56.624653723932084, 58.32404021293887, 62.05151565613286, 62.17290124585552, 58.90029914917485, 52.792203887816406, 49.13272665392969, 49.43410981085993, 58.78694657356509, 60.36965431705598, 62.007110503412065, 59.679321089098536, 59.705640192954775, 56.99972644928963, 56.49925162715297, 59.98796847558791, 61.15306146683232, 57.84358124579153, 55.29624500582295, 47.70976135807653, 44.17128532163559, 45.44916214481477, 45.4492719711796, 46.715385606212, 52.439014065650206, 57.266533913150916, 57.85886672235305, 57.830578588670306, 56.75946166438442, 54.5340225773473, 45.37460965494956, 57.37290466985395, 58.563018460427564, 57.637021387777025, 57.98614371207453, 56.45274408401982, 53.42750626225626, 49.97442806920698, 44.46086214434716, 42.62817782740439, 43.8472661664409, 42.466062345812404, 42.3039900102923, 44.25933468726374, 43.8421513957362, 47.29366456308673, 48.9818879865831, 48.18563507449243, 50.11062060633014, 54.40496483156758, 55.12501001358033, 56.84438097861506, 55.02675856313398, 56.18923925584363, 54.859736196456424, 54.592528650837565, 50.17620263561126, 45.60245229351906, 43.492817263449396, 48.04061328211139, 50.63271945522678, 52.56287074858143, 51.76484492517287, 52.287830229728456, 53.26577517294115, 53.32325750781644, 49.322086918738584, 34.712940723665305, 13.167163287439655, 2.458799029550245, 0.5496931520681227, 2.1443587926126297, 3.1305144823366597, 4.33117381026668, 4.722696956126921, 4.824189264928141, 4.791649281978607, 0.8405017828749073, 0.40794831610495047, 0.04934054010757997, 0.2243582255417301, 5.106833298360148, 23.60481389107243, 43.76897173543131, 30.417478622928744, 54.51635622209119, 40.76073738836473, 29.037220093511767, 4.052553148038926, 0.049816150473611015, 0.0660501856116518, 0.030722699819072604, 0.04563457828255431, 0.04582200935410877, 0.044281705312671206, 0.018837477696398576, 0.06634060954374653, 0.012736177267206293, 0.0191422542857547, 0.057952214903648824, 0.013840770716929148, 0.023664591961630413, 0.03725279881168277, 0.07169908813891873, 0.021454292319474683, 0.01354059065511871, 0.03491159198024581, 0.024021594680004546, 0.03162342578082556, 0.07213290074780103, 0.03804204940435387, 0.043045725868714434, 0.09151104116632093, 0.0579026528453875, 0.036914306692779064, 0.006813455284798459, 0.12339953528416735, 0.13554552990582683, 0.21729150877123882, 0.13968039754657977, 0.10632423218339683, 0.10871490148166496, 0.13333122936948655, 0.10960737859169323, 0.2505639637069356, 0.0747107636303671, 0.23352557072235694, 0.09807082989643659, 0.1502940860847312, 0.16506306616769684, 0.18985757844582682, 0.11936629686744944, 0.14211084212987654, 0.1754711060634544, 0.13477600990764557, 0.08811999127388963, 0.16785944030890543, 0.23297029487307996, 0.14263129162211574, 0.08724429915028234, 0.19246403939060627, 0.13767355362013464, 0.18000312900591284, 0.1494745405450944, 0.1926931609670001, 0.1648254716588605, 0.1827012600317117, 0.12397567936850172, 0.11989877394009983, 0.2436383756538553, 0.1804633486655451, 3.9658212084924025, 35.7361811976279, 47.46282069913803, 42.73139107611872, 31.675355280599288, 45.65924429124402, 53.08705629840974, 27.462896416264197, 4.118951030315892, 0.3801154531538487, 0.4008551386575545, 2.7692112374690274, 7.804580667326528, 12.016615425386737, 11.959163488880282, 8.432781100273132, 3.580902598557934, 1.7380224480744333, 0.6705308969943755, 4.819809448334479, 18.569559435690604, 38.41162596979449, 55.02669188284106, 59.89173704578031, 60.22654664131903, 55.721194590291674, 62.057528649607015, 66.5575776561614, 64.60189565535515, 62.49620260730867, 55.356429853746974, 52.04607494415776, 53.75777375313544, 61.70149510906589, 62.96730672159503, 62.785147928422504, 61.80318647815336, 59.58812990496236, 57.693021066727184, 54.11228541404971, 62.383603126771995, 62.70945795120732, 61.27582380848547, 59.717599499610166, 52.14970788648052, 46.487146808255105, 47.245552770553104, 49.299839235121205, 49.32865688877721, 56.07687119514712, 60.55531970916256, 60.59072302233789, 61.81991930930846, 58.947100870070926, 53.821461277623335, 50.730025614461596, 59.5661489425167, 59.57309938246205, 61.46219522722306, 61.05459820839667, 59.980759159211196, 54.634227368139456, 54.12904570179602, 48.07706386812272, 44.58754293380245, 47.44609963509345, 43.25977748440158, 44.794028266783684, 47.11160775153868, 46.379446368063654, 49.163164246466856, 51.80706924007785, 50.99453064703172, 52.32954855888121, 57.1980179509809, 57.075330134361025, 55.9809535549533, 55.621511474732436, 57.230487331267334, 55.67369468750493, 56.23562912787161, 51.17501066577051, 47.157624998400294, 44.992880667409594, 51.57833230110907, 52.86924708274103, 56.85027237861388, 54.59464280836044, 55.167324542999275, 53.958575571736986, 55.609673761552386, 47.06067969722133, 33.856871666446814, 12.01818633464075, 3.01213514420294, 0.5365328646955952, 3.9428052306175236, 6.510150951723899, 6.308498959387503, 8.04339123349036, 11.31698029656564, 11.111493206793263, 10.423857588921825, 3.656283198825775, 0.3126356708666971, 0.6667510191759756, 8.606994152069092, 30.924717572427568, 47.48075377556586, 34.45136570161389, 55.0390826502154, 48.94800655303463, 33.45390696679392, 3.9222809383946085, 0.33161123974188683, 0.27511513581679714, 0.13805333404771744, 0.1375308161180827, 0.14864831471875792, 0.13999175100076583, 0.12624799574334777, 0.22432995689732416, 0.12628089155881636, 0.1323712292698122, 0.1822991098367399, 0.3090611046120044, 0.11743590851584751, 0.10367849391073951, 0.2222405133708831, 0.07732602692539654, 0.09195913365411182, 0.1772110602788387, 0.1603321514783367, 0.07171568926423788, 0.16539590072727975, 0.16019082357806547, 0.08755195239979414, 0.2003872884257186, 0.16413179436518302, 0.16166834671410824, 0.12257432835477015], [0.05258864565421978, 0.019657444584393696, 0.09315387075466496, 0.0706414271506571, 0.028890824628873702, 0.014895528231957748, 0.043002790470998135, 0.05344153134032123, 0.05300339799554599, 0.09411558689128968, 0.035079966614683794, 0.04119431352122657, 0.056935662193404096, 0.011443222906710881, 0.031730580414014484, 0.045883480249153036, 0.045396987604157585, 0.0783465556319683, 0.049326474733290174, 0.05794589084783389, 0.07841561079746293, 0.061211367438156764, 0.08297821596985863, 0.021068017381513794, 0.012768465957994904, 0.028153166227463274, 0.012958107193210914, 0.03183552871398147, 0.0072125684199554315, 0.11244241719044025, 0.03443005975456007, 0.033461226661118774, 0.010494572399634748, 0.04344968786162715, 0.018368547617067254, 0.011256217013954396, 2.9427359132997455, 24.902828162716283, 37.93013541929184, 29.792082194359075, 23.86616926039419, 31.61820438600356, 43.56334147914764, 24.527861341353386, 4.152843740678603, 0.1030645280655834, 0.11380923296054525, 0.6330760616448619, 7.296111564482413, 8.101095672576658, 4.578891098499298, 2.4903214025881986, 1.3533236134436823, 0.2717786084019369, 1.1725290696467123, 6.151924806256448, 20.25655907969321, 37.36133290875343, 51.06805155354162, 59.776074194139056, 61.08633018309071, 58.761745345207956, 59.95418902366393, 57.87036711169828, 55.89787775470365, 50.769088499007694, 49.98104903005785, 59.35190123896445, 58.28285924849972, 61.45391118141913, 61.0647100787009, 60.33087776553247, 58.54269666056479, 56.918439249838556, 55.23661321209323, 59.10831420652328, 57.72947165273852, 57.398482445747625, 57.0798251705785, 57.250511030997004, 48.53651069825696, 43.28981499518118, 43.154646196673, 48.29738732307188, 52.76588086158999, 57.133432203723544, 57.56728949085359, 59.9764092506901, 56.09362756052325, 64.12119742362731, 44.46936584288075, 52.6695631396386, 60.25143800243255, 57.21861039438556, 57.82445969120149, 55.742551895879934, 57.92205218345889, 54.17778115118704, 55.96810779263897, 50.684067203152566, 42.71267352565643, 42.07618267305436, 40.83758838715092, 41.60278004984702, 43.16781751571163, 46.536992288404896, 49.22077994192801, 50.334991947297134, 50.21767385544316, 52.58118821728615, 55.74658801478725, 54.873056565561605, 53.903434891854566, 56.17818601669804, 56.125641945869695, 53.01057400241975, 49.6657532261264, 45.84853003101964, 45.04726040747858, 47.72656871426491, 48.95683580829252, 51.85044280944332, 50.86973651762932, 54.80866693681287, 54.90872267753848, 48.3486605459644, 31.114517142695767, 13.361542224884035, 1.4257882992106101, 0.12769222469820132, 0.7449400977742288, 1.4065558150891335, 3.12137732102025, 3.614035594847895, 2.8586478963974984, 1.781935833634869, 2.096230330005769, 0.26455522665093023, 0.034453666753946774, 0.32743566218883763, 6.2749082715280595, 26.83025929235643, 36.662629342848255, 27.351750173876365, 23.667950322551114, 35.414358569729714, 26.095922954620857, 6.908323985915031, 0.034850366233337315, 0.12394966302259315, 0.04712178476995999, 0.11303077271628766, 0.018414137509441184, 0.02126567955729702, 0.022887026125024405, 0.05362628876501995, 0.013693969118438903, 0.02949771565204907, 0.15200808524124085, 0.01989298214715335, 0.03935001046967603, 0.13391924781664727, 0.029825022887258284, 0.04400476452804381, 0.026720302186966426, 0.046213560722648137, 0.009606974312074242, 0.01190298578641828, 0.04246290149768034, 0.052194615991245356, 0.02415028404474499, 0.054948675265956315, 0.04078960459258768, 0.031888633928892594, 0.01753161379676913, 0.023789941183020993, 0.06805519092707865, 0.05090900554111408, 0.020978681953443636, 0.03917123619166594, 0.038595103598650427, 0.06078964752715923, 0.021472318368333004, 0.017360820239710233, 0.033260722299136465, 0.07158546197798944, 0.05090747336526552, 0.0273092782440325, 0.04055064261680649, 0.013375954529751214, 0.018848564903882724, 0.023002128920427734, 0.03479529600290041, 0.036456212927136696, 0.02578199386686808, 0.029273401277380127, 0.010538901119763333, 0.03178435978629897, 0.08011277134139692, 0.0563315597302731, 0.006611005059488479, 0.022569597593598792, 0.0443336422434978, 0.00973642114624982, 0.027363936702210098, 0.03616402699281612, 0.014127958885153696, 0.03226690324804476, 0.07395824312322563, 0.05419328575953842, 0.011562149438466276, 0.0391133314359092, 6.391043768775079, 32.7479999680673, 41.9334162435224, 28.285868513968687, 26.87193447543729, 44.56859788587017, 55.26225766827984, 24.519647898212558, 2.3905620459587347, 0.21539066076999713, 0.04486864740629831, 0.16964261720497764, 1.4982616877363575, 7.953499334473764, 11.122653330526045, 7.256828046614125, 4.5467002064951005, 0.8530866462857494, 1.5500292518446523, 9.081950033864668, 23.488637208938602, 40.66546693924935, 53.12634668042583, 61.47141671949818, 59.78572714713312, 61.976178692233184, 61.43547996397942, 59.899162092516505, 58.325864115068995, 53.91954406615227, 50.49562477296399, 59.70561273636357, 60.8079791838123, 63.122597279087195, 63.96385546653502, 60.12428652855658, 59.07838652210852, 56.93545841401624, 55.977293983582534, 58.91373326701503, 59.32597829449562, 59.57663736035747, 59.31207741460493, 57.49212118887133, 49.30547568105882, 45.6408130738043, 45.10996341705323, 48.74127411073255, 56.37094305407617, 59.00532453290878, 58.42813991731214, 60.418891829829064, 58.49440051663307, 60.84286866649505, 47.30995808878253, 52.93302089937272, 61.0722763307633, 59.34748072778026, 59.319588753484915, 58.04056659821541, 57.98446886001095, 56.75982252244027, 56.15924489113593, 50.52697235538114, 44.50591841051656, 42.879746883146225, 42.14255309874012, 43.53004840112502, 45.57340714239305, 48.04705381393433, 51.4112824778403, 50.80895546943911, 51.74074980520433, 53.69541198976579, 57.14862746577109, 55.68049607738372, 54.448691414248565, 57.051352685497655, 56.12404161883939, 54.211490000447924, 52.66638601979902, 46.86645961576893, 46.4334221040049, 49.61373083053097, 51.925552275873, 53.049327019722234, 53.66547646061067, 53.914813687724454, 55.02384031972578, 50.712288656542384, 35.725484894168, 15.105577053562289, 3.1798620666227038, 0.8126657636415574, 1.3472371981028588, 3.102818871698072, 2.5914415765193204, 3.788660740660083, 4.643122361552331, 4.493636911915195, 1.0944131064799525, 0.17834107061066937, 0.020340871621644305, 0.21128347954682766, 5.005476311329873, 25.763782531984393, 42.19838803814304, 34.64727240224039, 23.352697664691558, 40.38074993318127, 33.12405916952318, 10.810033563644657, 0.08298151014793305, 0.06810330124872346, 0.041960998994087985, 0.12885755168334131, 0.04819900398292849, 0.04913116444743449, 0.009371551662503232, 0.03381029079337755, 0.007978502169041144, 0.014440008521740957, 0.06013399117716378, 0.024553483780173045, 0.0665869451157989, 0.04007006417058649, 0.024762788577185526, 0.05471990609000768, 0.041726897846186356, 0.006125372348188033, 0.06693402124989419, 0.058847541860755415, 0.033046060632313454, 0.05295084053350072, 0.02161169274439735, 0.06402640348120082, 0.01169363598174025, 0.03213872907743339, 0.07228382772976352, 0.02627436049102295, 0.16347783106950023, 0.11305236107399387, 0.19068832419091658, 0.12837598115325938, 0.14168514239211238, 0.27296757686042017, 0.11936959104552386, 0.11423510123765278, 0.15639536353128572, 0.22573601935179005, 0.15125983184383762, 0.15290970944108503, 0.13929975910052178, 0.08912934275764613, 0.17001302071636723, 0.15335928047856978, 0.10787476349862353, 0.11899302818722303, 0.14393785457697608, 0.1285883943520246, 0.12240967307720454, 0.1206205819823569, 0.17710296527272273, 0.09933181061980226, 0.15952481738021299, 0.12205707344917521, 0.09108661313451107, 0.13039145889061113, 0.10064448695629837, 0.2635291897721829, 0.10145061063550173, 0.2788663619468289, 0.07644906309583495, 0.07632886390051535, 0.08111083835002877, 0.1143388755078758, 4.925311400044349, 37.29869657947172, 50.532334235406694, 42.61092724338655, 34.69320727932838, 40.483112027568204, 55.37632019289079, 30.363863745043357, 5.882271172538881, 0.39529373869299894, 0.27373473730779463, 2.040899170021857, 13.874850061631973, 17.62583128867611, 9.96611600922, 3.5460346889111305, 2.8633356190496877, 1.840542785583004, 2.349865003939598, 7.995959972181629, 22.10755890415561, 40.848857356655984, 52.991170037177305, 62.434374286282456, 62.1383333975269, 62.63707845441757, 64.267941136514, 61.728061322242986, 61.394746149739916, 57.03044645247921, 52.917664820148104, 63.38803583575834, 63.30162209849205, 66.0371732711792, 64.65872295441167, 62.333541916262725, 59.830171523555634, 57.40374626651887, 56.35380621879332, 60.091738700866706, 60.41978613022835, 61.1087033825536, 61.20370318812709, 61.17126910917221, 52.90779613679456, 47.97297593085997, 46.15344724347515, 51.02077914822487, 58.04069995880128, 61.92009664350941, 60.82031503800423, 62.771011706321474, 59.06493671478764, 62.27769520974929, 49.93715378545946, 52.59674825975972, 62.131210373293975, 60.855231977278194, 62.401881371774984, 59.058782515987275, 60.96017891360868, 60.11544550618818, 59.31263046879923, 54.24785429431547, 46.580185428742446, 44.757369795153224, 44.43127962850755, 46.84421585452172, 48.388190192561, 50.9039278184214, 53.71093673090781, 54.73765634721326, 54.93039377274052, 56.000290839902824, 59.34868881779333, 57.43414071298415, 54.8007986622472, 58.842452033873535, 57.44005172483383, 55.97238709849697, 53.0125940230585, 49.792516385355306, 49.48263737463182, 50.57781803992487, 52.68275014815792, 55.67211789469565, 56.04294661552676, 58.63019297199865, 57.221516870683246, 49.83760010811591, 34.00439593099779, 15.232503971745892, 2.312545858083233, 1.1150643854371964, 1.7038777254281507, 3.689568186959913, 7.683892278901993, 9.236866985597919, 8.14285763809758, 6.424404997979441, 10.487979515906304, 1.8623664854995667, 0.15221112918469215, 0.5688022041032391, 8.81080246740772, 34.82680712976764, 45.99659166028423, 37.55434490019275, 33.26702171756376, 44.15166562603366, 37.44504805534117, 11.096362663853554, 0.07575226782430565, 0.18128617306149777, 0.14275587284036223, 0.23843288481716188, 0.14567580164199875, 0.18447671476150715, 0.11035674281658665, 0.16398012427793396, 0.09916504860044488, 0.0647652339971354, 0.2017894131882537, 0.0852614184541087, 0.19930511262388, 0.2827805503001136, 0.12619577152954956, 0.08958131165033387, 0.13489783320936466, 0.1797977561551717, 0.11065813712775709, 0.1361306218971168, 0.07691011779130467, 0.22526318988492414, 0.12699431093830255, 0.14047291550424792, 0.20674978653269432, 0.06160443183034659, 0.14198469809226452, 0.15158538856813986], [0.08268944678768035, 0.10887196482790094, 0.03659742974465893, 0.048967164175044146, 0.01745319129118035, 0.04475663003001002, 0.019323619856168667, 0.022906528808356776, 0.09520572234666157, 0.03935553013317047, 0.03821437705248114, 0.04159553291937036, 0.02642163323358663, 0.027097730724621686, 0.04890010083815263, 0.027187924171167038, 0.049167005870971954, 0.10857810882190544, 0.05235726028800972, 0.011260685221772763, 0.12417572024728983, 0.07049578617537214, 0.12523118256320878, 0.02401027381570349, 0.04274409023984786, 0.013701018084952188, 0.02634808113197646, 0.02336962321292489, 0.0366264529856703, 0.033841263728156205, 0.013926388703346735, 0.10090180056830568, 0.029682421365812905, 0.06919424875729507, 0.03384861434178968, 0.017767902125694582, 0.09782321495755066, 3.3822605350325188, 22.873933161458663, 38.175185495807284, 26.998103395585094, 22.529411777373284, 29.30339017222005, 49.20081900012109, 29.815522278508833, 4.374153181429833, 0.07621283222350382, 0.23355794559803703, 0.602041655971158, 6.819106734568074, 13.849949875185567, 10.982006942072223, 5.485740630857406, 0.7339374204316448, 0.300799397931945, 1.2586527966683911, 6.451469842464694, 14.775662575998615, 32.68457720356603, 49.22557307827858, 56.0841275799659, 62.37118882517662, 65.42805271763956, 60.51312677321896, 61.45398178408223, 53.501517465037686, 56.81933272269465, 58.1245445436047, 60.419848888151115, 60.28141275528939, 59.29310098771126, 60.519371186533284, 60.24870803279262, 59.572036420145345, 60.142678522294574, 57.84888821263468, 59.81548616963049, 58.12115169340565, 58.23057013173258, 60.030463434034786, 56.10741469167895, 46.368020503751694, 43.57279046889275, 45.6925569811175, 55.78780035818777, 60.514554515961684, 60.44262609174175, 57.463142718038256, 54.51871356656475, 58.58549364151494, 40.580002415564756, 53.10173380759455, 58.004763203282515, 57.24669456481934, 61.33063108690324, 57.73902654647828, 56.79713210751934, 54.702794321121715, 57.579064446110884, 57.65475834569624, 51.657430818003995, 40.58363060797415, 42.05809662418981, 42.06363501087312, 47.06927753263905, 47.33339817293229, 52.399413816390506, 52.18067107662078, 51.84443766070951, 55.7721971696423, 58.034212358536266, 55.81479803208382, 57.06979959241806, 57.19771592847763, 54.02831139103059, 49.96788555575956, 53.30773276667441, 46.54002820291827, 47.98724551354685, 49.53848015877509, 51.88454781809161, 51.10677711425289, 53.218585137398016, 54.18990911975984, 47.05232897112447, 28.525256649140392, 12.115292452996778, 1.7652558319030272, 0.21968718828453174, 0.5566080455337802, 1.6145305455692354, 2.2651285702182404, 1.2546956154607958, 2.102133251966969, 4.335812012995444, 3.2350770263902606, 0.7525917839619422, 0.14611481598788692, 0.45437361203855087, 7.41610324190509, 26.19853019714356, 38.1561541557312, 24.017537447714037, 22.11325418564581, 30.60346761057454, 22.17487854342307, 7.6927970397856935, 0.20426563918590548, 0.05074830710767739, 0.08748415361849532, 0.03194515015028658, 0.02428447200556196, 0.06125801070142658, 0.045683140596074444, 0.049202678755166075, 0.020794098813747688, 0.026668830654553832, 0.061843029914363745, 0.003992662569808384, 0.06321624634907612, 0.025036456251156428, 0.0816846841705903, 0.015965912025421858, 0.06307707881675133, 0.017552897634525454, 0.06394489938693662, 0.02353463472137528, 0.01311719492678681, 0.03108766219098001, 0.08445972276310768, 0.0099607240295999, 0.0350818818344945, 0.024212873428158706, 0.057690124733433615, 0.006449899641842011, 0.06812524200687486, 0.10333344790964358, 0.06351186818773709, 0.01896874303178441, 0.036237046663318916, 0.016825183054372188, 0.05474954220135847, 0.001380347396573803, 0.03710639174847353, 0.019012394721709916, 0.019047828203427698, 0.04850686790661947, 0.027163390205391956, 0.029581636753714377, 0.07091747161241309, 0.05919740272445544, 0.050591760870790294, 0.03568809103941725, 0.044957153544190435, 0.0474466213716134, 0.023360757660421155, 0.042716886457656665, 0.05093709415485782, 0.04700831948749481, 0.06352512533926676, 0.029891842991233836, 0.009556185555524163, 0.06790135281100389, 0.045350807824081955, 0.017192338352962848, 0.025566977884380088, 0.05580791565138967, 0.0660160027684704, 0.05379156457380422, 0.03953906947806959, 0.036048056602838545, 0.026202585713397113, 0.08985399298610226, 6.640944836601135, 32.08478600748124, 42.93924923866026, 26.006640003573512, 20.80712845248561, 40.01026638092534, 57.78827974873205, 29.38807022187018, 3.2863291665430996, 0.0661158699902796, 0.04989814869458637, 0.10133892267702088, 2.4456713468797746, 12.29434669017792, 10.083561578104574, 8.455119978997017, 1.290228121703671, 1.077363543933438, 1.7753892752432057, 8.651569927892378, 18.65064855544798, 36.18085245932303, 52.05419032804428, 55.53116752255348, 60.12781666171167, 68.2071461216096, 62.748348251465835, 61.79717740704937, 54.7489292390885, 58.3061542049531, 59.942484671069735, 62.132422385677216, 61.21452108506234, 60.372447044618674, 62.21241128060126, 62.174995791527536, 62.009534528178555, 60.00319511659684, 58.32817831347066, 58.85309342415103, 58.52993719039425, 58.610690947501894, 61.29597694643083, 57.66492905155305, 48.285792796842514, 44.48932678468766, 49.13548800253099, 56.76293688435709, 61.314078684776064, 62.75913084706953, 58.82533088807137, 54.233165018020145, 61.62646409003966, 45.09907883982505, 54.03184152418568, 57.7287224800356, 59.37461176226216, 60.34572785900485, 59.878499046448745, 58.37966334435248, 56.712255939360595, 56.569097272811405, 58.405649046744074, 51.70921394901892, 41.694124206419914, 43.340515552028535, 44.77331422990368, 49.65326832186792, 50.708938952415224, 52.691744142963046, 54.367125726515255, 53.776679577366004, 56.27492735462805, 57.929618435521284, 57.66394061426963, 56.98515092172931, 56.85421436063705, 55.95112392979284, 52.64765277985604, 52.86743102535125, 49.695139623457386, 49.905315906770774, 51.78471565246583, 53.34178678451046, 54.92600071814753, 54.09953378861951, 55.47133568794497, 48.91389762201617, 32.95185535184799, 15.335071009974326, 4.16162935956832, 0.8139527913543486, 1.833928811454004, 4.435585343068646, 3.6838380944344307, 3.743954791176704, 3.343913483042871, 5.620791267964148, 1.2906649756816126, 0.17577121334691204, 0.13902615845924424, 0.22146428244248514, 6.478374360069153, 28.014360089455884, 44.42478026113203, 29.747302455286828, 23.28933373574288, 31.8806109505315, 30.077318914474983, 13.026647317794062, 0.4290632314739689, 0.08454499600995934, 0.057915749118453076, 0.0358370759884917, 0.04979229449564892, 0.021500236527513594, 0.06962777025276615, 0.03566931422439314, 0.0156656745070171, 0.04313743808456967, 0.013258475904172708, 0.021569703465267535, 0.038199495794551994, 0.019676514428048845, 0.01202119889879419, 0.02208996335074546, 0.04698976483796874, 0.027852503530260538, 0.10012509466539468, 0.03088720379427316, 0.0370077004716281, 0.041731513525930145, 0.03074867211492552, 0.029191077469036947, 0.05724858612783494, 0.04520613595002121, 0.030817296355962757, 0.026345271504514163, 0.05234354731416511, 0.24998835588414825, 0.20062664493678078, 0.06362667029363013, 0.13962517792899765, 0.1376174913058358, 0.13301960012364772, 0.12784724258967947, 0.11199951111789673, 0.21583209595372602, 0.18333843068009426, 0.14018062231761796, 0.11215737885645322, 0.09772540851225776, 0.14851369774870335, 0.15780957716126598, 0.09337196832582836, 0.1205343358038414, 0.24470334512091454, 0.1520391424456912, 0.10957803742419328, 0.13355469721699917, 0.12915336887442297, 0.18973239967899938, 0.12865156596226077, 0.12052642977646283, 0.07774742124902626, 0.15922228925891463, 0.14800308482541194, 0.09436650366912927, 0.13070786852509747, 0.14663492840143943, 0.22064498205098415, 0.11189294062675008, 0.13867135249799298, 0.11606878631057278, 0.10620377251818296, 0.16027831081901828, 4.992211835999643, 33.06983240189091, 51.69454036220428, 38.548469620366255, 31.70656361887532, 36.96888800590269, 60.118112717905355, 39.469614721113636, 5.744222864027947, 0.17900085617457667, 0.5486105779005636, 2.199154303919885, 14.81042262046568, 22.732376783124863, 22.846429501810384, 12.098030101868416, 1.9982018417889074, 1.356272255220721, 2.1731185913085938, 7.387920521920727, 16.672548247921853, 35.123452063529726, 51.25995743659235, 55.64739127312937, 62.7134705358936, 71.39474653428601, 64.66341410913776, 66.30456909056633, 58.612758036582704, 61.61060202506281, 62.58200445482808, 64.14672028633856, 62.16209903840096, 63.0773566615197, 62.97058974542926, 64.48229082169073, 62.82799197781471, 62.34426175394366, 59.37609834055747, 61.779656179489635, 60.17173936290126, 63.43796760805192, 62.65483894655782, 60.99582149136452, 50.83997749513196, 46.01218700408936, 48.60873722260999, 59.911874494244984, 64.62863837519001, 64.80977342974755, 59.1397520034544, 55.913167153635335, 58.16031655957622, 47.63646010429629, 55.810922730353575, 57.9861907805166, 60.652351302485314, 62.204825416688, 60.57674761741393, 59.599791111484656, 58.95371006381128, 60.25267354903683, 61.735423611056426, 54.98165130615235, 45.7241948189274, 47.2072978942625, 47.8423257027903, 52.43470338083083, 53.60364029484411, 55.790616619971495, 56.03891441898962, 54.70104102165469, 59.84214259732155, 59.45619706184634, 58.20431770816926, 58.080959166249926, 58.32774293038153, 57.83474022342313, 53.63516046154884, 57.31675594083725, 50.94026073332756, 52.402041804405954, 53.670277441701586, 55.51540351683094, 55.084943002270116, 56.41952553103047, 56.26681981548187, 49.051455143959295, 30.955759209971276, 14.922766166348612, 3.0660667534797423, 0.4761482210409257, 1.836773755569612, 4.653384262515653, 9.017685920961442, 4.402787464280283, 7.9133921188692895, 13.416717225505462, 9.45845050196494, 2.4393514279396307, 0.49779176772121464, 0.6026243118028487, 10.841043822226986, 36.67998190849058, 47.731973740362356, 34.11499500274658, 31.296540614097353, 41.88149975192162, 33.87964494766728, 12.593376425004775, 0.4855192230353433, 0.20682513894092655, 0.28113278710553724, 0.09457902412020391, 0.0613304443146673, 0.21470275977926873, 0.20483439818264979, 0.13061230671742272, 0.09390825285546242, 0.14072338029021217, 0.20137168076490203, 0.14154580632044425, 0.1252505339441761, 0.1333389362140048, 0.1358404890784333, 0.08937767781918088, 0.2416879311203957, 0.08855322165594948, 0.1596286069721945, 0.15086935682883187, 0.12172976238352638, 0.1950296678490216, 0.1459987843108754, 0.11512939397606159, 0.09887949698754857, 0.09885528094826207, 0.18023902279955728, 0.11730941973866955, 0.09393122017143235], [0.01608353141965645, 0.07767121848319808, 0.028337477405946103, 0.05840803721859571, 0.07658351152654617, 0.07604659114393496, 0.00392922594103091, 0.03233681643201459, 0.031028757690482085, 0.049640999791482766, 0.04225387440754041, 0.020708923243106376, 0.06684814279358234, 0.09467105426254774, 0.0702494046380443, 0.0314857674417116, 0.005452830462731542, 0.03242082563379119, 0.01005597844449503, 0.08310472006879507, 0.04667759933058293, 0.029481045578816728, 0.03785892757737348, 0.04952244002432112, 0.006140680221330014, 0.052191245204378525, 0.10197807749312732, 0.04368828211520468, 0.047426457937446334, 0.06901275486715379, 0.051965842984857104, 0.1061892474911386, 0.10340968131898873, 0.036681530876986446, 0.018457155261609345, 0.017518402610514915, 0.04389288121714227, 0.05494982439784273, 1.927086941657528, 26.36233033672456, 41.82628846937611, 35.46840490833406, 23.595710069902484, 29.247923935613326, 48.460989382959184, 33.23020242875622, 7.233290883802599, 0.35788440896618756, 0.060352992732077844, 2.363863452788322, 10.784605818410075, 12.626558696070026, 10.852666785640102, 1.0668069749109208, 0.778791378101995, 0.08203477869110723, 1.5566269236226238, 5.270261303071053, 15.409770588720999, 33.73703933531238, 52.397366339160556, 61.224738859361224, 63.376358939755356, 62.259075718541304, 60.05753955533428, 59.19397484871649, 58.65808886866416, 59.51212613813339, 59.83828690744216, 59.743738174438484, 59.813281797593646, 60.21577973519603, 58.12559573881088, 60.15377098514188, 60.881849181267526, 59.11669631158153, 59.40537491152364, 60.69356364588584, 58.80382453241656, 61.56151748472645, 57.69127168963033, 54.002419825523134, 44.71269399889054, 43.766783052875155, 50.13983834174372, 57.50396282442155, 58.18359974891909, 60.820734731612674, 55.64458677845617, 49.64140315209666, 38.128972130437056, 54.558796267355646, 59.577398300170906, 59.87214480676959, 58.176712066896506, 58.04282980580484, 58.40982244860742, 58.63384077625891, 59.59603740322975, 55.42977033122894, 52.371980759405325, 44.42217188496744, 42.47931211225448, 43.69086557818998, 48.02935607971684, 50.859585423623365, 51.24740192967077, 53.55313585650537, 51.82246062063402, 55.70312030853764, 58.33140642412248, 56.2292121302697, 55.055725266856534, 56.72674517477713, 54.40906370839765, 53.57926276422317, 52.489075276159475, 52.68907693124587, 51.09062871625347, 50.57218551635743, 52.930126190185554, 56.031206961601015, 56.731581457199596, 44.66939887692852, 23.430166436779885, 8.339653245864376, 0.9396831414872601, 0.548519566655159, 1.410199942127351, 1.8595504688639797, 3.2003991065486788, 2.4226230094509744, 2.6916966226793106, 1.8958451406609629, 2.561968396748266, 1.2406085455609908, 0.02860189265301151, 0.20665869867849737, 7.249404961063016, 31.486952074112434, 36.82954972790134, 24.63316325218447, 23.99761965197902, 34.92617645571309, 17.6602755823443, 4.0419588262035, 0.39693187982324635, 0.07160891192935168, 0.04980910629514725, 0.0349595375929869, 0.07171034963140566, 0.06634048696967863, 0.032766909684024514, 0.09513538781433337, 0.028275995019582972, 0.05274584689628213, 0.05843158676138809, 0.05204354728301687, 0.04005871457798828, 0.023293131248905294, 0.04470446327280614, 0.020530453485046184, 0.03568715258171001, 0.0609912014295978, 0.0720138583452471, 0.03718167137835295, 0.07073872797791997, 0.046406905992978045, 0.012202718644402923, 0.04667447752229149, 0.05106128466826293, 0.04713421071609182, 0.020191566830861474, 0.049593195905007666, 0.04752167883599478, 0.07907098369492639, 0.04071363165313679, 0.04716009299661364, 0.0549191425764753, 0.01817961118274158, 0.04838224838397676, 0.033165727396525686, 0.1191555997056346, 0.033821851060154944, 0.049255121304022695, 0.05047766356578758, 0.039180344977085634, 0.011743896137622577, 0.037202049317138816, 0.08101506203773522, 0.06129610825390105, 0.034230942011720715, 0.01558656539512618, 0.013169275499099206, 0.0607261962948307, 0.020745500111051147, 0.051127509138877356, 0.026027902344902678, 0.019655309114304763, 0.0607318883281081, 0.05105769171589806, 0.06956303582316445, 0.02125934975582265, 0.0793754883230694, 0.0786048345147602, 0.0279253029504851, 0.012693329011991382, 0.07068102623546316, 0.05153452782260795, 0.0178712627084385, 0.03190080132034998, 0.035723036140083306, 0.051209338820509376, 0.04422395760493894, 5.128834853249212, 34.33884859085083, 45.45195879474763, 28.207966319976318, 21.195611761462306, 41.256995662566155, 58.758230901533565, 30.56889780106083, 6.2342077974350225, 0.07866488814714455, 0.06765616637083792, 0.4220248139914005, 2.660702298725805, 3.7618175100895668, 6.7051770802467106, 1.9616824917254911, 2.051863910690431, 0.7910207154289369, 2.9155835509300236, 7.0831803064192504, 17.67364498107664, 35.395692010079664, 52.42662722064603, 63.0001957954899, 65.46614285438292, 64.3803523432824, 60.58509442114062, 61.58963303412161, 60.10268211364747, 61.47849659765921, 61.92938873844763, 62.85265191908806, 62.085565751598736, 62.819143110705966, 61.292184014474195, 63.11228929027435, 62.00960905321183, 61.935189923932484, 61.439084622167776, 59.973844020597404, 57.89972997480824, 62.91187578631986, 59.03848817271572, 54.88506294065907, 46.27209501881754, 46.773703405934, 52.928882798840924, 60.359056072850386, 60.128589368635616, 62.14364428674022, 57.01633768696939, 50.429854469914595, 41.4608294733109, 54.93104488618913, 58.81936496303928, 60.0088825533467, 59.00217094729024, 59.17062105671052, 58.74492622190907, 59.386355338558076, 60.09531982483403, 59.24227099264822, 54.31279305488833, 45.664304148766306, 43.552280395261704, 45.50526772775958, 50.44894072317308, 52.7399932184527, 52.25245829551451, 55.377304707804036, 55.18446922302247, 57.27914825562508, 58.43900488268945, 55.083891807063935, 55.37608877305062, 57.707302416524584, 54.16691226343955, 54.08639777091242, 54.05608569422076, 52.456323485220636, 53.782825931426025, 53.053065038496456, 53.78264158002792, 56.05075605453984, 56.723403315390314, 48.58973726149529, 27.413964848364554, 12.302676823831375, 1.8631943507540611, 1.4017337512585426, 2.5840246196716063, 2.85526289093879, 4.315248497070805, 4.87977562412139, 3.6988315995662444, 2.7830366117338983, 1.1688707240166203, 0.4943658531673493, 0.03860353822669676, 0.2949215423676276, 5.707879652900081, 30.8985867423396, 45.157804566044966, 31.02769744011664, 25.048634429131788, 34.83565599687638, 25.140462998420965, 8.729248546784925, 0.8830016442844946, 0.05391827934691983, 0.050140791722843726, 0.039661080471330115, 0.01565705889069866, 0.039078007121720625, 0.08206866275999816, 0.08167515403681225, 0.02950806933034572, 0.03194339006328054, 0.032684352218864426, 0.06446505776576458, 0.010319358515252751, 0.04500808689983622, 0.030600416864598953, 0.04058399042415042, 0.030752971783400546, 0.03317339976708735, 0.10393262825786106, 0.03629485565808512, 0.024849260751638683, 0.06301573432621456, 0.04523103380756033, 0.0587571932814054, 0.04804329278187887, 0.056028809443476706, 0.050121490137591485, 0.0728771168618433, 0.04069107036376673, 0.025362627761017893, 0.09838564606804041, 0.12475705074687159, 0.22501447177942724, 0.12764071294617269, 0.27597937492593644, 0.13234078493570128, 0.19628416746854785, 0.11054988124317701, 0.17368051343627516, 0.20173027120049924, 0.15242267670410295, 0.1210778751861184, 0.1771024443329342, 0.22123868487054305, 0.19823933110362102, 0.18100691869133906, 0.1611195213251537, 0.07962201541710286, 0.11959046185497316, 0.251592084344837, 0.17995025361737899, 0.1894257500046684, 0.058564809451420466, 0.18863321672524178, 0.1720162333860513, 0.09917984175826274, 0.19027362547574506, 0.20412244203109897, 0.14939744145639483, 0.19332368197219987, 0.13376635198871936, 0.23047347643202354, 0.22305915492676923, 0.14176296160346077, 0.12824899441893065, 0.18849683775296136, 0.17748695918388907, 0.15593158922368483, 3.9714993296131014, 37.22660733807472, 54.00898587319159, 43.70016551786854, 34.51549253156109, 37.9896063958445, 58.95749515102756, 42.262856114295225, 9.904873101942002, 0.6438130596953054, 0.3334387271634994, 4.834827223131734, 16.77127822752922, 25.680075230136996, 23.172964857470607, 3.5349277623238105, 2.4009590235448655, 0.9135152940307895, 2.313404121706563, 5.91426202366429, 16.929388969175278, 35.242723495729514, 55.21933517148418, 61.73449008695541, 65.4428243637085, 67.03613819614534, 63.25567545429353, 64.05580366811445, 63.41304486797702, 64.97614468297651, 63.397080821375695, 64.5435150977104, 64.56713561088809, 64.80656100857642, 62.245257208424235, 64.69946853576168, 64.41083308189147, 63.19075238320136, 63.235969466547814, 63.66967770361132, 60.719098275707616, 65.41170820113152, 62.22174652161137, 59.29929048784318, 48.09509500380486, 48.307809060619725, 53.84215570265248, 61.70380930746756, 62.76780320752052, 65.13678927575388, 59.80842198095014, 54.957936656090524, 44.52079988295033, 56.19445600817281, 60.01977497531522, 61.98191319742511, 60.99177360534669, 60.794831398994695, 61.891318213555124, 62.09541874547159, 62.66042832405337, 62.14757057928271, 57.44189131644465, 47.78980516618299, 45.84976557762393, 48.163257952659364, 50.92195110936319, 55.75853163196195, 55.41614009488014, 57.438400406991285, 55.725579800144324, 59.02638373836395, 60.734842669579294, 57.26097983698691, 54.10542518861833, 57.10917234420777, 54.684163062803215, 57.22572949624831, 56.29900678511589, 56.570172002238614, 56.815112252389234, 54.54979835018035, 55.68408504609139, 59.14279184033794, 57.40542504095263, 46.618683491983724, 26.142552091229348, 9.605714909492, 1.4287136519147505, 1.3487551553595452, 4.085019831695865, 5.763999454436764, 8.340652469665773, 6.262589087409358, 9.935600949871926, 8.378406263166859, 8.301618022303428, 3.242359887207708, 0.3122043633653272, 0.604069950359483, 9.975920954058248, 40.71565366560414, 46.181264692737216, 33.340534779333304, 35.17769452064268, 45.529578578087595, 26.68617298526149, 7.854398200588842, 0.7079169682918057, 0.15443900479905068, 0.20323298330749237, 0.15494382609763455, 0.15791370383193418, 0.16337039489899913, 0.1211575713128813, 0.16801115636142994, 0.08968375292756865, 0.156408938609304, 0.13602104068042772, 0.1396984772215928, 0.13183665311624929, 0.1184974305872475, 0.13568258303548061, 0.08533163807324826, 0.08707801976631727, 0.102839773190358, 0.23206713849738722, 0.15158780940598057, 0.14914671620053632, 0.14621672100357472, 0.10864769258806783, 0.1861286761179086, 0.25098371860240737, 0.15685383651045062, 0.1560543777961885, 0.1412076857541838, 0.12805717366357006, 0.12597505393768513], [0.06198304397384487, 0.06429923803455408, 0.027443638574632428, 0.012950472169435553, 0.021409573852114623, 0.030456085899664514, 0.07510583517291854, 0.0760278066680316, 0.016727962666341377, 0.06092408063611197, 0.05504583053651357, 0.03459123699294944, 0.010510762710304511, 0.033519771100292285, 0.053548967510822325, 0.054272146850463845, 0.01167851627894467, 0.0332538389991368, 0.02264964803602667, 0.03933827017223643, 0.008280987197893762, 0.045932712889606916, 0.03866779385134578, 0.11715765005999035, 0.10033913963143865, 0.02675252192984185, 0.04253332796055944, 0.031167243404554266, 0.05077805813221682, 0.010290467424408324, 0.04060975396104398, 0.07515732394230944, 0.05326345420232224, 0.025642307309974587, 0.0981734550347732, 0.04362635156740585, 0.0742978728826969, 0.00889554676119118, 0.04703633532288575, 3.5991693215985454, 18.48504412558771, 31.00837976701798, 28.93743891869822, 23.65840131236661, 33.02412894464309, 40.15582553801998, 35.7907295996143, 9.207807125583772, 0.7675303146243097, 0.05685094052985792, 1.3855382848170497, 1.1398830601284582, 3.0640991945420546, 1.377765495450266, 1.1240087377448236, 0.48638539268605174, 0.6230096663198164, 1.4972564578056338, 5.043806693246288, 15.4554210939715, 30.856450680763494, 49.440840598075624, 63.530202142653934, 64.84376861203101, 62.80246911510345, 60.952396931186804, 58.58175954511089, 58.22322353239983, 58.19550414239207, 56.175989489401545, 53.581314163823286, 54.177953735474624, 57.866699695587165, 61.324610248688735, 58.79887057888893, 59.58493317327192, 60.88967823213147, 61.962054237242675, 57.710153979639855, 58.06246911325763, 58.475302496264064, 55.3660318159288, 44.819696257191325, 46.74906307651151, 44.61263041342459, 52.27576894144858, 55.82208971823416, 61.66795492172242, 59.76403644008022, 65.14451634499335, 40.93486316742436, 52.28886965782412, 61.64124358084894, 58.09664864693919, 60.436095345404844, 58.18374879898564, 59.691770692025464, 59.46942721643756, 57.856823167493275, 54.46943290771977, 52.72203268543367, 43.326285193043375, 43.615203057566, 44.77635014441706, 49.7738576704456, 53.215251122751546, 53.066138298280784, 53.63136752959221, 56.27768870322936, 58.495412488137525, 57.95019518944525, 58.00859928131104, 57.543727813228486, 58.63774353458036, 55.826718115037494, 56.01756103577153, 54.32616441480575, 52.092504039887466, 54.15315651124524, 54.8717111925925, 56.59980550889046, 56.24556841388826, 39.098597726514264, 19.638985818432225, 4.00269688137116, 1.171571153306192, 0.1380826752152174, 1.2004904208644744, 2.3824042514447243, 2.5494383852328024, 6.322599389860708, 3.311425226349985, 2.914856931855602, 2.168543391650723, 1.3781046578961036, 0.06750857953222529, 0.9867548930548853, 12.044150463996395, 35.5557051012593, 33.8910904238301, 23.267558697731268, 25.44268946493826, 34.400327820931714, 17.77481467493119, 2.56444733469717, 0.014559170625533068, 0.004905949979494777, 0.05373264475154781, 0.06639025970211913, 0.02529373347398735, 0.06347506532385465, 0.012128860107623042, 0.036579637352617524, 0.01828325904845711, 0.06896526507672764, 0.016705642694667462, 0.08443373706071608, 0.034113251754353126, 0.019137491134085485, 0.024454396052826798, 0.0736702706724886, 0.04801541867275392, 0.016681181507245187, 0.04265265381564537, 0.02696500216130047, 0.015729313430887078, 0.017142665211952502, 0.017431273515666687, 0.05642197725753631, 0.00812825512125968, 0.0006164907033727956, 0.026878941759106614, 0.10551071575572414, 0.03330357342718109, 0.023395317801905256, 0.05349957016146472, 0.04350192739718384, 0.06116488122291142, 0.07536550067485341, 0.02969104368540068, 0.06987655730617624, 0.05039915487530732, 0.051685401178415746, 0.054731194395571954, 0.06202517880968029, 0.09414246891655269, 0.029408709641786355, 0.04497666963406148, 0.037067014829165516, 0.016412755789896174, 0.01660965379297493, 0.08287387479457163, 0.06239174039012963, 0.04187904290794846, 0.07230059739442603, 0.017927673592742895, 0.015164787069924418, 0.02346011734898052, 0.06750545389349423, 0.06371806841343641, 0.031409470830112696, 0.005684678833330832, 0.00986853875445142, 0.0330916352029289, 0.017905355536288792, 0.02269573588555138, 0.021840854540407177, 0.002358630064859866, 0.03304167094850733, 0.02132434848575823, 0.059360878226617654, 0.07064309722233204, 0.03295982977555644, 0.07146814327326513, 0.06804248152841484, 6.868578118662681, 28.768141577320716, 36.97579137740597, 27.86943635632915, 20.190631881836925, 41.01644454463836, 54.66185262126308, 39.170922310121604, 8.747946485396355, 0.1844844216060254, 0.013890682302805928, 0.18814903383533801, 1.816872139611552, 2.8193035817915395, 4.122706699755884, 2.7017371548760325, 1.4391656652573617, 1.33333288613827, 3.518332704421013, 6.537751199737673, 17.79606999889497, 34.7782717212554, 49.372434462270434, 63.097580402128166, 65.61228644463324, 63.068170470576135, 62.473884321028194, 61.43066329340781, 59.57339748259514, 59.89387081515405, 58.5752405658845, 58.035177261598655, 58.43455299254387, 59.776254623166984, 62.696059134698686, 59.49828801616546, 60.95009057752548, 60.5642823250063, 62.696321933500236, 60.98859256313693, 61.81541250598047, 62.29973108537736, 59.212763001841886, 48.13971196451495, 48.328985937180065, 46.52394648521177, 54.331671422527684, 58.959942710015085, 61.17959237867787, 60.59029940635928, 65.49235605424451, 44.366364402155725, 52.73645524055728, 62.25464736261676, 57.63054555462253, 60.428317285353145, 59.98836071260514, 60.61103305509014, 62.53146471515779, 60.955107288975874, 56.21482095410747, 52.66780984017157, 45.817825717310754, 45.11513702331051, 47.40576590261152, 51.46167316744405, 55.550167483668176, 54.96492631973759, 56.252044247042754, 56.81368058727634, 59.458287685148186, 56.74171686172486, 58.008042304746574, 57.10292400852327, 58.3966197506074, 56.556992838459635, 58.74124703868743, 55.69263973543721, 54.99102969323435, 56.43229676831154, 55.388326567988244, 56.28683174810102, 57.02272330560992, 43.04390984196817, 25.39709975642543, 6.838375378039576, 1.8649901834226426, 1.0793301222785827, 2.221087707627204, 3.295274376869202, 3.828277169696747, 4.757381004671897, 4.474789923237217, 3.8139958198993438, 1.362331336544406, 0.12201358263771381, 0.05940358379795667, 0.5203921888624469, 8.838873890138442, 35.927683076550885, 44.724068872390255, 26.839649446548957, 26.174360552141746, 35.946949758837306, 25.720771781859863, 5.2281173967546035, 0.08170072605172474, 0.00513712945957518, 0.06100101118546821, 0.0722248696031109, 0.03872190647187733, 0.09222033133189525, 0.0105776249491159, 0.023983577566762126, 0.04831890823439725, 0.020211289764472076, 0.049107760461347724, 0.10498682652870495, 0.02396482373437574, 0.05668220583409552, 0.019812008568776712, 0.041282869454833775, 0.053791667995673996, 0.026243900835153558, 0.01282536235052131, 0.09813990038368972, 0.0030351874480519687, 0.06254933233703337, 0.04166752603205462, 0.05074282957901878, 0.01968785635976782, 0.04653170171584334, 0.05069702135158643, 0.10736117049330667, 0.022861708834346746, 0.0862522459318561, 0.035315481194805716, 0.126185184194436, 0.19020722097446843, 0.20345422950002456, 0.10908181163211984, 0.1708499411301267, 0.171616212915509, 0.1467575177910828, 0.20341237045584187, 0.14872325343951104, 0.15255174719758574, 0.17667786308353947, 0.1283293493813084, 0.12497644300662702, 0.10796604287480155, 0.11001898231165064, 0.12221051319952934, 0.1236698111038535, 0.1038172324338267, 0.16549976692805368, 0.12249778851025528, 0.08187550901164932, 0.1334867452181155, 0.16093924551481203, 0.19956090938179724, 0.16050864281433244, 0.11531823464939672, 0.12620784507523622, 0.20694372935160515, 0.1496484118603891, 0.18618297642998158, 0.13249167361326758, 0.17685205615576238, 0.12678844013041066, 0.13221197491211276, 0.1849135074524149, 0.09928565382236436, 0.1517779371070285, 0.12072792622230707, 0.1742718107397518, 5.430776947929013, 30.402108815408525, 45.18970912502658, 40.6578379292642, 33.32298217281219, 40.82137330885857, 50.019382353751894, 45.12316219268307, 11.450373241978308, 1.3362711091195385, 0.16240091063082218, 3.2341986606197977, 4.353698511277476, 5.691089457081211, 5.606057374708114, 2.2082233140545506, 1.694672903226268, 2.414491936083763, 2.468547590317265, 5.802188631026976, 17.841967613466327, 31.176390570978967, 52.12570690339612, 62.95586124543221, 67.21430009411228, 66.83223770510766, 64.72581509620913, 64.12098169326782, 60.791673891005985, 62.35795867058539, 60.20556980563749, 58.49343953594085, 59.360734416592514, 62.87610769271851, 65.62658348391133, 62.39254613076488, 63.107013702392585, 63.82521929279451, 63.43599465585525, 60.362323407203924, 62.19868298499816, 65.25213833778136, 60.18862516649308, 50.76784903003324, 50.55169897694742, 48.260756308032626, 57.06121352411086, 59.68818956805814, 64.60378231540804, 63.92688320529077, 66.89829041880947, 46.87967800324964, 54.90604369871078, 61.9441839187376, 60.694599151611335, 61.33158422285511, 61.11412409813174, 61.18065141862439, 64.11377629926129, 62.30659131080874, 58.476032057116115, 56.747808302602465, 47.179319627823375, 46.79074218196254, 49.20268604832311, 54.438293210921756, 57.917549302501065, 57.859184434337, 59.46667763494677, 58.0124588935606, 61.82685798214328, 58.672672240964836, 58.68402750261369, 57.02628874009656, 59.55319335383754, 58.19363709419005, 60.075911937221406, 57.026928086434644, 56.42336553142917, 59.440017284885535, 58.83003380990798, 59.84400964552357, 58.862350217757694, 41.077002017728745, 23.495195411866714, 4.891403980793492, 1.8830476725293745, 0.6271366126114323, 2.829384563430663, 4.062571616903428, 5.502836281253446, 11.252269033462772, 9.135408016943163, 9.36012060411515, 5.692071520513104, 3.444789734578902, 0.19480440735576615, 1.4019134448420618, 16.34428018523801, 43.603424179938536, 44.23295282548474, 30.596166118498775, 34.85317330206595, 45.15236031624579, 25.996486948382472, 4.239530082671873, 0.15271860114749403, 0.12349569464042304, 0.1486186058290543, 0.15914626269330903, 0.10720073636020384, 0.24004137834473965, 0.17575348607234417, 0.1593025905951377, 0.20748596638441089, 0.1572621766958506, 0.1402771340743188, 0.18949095940878316, 0.11291536923137405, 0.1401834568429378, 0.15225553164078345, 0.1680428111144612, 0.2077796078857876, 0.10685981957301979, 0.1106237244581984, 0.304727069432697, 0.13166910968720913, 0.14586609788239002, 0.19724963743600155, 0.1819137676108268, 0.13498311411709557, 0.19325369217943764, 0.15468943894149798, 0.25029241618129516, 0.09443440204185825, 0.15179422413629873, 0.1487389429202003], [0.010781640866621128, 0.011035237994585789, 0.05168741215921698, 0.02256347655108379, 0.021646925128035007, 0.03187230093434694, 0.03831930811546984, 0.014411175845100757, 0.017895086127663815, 0.07873302400713006, 0.0319865495417147, 0.03404625353493518, 0.031626547589117, 0.08490146438200628, 0.028264666494402676, 0.03014033701601288, 0.025044887048763134, 0.05138729338444049, 0.04920971910319021, 0.12472432347074633, 0.04457739609924536, 0.03743063463198562, 0.027444144192662452, 0.07198465507357352, 0.026665672457085985, 0.036806108264793316, 0.05731318266161027, 0.019091328590988152, 0.1172872874585371, 0.025456207316188563, 0.04488949265871798, 0.016643794501320492, 0.03490438309287833, 0.029003770886770183, 0.06477583665400743, 0.04245308025049106, 0.04891233143186377, 0.06634496092315643, 0.14366336527370638, 0.11897672583619434, 0.5297564186396138, 18.557502069780906, 39.185309563913655, 36.874837413910896, 24.419988316874353, 25.73409411215013, 37.77310332944317, 33.30524913726315, 13.148014276258408, 1.3123717399374133, 0.14880320237528893, 1.120799258351326, 2.4489340234187345, 1.3644228178647257, 2.50758326342029, 0.6988356394633171, 0.5024807161140827, 1.5895511762749766, 0.5092417791245446, 3.1467758936266748, 12.925597256229771, 23.840715039160944, 38.0610562909034, 57.42291488955098, 63.53473640257313, 62.925278525198664, 61.4960805831417, 59.84953626509636, 59.331300950819454, 57.29146449796615, 55.69698572158814, 54.64026389583465, 53.44308199421052, 53.69080712718349, 56.89357534531624, 59.70598536152994, 57.81356726923297, 63.76250843847952, 61.956084389840406, 62.57419893818518, 59.74196918549077, 55.15502006776872, 48.05889544948455, 45.441078139889626, 45.458536609526604, 48.47369393994732, 52.783845316979196, 61.86916858919206, 57.862279184402965, 66.16608588926255, 40.920754401914536, 52.95943806248327, 61.78774410678495, 58.36639396605953, 61.93261684909944, 59.57865345862604, 59.53994750976563, 56.61780918798139, 55.06233446059689, 50.479307713047156, 49.36695491113971, 47.84573816484021, 44.428349617988836, 46.16081345465876, 51.86119402608564, 53.720358264061716, 56.27159726235175, 57.79587737975582, 58.4603778777584, 58.90609248991936, 58.56623872633904, 58.27249242413429, 59.064826888422814, 57.279356141244214, 56.6457913767907, 57.22762792341171, 58.05547552724039, 54.672792111673665, 55.8660908668272, 58.13755504546627, 53.80707402383128, 39.78540866605697, 16.841516110204882, 3.0887309437797916, 0.45226564450610074, 0.6135595121210622, 1.6045239663893178, 2.4071119966045504, 2.9177361967102176, 1.9127972568235092, 2.2527733493235806, 4.732035138914663, 2.4691945362475614, 0.46766094743244113, 0.05349252981344058, 0.941332559431753, 10.55870573366842, 30.218637989413356, 26.379373035123272, 22.674470832270963, 21.614073745666012, 31.283414402315696, 16.134559877457157, 1.32753660361613, 0.09267270625118287, 0.016100862243723486, 0.05778631473320627, 0.03954779904996676, 0.033279740431856726, 0.05661039275207347, 0.013001664079755787, 0.02180061768740416, 0.07217943292832182, 0.05877723031106496, 0.02444516277811941, 0.04745220998302103, 0.022031516587782293, 0.04040652998693047, 0.08602850995356999, 0.02011463819672504, 0.06401840552327133, 0.0848101007361566, 0.08224971231914337, 0.05129825098500137, 0.007832763038740885, 0.044490219123901865, 0.06765123276460557, 0.07441852406989183, 0.025338151251837134, 0.020786684997860464, 0.06846780588309612, 0.01869166243611084, 0.008049381581405479, 0.018852740083070054, 0.035994939896608555, 0.10871561394343454, 0.01539613125890854, 0.03278833333282702, 0.017884910564809557, 0.034636233167182055, 0.03783202639991238, 0.03026681813231159, 0.04591983878203938, 0.004228260461992074, 0.036481911346556685, 0.0626148596676367, 0.014822731684562902, 0.055316569839393905, 0.04078151087366766, 0.036037748889817346, 0.01174107789167113, 0.01966726966202259, 0.038125380618317474, 0.034417656791065974, 0.037733545797246124, 0.03353732983551679, 0.06661526738635956, 0.04287751211274055, 0.0809702612159233, 0.04908874615906708, 0.01090026958169596, 0.06310752315086222, 0.03412423362474769, 0.03398749842158249, 0.019099037350726225, 0.022026584896769737, 0.03753425951506342, 0.029455711051160773, 0.052994101518584844, 0.03016856544080281, 0.026923219725910216, 0.01704613430305354, 0.08540471520034537, 0.0727945019400889, 0.12159840128715001, 0.049971708457075784, 1.747254726867522, 25.818379963597945, 44.97063690616239, 33.201274948735396, 22.601285288410804, 32.056637117939616, 50.1550571380123, 44.34317927206717, 13.785282738747137, 0.8258020877838136, 0.11009957476128494, 0.1859886505671086, 0.8119293386417051, 3.2514730240068133, 3.3663825354268475, 1.9191359295960397, 1.3328971353269394, 3.492702711974421, 1.6175177981776576, 5.464396072972206, 13.82296592958512, 29.01705126608572, 44.2727570379934, 60.04756889035625, 65.96671181340372, 64.11344289779663, 63.11039086311095, 60.32126011386995, 62.124201097796046, 60.388418935960345, 57.4642409816865, 54.55180660370858, 56.82824434772615, 54.77986105026738, 58.527877946053785, 61.462301131217714, 60.60236069463915, 64.93563444383683, 62.83762924132809, 62.543090620348536, 61.832749382142104, 57.91041058878745, 49.477781480358495, 47.98572755629017, 46.55196397535263, 50.79931820592573, 56.02238947345365, 62.44870270452192, 59.51193786436512, 66.34246703117125, 43.582459111367505, 53.12329507643177, 62.23423142586986, 58.64310149223574, 63.12392696257561, 60.82124856210525, 61.40155538435906, 60.1213800522589, 58.44511985778809, 54.206869448384936, 52.430384851271114, 48.7416349687884, 48.05211759382679, 48.350700178454005, 53.40601951845231, 54.06751940327307, 58.438169417842744, 59.06263036112632, 59.40675558582429, 60.29800045874811, 58.80784888421336, 56.645528577989154, 59.512663502847, 57.42201274441135, 58.135817435479936, 58.287609238778394, 58.15491937821912, 54.90956206475535, 56.548842153241566, 58.19320171110092, 57.622085002160844, 42.50880049120995, 21.45191119563195, 4.933737141470756, 1.079975107023793, 1.1867003479311544, 3.709438914252866, 4.777855286675115, 5.370902457544881, 4.091075726093785, 6.107684393082896, 4.119258936374418, 1.4270700562384822, 0.38780985640421994, 0.01968649655370222, 0.6987918805210822, 8.993941853123328, 37.5108850386835, 40.5517731174346, 26.74808563724641, 21.974106142597815, 35.87003207975818, 24.400882451765, 3.146518978380388, 0.11800875842210748, 0.097166447780065, 0.044155760457919496, 0.06370877959735452, 0.01903341234391255, 0.05105300708824108, 0.02405406531667517, 0.03181792018304189, 0.0629860139451921, 0.05907650255868512, 0.04125816311927573, 0.011781580960227838, 0.039910311855736284, 0.014476870757437523, 0.05741394620629088, 0.03474186137018185, 0.010314184548934142, 0.0869459615299298, 0.07017380708167631, 0.000972089086820732, 0.039573026325313315, 0.03711918541680902, 0.0629834015853703, 0.06300277977941499, 0.037735131599249384, 0.04600523077251931, 0.019220638486947265, 0.009452923606600492, 0.027117074444709767, 0.04044439771302766, 0.0449561269863719, 0.06717301003875271, 0.12835586368436777, 0.176563378904135, 0.10350164251341935, 0.09703174654033878, 0.1805937521520161, 0.12236228287820855, 0.23809272645702287, 0.09452286221447492, 0.09206349781203656, 0.14225126604639715, 0.14944051091949787, 0.17099169803963554, 0.1392833188536667, 0.16236059908424655, 0.09058560695379012, 0.16511319896146176, 0.153033264101513, 0.2185377499629413, 0.11370113029355004, 0.1352641611329971, 0.14165972359478474, 0.11264942946933931, 0.1568218140352157, 0.24044886051166445, 0.087967072463324, 0.12407489541557529, 0.1451653572580507, 0.1269157716043053, 0.19816866715348538, 0.194999928315801, 0.18203605056530048, 0.08030689036053035, 0.15413207933306694, 0.07630227298866357, 0.18114119858270694, 0.14599106214459867, 0.1642934542389647, 0.22643027887228998, 0.376614370052853, 0.20361593533908168, 1.409717613170224, 28.75634308784239, 55.7691220314272, 47.47021828928302, 35.153921035028276, 33.94673316709457, 47.2709148160873, 43.19414054193805, 16.181407686202757, 1.9485967293862376, 0.38038122437654004, 3.3997121405216957, 8.86778764186367, 4.449621544730279, 6.422027061062475, 2.120782406099381, 1.8768289997693033, 4.001978597333355, 1.221537001190647, 3.9882640300258516, 14.667897416699319, 26.206584784292406, 40.61149512567828, 61.24551957653415, 67.48270004026352, 67.90835565136325, 66.77259414426743, 63.156168845392045, 65.21657812979915, 63.36356809062343, 59.33763165627757, 57.72382343969038, 58.43774580186414, 55.15624384726248, 62.60000813391901, 65.77077373381584, 61.01528036978937, 68.01647186279297, 64.81101682109218, 66.41870221784039, 64.57693369157853, 60.18955084585375, 52.07652430380545, 49.9853910938386, 49.753186779637495, 52.476115765110144, 58.52708954964915, 66.98530427871212, 61.985733585972945, 69.02591736085954, 47.68237144716325, 53.62264417832898, 62.14325204972298, 61.06223898549234, 65.31564151087116, 64.80601972149265, 64.49686634925105, 61.80214312768752, 59.731704342749815, 55.34454114975468, 53.05330430307696, 51.67912152505691, 49.89956178972798, 49.5299215470591, 55.88968392341368, 57.32168636014385, 60.025403576512495, 61.27832235828523, 61.09772074607111, 60.267923724266794, 60.42617567123906, 56.88911168806015, 59.98778020181964, 57.18707846057031, 57.82103938441123, 60.02298739648635, 62.142051804450254, 56.758967445742705, 59.25264958412417, 61.920375131791644, 58.32374995754611, 42.201651450126406, 19.661455115964337, 4.317256260302759, 1.1855506031743943, 1.5844467017919788, 3.879716603025314, 6.516415957481631, 8.417331864756923, 6.503421145100748, 8.376125404911658, 14.073868182397659, 9.054663085168409, 2.670698949406224, 0.1502321095716569, 1.424374407337558, 14.75130073485836, 38.65962174630935, 34.90703136690202, 32.5034676444146, 32.36040115356445, 44.50557324194139, 24.969784982742805, 2.2922380316642026, 0.19338794142728855, 0.19130004539845452, 0.20372248284759062, 0.15724293256719268, 0.16291274929479246, 0.10710883645280715, 0.13204530482330631, 0.17209579927786706, 0.1760106005014912, 0.2192667898752036, 0.15224132837066728, 0.15959100737687082, 0.12986963044010824, 0.14198569400656608, 0.15084677255682408, 0.12901530450870916, 0.14792659860705176, 0.31353913367755953, 0.21147006792166542, 0.14635049527691257, 0.1064996203527816, 0.17031358765257945, 0.12739157349231744, 0.18872615851221547, 0.10572023314213562, 0.11595629395977144, 0.1223623441652425, 0.09243803053733804, 0.0966180743829858, 0.10133844004162859, 0.13563631132485407, 0.2175741798935398], [0.03857011764100002, 0.06037617455266657, 0.02699337039713658, 0.04385315955826833, 0.02859217482769201, 0.013548026496033757, 0.03321160457187122, 0.08526622948627319, 0.019565425933368748, 0.040112773572365125, 0.013408771821207578, 0.06971989232566088, 0.009675145603626246, 0.025935749628490982, 0.08016178564679238, 0.08992058134848073, 0.015943639934243217, 0.09485952721367921, 0.03204650932832832, 0.0046304973206603, 0.03284377511590719, 0.07092363862020355, 0.024275801805478912, 0.010782688491857581, 0.05367676629835079, 0.048081742734798504, 0.0441886754255862, 0.04937895558654301, 0.014677789764508847, 0.013382524691311824, 0.026154710963789015, 0.021844700301787066, 0.006182670936874685, 0.06008113111038843, 0.08591054007411005, 0.025043686205941825, 0.01565216071603279, 0.0136456462073951, 0.09381359503153833, 0.01762518186062094, 0.0631058186052307, 0.8618510598617216, 15.443454923168307, 35.64859467168009, 32.10083438504127, 25.059497433324015, 26.42980490961383, 31.837755134028775, 32.35470194970408, 20.566112533692394, 2.378641963005066, 0.28471449329968423, 0.49748707923196983, 4.934981023111652, 2.8797316166662403, 1.321072660146221, 0.21231958282090005, 2.8434715107564004, 1.4642157597887901, 0.6626188021994407, 0.18949210854066958, 3.6227390891121285, 14.09531178012971, 33.474632770784446, 52.302543040244814, 63.29605625521753, 67.18051279744795, 63.07153194181381, 63.19898543819305, 60.28090284716699, 60.855910547318004, 60.766966881290564, 58.95809527366393, 57.66364643650671, 58.76639335386215, 58.69000127238613, 60.7895322768919, 65.36476135253906, 63.48242375158495, 61.81978987109277, 61.315859440834295, 55.01812934875489, 51.25357574032199, 48.931414927205736, 49.318592086915054, 52.4425285093246, 55.41867786838163, 63.4136293011327, 59.790551662445075, 66.54782664391303, 42.34196639830067, 54.352577655546135, 62.62967694190241, 59.628832340240486, 63.101898931687884, 56.0722977115262, 56.621641343639745, 51.351513401154556, 52.49393509280298, 50.386104353012584, 53.976794981187396, 49.15906929200696, 50.4984998703003, 49.64263869870094, 54.38401937484742, 56.98168354649698, 57.93764360489384, 58.698975655340384, 59.5848233469071, 59.782801058984575, 59.050898551940925, 58.755952004463445, 60.21456380044261, 57.28520439517114, 56.661233748159106, 58.05554220753332, 57.345620662935325, 55.73559361119425, 55.935203029263405, 48.14810975905388, 34.9198849739567, 13.936276339715528, 2.2724268753682417, 0.39008225704873767, 0.3047063544152245, 0.6296121797734692, 4.5440006352240045, 3.001781067540569, 2.6416503662063233, 3.080922240211118, 4.025718252505026, 1.1906803279153764, 0.4938586723179587, 0.15451677804512365, 1.0440374934865584, 13.092195026336178, 39.066826528118504, 44.62100859611265, 33.36043688558763, 20.66706257481729, 27.058052901298772, 20.844128170321067, 1.4015446194717962, 0.1163384109555233, 0.06315980865169438, 0.03505095103455167, 0.04815625627675364, 0.01670620576929181, 0.0629726457109134, 0.056276432043241884, 0.04780662140899128, 0.07314966796266456, 0.049021648348218975, 0.0494348110571023, 0.028960249431791808, 0.011791445299862854, 0.03326841382189624, 0.02618315963885717, 0.029261210903285012, 0.033248507027183814, 0.11271694479810615, 0.03774355473597685, 0.07401638919667852, 0.07081522185715937, 0.0199191574563062, 0.039559309521029075, 0.03239562517152198, 0.015363810009383147, 0.006916955199783609, 0.03608872054985935, 0.022654474389949636, 0.11759460362936221, 0.01191449529987069, 0.03253772682059677, 0.020099525197198796, 0.04776789183397928, 0.07365730846480978, 0.04661455412485427, 0.0659448255394255, 0.044084805394372636, 0.06145752680998656, 0.06670131438201474, 0.0681911102466045, 0.049204509705305106, 0.049582700500445026, 0.04638290828874996, 0.004023867246184138, 0.06153163049490221, 0.053004730988534234, 0.014301151255025499, 0.0644805404027143, 0.0489637014576264, 0.026118896353328903, 0.02707550268349869, 0.07784206375119188, 0.031123618527706114, 0.013112546688306236, 0.07604411667993954, 0.07365197649285679, 0.058435604892550945, 0.0352294456904694, 0.07885751329482564, 0.05176547651870116, 0.027838411342893398, 0.046863590156839746, 0.022121637255974838, 0.056812157328691215, 0.09604596758201238, 0.05557034412519105, 0.03560697764999444, 0.053806943788884155, 0.10709573634930196, 0.048136349482041214, 0.04525448375892255, 0.07235201721590373, 0.03058000253663669, 0.05418970812893203, 2.9328378121699057, 24.053752691515033, 44.17116765053042, 31.07454230708461, 19.778985015807613, 25.92402704300419, 40.654935375336684, 38.489920400804095, 16.786524480389012, 1.96710100097041, 0.21683185601667052, 0.2889261382722086, 0.3275532107199392, 2.30486168976753, 1.4160896260892193, 1.9449461059224222, 3.866432760992358, 1.7094845084413406, 2.1884859473474565, 1.4296486469045764, 5.117516854116994, 17.50768361553069, 37.057878740372196, 56.893002679271085, 63.26210421900596, 67.68977765114077, 65.62773273837182, 65.34960531419324, 61.50761235144831, 61.05830877057968, 61.293231287310206, 59.88286464445053, 58.437467313581905, 59.857318247518236, 59.93132945029967, 60.79726326850153, 64.67908005560598, 63.143295626486506, 61.51824981935563, 63.248164115413545, 58.126513573431204, 53.64764536580732, 51.14697748614896, 50.79420343522103, 53.32550894829535, 55.93971767733174, 64.28694501999887, 61.16096112035937, 66.41043386151715, 45.707340394296956, 54.52646417002524, 62.782861186612045, 60.340640544891365, 63.70630087391023, 59.261612199967914, 59.63610049216979, 54.93070363998414, 54.62846540635633, 53.131159428627264, 53.90800837547549, 50.674845710877456, 51.46423447516657, 52.15218682442942, 54.988754718534416, 58.93684779444049, 59.07815117989818, 59.57878289684173, 60.096680887283824, 59.29280288757817, 56.975560726657996, 60.44408913581603, 59.11064409440564, 57.967202586512414, 56.514258615432254, 58.89867921029368, 59.05359714261947, 58.99858590095275, 57.7245294663214, 51.715779996687374, 37.97962004138578, 18.20076446379385, 4.206996963870141, 0.8070081736772292, 1.3382280041133205, 2.681189573580219, 7.391617355808136, 9.184397439802847, 5.0214403579311995, 6.004572635696781, 4.790497576036762, 0.3025665482686412, 0.4109638220360203, 0.21484477715867184, 0.44255554135287967, 9.961366999533869, 38.47798070599956, 44.792631903002345, 24.758651641107377, 22.33316775291197, 30.105381511872817, 27.66401202447953, 2.9198591795659836, 0.1789043750613928, 0.05374610874681704, 0.04115039753096719, 0.012493233549438659, 0.014015847663094681, 0.03953446145920504, 0.02257753617971415, 0.02292776859605745, 0.03667384701510591, 0.07510463241487741, 0.03933868385971554, 0.052569462812595794, 0.029063332307663177, 0.034631004617098844, 0.02765567447509497, 0.03656435389852813, 0.05952634938782262, 0.051352738988615816, 0.04615063043010812, 0.03845255761857956, 0.032542832796612096, 0.01434103379236354, 0.020350296418332768, 0.02115046376392486, 0.05261939642350039, 0.07858699998788296, 0.032680935466722134, 0.04249582412622629, 0.053140060420358376, 0.013218948640109552, 0.04798189849562703, 0.0032381294060483457, 0.053155022117519574, 0.1718762231570098, 0.14446064829826355, 0.1319851362777333, 0.1511671198832412, 0.25731903590982963, 0.08753833901737967, 0.12695815158827653, 0.20520821844618167, 0.09116486901597631, 0.08641918415143605, 0.09468369471329836, 0.10262563629376312, 0.13055328730373614, 0.13778488151729107, 0.2085672841677743, 0.14440213450260703, 0.05773475318546257, 0.1808894161255129, 0.10154329195258119, 0.09476020391429625, 0.14215809443304617, 0.15151408110414782, 0.16810786730099112, 0.13558905902168444, 0.19160569915848394, 0.17889979385560562, 0.14107835479080677, 0.17580622356505166, 0.16785230036945115, 0.12180631754979973, 0.16587469035819655, 0.14960476017046362, 0.08510712834615862, 0.12688939519707235, 0.2046209201216698, 0.16385310690008825, 0.1687854567482587, 0.10538961257665388, 0.16985568157847852, 0.1702992464866369, 0.29089152152019165, 2.194717367810588, 25.83306923989327, 51.54519219552317, 46.24136324851744, 33.588734519097116, 34.42827470840947, 38.955948968087476, 41.03114951041437, 26.85038889608076, 3.2972539480655425, 0.5171759066081817, 1.2418976570329359, 10.12388942703124, 8.553808773717574, 3.0967163991543556, 2.974209992154952, 5.6010504691831535, 3.6181330007891503, 1.0708629508172314, 0.430152332710643, 5.225735047171193, 16.01463831240131, 35.89453120385447, 55.8321858990577, 66.7480714859501, 70.74495100205945, 67.64503125221499, 67.61329927752095, 64.78416819726267, 63.98163557052613, 65.94389930848153, 65.24486626348188, 62.42439185419391, 64.34512161439466, 62.29716585528467, 63.44259208248508, 67.05477729920419, 66.78691864013672, 63.006483354876124, 67.0117175194525, 59.9703452664037, 57.320321375323886, 54.402034821048865, 54.61519602806338, 56.81284120005947, 59.89432973246421, 66.7451532425419, 64.02458552391299, 66.69839859008789, 50.549553440463164, 56.95032419696931, 62.60755477413055, 62.219655898309526, 65.52269950989755, 59.14536491517098, 60.844841618691724, 55.57504707767118, 56.85419474878619, 54.649771721132346, 57.290264252693426, 52.91208720976307, 54.74406157770465, 55.708113485767, 58.148635741203066, 61.82678345711001, 61.813247357645345, 60.91935488485522, 62.189045721484774, 60.396193073641875, 57.62526212200042, 60.48938466656593, 59.84026770437918, 59.473784969699004, 59.02000596446376, 61.07561426777994, 58.0110272284477, 59.99848435001989, 59.01705634209418, 51.92796845589915, 36.26098255957327, 16.187448136268124, 3.7864088098849025, 1.3506215906912282, 1.6901854666010028, 1.7876357729396515, 9.472803435017987, 6.9138010855643985, 5.575126053825502, 9.56916626422636, 11.64914817579331, 5.092401427607383, 2.062888222355997, 0.4706562286423099, 2.0086658673901714, 17.2481462647838, 48.133534231493556, 53.49070349047261, 41.251143486269065, 31.968556373350083, 39.54484578101866, 30.841173048942323, 2.4410218673367656, 0.37630349157317994, 0.20249069007414006, 0.13089102482603443, 0.16174190647659764, 0.13076685729526705, 0.1429246420100812, 0.38419910015598424, 0.1945213685112615, 0.15588219187432723, 0.1612367480993271, 0.1843332418150479, 0.17735837898667783, 0.060765059935229446, 0.21044795341309042, 0.2031836778886857, 0.12388362624352017, 0.18074513112585391, 0.1504229880388706, 0.15900495011479626, 0.15566679859353652, 0.16458836744629568, 0.13742238403328005, 0.10961068043064688, 0.15433797312359657, 0.09292216746196633, 0.1378849479219606, 0.17663392028020275, 0.14301683303088913, 0.17245953782431542, 0.08810662303961093, 0.11514264729715164, 0.03581980453623879, 0.1519195407989525], [0.031719334243286046, 0.03870960309981339, 0.04030798426679066, 0.053588244838700186, 0.05671746503081053, 0.04699902684097329, 0.12033484650835877, 0.030599164310842756, 0.08502783058511634, 0.08204257746617641, 0.08802586971151252, 0.02025667281310645, 0.03719300181875306, 0.027340006030675386, 0.025739920318066597, 0.06572069885629801, 0.07267293144738482, 0.0343857875334159, 0.0256662379815093, 0.06052245138092868, 0.09338128395498761, 0.02008423408223016, 0.05551835739864938, 0.04924750255961572, 0.006782753353623013, 0.05051720902443894, 0.03358507626539758, 0.0019927589211522815, 0.05411484218653172, 0.06274554660663971, 0.025514954768662012, 0.08536104052778214, 0.010201402042331475, 0.07701481136703685, 0.0823008869924853, 0.11111596659306558, 0.045803397247988376, 0.046480101863703424, 0.06367820119785686, 0.0113324599993986, 0.06870912357924447, 0.07869850408526198, 0.7144499822489677, 14.310635193701714, 36.26519518513834, 39.354787334319084, 23.780708659079767, 26.652107200314923, 44.44298398110175, 41.44258652963946, 23.634061044262303, 6.433163160277951, 0.37209469644773396, 0.7918582640347943, 1.0847922678916686, 1.080557456420314, 1.323940035316252, 3.2702508809105044, 0.988451379441446, 3.593155347531842, 1.3865221868599615, 0.03895087483068628, 0.5113329233661775, 5.5129491321502195, 21.021942938527754, 45.290788604367165, 60.9766254117412, 67.87383879384687, 63.68178213796308, 64.37005612158006, 61.42153986038701, 60.85458086382959, 59.42124089887066, 60.49988485151722, 58.21737527847291, 60.034534854273645, 62.29764438444569, 66.83922736875473, 65.0018754313069, 66.02105232977098, 62.257840171937026, 60.05337399821128, 56.219453273280976, 55.517984436404326, 54.156329708714644, 56.995906060741795, 56.399662648477864, 64.60859898597964, 58.34821378031085, 67.58851774277227, 29.992903624811483, 47.191620180683756, 68.15932458446872, 58.81506212296025, 63.32219493004584, 58.37532912531207, 57.645368191503714, 55.981773330319314, 56.91188889165079, 55.29637052166847, 54.45471225246307, 55.491210337608095, 54.5984749640188, 54.2302389298716, 56.83014669725972, 59.35158744935067, 58.996059894561775, 58.2011955015121, 59.57316606275497, 59.92249235030144, 58.723804258531146, 61.193807048182336, 59.93932716308102, 58.82378155185331, 58.15651970524942, 55.987582360544515, 52.36992151506486, 47.271707134862105, 38.568422717432824, 24.995141144721742, 11.196127168593868, 1.9453322142362597, 0.4421337639852878, 0.42072074848317337, 0.5691237158833012, 4.245174373349836, 5.959613938485423, 15.591412609623326, 5.489710559768062, 4.1271811435299535, 4.406799558670291, 0.6593746956317657, 0.02669138811348427, 1.6271266245072888, 13.445463295905823, 35.32870577227685, 30.801290389030214, 36.94269834026214, 49.896278765893754, 31.693825721740726, 23.504791490493282, 3.093745448896962, 0.01861701482876895, 0.10615403042925943, 0.09905601896706129, 0.05157149539539411, 0.022603533373424606, 0.09218676135905328, 0.08080120859367233, 0.02581862436096755, 0.05086055814078258, 0.028152206702338114, 0.017434219123735543, 0.027235576755277095, 0.0253129641961066, 0.027131865687307813, 0.013545868043307097, 0.01791230778420164, 0.01970443450244925, 0.02534959660542588, 0.062218849667378014, 0.029451396060927264, 0.01970730541694549, 0.04386791058125035, 0.06502292299222562, 0.029351948272256605, 0.030290591755821824, 0.11983187148167242, 0.01621490209213188, 0.07356597546247706, 0.04231058023569565, 0.06843335490914122, 0.05352455611911513, 0.05952358764085559, 0.04264293982076549, 0.03119236342759142, 0.04422845071061485, 0.07165756617342273, 0.06183788180351258, 0.05379792310357575, 0.04270469033790212, 0.035240848909222314, 0.057498958983248284, 0.062068347864213495, 0.06545691946220976, 0.09888115939834426, 0.01860434373450135, 0.03725305928157703, 0.03696836568715592, 0.02160276398963986, 0.026807944560723922, 0.04366646010068156, 0.047202752602677193, 0.03338600065739405, 0.0287567918008614, 0.017586549961819284, 0.05657670786604286, 0.05290952158130465, 0.053851369227613174, 0.04615828364847168, 0.013764273007250121, 0.01902473065251064, 0.02105967468401838, 0.030080930727924553, 0.10287482937377307, 0.009273123728381771, 0.029858108309488145, 0.032772494464992516, 0.017296315636485815, 0.013958582590754717, 0.09903346533857046, 0.07698549318217462, 0.03317925267882886, 0.06560488934478452, 0.04403593664568278, 0.013144031944384259, 0.04170330999899776, 0.04525314693549468, 1.9369220397164746, 21.909196799801244, 44.50323550931869, 35.48421206012849, 18.308931666035807, 20.571472452532863, 50.88131927674817, 55.779367262317294, 21.992788391728556, 4.352006498844394, 0.15232961234306136, 0.5566960537145215, 0.03612621672331326, 0.6711070564004683, 1.2825943313298689, 3.8155360856363854, 3.121582510009889, 2.3626678653301734, 2.3391177096674522, 0.3417316595873525, 1.8043752230944174, 8.189121013687503, 25.757491050227998, 50.47715040945238, 63.545872011492335, 69.57298601827314, 67.19822622114613, 66.43301102422899, 61.79781675338746, 63.27738185082713, 61.68860620067966, 62.160769354912546, 60.77749060046289, 63.71406716685142, 63.48380050351543, 65.84229423153785, 67.86648042740362, 66.21714730416575, 62.64742958930231, 60.78822612762452, 56.06259376771989, 55.93774472513507, 56.516827767895116, 58.60156751448109, 60.35312937152002, 64.68389280380742, 60.95127513331752, 69.2559329925045, 36.68084090755832, 52.95179336301742, 66.88363644384569, 61.464419211110766, 65.20647410423526, 60.112621399664114, 59.86147988227106, 57.216774725144916, 57.942381828062004, 58.39680017963533, 57.14223400239022, 56.317755714539565, 57.35168856959189, 56.768455659189534, 58.39274837124733, 60.025795813529726, 60.16220800338253, 59.946854191441695, 61.5647691295993, 60.906132575004335, 59.549643608831595, 58.90827725010534, 60.17104510338076, 58.58539558226063, 57.92104805669477, 56.76731424946939, 55.76063010000414, 49.693335333178126, 44.71298033191312, 29.978071182004868, 15.53157194968193, 3.558703209123304, 1.0123781439277435, 1.1569131333981792, 2.401554978662922, 6.933574734195587, 7.788983852632585, 10.568852905304203, 9.380816990329373, 1.2790578243232544, 0.8099096244381321, 0.3896435338162607, 0.053169631414235606, 0.5985772225164598, 12.9103196244086, 44.04790716786539, 43.97205637347314, 43.79225492477418, 50.67705008291429, 34.063980656285445, 30.41539780555233, 5.884973195291335, 0.035735607642920754, 0.04732925670161363, 0.06805512197916547, 0.03797081471871465, 0.02086957762648742, 0.06636490219182546, 0.037288690030935316, 0.07332593713316225, 0.037625784039377205, 0.042546497011977824, 0.045251522829095205, 0.04334341614477096, 0.078581101110866, 0.06634493027963946, 0.025118218900095073, 0.019424117185295593, 0.025280600811745373, 0.04502026769783228, 0.09991651190625084, 0.031889038040272655, 0.02713256474253872, 0.031745921324698195, 0.046167036203006585, 0.07466718854923403, 0.04503766555459269, 0.03516180395719505, 0.029838031060212565, 0.057776604568766016, 0.035538769011656125, 0.004756987055448155, 0.025487042355140852, 0.0685881812786383, 0.03741878708223662, 0.038438775696821754, 0.17009315351324697, 0.09505144756046996, 0.14152766535839728, 0.21634447087924327, 0.15915593072291345, 0.1499829471351639, 0.23878361519065597, 0.152416241565539, 0.15851381114654003, 0.298387783789827, 0.17176774510693166, 0.13552208761534384, 0.17192889936268332, 0.09132702684690876, 0.12539808247839251, 0.1685040420101535, 0.2016112824241, 0.09925658078563791, 0.09692406522170191, 0.1387616436207487, 0.1319155142071747, 0.17213416496111503, 0.21212698831673593, 0.11715951165364635, 0.08730511120971172, 0.12215233648255949, 0.14213583191796658, 0.13826218493763479, 0.201433458095116, 0.1392667407109853, 0.12658433132474461, 0.16417789753646622, 0.12407820491540818, 0.10045176987806637, 0.15637798865716304, 0.32030874622925637, 0.16761484375644117, 0.14740532173985435, 0.2677814374046941, 0.12399372073911852, 0.19911472445293782, 0.23415305801937658, 1.6467594355344775, 22.728950592779345, 50.534773949653875, 52.02547857838293, 33.586792945861816, 38.71799053684358, 53.19394088560536, 52.6683864285869, 29.451318440898774, 8.526013878084, 0.586681102793063, 2.5276537864438953, 2.367024883147209, 4.111740488198496, 3.6328208061956593, 10.77893210995582, 3.9312840036807524, 7.510110687824988, 4.937276590254999, 0.16873918503763216, 1.1158679810262497, 7.093630971447115, 23.62038177828635, 48.14492087210379, 62.584985456159046, 72.08756262256254, 68.2958544454267, 69.42737194799608, 64.31366812798285, 66.57551857732958, 63.31587599169824, 65.22079467773438, 63.46228238075011, 65.72750214607485, 68.78410323973625, 68.32850425474106, 67.90471569184335, 69.16440840690368, 67.34291461206251, 64.06999088102772, 59.45473794014224, 59.13138558787685, 60.22150639564761, 61.67561923303912, 64.03253616825228, 68.70310629567793, 63.12118522582516, 69.91697003764492, 37.04212257939, 52.12042347077401, 68.06552502416795, 63.028538842355054, 65.91907070529076, 63.77641716311055, 62.465949366169596, 62.021387930839296, 61.173999078812145, 61.57757174584174, 59.10491351158389, 60.48186940531577, 59.56018693985478, 60.277710037846724, 60.62294529330347, 62.06944088782034, 63.54334208273119, 61.81790713341006, 63.66712031825897, 60.931588757422666, 57.9957966650686, 61.25365849464171, 62.01774797131939, 59.77168506191623, 59.54086142201578, 58.38939474475, 56.12468096517748, 48.81368890885384, 41.94055103486584, 27.290827920359952, 13.217397082236506, 2.9219409775349403, 1.0236916078194496, 0.9827869866163501, 3.1061906391574494, 9.57898787913784, 12.956734991842701, 24.162937748816706, 12.88037036695788, 10.177537645063094, 8.927895022976784, 1.9534339924012463, 0.2608560332127156, 2.460358661990012, 18.249395970375307, 45.991182711816606, 41.19666960931594, 45.16939909227433, 57.15973169572892, 44.27443581242716, 33.93248711862872, 4.988023725248152, 0.13077716883872786, 0.1631429893595557, 0.20238401999156322, 0.13287638764708273, 0.10432373912584397, 0.14760586823667252, 0.13460816004343573, 0.13232092793670394, 0.2010287798099941, 0.22572681097494018, 0.16432437354758864, 0.12524923159470483, 0.1995577530995492, 0.14502367695733426, 0.08732336708494733, 0.12239228288132338, 0.10278721189787311, 0.09982445112039005, 0.20419848391846304, 0.08529757780413474, 0.08824376809981563, 0.16012972040522486, 0.21821147311599026, 0.11655104631978659, 0.14450705790471646, 0.14824265584109292, 0.20046205860712837, 0.1925603826079638, 0.15992952630885188, 0.19341795675216183, 0.16444251962727116, 0.225046141854217, 0.1619275295806508, 0.164221779052769], [0.025675999856884443, 0.08744024911955481, 0.033701184551201524, 0.01282919949341205, 0.08932673297221623, 0.014151698034707338, 0.10999179385121792, 0.03745034990471698, 0.04860572389236862, 0.003084870165161368, 0.06150977400642249, 0.04440089327193076, 0.08566252676950348, 0.008821991786751296, 0.07167523982183588, 0.028198583750054244, 0.01686134815005766, 0.016154344756937316, 0.052860591545580864, 0.011745890839055423, 0.05264366991938122, 0.0497679865258115, 0.03263515405236714, 0.08010430606983363, 0.05939205417469625, 0.054927627000236706, 0.021747951057829687, 0.07837323847437098, 0.07066844707174648, 0.010356056999655501, 0.04650193919998504, 0.024500596900320342, 0.03749320869364085, 0.03329316612272974, 0.033857045139396386, 0.046692181814221606, 0.050425979443976, 0.02376543211510345, 0.0623180159187365, 0.01409109473423732, 0.042930724579961076, 0.04082261915168455, 0.07272345494599113, 0.7123624232988204, 11.616350297004947, 39.46914403669296, 35.39827292965305, 29.123437712269446, 15.437034983788768, 23.03113587440983, 40.32967282879738, 27.004149729205718, 8.831489047696515, 1.4229314654104173, 0.3780748400717013, 0.6392388406299776, 0.43198938090955064, 1.1666317860926352, 1.0227362655343548, 2.488755886593173, 2.1747642707440162, 0.7213401157529123, 0.45120081293486786, 0.11819890144491389, 2.0855624637296124, 11.392852663993837, 30.942993856245476, 48.719136253479995, 59.81871820265248, 65.70501519787696, 65.5780480753991, 65.62918401533558, 66.22800442480272, 62.81211422335718, 60.02899254522016, 60.25445430509506, 60.36589276406073, 62.868564974877145, 60.34432757285334, 62.86972991881832, 64.24981194157755, 63.305995541234175, 63.06733500572943, 61.96942437079645, 61.76700653568391, 62.93981482905727, 60.74728050539571, 62.59302631501229, 64.17061928779849, 62.169418181142504, 31.903013567770685, 48.428539614523615, 66.5234608804026, 63.41518255972094, 62.6392710593439, 59.452886581420906, 60.49349531050652, 58.54236325910015, 59.00847811852733, 57.4096651231089, 60.13981126969861, 59.81094406497095, 60.104615842142415, 58.65000486373902, 58.27026844024659, 59.2018235114313, 60.35270183317123, 60.52454871516074, 62.03236272258144, 62.172924780076556, 63.292588879985196, 59.758945203596554, 58.53159635297714, 51.33268602432744, 44.41950075088009, 37.96973566855154, 32.01868034178211, 22.937687366239487, 13.551017219020476, 5.2711051029543725, 1.0110374900602526, 0.2350861684329087, 0.5688655748963356, 1.0555014783336272, 2.7464024097688737, 5.980203930408725, 7.504396284780196, 8.35212932478997, 16.149077550057445, 2.6847091653654656, 0.5836292536508653, 0.38078700582827296, 3.310686349868775, 17.907139755064442, 36.38835760854906, 23.32047147135581, 14.106214008023663, 16.714131255303663, 27.16698692690942, 26.343506882267615, 4.95664329298081, 0.19643718587054362, 0.02755235602718688, 0.009967868757103721, 0.04227145229496303, 0.07356383041628907, 0.025601492060588735, 0.03488352634913979, 0.05583106682846143, 0.07153697627326173, 0.04554940079669318, 0.028190959259987842, 0.09925184636226586, 0.1098593295882306, 0.057756015955800974, 0.031925559366842916, 0.08432835400585206, 0.030957528750502297, 0.03649367079619439, 0.04511075034256905, 0.03410973158034106, 0.02130690083328274, 0.016988020788337437, 0.040929940408997, 0.04936407049817424, 0.032438430334291155, 0.07899103475914848, 0.024525697771159392, 0.03442092032562341, 0.05406137691029618, 0.021880756229943326, 0.046370378920748356, 0.07067636842088354, 0.009250087464498657, 0.019367966770885453, 0.03894642385984621, 0.05113664090693478, 0.043783751992328514, 0.04653372035752382, 0.008012949312556415, 0.058484910311357635, 0.017401440136675394, 0.023154373573619994, 0.10757604283430885, 0.06400789862738983, 0.015181650580357642, 0.04504438414568863, 0.025538697748655276, 0.02167311767416616, 0.026687053971052654, 0.06900508632703174, 0.04868157808819125, 0.0655769118137898, 0.019186899974761952, 0.07965547813763542, 0.028681780301755475, 0.011184886567324642, 0.06933633508461137, 0.008614875128372543, 0.08063505944465438, 0.03551474066391107, 0.07090545169288112, 0.023816530179652958, 0.030137263088216706, 0.036335128900264545, 0.014358115637855185, 0.03635199049547796, 0.011837884592222831, 0.019224656618110115, 0.010503209083371106, 0.03680927603836021, 0.02608119525135525, 0.125050462421871, 0.0428645997007768, 0.044340989026691646, 0.06247864157382039, 0.061807023781922564, 0.04307361529959787, 0.012711437415301561, 1.799191565763566, 20.300999533745554, 47.19645646310622, 35.96985640064363, 24.02358574251975, 20.510426644356023, 35.185386288550596, 59.23099417840282, 36.22916821510562, 8.575150389825145, 0.4176189504083126, 0.22550542688658162, 0.1674039857161622, 0.5114140061120833, 2.367794157997255, 1.715080382362489, 2.4163658484335873, 5.18123967993644, 2.6306743487235043, 1.1116829346264563, 0.6724325723705754, 3.6304683646848126, 16.626144647598267, 36.77807646413004, 54.2627828351913, 61.04420392744003, 68.75000999819848, 66.49041883407101, 67.23660269091206, 67.22568281235235, 65.80505917149206, 63.18801456882108, 63.14167568760534, 62.81710347821636, 62.98245883757069, 60.73816883948542, 65.19753502261254, 65.5225936059029, 63.65279974475984, 63.0627066089261, 63.62831238777407, 62.899281055696555, 63.474579011240316, 63.14343290944254, 66.24862040242841, 65.2300593160814, 65.31508453430669, 31.067240815008844, 48.63524852260467, 66.62654861327141, 65.37618721685102, 63.78824310918009, 61.02587861399497, 61.27485890542308, 61.752933071505645, 59.35170512045584, 59.59245235689225, 61.398507702735166, 60.43474605006557, 60.20053348233623, 60.281840293638176, 60.50134005085115, 62.16282859925301, 60.7930741771575, 60.51363275897119, 60.11845788648052, 62.35249873130553, 62.066954105131096, 62.453240886811294, 59.06192041212513, 54.330706519465295, 48.85435604280042, 43.71036368031656, 37.18867409613825, 29.149884293156287, 17.61497416803914, 9.075920370317275, 2.955647865610738, 0.9057695322459745, 1.76489926393955, 3.34772847833172, 4.392444664432157, 8.177854495663798, 8.916751569317235, 5.760327625659205, 6.2736531130729185, 1.7938305437564852, 0.3573294855173557, 0.2691578216129734, 2.1313875144527805, 21.29769144519683, 43.84894886324483, 32.369187262750444, 18.271722101396133, 20.770924975795133, 33.74734732412523, 33.23248917056669, 8.769193964619792, 0.2577682392251107, 0.06912287234538986, 0.1602311198028826, 0.06603214424103498, 0.03345547717124705, 0.07259987730292544, 0.030616035482155222, 0.03299398963610011, 0.01786773295832738, 0.06183294436684059, 0.02779738350410856, 0.07561410386716166, 0.13670492737043288, 0.10511901500003953, 0.04653708731395103, 0.07889466855915324, 0.037658112949781844, 0.021709761574804302, 0.05008130882596297, 0.043031059115404086, 0.036412787233148856, 0.050956296148679914, 0.07964431623657865, 0.06111705435379859, 0.06118060517755728, 0.10418758231906161, 0.012871219416058833, 0.07086851859405156, 0.03737640709826543, 0.05101758701306197, 0.060120159459690896, 0.03210325346087977, 0.056617751026586186, 0.05901812282841533, 0.0697170501394618, 0.16900078874201546, 0.12104853401861845, 0.16856404201638314, 0.1215006637897703, 0.18922189400801737, 0.1452745707525361, 0.21555972105312735, 0.18176306279436236, 0.13598828276078548, 0.0812610911746179, 0.10801344839555603, 0.15382607317259236, 0.13078240888012996, 0.1600632086516388, 0.22325194861379363, 0.15710207964143447, 0.16929531890538432, 0.11372665634318707, 0.18066893602090497, 0.1199903827340853, 0.18226429880146058, 0.173259609408917, 0.12939427288309222, 0.13743969762036878, 0.1407775427064588, 0.1550813082365259, 0.13629859433539454, 0.11930008388815388, 0.17527426743218977, 0.17518048294849936, 0.16403888322172627, 0.08257039672424717, 0.13517586183884453, 0.1595355426111529, 0.10935541227339737, 0.13723317563774126, 0.24606846783670688, 0.17787415534257892, 0.09120653653817792, 0.1411080483587519, 0.17544145846078474, 0.14380610277575834, 0.13356782796402134, 1.3471142563127703, 19.44741137566105, 53.3500982869056, 48.03404331207276, 41.657450045308764, 24.59617137908936, 32.541447954793135, 51.884010453378, 34.08050560182141, 12.19628155231476, 1.8578471796166514, 0.9682629401645354, 1.7707917671049795, 2.3472911936621514, 6.281006086257197, 5.505463778972627, 7.494238816922711, 7.881928336235785, 2.1534101520815203, 0.703515088365924, 0.2546501234774628, 2.939928721997046, 13.335985041433766, 35.195423633821555, 50.14139160033196, 62.23488253931846, 69.07496267749418, 68.74621314387169, 68.57626468904557, 71.08211794207173, 67.69309597630655, 65.84416912448022, 64.99295203916489, 65.2433757628164, 64.59487461274671, 62.853569753708385, 64.89876808658724, 68.78968869486164, 66.56857598212459, 65.7782340818836, 66.44332685778218, 66.68591760819959, 66.52321769345191, 67.59758626261066, 67.42042064666748, 69.9751623215214, 63.005914611201135, 40.48735995446482, 53.07517936152797, 66.28410216300719, 68.03936281511861, 66.09569503415015, 63.525259956236816, 64.13294884466356, 63.232294205696356, 62.6269861959642, 61.53178984119047, 64.41015843422183, 63.5909753461038, 62.98707154489333, 62.88284240230438, 63.046722950473914, 66.02288799901163, 62.89818671441848, 60.75249333535472, 61.22263254657869, 63.141534482279134, 63.90370984231273, 61.20844141129525, 60.26335024064588, 55.26525828146166, 49.32029439556984, 41.09242477724629, 35.033974955158854, 25.766092808015888, 15.17766825614437, 6.808795803977597, 1.9829028820799244, 0.5737258205490728, 1.411134691969041, 3.597329729987729, 7.687663147526403, 12.42955961535054, 14.392417592387046, 19.305148970696237, 25.357960385660974, 5.180390486794134, 1.6045879500527538, 0.826740698708642, 4.570387399965718, 23.44663254676327, 44.343665645968535, 30.646401874480713, 22.002002039263328, 26.707967635123964, 39.63782556595341, 37.003714730662686, 8.43090424614568, 0.31428177931135703, 0.229774528453427, 0.3320600753349643, 0.13416914569754756, 0.22346144301756737, 0.14642788547902338, 0.13479064218699932, 0.18561434000730517, 0.11960373815870094, 0.12928804713151149, 0.11858195306793337, 0.1759691857883046, 0.2522518392652273, 0.16480687104405897, 0.1510331923923185, 0.18751048422869177, 0.15073682361793134, 0.09983904509534759, 0.11512802267867712, 0.19210569410314485, 0.09097612793407134, 0.10487706145091404, 0.10657161729590547, 0.23906417191028598, 0.10838605057928832, 0.18688560163061466, 0.0979039759465283, 0.15995564990706984, 0.1556277434311567, 0.12870180600833508, 0.28722379897390643, 0.13978933524941245, 0.12591857027502792, 0.15768651279710955, 0.15183367766439915], [0.009024123127962793, 0.020807041869228406, 0.04648471754344721, 0.07458513287166435, 0.06241639309953298, 0.07628220148504743, 0.06395417288126004, 0.013701477737706757, 0.0451538925840249, 0.14207068380088578, 0.037385603983796416, 0.03615241693032365, 0.035331572871655226, 0.01626558263876265, 0.025886731492655895, 0.04398166314668713, 0.024521834772801208, 0.003013312046776616, 0.031042032078990055, 0.03981342088551291, 0.05220449086458934, 0.062240978117070855, 0.05579857703959269, 0.04408053445419477, 0.10212854482233526, 0.05981922097083542, 0.09744683596035165, 0.05925575564164789, 0.11266631404719046, 0.04785386988172128, 0.046738472677046256, 0.0911526269309463, 0.09900731109683553, 0.03611363372915695, 0.025109527632594112, 0.01282919757819224, 0.030644668018325206, 0.03212242098074527, 0.006165877331964552, 0.022808980917738333, 0.0180782443438206, 0.018273577612314015, 0.03491913028542073, 0.08695609687316803, 0.23924423321600885, 7.768326199823811, 35.79073744435465, 36.3555234478366, 32.75644090867812, 19.111536856620543, 18.09444469790305, 36.509982462852236, 34.07295111686953, 13.5526999158244, 2.506167778084355, 0.039394439738844676, 0.49376968354467426, 1.3041530261116645, 3.744102370354437, 1.2656360864639282, 1.2297059499448346, 4.163838144271605, 1.4404730402654218, 0.7827040036359142, 0.04576601981816273, 0.4095120547759918, 2.1307496390035077, 14.890133027107487, 29.03840857167398, 45.52735067182972, 55.89807779558244, 62.05498695373536, 63.879171494514715, 62.01939928916193, 63.77582880758471, 65.0299870583319, 61.106699051395545, 64.93268089909708, 61.568252194312315, 63.151724799986816, 68.29533669256395, 67.43774183334844, 68.67540651752104, 63.528974440789995, 62.92728677872689, 61.720506837291104, 66.14039436463388, 62.25460813891504, 68.21090375223469, 47.94493098412791, 44.16186771085186, 47.887793817827784, 60.517708101580226, 65.18156313127088, 59.254265600635165, 62.99406905328075, 63.3294120911629, 63.601801087779386, 61.724903814254276, 61.154477442464525, 59.67257461240215, 62.82124157874816, 61.34394361126808, 59.098249404661125, 59.48145320338588, 60.63221777639082, 61.68603312584662, 59.422488212585456, 52.54023082794682, 45.393994008341146, 36.540722077892674, 32.53659794407506, 28.15736774475344, 20.91357373422192, 14.215636368720764, 9.544523973618785, 6.316149052112333, 3.1418785693184024, 1.9533843499037529, 0.369773541967715, 0.6871793359037369, 1.0066452321986998, 2.3914384505441113, 3.2266235832245123, 3.1126858390146688, 8.481280226861278, 6.750258351525953, 2.1526499477124985, 0.33719289507116046, 0.0647545853749879, 0.4532602104929186, 5.87902246944366, 23.559885101933634, 30.550937268041796, 24.530322628636515, 22.73338875462932, 30.043290392045055, 39.55163148141677, 25.048369669145156, 5.576164011032351, 0.06071063704908856, 0.09616791345779935, 0.011937024988113873, 0.027907393730035233, 0.03502735935692345, 0.052186162211000926, 0.046149577059212236, 0.015774875552573755, 0.006697003695843441, 0.018440713099534475, 0.08311947492221672, 0.037287142533328266, 0.06863637586995479, 0.09989570495822739, 0.04597295931870899, 0.01044306447804575, 0.043165335176332344, 0.0552476832132426, 0.07122558451467945, 0.10963400014706197, 0.05957243723734733, 0.05670379419180174, 0.08873191932516714, 0.059164273252169934, 0.06128138404399638, 0.07537601140117453, 0.027863722887911627, 0.040686891354139776, 0.03367183955326196, 0.041160027256175395, 0.026252471443806446, 0.062492289430191444, 0.00556361778909641, 0.060015151787909775, 0.03897261257553774, 0.07928785552541096, 0.013143539732892909, 0.01378897263953883, 0.07833267411878032, 0.06938477482406363, 0.02555083832703531, 0.10247719909755454, 0.012404058999832601, 0.05310975398207384, 0.041960750015512596, 0.07320048257468209, 0.023423032947785916, 0.04171939784540765, 0.03322790692289991, 0.08325093561002324, 0.05343120830554155, 0.020087802136737495, 0.058042322165302696, 0.04344655073157722, 0.04858894656682688, 0.07447686932620502, 0.044079936905613834, 0.056069120990052346, 0.07262611581433205, 0.026790776530340798, 0.10001940517536095, 0.05648884524200713, 0.06970319926979081, 0.05520445670211508, 0.01412645064955277, 0.045785263946820656, 0.03948771860450506, 0.07448262264651638, 0.019551057954348867, 0.028371558742477532, 0.01770321749180796, 0.08771582626767697, 0.05075370036666432, 0.020170344280139096, 0.062301058562532555, 0.00968142656699544, 0.051107284417676355, 0.037712080013607784, 0.04105096697927483, 0.07025908032852797, 0.8241819037545113, 15.021886421788125, 43.48040296185402, 39.35166120529175, 24.295894330547704, 15.87557165853439, 27.085156479189475, 49.190444331015314, 41.91710702834591, 15.521721897586701, 1.1672642682829213, 0.09137409528897655, 0.1265515734051024, 1.2565686697921445, 1.5984271322527241, 1.2438446235272194, 4.878969577050978, 9.243920387760285, 4.785739250721471, 4.316446781158447, 0.16213389834569347, 0.4967173140856528, 4.767886582882174, 19.462288925724646, 35.188029966046734, 49.66858517739081, 62.2204678289352, 62.357233032103515, 67.59511516940209, 64.63247053084835, 66.61367539436587, 67.11827262755364, 65.00245594209241, 66.8814242270685, 62.4792815023853, 63.717059935292895, 67.57066311374788, 67.48309227728075, 68.68918188156621, 64.10308784054172, 63.36102639475177, 64.23713091881045, 67.2152885313957, 65.59152533931118, 69.49176157674482, 54.347835510007805, 41.22721310584776, 50.52548185471566, 63.47828957342333, 67.15207561369866, 63.992861393959295, 63.91365697306972, 65.27504497958769, 66.62226538504324, 63.17117583367133, 62.33646015967093, 60.91278883718676, 62.9003087166817, 63.68239402770997, 60.16652261057208, 59.96743486773584, 60.78510784333753, 62.982525517863614, 63.08245966511389, 59.599092929593986, 51.34227229702858, 43.612229900975386, 39.18983597909251, 34.56886814486596, 27.92289237822256, 19.82182906519982, 14.71075519438713, 10.746806917652007, 5.607087977470891, 3.0918303516603287, 1.4559340428921486, 1.1376779526472092, 2.3517776496948737, 6.327768583451548, 6.0694697210865645, 5.141072157890567, 6.5300010865734475, 4.821058723234362, 0.8792543711681521, 0.4520706291640959, 0.01607552963128734, 0.23943390126430222, 4.936622044732494, 27.665023995983987, 42.13710492657077, 30.609780665366884, 19.82891090454594, 26.57433052216807, 36.840944213251916, 30.14078090267797, 9.909643684664081, 0.20175549081496655, 0.028383749116572644, 0.04612045805721034, 0.0839833003438769, 0.04898476504510449, 0.023958275597842953, 0.019730703657372825, 0.016154329435178832, 0.022075093584135178, 0.031313615993806915, 0.09856985957031289, 0.03483421326945386, 0.07540961201753348, 0.06799864597738751, 0.04206540528684855, 0.05628547571118801, 0.03125577060986431, 0.043961151142514525, 0.011570498839231029, 0.18130144885470792, 0.05663758887338543, 0.038115869636737534, 0.05403525714251784, 0.03183379544005279, 0.059873620874338576, 0.01920317168227367, 0.087502853824727, 0.030741279366456216, 0.0182213150941196, 0.0364113814618078, 0.03651320603826354, 0.06747946819110263, 0.03841454816621639, 0.029137899475773017, 0.03450920429801749, 0.050312694192173026, 0.09495435357694665, 0.06390985469484041, 0.16706120733532215, 0.22837545272083054, 0.17991507485989602, 0.1992090758416922, 0.16526951154153194, 0.126328396671001, 0.1586628152478126, 0.17539112648415953, 0.07902581515091081, 0.13111202587043086, 0.14174627620846997, 0.1456205054156242, 0.12187041612642428, 0.1358176903018067, 0.15771930136026877, 0.18838151087684019, 0.0866794012366764, 0.1328938850952733, 0.2009164406767776, 0.27364390992349197, 0.13208166335619267, 0.1784923423321978, 0.17376849097349953, 0.2263707538405734, 0.15121455604751266, 0.1063834661017022, 0.2310513212315498, 0.183133211046938, 0.1400687581589145, 0.21224162571372526, 0.22314055942960326, 0.1775135424348616, 0.0736248110150618, 0.18883400837019568, 0.21679039533820846, 0.1456177321773383, 0.21664762719263955, 0.1010677658562218, 0.20393605283912153, 0.08565197773878613, 0.21993537012848163, 0.215465339020856, 0.776733298215174, 13.603150421573272, 50.5958648650877, 48.74839713496547, 43.06473762758317, 30.650165388661048, 24.314260828879572, 43.72983824822211, 44.464486414386386, 18.71988231135953, 3.25022840692151, 0.19207362566263447, 1.6713846883466168, 2.7215225706177377, 9.846573933478325, 5.090080855354186, 4.895060610386634, 9.1112599449773, 3.7994725088919368, 2.0916208096088904, 0.12238565622077835, 0.6624016622381826, 3.2795971535867263, 18.5346915260438, 31.372293349235292, 48.488442051795225, 59.16590244539323, 63.61880456247638, 67.0945893564532, 65.49099891416489, 67.8123438742853, 70.83180012241488, 67.0393310054656, 68.43111345844885, 63.969931217931936, 65.22584276814615, 70.00934185520296, 70.82554001961985, 70.41682120292418, 66.89644690482848, 66.25688875875166, 67.04941149680846, 70.31269796432989, 68.58502726401053, 70.45897099279588, 56.16539124519595, 45.16806548641574, 53.166084212641564, 61.46520368514523, 67.49428672175254, 63.625190181116906, 67.258544429656, 68.73446956757577, 66.89731767100673, 64.7836269101789, 64.83946577195199, 62.624283682915475, 65.42182007143575, 65.98607263257428, 62.46698094952492, 62.944690335181456, 62.12945707382695, 62.75006624960131, 60.67403416479788, 57.80168640998102, 47.41100226679156, 39.33568146920974, 35.884427178290586, 30.024423791516213, 24.154045735636068, 15.889760832632742, 11.599004595510422, 8.42427053759175, 4.67945086379205, 2.4058291364100675, 0.7563087812835171, 1.3947310947602796, 2.834971489444856, 6.0019868131606815, 8.647198446335333, 7.780288448256831, 16.18423375391191, 12.704675639829329, 8.251185167220331, 1.9491143596749154, 0.31037212619858406, 1.0528513044118881, 8.027108004016261, 31.847919956330333, 36.595807844592684, 33.92721545311713, 31.797405712066162, 38.899560974490264, 50.245424624412294, 35.49341394055274, 9.578508369384274, 0.40869188104425713, 0.20745000621724516, 0.10662519748532966, 0.13451743991144244, 0.19390356456560476, 0.1573175495310176, 0.1647279333443411, 0.1388403055288138, 0.1425232732247922, 0.13350479424961154, 0.2297341709415759, 0.16986427708498894, 0.1582909868128838, 0.1587119827707929, 0.24370815094199874, 0.1815552078187466, 0.1889761023583912, 0.16773758636366937, 0.14879833005609053, 0.23427097427268184, 0.18434290984465232, 0.19022540790179085, 0.1405989063242751, 0.1574723759005147, 0.1760361571946452, 0.121324249062567, 0.15004090934751496, 0.15266940298099674, 0.12585825617274932, 0.12242905510168885, 0.12021919021443014, 0.12425554660899986, 0.12580560294971352, 0.11736689165474908, 0.16094146716979243, 0.16416324993535397], [0.06037575320430821, 0.027365373117068124, 0.03724279370339167, 0.02402537915435049, 0.03786736986629906, 0.07152233633302874, 0.015069734710719318, 0.017158643890833183, 0.016216288711274826, 0.13979659776293463, 0.03573820085054444, 0.008922363668980618, 0.05869403699292772, 0.04449136059490904, 0.017376864036064477, 0.045450502676108194, 0.04198305849586764, 0.00832140408155899, 0.10978445215451141, 0.032905992946677634, 0.03753138668534737, 0.054005555913693486, 0.11390594390010643, 0.032980246018738515, 0.03505091656059508, 0.0806599036760388, 0.02779971432661818, 0.053197386779732285, 0.07279638651638262, 0.01328508213778297, 0.03447055133179792, 0.12764589170054083, 0.03700460547641401, 0.02425383806468979, 0.05367053417308677, 0.06337149023649193, 0.04810484028571556, 0.08054402521661214, 0.06975851081792386, 0.018489545459047924, 0.02762031760216961, 0.054472379251233036, 0.04771194443286908, 0.06535631679599324, 0.009299302867974245, 0.04441314301784, 5.902373809968272, 27.4410625427, 41.838212474699944, 27.257660358182846, 28.682728044448364, 26.461276046691406, 28.033169815617224, 38.712259954021825, 23.641839104314005, 5.718292565115037, 0.5284571335200341, 1.035702334296319, 0.68986983669381, 1.7433831023593105, 11.506497456181435, 8.510903927587695, 5.235621871486788, 7.344679332548573, 0.7205530063759896, 0.10282976042118766, 0.035673202120608864, 0.10496257218502222, 2.4106136925758856, 9.577115927973102, 22.503133858403853, 43.300326947242986, 48.97594167340187, 54.763167442814, 57.5207741029801, 53.916523841119584, 57.926923767212905, 57.422208862919966, 61.61192386381088, 61.15230837175923, 65.28226606307491, 67.01320802011799, 69.7644212169032, 70.25167372918898, 69.92323798518028, 66.44313073927357, 66.25639454010995, 64.36250163662818, 68.02965102657195, 34.45469579389019, 36.063816778121456, 38.600189993458415, 51.747476670049856, 66.28989942612188, 64.52808449345251, 65.2790222629424, 65.50865350231048, 68.67183716066423, 64.21850358286213, 64.44482826417493, 67.01306681479177, 67.37325022297522, 64.02478948716195, 63.96835834749284, 60.649174182645744, 55.885322247782064, 36.856351283288774, 23.270561272098174, 13.026157021522524, 9.123382029994842, 3.6216807846100103, 2.8557671606540684, 2.1712917474008377, 2.1289478002056, 1.0556446448449166, 0.49147469862814874, 0.1600506754531976, 0.07361551836854027, 0.06093683600005123, 1.2334041321469893, 0.8605587614640113, 3.1075149293868773, 3.893883468643312, 4.545828950020575, 4.428111266705298, 5.973444706009281, 5.7966100400494, 0.7559251857380714, 0.2910909801721573, 1.0514538374639328, 11.486551223262666, 29.576259659182643, 35.20684949813351, 27.16263701838832, 23.586986718639253, 28.183894734228815, 33.006027206297844, 16.779846645170643, 1.6850329430833941, 0.16626374044966313, 0.08689477919570862, 0.026577509143539978, 0.021809307039685307, 0.02825399680483726, 0.08053870856641762, 0.03402580281779651, 0.05051324451943079, 0.0777299238008357, 0.061707294455939726, 0.0850935762507781, 0.06952083203941584, 0.05902836542396296, 0.04616366158570013, 0.03872255381617335, 0.010693802182833034, 0.06742713672499503, 0.09671008920357113, 0.009873884132943087, 0.049568248251753474, 0.08622564735912508, 0.03074246297229923, 0.16347917938424697, 0.06542364826365825, 0.020063277747061466, 0.13413508542843405, 0.039958586886284814, 0.034959051127154986, 0.048354937349476164, 0.06780056628368555, 0.07274492072962946, 0.0311044127034444, 0.02328740857211092, 0.010736814189341762, 0.009631728528127556, 0.040677123733105204, 0.0240494707043493, 0.07456011244005735, 0.09458690716494476, 0.03813656550201197, 0.0444180459805554, 0.03126569336370355, 0.05593417843262996, 0.038002607367572286, 0.07584791390165206, 0.07537688474140822, 0.0793253938337007, 0.0629863012281637, 0.007559868634768552, 0.06337577266798866, 0.02394187940104354, 0.030697778978895758, 0.10118362133301075, 0.035283408923855716, 0.029315269897661866, 0.07746255145438256, 0.038755384514168385, 0.029630991968236146, 0.025435258641899116, 0.09709356217494897, 0.01574685301391348, 0.03792951491871669, 0.1004831488394449, 0.04587666589706656, 0.037039251802789594, 0.041953430045396096, 0.028145160608654542, 0.009880969488632776, 0.14128853867371238, 0.031077896485165245, 0.03323640283798018, 0.02886241617342157, 0.029559293799402735, 0.013710426602272258, 0.07067672082132871, 0.08877432229177606, 0.037383206128593416, 0.03431270657587917, 0.07703056213476005, 0.04025126694731655, 0.035406699283949794, 0.016576782875363866, 0.24804166518151763, 11.408970663624427, 39.23244076390421, 45.69416515288815, 26.781602290368852, 13.22880627647523, 26.06409880422777, 40.07745658197711, 46.21736226543304, 25.320027143724506, 3.447791328353267, 0.17604513574511776, 0.14559234402352764, 1.210147909099056, 3.6998889234758194, 3.2087937141618426, 5.755028993852678, 9.035853359007067, 7.9767805626315464, 2.2342195578159827, 1.1065522292929313, 0.21286914365426188, 0.5951602865130671, 4.783675593714561, 14.584960860590781, 29.71587250309606, 47.12102143995224, 52.99966196860037, 56.88997853186823, 60.036205783967056, 58.94478274929909, 60.72187531378962, 60.70703306505757, 64.16985834798506, 62.95499047925396, 68.89372564131214, 69.58280763318463, 70.39780555232879, 71.11217114233202, 69.77111278041717, 65.96013007625457, 68.56238734337592, 67.90210339330858, 69.35332544388311, 39.9132740113043, 39.445582359067856, 42.42948624395555, 56.45947879360568, 66.38049833236202, 63.757762370571015, 67.56240260216498, 67.16364660570699, 69.29912613284203, 63.76059039946526, 65.52154633306688, 65.49667458380422, 66.92298566141437, 65.74212474207725, 64.28724312013196, 63.17443140091435, 58.26261981841057, 43.1387762869558, 30.612394925086733, 19.842327371720348, 13.278573309221576, 7.098069623593362, 6.541785847756171, 5.270797196895846, 5.033583035392146, 2.882826857028469, 1.7454728676426796, 0.6182273164872201, 0.6417010472186151, 1.1281386258140689, 3.4785446716893107, 5.224781911219321, 3.4845584006078782, 10.658185866571243, 9.508838249791054, 4.032238457472094, 3.0051896072203115, 0.11196453920415333, 0.44031350843368045, 0.22843090216478995, 0.8254360203300753, 9.24093448346661, 37.494756252534934, 44.228285204979684, 23.96250267182627, 19.612084242605395, 29.4482119237223, 39.064202462473226, 27.520596442684052, 4.03462399398127, 0.06239932849101963, 0.06099488631251359, 0.06151664198466367, 0.003221855065109389, 0.004910996583695974, 0.0276191876224813, 0.06973066352187626, 0.09231813777718814, 0.07232525010382937, 0.02830624208605338, 0.0757914532216326, 0.06368888429396095, 0.019536080935429183, 0.016033194654981698, 0.057853554270320365, 0.010645794325448092, 0.010387657168922166, 0.07272779100364254, 0.04725890301708733, 0.008675603875740161, 0.013658310598393363, 0.05479603990792267, 0.07940603224861045, 0.10654781494409808, 0.06984456547445829, 0.04302705630599972, 0.01650380917013653, 0.013262163659918213, 0.01733715961416883, 0.02645984186881012, 0.03399181915747543, 0.04559230555089251, 0.03158724727860141, 0.05001512649018438, 0.014491714668580362, 0.0647947820083749, 0.2122817074339236, 0.1708870963944543, 0.2818589771707212, 0.15253768182329594, 0.1164118251613071, 0.16203381661926547, 0.14043110242534068, 0.18437090269740553, 0.14335124573159602, 0.1269411137928405, 0.28218860948278063, 0.14066118927251908, 0.11745730535157266, 0.1811177869357409, 0.2589287092128108, 0.06274605605510936, 0.2890333599380909, 0.14562960654016466, 0.08705372711823833, 0.13490112738743906, 0.11229573433557827, 0.09704533694011551, 0.2635198741430237, 0.21973699932136845, 0.16628468529351298, 0.12773171653069798, 0.2692470248908766, 0.11950383263249552, 0.14796007664934283, 0.1676814780840951, 0.18915538225443135, 0.16401842867414798, 0.20459419897487088, 0.1478751328202986, 0.19962426485313525, 0.12411279378518944, 0.1233898442719252, 0.13187362451947507, 0.12748770220505615, 0.20302807010950583, 0.19524815612502638, 0.15945222288850816, 0.1879849837672326, 0.11033005231330473, 0.20209160423086536, 0.14415265030918584, 0.22516392021169587, 10.134474923533778, 43.35853099822999, 57.535510447717485, 40.31307335822813, 38.44211847551408, 37.496882177168324, 36.26795261136947, 48.53098800105434, 28.309400773817494, 7.970513105392457, 0.5289728026236258, 2.275970001374522, 1.9221527225548223, 5.8609516197635285, 26.478746283438902, 17.197724196218676, 14.84823230774172, 15.194638390694896, 2.526550864981067, 0.5446720279512868, 0.14776415732358733, 0.24723423915284298, 3.685096194667201, 10.979602529156594, 25.9089651415425, 46.72270474895355, 51.08821645859749, 56.95985947885821, 59.96807421407392, 58.79574837223176, 60.187832847718276, 60.879460457832586, 64.27795886993408, 63.28011966520741, 67.49933873453449, 71.10371451224051, 74.89463821534189, 76.0885057141704, 75.52926201974192, 72.40354876364432, 70.06199575239613, 69.03738637124339, 68.37399590399959, 42.795400234960745, 40.77146507078602, 46.38228616406841, 57.23926559571297, 67.57910405435871, 67.1454389633671, 68.49387922594624, 67.76458509506719, 69.94701539316486, 63.02465961825464, 64.20753663586032, 68.38075807017665, 70.54068180822557, 66.01633764082386, 66.98630840547624, 63.05343020346857, 56.27362905010101, 39.28754614245507, 27.402070260817005, 15.394827338957018, 11.098493491449664, 4.937314343067908, 3.959153179199465, 3.090737971567339, 3.3214155031788737, 2.23193526748688, 1.0023648844611261, 0.4585219475050127, 0.2831168935423897, 0.7839255767964548, 3.5057016918736124, 5.129164332343686, 8.471445864246737, 11.855771772323116, 11.455069299667112, 13.874568631572108, 12.093276189219567, 11.03180633437249, 2.7004530689408703, 0.8444518547865653, 2.1943538131252414, 14.168823861306715, 37.907621014502745, 42.37188623797509, 33.303770403708185, 31.44725572678351, 38.77204472018827, 47.52529621124268, 26.710630924470966, 3.658085282771818, 0.37420321556348957, 0.1767499213136973, 0.14742686413228512, 0.07131152425802524, 0.09164115353938072, 0.18711262412609594, 0.12500818969020921, 0.2379348970228626, 0.25530371905094196, 0.12730418584279476, 0.21886480821957513, 0.19609813067701556, 0.17343367990707198, 0.17462715296255005, 0.12510369787172926, 0.1571916046762659, 0.13884632697989865, 0.1732343591509327, 0.15991199821714433, 0.19732990812870765, 0.26936248966282417, 0.15249281971445008, 0.21808416462473332, 0.24733252823352816, 0.12709223995766333, 0.2322426339190814, 0.22594745961889146, 0.18441423263040282, 0.17011350080851587, 0.15466132351467687, 0.12801243412879207, 0.12798224260369617, 0.10561721729895762, 0.12199063830438162, 0.12564387412801867, 0.17107762246122285, 0.27604090710801465], [0.044387168806767276, 0.026628011574728355, 0.04821341026634459, 0.03776795080592556, 0.02206554238293921, 0.07676644566198511, 0.05960218826188676, 0.04138824867925817, 0.0570900442319051, 0.050224306797909166, 0.019662770810687256, 0.054689982695685285, 0.017553318982883807, 0.010359898930595768, 0.04716694948353595, 0.04304884001612664, 0.0014352363993361172, 0.020742169543800336, 0.020154313890323527, 0.0686622926244332, 0.021949016579216527, 0.042606638744473464, 0.08509392865122327, 0.018712105492370266, 0.03235694539222506, 0.09020355890595144, 0.02803367374825382, 0.06410318464341183, 0.05106084033726685, 0.039419525287925236, 0.07365787536987374, 0.015318125313628587, 0.02811993716374761, 0.027509022263749957, 0.052454970972312075, 0.07710361627921944, 0.029788401969257864, 0.037901020278373075, 0.01755122181719109, 0.022905931259775837, 0.04205792826870757, 0.014785356169957069, 0.033527903123608524, 0.009190319199866105, 0.06764142683917476, 0.0025579864919681346, 0.011780402142434351, 3.3176350737771685, 28.103597933246245, 41.48079825985817, 42.01976722286594, 23.253824518572902, 22.89508846498305, 24.066606298569713, 30.76477900628121, 31.572132225959535, 10.749036785094969, 1.6723579264456228, 0.10957325703554577, 0.2349701061123802, 1.4781608889179847, 6.8603533987076055, 6.248933845950711, 7.988907550611804, 2.73361744419221, 1.749249006952009, 0.2289074088536924, 0.08082882606334264, 0.029110666965284658, 0.3488283303956832, 2.1972571024971623, 8.786721075734786, 16.708928231270082, 20.38900967567198, 27.41129763664738, 27.57878088182019, 28.61948374778994, 32.9044888096471, 38.33450432746641, 47.983303531523674, 64.62271559622981, 68.6944535470778, 66.1580450304093, 58.26648727540047, 60.39779340067218, 65.26381915615451, 67.62463492731895, 62.41125583648682, 58.410120548740515, 29.773448974855487, 35.27033305937244, 33.79244673636652, 45.81869256111884, 69.47498167714765, 62.94457266407629, 67.79292814193234, 69.32792417464718, 66.78960938607493, 65.33737536399596, 63.73010966085619, 64.44989988880774, 61.39202402484033, 57.759666058325, 41.23620317828271, 27.595117553587887, 11.97722698411634, 4.319987210535235, 0.8307779820696001, 0.5651031025955754, 0.06922774978222386, 0.15910651805179735, 0.12215482626831341, 0.3729031030689517, 0.6501715894668334, 0.2659074637678362, 0.47293656595772315, 0.9137168057983922, 1.0689494470434806, 2.5672486424446106, 3.728368517852599, 4.512539304071858, 1.4775029113215785, 14.754757323572713, 8.109895019761979, 2.4659026870804452, 1.3775126251482195, 0.45389603282655444, 0.7680530317368046, 2.5180380959664626, 15.316236768999408, 31.64242894418778, 25.356009006500248, 19.47520725188717, 30.924856816568685, 34.283872650515654, 33.8278422048015, 11.425679960558492, 0.7999917888833631, 0.11850753528696877, 0.018942696042358875, 0.03953635752681763, 0.024854018157648466, 0.13847249139460827, 0.06187251280812968, 0.08611852528467294, 0.03835829816037609, 0.12899665792863216, 0.016734819153263684, 0.054387489048343514, 0.03839692048307869, 0.009965469944290817, 0.04280725801964441, 0.023460737880199187, 0.03506788923855751, 0.04678539556240843, 0.05136280921438048, 0.02144100452442804, 0.05418147651418563, 0.10921912523166788, 0.13730416134480508, 0.03643823667399345, 0.04542589210154069, 0.0638328781802087, 0.0571758805533811, 0.05202455979381358, 0.06740086757007145, 0.05802099810793035, 0.02194246461224412, 0.0368543564822645, 0.0058167672344303185, 0.03371602750473446, 0.048888115392577265, 0.05039983669355993, 0.04528404326148091, 0.040465537909298174, 0.07199103658598277, 0.012648583731553968, 0.02234170750354327, 0.06160144791788152, 0.01858016408439125, 0.07770464289933443, 0.02277619618501875, 0.05362274943880978, 0.02522788438645582, 0.052563629053052396, 0.07355439987394118, 0.03913944737324792, 0.06545780046332268, 0.029115131342663404, 0.06420125155859897, 0.027330031565901254, 0.07345295451100796, 0.023194830676901246, 0.019296260941172802, 0.07430908840990837, 0.02133816871191225, 0.05781559461367227, 0.03919360212861531, 0.031167109339167515, 0.0028152768819352555, 0.053261895213396325, 0.07969861654865165, 0.025858437950392405, 0.020945812951052384, 0.10467791689499732, 0.025895936039066123, 0.06463495308473226, 0.04688105696151334, 0.04368435974503237, 0.03312491789279926, 0.0376890322584058, 0.0711076682613742, 0.025698245134985736, 0.011752470576715086, 0.025110510140357, 0.02817945261936515, 0.022441747095135432, 0.043918602619199984, 0.02248590440309096, 0.03987123754115836, 0.06100433217661996, 0.057355125975464626, 0.0205729617887447, 7.725407135102057, 37.56893611723377, 44.99285321081839, 39.92339372634888, 18.295068048661758, 20.141443398690996, 34.597881917030584, 44.01834426387664, 32.39585741873711, 10.159621238708496, 1.1608894361603646, 0.09318940957347233, 0.16381080352490948, 0.4581659004813241, 2.728650252665243, 5.226714168825458, 7.247229026209924, 4.425693125494065, 3.586761639002831, 2.4127440298757246, 1.1405921511111723, 0.6139114222699597, 0.9887130137893462, 4.213755207677042, 13.86880765038152, 22.01475170350844, 27.292545918495428, 32.23031182442942, 33.453601021920484, 35.478289281168294, 41.1300834532707, 45.54013759859147, 51.79272120998752, 64.63452977518882, 71.49066417447983, 65.63213363770517, 59.80093809866137, 65.85965464192053, 67.80071012435421, 65.59803255142705, 66.40116922317013, 60.83791863533759, 33.92224188773863, 37.58153869259743, 39.46750448596093, 50.964096976864724, 68.68615381179318, 63.68932485580445, 67.94579859702819, 69.88057044244582, 68.23533227366786, 67.03496932983398, 65.88831932313981, 68.5730169665429, 65.25642941074987, 62.88100281069356, 48.440020392017985, 33.90595620678317, 19.132368564605713, 7.698424660390423, 2.3946295438274263, 1.3079862849366282, 1.0061102576794163, 0.4932871400829285, 0.7707813466268202, 1.5852713801207083, 1.2427038266774149, 0.9688848809849833, 2.3152974007591127, 3.502930292198735, 2.683009308192038, 2.8460972924386305, 4.5982788839647855, 5.343281617087703, 5.084236523797435, 6.661332336164291, 4.633212983608246, 2.7732782450414475, 0.24909779399393067, 0.07514536530981142, 0.3890422160827345, 2.4372507535642196, 14.782861105857359, 44.04839354176676, 35.34175549784015, 19.989855558641498, 22.677226297317013, 36.08989269502702, 39.42359355188186, 18.449162283251365, 1.6562167603162028, 0.13660286913716024, 0.031214677653605902, 0.06553001191106535, 0.028541662820404577, 0.009602080925457902, 0.08253314952936866, 0.019708937184224208, 0.0596163149232105, 0.10796201325231984, 0.07212119492431802, 0.04471132359016807, 0.07578352421161628, 0.09496689443626712, 0.046875437706588745, 0.0278508679325422, 0.004722813788365814, 0.03731790479392775, 0.06716714946613198, 0.042154846052008296, 0.0204019001009123, 0.06141176071739005, 0.11107737108344033, 0.06940863846290497, 0.07091406252115004, 0.11008652828393445, 0.03292396919982087, 0.05116983166625423, 0.07804505406848847, 0.06903295660571707, 0.0784527430791528, 0.048104411276477965, 0.06067982882321362, 0.04212126458784746, 0.024838179289813966, 0.01590410022125129, 0.03498378427579038, 0.0342179108561287, 0.041887029374559084, 0.09875712976340326, 0.1429630996238801, 0.145686726055799, 0.10628084096336558, 0.18299579019508055, 0.14811998984265715, 0.1046863055577682, 0.2032884174296933, 0.15161454587453796, 0.2676137254363106, 0.13581890072072708, 0.24687033206705125, 0.1563206546369099, 0.11874177433069676, 0.12996526885657542, 0.14582508153492404, 0.15616516943179792, 0.16355972586860582, 0.1467685954224679, 0.19710965785047702, 0.12316979317655488, 0.10839642340978307, 0.15625449528376903, 0.10374426255903899, 0.20971505241768978, 0.16900431274646716, 0.10057766876754262, 0.11935658287256957, 0.1608764416267795, 0.11396854860527862, 0.1429657502880981, 0.12642789617060654, 0.19179761950527469, 0.12378248731575667, 0.13684993249274072, 0.285975382092499, 0.12630606520800822, 0.18053483999063893, 0.10106034246423554, 0.12364960936529022, 0.2021257564305298, 0.12197401419642473, 0.13617560658003056, 0.15930629846069122, 0.21963130983133472, 0.1071271536150767, 0.13325016194533917, 6.746427176460144, 40.94497503772859, 55.76170482943135, 55.78222274780274, 34.16905703083162, 33.06190529177266, 31.856851193212698, 40.40331532878261, 40.70275691247756, 13.700422260069079, 1.9381948488373912, 0.33252996302420096, 1.172979897068393, 4.138282431710151, 18.40419230922576, 17.78702501327761, 15.412377984293046, 6.395405934702966, 3.964903864168352, 2.1650144842363175, 0.8520527340231404, 0.22854725559872968, 0.9093529851205888, 3.2924193816800273, 10.918549856831952, 18.716103107698505, 24.395412706559707, 31.66129162234645, 32.03803135502723, 33.00112032121228, 37.87548503568096, 42.49322475925569, 50.900229023348906, 65.11327074420068, 71.7389266721664, 67.05880165100098, 59.66856987245622, 68.78109870418426, 64.25968454730126, 67.06060594128024, 66.54727751208891, 60.78125215345814, 39.97147021755096, 41.60793012188327, 41.105345064593905, 53.71471397338375, 68.54407771941155, 66.4921054532451, 70.04786737503545, 70.98321930054696, 66.49220743486958, 66.71443323935232, 64.06659410845849, 66.00587275720412, 63.14830057082638, 62.39600173888668, 43.45342489980882, 29.773160680647823, 15.006946113801773, 5.692886883212674, 1.1278395450884298, 1.0631324495038679, 0.49263483153716214, 0.4292751313938249, 0.44270652196099686, 1.0076466623333193, 1.3976647825010362, 0.8838128394657566, 1.6513320611369227, 2.792286050896491, 2.888137746241785, 5.076221160350308, 9.468049522369139, 11.782310681958354, 6.47406122376842, 25.108109328054613, 18.062875501571163, 8.720176104576357, 5.321321247085448, 1.3870813697576525, 1.302778970810675, 5.26058824792985, 19.561415064719416, 41.6474558461097, 31.707195120473063, 27.49819774781504, 39.15973963276033, 47.44176541605304, 45.354935046165224, 18.49125715994066, 1.7791655371266029, 0.17209668793985922, 0.12748076910934142, 0.1547499752092746, 0.2983773649940568, 0.259027473268009, 0.19163242030528285, 0.2143996494311479, 0.18107683187530887, 0.24943373887048614, 0.11036033576895153, 0.22009171335206879, 0.10107788587770156, 0.3014718392683614, 0.1695253291437703, 0.12343806184587941, 0.14157430479122748, 0.18557036656045145, 0.26476740236243895, 0.13912717481293987, 0.14751173135253692, 0.20638574155107622, 0.2008776919495675, 0.18977621990826823, 0.23306127547496752, 0.30133955120559663, 0.16011588485731235, 0.12425570748746396, 0.13905298685835255, 0.172620217105554, 0.2509259249293997, 0.13071971224440684, 0.15182154283167856, 0.14469874842512995, 0.15012779903988685, 0.16291265736424154, 0.1058517934213723, 0.2075271512712202, 0.16358266254105877], [0.024625524773352572, 0.0677203415562549, 0.08054229385790326, 0.045291144896538994, 0.05996993344817912, 0.023297055534297423, 0.046622946618064764, 0.017840992659330368, 0.05972593827473541, 0.04263180090234645, 0.019325690208784035, 0.03666644277531774, 0.04218040274516229, 0.06299690388503575, 0.03837462732448213, 0.036328709083459074, 0.04562003793375147, 0.06286963752861466, 0.04553261197983258, 0.0483593461854804, 0.08524129332433786, 0.02322187932628778, 0.03640116950977714, 0.03722639176093283, 0.09833061797243935, 0.034852986254038355, 0.033244473574262474, 0.03862701882157595, 0.06201551078007587, 0.03016417384177687, 0.025359482970088724, 0.06958830140290723, 0.05887071219002528, 0.01466878631617874, 0.036299923329704234, 0.02060162113799203, 0.07637615450808118, 0.00855899763278543, 0.10853684732630368, 0.10136422656115987, 0.05776177693699157, 0.04541551161016669, 0.03761217448740237, 0.05996238365168533, 0.02004600246436894, 0.09072202423046674, 0.023283137631933057, 0.07423562057796987, 1.767026414313624, 21.25696743688276, 40.68438453059043, 36.28232417568084, 25.68111465823266, 18.454481017205026, 31.149755716323856, 35.505600744678134, 34.04700463817966, 18.729043006896973, 6.153985031189458, 0.7225878584769465, 0.22922254678222442, 0.6263846819919925, 4.7126154841915255, 4.429442421082528, 3.889857645957701, 3.354572278838004, 1.6487276073425048, 0.8808888963633968, 1.7236231820237253, 0.0598785468196917, 0.027988185362529852, 0.04764355959430818, 0.3750956160647254, 2.0035634766663275, 1.5063854066594955, 1.8618283853415523, 1.9752134430793025, 3.578369973167297, 5.433169103437855, 7.800793618925157, 21.8219260246523, 42.56692217242333, 59.68992325567431, 62.39504468056464, 61.03259371172998, 59.856749503843254, 60.89645608778923, 62.7701723191046, 47.810028906791445, 34.19729417370212, 31.43102299782538, 28.48766269222383, 35.00433360376666, 63.99845077145485, 67.1571276264806, 64.67735029036, 62.96481209416544, 61.99263695747622, 57.70836145647111, 50.27925114477835, 43.4826857812943, 29.507571112725046, 17.04324753053727, 7.266269191618889, 1.5164878387604992, 0.2841774043777297, 0.0777871965340549, 0.30289259528921497, 0.2019595459944779, 0.7468150520036299, 0.4159038021199165, 1.9524614897466477, 2.722086411330008, 2.133075604515691, 1.2937430556743377, 4.645072760120516, 3.7754112193661356, 3.7737135685259298, 3.1583652717451898, 4.821829959269493, 4.915767783118833, 4.161923047034971, 4.901210886816825, 5.299169661537294, 1.1587462285833976, 0.4115224227068886, 1.0812819917355816, 6.288130581378938, 28.60044848534369, 32.546094002262244, 24.67635443133693, 18.63778514246787, 26.035463540784775, 32.822750537626206, 25.994857203575876, 6.201245179099422, 0.1710021934441982, 0.06469346688038881, 0.03654491824788913, 0.0611661644201846, 0.0845870848805193, 0.029497591162761374, 0.01584969265686889, 0.06608575507397614, 0.037523051648731195, 0.046767392496187846, 0.07844201018733364, 0.0673807041359044, 0.01109406492868138, 0.026678862575922283, 0.03711194588592456, 0.0813684583972058, 0.06993055118307953, 0.0708920604759647, 0.09785802599282996, 0.05153841571882368, 0.07378129213447533, 0.19728230342509287, 0.018639426730993777, 0.014888551086187364, 0.037832168126178366, 0.12332475744187833, 0.011835064431051574, 0.026713822998346824, 0.04184767160744917, 0.048390966464555075, 0.046893965543037465, 0.05093677622836925, 0.11037162024407618, 0.03946214275915296, 0.09149833176765712, 0.025544931789139108, 0.0755211697410672, 0.01777688450660677, 0.021006186425145117, 0.032600051903676604, 0.031554470206761075, 0.02939328829187059, 0.009552858818712975, 0.04027888441698686, 0.004845974392317717, 0.018600003846410303, 0.03092523239883444, 0.011951470533536087, 0.04694996657030237, 0.05045610968203795, 0.07939767422935656, 0.12191171592642223, 0.08792749636115567, 0.023307529871442148, 0.06101551322987484, 0.05989889028452097, 0.07048087810436565, 0.03338564059606964, 0.036303167712063565, 0.03513628556843727, 0.005303369581534137, 0.02222516829328191, 0.006983085345822357, 0.033268869644211184, 0.03814942428782102, 0.006907561046612119, 0.06293103564530611, 0.020012779146312706, 0.01298074796420312, 0.06679394973381873, 0.08739647485556142, 0.01979222434813217, 0.12421769420466117, 0.04483934071275496, 0.014454606327138122, 0.06027982750486943, 0.049845759771884456, 0.007717608532402665, 0.012960199570854106, 0.08675519031502547, 0.02696920223834534, 0.04764075954294494, 0.02805146614029523, 0.06315373357445483, 0.0477610774818928, 0.14384503536407026, 0.00563390922897886, 0.057460133647245754, 6.142286562150525, 32.001512127537886, 46.92367915184268, 36.0453345698695, 20.860033381369806, 11.745227613756734, 30.448502609806678, 46.794040895277455, 39.142971500273674, 20.27148565938396, 4.424703707618098, 0.6446642753097319, 0.42159433386498885, 0.35380946472287184, 0.8440097301237045, 2.2837284495753627, 6.212305772689081, 5.861624306248081, 5.943630770329507, 5.667461099163179, 4.419239845968062, 2.0951597680968623, 0.20814973560552444, 0.3402958269561491, 1.0804710417024552, 3.4012394134075414, 2.84797610775117, 4.03532168557567, 3.8625331895966686, 5.717571339299602, 8.131582785037256, 12.539228104775953, 28.751506805419925, 49.716708737034956, 66.87628592214277, 64.28702738977248, 60.138026591270204, 62.86340313573038, 65.22597220636183, 66.93519207739061, 52.2214166579708, 39.634546464489354, 35.061553139840406, 31.822277461328817, 40.56963166882915, 63.7145653078633, 67.34362063869354, 67.55131798405802, 66.01323112364739, 64.73589558755198, 60.71083776412472, 55.457066105258086, 48.77453580979378, 35.835934915850245, 24.60874257549163, 10.893750671417484, 3.580169850780118, 0.842345112994794, 0.3895098361517153, 0.9528247363144352, 0.8816614807132752, 2.1073953567012667, 1.9675079468757877, 4.961253058525824, 4.504872541273794, 6.171147852174698, 4.809821622986948, 5.303717159455823, 7.235529086282177, 6.469142081276064, 7.208776070225624, 6.231292495804449, 4.446676335027141, 2.824436003162015, 1.443121743298346, 0.7199876334878706, 0.5167304111584541, 0.18418420707025837, 1.2586275464104069, 4.560376530693424, 25.741672131323046, 43.479430214051284, 31.258942734810617, 13.773806864215484, 21.497218493492376, 36.151622956798924, 33.76683758151147, 11.6082525637842, 0.731616051447007, 0.24467883030733756, 0.03855996314556368, 0.026126220153885025, 0.04792062295300346, 0.027674188905005014, 0.06312081094590888, 0.04481186496935064, 0.020009281954938368, 0.053928437672795794, 0.03875785897816381, 0.03318365002351423, 0.031706825942702355, 0.029454104181739594, 0.01674452740248413, 0.03438878676763946, 0.03873427879185446, 0.03942086977223235, 0.03676201607431135, 0.055829438891622334, 0.024016906221907948, 0.1293276232336798, 0.03620739523020964, 0.02004132549759121, 0.04444055364377076, 0.10562241903596348, 0.10438753892817806, 0.019177402399720687, 0.07910528145129643, 0.01926812827737341, 0.004977149233567499, 0.027998646293135903, 0.058742951706893025, 0.06340630893265048, 0.01932778545925694, 0.01728045187079378, 0.118806746247555, 0.07779648918057643, 0.019735024393265767, 0.03729207997000025, 0.1586884638715175, 0.13273965627435716, 0.13929467227670456, 0.12892723504093387, 0.1608500575586673, 0.15540065964864147, 0.10935322892281318, 0.11716486660823708, 0.2071127589912184, 0.17111094728592904, 0.10562798083429376, 0.21272708030958332, 0.1462693359222143, 0.18362274123055322, 0.16202759598532032, 0.12009532145795324, 0.15490104774794272, 0.10117119538687891, 0.09141110499659855, 0.08346787638842099, 0.15685527675574826, 0.12376328149149496, 0.09776558982388628, 0.08981141381927076, 0.17116023738297725, 0.15845503688098925, 0.16498438893787323, 0.13068505442671238, 0.12814193363151244, 0.13454838986358336, 0.21963201463222506, 0.16908951704540562, 0.2616926012260299, 0.11578878117424828, 0.09866705314526636, 0.1675972237341827, 0.20253838670830573, 0.10790453367536107, 0.16179398513369023, 0.18094664289345666, 0.17940806254984873, 0.16551075262888787, 0.10185820771561516, 0.1693672085961988, 0.12686768426529824, 0.3087519115257648, 0.07571539601251003, 0.2259158814746526, 4.8787033461755325, 32.044420896037934, 56.360760581108835, 51.648566261414565, 35.60580161310012, 25.603008500991333, 41.038296068868334, 47.32213704816757, 44.904007604045255, 25.483021236235096, 7.573268692339621, 1.0415005780035451, 1.144962039205336, 1.0639614179249735, 8.746356944884024, 10.719844545087508, 12.93391562277271, 8.958267896406113, 7.36076791440287, 5.741015345819536, 4.280738503702225, 1.3208211381589214, 0.2921082530050509, 0.3118608495400798, 0.9410315175210276, 2.8166907929605056, 1.8288184534157477, 2.589453915434499, 2.352388313701076, 4.364669870945716, 6.431953109079792, 9.498882293701172, 24.79755763084658, 46.43715620040894, 67.88802992913031, 71.25297638677782, 68.71713269141414, 73.03116721491661, 63.75948036870649, 66.15638979019658, 55.45952150898596, 45.26479505723523, 38.00402502859793, 36.333915110557314, 44.960481889786266, 64.55968310756069, 69.51374253919049, 66.70556868276289, 63.7293291091919, 61.9558451252599, 58.71753631099578, 51.333615626058275, 46.280979187257834, 32.25315766949808, 20.52879902624315, 8.771841564486104, 2.3502616536232734, 0.5389503930364886, 0.3914324410500065, 0.5055941587253925, 0.5815785282081174, 2.210136450106098, 1.498605017700503, 4.2462775399608, 5.570422151396352, 6.278633052302945, 4.771642742618438, 10.119738578796387, 5.37476844364597, 9.129362663915082, 10.527265975552222, 11.535453373386014, 14.111915173069125, 12.729569942720476, 12.320278459979642, 10.928829408461048, 1.8461234603197345, 0.7091596241920226, 1.9791893781192842, 8.892325989661678, 34.682205030995036, 43.06864823064497, 31.131465704210346, 24.814153179045647, 34.53562998002575, 44.820551333888886, 38.721756012209006, 11.596062817881185, 0.4352242024915834, 0.3147942308456667, 0.1805198706325985, 0.1368221388228478, 0.1746730875944899, 0.0948601860492941, 0.1694885722451633, 0.13579221021744514, 0.10931786630422839, 0.178940917455381, 0.17156281658718664, 0.10526991133848507, 0.12498666261953693, 0.1771387569005451, 0.1413121341817802, 0.16268637031316757, 0.2251284503408017, 0.27061344995614023, 0.1600785457318829, 0.1910430688651339, 0.1242788203601395, 0.28628763953043573, 0.18726709809514785, 0.09195773937408963, 0.08165911981655706, 0.24227766560450678, 0.1313902077174956, 0.14752552093517396, 0.0793716425616895, 0.10507343276854485, 0.11292999384984856, 0.2427415624861756, 0.26416044622179, 0.1798128940525555, 0.13793471299352186, 0.10025234186961766, 0.2860146670812561, 0.18109786864970961, 0.10055991851033703, 0.1571046996621355], [0.012244808472572796, 0.07694317448523737, 0.014327165685714254, 0.023100479288146864, 0.015677940532294734, 0.02298785670239839, 0.041270102599575635, 0.026731374072692087, 0.018343465898426312, 0.02005692496294937, 0.046544736701874964, 0.12912442607264366, 0.053489304583279364, 0.034055324015958656, 0.14618569444264137, 0.027738507731907794, 0.0838009101308642, 0.02360867520403718, 0.029692719502735044, 0.09634638130063973, 0.061345045950504086, 0.060941972619583534, 0.040631212083803075, 0.03435567644755206, 0.07826652242651871, 0.031218803037078153, 0.04621035847512465, 0.029052314048092213, 0.013489645808154057, 0.0396186430307646, 0.018762577280041673, 0.010830723162319873, 0.05808623432512245, 0.04503706800601175, 0.004562369121554038, 0.038964806139589324, 0.039714580221522244, 0.06629157991659257, 0.08429113745449052, 0.03933979468720575, 0.02615759145438431, 0.07224924652086151, 0.023115536746298595, 0.07547210947039627, 0.09780747951158593, 0.050942169487356186, 0.02575875075924541, 0.030797740046475685, 0.05001851642924932, 1.0004243531054067, 13.845862765466014, 35.99180598412791, 39.78294149521859, 37.91457929918843, 24.68976893732625, 27.14227011126857, 29.005423399709887, 31.23706767635961, 27.516022959063132, 12.460768934219116, 2.667567917416173, 0.7564598538221852, 0.6160796349567752, 3.5009899447041177, 4.2084551049817, 6.837101588326116, 8.269063330465748, 5.493667740975657, 3.3434582429547466, 2.6692390922577154, 0.8872872014199534, 0.3282115560385489, 0.17197877168655398, 0.2311246971329374, 0.06453065021384148, 0.39562242105603224, 0.7194385016637465, 0.62907260872664, 0.5061726470387752, 0.5152503905757781, 1.1176046104200426, 4.826913841309087, 11.959292927095968, 21.86463082990339, 31.74217874003995, 38.82407496052404, 37.16979965086907, 24.012926701576482, 21.31096866823012, 31.52132184274735, 33.71306188644902, 29.950314529480476, 37.135890760729396, 42.02483884749874, 29.6909732972422, 35.51618329940304, 34.2484026570474, 32.62399031269935, 25.6907578053013, 20.080299531259847, 13.151671886444094, 8.470641778361413, 1.9428987512665412, 0.5112069478679089, 0.051161485138319196, 0.20072671134145031, 0.1979153678422013, 1.894599297834981, 0.6827940647640537, 3.1331584049809367, 2.7529137894030544, 4.299637463784987, 4.202914757113303, 6.456579219910407, 5.535415978200975, 4.929276425992289, 12.207852544323092, 3.8570168662455777, 5.130539613385355, 3.451640154084852, 2.265479132052391, 2.4217968602334303, 1.2551854214360638, 0.12203927722669418, 1.1454034284237893, 3.080828348475118, 17.845168267526937, 36.52999831784156, 22.324695433339766, 18.306721410443707, 23.512591123580936, 30.049409289513868, 38.495431330896196, 26.691799625273674, 4.307921509588919, 0.04840818046021366, 0.04471301281404111, 0.05315229867494876, 0.089056801892096, 0.07193703504820025, 0.011305485085974778, 0.04130580995772635, 0.07597806457910808, 0.06728709585243656, 0.047045631799846895, 0.05658508503749486, 0.0929681787026986, 0.024405600082489754, 0.04417892312631012, 0.03418809854455533, 0.03697003958927047, 0.03403786487216431, 0.056871452534030524, 0.048161503979034966, 0.06181590274096497, 0.023503956730447473, 0.05637418486238007, 0.09420881213079538, 0.02118786034594861, 0.014106773681217625, 0.12072679241217914, 0.08977942964843205, 0.030750997191775712, 0.04753004451612792, 0.0171530093141501, 0.017517328172201113, 0.057864750645333723, 0.0454469058933037, 0.013655075792133087, 0.10755821596831085, 0.0980853089582055, 0.007645313772598222, 0.04538723147444187, 0.16765757614085752, 0.04218750054978075, 0.0930679003678022, 0.08071778927959743, 0.029378893499773358, 0.048886207833645806, 0.021585821955194397, 0.012946904114928218, 0.09740665464872315, 0.017002415580434665, 0.10669868829990588, 0.009594840436963546, 0.03525788670465831, 0.02811548044724811, 0.02847906003045219, 0.07710780678016525, 0.06545112783750219, 0.062079850674396565, 0.11645155448106029, 0.04526241659937848, 0.04513148834267932, 0.08302223538198779, 0.08260267200849711, 0.06047698789306226, 0.030815660758244417, 0.057177776620993694, 0.022381687717091654, 0.015571146918040131, 0.023421970000790975, 0.013443801191545302, 0.06563860487433211, 0.03354393351342409, 0.036779329661400094, 0.02054434648955301, 0.07462098578652067, 0.02349048698951881, 0.031007699848663424, 0.03579580300157109, 0.09918944850083321, 0.08826830589603032, 0.029832794849250107, 0.05017694341199053, 0.02751324340821274, 0.026758600837521018, 0.03406478520182352, 0.05457432257131704, 0.019565207598310326, 0.05233861370793274, 0.03384104922353741, 0.028352450594426166, 0.06883076301986171, 0.16873273457730972, 3.268691738767009, 23.12864011333835, 42.05791619516189, 40.682356665211344, 32.49663683675951, 24.116524342567693, 33.020998893245576, 37.2531617841413, 44.35695855848251, 35.52061950006793, 14.324252682347453, 2.6668349244902214, 0.15889248840751188, 0.290842154814351, 0.8943634636459813, 0.8811861997650516, 2.2146229061388203, 3.2346622357445383, 4.73858549710243, 6.19907561809786, 3.8475894495364162, 2.7712800425867883, 1.609388440847397, 1.064788180012857, 0.569357158195588, 0.3286305142025794, 0.8599262179866914, 1.0796254032081174, 1.5273946018949633, 1.472214943458957, 1.62536658346653, 1.774609213875186, 8.436720140518682, 19.139791650156823, 32.79484483503526, 43.138133018247544, 47.655440453560125, 44.62053006695163, 34.89709992562571, 29.118797548355598, 39.783804416656494, 39.21522940358808, 35.33911574271418, 44.89403693906723, 51.097355581098995, 40.860832352792066, 42.16085095559397, 41.01205933478571, 36.46281596153013, 30.698690991247858, 24.52056965520305, 17.864244714859996, 10.647835712279043, 4.247534659601027, 1.3175193604923066, 0.16578588544601397, 1.2015818203649213, 1.318853824369369, 3.1273346658675902, 3.7932327533921892, 4.295053683942364, 4.189932202139209, 5.358728401122555, 5.096271336078644, 6.045379013784471, 7.9088240285073566, 7.905743497033273, 9.852535936140246, 6.649728494305765, 5.197025258694926, 2.663171185601142, 1.7142957857539578, 0.5119543126033199, 0.3061579991011851, 0.10309026861983923, 0.4473255112046196, 4.236983974133769, 13.288346875098444, 36.368533949698175, 42.14327481485183, 25.042886195644257, 15.54132100074522, 23.911382421370476, 40.696692928191155, 33.456436895555065, 8.60389449904042, 0.265015461632321, 0.061077830652075435, 0.04938353679233021, 0.0776129498356773, 0.03455277554871094, 0.038003909717043566, 0.02728232918607612, 0.08603150535735392, 0.04942749491742542, 0.04247976309289375, 0.057070972473030133, 0.04922994382439121, 0.11895882236140391, 0.04378391287079261, 0.015827772966135415, 0.045045923982416435, 0.03808396207469125, 0.0363117478968155, 0.060460762150826, 0.04657675917710989, 0.040311286105744304, 0.062323397686404575, 0.11144598960996636, 0.010926034076199418, 0.07316191004769457, 0.09866208123463778, 0.0709219838702871, 0.042885850979796344, 0.023400098190552766, 0.03985663590532157, 0.05248431213981202, 0.05497217501303362, 0.026772660466151375, 0.010457639300805188, 0.01845944203406332, 0.02817167874215351, 0.05250925979306621, 0.049293540613425356, 0.12791574617186863, 0.01011679720719375, 0.07277150398060199, 0.1516044028704205, 0.15822205422145708, 0.16819446587995177, 0.09110054827385372, 0.09819434625246833, 0.13860795106137955, 0.13841862009177286, 0.2279647223411068, 0.23872232815671354, 0.09662388899033109, 0.10937726110099785, 0.18130855815064523, 0.2743494156147203, 0.1941309394615312, 0.21362413862539878, 0.19821780403294872, 0.14988442822810144, 0.14134369700426055, 0.19400323260455363, 0.17339126927958382, 0.16330437344168464, 0.1903210616400165, 0.1850197638475126, 0.16233853575202728, 0.27426241867003903, 0.1009100360134917, 0.1460842797232251, 0.12759081763966432, 0.061548124367911974, 0.16129293298769384, 0.12412078408223969, 0.13603637776067182, 0.11133390328576488, 0.14758504596689057, 0.23425773627335028, 0.2006137440161359, 0.24101253268459152, 0.1890070982758076, 0.2147475912445976, 0.10467933415765725, 0.13956540774914528, 0.19655873338060995, 0.1187164934291955, 0.1754419487570563, 0.14351266045724193, 0.16474846450071182, 0.1015549441499095, 0.17019622298257966, 0.1694440778585211, 1.9206844077956293, 20.230779301735666, 48.9067667530429, 52.997285012275945, 50.59863798079952, 36.09472505507931, 37.784858672849595, 38.99562374238045, 41.92930167721164, 35.40582741460493, 16.774114101163804, 3.350972523612361, 1.1727428388211036, 1.9893561616059274, 6.2640026115602065, 11.45984576594445, 18.873558813525786, 18.272333991143014, 13.603031769875559, 11.092261825838397, 5.972667586418891, 3.0301275464796253, 1.4989047112964815, 0.31692165701139363, 0.32827783796575766, 0.185201924234148, 0.7114364375029841, 1.1486103337618614, 0.8986829737982444, 0.8758503054418872, 1.0370296888774442, 1.7050347020549161, 6.447158177052775, 14.094005630862329, 29.288526350452056, 36.753569495293405, 44.41250324249268, 47.14768179001347, 31.66689080576743, 26.72469066035363, 44.13540347929924, 43.22315823647284, 41.249841259371856, 53.31541668984198, 52.03270358424033, 35.16280912583874, 39.293547368818714, 38.50072260825865, 34.3948325803203, 26.244002234551218, 22.589682917441092, 14.935136341279554, 9.735762073147683, 2.9863644367264164, 1.0382998013688673, 0.1258105212341874, 0.6292277874965823, 0.8237867249596504, 5.006432879355646, 4.1741966336004195, 8.6064616903182, 8.870657836237262, 8.25602243023534, 10.31747212333064, 9.826010907849959, 12.569505860728603, 11.02535697721666, 27.81267965993574, 13.284524525365523, 13.555452439092821, 7.74835741327655, 6.436620239288577, 6.6153910852247675, 2.392792893994239, 0.25639006237108863, 1.7411632859899153, 4.9209663944859665, 22.59494673821234, 45.05981591440017, 32.25751542275952, 25.92135394773176, 33.30766923965947, 39.96804206602035, 49.96066447227232, 38.19374222909251, 8.102769053751423, 0.2273439000090284, 0.22467324089619423, 0.183337067043589, 0.2213923774299122, 0.1628868555229518, 0.12296055158179615, 0.15011056206159054, 0.2816730016662229, 0.155640720960594, 0.13950249660880337, 0.2295020463005189, 0.1967347957073681, 0.19614055662626223, 0.27655495210520686, 0.14590432566981162, 0.18539477920820638, 0.11591399824547192, 0.16655011943751769, 0.2128840364035099, 0.18504391093888592, 0.05990689973376932, 0.22925884402807684, 0.28575683252946027, 0.18295319570649057, 0.1348365614971807, 0.22258880758477798, 0.1518489687793678, 0.19445219077169898, 0.11157879861251963, 0.11493167434368404, 0.15591600699530495, 0.1787952228539413, 0.06907932790777377, 0.07170026791432212, 0.22828388989212053, 0.20483131850919417, 0.17598787833365703, 0.1443317616658826, 0.2786131852096127, 0.12158753816038372, 0.20442208966180203], [0.03537859534844756, 0.014847330767811548, 0.021867512484952327, 0.05978909839365271, 0.06211079296565825, 0.047960287155283075, 0.07843889220948182, 0.04448262719257225, 0.091512558020411, 0.05212828043788191, 0.046044423830725496, 0.042236334824514006, 0.056383148091094154, 0.04409748414951948, 0.053047122463824294, 0.016460063634440303, 0.09349568386472042, 0.025381693774233424, 0.07333633294629474, 0.04242902125922903, 0.08896125540617975, 0.11041155640756893, 0.03512018623070852, 0.03317444930754362, 0.023317736077813372, 0.078777005114863, 0.05684052939496695, 0.043677327057887474, 0.014221085490839136, 0.0938604796125043, 0.053779230558223305, 0.041444594446089, 0.029963487533912547, 0.07563562327695471, 0.03780681061588469, 0.008857191611652174, 0.036249989718799634, 0.011738567996109206, 0.12171843194312627, 0.06459810425557437, 0.015750946796258852, 0.02492796670975945, 0.07058651396824468, 0.06055071236445539, 0.016989985803863215, 0.04166312485692963, 0.03455123571198314, 0.015268297997423479, 0.07788539368418917, 0.06314243760801132, 0.05961493213450717, 8.633196565412707, 27.957499450252904, 42.64062350796115, 38.64301050862959, 33.69031998418993, 28.35642803099848, 17.894015504467873, 17.314397058179303, 29.047014251832042, 24.275127341670377, 11.037816386069021, 2.3098239783317815, 0.5653009984281756, 1.0577364938874398, 2.368034648318445, 3.1370535637101824, 5.579025870369327, 6.565373020787393, 4.0891807310042845, 1.955956689292385, 1.2127396151904137, 1.847226014060359, 0.44657422409903624, 1.0908018292919284, 1.9907930974037418, 1.4293206386989163, 1.332090475386189, 0.4422307813600187, 0.5569545624236907, 0.15591321843526057, 0.13631884970011252, 1.3669987119013265, 1.3526863508647489, 4.694088658978862, 4.728592768792184, 5.835781280071505, 0.39638501561937795, 0.5353975223918115, 5.3963365766309925, 12.36153591063715, 8.784178399270582, 6.823451249830185, 1.6097181650900072, 2.264867977749917, 4.368313752835797, 5.652649739096242, 5.150676081257482, 5.7337672960373665, 2.801136143745915, 2.044829875230789, 0.9955485405460481, 0.4928677529096604, 0.11514827038251585, 0.8000130554841411, 1.6152914853826648, 1.5282543364071077, 2.1446125209331512, 4.6454953955065825, 1.586750603971943, 2.932354380046168, 6.894834954892436, 3.885550883508498, 7.328955531120301, 6.903207744321516, 4.071732802737144, 6.172123541755061, 7.042516604546578, 5.590997434431507, 2.4066775941079666, 1.3123276132729746, 0.12276590396199497, 0.5459765224687515, 3.794369995594025, 13.099637723738148, 30.94950302954643, 46.08065589781731, 14.014685500052668, 17.621761829622333, 22.069496224003455, 35.33709964444561, 40.49338079267933, 24.877293532894505, 3.2413917972195536, 0.005839467856041607, 0.052028198711453914, 0.01912750900843211, 0.05765722891796501, 0.04505936116460831, 0.055881153656950885, 0.036607438683389656, 0.027335057102684534, 0.03744251282525159, 0.06469147505178567, 0.042412136681377895, 0.040063334088171684, 0.08016327185736549, 0.05693882996697099, 0.023054402929941015, 0.01791096904555396, 0.02625034938025619, 0.02489467252857022, 0.06033540718377598, 0.03615867586866502, 0.07103534190044289, 0.020111236766341235, 0.04595145906111406, 0.03276523961234958, 0.0950168586906887, 0.02093141815895515, 0.03110103808613795, 0.07369781153336649, 0.024694689106376424, 0.04837726498202932, 0.07351888403777154, 0.04201750946982254, 0.0914175401351625, 0.03599795828303022, 0.04983819082319256, 0.02984840197548751, 0.018741243646570274, 0.05282771105187074, 0.06692970817488048, 0.08218248810378775, 0.05372469275889378, 0.042433667582489794, 0.10343978857441295, 0.09006324990261948, 0.0559431876266195, 0.04557697230108804, 0.09236602593333491, 0.018657697927987865, 0.07957295514643192, 0.13413969727773822, 0.034908014349639416, 0.04654873951127933, 0.014973998618041797, 0.054023444066725435, 0.005580999845293381, 0.033640586996390935, 0.039086495375921654, 0.08302985029595514, 0.01930912164220166, 0.10710014901574581, 0.05178571273122103, 0.06499234842316759, 0.05241220411393912, 0.044601995182494004, 0.07299228285950038, 0.02475362616561113, 0.056700875396810235, 0.04154476427262829, 0.06170599593690807, 0.038966368958954854, 0.03209314493071889, 0.07745571028921874, 0.002946526177355179, 0.03050797494999584, 0.023581887024544904, 0.01799078583116493, 0.14416380454936337, 0.022149250895205527, 0.01643353017918285, 0.07370230080860277, 0.09482180504428764, 0.07051182805650658, 0.02968951150955212, 0.04443482330609714, 0.05147939630513711, 0.016489952554806106, 0.00035162124995915823, 0.04458233736635697, 0.06998917989192471, 0.04310169242202275, 0.062008367010181954, 0.03898821778655533, 0.8432973909281916, 16.213992776409274, 37.24631332582043, 47.779242223308934, 37.24813722795056, 30.996355741254746, 24.77271333817513, 22.161450309138147, 29.513078120446977, 37.416030360806374, 30.43971650062069, 11.336735313938512, 2.0134597391851488, 0.1963680081309811, 0.7652932765983766, 0.5281130681114813, 1.0848555161106972, 0.6518876877042555, 2.2555011126302906, 1.4745045044729788, 3.4101370649953044, 1.54497025234084, 5.79106233773693, 3.630914289143778, 2.0296859717176807, 3.1841124450006797, 3.0037481361819856, 3.6474411958648316, 3.861610697161767, 3.5679614736187846, 1.7343606703704404, 0.6356332018490761, 2.5093713739225945, 4.104943265838008, 8.229567024015612, 9.481274773997646, 10.483327584881938, 1.24512993520306, 1.7138733955160266, 10.112370406427692, 19.62943680824772, 15.218434429937794, 14.263403973271771, 4.909417956106124, 4.320288742742231, 7.965330673802284, 10.074978451575003, 8.206337276966341, 8.481550870403167, 4.949292771277889, 3.0898328846500767, 1.4658490592433562, 0.982092972243986, 1.429600107573694, 2.132391886365029, 3.905425042875352, 4.095087085039386, 5.5159781825157905, 6.674070233298886, 5.696697465835079, 7.515556898809249, 5.750817348880153, 4.769360413474422, 5.552760208806684, 7.193034618131577, 4.577611425230581, 3.098917584265432, 0.6893371297947822, 0.439504795377293, 0.37695052943402724, 0.6859797647883815, 0.04001773653491851, 0.28108942652902297, 1.8526882822475128, 13.295970982120885, 28.24099267682722, 50.36406847738451, 30.6792458411186, 13.64292129393547, 16.791651018204227, 31.369773226399577, 43.62117290496827, 31.757336739570867, 6.783653411173052, 0.09968607265862728, 0.01944544507310756, 0.018037724038285595, 0.04136819249740051, 0.09927621561913721, 0.031184122236745975, 0.0640022027636728, 0.029310707844072775, 0.037201853964718125, 0.03041936922067356, 0.028691860103619196, 0.09506991027944511, 0.04655260059441771, 0.09192467501927769, 0.014438677443972519, 0.017843681627944592, 0.057740502675334295, 0.03145801973709416, 0.09756177213163146, 0.008147773126350536, 0.056601306949291504, 0.05565885792396242, 0.0336534304604415, 0.010682117426767947, 0.05035023250046277, 0.016181263171376723, 0.13354363490737256, 0.11643359738011515, 0.03502953504662841, 0.07865656843228687, 0.09525308190214057, 0.03850746314011274, 0.11472163601748406, 0.04617752777712961, 0.054176328403334466, 0.01567775188314338, 0.07387381257309068, 0.021119948566680955, 0.017110003053300807, 0.05589909543613753, 0.030354129173041835, 0.030339404963137164, 0.12820443108437524, 0.19140927421469844, 0.12026065855377144, 0.17050926183019915, 0.21492567604347584, 0.12116759940381013, 0.18086392071939286, 0.20774991431784248, 0.22209586064902045, 0.14571428989931462, 0.12596317957485878, 0.16838292350932477, 0.14360071460325874, 0.1767814534926607, 0.11150349216956286, 0.19650964246642208, 0.1516117266709766, 0.2673690063097785, 0.234927189866862, 0.1458987025844474, 0.31551447606855826, 0.23573768024723377, 0.17481165757823378, 0.14084662851547042, 0.11865558177833596, 0.13277135699266387, 0.1285337722830234, 0.15929695218801498, 0.10893410988031857, 0.23175696481860456, 0.1676618662332335, 0.07036325296447163, 0.2106786684523667, 0.1659144503214667, 0.33571973863628607, 0.15248626200181825, 0.18524454936625498, 0.17591068731440654, 0.2027951487370076, 0.14788357510922417, 0.21062524148052741, 0.09075766264070427, 0.24827054160977566, 0.1314585734038584, 0.21280454712048655, 0.19411279849948423, 0.12117788796463322, 0.08687157439248216, 0.14342264512613898, 0.15078389205999915, 0.5736135427028902, 13.939324021339418, 41.203831857250584, 57.36953535387593, 52.03475106147028, 45.56440530284759, 39.75184494449247, 27.635259089931367, 23.256548604657574, 37.072140478318744, 30.676204043049967, 15.027121805375623, 3.275721851856478, 0.8708228687605551, 2.162326434927602, 5.972272897920301, 9.210432171821594, 15.0159675651981, 11.572701181134871, 12.74853950546634, 9.526650713336084, 2.766222636545858, 5.000628752093162, 2.164044678211212, 2.144337219576682, 4.20277992563863, 3.3892207809032935, 3.65809214691962, 1.643341947947779, 1.3151216891504105, 0.8947830346803513, 1.6159680942373893, 4.874990332511164, 4.888029271556485, 7.764352838839255, 7.700621187686921, 8.375666487601496, 0.6222524037284236, 1.099242279606481, 7.8906266823891675, 18.466538383114724, 13.944515278262477, 12.037816816760648, 3.2886661637213925, 3.52184469661405, 6.037058195760173, 7.293181063667421, 5.897084493790904, 7.054933357623316, 3.36319217758794, 3.221570834998162, 1.4087329756829048, 0.9737119703523576, 1.0414703022087775, 2.6482509797619236, 4.644130900982888, 6.727438982455962, 7.599148490736562, 9.72325755703834, 9.41504849541572, 11.963512416808836, 17.813754004816857, 11.426334015784725, 19.177928855342252, 16.27499936088439, 12.939159831693097, 20.42983566561053, 13.686692003280887, 10.303885033053737, 5.54863142390405, 3.2220711823432677, 0.346074121733827, 0.9042343533327504, 4.925797773945717, 17.06545599045292, 37.539451660648474, 55.86015239838631, 22.239024985221125, 26.031429383062548, 32.03989448085908, 44.92776540017898, 54.418222442750015, 34.241028601123446, 5.71231585356497, 0.20658490908963068, 0.2110823355014286, 0.27078646325295974, 0.17777980395382453, 0.16789846482776827, 0.17359152466299074, 0.22577804693531608, 0.11939461147713086, 0.1405513935512112, 0.29534191013343875, 0.1350562295485889, 0.17345277081814506, 0.14798456081940284, 0.17910907375476054, 0.22449264332892435, 0.15842730449813028, 0.22800639752418767, 0.12071371529131167, 0.2250910652500968, 0.09946736221712443, 0.19371575045008815, 0.11482993020646035, 0.15935851501361017, 0.14910076624683796, 0.2858748407133164, 0.08337233756338397, 0.24188311500174386, 0.20888948542696817, 0.16518913359651644, 0.11305974616158394, 0.20495715611163648, 0.15762165579343998, 0.17122723943283483, 0.12193862093432296, 0.1270370739662359, 0.1090683974325657, 0.11455332650051964, 0.15472172188662714, 0.1706443384530083, 0.21271226416912772, 0.23523157192093713, 0.13285889019889216], [0.03230691985076955, 0.020119294096084855, 0.03165057402164225, 0.10414424472518506, 0.03123261751757274, 0.01812745974729619, 0.02761783164685532, 0.014102069901362544, 0.026753240137270866, 0.0477558680840077, 0.05104976653632137, 0.04070452669815671, 0.02477394664780267, 0.03407845987127193, 0.08216751108486807, 0.02703177438478076, 0.020159414120679422, 0.10067866213860051, 0.01678101617031761, 0.03129570868857686, 0.05408256690228178, 0.0599099564245872, 0.041170212395128705, 0.07377625127593357, 0.030798174801372716, 0.07494941534053895, 0.03773821510314461, 0.11584531080218093, 0.042474530712370916, 0.09429118956529325, 0.0066618378660942045, 0.06358577652023205, 0.023291606733935977, 0.04177804187601132, 0.011191249885145697, 0.011912162562141256, 0.019494292754379493, 0.054946855807136145, 0.10221255402411185, 0.08119956665341893, 0.0310583803952942, 0.038985080656505404, 0.10652268726018169, 0.012280962076939404, 0.1077442680816016, 0.060972700406226425, 0.04594086023468164, 0.05130465548004835, 0.08533677852322018, 0.08532692663251393, 0.009609898852725184, 0.0738213049067605, 4.623256537222094, 22.697297065488755, 41.44482228063768, 41.94268480423958, 39.819243031163374, 23.658026726015155, 27.58165401797141, 20.878160615121168, 26.754424187444872, 32.28042990930619, 24.3444356226152, 11.087806013322647, 3.9678836397586332, 0.5017922788618073, 0.2917749741144719, 0.9318439169756828, 2.5051695348755008, 0.2546426924245973, 2.5349756258149303, 1.405259716895319, 11.671060496760953, 4.53929526190604, 2.622147115968889, 3.5464033917073285, 2.122504326605028, 6.069100037697823, 7.651732765859173, 9.436948068680303, 2.9442602444079617, 0.22362628981711405, 1.4726222570865386, 0.7977665179679472, 0.39397686419467776, 0.7701105600403202, 1.0033443125505601, 0.05134762918216087, 0.10434258488878127, 0.03912556202962034, 0.3891688044513426, 0.26049057862931685, 0.182695621624589, 0.15850791226952307, 0.2504704396931395, 0.07392581462139085, 0.6991247304024235, 0.8175056007119917, 0.5435700257939677, 0.2016253324766313, 0.1680132247988255, 1.1330585037508318, 0.4947680186840796, 2.916955399897791, 1.8522977612672316, 6.838219463825227, 4.573339473816657, 3.886041670076309, 5.243518092939931, 3.7353714194989975, 5.901404003943167, 1.8111735486215161, 3.2758478579982637, 2.5938190231400156, 7.039414500036548, 4.3416965488464605, 2.251921214403645, 0.6596913044491123, 0.3245421480988303, 0.4734698244400563, 0.920682444928154, 4.063941749834245, 17.332490951784198, 31.97712479099151, 39.832987016247166, 50.49003147309827, 15.73626377890187, 13.043457615760065, 26.584403168770578, 40.70490637133199, 37.21686024819651, 20.06232919231538, 1.484953208315757, 0.04034554172727851, 0.055797401094628926, 0.0036271095919918513, 0.04791801442362128, 0.02996708240149723, 0.03888482656029444, 0.04716466271108197, 0.04754603277110765, 0.04823072768387295, 0.03708180798698337, 0.04641156380755767, 0.028311022474700888, 0.05358983064070345, 0.04697336672594951, 0.035197473010949554, 0.029114181393637296, 0.017560895592454943, 0.014769031793900557, 0.03647072646286219, 0.038591771116179806, 0.02411955434288229, 0.04384393202922037, 0.08156515913264406, 0.025901369517669085, 0.06391088891353819, 0.0283355621861354, 0.06699624291110425, 0.030474994864855564, 0.02365273292056255, 0.10537176272801815, 0.013717853824698157, 0.026323072191688324, 0.038628796145560286, 0.10702897178670091, 0.011982284505070459, 0.04378263350395907, 0.013735865509407896, 0.048215608938687274, 0.025999618378738244, 0.026006497848298282, 0.009342440321380574, 0.03252522426567251, 0.022530745444518906, 0.011093337145153315, 0.027806187769578352, 0.040867247603713505, 0.03704660241642306, 0.032411747491888465, 0.047683449792525465, 0.031366276877721956, 0.10593508250050007, 0.00892929006142602, 0.05086358418808349, 0.04068220289604318, 0.1371432675589477, 0.014651185446118396, 0.12441832497115098, 0.07573058753604851, 0.028691911814554084, 0.055037518482535124, 0.054840656868632764, 0.03883654386886666, 0.029455393124672196, 0.046466496142168204, 0.05121866211054787, 0.0379932304513791, 0.07918635653632303, 0.01782100542538589, 0.07270685382067196, 0.054608888458460576, 0.024197197354008115, 0.03598051446099435, 0.043189049428028446, 0.056493640952413125, 0.02913495386770416, 0.029966402498464433, 0.06259224858255157, 0.02836158044726378, 0.09370907765602873, 0.01182908224197285, 0.058258450890500704, 0.030671111458251556, 0.0422259351809419, 0.047514006465433106, 0.04781221768127815, 0.09531744860953863, 0.03098763792114633, 0.057844127558412096, 0.02716995557890304, 0.03755863643281403, 0.06641188636422157, 0.1265375080308126, 0.08724635992679866, 0.030518730824452736, 0.31493283147292755, 9.135615902562296, 34.35779756115329, 48.990532890442886, 43.760417046085486, 39.96206045150757, 16.425069243677203, 15.634831286245777, 25.685031144849717, 37.68093155276391, 41.29988285803026, 27.172617489291778, 11.447675631892297, 2.2728164157559796, 0.7349573592505148, 0.35040512320495426, 0.11731938654256445, 0.3181305437559082, 0.10249058265359172, 0.9081439758020063, 0.7560631428514758, 3.5372640240576962, 4.700472316434307, 4.031477272510529, 2.6213829892296947, 7.009916315155645, 7.42560028068481, 10.84740492605394, 14.303732802790982, 6.068615624981542, 1.2094666424297518, 2.914427677469869, 2.0166383299135395, 2.3177981568921, 2.0181276048383405, 2.5683199397979246, 0.18955682764851278, 0.3300955807489734, 0.23152802710331258, 1.32344814558183, 0.8078762432259898, 0.48854677186858275, 0.3737173319583939, 0.6611268919321799, 0.39547223717935626, 1.7529263515626232, 1.3410621617109546, 0.6190531592695945, 0.7361491469125594, 1.0037674995199328, 1.4125357135649652, 2.69822834960876, 4.842366018602926, 4.786870364219912, 6.246808901909859, 6.106658202986564, 7.29147385204992, 6.634555295590432, 5.87687595236686, 6.881421429495658, 4.892471846072905, 2.7950378387205066, 2.8523853421211247, 2.9038676763734514, 1.306191310286522, 0.7988787550599346, 0.46294383764747654, 0.21536796924567994, 0.18795093881987757, 0.5037561299339418, 3.031021846878913, 13.338458095827411, 34.24667681417158, 44.82158291724421, 53.49741074346728, 29.755325663474302, 9.836353217401813, 21.170532126580518, 36.90771864306542, 43.07703425807338, 28.864692680297363, 3.430900376650595, 0.02964463216372796, 0.0688873692565868, 0.0435549330206648, 0.07490672892139805, 0.04653472776314424, 0.05134915752756981, 0.015233685187394581, 0.05257463773652431, 0.047047872607025414, 0.037046115950591145, 0.04638610670583383, 0.020532841764150128, 0.01521460097959085, 0.07955377230480795, 0.07814430075907901, 0.03985117369842145, 0.013008621115718159, 0.05177309143266851, 0.04773427206542223, 0.06793873790170878, 0.04521070949492916, 0.049462011008853876, 0.08914663336209713, 0.14254742031616552, 0.06417850257768747, 0.02978202620250804, 0.09567551044446808, 0.023251639926926266, 0.07979816201353267, 0.04901368486424608, 0.045926526729618354, 0.03249289535526787, 0.001966253715387035, 0.03770919186213324, 0.05103127700426886, 0.039226524757161256, 0.040844870175445275, 0.06833609238627457, 0.014593800672540262, 0.04506075544463051, 0.0073607647772728204, 0.03225020636173506, 0.017549814130630226, 0.1305670615646147, 0.1972712870807417, 0.14492180258516343, 0.22364941035066882, 0.14386332954370207, 0.07537259464903225, 0.08597646193999438, 0.2826648710235473, 0.12545684142218483, 0.1344254787170118, 0.15644826956333654, 0.269990834978319, 0.21967882260439858, 0.1425938452443769, 0.10539500583564082, 0.1618948635915595, 0.15571383639208733, 0.14766732380995828, 0.11585578322410585, 0.22602340957570463, 0.19641201222135177, 0.2080447049511056, 0.11234003720023941, 0.2648612021678879, 0.12816409655516187, 0.2513522068939863, 0.18284081060799862, 0.26260488936978005, 0.17468782712615308, 0.2990317572989772, 0.1749999619900219, 0.17488000794283806, 0.12207751267499502, 0.12991628519469692, 0.10296525839235514, 0.1706131586744901, 0.14202905458308038, 0.31562828609058935, 0.20760087957305295, 0.20613740648954146, 0.12518488020906526, 0.09384812261428564, 0.24509469347615398, 0.1449197188260094, 0.24287404973180066, 0.15953474587971167, 0.1370745954374152, 0.14398264007702952, 0.28718138834641826, 0.23876558148091842, 0.15878964876455648, 0.24798189500166526, 7.3286785137268815, 34.00669836228894, 56.799328634815836, 55.408075701805856, 53.55247689831642, 33.85245507763278, 37.708121422798406, 30.819503914925363, 35.68690053878292, 42.13020939980784, 32.34609234717585, 14.033792345754563, 5.150575570521816, 1.1761470884084702, 0.9463764823252155, 1.7804099090637702, 6.632839258640043, 3.4690687156492666, 10.545083342059966, 5.594649161061933, 18.4517922324519, 13.336051721726696, 9.41182921009679, 9.667120595132152, 8.6413727460369, 13.619527297635234, 13.92232152723497, 14.909896869813243, 4.607599416086751, 0.4480716501993518, 4.087591925936361, 2.7497097032685436, 1.6999111060173282, 2.410985827445984, 5.175195307500902, 0.2306341710350206, 0.2135698076698088, 0.4945475079359547, 0.94135272286592, 0.5215101256485909, 0.6453982488282266, 0.437370014767493, 0.6187266832397831, 0.3956313076759539, 1.4733514502163858, 2.044160375672002, 0.8814580077605864, 0.5148107173942751, 0.9110624030713113, 1.7329822024030073, 2.789560248774867, 8.250078078239195, 8.782715355196308, 17.16251700155197, 12.98396114380129, 13.062884134631004, 13.965871603258195, 12.301467753225758, 15.745010664386136, 8.213016092777252, 11.292367423734358, 8.929821887323934, 16.699285084201446, 15.077910615551858, 6.106129173309573, 2.396124702307486, 1.1028479183873823, 1.2132723220894415, 1.4568464842534836, 6.161953816490789, 22.423531316941787, 41.69832506487447, 49.02782678604127, 60.01161252298663, 23.782197198560162, 22.294910915436287, 36.547582303324056, 51.514538872626524, 50.55471135723976, 28.905169579290575, 2.88288765376614, 0.11024593585921873, 0.09805407555353257, 0.08122086389771394, 0.18271763899153282, 0.15827195718884468, 0.28281343079382376, 0.15498049106569062, 0.11053687307022272, 0.09802710159771866, 0.17079971640581088, 0.13029522292556303, 0.10159908613610653, 0.10627067497661037, 0.21608177933000752, 0.13833982028788136, 0.19943041396477532, 0.140597420113702, 0.2220977299035557, 0.17033601870700238, 0.14755855464646894, 0.18498187313877767, 0.08776230482204307, 0.18337124988677042, 0.2521138668300644, 0.24773883062504956, 0.16246941421301136, 0.1279210398394254, 0.17845671924371875, 0.2023798831167721, 0.1297933280828499, 0.09549223156946321, 0.11472286941904215, 0.16267156949447048, 0.22689547810343005, 0.1963109345806222, 0.15796877023193145, 0.1359124553780402, 0.12173055911496763, 0.17225721400351296, 0.16765774468020087, 0.09977052619139995, 0.18174562663320573, 0.13025811362651088], [0.12072158301429403, 0.015850663673312917, 0.010263807564643363, 0.08635933736279126, 0.03430153701394316, 0.06593505025751169, 0.023164623830046867, 0.02047589461829874, 0.03472385447352164, 0.0437543801813116, 0.02702782137109147, 0.05466863948611483, 0.03408287636815541, 0.021619614093534408, 0.04577281884849072, 0.05405951531664018, 0.028003782912668203, 0.009754917381571667, 0.054170460169834476, 0.029665956221100305, 0.055012704894667676, 0.07740109588109678, 0.026553821704921224, 0.03379635948447451, 0.09383128400170997, 0.025961597435056202, 0.03517883792219143, 0.02988396569215242, 0.0615458031215014, 0.05906325689847431, 0.06485096689674162, 0.010794533168776863, 0.050098438551949884, 0.04936431564631001, 0.04156880794213184, 0.016256927760438095, 0.0987191777676344, 0.03192982456136135, 0.04969722298424571, 0.019685079291042303, 0.03442969203235642, 0.02879574162615163, 0.05706435347336435, 0.09055776731862177, 0.06077446749493961, 0.011314714530242548, 0.021281526086010763, 0.028100528326185963, 0.022126605336163795, 0.03913462101932495, 0.007330584264690838, 0.0339507759969321, 0.0551707603247656, 0.46166578848515794, 11.89363637278157, 37.46158869035783, 44.322037696838386, 43.602318071549945, 38.83916431857694, 25.208533771576423, 23.830350175980602, 24.52276029894429, 32.94246127528529, 31.65944810836546, 28.886381426165183, 16.02742425857052, 8.182806488006346, 2.3786350988572647, 0.9558783627806172, 0.20130164500686432, 0.920938992452237, 0.6318198613101437, 2.865267876655825, 5.841613354221468, 3.6546404611679817, 2.513377829905479, 7.046412008423959, 4.440261298610318, 11.510921889735807, 19.404683036188928, 6.968613757241157, 1.737567943430716, 0.33024901283844826, 0.2761180981272652, 0.6413473597457332, 0.29749210443227525, 1.6600691406957566, 0.6694740020940382, 0.3390829871979452, 0.15712627269808324, 0.06463212622029167, 0.09251479254735094, 0.07154163408784137, 0.5633554415356729, 0.2731664839290804, 0.459140211103424, 0.7114125968467805, 0.7019633006665015, 0.309617284445032, 1.317591188896087, 0.7351313531398774, 1.3694081503537394, 4.633314965232726, 3.388550545900099, 3.445523708097397, 3.446172615212779, 2.4831910239111994, 6.449652804482368, 5.533086090318618, 3.4415790294447257, 3.84540272816535, 3.7137037563708524, 1.2518461361046762, 0.9568576070089495, 1.1026240981394246, 0.10576133375927325, 0.2036016401384146, 0.4530379837078433, 2.357460673778288, 5.384912673504123, 17.802794902555405, 28.526280387755367, 37.47417165387062, 24.16040978124065, 40.43454916246476, 15.056348366122092, 18.381723011693648, 43.84833697349795, 38.22552519459879, 36.92756191376717, 9.816117709682835, 0.07268635330781822, 0.013066498100787643, 0.11342767520897812, 0.04707522194592222, 0.0681559085064838, 0.044997714069341464, 0.0207418765151693, 0.035792983798009735, 0.008498218132092828, 0.018302145031010433, 0.06148257788511054, 0.03203719178394925, 0.01605569753014753, 0.052268696693523284, 0.009263055417836915, 0.014949345908638452, 0.04172402884690993, 0.09022192203349645, 0.025287903544883576, 0.021176564379505092, 0.05987455167116658, 0.014232871753554192, 0.07183564331142173, 0.02334217236737811, 0.04021275187692335, 0.04736231722598595, 0.001980797296123309, 0.03652290471138493, 0.08176043494454316, 0.028064807561496576, 0.11800819917792275, 0.08202485019160856, 0.039707214286130284, 0.05916753678672737, 0.10272497491490457, 0.0161245247844847, 0.05040466687792251, 0.01732781908715204, 0.0501607061784354, 0.004443588625309208, 0.043404933005090685, 0.04590207320307532, 0.06887551021551894, 0.028965294120773196, 0.06275187066245465, 0.07633972702728165, 0.07741994930491333, 0.046914642256113796, 0.08675206467629441, 0.05014627691238158, 0.03339985152706504, 0.09936700469904369, 0.034289781394745075, 0.06557088270182572, 0.033892472875454736, 0.11142435528698469, 0.010129932742265445, 0.057298538890937646, 0.04430721221011012, 0.045777909502747564, 0.06855409802688707, 0.02156121712628632, 0.017915027396332835, 0.05238521483636672, 0.03226093159267499, 0.07021274733086748, 0.07335789832136325, 0.02186358436912058, 0.055024613731450615, 0.028430675832374443, 0.03179589707043863, 0.063040547914082, 0.021048108671581554, 0.0892339673854651, 0.035956827022375605, 0.0985850204503344, 0.06717321688249227, 0.02823386784462679, 0.016085325980619077, 0.013514493869978094, 0.03263937519682992, 0.07370197139079533, 0.014583535094354904, 0.04855318558252147, 0.05733843675003417, 0.03575836811515112, 0.025488160843510303, 0.0672281836910594, 0.03994306594493889, 0.090400995085797, 0.05625375584068318, 0.01799698731291198, 0.04248538617825797, 0.043430987655395464, 0.10571349156840194, 0.02622825731973975, 0.08733603051833569, 0.15023407075674305, 2.756836404723506, 21.367266447313373, 45.6151411610265, 50.47067065392771, 43.065090640898674, 35.66795156848046, 20.571211614916404, 20.93308556464411, 33.14898190959808, 45.05844308483986, 45.282657530999955, 34.78932103803081, 14.593753833924572, 6.25194622624305, 1.826172324438249, 0.6056257217161117, 0.110575185127316, 0.1935541671850989, 0.13975859980189032, 0.6902294077219502, 1.2237193098952694, 2.8776530056230487, 1.8390824381382236, 2.2098251119736703, 3.5811671133964293, 5.441569839754413, 19.370783951974687, 13.76106994767343, 5.738640350680198, 1.0621494054794312, 1.7011226281043024, 2.0696185192754193, 2.2688486931785463, 4.496827269754102, 1.8138465213198818, 1.1323192595474183, 0.5922577325855533, 0.11839435345703557, 0.40548675303016946, 0.7658475565333521, 1.156345860612008, 1.1034208295806762, 1.6683083243908423, 2.9122666966530586, 1.542790762839779, 1.3640888035297396, 2.2395255440665833, 2.335950395753307, 4.839356580088216, 3.5675582049354433, 4.508767454854904, 5.011304953405935, 3.953424067266526, 6.5150117489599415, 4.619095392765538, 3.7763079712467813, 2.745293849898923, 2.0175224566651933, 1.5287525999930598, 0.9358760522257898, 0.6094551807449711, 0.6873923083466869, 0.29805766118149607, 0.1313931954604003, 0.14647421847668388, 1.2243117103653571, 3.7834719352183805, 18.172068403613185, 34.46716108629781, 50.88748132028888, 40.92897176742554, 44.47311562876548, 26.53915470646274, 15.369348602910197, 34.215576341075284, 38.96815146169355, 45.19487488654352, 17.0043650750191, 0.6652342263729342, 0.06143363635806788, 0.038474115332768816, 0.03456569179111431, 0.001507558690425339, 0.008231237448090989, 0.10817611950539774, 0.02174700302402339, 0.007753534225611798, 0.06643849259783184, 0.028516531306048556, 0.01566541882517237, 0.03292928585001538, 0.02223650256412164, 0.039027579384104866, 0.017315655526134278, 0.02552068127589601, 0.04423613457249538, 0.04323059437616218, 0.03465201074798261, 0.04071028384890768, 0.02610083583051399, 0.030100919877088843, 0.024895854219193422, 0.009515068659018125, 0.03992635756731033, 0.0639448764042989, 0.052827117333729426, 0.04113900963397276, 0.022174953145065138, 0.03441802451326963, 0.03855966054083359, 0.06643466215821044, 0.03801240180168421, 0.010860128489683473, 0.024032521009024595, 0.006989815907042113, 0.003854631720441244, 0.06471943726102192, 0.05237561575467548, 0.05693821709663157, 0.03790399269951928, 0.06192233150584563, 0.029541926586159298, 0.0357314822594485, 0.17493090682452725, 0.11494837506043334, 0.1431310873839163, 0.14708503570047118, 0.14700903977838256, 0.17728435957143385, 0.2712349311238335, 0.14769784475286163, 0.21722409303390214, 0.09943347048735428, 0.22229881266192084, 0.10880977381020786, 0.17663519198615707, 0.12319532688707115, 0.18942446297695562, 0.14774080696365527, 0.09988841180118824, 0.19183911082725372, 0.16821090612680684, 0.13149042733974997, 0.15839249346285098, 0.2029170486475191, 0.10197216329435188, 0.13714034110307693, 0.15241290142218913, 0.15050128222473208, 0.1355214900667629, 0.13714184263540855, 0.14950814116145336, 0.1582559919165027, 0.19895649665305692, 0.19375981582749277, 0.08678651565024931, 0.16718166700053602, 0.13963570397707725, 0.125615015595911, 0.12766189527727906, 0.15019133837232668, 0.15353852973109292, 0.1189755383999117, 0.14022831895178364, 0.18197050408249904, 0.1489585803280915, 0.16723104902813513, 0.2472024924692608, 0.1524010117376043, 0.14985151709087435, 0.11914462932655889, 0.12517745681707898, 0.17849459463069517, 0.2055757567887345, 0.19725984172715297, 0.182051464254337, 1.736920629778216, 19.148922927917976, 49.367496198223485, 61.20458572141586, 59.387296707399436, 51.76172664088588, 36.10734331992365, 35.62085174745129, 35.57100234493133, 43.9106281342045, 41.11615903915898, 37.99903577373874, 20.382471084594727, 11.005993216268479, 3.0043335499302035, 1.5954596140692312, 0.6543366562935614, 2.1367523362559657, 3.6915291268979353, 7.41724955458795, 13.798124578691299, 11.715115577943864, 9.304509239812052, 17.91819887776529, 12.46428337789351, 23.52729608935695, 35.20155429840088, 16.925823534688643, 4.580536532786585, 1.607372832875098, 1.6609367199482459, 1.9167032020707286, 2.0671314914380354, 4.54798037006009, 2.699185407930805, 1.22880392737927, 0.9024743122919914, 0.2054890816009814, 0.6234544876121706, 0.6969295514206733, 1.9500684762193312, 0.6728615203211386, 1.7156070831321901, 3.389243824828056, 2.1523861683184102, 1.3463090672608347, 3.3600069678598836, 3.882627246841308, 6.272917178369338, 10.812353645601581, 9.765102382629149, 12.119852208322095, 13.834104480281955, 12.314225262211217, 15.799688504588222, 16.00274372485376, 12.658909424658745, 13.490373453786297, 10.398736769153226, 5.242434047883557, 4.135358304746689, 3.4388010107701827, 0.6767615820130994, 0.7586435721285882, 0.6782483441695091, 3.146058099885141, 7.744126156453164, 23.988653113765103, 37.190372482422866, 46.85443755119078, 33.476582188760084, 50.33441143651163, 23.513850204406246, 27.475175396088634, 53.65957329350134, 49.89858511955508, 49.477424544672814, 16.057732412892005, 0.7000233208940876, 0.2027782028721225, 0.20606095091469828, 0.13309723547389432, 0.1376702134767848, 0.2263799162521478, 0.1391254281324725, 0.15709722264399453, 0.13436854306247928, 0.10651570819919148, 0.21801517074627264, 0.15229415779392566, 0.14652750755269683, 0.2114497512699135, 0.11827937898135955, 0.23409080571464955, 0.11912208335894732, 0.1862321439529619, 0.07740934664804129, 0.22366641750258787, 0.12340064611165755, 0.26940174400806427, 0.13581071890169574, 0.12405277845720131, 0.179458363882957, 0.1313635785012476, 0.169234445558921, 0.16803064563822362, 0.22132755106975957, 0.08579435517951366, 0.18064535583459562, 0.14311709861841895, 0.13727318074914718, 0.12252942794152807, 0.20505058819488173, 0.1594657979665264, 0.10094348341226579, 0.05403010137078743, 0.18517074445562978, 0.15144573073954354, 0.1963821654358218, 0.18336757266473386, 0.20466397426301436, 0.09566986437646613, 0.12204714494967654], [0.07871546527190555, 0.056554449181402885, 0.016282007563859224, 0.04044477692655018, 0.02266002469696105, 0.05295988037100723, 0.05994692016693373, 0.03173890204409198, 0.04400145885865054, 0.10532850174293404, 0.022535995062020038, 0.047723565986680413, 0.061089444545007525, 0.025770812813613205, 0.05877126248613481, 0.04697633148621648, 0.05376623770702751, 0.040726574708617506, 0.021504116762850075, 0.035883029772629665, 0.016381602824455308, 0.04861386740700372, 0.0348274908479183, 0.041648768369228616, 0.08327610159833586, 0.054068049536116665, 0.04160977066344312, 0.02309290076335592, 0.03329965871788802, 0.03412431789441936, 0.013128717846777892, 0.054564114449726, 0.09189882721271246, 0.0637749083069784, 0.07846221192589692, 0.035730156927339496, 0.027900719188994942, 0.08798338247523194, 0.07028929483626159, 0.011556361644198338, 0.054802827446931796, 0.02476547946101956, 0.000795368403252665, 0.027606033892821402, 0.10479231680473013, 0.03565984920808866, 0.02211899233741626, 0.042798804239399975, 0.05543719421351149, 0.09140715198290926, 0.00295553321672243, 0.05552412604071921, 0.04328557650648779, 0.06847424102166007, 0.21249014463636184, 6.026592821844163, 19.7164761635565, 40.77473632750973, 46.23956680297852, 39.50797550139889, 27.531402572508785, 32.19614994141364, 21.198153457333966, 16.272522384120574, 22.922319519904352, 37.50899053389026, 30.599162809310425, 24.31289976642978, 17.09315576860982, 8.587805917186122, 4.561715529810998, 0.46988934398658816, 0.6121984496712685, 0.5246308614169398, 1.054073735590904, 0.8490171259449375, 1.8862984593837493, 3.3918740191767296, 6.305898427963258, 19.77522150162728, 16.928339735154186, 12.865871325615915, 2.4828458553360355, 0.9526764216922945, 2.90439278368027, 0.7078124126118999, 1.3326593416352428, 0.28261103036422885, 1.6453184547924227, 0.38527444245353826, 0.47169697440920344, 0.062082765638948455, 0.6211232514150682, 0.5480594236043193, 1.8709094077348711, 0.8782161075261332, 2.0650825433192717, 1.464593900788215, 1.9020542526437392, 0.9484751955155404, 3.3558217988860224, 4.266298788209116, 2.541847373208692, 3.4016032132410237, 4.607160600923724, 1.412497470455785, 5.511193381201837, 2.4838075714726604, 2.4526357602688575, 2.5914231904091376, 1.0383974929009716, 0.8119849259814909, 0.33643388579930034, 0.18731598982647543, 0.9361651431648963, 2.4675532694785827, 6.640485919290974, 12.374611131606564, 28.9451071523851, 33.73448979470038, 31.26487728088133, 27.49411063809549, 16.967792895532426, 26.0089090947182, 22.46077226054284, 23.325052799717074, 42.455707288557484, 40.74420459808842, 29.80366103110775, 3.186973568893248, 0.00978957615687602, 0.07479852666297267, 0.08451918650779032, 0.2582480247703291, 0.018867299584071004, 0.039455565894323016, 0.05164135495320924, 0.08064981429807602, 0.03879731250626426, 0.02111851023660312, 0.04096559414099302, 0.02818339414173557, 0.057622551948072455, 0.018423857249980493, 0.08007231423811567, 0.04977394285942278, 0.03603062810256116, 0.053184198576115796, 0.05712378657453003, 0.10157442576582394, 0.028798421018666802, 0.03956508199353853, 0.043827947604680256, 0.0396790107591979, 0.023190517601887548, 0.07802437735541214, 0.03941120174262793, 0.07314955304947592, 0.024734696133002162, 0.018542371051866683, 0.06904729011078035, 0.055764386535532055, 0.02624343735195937, 0.02716406244754551, 0.06458606901428392, 0.11897926924810295, 0.0905529945908535, 0.030012701022168322, 0.042377237545987295, 0.020320141282413277, 0.039264132013364185, 0.02984651739919378, 0.03402638121417934, 0.00841197482640705, 0.049756096841226664, 0.03862971928150904, 0.04072745954017005, 0.07194510195404291, 0.045744396986499916, 0.02613515848474157, 0.06457969516275391, 0.0881276827966494, 0.05015633564682738, 0.03142085489666751, 0.05290825370578997, 0.05500333563935372, 0.036117858704059355, 0.012969540097870895, 0.058749605180515405, 0.07778017916866849, 0.03546929249780313, 0.021077664343700297, 0.04190257329854273, 0.04469968671459825, 0.03255748039772434, 0.037350249026090875, 0.058369767296338276, 0.013291354482663015, 0.04856168149760173, 0.04157759880106296, 0.058292216215763366, 0.033223498086895675, 0.022834072212478327, 0.054308865444674614, 0.028112998322373437, 0.05581894731749931, 0.032416286562839826, 0.01888717765048627, 0.04812681934826317, 0.0532092190077228, 0.14035682254020246, 0.022125345121528354, 0.028275073798854026, 0.07896389226399123, 0.08029626472102058, 0.07050723152896089, 0.03327507112595824, 0.09595728524389768, 0.057454843810128595, 0.035365943406378074, 0.08722030527649388, 0.031157596442367763, 0.03188440703877038, 0.03644073795106623, 0.05646054212364459, 0.1148426089616072, 0.055089072369399576, 0.015368904494079611, 0.0807363439291235, 0.07250554889680878, 0.8134155492148092, 12.541148104975301, 31.97258660870214, 50.571353973880896, 49.07624452344833, 38.723525001156716, 24.851639270782474, 24.641113896523755, 24.361417524276245, 22.816419447621993, 34.77941313097554, 49.26021545164047, 41.66918185449416, 27.60234844300055, 17.38959477793786, 8.381864813066299, 2.61554061885803, 0.6030729941783414, 0.06471268036552975, 0.12402952002782015, 0.35206183430648624, 0.6694457487713906, 0.8053510948534935, 0.6468384941258739, 1.0761233395145786, 5.957566951551746, 7.621105428664916, 2.419376022392704, 0.8551607833754632, 1.762705923568818, 1.7965969178945789, 1.5554062084805582, 2.8966887583655696, 2.880598215326186, 3.654269797186698, 1.131632844767263, 1.7801623094466426, 0.9742372615202781, 1.338518136932004, 1.9628302752971651, 2.4175217218937415, 3.62313132612936, 4.627932002467494, 2.9849239462806336, 3.095209473563779, 2.214160311606623, 3.071117050224735, 2.763282329805436, 2.988465846546235, 2.7791385112270235, 1.8369155737661549, 1.6882268555702704, 1.620073835215261, 0.625538859636553, 1.1509961154191726, 0.6566275043352958, 0.7494676161196925, 0.6477697506066292, 0.08042718148640088, 0.24975877465499988, 0.5465840608362229, 0.7149121477719277, 4.905459304009715, 11.300109201861966, 20.167944892760246, 36.40716537352532, 49.05387132398544, 39.02376674836682, 24.238247256125174, 22.508446708802257, 27.589375203655614, 21.236614258058612, 37.03038292546427, 49.48395136863955, 38.75988537265409, 8.27262484258221, 0.11543936847198395, 0.1608691025044649, 0.05627520630256303, 0.07213118471085064, 0.08187641299539998, 0.12695592227241687, 0.030830396459467953, 0.08358069815702977, 0.05234800977632404, 0.09857721401438599, 0.028285515577261968, 0.026768406762951807, 0.04212113818333995, 0.09930692042314238, 0.0412825170543886, 0.020979827254890435, 0.07561686944456832, 0.06266938980608698, 0.042115350389072014, 0.09285045397137442, 0.07251065870326373, 0.06455754756086296, 0.07853665268949925, 0.02450263852463855, 0.08910356389899408, 0.05585854640230537, 0.028707635769199942, 0.07210496152120252, 0.019844768403638757, 0.021575303567994027, 0.08961557876318695, 0.035015665024759314, 0.05360573845645113, 0.07032622793509115, 0.0772982792207791, 0.0929343329382039, 0.015943084520498113, 0.04138847467519584, 0.008737825536950222, 0.04953683098597873, 0.062269062900374976, 0.0447583269147623, 0.013049916127666593, 0.033132341284785545, 0.11905323503719223, 0.0685757936369027, 0.11302574717950438, 0.2282606161409809, 0.08003135151680439, 0.1850141407621484, 0.15541818774034902, 0.12793764862562382, 0.10080060801438748, 0.14126607697577248, 0.2761034811696699, 0.195108528939947, 0.14624972407135273, 0.09659273985532985, 0.15948354056285274, 0.11799165167875829, 0.2407073998643506, 0.11232001932277796, 0.1437721650807127, 0.1473598161171521, 0.1771967957216886, 0.15842017988043447, 0.16651939931175402, 0.14417756348848343, 0.1504031770051487, 0.14635564338776375, 0.21568675375273152, 0.1892812811439076, 0.12084919027984144, 0.1787002585948475, 0.09314278546240061, 0.10990449813224616, 0.08240982469531798, 0.2913193969476608, 0.2853362196155133, 0.1353937372445099, 0.25347776380517795, 0.11457847716707377, 0.18654536666168323, 0.2358704279627531, 0.21632727986622244, 0.29932519961749354, 0.10082130771010153, 0.2070497252768086, 0.0904871340120031, 0.10411026872574322, 0.16952733629413191, 0.21487632465939369, 0.11173588494139333, 0.06586810949468805, 0.1291511165759256, 0.275757301358446, 0.11448250167191991, 0.12329412924666559, 0.12005320960475553, 0.16681107962804456, 0.5188329241448834, 9.493506685380014, 32.121995572120916, 57.057875587094216, 61.26509612606418, 52.83672671164236, 41.99387565735848, 42.52311714233891, 32.98006896049746, 23.879919129033244, 30.33814868619365, 49.444602151070875, 39.791555020116995, 31.21237635612488, 22.265369584483487, 12.04211377328442, 5.774181437107825, 1.0448440308532407, 1.1801708273349272, 1.8367711815141865, 3.6815682678453387, 4.089804387861683, 8.336693817569364, 10.581910475607842, 15.904042182430146, 37.95754494205598, 29.74069130036139, 22.38731607314079, 5.346619063808072, 6.80812458838186, 7.266503062940414, 5.980729528011815, 6.713318940131896, 4.019563808556526, 6.8189831799076455, 1.7385681478246566, 2.3229859817412595, 0.5818821441742682, 3.3772793700618133, 4.325737895504121, 6.1410858265815245, 6.1228556306131425, 7.51350304772777, 3.967298471158551, 6.191513778701906, 5.225129531275842, 10.173070065436825, 12.127500830158112, 10.77908214061491, 12.901346222046884, 10.428768396377563, 7.578011818470494, 14.159814177020905, 9.492279964108622, 9.27043168775497, 9.883220637998274, 3.8019271771753993, 2.964205006437917, 1.0981843428265665, 0.4576518248406149, 1.91291774713224, 3.1131739289529863, 9.347737681481147, 15.146284391803128, 36.016179592378684, 42.219419787007, 39.6250190273408, 34.932616987536036, 24.426126826194025, 35.17538424461119, 32.11065403876766, 34.72612380981445, 55.17753447255781, 57.13647204060709, 42.14266684747512, 6.974236474883172, 0.18569405911670578, 0.18955229240800106, 0.19695579675176453, 0.3815172408376971, 0.17517588642095366, 0.2084399143894834, 0.139823334231492, 0.1749528016174032, 0.28853285937539996, 0.2051071714489691, 0.17242026815731681, 0.19897151197637283, 0.1320783232128428, 0.16962525765261344, 0.12001259928388942, 0.202393320298964, 0.18393574943465574, 0.15735712563318593, 0.12426535253443065, 0.2753441041756061, 0.16404706504075758, 0.12062366165581251, 0.2152649457416227, 0.10100230364309204, 0.15045318722484574, 0.18409264424154836, 0.14134783387905167, 0.18910406968526303, 0.08288476090397566, 0.13919485102017082, 0.21160609449350068, 0.16483737666520382, 0.08580267489437135, 0.15498021527403785, 0.15178372873173607, 0.21190221811975204, 0.12986914014383671, 0.17243853169343165, 0.14768085292270108, 0.14417468299788816, 0.1331583539684934, 0.1316104886392432, 0.14840711959667746, 0.11132258050624402, 0.2083133413426338, 0.174477091659942], [0.039686912956136855, 0.03463949670173949, 0.04395226069215325, 0.0648558851812155, 0.013220137034002091, 0.02266158943154639, 0.04664783681472463, 0.04675314326079623, 0.08160104269101735, 0.04942290222031936, 0.09111298954174404, 0.036235882209674004, 0.024560909087379134, 0.022018924017526934, 0.04475272298159619, 0.028724284775014368, 0.081185654496714, 0.06953718035571999, 0.0236163743876762, 0.03707544945721184, 0.07932887187287693, 0.02683322737744499, 0.052133305974665194, 0.014006004390877583, 0.07972591992227301, 0.05400456382983154, 0.11270957503227458, 0.026841926305825194, 0.028749646115747672, 0.047563840484907555, 0.07226392476549072, 0.04731672733361202, 0.019646428240042542, 0.03534684866486538, 0.030156679586657596, 0.017922433551340815, 0.009715261797781193, 0.08801257808602626, 0.05860957196883618, 0.02990488946858433, 0.014225840981629108, 0.027482898665531993, 0.03194360456789934, 0.05654098901657328, 0.07918518442179888, 0.07536742355554335, 0.06063245394597612, 0.13781056078451295, 0.010867550924059846, 0.051760148377187794, 0.018117805124230443, 0.0844747074429066, 0.014436765096991535, 0.1344906421558511, 0.045999783887377674, 0.05260500546184279, 1.4443769017534873, 11.100416433426643, 34.0003558897203, 44.85689993827574, 47.8216822685734, 39.93665133753131, 22.893758781494636, 26.648304462432865, 32.435512581179225, 15.45229692612925, 24.24964370266084, 35.00820890549691, 32.07221873344914, 33.7324893859125, 32.12967165054814, 26.750572419935658, 16.337442513435118, 7.021333844430986, 4.016864972729837, 0.569339997826084, 0.28439760869068487, 0.1967756741590077, 0.05735054860011705, 3.937064841870339, 7.996905263393157, 2.6702841587605017, 1.4243760008004405, 1.3539353806164958, 1.1963269475006288, 2.306431373280864, 1.7737478859001592, 2.878104078192865, 2.3726652514549995, 0.9022116360645142, 1.1125202380841779, 0.9419368495864253, 0.66634395069653, 1.745462939143181, 0.6554026829619563, 2.607795653804656, 2.890919196990229, 4.044135251352865, 2.826691366011097, 1.9880364066170109, 1.5528571581648243, 2.4343077501943036, 1.366591520847813, 1.6258621504229884, 1.1950493579910648, 0.7654051254353216, 1.4407232139379749, 0.9709327259371359, 0.34743512289658673, 0.08388732484872304, 0.3383467767027117, 1.4488567387865436, 5.2670606490104435, 10.060549032303596, 17.020670367825417, 26.05396143851742, 28.13604574049673, 42.403751573254986, 72.46214897401872, 22.586472457455052, 19.9930856304784, 21.11562090535318, 27.39486486681046, 30.374363929994647, 35.10285177538472, 50.51185946310721, 37.49355208489203, 16.605544359453265, 0.765408925231426, 0.023808568610899875, 0.02891461165892261, 0.08066934187926593, 0.06898167468006573, 0.032255086341812726, 0.06166326355249171, 0.011419595797516165, 0.04238483330775653, 0.014116575776208794, 0.07657025820545613, 0.021837652292883685, 0.044597923425176454, 0.0374507482704376, 0.07159532152957494, 0.05699079371087494, 0.0711006508959878, 0.08677984302442882, 0.05747670795948756, 0.08498437807805116, 0.020004283231232437, 0.044639081498908426, 0.03654031788990383, 0.04843211304696818, 0.06973690713845915, 0.0368993871304537, 0.07762619549588812, 0.012710503745643843, 0.030287288001648364, 0.17427516620486014, 0.045017927299223603, 0.003521325059175011, 0.03901322289640385, 0.025228487680696195, 0.019501019006354675, 0.06715998654403994, 0.22736466099177638, 0.03443211670063677, 0.09161930471178024, 0.09421904706546376, 0.1595304404655772, 0.028894553561845136, 0.05288000804402175, 0.1600357367386741, 0.07718194110859787, 0.05234938490414812, 0.0417880431538628, 0.09212021896195027, 0.022438424188763868, 0.05204214534211544, 0.014671346965065647, 0.026049331739364613, 0.04306110508379437, 0.05508225035643386, 0.0007901218979837253, 0.06461040762763831, 0.07519932088231848, 0.031029768926542134, 0.04675318156519244, 0.08195584865226861, 0.05126203417838101, 0.013501259701086149, 0.05064807216366453, 0.050119954131303296, 0.08821821906754086, 0.015193759557610799, 0.009246341294548925, 0.06817300758895374, 0.05573245599084804, 0.004960024774435067, 0.0383484386087906, 0.013824641693293328, 0.04046042810284323, 0.09949079684672818, 0.04637676809403685, 0.01850942352546319, 0.006616164182853555, 0.07543910640261828, 0.0417128554545343, 0.09301949893274615, 0.019010751463112333, 0.03603720113695149, 0.008444614002421018, 0.005217089407867002, 0.041159743803643414, 0.11741504794166935, 0.06946986420981346, 0.02581644484082297, 0.04049362652304192, 0.06802924352908327, 0.0427574125088511, 0.013942945778610246, 0.12187517353243406, 0.049850325655913165, 0.08112859626811358, 0.0354683923444921, 0.034141903442721215, 0.05686130952991306, 0.035889319354488004, 0.022296381911503214, 0.042720946723655354, 0.07248315614678207, 0.04417681255407872, 0.035022307007062825, 3.5384623081453386, 20.3663089582997, 46.98029464290988, 52.257949613755756, 46.812989865579915, 40.580610382941465, 22.40198181521508, 17.695486699381185, 24.683922644584413, 23.58197981311429, 32.18430830586341, 44.03151166054511, 47.21682925378123, 46.43557940759967, 38.64561104005383, 23.467793733842914, 12.658117105883937, 5.521351339355593, 1.4830290405981004, 0.2191414425690328, 0.16466041035469503, 0.10909238364547492, 0.1909269912228469, 0.4206043337621997, 1.280489121713946, 0.42283453828384804, 0.4947410830326619, 0.6912998470567888, 0.4492981263226079, 0.9258537835651829, 1.1542286387374325, 1.0894240967689024, 2.20821350812912, 1.429494571301245, 1.2001475811966005, 1.408063108401914, 1.557232439517975, 1.899962281027148, 2.087855579391603, 2.0343559211300266, 1.9846971212856233, 2.322255685444801, 1.9041041813550459, 1.5443527241868358, 1.0663373936568539, 0.28165204150061457, 0.7739186298943336, 0.7705007132983978, 0.4949705416877424, 0.2602310893276046, 0.9393875541225557, 0.2414603723633674, 0.21337770346191623, 0.08278073382473762, 0.2310484407409545, 0.49459050079026534, 3.6651570710443684, 6.978404483487529, 15.809667994899137, 30.12899418031016, 42.65452046548167, 47.31531996880808, 69.12416488893571, 35.151497010261785, 22.189389351875555, 17.559217676039665, 19.129722925924487, 30.193844687554147, 34.10986062019102, 50.214975264764604, 46.73175757931125, 25.096424587311287, 3.1846029864203547, 0.09214927667691823, 0.030476875610709674, 0.07276323789189901, 0.07519107011537399, 0.031007673035586075, 0.047530059837886406, 0.043086933738161484, 0.009900595703642937, 0.046681958370872086, 0.04520718932091709, 0.050854092358701655, 0.04949466167618671, 0.05439504650571654, 0.06503790767202455, 0.036835231097234834, 0.02141271098216455, 0.028637475521874525, 0.0626295532340244, 0.06509432238676856, 0.0580212049516699, 0.008810082949968356, 0.0192046981124628, 0.011903533539284143, 0.017288719874716574, 0.07428995153355984, 0.05287930324313141, 0.027711962785331473, 0.02050512470304966, 0.08891044079416222, 0.04534291711846187, 0.014118528342805805, 0.074571933176729, 0.04339290925511911, 0.019049279940044208, 0.0471719520376815, 0.14252364094699585, 0.023173606210959055, 0.02337145224784411, 0.07198420308169819, 0.022739010277174176, 0.05478660553513516, 0.015798292945199195, 0.08656562951904151, 0.02731578999138888, 0.03400068662519898, 0.08264034821261322, 0.0350235557303794, 0.1515837338182234, 0.26458332675599283, 0.08290837173380199, 0.25352679343233187, 0.12212786763425797, 0.17547519697297007, 0.16880361303206415, 0.1994408634040625, 0.20248079221815835, 0.1229357379939287, 0.20431088433871347, 0.21385332148882652, 0.13682688856797834, 0.09864839890431013, 0.1600291483825253, 0.16133281552503187, 0.22208177995297218, 0.25099353984959666, 0.1588261145497522, 0.14454349304639524, 0.21024500140019003, 0.09423509660747745, 0.09045283625563307, 0.10593614736271482, 0.2668248693789205, 0.20293597101924882, 0.29241033679535317, 0.10006388424024468, 0.1325804172384162, 0.3058062728133894, 0.15988870914424622, 0.24340206817273172, 0.1288500133781664, 0.08544799916806721, 0.1257820304242834, 0.08531725094203027, 0.1837905757730046, 0.2805466379129118, 0.194528830207644, 0.1402657346860055, 0.15309939281113688, 0.12821262056428578, 0.11127511369845561, 0.21871820963438482, 0.18213915067815012, 0.10278250811801803, 0.1851014441419994, 0.11329688867854495, 0.12019515037536622, 0.13615210300251362, 0.10570405336517481, 0.14631828894057583, 0.10922108641675404, 0.20063701776727555, 0.12837164509560794, 0.26128920996862076, 2.4053020679181625, 17.923207744475334, 47.146552147403845, 60.011926312600416, 64.28714113850748, 54.393833145018554, 38.14032739208591, 37.98183225816296, 42.25004565331244, 24.479186688700032, 34.66926905416673, 45.29630345682944, 43.45656671831685, 44.3984454677951, 41.582144460370465, 33.71281477712816, 21.45057562858828, 9.049489478911124, 4.701170498324979, 1.2782167210694284, 0.5896902961596366, 0.38551572950616964, 0.8516481170250524, 9.751549613091255, 20.08934255569212, 7.997960871265781, 5.00637355350679, 4.416906526011806, 5.387875043576764, 7.262429681516464, 8.144802153110504, 12.05753751339451, 7.058525758404886, 8.408730106969035, 4.189931221546666, 4.886856482874963, 5.135105742562202, 6.922992179470678, 8.861111767830389, 10.656813037010933, 11.487063092570152, 14.876850901111482, 10.40900553426435, 11.194962224652691, 8.135736084753468, 11.022233789966954, 5.433628020748015, 7.523943906830204, 3.890795827873292, 3.951977448117349, 3.082483098391564, 2.2741556600216897, 0.7277801572795838, 0.1810451924440361, 0.7604810186932165, 2.2749342505008947, 7.321388788761632, 13.625754060283786, 22.875551139154744, 35.10738603530392, 39.34694651634463, 50.854113717232984, 80.01315086118638, 30.93674944293115, 26.696751617616226, 28.274058257379842, 39.22845171343896, 43.93185992394724, 47.42282429049092, 64.90793074330976, 51.67690146353937, 24.14872504049732, 2.3272576880070472, 0.17528384353124327, 0.15940915342540513, 0.10650197224270914, 0.14351862062129284, 0.08611624234265859, 0.1444173949740587, 0.09326156739506031, 0.12562804675150302, 0.19471626127919844, 0.15863217173084138, 0.11419878100916264, 0.10581942620657145, 0.18503484045786245, 0.16158168684811364, 0.13877555577745362, 0.1741607739560066, 0.14866956599777745, 0.18785278763501875, 0.20634094072926432, 0.1369720315861125, 0.12016154209812803, 0.1421079156740058, 0.18575932980785448, 0.12075672346738078, 0.2278603811658198, 0.1257379803686373, 0.109830409769089, 0.15941934239479805, 0.2858255659380267, 0.1222914350669711, 0.10082723723063547, 0.25885314229995976, 0.17825588163348938, 0.1653573052176545, 0.12723296264847442, 0.48984961163613105, 0.0933836818101906, 0.16315144697023978, 0.12387646332142815, 0.290054248705987, 0.1851721234138935, 0.10053338122463996, 0.22836576936946762, 0.23702139846019207, 0.14853347813890827, 0.17757361904988367, 0.19536374347104182], [0.06288375652905914, 0.02597732138970206, 0.027359125670045618, 0.03769976131978535, 0.03365803464886642, 0.04474813411492975, 0.029035157509027954, 0.02718485024337086, 0.1301024292385386, 0.04161413736461152, 0.04781355833514564, 0.051030706268765276, 0.032963453371438294, 0.03379129564329501, 0.013120801285690358, 0.05721343418342933, 0.013043841050427048, 0.05368008345906293, 0.014557912326117438, 0.0769985166768874, 0.09224054073133776, 0.03257940200367763, 0.04550843807538191, 0.02217659831888253, 0.0627983415559415, 0.03756080829207936, 0.08696420974428616, 0.019876419326230403, 0.038400184017636126, 0.02110889774837321, 0.018931354110639904, 0.07193451461892936, 0.012348639241780245, 0.08119264887946268, 0.026501589830243782, 0.04375920653523457, 0.04139449612628068, 0.07045786482312026, 0.05308997742230854, 0.09075613046485571, 0.01512060965216088, 0.02494004600110554, 0.18250462058330738, 0.02765410016441057, 0.028388866583906838, 0.03156682720497972, 0.08916559403822308, 0.03231561494871013, 0.0492595607835439, 0.02937158310575591, 0.11199122204655602, 0.09563494608887742, 0.05857434724607776, 0.04357655585232762, 0.06071104690612805, 0.024097483349783767, 0.07376951736307914, 0.2304883078942376, 2.4670041376544587, 18.81907513064723, 36.413445088171194, 48.692895597027196, 48.80569904081283, 47.50784950871622, 34.41137713770713, 25.892387244009203, 35.20549628042406, 25.30807568180946, 26.4873186234505, 25.86687222603829, 31.019429083793398, 30.746408585579168, 36.73662877851917, 35.98805619824317, 30.76927992605394, 29.282554541864705, 18.349077124749464, 11.367671047487567, 4.742132300330747, 1.6504263613493213, 0.25774841286963035, 0.22458753097922574, 0.5777515819476498, 0.28840464690039236, 0.786730868201102, 0.16112370416522026, 0.4271950494618185, 0.4284765919850719, 2.290418051904248, 0.380333359203031, 0.9491137451221867, 1.2539488942392412, 0.7991026978819602, 0.717006080573605, 0.13101966631027961, 1.2443072180594168, 1.66064903861092, 0.3740336649840878, 1.3048330670402897, 1.1069535367911862, 0.8375984322159522, 0.26366405189037323, 0.5308168681879197, 0.2344527822588721, 0.03268999062598713, 0.150464080995129, 1.8414883219426679, 3.4070356959296815, 8.01290657251112, 16.117058261748284, 23.343662484999626, 34.94361923586938, 35.46419620513916, 41.35398410981701, 39.62554462494389, 30.489442348480228, 24.52749656092736, 37.99244226947908, 58.25590079830539, 39.61895112068423, 34.747422279850134, 31.517313180431245, 41.01482460575719, 43.2787892126268, 46.44540494488132, 22.84070480254389, 5.508365842603869, 0.26476519602921705, 0.03618539701546392, 0.05292398915175469, 0.030076912596761703, 0.025202743296000748, 0.02095580082236519, 0.05575658009958364, 0.04562552312328931, 0.04031902742421916, 0.005864608946496682, 0.051784701495160984, 0.03977210576375646, 0.04771702742624668, 0.03026037341764858, 0.05167084933829404, 0.07290494883613241, 0.040091219688615495, 0.042441922179873914, 0.06363209419613404, 0.03992875925295296, 0.01975695557531811, 0.005965641579560695, 0.07411877684775861, 0.013359602383007447, 0.02023661663124879, 0.04100153515596063, 0.05921059475851156, 0.023530394424714392, 0.027691588676985235, 0.04145982810446332, 0.07205873577585144, 0.012664298110100771, 0.04439081921572647, 0.061547339127789584, 0.03429837307081588, 0.03372261586088327, 0.01202144404692996, 0.09490088830071111, 0.08973481268772195, 0.021145401837965174, 0.020194543082447305, 0.03473481336127847, 0.10932814720417224, 0.032659270500223485, 0.05176297141118877, 0.02177000481394991, 0.015169310819117293, 0.031221564784045183, 0.06465369159536016, 0.042550495990942565, 0.04151314782399324, 0.03053248018747376, 0.038474582646402626, 0.01892858661801344, 0.024087865115894426, 0.02555458449698504, 0.03589488498325791, 0.09000445265443095, 0.04210530314594508, 0.024261169526125156, 0.03078778090346004, 0.052676964100570454, 0.038420987135219964, 0.0920255994424224, 0.07419931567123822, 0.02710115513764322, 0.1411944937201277, 0.030784869769347772, 0.12997757222863937, 0.06015171079085239, 0.06207800440249905, 0.051318674889062686, 0.07311120268798645, 0.06047549019117029, 0.025570522956249696, 0.025833961441211646, 0.03626422746287238, 0.06154216420386107, 0.023735211861710397, 0.02755858240679147, 0.03807727029667266, 0.03301548606325542, 0.05193074849704581, 0.036839103671692075, 0.08893895458670394, 0.006662014545121741, 0.03570998966273281, 0.19000672044292574, 0.023704863288590027, 0.05807908289434929, 0.01848718590824114, 0.053212555320633036, 0.03281764768724961, 0.061662382551378785, 0.05658064938841328, 0.08414684479395229, 0.024746237247581446, 0.04333293606196681, 0.0240891310761893, 0.07603770452401332, 0.03977294463003355, 0.03282890151885729, 0.034752226539797364, 0.05088180175892288, 0.06128716417738508, 0.06548272130349952, 1.0764268329066615, 7.132262395274255, 28.178697593750496, 47.92172624218849, 54.62864583538425, 48.15187915678948, 44.27269820244082, 33.96392099318966, 20.111150933850197, 27.07899835801894, 23.57008130319657, 28.445689409009873, 34.264762863036125, 44.49072707083918, 48.85250468407908, 55.93840760569419, 43.73356057751564, 40.47994667483915, 30.480499344487345, 16.34053922468616, 9.333747567669038, 2.769060716513665, 0.9797744224629096, 0.4772969545616258, 0.16329010888453455, 0.08356302450861662, 0.27454412452155547, 0.33266390583688216, 0.16473530311017268, 0.24576221652809652, 0.4411195555040914, 0.663591611289209, 0.9150189101215332, 0.3478094947434241, 0.4759345437970854, 0.14904948432118664, 0.4110859977381845, 0.5717821635546223, 0.5124283678108646, 0.6910705109757762, 0.7472387292692739, 0.7229703508557812, 0.5570928872592988, 0.23373235317487873, 0.010613745994745724, 0.17625809286630925, 0.21571810207059308, 0.07637767136217126, 0.21569631453002655, 0.5206122706013342, 2.075359888615147, 5.740158798233156, 10.838495262207525, 18.815682280448176, 35.315267732066495, 38.303474457033225, 53.999478047893895, 53.141012422500125, 41.12261133809244, 28.7017083937122, 40.16206602896414, 70.83500862121582, 28.156432259467344, 20.589562423767585, 25.83475193669719, 40.13946533203125, 46.2907458889869, 52.636693677594586, 36.52436187190395, 11.567106900676606, 1.1603423880953943, 0.16928793381779425, 0.021485359100024068, 0.024204716506984927, 0.04828649888476057, 0.0819190304666277, 0.04937640068331554, 0.0584834547443015, 0.0631167698321083, 0.050175434218779694, 0.08378260829035314, 0.06822468021944647, 0.03502023473922764, 0.10262585079838192, 0.0366904174969081, 0.05196434911340476, 0.014987518154685537, 0.03755087213170144, 0.04054652106377386, 0.03809390589594841, 0.03430063686063213, 0.019173719432024706, 0.03654510210899096, 0.028569761010247375, 0.049279184125724344, 0.023921987928089597, 0.05210937338791067, 0.045045946965054165, 0.04923538304865361, 0.048141367357945254, 0.042233370064247044, 0.0022907077518832543, 0.022822651756747116, 0.04889782555701752, 0.011591037656480988, 0.057898772610051025, 0.0431390890040465, 0.10292171395473904, 0.12157740281714548, 0.09504806145184463, 0.0805910706760422, 0.04852867842982373, 0.06905433045880449, 0.05475765890291622, 0.05515948351052019, 0.04954245407134295, 0.041213243553835543, 0.009122272397601798, 0.10173516633409647, 0.10446789389055584, 0.09518646289624515, 0.18437842568082197, 0.2552950775791561, 0.16826137599925842, 0.11341010881287437, 0.12835571812766214, 0.2516884275621945, 0.22275772997208182, 0.07750109333785311, 0.10901274880574596, 0.1509140503983344, 0.18385748589231124, 0.18045807798062602, 0.2602095775786908, 0.21386617644419595, 0.22227589131122638, 0.17210028855310333, 0.14629378944875734, 0.21179991473834361, 0.14136009128584018, 0.16973946604036516, 0.1961942593897543, 0.1370238038080354, 0.20051884104407605, 0.2222326379870215, 0.189301613117418, 0.12330571249608072, 0.14942284493196398, 0.1298231595466214, 0.08668083382109482, 0.20427743693993938, 0.18563579046918502, 0.19817493375270598, 0.08945998630576557, 0.18464076482961256, 0.11268838504028898, 0.16037851511951418, 0.21880972649781935, 0.202266639999805, 0.1282762824707935, 0.12376262265588008, 0.2727039506839168, 0.133719896416991, 0.13220671954895222, 0.09270172566175462, 0.23822532095495733, 0.11639193751879277, 0.20617135950634558, 0.14086840073427848, 0.12020317897681268, 0.18142270525136303, 0.182991071093467, 0.14325274214629205, 0.2117160587541519, 0.2336685227290277, 0.20542851468968779, 0.5777423276055245, 5.092497525676604, 26.825377902676983, 49.42966576545469, 64.21402423612534, 63.07329700839136, 63.20171148546281, 49.21715959425896, 38.729161447094334, 48.95962069111486, 35.88065778055499, 36.862587851862756, 35.478355961461226, 42.48562712823191, 42.075747289965236, 49.21359023740215, 47.87025690078736, 40.67868924910023, 39.449575331903276, 24.40238864191117, 15.014575123786928, 6.783771082278221, 2.229633571640138, 0.8584833986336186, 0.6238106878534441, 1.5752673749962163, 1.057861151714479, 2.0443740222723257, 1.815116388663169, 2.413393427287379, 2.6217281578048586, 6.986393370935994, 4.375400495144629, 4.9702014557776915, 6.802129245573475, 4.172587481237227, 4.821319560850821, 4.424907180570788, 4.513796914008356, 5.392404890829518, 3.255461829323923, 4.903410846187223, 2.9520819408278314, 2.2778206246514476, 0.34960070024094275, 1.5704130741857714, 0.6949347197528809, 0.42113535526779394, 0.5277050803265264, 2.573793607373392, 5.00712174561716, 10.683027217465064, 20.741052204562774, 29.19939244947126, 44.81955505186512, 44.69380778651084, 53.427674924173665, 51.442100540284194, 40.14226982670446, 32.17322957131171, 44.87315424026982, 65.89085317427113, 45.61837711641866, 46.53495657828547, 42.89540498487411, 52.20438180431243, 57.68453305767429, 60.984203430914114, 36.01949399517429, 9.387535029842008, 0.7979736068556387, 0.17007841398158383, 0.14234538760877427, 0.09408712672490267, 0.21031212602411548, 0.16877355174191538, 0.16477869433020392, 0.13740629618687017, 0.14535781386638844, 0.18363050936210543, 0.17481508965213455, 0.22137645812284565, 0.11729540032965523, 0.12182029099353861, 0.15553325414657593, 0.1546264971576391, 0.1550388516437623, 0.22373712741799895, 0.13608231239261168, 0.1454598261343856, 0.13276755719655944, 0.14155677669951994, 0.22060257142349599, 0.06220375773526969, 0.11962089852820482, 0.1567321664263164, 0.16980692774297731, 0.14536248700272653, 0.1022855315597788, 0.2122640567681482, 0.14057215453395921, 0.12072873827550681, 0.12136968573735607, 0.2017543723265971, 0.11533159522279618, 0.3279204732708393, 0.16328001184569252, 0.21393037461225065, 0.3088798175656027, 0.1643528566966134, 0.13742673541268996, 0.1108287372476151, 0.2277837264081163, 0.2510472426130887, 0.16681592130372602, 0.10941711299481893, 0.12991047824823088, 0.2510212415889386, 0.26280247876721047], [0.013254103457344877, 0.09932869264195043, 0.040244130838301875, 0.05699896020814777, 0.022133680158144525, 0.04159329977307109, 0.01807528724443288, 0.01707048823816642, 0.04068122613393972, 0.047330589694601875, 0.0547360360712534, 0.05542280325185388, 0.046650797744551976, 0.015545076945976866, 0.039112795174362204, 0.0680120295334247, 0.04564270647543092, 0.036361788760029504, 0.10096985215861952, 0.02503856682338782, 0.015868683976511803, 0.040867910269768014, 0.03357992432410679, 0.05863798616994774, 0.09894825337875275, 0.02434257785939882, 0.002412474315215443, 0.04832596007374026, 0.04142788606846044, 0.12318617979725524, 0.06973617935493108, 0.0287509752782963, 0.05033985200908877, 0.019003525338766557, 0.08192839972194164, 0.026992050810687007, 0.08449012113194312, 0.06158907942834401, 0.07277726496179258, 0.0443320143066587, 0.006089601787783567, 0.10142957386110099, 0.011670152514031338, 0.030492881102667704, 0.04634536998046022, 0.048671825788915164, 0.02815268550729079, 0.015280315044125723, 0.07631312845455063, 0.043372010376544735, 0.030319247274629535, 0.10245085333383853, 0.020716220230585145, 0.12426421872430271, 0.028127356725294265, 0.021555268453554283, 0.005898231587883446, 0.03164410823956132, 0.071998521265003, 0.7489370542668528, 3.6609993586617136, 10.990268434247664, 30.117107437502955, 37.288502339393865, 46.74531721299695, 54.10243634254702, 43.751791754076564, 42.55983052715179, 33.22750776044784, 32.933286851452245, 28.537261063052764, 25.642222396789062, 19.35119563533414, 32.45704247105506, 25.228180923769553, 27.460050736704183, 36.32964364943966, 29.33018388286714, 35.34968653032857, 32.467615219854544, 28.979231772884248, 18.236163854599, 10.383870986200149, 4.916577752559416, 2.5183702716904306, 1.094857805198239, 0.2630718046378705, 0.24554594990707215, 0.09910258945197829, 0.04144934036077992, 0.020173161568480636, 0.052216070283564835, 0.14686466284817265, 0.03778161781449472, 0.06580714421767382, 0.0551847375989441, 0.45566704424638904, 0.29033010164576195, 0.8747158211565788, 1.6200767769928903, 3.569669910976964, 5.213951756877284, 9.278996183026223, 12.283403277397158, 15.450465179258778, 25.103749613608084, 26.988199410899995, 40.053416375190984, 37.007048745309156, 35.163409248475105, 30.770984195893814, 25.04512586901265, 33.65002155303955, 21.574993210454142, 21.88660590879379, 34.91983006077428, 38.122111905005674, 36.908244240668516, 37.669756720142985, 39.790680331568566, 41.40187232725082, 41.686350068738385, 38.519710802262836, 24.653796880475937, 9.199289698754589, 1.200327887650459, 0.018769353327731934, 0.09090207021443114, 0.023276857626173767, 0.024513518888383143, 0.019915269560090477, 0.01917189997320454, 0.016087524652961763, 0.013397354238306083, 0.015549862122673903, 0.02577692044958953, 0.045001134651923375, 0.024358845736470916, 0.031112171258897554, 0.01757949237681685, 0.02741420356136176, 0.05378367386818413, 0.020516142962620627, 0.09979233671460422, 0.014699187557843905, 0.07221530882581588, 0.04739895538096467, 0.05837844707252038, 0.04826088090457263, 0.0831778355002884, 0.03749481364784222, 0.05988747557444919, 0.09517167739930654, 0.03415357096180801, 0.09481280351117735, 0.07214838338475074, 0.05841407016099942, 0.058161770594456506, 0.020293950651501937, 0.010692250854786365, 0.0420840633582444, 0.012877383551019575, 0.06420410906655655, 0.1169716515728543, 0.06499558131420805, 0.029241984011605385, 0.036882184626113985, 0.0585741940284929, 0.0329110874313741, 0.023058103134615288, 0.07904711239520582, 0.06697815557521197, 0.006642991624351952, 0.07113605947984804, 0.025968835050720843, 0.017220461440663186, 0.09219486656929217, 0.07787489827962653, 0.0502736735037498, 0.04313490616397993, 0.06320629486693971, 0.029147125089601166, 0.030019176380348303, 0.026094643924865994, 0.04110403388978974, 0.05297662322259238, 0.09645543391666106, 0.05108784493659774, 0.06517555068938002, 0.011988626755473596, 0.04309179073560142, 0.07391788561137454, 0.0315949943427357, 0.0748906487358674, 0.030614070466629444, 0.013414125818188393, 0.045617915870201205, 0.0470513238331243, 0.03331617174309588, 0.04526687140065817, 0.06660238178747316, 0.015759335459029723, 0.01820104823808276, 0.04282306624396194, 0.03994530292167779, 0.0722265320139066, 0.06026635967916059, 0.024706077003370852, 0.036017416916306944, 0.020859185643794558, 0.027139656801497745, 0.02198253675634342, 0.03453129827375374, 0.011049436476652422, 0.029007132097537962, 0.026969958750170567, 0.05287462244591406, 0.059421372359558466, 0.01031318193136324, 0.03130474852608337, 0.04014508716101128, 0.0748050460712083, 0.03209524401163142, 0.042253617768085776, 0.07517404764169648, 0.044884122382368774, 0.05379221191810024, 0.07013626877338656, 0.05608198360630101, 0.06629973875298616, 0.038081977906967365, 0.04132273283997371, 0.012831636610621167, 0.06643285419070913, 0.11065311925185305, 2.2349876069253494, 10.464609053827102, 22.74072554803664, 44.8029948049976, 49.18481965218821, 52.48605505112679, 52.560403577743045, 42.191704319369414, 36.205320204457934, 26.91988152842368, 21.78855646041132, 24.826487072052497, 24.022218796514696, 26.10244977858759, 42.37710299030427, 38.171102308457904, 45.35838280954669, 51.708025470856704, 50.329088780187796, 44.67063834590297, 38.02142858505249, 21.955822014039565, 16.140478734047182, 9.16700957282897, 3.18071125976501, 0.8929709609477752, 0.5980535860984557, 0.18812644956333024, 0.18118990645293268, 0.2800774243810485, 0.0932171266345728, 0.049496063617088144, 0.05004337981283184, 0.1963040244675452, 0.04444587029396527, 0.1418904079905441, 0.058214730252662016, 0.26012156939794945, 0.21275518041464592, 0.2744814585293493, 0.9047728212129686, 2.7753151809015586, 4.131033891631711, 7.548100804128955, 13.595785190982204, 17.628920155186808, 24.912075150397516, 34.95254655038157, 40.21066811776931, 46.927036700710175, 52.17548178088281, 48.581488517022905, 43.34845050688713, 45.76056695753529, 33.15999984741211, 28.422641561877345, 30.486932031569946, 24.36029768759205, 33.27808672381986, 45.87463732688658, 40.70575752565938, 41.47366346851472, 44.11178688849173, 46.25809215730237, 37.0377020682058, 17.97598715751402, 2.889396581918963, 0.06842914142555769, 0.09353043361296577, 0.05246257822540018, 0.032011303757768006, 0.057615565226203015, 0.01403926792854984, 0.03693247063746376, 0.03432238226636283, 0.0274795355395444, 0.04639541850455346, 0.02538676336107235, 0.06311578923956522, 0.027687457547853553, 0.025366178578546932, 0.04321007854154995, 0.03787975367759505, 0.014116355525930564, 0.020508133513372273, 0.04461559324314998, 0.01243146866815345, 0.05030430169896253, 0.025379893467611363, 0.038516951139054956, 0.00963934631492462, 0.010405160362772163, 0.03724138793205062, 0.008600855719358211, 0.1368839008313033, 0.04065691050322306, 0.06210657948207471, 0.07223006367923752, 0.016937108500109568, 0.1463580335820875, 0.07445736472765285, 0.02109611365613678, 0.024678932592993783, 0.02402024253481819, 0.04319290285028758, 0.03706685012026179, 0.015282393057620334, 0.04689455160029954, 0.02358720558995922, 0.050019336143328305, 0.09672806162627474, 0.07509072791905173, 0.01196353737595341, 0.07750311580997321, 0.08457256751435419, 0.0670786892935153, 0.07752665003100712, 0.17335811299422096, 0.24675612367929953, 0.14520614377913937, 0.20298250319976963, 0.15478613455930065, 0.1378914290258, 0.06751545900178534, 0.1979690093186594, 0.14137077055150463, 0.18714334425185958, 0.2910076298059956, 0.19876558754232623, 0.21737954759549713, 0.19266044901263332, 0.23734830349924105, 0.20139121600697119, 0.13478851246256984, 0.10062704313426249, 0.16808517577667392, 0.11891021408260831, 0.22054833239845692, 0.13368303226607461, 0.12192318426264871, 0.10504045268340458, 0.1970614249547643, 0.10179257696314205, 0.11215082880470062, 0.10539053188216303, 0.1192012585459217, 0.21006624244393843, 0.2134191334968613, 0.08986393680735942, 0.10956440105914109, 0.1705130769480621, 0.10781984265533187, 0.12147211169283237, 0.09757753822111315, 0.14198734875648253, 0.16938432300042722, 0.11002098946201225, 0.19252724164435941, 0.21198380648368792, 0.10555420656718555, 0.08885345917435424, 0.10581659168125161, 0.2191950993672494, 0.17322248478810634, 0.16702143205029352, 0.2312840740647047, 0.20780586937983192, 0.15116604736014722, 0.14973926988820876, 0.1958513890783633, 0.25661500110741586, 0.09075962382579043, 0.16677482834746762, 0.13284689326199794, 0.14137247126669655, 0.21329850529230412, 1.2719975580130856, 7.658618486696675, 20.081929276066443, 45.66180167659637, 54.40140331945112, 64.9126571993674, 70.54229782473656, 58.21344898593042, 56.73684527797084, 46.684057635645715, 45.185135641405665, 41.17798343781502, 37.32280738892094, 28.885526349467618, 42.655999199036636, 33.1774857736403, 37.407577653085035, 46.819406863181825, 41.67194320309547, 48.07072139555409, 44.12769209954047, 38.640786524741884, 27.699413376469767, 15.930176934888287, 6.582515249329229, 3.3934767976883924, 2.0810855684741854, 0.5190332101718073, 0.3263041196811584, 0.47237833300905846, 0.1881653515081252, 0.18167381355118367, 0.19261851335965818, 0.535242650057039, 0.22006652438111846, 0.49855463807621314, 0.17711457916565482, 0.8691190279299214, 0.5400867159328153, 1.357776484181804, 2.1211793009311926, 5.047598644610375, 7.118946929131785, 12.600471012053951, 16.896266514255156, 22.03283383000282, 32.43626959862248, 35.80250455487159, 48.99234110309232, 46.41489282731087, 45.42696152963946, 42.00488575043217, 33.38037429317352, 45.25643648639802, 29.508345780834077, 30.444921485839355, 47.93743925709879, 49.93135652234478, 47.021667803487475, 50.25235545250678, 50.74761352231426, 54.33078888923892, 56.82923670737975, 54.43675564181421, 36.29558963160361, 13.895956335529206, 1.9442935215850032, 0.13850603072393325, 0.15463984240928005, 0.1770250541308234, 0.09767917510602744, 0.15090844263472866, 0.0939062610268593, 0.10851416346286574, 0.11270712355091689, 0.12336934375907145, 0.20373215087719504, 0.1720743488159872, 0.19143490751664485, 0.11882965993737021, 0.1325483028326304, 0.09141560959359331, 0.14862265077329453, 0.10123337874369276, 0.1812038339313961, 0.16640716743084694, 0.1753982664236138, 0.25751334645094415, 0.1049759557410594, 0.21225504757415867, 0.14541304880572906, 0.12314914710699551, 0.11441726162428818, 0.16639373024865506, 0.2595414263346503, 0.11128890328109266, 0.11840010677734691, 0.14904073559709136, 0.17059058972424077, 0.31040313743775894, 0.16984406768554644, 0.09907178505654297, 0.10497884389253394, 0.2947907558371944, 0.16761901127474924, 0.22912661725234604, 0.1473787691323988, 0.15146200244705524, 0.2376929970998918, 0.1321748962565776, 0.13693593352312042, 0.12225296979229297, 0.13121428328656382, 0.21863795426343718, 0.1946128240876621, 0.09333731816901315, 0.2345165207741722], [0.0330925659997569, 0.023623529648888978, 0.0221967809052477, 0.045418664061975096, 0.014383444419851708, 0.03322283925128079, 0.062469456179608265, 0.05268315026055902, 0.05462666169830388, 0.058810118465654315, 0.05308882062954288, 0.031548588566722414, 0.01898588807952981, 0.043500479491006945, 0.07335438197779079, 0.03700910241252953, 0.023345746167544878, 0.03906086590441485, 0.038020296337743925, 0.09394766807916666, 0.035529457212936495, 0.058533664146858844, 0.028318530136358835, 0.05325454843020248, 0.03374488220640248, 0.04351231554943708, 0.03636499483799262, 0.041600190733949986, 0.032148324328685, 0.08401418134810464, 0.07748718118114818, 0.06679396505557722, 0.026317642543524988, 0.05701173472428515, 0.03312188035417949, 0.04186597727839986, 0.040838618897983146, 0.012789448148631042, 0.029139251620959372, 0.02465933606389069, 0.037828697747881376, 0.015437732706026686, 0.03177237051028398, 0.03387511332309054, 0.040927301236097856, 0.04348007473914374, 0.015066104411568134, 0.026508553569475492, 0.05773574909976414, 0.01951359050919212, 0.03587700066066558, 0.04064965948101975, 0.034565492608254, 0.07854051377263763, 0.06962557158042347, 0.008633098444871364, 0.031302666682149136, 0.0367166368561166, 0.03926562588481654, 0.06362747468595063, 0.04910915474136991, 0.20969378581691175, 3.1789837008522404, 11.150647286445865, 9.034046126950173, 22.192135010996175, 50.14001484840147, 44.05552048836985, 51.38521440567509, 43.135740372442434, 47.1685762559214, 43.89273428147839, 46.005640568271765, 31.79054548663478, 34.0481891939717, 33.033209231592, 22.38774557267466, 32.637812745186594, 28.34170933692686, 35.22599066457441, 63.40701618502217, 36.919422995659616, 32.315501782201956, 41.38295081353957, 34.318836658231675, 27.32802179551894, 22.905557270972963, 17.91097975546314, 17.804903176523027, 16.54139203409995, 14.751945964751707, 15.759842126600205, 14.69514023873114, 16.72676520962869, 15.960995977924718, 18.742535960289743, 19.975399663371427, 24.114808305617302, 24.53520597950105, 33.17093149308236, 27.806684317127353, 28.04364254397731, 30.569048812312467, 29.804586710468417, 30.99371598612878, 32.670117385925785, 24.859146687292284, 30.75693426593658, 31.405996314940918, 21.35982963346666, 27.21197847397097, 30.238675417438632, 25.51949731765255, 29.90632514799795, 41.27204187454716, 45.609751824409734, 48.81105307609805, 41.338769235918605, 43.81633827763219, 45.44206657717305, 36.6169729540425, 20.195603486030333, 8.02170935177034, 1.5417551345402196, 0.0551915749336683, 0.03446721118844805, 0.06259662677503883, 0.015412101319300072, 0.023215970873171766, 0.02523175313047344, 0.05666632483142519, 0.08881607408364935, 0.02143458279240276, 0.011751889307502539, 0.03355505711008464, 0.09335607200139955, 0.04920553626312364, 0.06287633313707287, 0.07821483447426751, 0.038771594934646166, 0.05381383091932344, 0.03834830071296423, 0.07223539565119051, 0.0568665802148321, 0.01551737999468441, 0.03546008029051366, 0.020702363615254724, 0.06235873732235163, 0.07899222985631035, 0.05421497753911442, 0.1148248740261601, 0.0192667301669116, 0.03913143792399957, 0.07434499495091938, 0.03257838310673833, 0.020463505061343312, 0.036179547934162046, 0.0362419840999909, 0.054919778429452455, 0.03398105562213929, 0.08043560079268872, 0.01887777583643554, 0.09313877116167739, 0.046993794460450454, 0.00841577462251148, 0.019277022558174307, 0.029999124028930263, 0.04916238253034892, 0.021176213894279736, 0.045792143416380694, 0.013780560036520324, 0.02007530532747267, 0.051783778359212225, 0.04864297491768676, 0.06302079816739406, 0.02658768087595461, 0.025892691656706796, 0.03397893738902865, 0.07635944613045262, 0.04994272735090025, 0.045574846407098156, 0.0673052674580005, 0.04765775903398472, 0.03715489660539935, 0.07972798835966857, 0.12453450986574735, 0.09676213721714674, 0.02714892646538154, 0.031809780498846404, 0.04485280470802419, 0.043033928114680514, 0.025858328782863198, 0.040512575707849, 0.04101709823214239, 0.024770570115276405, 0.06371521473591847, 0.023699102307399435, 0.019659411515139287, 0.06702123269919427, 0.06158652452511653, 0.07869423697552375, 0.079819091535624, 0.024706592197499933, 0.08508482752668281, 0.07995028409265703, 0.014787619002163412, 0.014354854018517561, 0.038163068313752456, 0.03177536591406792, 0.06921138614416122, 0.03574304252622589, 0.03708454292087305, 0.02518518456077624, 0.047945942158900925, 0.04608517204741797, 0.031942095374688506, 0.07714962751995172, 0.017841810458189538, 0.005889860640895824, 0.012247857502511433, 0.04474818391064483, 0.03462808199166771, 0.03000452686401625, 0.06981182287657453, 0.02512326741951608, 0.005945960301980978, 0.05832611560641278, 0.04428350944973288, 0.03904812969267368, 0.07368311796697878, 0.06070502545504321, 0.03858746953248497, 0.08032529945335082, 0.0674583777905472, 0.024572051836237795, 0.06411682483890364, 0.050586199072460016, 1.0499221519116433, 8.384730104477175, 20.271860245735418, 25.966019938069007, 43.11293178989042, 60.17753662601594, 51.63182950788929, 51.16763268747638, 45.067845006142896, 42.491004697738155, 39.0555497138731, 27.518858832697717, 27.162017283901093, 21.543359295014415, 22.992312254444247, 23.447921045364875, 26.22004439753871, 38.42047875927341, 44.33948439936484, 62.8477724905937, 53.17536061809909, 53.50626353294619, 46.05300318810248, 41.445006632035785, 33.87545585632324, 25.393116589515444, 19.956023154720185, 16.11804964080934, 15.57615851202319, 13.196843862533571, 13.861382603645326, 13.3676395493169, 13.795156325063399, 13.569752420148543, 17.005379007708644, 23.15804808370529, 30.092918180650283, 31.69094866321933, 27.443200234443914, 35.33990021674864, 46.47264188335788, 48.25789690017701, 45.912845134735115, 45.78175167883597, 47.365946000622166, 37.86748340052944, 47.659170627594, 35.63218739724929, 24.427756571000625, 22.935610471233247, 20.404104917280137, 25.31938779738642, 20.05776159224972, 27.909819118438232, 45.690937042236335, 46.538208223158314, 44.94058370590211, 46.805878608457505, 49.28153353352701, 48.203925086605935, 33.803543121584006, 15.509135992296281, 3.9174789767111506, 0.23615625536730214, 0.056854778630358566, 0.05244905294309701, 0.05972602254440708, 0.04009119287553815, 0.11950696593210583, 0.03954682994874255, 0.06341882680933322, 0.06756928433934528, 0.010588920915559416, 0.016638257600847754, 0.05294291535392404, 0.0534683367567918, 0.11934379686511333, 0.008930503353176099, 0.040168330268633944, 0.014151763152180901, 0.039511076625316374, 0.03167160313516375, 0.04605521800957861, 0.08946325750120225, 0.06361283857615725, 0.027026243229967453, 0.18662764450475094, 0.10545493689395728, 0.06612527754998977, 0.053435326028134555, 0.03485928349677594, 0.04893847035184022, 0.06639677911035477, 0.026100301484186805, 0.0026088757975582756, 0.04937814353334327, 0.030457953238979946, 0.00868502292676919, 0.056565802604440725, 0.1438987687710793, 0.055017860666398084, 0.08060847619368185, 0.08321824663829419, 0.0389649095614591, 0.010208337053266025, 0.05211373625863945, 0.04209741627076461, 0.03821528486667141, 0.05211437977249584, 0.03798267375978251, 0.08254264901962974, 0.04455428322656982, 0.07635390731476008, 0.08440068036678337, 0.07957679324693258, 0.15033065912223634, 0.16002360190595352, 0.14687987735434888, 0.15118259485931168, 0.17240454803311056, 0.12882853227276958, 0.1896538143797267, 0.18337753180774952, 0.1565693880641653, 0.22089560005453326, 0.1668129642043383, 0.16856586530564294, 0.11454647767447657, 0.14526134807496302, 0.16971184090981561, 0.1395239777142002, 0.1497496733622205, 0.12536448952291282, 0.12223491309991769, 0.2823302438182216, 0.10484080250945785, 0.10266784007751173, 0.1468760162712105, 0.18405731226648056, 0.15595991915512472, 0.12936526879427895, 0.1572619775129903, 0.1304546305008473, 0.14037864072428596, 0.16866326572433596, 0.16698165676526486, 0.11487265492999747, 0.21873130973789, 0.18495771072564587, 0.11622059429364821, 0.13028679595839593, 0.16299622223502205, 0.14314277788564084, 0.11217086200392055, 0.10758508267181535, 0.1824449729775229, 0.15429931632693739, 0.1551455217263391, 0.12904476825027697, 0.13732518279744735, 0.158214669133867, 0.1306488491114109, 0.11825593669087657, 0.1531493877090754, 0.13609671484558813, 0.1184088555014422, 0.1704202270916393, 0.09916679528091224, 0.20953903605620708, 0.13928558647392258, 0.1101110201148737, 0.1904701423500815, 0.13348882897726952, 0.17851193886130087, 0.20037357545187398, 0.26599406234679684, 0.6623216826588877, 5.933828276972617, 19.42248667440107, 26.899220443541004, 46.46571890000374, 68.7236124469388, 60.71154379075574, 66.38639757710119, 58.92258605649395, 61.63989036313949, 58.83871401509931, 56.980302872196326, 43.8565621837493, 44.97859931761219, 44.059721346824404, 30.73206840022918, 41.97563663605721, 36.86869498222105, 44.665445127794825, 78.65753266119188, 51.25500348306472, 43.79436908229705, 56.05915777144894, 46.95385786794847, 38.85520681258171, 33.29014016735938, 26.696163262090376, 24.965574318362822, 23.255677838479322, 20.967718132080574, 21.524247546349805, 21.55118638469327, 23.615698468300607, 23.13518851034103, 27.443111981115035, 27.643586281807195, 33.861386314515144, 34.67342284417922, 44.96261565916, 37.76916134741999, 40.46193907337804, 39.852689081622714, 39.73651239948888, 41.307751132595925, 43.46787098915347, 33.94390121583016, 42.54005785911314, 40.840086936950684, 29.059758032521895, 34.91897890644689, 39.568509440268244, 36.76787830168201, 41.09059303037582, 52.38903914728473, 58.8381491937945, 64.28772557166316, 55.216691493988044, 58.50672852608466, 59.0576450286373, 55.75592325579736, 34.47170319095735, 12.636254795135992, 2.5171354605305583, 0.2503869361093929, 0.2887324406014335, 0.17373522743582728, 0.25901187571787065, 0.10843512617171773, 0.18399184239247154, 0.07900182893800159, 0.23147300666859075, 0.15015375409876147, 0.08838944737949679, 0.13770818079431213, 0.17879488577525463, 0.10415990356235735, 0.2048503634549918, 0.15145060305874194, 0.17608131041690228, 0.11923040819144058, 0.16308228455243573, 0.19526830423743496, 0.2566354096897187, 0.20857379591513067, 0.08101789656305507, 0.07519509973785571, 0.30022250308144477, 0.2369731655644794, 0.14295421300395844, 0.2301803865139523, 0.13361944696835934, 0.13136161731616144, 0.1807826387906267, 0.147966802901318, 0.11269733294724457, 0.09497142201589961, 0.16530050745894834, 0.1438865266860493, 0.20841333113851088, 0.21625594175871343, 0.12309755108529523, 0.2785825416926415, 0.13868428406215486, 0.22583631558283684, 0.10960286633381922, 0.14625726237652764, 0.17611359336203145, 0.2154034391165741, 0.11243887020335083, 0.18296389029391352, 0.17793567220289863, 0.18120504435031645, 0.17629287325807158, 0.18115576957502674, 0.20234099649373563], [0.09661360809038724, 0.09080679185928837, 0.016116394676388274, 0.05934868210686311, 0.03595892993372775, 0.00223285231303664, 0.050232565225732904, 0.03137358152607997, 0.028660452413943507, 0.02661467015352701, 0.06895336007038433, 0.04942751406962353, 0.026730826319826227, 0.09398869974839111, 0.031999800947584936, 0.0740507482400825, 0.019940261263400316, 0.011578254521854464, 0.039222797739409634, 0.03787305040825759, 0.022060306171976754, 0.007473767055348764, 0.05775199782463813, 0.04696581692945573, 0.014969885683498316, 0.011223031042684472, 0.057857204679279566, 0.02435694200797908, 0.04904468844254171, 0.029916647003002228, 0.07272606730581292, 0.20379006712427064, 0.018672301479044463, 0.033414533602133874, 0.058009353571481286, 0.04767827486859695, 0.013802774671104648, 0.07715952537593342, 0.04390710363945654, 0.11318192952462744, 0.07431744642916226, 0.03428786617493437, 0.03826505376867229, 0.0715692745401494, 0.038429280037000295, 0.057273985772964456, 0.04966968212336783, 0.1010347091622891, 0.07205617704218434, 0.08814576247166242, 0.027572638204982205, 0.07186605700201566, 0.009699799270639497, 0.04430136312880824, 0.01789862545387399, 0.015552347120378288, 0.0276783027971584, 0.030415127008792855, 0.08363952604873527, 0.02039439435447416, 0.06279390590685992, 0.07467948426041873, 0.04160573721052178, 0.3715159936297325, 2.1515862499513934, 4.141613504578991, 8.396647245653215, 19.75690011055239, 29.243240625627582, 41.64836583598968, 52.1795492787515, 53.48812257089923, 52.85702889965427, 54.699479918326105, 54.25258467274328, 51.88523423287177, 46.14283330978886, 51.00973767618979, 42.776470876509144, 35.438712566129624, 94.89465467391476, 36.65010129251788, 20.68253044159182, 31.71943291541069, 20.50520989202684, 20.482154200153968, 23.64645181163665, 28.561952383287494, 28.092478013807728, 31.209773863515547, 30.68354279764237, 27.00599324318671, 28.398236574665194, 40.36173036021572, 41.649397419345, 36.9218195638349, 28.03712356475092, 29.805694780042096, 22.71907210350037, 74.75440563694124, 63.887581056164166, 31.71023887972678, 23.247713465844434, 31.28442833500524, 28.627042155111994, 26.33360093639743, 33.89302807469522, 30.94457261023983, 40.27490477408133, 43.615140299643244, 48.64493285456012, 52.370996244492076, 49.414239083566976, 49.77189648535944, 50.15182902736049, 37.63315316169493, 39.27504947108608, 37.828408748872825, 27.639426608239454, 16.960263905986665, 4.264783282433787, 0.16975377656279073, 0.04691628551471138, 0.0919090544865016, 0.011598724391191237, 0.054925106570965825, 0.06710983076763731, 0.04322774069864423, 0.051113348003597035, 0.03908962484509234, 0.0700621650884709, 0.034401515318501386, 0.05559485127788879, 0.037870227374256625, 0.02882641770185963, 0.016753427428944458, 0.04895727014950207, 0.02021666195604109, 0.03392158804701702, 0.049542503867058024, 0.08792050963928623, 0.040129512593510656, 0.055087157149588874, 0.05717141809122217, 0.05767224807172053, 0.04077171643955573, 0.009764089369245115, 0.06570732296114007, 0.01238040411995063, 0.014545478719106365, 0.03841228437640014, 0.1764231848139917, 0.014472697493470004, 0.06728985376896397, 0.036867127167962255, 0.03275452587272852, 0.08162706669780516, 0.04762257644606214, 0.09846076864989535, 0.016034398370632724, 0.059597978608742844, 0.09055170756314071, 0.03130771711678996, 0.03556077105684146, 0.042884081316691254, 0.01593004091597733, 0.024048857834009875, 0.1006883608117219, 0.03809371820440696, 0.06652203448597463, 0.018898571293140133, 0.030548219463878104, 0.05229724112958197, 0.05154496194013665, 0.07836417565422674, 0.021760639389075583, 0.038509765234325206, 0.06142340142339949, 0.04004821917342563, 0.04690299005878549, 0.01431505383563138, 0.02334353408866352, 0.03359793888164624, 0.01910957297490489, 0.014374648772871063, 0.09129433021430047, 0.05314888575324609, 0.040990507320290616, 0.04600745242749972, 0.024563559751597144, 0.011198703920648945, 0.04381223514135327, 0.08086227346211672, 0.09813159599059051, 0.07904958685920124, 0.07789234976254164, 0.017152206837049416, 0.014753741636541823, 0.06532761148147045, 0.019636652958128723, 0.046137537987482165, 0.012640554172497605, 0.04464853885433367, 0.04762986960310129, 0.051933747731269374, 0.020206748778300903, 0.08247054482419645, 0.0644472538824043, 0.032061398247136705, 0.08844948569012266, 0.05560967124878399, 0.031461049614834695, 0.035745019033070535, 0.02065061629118939, 0.0358730323252178, 0.08142974543114824, 0.016800124318368973, 0.04700427071281499, 0.017609174453443097, 0.0501437220091541, 0.042508188785324176, 0.02255312478800695, 0.007812115053961715, 0.08401857103191077, 0.04236490353040638, 0.048557333948631445, 0.1064121024683118, 0.011659206075203276, 0.052788307319485375, 0.023032012095134106, 0.03779236602807238, 0.020175049975213986, 0.01242005204286186, 0.019053307647306113, 0.05424100920678147, 0.039024285206030455, 0.03890847569451698, 0.06193468850406428, 0.23650249646555996, 1.2552818872274891, 4.444559726022906, 8.624998811752565, 20.087047969141317, 32.26988657828301, 43.58402021469609, 51.915205063358435, 60.19148065197853, 59.9216333512337, 56.91433645063832, 50.718474234304125, 50.83026962895548, 42.94334811549033, 30.182736535226148, 39.47980503882132, 31.250890108846853, 30.078021018735825, 92.92060421359156, 36.29374219525245, 26.43783204017147, 43.6715792840527, 39.639068957298036, 35.126178110799486, 40.122155912460826, 42.113049030303955, 45.57517613134077, 47.17606798295052, 43.53317060778218, 45.04364398217971, 44.858653237742764, 52.91669599471554, 52.364814589100504, 51.91803309225267, 40.360914507219874, 43.308101084924516, 35.94990722594723, 70.88223395809051, 51.0552175583378, 27.80074977105664, 23.396322265748058, 24.924281566373764, 23.01104549438723, 21.723292143114154, 18.863570497881984, 24.332315498782744, 29.25925958541132, 31.16285251032922, 40.3646368365134, 45.14612767004198, 43.949490977871804, 50.258756760627996, 56.31869316101075, 49.65644151933732, 55.70768594741822, 45.739378313864435, 38.72768663590954, 28.751791177257417, 10.395282141623959, 1.3231218534131206, 0.02400330816125197, 0.21120518536096622, 0.0230641188400407, 0.012993131775499113, 0.03385955024690878, 0.04771241174650289, 0.027956616794390064, 0.032872457447792255, 0.08668760603834545, 0.08800198309003346, 0.02601722690967783, 0.06692754780693401, 0.05519883744719048, 0.033525945768961986, 0.03588782548303566, 0.03835197027412154, 0.045393287399483305, 0.024346159320444833, 0.041592503041629834, 0.007904625916478015, 0.04092867253348231, 0.01879488129258877, 0.04185699489748767, 0.06447975899303152, 0.03519230191746066, 0.043534122242201725, 0.04278853866121462, 0.05340105125440225, 0.025637469464732755, 0.11112794820820132, 0.08463160224979924, 0.05704661853791726, 0.028356221662233436, 0.02676037816150535, 0.07235556420299315, 0.12529744916865904, 0.03021426641592576, 0.0544351282259149, 0.033186430922679366, 0.06289147486489627, 0.0617395582488708, 0.009205914834784645, 0.044215339115790786, 0.0024723584506465427, 0.024846451124176386, 0.06998587805297106, 0.05194819231908168, 0.11511751961323524, 0.025337348774736448, 0.018137853645208864, 0.025366347117890275, 0.014987137983553113, 0.0239241540416955, 0.040563949564051245, 0.2756940531394174, 0.2669160644854269, 0.10541027396797173, 0.14112574498980276, 0.1250591038936569, 0.11480504767067971, 0.19958326382742775, 0.18890686333179477, 0.12546567441595177, 0.11296494278095423, 0.13304598419175995, 0.20647728905802776, 0.1438951221925597, 0.15455584852926194, 0.17780650977886495, 0.22731458948504543, 0.16022134452096878, 0.15047520459178956, 0.2078401747970812, 0.17191834267108672, 0.09906705063317092, 0.08996588012744343, 0.18619121953604684, 0.09745389163013428, 0.17498369028251018, 0.16753670278816454, 0.17501618773225816, 0.15432450529788772, 0.13456562684187967, 0.07761520979505393, 0.2479423495430139, 0.17538896611621305, 0.16743913383012818, 0.11615327048686244, 0.19023938134552973, 0.18439469738833367, 0.09760632014442837, 0.16821384790443605, 0.16244117621212237, 0.2169987252883373, 0.2376697080269937, 0.1032357487166601, 0.13791833403370074, 0.14988821270244737, 0.08548461050996858, 0.1400178899207423, 0.15722290702885197, 0.31739488484398015, 0.16386390873982062, 0.2340896872262801, 0.28401986605698065, 0.13640622968875593, 0.14655239008847745, 0.15769703884518918, 0.13141634663747204, 0.14478531636057362, 0.17272985960927703, 0.15616477106607732, 0.20441694155095086, 0.12820505927647316, 0.09472828103049148, 0.20087019960966804, 0.2721776482799361, 0.49645307503881, 3.2395093046849777, 8.919582539989102, 16.33246502568645, 32.0781885808514, 44.29035279058641, 58.296771895500925, 69.56409792746268, 70.08129381364392, 71.70841847696613, 71.58186712572652, 73.86213702540245, 66.13005499685964, 57.982335090637214, 65.32487477025678, 52.5406309097044, 45.66834419004379, 105.00119055471113, 45.09037117804251, 29.698374809757357, 42.93424037195022, 30.73295681707321, 31.3107023316045, 34.74095429143598, 41.45491453909105, 42.89660523014684, 46.69950000701412, 46.42505176605717, 39.42874362391811, 40.99613843425628, 55.101114934490575, 55.143366705986764, 48.92468021761987, 37.101750450749556, 37.978309969748224, 31.182040745212188, 87.6693428716352, 72.39237785339355, 39.163897345142985, 30.498977630369126, 39.044257210147, 37.981039939388154, 36.62289965537287, 44.799052822974424, 42.313721410689816, 50.315572292574, 54.470958709716804, 61.07136241851315, 66.11240433108422, 63.06704867270685, 67.14285019905337, 67.18947149092152, 56.52546874938473, 59.05073381239369, 53.34761542658652, 40.89505111017535, 25.576140265310965, 8.171063402006704, 1.0471665642915233, 0.11054881638096226, 0.2544243420444189, 0.15668073128308022, 0.14853395311342132, 0.13835630650001188, 0.1994251126363393, 0.09504818402591253, 0.18003155086790362, 0.20618548616766932, 0.21505208055098213, 0.12476517127886896, 0.16651317867780888, 0.15221592489509814, 0.14536861570612078, 0.12074362336387559, 0.16121264697322923, 0.15773880595882095, 0.10233414749945365, 0.13875602053538447, 0.11260843610451107, 0.1407715825424079, 0.11932718807891493, 0.14197856938887027, 0.10452646131236708, 0.21399898544674922, 0.13299347652542975, 0.08949934790331511, 0.21010568065028037, 0.15489174744054196, 0.21738823503255847, 0.10518516669230116, 0.12962933930177845, 0.15029212489964502, 0.16668537992142862, 0.19204656743714887, 0.1613132956047212, 0.1336945389066973, 0.106021405287808, 0.12153852385498824, 0.21285245825927104, 0.18462012642093245, 0.10916402052727439, 0.08009822333171483, 0.16427827037630544, 0.10665939565026954, 0.20210067471188886, 0.12695656578627326, 0.2079100113722586, 0.19274433564034202, 0.12683202287242298, 0.2244607740712743, 0.16771950668865637, 0.16348612014084093, 0.10717749325258118], [0.03888656174944293, 0.0390561506332409, 0.03920795095543708, 0.033944451941117164, 0.07172837568026397, 0.0333902332931757, 0.024576882020600384, 0.02321778650155231, 0.07387575843641836, 0.05274509613011634, 0.02479170265066768, 0.015090888313528512, 0.033602535409191926, 0.034683190526500825, 0.036504242809549454, 0.023205994493177822, 0.0115569812178071, 0.06981484892387545, 0.03977598599909295, 0.03179729709612026, 0.04478178835744339, 0.03701428882777691, 0.015371081141394474, 0.053719494852327535, 0.053697914155500556, 0.11217726649896753, 0.09372367929186552, 0.10092034755695252, 0.08132876738184884, 0.060692791030892444, 0.03712171733739876, 0.048603578846180634, 0.02297608959188144, 0.007356532620296123, 0.030564832080516125, 0.0394514826456866, 0.043970953237505696, 0.02502433099453488, 0.04104755788801178, 0.010158187022522814, 0.07749020722844908, 0.06534702414947172, 0.016575520745508613, 0.01690936079549213, 0.051187114609826, 0.06783370724728993, 0.014202788438377602, 0.021297340055987723, 0.04186514224256239, 0.003036655464036871, 0.03778650928589125, 0.0758315809071064, 0.08236883899136897, 0.024975138573697018, 0.021524318501413352, 0.07001904966009241, 0.02587510610840494, 0.03557535354048014, 0.10314469150598012, 0.057521443663825916, 0.09278008113465003, 0.04737253300845624, 0.057636146178288813, 0.027820107587162527, 0.03515683204656647, 0.027426077924188108, 0.038436056084690556, 0.5103079896540411, 1.221283518018261, 6.467032826715901, 11.188819792962844, 16.356027683904095, 20.175736681107555, 10.915653186459696, 22.769480443769886, 49.51741703094975, 52.551633158037745, 46.99846306154805, 53.041227325316406, 47.19175354126961, 68.30617027897989, 48.681928650025405, 43.650884859023556, 26.743702388578846, 33.41225139556393, 40.758305518857895, 27.78358155681241, 28.989188709566672, 34.241922901522734, 42.71348937865227, 25.394022657025246, 32.795741096619636, 28.232475249998032, 39.46277802990329, 36.890295474759995, 30.99403762048291, 36.8406774920802, 43.07956026446435, 33.96876904272264, 81.6790520760321, 74.96726482145249, 39.993925786787464, 49.92716350863057, 41.277227247914965, 54.286901489380874, 51.20740159865349, 56.752389630963734, 57.820957014637614, 53.39594294947963, 48.92397811335903, 45.46104300406672, 38.841031366778964, 34.903540457448656, 20.00404473273985, 17.370271221283947, 9.160240542504097, 4.992919823815746, 4.364982679966958, 0.9908204297384909, 0.13782589786475705, 0.08345409446666319, 0.06893571706548815, 0.06170588485415905, 0.020073238805296923, 0.10490522284301058, 0.055093308835620844, 0.020155106791325157, 0.04811371541431835, 0.05520862805086279, 0.012941928373860016, 0.09214718525688495, 0.03797667912177501, 0.041750320984471234, 0.027373604731814518, 0.03070897918434874, 0.01896471915496213, 0.039413067166723555, 0.018048127512297323, 0.02514189484739496, 0.01524014043576655, 0.05873284317673214, 0.02722789289339656, 0.022901005314422712, 0.0462492412677215, 0.028383362242170883, 0.017816150343165766, 0.09858471401516469, 0.0051732418867158556, 0.060611279275749004, 0.021903020660242727, 0.06340467716537176, 0.024156339969786427, 0.02323141520572526, 0.011317309653086048, 0.06847311487241138, 0.07484056956825719, 0.0784839381794295, 0.07925037084327591, 0.01764414062152707, 0.05978652816866675, 0.017091015564097513, 0.031815240790526715, 0.09707534460410958, 0.028020724947113666, 0.06307570368892725, 0.03832655530723353, 0.07143192263620515, 0.04949645049148991, 0.0430058624835745, 0.051669225231894565, 0.027700188013935284, 0.058181244549491716, 0.021194946659248204, 0.03951450869921715, 0.06036377541961209, 0.07682701257327873, 0.06546952926944341, 0.09187477205189006, 0.009672637623284132, 0.014618676505051555, 0.018188543767938693, 0.031248636416069446, 0.05240045615562028, 0.027630627230410616, 0.05659037870505164, 0.045571203659018206, 0.04602391182655289, 0.04076946414105835, 0.06874335238770132, 0.057359741655208414, 0.0466284662815592, 0.02455267172697331, 0.02809863225857337, 0.030856290231308633, 0.030274237693858244, 0.041448830912310275, 0.024157782130303885, 0.02088787180611924, 0.06455258331111362, 0.06003879709169269, 0.033426044073196194, 0.059501386412809935, 0.07345176707472532, 0.056341001763939864, 0.05822835512639535, 0.08344772061513317, 0.07659294206889407, 0.03267275747813044, 0.04081080224545252, 0.06373344379807673, 0.053057885999160434, 0.04966684376760837, 0.02264195268282727, 0.02882365403967279, 0.029674229970682534, 0.03688838993830066, 0.08095500840535087, 0.032040214000810543, 0.01230298423193275, 0.04311664262786508, 0.0424547694743641, 0.030430278312715314, 0.02189051235965904, 0.0342257670877922, 0.01819110250160579, 0.0028708673339532392, 0.03581222409622804, 0.06973236423706816, 0.02996360627754081, 0.018218760190892126, 0.06881007864590614, 0.044385337856628244, 0.038449477945123954, 0.0551727100185329, 0.019426313942418467, 0.05343695396497365, 0.024191836653757962, 0.02552374371237332, 0.0662172923705751, 0.11696711633234255, 0.13060625462282088, 0.04883908959586294, 0.4161318205296994, 2.227097269027464, 4.971996430427798, 13.96882220622032, 23.419940817740656, 31.57895518887428, 37.16415928256127, 34.90280697422643, 44.95082501442202, 61.34776007744574, 59.634005946497766, 52.897445001909816, 48.48739870132939, 43.30148404644382, 84.84355757313391, 41.675865573267785, 20.043482203637403, 25.922556154189575, 18.251606225967407, 24.714548510889855, 18.37262507407896, 25.807752301616055, 28.355545497709706, 33.382268797966745, 24.886397354064453, 23.52447590520305, 22.904472735620317, 38.4170506077428, 38.280371696718284, 30.434501709476596, 24.6194016164349, 26.94772643427695, 22.27227883954202, 91.71330651929303, 70.65683887850854, 26.918720506852676, 28.403810262680057, 28.53281113409227, 40.51755043768114, 44.41691198656636, 53.21971870237782, 55.65220402133081, 56.768808672505045, 55.663782858079486, 53.1693240904039, 51.21524241662795, 46.43152367684149, 32.21722483634949, 30.597738988937873, 18.56205790273605, 12.392746210098268, 10.640156692074193, 3.685754417411743, 0.6647618259153059, 0.02264168072161415, 0.10339608325833276, 0.07664544973522425, 0.057037130538975044, 0.030159797564509417, 0.0532162172209111, 0.06457568086203068, 0.04015694237163952, 0.05558230275768907, 0.01488654776626537, 0.05480720180897944, 0.03875403619942166, 0.028123281137537093, 0.02521493175487605, 0.04217911188700988, 0.017494355110571753, 0.058587803580467744, 0.006406989141983251, 0.015050651460525491, 0.03563878562061056, 0.08654524391937642, 0.04797643628872691, 0.05034201620747486, 0.004508658218377781, 0.028228633548884143, 0.055233200321034084, 0.04504767832376304, 0.0786993467819787, 0.04911467823530397, 0.059745779951974276, 0.042051462486626646, 0.03225906999901899, 0.04528140791902139, 0.04540789669619934, 0.04033909509739569, 0.0326853136592094, 0.05371397901927272, 0.10193117759040288, 0.037610569533201, 0.0056928252207956494, 0.05347055075089297, 0.05326991232352392, 0.0519535472736724, 0.05996973043487919, 0.05106241464795125, 0.07356451989542093, 0.04098203055740845, 0.02252508022431885, 0.04293399577539775, 0.03909538199584331, 0.013551620406008536, 0.04763072762157648, 0.03543099959290797, 0.03173411974022466, 0.02665659048474364, 0.08488664058067145, 0.08132200282547744, 0.18453651558487646, 0.15115841712442138, 0.08530490160469087, 0.09468440717506794, 0.13825138309790244, 0.19063285942519867, 0.09164699879024299, 0.17025121277378452, 0.10736704638768589, 0.1317907491278264, 0.11201911530787907, 0.17210594228198453, 0.07932194643804143, 0.22418479855743148, 0.13498997826489711, 0.07638058249628352, 0.15567229910483285, 0.1371393298670169, 0.11719285946099028, 0.12795832533870014, 0.09906528097006584, 0.18329977388343505, 0.31354057392285717, 0.1434560618813961, 0.3343958467725785, 0.21682344437126191, 0.1826944418491856, 0.20803751904637585, 0.2323425011408906, 0.16398570139802274, 0.11700590336394888, 0.11106781796702456, 0.18023116273745415, 0.09016654153745021, 0.12056576839137463, 0.2028851027810766, 0.14232801273465157, 0.15320108332220586, 0.0986563049316887, 0.15206869811780993, 0.1268673242039738, 0.15981398492811189, 0.11494104359899798, 0.12255224203991315, 0.16055348960141982, 0.18517210809213502, 0.09175630421527932, 0.09670797480090011, 0.12500402983278036, 0.12408306191284811, 0.12810483199333952, 0.20455967905300282, 0.10656612444548838, 0.12572261264487622, 0.17302840407336914, 0.1177348283630225, 0.3103867431561793, 0.1771189611885817, 0.19219149595066426, 0.1824691353906547, 0.11241322157964592, 0.1562198374660746, 0.20629931151145892, 0.22723313901693593, 0.12999525353793176, 0.25013365211986727, 1.1725035742405923, 2.9063319054342087, 9.107647442048597, 17.703382430538056, 25.0678873831226, 32.55321702649517, 34.23130896783645, 46.5455352106402, 70.13578338007774, 71.19210120170348, 64.77759038248371, 68.60161888983943, 61.43680572509766, 80.8003705547702, 60.35683601133285, 58.98457127232706, 40.83218336105347, 47.603433747445386, 53.61971024544009, 38.94007121362994, 40.50302982330322, 46.95520716328775, 56.878897836131436, 38.832990507925714, 42.444610903340006, 38.845526402996434, 52.4966101492605, 48.591827884797134, 44.38530552771784, 45.82606661704279, 51.199533324087824, 45.03413615688201, 90.39231500317975, 81.65048153169694, 52.27594544810634, 59.9510197485647, 53.25951114777596, 67.40961059447258, 64.99979657511558, 73.89203333085584, 75.3066518229823, 72.02495374987203, 67.68381564847886, 61.27740844603508, 51.64036066301408, 47.73032634488998, 30.212701482157556, 26.920293377291774, 15.166378694195902, 9.889471915460403, 7.318376408469293, 1.935930415507286, 0.391683166305865, 0.2750355852467399, 0.24811157836548745, 0.14581478531322173, 0.18140320065281085, 0.15531557792377088, 0.145661705624192, 0.1646099864475189, 0.16563830626828058, 0.21785766306904056, 0.11793688405305149, 0.18048106061835445, 0.162284005613577, 0.17262986981339995, 0.17728651993938033, 0.10155138184106159, 0.102428529531725, 0.12534346807027055, 0.14105972353248827, 0.10153357029682207, 0.09320353623479606, 0.1714144253562535, 0.19277156240517096, 0.10740793250020474, 0.10433097865672843, 0.1258262490192729, 0.14136756830398114, 0.3524056545669033, 0.3147684902914109, 0.11496337506199077, 0.14751571500974317, 0.10774498054337119, 0.2216569382336832, 0.12296855720060489, 0.07624014325800442, 0.19224529064470725, 0.2837262705208794, 0.13894230247505251, 0.2653092410295241, 0.12270870783756818, 0.1283920230343938, 0.09838349336097318, 0.12317167775284861, 0.23439825212042179, 0.2662464729960888, 0.18224819563329223, 0.22134484933508983, 0.12911964568399614, 0.10662151260241386, 0.13740358423561821, 0.13918522895584184, 0.13577740939874805, 0.10843301942992596, 0.11109744258705648, 0.15440926526583013, 0.17279235706213983, 0.1765416679723609], [0.02759932679304433, 0.055774621470200444, 0.037239311833775816, 0.05047365309550397, 0.02535643777058971, 0.028096008407432708, 0.06607781074220134, 0.04863737481496027, 0.022718153533435637, 0.030372413776574597, 0.03855720905947589, 0.02256148663770047, 0.049406687969401966, 0.05371053545405308, 0.008597941712416228, 0.02470890961347088, 0.03653623081082779, 0.018080967786391417, 0.04467367036868969, 0.11578944000986316, 0.02818480565873606, 0.0567661767314759, 0.03639577242035059, 0.02432574307726276, 0.0877110688616672, 0.026971433469424808, 0.03533141199319113, 0.07488871819429821, 0.06294652594313507, 0.026253936586961634, 0.04471192879962825, 0.03615562683872638, 0.02528289141463897, 0.11003304768594042, 0.04000370180414569, 0.04104434797960905, 0.027596021123651057, 0.021162263433178587, 0.03348406374214157, 0.022268302873858524, 0.12940810843100473, 0.07393876916819042, 0.026500333446047963, 0.018332254201654467, 0.031329506572576306, 0.005810910013444241, 0.02527482259357649, 0.03936655796884049, 0.03623802725586199, 0.02847534833445905, 0.01253573802269755, 0.019560318042133606, 0.07195788030061992, 0.021301080480278022, 0.029318575567055135, 0.022923407640548486, 0.05110203671539503, 0.03789844239250787, 0.014398245238548806, 0.026691188930623957, 0.03104548330508894, 0.08620870915511925, 0.011270675965915284, 0.030170024838298563, 0.12947753131870302, 0.029114259917649533, 0.057854534862863446, 0.004915059243719424, 0.06673977199581362, 0.058199205480876474, 0.11437732546079545, 0.19534053100693613, 0.15600862702535045, 1.0660043599144107, 2.7210798330845374, 10.612042123271573, 17.93141334287582, 33.475668276509936, 47.24963988027265, 51.66127866314304, 47.0769496886961, 46.80604334800474, 51.19596788960119, 55.90841716335666, 50.21179422255486, 48.11794673242877, 58.050490194751376, 54.42746746924616, 56.69078096266716, 56.1282346325536, 56.07056402391004, 60.078637984491166, 58.97478103637696, 53.2698348260695, 47.10407287843766, 55.146375163908935, 61.099011205857806, 57.9709170710656, 57.939514575466035, 55.17997810917517, 54.7830891609192, 57.54132340031286, 65.95170482512444, 62.03371201792071, 53.672473968998084, 35.21630633261896, 30.054949637382265, 23.534897642750895, 18.08705299131332, 11.5376655901632, 8.396519768622614, 1.3650842275350326, 1.147913377611868, 1.259054226740714, 0.4499457157667606, 0.034594002570356094, 0.06458935553147908, 0.1789928428948887, 0.109681612511556, 0.03806160379862113, 0.04827386226444956, 0.015314246993511917, 0.07028177185284515, 0.014954676922981539, 0.034653937459112175, 0.03545703892145426, 0.007679247158399273, 0.08210254682888908, 0.01949939106951558, 0.09306632222667818, 0.02978696172396022, 0.03365250349405312, 0.044495631535086906, 0.0755073341931547, 0.038511082905554966, 0.017791342500957753, 0.053940430779250405, 0.055366143388974096, 0.018167755972113342, 0.027016939092127067, 0.03188748288178637, 0.016500775461956378, 0.033113399760857705, 0.049898819021520116, 0.05737560350568064, 0.06654927657256204, 0.07746658107686429, 0.01854867212504389, 0.05237997096452502, 0.04751494875357998, 0.07639868515393428, 0.04053448582248342, 0.06057785869005227, 0.03891507937242428, 0.04378851322877792, 0.024115557279137355, 0.05942139534219619, 0.007972201095863937, 0.024128724415335926, 0.07325544172236997, 0.04330013217704912, 0.03604347156661172, 0.05278933004686429, 0.03166800252191963, 0.04538500215858222, 0.08150182664394379, 0.005121848399510547, 0.030847248478582313, 0.07364787792246189, 0.04851744375041416, 0.03741931568290438, 0.09263111533777368, 0.055432735581792174, 0.031155311585133596, 0.10702327975342352, 0.010363253438094211, 0.034110765799038836, 0.09798946369799877, 0.08889115070022884, 0.06373824333892235, 0.045567292780164755, 0.024363790834022146, 0.08218432671480602, 0.08464477130121763, 0.029513592824279785, 0.08444121407885706, 0.026493293098023823, 0.10096340935917632, 0.030784796990994966, 0.07638594511175349, 0.04594991922438626, 0.0315484085360602, 0.04754614385385667, 0.02522743814023993, 0.03751903351756834, 0.10151124649470854, 0.019112260028299306, 0.026984072004955624, 0.09929200469125664, 0.03178747393371117, 0.062117676265657916, 0.10270360106181714, 0.030749091548064066, 0.08305422721370574, 0.09281611791060818, 0.030837488518426978, 0.02290905115284747, 0.057497790699163755, 0.05702005826958245, 0.11358044080195889, 0.04367370346200563, 0.04603388629132702, 0.0128792671697034, 0.02407347989989625, 0.05020144673424864, 0.03937853958397623, 0.07598482147460023, 0.05483379655127084, 0.05506488697363004, 0.020663501890075785, 0.04932809883968965, 0.0172796149197365, 0.009531053083558238, 0.03262415686021409, 0.04204743669458455, 0.06003705424166495, 0.061609273506028045, 0.07806226806414705, 0.05882782658802406, 0.03044168153146823, 0.05800279202840983, 0.026919061783701185, 0.03800103688732751, 0.0476652360521257, 0.01611802069800756, 0.011351947360972484, 0.0395627492558091, 0.06795836507432884, 0.0798943137089091, 0.1058295462280512, 0.24742986736518724, 0.09289900862401532, 0.10762926296240861, 0.06827809953040655, 0.02533904757470854, 0.15725885187425923, 0.4489090762311413, 0.7197565200828737, 1.718741792344278, 3.7896996784594754, 7.043201548437919, 21.657400246589415, 30.630157378412065, 47.29812429797265, 61.66954348164221, 60.861166523348906, 57.23450383832378, 52.43462101105721, 54.46909950625513, 50.997699922130955, 47.05332525314824, 46.33147578085623, 45.57019472122193, 46.71161228610624, 49.16392910865046, 55.222896683600645, 48.52039760158908, 50.13873223335513, 47.88247116150395, 50.53130265205137, 44.76714434162263, 47.103178578038374, 55.169642663771114, 52.24710818259947, 49.27153933432795, 64.22908221521686, 60.37783638123543, 55.127834120104396, 67.37714121418615, 63.03525001771989, 65.50646481975433, 49.57773131708945, 44.64806118319112, 37.398144352820616, 29.18752531851492, 22.446318326457856, 17.487040181313795, 8.025044347009352, 5.137162045125039, 3.782237124058508, 1.5696505409094597, 0.3346679612032829, 0.15658472514440938, 0.15087694109928224, 0.07277466026285002, 0.03411492182602806, 0.009754984414265042, 0.025783707988598657, 0.037012212729502114, 0.0218124020348994, 0.07453048782002542, 0.04226025208951004, 0.02238113038812674, 0.07093247927484975, 0.09466098786722268, 0.007426338073151607, 0.06530395468636867, 0.012391940446480388, 0.03668558731254551, 0.10315346321271313, 0.059245141493456985, 0.026608529958813906, 0.027770365498238997, 0.009762185640753278, 0.025530284188026865, 0.013056720903654014, 0.044058310243511395, 0.010975224581817466, 0.04011504119262099, 0.11181190384611969, 0.038458579069664406, 0.07192990276962519, 0.02396036893309605, 0.11263912558675775, 0.016401724123786536, 0.052832652318982355, 0.0645940286678172, 0.014581145857641054, 0.047508804728427244, 0.04198431871050308, 0.05805924504755005, 0.06229613644761905, 0.034508664206030874, 0.009523883458196877, 0.030601204019941153, 0.060432179410371094, 0.044467696138928016, 0.07267472409312764, 0.08861656180552899, 0.021569720702245835, 0.012063965757167148, 0.029052176152265845, 0.06725685836206521, 0.04921971272016245, 0.04114891515083371, 0.022045823279768232, 0.02858253552638475, 0.03371260309171292, 0.03954045609721253, 0.037181250029994596, 0.10024050581118754, 0.01718870709620176, 0.06503629122650431, 0.22298993122193123, 0.1459638660232867, 0.24926591964979328, 0.08346525636771995, 0.2036499956081952, 0.1647721366175721, 0.18525300697693903, 0.13694069859000946, 0.1770859581208037, 0.08229923990344809, 0.2023713029320202, 0.15070002075404892, 0.13116727613152998, 0.09208828841726627, 0.11207337731555586, 0.15417395369900813, 0.17613561072897527, 0.24055819658021774, 0.20327176267821945, 0.1433985593217996, 0.16608792327104077, 0.1204633730794153, 0.16242130389136655, 0.16235793309827007, 0.21589658523519195, 0.14126523427905577, 0.25847349976820333, 0.19009786958415664, 0.09921948680834425, 0.21369995068638556, 0.11206878078801018, 0.11791361796279108, 0.23567498361151065, 0.19430049004093294, 0.17208636107463993, 0.13073756209304258, 0.17823277642169308, 0.250187216987533, 0.1508184273036257, 0.25217890769483586, 0.21669808174333266, 0.24152643978595736, 0.10117585320145854, 0.20799618094198166, 0.1387163678244237, 0.18834473865647472, 0.18745993774744774, 0.21655586518106923, 0.09574381484379692, 0.08147843797961551, 0.16389239188884536, 0.20961699316338187, 0.08076272033635648, 0.1277503171454995, 0.1580613749402185, 0.13515753701569574, 0.11388095411201639, 0.10385155317283447, 0.11946858492709937, 0.14884886121557606, 0.1624198636460689, 0.13761926862982013, 0.1758144973146339, 0.250497528562142, 0.18860632703909952, 0.16539459837780845, 0.15543616016305264, 0.16940433321700943, 0.18938042824306797, 0.3252967447042465, 0.2911553315577969, 0.7298941309413602, 2.5442777718267133, 5.976378148601902, 17.953637492272165, 29.458484611203595, 50.74117691286149, 67.42440577476256, 74.73579791284378, 68.1104047836796, 69.59011893118583, 70.98501574608588, 73.54775121135097, 69.29770623483967, 65.12837579173427, 70.421096586412, 69.63550859881987, 72.52984908319289, 74.0440094855524, 70.7209696308259, 77.52101805902298, 74.33362945433586, 68.10882014612999, 62.731019220044544, 71.64470349588703, 77.00846625912574, 73.05277947456607, 74.94062408324211, 70.40809785166095, 69.66996269841349, 74.43546202874954, 83.93880013496646, 77.6472399311681, 72.5367053862541, 55.15332560385428, 45.548653064235566, 33.32390392980268, 24.537345632430046, 16.683972151048724, 11.375814868557839, 4.564729871288423, 2.341405922366727, 1.9330288421723152, 0.7494653484994366, 0.24935593498089623, 0.12829142036817728, 0.2307603610379081, 0.4011317270417368, 0.11960603642247378, 0.14440711407411483, 0.15632318272706003, 0.2328184256029706, 0.09011882192064678, 0.14240871243659528, 0.11781636310080368, 0.08212189820985641, 0.20508616531808532, 0.1871188600817996, 0.13398016712838604, 0.16873726981782144, 0.18443980464531531, 0.09938160633488048, 0.2158521368138252, 0.20080414750883657, 0.18305810378684154, 0.09249957804117473, 0.11232227162127534, 0.09466009154435127, 0.15310942856294496, 0.15801544030827863, 0.08857594382378364, 0.10800717413545617, 0.21244477690948596, 0.14046684808788762, 0.14610263518989086, 0.19785110838711265, 0.2632079844272906, 0.13629079556032536, 0.126057147919651, 0.24349306409637778, 0.12266776809889464, 0.1983656130370594, 0.17842455887265746, 0.2186655027851943, 0.11766288504605332, 0.14999728830110642, 0.13536430414645903, 0.15787858636148516, 0.1664168814257268, 0.12946613193038972, 0.14060322706016803, 0.23416513156506324, 0.21715722887987093, 0.0700911385337672, 0.11105279498282941, 0.1895288041522426, 0.144957410351884, 0.13511431433500784, 0.24708446896364614, 0.112123264961185, 0.22593972213085622, 0.14402094447324354, 0.19578297742672507, 0.23905346200110453, 0.09858254598633898], [0.021595352088972446, 0.03786776440158006, 0.09039613808835707, 0.05081149787011166, 0.02938919929757474, 0.0730765984964467, 0.07920713284082952, 0.07690083280566239, 0.01742186021029709, 0.02020666642384904, 0.13426193426693642, 0.011369546315813018, 0.012169512563324984, 0.05113983166313941, 0.05600766924720618, 0.03465909323084258, 0.010820055387974268, 0.048844122793525464, 0.02346765182371582, 0.03434463712056318, 0.030510547090201613, 0.01652423307419785, 0.03185740626987911, 0.05237232923748032, 0.02293257005212288, 0.07303398102521896, 0.025797884445637468, 0.08514571619490463, 0.04225382078138571, 0.020899738508066344, 0.06916979523075205, 0.05009601005322991, 0.04171211617968736, 0.0504942761824256, 0.06089789192042044, 0.0065006567972652135, 0.02746803464458114, 0.06850147544736825, 0.02454552029620015, 0.020096378491049813, 0.06155388534910256, 0.05564930863798626, 0.05259455219211598, 0.02818612332996582, 0.07311144017524297, 0.01620346056898275, 0.06478378098578223, 0.04258510401292194, 0.014542160600784325, 0.025761694452094457, 0.027426229226553155, 0.030129912474583236, 0.012113615915539765, 0.09146165147784258, 0.020269759510072972, 0.030539859529404394, 0.037355033245178006, 0.0427099840054589, 0.01799141210804303, 0.022512123762299458, 0.06909372269987099, 0.0752983300856525, 0.0328333946245332, 0.03372717408403274, 0.014707483332453957, 0.021807658035428296, 0.05825170548632742, 0.0499884627999798, 0.028896723505890662, 0.05311836481034275, 0.04778501772952657, 0.0900996390790228, 0.07960460223858395, 0.13811216960030218, 0.07301289828554278, 0.08673655905670698, 0.10445176773974973, 1.0742274864066033, 4.093308780462512, 12.326295375823976, 19.81217611220575, 29.308312746786303, 31.185814065317956, 28.855351555731993, 34.51769690359793, 51.027309894561775, 52.08830710380308, 51.57222517075078, 55.60663392466884, 57.62806269430346, 59.305075983847345, 49.7348379319714, 47.43537587504233, 43.973237006895005, 47.99687493231989, 46.26545836848598, 39.4544312261766, 44.017536255621145, 45.504169464111335, 46.699582376787745, 37.33806933126142, 35.44889896146713, 23.168840485234416, 17.420903136653287, 6.546086726650116, 2.0567779050719355, 1.4962453443196513, 0.2868061891246227, 0.11320671246897791, 0.04918534218543961, 0.03495652303700486, 0.11424691431344518, 0.07095259674374135, 0.16217555820701585, 0.11281257555369409, 0.10795453623417886, 0.029233218050531806, 0.05046136504519851, 0.05799388242585044, 0.03919241852277229, 0.037187524290094455, 0.012783044611193962, 0.013218622095131827, 0.04334517814699681, 0.032069183615667206, 0.05864031890767717, 0.08913073703766831, 0.09431704503273773, 0.03293943268457248, 0.006646981027217643, 0.022379038968093456, 0.02054475826181231, 0.06066657933256319, 0.04362213425338269, 0.08028643581295207, 0.035067984999548045, 0.022279558620686014, 0.02256650642882432, 0.017475386773566567, 0.03120495408262697, 0.026927394905097546, 0.059488945144919626, 0.030267298852484074, 0.014093723373427508, 0.010997869183249291, 0.05460598115478793, 0.031333224014228875, 0.06272876162021872, 0.02707435355161227, 0.020253005167168957, 0.02477449057022891, 0.06367016110509154, 0.03959962872848396, 0.08798494529459747, 0.009178540598030293, 0.06966013746756701, 0.040321187792165626, 0.027321045354549444, 0.036425274466314626, 0.03478109273278425, 0.10826304750216585, 0.050757940663325216, 0.04096287835930144, 0.005517502647689394, 0.014632603025905069, 0.06253440511382877, 0.04357030457486549, 0.038239707749697475, 0.03989390991327744, 0.06434161035764603, 0.02513082679210892, 0.04437617927549347, 0.07797315671679475, 0.051916441805059874, 0.037728118064302596, 0.06198648753906451, 0.026056075228318095, 0.10725895904244916, 0.09190816582450945, 0.08784044579031967, 0.006481147410663506, 0.08498625499346564, 0.057654574423307375, 0.03003402124910105, 0.10062552628017242, 0.05652853242692448, 0.10492185461184672, 0.04147888837201942, 0.016624762962061553, 0.014656475283235553, 0.020991552230571548, 0.03294472635212926, 0.03291633513365542, 0.05487728736273224, 0.06827505816134714, 0.04265199114959087, 0.09978691281210031, 0.02579338559430213, 0.01705921142392101, 0.04348031222640027, 0.03054640766593718, 0.040830318335323565, 0.07078899100663201, 0.03790862753146118, 0.026494139625180154, 0.05409167185726185, 0.10129568467457449, 0.10218137424559363, 0.0054335193013802414, 0.09912706596115906, 0.03786557722055624, 0.014833469364431598, 0.04660924896597863, 0.03320326570481543, 0.02282576973459894, 0.04414826811802003, 0.05421730644640423, 0.05750349422376003, 0.035807730990552136, 0.023794824993538282, 0.05631372520339586, 0.024468771692725922, 0.015906049915018584, 0.032114133824624365, 0.027947624837378823, 0.038899914661963145, 0.039614368260147116, 0.0346187012450349, 0.051609979822270335, 0.0511174044391561, 0.042828390555035685, 0.041599206310967286, 0.015409837529483824, 0.05659728115724941, 0.025255141794801723, 0.049846437759697444, 0.07011126366353805, 0.025561019635548996, 0.058540394229273644, 0.030296802813667926, 0.05089012147378057, 0.04022167297080159, 0.011535494366750844, 0.036341035438160744, 0.03470785089678342, 0.016196569608103846, 0.035328692381059935, 0.08658949315788285, 0.1549344951467168, 0.02295625940596144, 0.0944133116413028, 0.2701623160992899, 0.6687176588081545, 3.677623344044532, 9.838286945896765, 22.90496107070677, 32.789561402413156, 43.16530719880135, 46.832205557054095, 50.13126796291721, 49.48745012283326, 59.49636605478103, 65.3638356731784, 65.72251289121567, 65.8302447103685, 66.81629719272738, 70.82917997913977, 64.45529314779466, 63.891934887055434, 58.490901762439364, 60.74048696025726, 61.57441423785303, 57.801129433416556, 56.82321194679507, 58.33254783384262, 59.78801781131376, 54.33236960441836, 52.751254343217425, 36.53044939041138, 29.096002694099184, 15.404890179634096, 6.316115221669597, 4.142195486253308, 1.7486534195561565, 0.6719390278862369, 0.11134039971136278, 0.146873886546781, 0.16806994594873922, 0.0455325085579628, 0.08748042277030407, 0.0044285177606188005, 0.0771681285433231, 0.04886815114127052, 0.039987257726851015, 0.032919759546676954, 0.03977578298579301, 0.022646995456588846, 0.049029152179437305, 0.030242944917371197, 0.024204896537647135, 0.05884822367900803, 0.03903575354225693, 0.06071468199332876, 0.030740971016066692, 0.08317529208837979, 0.02247930072518366, 0.019019988568259344, 0.028954442485325763, 0.02339127860332449, 0.05925032024782512, 0.08452385964412844, 0.013241163274693876, 0.019318324273392078, 0.06440312721796575, 0.047725837437375906, 0.03247340224803456, 0.03617284083438497, 0.025647265814064492, 0.08415236828788634, 0.08903631670100075, 0.04906127424610238, 0.10226003615365875, 0.004886156661556133, 0.03256194285988327, 0.03204843412423807, 0.04573011327715171, 0.029059168619794712, 0.03663365804259816, 0.015540926664647077, 0.04639269123154302, 0.04080476930304881, 0.05599296035906, 0.034646862637131445, 0.04233498779696323, 0.024529742715399594, 0.03644992334527835, 0.11337876049501282, 0.060847000699610486, 0.0443984839254089, 0.018994851308243892, 0.056472941256699064, 0.029791272883754105, 0.04426381715963926, 0.020125168075244275, 0.03819441663161401, 0.0699248897933191, 0.014352753022385221, 0.03088286007574249, 0.06676869947583446, 0.046127425626881664, 0.05021876415177699, 0.04894759828945802, 0.15321956136293952, 0.13750361999677074, 0.176638440198956, 0.20431964838456726, 0.1615523456806137, 0.20569273841477212, 0.3023880497822839, 0.19025124038659758, 0.18781926362745224, 0.12070214736365503, 0.2053800519675978, 0.12907542708900668, 0.09417023194292862, 0.07903942087244603, 0.16195363785711028, 0.17011362338258376, 0.13043172447191131, 0.1639572029272395, 0.15018545481706821, 0.1952997751293644, 0.14664413677828927, 0.1904551423485241, 0.1033934249332355, 0.16359416918168146, 0.15931634953425777, 0.16118667659259614, 0.21064767253495034, 0.23134212820760666, 0.17749826664165144, 0.18285867577839285, 0.21872974691852448, 0.18996348244047936, 0.13915787961694503, 0.22073602393990566, 0.14411932548447964, 0.08685575467684577, 0.06516499399778343, 0.15587843804349824, 0.08662032053595589, 0.17169784724472031, 0.24450452998280528, 0.16949229543247532, 0.10919505474908699, 0.08701771332491791, 0.09732908824638975, 0.11052446244584938, 0.1356567352289154, 0.14013459575512718, 0.16381405173770844, 0.10555447469795905, 0.08739798404877225, 0.1287907947816195, 0.14290136825894156, 0.16674970066355121, 0.10742510053058786, 0.14257398824537956, 0.09747012503324978, 0.1691630001991026, 0.11284991467912352, 0.12895207161143904, 0.16696334726387457, 0.1316319850663985, 0.1647048434543033, 0.08365608886965821, 0.1265184477632565, 0.19682905516557156, 0.09855361850631815, 0.10595584348324807, 0.14868926977918995, 0.2244086800924232, 0.22827196956401874, 0.19756509712146175, 0.2071995107877639, 0.274956678190539, 0.22482877206658164, 0.15857727387018744, 0.3472415784433965, 1.69831212730177, 5.874392111455241, 17.559972732297837, 28.1147119691295, 41.71934112425774, 48.01167403498004, 52.88206931083433, 56.77975993002615, 70.12306705597909, 71.82084929558539, 72.33514262783912, 72.73501257742606, 74.17934694597798, 77.37713767636207, 69.23261842420025, 69.67552461931783, 64.65582432285433, 68.2896335663334, 64.68530877943962, 59.83328196310229, 60.554201833663456, 64.00065122112152, 64.82291729219499, 60.20367922321443, 52.330815484446866, 33.828599222244755, 21.58840967762855, 10.695548403647638, 3.873585938445984, 2.133035400221425, 0.7724582824495532, 0.3203529035372119, 0.08398981975211252, 0.25807090524223547, 0.14340137852536095, 0.20518921946565952, 0.2630430610189515, 0.1742646708002975, 0.17935230667071958, 0.2053589539061631, 0.19028988186149828, 0.08320631864931315, 0.11544124538739843, 0.0892247130433398, 0.14077535169499536, 0.14026821681088017, 0.07195651666411469, 0.16980973162478016, 0.11295855360766573, 0.37436725030983653, 0.19414800790048417, 0.18870248639535522, 0.13836548423334477, 0.08256798354728569, 0.15306853478954685, 0.13527450331997487, 0.16168633445857034, 0.17981356820992886, 0.15597714081166253, 0.11551911822490155, 0.18832627593749957, 0.07034936379040442, 0.18863654154683315, 0.09480630708557945, 0.11802516036456633, 0.16954615141355223, 0.12515605232047458, 0.15233641520382898, 0.18853918709341558, 0.10458561096100077, 0.17629993658873344, 0.08529655124631622, 0.17349371055681861, 0.09340087282321147, 0.14712753825851027, 0.07950290406663572, 0.2494032485710998, 0.12761900967527784, 0.161343326251353, 0.15329712010439367, 0.13821300209289597, 0.14337330906381532, 0.1147393249876557, 0.222564829032748, 0.17118752543484012, 0.144326536946239, 0.09588714223355056, 0.18577892633695758, 0.14940127189601624, 0.1811703099238296, 0.1091903126648357, 0.16860259156073296, 0.14537639915943146, 0.17235328142921771, 0.1394540032431964, 0.21555003770176442, 0.20659080796664764, 0.12165326084340773, 0.22788707166910174], [0.02758299571371848, 0.09200294622250142, 0.05311087247044329, 0.029933094910736528, 0.034667589145922856, 0.07067547975889138, 0.076357186171076, 0.07297387376667992, 0.06457172018746216, 0.004917825778735983, 0.04015414615071589, 0.07372689989185141, 0.03660329031727968, 0.020570198126557856, 0.011405078431351051, 0.053802914166402434, 0.07818239831155346, 0.10049629490822555, 0.03286524089954553, 0.04326308416503091, 0.06853250966918084, 0.024301287635499914, 0.03112429268507948, 0.03685845888309902, 0.022527083544240847, 0.05568910690565264, 0.047578124194255764, 0.026853616807549715, 0.07576640214650862, 0.0417003452387308, 0.10909768497391094, 0.07016669778573899, 0.035345891054960034, 0.016452577040200273, 0.020322981553392547, 0.009563708538940598, 0.01916963043772886, 0.010726750666846432, 0.0357738622434197, 0.031728328115517096, 0.1383540542015145, 0.0872384922038163, 0.02151685488981105, 0.018397745143081394, 0.09921250008647481, 0.06709223372801658, 0.031007920098941655, 0.0347406892556577, 0.09742121031928448, 0.007767048016596105, 0.016060746049568538, 0.061383993860574505, 0.05032689746228918, 0.058957356734261404, 0.04637336666365305, 0.04790188061193593, 0.008345871014640698, 0.0506007815560987, 0.026416458309658115, 0.05574346850475958, 0.11802686874063746, 0.04990554144305568, 0.03133564293684979, 0.04204202428339951, 0.01205539706373407, 0.029720693203290145, 0.07447211192019525, 0.028354794823474465, 0.02517426206219581, 0.04123496214648889, 0.08509094856919781, 0.05838281377368878, 0.03810629736812365, 0.026441135916919, 0.08181758510369448, 0.029241022571260412, 0.06169836953162186, 0.05748544519226398, 0.0632940617299849, 0.11615626589064637, 0.10960301955140407, 0.05603057527614217, 0.7929917677275596, 1.280992655984817, 3.187087807924517, 6.0323670410340835, 5.439525304302093, 4.488969781706411, 6.189113288156449, 6.820363854208301, 7.858413727052751, 5.892395790546171, 3.9902220281862446, 4.396402335936024, 3.535606332363621, 3.669552822266856, 1.6743887336023393, 3.6422729828665337, 2.7698915235457884, 1.64811939481766, 0.8495040514296102, 0.21522633491023896, 0.09362381207005632, 0.06849100302544332, 0.05509479504619395, 0.06570951397260351, 0.09580599053973153, 0.07126039554995876, 0.05604305101798908, 0.02239297985309555, 0.03373966897807775, 0.06101505740755989, 0.008746868247286448, 0.062479924771093556, 0.030469339220754565, 0.018084066612045133, 0.027999090624131986, 0.08829139578606814, 0.04602745498320268, 0.044654138957060156, 0.014793100361261639, 0.06584291286285847, 0.06508260890240632, 0.021573087658673044, 0.0889905812519212, 0.01656769515736209, 0.07075740520151393, 0.04511440458196787, 0.024998042687413194, 0.0566958575209062, 0.04546463699831117, 0.027144599983829166, 0.0539612798621097, 0.06712696049362421, 0.015487461388411542, 0.017169051195284533, 0.03294834228713186, 0.04981986983048339, 0.04824225347669375, 0.03563246922567487, 0.05283451774307797, 0.10900211550535695, 0.03606937299933165, 0.020281047815637245, 0.025794950328887473, 0.039051902675700766, 0.05982097531218202, 0.008269282332020662, 0.016612312118072185, 0.011194495225114929, 0.05669930108612584, 0.026355324493300532, 0.013620546294165956, 0.04028955985221171, 0.06745027258030831, 0.1029559810675921, 0.02940519712865353, 0.037650992162525654, 0.05666460496403518, 0.049471288333616914, 0.025937774015830892, 0.011716994960161467, 0.05319520342914809, 0.040737698305278056, 0.02368157613091171, 0.07830249025456368, 0.0645627799413858, 0.06737891915104083, 0.08948689897454555, 0.04548526774611204, 0.0442027599520741, 0.029883758848412868, 0.030433459492820888, 0.08623993489891292, 0.004493445148616429, 0.05786527158512224, 0.04183226940973152, 0.05879900252987301, 0.049789199500434825, 0.04674512232022901, 0.07213317653945378, 0.01408427942454094, 0.11580401866306221, 0.07014827337116003, 0.04531697355090611, 0.06812520370247864, 0.10006403745782953, 0.0966006612044669, 0.019949814379816095, 0.09641364382039155, 0.0023866245934304094, 0.027609822197606968, 0.024174971228104927, 0.06573037454678167, 0.07642203551386634, 0.04358202188966736, 0.015173386406874465, 0.021226497990409696, 0.015889912272893613, 0.06360577907593501, 0.0775594539159248, 0.05098629998223436, 0.05737669901141236, 0.0313356448520696, 0.062332996768095804, 0.0486080106648226, 0.023303691770941503, 0.03960544716626887, 0.014156519600580779, 0.024383894896375078, 0.08540564216673376, 0.036623675916944785, 0.017265645306437247, 0.01221132851506193, 0.03279083077946017, 0.005201142330113198, 0.06210336191279273, 0.038808305867977684, 0.004586492751484677, 0.05610537993150854, 0.04911599590653374, 0.07563255892525758, 0.05199410396838381, 0.08286110410887389, 0.028959726576783487, 0.011438884933839643, 0.03388836281374097, 0.02782541274603817, 0.04710996786372797, 0.060657596951651, 0.06789301777438772, 0.06804384516492006, 0.010916050035326232, 0.02204711030748102, 0.03663224077993824, 0.04666180642802389, 0.08534291488749367, 0.0359269381020098, 0.06305825220601213, 0.061468753828516895, 0.06872795402042328, 0.0458236794257837, 0.042876834124927564, 0.047083694878364765, 0.027460011788794113, 0.05697665938867196, 0.05406974259042933, 0.10441527897191626, 0.04647948133248476, 0.09948306701957219, 0.02766338131961323, 0.009166487162151645, 0.0840440434553931, 0.04944981488909933, 0.09775298001665263, 0.2831791918123922, 0.23106088200884484, 1.5209049178707985, 3.8634694103271734, 4.414588895536238, 9.137399600398156, 14.999810341865787, 14.974459082849565, 12.578263532730842, 15.755497121041822, 16.9183769149165, 17.453505877525576, 14.062189325209587, 11.259686235458622, 10.889905768056071, 9.766632106996353, 9.375426673120069, 6.450530925104696, 9.58513129142023, 7.737071283401982, 5.846552598860956, 3.768461024568927, 1.628790812626962, 0.5651910494892829, 0.226068256362792, 0.068116569891572, 0.037031724988933534, 0.0932883038636177, 0.05396893691091288, 0.06620678930513321, 0.01914564997047907, 0.07248688699497331, 0.03932795479833599, 0.045087710248246315, 0.07267210407242661, 0.13275594330362736, 0.038583378622969317, 0.07774473228041204, 0.029796217981305335, 0.04735199802164589, 0.005187149255371263, 0.04393461768725707, 0.02169497033220626, 0.05643646781062407, 0.06472515227693705, 0.040714792276342074, 0.03539197890448474, 0.04702665963240209, 0.018041738339008826, 0.019073746873125918, 0.025904483665081284, 0.06175246299995531, 0.043246253213334473, 0.03963435549409159, 0.02607104075591891, 0.01996704178201335, 0.026962056553231615, 0.022135691138945764, 0.03166974537194737, 0.030042528655500184, 0.07166373318121319, 0.05732381213155966, 0.05478502739401114, 0.08208275877780492, 0.009744420061789213, 0.03286322225786505, 0.03479081438854337, 0.04788382391956064, 0.030858046487875046, 0.13985082146621522, 0.01140039093086436, 0.029975532351302046, 0.011301762856272681, 0.05168678396711907, 0.031782875490945675, 0.05359853722996289, 0.10745304741806562, 0.04003340686340967, 0.058207804817826524, 0.03999664996480269, 0.023679402356426564, 0.034271058205875664, 0.019602671213027452, 0.09561380206216728, 0.04452652786107314, 0.07207352893366929, 0.036292530581234925, 0.06429934528686347, 0.039166406007303346, 0.11379006544067977, 0.05122215164104297, 0.05128005256636008, 0.07645611110473834, 0.021442040658345627, 0.026793837051598296, 0.0744905210130157, 0.10403529936147314, 0.1778348703538218, 0.22696215839635944, 0.16530125822511413, 0.20586461790146368, 0.23239597407800539, 0.15549577712532014, 0.21072069603589275, 0.20061876955291919, 0.15166144577726243, 0.13339541221578277, 0.16597739210532558, 0.22593181610347765, 0.15098946409360056, 0.15459640522397336, 0.10017002572215374, 0.09946322534233333, 0.16979240271593296, 0.3609759721063799, 0.12154669801314032, 0.17676990088676253, 0.10994122438733617, 0.0965806509878847, 0.1473710010008466, 0.10330444382083032, 0.18646610720503717, 0.11433471565044696, 0.1526564560950764, 0.09244891664674205, 0.12764602193548796, 0.10385420383705248, 0.13795277734677638, 0.19178626608223687, 0.1030089024214014, 0.17837817990972152, 0.09115112539861472, 0.07944557004638257, 0.08117976328057629, 0.15168933137770624, 0.08105918870217378, 0.15918023103187162, 0.23091967668264146, 0.16192684010151895, 0.14218760413988946, 0.17558873120334842, 0.148512992947813, 0.2188103393681588, 0.16513417444882855, 0.22822591235801098, 0.17614339418228597, 0.11309896220242786, 0.1537946482459384, 0.12157416992610502, 0.10571126225254229, 0.13886716457143908, 0.1321003559015451, 0.12207719857894606, 0.10615754677283187, 0.16081645694230834, 0.1799850646526583, 0.12334168798500493, 0.2218712589913799, 0.12273260978080573, 0.13133318013241216, 0.1538781977949604, 0.20238333051243138, 0.09433089590240872, 0.1634034286102941, 0.18882636281271137, 0.13942435564052674, 0.19180659805574726, 0.16055125262468092, 0.22335465036092267, 0.32638915544075353, 0.2724543898817032, 0.16335608437657356, 0.11298035646999076, 0.14979766110979742, 0.10456799093874232, 0.3141211459953939, 0.2521571048325108, 0.20338471468177535, 0.6155488279557998, 1.8820547000054393, 2.811223254088433, 5.7633169620267815, 9.232630825811817, 9.695818616497903, 8.363762094128518, 10.12224595392904, 10.816515280354409, 11.638525416774135, 9.740759172747213, 7.425603712758711, 7.058482122036719, 5.878335074070962, 6.019429103020699, 3.828402685542261, 5.438162280667213, 5.00903292048362, 3.614541335451988, 2.3877435778417895, 0.8296977368093307, 0.32359183135051883, 0.15358245721267116, 0.18934022394880173, 0.22946663771665868, 0.2166254412863524, 0.21395288227546602, 0.16419087506590352, 0.16746937898137879, 0.19628415214678935, 0.08079242922606007, 0.12481227036445372, 0.1714731076912534, 0.22141958887298263, 0.19565404482906867, 0.18599842584902243, 0.14967357018782249, 0.16499290783559123, 0.12532891239970922, 0.2556569162275522, 0.15317977075615238, 0.13680258825902017, 0.14940948435856452, 0.13791704700598795, 0.09516974685773735, 0.12707862657524888, 0.11233930941671134, 0.08855771093118577, 0.1250264762089618, 0.11972677954021962, 0.16577247890733904, 0.18932127093355502, 0.11050640575347409, 0.0948543331375526, 0.07214824548892437, 0.0838205985905182, 0.14615324295816884, 0.18890795117664724, 0.24532035233513003, 0.19411172597639023, 0.18770382949902167, 0.16365280555140588, 0.12553045481082895, 0.10531773054671865, 0.23935217500453998, 0.18027000339521518, 0.11074626788256631, 0.2382548766270761, 0.09373294129487007, 0.11190790998479051, 0.10622780469636764, 0.18224313945299198, 0.15825056801399878, 0.1457962919507296, 0.20486980676651004, 0.1278976664968556, 0.19973586854194442, 0.19041821691057376, 0.12741140750867705, 0.10621288130360265, 0.19792986222572867, 0.1682714117510665, 0.11736909032709177, 0.11663952181416175, 0.1645204307691705, 0.11421609459625137, 0.32578897151735525, 0.18638969759546942, 0.2023099392892853, 0.13821068850736465, 0.15380465335422946, 0.14566081696219985, 0.17950428319313835, 0.1369289314794925, 0.1348429659922277], [0.033393052496737054, 0.022939771278611115, 0.08497255734137951, 0.07589360338545616, 0.0549303274601698, 0.009203412600101964, 0.04760328252168913, 0.036773656780320796, 0.033004982997813535, 0.06348920347649725, 0.04781562294210157, 0.050761660020197594, 0.04375267180524046, 0.0378726750251747, 0.066669108045678, 0.0310201698448509, 0.027519379772486228, 0.031518352991570874, 0.009929582555477899, 0.044718325633796, 0.031495238203675516, 0.03354149352338526, 0.0200968592112223, 0.06730137573134515, 0.03929255387535499, 0.06900460369163944, 0.027485468890517954, 0.028682238039290233, 0.04874523999469896, 0.03334580402400705, 0.02857005020843879, 0.04216605774878014, 0.06750061987869202, 0.028168330937924407, 0.051429807433798436, 0.011442080478093797, 0.014749115423089074, 0.025662666096562342, 0.047733544281894164, 0.0532493275409985, 0.0689757451595318, 0.026144276846260316, 0.01686798630192155, 0.004133194217443346, 0.037713960759461894, 0.12133760963596645, 0.06557666666565404, 0.10727873943265408, 0.10347853730162306, 0.057315710751760396, 0.04421743436626369, 0.016411422796907927, 0.02963840578412337, 0.039752444117179805, 0.09149464688474133, 0.022480677768227555, 0.021035927873585495, 0.03948472320072113, 0.03415000099208086, 0.025238345317061872, 0.033189054773820025, 0.07440554654045452, 0.045811567575700825, 0.022303617611948042, 0.05766076824417519, 0.013982303545720155, 0.009284835297524208, 0.016227896858547485, 0.030729473951543053, 0.06474079579235086, 0.03291056649158559, 0.050451555289328105, 0.08619908709079029, 0.034538227539028854, 0.05602887456095027, 0.0179519432581841, 0.039968140002700596, 0.06231966683821333, 0.009926936679309415, 0.04589628157836776, 0.07791575374862841, 0.06138816137888259, 0.060199085668089895, 0.028396240180178035, 0.08802059902659348, 0.04649656892363583, 0.022348236487877947, 0.07229223171429289, 0.07846117004631989, 0.07363926709419297, 0.023628363663691188, 0.10815617823672873, 0.07515658083702288, 0.11812588560485071, 0.04024431086896409, 0.10184266379163151, 0.04303665155725133, 0.15297786062282903, 0.020673782790019628, 0.12343390198845057, 0.02238907855034115, 0.0247139600481117, 0.0719818052264952, 0.11669052794816033, 0.03614033955419737, 0.07582693841428527, 0.0740818897142045, 0.016197006278220686, 0.01223054295781279, 0.031718169789641135, 0.07257518628912588, 0.014506686899450519, 0.030352416966531067, 0.02754434849315834, 0.032938888762146235, 0.07413659605287737, 0.03765833894571951, 0.04466150489245211, 0.015784649876877666, 0.08480257775274017, 0.029616788698119983, 0.06289399529416716, 0.07113471882598055, 0.03428136208845723, 0.041635066886702855, 0.046162926141292825, 0.0019757480584948715, 0.010919626708322716, 0.03457814071988387, 0.10578189555916095, 0.019134675760963754, 0.03930136771692384, 0.03501302585186016, 0.05078043683522171, 0.06933856440047104, 0.032361633850321654, 0.023233882008841442, 0.05271754377791959, 0.012451094883163611, 0.07930397401533781, 0.02568565639517, 0.016380716077682954, 0.11127895945983549, 0.07052521161254376, 0.049225768645203886, 0.044658693349770004, 0.06874707557501332, 0.033321982520001556, 0.07991345824613687, 0.015592778368192095, 0.02159590750271755, 0.056399519390036026, 0.027223811559979955, 0.01612921898824073, 0.02944489005923031, 0.06857490497491053, 0.028817352966495582, 0.060960768586805755, 0.04884437560254047, 0.012073017085992522, 0.031670856199437575, 0.005796662693272435, 0.028848124803194118, 0.07212881749916462, 0.025429417221476475, 0.05405660418252792, 0.030188776755465135, 0.06193826230423105, 0.05666350945830346, 0.06318845650962283, 0.05378936973190116, 0.01666635387547074, 0.018275573271356763, 0.06165594358237521, 0.041948871822246624, 0.01086207531062105, 0.035887656943692316, 0.049112215262627414, 0.05351522133775777, 0.05325339929831605, 0.04305248659464621, 0.0851601722740358, 0.05338795498133667, 0.04607733879839221, 0.05878434726788152, 0.04221265121633488, 0.009549344390360339, 0.041201189160346985, 0.12438175959452508, 0.055818514477822094, 0.074874829020231, 0.0452004247645457, 0.023337097034879753, 0.012376757541431055, 0.017232155772827325, 0.03282592526727146, 0.04121875938689036, 0.023149845993987495, 0.03127295779244554, 0.059186252314717545, 0.13792737387120724, 0.03613942407912785, 0.009176935643828925, 0.013879763634665119, 0.08311356838432052, 0.025498407269497553, 0.06785102083437866, 0.0476376032606969, 0.05271102053924434, 0.007994465047358386, 0.013786662884447125, 0.01489543917423655, 0.030032619308199615, 0.04529550776726777, 0.08261324402185218, 0.0926306327023814, 0.03954943847812472, 0.008927185234854059, 0.01349122299166817, 0.06039700448332776, 0.028251778980296467, 0.01401089873510383, 0.025630369744894486, 0.11113827507342063, 0.04974406159993622, 0.015421193825351375, 0.041203020110486016, 0.05915311901199241, 0.031160913603079897, 0.04325499427655051, 0.054267446901048386, 0.009370296235917317, 0.010764339728461159, 0.01342455035961804, 0.02595027465553534, 0.029576528862479235, 0.03778334534276397, 0.04982442422319324, 0.10942659716332152, 0.029898312603754383, 0.013294149745976733, 0.03445383912372974, 0.08809344632731331, 0.031674767078291026, 0.040229873942031015, 0.02117377198902109, 0.030484986566607992, 0.05962548882610375, 0.08207607083022594, 0.03837014954056471, 0.0673748895285591, 0.08375314454878531, 0.0392243490674563, 0.08255272307583401, 0.034767529146084865, 0.03628182833293273, 0.02465327439318982, 0.10860005724093608, 0.05022596154782561, 0.012286301709771639, 0.03846529383032072, 0.027138028864658652, 0.06374317311471508, 0.14956192053373785, 0.016855962551949967, 0.06661806360728319, 0.07390466293380146, 0.2939506638194284, 0.09904656544207566, 0.048700488968602115, 0.05224444234984056, 0.057242836637963215, 0.08479254966181132, 0.04946795585114629, 0.15154299326241016, 0.12389088109616311, 0.021820624073546742, 0.01672516261497813, 0.011635079093637967, 0.046395318913123304, 0.03084626405559961, 0.06451807105012479, 0.044392634844107014, 0.06442160525869939, 0.021970336806149255, 0.04030257951648485, 0.10683310608710013, 0.01940295017594772, 0.022348041135457256, 0.04840149251263469, 0.04111526473875969, 0.07169072245878559, 0.09437103124876177, 0.047150015109969724, 0.030402337170896993, 0.046209082938730724, 0.02474578525570612, 0.01750500756315887, 0.09106111006751176, 0.018006929218949332, 0.04554207316569744, 0.012253418343231804, 0.031388395751315745, 0.020017138186601863, 0.08755032063251542, 0.028715513068281358, 0.05431880160505253, 0.06731891914481117, 0.016619982573414044, 0.011200579878453527, 0.12222188194432568, 0.018858999021411426, 0.020039159383985306, 0.01740946490768223, 0.05112537175356861, 0.062292558817012664, 0.034411076095796404, 0.030467732351333387, 0.0417970102130165, 0.02024653746986822, 0.07234970363037241, 0.052901826228105256, 0.04957645688386214, 0.016227134601062825, 0.06439457767673078, 0.023546767638876073, 0.03872371060893901, 0.030725451989940582, 0.03132936676153012, 0.014032718834407149, 0.02230366740766312, 0.02183706240518199, 0.0194643521230788, 0.028960678441029404, 0.057152323349709475, 0.041092278270591656, 0.03873906684138122, 0.02217250357892725, 0.028009053597587253, 0.0700680333219709, 0.10581230158887564, 0.06884116649387345, 0.006707157712474827, 0.04656459753131194, 0.07764743145314917, 0.06855686360429372, 0.024516198280898314, 0.08848049692929753, 0.021254544469317602, 0.014544854357448078, 0.05027926211515742, 0.03447134806323917, 0.12206499479831227, 0.13960417179811385, 0.2620378617317446, 0.10709764390823343, 0.18734746071840488, 0.114491717709649, 0.08568490419777171, 0.1476193973494153, 0.17107592174603095, 0.16259643159085707, 0.19796234435371815, 0.128534201292261, 0.1762174595628054, 0.1857084156044068, 0.12044269636633897, 0.15692592538412542, 0.07555938986760956, 0.13907120442919194, 0.1033173983676299, 0.1641177749561687, 0.12469941795232797, 0.1642634235923329, 0.1429721547831451, 0.23158470228795083, 0.2464174821732506, 0.16246527733822025, 0.12050472650556796, 0.08918555828952983, 0.23420355853534516, 0.159954424166391, 0.07393071758410624, 0.1532910220445164, 0.3099854663014412, 0.08483330553938305, 0.10111165503340383, 0.05734879808921007, 0.13875643422286357, 0.07074332450546565, 0.18197919151956038, 0.16930843433064802, 0.19709649645993788, 0.10627712543693282, 0.11267057349604946, 0.14041293081977677, 0.10941525140116293, 0.229751116806461, 0.10987242203085654, 0.24592235954778813, 0.21391473109683684, 0.1221688916426032, 0.06450759862819988, 0.13043699515683035, 0.11305993768356501, 0.11177006778457474, 0.1638469935184525, 0.07857894840379877, 0.10108453552088431, 0.1256924134589011, 0.10295038096486561, 0.12258891466884844, 0.18592901828308261, 0.14917316155568247, 0.16982820966551382, 0.12004884290358714, 0.12474661662934289, 0.08631968465183051, 0.12350379218978268, 0.05918146426519079, 0.07360293154394434, 0.1474096424757473, 0.12647969137516715, 0.13590634199640445, 0.2386862760589969, 0.1753203552817145, 0.16966048237537185, 0.17543559022728475, 0.10401204093209199, 0.19068354380226907, 0.11437869675817991, 0.13285734270128513, 0.18226806795404804, 0.18646707247582175, 0.24359368208435275, 0.14509395786350773, 0.29331193035168035, 0.19106899328049154, 0.09626499978044341, 0.29366341149134023, 0.17167653467866684, 0.21572795396129932, 0.16971179494454017, 0.26256747363555816, 0.2510552405710182, 0.20310562885095998, 0.15316225798620334, 0.26991563578767164, 0.28042237845159346, 0.17791786831953835, 0.1985652402283684, 0.22971178585242844, 0.11563015500864676, 0.10966583110031583, 0.13904768552991653, 0.22274803129896042, 0.16307108434698275, 0.20419094561328813, 0.21145073186245658, 0.1794916887076632, 0.1685028622347501, 0.12350007666334992, 0.18651363529985954, 0.17586879762670687, 0.0933177293007893, 0.096788743450757, 0.084676050671166, 0.25218514365053946, 0.18606994781763325, 0.10671364233618784, 0.16225608936961622, 0.25708105835703116, 0.15908480712002324, 0.1350013776532104, 0.30520201330223395, 0.13631399270267258, 0.11687563011242498, 0.14093926386727443, 0.1292653709289528, 0.12544605490421096, 0.183798635017968, 0.2948420530846042, 0.11924819675304237, 0.17269265837967399, 0.08783431708692543, 0.13902864058411893, 0.2115270648632319, 0.16894382244396597, 0.12530310289754024, 0.1409398154505799, 0.11985857730671284, 0.15990635981002163, 0.125290316890084, 0.08760613013779925, 0.19998135375640086, 0.2295215355773126, 0.16624975168416578, 0.16922319938819255, 0.1776369285559462, 0.11839055366093114, 0.14991962230734288, 0.06371003981198996, 0.0951585696349221, 0.11810973647140688, 0.11120284096367898, 0.11556950382768147, 0.1543906340075116, 0.1932995042373096, 0.11637592628117531, 0.19852025554545466, 0.11111515453986584, 0.13229846623876404, 0.12046686644035003, 0.11397037189453842, 0.16636117151187313, 0.1443330640153539, 0.1806841505270812, 0.21844942002527176, 0.11391090048897652, 0.14053061724670474, 0.12009337559462556, 0.1689009674854817, 0.10706451060550828, 0.18307702615857127, 0.07274772461143232, 0.2357912144713825, 0.14224542845641414, 0.18348460025604696], [0.026343936596306104, 0.023751613804169243, 0.00937257151705243, 0.06327032449565108, 0.07354971141584458, 0.04488695690768861, 0.005436134055226801, 0.08475831319247523, 0.06887410061373826, 0.035864046113866, 0.0030532022449939003, 0.08978461606367942, 0.05416454597105903, 0.011968903821862996, 0.01632348547929958, 0.10409023552652329, 0.050336021569467364, 0.03684417134331119, 0.03000094348775043, 0.02576795722087545, 0.011949369537403748, 0.051662004853208224, 0.0008091305144555537, 0.024325325559344024, 0.038201598705904144, 0.07114697623276903, 0.05272593244069046, 0.004606206587801177, 0.08471476875485913, 0.019901723210369388, 0.031039525056257847, 0.02752129116185731, 0.0275369499990296, 0.023362885469630845, 0.013318307371059013, 0.042635842016147035, 0.0783242931168887, 0.024119096605347532, 0.03236456796707165, 0.017574581753222213, 0.03317684716274662, 0.09896968085799487, 0.059115676464693206, 0.08274670419914108, 0.08016439034573494, 0.016613398047704852, 0.04606115136055216, 0.019676997063441143, 0.010679822993434725, 0.036828558471414356, 0.07683800593499215, 0.01654347720285577, 0.03388382374278961, 0.07581933116119716, 0.014145207354768872, 0.04689559347987656, 0.05867436002459257, 0.020376697723423282, 0.04099264087515973, 0.004048308323798401, 0.04082429688423872, 0.032649269222372004, 0.05963170179916967, 0.03739591169681761, 0.04484852227652746, 0.04317899835446189, 0.039626315401326266, 0.03680851378087555, 0.06095269018964422, 0.06056373585916816, 0.05628145758002516, 0.045480157939657095, 0.029195758266254302, 0.05963625619187952, 0.06044346388549574, 0.03662383296496926, 0.0836910761051601, 0.05876463199515016, 0.023300753823751887, 0.04278923197078609, 0.02118902863003314, 0.07306971902688665, 0.04450762081110189, 0.06054646440691525, 0.04014537444398288, 0.011185326110271197, 0.0035978742403864504, 0.03156540228144056, 0.0721355973772945, 0.07574253084678804, 0.026469536711491888, 0.0796172273675761, 0.02871265172988417, 0.04376651118359259, 0.06073127162732905, 0.03773195999524286, 0.08219246256856189, 0.018253852763483604, 0.03888887150453464, 0.05111869529730851, 0.044792314405523004, 0.02087031498611454, 0.03728861725258251, 0.044640510252887206, 0.03902013300948086, 0.12471466310202114, 0.03594727390595982, 0.02069727104577807, 0.03888665751043347, 0.07984722994508282, 0.07893832790995799, 0.033386015979152535, 0.010700008452629611, 0.07848068230575131, 0.05112380127332384, 0.019654410876213543, 0.0894633187882362, 0.037994620900961666, 0.04103463781516879, 0.047577913520076585, 0.041835582740004026, 0.05547965846715435, 0.035699157179483486, 0.05797855683692521, 0.025039804055385535, 0.010418551579688587, 0.024425874599405838, 0.061926499024153724, 0.007447631487006983, 0.07476849601634088, 0.057024903775703524, 0.01270836444511529, 0.034132235413116795, 0.06747342375738007, 0.023817365215490424, 0.0367418909445405, 0.03467556795165424, 0.015158954267990927, 0.051073798714506055, 0.06509587754525485, 0.04046748377262585, 0.05407940678959412, 0.053873106972464634, 0.086484462503464, 0.03854941794528596, 0.10252361636488669, 0.06536750934056698, 0.03310425650148142, 0.007736756900070056, 0.04280261935726289, 0.03497606210951363, 0.04168372113077391, 0.04356401116256753, 0.10291720935774427, 0.041895444850407304, 0.06981334739154385, 0.0634948840184558, 0.025831283963916284, 0.07514036275566587, 0.03427994482579731, 0.055565111744668216, 0.022530247487368125, 0.018844328437661453, 0.07082405485092633, 0.08318661486790066, 0.0791007462107847, 0.033646784647698366, 0.018429332863419287, 0.008793352547311976, 0.04651077219375199, 0.0536261010734785, 0.05455827685974298, 0.031469982200031804, 0.05012345132267764, 0.02628621378643138, 0.03267304476110205, 0.015835964361265782, 0.028046124592243184, 0.05277899935120537, 0.04952918159805479, 0.026378439281195886, 0.04847925426738878, 0.021666877888022892, 0.07374345505189511, 0.07504027336835861, 0.06508069368259561, 0.07878745455415019, 0.04165308144424231, 0.021122036156274622, 0.045650574198413285, 0.019098401497749072, 0.09872044947358871, 0.035989879885868686, 0.042203393043769945, 0.08873646222655812, 0.0323592972821526, 0.04628683703260557, 0.030889762527940255, 0.034511039078596144, 0.03722615810411592, 0.010104345405594477, 0.028917490234298092, 0.023971505936295278, 0.03479891959878226, 0.02931083616380009, 0.09118838791525172, 0.058520966239513895, 0.05099053644845563, 0.023523013167563948, 0.062253993950904384, 0.09577792107818589, 0.04517423604885417, 0.04029617502143787, 0.03941165756494288, 0.044204525784739566, 0.013570820484610816, 0.08817589270972437, 0.05522371232209187, 0.025602265809392257, 0.017237872703962268, 0.06182883047468721, 0.04457263486279596, 0.0382789084687829, 0.029437014675368706, 0.018198066240837498, 0.023289984542756312, 0.06345051220588147, 0.0733613457170225, 0.023348473440555316, 0.06321321647133558, 0.00765457529679782, 0.04014385375945319, 0.024377992188918497, 0.08914790506805144, 0.07725835837904485, 0.057131780702019894, 0.014186582805949354, 0.02887432117976489, 0.012927270239038814, 0.004705531802403951, 0.03331342531788734, 0.014570357424447374, 0.06340950734973436, 0.028900764619691238, 0.045105035326653914, 0.005455307320751731, 0.03226500718043216, 0.06828042077681712, 0.018788697047820015, 0.0979752604278826, 0.013710667919968406, 0.06815768583046813, 0.037477844800319404, 0.00691211783334673, 0.036723049012042826, 0.05150034114898694, 0.01505167131507469, 0.019493101487657236, 0.06345969376965396, 0.039836844023797786, 0.019331372665962385, 0.03451884551454456, 0.05021271205717518, 0.007310715295569672, 0.07130615398167603, 0.0069812654081972386, 0.03805575471731924, 0.09458020389560731, 0.016774579116533843, 0.03287352997088625, 0.043990875353976604, 0.031055266247882, 0.026843588716620882, 0.04324977721778616, 0.04300374425046387, 0.020565726088299867, 0.005168572580817366, 0.005735960758982167, 0.042926989901330204, 0.01342685532666022, 0.0491311299734779, 0.10132975260456724, 0.008012933511992977, 0.026485046161518946, 0.025096159398315415, 0.057463776395325704, 0.009627730506772717, 0.02474663369808226, 0.060189796852007996, 0.024308873821170102, 0.050232833356506405, 0.03917539604909478, 0.03090143770790629, 0.0826631623109983, 0.012446354714132125, 0.06038180529891003, 0.0141892037842603, 0.010266824035845216, 0.014154536390466797, 0.10480197717345531, 0.010194218052821535, 0.022732791558448828, 0.034050451696760235, 0.06289258569238648, 0.03476467929900654, 0.030041323982239253, 0.05426000818730362, 0.02221640041698852, 0.028865606929626197, 0.07421309759299602, 0.031931111589074135, 0.011501955037425843, 0.10831978397383805, 0.02711398902559473, 0.09954860584149439, 0.06812100554065359, 0.04512535963928507, 0.07814482935974676, 0.035076595827816956, 0.08585568817873156, 0.04963177226243481, 0.13141600955878535, 0.01563829548221322, 0.022111685773838433, 0.050052929098808, 0.02645288962089727, 0.0373575919788451, 0.02385185257862172, 0.034362237990623525, 0.06616717489856867, 0.026169678406609644, 0.03825078921152219, 0.05432028398518601, 0.06463842346302925, 0.05747357465987725, 0.04880343969430655, 0.08695844110221633, 0.09569089348998763, 0.04288100164323565, 0.08990307623941092, 0.06634904417179285, 0.07166767853402323, 0.03408065088273537, 0.03662347290364485, 0.04685117570202678, 0.020959608279348865, 0.02701777029752491, 0.0668189625045465, 0.011498590953828347, 0.04427983605813596, 0.03486003043250211, 0.07120700688251565, 0.058829014024306694, 0.11548469023358439, 0.1542664051897103, 0.10813263635481558, 0.21128297392879763, 0.11263326501413701, 0.14143769599256978, 0.2379671646462333, 0.21765906243555008, 0.14700577624382513, 0.2618225603815048, 0.18893551502016284, 0.13027892057453433, 0.1917260822149054, 0.17790150468147573, 0.21145675331354144, 0.19469646556723505, 0.13532658197706746, 0.2057827384241166, 0.0951522187660298, 0.11897386832823677, 0.13819460066095476, 0.16339003739337768, 0.10713534309498726, 0.15220614961318432, 0.20887468460827105, 0.1404751678027453, 0.09438174881882246, 0.16560337265893338, 0.2125465287075889, 0.1634885103351647, 0.10931902309699405, 0.09170943495607184, 0.12243925173196102, 0.18197067262184236, 0.17191042132194967, 0.23574302754094525, 0.2149200836016286, 0.09217664899845278, 0.12543022752769534, 0.26627506339742296, 0.3077658950801819, 0.20322391282646887, 0.15459202320104645, 0.13140056522623186, 0.14586759941472163, 0.16568227971513427, 0.22447571278579775, 0.13030268462194552, 0.12204539060832993, 0.20968750389593266, 0.1661365545324741, 0.14415346236238558, 0.1270310065498756, 0.14729469864358827, 0.10833872166732628, 0.18512024393966123, 0.13114395641511487, 0.10165018420065604, 0.09313838811771524, 0.13708584160814363, 0.15101436195113968, 0.10976548381750623, 0.16152850502441007, 0.12467070497692594, 0.1658084237527463, 0.18560378331570856, 0.15209422416744695, 0.1857782828231012, 0.12642174448457458, 0.11076061670938808, 0.17705248007851263, 0.2107870852154109, 0.34047837038674666, 0.1108802106952475, 0.19026994825370852, 0.20161388712304257, 0.0993060470829087, 0.07065740008387836, 0.09088882455422033, 0.1413584671794407, 0.24271297208484144, 0.1421842333530226, 0.16165003721271792, 0.0775844743475318, 0.09078727959985695, 0.1275442854591435, 0.12199745648690771, 0.12419030656136813, 0.19751887137611068, 0.11880804093614702, 0.2399014447244906, 0.2536909201092297, 0.17150896060610973, 0.15521233991509484, 0.09666461422438584, 0.17401727036603037, 0.11068789964361538, 0.19004599010992437, 0.08245527669186554, 0.0944641722185958, 0.14558797732235926, 0.17122803616427607, 0.17034916477578302, 0.130419283204021, 0.2628026626283123, 0.10138181593990135, 0.15008246195652794, 0.113249467836032, 0.16863917991999658, 0.2033617933310809, 0.1288204117407722, 0.0900717381568205, 0.17082579403875336, 0.12310482892057589, 0.09869923649896538, 0.17029668775296983, 0.15272293720514546, 0.13846263950390203, 0.2341738036803661, 0.13082117292909853, 0.1252225947175776, 0.0887052977697984, 0.15502546042684587, 0.06893098264211608, 0.12959569272014404, 0.12199862860143186, 0.1479454137264721, 0.12760124409631377, 0.11479730252176525, 0.12029671831236732, 0.12458397616301814, 0.10766145397698688, 0.1522485295971555, 0.17796518190974192, 0.0729393998100873, 0.1671649509620282, 0.12649565664750914, 0.20565716129156852, 0.12904988571761117, 0.12004128161577449, 0.17278224470153933, 0.1896437020191262, 0.12358078402617287, 0.12818715580168272, 0.2551286373167269, 0.1798937163285671, 0.08958017784020594, 0.1854496004600679, 0.15851519010480375, 0.14484458092239597, 0.08903686828430622, 0.11989154973097386, 0.19068815565157324, 0.17496798548006243, 0.12410954557239048, 0.11701169498865643, 0.1652006862024146, 0.19955793696065105, 0.06350789985228932, 0.33489671505747304, 0.12273209650189647, 0.13130953865906886, 0.22810362940353734, 0.2076970542510671, 0.23616169459156452, 0.12208848305407072, 0.10454478613551586, 0.1603629482128928, 0.09898894030841128, 0.18342999350880423, 0.1804987725711638, 0.15401137451971733, 0.18790117374831633, 0.13971396751942175, 0.1644936176918207], [0.03501134428886637, 0.05161623493017209, 0.04747482106810616, 0.028696764981554403, 0.02355628628133526, 0.03368387096411279, 0.023464587472018697, 0.08383038919419052, 0.06249395567142676, 0.004623364563280296, 0.009719865028596213, 0.033397001679986715, 0.10255701779838532, 0.02026219630704051, 0.027479462761191592, 0.02682949269881412, 0.03370893736099524, 0.08641448803246023, 0.07748688240685771, 0.014702904041886572, 0.07105353648864454, 0.04707406515315656, 0.061657211457889896, 0.10228204585972334, 0.06190571122832837, 0.019595475732198647, 0.07143678729452434, 0.02935182569818872, 0.013194858047720647, 0.03494716527300977, 0.03875947542368405, 0.053369645479946375, 0.09616566115930196, 0.04285787344880162, 0.0030945707535025694, 0.008749967072940162, 0.04328099530070059, 0.029660329305296464, 0.07486611093965269, 0.08409452098872393, 0.024363057304834648, 0.014609990025600119, 0.03071544879686929, 0.025408083588005077, 0.04397764118508466, 0.02246268236288621, 0.007561005796531156, 0.012876187496247792, 0.024388690606781074, 0.01553818885792768, 0.08266323891979072, 0.09265490236782259, 0.026222772130201903, 0.06279358031949209, 0.05157511899127595, 0.018666276197519996, 0.033954480032046, 0.09044019580488244, 0.06538453181424449, 0.042229604742099205, 0.058748436896430875, 0.06506784638810544, 0.06709918214548981, 0.019291302437082897, 0.043679962400347, 0.07224719340522444, 0.03173380181373608, 0.029695732143497276, 0.0580636921879505, 0.027928729278726444, 0.024416388515683434, 0.08082293484720492, 0.03434653318817577, 0.00970423108928146, 0.06916030340137021, 0.15482221730053425, 0.057524324154421214, 0.027429703435289766, 0.020087208418596177, 0.06987126363861947, 0.06217384583226616, 0.025920854964023157, 0.01847049668281069, 0.00713362162294347, 0.052216024318289374, 0.026912737727886247, 0.036316405711395126, 0.057477171442681746, 0.062304180370824, 0.028754778904840354, 0.08641670202656139, 0.04008126437603947, 0.0707419378863227, 0.03866233547488528, 0.04287683795536718, 0.024119956539042538, 0.051619896830450145, 0.049076220621505094, 0.08732468475617709, 0.050179812411266955, 0.08933968751901582, 0.0762325666484333, 0.034727573830394015, 0.08856180184070142, 0.11160800954507244, 0.020544470978840705, 0.03457372039256077, 0.03821347689917011, 0.0401647066727521, 0.060184384440822955, 0.04536110021534466, 0.05171124132410173, 0.06612555334164251, 0.019441202861226855, 0.08217853509009847, 0.022075059110178583, 0.026860741425245523, 0.06394863023512787, 0.05546836250071084, 0.03396972135129956, 0.048388151091433344, 0.025912625264496576, 0.08221085633962386, 0.02815960519646685, 0.028111104169980656, 0.06736883743395729, 0.05208353324222469, 0.018159104924228404, 0.06787783391172848, 0.055374585677899664, 0.032810392834606676, 0.022502892402811878, 0.028413994267823237, 0.02123491921191735, 0.02102712552333551, 0.05690533277248183, 0.017136027060088613, 0.1328549065416859, 0.0045919616616541346, 0.008458840255174906, 0.10941933464979935, 0.07411743619389112, 0.021098856250905705, 0.049154851886053244, 0.018207364633018454, 0.06800401625373671, 0.06558327034356133, 0.025401715482134494, 0.05442557893993874, 0.04151433526027588, 0.03628585412497482, 0.1078447251911125, 0.09237361020378529, 0.03774753073230386, 0.06608723362367, 0.00667129043346992, 0.010532330000592817, 0.007258080267122076, 0.023902939151852362, 0.02468650920256492, 0.06791102850148756, 0.017711077553911075, 0.020690979548699914, 0.01266883813866204, 0.006550671326206818, 0.017129256758057786, 0.07331171854128761, 0.014924648191569554, 0.025254076932586973, 0.017718094919297486, 0.04342750961621923, 0.06684237415151251, 0.028152848300974698, 0.04554948889680448, 0.031225981280928662, 0.031958752041382175, 0.05648268589509591, 0.03766378966130076, 0.025045712508501548, 0.011710043669858528, 0.020090510257549828, 0.04655417107466248, 0.030735976122800383, 0.02906571484110769, 0.058001654387842265, 0.014096783894685008, 0.03793351389768143, 0.05448560192880612, 0.011706313779277187, 0.016272768543492404, 0.030162735511699033, 0.048887498691798224, 0.0035089039010927085, 0.11287715676571093, 0.045683236357064984, 0.07141349056074697, 0.01510049314087918, 0.015518248546868564, 0.041219479509539185, 0.011291645707622653, 0.014502545236609878, 0.06049610561721268, 0.015008773264144699, 0.1102524629283336, 0.02100016114362065, 0.07949918087932371, 0.040458535865670255, 0.03665236974014871, 0.05228103836998344, 0.039183876642416564, 0.05600991005438471, 0.04872708754133313, 0.055573255259303324, 0.0779213002252002, 0.01805049089354373, 0.02415552408614707, 0.04369909161581628, 0.018661120425789587, 0.017051046841867992, 0.037878803728568944, 0.028627642783366387, 0.030586814973503355, 0.06678282613715818, 0.039332087842687484, 0.0552144464886477, 0.017252466678919814, 0.02037057859612809, 0.03999232539847013, 0.034024496637885614, 0.0249989026211082, 0.046190252497551904, 0.02777982668410386, 0.06168832994937416, 0.05024473070197048, 0.03657081201972981, 0.039430338618976456, 0.029902460969864365, 0.10068027858412075, 0.043677817354159015, 0.042515386181372794, 0.003570058306063255, 0.10465239084536031, 0.019877723590921492, 0.004811432445421815, 0.07686976794033282, 0.029414095239894047, 0.05701810857581516, 0.017346239671291366, 0.03608017100862438, 0.05043373608420934, 0.11221198560369593, 0.09858835293280502, 0.058845622810505094, 0.0933103901784747, 0.036049286173957015, 0.08089346856239342, 0.04203997116776244, 0.031649783035860427, 0.0633356181694375, 0.11500324227757032, 0.02382188704946349, 0.11927084997296335, 0.052201901487405264, 0.09102127349544918, 0.04385579490072785, 0.008779782257343252, 0.02073553905281569, 0.00799704293322359, 0.028849486524479526, 0.05378625175404934, 0.05989528967127685, 0.008300040762180523, 0.041063546142991514, 0.10117925463184234, 0.07895030186421449, 0.03239551791921258, 0.01206388914837472, 0.0629961071535945, 0.04287576926271281, 0.045630659742821614, 0.06762799731786213, 0.007263367231409516, 0.016379379254255085, 0.036332302035823945, 0.05323829204444924, 0.0775650540186513, 0.021617995732794368, 0.04877738504400177, 0.04533308821039335, 0.028254540727263498, 0.022717659406724478, 0.008528116628557684, 0.011768418612078795, 0.037301292177289724, 0.03376336407757575, 0.08366894382502764, 0.024335181280489893, 0.03695092952599929, 0.08850665883191171, 0.03767511627126125, 0.08629585931738538, 0.06633169994118714, 0.10318715575962298, 0.09417947862417468, 0.027954883520461382, 0.02170664359695248, 0.04271752997151306, 0.08317240393690525, 0.02401027381570349, 0.08072220960692053, 0.05038071896940951, 0.011168745094760051, 0.04943978296773088, 0.04382423590868712, 0.04474645638237557, 0.014528157471138385, 0.11370565787318254, 0.057374959991824244, 0.043252611743106, 0.018077238853419983, 0.031454175890934084, 0.06669942214484177, 0.05158553012616692, 0.01681005473308746, 0.062373603258522294, 0.04885801579803229, 0.03544351363915109, 0.08774522106133162, 0.07252520671294582, 0.049643497238115925, 0.03398508907506063, 0.013181819231249394, 0.07203504067635344, 0.018934437614535133, 0.01816382211062216, 0.01570554842586599, 0.029102956290326776, 0.030973804288453637, 0.04626371649905078, 0.013451745523320091, 0.09006684285498436, 0.014761395812515291, 0.03652571625406704, 0.0601570810672016, 0.024872339150357633, 0.018289142603715582, 0.03251860526600673, 0.017196961693585883, 0.04503226463472651, 0.042177572050282074, 0.056013039523555394, 0.019903837613040404, 0.18922433016761658, 0.20543144114555853, 0.0988483784960643, 0.06815188654488133, 0.09851870787960869, 0.15718893869028938, 0.15985999616884417, 0.16094051722076633, 0.1279035883565103, 0.13841509608732117, 0.10726570061618283, 0.16437772391063554, 0.18275844083437998, 0.10732638244066509, 0.141172353779116, 0.13030443130241287, 0.21035701877647833, 0.17295803123664472, 0.22790833826987977, 0.12467576881810544, 0.16964727501955726, 0.1622204203158617, 0.18913394711430997, 0.1903404283427423, 0.09341581919861418, 0.13244411487492824, 0.1173468124902537, 0.2735788230934451, 0.11644158001628616, 0.16518239202278276, 0.1452229364264396, 0.11451436326869073, 0.12666870824872487, 0.08025193121284246, 0.12887907875401358, 0.12283138149688322, 0.24021209337778632, 0.13131477870047092, 0.1287322350206875, 0.2771660451206469, 0.32453813379810703, 0.07548399149410187, 0.10671630832216433, 0.12176966024262291, 0.14077706773194576, 0.09570556407373759, 0.14952566925316088, 0.14650524503761722, 0.12983440571734983, 0.13835834429389046, 0.18115563167920037, 0.1513205366509576, 0.07457887393332298, 0.13295508019866484, 0.12002851093007673, 0.12912850166040082, 0.16884812274046485, 0.2775382106342624, 0.16216532327234745, 0.12091611572090658, 0.14408448380568337, 0.21498156981843136, 0.20640149231879942, 0.16366255018980275, 0.13861870693583644, 0.15886653334863726, 0.1809076490181108, 0.22203558485113808, 0.21131643664933022, 0.14766254342131077, 0.1611732700539212, 0.24627089890981876, 0.11737311228869424, 0.17743120330475992, 0.2064461399230265, 0.21630120223327992, 0.13512697010751695, 0.158862013429884, 0.21380357173902376, 0.10486302672014122, 0.14239605666408617, 0.16488257585273636, 0.10458155069500209, 0.21148793309205965, 0.1065854375220595, 0.17852307777971993, 0.165856656648459, 0.2744747782426496, 0.22989357851686018, 0.16463851556181908, 0.1564768446429122, 0.11873355420726923, 0.23355474335051354, 0.12032836540451936, 0.10557963302539242, 0.11706982574035084, 0.17482422142019197, 0.14974628725359518, 0.21053816792705368, 0.20676975078400106, 0.1589331370327742, 0.34200147575428413, 0.19664307966107325, 0.22508455350274043, 0.16811482337934358, 0.16695505819253384, 0.1585992605936143, 0.11628640890722314, 0.1505795151235596, 0.22171857766807082, 0.13950801244185818, 0.1875595291776042, 0.22278995163017706, 0.15657303464268485, 0.14729226248398905, 0.0972232531996504, 0.1405829104084161, 0.15870525651881773, 0.14625257391843105, 0.16201412815961147, 0.12982993176387203, 0.11377093622521048, 0.26093052760247265, 0.18598558621541147, 0.1429905562150863, 0.14737794175744057, 0.2037179322853204, 0.1406386356440283, 0.21754264771457643, 0.12758877218490647, 0.17763372630842272, 0.23339873720561308, 0.07148330415328664, 0.1954350969003093, 0.127972865687503, 0.21900360802969626, 0.12434203793565113, 0.22168332230179544, 0.10057477295518884, 0.08526065236618442, 0.2558025035766825, 0.19626149126598913, 0.09757903209256549, 0.10028637915609345, 0.11412116864155378, 0.15985711567824887, 0.2062417170213115, 0.14036045379696355, 0.1618091383528325, 0.14260604136413144, 0.10869329780220024, 0.16300069618849986, 0.1944173337711442, 0.10303535543742681, 0.1347320211390334, 0.09243233084318139, 0.1065088746949069, 0.11046231739343175, 0.12606764332421366, 0.10719116792202958, 0.22758330248536604, 0.132840963741464, 0.16348406702520388, 0.09524945064537949, 0.15199124662866517, 0.13043829750630165, 0.1340715614177527, 0.18555458514921128, 0.08634087464381611, 0.19064263470711248, 0.12868994696726724, 0.2129076778768532, 0.10977335154048859, 0.11742373537873069, 0.24519411636696709, 0.09572895273806588], [0.02449686988256872, 0.036984055167845184, 0.0284418894443661, 0.08059305484376608, 0.030957603444074912, 0.07307435385882854, 0.03396117181006459, 0.035533145926291906, 0.01986116268521836, 0.047693267209275116, 0.03551672866207457, 0.052835804770790765, 0.01701261604114646, 0.053178996839109934, 0.006630767255105199, 0.065727892421907, 0.06312857141658183, 0.06502548172589272, 0.03866254614906446, 0.06463214154205014, 0.022105702627149802, 0.03484225719265881, 0.033858324506229935, 0.022781807779064103, 0.013979704592437034, 0.04060171003783903, 0.0322195551838846, 0.07340098310622477, 0.03825859947791023, 0.017668019582126892, 0.02841092034002706, 0.029253230182333823, 0.05988921842447693, 0.04588666334447842, 0.019866412302719492, 0.05204430954050153, 0.017461696782359676, 0.03933226404291007, 0.052287653539209604, 0.048761147810446645, 0.08631108148444085, 0.028539008325746948, 0.08324458474113096, 0.04372068763440175, 0.06280913190435498, 0.07565620039860088, 0.04817768375599577, 0.050771167171337915, 0.08631814481510271, 0.02117684974725689, 0.05896628548901889, 0.057112513590724244, 0.016156635359830914, 0.04723143110412264, 0.049536053406735586, 0.0263717666553754, 0.03527413159909268, 0.044844017679532694, 0.04306761683115075, 0.016241366599476146, 0.019141945935365175, 0.05332515492374378, 0.05920255849618585, 0.0738510137964641, 0.029685112249646938, 0.03590265694524973, 0.030131161197899815, 0.020765050674878785, 0.03611463730433776, 0.07833498770431166, 0.08145383889636687, 0.039918187239597884, 0.011172662676882841, 0.035691457995844465, 0.03747654245084813, 0.023500287169290167, 0.12302952247761911, 0.012462226140703405, 0.048618486917187134, 0.06243413186541969, 0.07508701239261897, 0.02757095281154879, 0.04188226047723044, 0.026602307409648935, 0.024342888125008153, 0.04302489210761363, 0.05586849788444177, 0.0769679497687086, 0.013969778965768075, 0.014747489401469789, 0.020447836648071968, 0.011326420353725554, 0.08520001650697763, 0.055221023353477644, 0.04456713435149962, 0.057755977651404763, 0.044778302657387914, 0.015975360762357952, 0.04273477078024899, 0.0617918897149784, 0.06387171117709049, 0.07747418066907315, 0.033355709540868, 0.023139059476013628, 0.020013148783736175, 0.01993617035388466, 0.027382554553989923, 0.017990389380664114, 0.05272259995821984, 0.03436018870542607, 0.010093696783446978, 0.026736244476670702, 0.030757903474413102, 0.05345416413019261, 0.02016456989240983, 0.03762122581622774, 0.06336070371851807, 0.046814978047604525, 0.02189803342785566, 0.04266057516478243, 0.030069282361035867, 0.06236637138851708, 0.03332734513547152, 0.09775256632917351, 0.04287198478836687, 0.009268231299375335, 0.054027653719869353, 0.07231347533243318, 0.08371337692463592, 0.036041525703284054, 0.02009574263807266, 0.011286658475235587, 0.027692632471782067, 0.03976996837844772, 0.023567725889264576, 0.01855757789716365, 0.09076408245750973, 0.015089088006906453, 0.013372732172419709, 0.013280275893668014, 0.05849302318247576, 0.025947240947355187, 0.02376742394370658, 0.07559757935063494, 0.01936091493154245, 0.013744596038914978, 0.08177441604916127, 0.04953468210935112, 0.053232408489190766, 0.021270795109411402, 0.07026049759118788, 0.04843091411936668, 0.04843881631630564, 0.02787105817978661, 0.08332751375893432, 0.05836116029850899, 0.03117667586212197, 0.05073158340829034, 0.08166009274822089, 0.01654966527806415, 0.04080863421662681, 0.050523743754433054, 0.06214959148858344, 0.0369785814696262, 0.03246819668058907, 0.061763758966398824, 0.024127979394829562, 0.022292034362532923, 0.03126343340432692, 0.09069571677114695, 0.05855500352598968, 0.029749611107211922, 0.03307871513008591, 0.03221087923814212, 0.03722385600990346, 0.06685018824834017, 0.013114235912179275, 0.011293226721576385, 0.07842069762128015, 0.06763732826877987, 0.10443371870825369, 0.05226123882758041, 0.06957616657018661, 0.05702428324448486, 0.03397890674551168, 0.007377813585222729, 0.01755681617425815, 0.03315702846814548, 0.05702313794303806, 0.10227324350947335, 0.03929948314063011, 0.06357321267827384, 0.03990941936330449, 0.07210689972365095, 0.003958830211852347, 0.08085917846690263, 0.05437924594227826, 0.01492273775980838, 0.010835858824242268, 0.09098062487018686, 0.04031923809839834, 0.025000882958392465, 0.0465359190298665, 0.06240862879842039, 0.039995022027963595, 0.05252909380942584, 0.0472907722747374, 0.0773437925043606, 0.009803073668491938, 0.04598145906422888, 0.020812011864637176, 0.05424603857400437, 0.035784729200625615, 0.058141840817106355, 0.020274622253172343, 0.06037612092651187, 0.07368776045979993, 0.02547209789495795, 0.024583433987572793, 0.05287936069972573, 0.04837245778030446, 0.06437558635708786, 0.026288226682452426, 0.01669806800031614, 0.03022409532399428, 0.0327204272992188, 0.05695310984587958, 0.08279038653258355, 0.0357720542759184, 0.035330860409885645, 0.06557993786109072, 0.050287735047599966, 0.014304269232877321, 0.049895720195866404, 0.004034948708008855, 0.02744027927908446, 0.017083645798265934, 0.04694716651893912, 0.04672899616942291, 0.03868404640665939, 0.034721138691830064, 0.07582858550332247, 0.06294373738309068, 0.06145692543096601, 0.04346851447236635, 0.06162155772589388, 0.018160725200188257, 0.011423266316283376, 0.05446379906648109, 0.08410093314465016, 0.002870134762375646, 0.014681930469739583, 0.03557665588995142, 0.03197102285470934, 0.03443525383068669, 0.07047001497759935, 0.01425231698029224, 0.04108246851472124, 0.012180286632370085, 0.032158800581049536, 0.054411486752571604, 0.16170666643208073, 0.03796106241943856, 0.04592747284820484, 0.022048676957286174, 0.048730427684683, 0.006437376498304789, 0.043561632459562634, 0.029979249792954618, 0.044834702050373446, 0.040186249065182866, 0.028392800445398016, 0.02887599699709925, 0.0720322061510336, 0.05776864491523274, 0.010572565895985934, 0.05557309821127884, 0.03598273994641439, 0.05615137968092196, 0.053098006023755, 0.043326485601644364, 0.02992274697809931, 0.011674423454209201, 0.019603715007824284, 0.012340334848681045, 0.011373562531756058, 0.04570096746207245, 0.03569326213290615, 0.10607606566120541, 0.049037812803421295, 0.0580260542882306, 0.03369036355927106, 0.013446942152034853, 0.03947219383271952, 0.06931754294782877, 0.0358532021392978, 0.029423652186749444, 0.057889560402761546, 0.04650724435886068, 0.001862695146795182, 0.040955497102150996, 0.040695490691089825, 0.03441638891555129, 0.05936102761376289, 0.033719130160827795, 0.03557834894426408, 0.0454650008900752, 0.04482602227419134, 0.03530738364544607, 0.04797411887275596, 0.03991787314354893, 0.014571121597151845, 0.05558021133765579, 0.019885669837916092, 0.012595931466128077, 0.03920885493918773, 0.08689047378157416, 0.03224821836357156, 0.0066851527944597755, 0.023307252164569595, 0.03273341248953535, 0.048468272396994215, 0.0940424944424341, 0.016992630722421794, 0.034697420609694336, 0.02265254576360026, 0.00373224510469534, 0.043532402374811714, 0.024127571453009884, 0.03878166132997121, 0.04339021645606526, 0.04227018441944834, 0.026369650337484576, 0.0060600786744016075, 0.03253152150841009, 0.021305244168146484, 0.06345319351361645, 0.02740478067989311, 0.04298706268591266, 0.09828723441328734, 0.018751740966352726, 0.02261818672019628, 0.004697026311224628, 0.021655769613120827, 0.013582749431201769, 0.048536151617525086, 0.02398661893582152, 0.07118510442876047, 0.04831331196211038, 0.027251589908114365, 0.049292088876808846, 0.04631134035486368, 0.1261078476184799, 0.1059526105922076, 0.15240876454739802, 0.13885801748162316, 0.23261987093475558, 0.12556222447704884, 0.23068030484982077, 0.14106729248118016, 0.1795077612323146, 0.15469863199658934, 0.09403012212245696, 0.14971875405359655, 0.12379446893089241, 0.3614502724620604, 0.0811976820771252, 0.15688904591145056, 0.22180937440885654, 0.16261184527989359, 0.15978121168671117, 0.09398218800103474, 0.10404990865818917, 0.09605723673537855, 0.07915198217116057, 0.18337995264559023, 0.15139426495279037, 0.12485259723278785, 0.1269580060315709, 0.20835930661809063, 0.24127965222202966, 0.07946161958839625, 0.1191790113526006, 0.1479401890068285, 0.23530320114185735, 0.09974768911037715, 0.14572161369987074, 0.15312720180278824, 0.09644897579545937, 0.20340892306018263, 0.13887488673771584, 0.11579468005126524, 0.17389077392797317, 0.09917352919376667, 0.07326861843466759, 0.16633000705511342, 0.15112323836693842, 0.10865915326341506, 0.18139383905837614, 0.08545716157964162, 0.1820909484259544, 0.11224285894704443, 0.15985231996784288, 0.17157590136893336, 0.11752255306008363, 0.12011094199072932, 0.14312477481942024, 0.09841592186280797, 0.10555697980547145, 0.13490903341481764, 0.14078226180807238, 0.11700421797051547, 0.1874835332555156, 0.13956450376539462, 0.1740345992748776, 0.12429157572407877, 0.15458256967606085, 0.124765929705914, 0.16520087006351641, 0.10094470915294464, 0.09014108443572637, 0.20323759515679654, 0.1712001199203153, 0.15754633402872473, 0.1329075214603255, 0.16481292313866078, 0.0965815090063599, 0.08043665033314498, 0.16105507800896324, 0.14138013214593934, 0.20535435737861743, 0.22157171861298625, 0.17442741851893165, 0.11219653361026319, 0.15763340758219843, 0.0756912642428952, 0.19800924425644262, 0.2015110781236041, 0.14297858992170903, 0.1880882677411841, 0.1266747986477229, 0.15435098129655087, 0.13100184710516086, 0.1210124589382641, 0.22075819452443432, 0.13271216903963398, 0.15012110343142865, 0.13919319627025437, 0.2855793759226799, 0.16624746874215143, 0.22223144288985963, 0.07572740827116274, 0.17319161144475784, 0.08098682403684625, 0.16370327542385749, 0.19450627657915318, 0.10466045009032374, 0.12934936480897088, 0.0935034826397896, 0.14366598529440744, 0.12845678810751246, 0.20089218633309489, 0.1053524419905678, 0.15753603780702238, 0.15645588447730388, 0.20538896923103642, 0.1194784674613226, 0.09848424158389531, 0.1311717194414908, 0.14397534691999037, 0.13690515211032284, 0.09329093920607721, 0.16060904629768866, 0.1782260348479594, 0.0969430182369486, 0.19310851851778646, 0.127509436119468, 0.15411844296801477, 0.12069091651468508, 0.14046620457403122, 0.20667895404321535, 0.13789291523637312, 0.08125031997840251, 0.07879429571931401, 0.20235709966190402, 0.10846110421323008, 0.14028770608767388, 0.0934431532157525, 0.14077925874340919, 0.15784135448836512, 0.076066785221619, 0.22720310837030414, 0.16997338332716497, 0.05452117522157008, 0.0820347174040733, 0.13944139343596276, 0.12646843754355946, 0.13838437596155753, 0.20856719223722336, 0.15835003687008736, 0.19037097992916263, 0.10053069225602573, 0.1315161525722473, 0.25025880024317776, 0.20848206454707732, 0.11176396972469746, 0.15817598169369085, 0.13650931447984713, 0.10020263808509035, 0.25849927096597614, 0.177902807030947, 0.11450477950875798, 0.15113309025764465, 0.12949153540595887, 0.15538962798253184, 0.13065965095114324, 0.09613550793860229, 0.11974065339252835, 0.09743319193442022, 0.11155112751669462, 0.14980858552359766, 0.24933548043331794, 0.06778895239075346, 0.20922641089606672, 0.20841815749243384, 0.13905238930977162, 0.13590920716524124, 0.14862992860857518], [0.08071376731799496, 0.013106547262249215, 0.036716606212599624, 0.013665589391283933, 0.09778478798726875, 0.032187885109094844, 0.033145862736649094, 0.056588191524027824, 0.07038070444738673, 0.03480781004914353, 0.023431335425665303, 0.05606568891615157, 0.0627076022717501, 0.03324925396290999, 0.015312136421280523, 0.03225620099974256, 0.0329394556672102, 0.05074302493143947, 0.031043499137365052, 0.03447880209874242, 0.07243057187165945, 0.08281729920136352, 0.047223456128830874, 0.007255238559727948, 0.02885602316969345, 0.002565271269920613, 0.01509066423281066, 0.03478172092488216, 0.029072529193194165, 0.0034608019585345663, 0.023672147503783627, 0.047087372100401315, 0.02940806421271015, 0.09476442505875904, 0.02591276890598238, 0.032782641299549616, 0.02250999786830958, 0.0328238376776778, 0.01898862875907892, 0.05423516012547959, 0.016932837559931704, 0.0262821190464761, 0.029570930674972556, 0.06066593964914642, 0.01747951215703882, 0.01337578407518806, 0.025916505499833056, 0.012936044818601541, 0.03152038503979002, 0.02628243888818449, 0.011148459086525104, 0.01497841798775499, 0.052275032240657084, 0.04005220666107151, 0.03938822293533914, 0.05405461235392479, 0.09860797244454585, 0.05623646140579255, 0.021011955067214948, 0.03307236809163325, 0.029718879490129413, 0.031974104443384756, 0.0351849168298706, 0.005640775292000223, 0.0278595840979007, 0.04477310475082167, 0.018353476752376845, 0.07213997940022139, 0.11337917418249192, 0.06866734114385421, 0.047289217116251114, 0.005372938025938047, 0.04648928342747592, 0.05550564416954595, 0.06177899645521276, 0.030749442033289425, 0.05579465466942038, 0.021112460057221113, 0.046472180514566364, 0.11813033657569079, 0.08283012351321598, 0.11136290737457814, 0.06865592643378243, 0.05881669533048427, 0.013906459883606483, 0.0840947661368597, 0.07943905829902619, 0.014851752052744551, 0.03421396550331866, 0.03370710258041659, 0.017353157445247618, 0.019198245736920548, 0.07101596753683782, 0.028353354578176816, 0.018891559673413154, 0.03930043692009584, 0.04062462755809388, 0.05167741471180513, 0.029247743077576164, 0.015789334504534642, 0.03660323286068536, 0.027381631418041168, 0.09408529577476364, 0.06756605910918406, 0.024912595155558763, 0.032099604967140385, 0.08477529736175653, 0.027784974794955026, 0.06710820666123783, 0.013005753074051633, 0.03629941388123459, 0.05752502129443231, 0.019630562559130694, 0.019020373527441296, 0.05118292410888019, 0.05516720184635732, 0.02183017910518233, 0.04028965178276262, 0.06442344386971767, 0.03016920512421958, 0.042904463085916736, 0.04053137550551084, 0.033734482562830376, 0.069970226876678, 0.06807008367632666, 0.10402579221033281, 0.04937512897736123, 0.016396321288700548, 0.06554074480288452, 0.025237786072877147, 0.04288031982498304, 0.04255232311064198, 0.04727365020962973, 0.038084915854156985, 0.041350170278981815, 0.051467452994397575, 0.02579928447131909, 0.05291181984507749, 0.02643485782637952, 0.055368284604722456, 0.05302354610795456, 0.018371669425358696, 0.0406601395638239, 0.05798163651038082, 0.021425167571813352, 0.0263205441015382, 0.06311841309070587, 0.055518564242388935, 0.02509015709942868, 0.029182493453845385, 0.03177227666451326, 0.024636520050285805, 0.06964525237919823, 0.031044682743208065, 0.03618804384924231, 0.012991111218598823, 0.0384831513398357, 0.06179016984758839, 0.033320373735360564, 0.027754877115629857, 0.01670718253139527, 0.06936913896952906, 0.03601111967356936, 0.06483915382094922, 0.004566521318103638, 0.026063567568217556, 0.04062231397256255, 0.070158967958583, 0.042126110093968536, 0.05582512198616901, 0.03712572397724275, 0.050612908727940054, 0.009864269729493367, 0.00246769129937034, 0.030959930436144915, 0.03692741445716351, 0.04348356810007845, 0.04274053176143958, 0.026243489062894258, 0.058635362318807074, 0.10003357780196014, 0.04416132608668939, 0.027648184050415314, 0.036686475974537676, 0.05259078686996814, 0.044170400398152496, 0.052091136664873174, 0.042863684225707285, 0.05075671875308599, 0.09130126331001522, 0.02550387905249673, 0.05198602174078265, 0.04343569143525055, 0.0336840701469731, 0.0534933380362007, 0.042067669076664795, 0.03066708183576984, 0.03867381530243062, 0.03949000920739867, 0.02186849690793503, 0.03128014178195548, 0.01439750500609197, 0.03852414087422433, 0.03360289164007672, 0.03993076257287495, 0.03096141856193783, 0.04469261572305714, 0.05944378043134367, 0.07074964473084097, 0.10087121833836842, 0.024924481009703972, 0.06024597407949548, 0.035765289719547, 0.028080236572291584, 0.06934990250175038, 0.0702548438623067, 0.0667928159236908, 0.03385819427128281, 0.011775543229774603, 0.029968677779599547, 0.02229866293829776, 0.05181158352042398, 0.04601872541130551, 0.027869393853771112, 0.07926355521645277, 0.04742694440327826, 0.07073183318660145, 0.06783045137361174, 0.05808046568305262, 0.04946922372666098, 0.043904613853702625, 0.04180471705753477, 0.021345310566586354, 0.02682765408779585, 0.01207406566883888, 0.08826753980810605, 0.008672030075573394, 0.023677879756677057, 0.04904132531655412, 0.06643430209688603, 0.010724072231941167, 0.013543958569155827, 0.03510656901785443, 0.03248602354658708, 0.020675901023130265, 0.03606587963839693, 0.010062065013053437, 0.028850650978124434, 0.022589050481216084, 0.018416782427999764, 0.029750988150255817, 0.0677774151066138, 0.03436681919641072, 0.06898837028852395, 0.024651127431782025, 0.038002634180649635, 0.002072087804516477, 0.013068995547420798, 0.0168630201369524, 0.013423121605639257, 0.01922125518772631, 0.016924818534584298, 0.050556811939684615, 0.012044596181611621, 0.04080359335808505, 0.010369641653772806, 0.04813234667263685, 0.040903353327584845, 0.10119905034380575, 0.023960763468377055, 0.01814999996924833, 0.06275072536100784, 0.012978499496145355, 0.037019973200175076, 0.0541247898382285, 0.018485590530138825, 0.03497408177222937, 0.028800487540842547, 0.046551524240884094, 0.060610811962115194, 0.05556499300103995, 0.015454423846676947, 0.02202601990692558, 0.028567684911972577, 0.0642828667356122, 0.0807792984790379, 0.05205659759080699, 0.02675549818142768, 0.016544272019077214, 0.03167338045914808, 0.036981634330004454, 0.06996732340344498, 0.03045186667042154, 0.06053198534514635, 0.03517922479659319, 0.03271824777907422, 0.05942511086862895, 0.07624634090931186, 0.04209194640298525, 0.02123099492652522, 0.021211984454684203, 0.04183778141234671, 0.06949830139356275, 0.037804818787281556, 0.05877593945291254, 0.05155552246217286, 0.018237362720913464, 0.04309611530193398, 0.02261963654159298, 0.015854774692636586, 0.09578731331613757, 0.032946243206219326, 0.0421550260826705, 0.0596988225926555, 0.02097121451140171, 0.025498550910983356, 0.036615597519783244, 0.030087932771552476, 0.05388195528799007, 0.04440889122986025, 0.01254564066672878, 0.014727666876429032, 0.13787596937148802, 0.010822138189518405, 0.03661413812228749, 0.025652823781955148, 0.042645586654543884, 0.013273697113618256, 0.1216857199887595, 0.04043999270746305, 0.03403656252269303, 0.05959883662721804, 0.01677839040395714, 0.03166071128010029, 0.017627102826091073, 0.06708512443207926, 0.014597616748013085, 0.040144573882102005, 0.035011926515688824, 0.05312507957099907, 0.024471757520410805, 0.02189679428063814, 0.038488253485411406, 0.042730335131167405, 0.10047118254606763, 0.045855655935743166, 0.03644700455028684, 0.03600821620033633, 0.04989311166648423, 0.09773960412149468, 0.0726549590246812, 0.006830068859046386, 0.2287766989320517, 0.11713027773845582, 0.10926605577790931, 0.13696328286201725, 0.19005100032494915, 0.14807900413870811, 0.12179116433065747, 0.13409799145114037, 0.13140411987420053, 0.21189038972220114, 0.1576106547708473, 0.1420179463081783, 0.15639813676957162, 0.20146005666784703, 0.09747675935467405, 0.14048903399417478, 0.09280189931873353, 0.10932082340361611, 0.13278393615638057, 0.11206436046068707, 0.14965357529299875, 0.18289080550593717, 0.18007550899299885, 0.1207658016092835, 0.11486523919889044, 0.07779989061096022, 0.14712194581666302, 0.12432873864928562, 0.17768716860202052, 0.10167597072018732, 0.2663406711672583, 0.18378896698836358, 0.13454647464377267, 0.18310341022668347, 0.08583416110805928, 0.1609948481763563, 0.08959635761716674, 0.1107027234449502, 0.14531469843800993, 0.13644899271668928, 0.10625498549592112, 0.0972176147925277, 0.08182683944581978, 0.12929915540641354, 0.10987730967181344, 0.1945216902681897, 0.0975607608955714, 0.06702740736786397, 0.17650789881665863, 0.11500373257384186, 0.16487833172563585, 0.16830248427727532, 0.09537526526518407, 0.09707919036548945, 0.11295426351528977, 0.20415054213616157, 0.2428801784351949, 0.16485498136570378, 0.1448459139153842, 0.12729829462665704, 0.08067995219701722, 0.1997642137951428, 0.27397323580038163, 0.12813705365143477, 0.06892435598157107, 0.14094963669776917, 0.12770868026681487, 0.2194391290146497, 0.23179484020558097, 0.1445219200104475, 0.2188061718498507, 0.11941947869115299, 0.1428641976728555, 0.12769420120504596, 0.12906897662868425, 0.14643525524485498, 0.14508767594252864, 0.12085372552035317, 0.10498163245257833, 0.15434425504457566, 0.12492946649511015, 0.2745231949994641, 0.16566738696588626, 0.12148024754658823, 0.12107245128361449, 0.1331509995244203, 0.12419782954478457, 0.08297534314014259, 0.10584215603528485, 0.1654824993062404, 0.07596274282062247, 0.08352516444339868, 0.17372208136704662, 0.11696187629094047, 0.09323160569634169, 0.20582171697770396, 0.19405402423393345, 0.17291560528739808, 0.14512181282043457, 0.077914857425757, 0.18891110745889528, 0.16319244799594726, 0.16035668161367217, 0.1271307511976169, 0.1823922814500909, 0.06962920283718456, 0.33015925797723955, 0.09632957333158101, 0.2814176492393017, 0.1154169527393195, 0.1111356397309611, 0.10159317959821033, 0.08223692631168712, 0.14013321679686347, 0.15697849433748953, 0.14535523981096285, 0.13199926293905706, 0.12612326896839565, 0.10804638251542084, 0.06302397743227982, 0.14310929984334977, 0.236982619089465, 0.14543436137178253, 0.16686133499587738, 0.1369082930708124, 0.155244117242194, 0.18416718459658085, 0.1126500346787995, 0.23168446225745065, 0.12179480324829779, 0.11906051287247289, 0.10441055220942344, 0.08497117838311581, 0.2362406322912824, 0.14206046418797585, 0.10377338922192013, 0.19147033142226358, 0.2623202417406344, 0.13203865518012356, 0.09383149850632876, 0.11554480515300267, 0.1783347427244148, 0.14234315063203537, 0.3710773010407725, 0.09795698157000927, 0.10012186177435423, 0.2654663503410355, 0.224776218434976, 0.07483331471561425, 0.1273738308959911, 0.11662445286469114, 0.10905184993340124, 0.18233873190418368, 0.17855410434065327, 0.08372019510716201, 0.11337285395711662, 0.1061415508569729, 0.1815622098623745, 0.1541943163160355, 0.1425492129619083, 0.13551108659275118, 0.19203054087777294, 0.142599590903809, 0.1303545487744193, 0.13952273665176285, 0.1118211428664865, 0.09993693581031216, 0.19329274734181745, 0.24094203727379923, 0.16334949602042476, 0.17487050845257698, 0.14304516296232903, 0.12621591964195814, 0.18817943220417346, 0.17105643246923724, 0.13541592315079706], [0.011280829503741718, 0.030308615889460332, 0.04109190671794838, 0.017414773896997495, 0.03681410239228318, 0.048262317319430655, 0.0532110806013788, 0.025041424331345388, 0.030514628423618215, 0.06573472592619158, 0.05768560481468036, 0.005849810043019393, 0.04176266649137101, 0.08885342853083726, 0.006229341013221852, 0.027400908105435873, 0.054697057517666015, 0.031587304735195734, 0.020074883979114316, 0.03887414729462997, 0.06085737736054486, 0.038426817064323736, 0.056983270727458506, 0.06157609423802746, 0.07164409068683464, 0.05988950953788816, 0.05169238406984557, 0.029845351030329065, 0.07980959204536292, 0.03551649883569729, 0.05719247784826064, 0.051571426447480924, 0.026999677215973218, 0.005354729552392758, 0.057000040392121004, 0.045766372218607895, 0.0934540699686735, 0.09851545966680973, 0.08967172534715745, 0.05523447585742801, 0.0685280816809785, 0.013277741100248552, 0.026043942310817303, 0.020888925177015124, 0.031111736504000523, 0.08648528221754298, 0.043493527243094104, 0.037808894375038725, 0.025391938285000866, 0.0047273744055400455, 0.03113346850319255, 0.12233410616435351, 0.006345616401954284, 0.051640316904071844, 0.04681079903797758, 0.005852086760569365, 0.05227869031049552, 0.012886708756277879, 0.05817658673491209, 0.04639785849459229, 0.060831292066723115, 0.0465755257755518, 0.020768992197249207, 0.026046606381573988, 0.05616619199093792, 0.037819106327069384, 0.061354629710436835, 0.033341483288114114, 0.04925440118137387, 0.040608604829157555, 0.027774829875617742, 0.01057291446599148, 0.019865186562040643, 0.04375482068186806, 0.04925025664570351, 0.0517244793234333, 0.028130078252645272, 0.0681945116769883, 0.061494540348048174, 0.05249126438772487, 0.02887495320230242, 0.029426189852998625, 0.017225718719043562, 0.0339070170546972, 0.034085032905662255, 0.05051212603106134, 0.042278036820672216, 0.07752590692572056, 0.01337879958878001, 0.04986766222563963, 0.022449666529052684, 0.027830840478981697, 0.0710485186127405, 0.049015228531413504, 0.0192160094006648, 0.09424992040881226, 0.037776665056064244, 0.05022595388694637, 0.10434833820909263, 0.004859260750949504, 0.049617258726709315, 0.058096350516162576, 0.03265729782381847, 0.04903131254738377, 0.011526850022135243, 0.010563741520708127, 0.07974242911704126, 0.048941799003871224, 0.05743661857840996, 0.03899314756234808, 0.04421477987160606, 0.04439119076836975, 0.03741758049375588, 0.04791891074649269, 0.07301066896968311, 0.07969514617035467, 0.06258289464899609, 0.005077725565511613, 0.014138967568625607, 0.019707678884808576, 0.035518165076932603, 0.010392884761395474, 0.09446553585510101, 0.030829277971098502, 0.043798315323769085, 0.05034287422595005, 0.05321671134762226, 0.04302451289409111, 0.05698364994098103, 0.050219277430686264, 0.014081298384905584, 0.042297242644933924, 0.06371609190659178, 0.032636981172066544, 0.05150877960747288, 0.08004489595130568, 0.047604512092807603, 0.041426445823162794, 0.03451106206123387, 0.021063872845843438, 0.047552238083294326, 0.04111362148016211, 0.01900478938384162, 0.05062676725849029, 0.051483544671247085, 0.06780284156482067, 0.01892164203097984, 0.059663260791210405, 0.06541969524996896, 0.03958821018797256, 0.033195057072706764, 0.0464758385844048, 0.030548054754974383, 0.05023147738088043, 0.041158491249887214, 0.008876343809759185, 0.009322715472550163, 0.016822490255318342, 0.03103544372284124, 0.002714783862052906, 0.045120966125039325, 0.040681149525147293, 0.03310557034227156, 0.08279242432646214, 0.023541382040768385, 0.023975221462728038, 0.017544759865549785, 0.10118477046489717, 0.0154836060509326, 0.0670520753990258, 0.02013563858194938, 0.0342985722536762, 0.03454081691621292, 0.049858028669991804, 0.01872224466604812, 0.029846797021286144, 0.03377332705103102, 0.02570767376211382, 0.010539617411972535, 0.009968323621808762, 0.06577925861723001, 0.057752817538717104, 0.07553938731190658, 0.07207613363261185, 0.03839834540661785, 0.06870919252715765, 0.0579074140818369, 0.042851036114077416, 0.056713902721962625, 0.053368354621793956, 0.016935953622563713, 0.03020399317686116, 0.019247051283356645, 0.062405192894079996, 0.012507507682687814, 0.04636084495653068, 0.03056016468983745, 0.06883351327550989, 0.041958244908000195, 0.03676938200970331, 0.045853579837468364, 0.03837374249292958, 0.07397992341148277, 0.051208653171817144, 0.027376328174385334, 0.04377675760957984, 0.02827623059161969, 0.09584019636555065, 0.010516417396795607, 0.018769989180709087, 0.024437019263484308, 0.05423113433343749, 0.11566974643257358, 0.03827885867306783, 0.024362771937082854, 0.03887874765261527, 0.05803040949808014, 0.019541550803208546, 0.05161411669706145, 0.04906869763808866, 0.016793007361552408, 0.011495150261438422, 0.046076630167062246, 0.046971566419327454, 0.013744225443881607, 0.03684853421403997, 0.030600066379373594, 0.08315163529327801, 0.08378341268267363, 0.04319425882591356, 0.0038025221804292094, 0.04447494333069171, 0.03202128779864119, 0.041081369178549904, 0.0563298398628831, 0.02467774898715077, 0.026914557186706413, 0.015625471170360766, 0.03257505828514695, 0.018420279619374105, 0.02762377648914774, 0.038628600793139595, 0.05845794784686258, 0.05628983092103755, 0.026865035348061114, 0.0281718377053978, 0.013691254294357233, 0.025339744714719635, 0.0356247968551132, 0.05638380309626941, 0.01947576300271096, 0.04207580109998103, 0.022296196135181575, 0.09615979292580197, 0.04427338942825314, 0.029048629165176424, 0.07263304124916754, 0.03162846855458713, 0.05381232555655222, 0.04040785148859986, 0.007137431473951908, 0.036764272203248356, 0.05439161060137614, 0.06002501516993489, 0.06727948859934846, 0.05595611536034173, 0.019125067103173465, 0.04007503991165469, 0.06659205492225385, 0.10355860115058961, 0.02262768812567717, 0.05277903765560158, 0.005637627628241336, 0.017046674395040158, 0.08753786404286662, 0.042637837675189784, 0.0340681636495696, 0.04177120837172674, 0.07013776264483891, 0.034851756682919885, 0.045720916391620715, 0.012663981141222101, 0.03356472513968906, 0.04302214951284471, 0.0924511612843602, 0.051337892204643264, 0.026845639917038144, 0.058499657503900036, 0.0454440254027084, 0.050374092308864485, 0.08552157425231512, 0.029235604414415937, 0.026974779358434103, 0.018036869850250024, 0.01879781157889914, 0.0305155745422047, 0.029913174709485426, 0.035828572412532185, 0.0835031700590926, 0.034419920580882224, 0.05038101774369998, 0.047441637969665953, 0.030056647655944672, 0.047880522080606995, 0.07329328646582943, 0.06550841589247988, 0.03581648737552666, 0.03564323276101101, 0.05474148678683466, 0.016009408582542694, 0.019517223681173018, 0.03118962849370174, 0.05302608185898393, 0.0489967581515591, 0.05848308702209785, 0.0398143861562975, 0.1200054899879521, 0.0545261547930779, 0.024380778833743066, 0.05138650048343886, 0.02054120552906346, 0.06097585285803484, 0.04344226063920125, 0.04112031708862032, 0.01743294933300105, 0.04436114863041909, 0.016791975058074442, 0.034489607768914396, 0.0111133617258841, 0.04579915312088786, 0.034464070227958506, 0.026939049017645662, 0.0799727764341139, 0.03423222520899388, 0.036779344983158574, 0.02967823852574633, 0.012141714105382563, 0.01943886246261818, 0.02066247724747706, 0.06484869161560651, 0.054011156016419974, 0.053729469317101666, 0.05860305256060055, 0.057220991640802354, 0.028211065237560583, 0.07650832765765729, 0.016965702731883334, 0.02046166070466561, 0.04199605517750306, 0.027390671255547675, 0.02539294186018167, 0.03131501410426873, 0.16908487455258447, 0.17144975733132134, 0.08093153547135093, 0.1885565160022628, 0.18863292561183054, 0.21607729005477122, 0.15892319321151704, 0.16430489959255343, 0.10567731689661743, 0.13756155156560484, 0.13415147971001365, 0.12450366716591582, 0.21357739194025918, 0.1541335195783646, 0.06826882220564351, 0.08894290760039322, 0.14575152177243464, 0.14471051553564687, 0.08366401787967452, 0.07539926216967645, 0.11895133768238368, 0.16499586493497895, 0.09942544188590781, 0.1796863822927398, 0.13209640288785582, 0.17819125445619707, 0.16071168675778374, 0.11001666872611932, 0.16611214697120652, 0.19118746111710228, 0.14550884043978107, 0.1361093246528218, 0.13495829286834887, 0.11118073166618425, 0.09588613865836974, 0.13697477418088144, 0.24609310522435174, 0.21112846931622875, 0.1870207855057332, 0.13782136262424532, 0.18462038689082672, 0.1445369353337634, 0.2011154549977472, 0.18764378352751657, 0.09965818705818347, 0.16127508313905808, 0.15360665026931994, 0.13204741922597732, 0.1119727669884601, 0.12325912668940522, 0.12701009234954275, 0.16086213110435396, 0.15567179348680282, 0.09061989704928092, 0.12555928269941963, 0.15666001626560766, 0.14779907561117603, 0.15177108828098546, 0.23797692460638864, 0.08571369378196617, 0.2068813851163272, 0.13134840996034686, 0.18676092848181727, 0.1203955053502033, 0.12213840900409607, 0.28649120441367554, 0.1770854371810152, 0.1301344823572905, 0.15668108368352537, 0.12412381012954059, 0.06628503752571922, 0.17276840915362682, 0.0862849425644644, 0.24128731310127244, 0.17736397142852509, 0.14874560788514155, 0.11767657503726021, 0.30500022574297847, 0.15792252916482188, 0.06402893540179057, 0.2389328337965473, 0.08535135717641923, 0.1790715354464708, 0.1234939709425934, 0.1102084894814799, 0.14702276807398568, 0.13507924282983427, 0.1743302785701329, 0.1741412846792129, 0.11695858977374532, 0.12687495443969965, 0.10075353957231968, 0.1900015570103161, 0.1681067181691047, 0.11602648293539403, 0.19705659860084135, 0.16224256025687342, 0.15244789631857028, 0.2307120974986784, 0.11387783613416458, 0.13552165860610624, 0.15165429051604964, 0.15663603771357767, 0.22473403763386512, 0.1667174636836975, 0.10511791183342857, 0.14756351889621827, 0.1102036937710739, 0.19752360579948272, 0.12555271732590853, 0.10931518499649341, 0.14407386582705284, 0.16812122787439054, 0.23304558599427824, 0.20977135988012438, 0.1620442200932772, 0.16648794374158307, 0.10796879313044971, 0.13679220010676693, 0.07563464268441163, 0.17873021263268687, 0.09429322735917184, 0.24528253823518756, 0.06513097203306614, 0.13297887488959298, 0.1467774207553556, 0.13197735282442263, 0.11289477678796939, 0.2234790936833428, 0.26115664611420325, 0.1424269146856762, 0.1518106337396368, 0.22585566696380416, 0.177492352442876, 0.1483770429847702, 0.16090012906539827, 0.15976123211364593, 0.14861520439867051, 0.19455152173196116, 0.08851210571705334, 0.16871992558721574, 0.1162550988937578, 0.11469643938565448, 0.22735438009183254, 0.1346052948745989, 0.1572463033540595, 0.2319975623921041, 0.2208356153700621, 0.11406971051567986, 0.175349619840422, 0.08256131092146521, 0.14866188979677616, 0.12475005636412291, 0.1437516186025835, 0.09163640379425018, 0.11843506336933184, 0.22710978353936828, 0.09209682263674275, 0.0897781502815985, 0.13509949819455225, 0.11724258622815532, 0.13141633131571356, 0.16542390890179143, 0.27199066153937773, 0.14861983156973316, 0.17092282673524273, 0.15102186961279762, 0.19398245630004715, 0.1353007801357777, 0.17108797996995911, 0.08255316740683011, 0.1456003726249741, 0.13834026461887744, 0.18410349204655618, 0.2026253070441946, 0.15022533735440624], [0.01767129460800319, 0.019622286894328652, 0.06769445544529347, 0.014673818556231358, 0.05349555586074149, 0.02872388257885412, 0.04826377671692641, 0.05385099001409066, 0.08772433750451573, 0.04922986338515917, 0.0259061690585147, 0.04574569933597119, 0.05622966620590418, 0.05132728954777122, 0.032561506189766436, 0.050995278532706925, 0.022013900395963463, 0.01956231944683579, 0.012360475300210378, 0.057029733960066116, 0.03572784717224779, 0.09274631197894774, 0.03314412371706098, 0.07732958923424445, 0.03041103992971682, 0.04153210083923994, 0.020897691138088707, 0.05158707379333435, 0.03233475565549827, 0.06553599505775398, 0.03604445598959442, 0.08217176287284783, 0.01750189150052686, 0.0399968836216196, 0.023730954328071208, 0.03349295802294247, 0.1024053170676193, 0.021749565588130106, 0.06038229559518157, 0.02583597433723269, 0.020928284859344847, 0.023828023413736975, 0.10578004162638419, 0.1139945496294287, 0.03477854549043602, 0.011983013246208431, 0.04605046060356883, 0.051812008699221965, 0.013599521968693984, 0.0555874087337044, 0.04624335005158379, 0.1104616125925414, 0.03491642599504802, 0.05638960238185622, 0.03620688195130037, 0.10224931092271883, 0.057240132347590504, 0.01894314994945401, 0.015052728516410195, 0.07131013763888229, 0.027654490869251952, 0.040050440828406045, 0.03407468305780523, 0.07336504592169678, 0.019956362516348882, 0.02120291205844091, 0.021818932934453892, 0.056205377388264866, 0.060513982278925765, 0.04870614269748331, 0.004841265824413108, 0.03198041317744121, 0.03919836719550433, 0.04115871341538526, 0.027717800375314492, 0.056994896111709464, 0.04631991287873638, 0.06149326481165425, 0.015693539997652894, 0.014396282138242839, 0.05444977582702714, 0.042872823654643955, 0.03585302976951484, 0.028141226747163364, 0.013582428631883477, 0.061734467594613956, 0.09390135040326465, 0.03957707509999314, 0.02672230359166861, 0.012431593157441146, 0.05786088190131611, 0.04904584140486775, 0.06430818594150967, 0.04781383412679838, 0.016759175003596374, 0.07563697925258069, 0.05917569945356058, 0.013909925473853947, 0.03937465551820013, 0.06687992012068149, 0.011713087911747638, 0.0401743363979603, 0.03451471247019307, 0.04854197771618924, 0.02592277018383386, 0.012368651373582262, 0.0648739954997455, 0.07680935424662406, 0.05100275172040828, 0.031813160861812295, 0.032318441813150724, 0.04049610098703735, 0.0302897643808636, 0.05997628048663178, 0.06051580556818555, 0.035952203681752566, 0.0560699368736917, 0.03586007777841822, 0.038715770107603846, 0.02075458016817368, 0.07459584278084579, 0.018731250029598034, 0.048700979264873656, 0.0947470578455156, 0.09452434076416878, 0.019853930815213153, 0.042423945926730676, 0.03390160081307254, 0.03900517131231966, 0.09948966303660024, 0.10578903549861525, 0.00302317327417944, 0.024114226201368917, 0.014942433880341631, 0.022349353061027588, 0.020452672578093987, 0.04996038567755492, 0.039535480356144334, 0.06334088885435654, 0.06186250769983857, 0.02985069640882073, 0.06780930734690159, 0.04378122390217839, 0.018429373083035314, 0.04577612068744437, 0.0670827342377555, 0.05067158723250032, 0.028100120384366285, 0.006263778101833117, 0.045290194947512886, 0.008930907464556156, 0.047119739315202164, 0.031293871992778395, 0.06633402884847696, 0.022143784857865785, 0.01666026347647271, 0.043977576067611095, 0.018340280887881116, 0.03486216015693161, 0.0541303018408437, 0.025565958987440796, 0.03442206945750983, 0.02926581317649013, 0.09250900092264337, 0.033448348723111615, 0.018829960458641572, 0.046183851832944545, 0.01579487140500738, 0.009138531656184746, 0.07687359837995422, 0.029776705721873912, 0.04799740411521447, 0.003623931524118469, 0.05016263288956496, 0.02015621761881536, 0.00983528383526831, 0.023693638185279507, 0.04634760695719912, 0.041533885824103514, 0.0536631835594533, 0.05089367995218885, 0.0185469024619388, 0.059650382853203246, 0.0529991232249285, 0.0035643622029437536, 0.07766378743033256, 0.03179391673315437, 0.04818023482878362, 0.03583764672399529, 0.08697182465825351, 0.02705067377387276, 0.030698914704243505, 0.11186970518000665, 0.025632286879924998, 0.014431803720071914, 0.05600122644776299, 0.014855401504093842, 0.01380874728408432, 0.0608836043806326, 0.023950631955578446, 0.012172528076916935, 0.07181594719088848, 0.023633521350641406, 0.06543484846911123, 0.07101146293984306, 0.02922186845793359, 0.03511992959125388, 0.02298280626775757, 0.029192234261802612, 0.03386994222960165, 0.006037323469025714, 0.03663448158711676, 0.011497626640653659, 0.055449746564150824, 0.06981425903617375, 0.01191807101525727, 0.037548949251011494, 0.08904789228953662, 0.016754411851927158, 0.03362043122310312, 0.03842710817773496, 0.08490111198156111, 0.005362885515956629, 0.024111705772098035, 0.07004917223727511, 0.00749724765022796, 0.04669535341822813, 0.055250065746687116, 0.030108961885073976, 0.07645674695771548, 0.041649706826935855, 0.02805919405223141, 0.03163162100639555, 0.03461302453351598, 0.02510408266267229, 0.04715726613217304, 0.0149401911579433, 0.03342087681014692, 0.01990304279681896, 0.04039100521514493, 0.03719364150216983, 0.007793507257085895, 0.017248460039075826, 0.014055498458835629, 0.03694099336562138, 0.03510525134662467, 0.028664323073180936, 0.027462767790101712, 0.011276918624888265, 0.07064525759027851, 0.04083883340260194, 0.02985457089849778, 0.04183767032959769, 0.02737617495680048, 0.02804441621617204, 0.02694185864510796, 0.03914525048927434, 0.028276161643706506, 0.03356225833657288, 0.018450986338599075, 0.008798364677556582, 0.04979589510889304, 0.07005782136994024, 0.019767462471199614, 0.03508138004690409, 0.06952483867925983, 0.026584304343428344, 0.018117178847352346, 0.01282281032012355, 0.07085538018615016, 0.023856142670997692, 0.07811479871311496, 0.02281836932525039, 0.03092435331294133, 0.057030817974478974, 0.023027693274460977, 0.01639475080845577, 0.040438816762499274, 0.052725212318041635, 0.028308938715546846, 0.018252713207696235, 0.018711199593399803, 0.04379211001158242, 0.09886273498376531, 0.035128421675894535, 0.03986767906275007, 0.03467063051498225, 0.0440986869075606, 0.03823956602343148, 0.036337365877003446, 0.044064546199215036, 0.03812180681815071, 0.0188599432247781, 0.022314363910305886, 0.04948742214530226, 0.035962710577634074, 0.0542551167159071, 0.01841068053768287, 0.03083560585735306, 0.056330050537062276, 0.03342862195906139, 0.014000103598640812, 0.02406681493495501, 0.023651926613022244, 0.036171419741285425, 0.09577624334563171, 0.046168993557653124, 0.017041528199408806, 0.031445708704150976, 0.03074238253306718, 0.10353951790039578, 0.021692120485127937, 0.07671143288814253, 0.013384526096014007, 0.09954135098885145, 0.05268178279361418, 0.01438082439915067, 0.028811078706395724, 0.038393875283579675, 0.08381869869246598, 0.025897688465192917, 0.05563597870810379, 0.04986503454405935, 0.0780828758293102, 0.03056339183521848, 0.04501376361135514, 0.030327335247890125, 0.056813030668924895, 0.027511914245664116, 0.048578259640283165, 0.02645419388558836, 0.027991299509942055, 0.03269048092225867, 0.019803462857981364, 0.016424222210902843, 0.04888757913103027, 0.042229091463189934, 0.06441067318401991, 0.09170698347471415, 0.09649536241927455, 0.017538612009957433, 0.06827678185917678, 0.02384387951854977, 0.04907503318522246, 0.02969630479422068, 0.0620941382141844, 0.03352517585059808, 0.07791064394217345, 0.021005202002162417, 0.0232117171699722, 0.03771248604020765, 0.016844450165667844, 0.09364361544289897, 0.19179119968846922, 0.11468762937452524, 0.14165256833357198, 0.16581796920828282, 0.13991256815291223, 0.21231183001110632, 0.08552181940045088, 0.1862513267945859, 0.11701927159822757, 0.14354187905067398, 0.10926234791235578, 0.13027155080870276, 0.24983090949395012, 0.0788345076744595, 0.17597940540121448, 0.13301160216571825, 0.1537884735772687, 0.07276700704448646, 0.21931482358805596, 0.09773736714475578, 0.13655154124623345, 0.17492603450532884, 0.1366035432945336, 0.1111826009207195, 0.10819275893511311, 0.12077268873972279, 0.1435763683290251, 0.1997431310554666, 0.1590324526712779, 0.10598801917606786, 0.2817817555079537, 0.11096988128678453, 0.14193694017106487, 0.09989185153596825, 0.20088179818084165, 0.22078275530328675, 0.11287083654033561, 0.10000999761565078, 0.11663267298811868, 0.18837619422664567, 0.10610101714489922, 0.2050683154694496, 0.29238242055139235, 0.08780257040334326, 0.187837619094118, 0.20682543005433776, 0.15871567531458794, 0.16497780058172443, 0.08241099680984214, 0.081503473732981, 0.1998668695769964, 0.11435297918656182, 0.19948762541096057, 0.09269153669236169, 0.20234217626913903, 0.12430591689002131, 0.1361659691939431, 0.058525260162329486, 0.16774578350445918, 0.07487649143102669, 0.161019638781586, 0.12584504115605546, 0.12167540844529869, 0.21021788188767052, 0.11649589565011764, 0.15325676259254256, 0.14869057212866124, 0.1524921608788352, 0.08724044572802321, 0.07245722407054517, 0.11098645176858672, 0.11241820881203299, 0.13071977353144076, 0.10337321553379299, 0.14657413166376854, 0.19272087802810056, 0.2509710168646228, 0.19790887141660338, 0.11610243289220719, 0.19589217559945202, 0.10386846073332334, 0.13057427811286143, 0.10296011794238322, 0.06361977933275123, 0.18270142857105504, 0.14585092934148927, 0.10294861130176053, 0.1098081089496132, 0.12390790356984063, 0.14282494332761536, 0.08945178150409654, 0.2692205795357304, 0.144020454176972, 0.14680049532363493, 0.3415922009416165, 0.16145551216698464, 0.09180242270832101, 0.12666695390737828, 0.1962412971883051, 0.13194453361774647, 0.17978218924855033, 0.15938854566024196, 0.1402607397927392, 0.22333998743805195, 0.15032393287026113, 0.149162482290018, 0.17560446664931315, 0.18893476425399705, 0.12019072238716388, 0.1593486937664209, 0.13501771064775606, 0.14913772232830524, 0.1255421146690365, 0.15873144140406964, 0.15148993401277452, 0.1422738962836804, 0.0959199920837437, 0.14251014247777002, 0.10089085317186772, 0.17768411957208188, 0.17507989560404133, 0.09334988201097136, 0.300137099599646, 0.15416315185927576, 0.1284317753367847, 0.09690639157328876, 0.14691914702134748, 0.11978070446920973, 0.23387150538544502, 0.184786704579188, 0.1129884003931957, 0.16416763195828085, 0.07128221373404227, 0.20873571625880658, 0.08189712801287252, 0.1119132036523473, 0.1658786740154028, 0.24042131198990732, 0.1495800768175433, 0.0647814674002509, 0.16636667202316946, 0.0922746929310022, 0.22603359854509755, 0.09727087322502367, 0.22608996729456612, 0.13883485098279294, 0.21341858191355584, 0.11284948566988592, 0.1327435786445295, 0.10840819818117928, 0.12868987035847482, 0.12141408053256812, 0.17152331709381075, 0.10191521231806087, 0.12680957649624156, 0.13017448746869642, 0.08504509054605039, 0.0841680730903341, 0.22702952816842065, 0.17997723523407214, 0.22160375640997965, 0.16338548683110746, 0.17865357319674185, 0.12501280153951339, 0.152036675642575, 0.1482667569671908, 0.13797735344738732, 0.10178314642079415, 0.09884172119200231, 0.07050004562423115, 0.15165744679829768, 0.12599852687168506, 0.10506017178657556, 0.13413073404902412, 0.11202768783175177], [0.014502076007756255, 0.025630601486491583, 0.015914212581851793, 0.024171987315639857, 0.04914844739100626, 0.005404101046282919, 0.010039950927509176, 0.04867959775090699, 0.023078360414553075, 0.018567527464080243, 0.1362717965798032, 0.027926381219238527, 0.03674901556223631, 0.032579727591045445, 0.01144230264359184, 0.05047730350446317, 0.06098380102024925, 0.027521921269175027, 0.0554634518771162, 0.07383339377420564, 0.013426131373571773, 0.03576513650196214, 0.020314801649581042, 0.023323694326644464, 0.053525176650333794, 0.01741607624646877, 0.047212416801841996, 0.0488939912869565, 0.07073662889700744, 0.020872682197800568, 0.01988944282094317, 0.06175730850607638, 0.03265949649616115, 0.04766861833031139, 0.02392631440964197, 0.007955529586216736, 0.007485903803289178, 0.05372106533257231, 0.059098581212662885, 0.024516027826335163, 0.022528230760907455, 0.04484746890563158, 0.012289594930236139, 0.011660016213183202, 0.026380917575630932, 0.026097677633046143, 0.018053869341289806, 0.0032290117627370263, 0.02933095937835113, 0.09606737207861678, 0.010965214685476836, 0.03905261130703073, 0.033421075993007233, 0.03374816872359764, 0.009206658897681103, 0.02938234089543262, 0.1304916785128655, 0.008102248351450169, 0.06914321197977952, 0.003919296244519853, 0.01412851621411861, 0.01867682522823734, 0.039991233723178025, 0.011087275474452445, 0.051465484148432175, 0.028142653585922335, 0.021842421190212333, 0.06128826734399604, 0.07438749750895847, 0.0380304393418614, 0.039794146113338015, 0.011622675172533962, 0.058465551269511064, 0.028893459971333225, 0.062421207962137085, 0.12884728610515594, 0.02680493958084093, 0.038117187307967294, 0.05322389342191239, 0.012841444451271767, 0.07429185143161206, 0.031154756171388492, 0.1016660881859641, 0.033913498158536615, 0.0306511280547467, 0.029041619460669257, 0.02488135217478679, 0.030542814713572303, 0.02589679788798094, 0.047142607039741935, 0.07150830926313516, 0.059898407649128675, 0.09956358286041407, 0.0391329471172104, 0.062489014404315146, 0.04356327571816022, 0.0416716743981646, 0.0403338359037955, 0.00995926175927443, 0.06614135773552042, 0.026454900601698507, 0.02834737909236743, 0.05146920350530455, 0.06393031690329795, 0.017044119491812684, 0.027595779805954908, 0.03752381007577624, 0.11476901089472157, 0.03838312707000202, 0.026791540703045267, 0.02677650239709164, 0.06721303047191712, 0.02823154085255679, 0.057737434493197556, 0.07957971204192409, 0.038253524145411874, 0.03620225094979809, 0.030564766963042563, 0.01946112497769777, 0.020995419059369354, 0.03517303863660463, 0.011507878812300342, 0.03631310387244148, 0.036955909097507116, 0.08045289139713972, 0.05703190964977107, 0.029724600251703977, 0.07354248720671862, 0.07863216087101929, 0.02181988288348, 0.006506169757490317, 0.028308253066854614, 0.0548779078939509, 0.03125509645249094, 0.03545546844120949, 0.02701243832557192, 0.03142195423283885, 0.04825807702276976, 0.029509174412176497, 0.020394944022559834, 0.06060433085827578, 0.05779238214956657, 0.010842354292230261, 0.04647920937127164, 0.029188449787456664, 0.044638997229236754, 0.039573995426537535, 0.030889078794467836, 0.030863156294329997, 0.021022850752718026, 0.04305036453109595, 0.046244188917860876, 0.05582974149635243, 0.04640991288808085, 0.013766544457945614, 0.03778369391276952, 0.03362831809828359, 0.023044083725600954, 0.014058199876378623, 0.00030354214041219697, 0.019798642249717828, 0.010548906228054437, 0.03476657536661914, 0.044968434188875465, 0.011443776405236174, 0.0007354277089865308, 0.035866758065117944, 0.06195672119276659, 0.047096055707023035, 0.047904581071869026, 0.008749795660767104, 0.04695561646874394, 0.022597226554587967, 0.028729517155537204, 0.028951154052910787, 0.08960212625923658, 0.04400885926799909, 0.02495096658446616, 0.03638858651562083, 0.040537251399890076, 0.03210358479390702, 0.03883973462507129, 0.02857575564825487, 0.024953044597960772, 0.01599499559585726, 0.007514263899441088, 0.06074188194508034, 0.0691773411968062, 0.05966333356956321, 0.020211793467282288, 0.09950271717482999, 0.03596063447935927, 0.046050832156212106, 0.020380915037446448, 0.02412417959872513, 0.06131411132012164, 0.04004670614977518, 0.02782410273568765, 0.018145851603138353, 0.06937597247381365, 0.04343792075111021, 0.029817729730219133, 0.056570946884852265, 0.06909662617310401, 0.0353999002536218, 0.057940045596971634, 0.055742943734531446, 0.027933613089243733, 0.041081246604482015, 0.040598358403170304, 0.019239285067024253, 0.02404436472833397, 0.04116704845200143, 0.02694959421792338, 0.03200044446144133, 0.04013876310519634, 0.027328223598399953, 0.08622204674588096, 0.04311579610070875, 0.034921497497106754, 0.050871459571945096, 0.06400609449032815, 0.11616180470633893, 0.050984737162868825, 0.0031202734821671324, 0.0772514789094848, 0.012394709854326662, 0.04030626056896102, 0.014680094731551026, 0.040393537135734674, 0.012778209638781847, 0.0012094456295955987, 0.07834739066780576, 0.019432544152462677, 0.06308740951241025, 0.021032018909951853, 0.0063286959137316915, 0.029390762116940274, 0.017541423552639542, 0.010849244295499258, 0.09604474950221278, 0.06610486896768694, 0.038479320900214296, 0.05584939931248946, 0.03962929931379134, 0.007186479774499013, 0.012342049928021528, 0.023430933229505055, 0.022964900877747326, 0.014258734881877901, 0.04542897943587554, 0.04812979943028862, 0.09454982084853035, 0.07074415954130311, 0.04515637470889957, 0.027364329322271293, 0.031213229747429013, 0.027927932547285195, 0.06561281069392158, 0.04585976599745693, 0.06160753448643993, 0.0566511677818433, 0.047616861430147005, 0.037427838411061995, 0.03911361488844118, 0.041901837854135426, 0.05826069935855847, 0.06378579824682205, 0.010596174810592447, 0.05600749687742322, 0.07476871818183892, 0.008317106328303776, 0.06289308747997688, 0.03289038773566004, 0.013355920372921373, 0.0373759551063901, 0.031203573209143458, 0.04794054123903475, 0.014756260150592896, 0.058397775470849976, 0.02106595085933805, 0.024629824441827597, 0.0970552501178557, 0.08449900009098553, 0.050935148291530154, 0.03641087584377777, 0.03400575046637847, 0.06045858646112104, 0.009655422670015646, 0.024458479301463214, 0.05716119464787264, 0.027728460488780856, 0.0884462374773237, 0.010424876593113428, 0.029206958471707282, 0.07911765377127356, 0.01858161007534833, 0.05969761217373514, 0.02300778647974855, 0.01632973101110228, 0.021435203323621425, 0.007720745662452594, 0.04846972796405035, 0.0837381445472279, 0.059056791116393385, 0.030334670539765112, 0.015341823285956298, 0.02610760613254482, 0.08013150985202483, 0.010509480470641246, 0.05037583515889222, 0.06619296907897919, 0.06530434539121005, 0.07835224766524569, 0.028642399552007838, 0.03688736721092174, 0.026275300863950003, 0.020737191887512323, 0.024267259925123186, 0.039457082748413086, 0.05953665327040419, 0.026668821078454776, 0.013886803025079351, 0.039165310501571626, 0.036807920062734235, 0.04435945940654605, 0.038311022874568744, 0.03912450865872445, 0.03854078796481894, 0.02158003607614627, 0.06740383999121767, 0.011742050823334967, 0.02708498493678147, 0.02063821715813491, 0.04046000292404525, 0.021240371842718413, 0.015352278470902916, 0.03085448034858752, 0.03110066653349467, 0.0566211907613662, 0.03626973563504796, 0.010230767150079052, 0.07020211403047846, 0.06597494811660821, 0.03306335889764371, 0.028721000173039017, 0.0032078837759928, 0.047314360121926, 0.032135193581662835, 0.027266607146650076, 0.07522595775944572, 0.05642209217072495, 0.13721488145810945, 0.06745005041481027, 0.2178740113853447, 0.1573840766063621, 0.1983676355091795, 0.09659988745566338, 0.10237154025103777, 0.1155828950445979, 0.1033329499524928, 0.09842684627660821, 0.22447966579948703, 0.15061703811009086, 0.1460618180252852, 0.19333788524231604, 0.14968346804380417, 0.1416451066371895, 0.18609049429576244, 0.15036968364109918, 0.11168064234117347, 0.13283563176951102, 0.11847377379214573, 0.18573349732304775, 0.17402525300220137, 0.19313265028740131, 0.19750954042519295, 0.1284276920881483, 0.12510581227440026, 0.18170624971389773, 0.18925100534914002, 0.13003934955885335, 0.09116423316299917, 0.17326605986923943, 0.15194891260996943, 0.11523117641768149, 0.16692354133532894, 0.0938130357873536, 0.11370103070211988, 0.11473918709182933, 0.1694486590643083, 0.13326769003704672, 0.12048797216266395, 0.2348837526815553, 0.2035129578002999, 0.1463450407308917, 0.1491517417373196, 0.17927071830678373, 0.2052972225412246, 0.0984272369814496, 0.0765534655581559, 0.2772594159168582, 0.05909080925067106, 0.13096679092174576, 0.13177726598035905, 0.11889959610397778, 0.08009718911301705, 0.11871841630988544, 0.1997508991870188, 0.11653066838100073, 0.16843777540470325, 0.06746399321503217, 0.09331115626639898, 0.1442816288721177, 0.15416975553718307, 0.12244086817748125, 0.14946076628421584, 0.15630285075354963, 0.22054862351186816, 0.13760538711663217, 0.16076830065538808, 0.11323714914220957, 0.12217822259352093, 0.14846667527191101, 0.13188278693104946, 0.07224184611151296, 0.14901637400109924, 0.2018523396503541, 0.20542042480120737, 0.15338315177829037, 0.15491557277498708, 0.1094142095215859, 0.16661319911720293, 0.07940103735534415, 0.18386459518824855, 0.17119058978653726, 0.12228758164471197, 0.29961628238520316, 0.10875054755278173, 0.11506940929159043, 0.10095099873480298, 0.17939612689998843, 0.15357056752808634, 0.09785453263189524, 0.22870392057924505, 0.1841990691759894, 0.19148409036138367, 0.15552311114245848, 0.15120163980510928, 0.11181735839214056, 0.0951033576782192, 0.11964431783605008, 0.17287515584499608, 0.15038197169140463, 0.17202306689033586, 0.14388669522539263, 0.08862609960018628, 0.1499929675652135, 0.24522457602283648, 0.3114771620640832, 0.07295095241598545, 0.2229381130347329, 0.12199777058295666, 0.20809785613129217, 0.15255151737120845, 0.10390291936815747, 0.16812858231846364, 0.14684785487911395, 0.10165186959408945, 0.11385469261797206, 0.11872190200994093, 0.1827233080421725, 0.07858550611643061, 0.16489671783581858, 0.07922043978807428, 0.20539733491116957, 0.17528920614671323, 0.10695866023701046, 0.11956134285297125, 0.18816190411246594, 0.1652336739484341, 0.1474950612793046, 0.05473145869590583, 0.09021161815091487, 0.11414482543665556, 0.16005536391129419, 0.1599930503195332, 0.11886592653970565, 0.1731725818207187, 0.1804593650083388, 0.12710312606706736, 0.04944238000579419, 0.19167594942114047, 0.13936012682895507, 0.12069955032559172, 0.08321707452377004, 0.14025621987398595, 0.16023493492074553, 0.11888496382462403, 0.11061063201557245, 0.11309797394900553, 0.09668138388904834, 0.10718799631802306, 0.11499143686265716, 0.20007636398077014, 0.12235468328599969, 0.14210209340578125, 0.11644760912825024, 0.07266169293753563, 0.08998112527713661, 0.08074085618699751, 0.18369623970600868, 0.0725430642224608, 0.10044298284957487, 0.15194443865649163, 0.11772947340843179, 0.14700193048244523, 0.06223136371362114, 0.14247361540554032, 0.1576809356770208, 0.17626739317371, 0.15547688539710738, 0.0487267236495691, 0.12158559995793528, 0.06733260147513882, 0.13258996269395276, 0.174970559535488, 0.14911579689191234], [0.0668499814046006, 0.043591571175643516, 0.045460036640325864, 0.042495862430622505, 0.033452765219995094, 0.05495072455115377, 0.03757975747688644, 0.038008452618434545, 0.03301854658451292, 0.020923178883329518, 0.06072871289366196, 0.005922463906538343, 0.034817217608853694, 0.06584882706163392, 0.025139906849231453, 0.041222187630351514, 0.08003111402954786, 0.03603279613138687, 0.05334523408823917, 0.06154161262055559, 0.03743586701250846, 0.057953061430805156, 0.017735360625890956, 0.006518525798099056, 0.04873655255763762, 0.04215203450932618, 0.022399909118370667, 0.04149441697424458, 0.0746831461606968, 0.036446054601260734, 0.06795145496125184, 0.013330229614380629, 0.007110322495141337, 0.03408466901389822, 0.020867212330021208, 0.06893393974150382, 0.03534213339369144, 0.0062035238501736, 0.06621018307463777, 0.052749432187767765, 0.023514109310664, 0.044033324285860986, 0.025185448861110116, 0.07889890502537451, 0.050927912591085325, 0.0873367123365883, 0.017856959846892187, 0.04786922611416348, 0.05035187192862073, 0.05621951554090746, 0.04583146287909439, 0.03256626359577621, 0.009127062362348361, 0.027598635398692666, 0.06646437870879328, 0.031946352908327695, 0.019603931427662893, 0.03281950545046599, 0.020087359720961224, 0.09121982050278495, 0.003939852298748109, 0.0715048618674759, 0.06094865673672288, 0.07999736019560406, 0.005652599859111492, 0.021261784000202053, 0.026771101477225463, 0.041523650889435125, 0.10075330208506315, 0.02321421270138554, 0.010803324027707981, 0.059151560023066506, 0.08612750383514552, 0.0466361616347586, 0.05615402268426073, 0.010164610669767905, 0.027775040549796917, 0.020385452193177996, 0.060219076732473995, 0.05100127700115404, 0.01916302292938194, 0.1162467945006586, 0.033803621997996684, 0.031219764477423126, 0.03934548289004353, 0.04182538994017147, 0.029949728594792467, 0.017992038384921128, 0.012701678412756132, 0.038631971580006426, 0.08119413509003578, 0.09380060984122177, 0.053975050292548635, 0.09015743275203052, 0.011587001330729936, 0.11898679989239863, 0.03773502434693998, 0.057792853293640006, 0.004151096734623876, 0.041126591348720175, 0.041690267352086884, 0.05153072802650352, 0.043656596718656446, 0.03001542637995895, 0.06869751734719162, 0.053267974121075486, 0.01960667976809125, 0.021672073879369327, 0.07215849574535124, 0.15933053748261544, 0.1321448809317043, 0.10451165283279074, 0.0807510911216659, 0.05285910916544738, 0.0223898925187607, 0.05520395491452468, 0.02583810214644238, 0.014568895154121905, 0.009518874200781988, 0.02335864517296995, 0.007774200883784122, 0.03728772859059034, 0.016396861380687165, 0.03256345588353372, 0.07461795207834052, 0.0315867071866148, 0.018203036236246268, 0.009612255530702251, 0.014289968286550814, 0.045553120153565566, 0.04527156368919438, 0.01761917764651439, 0.07315965774919718, 0.02985628693544817, 0.029357900775428263, 0.0300016004081455, 0.044887451034399777, 0.02004659809773007, 0.030408975322760885, 0.047523084607335835, 0.022774173712898648, 0.010190403892568523, 0.04379918100312353, 0.008571516467078079, 0.009156563450702497, 0.0182764025615348, 0.03074077183320638, 0.03604058341513719, 0.022006750880410115, 0.057074860369245854, 0.01987514378983648, 0.03075180924497545, 0.06342885873070167, 0.013050714774327654, 0.021029048404025457, 0.06779336505719731, 0.05190874262142086, 0.016985824031214562, 0.026111359963373795, 0.010125295995103737, 0.05268581624653551, 0.0196770966548713, 0.019914220019634214, 0.03947138560995941, 0.03208931832153711, 0.04960893518141201, 0.04327563651567025, 0.03705729700384602, 0.06450977431790483, 0.014429960321004113, 0.03928504621369704, 0.05426874158964042, 0.05553574376409093, 0.08734712347147927, 0.0761465196527781, 0.0506158696577674, 0.023553152981724952, 0.017696054569715937, 0.036789369243647785, 0.04097930711483763, 0.08063813911810999, 0.03494653708091186, 0.03967076765313264, 0.036864200712091504, 0.02726654202917651, 0.03581268757942223, 0.0793714280570707, 0.018705679929905364, 0.014995847445642276, 0.011381444618886998, 0.010404884571119422, 0.04630476732047335, 0.008492599834778137, 0.04790220236886413, 0.02782024931342852, 0.0428348716588751, 0.037753632622620756, 0.01832138915966836, 0.04719976102933288, 0.03567363112984646, 0.10342829725554875, 0.03801192682717116, 0.062463752655012, 0.031121596055586013, 0.04971767370138438, 0.021738773324496804, 0.05485836499100251, 0.008100337919688994, 0.0576344263108988, 0.00800134547452833, 0.026313017287682143, 0.0023717239439006777, 0.03004069387492153, 0.020389077704279654, 0.027285232659309145, 0.052788996798617226, 0.03862161790170977, 0.06032262883719899, 0.04598329001436791, 0.03682028855227175, 0.01073274434724402, 0.06323532576883031, 0.04824616052510758, 0.007382377075226678, 0.05844400121620106, 0.04192140757016117, 0.015602570887084211, 0.08378340502179439, 0.030855296232226877, 0.015432791438915077, 0.022733956012093735, 0.01227987327447702, 0.022728080117714503, 0.05530485252459204, 0.04176024565353029, 0.03720132153361075, 0.02711576826479887, 0.0505480747069082, 0.11752661332608232, 0.033909843919137796, 0.02954045378212487, 0.028305726891924298, 0.04721988232866411, 0.06111604311773854, 0.019123617281776764, 0.032315867757725145, 0.011246433113551429, 0.010458594037880822, 0.07530094244547429, 0.04128465060925773, 0.04332523304788817, 0.016031782180371306, 0.06600063504470934, 0.01379171619191766, 0.05572832677693618, 0.07068346239506237, 0.009936340408579958, 0.09136551510422461, 0.010505184632605843, 0.06222790865708263, 0.028177684871479872, 0.05200156949520592, 0.011168826491602007, 0.019760709406147083, 0.04825938320268066, 0.01934883755541617, 0.02612645189548212, 0.010378907487216977, 0.03892796114087105, 0.02681047073565424, 0.01825072903997235, 0.006463604476002436, 0.008633767814195205, 0.023856642543368285, 0.023992508236739426, 0.02334105196378885, 0.06271268143468807, 0.023301161765571565, 0.015844060953015524, 0.010527738261096662, 0.025712626520544294, 0.03833611991496817, 0.02275732552422391, 0.005539270557252871, 0.018533878967226036, 0.07246709894388914, 0.08880428399049467, 0.028497492105910377, 0.06869468282187177, 0.06543993529292845, 0.017944719049058134, 0.07376928753670185, 0.036118115343513994, 0.03320131218060851, 0.029249213966390783, 0.025395429730715773, 0.038669494566537684, 0.04090644449235932, 0.0066351387443231245, 0.038161861725271716, 0.05389276861904129, 0.03791123606084335, 0.022780551394868283, 0.04653274359542035, 0.04680908300102719, 0.033769420002617186, 0.06017246028228153, 0.08077161461715737, 0.03729882154373392, 0.0838673989018125, 0.02933707659042651, 0.03468279982165944, 0.037922440096735954, 0.021395594662716313, 0.04241350031788311, 0.042547270760781346, 0.021566393965434645, 0.04674532150308933, 0.048868419272044016, 0.07907489840421947, 0.013141119852662088, 0.07463490560410485, 0.04064868654935591, 0.038390810931882555, 0.02381319961240215, 0.040076246500135436, 0.01691212637289878, 0.03320437270186601, 0.03154036461285526, 0.045168865772504965, 0.0882902619759402, 0.017427722698137645, 0.044392519930918375, 0.041616811011467254, 0.02212691943221275, 0.03511880344200519, 0.019905268282238996, 0.03863859824055145, 0.011426219585231476, 0.017674665394870025, 0.05703360270408373, 0.01574552480897476, 0.012294644407267052, 0.06973313798587169, 0.019902717209451144, 0.01924067360138701, 0.07873729111686831, 0.027197802874950633, 0.044476452523902546, 0.0749674107458803, 0.04139412074319778, 0.09114182509121396, 0.1924510158958935, 0.09649916221537898, 0.23287523868343524, 0.07070811510446572, 0.1221614299462207, 0.17585709180322387, 0.08224610404502, 0.15492810597342832, 0.18645415623341838, 0.08048391795807308, 0.13251782785500252, 0.1257436724019147, 0.1947890243102466, 0.25200192606256855, 0.09248720572119759, 0.10822383912220117, 0.10276937737099587, 0.12503468101063084, 0.1895419195775063, 0.14174108213234332, 0.144988268373474, 0.08356723033132092, 0.11860095970933476, 0.11422715690587798, 0.17070591660036197, 0.14538784451302023, 0.14023981027064786, 0.11900495617620407, 0.11309978191650684, 0.12008751502200482, 0.18672443205310454, 0.17976190324031538, 0.14495112843090488, 0.09863447908672596, 0.08076347110252227, 0.11570981283101345, 0.1278220995840046, 0.11742738195725026, 0.11307908222079278, 0.181052225131181, 0.16656910309628134, 0.19202125589213065, 0.11734367919064338, 0.1609324426540444, 0.14912698177560685, 0.19383308447657094, 0.11748897542636241, 0.11144881647440696, 0.21098548666604106, 0.26650948630225274, 0.17222693820874538, 0.16008628321991814, 0.12036458604157933, 0.1141783724268598, 0.12704630532572347, 0.11527118918996666, 0.13751075993622505, 0.17423813351460044, 0.0987630439621787, 0.15339384636571332, 0.17692190805269828, 0.25741268249769367, 0.37643688280255566, 0.16617712654894398, 0.11931700677040125, 0.13655380886648932, 0.12358171099256124, 0.10412590458027779, 0.23487888036235688, 0.13029145377297557, 0.1228447650529204, 0.174957811832428, 0.18457216931687248, 0.11255051985743547, 0.11777884011427242, 0.11167148759047832, 0.1390371901253539, 0.07650432867869254, 0.19630436154623188, 0.13974822697139558, 0.12955073868074726, 0.2635809466723473, 0.15993649770896282, 0.1877960051980711, 0.12188186148001302, 0.2338046871966893, 0.14536719078258162, 0.11402364564879287, 0.12087339099736945, 0.1408679410815239, 0.20151129262822293, 0.10962501393571016, 0.21953652943334273, 0.1744204317970622, 0.11259492997440601, 0.27955158162982235, 0.15019533735129142, 0.10050111360126927, 0.16133025679136478, 0.10097010496763453, 0.1071427051999396, 0.12800373136997223, 0.15807950058050696, 0.12471061815778095, 0.24969788598677806, 0.10588728627490421, 0.10089191803408247, 0.10178992629892404, 0.11254170984630624, 0.2491691167796812, 0.2662971573731592, 0.16302654399506508, 0.17746302659713453, 0.14129705757143038, 0.07682328938596672, 0.18609314495998044, 0.13651907444000244, 0.09360213944267842, 0.06810690952284683, 0.13484197007792612, 0.1722852681433001, 0.11448501444031155, 0.1406763884569368, 0.12304629214228162, 0.16490581896035902, 0.14184180737262772, 0.19359141437997743, 0.11131208510168138, 0.14838710938009525, 0.19804548021526108, 0.17812431369337345, 0.10142547529070609, 0.16050853556202305, 0.20954813718074755, 0.10698466892203978, 0.1088683795364153, 0.09254708315335936, 0.07977962268576508, 0.1183710030971035, 0.12304920327639389, 0.1804947582704406, 0.1018522935168397, 0.18715220022826426, 0.2196802015626623, 0.20101001065584923, 0.11468988933390188, 0.1682870705882388, 0.1205567975017813, 0.09525269885817844, 0.15536460755092485, 0.17815265894657184, 0.14761786517356673, 0.17818667325040988, 0.17020334760027547, 0.15818839231806417, 0.18982813002601748, 0.16323559406784274, 0.1558315228190153, 0.1309017040916989, 0.13440882396553794, 0.15369543985974404, 0.11957651139387201, 0.12089844973337267, 0.1580721308146754, 0.233724094747055, 0.09827994125624818, 0.11025207222349222, 0.12540870811790228, 0.0933100147953918, 0.11754276245952615, 0.15168176242901435, 0.13153826186974205, 0.1640244654469913, 0.2424839730825155, 0.22772959463538664, 0.20475978121882488], [0.04772223299369217, 0.02620577263916212, 0.03338666332344855, 0.010939043206763605, 0.03894703673018564, 0.11177460302508647, 0.05573298842195542, 0.039654695128481236, 0.023161879320058133, 0.020740196867395314, 0.024293643993235404, 0.025862063461494063, 0.02910048565677097, 0.04266178558370279, 0.0576681265186879, 0.03374133138887344, 0.05138189246457431, 0.13309890554556925, 0.039168964740970445, 0.03131926972268811, 0.00838210984628888, 0.044240432325750596, 0.02274036433758034, 0.053799600836129925, 0.07757337373350898, 0.028487052242722244, 0.027333883072940574, 0.014013129008573391, 0.06051056169634385, 0.01621632701567104, 0.048928583987177386, 0.05608278416818189, 0.04227074749407269, 0.01630987975776436, 0.03492789816171412, 0.04614059084786042, 0.03645854566486613, 0.009454543882560347, 0.01118435126338755, 0.04828728412488296, 0.041804904749076215, 0.045318107361034046, 0.09820497955285734, 0.04266179707502166, 0.03483439713055569, 0.03562362857102867, 0.025165838925468347, 0.026585087668330922, 0.010530118879321362, 0.0312504539596698, 0.07642248750574167, 0.008776109823356233, 0.04129553288822213, 0.03575918016835086, 0.008724974412020416, 0.05540368552770346, 0.03819744267891492, 0.003877693360986849, 0.019643674153954755, 0.08738329814326379, 0.018948296145085367, 0.039587244917187965, 0.018854417815624226, 0.04223066577387433, 0.11346823956456878, 0.009028001448079463, 0.09320575022889722, 0.013153830208935806, 0.0632967468681595, 0.00982935431473438, 0.09959388163781936, 0.061666933113649014, 0.041635005599668914, 0.057321517698226444, 0.1065675034037521, 0.026512173334917715, 0.05737506341369403, 0.04796815487826544, 0.027306727171244643, 0.04275945796360893, 0.03956706616126242, 0.08735466177665419, 0.017276125389241406, 0.03990869541021605, 0.02061659432647209, 0.021873200687790112, 0.03716326994641173, 0.047561664795202595, 0.05588242153246557, 0.03471178858871422, 0.061694044965289296, 0.07421125898197775, 0.05941623574002616, 0.017112104049433145, 0.02777111626440479, 0.05970290201085229, 0.02241851930927125, 0.0819786474288952, 0.03290524601095146, 0.025819105081140034, 0.047526087671999014, 0.031108294854000695, 0.01842466547274061, 0.02611290937620065, 0.01934392501660172, 0.04608981454023912, 0.04516744467940542, 0.04771965127738734, 0.0661710283208278, 0.028255438965354717, 0.02693833655587608, 0.048153065520549015, 0.045018099669006564, 0.030858856625854972, 0.10915125750245587, 0.056921232927350275, 0.04110290391010143, 0.02200651722359321, 0.05275143167725014, 0.08001115743912036, 0.06260723326235049, 0.00750133520810895, 0.03268752765331057, 0.04594108240017968, 0.023091985288286404, 0.03625982245730777, 0.03463219971426072, 0.07852904543641114, 0.09572885314663572, 0.01937527524968309, 0.08878462617435763, 0.06519229737140479, 0.07385432329629699, 0.025867998727687427, 0.0321408434801044, 0.038381093106563055, 0.057636291734994426, 0.056532431814459064, 0.06476796893102509, 0.05263115970357772, 0.027593230648386865, 0.032805585632881815, 0.018416104440186775, 0.15474421422808401, 0.10322426505867513, 0.0662491156629497, 0.05546501469648173, 0.029016097241471854, 0.01101780470625888, 0.06735767553290052, 0.022107682964434067, 0.013764342912773212, 0.017465441037089597, 0.04391773693984555, 0.01969310789248876, 0.007323900147551491, 0.04708520790201522, 0.03896885874470876, 0.04182018054228637, 0.0503895404718576, 0.06044812936095461, 0.07621968104954689, 0.013718488720065404, 0.021722166453518217, 0.005219063999491834, 0.05351578441238212, 0.09222585482582932, 0.06522025191976179, 0.08019580761150968, 0.1087684586884514, 0.03570122178643942, 0.04230728222718162, 0.008115082239401678, 0.01791712264680574, 0.059403917046203736, 0.029493280002967488, 0.0277145445016363, 0.027235007934993314, 0.025981299301248886, 0.05146817694748602, 0.07918932895746925, 0.037748013367696155, 0.017364376802898703, 0.018894777242695133, 0.024503253310197787, 0.05654052170293947, 0.04806910228404788, 0.07072178977391413, 0.029340813184277188, 0.03682542134136443, 0.03641926450654864, 0.03645759571584002, 0.008388509553286337, 0.04457968287169934, 0.030186484237351728, 0.10600966115992878, 0.025481522691646413, 0.04885131252869483, 0.055595866344388456, 0.05125374127660067, 0.03062469036047978, 0.018467692801007823, 0.017494854982942343, 0.08530972795861383, 0.06580030305250999, 0.038896103374539845, 0.04529417477427952, 0.04600043889255293, 0.028591634735705394, 0.043813434068954764, 0.09560137611603546, 0.10945429124178425, 0.08594394916848791, 0.036833664447429686, 0.030799624622769417, 0.07431288054513355, 0.030799484811723236, 0.041678871794213215, 0.01907840660292535, 0.014065935449194045, 0.07144742059491335, 0.028907253384409897, 0.02409480970292803, 0.026393877868089947, 0.02226578435980745, 0.031958886106768926, 0.02370317981037642, 0.02528053760949162, 0.023607259856597073, 0.10158901974078148, 0.02169453940774885, 0.04409814681557398, 0.04131991746685198, 0.03495758789921961, 0.024986357931348107, 0.08470526926459805, 0.04693235037848354, 0.03330022945339161, 0.010283202038056428, 0.0307310750753048, 0.0978380770632817, 0.03504885195363914, 0.02017469565954901, 0.08174102993742113, 0.028874137318663062, 0.016319178149945313, 0.04129908753619079, 0.06556921263015078, 0.00890470821515567, 0.057603767472169096, 0.008063307144649087, 0.03950116344757619, 0.012644758079982093, 0.039074896804748044, 0.08051693634760958, 0.025045105383821556, 0.04590316870880704, 0.08681721279337522, 0.08012197971824678, 0.02381918275909078, 0.02311989004092832, 0.06886166700672719, 0.016214804415921533, 0.022664548446153922, 0.06394696399389256, 0.026382466988457788, 0.03218258761109845, 0.02530370602354167, 0.02920687037159599, 0.01224936382289255, 0.04062309921268494, 0.04744233894011667, 0.04190589812013411, 0.055364174543008696, 0.014191132410609675, 0.07589161155685302, 0.05896218308818437, 0.0344207402949612, 0.02123923611737067, 0.06712827816485398, 0.017407452011661186, 0.06701505036964532, 0.04827658187658076, 0.14826171610864902, 0.0366004481310806, 0.060012692645672834, 0.045454164576386256, 0.04729012110000176, 0.04272325264830743, 0.03276361933638973, 0.07484302104961488, 0.03943364811880935, 0.05404613559104262, 0.03940702273300098, 0.023498348966841737, 0.01620460587042955, 0.038529388576505647, 0.0043208441028611795, 0.03788759075706044, 0.05963191247334885, 0.04777997687098481, 0.026152303532486963, 0.04893258679658175, 0.05088947029904493, 0.08401016704738141, 0.007670211630137338, 0.1102905681416873, 0.024766312581637216, 0.10649631851382795, 0.04457339712028061, 0.008501727772395938, 0.02299085785184176, 0.08240799374517896, 0.017323751160274112, 0.047026184657889034, 0.055479884463092016, 0.0048316533361831985, 0.0446472211831039, 0.05356217869707654, 0.06314347565714871, 0.04588710384503488, 0.026071236108339606, 0.07477430296280692, 0.02331810188479722, 0.047780854041658105, 0.02892540583777572, 0.005558291083997897, 0.01621305582023436, 0.04334171159913944, 0.12073698138157207, 0.06664946555129944, 0.06082387250517646, 0.006496929779513589, 0.06963840355315516, 0.06506059919634173, 0.054954409434069554, 0.03558302208060219, 0.021082687965263764, 0.019655314859964197, 0.04555586657877411, 0.03726437823065827, 0.06452387799659083, 0.04749688823076506, 0.05273354735465781, 0.043347679424069585, 0.0675507833159739, 0.05862208218463968, 0.04723956312743887, 0.016868091639011137, 0.06324376039687665, 0.014653098750709286, 0.02256337504443382, 0.11751797951517567, 0.20436412744945098, 0.13753297648602916, 0.0879818196558664, 0.1638353949472789, 0.19732002559448444, 0.16562280064869314, 0.09795251527741071, 0.16171058880225306, 0.08434528454897866, 0.1416686255364649, 0.11819233607140281, 0.23755009105849653, 0.1452750304052907, 0.15442339192715385, 0.0944587866204881, 0.15879997562977577, 0.21440300489625624, 0.13168355810546106, 0.24601242084416652, 0.09514481835668126, 0.0632037514550311, 0.09321958577680974, 0.11234529256339996, 0.15500613968939553, 0.1325986348092556, 0.0957105206626077, 0.2136967331171036, 0.18482457996616442, 0.11630096457778447, 0.17703683656309882, 0.13987918204117206, 0.16965462946363036, 0.22569213783548725, 0.15768835140812784, 0.14105911066214885, 0.19613508675848285, 0.1238056155101907, 0.17835084589258318, 0.13473825709473702, 0.11139120666250107, 0.11315674821455633, 0.18889334954081044, 0.13451262887927795, 0.15700184469742162, 0.10508760539514404, 0.13712786919166967, 0.10936696487929552, 0.09351660572593251, 0.17414759724370896, 0.10085402732534755, 0.13778881920922187, 0.09218004276795734, 0.18529857388667523, 0.11938536479588478, 0.23741769574342236, 0.09610670303264934, 0.07609699206847338, 0.07696002841957154, 0.13524651046722166, 0.14970888684113182, 0.12435499248245072, 0.09377132229987653, 0.07670723472631748, 0.14308447859460308, 0.17766748014236652, 0.1657274789026668, 0.10235544474374864, 0.18850443734517022, 0.13942052520090534, 0.15239977067516697, 0.13340553989814175, 0.10519969171934551, 0.14279302810468983, 0.21726972123067226, 0.14224742028501727, 0.12352703529740534, 0.19874078161533804, 0.16653003261214303, 0.12273815625737752, 0.14771560267094644, 0.18786340561364928, 0.24885264585816094, 0.07091252268442223, 0.1250669256513638, 0.06879690959448777, 0.14145238955895748, 0.11938185611319159, 0.16244336722358582, 0.09172996611244257, 0.17540152995817124, 0.15326218649504647, 0.28685175603435886, 0.14323783407528556, 0.09618013256019163, 0.12900977335389585, 0.17739558021628088, 0.1451791928059632, 0.0901117202855887, 0.21595249433190594, 0.18565232264659098, 0.14629408056216855, 0.10930241431079565, 0.12748156584078266, 0.12963600426671967, 0.20317937247455123, 0.13517230719087586, 0.2233233173648196, 0.15481956663631624, 0.15474566979514015, 0.1528626716425342, 0.13533651047656614, 0.12189848558796991, 0.15245177272346713, 0.25377129805424525, 0.138421653799953, 0.06646250945425804, 0.11312589019296632, 0.12287343206304698, 0.11937836275225687, 0.19502257387484276, 0.06545351037094671, 0.09038786433877484, 0.23562636767183584, 0.11035508806667021, 0.150552456898074, 0.13364811397848592, 0.17652118278126563, 0.13037694918532527, 0.11229131400825516, 0.29188982601608005, 0.20343901499384837, 0.13849990202053902, 0.11276589015558844, 0.15446076169610023, 0.2099375549944178, 0.2270103146832797, 0.12272369251736712, 0.16308047658493444, 0.19604471902693474, 0.15541149213189082, 0.21532678435887062, 0.18697907967913538, 0.2968156487951356, 0.20748046587311453, 0.13505647469672466, 0.11439759614727191, 0.09228102081725675, 0.13475322645277749, 0.1922429770591759, 0.12561683122429157, 0.09463572228747992, 0.07945015125216977, 0.18352485051558864, 0.10567933936873752, 0.13781734832352208, 0.10996895677019512, 0.145235285763779, 0.2474456487764274, 0.1449187688769833, 0.12083405238245765, 0.18493013156037177, 0.10564596091787662, 0.11173912549331305, 0.1253739200652607, 0.08854666394331763, 0.24198600060997472, 0.2479328960180283, 0.22302354716004866, 0.19450673623190773, 0.07396819460536204, 0.10583855542204074, 0.08742062960781398, 0.19290455526882605, 0.2923656585476091, 0.15573881085841887], [0.05257140867592347, 0.030892625781557256, 0.03605567151680589, 0.03795486093769151, 0.058153542810149735, 0.04830660869277293, 0.016992806922644377, 0.0633790553547442, 0.06359777345712628, 0.019480855572187615, 0.04299362805942374, 0.057917572407712864, 0.023088585773122408, 0.0734260801466242, 0.021133902858221726, 0.015780163474471098, 0.07700728072274117, 0.0307717198701275, 0.06952992550307704, 0.044925108086317785, 0.04199861008073053, 0.03751951232252102, 0.08415297349734653, 0.015049047463934028, 0.06860103623400773, 0.018018905088425647, 0.03814557086556189, 0.01764488181159381, 0.09427449650942318, 0.020070593886738344, 0.06427452403811679, 0.023037882243853905, 0.03395252267739946, 0.050184152299358006, 0.06276180299239294, 0.06512471309472477, 0.03492896685436849, 0.09245527517651358, 0.05001462470259398, 0.03622905636626867, 0.07397351125555654, 0.018743030546653657, 0.030054703707836812, 0.02366974581814101, 0.050427446502350995, 0.04796876774860486, 0.027829281490055785, 0.030420910972621173, 0.027533772649363648, 0.046518996147619146, 0.05460538743664661, 0.03475494232148894, 0.07859785545377002, 0.03362005967045984, 0.021962319696021658, 0.03785201746429648, 0.06512689644530897, 0.07784513576376824, 0.010116942763899364, 0.04741581314573846, 0.05439649441189343, 0.016208692949505586, 0.050185791727515965, 0.049795546538887486, 0.056786688735648516, 0.02711789415878875, 0.06140080949051246, 0.016165487505795977, 0.0026293722405699234, 0.054411793187741316, 0.05123273131527728, 0.028210944578712507, 0.08461967426081819, 0.03713134706260697, 0.034735276844472654, 0.04629399612425797, 0.032686037612297845, 0.043408671514161175, 0.026561972880435568, 0.04100903132629972, 0.02451823224433728, 0.00866342978101344, 0.049458724491658716, 0.027170708260288643, 0.06023220364905654, 0.053888160600176746, 0.05379019327641976, 0.013729612316725957, 0.08661671226183254, 0.09134106923856082, 0.02043553136078821, 0.04800003179679475, 0.029837810809934334, 0.03872309773859959, 0.07116666469242304, 0.03786060530992766, 0.07747526851392562, 0.05616647544346991, 0.03968519691918646, 0.037503405323913025, 0.04021751311337275, 0.027704776880601724, 0.035115187507002585, 0.016523871097653624, 0.05824659951031209, 0.018758409761733586, 0.017061088339335496, 0.03993476155183969, 0.023083554490679697, 0.03796896078593789, 0.08094787612677583, 0.03648752677104166, 0.022562543839035977, 0.021611547187691735, 0.01416302368705792, 0.014451702853905098, 0.039107394254496025, 0.04651492055986197, 0.08202392322522017, 0.01102767670677314, 0.030165311482344425, 0.01343430265889413, 0.05612811742110118, 0.03786992859996615, 0.052332370091349854, 0.03194340730025884, 0.033875473384414954, 0.039913560068535234, 0.012819443363696338, 0.011969375923546332, 0.03558120262178202, 0.012647215306999223, 0.026299264094221498, 0.06799980277015318, 0.06065073280384945, 0.06218005497489245, 0.023909025720410773, 0.028241668534915776, 0.057970367357014656, 0.05560723125874516, 0.05636653164401651, 0.0029440890601460613, 0.04891647596753413, 0.07743633592561369, 0.055947853102078365, 0.07616705847002807, 0.017012537517134222, 0.0799525517129129, 0.05885913277104978, 0.08251065718791178, 0.022314762276026513, 0.030893219499698574, 0.08625812182623534, 0.016378837247048656, 0.044426300577939525, 0.0478758336225104, 0.022628224387224165, 0.06706597223397225, 0.037644924746165355, 0.02766068085968014, 0.049559219905565825, 0.04623431787495652, 0.11683348761571032, 0.03830418937028416, 0.03370786483790125, 0.04659965754516664, 0.08056286331867019, 0.050635492999947844, 0.025240570802481908, 0.017836103103153648, 0.02139733176708462, 0.04065004252498189, 0.04088148151734664, 0.055134539687705625, 0.035554833875428286, 0.04573273329785274, 0.04660415065084254, 0.014257550318424982, 0.025403814563047022, 0.06023262882785452, 0.06043283441554635, 0.04142698974558904, 0.038105458501846566, 0.03632361842920223, 0.07604354977487557, 0.022152282688165867, 0.07808538093682259, 0.020167052017284498, 0.04109174200904466, 0.060406542277985045, 0.031191195143506895, 0.04390190190245067, 0.04376179974285826, 0.020881132147605383, 0.020867786895964417, 0.056447039823979146, 0.07002350829181171, 0.0071172326082183475, 0.08954872993091423, 0.03324816994849713, 0.055320986336277383, 0.03591903207463122, 0.021142728191109437, 0.005915899490637164, 0.013752657199098219, 0.05237852305834813, 0.03887335822406796, 0.09155568110966876, 0.0036483579981816754, 0.019586529740462863, 0.0357621755721348, 0.015617650370263766, 0.0758218975557435, 0.08869182994408954, 0.028877596205641187, 0.031459636182614395, 0.047317930091653145, 0.03736329550344137, 0.02713996323666746, 0.011161784228358057, 0.01586896455621407, 0.022578212252307325, 0.05291661172504387, 0.002950506243524292, 0.03743729959692686, 0.026172104990109805, 0.03024884954004759, 0.022484820388678103, 0.0169269310220355, 0.06900490246592991, 0.028460934390163714, 0.025342996757958206, 0.012169005030075149, 0.08736917148194007, 0.05484880804414711, 0.08550307322894374, 0.03904055308310255, 0.03698524260412782, 0.043672109999123125, 0.02060776899358438, 0.01955010992054257, 0.021146851659361875, 0.03369281121018914, 0.043844878147806854, 0.0636766153958536, 0.013574436419613421, 0.07010718807578087, 0.02485178884178881, 0.06266935533213039, 0.01801735950603841, 0.02670919965772379, 0.0793082487859553, 0.08206831802043223, 0.056951508722117836, 0.0026548887141078954, 0.022323792537433967, 0.0679778466902433, 0.02939730642303344, 0.08647044309444966, 0.00897892106760053, 0.017199805795004772, 0.03543022967454407, 0.11632735630677593, 0.024552966670824156, 0.10834209245419311, 0.03485850591753279, 0.05384207658109166, 0.06102475608068128, 0.0066195062414232285, 0.05146087996000725, 0.0546512377989148, 0.060607625036350185, 0.08466542503165622, 0.03970940529759373, 0.004361532468934574, 0.021123248490414793, 0.009058434290871506, 0.06832329871793909, 0.013510384765874236, 0.053510758875598835, 0.05735878787574269, 0.054932422710642706, 0.03546766839140365, 0.02490715210085675, 0.03519022198874624, 0.02816580284777428, 0.03653988505022661, 0.05595835233708063, 0.03964399288017904, 0.029970704082159266, 0.03521112469776023, 0.01692076209902523, 0.09113827810412453, 0.0933881710854269, 0.09071355895890344, 0.06542148023483253, 0.01712774181918752, 0.026727970727088473, 0.027850013744506626, 0.03867976014472304, 0.01899219681358626, 0.03214184705528521, 0.028592176742911823, 0.05428346579954509, 0.039890209708603165, 0.047088551875804706, 0.04731187416661171, 0.031582219826598326, 0.05193259859938295, 0.02170306022068666, 0.0176048077522747, 0.024006715337295207, 0.0305565947201103, 0.02230383594700646, 0.057507814959652966, 0.031114459946571343, 0.07976406344002293, 0.012716670753434302, 0.011165513161329493, 0.039454095005508394, 0.03755959404271938, 0.07125768359870681, 0.01909552100715378, 0.01970170722943881, 0.06617947827063261, 0.059116515330970294, 0.04344639368355275, 0.0637947001885022, 0.034746519184761473, 0.04173662716282472, 0.052380457430356936, 0.07811996214572461, 0.015105890230305735, 0.050620849229275226, 0.05771109639036079, 0.026905231981448112, 0.03096714698439164, 0.006516385061155644, 0.040642308867386276, 0.008974254634531756, 0.05277173300724357, 0.022134710546402682, 0.024500403463119463, 0.03432127909975187, 0.05358637941460456, 0.04229542701655338, 0.01950463111091766, 0.01229126691713088, 0.10100336850530679, 0.04434530976258459, 0.021591879795455647, 0.08011904560149678, 0.08689087980817403, 0.103439474478364, 0.08342936514846741, 0.11176842069553752, 0.14250225177214992, 0.09307592130836942, 0.10591236033266592, 0.14201874303961956, 0.19936460701207961, 0.13474795576785842, 0.17986486545733868, 0.12604965557975154, 0.13338830291984544, 0.20182961748251993, 0.09352363075219816, 0.15307523039800508, 0.1444832938573053, 0.10544112432868251, 0.17942867031501186, 0.23514990694820884, 0.21247684534999633, 0.17051799523253597, 0.34020386576171846, 0.08864916650758636, 0.17986088180013243, 0.13067128016583382, 0.13187970725759385, 0.11769232580498343, 0.25078868793864406, 0.1486371758003389, 0.09350960368230458, 0.16952387357671417, 0.11972297208323596, 0.1614443732485656, 0.13881451900928252, 0.13156794011592865, 0.1434815879310331, 0.2849236353030128, 0.1297881340067233, 0.1281636675459243, 0.11384828046204583, 0.15249776864244094, 0.12066535982153109, 0.16067574191237652, 0.14537675155987664, 0.1482341522651334, 0.1850313777404447, 0.16055286140932193, 0.13593795078416027, 0.13763598466832794, 0.1312895897295206, 0.1654970856203187, 0.12184480580711558, 0.1941959956480611, 0.13104782770237616, 0.08042485257911106, 0.1372736097583848, 0.21319724379047272, 0.12275442796488925, 0.16851194803753208, 0.14839196637753518, 0.13687608673447563, 0.2380012249153468, 0.15806448525719105, 0.1946992847707964, 0.09816643766938679, 0.18595635230022092, 0.1402607397927392, 0.18574872715098245, 0.10489855787806934, 0.16191685031498634, 0.09763351626574032, 0.22105914450460867, 0.0795638770045292, 0.1600623812766806, 0.15803289179119373, 0.1504089226645808, 0.09491195827121697, 0.14252583195845928, 0.1359895544667398, 0.09533663145116261, 0.13512315498965402, 0.2773037264423986, 0.14943490315589214, 0.1840229762057143, 0.09912358792198282, 0.19767161398645372, 0.09938431828613244, 0.17956434448640193, 0.238937430324093, 0.16843563035851525, 0.14870571002604502, 0.0973014631158402, 0.15987962334146424, 0.11060303242336358, 0.12106002533748267, 0.22178320484536312, 0.10158791657417052, 0.12508266875820775, 0.19801324323540737, 0.1678494811658898, 0.10276674202853635, 0.19219952455211073, 0.17026458866894248, 0.1146451881035201, 0.14734155258103726, 0.10954285866671032, 0.16057627305628794, 0.1050399011000991, 0.1867025525819871, 0.1739341957915214, 0.1936367821068533, 0.10932257008408347, 0.13746559139220946, 0.12735418840161256, 0.16326490459182572, 0.2131042100729481, 0.2163388171503621, 0.15054444361838604, 0.13575431950871023, 0.1066884916696337, 0.18772676617147463, 0.15462951554406076, 0.13204554997144208, 0.14930171110937673, 0.17485106514105875, 0.15216609853650295, 0.16266822935112063, 0.06535881424262639, 0.18255924265230858, 0.09971032700230999, 0.23454477409681967, 0.12181974707111237, 0.1371694677659581, 0.07791716335040909, 0.10183897124783647, 0.14641788037073228, 0.2146459313770456, 0.1964478651362081, 0.13205774609119664, 0.13963712890061641, 0.13119785836146725, 0.11151871433661831, 0.17753349136440985, 0.1818821741448295, 0.1808655907910678, 0.1482138356133815, 0.1466579570044433, 0.14717082222623212, 0.11128920205538312, 0.07901421657973721, 0.17417126936056923, 0.16601591100615842, 0.12702825629422743, 0.11084798903715228, 0.1765477353887212, 0.121186368557955, 0.1302143393625175, 0.13577897221811358, 0.13873498376098373, 0.11202231755540257, 0.11067129085741698, 0.1967050868176645, 0.11063981230460829, 0.10146176487567926, 0.09886390709828946, 0.17141237224061645, 0.12631142782347818, 0.2339284103964606, 0.11708331654869741, 0.15501360138577802, 0.1169363962065789, 0.1690916774133521, 0.12659915512607944, 0.10561360902483426, 0.11200144932034517], [0.05212145076403695, 0.021241203048116258, 0.03560567147008354, 0.01444276356543865, 0.02434233079604324, 0.07408772730418751, 0.03275971611841552, 0.03347449147352769, 0.011605179639563206, 0.04259841479060631, 0.021790558952958356, 0.039283897081810626, 0.010940199041919363, 0.04037179173000398, 0.0605680029689064, 0.04830360945854937, 0.08728247331154924, 0.049096023994347746, 0.01500599428019937, 0.08585469992530924, 0.05842152419650267, 0.01438939213497384, 0.0056193573888571515, 0.028172266714635397, 0.02097478639634867, 0.012408798211254181, 0.04218041806692078, 0.02632533023584514, 0.01451710856805045, 0.007538594373111283, 0.02160508332083062, 0.05433344154528553, 0.014039198980636656, 0.02824705604824328, 0.03785718472734575, 0.04656569303704366, 0.0640172180869887, 0.026822994357996413, 0.004954584113757817, 0.05773462678095507, 0.03217690706913991, 0.03974216321723596, 0.0737992185919035, 0.11063468717639485, 0.042535572598177585, 0.049199725486217975, 0.06895814811991108, 0.05635875585158506, 0.041874090149517984, 0.0319589703764406, 0.03387718942136534, 0.05711294259996184, 0.015408403987455514, 0.01512117559961494, 0.02750043058767915, 0.0425695983933345, 0.059236339143207, 0.03464575947052048, 0.031181933140502344, 0.08808216185218866, 0.053331034648562634, 0.021550804076175538, 0.04777296716647764, 0.03029052855356807, 0.07360205054283142, 0.06885455771078987, 0.0319997224235727, 0.03757087468740441, 0.04445334348166662, 0.046608367964865706, 0.07205587826789388, 0.03230844819617849, 0.07019918757460772, 0.0365096015945798, 0.03122789075507993, 0.07710816684148966, 0.02988794551891906, 0.055368135217577226, 0.05894377399536391, 0.022329953799564994, 0.039320807198002454, 0.03140420206041346, 0.029893470928072933, 0.035238313158192945, 0.0364765640528452, 0.025540409955166044, 0.028206043531216925, 0.08312978646567754, 0.044966970960940086, 0.050228899495015224, 0.02268923945995348, 0.04575851215650478, 0.06397908223011801, 0.04647994481567894, 0.03048909662832176, 0.05104945244027242, 0.022564064523565675, 0.031525730418281696, 0.046699145553453315, 0.04158517541063409, 0.029320165199498018, 0.04512591505303018, 0.033879223384804306, 0.03984563105228928, 0.028728320143155517, 0.03308857085123178, 0.050700258073066516, 0.08222324398135947, 0.05238666657298323, 0.03152704617429165, 0.013038482265396705, 0.03072074437964588, 0.04146219531614934, 0.062298633894252206, 0.044733808270745704, 0.016144692049091382, 0.050351837454664136, 0.027244024789862098, 0.03442338329829997, 0.07255109282390726, 0.025721865540911115, 0.03351091129344798, 0.05945869233278979, 0.03208023443397495, 0.008878178590337836, 0.013537602912214015, 0.020154566699338537, 0.06258456855111065, 0.011012344414578571, 0.032031070741434256, 0.017662457783796617, 0.0346801798009584, 0.09772427470212984, 0.01074485332449718, 0.06190993620323078, 0.0032628070133092304, 0.02356081386096776, 0.04138373259094454, 0.02838570455599937, 0.030460234265774492, 0.013121168050284108, 0.02893283689064124, 0.011621741502876244, 0.09179784916341306, 0.028751048056649107, 0.04854846265046828, 0.044583356263296264, 0.023631688485282566, 0.03138657437727577, 0.01020026440176392, 0.06452352559614567, 0.022025759437031323, 0.04828789316478276, 0.023177486446295536, 0.02187696600993795, 0.03279985912564782, 0.045835431214542165, 0.011098430672239874, 0.047238325895441156, 0.01660630981918545, 0.015773077161171507, 0.06095973053766836, 0.04469415555978495, 0.046093200648864435, 0.027435102439936132, 0.03822713241642041, 0.031804316376726476, 0.04960165351569172, 0.08470580552614505, 0.09042326526175584, 0.04905208502145064, 0.05500646127808479, 0.0035336894788704216, 0.03086087143709583, 0.01681603787977609, 0.06669585217511462, 0.021140820632177978, 0.035767074704410574, 0.014727777959178052, 0.029741751045108806, 0.053045866079628474, 0.026801308324079842, 0.03596304765632076, 0.007771040771096464, 0.008261172333732247, 0.03459431666640505, 0.03618307193861373, 0.052629014657389735, 0.029412151291786186, 0.06307605991981204, 0.02314122175917991, 0.014878137078466675, 0.06306700476054704, 0.051335038527125315, 0.04951140835821148, 0.022633577426595074, 0.012844546149755198, 0.014390362193807961, 0.047679401017845645, 0.012495545219750175, 0.07885370583784196, 0.05763606190861714, 0.044854903788936716, 0.043464002214492335, 0.03171110837419908, 0.02017188986252633, 0.054006184105791395, 0.0303634831065973, 0.01949165932713978, 0.04663432302374033, 0.06913414149875603, 0.013290776086280183, 0.03834206475726059, 0.04745850339531899, 0.09827300816053346, 0.03602851753032977, 0.019404158679648273, 0.0156843593914903, 0.05288848097646429, 0.04763038671245018, 0.061752355747645905, 0.09635411878867496, 0.03910488148610439, 0.0787077967317835, 0.02045967462172191, 0.01295947178732604, 0.04564295162356669, 0.012901452118380657, 0.028323268390170513, 0.013336926180448745, 0.048802171818791866, 0.009140725540477903, 0.04933637258927188, 0.048177913582373055, 0.01834013341595569, 0.036562193530581655, 0.019763044059096325, 0.04232363820436501, 0.097421984068088, 0.01040577897877102, 0.06499646231532097, 0.05711309581754669, 0.04977238387049687, 0.032259502838696205, 0.022139870148572712, 0.007966011584240703, 0.004983671993437794, 0.03730875770411184, 0.05321782600555209, 0.04232967497720834, 0.028733564014997215, 0.027825359119883472, 0.05787017071739801, 0.054061920832722425, 0.023874155313317335, 0.01112854750376315, 0.05656299489219824, 0.035944044845358986, 0.03823188216155095, 0.07492652463336145, 0.05488545002956545, 0.028594367754375263, 0.030435347899554238, 0.017561326516912352, 0.023008025882224885, 0.031961370146863406, 0.04339651369880285, 0.008131805938788721, 0.0211467482374921, 0.00868335668553388, 0.04281217630411829, 0.031833238111087875, 0.025433375980825196, 0.06365968485272701, 0.060517429674585024, 0.09912784737084182, 0.11068806818295872, 0.031153764087526552, 0.09094186848209751, 0.10003295727074148, 0.05013493115022298, 0.00860796980334506, 0.02998494374145183, 0.021374588531832543, 0.05781926417482957, 0.01970875332312238, 0.00844927468983036, 0.04125743533574766, 0.08380267213309005, 0.07520493630680346, 0.027851781492391904, 0.03153593470943311, 0.013810837746507699, 0.027584838155176372, 0.017802820413283283, 0.005969588368785598, 0.009695048567899054, 0.04491982591007987, 0.06349198054522276, 0.019383725199487903, 0.02352891779024034, 0.012909453906749767, 0.05178279776666915, 0.04039488928092103, 0.02770891950105227, 0.03511510706777054, 0.0626506895998553, 0.03358719832894783, 0.0534788053482771, 0.011157221217159063, 0.03979932103726653, 0.030317540813778198, 0.01820224716568426, 0.04824872691965392, 0.010393702560254644, 0.06412676099928157, 0.0876494141055211, 0.09563712943946162, 0.013165094574252445, 0.09063761666296952, 0.02856458800153867, 0.03945484577167419, 0.07370026301472418, 0.04682956436168283, 0.03145440188687175, 0.02028461203970496, 0.05494530447908948, 0.026302127347838496, 0.04293044878830833, 0.07277566383803084, 0.04313704354928867, 0.032959282022690585, 0.027254592972777547, 0.043790868949145086, 0.08938529273314823, 0.02846313689294602, 0.03115058865308041, 0.0335201847877714, 0.026925498837484952, 0.08680466427317551, 0.048293378354320605, 0.016164395830503876, 0.02304215509925158, 0.053518140132749276, 0.030873079048169237, 0.06850933550947136, 0.007205349477683946, 0.01768516462987229, 0.027470183521208745, 0.0541292293177497, 0.044116950443675446, 0.08050912991166115, 0.10002857524781458, 0.10467846081742357, 0.08082874179367097, 0.12496964780673867, 0.13139540179362222, 0.09982428258104671, 0.12451294449067886, 0.0996601252606319, 0.10162317960132515, 0.15667202852426038, 0.08042139752257256, 0.11564409014798942, 0.15385239595367065, 0.12749357043855614, 0.14594814589908048, 0.1893305865627143, 0.20716370383818306, 0.2124796339100407, 0.1214984957609446, 0.09952687192708255, 0.1275943263223575, 0.1187374152904076, 0.11393245820316578, 0.09500006604338847, 0.23190333357741758, 0.16245401584573332, 0.12254001527664163, 0.11153251158013461, 0.08693281546114914, 0.12103425413970986, 0.14529016830267447, 0.10728091512235904, 0.07884018438597841, 0.12535433119703687, 0.12822196683696202, 0.10759669656474745, 0.1611833058057293, 0.12739774816098715, 0.12509061308998254, 0.1385613729155833, 0.12261358270001028, 0.12152019903183946, 0.11197453665156519, 0.11644036193648655, 0.16239001686053892, 0.2403829922719348, 0.11480131682248847, 0.22079436919621884, 0.15205138453072117, 0.10003043684147059, 0.10576534039911725, 0.1495054292102014, 0.19590746671442064, 0.12832076153567723, 0.11355621710179314, 0.09171934813381204, 0.14791470892246694, 0.18754167932896845, 0.12984367538123362, 0.26736339854617275, 0.2560626363922512, 0.11130257795054106, 0.1899790799906177, 0.12436511250393045, 0.21225693215045238, 0.211355553098744, 0.07904342751229003, 0.09847659602641098, 0.07197800543039076, 0.1070762164289913, 0.19172193001835577, 0.08570745016538328, 0.165564899723376, 0.19113904436028775, 0.23005644880956222, 0.14854595005031557, 0.16102446513550897, 0.15013625665057093, 0.1332745388630898, 0.11893799243074273, 0.20105787582935827, 0.16237867875925957, 0.12167712448224907, 0.1949344737635505, 0.11679309179946301, 0.14716941262445143, 0.17918738326238048, 0.14437792612419975, 0.18093495239173213, 0.145503600398379, 0.15604068014410236, 0.1647036483571414, 0.18968600539430497, 0.20306219166565329, 0.13021685213090914, 0.14984753343366808, 0.10372576919654686, 0.1000909501266095, 0.2358803258187348, 0.2104913905983971, 0.18011203606522855, 0.11625169746337399, 0.2622355737032429, 0.18638965163019397, 0.16784549750868352, 0.14773058735074537, 0.10971655378178244, 0.14179182779644767, 0.08768767253645966, 0.155328769957827, 0.1930752703018727, 0.11476702672699768, 0.12898034025584498, 0.1490805874909124, 0.07488212217727015, 0.14157856424008647, 0.16355788725758755, 0.09629353655562287, 0.06404349873323115, 0.15873930146617277, 0.13428479433059692, 0.09406021405612269, 0.18923088788024842, 0.11705375321569944, 0.23217071358474994, 0.11010697517063349, 0.14238295656058098, 0.1981969664414083, 0.11499437864028639, 0.09903266094624998, 0.21723947607942168, 0.14259404442723722, 0.13051371120156782, 0.05901137742424204, 0.11955404203505286, 0.10003212989578325, 0.15823173757281997, 0.10420733206574956, 0.06912071197744339, 0.16031967956692944, 0.1494708326795409, 0.2290653148966451, 0.1644223561931041, 0.1735398290498603, 0.12152111067646935, 0.2253734146154696, 0.17409616210047277, 0.14363626108294533, 0.10632157385829957, 0.10767643099590656, 0.18408673004277293, 0.08399635448210663, 0.19765508180904776, 0.10920581062354388, 0.11191883439859075, 0.1524492599550755, 0.15801421456759976, 0.10236698968876755, 0.1448439220867811, 0.23112299641774547, 0.16551207030011764, 0.22088228544640928, 0.12350169310887014, 0.09852072269084955, 0.14340704757600062, 0.11490804819209922, 0.15641682931492407, 0.08339522060968223, 0.15176970932272174, 0.216865946929301, 0.087698221567177, 0.12361143520402333, 0.10884037902278286, 0.1348403000062512, 0.09912721917874391, 0.22056169297185638], [0.017724759884238724, 0.018433061796390725, 0.04050068985370379, 0.008267768350760303, 0.07007327336337298, 0.013842087430549006, 0.06439682997522816, 0.07026335509914546, 0.03927028752983578, 0.014744366635568442, 0.05423664250561307, 0.008754337604548182, 0.04281293473116333, 0.025327253651114243, 0.07852695401637785, 0.04328658774254784, 0.017393415365668557, 0.0735794586099444, 0.06343742742413475, 0.031052682616357363, 0.030298130060996742, 0.014860264247193214, 0.05769419266031154, 0.04486460246205811, 0.03628796852764584, 0.021935048881137086, 0.07159889149930208, 0.026719972769158985, 0.0202613172211474, 0.01221265863522046, 0.030650404101658254, 0.10555071320625083, 0.024704307340265765, 0.09932080193633035, 0.0392012247034619, 0.01650563628983594, 0.02005812389055087, 0.044851939028669754, 0.11333837233964475, 0.05512828841024349, 0.02593006334087301, 0.03199471412376771, 0.05226282079914405, 0.023482751416703387, 0.021033844114431453, 0.010801550534163273, 0.007779203916734626, 0.04261946305632592, 0.09013947565108539, 0.05397583170223141, 0.049650077933385495, 0.02884777623318857, 0.046989339659170765, 0.04853841923778096, 0.05668266165641047, 0.048022780777706255, 0.05175033479087776, 0.027870395513732108, 0.02757934721997909, 0.037926063692617806, 0.015381100613834157, 0.013155374833713136, 0.02570980731698294, 0.08415034581576625, 0.01955327769410947, 0.015798478721520834, 0.07225735939197964, 0.10508102469987447, 0.07824727063698154, 0.09542729795700121, 0.025890856876128146, 0.01027515045397224, 0.030309667345136408, 0.03327207955261392, 0.026196489568739652, 0.0014577441822527157, 0.08142389251940674, 0.05609797569172037, 0.04465811112294755, 0.03920394431559309, 0.01244389461428528, 0.025463914160706827, 0.04489727228158905, 0.053193598474946716, 0.01414289664206726, 0.016957383017025648, 0.04061785151040362, 0.014769533581490961, 0.015033289992941484, 0.07344514807505954, 0.01613704266116744, 0.07858408885377069, 0.05787711147399199, 0.038225600240571846, 0.013009156419655249, 0.04816883544047033, 0.019552143883981535, 0.016667073998119564, 0.02514995026191877, 0.006383571270552855, 0.024146884529580994, 0.026511843917110277, 0.03331895264226102, 0.04738651411307435, 0.06356459801956531, 0.047705064963309035, 0.07408725999055371, 0.04144586232160369, 0.0348301032077401, 0.04123090954136945, 0.01965082175428829, 0.01625568861322057, 0.04616758395587245, 0.03749626538445873, 0.06139069329947234, 0.006684307703718304, 0.08773425834313517, 0.032271461471194224, 0.048235029267567786, 0.017983553961159724, 0.05636847367690456, 0.07291889163635432, 0.0460603354769128, 0.04355361151899542, 0.04203305339380618, 0.029501115167213064, 0.02930854173046687, 0.017254504472798398, 0.031203157606444536, 0.05165256664998109, 0.028605205983284022, 0.014371831484529522, 0.057100237031737645, 0.02774399100622583, 0.012945828719004508, 0.03404780486298185, 0.08090102985020607, 0.004164485557515535, 0.0353593435589104, 0.07710665764827883, 0.025918554785030506, 0.03479312031319545, 0.04400659547818284, 0.016573140127283913, 0.017472276456593987, 0.10959858390232248, 0.05421023928530274, 0.029921291411043178, 0.04135516517224812, 0.08062860132345269, 0.02292954208960216, 0.05955975848220049, 0.0311906052558052, 0.014768368170236149, 0.03821735713450659, 0.01769598945224237, 0.08612539709335373, 0.054962637218376326, 0.02936539694576735, 0.005250460676653612, 0.059356201259839925, 0.007712320131700367, 0.03589767354330228, 0.037685642319340865, 0.03329282138316381, 0.08664562442009488, 0.02843421898902424, 0.043780036465895754, 0.03831394166956025, 0.02054042986504013, 0.06309749122949378, 0.03279527025898138, 0.06274918935471965, 0.009865737745478269, 0.014034831321858352, 0.02265309734690574, 0.0425307079398584, 0.04436478754805942, 0.02113519754681376, 0.049354444603405656, 0.0260079687371129, 0.036620944813494725, 0.026717954127478506, 0.06442163590221636, 0.04387694275787762, 0.03977978579519738, 0.026554949769389727, 0.02206212754601673, 0.04284966864713258, 0.04338005429974968, 0.021577071315879305, 0.046416390161480636, 0.03045823669151193, 0.04793631243369272, 0.038342601018807584, 0.02084362448283261, 0.03274302689298507, 0.05742503532899484, 0.04988626667088078, 0.08934214666125276, 0.02678242617196614, 0.05481438771370919, 0.0842144443923908, 0.019935256794034954, 0.01656260833354487, 0.028429639698456854, 0.018513064358323332, 0.08131257228312955, 0.04759245769931905, 0.048864175144943504, 0.02031326755851267, 0.03814661657557853, 0.05033930042578329, 0.01129779835126453, 0.055025092536403294, 0.044294242341552055, 0.05060630505003276, 0.054609248519784985, 0.05899234396976329, 0.07712298298194524, 0.029494536387163307, 0.05385106279244346, 0.021928927838622082, 0.012132422416470947, 0.043559207791282285, 0.03024884570960797, 0.12106494362195655, 0.0424694630407518, 0.055654433766199704, 0.03492635066410707, 0.023065448002589327, 0.02548714769223044, 0.014371171691304734, 0.01493924599696672, 0.015007612640939414, 0.01729577362927939, 0.05471478862267348, 0.012756715126846348, 0.038513963396150264, 0.019503960783983913, 0.0654433980103462, 0.06267929915338755, 0.029459736843202865, 0.005271359555227983, 0.07572902471668298, 0.031352575395196196, 0.07907887440054648, 0.028174499860934676, 0.03001561215628059, 0.0504914837919416, 0.03947398264802272, 0.02584331537476711, 0.05047778997029509, 0.055909223118496526, 0.03458828755444096, 0.0030338274025838944, 0.048980413665694576, 0.0070340790308921815, 0.08820302754400239, 0.03118910372347361, 0.05721401641025178, 0.05679005569207573, 0.049665901479461504, 0.01912513988152627, 0.048903341390072345, 0.06329981505029625, 0.03291298732942632, 0.059832129552359545, 0.045246010826480006, 0.04924552222233146, 0.0061840934663890835, 0.06225401310310249, 0.04649124078212246, 0.02771730624860333, 0.006241030557336467, 0.019623909085508318, 0.03582234411770779, 0.028303016855892156, 0.06632786950156574, 0.04357180227675746, 0.04436857585284499, 0.10947444701507207, 0.027689866894375414, 0.01516104856085393, 0.037019410125550725, 0.04335085868895535, 0.027937022180506782, 0.011772955767810346, 0.04367966362605653, 0.02681146090429637, 0.040604100232162786, 0.027085906157510418, 0.06535350525331113, 0.05323864444489441, 0.04459862822606679, 0.06306349607785383, 0.06447598984044406, 0.0568880919637459, 0.09419444798221512, 0.07441812570417121, 0.03572083746774062, 0.006143812084525463, 0.015435429654204318, 0.017315326108326836, 0.05121033856525056, 0.05819206171098256, 0.0482091891218818, 0.012580183571234587, 0.046121875319870255, 0.04392185083199893, 0.05311800857945796, 0.004607350452833119, 0.09995609566929842, 0.027231104717019106, 0.012185813956743768, 0.02754312658291911, 0.02028040813222047, 0.03291134790126835, 0.04309683159414319, 0.059629529939904335, 0.031829164438550515, 0.025581558452798955, 0.036111300991427515, 0.03923594380819029, 0.09778694069433598, 0.05278669853484439, 0.004134465923397652, 0.009929595962016573, 0.022468140739346706, 0.008729160124916703, 0.01274591999038333, 0.041944214007667, 0.020470556900686315, 0.027479355508882194, 0.021615124818298127, 0.031731405873752894, 0.029307304498469158, 0.023417373473245292, 0.006696909850072717, 0.013574379920629005, 0.023057925019172892, 0.017733386034266125, 0.013252284956134617, 0.028118613746858416, 0.02950465066298362, 0.04932257534575559, 0.047212933911190885, 0.033920756841619173, 0.025799338097473788, 0.008924510630388415, 0.027805354648960695, 0.008996148469797786, 0.1268721505578968, 0.13739875788169523, 0.16506018567710154, 0.1330957492633212, 0.13406535610556602, 0.09543020143023423, 0.09280937633687451, 0.22118390958395698, 0.12320555416086029, 0.14558172604489714, 0.08499708747671497, 0.1654574788746334, 0.20409094049565255, 0.14727136360541468, 0.1895696979256407, 0.16839858234649704, 0.16255682484517175, 0.1955412307213391, 0.1919094223769442, 0.1224887716553865, 0.08494767480559888, 0.1272403707187022, 0.1462802143707391, 0.0978973875903795, 0.11655349014026505, 0.13192717406538226, 0.17675788862810982, 0.07813262557911296, 0.15243150203699066, 0.19056620977578625, 0.18705812463116261, 0.1888027060176096, 0.1318718778390077, 0.23964276747597804, 0.17672442590757725, 0.12628411678897758, 0.138582440333501, 0.09579531127406705, 0.28517218486916635, 0.14941539855733996, 0.11632004782797829, 0.1506789380143727, 0.15270213025712198, 0.15895434234651828, 0.10887979424648708, 0.10441710992205529, 0.06081153465915592, 0.18958607688546184, 0.23760923304625098, 0.11864317881484186, 0.17035062034283915, 0.09063328826619733, 0.1338019903989569, 0.12496039346461335, 0.14635426442950003, 0.12294687691234774, 0.10942381626415638, 0.10836250869737518, 0.11465481782872831, 0.14042823725650388, 0.07517041638493538, 0.2634504665770839, 0.17121007906333094, 0.22960321587179938, 0.15954625252033436, 0.10324534779835133, 0.18113192891882313, 0.28537835445134874, 0.22448167294984867, 0.16128265208775, 0.20914387258310474, 0.12704262810368694, 0.13075599416850076, 0.1377186608771163, 0.12361547248738429, 0.1324115867816633, 0.21188580851641395, 0.1209851479037635, 0.1548803940175041, 0.15231018435330163, 0.10729023841239753, 0.2113908850738118, 0.13370305780441533, 0.1112143322825432, 0.12459835563335689, 0.12806767672901193, 0.14090079093171706, 0.10523320806603279, 0.15792320332219525, 0.21188689636126642, 0.11378767524635601, 0.129113425050051, 0.11564395225216305, 0.13156069292416497, 0.11218158723486048, 0.19376704769749797, 0.10662579503391059, 0.09164067856486767, 0.22564396622680852, 0.14476559725740265, 0.07505831473897542, 0.1504045712851709, 0.11545231535790429, 0.11790876096535115, 0.1736620353955415, 0.24123408531229346, 0.10680894367396833, 0.13744585696728, 0.22412470662065093, 0.09960595518350603, 0.1437520629335796, 0.07990154557891431, 0.20862140061874546, 0.1478556588652634, 0.14747305923411924, 0.09015367892120155, 0.17363061046888753, 0.20216703324789004, 0.17945439554750922, 0.10988661764009346, 0.1744614328227697, 0.14918321262924902, 0.1800830319764153, 0.17926837407773544, 0.216118015288826, 0.07551934645180741, 0.16162970523920753, 0.07724177257548417, 0.09068640880286695, 0.1368300142067094, 0.13001956916864843, 0.07608633578544663, 0.1217196730055636, 0.28451025425907106, 0.1308211269638231, 0.0919961050573376, 0.19173821704762598, 0.0736444611703196, 0.11261658728002541, 0.26402552281656577, 0.15510825920970212, 0.10905195718571063, 0.0917458471151129, 0.1537819618299123, 0.1232600536557936, 0.2531080191294032, 0.14385275753034701, 0.09166692473715352, 0.25992477673196024, 0.15579021535813808, 0.12182454278151836, 0.10270714038802732, 0.1917174407431195, 0.06524352567090143, 0.11768506329146125, 0.11217898253591792, 0.1555611703905367, 0.196653452491568, 0.07923967625585296, 0.11436679175183659, 0.13749666391841828, 0.11024932962872329, 0.09314506074353572, 0.1377269346266985, 0.14264984627164182, 0.15905011865881183, 0.1624185766183561, 0.1991920227244977, 0.07729588902645534, 0.12003100837670988, 0.1720360444197732, 0.15032851407604833, 0.1196745859699384, 0.14788060268807798, 0.1683030511823393, 0.09236860764963974], [0.036672023725846124, 0.062170069018799456, 0.04547900114689143, 0.06604475404826865, 0.017089655758031917, 0.023343769660700234, 0.02147168826101528, 0.008839877066953529, 0.03387288017679126, 0.05658163381139598, 0.06759292581268857, 0.029773084041211876, 0.024522045446980386, 0.0411144794986373, 0.02399484672012829, 0.011749201296498219, 0.034703066677696286, 0.05512243932894161, 0.03835966562732093, 0.013194840810742351, 0.02431623975656206, 0.02921383985648713, 0.08335218179009615, 0.03695131640040106, 0.0010793639000527741, 0.06965233103161858, 0.011658756956157666, 0.046412306912844224, 0.07130868207182615, 0.018279962955162894, 0.018336793272605827, 0.024811716697689508, 0.05459977201216164, 0.04099233443999002, 0.010333966854358874, 0.008829194928459343, 0.0204173635856639, 0.03245557155159693, 0.056973897641704935, 0.03389068022971192, 0.08400426817036445, 0.0031355430509129, 0.04117199354955266, 0.06249394418010789, 0.03136370282229637, 0.03198703600754661, 0.05418984985519802, 0.04894836437738231, 0.016827613468311967, 0.06913782638167182, 0.019731688080355525, 0.04526808948045777, 0.046435691746732885, 0.017009193543344736, 0.06534281066588818, 0.07547221672270568, 0.04973875644106058, 0.05677173469936656, 0.022580993151472464, 0.03726571122364652, 0.0537655022626202, 0.019455398470463774, 0.03615119885052404, 0.0918360846117139, 0.039468535762881084, 0.06971917220301206, 0.034334547742600405, 0.047513991143674626, 0.08152185984316372, 0.04133167691648968, 0.00772234151935986, 0.04418811618140148, 0.023895783890639583, 0.0475965294566366, 0.03567157418376977, 0.043296543055123864, 0.025273895627188108, 0.013476780319075673, 0.03857880124762174, 0.04102561712986039, 0.04218153655529023, 0.11748398053309611, 0.051513694061507145, 0.04720256108069613, 0.018279009175697164, 0.03267653429159715, 0.057595482231268, 0.06623789247485899, 0.043410686325402036, 0.04590231452077147, 0.07868872880334817, 0.02903971381695761, 0.013686195241227267, 0.06602423055277717, 0.06763829353956446, 0.036436248675829945, 0.054546004131196014, 0.056038883499680996, 0.05017607007175685, 0.03762175441689549, 0.020687074415505897, 0.08634134195744993, 0.037672147680554664, 0.01268712561502452, 0.06617929440953078, 0.04080760382836865, 0.04372426526500814, 0.0852714235623998, 0.04846574047640447, 0.019343396415933967, 0.02826598799607206, 0.02078907519218422, 0.061745353704017986, 0.013013801785306105, 0.04134689142266589, 0.009697204147795997, 0.015643259731962556, 0.03424899487365638, 0.02416323284588514, 0.07427501281903637, 0.0963322929437122, 0.013944960589851103, 0.02608725692205612, 0.051549811276697347, 0.017566779147713416, 0.0538108891416942, 0.0426508343568252, 0.018914099895365296, 0.046736170582833796, 0.03258649214741684, 0.016818945183448734, 0.05856641823606146, 0.08067493432111318, 0.07760620060106439, 0.05784448378929689, 0.024705075343409856, 0.10901715381131058, 0.03551159970342152, 0.031224209702603763, 0.09173229501973237, 0.03205821515181132, 0.012375911014274725, 0.10086767135127898, 0.05323342355569044, 0.012267063326773145, 0.041477459618040634, 0.060780377863275434, 0.0735412308225228, 0.012775167312112548, 0.03251641425454328, 0.024851587743708686, 0.06682984095307128, 0.028170594727740656, 0.013520886873706214, 0.02023036726900647, 0.07027636327209973, 0.03818063087941658, 0.06613502984926586, 0.06175880620796835, 0.05591974916657614, 0.031991632535092296, 0.03469170942421883, 0.05353024049151329, 0.03657250890448209, 0.04100481018183693, 0.038014562169630686, 0.02697321845428838, 0.04206224517416089, 0.0655440159983212, 0.09879463742817603, 0.011131925951509226, 0.04453754037498467, 0.060262134704258175, 0.08985754763407093, 0.09792768636778479, 0.04174596960506132, 0.05357245576658076, 0.06875071449265366, 0.04312076801133733, 0.05618600685509944, 0.06628107685115069, 0.027881195438244653, 0.06373352423730878, 0.003960027463636512, 0.019321394370748632, 0.08075793994770897, 0.027881892578255747, 0.014279143464180731, 0.034545838622556585, 0.04568047077965833, 0.059165928002086386, 0.029421687171223666, 0.019782380118305166, 0.09649189204097756, 0.030016939403609406, 0.0037741290467355644, 0.01863689481040403, 0.0766077122440742, 0.036037469267724984, 0.011440997421290847, 0.010041657388360511, 0.01801932069112457, 0.038005771310699564, 0.0458830091050796, 0.08550626781558798, 0.02826000676460324, 0.024966278766852715, 0.002623613414001621, 0.04582627263340739, 0.003894714158847027, 0.017765502355271773, 0.0355468359174988, 0.01207024289009672, 0.024475505605580348, 0.015413577953774123, 0.016110886504212697, 0.030015050996876055, 0.0649344704804882, 0.01723013904636666, 0.05244145335088815, 0.04824147206701098, 0.034679302630285104, 0.04875468585880534, 0.012414660699094736, 0.04336500833291681, 0.04013208281849662, 0.0530596518318259, 0.022757859870551095, 0.029519878575698506, 0.030884917021819183, 0.018683551480212522, 0.06610768051036904, 0.08397458992417782, 0.06359089398756623, 0.09056957273353493, 0.03721239533455622, 0.03043881827785123, 0.021537629279097723, 0.029658094243777376, 0.05014513161093478, 0.045017076941627654, 0.06419200487735291, 0.0649537299309046, 0.0989505363207671, 0.061106543627477465, 0.046383793120302504, 0.029725013939183087, 0.03487325311007519, 0.027102752430965344, 0.03340309590942437, 0.018655897621365807, 0.03556456702250627, 0.05083136252998825, 0.02997513398558142, 0.04539851978000614, 0.018144051296516292, 0.042855429628323165, 0.08516676063018461, 0.025314946448610678, 0.014826329424977304, 0.024764267126879385, 0.033917213684969374, 0.048742574008722464, 0.08100245223050156, 0.06350516108796, 0.058197359208978956, 0.029334623193849, 0.03011506377539087, 0.01830524960232358, 0.029885237398106727, 0.012993866262296516, 0.013448903337121012, 0.05239851412273223, 0.020043005145365195, 0.08575981993588709, 0.01638256234958047, 0.04201665145134734, 0.04655937664210797, 0.031804429374695305, 0.03522409073587868, 0.08619369383180335, 0.05039252438432267, 0.0622831167833459, 0.0329924842733289, 0.0686346598330044, 0.045128971743848056, 0.012966297630731378, 0.015602691545932284, 0.06457489945234791, 0.013782792225209697, 0.09328843409856481, 0.008486660738145153, 0.02188508654193532, 0.007910945184243423, 0.04917529111187305, 0.024205476849249775, 0.008521678617164012, 0.06473464410631888, 0.018413871293887496, 0.02201449985976421, 0.020541262985657782, 0.05043996054859412, 0.07944649701277096, 0.008777761700442963, 0.030440201066554557, 0.03170347813847325, 0.03828859948102505, 0.044485990318559834, 0.04743501130912093, 0.010242533302986094, 0.02360686915175569, 0.04274148554090531, 0.12686691817737397, 0.06950924879000073, 0.022157469103413246, 0.08473142350633299, 0.060343604324565786, 0.020477528300797267, 0.016201533857853185, 0.06933330903731047, 0.009832349718518315, 0.017213608784180497, 0.03341125091537833, 0.04318432649597526, 0.017721730006498196, 0.01378662458005091, 0.05434092239386613, 0.12346457614893876, 0.07024003538273035, 0.08622373980019363, 0.035493156136644465, 0.06599034648388624, 0.03448882635923163, 0.0210038747548336, 0.06876610519905245, 0.019112667970118985, 0.03162681763511031, 0.04394555742281579, 0.041599037771623944, 0.059815210500551816, 0.08081725813568601, 0.05916931028027208, 0.031441751860022064, 0.02260750170887238, 0.04164504901235623, 0.06880028804223384, 0.015021271988629334, 0.0531722437740574, 0.024357780874256166, 0.016018402454773747, 0.024500430276196812, 0.033969300002941204, 0.15870043016489477, 0.20248099140101866, 0.12940571823668096, 0.10483026880049899, 0.1148574480847005, 0.1609189595065771, 0.18449621936005933, 0.11580593388287291, 0.1147596033350114, 0.27545828191984084, 0.12730558012281695, 0.07335900148797421, 0.2803546256355701, 0.11500854360600633, 0.13118762342679885, 0.12253617717614099, 0.16292699853018408, 0.13290543770117144, 0.18429302219902316, 0.06505202667246904, 0.2601159616343437, 0.1588427386577091, 0.14157398303429927, 0.18257739893611402, 0.06402427758721095, 0.2127097667224946, 0.12307616191044932, 0.2650700377360467, 0.1725875357947042, 0.10932060123811807, 0.13715655152355472, 0.14751470377368314, 0.18302041226096694, 0.16853307674248375, 0.1720641292030773, 0.10802913021536605, 0.1498966090260975, 0.14535275768608819, 0.10036759213694643, 0.10186572303815235, 0.1917547032597565, 0.11624196814673564, 0.07943950263002227, 0.15162395343424814, 0.13740404388837277, 0.0919917383561692, 0.1761583635403264, 0.15803895920755404, 0.14472841134955808, 0.17125391461435827, 0.12538593232391343, 0.12150535990874614, 0.13452978924878184, 0.07024998686486675, 0.12338098829552052, 0.1428537329118098, 0.19072380938356925, 0.1654751601839258, 0.11539107428923731, 0.1275652992509065, 0.14833774267425462, 0.10626291450593742, 0.09520134798461392, 0.10393503377394331, 0.1392302136387556, 0.15407924990980856, 0.17603863931951985, 0.19946076636833532, 0.26033239679471143, 0.21636337792921453, 0.16296781569478974, 0.08882684527986473, 0.17783490099733879, 0.15639291204992803, 0.13634305807851976, 0.10903773859383599, 0.19482722145415124, 0.13291037130740382, 0.12399079428324777, 0.1057527152701251, 0.1350150140182626, 0.162207335534115, 0.07846205870831206, 0.12889423197315586, 0.16475935827099508, 0.1212023491520555, 0.21929086035778447, 0.1489595762423931, 0.14230548974967774, 0.14303163384958623, 0.11600477966449915, 0.08318273080212456, 0.16935545680744035, 0.14866565894936362, 0.11246068838743434, 0.13969427905976772, 0.26390650339664956, 0.11885545411778074, 0.17537359839245198, 0.11799423339506311, 0.14924396340164447, 0.1787829960906698, 0.0942465266393077, 0.11195971285023036, 0.1281781312859347, 0.1545407719189121, 0.1438770271957882, 0.172441350896993, 0.15362802412240736, 0.16634218785310947, 0.07585108550565858, 0.07108528317222673, 0.26906892477023986, 0.10181870056136001, 0.15506495992022176, 0.18807801748475722, 0.15176142025138104, 0.13621607134419103, 0.10823309346432648, 0.1620757369504821, 0.1162356632431188, 0.12889582543603836, 0.11373645460773861, 0.11566794612595152, 0.0702564909513439, 0.12062764531301877, 0.16555209073328203, 0.08660607130056427, 0.18968185319775538, 0.1751608404541208, 0.10971460025757553, 0.15035799313937465, 0.1255342775895711, 0.16801602868062837, 0.1582389387993082, 0.09013133979732953, 0.22649289889922067, 0.1049906493074471, 0.19707202761163636, 0.12868775595580378, 0.1711394151131953, 0.12657535277427207, 0.14262177681009616, 0.16796117678524988, 0.10149375670739721, 0.18565638291258968, 0.1745250947292774, 0.12528653241573803, 0.12087269385735835, 0.08893128604658189, 0.1624460332095623, 0.21752571717144983, 0.15660511840495372, 0.1102571360646717, 0.11418341328540157, 0.21669118695201414, 0.1330040025735094, 0.17201912919840506, 0.2077511553802798, 0.14365404964454714, 0.16897589088447634, 0.16030717701200517, 0.1290035220764337, 0.25144297299125506, 0.15237061336876886, 0.12524944609932362, 0.12995823616943053, 0.23104241928986965, 0.20054980631797545, 0.23343763915040802, 0.06445942701952112, 0.18135748052548978, 0.11111097169979928, 0.0912968046782959, 0.1609774733022336, 0.1362214492814195], [0.006575720007306026, 0.03169747583958651, 0.05124217717938366, 0.034794357545193166, 0.07238315869002573, 0.03007859607497531, 0.05753258641268458, 0.040072891035027085, 0.029915522768973347, 0.07303349072894744, 0.08296684722506231, 0.10580748289583192, 0.027026637765248458, 0.08850822931215649, 0.021323004001451117, 0.05316994934072418, 0.03770674804165479, 0.06212294695057696, 0.03758038183854472, 0.029699800070375208, 0.022180164458170053, 0.07160331948750442, 0.05478023168360514, 0.02075835315120076, 0.14435984644918673, 0.025836117978718494, 0.04248101947708957, 0.04751578761985706, 0.03340223789094918, 0.00970719297671871, 0.06552283366721484, 0.035785713623608315, 0.013026115691079008, 0.016884085639650305, 0.06280815514225153, 0.0321914206048654, 0.07952500570325122, 0.02869574225417549, 0.05967561012854981, 0.03578667889439291, 0.055765604615331664, 0.022414334553984866, 0.029298885192181316, 0.06426895457890726, 0.07055922591638181, 0.0404730225883184, 0.02260248383296834, 0.06663296401741044, 0.0353116660769428, 0.030966727551253095, 0.03232178195650059, 0.019568530504681894, 0.017988014508098844, 0.035434351227576696, 0.01512174441989872, 0.015884672231491537, 0.028166856218670166, 0.023556498870734247, 0.03267824266766829, 0.019576570597447215, 0.031614786224259485, 0.06405410905098242, 0.013815178592208655, 0.02649688796560851, 0.033451999132070816, 0.06547580352954327, 0.02976075194085077, 0.06309145062621083, 0.08367712564405896, 0.03907021217709107, 0.03595875756394479, 0.035299795544556076, 0.03244001230585479, 0.06282603180396461, 0.06398409627558244, 0.04144043841909978, 0.09037394452119067, 0.006198263220158556, 0.08103607582949823, 0.03848410128886181, 0.052396572089844176, 0.020560030224582842, 0.11364468493528905, 0.030640138523472898, 0.03731801204623715, 0.010800190728097674, 0.006030406173874414, 0.038921135297465714, 0.026004019553863236, 0.024584370530060223, 0.008818236998312416, 0.02402937047243599, 0.04744473296488005, 0.02860539367482547, 0.03512612341212169, 0.06501611247057877, 0.03175950789403531, 0.03287078737611732, 0.045309473550127405, 0.05779171948351207, 0.041625827866336035, 0.030174301524135857, 0.00676101656638146, 0.029439990926954537, 0.03689087972405457, 0.0205999510663171, 0.02508919757430352, 0.011318508580687546, 0.04215752352930365, 0.01706535544907374, 0.08544956964831199, 0.01948745541965529, 0.020963720256282438, 0.04819573661793144, 0.049126004845264463, 0.06251564745100276, 0.03875504743548171, 0.005479578422607794, 0.025407554987337322, 0.023221948274200963, 0.007434776052832604, 0.0343020273102147, 0.02544077064451431, 0.05897758911634165, 0.05912333351349639, 0.015960229568243507, 0.05723183178493092, 0.06008429122307609, 0.04051215052905102, 0.03940715679838773, 0.05552657369163729, 0.05254158104259161, 0.013452438832891565, 0.036467999189851746, 0.0498969191234679, 0.010351187553286794, 0.06101939346521132, 0.047975306309038596, 0.0056006126537648665, 0.06860353368064089, 0.04800360942740114, 0.07022027797516316, 0.030063885271609313, 0.014329599930093655, 0.029263922854536967, 0.06848878903134216, 0.04514903175614534, 0.023689047403393254, 0.06157201098939104, 0.03699869127763856, 0.09161798704055049, 0.03512631110366314, 0.06012505859196667, 0.07721336603525185, 0.03658921345167103, 0.09688748452331751, 0.05256142271983047, 0.02952136670149142, 0.049586086609070344, 0.03782269161855502, 0.036396504034318274, 0.06280279635722119, 0.0454385478740498, 0.09271970574533747, 0.02539402587459453, 0.03277151770288906, 0.005577299161814154, 0.03939341318102614, 0.030604576722027797, 0.08234328995909422, 0.0387197001386554, 0.0913804921231443, 0.02333397139614869, 0.02606791894762747, 0.04265369952566201, 0.04326670393047314, 0.036762169291896206, 0.027985944555351333, 0.04991442423253771, 0.05444706770621481, 0.06910968031133376, 0.044657820009536324, 0.08436868853506543, 0.06495152359768268, 0.046262299236390865, 0.037249807238338456, 0.06667260140661271, 0.03983703554577885, 0.08302945193023452, 0.03526238364077384, 0.03266508510756878, 0.00522503373964179, 0.05294772638608852, 0.030561095486665447, 0.056597541627143665, 0.017264917522909182, 0.03377521162732475, 0.03330993578739224, 0.042766908168672554, 0.06913213434839441, 0.0282762861329942, 0.11271240955759441, 0.05953241680418292, 0.0238669540868291, 0.04872742462001982, 0.03322594190737413, 0.06001303355479914, 0.07493699705528636, 0.0048010907372489815, 0.041474272692275625, 0.06966175391308724, 0.04339024709958223, 0.020497996254914233, 0.020259013211715127, 0.06856299996856721, 0.05627344813077681, 0.03951091191641266, 0.023143454905479185, 0.018106392329378475, 0.05305891638741859, 0.04481009147580593, 0.05414763074969092, 0.019557962321766445, 0.01277025668851791, 0.011123074763154071, 0.04470393467213839, 0.016407904538115668, 0.0241005132275243, 0.07167835013880845, 0.034144485159026045, 0.033293223579324065, 0.03391327982347819, 0.04080638574856905, 0.02440315817723111, 0.04833071747975004, 0.01595806728507723, 0.0454672378668141, 0.02768338387531619, 0.09813149639916036, 0.05021555424337426, 0.02241549709240996, 0.02947246922450441, 0.006765928147586003, 0.05863058193015957, 0.07574674433037158, 0.02571367989144018, 0.06229547761200417, 0.07638253602049044, 0.0600033616947551, 0.007391653921184762, 0.03421392336848282, 0.06162650665388473, 0.0718810799862108, 0.028195304893738324, 0.039642368773779565, 0.02577893334561058, 0.08203798859950998, 0.014896790361813, 0.033408010363458626, 0.032105473200640375, 0.007092360127341724, 0.013126184010968335, 0.03548458361277177, 0.07133600842808524, 0.060996571705947, 0.015946161321124003, 0.022068124099244035, 0.022778867916654677, 0.02588751290233866, 0.03596448407117878, 0.023833460722779556, 0.06814122260097535, 0.013388479109703293, 0.02498456337038548, 0.06571391131728888, 0.08942740458634593, 0.005046204877867094, 0.013510027577379539, 0.023094852372343024, 0.021781239493359483, 0.044603067705588, 0.04819397461570559, 0.04866487354100232, 0.062141677800325625, 0.021735402537629973, 0.07193924138142217, 0.04910232889796457, 0.04013179936596463, 0.01719534907850527, 0.05244178659913521, 0.054926569798901204, 0.03325435610848569, 0.050893385008338, 0.05661801532692006, 0.0527008124176533, 0.033496041526837696, 0.03703556308943418, 0.008952815663970767, 0.08350778190839676, 0.026150985861257203, 0.04192503499648264, 0.020885393511684194, 0.017262322400065682, 0.04896188199880624, 0.019741495921006127, 0.004065424164441685, 0.03296465229903979, 0.10223321541542969, 0.05178560547891164, 0.041687731601057515, 0.03034005039221337, 0.026203447562311927, 0.023381951482846372, 0.04969690505775714, 0.07170964483051531, 0.05299755274468372, 0.03841971542926566, 0.034486746430517204, 0.040795698822025335, 0.055118781259103175, 0.08405907410046748, 0.02251760895183731, 0.017361232011969534, 0.013169757176881597, 0.04003966580175104, 0.0176381862031356, 0.05202563231690757, 0.021076672259838353, 0.0670461152349749, 0.031190898284436237, 0.02910808141854021, 0.02761181594142991, 0.03679299283952963, 0.12276146065203414, 0.018354888269377333, 0.0601977258620243, 0.034232577609439055, 0.014730584713810635, 0.019370751500490214, 0.02570371883320472, 0.022443863413026257, 0.02569404314272106, 0.023797414370722348, 0.024508192662089586, 0.039311775021375193, 0.048828697613170075, 0.02816809536588769, 0.04766731598084012, 0.043684440184264414, 0.010105069358682921, 0.03290297456025597, 0.051602870526333014, 0.12870149957316537, 0.2059537139270575, 0.23114786363176762, 0.11353475897903405, 0.19025572966183388, 0.07232560250427454, 0.22473196919646957, 0.18311343065673308, 0.11241569604364135, 0.15934383676898095, 0.218187234094066, 0.3046617068109974, 0.13262051428037305, 0.18320007520096918, 0.0830763748155967, 0.19241903938593405, 0.12838675234947475, 0.18467061161514253, 0.09677919799522047, 0.11293115830349346, 0.07085899612115276, 0.2838713675737381, 0.12177273991607851, 0.1644136381125258, 0.1944141468453792, 0.2794442373898722, 0.17065123324432682, 0.11035817540100507, 0.1699944354233242, 0.10204808260764807, 0.1686503341601741, 0.15557871380400273, 0.14947302369100435, 0.15741151787580984, 0.10620219437705894, 0.17704491112982074, 0.1777731083453663, 0.08654924289834115, 0.18568889568409613, 0.28498581099894743, 0.10680116788153687, 0.12613630778486692, 0.07794363168819297, 0.14486544915745336, 0.2165527242205797, 0.19551378945189138, 0.16306310171081176, 0.1244375154736542, 0.1556895973701631, 0.13644385992759658, 0.07931613949157539, 0.15123839670371625, 0.16310892909044222, 0.1158109440978977, 0.09215724399133075, 0.13321199544495152, 0.1202192361797056, 0.09325890906996305, 0.1654459875557692, 0.13127708717459632, 0.11457696797386294, 0.1919722262649767, 0.1214133221055231, 0.13861142910055577, 0.10572188023117282, 0.12165627156895016, 0.10476060076466492, 0.13236986563330697, 0.15637987323345678, 0.10189815153998714, 0.13550760855357494, 0.25112832535899454, 0.17775755676050342, 0.10285006175118108, 0.18475216933556143, 0.1722627911236017, 0.1790235323771354, 0.11730317612208667, 0.1925445092661727, 0.22535702033389002, 0.15400219678638444, 0.10526422696608691, 0.24996687477875143, 0.13529282814312366, 0.0816412316635251, 0.06729215969361606, 0.07572231378646628, 0.11133364281587063, 0.19467650131592829, 0.1391007294577937, 0.16120976648263394, 0.19709140963612065, 0.14443570447544898, 0.13269408936462096, 0.10033357783310837, 0.19105993812122654, 0.14565162390710848, 0.32247266882369596, 0.13549535114678646, 0.18818053537078444, 0.14804842190877085, 0.3136084799564654, 0.14130464184188074, 0.23711286935835119, 0.1153153311761637, 0.1156615722744215, 0.17374068198184814, 0.12048557430746094, 0.1656285769516422, 0.14788670074795524, 0.19305179736787276, 0.06307090414808163, 0.1526264254484446, 0.18807720543155748, 0.18776790509300847, 0.1074171791814508, 0.13417489135697966, 0.15804072120977988, 0.09445545413801748, 0.14478438173330602, 0.10854593312908566, 0.14244781356425057, 0.12264866186606309, 0.10213291152350365, 0.20969026181246006, 0.09169557642552162, 0.09269811738763126, 0.12892617783959837, 0.18521369134466495, 0.1008462668546746, 0.12102034198300493, 0.17366379739776736, 0.12483861612816974, 0.15620549630013206, 0.19516177205068452, 0.11735826550472168, 0.21706482335444421, 0.17277819975729913, 0.17086904736295824, 0.15552259020266995, 0.09637412900525717, 0.22433697426271057, 0.1147072718689038, 0.07521101138404301, 0.20777118091862048, 0.18119873178582038, 0.3000703580196827, 0.11773874307231558, 0.15662348919337796, 0.0776742828348952, 0.14284409552572236, 0.08208445949299682, 0.18830436582286514, 0.20342125707576353, 0.12158906267535304, 0.17118919550651507, 0.13069744972932723, 0.14842530652399988, 0.11270162303962054, 0.19080228743053254, 0.13335134683837815, 0.07892419358775501, 0.1587112320046271, 0.13027676020658788, 0.13154757749890128, 0.07818422160081326, 0.0754232560434649, 0.13385984535899856, 0.11015183727947936, 0.21291264212660252, 0.10605533532197438, 0.12433057726030389, 0.149765117694774, 0.15319630293355835, 0.09837440755819121, 0.1178320985467684], [0.013816807486657656, 0.1347959894807108, 0.03552828126797273, 0.06979522175125538, 0.04106505916664197, 0.09104260138326115, 0.010680344890833143, 0.04253865610207281, 0.022100182963655363, 0.04722735551636546, 0.09027349507255901, 0.01942815063821693, 0.050635592591378, 0.0334422966285098, 0.046470544916848024, 0.054113172114856785, 0.0937741261816794, 0.036080397004562045, 0.019252789281909505, 0.06365318076624986, 0.035405825943716114, 0.03808199322872585, 0.03302347636030566, 0.05002980090437397, 0.023101226223873037, 0.0793229806567392, 0.024219289414524555, 0.030906359822819793, 0.015693234520093087, 0.025504909440754883, 0.068064131173155, 0.02440302794228398, 0.04934166242638904, 0.019345842151632233, 0.024119205772876743, 0.02828977885656059, 0.06694972605234192, 0.024551817538937735, 0.03657893255172718, 0.03540948784399418, 0.04690029725973164, 0.10502421928028907, 0.06350756277360263, 0.030186478491692297, 0.04012724497325478, 0.018518034353732102, 0.10907916862878109, 0.016862273201226227, 0.027891616149234678, 0.057863321891354944, 0.0325549676293327, 0.027037801581525037, 0.02956695467864554, 0.09836894535129109, 0.07136534193470594, 0.029099840227694764, 0.012537713571932289, 0.02238366805437592, 0.024850216446324222, 0.23103828241507854, 0.01164523071624459, 0.05906373953386661, 0.032562911961107485, 0.02299501196361117, 0.08377723035312469, 0.05156674565026357, 0.04150300098943614, 0.010060634343854843, 0.0808442627350169, 0.02043800965522326, 0.11065750127477993, 0.04072257189921314, 0.06857314297268469, 0.06350540240565616, 0.04727580674713658, 0.01870417073669453, 0.014453411229976244, 0.02634444604477575, 0.037882124719720696, 0.032850907394482244, 0.005787536670874444, 0.027430193731561307, 0.09472877898764226, 0.030050325515349547, 0.029589694083457994, 0.02365931553105193, 0.013273997803128535, 0.027519282096275882, 0.07121473670967164, 0.034963555724149754, 0.05454917190476291, 0.024051506583008076, 0.04459287107531582, 0.06261890078143728, 0.02759132500467522, 0.0657292330757745, 0.024510659465205767, 0.012575875284270415, 0.06134727143592412, 0.07038919270158776, 0.03667679262317477, 0.021135733808360754, 0.06411958658587068, 0.024254420291512244, 0.010655999574209414, 0.06122024256675955, 0.08332709241057597, 0.024425512622861613, 0.05410706639410027, 0.05611204106601016, 0.07679845281546155, 0.03294388748585217, 0.015824369620531797, 0.024650338361220017, 0.0031176616011502883, 0.1288812238002016, 0.022533315669504866, 0.05944309095221181, 0.043018031790251696, 0.01834490997416358, 0.042565243183484966, 0.055786442206872094, 0.04926811032477887, 0.07003135303215635, 0.07967181113218108, 0.08469177845625148, 0.007733472776899656, 0.06581672031672732, 0.0184411114652551, 0.0037258817868742852, 0.006964287463380325, 0.05207149417049462, 0.03808739414859203, 0.04566828232078303, 0.04123433012395136, 0.1655030304626111, 0.04210546019396955, 0.04649003802408134, 0.04040617375604568, 0.11015470244831617, 0.050956135270215815, 0.04038567707363156, 0.022138217313876076, 0.038320372977684584, 0.044528898903198784, 0.05227423933965545, 0.06651862539471158, 0.06302956221324783, 0.029437694578401508, 0.07123353650733348, 0.03525964870688415, 0.027459879638627175, 0.02856431604032555, 0.06903838050822098, 0.04026700239328127, 0.061114798224861586, 0.04462962031304356, 0.030503945327514125, 0.024435238109060356, 0.032845012347904906, 0.14493660340386053, 0.02225687475724807, 0.038998943017495256, 0.07359684114494632, 0.046444624331929994, 0.04542380451194702, 0.011277120680578295, 0.05503987037246266, 0.0285363691528478, 0.017696847470717567, 0.03343788396206594, 0.05796246132963608, 0.025719274248507236, 0.03453668004142181, 0.01718793717783786, 0.014818633114168001, 0.06615951401932586, 0.05614762585009298, 0.02409678237933305, 0.04137525199762276, 0.051830869783917745, 0.03814007418470518, 0.06643958044268432, 0.03888890214805161, 0.013087071391994195, 0.0192528773820208, 0.008869398265115676, 0.06243563339775128, 0.041523122288767374, 0.06753183030072721, 0.013445045126812353, 0.014135262575901806, 0.06749962396439045, 0.02339985687285662, 0.030059926512260592, 0.03181437511117228, 0.031262872244922385, 0.04636344965547324, 0.012665136018767955, 0.019366639523556637, 0.01850245787101167, 0.0778659273900332, 0.03144590597179148, 0.01809151490188895, 0.008937006482043335, 0.093609792661042, 0.1325998299064175, 0.026377851308714, 0.09007970547123302, 0.01286303951224733, 0.008286759670403215, 0.0425199520654015, 0.010797008590382195, 0.06303356885309182, 0.10264017664256597, 0.04777993856658859, 0.01670372555963695, 0.0250910553375199, 0.007399184565480439, 0.04348696570002264, 0.06912020635941336, 0.05990680397277879, 0.06732988186300763, 0.05664491267394155, 0.018642366593403202, 0.031353745594500534, 0.025203026748532732, 0.04415328599392407, 0.03989652610353885, 0.05003841556308251, 0.0394528960779069, 0.07368645811032865, 0.026142306085075104, 0.04071224503399384, 0.047591948250849406, 0.044545530672034914, 0.04899336438205454, 0.06697510654527335, 0.0504847537095268, 0.03782906547008503, 0.03035144020442761, 0.021596844045204983, 0.027902287754019903, 0.022111735569553512, 0.09694171588747733, 0.03698575971347671, 0.005566651976081513, 0.08206720719294203, 0.04357892306401365, 0.023422385603489897, 0.005784795512520378, 0.04498951309811204, 0.03884661026419171, 0.05299282981263054, 0.03035430345804461, 0.020754986194773548, 0.048070523377147414, 0.05354545882812912, 0.010005048919288863, 0.028878741507087986, 0.01508061124402429, 0.02650514064777282, 0.033094737859022234, 0.039068159061454, 0.010275679054639993, 0.007548669386925477, 0.020735058332643202, 0.014503708732644878, 0.050278017222280466, 0.07364864401038616, 0.03521887750755395, 0.059085576870148225, 0.024293868073953256, 0.01027863136597819, 0.05173916522894175, 0.032710334090816404, 0.036725914180879636, 0.043735044122102766, 0.05748931010584197, 0.038570270858584874, 0.04782092427053759, 0.013538797051765987, 0.047504016678900494, 0.0271864858410892, 0.027863313030872135, 0.008025343178756415, 0.06493335965299799, 0.03023605970215173, 0.01202697232891355, 0.022084529872142503, 0.03428494354950325, 0.025793218970178597, 0.024740849734253945, 0.06540175347078232, 0.026506134646854577, 0.007348733845226948, 0.03077534538122916, 0.034798616994052164, 0.028085585781222874, 0.057653969213847196, 0.1225412103738035, 0.011734039458866802, 0.026700372409616268, 0.039612376431543986, 0.018357833877446193, 0.03186152399247212, 0.038326792794490055, 0.06639532354329863, 0.027736546546821634, 0.03557664056819293, 0.03148213810017032, 0.01695342425767693, 0.021029109691059398, 0.06828230535311085, 0.021647053447762327, 0.0463313888758421, 0.04558312398712001, 0.05382707657953424, 0.02811084753052602, 0.04467690325973015, 0.06832833191560161, 0.03484483507852401, 0.04140160159177838, 0.04160139349199111, 0.056333474950083805, 0.02005973075997205, 0.057710667381123196, 0.031427824381558646, 0.021232622863364317, 0.048433629901058255, 0.04015833282122209, 0.06861989731870352, 0.005980266676840163, 0.04189708427856526, 0.027912836784737247, 0.055843975409985556, 0.05229926360170207, 0.03754390839246973, 0.05223750159324658, 0.03747676461634617, 0.011529702742043282, 0.03504514791852525, 0.031413640263640595, 0.04020164360202128, 0.0190867550460802, 0.03627730075330023, 0.03571288930552621, 0.01378520540217118, 0.01852471847087145, 0.02889446163129422, 0.034209832458967165, 0.04843153465058535, 0.1274840249830196, 0.15181808011426082, 0.08777253209583222, 0.1508552608110251, 0.11814297702644141, 0.1657393379437347, 0.19081572461272442, 0.09021241488235612, 0.08977620441827083, 0.10960671209519911, 0.10847961289748069, 0.17400479845462308, 0.11876244338289385, 0.1304584609404687, 0.16619877619368417, 0.1358820110439293, 0.2661399867746138, 0.13965283370306417, 0.1171382756963853, 0.15160751318739307, 0.09880831975850368, 0.1996802352368832, 0.07329850352459377, 0.09458064822660339, 0.08059902266869623, 0.19774684382061805, 0.12375015074447279, 0.25360445942609544, 0.0563306634074017, 0.15992833121169, 0.26934067147874063, 0.1293123014751942, 0.16152323433949103, 0.16802456290010484, 0.150337906314, 0.0927439064628655, 0.1628812937246215, 0.1837388341945987, 0.235570810975567, 0.15802929117794962, 0.18398916108473656, 0.16351029787573124, 0.134170294829434, 0.20283892300100098, 0.20571495496457626, 0.18435738890642123, 0.2144751397352065, 0.101529655587529, 0.1175361511207396, 0.1503176049840066, 0.07535439239995134, 0.11672006063764134, 0.13600207234342254, 0.1750122193968104, 0.22272765336017455, 0.16644121237820195, 0.07404269665599832, 0.1623364979581487, 0.13348689843570033, 0.2927625840229373, 0.17194651938494177, 0.1667662175191987, 0.11869473653214595, 0.18286604554422442, 0.2622426217121463, 0.1442754388816895, 0.14244048976369444, 0.1037757104683307, 0.16971211670146835, 0.11708630429160212, 0.14886219114545854, 0.1708914477738642, 0.21631338303127598, 0.10859644896681271, 0.12762471703031372, 0.12018987202956793, 0.0713182122056042, 0.1775007640882846, 0.14649130223739534, 0.10522277394850409, 0.17768623397475292, 0.14360420796419346, 0.16708665677616674, 0.20026561834158438, 0.10791043255237803, 0.11683214696184283, 0.08383392852040068, 0.11424457774527612, 0.1473540551359615, 0.11639507847928232, 0.18011054985465544, 0.16653724916038976, 0.17014707078135785, 0.21517725931780957, 0.12286734166404895, 0.1758977557502447, 0.14747776301397433, 0.1378351215633654, 0.19400096498429778, 0.16205234062527457, 0.1800629911163161, 0.1847948710764608, 0.11085908199029584, 0.17921784291824988, 0.10197593244693934, 0.124268707999539, 0.14820091937097812, 0.11178264694829142, 0.11108692419985611, 0.07380076608951054, 0.1845579047597224, 0.07432089382482153, 0.04909100994888333, 0.09039655177583618, 0.1502084680983136, 0.15894067533794912, 0.0631674733613768, 0.19392749715235927, 0.17176370016269146, 0.07699158358117265, 0.13817675081231903, 0.15282258992233586, 0.21686528809368613, 0.1588628561266007, 0.23775377851580423, 0.15161672156424294, 0.08838956995356469, 0.16927687150816764, 0.12083864891000333, 0.10134693595670885, 0.1282861267006205, 0.20634973541863505, 0.17372068708702443, 0.16427955740401823, 0.17981113205032964, 0.2549290101254179, 0.10236349632783283, 0.19297405476531676, 0.11439878358355454, 0.18574105094998114, 0.22266307214815773, 0.1204952653197031, 0.0782343773772159, 0.10473617022075962, 0.22836085108499374, 0.17528683127414796, 0.1442881252977156, 0.10869996276714149, 0.20669214607727146, 0.12231637888978567, 0.1262072858310515, 0.12029160850591238, 0.11711507089315884, 0.226339757923157, 0.14790223701105965, 0.0874465310405339, 0.151328120921408, 0.11199305299669506, 0.17376231630482983, 0.2351231091926175, 0.2931748619002681, 0.12266454286873342, 0.13324761853343056, 0.12928769473106633, 0.07896176253956172, 0.08865352554787552, 0.0884199453397624, 0.11252686306233368, 0.13234616287292975, 0.14760664964635528, 0.19677849336256906, 0.18984498396035165, 0.10565015907970168, 0.08092465600179088, 0.2038379169760212, 0.07893812106621843], [0.05799335765562231, 0.044232844224860596, 0.09037517792274875, 0.047415246240674495, 0.05518025215414744, 0.05855573897039699, 0.026289484981868057, 0.02723272499297896, 0.05094294323615971, 0.0633573980491248, 0.06888803575308093, 0.06334645065268682, 0.03045528533778364, 0.09000871210328995, 0.0674916336673402, 0.019978990838412317, 0.008633940183978167, 0.0043434867890731945, 0.053209517782013264, 0.03374362199176704, 0.019609836050339287, 0.04753481724389619, 0.04726616170016989, 0.06163911263067877, 0.04361377240368917, 0.03478239508225553, 0.05393601811280655, 0.04210984221689644, 0.026227299709834402, 0.02663913708660872, 0.07188799009928781, 0.04527494596738008, 0.0203911978526101, 0.05544206270227029, 0.040020203338034695, 0.02282842614447638, 0.07446337085697921, 0.09328490243323388, 0.03439888380648148, 0.03658288556541647, 0.06833786204937967, 0.03478856975092523, 0.020992601771027814, 0.010527642500106125, 0.0391241945626755, 0.027208788575784817, 0.03126201805688682, 0.03396993585591836, 0.002321626821104738, 0.028526636005769816, 0.03080025664530695, 0.035909195505683465, 0.03907115063479832, 0.04426313917182627, 0.05739740253756604, 0.014371766367055958, 0.05298528767701599, 0.04896782301065903, 0.030295107844135458, 0.0614085125045911, 0.009786691835841105, 0.028856588159537608, 0.017394882424043554, 0.037585139244554505, 0.08952389336040906, 0.07219175162214427, 0.03844067942531359, 0.03306859127816654, 0.020887115294294014, 0.06761662091218656, 0.028349062570581035, 0.08680378327206259, 0.11737392434189398, 0.03335359896863661, 0.02210044534876943, 0.006817153574252922, 0.030883013293327346, 0.024100595581976157, 0.03722613129103857, 0.03486671071920184, 0.02707790819958093, 0.04123298947008387, 0.030437184595352704, 0.017305026056184884, 0.04214418976898155, 0.039120532662397435, 0.03771863006536038, 0.046238619458651355, 0.06924563793525582, 0.03463373955098852, 0.04756535733899763, 0.04090963524856395, 0.041947366459475416, 0.036051094141458316, 0.020633216519209168, 0.04905013532768335, 0.08147633123782375, 0.02365631629682837, 0.030301037364669388, 0.011016992653059143, 0.01403500464925122, 0.028453669961421724, 0.053923059735567345, 0.045193974304223256, 0.04426794637355112, 0.08768176599856346, 0.050119582578660025, 0.05131025558277484, 0.05166129239143864, 0.02550527524773873, 0.01902087339981189, 0.04315999937393973, 0.028454905278199626, 0.042512739347594405, 0.03183655144136039, 0.03314339210309329, 0.03834725883338721, 0.009447086974227381, 0.032587193117867556, 0.02084343296085154, 0.031883820981508305, 0.02965599324764504, 0.037170203042126475, 0.0391590055979548, 0.0441850058644289, 0.07235299780844681, 0.021641344177506624, 0.016058627816457904, 0.03345307931604405, 0.05990593063254511, 0.04841885972587813, 0.05105965673142383, 0.05974522070778955, 0.01189182292775161, 0.011812143080357102, 0.028278356485609567, 0.043271419201647086, 0.03691143386306302, 0.05293305197189893, 0.03496922477478943, 0.03357536993139694, 0.011724781286301873, 0.06247498350398195, 0.07708928277415615, 0.013710018660452579, 0.004866418406187047, 0.08206877767318681, 0.048597817864990046, 0.009512770395245283, 0.034014223398821014, 0.08201906622778024, 0.055373896198767814, 0.07692512545374132, 0.05151501939361615, 0.04270426132866452, 0.051613967309916214, 0.013986655882739974, 0.009740852964891782, 0.05654344815881022, 0.07305379205894086, 0.02180643612518907, 0.051505772712370085, 0.029783114047360518, 0.03798374245243688, 0.07029730045507032, 0.06732143191320282, 0.014427108558705978, 0.03896833397448063, 0.07134979034984304, 0.02233095928996561, 0.04554745493336551, 0.030641747308113886, 0.018294677588968508, 0.02962720940911001, 0.04167527501140872, 0.03224115886334931, 0.048806209102152824, 0.06584104360832323, 0.1028363564382157, 0.050059306780777635, 0.04274494059744381, 0.0027786200535633875, 0.02715089722656675, 0.07462404247733855, 0.014198661139685542, 0.03256842779416231, 0.09080208041855405, 0.06481945003953672, 0.012440015336558705, 0.10070506918935046, 0.03652050685618193, 0.09538667997525585, 0.027198576623754158, 0.05107503977694339, 0.07025040055234587, 0.09997017636534669, 0.01946546295056901, 0.04915595122222458, 0.019359016948710048, 0.06539433007879604, 0.0365808860759341, 0.033051423247783415, 0.025467330912849116, 0.043634774704133315, 0.02600490247019597, 0.06470734839357677, 0.14628375369694926, 0.032882052699043866, 0.01763110946593506, 0.08098492413879403, 0.019958526714734977, 0.0266897467701065, 0.049698904547239506, 0.14023855388645204, 0.04265675621647989, 0.01819645745619651, 0.08222243958903898, 0.02944339235733834, 0.03172171869195037, 0.029153541075967015, 0.0075702108217463385, 0.04416225305307777, 0.061890661431055885, 0.015363177986845616, 0.029495465268771497, 0.04535173862090996, 0.037091299816365206, 0.04851739012425946, 0.06005336425357288, 0.050926744307000796, 0.03230096734759789, 0.024505915465734662, 0.0358433042833161, 0.05354914371104491, 0.0464068983320988, 0.07123175918334915, 0.04113000810086247, 0.02950273927361254, 0.01210638787597418, 0.06783091868724554, 0.041939694088913744, 0.0333277358403129, 0.05863605179793893, 0.07409449952143816, 0.01981716242528731, 0.031641555251553655, 0.0181452157501612, 0.030568187545624473, 0.067927859453184, 0.050774978458761215, 0.02005023126971097, 0.027992440980949232, 0.04671075178550617, 0.015571312584553756, 0.02051219569459077, 0.081130817923094, 0.036649374336364775, 0.006972058467762245, 0.005757387759419339, 0.021464329986502568, 0.039690605499931884, 0.022100466416187348, 0.06979117680701517, 0.020669274362585238, 0.021678602863704006, 0.04645345732569695, 0.05149567950396769, 0.025931310148969777, 0.05142452525756052, 0.04982009582642106, 0.045575030268199986, 0.012275691392020354, 0.0355491456725905, 0.05500619314731129, 0.0797800210514857, 0.057680211555693424, 0.02497576293535531, 0.07904772526554524, 0.008931952216962894, 0.019479154856995713, 0.05012729325361791, 0.025242231298057784, 0.006084926736225645, 0.0502155082780988, 0.0450164947148052, 0.03556924781972363, 0.02359171401739361, 0.04400333577406503, 0.02340395544325152, 0.04623990265592452, 0.021662612693504463, 0.03986942574321743, 0.034830513064779585, 0.057580244742454066, 0.026340334067842173, 0.014070705304132595, 0.03924904008125586, 0.06635546398859832, 0.010689750535323495, 0.08370977631139179, 0.02831007252567478, 0.042454654561175455, 0.03117649008580033, 0.0650997156457555, 0.04048874271252463, 0.024131053322625738, 0.03545803100531621, 0.0859221309844044, 0.0652628310865933, 0.024657263796055512, 0.029687174941383065, 0.06278284742767293, 0.06122128444633657, 0.055380082358756376, 0.1300384608968612, 0.04326913625963273, 0.04145482938075739, 0.0288916654103706, 0.036089907986141985, 0.06810429716302503, 0.015710289552507382, 0.07617478829718406, 0.03514065610004529, 0.02253485550623267, 0.04220659912173306, 0.038124468973687584, 0.12504444097078618, 0.05396682250824186, 0.14050144461854813, 0.0390377147273431, 0.045648670469921444, 0.03584221643846362, 0.02860336737226575, 0.018364435640133677, 0.004672207456502703, 0.0445195947653584, 0.03867621698807325, 0.05615683039650322, 0.053734180757835995, 0.03282660325508445, 0.0421083674976422, 0.03336666842862483, 0.045366504965650464, 0.013726356443047765, 0.05215278376014002, 0.04171693104229147, 0.014065954601392152, 0.05470845690597931, 0.06882099539882715, 0.008348284191602181, 0.032066797251783075, 0.10189781446130046, 0.12750948208474344, 0.11844749697634291, 0.1885285231495096, 0.11716174863038525, 0.17517032462262339, 0.10203763316836088, 0.10137159632699144, 0.11003074176128834, 0.17061757134093394, 0.12165352131330198, 0.28585360475605537, 0.1798911422731415, 0.10220675473852504, 0.2110011914684888, 0.13145835889923957, 0.16748024210814508, 0.07706046254644472, 0.18383959007840003, 0.12204658570549182, 0.21296940924179172, 0.1416149534164898, 0.11423860225946673, 0.20676484782128565, 0.11267670986032295, 0.11542799206630838, 0.10008075349633733, 0.1316168624907732, 0.11368528759527592, 0.14757962206438666, 0.22990960507623612, 0.14996138942097464, 0.1524039841587505, 0.09213180987224465, 0.20740114512943453, 0.12439672895256551, 0.1112158031713578, 0.23626816549128105, 0.30301063411658813, 0.14470619479975394, 0.11704891154001798, 0.1705949257818922, 0.09395863845824234, 0.15012599107238556, 0.11537148542101346, 0.2233087157289828, 0.1284110296757952, 0.16009650283282803, 0.13773528498507318, 0.1080933207225415, 0.1258751101070835, 0.12908725548655758, 0.10387494949804199, 0.08884408225816104, 0.16166591055450902, 0.14949162430580587, 0.143140479621868, 0.1916403569761784, 0.2127936380284448, 0.14384695058388097, 0.1743875359815936, 0.1582733514688669, 0.10107253858399007, 0.13144792478171088, 0.13074151510673185, 0.13975951910739945, 0.17976619333269137, 0.14375877386379626, 0.15971946500001416, 0.11477674072187756, 0.08418795307196918, 0.18820938624201283, 0.09193264999456945, 0.18840434029698375, 0.1439633959483716, 0.11053236847322796, 0.0781547348766077, 0.10516530969330382, 0.09186757082540183, 0.18399645424177571, 0.13309558072397787, 0.15738383145822635, 0.18295989131494877, 0.12491504105949595, 0.07008986682781289, 0.10773387226846912, 0.08864296885627894, 0.12978012072703532, 0.172242796228778, 0.14997045990199814, 0.1170120473891016, 0.13429320597600553, 0.10496623408530029, 0.13023911464598872, 0.11781345962757066, 0.11309651072107016, 0.09376836520048881, 0.1586461911398557, 0.10321318742729003, 0.208827355696309, 0.0873803640265138, 0.07451430804306462, 0.18610622974172716, 0.18493638283783392, 0.1023821046035136, 0.1303041861542771, 0.19539627156430678, 0.11063595888234916, 0.1317492271623304, 0.18460534092399383, 0.19109824251744056, 0.13019105028961936, 0.09456272176917523, 0.12642703815213135, 0.14459725709692126, 0.10328895352300137, 0.1900904691748081, 0.09304360005884402, 0.1371248354834895, 0.1705141341493976, 0.044211807450459856, 0.1432188197730049, 0.19306028562207378, 0.10455679839416858, 0.2166409775494568, 0.1268688793624601, 0.13201876753760924, 0.11836478246315835, 0.18439417644854517, 0.11055810902748378, 0.10711117302097621, 0.10062571780215349, 0.2023474316322996, 0.12014977498761109, 0.1324597124250666, 0.137180223640415, 0.20080296773343317, 0.1586870695914953, 0.10135410653968012, 0.17702096322130773, 0.111621783805951, 0.07950871867398102, 0.15934058855618202, 0.11954213702870954, 0.15176203312172046, 0.12035780616344945, 0.14356211909363348, 0.1416729769158748, 0.16526293850714163, 0.21608311232299576, 0.13356649497103307, 0.17770481926779594, 0.17308192297575936, 0.1627530046408215, 0.1488956538659911, 0.1880748765242677, 0.13774029520009795, 0.10901172990880667, 0.08030664521239458, 0.22192169822031454, 0.14193407500222807, 0.09731002031795441, 0.1189862023438177, 0.16705535442358063, 0.13924567329306758, 0.14722020425383123, 0.09131167444490618, 0.1524650260445572, 0.09618657535963482, 0.16290668187843216, 0.08101542975993888, 0.19930407074430298, 0.11003309365121589, 0.19119234875805918, 0.1899759083866112, 0.13988132708736006, 0.1910756429236743], [0.1243069894131153, 0.0853109920036889, 0.03332152669768661, 0.03214053704493469, 0.08438803991603275, 0.015819608384082397, 0.02546261947211479, 0.06844197339828938, 0.03363861431998592, 0.01734142480868726, 0.013626736284594142, 0.02677368702396991, 0.02314114131994786, 0.04040843371542231, 0.0503142110462631, 0.035703634963400906, 0.03603614393561598, 0.06322034108903139, 0.02538935082303661, 0.05904878932802428, 0.004857202847262905, 0.038351299947187785, 0.07425314100879817, 0.04367589830390869, 0.056477882523810675, 0.03417095349680993, 0.05392621601781538, 0.04852381760194417, 0.053958675163167144, 0.10550818000469478, 0.04502100314223959, 0.02444699947391787, 0.037273314646295005, 0.10256218889187421, 0.030718467183290955, 0.0687299075446302, 0.09032421009314638, 0.020098897005100886, 0.04170379263439006, 0.03308870491661853, 0.02192990077028592, 0.011336158288853064, 0.040148975057227, 0.015267050231716808, 0.022353714016536554, 0.009690092936638863, 0.03489111061959017, 0.11081678627599632, 0.04132725658916658, 0.04189130414517657, 0.045416844603154934, 0.022296171237324035, 0.0542446481244218, 0.039943391532306714, 0.08931280549375281, 0.02245059349544106, 0.03773260350909926, 0.013336965442454864, 0.027395344391885786, 0.04134969530446876, 0.05337847081283408, 0.04189842493243275, 0.11964002008279485, 0.044563503094738534, 0.02486711443071404, 0.04162134625197899, 0.03290077205747366, 0.07772993912259418, 0.01296198647093749, 0.02761850963466831, 0.05143076121326416, 0.023100686131886417, 0.029502949947791717, 0.04741806927467546, 0.03432047087699175, 0.06788968529191709, 0.037863079773923086, 0.00532283348166534, 0.054664334071980375, 0.023125254571618094, 0.05033869138588348, 0.054280190773668795, 0.03832058365186376, 0.011663533514365556, 0.03639199177644426, 0.01565887739190892, 0.056014590851602056, 0.01875543925580719, 0.029814581108850338, 0.07148734909752685, 0.017235572524969617, 0.019053407238736268, 0.0182684026883855, 0.04207606540031491, 0.06393990832410994, 0.052083065928590876, 0.07843850150464043, 0.01811050239109224, 0.024106469561135577, 0.01048799170436518, 0.007402094741982799, 0.1085411987057136, 0.07911779932797917, 0.03783879095628377, 0.007435442549326728, 0.014994404327514914, 0.028955059186104807, 0.04720791986572647, 0.016560007465041934, 0.019904500279094905, 0.10751903823186314, 0.05221151206041536, 0.06626193231392292, 0.0566595258010972, 0.07882566701981329, 0.05119244275133937, 0.036034240207124146, 0.029868358565915017, 0.012309532368465537, 0.05007433742585202, 0.03934265602560293, 0.016670986792192827, 0.11700813267980853, 0.025376363717500242, 0.054074235696105234, 0.023211845489699515, 0.10584340475860143, 0.03216209092868432, 0.06841447084180771, 0.11128034607897844, 0.03076532686639938, 0.009581725011699864, 0.046372841893424915, 0.04272662343517427, 0.05824892458716228, 0.062232317493086865, 0.025791782555320573, 0.03972964917099284, 0.010225889085221195, 0.04013584431020483, 0.026304720555462187, 0.05548748405530088, 0.005173280669917023, 0.06948122529373055, 0.04375994964052112, 0.024601276175329284, 0.04713193543495671, 0.006110146829497911, 0.019589950323044773, 0.056040963428395416, 0.0829203303663, 0.010369135078132875, 0.041264958319164095, 0.03945544715069475, 0.025345679980913, 0.018254729934156905, 0.0490684180159963, 0.0866487040935505, 0.014526147447947054, 0.043305939123515165, 0.06042965515066059, 0.06458028505045561, 0.05833757628176001, 0.006215501634869725, 0.06511944240980572, 0.010375599902603897, 0.026213935305995327, 0.0710038633476342, 0.019051187498975667, 0.037576662481672345, 0.023301380100629987, 0.02830404341371069, 0.03737612364573344, 0.10912501133017002, 0.02488664201190395, 0.0327112112614897, 0.07212723169716136, 0.05421383606810724, 0.024558829158664714, 0.03427255207732801, 0.03698920710913597, 0.02203027935578458, 0.07277196363335656, 0.045994949872575464, 0.038090355078419375, 0.05167644178014129, 0.03719179906071194, 0.03716921095826453, 0.019274391046154405, 0.03766815253202954, 0.008846972956352176, 0.02491734873112892, 0.05401329340172872, 0.017306383947030674, 0.03296871256503848, 0.036730935887223294, 0.021564300630181547, 0.014736038302221607, 0.021636293742865808, 0.04017198450803276, 0.026967761993047693, 0.048163254489941944, 0.002371500102585302, 0.02407276935334648, 0.01539147631715863, 0.07721808513686543, 0.019107023817336848, 0.012900201479844269, 0.0294945708611199, 0.02976868861174632, 0.01470049469536471, 0.0287383041840287, 0.10756268992178863, 0.04346359235745284, 0.03659125890642886, 0.039653377457251476, 0.028277124999271288, 0.08266536864422022, 0.03261963694146083, 0.023581620808991215, 0.06419758582788129, 0.012904768321482886, 0.034236381235983104, 0.06857099026561746, 0.037994896692614404, 0.03757162162313058, 0.02554168740677978, 0.04724534326082757, 0.032744509273118554, 0.08257969703164794, 0.05597544375867133, 0.035804226138298555, 0.020873488505340872, 0.038241810661049626, 0.023085534827963963, 0.05241507311321555, 0.013322522769862366, 0.10680950291815305, 0.0418925988337686, 0.10458052413718355, 0.04116662710364308, 0.015313052853959945, 0.04435033146892825, 0.04123137302456364, 0.05371617386117578, 0.041405259661616824, 0.042428672689223484, 0.02594252184574162, 0.0038442153186957926, 0.04780065358406113, 0.03941392901563837, 0.0811324650121312, 0.09738789315545753, 0.06308447922609987, 0.03633996674550637, 0.010686214081943037, 0.06318285640689635, 0.10065184140037145, 0.007204805555257707, 0.040040439550554564, 0.12034793895098472, 0.03354032906974035, 0.0623035368569676, 0.03627434365391251, 0.03529610300076104, 0.05969135706583339, 0.023250762756252964, 0.039733242123357715, 0.02706867684009335, 0.0026577086358766763, 0.008882024351717725, 0.022818871112840793, 0.018968796657939112, 0.03923441546278135, 0.024899058381936727, 0.07583806967182506, 0.017526789358065977, 0.06119332606753996, 0.08194690074531302, 0.01795052791074399, 0.02332751135972719, 0.04043358438197644, 0.020929491447825587, 0.04709306413367872, 0.00705346680103591, 0.06506849756284107, 0.06194002047601727, 0.02163905932027246, 0.07924773550081639, 0.03339503666446094, 0.05238553659329492, 0.030947690266334725, 0.04126745959623687, 0.11203752440069953, 0.06721846203530027, 0.028302348444178223, 0.010542219238085373, 0.016727698366007498, 0.06386257174815382, 0.018633884084861607, 0.0437489754310058, 0.01584607767947619, 0.037929894132239204, 0.05965696737891244, 0.0813455293856321, 0.049918143589410095, 0.022442271865363565, 0.029976398030656482, 0.036698829142316695, 0.08922403888596643, 0.05129700226168479, 0.11559941190024538, 0.028924143707920468, 0.07450210426243083, 0.01327414527505396, 0.04533071333782808, 0.007354101248746438, 0.025763305151955258, 0.021336295626937382, 0.06813645753408633, 0.09451399857719099, 0.015057743519484518, 0.048044809635968945, 0.03960329062876202, 0.02094271221017886, 0.04383683422460191, 0.02941530948925403, 0.02593050001098985, 0.05879475457233287, 0.007286310607131812, 0.0726929340030878, 0.029732056202427037, 0.04577893989100572, 0.043291299183282166, 0.018404247314338724, 0.02973693426728489, 0.036654419025346156, 0.01865307075692521, 0.04537620746921148, 0.05034934000803098, 0.01708939528813766, 0.05143784752656376, 0.022777176777561827, 0.010702967467237144, 0.06250599857359644, 0.01478361331992933, 0.06088756505520113, 0.049495496712024176, 0.020719771048114188, 0.06263234945494803, 0.028437472947482622, 0.06799218019530659, 0.17149771443538128, 0.20539587934411344, 0.1690348030458535, 0.13152624961108933, 0.21703036471961007, 0.08751225372355792, 0.16105998097167862, 0.1909196521005323, 0.0809411422139214, 0.07327589626994825, 0.10583560598353225, 0.13658227669375558, 0.158446257513377, 0.16154514445412546, 0.12587301102617096, 0.16973877656123332, 0.16197168688860633, 0.09570381739327023, 0.19617922874467988, 0.1815756317228079, 0.07711149166308104, 0.15237427526904693, 0.11767528800954742, 0.09973409871060042, 0.12041492567908381, 0.18802983055432, 0.13011505436753074, 0.2191839298053134, 0.12035232863479084, 0.20420007738134555, 0.23198843062404664, 0.14734519915955682, 0.136349753686978, 0.20459475055817636, 0.14700989779685775, 0.2681152372350616, 0.1982124260957203, 0.1900915263761436, 0.1373157599159787, 0.0936602472117351, 0.10027327139170901, 0.16499906718250246, 0.1989112668220074, 0.11322834679195959, 0.16944403189324564, 0.05233797402451596, 0.09959908337482523, 0.1611541025340557, 0.19430208350381545, 0.140009141196647, 0.1287065863969826, 0.16515397016079197, 0.14382885558710945, 0.21999647330132224, 0.16782821456511177, 0.11077314224695006, 0.10040352166059519, 0.1222868002350292, 0.11337113025928698, 0.15899653846938766, 0.16194462866312073, 0.2598421005231719, 0.3108508698642254, 0.17077501773113207, 0.128134694100628, 0.1313316326348051, 0.1084768396591948, 0.1414476704573439, 0.1181339371889349, 0.08898269820718036, 0.22614259753496418, 0.09923748987456484, 0.07733526594576336, 0.12150410352455032, 0.07229431547344693, 0.25597219205191063, 0.1566632951219236, 0.159494970594683, 0.11554636031148896, 0.11540025968344943, 0.2220834500246471, 0.1381153412043087, 0.07252149118651306, 0.12516835569253854, 0.33773415151142305, 0.09252748662425626, 0.13232572364710993, 0.18413525405189685, 0.11106948037782025, 0.12645079453866329, 0.12313159603265025, 0.15787219718819664, 0.08729301468138734, 0.09975169575022114, 0.17742622373325212, 0.22751138215103459, 0.2671110185403978, 0.173223388771857, 0.10085039606858646, 0.13380805781531718, 0.07599160135273011, 0.2221639505437305, 0.23191434992176874, 0.08600090780565817, 0.10225187731726516, 0.05681257484660995, 0.10152201769092392, 0.17134648867912833, 0.11050343333232789, 0.15427409671247005, 0.23235129583026135, 0.10830905874289813, 0.15558465864629517, 0.08399783303180049, 0.17222540603289682, 0.12698406068187568, 0.21138276454181443, 0.2500556337256586, 0.15272359604076033, 0.16078002180062956, 0.11410324218412561, 0.16687659546732905, 0.46233023186364486, 0.1138306987441836, 0.15517071069728944, 0.06369521601065513, 0.18001221480869478, 0.15664535334273694, 0.19289481063042918, 0.13944137811420426, 0.10393607565352034, 0.100435919518913, 0.19197161339463728, 0.1659896495121141, 0.15598284050581918, 0.2590289748003406, 0.14225436104161127, 0.19896772750202688, 0.1240071732430689, 0.20385886181987103, 0.15367248786553261, 0.11803472880274059, 0.10391238055402234, 0.20601869350479496, 0.21867927704607287, 0.14666419296014696, 0.18937143437083692, 0.1450944481597793, 0.06317459797907261, 0.16385326011767312, 0.19349611304219694, 0.0772979574638509, 0.22130320479552593, 0.13604578532038197, 0.1957296117419197, 0.14433989751963847, 0.20240902510141173, 0.17246919053216136, 0.14109130167672712, 0.1190727549575029, 0.11784453981465871, 0.14661648100422275, 0.10518164268784946, 0.17466634602075623, 0.14682623587789076, 0.2025949852841516, 0.10821810878452756, 0.1767073421468658, 0.11696821949895352, 0.12985248539236285, 0.0987314734788191, 0.14354658283052907, 0.11510774433132141, 0.20056560305097412, 0.19854074073654993, 0.15975501147970078], [0.03685725229461828, 0.04688967928110112, 0.04847425937412247, 0.05373740981843683, 0.04756595488757857, 0.05377391773846842, 0.03501286497339606, 0.03747033713866146, 0.02087150816805661, 0.05812344704604438, 0.013714336523515804, 0.0212780250641968, 0.036762245900688634, 0.09705457596048232, 0.03087447141297162, 0.004603027801720365, 0.04411859753271265, 0.06565335972775375, 0.05004272863809621, 0.05723612570774652, 0.05964335399649798, 0.019813065770112222, 0.032967735802935015, 0.0037724048701009805, 0.06950953990341195, 0.030452847262964617, 0.011869414855966405, 0.03100659285161284, 0.009711363367856512, 0.02019300516093931, 0.025788369633617903, 0.049039559483888655, 0.07157046963731128, 0.07184965505955682, 0.031168246979735074, 0.03599165720985301, 0.0048506872694668995, 0.07017118706097526, 0.03403975327889766, 0.0222915115075246, 0.019268541964852524, 0.01973122651238115, 0.03811130758314844, 0.03287178712085851, 0.04358570677258315, 0.07715720412952286, 0.055287699815967394, 0.03214998673948069, 0.09259967508936122, 0.004225583942306619, 0.028466787301905216, 0.060757923826214776, 0.02574594559959106, 0.0447730741073047, 0.06756146258163838, 0.03723584911635807, 0.009642991935834289, 0.042339630289784366, 0.04812044549673315, 0.03792733156813249, 0.0501762232893417, 0.035563299146991585, 0.09878333763129289, 0.021538154049325856, 0.06784322972018873, 0.007260845844528728, 0.057940060918730114, 0.017234195481925722, 0.031347591993248755, 0.03492486828397359, 0.03333037884365166, 0.012341445676171252, 0.032442942592165167, 0.019128336383390333, 0.0496302132735089, 0.04124304054365043, 0.06177139303256428, 0.02293300863745953, 0.021853443280222918, 0.028353276054164576, 0.010950230005677911, 0.04485405343134077, 0.05145233807965152, 0.014477188683926098, 0.006947613080903407, 0.014970036028253456, 0.029714487891103473, 0.01738444256085542, 0.04276213927134391, 0.02679007364467027, 0.029110760811055382, 0.020170327043160796, 0.1165751934111599, 0.06729413620046071, 0.034730266629447865, 0.03200282507966603, 0.025627217293086074, 0.059689763602950884, 0.08587779747622629, 0.07049734133385843, 0.011024294428587442, 0.03275419262448146, 0.034714370305019046, 0.04198974261300699, 0.052921461061604565, 0.055643999648671, 0.029931865339618058, 0.023312800556361195, 0.035572549658677274, 0.08296832577475617, 0.03572938700897559, 0.03878827649919737, 0.009090706702291725, 0.06010683719068766, 0.03507695588914137, 0.04034263825404548, 0.03050332479629546, 0.012370072466681802, 0.04987738005095913, 0.034581909872471325, 0.01570715529528717, 0.033736650591656085, 0.06344111230705055, 0.0637986761848292, 0.06409801738036257, 0.027970004180866866, 0.023644474492738807, 0.06571059415657675, 0.050476763412476554, 0.017252206209025556, 0.053625560981491883, 0.036891634320659984, 0.02852708225198571, 0.04394640778041175, 0.030497176940703107, 0.014530007573475522, 0.09011647769159849, 0.022691796278400768, 0.041020093635926326, 0.02354055466581016, 0.052593142590335304, 0.02972311021069125, 0.05689114865456378, 0.01720200638256727, 0.024590514555212953, 0.017950706026186387, 0.016068550570297147, 0.026668683182628408, 0.002908640974877222, 0.05418765501329496, 0.029361214105700775, 0.012259930090588188, 0.04351662479401116, 0.008271262669304927, 0.029044835114731427, 0.007965861239485563, 0.016223871066505392, 0.07362084267961402, 0.07834671651043239, 0.008122059385172062, 0.08583054517305667, 0.01958190831505964, 0.014774089889420618, 0.026321241241549293, 0.022407114175298525, 0.062205822342225624, 0.06093480203661227, 0.06036174528661275, 0.028567956873185696, 0.04343971722729264, 0.06691788743820883, 0.03764933358216959, 0.07289285996868726, 0.0764198445024029, 0.011451052325297029, 0.020435232586497744, 0.014128613890328956, 0.10060085824901059, 0.03935326634335422, 0.04841709389321266, 0.04850061662915734, 0.06216784736381904, 0.029093508511000586, 0.0264539678896507, 0.03321217147693519, 0.02958388905221176, 0.010378955367712245, 0.05286590053489613, 0.12091832971500775, 0.08438887495187022, 0.038582237151962136, 0.013070453987306645, 0.015328366951566311, 0.040089400229795326, 0.06217737366715747, 0.030377793629022858, 0.0367325293501058, 0.03911705079278158, 0.03883297389913951, 0.02663241466507316, 0.052392933172203844, 0.017750465964537956, 0.019241364995738672, 0.04555187909112823, 0.04390492794975158, 0.08314729157474735, 0.0952315012053136, 0.012212679702638379, 0.03140442805635112, 0.012052983886772587, 0.05324812095251776, 0.012039828241892881, 0.03746766349180572, 0.03782560275266728, 0.045618969241097096, 0.020106534901705962, 0.007891723559418274, 0.03821881270156272, 0.031910149508246013, 0.0452270922851899, 0.0053502220825682725, 0.04947188205175823, 0.05381457785504961, 0.029470031149685386, 0.020837294681358243, 0.007871748295597612, 0.023904333431874553, 0.03917392516028016, 0.07359166239057818, 0.0358624718031816, 0.03548185250932171, 0.04348485895823087, 0.04518094314863125, 0.0460904389018974, 0.02425139998987077, 0.03467123189400281, 0.011215842265125004, 0.00650826069871865, 0.07131545428907679, 0.046056911063891266, 0.053970128177635135, 0.0397231106105591, 0.0412597335995205, 0.06970571203818245, 0.03254391298058533, 0.07263647332306832, 0.028809707409011263, 0.11284888812130499, 0.018237966015153838, 0.026947506628329718, 0.02014962351700712, 0.02428119889490547, 0.02568967835677247, 0.06340498360054148, 0.011179342963582566, 0.039480996182969505, 0.01212687115184963, 0.019610782168925773, 0.011887430371115766, 0.054266228821248784, 0.04119164370481045, 0.019352989751965772, 0.021440780443710186, 0.017991285703535524, 0.036637848543543974, 0.08862496579005834, 0.022754556116377635, 0.025989603694348086, 0.0926762379165138, 0.06868077832604609, 0.04200526738479253, 0.016266785396803773, 0.031033300591873068, 0.0836424678263645, 0.07842679568115743, 0.03417213327221332, 0.04078555964834748, 0.045019107074626995, 0.07033615643458982, 0.02317731407651257, 0.053976513520484014, 0.03942258580918274, 0.010247959120709811, 0.011538596065234275, 0.00768731119141223, 0.06992737957907301, 0.08264149734449965, 0.02591443514721769, 0.027486778900868473, 0.03938156563127714, 0.05173977043840194, 0.08370671962057391, 0.021440962389592203, 0.01088546876299886, 0.03997497350698517, 0.027268782836355032, 0.016923610030883746, 0.04248739332861958, 0.06176580442115665, 0.07539121058559226, 0.11569279801821518, 0.04654958986887529, 0.020643457199536988, 0.007069028440802809, 0.029052808174803376, 0.05131383704382086, 0.011862717332288384, 0.030982321270951824, 0.046045124801176215, 0.03271145257918585, 0.02391152891270336, 0.01178855236033879, 0.0459284496103083, 0.015824831188506177, 0.006348379585336173, 0.01833056689300124, 0.018748529142730178, 0.10981354817387559, 0.031387376854376446, 0.02392431683537941, 0.024779912557513006, 0.02285128812335672, 0.015436279054190365, 0.037725524856678905, 0.00941377459844995, 0.028026024360329877, 0.04952181566266283, 0.03526943548011684, 0.03560492070391774, 0.01666935694013392, 0.023474900930699323, 0.049011451717946804, 0.03700198545571297, 0.007200678256565646, 0.014963908282469117, 0.012930107637188368, 0.011338668184414988, 0.057601909708952716, 0.028261849206061136, 0.014025481218742508, 0.027476300733284127, 0.027645680858122728, 0.057487211024929444, 0.0495564581585988, 0.03410044276425916, 0.013271381612867119, 0.0123773024214672, 0.032948468691639365, 0.023128941369753693, 0.03398734520399763, 0.10792482734447527, 0.036706689204419815, 0.13643318066193214, 0.12528630258936074, 0.17297874625411727, 0.14913641997883398, 0.27996493203024714, 0.20360760030246552, 0.129450932745972, 0.11720276497785123, 0.1076334841068714, 0.09391725438857272, 0.07726360608132617, 0.14771141983087988, 0.21612579874213667, 0.18785228201698875, 0.17151689727700528, 0.12721611637501948, 0.10662174242879115, 0.2068615894043638, 0.1308735886648778, 0.18297764923303358, 0.09407060220837594, 0.08245454124745824, 0.12666715309023857, 0.10682103254141347, 0.21153118641626453, 0.13936300731955037, 0.053661050004584175, 0.11383623755987614, 0.10922238876622532, 0.12075820967795388, 0.11177680169742917, 0.12839982180946297, 0.12067217800405719, 0.24839490832340336, 0.19856592970750025, 0.13181417609655088, 0.12210126906152695, 0.0792999290710976, 0.08308345346801704, 0.13685298152267933, 0.12972778160004847, 0.10068437715451564, 0.1673202063407629, 0.1431562457113497, 0.09301949893274615, 0.16239030797395015, 0.1450311846189922, 0.1361033644887709, 0.14867578663172262, 0.1695257275094909, 0.13840254756712145, 0.167377065386503, 0.08987879891309047, 0.08767163831620448, 0.2286122964635011, 0.08610724080954829, 0.11173578534996319, 0.16909175402214452, 0.12562998495395147, 0.20483006212499835, 0.17289774011700385, 0.11249178389628088, 0.14038314532128074, 0.10637070307688368, 0.25995679920719517, 0.12749641262475522, 0.11769507606063159, 0.11147758307596368, 0.16551516529533172, 0.16817028814506146, 0.09474235406566052, 0.28947079614285504, 0.07091800021308084, 0.11342042801721443, 0.12584213002194322, 0.11894311755895616, 0.08411812415767102, 0.13588073933797498, 0.1569841633881292, 0.1406127112286706, 0.09839274770309848, 0.1330631598830223, 0.08778459798063963, 0.08904670485325399, 0.1278538003023113, 0.055272477648911945, 0.11497477445030406, 0.08075256201048052, 0.15167203311237598, 0.1474405158190958, 0.09486315080956106, 0.09804125890255937, 0.2419385338021863, 0.19982444362774973, 0.14237287484349745, 0.17094081447970483, 0.16026726383115017, 0.16692760160132764, 0.1994403271425155, 0.14363040817120384, 0.09086543588989204, 0.11386670487662477, 0.16471480259731894, 0.10125027864330238, 0.18215640297820493, 0.10628335373175722, 0.10801904083740328, 0.0988814505117555, 0.13808273650225134, 0.11435173812412447, 0.2126821569137035, 0.12296009192904159, 0.09589351608508057, 0.10873912518183071, 0.1672061664923545, 0.17984123930575388, 0.11772838556357931, 0.1124426776603345, 0.18645150556920037, 0.15798784582124603, 0.1635164265791255, 0.11786523951037277, 0.1675621062637337, 0.14081197069777598, 0.17084752029228598, 0.1320846204555804, 0.12597278631742925, 0.21209099750605323, 0.08352510315636474, 0.12236743864993896, 0.1443596779098434, 0.15359931114700534, 0.12937329739572542, 0.1387425833531926, 0.1771904065484001, 0.06939442753190957, 0.12431248226353239, 0.11414645720393428, 0.10182630015356887, 0.09124743797245527, 0.17496656055652327, 0.13699922770742448, 0.13791715425829734, 0.10069770708439812, 0.08493835151556038, 0.14023170506040897, 0.1198995017236279, 0.15214968893316486, 0.05220489306074958, 0.12799653780436324, 0.21121152856897926, 0.1615422333200132, 0.10531362431544451, 0.1006177734703787, 0.1355779507467824, 0.181022408989168, 0.12832122884931105, 0.11403052511835292, 0.13868494289776973, 0.15906626779225566, 0.11165587471858149, 0.18076065206719985, 0.10451810329311317, 0.08746133952011025, 0.10890503684359212, 0.11126014434041516, 0.18044310862258559, 0.1579155884082279, 0.10121095535014907, 0.16560775468186026, 0.25339206920996793, 0.13101114741256162, 0.11592660039182633, 0.32892720473389475, 0.23821318612223674, 0.12000398079474127], [0.024639982767703555, 0.004159121026825761, 0.010178518996033217, 0.06873035953650553, 0.05705108483051581, 0.018476387898948406, 0.05178933632710288, 0.029899205096186172, 0.008176965864315149, 0.027950219960222324, 0.030335444288568634, 0.06649651609721684, 0.08141662234500532, 0.11602791551981242, 0.03128454295708047, 0.008789212799691146, 0.030754835292276357, 0.04272824754157374, 0.04917233784292494, 0.03788333513864106, 0.0489425650917955, 0.02222142212333218, 0.08018742660961806, 0.02366734030205877, 0.041190927412601254, 0.026268957655936963, 0.07501894548054665, 0.04594487070496525, 0.05230361498111198, 0.026374559045859405, 0.04935974593184168, 0.046524791602766326, 0.07800492638301465, 0.030059553044397506, 0.043514797674311746, 0.02301282350785069, 0.038107588226276065, 0.05471863055361375, 0.043804662362221754, 0.044570478325289105, 0.06497979990296787, 0.013401533247933034, 0.061139780352072376, 0.09181280319969501, 0.02791242884291757, 0.05888793001612348, 0.06098218840516864, 0.019747967448746486, 0.0553348065624314, 0.04835363883044451, 0.042002628211893385, 0.014587923820551126, 0.022422656184062365, 0.05341894706831344, 0.07735581242389257, 0.023927122632402088, 0.02393147209659219, 0.04913287665394526, 0.054074519148637215, 0.06230486601951623, 0.04043923044997839, 0.03285091888580111, 0.036777843450826984, 0.11338711085338747, 0.08449958997868723, 0.10358227326744988, 0.02202413724585166, 0.05921635190926253, 0.039254709131895535, 0.032667253136394486, 0.032600982700504606, 0.0460345987530966, 0.07240693039831615, 0.07627845531509769, 0.018435111081588174, 0.02298865534905945, 0.04046565665292644, 0.03697678882388338, 0.026544452449607275, 0.03349501496901916, 0.02295108831247255, 0.013221380011659237, 0.06635647522465837, 0.013152598722597525, 0.034087786991750045, 0.031047272120392135, 0.02194949155372958, 0.04253564920697001, 0.03403309980527528, 0.0058594967460169674, 0.053237185047398654, 0.03221882740035653, 0.04422321066921277, 0.07367650662819225, 0.03845310537144542, 0.02625749889580954, 0.027168716431685516, 0.07477731368834935, 0.04687099439662792, 0.1754622654088082, 0.0476221053019887, 0.05001562061689554, 0.015338903533354884, 0.03786376159217569, 0.058980435132980354, 0.10334434167992684, 0.009111037718192225, 0.03484729805120057, 0.04380671930829844, 0.028516651964896632, 0.10743854537365899, 0.04193022907260926, 0.03200148442579854, 0.038067747823773854, 0.010483762899023152, 0.028186109923427145, 0.10986407167248188, 0.038147631642078204, 0.0550733101103575, 0.04375555612627537, 0.01870838038983845, 0.0883692073365373, 0.049272526821662346, 0.04190266139865403, 0.04849758675141681, 0.010096760177534195, 0.02040170857893123, 0.05981582720133086, 0.016542079092393962, 0.07569923921818696, 0.10308130539112514, 0.04778130603353343, 0.05635752628046659, 0.11473866615204081, 0.029707336460330316, 0.05453403783781875, 0.049351801600066886, 0.08038578209497275, 0.04982660374333782, 0.042616724291996616, 0.05303011531190527, 0.10139041910729102, 0.06938695817464782, 0.031642671824703296, 0.052233640510108204, 0.04077324095452505, 0.018085579635695587, 0.03914633833412682, 0.03730649008385597, 0.0396443797545808, 0.0511990349379278, 0.024459059613065857, 0.024918754502469977, 0.059365647123946305, 0.08489281524934116, 0.019236456287363847, 0.001863115537543631, 0.021846824280557134, 0.026941232368229862, 0.03908274154509268, 0.053537981809988144, 0.007094857095169925, 0.04643816621072831, 0.05695160448310837, 0.029941223103613145, 0.03478193925994058, 0.016485333044622696, 0.02439034535669752, 0.09191585734726922, 0.047253873649864435, 0.020307652134027694, 0.03207170212971828, 0.05971440482103537, 0.021500564030101223, 0.07554733164368138, 0.04487270001141776, 0.0728715320808753, 0.0918615340525585, 0.04003106646480099, 0.03132255815510308, 0.052016596309840686, 0.013050008058217506, 0.03986281057399127, 0.016176988400759238, 0.03162668356972356, 0.03663597545856911, 0.035702470509756, 0.04783773990047555, 0.03569610814954485, 0.09918574829615893, 0.02648994912423434, 0.07543421876166137, 0.022991939951034806, 0.04885359164026957, 0.034922259754591414, 0.08361875740510803, 0.04633581303360482, 0.05798751240476005, 0.0329459520928081, 0.047176054438516024, 0.016932799255535487, 0.021222975901177814, 0.11089585421066131, 0.05780113087366185, 0.03114237427531231, 0.016812958206320484, 0.010140606262270483, 0.059547543210247834, 0.011380204514059569, 0.015718583411897625, 0.023389815375389113, 0.01701327679198115, 0.06875919508597544, 0.02406607374488827, 0.04212478859229915, 0.0553294018121256, 0.0670008547604084, 0.02666582375945103, 0.028958558292698958, 0.005367814812944421, 0.030645026164429805, 0.06303237758636956, 0.054250727032100966, 0.016757681132144025, 0.043776761440019456, 0.013710123997542166, 0.04666973160760057, 0.038709748656519, 0.022379309014086763, 0.0069877019831760525, 0.026041599996988813, 0.08180870614465206, 0.007573108549319929, 0.06907096222764061, 0.024589001531562498, 0.04619894759549249, 0.02300694569825165, 0.011004561918877788, 0.018385560514645714, 0.012031624397833743, 0.06924340861939615, 0.014803464573267248, 0.016523193109840635, 0.0266201266147677, 0.04616595218859373, 0.027329625539301385, 0.029165398201815067, 0.02630375145423797, 0.05465629397921505, 0.02419423833940058, 0.023081196855092724, 0.03661317668194252, 0.03740020945007282, 0.024664570359633337, 0.0495615603041745, 0.033670740217090614, 0.04780070337977621, 0.06247533973486674, 0.08919020844323021, 0.03996196150359127, 0.012232358586193334, 0.0554720244009889, 0.026037346293789246, 0.028872886680126674, 0.004676020180340856, 0.007623689025715595, 0.01751049275269672, 0.016738473392662503, 0.027027909471202764, 0.031771422476477684, 0.01091764445581864, 0.050543562449034185, 0.07953239845172053, 0.013663248035065351, 0.009993728054987808, 0.05853247671057621, 0.027143801337168105, 0.06060862478109137, 0.08780307602137329, 0.07269055146964327, 0.058776854927982056, 0.03864800963070124, 0.06281003971854526, 0.04228023166257528, 0.066933416040434, 0.04177391266209945, 0.06044507650057636, 0.04458141806084783, 0.04922820863524272, 0.02207769445263811, 0.024515575834459836, 0.045629502950055946, 0.05839919656394951, 0.01691635517824081, 0.047932313454727975, 0.07940983204471488, 0.011999740776035094, 0.15869065488298095, 0.014096944773149107, 0.0770693721490041, 0.03805108158098113, 0.01930666633040434, 0.037372603471721375, 0.015206168266764332, 0.015899050744220374, 0.030489571602834813, 0.050144829006204684, 0.04536877641634596, 0.018084589467053453, 0.006095590201326676, 0.05786802567121002, 0.012695504701696338, 0.03947040884785595, 0.05043373608420934, 0.04841652315770907, 0.04441208964694412, 0.06890615373249016, 0.07715580218862142, 0.021682808686408307, 0.026322583810636596, 0.08169492676613793, 0.08289619093580593, 0.019392203877589876, 0.03543539310715372, 0.04162032352460008, 0.06680547169619991, 0.025659339359751152, 0.053471699882779396, 0.04867749483955484, 0.041005507321848024, 0.02549852984356544, 0.043627182772803696, 0.06259054786735965, 0.08633312949490163, 0.015551217140689974, 0.01646533048891973, 0.08271237579925407, 0.029093590865452445, 0.012559455147223368, 0.048815325548451756, 0.07635975256562233, 0.09701457850995565, 0.02950431932995637, 0.024797229975041364, 0.05676832943854313, 0.046469621780899265, 0.0837726491473375, 0.011266319798455845, 0.02333151799957118, 0.06831034417113951, 0.06292151317240731, 0.051282396795408386, 0.20461407129562673, 0.2003664201906612, 0.10653233996802762, 0.22447057999670508, 0.11878199394672148, 0.20868264168741243, 0.14391956039734427, 0.09024202418062957, 0.1245790272350273, 0.0923758854849204, 0.1343738443909153, 0.1888927826357465, 0.20456727864521168, 0.16311093624080383, 0.2819212447972067, 0.20852916363266208, 0.14808484172869116, 0.10711142582999122, 0.20863287661585117, 0.17601671388312695, 0.15163095547787606, 0.09876391730241238, 0.11452875806078797, 0.13217019247672251, 0.1692512688497382, 0.12223057704226625, 0.17487421631813052, 0.0808878607987877, 0.0863623327665752, 0.1488915016694415, 0.13745839016572123, 0.17963315450376083, 0.12628123629838228, 0.08266722257699698, 0.15244985750365644, 0.1552527587139799, 0.14580355446425178, 0.14649131755915382, 0.1028911547074395, 0.15979068053345527, 0.16371898022630524, 0.1193527217894312, 0.15785485295759094, 0.2258678937270757, 0.13557415095067796, 0.17869517177103028, 0.13904629124989434, 0.11107566270736918, 0.1325794672893901, 0.1659292511401638, 0.19081983084399856, 0.09135459069042437, 0.12842777635781996, 0.14533573521241067, 0.11324448826452417, 0.20237704859145228, 0.11678341610897934, 0.19263547454630175, 0.14940220652328384, 0.11152795335698514, 0.21281006295354138, 0.1585853944021848, 0.10113886647647428, 0.24871018414776175, 0.1680972033570851, 0.1598398327346771, 0.11879376871811768, 0.17238985446672286, 0.13806517776702681, 0.08197608103434886, 0.20333116513586816, 0.12664525829736265, 0.2477737948779137, 0.10175431087132424, 0.12570012030341934, 0.08341154594334864, 0.15525525616061303, 0.07959516403535682, 0.10611775616604475, 0.146090239887276, 0.12958057014451874, 0.2613670751452446, 0.11767439934755526, 0.09921177996382599, 0.08435677586784286, 0.1987104751770535, 0.10899607873251362, 0.11567934551426481, 0.09568301810612602, 0.16581686604167187, 0.10754468685556805, 0.1527795357809913, 0.1353729762617619, 0.15507891804220217, 0.13468297619012096, 0.15735781511231778, 0.1616729585634124, 0.12677692582890873, 0.11492866361814161, 0.28755677142931574, 0.14784493363432347, 0.2501480086075683, 0.13435590261172864, 0.1297721687343813, 0.21513167708631487, 0.24396762492195254, 0.12664634614221512, 0.13073955392164568, 0.20752574166943952, 0.08701184509141792, 0.11497258343884062, 0.1460608833980176, 0.10887803224426125, 0.11644630677877896, 0.14700833497749222, 0.1808652537123811, 0.2552010939126053, 0.10605444665998222, 0.0987592135225573, 0.16894587555960303, 0.11323512667008948, 0.2185299818313891, 0.16475578830126794, 0.21964215763634254, 0.13138440077102956, 0.075654216230877, 0.1333781445939695, 0.13600884456067316, 0.11944986173822997, 0.12349001792890411, 0.3573266663137944, 0.1176378416318086, 0.2441575074748647, 0.1795117908547963, 0.14758259448553288, 0.15317757974468893, 0.17367200986031564, 0.1856595545165962, 0.16580666175052045, 0.20126412202033306, 0.23582352806002865, 0.17811767937194917, 0.13979595424907823, 0.08438490661642245, 0.1676869939171499, 0.16173541005099976, 0.09542849305416308, 0.09962815641155166, 0.09948395568156436, 0.09867092955016321, 0.09722758159642259, 0.12127354936373812, 0.12230583751994757, 0.08104275611619796, 0.16969613610736786, 0.09819334267728752, 0.09949315639753496, 0.19494622555230895, 0.07963826414197683, 0.06835939678093118, 0.203682676919045, 0.07047384541722075, 0.09451193013979543, 0.15664268735676043, 0.14560392727294277, 0.13997010135602567, 0.10481681629654863, 0.14228555614188795, 0.24377345227666442, 0.11003650274247893, 0.10829198264306593, 0.20045038342716234, 0.11425524168918211, 0.1859919600669415, 0.1414339574834993, 0.1159307832318929], [0.08765828540368427, 0.05297767659348827, 0.0498996387355991, 0.02233068158309306, 0.06529204968002535, 0.008982576264609254, 0.1060409328689979, 0.03807460048025654, 0.03358197360930424, 0.0032844032712971735, 0.033938522420583234, 0.08250747026214678, 0.05629994711207767, 0.018974672552318345, 0.042935401546738805, 0.011313506984151902, 0.014333272364080675, 0.021708585629840533, 0.02458809946303166, 0.05174421374836276, 0.04167699487879873, 0.08710753713403979, 0.03208162488355752, 0.049677404289644574, 0.03306510940855069, 0.0547027112465472, 0.057324555236846216, 0.04251718648799485, 0.041084494817280964, 0.06991781114089875, 0.010690120172746962, 0.051296458339258555, 0.01205005838851174, 0.01734275780167551, 0.0695497825020744, 0.07306564343912948, 0.07214957082103338, 0.018266920308252017, 0.013593762902723206, 0.03976299697833677, 0.06457325236331071, 0.03527982746280971, 0.015821301438395056, 0.02949752029962838, 0.08537521315438133, 0.03263087162087041, 0.05107441158484548, 0.022074488374674996, 0.041161819901918216, 0.08392442648689594, 0.007694108306520409, 0.01955830897655218, 0.027057955439593044, 0.017301339258049286, 0.003312286717118696, 0.07340443050188404, 0.031164276729067488, 0.03251855547029165, 0.044825171916595394, 0.02092149157467629, 0.06736668472689006, 0.030699125378422683, 0.06339415494773178, 0.04331042456831183, 0.013678994972348936, 0.0142569987351195, 0.08387082331483403, 0.008785375656800406, 0.017357376674490593, 0.016162191412501758, 0.05917507509190229, 0.06873504799460212, 0.04682648468822722, 0.04446997142006313, 0.02832589032609136, 0.024768448051726146, 0.05480849266713185, 0.028723430586978797, 0.08937579324288715, 0.012833274123559316, 0.01612445200613189, 0.017993122399333986, 0.04235795894337278, 0.04292742657144705, 0.07002740001846706, 0.05396181612365669, 0.0470025010497099, 0.029150955529222568, 0.05852916721074332, 0.07102455538246902, 0.05647551531212465, 0.029121758003208428, 0.03038951668948416, 0.023475431446586887, 0.0625254801895109, 0.01931761564206212, 0.04625823513995256, 0.023662188360767982, 0.028378095387691454, 0.08400555519807724, 0.030089545386633085, 0.05581222106552413, 0.01582048268192598, 0.012633962943519076, 0.040030020754784346, 0.02685723848821175, 0.041528657274020296, 0.01226433318093299, 0.026001006913101, 0.019922794458726724, 0.01704175802578609, 0.052673064713035865, 0.026296385518846013, 0.03598227263278058, 0.02983807511026821, 0.03517142602152402, 0.04148617386817932, 0.02393286829183419, 0.052096437993309194, 0.02577333707332371, 0.0926249636517417, 0.025588367059226, 0.0879836276233677, 0.06147503191905637, 0.023572912304511955, 0.02149757437197672, 0.07904345815580699, 0.03358145649995535, 0.07239977513710338, 0.028823609989617142, 0.03965140095040683, 0.07142843693614968, 0.0686081531908243, 0.03250182411002536, 0.05802223533992806, 0.051750131777577826, 0.11224328795628202, 0.07691112902736472, 0.11475030302761063, 0.06199272349476815, 0.07566211459737632, 0.010503239726888077, 0.055558136514117645, 0.0322936856818776, 0.013856882503586672, 0.05965650772615787, 0.004816431169127745, 0.06344386256269871, 0.06015602386586609, 0.020767561528050614, 0.04124378364893698, 0.019648856738762512, 0.047025460704800584, 0.03835635995792766, 0.03893774025322449, 0.023461360326637665, 0.05776243960304607, 0.03565064849211805, 0.04089581502240993, 0.07473204555290361, 0.04868269274612108, 0.06868517567073146, 0.013848139525150821, 0.03469658940429649, 0.03092837144410418, 0.026081587871416442, 0.05935301816451454, 0.02923774179972468, 0.043367371714163216, 0.09347788764223938, 0.009137893887987782, 0.04022285274620499, 0.03605956707390086, 0.03697653218442875, 0.04429375587572013, 0.02325724577531219, 0.009011504702239988, 0.05971733893778536, 0.0488216687564648, 0.03830478308842548, 0.03475717929822784, 0.00787113925569781, 0.012618850901602738, 0.05032436554169944, 0.04333922947426477, 0.006736771319992841, 0.016510648420080543, 0.047141783495223334, 0.029397940360790784, 0.03481953119438502, 0.031290378631843675, 0.03531494493325872, 0.04301267683566098, 0.06471821152034306, 0.0356959204580034, 0.1220294023533502, 0.044335921355072534, 0.04809336428860984, 0.0509488306218578, 0.05431417060355025, 0.05839012225248641, 0.03560710022406232, 0.04139361512516776, 0.06230126540627211, 0.02301494557140095, 0.01624954841850746, 0.02932044673681019, 0.05402856536449925, 0.02683460442048888, 0.07073451449433643, 0.01649422349498397, 0.038021591026335955, 0.030791429397199425, 0.024477675549625873, 0.051181637081167394, 0.03663854568355507, 0.0668154921262495, 0.011608063002988216, 0.044813324366846395, 0.0421308291955821, 0.08885122985849458, 0.008198576247049196, 0.07742749527096748, 0.025733416231589454, 0.037442275337995067, 0.0688485132770673, 0.03497245766582989, 0.05348698333686879, 0.036831967562677405, 0.03283185861824501, 0.020741345999281735, 0.02525453275490192, 0.04974939740232883, 0.04220387567916224, 0.013191205723541639, 0.03887564116608232, 0.014633360495340201, 0.019611824048502792, 0.12406965537417321, 0.030293031745860656, 0.03192915040398798, 0.019500086294306863, 0.028404180681513205, 0.01824977909094624, 0.049107599582883625, 0.10415960478806689, 0.04196546911712616, 0.038673045384066726, 0.038476551492368026, 0.06258223581338121, 0.04751201080639036, 0.06344680434032794, 0.0033316701780178497, 0.020307767047216336, 0.05303062859081453, 0.04940480339310823, 0.03450833095778381, 0.04894504721667017, 0.0026973029326332076, 0.017958355414110328, 0.14243163378728976, 0.059970435235769524, 0.031549942627128576, 0.013649445045889627, 0.04066809155647794, 0.03494921838864684, 0.060902469295768015, 0.029018571705467282, 0.008559217883063661, 0.00195975836710028, 0.04038615587858423, 0.011489860424321267, 0.03190116138167439, 0.009516943659212802, 0.06572984594611392, 0.05724665941670538, 0.10590656870795835, 0.03521542245101544, 0.04370628135098566, 0.030316278683922948, 0.03755831850632545, 0.022326357016760497, 0.06764431499064931, 0.01377651796510984, 0.04545632494433273, 0.0493840002755244, 0.020690684604849068, 0.048218336211697715, 0.005158612480191815, 0.04042927130696274, 0.046040375056045676, 0.051114037482728886, 0.040409759047531316, 0.026607838564462243, 0.06317436049181609, 0.09411885042584713, 0.030924330330303604, 0.016691703724885182, 0.01069772263778554, 0.042792602757652926, 0.009228233848848652, 0.03926220530223462, 0.06342564499185932, 0.017548473476762735, 0.03269289409922015, 0.04217466857704905, 0.04708886597185366, 0.020880459905451825, 0.05440569512786404, 0.04015684661064898, 0.08470123964211634, 0.08545244247802804, 0.024664767627273838, 0.08295411484376078, 0.07477650163514961, 0.012364276053924716, 0.03773859814710675, 0.050436398239746216, 0.029513792007140098, 0.06776544115235729, 0.022426291271263075, 0.10771589218488625, 0.028529146858941645, 0.08808515725597259, 0.050257030243594805, 0.053486968015110305, 0.010816235482061823, 0.010044276451451645, 0.01682128558205741, 0.035875058627777526, 0.013314389788936223, 0.046697092437816244, 0.011152122902022976, 0.025574667491920056, 0.045401453896756136, 0.11172429403109897, 0.028703135002644795, 0.05716607845838993, 0.06090877802982446, 0.01620709565618346, 0.045489090524854205, 0.03538661245857516, 0.06919797194460708, 0.04476545153245811, 0.017628186840503927, 0.006505662224240482, 0.02094306844106365, 0.03605681298781307, 0.0043197380634205, 0.037091644555931134, 0.04484517830273798, 0.013484665279036329, 0.2039026667273814, 0.17276767370921953, 0.1435784827316961, 0.2113151802651344, 0.20874959777199453, 0.10690422202911108, 0.21850269377952625, 0.1305452433805312, 0.12658143551239084, 0.09222557903417657, 0.14929211968856473, 0.25878572656262305, 0.19662579671750147, 0.13651813981273483, 0.09371201177277873, 0.11667679199167799, 0.10311413991955981, 0.1590672024195233, 0.1108185559391014, 0.22150249490814827, 0.1328120209396847, 0.18308361451472008, 0.1330890383331045, 0.13313964610138249, 0.13081340479754633, 0.22325116720411087, 0.13744259343272255, 0.12962301141552388, 0.11947386327289766, 0.1287417498327071, 0.11740298205686193, 0.15797597145841968, 0.06812852086319078, 0.15670728389053576, 0.12687391256012265, 0.21388908247313193, 0.19444787003580602, 0.1238278627035118, 0.16056925569090152, 0.11269476655269824, 0.16810592143766342, 0.06211433229186843, 0.1291138540592886, 0.09761398868455042, 0.2053193318387193, 0.12085986188462666, 0.18905785926167043, 0.15753438305710593, 0.09397975950231476, 0.18172498822452562, 0.20275166558642543, 0.09568936131413906, 0.10350894333133775, 0.21382751964753677, 0.16977496655477634, 0.10908561142822427, 0.12289529621240594, 0.15372102719641503, 0.13915319115884844, 0.10672144877213625, 0.13472279744042506, 0.10209489824070085, 0.18317367581109847, 0.21467729501666563, 0.16370972588417992, 0.1212014911335803, 0.13074212797707127, 0.07554897873271858, 0.11618530828385584, 0.1518698370144252, 0.2878474251877877, 0.10744136457722034, 0.12586531950341118, 0.17735172934349508, 0.11871056390866158, 0.17324211196072642, 0.12928395622199582, 0.1002021631105773, 0.19098542840971103, 0.17403515085818308, 0.11548253752651716, 0.14056251714787177, 0.10212250804949193, 0.09988192303646957, 0.2558579530206419, 0.21299980761062717, 0.09459719572576786, 0.07290283443346139, 0.12605913974825414, 0.1445624920269174, 0.15433789651480415, 0.11550737409702233, 0.18615041769319968, 0.09870569462016707, 0.10567812894981717, 0.11286312203493812, 0.08402746531271166, 0.13932097973602434, 0.1012491907984499, 0.19475179243712656, 0.18315728152951888, 0.1544480293147987, 0.11500256812019695, 0.09463219828302823, 0.11226773382194581, 0.08549712072577208, 0.10575633120512772, 0.129744804073726, 0.2029983918633192, 0.2759783943333934, 0.15050586343051928, 0.09962821003770637, 0.11982663910114959, 0.10109209680869695, 0.11215667405556287, 0.1831680067604588, 0.09717534972174514, 0.052867022853705196, 0.1406084671015701, 0.15578828481656892, 0.16109597178236132, 0.07850020988694123, 0.16014665094835145, 0.13939527494292106, 0.08757066026690506, 0.08168029448678417, 0.1462847802547678, 0.07046140414933044, 0.12454928770180672, 0.14895888676326122, 0.10337749030441047, 0.16984841906495635, 0.13433045317088405, 0.08881131667763957, 0.1476280081776842, 0.22525306220256516, 0.21762034435185695, 0.19233777277892639, 0.16415721316251064, 0.15748008274503295, 0.1750636392182881, 0.2744639610811588, 0.1910195193223415, 0.12011062789468036, 0.08238585380416724, 0.1745949466262133, 0.08922898015307804, 0.1914620117074059, 0.16312467985816542, 0.1766016066915566, 0.1942227014731015, 0.0968280284395141, 0.19565237475739372, 0.16586073223621617, 0.12689736251148487, 0.1314597225357448, 0.17068175418723017, 0.08657381899895207, 0.21028607903468996, 0.2250992623908866, 0.1726238483623151, 0.16397352060002668, 0.19950385115319685, 0.1057815661413535, 0.17426365956423745, 0.17464910904245992, 0.169509670306598, 0.12504399663979007, 0.29524737488358255, 0.13734384469928282, 0.24846178779919303, 0.1657069477462961, 0.1570937139613013, 0.16646295395349303, 0.18005903810262683, 0.10312007710097298], [0.02281621853340297, 0.03951045226365809, 0.11384509353628082, 0.045956220297563466, 0.1040166987466716, 0.09064952166931284, 0.028591768801092144, 0.05027530144058889, 0.03042272468578191, 0.014178826165716014, 0.0936099382177476, 0.005177349075599904, 0.10467505938703976, 0.005800233141804535, 0.02241683008539821, 0.020796006372679147, 0.01860753449070598, 0.05846991030980022, 0.0735751302131722, 0.009249772410839796, 0.03843454689147972, 0.0430923767928635, 0.06959927178198291, 0.014102929835057548, 0.009538526271259593, 0.09598260444979514, 0.11410960837477639, 0.04475669514748358, 0.04387356047969192, 0.08485728409141303, 0.025830550434728785, 0.06132538430392743, 0.010910028584241387, 0.022920291577916474, 0.028115204655595367, 0.042037243894752, 0.03485231975754423, 0.0011963229025563887, 0.023930537469324567, 0.02818163788516916, 0.05416790909704663, 0.028140481726657, 0.09149969540416233, 0.05359796266401968, 0.023521833392160556, 0.024385271939418973, 0.014386647624985106, 0.041866348831043135, 0.03926333911236256, 0.014887265973694384, 0.038155974339573615, 0.055433854070161624, 0.04179633988608276, 0.03748378198173258, 0.014411789673050086, 0.019596008163306023, 0.0252929367425461, 0.03530403584121697, 0.06711405191210008, 0.04438286339263282, 0.0338026758794102, 0.016967340244821483, 0.029652867608913974, 0.05684345968127732, 0.03397426425269054, 0.10050138173204276, 0.0563219300050649, 0.047612111685016466, 0.06413316549432856, 0.024221861554730325, 0.05770516686982686, 0.035254538900429205, 0.03332795417537132, 0.0034013231314959065, 0.06393438483017587, 0.018813284639749798, 0.011578005543279072, 0.03533396306597898, 0.034713588895336274, 0.036006488672067086, 0.07846899180402679, 0.035135029184241454, 0.018474179650506666, 0.030798036905546344, 0.024313008780741406, 0.04416788379932123, 0.05726533280985971, 0.025873891859044953, 0.046388749709172596, 0.02057916710093137, 0.013030553255380403, 0.03817120799794793, 0.018513487621901498, 0.05349592741338476, 0.04631979413510812, 0.041676991048359105, 0.07624358299278444, 0.019907101147597837, 0.040656320615521366, 0.037435093263704936, 0.03378836918742426, 0.028002963198589224, 0.043766043869958776, 0.03339961020936889, 0.013801562336964474, 0.01028499755662896, 0.054436104988018354, 0.026431460226435336, 0.03008427470171404, 0.04628856456087482, 0.04166194891196586, 0.04181733452564767, 0.043587993545037125, 0.05440774058262187, 0.04565454636430068, 0.017718006819186193, 0.03070064414773257, 0.04013139333936476, 0.05726367039906402, 0.0500362666864549, 0.0442528008152881, 0.04527111552775868, 0.027956748944557006, 0.037568312123297684, 0.022970656113278483, 0.027214300578400016, 0.06289644677552485, 0.021574014625061425, 0.06556027238407443, 0.051245245361520406, 0.03460618719879178, 0.047233859602842605, 0.12047453498047207, 0.07086206047284989, 0.05200400565480513, 0.02411435835153586, 0.03471445457469072, 0.0653337401848647, 0.05277635251742698, 0.045655274147828745, 0.03388005842064177, 0.03801576492767181, 0.07188420562494187, 0.047132644066286665, 0.011268633383987172, 0.08681480727729299, 0.030670153848346204, 0.05989049396087086, 0.06417932229176646, 0.02536506775105673, 0.023406427992027135, 0.012879704797430145, 0.05686458838622897, 0.004923342090595755, 0.032095420211854006, 0.037444742141111244, 0.025277795014722694, 0.02987104178886981, 0.025160338414172013, 0.00497847743850622, 0.047348010534000014, 0.00737578584624815, 0.0554673704168489, 0.036478406494303096, 0.027825996888080434, 0.066604143789699, 0.012784099897309657, 0.07750791152037921, 0.01608902235485373, 0.020537806013899467, 0.04651021678000689, 0.10723537119526057, 0.022533369295659567, 0.0077325142093844, 0.049433079698393424, 0.016482538738918882, 0.05426090834061465, 0.050096297336201516, 0.10050071523554864, 0.02545146714715708, 0.02933049781037675, 0.037799777928739786, 0.041079434806541096, 0.055876553298965584, 0.05916789301761216, 0.07165442521293318, 0.06180484043133836, 0.08017613447361416, 0.058049136517389174, 0.011697691459689411, 0.04526180755947867, 0.005525846302794714, 0.04121692843675133, 0.012185577427097147, 0.039076038275755225, 0.04632788785402814, 0.07202428480189654, 0.005380989610022235, 0.04096717994299628, 0.008803516618847367, 0.02804031956099695, 0.05416037845275095, 0.02748680379872601, 0.04025340050218567, 0.0754140017013396, 0.025363424492459145, 0.07141306155150937, 0.05834193532204917, 0.03867008445423938, 0.09215578842427462, 0.039649209938943386, 0.02843164876403828, 0.028909948098683552, 0.017859522410998904, 0.06358984444710998, 0.007730284414719791, 0.1458284370000324, 0.06114967820805408, 0.04805122562233479, 0.05704773702628671, 0.012343986215250147, 0.0393888779405144, 0.006451679359851105, 0.008477650586545708, 0.018994529551315694, 0.05078076625302915, 0.026516179974761703, 0.04045769316895355, 0.014336368316904673, 0.07630411159968184, 0.022288054535766284, 0.0637248291393682, 0.08019417584423097, 0.02250919922164852, 0.052336342257237246, 0.022516095928186854, 0.02048559329142013, 0.02490941972111262, 0.027179610201968785, 0.053964972405904726, 0.032525254909189484, 0.049382360847366434, 0.01657009875822452, 0.05166852809188347, 0.05839377649188523, 0.025388138488896435, 0.017529562596351873, 0.05870560492058435, 0.033646995321877544, 0.029066195561280175, 0.035083743428150495, 0.01010329011947878, 0.010016537365323354, 0.05325081758201123, 0.022658948343427434, 0.03273220207061499, 0.07291823280073943, 0.056037604132847446, 0.05311625040767174, 0.01680295501324919, 0.00855718104679498, 0.05540304584428669, 0.042335206132021644, 0.04117646750303046, 0.013496693817057438, 0.050150030743210554, 0.01100149660957076, 0.03463203883579662, 0.027031563710601583, 0.024046255050287135, 0.02604507995138486, 0.07773046006238268, 0.048873008138710455, 0.028253847417692025, 0.07761656577067991, 0.05119364550938049, 0.011818090795479234, 0.045315207718240644, 0.07310925682465877, 0.034109413653852484, 0.0532309644134535, 0.023597951888317065, 0.04763263518050794, 0.02479637387178598, 0.027358296379867583, 0.10392593264940286, 0.04569228385545073, 0.050780306600274584, 0.03152627817114755, 0.017580381038809018, 0.03211331985620482, 0.029239971115584337, 0.02786444109534064, 0.035118102471554474, 0.017699553676310088, 0.01361141739893825, 0.015821124280562565, 0.010499645816913296, 0.022075899891675483, 0.03335169140970515, 0.06523732035871475, 0.039842827170486414, 0.08239195186404452, 0.01574962720980928, 0.045533761111718994, 0.10336073596150645, 0.0524222053917906, 0.01786823091547816, 0.03702873341558922, 0.04949148241130095, 0.03733844361117771, 0.057147133104022474, 0.04422045275268536, 0.021905408939346675, 0.057944573176604126, 0.037939228913596565, 0.04063396616989086, 0.028338498218105208, 0.048432040268615376, 0.09489822231473462, 0.04115240468132881, 0.039104084754663135, 0.011028744441817605, 0.05045392250101413, 0.041262299994066845, 0.03503325440350079, 0.026668376747458696, 0.0187386178802098, 0.054988672716483, 0.023946265254410046, 0.033123324429916765, 0.025743607116202195, 0.03159933997648618, 0.07430202507924649, 0.051377318919666355, 0.019977267140582688, 0.06056044168109375, 0.015071957323309636, 0.07478543422034672, 0.007506371757406141, 0.02342851047644452, 0.05761299883165668, 0.04907239784276293, 0.019782249883358038, 0.04306117786214717, 0.09095727451025479, 0.0406997271573111, 0.04910505234053539, 0.05128279899156863, 0.05501573860284783, 0.04163485238208406, 0.030672812173443458, 0.18057899729859445, 0.19868019938228593, 0.20486842780824632, 0.10559113200513587, 0.17981954369573824, 0.14331868699481412, 0.13045628525076375, 0.12376004093957525, 0.13763881919364776, 0.3301059076141927, 0.20143771754397502, 0.15938401041973024, 0.22194405266594505, 0.08827252704049311, 0.10672675776145152, 0.09353801022253691, 0.1095817069853506, 0.12036938175198533, 0.17340584027190364, 0.1414244886367552, 0.11665475164209643, 0.1058120794233776, 0.14500142976401315, 0.11141674037301734, 0.1339202896962243, 0.15661938296210381, 0.2061786833069017, 0.16366400575685888, 0.10551227091421043, 0.17188708628377608, 0.07625092211509905, 0.14984408603800883, 0.1424702446186735, 0.3039309202182678, 0.12211493607009612, 0.2518270128676968, 0.11072263407010226, 0.073494162380455, 0.11294782071584657, 0.17872239853585922, 0.3106389086573355, 0.14154962143830715, 0.1388202033816807, 0.09446337548715454, 0.12081896811122857, 0.10894631366095237, 0.09111998392449272, 0.10565034294080351, 0.11229141359968532, 0.1549724011772102, 0.11562418718371661, 0.06026701085389622, 0.13477418661838578, 0.16955627909591123, 0.14343937648640526, 0.1783173065632582, 0.17144206580856156, 0.10987981477932585, 0.20673910726702985, 0.191671107745459, 0.09328414400618884, 0.11645604375629656, 0.08508814468739495, 0.18435901301282068, 0.14536138383611558, 0.19414017848189802, 0.15453186997723195, 0.2141270906694474, 0.17259856746081384, 0.11094862234688575, 0.11551472088021618, 0.09893526052755695, 0.13152836401376033, 0.09339648313940534, 0.16567199881519043, 0.20088636406487037, 0.13539117851084279, 0.16420965954180688, 0.07611534753513914, 0.11846019105324823, 0.12839177788625802, 0.10678786859517136, 0.23856325766011593, 0.14729874358782846, 0.06411487897557598, 0.15265996477776958, 0.3135922082489537, 0.21325630916943475, 0.14275052554665074, 0.12698965312372293, 0.061820273272572994, 0.1507113282118113, 0.12967999303533187, 0.12324571248985107, 0.14440435615758743, 0.13523580055804024, 0.17011671837779785, 0.11077313458607083, 0.1639421876039236, 0.15974292261225564, 0.2375098714424718, 0.14873027080489745, 0.18437583630363788, 0.09481949145875632, 0.11556880668767038, 0.16828325547037587, 0.31957679518288185, 0.16742439429846503, 0.13221732220582424, 0.17549157593279116, 0.11517786435903081, 0.1369622716259572, 0.26726402162063506, 0.15064991860380098, 0.17859674479451873, 0.16242896477060934, 0.05816573892990428, 0.09243076036293661, 0.14132422304922534, 0.11170273631690972, 0.15061961216551645, 0.10151388183716806, 0.1699372699424144, 0.1373972103840882, 0.11090926841021546, 0.18630722056954138, 0.2112627798511136, 0.1529702150653447, 0.12448026317982905, 0.207418228890146, 0.14852200214180256, 0.07178577098755107, 0.20066856526799742, 0.2256854881923045, 0.12294174412325506, 0.16810316352113602, 0.0792963667622497, 0.129732531345179, 0.21659226967923104, 0.10295701528628988, 0.12148959381926445, 0.12785229110910049, 0.23456596408880528, 0.16378584438033644, 0.17605526342747674, 0.14049701663034578, 0.06644694254763665, 0.15132663471083488, 0.17497780672725172, 0.11983522694678077, 0.10884322886986118, 0.11177566022642198, 0.20101742638695627, 0.15606574654098482, 0.14703858012874282, 0.12520941034440072, 0.06297647998097443, 0.16324198324113123, 0.14804099085590533, 0.10330183912188777, 0.15018007687983975, 0.05484519977002375, 0.15405023049923683, 0.14325415174807274, 0.1083878202423934, 0.11611970051402047, 0.08296107858299248, 0.22311152469727302, 0.11394709048251953, 0.16120814237623446, 0.1441771804445213, 0.16135457242208143, 0.12173288802225744, 0.1020096632982454, 0.1533323141836351, 0.16279670229602247], [0.049163290344539194, 0.0262755326055471, 0.025558612204246947, 0.0029399830682743946, 0.10730476343944188, 0.041332646017713894, 0.02460754852020933, 0.12406659102247608, 0.03005882526086944, 0.034637133320493084, 0.05909460904677549, 0.03615646187456385, 0.06923806132568468, 0.040925447303321094, 0.021427316448440956, 0.028540647753904906, 0.043784349540909456, 0.07224451209748946, 0.029922264342707013, 0.036902508938745145, 0.05950695970245908, 0.08358156383638421, 0.012092553285671579, 0.061754213510862285, 0.04514432031541102, 0.03668865166424263, 0.05623558423511925, 0.03489335525720831, 0.024883568084107775, 0.0764017878100276, 0.042184325115334605, 0.044272960419015545, 0.03507999342776114, 0.0362889644419474, 0.026845800795502243, 0.06241741582691189, 0.05631406611252216, 0.08125188279776804, 0.04714245382215708, 0.05250039232534267, 0.0341337752498446, 0.027743121496431773, 0.04609608113945973, 0.016181240188738993, 0.026868695333119363, 0.04245880292728544, 0.02124292674594589, 0.023041731835673415, 0.023562857400505774, 0.04511232082281382, 0.03645543151745393, 0.033937599284634475, 0.010079310609838896, 0.036340541311449585, 0.057661633923529625, 0.12375044185788402, 0.05039840410914152, 0.04017670744008595, 0.04003633714972004, 0.04574076572973882, 0.022703881315406294, 0.023821680205723932, 0.12317996682418932, 0.031230317338580088, 0.011081440757299143, 0.023936375059307586, 0.02072092975609966, 0.03076677094213665, 0.057056910929179964, 0.08111014887089692, 0.010257729614574102, 0.041307744329735156, 0.02639251997724416, 0.07684854730483025, 0.02076498555740522, 0.05397868921018897, 0.02672362509333799, 0.06297317814202079, 0.04514951822197726, 0.014613452743017867, 0.10927540205058553, 0.04136785924915345, 0.07338998974451134, 0.0148790362741678, 0.05260055449100272, 0.01929344173761145, 0.03845132038658185, 0.06149978421988988, 0.13081775617695626, 0.012822790210315538, 0.02083207187693446, 0.04324563268211581, 0.10212782469968643, 0.03840945751195954, 0.07023276520832893, 0.05049917148426176, 0.032914580792308815, 0.02229544536901578, 0.030436726857817946, 0.03912643536985402, 0.02985784400915427, 0.05683258123275253, 0.022300735206132936, 0.03176824704203154, 0.04820140566857112, 0.04243494694932334, 0.020488008383601423, 0.05156627833662976, 0.1358010968373668, 0.025178397021767114, 0.044714280689555796, 0.034892305716752045, 0.04496980931669955, 0.039868805211998766, 0.023652612261714476, 0.010971597155495998, 0.07422746174157628, 0.043655072203687126, 0.009881620663368415, 0.07457675953065196, 0.060300653605091, 0.009989180365547298, 0.06207206722108587, 0.016423157348688093, 0.07575692563888527, 0.04889864144065688, 0.03861800579714679, 0.03955413076666094, 0.015146023661438978, 0.0579806482569585, 0.0669240391242408, 0.015246765181091766, 0.02471951227034292, 0.043631147277811845, 0.04846401677857484, 0.05972603020528632, 0.09117673571792342, 0.029667867610471386, 0.005814590587115457, 0.07323455816555409, 0.017442787817168622, 0.026886822888627652, 0.04384526119176899, 0.04923612615394016, 0.023727125803669615, 0.02689938098492642, 0.04901180411839197, 0.00962845924791069, 0.027689405326401035, 0.031857055784653754, 0.07235669801312108, 0.024644370536289872, 0.05593944911754901, 0.03236978885627562, 0.009578538085934857, 0.0043711104832078905, 0.05187413076900187, 0.02221595800121225, 0.02738158162232609, 0.12867398169492522, 0.02581622076010512, 0.02257959121057103, 0.05106558625195777, 0.020524273070717053, 0.07103986948007537, 0.05677338561884338, 0.05673105543058726, 0.009842639236951308, 0.056103702198954365, 0.031932314347115257, 0.11195891611878911, 0.09533932041977683, 0.02402865801066641, 0.055295165342789505, 0.04612677828258565, 0.09080168971371266, 0.04959235703873058, 0.015632628346793354, 0.03059623210931257, 0.016702836897644787, 0.018411469608244878, 0.034691996707190434, 0.04838871416605769, 0.06940496890174766, 0.08623890068021514, 0.026220157855160298, 0.017678266008114143, 0.07228345234668063, 0.02097902094735013, 0.059125861603646516, 0.034756482158216744, 0.009682016454697137, 0.08112883375537011, 0.06508888316250618, 0.02136403184023596, 0.036092256045629906, 0.023262598814683098, 0.0761024542753735, 0.014611990472692397, 0.016692885415508382, 0.0343472724630227, 0.027601446941374775, 0.04934275027124151, 0.053651343670583544, 0.02919197953756779, 0.09697982876171028, 0.04603973154218928, 0.020778759818283782, 0.03520320717906279, 0.030442114371145447, 0.08541232245343347, 0.05803946465734513, 0.08115507992765597, 0.04302953076999515, 0.013760139005288724, 0.043931331170061906, 0.04973793289654198, 0.031402164266534874, 0.03609907039771638, 0.03280823629709982, 0.02614242865914299, 0.06276623864147453, 0.019651539961717302, 0.0641748406774094, 0.014760565564727351, 0.037163438485755075, 0.03315047841639288, 0.010303002538069362, 0.014102528596507206, 0.051639550816147566, 0.02758592791524866, 0.015152677135061354, 0.01879542713023482, 0.031235302655747345, 0.058965117204934366, 0.005783146508263365, 0.02344992071870835, 0.040664540738948894, 0.08889242240618314, 0.015528607970824646, 0.00778700077658399, 0.023660231006121444, 0.02750389522031671, 0.037195579704618266, 0.007868715545027367, 0.022289017891331066, 0.01759675616819051, 0.02322985621679935, 0.09628489508383697, 0.009620892214438608, 0.023368083376197085, 0.03224064175400042, 0.0405473331169736, 0.017146217944701354, 0.02962578448557085, 0.03136330637179556, 0.03340443273285224, 0.04863769657188847, 0.025012899047484802, 0.013746495936967194, 0.03904524537163877, 0.06807375323748396, 0.0325659571606065, 0.04385885159154573, 0.06144457609362661, 0.0187348410667431, 0.038223263672402794, 0.035173226328146075, 0.028847986907367746, 0.03822365054680455, 0.022131303370359446, 0.09091439656913282, 0.08175550133831079, 0.06509596947580576, 0.035912861236401146, 0.0409158558825091, 0.0416956567806342, 0.05437856412402565, 0.00717122552751173, 0.030298202839349548, 0.03600715133812159, 0.04608182424318887, 0.08607059882412996, 0.05930567010035438, 0.10206259997381319, 0.029042854777447162, 0.012779589554655456, 0.08718458259658468, 0.07709469901578081, 0.04006389333235641, 0.0021402703479848685, 0.012890408960952154, 0.045769754496793595, 0.01324497456211717, 0.04186668974016944, 0.041357601331847335, 0.03027471075315149, 0.047979918158342766, 0.03754470895435061, 0.017829125957383264, 0.02960672804845437, 0.06034726239440422, 0.049991891043440956, 0.05805874709039927, 0.02680203802282772, 0.00550162882709335, 0.060544112516987714, 0.07387184372712528, 0.016675995091997808, 0.02920610619889152, 0.09447195567190649, 0.027592491373539935, 0.018493293544217464, 0.05889527679931733, 0.06361441288684165, 0.017347762271040873, 0.0465592923724363, 0.010317471066129305, 0.026183607800292875, 0.06699020613826091, 0.006052939213752266, 0.04749201591156664, 0.03987325235239921, 0.02601992928483073, 0.03561916610886974, 0.02078940652521147, 0.023164212057787566, 0.059721609877963225, 0.04384790419510776, 0.020162505285453894, 0.009852593591917428, 0.03721798011552423, 0.05391859727340841, 0.07721178789412783, 0.05011562956497074, 0.06678935320627305, 0.027337056592166908, 0.03632739907310855, 0.042275550865357926, 0.05757640664195342, 0.05079482779687932, 0.06603960593741748, 0.044656096311706694, 0.02888547541994241, 0.023307064473028147, 0.0425437007910542, 0.06892032635908935, 0.01816136105316541, 0.05882562408524175, 0.034957660677572416, 0.05718284429261281, 0.07833439781660996, 0.1324856828056997, 0.05560461889892336, 0.10542997008850498, 0.053615444790451765, 0.2091712832090355, 0.09349936108675697, 0.1644018250367334, 0.2937829824945619, 0.1555979272891437, 0.12720189778314483, 0.15693767717288387, 0.11763512201967741, 0.18963355901500872, 0.17736717367604857, 0.06797162605629814, 0.11150292526449888, 0.21060690133562013, 0.25754438833363597, 0.11654052027170697, 0.11890583972056067, 0.10897314206006066, 0.13533041241668886, 0.15917102265502178, 0.13253023847937584, 0.18073339465885394, 0.22137258171794877, 0.14432524991852624, 0.08474725854372786, 0.13804011137014435, 0.19372808446566905, 0.14831993879089433, 0.14003004007522138, 0.1687512739050773, 0.0944601119525971, 0.15793020536582317, 0.2324882417076057, 0.154130439904909, 0.14801204805412602, 0.14942698180675507, 0.14802804396998498, 0.13547056054155673, 0.1567995361983776, 0.16129101776788313, 0.14065568876122275, 0.1133196797942923, 0.11947253794078866, 0.11012435770563542, 0.18127702597168185, 0.13239004438923252, 0.18877390111165662, 0.11040144404696842, 0.05908679111950821, 0.09406040557810376, 0.12265069965994167, 0.24150897298128376, 0.1641283010042483, 0.09557494608264777, 0.11673488443897617, 0.10813999079888868, 0.09996593989912542, 0.1353377208954865, 0.1225069892262259, 0.2142821162218048, 0.15728036362317302, 0.13013206151944975, 0.0957578419136905, 0.10822281256438264, 0.10793226605822002, 0.1068492092552685, 0.1209339655695423, 0.12070957841652057, 0.08496226111967718, 0.18936050995703668, 0.0956155947079101, 0.0888796363987269, 0.19259611294875223, 0.14597050034471099, 0.12047918513417245, 0.1490943464300325, 0.10718448763532985, 0.20078033749614993, 0.18972191959619525, 0.1517081005318511, 0.098160891192815, 0.24415307948666237, 0.20623105307740552, 0.14787551586426076, 0.12597310807435744, 0.1708729237678551, 0.1148677749499198, 0.20214294744355066, 0.08944206750921666, 0.14912701241912382, 0.15429681888030422, 0.13576190377916061, 0.1975122370546864, 0.15242920377321784, 0.09653613361860476, 0.15093366224919597, 0.21406460853834308, 0.13819020331626938, 0.12342286266146169, 0.0715657505356977, 0.11379868392982792, 0.12557972958611865, 0.09546668253718846, 0.11945549248447342, 0.14925353950069797, 0.20377571063656963, 0.14022684806296903, 0.15024504113581874, 0.18756892141555587, 0.11336837234275957, 0.18124022310779941, 0.12510301605347665, 0.11395822174005932, 0.2846513063676896, 0.1094864592737248, 0.07655839150350902, 0.24874643542833869, 0.1399474098317085, 0.14239319149524937, 0.15850228918415887, 0.11497773154969178, 0.22294834796940127, 0.11825346222688114, 0.1433346522671561, 0.17722507968785303, 0.27552805720798434, 0.16586540537255426, 0.29814879500096847, 0.17482512540394263, 0.11504660285408459, 0.2667613453682392, 0.17351912935414623, 0.10324118794092249, 0.1490125742049948, 0.1308774344262577, 0.18716648010717285, 0.18298817528111322, 0.11302005514622697, 0.10419997762167647, 0.15080860605643642, 0.21069950604390716, 0.06849973642778012, 0.18563384460585733, 0.08646798395221272, 0.05829419655304763, 0.07296024506250698, 0.09992335307141466, 0.2003089176310647, 0.1877743708750894, 0.14364877895962808, 0.11509997619976921, 0.1251106462892025, 0.13310924773254704, 0.18940843641757968, 0.1917165980464028, 0.17109401674280245, 0.23290995778816365, 0.14281751227474984, 0.08703075214138917, 0.15876858134663877, 0.22717834840859139, 0.19587688448448337, 0.1928534878477935, 0.17483882305602874, 0.09448185352788818, 0.19549554123753504, 0.06735008360157091, 0.2478344077544828, 0.1680715547333802, 0.11547854620843165, 0.130281938960956, 0.13341874725395633, 0.2006641219580366], [0.047082538085599104, 0.023575999638846806, 0.03945290756922576, 0.014455797593860377, 0.06011308846814979, 0.03095304905136507, 0.025773139805683208, 0.030456421063131386, 0.015749370570354644, 0.021951167371063944, 0.05104479845613242, 0.018146537251830585, 0.014465186001372435, 0.0395006463382273, 0.037449388464372006, 0.08733066024198648, 0.035350740391520724, 0.007914378215754105, 0.010894312290474774, 0.01113049815514035, 0.01604903064998648, 0.05465283509223692, 0.05071551471407856, 0.03173987497575581, 0.07250070722112734, 0.058224857935021, 0.03617537275497471, 0.03431265678016409, 0.03426128675440147, 0.05559439162513422, 0.09231708057585264, 0.03750262774466988, 0.06480654911889185, 0.07347782938590935, 0.03732298395686573, 0.01949018652310535, 0.06668008608563293, 0.040440130603289416, 0.10875486062779542, 0.051154609499198776, 0.03837316409654675, 0.034411099078434135, 0.08813644684250317, 0.02597928832044765, 0.03243325541036264, 0.09464899859120769, 0.16470657481301218, 0.02366016014298845, 0.04707359017864351, 0.007993524674431332, 0.041832820993037, 0.016387156961906343, 0.04646921958473902, 0.046701321243158275, 0.007058177762965282, 0.05346189012690898, 0.03422056918122596, 0.06700050235996324, 0.02022780662011956, 0.030469752908233675, 0.03162090726677449, 0.057686386224363125, 0.057104971455109704, 0.028306558097322142, 0.017527007693124395, 0.00943149995779799, 0.015252662142888914, 0.04348563270703439, 0.04216896122201316, 0.034916012307568904, 0.029867140486115412, 0.017527963387809934, 0.059256705590673996, 0.0508973763264235, 0.015431312889221217, 0.01757773995069006, 0.030984234575542714, 0.07495027335901415, 0.047885382908486554, 0.014339713248304062, 0.008227154199454573, 0.007549100311382884, 0.01078739705976219, 0.024080897546223095, 0.0459929350613346, 0.03279441224050618, 0.02652737251933544, 0.0988557329401374, 0.03229808302656297, 0.06815546417548772, 0.057654202870664105, 0.02193194814026356, 0.009161554513529185, 0.10504279691245287, 0.051147634268648205, 0.0070518776473979805, 0.043075948037327304, 0.031551086013355566, 0.03129068315179358, 0.034645250022050836, 0.06787463166420499, 0.0762967111903333, 0.06558028260065664, 0.05556235382814081, 0.05164975510729898, 0.03715235702393036, 0.020160777757184643, 0.03233752123290493, 0.08536258802538918, 0.03858538577333093, 0.0586024358598215, 0.06050523355483048, 0.06442038717889978, 0.0014103205866112765, 0.03010813067967613, 0.0447977191558288, 0.015295722987502815, 0.032516349137069724, 0.01871512004835231, 0.021813641182116924, 0.04128567716707626, 0.03250647809416537, 0.04464548599395541, 0.00863267326607339, 0.034208736953235445, 0.036409198111223604, 0.04432457559291394, 0.05202859707717454, 0.04339511175790141, 0.06327451499659689, 0.06589514473753591, 0.0460204950744106, 0.04403414399993997, 0.01268779498434836, 0.0480306982964037, 0.05843813681314069, 0.027314321017794074, 0.022467813236759077, 0.044370318702872724, 0.01340939522525596, 0.0497331946427303, 0.013357622045723182, 0.05265027359728852, 0.0615249693604006, 0.07112305130689375, 0.0116576892211132, 0.02331603919306109, 0.007772742443898273, 0.012337790479162529, 0.04454179982384367, 0.030522419537808147, 0.05445965453081074, 0.04232879780653504, 0.06244085811739487, 0.03327401775506235, 0.033193509575099714, 0.028222818941538854, 0.023733536044376034, 0.04263065560089965, 0.01935768587094161, 0.0288881758798755, 0.043718389370628906, 0.06178569972455021, 0.025934263417917876, 0.021982517604145314, 0.03334693783413499, 0.06951969056840866, 0.03213441600241969, 0.024282058828600475, 0.010126292867015206, 0.11013988630786059, 0.056955446414048636, 0.051826254104173956, 0.0795914561698033, 0.03182626862619673, 0.044041529087530035, 0.09496446593754715, 0.07237542886286974, 0.02355415847212557, 0.07522306194709194, 0.0018242702114343223, 0.019890703035578616, 0.021045858288303982, 0.045960920246978926, 0.024269035333887707, 0.04649585263142663, 0.04132978850975633, 0.039317175941241365, 0.04400508245453239, 0.05090055176086965, 0.0026849780143463928, 0.10069089656275126, 0.010194207519112576, 0.013894113419096799, 0.015089353264850235, 0.01893197272663876, 0.02382765952197294, 0.039783643047896125, 0.04021805320535937, 0.04986857387026952, 0.1322398451907981, 0.06434267521986077, 0.031339513596087214, 0.053457308921121785, 0.0320672492436584, 0.03213296426580318, 0.03613596902258935, 0.01387897456410311, 0.02792298170407453, 0.017441832122483084, 0.043062403602826024, 0.08476690103810641, 0.009957780336750852, 0.06651899311691523, 0.05651514121000806, 0.06821232322122782, 0.027641024958762913, 0.07209926182704587, 0.09560382759739315, 0.015510444026139956, 0.01989210689169986, 0.09249046159487578, 0.005674021113889233, 0.02089934397278534, 0.07628947165944884, 0.05582612939178944, 0.04016395590658631, 0.034839407345580484, 0.027072185522786556, 0.04458967648867158, 0.03232699901526494, 0.017241061544947086, 0.022836230665204987, 0.07255450191517031, 0.047322273810183814, 0.03533624217755372, 0.0158062219552155, 0.08673993750445305, 0.06793001216025123, 0.022852109752655513, 0.053317042052625656, 0.029271765679661787, 0.10063547776230883, 0.041252693251496365, 0.04296152514495677, 0.05640487817506637, 0.03341151904615183, 0.011519552077046566, 0.08026824888562964, 0.008866029393468654, 0.035618717947434035, 0.00734359578927979, 0.04301581396571091, 0.04114659773486276, 0.08283320318667159, 0.025161052791161403, 0.02479047307954921, 0.010806808770153551, 0.023965580246200966, 0.03250253657179494, 0.038395461085582935, 0.022174845892755736, 0.017920240624657562, 0.0462094008652193, 0.06405501303473307, 0.0923509723056228, 0.08497136224421763, 0.04066900703154745, 0.035758502180537874, 0.03308985787894457, 0.05644877501312764, 0.03794674040569413, 0.06430591832125379, 0.045464265445667895, 0.04009062597047418, 0.029817986369673765, 0.045970124793389154, 0.04135182502889826, 0.07377862614849884, 0.026141055446538716, 0.034824127721930706, 0.04898432071410841, 0.03299215868596108, 0.006775730242577172, 0.08534401805410463, 0.0790332768472933, 0.10355844793300475, 0.045189952342620784, 0.04590576957730998, 0.027891641047092217, 0.04080087757639347, 0.018557095261771354, 0.027889934586240884, 0.03955036927495272, 0.07310356479138136, 0.04304843398952677, 0.06275030018220987, 0.025397036600136952, 0.05984008154501358, 0.011591238754561112, 0.03738679525051867, 0.00973551907771898, 0.011727234682879381, 0.01091068933507608, 0.020184624159047683, 0.020608433574858694, 0.027582683532889334, 0.07269241306329928, 0.03856222310494031, 0.03328549375216807, 0.05712045792249903, 0.01196736398513519, 0.01101918270691268, 0.03337539417008239, 0.07256632265184196, 0.03903313352155589, 0.03548773223414056, 0.016232899412693038, 0.041290706534299164, 0.049641528392150525, 0.06557036942291646, 0.026612337415797577, 0.028715557118337003, 0.04701820968259727, 0.042406528917772156, 0.08920738413449257, 0.010986986904284887, 0.07522069473540591, 0.03414915446492453, 0.02529779948564547, 0.02230022575766329, 0.020753425290627826, 0.04587606834848562, 0.054830383629568165, 0.006731847289859528, 0.020723283561247013, 0.1297978020363277, 0.038708882977164565, 0.05156833528270645, 0.01557349306230824, 0.02318957148330106, 0.006847167941516326, 0.04103201013358851, 0.012374759967168494, 0.06655257075063645, 0.022441341068535563, 0.04336929076441354, 0.01920057655943017, 0.0029570167938682943, 0.033521655676586014, 0.0393354547991147, 0.06605744046429474, 0.23370095889174172, 0.20693275897252947, 0.11700550499822825, 0.13601589256957655, 0.08604671986353013, 0.08845218231961613, 0.10303979108650839, 0.12317436672146283, 0.12179784461735718, 0.13385866558359516, 0.14578204271533798, 0.14542530621251754, 0.11856506082920298, 0.17187528852974215, 0.1126120213959967, 0.20272512830072836, 0.121683054002783, 0.11612868672537228, 0.08899687849465879, 0.10368884375859654, 0.09681466786611466, 0.2155535923497331, 0.17271720383676792, 0.14706519402323232, 0.3449429163048345, 0.13610160248654504, 0.1679430358232029, 0.18908838020457377, 0.16102587473728966, 0.21521655962832514, 0.22709682133168946, 0.1581339847536818, 0.13405798633973445, 0.1348393194137081, 0.16922915955224346, 0.15030104216308365, 0.13961218507780185, 0.18342576470346222, 0.1240433632366119, 0.07379958631410714, 0.1484686058134802, 0.12882445668501238, 0.2090963138447654, 0.11446868910664514, 0.09213621487780925, 0.2549381725369923, 0.2563532441854477, 0.10758931913803663, 0.2157859161736504, 0.14057672041798794, 0.10971408697866625, 0.1478192237235846, 0.14673416743115072, 0.2191658194867834, 0.08529691130764062, 0.1515855571074832, 0.16916972645107778, 0.1758133941480229, 0.17464026838781374, 0.08593099462168832, 0.11621216732648113, 0.22512402235259935, 0.1423458779050458, 0.13335582079185596, 0.10797641570529631, 0.16917530357116656, 0.1722386287104699, 0.15392227849412352, 0.17458566164057102, 0.22860710238737447, 0.1011369742393013, 0.11733606427667603, 0.2024324980354117, 0.3058591022366478, 0.17035322504178171, 0.09109172294096601, 0.14849281419188748, 0.1267754013139394, 0.17472645327929529, 0.15219314144023005, 0.14211766031240264, 0.056240908546193, 0.13568777711160723, 0.0789926129002725, 0.12133005600903304, 0.1576762472189242, 0.16167387786892154, 0.16244048673299052, 0.13938766002895372, 0.17450087102911166, 0.1672780408614105, 0.1879792381078005, 0.18010817498209017, 0.15750810624130313, 0.2243118312570357, 0.1675666568260039, 0.2248907792231729, 0.15304115480713307, 0.1204869992310001, 0.10073821015295484, 0.2692904467544248, 0.14488093945528233, 0.17882350682010575, 0.11154466173461369, 0.147151792602193, 0.14397511709361308, 0.19465289048610196, 0.1855655402065285, 0.1710738533086354, 0.23384965655784454, 0.2234359782549643, 0.1429411588657287, 0.10644211013230587, 0.09014800220968262, 0.12549331486825982, 0.13570027966653148, 0.06518632954647464, 0.11873648832401923, 0.0968299972854795, 0.16297748372439416, 0.1642230660804818, 0.23158116296174067, 0.13808731770803853, 0.06889853115764356, 0.15193581250646424, 0.08957641634849772, 0.11233224608604947, 0.19092427927159494, 0.13100203096626267, 0.11822561493083356, 0.15873852005649, 0.12409049296571363, 0.12567717597008715, 0.23051957960330674, 0.19707735958358935, 0.14723684368354661, 0.09280366132095938, 0.20315566971417398, 0.13404507009733108, 0.09166393699424882, 0.2605972180683767, 0.10069016111834396, 0.1665824483479223, 0.11287633705163196, 0.1810069646566145, 0.133908354046364, 0.17062871025935297, 0.1494670788487119, 0.14684554129358263, 0.21268937346195022, 0.1303501973950094, 0.1976824005044276, 0.07744646360797268, 0.20001567449540864, 0.11489102571842172, 0.07668391500990238, 0.12824521760546392, 0.15739328498321195, 0.11811644740162358, 0.11892415688283021, 0.20456355545789967, 0.13522832353989925, 0.10204654277092028, 0.09713245645886469, 0.1699088174369066, 0.2453917057643975, 0.2819114695152929, 0.14818057207570923, 0.1016988767491233, 0.10938948786426937, 0.2127048331162622, 0.12141170566000285, 0.12835312108959884, 0.1419750453844186, 0.07856299845321525, 0.3759786090062511], [0.021421385012687217, 0.06467593878868126, 0.04540293244645, 0.07618056460013313, 0.044617209688670216, 0.004807829438152934, 0.03353847896740322, 0.045128515921533115, 0.013617956916981888, 0.057340585626661784, 0.04066853971791364, 0.04696010574398022, 0.09667186907702878, 0.05146043179857154, 0.06386965806145342, 0.036897092697120486, 0.005350656358660349, 0.11200826750287127, 0.03560575957019483, 0.00867010911010326, 0.04303852081178658, 0.09786521189755971, 0.028194144270533038, 0.019591469092354662, 0.05698916194359622, 0.036147544611125224, 0.0535091424300786, 0.05947066245660667, 0.04529479147505857, 0.05654597624896034, 0.08381827734410764, 0.007923069483255068, 0.038328918688479936, 0.04085416665240642, 0.048389219784087716, 0.10320873645644996, 0.02612623164520389, 0.05204239049025121, 0.013956078440852225, 0.03116708444130998, 0.02352299210014603, 0.01251842060516919, 0.014125537089703065, 0.024871760753974802, 0.07614068972367434, 0.027436148149952776, 0.030741825204102263, 0.019574103794331034, 0.050676245047079946, 0.025030459697929122, 0.01233279750111603, 0.06907653934772938, 0.017891487429639506, 0.026703798737857613, 0.06606292565383258, 0.050461744258721034, 0.013380554887736517, 0.041113142675209435, 0.00667755990552025, 0.05699629422217127, 0.11011226117731103, 0.05629982070757016, 0.026737703874166456, 0.020193064532753442, 0.027416545875190247, 0.006202550918509763, 0.029960319760345647, 0.053880350333788705, 0.016764642956155925, 0.07067335769534111, 0.03933523263361666, 0.04996215534066001, 0.019517706316565315, 0.014165640834929242, 0.03829804151469181, 0.01751839111919605, 0.027488558140072613, 0.11159947532559596, 0.025643040839162086, 0.0156634729618447, 0.014383341955591836, 0.027664959460737246, 0.020771863111745448, 0.010369374480609213, 0.08182217397036091, 0.028175890310517246, 0.04524761578068138, 0.033570624016706026, 0.019042819903622714, 0.02764885437734906, 0.014094793023691784, 0.010296536755988435, 0.03357335128971646, 0.030706885849095644, 0.07248645798573572, 0.006944922675874325, 0.023124961542987058, 0.029046064685849898, 0.045108306522090594, 0.006928047674122237, 0.07252978791873302, 0.03706746682104084, 0.016484164760538166, 0.09001177645498708, 0.02123972832886202, 0.05066605607768701, 0.0565648143510184, 0.0684811894391333, 0.05767226722391863, 0.04947510345147983, 0.008127422000642025, 0.025593409832987576, 0.015549534620086273, 0.02114968043902228, 0.032619495215194846, 0.11993815085940784, 0.00915934339225773, 0.0464103878625939, 0.020522777284044894, 0.027879266811895276, 0.06685913615529576, 0.0162504140978619, 0.04024618395393895, 0.028437645317265586, 0.0374705784563576, 0.04194428678601981, 0.040753529512233315, 0.04791620645611998, 0.03623669809331337, 0.02824547216145983, 0.027441621848171758, 0.03295492681284105, 0.056373162135001154, 0.0340235811628161, 0.06429091065881715, 0.07674307998029456, 0.05571660180125506, 0.026525736921617103, 0.021785150372212934, 0.013207353899375567, 0.008926324343549149, 0.008271210958370039, 0.04939744894903514, 0.020231087391655293, 0.01433833812047998, 0.020854968329771392, 0.023676451002698273, 0.0530196697030577, 0.046675450453955325, 0.014075663808222501, 0.08201401770835923, 0.06111697008412692, 0.06031156652757238, 0.01026564521805173, 0.08654247834196976, 0.05449093390075911, 0.02406452050162179, 0.062060610376178264, 0.030766537285319744, 0.07903900718496693, 0.01500812208940906, 0.04706533175081976, 0.022960932542299552, 0.025649010579312043, 0.041823306181017435, 0.048613430736886884, 0.05554296414277727, 0.08350767465608736, 0.013415016395400369, 0.10632462288823821, 0.031222551122247696, 0.07347249741395635, 0.029071267063338912, 0.06433448573995022, 0.011861561497132625, 0.05866504822587294, 0.03387702471246162, 0.07254219088222712, 0.013220559339970352, 0.05514704990350912, 0.03256048346238752, 0.04023198068382279, 0.039312192539293925, 0.07136362589775555, 0.03406865777628076, 0.02317208935686898, 0.040737571900770556, 0.02996789445469697, 0.029701868507770762, 0.005229761459744506, 0.02547635925903676, 0.017508675209096363, 0.03423563430025693, 0.01365142155273427, 0.04414753650405234, 0.029647102797283765, 0.08312564959088642, 0.06960979783006253, 0.03669677985711925, 0.04812720239222531, 0.07590884087427009, 0.008618628001591612, 0.0035806365438827105, 0.06705639613491875, 0.04694689072728638, 0.021460907488700845, 0.07155651917621013, 0.02338445467513896, 0.021051471797569145, 0.026151397633516503, 0.04679625485873511, 0.019017234482171557, 0.02352572894925552, 0.025431677180853103, 0.034057610788412636, 0.024746524530553052, 0.03616520293777989, 0.005299462054315354, 0.05568208187938698, 0.057280838429447145, 0.04309628767171695, 0.05674365374650206, 0.01681279158219695, 0.06231199063721204, 0.03363401013156099, 0.04902712587687758, 0.049207256130513646, 0.10363337133199939, 0.012559569102802105, 0.06786644984517368, 0.02767073576368632, 0.06708071942651464, 0.030835165356796597, 0.009425578098143301, 0.007917499066435643, 0.03858625528312499, 0.010805578241425176, 0.05901802323698517, 0.03342732727046936, 0.028644134741156336, 0.03432554620949011, 0.05683122142668694, 0.03516936907544732, 0.020747807950923042, 0.03519225212174558, 0.099960247865848, 0.08649780009422572, 0.05182826891541482, 0.02290798820585253, 0.0558424623863351, 0.021057422385520993, 0.08157520254533138, 0.07643033990696554, 0.030070312749294024, 0.012334079740779295, 0.014871609051741902, 0.02932956126788932, 0.024105098263751117, 0.015099776848669977, 0.08078268458766323, 0.07061760947709123, 0.08518544551465781, 0.04295138597127892, 0.07500108797103167, 0.04885064220176109, 0.04451514762495795, 0.025092332789133635, 0.0416804269526995, 0.06966643471030459, 0.010279622492230227, 0.06829958063580337, 0.03783519034303966, 0.04761022327828312, 0.059343886396457116, 0.0435865571301791, 0.03003418212756515, 0.08366785598017516, 0.003547693805528745, 0.01199995815348361, 0.027968412633204175, 0.06141757532473534, 0.015153235421636173, 0.04272827052421147, 0.033848740746297186, 0.031540385680273175, 0.033593545367400494, 0.04340999684627018, 0.07635219893868893, 0.05692730800458982, 0.045684259084443894, 0.05918700308088334, 0.05842024482966912, 0.08808795347689621, 0.04424901251050253, 0.026437550625433365, 0.062480687028578216, 0.05701096863636086, 0.035343014394804355, 0.08382288153253256, 0.038738419497085196, 0.05715683943802311, 0.032621774326769576, 0.040015882602141756, 0.040803191161924796, 0.05774877642491653, 0.03780579554938501, 0.06101232247367021, 0.06283707496139311, 0.04175871730812135, 0.015863608644013445, 0.013345067779864035, 0.05408131434852558, 0.035714563207640763, 0.04530346359036142, 0.019414977756358927, 0.017855029305322997, 0.11935038522126214, 0.008930826067714202, 0.039590688482407606, 0.025121612669599634, 0.009746086303024523, 0.022867759013728752, 0.07099223413294362, 0.08766663576205892, 0.03922931331720564, 0.06308349097267756, 0.015180999405622004, 0.029257041469757116, 0.04486102483145172, 0.0625328001596274, 0.044547300335140004, 0.01369234884247905, 0.021467740992985426, 0.061902137428161606, 0.028369676081403613, 0.02533956659927724, 0.0772208200707551, 0.02552578916713115, 0.054408633075053656, 0.1052987315661965, 0.038539355380400535, 0.10689112192560589, 0.03210818323667251, 0.03222579113958824, 0.01963882290217425, 0.09064995833942968, 0.005547064065467567, 0.06114195221133771, 0.03828835816332891, 0.01601307144043066, 0.029649678767929157, 0.052079040136548786, 0.08474605578568675, 0.18943771629804568, 0.13264311387413932, 0.13927915133535862, 0.1365436045753379, 0.12467070497692594, 0.14445776780766828, 0.23392195993613815, 0.22722543217241767, 0.16332970030846136, 0.09559969838348129, 0.1162233139057794, 0.13602750646250863, 0.16189277983240544, 0.22207221917567715, 0.14243365625940985, 0.13402371156600215, 0.24708788571578844, 0.17252411903633227, 0.10231395342176962, 0.13730442181469935, 0.15750182432032403, 0.1469750254745445, 0.10283579719403099, 0.20554780990125673, 0.18793848223022877, 0.11533621473297959, 0.17788344032822118, 0.30702594607587785, 0.13455477903687185, 0.2359580530995323, 0.08741977925021803, 0.13628469750044808, 0.149825286240347, 0.2667831941958397, 0.1739682560606349, 0.11470708800780197, 0.1234832150681365, 0.1699985876198738, 0.09454806650718374, 0.19034338544213003, 0.1044045307583386, 0.09595085776621297, 0.12509913198770056, 0.22474519187404265, 0.2131783367405015, 0.0891375169157982, 0.08773224353189431, 0.2096733925563674, 0.15850510838772022, 0.11216315515940228, 0.17006453246839587, 0.14153843655461265, 0.14275325281966117, 0.18229656642483127, 0.12284142490957053, 0.15309343264708597, 0.1766746761577745, 0.07739793959884875, 0.12399372073911852, 0.21614746370863533, 0.17493197934762125, 0.1274087491835798, 0.10311645350509113, 0.10399927024639423, 0.10560872904475659, 0.16729012972885565, 0.12055082967685116, 0.10789983755638523, 0.1849474757909775, 0.18258145920211272, 0.20678574669986002, 0.12623547020578577, 0.08360984780254864, 0.21675400616180515, 0.15402456655377342, 0.13496180155104207, 0.21524519599493475, 0.09286563017315443, 0.08242004430822789, 0.07623858809951814, 0.14235626605729904, 0.09589448901674441, 0.12172309741858514, 0.24095239478253552, 0.15016040374194423, 0.19232392190925537, 0.2986042495937117, 0.15278477582239336, 0.22862723517802455, 0.1687329490819285, 0.08236180630422409, 0.13574494259251704, 0.1739601968156715, 0.15896833111201564, 0.17283202509485907, 0.05248223604153722, 0.14456846751272678, 0.21104819862352264, 0.17475069230121953, 0.22167943057514009, 0.10658300902333953, 0.12689630531014937, 0.20054260509148722, 0.16262007306420034, 0.15190392792705568, 0.09011967993912198, 0.09284106173342274, 0.13263499334214196, 0.15587031751150088, 0.13626733794808388, 0.1425222773104906, 0.15500097625678586, 0.1765358150606194, 0.11841378144679532, 0.18093812399573866, 0.15590106828078149, 0.1687821472484258, 0.16723679468756722, 0.1439494531481497, 0.1456927934721593, 0.13961426883695588, 0.18525351259496906, 0.19248464715576943, 0.19709490299705537, 0.10529886946202287, 0.1344892631975874, 0.17959596859591623, 0.10204488802100382, 0.12049220862888521, 0.2204522343292352, 0.1911380331242277, 0.13082151000778522, 0.1543473040745143, 0.29948479105387965, 0.20960412288625396, 0.13350055012251102, 0.10708098149588031, 0.154745317394695, 0.08585480717761863, 0.20135760006885375, 0.08583049920778121, 0.13946523409216635, 0.10488070036855437, 0.08663942676878746, 0.16137222308785687, 0.20558802951728145, 0.16639653413045793, 0.17985597883741702, 0.07443127177295185, 0.1305833485938849, 0.167726278905907, 0.15602324398294573, 0.14888135866532404, 0.1543180395158068, 0.12281136361942177, 0.16249379113076196, 0.09680353660857487, 0.20172268693004886, 0.19018655192227135, 0.18195001889140378, 0.1573135045867774, 0.26729248944790135, 0.21545214698679988, 0.13382100470123753, 0.21949882258570966, 0.3243958253052927, 0.22267519165911984, 0.13964619938163988, 0.2997156899542578, 0.19544493346925707, 0.11266976144284972, 0.17845812884549941, 0.08265380071656359, 0.13947854870029036, 0.16798397556187647], [0.03240548855354709, 0.05557641154155136, 0.08807795602948436, 0.03231048982049669, 0.02542559827317394, 0.007615968774658658, 0.019139952191542235, 0.07480892247610516, 0.037892286876036275, 0.061739550587991555, 0.06085009569482458, 0.014192779499646879, 0.08369306027288399, 0.06855753776166709, 0.09146466986426423, 0.0178402284866259, 0.014239979134271703, 0.052866988379748604, 0.033434532327397216, 0.03341287502177781, 0.02912550225793835, 0.021660458071217425, 0.010813531191689114, 0.016851618833419298, 0.023621543565945282, 0.02587144612334669, 0.024394353911761316, 0.026479283265108546, 0.07272871030915169, 0.05197857153571902, 0.04108295881099278, 0.01607351098960686, 0.02504817548117811, 0.036914352658054525, 0.06249256522184419, 0.05615855026389322, 0.006404163713957514, 0.016285307487593065, 0.022283030914202816, 0.040381674264227195, 0.015081824535774368, 0.014469393739296545, 0.09338275484380223, 0.06014970364049078, 0.049237677481986826, 0.03736421863939013, 0.03428071857460084, 0.04945600487952752, 0.024164090864360336, 0.07669364432654074, 0.021049386123195294, 0.040852351024025874, 0.05809934591994651, 0.021041123864931927, 0.09776795703557231, 0.011116272859996366, 0.04960322016549688, 0.03201615500954851, 0.028859868931073337, 0.01966365755745961, 0.016187388044331345, 0.02141356325498031, 0.036409504546393315, 0.05037973837686643, 0.045963919481202486, 0.03483217930601489, 0.04062103843616863, 0.02604804279643201, 0.037539840465591806, 0.03288238977773055, 0.03751954296603799, 0.046219279569002895, 0.021787967660554478, 0.031604535967832616, 0.023655580852421063, 0.008275025118623049, 0.013908972651998123, 0.07719521741232566, 0.08328281252855256, 0.010996924979882616, 0.0187359863681899, 0.046729750766028325, 0.05260484841381831, 0.03261224419299153, 0.02568295976567653, 0.022243540996925968, 0.08468554250054783, 0.043571407741476456, 0.022303050706884073, 0.03531793267616341, 0.02830417173343801, 0.06244905142774505, 0.07660690019087446, 0.042189810304872455, 0.022983470849031885, 0.06500914873134706, 0.010498985066078605, 0.06590924075534267, 0.06592656200331065, 0.007570924719930777, 0.018231657281097387, 0.028712795371369972, 0.028338297120025082, 0.06667933531946714, 0.028086928350310174, 0.05411060955075007, 0.03040410108834265, 0.03731656797049988, 0.015659243198892763, 0.04365786842461075, 0.039304489525215286, 0.06114133551055866, 0.049867780969267896, 0.015523964520393601, 0.04741430778296725, 0.03308404327159928, 0.05761424372453363, 0.06523414875470823, 0.03527475596075097, 0.019331014519857786, 0.02554362752444802, 0.02341990922427466, 0.056050118179090565, 0.0792915863736022, 0.01247078525803743, 0.017249329548869884, 0.0861988955688092, 0.0389792277447639, 0.005676225053086396, 0.06875001735264255, 0.034226537006156105, 0.01379423470596873, 0.049933668361195636, 0.056294255078800266, 0.049260116197289004, 0.02776436702979188, 0.04176185443817128, 0.041708163165998076, 0.025198533642856825, 0.015550553517025566, 0.05824813551660027, 0.022004042759597785, 0.0543825822551885, 0.030404577978075515, 0.028056579777189804, 0.061356943295968164, 0.051928369794040925, 0.03439773850503468, 0.003774867603375066, 0.017462501174680168, 0.018041880065274817, 0.04328731935651552, 0.039432357260656935, 0.03891709418366513, 0.018795881037329955, 0.06193885219193274, 0.018655863147409215, 0.03538598043603763, 0.02270515493658041, 0.0004842788304461377, 0.13482255740992485, 0.05228333280331666, 0.09455581931697746, 0.013336211803459353, 0.12323151688061415, 0.05653350433755306, 0.07322577113706259, 0.06742342885944151, 0.020373079873200868, 0.04888012509552702, 0.016283972579385006, 0.03129599022588903, 0.03934593105147924, 0.06988008897150717, 0.08655000898626544, 0.04651262995696837, 0.021885059728857972, 0.03596328131313767, 0.03231623164948917, 0.03255789791564307, 0.07765164493673271, 0.02997617778037825, 0.06659888842653844, 0.07445299036560521, 0.06563045369881777, 0.046615304891020067, 0.048713600563426177, 0.037660189048056646, 0.03330695953580641, 0.02900816248579612, 0.050467731235849286, 0.014801349212986328, 0.06075782040434499, 0.04880524383136823, 0.02900571291965823, 0.04126510004543009, 0.027490526986038013, 0.05320580991645975, 0.01721834703799217, 0.048643668227258234, 0.0053035989291064685, 0.04414669380733564, 0.05106966950059418, 0.032703852986976985, 0.050895143180124225, 0.021370147137091528, 0.03746512774077635, 0.05178335318041425, 0.02782000991095218, 0.03294943396242396, 0.0909998000509316, 0.10923131369054319, 0.08173802687275795, 0.04724228273957007, 0.025207941202566992, 0.048442118155259284, 0.03465455799033085, 0.07221970617050125, 0.023279891334353917, 0.08476153076175721, 0.15101282977529112, 0.043625302026949586, 0.06856030333907374, 0.024880994028682192, 0.010107336978938793, 0.06727813262372248, 0.06432247348129749, 0.014542254446555051, 0.032738970457426006, 0.047296648169116634, 0.09955022228701461, 0.03304177437037711, 0.08250170162007694, 0.02712372408789252, 0.030723797240024133, 0.09582367184902392, 0.024725780784783345, 0.008669929079441054, 0.0305367109080356, 0.045162702595154126, 0.041487533674244924, 0.036450321710998976, 0.043000270041727254, 0.02752583023280867, 0.03232326050619445, 0.015507802938021, 0.010404462265151163, 0.06893060725903319, 0.021997077105146264, 0.10670598145694503, 0.0614449323245114, 0.03688323799700987, 0.04882548387432772, 0.07886423954680082, 0.0783151307053143, 0.06391043309122324, 0.05384885262878192, 0.02708503664771636, 0.03926525433217326, 0.0376060419535685, 0.05460008227777097, 0.02279826909333708, 0.025832465654539487, 0.026697419140668168, 0.01785847095532283, 0.03898922902261538, 0.04588891181253618, 0.04805695979044803, 0.10451686989155509, 0.046688021956792766, 0.011905104977138823, 0.040898848730590076, 0.032124726905397354, 0.017592031320917512, 0.03606668403071742, 0.008690968726671511, 0.027527303036843098, 0.006428437688643294, 0.08406976868789043, 0.042286911949275, 0.028351659608644345, 0.046179734110351534, 0.007394614372207153, 0.025473518988057494, 0.010053625596957582, 0.01058757930408202, 0.03557608898488745, 0.026300673696002173, 0.07162955799891103, 0.058623909304339084, 0.11102927608355401, 0.07199691248036201, 0.042556410189718015, 0.041755982374231664, 0.03620767868274162, 0.07779944627996414, 0.011705998725618326, 0.02451457225927903, 0.01653683330533245, 0.014972768089313422, 0.09726937935357133, 0.03796978433045649, 0.08575903086532509, 0.07510526060697532, 0.03853706860794656, 0.07259395544327076, 0.08729569598912232, 0.01490245653962296, 0.06929998421260426, 0.01701349129659995, 0.015435210361535993, 0.035189743183793566, 0.0484048403168638, 0.05994218191312206, 0.07889918081702725, 0.028122346510269472, 0.06984141685308949, 0.03549469980381189, 0.030409082575070284, 0.07231975725341229, 0.025507200043648485, 0.02076979275913008, 0.01543172370387061, 0.03864995549402891, 0.02888246469439999, 0.027403744545975522, 0.030640709258976485, 0.020917373852083282, 0.04232294489479354, 0.023152935243542158, 0.048110720010534416, 0.06496719009573422, 0.05376355256885291, 0.06819638093152354, 0.06093201730700751, 0.04368758880563321, 0.11165785122542612, 0.1041278581044847, 0.06986895005308813, 0.10093064377865485, 0.06704470563319422, 0.05861515291936456, 0.04407861540394445, 0.026508070934083194, 0.03761046611133122, 0.0537505941916137, 0.007710093688670427, 0.010659451757918202, 0.08371798877394007, 0.03434752910247734, 0.04584499199183718, 0.020511986935631405, 0.13778554035290597, 0.21682287746619797, 0.2719391191438321, 0.09985943835589195, 0.19682001532806506, 0.11870938413325818, 0.1553747658768008, 0.18762112264671635, 0.20380318254953433, 0.1301436294471064, 0.1258779216497656, 0.12395337854902591, 0.13175376240284215, 0.16590141150499546, 0.14547075054818584, 0.14030840578338794, 0.2297895284549844, 0.149268432249946, 0.09827217312469598, 0.17539558511587883, 0.10615034554634364, 0.16285795868644792, 0.07254011478395232, 0.15060352431910654, 0.09705938699264681, 0.13868383973115875, 0.12781076914360448, 0.1438261436358575, 0.14315898830611862, 0.1355560865974234, 0.0974563660941297, 0.18424927857854675, 0.1696504466235638, 0.10606755442436665, 0.20259256444631085, 0.21551890388852168, 0.24477583236030995, 0.1152004333092801, 0.11359174059884203, 0.21980553354707458, 0.15759655875304054, 0.15906599200060292, 0.21773032393426667, 0.24164058688667514, 0.245936332991527, 0.14913464265484966, 0.1363592072119636, 0.22084113120311694, 0.14194535181647347, 0.10395536574745372, 0.07405971912967582, 0.11348212873863597, 0.1487868693807433, 0.06796303054978771, 0.2597565131802713, 0.12620376182659981, 0.1398341054277074, 0.07738365971994016, 0.0965674972582248, 0.18196886465434106, 0.14694131760587617, 0.09705070721646471, 0.1366924554590256, 0.11411890868217715, 0.10239117508453709, 0.18389283318913754, 0.0806485579138802, 0.11215300449440557, 0.16638833698966812, 0.08637308098015287, 0.12482275044725788, 0.1663934697787608, 0.0533646390953612, 0.17129126906154618, 0.17688007965203256, 0.1364346055854713, 0.126057431372183, 0.2105711709948317, 0.1732983428143686, 0.11600860244324131, 0.26907094724235997, 0.13210487582029837, 0.17835769471862625, 0.12477395830736046, 0.14167142941826774, 0.15693738605947266, 0.1488067723450161, 0.12741986511936113, 0.08836571397560258, 0.05899172343854463, 0.13663003461495524, 0.13931566308582985, 0.2329448147887184, 0.10136758968714746, 0.16921627395335706, 0.1780378070449637, 0.06737233079489201, 0.12520355743265923, 0.12698764597336132, 0.0708541544454713, 0.14121286450855194, 0.19603990799477025, 0.20669567008172313, 0.13212169911111557, 0.09486212425174252, 0.21280776468976853, 0.14299959605259283, 0.10291155562886309, 0.14943111868154618, 0.1798740125471546, 0.1533463795579249, 0.10501586126103517, 0.1626979382408242, 0.23397547883852837, 0.15583673221690042, 0.12505388683489255, 0.11626580114205999, 0.12584383073713512, 0.1186492155876852, 0.29098841632085465, 0.16000988893210888, 0.08849955719685362, 0.2078972330256816, 0.1016354293472344, 0.19357829895471373, 0.11894394493391437, 0.17314681062294593, 0.14484428980898473, 0.09884405776017136, 0.15471925508351098, 0.1658186586874147, 0.10727622666426244, 0.11466090056684711, 0.13100325670694152, 0.08813254745496858, 0.10366298063027282, 0.16557721841719844, 0.1944530947554496, 0.10376126205007877, 0.13484085158955667, 0.16994136085193004, 0.13165432419027054, 0.15383690565584168, 0.0999695711558865, 0.19483888131235877, 0.1583796078639646, 0.15290353477241533, 0.15012219127628113, 0.10902853021698614, 0.15804447504060884, 0.17163672875012123, 0.19913772241242472, 0.17698520223700231, 0.09740720623202863, 0.14049588282021785, 0.21188976153010325, 0.16253146733487808, 0.13208419144634279, 0.15871798890011926, 0.1289868366814429, 0.32758762338949793, 0.304778182819005, 0.1667390520414037, 0.17658849126629292, 0.2815576594683432, 0.12404514822147547, 0.2020104601979256, 0.1345028689191226, 0.1151339598600903, 0.13803799696747335, 0.09937212982725713, 0.14276076048131914, 0.20678677325767858, 0.17322855220446665, 0.16447883219488207, 0.1984932739287615], [0.026921846513305942, 0.03448087053613798, 0.013558510409277535, 0.09461836273511572, 0.014802073166074773, 0.1298295333981514, 0.051201134018840334, 0.04625630459838337, 0.036566315083614284, 0.06514139082883635, 0.03648403724054656, 0.10587440067601782, 0.02093747216877678, 0.049413667030392155, 0.006606056610302579, 0.06877675382119995, 0.030549027686638218, 0.043516310697962204, 0.04509901387556907, 0.0352152002855174, 0.003534458439624418, 0.04784603280225589, 0.05933808328043069, 0.03115324123251823, 0.02172136014597791, 0.019951208659838286, 0.018990262441577452, 0.05784736427989218, 0.03180408463512938, 0.035772146206469305, 0.026077768923113906, 0.03640012763020012, 0.04197318362252366, 0.05777865768440309, 0.06453437340115348, 0.038841002500585975, 0.03667352908861734, 0.06493453942840138, 0.014036734092740283, 0.019952267776393605, 0.02466512768859825, 0.0104355386217996, 0.03147723705267474, 0.07114918256599097, 0.028706513450390873, 0.04216917572663196, 0.015570560860778055, 0.0072046652654065724, 0.007973424921322974, 0.019214931131911375, 0.02247579587293008, 0.01897218276656443, 0.011462784004247478, 0.0047178232043440784, 0.03355852365794201, 0.015165741807000052, 0.03698276430969277, 0.04911991827670605, 0.021737746766678268, 0.03775536398132963, 0.039964313393518816, 0.02583181256458404, 0.054147799289034265, 0.08377213586842822, 0.07229237727099849, 0.06747370720991204, 0.02724330275199346, 0.06998033923727852, 0.059422471695729805, 0.07440740813411052, 0.048137981249319936, 0.054912538898568, 0.07685426232074538, 0.10641734250971388, 0.050519377053264654, 0.04274854121068793, 0.03410186768779832, 0.03419793128306347, 0.014460842282841764, 0.014619977896912925, 0.12157486706611612, 0.11297647240421466, 0.04259370718031161, 0.05204246326860401, 0.04188720557478167, 0.025489440210343852, 0.030779047501123244, 0.11262898258264027, 0.014244951044900284, 0.02734898075070833, 0.04991894798173059, 0.04630069939359542, 0.08483976366058474, 0.0030263020251426968, 0.02220148468510278, 0.03753653096575891, 0.017667669096901532, 0.0187319241869714, 0.026203572051599625, 0.03700266344352596, 0.026647862828066273, 0.04688584884147971, 0.02707146348491792, 0.02104304291518225, 0.0830319187333507, 0.04986473576976888, 0.08890665631981627, 0.05446859860732671, 0.08019832037990132, 0.05936334119929422, 0.02794958219202536, 0.009278937378117155, 0.068474585761226, 0.052211998526247284, 0.012608870691169175, 0.08014082548118408, 0.0062708543602287056, 0.040633858917581464, 0.12233364651159895, 0.059035214250006025, 0.04108543327498821, 0.06313192305125057, 0.03276276897879378, 0.009773295830875155, 0.024912520461986144, 0.029863574346827886, 0.037252599628822464, 0.019414814962675015, 0.01616159769436044, 0.04934678755460247, 0.04358744579217127, 0.04210834451500447, 0.06153850613402263, 0.012371711894839764, 0.0684773053733572, 0.013958496405863234, 0.03173178891771503, 0.011412219328415251, 0.03867704436303147, 0.023178930522032806, 0.04265665279461011, 0.03414504823365039, 0.0058883260710225, 0.07273329151493889, 0.05871536871117931, 0.019145548463829102, 0.024347758528986768, 0.07020774477672193, 0.043232164856406956, 0.021250530168594375, 0.03603630481408008, 0.032827767708729354, 0.010197894317248176, 0.03184255374024712, 0.05430288229798598, 0.020160411950200796, 0.05996909841234165, 0.038094488122770866, 0.07922541935958209, 0.016104792274775046, 0.04164712511063103, 0.071086332712683, 0.02878869744768787, 0.02885072950213667, 0.028910218144676862, 0.007979850483787878, 0.016999439328848835, 0.07560946903521977, 0.014863830386480738, 0.07371577629519087, 0.013029981562266908, 0.01952072661820679, 0.07430327380256307, 0.04141616492321895, 0.010963084961047337, 0.05810359387748665, 0.00703735932362296, 0.033147536638763644, 0.06955980293212399, 0.06878524973628021, 0.06761029302593201, 0.08438095360273316, 0.02625878975396195, 0.01786765826475476, 0.02693342401706163, 0.04135971190407872, 0.029138175267425757, 0.059056300820121845, 0.013505228994143827, 0.046643956579388156, 0.03152101514710775, 0.009435610019511754, 0.039858937999534036, 0.05429687999909925, 0.07171362082684232, 0.07875738560312218, 0.061914318226157665, 0.11364392650824402, 0.0592716328138786, 0.05035936043808057, 0.04297837907929094, 0.05991784713020729, 0.03305161476976449, 0.031590146921394814, 0.03795908974303353, 0.012523591698658083, 0.030187836382538084, 0.09954381779196764, 0.042991716670052665, 0.03950542672687481, 0.042752969198890274, 0.01824265064281081, 0.07048866921855558, 0.025245291819315285, 0.05642373925976216, 0.028321912414544535, 0.02348717557446611, 0.05216099239224869, 0.01917365239933133, 0.06338724483465476, 0.03787144545405623, 0.023779595165603587, 0.0643399249642126, 0.022661487924896424, 0.014477592795306157, 0.06826991771137522, 0.034072530350738, 0.057050364707866986, 0.024516667509751938, 0.04959213487323254, 0.024821348338117524, 0.009100430273270656, 0.04659778829063139, 0.008920931084562213, 0.09359589582609554, 0.039236759691829645, 0.014671983775652707, 0.04747823782024845, 0.031395100935873006, 0.021717081544920806, 0.057105009759505915, 0.06809035436280313, 0.06153826481632649, 0.03995095282011936, 0.061016149082851995, 0.06890341113772123, 0.05518910813055212, 0.039233205043860984, 0.03180737689798398, 0.021593925250213475, 0.0228469175917487, 0.033581919983149536, 0.027883903559056983, 0.027780292082517862, 0.06277521719194709, 0.044289212974329153, 0.03220226840987321, 0.07335090393861456, 0.014403740961795614, 0.03213490246825161, 0.00844247565950237, 0.02966490285020442, 0.0373526890161297, 0.10624390786453601, 0.10298495451288839, 0.025653095743168267, 0.09387211648807411, 0.015978066967950476, 0.07494910124449, 0.08202905601431286, 0.025651329910502802, 0.011396006035107759, 0.051026205502210126, 0.05930675411476724, 0.024230221489204035, 0.050762552512629386, 0.013449443429107628, 0.041523968815923705, 0.02292517155799414, 0.014211263286039956, 0.043754816851428444, 0.033168818561300155, 0.0160771154332906, 0.054919866529563745, 0.06192174544858356, 0.03219696325099757, 0.07404684885254792, 0.057885806571932576, 0.01747146631861406, 0.07208892730094733, 0.006935933591692799, 0.11457522895427481, 0.03296913391339683, 0.045725037944653345, 0.0632210037550859, 0.01093356376288519, 0.04912837588739011, 0.045480958501537966, 0.07048592662378665, 0.005913269415032119, 0.053558539779436205, 0.04411724155708667, 0.034790335583590695, 0.03473073777352129, 0.02723310420650148, 0.04183302017589731, 0.027798963560452385, 0.04779342937493517, 0.030654427978480538, 0.03675546985299837, 0.01970676149451925, 0.0812516070061153, 0.039224383541412895, 0.07365674922062505, 0.060013294024693395, 0.027832592905108488, 0.08500847154326978, 0.023363676455412662, 0.012883189539875717, 0.022616671781326016, 0.03883444095751451, 0.08370817518763005, 0.054325535517906955, 0.021620096728926706, 0.05168941547913898, 0.029018663636018193, 0.011952411864073047, 0.06121578010460062, 0.03935902732454481, 0.060634752209748954, 0.09150488948028895, 0.023155771684081807, 0.09199481036874557, 0.02306717170041896, 0.04713715632416068, 0.022468550596386198, 0.03797197151148031, 0.08211645898559401, 0.05442277505813588, 0.02875998638750565, 0.03243270382705716, 0.027618737545825785, 0.01877051778137684, 0.11330389072217288, 0.024440236832766284, 0.08678264690623169, 0.039175051309528856, 0.06791857446754171, 0.06545848994245453, 0.009576988673108, 0.04177261797350742, 0.014768311671251732, 0.15797846890505285, 0.11361561955944185, 0.13261591775282738, 0.22400617749700624, 0.25618689585356946, 0.25654761601359616, 0.09816232377723341, 0.1671652880407149, 0.11748833191250602, 0.11506436077216942, 0.12385482899844648, 0.3456122932895538, 0.05798619473353029, 0.10111280416529025, 0.10553664783196104, 0.1664779845985674, 0.14027197064170915, 0.1909594733508364, 0.23246516713932638, 0.15566028684618013, 0.11161968472503847, 0.16842415436140953, 0.18592512655642726, 0.10887125236613136, 0.09101008861175469, 0.14763193054785653, 0.12128583741404357, 0.1234255669518344, 0.08420510578059381, 0.15015281947149386, 0.12386994391319253, 0.18110218938560257, 0.13808229217125526, 0.15643985791792794, 0.16099261119961739, 0.08094190064096644, 0.1523702456465652, 0.12231136867476088, 0.10111484962004809, 0.14487995886273924, 0.18321193424203705, 0.17773966094659222, 0.07782550093026892, 0.12613721176861756, 0.07224773732765068, 0.12332741576697558, 0.18326857878315836, 0.08356275637784312, 0.055848679189840635, 0.14362149090776521, 0.08187417601866108, 0.16692632989537332, 0.12103513514082279, 0.20726622172421028, 0.12045014274096298, 0.11179197789920915, 0.1337346972356881, 0.1389296313807849, 0.13455585155996586, 0.10692008004914369, 0.17127286762960497, 0.13785022881723222, 0.18890707783641356, 0.19523231342675226, 0.13741185798520042, 0.2518333560757099, 0.18483706719933019, 0.11973278566954598, 0.1350989159677298, 0.14058762951002968, 0.15888282037790746, 0.1262158047287695, 0.11169018779671001, 0.2197590013665538, 0.1432662099720009, 0.11666355399234642, 0.14626716023250935, 0.09107427911893015, 0.19591498969783708, 0.13484187814737522, 0.13633737370612162, 0.2679554312940567, 0.134457225400594, 0.1715527348701031, 0.09888493621181096, 0.13065465605787693, 0.15229565932625724, 0.18733278247377566, 0.1529367829883291, 0.20224220179502042, 0.1562443063143761, 0.11694603359266637, 0.1600342658498595, 0.1520921557300514, 0.13131591251059888, 0.1688095119090811, 0.07292777059539672, 0.14882845263327324, 0.12656684919831254, 0.16971550281009368, 0.12010412380820322, 0.11042332351808587, 0.07192158305476751, 0.09844032942407555, 0.0808987086037955, 0.1528043417079795, 0.19157337024807933, 0.14429054613555634, 0.15129058261311826, 0.15467505181028, 0.1340092937912672, 0.07832581763185802, 0.1510116806434047, 0.1364391714695, 0.1220386566954755, 0.20184299337767786, 0.10758794784065216, 0.12597472451987768, 0.27158037549065006, 0.17365835817350497, 0.1140794168496805, 0.16488046145006535, 0.13332908432329857, 0.1270901561985093, 0.10809517465531827, 0.18738043314266592, 0.1155156555074838, 0.12270823286305513, 0.0914799839618706, 0.18397282809019092, 0.09565760696967764, 0.15208944377879943, 0.1524214662851826, 0.10695560354619257, 0.17650910923557897, 0.21338979232936137, 0.1598365385566027, 0.22216493113627359, 0.11171160761507289, 0.12617899420400783, 0.139984657026587, 0.10047710440572231, 0.0770998701092697, 0.12015486181142832, 0.27616133612971155, 0.18509819592920043, 0.1013753654795789, 0.1413447082403206, 0.12036161362043313, 0.07847455360235707, 0.128582127752804, 0.13981703698875445, 0.14344771152302144, 0.12578672654325926, 0.13749821141602533, 0.06563177137004753, 0.2016577226740699, 0.06317711074746425, 0.22017563062329448, 0.15310973499811467, 0.10310789630297693, 0.1446789833566835, 0.10779849178488217, 0.09891166501948911, 0.1226637537981714, 0.23817601553615064, 0.08948984841305403, 0.20461024085600532, 0.1538810782855557, 0.2356941051661007, 0.09995048790569268, 0.17096381243919173, 0.1936075022263873, 0.14072693493818084, 0.1259794206388535, 0.13185713830734455], [0.062473110419007084, 0.07723671639518392, 0.06104981864712412, 0.03638334264377913, 0.015571595079475834, 0.03666004594115, 0.046251508887977376, 0.05757501236193123, 0.04658531254878448, 0.005910545014851397, 0.022087027318775657, 0.02525727343445103, 0.026762163146368922, 0.06354653366631077, 0.013838351794308233, 0.010760088898091307, 0.03189126735613231, 0.04856705560439056, 0.042111968110886314, 0.07049896544025791, 0.013711018405193764, 0.09070661054143021, 0.03856517254344879, 0.021523571565687176, 0.07520802364113831, 0.0173850650072939, 0.09094585980018301, 0.0471398452927749, 0.018104285587586703, 0.020914797881437887, 0.06963301795504748, 0.015507223584028262, 0.02288779604338831, 0.03462187284904142, 0.03984391501533889, 0.018424129211193612, 0.04195380159803937, 0.010608862184228436, 0.01271536936157293, 0.022965910198587566, 0.03419837561405955, 0.07731432110191354, 0.044909280709802143, 0.08398143875022089, 0.053585172826123816, 0.012184472345266373, 0.017183750507331664, 0.057270124689826084, 0.019038587267841064, 0.035323835383619995, 0.02923984279585702, 0.06259725113669712, 0.11228721543786027, 0.05338417816786997, 0.025892390967196515, 0.04703990529261289, 0.030384184717531168, 0.025919263416360465, 0.0558343380238981, 0.04546496258567899, 0.05661635291612437, 0.027963796953460383, 0.03836347308430461, 0.021355183524710518, 0.036881177220493555, 0.007556562965375282, 0.04803958874676497, 0.02969592749591797, 0.0363359447839039, 0.03631557450599728, 0.09393877379836575, 0.06118876018351125, 0.0489851059542308, 0.10182859841734172, 0.020187276738485502, 0.030629070468186855, 0.04532014515491263, 0.06701931747938357, 0.03910860467341639, 0.057940953411161907, 0.035666261364014885, 0.03735756133532813, 0.07963051899306237, 0.07634574847836649, 0.10751573639290948, 0.03754943571684342, 0.05656368054089047, 0.035895467210080356, 0.03511644772163803, 0.002896332814763751, 0.0233472534455359, 0.059560716092105837, 0.01342511056141267, 0.02773440150063365, 0.026898379324965423, 0.035569757268193274, 0.03435485290303346, 0.03241938921893316, 0.028195521313576933, 0.04140803289990272, 0.02914632069728067, 0.08903702916277033, 0.0496818475996054, 0.029347005089925184, 0.006196097585357606, 0.017139642995091218, 0.011766829937245819, 0.03140615558462038, 0.01659490276999291, 0.010777610286529507, 0.06693537722552015, 0.02834858568084817, 0.019472474570295984, 0.01628982549112651, 0.021645687896037297, 0.045977931229337576, 0.006233692392631765, 0.05095140467728338, 0.10431134382322912, 0.06846993560752562, 0.0525741895750886, 0.011733098128329844, 0.06042462195299807, 0.04281101568091301, 0.06830756327197438, 0.04646777167856213, 0.040914706750622684, 0.019049519342520548, 0.027790760674003153, 0.022843625328894106, 0.01711357302302795, 0.14485683832918445, 0.03580459769094183, 0.006830999177069434, 0.013487864653730105, 0.05199301229309171, 0.02483597487181185, 0.01766520420900516, 0.036970694594445734, 0.030923160130999265, 0.06100975224868425, 0.01106243315828784, 0.07587568458890723, 0.041194225421115276, 0.00311896035958442, 0.03158471152757204, 0.028683159260019183, 0.0523673496659725, 0.01073633442677918, 0.07673567191006676, 0.01875032753413243, 0.049170744380042444, 0.04532830016086659, 0.054913626743420485, 0.03675920070118962, 0.015733712690792257, 0.035839657704796524, 0.04383313401992764, 0.027107281925817652, 0.024999797028759797, 0.046390595981070114, 0.027867057285602057, 0.030526351484079516, 0.04350340977731732, 0.003719705921192203, 0.07191954526088892, 0.023565010107573003, 0.04189366752642297, 0.08140903807455495, 0.011147934316296973, 0.014094906021660615, 0.010713802823316186, 0.019062615615586122, 0.061411412147384506, 0.020911940373480323, 0.01758864521229219, 0.008137324644673255, 0.09194481547080702, 0.03558121411310088, 0.0338556700115723, 0.016303563362828666, 0.01301238164981647, 0.061511884578653885, 0.07030353641077396, 0.033844963932830485, 0.04254429833963514, 0.03282470718747185, 0.020068243912030614, 0.11857098268885767, 0.05061815259978176, 0.027372522632621472, 0.022110785620527405, 0.05179531564335189, 0.07084023462788713, 0.0030256613841160174, 0.09135429191613391, 0.03991266757610344, 0.07859259242973021, 0.011717811801410731, 0.04461609503074039, 0.05355486255739966, 0.02344197830215337, 0.0625906819327464, 0.020205894590265328, 0.0046872136825244996, 0.025277576679664276, 0.005250236595935759, 0.06135893512457129, 0.04194344791974272, 0.02371451025077653, 0.06596475148633604, 0.04301391406765869, 0.04377735515816077, 0.07443111089448776, 0.03256825159393972, 0.01498093075614663, 0.06950149598020701, 0.06353829439068515, 0.0376392058998106, 0.037687005955846085, 0.03777078533124539, 0.03370591131369433, 0.061536644540366635, 0.015966106420232645, 0.042700059336399844, 0.03929741087279493, 0.004540204282684793, 0.050230274622839306, 0.08708529760159793, 0.04109334696324603, 0.03957060548747259, 0.043989504056592146, 0.07548963756210382, 0.022511648787786404, 0.046501429751515395, 0.026891752664420395, 0.11542683527354272, 0.03307249066570113, 0.020532996896954796, 0.020858281660043908, 0.028173465642236897, 0.04109618914944511, 0.058027977168920546, 0.011924667032285324, 0.061634925960172574, 0.022257319088244153, 0.055778593636087836, 0.08397816755478421, 0.022924227354627465, 0.039551694607061726, 0.029076924622659723, 0.015667324468884018, 0.06131070605929821, 0.022612621091426383, 0.059825594822365435, 0.03392236945669978, 0.03558716661627254, 0.06799558928656964, 0.050520422763281295, 0.1115966178176384, 0.05751827972069864, 0.018384750376665787, 0.024090404697363416, 0.022430564126660748, 0.03234866015132397, 0.07579553647026901, 0.04111980380971105, 0.021846270782031843, 0.021841996011414358, 0.036307511430594235, 0.028365129349573005, 0.05723607591203144, 0.032176826629907854, 0.026996476883669535, 0.03854358035530295, 0.02819620696226916, 0.02250817074861017, 0.07721453048889676, 0.08934495820393486, 0.04239326410536324, 0.04452101585845794, 0.015886128756157573, 0.042020945374162934, 0.016262707893826788, 0.011398758205975737, 0.04742410987795842, 0.03405986308691002, 0.056723275807716196, 0.023286376268632954, 0.017663319632711432, 0.05796814187159462, 0.00937804617288132, 0.03318016432345875, 0.03979747476536901, 0.059842988848686225, 0.036648830413938537, 0.022620693742928487, 0.02052019748295988, 0.03242326945426964, 0.026868536369875077, 0.046527411623467366, 0.03281237317189094, 0.08754331092800825, 0.01641861444729711, 0.0974335443348654, 0.06424827403539131, 0.02012455712012466, 0.06217973704840388, 0.03562897203430053, 0.02289036626837427, 0.04296709460416629, 0.015970702947778328, 0.039335175177022334, 0.015261790080506717, 0.039167784965567054, 0.018399447773493106, 0.03686008681993812, 0.02281893814553417, 0.1231045454680439, 0.13936412580791982, 0.01524806370012342, 0.03994102049018106, 0.03478590376494873, 0.10308431611666757, 0.06281765846295223, 0.020658380592301972, 0.08699679912458505, 0.050931160803884275, 0.09244052032309194, 0.017991189942544988, 0.025788723949282884, 0.043722583702014345, 0.024148516296859712, 0.05905022957332193, 0.030894671236315084, 0.058143097201302174, 0.03006584645669547, 0.06559093122280414, 0.04556306780526235, 0.02012133188996344, 0.09459503535782138, 0.02345511862527459, 0.0905554307504527, 0.0443646764653104, 0.03287594314784773, 0.08231048607417653, 0.0459119672286174, 0.027371026845949314, 0.046969743130067666, 0.08551486332209841, 0.03620182960143974, 0.03840026062642855, 0.0915366821291466, 0.1488993923750616, 0.15826691633030293, 0.08112620607378983, 0.1322212139324796, 0.08976719522428128, 0.14750564861441814, 0.14131837013748386, 0.1217620529895348, 0.1093146640567049, 0.1179299432964575, 0.13611278737023955, 0.10541405844231767, 0.20470244719857172, 0.12109797733325152, 0.15590940331739767, 0.22720056495839552, 0.20040417300356975, 0.0850283055596294, 0.23727344138728035, 0.1308134354410633, 0.31598381217448945, 0.12525639451679685, 0.18757406952640704, 0.15585680372051655, 0.0850736732865053, 0.1749961315504005, 0.10185029402735735, 0.10871881619095804, 0.13621294570545997, 0.10083083018300035, 0.16480403651873912, 0.10495108852703726, 0.1389585128955303, 0.18829259871234819, 0.12641565408557653, 0.17560785275793847, 0.186476418748498, 0.07924738310037122, 0.10910494748743312, 0.14544432051479816, 0.15293417828938655, 0.0914793940741689, 0.13060530467379478, 0.11221586200859278, 0.09371364354005746, 0.1042348652657482, 0.12956432908052398, 0.12909093270859412, 0.12099907538222691, 0.1803731647950988, 0.09198286705800603, 0.2257124238437222, 0.14060266015510406, 0.11054261106877558, 0.11561641905216441, 0.19147711896127273, 0.19771388671811552, 0.18554341558727527, 0.11107736342256108, 0.17987551407948618, 0.11575974644191804, 0.13561985575624053, 0.10700871642198294, 0.14046991243958473, 0.16226030285319976, 0.10395204092586234, 0.11333460318705729, 0.09689634816060144, 0.10950341279948912, 0.12227543915111212, 0.19962447935775404, 0.16544454731047153, 0.18615040237144118, 0.14353925902997294, 0.10761598665868083, 0.14031410547754458, 0.1649292765726005, 0.18033400238040956, 0.1615917225999217, 0.101866374212888, 0.24660089894408183, 0.12600875414547422, 0.22701863439813738, 0.19058517811279144, 0.11454647001359733, 0.1178051628953507, 0.0815084303218511, 0.16195673285232437, 0.13587827253485882, 0.12707579971080826, 0.23247206193064493, 0.1512278246903612, 0.13979751706844376, 0.13662799682107665, 0.10131688998831857, 0.1722359627244934, 0.12113916222006084, 0.16479317339197283, 0.13208339471490155, 0.04788910992623818, 0.21411158504985997, 0.1628682089428748, 0.08749932215939607, 0.08350869355302665, 0.05390920503545673, 0.10745337683587305, 0.14277525486484652, 0.10868583610581775, 0.15115346819643052, 0.19164507607779196, 0.09268777520065347, 0.2700755949462614, 0.15834907159930275, 0.10632812391005217, 0.11982431019385976, 0.18683367619110694, 0.16337983310222626, 0.18458847166790118, 0.09297528799863593, 0.12390969621558344, 0.13540731232252814, 0.15182227827608585, 0.12815255161014297, 0.1545286370861915, 0.15652682421909225, 0.11478812478843237, 0.20720317268804198, 0.169889236229562, 0.1775280214966305, 0.08233258004991278, 0.15570907132519832, 0.11172139055786595, 0.08543602521381072, 0.16270184528923806, 0.15086869799321698, 0.1557260171900834, 0.11627530063232107, 0.19157553061602578, 0.10668949524481451, 0.13854372224980785, 0.12292801582765196, 0.1844974144572212, 0.212481472521059, 0.05604687379673124, 0.1282003248531011, 0.1635159669263709, 0.18047655602135967, 0.14143757341850188, 0.09600966267528073, 0.20580745242055387, 0.10227635382644593, 0.18773430447664954, 0.11027882401380809, 0.17279957361038656, 0.1172306965435705, 0.14459791593253613, 0.10047420859336854, 0.09787601373729207, 0.12399765843104933, 0.12555572805145096, 0.12437222946074702, 0.16945595222134746, 0.10998574941749535, 0.150368825622624, 0.1483055056944009, 0.16200827524786995, 0.09716962704495077, 0.226495212484752, 0.26140740201357876, 0.1676314065773641, 0.04458443261682988, 0.0972076096842366, 0.1221053752928011, 0.12930617277179995, 0.07100538786260352], [0.06686122757532904, 0.09755612606362951, 0.038365384473675684, 0.05685840222624041, 0.008809618509164261, 0.010281269581267431, 0.04326035306158085, 0.02978748840940816, 0.056943449477154406, 0.0862979737200564, 0.014654710408179991, 0.02989810192957521, 0.008085957491740344, 0.08164038130592915, 0.0887732191251651, 0.00946705122553413, 0.023620779393240813, 0.07501886121087498, 0.04563778819095704, 0.027974828619570024, 0.009578076517960478, 0.03231327071966183, 0.01954388354093798, 0.044880111912085165, 0.05090252060683505, 0.0475587306784526, 0.04417599283999974, 0.02186475265320511, 0.03626991949614979, 0.008585393192216514, 0.03647428877171009, 0.01869011110806417, 0.03702756896194431, 0.05515190307050944, 0.03319354787949593, 0.061177720856522365, 0.017721369945173784, 0.028856676259648897, 0.03647693560548848, 0.0256732361946976, 0.013013379479337846, 0.09858299031733506, 0.01755703833975619, 0.057619663796597914, 0.12086673369330746, 0.022848187382483197, 0.038901649851111636, 0.043926140924374905, 0.004898786099792849, 0.018827317455302806, 0.028264088098019845, 0.0763360881096413, 0.03279764513154665, 0.08048813910253587, 0.042812237591152234, 0.016030767113871632, 0.061197823003655484, 0.03852885614539828, 0.03980739943442806, 0.03632855586587422, 0.07479157824549945, 0.03671093333152033, 0.04087323075040214, 0.015195836613495505, 0.03338070698983727, 0.016555500952827356, 0.08768473075883043, 0.05896431664305349, 0.025445583591898604, 0.0598433067751748, 0.09286952956068902, 0.03547968065005637, 0.06567670242680658, 0.02987139227409517, 0.03318861427326356, 0.027930449146116455, 0.041115272399638934, 0.02059069289375217, 0.10653284558605765, 0.04019426234487084, 0.06367144813280433, 0.04544407136798386, 0.03755446125362669, 0.03885943840648379, 0.0685758855674536, 0.012538749705849877, 0.04134149433323934, 0.044536709169586824, 0.020904204800664898, 0.052980813723538196, 0.014228988645387994, 0.021327068097889427, 0.04830022334992405, 0.04154768306761981, 0.08279555762607245, 0.058895441508221055, 0.050039338699031266, 0.04594159950952857, 0.039790028390745004, 0.05628131585375917, 0.05826505073796838, 0.01544271610797413, 0.01663317077703053, 0.023990594932148536, 0.0648481170496633, 0.013927428667703945, 0.1080365842508693, 0.018322530630675536, 0.0252928294902367, 0.05215932615101338, 0.02232688370220844, 0.03163015394802055, 0.013390466150256896, 0.07893587642860028, 0.04321549095273499, 0.053284556094196536, 0.01783782680098328, 0.050576109694497245, 0.024962021233213526, 0.021474720053975622, 0.046903817433743715, 0.03529494620799538, 0.08199843547997937, 0.03134669950081697, 0.01723202745310001, 0.04235061599061855, 0.026507720448857835, 0.061827298298838644, 0.015667209555695377, 0.02853216716058312, 0.024937627078484625, 0.04286086885258556, 0.05370049204136576, 0.03720145942943712, 0.006450042325717908, 0.01044599955240565, 0.03602263397507129, 0.023826359087721478, 0.0072681026123914754, 0.013503729377032049, 0.036083020855702704, 0.04348294756885979, 0.07062474175566627, 0.04624202471947478, 0.03206226201127133, 0.03483493339210268, 0.04873781277227306, 0.027484712378692724, 0.03778824830547937, 0.009030239382428269, 0.07056972132094445, 0.0189176258150368, 0.0019735363387172263, 0.027044631255369996, 0.025701627413171436, 0.07531347564391552, 0.05474082029034054, 0.0343354593872303, 0.02717487386337692, 0.02790027868843848, 0.040354723291051005, 0.05313960842848305, 0.06811601830826652, 0.039768731146450007, 0.07177519131331675, 0.0235472732569061, 0.02552477410063148, 0.05066481118481006, 0.027629280830883694, 0.0561870563955557, 0.05727502765254148, 0.03348856833913634, 0.009081584510333356, 0.09150541808095672, 0.017457381792126164, 0.05903327987799722, 0.04067195647005593, 0.12458068198494374, 0.026310732430447976, 0.029635013929838618, 0.01706981025035343, 0.0856686171685015, 0.01750740541836187, 0.02078787817980253, 0.060193378313054005, 0.02717435292358841, 0.011981094195958109, 0.04143729745861023, 0.03944750281891996, 0.029406597154335152, 0.02087004494012123, 0.019487694822131627, 0.04065781831741333, 0.03917482148315157, 0.043292398519453504, 0.06524880401669972, 0.047474024336664915, 0.0216706374645113, 0.04812780760168549, 0.06379300330374992, 0.04249455242027198, 0.040743578030096914, 0.04833966538670564, 0.03312767580932668, 0.09087175611526736, 0.05811791972167069, 0.05768036477327828, 0.030298635679026766, 0.04233700643864371, 0.024492675551183285, 0.013451805852744128, 0.03274457822103174, 0.043187808365591114, 0.02916450379416347, 0.06146030004827246, 0.036164528780406525, 0.0024883098376449198, 0.0694355434708057, 0.0069966321743483995, 0.06656335726861032, 0.04188436721902221, 0.07841647647681736, 0.06876542338079984, 0.03331243706446502, 0.021890035469926173, 0.08457251388819949, 0.06222755242619784, 0.047006783481206627, 0.06654608964679704, 0.05105617486180798, 0.03893590547264584, 0.043137353814898, 0.03052816136680063, 0.02886380279256452, 0.04506947735564844, 0.04319227082775005, 0.0627595047286201, 0.019090152646024382, 0.021740115893584107, 0.02246954076502833, 0.08221231190667999, 0.01858297562707336, 0.01794743100031009, 0.05298622613472324, 0.07045362069601975, 0.04108849762668533, 0.02191086157014774, 0.017991751101949525, 0.022199557973973216, 0.019348983112121784, 0.07020161607332769, 0.02956001392205156, 0.02650803837534641, 0.03160118433316389, 0.008741406040386328, 0.03441877910987504, 0.06341418431651208, 0.009501133519675463, 0.01891115428729644, 0.036023208541014505, 0.020421284040616407, 0.03659362228767526, 0.07119871781117494, 0.016801085758713946, 0.019931518284964467, 0.06467050722529812, 0.03884074969157096, 0.048055573171305085, 0.011051829543805892, 0.01918251603661526, 0.017597030044623443, 0.05746458844852544, 0.07433061548058065, 0.00801737442792904, 0.07313189472282126, 0.026991238757487268, 0.0544784045327575, 0.015175938437272225, 0.034747292933564995, 0.018378351627278234, 0.06389686950452386, 0.015271475347089431, 0.0782309223206774, 0.027180450983465682, 0.015537457243959992, 0.05706166450475013, 0.016160684134510737, 0.01262881483266791, 0.023888684170801314, 0.05754994979548839, 0.012207584260332008, 0.010982782996800399, 0.07659091193589472, 0.025800768766672384, 0.06718601055082775, 0.02733764073420917, 0.066801909387352, 0.06307860716216027, 0.04974988769860037, 0.03586966153835097, 0.03809143143195299, 0.08013758492926437, 0.04100865594321682, 0.051958388949353854, 0.006141705821538645, 0.03899906176112352, 0.024993833034269275, 0.142324902417679, 0.055513419961977395, 0.02850275321473037, 0.02636694604711187, 0.04989740941973944, 0.027678425371226285, 0.024631651561527003, 0.02009814623893509, 0.0867424885772409, 0.04364068890290876, 0.06496316813413175, 0.02513097234881453, 0.02398732948237129, 0.009074802716983663, 0.060645527236403964, 0.017840603869708798, 0.011768121753008136, 0.05053591689154987, 0.054301522491920384, 0.06241672634778004, 0.02334023416492968, 0.044578227304643205, 0.10789950047769856, 0.028464222822578687, 0.0060154698533757085, 0.07865554187446833, 0.04736468443767198, 0.06561835717049337, 0.04360770881776849, 0.008770712733929677, 0.038546414880622784, 0.01932881967795472, 0.009689224384454711, 0.06625959574575387, 0.05367862023112755, 0.026960436277271762, 0.038207011117089185, 0.06727118420624925, 0.025271503517644543, 0.020492545539332975, 0.07329171598558465, 0.04033651721153048, 0.07572537813816341, 0.01005688242824568, 0.04477344565994797, 0.1249589532193157, 0.22862801658770732, 0.14373609766123757, 0.1771424800878571, 0.12896998274710872, 0.1834508004568277, 0.1380714596880059, 0.1253208378329873, 0.20489501105921887, 0.17124455301992356, 0.12062068157378705, 0.15968123721259256, 0.15209731916266103, 0.22837009010536058, 0.16332312727407103, 0.11362485857980867, 0.1435462304300839, 0.15486318768272478, 0.19763450468740157, 0.11122930930146288, 0.1106244599026057, 0.1302749062738111, 0.12044653446683962, 0.17475916523366206, 0.15517746759278161, 0.09373881718924931, 0.14966425455866322, 0.16781200414463399, 0.15367578204360702, 0.13710474865811487, 0.15352241124116606, 0.07093250991836672, 0.16664140647457493, 0.17073030883987106, 0.12520244660516902, 0.1771422655832383, 0.12808087642394728, 0.09567842157858034, 0.13948665391052925, 0.2379295956944266, 0.09197197328772276, 0.18214793004576238, 0.21355016517543027, 0.3164175405137001, 0.17795724523884637, 0.21202339790761474, 0.1690636692388404, 0.14760975996332784, 0.08314888503762984, 0.2720791600163906, 0.15337038875347184, 0.15036885626614094, 0.16695070681312393, 0.22316518149548964, 0.13071874697362224, 0.20669320327860696, 0.11852808176509796, 0.11327790501978129, 0.23182543775727674, 0.11801776761609702, 0.14245506075601425, 0.09966996949045889, 0.12736615469498982, 0.11457113038387992, 0.12420443322269187, 0.1107958950583012, 0.26534187637509843, 0.1450498158773107, 0.1777671635030739, 0.16028335167756005, 0.24272947361873043, 0.14569020409497524, 0.10982884694972347, 0.14336728761273046, 0.15653790185047736, 0.14565701716609541, 0.13866712369265097, 0.16260796887499673, 0.14770913688886553, 0.10049129235408, 0.19421304876525558, 0.17587149425620036, 0.12312182075073644, 0.11377795359059689, 0.14217032119631767, 0.11061138278173824, 0.18004313411731876, 0.11799598773640972, 0.12159006625053384, 0.11700330632588557, 0.12072339098179534, 0.1005740145281438, 0.07844072315962085, 0.12338943058444608, 0.19926172140384876, 0.18796661297880835, 0.188158655899667, 0.11245654385176398, 0.15533512848759853, 0.12291146066760826, 0.2416144479666987, 0.07942708434476968, 0.10014626933562179, 0.06600032094866037, 0.16075792782489332, 0.13793601534299313, 0.26042380640583657, 0.08448696484969509, 0.05203349237901069, 0.18313727131293667, 0.1703998797963704, 0.07239055909937428, 0.10041449203967087, 0.23535532576422538, 0.1335858463520004, 0.10325300867759413, 0.16140182472525105, 0.2071572840213776, 0.1369186965448241, 0.07096751247562709, 0.25598565987761945, 0.18766359456123846, 0.16473701914712308, 0.1434419965071063, 0.07993641790122756, 0.14730844226094986, 0.10849265171395195, 0.1616477236271866, 0.12870140764261448, 0.14943522491282032, 0.19654056177504603, 0.3197285725224403, 0.13307803731051185, 0.1085373682660922, 0.15194408625604647, 0.1503741116293015, 0.1716694253827295, 0.17193424665639478, 0.09770864650847451, 0.16945218306876, 0.12135514538855323, 0.16905626882949185, 0.1013532638429634, 0.13800851790414703, 0.11471146236984961, 0.11893583206279625, 0.0921513297925553, 0.1253042826729436, 0.08054971724988953, 0.17711287845046292, 0.15614036350480973, 0.12314328653437477, 0.09880987491698996, 0.17367417022826212, 0.1314315305001313, 0.21839515035671575, 0.1585387702911131, 0.10294514092346353, 0.1250772142121869, 0.17566256675749056, 0.14411790056094048, 0.17313467579022532, 0.1357956422913459, 0.15226437229542963, 0.13924057114749186, 0.1190830281965675, 0.16118024145403217, 0.12741233447506545, 0.18051406368613246, 0.19529186910198582, 0.12904424731048847, 0.12594425720312905, 0.13868524933293944, 0.16975057431526724, 0.1289217958166715, 0.1885164649255814], [0.07127736439748157, 0.03486294922749362, 0.05108973717377071, 0.028694177519590146, 0.057611064459647865, 0.061878618528886195, 0.021851995374046026, 0.08996599504063207, 0.04873180281250708, 0.10604749824250899, 0.01947839068429124, 0.019288910327539332, 0.02190507186065999, 0.02414684239474516, 0.04952800565309102, 0.021676053706135963, 0.031125937858896873, 0.07396205824108855, 0.03469130339761896, 0.013563014048662399, 0.028271113124285496, 0.0483144419417987, 0.020302689799498168, 0.07249463980476703, 0.05121598080281289, 0.08902617369688327, 0.0379449439295117, 0.03417139782780602, 0.02712158478736397, 0.034717411674078436, 0.02174275123604363, 0.03289144493699555, 0.0055285084583315885, 0.010804484650913266, 0.04191021119514781, 0.042158170873599674, 0.025579645148208065, 0.14667047488112606, 0.06267900803997632, 0.021700892191860947, 0.08964862013536115, 0.03912681458337654, 0.019500641708051967, 0.04051682366538913, 0.07345089373449165, 0.017178669429173874, 0.02285907157666741, 0.016897915441903378, 0.02302161628200162, 0.005967478275359158, 0.030419533929577282, 0.0833595821994447, 0.030118576288523696, 0.11012163809350423, 0.04621981583054989, 0.03667897214331935, 0.0675838936360613, 0.07607408603953739, 0.029826721687230374, 0.03287827971601679, 0.055341283835831194, 0.027504755154011712, 0.02176751885863562, 0.014867398440988075, 0.018571840539093942, 0.09279018583437128, 0.014520153767549464, 0.050311908952050635, 0.022533154791040767, 0.037840100966634295, 0.028198352008457148, 0.03942612130495329, 0.014434524289813015, 0.03642681047260281, 0.026600003400216662, 0.045628039722120574, 0.02250502404246119, 0.004306606358788427, 0.03922557863857477, 0.04149475788337089, 0.06064143249644868, 0.05785882112479979, 0.06078325069299149, 0.045326599445674694, 0.10263909645859273, 0.03718010089810818, 0.010522874560387386, 0.0360497496571512, 0.06873074258046766, 0.03118517943808148, 0.1181020985748018, 0.015841201529838145, 0.0007533952837900049, 0.033865617663269086, 0.02761945766847461, 0.007067016502391668, 0.04512151387790519, 0.053519170521007436, 0.05147078164642857, 0.031135173048824075, 0.06966642704942534, 0.05730284813551172, 0.025134111394084273, 0.027558078703981255, 0.021143243385238514, 0.02557678955547031, 0.03694232252817001, 0.027749481941423113, 0.012081646108849636, 0.022468650187816352, 0.02610093542194415, 0.16606294880470923, 0.04495340354380108, 0.06777220570872869, 0.014072344732290555, 0.027505967488151886, 0.026131904526283185, 0.04082302900872404, 0.04250705114475662, 0.001111595613052017, 0.055942624551995154, 0.0807292193114277, 0.038476528509730296, 0.03971624646275755, 0.03723078527517858, 0.021508646257702383, 0.07380810521182514, 0.0637576368547255, 0.00663566590857602, 0.043568630672750935, 0.030444807170199293, 0.025107292571075024, 0.01741432573556179, 0.04970225618190823, 0.03929175714391374, 0.05461445025679085, 0.05249052511287793, 0.05176281053272467, 0.01148151581160604, 0.06808463934688799, 0.0657043582008731, 0.024473069445981134, 0.051498981342921336, 0.03638995398256568, 0.029631329046922828, 0.02961830555221006, 0.058589473652142676, 0.058594847758931506, 0.02483371491243522, 0.0359792695681174, 0.024199254300084808, 0.07583489806781854, 0.06781778027934414, 0.05036330962133023, 0.07347336309331079, 0.04288739464696377, 0.07714618012429246, 0.07133015551634374, 0.016048695486519608, 0.02266259875238663, 0.01949723070156911, 0.06322300324456827, 0.042179230630638144, 0.05270393805638437, 0.02126412822925035, 0.030663268633126736, 0.03041775469037314, 0.03417122545802305, 0.08442864257601962, 0.04809722154130859, 0.04014979094086636, 0.00824663294253931, 0.08398091781043238, 0.029866180960990252, 0.061517454037863406, 0.005985602958037729, 0.04210092495345781, 0.016938274868974285, 0.00799743315926002, 0.023542835692604704, 0.039024066870972034, 0.03494182564017754, 0.011898177627083516, 0.05084491079492916, 0.07889912719087255, 0.0063725429560778845, 0.029573640711004698, 0.0663074609192629, 0.017078288928455403, 0.028839132846182877, 0.021428624543571667, 0.005784126622001491, 0.03823719115086621, 0.03476128552950198, 0.032917361691473954, 0.025610710013537638, 0.01865727657962951, 0.0413477877455373, 0.0477014068934706, 0.03740148881690637, 0.052635200817378304, 0.10736488601973943, 0.058457649072572115, 0.0418598638967641, 0.04230913232951876, 0.04076171516170425, 0.08275928336285776, 0.01850442288653745, 0.0033745280093318156, 0.010236026343679237, 0.04328831910125671, 0.05339504129463627, 0.023642174313746156, 0.0762823393808738, 0.06782069907433565, 0.06821917970815013, 0.03501060501401944, 0.03922303139622654, 0.029626190512170716, 0.034557134589000095, 0.06364836973408539, 0.024546897339244044, 0.06825483344014614, 0.050320519780319546, 0.022266447025861953, 0.01872416754673806, 0.028625637548224583, 0.034083263242557164, 0.004190042729474484, 0.018439481613196192, 0.13231642333970917, 0.015317415724688721, 0.04178199872014023, 0.1258578961114249, 0.01073335434475373, 0.0680069120660905, 0.02614865695396739, 0.06436424825580851, 0.015563025428432853, 0.05321129127555797, 0.027453846696223465, 0.013827328746687743, 0.032144137658178806, 0.028081450821651567, 0.04504493572899411, 0.03975773012385734, 0.018311125496702812, 0.03179264694241987, 0.026654476082072626, 0.03893620424693631, 0.021991808335447026, 0.04963006005592404, 0.018409169429252227, 0.0566925288688752, 0.023065930637981624, 0.01707872176813262, 0.03540607875273113, 0.04758934355190685, 0.026331219536763047, 0.043502720298185464, 0.04311436351629035, 0.03442743973385903, 0.017646952164209178, 0.07610654518488916, 0.021761470594473427, 0.05323687861222894, 0.0602449934869524, 0.05422894332197405, 0.05147303777536558, 0.04225335729819152, 0.025627889535239628, 0.024011846211168076, 0.04764303482408005, 0.0317093578632921, 0.041620561011856606, 0.0755119000771834, 0.0314914939489456, 0.01750544806371533, 0.03678746551515595, 0.03879166260782269, 0.034852273792268774, 0.03451903703652563, 0.03681369253524369, 0.003704734647931952, 0.04583675654665117, 0.05246554298566715, 0.026948952619286797, 0.015624740514002982, 0.0793827738192293, 0.06779865106387485, 0.04044636655899306, 0.05394747112727454, 0.040006758494963574, 0.008294190723268736, 0.020514166455775983, 0.043762527526386326, 0.04439406742852542, 0.008102104709964366, 0.06185463614641659, 0.017023802840060765, 0.03356420803034017, 0.01838844866612025, 0.04259045896751266, 0.07566362379058715, 0.07461790611306507, 0.033722144716809836, 0.00950807714909916, 0.019829986737139767, 0.03539171077371125, 0.035428965629469004, 0.01082440485216437, 0.023597580335673787, 0.012005065087108843, 0.05618539015432039, 0.01237560745193473, 0.02249879383241698, 0.05225897503776416, 0.015521937260223974, 0.06202746175169464, 0.027831681260478594, 0.05173991599510755, 0.025442946334219268, 0.0802800006743881, 0.030765696503822843, 0.04250469925482908, 0.04204993797165733, 0.02170620692683564, 0.0469384292861627, 0.04406284548402314, 0.02315004709206762, 0.053903907537460334, 0.017721366114734162, 0.05800004560320128, 0.06207086446304476, 0.012162635008984757, 0.015663492114042804, 0.0230186955717903, 0.04639387483738604, 0.023207222149076483, 0.03742828274205808, 0.024946666915991136, 0.06305500782365281, 0.02409008102521541, 0.021406390756789236, 0.012269170068564915, 0.07202118980668246, 0.023747386914047024, 0.017537997224398198, 0.014837274906195462, 0.04682486058182774, 0.02813662830439787, 0.01359584857709706, 0.17783552918943668, 0.15733034319935307, 0.10896562673752347, 0.12426424936781968, 0.11982956555702033, 0.12596102686779154, 0.13177694422343086, 0.23170032027748325, 0.22550842995124482, 0.16719266802312868, 0.11962021670995221, 0.08500523865222932, 0.12743413733739045, 0.11522542309737015, 0.15982222803417714, 0.10175457900209774, 0.09359747396721955, 0.1505314814107072, 0.1529910833004021, 0.10211221948866883, 0.06866616902933007, 0.14464870756191595, 0.17169668279107542, 0.28375550443606995, 0.16105494011313687, 0.23766598483968168, 0.15606890282323285, 0.1643305022509829, 0.14410666971197053, 0.057654509305833816, 0.1575636935810889, 0.14684558725885807, 0.07011846489002628, 0.14211943763638699, 0.17897951296500622, 0.15843311144459635, 0.14989996449120585, 0.2161984698426339, 0.20586945957714514, 0.08412731721276238, 0.1111233976459311, 0.15097647124240476, 0.17229360317991627, 0.11056317286866327, 0.20027364694303085, 0.11017264422750282, 0.266802039958777, 0.18299484024605445, 0.08525645420435937, 0.08042520497955623, 0.09650375874292466, 0.13254598924709907, 0.07313055406895376, 0.18523773118372888, 0.24331982097318097, 0.11204382164343712, 0.18199307303274834, 0.23292722540997693, 0.1355811223507889, 0.1615262527259127, 0.10549925508037691, 0.16928430256103316, 0.26368185577373354, 0.14709710924615785, 0.09127415911925417, 0.16802434839548605, 0.13502649001536832, 0.13868195515486503, 0.16541145231214263, 0.14065185832160135, 0.16353210073805627, 0.13639423275186172, 0.14239596473353525, 0.12516926733716843, 0.1893740084262625, 0.11048048133811644, 0.08974408235160575, 0.1350005349564937, 0.18693136772321117, 0.14944581224793388, 0.10254289879794083, 0.15468501095329562, 0.21502773427674848, 0.13574724085628986, 0.18301123452763404, 0.12021879184870951, 0.0957568766429059, 0.19791071002762164, 0.11047127296126659, 0.14035363561443745, 0.16003950589126156, 0.07927607309313552, 0.09260463933911055, 0.1311788747027036, 0.08304088196206479, 0.09457613596872938, 0.08309941874035905, 0.12170271947979928, 0.1217565754608762, 0.20538392837249464, 0.13360061652718053, 0.15192844274063266, 0.10599243184251171, 0.08716968984733667, 0.14012428421166637, 0.1595292453684153, 0.12125885579735042, 0.08234793245191536, 0.14793821249998387, 0.20982225876181357, 0.09352359244780195, 0.239610867574811, 0.18220569307525314, 0.21403163611408205, 0.1658788731982631, 0.18564354327897872, 0.18022383893689803, 0.15208398923277855, 0.12436622333142067, 0.12477400427263592, 0.13150715870001625, 0.190675622453132, 0.15709103265356633, 0.17644216847275535, 0.11035482759677595, 0.07881499541502807, 0.1391476753257936, 0.17921413505269637, 0.22114251019252887, 0.2313946971609708, 0.1435298361485043, 0.1430133703134714, 0.08780701371330409, 0.1692861871373269, 0.07636887667280051, 0.1966969969291841, 0.12546808759291328, 0.1283737518373997, 0.11328384220119446, 0.13822270076601736, 0.13226408421272232, 0.09526467281243495, 0.1677399918797516, 0.11761526502068005, 0.1058630855573762, 0.0769709375116133, 0.20493611933723574, 0.1757388844365074, 0.1425477420730937, 0.18522199573776416, 0.12486723717302085, 0.19323398839802514, 0.17830688776748796, 0.11775530589323853, 0.1439596421175426, 0.07232758667199843, 0.16761573241843333, 0.20663871910543213, 0.14222725685085022, 0.1384151573743551, 0.14751214504001603, 0.1993867622748498, 0.1300078939886824, 0.09584501505859437, 0.22076384825331552, 0.18524119390114663, 0.12788147139813633, 0.14662308468213006, 0.17975352223842375, 0.1669083881161867, 0.15281777889017137, 0.0994881155389932, 0.1515188002057614, 0.0897232064556691, 0.156409444227334, 0.0963349742514472], [0.029063192496616996, 0.0528321428705127, 0.0301074450309839, 0.035516701848997224, 0.0536606248257862, 0.10148413464306824, 0.020575332830870346, 0.04643659573048354, 0.005705932506375136, 0.058765980309896895, 0.047241240859993046, 0.05897807558217357, 0.053654070943593986, 0.02618872526762707, 0.005761750630148116, 0.09148688641406837, 0.008312513631197714, 0.019615315494217703, 0.050199347653336106, 0.09077607939440398, 0.03092258173461643, 0.07989575395420676, 0.035434312923180486, 0.05504836245710331, 0.07167209886134633, 0.10134121327991448, 0.026817292748619954, 0.024456190613789425, 0.03807816278910445, 0.09987135102311451, 0.029549056949514537, 0.03234872526879753, 0.02673891237786701, 0.03043622507022754, 0.017474865833778056, 0.02212803409014258, 0.04703484911231264, 0.04650922469614495, 0.056528896318688515, 0.06072989266906535, 0.027787305617464647, 0.019299432545179324, 0.042187902745940996, 0.01968850944972327, 0.03294202972263579, 0.05299472204980351, 0.06460426360248558, 0.1338054990816501, 0.05507184688242213, 0.037177055698609164, 0.03521486320683072, 0.02967842238684816, 0.09086231791204022, 0.017118135076617042, 0.049734677022863785, 0.04338536711950456, 0.004319780677061288, 0.08085563914069245, 0.02413215265879708, 0.07358453011200314, 0.0769174952180155, 0.020014142782817927, 0.06092476628480419, 0.03483123701786803, 0.022041581067887527, 0.05733398960963373, 0.02397613502257774, 0.047802526669036, 0.017408846291683374, 0.036341035438160744, 0.0718117107246672, 0.02641204755843407, 0.03013899253170577, 0.048714232585963704, 0.1510434120052284, 0.019238610909650886, 0.005401467140238252, 0.0408696263067184, 0.009029638003407708, 0.07458921612030076, 0.03297541966481555, 0.05608261179839892, 0.03389632246727425, 0.028393999372999516, 0.07044170036791794, 0.0799840685701178, 0.04246026615522081, 0.05905653830737837, 0.0352709676559654, 0.025690228024858142, 0.0145866664787454, 0.025357705646104393, 0.019647144532251744, 0.05538857444339702, 0.003971661466376616, 0.01459425841007502, 0.12559103704388105, 0.0587443613086737, 0.026957557701896277, 0.02144838003591905, 0.07784942585614421, 0.04221819386246704, 0.05105848078646007, 0.0344904504656311, 0.025031658625530622, 0.028424985714316852, 0.019282998043983694, 0.021033206346234488, 0.08730776953480898, 0.04385834980395533, 0.0449637687134166, 0.08150705902446663, 0.02212607098983661, 0.03324011453397332, 0.033155860184060956, 0.04406459982536974, 0.06090530765152747, 0.0288532403553085, 0.02100906308530079, 0.06898249439414471, 0.01711412077589381, 0.06488739437754117, 0.02383070663669177, 0.07200851871241486, 0.04860454411696523, 0.06991044137506716, 0.03338284820558564, 0.06935190965211199, 0.07728733182434114, 0.017069521052162015, 0.10131725004964298, 0.06014003561088636, 0.10025938987852105, 0.02633889956820396, 0.04021883461504214, 0.06658394205113573, 0.05459114586213424, 0.06471590559569097, 0.0238952323073341, 0.037988044036131714, 0.04230535551605206, 0.014239085684230011, 0.022820432016986514, 0.07224089616248686, 0.045653504484723655, 0.08646239151036547, 0.023426208382232055, 0.09430728507258239, 0.06279164977792291, 0.06887355669131202, 0.04033476287018388, 0.04599540952533003, 0.07539743888041667, 0.002879940687806436, 0.058283287461005875, 0.06885235137756794, 0.05099012659141614, 0.02544633818850402, 0.03727604191930544, 0.03771518650014074, 0.0035654670453720517, 0.03080463483779421, 0.04977930164445312, 0.07576595781551254, 0.008427959250947161, 0.05157084422065847, 0.0347447341998979, 0.011959833340839514, 0.03726999748558287, 0.03719830314718908, 0.09265747642324818, 0.05253520336062197, 0.07353838863632373, 0.03457783428471416, 0.03574863879851276, 0.019410329517878352, 0.05786410330103771, 0.09864495150865087, 0.05406855898458631, 0.033571757826833956, 0.055241566001167225, 0.05959489893528724, 0.027437103844638315, 0.06032288547665362, 0.06808113066419479, 0.05189607152715326, 0.014743803560944095, 0.02134945893269633, 0.040888112008331284, 0.03598271313333704, 0.04153102448570632, 0.07641972958921425, 0.017372595011106422, 0.019711890453172308, 0.03722465657178433, 0.05817792738877958, 0.0620927247819641, 0.08424563183178825, 0.03693278473351271, 0.007419309695251287, 0.02189089731884099, 0.023067631353173527, 0.043723522159721584, 0.039219438443861665, 0.01688415841800311, 0.03156332043750632, 0.04872207349586872, 0.030908432090654973, 0.016003432139123402, 0.025907331596939795, 0.03128596979583944, 0.0522550258545145, 0.03741688718418441, 0.020988757924867735, 0.07990883107507422, 0.05994409713293276, 0.04916065500207967, 0.08901679678069008, 0.04787835022134166, 0.08567074689293101, 0.04178334703488697, 0.025927380117918217, 0.020075983315285657, 0.10918604555509745, 0.02514140455112342, 0.014563449226590175, 0.019458382382928845, 0.03592586174847619, 0.015194594593448265, 0.014388007431050703, 0.05084484950789521, 0.055521747337714325, 0.06821664395712077, 0.02695829889196302, 0.015400971976980088, 0.012776015754488688, 0.04824932829867448, 0.006090387027905954, 0.007260876009240747, 0.018430694584704695, 0.05274367120657718, 0.02230006296397938, 0.05047334282989464, 0.018373948536933433, 0.038802414651839964, 0.07390987233168657, 0.011145685848239209, 0.046730290858014945, 0.07376484422674102, 0.04295173454128447, 0.004383212278386759, 0.013150188418465757, 0.006442994316814528, 0.019310130963041898, 0.0542700094651551, 0.04365842766879548, 0.018257899622943614, 0.04594475962221623, 0.033852977212518454, 0.04204861646998794, 0.0698551451486926, 0.07478682083948966, 0.036090103338562676, 0.04702916473991448, 0.08638939865294003, 0.03393739627133455, 0.04831238882616163, 0.022495853970007553, 0.05032041635844977, 0.037296676497545936, 0.06701649061494297, 0.03166767884977162, 0.018531787547192747, 0.03590752926444815, 0.02631123613325819, 0.018165792871807373, 0.027490011791908936, 0.03178640332583699, 0.03992670613731589, 0.028847077177957665, 0.005279797056104027, 0.01701044992754056, 0.031041047656007355, 0.07713690279952942, 0.01644865658524777, 0.02123276650485012, 0.10905777179305592, 0.04615187532298508, 0.03444680260614522, 0.01395023606281968, 0.035677212590892474, 0.03940553269198826, 0.03421419532969594, 0.04925469612522472, 0.06985932032787992, 0.009393329626970716, 0.057087971964069915, 0.05492217245421583, 0.0618124706670642, 0.1422749534850159, 0.07833687994148462, 0.03459497550201993, 0.053088073693816705, 0.028155575573985136, 0.03143636434669456, 0.0206539832476166, 0.0274966269611351, 0.03257139255442927, 0.029229510184978286, 0.03414063173676691, 0.021929483252367186, 0.0227006254417281, 0.07894287081134897, 0.04013414742545255, 0.04242347095221762, 0.042544727348872734, 0.017891916438877102, 0.05362782477130813, 0.05022564362133703, 0.06640314530100554, 0.010556098836053525, 0.015926833880404313, 0.024366552580989177, 0.020679649108299808, 0.04369287098187112, 0.05239191810570417, 0.022103310517606237, 0.06316599864212256, 0.0372689287929285, 0.019549613878611597, 0.028652984971901583, 0.020438032637860988, 0.04628194939164866, 0.05061470520412249, 0.02505085487369328, 0.009665607808968954, 0.003941936297304628, 0.044968349919203794, 0.028175319575013655, 0.024560880359081973, 0.028576868390964887, 0.06693726180181389, 0.015445214512217191, 0.01613291344725557, 0.030548907027790145, 0.003976461486027186, 0.03291177691050595, 0.050741557873064475, 0.00809877126988384, 0.03825930427880057, 0.030157415031064904, 0.018863946034182465, 0.10889805778260193, 0.22289559515493534, 0.08267077722496564, 0.10972528718411924, 0.2265707947193615, 0.19431763508867836, 0.16093611987608095, 0.13948961100991697, 0.09071491493452942, 0.16389881170565085, 0.20085601166131037, 0.14818909097342722, 0.08930808639213925, 0.09595252017700866, 0.17218302604892563, 0.16413666668438143, 0.15233741111813054, 0.11028237866177676, 0.23128594331923993, 0.2690781791123652, 0.12705146875833312, 0.1638239036284147, 0.11495395218052211, 0.20185597090711518, 0.1919041823355421, 0.18746778248779236, 0.1305667704512035, 0.1250861084929878, 0.17216949693618283, 0.17060362854071204, 0.13045636185955617, 0.16765517062477528, 0.12346558738499881, 0.1411140238445613, 0.07299753822266095, 0.15833859151649862, 0.11734376346031505, 0.21298823968297054, 0.15937523105211798, 0.16066731494520942, 0.1845585482735788, 0.16256918950426966, 0.14122274704277515, 0.1984353576816859, 0.17366277083994883, 0.09810060007317413, 0.16667221853088948, 0.1939918025727234, 0.10628842523381596, 0.10617122144228029, 0.10310528394315513, 0.12517299052448044, 0.13824510117692335, 0.15966122699601037, 0.11714530072265095, 0.15762718694825328, 0.20806914315589015, 0.11870651130354214, 0.09613445073726679, 0.1205398822804132, 0.19704365171492103, 0.10256101677735006, 0.15743941879801213, 0.2186802116733405, 0.08128232713187895, 0.09381246888228963, 0.08760769295716479, 0.11114359172361513, 0.1344558157988133, 0.3815655350204437, 0.23669052508569535, 0.16472488431440246, 0.2942031663992713, 0.14334163898902555, 0.18317010584137133, 0.14572584250521275, 0.1606282751045881, 0.11236423025688819, 0.10669286603168135, 0.14110317603955347, 0.1603967020468366, 0.18376914063288322, 0.12298446118591294, 0.11991212685262004, 0.2528429680293606, 0.28225152062312253, 0.09280867919686342, 0.09574176172815985, 0.15629799375610967, 0.12242261996312488, 0.15581869850716284, 0.08132653806598918, 0.11799373543791233, 0.15881678359883447, 0.14717364142979347, 0.15691426552591786, 0.2539158128802815, 0.20589924507564117, 0.11654035939324288, 0.13723254744564334, 0.15236560315374406, 0.1500558787055554, 0.181552633763321, 0.14334177688485192, 0.12205557957772287, 0.09726615412341011, 0.15548238590840371, 0.2050730958580971, 0.10042710950778377, 0.19325151648973266, 0.2832342275688725, 0.13092019745419103, 0.09685026031107673, 0.12434842710893963, 0.16415391898443624, 0.09248286200266692, 0.1882890747078965, 0.13373495770558236, 0.1937701120491951, 0.10692706677101313, 0.20522570057261377, 0.17256470637456064, 0.14563853912536176, 0.23643858941091647, 0.15098042425609406, 0.1102021539343461, 0.25741982243714795, 0.18588524401908924, 0.1204732173092423, 0.08885592597747043, 0.159056844910787, 0.127442357460818, 0.2097513343417837, 0.1334226236588532, 0.09196731547314314, 0.142626756381604, 0.1917205357383336, 0.2168775301787161, 0.18479663307868666, 0.1446634470935791, 0.09481217531907944, 0.11194220008028131, 0.09658003045666604, 0.1228023314427945, 0.13626847175821183, 0.13243247033847919, 0.13914166919646725, 0.13678348202618862, 0.10642821329735941, 0.15637391306940587, 0.10199159894499088, 0.10739136201840256, 0.2081261554192151, 0.11075386747477517, 0.17013778579571556, 0.1544477382013875, 0.07429156031820082, 0.26669825036679545, 0.1507551944063556, 0.12915280196935902, 0.12332026816664204, 0.08981787960135168, 0.09619641958946183, 0.14156770111332018, 0.0843240102873214, 0.19347264010819698, 0.11670087013513812, 0.19194181257438278, 0.16360107929475848, 0.058095354601861014, 0.18543035633140997, 0.16438869428971123, 0.23156574927270415, 0.211423673636971, 0.141058421183017, 0.14817490302506955], [0.06833241516423803, 0.032026485705207434, 0.055494489929368424, 0.06007413289720013, 0.015234618857052299, 0.0331457746365378, 0.055586784372046116, 0.08410618850781072, 0.0782495382572374, 0.04064986249431968, 0.08341140804752227, 0.07453033460244056, 0.09243636812654235, 0.03237857588476712, 0.0674499125189839, 0.07130236184645085, 0.05125121701689017, 0.051228062009378794, 0.04161278904986478, 0.02811390996700333, 0.040645174036223086, 0.02924047673361436, 0.027777003650102886, 0.04156374410095234, 0.04046369546784028, 0.020345749686502164, 0.04479688411999134, 0.060571530803797714, 0.06495219009417681, 0.05873918255430557, 0.07151517341093672, 0.022063973817914244, 0.029164867685927503, 0.07157279088372184, 0.049598129511240034, 0.06104495398880494, 0.0764702607486998, 0.04403350431652319, 0.047061106775917357, 0.024131815580110398, 0.08090825405933204, 0.05243551616947498, 0.03434026275851554, 0.034915679059321844, 0.05908769893369848, 0.03738881772263877, 0.08022596083220937, 0.04046879378297637, 0.07751583286951627, 0.04758326847466731, 0.028989849153966196, 0.021317700757795287, 0.02540148757097702, 0.0294240735351078, 0.026029754362459627, 0.07526911149222044, 0.03531606725206779, 0.09191126081972353, 0.024119031487873966, 0.07905512567489378, 0.026531806253197215, 0.06736981036562113, 0.017291692295862783, 0.05397300483779081, 0.015416364598598693, 0.031947519277192415, 0.01716188827319251, 0.011586108838298149, 0.03629396316565333, 0.030078963797178962, 0.05588618302417379, 0.061025782638499816, 0.03693292262933908, 0.028388008565431642, 0.022432278248391325, 0.017271819975106947, 0.03640669683415083, 0.058660244854587706, 0.06203151818725371, 0.03849429791913398, 0.013254410850124495, 0.024297849815939705, 0.09120573980673667, 0.07577648386359215, 0.04075070647823234, 0.09041835463816121, 0.03168284356023275, 0.05506586756617312, 0.033540413339412024, 0.05678602990003363, 0.043167656422742916, 0.03306299117544005, 0.0349542745689471, 0.021760321462587006, 0.05886786617338658, 0.037428661955580596, 0.07876081001614371, 0.0315255695398176, 0.03728936418830868, 0.07418361086879047, 0.022600258347548308, 0.030818317168121858, 0.004508848782748946, 0.03179699449139017, 0.03748827125696886, 0.02881562352300652, 0.043271913328358245, 0.03875025172507571, 0.09522370243024442, 0.04149230640201319, 0.018287832593365062, 0.032422181609417164, 0.020317375705006625, 0.007184969144873322, 0.06015233132207106, 0.039789289115898074, 0.03668718077542801, 0.027873660963509354, 0.014212433485344294, 0.046206007095714735, 0.0325362827448595, 0.08309139013891259, 0.031768212568074945, 0.04218462388962508, 0.019114993046969175, 0.04089581502240993, 0.012963422885795516, 0.06315030533099367, 0.05710216374286721, 0.025365988971785675, 0.0302906951776916, 0.03467746401926683, 0.01120214269781906, 0.06290974606189036, 0.04199437744494888, 0.03388642461129254, 0.02024290238266751, 0.055813113557955915, 0.02118344193384532, 0.05499734483178585, 0.030003381562569452, 0.023268026547626625, 0.026202834691972505, 0.0759985421093241, 0.10024731633283439, 0.025096898673162348, 0.033351484565965595, 0.03859621825658026, 0.035260851464925275, 0.04204152249580911, 0.049430283477469805, 0.029574286140080903, 0.033925541060706305, 0.039507250016134594, 0.03186540039736898, 0.07624590423919501, 0.0470558169388002, 0.06749007850885391, 0.06813958317281739, 0.025683591788214062, 0.013552192099122031, 0.013203701575196559, 0.011835814239607464, 0.031491472881527684, 0.0430104973155164, 0.027217460691087672, 0.027856366528618722, 0.03709283965309301, 0.024841157456619606, 0.03197897867780299, 0.03538016582869234, 0.09525185616146173, 0.059020179774492025, 0.032689063659598755, 0.009649415583079381, 0.01932439168975238, 0.08587105590249262, 0.02442996167848187, 0.04097411303871101, 0.05936948139400733, 0.02718664288911368, 0.020664702732897094, 0.06008355577866878, 0.04613469197084347, 0.02589578473670108, 0.08172219949624232, 0.035370877012610435, 0.0637441077419827, 0.036780796719775084, 0.04929514556762673, 0.03237606311637548, 0.052694369618210106, 0.006158087175384525, 0.03988883075033946, 0.06884764759771286, 0.03418951580721525, 0.03320409307977365, 0.026051984318802436, 0.0208985491565639, 0.02689940971322358, 0.0684954003701287, 0.027300238406525987, 0.043871978508128275, 0.017600397001050653, 0.07265253818684048, 0.02956733963782749, 0.09065368152674168, 0.09134411826849946, 0.009501604663748896, 0.04169883221508034, 0.07699487775924706, 0.04198733326648513, 0.018101634923368692, 0.08024899709609248, 0.006281722753849482, 0.0838643575327531, 0.03405651145224129, 0.05472143443541662, 0.027028179517196074, 0.04338747003085671, 0.018633221418807105, 0.05005156546230278, 0.07046823765361501, 0.06243580959797387, 0.0520626496854088, 0.031070271995098844, 0.0227085716887227, 0.09313399843390911, 0.05337223485713044, 0.011250075861631383, 0.024888559146934462, 0.020436902658172676, 0.037617123415393215, 0.1037355674610984, 0.06719308154236886, 0.022698120334215706, 0.030624221131626158, 0.012683208990511636, 0.007794671710730801, 0.042970722030487754, 0.0388860714531714, 0.018510340915752516, 0.017619857549547188, 0.022072902572671735, 0.02482641792495645, 0.0634414647074957, 0.04693674772316891, 0.04359407245271629, 0.08563039704195916, 0.04743755855146916, 0.06305090159237867, 0.034113902929088766, 0.00621964042488065, 0.08501231730464967, 0.026170113161506674, 0.06621924589478201, 0.04267471331742503, 0.0035198534521529634, 0.03734471021039832, 0.031448001222264384, 0.018710812718998042, 0.02587294765567828, 0.03901383193630365, 0.03268740890968231, 0.059624584842353105, 0.03453848800892311, 0.016673706404324022, 0.014754295135067116, 0.0738209831498323, 0.11739522158618897, 0.058534326812913345, 0.029996938763126254, 0.06787344422792235, 0.07073954769199894, 0.022302757678253037, 0.013054369013726473, 0.04692701457609092, 0.0937367410909745, 0.007619099680244202, 0.050286455680766416, 0.02666076566393097, 0.035442280237593, 0.0490107890518923, 0.018489093467172597, 0.006165814608515751, 0.05422948724440029, 0.018731361112347054, 0.0148815059501137, 0.009772712646442796, 0.014820442039279208, 0.058646715741844914, 0.03155651374629909, 0.030646715388302843, 0.0377151252131068, 0.0919841847292358, 0.011065474527347232, 0.017886153542466702, 0.004479570817502757, 0.030594853151048866, 0.03434513124727434, 0.08101708450985533, 0.10826396680767499, 0.023252383032212817, 0.012946354446842546, 0.048837630198367184, 0.05314698968563349, 0.07286320470513837, 0.04215270100582031, 0.04923206588794147, 0.0727938584262325, 0.12376009456572995, 0.028773415908818285, 0.06801845701110941, 0.035029381829043554, 0.028077124340099194, 0.08642014942222065, 0.05691206285489663, 0.04805183849267421, 0.0385166906691607, 0.046123020621317054, 0.07845541672600854, 0.05934423879690229, 0.06836347236868835, 0.04876518892424722, 0.01808750443160534, 0.0411368684182244, 0.029890881550888863, 0.009430931137514212, 0.024212268218698523, 0.03624268507044162, 0.13814649033930995, 0.01991901573004021, 0.02589835687690685, 0.052938927866278164, 0.10606333327990387, 0.029674429153542847, 0.013996650457322119, 0.01959312767271073, 0.02219593246287156, 0.007178268748365584, 0.04201042315652294, 0.04733410220773471, 0.05632564170105804, 0.018537605984977657, 0.01799124931435912, 0.01650222336813327, 0.023355772343253898, 0.05824598663997266, 0.03317988470136639, 0.003832194680956403, 0.04621133906766773, 0.028908892812567855, 0.2034769823113757, 0.09707967300088176, 0.1663120346324098, 0.1354778230550789, 0.10800498312399273, 0.2339270161164384, 0.12840343774446558, 0.20564429101444062, 0.19255489741842594, 0.22276873099467448, 0.12183551316059406, 0.15397060332038712, 0.2269568723896819, 0.206330077602498, 0.21591529310230287, 0.15403394346996663, 0.14667050552464303, 0.09602207329965408, 0.14456892716548136, 0.21322013449765023, 0.172089456069854, 0.08262392328751665, 0.08794386766009754, 0.12652551109391835, 0.1582377743456633, 0.20252612930151725, 0.17032115660127134, 0.17392342459530602, 0.17889004921720875, 0.14345577076798485, 0.1396433188910446, 0.22072669298898792, 0.14095904425747935, 0.1733360496620017, 0.14065584197880762, 0.09748021441121256, 0.2205139656941737, 0.15489816725734742, 0.09505702468055872, 0.13621737369366232, 0.2416590496056503, 0.1216688430717876, 0.13893430451712302, 0.16007257024607352, 0.10403306238473424, 0.12248256634319983, 0.1338514950006239, 0.18748308892451948, 0.13251007504520879, 0.08334564706010204, 0.11798234371047829, 0.15201323335209202, 0.2127970241370701, 0.11012878569383776, 0.06745244060913402, 0.18498884453888864, 0.14162091358054069, 0.15504435215505863, 0.1438769352652373, 0.1884703004672643, 0.12036859268142332, 0.23581733806960045, 0.08925489690755645, 0.11890859763708808, 0.16907117690049833, 0.1259312413692955, 0.10130251051797982, 0.14146279303296921, 0.24729699707560002, 0.10452150472349699, 0.15147341715712703, 0.24372141958484728, 0.09691438953121824, 0.12887817477026295, 0.15046051102540187, 0.15632845341197907, 0.11928044139377533, 0.21356361767938062, 0.15184734467296832, 0.13896235865691017, 0.14219858984072364, 0.0935430204375617, 0.14034419741121032, 0.14733845758582317, 0.1440661283390176, 0.15171292688577406, 0.08282327468717292, 0.15573007745608208, 0.15676023588786203, 0.14746935136856573, 0.17255523752781654, 0.14825572530108114, 0.16311078302321896, 0.1702607122640456, 0.12296713993794496, 0.17338302617351856, 0.23454819084896197, 0.09282335744149263, 0.19855998486520784, 0.12729335335954545, 0.15282887184331495, 0.11245207755916542, 0.09294654437971693, 0.14762117467339964, 0.2596494140884569, 0.10766465622451037, 0.2091040819763176, 0.0963816519886736, 0.17929780717578628, 0.19250179220351482, 0.15480292720660088, 0.16007086953088162, 0.11864580649642215, 0.11054258808613786, 0.19237508126083883, 0.16945337816592188, 0.1257160779148821, 0.17736453833358903, 0.14110993293504562, 0.08969284639122987, 0.11121273881966069, 0.10814892338408578, 0.10030448947462345, 0.15503871374793593, 0.17431518663802456, 0.2231636033543656, 0.1589218602185288, 0.13706889574325856, 0.18186691367337782, 0.11976889139341733, 0.1930302396536835, 0.1268453757849432, 0.07070437659539523, 0.2717790374111745, 0.1747144103771256, 0.11402038211423544, 0.20625009802320313, 0.10901718445482755, 0.11067060903916437, 0.38755389110695937, 0.2335946105660931, 0.1588796794174179, 0.10599518975903911, 0.12157629198965528, 0.23573077013415678, 0.1207885850641516, 0.12782223747983096, 0.22208159609187036, 0.2149974891254979, 0.11399130141662975, 0.17380112631907388, 0.10377899698552587, 0.1175644274260248, 0.1148239087553755, 0.2667554005259468, 0.2262057078581664, 0.14844804401359252, 0.21971887368107998, 0.1876961379762619, 0.19303163393370568, 0.08147417086987727, 0.08285611687648682, 0.07841725788650014, 0.09600213203098505, 0.09226758363506488, 0.07228782670872827, 0.1742314532279007, 0.1628482906568435, 0.11872567116252838, 0.23972067861787735, 0.17409947160030567, 0.15454699255285725, 0.10747617561249964, 0.07111997929431739, 0.09487265029982214, 0.06159420072611782]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0184487895814762, 0.05748895004451756, 0.02080322675136549, 0.04108046902523887, 0.026424190052033916, 0.038419546889922315, 0.013252120247230896, 0.018628845141539653, 0.07477218856013591, 0.03560875114353915, 0.04628933447923872, 0.07441644797161703, 0.0386241996180146, 0.011734790225032599, 0.052168794997757485, 0.08367121144528351, 0.022427300592103315, 0.05829037377430547, 0.030931504743714488, 0.06639314785359368, 0.059108988517114235, 0.020169149182977218, 0.012129015240427709, 0.06619420248053728, 0.03735039458279649, 0.05449463027499376, 0.028320679012986443, 0.011893648132231208, 0.017968843157793728, 0.054401585066150275, 0.04732357999009471, 0.0675742639108531, 0.04987314741517748, 0.024824403113715594, 0.029802402226074092, 0.04178841087606646, 0.019899564757642728, 0.05975054118842368, 0.05816762350619801, 0.029938051499606624, 0.024724055171733903, 0.06036600090503212, 0.03051212906176525, 0.016011218465263807, 0.02174673106281027, 0.04183721450728275, 0.10779839219345201, 0.03960824721763211, 0.02904684226509304, 0.04427410955090196, 0.02968951342477193, 0.0687691925333873, 0.060687267536958384, 0.05976535349843964, 0.028091400388568163, 0.04935919051809658, 0.12514319736510515, 0.022045698790480534, 0.020613208217846773, 0.055225424528602636, 0.013151271475268709, 0.03176337472283312, 0.013513917388815074, 0.07227930015013104, 0.07421014815448754, 0.021302231527384252, 0.0421571021809453, 0.025059747239274364, 0.07960791173841684, 0.04634633908168443, 0.10310767413747889, 0.03438741163981538, 0.049186924157003244, 0.050177958478490194, 0.031138591716186177, 0.09874816653468917, 0.024413383535800443, 0.00719534389058789, 0.012570228258658563, 0.031309988567485444, 0.0555050810949216, 0.04285572840261363, 0.04587800272049443, 0.06466912060615516, 0.03825029508481103, 0.034158267080783844, 0.020010839028644468, 0.017443366213551453, 0.03389548743143678, 0.018758149291839332, 0.06474458792757604, 0.059182697666748885, 0.01896447017638674, 0.0577703915957001, 0.03691961185165471, 0.02018005827501897, 0.022914714457827712, 0.06139469227843708, 0.12462519935422367, 0.04997227919257937, 0.024901892907256563, 0.03435130591594404, 0.034482264816160166, 0.04038076645003692, 0.03005494502553296, 0.04341307268928617, 0.018502151435841958, 0.05503612037207331, 0.046147071951699835, 0.05570898688728771, 0.017973838051060037, 0.07207914435815427, 0.07185455802227221, 0.03663836948333248, 0.13044615756840477, 0.042679083849033045, 0.02573075599127239, 0.024538786383345727, 0.010484760728544526, 0.03093874044415932, 0.04874501782920092, 0.03630890954105604, 0.013843844644725324, 0.01706229492781624, 0.04718737721803689, 0.02223202286498441, 0.014471578047490649, 0.039904443622236295, 0.06217139052046884, 0.020153476939266248, 0.031475296935006496, 0.012673777490553838, 0.03217298852940721, 0.04934085803406854, 0.04281106164618846, 0.05312170878413224, 0.06297787426099663, 0.08910529525770296, 0.028804013460514047, 0.02143778120948663, 0.015553975057217385, 0.04520178074017168, 0.016705192618011948, 0.04115339293475113, 0.039205894009360386, 0.09439195310997386, 0.03530559483014288, 0.049436190015366005, 0.04371245601965536, 0.002260329492855817, 0.019996302510281245, 0.02468986658289308, 0.06400821655387841, 0.05819711023040357, 0.01951242797076702, 0.050602807858658415, 0.019797699961570964, 0.07547392509877682, 0.006201970128102169, 0.03412910211350649, 0.013651128524103233, 0.037506201544836644, 0.013639860328346973, 0.0789882461991041, 0.049370141744974165, 0.032640842255204916, 0.05979953634162104, 0.05019461706040367, 0.011858477993237396, 0.018323723812617602, 0.03415820962418953, 0.04170730514752288, 0.018957123393192887, 0.008139869014191772, 0.039422984174903364, 0.08870518285660975, 0.008926946789987626, 0.027895490638911728, 0.045523438076939315, 0.12044045938960007, 0.07465328405340833, 0.03166505691385077, 0.014313901830915243, 0.008233932162364645, 0.008699074894520304, 0.05885122291323158, 0.13306490656348968, 0.04739497172375841, 0.019416071346870834, 0.03318279966591828, 0.005752100316326945, 0.047908212328630115, 0.01550967698060577, 0.04406653802781817, 0.0435348155517732, 0.04546286733520608, 0.0077198756738535825, 0.0304388489213682, 0.03487161751235685, 0.009036155496423524, 0.03937660904240705, 0.0404619449569333, 0.040541621931498094, 0.02063940076397792, 0.017027211931323814, 0.05015297635127941, 0.02446661323999926, 0.03942651967067392, 0.04897166111115967, 0.04900689349479733, 0.0456172532041467, 0.01855512450058614, 0.03551444572006022, 0.05991746408624515, 0.016227511899365533, 0.060491532072304725, 0.0647372258226237, 0.03495859147440042, 0.0200287961295896, 0.055285972287698146, 0.03941826890372942, 0.01676233128584441, 0.07362591418167276, 0.024302702982940023, 0.02423755678107902, 0.05190043056744242, 0.05312464290088224, 0.022931219822156335, 0.13730791517563407, 0.03920682480618839, 0.0600323198182929, 0.026016960694124142, 0.021651611670911796, 0.03826373609744253, 0.0366650753083729, 0.05443466857316033, 0.06011928994989684, 0.022061349966773586, 0.024208447355176174, 0.07000483106821775, 0.039678892015569636, 0.04585323892834206, 0.023450757669765624, 0.018592327645409013, 0.03768103430047631, 0.05243134099028764, 0.08897804039260072, 0.020921018515383045, 0.031465182659186186, 0.05497629656606624, 0.049577782215971145, 0.0455715062637483, 0.020568688933347023, 0.06919996377321021, 0.0860546948388219, 0.012964668736282377, 0.017003911367106824, 0.0576344263108988, 0.08678326743745035, 0.06567946800421323, 0.04937095762861352, 0.06305891487206663, 0.031107095926399195, 0.061980615475124894, 0.02427595310784396, 0.010015383445387407, 0.025674099958832228, 0.08691025417177908, 0.015987476442880448, 0.016014177479871338, 0.01615186646250227, 0.057525898465105606, 0.07553396340940269, 0.07179039815861372, 0.1505613894832711, 0.02687562459839448, 0.0711024971678853, 0.029208017588262598, 0.025177943114671978, 0.039437880754591, 0.013611408780449101, 0.07669663973032467, 0.05379184419589658, 0.03429004569507895, 0.05596707041765894, 0.02727658735708364, 0.008377743145120482, 0.051933265095877076, 0.06101497696832784, 0.005722087864283352, 0.06515613802137875, 0.03928887282287882, 0.09959771207744077, 0.06767107444184442, 0.03636787149814829, 0.02810494482306944, 0.033191023619785424, 0.05777728638701862, 0.02856155429335852, 0.0450882273575952, 0.04053268551586136, 0.038730766278721636, 0.03752911140421226, 0.06654621988174415, 0.09126239200873722, 0.04566403819368251, 0.011879099164939216, 0.027709587912766204, 0.02776651973685911, 0.009280483918114295, 0.005923703532560819, 0.04795862091404777, 0.07074386076701265, 0.03807661912193702, 0.03182128330902948, 0.06276476392222029, 0.026446889237230344, 0.025213612168426477, 0.033981599544565526, 0.02963605580941564, 0.01804068496811294, 0.055694890869480956, 0.03725645305108159, 0.006162152229432738, 0.01660901985521759, 0.03906207249289559, 0.010303456445164498, 0.06646159780962814, 0.03085710419972818, 0.0738468999043107, 0.030880829942743146, 0.031791019005580776, 0.011131819656809733, 0.045412868606827916, 0.021676459732735832, 0.00983860195359035, 0.030786016986014384, 0.016520431362873605, 0.0645809975122252, 0.04494937392131937, 0.051798418299445224, 0.00818503755820735, 0.059806592011403654, 0.04575947359684975, 0.024948909638389468, 0.05992425928613352, 0.028842811983439232, 0.07298306682177129, 0.04448610523174848, 0.032845629048683954, 0.019649245528384082, 0.015146823265709946, 0.12258856992928252, 0.1510600054696683, 0.25006341717896924, 0.2292425723205651, 0.1209657122531245, 0.11574486135354928, 0.2645293941661235, 0.12798336875294486, 0.09367583710099421, 0.12697063116056304, 0.23219182696794313, 0.22436832258057213, 0.157748336092599, 0.07649142009716842, 0.14088511677278628, 0.14792043926014056, 0.1477074514954321, 0.13470451858255172, 0.14057596965182212, 0.15206453059950184, 0.10403729885095551, 0.15427808036967633, 0.14241882479719578, 0.13512099462170757, 0.11550344406597077, 0.13771112257194135, 0.11038829797818778, 0.11186812703888263, 0.16676430229938802, 0.2537368394194111, 0.15529595075115082, 0.12205563320387756, 0.16978736185739118, 0.15415212019316613, 0.09661263515872341, 0.10410276106408528, 0.1320295693773416, 0.2836288547804279, 0.18278519262469586, 0.20695103783040278, 0.1546551335242487, 0.12450489290659467, 0.13676002441394713, 0.1932803213956856, 0.1647435921815134, 0.15162127212651316, 0.211831477560824, 0.1403772311225053, 0.12561739046847628, 0.1641245778169363, 0.13649725625591894, 0.17990461009885036, 0.16996765298949135, 0.13417257777144834, 0.12551019178523173, 0.10441614465127069, 0.17874309823157328, 0.13932284899055958, 0.09015705736894762, 0.32951108630626436, 0.13918179688194107, 0.1611212220403456, 0.14449409569703764, 0.11335354854142475, 0.21444884759764518, 0.17817685200322061, 0.12624658614156709, 0.07824799075963036, 0.1379943912428233, 0.12177342939521037, 0.20947747323061192, 0.17177306175712617, 0.18325000881187378, 0.14661044423137942, 0.0879631883975479, 0.19403301810304965, 0.0967644737853158, 0.14225512712953553, 0.19597817662983172, 0.13486346650508144, 0.19977415761639997, 0.1245140246746521, 0.13847132694096337, 0.1704071269881341, 0.14194498409426984, 0.16820892961996217, 0.1343254123123423, 0.13534152069159094, 0.1522088309209193, 0.08922796125613874, 0.14261465219240035, 0.09186920259268054, 0.09550920041698603, 0.1520924621652211, 0.10243746977780135, 0.09568539297869129, 0.12938287349477892, 0.14369794648260842, 0.23264735816947876, 0.2000024058525601, 0.15745855567436065, 0.21858858755759655, 0.07509903231215093, 0.09481707828179484, 0.08633148240586443, 0.11317932482568488, 0.15065848346679442, 0.15575116019575827, 0.15409325399706442, 0.11821108224290995, 0.13092713821078503, 0.23407006005366005, 0.3455494740797628, 0.12744526859493027, 0.20907740679479417, 0.14288256846127972, 0.22287641231331135, 0.23037036099741537, 0.07286652952672974, 0.09331065830924819, 0.09193135530597742, 0.215258234811406, 0.1354501672810124, 0.17001032408687378, 0.20307752874589738, 0.1399498613130662, 0.18043480422948638, 0.1612169523873637, 0.1843894573469316, 0.19835402978764427, 0.09986228054209102, 0.12340110576441213, 0.1253649874800636, 0.18384627036509976, 0.12595730368047953, 0.17714465577756205, 0.1973123953587586, 0.21387501709884216, 0.1248979036726298, 0.15949942922640234, 0.14629973429104975, 0.1287259530997084, 0.14311530597267613, 0.1302217857371415, 0.12531228829175234, 0.19229390658438208, 0.3177923925461308, 0.08583415344718003, 0.16157454690865933, 0.11453235867403208, 0.08798954182214315, 0.17139764803071178, 0.10716727363967127, 0.18800775190034222, 0.13658010100405063, 0.09850579929808456, 0.0902797769935381, 0.13510450840957705, 0.10145365966544037, 0.10577456409772558, 0.1639654000680293, 0.11040434752020145, 0.1285241961839699, 0.19231224672928934, 0.12487780152549668, 0.14185012708748543, 0.18018519746199732, 0.1341540844089562, 0.13134839463858836, 0.20397722240417235, 0.1718116879102684, 0.16879848024297148, 0.12629226030361268, 0.17111747435504393, 0.08752548406201024, 0.16819929223387473], [0.021863892719510104, 0.020541437270660556, 0.04432303192574651, 0.02400096584742348, 0.02269950120769922, 0.04862547746949619, 0.05075077391079357, 0.06333324712731185, 0.05365662584682146, 0.04166160034196031, 0.01154080048323639, 0.06379233297681616, 0.019672693564526497, 0.01016639565463148, 0.07956943880285948, 0.034957993925819476, 0.040531436792544784, 0.026703015412955035, 0.013591223321254215, 0.020318164775568633, 0.0649406451491579, 0.025974548151416164, 0.030888264826048287, 0.04712022195059446, 0.10987888015205823, 0.09004079586555881, 0.020637742183621854, 0.016727141037042585, 0.07652596300167423, 0.026858537007243406, 0.056669519418069435, 0.10733119347282957, 0.05313315413772099, 0.07488180042034195, 0.09607229036309066, 0.05741801030272919, 0.007958600162378242, 0.06705291809574251, 0.014555292305416398, 0.03533242322925118, 0.05891942772113028, 0.029127865639184753, 0.04377205766016438, 0.04978231620043517, 0.024926614564573093, 0.12188989008145949, 0.06928505315896004, 0.01826266085939302, 0.08575515446042822, 0.04281571563032847, 0.018663087356535178, 0.0842171486827635, 0.054957163520157344, 0.041579563816588734, 0.021669856054828535, 0.04838733137735436, 0.04864850990293969, 0.006381311311176228, 0.006624516935252975, 0.05351068226680641, 0.011476205864680872, 0.06320156427400728, 0.04810580555650015, 0.02536143840951545, 0.016649398434486602, 0.01997785319784476, 0.04067886658313294, 0.023446145820461457, 0.00719300828002874, 0.0786727175657307, 0.009042886536448233, 0.01666239894656164, 0.030778423139464953, 0.033139726372375604, 0.046555140175886696, 0.01594320039129666, 0.0530139776697803, 0.014659156590970534, 0.04705223547775419, 0.0041554912064795295, 0.05078064367896126, 0.046065066069845235, 0.09945816916203308, 0.017459643666722605, 0.023758596695599057, 0.037754915819893924, 0.034068021923303604, 0.06676465453159425, 0.05330633597388383, 0.0539741846131942, 0.04171622624140113, 0.09588103651279405, 0.016655825912171317, 0.04832166232048504, 0.04637649230238411, 0.0343087037664748, 0.010455295071756888, 0.05944289943023075, 0.046121312245245905, 0.04509696842081124, 0.050201527173480684, 0.031858049783735506, 0.016806540304734822, 0.020765201977243828, 0.02950672867647823, 0.06054279101531833, 0.03977249263815823, 0.005974441056980962, 0.018620722694322467, 0.018529707618478327, 0.038821662610937516, 0.026717082702464638, 0.03648717437059649, 0.045593630883001515, 0.03928122343495488, 0.02518310846250144, 0.028817770484414314, 0.009055218636809338, 0.026460987170256918, 0.05695979779345855, 0.044307874876164624, 0.03322662372562674, 0.044160881755693306, 0.0469780896580027, 0.07345273234550992, 0.06516277234280302, 0.02382145037934665, 0.03225809706735515, 0.08805963886721481, 0.019751026054784175, 0.042973426320860465, 0.05312650832497785, 0.03982610347109937, 0.08587093332842474, 0.05637349921368784, 0.030316562136454932, 0.03081405197360343, 0.021784052951261405, 0.06704477458110741, 0.01228091323883423, 0.018701073826260625, 0.09044071674467095, 0.022332606379002817, 0.08012226317077875, 0.018047688926960674, 0.05064272103951343, 0.032952885188522844, 0.05395895095481988, 0.03216697856964123, 0.023717471180603873, 0.017487050462213737, 0.00354753723630922, 0.03062059179008488, 0.015898958813669463, 0.01932930997422626, 0.017875487683340907, 0.029271721629606142, 0.07377239019279519, 0.04117116617459444, 0.05429034526910513, 0.03155744262790728, 0.06485543318934019, 0.03696153601331096, 0.07648551355927222, 0.05924567392456436, 0.06889896782776041, 0.006043231922141727, 0.06186402455392865, 0.07664672144117855, 0.0681782782738728, 0.06240789335401309, 0.03696307201959914, 0.02613625399047329, 0.062151112173113136, 0.047218039887206215, 0.05716071967335959, 0.05761301032297554, 0.060986800254472805, 0.031870954534820015, 0.05205436827494733, 0.05112300837232221, 0.028865509253415852, 0.037123333782918995, 0.05269519316272871, 0.03427265166875816, 0.017061381367966533, 0.04018713006629579, 0.02445016916270458, 0.007450557942877734, 0.04561710764744109, 0.03825784871174443, 0.025125582920267217, 0.07145803857354388, 0.075509142160656, 0.012298277579247953, 0.07862993921603888, 0.007898764386247363, 0.03442987972389787, 0.06269095135071585, 0.04793047484370971, 0.02095779265096832, 0.049441027860607833, 0.043497304056560805, 0.014949333459709682, 0.04626228391463238, 0.050645379364610686, 0.034729565658997145, 0.07365256638055848, 0.03948312973783862, 0.036794387119551825, 0.03676041878098923, 0.09470846999676959, 0.03885493380948901, 0.00920539485260604, 0.09225148812777574, 0.06313727034496204, 0.0756327581081179, 0.02037362571084692, 0.006078866980744587, 0.02230216779055134, 0.041915328662482, 0.08473219725513652, 0.07254075063692947, 0.037130086847971526, 0.00992699126307402, 0.06692241501784132, 0.11560747114520882, 0.030838620413335103, 0.05197811571340408, 0.05921055645411534, 0.008851990832256214, 0.06848695808120313, 0.07030468554266038, 0.04058375676733352, 0.02096855235586484, 0.08914729985859125, 0.045400691639271476, 0.04949547755982607, 0.05401872879555149, 0.006323001486429524, 0.024821804160432472, 0.03430248313252965, 0.03249540812365952, 0.01938279248744009, 0.045627928639371554, 0.09029920498329787, 0.03312194547165306, 0.06002143370888888, 0.04827127671770511, 0.03686725740290938, 0.03599074939566274, 0.03811038827763931, 0.04797823659534897, 0.04015627587514539, 0.034170271678557324, 0.07365225994538876, 0.00655360879459148, 0.08277282779735905, 0.022989913648475083, 0.04848901805798373, 0.04430332814433402, 0.05208337619420021, 0.039906029424239556, 0.023490603817927263, 0.04628581430522665, 0.0556889575185074, 0.08578665599587464, 0.045478315498199195, 0.026822890936126633, 0.04179593002904327, 0.028068994232002768, 0.04387112432009271, 0.024614445226747664, 0.0406512261308249, 0.05027632799840743, 0.024126600436565858, 0.04554301162340468, 0.027093762389173912, 0.04344050246741503, 0.11619060961229187, 0.016802692628135125, 0.0030193088394063978, 0.12751268433226695, 0.038135921988155574, 0.06571683011228038, 0.057175558796452905, 0.05589650988939309, 0.03575887373318115, 0.053665167727177186, 0.06973443267446372, 0.06576088016792651, 0.03683499360997831, 0.019943858046204816, 0.023134767468417847, 0.017712734219047333, 0.040501061406347065, 0.055048209239518454, 0.03437235418166365, 0.004202246988913225, 0.04476034555644278, 0.07816435694093667, 0.08372247038829712, 0.027818707561480905, 0.035864900301901564, 0.06174040094558751, 0.07843111641705036, 0.04129847466585137, 0.06522684793678984, 0.06889254801095494, 0.06805276242835868, 0.02555351197389105, 0.006596335912153366, 0.0284018536894432, 0.03426792490626535, 0.009622322883637202, 0.011492784964972207, 0.04851916361780417, 0.027635888339230613, 0.042761664296830856, 0.03862799558367941, 0.05409045377746225, 0.019334119091170932, 0.026569785062043418, 0.08479373709809396, 0.05882492311479104, 0.038546514472052935, 0.028033723543968894, 0.025767047491465366, 0.029180392457713044, 0.02818568282940936, 0.04640152039487035, 0.09432298987503014, 0.08101559829928222, 0.022746611784602848, 0.03066749360802914, 0.06398107788916077, 0.007075384097744621, 0.010588868247014622, 0.010024065136789315, 0.02248885767203906, 0.04160636540261969, 0.025841718081444986, 0.04592329383857789, 0.045196556020528085, 0.03641952114600328, 0.006259288347791881, 0.03446985802222644, 0.05004529886308217, 0.03539372175451248, 0.04103675604827943, 0.052470614487725886, 0.04186051507149974, 0.21690708585083487, 0.18696601021914713, 0.15678600708563484, 0.134296438867046, 0.22166168797881375, 0.1595939185109831, 0.18445924795683355, 0.12472337352172022, 0.19327454509273653, 0.18011493187758232, 0.1395844373731844, 0.09605185113727085, 0.1779104525884313, 0.13656644931723996, 0.14956435669333706, 0.14390080656495788, 0.1356195799645878, 0.22036729050019097, 0.12644463519175209, 0.1370766179095353, 0.11304715933698802, 0.16703971090816683, 0.1134674045287313, 0.100183853609187, 0.1839815614925277, 0.17111286250573976, 0.09267613832508365, 0.0695391338799269, 0.1359207444493809, 0.16644061482962103, 0.07965020745271638, 0.24361994357839709, 0.16039740684772694, 0.17632204588622818, 0.1396276600538723, 0.22199804654284833, 0.16067422505828644, 0.14572906007449474, 0.13936719015961693, 0.20264433666823373, 0.14240224665451434, 0.13778462104739683, 0.13756996321101345, 0.10394693111940738, 0.14370395261193478, 0.21728026260051037, 0.23489826238684117, 0.09060453698639909, 0.20929843848270757, 0.14315540301463298, 0.125281797992366, 0.182854768729979, 0.08908263437690274, 0.1262284758230371, 0.16983159577413914, 0.11451427899901906, 0.17012762746983962, 0.1551833358262816, 0.12594294719277851, 0.21382568103651847, 0.11295068588468338, 0.15434256965114226, 0.14595177715584157, 0.1399696263815126, 0.09290142180097681, 0.11875009404555445, 0.12034151147330001, 0.1046382335405196, 0.14396612322138203, 0.2041746739057764, 0.11210952134382342, 0.12553102937677216, 0.17890602981130924, 0.1371201623471514, 0.15381084334465767, 0.08577321115280352, 0.12792069509985948, 0.10462448226227876, 0.06573854870493374, 0.21754333719370827, 0.16406137556318315, 0.1763045484380376, 0.2558281522003874, 0.2122182753537932, 0.11201699324432882, 0.15710345859969818, 0.14649672613989922, 0.10164566428190279, 0.20276029173645282, 0.18521114793275634, 0.13768075484662287, 0.15375259001889538, 0.13541218464172658, 0.10267629768819579, 0.1027610959605344, 0.1526106593589629, 0.17548226030363193, 0.10191155041778281, 0.18425681688372167, 0.14178122513957564, 0.12490449968965785, 0.11430748122473879, 0.17004528833973795, 0.1937458270619954, 0.13241664296196354, 0.10636734761177533, 0.2311572711914778, 0.07057743582634196, 0.12815435957764426, 0.14840797761515265, 0.10608653808313032, 0.15683984774495327, 0.11523279286320172, 0.19371106199199156, 0.14407155224152152, 0.16910866924351262, 0.16633259643229747, 0.09150120459737317, 0.13505371678019726, 0.2196273874611624, 0.14290408021019352, 0.057969087990181106, 0.1201165957196105, 0.1961454595889776, 0.15430929079171152, 0.18094068272940575, 0.06325101907995921, 0.15362100675702095, 0.20244766657631244, 0.19340845726190076, 0.13308707714801835, 0.19224694539462367, 0.15812698271005385, 0.18985817599440777, 0.12129149880380401, 0.1629330659465444, 0.07094095986817153, 0.14175284924286027, 0.10467799350378976, 0.07188670307157502, 0.13592465149779476, 0.14959527600196101, 0.16799643215152527, 0.2094026570839267, 0.20929689098510051, 0.11971171059074903, 0.11036519276639147, 0.1432329923996041, 0.17918214322097842, 0.09546046956412255, 0.10973792763486986, 0.08086234241002992, 0.16067719747943265, 0.12098757640248346, 0.144746582955122, 0.1694474792889049, 0.2184770757993383, 0.19681094484704156, 0.12705836354965164, 0.1764328375218376, 0.10911633921486717, 0.12652947942936613, 0.14111201669419968, 0.12734058268007734, 0.2049992909474719, 0.09065671523492183, 0.13888424833215054, 0.11548450637248256, 0.17186594225706595, 0.16726720837816117, 0.1541164664611701, 0.10616813410794544, 0.09978360331226742, 0.1804829298728897, 0.20178000562854354, 0.14335236421996547], [0.040781982017741095, 0.023374495532123313, 0.01593908458392346, 0.05589208190119075, 0.015578117360541177, 0.06170693439461532, 0.02545313338839239, 0.03572677081871418, 0.054938685479423696, 0.026613576563015103, 0.04402624946388026, 0.07960980397558982, 0.05021510225149894, 0.020536084231289647, 0.10040826374484647, 0.03179424806618162, 0.05762540945603002, 0.04452252122122915, 0.03575284079077744, 0.04063644829476553, 0.043264593358241746, 0.012192083428794099, 0.058927268631035284, 0.05370795373774825, 0.01200252646324976, 0.030314012978886886, 0.015849534651234506, 0.026260126577389818, 0.02714127324701798, 0.04164909395659643, 0.03170113965508438, 0.03608934491151764, 0.014593253877284306, 0.009264948612619794, 0.006672325130972651, 0.05617877115465461, 0.03434257251360724, 0.07825589678700894, 0.015127653830624638, 0.03673941648054508, 0.05293764083856537, 0.04091749531066707, 0.007551507742684936, 0.05889385953665741, 0.07647460446723046, 0.08075420143863848, 0.0422282449360336, 0.06577500682925025, 0.050148172979994174, 0.01047755950205629, 0.03966604089063983, 0.04652991673097976, 0.025351458199081883, 0.06055089622555722, 0.059255682863295085, 0.025807353292381572, 0.02947919547647959, 0.020847456837673823, 0.0261686499335713, 0.007844437739901967, 0.059334574597737486, 0.029486410109506502, 0.02464062245112033, 0.04706296836957336, 0.02757718110637319, 0.01004931730999341, 0.025123801765843265, 0.018054576057399956, 0.030919752954956026, 0.05024379224426324, 0.05666305363598851, 0.05701403681849761, 0.0172130188964788, 0.012865198922583894, 0.042443864212761966, 0.03076524834238714, 0.04277513595297933, 0.010541526886123804, 0.07838436207103153, 0.009862434948914716, 0.03448262487748458, 0.009808222736953007, 0.014520567455028575, 0.01155164445780458, 0.02408377420637877, 0.04703969844887334, 0.026271263580589045, 0.03918551990101415, 0.05408354366438524, 0.08599127041957072, 0.047142223995779796, 0.07247841406253076, 0.003581735161846624, 0.05338943736147016, 0.04139235874097194, 0.0384502018982124, 0.02174930511823585, 0.048389985872011994, 0.045749763432409496, 0.02412400722894217, 0.016929700429881775, 0.017040109021529075, 0.06818654436257578, 0.07356989017177014, 0.09472444292999084, 0.03068352399784471, 0.08912197299181454, 0.05811655608516547, 0.08647423522967486, 0.010944462321217983, 0.04825332727763922, 0.052299730915335886, 0.008571832478346844, 0.02535477919023364, 0.019878633320331573, 0.08273184209341004, 0.03412145655602217, 0.039815650201372565, 0.056545884318409435, 0.02403955178094968, 0.023412380495198795, 0.048027699062180136, 0.05074819602492837, 0.07320153211513836, 0.009679112023854209, 0.0503516344413642, 0.03223147168154678, 0.03558014925088614, 0.016955596116942265, 0.0127272657494271, 0.0791162671521306, 0.07174525259723587, 0.06703347478422426, 0.014687913616428213, 0.025763021699423273, 0.10409143828456441, 0.02553639756966262, 0.03570086555555463, 0.07198232616628371, 0.052575120371916605, 0.01679402434327189, 0.0029541688620097818, 0.018737338513376254, 0.03558137882200461, 0.07619585571510178, 0.013652007609996344, 0.06391370428665992, 0.024801684776321057, 0.05117221803013837, 0.06248942809179426, 0.020473960246289932, 0.02157476922166684, 0.015193845742502281, 0.07067714216968707, 0.032304158103802515, 0.01981890719053486, 0.03609867586243538, 0.0303160737554032, 0.05512109867507412, 0.048075185022166664, 0.014372573632206169, 0.04670603651433222, 0.025280162226408723, 0.07252029608935118, 0.06756690946678001, 0.03989487135362241, 0.04405122776065142, 0.06352983678000108, 0.018253663156722343, 0.036837763017824585, 0.03716052735164281, 0.028795343260431004, 0.06689909530142624, 0.04332291946235684, 0.033950588305390654, 0.012632292871844145, 0.044703030688387733, 0.02724832445833712, 0.0671640774535556, 0.04841242841775379, 0.028668421643575834, 0.013945036241033626, 0.038672321430978276, 0.06690847987849867, 0.029997566955224163, 0.025551008781598463, 0.045850576772805185, 0.0698602089898721, 0.024239498813967073, 0.05865509291329692, 0.009847327695047904, 0.028101411242518696, 0.07690057233576814, 0.021325918966003006, 0.010647952778174753, 0.06267802744743324, 0.010151789230745166, 0.007275449395585325, 0.02294999472196064, 0.06312594373500155, 0.02749220280337238, 0.02616687644002659, 0.002888934799439965, 0.018715985727706747, 0.06387324718337867, 0.02963436467032279, 0.03635198666503833, 0.004922231263105548, 0.0076346905271132155, 0.06104641721674031, 0.03627992460444089, 0.02510747643217685, 0.019161176657484427, 0.023637422653395804, 0.02385139101064734, 0.019174751735502676, 0.017664422799322396, 0.027046927603923028, 0.03004052150513857, 0.026892331060803226, 0.03499019643171661, 0.02573023696670369, 0.02278411944937562, 0.08827794328211777, 0.05889333476642928, 0.07301970114631039, 0.03295976082764326, 0.027608500695937586, 0.02271247107625729, 0.04669978140643047, 0.03573388777553074, 0.07320130994964032, 0.0666128388876396, 0.029905172921116316, 0.01776847286119817, 0.05567768070426199, 0.03126470702550104, 0.061768608302959514, 0.06694081644978254, 0.05628990369939035, 0.053899663410359816, 0.06074021570384503, 0.02829682495024416, 0.01779633356378444, 0.024325702857646733, 0.02642043813642475, 0.014972941416706291, 0.004307009991363533, 0.03097083952818667, 0.006926899978650675, 0.0473304326465774, 0.013872368970976002, 0.023715703432718595, 0.017468386645158453, 0.059875551415907766, 0.02199401083822933, 0.010318375049879955, 0.05273199985705076, 0.022995481192464792, 0.04238004142779016, 0.026173506931011236, 0.04598804358993808, 0.05282389210356821, 0.029832513311937935, 0.05251735734242586, 0.06867101070501151, 0.011612261164813273, 0.09803342948397321, 0.03415239884728386, 0.06259381523235671, 0.03415090497583151, 0.04024162573078948, 0.031016804803643497, 0.020736483256182364, 0.04976599469720837, 0.04491618316199991, 0.00500599627435628, 0.024683243752787673, 0.04241137825433285, 0.08101503139421826, 0.03323716126502522, 0.031538859250084046, 0.04624412763082693, 0.06555212886943933, 0.051258889387451836, 0.029130458846808444, 0.03379453619521472, 0.0369247293189889, 0.03211459730781856, 0.08707087982686297, 0.029570296737215215, 0.05270047916940624, 0.09134739712481538, 0.016492612795123172, 0.07378264044922206, 0.015629602299492448, 0.0477573542945808, 0.040237894882598234, 0.0610267632310429, 0.06666906974128177, 0.05670721860482328, 0.03653680920721062, 0.0389917188083693, 0.021318051243020643, 0.04973491834055993, 0.030363124960492698, 0.038399666908287236, 0.06332540621740684, 0.0628138050406931, 0.04803308849072745, 0.034171072240438194, 0.06086182833138493, 0.04266132593094822, 0.028165519395242297, 0.0508355760135718, 0.001937133157269038, 0.03223406488917047, 0.020382820681158095, 0.019227054473313115, 0.0711481330255347, 0.04013722326846854, 0.04962980341646941, 0.03308176799046417, 0.04773873835802079, 0.07481804658328334, 0.03676368614598628, 0.011403384419428486, 0.03101418095250284, 0.009663707910916738, 0.010223256615591387, 0.051351643482884096, 0.011494853402367763, 0.05740608614418776, 0.03848502059437094, 0.04828504714814406, 0.03018788043259373, 0.018762117627287106, 0.015710602690946433, 0.04902665090236453, 0.02437704032467258, 0.04823554254647705, 0.027883470719379765, 0.07517502823423955, 0.05535313521601981, 0.061084227486243176, 0.07796332014784699, 0.03446865526418533, 0.0049323962922508445, 0.08349825177461871, 0.044083675414684324, 0.010420774192278905, 0.025879721788148728, 0.11853840863031727, 0.13260623440146446, 0.21092298921317826, 0.15313049598086267, 0.15363620594143867, 0.12001804616903106, 0.13125781240242143, 0.17028714229743327, 0.1410814191425039, 0.18231421709060672, 0.13333141323058836, 0.1692319787558048, 0.11330127836235108, 0.1516361342322442, 0.2379243556530245, 0.11913477743585264, 0.2429552397300159, 0.1483769510542193, 0.21438316321901738, 0.11633301003565712, 0.12046007890134089, 0.09228087526055113, 0.21234320897248485, 0.13008436488528408, 0.15903027698157296, 0.15289924468003935, 0.11888605166947651, 0.08245123940850459, 0.16108690130133785, 0.12707500297936702, 0.17533298041070663, 0.11824931003033154, 0.057912979710606806, 0.12822770483551488, 0.0924968890725605, 0.12440633569513598, 0.10142715302326026, 0.1359388547679109, 0.12835961751519673, 0.1213672036124814, 0.1357548864137742, 0.15312842754346712, 0.11455446797152681, 0.13472314984087022, 0.13205970727628277, 0.20272712012933147, 0.14547173114072892, 0.19629958115758436, 0.18403002421461767, 0.12522663200093856, 0.13484089755483214, 0.1438717105455937, 0.10478647155386787, 0.11683773174281083, 0.11351996582121619, 0.17562030934758727, 0.13908130146803396, 0.1844272408033571, 0.08404752915544857, 0.11590429191147128, 0.20229529168817306, 0.12474437965260399, 0.14001844150404777, 0.1509860166979413, 0.1548153684744912, 0.14412752262526943, 0.11943417991841994, 0.07562221673827979, 0.07667607026955775, 0.11130268520285046, 0.17764457411343054, 0.08970759358377227, 0.09566847009644394, 0.11114444208121109, 0.15840606854086922, 0.10916433462332334, 0.09595069688774886, 0.07461150161801808, 0.11839095202665176, 0.18357787912170734, 0.13131347635099966, 0.19904536285227348, 0.12173727004518434, 0.08161411981188482, 0.10393666554122202, 0.12414393525931144, 0.10478118554719033, 0.09150610756008856, 0.15228010774139436, 0.20387459726583576, 0.14567800797522068, 0.22405911417257404, 0.06640520607752186, 0.15415516922310477, 0.13384417120006778, 0.152502472422296, 0.13892627591567655, 0.14787075079737172, 0.1450944328380208, 0.09211817350719245, 0.06527887296772773, 0.08060832297609699, 0.11497643686109975, 0.1630331323512139, 0.17639134619985858, 0.1447617055307473, 0.1391503566335286, 0.16973416471192915, 0.13413468706271342, 0.1330915051362207, 0.10783016185967192, 0.16058494517159078, 0.21043779508721447, 0.19444635318171596, 0.08553902573523023, 0.17108509947936382, 0.19658094993041408, 0.10032797773038188, 0.16599363316932034, 0.16221193206166068, 0.11465512426389803, 0.15461503648229186, 0.18730563231773917, 0.15507913254682096, 0.178198792761372, 0.13140346103858563, 0.18229815988771378, 0.11853435602519782, 0.16223621704886038, 0.12896486527977452, 0.19719316143422358, 0.18294884432708064, 0.12605540123918366, 0.10600527147612265, 0.15843128815533655, 0.1174704131159571, 0.12541269177510855, 0.1413069401056536, 0.16150086457210203, 0.12900419623380707, 0.1997601535291441, 0.13727180179088347, 0.1929593458771706, 0.1625513396556339, 0.1096232136290881, 0.1012116754727979, 0.12922208696123094, 0.16627766792812657, 0.13977926885408742, 0.10655980422011307, 0.06916954242173703, 0.1183676552928744, 0.1614918553781125, 0.1186247697220214, 0.17404403747810474, 0.14362890663887226, 0.23145023853548113, 0.13240191875205887, 0.20264424473768283, 0.12678431857737804, 0.14013401352830474, 0.19505815099804633, 0.17033977253783136, 0.13077891551919524, 0.1487665986942668, 0.1048458586897581, 0.14521867697758062, 0.17704886414351004, 0.12263300302889078, 0.16332493524157232, 0.12814539634893019, 0.09501430761790085, 0.09757736202089057, 0.1496968745824791, 0.07207385835147674, 0.1424012507402128], [0.020481203607614004, 0.012839292701814446, 0.034163101095586054, 0.04006709941031952, 0.03205494204115483, 0.02774183063827936, 0.05830795549216771, 0.036754922100132516, 0.05140263046468458, 0.031771681031152126, 0.03817506908108631, 0.050420804520047484, 0.017490187592263666, 0.018764187979902473, 0.05972028837629384, 0.025217237679528135, 0.06650567850879123, 0.06128414579096341, 0.04596858112622173, 0.04500034175092175, 0.059592194644914526, 0.03323336146892079, 0.05701240888165851, 0.06778155198140491, 0.026219273023607752, 0.046536727252626614, 0.06820814804204049, 0.026869059224883397, 0.07118380207928919, 0.023176195588143125, 0.054569726043771354, 0.013144807608407593, 0.019490657667178782, 0.05779434333465273, 0.042693179866839806, 0.050001635681837804, 0.015056953491312603, 0.0952421498274611, 0.01852613764875118, 0.07140252784255051, 0.04037011782788942, 0.028866141275953383, 0.07929000823247818, 0.05691262592952098, 0.011835141997453908, 0.019119375069896062, 0.0046002689275830505, 0.03762841938183673, 0.06817781096023899, 0.024287170550275235, 0.011185168104636814, 0.025116772909137993, 0.05291962245058629, 0.021591295653413382, 0.03302387089558667, 0.006430910237418909, 0.034590018913149834, 0.02643890277061972, 0.024059900991438378, 0.022250671360281207, 0.08259337936197558, 0.027680139492956862, 0.048574766279348446, 0.06047186659528844, 0.04806478154815493, 0.0444166861744898, 0.06219325466982781, 0.06101313835730957, 0.017147012760922793, 0.03935668309549651, 0.04501416580751539, 0.025600869614150257, 0.03751920588735131, 0.0378804967828816, 0.068661970867505, 0.11720483341524679, 0.05292004762938427, 0.0361391099830789, 0.03133251729811872, 0.04883501400810577, 0.052618005973917824, 0.07684089408646669, 0.015689631034019255, 0.031063831110875455, 0.04745534328263133, 0.028577054167286526, 0.025639675797954686, 0.04992649011734513, 0.03534664565156545, 0.018465628194051887, 0.08335922979899953, 0.08681826233383148, 0.06693736905412329, 0.028064859272431464, 0.014013328191433704, 0.06526364313979303, 0.05310919856832874, 0.018321113368015618, 0.039046340877370495, 0.03550233770041697, 0.06034673762417609, 0.034606267638023824, 0.030919331606597673, 0.02632939816272307, 0.0290030756619789, 0.02232603334461249, 0.09042276730460506, 0.014482993715172334, 0.10406426514589018, 0.017335912806072065, 0.031442514117506724, 0.011666651492217376, 0.020912708376624414, 0.05382745962349638, 0.02921558079129506, 0.02083125790851491, 0.005309995284469258, 0.033953503269942543, 0.04476421047002078, 0.025575188431708563, 0.042766103776352066, 0.009949431893596006, 0.059220427497019695, 0.0853981881312305, 0.021577781862429073, 0.05070385868631063, 0.08507163549262671, 0.027742278799715064, 0.03034770169535712, 0.013877479735040858, 0.09354426916087828, 0.028727086741597425, 0.04971197783766736, 0.05002326617437986, 0.0193002694962366, 0.02866348229168404, 0.09636203247693279, 0.024078882734982238, 0.06297413958236575, 0.041706244115747755, 0.037208178020533056, 0.0495483146439637, 0.01802490547209257, 0.06208955317795758, 0.019950597704718673, 0.05195425973544198, 0.013688335499365725, 0.011480869424919929, 0.018010815199945244, 0.10487774326916664, 0.0199010988487111, 0.021415401865998586, 0.019078247639681065, 0.04405431509498627, 0.050950182767044154, 0.02379820727172398, 0.07158147065990395, 0.029749819866171288, 0.07699845538985345, 0.05356411306908535, 0.012160082020977092, 0.05935223292439215, 0.003994396083139545, 0.04909963609891073, 0.08253629815073744, 0.04148060440896981, 0.004496838439316039, 0.02235313370493391, 0.04526781751924465, 0.030579163670359604, 0.008323722455139843, 0.024219544138759378, 0.03991871200982602, 0.025554159318187067, 0.021746223529560432, 0.03440911108027062, 0.018531195744271242, 0.03385012736544013, 0.04715868339483296, 0.008531717241801804, 0.03821919957596449, 0.03433185877398618, 0.05780144113927119, 0.037656121121178714, 0.02182908742989023, 0.00829649664792082, 0.10335224004642618, 0.02308739450640015, 0.03444211797848825, 0.02745809273854379, 0.029969428545765342, 0.0371136351097976, 0.024315820323423516, 0.02005220011567637, 0.01477040500650483, 0.07597451759201866, 0.019011347096473463, 0.013506031471244512, 0.03246932282983776, 0.04728039944424264, 0.052673976357665755, 0.01669033625794034, 0.032467193105408264, 0.023117314070282925, 0.02885135194857515, 0.017106094089667165, 0.02918324996567061, 0.05831327214236221, 0.012635949984072678, 0.038728490997586525, 0.02224507508799434, 0.01659233446022676, 0.022289718861781785, 0.10992794042272915, 0.023536197540740815, 0.062131335613347834, 0.016555025978314302, 0.03012683280112763, 0.09871183098444054, 0.056793568205208554, 0.004754807535303576, 0.028199740542819905, 0.07192493851987586, 0.04195881947394341, 0.07228241046710361, 0.04710040708643295, 0.0458086104763131, 0.04137997109923632, 0.0460465190811984, 0.052203127228084116, 0.029581604194977594, 0.07069817128320856, 0.0353304582137254, 0.021253588774632064, 0.06766418731140514, 0.0367784180167702, 0.023787974252275402, 0.028068909962331096, 0.0222790549178758, 0.01643279856521516, 0.034014679221135956, 0.04700877530980976, 0.01686579912089773, 0.08947557619502468, 0.02403256122864062, 0.07217624600255682, 0.07292736456879685, 0.026296442975440336, 0.04034638442399521, 0.018601875016165358, 0.011891557669807828, 0.06480534636085072, 0.029842053021815036, 0.01202577148609224, 0.037294535281797575, 0.022395701380446557, 0.037673660704205116, 0.07369713737599312, 0.11791377118037594, 0.02536201680589828, 0.006654910516038898, 0.10640181390748871, 0.028428251164094098, 0.039892243672042124, 0.022461364691656445, 0.01020822692812691, 0.05162570760735581, 0.04691833096946921, 0.049434738278749495, 0.03429599436781099, 0.06872232327417982, 0.09875829421704817, 0.03574485049372719, 0.060716654669733784, 0.019935812207780058, 0.06150223187080795, 0.0062613093834971234, 0.023388371299651843, 0.030338945310382597, 0.0323464653094209, 0.06002188953120382, 0.05285752336344412, 0.014433955469529235, 0.05473749546874916, 0.09135672807573311, 0.04418839197305422, 0.08960081624888605, 0.02119187081623222, 0.019869953544149478, 0.03728847552631651, 0.022977843933228045, 0.028779996604087855, 0.028453482269880273, 0.026207503997870994, 0.014714566772923836, 0.04567918375194554, 0.0101100230747233, 0.04774305526347411, 0.02584798659588541, 0.024453562932209145, 0.03766353302184613, 0.06257593474020401, 0.04666651020787897, 0.047160824610581326, 0.08285030226914153, 0.0415962377202607, 0.04148722340863559, 0.03018558982970013, 0.07037282906352513, 0.07788034516476816, 0.02404802279817241, 0.017612522257672205, 0.091575913491749, 0.06991269367356455, 0.014147512321811051, 0.012143305653045255, 0.03134165289661577, 0.04832013780551572, 0.031925634060415535, 0.043760646780532216, 0.030068862927897327, 0.03179207046125685, 0.02101947230497195, 0.014466265227735765, 0.008439122109613832, 0.023840395733714107, 0.0362018219405605, 0.06236159099986958, 0.11205893655818318, 0.05048723966484109, 0.012822732753721217, 0.044956946700450875, 0.043070313460644216, 0.06468245053603765, 0.029482916748571782, 0.07909315427945507, 0.04271402511925947, 0.014874921424404509, 0.019399006738357486, 0.0319694408831457, 0.08461955168675031, 0.05753500342008568, 0.043916262220591314, 0.03429452347899637, 0.07211307439232065, 0.01996501930989325, 0.003833988523711601, 0.10252939266783577, 0.04648447239531144, 0.02251829843096916, 0.02647675709017823, 0.015191884557416123, 0.15211945910367275, 0.09627192521527891, 0.1182604336269921, 0.09766587581966193, 0.13268426811743167, 0.07125517849119441, 0.17515167804254642, 0.10943358388519096, 0.16473413865652778, 0.07749039108955091, 0.17142747949448325, 0.1019378042509479, 0.07720863927275905, 0.08704716174472725, 0.19102183290787283, 0.07991524323100045, 0.12518797520427935, 0.12203354688902056, 0.12189263267622841, 0.20095774813765482, 0.13336378810626845, 0.1249072652670645, 0.15114675726621382, 0.16177328543797617, 0.10022512276566799, 0.08651593339539344, 0.19751263542040703, 0.12500107273339264, 0.15216651222398206, 0.17097974706801677, 0.08937098221072266, 0.18171614756987942, 0.12318454802997651, 0.1803875059610413, 0.10427867017325856, 0.14575587315184457, 0.11350924059027627, 0.2445762817777934, 0.06742745848192323, 0.11787796423079507, 0.14587274752557278, 0.15406831017424985, 0.2461175281073778, 0.16768664151670473, 0.11473577800056628, 0.12210780379152107, 0.16249708530883636, 0.13141233233674882, 0.1381396261915084, 0.11846569156454456, 0.14546287516432424, 0.1486039582279421, 0.14803918288840404, 0.23845304825132896, 0.1333623785044878, 0.19063350293905507, 0.11224309643430096, 0.16097744265871664, 0.21352899050520313, 0.125333953258251, 0.1494213127561154, 0.10452597867697479, 0.197300260526038, 0.12225727520642743, 0.18340206194308498, 0.17339206601102508, 0.14558921838479658, 0.10008214011548028, 0.1953405616504531, 0.11514207273120843, 0.11949894499153861, 0.08628554011304533, 0.0957281866501416, 0.09525413144259684, 0.1591881523810087, 0.21977567143978613, 0.11235066283974918, 0.12832953324241023, 0.1199663658776591, 0.1656038782769634, 0.13545831845652673, 0.22887435982063895, 0.1632347973364015, 0.09967766101321868, 0.13645723582275454, 0.13486922748627203, 0.07649263051608879, 0.11862719055986214, 0.24449412650879354, 0.13967520347045315, 0.19359374328726725, 0.22928982462373473, 0.13978244045809393, 0.10177995183414991, 0.1009148853500524, 0.2190876785185068, 0.12397870541580262, 0.1287879296127827, 0.0748982023628008, 0.15317793214513412, 0.21807336278500097, 0.10533897416485895, 0.10786048361971494, 0.13897199604299762, 0.12589711215226881, 0.11368670485793583, 0.14878944343616887, 0.16347677386816473, 0.17358515081146073, 0.14571413668172975, 0.12310297498779914, 0.10932709766371597, 0.1126957241626036, 0.20373671676122374, 0.059547815171460954, 0.18678247087424804, 0.15076769696127984, 0.125034780602061, 0.07160491295038693, 0.12449949964760773, 0.07401814353802512, 0.10163781188067891, 0.0941295833176663, 0.2550733257685938, 0.09690846001068432, 0.14620495389305777, 0.1887217764892886, 0.08356420428402002, 0.19437682304170825, 0.13916016255895938, 0.1266821377700375, 0.1324640638044765, 0.17119880224908554, 0.18696207252721633, 0.12226908828221983, 0.10138563105776426, 0.2720662284522288, 0.14583304884933657, 0.13776013687733682, 0.12292252297723487, 0.10740097642185227, 0.13968203697473774, 0.11774107964048464, 0.24982217609161333, 0.13901730248283956, 0.15149391766998077, 0.15577745233331958, 0.08463222278101791, 0.1644607984851445, 0.23752885510123548, 0.15414476574909303, 0.14978569481642018, 0.1999173241276895, 0.12121243853001826, 0.16510550743870198, 0.13116315457849734, 0.21705549240352648, 0.16228832634946994, 0.17621218887788637, 0.20275981676193977, 0.19051066840127592, 0.11441592863129993, 0.06558502468490793, 0.16951005335056013, 0.25348510292749254, 0.3035663542968612, 0.1409465110590381, 0.13982852830761863, 0.2613327544062369, 0.10518355024678093, 0.1378964545625833, 0.17064504325389865, 0.17046199420527106, 0.09838819714082826, 0.09643708611087454, 0.1603202464719934], [0.015064582769428531, 0.048439103599277236, 0.045408739392916043, 0.06247315638428254, 0.0943557171511554, 0.02748259989124152, 0.06717720053969853, 0.04238318621871933, 0.05448107434917362, 0.07622325868015328, 0.028661314262858326, 0.037304563372726404, 0.06371956228488876, 0.038536965186076785, 0.054796503391116864, 0.020343462914048184, 0.03487957716589013, 0.014971949332844348, 0.08378223290727024, 0.040423146434008114, 0.07308474967196103, 0.041235387325286865, 0.040160454884772344, 0.024686867348669518, 0.031028926229825428, 0.014158459718249018, 0.016063882222008562, 0.060935614089812004, 0.022205054654829928, 0.004892211150182712, 0.06260798402851628, 0.01863465783366513, 0.01819782492314135, 0.03835317686260228, 0.011475061520843977, 0.02119592150613185, 0.02881517153113119, 0.05691374824833005, 0.022801867791361386, 0.06737423835382347, 0.11057721526031533, 0.059443113934849544, 0.05696795279941252, 0.021600283779985, 0.043077078017015616, 0.04006766248494387, 0.07739925727007851, 0.07625613151298416, 0.04054762423038483, 0.05714455521815727, 0.03364975323840495, 0.040144378529681314, 0.035888652857993884, 0.03710376406689325, 0.03663227142345521, 0.06693857947304364, 0.034800114695944136, 0.09063708806230177, 0.010290643624630908, 0.018613063730299473, 0.016032976319923276, 0.016245737131084168, 0.037051160639572533, 0.007447052611819199, 0.054542893814223434, 0.04694184986874462, 0.03212134654243146, 0.026529157504199014, 0.08644746045672125, 0.08879972576734521, 0.049096407038309885, 0.009313664143724788, 0.06024202489624581, 0.017864523049924644, 0.06179329165587984, 0.06143279366135117, 0.09239558160545365, 0.05417950383778061, 0.045181130840172695, 0.06015978918801393, 0.03882700224376975, 0.047623710256190076, 0.05991249217561657, 0.09092385009411844, 0.0625002644054832, 0.0614411401892862, 0.024556015700762792, 0.03208845072696286, 0.016361054431106296, 0.026278326911250913, 0.027128027586807168, 0.03559010456346216, 0.08261086148840767, 0.06841471598994348, 0.06601954209468057, 0.015917519208854966, 0.04124990852189161, 0.04501335375431565, 0.008582560582116486, 0.037883653065129634, 0.044884317734789465, 0.019973363922608477, 0.016422781965605194, 0.03843056706471309, 0.0888710102486995, 0.07868184933378812, 0.05077282192125436, 0.01416739613388575, 0.03543796333213968, 0.1458963583553991, 0.06275667020330025, 0.029920073331243573, 0.08057878262573674, 0.02785015547077262, 0.04861918405719823, 0.012701340376459544, 0.015062722133382436, 0.1317296459549858, 0.038986233618831447, 0.10108826636907556, 0.016867310229328372, 0.0322557604991861, 0.05491319007330364, 0.05085797259403814, 0.0689725429120083, 0.054198200213572675, 0.05201391117166608, 0.04099480507354583, 0.08482501646804233, 0.03325151009184699, 0.049855071570604086, 0.04195495072992579, 0.019410373567934, 0.030978249513634273, 0.029274709372510834, 0.10746792484555515, 0.025031723743004185, 0.06095190111908221, 0.03368751754263236, 0.042975441132101326, 0.08451799907150769, 0.04137892538921968, 0.0384373890776788, 0.011834160447300924, 0.030004450255223823, 0.051944767906060146, 0.030171126089689713, 0.06659868158279889, 0.05323967483315257, 0.0476492554580252, 0.03472138000952621, 0.012239668022600875, 0.054097903982525876, 0.06308200859254406, 0.058544894995828795, 0.03340609897408755, 0.062471095607766224, 0.07862613175905521, 0.0010155372846413465, 0.046608367964865706, 0.03446339224014552, 0.062391797846723954, 0.07306026550190103, 0.08521890057431114, 0.03411235926192134, 0.047985257791175, 0.08517871926268263, 0.04517327843894882, 0.01913382157292818, 0.03634916363103736, 0.028388996818853963, 0.0971749130516283, 0.042373303684496114, 0.010638811434018276, 0.03992908867076039, 0.009504855749377561, 0.052030512296985236, 0.007120159064089099, 0.028139041481359352, 0.06818026244159668, 0.028252504848604722, 0.13738741978041588, 0.051561965261616056, 0.005854754182960718, 0.020272697457262588, 0.06103545449854386, 0.030959214143935713, 0.0215616078311277, 0.058222257066518075, 0.03175035888899959, 0.07375310009886181, 0.05097896085991975, 0.03287531878618944, 0.04369575147246642, 0.03153117921864314, 0.057181917326224435, 0.03339440847236303, 0.04106338909496704, 0.040798062203271736, 0.017515148652056535, 0.02650789856430023, 0.043923777543128505, 0.018134444553945816, 0.046443023208168246, 0.04903314732796243, 0.021709106569629044, 0.04000887672807421, 0.05225457003219955, 0.05309705607472889, 0.0715346780094889, 0.047358241638228785, 0.05260501695316165, 0.03602722667217736, 0.01794391274151783, 0.04273275979944775, 0.045676004487059774, 0.07191901666022117, 0.029086211523521813, 0.029789282970370787, 0.041077508095411525, 0.023658762032526637, 0.01172384282859463, 0.017488586468501918, 0.09076923822924014, 0.0492982558845993, 0.035072550883576754, 0.030971860340345773, 0.06562119935669246, 0.06124237484689202, 0.0752334884037414, 0.03257433433205851, 0.04616772951257806, 0.05655467900778017, 0.06647993795453541, 0.034355791360740705, 0.009885521966122813, 0.047539838950239846, 0.028966110004412553, 0.029886355886476177, 0.04170076658708915, 0.030963423797079635, 0.022194833126700213, 0.025273340213443005, 0.03212761505687189, 0.068550183317594, 0.029696134339657523, 0.03979108942252013, 0.03832049555175247, 0.02829521808082298, 0.0336045348986743, 0.07189821737307696, 0.010835993847238922, 0.08866431972672863, 0.052505306779376926, 0.05213841578112014, 0.04975502048769305, 0.030215451936988585, 0.06508362779934561, 0.05087652724356421, 0.044196516335491216, 0.04082878615947501, 0.10484823356232337, 0.059318126690003185, 0.04747492448997594, 0.00842327175046047, 0.03526483129169192, 0.07497265078728238, 0.017082793525450172, 0.07981447968631983, 0.047420673973618016, 0.08370769255223774, 0.013867341518972912, 0.007816716369556925, 0.026379590328302116, 0.028782614709569082, 0.01841988316887329, 0.008741011505105324, 0.04846087964852491, 0.12055145786894907, 0.023117258528908415, 0.03105606297932325, 0.03209897294460285, 0.03525437419152549, 0.04745711677617604, 0.012745874982717778, 0.13260591264453628, 0.08281686253124669, 0.04443539021116111, 0.04962830954501706, 0.03267758000161379, 0.040825036159085656, 0.04207548700393208, 0.034182031128195026, 0.05023520056819243, 0.03333109896630049, 0.07754778639683801, 0.02952322637992761, 0.04785571615361879, 0.06895575792558732, 0.013823912952155357, 0.03811258694998199, 0.09657022453123525, 0.010702785521355129, 0.04787139797342881, 0.06335046878384967, 0.056573896323360746, 0.00845535263989962, 0.05585012326557791, 0.030968359318531813, 0.03567578383691369, 0.037936248831571116, 0.029170124964307875, 0.041463149095615076, 0.11018104055115294, 0.0412956707840485, 0.03565913674631908, 0.05882331433015005, 0.039478682597438176, 0.03465399874614612, 0.025335830005426562, 0.03915312587313595, 0.01151387919596727, 0.0504105351114225, 0.055628317828860976, 0.027612808025291855, 0.04885304005696409, 0.0230061317298321, 0.03041155320862609, 0.005009073074982172, 0.06455086727416323, 0.09823985187517059, 0.050251165840534434, 0.028292820225619984, 0.023815490215295748, 0.04692899874381481, 0.08156626996013426, 0.022857629416149952, 0.025372023829409195, 0.07417716040846802, 0.036652526788173184, 0.037554913245502024, 0.005732343866369657, 0.02388604499790217, 0.05428480645341258, 0.019556320978388674, 0.04637173106593471, 0.014193985130517714, 0.10022697669844474, 0.0215570438623188, 0.01230642013627315, 0.05235658996107598, 0.043294631665752786, 0.0820915764498134, 0.12770694124722673, 0.10298780435996671, 0.16754021147085776, 0.23158451842684902, 0.3131195013561557, 0.22047434362672994, 0.08307102752188522, 0.11196124502607893, 0.22378035009868685, 0.09537319682778851, 0.12694810051470995, 0.1854395647082598, 0.16108680937078693, 0.18152726093126884, 0.13073485014179062, 0.08297165059634755, 0.11185475880460394, 0.1750255186831759, 0.1436339628191725, 0.23372228677955367, 0.22552214292508943, 0.08806212865296872, 0.09034909262892701, 0.08272696211333237, 0.15927678875384793, 0.0865604737473111, 0.121959604082569, 0.10635112953041831, 0.09170509889842042, 0.11181170466325938, 0.07507286274865752, 0.1362635994390134, 0.12693830225015842, 0.11496806352008736, 0.1485660368756902, 0.19948656820962507, 0.07910211750816915, 0.1380109080984708, 0.19382991287256443, 0.22511401724430824, 0.16289542038594523, 0.2551603686785506, 0.08436688822844336, 0.13777285393687988, 0.11510232042881752, 0.1087488774811068, 0.16865284692856575, 0.11605628375564853, 0.18756518290648538, 0.10887006492984873, 0.10207068986229359, 0.14617446359367142, 0.16815223911356542, 0.15675562403855786, 0.14731127678626968, 0.10559111668337738, 0.19539875368918144, 0.19989807999903159, 0.1120839263462732, 0.14012288993164418, 0.14357249192412824, 0.16927058958718855, 0.13256639782940188, 0.11950580913934017, 0.14533150640706863, 0.06726717756640527, 0.11991826321689353, 0.1806429503185134, 0.2223724337114442, 0.1651580917138246, 0.13207383393760652, 0.15858662014286365, 0.16004071631018194, 0.10652913772050412, 0.11955704509971604, 0.22532867508069163, 0.1149987453414548, 0.11872059966046965, 0.1068565100731869, 0.12554150179869708, 0.1368656985822224, 0.16679505306866863, 0.14962778877346747, 0.14761064862532003, 0.18146249585815016, 0.12500238274374317, 0.11324369919396217, 0.06855743817023693, 0.08428850977291023, 0.1541507565566609, 0.14493507122801197, 0.08954186578311267, 0.16788619209922132, 0.1681989245116711, 0.15142199733564932, 0.11558530822155938, 0.11038584649683007, 0.10486822079626784, 0.12103298243375556, 0.152389106731261, 0.1529633049522677, 0.27721038628970424, 0.21255581369323118, 0.15124481652052174, 0.183325361220106, 0.2426737330613598, 0.09641369744654625, 0.09592562282998716, 0.33168781789079793, 0.16401055329028638, 0.16971395531248662, 0.15728526658588843, 0.10682885429912037, 0.12764704083242726, 0.11862478504377989, 0.09319585237291553, 0.1610038880138628, 0.19666538814142828, 0.1555010171667222, 0.11028211053100326, 0.1117833057839063, 0.20117841210336457, 0.10747897183342327, 0.211487029108309, 0.18369717433327631, 0.3377868277170966, 0.10016394298403494, 0.14045413102834456, 0.16738060471271315, 0.12532733425858522, 0.12971969171156808, 0.13121658155033666, 0.09481584488023674, 0.10706127005358858, 0.11116059121465492, 0.16141589009954085, 0.1615543528309753, 0.2031308331436688, 0.10254148919616016, 0.1372534463242177, 0.16869383263251475, 0.16812375596454068, 0.065208584400675, 0.18449480975827864, 0.13759040243683324, 0.12183842429470633, 0.10805876249627722, 0.08913338004100708, 0.19095395751778158, 0.13116886959441248, 0.0868520544721715, 0.17842417582869532, 0.1235988483794274, 0.1513387695435555, 0.13833369158448713, 0.17054980320315208, 0.17237451738647877, 0.21885091138462867, 0.09496305633576647, 0.16907994094635212, 0.17002178476222102, 0.15114530169915769, 0.16974973161855053, 0.16200415369483734, 0.10269087634139484, 0.22726194392288887, 0.15006999004512064, 0.14639011734435636, 0.12210676191194404, 0.15504124183808604, 0.26420929198784215, 0.10462371617435448, 0.11416152615340487, 0.1718634294886743, 0.14886091943950425], [0.009314592067723074, 0.11834695559716034, 0.06609331636178879, 0.025530554234020175, 0.005117357687859406, 0.018997839051148584, 0.035145398184296586, 0.05374678673463003, 0.020115691567620924, 0.03858694093181722, 0.07892534271964143, 0.009572774231914551, 0.019295527411985303, 0.023097639017167593, 0.03360549250857965, 0.02376419679832555, 0.022006881115357244, 0.03524115917483165, 0.04402421167000167, 0.012870451412914742, 0.03694569714547646, 0.038372210317081025, 0.049078369498132705, 0.136358272584696, 0.1079758947655078, 0.02345429508075599, 0.01886008303582428, 0.0650175144114802, 0.03322782648366786, 0.05241940150998774, 0.02618272105352052, 0.023594757301672816, 0.03200614415559798, 0.06051711557853607, 0.01768451345513665, 0.05792060228545339, 0.08106339452487808, 0.027716735513099743, 0.022190307462287527, 0.05668149720276556, 0.027081455186670347, 0.01371862757350168, 0.05167237002282374, 0.02187775699571977, 0.017686440166266217, 0.02709788011176692, 0.014141594292595984, 0.051164821451229435, 0.03547249474532662, 0.09408041579468597, 0.045449813196976344, 0.05319768938446238, 0.04315588931222597, 0.04846623460311563, 0.03732973319147864, 0.023555119912470543, 0.0373837040857442, 0.011023708371325366, 0.04852545319966251, 0.02300612789939248, 0.009936029185360719, 0.11228349225054826, 0.02018103120668281, 0.06803026242602257, 0.028868385913571524, 0.015791078312172285, 0.04685732355761913, 0.060151994243384375, 0.015964191200421946, 0.04169857557562571, 0.050275136731685176, 0.007925712965398787, 0.04372524585755121, 0.016453186080100077, 0.1055039435384735, 0.030444753544044592, 0.033686678676355275, 0.03078147216940359, 0.03270196458024364, 0.028551374900064645, 0.09981220137448081, 0.08935687087115743, 0.03321811248878798, 0.025781787023128524, 0.014691353351208232, 0.029192017841964003, 0.036142139860819426, 0.03148284481628047, 0.03599335792504492, 0.028118814844938538, 0.05186759603900775, 0.10968571108195091, 0.011540012370284286, 0.1032919106223891, 0.0456927779821619, 0.012183663164896351, 0.013543870469044535, 0.010358460600517932, 0.07919363437160369, 0.04366234620852817, 0.03525876387533161, 0.0302623097048772, 0.019285711910455458, 0.026980810385618, 0.09020555839543382, 0.04421037486604145, 0.05612023437636034, 0.04096955098512192, 0.03734852532826124, 0.029443313833326105, 0.019913921245343743, 0.04983178249770596, 0.0911575298936617, 0.020437308684772542, 0.01740427083155561, 0.06990585250840073, 0.01018707619814743, 0.025240134132365068, 0.06647114326516468, 0.051689017113418355, 0.03686485571726676, 0.05157689631526029, 0.031763351740195386, 0.06884452961986104, 0.017915358729360085, 0.07961961756189985, 0.052412648444935206, 0.0775687772059633, 0.024128917852536808, 0.033993336011565504, 0.04423651761645752, 0.04832546594702909, 0.03735081210071522, 0.05690498037203666, 0.03904267514665281, 0.016497291677120714, 0.08921381927305654, 0.03241159810474323, 0.0054625794103729634, 0.00250007287831977, 0.027125775288309784, 0.041697916740010825, 0.02694300394655476, 0.051676323036513025, 0.09352964454240377, 0.05854598284068127, 0.030690809494004618, 0.028833559556533734, 0.02338361197842225, 0.01570531189621937, 0.03258320179978206, 0.04277502103979069, 0.020968977534662814, 0.043299224362858844, 0.053457285938484055, 0.06583123768289244, 0.010322390308213091, 0.058237659264235735, 0.028246161640591683, 0.025140590582703872, 0.03974697807984006, 0.020338000707148064, 0.01586081721113935, 0.051465396048320886, 0.016557667066433256, 0.06641480515921308, 0.03713640707334684, 0.03066650535460682, 0.015634331934814973, 0.056887233945270704, 0.08005509258157785, 0.016183492487236377, 0.05771220338741138, 0.046574008921461726, 0.011465493082669715, 0.03406850838913553, 0.0481763469325679, 0.045973530054212584, 0.022199004475447922, 0.05113303263281142, 0.0730732889966138, 0.03339424759389893, 0.059058120278942014, 0.045260156640001846, 0.02433077435970547, 0.02600378589704633, 0.08767925323017182, 0.06662854369008733, 0.06205073933327391, 0.0725986515622466, 0.015310660744416378, 0.05402029927579626, 0.014607196677506212, 0.030010218897293654, 0.03135201232057185, 0.07019430759453005, 0.04105961611193996, 0.07668411419276269, 0.056907481649109436, 0.14089101564980325, 0.040863382690135515, 0.01984535446090083, 0.018745981900381948, 0.004702283589605002, 0.08856949336346119, 0.023198481085860444, 0.03543929249468831, 0.038385176355199474, 0.030574312418579098, 0.00861148997735713, 0.032025832615251985, 0.01907168035095017, 0.04460086520280569, 0.046637881502148607, 0.05661234244584076, 0.03354382626111469, 0.029543211698652278, 0.02989132971232457, 0.041580226482643236, 0.03595134566327737, 0.030892317431167732, 0.02256344782278663, 0.03700899899065976, 0.03396200684590205, 0.03631514549675969, 0.04561575550225474, 0.07942618802189827, 0.013760087294353834, 0.04024307363696637, 0.06288505121765119, 0.03749066528173224, 0.00901343428619927, 0.05875103776493381, 0.06181573420162163, 0.027716419501830975, 0.04635901017595203, 0.07679441553210059, 0.07417951229839556, 0.024460283438524893, 0.03285645770149366, 0.02112547206061502, 0.0046849446258537715, 0.032484736518874284, 0.048288368139295816, 0.04017026464064275, 0.011678974016479427, 0.01758304702478551, 0.007925881025937177, 0.023557889320316817, 0.06315017892648617, 0.03262161344830548, 0.0673869324307288, 0.05509053176689533, 0.017481258837506175, 0.024281976474148613, 0.024962094011566332, 0.011274483422898959, 0.045462112738600666, 0.024496670699708407, 0.025433180628404505, 0.08115446705731653, 0.05826695829689984, 0.03553535225951383, 0.031529375081581455, 0.03407579771573505, 0.07333604183288352, 0.025100516523384762, 0.026997455560992804, 0.03164874115628341, 0.09805461947595882, 0.08027485256353695, 0.0771863844185587, 0.03450687539072768, 0.020764449295858224, 0.07383687181338187, 0.010194698772994022, 0.05024967196908209, 0.059646498787427144, 0.06997706038096259, 0.04060898021224045, 0.10342301124887121, 0.035943309400951674, 0.0583899230696261, 0.025881562314386812, 0.062439218689236915, 0.032278325618995775, 0.06869564043177713, 0.0883903437023682, 0.02437196499217422, 0.015599477807089928, 0.02014717586608904, 0.0223234937631435, 0.04842404231068589, 0.03610835538335866, 0.06483393676218487, 0.00598187163104153, 0.06704934046513612, 0.025321659294047186, 0.029697662685066465, 0.06315763679242904, 0.03765635477799562, 0.06202353555108271, 0.03877712608945947, 0.023096844200946154, 0.019896393153636206, 0.03419293638979716, 0.08242227362408754, 0.03295129172564034, 0.046168032117308154, 0.04040445005821605, 0.0839326695929612, 0.04807531525711379, 0.03274686116304609, 0.05214104729314005, 0.023630918566918662, 0.033601550986209226, 0.08152379804561216, 0.059832681135665026, 0.01151567088410018, 0.026219939520101876, 0.08400710269568429, 0.047322664515025196, 0.0055685197942019, 0.053645169001913844, 0.028717796010295712, 0.035526772074761896, 0.09457602105554073, 0.04802857623285344, 0.015377712589989026, 0.03530691250137264, 0.0991301149910977, 0.00899358590569107, 0.019552086427387212, 0.03671458374047953, 0.024763983674347404, 0.008053734876035203, 0.00628438203655664, 0.06697842370598547, 0.07209887878308374, 0.034673407583707766, 0.045233339732212406, 0.020835000248025023, 0.020607272951653408, 0.017876600426050927, 0.05498394978442981, 0.057728938578117284, 0.009543562341751832, 0.05040159486534615, 0.06898391931768387, 0.057011087379989125, 0.049197170582990495, 0.03747365046893397, 0.1046676742994497, 0.23654453937084446, 0.22957441096584644, 0.178872766273637, 0.1657830815642111, 0.09727975984494533, 0.14850965280446315, 0.17837712270838602, 0.06672299467027187, 0.154982743364188, 0.2626552673116807, 0.11389626054874352, 0.1143645930794939, 0.13221444171522895, 0.10479015643678366, 0.15349382083983193, 0.16567078839627006, 0.14500549003001184, 0.12881756189369387, 0.17919945680806715, 0.08927397249687104, 0.11349245560385528, 0.10984517994426912, 0.2269960501261296, 0.1861608977760038, 0.07283465260820043, 0.17121274504930745, 0.15507386186190192, 0.23030767968345076, 0.13337754704538854, 0.0787646557775236, 0.08802632170338785, 0.12720618021464156, 0.18440807328349162, 0.16912150887712357, 0.15184901474464327, 0.15932993993403452, 0.08321902804797696, 0.16882227493389962, 0.11994260949112716, 0.14116930474917735, 0.096171215296753, 0.24564760977462416, 0.13344002917649286, 0.09724606729803548, 0.12503559265526074, 0.21028203409044974, 0.15333087393833747, 0.1620964826114716, 0.13349495768066377, 0.21513054327618694, 0.14847620540568907, 0.10464378767797064, 0.14236901376035907, 0.16770481312226865, 0.12335389942651796, 0.22219617220182575, 0.1475586925422953, 0.1355808005938607, 0.18653418177798872, 0.14236688403592956, 0.2971246580202734, 0.09914572786299453, 0.0951486028310272, 0.18668905411276127, 0.11129696252605609, 0.12917042199161746, 0.19598281912265286, 0.17959189300815906, 0.08289878031299, 0.11484761151575273, 0.13471293022796033, 0.12457010231070942, 0.19575532165265855, 0.20100840187120825, 0.19786022483341156, 0.10200623888522388, 0.10148811063939527, 0.11867150874628175, 0.11106208762935094, 0.13975768049638118, 0.1948198823318366, 0.10433627998516445, 0.13792706743603753, 0.11679615615116012, 0.14570540327939296, 0.08613554009747121, 0.09633304370987801, 0.13130177052751665, 0.12825229625788429, 0.12053332456778135, 0.2988625437982621, 0.09786279872059823, 0.2586098940622422, 0.14015488176336213, 0.14249342643926222, 0.1649235462349269, 0.11828096478336281, 0.22837767437581094, 0.09810948669309578, 0.1672091389135007, 0.19576570980491179, 0.20817690108331943, 0.19541490282262527, 0.15996138024474346, 0.07018528307878202, 0.21989617707027545, 0.10748711534805837, 0.1439091875668495, 0.153767375515834, 0.1653055636392486, 0.23274520291916787, 0.1943541161956326, 0.15989897472243156, 0.06175544691242038, 0.11387895462253403, 0.12685476802289486, 0.22876948238380496, 0.1733088688624482, 0.19364562276149952, 0.14193906989549437, 0.1084946818469513, 0.12527792924834838, 0.12796627733135416, 0.1397957550662179, 0.11372500159327062, 0.12916515130669842, 0.1991668184317889, 0.15138614442079298, 0.13484376272366894, 0.16143295853849382, 0.14803988768929435, 0.14794014304155303, 0.15840422992985095, 0.1685723004442069, 0.08996273916695388, 0.2783021228688379, 0.13191410460539404, 0.07965252869912694, 0.1370381756174949, 0.15742159959289337, 0.1800328685391334, 0.10673129300196325, 0.12157698912966637, 0.2462890551936242, 0.18790212369734244, 0.09543963963346136, 0.1073771434265279, 0.13586992217648414, 0.09707817912942941, 0.3579367480931744, 0.1317543293079061, 0.19562740029106218, 0.16059637520342104, 0.13723915112355065, 0.13186286864501814, 0.2382424047156688, 0.11739990238340632, 0.07204566631586322, 0.09488752772731167, 0.14561638386259157, 0.1133239392431513, 0.10314888966780517, 0.1820254785519454, 0.11653562496987083, 0.18841881935875263, 0.10646284813241613, 0.14592701719412882, 0.11307036414021447, 0.12497298795008853, 0.17257419054306325, 0.10739026651267083, 0.14287584220930455, 0.14078243034741572, 0.11017439090797018, 0.1665045218842645], [0.05784690079669799, 0.017449129109961853, 0.013848509162574286, 0.0349497469893146, 0.0729784319898294, 0.05844741030746411, 0.022776929714206248, 0.03351548100791631, 0.04221511035857182, 0.014464167104433141, 0.029635138419126312, 0.04301331268863813, 0.0997051559088211, 0.02011141679700344, 0.02732140733109367, 0.043388488927796, 0.01842991317502193, 0.05054908211252863, 0.037393395097986344, 0.05779515155741285, 0.0232185008785417, 0.03691194714197228, 0.07913813896236882, 0.06153535751265384, 0.03801983285454973, 0.08369325179486506, 0.026167391634155667, 0.04262103353657069, 0.05485525084359031, 0.04346545012066922, 0.07370574054338279, 0.020375749689616987, 0.052451990890286626, 0.016982805644792896, 0.07052393990658945, 0.028144779479912216, 0.06237926464828272, 0.035881382683592464, 0.007152317998735535, 0.03564287653012622, 0.03763891095595975, 0.012105821928520118, 0.0874542072415352, 0.06013885200504334, 0.03916842081854421, 0.018805518423417406, 0.04727199162927367, 0.00853538201490958, 0.012566235982963156, 0.026278420757021637, 0.04154800099410838, 0.03442204264443248, 0.03517066376403936, 0.04280669111458044, 0.0999018643051386, 0.03117397157174926, 0.04005239052217334, 0.032984662515621994, 0.028154340257207235, 0.0037010442587592073, 0.033575814262393026, 0.0969010825839735, 0.05919029725895775, 0.035623578775313594, 0.026964927467727856, 0.14133212907660392, 0.06537208288547493, 0.013089467331977382, 0.045409068810723485, 0.028631084433366216, 0.05720577713462615, 0.1505401228824931, 0.026625387723587697, 0.012902188520397873, 0.060927845958259806, 0.0265833122595664, 0.04581760434854416, 0.023515846415032304, 0.04785403842106462, 0.03292396153894163, 0.022215586448568973, 0.044075432308619066, 0.056165406750815536, 0.05163140730151246, 0.0582752205551632, 0.02256710397740526, 0.05606119581047566, 0.05503698222098812, 0.0447462993343511, 0.018253578887050672, 0.03427634038211357, 0.02389998013724483, 0.008000516184350296, 0.014321872975767381, 0.010929161630150293, 0.017660134622166236, 0.05280847458409206, 0.035826787427668615, 0.07681472452297326, 0.05136284368833707, 0.02864414431725539, 0.05642881459226051, 0.036396143972993865, 0.03292047583888615, 0.053430476691573865, 0.04914056051582579, 0.055726649044382, 0.0322651565675774, 0.05302868655792648, 0.038819785695523024, 0.0055067989629723375, 0.01811040088444227, 0.04658587945384845, 0.09075135773708744, 0.02925161182159378, 0.023005530350811543, 0.03184622713184405, 0.03899538070864735, 0.03319990640926746, 0.07178023217185851, 0.10029724228285974, 0.08137097882647669, 0.02710618833530574, 0.03671209778516524, 0.014867250011452745, 0.01949650291804104, 0.04250787468927522, 0.04182805975658759, 0.06260817555049736, 0.13308877786321024, 0.09820247444534495, 0.029598975238660653, 0.030944989806401636, 0.02945803229757134, 0.03230796556078619, 0.018072799373898777, 0.06770393961379606, 0.035280788903154676, 0.08648970254486607, 0.055289312431048, 0.06562626319787195, 0.020671704776525017, 0.017804515382815755, 0.07123804110432826, 0.03877316924533056, 0.026597260805447737, 0.025340068386867646, 0.08510931935762206, 0.07705129247399108, 0.0423376499525001, 0.02585188789863981, 0.008459958743544356, 0.013990204785049204, 0.0147942389594391, 0.03982260627972503, 0.037234504632050955, 0.022915377123882214, 0.05422874030867412, 0.03360736559355452, 0.042315973494682586, 0.04364267690107227, 0.031024145841177915, 0.017497337107817014, 0.03490922476855978, 0.0695125199854374, 0.06651081129788391, 0.055979787477201996, 0.017803525214173624, 0.025735806425913207, 0.05064187068191748, 0.08206885428197923, 0.028360358537024552, 0.009675638772727502, 0.029734538327301704, 0.06953721099923696, 0.0062968084614934226, 0.0439385247356709, 0.030392263114692706, 0.01015555168006329, 0.036324009134043614, 0.13844973858325713, 0.052656272065735636, 0.010632614740320753, 0.011688846016993687, 0.0350327372941519, 0.04975861344005793, 0.013083815518316003, 0.04169800484012212, 0.052697644644086404, 0.05884553854083342, 0.026620032768996976, 0.04615341515971288, 0.0508658939431752, 0.055706087244494315, 0.023636809783056382, 0.046485954775444926, 0.03531657287009782, 0.010070005514388605, 0.02538941402529036, 0.052436726588395335, 0.02572360073005961, 0.025885256773401654, 0.034580948432126356, 0.05507467374686272, 0.10536630818199728, 0.04032014591258861, 0.015011029393081705, 0.023573889066615415, 0.114996132981633, 0.03969622092441686, 0.021387728854953762, 0.011296107212171681, 0.018378736586460186, 0.07241113622102045, 0.029031539658805536, 0.022842232964091727, 0.036143557123479345, 0.039176663924609466, 0.01868704292592743, 0.02683913200012138, 0.05107320116592511, 0.02432818306730159, 0.039431261754925215, 0.03533397838773747, 0.03250299239410989, 0.03549600215328317, 0.08397479676791737, 0.043807466244024616, 0.03007474839837561, 0.026344537975326664, 0.038036545062617916, 0.02561169635174015, 0.06838470066507017, 0.07179625873123446, 0.06209585042069517, 0.05831720983429302, 0.0024323164712592603, 0.040318824410919225, 0.03663113761332728, 0.10264463527428527, 0.03374854027624092, 0.08408526664659863, 0.018288633155245936, 0.033505858943587354, 0.062266098140108014, 0.025147724776498737, 0.03683942159818065, 0.07105184343433188, 0.019549192530253244, 0.043532632201189, 0.03941641880139228, 0.0527235230941686, 0.0709489731478595, 0.06806274455401205, 0.01908943060815575, 0.04762199421923968, 0.032240852428179596, 0.10478057267685091, 0.056152900365451654, 0.038907675132636106, 0.03346631731537562, 0.03882897875061439, 0.02643897937941215, 0.024523378439968633, 0.03606326344813551, 0.0033065568582500305, 0.09002070137930494, 0.029725167156767943, 0.04235978989351181, 0.06323215033438417, 0.037512694139994925, 0.03310936247749675, 0.032858005199100704, 0.02842004253198543, 0.024912369159621098, 0.056302448389150446, 0.09495233110482655, 0.0584677767549311, 0.014726058091788043, 0.018325315360280297, 0.017537903378627474, 0.035804842839077596, 0.07544173408419856, 0.026110532588415572, 0.04108699226391412, 0.04266363568603993, 0.06955224930519058, 0.017103035483629476, 0.03262268980183909, 0.10037008192270033, 0.10802139272733081, 0.02340239836954542, 0.0574787917186416, 0.010110401330635914, 0.07570386638924961, 0.053939936652539246, 0.014472168892802251, 0.06157897472862275, 0.07238551824083252, 0.07845437484643153, 0.031945699818372246, 0.035976094133671255, 0.06227953532229989, 0.04001243520648249, 0.06454807871411886, 0.08828859956514451, 0.07479108028834866, 0.049876958702600775, 0.039090835264012705, 0.036122286692261696, 0.0352397725556887, 0.02238039111327981, 0.022302388040829572, 0.023406703783679875, 0.009612180837129634, 0.06771101826621641, 0.08235809077779133, 0.03858106120699837, 0.02141721749437913, 0.05833556147051915, 0.007122889688734206, 0.015163147641766458, 0.02002176727288433, 0.07006233362781425, 0.05122221292807691, 0.10099153244687666, 0.0549355904842096, 0.05793303972290409, 0.026907924780501958, 0.03681327884776458, 0.04793967555968031, 0.02526666567240271, 0.016183536537292025, 0.04278745464680176, 0.005022683105761967, 0.044957475301118634, 0.03140790226508773, 0.03195821386461537, 0.035534635967304634, 0.036658797217833425, 0.02386766080293925, 0.06738160045877581, 0.018785286041337158, 0.06666107178335229, 0.056000322464012334, 0.021817080916896946, 0.1441730282479717, 0.021398277885671106, 0.031941641467593374, 0.07721846818082756, 0.01337003171248662, 0.027975730688100862, 0.16564452690222572, 0.13206591258846945, 0.15476091494483335, 0.10668836909556582, 0.12587082767558674, 0.13828936573718825, 0.14829914716462936, 0.05133633321571735, 0.13888112269341946, 0.1261286315838656, 0.13084787875413895, 0.13499716416962687, 0.1726297012740566, 0.10048335568318445, 0.15149178794555127, 0.13953830355838423, 0.10618481950293626, 0.11778170528310923, 0.08521478668215775, 0.24033256836475866, 0.18643354846825524, 0.15055411164799046, 0.09729550295178929, 0.1613611148129548, 0.20270285046389028, 0.16572095183355195, 0.20346434186062506, 0.12238292128688867, 0.2506498115197305, 0.12068008403143576, 0.16782216247050993, 0.11420520848684734, 0.18059733744350173, 0.16317884227441204, 0.0807096764084793, 0.0941828647328, 0.131242306782834, 0.2652698028231821, 0.11964834745853178, 0.14609906522016372, 0.16853039543474876, 0.08666981747674365, 0.17383851140977877, 0.12604077662070914, 0.13731690904786512, 0.12267670068409174, 0.12377693317830564, 0.08086235007090915, 0.0934862303397348, 0.11625108459303457, 0.13607095896957383, 0.164156278535243, 0.12050779085726508, 0.1916401424715596, 0.1335556012007498, 0.09752258673430451, 0.1263069002438457, 0.18524831851884244, 0.1289062135882916, 0.10801648210373618, 0.13594732770035345, 0.1266053068121114, 0.19305504558067169, 0.3667471575881205, 0.12845103478720113, 0.31854980835510843, 0.1807325826056542, 0.089960471546698, 0.13584758305261213, 0.08262475832335411, 0.11016803237819865, 0.1584617937764814, 0.11577800231715364, 0.12134945335527583, 0.13658825217956497, 0.1350556779652834, 0.12978168354640085, 0.14046738434943462, 0.1541512928182079, 0.15035577148439425, 0.12970162735831353, 0.15977920453634956, 0.2216356409893882, 0.07839959189896623, 0.25481798866343114, 0.10760215111076833, 0.1392411533743143, 0.16647718786712618, 0.14771387131223757, 0.12043800024736313, 0.15128238547232845, 0.0815008613731592, 0.15436112430066834, 0.1767547170241033, 0.1057039078084692, 0.1432723846406706, 0.15611990895723143, 0.11492854104407373, 0.22474802639936248, 0.1699385416483687, 0.16492156972808225, 0.14682347796136333, 0.12324657050832627, 0.08220073631814412, 0.11609909274885732, 0.18793167936946117, 0.13263873185121244, 0.12138179758743894, 0.17780808791998895, 0.11921571462505287, 0.19616189983583268, 0.18622082117344105, 0.13271855821292247, 0.1966744279789348, 0.23319901808375315, 0.10050726528730124, 0.2186987356793496, 0.07679939510360842, 0.17666001323490374, 0.2159393176196083, 0.2522242447781948, 0.19191457048779537, 0.13760837485953686, 0.13146395134108682, 0.09807826094930211, 0.138384927544863, 0.13798263945406483, 0.20426640527382975, 0.12833128758375684, 0.11377909506160407, 0.1549861447945718, 0.11565751200842282, 0.1356456269540133, 0.18281523859308613, 0.16126504738725003, 0.0777791066455745, 0.124170487866767, 0.13234490648873393, 0.21307683009053432, 0.15250166036909626, 0.11066470250126817, 0.0642268312343907, 0.1315221127362982, 0.21636164657050566, 0.11145145181686648, 0.24021684312291686, 0.136630279763091, 0.2703075357262166, 0.12972770499125605, 0.16395844398967682, 0.12903661707476263, 0.09983954305249838, 0.11750205254722988, 0.12706842228409745, 0.14885995416871964, 0.12654025062558152, 0.12182792122926443, 0.2856497947246798, 0.10258591463488918, 0.11035267488970874, 0.1556641785728355, 0.21566755558934905, 0.18905533117152032, 0.13033717390029662, 0.20680016447459498, 0.15954989909885392, 0.09674737470284586, 0.1193001221925501, 0.1638815134403206, 0.15187284007908838, 0.2211743028413865, 0.10737349684800833, 0.1149056809804132, 0.19288036221217728, 0.1344566738172885, 0.13010322596997986], [0.07144411109508046, 0.03192667593999255, 0.0026495464478484207, 0.09266933546431604, 0.057864122453235814, 0.09255485894579081, 0.06931225694115124, 0.038134025920542984, 0.02063546498726693, 0.028160070594880852, 0.029558922246759458, 0.03281538006699374, 0.05468614076474502, 0.05673634526770442, 0.05029167656997039, 0.015428330891975954, 0.03093885727256777, 0.04397517055152886, 0.037753743705369776, 0.04735247682659857, 0.09632361316753012, 0.037625833835092284, 0.032516939024771416, 0.028156713214552695, 0.016679444402876883, 0.13750882939465586, 0.030433560999470855, 0.013386064017521999, 0.05723432923156408, 0.04640631227483673, 0.0189304405507902, 0.05226150695835391, 0.011790009842614734, 0.010768186447450952, 0.03500962442147636, 0.054555243151562835, 0.0896778540505517, 0.05810569295839918, 0.0409517930670371, 0.043138181189856226, 0.03957235599837957, 0.03481441755749045, 0.020825548638259212, 0.03488618467423705, 0.025563637741030227, 0.04106418582640829, 0.060519777734072945, 0.033794923069616484, 0.04241140889784983, 0.0458449958222768, 0.10646431902123075, 0.07124931025769442, 0.02892016005071421, 0.027354481262004664, 0.03094044498979084, 0.05969131493099755, 0.07719593753497447, 0.006604195974256483, 0.008148355353172989, 0.032980996784904314, 0.02090399221126591, 0.08783486867023092, 0.08187641299539998, 0.07961317476245665, 0.06896011696587648, 0.03944668310484098, 0.09218276238008853, 0.018282257388496113, 0.054384508966318065, 0.02078902156602952, 0.0504926290933884, 0.09727534717850148, 0.07144070966469665, 0.032173873360959754, 0.027290265856971665, 0.04653190472914327, 0.058745989245512796, 0.019517813568874713, 0.08327713581703364, 0.037243678534944216, 0.054446753610165856, 0.0700155409773992, 0.03771764564237768, 0.0372996948839676, 0.02632603503673548, 0.06484972583430429, 0.05914210266764126, 0.030157773177169507, 0.027873691607026324, 0.05357812481722044, 0.02379287913021061, 0.05172800715832461, 0.012736338145670392, 0.01721831447925539, 0.10466510790490335, 0.02592353818697795, 0.04993243495963755, 0.0367419981968499, 0.07731912447319877, 0.05586711126529882, 0.018899586359639804, 0.041579720864613215, 0.04666954391605912, 0.010590575665475862, 0.04303486657238776, 0.04207898802574604, 0.04827802212187841, 0.02408868482997341, 0.022569362021562074, 0.03643594990153948, 0.036115778775344935, 0.026688948123445435, 0.023345087331929998, 0.025406444159847115, 0.012767193294430693, 0.05670091753164607, 0.033015819311502485, 0.061700713760670156, 0.04085990465095928, 0.015736172790639102, 0.05265963519172323, 0.007855954435428665, 0.08668115557802301, 0.10499548332224931, 0.028508834037629348, 0.016209918690184434, 0.04736493724668699, 0.006685419010013463, 0.018066082698022647, 0.06544227952197676, 0.01418775970852303, 0.03481524110200905, 0.028493270961447593, 0.055039004693108226, 0.01606271106509432, 0.05662978626787663, 0.023493781167593215, 0.04892074307727237, 0.021125682734794194, 0.015404753578496317, 0.03766775033586929, 0.02827409703675057, 0.03326981959323729, 0.020491361933489962, 0.01137907166154154, 0.05606660439122108, 0.02143966770100017, 0.025819015065808932, 0.02665656941732572, 0.02821658490105502, 0.07076687404825803, 0.010196630272173114, 0.014091114844045332, 0.05242091453363819, 0.06858795911314026, 0.01718868028312441, 0.022740793346817938, 0.015065104666826947, 0.06125033066998567, 0.02869222208016342, 0.08629651049212103, 0.04416514120455231, 0.05129104209763389, 0.03602148101274525, 0.024750600118310224, 0.0317093406263138, 0.010789065216217312, 0.037600319276774125, 0.012686588395867619, 0.10903892603011862, 0.017413507936702623, 0.007118117918575844, 0.03329250728711486, 0.05891135698484798, 0.08884760626261273, 0.05911497549424249, 0.07450952765441711, 0.047995274390784964, 0.021187555825998707, 0.06281406934102697, 0.04703337056261878, 0.026102423547737064, 0.03553717554877362, 0.052984728432831266, 0.024524535232734297, 0.06338997593810482, 0.026296004390103683, 0.013398213214391183, 0.03822884462293118, 0.06761048454791307, 0.04756518496921466, 0.02068583335306856, 0.012948429587507441, 0.02639052814864103, 0.03684851123140224, 0.06525493272009396, 0.018899804694698225, 0.057229108342360106, 0.018099212170308156, 0.020070235740633744, 0.019139657247691386, 0.003584564899116935, 0.04017092730669726, 0.02761457768839694, 0.040283691618711724, 0.04549279072952848, 0.0313935074729905, 0.015910114969066795, 0.009552568662911654, 0.02581698493280959, 0.0787673217635001, 0.018342391460112507, 0.049772835862372196, 0.04218635141789433, 0.03690498340274057, 0.026386036958184936, 0.035368023335092494, 0.03314219700593141, 0.027634482567889557, 0.04345222361265652, 0.013233476539983625, 0.0929941107789355, 0.021775070570349213, 0.06818932526174092, 0.02223657725769426, 0.016839551033392068, 0.0020142910192765657, 0.06370399537826739, 0.04952110320089325, 0.053341832657855366, 0.02980953450464914, 0.021599623029150312, 0.03234051663668887, 0.057658002666768536, 0.028026648721988165, 0.022235753713175658, 0.01747378373458501, 0.02687348529786593, 0.019407418383766088, 0.06601712125683985, 0.06950272172088585, 0.054511411430975126, 0.09985125653686062, 0.04701488103056627, 0.05169528754307859, 0.02733747794052526, 0.06562967995001424, 0.06439214917801081, 0.048025396967967676, 0.047912529234083436, 0.041944857521523396, 0.04768619621773401, 0.014550181541351542, 0.012869612546637656, 0.026958097793882894, 0.023680823449526104, 0.01174174726099497, 0.03488744105843287, 0.08424033050335224, 0.021899531129747633, 0.06876128650600873, 0.00519724294257861, 0.02741567253495657, 0.01574810077962015, 0.006807355309701375, 0.03608521569760577, 0.027965030355018475, 0.08615938075367482, 0.03917826121793159, 0.04260386933662719, 0.03453139020430465, 0.022679255419080297, 0.10087969893169019, 0.019438381742445693, 0.05682533404098884, 0.07251078893821086, 0.047846507776768944, 0.014835535886607345, 0.06656309679871605, 0.01588387071200076, 0.04300614593610649, 0.01768117331178679, 0.04683206180831598, 0.029535449312759504, 0.01918973258486198, 0.03720117214646551, 0.036664454777154236, 0.008358672343855424, 0.046968379493562445, 0.026501434697439114, 0.03874278236781398, 0.01633006425934934, 0.006158896355754546, 0.07589885108773747, 0.04611852368520153, 0.023761166920585018, 0.014595252409156774, 0.021263536426328847, 0.043507282351774555, 0.024718926213080847, 0.07109462944490295, 0.029520910879176472, 0.03297921180004074, 0.06485197813280168, 0.014581792244327166, 0.06105691262130296, 0.06429971300906713, 0.03258161216733917, 0.014015456000643392, 0.013599047951790835, 0.05867110415091438, 0.033194467185005065, 0.011992223538278092, 0.0317915418605891, 0.03907689629423042, 0.012430568514842422, 0.06169756896974099, 0.0385919128424458, 0.01379113109226549, 0.00840703355929544, 0.09743788805339607, 0.08271405353180825, 0.012606967920287242, 0.03641427727416158, 0.007900133289607062, 0.017453670096133026, 0.08309163528704837, 0.11483431989026648, 0.02779042551053628, 0.028890079608367338, 0.04556656116619707, 0.05276378101458954, 0.011792633693755395, 0.043237964141993754, 0.1381603718524979, 0.03701054265782718, 0.036174671784524, 0.02030485399788426, 0.03553975726507845, 0.0400921696376416, 0.01797111843892884, 0.02769042805377995, 0.04856477649281583, 0.01254805480130017, 0.028103316886230346, 0.054833777399072726, 0.04523074652458872, 0.047056031443419, 0.02813550790080861, 0.027040314349916675, 0.10438854250335887, 0.0422380508614644, 0.2571526416126759, 0.1699031637080254, 0.08264269244166152, 0.20542534308568125, 0.16542384761475748, 0.15853530757369536, 0.13618047889922896, 0.15799732998974864, 0.11933629686433463, 0.10774128799957615, 0.1740953960125485, 0.1266608022213463, 0.13521652578586532, 0.2696966265718783, 0.12426771974611668, 0.15535159937797055, 0.1141292432082757, 0.11546198338750871, 0.09564179491492049, 0.16996074287641436, 0.11167427615052271, 0.22899958455274183, 0.13791744537170858, 0.11503228467077979, 0.08671372963656342, 0.20275800879443848, 0.0813555881200779, 0.1539245154708624, 0.15460585874895896, 0.12447655531427554, 0.25713309104884824, 0.16991295431169773, 0.11374198576255191, 0.0910170370292279, 0.14368487702262017, 0.05896656511111125, 0.14885282955102383, 0.18218382892589416, 0.12032882505727392, 0.10597391549738185, 0.11186592836653995, 0.10089656818778285, 0.08677205957111814, 0.1562001336846621, 0.1104339414967164, 0.21026381651961037, 0.10515836893670982, 0.10260911177723639, 0.19830136890372924, 0.1346670722048129, 0.17786362929449928, 0.08772283597218414, 0.1266131592133353, 0.19633433090582972, 0.09845144535985687, 0.26844591142669805, 0.11136333638381575, 0.10256473230378282, 0.16241681461613025, 0.10696562397624217, 0.1231930286232983, 0.1544517525021107, 0.15076213516294956, 0.23617954444020028, 0.15202999535587527, 0.11502642409815905, 0.21750855680194595, 0.11438209818856371, 0.20488949522616404, 0.2070037446795933, 0.14268864096412737, 0.1760721480053279, 0.17416285771516063, 0.18111709745660906, 0.16010211059643378, 0.1836315818851994, 0.11786065830458557, 0.19041155194563253, 0.1411711740037126, 0.12105367446859037, 0.13302683199365295, 0.17013931797156412, 0.268066943052315, 0.14543082204557237, 0.19587035741536848, 0.14442625095046338, 0.1660024125369326, 0.15672695702843129, 0.08520213857052789, 0.13809738410336359, 0.12724609339549658, 0.153178024075685, 0.09181116377153704, 0.15073596559945615, 0.15305531211197376, 0.15684591516131358, 0.18163809853215374, 0.13407154609599423, 0.12307907304456159, 0.1570284892354281, 0.12516129236187667, 0.0706996651546609, 0.22329258191729748, 0.08081813913679893, 0.09503331425930224, 0.1342253152641558, 0.10781482477942783, 0.07877146629917045, 0.09318256840830849, 0.12953310333673032, 0.09531623819061825, 0.10160590431863263, 0.16147558367060078, 0.13241291977465153, 0.13122316990648547, 0.15905663040616821, 0.15192260515064965, 0.13563304779029664, 0.11648303303386896, 0.12402849347000161, 0.13373730193463065, 0.11301499896592672, 0.24536398870329706, 0.21729500213217354, 0.22446189255964374, 0.17047864895674492, 0.16862555887670289, 0.13066057025665237, 0.07380451992033951, 0.11787303062456271, 0.1592808796633636, 0.17129050297362192, 0.1303322096505473, 0.11134773117279816, 0.21001290740265002, 0.12686555454086873, 0.14501327348332252, 0.13188651011836144, 0.0914261662851899, 0.12696930582845403, 0.1465273390133535, 0.08032655583754664, 0.11704212400100886, 0.11273203673021448, 0.13675384974527743, 0.17891114727864343, 0.19189722625718963, 0.11888252000414556, 0.11975167739775874, 0.14237232326019195, 0.1489967315067207, 0.24890755904057335, 0.08914663336209713, 0.157941022527314, 0.135690136662414, 0.11122128836089566, 0.14508743079439287, 0.10036542410812072, 0.21607237177029734, 0.12226347285773485, 0.07753960457780669, 0.07551501039415598, 0.15144972971850826, 0.13165346617179532, 0.10295578954561103, 0.11504550734835287, 0.11902236169384373, 0.07229061526877266, 0.10763908420959789, 0.2095132495366758, 0.1412248614454462, 0.17950632098701694, 0.09374742801751822, 0.19263063287062032, 0.20449828476675097, 0.11891949140737135], [0.0884513013185032, 0.0741283682685706, 0.05502622251609161, 0.033506559914038066, 0.062276700796980056, 0.07664638436249188, 0.020133583551092495, 0.051165384525853785, 0.04184698212831732, 0.007676002297234992, 0.022331951373827555, 0.03680557200324632, 0.0662400221992885, 0.03804282698359701, 0.04312475549898321, 0.06383449079528933, 0.044414196388735894, 0.026330194894164324, 0.00795253801287242, 0.06799201931684248, 0.05849141439783478, 0.09977171362768258, 0.03439857354087215, 0.03737583253232222, 0.02934407671883462, 0.03987846558072394, 0.061343632518283786, 0.07507302362712161, 0.010224363612641972, 0.0449079477168139, 0.039307986716589624, 0.014623851428980069, 0.03793117732951238, 0.14296789533428608, 0.11295387281044839, 0.037671067496581424, 0.06286083900880429, 0.04787846130409068, 0.0451627332386711, 0.027449363166646614, 0.031192526221275333, 0.03505247554952099, 0.021898424132697044, 0.04172094151257508, 0.03799332238193001, 0.004393818765698422, 0.06063826089244216, 0.031948972929028735, 0.016187119913557847, 0.04902512255695559, 0.09858570226858701, 0.04173591853149476, 0.03556008923858885, 0.026159905039915637, 0.051717373857935595, 0.020011528507776318, 0.045423597668207465, 0.07436476001936583, 0.07729936706563158, 0.007161628839845259, 0.005523672049504615, 0.028466867741137266, 0.014638557444296539, 0.008536564663142688, 0.008658877303523403, 0.023760831757118146, 0.026249554564034747, 0.04286435455264103, 0.031524924110741384, 0.03773409355011198, 0.03561237473942099, 0.08007072077523317, 0.1232580311836735, 0.04738839102848884, 0.01717147777878469, 0.08570362738664113, 0.06600598233842081, 0.011934225894360533, 0.07327615673984252, 0.030302014126772844, 0.023842462255889853, 0.06787794882491713, 0.054164607258092974, 0.026669309459506508, 0.03713310906483281, 0.04013903889684908, 0.01578048714661911, 0.007428762741431955, 0.015172734274528922, 0.013406678485954482, 0.031964536005210493, 0.014704651679963836, 0.05595842511543343, 0.0584663633227108, 0.019685607891710057, 0.07843484726524161, 0.07335588351012239, 0.02124346875315232, 0.04008999777837627, 0.05962040200228653, 0.01735420698570388, 0.027149671485887903, 0.11649779554816986, 0.049031415969253554, 0.036888298007749745, 0.03696091931253191, 0.011225952710505697, 0.018464048137708057, 0.039643847323473425, 0.02399516847705649, 0.01032311138847182, 0.042414032748990485, 0.037623259779666705, 0.09483855172631242, 0.04990425441534289, 0.021103100378006216, 0.02745241411180506, 0.015232446997786964, 0.06957308689673102, 0.03602859030868258, 0.020225085092768557, 0.01882558418137412, 0.08533785870719342, 0.04117822184437706, 0.051352727497296954, 0.05300138701474475, 0.048413550736562866, 0.030597768115600756, 0.03200366203072331, 0.06045170316112138, 0.026610851205224474, 0.05162743896606469, 0.0770991882910171, 0.024893653631630926, 0.05363085464904866, 0.03737570229737509, 0.07262491305629093, 0.049459402479471705, 0.021294725780946114, 0.02765808382161683, 0.07633334551487239, 0.035862058115702485, 0.02106483620140822, 0.04683715246257283, 0.06541301496326923, 0.05137234317859815, 0.035170617798763903, 0.05806147819384933, 0.06184362363250506, 0.02327898926582308, 0.0518513358228149, 0.0326737878663886, 0.01112479463054408, 0.03625997567489263, 0.05245986627414823, 0.0020565615963160752, 0.03451675026407165, 0.07047901651070965, 0.08745161786435113, 0.025395487187310092, 0.0749817825553398, 0.008397346377492914, 0.024371892213821415, 0.05007908334054294, 0.024014295777305964, 0.06964400365588165, 0.01387269455834382, 0.04395066339883112, 0.03451658172472831, 0.08382159450481977, 0.015382880810648205, 0.015365699373726404, 0.026889559737737143, 0.02366873458208096, 0.03906349358599513, 0.04152321804975791, 0.023180600593707735, 0.05209969003654776, 0.027412759485624494, 0.07181274494336498, 0.04279367911118654, 0.052444169132579724, 0.04688775256997155, 0.03787216940714467, 0.05557302543292603, 0.016893372540512396, 0.010316409076744271, 0.0060964745540742675, 0.03023874292510652, 0.07465078660677518, 0.028634995312219667, 0.017883692485009952, 0.014517501188111643, 0.0502385598637404, 0.04929232636406537, 0.04520445821746703, 0.04151095298209018, 0.05603347491893557, 0.00924615934866691, 0.026225405557441617, 0.0277272692220586, 0.053194199853967276, 0.0244313272302069, 0.026250747745976816, 0.019283970975647532, 0.09888119004186123, 0.04764958870627227, 0.03340069805422137, 0.0383072920263775, 0.023812473744093895, 0.04798280247937768, 0.0677458446232542, 0.04651761335891582, 0.02768474751182141, 0.030078839307891268, 0.0078865917279355, 0.04731082462615544, 0.09292739218160992, 0.042384312367968024, 0.0210682510383307, 0.015624333529793208, 0.039900988565697786, 0.028116455294131756, 0.09607303346837721, 0.040408422224103444, 0.01907712149043237, 0.0736747063215702, 0.06881295913650144, 0.02976457088915331, 0.049053954275985884, 0.04311556627433147, 0.011939856640603996, 0.04107866105773757, 0.017976360395550728, 0.05344202546703239, 0.01241247256046101, 0.016811684585146366, 0.05021060148494379, 0.024071830895639235, 0.058179130146820704, 0.041158931750443675, 0.0250944203787273, 0.043916223916195096, 0.01607658874784266, 0.01455562172322384, 0.041572071476689273, 0.09061245067465691, 0.07888266396137976, 0.04633368713961494, 0.04649050150727553, 0.012782976620890682, 0.08010088931769133, 0.015285173956785473, 0.02119772181275391, 0.08331755461591868, 0.02519509965373624, 0.01591420875141217, 0.07398815885666879, 0.03521628429993026, 0.030949904260435895, 0.07513288573752488, 0.016175617103374774, 0.029343463848495198, 0.03891292283491742, 0.05197457255675428, 0.0419738347972593, 0.03804282698359701, 0.0346005181481521, 0.06488585454081336, 0.04233237160670181, 0.0563143419041749, 0.05739352613266918, 0.07633313101025359, 0.01831713545646879, 0.0406215517150779, 0.05996319570488507, 0.07037878156669679, 0.0321090221029496, 0.06872220836099117, 0.01823388468173723, 0.03973303911005778, 0.028143636093685226, 0.037493932646729296, 0.03651658831644924, 0.06599495833319041, 0.02936592937687472, 0.045694306327570836, 0.03584698916623189, 0.047829469981332945, 0.05015846154081726, 0.045586559891460404, 0.029750292925464532, 0.023275005608616818, 0.027745933039113883, 0.07355439987394118, 0.0714118664543475, 0.01471243609088443, 0.05567202314494118, 0.029245291596218467, 0.026321733453040643, 0.04849156530033197, 0.029725090547975515, 0.04335768453236069, 0.036612655742154006, 0.027910505962227623, 0.037342377472668886, 0.05111856123192176, 0.03330564186457665, 0.03034775532151182, 0.013151771347639302, 0.04459578987030734, 0.022250096794338, 0.09257739725252313, 0.0356224871000215, 0.028710133215833097, 0.005664334410891658, 0.04401817106671872, 0.0761065528457684, 0.030916769042490955, 0.06684032103587544, 0.06084991566416237, 0.031403481937764634, 0.06079668404474374, 0.036863522724278515, 0.038169453656601335, 0.04684853269868801, 0.016761084477747643, 0.031887858264869264, 0.03812702004647544, 0.04728648218236143, 0.08120492160800966, 0.05858307298753531, 0.013739130001575237, 0.029130487575105606, 0.024549383294558334, 0.007576671336972787, 0.037099519939792734, 0.004867103576074325, 0.026872828377470858, 0.03739661266726833, 0.03128894221698565, 0.04013906187948681, 0.008844631600133594, 0.05729226846127741, 0.012528044584717964, 0.08734500906880825, 0.04232627737726416, 0.004733054468693633, 0.003990378909586599, 0.03779168804025939, 0.005230731518578626, 0.017906203978664933, 0.16178436306936128, 0.13293484015570534, 0.15386399452484426, 0.1478614964552464, 0.1736174490783484, 0.11920511962906008, 0.13971117895937737, 0.16040390327332482, 0.0931829437913914, 0.0888372564147557, 0.07671411419587751, 0.08864246323824891, 0.07884172422270622, 0.177343302376328, 0.14822934123296894, 0.1598631677728507, 0.16384630403932066, 0.14445910080065652, 0.12979879795062926, 0.198692349536765, 0.1572642910985216, 0.1746338026057328, 0.17649490596546283, 0.18867210334827825, 0.07962563135210546, 0.13955575504129933, 0.1580996793364325, 0.17073104428427835, 0.17083412907536955, 0.20755327486943817, 0.17581348607857383, 0.10497007218580093, 0.151829065815095, 0.20996613007399345, 0.15099589923216453, 0.15502262590152605, 0.17340469114001722, 0.12651788085819254, 0.1760187057117301, 0.16509479752952055, 0.08736851264632518, 0.11179917146481815, 0.15680469963098728, 0.09399291323197466, 0.15506882100336014, 0.1776898499097555, 0.16658489982928001, 0.23185586676962916, 0.10533241645222712, 0.1552684022293937, 0.16931007375880597, 0.21102071138879946, 0.08887987388598342, 0.42660580527397896, 0.13685488142073154, 0.09950856242569224, 0.1145999429507121, 0.12079473675018358, 0.1711145019338977, 0.23030760307465833, 0.10773757247314339, 0.1138404893478559, 0.10337788100925185, 0.14416349811419366, 0.10024024534129328, 0.09903830701425191, 0.2122660792402683, 0.10754261075729325, 0.12939703079961962, 0.1547533153526245, 0.17853656092718725, 0.15414882601509172, 0.2870327060020739, 0.1612504917166887, 0.0929819223200602, 0.10660404579774027, 0.2315661169949078, 0.05677367290181499, 0.19267829886126905, 0.09076204466363115, 0.13060979394903108, 0.17745291423653403, 0.09615380977911335, 0.1672704872344771, 0.2568228560830316, 0.24907723219404299, 0.07561818711579808, 0.09054753238395338, 0.1668234902524179, 0.08780616335570814, 0.1701745733378395, 0.16914063043171362, 0.2124012937589038, 0.1811980729502055, 0.12151184101258555, 0.21074369399537965, 0.16402710078945085, 0.09800524510923894, 0.1584580552674109, 0.15699298872101694, 0.22035973687325755, 0.1444079108055561, 0.2086276365744491, 0.12315733658690607, 0.13993830870716803, 0.16258250411239364, 0.15157158366374432, 0.09510529588066763, 0.1654282296376844, 0.0857395798929276, 0.12565491345500754, 0.12014572238249165, 0.11305069866319818, 0.15559236549081343, 0.1200761999033632, 0.20184800359270266, 0.11513091849103091, 0.10164202536426245, 0.30634486326767557, 0.1352307290559815, 0.07183692267825527, 0.13394488111859368, 0.17020107998001963, 0.16203396983685034, 0.19676563840719963, 0.09527225708288532, 0.12152376900156661, 0.1760725770145655, 0.16543422044525224, 0.2513639433609863, 0.07975240358181539, 0.26077142646235807, 0.17973234756819664, 0.11411976670065235, 0.15461598643131796, 0.1617412169974658, 0.264126401274435, 0.09804132785047255, 0.0921264855611709, 0.19290647048863674, 0.09382950667772563, 0.15393404560464044, 0.10333473493735637, 0.23653326255659904, 0.17174485439975418, 0.23392879344042272, 0.10832215884640332, 0.15695008779725722, 0.18698877835225675, 0.09700970619075722, 0.12458564623469308, 0.1340825317968284, 0.14297894232215422, 0.14981040881285745, 0.15965526683195946, 0.16500329598784447, 0.11547067082457005, 0.10912893370034234, 0.10608235524306375, 0.07816496215039685, 0.16051457233486638, 0.16991061008264943, 0.1173946163767288, 0.14921255379674897, 0.08520762376006573, 0.2229836646227106, 0.1755315657224386, 0.15255251328551, 0.06216426207233341, 0.2110809565431649, 0.09107411057958681, 0.06972240509405252, 0.061175778823634314, 0.14085274189710617, 0.1185819224244164, 0.1559534227295268], [0.014954077459180789, 0.05890576837344035, 0.05938339738115188, 0.01954937447613526, 0.07635190016439847, 0.04510359125091665, 0.07106755589765888, 0.04348520752823642, 0.05786768859252334, 0.011918553650649566, 0.0554035859362733, 0.027019168407986724, 0.05536160814846235, 0.05018363135956949, 0.01078717680948396, 0.040364736060221354, 0.029876034766916307, 0.018595878462938052, 0.05631463684802575, 0.03559917121404602, 0.02329344151451463, 0.04028561832984129, 0.007464928794727331, 0.015418929077925221, 0.010436127551891392, 0.06935676664955194, 0.046658684619732445, 0.06346664984800643, 0.03219316345489314, 0.107426556097644, 0.010773455217150191, 0.021030274144704306, 0.013118090292048312, 0.03302904198907557, 0.0743994944458527, 0.05474342881972271, 0.08066004157186517, 0.029347221509763793, 0.023704317450943976, 0.023607840168199713, 0.01167402221565886, 0.030076163745815718, 0.02138888947815905, 0.012994160248537459, 0.019835512146293637, 0.04088837630866517, 0.031128289748824416, 0.03575405504013743, 0.07097910338592145, 0.0340561552213565, 0.05835229283078544, 0.014552230826548994, 0.060224332095634554, 0.0403786865213225, 0.04591857473696432, 0.02166771100864055, 0.06123017106625823, 0.04361889370146298, 0.07420009708092098, 0.02697414350545695, 0.023176660986557122, 0.056848535013775674, 0.0661724609052462, 0.04869277063276499, 0.03126583125952992, 0.0284814425638967, 0.01448015440180297, 0.013769472829036176, 0.013105770640615976, 0.06338523768429315, 0.03980178400994309, 0.01939942425627622, 0.05195603322898669, 0.042554640526612925, 0.054448071281395616, 0.059080447911495165, 0.02770672657436902, 0.009139875182881951, 0.011501398666070835, 0.06870426658180452, 0.011942735215979479, 0.046730095505594246, 0.00787694859618862, 0.06970620999533324, 0.026998685132111275, 0.04227609861822378, 0.027924171055576978, 0.027304411670493505, 0.03647218202991832, 0.013091095268816478, 0.05607154182789307, 0.025366584605146802, 0.06276540743607668, 0.05126802498594888, 0.05254189513864056, 0.05384838148470848, 0.05414933529532245, 0.05731258511302933, 0.0667455482987627, 0.041797056178291964, 0.04230334453525082, 0.0375214237118921, 0.04659808323448224, 0.08350425024306582, 0.06954476462617036, 0.028742628750361265, 0.02332144202814708, 0.02979322449274121, 0.10710429355141618, 0.05501090458804562, 0.04353993301910739, 0.043547666676703005, 0.01706407608224019, 0.06718227204175727, 0.03400652038474237, 0.019271774855892987, 0.05084928898741642, 0.07034511200242466, 0.043478151858453794, 0.044402364160745375, 0.011292863787422258, 0.02148771865083085, 0.011710543542229121, 0.06143107762440078, 0.04528601976832555, 0.0945071267685102, 0.019293981829598066, 0.03368245753189249, 0.01663999853565568, 0.04504290559599477, 0.03542736067526764, 0.060509458529732885, 0.04554850064338215, 0.03198856435295555, 0.05919798112083828, 0.06708756825255771, 0.06261616201710797, 0.05208907971879648, 0.03162528162882213, 0.04120662838460938, 0.08339441621736174, 0.09161039510922087, 0.054810308295512394, 0.062176232196150295, 0.07075389651882072, 0.017239877939104073, 0.0217210364738299, 0.05930154088644251, 0.07535728821230513, 0.036212776997877706, 0.07324824815676098, 0.06817242536213129, 0.005795153500061603, 0.022947520257965214, 0.045736429672087395, 0.061389149632304914, 0.05392363430151055, 0.0235541814547633, 0.06602663606885942, 0.023213473426538612, 0.05708800643802651, 0.06979600316093815, 0.11349411801465097, 0.01668025454085681, 0.032504861648645134, 0.09389270893147877, 0.015268683914215335, 0.06480156954738402, 0.02662195756490673, 0.06093770550984529, 0.06979264003495056, 0.06771546157617724, 0.018238626765988527, 0.02409213031041286, 0.02392775465493962, 0.053417399570706396, 0.03880611102607462, 0.0843908054934394, 0.01508154012563248, 0.02700667542916152, 0.06641103600662562, 0.06585810438639696, 0.08683552229476553, 0.06926767828483736, 0.046037808661499334, 0.03963250922219407, 0.016230442185675906, 0.041716084515135136, 0.0028296630555433373, 0.03580506500457564, 0.06376463889835343, 0.023117394509514975, 0.022124571372724833, 0.0745945404313745, 0.0031301988694336148, 0.06463103837543918, 0.018255712441919793, 0.03720410243277589, 0.03314384792540823, 0.06829296929701682, 0.08166666578261123, 0.04588320445750029, 0.010622614420079177, 0.058030846168196974, 0.058413058924939365, 0.03555933081154381, 0.05682591243737167, 0.013101811881267257, 0.015196575888342436, 0.05852274356349822, 0.06996937651908205, 0.030866180426411094, 0.00947667807791262, 0.04726226997351454, 0.018435193436040033, 0.05229522248790149, 0.05495273936239462, 0.01865423904100974, 0.03453990144114341, 0.09043096444539486, 0.032521995205071666, 0.024557417641664227, 0.0300528229619827, 0.03224858225533559, 0.041091960344103076, 0.03833119013917543, 0.048009309121557785, 0.03629002164328291, 0.10210581499362185, 0.054962303970129266, 0.07976395618771354, 0.042936841792036454, 0.01914537609404614, 0.07186289305888838, 0.012911213036145897, 0.028761394074066516, 0.04822184872483054, 0.007441611472336997, 0.039057165699740576, 0.012662965117112525, 0.01031632672229241, 0.03009247184250384, 0.013260769379896023, 0.035527243218835325, 0.038741357444274815, 0.02203167746624639, 0.018031903685280876, 0.038476578305445375, 0.015495422957164627, 0.05017022482089458, 0.0339329146569775, 0.05933615656930113, 0.024689721026187463, 0.02698298990576258, 0.04678158044454552, 0.009055680204783718, 0.01862664838441678, 0.008266363537029154, 0.020956879091118614, 0.07890632075648155, 0.00723397339536478, 0.05762024219298075, 0.014846513926562284, 0.019540924526330446, 0.04070680580973145, 0.011254696329424699, 0.060842561220089277, 0.04418477986849124, 0.05114360464616649, 0.030358988085701585, 0.02382500885775493, 0.07385975485968013, 0.06931238717609836, 0.03563692019651494, 0.06799575782591297, 0.04831693938843185, 0.033629072694889, 0.08095945937619095, 0.05221332385835629, 0.04724785219877959, 0.03940817952576665, 0.02030718290517407, 0.04511835376521753, 0.10167756418306982, 0.047334807008625045, 0.1544335655747883, 0.018900679950151714, 0.03253623677958404, 0.08561332094212694, 0.04204754011645433, 0.06113038811412069, 0.05148975381387338, 0.05895044662118439, 0.017594524937111045, 0.031057530037698247, 0.021393250433668014, 0.011863874125054047, 0.0489491687697028, 0.01010383404190502, 0.06936841884688025, 0.03469239890335068, 0.02377400655419596, 0.03187710239041237, 0.0389128998522797, 0.015309388080852167, 0.06283146719778739, 0.02610386570825452, 0.06267026697676029, 0.04212878757126389, 0.02630599609185611, 0.08273719704800075, 0.03649004720031254, 0.03528432822936485, 0.028833335475815885, 0.03234031745382855, 0.097597127089337, 0.03156895501418941, 0.018299802717181946, 0.04242978734715332, 0.017955132099168918, 0.027335608685990016, 0.06506903382438807, 0.023713713519335277, 0.004492861006574165, 0.03955295865213679, 0.06337697159559016, 0.04458814814326264, 0.02780740776459777, 0.04643815854984907, 0.026553429084860032, 0.08408440096724419, 0.048084125268243016, 0.08152461775969114, 0.07472385607299305, 0.03499512237706973, 0.026373302661663583, 0.03965417418869273, 0.04656413021767813, 0.036865005104412, 0.01951596921219701, 0.08374865527354902, 0.07877111389872529, 0.08730208516241082, 0.05460637569006893, 0.03591905888770858, 0.07793446927661858, 0.06556092355881007, 0.015245484856648311, 0.02164532208905345, 0.019616315238958886, 0.011188599220927686, 0.028712400836088968, 0.15177692587096847, 0.12188114901824344, 0.13128482466263156, 0.09034623512096944, 0.2597906807016942, 0.2106391996025078, 0.19821023508425684, 0.1098086452111602, 0.15921350989130237, 0.08424747044280653, 0.1419950709227593, 0.210388780781819, 0.12862228608179477, 0.14880712474546126, 0.2075903994902488, 0.196228105154249, 0.074750263123743, 0.25679071103372886, 0.12763968638835416, 0.14097255804846365, 0.06395787308593431, 0.14783777837311068, 0.11775754286997742, 0.17063663160849005, 0.13807395713463907, 0.126377081558589, 0.09337837282087534, 0.145338585059489, 0.22305008444574573, 0.11014655127280182, 0.22064603925231965, 0.0580965152250663, 0.08994140361826267, 0.2076984638528478, 0.1810153763020231, 0.11420662574950727, 0.22599089680419815, 0.145425321534276, 0.08200556009767518, 0.05727302816305911, 0.12032330156333985, 0.0817534099182775, 0.12077819691189837, 0.2528732591458867, 0.06523965692688381, 0.13570605596948054, 0.17918730665358806, 0.11844585754818494, 0.23004350192364187, 0.16728775485629038, 0.1278105776216234, 0.0910111841174864, 0.20217999545556886, 0.19469220611837604, 0.15433369835297908, 0.11017121164308441, 0.14674716028234652, 0.14467884546085713, 0.2021662058729318, 0.149939188192929, 0.0992142697495799, 0.15463208959948632, 0.18219311391153645, 0.1237579725021797, 0.1954544942465521, 0.13300954905008117, 0.08083333832121666, 0.08397453629802312, 0.2296335376318424, 0.14985531688697878, 0.0738474897920124, 0.19686227273796836, 0.10468338676277669, 0.1838788291018817, 0.15737468436841043, 0.2088208899142281, 0.14831905012890217, 0.14699819197337474, 0.11640925876676075, 0.35531225343865735, 0.09552932554675687, 0.1921377931871722, 0.07177182818732916, 0.2164483524017757, 0.16763319922310693, 0.16133088498346268, 0.11231135486835435, 0.11245207755916542, 0.19178113329314417, 0.06372115574777126, 0.16294363795989947, 0.09887847809060928, 0.1533150925270973, 0.1478014504837413, 0.1996718848785085, 0.21678391423436905, 0.13554218976247695, 0.1504400411560651, 0.21108245807549647, 0.15681280484122617, 0.12960549864557483, 0.159521063549384, 0.19616523997918253, 0.1469187180121099, 0.10282320270855581, 0.10696125727507377, 0.12438845520298328, 0.15607469444794042, 0.23303699048776783, 0.2869161687070324, 0.11377531824813736, 0.17941062128351581, 0.17000745891803698, 0.1481809397979129, 0.1700997265476373, 0.09632008150219919, 0.18876810948694908, 0.1960703063636057, 0.16009998087200428, 0.13748062203728384, 0.15023045482174044, 0.09324554083568436, 0.10829502401212532, 0.1598003638848182, 0.1450837688941148, 0.13865290510077632, 0.19386354413244034, 0.1478621399691028, 0.13974122492776764, 0.12303432584890436, 0.08841288200910054, 0.2062291378575948, 0.27277544200901066, 0.11442748889807733, 0.22566809799642334, 0.22527840439110036, 0.26987962965523044, 0.10100937463463315, 0.11107171735455913, 0.14617711425788943, 0.2738473522326639, 0.1638590517423807, 0.09627362593047081, 0.17960510036397367, 0.18136868073094278, 0.09076543077225648, 0.0954260262510469, 0.16285377584638136, 0.1481326762586832, 0.14405403947157247, 0.19732684377701054, 0.18628137276297618, 0.10822075178786632, 0.11075083376659502, 0.18940121986933295, 0.11929888113011276, 0.1251437566092899, 0.15363603740209533, 0.16241989428958586, 0.11670879148427518, 0.12070731079626469, 0.15842255475299974, 0.2659083217863114, 0.11201786658456249, 0.1949639528268768, 0.23806474892602814, 0.093373944832673, 0.13167358364068693, 0.1443607351111789, 0.23382754726034982, 0.24360589352586579, 0.1773931440566817, 0.07298284465627325, 0.1176323487813915, 0.11432095671132689, 0.20757714616915873], [0.014965133065538061, 0.032691767949971466, 0.03566650651215065, 0.025747435640603788, 0.017471179035642458, 0.05806576445578568, 0.03178204045510821, 0.02332612091014462, 0.03722908455998667, 0.03982283993654194, 0.02377573408246521, 0.03237268083818978, 0.10526706915228598, 0.0494069446088566, 0.04310975932786542, 0.03485993467151158, 0.01513247060844855, 0.03159200659983101, 0.04828959387997466, 0.010928664630609415, 0.03049117081137675, 0.05601516541754527, 0.022652126330461715, 0.022118046218829773, 0.06164467442900904, 0.06321754869854739, 0.03150316721369182, 0.042651037370125135, 0.02444924028109639, 0.02353962961464159, 0.040541127804786935, 0.02079755195506638, 0.09414885042896194, 0.04312988445763627, 0.08984116101337057, 0.02228714097591658, 0.034709513307579105, 0.04651907658685119, 0.015826473489493852, 0.026730537121634812, 0.04105856657148369, 0.007298975476935025, 0.04463117930196947, 0.0314141784404074, 0.03251625720651881, 0.04062705222637423, 0.06227870411690205, 0.04861452241217898, 0.06279912679606388, 0.08812258831195294, 0.022740358591920907, 0.04389983346505512, 0.04037282211826213, 0.08437002918893292, 0.03276216759977322, 0.05043354073178865, 0.034529712471750476, 0.09609029342931125, 0.005854457323890059, 0.02016115697070716, 0.0486186248130135, 0.031558654962047454, 0.016938006738200784, 0.01824251083176463, 0.029284649363328374, 0.034795437729166406, 0.04157944124252085, 0.033210225613607515, 0.012925134768949883, 0.02091756728928416, 0.042632915560276284, 0.0641158672289983, 0.10681096614608843, 0.020623102243388855, 0.02851095993161923, 0.01582774902588778, 0.04265756443924001, 0.03430120759613572, 0.021680926025334387, 0.00825731220820378, 0.040795426860812216, 0.03492795944874806, 0.04028683257920127, 0.03338107854248055, 0.03965110600655598, 0.03722361852264693, 0.047696718435374, 0.03872839906703561, 0.0383031934559826, 0.03105647283636274, 0.0278365861384138, 0.014186434376414024, 0.018644772109485442, 0.05573946952579483, 0.03523054502664074, 0.009657597402110696, 0.03921929288715605, 0.03292493830104509, 0.08541945473200853, 0.06812375579630175, 0.06466166657065192, 0.01608671834542146, 0.05571432268968033, 0.028561245942968997, 0.023966361655883735, 0.021297705862971566, 0.021176784629783323, 0.036026468245132316, 0.03395674765230187, 0.049813679840055206, 0.06406084679427647, 0.05096507934673179, 0.08044867025267693, 0.036628624844935634, 0.02463516598987964, 0.02517786459065974, 0.0073178916242003685, 0.014046196236215053, 0.018568739798220418, 0.02847196797149316, 0.027835894744062138, 0.021943845485727635, 0.040587250128268235, 0.06107798770009991, 0.035100758240948764, 0.022136491700826634, 0.02735435294227735, 0.0025150647401929863, 0.10439346078783275, 0.03677118231632537, 0.06019478408439506, 0.05117521726436192, 0.03170358347556284, 0.055911145999186465, 0.04558023966608509, 0.03586153334547435, 0.04320372001177842, 0.06545661302704005, 0.01835192159389056, 0.01271452666485622, 0.029431404996543165, 0.06675829600182272, 0.031954186157353466, 0.01915247006822498, 0.05218474111790138, 0.030957555563579646, 0.030032213281599746, 0.06441825745447029, 0.021493810965048692, 0.0389183237547836, 0.035685172244425745, 0.05499381316645492, 0.06736578074313941, 0.013217728645090136, 0.033432452398682797, 0.10540468152612449, 0.01759901804278695, 0.08071521522417184, 0.03587160357123902, 0.02535573488491918, 0.037375296270775224, 0.025808104058547367, 0.0341470017578573, 0.04272037598815176, 0.0170501179602598, 0.030594540970219724, 0.01318692999531425, 0.010493260474064419, 0.019825784744875088, 0.08152533022146072, 0.07856574104798418, 0.056102300258052934, 0.06251994520425797, 0.07739417810714053, 0.023004932802230604, 0.030813094363698078, 0.042665750088710944, 0.028679895725461747, 0.03479619615621144, 0.050542601008689216, 0.0070706736146202015, 0.06750180731497465, 0.010425336245867995, 0.03418635569452759, 0.02191559024786036, 0.025658925672272043, 0.045180686509176615, 0.046175497644130266, 0.11821079879037796, 0.06661914379125641, 0.03602699301536045, 0.028494044710251114, 0.007159580512257714, 0.01101192881187965, 0.041461490515259006, 0.02780283038925019, 0.04441276763475711, 0.02225998698944046, 0.01886903285799969, 0.03516352765502469, 0.09245794882336933, 0.06735496358164857, 0.0017386947189562865, 0.022823494453463825, 0.048896714729527314, 0.029877421386059255, 0.021787881475662994, 0.06487013441660712, 0.030440938426181677, 0.02228186646055791, 0.10696814440551305, 0.034244796711831324, 0.04757577996520747, 0.04816687425538417, 0.05094672388006603, 0.024602318054906303, 0.013826017778727316, 0.015008480235513662, 0.04934393387708453, 0.025387847375485207, 0.012030337370120952, 0.013497128571954467, 0.009428595526955061, 0.06669453450388486, 0.0134787003269359, 0.03667576989579586, 0.03453550026601842, 0.059681459209851684, 0.04336358340937765, 0.052493252385888374, 0.0680714856172281, 0.036204660296319954, 0.06764785431685948, 0.10013839395176019, 0.024495598176614414, 0.013518584779493753, 0.11980376371573057, 0.05818274225138369, 0.04161083552565786, 0.1025039125834742, 0.02437078521677083, 0.0396712081536891, 0.02102299630942364, 0.0343667081136617, 0.005417856154963375, 0.11600193747830008, 0.04501003276316389, 0.08612282303792816, 0.01045007801299254, 0.009964400294026541, 0.024040926908773762, 0.047191395349199736, 0.029103316351651188, 0.034193384551232865, 0.02238924134402506, 0.03289971485613816, 0.017665818994564396, 0.040891249138381214, 0.013089473077636814, 0.034001050516963005, 0.04625749969554525, 0.017394886254483176, 0.062172738835215575, 0.02876851294610289, 0.010762899483163512, 0.022540442202420487, 0.03423862204316162, 0.04594145778326258, 0.027784727731599446, 0.04005578812211752, 0.017134860691223896, 0.017843382853654124, 0.01623798432129045, 0.016927337048635367, 0.06972901643283906, 0.03391558191769066, 0.010859976229708522, 0.05606655842594563, 0.0275657472441033, 0.052624904595675974, 0.05778166840994551, 0.03179500074756723, 0.06717794364498508, 0.016980767850914312, 0.0437058600026273, 0.03354755327886632, 0.026807360418681658, 0.09321640651192396, 0.09319491008476866, 0.040082708451776736, 0.07016683568156536, 0.04830843964291196, 0.06180850233161642, 0.08469534842597862, 0.051533478282151685, 0.025056924205273393, 0.03315654583275318, 0.055918381699631294, 0.028207278847994826, 0.04291706140183153, 0.03907479721331789, 0.0109645817053294, 0.03808328791731789, 0.019668311541599613, 0.10689322866739766, 0.03921366214091259, 0.01579507729113703, 0.05759710633766748, 0.03132472043826936, 0.020216428299224185, 0.04630433831123575, 0.04907112230636901, 0.05237183894120878, 0.04063423813110398, 0.036407596987461856, 0.051845153493265954, 0.0765255646359536, 0.03969185039280884, 0.09263172054723387, 0.02797886781815079, 0.05541913369069657, 0.044679481145595355, 0.022094148106031844, 0.13903997868539827, 0.005992609789715179, 0.05629443127902285, 0.013457413616349861, 0.021883558196526383, 0.06789191460777676, 0.005975242097666788, 0.03283551668808345, 0.08327101477451863, 0.07977969163367826, 0.06723086499879438, 0.07137584500014782, 0.05355488937047701, 0.022909392061973774, 0.03115687440449913, 0.023572328162469694, 0.03472119614842438, 0.028415934385491476, 0.0486489772165735, 0.05914299516007305, 0.04848037658619785, 0.023692523527349678, 0.044805893313980875, 0.02259092931185038, 0.0594317413596136, 0.05169817952499275, 0.03194912423139378, 0.009938641545182515, 0.058903401161754326, 0.14929231887142505, 0.14095475416510336, 0.14470434086697717, 0.12546428779680885, 0.06738952180791287, 0.23571345654706802, 0.12714509236355945, 0.09545244862355533, 0.11275498106354669, 0.09899226513000266, 0.19853721673209823, 0.11386129629587936, 0.16136637017611535, 0.1892654997326674, 0.1284241297793004, 0.10900390815109977, 0.11327441165884657, 0.07985219419483217, 0.14769182330177677, 0.17019251511702616, 0.1276660015085532, 0.13127485019785742, 0.12321467060715922, 0.3229617087110397, 0.16094880629210703, 0.1870485791756261, 0.08269678590999496, 0.11112496812617588, 0.1206946243802386, 0.1348082468874993, 0.12829099135893968, 0.15119399424762497, 0.21380271372054854, 0.05622542590924329, 0.2326315920799971, 0.09361033658346823, 0.19334076573291134, 0.19547571488205465, 0.12442003334722213, 0.10895128557158094, 0.18718724108992085, 0.17724251584900966, 0.11794228497291766, 0.09725421847354981, 0.16871733621003168, 0.14526772192649304, 0.10528129540503987, 0.21958880727329563, 0.1964081511382134, 0.199988110651893, 0.17002837311836982, 0.11026962329783749, 0.13370252154286832, 0.17630297029691358, 0.21893300536659457, 0.11640769594739522, 0.14733304900507774, 0.2595980555540131, 0.27764589195289924, 0.08975075497742623, 0.12525561310711408, 0.10225176240407652, 0.11658606419880545, 0.15553460246132267, 0.11070984040176678, 0.1547858740894064, 0.14049972858159773, 0.17063566633770544, 0.07745961733763257, 0.1279527022533359, 0.15446359622142009, 0.17231298520440058, 0.1620327440961715, 0.11556663865884466, 0.105429686635973, 0.18188601990620937, 0.12676007189457456, 0.1362974758470251, 0.09093287460986646, 0.09159281339135864, 0.12797583810864918, 0.14561584760104457, 0.1091560225693449, 0.06733855397831048, 0.10332440041125783, 0.14950270193719095, 0.19481295689700112, 0.08957729734961065, 0.13322026919453375, 0.11111708508143503, 0.14225192488201205, 0.07734054429156166, 0.08399156643257988, 0.28752640370399724, 0.13894950370154074, 0.1428877012503724, 0.09180212393403055, 0.09720556422947876, 0.17493924186114343, 0.10411393062602128, 0.11662187114838632, 0.10577444918453695, 0.1495131054112027, 0.11571476175900429, 0.1316899013134741, 0.13278543768871215, 0.1153827698961381, 0.07782468121618995, 0.08241931652469982, 0.14034862539941265, 0.2407686102895006, 0.2904985797020697, 0.1623723661947635, 0.15121593500577635, 0.14326369720360926, 0.13166290437502245, 0.10877389025183455, 0.13685979970520543, 0.11602338794017993, 0.13170764390980044, 0.0781079498870719, 0.118332936188146, 0.0876734692663435, 0.10818528957785138, 0.11218050705088724, 0.12974333318491138, 0.19787493372155776, 0.0804974317490574, 0.14964058244180295, 0.17559703559644763, 0.13821047400274586, 0.13094941604762309, 0.14186753260512508, 0.08752767507347368, 0.16060319338594714, 0.10858589993609537, 0.12805884373524498, 0.17710377732592245, 0.14658959131808053, 0.279962940201644, 0.15980132915560277, 0.14735808475844323, 0.17055579401071996, 0.12271714246561452, 0.11823055619794516, 0.15249874923498402, 0.184570039592443, 0.23922348755501935, 0.0679919503689293, 0.17714580490944848, 0.09586718564312305, 0.11615456517545447, 0.15829359151182637, 0.11369097196767408, 0.0875437859025213, 0.18038753660455828, 0.10021635871981421, 0.14644958108903902, 0.13173396669087872, 0.12151187931698178, 0.15534904064430347, 0.08667725619048842, 0.18221949797964868, 0.070738161072856, 0.14203821699465477, 0.1158136790317874, 0.1851329150339288, 0.12808119051999625, 0.13057277658052985, 0.11999350837281636, 0.17802973247824178, 0.16308346432783913, 0.1344144930161776, 0.1630787145827086, 0.17481967085792174, 0.18394537149898468], [0.05389491366522928, 0.019836866206699805, 0.049445429035732825, 0.043881286476408286, 0.03299625342591636, 0.04495549113339475, 0.03657679133597882, 0.07414442547146352, 0.06305399275715314, 0.05333595676347614, 0.037628810086678115, 0.034530819468801065, 0.04316431627939305, 0.06560767790482891, 0.03183808170198914, 0.03312090742251566, 0.015338316518482904, 0.019225307792845755, 0.03182817426990838, 0.05733274088631715, 0.03686451863858008, 0.027797655465321678, 0.007478845260676838, 0.0348127436553759, 0.04057455988180253, 0.038612053293975136, 0.022953480422016115, 0.015302041297658317, 0.026892737087403095, 0.041068081383503256, 0.02869970292874402, 0.04760219084639703, 0.05248457260970628, 0.050575730480974725, 0.06118427090827496, 0.016514090070080374, 0.0443345194141711, 0.008977415704829319, 0.04249477458577003, 0.0800670205705589, 0.06683747118879711, 0.06665934042464342, 0.03237721990914114, 0.030779874876081467, 0.05793597000921446, 0.03220594946234938, 0.042935596899159496, 0.040815617108056625, 0.030142987680230892, 0.001990856868477779, 0.06751342886878599, 0.04500660068926312, 0.03519163159052691, 0.04278673069371332, 0.028391494265487118, 0.024555963989827904, 0.022154060012150197, 0.020276031854953018, 0.004153204434025552, 0.03178730730958764, 0.039512597309846076, 0.026685678843228568, 0.010132697362062192, 0.01552640738326215, 0.017984599671176365, 0.014783483084982202, 0.04614327981647465, 0.06556254766520954, 0.015568590099592845, 0.01092525266651665, 0.07907112159075276, 0.012178926826304486, 0.08722037422440707, 0.03715692290795907, 0.022010158056453354, 0.015313732756992743, 0.06955477739534072, 0.01440362221816735, 0.0335064411704098, 0.007726531541500722, 0.049482852430833925, 0.018450298774687034, 0.049084582471198616, 0.05371022518844374, 0.029066143850345286, 0.03672498721449125, 0.02169672275833305, 0.03181562766492848, 0.04145849128103545, 0.06443225388084689, 0.005006072404343756, 0.050959306874222336, 0.023526173280251604, 0.047473618310065045, 0.051913155287864714, 0.07327862354295869, 0.008289076128764259, 0.06863937893461797, 0.04828983902811043, 0.06117079925212649, 0.028133858896551595, 0.0036864387924828, 0.047995726382660295, 0.03556134562278467, 0.01807816198936874, 0.07728316430603305, 0.03367444808264414, 0.0416324430355622, 0.03640241823309372, 0.028875296026648536, 0.08873940400418737, 0.010573763865977527, 0.04880108780437901, 0.011023681558248018, 0.06094708625647811, 0.06988417222014359, 0.04755681928908152, 0.05312296899876768, 0.04296065180472309, 0.03667426453302464, 0.02544608920992863, 0.011540953700821246, 0.03380524993483578, 0.04022011398187569, 0.02501226319450765, 0.011794290358891651, 0.0355702284122667, 0.010264831249632183, 0.016600880171022108, 0.02714815654701764, 0.04053607928536592, 0.07334284469365113, 0.05442559426169723, 0.05916448392634911, 0.04065905937985067, 0.017684118919855645, 0.06218728301445804, 0.0017140241740684536, 0.03358466640835808, 0.004294206268124042, 0.04948808098091714, 0.023121219203476946, 0.04362558164904195, 0.051567910103908474, 0.047237257202786785, 0.04039542937290765, 0.03863094885262751, 0.12253540342733746, 0.036022473096607194, 0.009035196928908269, 0.006487994800291715, 0.04296206523694339, 0.0664937351980517, 0.009812715842628912, 0.028278291368136005, 0.01696885709891156, 0.011573068106607085, 0.0939859035274675, 0.05519448606778057, 0.056205894497613755, 0.020310161071979714, 0.03117290862475432, 0.05202251050861613, 0.01847856550387317, 0.04162078700779427, 0.023626877453118086, 0.03301704122174171, 0.01897916757321406, 0.03736322272508856, 0.034241571481670105, 0.05920662259262416, 0.05241223475745609, 0.024811973337144144, 0.0237130202097638, 0.03992802380854565, 0.02058222570696906, 0.03934051480985457, 0.03472702990796778, 0.032525894592606255, 0.07454400161100973, 0.05167059652927903, 0.058099648524676605, 0.03215282892567977, 0.04316324758673868, 0.05000802868556592, 0.08052659671633475, 0.032608229892268296, 0.02156924189729316, 0.027081997193876776, 0.03929309396734161, 0.05693224161082218, 0.04717979294758651, 0.03867892510888558, 0.021456182641427846, 0.013893358822491382, 0.034738387161445235, 0.022037967048104734, 0.018624271596631697, 0.034001245869383696, 0.01141728604242446, 0.026162728073916612, 0.05072882932220256, 0.04734639025804016, 0.06336607782530689, 0.05821085384776516, 0.02126794526233308, 0.020023106011532007, 0.061948765369672934, 0.04355894349094841, 0.07995060584958523, 0.04735101742910282, 0.02880705099913382, 0.05577452570920991, 0.04553669139802937, 0.041119221582888596, 0.04357348383975126, 0.06338805305741488, 0.06518086733957452, 0.057741755229090495, 0.032912290189415216, 0.03412430640310049, 0.05644307531897099, 0.032198537561681964, 0.018479818057629372, 0.030069429832961292, 0.06724259380491511, 0.040945055323743054, 0.014958538006119912, 0.07344939220216005, 0.0954757453573327, 0.04748587571685353, 0.020156441699533213, 0.030475626887393095, 0.035125997007614186, 0.027546529928522728, 0.03433177067387489, 0.10249288091736455, 0.03398254183271239, 0.029539136110895106, 0.01838855783364946, 0.048636026500213536, 0.04416282761902098, 0.017278444720432162, 0.017805143574913664, 0.04500865763533981, 0.008877658608159231, 0.046087110249866406, 0.045820300978037624, 0.05202862389025189, 0.06674840580672026, 0.05359902369579481, 0.047407746239895784, 0.005234202375680569, 0.035172326174835046, 0.036968810018152, 0.033333244012488474, 0.0770645764385981, 0.003444202509032743, 0.10304515370197835, 0.05828845855449477, 0.0726472981454384, 0.01859164199671678, 0.03690598314748176, 0.02065556521918024, 0.038690577306213884, 0.023626611237564397, 0.07263316382323542, 0.05576325272540412, 0.010385522656443139, 0.04814403717436137, 0.0130716806855954, 0.05154215422789416, 0.03287118191139833, 0.05074713882359286, 0.017563442834803177, 0.05236850262829854, 0.011585823470546354, 0.054649353222621065, 0.022500676493490898, 0.01786094158887863, 0.03952645584039631, 0.03539274499240903, 0.05225036420949525, 0.06496925087225053, 0.04157820784096276, 0.053306550478502635, 0.03467123572444243, 0.04769805908924149, 0.03543012625267429, 0.026150323195202697, 0.003586047997457847, 0.09269299992029706, 0.027206827390698657, 0.06815962403291656, 0.013433217686871368, 0.06512685048003351, 0.021064499122721535, 0.05576887964120796, 0.03683851761443, 0.05837142587669435, 0.02649669452840763, 0.0535052047381478, 0.02201880718911848, 0.022606862025455605, 0.022351360211389202, 0.03580222281837656, 0.044040533173228466, 0.044821701538298404, 0.022852029313423464, 0.04129648666768786, 0.023818024051105304, 0.050225758534525676, 0.04017334048365874, 0.07881785292298564, 0.013720051539430936, 0.044289630492247885, 0.014268251609117275, 0.03835780403366493, 0.05293280682376316, 0.041440013240301804, 0.05171221042532594, 0.04018230371237282, 0.0819313798039671, 0.017237830569126436, 0.053264354355633266, 0.10872207206463623, 0.01946615434492067, 0.01870403284086816, 0.053273558902043494, 0.037173290376461325, 0.02865281068689881, 0.0361508158065619, 0.04942778603083665, 0.04694804752005204, 0.01712867070079571, 0.025577486695481405, 0.03773196382568248, 0.05017232007136749, 0.022517093757708228, 0.04337174607621085, 0.08106030719054323, 0.00782945832695752, 0.03724548267200589, 0.06550186584072729, 0.07262638394510554, 0.048792342910723346, 0.02839356461810249, 0.037035796746251085, 0.03204285891936912, 0.03972367751562307, 0.04674006613992876, 0.012866906341045134, 0.13282611695749144, 0.14136609741516654, 0.15356253892663987, 0.10858949288846025, 0.10150505650428035, 0.16308974624881822, 0.10943653332369943, 0.17136139675013481, 0.11832145253016103, 0.2764743290120556, 0.22112858271406544, 0.10368172680177998, 0.09990737247731417, 0.20432542468751633, 0.10427557517804446, 0.12292905770722898, 0.11033357631775642, 0.13357473807709833, 0.09468293628625332, 0.11870152407115507, 0.14128368167627242, 0.0912706044712855, 0.18138444682042446, 0.16333736118770417, 0.12676663726808565, 0.11619298448485714, 0.12826278400156768, 0.14999757941451766, 0.17084500752389434, 0.09713270926787969, 0.0863086759683586, 0.16404115084198215, 0.11178166635574834, 0.11918034434558884, 0.1256528296958535, 0.11234856375883664, 0.18330528971648988, 0.09914738261291098, 0.1401979359047067, 0.19073615872090866, 0.1475593513779102, 0.21539164136254021, 0.20652955157622216, 0.09599856972213715, 0.21704150363802913, 0.27688127491743336, 0.11298179671528841, 0.11701491255793842, 0.1244498111848389, 0.14634292632822068, 0.25846930160637827, 0.1299253863192374, 0.11283125277728805, 0.22821242921054366, 0.14986078675475814, 0.1345944623913496, 0.10446276110146316, 0.1021419590218894, 0.10588167851129848, 0.1237280491078573, 0.16577442477066673, 0.14053504523490706, 0.10451462525393694, 0.1744763408937762, 0.16023511878184735, 0.13033841496273396, 0.17366722947166813, 0.18842070393504637, 0.13381752666206131, 0.08748488906290262, 0.14633655247669067, 0.1319795285141276, 0.14492056152272612, 0.161114955441125, 0.15187349891470325, 0.08152903042613499, 0.19547850344209902, 0.11370820894597039, 0.13062649466578038, 0.13050448750295948, 0.19547738495372957, 0.0639838932622825, 0.1653640008261127, 0.12698851165271577, 0.17158126398440332, 0.10050007172169224, 0.15691953621083693, 0.09779689983735163, 0.18809171513684336, 0.16465316316293133, 0.14798336572224094, 0.11095375513597844, 0.14398092404007912, 0.20112553671483072, 0.11794629161276164, 0.19425101608278292, 0.059430917815095, 0.15201746215743406, 0.18715797653121335, 0.25566436260217623, 0.14529732356388725, 0.2293677051221171, 0.17382285257260646, 0.09270017050326833, 0.1747010957690016, 0.2889476193776054, 0.13670216945390548, 0.1581803943601347, 0.15843352513207545, 0.1513867726128909, 0.15177956121342798, 0.07077748436600932, 0.09277279563849011, 0.12760296013326416, 0.17255793415731, 0.20752316761401393, 0.12615267908380878, 0.1983544281533649, 0.11799651633707747, 0.17552822557908876, 0.09994073560641659, 0.236440688491829, 0.11453524682550661, 0.1080173784266076, 0.1795308511223524, 0.12277110569900083, 0.15619674757603677, 0.08313196215538249, 0.12487099100384982, 0.10885808331471299, 0.05507879913033498, 0.14058977455621766, 0.12761066697778242, 0.17408293942289968, 0.10537730920458994, 0.10076019687638169, 0.1556730958362741, 0.12480305432672463, 0.13787069868656898, 0.07752341713996665, 0.1102756217662846, 0.17602042174868046, 0.11323097447353987, 0.14635051059867107, 0.1271925285278309, 0.10784269505811316, 0.10577607329093641, 0.19963024033894464, 0.11785292081655034, 0.20349000580608848, 0.12069366677033326, 0.12193768630705534, 0.14159848252611776, 0.08521824173869626, 0.08755067303296059, 0.1164282730690414, 0.1775928785003001, 0.16978538535054655, 0.09457054352688213, 0.11645860248996366, 0.2945680387558476, 0.12878638211517565, 0.13508754722293348, 0.13008418102418223, 0.20704987849439346, 0.1354629456275894, 0.14455677701100228, 0.12762049588585092, 0.15015971426281238, 0.08878262668487527, 0.10761780994794062, 0.21502971078359315, 0.07282296210647592, 0.10410473757092992, 0.13601891095599822, 0.08440632643478532], [0.029090984251290083, 0.07432276307935677, 0.11656847482006397, 0.03603071620267245, 0.05979778583071405, 0.04822152696790234, 0.020139995707018722, 0.019631460797221913, 0.015902736584746068, 0.006533990240460563, 0.01609841076236579, 0.07234328381356693, 0.03898990317998875, 0.061786036803236896, 0.05165583401497814, 0.005580893550593887, 0.07550501294674412, 0.041456445826277624, 0.06638511159126798, 0.13817167931026028, 0.028901517301076846, 0.0096516381956697, 0.037906926816269275, 0.043044775919688326, 0.040589104061044996, 0.047482796043397925, 0.020448677429568865, 0.11888481060703916, 0.03842281425491937, 0.06183950590991205, 0.01610240782611072, 0.04721258534118534, 0.013983597276702285, 0.0669394145088811, 0.04831616563962833, 0.046185008625710205, 0.023883765886327433, 0.03851592841167604, 0.029542106616821502, 0.07298952494297298, 0.03554771691861172, 0.028210481095518318, 0.024599789964756178, 0.047622001880118926, 0.012904908132529067, 0.023323989270495313, 0.036604090879160556, 0.03672090396585484, 0.03545628049440923, 0.031358577694082936, 0.05673057279519497, 0.03867721290237481, 0.023474357008273085, 0.022059903975816506, 0.018206431920970642, 0.046732604443546266, 0.03026961052279559, 0.01783135718846273, 0.0436292780232766, 0.035362967154792244, 0.03993702151121632, 0.0399575105327512, 0.013056886570167639, 0.06345816542424502, 0.04136507834998831, 0.03424212306497559, 0.011748188145218358, 0.03537985173264339, 0.03783726261087483, 0.05418011287768042, 0.022628025204363852, 0.04766155499964953, 0.052458291963463834, 0.08270902799502497, 0.01724721706141868, 0.0392530199080225, 0.031997010472320744, 0.041472978003683596, 0.0449519747898223, 0.0609136886534191, 0.08908217472414817, 0.044902412731560974, 0.035987259865167646, 0.0543951997233014, 0.03526951591934889, 0.014161736659345128, 0.022308786790217125, 0.07780279408419326, 0.09386158277911526, 0.05616060720996992, 0.06567953695212642, 0.01897572975365385, 0.027854619848151362, 0.03420214859708663, 0.019879815010954777, 0.043872246638901775, 0.09141190938891904, 0.022052802340758425, 0.054114918795324145, 0.01432893151837972, 0.032015251025797865, 0.04421050127054896, 0.060026715885126786, 0.049568765361102364, 0.08343767720244585, 0.06670043338090181, 0.05770777156876941, 0.07765827925815698, 0.0644662605238057, 0.039374096274015405, 0.01519933284725994, 0.06261524271159884, 0.01218629946496578, 0.028581122094164454, 0.025581769126978134, 0.022518317583167267, 0.04121183778249449, 0.019648008296386372, 0.012095420369728199, 0.06605787713441157, 0.017673928035242904, 0.04124065801020592, 0.0462318089370045, 0.025352645635364518, 0.04187770608452059, 0.03645282298807175, 0.02532637265000132, 0.023806065418607286, 0.011268737763466855, 0.06284819855805367, 0.0749323315798275, 0.03426350074850264, 0.044619006164852655, 0.027184861734689727, 0.10649444159841347, 0.02145729538413786, 0.03971888946609632, 0.042374177024729794, 0.05915467034003908, 0.017967496758266803, 0.024754807856234334, 0.03245806516779046, 0.021320996851089503, 0.0479716559000794, 0.03851644935146455, 0.08571229950194398, 0.04772936144182759, 0.06090470627250691, 0.019530727896058274, 0.05502655193389905, 0.07095060491513822, 0.06129621550621045, 0.027689344039367094, 0.01293727055928039, 0.016484101558284416, 0.026675698632795005, 0.032953325689079306, 0.04153616876611787, 0.0883762936498369, 0.057798897727362575, 0.0478989924604614, 0.031037663462601846, 0.04084359463905135, 0.032314354734074686, 0.017411274790403344, 0.05118575097332078, 0.04737003173138346, 0.08107418870373119, 0.024024243429002744, 0.05898480566458837, 0.03332783160130343, 0.01552066746948948, 0.06852837279438972, 0.031894343199148294, 0.03132598448334442, 0.032775325159872734, 0.0673051448839326, 0.07000033413210223, 0.094895678902826, 0.016988490017191056, 0.027410633591634613, 0.019200212667666135, 0.0214498566703931, 0.08873238663880095, 0.07589616211912326, 0.03360582575682671, 0.049189406281877915, 0.09020354358419296, 0.03593263396572682, 0.04803888394587463, 0.08409260576891323, 0.023767006425787846, 0.02301613109246377, 0.05822328745477623, 0.09123996861519353, 0.07527972180997172, 0.029950826015744, 0.02293156264650245, 0.07273719856335271, 0.04169013328670014, 0.06569390110070668, 0.0423586790660216, 0.08533041233256941, 0.055502928387854374, 0.024563753188798026, 0.01924231111432516, 0.08838224615300856, 0.025158867525357394, 0.010155122670825693, 0.04878450583125796, 0.059792112949634754, 0.026732437019687028, 0.06519998889416456, 0.025816427603844675, 0.039521016616133914, 0.007151927293894152, 0.027559986262912714, 0.01808543024855035, 0.016110986095642852, 0.030940594376936078, 0.013618359113142136, 0.026053123874589804, 0.0879567455981047, 0.04089389980259923, 0.01265855436588848, 0.025094853218404517, 0.06816602086708431, 0.036159005286472465, 0.04638276656248397, 0.013605386371754352, 0.02224572817794979, 0.032629190057876616, 0.013513231740122842, 0.049073355452668284, 0.027884807542807637, 0.055493727671883764, 0.04446444409568945, 0.04460298343591633, 0.06619191953852292, 0.08492382648851603, 0.041581172601229725, 0.025520991541505344, 0.05177837360890643, 0.02644469631054709, 0.03293308564611981, 0.0491560431527755, 0.02055185223599115, 0.03500104806716404, 0.0269297314732666, 0.03145318189185233, 0.041355398829065027, 0.06393204826200682, 0.09150623013415644, 0.07318605713906788, 0.03438789427520768, 0.005811616250749437, 0.014258875650533987, 0.07366653982429736, 0.019012509634898558, 0.030625833746706767, 0.08077364475015672, 0.030912940518089363, 0.03164883883249375, 0.005960272260821395, 0.01113569223126697, 0.057670394138943766, 0.026354855264446912, 0.03083067033590088, 0.06339342333376408, 0.041586661621207194, 0.02366286251814135, 0.056139168239408926, 0.035612405382937966, 0.06790401113610114, 0.008919832706000776, 0.05178531819594003, 0.048268070639742, 0.017460225893545057, 0.04128472338761053, 0.0369278779403577, 0.017690125049182007, 0.06293641358253456, 0.08815167667043787, 0.027417430706742792, 0.014598608831875028, 0.020824652315387805, 0.0655977800488472, 0.023424314229839274, 0.007853921429599606, 0.039384748726602525, 0.054249302108561805, 0.06013584510994054, 0.019699313204675432, 0.0491519445823806, 0.0020403631459621173, 0.060040099441163966, 0.01993155658936068, 0.021659939046648723, 0.03347026649862528, 0.03690142875477191, 0.027531319252786138, 0.04454303705584138, 0.018569373735977758, 0.055965308415433096, 0.054884457945703506, 0.005808959362067042, 0.07235075317082867, 0.04661633910971784, 0.045745959805865447, 0.07856590192644827, 0.05099046367010282, 0.022184236215487606, 0.005819421250282997, 0.025763709263335315, 0.07310792383167052, 0.01870748023652742, 0.04619594836126893, 0.07675174443471817, 0.03042359802601559, 0.010039335184340036, 0.03667643639228998, 0.053401468772320985, 0.019092994832223462, 0.026475245981747587, 0.13873878355708816, 0.014661054573802939, 0.03794161910792032, 0.05691211265061171, 0.08578866314623626, 0.004556117365286956, 0.03801180425310328, 0.04485818647569226, 0.03436904468183075, 0.03611357627256263, 0.03767439614861243, 0.04472347374464716, 0.03312368832168079, 0.015428041693784538, 0.031760745126033024, 0.0250776507140648, 0.004622424669158195, 0.016208193077134992, 0.10806908936149652, 0.01324115178337501, 0.0550106862529872, 0.05673039276453276, 0.03286244084818229, 0.05505544493996328, 0.06722531852222259, 0.01295865398846687, 0.03201996055131238, 0.03820463241408429, 0.17339955835092455, 0.1439395399704095, 0.2718460854263075, 0.13231050914093373, 0.18236237337752698, 0.17049285222686109, 0.15253365220081422, 0.23971343142611368, 0.1266503144776629, 0.1364628895516357, 0.09037085718685582, 0.18357576471903633, 0.16588520108451768, 0.15904671722842803, 0.24258570955885997, 0.11231670982294506, 0.15148060306185676, 0.16242626814111588, 0.10654843547531676, 0.2875334210693836, 0.16083115050869604, 0.1822684356762517, 0.16799162111936078, 0.13257571345856115, 0.14022833427354214, 0.20501098144919644, 0.23652984580445677, 0.26806629953845856, 0.09027426116048329, 0.15215480640049905, 0.19905262536579565, 0.14537704267328785, 0.10641059327510097, 0.14734199691203334, 0.0683935489805956, 0.15850561400575025, 0.20486507234313797, 0.1368887118634678, 0.08744712858911484, 0.13895068347694414, 0.1482847447116529, 0.14010041291194578, 0.15460415803376706, 0.10996118097776368, 0.09406929985890466, 0.10933951594896855, 0.1886066794395447, 0.11839566346738609, 0.12511343484924686, 0.11629203199258736, 0.18052344060232564, 0.1146944935223268, 0.11627887060204822, 0.08756828539433979, 0.09125453960751334, 0.11412153636375744, 0.15975700330830392, 0.09928298017550861, 0.09132436852181151, 0.18129080023256042, 0.1405534466668483, 0.08517992202072375, 0.11408140867828362, 0.18486492215625702, 0.13559051458874058, 0.0999234296802071, 0.16049535884972543, 0.07593263556519825, 0.09816921856855193, 0.1508757306803619, 0.13206326192425144, 0.12306069459525809, 0.14210092895213636, 0.16358033363376895, 0.1429962099439675, 0.16197084419188962, 0.1678736282572631, 0.13669115310955432, 0.1272582665326134, 0.22569201526141938, 0.19854562837750683, 0.12209772973531678, 0.09423164921181817, 0.1588262371238201, 0.12822004395627207, 0.11204875524966948, 0.0861565845327512, 0.10870141067331839, 0.17377088116782327, 0.13952281326055527, 0.17293959916118654, 0.08808283600956203, 0.08619425307598808, 0.15959074690697655, 0.1102257417815347, 0.11619210348374422, 0.24722732903976596, 0.13434137758468429, 0.13320398216526355, 0.09615194052457811, 0.19241337033529438, 0.13850711856878575, 0.1305585579886552, 0.11976098536603874, 0.23685365584829163, 0.1883094066814069, 0.19497020410433893, 0.24580531663471655, 0.2481806182092236, 0.09568150125203595, 0.1752848854108203, 0.07855097087280405, 0.18070075931327959, 0.09643934607025116, 0.22055536508560183, 0.12474489293151325, 0.13165412500741022, 0.12079656770032261, 0.13082060602403459, 0.17974172448438985, 0.13476643380859207, 0.18944271119131198, 0.068133607687008, 0.09074297673519581, 0.17718967110399278, 0.1385008826130821, 0.12364458382850695, 0.17284835808940474, 0.08562871930940498, 0.10190457901767186, 0.13724843610919293, 0.23346069839692887, 0.1597681881919984, 0.2600914774642837, 0.16511410294521242, 0.1267040249020342, 0.17976585625400468, 0.1234943846300725, 0.17744431873002361, 0.08155267189947829, 0.10718238855441732, 0.18235793006756615, 0.10942782290400037, 0.12050168513650857, 0.0850515180237351, 0.20078404536170347, 0.14243759395134065, 0.1078931036435308, 0.2144544860047679, 0.15588828993420448, 0.1131989596591842, 0.13045297575093087, 0.18858023408439853, 0.12464009976435093, 0.07199117448180914, 0.15347134382013353, 0.14697946878450532, 0.15004927502764812, 0.24575069456571536, 0.12123862341527017, 0.14312613845592545, 0.13245445706190603, 0.14414177186066104, 0.14780909604122563, 0.09791935133116861, 0.09430020642016204, 0.19707383557913766, 0.16293662059451305, 0.18893016772645135, 0.12716293455131594, 0.09587330668563805, 0.10652098654498977, 0.17915628009265472, 0.12411229582803866, 0.14430372284785395, 0.2241083429825883], [0.055449489924696185, 0.033079136478444265, 0.04846024762598738, 0.02185112777947178, 0.028363422888721672, 0.039111600077200326, 0.03387890928875535, 0.023860289121887857, 0.1085915230214596, 0.027639793472424633, 0.07028509667443653, 0.04672646424883316, 0.026534702065550995, 0.07096124587640648, 0.050094355303313465, 0.060308314484333804, 0.040016058802364335, 0.019885566416046312, 0.02022706351483301, 0.016576499422831882, 0.040461033312303406, 0.02977530952663191, 0.044609778635804696, 0.00869433472548882, 0.0397046747046613, 0.13626510097134498, 0.039910683408379555, 0.038280980736618085, 0.010508966234122074, 0.024333553343650796, 0.029974952039699403, 0.008960652743436156, 0.02409215903871002, 0.050838789752414154, 0.06951718546089626, 0.0013509287823727657, 0.05975084762359339, 0.015033250730935366, 0.02136261840801566, 0.028193269015079545, 0.020443946836636435, 0.021521133490868156, 0.018193245632573962, 0.06812044629646886, 0.053901459886542255, 0.02057111360162737, 0.015749008593810423, 0.003818836022776762, 0.018632246571923458, 0.014548024046234788, 0.04890783066530863, 0.030397148840429804, 0.027190400550382274, 0.07781853719103722, 0.04083530173727101, 0.014754590078917964, 0.02724977427973382, 0.032933093306999055, 0.010429626338243967, 0.08182135425628194, 0.03880731761455536, 0.05169421885042422, 0.007973670069458745, 0.06623071423100849, 0.061627663446650396, 0.06604598744982673, 0.039813363428918586, 0.06929506592813038, 0.009297408715581462, 0.0049669961745460196, 0.050188139787003885, 0.10041194862776226, 0.06847699893818748, 0.03007502419002835, 0.012160358770239738, 0.02790172659461537, 0.028549114940688017, 0.035251168113562374, 0.08693031801451599, 0.12451166512384532, 0.05463066067726863, 0.02907032669041186, 0.012228790531685997, 0.06429806592002993, 0.06622572699862142, 0.050222920178766214, 0.012628626183516557, 0.031337318754184156, 0.037836963836584366, 0.022444686957544858, 0.014199522988600357, 0.02132159248445063, 0.022932338310525786, 0.02314261412398229, 0.0914198690424523, 0.05454808022947081, 0.02498038627597834, 0.018707738791201866, 0.06694182002496335, 0.03670533705923346, 0.03652428366964863, 0.011856948690218552, 0.08812775940544183, 0.011979311126314346, 0.029499234421358957, 0.03227628016423795, 0.0679094273777258, 0.044999437767171094, 0.02127105749452547, 0.024758824072177374, 0.012047283235006036, 0.040278229411811604, 0.03973207766971281, 0.04495795027563169, 0.00622309452380925, 0.027221802494398532, 0.01085602034318952, 0.07082906506595112, 0.05518634638358509, 0.067819258829038, 0.05533400600055053, 0.01707634114990792, 0.023096961029354605, 0.04512663900611862, 0.011424281382783046, 0.03227667852995857, 0.005184766243121797, 0.042287681867638906, 0.047817178100587866, 0.036096327802947456, 0.04617708344613353, 0.0034691379527606436, 0.02113866984033056, 0.062400098409383535, 0.02881289050433665, 0.029908396236057726, 0.05668578729514153, 0.00831871415533486, 0.046837156293012445, 0.026900227512082747, 0.06675436597077117, 0.013899589990145497, 0.04652222520821998, 0.059898518731877695, 0.07480676210815869, 0.0057524436194780135, 0.07895660676783131, 0.04314752746253245, 0.057472659184807734, 0.04341288499774472, 0.03449117824915917, 0.01368715859679205, 0.10077240831789472, 0.1386995445336065, 0.017545045233301578, 0.06907703730488016, 0.015062384097085846, 0.05164535393217399, 0.035622100225619735, 0.04918615040819972, 0.01672710464786618, 0.02640604142910771, 0.021823412633591124, 0.09449916711497693, 0.11767211640554091, 0.025274763221762357, 0.06538384999599188, 0.06608723362367, 0.05916541855361673, 0.02537094556065577, 0.07313932577568678, 0.06283805938437581, 0.029893606908679492, 0.016385643938255888, 0.02215456563018022, 0.032521344030336026, 0.027876279068990584, 0.06549481017094466, 0.05470996609919014, 0.022601945656201532, 0.03336158543524723, 0.06529652363350315, 0.08623320864693773, 0.05564279306019026, 0.02423056239833034, 0.10701660712760304, 0.014494964796599123, 0.04401510288458198, 0.050984453710336844, 0.017075787651382627, 0.04260833179878612, 0.010177299001013801, 0.029818501563802845, 0.010866759938278027, 0.02298750430195322, 0.054232130247739055, 0.00998022671293227, 0.06670596453571512, 0.05628721473077613, 0.045798563233186165, 0.078526800798793, 0.10171802128635107, 0.0373827924411143, 0.04009857413268859, 0.03327518603914688, 0.05599764498671698, 0.02796796255654866, 0.012284140384215261, 0.07457936422959452, 0.02491283264281529, 0.11147505498581356, 0.04236236011849777, 0.03732742726682656, 0.04425367032508216, 0.058303925869685996, 0.014599807759476526, 0.007992561318866548, 0.011475656196595201, 0.03290206291562608, 0.05530145875508747, 0.04445459603542282, 0.06763649323294241, 0.02072015792251595, 0.029768374515697364, 0.0797874674261097, 0.033198266981109496, 0.04045568601859193, 0.07662169334869232, 0.054049203773179365, 0.06570743021344946, 0.07805825376342382, 0.03400725582914968, 0.02505973957839512, 0.049299163698789575, 0.011655551835804457, 0.029379671079016505, 0.013130954823516791, 0.06035489646056968, 0.026196508720937758, 0.08278938295740275, 0.014709163937837848, 0.06110849332124476, 0.0747045889616974, 0.050322339239139716, 0.057550685239895705, 0.03732537032074986, 0.03484571224919731, 0.10019178261920329, 0.06289085050323798, 0.030906233418312286, 0.049462957127440366, 0.019706202250334526, 0.07155206054449081, 0.023836377602551254, 0.016985276278348702, 0.02800282530276285, 0.028923563396317825, 0.022113905513599035, 0.03937427247423799, 0.045971538225609454, 0.015721783744201304, 0.06134886489880662, 0.038987907520946, 0.03733974979108861, 0.03580157164364092, 0.00934224113852026, 0.03634347542819958, 0.03791629607158323, 0.02679992745059633, 0.023504381909245448, 0.04657961668506746, 0.10506745728273546, 0.045716339016273144, 0.03776360325695526, 0.07499367223992463, 0.014142554775331051, 0.04447969307582225, 0.023921737034294396, 0.07802482168640822, 0.11198844114739089, 0.043111145947008364, 0.024698385480611075, 0.04797547484838194, 0.04982845001523534, 0.06070091156288982, 0.03270358868664311, 0.05723662749533692, 0.01015636947892246, 0.055388298651744286, 0.008065214703580546, 0.0492349885133726, 0.06383238022305793, 0.022836002754047516, 0.051245827588342854, 0.0030092388530442073, 0.01401122623769146, 0.0551413540397921, 0.03441717415567368, 0.029860102053311084, 0.0249257565460979, 0.0193350977684942, 0.03514236830655606, 0.024050493431728215, 0.026656270643035253, 0.02189824601725465, 0.03243222119166486, 0.03465636978827177, 0.026666622406112093, 0.02318328764710215, 0.039149513768572966, 0.05742799625882218, 0.04415455003899913, 0.015447006200350102, 0.025919734560433897, 0.0383431947369489, 0.06283215667691923, 0.011046064732175682, 0.051319486942262425, 0.10375021506221065, 0.09183348757365058, 0.06340840801356301, 0.030733865550568992, 0.041703919038897565, 0.0828744416996356, 0.07810763579102294, 0.025676425035682418, 0.0346554275001249, 0.03406655486492861, 0.056280120756597295, 0.08567771829304197, 0.044862357824439966, 0.03653345374210227, 0.03923579059060543, 0.09211351569261282, 0.03746814612719802, 0.046133795647972056, 0.016146856247477474, 0.02060746638885429, 0.06486153124921745, 0.03702170455888395, 0.12318406539458422, 0.024520781401905323, 0.06419697295754187, 0.07764747741842463, 0.061713764068460276, 0.031855171208360025, 0.051200210882891575, 0.005710029161550226, 0.019142382605482015, 0.03415643996108444, 0.07864303165866483, 0.026991206198750485, 0.09198491251276386, 0.1289998295326387, 0.14558710398212557, 0.1018663052649748, 0.12110664178767513, 0.16474412844306038, 0.20353721214398263, 0.11337456233318775, 0.2385552903457034, 0.17905884903044472, 0.17831254149636916, 0.14203286970094328, 0.20343290161221259, 0.09788241823233905, 0.1056990048457538, 0.17825568245062906, 0.13830713897703156, 0.14121084203643186, 0.07952734227142028, 0.11210837987281623, 0.10532765904621733, 0.13842894695699215, 0.10486963039804852, 0.17981948240870432, 0.1368841306576806, 0.31036811189786084, 0.1210986361688664, 0.10286169096587167, 0.1592859818089393, 0.17291730600258998, 0.16460819380177608, 0.08561748846043503, 0.18611471799592819, 0.2297419390731281, 0.2325617401830612, 0.17108303104196826, 0.17051249472123964, 0.15026719639858893, 0.12218854179786098, 0.08288809338644629, 0.13742832887557246, 0.16944522699040754, 0.17533028378121315, 0.10260816182821028, 0.0922546137665068, 0.18691550970317858, 0.0870927363153427, 0.09150076026637709, 0.09555387100385082, 0.10656841504838198, 0.22186952763267104, 0.14766332483099354, 0.12453688473831262, 0.1235690322374144, 0.17427363402901158, 0.11919985660502028, 0.12591296251142217, 0.13099216375379794, 0.13654864543387968, 0.12645038085118418, 0.20610921445392794, 0.11071627554033073, 0.09713120007466886, 0.12094810755262453, 0.11422089796753661, 0.17142758674679265, 0.14202591362259082, 0.1481297191592955, 0.20772019010638038, 0.11275324970483781, 0.11427896743219708, 0.2202999666934052, 0.1604393884659775, 0.159724980833069, 0.1840033796766112, 0.09363091370511441, 0.08748415361849532, 0.12561436442117538, 0.14712312559206642, 0.2846739825702483, 0.16734277529101219, 0.11920678203985577, 0.18325431422600824, 0.15327937750806733, 0.15212160414986073, 0.14331234378680108, 0.07914976051618015, 0.14933788578116125, 0.12135310759467464, 0.0878289238279385, 0.13141057033452297, 0.08633971785105045, 0.15636475065783148, 0.18093060101232222, 0.150022262767438, 0.21639101838152255, 0.11598527506594697, 0.1276651588118365, 0.1594645415823306, 0.08326804235337243, 0.16029435270015271, 0.0827379554750458, 0.19287431011757544, 0.21367324486134515, 0.1183555740863085, 0.10058590421272863, 0.15171548561944118, 0.13629828790022483, 0.15014837616153304, 0.1436647289102116, 0.11445214926835992, 0.16341950113494552, 0.10054995170644215, 0.09492594703671434, 0.18837251700460914, 0.10643984251204999, 0.0873383594256255, 0.1669526526764516, 0.1431682426482439, 0.11375785144346376, 0.18503408969169666, 0.0958035160757361, 0.14264872778327237, 0.28289423774807687, 0.1327588697594981, 0.2059148426257795, 0.10564533272577871, 0.1061136652565291, 0.12546547523309148, 0.13514449819922447, 0.13820911036624065, 0.13654838496398541, 0.15787265684095123, 0.07646309782660778, 0.1474534167397407, 0.08855662308633329, 0.21911268362835531, 0.15597490383492363, 0.16895586534613566, 0.1802996663196433, 0.15118961222469807, 0.14241268077204305, 0.2856753207743168, 0.15699721752635895, 0.19996636907660192, 0.18689517772966818, 0.2207125356841472, 0.15880414314808386, 0.12131270411754809, 0.17209088099339317, 0.11542218511984234, 0.12002225965261461, 0.26166793319486803, 0.23796935565769675, 0.10398943367744647, 0.21332133471244769, 0.11809281358915953, 0.12949741896121733, 0.16887490517429768, 0.10605905850928639, 0.14994848850032977, 0.09261663627600478, 0.1519869412145307, 0.19815504611019166, 0.25359053194763204, 0.10023390213328023, 0.18585254738648094, 0.12149261986656536, 0.1571922022248468, 0.09790332477179267, 0.18174495247583236, 0.13659458006581954, 0.16937240267232542, 0.2263244208429129, 0.20085031196715372, 0.160189199471666], [0.036841700709755384, 0.05677684067538189, 0.012099912517794199, 0.009128430786903107, 0.04475649979506289, 0.02632232717118196, 0.05565700782162528, 0.013212602559266793, 0.059416703053659974, 0.11568795634253372, 0.034198873571210334, 0.03423559599586072, 0.01871050819904814, 0.016395687350943204, 0.02104586020352379, 0.04395282759721722, 0.01198301133098862, 0.011609443876471733, 0.04083014979598023, 0.04935326865844188, 0.021849967156266494, 0.058033994789565765, 0.02088418117754402, 0.04709774876133569, 0.017549523017218998, 0.05089252698986281, 0.014290757357112825, 0.06305920981591748, 0.03389010566376871, 0.03168257159901963, 0.03399554234478743, 0.003040762892323396, 0.011272537559571286, 0.023136510318445585, 0.027230032193925113, 0.01320494551046361, 0.029940621724592584, 0.06887395505703266, 0.011077542327374462, 0.0566366542461178, 0.01955246947134935, 0.057883619390908754, 0.08826304287199052, 0.0650308136978457, 0.023225525904807354, 0.03577449809639685, 0.023386592060447704, 0.0759158046135018, 0.03799650930769501, 0.05951135704714445, 0.05648864988958644, 0.03865896085757883, 0.07883724260834918, 0.04730838080567699, 0.050030815970873645, 0.06336321648690971, 0.051470134302132556, 0.031318254656188434, 0.021196637798341054, 0.02619077838326414, 0.020759239897973115, 0.022014180018055825, 0.04397814297267506, 0.039811605257132364, 0.014508825242369166, 0.023772654409009605, 0.09055353851327974, 0.019696727657930988, 0.04538279965579991, 0.01220893927834808, 0.05607956276846029, 0.04850702495464394, 0.015781891002740352, 0.037231612650136796, 0.02172565023835388, 0.024825125151584228, 0.051796533723151496, 0.026358685704068314, 0.011084620979794813, 0.016260943976381136, 0.04489097503885146, 0.022108056432297154, 0.036970572020377845, 0.042414300879763986, 0.04976535118335197, 0.02845368911361983, 0.056452256882743496, 0.06434016245146913, 0.026071448697738593, 0.0042507178506874035, 0.02277675351398366, 0.017254295713839032, 0.001144267587205245, 0.055069219200841846, 0.06644953958569996, 0.024528656785766927, 0.05117118381144059, 0.05584775222345226, 0.057211656859445, 0.027615876207428596, 0.07036708340409302, 0.012719100209764175, 0.004290817286669007, 0.038257117097776745, 0.047828313188567284, 0.02536136371594283, 0.07419662670262399, 0.03966971428223676, 0.021929895024626486, 0.05454050361989968, 0.02148100005973491, 0.037262466841287194, 0.06356255256480749, 0.04535034434088776, 0.06826593405416898, 0.013972653710703938, 0.06451318340916788, 0.03636902829091396, 0.032844778691088004, 0.03614143505992909, 0.054680142296297904, 0.016643853873134624, 0.010588216114669077, 0.08136889506732264, 0.02983119181026855, 0.057045703062847744, 0.02431924665166486, 0.028617268037651817, 0.034000361037831155, 0.042741994989374955, 0.05666190067366247, 0.011402964028680037, 0.024320897571141684, 0.026385487290099267, 0.018734207128985755, 0.034812563624713695, 0.03408318663376474, 0.038034457473024245, 0.013554287349594938, 0.04781899755940803, 0.027745481047238556, 0.11331483045773161, 0.0306980011443938, 0.025391373295156706, 0.024576341928613764, 0.03640969223793476, 0.051369975966912125, 0.0032633068856798234, 0.007201728275826862, 0.04438030848940534, 0.03101063205019361, 0.027218617483853336, 0.0505536939618328, 0.06295389953940626, 0.020580580533151666, 0.03319475446797667, 0.038498465437442064, 0.03202909423458961, 0.038432723602219936, 0.002455201672179805, 0.023190979169861927, 0.06513340819266535, 0.018016419133111354, 0.06542848993933971, 0.03259913642860709, 0.03490619489081925, 0.028957368941196514, 0.03899041645889802, 0.04095132575340329, 0.022376087614365166, 0.014476343114379675, 0.02046158218065337, 0.03801438979984772, 0.02801016825551708, 0.03443955541438153, 0.008213976529547045, 0.0052040850653523405, 0.03410982734133159, 0.03878646087081682, 0.024830039605618488, 0.047085663724330165, 0.014694846712142952, 0.08183483740374928, 0.03873259722886067, 0.03162421293616776, 0.01326232070794269, 0.014837971088596651, 0.04045783106477992, 0.03837850755981861, 0.042843026664829066, 0.06037713599301154, 0.02695431331953695, 0.029049663383874203, 0.018441613252845504, 0.0636338408766014, 0.01922151948806019, 0.030961477933751962, 0.10307945911922764, 0.005531805030430758, 0.07122278829375583, 0.0401550424735873, 0.03366301805081387, 0.03232304600157565, 0.05126437457698969, 0.060967828087028, 0.01849757214527457, 0.06354525812991685, 0.06594958294543528, 0.01642937989785306, 0.053060345141397375, 0.03334534054081286, 0.057889977920680284, 0.02964529482978246, 0.05533015640873102, 0.06869831407863287, 0.06169481871409282, 0.020448621888194355, 0.03984791016386401, 0.07930800363781952, 0.07337935644412234, 0.023262679253915147, 0.028839898934107155, 0.016656695421965375, 0.05407645735108564, 0.10355834068069536, 0.07099532146727847, 0.05267025317035375, 0.013128727422876945, 0.062470907916224776, 0.056201217530836026, 0.03758240431066483, 0.0532022399467326, 0.02768509416660715, 0.06418911672587838, 0.013236984265066925, 0.020078678029559312, 0.0324383498950591, 0.04665233375084016, 0.04595227494475342, 0.05441459323910456, 0.06713662852322863, 0.0495358044281602, 0.03732589892141762, 0.09373970585124147, 0.07773678794863724, 0.021275125421403397, 0.04249568623039992, 0.002580058921481513, 0.03954901712976637, 0.044434739036425475, 0.0353057786912447, 0.01654846635046265, 0.04167352833094136, 0.039860167570652506, 0.028442615312674356, 0.051850906813577305, 0.06503715690585875, 0.07150991804777615, 0.03570669165421878, 0.030554309862876133, 0.010878124852634726, 0.019938208147763245, 0.02237837630203895, 0.011523675545299006, 0.02877301754309766, 0.009724890565379493, 0.07048312274198379, 0.034171378675607905, 0.04721486828319969, 0.1100727387012974, 0.037416569257695834, 0.03338122409918616, 0.05381346319711978, 0.04711100974330499, 0.05391259880496129, 0.05972008919343353, 0.045657315772146954, 0.04737052968853424, 0.06562947310627469, 0.01156307544724475, 0.08907236879871738, 0.02398450836359013, 0.013674412808951833, 0.0807407106302919, 0.013715297006250871, 0.05482531595794905, 0.003129252990249605, 0.03460485420580353, 0.04724555776544637, 0.01835846015432429, 0.01276551939231614, 0.027536417567922224, 0.02062663965437922, 0.04610511714652662, 0.023358551327199228, 0.03733212338580239, 0.04316710866987706, 0.09127067341919869, 0.04751920437199935, 0.11748136051239506, 0.0292071404175893, 0.04831257651770308, 0.0202891472802167, 0.003854544099134904, 0.018057278432552854, 0.047243937489486514, 0.016957886719835863, 0.0351955118258634, 0.029952988298910282, 0.0341921741323125, 0.04952882919760962, 0.02506664777625232, 0.009760826792297585, 0.043954348281746915, 0.010480921670433976, 0.04133387941927199, 0.02278158369834625, 0.08526819833223859, 0.018817151468547604, 0.04038042937135024, 0.09099403140886177, 0.06795769857783472, 0.09384058430911073, 0.038495006550463944, 0.06689639101105352, 0.01858800307907645, 0.01108940424127204, 0.030824486091132128, 0.06500492758688427, 0.0284730309184881, 0.11175027207261133, 0.011164402333839286, 0.06829151372996069, 0.031490063279747, 0.04953323037273461, 0.008396133085742833, 0.014430186316941776, 0.06456942192368931, 0.02136843493058076, 0.02646075734387963, 0.048449943743405804, 0.06161938203618892, 0.0062437247928051704, 0.07211078378942705, 0.06900468030043187, 0.03958459042253033, 0.050465383176361366, 0.02202694878853377, 0.017589583669999437, 0.040368351995223956, 0.03301162881055667, 0.01072763262556926, 0.1715659422259177, 0.08981542811999399, 0.11823234118280873, 0.05663568131445397, 0.12653210711094642, 0.15105759995358606, 0.1351560048398472, 0.10456368552460786, 0.21219072683203608, 0.206574444328585, 0.12987592768284584, 0.10614170407455777, 0.21679159043537033, 0.13211960003020304, 0.1521050413289378, 0.10634919898884912, 0.08110965091374614, 0.12500939244825032, 0.11670559689763094, 0.1689885926222609, 0.08528132141838152, 0.20537628281501033, 0.09917578149226405, 0.23525689878771383, 0.09286223640364986, 0.2879204486887301, 0.10970485561917867, 0.16557239206327548, 0.1457107965383799, 0.07768187476622482, 0.0970186847412298, 0.2379342688307647, 0.17972156105022277, 0.2091697663549454, 0.1179502216438132, 0.1341186298598205, 0.1403254895440994, 0.19546284460492674, 0.1435482682239625, 0.13869738416566005, 0.11947683569404388, 0.17038906263487955, 0.34036422328602883, 0.10461362679639172, 0.1145387325255621, 0.13558887516058263, 0.12621183639332173, 0.22482353202517957, 0.2028800006355009, 0.17112541102593945, 0.12162011221892412, 0.09629076331733696, 0.14361632747515557, 0.19508173118435568, 0.16205139067624846, 0.1530209760512075, 0.09438570183251174, 0.18594588753917526, 0.13803022883592114, 0.1257825130596757, 0.13092320051885423, 0.10652166070236314, 0.16865888370140908, 0.17431250533028958, 0.15141182368801487, 0.12351178248683292, 0.20186349389053163, 0.28151310379466704, 0.0830301107658494, 0.11508287711729927, 0.12767852704611518, 0.11400886015185427, 0.09932963493009729, 0.14100343139181215, 0.08991424580134692, 0.14449182807678176, 0.13019351709273555, 0.1476325893834714, 0.10652119338872934, 0.14996747215909345, 0.17515337875773831, 0.2628856452722704, 0.20943349978375822, 0.12894811859774974, 0.10882671967509294, 0.11132733025137456, 0.09530467792384087, 0.11599976178859511, 0.2181551043665217, 0.06188171735453991, 0.13569318569235264, 0.15565006723327024, 0.1425191057064841, 0.21764505834829426, 0.17317838876718478, 0.21607632478398664, 0.19047568882665328, 0.1140810639387177, 0.18794695516267132, 0.10962322128996735, 0.24991755403818625, 0.17221976762577412, 0.11528740727132368, 0.06953362570775133, 0.19955197679660014, 0.11456107931031335, 0.23633404905276917, 0.16897268863695283, 0.11023966159911887, 0.1865980122238398, 0.10509948741884963, 0.1765989560273386, 0.09118374542243059, 0.15641780990746715, 0.17227831206494765, 0.10910386730345989, 0.1376813677169623, 0.09571681024446603, 0.11040197264763618, 0.14198379410851386, 0.1365260305183549, 0.2166095679445613, 0.0944024102101403, 0.19594086814791928, 0.11549080361522014, 0.17176394531082723, 0.17776604501470444, 0.12204086302869743, 0.12177414185697995, 0.07442298270161114, 0.2277886446925902, 0.10701913521775316, 0.1490861492892427, 0.10645442116524904, 0.15034997985968668, 0.10373372118920089, 0.13895095926859688, 0.1536071405655915, 0.07560525555163622, 0.1278055444239609, 0.2130101038323295, 0.18591421746438552, 0.1456871550650366, 0.15778138512565246, 0.2164593534243684, 0.14959222697202237, 0.2009567062580778, 0.07871534269783767, 0.15257935700637681, 0.14233089322524686, 0.08644605085494057, 0.12222147591772581, 0.17896376219728302, 0.12723524559048877, 0.16567497123633662, 0.1722438534301135, 0.1622041332865915, 0.09898121814213454, 0.23044355303770114, 0.0842721461348476, 0.08097586897952903, 0.2322907595624847, 0.11851901894495373, 0.19500034200328012, 0.22966329248682146, 0.1534903274788972, 0.1011315503367974, 0.13105487571127955, 0.11058920453633032, 0.12055511210834789, 0.07710646612629776, 0.08546365800523952, 0.20416747267928817, 0.17119465005253592, 0.1742545431179385, 0.10184895337348986], [0.04235903529690639, 0.06535319881814142, 0.10744486559903431, 0.07737822815655701, 0.00334029489163039, 0.05461241246291226, 0.055449941916571516, 0.038329301732442075, 0.026167194366515167, 0.02164076195068417, 0.030813758944972392, 0.08336541212854848, 0.035654279748879136, 0.04536098530215602, 0.0037844750641529722, 0.02629355865440542, 0.027634798579158324, 0.03520400008006442, 0.02526660821580839, 0.03201084602023325, 0.04539854659308349, 0.021378081892767263, 0.01515613602203948, 0.034099128923469016, 0.019775579172757365, 0.053370714172600746, 0.008910889587094708, 0.020120473871488246, 0.08078845322973306, 0.04490197606144413, 0.02790520080335198, 0.08371505465719008, 0.039777269196366115, 0.03077933669931466, 0.03858643531378719, 0.016897561126238397, 0.029502396449266426, 0.06859012714196598, 0.03925015856962531, 0.04056604864496378, 0.016845691228105177, 0.06760603357707301, 0.0696308039609463, 0.042983098180904504, 0.044817062875916885, 0.025922415868168878, 0.02335520352297012, 0.051123594429584286, 0.016199733551231124, 0.013067926854766427, 0.0524419627993578, 0.025443181906255986, 0.08382164047009523, 0.03822660381575266, 0.008109721539151526, 0.025751053490826202, 0.013955762429583459, 0.06845190189778805, 0.07929560067432542, 0.0316875415944284, 0.04636100200455516, 0.02452827757224441, 0.03814508056929035, 0.014648439978519756, 0.03755438847527389, 0.01910014051733719, 0.02394078581053163, 0.08041552928907257, 0.03551498198160722, 0.06592361256480217, 0.017183455563480818, 0.05522000445653835, 0.01067470169566091, 0.036336496367209384, 0.017588426877233772, 0.049246407053884, 0.044465125913942055, 0.031687057043816295, 0.022204610323833845, 0.04016659890992507, 0.030745077247340834, 0.03031869377610424, 0.02686368128765495, 0.11709618682582533, 0.07473969111038793, 0.035691975105193355, 0.10186265868645522, 0.07851530181904955, 0.0072262363861345, 0.04119809033469327, 0.012070846184337092, 0.04276884637112099, 0.06629023160184584, 0.040032640775485386, 0.024161777278829007, 0.04529618192464114, 0.016791113209159627, 0.08975346692867818, 0.03484347144201879, 0.07827268943430916, 0.015261574618278012, 0.06272812193680195, 0.02921858960161767, 0.060771950896108345, 0.0412191424308525, 0.07226030116960888, 0.0036929632281704297, 0.05120506021945227, 0.03594700960562595, 0.02122847832769396, 0.0477555463270795, 0.05569307141066079, 0.057815931692358956, 0.011425730246569843, 0.05105668431027763, 0.016077615305661194, 0.024414500108950084, 0.07591697672802596, 0.06640840832504534, 0.06957479527280216, 0.032660990367613496, 0.041314558681821635, 0.043809078859105226, 0.035889342337125735, 0.05179327018859406, 0.03319468935050311, 0.05594661587008065, 0.04535880961245106, 0.06413281309388338, 0.01989675321496062, 0.022755940820300774, 0.03802306191515058, 0.06279024017614222, 0.029489608526590372, 0.0381030491553247, 0.046164132729773565, 0.011634067857577916, 0.0115815898771548, 0.025442048096128052, 0.1046345639793623, 0.08132048597138736, 0.030563104552246874, 0.011526832785156947, 0.03738686419843185, 0.00936420296408957, 0.02315525840517254, 0.0614842709394232, 0.02186306534455188, 0.025773352395082195, 0.017403592843742623, 0.032560192348976294, 0.023511288191882834, 0.03942348213205415, 0.05283930196216511, 0.03246674494397256, 0.01803724906377254, 0.011871313796408716, 0.03881193712473877, 0.035460949800307714, 0.02324294482898568, 0.09125267801385734, 0.07269476495322681, 0.007340242239391252, 0.031126600524951375, 0.04136174969795731, 0.057830521836876876, 0.020430626482853008, 0.0704626681944055, 0.03886102037804742, 0.037385197957196546, 0.035782821641694156, 0.043510503751496156, 0.02819387230931992, 0.02877694565892941, 0.017219092058498534, 0.06568965697360617, 0.0458162522033578, 0.08995442711297544, 0.021241258589490768, 0.006958242072047847, 0.026895064079473098, 0.07108356713527633, 0.06174681310151374, 0.03606812810645469, 0.03498851869916243, 0.025211281345916853, 0.05317508596025648, 0.02973428360306688, 0.08738239415951314, 0.020947952251580935, 0.006319710659989787, 0.040259804997232654, 0.021955036115081563, 0.0705581304106501, 0.034779487778582883, 0.09097471833229066, 0.02533055549006789, 0.012293585290711735, 0.029687115569568934, 0.04159009369510797, 0.02089688866098802, 0.02707472127381592, 0.04671688048890041, 0.017883432015115698, 0.028793435701499545, 0.02164092282914827, 0.07966684688243174, 0.05429247499353463, 0.06917300513915478, 0.07550439241552546, 0.061199853136654825, 0.04417357966303826, 0.05341514727220901, 0.03865752061228118, 0.04123797287203131, 0.022686265123587464, 0.054612358836757566, 0.026295358961027478, 0.05310017405258072, 0.05815997411827407, 0.024633164585177458, 0.07191764536283671, 0.03308346870565607, 0.06959661345688567, 0.03329509666429893, 0.08499931679257462, 0.06168460293162254, 0.028557335064115546, 0.06098565112258639, 0.06635990729855915, 0.015554127317192334, 0.03753168545963784, 0.021074006273861856, 0.028515079569432045, 0.0479318154975772, 0.02997207729476354, 0.02479628960211431, 0.042726248052091374, 0.021040740820969787, 0.06788303564873434, 0.024434140688108823, 0.11281278239743364, 0.01836804199903723, 0.06268857647815058, 0.047219319254039764, 0.07075256352583248, 0.03194198812237911, 0.018593647231858586, 0.03215141549345947, 0.037215731647466464, 0.032636510027993115, 0.02325933144968604, 0.01088220427083152, 0.06609799715900613, 0.031317086372103904, 0.05899471884232856, 0.029026366650096835, 0.06822361535723172, 0.03871979973008556, 0.025619104421967943, 0.07448905778508033, 0.012461082754476417, 0.13920767533202327, 0.09162422299625413, 0.019935254878815145, 0.021879344712942842, 0.007654925303218226, 0.015721452411174053, 0.03439943538978696, 0.02087855234652037, 0.007348601695060009, 0.04227553171315982, 0.04354596213107148, 0.021672726969324776, 0.10618411470204593, 0.03322726723948314, 0.020529815716849222, 0.03434659830564934, 0.06825268073307891, 0.013179917417977367, 0.004549418405194077, 0.05478590456468444, 0.03555808974910648, 0.04513927179599001, 0.018244975719661004, 0.04872462073821695, 0.03047970439037008, 0.017043897326314644, 0.031099404403639418, 0.054141402454866525, 0.06380120427497933, 0.0491110852829391, 0.09813183347784704, 0.016717995862446485, 0.026555629672422528, 0.049021859022398154, 0.07237457850527379, 0.0349962446958788, 0.05348307628845496, 0.03258272299482938, 0.004623227625063831, 0.07962848886006302, 0.09945542656726415, 0.02667355741704664, 0.07134726225969291, 0.04777753305050635, 0.011166778164014462, 0.04467708712083198, 0.06973508384919937, 0.08293080278822491, 0.05803573380915388, 0.05963186267763377, 0.023944292578005025, 0.037556621621573166, 0.034088832701766686, 0.06773264492831885, 0.027797969561370633, 0.024921022122725848, 0.05014472558433491, 0.06532686071530466, 0.032056020309908256, 0.04455542852801662, 0.015367426901995657, 0.027451617380363807, 0.05502110121831779, 0.059804397169500596, 0.04524914029565069, 0.00714556445487805, 0.03060267682397558, 0.03591871414814265, 0.007222905818883691, 0.01637220867128382, 0.035343665569539995, 0.08836492490504058, 0.04881675047199092, 0.051420878679040945, 0.03076533644249843, 0.04327346848684453, 0.05971886345275468, 0.03854257294968252, 0.04912684371154155, 0.03629473691445686, 0.02088268156043224, 0.03792217196596246, 0.039806939781673496, 0.03373758904936333, 0.021893450306848656, 0.015948835925589648, 0.020547418502129374, 0.028898238444760926, 0.0022984414094788653, 0.0065375812776056275, 0.15431181888186163, 0.18197647956830842, 0.1986357356391607, 0.14474204771461027, 0.06212746686933022, 0.1290691451680276, 0.17487695891289942, 0.10944420952470073, 0.12631427000967727, 0.12396310786566428, 0.17411159111126778, 0.16943298490537753, 0.16780776001753347, 0.1126623303899842, 0.1479548672514577, 0.13943019323050976, 0.12502607018236192, 0.2250421888405277, 0.23594383450765766, 0.12977206148207188, 0.13574403860876638, 0.14130200649942123, 0.158503208489668, 0.14683207346787377, 0.11726046672030804, 0.13812140862066902, 0.10546560083786327, 0.08762528233590626, 0.1733868412913815, 0.1365905810868548, 0.3686936337861323, 0.20050178792688156, 0.181419548969115, 0.1720216572885552, 0.14568007641261624, 0.13962833421124568, 0.21197257563471797, 0.1330642324061163, 0.10367976561669381, 0.09363603883332784, 0.08558933472921772, 0.1219837281913046, 0.1741547831484387, 0.1676685465199332, 0.10586028933645257, 0.1257773036617906, 0.08535306555249038, 0.20688903067381154, 0.1542403122350093, 0.13246994735973497, 0.13982385517128054, 0.09411822989462845, 0.22642082534730437, 0.13099879807522222, 0.05357616363213428, 0.14841471918888632, 0.16466131433844566, 0.24798509724918874, 0.24442396817668793, 0.16971810750903624, 0.14651837578463942, 0.10323305208716663, 0.19541599066747775, 0.14488614885316742, 0.1321542272043805, 0.11724083954768798, 0.197756496528464, 0.1926434112171973, 0.09944990307333008, 0.1325180270378628, 0.12340575591811251, 0.10642594567710355, 0.07274551061733116, 0.1815976644115102, 0.10677722763390311, 0.11096243491216053, 0.10369114202236938, 0.15025912183186702, 0.16475094662558648, 0.14427124071986447, 0.08311407400235053, 0.12279663174863785, 0.12986333319737067, 0.13625947788598078, 0.22752996744407764, 0.11377879628731359, 0.2659081992122435, 0.24510391717476232, 0.10779074663596769, 0.1602551902854635, 0.07132347522964401, 0.11973657014389193, 0.12654142274010566, 0.12034823006439595, 0.10742375221584113, 0.08005968144824428, 0.11922267836428459, 0.1660745933411583, 0.15909404614039008, 0.12754653775764088, 0.18631586204132727, 0.1703848644730545, 0.1140741921300369, 0.1660764013086596, 0.14346548476286475, 0.12724261535632034, 0.11860681262107627, 0.11158126541563582, 0.09815890702509111, 0.10208061070091302, 0.14716939730269296, 0.13870501440138588, 0.11272454439031501, 0.08938461857577486, 0.14169130173902358, 0.11676458566780053, 0.19754945360604795, 0.21192740709070237, 0.12632899421958194, 0.23023977364984252, 0.17571191814157272, 0.17410797517626517, 0.11849365377378081, 0.14085497887384507, 0.13462266974872159, 0.16047652840854662, 0.1880607805064609, 0.12770126453570782, 0.11791801530747645, 0.08701027461117314, 0.11164087471702408, 0.16568077818280266, 0.13088347119910101, 0.18283336423337462, 0.21441130928935545, 0.18689955975259506, 0.12043816112582723, 0.06159616957208323, 0.09703142478341058, 0.1919477574166752, 0.1840037933640903, 0.10383084581624116, 0.09501337299063321, 0.1803357797043939, 0.1221857685595751, 0.08934727945034543, 0.10809164298998733, 0.11598432511692086, 0.1379377620234605, 0.14494234906329265, 0.23411231746356334, 0.09020433265475497, 0.18038128532709616, 0.15292343773668812, 0.15632057802811747, 0.14857936680557268, 0.09384531873248278, 0.17088971641515532, 0.11205331347281895, 0.18770264972361828, 0.20494351974658429, 0.1317199319601059, 0.08389035855690319, 0.07722063620965328, 0.12577197168983761, 0.1403526397001359, 0.09836025025335052, 0.19182863074444956, 0.10785745757241404, 0.12478223971782193, 0.11242626039611717, 0.11918536222149288, 0.09776739779138759, 0.0930323921925118, 0.07670999264284488, 0.21032807597469902], [0.035013060325816754, 0.043388462114718654, 0.03029616313025115, 0.05901388636219406, 0.04125804054520784, 0.02123322998804431, 0.005540879820698813, 0.05972133025587086, 0.07022171055958157, 0.037365061336106835, 0.02654039792926802, 0.03203936938887402, 0.009055885133303462, 0.037998313444756696, 0.014628290908501275, 0.017586630401051333, 0.04169682506471873, 0.06178686417819512, 0.03861201498957892, 0.10052736743443436, 0.10045046752859509, 0.04222694258656233, 0.028242453775038163, 0.013034700663880476, 0.049601822055035064, 0.0374666216122287, 0.030948764704648527, 0.053366657737041676, 0.026120612390279293, 0.017161001526420156, 0.0151497861107571, 0.00656740220766815, 0.06515821411965356, 0.027290020708835898, 0.0440693534009399, 0.05358739448110423, 0.052919519028716513, 0.042846263386309154, 0.016685733984735225, 0.013270933451431413, 0.01762793786192854, 0.07816823334583352, 0.0030931396054990233, 0.011332527032091973, 0.06987130960389491, 0.08138381079920838, 0.015005958848632874, 0.07730400955845272, 0.024068586513279908, 0.04909447266630108, 0.009289156991027055, 0.0440820244952075, 0.029594307847981973, 0.043818574518926685, 0.036709064076985085, 0.048537787215243426, 0.04802411377069451, 0.026512678952947743, 0.028838479756227428, 0.04616689830718022, 0.05970288668909381, 0.02589761951727973, 0.03653038939040515, 0.01630829970142053, 0.0732283681751259, 0.03935050459638719, 0.005640172955369758, 0.039306351118871284, 0.019895433628511046, 0.06020501135818421, 0.0513169588521123, 0.05111793303982385, 0.03962810804706909, 0.03311071079224348, 0.029511836567713372, 0.017762367140441652, 0.010406919492168293, 0.05246219135099842, 0.03610864649676988, 0.03650637253397896, 0.04506714844835862, 0.018152108626259912, 0.020020388314620625, 0.02257197438138387, 0.06547316818708374, 0.002780083760303716, 0.01494999708337409, 0.027780075662679253, 0.020499834865932504, 0.04638953111885537, 0.005045910412821198, 0.02236271746486666, 0.06644852068876067, 0.043819229524101944, 0.017711102451768615, 0.10110537311242473, 0.034415860314883535, 0.05424062616281933, 0.01314083927295982, 0.019203309578100042, 0.013769850127338884, 0.028653473352953315, 0.026655816735940117, 0.07164792112645603, 0.02428217757222874, 0.007174986540414994, 0.04903152322156295, 0.04642948643454621, 0.03507748832024875, 0.04598024864530852, 0.025964966306703228, 0.018745681210871667, 0.05110222440693648, 0.023148323394237988, 0.006622906714197129, 0.07177828630853085, 0.06256738902940866, 0.09732661378239432, 0.01144066513065369, 0.029543309374862624, 0.04255678557280091, 0.03215499312406586, 0.03548854811777992, 0.05834420294230504, 0.05721446457168749, 0.058475671290990815, 0.045747783095125234, 0.02135753158419844, 0.034596844756555174, 0.014579645282919369, 0.056666259713951624, 0.042447307777981606, 0.0025998764190702673, 0.027408005910054333, 0.01463141846245215, 0.08426896686996184, 0.062289927304992755, 0.013056694090576663, 0.020078323713894335, 0.044365446383674303, 0.07778751063010386, 0.04791437933642057, 0.038481216967826894, 0.03845984694517909, 0.04955122960851558, 0.06619271626996417, 0.02052188479161311, 0.05244726029735419, 0.04224448216958873, 0.023217790331991933, 0.032505792445473136, 0.04049907340818355, 0.013435221006793362, 0.05854871011369171, 0.02653225824507254, 0.03385892205481087, 0.05277234587758299, 0.02330097981968955, 0.03629721903933152, 0.059605838670845956, 0.0473103343298839, 0.04016157720358141, 0.020415682022670106, 0.048476266524484085, 0.04370716235209857, 0.029078428070211125, 0.013316117317205476, 0.030361669393436565, 0.024131105033560626, 0.03745724086559588, 0.07031712681055069, 0.0886378973542202, 0.01678706251925999, 0.06409851150707373, 0.048618904435105866, 0.005593708286347289, 0.03071190947065911, 0.06540388319521181, 0.06726032107948296, 0.047287347861715866, 0.05012639310030688, 0.027487062353400454, 0.0270717641744282, 0.022187156925698923, 0.06669457280828107, 0.032462305464451356, 0.02665429796663023, 0.03374850963272395, 0.08139280467143944, 0.026017479718692844, 0.04102218888639923, 0.026567613202778083, 0.018007917472371654, 0.04700698649450656, 0.051970615712625366, 0.09272561994411292, 0.015250346642137777, 0.02805528891903739, 0.006932630316324293, 0.00765193899672839, 0.03090129406642049, 0.028887639618328506, 0.06051528079795742, 0.06097303748491311, 0.04129019708582952, 0.0810857872749048, 0.019604149762721314, 0.01958362818244965, 0.07455124880277342, 0.019452341779645894, 0.0555281863067179, 0.035967701640460766, 0.0366410929259033, 0.03892380894432145, 0.11461364060279824, 0.05180366217128692, 0.01824266979500892, 0.017820415537684195, 0.014922798089232418, 0.012297730783991998, 0.03972273522747621, 0.0078437635825286, 0.03544922099418698, 0.034686082508414984, 0.03346568529283808, 0.006729792737807598, 0.043974151654589566, 0.02120479471951483, 0.03362894245994187, 0.04204462898234206, 0.0258099886348411, 0.04677663917743391, 0.026978669169869636, 0.004071054431880194, 0.04852441898096473, 0.025649380216735507, 0.028174993987645836, 0.030829971280669978, 0.07395108786201285, 0.07004640665986846, 0.023433311932509946, 0.025644701334737965, 0.0679056658860176, 0.02694830335977097, 0.03546008029051366, 0.02602305109312217, 0.028788191829657847, 0.009265198548805089, 0.053529110511824976, 0.050250204400189465, 0.026901041480502295, 0.027230059007002462, 0.005682911085445555, 0.01246420264754805, 0.0027931757241247165, 0.0597479671329981, 0.020202039252786387, 0.011743651947096713, 0.026163047915624998, 0.0637931986561706, 0.07938193878339184, 0.029887604609792753, 0.021376316060101794, 0.02596147677620813, 0.052387712282999876, 0.04919535495460995, 0.03364691488264549, 0.02546846280775724, 0.06330690136359585, 0.012757922672936994, 0.027183687704945766, 0.048800107211835926, 0.022653953450161125, 0.04002383459479578, 0.05379841723028691, 0.03790822150486131, 0.036572945574598933, 0.01713233451629358, 0.03037522723447652, 0.09019474889482222, 0.0492216011268958, 0.05053570621737069, 0.01883901753312638, 0.06315771723166108, 0.030309148320567705, 0.02029554219916463, 0.08212490127451959, 0.05439149185774788, 0.06202447400878995, 0.08535816769806609, 0.03733161776777237, 0.007533662682098727, 0.05175412309566333, 0.03469378935293325, 0.024890305827401822, 0.07044508647654327, 0.02908931034917553, 0.02049755766957758, 0.08860820378627508, 0.047934623209819685, 0.005669839231432566, 0.03506523474389988, 0.009614762553434459, 0.012524695822878951, 0.05072323688035531, 0.01590851576052486, 0.04122348614938317, 0.021666084987021262, 0.06652006564000923, 0.01850238126221924, 0.015193474189859005, 0.044719497748320146, 0.025128072706021132, 0.05969028837317902, 0.007800899047945296, 0.055266820089591134, 0.03466490400774825, 0.029572748218572913, 0.0033548644475353464, 0.017122641588831623, 0.036847580434574236, 0.05172850894591501, 0.036397300765759526, 0.025193123146891597, 0.03270612443767248, 0.024248050270421852, 0.037117982658767895, 0.06612346192160923, 0.02069118639243947, 0.05528987167523273, 0.0662108495711319, 0.033351105352443074, 0.029447069579374888, 0.02865750680587465, 0.04695628296523806, 0.03844728310322089, 0.04741324675119212, 0.041312651122890176, 0.05279254761614627, 0.030296714713556633, 0.04417795785552552, 0.01660421648393235, 0.0558511421625172, 0.02209223480144095, 0.06152183606079029, 0.00308447586928284, 0.03306038264605788, 0.031048788974482208, 0.0703209036240174, 0.034676383835293596, 0.03226446708844554, 0.1384276139640039, 0.12472780150992256, 0.18507452381234016, 0.15415616513740632, 0.21351394453837028, 0.18519006519308015, 0.10981157166703094, 0.1330254070701138, 0.13819155163101612, 0.17517964025178265, 0.20319745214956425, 0.1281284658058036, 0.15111759995981572, 0.1697998031252815, 0.12424199451361934, 0.1346181038646929, 0.07260154737460037, 0.1385372717894854, 0.1800396867216595, 0.23797968252291604, 0.21169258582015194, 0.1284496864724544, 0.13328273600387958, 0.11910232595138012, 0.14767798775386426, 0.13917603590075048, 0.14508724693329106, 0.2664711206190048, 0.11161865050634069, 0.17348148379354708, 0.22077347031764447, 0.114849197317756, 0.1355109793404418, 0.1517797603962883, 0.08497189850576463, 0.1718029698296901, 0.22761990616638816, 0.1772252175836794, 0.11149315764346432, 0.17961614735184178, 0.1290256926609624, 0.1394583546226063, 0.140928523314576, 0.10179201771895732, 0.18932520862548582, 0.2026824725251044, 0.1674818049275106, 0.12904941074309811, 0.17775626973279063, 0.15123468883816274, 0.15739302451331771, 0.10066974487516189, 0.17920655078224598, 0.0945354950043463, 0.13311552965352613, 0.13274555515137412, 0.20837027699716631, 0.09114883479572113, 0.1471245198720886, 0.21333720805423878, 0.14013522394722508, 0.17754582537999078, 0.11200275933069569, 0.13260033552444753, 0.1836163673790232, 0.14032251712295318, 0.13104932923470775, 0.15935568048829035, 0.08871777734208493, 0.060715536181364334, 0.1763905647901758, 0.11789765269044908, 0.14245981050114478, 0.13420489136009447, 0.1525160168567973, 0.08088318000157034, 0.12487484442610895, 0.16373514468150754, 0.06359552115862889, 0.05784557929502861, 0.18082613726296734, 0.1517974263838222, 0.11281774664718298, 0.1427436460770907, 0.15815872939363604, 0.16376759616598008, 0.09225899578943368, 0.09773342179194575, 0.07807248767705695, 0.21664940451662387, 0.11778684573308115, 0.15377240105261727, 0.13875923810466645, 0.1493596733217278, 0.14063319641976588, 0.11252346163194989, 0.14924972438283507, 0.25317653803335083, 0.2675567897817781, 0.07715892782735248, 0.16675956787601595, 0.15216275839315307, 0.10701363470645682, 0.14761081716466337, 0.17444836336278147, 0.10036456608964552, 0.1438525583474867, 0.12208312043860076, 0.11795890908087454, 0.17673412458069865, 0.13856446791079738, 0.18483323675970878, 0.14915863652863812, 0.1890504282088049, 0.1961084115769594, 0.15580190585986262, 0.15925291745412737, 0.23187411498398552, 0.16608352592635542, 0.16720621245762995, 0.20916990425077178, 0.10887469976179062, 0.10457230401375603, 0.17805553431953156, 0.12705900706350803, 0.13618360453796002, 0.15952391339646232, 0.11608693493349899, 0.13105957949113461, 0.13908900831255222, 0.10456931627085132, 0.1541201130396897, 0.10426211501321486, 0.24154199137082025, 0.08765298407524826, 0.08774563474881072, 0.144932389920277, 0.12954477851669635, 0.1826192426585382, 0.10289926757855762, 0.2361035178745947, 0.15962076223184987, 0.14412753794702793, 0.08861548162155575, 0.10469186735609848, 0.1131028539290832, 0.2123862631138294, 0.15513709475917203, 0.13406694956844853, 0.08688444466961008, 0.08815900813187323, 0.10956840003810583, 0.18500946762581028, 0.0989665705410223, 0.14788382025735994, 0.16463082403905932, 0.20340241131282624, 0.17712317467216523, 0.11182340282586314, 0.13893513189208123, 0.1444941263405546, 0.1565683002193128, 0.19202586774143482, 0.0950406993468923, 0.10050852167149706, 0.13929617380903614, 0.08216135173795686, 0.2545754299048455, 0.11380976922209225, 0.15301369821592686, 0.09597954775897727, 0.13213057040927872, 0.16064021075444837, 0.13940558648638188, 0.13271950816194858, 0.1604470493452203, 0.3323280528908776], [0.02664061563630258, 0.00962860959266583, 0.03872755253987928, 0.09085533885105003, 0.018886702675973217, 0.021968998067501574, 0.03650651809068457, 0.09436984381247913, 0.021639741138525067, 0.016654213297090704, 0.04388264628247388, 0.054694621358066804, 0.026659235403302218, 0.07322638400740202, 0.013230777995270348, 0.01719360239803791, 0.013537858594058743, 0.07814305203576243, 0.0366117402670845, 0.04314322970927723, 0.07203698653968112, 0.019707320738703977, 0.05165795990896802, 0.039109987462119716, 0.028586019311220418, 0.031785150772080786, 0.0640225692111398, 0.04125501066746731, 0.06354438095924354, 0.01030217707833095, 0.03423269252262769, 0.07194206824586277, 0.03871008190476606, 0.05723628658621062, 0.056584843719798716, 0.018294970617599545, 0.04141270603624083, 0.039009446082937146, 0.02677663263203877, 0.07499567939028626, 0.04882156533459502, 0.04297430349153377, 0.04153435696817694, 0.06321433879014465, 0.010953471515207522, 0.030064055726172465, 0.02307837382109175, 0.02742315338353717, 0.06753347738976441, 0.025166848246308587, 0.04370782118771346, 0.0548820945644571, 0.04244343137308475, 0.10920201082743945, 0.04279881956115846, 0.023237844598629785, 0.03667795707681968, 0.046229932021590016, 0.029166595214196754, 0.048827908542608066, 0.012424248289467107, 0.044442970651171865, 0.07182523217653075, 0.02789618777892282, 0.02977063064463437, 0.05145614170619557, 0.08626776687320202, 0.09068604108066329, 0.05390476555593553, 0.028343106236969753, 0.061554938719998446, 0.06956255318777216, 0.06606295629734955, 0.02966465387162903, 0.05770740384656576, 0.02568421998031197, 0.03925378599594678, 0.0646704689209019, 0.057785475866929184, 0.04877280766865419, 0.0018981597508348886, 0.0371249272458015, 0.06850196574363979, 0.019885800072863218, 0.06011229939758778, 0.07363085544878438, 0.058768316878065954, 0.046697088607376626, 0.07090178979260307, 0.007223061909298263, 0.03420628164143812, 0.01098314305812481, 0.0194582847067185, 0.09175976693269708, 0.045078019236004165, 0.023883497755553935, 0.0438132616991718, 0.0217870234571878, 0.048401105638232925, 0.06025637755350721, 0.028833733841536507, 0.016985622933134437, 0.07336413427706688, 0.0426364625473657, 0.010305102576591797, 0.026183808898372997, 0.019709799033139023, 0.049166573031294736, 0.03883985336869955, 0.0565788452513516, 0.03796413443201492, 0.05463721455946084, 0.02820035341315933, 0.10154310043060011, 0.051312933060070204, 0.0418571442846329, 0.02144103516794501, 0.08107654059365874, 0.07645984961380882, 0.033133658956015305, 0.03698232380913631, 0.030043323471721624, 0.09023291539520988, 0.03330249707364748, 0.039151988232568394, 0.028519402220544797, 0.024629600361109744, 0.01886805418067642, 0.025299756840292006, 0.05938601740185292, 0.03457529470324516, 0.02846920813974594, 0.05515522406166119, 0.03291188799325497, 0.03727090913021276, 0.022804773179814223, 0.0644801496978729, 0.058783240270830935, 0.009612478653810198, 0.03194083899049269, 0.02683675712755611, 0.005210835257575157, 0.07951906852183804, 0.042401706394288814, 0.07618443334415075, 0.027461815925855792, 0.020655659064950965, 0.038905461138534936, 0.03148131647087153, 0.04740466656644018, 0.04471516169066872, 0.060222792258906754, 0.031799175926754554, 0.01905960680526351, 0.04923295071949402, 0.05303638191112588, 0.022214088746677005, 0.091065660629782, 0.03956983173866907, 0.03746977023359749, 0.04781943422952487, 0.0189930452559624, 0.013205182997720137, 0.039964313393518816, 0.032353103461284796, 0.012135491556217595, 0.04452301917837993, 0.03670918665105297, 0.027027903725543333, 0.09152807896175692, 0.05294908619215412, 0.0377608721535052, 0.030421753669337883, 0.019998792296035156, 0.05549805223821633, 0.0527732422004544, 0.05043092071108761, 0.029141856319901925, 0.00521769413852223, 0.021762146667066603, 0.016650752494892767, 0.05538983465803247, 0.057435163011353825, 0.11463643171854558, 0.04169537332810221, 0.02815683770384039, 0.02840258147297127, 0.060250030515054544, 0.03713588613355833, 0.06350979208946228, 0.015033019946948176, 0.02451468525724786, 0.03500462569777043, 0.06882799744245506, 0.04120745192912798, 0.02334509690802905, 0.060156698023239454, 0.03321161989362971, 0.07329846522019756, 0.025828886108713287, 0.0039413444943831215, 0.017779138720323964, 0.017494098471117117, 0.020271155705314972, 0.06491658232745624, 0.04969428886749572, 0.0009821646392904975, 0.05152462996662625, 0.01710138264893284, 0.03928247598871108, 0.02485879088541673, 0.027119612110958948, 0.05881858756765724, 0.0361420096258723, 0.025707034078697046, 0.050073858620899345, 0.036383794635654464, 0.02024195051842159, 0.06244858794455087, 0.09369685855363646, 0.019423615397705186, 0.012163811911558433, 0.027143506393317255, 0.03577367838231787, 0.04198253372563951, 0.028471456607803706, 0.12472890467653353, 0.012066467991849829, 0.025551817004358577, 0.025064414629953045, 0.04733594847963222, 0.04764192399658984, 0.0038947685032091556, 0.03163339066950064, 0.03702709398743126, 0.020118832528110475, 0.06149865040976194, 0.06504465690663745, 0.06512598480067908, 0.028666362782279332, 0.018194745249685743, 0.04082094908000962, 0.012922689990861522, 0.03934487768058335, 0.04186313126176115, 0.054802164780877294, 0.042891596639228445, 0.03854136253076215, 0.007445045461457584, 0.03012760463471134, 0.021439414891985156, 0.035721254985659354, 0.054029201217476404, 0.05939716781159082, 0.029563572400459842, 0.031194136921136133, 0.05060374631636566, 0.02695574015829592, 0.03372931146934148, 0.01964413572192913, 0.06372227806658035, 0.021289533620039304, 0.04079592864840262, 0.04380866900206574, 0.019143255945715695, 0.10743055507660874, 0.036858872570578134, 0.020408448237445087, 0.04816919933223436, 0.052558461790003126, 0.05264286935750035, 0.08027084592369296, 0.017541368011265032, 0.052511309078263665, 0.0419466654890247, 0.03544065996163315, 0.017127398994841406, 0.018429890192384203, 0.018241733252521486, 0.09401460118111103, 0.043821183048308864, 0.01291636114699706, 0.06992292860823293, 0.037750656371034925, 0.08480306804901169, 0.05481225415884007, 0.018605657575291493, 0.02924440101900649, 0.07225797992319831, 0.040769617358643206, 0.03257289025632124, 0.039005956552442045, 0.02130225451002198, 0.039586643538167404, 0.029019818513564048, 0.026533874690592773, 0.06422209298057903, 0.07467435147132605, 0.0746867084695447, 0.06852930742165736, 0.023508315770736626, 0.042638327971461325, 0.05780084742112987, 0.0363759269126721, 0.056304401913357366, 0.036624327091680425, 0.06390272624670498, 0.0706070451246154, 0.06325301473900195, 0.06134695733987516, 0.04227170893441766, 0.005673065419203692, 0.05302048941713668, 0.056846845789902636, 0.07761376188887704, 0.01852067352663125, 0.0517975372983323, 0.029408079534468633, 0.04372334978993862, 0.017888752495749824, 0.05985166862486832, 0.056289064833113266, 0.0316544657482976, 0.04867690495185314, 0.01999039214194542, 0.038775287478441195, 0.04138136154881889, 0.04569779202762631, 0.045947463912588936, 0.02235354547719321, 0.03729596020533674, 0.03164586641134755, 0.0720084191209847, 0.058322974645923224, 0.025673929504269076, 0.01648406708432782, 0.026094458148544355, 0.04369051909194358, 0.006560446129315683, 0.026602548727345084, 0.021834179999366887, 0.04836652059889129, 0.022166129727397236, 0.0461391008068477, 0.04392399587818692, 0.03577597664609071, 0.035390756994245515, 0.03750840404761895, 0.030733664452488867, 0.04362542460101747, 0.014421908736919925, 0.05158526965627267, 0.1430348360971097, 0.09569517592148435, 0.0762748776844913, 0.16777985909533116, 0.08782996570751553, 0.23495656167787893, 0.10486652774195518, 0.16995896555243, 0.0948987892197986, 0.10176359585696652, 0.15247817211333783, 0.16441215190195269, 0.13587215915322304, 0.12041292618960144, 0.10741363985524063, 0.11986132756236101, 0.07685524291328846, 0.21276754507374382, 0.17591834819364935, 0.16370378104188751, 0.13381410990991902, 0.12244240801420905, 0.15320627739833248, 0.08312050148003525, 0.11033707733957038, 0.1681903902921946, 0.11415028764355568, 0.1473420428773088, 0.13608778226039103, 0.10849255978340104, 0.07833475021705513, 0.16832525241038493, 0.10626869080888648, 0.19849780916927323, 0.08368808836225541, 0.1468287333245239, 0.16935553341623277, 0.12083370764289172, 0.0959262740047228, 0.11331895967164349, 0.13602716938382195, 0.2446519712647123, 0.1454944686303216, 0.21881400126843684, 0.18143013630422855, 0.15258586875373317, 0.06980502001580692, 0.17927578980884246, 0.1333673887195126, 0.15125823838095512, 0.19229801281565623, 0.15311332028960029, 0.13764419713087622, 0.21692731057203588, 0.12414871564795896, 0.13855211857345798, 0.10010323051603572, 0.10013355227607874, 0.08181619848455153, 0.1183143585559822, 0.1359710151389722, 0.11114593595266344, 0.27108447145550485, 0.172079864649042, 0.14716282426830263, 0.11134303505382231, 0.17806690306432787, 0.12996228111367072, 0.09729694319708694, 0.17106078384864717, 0.18892549459011326, 0.11571345174865377, 0.0982248365518547, 0.12907518194087092, 0.1535841272843461, 0.12121341912256134, 0.09506951957460373, 0.16634958826245802, 0.15300243672343994, 0.11398521101763172, 0.16603484869964663, 0.1402435028144429, 0.14000816060410393, 0.14428021927033702, 0.2220028575750128, 0.12990952829920477, 0.12170396054223662, 0.2504916143633666, 0.16522337772673176, 0.1991723495866022, 0.11752835234567044, 0.15089799319544148, 0.16687340854156404, 0.15334622634034004, 0.134963502266234, 0.17998020765521835, 0.16150555303019865, 0.21113360210532145, 0.20423317237967448, 0.16532221839072245, 0.1270617343365185, 0.17911428315264566, 0.1491211748291408, 0.18550500393875186, 0.1669294555341044, 0.06691110756007895, 0.09092114580374572, 0.14412545418787387, 0.1252274440541383, 0.16076175826451472, 0.12502547263378097, 0.1413728236671417, 0.12530497215207548, 0.2336420007650891, 0.10971522078879418, 0.06586680714521678, 0.17127040082648878, 0.13090637722803702, 0.10837430645140911, 0.09268609746809929, 0.1613436173647642, 0.22849182147652874, 0.16775050260607274, 0.13860185300150227, 0.1800416019414702, 0.11227927110608547, 0.13985799204918647, 0.07899397653677771, 0.11457593375516516, 0.16483671782958895, 0.1970695301650032, 0.13898750166258506, 0.18916339553411932, 0.13785675588634708, 0.2543460631803159, 0.11959103642091637, 0.11973130711985212, 0.1569330806453382, 0.15488889759346364, 0.14625573020067908, 0.20181449490689463, 0.11995249202535038, 0.20192907101685004, 0.17424928775477797, 0.1669906659592544, 0.1517902864443679, 0.15152587885818175, 0.13083520765987136, 0.188455177891639, 0.1105916713394465, 0.12433514314433261, 0.1854081704251228, 0.11636935324678499, 0.15364628765852223, 0.1888812606733653, 0.22511346566100277, 0.26257090570945896, 0.2411952752980494, 0.05958356849488713, 0.11685403409383952, 0.1048003837105728, 0.11892750468705932, 0.113065016846503, 0.13374473298749617, 0.10936366304034188, 0.06874372777078422, 0.16366714671734842, 0.18399484545713474, 0.1485117212418587, 0.20199110881695825, 0.11413127334127504, 0.08472351747895442, 0.09938122329091835, 0.15718782020191993, 0.12345159095862221, 0.17592836862369893], [0.005372720648489532, 0.03145426590626519, 0.053855697624385364, 0.04817894397063121, 0.022731106165015412, 0.01346595932714521, 0.02340961108735252, 0.06061512503712889, 0.059630207927717324, 0.010786788019862388, 0.12424386376815459, 0.02667554541521015, 0.028195534720115607, 0.10166355243493473, 0.03159954682022574, 0.07964960224325619, 0.04404098133466417, 0.0476100049432247, 0.10971649249474849, 0.032176738529796564, 0.055732785408655484, 0.042483513093283104, 0.031336043217790224, 0.012910183605497644, 0.08666905904969863, 0.0653603004531995, 0.032688695937395096, 0.010737654970838659, 0.03516963720622082, 0.057732554513119885, 0.10243412963445149, 0.07369598058322746, 0.03741920843059498, 0.031998569461246656, 0.032766258509288874, 0.021209772375802842, 0.031989146579778006, 0.04720554882360082, 0.007062013469441164, 0.03814253715738174, 0.002870464658988039, 0.0254095200028631, 0.040247957447483655, 0.07619878217097252, 0.005441834706993353, 0.023237022969330993, 0.08812359954801299, 0.03658943561716907, 0.022839775737074595, 0.054176473960040085, 0.07025501240165004, 0.026797301684235855, 0.022777741767405983, 0.04581900245900597, 0.04482267830040186, 0.015086572365685096, 0.05674024465523901, 0.04512998297990811, 0.0584304606121394, 0.00925348506444284, 0.06848348770290613, 0.02785204387750597, 0.07329679514852262, 0.020108586102123224, 0.03351397181470548, 0.03748047248189969, 0.04928262003006474, 0.009944714707202248, 0.10763379054204111, 0.01725412142883626, 0.04696231973808139, 0.05350714677103585, 0.04774601619330145, 0.03609379205191809, 0.03361675017062695, 0.03303255450220839, 0.049558013317085085, 0.05792561250047819, 0.017724070405106873, 0.07750208925215468, 0.06406865706066452, 0.060610712370685035, 0.06788519601668082, 0.07096175915531575, 0.032611328717922015, 0.029818727559740507, 0.030394115132249655, 0.10089066164988665, 0.06710038490353093, 0.017398638170092337, 0.07352886616342491, 0.031128090565964103, 0.03170110326590798, 0.04863293150499944, 0.043348997095299345, 0.030418208597468275, 0.06488603074103594, 0.07111020401240357, 0.03328986045333647, 0.021974431546104532, 0.048147875274862015, 0.014952504106106298, 0.05382002857063086, 0.05715421558688245, 0.022889125205936934, 0.03493019642548696, 0.03560412014203687, 0.04486872784553036, 0.003957198923378582, 0.04840030890679167, 0.014226790930655216, 0.044709768431681784, 0.03095849019084727, 0.056828884858517885, 0.02653499700940184, 0.032831540691756436, 0.007431255878820535, 0.035025432645793886, 0.07279137630135783, 0.04853819707228292, 0.05637614604746623, 0.043708928184764045, 0.014330196521064688, 0.036658234143209074, 0.017116120265376185, 0.029137286605433594, 0.009458828229276885, 0.050500232516036886, 0.06705494822874185, 0.018526072531277617, 0.05869129056771917, 0.06296675449477569, 0.05281314005955093, 0.06105826093604969, 0.05117550837777315, 0.05296634232264854, 0.054724648174258976, 0.1181222313654519, 0.023360497190526897, 0.060135546335650075, 0.038284573688982956, 0.06907715987894805, 0.03005792510755841, 0.03972601408379213, 0.01324905685314368, 0.0983423161350431, 0.027523549206014124, 0.027789893079428907, 0.05768814822658897, 0.02733427952344139, 0.03342013753529999, 0.055684081368869355, 0.010797711476052721, 0.07090049510401103, 0.040030070550499425, 0.07195280879856118, 0.025243665797696, 0.02010548727646951, 0.01338216941803694, 0.06270293296585161, 0.014150079673967295, 0.021140125407386693, 0.022260956090664672, 0.0560411932547727, 0.02899677458880169, 0.04092077799742261, 0.019356779971971147, 0.007420760953062846, 0.01977272549523942, 0.023668062339927402, 0.03896901962317286, 0.00659035180785483, 0.02039520832289371, 0.039183087571854555, 0.10589949771641724, 0.002428664386482729, 0.01750789954507303, 0.004758219020591388, 0.03566231984164446, 0.054446546766426296, 0.02557146332917675, 0.02922367451021508, 0.0945996548680048, 0.009017619041485653, 0.03658606483030223, 0.021378832658933058, 0.020345542842762607, 0.10447179327809042, 0.05922949031716394, 0.0966733935919981, 0.03151338491138191, 0.0723054773745037, 0.011765711448876368, 0.04894442285501188, 0.09933731879197782, 0.022428526332782164, 0.031015479471534494, 0.0732853344731754, 0.019204328475039334, 0.035364208217229576, 0.021667709093420737, 0.049428111618204464, 0.03093475678695306, 0.02519290672705299, 0.04822846772449632, 0.008893125923350453, 0.057367574904234185, 0.13402463087151129, 0.0883944039683669, 0.06729194518899725, 0.06366498618116302, 0.035002748782355944, 0.07489545976803189, 0.03995895843892809, 0.01676700442218252, 0.05785754941884549, 0.029153150371125633, 0.08066394095939976, 0.05782012219330477, 0.03325468935673276, 0.0065361065583513876, 0.03672584523296645, 0.048441639350306605, 0.05324612146303539, 0.030100036960756107, 0.046794826104756326, 0.015917620715504933, 0.038651556617790656, 0.008556054897546288, 0.051428171836080096, 0.04395897162236995, 0.04044573836689515, 0.0307270301310646, 0.1239700562831375, 0.07304736458125614, 0.027391598221936056, 0.14746651684324588, 0.07718813109902606, 0.09937893268802475, 0.04987661779347447, 0.03579487986562233, 0.017938082812414054, 0.05700136572423001, 0.024389927838778785, 0.02353326916965025, 0.05089741463081972, 0.017712847217016162, 0.09064906201655827, 0.013021318065453202, 0.014168980978279105, 0.008823800711862503, 0.024386313818995992, 0.05142272878137808, 0.11334899797915451, 0.06393716572934101, 0.04150468255242994, 0.04138379004753886, 0.029294085651335698, 0.03153949127262158, 0.0526547628725248, 0.06557069117984464, 0.05992426311657314, 0.0092019158558199, 0.02820641316864039, 0.014046813894604004, 0.010526109366647659, 0.10562054978142824, 0.02850645916506408, 0.04478188411843392, 0.094597831578745, 0.011955394818928215, 0.016604685712785974, 0.007174481879994875, 0.023327542003244165, 0.04271809687657703, 0.027925854533790585, 0.0778119488348884, 0.022008568424010472, 0.0435624674954001, 0.0411331643831105, 0.02799845094071521, 0.05506348120228899, 0.02131449276461236, 0.05711476971966125, 0.018618629359069373, 0.041409059457721255, 0.021437438385140513, 0.02350458300732557, 0.021378164247219122, 0.030174839700902664, 0.03061024002700804, 0.047930934496464274, 0.037893566242869825, 0.11214773380948652, 0.1328684662979457, 0.022494900190541824, 0.06289706730674352, 0.02964480261829111, 0.06672944513059433, 0.012463107141816329, 0.023156148982384515, 0.05429385395179834, 0.014593528711327143, 0.013892440474592151, 0.099712724857513, 0.008102160251338877, 0.021729126362310305, 0.0782042394782747, 0.030947607911882863, 0.070293125275883, 0.015958806559924158, 0.044708661434631196, 0.04858210157122343, 0.03734803120155008, 0.008103328535423405, 0.02137747476808727, 0.027965490007773045, 0.039154707844699585, 0.02822319049418213, 0.07819729106080148, 0.05021894801287882, 0.06237872455629611, 0.020545851852324222, 0.03028307451806482, 0.026618278427650372, 0.015683985923627214, 0.07245035226186437, 0.02455499105816407, 0.06521429941659013, 0.04644958475123971, 0.013988186143368725, 0.014488644571223808, 0.019021884635871938, 0.014306117419994647, 0.0347060582510406, 0.0687287277692268, 0.032618821057821476, 0.040756088245900414, 0.024528415468070778, 0.029045156871659622, 0.049072099068472465, 0.0856966789691679, 0.015832309164257062, 0.012655594393671041, 0.031933310261416825, 0.08018877492436478, 0.025038289116515268, 0.0625265182386483, 0.06168983531214538, 0.03414283423954922, 0.04983364792180158, 0.02731441869400442, 0.09994485715944922, 0.09803736717590401, 0.14999788584968737, 0.1998569563992562, 0.10380499800967594, 0.18145610668486167, 0.16889592662693995, 0.11962318147021918, 0.12818789124609004, 0.1524213590328732, 0.20610368329911463, 0.19965087874762474, 0.10102965298198885, 0.18012714331909535, 0.09569259420517953, 0.17543752076885394, 0.12238780126696634, 0.0900246850365112, 0.21161455210418473, 0.12192218834834716, 0.13234225582451592, 0.19814332496495018, 0.0903097003878605, 0.10420818242334551, 0.1340901926760712, 0.13350459506675122, 0.10496798076576765, 0.06924439687281847, 0.15025386646870645, 0.13989526988758197, 0.2564992452220571, 0.3271717295771645, 0.26694955784947644, 0.1060085579933178, 0.25141919362208537, 0.14994381536399165, 0.14061914636723458, 0.13614326234786742, 0.12854285808580537, 0.15563410196092822, 0.06635901097568773, 0.22628023289144042, 0.11490833930551045, 0.1257965094860523, 0.12372285503173068, 0.1340996768445738, 0.19427871782212489, 0.2410421496437442, 0.131445657161455, 0.18579141357012335, 0.12471304665650092, 0.18272131621356935, 0.12439229330348393, 0.1870331348430726, 0.11735716233811072, 0.10416839181655839, 0.11726694782414745, 0.17968776125100352, 0.18690933503450888, 0.10769330025199922, 0.3025435656309128, 0.12341675694070517, 0.20409150740071652, 0.09452492299099123, 0.1387294832496874, 0.14470585772106725, 0.08015193375608615, 0.07544253847651905, 0.2734791703762547, 0.13717614805265782, 0.1006454062618075, 0.15060078172433763, 0.13071577455247604, 0.1522598676984349, 0.12647779147711494, 0.08830666391839904, 0.20816210026462234, 0.26534959854137513, 0.1880660052261045, 0.13324243977906244, 0.17965875716219026, 0.1420976960610959, 0.09720489773298464, 0.1457707352575756, 0.17019516578124416, 0.10427020490169527, 0.1253982050524604, 0.17614815924917498, 0.14070223626350203, 0.09449287753311858, 0.1876641001792685, 0.17309044187347736, 0.1542355318463618, 0.25033403007734206, 0.05053925320446011, 0.11993057424983672, 0.14664899377572924, 0.17231928244713815, 0.17416149407865542, 0.114418518008484, 0.14993871321841595, 0.1346153459481655, 0.11343804037859363, 0.16246037437550484, 0.16573536960828691, 0.13750640855681512, 0.12887472737460368, 0.1436349280899571, 0.08426735042444161, 0.10673104019294824, 0.13740021344875136, 0.13997765498295908, 0.0870361454003761, 0.1882309439562021, 0.07671626690294474, 0.14033866625639702, 0.0741987564270535, 0.17412340418706018, 0.20948130367023332, 0.21371763199567798, 0.1332197942200207, 0.2236948087210617, 0.11773093663636716, 0.11445357419189908, 0.07159774236741566, 0.07600014323308583, 0.09002696031764632, 0.1400091565184055, 0.2070589030101415, 0.13994483577628292, 0.13496108142839325, 0.17560868013289668, 0.15820290202335005, 0.1550541887240064, 0.12153384305777089, 0.14042218516190208, 0.11511486128813798, 0.21144175331198403, 0.16760295407185632, 0.22262214773124267, 0.19722426460394937, 0.11355209554876051, 0.16955710647086944, 0.10833471502748229, 0.11181491457166211, 0.2623132856622819, 0.12047878676845182, 0.11449593885411179, 0.12441675449090621, 0.12272177729755641, 0.1934214041478211, 0.2090252821724261, 0.21011426083503232, 0.12125468827904233, 0.20699102762005023, 0.2943895709130072, 0.10812275382059236, 0.13750763429749396, 0.25072101173141315, 0.0995329470043221, 0.147354606719267, 0.060399750908536304, 0.08361733248156887, 0.15083011780535022, 0.1861380223905848, 0.1452902142679499, 0.09446726721380988, 0.08054547312278902, 0.17486775053604958, 0.19545647075339673, 0.06849823489544854, 0.13983456508046196, 0.1325190995609568, 0.11951817379843806, 0.26175407212107415, 0.1147399531797536], [0.027757504797210137, 0.02642728504724801, 0.08682262903499989, 0.031766586546455665, 0.04632613734312115, 0.05102341694216575, 0.028924507599684502, 0.0009353480486278123, 0.047324683156705676, 0.05510383871414008, 0.021585431250353015, 0.06493800980669838, 0.07379491317776904, 0.06035552465266759, 0.012573426675742433, 0.0331267143689817, 0.041443774732010025, 0.10297302652390734, 0.03351413269316958, 0.04705327352689159, 0.02228623316172631, 0.04465632613808398, 0.03959029777756622, 0.00735428415223836, 0.016336313621591658, 0.010152378160836957, 0.02273648027180424, 0.040199107850991914, 0.03648307580020159, 0.01954331280543439, 0.03211946771179717, 0.08320933703573481, 0.04154915778687404, 0.04107007321210639, 0.027789431511454528, 0.05463415403820334, 0.029244073516418858, 0.06078027444140566, 0.023756980250078826, 0.067221419134688, 0.04673474182885501, 0.0321606736660244, 0.017048055268523675, 0.06650707278881343, 0.0398556744649766, 0.059544858072073235, 0.02090470084259587, 0.028011748311860908, 0.04757978660505145, 0.02754643416753219, 0.0641719218824179, 0.03651289577265421, 0.01836225995042872, 0.06332629870983862, 0.0393754024539263, 0.017907492921597535, 0.1344588188634765, 0.030504064071142388, 0.03934278243011044, 0.042067898903042085, 0.036171825767885295, 0.05926658812489721, 0.04457150105266802, 0.02502119386448495, 0.020911999745294455, 0.020044763317151416, 0.09431214207002232, 0.05080467968758556, 0.027938140668876232, 0.05232675466686488, 0.04965266731056956, 0.05601156480430115, 0.06503878867313748, 0.0894524020353152, 0.06279544574358771, 0.07300458623156433, 0.03992912314471699, 0.05984562036070613, 0.060874779047744895, 0.01181147849908279, 0.026136215686077074, 0.032127027084390004, 0.05217928657188051, 0.03765464640192447, 0.009151786892494608, 0.025987196263046037, 0.008670066975267425, 0.027844497911451806, 0.04734750108553037, 0.05178799567323539, 0.047943923517220446, 0.03996942703041338, 0.09832706332447068, 0.025990549812934576, 0.004951607862171988, 0.08021182651000638, 0.03678364273641379, 0.02853008914708851, 0.04042313877312888, 0.062334632365814144, 0.06580276219474693, 0.0626355861764281, 0.01566590050295476, 0.024931402614099846, 0.05982514666092973, 0.04321729892023629, 0.05471893315834384, 0.033965975181349826, 0.0362830579040512, 0.021219344644416726, 0.048010389305531025, 0.03711117213712104, 0.03715289711591698, 0.09403138616753202, 0.058245618917769006, 0.023290721902383432, 0.07032909310392796, 0.05564936226414097, 0.03556765435684112, 0.02076637983742741, 0.025519053339056914, 0.05037845134915364, 0.017439468741236676, 0.021318897770176974, 0.03817572025582194, 0.12486953543679369, 0.03813377694196759, 0.022488518678132566, 0.03499662390940132, 0.017292724599340753, 0.019755794952112823, 0.016937598796381105, 0.03969856132302554, 0.08033527391812495, 0.020506390663344535, 0.04113866872484646, 0.043874594698389696, 0.048608631196041266, 0.0023673737615031464, 0.04371254411976665, 0.012055992697095199, 0.05317947947450223, 0.020722664945248156, 0.021655332943003987, 0.08941378354305222, 0.04657863609252438, 0.05741070182393155, 0.06090950964379215, 0.05045433618849324, 0.05596825402350195, 0.08565739398041079, 0.02744864112877798, 0.01254138121786978, 0.1141010205291452, 0.016438553800746318, 0.06443989943833121, 0.03598385843478384, 0.016403306095350175, 0.05743512087651799, 0.02919189909833574, 0.02371313129251282, 0.017590817071557525, 0.035499909201696996, 0.03470692393039504, 0.03313570824121276, 0.013996766328120665, 0.036645478779269804, 0.08494123966703493, 0.047372647921644875, 0.04881484291305946, 0.023708848861016096, 0.0363725982606411, 0.05163744024391617, 0.022595502856758334, 0.10515558037666545, 0.04568274989123306, 0.043646009383542884, 0.027151234305253433, 0.11042929134301602, 0.044932822591715285, 0.013582642178892369, 0.05528623658803202, 0.031214147137718338, 0.07230658054111466, 0.04904699819763342, 0.045611319853173155, 0.03776570999874704, 0.04758257133465621, 0.0499350932847348, 0.10720904841418229, 0.029073977099371054, 0.02082084294318432, 0.019915648773612998, 0.09396940199357849, 0.08804827778329773, 0.07149239761694785, 0.033314865563184984, 0.06804185333631693, 0.06298513677451881, 0.05792447869035025, 0.04341674991132271, 0.025732010460248398, 0.06281013547953579, 0.07574756404445057, 0.020990734431712378, 0.00789506466037804, 0.08297435488672027, 0.03628629462553128, 0.05453348625451327, 0.029805585321399476, 0.05716479143067714, 0.00510028446085691, 0.10384148677750941, 0.060717060696333654, 0.06626063762533088, 0.08678607898013246, 0.06202117983071555, 0.05250499268332797, 0.05164466445304213, 0.031238615986019857, 0.03309976339580552, 0.01855186096602871, 0.03285204120461018, 0.017529662187782027, 0.08330344327635343, 0.05082051472498044, 0.06320991080194231, 0.014909163639400036, 0.027014198412577954, 0.030534157920027935, 0.05669502631550836, 0.05408003498169203, 0.06044530249651402, 0.06916997909185386, 0.05576189674977815, 0.08216065459794576, 0.03277335248346771, 0.07165309221994492, 0.061760204318430156, 0.09085985110892404, 0.05531675753093535, 0.010728476279895875, 0.020400706918970234, 0.04897981994755326, 0.022438020077383807, 0.046141789775461926, 0.04873578646971334, 0.039047340622111675, 0.045830386525560776, 0.039721850395923665, 0.027248694095760587, 0.025317340473374052, 0.07820893559725055, 0.04246123908688465, 0.03295785709915142, 0.02838270149133619, 0.06636130923946058, 0.013308252467052832, 0.062374625985901204, 0.022705687367687785, 0.03246637339132928, 0.03859655916570656, 0.030319212800672943, 0.010285423693036842, 0.056910201261240634, 0.028751538352920648, 0.03693637002499835, 0.036467114358299205, 0.17752633610319707, 0.02124030864046466, 0.03309694419224416, 0.03750234046169827, 0.020074700118012486, 0.02263722783555427, 0.046469817133319956, 0.06315246952937976, 0.03610120778302512, 0.04599827469416684, 0.014381453548858484, 0.054629274058125676, 0.030797443187405026, 0.08342993205353137, 0.0268923080781655, 0.009350560853377947, 0.05479687111332052, 0.031723743079290274, 0.08317532273189676, 0.03290319289531439, 0.04442110267137328, 0.0432188579091622, 0.020372514883356712, 0.004435920563992113, 0.01936557849178151, 0.06112626656108807, 0.007835390720321167, 0.042780276402951255, 0.0869735943213586, 0.02448908451403822, 0.007192722433471993, 0.07055115134965989, 0.06031198787593073, 0.019413047214789737, 0.045170566487696864, 0.040264539420604706, 0.02149607667008475, 0.008472404799484199, 0.008799841312030631, 0.018316329148928487, 0.0087001838067907, 0.13842254246194519, 0.021644155720188733, 0.037400492902604804, 0.026674131982989853, 0.013011993817804803, 0.04334782881121482, 0.02700402476494351, 0.07712581750726508, 0.04409086898029332, 0.06817878389190282, 0.04814420188326509, 0.07660192061936663, 0.032393529921049075, 0.003020223596268484, 0.07208940227546039, 0.07201045691486328, 0.07825208933002527, 0.025083417440914822, 0.036236284405834256, 0.04417104391200889, 0.0297729806193421, 0.06672215963443441, 0.014953171560210327, 0.0038010304635991495, 0.008508251968681092, 0.021169761518737482, 0.013112234507477092, 0.047035201512757814, 0.019844322157422864, 0.022245536655968717, 0.03364110793617945, 0.05574745216196584, 0.025748381759190274, 0.020911785240675655, 0.025363506846911004, 0.05313192839704214, 0.04408156867289255, 0.043942588832109206, 0.07951797301610632, 0.03885560796686238, 0.023285855328844442, 0.14755841675064257, 0.03358866921776245, 0.21157586466400854, 0.06698644464655269, 0.18509315507065865, 0.3265929041850952, 0.05113945244961689, 0.14820801334515696, 0.2069838110718035, 0.12258727524069049, 0.11875347249330052, 0.19776524525255929, 0.10650618572629268, 0.17072123835884756, 0.22740371615415622, 0.2549120795822913, 0.1908291617949163, 0.11202836198912514, 0.08738876801104316, 0.16594078842430346, 0.16980326584269925, 0.19543764031221791, 0.11595810958815199, 0.25587301430923326, 0.1435493101035395, 0.1366460305308142, 0.22939578990542123, 0.09546705792027135, 0.1934118280487676, 0.2126240414837676, 0.08706540229820436, 0.08246882112636682, 0.13560608149536196, 0.1290911472132129, 0.0858117223927571, 0.10246237529621971, 0.1256113077303575, 0.16180353058922678, 0.20571048101109846, 0.14479308449212583, 0.183195999613212, 0.1358010815156083, 0.1305159788218237, 0.07702277868144936, 0.12917701034776627, 0.14175565312466315, 0.14106795131679506, 0.14648796209404547, 0.1272156720440234, 0.11462490209528517, 0.13431606603966606, 0.14811360066936863, 0.18555651569078047, 0.10805205922693976, 0.08819173540799849, 0.147241746646262, 0.24061427421627507, 0.12910957928867112, 0.2655820909046358, 0.21021674807754256, 0.15216193101819486, 0.18316595364482174, 0.11459421261303848, 0.29122112318873405, 0.1677995475549852, 0.12158795184786282, 0.1796943955724278, 0.14656049529871634, 0.20116733447197946, 0.1573111603577291, 0.1508315274071309, 0.24244787501952342, 0.12503249766004662, 0.12368214511943441, 0.14430914675035786, 0.21022286145917832, 0.13270645402371883, 0.18341222026896092, 0.18305010582891204, 0.12801314659056165, 0.10515262327727773, 0.12300926711290114, 0.1408926397562027, 0.09636080673625393, 0.1369810867453775, 0.10270522516821662, 0.137711490294145, 0.08471518244233825, 0.0901545292787975, 0.08022281221084057, 0.1108560482821157, 0.16273042036881372, 0.17786263338019773, 0.15165312606240475, 0.35120240622951143, 0.19604605201992298, 0.09465089848925991, 0.21565070165501488, 0.12379810018765351, 0.11850858482742503, 0.26610226460522224, 0.16405529282506437, 0.24014224148085042, 0.1256465094704782, 0.09269748919553335, 0.08396722015834625, 0.16711529314277634, 0.12253102140441058, 0.20492511831464308, 0.18138625478792578, 0.08566355332732202, 0.07381857763375006, 0.14340721611534396, 0.12011616671037291, 0.1336015051891727, 0.15730959753836357, 0.1320974907327083, 0.09197203457475671, 0.21562497642251754, 0.14685733904761655, 0.1462923185599427, 0.09200685327091525, 0.16262198828401106, 0.14150702694971717, 0.13613717960974864, 0.09341218028097384, 0.212516084373478, 0.1502732791367077, 0.17247548777489893, 0.08100662740968889, 0.08846244789780149, 0.13356323143647564, 0.0941690291848875, 0.13121336398105468, 0.17695710213193971, 0.18282366556025323, 0.11885919262685123, 0.17660750556857358, 0.10827915067033422, 0.13628921741920133, 0.15492819790397921, 0.14663551062826188, 0.21265436324381062, 0.20248756443540897, 0.21721609507597264, 0.16814560479214116, 0.34692273264931095, 0.16581072201651914, 0.2061439795239318, 0.22336159111751666, 0.14467277804449682, 0.13012386437865997, 0.26000490952884, 0.06607064015923009, 0.18441334396841066, 0.25265372899030486, 0.1463408885343421, 0.11522258857205031, 0.13116977357816312, 0.08622772345739989, 0.14663569448936373, 0.13453982500058992, 0.12428039084038428, 0.11567300996713101, 0.1664639651895531, 0.11975798996225481, 0.15523349926356347, 0.07965260530791937, 0.16568920514996976, 0.14854535250173462, 0.17701420632581558, 0.12701118785527446, 0.10225703308899557, 0.16318541530880237, 0.06579617383859812, 0.09556594454953748, 0.22685723499424998, 0.1944317362241207], [0.04884673515334726, 0.03131817421695638, 0.04016824599896227, 0.017047693291979454, 0.012783600024939066, 0.045858842861508174, 0.020020533871326237, 0.04958956081780696, 0.018335232368460106, 0.026763371650069475, 0.03766737878322601, 0.013983863492255971, 0.10985038934215424, 0.042934750372003165, 0.0495887985603223, 0.022088860184134498, 0.030254729264866442, 0.03939461210862764, 0.026354181107073545, 0.01172509921279045, 0.02622815006743035, 0.027539939657154105, 0.04910180412773644, 0.019062154047611742, 0.009301990878978565, 0.07684617243226498, 0.0412934874334643, 0.08419762876245283, 0.05492090457870115, 0.026599578221418688, 0.0253430312319148, 0.021245236501037594, 0.024649451614447662, 0.05320992763905276, 0.05021975240519932, 0.017157452624110926, 0.009410466056226963, 0.025480894499548504, 0.04610600197807916, 0.05356190673586342, 0.02764631288066026, 0.013896951774856257, 0.01914264116015646, 0.08491321617076475, 0.013517792836102027, 0.01502205148309229, 0.023382886110113996, 0.019498398985653635, 0.03199994458907074, 0.03837092328936823, 0.10602974798530342, 0.09036593124150269, 0.0484723862891476, 0.014747084332479826, 0.035322935230308966, 0.03136355726559076, 0.02825055132439781, 0.04140230639266872, 0.021487519467970537, 0.0381706296015651, 0.02795766825006614, 0.06432714661763561, 0.015795873064968376, 0.08181844312216967, 0.040600545584194125, 0.07926807513520603, 0.07502569471515956, 0.006622826753770032, 0.09685001516294095, 0.0520543452923096, 0.06182260601030243, 0.06154323289651544, 0.015006003856298425, 0.09235088037507189, 0.018745077916631298, 0.003567682715290557, 0.04327010919129656, 0.012142743536030814, 0.06894807406370679, 0.0419479180427809, 0.014650612795394997, 0.03393985541357148, 0.04706357740947316, 0.061862699221819646, 0.02871374148995646, 0.05696439815144386, 0.018138535463461475, 0.00786058352171113, 0.07515938471882574, 0.06842439934130638, 0.02660586971849684, 0.07524692558593328, 0.031222001454162023, 0.0586913671765116, 0.04864118610238356, 0.01914723385726252, 0.07307918787363075, 0.047217522777857325, 0.07493525803569825, 0.038894161341651794, 0.05072877952648748, 0.037781127518223184, 0.02527649649569104, 0.051409636338752125, 0.019757926591762134, 0.023497117480503458, 0.07102666978514002, 0.009284006007346175, 0.03230208200552771, 0.05136388173747448, 0.027354950490858287, 0.01607755210340744, 0.06403686441180688, 0.01967971667557234, 0.020009019569824302, 0.04318628768106142, 0.056920470669865615, 0.024617747065701315, 0.05608119836617863, 0.039552238529487964, 0.02829381805514136, 0.0455342092731547, 0.020177692978552753, 0.022848401887101993, 0.026626052304862008, 0.02317473810586718, 0.06749102845788002, 0.07799711994706623, 0.06673629395663738, 0.06590881940698431, 0.026312659141577543, 0.014716964628126834, 0.014824720640336315, 0.04128748896501718, 0.020381430231575525, 0.03889340291460676, 0.007357981005277966, 0.014568369426283867, 0.03405332835691591, 0.04831534975598897, 0.05594858471604605, 0.04650627525763647, 0.05547619958017623, 0.02839332521562615, 0.034183559473603964, 0.025147766911334572, 0.0631098635494709, 0.04143161691665169, 0.025200757213057052, 0.000970203732468954, 0.08744456985544774, 0.02787679617833947, 0.052476643599689975, 0.05392826913345245, 0.01477674438407825, 0.04252002867419393, 0.052767354814756307, 0.0486001889071157, 0.045435947005546866, 0.018513068188762954, 0.031120987015686212, 0.029440609542953394, 0.06791081399686875, 0.009896636944294218, 0.04153809930768706, 0.03379679998503097, 0.07213277817373315, 0.0569826616875587, 0.02977159591541896, 0.034768241607854446, 0.04667060877827387, 0.024074140650730942, 0.053290546901764414, 0.05306169728658373, 0.05228316809441294, 0.01948822342279938, 0.0373219765512453, 0.053905175412975015, 0.04227657742317646, 0.025792094736149716, 0.057630768241060365, 0.01713123709534205, 0.009407771341953306, 0.043327581107376084, 0.01986745418229651, 0.015922308215991627, 0.0495412819568188, 0.0348488072444114, 0.06137141469685782, 0.0633268119887479, 0.04290322968435865, 0.03324512091855849, 0.07524117992650117, 0.03370228771781249, 0.03000597860063276, 0.03388459366115351, 0.037630062640434316, 0.10363272781814299, 0.04642450303259877, 0.015809460591915396, 0.04057763189437889, 0.044046206054307764, 0.0029061064208602354, 0.06381216316273616, 0.049390255383426146, 0.019610035233199596, 0.028745357938591513, 0.01057146464459478, 0.08824268791584239, 0.027935256347841317, 0.01867624874707432, 0.025877858279272917, 0.02321018690934345, 0.006044689883222623, 0.04318473635301475, 0.0386402185165113, 0.040148484760955463, 0.039123129700460745, 0.04699173368393414, 0.08095756713901797, 0.048663938913734696, 0.0686174075329496, 0.04184585980950825, 0.019983529909363678, 0.06367676095255921, 0.04033525699689504, 0.02865647067195706, 0.06806519603536976, 0.043759145248200626, 0.058654832443402666, 0.054411187978281136, 0.017547626949606404, 0.00956804746942174, 0.07989137959215911, 0.030597691506808324, 0.02571094878799012, 0.016914725326181903, 0.0403143274748037, 0.04167941954707907, 0.06998836783872497, 0.03008132909364518, 0.029562760347260103, 0.02485820865859428, 0.046434745628146396, 0.07219120769971801, 0.04414857072275012, 0.0370337053262178, 0.05006022608628677, 0.04461666193580435, 0.10182086859018573, 0.003048736431200298, 0.09217383745577067, 0.053306906709387425, 0.013214349239734153, 0.02487593976360175, 0.06435025949031115, 0.056274313810131246, 0.015482543103937662, 0.058443147028165485, 0.006571488329134281, 0.06308516104435248, 0.027224715543730606, 0.01987561110347029, 0.025043663223304098, 0.10557277653847011, 0.01852709717387634, 0.02292923565443245, 0.02031884467860143, 0.021046358160674575, 0.0352150202548552, 0.03920597444859244, 0.04690459884342648, 0.07331310516043056, 0.003917074828941916, 0.05417111900544936, 0.0338776835480765, 0.06649032610678865, 0.06282725754464347, 0.08223593039738555, 0.028143546078354124, 0.01956623415612886, 0.013849985797048337, 0.0425098205526029, 0.04965682333755878, 0.06362310032390299, 0.03319482724632948, 0.06174487872950493, 0.0216813224758352, 0.03029118164352352, 0.04491219950479366, 0.029759863278858607, 0.019294286349547968, 0.07651062592143014, 0.06154047497998803, 0.02326323083722063, 0.025594089736020374, 0.03389713069003436, 0.024567577882759997, 0.11044471269293178, 0.038279816282973174, 0.007498904315364217, 0.09766316386840998, 0.030206498284373554, 0.0021689031235573274, 0.07383957610375459, 0.03998676360013985, 0.03795633182650612, 0.04129577037547866, 0.04736902815620265, 0.02304734726015839, 0.037029434386039936, 0.05302458415709196, 0.06765819650383727, 0.03586102772744433, 0.0666373077359411, 0.027943658417150862, 0.03261900108848368, 0.03155975621343861, 0.061784979601901394, 0.06071118480195442, 0.06341331480671802, 0.11596596198937587, 0.04927805031559641, 0.0067584707604480855, 0.06292588753445495, 0.03386059595692543, 0.07585166773248105, 0.07217625366343607, 0.01846209269828133, 0.026111381030791712, 0.02907960976083433, 0.06438724621529542, 0.020666529852596503, 0.020487158026005474, 0.014107962075110166, 0.04221200387203886, 0.04693739889790455, 0.015029041077791443, 0.026400263210938826, 0.011358284823326095, 0.06028318680041741, 0.027309000537159945, 0.04955875642237164, 0.05756353253438588, 0.0614483337548952, 0.042413408387332194, 0.012556487514126687, 0.06682130673359479, 0.13138980935177497, 0.02829958669721119, 0.025581740398680972, 0.02590277337379033, 0.18493451358329865, 0.09002892916361172, 0.1990867316001846, 0.06892573493983477, 0.22462837878734837, 0.17508725004811443, 0.1149262810846971, 0.2362779867384703, 0.115213334229925, 0.1132800194224523, 0.16359084436009008, 0.2255083380206939, 0.20472754423897113, 0.15276300360358533, 0.15208006686260625, 0.1597319981984554, 0.1907038451322625, 0.15314073091553104, 0.2253672552685584, 0.14074925874029437, 0.22358147367354364, 0.2978984374673136, 0.1692625456639836, 0.12080385319648251, 0.09697353917985194, 0.16466062485931382, 0.06059043402332933, 0.19740648627761873, 0.14055517802555717, 0.12073427709119937, 0.21203793825641756, 0.06433762670043977, 0.21776953231423132, 0.12855384378663956, 0.11813241267396558, 0.1301971636712551, 0.14356175137142982, 0.1024396071631101, 0.23703681214922862, 0.09994422130647207, 0.13721558625899977, 0.13056966626355726, 0.08526996799534367, 0.16927239755468984, 0.11283506789515096, 0.14731432581620832, 0.15477485774505526, 0.13941959057363773, 0.2507266654602943, 0.14667602135769783, 0.23254488624872702, 0.23937187878595245, 0.08800905408157457, 0.16761855162199468, 0.12208247692474436, 0.07947053685183487, 0.11536228470504285, 0.1313811525582306, 0.09755222667609492, 0.12081751254417243, 0.13453282295696198, 0.12480402725838846, 0.21623822980590407, 0.1398850043093966, 0.09001824989794724, 0.1715075050390536, 0.11313760367732857, 0.16561279554040204, 0.201838580711234, 0.19647898362769237, 0.2349694779202823, 0.19320788012156564, 0.09938249499687266, 0.2242578220583739, 0.0976640065651267, 0.15552168621891932, 0.21277065539071638, 0.12913767939373372, 0.09177190176541768, 0.2541228404809391, 0.16301370436145415, 0.1521766858716165, 0.1563257874260026, 0.14869394291552807, 0.086128844489013, 0.1221020657929682, 0.05758491404835255, 0.11637162086704086, 0.1437273336153838, 0.13509438072721805, 0.1135283774666248, 0.1963921705441129, 0.17602025320933712, 0.08671936038280688, 0.1387826957169079, 0.06518229226311369, 0.1853838088291307, 0.07106687407940626, 0.1904371392823035, 0.0903688500364942, 0.1343368729876895, 0.12939398176968098, 0.20579882627052648, 0.15987917901046816, 0.11474445777674837, 0.12052854417913383, 0.1594786835654128, 0.08918836983221193, 0.2630327647972492, 0.07633071783329211, 0.07679332768724811, 0.16332430704947443, 0.1112764543523231, 0.13391961553885093, 0.1305757030364006, 0.18406048387048707, 0.2005428349178645, 0.2782942168414593, 0.15572476080588757, 0.07435735194913803, 0.15325657873144075, 0.1634213397459638, 0.1685647161737565, 0.09200833948148836, 0.09796128698414373, 0.16498595175723876, 0.14187375323907023, 0.2669956150554842, 0.13928701139746175, 0.13669083135262614, 0.12537059524366934, 0.11353230749767636, 0.1489198316008814, 0.19891567948845126, 0.13861944238024373, 0.10565234243028587, 0.1147659925082999, 0.13942110742772781, 0.19174774718140403, 0.0798879245356206, 0.2603417430673876, 0.08423936523256764, 0.16872049249227972, 0.06973424115248265, 0.19688049030880775, 0.16229692185598035, 0.165407867020657, 0.12557544715462193, 0.21772125345324317, 0.15612468934587895, 0.15776774876060026, 0.14342652153103583, 0.15730164554570952, 0.1529192089313461, 0.17255408839593012, 0.14524912131169151, 0.19998420360347918, 0.11910105424542582, 0.15241630285257293, 0.09893212722794664, 0.25233814673077676, 0.09401440199825073, 0.13520025407835362, 0.11980731836369923, 0.18329966663112565, 0.07068139395766682, 0.14456106710337824, 0.17065420566547304, 0.10650109890247546, 0.16593993040582827, 0.14491527551604858, 0.19854264063460214, 0.19379914678152532, 0.1045942600936659, 0.12084192776631926, 0.09807550303277471], [0.07709574089535783, 0.04928319076556833, 0.05615489985493403, 0.030271397422878977, 0.04842081325008504, 0.05362097594526507, 0.04014976795822863, 0.017212877170212807, 0.04796355068984051, 0.03378363476405221, 0.019649082734700174, 0.06662697320984257, 0.07121140422720103, 0.03403383908012221, 0.0785854678120344, 0.04102611508701117, 0.020131974766451507, 0.026647684712623878, 0.06782416179175339, 0.0800609378324401, 0.04365347107992538, 0.018743547656002547, 0.014097339308430112, 0.04144635261787523, 0.01691280627593158, 0.031232144458279498, 0.01766175489812609, 0.04656855820588047, 0.029488790727731203, 0.011278646153157518, 0.03109651625216488, 0.1078831674831529, 0.061104808438328974, 0.0574632746077353, 0.047311383870340167, 0.04967072017250523, 0.04168840192799126, 0.03535905244549917, 0.05668869076837456, 0.007964561762844003, 0.04182739326009347, 0.025564116545982903, 0.028618398017340133, 0.027771947469802636, 0.045504576992243535, 0.035524339745602304, 0.04476022681281452, 0.022312289727250897, 0.05276636656133398, 0.048008029754724235, 0.09550828877235613, 0.038018722027059526, 0.012397337535906945, 0.04740605318558313, 0.04389878775503847, 0.0216532415229707, 0.02466400345456937, 0.04925778345955957, 0.01256070482814985, 0.026972272335701895, 0.08929471815786055, 0.023841711489724058, 0.04430522421194662, 0.04021115841404085, 0.024004949504629742, 0.03921896346934861, 0.010722024861963527, 0.03992888182702084, 0.01307912418738969, 0.01392935537883351, 0.05448372501339163, 0.04877269658590517, 0.0322914831790953, 0.06011729429085409, 0.04462763614531967, 0.0774919615697957, 0.014332040877742393, 0.010303019775047658, 0.03960050972959688, 0.019233977992928798, 0.0688182681258167, 0.017962057534004414, 0.032246904522781415, 0.09822715779826527, 0.007541560090988154, 0.016601025727727724, 0.05061842073055525, 0.050195092034916726, 0.022694902764933727, 0.022181175694230105, 0.011549851812061765, 0.0004826965596294031, 0.04855391719648915, 0.024390146173837206, 0.0328589704698853, 0.028617716199087522, 0.01259413690516545, 0.028197670190204537, 0.03370319170156314, 0.03632110183037097, 0.042080914736875606, 0.05461959070676277, 0.029231609265890815, 0.05095571009141784, 0.08672559633851053, 0.033781489717864224, 0.026668734893563296, 0.00435581362257982, 0.044705895857224544, 0.1320045489457346, 0.029553825846843185, 0.013803293695673348, 0.05629196447590667, 0.01264030806675193, 0.06881691981106997, 0.029954476424703197, 0.09722866178039583, 0.03304987958061599, 0.02074264260309358, 0.04009503480647841, 0.02047559967444789, 0.05138686820564251, 0.02722072997130454, 0.08642666883045629, 0.04181776736532489, 0.10255345548953741, 0.09081160289145286, 0.07319904232938444, 0.09001408237963916, 0.051490320718937346, 0.012775402884149264, 0.06755399322437664, 0.03921641622700038, 0.03801842325276906, 0.07951405830681324, 0.03289485019781897, 0.04959946250422828, 0.03662320477287135, 0.02574403037978036, 0.06812844425439835, 0.09033436841902234, 0.015117536681974608, 0.012210318236611785, 0.03995486369897281, 0.0649534618001311, 0.02006328923838033, 0.017846772792719064, 0.0015063895684321441, 0.050416767236686526, 0.07110872546270972, 0.05414183529454374, 0.035862686307800394, 0.004734939523792316, 0.030195183165731932, 0.04548244471211107, 0.023222331318163106, 0.017953548212385467, 0.03975695637505382, 0.05352475913241506, 0.025093332533874822, 0.03957281948157376, 0.10565519993824345, 0.031614700039368004, 0.04075111250483221, 0.020299397536643574, 0.03705613638064073, 0.05741925136516652, 0.01336232678318817, 0.017055095616547812, 0.0673689446862667, 0.018357106093918125, 0.06361608295851658, 0.04268672940651736, 0.01628906131842204, 0.049270182592614044, 0.04985313719859527, 0.005570502525510928, 0.010843987974728788, 0.04639046191568336, 0.04508828481418952, 0.023951666174276222, 0.040264206172357646, 0.019660388277242744, 0.02324581574348192, 0.00912279908304974, 0.06039680147002782, 0.057847709019458106, 0.027882589718266845, 0.03157547825286466, 0.051190765018785195, 0.09206149066167493, 0.06480300979268167, 0.03727285499354044, 0.041317040806696306, 0.02899831251030968, 0.06347953544689283, 0.011600539061961877, 0.003871168685896743, 0.052641363994729136, 0.0528412516559324, 0.05645221474790766, 0.021868324538152066, 0.054221044955474716, 0.02304275456305233, 0.020251093777797876, 0.058357801002961014, 0.011900008577222546, 0.0884006705675875, 0.00697242092311142, 0.06771302541657802, 0.004547765091692488, 0.08871260624859603, 0.031814775392112714, 0.025476500985302755, 0.026475629025709727, 0.04345407371499366, 0.017927541442575957, 0.08069187252511902, 0.05815994730519672, 0.06411729598297708, 0.020706222783173286, 0.03323413521772431, 0.005895845702804265, 0.04354839062979145, 0.021228114435929927, 0.05566710103002768, 0.024715503715279124, 0.05703294386846885, 0.023749899682438663, 0.06365846294248778, 0.06674583941217392, 0.05345532858383752, 0.02329948786345701, 0.026335149567814607, 0.027131270053946686, 0.03915723210441009, 0.05000047122819289, 0.036203365607727925, 0.025091024694002928, 0.008122655976143095, 0.01957188213935062, 0.021468124036947568, 0.01768285104434096, 0.07323928492804689, 0.06864637331736666, 0.01010663888131779, 0.050229167625788725, 0.05012643906558233, 0.014184861023339533, 0.05525554327534572, 0.016252651074600798, 0.04205476432558029, 0.03854784746504119, 0.024687053124991157, 0.03612488756076463, 0.018811254506750454, 0.03142736664402389, 0.047872355583334164, 0.05795563548623074, 0.06820243302612536, 0.054956389771353815, 0.03064478867717328, 0.10143151206354942, 0.021722775493418018, 0.01950206471637132, 0.020717062927301855, 0.05391074104174491, 0.03124236598640921, 0.004516703577997584, 0.01757492266234852, 0.04402109369214985, 0.013395231217145922, 0.04963093339615772, 0.043938428974680366, 0.031628035714909915, 0.042397400980154355, 0.023360267364149614, 0.10837851993499265, 0.013724574331013907, 0.037861470989282095, 0.02740172207385542, 0.04844732372270477, 0.04933446503034042, 0.041691803358375065, 0.012225520293859225, 0.05211106261178371, 0.11180081855385535, 0.02727124580903159, 0.06367691033970445, 0.0027649619028858484, 0.021945670690207232, 0.03487878809532812, 0.03195602859881136, 0.015007179801262196, 0.07757875933161668, 0.03225020636173506, 0.021590069912734534, 0.023842554186440768, 0.03360433954625361, 0.0712916519372694, 0.026823635956632997, 0.032813039668385065, 0.05921593056090417, 0.12020677192917756, 0.022000309996186726, 0.06374116596435347, 0.027751278417605548, 0.036983155014534155, 0.022848463174135938, 0.02723461339971231, 0.08169884913631024, 0.029943383471559615, 0.05438125309263987, 0.02869899429741406, 0.056430277820195884, 0.030526539175620968, 0.059866473274005044, 0.022990990002008698, 0.03500900005981807, 0.046757368235698635, 0.02059167731673487, 0.026991386229412693, 0.017765789638243375, 0.027268715803661657, 0.029798644564805493, 0.0399837835181144, 0.031038347196074265, 0.017088972024559494, 0.015429926270078269, 0.056287413913636446, 0.06604886027954279, 0.053415430724740996, 0.030865309001397223, 0.040229245749933105, 0.08628525666051334, 0.00493676778146877, 0.03564935380352601, 0.018592860076516386, 0.047117341459999164, 0.04306163368446212, 0.013575589381939462, 0.009315902078073592, 0.02411537724847515, 0.05142038072189016, 0.01756739201805284, 0.025781595501147454, 0.016449016646572178, 0.016756635422127384, 0.05653275357138726, 0.0025636466847161854, 0.028995855283292554, 0.012749525391676975, 0.11088486084894789, 0.17195347546329423, 0.1400405508015425, 0.0769088154418334, 0.12910003383313456, 0.13972210337317761, 0.105007526224419, 0.08350077986476884, 0.14827123092066857, 0.19075626086804176, 0.16648682525321362, 0.0580040215995283, 0.16851870493302423, 0.08679891095286416, 0.12640667553510399, 0.18612012657667362, 0.1913447083244401, 0.12052466011335775, 0.13744536667100846, 0.13122416582078705, 0.09659488490151782, 0.11882118700492768, 0.14007928420699414, 0.10811206689404865, 0.1702848899989359, 0.08598334907043366, 0.12250301322989887, 0.07858922164286337, 0.08351948773187977, 0.15885643630979523, 0.17647766898716652, 0.2569916558962676, 0.10520415035106483, 0.16431917947146202, 0.16413997618421433, 0.14483713454777195, 0.13776563738863315, 0.1739744307293046, 0.13446056554394384, 0.11816085751859412, 0.14882878971195992, 0.1722730260582701, 0.18225657663518385, 0.16347927131479786, 0.14038162846719066, 0.12187901929381395, 0.1109555554426005, 0.115313415956353, 0.1619929994546598, 0.09845302350098088, 0.17150486969659406, 0.12109862084710792, 0.13560597424305257, 0.1308865968378321, 0.15794739637884403, 0.08517631374660038, 0.08628228423936714, 0.15227819252158367, 0.12854587647222704, 0.09289857195389849, 0.19947434144635356, 0.12511945630033172, 0.10597358607957441, 0.1397663985769595, 0.1407977827494183, 0.08662471788064127, 0.0901154587946592, 0.15941909724666228, 0.10648602995300487, 0.12958611662109054, 0.18501366578763534, 0.22831027396023276, 0.09463170032587745, 0.14925740058383635, 0.1755820662384072, 0.2310394928339989, 0.19358405993590433, 0.18637978441772923, 0.14489497418605513, 0.11316649285295319, 0.1356420416625277, 0.1462330539981204, 0.16495687105963308, 0.14513730311826353, 0.09047992512463562, 0.08676694976466318, 0.22816211255567692, 0.10022615698436577, 0.10279702548418315, 0.12992820552279874, 0.06684146250688261, 0.10852357868345515, 0.14458394248879727, 0.12656269700176295, 0.13961526475125743, 0.21467027765127922, 0.12039588839416543, 0.17423107018393857, 0.13561725105729797, 0.14340298731000195, 0.12920579993196074, 0.23516348202622708, 0.0855204097986702, 0.16457525202103201, 0.19855241591651596, 0.2850303360291066, 0.1531648473633874, 0.15240923952191107, 0.10600607586844314, 0.17407115699062425, 0.2379698153104513, 0.15046775821716557, 0.1319156214594841, 0.0899089980990656, 0.16844416457799175, 0.12951165287485047, 0.14798354958334278, 0.09529519375533828, 0.1860938497608708, 0.10382865480477772, 0.1954573747371474, 0.09902322274302283, 0.2431279312699072, 0.15080862137819492, 0.17151629972842433, 0.17910712789143288, 0.1513183149959772, 0.20145141519606116, 0.10792074409583885, 0.1453019660567084, 0.156416384983928, 0.12219975732507245, 0.1603687091940834, 0.11784863838505362, 0.1627190363022589, 0.08449947506549858, 0.11182965410332527, 0.07364173389730916, 0.10173431597650053, 0.09170403403620567, 0.2056794391284066, 0.059646939287983605, 0.09234120468458823, 0.19917545990357477, 0.12183889160834013, 0.09601649617956531, 0.07088677446928716, 0.153896737122728, 0.16721689172329443, 0.15468672699024602, 0.1463894585087415, 0.08116211261480086, 0.11354977430234994, 0.1163678517144534, 0.15496115500648178, 0.11778968791928023, 0.13664460560727504, 0.16955632506118667, 0.2584086887298092, 0.1797014282595727, 0.15290522016584873, 0.14479202729079033, 0.1455660978512418, 0.08605721526809278, 0.0930683140552813, 0.21239027741455266, 0.15458233984968356, 0.19217093415077657, 0.11317680439641399, 0.22396868515399196, 0.0927173998206854, 0.09731336812218351, 0.17509520204076845, 0.11732963679899132, 0.15540285066010492, 0.13167549886049765], [0.031515815325321696, 0.06518865079288522, 0.05092349226376222, 0.04512349421518945, 0.017272802482869838, 0.05927570840163578, 0.04030126184525509, 0.020676328117148052, 0.006088312844850965, 0.027007016338287827, 0.04546242683464962, 0.046979978064736055, 0.08021561864523158, 0.012105989510253554, 0.023965361911142548, 0.04280548069566008, 0.056406015815633925, 0.04266071689104842, 0.031073774932132616, 0.06180822270952406, 0.03328389262840633, 0.04657824921812262, 0.020310576674678636, 0.01924952766257188, 0.01981063727139225, 0.026859079014449835, 0.07681074852664625, 0.018590912297968904, 0.04292926901290494, 0.019393946727617614, 0.008800822862183616, 0.03955806845859174, 0.06358406048328166, 0.043134653354964914, 0.020184631819926926, 0.004834265217200043, 0.06969851847257345, 0.05396403394819749, 0.013617830512474382, 0.05154200867118855, 0.04479676154592345, 0.026782546830814213, 0.036428511187794714, 0.06355996318762341, 0.0406203183135198, 0.029343477255033872, 0.02867148982571258, 0.09241563012643207, 0.023193832847379872, 0.0639882254894943, 0.04156798822805286, 0.025489666206281514, 0.08509218963163515, 0.043458333163852655, 0.025081052144448605, 0.02305827741961806, 0.06814319910781999, 0.006829068635500247, 0.07133649872435678, 0.05485364971982856, 0.052736554249760606, 0.04979939996114662, 0.02976908123180751, 0.06248730985868362, 0.048992127150056825, 0.04499079246494559, 0.052018492377453276, 0.0395427773436231, 0.033766171789818236, 0.04634346625196838, 0.10064618001061101, 0.02639654193884663, 0.06348294070771625, 0.054519742637151675, 0.025824406409576058, 0.021375678291904832, 0.06488948579757445, 0.004222983073803687, 0.06575629130126008, 0.051861057478574016, 0.015885720814337895, 0.049973010806547064, 0.017677360109143683, 0.0146896114587904, 0.024857595788254857, 0.07799418583031624, 0.0732983120026127, 0.042823552709793856, 0.04493610144803121, 0.010381968008474478, 0.02584637015036518, 0.06444422017422415, 0.02668996702038473, 0.04487840736645364, 0.019862101142925602, 0.060480783858727065, 0.1023722603736866, 0.02750163334572027, 0.028279582226288416, 0.016358539747494846, 0.03993677636308055, 0.04568952976936295, 0.06828452700809126, 0.02588595582863256, 0.02308250495022343, 0.05888761975051415, 0.006178832357569088, 0.015261703895615234, 0.018246618978258584, 0.028002275634677182, 0.03271517193605823, 0.05196782715258099, 0.06760145237128581, 0.027763892055278825, 0.044981526631501415, 0.0420250745880748, 0.01427576405882475, 0.0181278198086206, 0.0466146498858448, 0.01953305105768865, 0.07267718323536458, 0.06533929432231574, 0.10564815192934006, 0.010318185443118697, 0.03901008959679354, 0.022987684332615426, 0.022075825198102864, 0.04752246407611717, 0.006498315441046632, 0.06335604590393844, 0.11242344885343507, 0.011630386805101749, 0.04218558916040967, 0.03968849492770049, 0.024300190214548382, 0.03241433686907253, 0.08986104865588489, 0.03631771572174565, 0.009987989098825043, 0.08460067528029604, 0.05633928189654985, 0.02343788739263771, 0.041037265496749076, 0.08426040966784762, 0.041803242338280526, 0.033514259097677086, 0.026614654831768527, 0.038656946046337966, 0.030186179717401826, 0.07766393298703818, 0.0868732980903118, 0.03106608149415303, 0.06962930242861472, 0.0021757964784609937, 0.04401046039176084, 0.04652898593415176, 0.06578302776981747, 0.03322624451210422, 0.03212227159360003, 0.07356736208162001, 0.08746150805945359, 0.08303475325867053, 0.0718844814165946, 0.021052896721108307, 0.01616990017223983, 0.029626811043389385, 0.09668885324631007, 0.07914102711384335, 0.04013469900875803, 0.04251095053229121, 0.0037854288436187013, 0.0690941363873501, 0.08811750148813571, 0.02163130268003912, 0.07455237495202212, 0.029761615704985398, 0.03213084028703311, 0.028441263167488, 0.04071920111234631, 0.03720116831602589, 0.025391250721088825, 0.05465625950525846, 0.053545929972202554, 0.014428419526666405, 0.019353336406751506, 0.025262193634144725, 0.011775345004524195, 0.005896607002679018, 0.05184135369716152, 0.023844463660592036, 0.01269070707607053, 0.06856693766049801, 0.06466394951266628, 0.01355695429318134, 0.046450059725752765, 0.07076225453807462, 0.018143972772504055, 0.03993634735384295, 0.019043179964947126, 0.03766591555529064, 0.04594705405554945, 0.15090108819065556, 0.041266122772809, 0.08651826230268325, 0.0638411634211098, 0.024056277395556533, 0.0207407312137225, 0.0676609390986062, 0.04320208441406008, 0.04201039634344559, 0.020154011285593434, 0.02047409239645687, 0.04985199189714847, 0.009439241276272844, 0.044481041390568986, 0.01620813562054067, 0.10330568488326766, 0.01920844428241253, 0.039234840641579324, 0.023532227290073232, 0.02524511944953232, 0.04217647271411073, 0.06087973180617537, 0.08863955976501589, 0.015006093871629527, 0.022322603185931524, 0.0029491131605144834, 0.022726695413791367, 0.16810642705569345, 0.029467976118828502, 0.0543366935885241, 0.03477000361008029, 0.14523320200462497, 0.04365126857714307, 0.10420103482301198, 0.021841471241186225, 0.012143351618320712, 0.056670798784902984, 0.024502397206942403, 0.055504046876223824, 0.02775193342278081, 0.02395547937691933, 0.04453084859696608, 0.038193688848085945, 0.056515600862762624, 0.0177344202529639, 0.04034640357619332, 0.0376074017596341, 0.017955229775379264, 0.07127311260950181, 0.09221496105554605, 0.0269008633650599, 0.01153667318454433, 0.025134113309304082, 0.008618886556266057, 0.0403413703785308, 0.028570008073602954, 0.06872928701341152, 0.05908640807554607, 0.05627903291174481, 0.037536768453015436, 0.019850437454278433, 0.0713906764623619, 0.029924949480881615, 0.015522093350638547, 0.10457156856934871, 0.06579394452273846, 0.03520358256214569, 0.05617973259499958, 0.01800757847846516, 0.020409808043510686, 0.020754246919926618, 0.036031133720591184, 0.0287239323745692, 0.022028132394376784, 0.061336289565529556, 0.00956463071727945, 0.051931051101775906, 0.03328124962506756, 0.024792443840734424, 0.04276677410328581, 0.06796617151027726, 0.05942199672121675, 0.03372553465587478, 0.053841314323607, 0.009437366276078168, 0.02663992998761035, 0.0515146708236106, 0.07235658309993244, 0.016990648469917716, 0.019162128521730343, 0.0295042886864394, 0.03669679134843811, 0.053983867964557106, 0.04515920540377979, 0.016135297895919894, 0.0553331058472395, 0.03281309712497938, 0.006653603857323047, 0.01511845886031346, 0.0637664583571736, 0.038992645774757674, 0.1592473403340386, 0.009775273295329704, 0.05063343988431077, 0.07817992384755805, 0.019365865774753115, 0.01216227207483063, 0.09344391930367678, 0.06831601322177919, 0.024543164575832988, 0.02454650663440266, 0.11816839582376903, 0.0710831304651595, 0.05998500622808934, 0.011268093292000554, 0.022564914881161625, 0.04321893834839425, 0.05335440799113243, 0.03342126368454868, 0.08754459029484181, 0.04809593068315618, 0.03392270653538647, 0.04061718118346987, 0.06485543318934019, 0.0157731480243045, 0.004224908348518394, 0.04073109462737076, 0.07756859334486146, 0.033071705425578746, 0.021564011431990132, 0.1162063986844113, 0.02090415692016963, 0.055201005476016196, 0.02429772724187182, 0.028156016074541598, 0.028663951520537658, 0.07554547771090463, 0.0813074624766746, 0.042820810115024935, 0.03543359663097128, 0.05688829497704583, 0.04381659801208204, 0.04456985396363082, 0.041333764506083344, 0.04726926818670285, 0.07657003603995809, 0.08204788645549167, 0.03923128216317104, 0.02216176877188827, 0.03678806689417651, 0.061270609017341375, 0.19647834011383597, 0.2173669837535389, 0.06517011912599688, 0.0943441722061365, 0.10972697257755265, 0.1626010740836782, 0.127171139352985, 0.1907845295124477, 0.150662130045314, 0.091423393046904, 0.08926679425302053, 0.09696237727879517, 0.2867551676688656, 0.22600487024793703, 0.08497349962952637, 0.1917843048971507, 0.1521650873004429, 0.14562350848028738, 0.12166829148848211, 0.08496655121205315, 0.09290241771527837, 0.12038688686105514, 0.10847299389781491, 0.11796525228888759, 0.1182336052278838, 0.3206613611790442, 0.16630100296630015, 0.22584143305017104, 0.1726953703309259, 0.10077531945200698, 0.08354712052330857, 0.2024077993607329, 0.1257609630063657, 0.08410125490157835, 0.09244692481813893, 0.2063914259234744, 0.2674463811901308, 0.10206764083235495, 0.1446977218673114, 0.1259576867244417, 0.1781828121672715, 0.15628058823847002, 0.07900428808023853, 0.1893067152629937, 0.12179233644518161, 0.09911967321268975, 0.16507222857927123, 0.1787676590104257, 0.10689694419383042, 0.07359576096097309, 0.12221923128010766, 0.14531699670178277, 0.2568237600667823, 0.09063134240286966, 0.08121856563394109, 0.07673250030606024, 0.20589850963123385, 0.08475993729887471, 0.2505004090527373, 0.10901533818293004, 0.15029100641127557, 0.19737426461952348, 0.19481238999193717, 0.160275935946453, 0.1579707467387761, 0.11628277765046205, 0.1189476911038641, 0.15386943374910664, 0.14817640455740114, 0.09671133026600846, 0.23812654157800062, 0.13744999384207113, 0.13491350736829544, 0.12070240017267005, 0.2039461805214805, 0.13493203137430454, 0.150584387442758, 0.19190459602302123, 0.161629720560966, 0.14539481591313116, 0.09139250438179701, 0.15299696685566058, 0.12779361643497983, 0.11733208828034902, 0.1434814040699313, 0.24742188472901624, 0.20773952616558922, 0.13034154060146502, 0.12099770408484245, 0.20146687485037312, 0.11939677950595656, 0.12756941314305992, 0.1804099676589812, 0.1474957814019534, 0.11929500472521591, 0.18823121974785484, 0.21907307688267003, 0.11421635506614564, 0.10427960480052618, 0.07198936651430785, 0.1738050333674877, 0.18418174026714218, 0.12729730637323472, 0.09338047956266711, 0.15015622090187766, 0.17096019650418914, 0.11547344406285595, 0.09921182592910144, 0.12532131280750036, 0.17463898136010095, 0.07288796466685112, 0.14646756883350112, 0.16493208045440336, 0.08364831307722677, 0.11547512945628936, 0.13302362974612944, 0.08626402070325229, 0.21195628860544777, 0.08960601798589192, 0.11335446018605463, 0.19730113386627168, 0.1633639444386767, 0.1196280001632629, 0.1407461484233218, 0.17998350183329276, 0.09503791844772716, 0.2871313168396873, 0.10669889514364543, 0.072329371656862, 0.1522770893549727, 0.21842999203551203, 0.07184787773557248, 0.12404381522848723, 0.16653574762805817, 0.0757549414711614, 0.126580462580727, 0.23583506534416832, 0.1672409009188414, 0.13161790437035023, 0.21767754047628374, 0.1379972564116601, 0.17605950755457725, 0.07647275819533295, 0.15999776942114677, 0.16616972613959544, 0.19861345780232262, 0.13230085643308778, 0.14990921883333116, 0.09278350554767156, 0.13260490140847622, 0.24557185900067133, 0.1024537108417961, 0.1505972730416444, 0.15158909643369337, 0.1785990124147746, 0.19056476953048862, 0.21247782594253942, 0.14176596466812397, 0.1322065203660919, 0.1389166538513476, 0.26067367364321986, 0.2038244951155878, 0.23228833872464397, 0.15503897421783017, 0.20280346845186528, 0.14352422838489856, 0.1824631905483623, 0.14234803827299228, 0.20226595052067312, 0.08551022082927727, 0.14748885596711792, 0.11083216932151588, 0.2684699053004865, 0.07199493597351736, 0.1943013940246836, 0.16056954680431276], [0.06524082138052871, 0.01987203155764409, 0.03125603491019818, 0.028440037426809152, 0.0218624601350917, 0.03058664260372039, 0.012434923724691956, 0.032828369087749915, 0.027090705698356036, 0.04979198806047921, 0.017755372757692973, 0.03729754217690037, 0.03241499953512703, 0.011743185591072807, 0.044544469640259786, 0.010245301753222462, 0.02494227723218501, 0.05595160310246772, 0.04610379564485723, 0.07537111609933839, 0.022013611197772048, 0.0560132923325704, 0.04031769826167053, 0.08553237609204747, 0.0665878031342741, 0.007951371165202751, 0.04403224793232737, 0.055173265432278, 0.05786851596748156, 0.0647491078463293, 0.017602969141256426, 0.0030973413583612252, 0.051622735186209606, 0.025772201347975962, 0.025003307626672813, 0.07327623334863494, 0.04949026050106172, 0.058835437671551784, 0.04091502467711126, 0.030392238216835166, 0.033763000185811715, 0.033905549996322205, 0.04045830603929297, 0.013918689519707716, 0.017563582645849358, 0.04744410477278214, 0.0757541217570824, 0.0431085029436696, 0.06646657738113596, 0.05887226351807195, 0.03902695885288619, 0.04623240648558544, 0.051936517139115644, 0.011648760466355712, 0.11632544108696523, 0.04309957035847249, 0.0024536867333095403, 0.015671809913680678, 0.007100418414695249, 0.03500764025375247, 0.053628104393400496, 0.01198743548875134, 0.024393176051577734, 0.07722478074532363, 0.01666657029530935, 0.02302748834594123, 0.01130651260140322, 0.00956994257942443, 0.018585963369978052, 0.014309544705845898, 0.016251884986676516, 0.12291349846148684, 0.03542086424966974, 0.014329937008780338, 0.016479020480126623, 0.04571184591059724, 0.08607063712852617, 0.009540732604481522, 0.030263512462918318, 0.06809944782646433, 0.05507098503350731, 0.05203650693499273, 0.043252328290574016, 0.027874955652101387, 0.09140319130834072, 0.019829877569610556, 0.04431873034205168, 0.04106734976953557, 0.04114345294393359, 0.053553510412213304, 0.014591029349474177, 0.04024049575110117, 0.046933442053775636, 0.04336678948734076, 0.03323328486012836, 0.019326146031098983, 0.05552920903409681, 0.03244482333801928, 0.049267792398290294, 0.021666196069770285, 0.01687686143052434, 0.04580343938282421, 0.023973451799622948, 0.04077552006609979, 0.037991866814873876, 0.05634228879165265, 0.005806308697849032, 0.03151171483970698, 0.015231095810210513, 0.021505376977485516, 0.05815414035873068, 0.06350459801333566, 0.05928272959746181, 0.033342912042092894, 0.022498163725099257, 0.02227979802316235, 0.07671324851652307, 0.02486684246950092, 0.019367803977201545, 0.05851561128492317, 0.024442504453022155, 0.07415574059010514, 0.03383186765976491, 0.035858809902903535, 0.009140915147239163, 0.03046850610013691, 0.03835154126488394, 0.03170747520221818, 0.01063126834079383, 0.05504407236472734, 0.038275434260046294, 0.02599460433327383, 0.04077558135313373, 0.03357199531409048, 0.030115485123749224, 0.06665780824879486, 0.04519211271056726, 0.04763559227989567, 0.025413003787698767, 0.017706166930316437, 0.038828787228633324, 0.0568645922166686, 0.012541528689795205, 0.07630329188560286, 0.025678133411753564, 0.041956789340944066, 0.0428980854039471, 0.032962775383625305, 0.02304983130025287, 0.06572200120576928, 0.045665953413493214, 0.022672287849408966, 0.018474330952871713, 0.04291668218830901, 0.03800618116773906, 0.055399039204442696, 0.00472051696100783, 0.03874905279747421, 0.039565940012013724, 0.047969376788504665, 0.015977883106848646, 0.014887205644270346, 0.07391085292422965, 0.02546162930347266, 0.05662798213081495, 0.04144745578448619, 0.019365329513206117, 0.04604236688464881, 0.02961254648623928, 0.023248698149297028, 0.022301654511642073, 0.08246312909308942, 0.023486813597921884, 0.020631347264673923, 0.04480444923824361, 0.027436035151983944, 0.05886292490627497, 0.05316174070861551, 0.044007158552807187, 0.04245164383563303, 0.05216946915513085, 0.007759357930251187, 0.06559247872041118, 0.04989712596720746, 0.03543055909235151, 0.03613329537573361, 0.03507502534757218, 0.012927481870827897, 0.009064763134735967, 0.07765180581519682, 0.03655276298823376, 0.030741164453267574, 0.0332543216345291, 0.02426776554315321, 0.03729940377055638, 0.027286929544061426, 0.1203318281219371, 0.03658135722000753, 0.0639985140503174, 0.08261298355195792, 0.06769316075670143, 0.0536158814605686, 0.07855636413179098, 0.04630358754506996, 0.03469089737101909, 0.026202193093335917, 0.04079513957784061, 0.0575119556648837, 0.0656226012975939, 0.009164674406600817, 0.07717136143436355, 0.02189623120601379, 0.07034685868289202, 0.039300961690323974, 0.013300348354894067, 0.05271097074352926, 0.04772936527226721, 0.039152283176419236, 0.04790081191928156, 0.03516777944300444, 0.032202927245488094, 0.024719546744299513, 0.0626429214683031, 0.03807244777318932, 0.004754966019742912, 0.027424785150815884, 0.034649417540358926, 0.030228057913782618, 0.03472483889650434, 0.017276761242218556, 0.058771381229763074, 0.04241194515939682, 0.01819671026521152, 0.0177578299847101, 0.06696586752490652, 0.06454125287071352, 0.03852867228429645, 0.01989819729069789, 0.11324812718216451, 0.059446580482706915, 0.05297393425397816, 0.04653939706904273, 0.040509760334727266, 0.020499066862788413, 0.024404244106863777, 0.017227836952154196, 0.03423006484104741, 0.06520474630017435, 0.016481035291367484, 0.012868268062330544, 0.04795849067910064, 0.05366607171092784, 0.05327201523487607, 0.005778250248817307, 0.036157503754140875, 0.09548491542978634, 0.025824132533143127, 0.04244101819612327, 0.033938913125424616, 0.015027866090437578, 0.04885511615523889, 0.022425201511190786, 0.018546948427214258, 0.025378123804506277, 0.026151049063510956, 0.01529243263986803, 0.032134343224066886, 0.03097973763942719, 0.045856778254552234, 0.025350370354229407, 0.055273132654087204, 0.02748486368105777, 0.038465408743509365, 0.05281241227602286, 0.035584853030741215, 0.012114220167390041, 0.02126668313247783, 0.024926509227483504, 0.05897954647098819, 0.037469808537993705, 0.02448460864534061, 0.030809296482813456, 0.00893244538606415, 0.05740741913717601, 0.07159273215239087, 0.014084616503227624, 0.06882405208964502, 0.04543844445218002, 0.06689417701695236, 0.05856683575398019, 0.036695454525010246, 0.025453780732688405, 0.019686578908154083, 0.03895569735416963, 0.012654655935963797, 0.08816845399597961, 0.01367532349597182, 0.028114789052896445, 0.04631932299103468, 0.013561768198175537, 0.034238261981837215, 0.024806702652225093, 0.05754043498346883, 0.044115747685634324, 0.053550281351612466, 0.02910930907443887, 0.04557586147359783, 0.028512764068680908, 0.026766374714732654, 0.02914964934931167, 0.05246565023797655, 0.02553305742631276, 0.0253672817451579, 0.011824904189955805, 0.03754160629825727, 0.05325902238368027, 0.0778378809111253, 0.07459305422080141, 0.07529962477424453, 0.034858731913470456, 0.025554764527647246, 0.03064444202238754, 0.041326938662678, 0.04689612591098394, 0.038435083153026725, 0.055783255281107086, 0.02612016997450302, 0.09894262263250929, 0.053075314499437816, 0.014115795324135934, 0.0444666197853944, 0.038853750203646, 0.05834060232906092, 0.051893604724037076, 0.054866772805971485, 0.02981037145570642, 0.01319086577202524, 0.032380659643921166, 0.05192735472754125, 0.07769607037546174, 0.0365855745340307, 0.019546683592301224, 0.061777514075079275, 0.013101816669316783, 0.03261491783984727, 0.0720158271912125, 0.031149847463013667, 0.04812460918460162, 0.06994025751708016, 0.053976793142576376, 0.07756504635777205, 0.05022577385628416, 0.3648899153115288, 0.12256109035543858, 0.13517550943839934, 0.17668498770123528, 0.11982983368779383, 0.1591807826151771, 0.1145562912607866, 0.12348022732523181, 0.1495053066361335, 0.1622942099047284, 0.06737001720936069, 0.1680735618837418, 0.1174356557068325, 0.12865469160099186, 0.228792863387254, 0.07142551048027893, 0.11634062494962447, 0.12627893803460946, 0.14719997953263023, 0.11803315832249581, 0.21347044606602963, 0.13767223594890488, 0.11190923531689953, 0.1553515380909366, 0.10887182693207458, 0.21825501755360635, 0.21361267795005154, 0.18166572366270328, 0.15476534293303568, 0.13726738912443961, 0.12459606503046329, 0.12168201212320598, 0.15480329492880454, 0.07030575040487513, 0.18597899785926267, 0.14124309433804405, 0.12406571002136316, 0.13086788897072116, 0.17973933429006608, 0.10523933676942702, 0.07566684902074837, 0.1652385769111495, 0.16060167653185708, 0.11964460128858206, 0.07027054866475445, 0.13586079040842672, 0.18648646982206454, 0.12825231924052202, 0.10535676272646075, 0.1322546306877367, 0.15885560893483702, 0.23849496858254557, 0.11178420976765695, 0.12387158334135048, 0.19955058251657795, 0.09940617477461215, 0.13095876232029932, 0.10802608118542742, 0.14595519390798387, 0.18620551473671393, 0.18675175074848438, 0.21369192208493912, 0.1640273612593451, 0.15925650274561298, 0.13373207721498706, 0.18463675052888934, 0.13422516204657095, 0.1236806589088613, 0.10011852163100436, 0.07819342231678386, 0.1373177670663403, 0.22676184172591857, 0.11520447825352031, 0.1197432044653162, 0.16685295399398575, 0.11643815560326462, 0.10125086853100408, 0.09054264474299648, 0.17413984443391525, 0.17572048300456616, 0.14139435073781398, 0.1597818398788091, 0.12146209126278279, 0.14294534170579526, 0.11664571946546917, 0.08380040451283417, 0.11794527271582235, 0.13626811935776664, 0.09334650356322528, 0.122063156187294, 0.12265403980329154, 0.13622523375576542, 0.12930903794063678, 0.20178785036888816, 0.2047717781557191, 0.08500766715094929, 0.15292644080135132, 0.13652164849542803, 0.10374662210984577, 0.15093079708035917, 0.12138242577953685, 0.1237205874114748, 0.14679804384227724, 0.10506685973415453, 0.15488526633670255, 0.16686161078753012, 0.052732237344307285, 0.09326218026539973, 0.2028233560943796, 0.10745693148384172, 0.16410269834581884, 0.1880550654905458, 0.13646901825502997, 0.1974493259143445, 0.13556008557638816, 0.08289035334582291, 0.0812617193667158, 0.09360242289521041, 0.07171314585232927, 0.14951537303145856, 0.10984242968862096, 0.1719076327619053, 0.09862159348783955, 0.14889825856493366, 0.0932338809774768, 0.12174919803416538, 0.11001965646902401, 0.0909097770589494, 0.16065798399429168, 0.15059145077341987, 0.1456695963298121, 0.13355154093475113, 0.10991997310831664, 0.15964821882305608, 0.1413714600306365, 0.14784105722942661, 0.08694009329642981, 0.15991680924930882, 0.18323931422445083, 0.14054808405137834, 0.16146300450688408, 0.20219183917487824, 0.15802543009481124, 0.16744608990848067, 0.12430715795245864, 0.12923078972005075, 0.1314311780996861, 0.07854678037185824, 0.15281744181148468, 0.1837185635081222, 0.1531400261146407, 0.21448306108434356, 0.12357958892901098, 0.13217961535819117, 0.0996398852176724, 0.17702264861474115, 0.09657553352055051, 0.15617022561209817, 0.1294053658362358, 0.11440013189830127, 0.09691816634468495, 0.08023727595085099, 0.1321156776600307, 0.0802039358043863, 0.15589804989435982, 0.09675478277307364, 0.17620920113498167, 0.11657114846691971, 0.1258975564832649, 0.25432563927625457, 0.10682038902755707, 0.16380562477054136, 0.155509244951029, 0.1415733241986844, 0.14004029033164825, 0.10798149486823429], [0.0024890120051080183, 0.031590219699747624, 0.011937928014254619, 0.041312072726507346, 0.05339477316386277, 0.03467599696089183, 0.033993290046290044, 0.013238228200333975, 0.031748788408754815, 0.024459051952186613, 0.0159870914836985, 0.07749538598281723, 0.007188180489690915, 0.02752013245387183, 0.021336466081500537, 0.03764180293787391, 0.07433555674769225, 0.025316585876768636, 0.011434634103469793, 0.06485564769395898, 0.06810618173931876, 0.029271489888009046, 0.05165019943829506, 0.015362748977608018, 0.0433489894344201, 0.03785429657587121, 0.04298119445241267, 0.04196474133359809, 0.031001467723399404, 0.02835961734695781, 0.048108973330067056, 0.04216592368339339, 0.04409540805124468, 0.05440337388145347, 0.03477650003567819, 0.0739756869452615, 0.04348035053079648, 0.0662165416044093, 0.09899457871553399, 0.03703377044369136, 0.02539607515979198, 0.05171228320367875, 0.028482384852043567, 0.035597485820612604, 0.014759951736778023, 0.0038425646386214445, 0.05108746955351484, 0.053190177892364805, 0.08537372694380822, 0.06532963395359055, 0.06586155944293545, 0.0404406285604402, 0.027766159675534696, 0.10057621320048649, 0.01091167567327859, 0.04858504717929229, 0.05611823871731759, 0.033019485042220166, 0.06222473705307611, 0.01473076091403322, 0.0474605986457919, 0.038663086241051074, 0.03523477383198277, 0.05577786585255977, 0.06387867874676181, 0.005963023474079467, 0.01728822000234598, 0.0697358959023991, 0.05160821782004449, 0.047128863422380346, 0.049201399388332526, 0.07944304195623245, 0.016544442473640366, 0.027919842658804792, 0.04597596238337217, 0.010337031206055995, 0.06009177207165669, 0.08359458733109698, 0.011012531148510115, 0.04841306427073094, 0.045440336689352996, 0.02828196859017255, 0.032392078184432564, 0.03546776415239419, 0.01973448621649896, 0.04452302300881955, 0.01331237018964584, 0.02209671067013856, 0.025407627765690128, 0.04930430797920112, 0.03878970142273653, 0.016871977620007052, 0.03566324297759322, 0.07680806721891127, 0.06412519051903678, 0.06277272740619318, 0.015239389669600756, 0.054707215843541976, 0.03900191160820184, 0.057217567227780826, 0.05725423985671613, 0.11356396225070763, 0.03758590533247879, 0.059424647385434765, 0.03887350761121319, 0.05285844266895325, 0.02691714847911029, 0.024136264635730657, 0.049615634620309844, 0.0013919089800648152, 0.04994058230471227, 0.06107836691362243, 0.06656141906616188, 0.028616473221430377, 0.02009705264842318, 0.06451316042653014, 0.06406674950173305, 0.12074736187294607, 0.05668031359692255, 0.015953629720775832, 0.031198111002243338, 0.031120429686721296, 0.037723065714441964, 0.026160466199320172, 0.020386488327095588, 0.034920080234446836, 0.02606371504014298, 0.02723401010547194, 0.024824931714383346, 0.05703756720909188, 0.04553984384983779, 0.034602207372025136, 0.10159877970093682, 0.02808746078141755, 0.02261214994735295, 0.054682122633582166, 0.11803801531993574, 0.012325873023890441, 0.04288183667907312, 0.043602300237023064, 0.0391068350103113, 0.018459648877802878, 0.03929412818603939, 0.03886257170609409, 0.03919667414119167, 0.04880838479185778, 0.022598007964270733, 0.04270452945943802, 0.006149679839220499, 0.041704953257595344, 0.04877352013042377, 0.05356824228299722, 0.013460501908294618, 0.030742662155159542, 0.033087751137152795, 0.03885259724131996, 0.05846090111581068, 0.02328279289236713, 0.053234538213620265, 0.008178651257748566, 0.0973582149092709, 0.04958214508669992, 0.027225198179122903, 0.06723530064787596, 0.03482786240056157, 0.051950685935275215, 0.014459157847018253, 0.016035672949416744, 0.034045460633933544, 0.0466761092895702, 0.027704344040924506, 0.012122824292389617, 0.0161766953721282, 0.06307259720239429, 0.010468918987880311, 0.0263633186207904, 0.01073388773347101, 0.01982011569423541, 0.02396288553192731, 0.022420082128636783, 0.054003119754094275, 0.031382642431004394, 0.020748227384061586, 0.015274780058872797, 0.039668967346510584, 0.017150521443616, 0.026780135569072543, 0.04127770602222412, 0.01897316527432732, 0.07353584522441511, 0.0438086077150318, 0.004186272619277119, 0.08350423492130735, 0.07229749473833269, 0.096981996790536, 0.03289881853326675, 0.05373306993034579, 0.04234141144420832, 0.035394913021234736, 0.04750986576020237, 0.04003146483052162, 0.051139601836762125, 0.004640961124096066, 0.03531516326831714, 0.022848888352933912, 0.01276957678548511, 0.0823753737213631, 0.03827821898965105, 0.04390404311819904, 0.05799833722713013, 0.013522136554632698, 0.025054279286714814, 0.027319951764037533, 0.027565111391126152, 0.058235495065849636, 0.05524528918847923, 0.01957341431519918, 0.08067167078655574, 0.057735408190637834, 0.06632063763156053, 0.016735962539490674, 0.03718893389187513, 0.045430841029531537, 0.04994013414327657, 0.08335880845064118, 0.07110258143755697, 0.09255307396092723, 0.06159953652851044, 0.052714054247424494, 0.0071117014534050425, 0.029614578534458435, 0.12157524244919901, 0.0400795521695287, 0.05360678799690739, 0.10127056465153733, 0.04356857704659624, 0.02371550233463847, 0.03489375745336856, 0.06052015311715584, 0.06446362518134617, 0.0726246755690344, 0.028682261021927963, 0.01891867535549306, 0.022507123123373718, 0.040225848149988926, 0.018031545539176273, 0.06664824747149983, 0.04782838596692009, 0.02878106721196204, 0.075795283661254, 0.0729981204494834, 0.0171871749203532, 0.039360712717978225, 0.08144393337950592, 0.019514971382675633, 0.044700456632962154, 0.061591611348933754, 0.056149131212864196, 0.03624525529542758, 0.04689510318360502, 0.029743262153539448, 0.02137340492598953, 0.016543479118075584, 0.044873132851094975, 0.05693760039585252, 0.06089956582253499, 0.05855282017540547, 0.02071521665540434, 0.026670196206278862, 0.03068335928894099, 0.03958223470216317, 0.026406418727410418, 0.07134890934873013, 0.02911439206781647, 0.042984779743898305, 0.016608600422079046, 0.016271592598528634, 0.03267794772381744, 0.02945209703137798, 0.051352126118276394, 0.015920575899672846, 0.008524558150149401, 0.018181583859146606, 0.03184775930769261, 0.05815659567052799, 0.021668611161951578, 0.03925162562800031, 0.0289338672788994, 0.030528117316744985, 0.020522399985742186, 0.016852750728327422, 0.048192660774915456, 0.029845111627852725, 0.07750205860863771, 0.022456178276409066, 0.04077815923899893, 0.04287188519693671, 0.05532037346593796, 0.03146194210726648, 0.04970666118747285, 0.028042853396806507, 0.014991724934999742, 0.1335658208136597, 0.1185496701228042, 0.034167896805992054, 0.06966472633423344, 0.04955275795392452, 0.07227405244784971, 0.04285311987323146, 0.0525203182722532, 0.045778526203526605, 0.09525394758149501, 0.16411877087047025, 0.01608691944350158, 0.022103873592230584, 0.06225406289881757, 0.02061185990310004, 0.026759610158361258, 0.03317379813280798, 0.01904102917309971, 0.0352378037097233, 0.020073152620405443, 0.016126803896059434, 0.042913380349355365, 0.06464047657866633, 0.020161607047362674, 0.025245320547612447, 0.06524896489516382, 0.05818226344643101, 0.07501487755366872, 0.041934883056749264, 0.04908940116424234, 0.0579125851753258, 0.03302195567577597, 0.037241870567442915, 0.06109754209436717, 0.012274132403094443, 0.037571690571043766, 0.04312139237299562, 0.0490965525950155, 0.04838340900718205, 0.04351332678549713, 0.02484028986204536, 0.030065497886689923, 0.04344258239612945, 0.046542790838547295, 0.04257690304169252, 0.02571365307836283, 0.026394688006069873, 0.022596623260347594, 0.061975099642070076, 0.027123930931632078, 0.08453427843989865, 0.11200580069975508, 0.1004928858169625, 0.14708753314710435, 0.06755086758564557, 0.16376635510354273, 0.11862745102975639, 0.1145105634725863, 0.16124243247172526, 0.0890612758455738, 0.13861452409576985, 0.17081120772467506, 0.07971777640763791, 0.1844644267112017, 0.07659780672721325, 0.09606636084255674, 0.2554215280519378, 0.15643772819349844, 0.19893657836702563, 0.2739701714486845, 0.13423420188407745, 0.06419779267162085, 0.14752443309032148, 0.1800171024496517, 0.176177944747671, 0.13605808869244593, 0.1880352391350654, 0.12559243132390324, 0.10138368519443659, 0.1723847216776302, 0.2266606415111211, 0.13225156633603957, 0.15461797825992107, 0.11927896284408147, 0.12963349149832804, 0.11159523119849545, 0.0997518336460475, 0.10585354010183966, 0.24873207894063767, 0.12581373880346938, 0.1197394812780042, 0.14848739028938357, 0.12094971633726552, 0.1437947493527205, 0.10998679895795162, 0.14864097559644332, 0.09639542624955216, 0.10661958206084468, 0.14271962155978526, 0.15843988366184697, 0.25086131307386583, 0.16380087502541082, 0.11363896991937392, 0.16698657504973874, 0.12063670047228375, 0.20559513881321878, 0.08968985864832517, 0.16216009855270386, 0.14132805348884675, 0.1943760109885085, 0.09088498645371969, 0.20741355575380788, 0.22896434450822495, 0.18841388575252027, 0.11577121477814452, 0.20812709004648272, 0.0975729110500505, 0.09834178753437535, 0.1484735087761956, 0.17154364906732114, 0.10907205167196452, 0.2762722656611474, 0.09615801560181765, 0.11916233361848902, 0.12237791107186388, 0.07368561541361195, 0.18777415637047062, 0.17820813903404822, 0.0964510748763719, 0.10999445983719443, 0.1596564925726383, 0.1046252943154785, 0.10429894852061426, 0.13425346133449387, 0.15224305972937616, 0.09525309722389906, 0.062116936990810986, 0.15835409713608606, 0.17037853658679994, 0.18512712340922127, 0.127804632779331, 0.13122430371661342, 0.1059969747439027, 0.13888231779058136, 0.11221798407214303, 0.16135262655875376, 0.17177522212507265, 0.13549504471161675, 0.18375709773071353, 0.11445489186312884, 0.1656535973832492, 0.16577928176810666, 0.13070883379588205, 0.1038539740106752, 0.13224631097287903, 0.1347667096002448, 0.15172622617213957, 0.10619117037182856, 0.17838418603904788, 0.10080292926079805, 0.12432448686130586, 0.11180909996431683, 0.15257220174516403, 0.12768745963131228, 0.1106266049487937, 0.18522922760776936, 0.1436639934658043, 0.3878873845021571, 0.13376144902600398, 0.09199652640569596, 0.14023201149557868, 0.12675169855356216, 0.134548788229304, 0.09699783948881012, 0.07294722922867344, 0.15162268172829382, 0.1410966336486801, 0.15614597126841545, 0.13902268042006802, 0.1798055549302409, 0.19364111816450474, 0.17453601914307765, 0.1304419594065797, 0.12819959706957304, 0.16227073697072847, 0.16973663151504534, 0.30742988891659245, 0.09544294913329425, 0.16408520089762826, 0.1604969676343664, 0.14469551553408946, 0.2601418554061844, 0.11562742007475708, 0.1195164271179707, 0.09413639383931315, 0.09356445557768307, 0.09263974914868033, 0.12498712993317074, 0.1425669095929592, 0.11754408013075592, 0.1597959818618913, 0.15666930125124995, 0.08674446508408555, 0.1574336884603385, 0.14519380976355847, 0.16026096658841257, 0.221120554112619, 0.19208902402991251, 0.1594356753893437, 0.1355909435979782, 0.18620491718813298, 0.14115416685179358, 0.09914442551352325, 0.09696439209003603, 0.22139643769591089, 0.09904995921158022, 0.07599375405979734, 0.09048523411395089, 0.0756432841561975, 0.11148795590645845, 0.0942122518655754, 0.11109335933842006, 0.09214597483796459, 0.191747777824921, 0.13736826758230888, 0.13294663790973926], [0.01162677374292886, 0.019479438309527693, 0.13646797637545294, 0.042185527873375726, 0.06686216986347591, 0.018623810028657317, 0.03427134931928689, 0.03447072370158088, 0.04081030045786212, 0.026851349187293844, 0.007669522629810438, 0.06349661920760429, 0.027026605206511678, 0.05677121759001767, 0.008659792778592919, 0.043929772181135994, 0.034689031946923465, 0.021247458156018008, 0.019094207166363637, 0.016875863601002964, 0.06540872487089326, 0.11012309366056036, 0.029278677707958608, 0.07259694318617545, 0.045464292258745244, 0.05341628874321619, 0.01746490669076241, 0.01346977157217841, 0.06360087994365923, 0.033482435805302475, 0.026276969020405126, 0.06326348333048724, 0.05684900998828873, 0.030717959650041118, 0.004630828653687551, 0.018417669174772118, 0.038831690701866345, 0.026216561072355798, 0.014033912016349214, 0.03899896600013299, 0.027192756270749435, 0.008073612942450471, 0.122692390164781, 0.061206678980060165, 0.015326829030058317, 0.06844273182533442, 0.06188087848826282, 0.03858009210577415, 0.029998564784745538, 0.05467857564649275, 0.009130368031741632, 0.030227420145585656, 0.047048006672412164, 0.038752235892799594, 0.0652937044299418, 0.026655450928956274, 0.06965340355471258, 0.11028346650662924, 0.06361738147754824, 0.028817969667274627, 0.051311764775985674, 0.026784237969907063, 0.018193488865489924, 0.03667406151972471, 0.0501320889640239, 0.04514982848758659, 0.021605267181932446, 0.012756198017497458, 0.018987782231922594, 0.04217486775990936, 0.0672363272056945, 0.04439178831695069, 0.019075495468813087, 0.01512010499174076, 0.12119474955984663, 0.052015945135105046, 0.007573924432959288, 0.051601123845865654, 0.05693083966992075, 0.05965795180189514, 0.07494419062089536, 0.03296450674233418, 0.024678271842159094, 0.0584324294581048, 0.04089727058946606, 0.01233765641377578, 0.06632511158503833, 0.028711439395743995, 0.005002175410833931, 0.04762744876526056, 0.013513992082387691, 0.012486118507841903, 0.03972493006937927, 0.068880497447906, 0.01841411835724308, 0.04097960588912811, 0.06597243534821658, 0.041296869711649996, 0.002229900719905873, 0.042331536570864345, 0.032428907861392346, 0.06181764942143233, 0.04627280613227237, 0.04281717885826384, 0.039673418317350655, 0.07618443334415075, 0.04684953627386882, 0.04804081831788344, 0.026974729562719024, 0.040580585163327, 0.033411124510870825, 0.019574513651370522, 0.04399850175926282, 0.06247124882535108, 0.023339916238441102, 0.04534941354405977, 0.049067782163019144, 0.026560071067163543, 0.0416102149944392, 0.0337731814943254, 0.027601807002699184, 0.04382600940223183, 0.02284390495098647, 0.055724431219841206, 0.01639277047117151, 0.007156625806894755, 0.07619477553112854, 0.02751222451127345, 0.10558588430285455, 0.06801227468156046, 0.03482202864101818, 0.04572834361404662, 0.07668174698107666, 0.02837207393660661, 0.0769875846022079, 0.11759607451817683, 0.025559560238053242, 0.027266827396928307, 0.014377326250166423, 0.07161266576018065, 0.012829338346848325, 0.0073021202678641975, 0.049559204583807345, 0.032564386680361726, 0.05742858614652388, 0.07315028849388323, 0.03969748879993155, 0.03390257757517599, 0.10524021010966071, 0.0492449208433109, 0.06665189405001941, 0.03126113514055408, 0.04342286329295847, 0.03209925831235465, 0.03683882404959971, 0.038094760083983985, 0.06906744588406817, 0.042080412949285204, 0.0312851922165963, 0.020195230646359346, 0.041097411059684334, 0.08736560917309216, 0.011764227153523075, 0.003239250527845035, 0.027733441975508488, 0.043926631220646446, 0.110352651907071, 0.005063596510163118, 0.016531443876785137, 0.02768277483541639, 0.041813450459871566, 0.04909435775311244, 0.048983918517948165, 0.024429775902160236, 0.02130872795298215, 0.029406093451524937, 0.03205269548831688, 0.04210496223681877, 0.041007165902204094, 0.06530766255192219, 0.051605502038352916, 0.05112817563537148, 0.01995069538092902, 0.047714694688517245, 0.023108460009098056, 0.025004496978175257, 0.007872219918475998, 0.07306103925070456, 0.022918625336681164, 0.01319990752475156, 0.017859060843024525, 0.020403600816104202, 0.015161154855553423, 0.019008164001148076, 0.08533370651064381, 0.023334557453410763, 0.06487695259913322, 0.0831817731922192, 0.01945385480329635, 0.0455355346052637, 0.02158522632183327, 0.02162698768980561, 0.010759236625275545, 0.0029827156920932355, 0.014044965707486676, 0.015153947883405754, 0.021825389140435768, 0.031841563571604996, 0.0872491944521185, 0.0018647142672806138, 0.03791667528510575, 0.0695943458366298, 0.05957419157869393, 0.03019821687391208, 0.0019254059072644002, 0.01503468523057358, 0.0658896135827226, 0.025496357984300104, 0.039466149398996946, 0.06050083621014511, 0.05593103364170079, 0.06769082418853237, 0.04490126359967455, 0.07864346066790243, 0.012182706512600906, 0.04410456663237945, 0.02059686373198225, 0.04493373423634518, 0.03559634434960542, 0.04730589101992307, 0.0317681685180193, 0.0467167885583495, 0.08089245732633338, 0.019740231875931064, 0.022115211693509933, 0.041088183530636375, 0.030582482746291547, 0.058040131153839256, 0.07169166474693245, 0.06892393463321271, 0.005969063598557466, 0.07010026264094538, 0.04446685727265093, 0.008692408971969158, 0.027049109039287415, 0.09415857208472106, 0.007031707988766533, 0.077161310360797, 0.038742295901982055, 0.05467998524827342, 0.02129768862599327, 0.022086979438280387, 0.020855293917139212, 0.0449860695328924, 0.036744480321724574, 0.02547875328380014, 0.008115889504551888, 0.04838923893628582, 0.05800093426519345, 0.05248621203786424, 0.025066318358444882, 0.016111972433845365, 0.037556181121016705, 0.04105585462023174, 0.09589465755608775, 0.06122454798089401, 0.046822504861460584, 0.049063128178879145, 0.026479419245715105, 0.05775464465841652, 0.11160270055575718, 0.022618035417831233, 0.0641059004251034, 0.03387841516204419, 0.05782895901751134, 0.05797642711249571, 0.05591692230213554, 0.015114163022278058, 0.038737484869817575, 0.049629033498105504, 0.06652728984913518, 0.02038070627848708, 0.08432885962388209, 0.040536849203729824, 0.046100382723154566, 0.029472591798572294, 0.03659415854922226, 0.037067374890489925, 0.046642581451564066, 0.036297571439776695, 0.12132678481359636, 0.020518498682987787, 0.061151175909946044, 0.016514582281571724, 0.05081986355024481, 0.024735452644827387, 0.03978643543838013, 0.011378352496502622, 0.023576290752258033, 0.02640177814980909, 0.023703459432468783, 0.018498453146387494, 0.02294792436934527, 0.06347354080888533, 0.04149393433885228, 0.03751547120872044, 0.02692678203475812, 0.08316674254714482, 0.0448922697274435, 0.029106183435707807, 0.014167854829030413, 0.09651173371821643, 0.13014546805812469, 0.021369834956262383, 0.04296532111062158, 0.004104467835502639, 0.059253874895793784, 0.035303354022964355, 0.05419930338018364, 0.0215726318363581, 0.01851674924123912, 0.06144520045528489, 0.023099822367751793, 0.04150294353284183, 0.016954374206703038, 0.045140486045349995, 0.048876256351509405, 0.037106790114194155, 0.004955633654214081, 0.0029101350857320455, 0.054731822587669864, 0.06743033897251853, 0.03441740398205096, 0.06688947323709726, 0.017004156515242595, 0.10670421179383995, 0.05103959288868693, 0.06314870420723193, 0.08810359699231002, 0.05368992768888993, 0.024647613003429387, 0.07156228015740072, 0.06338034238245699, 0.025187385148338737, 0.02346544357527408, 0.10582687258119546, 0.01496756156425803, 0.0021314371148154383, 0.05602282629678807, 0.024105421935899124, 0.020375943126817866, 0.032589851442964814, 0.1852453767412132, 0.17441251044792516, 0.2298567296877023, 0.15207026093717546, 0.160059837864772, 0.1486962718228179, 0.14075727201998234, 0.10791850711909995, 0.10841057305374455, 0.10652196713753286, 0.14216877369871064, 0.2215212793840516, 0.0611353102290342, 0.14143432520570295, 0.13748102040300447, 0.1183406506935435, 0.10367609605553652, 0.11899006342695606, 0.12845096583928794, 0.13393980961653495, 0.19434650128166522, 0.22044616691287489, 0.2965601737941465, 0.09770748971570885, 0.11226158213591385, 0.1655756555978329, 0.1110949068360271, 0.13829354857725484, 0.23252763394867224, 0.12561246452312316, 0.13562449824906167, 0.18559239924915377, 0.16915503288469008, 0.12290469611123686, 0.07347866442174682, 0.16742217264348463, 0.12040282915075941, 0.13690266998544817, 0.156463744539407, 0.13433538677711643, 0.17639831759996955, 0.06939356951343437, 0.18905626579878793, 0.15863312167986748, 0.10718717660394408, 0.14596380473625276, 0.1474920582146414, 0.18578759845226042, 0.11385447045247402, 0.19428366675011574, 0.14039076023524807, 0.25227448482426906, 0.11573292570368898, 0.14345759405724465, 0.13020185212935173, 0.061619473966739835, 0.16651863322382973, 0.1874719959713759, 0.13350753684438046, 0.1706337970831702, 0.15324611397039506, 0.1413749687133297, 0.18854179179235814, 0.2098223506923645, 0.21439845433398602, 0.1629360230459321, 0.1158072745367404, 0.10089052375406028, 0.0829333232174958, 0.2413162099377763, 0.12432965029391552, 0.1520388972975554, 0.2125031987745916, 0.12926564672060553, 0.12244315111949561, 0.1249273827359561, 0.08660875260829927, 0.1228705209289347, 0.305490491371001, 0.14145073480904102, 0.1075995693944635, 0.1822295643749737, 0.1136938754409071, 0.21415516013099303, 0.12804622626713208, 0.10016990314808585, 0.16798498679793653, 0.1051395538172895, 0.1786176436730931, 0.2395876704324638, 0.08921257054973995, 0.1770230163369448, 0.06936570689562829, 0.12260183091125182, 0.24539529105588315, 0.1222621015603504, 0.15032106770142434, 0.18936417185731474, 0.12526155028852726, 0.17797835862203953, 0.10692184971224879, 0.10950152056231614, 0.14639649119588638, 0.15840381624237185, 0.14719985695856233, 0.22322115187923755, 0.13109200033209017, 0.16695237688479886, 0.09968355989023563, 0.15365060839441516, 0.1641784337980132, 0.11284650558786047, 0.12506598336321692, 0.15382025090436782, 0.15249542441339264, 0.13864666914507268, 0.19323106194215436, 0.09634214483441846, 0.15177482679005594, 0.11722953975080483, 0.13174885944012674, 0.1177715546181125, 0.09840646833782235, 0.17404901704961256, 0.1633789597619926, 0.09341427936188637, 0.16402978209718583, 0.21799828616842148, 0.19264701183044142, 0.15114206880811723, 0.1476509142066202, 0.17017624340951445, 0.1822034714202727, 0.12280407046238262, 0.20051839671307997, 0.22567853211395203, 0.21202964918507686, 0.17087914440180027, 0.12092907026770616, 0.15295005163117764, 0.14585794670687569, 0.09305658524916058, 0.10731159694372647, 0.1707171627710904, 0.22126689222791504, 0.17019092165414365, 0.11317636006541791, 0.18839747614918217, 0.19603852903650654, 0.15614298352551076, 0.21002046102958344, 0.18601880378780827, 0.16598825523209187, 0.10281758728407084, 0.1938227116460762, 0.12594483176907226, 0.1419945040176953, 0.12806928551365293, 0.07765652491681038, 0.3396332221886804, 0.1516279370914544, 0.18186452347905407, 0.15197803927285058, 0.15764883659299345, 0.088567310012877, 0.12411679276415419, 0.2249064533821037, 0.10693366278804119, 0.2091101340709194, 0.20973708510639208, 0.10175030423148025, 0.1154302673474435, 0.20766489388000584, 0.20289118551919538, 0.10859235805729706, 0.11322890603614431], [0.02143926742005973, 0.04633827217584176, 0.10073008962095746, 0.028513415243416548, 0.03838222308625137, 0.03872160769758686, 0.04776580424438562, 0.08412254448499411, 0.03907007045082508, 0.08253924758924593, 0.03815936044819894, 0.01702127474991064, 0.10453180860607855, 0.026140672402576576, 0.03911145835093433, 0.07332762252659568, 0.04229867522935233, 0.040175056520609126, 0.04923717569439642, 0.030688097542752663, 0.03550127666864184, 0.04703530876506721, 0.028500380257384914, 0.03307600700927358, 0.04964644284618478, 0.04673528575128125, 0.05517231548325189, 0.02649765213831298, 0.05138066289345584, 0.06294107522755381, 0.00935862967444043, 0.06787481552530682, 0.02131146097165202, 0.02643386765773739, 0.05544384385669424, 0.01851998596271921, 0.08238828230288722, 0.06078884696527835, 0.024977829457531055, 0.12378210427179454, 0.027042850100946043, 0.044493344762632926, 0.00849624066763828, 0.03680068819272903, 0.05121736359151621, 0.024918746841590733, 0.03733167905480631, 0.029555656796982212, 0.028215751780437368, 0.07041728514577113, 0.011080152771976447, 0.07377380745545511, 0.012128468445171754, 0.04513258384841104, 0.03571567403513097, 0.01598689134322828, 0.028577688105043866, 0.07495381268522433, 0.02967112348414958, 0.04167875305058495, 0.058110032846490224, 0.0671738833789864, 0.04444928704610756, 0.05738540560067181, 0.01055091337841605, 0.03290464846237052, 0.044758307762564196, 0.05911650767009105, 0.05058069090028444, 0.08755762911131305, 0.04207829088573495, 0.03115199059398184, 0.040368351995223956, 0.034562642761175676, 0.0388900282973003, 0.06126188710632344, 0.08677701615998823, 0.030980055565915765, 0.01708100662536679, 0.06408328934001827, 0.045199103262876315, 0.027605074367696242, 0.02925734982014664, 0.03411203367455352, 0.05890206433832646, 0.036149402374341603, 0.06755739465476045, 0.12546158350643613, 0.12728804437023017, 0.006052711302594793, 0.024252238856147856, 0.02014864483968385, 0.06505878356796119, 0.03776462598433418, 0.033211884193963585, 0.016422893048354214, 0.052673126000069806, 0.05531360890956656, 0.03263067626844972, 0.02891169669437072, 0.048365700884812304, 0.006632700190699149, 0.05872292999899196, 0.05859541466399547, 0.08799201628613858, 0.01713880412881413, 0.017866959209523855, 0.027489770474212787, 0.05468113054972022, 0.07312332219894856, 0.0317684538857711, 0.03761295589708513, 0.053882142979531526, 0.005434010076456734, 0.062345196718289975, 0.01654518940936654, 0.06366945247376157, 0.09436807414937405, 0.03249504040145586, 0.08095483986600753, 0.03156066211240907, 0.020677408301121285, 0.09508448893264418, 0.015958632274921385, 0.03609956835486716, 0.05904297089023937, 0.04100062351133074, 0.03811719879928616, 0.030879768910968018, 0.039972705886729305, 0.03829471286266081, 0.027934310229254827, 0.02745041845276231, 0.08012853743087861, 0.03046124167139492, 0.07044684081788986, 0.06974034687323917, 0.08166777661010143, 0.04200766523999553, 0.048346138829665805, 0.03466858506022442, 0.03983664484093747, 0.020680756105350393, 0.013064730352902365, 0.060993541828206474, 0.03625612608307312, 0.07229702742469889, 0.0062520004576072105, 0.030394256858515645, 0.0226423874377243, 0.014936365506371424, 0.10465846592259985, 0.06606773668599707, 0.03639191133721221, 0.019354368710229476, 0.05844488987819322, 0.08061468916674776, 0.020752205295608412, 0.07955509763691695, 0.04050343244847271, 0.07374236720704264, 0.06589959570837599, 0.048325412320874395, 0.04446892954048611, 0.06129952500604334, 0.040216685738414526, 0.039752582013006174, 0.0365872944014207, 0.015425004155164766, 0.0619891343728429, 0.08956124780759697, 0.01837268640707818, 0.016112355477807504, 0.04073282981651925, 0.03073092185771994, 0.03400359775931124, 0.0487041738515179, 0.06677707281684683, 0.05452902379235434, 0.054452058769041495, 0.030495614121337573, 0.015257629265467969, 0.05108593354722665, 0.04101309925317764, 0.08761974352021372, 0.06672252735663807, 0.059996378803325284, 0.01993404062945516, 0.04591469067118822, 0.046402209874002204, 0.03792765715550031, 0.04826579535860689, 0.03897185031805308, 0.054129803883692915, 0.0627095902699136, 0.047962757788838885, 0.04994507541038817, 0.029347857362740946, 0.024810339654645613, 0.06027429251961651, 0.05382183270769254, 0.03931866981269371, 0.01595197209802967, 0.024972660279261972, 0.009902662225818683, 0.02356749223244767, 0.019812638676094434, 0.018146269121057084, 0.0429144069071739, 0.004830591346798164, 0.035199993440220435, 0.045373039695644574, 0.06369866340631439, 0.05254654912278057, 0.0606892210611653, 0.02874266896997729, 0.04995120794422204, 0.05650086899197871, 0.028925334974642725, 0.13681683749441179, 0.06597363044537845, 0.01755129268032409, 0.033242772859070575, 0.013844025632997435, 0.05538775089887842, 0.07684775823426825, 0.026740906121689948, 0.04714546837813912, 0.03573281142199713, 0.06730395744764997, 0.08805822926543413, 0.026398384380304528, 0.04673705541438634, 0.028629037063388575, 0.004716038698285458, 0.06226878327828261, 0.06542852824373592, 0.04206371606297551, 0.025938689490900408, 0.06432147756699594, 0.045190346877901785, 0.05106783088957591, 0.025838709271122372, 0.06031841535361544, 0.026453389493267865, 0.03690051711014202, 0.029919835843987046, 0.02438915025953564, 0.0055764200759210415, 0.05540690692742506, 0.007018293789212382, 0.056808821015780976, 0.05483460860447057, 0.04115572184204094, 0.004425573110159848, 0.053902555392273975, 0.013145148517533898, 0.1135078309884956, 0.056154953481088725, 0.10337124668782759, 0.011393567960288738, 0.05737364998147373, 0.03418023465201259, 0.01488686090470442, 0.05269281829016344, 0.02681424946434075, 0.03632520423120549, 0.028007523336958502, 0.04098787197783109, 0.07741600395210328, 0.036403008120795416, 0.03752433484600436, 0.020793823022094947, 0.03197343028601139, 0.042996294045400237, 0.021469208051360423, 0.09195148043574826, 0.07117357480550005, 0.067926534121075, 0.025318637077185898, 0.07542222182476714, 0.03121371812848074, 0.032861176803107225, 0.0729310417908334, 0.06601134495389077, 0.08839469508177812, 0.044746425738858606, 0.029354323144821875, 0.02659969504982714, 0.08516074683997901, 0.12308768387283049, 0.03714886749343526, 0.01825769469442387, 0.07020882496069517, 0.013545816332372207, 0.03516204910533082, 0.04155820911569942, 0.051443394003135544, 0.028314900794817556, 0.0846875419900302, 0.03897168177870974, 0.03551987728344337, 0.05996354810533024, 0.05308836480722793, 0.06130916622257041, 0.030422199915553776, 0.009413121508494502, 0.01825373976551477, 0.03918642771520442, 0.05535275600249729, 0.04144309291375741, 0.012965835105147094, 0.025797541621291352, 0.08998969014013007, 0.041338498929455396, 0.012120534647105923, 0.022543466334501584, 0.05938604421493027, 0.013783190590930323, 0.023068822619895783, 0.021173400436377814, 0.02073627258200319, 0.03166633628068432, 0.020183356283533, 0.025869751153814218, 0.05084777596376596, 0.05340583547348938, 0.0641603424634424, 0.024132872781445904, 0.03518447249887451, 0.03265120742482043, 0.06768124808947887, 0.07030568145696195, 0.04664326326981668, 0.02286114767494221, 0.08395870126062825, 0.030961862892933914, 0.04504684328792557, 0.04323265132223887, 0.03891558882089392, 0.01461366629002676, 0.026327716599729274, 0.006722815113232261, 0.04742499853995058, 0.039295143252539064, 0.045452751144165957, 0.0666743174435631, 0.06282607393880045, 0.024715314108517863, 0.04418042082820208, 0.10806223287457421, 0.021985279351112344, 0.1233946246605727, 0.10452642300797087, 0.16891028311464096, 0.2062415025166927, 0.12576727557086176, 0.15824591019941917, 0.13449338475062003, 0.10099935420458356, 0.19026078584213413, 0.20673941370219956, 0.1494112003955149, 0.0757557688461196, 0.17381551345029186, 0.12884298069102149, 0.10360593006255166, 0.1250020456650565, 0.07758607547129355, 0.16275527226107736, 0.23238771565018163, 0.11091365043314234, 0.1751725769211208, 0.10518135923531749, 0.170895921727342, 0.11816986671258366, 0.1408723231044508, 0.12030172852739213, 0.20411085878168383, 0.18668408986301194, 0.06765996616694235, 0.13956479487880585, 0.10165439768423958, 0.14976076631536409, 0.13152434971303711, 0.08067106557709557, 0.12896757723102648, 0.17514243902217957, 0.14115910045802593, 0.21197729473633153, 0.28630219520099703, 0.2108336173959317, 0.2350249580077587, 0.19042719546104633, 0.10257060053728281, 0.2026092345195432, 0.14989835570656485, 0.07589084546892874, 0.09808825073583473, 0.09576983885058472, 0.22566337889480978, 0.20193785038446227, 0.15131662960254377, 0.13126533538583787, 0.22418113665715342, 0.12636676235424896, 0.12255687687185504, 0.17302509457353624, 0.18110084107085583, 0.11998181787109184, 0.12238327368733384, 0.15024930058467775, 0.22046663678221165, 0.23999634769655045, 0.18401146956509162, 0.10913082593751532, 0.1463843257196488, 0.1610763752532582, 0.12175419292743168, 0.23029523841556043, 0.08744674554515271, 0.18199485035673266, 0.08803082630038263, 0.1133688779607896, 0.158993520082966, 0.11274791773288481, 0.11909478764620521, 0.15891720240394916, 0.17538148909807208, 0.11479230762849893, 0.09348058427173285, 0.1436358780389832, 0.24976606781203903, 0.16818683564422593, 0.07756755146528445, 0.21630636566588957, 0.16597874042007232, 0.20061613421045965, 0.1564478865193744, 0.1664448896002385, 0.2567804148120265, 0.09847866446380654, 0.0964423031696389, 0.20688558327815226, 0.15944880613636586, 0.22305805176015825, 0.16260295865997193, 0.10556356050074102, 0.22987059587913178, 0.15570772301045158, 0.08367392339653547, 0.09771518889934787, 0.19871458140832765, 0.09010750680200516, 0.15620132878182397, 0.1219950203273085, 0.19193946834533446, 0.1208982045852369, 0.10992923511132119, 0.13223135693659707, 0.15261995966636366, 0.15830849958283288, 0.19473406516255873, 0.16142270828206695, 0.15055690020803483, 0.1694832709167273, 0.14185106171475304, 0.10162214538262737, 0.16847865385634286, 0.17159862353676752, 0.13490267488504612, 0.19471872808231463, 0.13230073385901991, 0.14065167446049953, 0.12042354416823196, 0.18681144431954433, 0.20142693102600115, 0.16701370988401676, 0.18025937009482615, 0.14469177702501898, 0.19236720587697723, 0.1156619476575044, 0.11181971028206811, 0.10804526402705139, 0.15060488795561178, 0.17201022725672493, 0.10180335582023668, 0.12599091961859696, 0.2760700184491373, 0.17072528330308778, 0.12478063859406019, 0.2448023083589731, 0.10024899406538856, 0.0934408626128589, 0.14189163373122293, 0.14419095470539986, 0.11449905683196361, 0.09172927663331071, 0.13997589298073324, 0.10622267190727497, 0.11731279052553639, 0.20576511840185813, 0.16364892914650903, 0.28188946747010757, 0.18471639302949752, 0.10048165496799255, 0.16413347975861642, 0.2654655229660773, 0.24414249215154882, 0.08919420742219494, 0.1132940311705874, 0.11512880408835989, 0.14999109831067825, 0.16385598739068355, 0.1752353808091533, 0.07026779074822703, 0.12187121285786554, 0.16413110488605115, 0.08081533525499605, 0.1100121564682453, 0.10214777362923469, 0.14086735885470145, 0.24138642955691586, 0.20291933158953346, 0.16486432763838, 0.14550933073605263, 0.13069507485676196, 0.14168570929717633], [0.023365346527087594, 0.061526953528124484, 0.030639431807362748, 0.08822735849647753, 0.023588802883281343, 0.014417957638450449, 0.04332851190420409, 0.048978333736980156, 0.06825271903747512, 0.03412791084678423, 0.030898526573794025, 0.014638051826266513, 0.08490108899892339, 0.05683933812824469, 0.05964091017601952, 0.047435681636054675, 0.04568239366034827, 0.032538071560162696, 0.030707324434432293, 0.05113139320465346, 0.03156111984994383, 0.013231538337535195, 0.027280073057139115, 0.09152706006481763, 0.013176218170912997, 0.03573125626351084, 0.03573319446595927, 0.01074752888657273, 0.015402132600185373, 0.015177242701963313, 0.09318637586529217, 0.0664478465313873, 0.0501302809965226, 0.00940075780700652, 0.04300445671223345, 0.0531578719645979, 0.04159746346093955, 0.07636344510941737, 0.031855123327864755, 0.03872913834188254, 0.08611299412985964, 0.057965816794744426, 0.025877358406902324, 0.0669626422947453, 0.06592745066530283, 0.025532680128010053, 0.041688899885142044, 0.09095789504147346, 0.005953975018083809, 0.07057521417136155, 0.04275329478625809, 0.017994202583307223, 0.03333956040742417, 0.04960860193316495, 0.052499365767524134, 0.06113925941228386, 0.02724690336523758, 0.036176686595764854, 0.05886497802191204, 0.020532341891779535, 0.08405821608199228, 0.029118142068205826, 0.0114731146999064, 0.029350908307899392, 0.03161513670948485, 0.06975897813155767, 0.05164227425871838, 0.00942161359313515, 0.0752895966833157, 0.07790730379882359, 0.020939511877875176, 0.0044056375871502585, 0.04194137565190754, 0.044190184618797035, 0.05076294704791039, 0.05151590039472907, 0.04177008222247805, 0.053894657025774645, 0.03869539599925761, 0.04775341277221038, 0.012334286584518852, 0.059259091954558134, 0.05653245862753642, 0.07873460980913333, 0.00940694492460499, 0.02047092653810978, 0.08394560115712305, 0.006214005848197568, 0.005019688659587936, 0.049829177798763405, 0.02923769008878979, 0.08497477899635993, 0.01655311650416303, 0.045534630621513056, 0.009094547675622087, 0.031807455421996214, 0.03326583210559141, 0.05485013337625612, 0.029871384613215927, 0.018066917733860113, 0.0338027295055649, 0.044989087919314066, 0.03390576833138063, 0.07043738729290425, 0.10278343508440642, 0.0256939071621145, 0.044107332209786104, 0.05201629370511059, 0.03272708077284117, 0.031881668274441076, 0.03857954818334791, 0.11332895711905534, 0.02860066882755247, 0.037757842275764675, 0.04614543252354188, 0.03164479580347336, 0.049659872367497415, 0.09802553877835313, 0.045043009017864545, 0.015515354649734595, 0.003803599491572729, 0.04038810174191191, 0.1017120841049379, 0.01787057514452646, 0.07325569453138499, 0.05530571054306723, 0.02005676408448527, 0.015919294617619487, 0.04711171454419533, 0.04660803088617902, 0.11979129180432328, 0.005021576587516334, 0.03962584425725284, 0.013546961633819006, 0.025627134938634215, 0.021709738592166575, 0.0783111010828326, 0.0937850429346004, 0.09553870246295007, 0.06355854592496349, 0.023830697060592716, 0.034804902745470885, 0.08646002429867945, 0.036401410827473286, 0.04312210100432558, 0.05031747075038091, 0.030315673474462766, 0.08527910742428034, 0.012018705282600657, 0.0384825422999359, 0.05415865475492132, 0.01609287003145343, 0.04598779461136268, 0.016108322024886167, 0.01799253825729172, 0.049915818512559905, 0.00634962112657846, 0.01520737581285498, 0.061285900132310014, 0.027910101850847566, 0.015197716401739707, 0.05057586071592185, 0.02928286246324499, 0.055626494539601196, 0.028046532534062866, 0.044946585361274986, 0.053638182280044404, 0.06827990749790784, 0.021751519112337022, 0.03057047048763883, 0.0709032453596592, 0.06296115056160959, 0.09746768121277133, 0.07724762548722568, 0.027031793536978866, 0.06502297661838032, 0.002898193450809847, 0.09311483857492286, 0.06099193687400511, 0.04215117649085099, 0.02347190935735501, 0.016839646794382605, 0.07587035261695424, 0.05431585982742329, 0.12175114389749304, 0.04857026168235368, 0.06011861196208385, 0.08379608377694123, 0.060820677918532205, 0.05391134242076547, 0.08806765980778203, 0.025774549407463883, 0.02259426370954081, 0.013396822764808613, 0.061204047468040264, 0.01774553044308578, 0.021068503847345713, 0.05249935044576565, 0.03661034981750193, 0.032989852761308995, 0.00988756167522121, 0.03303015281656577, 0.07273841664315232, 0.010310891328469641, 0.05898282532730411, 0.0967422112702362, 0.01382240854699405, 0.05994720744990534, 0.023158767087865743, 0.09270935589748044, 0.012368332489483781, 0.05497290279656168, 0.027718403669554862, 0.011610869757620799, 0.017327340282199365, 0.059775822089924935, 0.0382884462634402, 0.049251578147372896, 0.051983275315574104, 0.023501185407381386, 0.08194586652661524, 0.041108197577658205, 0.03262379679888968, 0.027366930190774224, 0.06472326770064331, 0.035590828516550606, 0.037129757430164084, 0.04352406733819554, 0.11826755058380867, 0.021339409774349585, 0.01996258123507423, 0.03481704906951036, 0.02855286685629718, 0.031695359521695686, 0.01815231546999947, 0.03706314991558752, 0.17698468129721381, 0.06824957041610634, 0.009619417495184369, 0.0369495888721318, 0.05843556658815473, 0.035665759576424476, 0.04991951488679455, 0.07598811565267463, 0.022926621379390843, 0.033341471796795245, 0.0431954654143943, 0.06488488927002876, 0.057912071896416534, 0.009102302400635616, 0.04011156315344476, 0.05191536545152626, 0.039014061762680935, 0.044521234193516356, 0.01971214517740713, 0.043452503234748883, 0.05686681770208863, 0.05738976081052134, 0.053507399580050866, 0.058955364905658274, 0.04610256607373876, 0.0042125580535690875, 0.04486875848904733, 0.03310490384577744, 0.03040816901522058, 0.03087797435000539, 0.079828682956436, 0.017237847806104732, 0.010921925929705463, 0.05546692225541319, 0.03734101000572405, 0.049089309233691425, 0.029360880857453715, 0.056311492057096575, 0.04015553660029846, 0.06118516723114637, 0.047184542692717046, 0.01851753448136151, 0.02404606352830606, 0.010888890303190677, 0.06443134223621699, 0.060453878850826336, 0.023009431653565938, 0.018723604472113714, 0.05644631204045108, 0.046429072747067104, 0.07216826336638582, 0.08261547333771184, 0.05182227810784694, 0.022958017577747666, 0.07780749786404834, 0.07452654246721538, 0.048190201632678516, 0.028655327285730073, 0.045440336689352996, 0.03826684258397549, 0.04834702366121835, 0.05093157066092376, 0.022068256249410972, 0.016476484729097258, 0.0407707971340466, 0.0884085995776038, 0.01994925322041156, 0.02931058335478508, 0.030410233622176513, 0.08230788903611322, 0.13581646456112786, 0.017762430342695406, 0.05710952201737993, 0.023628185548248793, 0.04082838013287514, 0.024230081678157853, 0.07857760774993128, 0.054486869804320805, 0.06919461647949873, 0.015730937537286552, 0.017492861239119403, 0.038367353319641084, 0.06444274928540954, 0.04114040008355533, 0.02696991661533473, 0.016979090118360136, 0.06348345015618591, 0.017755958814955047, 0.01537142396574059, 0.032451495963839755, 0.0777194360571523, 0.027109735322395162, 0.06008320720866323, 0.05842687915109339, 0.01707707467909542, 0.03778388160431097, 0.05712158407174772, 0.007044730047064443, 0.0889360128090747, 0.050784022126707344, 0.04220386035740376, 0.09440388109895492, 0.01136100252023748, 0.05491181111503994, 0.027648141915579478, 0.015289447769793052, 0.07716091965595562, 0.040962349758633686, 0.01983369077225366, 0.007384307616795864, 0.02363473176956177, 0.07648304675615604, 0.04236983713663874, 0.050627609955207, 0.08344498568124349, 0.049792003382237694, 0.09077566570692486, 0.13580360960575844, 0.1322253814507877, 0.18457399260613228, 0.12206330940487886, 0.11073503703359636, 0.15051323319635085, 0.1612834794627082, 0.22990369087746068, 0.18048086143549413, 0.2085261758897574, 0.1434241006931951, 0.196195071442954, 0.16207582888103303, 0.27799679086573664, 0.15633527159450517, 0.16203418434146913, 0.1293730828911066, 0.1782660859246408, 0.16110902592059106, 0.10067359829742102, 0.1623368043933184, 0.07294975731882357, 0.1954028292769386, 0.07173903962416996, 0.1476478192114061, 0.18267934991707727, 0.15885527185615034, 0.21045795852138152, 0.1817493038552423, 0.17552660147268928, 0.09734300806397393, 0.1642874787531553, 0.14192598511374768, 0.15191839166706608, 0.08522817023819493, 0.2319675011019553, 0.20324174735334613, 0.10629362697082181, 0.15341460734846132, 0.15030905544277162, 0.16431665138131188, 0.2372648765242869, 0.1759686648485161, 0.13221359901851223, 0.09880731618332286, 0.18698701635003093, 0.15467595579403062, 0.13190406885358597, 0.15641503666918125, 0.12549879239691844, 0.1884703770760567, 0.17300673910687048, 0.17390790365396008, 0.13927403386802445, 0.28890315563448016, 0.08531345880680508, 0.13321818543537972, 0.09413784940636928, 0.16580370465113273, 0.26563973136005864, 0.16784657003177753, 0.11552213661132321, 0.19072713420516063, 0.13800146989524364, 0.13083781235881392, 0.17411301603480694, 0.11166681445414021, 0.13981476936849857, 0.18385031530933996, 0.0825444493262518, 0.20201398420237726, 0.2085962269695536, 0.11011113502806234, 0.134617981290625, 0.1796142321320311, 0.19596090900801844, 0.22411061060284415, 0.10586528422971887, 0.20477832054659245, 0.12568440784009235, 0.18554991201287319, 0.20920826993401975, 0.21463552790303386, 0.13393064720496056, 0.08996797154747671, 0.21796146798278057, 0.12151058462838973, 0.1518498114760845, 0.1502301637083292, 0.13974336997395562, 0.19579580173857752, 0.07752015360540922, 0.22428578426761014, 0.15155154280364513, 0.13094495741590378, 0.098009979532611, 0.18125479410011924, 0.16852126366669135, 0.13366556546140101, 0.1900259339280667, 0.19280880960004945, 0.08969975650430688, 0.14281322218237386, 0.26202321413063234, 0.135374462472335, 0.15613866278961783, 0.3198727196262729, 0.1997992546567994, 0.10664178328889032, 0.16006362233911792, 0.1833531702117574, 0.1708178880113748, 0.08783628593289083, 0.11144395181608778, 0.14996428523332844, 0.18923177654224058, 0.15827157414488255, 0.14789593976832208, 0.16877679995471434, 0.09856650410520454, 0.2143398179642616, 0.31344226952041354, 0.11120546098438003, 0.20912301966980582, 0.20831907168030742, 0.20519566992598198, 0.11746806122602955, 0.10589452580578866, 0.18955676636147886, 0.1615374222878487, 0.15519047576573589, 0.17413078927465026, 0.10601562132397968, 0.08933977178868749, 0.1635850527353825, 0.22659362413950507, 0.17262174928140256, 0.18604232268708368, 0.1860881041014387, 0.0776855213447444, 0.07329588350389274, 0.12256652191882172, 0.10515404053993764, 0.12923996745338365, 0.16424192716517758, 0.2074297048872517, 0.19153167974323998, 0.18877002470675977, 0.09782011996233657, 0.14928194604093029, 0.1437437278969634, 0.13472079029006345, 0.17222647855599083, 0.09621011724154796, 0.12006819428455447, 0.11147870922521239, 0.12215847284683298, 0.183684196803839, 0.1943972163022526, 0.12788537844655015, 0.2258810704393733, 0.14976835058581445, 0.17836042199163668, 0.10042322544200767, 0.06994811757918327, 0.1780921073570367, 0.18990628631605258, 0.0979752604278826, 0.06969114870674188, 0.2252744207338941, 0.1251597065598734, 0.1474462768002864, 0.19378282910873815, 0.21426333174590143, 0.13965113298787227], [0.04075384360828227, 0.03561035992818014, 0.060776907484978444, 0.09211527003395943, 0.04105300860359304, 0.047718655363085775, 0.03552048249290355, 0.014213149777553497, 0.038093909726388035, 0.08274824403586888, 0.0679705994984796, 0.03494203248391709, 0.09267821442335845, 0.007571674049681714, 0.03224636060035518, 0.029369432313908494, 0.059119441786841045, 0.036386318895364964, 0.03244432538086849, 0.0518700207072881, 0.03376221877612895, 0.026620254934495016, 0.009304934571827612, 0.010322890180583683, 0.05003121050615465, 0.07105926682631816, 0.06094080816593863, 0.03195872905874445, 0.027385333537935253, 0.04470434069873826, 0.043918870749973485, 0.04407841622108414, 0.03971750284695337, 0.05397002858620498, 0.04204305850209729, 0.023129692135919488, 0.03576282674687044, 0.06614747111715617, 0.05040702259828968, 0.029950600019806338, 0.0400961073295724, 0.0025125929096248, 0.029553615172664006, 0.07070065340808324, 0.021105574842001644, 0.03823799554318671, 0.04658356586831712, 0.016407862403279832, 0.05157279391442576, 0.06748380424875407, 0.04432602732953045, 0.03600753438208373, 0.09544307936824138, 0.020001079068489133, 0.02220760381239797, 0.02299656712209746, 0.011638520743637797, 0.030598214361816648, 0.054547406072097446, 0.030291997527162877, 0.007705038944785033, 0.10246620573584111, 0.0372636849210868, 0.10008555686762256, 0.06786101062091128, 0.0207952460304143, 0.023480234817872127, 0.06998607723583138, 0.054113823289592425, 0.03510778709765404, 0.008861029712152819, 0.01985180109078365, 0.03531599447371499, 0.07793479103354678, 0.0657357295013724, 0.01234925402733948, 0.02688691098873894, 0.09216016278632226, 0.045176281503612, 0.02762517268438974, 0.03683466802261049, 0.06767186351240644, 0.0316617684814358, 0.05772273326593061, 0.04104272387320957, 0.039007653437194326, 0.11339135498048798, 0.010659103187912656, 0.07305474200796697, 0.06294637272555022, 0.03008035424676153, 0.1125853538753525, 0.04690240017108379, 0.05371095680241143, 0.01102337225024859, 0.036657962181995955, 0.06028427081483026, 0.04240069132778914, 0.03947663714268035, 0.07703735733464842, 0.030420738602838213, 0.04760521306325832, 0.046480140168099635, 0.04681931027481633, 0.03644342691968045, 0.051119683550730835, 0.02163641057127426, 0.022952685605794675, 0.028736678162409414, 0.03595004714424572, 0.04735023218898043, 0.0443837903590212, 0.033234935779605186, 0.0921236970011265, 0.0197060547784091, 0.04676946476402302, 0.009827269597970431, 0.013984077039264865, 0.01882213487049505, 0.020409432660427787, 0.06574774176002511, 0.06831840341610294, 0.022263576111365712, 0.0582541722894436, 0.044181569960088506, 0.00825084068046342, 0.06922290044566316, 0.03800752182160655, 0.01666747427906, 0.03359670931052777, 0.02154131033157389, 0.05010620668350209, 0.01835390001595501, 0.03198240117560471, 0.020695918900591713, 0.026391539384701082, 0.028436082497900052, 0.03216730798744867, 0.02500849021148057, 0.04410092005385988, 0.04636830665291317, 0.019179196960683313, 0.016195068075772256, 0.07510961198638524, 0.017860152518316623, 0.06997372789849197, 0.010073318844661117, 0.04194265118830147, 0.0038393449147171793, 0.03697931308359389, 0.07264981857470929, 0.041374554857611656, 0.045026905849696174, 0.024916460069136757, 0.016339797406427322, 0.03423103777271125, 0.041726503310905355, 0.05947624723757467, 0.024944920235523776, 0.02374677787414722, 0.05652088303900054, 0.008303554232923255, 0.015204166862062149, 0.024123315834590507, 0.013501404300181857, 0.009999976459620221, 0.01646707333894747, 0.021390785545771642, 0.08049157883731589, 0.051287280605925675, 0.041761084519807375, 0.05089114037071986, 0.04852625376154338, 0.025220717633924177, 0.03456040961487639, 0.03417930768562421, 0.053058797643790324, 0.034644265599068136, 0.05892599692508098, 0.08817590803148286, 0.02536311231163, 0.06471469517677061, 0.03439828625790054, 0.01892451869113551, 0.06240048528378529, 0.027824349799043233, 0.026373739331780423, 0.07773399172771363, 0.04780008667899717, 0.06992976211251752, 0.04090562477828034, 0.05168949591837103, 0.04941358276072049, 0.041839692801717794, 0.020803236327464544, 0.05756316864262185, 0.02610391741918941, 0.017380491462385943, 0.048359250424489866, 0.015920142102385723, 0.04829300680167733, 0.055546277473049785, 0.025466133900467428, 0.07890108071507947, 0.05271837881375706, 0.04274380678731588, 0.011949274734023118, 0.03678780259384263, 0.033899865623924046, 0.12439702006597674, 0.07959472736523998, 0.028610126182977712, 0.0700014219769547, 0.026417341225990848, 0.01785410425415443, 0.0341498286222979, 0.0410384682547902, 0.05387932377597017, 0.048093674554219173, 0.10755687531444336, 0.05660033784806729, 0.023274637886413166, 0.014482441174256948, 0.038597172036045985, 0.043750622520043005, 0.09683215765342598, 0.07824818228161143, 0.014789270879250142, 0.04654809982786256, 0.08724345645356564, 0.04557760432362557, 0.020620191109276587, 0.0450128787798026, 0.028178154100333492, 0.08594722802480383, 0.05361590444320633, 0.07338500251212428, 0.04798724578933851, 0.03784657824003408, 0.08426712825894357, 0.020595390927947817, 0.010942982813914218, 0.03938715424268477, 0.04297146513577431, 0.06525365335326042, 0.07177449417330566, 0.03982511521767705, 0.06093253058591678, 0.05415038100533909, 0.044298969104044864, 0.025804162536176945, 0.05805197104270901, 0.0815829553551251, 0.0506256947353963, 0.020095890109998085, 0.06216616963126487, 0.06802366640899452, 0.07122628165469055, 0.025212782878248442, 0.029330348423231515, 0.02635359696503128, 0.0368384103621206, 0.038895636060906034, 0.032648074125210126, 0.04995166376653699, 0.07830947697643312, 0.06142155515150197, 0.14082499419248876, 0.05949757512538664, 0.021828524355265885, 0.011896023962406382, 0.04692971886646363, 0.04212114967465882, 0.09167705241951252, 0.021663568388190002, 0.021959682438342322, 0.03547662778967812, 0.05453401868562064, 0.01695104938511166, 0.05575438908812019, 0.05569465721266405, 0.054310811308002284, 0.017011344335192156, 0.0161921052307251, 0.03317546437404329, 0.025533180000380646, 0.010509794566690201, 0.04251095436273083, 0.03499281262197802, 0.03857436942897978, 0.038540669221190677, 0.02194607288636748, 0.029640987500428196, 0.03330217148627966, 0.07565761000038156, 0.02024765978867729, 0.015274491818291287, 0.03474180008314791, 0.022361987766118783, 0.06986788519087338, 0.0267684948630631, 0.03529213083487365, 0.02228078053092524, 0.013083063794540302, 0.03359214725693868, 0.07816906072079174, 0.043404281830355045, 0.013392132391492206, 0.06334369273615942, 0.024998421900935715, 0.022767771133071473, 0.05728616657096052, 0.04051120824090416, 0.050307615029235045, 0.027094260346324697, 0.05022583897375772, 0.04625561128881189, 0.023900700259893656, 0.03133153095991621, 0.021585517435244495, 0.06343049815885964, 0.05366811333524604, 0.054072933346633954, 0.032950992951349865, 0.03983991986681377, 0.037082194861385136, 0.01566059917451874, 0.024090872010997227, 0.01805305920330988, 0.021166302631759358, 0.03323998429902619, 0.028020177194247806, 0.06805561227543701, 0.026944712322625904, 0.07240898351395324, 0.013698430622987931, 0.03354675654742507, 0.01507424505337352, 0.01156030125134895, 0.023747321796573462, 0.011199470008573225, 0.09100749923457062, 0.030751460674969904, 0.03598806042704852, 0.02752073000245277, 0.008317613861553611, 0.042044368512447805, 0.030339404963137164, 0.004150857332147538, 0.03609910487167297, 0.04274852971936907, 0.026157252460477814, 0.11340835447152776, 0.20966223831618988, 0.1494028806806572, 0.17085262243786167, 0.12636100137305836, 0.162534715547677, 0.10329797803874939, 0.07771344524958441, 0.15742915321982678, 0.1342492784944273, 0.14157646515917394, 0.19391669531262692, 0.21713482846896495, 0.15035695125979764, 0.14379556140592023, 0.0861407648171148, 0.18147461536911227, 0.07791704843722044, 0.16461741750038442, 0.20717118085632402, 0.10848137489970654, 0.10767902803396988, 0.16221976148024683, 0.1409245856226452, 0.20980895947544806, 0.15095658359989045, 0.12843352967813132, 0.19218915172161596, 0.19816100627424257, 0.08337720988258239, 0.1970651941073518, 0.0911641488933275, 0.11092141856469455, 0.17902540163167063, 0.27297508452207814, 0.10036295730500452, 0.2057480193193882, 0.14139084205512079, 0.14620855450630188, 0.1452468077261602, 0.10147654271173863, 0.225018440114875, 0.15860523607942367, 0.20505919902315065, 0.08573345118953336, 0.11035872698431054, 0.16110804532804798, 0.1463001326567704, 0.2028835093181941, 0.203170026201875, 0.13444069322318802, 0.09656385834058447, 0.19141180230484856, 0.08385075947209712, 0.052131352450458274, 0.16689073745041125, 0.09415478761037512, 0.11569880414754154, 0.16731737181544307, 0.15455848387172147, 0.22011733133225675, 0.18589756271291166, 0.13314338461045297, 0.13170090233606677, 0.18728968236715565, 0.09782418788921449, 0.092214738890048, 0.10639773065885229, 0.21052168171492316, 0.249936445766399, 0.11915260430185065, 0.1063968726403771, 0.13610992220140275, 0.1824737012746834, 0.11697489978565324, 0.12291182072893267, 0.23249694446642555, 0.25920888288847865, 0.2179297979079908, 0.11987581428500915, 0.1677354566392399, 0.1728776992569047, 0.15294691067068808, 0.1823785225109708, 0.15142590438406314, 0.08413048115588966, 0.325923404626308, 0.1017818823757191, 0.14203671546232316, 0.2098617582551895, 0.16704407760933523, 0.25706858644562386, 0.11870600568551211, 0.17859936481521976, 0.10750792229608183, 0.10484175245848396, 0.1714716368024388, 0.21276359206005452, 0.14794725233749037, 0.11134898755699398, 0.14530512233895643, 0.15903605328452203, 0.18034296560912363, 0.13362957465071834, 0.09522886586285408, 0.1722890985829215, 0.12000585004927651, 0.09589626634072873, 0.12950042202588052, 0.1667250173106309, 0.10882452100275025, 0.23531737376845654, 0.15196697696322395, 0.11191344880048307, 0.17449843486951244, 0.18296778202056888, 0.12082154982753339, 0.08797792792921105, 0.1385226241883732, 0.14748144023601087, 0.12363439485911401, 0.1788638336884399, 0.17077947636285137, 0.11282371447211313, 0.08555975607446126, 0.09850905517176275, 0.14293506080585142, 0.08866410522210984, 0.13108429348757192, 0.1159565927340619, 0.12470031427519938, 0.11618940685425075, 0.15542921940645865, 0.11785705769134146, 0.09968696132061944, 0.12858548321791236, 0.2466833453264929, 0.090762197881216, 0.10981643632535013, 0.11662180220047313, 0.1612321668935399, 0.12425645059275052, 0.08680779757278581, 0.14266265526173577, 0.20404284549576623, 0.12623229094090002, 0.10188691303013794, 0.15765896427535242, 0.08710582875796864, 0.1409217204538084, 0.20150465830679865, 0.194240290851843, 0.1560258333601298, 0.13604696509578537, 0.10752594834494014, 0.09687851363372418, 0.1841601365876775, 0.11759491772541117, 0.1218778471792898, 0.21368727959211797, 0.11267640342515324, 0.10264315672459141, 0.19650539833932154, 0.0897424276016893, 0.12191846516103515, 0.20830048638726437, 0.15953997059935526, 0.05479140507598078, 0.21208427125407806, 0.09380652403999722, 0.14276986160585958, 0.10976500884299317, 0.17613277620365544, 0.1053160757968022, 0.15563451564840733, 0.06718772658777815], [0.04760436653610199, 0.007477641545025813, 0.0649507038836037, 0.0545210526475022, 0.026970843581723112, 0.07681541400210512, 0.03107058417592799, 0.03788002946924779, 0.03053013404320565, 0.036889305413370176, 0.024613018387988694, 0.004859385719042151, 0.050580675578525955, 0.01823652002419676, 0.05292862398369659, 0.05522057519204194, 0.023311894657390735, 0.012055717863052363, 0.0236217255118273, 0.012675759743057914, 0.05631243051480382, 0.006464635343065546, 0.05723062519645018, 0.050223728401526335, 0.020474034939862547, 0.04348959338160292, 0.04567625729607479, 0.016712797955880244, 0.030101613186660315, 0.031836905757025365, 0.05427308147773147, 0.030494656511432225, 0.039155849315706766, 0.03736836317506048, 0.06789821185051434, 0.08594961821912758, 0.03710816907245786, 0.013182754816126921, 0.002763708870324697, 0.011903835186404328, 0.02148833918204952, 0.049884596599205855, 0.051241434074097106, 0.02317705935227775, 0.01676782988192093, 0.053218029018852024, 0.02262990403499815, 0.03394604923443929, 0.0610341904534688, 0.013098372146487238, 0.02602659041933235, 0.06350871573592867, 0.019569825193273927, 0.019499180395336404, 0.0935971215667744, 0.04389489219794351, 0.02968060573743236, 0.009975290233870188, 0.017446507174041004, 0.03422759420749161, 0.020241312750224626, 0.03281960121145652, 0.045217680895040115, 0.01625301305114502, 0.08057888987804614, 0.01843212142346367, 0.0917009620236293, 0.043630840842642134, 0.032402880024164915, 0.04257531340924963, 0.02637295600687785, 0.026145284251880743, 0.02466723634560983, 0.07206239001525026, 0.06590326526953329, 0.04263736653111635, 0.04699032025171384, 0.0931630255053601, 0.010271802649743134, 0.031143395087471416, 0.029534108658892014, 0.04177970045636739, 0.038817541057904886, 0.03222772168115743, 0.03089654432128995, 0.030745705439438744, 0.07729124653363421, 0.018197047343898206, 0.025200249679807215, 0.05127581226969919, 0.03302541073231447, 0.0517290069030658, 0.007109527678919897, 0.028819814023952332, 0.04565889008283135, 0.02101532010842235, 0.08027140516787767, 0.013984248451437923, 0.055029620116035786, 0.031454557019676414, 0.029645105223021204, 0.03875163834421866, 0.04024542169645429, 0.03507373065898015, 0.008263385370223513, 0.05104122082552603, 0.03564059358811186, 0.08345310621324085, 0.012259206137499742, 0.028432504867293665, 0.04565381858077261, 0.018669252449105826, 0.035241990380229495, 0.05110946776826055, 0.005606396138788231, 0.013870030487587136, 0.06468422786002198, 0.00793928325536751, 0.05638215600723221, 0.04167788354079089, 0.033881487174620556, 0.04336015133547687, 0.05558884514856243, 0.07542724736155042, 0.11218360204610134, 0.13991361003248923, 0.0030978515250383006, 0.017964131717059403, 0.025949686683053454, 0.018764800850241896, 0.03392893099977124, 0.06888792083989229, 0.039594875152913794, 0.016531769464152957, 0.018709100512487274, 0.04278409918169341, 0.08156285320799198, 0.042583525871797916, 0.035575008800914215, 0.03467570201704099, 0.010043396407948628, 0.024676281928775773, 0.08104169891486246, 0.02545554081969444, 0.03813536274397085, 0.030381685355678204, 0.052820096137903394, 0.017044414435663534, 0.031446631840099735, 0.042065478065201355, 0.15849602258493825, 0.040358128551874435, 0.0370782686607732, 0.04494027279677891, 0.045565595895412474, 0.09538072747208419, 0.07793682116654613, 0.017350533594106956, 0.01967411465762604, 0.05869278826961114, 0.06888776762230743, 0.07626613662127527, 0.011482180392880355, 0.03280578864618175, 0.007757510700743766, 0.015514333837575492, 0.08322516441225045, 0.006396931365147354, 0.03295224167466645, 0.06790468529347451, 0.038737496361136436, 0.02412663491052245, 0.012126866363800101, 0.018704588254613262, 0.056226571210690086, 0.035612087456449386, 0.08284350706925316, 0.028691199352784504, 0.045692670729852496, 0.0026804731779491472, 0.08477658438946932, 0.03387769120895574, 0.006238116071589532, 0.0829108078934012, 0.031192225531765053, 0.023024833851283597, 0.03156307528937056, 0.01727963790237423, 0.09750367202345403, 0.018825101545981823, 0.026260011664201176, 0.08568084393177303, 0.07728409893330067, 0.02100974298833359, 0.022768828334406983, 0.024832897113576054, 0.0931423181487668, 0.04882606610115017, 0.03036772723369781, 0.0435418673911162, 0.08580200073699798, 0.02832211159740485, 0.06563226932719832, 0.022186919438442396, 0.03601789189082, 0.026177249270521348, 0.06580909008100148, 0.02118649479422358, 0.026523829362685644, 0.013181897755261632, 0.032768445690312696, 0.026246386790467847, 0.027819967776116346, 0.044060696607395526, 0.03642152829636489, 0.04495903429004454, 0.05994493982964947, 0.04978175695625044, 0.07646161161603467, 0.08232887218435926, 0.029828064256317677, 0.04985698679041478, 0.05895731076898594, 0.027595412083751256, 0.046946174435077176, 0.05917399873836868, 0.017689494941864285, 0.05372794097169273, 0.02492116384899184, 0.010728894755424512, 0.0269436915104668, 0.052731815995948936, 0.014024367518422585, 0.0477409063868465, 0.029211087685619152, 0.059059411137094425, 0.019936762156806166, 0.044362075596807465, 0.0222174710248627, 0.06622505284124805, 0.01005890490036578, 0.006273121980484576, 0.017769298320936582, 0.01317524332402935, 0.0920505509261162, 0.04269999038848666, 0.014256636758575277, 0.10743822361673079, 0.013888855183106518, 0.05891789937572134, 0.030384236428466056, 0.033294491454838746, 0.05588061739540389, 0.06796489980432295, 0.06230806826703972, 0.024354637998546806, 0.08046886433036098, 0.07754516637613697, 0.07053286483090732, 0.06410714531798037, 0.04474111674954334, 0.11586552020162345, 0.0556053773259684, 0.02145433828475014, 0.012236284786805272, 0.037522852465870886, 0.04143527498649013, 0.0769622577354312, 0.055732107420842496, 0.053139175588805834, 0.0486479927935908, 0.05763713443171113, 0.07485265843570232, 0.013875870950399868, 0.01673966657460457, 0.036110071420309045, 0.046658079410272266, 0.05470349648666959, 0.005933114922710605, 0.03311630323409073, 0.029699677496307322, 0.008011746554515295, 0.011542099959877952, 0.02325623836969176, 0.02454639555165364, 0.05986639283477299, 0.05047338496473047, 0.04517000341307252, 0.03575035866590277, 0.016350972714022766, 0.031098927513906555, 0.01010432625339637, 0.030107242017683965, 0.05661981563354212, 0.05403189784696987, 0.012462736546782958, 0.09714793909581439, 0.01743947831733573, 0.005749616755037419, 0.02977650845423341, 0.044006212434220704, 0.031346249424161456, 0.013826277291011668, 0.05720693775783143, 0.019414983502018358, 0.08267084617287883, 0.052485599167524814, 0.03948264327200671, 0.030332247786704573, 0.012742766580965011, 0.03900980231382194, 0.023656182231441624, 0.03483736955170189, 0.03473859783562441, 0.05442357562001675, 0.04033830219639405, 0.04491586906595096, 0.05937602378488068, 0.014194459147420863, 0.03806735711893247, 0.040483594601673466, 0.01848700396235912, 0.06631434038882295, 0.053250392403213255, 0.017356838497723785, 0.082553542789913, 0.021744720082009034, 0.07288383545293924, 0.021056185153523282, 0.030474621396992477, 0.06308045343405778, 0.024515278975389177, 0.03510302969164426, 0.021294045877913316, 0.04366879666885061, 0.035200326688467495, 0.034032333717351, 0.037453559813119715, 0.025432466251415112, 0.022060237224063566, 0.04069845928179641, 0.02631383125610169, 0.02050375915132463, 0.029557598829870264, 0.08453672992125635, 0.0673992817680682, 0.029020961899791035, 0.04697800155789141, 0.03479253042549376, 0.03204879035512286, 0.03343767711832639, 0.020362942614742828, 0.18879254769173362, 0.08069361154470714, 0.1248015451335138, 0.14956032707085534, 0.19011797173128975, 0.11795020632205472, 0.12931628513240045, 0.14210239984095097, 0.1310762035990915, 0.1273927992329963, 0.159793132014813, 0.1453382479808023, 0.15900652825592027, 0.21949926691670574, 0.18311934485550851, 0.18531446255022482, 0.2982182944974592, 0.12278172367763136, 0.12468818710335802, 0.07344636615485915, 0.12434890208345269, 0.1721568871289492, 0.12559453040481577, 0.2026817677242141, 0.16345046640884492, 0.09017883724863492, 0.11212014698333318, 0.12737718636109946, 0.22826064678449787, 0.09844076609419239, 0.23574356380249226, 0.09826845759826322, 0.2103966561656806, 0.13761148517650945, 0.1310850442537377, 0.12018754312227811, 0.13082751613711158, 0.09616624338612442, 0.08908614305959595, 0.10571642568515194, 0.1355488394056597, 0.11080206206609165, 0.15801522580365981, 0.13089332308980728, 0.10922323146294202, 0.09467509920678793, 0.19234414663045638, 0.12352518136462859, 0.17566492630829736, 0.23678101539131136, 0.1929746369921392, 0.1413027725873455, 0.14937854972818207, 0.13020566724721463, 0.17597416535981242, 0.12770750049141147, 0.09546897314008206, 0.15470022545947185, 0.08177890532439755, 0.21704973142233588, 0.2705009882488559, 0.23374589760938, 0.17228022728475834, 0.19679383044281315, 0.14602567399701766, 0.1001931768992255, 0.1826124551195291, 0.23147164303208553, 0.11746236919275216, 0.09401948882206794, 0.15394204356256994, 0.13631105092504334, 0.08497703129485731, 0.2828445339635495, 0.17598179559553825, 0.14423122028670005, 0.18806646487885909, 0.1461375075122041, 0.1352646820727856, 0.07669737517473198, 0.21040713624848476, 0.22840110134453545, 0.14719029618126733, 0.09529636586986243, 0.10996085155995623, 0.22339460950705314, 0.2097475805109547, 0.0851113111862252, 0.1238317467692879, 0.146134979422054, 0.24735592455873567, 0.133605994464409, 0.12942295521497726, 0.10581289147657734, 0.20258490356706804, 0.12441760484850216, 0.1925784929264938, 0.07130279851656768, 0.10836027938151553, 0.12354037288816706, 0.10311404032812965, 0.2020140454894112, 0.08754287425789141, 0.13730981507368628, 0.10205376698004623, 0.09436265790774938, 0.2720528372353123, 0.16517197322701255, 0.12138582720992067, 0.20264632849683686, 0.1696763097518875, 0.11549599769134676, 0.26321549208894857, 0.10411692602980523, 0.11247043302583118, 0.13520995275147502, 0.16515902634109222, 0.13518609677351293, 0.08743540744387335, 0.14075969285782308, 0.18268736319676523, 0.21703200414776805, 0.11677747892756617, 0.12147733641247596, 0.22200039077189662, 0.20880720758390045, 0.09024669731696768, 0.22089725480444972, 0.15005946399704104, 0.17769843009450745, 0.1241499413886378, 0.13309910472842956, 0.1569171000512377, 0.05970872427907683, 0.10743474557755456, 0.11179272866537494, 0.1870443044050086, 0.1949945197350556, 0.08013976061896932, 0.0806187953980219, 0.09622216014371765, 0.10411039129981112, 0.15322236524474236, 0.13680471798344968, 0.10678595337536066, 0.150910189315196, 0.13191312401285096, 0.13351614767264935, 0.08562346394624441, 0.1554902612922653, 0.13050536084319317, 0.2677201503707517, 0.07814790137232312, 0.13655526443354546, 0.17025055393816965, 0.17685280692192817, 0.1906297337864676, 0.133149191556919, 0.14900014825886296, 0.18365742969176463, 0.10221053921287099, 0.24428680779472475, 0.06809671289257466, 0.11989730305128521, 0.1517322629449829, 0.10963151036130805, 0.15514662489295006, 0.18261144388346903, 0.15762740145287207, 0.2672171676831861, 0.13391213852070993, 0.17227625894931056, 0.09940742349792873, 0.13709517255906137, 0.18481667393878584, 0.08994963906344869], [0.004969559696262642, 0.04511313670645318, 0.045336056801099936, 0.08219173478503382, 0.006403298034603077, 0.04067320902381213, 0.05000908588690143, 0.01155724456053107, 0.016311404272733677, 0.020423243310482755, 0.009147073536540472, 0.048831378920905055, 0.04461917087375637, 0.040634475618360505, 0.01192361940704887, 0.025362903552670634, 0.12293474974050639, 0.1539070639879473, 0.05116960950075619, 0.06439594897411524, 0.017094265692116275, 0.042552721476362604, 0.04283653790011041, 0.007411851350503464, 0.10924288927907906, 0.026596820304891276, 0.04292374551897088, 0.0600653228860709, 0.08869690910702752, 0.05603540929094438, 0.03256688029655526, 0.016126897741830157, 0.01819703393735953, 0.049362243378474835, 0.07470552358896503, 0.09633333482328924, 0.016160709032368277, 0.015339819966034304, 0.0740703983953403, 0.02002460945908341, 0.06568579589046779, 0.0488095339237442, 0.09497421823682324, 0.03773675953608848, 0.03362477111119417, 0.02454750637914385, 0.03587479815788327, 0.07602216060002966, 0.03530053098896339, 0.05637430743644795, 0.04907600228644667, 0.14857685403718104, 0.03934638687379418, 0.03603141717312317, 0.025051105767488483, 0.032647610642015934, 0.039831580999757976, 0.013029632992261361, 0.07861083298320733, 0.039366799286536636, 0.10170436193866116, 0.04779060251049457, 0.03391609902703955, 0.10229176751548245, 0.027988332834455277, 0.03342826189773698, 0.03888840802134045, 0.03552920823436111, 0.02658770960425177, 0.033388168686219764, 0.014042192469200781, 0.04389652779566185, 0.022166612362789533, 0.05225957641678472, 0.027990301680420677, 0.026330418974882173, 0.05524872126238001, 0.018682607276845845, 0.0337310504889296, 0.05651216112798261, 0.0680599789766054, 0.04654897699853586, 0.04129505025282983, 0.05331009363515243, 0.028132428227353002, 0.04065789109576614, 0.018646547518249963, 0.046551834506493424, 0.0588608717906379, 0.0748910241189503, 0.03400090496025739, 0.011174314553969571, 0.035149102219410484, 0.02848742571058533, 0.011253029130579484, 0.034153586283566496, 0.021292222588653528, 0.012755323719653874, 0.016198212866701426, 0.06719757847848438, 0.03936113406633658, 0.07568328926760344, 0.06450308637032587, 0.020178619944941134, 0.028657163981528535, 0.027789123161065004, 0.055925073477649884, 0.011771348898389168, 0.0329445195083897, 0.07040023968945588, 0.014246693894928022, 0.01760303234351018, 0.035276606063088106, 0.04842160232064705, 0.02484261302367574, 0.02492939163329861, 0.06905530339046832, 0.03141235515114761, 0.0457282325312976, 0.027412874398813136, 0.014490035020806378, 0.016469363941841068, 0.009336850752363042, 0.04282064540612121, 0.03399903570572215, 0.03793280143591185, 0.03320711529663494, 0.0486977118998766, 0.02553868242689679, 0.043272246576605305, 0.014430347195405875, 0.015578948565939022, 0.059507028650372266, 0.06865217260295345, 0.08603436286531149, 0.0137797144669739, 0.021461445665467652, 0.03041920451176984, 0.025259799609381347, 0.03910904134353323, 0.027993553723659248, 0.03881537302907917, 0.016882451957151774, 0.012523879939239594, 0.0467955002621297, 0.021036173021721265, 0.01146435927254178, 0.04609667868804067, 0.033844668988979636, 0.04753700442492001, 0.07830444377877059, 0.05103253338846469, 0.1122016893819936, 0.015202453697941478, 0.013870845413616589, 0.13705055559835128, 0.01776199558779838, 0.014681374098384574, 0.041994649406162, 0.10409215840721324, 0.08447650774952867, 0.029572968468851143, 0.037149671885755756, 0.04933580185376829, 0.03468860676812549, 0.012213026357424116, 0.019977613795368422, 0.017023915838029598, 0.04253393317001962, 0.08584103291674007, 0.02282713528632397, 0.08406369361065089, 0.04234745204749127, 0.05696435601660802, 0.009518877073611704, 0.05793620366603137, 0.029345616555562424, 0.0535227979473289, 0.04571421312228326, 0.033853172564939145, 0.02543431443853244, 0.08413914561031327, 0.03987143672401867, 0.03371502775999327, 0.02857677262997435, 0.05622962790150797, 0.005593470799090762, 0.02200947049254131, 0.04921891981916082, 0.03287798860260556, 0.04487262340262533, 0.015348234484272619, 0.07606714528294341, 0.11322943463681207, 0.05604321189645318, 0.015378253639585551, 0.018371824558163365, 0.0510022001371028, 0.035665391854220824, 0.04046870185242545, 0.07212775263694987, 0.017422524791571404, 0.021011629479847128, 0.04214718900320511, 0.008807248424648518, 0.03712535625503909, 0.010220648086209212, 0.05398502858776239, 0.02674295349166759, 0.03933650433957096, 0.08068926782617647, 0.040434610939794974, 0.025481614622197328, 0.009732166485440348, 0.049040605193905296, 0.054303636894591396, 0.04912192925750729, 0.05801825551316143, 0.04783546461934044, 0.03647345373587262, 0.05945239125961258, 0.12040444559627965, 0.01805919748280318, 0.05158556843056314, 0.04085309412931243, 0.031855284206328854, 0.06663061978836214, 0.03450159321448976, 0.02774619542422795, 0.04692534067397637, 0.034073679482624415, 0.07599463506091027, 0.0108528133076165, 0.03887550710069557, 0.03945503729365526, 0.03472354037747268, 0.027787108349824147, 0.07249918270615802, 0.018176454900493546, 0.03224577837353272, 0.028505555181313428, 0.048763867422577836, 0.015135878742101695, 0.018550164081276427, 0.05418810700517028, 0.04148175737129585, 0.03273997020216719, 0.050046030477049856, 0.03711889047295817, 0.06519202157975205, 0.07099856968007742, 0.021762836146198457, 0.03906168561849383, 0.03724662797345269, 0.05794829253347651, 0.05197613537611981, 0.06753141661324809, 0.046800288311656446, 0.015346919685872573, 0.021699821583986766, 0.12068340885302714, 0.03535030372140389, 0.023227253433076606, 0.0701375098358239, 0.043785176915867675, 0.017107677976450613, 0.04177583937322901, 0.013130025941908601, 0.0210317584400576, 0.06148743105211085, 0.04304242402976079, 0.03416035083993789, 0.05243938874393221, 0.052373727347942135, 0.08834388813063984, 0.051666149388878584, 0.0411469807788249, 0.06701015506780918, 0.058729077854584304, 0.0247863189677798, 0.07787443096599272, 0.038149305544192755, 0.029648468349008795, 0.04752350978613381, 0.029048627249956615, 0.11660927666291115, 0.042900663289812305, 0.08829792285518301, 0.033590270341524196, 0.0500778959042603, 0.052982020312018936, 0.04444992672952433, 0.029233170170036536, 0.029257935877408714, 0.024759703158070485, 0.022549909133944782, 0.06227737495435342, 0.048142819094561765, 0.06633090320974588, 0.10728173483643802, 0.015070895333924602, 0.0394465605307731, 0.010819875357312062, 0.04219172169424353, 0.035867949331840204, 0.03663142489629888, 0.0344319443308538, 0.03757698806904016, 0.0522113396906324, 0.06745795644218884, 0.03373278184763847, 0.04977976895808693, 0.037152253602060585, 0.015423055419007377, 0.040461538930333434, 0.03672525534526475, 0.03800191405800082, 0.10883248065628352, 0.03320439568450374, 0.03181459919189013, 0.052832039448642926, 0.03212920660453458, 0.01952231242021005, 0.034649421370798544, 0.017363124249142506, 0.031084002205921762, 0.04453899211160118, 0.09205664132511424, 0.04942086442644077, 0.03178641290193604, 0.02157915890547297, 0.026419629913664637, 0.04770241429909103, 0.024900332003110842, 0.037342500046736775, 0.027328907331872373, 0.014692778274747393, 0.029492048516629205, 0.029215224560410268, 0.05011322021844888, 0.011345173228502033, 0.03287775111534903, 0.034199448137153546, 0.03222625462278243, 0.03120145306081301, 0.09532052828299423, 0.037265443092873024, 0.07955977843413431, 0.06102752165808793, 0.052469361933969685, 0.019456267980257833, 0.044985215344856826, 0.19126676653902377, 0.10989252417798966, 0.14853847303217457, 0.17695736260183398, 0.1666125862468635, 0.1632473611783597, 0.14174117406289424, 0.16904459364952582, 0.12478161152572402, 0.13152007494241963, 0.16494027759519317, 0.08161790428623077, 0.11589024951981923, 0.12721106019471923, 0.10601071070038504, 0.18178825176531271, 0.19850258955792074, 0.1665207935917762, 0.10125829192299036, 0.13388244495276483, 0.09527872286496625, 0.10884931160797996, 0.1248792570925528, 0.14066229243913006, 0.2236351611152772, 0.11047072903884035, 0.1125034743980054, 0.14009213916236354, 0.18103466639595647, 0.39440424932587537, 0.1410565059632063, 0.11665944776107227, 0.10844152300588547, 0.14457350837126856, 0.1719083375627956, 0.1826475725899781, 0.1344990538012597, 0.07371772981939778, 0.1651325196989121, 0.1579141941282057, 0.2416558626798853, 0.15693484264756405, 0.21062090542287598, 0.1132789622211168, 0.20916748341293107, 0.1408683700907615, 0.09562587560785395, 0.1364424656475744, 0.07547809261708491, 0.10501558546938243, 0.17412288324727168, 0.22732552922060414, 0.20041744164641828, 0.16344308132125487, 0.11048798133889515, 0.1518272425258352, 0.06159869000135411, 0.2058905729603383, 0.23771286942064765, 0.10742712300270797, 0.15250519969530646, 0.11311542543192064, 0.14372822227737597, 0.16521156465093936, 0.12134943803351735, 0.17985858353635958, 0.14114480525735887, 0.08100318001402963, 0.14675540338841178, 0.09305301527943342, 0.06990863340756587, 0.11039448030773671, 0.1220086413706022, 0.12179894012308891, 0.10135033738709266, 0.0916304819345955, 0.15332770233433093, 0.1691902576074485, 0.14288416192416223, 0.20327392304616593, 0.175682331825937, 0.17824518704606643, 0.11857022426181263, 0.1692684138974836, 0.19304819675462861, 0.12020104159150394, 0.05987489258029288, 0.24606445353598366, 0.10382564407923531, 0.1746018720610488, 0.10771968432011143, 0.09750606221777779, 0.09637891705478392, 0.1920600659063747, 0.09443726721069506, 0.09211733847135499, 0.15700794275729887, 0.1890206120667919, 0.1138303769872554, 0.17531379756908264, 0.19064511683198715, 0.21985920566704967, 0.17624770471405599, 0.11452043834593027, 0.15241936720427007, 0.09432741020235325, 0.2067580909257935, 0.13042634653468288, 0.10568343793913242, 0.19005562749601182, 0.0869898813506288, 0.12460301344793652, 0.21833743329250047, 0.11654772149819521, 0.21901683070726935, 0.1646645931947616, 0.09646749980146847, 0.12182901673499616, 0.09766859543179313, 0.17863601446151736, 0.20800908186262657, 0.1274598242654916, 0.16006270303360878, 0.17037567141796314, 0.1400850451881847, 0.08826151069614195, 0.18454538688303965, 0.12024378929767879, 0.1282724137267759, 0.08083666314280803, 0.09482833211340251, 0.13890885507627843, 0.14976108807229227, 0.1581632646341478, 0.12308972932758833, 0.09352664147774059, 0.1293508663413025, 0.10720365515519535, 0.14414137349494044, 0.11176521844801404, 0.13939153643385058, 0.11350432230580239, 0.20317387196325487, 0.19062699119169868, 0.17049200953014437, 0.2637870856110127, 0.10537786078789543, 0.12528093997389078, 0.12471358291804792, 0.1638868147687566, 0.15981009320145653, 0.26361247885131067, 0.16956680514399083, 0.07011681780098908, 0.13212698511779308, 0.25161299854516983, 0.18928272138920524, 0.1351867556091278, 0.18048288390761424, 0.19162220069237296, 0.15071299828348622, 0.10915800673706878, 0.06633818104502655, 0.11716634515793094, 0.10936577744301289, 0.08038290160437746, 0.10368213282837983, 0.18647281813525385, 0.12996623412736003, 0.1832056982863334, 0.06771811224039524, 0.23716462625851556, 0.15517904573390562, 0.13891407979592202, 0.10336540909784456, 0.07908085856827037], [0.06356362125746186, 0.07919663743626687, 0.053212233563704844, 0.011192692045663154, 0.04026501439511776, 0.04668327221166223, 0.057205991639244946, 0.0428487416807442, 0.010297838147849807, 0.024687972430500294, 0.024464623326615944, 0.03386128160561766, 0.08401805009212225, 0.027144349090033965, 0.04301487550800366, 0.016182527216451786, 0.05480912085922976, 0.02071846486820329, 0.052058658367323304, 0.007873258446418351, 0.00972366386709074, 0.028782997753531225, 0.022023237092540632, 0.05432601049242001, 0.05928143107843015, 0.05141584548137842, 0.04034941047129612, 0.04604874839705806, 0.03916589272839408, 0.00633173632518118, 0.02443804007564341, 0.02524117601194209, 0.04418988584450657, 0.02627600374962053, 0.01974316407746125, 0.015762614315345643, 0.053180471558364174, 0.012794094471891802, 0.055625196020569534, 0.02190100584900187, 0.05657010418813556, 0.0402095572902791, 0.008105723517796686, 0.06716789257141852, 0.024267235027265646, 0.04174660162759885, 0.006998895006554743, 0.05812247028394092, 0.029359252920614618, 0.022377866853569305, 0.05917535854443427, 0.04105194757181791, 0.007362666111739894, 0.008598349654235908, 0.033646393942856984, 0.07956657363402267, 0.0730317134049631, 0.03279415560105155, 0.03381762225481291, 0.06474327025634628, 0.09289548461956364, 0.017257384963393692, 0.031228178038051536, 0.016736835879724354, 0.01953470197716548, 0.06929708840025049, 0.03541015051004868, 0.048206615066456224, 0.06654821937122653, 0.05737319032871916, 0.013902414939366283, 0.04923212717497542, 0.04895854951633562, 0.02275507897138596, 0.08179290175077417, 0.03085073992429722, 0.02752935423726036, 0.008770236801806717, 0.08335875482448647, 0.037141467084086714, 0.07224857236348814, 0.10641722759652524, 0.05438876841517706, 0.004813396503337689, 0.02734196147010211, 0.026668679352188786, 0.04972354576532399, 0.01973344625214175, 0.05209329320238002, 0.046128249171400265, 0.030701636231594512, 0.07690007437861736, 0.023015642711412043, 0.02650948245108368, 0.021600262712567084, 0.07474752052897408, 0.03319683439669109, 0.023441736984457222, 0.0278151988787877, 0.039485228818751154, 0.04589223280368794, 0.03963668057094178, 0.0334519072015199, 0.007783560562999018, 0.03768139819224035, 0.020042545492610624, 0.008761375079742603, 0.019071490744188912, 0.019400808960199356, 0.02358475219338171, 0.010325204723724916, 0.007104088454657505, 0.044927594041632074, 0.033522820130230925, 0.06385004238015221, 0.026244900579894745, 0.026227634873301275, 0.010667029325099242, 0.027376217091636314, 0.05073380123283114, 0.04709778323529228, 0.06732415152533401, 0.03171645183747094, 0.012413427297536646, 0.02674315458974771, 0.0713880641025401, 0.03087015833795792, 0.010774912699426134, 0.044171089877284346, 0.06322361228446807, 0.034934632074568546, 0.04452433684960969, 0.02383680278134923, 0.015161984145731456, 0.055670916147890596, 0.09171960094282705, 0.02389506376799076, 0.08419500108087256, 0.011852234376654511, 0.018251081440417517, 0.010016030789683423, 0.08093751095716031, 0.027883530091193896, 0.05475853607358952, 0.06541297665887302, 0.013896143552096141, 0.02235237144744925, 0.02884714995631047, 0.07404863383741149, 0.045295488615069664, 0.051786827389150865, 0.027404112268179178, 0.04332251726619659, 0.06437292803199061, 0.030877265718675433, 0.05675791830365216, 0.09940712472363826, 0.060558886522607464, 0.056700480861529234, 0.046924045985384334, 0.04572902926273885, 0.0434309225379219, 0.03776344620893079, 0.07907250054901646, 0.015860794228501618, 0.02494086763040433, 0.023322464755525994, 0.043022153343284325, 0.029327017855980707, 0.028219865672590754, 0.030519659706060926, 0.052548303464127165, 0.028256444455755335, 0.07083341644536104, 0.10990674276986431, 0.045604582109879103, 0.04731603402404055, 0.03245501613785182, 0.02769938362161479, 0.0559580075975147, 0.039425937443851464, 0.05491955243351479, 0.048428757581859834, 0.014290804279998187, 0.010719992813744373, 0.02568273376973887, 0.049598328694100344, 0.02132191807181845, 0.03474936520140018, 0.05152047010919741, 0.05263073835521937, 0.02377976945060636, 0.014579841592949967, 0.03419160339680891, 0.04081274427834057, 0.08135832305396758, 0.09019635767946321, 0.008051324571903435, 0.04861388272876221, 0.050032535838263656, 0.1049043648245354, 0.045912710333903956, 0.07490508183236085, 0.04328692865167414, 0.019984780547900066, 0.06157278090775494, 0.027821634017351656, 0.037174090938342196, 0.07013386325730432, 0.03951068592047499, 0.10531900225267296, 0.05769606957572603, 0.06344406940643826, 0.042869636728878946, 0.028441134847760684, 0.05734132107106909, 0.06824488195800973, 0.025462027669193286, 0.023763689265075712, 0.0799457488521453, 0.05250712240775747, 0.0460353686714605, 0.005753343293984091, 0.08815910772330339, 0.04039543703378689, 0.05550359871478812, 0.04397427039821783, 0.035242829246506575, 0.050027039157406944, 0.024748991333669233, 0.03599635715926847, 0.051502218064401424, 0.033570156703072215, 0.05284739568108513, 0.004621649005134861, 0.08156413257482552, 0.04620982221357765, 0.07617827399723953, 0.025906431443628766, 0.04401251733783753, 0.013899231844040898, 0.02536397799098444, 0.03302906497171329, 0.07468743625307277, 0.014214734621946851, 0.02689823951391924, 0.12736973998647544, 0.0334015445813777, 0.047913218713215286, 0.05229698449012734, 0.048440900075459675, 0.04446341370743129, 0.02872521748706218, 0.0196695085539813, 0.014121990102613646, 0.051322597259235, 0.06588247364326831, 0.08858946527564719, 0.09195926388905895, 0.010120845024263667, 0.04592521671926783, 0.028254931432104884, 0.015864825766203145, 0.049735343519357905, 0.040522676577130635, 0.044894602465172934, 0.04621205152943731, 0.023854752221415122, 0.061173660590523676, 0.01430354240695916, 0.05004329554316017, 0.011971203043245742, 0.031095158361319094, 0.02756256414877792, 0.0917920575387055, 0.017473105746772022, 0.01817192923608086, 0.10811427322727059, 0.0241140442554869, 0.01173274668549458, 0.04900467567025654, 0.09824578905658377, 0.024564073030506412, 0.04088122870833163, 0.028172942787228573, 0.03376788782676862, 0.042351282487112674, 0.02157845601980244, 0.09687156521625097, 0.04952980212927346, 0.025987048791120612, 0.03634581199636863, 0.03207210432587853, 0.06311147999499114, 0.047563162497094566, 0.053254946795923096, 0.0444369453696474, 0.080645585492734, 0.04200364327839306, 0.041389868955218026, 0.058593928453422366, 0.0340943293826234, 0.03341172205945177, 0.05979940993711353, 0.010564366839976322, 0.050069036097415996, 0.08219723529633015, 0.022038434361738544, 0.08053372133403056, 0.03033322071836841, 0.050419908197176073, 0.04862339754078177, 0.03304788392157324, 0.05924936646835939, 0.03486676051491692, 0.09284882220409571, 0.07846091723730488, 0.014561785858184581, 0.07299535487207674, 0.03941625792292818, 0.03880455969802795, 0.04593210384970711, 0.024224663521313382, 0.0023137959661037335, 0.04076649171991214, 0.011476431860618535, 0.11619184301384997, 0.04266513721837152, 0.06599013964014669, 0.05914729291332826, 0.01665023730076369, 0.012570380518633514, 0.03917050457769825, 0.07588816416119376, 0.02837466905945011, 0.08240798608429971, 0.04723886215698816, 0.020191758352842544, 0.018328452490330226, 0.04882293663197949, 0.039238012245585846, 0.013958940736859316, 0.028701690926907525, 0.03364337938687494, 0.10040654004701685, 0.03390572619654479, 0.06678463410465948, 0.04363462531698808, 0.014960378532357996, 0.03786582619913163, 0.06889553575385964, 0.02929862280706725, 0.2228713714547696, 0.16379640107193302, 0.16293145716190338, 0.16135042022553184, 0.1537214562056526, 0.1375915209252027, 0.16908567128402574, 0.14018117390092344, 0.13444879843342689, 0.20703922987224596, 0.1367198354414394, 0.08314117053223234, 0.1551573348021315, 0.1400883546880176, 0.1769126383888145, 0.19430029085807263, 0.09703361579487402, 0.11535539757460357, 0.11911723402238662, 0.21026138036001116, 0.17174329158038865, 0.0888627058556003, 0.13335591272240685, 0.11914305884631411, 0.18403529489953674, 0.11129765966606718, 0.17819148428257436, 0.17713457406047853, 0.21649918999643097, 0.23348657684701107, 0.19565864135661434, 0.11816684066528275, 0.14602028073803072, 0.15988313202415744, 0.14436061253711102, 0.13805399288333234, 0.14380883004876877, 0.10210302643357747, 0.19773293166391312, 0.24277407525768205, 0.14758006639538274, 0.166092473833311, 0.13800799696435853, 0.25681865792120656, 0.12321173649040923, 0.24095801786789972, 0.05291360866038069, 0.23843642414337207, 0.21527683542620754, 0.09510382499185302, 0.1287778172521822, 0.160939781776359, 0.19077565821428455, 0.08618100741577726, 0.17799420132031366, 0.15284017930107732, 0.1033442420884967, 0.13600064741988338, 0.10522086638957263, 0.20437512847204364, 0.1374839775023922, 0.22160164200730864, 0.12076969333593884, 0.07928891272674646, 0.1409164038036139, 0.2035642856912267, 0.11878643725668231, 0.17143419042469996, 0.15971371934058207, 0.2307901618581626, 0.25867133431376954, 0.21286601801553082, 0.145459964030212, 0.1323090382521191, 0.12148903457507973, 0.17338826621492065, 0.1034158330050207, 0.07129054877065844, 0.13835589281253277, 0.1685711206688035, 0.2718469434447827, 0.21608271395727513, 0.18655215420069235, 0.08928411550098851, 0.2620282396674156, 0.10824088457851641, 0.07020589850482441, 0.11352915887630756, 0.17026107998624926, 0.08068189806034488, 0.12081278578167963, 0.22767774580467134, 0.13542019792141455, 0.0785203043731951, 0.20651962307672347, 0.22726741379066823, 0.13212316999993018, 0.12350475746056727, 0.16495346962924928, 0.118470816692758, 0.0893686073381574, 0.16344939388575094, 0.14343052051000058, 0.1274078375389499, 0.17739977837810594, 0.16447846447267842, 0.2038294134000617, 0.08774356631141517, 0.14576603147772052, 0.11660340076853191, 0.09271006069837079, 0.06282143527641892, 0.19238750720697065, 0.08646449825215725, 0.12217865160275852, 0.09841881001428252, 0.16313977179027375, 0.1925714602393489, 0.09146611010956188, 0.17924555997935035, 0.10587970200445383, 0.2563442809567336, 0.12267709904981237, 0.2072613953702873, 0.12393253329660624, 0.12657895338751618, 0.09359990246593954, 0.12666237270159106, 0.15437301398525316, 0.17405574330158774, 0.26914528841453217, 0.1455589579117875, 0.15130211989725792, 0.08059174483341557, 0.12416489542491975, 0.2120389801359946, 0.3168298490345478, 0.2091489134416465, 0.08368536108924497, 0.16204173796840254, 0.2144822796746608, 0.10219818221465235, 0.08675556569810837, 0.1470193206783264, 0.15456183933682982, 0.18890242002183394, 0.14779614915530528, 0.13181011583055222, 0.16728447599997445, 0.1292622606119802, 0.23713822686864486, 0.13682644423698226, 0.20030231395315742, 0.20388631841107724, 0.11587770099961951, 0.09209516022594706, 0.20693979165967435, 0.21877149871039778, 0.13998897776247995, 0.16297389843290852, 0.16726353115612463, 0.08634020814732199, 0.09891439995337879, 0.22933673984821767, 0.15653181911235856, 0.06334172389019402, 0.11247979462026589, 0.115807703545978, 0.153757784095022, 0.10128214790095245, 0.204419469641101, 0.1960115320980549, 0.09268401370894525, 0.12103983125979863, 0.275736004114151, 0.11495382960645423], [0.0345403840765357, 0.029736419073155815, 0.04535779071551177, 0.06551324990728209, 0.023518190644080603, 0.027948122794529604, 0.0222331126250567, 0.023489159742189993, 0.010573072471625863, 0.04076767149531553, 0.06776639876226265, 0.0344618677251762, 0.048486428680799665, 0.041106516014664404, 0.015750048558167633, 0.04975688591178867, 0.059759772547911254, 0.03235220330797377, 0.08962582135873456, 0.021653007866153796, 0.017429086334642865, 0.016817752001506668, 0.03194394356180583, 0.03483853017490718, 0.07836498770742648, 0.05044878971192145, 0.03528345488913117, 0.036965623092387, 0.017070750623280485, 0.04040600138626272, 0.04125556608121242, 0.03191647739450057, 0.03733431822770546, 0.03518549905669305, 0.02382661955761573, 0.055555949333093824, 0.03814781167274041, 0.01753613754596201, 0.05989690228635746, 0.058240279284936775, 0.028178521822537148, 0.07626642007380724, 0.03218104777437064, 0.038551689395981456, 0.07342090139225607, 0.045081635171006766, 0.014541182881070962, 0.02600381462534349, 0.04817928487975751, 0.06844693764803872, 0.10400436473109069, 0.00468429297231318, 0.062254794512785254, 0.0031385702952261897, 0.011345015222867651, 0.06868615626327454, 0.0383857011254276, 0.028848038618302638, 0.022600306228043574, 0.06863609241742281, 0.02799721179349769, 0.012517227423227122, 0.02278804756520737, 0.050769370695155476, 0.028448765083486517, 0.03826381270623496, 0.06891678703287918, 0.03073660048445867, 0.02418934303756443, 0.0679148666019882, 0.055277066515578385, 0.019702542265276277, 0.009793094415668278, 0.055157890047637693, 0.06911217775796691, 0.010064100891712212, 0.014584122109226884, 0.022162621044704033, 0.032964472268377586, 0.01499981769630986, 0.0678823461696025, 0.05200562210032537, 0.026564493309706453, 0.03762947658317224, 0.0394919129358905, 0.062197969941001754, 0.02373978923705797, 0.056127960373076706, 0.021569563654221354, 0.028621688364974918, 0.018086033542790723, 0.08001026877712819, 0.06411515859766834, 0.026020727931491794, 0.04171664758975949, 0.04742839613989477, 0.04041563494191055, 0.03853405788240414, 0.03434167236029621, 0.059828647682743694, 0.015073642716743054, 0.015513682662839852, 0.026679117300157106, 0.059839522300828854, 0.026154720539888068, 0.01418668910064885, 0.04181808146137384, 0.007352068242917379, 0.04268970565810319, 0.03667924793497209, 0.04012295488087882, 0.030695245143086202, 0.03488923370417568, 0.02463641471319622, 0.04308259385007043, 0.0131473146311398, 0.04999759456803722, 0.028363570360647097, 0.08178084352684599, 0.04193273801056128, 0.02862871530646038, 0.03097015579471425, 0.048454176379187454, 0.07320069707930088, 0.06505817069762176, 0.006285784935067979, 0.04738021687033677, 0.06321102929031176, 0.06094969095542066, 0.016053733472231657, 0.03201485074485742, 0.022577020985585068, 0.01297799196289552, 0.07561559007773477, 0.013290604674107125, 0.09310472621432236, 0.02697272241235741, 0.03981436317365977, 0.027083389558679154, 0.0341572022185691, 0.04578202339490095, 0.03723175437640279, 0.03399875608362979, 0.061128327337604385, 0.060449546623614535, 0.050435996043585965, 0.01641014534529419, 0.08312028697541646, 0.05258373886106476, 0.04654172980677217, 0.05073712222398289, 0.025416805499023008, 0.048493576281133204, 0.01793962264914186, 0.025654110809667938, 0.0646223432774986, 0.020863854949693048, 0.014535448712957724, 0.10700386708542224, 0.06339443073938451, 0.05517271767941214, 0.05080411661296122, 0.017881298460246577, 0.04690107866941441, 0.04409721218830636, 0.03560184869134138, 0.056525628953691454, 0.024271674506786852, 0.009370242609762618, 0.03145932208656544, 0.04854340647016803, 0.078757569464224, 0.04574821210436283, 0.12646945644049876, 0.050609633702063755, 0.030829804656546445, 0.053167283354747685, 0.051307482344488946, 0.01262353840208943, 0.07265883542957806, 0.022631451532605196, 0.01090429824656777, 0.03707874363528625, 0.06892071706393073, 0.04070939901735514, 0.01148028432526776, 0.05008244263609091, 0.09338259396533813, 0.020293259257150274, 0.03642105332185184, 0.004390676847598966, 0.049689393565659566, 0.022360541775161703, 0.012284145172264789, 0.03695730337752931, 0.037336731404666944, 0.011181631651256355, 0.018791564131876635, 0.06606986641042656, 0.06938252252556625, 0.05769653688935984, 0.032794094314017606, 0.06318375656020737, 0.03042051452212036, 0.07464552358273538, 0.04442238586864645, 0.014041128564595938, 0.09390256082218501, 0.021084361867378318, 0.025270990238735275, 0.05723767703579319, 0.05391230003067082, 0.12027146805438305, 0.014612785288913837, 0.045732740958731984, 0.0867018246302201, 0.031871149887240706, 0.06739326797786259, 0.0798653555853713, 0.04199241242942311, 0.09551784954965116, 0.025066921652685252, 0.059605356035453666, 0.016332837497635234, 0.029039430364425627, 0.01265332868863498, 0.06321984313188062, 0.012348271519576591, 0.031710468690782305, 0.02989368543269173, 0.0322894262330186, 0.028723240980217536, 0.018451455567452698, 0.03610678107267426, 0.0383306845211454, 0.004829958366650728, 0.023938592883848378, 0.046167825273568594, 0.023311791235520955, 0.07116437408952944, 0.016023805289859736, 0.06096047747339453, 0.09218489210451804, 0.04221037210476014, 0.031137718375952497, 0.08204899728298187, 0.0321330753485522, 0.03207850307526608, 0.005033668327791196, 0.033427878853774844, 0.07034818401500102, 0.007682853517302824, 0.07934503632807925, 0.03744238259030446, 0.07821940035829622, 0.05023720771855405, 0.04949577633411654, 0.039251889928334185, 0.02052151132375002, 0.022624399693262194, 0.04961484171930821, 0.038294203414191166, 0.050448973573023276, 0.04226661828016082, 0.05242904655695443, 0.06834199126329153, 0.046755426202810584, 0.05282858439210442, 0.03891725123168961, 0.01713642925624886, 0.05841360667780523, 0.03496131108653161, 0.04200578449414142, 0.026375780956098632, 0.05140199461170743, 0.026631100824283018, 0.014045556552798278, 0.05998324422586349, 0.03854080328657743, 0.027396807619821162, 0.04253504016707021, 0.031069122863212423, 0.026317077553680828, 0.04912341163764077, 0.01818146128507872, 0.008526143952152662, 0.06792445802280019, 0.050912269075671514, 0.03599069193906842, 0.02706176289657672, 0.019768410505005912, 0.03503479807066821, 0.03205093157087122, 0.050735601539453196, 0.020671880976747603, 0.04968133432069614, 0.030428907015330853, 0.12379621561135977, 0.026371831772848967, 0.05876711028958521, 0.011416012421250345, 0.02217113228154279, 0.024513405890414314, 0.07468185147210475, 0.049521796510464726, 0.041694385074679895, 0.04368455892789268, 0.0735622063098896, 0.014837311295371865, 0.026365779678247152, 0.07274629968789316, 0.05252879886557499, 0.024924624651189775, 0.03888250914432349, 0.05046717582210418, 0.006741923261283627, 0.03961883838318529, 0.05347206377454343, 0.02465417454650085, 0.027095200719251752, 0.024444682057946924, 0.09431836270396748, 0.015641548483061696, 0.06698618417665844, 0.03981815147844534, 0.03839970521268345, 0.03356462937869853, 0.06604800992194684, 0.02738521479430699, 0.03931786542037322, 0.04847110309187443, 0.05605184570735982, 0.012731943673814737, 0.029730501043940746, 0.04624413529170617, 0.02223065539803957, 0.021748324525692773, 0.014469807426775656, 0.06780330887845448, 0.10733419653749275, 0.019734746686393217, 0.05438038358284582, 0.045341388773052924, 0.0613335048359248, 0.022170697526645758, 0.0699171599661631, 0.03292773069152909, 0.009527256160283522, 0.024915224752358855, 0.046085191199616085, 0.05927928603224217, 0.02225480631985251, 0.12665370824716746, 0.1832311630489365, 0.23509929917993086, 0.2054636168383783, 0.15712213582329213, 0.14328887085280112, 0.20795216152985252, 0.13061633633990444, 0.13356032030236337, 0.20196251841562413, 0.16658424099366512, 0.2302523681353177, 0.09984705837503557, 0.11736637837583981, 0.16146432217811385, 0.10318430591254465, 0.2323632468018801, 0.11300864043615519, 0.1338142171622284, 0.14365412625333956, 0.10876044540876344, 0.08148393849091184, 0.09859021452646102, 0.1445647443254148, 0.16475460852586454, 0.09770975733596472, 0.12529716571612706, 0.1144439674493286, 0.13831034122455504, 0.0849780501917966, 0.16987918515599545, 0.17278969107616335, 0.13212258777310773, 0.10009486483590257, 0.16175837736696969, 0.09461559715770906, 0.21661344434945815, 0.1204735926923252, 0.17252145305035577, 0.21883701454968224, 0.09097469534965293, 0.14603046970742364, 0.21122064501527818, 0.1277777890584642, 0.22508614696562293, 0.06835524458438158, 0.1698267234549407, 0.13645400293171406, 0.19162123542158835, 0.10782661487258251, 0.15363675752474418, 0.1273342394720643, 0.21073281554685486, 0.09299313784727166, 0.20785667633097019, 0.08278136967771477, 0.12129113108160035, 0.18787508079361534, 0.1334944980279092, 0.16240386773020993, 0.12937303692583116, 0.0908506274103157, 0.16512671275244606, 0.14083319133327854, 0.12768646371701073, 0.1442931355127404, 0.13806643415122263, 0.08710168422229829, 0.2262361521922773, 0.21314781579759814, 0.14881405018029675, 0.11324754495534206, 0.11502155177896062, 0.13586157181810948, 0.17416532451827682, 0.1755479600040182, 0.14089855395497816, 0.09383384273537705, 0.13581847171148947, 0.10259134619827233, 0.23213147456126831, 0.10239891257257232, 0.09038053287733948, 0.09211040537564025, 0.1781062646618774, 0.12403893524840956, 0.16359269829286685, 0.10494358086537932, 0.08795858420912298, 0.23266932957114714, 0.16063846407398102, 0.17010642215609553, 0.11585713153885258, 0.11824013229699866, 0.14611501517074724, 0.14132722611388854, 0.09706632774924079, 0.1344641201919125, 0.1298061217511854, 0.11740595447800814, 0.145117093718821, 0.1776793238616759, 0.10658086397715154, 0.23115196986304176, 0.15736621143596788, 0.13776565271039165, 0.1423787737205144, 0.06829087787698354, 0.09050033370693845, 0.17646858318438455, 0.1630794500271159, 0.24779173665710036, 0.132255902393691, 0.10146106773566815, 0.08225034817212051, 0.17717929827349801, 0.13486769531042347, 0.10258091974162287, 0.12229414701822305, 0.10183510250381886, 0.08604958503236694, 0.15832173758216445, 0.30682955177560933, 0.15721613481160135, 0.19655373848734364, 0.16404459823764142, 0.12546654775618546, 0.2144447873316465, 0.16441679439477383, 0.11507511664662631, 0.06960719313111997, 0.22146111083847864, 0.1505612056221693, 0.16099330067874926, 0.20339942356992155, 0.11838474671446508, 0.09244404432754363, 0.1550937801479332, 0.1713577961368907, 0.13340353274778013, 0.12076125870789252, 0.1384343248942206, 0.12617750799343472, 0.09742967559084778, 0.10132131797652091, 0.19712088869944697, 0.12543889198211894, 0.22336373616370464, 0.15332702817695756, 0.13818122476579683, 0.10918113493150282, 0.12214697386708953, 0.1088705628869995, 0.16286100771638656, 0.1087953024093182, 0.17828415027789532, 0.17704472726871892, 0.16387618146836758, 0.1349028893896649, 0.09848999490420665, 0.13756334421134767, 0.21953306671592498, 0.14584336039279738, 0.13667566281172538, 0.15416947974553033, 0.17890794503111995, 0.14458833983348263, 0.1432765521589787, 0.2110442149663164, 0.1724801149459616, 0.11815990756956801, 0.18179994226703722, 0.11497261408235758, 0.2754499468832247, 0.18701251175615097, 0.11576539250991999], [0.016395122361099048, 0.028222345882245613, 0.02468146068314391, 0.039130104931011316, 0.0648009413552861, 0.023354954544394728, 0.025133510015063712, 0.01896859555985899, 0.014256503650798433, 0.07030801036425176, 0.026950791230305072, 0.040659702893707066, 0.06858198362733088, 0.08183173474765594, 0.030775931438491232, 0.07480109305751902, 0.04259478353384522, 0.042011043687741605, 0.026782991161810297, 0.1266891168310277, 0.01834974398896579, 0.042595503656494046, 0.019262669900912913, 0.06583273921522402, 0.015870916165201174, 0.018470523495888038, 0.008010768834801932, 0.05842939191948503, 0.06580688374777956, 0.028434690133097674, 0.015397637579289657, 0.034744343495056514, 0.03242614994486494, 0.05123599101939509, 0.03174838621259457, 0.05846860796032895, 0.16985802580752682, 0.04507700416950449, 0.03473979293278629, 0.014880083899404255, 0.05443228603971582, 0.0333446663834395, 0.06693694770576493, 0.06957148577296926, 0.019192256844572483, 0.046186582936394605, 0.05789795289597204, 0.04614281633328046, 0.053027303769223155, 0.03405416339275337, 0.039040943787943934, 0.054942856828171405, 0.00788669036175575, 0.020733089486677802, 0.052591725327675386, 0.08325475072788616, 0.03092830824185043, 0.005596696508056935, 0.019948709297985322, 0.03095587591580566, 0.04778460787248708, 0.01417571489113353, 0.0218351491005911, 0.009409652087807415, 0.05018850367876792, 0.03141611472763602, 0.09719845493354144, 0.06709155190976397, 0.02400251142981072, 0.036680990784999826, 0.06613660032951063, 0.005526959524309684, 0.06725890381682305, 0.03967919462029973, 0.08710403611222584, 0.031931601885345676, 0.025037134238969416, 0.058673923354475736, 0.041529787253708615, 0.05253880397386609, 0.0464763212197971, 0.03719060779398969, 0.07083655740585058, 0.06966662623228566, 0.04838158954836188, 0.0728895198253374, 0.035109771265377926, 0.07631130516529083, 0.02836172600396939, 0.06812473638884484, 0.07215058205709343, 0.08584237357060756, 0.05021402589796532, 0.0526781362150946, 0.0029102148067566658, 0.05538374042859482, 0.04109895472685176, 0.01750660677170081, 0.07269599835478491, 0.006182610607450648, 0.044857596587990566, 0.01973831091046093, 0.061780440530950026, 0.034130205280117454, 0.02685701823793352, 0.0365681268815552, 0.02506965467135512, 0.049313171616485046, 0.040005096084167885, 0.03729393007233739, 0.004189968514706819, 0.07052175655600525, 0.07914935448958028, 0.023116787384834983, 0.009069230384944428, 0.030997817314440207, 0.03176796741993918, 0.06975604401480767, 0.0842755628869899, 0.03266427305436904, 0.06076519017017657, 0.07044435103213595, 0.03884815393135913, 0.12611841197095572, 0.018977158507632635, 0.044672850654610706, 0.011890105933191316, 0.016369349248106443, 0.04259460350318302, 0.09642339611966765, 0.022994571463054708, 0.06268298786674296, 0.009525198256596923, 0.002794578622636055, 0.014486810748255061, 0.02111168630841759, 0.07566169324901796, 0.006365105678747979, 0.0965573848976243, 0.10052964271556947, 0.07005750727389129, 0.01653746149743036, 0.054007551572736234, 0.03409741288651863, 0.0235218774422162, 0.04008664614370754, 0.10099232917831791, 0.05841706173434373, 0.035806823176361864, 0.014912792023331409, 0.024777418941319473, 0.0330055307506794, 0.058860174650626804, 0.03678287664848951, 0.022315725631591295, 0.027486650581141154, 0.06883151378602752, 0.029989781586693662, 0.06984032900823701, 0.02761545102863062, 0.021959479425042387, 0.0556403837136684, 0.029768238535090804, 0.02107300461390086, 0.03309990895251113, 0.08896995816499957, 0.05509166557702327, 0.03333755325706255, 0.007995663496154931, 0.003314594078185638, 0.029639840283761584, 0.03458940221237079, 0.04501616146655814, 0.04972074571396074, 0.012090750106219805, 0.05880502781139747, 0.06885480285892565, 0.04805677209890658, 0.014348265662368749, 0.03721726382331502, 0.04758378941445582, 0.02677706547171599, 0.024119736288764307, 0.04078490464317222, 0.024407678095984365, 0.023074263759377985, 0.016674056889549378, 0.024220831166472168, 0.031947030896140684, 0.04119567332729217, 0.01604353779956939, 0.0844656676054001, 0.04326171286764645, 0.01521457225129369, 0.026726482601295558, 0.1094342350599266, 0.02424408001975427, 0.024192878533334985, 0.027099820229435162, 0.0718439247218832, 0.02498841296220499, 0.04783981216831073, 0.07290543913240395, 0.025672726746227954, 0.03522808205396418, 0.018586618375153314, 0.007305559523839264, 0.09043205229024734, 0.036745035735469674, 0.03831530913650509, 0.07392768387592609, 0.045205166848796996, 0.10372506439565651, 0.05137469123808607, 0.051753161655318354, 0.040183981444927, 0.06419598087367993, 0.043329178400698214, 0.025304646396468726, 0.10709977363266292, 0.02736254816784734, 0.01955653356778766, 0.0388139289533419, 0.06254849730119591, 0.03276705524073013, 0.07761047537168188, 0.03196863266038558, 0.0510174299650375, 0.030326873679915746, 0.06309197156599934, 0.012105988552643648, 0.07274747946329656, 0.029915518938533725, 0.09571891698625781, 0.023995262322827213, 0.04637351222035866, 0.01786519720729801, 0.07235294418229211, 0.034882239321427005, 0.01308345354177178, 0.020188644205430345, 0.04555429226808971, 0.07891719154412709, 0.024928947302302527, 0.02623371569620025, 0.012588774289695487, 0.011157852282086688, 0.05743188798547753, 0.021912516320064183, 0.04456794640469936, 0.0428981735040584, 0.05926137106613286, 0.03396279208602444, 0.015172576268894539, 0.03031352268261535, 0.029999459192397136, 0.020042248633539966, 0.09543965495521985, 0.022502748761326078, 0.024063689296223947, 0.016861796311493364, 0.05891293129553238, 0.05605526245950211, 0.05528170900839952, 0.061850817198114055, 0.02003322028735232, 0.07634256155260148, 0.05445950897410513, 0.045282350207168254, 0.01102728121388223, 0.017403378339123823, 0.12412054659498316, 0.0609565895771788, 0.05823009031554384, 0.039791403518569086, 0.033521222836908796, 0.06645693233416927, 0.05216674571256003, 0.0418870140528006, 0.03062843653042951, 0.0006548292144396973, 0.04284449755364368, 0.02916319378381295, 0.030421814956371824, 0.042880178098717046, 0.030415418122204083, 0.025597613740472064, 0.037526816970879034, 0.03516207591840818, 0.006777517621465509, 0.09983561302144682, 0.05786947740782654, 0.010641860463956912, 0.04053949603750821, 0.056599265324973294, 0.019835937325091615, 0.02056018152694789, 0.05067760868358517, 0.09651995384164395, 0.061122930248177824, 0.021591111792311556, 0.020852340648191112, 0.07858857046812773, 0.032598818502118515, 0.08449906137801948, 0.02791232925148741, 0.03398713836025807, 0.03342976726050819, 0.03314197867087299, 0.026890358384398204, 0.004685964001598018, 0.03212069919813545, 0.04658110289564056, 0.0573280064629451, 0.04944491575682356, 0.04345492790302923, 0.015002185865605791, 0.019066336887678313, 0.046240009908233924, 0.015674984390516917, 0.046606602132200234, 0.0790973294586424, 0.029958946547741373, 0.024918610860984174, 0.032703209473120595, 0.0010652978075555556, 0.009809520298374758, 0.018434398619818593, 0.05919044664610298, 0.07232507390360679, 0.011007140762352896, 0.03748991451556644, 0.060000128803714636, 0.02320177717915466, 0.05214447170616158, 0.06726975928271009, 0.07156453245589811, 0.018159600966159376, 0.07118579390789233, 0.062238492161756566, 0.02711964850013535, 0.08711990179313768, 0.0804400364417703, 0.047736076202483914, 0.05425049720572368, 0.022642939021029783, 0.09225443756628422, 0.01448283187909833, 0.050295434231238986, 0.043229104335149454, 0.056970097845600504, 0.02654023896602373, 0.15728940346067952, 0.09263725936292641, 0.113619189529169, 0.1476629417870314, 0.24296317640091145, 0.11051173006454784, 0.11122004729845833, 0.15397547563958555, 0.06611309675199371, 0.12376209405521232, 0.13084087671051103, 0.1224653983128167, 0.1426702088886692, 0.19697740043122924, 0.11719857447690542, 0.20714698779967525, 0.20455362695840099, 0.10209034767843063, 0.12837251077496237, 0.284621061216439, 0.11587561724046547, 0.13019370095383737, 0.11926598531464416, 0.18751995307543587, 0.11927479532577338, 0.12624908358820025, 0.14203322210138844, 0.11561981282166897, 0.1225350893312885, 0.13027559575294295, 0.06807578337048331, 0.16012596657439587, 0.1466814912254772, 0.22263134078633404, 0.16604371999780979, 0.10074730361661605, 0.2056836985772656, 0.1947044941686815, 0.09733252798116977, 0.12501494658570136, 0.33220771579973163, 0.10784092539500807, 0.1118272256046053, 0.22504839415271438, 0.09010322437050844, 0.06703730522384567, 0.16708206024862107, 0.12593595281002984, 0.09676056673690196, 0.1718269024164446, 0.11479841334925545, 0.1589288775839152, 0.09157579091768112, 0.16986861314264037, 0.1354017352024394, 0.15306786063217348, 0.10144261267757225, 0.17420255639139684, 0.1160768608772947, 0.14068869182900076, 0.19240103631971345, 0.15120655808958317, 0.08373586926609279, 0.08883812975498939, 0.09098346705638594, 0.1775682717561722, 0.21340603339335612, 0.2262903605737994, 0.12510843995598056, 0.1426031149082607, 0.1035114944041256, 0.09752669296557866, 0.1309707132919181, 0.16351685558836307, 0.20691798879734932, 0.15340719161735428, 0.27871749574138277, 0.14036623009991261, 0.0871259538877395, 0.2190227142625278, 0.0823874932323252, 0.14301073497101185, 0.13488162278888688, 0.16786748423211037, 0.14531586289165482, 0.17476854214985527, 0.11192824961918016, 0.08797470269904983, 0.14578971891633927, 0.14286775232082413, 0.1454667822127381, 0.22045782677108244, 0.14160084207692455, 0.18438479953235198, 0.20840444451858922, 0.23645745049561226, 0.2200633834206289, 0.1317361270588252, 0.14191227213990304, 0.08311676297096476, 0.16399665645533995, 0.12591339152065978, 0.10710050907707024, 0.21297881680150188, 0.17050415968462346, 0.11493031070717882, 0.19967196148730096, 0.13563959018116997, 0.11381661804813532, 0.15056112901337687, 0.15492553191800273, 0.20834151805648882, 0.11423693218779181, 0.1572906904883923, 0.18857214419591814, 0.14013163865573947, 0.0503354010382487, 0.1595284179934571, 0.16739019613352515, 0.08526762376629538, 0.13604923271604125, 0.1951566699051088, 0.23520696517680925, 0.27867842525724446, 0.0889000756245467, 0.10719993962876259, 0.17461094254207227, 0.10603779190850836, 0.21289941944902946, 0.16729895506174336, 0.12278488762075863, 0.15479318256820404, 0.13670221541918096, 0.10352555977841539, 0.12222401166875517, 0.10897330293852477, 0.16767789279260945, 0.13158244982121453, 0.2021770689996981, 0.1685426988068127, 0.19849880508357481, 0.11860773192658541, 0.1295077917917121, 0.1077467578673555, 0.1635214980811842, 0.12600559020234695, 0.16371567072647233, 0.11227112759145037, 0.1561259150865578, 0.14456262992274377, 0.12442125908790097, 0.0987245480439836, 0.13768876812631084, 0.2021126563270246, 0.09306856686429632, 0.14045155697291897, 0.19096730276942256, 0.13003925762830243, 0.12321956590899538, 0.18580016229421864, 0.13691273638077323, 0.20965676844841052, 0.16595430221528779, 0.13076238334178925, 0.15702268228896205, 0.12526593231145414, 0.12386668803951434, 0.1166604896406493, 0.20066312604373504, 0.12880098375101245, 0.18342784846261626, 0.31426731557134663, 0.10376146889381832, 0.175397546300965, 0.15218417821151597, 0.14366459101438522], [0.07580777089441977, 0.04983872708473956, 0.017863940823102192, 0.013645926787097369, 0.055036717920654246, 0.08185473270714283, 0.04043140486183186, 0.02664123616752125, 0.04459410447687392, 0.047220119815920635, 0.1004086774323256, 0.09684982364095988, 0.03460298495126828, 0.09258709592564453, 0.07996710738347423, 0.06941291323352246, 0.06345626169575319, 0.02001827391194961, 0.06816849533107973, 0.07494903229657682, 0.04123659391376761, 0.02680465804352876, 0.026309416674438025, 0.03509939460444354, 0.0769943108541831, 0.0398226905493967, 0.02435194136905334, 0.02469877618545246, 0.05840296188609735, 0.03939806333472652, 0.03447578754276037, 0.03337615259712742, 0.08072262329439964, 0.060465871957280946, 0.025087025715038184, 0.032137051344879215, 0.01915258498141362, 0.058171955733409816, 0.010860282664878235, 0.02158014141323586, 0.07045208085929194, 0.02168383141378722, 0.037008190767899636, 0.02634745868553798, 0.029114765535679557, 0.03519011856687646, 0.018477420202426372, 0.03665658705417187, 0.013417112603483182, 0.012901997956026708, 0.03742165608151305, 0.05400978088859589, 0.05196407715219164, 0.012818907102149342, 0.04747694696209604, 0.01140339782596716, 0.03574255222995435, 0.011610525018054874, 0.05383084190168208, 0.030383575677631364, 0.06404668182855652, 0.012854131824907758, 0.07121436132658875, 0.060200748078885584, 0.09069301248077424, 0.012220557959329699, 0.027262862891920155, 0.06010334766019256, 0.11428938622796729, 0.05959373065120271, 0.036167815297601685, 0.01782151104341592, 0.05749754938146761, 0.03463955798877343, 0.03394333345274772, 0.005060513485072842, 0.0412469552529435, 0.10305986259012453, 0.09594037002252956, 0.19302665436219787, 0.595511767652727, 0.732921403982947, 0.5629443893990209, 0.39591157328217264, 0.21403995582893973, 0.30017984730582087, 0.19147881967646463, 0.12540414223387358, 0.07759198200918975, 0.053871800792553735, 0.016223248620066914, 0.04392643969866537, 0.06728852077597572, 0.10216911683880514, 0.04627832579576681, 0.10522471981183176, 0.08526865032411392, 0.10899046330802864, 0.040759708011342634, 0.05545194140605389, 0.05148234191320596, 0.050221736572923205, 0.017117928232877486, 0.04687291344687824, 0.026003107909233342, 0.011667193499423805, 0.0740552221935603, 0.08314900761169773, 0.017286553761110674, 0.04297582800650308, 0.05517928688336284, 0.006554426114645697, 0.09519390927086915, 0.0761829394726984, 0.012206243606464518, 0.02272639855472071, 0.03987512543737408, 0.036648585265802766, 0.0351725866447293, 0.030198856557328856, 0.026043511386359894, 0.02799613352474426, 0.03829139187150905, 0.03306236298334214, 0.018354520547173677, 0.010243383660582046, 0.03517605702302629, 0.026903351235594, 0.02838810241120237, 0.031168587888861378, 0.06059872309467005, 0.0458423106841022, 0.036366818127252405, 0.04452953092573632, 0.03819093859243778, 0.026905540331837632, 0.08185847121621333, 0.05044664083529384, 0.04080267788301553, 0.01989815324064224, 0.015872938637321275, 0.026719599301295898, 0.08740328537720828, 0.07739751825049039, 0.013437658124002478, 0.06064395675615919, 0.10408615993876612, 0.03813414083373162, 0.02355516779296581, 0.06787769601590211, 0.0951830538049821, 0.0425579653482043, 0.03191973326817876, 0.04328252364610953, 0.025229426138403437, 0.0417373587767924, 0.030193528415815487, 0.050562680173184604, 0.044797688512311834, 0.04497910962410031, 0.005042301659892884, 0.0765836034570971, 0.12542776838545838, 0.03927409881725907, 0.023733641381465623, 0.03564794037130571, 0.04720307052916577, 0.015665852622459495, 0.03754408459269232, 0.0662404358867676, 0.05403970811335791, 0.050714235347245014, 0.03763753582813567, 0.03426326709168573, 0.050542650804404295, 0.046497346502878976, 0.015541909172409966, 0.034194947370598396, 0.03210867927860349, 0.06715916682996097, 0.1178364116217821, 0.07081123819995312, 0.03746333126459391, 0.0452801400435067, 0.0043532606345721555, 0.0577145705990974, 0.059313993645651694, 0.07343054643922275, 0.017802224779922157, 0.06354055435006177, 0.037222201259987014, 0.04538412881834854, 0.03461590119367165, 0.034045127385686484, 0.08152094053765459, 0.0600058323283109, 0.034197923622184226, 0.04710084758698941, 0.02179144569973071, 0.009183341096485815, 0.011391963963697275, 0.015100076580570351, 0.0425038795407501, 0.012241956710274662, 0.012326850743603804, 0.022950504170430285, 0.025905422122788527, 0.051056810714785135, 0.07078298487730565, 0.01669647453743364, 0.022504978077185732, 0.05815826957264255, 0.046845977795460535, 0.027817286468381365, 0.020561357471911658, 0.07682671379898826, 0.050084648969312834, 0.05210527864795539, 0.0371476570745149, 0.029570223958862406, 0.05488222862984385, 0.02041424560781208, 0.07087746650100717, 0.023277583494482022, 0.10606598394412188, 0.0542216501649349, 0.039002241026009285, 0.09082136285160819, 0.05782409435919216, 0.014386859256774189, 0.01765771761476513, 0.00999437444167392, 0.01894953529230289, 0.07318744375821083, 0.0306810342120908, 0.025692338597089536, 0.0452253379438433, 0.013768669394325587, 0.021122208526057583, 0.024407572758894776, 0.09114202427407427, 0.01400245644617826, 0.027320396095033617, 0.01695932888035332, 0.060433309390059406, 0.06153868616468484, 0.05696614483191122, 0.07082845985649094, 0.06489961347993344, 0.002474054856593871, 0.06242313467326665, 0.05807721747025367, 0.08662375260985668, 0.032597822587816946, 0.0755265400174164, 0.2194707684459225, 0.4211780110434179, 0.9716336044573015, 0.4641366978326152, 0.3940666803429204, 0.22844761820329776, 0.3104461302920696, 0.14089080114518443, 0.07916250821924017, 0.11618390634295442, 0.03291468038373897, 0.07741433388042836, 0.03092709016205082, 0.07052352621911034, 0.07151396299201636, 0.04260152510757889, 0.07344123336576647, 0.039137942010476705, 0.03708456590351078, 0.09504820700855025, 0.022526093375598712, 0.12895047814855654, 0.045886789748985926, 0.029029457814871307, 0.05342224124638785, 0.05361026220564401, 0.06953852867046673, 0.12406307467890364, 0.0273887426291983, 0.06528147000579104, 0.08809926859553784, 0.01903401563815292, 0.023582988275936054, 0.06918438154483034, 0.03408135185318609, 0.026338482050285227, 0.011346955340535892, 0.031247523673359427, 0.09417261447637312, 0.007516785765126829, 0.026652126107364896, 0.09991110332550542, 0.046854132801414504, 0.017487182612380674, 0.02833162257898479, 0.019569852006351276, 0.03686460290825175, 0.04632589219498538, 0.034019946075615384, 0.011101375322698826, 0.03095914902646215, 0.08015242405235767, 0.04762252281990744, 0.010956643119214043, 0.03328294650981984, 0.05016480857926992, 0.05831746264330803, 0.04279109356444209, 0.021459871354783257, 0.05385766263991114, 0.07469204044149769, 0.06388181970725137, 0.07139457584989649, 0.039718494930815314, 0.013310116933538549, 0.023569656430833766, 0.09420816861693898, 0.06032368220809487, 0.05280168321464331, 0.07493230859718977, 0.07584100378857506, 0.026619820179597988, 0.0097045605070889, 0.05743538517685187, 0.019859101908702045, 0.045844264208309116, 0.02451082991976892, 0.042940185765825936, 0.03873997848601111, 0.049037985173204256, 0.040900867372270555, 0.02361790847874457, 0.035143823873612194, 0.09264351830126778, 0.011387750480113732, 0.060157850985565496, 0.010508116834136027, 0.04852965136148757, 0.02884993468591523, 0.028893810456558585, 0.012892216928453456, 0.021806545292718277, 0.026585997397741003, 0.05244329962278566, 0.056678291124802445, 0.08567839245041532, 0.08521824939957551, 0.15501940833224406, 0.1444305716863563, 0.24484588344010616, 0.15013135368785552, 0.24080715983385043, 0.17935183169620653, 0.1548566912571269, 0.197305561854474, 0.15775193670584312, 0.18004555495515948, 0.17050964487416131, 0.2368215414425058, 0.1483978192892767, 0.19216241525305858, 0.17791560069928247, 0.1475757303377313, 0.1869121695598287, 0.11029721778487006, 0.18039282261123582, 0.2446535647275948, 0.1350248046219349, 0.16627438907181064, 0.09062378111505702, 0.09733219090248309, 0.1590037396958759, 0.13049342519333287, 0.1599129788096874, 0.12061643744668654, 0.21722291325849874, 0.07562792409331569, 0.1000934552341219, 0.14162739468438013, 0.19268813543021682, 0.19103116385879057, 0.07665014585420009, 0.09201722610141001, 0.08332059598497807, 0.13344497810448372, 0.10946451085469416, 0.20884750380871758, 0.13737883959566394, 0.20929489915649738, 0.15198206889533228, 0.16788884276343932, 0.11616463157077951, 0.14031721579451717, 0.14740990294564157, 0.14195126601524893, 0.19069845187327555, 0.14393920289172282, 0.16564746867985497, 0.17135113117194947, 0.21043800959183326, 0.16267990453108666, 0.15245840704489141, 0.1041617728168926, 0.1569394851403852, 0.10958989646526114, 0.18114528949222258, 0.11105768262378632, 0.15614479149301208, 0.10419767935790362, 0.26159392910138257, 0.1005376483343782, 0.2501661955348907, 0.15663076702865864, 0.08817476656047568, 0.10839327478841429, 0.24999960205487667, 0.16452335722504124, 0.09626448650153414, 0.15705343305824265, 0.1236871553344592, 0.13750352806621982, 0.148148856035644, 0.12725016132237452, 0.19183917211428766, 0.31444676400673005, 0.35352181402906296, 0.4690901917074958, 1.0801734318656306, 1.842445502838781, 1.305695130459724, 1.2969806045293808, 0.3776495693431747, 0.5899852706540016, 0.31474851071834564, 0.18215727631843862, 0.18209241931476902, 0.13483282298811022, 0.317350329170304, 0.1674906762256738, 0.1787962034464844, 0.1864513829951325, 0.15874867838236595, 0.38255409487793524, 0.1898656070472733, 0.19540253816352737, 0.19404461667422326, 0.12602555445365368, 0.26317865858154915, 0.1091443014241034, 0.16539772401653952, 0.1605379993035909, 0.18645941159657894, 0.24074522928605158, 0.20574166078961667, 0.19303953996108425, 0.12267624103133717, 0.15750216139901071, 0.08350340754634912, 0.1051577560663704, 0.15732271296362724, 0.1255611213104379, 0.13680148509240922, 0.14030187871427308, 0.1053897581333595, 0.2083044700444706, 0.10355496989382852, 0.11047793026532858, 0.2290085477814559, 0.15986958758965616, 0.08753427875138099, 0.13192502901919428, 0.08940623757699806, 0.11817208070668483, 0.17143749992453283, 0.17598220928301736, 0.08229756983177317, 0.17404094248289065, 0.14941732909890915, 0.11390763695441908, 0.08038798842819468, 0.1160610564834168, 0.18213677580558485, 0.1325661680030246, 0.14351391684143774, 0.1500492903494066, 0.10406279425707557, 0.13132343549401532, 0.11245665110407338, 0.17928044762342207, 0.1832369087083686, 0.2054405269483405, 0.16330141634229692, 0.140931173978794, 0.21943214229278027, 0.33469860472025414, 0.14619945338176144, 0.18541393140631338, 0.13863327792815625, 0.09382170024177722, 0.21146427629695785, 0.23751918707163105, 0.12790935699858014, 0.18675617873668673, 0.18796972329578093, 0.1677836742131941, 0.183719314274288, 0.14141855911622125, 0.06746564030406937, 0.15739955158243257, 0.26163906700188116, 0.1455439579102301, 0.21025479200386235, 0.170322566203052, 0.19492567907417976, 0.13410119369866388, 0.2654107630012497, 0.1485697447412437, 0.1368440795809992, 0.0914106683264817, 0.1174418303755022, 0.1487163892917095, 0.15158027110080566, 0.1572024371595152], [0.013696809389418172, 0.0362114325135706, 0.031930261231478185, 0.018389310515035066, 0.0013701730307319293, 0.09449463953534443, 0.05530748403661194, 0.06254802998756209, 0.04655458093170197, 0.022338798284650813, 0.07548980610144716, 0.028001078622295495, 0.04530774985229777, 0.0316585470817142, 0.03921579186534209, 0.024888358048854337, 0.027399954325970144, 0.024378151152162783, 0.04704774620251791, 0.03799687702989867, 0.048981716015165856, 0.03100856361279805, 0.032484476048980034, 0.010761713004490782, 0.06251393141405237, 0.06238146332062541, 0.00742628301058205, 0.010358443363539634, 0.028820700770724687, 0.01860830057863026, 0.028583939382505995, 0.08384197244360563, 0.038312386511073965, 0.023840483833825397, 0.03759391861216676, 0.02037868572158679, 0.02215231524690265, 0.07494136375645477, 0.03960643925013081, 0.06602941696802456, 0.013524896386379917, 0.047774652559911056, 0.0525708417708595, 0.029011372394198855, 0.04273812624535734, 0.036407443769877, 0.04678131614421164, 0.009263142560338302, 0.02784791657881391, 0.0094502403836457, 0.03337068272934806, 0.06021507009263, 0.033645260132729046, 0.06550941180678145, 0.028452633827504133, 0.02385228924873856, 0.06955988720179566, 0.03240034044269593, 0.06505457008437765, 0.04903961311004335, 0.01458300840890696, 0.009598902618182043, 0.04144016262744704, 0.05747730933850812, 0.04238429321576992, 0.029627228561308117, 0.05772945951790579, 0.04187043974055879, 0.05013972686062898, 0.009787136166837188, 0.06218745921468062, 0.04838044041647546, 0.18735538206754193, 0.6510763699489256, 3.718253705770739, 7.647684389545073, 15.122439322933076, 15.667566407111385, 19.848320753343646, 27.7400863939716, 30.13300088144118, 28.618873819228146, 31.10542116626617, 20.351390223349295, 19.37053095909857, 12.12173886837498, 9.999918014772478, 6.717528623919334, 8.772172024173122, 9.45269638492215, 8.899536286630939, 17.926963413915328, 12.879133839761058, 6.670250335047323, 4.079467716716951, 2.2984130680561066, 1.2149400648570832, 1.0618489764390453, 0.8726971488325828, 0.7066663450771763, 0.19679903984069827, 0.17686930845581716, 0.057404236041850625, 0.07195420307858337, 0.03842279893316088, 0.044605906061347456, 0.05373331124804193, 0.025098011415872364, 0.01191163874952303, 0.08059844044187377, 0.04171800739582508, 0.03186162932956171, 0.041820624873282454, 0.03168142821279264, 0.04768308207032181, 0.037437456644951336, 0.027806277784909454, 0.025299368050670432, 0.029412402185581388, 0.06357381022685478, 0.05857629310940543, 0.08700264437544732, 0.050176146680549275, 0.06497329581649074, 0.043701734619155046, 0.021863865906432755, 0.03368134287396266, 0.04894023235406607, 0.018968260396392118, 0.04429431511990486, 0.08706239157266195, 0.033939342134662216, 0.04886088479730872, 0.009519008266168737, 0.017135207346009634, 0.0469325227482665, 0.04533112702530719, 0.03436134932863136, 0.02325700062717642, 0.0677953492249212, 0.019147865879800052, 0.06167680798699299, 0.024188672710630684, 0.01906750134132322, 0.05353201015461838, 0.024235379176154256, 0.022186741323, 0.043269561438430706, 0.06224882668785511, 0.08426322887140898, 0.0372246335891466, 0.044444399405150645, 0.03164014564977298, 0.0407654460098955, 0.057535237076902584, 0.016513601689028646, 0.015428589446650398, 0.028480827778337464, 0.012609409825545887, 0.016820699524795337, 0.08338233501079582, 0.12353409096718797, 0.060505559142198295, 0.09043397517093728, 0.03526681928985542, 0.0167144009948618, 0.04424481051823786, 0.0886158493437594, 0.033844151879630746, 0.038447853838724476, 0.10242153514897633, 0.04842603413928901, 0.08490128052090445, 0.09839791879658738, 0.03402092283771884, 0.057843097170153936, 0.019494440226304918, 0.03276590993928333, 0.04446969562841039, 0.10495283520750462, 0.04390703086110373, 0.018629367996547973, 0.07266078895378499, 0.07982332800184527, 0.08032040415151466, 0.07837605767793233, 0.04472185729912693, 0.008422878172789371, 0.02345396566294855, 0.038074439601792444, 0.008468748644865569, 0.014743622572671984, 0.030614275395149187, 0.03343558186785348, 0.06672752224990437, 0.012991590023551498, 0.07132483120526999, 0.0515553156184333, 0.05804892201277037, 0.027929332572966818, 0.06766983337940709, 0.020893014171310974, 0.009736697895512467, 0.024489126648874055, 0.030661914572720567, 0.06542488932609558, 0.018477565759131988, 0.0499334653478957, 0.03535945464165942, 0.03048440433978554, 0.056577378192976605, 0.09622943797899831, 0.010961930083501483, 0.09379353118880142, 0.05116406685462402, 0.04789123965066768, 0.06123044685791097, 0.04572990260297253, 0.09620353654627839, 0.006286269006875134, 0.009645091016746817, 0.040449090001563874, 0.041482220854490034, 0.016285688616335392, 0.06805979511550359, 0.023359585545897003, 0.05029064235127261, 0.03520178608596325, 0.06645853345793101, 0.07213281647812936, 0.050229883917997924, 0.018020624955815655, 0.04617100070801474, 0.03959598214996438, 0.024118916574685324, 0.025049439526253173, 0.0042641196013127845, 0.011722206273266386, 0.056399347020253066, 0.1007143465141135, 0.025190248401955734, 0.045153762349077774, 0.07312447899171422, 0.03135557462941976, 0.03413120502485864, 0.04680495761755494, 0.06747135531998451, 0.027545706384004127, 0.18274624471462544, 0.8512208238244058, 3.7584415751118816, 8.214753212467317, 15.89673480679912, 17.235316191950155, 20.34296693340425, 26.963859142795688, 30.301033258438114, 32.506044641617805, 35.04683640695388, 23.343927244986258, 21.83899029608696, 14.179865333341784, 10.739576028239343, 8.281496263319447, 9.00148751274232, 11.536689900582838, 13.033306521754112, 20.892545907728135, 15.505405818262409, 9.28551418166007, 5.4873438996653405, 3.943350930367747, 1.854253062798131, 2.023812835254977, 1.4717793152216943, 0.9271669808414675, 0.2444082480524817, 0.17749711750976502, 0.0636645686632443, 0.054128375129714135, 0.05542978614328369, 0.048803171563533046, 0.07424945612588237, 0.011469829140321143, 0.058608947607177886, 0.057096954344982104, 0.01766393824871029, 0.033258546609431505, 0.04308753894762166, 0.1568616352855198, 0.006296003111563022, 0.027187968221222682, 0.018335263011977077, 0.02319479045728522, 0.06357733040086685, 0.056633957616624334, 0.024905091324340434, 0.04331666052401547, 0.025374925387422406, 0.06681899314806347, 0.018070987575957854, 0.03840019933939461, 0.04082287196069956, 0.06053391971715516, 0.0405832703015016, 0.022310451116232623, 0.03944006793561482, 0.01843472037674679, 0.05087606759080964, 0.0025765040341103754, 0.03573165462923146, 0.014168593146267438, 0.07435090914969483, 0.06826267051961153, 0.027386904018180027, 0.022148207100408695, 0.10235300858414943, 0.009531994414095198, 0.06746983846589442, 0.04941910242421493, 0.03401853647383471, 0.043378717476321806, 0.033344934514213, 0.0331726375096027, 0.040824496067099036, 0.011846285703922472, 0.01627401726680898, 0.04743170563972766, 0.030230699001901576, 0.04090360230616024, 0.050597774660995895, 0.012798981155238807, 0.018152847901106845, 0.0696171292914979, 0.013271133591901633, 0.031513823496718565, 0.07433539586922816, 0.05678763102379538, 0.10868844846563955, 0.04969174162514749, 0.05784423098028187, 0.03534544672396395, 0.09972767889379494, 0.09008511405197844, 0.03531705933592973, 0.044371498478276115, 0.06541396491229534, 0.032274878223336516, 0.033099192660301924, 0.12476948435388266, 0.07027002772496593, 0.04806960407163828, 0.1144002621332484, 0.1408154487369522, 0.10581913509316022, 0.2870181196879956, 0.102545649053589, 0.10819763125431155, 0.15435995984702341, 0.23836566826268551, 0.14801849851444845, 0.13521983528569823, 0.1575819111519283, 0.18003783278888275, 0.1380641358874498, 0.11235179664987711, 0.11313771092963797, 0.10455705886406284, 0.1435196165355944, 0.12145517348882653, 0.13271935494436374, 0.1571667834275192, 0.19107550502784793, 0.09226019088659557, 0.10691684715810323, 0.1136194576599425, 0.2026474776287233, 0.12691428539373223, 0.12519889195720035, 0.11156107899883103, 0.10798444430674277, 0.21291388318903987, 0.14578208868061343, 0.19389323770038544, 0.139484784655994, 0.11313388815089581, 0.10584914275715429, 0.1738304828083323, 0.09558356457179594, 0.21813907780714575, 0.1292643750146512, 0.1896492331739395, 0.1036837186303831, 0.15573563925441236, 0.17538993138699763, 0.1427517359655711, 0.13478241440269256, 0.13527704673188348, 0.1061613465689363, 0.090635770391072, 0.12872184686843427, 0.1093355322917623, 0.1455660825294833, 0.1792984200461257, 0.12041268870234491, 0.1917728901870789, 0.28434851777649695, 0.07501626417281167, 0.11237905405822302, 0.15487898441572345, 0.11481741999065685, 0.14390721106000487, 0.12213825578651122, 0.08069692104454003, 0.08299093302940169, 0.18598474351869476, 0.09290918227164977, 0.20473710501626616, 0.20125010261131873, 0.0901850808652178, 0.08621137514109574, 0.08766279766155828, 0.1706842669556218, 0.17775073857797732, 0.4691260446223521, 1.9537354020341753, 7.1447443577551075, 14.74125260306943, 24.457129240036014, 27.947275792398763, 30.695466802966212, 40.70987209197014, 45.33165577919253, 47.700759518531065, 47.62367709990471, 35.35227921701247, 32.99269507008214, 21.578650820639826, 16.922616997072776, 12.890186098314102, 14.598825458557377, 19.006054516761534, 22.880316818914107, 30.972615595786806, 22.797541079982636, 15.293038891207788, 9.818787863177638, 6.748429546433111, 3.8899914968398313, 3.650919112466997, 2.473639807393474, 1.7346727439472753, 0.5169144561213832, 0.3650405588409593, 0.1735362131148577, 0.19982068979692078, 0.11072140066854416, 0.1063866377057087, 0.14821069465289194, 0.1876716384844434, 0.1367126955019851, 0.15471160952602664, 0.10234251317958679, 0.15417304971525747, 0.2346474758439487, 0.33591349759409506, 0.18375273102954512, 0.09667592934302746, 0.13795685293453355, 0.1674445730543906, 0.13733345654702958, 0.1872511787880813, 0.22373691291338016, 0.19073752235741387, 0.1118412756571366, 0.15182647643791092, 0.12730617001051867, 0.09868078144086946, 0.13671880888362087, 0.1462422930184872, 0.1308335529099549, 0.11545425356035272, 0.21718532898493353, 0.09714930273231961, 0.16928802574834517, 0.08964808387381416, 0.16382640107504784, 0.20240977586757755, 0.15679611944623534, 0.12736805459304204, 0.08347258782915531, 0.1661677496327508, 0.20253659406256294, 0.1769455188825246, 0.12154410097507701, 0.1165874508179484, 0.1923935286580555, 0.19585857498309306, 0.10932290716277016, 0.09764712198727554, 0.11414484075841405, 0.16745110012350545, 0.14643294165932363, 0.15152085332139847, 0.11758845960420948, 0.10011449200852264, 0.16055825466830886, 0.17021571225937338, 0.12546802630587933, 0.1372456781926655, 0.10091127707592903, 0.07367702756798075, 0.19049343142297961, 0.1736802682881394, 0.2256423880856845, 0.14305290045036426, 0.19695463229811963, 0.24920916785636257, 0.10133375158353199, 0.1987708429054868, 0.08842522368556069, 0.0975356485334135, 0.20233161957754245, 0.09276384007065527, 0.16009850998318967, 0.2367041001637136, 0.1093441584417897, 0.17649447695622522], [0.053198076258864135, 0.11260450607345951, 0.06731374039044304, 0.053424796149615324, 0.023361412665596413, 0.020963373601496704, 0.018527826872624217, 0.06769697587456434, 0.05498423323696179, 0.047376129791260733, 0.05892401275735709, 0.08774297642371348, 0.06204488259109278, 0.035066215336442955, 0.03201720263478497, 0.047510658661204005, 0.037536262834985415, 0.024455391967128363, 0.1236470276489854, 0.04885809623726434, 0.04001731901699978, 0.03750611727516498, 0.01916932974821858, 0.014192304525133825, 0.05953907027780529, 0.051353773207313595, 0.046321571459092444, 0.019159774716582992, 0.028095259556486726, 0.0162506113655024, 0.039235855708079, 0.025901269926238927, 0.03268290431268754, 0.05188379496816666, 0.01610346694266604, 0.10309242132690646, 0.022840670144726193, 0.006093341254463961, 0.0521069257369926, 0.012359854768991712, 0.04984026692146736, 0.031696801682213144, 0.015508402401821749, 0.02769867499028483, 0.022543205864607327, 0.041139925109042276, 0.0159389840348834, 0.040570204671953, 0.007620367076953934, 0.027130377561514898, 0.0031790266803000127, 0.08912707513739025, 0.04261053430156843, 0.04113334824421233, 0.046193765010684736, 0.00985563304575701, 0.0721762076981606, 0.01831104314225095, 0.050668595659156004, 0.014120159152474616, 0.02408590776124789, 0.032789582056143594, 0.011727288309034082, 0.02946384690491663, 0.026109205341086756, 0.026643927051355282, 0.05370677013190524, 0.04670875612646342, 2.0735303480778975, 4.821918702894642, 7.683853545496541, 15.949233770370485, 24.92284990126087, 34.02881268532046, 46.8464437607796, 63.068813739284394, 82.32978897710001, 72.01044098023446, 82.12329187700826, 69.78484107602027, 88.73983613906368, 87.10583163845925, 88.48667067866172, 92.80895786900675, 82.33422910013508, 69.31758480687296, 70.58085472353044, 79.73250527535716, 64.30889852585332, 75.00848108722319, 72.00929564814415, 76.48188806349232, 78.01391878435689, 69.33933042710828, 62.42240321251654, 62.59215162646387, 51.1219645315601, 45.914041457637666, 35.61509370803833, 33.150433186561834, 18.0899320110198, 4.32313883496869, 2.5895522198369427, 0.5066628207362468, 0.1499373802254277, 0.03944600511702799, 0.10523927548239309, 0.1846826851608292, 0.038993737450049776, 0.03221952454036763, 0.021140912562728893, 0.03550140690358897, 0.03773131265094684, 0.026011555943818345, 0.05993748962458584, 0.08147728884772909, 0.07035838830615244, 0.005973264154407286, 0.047604925780286717, 0.0689426195176859, 0.0656143352088909, 0.034014774982126496, 0.056642304144559376, 0.04793532034983078, 0.04250734991904709, 0.044231936410670324, 0.06270022101459966, 0.03488737977139893, 0.024422044159784436, 0.04671838585167162, 0.03085549158464757, 0.01725740220037199, 0.039545715290812716, 0.039992919116611444, 0.08098904569182666, 0.005557652358191029, 0.017914858856989492, 0.05718997274074824, 0.04783794291377549, 0.042640001873575875, 0.023070485030691472, 0.040729761634382515, 0.024946802896597696, 0.029524092059282046, 0.017396937454900434, 0.02863627659427303, 0.02436041430149588, 0.04458203476162688, 0.016909577215330738, 0.011094665350092035, 0.05647031357511879, 0.059793943899773785, 0.03880051475378775, 0.039284590391382095, 0.036247408002494805, 0.022430435806933432, 0.04904106867709949, 0.08056865494337775, 0.038632009884402636, 0.06252996563430756, 0.009291725300793207, 0.08643305800374478, 0.04761802205335229, 0.07588484700048163, 0.07761719396277782, 0.06746313519655697, 0.028724989575904705, 0.018056623427377596, 0.03934759346227493, 0.08775885742638381, 0.010406350671884515, 0.00352110026024973, 0.05547249937550195, 0.03295857339136062, 0.044245159088243405, 0.019629445985981056, 0.08136897167611508, 0.06496720541749271, 0.02989826663847893, 0.036537479534144365, 0.02081218040398052, 0.011283589335488937, 0.07668491858508318, 0.010024022044343574, 0.048008263411541144, 0.056878462238537694, 0.0378112156214493, 0.050733092601501176, 0.09385602098078498, 0.05859179106811362, 0.03183863137007481, 0.015258888522493503, 0.031065457132494742, 0.022909428451150175, 0.047974065246601263, 0.035411977629748084, 0.055854769588838664, 0.026714240516265555, 0.04522570949648658, 0.02703658541694524, 0.08308311638933036, 0.11610457793839517, 0.048307489693885854, 0.008413446672831573, 0.04822758289294378, 0.022855072597702666, 0.0460411679570473, 0.024283483752139637, 0.0419635615581947, 0.0255353729270639, 0.01484786990218826, 0.030229187893470934, 0.09679376132666104, 0.04098311840226093, 0.04332982574499423, 0.027840987313538793, 0.03021500569077269, 0.03592819831664524, 0.06387657583540966, 0.02926453572487639, 0.019220117547158754, 0.03389879310083005, 0.07882460215759855, 0.03946690399560236, 0.08191922198860876, 0.02690093614341271, 0.027459148024659485, 0.024273681657148466, 0.030241904953013987, 0.0447245730808185, 0.05524553816705462, 0.009031061969336965, 0.04744135834757359, 0.01699355768881017, 0.04561305121188203, 0.0564710145455695, 0.02904754515076357, 0.060050667624079415, 0.02578853242730181, 0.032974232228532914, 0.04255714563412532, 0.06220204552875892, 0.04129067206034257, 0.11111433482578686, 2.209546868839572, 5.57858411342867, 10.253653199441972, 17.030966589527747, 27.18025434401728, 38.93936126462875, 54.897104617088075, 71.07531655219294, 89.56649134235998, 80.47855577161236, 92.9027025161251, 82.23263971267208, 102.42609177866291, 97.56852657564225, 99.99884282388996, 103.18193251086821, 93.42351482760523, 81.41494320284936, 80.90562343597412, 88.8142042775308, 73.38296459567162, 86.72519699219735, 83.12244507574266, 90.25735409029069, 88.49922226321313, 82.02975903787922, 73.72235159720145, 74.01253638728973, 63.962945476655044, 56.215209268754535, 45.072449868725194, 41.81925173728697, 24.267972938476074, 7.612994947741109, 2.884424977725552, 0.49651923439195084, 0.11768180741778306, 0.06666208301941234, 0.06478852307003352, 0.05315494167828753, 0.043602840329009684, 0.05639812511001384, 0.037981953637133685, 0.061958544482026374, 0.016587586630316033, 0.03245229269528101, 0.026384795895747604, 0.07841493664008957, 0.04099209312229388, 0.03821643782899745, 0.05240515610503574, 0.08377428091461621, 0.05357341720692573, 0.03484460525214672, 0.045141665820753386, 0.03178491136960445, 0.02381459197720453, 0.03709424925487369, 0.08083344557352605, 0.05492230651960258, 0.06629253752649793, 0.028161941764635906, 0.06796532115268131, 0.028180126776738514, 0.021121806329897335, 0.03368218557067937, 0.03873830075345693, 0.009745596006752984, 0.0021051351617526024, 0.059580963795944575, 0.05684439430854494, 0.029441513526704044, 0.08489591024455526, 0.007204433045004525, 0.04855993481713438, 0.02806558322551991, 0.03554117452773837, 0.019098838167865912, 0.014647159654076302, 0.07667501306822223, 0.06713851309952236, 0.03125469808677032, 0.05880686642241575, 0.033582337501068274, 0.03089958377512953, 0.040617805545128165, 0.07941446687665679, 0.010922654670843435, 0.011279872851446273, 0.034801309793106014, 0.04583798228733001, 0.04843817280244924, 0.03366645778559389, 0.03297666072725289, 0.04753629962402967, 0.09079404415622835, 0.03963900181735235, 0.02073800202549225, 0.05184813357529141, 0.024493755735156518, 0.09653601104453688, 0.019411675917405277, 0.10741881860960877, 0.07703772505685207, 0.019088750705122948, 0.03138195869753198, 0.006627967682546906, 0.026299005539547053, 0.15205173693116636, 0.18353303233461996, 0.19598177724307586, 0.1481145812619117, 0.11123852533919197, 0.13513113762582504, 0.20828122693684795, 0.17188786769345885, 0.19045560200127865, 0.12112302074749624, 0.16721603370481924, 0.12347420587414697, 0.15961683986167755, 0.1652520140933414, 0.12275623593239054, 0.09351218539860942, 0.12293225229387322, 0.1431393151682231, 0.23525722054464204, 0.14245772674199075, 0.1195841875948733, 0.22272875652678553, 0.1678034699251575, 0.08012561097500787, 0.12084713716420437, 0.19070897792135516, 0.1346471539187816, 0.18229491167491485, 0.2277487927987691, 0.09236044881324615, 0.11681408260858829, 0.08863041267519997, 0.13356663286685944, 0.1841500089053185, 0.18293076465206762, 0.21740573248074901, 0.26143890354902516, 0.24578765064718264, 0.152468963736488, 0.10495916309375918, 0.1562045923163814, 0.15268755926480218, 0.11946142200500735, 0.11278260619409623, 0.1265641372470606, 0.16208172775804996, 0.16551686601052362, 0.139310714157839, 0.1964573186611937, 0.13382884944158216, 0.12353555419512334, 0.10943344598936458, 0.14724658832194346, 0.11560668973552606, 0.17906318508809616, 0.06913788000782652, 0.21014041507676726, 0.0896928693738676, 0.11903789795694814, 0.19596316130651584, 0.18034989104395915, 0.12161011477151226, 0.29755811056783127, 0.2227083632662412, 0.19870083779096606, 0.179676070749279, 0.16501402121878442, 0.2488749390167575, 2.9033920889900577, 9.108714326735466, 15.793544111713288, 26.92346461357609, 38.82640092603622, 54.087472500339636, 74.34640853635727, 91.02329884805988, 111.3699822272024, 100.88223903409897, 110.68978832614039, 101.05523909291914, 120.10466914023124, 119.53723553688296, 122.3156072247413, 124.45794305493756, 113.49830735114314, 100.54174592418056, 102.08901897553476, 108.92676138108777, 95.11178924191384, 106.0264353598318, 104.90733608122795, 107.58163159893407, 106.1557637491534, 98.52012495840751, 91.16050335668749, 90.69486310405117, 78.80360957114928, 71.02423944780904, 58.91901669963714, 54.61306225868964, 33.40789756467266, 12.428754548872671, 4.360043435327468, 0.8151807996534532, 0.28729642410912826, 0.22539108060300353, 0.22108300048257076, 0.23429620920890765, 0.24226539287595983, 0.22468854733292135, 0.11434786171922762, 0.15095620055592832, 0.22221489539069517, 0.1823520158687907, 0.131365263894681, 0.15782664560021895, 0.169787040100463, 0.10389641528168034, 0.100122359731505, 0.15026048546837223, 0.1798366121346912, 0.12311589889108174, 0.17359449708413693, 0.11403515995029481, 0.1723905745893717, 0.15484683936642063, 0.14521596502632866, 0.23093839987151085, 0.11224501165411166, 0.1344327259087755, 0.12499720398937503, 0.09879330443518777, 0.12606930573500935, 0.16583751977211045, 0.22146575333129978, 0.05196280544623733, 0.1089754939499882, 0.14421796696560998, 0.18623001422853241, 0.11327967468288638, 0.12648951262235641, 0.08243191867105423, 0.2576906498401396, 0.14515498442755592, 0.14444146545663958, 0.12258152192037915, 0.18820914109387707, 0.22016584001962217, 0.16945325559185398, 0.16814689181985396, 0.2112901598335274, 0.24195659815544085, 0.12073447627405967, 0.12467645829723728, 0.18466406922426917, 0.06384214018321326, 0.11312009856825876, 0.14036336493107582, 0.17495447168907813, 0.1338473121605573, 0.10319254135773068, 0.20921430670686308, 0.1251963945105672, 0.1813597021804702, 0.25611981719491944, 0.15636338702132627, 0.16627716231009654, 0.09981842966930521, 0.2896541975919278, 0.20942792266366944, 0.21643209601602248, 0.10378022272620471, 0.12804144587848457, 0.13628828279193372, 0.14097454987706678, 0.13476479438043412], [0.049770625698710644, 0.04676438560108504, 0.07751970927441314, 0.04494778428887648, 0.01033390365210512, 0.0117967332217602, 0.04788321104922122, 0.0364769394359281, 0.031574606827850786, 0.0015218125941652446, 0.049131934365798394, 0.044899214314477104, 0.0436504680152622, 0.07257971386875837, 0.05302993911168268, 0.07777963524624225, 0.024553797876222, 0.07962160939050299, 0.09212542835983539, 0.02955660674600832, 0.033816955758318785, 0.021369511284114375, 0.03411967923203784, 0.062059775340340795, 0.020576476217097333, 0.05694038129501766, 0.010734479536392517, 0.05273874526122405, 0.014470819620445613, 0.025311010671899687, 0.0688556532165216, 0.030918035002785827, 0.051613634061669154, 0.024974339927035957, 0.0822194365243758, 0.0151087295436751, 0.014212163439350984, 0.041104704216723485, 0.05074428131563529, 0.04253117525349221, 0.024549193687797077, 0.05700976204788012, 0.020673782790019628, 0.03556048760430948, 0.03423933833537083, 0.012514810415826017, 0.03401100965997866, 0.0667595447251393, 0.08304566235071228, 0.05184714915230871, 0.024555906533233585, 0.019703421351169387, 0.07085749458882117, 0.026155722199849067, 0.02041661856515754, 0.008241684014548459, 0.020104933777944218, 0.03900958780920313, 0.038693430983731826, 0.016323744033974026, 0.026995902317726327, 0.04275938518525612, 0.06661676125781191, 0.4159138225499661, 0.8115300536155702, 1.5090480831361588, 7.608752414103478, 20.47174422971664, 40.453780543419626, 65.36607142417662, 67.81493263859903, 79.85408306121826, 82.6645475818265, 90.49630488118818, 84.66705091537969, 79.79173306495913, 76.28485956499654, 87.85188997945478, 81.0264559715025, 83.7115615414035, 72.7024333707748, 70.48019101542812, 71.63349336193454, 72.29325955913913, 84.12606193173318, 85.26067026199834, 86.16098757713073, 93.15723296134703, 95.93207451605028, 82.34180711930799, 79.63763098562919, 84.22655305554791, 87.50585063811272, 90.81782940895327, 89.97179769700574, 88.31318424594018, 91.25609151778683, 89.10525983379733, 92.14952899563698, 93.79659498891523, 85.52982330322267, 57.443766209387014, 35.94874228200605, 18.10997140023016, 5.2780780965282075, 2.3641412056261495, 0.7097678367168673, 0.17705365985391602, 0.055029938042524366, 0.028727496598636913, 0.027526701657822537, 0.0898654000352948, 0.06140161388283295, 0.045597407696468216, 0.03304167477894695, 0.033848296415301106, 0.03672797495739595, 0.027575045636284257, 0.040172513108700514, 0.024750908468699744, 0.024334788660428697, 0.012807963536150995, 0.032384440287827485, 0.06201718851263004, 0.021593379412567424, 0.020744165202843088, 0.033254930674428904, 0.04850152444334761, 0.005066754707630965, 0.044377768907936356, 0.026374771635258393, 0.04626211154484942, 0.02463762704733639, 0.052616466137190024, 0.04625001884696465, 0.029802949978939952, 0.03559387371604962, 0.06307445496561066, 0.037892237080321196, 0.017576985354084643, 0.07624194356462649, 0.00812541676550022, 0.027555326533113277, 0.025034226935296774, 0.07116244354796025, 0.050131395654452425, 0.01950267375627112, 0.10032421623867366, 0.038087352013756196, 0.04435325026391976, 0.02812690281819913, 0.052702589741637634, 0.036722692781158035, 0.09015351804273744, 0.056813226021345586, 0.05605147415471654, 0.035164657634713, 0.0525900629168797, 0.04170235238909241, 0.07968630551570847, 0.08632101764481875, 0.09857104700659552, 0.026847112721072573, 0.026435235124682228, 0.08495879074138019, 0.043593746865348476, 0.014395638624386442, 0.03622136867394851, 0.03665780513397148, 0.0477273581219056, 0.053688606187220544, 0.017868684822573297, 0.025248704741017956, 0.031010593745797396, 0.02661101016846876, 0.04112408624120778, 0.028250953520558057, 0.06072203260696223, 0.06353707248044592, 0.04712761852950339, 0.01036659645427379, 0.029022898187019655, 0.020446271913486625, 0.03132187633685047, 0.03254414663740224, 0.0526466729840444, 0.04658392209920191, 0.037010933362668565, 0.04896302730025304, 0.04750089870104867, 0.02433801963624935, 0.06215868878268427, 0.026381040149698817, 0.09408705777698949, 0.019253469184942303, 0.045042503399834524, 0.021292678410968473, 0.06472862265523403, 0.06375688991899933, 0.05888013507149393, 0.04212637822474203, 0.010907354937385648, 0.019529155500593687, 0.028280423007785317, 0.018809749143979242, 0.02618875974158366, 0.04240839051142816, 0.08638358404559475, 0.032343657597178416, 0.01940130883256995, 0.07627645582561532, 0.030745944841915084, 0.014480475201121262, 0.05238388184337847, 0.041160540535084666, 0.0410021556871793, 0.006483128705557677, 0.05383665267858775, 0.04168968129482481, 0.07328715776243518, 0.024888597451330676, 0.09989129995266277, 0.010942832469159077, 0.034353699940707416, 0.026116421889333476, 0.017325645312666893, 0.029252670938149098, 0.018032497403422193, 0.09746234157993909, 0.007358965428260666, 0.07124163405669313, 0.04149022264285915, 0.009427324778610661, 0.047808877537928285, 0.029814060169061827, 0.05375504899289339, 0.06154697140558593, 0.04456101330898462, 0.03984091195067571, 0.4704386903153312, 0.8215922814223074, 2.560488192304488, 9.495492385279748, 23.354792210363573, 46.243822574615486, 72.44626337482084, 76.84254215609643, 92.03480751283708, 91.51474829643004, 102.9882223375382, 95.24741695773218, 92.24928271385932, 90.38151279572519, 101.17337303776895, 93.68582725524904, 94.80597772905904, 85.04236682768791, 86.01676202589466, 87.72893151929303, 88.70662150844451, 97.20333822311895, 99.11539954523887, 99.41734360110377, 105.79364269010483, 112.01969146728517, 100.02272221349902, 92.60506522270941, 93.0785894393921, 100.46271800994874, 102.93681575405984, 105.99100851243543, 100.18358645900604, 104.66491007035779, 102.68336788300546, 105.00281441596248, 108.7243906144173, 103.12898051354193, 73.01665444527903, 47.32088973445278, 23.19483599355144, 7.333099024911081, 2.911767820196767, 0.6816109798608289, 0.21694269361755542, 0.02941180846744007, 0.05039028740758377, 0.033566839542360075, 0.1654769681514271, 0.029574770690693013, 0.032535355778471116, 0.06180683609038111, 0.036061034132275856, 0.027699649837168477, 0.05395845682810872, 0.022812916694449323, 0.036153041291981936, 0.05372243662995677, 0.02696594444944734, 0.03012547682550165, 0.049949610650899916, 0.043976786997049086, 0.0336907466032332, 0.044277748468542294, 0.056639121049233986, 0.04244070793051393, 0.054700933922562874, 0.012655641316556403, 0.042391471459620425, 0.011854358355424578, 0.003857879215032764, 0.014042708620939766, 0.09670166223640404, 0.03218742162590066, 0.06201709275163951, 0.07930968903125295, 0.01666829590835879, 0.05028309638521845, 0.03247569668136778, 0.034155765803711075, 0.0066291067595293214, 0.04264191326294695, 0.10121971939600284, 0.03383570959070518, 0.05830750350029238, 0.06747988187858174, 0.015400459655680725, 0.013753914540903944, 0.09295853365573192, 0.02382686087531188, 0.037366405820413943, 0.10518370346436579, 0.1065251080980224, 0.13327224059931694, 0.04635160210572424, 0.03199563151405704, 0.04468083329078171, 0.03790143396585219, 0.017428228316167672, 0.04081056858863562, 0.05653949131468131, 0.028876247890894453, 0.016302707259573283, 0.05825268990931012, 0.04586117176879798, 0.06670511417811917, 0.026980381376380404, 0.028296888152497913, 0.02237165196528358, 0.03434791214643948, 0.023114952604256334, 0.06340090801278431, 0.09691278074657726, 0.12472406300085208, 0.21774406755162826, 0.22701710222228882, 0.12848626717083877, 0.09309665164760045, 0.0877310254520947, 0.20992748859909274, 0.12397144290228045, 0.13005405844699952, 0.1616347307759908, 0.22586052396124412, 0.12059645021274207, 0.16544283127352116, 0.17818776109526235, 0.17838207163637687, 0.1659342460334301, 0.19640724715446273, 0.1748343797460679, 0.20674791727815905, 0.13393173504981304, 0.0882254739201838, 0.12108965761839383, 0.11749213170861045, 0.1371138957479308, 0.13502039195549104, 0.1421857502071127, 0.1227821067215935, 0.16230861235770488, 0.12065031385469822, 0.10658798093396811, 0.21140458272589793, 0.16891924634335503, 0.1575036629313423, 0.12315635599436299, 0.30620730451999173, 0.18966536698562486, 0.0771055085163924, 0.15377218654799849, 0.1424573590197871, 0.12862584072976344, 0.09383141423665708, 0.14469948386953724, 0.1574685148173763, 0.09662978786734805, 0.1754954983029635, 0.2537199854850769, 0.1484052656639007, 0.23151060626391443, 0.24198673605438203, 0.14344000467850318, 0.13242344582273116, 0.1783069643762804, 0.19676378447442286, 0.13393308336455978, 0.20748988875458318, 0.09498583979063457, 0.06260337600965174, 0.11290876555346674, 0.13769699591061763, 0.12498823309978171, 0.18136198512248455, 0.14987333527495786, 0.1829425164408261, 0.9341921296811874, 1.229887727287508, 3.8327322467680904, 13.484882135545055, 33.17949010479835, 60.5787205696106, 91.36361152895036, 97.89269478090348, 109.01037846842121, 109.53964740999284, 121.01189767160724, 111.74696906920403, 104.83361905620944, 101.42786425928917, 115.79938934695338, 104.76899408525037, 109.6563300778789, 97.36908974186068, 95.37305831909181, 94.34324003035023, 97.61574406777659, 107.41472690336167, 110.71873541801207, 112.88397789001466, 120.24483111596878, 123.3007497172202, 107.85862938050302, 106.77592969709828, 110.42420464177286, 112.78459287458851, 117.00395707161196, 118.01392032254128, 115.3951184980331, 118.56744520125852, 119.23311848794262, 120.05284678551459, 124.0679810124059, 119.07268570315455, 91.92525571392429, 58.72308646478961, 31.01306111581864, 12.460062907588098, 5.64647690903756, 1.7412155025428342, 0.8351304033590902, 0.18371661764479455, 0.14622695593824311, 0.11683518067002298, 0.34460228297018236, 0.10733552953048099, 0.16195786666245232, 0.14450477496270211, 0.2203763303376975, 0.21362605384520947, 0.159390660062913, 0.0868526443598732, 0.1178514652494942, 0.19750875901551018, 0.09939531164784586, 0.1613557828410018, 0.1268196045871704, 0.08568989143015877, 0.14312019361363304, 0.12974688783288002, 0.11879510171110592, 0.11178640077912039, 0.1563658844679594, 0.11281502703505178, 0.14942362634164674, 0.08943213134883873, 0.1516644488419256, 0.19928622089566725, 0.17670484470023265, 0.10949908440271694, 0.1709025254052493, 0.2037175952066337, 0.12779923952034405, 0.19683768131559898, 0.1104077566114645, 0.09575263251580539, 0.09366700410722725, 0.13758666392776275, 0.1564319212470324, 0.11413630653893757, 0.22667703579270074, 0.14046744563646857, 0.15060631287915094, 0.09745020674721849, 0.17595349630761534, 0.21826064063897058, 0.27585042700652157, 0.22192419566694768, 0.2697605795917973, 0.2701865244776972, 0.19115321698688692, 0.15031242622963845, 0.20657727885390484, 0.24690281419504076, 0.15211414245347823, 0.17005653451046637, 0.09248700653833729, 0.17048350595418485, 0.1409276959396178, 0.14481050533152398, 0.1704915651991483, 0.140543089158112, 0.14537929497178526, 0.18737994284639437, 0.20079598101156376, 0.11130872197569379, 0.10930187804924865, 0.2538613899941406, 0.21396005285843728], [0.032070204427826314, 0.04005696789752092, 0.05078932728558298, 0.04892977525389964, 0.06872292848364, 0.01357339837047602, 0.03319336018795448, 0.02084326059106858, 0.0429535846436216, 0.04619841133394549, 0.09275601831294837, 0.04568823891121053, 0.02755032972462716, 0.07007578613176461, 0.04591270650346433, 0.07410371555916725, 0.03305782008195116, 0.037629128013166695, 0.09590725204156292, 0.04576970853151814, 0.04642965880432918, 0.05364770475294321, 0.04462621888265975, 0.017002446223951636, 0.046109893704734506, 0.023780773025787166, 0.0720646346528684, 0.0037075732430938875, 0.02242292623005567, 0.01725939785941474, 0.030260329367592934, 0.04158280436850844, 0.039901528657684406, 0.03313391942590956, 0.033167611972819415, 0.035217364483903495, 0.07389982125812, 0.10934916865681449, 0.06837245091916093, 0.02966055913167375, 0.03327114109490668, 0.029538781795230125, 0.02404285361990333, 0.03134709020565835, 0.015467885926726366, 0.007243917216621941, 0.015763582458959955, 0.02179319238019807, 0.027696911072839173, 0.025144277380839474, 0.07426933610751744, 0.02472926648483882, 0.02346931423451151, 0.12436214774366348, 0.02314906266908492, 0.10033876424835575, 0.02450419559834465, 0.056476541869943185, 0.020567698764704892, 0.04367459212399779, 0.13979986129749206, 0.8294955508843546, 9.715886442892014, 23.322842544124974, 28.395647810351466, 52.86170436489967, 75.121060955909, 78.38590068201866, 64.46685629506266, 86.30230272969892, 85.52835633677822, 81.56042391254057, 75.12660718733265, 67.74596168148902, 61.33873862604941, 54.70710892831126, 44.73840513537007, 59.11854767030286, 63.709732947811005, 58.7842244486655, 52.73549033749489, 35.45201724575412, 40.85767092243318, 44.065726495558216, 46.30999688179263, 53.0566853861655, 48.711828877848966, 54.00867992831815, 39.945861062695904, 42.000653513016246, 54.191627117895315, 62.260142603228175, 57.467135690873675, 60.87977424744637, 65.38169422457295, 75.8582547403151, 58.39316022011542, 71.97257441859092, 66.64108491713002, 74.26754536167269, 78.2196706341159, 82.47807025909424, 97.6391213940036, 77.22704425934823, 57.55019187927247, 35.17746702317269, 20.43487787246704, 14.157193053153254, 7.451051069844154, 2.357383942411792, 0.22225270949063763, 0.08346074410984594, 0.06599400072328507, 0.1487734321985514, 0.03330337424432078, 0.04000693469518616, 0.030663506120383262, 0.0619477388118544, 0.05572690951427626, 0.06180449952221206, 0.050143706687395616, 0.033206866318059546, 0.02880491361382508, 0.08802472824050535, 0.05118173667259755, 0.021691973013202512, 0.04147806482750081, 0.03828476904140365, 0.012276502487610185, 0.08246839977800846, 0.04813819575393873, 0.02393835539659185, 0.0595265255880452, 0.01902931377351765, 0.058365362290773666, 0.02572305680763337, 0.0062204677998388734, 0.04697693286523704, 0.024515547106162678, 0.02713996515188727, 0.010702244471758606, 0.044334814358021946, 0.044430789853175806, 0.020206467240988728, 0.0652884797102982, 0.0018191589685645137, 0.013770326059461843, 0.019744864792653152, 0.06906940706915433, 0.04152577295298538, 0.06780222103360199, 0.032255614942480484, 0.011583044486601028, 0.059722287865776214, 0.016440942079850262, 0.09307736155366705, 0.07789245701485104, 0.007665191360208537, 0.019230791067163792, 0.028013491161888646, 0.012061602375920744, 0.01870189737077923, 0.04021316939484208, 0.025351094307317853, 0.030008535419080048, 0.01984988778619276, 0.0800459761352789, 0.01022396237409163, 0.028839621227234605, 0.03681564988989023, 0.03481519130629397, 0.05052799554241281, 0.060906801522979816, 0.054686868548273086, 0.04982562698123436, 0.03853581222375074, 0.08052662735985172, 0.005109349675025912, 0.025390729781300313, 0.04508440457885304, 0.034170214221963, 0.04331449632562938, 0.021445700643403877, 0.05488291427853608, 0.014621416226990763, 0.009463272496847617, 0.09018324991507877, 0.05463422681655615, 0.01650727763321371, 0.024589263916676565, 0.012940494831831706, 0.05592803440747723, 0.019386797212064266, 0.03930233298770843, 0.07145351099391138, 0.02767306084053651, 0.032830226850966295, 0.059632264873794014, 0.06782901112831409, 0.0225689368427641, 0.031196778009255088, 0.07291466283101229, 0.04924814990391174, 0.03431904978389221, 0.04169330872114628, 0.029729484062221263, 0.10059342719614507, 0.020613683192359827, 0.028205507269669926, 0.009638246978753278, 0.09277586765106648, 0.03277658154406855, 0.026235868403267477, 0.04495648321725669, 0.024276188679880673, 0.013321717419931966, 0.026701787757056377, 0.10457998021475731, 0.04976539331818781, 0.06348833396670318, 0.029546888920688824, 0.009711485941924397, 0.04248953837480757, 0.01748131437888069, 0.06577756556291735, 0.08092667847391098, 0.07065405227964924, 0.03824251546193996, 0.05583765901504986, 0.054725682392956755, 0.04814023737825694, 0.04721551562749571, 0.03375513629326898, 0.04326894090721204, 0.024978651086829846, 0.03997282463035757, 0.3379456530655584, 0.8155373676169304, 11.378540915827598, 27.34508018339834, 36.12957139169016, 62.736836095010084, 87.4196683206866, 90.34967883940666, 77.02470487163913, 97.92911006558327, 97.4909342488935, 93.50349195541875, 89.36722709286599, 80.9101890748547, 77.18033667533629, 72.21298433119252, 59.83247395484679, 77.28661721752536, 80.7925650381273, 74.74224628940706, 70.63216717012467, 54.0888806312315, 59.01140420667587, 62.06980174587619, 61.185766189329094, 72.66918736119425, 71.69095608495897, 72.91368438351539, 54.79212237942604, 58.53653461702409, 67.5385545915173, 81.28643851126395, 74.19635434304514, 75.37545019580473, 76.76040772468814, 93.57938981825306, 71.77693443913614, 85.62508198522752, 77.38474707449637, 87.68265539600004, 88.62907625013783, 95.49550687113117, 109.33008301642634, 92.04992432748118, 66.68362694401895, 41.45745623496271, 22.695108382932602, 16.47913617472495, 8.177429408796373, 2.3887278476069054, 0.31284894974481675, 0.1225336031207154, 0.02373461239790965, 0.16470757072731373, 0.04744813822570348, 0.004467973203939056, 0.050278610940421783, 0.014009043844717165, 0.030879918298113252, 0.045778464916492664, 0.05495059814664626, 0.07001937907789985, 0.027902251364843502, 0.07977529428899288, 0.043469885769750805, 0.04342793096457759, 0.005524203044197132, 0.029599817935377363, 0.014375644687172628, 0.06305277084691391, 0.05496248783123109, 0.043109284353352366, 0.07032192252095669, 0.03780738901226752, 0.02875633214810683, 0.04767339488851929, 0.011913257110263071, 0.055212385712131384, 0.07015061760020834, 0.027616224777434143, 0.041288197596347144, 0.053251376826195955, 0.12525620299481577, 0.04912017874660031, 0.03285146663866697, 0.042538192618878624, 0.02249789559432576, 0.0233406497676286, 0.1641501038665733, 0.08236260303566534, 0.018931356025859714, 0.01014851803530849, 0.009562848605245594, 0.002640780247372365, 0.01675242002332403, 0.014260987180375285, 0.03177859497466876, 0.04636626502859496, 0.0747325971362091, 0.020725179628859607, 0.03509074930221804, 0.04804939084175614, 0.027175578664267258, 0.03843749249954859, 0.09071556610926505, 0.046025294615256215, 0.04425743181679038, 0.026699983619994698, 0.02391173001078348, 0.04870365291172939, 0.05506838033456476, 0.049490563105791814, 0.030185415544697357, 0.04717266449945108, 0.03086961633075149, 0.036352132221743945, 0.20501390790506718, 0.12910217887932254, 0.16331126823300318, 0.12216596518673244, 0.1745455492768557, 0.14932395830269785, 0.13977336997707046, 0.10242073841753507, 0.12929480402700363, 0.18222424772477921, 0.23698966709836838, 0.16308634481843443, 0.12209134822290753, 0.18804358949344005, 0.16862752006178902, 0.1756171683870977, 0.10640311625695999, 0.13605290993807778, 0.18010275107958626, 0.12197795188835553, 0.23858248646701538, 0.16242370940744877, 0.12295508171401678, 0.12295403983443977, 0.1533454142871403, 0.16079663058682797, 0.24030967765758116, 0.0965740473099774, 0.20725770282649225, 0.09589690985458513, 0.23721034638583663, 0.10348140247045987, 0.10382042702047095, 0.11024044300880163, 0.1951278037121219, 0.14272797191815992, 0.12864692346943965, 0.21274269318148015, 0.15348562369904212, 0.10375652762670672, 0.08098510799989586, 0.13693047897709956, 0.09358045915442129, 0.1429817308821986, 0.2931237178704431, 0.1580760378630892, 0.14280479521520678, 0.15324865738230367, 0.15490996501138135, 0.20852738630867776, 0.2024769158132615, 0.09817878700672619, 0.10467076163378455, 0.24823004620209818, 0.2440639221740346, 0.15030073572791394, 0.08131797320299572, 0.12478594758337545, 0.10505202827194046, 0.1569879172189582, 0.6951057105775803, 2.0475170665210296, 15.125783143504975, 33.895291282284646, 46.362956723859234, 76.49083891222554, 103.60715666124898, 106.76178563025691, 93.74884405443746, 114.01174560669931, 109.9974193880635, 104.5418574733119, 97.0305185933267, 89.89894359342514, 84.42755883739841, 76.60901208077708, 67.68254480054303, 81.68138196391445, 86.28076891745292, 82.11956562534456, 70.06813033934563, 55.148442252989746, 61.124455621165616, 65.8718296789354, 68.83845160084387, 75.21019289570471, 73.90500068664551, 76.83957684424617, 61.6088330361151, 65.04634334195045, 78.06563915744906, 87.02820008800876, 81.77634254578622, 87.71077879013555, 91.34506656277566, 101.90394586132419, 83.13017998972248, 97.61021352583363, 89.86169676626884, 101.11640453338624, 101.04851615044379, 108.0992824800553, 126.98020750476469, 105.96976495558216, 84.84985689963065, 55.19628340198148, 32.629816993590325, 22.690850650110555, 13.038212426247137, 4.670751537046125, 1.4484572698993068, 0.40815515984450623, 0.15901320854262, 0.29878933643621786, 0.17243148368452826, 0.1398234568055599, 0.12773556229207786, 0.16443438377351532, 0.26980050809441075, 0.1580220439861859, 0.11605376332637765, 0.13084201052063896, 0.23855630158176347, 0.3224519231627065, 0.08963344393358116, 0.12829808533311854, 0.16915273462091723, 0.13700382423497018, 0.09821215779670785, 0.17614935434633688, 0.1681803851839035, 0.12291162154607235, 0.1666137507005084, 0.1350405860331751, 0.18714493771474208, 0.11948320188469465, 0.10049876171134173, 0.1633926727358372, 0.14309996889243204, 0.13521991189449065, 0.10367275591218665, 0.11650897277098511, 0.17356451240278062, 0.15419448485537884, 0.12071484144056037, 0.11037813199143257, 0.1025099263736798, 0.10666815203524406, 0.24972258466145686, 0.14415720087145606, 0.14474511206630739, 0.09141948599849017, 0.09387024723353887, 0.17688798567941114, 0.11772380435779212, 0.2104959105171504, 0.0881413574660978, 0.09990096798226719, 0.09641351358544442, 0.1845506422462002, 0.12525167541518328, 0.1446191365680387, 0.1416368788528827, 0.11355479217825398, 0.23398913052533907, 0.14180512708281318, 0.21784686122930821, 0.1822838953305637, 0.13781000920120748, 0.12727482935353635, 0.14243972367577015, 0.10382124673454993, 0.14523877912471372, 0.132973006656093, 0.11924170032744447, 0.13271057557675148], [0.03600253948881742, 0.05527946437078138, 0.008252507879308636, 0.06111276426142263, 0.056971476803864204, 0.028656305963053342, 0.038688041555184516, 0.043791979776635286, 0.020662055899118705, 0.07385436926157245, 0.023968472228115125, 0.09122291549799905, 0.004248424853769041, 0.09352897804590965, 0.06400112257969957, 0.02721106577213974, 0.039961264363580176, 0.038437189894818494, 0.04486277151191908, 0.10325363686969204, 0.03155061295406232, 0.040027239855619214, 0.0351080667197464, 0.03391115392948832, 0.05821096493051418, 0.07616780923619386, 0.014770856040770249, 0.06603445782656632, 0.01338044093215778, 0.06946591119612418, 0.07982351952382634, 0.027130557592177106, 0.008954344009379707, 0.04055445773466941, 0.0004556187330660666, 0.02439897916760416, 0.03772320744070796, 0.05175455976578017, 0.009708543206685254, 0.043195273892413226, 0.042762058832111864, 0.06917858992012278, 0.05210014585886271, 0.11052096142403542, 0.03668113634170544, 0.05481253761137205, 0.020961985067133943, 0.021967837444296288, 0.01889605469430887, 0.04746376258891918, 0.06312731886282563, 0.03488462185487151, 0.019298413648240028, 0.03901295859606997, 0.03497494362114418, 0.07203747683595266, 0.025537523718911315, 0.2545991786304982, 0.9828699079732742, 7.324750750295578, 14.322230700523624, 30.605479786472937, 58.035232174781065, 68.60028528398084, 80.1269466646256, 93.85081783417733, 80.34337520599365, 71.45353501842868, 56.36121165367865, 58.08514825759396, 61.740812947673184, 51.18795840970932, 31.53961773841612, 38.1045396866337, 25.07386507526521, 19.236984060656642, 18.50541103270746, 21.616446779620265, 31.253710293000747, 30.999679949975786, 19.879709520647605, 15.319747290303631, 12.49649093997094, 19.778853616406842, 24.489598620322443, 18.703777059432, 18.154809974854995, 18.737833038453136, 28.919015545998853, 30.1251914424281, 20.659972890730828, 14.791239288545425, 18.040769023279992, 24.491279355941284, 31.55369120259439, 26.076220889245313, 29.899733604923373, 42.2564979522459, 55.931417942047126, 67.52568137261176, 79.3733024597168, 82.55505854083647, 83.19572279530188, 75.82149428706016, 80.53412791221373, 78.65906238555908, 75.4441858107044, 63.97813289396225, 52.213026708172215, 35.39087141713789, 15.781714243273582, 10.372122506941519, 1.9592509899408588, 0.008196387150805564, 0.18622206223587837, 0.10162694875391261, 0.03758974343297943, 0.011793692810310712, 0.07385643003808876, 0.05323321288151126, 0.1263854165952052, 0.12726267919905726, 0.03931087486806416, 0.032763427814408656, 0.029988473491562955, 0.027472690543940956, 0.05700705775750741, 0.04743192397478608, 0.0697984469814166, 0.027712234746544596, 0.024718677234505455, 0.03375094196188354, 0.06032750498683703, 0.04279750572036832, 0.029374115026345658, 0.12295074565636537, 0.021402481793155594, 0.03906828163552188, 0.05134039348171604, 0.058914352388631915, 0.02632472694160477, 0.029066224289577336, 0.06446958534539708, 0.052237708436986136, 0.017786644466762102, 0.02981479944390876, 0.04568314825695369, 0.05358597338800469, 0.02567355986684561, 0.08217862702064938, 0.03319938163903933, 0.07678093238463325, 0.052354257223346544, 0.05552324120916667, 0.05845088834664034, 0.03424791085924353, 0.028335320868439255, 0.0453297518974831, 0.07713421383091519, 0.011509061460533451, 0.009872895879520765, 0.005179895839143184, 0.0494134601866526, 0.03082312628506653, 0.033002462568542654, 0.0674576117026229, 0.03110142687575952, 0.02434101887047291, 0.09146202686092547, 0.01497131635269691, 0.0253984232192799, 0.07080985924168941, 0.04667640040298143, 0.07331701986972364, 0.07403645303941543, 0.036300869448290723, 0.05043049936272925, 0.06566429180243323, 0.021678022552101363, 0.035830786406633355, 0.03558515563547131, 0.04447608863213851, 0.0326583780077917, 0.014429626115147146, 0.03484457843906937, 0.01627169218995879, 0.01566891601654671, 0.03291602103760646, 0.025932235200138345, 0.027620758102726073, 0.07818798309252148, 0.061785151971684354, 0.033681994048698295, 0.01842209907819427, 0.012267524894747523, 0.02570442171887525, 0.04729904985475925, 0.07665461214679865, 0.029097314052764448, 0.0792512824879058, 0.024292489115689552, 0.035266853763812014, 0.02482253768961997, 0.06430873752481515, 0.047346754149804195, 0.047879575962020506, 0.008112469879579882, 0.017518203427654602, 0.04034729606862511, 0.017493803527266268, 0.04775414055573845, 0.05332036304377741, 0.02748619858926583, 0.05038013674258705, 0.04277474907857757, 0.01864516855998626, 0.05764620491273462, 0.08958866609440697, 0.047819813443047386, 0.0540643148574858, 0.025768570091214874, 0.04757399114990427, 0.043192297640827396, 0.07740995951838071, 0.02306632325804282, 0.01282939101539312, 0.02831512487553541, 0.03556770032211658, 0.0245071392911937, 0.01616503359870084, 0.02369033826154567, 0.1053790175806611, 0.04407768077667683, 0.11242472055938937, 1.197021084447061, 9.298154019540357, 18.250815868377686, 37.7930328922887, 71.72254685432681, 87.05611167415496, 95.9169263224448, 105.65279822195731, 91.70747003247662, 81.97020176918276, 69.25630954004103, 70.08196061657321, 75.14012367494645, 63.39177385453255, 46.780861731498476, 49.83943185498638, 41.572624867962254, 38.305314048644036, 29.369058493644964, 41.575013591397195, 49.517232679551654, 39.8002116910873, 30.61156926616546, 30.182977760991744, 29.475166451546457, 38.982993710425596, 36.22652845997965, 35.8015396518092, 36.62104829665154, 37.57972263520764, 37.63789138486309, 42.31235642586985, 38.061138660677024, 35.255149564435406, 34.91555075491629, 45.13854965086907, 49.772139672310125, 47.00050269403766, 44.691207255086596, 59.573460240517896, 70.05528065466112, 79.16092180436658, 86.6361827235068, 94.14053193984493, 95.23418288077079, 87.53507229589647, 95.50026862852036, 89.5497428217242, 86.47109016295403, 72.68548088689005, 59.68373767791256, 40.18658868728146, 17.134525006817235, 11.464183907355032, 2.300060218380344, 0.06743597737964123, 0.0754786978265451, 0.054499491102873325, 0.0033687749284229455, 0.05962439715081166, 0.03327165437381595, 0.15081893292165574, 0.031057756033635912, 0.06264612371582659, 0.02729910268117824, 0.019723462211268566, 0.05794781755896346, 0.010402810388064433, 0.07352142744968015, 0.03566186018888989, 0.060966276758981336, 0.09506600323103129, 0.01774659530530053, 0.01076804472118496, 0.04236474265194228, 0.0402416295612291, 0.03392516950806303, 0.09344084729110042, 0.020182802785007704, 0.02106888880652766, 0.030647397206555453, 0.034154501758636005, 0.019138391287396514, 0.02657347186017902, 0.08067181634326136, 0.06408743387568863, 0.022938457437820976, 0.06103676450889438, 0.01781684748317686, 0.04322289519252316, 0.010227903896462052, 0.06437978451891292, 0.10803502143150377, 0.05790098277371257, 0.03176133501373472, 0.04395057912915946, 0.00887453201181826, 0.04036668192354902, 0.04051498122393124, 0.07777175220150141, 0.09393266041673, 0.00858843647649572, 0.02955091854317054, 0.07622091445110499, 0.08769432217964242, 0.03231144359996242, 0.07355459139592226, 0.06558687095680545, 0.0238187748172711, 0.007054033706099877, 0.010206528128154818, 0.037048908341075146, 0.031382305352317716, 0.053079696522364696, 0.05102667281584394, 0.050702299697384726, 0.046018591345918756, 0.057147512317544995, 0.11754047951751179, 0.1774043136186177, 0.10214265616190049, 0.1776385220188287, 0.11633455753326417, 0.10354470431564317, 0.1434355000815084, 0.23484089772307107, 0.1082072533186405, 0.17789525340401358, 0.13535601507511832, 0.1360482980887736, 0.17461068207217803, 0.12863201539843314, 0.21068792279449203, 0.2484015579665861, 0.1270025157399716, 0.19053663878190905, 0.13338752151016267, 0.20024528636807398, 0.13216600963665595, 0.2515229832140669, 0.24592729315402048, 0.16838739746280257, 0.14631208362838916, 0.10699722510311874, 0.08563171471318892, 0.15572522045864215, 0.13623557594274321, 0.23108041725091397, 0.2008605622235806, 0.11910608744308834, 0.11349646224369926, 0.1233024872659195, 0.12853170384562787, 0.11816505568041918, 0.1461875483754181, 0.12258426451514806, 0.1255370661496155, 0.21078771340750882, 0.09200034918443811, 0.18999202687653804, 0.17835161198050747, 0.31595264771772974, 0.15922533828885327, 0.13678588754227086, 0.14159946311866084, 0.18034639768302443, 0.14546957077278247, 0.1010849262257257, 0.1379976700991392, 0.1430195449821411, 0.16848790819846815, 0.10467213293116902, 0.113375642517161, 0.19598971391397138, 0.13329974315579862, 0.4826520623699312, 2.7369112545444123, 13.025940310570503, 24.630148910707046, 49.785758141548406, 85.77819562727406, 104.82006334489392, 109.51934522198094, 121.17655092670073, 102.59655014161142, 93.31943081271265, 80.71618864613195, 83.40142757661881, 83.37196273188438, 71.90893004017492, 50.72918622724472, 58.560359093450735, 42.70608786613711, 33.580913312973514, 33.90779579839399, 37.91153161756454, 48.24937751216274, 50.36270741493472, 32.682584639518495, 30.748273672596103, 25.977392850383637, 36.92326691842849, 41.31122243019843, 31.327864662293468, 29.290401243394424, 35.5833891899355, 47.96801413259199, 48.949995194711995, 36.93623035184799, 29.673271640654537, 35.48087804548202, 45.787015499607215, 52.10196871911326, 41.24025498667071, 45.573862137333045, 64.90625589124619, 76.97474956512451, 94.23939920240834, 100.88537693023683, 105.44120204064154, 108.13346201373686, 100.09428193492275, 108.84761579575078, 104.60706295505648, 104.35750607521304, 87.71716440877607, 74.0967575196297, 51.712873520389685, 27.96496372069082, 17.874807657734042, 5.401908793757039, 0.8680913669447746, 0.39267810001488657, 0.26285380665813723, 0.15620240130491797, 0.1586459000264445, 0.18547287421120753, 0.3362761329739325, 0.16114832623110664, 0.297181471100738, 0.1256094078323053, 0.11873201437054143, 0.2708246450751059, 0.11024105587914107, 0.11860040046515004, 0.1251695124853042, 0.1402691361163893, 0.21752381727339762, 0.05989189973221191, 0.11202147485868585, 0.14925870293330762, 0.19056282366716093, 0.08970372483975465, 0.3512691478094747, 0.06351303647182162, 0.12795413483775434, 0.12643851414923707, 0.1507207970585554, 0.10862680903125195, 0.17788898680479298, 0.26559937384820753, 0.16845121258689513, 0.1505591678282907, 0.21004689106297111, 0.14656365158096438, 0.1458562306699253, 0.09199947584420444, 0.19176280846999538, 0.2647985055321648, 0.19501226233138194, 0.11032494250684978, 0.1501689686049377, 0.15660858112237147, 0.15488410188305765, 0.12329510983920867, 0.18355175552348937, 0.13160944675966618, 0.12120411881516058, 0.1671544249139486, 0.1736988842246994, 0.19502926948330096, 0.06827736408599923, 0.2321306165427931, 0.2743741142893991, 0.13217322618490265, 0.20770543525295876, 0.15554056262537358, 0.1400511074931391, 0.10004653234875972, 0.12217933342101113, 0.11512699612085858, 0.20888973057510393, 0.15030881029463586, 0.2050036729703988], [0.018695441164797353, 0.018631564753670848, 0.03757420716987502, 0.10112220406412117, 0.043337023141042846, 0.043051222549571146, 0.02145816872437154, 0.026739530993865866, 0.04538804352764161, 0.014910661341292004, 0.049580486506343856, 0.04460852225160888, 0.023359200586715055, 0.02782831047361176, 0.056572467569381966, 0.043339401844047734, 0.05950076205115165, 0.013782931078645973, 0.020527536605274486, 0.014574110297666443, 0.08406431414186956, 0.00869653435544141, 0.06749124296249882, 0.0405447743833065, 0.0439873130451287, 0.044191463985630584, 0.08320279464486145, 0.038534521365598325, 0.027962130712225076, 0.10009870293640322, 0.04132698845839308, 0.06147652579050872, 0.044799163231566075, 0.049220490299405596, 0.044315401690020684, 0.03180798593788378, 0.04606615774513734, 0.07096959623478113, 0.015688682042603052, 0.025586009423639026, 0.026598017317272966, 0.0343569902883422, 0.05656132865096292, 0.030508564837697535, 0.0168723261900126, 0.005930679241916346, 0.09484602108357415, 0.07274774759407006, 0.04934301457157539, 0.02976326662446222, 0.049837237043726834, 0.07403212464264325, 0.04125570397703879, 0.19602127673645175, 0.367917770579938, 1.4247753471136095, 4.369624314769622, 10.603566861921742, 27.469493842894032, 49.36260108024844, 64.27929639816284, 78.33927154541016, 82.69237287582891, 79.89202807026525, 74.26119112199353, 74.20824696940761, 78.94135536686068, 53.44718479341077, 35.78170030347763, 36.907804935209214, 29.245607776026574, 26.261884320166807, 22.2192072099255, 18.145468850289625, 16.258707796373677, 33.29076382421678, 46.19802105811335, 36.48391439068702, 37.68116689497425, 47.413492971850985, 60.75182261005525, 58.80675062056511, 56.8505665563768, 60.02294817278462, 39.72827542212702, 50.79502321058705, 52.04758897904427, 56.66563072512227, 41.974538372408965, 37.31668064671178, 37.90949982981528, 29.651475029606974, 24.421196406887425, 16.283785470070377, 18.484636199089792, 24.53070309854323, 33.16729153356245, 22.330067119290753, 26.88946943129263, 33.63507732268303, 49.03074502944947, 44.09880384322136, 60.4839208049159, 56.35121745447959, 62.08598936757734, 64.63759706866357, 71.71789492330244, 73.64972499109084, 76.35507783582135, 78.55356631740447, 68.20053300549908, 44.21389402881746, 23.694355718551144, 13.487027672029312, 5.362669402553189, 0.8086382249189962, 0.2271751308393094, 0.07463687445007025, 0.05181203551229931, 0.053751253027228586, 0.043146408974163, 0.042210241869813016, 0.045128370364827496, 0.10125459937919533, 0.026594937643817356, 0.06711409787737554, 0.04012948578043331, 0.046260123546685905, 0.053396971836205454, 0.045514248852287574, 0.03062851505444175, 0.008359489185104688, 0.059649049860215, 0.025530906634465344, 0.0458060862166026, 0.05366507196618665, 0.05132269685066516, 0.022826359622300636, 0.043590992779260686, 0.037246103203224565, 0.0575949804436776, 0.020661887359775363, 0.0684389703336262, 0.03915269303345873, 0.06551757830405427, 0.01119690074119717, 0.10810465116294161, 0.06115132529709128, 0.02451738954762057, 0.01766205750285618, 0.08741128333513776, 0.011133769350577027, 0.04033758973462447, 0.027800403805750034, 0.0420874456364301, 0.1232777885912407, 0.05210967982308038, 0.0309715788030336, 0.030919320115278807, 0.012656990588913042, 0.17704472726871892, 0.05577293990720665, 0.06627053548131259, 0.07891444128847892, 0.023756980250078826, 0.03640189729330521, 0.035535398224789294, 0.11012370653089978, 0.03517207336582003, 0.005669257004610113, 0.015303869374967633, 0.07490110583603382, 0.006042981507151478, 0.040411233766785556, 0.052796734286652464, 0.07512812067063586, 0.017881712147725687, 0.03660484547576597, 0.05419404801702308, 0.09431154452144139, 0.022178766347708243, 0.10140130521669503, 0.020203994692213113, 0.02659398769479125, 0.02270772324634656, 0.032170697926513614, 0.04795849833997989, 0.0079368025669077, 0.029387670952165802, 0.02097855746415594, 0.01817474077876297, 0.016665721852933208, 0.11504703186332219, 0.041545767847809105, 0.06168633812077104, 0.028720115341486472, 0.033606656962224556, 0.055653916656850815, 0.025581847650990374, 0.024881583916383888, 0.07134363100293183, 0.02479689098113487, 0.051749691277021365, 0.08906075490578529, 0.046785613897466855, 0.0706555997772563, 0.03510762621918994, 0.011318603384068177, 0.012846141527857513, 0.009260213231637834, 0.035918572421876654, 0.07252630221867755, 0.042666772816089854, 0.008046278925312143, 0.05775363342235646, 0.027832851459782933, 0.02726279011356735, 0.02550079171816188, 0.03717088102993946, 0.04508758767417843, 0.012897831395328527, 0.03494006746839132, 0.1620788472674547, 0.026318806997169892, 0.016913909442542542, 0.015545491591065884, 0.04801801188037761, 0.058447869960218675, 0.07011795927199625, 0.13932182243274105, 0.34762327409079, 1.597700022882031, 3.8448837495619252, 11.476228525561671, 31.419426510410926, 62.22406072001304, 79.79379623166977, 95.11451136681342, 93.79746575509348, 95.8128579970329, 90.40546278799735, 91.58546078589656, 90.62825341378489, 72.94905631772934, 51.271595108893614, 54.18735565677766, 46.908013205374445, 33.77258777618408, 29.93317573301254, 28.421543298229096, 29.55830304853378, 37.34214075150029, 40.889889271028586, 41.130483535028276, 43.83270632836127, 52.23342695543843, 46.068061167194, 35.27780125218053, 37.38626349356867, 41.951023763225926, 38.394614650357155, 37.31503325123941, 35.80206917178246, 42.08865188783215, 44.67490196228028, 43.55663422615298, 37.11707122864262, 27.638242052447413, 26.191501309794766, 26.18124431179416, 29.360476347707934, 29.453126653548214, 46.739876885567945, 38.24524294945502, 35.42944792778262, 54.78509741444742, 70.24891238058768, 64.57057552952921, 75.09901723554059, 70.75183868408203, 70.14764462747883, 73.70839580412834, 83.55909901280558, 84.85186515315887, 88.88264179229738, 89.55143728563863, 79.98426652723744, 52.226880519620835, 26.698791250105828, 14.004964886173127, 5.533096876836592, 0.7470627741948251, 0.16867034437675632, 0.04650420682024091, 0.024441901158781785, 0.09882467573568707, 0.019442897830759327, 0.07149979036541716, 0.04135273284308853, 0.024464772713761178, 0.045854181216488925, 0.025589248060338923, 0.08200140790112558, 0.04357044630113148, 0.058078941168083306, 0.04602773843573467, 0.07941136422056345, 0.02095964658374508, 0.07691156569748156, 0.0678509212429485, 0.006491191780960729, 0.012197731412015857, 0.011235718416320461, 0.0051974301553151065, 0.08033886687048981, 0.0905907397428828, 0.03897255511894342, 0.017871166947447968, 0.03552124858082783, 0.05286374399738927, 0.028805944002083236, 0.0970615856649895, 0.04119104615622952, 0.08749741460046462, 0.011747813719745365, 0.10110548036473413, 0.015267334641858697, 0.06202064356916855, 0.0401006885353596, 0.0479837179544472, 0.013452732819132509, 0.08706167145001312, 0.06177018644408353, 0.0645062426525739, 0.04546130451584055, 0.06189462976650365, 0.13235759290476, 0.03822866076182935, 0.08378259296859465, 0.026912977130362586, 0.02733668503952363, 0.017023067395653457, 0.05018353176813933, 0.06717377612667699, 0.03380618456210341, 0.013175263433837363, 0.0566964129346513, 0.07106043894084231, 0.03176456215911575, 0.025617355826280774, 0.009162693111706645, 0.05870650507389538, 0.11209975372278884, 0.11802606434831697, 0.0760618439545074, 0.2980097040774361, 0.21063601267674278, 0.2362768222848254, 0.07263605963558921, 0.09693325827679328, 0.20328668607098443, 0.10859529983492629, 0.15631584360474543, 0.13742449843595106, 0.13381801695833284, 0.12278229058269532, 0.15688737583977563, 0.11714251982348582, 0.3631240213590284, 0.1130563753747171, 0.15541029703472892, 0.10642580012039793, 0.21948486446372925, 0.124024624725984, 0.24975848354158864, 0.09771368736701627, 0.1434166543185711, 0.1160288578079593, 0.19736721661062012, 0.16065050697615071, 0.20439208965868721, 0.24073205257375396, 0.11516523156915942, 0.130347975740029, 0.14137533643553335, 0.15300088922583288, 0.15478621116809307, 0.1588289950403475, 0.15386784028622413, 0.2073199398094608, 0.22980917094936296, 0.25495789164016325, 0.09428558946256677, 0.13508736336183164, 0.11139545078960159, 0.07719942323502994, 0.16629960868627797, 0.10901925289222311, 0.31827836808177734, 0.14555929499047418, 0.18863747617410076, 0.11619186599648769, 0.2021141731811147, 0.2160445168133705, 0.11671723377320076, 0.4132361001064701, 0.867881213705386, 2.728267331277171, 6.670416055187103, 16.290309352259484, 43.375899253353, 75.62579939442297, 98.58430277916693, 109.14184847185689, 108.81137309535858, 103.69888521009877, 98.36326153047624, 98.28486119547199, 100.79944564450173, 74.43166517442273, 58.73745802910098, 60.266582273667865, 48.74091717504686, 43.52274102549399, 38.54165646337694, 35.54203564120878, 29.665487697047574, 46.99730203997704, 66.44551554033833, 51.48861985052786, 55.91025283259731, 68.07554275758805, 82.40949153900146, 80.3316943876205, 74.39120984846546, 80.46339973326653, 59.76316175153179, 72.67426290819722, 70.77163880871188, 79.89345581300798, 61.28282523924305, 56.4586550958695, 54.38106190773749, 47.82376896950507, 39.032435186447636, 34.00635319371378, 30.89227760991743, 38.8511706936744, 49.120861484158425, 38.710918503422896, 42.03298168797647, 53.81918630292339, 69.4893846204204, 64.34557268696447, 82.08130682668379, 79.55424924050608, 83.55691817498978, 88.10478871868503, 94.89812989388743, 98.0478088317379, 101.43155913199149, 103.65843772888185, 96.46430092473184, 67.72556535659298, 38.33213521588234, 23.965007105181297, 12.170889108411728, 2.669234924739407, 0.5118512278122287, 0.19391258908135278, 0.25973098713063425, 0.18511953913877088, 0.11855137083799609, 0.24684370285080326, 0.13746372213767422, 0.1948076555685651, 0.11388425595097004, 0.17925152014340126, 0.22053189215160188, 0.11485597719588589, 0.09573692771335764, 0.3019378658744597, 0.1622441843632729, 0.2767720920664649, 0.21342322440637698, 0.2117619320990578, 0.1200070451464384, 0.19465459120129386, 0.15828576209324022, 0.12479923154798248, 0.16771098779093835, 0.17005455800362174, 0.125558095263137, 0.15641586404413949, 0.11161203150667491, 0.15253650204789254, 0.23528746569589262, 0.14563679244489441, 0.19375356455003062, 0.37196256160255403, 0.09886751537241283, 0.15413811610591027, 0.13329775132719549, 0.1353864900527462, 0.18882634749095287, 0.23771378872615678, 0.13967670500278473, 0.27331415503736467, 0.19137761946166718, 0.19772818191878258, 0.13058842009594365, 0.13625789974485675, 0.2833190488238489, 0.1122582802969602, 0.1452222929125832, 0.16607879150298335, 0.19657676709034752, 0.1823478789939996, 0.14171570930029118, 0.2552617067891744, 0.1446113684364865, 0.10384347860611255, 0.15384171668800617, 0.1481636874978581, 0.14475260440620685, 0.20078130276693454, 0.25345357074852914, 0.2600793732750801], [0.09796899382866199, 0.01508309528411877, 0.021245625290659167, 0.016594921922191017, 0.05723109634052362, 0.07777472462264762, 0.010350364008768192, 0.06419109706316264, 0.14046375309267353, 0.04252765890991977, 0.023464277206409364, 0.026788920682344227, 0.040063380053447145, 0.048144830075363, 0.001837198423961508, 0.06792981297739091, 0.017824447075385722, 0.005264968945524626, 0.017015465888224782, 0.015567966695544461, 0.028140389796106086, 0.03246628529121799, 0.03438853395862445, 0.0336349600805871, 0.08032698484678423, 0.06817674609802424, 0.03492672604718997, 0.02696513048102779, 0.022334167283148538, 0.015218580806357487, 0.043489761920946265, 0.03240105673490513, 0.03287090228930597, 0.07231215766120343, 0.023242845237555525, 0.06994469316616174, 0.05343720294354905, 0.019106382218700264, 0.019948783991557938, 0.04676248953347245, 0.04080286557455698, 0.03716382536015684, 0.06844427166206223, 0.0829844212820453, 0.08037137198111705, 0.048900008907601725, 0.007840666672094695, 0.03699404112393818, 0.05286239568264254, 0.022654229241813865, 0.06250648886986798, 0.2735255340174321, 1.4747115320736364, 4.641357785271061, 13.274802930893438, 26.60253236370702, 32.59248779666039, 49.33466203751103, 66.2596030389109, 58.94324910256171, 72.67220758622693, 58.99352604343046, 55.046076236232636, 44.035206533247425, 36.41229191134053, 39.855591635550226, 29.481869782170943, 27.41892468544745, 34.65007297454342, 29.580003561512118, 39.24536889599216, 42.663824327530406, 50.82028719686693, 47.64208478312339, 69.04556843542284, 72.4769441543087, 60.17806222361904, 90.44511795043947, 72.99963135873118, 52.187582292864406, 70.55317847959458, 91.11268966428696, 86.21892882931618, 80.63226561392509, 62.25599273558586, 76.27667750081709, 80.38412078734368, 70.77061114772674, 61.87645243060205, 71.21603550449495, 81.89771636839836, 94.25808537390925, 78.7349759378741, 53.42684730406731, 51.469682647335915, 55.9579017854506, 51.45842544494137, 43.51780276144705, 33.61386906716132, 25.25997369520126, 18.28439724060797, 13.94586947656447, 18.20109002051815, 26.49842481459341, 49.2210505854699, 46.736115332572695, 55.32438408943915, 62.406082230229536, 59.34622949169528, 74.31128763383435, 78.53122449690296, 75.25650824269941, 66.9247507279919, 59.38131901525683, 44.58605243313698, 31.109355303549002, 13.438813897871203, 2.961624577160805, 0.277922909346319, 0.03493165199254309, 0.2238642980134295, 0.06545249913488665, 0.05819157141471102, 0.06201541884952496, 0.04078706118067907, 0.0023935780383556363, 0.11701321184274652, 0.096182921120236, 0.09374101586159199, 0.036569463704983075, 0.0035011551611410876, 0.033995281874893174, 0.08098508501725812, 0.03184376798960711, 0.037080268150255564, 0.10653666070392055, 0.036441795152401736, 0.027868798220409986, 0.09945833004049717, 0.07834267156619219, 0.04779162140743387, 0.11076371936548142, 0.031911687429754004, 0.09574009165648492, 0.0737579494354225, 0.028208374353726546, 0.059475699484708815, 0.03267665686566503, 0.006768413145290387, 0.0551133994914351, 0.020731176182086912, 0.015656358877857848, 0.04475237441159064, 0.023737332010040843, 0.053722961400184906, 0.04134981787853664, 0.09038131428702224, 0.012761953253028615, 0.02174913849411232, 0.025106229624080083, 0.06061464623217622, 0.026642561499630252, 0.01674422671297385, 0.05034794955844841, 0.08964598479290163, 0.008407421391307107, 0.015651047973322774, 0.0495228843553172, 0.06886424106215278, 0.049736718647181995, 0.021409443617167494, 0.016378071159124374, 0.05390424461614701, 0.030182222873272917, 0.06325673026543471, 0.05331564011172422, 0.05953515556851222, 0.10225604483557325, 0.012742536754587726, 0.0633175078509075, 0.0626692327580625, 0.04523101848580184, 0.056363245126821344, 0.05857563427379055, 0.16020193185296752, 0.015916355712819966, 0.07327827114251352, 0.03128108598532216, 0.0762002990250626, 0.03351616282616893, 0.028538625281784805, 0.02582329558208585, 0.019991715558834618, 0.037741061119783315, 0.046531471889466054, 0.09328477219828675, 0.031436509903400175, 0.026562424872310895, 0.0442466797727731, 0.053405973369315754, 0.017828597356715513, 0.05995828891173006, 0.06738704734391744, 0.09331895504146816, 0.0661962479352951, 0.041374945562453046, 0.07076452981920973, 0.0426941451376244, 0.029874906702447804, 0.0800297427321634, 0.0818339487417571, 0.10422633104627171, 0.09749188959117859, 0.05924118464932807, 0.07304174149589193, 0.03363617816038671, 0.03234511699467417, 0.029282037003506577, 0.060573047657887784, 0.21295552772860374, 0.03941909627868764, 0.0761113485561744, 0.040731979458923304, 0.07943996228277683, 0.05923516319824323, 0.07178141960814115, 0.07236611323371049, 0.27856032514283735, 1.7553703559021798, 5.595648384863331, 15.10377472446811, 29.622257294193393, 40.13250312497539, 59.44905050339238, 82.31656274487896, 73.34840066971319, 90.52297699835994, 71.79366727029124, 75.3700137907459, 64.8786816289348, 55.844690415167044, 56.49425060518327, 46.825109989412375, 34.410941754618, 41.34558631527809, 42.996307957556944, 39.2238272390058, 50.22367115943663, 51.317071068671446, 40.39683165088777, 43.66175374677105, 53.977548076260476, 57.03295676938949, 61.091135086551795, 59.25678376228579, 50.17620263561126, 60.84755982122114, 71.80102563673451, 60.99531942798246, 64.649693658275, 52.07348054455173, 58.5349460571043, 59.832572014101096, 63.55900802919942, 51.278471023805686, 55.40708334215226, 66.16564658380324, 68.10700016637003, 58.31055510428644, 48.87294807741719, 38.43932967032156, 54.00942910102106, 54.02147077745008, 32.399420892038655, 36.862074021370184, 37.889687938074914, 34.66111444657849, 27.482086612332253, 33.866516774700536, 46.529378967900435, 64.13119162282636, 58.21072686103083, 65.32673005134829, 71.58246332599272, 69.0736996742987, 86.83877314290693, 90.88626692371984, 88.05739079752277, 78.31331329960977, 69.98153225068124, 50.38496686566261, 36.82131275053948, 16.089195705229237, 4.225835127215232, 0.34757522505617916, 0.11397195769654167, 0.06572169477059957, 0.04570246516396442, 0.030780045330644618, 0.033951867672224204, 0.07141103141851003, 0.03259216885893576, 0.045580419696747296, 0.05288568858598029, 0.0122315292960153, 0.026098451381849668, 0.04316690948701674, 0.05743697097885513, 0.06698059173481119, 0.07638629751219865, 0.020218445025684855, 0.02347198979658706, 0.021986936016248602, 0.04025133206479011, 0.048207710572187944, 0.026642235912262436, 0.024623565503486225, 0.055038652292663054, 0.04143314143162101, 0.016260382816976598, 0.04709044028253806, 0.07274213983046432, 0.023651595279994993, 0.04301396769381339, 0.07359248976553641, 0.027030542898442478, 0.015749537194478178, 0.03403545169520282, 0.05296345034073438, 0.018080061887420954, 0.05463359862445824, 0.10242495190111861, 0.037437579219019225, 0.03634881506103181, 0.006031197638461186, 0.10311030181905917, 0.08162939560509498, 0.041013145218453104, 0.02740270075117869, 0.061241493845779094, 0.03447293003480281, 0.03142952892719017, 0.018016013106511488, 0.04210434553603973, 0.029503685392199025, 0.04150853597468907, 0.03939474234357476, 0.038383196017915205, 0.02262121851315662, 0.018639181582858006, 0.05794385688439493, 0.039399829167391986, 0.3036478966955216, 0.16668156480356572, 0.09919081979821767, 0.1532458841440178, 0.1624435051194122, 0.19789463750297026, 0.1634768045116817, 0.12974943124478863, 0.28143162268304056, 0.08950805066213494, 0.11236780022661533, 0.14837307464932242, 0.27511642284450993, 0.22549146876460124, 0.15568926029147642, 0.25877978172033067, 0.1409485488529167, 0.09253592891318184, 0.11680221590664118, 0.24322648082048665, 0.1586070287251665, 0.12329839635640384, 0.1851710508907995, 0.1294118469400752, 0.09533129181833037, 0.20899701352802016, 0.21884086031106212, 0.23636384987302367, 0.1385147334827531, 0.13071108609437943, 0.18017856314057307, 0.13172734769121294, 0.1559405371306404, 0.12271913429421764, 0.1643436789632805, 0.2130016921869209, 0.2712726532932251, 0.13627939617201207, 0.11953268350372392, 0.19151744582960684, 0.19004792065149356, 0.10582048340790695, 0.1346779200098207, 0.26525837279135184, 0.23919204730660687, 0.15744139530485676, 0.08776161534291121, 0.1479459499880191, 0.10587109883706416, 0.13991809930772553, 0.2814689464867115, 0.6981088978148277, 3.6981086577138598, 10.240133770050543, 21.950032595665228, 37.33909699224657, 51.746052849677305, 74.54478633019232, 98.82866644090223, 87.93651119355233, 101.67978240597634, 83.20472071247717, 75.90384837119811, 63.21388652247768, 54.93926225170013, 60.54656497893795, 46.046221410074544, 42.50343468881423, 55.10296237084174, 47.72656086952456, 57.66939270880915, 64.72796847743373, 72.15716115890011, 66.55113712433847, 95.4712038655435, 102.52733599755072, 85.42299362920946, 116.52233708289363, 92.90391060613817, 73.37704966145178, 93.05072492168796, 112.67202869538339, 111.70951827879875, 105.34053833253923, 81.75392227788126, 100.48245537665584, 105.70414204751293, 93.93838867064446, 80.71127783867621, 88.31984443049278, 103.79458319756293, 120.18803519587364, 103.38614679151966, 77.69113909813666, 71.78649717761625, 82.19783259976296, 72.16713966861849, 61.612194507352775, 50.67412791713592, 41.952969258831395, 33.72351500295824, 28.983271814161732, 37.06801022252729, 44.507471669104795, 69.97934356812509, 68.13665328487274, 74.51805145509782, 84.27013843290268, 79.96139126439249, 97.30591604786535, 101.32738882495512, 100.11493713625016, 91.58156979468562, 84.49642781288394, 66.63388344549364, 53.31812312526088, 24.685342542586792, 8.040963776649969, 1.06428844553809, 0.277013716197783, 0.3839177313831545, 0.20337800375155865, 0.25091808018905504, 0.20649360673081493, 0.20709334632321713, 0.13146119342455942, 0.29652416766170536, 0.23764176113951593, 0.16626692737542814, 0.13862531061374372, 0.08557625760835025, 0.14280110267141174, 0.19988566937465824, 0.2015055622905493, 0.07860782991854415, 0.18481172501079499, 0.1988785089023652, 0.15651225322677245, 0.16832277028551026, 0.19625550045842127, 0.1306258664736825, 0.2581135916613764, 0.15529690070017693, 0.16384077288450735, 0.18504824699653735, 0.20390717132437616, 0.10272260770321855, 0.22363572802034118, 0.1555611703905367, 0.1559246791106078, 0.22950967653624474, 0.127212914127496, 0.14321878912948793, 0.1085726619367638, 0.09559239756556288, 0.13883325751991044, 0.29142631217837334, 0.07803083547661382, 0.11562833938026622, 0.21805724429507412, 0.16531982819639868, 0.12417222688635512, 0.08532863500858508, 0.11449410790397276, 0.21467245334098417, 0.12756870068129034, 0.11113333380630902, 0.1428570424116427, 0.12511183372548512, 0.1321687062661494, 0.09426879681526654, 0.20346736024704673, 0.1324799218245091, 0.12312684628751971, 0.23660450873355712, 0.09902971916862073], [0.0635736531788303, 0.04163266520106024, 0.014196534288085759, 0.012306659538749487, 0.0331476898563485, 0.07498066406697035, 0.01413512563768534, 0.058278821168407324, 0.052764884181200504, 0.07205306672521176, 0.027075629088006196, 0.02998196174420657, 0.010529676463545091, 0.015204999982679804, 0.08265734004277377, 0.021876902807684197, 0.016497523418717807, 0.02568323555732927, 0.07798060309141874, 0.04651393613687927, 0.04771337318684786, 0.04632018867038912, 0.06249797763302923, 0.08895246837768825, 0.058621768088590716, 0.026102814252578446, 0.08299739881148262, 0.07565635361618574, 0.045865890870411555, 0.03348930378354365, 0.10034264065325262, 0.0755124516604889, 0.042844371149136175, 0.056691965794250856, 0.034756321279752644, 0.08840640856614036, 0.019774453023508675, 0.0363057341066099, 0.04429161465997177, 0.008785375656800406, 0.0350292286114587, 0.02967568745295848, 0.03992172656580806, 0.07006261708034624, 0.08155796556703507, 0.04660783936419795, 0.07954574370336148, 0.07488255118650776, 0.042069867749007485, 0.2160438886212726, 2.277472024002383, 8.10591822670352, 29.598179824890632, 43.750293408670736, 55.556121641589755, 57.41029662470664, 62.130567104585715, 66.61856266760057, 60.21338708939091, 63.69683227231426, 41.74402852212229, 33.92848237868279, 14.618005848700001, 29.789060008141306, 31.758970406747636, 20.12746995495212, 28.761532383580363, 45.84395262502855, 48.54895637881372, 42.78170331831902, 72.66495120140814, 55.73907667590726, 63.16905383140811, 61.17643094831898, 84.2290319934968, 74.07541198115196, 46.40619301026868, 61.19889436229583, 60.383233562592544, 37.30486646775277, 19.824258973521573, 15.292382874796468, 15.259550675269097, 8.93956897720214, 11.337898296694602, 11.854313631211559, 12.289779090112257, 11.174581589237338, 21.388898318813695, 33.800554275512695, 34.32849353359592, 41.45377312937091, 49.22859722568143, 72.83892400803106, 66.8548462467809, 62.43391144660212, 74.96437011226531, 74.4468447469896, 64.32668647458478, 74.42603265085529, 53.45369200552664, 41.17835606298139, 16.15159963407824, 14.621216308686042, 19.47197129649501, 21.909779271771832, 18.932168829825617, 26.452438946693178, 33.93967682315458, 56.88464410843388, 64.74263814187819, 69.49194200577276, 74.00339726478823, 76.04471637356666, 84.91659210574242, 78.47133774911204, 76.69425302936186, 40.53355763035436, 19.481098651885986, 9.01571100757968, 3.0635409922369066, 0.2635665748628878, 0.03166166505956602, 0.07330882272893384, 0.023542964012332024, 0.0690139193207987, 0.03972673803688057, 0.0020922612935875455, 0.023871077555081537, 0.041445720595337694, 0.08618632406597176, 0.08071703851343164, 0.020323379919113174, 0.01079746058225752, 0.05480750441370953, 0.020878707479325034, 0.0948877652145682, 0.015169751319673755, 0.036855356227005684, 0.03852442432675631, 0.049118428235693325, 0.04327105914032267, 0.019621392486677058, 0.06045142736946864, 0.054337344763259736, 0.09332708323434477, 0.05009064743775995, 0.06321818455152454, 0.08401564457604001, 0.021881353778524265, 0.04066632955425209, 0.023122330030967152, 0.06783621235480232, 0.06372431586045893, 0.04024102818220854, 0.07604326632234358, 0.11193832367538445, 0.047486132356308164, 0.0608060188261011, 0.04082478335007064, 0.014833524905806108, 0.028796421529184428, 0.006986444162565374, 0.036791778590169646, 0.029215896802563823, 0.06020008541283108, 0.057036736003694036, 0.05784916841695386, 0.009885033585071083, 0.04387205894736033, 0.06974706546433511, 0.027942873177028475, 0.12507316160706744, 0.04677705669535264, 0.042994290725478244, 0.05047550319784111, 0.04954363001630672, 0.035374642334758274, 0.08737419701872334, 0.03220358608110297, 0.03165868114710095, 0.04238555343040536, 0.024934357798267758, 0.045799880904415925, 0.0721362791955471, 0.020208767419981382, 0.047663803467707294, 0.019768395183247425, 0.05490305473006541, 0.023968012575360558, 0.048601943248462294, 0.03527019390716188, 0.03148847939296356, 0.057718481477950855, 0.023215442272504012, 0.015001257941607508, 0.013514109868406048, 0.015172340696857823, 0.08417619362233147, 0.02552461896782681, 0.08798832374234354, 0.04669497037426599, 0.07222389667144707, 0.05191134348992379, 0.0357332902269498, 0.03330056270163867, 0.04417379033721743, 0.05367254132344838, 0.050699905672621344, 0.058242577548709616, 0.028533178396643172, 0.03943230363450224, 0.03068278663821759, 0.11966451957461335, 0.03599998841602956, 0.04081510382914736, 0.03093770239502192, 0.05648575407723266, 0.05246774165800983, 0.05911486058105385, 0.03492127150116909, 0.10187221180287101, 0.04504959737401336, 0.02688830143832151, 0.02271122235294071, 0.25972485842724, 2.4396071174452385, 9.915178148977219, 32.72336552220006, 48.85579555265365, 64.51064955803656, 68.55345218412339, 78.10672990737423, 82.39168397841915, 75.8953760516259, 73.24681912699054, 57.938655576398304, 51.12664784154585, 29.897790070502992, 39.10256324275848, 31.91170357888745, 29.10435538138113, 33.32715165230536, 40.32241252160842, 53.52489479126469, 41.87925223381289, 56.533407626613496, 50.84549234759424, 53.82909028760849, 57.782588389612016, 63.05589345193679, 58.497012815167835, 47.335888877991714, 53.155529114507864, 49.32058072859242, 34.750564098358154, 23.061926480262514, 18.814595783910445, 15.3847066433199, 11.358992803481318, 12.354825715864859, 12.648387666671509, 11.888870693022206, 12.983613033448497, 20.600800014311268, 27.525775932496597, 28.453067387304, 35.24541424166772, 43.12526372171218, 53.87137736043623, 55.28906314603744, 53.277169658291726, 50.5484434097044, 63.062353595610595, 60.8235784499876, 58.1807364186933, 49.55233004785354, 38.544868884548066, 24.51770632497726, 27.257207324427945, 33.098873630646736, 38.6637088560289, 37.94626028307023, 45.58250704119283, 48.57624430810252, 68.79793351696384, 74.88833888884514, 78.81229369871079, 83.18112373352051, 89.37281254799136, 93.98275067729335, 89.54753844968735, 86.71510081137382, 49.219591463765795, 22.350641912029637, 10.527820010339061, 4.084045122708044, 0.2951527783466924, 0.06714942985244336, 0.06409577657318404, 0.049430570760441404, 0.06189013283038813, 0.11273348463639138, 0.09555603137179729, 0.012131302012881685, 0.03921510238621024, 0.09360084475408639, 0.039958717121231946, 0.048170999638856425, 0.005197310454076938, 0.019343007626312397, 0.05335174966603518, 0.034826774555709095, 0.08591113762269098, 0.0618514338988931, 0.007295599423213712, 0.010791295489686872, 0.026214475397981947, 0.05758938034095111, 0.04016682107542311, 0.0501593999985245, 0.037326584570109844, 0.027227356631849563, 0.03029276744552678, 0.08570116824440419, 0.038455158487082496, 0.031486512462217967, 0.06663536187261343, 0.04150689271609149, 0.046150454229885535, 0.00643475839282356, 0.019290306522781332, 0.044856183155770266, 0.04677254443747863, 0.03279042092242068, 0.02109480939144569, 0.06428224620439353, 0.052735581318096775, 0.01916938337437328, 0.05074890848669795, 0.04047971819677661, 0.014321507168783536, 0.05746986679432373, 0.0628598737380197, 0.07019216254834207, 0.039581721423253904, 0.04494165941592186, 0.025897213490679864, 0.059775795276847586, 0.043920372282305074, 0.024080955002817418, 0.029992365218218298, 0.20549963829257797, 0.35170891292152867, 0.12759421140916888, 0.08544124993345431, 0.13749378342782298, 0.18928598492376267, 0.25627844336052097, 0.12195710663593586, 0.11199293042262716, 0.13043832814981862, 0.22844996243234605, 0.08190743955633334, 0.14753937180484497, 0.103485792154266, 0.15700235031545162, 0.1251743618218649, 0.17013983891135262, 0.1354010763668245, 0.15464655333949676, 0.12510655537968682, 0.14395440207614055, 0.14285670533295602, 0.18175285850321093, 0.17556780168125707, 0.1739709067248529, 0.18897225659701133, 0.2730264124130049, 0.17128078897874202, 0.10578657635637831, 0.14433516309626643, 0.16724494586308158, 0.1394841258203791, 0.28359088746290056, 0.18087902797325967, 0.18207965628995051, 0.15357308029647798, 0.11800337282399978, 0.14785077122430648, 0.11402678660928242, 0.13247298106791514, 0.12433499758762699, 0.12502305179594025, 0.13492415599044294, 0.10656974804137023, 0.15853752922867576, 0.12592938743651877, 0.18312484536680484, 0.18397716414784232, 0.06895437896732362, 0.9613211416909773, 5.44393846104222, 16.083456297074598, 42.971396984592566, 61.50939310750654, 79.17284580969041, 83.01492506457915, 91.997497927758, 95.63083648681642, 88.2741331285046, 83.72572129772556, 62.814365663836085, 54.327945170863984, 28.836590859197802, 45.45588116491995, 48.479636330758375, 39.546610847596206, 47.94864939105126, 68.7590471390755, 70.99446865820116, 62.54124318399737, 96.59512765945928, 76.94410016459804, 86.62783591978013, 86.66146632163756, 115.338573609629, 99.82826678983628, 66.00124436040079, 81.2606450050108, 78.61113886679374, 50.521206471227835, 28.79924205041701, 21.907429772038615, 19.762230611616566, 13.222782496483097, 15.683487307640815, 17.139747642701675, 16.25083658003038, 16.25085815306633, 29.078132375594112, 42.84126058701546, 43.48051278821884, 50.81567056717412, 63.56816676355178, 90.70538290085332, 90.09980816994944, 83.26244231193297, 96.95769586870748, 99.26961929567399, 84.24438415035125, 95.46732856381325, 69.38758342496811, 59.528251001911784, 31.28431654745533, 28.16361019688268, 34.65215967547509, 36.960376462628766, 31.41280358837497, 45.823438629027336, 53.217051490660644, 76.846174270876, 85.1380491256714, 91.8864320939587, 94.39571349851548, 97.6855936358052, 107.6075819999941, 103.54635207883774, 101.86840918756302, 66.29646547379033, 33.163051451406176, 16.749769910689324, 7.892887928793508, 1.226546603345102, 0.21419024695792507, 0.18930170504796892, 0.20011427001126353, 0.15785816245742385, 0.16080306572539194, 0.15155759489824697, 0.14288520380373926, 0.18380552980928652, 0.1982423188465257, 0.1325957696404188, 0.19741489792302733, 0.191878748216456, 0.1968020735488784, 0.19026343650635213, 0.15726775381593935, 0.18139380841485916, 0.19889006150826333, 0.16142868376787634, 0.21162451124720036, 0.11854121251212013, 0.09303444530814887, 0.20683404088260668, 0.10253663985959946, 0.12581049825154966, 0.1161426142038357, 0.1193130614175912, 0.2302300136896872, 0.16984786748165087, 0.1486257764120256, 0.10557540422005039, 0.21639232073099385, 0.1301782259777669, 0.14114452946570613, 0.14142897791199147, 0.1825472763589313, 0.11741002240488607, 0.1372418630748026, 0.15746974055805515, 0.15460074128162477, 0.11104400795433791, 0.10682032007964389, 0.19509915202375383, 0.18792711348543245, 0.12777223492101317, 0.16113524144935995, 0.17005517087396116, 0.17508967088595515, 0.10312638966546905, 0.08744432470731198, 0.09376993568073358, 0.2656721522010142, 0.17995713308693903, 0.21218233050838595, 0.1379771389427685], [0.037703764129189715, 0.023901690428535786, 0.011500240915695266, 0.06651447319816198, 0.05356493661360395, 0.14578662392112518, 0.08969722841415675, 0.05827410589723338, 0.039422333000167724, 0.07658345023951224, 0.08201830013985596, 0.0057499777739717355, 0.08213090740384595, 0.012612351603175124, 0.02581647548433994, 0.09694975981068227, 0.03355536737569398, 0.08629294052239388, 0.029286120252142993, 0.035804976904464346, 0.03745772350098818, 0.00989711383402708, 0.030881270443299608, 0.025331271782277093, 0.048165736614816615, 0.034720732665230195, 0.024385260448100108, 0.0705637151916181, 0.06883488457289434, 0.028675684157098015, 0.04361299482444602, 0.05894300790743963, 0.04634699408685969, 0.023489358925050306, 0.046458877397761236, 0.04828322385888427, 0.04051024680055919, 0.05512489847117855, 0.021506579735526637, 0.02617789278437774, 0.052351476324181405, 0.03243062772878236, 0.11050773874646234, 0.03368328107641109, 0.0410377711147791, 0.026944871285870194, 0.0954752090957857, 0.15323849905642772, 2.727236238218123, 12.357904776450127, 40.99212977194017, 50.610471771609404, 63.77181622289843, 73.53030450882451, 68.72450674733808, 63.69108992238199, 58.63596277852213, 44.47127211478449, 42.37125473637735, 32.267672400320734, 27.632029018094464, 17.072647656163863, 32.897895305387436, 57.237061223676136, 64.1036997302886, 45.27298104378485, 57.53890722028671, 48.16248524573542, 44.293357326138405, 58.156747202719416, 43.78764221745153, 56.570650531399636, 48.67796313378119, 27.686102813290013, 19.75598031474698, 23.380503346843106, 20.389439175205847, 13.570590826772875, 9.908767034930568, 3.002237778517508, 0.6034860687871134, 0.417140451890807, 0.19665181306341004, 0.12510771217245248, 0.021838362839433457, 0.1058921892376196, 0.1543180241940483, 0.4669817032352571, 0.2922628801916876, 1.0493084235537438, 3.117673868133176, 4.95875156694843, 8.872554302215576, 19.761787383787095, 22.523159519318614, 42.332584088848485, 44.48304314767161, 36.09249322645126, 56.059000876642045, 70.98441954581969, 81.2509959743869, 81.00380036138719, 47.856826705317346, 56.52639050637522, 42.18570309300577, 27.723702653761837, 28.318518323283044, 17.416492431394516, 11.639593282053548, 20.050505207430934, 28.854720054134248, 47.86314956603512, 51.63513998831473, 63.83844160264539, 69.91995103897588, 71.19723950662922, 77.53589953145674, 86.08134777315202, 71.88647054856824, 66.67443290833505, 52.99520615608462, 16.810745116203062, 9.084636857432704, 0.44821340710886065, 0.018189702475924167, 0.03927907072788766, 0.056718736736764835, 0.0636517749949088, 0.07993391279371516, 0.06894964454395157, 0.03096529305161488, 0.04627163401774822, 0.04474054218360013, 0.07147401150676512, 0.07834337636708252, 0.03776957108188541, 0.05422962514022666, 0.07195065609149395, 0.08968474118099098, 0.010159878161615662, 0.056719069985011895, 0.03454492697792669, 0.0432083165393241, 0.08277345598945696, 0.03253150618665161, 0.04690131998711056, 0.02876903005545178, 0.05287048940156257, 0.07981732187251891, 0.019317550524588556, 0.1196844838259201, 0.048906332963416656, 0.011897266940063527, 0.11481057116461378, 0.05612811359066156, 0.038411303783857056, 0.05382122366779274, 0.01191278979662926, 0.03735036776971914, 0.03370073638976582, 0.015492573110086304, 0.03814821769934028, 0.0876051189017392, 0.11863610016242152, 0.054390055442889856, 0.08497836428784555, 0.051206006338038755, 0.07534988014207733, 0.043710157755882516, 0.03698931436144537, 0.04848804895675952, 0.006242006840634972, 0.01739765757754926, 0.08178295026863776, 0.02507291629069275, 0.021441969795212634, 0.021506169878487146, 0.027465868530975237, 0.03117208699545553, 0.03230324645917262, 0.031510872142990275, 0.12827075897685944, 0.014791068313042484, 0.0030072637826144217, 0.01997137783966478, 0.01975404444120584, 0.10339487283941239, 0.011256125083403483, 0.03380154973016151, 0.04516919135987278, 0.04484428964074581, 0.014729451861292606, 0.014916070879647329, 0.04586086150318865, 0.06156691650469458, 0.05348828951677969, 0.03409591135418704, 0.03102363447748846, 0.018864147132262588, 0.018375624354267796, 0.04962237236360389, 0.010389993737091222, 0.05636849282910267, 0.07267599579908195, 0.051308543376264074, 0.08130350946298531, 0.05772019751490124, 0.03091244256093858, 0.04779894137755037, 0.0681556556974688, 0.0695828545177656, 0.07134032916397819, 0.028984766160588593, 0.018606481119810094, 0.022243339898845842, 0.12455785256480018, 0.08833998874310525, 0.0288859561401149, 0.09640887875350253, 0.03570575319651154, 0.005067428386199379, 0.07385647600336422, 0.028336776435495387, 0.17908923207752167, 3.719213705870413, 15.246609795478085, 46.83588474027572, 59.44294729540425, 76.54939989889823, 86.98347722330402, 80.44630604405558, 78.95888051679059, 69.70513851411881, 57.27584561993999, 58.3282293042829, 48.36989625807732, 39.22698474699451, 27.700166471542854, 35.77655807618172, 50.63641825029927, 61.01556278044178, 41.887987352186634, 58.12470536078177, 52.95064018618677, 50.41975436672088, 52.9585123831226, 52.220373307504964, 55.022651841563565, 48.44729638868763, 33.22988079440209, 25.775653585310906, 25.232554366511685, 21.277422597331388, 14.93796338958125, 10.953354027963455, 3.9111619995486353, 1.0477682803907702, 0.5334366437408232, 0.177350212489405, 0.10368715836516312, 0.024736101904343215, 0.1315547174383556, 0.11400070131546068, 0.4337113320587143, 0.39857651737909167, 1.1089532101346602, 2.6576014199564537, 4.215142255829227, 7.194345180065402, 15.968766193236075, 19.10832835781959, 30.06185693125571, 35.96434547055152, 37.56999907955047, 47.83994874646587, 62.101490574498335, 61.87677798732635, 63.04068250040855, 38.24079498167961, 36.28219865983532, 40.560947541267645, 28.82351956059856, 30.031846877067323, 27.192970668115926, 20.88945900240252, 32.90195495851579, 44.643715197040194, 58.99423599243165, 66.29997207272437, 72.79233409512427, 80.5522963308519, 82.49466972966349, 88.29358023981895, 95.91513772164622, 81.807658749242, 75.98215456931823, 61.42971015745594, 20.539377658597886, 9.238414360630898, 0.679877414818733, 0.024619823163976113, 0.06095200454095199, 0.08131339965808777, 0.01598604098563233, 0.06765009129359838, 0.025274696189068982, 0.035638597929069114, 0.04023518293134628, 0.06167693056106087, 0.007444084978722517, 0.04016938746996945, 0.05344538476258036, 0.020406640269943786, 0.14081463668375246, 0.06739444009238674, 0.022394720787903475, 0.09287883752896901, 0.051447584504081365, 0.044323384326191685, 0.036947926461336114, 0.05230797785184076, 0.05881876376787982, 0.03429538532791119, 0.022610807378265648, 0.03246224034697779, 0.05492856545794395, 0.07632792927324772, 0.019827014315993558, 0.031713224692089904, 0.08031594551979535, 0.04023630141971573, 0.03500407411446495, 0.0911398639061278, 0.021793533289324374, 0.04361258879784615, 0.1317671076544831, 0.10699450549098755, 0.05179332764518838, 0.05923086544498802, 0.052727970234569044, 0.051610079413700494, 0.06479483563452959, 0.025189685327331388, 0.10247156069043184, 0.02490672117639934, 0.04486040813067267, 0.04801511989846345, 0.022981714592465473, 0.04754634686715661, 0.06611979236045191, 0.05331008980471281, 0.017642627597876617, 0.12743792947261565, 0.10100374388838969, 0.12092634299469572, 0.20724703888258628, 0.179454073790581, 0.4551644599245441, 0.17430179542110813, 0.14196134773233246, 0.11774284164271048, 0.10098433888126766, 0.188105933728718, 0.09911468598030268, 0.1520876511330566, 0.13311358379019847, 0.1139411609619856, 0.2388482270461898, 0.18540521332573506, 0.20584033291426398, 0.13656514696776867, 0.14092547428463736, 0.11170449065825633, 0.1404474967069203, 0.11502172031830396, 0.13214883394539356, 0.14001651096247858, 0.23343921729153205, 0.1232253498728237, 0.1960738150462989, 0.27618873143388384, 0.15786176307066796, 0.15288016909072477, 0.17207923645694412, 0.13541187820655687, 0.09398982589763981, 0.2214070556745414, 0.16719685086319525, 0.17227382278971134, 0.1447639578292447, 0.0989849336685673, 0.23448563210906523, 0.15643765158470602, 0.09800170578302876, 0.21142051735472298, 0.10974162783954414, 0.08991747103150814, 0.13740801222382054, 0.16878582447046236, 0.6248490740695308, 6.7127305846060485, 24.711806774139408, 62.66529990780739, 76.24416105208859, 90.38343475710961, 97.22302067664363, 93.678406130883, 91.35020486770138, 82.3266746151832, 63.75237303395426, 59.20866804738199, 49.84864942489132, 44.72473567531955, 30.16785506279238, 52.91993587247787, 79.43206740963844, 87.75934557760917, 66.72120325026974, 83.02335031570928, 67.81738019758656, 64.05983194228142, 80.85721354330741, 66.22348585436421, 78.36013070998654, 65.60023300109371, 40.01684027333414, 29.725017509152813, 32.58470189186835, 28.78664928097879, 19.397724751503237, 14.908559341584484, 4.307007597338769, 1.2905410532989812, 0.9321501069972593, 0.6717028889444567, 0.32697787868880457, 0.22083815878197072, 0.29914857038567144, 0.46132322460893666, 0.8703223988413812, 0.6915619717009607, 1.4237359190179457, 4.575944908203618, 6.805834414497499, 12.26612033382539, 25.63197716589897, 28.392007850831558, 53.406956964923495, 57.13979821051321, 48.057016634172015, 73.51540734691005, 92.64173938382058, 102.88420892530873, 106.12582037525793, 69.01811184421663, 75.02498642090829, 61.01942239269134, 42.499327967243815, 42.5792815608363, 31.769737312870642, 24.48996928430373, 36.54789609293784, 46.40060363277313, 66.16540339685255, 72.24491242439517, 83.25214216786047, 92.95208515659456, 91.9557874433456, 98.98364713115078, 109.62988545817714, 98.07103710789835, 90.71260006197038, 74.29611590600784, 31.722845377460605, 15.714044532468243, 1.2989773360952255, 0.11801685597146712, 0.15673138501663364, 0.2251498395156476, 0.28720044861397437, 0.1765226077048048, 0.11483522387401712, 0.13327694437917204, 0.2109023967697736, 0.1457160212580235, 0.17957122395596198, 0.13196345598947617, 0.15595742170849156, 0.15395128258293675, 0.25518597133698007, 0.2602900168107402, 0.12713840441598048, 0.1814790586790731, 0.13067200028848264, 0.11165313212381256, 0.1028185831983724, 0.18352592303868265, 0.1359356831639044, 0.18415270553481194, 0.21266881166206253, 0.1820064182843893, 0.09861087591777887, 0.25759544043291, 0.09045695014778646, 0.09993079944603867, 0.2815801211662831, 0.10867403835178384, 0.09770896826540271, 0.21710921048877702, 0.13693604077542984, 0.12211278336302889, 0.2964004904272095, 0.183184293789729, 0.11872534940560019, 0.11287554798106994, 0.2594588114128959, 0.16736558938939727, 0.21300949096199007, 0.17077031395127698, 0.17172496675723986, 0.16118246310901257, 0.19190421297905907, 0.12104009172969288, 0.09847036007070735, 0.07534789597435344, 0.11950409310238978, 0.1234656027067573, 0.11018183728259419], [0.06364190012156483, 0.03945101916249241, 0.04467961138054248, 0.025442281752944957, 0.061360781396468805, 0.040562693179855426, 0.029441187939336224, 0.008476748518014868, 0.0766202071381192, 0.032330373632571394, 0.02762569553939806, 0.019864665622252132, 0.04706987082177112, 0.05854897824446521, 0.04851665851029177, 0.040159171687499176, 0.03004008866546135, 0.03331288905634034, 0.0942424816950675, 0.059780177299774466, 0.0720008118678966, 0.06466250926736863, 0.08594247061879405, 0.03212982330531363, 0.03549725853747899, 0.050930976942782445, 0.008049018647251351, 0.029326968060265628, 0.021224416146475463, 0.04545551672157261, 0.04271231291274871, 0.009590659512116784, 0.025546858500268672, 0.03156917526446764, 0.053226727947232225, 0.04164027628458796, 0.03898552881794111, 0.033592093630783984, 0.041642524752645724, 0.030906934388763005, 0.06723398297664619, 0.06201565633678149, 0.012024952729623164, 0.06061813576267131, 0.028195004204228043, 0.36948739280623777, 3.935460347321726, 18.31633121736588, 46.798783040815785, 58.895619761559274, 67.92881473418205, 71.84498756162583, 71.18072632820376, 52.22495071349606, 54.26089617513842, 41.20315720958095, 36.41862653916882, 37.629999576076386, 19.81635735880944, 25.753751070268695, 37.1633630414163, 59.093668076299856, 81.95506142031762, 65.12966625152096, 50.0756722880948, 61.271128731389204, 52.42058284821049, 40.916012256376206, 40.4092812538147, 31.77994724242918, 23.153201995357392, 14.445129344540259, 6.794460031294054, 3.848098377066274, 3.290175540793327, 1.5697728698292088, 0.9127388485977728, 0.47039254117877255, 0.1698039553218311, 0.07750635636189292, 0.08760031553045397, 0.02871720995303364, 0.05293666790690153, 0.027169319725925886, 0.08309707451131075, 0.06881224667473186, 0.02009879741367073, 0.01675504770490431, 0.05319538729024991, 0.06932791577832353, 0.07903834834935204, 0.02373324684618462, 0.13670739417354907, 0.16987373060997457, 0.39629792674414577, 1.5972586336635775, 2.000973854334124, 4.421542277259212, 6.708205150019738, 13.614057552429939, 33.82590847630655, 43.535343600857644, 64.84674961336198, 84.94967337577575, 70.98969905607163, 96.22341248296924, 90.47916412353517, 51.97411906334662, 36.17940118235927, 23.906289223701727, 17.25826794101346, 17.49049186706543, 21.617258710245935, 39.27038185058102, 60.72221263762444, 53.345752300754675, 58.14778458687567, 67.49096055184641, 81.0919987770819, 81.06990014353107, 86.66564756824125, 79.2373295753233, 45.731262929977916, 20.512809484235703, 5.409570163296116, 0.40330772318186303, 0.04983180931078331, 0.007239167471491402, 0.07201121534190832, 0.009112833236764756, 0.06926902659958409, 0.015976279110257185, 0.05433179445624833, 0.03071476506339687, 0.04710452480902595, 0.016922729029770822, 0.016230633707656976, 0.05159047905415778, 0.014349316160434918, 0.04249740992822955, 0.04780845618956993, 0.06253697916925435, 0.04436840348306202, 0.05633711769816376, 0.02572726071511786, 0.05073572028308146, 0.018187511464460723, 0.0500756589275214, 0.09027603082358839, 0.07707281188378412, 0.06836669759884959, 0.07162616422940647, 0.0019511574740341355, 0.05256866991159417, 0.02392751142202366, 0.022441208918368625, 0.042302838917220795, 0.05573390772746456, 0.06394732788565659, 0.06096196751440726, 0.020909021578488812, 0.07664580979654867, 0.027498779668202324, 0.02606966754331464, 0.025859089125128045, 0.04995538695384899, 0.02371875054743742, 0.09983972691360021, 0.03583018885805242, 0.04297335354250766, 0.022048037273869402, 0.07226366429559647, 0.03638717308340054, 0.042712519756488265, 0.09408732590776298, 0.01563900602876299, 0.10154013567033315, 0.03234962925254818, 0.04989832872524858, 0.019154611283973343, 0.03303952207187972, 0.0908237990112074, 0.08196132618092722, 0.004969478299420688, 0.014967354720518475, 0.036801067406251546, 0.012461447603850356, 0.022056818556701465, 0.020654086669486378, 0.019980423422830722, 0.03163733027665125, 0.011801793232500073, 0.01561178979764302, 0.003857885678899625, 0.066926758736372, 0.05805032395367181, 0.0066052953104278255, 0.009109122498381523, 0.007153875072441635, 0.026713830659226067, 0.025353363842793533, 0.058186151342646736, 0.021932162644882357, 0.0372990322179131, 0.04730611318542112, 0.07421315121915072, 0.022774874683349364, 0.015116825177814933, 0.03351296057864543, 0.02091914159996856, 0.040724693962763396, 0.02780126756988466, 0.05340394706675603, 0.023386758684571234, 0.04565734641566392, 0.038783702954289415, 0.01991704879929462, 0.07095877141241105, 0.06885233605580945, 0.017903589703623327, 0.0952987790468239, 0.40137852992742296, 4.398935696771068, 21.056665720478183, 51.51735905678042, 69.59910115888043, 81.07455991929578, 82.7686002177577, 82.28123003436674, 64.34556484222412, 69.31773385693951, 53.8367820555164, 54.02492246320171, 49.42676321152718, 32.646126208766816, 33.59753631776379, 41.85800867695963, 46.5200045031886, 63.701280240089666, 63.30816853430964, 52.18226748128092, 54.7704787408152, 48.30452995915567, 43.74119350987096, 43.820017460853826, 37.72909825847995, 28.650945078942087, 19.983697437470962, 9.895578065226156, 5.290253623839348, 4.200919251288138, 2.1845934852477047, 1.647167607180534, 0.9978567941054222, 0.2244146708999911, 0.05784082571945845, 0.0037174031087723112, 0.09900056952310186, 0.024084042337152268, 0.04846598945497986, 0.07010503536871365, 0.058298988433014, 0.036428706540215405, 0.011045891404782814, 0.08724601518723273, 0.04397152397300928, 0.025389019490009355, 0.06733077052499979, 0.21483685580953477, 0.3764532770841353, 0.6029487040735061, 1.494138663814914, 2.1840673973483424, 3.4263151259191575, 7.978625057205078, 14.840488568429025, 30.588417476223363, 42.562262396658625, 55.18496344166418, 68.09529581377583, 61.03187984035861, 69.09965007535874, 73.84936578812139, 46.752624588627974, 33.15703845793201, 27.9738929963881, 26.169022206337225, 31.65278596262778, 33.22703315365699, 54.93174699044997, 71.87087520476311, 63.985071566797075, 66.89479166461577, 76.73399448394775, 90.81301273838167, 90.56882166093396, 97.52410181107061, 89.04935821410149, 54.5644562475143, 24.59940537329643, 6.384286505560722, 0.4791622254396639, 0.00934712877947717, 0.006339381403860546, 0.05106402343259223, 0.014452043763031403, 0.05749274984062199, 0.05096932730427192, 0.0496099349261532, 0.02037303390792541, 0.027759280205974658, 0.07286495904648498, 0.026436650472122337, 0.029652187705881176, 0.09510944807721723, 0.08743594370542035, 0.01585788213677945, 0.06777327823182268, 0.017104324426562074, 0.0484443398102397, 0.00578230093871694, 0.06275214645410739, 0.009816393064665458, 0.05438168593231709, 0.05911627401327414, 0.020067481654545954, 0.033929340856810736, 0.031225690167517434, 0.051890187971894784, 0.03649081328823682, 0.033692696297000495, 0.02921388965220221, 0.04536722125785966, 0.04489917984052051, 0.039163724699568365, 0.01586953337649785, 0.028072719334534584, 0.035060580759759874, 0.03804867223445927, 0.07598243894115572, 0.09168230012179383, 0.06859950405815918, 0.020142081381392576, 0.05562744065818768, 0.028903068629123514, 0.0568692462008086, 0.034138210898926186, 0.08681517499949663, 0.07368099590342853, 0.06533104355537123, 0.11834394487161791, 0.025800123337596178, 0.29369255347597983, 0.16011062949415178, 0.1414038195845581, 0.21378982812166217, 0.15086033231308385, 0.10854340503893553, 0.17102307700101407, 0.08368294025140424, 0.16023991449225336, 0.15895734541118145, 0.16573449626805323, 0.1425315622961329, 0.1396224659777457, 0.1533019771018336, 0.12979363451801962, 0.18483383430828973, 0.08808240700032442, 0.18356211303222567, 0.16145955711122484, 0.17533465048238156, 0.08140288638852297, 0.2465525741178182, 0.11581837515076322, 0.1959473339300002, 0.18879290009217878, 0.15386109871249046, 0.1650508547261838, 0.16430465444441766, 0.21143999130975819, 0.1839737933609755, 0.1139497334858583, 0.07591293178378575, 0.16397589547259195, 0.10313585851221316, 0.12864413490939525, 0.12235348052795857, 0.1358085432119908, 0.11314837487354396, 0.13029896143463351, 0.07599012280303626, 0.1492509807670309, 0.20837813705926944, 0.15127595033376448, 0.2084027744469143, 0.2164314218586491, 1.2382644390867603, 7.969213820272877, 31.77792722179044, 66.50683003087198, 84.03905591657086, 92.48545646667482, 95.16483537612423, 92.19253386220625, 74.07058746584, 78.91465971546789, 59.62933440362254, 56.295488419071326, 52.08318448835804, 30.529579962453536, 39.744953340099705, 54.492708252322295, 78.68931954906833, 102.30117213341498, 84.29441005952897, 68.58268168664748, 83.11361974285495, 70.61970187771705, 60.380880140489154, 58.22659284837785, 47.4631933243044, 35.82585834687756, 22.50149626885691, 10.885468586798638, 6.2960062103886765, 5.700924800288293, 2.979749849727077, 2.0699864866272097, 1.3554112949678976, 0.5577712121509737, 0.20748060376894092, 0.4381063784803114, 0.23206373706700342, 0.13832204704803808, 0.19460493338204202, 0.28756207275775175, 0.37607289910797154, 0.23038710767944015, 0.08620317033942669, 0.2954969663293131, 0.24837359575734985, 0.23623156181025892, 0.2229406717684, 0.5215662032846482, 0.6763781703287556, 1.1691163624486616, 2.407811894532173, 3.1991289940572556, 6.051419463849837, 9.908610140123676, 20.019820505572905, 47.18372052715671, 59.81916535285212, 87.61424926019485, 107.42698823252033, 94.73041719005954, 118.70307291707685, 117.2564478843443, 72.05042562177105, 54.34646268044749, 39.003821496040594, 28.918119284414477, 32.260663124822806, 38.08215079769012, 58.77425770605765, 79.24887703311059, 75.79049187321817, 79.36267283654983, 86.43908362234794, 100.87183690840199, 101.25625271950999, 109.56232655432918, 105.18064683483493, 68.69314347544025, 36.02506768318915, 10.300406871303435, 1.440036308861548, 0.17496444615385226, 0.09007980506266318, 0.08571026936894463, 0.10704030222710102, 0.17923169378792086, 0.07892790911418777, 0.13714096929517486, 0.1600767224426231, 0.18546699065594904, 0.1620969269424677, 0.1337921997952846, 0.12006811767576203, 0.16933115649848215, 0.10605474543427268, 0.10506410947850636, 0.13120784814799988, 0.14998290116988844, 0.1169342281777532, 0.15830307568032898, 0.11728137325976165, 0.1578948427472384, 0.08708289974639494, 0.2094364109178705, 0.14521196604736392, 0.1415807858950669, 0.1870363217688376, 0.1750657536209591, 0.19168356433510783, 0.1481891216169442, 0.08462745005324965, 0.20294533261368353, 0.3161432197497737, 0.08828725125039778, 0.13495984036595593, 0.18764261907387167, 0.14887844753121177, 0.11780894736969665, 0.21223280038083756, 0.2065596435098879, 0.12331875897343121, 0.1993432484807507, 0.19517268114272626, 0.1347585277812135, 0.17833083567600097, 0.07747711478582314, 0.2702057073193212, 0.18184508016753584, 0.15932781020960501, 0.24901395333149742, 0.1413839166202853], [0.031465211387483344, 0.09201288238287934, 0.008927107668451725, 0.00583143255132581, 0.016119934002598448, 0.07977514107140803, 0.07542894807674232, 0.015185590187508254, 0.053229505015957745, 0.03981301485891304, 0.05896612078011517, 0.05849926679905865, 0.07129499974149851, 0.0960087433697716, 0.04918623084743177, 0.052717731469461036, 0.05852324152064901, 0.07377662665901646, 0.0070822539912056065, 0.08623881641054347, 0.06361931584955705, 0.0729769304574978, 0.04612581684224067, 0.029582483280870705, 0.07111237970210853, 0.043068287158084494, 0.09199235888738787, 0.01701562293624926, 0.07064564063424064, 0.050801121209177284, 0.04648138889141622, 0.09280397541700833, 0.08009993170778598, 0.019727267753032428, 0.02081548990381341, 0.034609649916209524, 0.010154201450096744, 0.029145244343747056, 0.07259681295122832, 0.03237985525160067, 0.07172027047002508, 0.11753995857772329, 0.01857063586583301, 0.1823397584620022, 0.7681364433900003, 18.02711525271016, 49.44209967890094, 70.91074958924325, 68.89880118831512, 77.42754013307633, 69.55921849896832, 66.18212053852697, 40.73139805947581, 35.32884305523288, 24.133627837704076, 16.784794715143022, 12.729806265523358, 15.687331230409685, 25.85648382863691, 42.93413054558539, 58.46113489520166, 66.89162238951653, 62.42076758415469, 47.83285317882415, 40.7842049291057, 27.43660673018425, 24.771609190971624, 13.325493681815363, 6.606163709394394, 4.346659327706983, 2.5182989335829213, 1.5037694309026965, 0.5795824095126122, 0.12022149613908223, 0.08874937080808225, 0.029582889307470574, 0.0482144329937235, 0.053027426343291044, 0.032746083583802946, 0.05480363183925229, 0.060127912269484614, 0.03987547017694001, 0.09312371753396527, 0.039057081430068905, 0.00620723746138655, 0.03575421591860152, 0.0725370887366514, 0.06548698841323776, 0.06674685064823398, 0.07722315663892416, 0.025565823006834236, 0.0651051395482594, 0.06677544871044737, 0.10459720953217438, 0.07541925706450017, 0.1398577315792922, 0.03822532061847948, 0.021593061486078848, 0.04076449606086939, 0.3771942986115333, 0.9060902472945952, 3.8336412560555244, 9.429190601072005, 16.98787150844451, 25.542043101403024, 42.23409337382163, 56.415920872842115, 76.33536400333529, 87.19368488557878, 61.1545519674978, 60.81785963427637, 32.38245075748813, 31.827866838824367, 12.433720269510824, 26.719122855894028, 34.09647357079291, 38.57969168693789, 61.27878912033574, 64.69946069102134, 62.837044808172415, 65.12501824286677, 68.76932374892696, 84.17043178312241, 66.10041756783762, 44.26367675104449, 23.319141787867395, 4.751976468870717, 0.34018535707746783, 0.00666299322244501, 0.0507392711006105, 0.022118729952302192, 0.05071420087328842, 0.04089543580888741, 0.022837502371159293, 0.0489992096329168, 0.06605311972840179, 0.014599910223736398, 0.01962427489249216, 0.028761466852419322, 0.11083020813642971, 0.0231483789356125, 0.01519605782138364, 0.05576075527877097, 0.050871463402384715, 0.07566812838758193, 0.05860403315314363, 0.0919360054596778, 0.017359946899476553, 0.04088962503198174, 0.03278240764273271, 0.020482576820218278, 0.011897261194404096, 0.04782228024616357, 0.017413195755873478, 0.059796770764214385, 0.023961418473552314, 0.030695681813203042, 0.010493050757495147, 0.04181557635386144, 0.04664703242240414, 0.0368545365129267, 0.055223348430327834, 0.035209255443224986, 0.058168362781044945, 0.021007925444733233, 0.04046132059527501, 0.0630314199764642, 0.07731853458549708, 0.034980497758595214, 0.012793194318580772, 0.044652576137694626, 0.04810773609806934, 0.03548732237710107, 0.012814356539879116, 0.007609312907011519, 0.012658986247955792, 0.02019404321007671, 0.041131471328797846, 0.0410674991566808, 0.01784837008604119, 0.058238777752605185, 0.028274543282966462, 0.04441878142496271, 0.05283417300351205, 0.06187663053072268, 0.04586921952244255, 0.060925130176568226, 0.018824498251741453, 0.037169597832666296, 0.078750659351147, 0.05385600788999469, 0.017028935629153447, 0.07010756345886378, 0.02575265652980776, 0.015822627728113967, 0.045934915392389225, 0.09040437353354308, 0.03058765767022006, 0.04611284314324299, 0.05515977845437104, 0.03669064349284576, 0.006435661418964306, 0.025664472148843834, 0.024966546897626212, 0.030586906904054266, 0.06671285932703365, 0.016895157525375966, 0.0713831764615832, 0.037885445710872455, 0.04495986932588201, 0.020841287914663557, 0.057872557081282146, 0.0332719493176668, 0.05766926798969508, 0.05205971556865881, 0.021237075749424197, 0.019319714722974647, 0.052890974592657826, 0.07241688954133181, 0.3240841807376954, 1.55876032527416, 21.729411040582967, 54.82498007435953, 79.19898448451873, 83.42902537315123, 88.23604691413142, 83.88136094616306, 77.43895423027777, 52.006094224991344, 47.48553122243574, 36.325693822676136, 32.66376314624664, 25.374495137122373, 29.196625217314693, 28.937048642866074, 44.918504684202134, 52.621737680127545, 60.20651509684902, 59.45627158687961, 49.97797781421293, 43.539332651322894, 33.36284129850326, 28.067643527061712, 17.554646153603834, 8.628889802963503, 6.143430423352027, 3.6668297167747252, 1.9778154453923626, 0.552140711055648, 0.16016739660934096, 0.07313665978971028, 0.10828140296883161, 0.061617823047263015, 0.06748421027535392, 0.04544235916147309, 0.057425111937787265, 0.04928047115343714, 0.08411187288020888, 0.10510516413036855, 0.06251791890169825, 0.07930526870392984, 0.2030814204725527, 0.08969377335761824, 0.13441778719425201, 0.07365018384711397, 0.05015738135684402, 0.11337295354854678, 0.08896555315943495, 0.017253071888379993, 0.1282299954384085, 0.07379804647737935, 0.12383640458386753, 0.12268825328998989, 0.026129661803884853, 0.15787710015091205, 0.16167436816519307, 0.7781841461696933, 3.7965231316704906, 9.33741988674287, 16.47049911560551, 24.86377900646579, 44.4338801599318, 50.30618998312181, 62.12884910645024, 68.72770740139869, 49.93411394857591, 41.311748027801514, 31.295497263631514, 43.46720418622417, 31.45972690274639, 46.08402129142515, 48.782447230431345, 47.827408929024976, 71.60966104076755, 76.71741070285921, 70.60611478744015, 74.4115355706984, 79.06567096710205, 94.88935162944179, 78.14872280243905, 52.589523253902314, 28.585112017969934, 5.080383775695678, 0.39154174647504286, 0.0603217899709219, 0.108582827923519, 0.07166724952478563, 0.06157388790480553, 0.06343578416553718, 0.023354420198067542, 0.07301709644736783, 0.07793761023710813, 0.06586352828890085, 0.06092886102475947, 0.05018707492478913, 0.02256549902320389, 0.038574204720076055, 0.1131691818215674, 0.02330535035129757, 0.059238779133245836, 0.04405420784267687, 0.05406794994468651, 0.05080489419220437, 0.0533329077335375, 0.03695196374469707, 0.08092794251898605, 0.02227848418237221, 0.04760154733254064, 0.038545196800823175, 0.06656422294796475, 0.0585835900968842, 0.017019968569999742, 0.07115122035986955, 0.03591576470963417, 0.03743642242625356, 0.02529488069065396, 0.032800935479181434, 0.07149566881238453, 0.028794611646463315, 0.03267840737657201, 0.016044833445771328, 0.07142886594538728, 0.049534172660881476, 0.0052615928918033125, 0.032898672976561134, 0.04586671058449053, 0.04399267566059867, 0.05248417807442527, 0.01808433091237901, 0.024683605729331894, 0.055281720499718384, 0.03914603189895711, 0.14719941262756625, 0.24434642475699228, 0.1438629771432569, 0.20970291758496917, 0.12893163238561925, 0.1122590157413675, 0.1240444204379474, 0.1474065628022917, 0.12000487711761268, 0.10705097383188625, 0.2309218830158634, 0.15978156408715635, 0.20525585379331343, 0.2332131141015599, 0.19179263993376688, 0.08735298404410001, 0.10357492648425604, 0.10122451510640884, 0.16036789714088365, 0.20646544533871836, 0.1838689159241415, 0.20659387231834475, 0.17715277630955945, 0.1466531766157958, 0.15884203385681878, 0.10816930132287164, 0.14939889702345097, 0.12829848369883914, 0.1844814185413622, 0.12669153766886843, 0.10445764363412896, 0.18526544824482935, 0.20251264615404993, 0.17744451791288393, 0.12440346286541994, 0.20278793218876087, 0.09751324046162829, 0.1755406208817036, 0.2327614746266796, 0.13222616286047045, 0.27419938495562923, 0.1460644074024693, 0.1456683246238578, 0.6026915436790836, 4.09137970978214, 30.98978381003103, 68.28495025634766, 93.4008199937882, 91.81338971660983, 99.31108659313571, 89.93351536412393, 90.55972960687454, 59.057103741553526, 53.79909984527096, 40.66097974777222, 30.17092431745222, 21.479622740899366, 27.646877150381766, 41.856247532752256, 62.09346932749595, 77.79332468586584, 86.7660523999122, 81.07492077735164, 63.74559910066667, 57.13864895605273, 40.241878417230424, 34.13188472870858, 20.164295127314908, 10.420785392484358, 6.945835082761704, 4.370288175921287, 2.848383789100955, 1.1914842912266332, 0.37704273577659364, 0.19952504114518244, 0.17102349068849318, 0.33505737901695315, 0.22938010042473195, 0.2584353485895742, 0.17750237287292558, 0.19094021390041999, 0.3425924666225911, 0.24200685352327364, 0.3156493075432316, 0.18326223557514532, 0.3619695575006547, 0.19285825291468253, 0.21354814270331016, 0.10794846115693932, 0.12899845057437498, 0.29596605728710856, 0.4324490336641189, 0.2354303717372879, 0.4445008530972466, 0.3846956477049859, 0.4011317270417368, 0.392989652651933, 0.15327283511719397, 0.2794333282978304, 0.8120703601068067, 1.4616746767874689, 5.8962465774628425, 12.575351172877896, 21.869763251273863, 34.14976289195399, 55.29045950981879, 72.47113120171332, 97.55348820840159, 110.59957381217711, 82.18533592839395, 78.43739355764082, 45.37054215708087, 47.00771593278455, 22.05494619184925, 43.19952203381447, 51.69871376406763, 58.390834254603234, 82.16674389377718, 83.35170761231454, 81.7876075929211, 85.74441617535007, 89.37157307901691, 106.80821080361645, 90.87087554316368, 68.66257252231722, 38.621617901709776, 9.128389916112347, 0.6598249101831067, 0.09209429454659263, 0.16716553318885066, 0.14589102638344612, 0.1381937119989626, 0.16051411268211183, 0.13686372207537775, 0.1835771896425755, 0.1661463604579049, 0.19501714997233885, 0.10807445963784572, 0.18517923270983083, 0.18193935494749777, 0.10158014844261831, 0.21590564039445695, 0.14678926447466498, 0.15047921889251278, 0.13054547320690849, 0.19379369223550444, 0.1386753821204747, 0.1105171463061725, 0.10952458746971623, 0.11721604894245825, 0.11534218255790973, 0.10539128264832882, 0.14888931065797806, 0.16506542571850363, 0.16858503282550844, 0.17173176961800746, 0.14377879940213698, 0.13927504510408448, 0.12360552866612712, 0.09915978557640508, 0.16037839254544628, 0.17276198933682135, 0.15245492900571517, 0.15552407641324306, 0.13086860909336998, 0.2197295989120199, 0.36334296928778775, 0.17055865917955676, 0.09926800315658893, 0.08848599744059386, 0.2120094857509098, 0.21754015026794327, 0.2282637877449874, 0.09605336799136094, 0.1438017667181069, 0.08824125533142398], [0.02149175976463143, 0.0391555696936144, 0.021940354040012728, 0.0140105894271044, 0.07743564644648183, 0.031649855814213236, 0.0595094150142564, 0.02467798838962711, 0.0054434985542039, 0.07433230087401406, 0.02338173123256814, 0.026667304224364703, 0.04246623398015096, 0.052578253671526916, 0.061647447667294936, 0.022984240767395785, 0.030318701436983484, 0.021754501109582283, 0.061744997473133195, 0.023052204257598328, 0.04927549924280855, 0.04804428103530119, 0.031238332533487873, 0.04465910320680949, 0.054021153463831836, 0.042608557794723785, 0.13704792025589174, 0.02329303165747514, 0.0346060301507673, 0.04263790279266335, 0.01797808026294074, 0.028891870338890343, 0.05276089669355462, 0.017485652351751924, 0.04053862652771416, 0.08565970756594213, 0.05953453503729356, 0.026124446660340316, 0.012587419271679416, 0.02871674646983945, 0.07735756676523917, 0.028045841139711203, 0.3569496284809805, 11.067221414658333, 36.35659425489364, 58.76223171910932, 67.27845438065069, 71.01274690320416, 66.82089421056932, 46.545743096259336, 26.076491532787202, 30.90509591564056, 27.246277639942786, 23.31435061270191, 28.460657173587432, 23.881403746143466, 37.95182220397457, 51.312419137647076, 79.70476627349854, 62.03200970926593, 62.177192318824034, 39.83095915086808, 24.94643315192192, 15.44536707862731, 7.843960283264038, 4.6064285885903145, 1.5785166909617763, 0.4858063221458466, 0.19252786983645734, 0.044383947407045675, 0.0997397141350854, 0.6152062947230955, 0.9868828603817571, 0.09822609293605052, 0.17905409928531418, 0.0354018499473891, 0.029526518642782208, 0.10807449794224194, 0.1041872222577372, 0.0579655065291351, 0.16301618648632882, 0.07276869243791989, 0.056573245148625106, 0.06895693004011147, 0.10943751391624251, 0.18121247540318197, 0.07958938773240774, 0.06157485700602974, 0.16749637591983044, 0.09350952707351216, 0.16001765706366108, 0.04784940741956235, 0.12126820973090588, 0.11913510685366009, 0.06730223374982035, 0.0810174905364552, 0.11015928365410337, 0.0578224549310342, 0.08283903311577537, 0.012223973753862085, 0.039409190761826696, 0.08291286866991751, 0.1525505214569069, 0.3719689048105671, 0.4897586923212775, 1.7073297789019926, 13.204612116659842, 27.138938057807188, 34.35013717220676, 61.275380580656, 84.9143014415618, 82.04043572948825, 45.0156343367792, 32.60062279239778, 24.90041002150505, 18.117616099696008, 26.58923552882287, 32.456638466927316, 39.16030445406514, 47.950406612888465, 56.01380340514645, 73.676679518915, 69.15897984658518, 82.38149366071148, 85.84636642086892, 81.67627503795009, 50.571016650046076, 11.95982244706923, 0.6901457509206188, 0.13732578034602827, 0.04781538928528467, 0.010589160318035754, 0.07613656050976246, 0.034052148581512516, 0.04156440293656723, 0.048793193268319296, 0.08020536072792546, 0.01635833864941472, 0.0052219157617899685, 0.04563768859952689, 0.023479957110999573, 0.04330919499719336, 0.021284900703317216, 0.030895628846220435, 0.053165291526144555, 0.09333283655465612, 0.05147118767302844, 0.09215668474714603, 0.01308082107214197, 0.018865627597176263, 0.04703404855043177, 0.07613915754782577, 0.00426540375619586, 0.059678984745856256, 0.030743644662922433, 0.031247115731539748, 0.03202244267618704, 0.05667250333053451, 0.04040479479778198, 0.03396647313850061, 0.04060904916015364, 0.017848919754126863, 0.03959320508123886, 0.03338215489601416, 0.05459229116358104, 0.044782998776363755, 0.04828803489104875, 0.021263116993190303, 0.021614956278954784, 0.06550767278719334, 0.048244839023438194, 0.047339767427934755, 0.017585264849326303, 0.04091344653598724, 0.10262085590511562, 0.04644476222775636, 0.028044184474574945, 0.009376714137502977, 0.04136829974970991, 0.058214975400797786, 0.023353981612730893, 0.06372428521694196, 0.061955257964831215, 0.10804497291364017, 0.05719768341570612, 0.025406689307982885, 0.04035204964419527, 0.06386253344375761, 0.01939412867349963, 0.029248903700781446, 0.052638766956665826, 0.02889659135572372, 0.024992218503968853, 0.003389714984223247, 0.0472392643531484, 0.01155001747857539, 0.027499708549810514, 0.03163928380085817, 0.01454871161014683, 0.006152985987418722, 0.03234454242873096, 0.04339466742690533, 0.041750064345016595, 0.06345773641500743, 0.042633447991383654, 0.0660003592530566, 0.04878005102997826, 0.023876260139889294, 0.08254375984711994, 0.03566617326390359, 0.017704866496064973, 0.0225152991967456, 0.040677732773005, 0.08665572911981614, 0.003269474851080187, 0.014342892513189827, 0.05924188561977879, 0.043392713902698415, 0.607825190790238, 13.60022629460981, 41.42283347345168, 70.48439579625284, 78.22910001201015, 83.56482567325716, 73.79565285098168, 58.00783441912744, 36.74106105681389, 47.612208089520855, 37.996494077867084, 36.49506961145709, 38.29193484398627, 27.85339778469455, 36.658510854167325, 35.72395124743062, 55.262920548838956, 51.17818778561008, 57.6354524397081, 41.21332399306759, 27.417326319602232, 16.881698831435173, 9.676668624724112, 5.647738931640502, 2.0236469925411287, 0.5750346664459475, 0.20828637504769912, 0.12971941591991534, 0.06021335788611924, 0.8210297890247837, 0.9950786528568115, 0.08727881141127118, 0.2560428866455632, 0.0349292541373401, 0.14066932512627495, 0.07722049831382691, 0.027962314573326902, 0.0665215288679446, 0.21849684086778473, 0.3012881313841189, 0.40368712056548367, 0.17452644304402415, 0.5745835938761311, 0.7760441255184912, 0.5773708056057654, 0.809615814397412, 0.4306276443023836, 0.2563964668661356, 0.3622500682550092, 0.062190358857474023, 0.31140861251661855, 0.08955763187259437, 0.08147378016503588, 0.02640361484560755, 0.27170711707684303, 0.011880158281494534, 0.11406862267082739, 0.09716109282547429, 0.07466518139887242, 0.11985827087154312, 0.10210396106084509, 0.044885129787989204, 0.6124288889188921, 1.7027152329683306, 9.5630895322369, 22.507644584102017, 36.12611578356835, 55.674875320926795, 74.01687452870031, 70.55064462846326, 43.799711350471746, 23.70284764997421, 31.260239078152566, 30.696215975669126, 37.915697174687544, 49.550141365297385, 52.288151864082586, 61.013436855808386, 67.07927642330047, 84.78873852760562, 79.90170063511019, 92.35775978334489, 96.81741622186478, 94.26263532330914, 59.82176196190619, 15.115508494838593, 0.538816787302494, 0.11931473148926613, 0.044278100868987466, 0.04563469319574295, 0.08416570587864808, 0.038964005577708447, 0.04927054648437808, 0.020857952242236466, 0.04788479302078486, 0.03227202071537895, 0.03653092948239177, 0.0032836568143759528, 0.02996037913215978, 0.030585233001939716, 0.012804464429556843, 0.012405458067904317, 0.04861466413844497, 0.03446680899228781, 0.03432424386001883, 0.061005308938723427, 0.051627952244973956, 0.034551055681320934, 0.033665404414698, 0.024275093174148953, 0.03416362969625381, 0.03270283792047732, 0.022824605280954032, 0.016837844572540735, 0.06424386519938707, 0.050936550232431585, 0.008036004728637636, 0.011030920131522562, 0.06783910050627685, 0.038489448582573284, 0.05082277468435707, 0.019273582823394288, 0.032979085395533236, 0.03682843589734647, 0.04359755815277177, 0.008752785318891608, 0.10070889962897187, 0.016939749588228522, 0.031620185228905855, 0.010717976087283705, 0.03544583105512204, 0.03995526972557268, 0.021545569780432892, 0.0778162619099021, 0.14552079141139984, 0.09417186371020733, 0.12449048279273896, 0.15168419858861357, 0.14614017349818062, 0.16144156936676274, 0.15330957669404247, 0.16336772891302265, 0.1328086195093009, 0.18777873757625782, 0.14022966726653038, 0.10131508202081728, 0.17693631050567474, 0.1565255065478625, 0.1806462291748293, 0.13028964580547425, 0.14139436605957248, 0.12848905573088315, 0.124404190648948, 0.07340532682475544, 0.10489324888875408, 0.1817106164150661, 0.1071431878353319, 0.06404339914180099, 0.16438714679210417, 0.11976813296637229, 0.21247658488010207, 0.17326463494570027, 0.15377598634410292, 0.14763318693205235, 0.14677674659798223, 0.11131102790034587, 0.341611904723029, 0.1646197617294327, 0.14864252309405035, 0.16152919450354192, 0.1080486118312805, 0.17501482409575295, 0.11551328063491853, 0.11372115583189073, 0.15034542929741646, 0.1316151617755813, 1.797693588079945, 20.668066701581402, 56.98489989003828, 84.70525480085804, 86.40682605005081, 90.43591607001521, 87.01512290585427, 67.18981665949669, 43.01028728485108, 49.505516559846946, 41.867716543136105, 36.66209982287499, 44.805163875702895, 38.75940684349307, 53.87347190610824, 68.3659315109253, 100.10724929071243, 79.93373070993732, 79.70264034886515, 53.01681841573408, 35.17536071039016, 23.668328831272742, 11.498705667834129, 7.547001069591892, 2.710065572492538, 1.1998738733030136, 0.5969062315360193, 0.5141295120120049, 0.1918956634378241, 1.32566073008122, 1.5967636795774585, 0.1754453348656816, 0.42225745957224603, 0.11238395702093841, 0.5154382966218457, 0.24465829915096685, 0.36482473655093106, 0.19279318140639415, 0.23823984598200168, 0.28952056121441627, 0.2922744021540688, 0.2509956389305092, 0.5395874104672863, 0.7318021801690902, 0.4820334616928332, 0.6449871966915747, 0.3935356894808431, 0.4682145532100432, 0.4329148151220814, 0.14777422371891238, 0.4224471122987809, 0.26874695333742327, 0.35138442872032044, 0.23614974361994576, 0.6847718586364101, 0.3641758600790655, 0.4090490925215906, 0.22933805751944744, 0.228681581455373, 0.3349526701194625, 0.49780096077630603, 1.0168102996483928, 0.9853217570531754, 2.8531470173789613, 17.348527562233713, 34.9074589052508, 47.804663104395715, 78.47117300956481, 107.79129797412504, 104.08009252240582, 55.32148153551164, 45.27581691741944, 38.83373183588828, 30.524839778100294, 44.216784815634455, 47.725803852081306, 57.3014194734635, 67.38919858009585, 77.69770514580512, 93.49188173970869, 89.09118636961907, 101.58061704327984, 108.03079789684666, 107.49996785194644, 75.25905778331142, 22.9177931047255, 1.6491279342482168, 0.23544619911380354, 0.11448254763719537, 0.11006311663696844, 0.2120892048603104, 0.19830383570684543, 0.10488623152336768, 0.14865842707935842, 0.16146211584489192, 0.14447528057761733, 0.1320194570167411, 0.1383133749327352, 0.17418341951504832, 0.1489300665355498, 0.15118044981312367, 0.19451513255555786, 0.15968914323997113, 0.19642289066987653, 0.1533057002891456, 0.13888475395018055, 0.16497933275757298, 0.12834447195693371, 0.10299341212357245, 0.2605055326655988, 0.1493106896598493, 0.1564221153216016, 0.16278934785194937, 0.10963586174071797, 0.10076722190264734, 0.1392293556202804, 0.09152210347594754, 0.1458539936931864, 0.11030133167702345, 0.13607460554809342, 0.14974081738581582, 0.08435132132182199, 0.07290771441353906, 0.11459232037586552, 0.10863099953219776, 0.09137629396131924, 0.12133104426245536, 0.15560883638118544, 0.1709134038537741, 0.1512387644259199, 0.1175748079173988, 0.11875873551734033, 0.1805352077128426, 0.17092370007547641], [0.05057777593573255, 0.03958641754222974, 0.03811545977969805, 0.07158267341794507, 0.07185101869606203, 0.05782908925245847, 0.0343823324768774, 0.0222230366536326, 0.04947122321614335, 0.05130134981065508, 0.019431199668155565, 0.05497572200012304, 0.08882194231714934, 0.0358972100601081, 0.03774654630932116, 0.06936655725322424, 0.049807983976338184, 0.023595109702117985, 0.025260123281529354, 0.05931226611738244, 0.046301124572393396, 0.015328976949076019, 0.042431978358616756, 0.020061617251485586, 0.05229976155885285, 0.09564194047162611, 0.029844427894380306, 0.028440001037632747, 0.0379994051200488, 0.08269079510242709, 0.040294049127447995, 0.047562292987300504, 0.053777583469186103, 0.02391271443376618, 0.035721572912147934, 0.019769733921895107, 0.03946588126822345, 0.07363925177243448, 0.12611274292031605, 0.09178788235951817, 0.601039674253233, 11.568890598512466, 34.818111235095614, 54.71001932697912, 73.34143454028715, 72.08990035518524, 71.05470841930759, 60.8487129980518, 77.29788226466026, 83.1935811811878, 86.68181557809153, 39.83941970332977, 22.505191141559234, 25.366452317084036, 38.05924415588379, 81.01156665432839, 86.10617637634279, 77.90566136760097, 66.18272458353351, 46.9579057539663, 21.172585487365723, 8.017680097010828, 3.0451906736819976, 1.7783185503175183, 0.30805317805178706, 0.12171380477206362, 0.1185946471448387, 0.007141856589324533, 0.01790471776809183, 0.09515887607009181, 0.08630951100419607, 0.7384825894428838, 0.8276950604011937, 0.033232258302309824, 0.03758411268673597, 1.9047638749884022, 0.3789312344404959, 0.16780705521664313, 0.08351201837461802, 0.061504465017107234, 0.1566121664138571, 0.13356623450113883, 0.31228575254640273, 0.2873623996011673, 0.18872880917643348, 0.31254698852858237, 0.27117946635811563, 0.4730049929311199, 0.13840650058081075, 0.25018672669126146, 0.06566481274222175, 0.20638880590277336, 0.1546087239177958, 0.048244773905964634, 0.13047759781681723, 0.17308756138288206, 0.05859361052693379, 0.14404139902082183, 0.07787094526593724, 0.12618084813678457, 0.04828454153011403, 0.11633398296732096, 0.08327633908559239, 0.041279437380932996, 0.025315821704064167, 0.20217958176808976, 0.0530192406938201, 0.06251077896224395, 1.7736414916092351, 7.823440403707567, 20.44941809869582, 39.484041198607414, 78.4764446750764, 82.61501589129048, 53.7342316873612, 26.15725313463519, 16.593463459322532, 29.49611975300697, 29.091595911210586, 27.399993365810765, 31.75929596347194, 38.36789938711351, 61.885215005567005, 69.60558875914543, 67.86440157121228, 81.12096940317463, 82.47208472221129, 70.99817137564384, 21.409122059422156, 3.0700359469459904, 0.1606525294482708, 0.09088422802667465, 0.07912317726520762, 0.05869728520572667, 0.03423916596558786, 0.08368833351039118, 0.0952230359337503, 0.053146001432211175, 0.04313315948351257, 0.0930381914780986, 0.01359930267602566, 0.0601754441947466, 0.056783137918119474, 0.04277137829171073, 0.00874363439863608, 0.009264540670800113, 0.015751283874945537, 0.04004412443347035, 0.04803416101382144, 0.06426222449649246, 0.08975344394604046, 0.0072340078693213725, 0.05458145484989209, 0.09438891174091447, 0.07271223175790041, 0.02434626657275423, 0.02916631559210439, 0.05840968047719329, 0.06722475927803787, 0.07829540394126408, 0.048738318390303084, 0.019062571565530474, 0.026125448320301312, 0.03523940100304542, 0.038186801717646664, 0.04477676665109973, 0.030484660979240175, 0.04652869865118016, 0.021119655538049918, 0.02964491178582032, 0.07981079480340404, 0.033785155448581905, 0.038605549207497994, 0.06204353044590643, 0.010191304045879554, 0.05360294223552751, 0.044924545011693434, 0.03255798601575437, 0.012729567843639563, 0.0325255268704026, 0.08134766677094084, 0.08270529714683372, 0.04485472375827451, 0.067922274672216, 0.04112456504616045, 0.016632107830035592, 0.03518067270277008, 0.026469011941263755, 0.06824259901599539, 0.010771653952918226, 0.009971962539449094, 0.09213750190552204, 0.027824935856305306, 0.04743016580299986, 0.025518289166352442, 0.025294183550642866, 0.00449378174849816, 0.0471651874813101, 0.01782091924049441, 0.04599202724714433, 0.02611683557681259, 0.07619632302873558, 0.01465358808937092, 0.0213418823231252, 0.05382022392305155, 0.06587174075144915, 0.05795031117515699, 0.07924805725774459, 0.03132644222087918, 0.01699947571802524, 0.04372594682800193, 0.02361189851897859, 0.05705027277731607, 0.09282933292730201, 0.056716066920348716, 0.053316134238435384, 0.6495853177001399, 13.842709179847473, 38.814096450805664, 63.92847568758073, 84.36204741078039, 80.25790675993889, 81.24682257252356, 70.71416824094712, 83.50195007939493, 81.52284760628977, 72.43478651969664, 40.487281507061375, 29.89762729214084, 33.582572475556404, 47.76323503063571, 63.77705650944864, 66.61444417891964, 67.89836929690453, 61.90423065616239, 45.02152181440785, 22.65573955351307, 9.454563433124173, 3.8767037324367033, 1.7031702279083192, 0.5058936684602692, 0.1290033535370904, 0.05022573938232757, 0.09092585724448005, 0.04542463571734486, 0.06871149079093049, 0.014087729693029918, 1.2333168594106552, 1.384399694300467, 0.04860882654846196, 0.08441699037869131, 2.0044548352879863, 0.8941426464626867, 0.04660436898590096, 0.12157772457407368, 0.02997950260196963, 0.6123446805342552, 1.1959285817800032, 1.7669208780411751, 0.9391113334605772, 1.06906074429712, 1.4789497756188916, 0.5014144442975521, 1.2522163097896886, 0.716431208195225, 0.21608628392700227, 0.19344031119779234, 0.20560408672017438, 0.10041465291813498, 0.06421062847479217, 0.25371091500405346, 0.20731964869604957, 0.3180599717363235, 0.4727368315141048, 0.13059015145465253, 0.029246664808822737, 0.02436625763713833, 0.0778527353559771, 0.03711299159594121, 0.030127727208779227, 0.09678311270451355, 0.026114259606167197, 0.04788532928233186, 0.14936908088143797, 1.7913557733258896, 8.499761454520687, 24.125316335308938, 42.1397642935476, 55.93021377440422, 56.56030331888507, 47.21087117348948, 22.673411792324437, 24.64656402987819, 32.925049874090384, 44.57251241130214, 39.26946401596069, 49.098821686160186, 56.85182955957229, 72.1189494286814, 81.5334850741971, 76.83863547540481, 92.46094165309783, 95.42631626129152, 86.12375643945511, 28.518061061059278, 5.140257285487268, 0.2213777757940754, 0.09845443310276156, 0.06685452430599159, 0.027248119529817375, 0.00813026131401139, 0.08302094835427501, 0.039648727303551096, 0.044227224969935995, 0.008766079817207591, 0.06160731232094188, 0.0021158508165934754, 0.045803558126452475, 0.08627619384036911, 0.021849771803845803, 0.016231987768063144, 0.08622140323202457, 0.006754197426245458, 0.05445881949497327, 0.08523284337453305, 0.03304665052001515, 0.034445362360847574, 0.035647660749213356, 0.042267162202587055, 0.01915938784218123, 0.05169871578653974, 0.042930077235665054, 0.02961527375924972, 0.014798562568161758, 0.054134771963881875, 0.01345865180595748, 0.04681265680119396, 0.031638870113379056, 0.008199871893251135, 0.05832325043757597, 0.0492025408593397, 0.03259277406839594, 0.0608659920192534, 0.09498082191473055, 0.08442629834697132, 0.09461272432799302, 0.053792430253158656, 0.08494575192490894, 0.027449895597753987, 0.043496342616215836, 0.05643648313238256, 0.03567273863741467, 0.10584367288937492, 0.09851948928929145, 0.1756793747265493, 0.15016080210766486, 0.14723607759562232, 0.16635809183841752, 0.151080031008009, 0.14485320707242336, 0.20466268723530157, 0.11727416437239417, 0.1617679228225062, 0.1390095956383213, 0.2548207772234755, 0.12221909338428129, 0.13945077035215594, 0.16829607978222832, 0.20041509741737, 0.130261177978208, 0.10939257519860422, 0.1551211448085885, 0.16171872465600892, 0.1619999248894953, 0.10461564926851182, 0.12817776356373103, 0.13536278729236897, 0.25101624669567235, 0.10215868272127644, 0.06612443485327306, 0.12460358035300048, 0.21054619652850015, 0.21842901144296895, 0.1637441538754971, 0.12334420075339657, 0.13285781767579818, 0.15138364697415985, 0.11320878856725271, 0.089824199826727, 0.16433024178108863, 0.22127475229001817, 0.2651391695103338, 1.4585132464285822, 21.513515941558346, 52.616030631526826, 79.24762187465545, 93.86407544535976, 89.88896508370676, 90.28497542104414, 79.33486323202811, 93.90042797211679, 96.93499319015011, 99.94998578102359, 52.877727247053585, 34.437233401883034, 36.31356977647351, 50.83028531843617, 96.76559386714813, 101.76053616308398, 98.17719997898226, 86.55352269449543, 62.27755008205291, 29.51949707923397, 12.088838027369592, 5.800248528680494, 2.8369106111987947, 0.9155162544019761, 0.6517239900365953, 0.20333616002913446, 0.2339276443085363, 0.12607612391753545, 0.4745415814461247, 0.15925539957900203, 2.4452237063838593, 1.9325726214916477, 0.19846638424261925, 0.9064327192402656, 5.2346716773125435, 2.3797059059143066, 0.4527364515008465, 0.4550114874878238, 0.48373485104210917, 0.5791181602304982, 0.7087048744001697, 1.312959727741057, 0.6952708791340552, 0.4091268044806296, 0.92457496831494, 0.864429282805612, 2.843232491324025, 0.4907558936505549, 0.48593554585691423, 0.4005147811145552, 1.3323408942068777, 1.169321428864233, 0.2901211435035352, 0.7272288191222376, 0.4220795126691942, 0.39395709912623134, 0.5331770931520771, 0.3319887372274553, 0.36097876066642426, 0.26945913931535137, 0.3103718810504483, 0.2697338890885153, 0.15988855592666135, 0.25130072578547463, 0.5293031397365755, 0.21672150871205717, 0.36288929201902886, 3.0865393194460102, 11.43095947081043, 29.200575044078214, 56.088861880763886, 107.1430870794481, 117.04668737226918, 75.09944085151919, 42.554739290668124, 31.015669491983232, 43.91777469265846, 43.4993205531951, 42.8267321278972, 48.68393690355363, 55.43060187370547, 83.45892167860463, 91.15019536787464, 88.03029506437241, 102.54589665320613, 104.54981988476169, 98.98864423075031, 44.13272450047155, 9.438887680730513, 0.8336231713333438, 0.2106545060392349, 0.1607489799179377, 0.09956388163470453, 0.061122780861032594, 0.18997149572016733, 0.2228769945401338, 0.18766137290625803, 0.1889433291169905, 0.233827869017278, 0.13815058124882562, 0.2006429166442925, 0.24436318676077554, 0.21016407187186906, 0.20124466338705635, 0.19971498498512855, 0.1996315580101744, 0.13592860451148403, 0.22976386450952102, 0.21778347511445323, 0.18105440082088595, 0.26272905690054743, 0.1644447412822516, 0.1225958324428047, 0.14424094960333841, 0.1769104626991095, 0.11646651617822149, 0.1629572283596762, 0.18259420690517272, 0.14947152215867274, 0.14088545385147297, 0.08993971822482925, 0.1777311726923912, 0.11987001499942235, 0.15290626204542576, 0.09154608968885676, 0.22220394033337795, 0.20349078721577124, 0.18318204149123163, 0.2427745655539536, 0.13569677098383828, 0.20942715657574518, 0.12144483130184874, 0.16485300485885915, 0.12419778357950911, 0.12349638411955488], [0.031187673054275014, 0.03244810219433519, 0.05662569535836097, 0.06811618684760987, 0.03357694807252096, 0.05821694041632357, 0.0746603627058287, 0.07690584302068719, 0.011922381217441252, 0.08419068034497962, 0.04399691978769918, 0.06267211707909742, 0.10367775080545295, 0.007709321376281761, 0.09467126876716653, 0.05928313179362205, 0.08420137493240257, 0.03692836057574999, 0.061115828613119746, 0.059593018189433127, 0.016801704374712803, 0.03170936743939116, 0.07481731113887603, 0.007155106558779916, 0.04737516452047614, 0.021831958344386473, 0.07304255354909167, 0.0750085190238972, 0.05784665947900184, 0.06615336999417314, 0.07375807200949039, 0.05269553024141539, 0.005815479727912574, 0.03734693952625798, 0.035130719939667376, 0.0065358494400918005, 0.0489985124929057, 0.13326925285641225, 0.5751335837187306, 5.713974525851588, 28.619326852983047, 57.10252000439552, 73.14870495950022, 73.31811212724256, 67.49669505703834, 69.64496935567549, 55.264081570409964, 73.13181523353823, 73.10253081783172, 63.257605260418316, 86.82248746195148, 47.08166437764322, 24.94386596064414, 47.82784038974393, 58.904731427469564, 72.37225609440958, 61.27443136707429, 30.742996123529252, 15.170891381079151, 4.210423154215659, 1.148755461458237, 0.2687509063511126, 0.027457194500452572, 0.007349873879819268, 0.060263387258014375, 0.12430547255902522, 0.045613928382555326, 0.06762369956460691, 0.08242398966103792, 0.07286781655444254, 0.03750296865379618, 1.7751653324211798, 0.8801864856673826, 0.9727814493160095, 6.383904564765192, 3.973932424860616, 3.4368096724633252, 0.23312493738147522, 0.2855379765312518, 0.08167578988978941, 0.3987824724566552, 1.7800803073952276, 2.4947399525873126, 0.4402983705362966, 2.058543952242021, 2.4435069339890636, 1.3766096219901116, 1.4800435040266284, 1.48394932669978, 0.14741312051492353, 0.4124853339406752, 0.2581822024958749, 0.1603115130696566, 0.07555788833527796, 0.24602383555423832, 0.07911907869481272, 0.14625416738131355, 0.19510894262742615, 0.13420957981819107, 0.011900479721295978, 0.020245070411493222, 0.0035688699121707154, 0.1167348001693045, 0.0436359353273386, 0.06170597295427035, 0.022706857566992124, 0.07105709879749245, 0.031251752478701454, 0.04562660713770217, 0.23559607655530979, 2.0076725271440323, 11.685775268462397, 30.43042244449739, 42.8287443037956, 55.28166555589246, 76.83134771162464, 68.90582223092356, 55.644210230919626, 30.707145660154282, 34.13962748742873, 50.12332516331827, 32.283885517428004, 31.042349453895326, 39.89469766616821, 55.07899668908889, 66.24683964637019, 70.50251714644894, 71.84228897094727, 72.86632568605485, 55.012685098955714, 23.481943684239543, 4.114507965503201, 0.5048467939899814, 0.053174519055192514, 0.04774772073893298, 0.035052900728318966, 0.07502743373474768, 0.034266802587456284, 0.07657143798085951, 0.056012032117934964, 0.021328623256375714, 0.05242327408444497, 0.03658279746530518, 0.050856873257866794, 0.025963614161516872, 0.03814826366461573, 0.059378551875030806, 0.06637637052805194, 0.03933140602443488, 0.06630515499461083, 0.045676161535084255, 0.051221569414220514, 0.0562939563045098, 0.05570716359802792, 0.011139039077886171, 0.04148383346957065, 0.05217269055485245, 0.007431399520306338, 0.03228824262717559, 0.05981163670038504, 0.025596931922219457, 0.017316088365811496, 0.032076896205844904, 0.07331616185124844, 0.07758786811703637, 0.01959417338272737, 0.07271508926585799, 0.0537809657473718, 0.016572816455135905, 0.06358049051355451, 0.035136404312065536, 0.03256324137891493, 0.029211928467116052, 0.03770231622301283, 0.05149297521359498, 0.01566747672885897, 0.024068044506073482, 0.02078419329688674, 0.033613107422547, 0.06872656740128033, 0.015392470316240385, 0.04437254801873238, 0.037670355034811843, 0.03514735936938274, 0.06447992753237486, 0.03605009439671713, 0.04683298494426474, 0.08408207972083362, 0.05720673857497112, 0.01594778255469376, 0.0923344707717338, 0.033786545898164475, 0.050348286637135094, 0.04373653033267587, 0.002359796194322107, 0.05016707619952579, 0.07405328399111187, 0.04865376909653987, 0.05476949496134635, 0.06774497894389976, 0.0631855492059502, 0.020595507756356272, 0.027360133075666045, 0.07594842463731766, 0.027096725234221068, 0.0804695844530098, 0.032376970930565754, 0.007775419921193633, 0.011332741536710773, 0.02711248940848295, 0.05905987078984899, 0.08673060655353532, 0.052823612481475844, 0.10773298360647694, 0.46150089572033576, 7.303386580559516, 33.44415987691572, 68.13887334639027, 86.57187938690187, 83.44225160537228, 75.84412636295443, 78.98447005979477, 66.0488619342927, 77.77873346882483, 86.4655831552321, 85.22722028916883, 114.18554582903462, 55.50709985917615, 28.090622732716223, 36.273781253445534, 39.84545623102496, 61.243546624337476, 52.35330243264475, 33.18320458935153, 18.55195191598708, 6.429909063923744, 1.289425384133093, 0.36681469589952503, 0.02379030699000484, 0.05893325177772392, 0.0508970354172972, 0.04334561098667403, 0.083286328872125, 0.03726295330711911, 0.12426270953109189, 0.47753361444319453, 0.25605943414472765, 2.389310809873766, 0.9902960578760794, 0.9332071244716645, 7.629822896372888, 4.135725046357801, 3.942143575799081, 0.1539665736979054, 0.29026823238499705, 0.19621407042347616, 1.4216064397365817, 4.161220942774127, 3.921698711572155, 3.1458092745273345, 4.496278137929978, 4.08196724710926, 2.2132917517615907, 2.20592039246713, 1.3989450686400937, 0.12156630220312266, 0.25922791251251776, 0.22308794451096367, 0.10221603972416732, 0.07503390717770785, 0.42790561133334715, 0.22065858777251937, 0.5487195462469132, 0.7395096988447252, 0.03954529394245437, 0.14643413675648553, 0.3395885132974194, 0.2584953485958038, 0.04895569200837805, 0.01595583988443738, 0.0362951927367718, 0.041789793664769787, 0.1265022373427787, 0.11747868686553933, 0.12849025082804505, 0.24596179775413007, 2.0988328226151007, 9.805204695270909, 29.387677984852946, 45.88561996336907, 50.02616805415, 56.54409608533306, 59.570875398574344, 65.47896116010605, 40.090019933639034, 35.36190079104516, 43.24045981130293, 39.22196019080378, 46.71613477891492, 53.547428807904645, 64.83356652721282, 72.47938386855587, 80.04467887263145, 80.61138291512766, 85.47713018232777, 66.43414851157897, 29.45011623444096, 6.390069059787258, 0.545617196588747, 0.13280474310440402, 0.05478074879295403, 0.025740374225161733, 0.06704200134282151, 0.03278276770405712, 0.030613290972166488, 0.029988596065630837, 0.016989271426873825, 0.02290413669881321, 0.02814056025066924, 0.11500098997907293, 0.012261449817507979, 0.012943988192766424, 0.03496516067835112, 0.023153065478489287, 0.0690040061430585, 0.10435102717770685, 0.03740601639653887, 0.06906210625123593, 0.059861872916019736, 0.029668731374606013, 0.024233107725458763, 0.030144856934766137, 0.037566343277332284, 0.05196066040004935, 0.05547000958974804, 0.0602691903740408, 0.05296430835920957, 0.016536961625059767, 0.045230681407115156, 0.06137562435000174, 0.041098123521453915, 0.0012481257679962344, 0.05283106268653947, 0.0397119946747778, 0.04115667179106705, 0.03975794845891576, 0.020437364226147052, 0.02580729392056744, 0.005597255273436707, 0.06851060721542566, 0.013680344244705574, 0.035685390579484166, 0.17451187205170432, 0.1287896303279746, 0.19606164957006134, 0.16184712099211832, 0.14243227730114616, 0.17825122381890976, 0.09264406222369402, 0.17840611147544078, 0.1169103721997911, 0.12523763302353122, 0.15731194176741187, 0.12560049056886666, 0.20151624155621375, 0.10186956113865299, 0.2895431148429071, 0.2521667115750813, 0.11604213411168707, 0.1400567612220203, 0.15717130334627244, 0.19478079652593983, 0.12479289600084867, 0.14415913141302525, 0.2528994593528971, 0.1040424163182897, 0.1299745385204592, 0.08359928345007282, 0.1649033981225183, 0.20813992968009365, 0.12545157839814502, 0.30550326971757796, 0.12692353207497828, 0.11435065027927199, 0.10569417083095159, 0.0993828090929216, 0.12842258228169334, 0.28184111200032697, 0.1781827049149621, 0.2812287932442081, 1.090060011033089, 11.423747212656084, 44.38516040002146, 78.12606719232376, 96.25697228216357, 91.71140024738928, 88.87608358936926, 89.94132088076684, 77.23040965295608, 87.46159845782866, 84.18006512426561, 75.4686378663586, 94.0118311297509, 57.31571651274159, 37.11208589615361, 62.768352339344645, 74.09867948101413, 88.34572422888972, 76.69079349886987, 43.9102594314083, 22.78694675814721, 8.179371962624213, 2.0857551501643274, 0.6487304248636769, 0.3965503373934377, 0.12986285822285762, 0.21783969064633693, 0.19069678180160063, 0.13932065797909615, 0.2595248175484519, 0.22657434936733017, 0.5347114753338599, 0.2915931661282816, 3.8284414189477123, 1.3744140752861578, 1.3871502563838036, 11.349877215200856, 6.087981837411081, 6.230329553927145, 0.5268401364164969, 0.6966315738616452, 0.49167700712719276, 2.267772738010653, 4.66049502934179, 6.706178265233194, 3.0045943875466627, 6.806394332839597, 7.52365267084491, 5.967362580760833, 3.99446897449032, 4.422794003640452, 1.3539347677461564, 0.7927993264409804, 0.8515319168086976, 0.918867122982779, 0.23530703158147875, 0.8220667043520559, 0.4196089097569066, 0.8970846079530255, 0.585139366167207, 0.3636829591085834, 0.23298224584469873, 0.24210000981486615, 0.2606484233852356, 0.5827967305817913, 0.3901476809574712, 0.42403297558907543, 0.1791354118575973, 0.30228104262102035, 0.31074288211041884, 0.2651481174172894, 0.6029669676096209, 3.611995226913883, 16.50521993637085, 41.87609864819435, 56.88983340417185, 75.98923052510908, 99.44476096860825, 85.54624234476398, 72.35744522463891, 42.429709819055375, 48.964472663018014, 65.0200399275749, 44.55206509559385, 46.50110652369838, 59.71560301319246, 76.47920516229446, 85.71805000305177, 91.65440036404519, 91.81460565136325, 97.68771171569826, 81.93420225574125, 39.27988575350854, 9.61024328585594, 0.8362520173672707, 0.2280815201060426, 0.2310254427814676, 0.17188071243224606, 0.13220408420649268, 0.12392682594157035, 0.2176507580424509, 0.13094489612886984, 0.10714851214640564, 0.18415737867115006, 0.22118213225997266, 0.23106875739270644, 0.0862509205997471, 0.2124138422791035, 0.11446796132311707, 0.11106175055066425, 0.31351930732207917, 0.29144751749211745, 0.1638370956624708, 0.16016371938730442, 0.19251403428854483, 0.08487869624889667, 0.1185302727765614, 0.18540150546018155, 0.19765621561917568, 0.1719514836346911, 0.1094716967594239, 0.2310114999812457, 0.14737230335031787, 0.13399861452560272, 0.24503861584009665, 0.1497871350617178, 0.1314130677811561, 0.09622879446514192, 0.1330596665220876, 0.2147417383328561, 0.16595113061128125, 0.1987778909143902, 0.15735839733914023, 0.06171865937029643, 0.15110882059220346, 0.12037138890234694, 0.13263300151353882, 0.12285404237768344], [0.044485856253173084, 0.0290649468379636, 0.06492160020336028, 0.048910722647222786, 0.04405443000817492, 0.07515903231838057, 0.05672697218195085, 0.06846321701642967, 0.03149246305016981, 0.053864113100233584, 0.06770406218786394, 0.052541473790282206, 0.07677402993243548, 0.027491323717479265, 0.027407640103070487, 0.011224520126087292, 0.01037069119422907, 0.09601499464723373, 0.01831967120749816, 0.049592594525987105, 0.02869970867440345, 0.022834993433207277, 0.014639021885100634, 0.029151087679389506, 0.03596727646166279, 0.03674339247687209, 0.017571241609872352, 0.021660701304133383, 0.03153296037306709, 0.04376204106055441, 0.10075569994026616, 0.03520592679119399, 0.04980860450755685, 0.06857069915220623, 0.07514299809812539, 0.048653504796206, 0.27273753597851724, 3.138898548579985, 23.372833151971143, 61.25701212113904, 72.48150194844892, 77.29413247877552, 71.88576452193722, 68.94131968098303, 62.27452985702023, 55.113945007324226, 48.05464360021776, 43.032923283115515, 19.151970609541863, 18.2913496417384, 11.872666401247825, 19.47549162372466, 45.042675156747144, 72.37523709574054, 61.571260652234486, 26.66117964252349, 12.2945830129808, 2.951663227811937, 0.6575516515201139, 0.15627075166952226, 0.035487092550723784, 0.03581752925510368, 0.04593783418738073, 0.08633652326440619, 0.06601342105216558, 0.020631546447534236, 0.05092133572625537, 0.002397192536943382, 0.1996825488224145, 0.17600396618006692, 0.31272548701493974, 0.7303929461106178, 5.633484548138035, 7.972987630674917, 3.869740054492028, 0.10085503856140761, 0.37009606498383707, 0.19032316072092903, 0.31140236123915643, 0.06919112311856401, 2.158901225174627, 3.631060152284561, 3.1287405904262298, 2.846644708225804, 5.4960799986316315, 3.810022458914788, 0.46793450210844323, 2.299169595203092, 1.9053046717759103, 0.1937690395261011, 0.02269952993599638, 0.02586907125078142, 0.02346225090384964, 0.0764587541080771, 0.07649829190584921, 0.16991270916356196, 1.7292789946640692, 1.9310372587173217, 0.18680765984519837, 0.0918886152606818, 0.4469168799058084, 0.26067063993503975, 0.08891470790390046, 0.08960927385957011, 0.03812127438704333, 0.16582814285591727, 0.010941236133446858, 0.010291832018523447, 0.05840297720785584, 0.03647613887404723, 0.07838295246925085, 0.19693638408376327, 1.8625679972671696, 12.260611364918372, 31.96772090850338, 60.34314693943147, 84.32949173835017, 51.76744153422695, 49.59755497594034, 51.410313652407744, 112.44632767092799, 35.645441086061545, 16.20506448130454, 20.926103745737386, 41.30048298066662, 41.59083643267232, 55.1565811710973, 67.81941983007616, 66.78274523827338, 74.60453187265705, 75.34120005946006, 55.648293418269006, 19.24535047623419, 0.6756844011045272, 0.0898744015684051, 0.027497327931585814, 0.05163296245999875, 0.017119789826533487, 0.01691548758366656, 0.008582373848184943, 0.026118459683212063, 0.07292410869511866, 0.035016477077959046, 0.06889846987060963, 0.04874492972908963, 0.0438796240656126, 0.021470351437587413, 0.05241650569763395, 0.05820232728916792, 0.0336004363282794, 0.013288359078879078, 0.07563065136632613, 0.07881697958275195, 0.03341066868855588, 0.08917342345680922, 0.011958914035330377, 0.039575807224478454, 0.021574510666992397, 0.06209827125853589, 0.045876091331123345, 0.04356233343001335, 0.03981494540048223, 0.056088104648816015, 0.029280987463050315, 0.026128106645398566, 0.01444170923693286, 0.03683903472377889, 0.03636036766692996, 0.03113980596554616, 0.04023525954013871, 0.10062270707661107, 0.10240918581163692, 0.028756749666025563, 0.04267468650434767, 0.03402255460499756, 0.05162935035543577, 0.044975780972069314, 0.02970562808425917, 0.07184890429339102, 0.03100555863291506, 0.03487812542927361, 0.03745371686114419, 0.12319700461962532, 0.0572190840818709, 0.047268034785144755, 0.015775497041402325, 0.02672736168718867, 0.08909863029276172, 0.04229230137782232, 0.0409896454713758, 0.0927984212795573, 0.02118483238342789, 0.067701603045627, 0.03935130898870769, 0.0076417136381590565, 0.02167642525877924, 0.021646905975836902, 0.023723031063714338, 0.04819186021303458, 0.019041454351897684, 0.020223089433725805, 0.03236441857992642, 0.03462925027575224, 0.0012855199559952224, 0.04380735133083598, 0.014104092373482644, 0.043187069090744185, 0.06482641377876844, 0.04033275955026189, 0.05249414487832016, 0.015170026153716591, 0.08602800433553996, 0.12766453828061783, 3.7364226147051784, 28.737821655888713, 70.32681065220987, 83.63724047137846, 85.97225881391957, 79.90951399649344, 77.92960351513278, 73.45337898500505, 64.30343858657345, 56.82205876996441, 51.574955140390706, 33.488521883564616, 24.876973859725464, 17.9369419236337, 24.743089637448712, 41.64149776581795, 57.62197125342585, 52.4088784956163, 29.024246854166833, 11.840857940335429, 3.219968056486499, 0.8137423929668243, 0.2603696286678314, 0.07637731896172609, 0.03363160461547875, 0.06869101326071447, 0.05029705833763846, 0.16159569093536946, 0.0928855101547895, 0.12490791644180015, 0.4524198733270169, 0.2211653549344309, 0.736975909000443, 0.9288995652910202, 1.5582312955971689, 5.160584478609024, 9.560756702576915, 3.383144048913833, 0.23062992690792009, 0.9514752571140567, 0.6266650701722791, 0.180934033086223, 0.1487491472113517, 2.014747012046076, 5.422102626292936, 4.778445113089777, 6.518230053686327, 6.6734073527397655, 5.260655908815322, 2.9131992401615268, 3.083804201695227, 1.2029102781126577, 0.35997598221705807, 0.06916642444388521, 0.11495697822782303, 0.10197008719607707, 0.1694386386342587, 0.07816300862618993, 0.2916381201676784, 1.8985251000811978, 2.198432097511907, 1.2655092223036675, 0.1749533378789502, 0.9261058571357882, 0.4730915302230466, 0.06665436851401484, 0.18751753223759515, 0.0540955635839172, 0.24219405476845082, 0.02319779160672859, 0.06200157947117283, 0.06483381418811698, 0.04799858389061786, 0.032306621076479074, 0.22172446122332928, 1.9397661258136074, 9.646464413212193, 28.103909761674945, 59.93506354670371, 76.0956601173647, 41.66316886102, 36.70895645695348, 47.62898798911802, 103.23526890047135, 34.271215161969586, 21.98630863620389, 27.750868989575295, 52.16613085039201, 53.41052239941013, 65.15633052395236, 78.02982007303547, 75.2699698171308, 85.46700262254285, 85.52654420175861, 67.87091270569833, 26.691326979667913, 2.730134379479193, 0.04058051621541381, 0.07066016566128501, 0.09725221898406745, 0.011959407204431633, 0.037064111355932496, 0.04226602839245912, 0.019365063297652432, 0.043687688397063364, 0.06408704317084725, 0.029801760627437505, 0.0214005320993883, 0.023613710316919514, 0.08774728949872718, 0.010018629742966545, 0.07031161863837512, 0.022310564114201455, 0.05778067249564394, 0.06495365332211218, 0.01500078775514398, 0.022705719926424568, 0.026392451029330976, 0.03964590426955012, 0.015514081028560478, 0.028259943562349486, 0.042438834845539064, 0.027014711691487222, 0.006949363113005436, 0.02734047525952901, 0.045994589811251055, 0.037808810105367054, 0.019672025152812564, 0.01274105916250377, 0.020871236206843488, 0.029942456505171237, 0.0533856682088827, 0.0505994753761878, 0.04133844147286108, 0.041405504809752594, 0.013284258593264367, 0.02256686457492892, 0.0593625329765341, 0.07569333268029076, 0.18955494307221907, 0.13482333881960762, 0.11795125586251098, 0.10056541902163338, 0.1270089355567771, 0.1991840707318437, 0.20106006684082173, 0.19399952473900012, 0.13478932451576958, 0.15189395346228154, 0.16017228425029786, 0.12487423155576953, 0.1005842877672084, 0.12354187442049866, 0.22017023736430755, 0.04238047043702776, 0.1128849708625386, 0.11148255498659228, 0.16966382251872172, 0.11456084182305683, 0.09938004351551495, 0.16344291278191153, 0.14484053597815577, 0.15437448487406777, 0.11486946034335321, 0.1511016500092322, 0.22349907325640803, 0.1558731673585792, 0.09918047761123988, 0.18211642851031598, 0.16116867352637554, 0.21348313248205572, 0.1283008355887667, 0.24361240527322217, 0.1837294266348885, 0.23193603021002587, 0.819382393552411, 7.192275149206962, 40.09406781965687, 85.58075135754001, 97.56635358256679, 96.71488546556043, 89.72420984698881, 87.56372913237541, 82.5981261653285, 75.28016797957882, 64.97267730774419, 56.82264320312008, 32.17087026565306, 28.75780220954649, 20.717253223542247, 31.201278009722312, 60.90128844784152, 94.7795880225397, 80.23332134369882, 38.46050262451172, 17.12966715135882, 5.153737981473246, 1.4343775544435748, 0.4986449138772103, 0.23551551474919244, 0.261132437735796, 0.3954156692470274, 0.3192850076142819, 0.36413605415051986, 0.45690020065634485, 0.28918550499985296, 0.24895099622588007, 0.3013267115719857, 0.7170883890601897, 0.3995807054302385, 1.2575367597802993, 10.305771693106621, 12.073666299543074, 5.9914326956195225, 0.19389801808903295, 1.4561670561951976, 0.5031682953478829, 0.846091834527831, 0.24152526001055397, 6.638923835369849, 13.248766237689605, 8.716526339131018, 14.161065413105874, 17.01002113280758, 13.398236978438593, 6.079038833418201, 6.456177667264016, 4.544060451369132, 1.3344736829880746, 0.5608356251351295, 0.3166075609624386, 0.2681822852501946, 0.31970485444030455, 0.4908533093910064, 0.8674539817917732, 5.5428542629365, 6.85012532818702, 0.8164232716925683, 0.25545983244815185, 1.1931360993654498, 1.0057170400696418, 0.18319713342333996, 0.358456676645625, 0.1244153219064878, 0.43305304802713857, 0.3649566875350091, 0.15488016419112682, 0.2425396829963692, 0.18356479433996065, 0.21748488468508567, 0.4451691882023889, 3.142050418161577, 17.346442822487123, 44.14900625905683, 74.25293061041063, 98.96238788481682, 63.35280902924077, 65.29939113124725, 66.82123153440415, 116.52585152656802, 47.85278274166969, 29.347418777404297, 35.89301324659778, 58.61582925242763, 61.06413741265575, 75.88109862419867, 89.1110884758734, 85.83614472419985, 94.81259084516957, 99.46186250255954, 79.43955129192722, 33.42110810741302, 3.676095335714279, 0.44275359040306467, 0.19050320670489343, 0.19811341689238626, 0.11428459051756129, 0.1577168192353941, 0.4424288916972376, 0.12244325071092575, 0.21371090574370277, 0.22721760275383152, 0.1464243614745717, 0.08463825955386124, 0.22796806248445667, 0.1457496678396579, 0.1471806281516629, 0.16418436331854713, 0.1157353082371335, 0.09400347758445049, 0.23825268561561264, 0.17228807202510296, 0.111978727152511, 0.12867480906988346, 0.11851750209086365, 0.11703087783028042, 0.19525485173348459, 0.1388291359668778, 0.09213998403039672, 0.18477533583439168, 0.12402447916927839, 0.1496703526185405, 0.13130625980275293, 0.16752167214309016, 0.1263199313994377, 0.16711818895513014, 0.09614677709196845, 0.15884442405114252, 0.1629369883167167, 0.2531042806203327, 0.15369000063548166, 0.09193356930007858, 0.08048776371945297, 0.1137790490963286, 0.15094521485509413], [0.01889163628220558, 0.0446457349725308, 0.05571626472256838, 0.039603309780960126, 0.04102794220671058, 0.056036596727227016, 0.038108338992441856, 0.06809492024683184, 0.019024541045749382, 0.09640961419790985, 0.03055389617539702, 0.03977813870616017, 0.046283630954642455, 0.06640282354407734, 0.054685010785056706, 0.0062952777220597195, 0.04715628937006958, 0.045463771318956736, 0.029392897587029204, 0.0906519501680328, 0.047640824660418496, 0.029944120831186735, 0.00798106952119739, 0.1330402998193618, 0.1548317474343123, 0.03505712570322137, 0.1275619667684359, 0.030982771347607338, 0.026876946100063866, 0.04573831807882075, 0.04259688644519737, 0.09775395294831646, 0.054327466059476144, 0.06771705503905974, 0.08748573942049857, 0.43605500952370707, 13.005221370727787, 46.385290699620406, 69.93032963045182, 72.48696973246913, 74.71816293654904, 68.82579018992763, 62.22448825836182, 47.49672566690753, 27.649208999449208, 39.12487368429861, 26.44031293930546, 31.48242565893358, 29.77343720774497, 44.58785280104607, 68.1413052158971, 56.3150728133417, 57.25060516788114, 29.267290638339137, 7.1860645663353715, 0.5692768721811233, 0.07397218592344754, 0.06853803316311491, 0.01729498647393719, 0.011864584671603817, 0.058696561252638224, 0.03598743223495061, 0.021240864054209763, 0.06296778488303385, 0.07337411640272026, 0.04357068378838801, 0.15067601155850197, 0.14188768071753366, 0.2641319477510068, 1.664454350548406, 0.3340191460184513, 0.032143731631578944, 2.4805904924869537, 1.846101519561583, 0.050670748366223234, 0.17549873119400394, 1.5767999185669808, 0.421351453349475, 0.03610627928508386, 0.04439320557961061, 0.7267277976197581, 4.225462502048862, 3.2364942277631457, 4.532094280565939, 5.73072353678365, 4.049425057826504, 2.751729723907286, 2.136857504806211, 0.35083526625267925, 0.0912837582009454, 0.13741674562615735, 0.05090386892158178, 0.05318306093554824, 0.08518527697531447, 0.1518169156606159, 0.39831240090631675, 0.8025407166250291, 1.0293544684686968, 0.19690869766617977, 0.1996659553579746, 1.869177191007522, 1.3601719491904782, 0.13477579540302678, 0.0951562254058738, 0.0586124945942673, 0.12905681115244666, 0.03248492804085536, 0.06345396726241996, 0.12981925249820755, 0.05649560596793891, 0.12488289601019315, 0.08486541994516889, 0.05175200869299231, 0.09599789556476379, 1.249570793682529, 7.433633785093985, 27.205390853266564, 73.51597216821486, 69.8448690291374, 41.51337354413925, 52.780758411653586, 60.61153119610202, 46.88587927049207, 40.641599316750806, 27.945269500055623, 17.927659634620912, 33.91336556403868, 48.833132097798014, 61.36063329635128, 74.18505791694888, 75.40853146583804, 74.43415980185233, 81.47985058446085, 53.04742859255884, 7.786092575519317, 0.41172402640504224, 0.05108971036069336, 0.05643147291735776, 0.02254020088472434, 0.038488816560035756, 0.03927028752983578, 0.053187630650016575, 0.0509323827141235, 0.03462016064253065, 0.024883386138225758, 0.026764769760531285, 0.03309608234332935, 0.07571452267227635, 0.06269598071793876, 0.05402994432276296, 0.04805898992344738, 0.038720186604487325, 0.06130070478144673, 0.03238658533401547, 0.018042100315553047, 0.02907778647157454, 0.03563632647837362, 0.006992773964039742, 0.025131613947451118, 0.025712394778947198, 0.006861361635533432, 0.0315528633373399, 0.020315510280911, 0.06125177474572294, 0.021864446218035394, 0.03970462490894622, 0.032613987043019266, 0.05742073757573963, 0.04487009148203558, 0.04449909808294428, 0.10974931936230391, 0.014334127509726152, 0.057372213566615704, 0.10133150694591385, 0.030471357862435045, 0.03319887219056968, 0.020899464631633415, 0.05374605129022272, 0.04722497298292095, 0.02823025957050343, 0.05286458286366636, 0.022882785828363512, 0.09312723387753771, 0.021869326198113062, 0.02843307177235763, 0.05748583972754498, 0.030497385699662472, 0.07466741071473207, 0.02608778360750406, 0.04749534839403726, 0.014144037155464534, 0.021686985780815446, 0.1057095998417466, 0.024932352563125953, 0.014384305311156618, 0.03982162185674233, 0.0482999284060732, 0.09014974889014998, 0.03373671570912965, 0.08928764716631944, 0.01744213089677355, 0.06235340918083826, 0.022436646864779537, 0.06941792344854725, 0.029784006539792306, 0.040103584347713384, 0.026760364754966674, 0.04726277176110495, 0.03678547751699244, 0.05246888312901701, 0.04582636073351868, 0.4955328195806473, 16.259504037518656, 54.28578361388176, 81.64957154181697, 82.79755515436973, 84.06233910591372, 78.98257163263138, 73.04536619494039, 59.257011259755785, 43.077210764731134, 49.57880604651667, 37.992340287854596, 39.465551145615116, 23.75911993365134, 34.45564500747189, 46.864620024158114, 45.896798718360166, 51.38762666333107, 32.449762552015244, 9.748761788491281, 0.9145803401066411, 0.12052493590501048, 0.08148596096303194, 0.044775471962507696, 0.04065919344523742, 0.04045214669238176, 0.054531429308436574, 0.10659393343713977, 0.09962360584928144, 0.18173476350643944, 0.1807385427697051, 0.38755949887056507, 1.545851682463, 2.0536988444866675, 2.6919008310764068, 3.6713602994718864, 0.49774607823741057, 2.750671664553304, 3.261474087353676, 0.20425874439458694, 2.2779230965721995, 1.355034011986948, 0.35006396893051367, 0.034257525262693246, 0.044902202057381796, 1.0951028307599406, 2.4127155926919754, 4.521553401024112, 6.030401443281482, 5.0496505345067675, 3.4989007922910877, 4.517841367952285, 4.341945129056131, 0.8030649659133727, 0.17754508993558346, 0.08979087500202079, 0.27120125389868216, 0.2206655744943888, 0.34918220172966685, 0.699233943896909, 0.6304894423773212, 1.2373323858745637, 1.9850429027311265, 3.2348098149222717, 1.6536520205197798, 2.606866297221953, 2.060736066872074, 1.1100593185232532, 0.5441445917371781, 0.18915795630985693, 0.16310258588242918, 0.11267192181079619, 0.12365153990685941, 0.2391232219674895, 0.06814325273397469, 0.08016831271590726, 0.043022865805053906, 0.02619091053343108, 0.10898312418571404, 1.1822761595249176, 9.044616914564564, 27.50935296858511, 57.471826845599765, 48.48595526910598, 48.11233774308236, 66.86928841375536, 47.97212869890275, 37.80971081026139, 40.44994054302093, 39.06200201280656, 28.307863204709946, 44.545004829283684, 56.25588816981162, 71.05926621344783, 81.07503844845681, 84.10009584119244, 85.55749170241818, 96.98554469693093, 67.95441996666693, 13.83240903577497, 0.4767084764617105, 0.064169826631945, 0.05555526751484122, 0.05527023684173342, 0.0733699718670499, 0.0566672747804513, 0.12467938475310804, 0.019788803765550256, 0.03390209110934408, 0.04623396547451135, 0.014657407995283365, 0.029363640689200936, 0.04900538047114688, 0.05109250658161698, 0.08428143112048989, 0.014690421596770326, 0.006276917946149385, 0.015522228373635202, 0.01364644581166607, 0.013972092551299402, 0.04876523105908306, 0.020126162074326027, 0.055197722789260655, 0.044280180797701886, 0.027249816414569656, 0.007644287693584639, 0.07244448402836438, 0.02784532145597041, 0.07161550028550048, 0.023142899491734082, 0.08142829752497135, 0.051946775056421764, 0.052951821126043803, 0.052007495185300234, 0.07949266147108809, 0.042494065954440066, 0.04908636745606219, 0.06819494068622589, 0.1349288750920565, 0.04135794224097364, 0.043228759595583525, 0.17062650392613105, 0.10972049147371324, 0.11464555582572376, 0.1184248743999389, 0.22169352659294683, 0.1559265023998676, 0.23171116808249106, 0.15228193103065416, 0.1311117807222951, 0.2034836779198339, 0.1369510867422627, 0.1950691366988805, 0.10974810894338355, 0.10932001901129562, 0.19116886050230075, 0.12974602981440483, 0.22707602970542448, 0.13371641837781476, 0.13174426291258107, 0.15737181919957363, 0.20353358088722154, 0.1592184894628102, 0.16419747874381083, 0.1810982057283963, 0.23773799710456403, 0.15696208473415146, 0.229508358865015, 0.11358220280418474, 0.2191984088670823, 0.24000270622632197, 0.0888020316919973, 0.19845870804161797, 0.11074407687110287, 0.1539668954548336, 0.19330851343129912, 1.227363314359419, 21.992135317094867, 67.51207074811383, 93.86551887758317, 91.37267220404841, 93.84358498357958, 87.80354284471082, 82.43159801729264, 64.76207348608202, 42.60879739638298, 53.58944131482033, 40.48292375379994, 46.16709709167481, 43.92789048533286, 62.94581997779108, 91.469358628796, 74.49007711102887, 76.75673638620685, 40.14119117490707, 11.092133368215254, 1.2230217408749366, 0.19059878383432666, 0.19853740059320005, 0.21658549746198041, 0.11091850743058229, 0.1759500948772315, 0.14256310979685477, 0.22441004372892842, 0.28766822190054003, 0.231450391753066, 0.1891202954274993, 0.3633600683702577, 0.6052790822521333, 1.1000137607897482, 3.424635125744728, 2.430291243137852, 0.19226468799095, 6.450234295860414, 5.368985889419433, 0.17947264376186556, 1.3789939327586083, 4.736260021886518, 1.3349361549462042, 0.28563649543831426, 0.3662113863373957, 7.053178587267476, 13.706178338296953, 10.071893507434476, 15.358754281074772, 14.457689754424559, 11.81078120585411, 8.305847317941728, 7.674154994949219, 2.489178276831104, 0.6290977364105563, 0.3366080022627308, 0.37104368510265506, 0.33170004465406944, 0.2457318028375026, 1.3701607551305526, 1.3972442308741233, 2.6718673254213026, 3.870679217000162, 2.2472636449721555, 0.6707069746428921, 3.215521804748043, 2.82265892432582, 0.5742454120228367, 0.3635133778856647, 0.2873642075686686, 0.26477601319070787, 0.3048578559631302, 0.2315797380382015, 0.3524585452771956, 0.18549098452973753, 0.4378101782452676, 0.16692306636081589, 0.19022813517480128, 0.3243041705460318, 2.2353207632418606, 10.959368002030159, 39.5921064192249, 96.33863602915119, 89.84137104403588, 57.44196584147792, 67.9772638505505, 74.70983182230304, 63.30157895242015, 55.604272657825106, 42.68604847692674, 30.85734105879261, 52.162232014440725, 66.18725884345271, 84.75087196596208, 92.68655638540946, 94.79767799377443, 95.0400177125008, 107.90470154054704, 78.15172733799105, 19.0745214493044, 0.5972200824368386, 0.1443250660574244, 0.14857533718309096, 0.13708682220068671, 0.2805704785691154, 0.154050552256165, 0.22091496675725908, 0.12254981354119317, 0.09368185855207906, 0.23618956487024986, 0.12755479618546464, 0.19051696564401352, 0.1932538147535055, 0.1596033873577272, 0.1715105693907507, 0.1293274240508195, 0.13238563172278867, 0.16877735153801982, 0.11012802726679272, 0.15145901470415055, 0.11707727211497485, 0.1429448820530407, 0.15915977648429333, 0.17138482371885932, 0.15142588906230467, 0.11321790501355164, 0.1420114345608219, 0.12679024043703271, 0.19140202702293474, 0.16185479719311963, 0.19942698189087454, 0.1982773443864238, 0.14199269605019402, 0.14527518362287553, 0.19870692052908484, 0.1823400955406889, 0.16962942517092153, 0.21743318907195525, 0.16120711581841593, 0.15158209439006545, 0.15267272780258812], [0.04179932762898746, 0.03378653057640599, 0.04262021765293133, 0.056567798263483474, 0.031391546287904346, 0.04649919660521611, 0.016657300631425554, 0.022463938747082027, 0.10567810596717943, 0.031962835290018594, 0.03306130961244626, 0.02499822463329521, 0.03520428353259641, 0.01929226579264768, 0.06607357427598008, 0.01804913300269794, 0.12532127450310415, 0.05635760671969864, 0.06935269106179476, 0.03148445168570165, 0.041681219853701136, 0.024741613906958414, 0.04667293768556369, 0.06587665903592302, 0.017393635615946788, 0.028144852258265022, 0.07298970114319556, 0.02835619867959571, 0.09223613572577316, 0.03052154811279428, 0.042021117743945895, 0.0161073969737176, 0.051139724410830006, 0.034115354665705276, 2.168059959526985, 27.224018189214892, 52.595281293315274, 69.99084395747032, 73.70980785739037, 74.18188864184965, 75.4693203587686, 76.99602450093916, 58.418785064451164, 33.5886090032516, 17.534681289426743, 18.001196230611495, 25.514562975975778, 19.77021851847249, 47.22613311582997, 47.680539700292776, 41.28666839291973, 40.345491747702326, 17.334148153182, 1.8403562278516832, 0.11946974938074428, 0.1448063224914574, 0.14174829868059005, 0.08132017187533841, 0.0531235090907543, 0.10076487001271979, 0.06291002185354311, 0.05284619675348363, 0.11097561928533739, 0.18280193930672062, 0.11750838809436369, 0.17595056985174456, 0.3427023849179668, 4.197759782114337, 1.2067268668643891, 1.5070918010127161, 4.006230691748281, 1.9628583447587107, 0.2498860984680153, 0.1107133720670977, 0.5441430595613296, 1.1209630173060203, 0.8219278892201762, 0.6245292783264191, 0.24667262009555296, 0.4543264210224152, 1.0320604135913234, 2.31589213013649, 3.434875208523966, 3.2622401752779564, 3.0462256891112176, 1.7110077363829461, 1.7570887217598579, 3.72733865053423, 1.3805696224012685, 0.16620613063775724, 0.26070272369730857, 0.11962728004061407, 0.08635634961988657, 0.07938999036747603, 0.03239516934920703, 0.09187874038733783, 0.2391937327000403, 1.0387391068281666, 5.090157341572547, 0.6537563906561944, 0.43422669472713626, 0.24069040803419006, 0.3065109204861426, 0.5993078252480877, 0.048556299729933666, 0.15644921951236265, 0.1097567274325317, 0.0746929367643691, 0.04479079755143293, 0.08126957942881892, 0.13215378287338442, 0.0712352219007669, 0.07045581170748319, 0.035737342832069245, 0.031725600842506654, 0.021747184969905405, 1.327651455517738, 5.724196712816916, 35.32566985776348, 40.4978758288968, 36.525922975232525, 44.06913895760813, 35.14744520187378, 29.748243824128185, 21.512266666658466, 17.73503791901373, 17.79050023325028, 39.34406749663815, 41.427002952944854, 53.11987476964151, 58.285004784983975, 71.3547383585284, 74.19423626315209, 89.1834326713316, 62.3329653278474, 12.760426248273543, 0.4677985061801249, 0.009644440799621085, 0.06343428263320558, 0.03268306902159126, 0.031127261275786067, 0.0283520809570027, 0.022975492043300502, 0.035821731247368364, 0.04595761840802528, 0.03059240358491098, 0.06935665939724253, 0.005756670988405184, 0.016136339775496916, 0.0694317130311843, 0.03691327247408129, 0.021453756057927688, 0.02005635422744578, 0.031040310296380234, 0.024310884801971338, 0.044762467619993036, 0.009762759249086582, 0.05436676253955211, 0.03143856110381744, 0.05825093173752389, 0.07102136845670401, 0.0447684201231647, 0.010132753861046607, 0.1389233647815643, 0.02508488449928982, 0.056473872053527066, 0.025916978559126298, 0.08080653290474608, 0.025801569328553257, 0.027922370748954917, 0.01972063343160816, 0.017428320246718584, 0.01897381453384315, 0.013539716357275123, 0.008989856972719633, 0.0762871350912798, 0.03844469372603682, 0.02884744490016132, 0.04989907949141437, 0.006517748697660864, 0.033604109719876325, 0.033290431188840064, 0.06517555835025926, 0.019433959499902783, 0.0597487025774054, 0.026710770137968565, 0.03316396156386022, 0.009995857779417309, 0.10535895373792419, 0.01471356702818265, 0.05059234692805237, 0.09237163369694064, 0.024418382259506374, 0.027366625670824322, 0.03441846884426571, 0.04092376190988768, 0.03645763785067586, 0.003368456762531893, 0.1317148298145302, 0.06882847241696811, 0.02979163486029833, 0.08884687081820543, 0.06927058175807038, 0.03429067005673724, 0.028210144016831636, 0.014718037151220827, 0.031894942662949045, 0.0203045571388136, 0.06893616905736347, 0.028841586242760384, 2.506233968081013, 31.80210667271768, 61.480587220961056, 83.62698739574802, 82.71486374639696, 83.10049549225839, 83.05702778600877, 85.62005350666662, 66.49510214405676, 40.81871394188174, 25.829590097550426, 34.10326711593136, 35.34537192313902, 34.342598376735566, 57.43569397157239, 50.63204088518697, 49.827727502392186, 42.86449670791627, 19.625459524892992, 1.9673403881249891, 0.19241732334898365, 0.12972821060928608, 0.10620811623671364, 0.13082098906799672, 0.08848824973909125, 0.025522261332239837, 0.17670666798949244, 0.16860001750530737, 0.5462695357780303, 0.43130716429122035, 0.884197905900017, 0.9935743013216604, 1.9486591195867908, 6.399044423334061, 3.464507244286999, 6.5435072779655465, 8.56012280910246, 6.144370811600839, 1.4938101653129825, 1.0310211080697276, 2.949604718915878, 5.748755162762058, 2.735910805002336, 0.5408124769887617, 0.43271940141435594, 0.4888332887522636, 0.5081258648105207, 0.5358303314255131, 2.813897575101545, 3.7063880457032115, 2.2651876509189606, 1.2839647094088218, 1.493970369619708, 0.9042291439348652, 0.8953412982725328, 0.12520901963955935, 0.5352109646604908, 0.13129792476613678, 0.1688638122211541, 0.6093259876774204, 1.0699771080286273, 0.4134940572323338, 2.33953740327589, 2.4461175164868756, 8.094206519665258, 5.8326742725987595, 2.8907777465158895, 2.516050680029777, 0.9880734223031229, 2.5717743221790563, 0.5848212251740118, 0.4994132694217467, 0.12955361917134256, 0.15794163539765343, 0.14725230333785858, 0.17512754627293156, 0.18780401847775907, 0.11082959526609029, 0.06027740666702871, 0.03280033410016087, 0.020795445213274612, 0.08687328276855331, 1.4048403910090848, 7.517831873509192, 32.58635320971089, 42.99886926527947, 50.31754524477067, 53.351957490367276, 42.490898793743504, 42.01516628265381, 23.673310241391583, 28.601572244398056, 34.59916060970676, 50.54950244965092, 53.1544190837491, 66.58381046787386, 67.37478779208276, 79.72531164846113, 82.62554353283298, 100.23270237830378, 80.87073003092121, 20.931314614511308, 0.5682926024160078, 0.02095544650670021, 0.025013575120077982, 0.051992770975395564, 0.02893783369912736, 0.04288438009098173, 0.03397704515185568, 0.032111810662993984, 0.07483200470526373, 0.04220549212468248, 0.02974774759833611, 0.007868957341528468, 0.058823885065653635, 0.024389347527176145, 0.0617713968630039, 0.04374399585949798, 0.07905105774801585, 0.03706047626873178, 0.03394770015391611, 0.018193216904276804, 0.04727139791113235, 0.00962832518252394, 0.08182103249935374, 0.08752647231543258, 0.020732963082170295, 0.02685240064296992, 0.06271314491788227, 0.08802420730071683, 0.09226738445220456, 0.03505597274089533, 0.04438790042073496, 0.024468961299487182, 0.03019561600540915, 0.015709302256694965, 0.02177271101954243, 0.016398809159234647, 0.060092993981895916, 0.03161379797083717, 0.054872786596177094, 0.09871772220057827, 0.1919487073657013, 0.09493228258384813, 0.1167502981280127, 0.16840399092724248, 0.10123954575148322, 0.15631964340084986, 0.14973482657824794, 0.1695828317033668, 0.28952699635298024, 0.12454751803870164, 0.14547323267306053, 0.16954912383469845, 0.23041457959240486, 0.1683423208493379, 0.18783446281186997, 0.13530890066777507, 0.19241284939550585, 0.15139164493208931, 0.1487488560979405, 0.12015462432417179, 0.20538086402079753, 0.18179113225590798, 0.12833572323283843, 0.27506236768057274, 0.20005261525511744, 0.2392023128847922, 0.16226261643873108, 0.136541903860146, 0.24007280327139363, 0.19418773722023736, 0.09692138391396693, 0.09703874092308745, 0.16088623223045181, 0.16063769798605673, 4.146607662400892, 44.05415158117972, 76.23961894742905, 95.16380771513909, 94.39419946362896, 94.09043542800411, 93.92493494095342, 95.80228328704835, 76.70471006824125, 49.174648946331395, 28.476015213997137, 26.628727912902836, 37.19495381078413, 32.835578649274765, 66.37880386844759, 65.0326934937508, 58.21336269378663, 56.53381163074125, 25.51221347624256, 3.0652001548197965, 0.5094869579038313, 0.4837545241800047, 0.3105325450099284, 0.3191950382484544, 0.25559408169600273, 0.19258920283567524, 0.3575903231338147, 0.15161425476112675, 0.576029661442003, 0.5232883689384307, 0.5382070426018007, 0.5311490439118878, 2.1296253896528676, 11.3822102931238, 2.984098287359361, 6.554217309721055, 14.958400899364104, 7.236123325363283, 0.39654025567635415, 0.356442325057522, 0.750117565114652, 2.821537861900945, 3.2644756811280407, 2.4213600062554885, 0.7751447995824199, 1.250559108391885, 3.280818971895403, 9.130723726364876, 10.383790577611617, 12.129652250197626, 9.948299623304798, 7.8937282966029265, 7.033017604581772, 9.396587860199714, 4.024441766162073, 0.4948499900919776, 1.2549046042465395, 0.3916999283096483, 0.27300214274756374, 0.6128051913072986, 0.7121640984569827, 0.2895306735750168, 1.9330661046889521, 3.6816396059528476, 13.471179335348069, 8.685770054017345, 2.3947744263756663, 1.1616808969166972, 0.4426375434042946, 1.6316367373351128, 0.6662510395530732, 0.5412665526232412, 0.2882870677257738, 0.306706395480902, 0.18561432468554667, 0.24990422410830376, 0.3906095706887784, 0.21856123821869974, 0.2816876799108521, 0.1551986575847672, 0.3008346992634958, 0.3060188775341357, 2.0822512478597703, 8.310098186615976, 47.016302001091745, 56.15433408368019, 55.215228449913766, 61.10685202383227, 52.64370687546269, 44.89808090271489, 36.34123033092868, 30.357495777068603, 31.889577488745417, 54.61561964404199, 59.98754093723913, 72.54195351754466, 78.9516241319718, 92.46729589277699, 94.27109195340066, 109.93954873854115, 94.11607203945037, 27.32455049791644, 0.8438147147816997, 0.11448624784186964, 0.11702776751330785, 0.13840732795576896, 0.1819491455511701, 0.12408327641746691, 0.1620187859741911, 0.1198801196991436, 0.19123066847603168, 0.13759414094590372, 0.1637762989247999, 0.1111783414718605, 0.11395207771490659, 0.19197570430415292, 0.23949944774710366, 0.08776786662037335, 0.11521914117639104, 0.17911344045592895, 0.1306091044698992, 0.09497740516258825, 0.09800612611035187, 0.12745787074128467, 0.11138354578325826, 0.21417933786588333, 0.1663156505674124, 0.16231238151029234, 0.20711747809283196, 0.2567054454477564, 0.29898527108373185, 0.16409888322795593, 0.12080325564790158, 0.17635483444938738, 0.09688871026399637, 0.11740069145396834, 0.08265343299435993, 0.17785098884374867, 0.11570283377002324, 0.10769095602295092, 0.17553810811331197, 0.26818004827345576], [0.02628252507307597, 0.024942026338389805, 0.0434511817330795, 0.07011185355123974, 0.031058332514798934, 0.02433708883942135, 0.01960096858261574, 0.07131409831345081, 0.04883036385440538, 0.0869291918652673, 0.03281143471418369, 0.02913205805535038, 0.04411583961618524, 0.1297767499401685, 0.029897826137922467, 0.05240252459301584, 0.027395943855686535, 0.024523707857776075, 0.060674948843135956, 0.03247475056278129, 0.035746681443866224, 0.02616709860552463, 0.028315414073726827, 0.05508301644435814, 0.09254020368379932, 0.02410344542905448, 0.01961904825762876, 0.070331176863082, 0.033238199314162616, 0.04347771518833695, 0.028403447152325706, 0.06261986605222188, 0.13083364484050583, 0.6044927696066519, 33.77663566220191, 57.75222924447829, 67.0476621197116, 73.91333964563185, 61.43853941271382, 56.26162267500355, 49.02957616313812, 32.34238570736301, 27.818182745287498, 28.41614023331673, 28.41257872120027, 17.234580747542843, 25.11499897126229, 23.48930205068281, 22.12792581127536, 50.33666287699054, 35.25997015737718, 9.131632735652309, 0.17883715850691642, 0.04316690948701674, 0.1385496211268248, 0.08397955417392716, 0.04456932919340269, 0.022405974619511156, 0.18766765482723716, 0.03583329151414576, 0.08883488920306967, 0.27749497263181594, 0.2904997441557146, 0.3089012373839655, 1.0394963694195594, 0.9320543153632073, 1.4561248907158453, 4.981967585702097, 5.630060318977603, 3.3463348111798688, 6.853281855583192, 5.184282948893886, 3.2576713494716154, 2.131689536956049, 3.4372305918124417, 9.010608003985498, 0.8684864844526015, 0.23544835948175002, 0.2531929782802059, 0.40908592602899, 0.240889054632956, 0.5828424507091122, 3.201948197618608, 4.120343962023336, 2.474095782926006, 1.6525260551321892, 5.619666038020965, 9.56149410816931, 11.05176531499432, 8.437033930132467, 3.476441300684406, 1.4179639061612468, 0.264596993764562, 1.2261830486597554, 1.2925645060116246, 1.1772892335730216, 0.2881285488124817, 0.6810757601934095, 5.167757022765375, 5.024332615637011, 4.346574506452007, 2.8191236430598847, 4.182141394384446, 2.100461341681019, 0.6815955355282753, 0.45347505219040385, 0.13377431930313188, 0.1552012163184343, 0.10780054490051924, 0.14373248172623498, 0.11555195275333621, 0.06359195118890175, 0.07590281176230601, 0.16183101782394996, 0.02879483955762079, 0.10434072329512528, 0.03135294120218004, 0.060761922805179516, 0.5176443846956377, 16.462085631585893, 33.48767072923722, 42.00232444270965, 29.21668225719083, 25.104108510478852, 34.0575401244625, 18.01536775404407, 20.046445554302586, 18.583623093943444, 26.091706406685617, 28.043762176267563, 53.47952081311134, 56.420694397341826, 61.06793426698255, 68.0425085559968, 84.22479583371071, 67.78909990864416, 27.528664758128507, 0.6374900151164301, 0.04364132858632554, 0.04160992388102797, 0.03671647214721288, 0.060339620667359525, 0.06625240984102411, 0.07749322561487075, 0.027541220939207463, 0.04906505489000871, 0.034006596993534796, 0.018903631303880005, 0.02852560370229185, 0.06420040503144264, 0.015364566521208375, 0.07020463445974935, 0.05466185577754533, 0.07286495904648498, 0.08977961350953387, 0.08171312135433959, 0.0630522499071254, 0.07970620081910203, 0.04384574382716129, 0.05908425536847884, 0.058647378407899416, 0.015716220988261125, 0.06394167032633578, 0.05427864710650137, 0.018885005791220936, 0.03029178302254408, 0.054404116986740025, 0.05306705607161407, 0.03373814446310844, 0.037367915013624776, 0.0650116614997387, 0.046828066659790855, 0.04421736541835051, 0.06251383948350145, 0.015239065997452747, 0.01575958539521502, 0.03009225159222561, 0.06457000415051176, 0.0604112230752024, 0.050292572892841794, 0.057168261808974136, 0.07346907300093482, 0.03121013666743473, 0.08010758492614954, 0.03331515284615659, 0.05223153759875605, 0.03647168407276754, 0.035809171235849785, 0.057597899238669106, 0.055658566810551195, 0.06581127343158569, 0.06983689693433624, 0.05426586492948475, 0.04441996886124534, 0.056342782918363817, 0.01522134829898395, 0.03149938848500531, 0.02451377552783778, 0.021130357786352118, 0.06482540254270838, 0.07605063608817517, 0.019808492225204265, 0.05656046680204811, 0.04656761974817322, 0.011072733210429791, 0.0458739347936165, 0.05064805301146642, 0.06854118944536294, 0.18952132713410164, 1.1853482333883163, 42.29429783359651, 70.4035557470014, 77.70263948748189, 82.19559684876474, 70.63772124628868, 64.27738620388892, 58.05234939821305, 49.40174633456815, 47.55843239445841, 38.04221714696577, 23.97018071143858, 18.03214765364124, 25.64114570617676, 22.240495874035744, 32.229494010248494, 52.97361350828602, 38.22913769752749, 10.713658967325765, 0.21964701463378247, 0.045495464376384215, 0.07277073023179847, 0.02528130561263571, 0.12443877951872927, 0.17549094774069326, 0.2551090101441068, 0.26627374572619317, 0.38940947863363456, 0.7272291255574073, 0.7602109267346321, 1.4870883260042438, 2.082912167233806, 3.1601957928749824, 3.539899121369085, 9.119762662918337, 10.167341443800158, 8.394838052411234, 11.646402516672689, 6.295003554513378, 7.572439601344447, 5.228371860519533, 6.6513440205204875, 9.270532688786908, 3.798609342305891, 1.3545434705672728, 0.18600081604334617, 0.29397367710067385, 0.5578510691562008, 0.4597462479385638, 2.3323006303079667, 0.49858886688466997, 1.0119556924027782, 1.9818656603174827, 4.382120986138621, 8.540481540464587, 8.859382002584397, 5.875389374071553, 2.436301785130655, 1.3563791398079166, 0.4280444571087438, 1.78230956196785, 3.536062553044289, 3.393506950909092, 2.964034873631693, 4.375692711722467, 6.410114822849152, 3.530690131648895, 7.814857767474267, 7.624777257442475, 6.695820756496922, 4.516785760079661, 1.718511720818858, 2.786395141193944, 0.8202551822027853, 1.4188586968568064, 1.0055477039948588, 0.5526512933354224, 0.5522612626514127, 0.20682754445700877, 0.12644098095235326, 0.1403516744293513, 0.09456744087078879, 0.04210439150131518, 0.011746113004553463, 0.07464718599353107, 0.7446597095939421, 13.423190116882326, 33.28409971729402, 41.723506681380734, 27.941886455782, 22.70092918026832, 30.003617578937163, 13.911780157396871, 20.116144111079556, 25.87995529174805, 37.157161774173865, 39.02313524676908, 65.04682971585181, 69.59107598950787, 70.9167351261262, 77.17408441728162, 93.76746746801561, 85.21942261726626, 37.898760380283484, 0.8605215602344083, 0.023188592805977792, 0.10191973989769336, 0.039401246430051905, 0.03285221740483277, 0.06799167457727656, 0.025997865952611453, 0.03442196603564005, 0.02110774670126698, 0.009387597374077286, 0.06142949182239752, 0.05196020074729478, 0.06776922562670323, 0.040574207481357365, 0.052866532557433656, 0.08459136731201604, 0.05055804534124271, 0.09962608031327687, 0.04223687108606101, 0.039872915273712534, 0.049588162707345146, 0.009675709635860497, 0.013542635152266632, 0.058631485913910215, 0.050670648774793076, 0.060141908695861224, 0.047041399164065245, 0.07804024303632398, 0.06687645740326374, 0.022589960210626165, 0.01769286955917074, 0.04829988244079775, 0.06727989462594833, 0.028188553743905602, 0.040731592584521546, 0.06566266769603377, 0.03782511245639574, 0.036137566315911474, 0.014243198618773493, 0.11512689652942842, 0.21491804580775, 0.12126300799390002, 0.13191289418647367, 0.17474192825536575, 0.18026255702059116, 0.15646794270123207, 0.15836206445049855, 0.11923163393211943, 0.2120070189477936, 0.16073532823112704, 0.06289774146411689, 0.08646870407486155, 0.19742229833237587, 0.13384463085282233, 0.1421481352900305, 0.1420103773594864, 0.17227906283111344, 0.21192933763227156, 0.09754744628744741, 0.09691574550684422, 0.11957327084195231, 0.08496709513447939, 0.11673305348883714, 0.12589451511420552, 0.0856168372856994, 0.14336754808262472, 0.16115630886727766, 0.1347275471855556, 0.14066740990646426, 0.13335122426431026, 0.21402883223227917, 0.26170081368857817, 3.090597256537407, 55.834260832878854, 84.74918534678798, 88.04867529099988, 93.79633611248386, 81.31354993389499, 74.50932810383459, 68.57041251274848, 48.93935772680467, 42.34441395728819, 43.00866342359974, 39.13984537124634, 23.84086997278275, 34.24805356610206, 32.95063941709457, 32.354472491049, 66.04178597850185, 48.462644623171904, 13.970799080787168, 0.5204972961256581, 0.09578361311146329, 0.21175971044407738, 0.2825998148370174, 0.20583835640741935, 0.17648059544303726, 0.5119015138235785, 0.18950468770438628, 0.5563716001568303, 1.1362576869226273, 0.6166730773064398, 0.7430663079984727, 1.6371738982777444, 3.2499310422328214, 6.437022282231239, 17.64317012602283, 18.039107899512015, 11.498928262341408, 17.983467117432628, 9.524322786638814, 9.013432110509566, 7.497179613959405, 12.312594536812076, 22.550504322974913, 4.9575493604906145, 0.516980707405075, 1.166030315141524, 0.9233632623668641, 1.3370492093024717, 2.7036907403699817, 9.893537452144008, 8.834540651690576, 7.318247460549878, 6.541500005029864, 9.158450961112976, 10.173104386175833, 8.541671979811884, 5.60998906050959, 3.9892885040852333, 2.8063695661483274, 3.133358200711589, 5.347014732899205, 4.8569812601612465, 2.774693485229246, 2.966374077143208, 4.583371425828626, 14.16929650691248, 15.814565074059272, 11.342984630215554, 7.918416184763755, 12.079642030500597, 7.830599219568315, 3.023680150508881, 4.668970780987894, 1.3235424050400335, 1.0355260727867004, 0.6283410866895031, 0.5074885409445532, 0.39215256369883017, 0.18450141343618595, 0.14864872840623702, 0.3425778190214788, 0.18790584688465442, 0.26372126333655854, 0.06544912834801982, 0.3314589108190229, 1.3906579584844652, 22.251541268440988, 46.78632559314851, 58.86004386409637, 43.85764475791685, 41.27823529704925, 53.671846389770515, 27.009160557100852, 29.50229552484328, 30.0700056552887, 43.801139093214466, 43.257863367757494, 71.76775609293293, 75.80675401995259, 82.90203925101989, 86.67261369766729, 104.79299899070494, 98.15289697339459, 43.407050717261534, 1.066534125035809, 0.07347334011067307, 0.25761293788110057, 0.21836818406178107, 0.1621397359356765, 0.19971519948974734, 0.11461726419868008, 0.131181632619231, 0.13278172982315864, 0.16021359171117508, 0.22887140272125123, 0.10092096808817118, 0.1886282984407679, 0.10989500630286433, 0.15509673724732093, 0.10739332320348871, 0.15018698699291677, 0.20954156414635722, 0.29807644565739944, 0.11009203645611003, 0.18415440625000387, 0.08408682180508491, 0.11409838518668568, 0.1263075437577021, 0.12644304938974882, 0.13736595399677753, 0.1378430888777779, 0.16141386762742074, 0.14850998988314984, 0.17611509489436306, 0.10931948274974862, 0.24120927938530523, 0.12366810272778235, 0.09564788531391852, 0.16300359200085365, 0.15198966848754114, 0.12890851185206445, 0.12264608014975825, 0.12887881828411935], [0.12496485209633267, 0.03565089364025382, 0.12688790898649924, 0.09426544901103744, 0.06808867663024895, 0.07537062580306685, 0.08903230240027751, 0.0393051368695113, 0.17497294972981178, 0.16588322457767304, 0.01934190062926181, 0.03678147470758807, 0.05521594419053966, 0.034991908638227376, 0.025465869600133553, 0.026029206609593767, 0.05290680196917346, 0.0248482437699192, 0.14229939168980046, 0.19989896866102375, 0.30737696756278315, 0.2731625002718741, 0.24544926961102795, 0.21273515487630523, 0.30175115492555404, 0.29452648614683463, 0.2851100704602657, 0.11812082942455046, 0.09323227985371506, 0.019469984784542073, 0.08450950315642743, 0.027323211468155348, 0.6621455437233371, 28.018968874408355, 58.79100622669343, 69.70279293675577, 72.50598538306453, 60.5933000195411, 52.714301693824034, 43.18506025498913, 29.28640434818883, 21.29364944273426, 20.066492788253292, 16.1948614158938, 40.94347669232277, 79.1326964286066, 50.76745679301601, 66.74908345745456, 72.65805567464521, 29.333092320349913, 4.381218350702717, 0.20823504715677232, 0.09180033894916696, 0.1434319760770567, 0.04292597483483054, 0.11562807891037195, 0.11416351032112876, 0.18511520308111945, 0.3402257758763529, 0.12121822249384658, 0.30596497558778335, 1.4606910198926928, 1.6921960490365184, 2.6222137962618186, 2.3861464377372497, 4.234007875765524, 2.3682513592704653, 5.483913786949651, 6.692145985941734, 7.631850761751975, 7.487697774364103, 7.51081818534482, 11.080102478304218, 6.553817227963479, 15.326614379882814, 14.177394240133225, 3.275442628129836, 2.4994470419422274, 0.2894003466973382, 2.3079191773168506, 2.4397534708822928, 0.4373839269241979, 1.2010813504457474, 5.627973618045931, 12.806904373630402, 34.81296900779971, 58.64217973524525, 73.59104633331299, 79.19098284936722, 80.31617749121882, 55.00028256447085, 35.06484400841498, 4.4215192333344495, 0.8088068255493719, 2.71338316221391, 3.806690895749677, 3.5065486786826967, 2.2901106361419927, 3.533311010368409, 1.9339814878279165, 3.1153241232518227, 9.952299460288017, 1.7979663153809888, 3.6725482873378263, 0.9064969480518372, 1.8906682249038451, 0.4078208390743502, 1.0527317946957004, 1.1714086200921767, 0.5618929490447044, 0.1375177466580945, 0.19105615364688058, 0.33263485578279345, 0.09308408780564224, 0.14753653727952512, 0.1124415668328443, 0.09401489229452226, 0.0378795123598989, 0.040685332365213864, 0.0792458049592472, 4.88479184527551, 30.051105714613396, 59.32738642538748, 71.0559400435417, 42.31975793838501, 48.99064663917788, 39.17736676431472, 28.070591188246205, 16.890551620914092, 20.85108449382167, 24.297163217298447, 31.2237786862158, 63.90343135403049, 76.11957873067549, 78.75548993387531, 77.45685592774423, 76.32901760839647, 33.74757482159522, 1.2157605756675045, 0.0420224967022096, 0.030495673493151704, 0.01145892387871901, 0.04806207725778223, 0.06901901380549516, 0.07126755081117153, 0.015631262795068324, 0.019885240828678496, 0.048674706279510455, 0.030280021657686562, 0.041707852900388746, 0.19915911158727062, 0.1199743485138301, 0.39873221708882245, 0.42090240325177875, 0.4358320779377415, 0.1941534011594711, 0.15924171724867436, 0.25053373387744354, 0.05754311629120381, 0.07348184368663258, 0.13329525388056232, 0.1509337541797469, 0.1260105238085793, 0.035382613479610414, 0.05328175987327292, 0.036810589879150354, 0.01141007332461736, 0.057490581811796275, 0.02001035639325217, 0.027519891136175686, 0.06072504716294427, 0.047466225561595736, 0.16434018560234578, 0.11818153423167045, 0.060257434754842715, 0.12223086815567748, 0.08977736887191573, 0.0584414309912151, 0.1220435060320362, 0.10467500576088506, 0.06420476024129218, 0.10983986329407462, 0.04087765873860448, 0.07606111617097933, 0.11725329613733677, 0.06334157067260916, 0.05673562897549522, 0.016367497230549494, 0.01047027879394591, 0.004829513556849693, 0.021859594966254888, 0.04038241736951374, 0.022491222968505278, 0.0663697591892654, 0.038057474584709254, 0.09552842922388546, 0.17226182585281713, 0.12792650970720476, 0.17162798002602594, 0.17501186699636523, 0.1932299740973019, 0.15844195209924253, 0.08961803024454464, 0.05387427525654916, 0.1076263058630209, 0.043997180257593436, 0.09655787519389585, 0.03987059785774158, 0.7729768320437401, 34.352741626001176, 71.77134898401076, 76.88316222160094, 83.51379563731533, 68.33980852557768, 64.62941108211395, 52.79878562496555, 42.16048617516795, 28.731618427461196, 24.043685928467784, 26.98868774598645, 39.45915375986407, 49.2156377146321, 32.928525094063055, 47.016407905086396, 51.10469825806157, 33.18925680652742, 5.804887712001801, 0.09093328063646633, 0.03741008049297718, 0.030098577563260353, 0.040684370924868894, 0.17983998292155806, 0.6103597773659615, 0.7243125368991207, 1.0025110540370787, 2.135269435182695, 1.1022438733808457, 1.9878986333647084, 2.557938406544347, 4.637627611237188, 7.2215154382490345, 5.264623876540892, 4.48609370377756, 7.422788921863803, 9.73549044901325, 6.639162609654089, 8.590277010394681, 6.283715463453724, 5.188477433496907, 5.664086389926172, 7.376250980361816, 11.630255099265806, 4.581009668688621, 3.7703246406970488, 0.6661923265745563, 5.042369144578134, 3.1939781865765973, 1.7818436579358194, 2.879550207045771, 7.898676856871575, 15.025714655076305, 35.17357210959158, 58.28600891174809, 78.21098650655439, 81.83356208185997, 81.89201324216782, 51.4420573942123, 31.46520253150694, 6.376094145159568, 0.5728184047245211, 1.1803663329732035, 3.419580661481427, 1.258518823212193, 1.936403183687118, 2.747567844006323, 5.322785271752266, 4.695714481415288, 5.985713389612013, 3.8304675682898495, 4.380119596758197, 2.891494804813016, 2.4479397025800522, 2.348723349071318, 2.5317649206807538, 1.8883029131158706, 1.220138185927945, 0.9589770352167468, 0.7189197069214237, 0.3369632525549781, 0.05595027393991909, 0.11324549950058423, 0.12695774556167666, 0.06860195553951687, 0.036334565825640194, 0.03624510973872196, 0.034126834493250616, 2.992492649824389, 26.240199496669156, 45.771824159929835, 52.262695681664255, 41.60746728220294, 27.624647117430165, 23.138367591365693, 29.248451494401504, 25.37017660756265, 32.35459212333926, 41.63272342374248, 44.62330318266346, 70.4211671890751, 83.39166087488975, 88.55180555774321, 87.21464603177964, 90.81902180948566, 44.8357387511961, 2.2700045666387005, 0.054528770983339324, 0.02352490348951711, 0.02824186580255628, 0.010867911942994163, 0.0758497295300326, 0.046596118218956456, 0.013996198465446792, 0.012272708437165186, 0.02626245548467963, 0.07982786324235701, 0.04194585726626458, 0.1386942125616535, 0.07503630503291085, 0.40472186020305084, 0.3032981315928121, 0.1942785186392646, 0.12695586864626215, 0.08102964835181352, 0.17664464551114267, 0.11215246057197933, 0.06814453976168748, 0.04753321612013444, 0.04108810692184395, 0.10795665829772912, 0.014525474248183592, 0.024004175755826217, 0.03958139583588608, 0.014539272449309788, 0.07531357523534568, 0.03344230045894942, 0.07440288821535726, 0.06681196812179781, 0.03624021826732544, 0.05457539126397141, 0.12684056475277872, 0.03144444848951553, 0.14509234907886676, 0.24854556717459234, 0.16114999630278157, 0.34298874858406286, 0.20009104222539933, 0.23728966712951663, 0.29942494426523486, 0.17691029415976617, 0.2211526072313709, 0.24166255828834352, 0.255069388076663, 0.08415874980029561, 0.11732425120088363, 0.08503323150498253, 0.17981217392990667, 0.09999489036178398, 0.21091724355374614, 0.32851900244432114, 0.13319077480944896, 0.26751238732568683, 0.24435227766873377, 0.45415493990144423, 0.352536962037125, 0.316907377132485, 0.46700814859040324, 0.4376565316511739, 0.38048878312110906, 0.3740417855160852, 0.16781234122332067, 0.2749214075025051, 0.2069834893148753, 0.25709935253666294, 0.15324721713700604, 1.9063268169280023, 48.09405165333902, 85.82054938039472, 89.06076446656259, 93.77824614124914, 79.81649106548679, 71.06970756284653, 60.85339238566738, 44.80365376318655, 34.934189857975134, 31.552490957321663, 29.948196449587424, 57.79594798241892, 98.30219807163363, 66.07134496012043, 86.40306057468538, 94.03531043760239, 44.68764574297013, 7.154683153475485, 0.46408723919622363, 0.16662372516528254, 0.33559667427212964, 0.2474603423428151, 0.31854803103112406, 0.5312577058230677, 0.5347511280448206, 0.6702883842010653, 1.8147116490910131, 1.4511056052100275, 3.7037835919087936, 4.39322570639272, 8.198259155596457, 11.493834084080113, 16.4960886586097, 13.195983882873291, 15.728203308197761, 18.362701477543002, 17.519111441027736, 20.27043838654795, 15.259900746806977, 25.514137398812082, 17.581577147206954, 28.910360836213638, 30.238777399063114, 13.282960480259312, 9.065735936164856, 1.1618858407582007, 6.720460105326868, 3.6737789309793905, 1.7918868867620346, 6.239743732636975, 9.74926483246588, 17.661289515033847, 32.32388192607511, 49.59500151295816, 69.38373950219923, 72.28897633091097, 73.33673554082071, 47.20826671969506, 36.25777406077231, 8.615207595209922, 3.296326062371654, 12.498744341634936, 9.74965608889057, 11.834362495330073, 9.311343969837312, 12.566162040156703, 10.992664021830405, 14.469504913976117, 23.330002830874538, 11.4418097272996, 13.738312355933653, 6.100861920464424, 6.100536854036394, 3.5268685173603798, 4.066071351689677, 3.639642543369724, 0.9356487999039312, 0.4011216453246532, 0.5245868573265692, 0.40473751904022315, 0.12117077100781665, 0.1432994275443977, 0.31418080892293687, 0.21329752469976104, 0.130902654040725, 0.12500180051692072, 0.20702191628515723, 6.912806764725716, 40.128647435096006, 77.29916095733643, 90.27487139548026, 59.0380371001459, 71.82714077734178, 59.0833757769677, 45.70093124143539, 28.236542747866725, 32.66515951002798, 38.49945176032282, 47.24845532448062, 81.11234803353587, 96.64049379287228, 96.78642165276312, 99.11266957559894, 100.06891988938855, 50.144929578227384, 2.630951120968788, 0.11855334734484074, 0.09192417706212691, 0.08795512915258447, 0.08850734831104357, 0.23565724101518434, 0.169166294377177, 0.1577172329228732, 0.10718659437712162, 0.13064986034747095, 0.2020336266967558, 0.24897269183589568, 0.3968798471314292, 0.2620383520280161, 0.4993595819800131, 0.49370710948301905, 0.3775779860875299, 0.30698794811483354, 0.16648074251509484, 0.307657171881968, 0.25228041434480303, 0.21561486406191704, 0.27223118250408485, 0.2541932439611804, 0.3330200447911217, 0.0800046686744017, 0.2528716503612457, 0.12919446183068137, 0.11369925337813555, 0.15737586414381383, 0.1706516775753229, 0.2399453109190349, 0.14471365649613643, 0.2632800886227239, 0.3028473654581655, 0.30184676269850425, 0.11492598997128588, 0.26728862836476297], [0.06506817580591287, 0.09423576310397157, 0.11414225138122998, 0.019008296151315014, 0.11341044589156106, 0.038580046140498696, 0.025746142867231564, 0.06619777245026442, 0.06971097506222225, 0.1903030892173129, 0.16794191733483346, 0.006993101945432324, 0.014401199465106814, 0.05704300260291465, 0.03451303090719927, 0.0302351595488407, 0.03312106447054013, 0.08167814944059619, 0.21086275938057134, 0.2502365377280982, 0.22727463033891496, 0.23955308922356178, 0.14467944300943805, 0.2334280936948715, 0.43857170028551934, 0.5198785422309753, 0.2596955019379816, 0.3264250696426438, 0.11548856663848124, 0.08738422510965217, 0.300751410184368, 2.2206773296479256, 28.062542484652614, 59.2620671949079, 61.888250920080374, 71.8931778015629, 59.77308534806775, 66.56372008785125, 26.92250167169879, 29.536629992146647, 22.553151922841227, 18.473075013006888, 38.72833774935815, 30.464694153878, 29.43537400614831, 80.21945968750985, 77.13747301409322, 52.42406591292351, 34.48758486778506, 3.6318335946529143, 0.3507352458132852, 0.022194748857028546, 0.08626603551449315, 0.10861553987788578, 0.2042760426599172, 0.09360293617411967, 0.23727440665806496, 0.3079155580170693, 0.6184652940400186, 1.8186134268199246, 1.1939130963817721, 1.9855915442589793, 1.25244687161138, 6.155560843406185, 5.293275319760846, 4.190997125640992, 3.089146960166193, 7.165811898246889, 11.56504471455851, 6.0706748693220085, 9.410227902473943, 7.8620257396851825, 5.477175645289883, 5.046378297190513, 8.207451230095279, 6.7405504853494715, 4.950480759143829, 7.512660718733265, 4.289654541400171, 6.992395087595909, 16.744700247241607, 22.088466767341863, 32.262949866633264, 37.17017227603544, 70.37544804234659, 93.38390673360517, 79.42340681629797, 70.1855190338627, 69.8155689239502, 78.01372266584828, 79.41991590684461, 86.39698874565863, 46.89284932228827, 9.890606461032744, 3.8437369465827946, 8.257444289422805, 3.445167753004259, 3.9357689888246603, 2.4023781861028364, 0.5033276722796503, 3.685281771805979, 3.96536989077445, 4.729338019124923, 2.406268196721231, 1.568470275209796, 0.8927732489762769, 0.605640369317224, 2.759013810465413, 2.252064871211206, 1.0502180457115173, 0.626996387877772, 0.845125154141457, 0.802112749267009, 0.17370228565508322, 0.3647394862867171, 0.1795617244657009, 0.12842034530495444, 0.021802352876552654, 0.05899304110977439, 0.034087197104048346, 0.08561862227056297, 0.33546015740402285, 7.670790581933915, 30.120978816863033, 46.02777450315414, 45.479784088750044, 36.35009488751812, 17.99423010118546, 28.783013243829053, 22.48582051646325, 16.32819748693897, 21.946302421631355, 33.58003470205492, 57.49306648008285, 64.02828824135565, 66.69553525986211, 70.84428894904353, 74.4768665682885, 33.6513041680859, 2.0226781671085665, 0.1322054478429979, 0.035565267992956985, 0.05518867146043528, 0.04598631989210845, 0.08673906416421936, 0.04573874708805834, 0.07109732607439642, 0.07428384581280333, 0.021076235589721513, 0.15701630843743203, 0.15404286073340526, 0.3115647718791039, 0.7214005447683797, 0.7181447936642555, 0.6526447664345465, 0.2423809495784583, 0.19418997419697626, 0.1937906432055658, 0.060361626542984485, 0.0170554154582562, 0.014150017429323447, 0.03767223961110558, 0.2469027529080068, 0.030409433060295643, 0.07593428265423545, 0.049041689208318154, 0.0699618305530279, 0.13717532067769958, 0.01652503363607872, 0.01540613924002936, 0.048994793136033325, 0.14435338066710582, 0.21627870989182305, 0.20865858652659003, 0.03713209782877276, 0.0360940448609331, 0.023323230843450275, 0.05479570282923599, 0.1091642197101347, 0.019630039704122373, 0.09504594704917363, 0.03045166174190179, 0.07432308483628497, 0.030892597053260095, 0.09570968562677022, 0.13077312389448767, 0.12132076336251152, 0.050460798140134544, 0.07607750279167969, 0.04654725330070623, 0.055524210310390884, 0.03484112338253087, 0.03650344607810821, 0.07273677721499436, 0.17858968146385687, 0.2690164324256682, 0.1616503742914046, 0.34727167037706225, 0.131260417101364, 0.13380004453562921, 0.411576294009724, 0.34841930073115135, 0.30559795818501906, 0.18223123444664865, 0.11770970833998536, 0.11784675380875988, 0.1309318573123986, 2.4818959063099277, 34.22886925358927, 71.4811328149611, 72.77061200911, 82.59714557278542, 68.23201394850209, 80.3353500366211, 40.953541494184925, 41.28818242780624, 33.09266059629379, 31.42103272099649, 33.585902567832704, 30.082967127523116, 34.82887814121862, 74.26181085648076, 71.72223306471302, 49.736300976045676, 36.10471140953803, 4.692026963157039, 0.02921214680217447, 0.03369038654190879, 0.053587149332968466, 0.1472522880161001, 0.6799427467969157, 0.3475535294461635, 0.6645898544980634, 1.0212832725336476, 2.275490491620956, 3.5807381041588324, 4.29989290814246, 3.4944481667011016, 4.997793859051121, 5.817507938031228, 5.833335191972795, 2.9844297276389216, 4.4128444214021005, 2.7964241514282846, 4.534708540285788, 2.406524621671246, 3.000316062281209, 4.171885867272654, 2.4188016403105954, 1.1185003817081451, 5.310832338948404, 7.068900917806934, 3.7746782264401837, 5.8144195618168, 4.660822056954907, 10.4490666620193, 21.53740513709284, 27.05472673139265, 37.15485149814237, 44.59310877707697, 81.53594047792497, 105.06081842607068, 97.67166922169348, 85.35834512402936, 86.58015558796545, 93.2893305440103, 98.57697579168506, 98.89354244355233, 54.00780523976972, 10.176254049424204, 3.5870827830606893, 3.5287225727112066, 0.9196020770938167, 0.6601849715075185, 2.5628622068512827, 0.7072182961048619, 0.422214895727173, 2.3874820047809235, 0.9068043638140926, 1.8829811148105131, 2.1993876849451373, 1.7845276623002946, 1.899396846851995, 5.20967343161183, 3.0354872201719596, 3.101171476225699, 3.3567227182849764, 3.0423641156765724, 0.9614932356822876, 0.3696489147841931, 0.3408100251709262, 0.3493391271800764, 0.2516771967132246, 0.1962454647066132, 0.13028710239356564, 0.01478735948987906, 0.17615085587866847, 0.2174216058225401, 7.956936311337256, 29.567648095469323, 43.158823520906516, 47.316673186517534, 35.290607790793146, 19.16778756726173, 28.574898166041223, 26.750513584383075, 24.321727060502578, 30.916133465305453, 48.783553338819935, 76.1952490960398, 73.09998912196006, 75.89038679676672, 78.51203626201999, 89.6745212616459, 50.39121520134711, 4.084109841815887, 0.11675919240881359, 0.0032810269781733837, 0.0795817191922857, 0.032688707428713965, 0.021993118345797546, 0.03972881796559499, 0.03399094964768137, 0.04002396099930329, 0.09426292858176655, 0.1166013399920156, 0.10745714598846053, 0.23801265494717708, 0.4310767250435968, 0.4191464684422939, 0.5059454560039506, 0.22060698408993984, 0.1946818179661228, 0.07130109780137578, 0.04717340760473763, 0.03302043882168589, 0.029444072260371143, 0.033578767531341126, 0.1690977295079539, 0.10311892796908656, 0.07109023976109682, 0.02966768566458937, 0.02492873471290354, 0.052041570776172226, 0.032261827915546396, 0.022382802375021483, 0.054390499773885936, 0.12206123330660405, 0.13084394106220815, 0.05014959407309371, 0.062222293232597654, 0.09108489709756068, 0.15020615451278227, 0.18091783798750372, 0.2943502552807331, 0.17237434884713543, 0.2535986831231464, 0.10628929857404963, 0.2383349021716464, 0.2103674988592825, 0.32012212721090166, 0.5673961569705318, 0.42183954328779255, 0.10827208733967236, 0.25014515876049, 0.14939705841243267, 0.1530543161976722, 0.14975739552849723, 0.3143381633825841, 0.32388141258589687, 0.29765028626688067, 0.49794360634780704, 0.6433937950961052, 0.5561540924733686, 0.4050605936396507, 0.39144635320671145, 0.7458369722289424, 1.0323534881876362, 0.4817715821967971, 0.6679197629132579, 0.2636763705841957, 0.22278445111888073, 0.49023158307517734, 4.644902137018019, 49.99842512992121, 86.21644989136728, 81.48535759218278, 93.97688281151557, 79.49200122587143, 86.22682063810288, 42.86768167249618, 44.76388877437961, 35.56624058754214, 30.37898252087255, 58.031788333769775, 45.0663427383669, 43.09027225740495, 93.30585941191643, 93.30542010645713, 69.98395627544772, 50.58288574218751, 6.198147487255835, 0.8277480736855538, 0.12103529601928689, 0.28033243972928296, 0.3069701135879563, 0.9893136267219821, 0.49970144105534403, 0.558956013091149, 1.1101007485581984, 2.738742756266748, 3.498954234584686, 3.5061878206268435, 5.696136076604167, 7.459535646823145, 15.91848042703444, 15.59208921847805, 15.543427313527754, 13.130939218305773, 13.9513058816233, 21.97404142348997, 17.619994801859704, 20.019463569887225, 18.405021890517204, 16.196772590760265, 13.10802375116656, 20.119211404554306, 16.487490823191983, 12.675673634775224, 15.277468062216236, 5.36086707345901, 12.68477745594517, 23.56461940273162, 29.915158325626006, 39.53930739433535, 45.86514519106957, 84.53817752099808, 100.6588992764873, 91.65879341863817, 83.96056144468247, 86.88169956207277, 93.13002740183185, 91.096050970016, 92.8757401435606, 55.75055745340163, 15.255449837253941, 8.398409370453127, 14.709414724380741, 9.497929157749299, 10.469388461882069, 8.460649540347438, 7.972945955491836, 11.664000230450785, 14.710826777642774, 13.920348575038295, 7.848685758729135, 6.517596590903498, 7.1724269755425, 5.364711486524151, 8.568958928508144, 9.62671822117221, 7.641966554426379, 7.0941649040868215, 4.1786210671547925, 1.3733215726191, 0.5754402027495447, 0.5584028363227844, 0.342637267444403, 0.2263342267683437, 0.19387705792342463, 0.3893890394078147, 0.13312305263694257, 0.30296623166049685, 0.9104719637863098, 11.838875182213323, 41.186840149664114, 61.48580789566041, 65.77005201770415, 51.329199037244244, 31.175684544347952, 44.344861968871086, 33.2412007547194, 25.892789286951867, 35.213129212779386, 51.40393587850755, 80.60269094282582, 87.17651274896438, 90.16518623598161, 91.75868834218672, 101.86662058676444, 56.86440075597456, 4.426187834432048, 0.2075758131761705, 0.1529211394729153, 0.19728752814473646, 0.09928951490550272, 0.12260291109522506, 0.09619147066147098, 0.19490930011435864, 0.17227708632426877, 0.23003199528301918, 0.3956867724416718, 0.46936340930481113, 0.5688032459828162, 1.2364255829203514, 0.8304622312707286, 0.945095215593615, 0.48269762927966736, 0.4123174993982239, 0.4276405755550631, 0.18704277222916005, 0.1937160109199824, 0.08633961059874104, 0.14441823767077538, 0.2772726845597067, 0.2891086204157722, 0.1384152646266645, 0.1461070938216102, 0.22478702027470837, 0.30131583312346094, 0.13480392615160636, 0.06881328089342964, 0.15506751865388888, 0.28226904871483005, 0.3564994445731563, 0.2029302560033337, 0.15308963285098154, 0.18522935018183725], [0.025704373838379983, 0.06026420697209336, 0.10132458151107836, 0.008346469520831542, 0.03937175970584635, 0.11386965431513325, 0.015572420539214246, 0.14175572973345557, 0.026442932393101436, 0.09076139348889552, 0.06019033694399461, 0.07242826594700737, 0.041046826274044095, 0.09361354649187097, 0.007623410840038091, 0.08042096851333495, 0.028646425344049934, 0.13125157644671778, 0.026557460622561556, 0.052475119084720655, 0.1777070102792594, 0.03193575216667547, 0.29780105237037907, 0.24753485205433062, 0.4800574757879781, 0.2533356544952239, 0.23802869682831151, 0.20294162474813002, 0.06723572199623432, 0.10825691879877161, 2.671330696152103, 37.896406958180094, 67.55713878139373, 66.96578656473469, 69.561783729061, 64.50335394951605, 52.84589721310524, 19.983232636605543, 32.69733667373657, 21.790482344165927, 26.85473684341677, 35.8720560227671, 34.264692260373025, 58.16867120804326, 52.902493092321585, 37.198119163513184, 27.80878278516954, 22.652964476616155, 6.1918613987584274, 0.129726693755196, 0.005962906166866061, 0.15863463853395757, 0.02814706242192657, 0.10587229393422605, 0.25002989317140273, 0.24673652715019642, 1.192815323029795, 1.5457379337280028, 2.151146209047687, 1.4093688899470915, 2.861270981450235, 2.058094350561019, 3.0805706977844243, 3.504188882727777, 6.315055201130529, 3.097248615757112, 2.6669866711862626, 3.332656280648324, 4.666646286364525, 2.5117390146178584, 6.286968579215388, 8.310578676962084, 7.451675216997824, 8.284136999037958, 20.669470910103094, 22.322318477015344, 22.698818945115615, 22.909864033422163, 20.702016776607884, 22.34504076742357, 26.34478165257362, 40.92529650657408, 44.59571715324156, 42.66529913871519, 57.41825511378627, 60.58279591221964, 45.31456208998158, 57.200944039129446, 50.67905833644252, 61.54082305969731, 51.87060379212903, 59.28623291753954, 58.98910160987609, 32.73960413471345, 10.875932324317194, 13.835300803184511, 9.755281748310212, 10.752493373809322, 9.510572917999761, 8.905294326043899, 6.5813120622788714, 4.539043249622468, 2.4878010346043498, 1.9520967093206223, 1.3885571615349863, 0.326393966472918, 2.462014637647137, 2.849599478706237, 1.6816637496794424, 1.407326070531722, 3.749155118580788, 2.7034948670095016, 0.9225653051849335, 0.48051688339441057, 0.9146562134546619, 0.47097455349660694, 0.1585908183046887, 0.24990901981870978, 0.06031515947993725, 0.13157262857402527, 0.016419531837586435, 0.09600244612703401, 0.032512150975244666, 1.3868896639154804, 17.06944307973308, 38.596906969624186, 48.01889511846727, 46.83011101138207, 36.78245382924234, 37.528986777028734, 31.815948717055786, 23.73259098299088, 36.82805922723586, 38.09094475161645, 33.94583102195494, 54.83087539672852, 68.02376747131348, 72.95823466393256, 77.64073664142241, 53.82733698814146, 2.97930171893489, 0.18292688824717077, 0.11527531074299929, 0.04856749227450741, 0.056508388144955526, 0.017541758716106415, 0.08032464827861517, 0.03725411648291253, 0.1064555396536185, 0.1331832824695495, 0.16351877080817379, 0.3466725589767579, 0.306604168708286, 0.3277265610954454, 0.06412334424713928, 0.13269634166311833, 0.07464566913944098, 0.08767845649873057, 0.04225481669568727, 0.05042248608304128, 0.022391194868231976, 0.03391689958892042, 0.08780525937195748, 0.00983479162377696, 0.006152284538163053, 0.04646483756181213, 0.01562373981165189, 0.03282000723805639, 0.02343848302599884, 0.020831755865665696, 0.026977248076770096, 0.019255047326066324, 0.13273533553846423, 0.13269730693390294, 0.054580646627131975, 0.044632811069248185, 0.09899423397596806, 0.027858291324528477, 0.10183157083848793, 0.0462227346255414, 0.018820924451574683, 0.024092995989767295, 0.03827509335091999, 0.03652589628472924, 0.11291361489002744, 0.04496309838648285, 0.0545968838606871, 0.029940470422227538, 0.12316225487137995, 0.11138926846005263, 0.009340759715996683, 0.02108819613743934, 0.06481798681160135, 0.0808562366892734, 0.09447227742883468, 0.1695099767417677, 0.10685101722276981, 0.09723001009514255, 0.18001279703551726, 0.11899219315138557, 0.2527157974339301, 0.2651290877932503, 0.12718092229577804, 0.17026250490978842, 0.1254247116946405, 0.05189440528591795, 2.971317244152869, 45.01847413278396, 78.92132774476083, 79.0955045146327, 76.4993896792012, 73.54826896421372, 63.255899029393355, 37.0818522668654, 35.345254252033854, 33.74918691573605, 31.238958258782667, 22.314083460838567, 36.872605585282855, 41.968191977470156, 44.588343097317605, 45.74298297205279, 36.68781095935453, 25.46745138783609, 7.006460707033835, 0.051012316328142925, 0.054174064613518216, 0.3362398816933555, 0.25192623657564966, 1.4497972496094242, 1.177214340817544, 1.659068813727748, 2.4671627484983016, 3.408306543865512, 7.733945644670918, 5.586810794568831, 4.2529048746632, 4.420260642805408, 3.845369878315157, 3.6158386593864815, 2.7084851024612306, 2.7909683796667286, 1.769469192912502, 1.3560365452881784, 2.854461256534823, 2.823834409636836, 5.228060522387105, 7.93525884228368, 8.952665771207503, 11.688674880612282, 19.86233538196933, 19.96661159300035, 20.818285634440763, 22.51999612777464, 21.67926157674482, 24.98404868187443, 30.238163548131144, 44.782523955068285, 51.61745009883758, 47.00539781201271, 68.86655930549868, 72.17212107873732, 55.71002760241109, 61.60668357726067, 57.823149619563935, 66.93205418125277, 61.51062080937048, 71.15197535484069, 68.37776922410535, 38.75778298224173, 14.379237448015521, 15.348188396423096, 11.615971788283318, 11.688947485339257, 10.25544866438835, 9.166696763807728, 7.376287752582182, 6.547658616496671, 2.968288193787298, 0.5888580795257323, 0.9598412436823692, 1.4637318373687807, 2.296208205722994, 2.6159255014311884, 3.215501947749046, 2.0131439883862776, 3.213269138528455, 3.6590031173921402, 2.476516130470461, 2.6890808920706473, 1.8780568242073061, 1.431315409079675, 0.9748395292028305, 0.5349428338869926, 0.2903604080840465, 0.18281640304673105, 0.03464963587541734, 0.027709430864741726, 0.035048511044512835, 1.4504217644852977, 15.14349558661061, 36.65008952540737, 48.36709176340411, 34.555041790008545, 26.974274996788274, 26.684933516287035, 20.352680683135986, 15.684372782707216, 35.72671259603193, 50.0769196018096, 48.189749640803186, 65.69464052877119, 75.65901402504214, 83.43827432201755, 89.19256394909274, 76.71103292895903, 6.955592959157883, 0.19930738024413588, 0.05668580644733964, 0.03971820381740409, 0.11009885463863613, 0.04996282183715413, 0.11943297716037882, 0.03237101459695447, 0.03280123808391152, 0.06935709606735938, 0.23364524897788805, 0.2471868336320885, 0.30808621176308204, 0.3977404703055659, 0.05095857909069427, 0.17969272550075285, 0.09843331205868915, 0.019606193302259333, 0.04297821820082684, 0.037970512113984556, 0.0182238029646537, 0.039795180332035794, 0.07290482626206453, 0.0400723394517216, 0.007849801791786787, 0.05661666701217333, 0.032299301106362574, 0.00917144375102174, 0.024155376614221645, 0.03510705931412597, 0.01945970388459823, 0.04866130740171479, 0.10617931133076068, 0.02833091777809445, 0.03055825713090599, 0.025351781871229894, 0.20265754402404834, 0.2080773709401969, 0.2159740367243367, 0.2110897818760526, 0.2688444916519427, 0.17794970693367143, 0.17137463474946638, 0.2573966865818347, 0.323158317515927, 0.36991214259497585, 0.2236845737863933, 0.16061894415367037, 0.26738595217466354, 0.2512876869690034, 0.10690337167151513, 0.19372126628314296, 0.12380213747101447, 0.2394883241504431, 0.2678631330209394, 0.33604171006910266, 0.40773883702293523, 0.23788407474996584, 0.45384755478270594, 0.44478657324948623, 0.6634071373170423, 0.4088971619644473, 0.3535868702155929, 0.3163148847318465, 0.20055356014880443, 0.26504399074662116, 4.552132689183758, 60.76079307063934, 91.51062980774911, 89.46274465130222, 90.62732773442423, 85.76306312314927, 71.19039104830834, 33.38741102526265, 45.463682759192686, 37.72157123011928, 41.270221894787205, 51.49687643974058, 48.99138404477028, 79.98884001085835, 72.22188811148368, 55.39810111445766, 43.620702220547585, 37.099757886702015, 10.348045037638757, 0.34725604218340694, 0.1447102703875111, 0.32045221917571565, 0.3954518592405704, 2.1710095818965667, 2.318670393959169, 1.7146338450331844, 3.8262662195390273, 7.796226018859495, 7.989621912279437, 7.3711136560286254, 9.68282380411702, 6.176421969167649, 11.536144691128886, 10.164537929719495, 16.53950341286198, 10.671265009910831, 9.875069952780201, 14.331308045694906, 14.174219081478736, 11.258495796111323, 12.70270759059537, 15.307467329886654, 13.014252628049544, 15.30009033218507, 27.88249588781788, 28.411927607751664, 31.44594369396087, 29.294054931209935, 25.415093629590928, 28.197624991017005, 35.03179019497287, 52.07363351698845, 57.82789960984261, 55.8261219147713, 75.35969011245236, 78.47693889371811, 61.19355601649131, 68.29510135035362, 65.57165068964805, 75.40173792069959, 66.18463085543725, 72.20217427899762, 71.81675434112549, 43.100670460731756, 16.1099862283276, 18.822016908276467, 13.14616095635199, 12.77377603515502, 13.296253392773291, 13.562201857566835, 10.129403298900975, 9.531244789400409, 7.291535139083863, 5.8343309837002915, 5.3972235225862075, 4.385053938434971, 9.976507348399009, 9.617846800434975, 6.05540115987101, 6.806109470705833, 10.326541623761578, 8.013732721728664, 6.012327161527449, 3.7210344210747754, 3.7817610463788434, 1.5388158083923402, 0.8694610708663542, 0.3926042797825029, 0.2691481382616105, 0.2564943116158247, 0.2818045849280973, 0.1928097135838001, 0.20873796855730398, 2.6463285280812174, 23.877508832562356, 53.393444399679865, 63.29655047385924, 63.73917033595424, 51.71509750427739, 53.06704044342042, 46.76136362937189, 37.54581766743814, 49.76380855806413, 56.169858824822214, 53.79476170386038, 78.12850690657093, 89.45238174930697, 94.29979585832166, 101.88898594148698, 83.568646061805, 8.079836426242705, 0.33594536685174514, 0.18689356894502718, 0.13820400822066492, 0.15878243221630975, 0.07989951544591496, 0.24378212439196728, 0.14381454506468389, 0.22045217304220124, 0.16908734135570067, 0.36280995595359034, 0.6721877919570093, 0.5493107209763219, 0.7116331688819394, 0.34767398911137737, 0.3802550037301356, 0.3088021056065637, 0.23289311917558794, 0.14728881508832978, 0.1796486294798313, 0.15299327431186555, 0.09976718604805009, 0.20753456700232722, 0.10014774788531566, 0.1327764438164811, 0.15383915795433908, 0.06422840937551472, 0.1348303715067525, 0.10684393857034946, 0.16613094676886836, 0.11239833649127715, 0.14443394247322314, 0.23887235881580463, 0.31449778546248713, 0.13322840504828962, 0.15655634924769402], [0.04803222281137302, 0.029513043156194112, 0.02739136073467953, 0.07065536228999977, 0.023388313843057524, 0.019409873695563407, 0.043709238450373375, 0.05867698387573323, 0.065760895489685, 0.07920642803993919, 0.06249404377153805, 0.02288173820312706, 0.059589268189043774, 0.02039274918065677, 0.04144559036039057, 0.06457332897210313, 0.035569607881048036, 0.045518086952788216, 0.05421353346337715, 0.06414324721141208, 0.18341951342600007, 0.034442742340146534, 0.09623028067571503, 0.15401813141520948, 0.33503258841172345, 0.16018037413877828, 0.05158672139288918, 0.03820250268965479, 0.04206954599207929, 0.28257079542644564, 19.855222163661836, 61.2558981680101, 69.18895459944203, 63.22315900556503, 48.67223647332961, 31.001166528271092, 30.856699751269435, 29.929186682547297, 54.67264306160712, 41.35150517186811, 33.71138703438544, 60.599489519673014, 56.61057241501347, 55.24005705310453, 47.56208412108883, 26.28611868427646, 9.54017504569023, 2.429782315607994, 0.15970817286401026, 0.12623759993021527, 0.046318518598714185, 0.07977300368609928, 0.09851821758333715, 0.8270411890360617, 0.8319008218184595, 1.1549813660883135, 1.8142517511883092, 1.6836005425260914, 4.800428036720523, 7.075947946117771, 4.877930639251586, 2.8739301860332493, 3.3500051690686137, 2.368379326597337, 1.8990717804239643, 2.3045437326354365, 5.082288086414337, 8.937125340584787, 20.97751425158593, 30.154497431170558, 38.88848027875347, 37.87871314633278, 40.05500493511077, 39.541958916571836, 45.71931931280321, 49.048478064998505, 41.8443117603179, 51.44579541298651, 50.210982291929184, 53.04827974688623, 54.96033322426581, 50.77583497570407, 52.945333219343624, 48.649843662015854, 41.3569611887778, 46.44201209468227, 43.29748715123823, 52.924544657430346, 48.93617276222476, 56.95271684277443, 48.10320646532121, 43.984415761886105, 37.77538222651328, 49.182387782681374, 41.65729707287204, 42.691888886113325, 39.39509753257998, 40.66805962593325, 35.322202482531154, 32.14684574834762, 30.036026162485925, 37.66663451348582, 25.281897783279422, 8.843928844698015, 2.660749122019737, 0.3098819831446294, 0.25982343862133644, 3.4133489958701597, 2.2184511394270006, 1.237756001853174, 2.2633448723823797, 4.229376537184562, 1.8843134949284217, 1.5643541154361542, 0.8033859873971632, 0.7325034876984935, 0.7756061683739386, 0.4927274056019322, 0.061565824829402475, 0.07716730116836487, 0.0526570534754184, 0.03642028723392756, 0.06244230219313215, 0.057944389315502304, 0.26073281563097433, 5.889586883206522, 29.490975564525975, 59.72106687484249, 56.31359800215691, 51.41877420486943, 55.16891310291906, 78.28099296938989, 121.95292134438793, 92.83494749376851, 43.6696808568893, 50.11141292510494, 57.42597826065556, 61.93917897439773, 65.67136518416866, 83.4264366088375, 53.50384735292005, 1.0626590684536965, 0.22529599376984183, 0.06158924413724773, 0.030415567509349317, 0.04421394100532897, 0.07689255905608017, 0.0274939609751586, 0.03396949918580151, 0.1192917641732962, 0.15464548081640275, 0.030010954341700966, 0.0296354582608347, 0.017761828963674845, 0.04790995134821823, 0.060469242744147784, 0.04078611123165296, 0.08147832306642687, 0.03291641940332709, 0.07815860362062532, 0.0165816571097821, 0.08783656172454359, 0.09044477701066964, 0.03326949017542986, 0.09258387835636255, 0.012924808223972158, 0.09496726215847077, 0.07998930095064063, 0.04880915471022168, 0.09787713988654076, 0.05012904759496451, 0.06236450596442146, 0.10205247995233345, 0.07155337821572058, 0.05582221468249637, 0.011169879862497891, 0.022070933726706335, 0.029522115552437403, 0.037384975791698506, 0.053044575221476056, 0.06118392616870904, 0.029432824174422893, 0.054222385609342214, 0.0777360984695054, 0.051134499691186414, 0.0835196026450684, 0.019713273241875634, 0.1334437063985294, 0.045686902087782665, 0.05394039247485419, 0.03648437814967286, 0.031362651366620295, 0.03412178597382961, 0.06424183506638774, 0.05643979263221545, 0.05447785677989164, 0.12064423877745868, 0.02883378746769121, 0.06238361219725302, 0.0857162065503578, 0.1343418832027143, 0.023259074810231407, 0.131195989106932, 0.06978756853289182, 0.015563257170029947, 0.295385270709953, 24.830521229774725, 75.28543180035007, 80.75678517741542, 73.46155320444416, 57.98680267026348, 44.65950273698376, 40.94333548699656, 29.48091664621907, 57.62506992586198, 42.82985433455437, 27.670032862694036, 49.638112283522084, 46.348349817337535, 57.094690953531575, 49.62102643905148, 28.01629185676575, 9.519520824955357, 2.744615034710977, 0.18306115281678018, 0.1945520273499912, 0.16882684081792834, 0.28876483079887205, 0.5641184038212222, 2.3656716654377603, 3.3119140517327095, 2.380983372849803, 3.1120538471206545, 3.0812578480089865, 4.187809219283443, 4.287840935491747, 2.325996400848512, 3.2435748413685834, 2.9647526673732267, 2.4250406603659354, 1.571822308244244, 1.810550994930729, 4.127849417348062, 10.501607791070017, 21.055757691783292, 30.959383480010498, 39.444746894221154, 40.53544036803707, 42.388458251953125, 44.23418052734868, 48.45569418322656, 49.77566588309504, 44.17199134826661, 49.88246417814686, 50.55913579079413, 54.72262190234277, 58.15410744759345, 54.84615302854969, 57.0166200976218, 51.012126399624734, 51.47694687689505, 53.59350096794867, 50.73873327624414, 61.78570447429534, 55.09382717071041, 67.49582429086009, 57.18467404765468, 53.155027051125806, 46.36046601879982, 54.470421345003196, 46.821477874632805, 44.33041587952645, 41.74451097365349, 43.23308575537897, 37.95458747494606, 35.32492852980091, 32.659175934330115, 40.40662188683787, 27.987168258236302, 10.790339343009457, 4.013643726225823, 0.8921435247025183, 0.3100194499617623, 0.9459860226319683, 0.7653373419757813, 1.1377519873842117, 1.7867895215749743, 4.987436350314848, 2.1159196476782522, 2.2759449962646734, 1.7819553229116627, 1.078583401057028, 1.4809721251649242, 1.414149033446466, 0.8253400448349215, 0.4597274941061774, 0.4138756915926934, 0.09841788304789413, 0.07290737733485238, 0.07367185647449187, 0.10906797608420735, 6.530337429815724, 28.610901601852913, 54.585503685858946, 45.46474964387956, 36.046738778391195, 33.53646109181066, 60.17011157927975, 101.8259063843758, 83.60051139708489, 50.20574592774915, 60.900303932928274, 66.17418950603854, 69.67216707045033, 77.59523714742353, 92.17417716979982, 74.04155408182453, 4.402520252812294, 0.3814776187702533, 0.06300066537674397, 0.034289130220009435, 0.10323504391576975, 0.03889275940075036, 0.04176163227267323, 0.042763353520703894, 0.10449119062433321, 0.1494754138853281, 0.03832573176271493, 0.04679730439919137, 0.12884422175345883, 0.07954496229367872, 0.02623849800006757, 0.06891633504100385, 0.04789022458416801, 0.05513942349822291, 0.026996645423012878, 0.033983434325144175, 0.049337257420824426, 0.061681140214204795, 0.06432353834351225, 0.03062340716320661, 0.04987905778351331, 0.02418172812359708, 0.06309840670456329, 0.09072384751972654, 0.01761737542467252, 0.06397897497780862, 0.05953686011414375, 0.04358799737547675, 0.03627270805619417, 0.03877190136981588, 0.03308824909430358, 0.17800976822693504, 0.15950261615216732, 0.14159872767425355, 0.15113836094256372, 0.10887506748399428, 0.1329512804025604, 0.18053070311584782, 0.13795090809224114, 0.18175014655195898, 0.20766731471784655, 0.15833378048433414, 0.2163665035679456, 0.11590135779472129, 0.19732096022175205, 0.19692002044570064, 0.12384791122449022, 0.11143137265237109, 0.19634854949770436, 0.18605461073738916, 0.20165615985470436, 0.40609199313386796, 0.13309780237895827, 0.40223075677790954, 0.31398168734965787, 0.34630713503687616, 0.5653487410276168, 0.22206092703967328, 0.14714477523680658, 0.10529308549819455, 1.3467160131662124, 38.304549186460434, 87.13040136521863, 90.68800680098995, 84.77267249937981, 66.40812750785582, 51.02772958817021, 47.8198819006643, 44.11617209834438, 68.38642981744582, 52.043568549617646, 50.51801366190757, 84.74321549938571, 75.41228909646311, 73.91446144350114, 62.85082017221759, 39.51881693255517, 15.678772618693692, 3.914952970320179, 0.41980371059429267, 0.5355835898268608, 0.3751945026939915, 0.519758542218516, 0.6476879324163161, 3.286420361649606, 4.147427437766906, 4.702531070478501, 4.9720145713898445, 6.140978941994329, 10.523010203915259, 16.369832465725562, 12.413761288888994, 7.277931378733728, 9.646159448931295, 8.186059603768012, 6.254244735164027, 6.065193357006197, 9.360100011671744, 13.301020053125198, 27.864247060591175, 35.04850341427711, 45.21482013886975, 43.10103131878761, 45.01233562346428, 46.236440673951186, 53.07415170054282, 54.691278242295795, 44.84999656677247, 57.88314619371968, 54.62031472113825, 58.953164854357325, 60.20947256395894, 59.02678382012152, 64.17317667315083, 55.23327527507659, 57.67198147312288, 60.35017190441009, 57.29357473311886, 66.97054832212388, 61.04571403995637, 75.74524341091033, 65.69361679015621, 61.4585631124435, 52.756357346811605, 65.52256222694152, 53.31252982539516, 47.75724949375276, 45.090006397616484, 49.45085440912555, 43.48610608808456, 38.45335214368759, 38.49592947190808, 46.51971032542568, 32.360146199503255, 13.97108639440229, 4.973952222254969, 2.148398098445708, 3.16428731526098, 10.621941204993956, 8.472535302562099, 5.592232000443244, 9.644835648998138, 12.280304604961026, 4.156043904442941, 4.582127544187731, 4.464680504414344, 3.930167599070457, 2.959510909934198, 2.219119413245109, 0.9849214914344973, 0.28865583180900545, 0.43114076999406664, 0.16793024215486743, 0.17357221924729888, 0.1971124464105214, 0.5294908619215412, 9.131335616111755, 41.791497045947665, 77.36361334400793, 76.02212352137413, 70.47454280237999, 70.81164698446952, 86.49195717227074, 125.72753583231281, 98.23541579707977, 57.403867859994214, 68.15180932321857, 76.03188237836285, 81.78767035084387, 88.81197637127292, 105.9491882016582, 84.56457507225775, 5.374714020759829, 0.49671544483111757, 0.1456182684388853, 0.14352071970220537, 0.2549000979671555, 0.3689698850916278, 0.09197402640335983, 0.16571195796132088, 0.3430060315276346, 0.44528995430277246, 0.11394226412859657, 0.19388995884406954, 0.2685187510665386, 0.1371170826736958, 0.21469534404816168, 0.22054595752589165, 0.246395219658171, 0.289711470325147, 0.1638132550062672, 0.19759099089330245, 0.17548278124342043, 0.18400471266959945, 0.22535950245876468, 0.098185911624422, 0.15003088891746538, 0.22376838380530958, 0.1818508564704849, 0.16980069178727367, 0.18928558655804206, 0.10272761791824334, 0.22602979874899312, 0.24196841123123325, 0.1588057825762418, 0.19377400377585044, 0.08829975380532204], [0.04134043713190383, 0.06481920489140096, 0.024098481179305145, 0.035988776719257716, 0.032758988334887454, 0.05764037498363084, 0.02359657484527317, 0.08566056558441731, 0.034500038056003476, 0.03111213870016077, 0.05166318845905123, 0.01071772806631822, 0.02655203672005765, 0.05155692823351391, 0.03961608812753712, 0.026290440676553596, 0.02974351113211484, 0.05043629481787643, 0.1287661114286992, 0.07512533977147072, 0.017366056450672688, 0.020272666813745614, 0.03175865753643936, 0.037691499061521985, 0.04686821349746278, 0.10189300342913597, 0.0966799972699054, 0.25757000631382393, 0.06515812218910264, 15.523042755742228, 56.91437175196987, 76.08845864572834, 80.12024725637129, 60.148275744530466, 38.07095635321833, 57.696143273384344, 57.73399806791737, 26.427757432383878, 22.85720229148865, 38.11589887065273, 61.61523826660649, 44.34007667726086, 51.03325228537283, 30.74625365195736, 16.644005160177908, 1.798907193926073, 0.061751815655659285, 0.056024358472636634, 0.0008500575049472372, 0.09399588565312086, 0.13686240440414799, 0.35251866785749314, 0.6360951222239003, 1.7747172016289927, 0.7085415444547131, 2.4391131439516625, 2.297451351919482, 2.6118626613770766, 9.899165072748739, 8.987359135381638, 5.089975441655805, 6.7473891377449045, 6.701498877617621, 6.408300236348183, 10.404869394917643, 17.532961330106183, 34.66807273126418, 54.88591801735663, 60.57472759677518, 65.71597430013841, 68.64913448210686, 66.55142737973121, 66.73300173974806, 74.78914999192762, 73.78681967335363, 67.89764758079284, 67.65586483863093, 67.47837758833363, 69.35020323722594, 70.18186338486211, 73.0381098101216, 75.44739430950534, 66.84047468246953, 66.97281545208347, 29.924521023227324, 38.157425003667036, 51.92459129518079, 50.534064000652684, 47.67831571640507, 56.30565912492814, 46.72804701712824, 36.16600236585064, 37.254358107043856, 42.154273140815, 57.4902972867412, 59.05137708110195, 59.870905337795136, 59.111091244605284, 53.97327661514283, 60.76370739167737, 60.65185316147343, 54.3014770169412, 59.57249141508534, 51.50247366197648, 44.16839061244842, 34.137399581170854, 16.066751903103246, 3.852728980202829, 0.7862092542552179, 0.9017415032271416, 1.5966526274719548, 2.799867747291442, 1.0231128743579312, 3.2019413334708062, 2.0706574570748115, 1.8914091851442092, 1.194039837967965, 0.7945361396958752, 0.4253932106639109, 0.2232634858979333, 0.12376906545532328, 0.11062801455057437, 0.11116256772149956, 0.07350325584411621, 0.02509941718721342, 0.057567106334552656, 2.9522851686323843, 15.470889941338571, 41.10926743476622, 61.63980799336588, 56.3730925129306, 73.79856324964955, 92.1735260563512, 101.26707846118559, 54.466895134218284, 18.36280345916748, 42.92651722508092, 46.15368650805566, 67.67719468762799, 69.66137270773612, 83.30590217344223, 44.32238678778372, 1.0098736492856857, 0.019610136739849564, 0.025602989762480703, 0.021661618694422707, 0.04611434084513495, 0.0475483846610352, 0.04008137545878849, 0.10228833544158167, 0.1190757810048038, 0.08161262594043248, 0.06769910559899385, 0.07408642495471625, 0.01791951858678893, 0.05523821819693812, 0.04278988314552173, 0.07817302139536028, 0.07211577868269337, 0.024332936642871752, 0.07399577377063614, 0.012777792120863114, 0.09196527767926456, 0.03949578934078736, 0.019376252011786547, 0.08199399983089778, 0.048794227487017075, 0.05905698646881408, 0.0675225223324472, 0.08425585144469816, 0.09389689943242459, 0.058451378642911875, 0.029851173298553597, 0.034455631769472556, 0.04424068896520523, 0.03083151303261759, 0.0412894961153788, 0.014743712588003086, 0.05762333718819484, 0.07894696938174386, 0.0318556500133127, 0.06055732370324193, 0.04696233505983988, 0.05772659051862936, 0.04812684616134052, 0.04996004859886823, 0.03139188336659103, 0.04203573853198079, 0.006205053153192445, 0.005484927631539083, 0.041516307936680895, 0.03817750907112514, 0.027113623218610886, 0.05972412264635486, 0.12651921385118078, 0.02540675825589607, 0.051912783735221436, 0.011818671107081877, 0.014545481591936082, 0.03134731237115639, 0.07282651675444457, 0.1749610906887439, 0.036020860481526584, 0.09643135577320092, 0.10197105246686167, 18.893792360059678, 66.88719795596215, 85.81522280170073, 87.79408208785519, 69.86324925576487, 49.779623554598906, 60.744393640948886, 55.937058310354914, 36.23616572349302, 34.28387657288582, 36.46412211079752, 53.032409837169034, 49.35839237705354, 54.94223933066092, 36.2089797758287, 16.220340151940626, 1.1408178099701483, 0.053464678686953364, 0.1379523483375388, 0.1192002013445862, 0.0881308850441729, 0.39244738497561027, 1.3279917211301866, 2.128070660175816, 2.582560349856654, 2.444193103621083, 4.177446317288184, 3.2331119189339304, 2.6710754969427666, 4.40126411376461, 5.229937376514559, 4.294656543962417, 6.163334490791445, 5.59531694458377, 5.965757350767813, 9.542649080676417, 18.830773599686164, 36.315068121879335, 56.30472167845696, 63.777515426758804, 68.26224757779029, 69.48535242388326, 69.85259609837686, 69.90101383578393, 75.23189144749796, 74.07639257369503, 69.14100754645564, 69.0027283084008, 69.5220422744751, 71.40393272522958, 71.27922488797095, 71.89867696454449, 80.52575757426601, 66.7528881565217, 64.91002528898179, 35.96254118027226, 43.6252913936492, 56.310750361411806, 55.20891343393634, 53.76507328402612, 63.3122831006204, 51.786645458590606, 43.40092789742255, 43.9606422762717, 46.84985230045934, 61.47973606663366, 62.349015666592514, 65.14002523114605, 64.58247600063201, 56.57503181888212, 63.07104949028262, 61.82421430464714, 58.03991548476681, 64.85354315850043, 55.90864466082666, 48.742176255872174, 36.575929272559385, 17.396111795979163, 5.554573814715109, 1.3823478044040742, 0.726602281774244, 0.8461974933743478, 0.7668866781938461, 0.7848592847585679, 2.2561907143362108, 2.6929194215805303, 3.753825435715337, 2.45181794608793, 1.7996229039084528, 0.9373680850671184, 0.8572549613252763, 0.7317083497201243, 0.2420125532174303, 0.213975788304402, 0.066112254055277, 0.07838778648405306, 0.025343464071592017, 1.7279344797134402, 15.219103194052174, 41.7720381675228, 57.70848697231662, 56.70535649022749, 79.39517359579764, 98.00122676357147, 106.8141100483556, 64.48825674672281, 35.294279129274436, 59.133448754587484, 57.607140771804325, 75.46078528127363, 79.15969802487281, 93.51811455142115, 64.37594359920871, 2.595830463594006, 0.029077589203934037, 0.0776969054112992, 0.01367922671394603, 0.06992062268358085, 0.04649528955680229, 0.04182605260622598, 0.12980940060750132, 0.03162317105659074, 0.005554933224864785, 0.09973603691304884, 0.042044391495085535, 0.025066737791583426, 0.07579031175062542, 0.05216413718317786, 0.1143899352680291, 0.06522128613845957, 0.013465521699418465, 0.10674692119561857, 0.027126945487614122, 0.06583346699875209, 0.00804423442816422, 0.008644723829122321, 0.052075117766376466, 0.04330528411833991, 0.050703716960044644, 0.024043255816063574, 0.05933843185043624, 0.038447987904111226, 0.03291543498034439, 0.03546563059752507, 0.03561711299323267, 0.0171952648088336, 0.024727858798277956, 0.19565882521771616, 0.15176502086462515, 0.10379386675213614, 0.21210760629225164, 0.20515047073844941, 0.1305539614611095, 0.0999762284599485, 0.21998190230900244, 0.16484597217171423, 0.22189931313116706, 0.1704991035043232, 0.13483406405054754, 0.1791723679390646, 0.14234613837494006, 0.1233931001456034, 0.11814807151113788, 0.1375239213267642, 0.1296247887395082, 0.28053814965871077, 0.08299511586946827, 0.15370095569279887, 0.07420656286300191, 0.13317470228479755, 0.14822439230497808, 0.18917914630184252, 0.2786907133075499, 0.25896388797029374, 0.48110024402699164, 0.43585711369110697, 26.1726955060036, 83.05295636576992, 97.53085613250734, 101.6117214387463, 79.22512315934705, 55.46886067236624, 69.82491200970065, 69.79581586776241, 39.352665332055864, 32.16239402371068, 54.58364448239727, 76.92593174595987, 58.7841813025936, 70.42141822076613, 45.219958443795484, 24.165757932970603, 3.7650644971478373, 0.6791292227083637, 0.24467856983744332, 0.31728242313669575, 0.27699266410162376, 0.6257044572022654, 0.8273834771206303, 2.852224279795924, 4.810825259454789, 3.9519509721186856, 7.291317447539299, 8.375694924785245, 8.109884723540276, 24.00174794658538, 17.136284189839518, 11.709902747984856, 11.853941006045188, 10.516098987671638, 10.314535248664118, 14.111077747037335, 22.010609680606475, 41.13858322943411, 62.95937176673644, 68.24371045635593, 71.11644652581984, 73.31866125906669, 72.92772646873229, 71.6912934087938, 76.36081234101327, 74.74885156077724, 69.86959565070369, 68.43259611437398, 69.4351068619759, 74.21600541760846, 72.65556104721563, 73.83607679797758, 80.69071677423294, 72.96836222371748, 70.70822977250623, 42.053483916867165, 49.84599398028467, 62.98543983890165, 62.39824533462525, 58.780698237880586, 71.55101376195108, 59.32690397385628, 49.98538717146843, 47.53018740684756, 52.88736451056696, 72.28881943610408, 68.51037671489101, 67.86717076455393, 63.74540298215805, 57.69237387564875, 64.35852043090328, 65.00484466552734, 61.94632553285169, 66.97039142731698, 59.95063927865798, 52.61901163285779, 42.2813069435858, 19.942763582352672, 7.238024694304313, 4.68532657431018, 5.089081141256518, 7.187781093582031, 8.545575718725882, 4.236604975115869, 10.573713702540244, 7.375353738184899, 7.402505855406485, 6.18975067330945, 3.6683555187717563, 2.7935235586858567, 1.184568172020297, 0.6118136896721779, 0.22407843491002438, 0.1986328398268069, 0.22447379756598707, 0.2741631336750523, 0.17717473238946932, 4.181336818202849, 22.810169150752408, 58.68241540847286, 77.65382166831725, 74.32576902451055, 80.94611014089277, 94.18288569296561, 102.94414274154171, 65.75420564220798, 33.96099098267094, 59.23749354577834, 66.88284412507089, 89.67640399932863, 90.7104584478563, 102.86303597111856, 74.22162225169521, 3.4829303718382314, 0.24590234933120592, 0.16256850002513779, 0.1566513441503048, 0.1884724301916938, 0.217939711085731, 0.15035514329229632, 0.24147129677716764, 0.2532092806312346, 0.2631211100566772, 0.19701211953595762, 0.1495496937704663, 0.10890951079706992, 0.14551431030756043, 0.18386888528062453, 0.2292322607771043, 0.4254950697143232, 0.13601451361131284, 0.24096754800167777, 0.12246639422711827, 0.19283713953148937, 0.1355806933415513, 0.16535776487040907, 0.2107560892979945, 0.18734513181111506, 0.11551115091048902, 0.2327574143606809, 0.3225260191867429, 0.14901061301990864, 0.1331535735798459, 0.131110263868205, 0.16656610003161818, 0.1373550449047358, 0.09827485443243096], [0.032948763635490215, 0.029209398461746115, 0.015080580600507319, 0.04805376137336416, 0.03973018543253984, 0.04265971714630724, 0.043812756081141775, 0.024699965536954905, 0.07504637142823589, 0.017027020409342744, 0.018780287317631227, 0.005584018710519998, 0.06060304000012337, 0.03399837687010727, 0.07125785979892939, 0.015437977854162456, 0.015864639989881506, 0.05330289240866419, 0.08258222512179807, 0.06054654101570768, 0.04911692287292212, 0.0989027860604467, 0.0428080968859215, 0.07774186711157523, 0.014388497727322242, 0.04675285980826424, 0.05607474790585618, 0.13130719443002056, 7.233059954258704, 48.497479192672245, 74.50459772540678, 69.2269859006328, 71.82197109345468, 63.539419712558875, 38.58579489492601, 78.84582996368408, 106.03951254198628, 31.68217432114386, 30.462430946288574, 42.8829240029858, 38.89168877755442, 50.45667563715289, 29.116236240633075, 15.273457438715043, 1.6708773542796413, 0.38758946823016294, 0.11180716176186839, 0.04072078691434957, 0.05711207309016778, 0.18116035078081394, 0.1136565056719607, 0.31700139144255274, 1.4902927798609582, 2.596087133692157, 3.09886267108302, 1.6836232187286502, 2.89744675640137, 4.014427219667743, 7.725117860301849, 13.507473026552509, 14.58947648925166, 22.330679009037635, 23.290249609178115, 36.32572912400769, 46.004679587579545, 63.755962002661924, 66.26902457206481, 70.68811585826259, 67.26614598304995, 69.67482643742716, 71.86020635789441, 71.60986500401651, 74.50057337360998, 74.93635654449463, 78.13731654997795, 72.622495466663, 69.9674117180609, 70.72476648515271, 73.50442471042757, 76.29970965846893, 77.65083282224595, 74.8358654206799, 69.68575416072723, 56.35282170388007, 43.02160332279821, 28.90958420691952, 52.008557473459554, 49.15946937376454, 49.94751276508455, 54.47601464486892, 37.18393587297009, 40.47188228176486, 56.42049435646304, 57.76000338215982, 64.35266825460619, 72.44966014739006, 74.88451065555697, 69.05346024420955, 71.03796774341215, 69.17156281009798, 72.1017380683653, 74.76629041856336, 70.66413448702905, 75.76269795817714, 75.55358855955063, 76.54708570049655, 79.42644273081135, 68.58268168664748, 46.027052787042436, 22.14623739642482, 4.72514892778089, 0.18264882897417392, 1.7527992422542267, 1.4972617284905527, 0.5318293299886488, 1.9024277358285844, 1.590284291774996, 1.4044420252884589, 1.3298590144803448, 0.9838777732464575, 0.7575374637399951, 0.2489601279939375, 0.07346518127427948, 0.0401938793009087, 0.029279863229021433, 0.03245122017218702, 0.10946342300984169, 0.5097659058388203, 8.514320312007781, 31.181717149672973, 37.796249235830004, 38.55625160278813, 48.23805755184543, 32.70780155735631, 17.584124726633874, 14.794041822033545, 12.069322274577234, 30.69366055150186, 58.93192521987423, 63.55414036781558, 74.7381591796875, 84.76146236542733, 39.96009534405124, 2.347511826984344, 0.02151612136062355, 0.0596349998076837, 0.1559604707384302, 0.04787771436836451, 0.07757278384580728, 0.04128506429673683, 0.09183799217064535, 0.06942831160080049, 0.14319248167016815, 0.07401722423251599, 0.09452756599433, 0.06178175054130055, 0.05039974859344864, 0.018202208861288045, 0.014471829898895757, 0.03506016324184114, 0.03326647561944781, 0.011472372552229753, 0.04110737786357922, 0.049553225267558336, 0.027972702725580143, 0.04229359606641435, 0.07499134333263482, 0.033282705192123695, 0.11249742996428283, 0.03821025166900889, 0.04787269266202085, 0.09470034946477222, 0.031573179989091815, 0.065596669221357, 0.07311596775487547, 0.07635524030774832, 0.03319655094415911, 0.02436549537965367, 0.0309739230320819, 0.0163395963083472, 0.07256671335668334, 0.04489454117813899, 0.03716403603433602, 0.014931803452782335, 0.04879175302302165, 0.013041231563434967, 0.032102066024597135, 0.040297718688605294, 0.01660983382363714, 0.03201559193492417, 0.011465779408031415, 0.011318801609318585, 0.049037406776821425, 0.029818346430998177, 0.03986903120793643, 0.04989444465947248, 0.07289727263513111, 0.07660314636004549, 0.026301305718539704, 0.031847041100263596, 0.0023270813671256146, 0.04639064577678519, 0.06544378105430834, 0.1187193202936361, 9.735542420418033, 58.18938132255309, 86.44695974165394, 78.1409800437189, 80.4014027503229, 72.04607963562012, 45.61404289737825, 93.37950583427184, 106.13554000854494, 32.72570129363768, 29.00428395117483, 41.153770646741314, 42.52530974726523, 52.32018586127989, 35.597878425352036, 14.590878736588264, 1.1486194042428848, 0.12348463999167567, 0.05575259261193776, 0.11271531303082744, 0.12213643249725142, 0.7893849644930132, 1.4667236252177147, 2.3878053551720035, 3.5497709916483973, 4.067965366186635, 3.865476683262856, 1.5996625562829356, 2.842082991715401, 4.301120119710123, 9.454222186919182, 13.98852329100332, 15.145224371264058, 21.77882702119889, 23.13288019549462, 35.898261377888346, 49.893325221154, 65.32508265587592, 70.74281723268571, 74.89135126913749, 71.17496044405046, 73.1865950553648, 76.28832694022887, 75.42178123228013, 77.25620315920922, 77.57838664516326, 78.00113185759514, 71.73749108468333, 70.32401792464718, 71.0613529143795, 74.32336068922474, 77.288907881706, 76.38447992263302, 75.06224109280494, 73.03232823648761, 58.203423407769975, 45.50359679806618, 37.31098536522158, 57.50388829938827, 56.10291965546147, 54.10982608795167, 61.52641619405439, 45.183017561512614, 44.5600078951928, 61.679247425448516, 62.687131820186494, 69.92990601447322, 76.12617615730532, 74.6566209485454, 70.9781280640633, 71.10960591223933, 69.2156110271331, 71.656494140625, 75.99736552084647, 73.97512482058617, 78.67643848542245, 79.79943659997757, 81.1060094833374, 83.78247014937863, 74.52773186468309, 49.14003795193088, 23.746640912948116, 5.276920997327374, 0.9791139933851458, 0.4286233131443301, 0.5553255530615007, 0.4238834352262559, 1.9121590136520326, 1.3084478988762827, 1.057807586846813, 1.834875450980279, 2.362409234046936, 1.3602420615573085, 1.5607759332464588, 0.6094901756413522, 0.3130174584446415, 0.043969838579575864, 0.05739748680723771, 0.03450355439957592, 0.14165606169450667, 10.09181228376204, 34.87551512256746, 43.06975433903356, 49.7048867133356, 59.119163482419914, 38.96209924451767, 22.047117140985307, 22.43075240042902, 22.669612976812548, 44.38654891906246, 68.2067931082941, 71.17045756309264, 81.50057638845136, 94.94537876498316, 57.92673941581481, 3.021769956234963, 0.0891653488900873, 0.04953060652159395, 0.03996541656012978, 0.06344704565802409, 0.05618460108375838, 0.0162941194139421, 0.11153550698391854, 0.12565745686691615, 0.1040815557503412, 0.007504946833866979, 0.05236350007415299, 0.015254322638464792, 0.029903805454171477, 0.026735510947483204, 0.01896427865440567, 0.09022938372987895, 0.05366048309952021, 0.06550032600399948, 0.046966016112316045, 0.062136767176730986, 0.06957504042093793, 0.03357164291364532, 0.00580971060703779, 0.006097454667812394, 0.11430799450364806, 0.037450966605496024, 0.030206362303766995, 0.03269507361936473, 0.013400224195192418, 0.06601057120508726, 0.07789927519737713, 0.051408307176203503, 0.1430733856414595, 0.08367488100644081, 0.12257336308398556, 0.12971984492915292, 0.2841118885384452, 0.17710451277032976, 0.13937472846479187, 0.10733861686481584, 0.1800472250268344, 0.07170073522795593, 0.10928787396199281, 0.15481478624766873, 0.10548422443530253, 0.1666175811401298, 0.17735785804688933, 0.09211341610118266, 0.15322740610328414, 0.14004476428512605, 0.15666502648063246, 0.16959927195022184, 0.2058052920526074, 0.21511463929087887, 0.17662648922733723, 0.28252847672950837, 0.11369142395954941, 0.18448731741837918, 0.1543175032542598, 0.27411416533493227, 13.7935765904765, 71.34956867464128, 94.01454540991014, 88.6243772506714, 89.68008318255025, 81.97191976731824, 52.16478939979307, 86.13539803412654, 109.04323224098452, 42.35352170082831, 43.000159725066155, 59.44612049287366, 53.610465218943936, 67.77012348175049, 41.962951690919944, 21.608651068902788, 3.067835987575593, 0.5588867587427939, 0.20070218120611485, 0.19158090855325424, 0.23104338456065426, 0.7580637967874928, 1.3176109233210165, 3.550261287919937, 5.764519658780867, 7.220613783405674, 8.398531944521013, 7.967282052963012, 11.141860196667334, 10.140875251062456, 12.714206999348058, 15.979667440537485, 19.553150630766346, 26.231072141278176, 27.175202331235333, 42.40818385154971, 52.41111032424435, 70.67409730726673, 73.47345367554696, 73.55941634024344, 73.82958135297223, 75.54186067273541, 77.66267053542599, 75.6815205850909, 80.23191713517713, 78.8701408140121, 78.58019136613416, 69.81312136496268, 69.263228601025, 72.94762073024627, 75.86550328039354, 77.23244144070533, 76.51817783232659, 77.79393657561272, 77.03894307536464, 63.289145038973906, 50.639387484519716, 44.29156480296966, 61.94300720768591, 60.30104029563166, 60.091009140014656, 65.93503475189209, 50.87181929619082, 50.53564079346196, 62.12645646064513, 62.478449959908765, 72.78681139792167, 79.19834906055083, 74.99313677510908, 72.89650440216064, 72.37980273462111, 69.0705539334205, 72.49809357427782, 77.15288008413008, 75.29382567251884, 81.93833643390288, 82.05919250365227, 82.76153995144753, 87.72569948627104, 78.62678912378128, 54.26917629857218, 25.474544994292724, 4.95728999376297, 2.741623737158314, 4.942308010593538, 3.915683511764773, 4.263791903372734, 7.5169302186658316, 6.772731081131966, 4.72824122636549, 5.519783862175481, 5.253479932585071, 2.3726637805661848, 1.3309493108141808, 0.362376963058787, 0.25645285093736264, 0.1968465832572791, 0.09954692810894021, 0.2087241942964254, 0.9285167664770158, 14.464277375128962, 45.7822145185163, 53.40595283815938, 54.748866481165734, 60.00686645507813, 44.466984964186146, 29.626779787002075, 24.584192460583104, 23.484577555810255, 49.36750012059366, 75.50237809458088, 83.6191269659227, 92.11694194424538, 105.71875679877498, 67.3917402759675, 3.6042620289710263, 0.1822552129986786, 0.12982536587984334, 0.2566652105099732, 0.2386934006766927, 0.19201921809825206, 0.15852942401843687, 0.28897311478372545, 0.20317263090081755, 0.22232426210276543, 0.18512487111072387, 0.2074024628006643, 0.2038954042138592, 0.15506063918432883, 0.08193680370647101, 0.12878834330026181, 0.15905517483911208, 0.19811631270474006, 0.271824328529258, 0.21565594169641697, 0.18560851773908063, 0.18540515203870114, 0.12991564168084052, 0.22352459930604507, 0.1133947027847171, 0.20484431136038997, 0.18265431416371178, 0.14265576047041725, 0.19798572535716719, 0.11042655640912634, 0.18152776654929886, 0.17852295520565203, 0.14144760917030996], [0.1247774746509329, 0.06624419737847582, 0.07230966787544951, 0.08157324136024521, 0.029567073422273802, 0.03654892488773312, 0.02908529987889192, 0.06676834707538928, 0.07591814118167085, 0.03584801572405043, 0.0610486695152377, 0.06582048180843554, 0.03988489305840866, 0.04607663782794149, 0.05134739169490434, 0.047715652298422596, 0.05756791838775239, 0.08632366064815752, 0.010282875493078703, 0.05576966105089073, 0.036424623291578986, 0.055504157958972844, 0.04037570260885743, 0.03659460288021834, 0.01607279278217785, 0.1243230619377667, 0.04990781289375117, 3.3674964885557856, 46.17462412003548, 74.70804322150447, 74.83246864811068, 70.56764418079008, 55.39908170700074, 38.17713491378292, 28.569510790609545, 25.63329508227687, 21.303363192465998, 41.43815817371492, 49.06050405194683, 42.71739213697372, 53.31252982539516, 31.07648584150499, 9.360469695060484, 0.19285630705135484, 0.05853294402421002, 0.0847202386226385, 0.055235364519420176, 0.03726566908881068, 0.24006543350556206, 0.40434056292137793, 1.3448321723168897, 3.3521641887003377, 2.711611476636702, 0.909095150568793, 1.044417963393273, 4.000263050679238, 8.568755945851727, 15.438129325066845, 25.56493405372866, 28.615071081346084, 39.089823384438795, 48.71311933763566, 54.400591388825454, 65.55503945196828, 74.8251965738112, 71.1338383151639, 67.25258242699408, 64.18874063799458, 66.31502612944573, 69.62065066060713, 69.65468898896249, 68.39689470106556, 67.37932205200195, 69.65905850933444, 76.05844466916977, 74.16878008073377, 72.13811412934335, 70.26448419017177, 73.73437758414977, 72.44821671516665, 71.36326559128301, 70.9669336195915, 67.76721308308264, 59.506019007775095, 69.2333479850523, 34.47431156712194, 35.018767926000784, 52.34469283011652, 50.22778572574739, 44.41004783876481, 35.50519281818021, 63.080678909055656, 69.87450645815942, 73.68430460652998, 75.01090511198967, 75.4276647875386, 70.17950996275871, 66.96242901586717, 65.68978855686804, 69.0060858572683, 73.3541508643858, 73.23528735868393, 67.13050257775092, 65.06277022823211, 63.19509836935229, 65.72687848921746, 64.67954289528632, 70.9190022560858, 74.94315793437343, 82.65346296371953, 75.48882238326534, 52.25370168685914, 22.02784065277346, 6.84587691099413, 2.2449658714955856, 0.6720200493451088, 1.522719626945834, 1.0100910343950795, 0.8424450108601201, 1.4446937557189696, 1.4424046850012195, 1.3635310915208634, 0.8835911029769529, 0.05875728904239594, 0.03649878443308896, 0.012718509364452575, 0.07871478345365295, 0.06686212389820045, 0.2822260558605194, 7.198051329581969, 27.274157847127608, 36.93678340604229, 40.543728336211174, 41.34833589676888, 42.78823798702609, 36.825595978767645, 26.12720777911525, 18.364533224413474, 33.963948449780865, 62.81896268167804, 66.263839198697, 72.66408043522989, 81.69161150532385, 27.279558950854888, 0.37907758787755047, 0.06350559775807685, 0.06546461098496953, 0.037844705155059215, 0.040064781994348576, 0.06584649049346486, 0.043220773128972906, 0.0724586260114466, 0.0334808653250577, 0.1318863569007766, 0.03836494780355885, 0.02527457744544072, 0.06301701369304812, 0.014904952071036303, 0.03225545023357676, 0.044363738007603154, 0.02836172600396939, 0.06319846544835357, 0.06642697063545067, 0.036723075825120174, 0.10035415495475454, 0.010855910218050404, 0.033285363517220945, 0.047544649982404326, 0.04203227581456304, 0.09706025267200125, 0.09682422098253043, 0.045061582819588726, 0.06885193002920958, 0.033636159008188594, 0.03726231362370234, 0.02905659839480875, 0.03427706433520202, 0.024138041959714987, 0.05421577427055567, 0.0722116622472963, 0.08080322340491318, 0.03415172085947087, 0.052893127299725055, 0.02283172606821022, 0.03830967839026163, 0.03610403464746571, 0.04954024773812102, 0.11499924329860557, 0.04656010442563603, 0.017592883593733274, 0.013348409838433708, 0.08968101033279974, 0.035342570063808275, 0.08185843291181712, 0.02069255002894469, 0.030876511122070016, 0.03147330510640337, 0.020859779361935876, 0.0589121652076081, 0.03958117750082766, 0.018825429048569455, 0.03657753827170499, 0.07388020940725842, 4.988154634352654, 57.58757598938481, 87.53908880295293, 82.14320967274328, 77.4824062470467, 66.40612709906794, 51.25852969384963, 40.29816442920316, 34.745566998758626, 39.481307306597316, 45.804344531028505, 38.812452977703465, 41.09947327644595, 52.579285867752574, 35.21696921317808, 9.546160582573185, 0.13044401252221677, 0.041186204480548064, 0.02664700097915146, 0.26844814840343695, 0.9185231801482939, 1.069745320466257, 1.8745195817562843, 3.9809431712473597, 2.752348722950105, 4.026109999225986, 2.290158194880332, 1.7753588768743702, 2.6644530652030824, 7.765745280250427, 17.13571152379436, 25.93516069073831, 30.763268893764867, 40.04088832486061, 48.300231041446814, 55.30025759050923, 68.29721943024667, 77.62136797751151, 74.73131072136664, 70.99257807577811, 67.05339662490353, 69.97374242351901, 72.9304172146705, 72.9825141352992, 70.55971314830165, 70.91997500388854, 72.70610470925608, 77.77510135404526, 74.01044968635806, 75.28784013563588, 71.66085581625663, 74.37575570998654, 71.84594461994787, 73.26541116160732, 72.33254601878505, 71.16965739957749, 63.51417926050002, 71.3783431822254, 37.38743628225019, 41.4134080179276, 58.16099905198621, 56.62555194670155, 50.62618870888987, 40.775418819919715, 64.14143685371646, 71.01197027391004, 75.4535916543776, 78.17122151774745, 75.73788504446708, 70.35407896964782, 68.29979250507971, 64.39524950519686, 68.76627998967325, 74.60508100448116, 75.74728304339995, 71.47489624638712, 68.69748946159118, 66.95229361134191, 69.5657531676754, 69.20473821701543, 75.48253090150895, 81.95935249328613, 88.20600940335183, 80.65237168342837, 54.22652444531841, 24.163628085967034, 7.582933412444207, 2.841743951843631, 1.0184887063599404, 0.3825896107141049, 0.6655550639956229, 1.1394465738727202, 0.8271843555473513, 1.7702187333376178, 1.5134036300643798, 1.7227115986808654, 1.0445676263301604, 0.4136243534664954, 0.11043387254880321, 0.09697525521680232, 0.10116623879800882, 0.09766586049790345, 7.3948837095691315, 30.293951419091997, 40.10661940420828, 41.337517999833636, 35.01529270602811, 28.664059523613226, 27.49764861599092, 32.18360816278766, 29.775996554282408, 46.47016686777915, 75.42633902642035, 75.08468489493094, 80.16919843612179, 92.65272202030306, 42.681157281321866, 0.5317818325373435, 0.1466974564978192, 0.05425329342664731, 0.09221962653100492, 0.05715435348270882, 0.040638072401165, 0.017509199979324496, 0.04549228128105883, 0.045032628526490544, 0.023787110488140778, 0.056424233386473316, 0.06629024692360433, 0.04129750556462715, 0.035211385167654485, 0.02814831689090258, 0.025888803760491075, 0.02619714457391491, 0.024226858363216443, 0.05157483936918359, 0.016025495471342677, 0.017439639195799828, 0.014046520865972967, 0.019009550620291023, 0.04007664486585606, 0.04257539001804206, 0.031004892136420936, 0.009104520225176408, 0.03853687708596549, 0.06426008328074409, 0.03889550965639853, 0.05904776660064536, 0.033910721089811094, 0.2043324573746612, 0.1668689805533617, 0.2606271567844576, 0.16415306096596105, 0.3298102896059713, 0.17457680566416633, 0.16107052234151673, 0.1334147482749916, 0.2507568340027525, 0.08974889338377023, 0.10786792999433895, 0.22906448752168687, 0.23377073417988517, 0.13894901340526922, 0.17614308774711626, 0.21209881160288088, 0.17977906360981927, 0.2373881707148206, 0.07760322051903895, 0.24688148630722878, 0.08589696499609178, 0.10240822820173157, 0.3505818750108442, 0.14447957066999328, 0.18089045800508993, 0.21175719767568574, 0.15478722240415313, 7.004525017353797, 73.7668469644362, 95.69074676882838, 93.35652858980241, 91.22381825600901, 74.34214884235014, 54.35862202798167, 42.295447088056996, 34.17419925812752, 30.374144277264996, 53.526742227615856, 68.4235119050549, 59.7459739254367, 70.18805288499402, 44.834350232155096, 14.12631517456424, 0.46140893452590515, 0.1426651680301274, 0.21732938415821523, 0.3384721699741579, 0.4697644410114135, 1.2626021331356418, 1.6572467502086394, 4.712220305396665, 8.229180670553639, 8.262972870180684, 4.672827941756095, 4.917442144886141, 10.004703306382703, 12.37642522781126, 20.865950276774747, 30.862240099137832, 37.44910378609934, 46.230223717228064, 52.90084569684921, 58.05265926545667, 69.32075408197218, 82.11096778992685, 75.72584336803806, 73.02607597843294, 70.30214678856635, 72.10285986623457, 74.52992054723924, 75.47090499631821, 72.74998818674396, 74.25717461493709, 75.70601970918717, 81.55688593464514, 75.05254499373898, 73.59652980681389, 70.74879492482832, 75.37279082882789, 73.56091468564927, 74.75174626996441, 73.30580372964182, 71.45311924719041, 65.18905878067017, 71.77382007721933, 42.30768096062445, 46.21611495171824, 63.469142606181485, 62.560972705964126, 54.88164263386881, 44.50329434487128, 67.50313558886128, 75.72334089586812, 79.84515574670608, 77.66962097537133, 78.18663643252465, 75.58048817419237, 68.48739162568124, 65.22144579118299, 70.10591060884538, 78.00391674041748, 79.60775821439682, 75.85819198239234, 70.7321640752977, 69.18662471155967, 72.78570528953307, 71.26720674576299, 78.93311054475846, 83.17207874790316, 93.32025451044883, 84.18652134556925, 59.106823705857806, 24.286902296927668, 8.448873604497603, 4.886076421506943, 3.5391205308898805, 5.211424279597498, 4.76947759428332, 5.529900635442426, 5.82918385344167, 5.9182927493126165, 3.498636767748864, 2.539682960317981, 1.1476118454048712, 0.27426548302173615, 0.17883257730112923, 0.2727889864435119, 0.22970594826244542, 0.4509602306831268, 11.983272337144422, 42.53402917615829, 53.51851309499433, 61.957743552423295, 62.715368963057, 64.46511476270615, 52.20897097741404, 41.477256359592566, 31.41234074869464, 50.339306554486676, 81.73030176470357, 87.28447991032755, 90.84758450908046, 103.22824785786291, 48.162936318305235, 0.8525420497021369, 0.31571932797951086, 0.2092696488985131, 0.18601603054952237, 0.16227884218096733, 0.1547251539605279, 0.09367322474117241, 0.2660384035158542, 0.20056793195826395, 0.2044743215364795, 0.13481713350742094, 0.1449365267950681, 0.19712444334741563, 0.1901425018666252, 0.16069860197603703, 0.15635425525326885, 0.15680350453382538, 0.1102639006210431, 0.10632232462446536, 0.09918550314802317, 0.16167708011644502, 0.09341041827874799, 0.14027200128522613, 0.14345633767304883, 0.21558118683676566, 0.16292247861143083, 0.14144658261249143, 0.10120710192788994, 0.1904119043460777, 0.1266709145819468, 0.14885416254401207, 0.18578385994318994], [0.033049477384455746, 0.04584875731398502, 0.09343928447173488, 0.04981073040154673, 0.0319329118956962, 0.07261879201377593, 0.043503639603694605, 0.061238402681004625, 0.052268378767034704, 0.007725799927533034, 0.011923196143470706, 0.060065748064868876, 0.048467962131384885, 0.0383066485125211, 0.04612269120350961, 0.053446078072151834, 0.014617337766403874, 0.08843018793531003, 0.02689020708203316, 0.04002809404365478, 0.07466469876348011, 0.01979544191741415, 0.03487985295754287, 0.048287253481365984, 0.02777627969701444, 0.08757449070652647, 0.08271482728061177, 21.135599497825872, 70.99836749415245, 70.0606543017972, 72.34602328269713, 61.948490681186804, 32.367955638516335, 19.823927533242014, 17.34578190311309, 30.126827070789954, 15.472251003788365, 36.3829251258604, 49.99022737626107, 46.57662783899615, 40.52839579120759, 15.705867371251507, 0.5613140930091182, 0.232766883207425, 0.1152861585480071, 0.28256270553796525, 0.08800579820789638, 0.04895778342841133, 0.26698029329699857, 1.9483759734899768, 2.078172473176833, 1.2734145142378346, 2.2010247841958077, 2.678900625436537, 6.15684247785999, 9.196421465566083, 21.441022696033603, 31.774114677982947, 40.2116604774229, 52.76761062683598, 63.75254954061201, 64.29691960734706, 65.17099234365648, 72.61822792791551, 73.08113821091192, 70.99206032291536, 62.48739688627182, 60.16529098633797, 68.47594614951842, 73.95072767811438, 72.63188562085553, 68.26595029523297, 65.5809663188073, 63.42240756557834, 66.16896490896902, 70.74972844892933, 71.09594821929932, 69.65644621079969, 70.11487714705929, 73.28958865134948, 69.93363226613691, 69.49553489685059, 68.67060553643012, 67.25366500116164, 63.12087928095172, 62.08337314667241, 37.08098934542748, 38.3405133985704, 40.991086421474336, 33.26081652795115, 61.06731061012515, 71.94976191366874, 64.70596005839687, 64.138922614436, 63.351812747217, 69.41062342736029, 70.60597358211395, 66.86957866914811, 69.57450005315965, 71.65643922744259, 67.08520704700102, 65.58274315249535, 62.623852222196525, 59.94061762286771, 55.6240100245322, 57.56300234025525, 60.87468693333288, 63.13698845524942, 61.80212351583666, 62.76459863108974, 66.79281004013555, 74.10474346530053, 82.46927630516791, 66.39459533076133, 42.427372086432676, 25.833628177642826, 6.910503352842023, 1.3308842239841339, 1.254370671606833, 1.9222739483079605, 1.0092745072418645, 2.3107192593236126, 2.3362737461443874, 1.1460951138888638, 0.11673634000603231, 0.06830646010536341, 0.05913311262584983, 0.03314500854861352, 0.014142015640954337, 0.06671892674339396, 2.333700426163212, 13.960463635383116, 36.160836604333696, 52.3689095435604, 61.28263696547478, 50.74873139781337, 38.8063850710469, 17.262476644208355, 24.071252346038822, 44.12932380553215, 58.65897532432311, 67.99565192191832, 73.85220558412614, 66.51238410703598, 3.9394194897144077, 0.19396232350939707, 0.01385933398494437, 0.0729440882681839, 0.04857639804662717, 0.050258508793288664, 0.033212780516834996, 0.011873007808331282, 0.012578399543980918, 0.04736371150600815, 0.013194110154384568, 0.028017808067341967, 0.006753311637083009, 0.03979164483626524, 0.06125607249897815, 0.0336464858734079, 0.07894578194546123, 0.052306143071262114, 0.07227461169203443, 0.012409470453407737, 0.04606839472187623, 0.05532315436510309, 0.03430174768812234, 0.02622317432636215, 0.02573826748336996, 0.08035536074349958, 0.07459290100321656, 0.01117642799903068, 0.11194806065290205, 0.03007568111042342, 0.04751835784484302, 0.02116472832107496, 0.05085001677094449, 0.051790087093268676, 0.047985514430629636, 0.10395449240722003, 0.021231217092023264, 0.03197775102190433, 0.03359713831976537, 0.022518365463662534, 0.010938396820077493, 0.03806685533134207, 0.022278681450012713, 0.015172947821537814, 0.05988420820945214, 0.03511915201201074, 0.04349237811120768, 0.04536112319798239, 0.027494439780111277, 0.06210999240377738, 0.03898075225973322, 0.023826537203163873, 0.02227877721100325, 0.027582888461409077, 0.03797427360569278, 0.025341194536116336, 0.06946936625266267, 0.05603189294737193, 0.28156510584296723, 30.25327251803491, 83.76066177122055, 78.84506902387066, 82.20144902506183, 71.805771704643, 43.94436444005659, 27.442072553019372, 23.63403162648601, 33.53761034627115, 17.11814126660747, 27.545209315515336, 48.23266821522867, 46.062142310603974, 40.14778467916673, 14.561670807100112, 0.13951142919400047, 0.23383456462573624, 0.07040001752395784, 0.3043513186275959, 0.3227829650765465, 1.2424482597458748, 2.3186547044784795, 3.628414268455198, 3.4075551648293776, 2.8655417071234797, 3.5285350343873425, 3.1033665326333817, 4.977067564764331, 11.405760203638385, 23.91892513921184, 36.38356054982832, 46.790628433227546, 61.145228493598204, 68.61894792126071, 66.95016768670851, 67.00932487364739, 74.92417366273942, 77.15463730596727, 73.72411666377899, 63.78706247575822, 62.904380136920565, 71.85538968732281, 76.25091537352532, 74.7052897176435, 73.00563258509483, 67.99162757012152, 67.02972119854343, 68.62603956653227, 73.33538624548143, 74.28890658963111, 69.00417174062422, 70.76997572375883, 74.56064055042883, 72.16939895383774, 71.03710482197424, 70.06695362829393, 68.49674255617204, 65.53084627274545, 62.96134864130328, 43.552205870228434, 44.940160089923495, 47.079216818655695, 38.512493641145774, 63.94547916227772, 75.07618119639736, 69.54858103106099, 67.03559690906157, 67.12431307761901, 69.35144270620039, 71.04303544567478, 67.14533698174262, 69.14590266443068, 73.10781032808366, 69.76444475112423, 67.40891241258191, 63.756083596137266, 62.96159967299431, 59.99809603537283, 61.252889710087935, 65.39423011964368, 65.65220048350673, 65.73799056391563, 66.2722566050868, 71.04454948056129, 78.83872262893185, 86.73274363240888, 69.15239810943604, 44.9704094086924, 28.635039867893344, 8.609685878599844, 1.8491576587961567, 1.0168187572590768, 0.48872232857731085, 0.7133800944974347, 2.317485102722722, 2.947824453153918, 2.1385269636108033, 0.7423929473565472, 0.5382143357588399, 0.18647317053569903, 0.09430650366289962, 0.028403598454690752, 0.056488278336943164, 2.6145941019058228, 13.796408541740911, 35.9451650804089, 50.85729083707256, 53.48714197835615, 41.025462073664514, 28.03142239970546, 19.19803100247537, 36.72282595788279, 57.429524083291334, 63.77239673368393, 74.71206757330125, 80.93817910840436, 81.59267364009735, 6.179806974626357, 0.1940259700941463, 0.13665231245179332, 0.13832791528153804, 0.03944285266521958, 0.07302108010457409, 0.04385158907802355, 0.06896020123554815, 0.03145383689702759, 0.02787541913529558, 0.010456854060682799, 0.028138524372010466, 0.018031476591263088, 0.030228046422463753, 0.00451813281078132, 0.025373667088006775, 0.0389841498596774, 0.01896021455796736, 0.03516821228268166, 0.055556711590578484, 0.07281366945995439, 0.0855865921344488, 0.033701552273405176, 0.040025971980104526, 0.05105241337009976, 0.03512663669103096, 0.20481418878320726, 0.041744203772395856, 0.021808046825049866, 0.05859118202821382, 0.04427970199274921, 0.05540034921479322, 0.1788127049803734, 0.16840022177465502, 0.17177159086831156, 0.2175556712092892, 0.08697702639525937, 0.1967145709861671, 0.07903055723516211, 0.19624848309303486, 0.14797155264644854, 0.10170233946654106, 0.12953964572760368, 0.17997553451888024, 0.14276912616145226, 0.09381892700349131, 0.15257356538166925, 0.12645419596904708, 0.10193172151282912, 0.16984256615321483, 0.14016560699430206, 0.1031090914001388, 0.12130825314670803, 0.10428196435133297, 0.09513102111316497, 0.3429615371409924, 0.14690802342468692, 0.11776804593541931, 0.5110311766545619, 43.600145078474476, 97.32481402735557, 88.81632235742386, 92.18111976500481, 79.45767264212333, 48.01247812086537, 31.260346943332305, 26.973692524817686, 43.45952810779695, 23.280204419166814, 50.587635732466175, 67.24146642992574, 62.82128864719022, 55.10784572170627, 22.02352604558391, 1.0652603353223493, 0.4453963792372135, 0.3643281890019294, 0.5678679445578206, 0.31361794880320953, 1.222561352675961, 1.723538483342817, 5.3269140566549, 9.209888923552729, 7.624546818194851, 7.587210757117118, 7.142104602629139, 9.885153385900683, 13.414101985193069, 30.833695050208803, 41.52701162522839, 52.78841880060012, 63.35291101086525, 71.18598230423467, 69.36781467929964, 68.2480799767279, 76.04615196104973, 79.4915226967104, 77.18473757466963, 67.6021283672702, 65.54217800017327, 75.66189304474862, 77.99495020220357, 78.19326523811587, 74.95121448270737, 72.03182574241393, 69.59395500921434, 69.87729918572211, 75.66852185033983, 74.95734906965687, 72.29197302172261, 71.37063180246662, 76.48100160783338, 71.574799014676, 72.71231774360903, 70.01021262138121, 69.10340770598381, 67.84271870889972, 64.51528579958024, 47.41056296133226, 50.75282635227327, 51.29043817520142, 43.189971062444876, 67.10221444406818, 76.40916732049759, 72.738903568637, 70.46454075844058, 71.28211959715813, 72.60721391247165, 74.68551312723469, 68.68471037956976, 70.64525219701952, 76.81623874172088, 71.71113275712537, 71.95000510061942, 67.86525664790985, 66.2125502863238, 60.615375118870894, 64.50416588014173, 68.11178545798025, 68.53653892394036, 68.42170761477563, 67.32636220993535, 73.27153005907613, 81.48580474238243, 91.3963633198892, 69.4697178563764, 46.822454544805716, 29.3728220078253, 9.516337821560523, 2.316462589848426, 4.375796164235761, 5.230721850549021, 6.195553819979391, 7.90534096379434, 7.434821772959925, 4.515106495349638, 0.6939389893124182, 0.40204910200930416, 0.12671507188990233, 0.1882687427343861, 0.1633775654819704, 0.298810449819411, 4.386124255195741, 23.341463996518044, 53.278754295841345, 70.21288933292513, 80.00423139141452, 73.27445614722468, 53.05792877751013, 29.429000154618297, 35.81281646605461, 62.61417181261125, 75.86248305536087, 86.0467524682322, 89.93502155427011, 94.9909096379434, 8.679702147360771, 0.6307713014464225, 0.3925192440229078, 0.1980249030936149, 0.15443224790355853, 0.1598958490837005, 0.1322604835994782, 0.17737665784455117, 0.11738487173833194, 0.09972387143681127, 0.15381586888144094, 0.13292193923506046, 0.14604324805400065, 0.06100617844851748, 0.15547319285331235, 0.15195600658414826, 0.12323897857699664, 0.15006402988106976, 0.22208789333460793, 0.14677173638295743, 0.17353068196004437, 0.23559930944635024, 0.07576169070577429, 0.12647186961746024, 0.1002769026484701, 0.13750394175369895, 0.33877762455132704, 0.14345279834683866, 0.1403311279512221, 0.15138614442079298, 0.12340508942161837, 0.18835396235508306], [0.0291558297636408, 0.07087458601041187, 0.024363218183298747, 0.07737486503056942, 0.045037535319645564, 0.031374851316814466, 0.025982980864242684, 0.026385893316699133, 0.0651063193236628, 0.035234103505049026, 0.03015382016348022, 0.07720384356235305, 0.029113625979892192, 0.02347398928606943, 0.05755261961190451, 0.01577125961757115, 0.05582075528500061, 0.024099523058882164, 0.09967139441399805, 0.04007647632651272, 0.038014466408640146, 0.07172364125689192, 0.062171218150685874, 0.06649992518847989, 0.04209012311372546, 0.01370894517974868, 6.146703150964552, 55.8300325178331, 70.46870631556358, 70.86856842041016, 63.10894743088753, 47.39406155001733, 28.49900422557708, 24.871884584426883, 33.47443272990565, 33.24680189932547, 52.77492192483718, 68.20259617220971, 50.15445701537594, 41.06124193437638, 10.647986723530678, 0.35561495009929905, 0.019301843806920994, 0.06968000978832284, 0.06914338051912285, 0.10775287890987051, 0.46476804621277323, 1.9184240194097644, 3.3608983264815424, 3.043926689893969, 3.328892521319851, 1.085797988118664, 2.597664171649564, 6.751615981901846, 13.48120197173088, 27.02533248932131, 43.764861091490715, 57.2410894978431, 65.60337874197191, 70.09306092416087, 67.88659434164724, 68.37904007204118, 64.83529237008864, 69.64299248110864, 66.53665573366227, 64.46227104433122, 54.61440763165874, 59.180489740064075, 67.05141975033668, 68.91670288578158, 65.84339249518611, 70.72234246038622, 67.19907345310335, 61.907537214217655, 60.580924941647446, 63.77426378188595, 66.79365727209276, 67.24978185469105, 67.46126036490163, 69.03325219308176, 64.70794477770406, 69.22853131448069, 64.17250594785138, 65.41114337982671, 62.024098288628366, 70.29415299815517, 54.405208018518266, 31.054069495970207, 23.138504874321725, 46.760838031768806, 73.80452525231146, 64.17058398646694, 64.33845750747189, 57.0742004917514, 63.10002011637535, 66.28176443038448, 74.94868847631639, 67.86327192860266, 68.30103197405415, 63.60122057699389, 63.733016137153875, 58.1122753697057, 52.857209328682195, 51.78963038229173, 52.475119483086374, 54.270560895243, 55.4089190113929, 55.07462716871693, 56.10372766371697, 61.987337835373424, 65.27612755375525, 63.74139039747177, 62.99561838949881, 72.87231906767815, 62.41277379374351, 62.59760372100338, 47.466017430828465, 46.608767740188114, 22.59188532829285, 2.9329415098313363, 0.590051950946931, 1.419647093261442, 1.1728428592604976, 0.9377387490484023, 1.977346477008635, 0.6488658692086897, 0.23891777250795598, 0.07568670601974573, 0.048942059473765474, 0.06853897545126177, 0.007111944207516049, 0.5559762987879016, 4.126842839102592, 27.661901789326823, 38.537973357785134, 59.6416663354443, 69.93733498357958, 42.7384631095394, 25.569850744739657, 24.712622627135246, 53.22504528107182, 57.2505541770689, 72.65254866692328, 68.87979338246008, 24.346414458367136, 0.40050534291132805, 0.031224491239915934, 0.05007430678233505, 0.040662433997157126, 0.012133150199999013, 0.04281434816338363, 0.04467230673218447, 0.051923635370668866, 0.00375787936425167, 0.04996688976403206, 0.06895211900794698, 0.05128910772562508, 0.005890747866473131, 0.017852591230503975, 0.023646418440846667, 0.030602232492979498, 0.04646579900215711, 0.016339964030550855, 0.021816732346891396, 0.029254363992461757, 0.08339447750439567, 0.031482220454622185, 0.03567555784097603, 0.028109196611049197, 0.0345106024084793, 0.05381283883546149, 0.02746355494544391, 0.09912714256995148, 0.04965318825035807, 0.08050362173948558, 0.034321336556346185, 0.03175307275547135, 0.028574026204765807, 0.01726581767622021, 0.005722428773409657, 0.08409426817970891, 0.01970697791435786, 0.019099470190403443, 0.035862908473298434, 0.06529876061024205, 0.0072424353152934105, 0.054005138395774754, 0.06814770370481477, 0.05446504395935805, 0.05447111520615797, 0.026677922202995228, 0.046915626679096496, 0.021982247558152004, 0.022825662482289538, 0.03236592777313725, 0.03835994907985291, 0.08764500909995648, 0.0476119737891901, 0.034867626194271355, 0.020572902416930567, 0.01725311785365545, 0.030287544641102997, 9.292566603229893, 69.34772429927703, 80.67099509700653, 80.25436093730312, 69.91634245841735, 57.92507240849157, 34.881147646134906, 31.489483964058664, 27.92483787382803, 25.989230563563687, 43.42118301699239, 62.97558684502879, 51.41514993483021, 40.02849755748626, 11.495812919832046, 0.6656677095640091, 0.10483708698302509, 0.054841932405026696, 0.12626406060711992, 0.8988925754543274, 1.4135023326643052, 4.864247941201733, 4.889781100134696, 4.905287210018405, 3.8824799128117102, 2.3803996751385355, 3.4463300003159434, 7.6338271460225515, 16.963250790872884, 31.528913590215872, 49.476102705924745, 62.0351593725143, 68.5398494043658, 72.10901798740511, 70.88654856528007, 70.222993358489, 67.9646259738553, 69.87215303605603, 70.02898508502592, 67.44416667569068, 58.88913216129426, 60.73310505959296, 72.63426257717994, 71.21219942646643, 70.79995047661566, 74.13187057741227, 69.4730754052439, 65.91555626161637, 63.95538314696282, 66.37444219281598, 70.07646145359163, 69.8384520315355, 67.37787861977854, 69.21035505110218, 67.06056671757852, 70.17109255636893, 66.13753887914842, 66.83565801189792, 64.259268776063, 70.970746163399, 55.412123587823686, 36.51494426112021, 27.983967604175692, 48.45352903489144, 74.57279989796301, 66.41947100239416, 67.5544245012345, 60.47754695338588, 65.2173351472424, 68.60169733724287, 75.62474819921678, 69.20707594963812, 68.93902117206206, 67.16053224379017, 66.20718448392807, 61.94905158012145, 55.848930497323316, 54.49129619906026, 54.24968211881576, 58.04481060274186, 56.9803773972296, 58.68735759488998, 60.90135905050463, 65.50171875184583, 70.38678369214459, 68.48533630371094, 66.69877513762444, 74.6756052201794, 68.01719357890468, 67.89807119677144, 54.701801961468114, 50.85366264466317, 24.549302977900354, 4.100181753596952, 0.31085436322516014, 0.6459629475589722, 0.5077104000074248, 2.0288583516113223, 2.281425282839806, 1.299415415813846, 1.2658861375624135, 0.39883324876427656, 0.07927806492173865, 0.05114158983492563, 0.11988588068033419, 0.478513747333519, 4.204746503983775, 26.862054024973226, 41.191370487213135, 53.794734247269176, 69.72346382756388, 36.0174661297952, 35.913488018897276, 36.1215187657264, 59.35766320074759, 67.42171502882435, 77.88055819849815, 82.64422185959356, 40.444598274846236, 0.3782328993322388, 0.025623321735991106, 0.14294630697657987, 0.04948390197129019, 0.07325826858681056, 0.05054466561564515, 0.042603551410138614, 0.005698754262524627, 0.038434838004890955, 0.07023634283893532, 0.030528440988892992, 0.06902816855619032, 0.03561876008226987, 0.03111360958897539, 0.01606962309339114, 0.09779338349377918, 0.020792781142517928, 0.021589968406084566, 0.06390743002656006, 0.07355629977199339, 0.09589121016042848, 0.026459508620563055, 0.02380916041382138, 0.018436283196112322, 0.053304336484401464, 0.013354560566855776, 0.020884070094795, 0.01933952384147673, 0.04732505470934895, 0.04855147720645032, 0.02788845795176683, 0.13350038158316768, 0.11559024182779175, 0.1312078021827244, 0.18534443190982267, 0.17484444614139297, 0.07974469673729713, 0.0614594113862803, 0.11561608963435697, 0.2851641869112369, 0.09231318884919729, 0.1789962443252725, 0.1453307096756274, 0.1580113340770045, 0.1432186205901446, 0.13144669904103204, 0.14046232816913437, 0.10744812913359174, 0.12627718369326285, 0.17954081026536806, 0.09879328145255005, 0.23999241000461966, 0.17350569217195436, 0.2199092312085052, 0.22493561068850182, 0.09271726192485902, 0.24198480551281285, 15.495101751819735, 85.30886050193541, 89.77392196655275, 89.57886249788346, 82.44785231928672, 63.580726192843535, 42.32282523185977, 37.416599104481364, 49.15358189613589, 47.79538277656802, 70.47586856349822, 90.23714603916292, 66.22781615103445, 56.3987369691172, 16.346448275350756, 0.8183551002894679, 0.1688334751393526, 0.1509046734821412, 0.14180518836984712, 0.5712151359165869, 1.4694046878045606, 10.981279342405259, 9.164174679786928, 9.286856612851544, 10.456123005959297, 8.53080407265694, 8.454613993244788, 11.710023360867655, 19.582560562318374, 36.36872614583662, 52.50261922036448, 66.99489055141326, 70.99128369362124, 73.35666902603643, 69.99544882005262, 69.86240202380766, 67.33983162910708, 72.58629983471286, 72.9770149723176, 72.31377355514034, 61.56535356275497, 64.17419648939564, 75.00956366139074, 73.82523536682129, 71.67638055739864, 76.22027381773918, 72.85194627700314, 68.34204427657589, 64.92667967273344, 69.82087981316351, 72.42251734579764, 71.31592258330315, 70.26988137152888, 71.66289544874623, 67.39871425013389, 73.3485261855587, 67.34429528636318, 67.73707359067856, 64.9270954439717, 72.98063139761649, 58.10505036384829, 43.24276616496425, 32.87526126830809, 51.065321583901685, 78.99964963236164, 69.40817586837277, 70.00607059847924, 62.7676502350838, 68.00705817437941, 71.17692162913661, 79.81502409904235, 71.6957570660499, 72.8029872525123, 69.28221287265902, 68.80609204692226, 63.862230777740486, 58.81467380831319, 56.72647453123524, 56.891182699511134, 63.53049632041686, 60.15978005624587, 60.95757053744409, 61.513766550248675, 67.47143499312863, 72.94864054649108, 70.8305214297387, 69.1439728583059, 75.38268304640248, 68.58636086986911, 69.152374575215, 61.12744054486675, 51.58880110709898, 26.587517530687396, 3.518176790206663, 2.926226902392603, 5.66933403092046, 5.504963676775656, 4.2890691276519535, 6.03077995200311, 1.7727346886550228, 0.7809884569817974, 0.22961245489216622, 0.23567820118079263, 0.39255813064594425, 0.2521956543768606, 0.8910991323571053, 7.414139605337574, 40.12152441086308, 53.71819703809677, 76.21840676953717, 86.1143898194836, 59.34878295467746, 38.26285831389889, 36.6316936092992, 67.53268672573951, 77.51994332959576, 89.40736862920946, 91.70401834672498, 47.64548155569261, 0.7243344163702381, 0.12238377930536387, 0.21954779092582966, 0.20523870874556804, 0.1272517011591023, 0.11614017038335724, 0.1249797678282184, 0.14239296166887208, 0.18231311392399574, 0.1079023733074146, 0.3047346383813889, 0.16734348009190253, 0.137101439158282, 0.11129360706094774, 0.17199620784771058, 0.2173159929412988, 0.08497814978322676, 0.20843150274407482, 0.12837274060133966, 0.16364709053549076, 0.26366892420957166, 0.17656687226506973, 0.20221233968773197, 0.09697720108013, 0.17772368035249173, 0.15656356579594075, 0.2271511829307964, 0.2008337031809553, 0.1766030009715788, 0.18550140332550774, 0.09769383036801893], [0.010953155503938756, 0.01779507526436881, 0.041304189681766496, 0.024959309281961575, 0.027539229110604333, 0.07302048255599315, 0.041650997685088266, 0.06784968018051117, 0.028306075461929845, 0.07503782188700092, 0.010719211404061606, 0.07199362596316684, 0.032117466307094986, 0.0282957045466549, 0.020601716898982565, 0.10482981680862366, 0.035673351507754095, 0.04831459515938356, 0.05217482027928195, 0.060028045047675414, 0.027057465143321503, 0.0610100471925351, 0.0674232449983397, 0.008447829656483186, 0.058619182541846275, 1.449076636664329, 45.36298767212899, 80.91710813583867, 73.09332893740746, 73.11094822422152, 52.51968545298423, 33.94031224712249, 21.756506773733324, 27.914571069901992, 40.43221927458241, 53.99382199010542, 44.42400755420808, 37.26513678027738, 33.65596002148044, 12.486049590572236, 0.6107710133637152, 0.09551205026406435, 0.10090165501160007, 0.021559755813570756, 0.16233283605787063, 0.586187006725419, 1.5101545592469554, 2.760038774821066, 4.650793046720566, 2.521821467145797, 1.263258884991369, 2.2298787197759076, 14.625357350995465, 24.095104279056674, 35.598843328414425, 57.00574336513397, 66.56657557333669, 69.13909342981154, 69.57683778578236, 69.34788119408393, 71.53737960323211, 66.69767687397619, 66.52885021701937, 69.50832966835269, 67.38023988662228, 62.131120158780014, 51.62474962972826, 53.82405788667741, 66.1676077688894, 66.957212263538, 69.26009070488715, 69.45816255384877, 67.94434732006442, 62.58020016454882, 61.46427016104422, 61.52723596942041, 64.75864533455142, 64.99814133490285, 65.92853930688673, 63.95987033843995, 65.81441402435303, 64.93921556780415, 67.74112932143673, 64.21971951761554, 64.53169307401105, 60.352945020121915, 65.60737171480733, 30.62125752049108, 26.050692142978793, 68.77192035798105, 62.985855610139915, 65.11361591277584, 56.9420519182759, 52.33922504609632, 52.589166318216634, 61.02281132052022, 64.9204509488998, 70.61780345055365, 66.86666827048025, 63.29908040262038, 57.28226653991207, 52.44249713036322, 50.29841192307011, 51.19973728733679, 57.37060616093298, 61.73686704327984, 65.58644194756785, 63.53478739338537, 57.739905157396876, 49.07327136685772, 51.865269368694676, 62.883364077537294, 68.64005811752813, 69.44814482042867, 66.80722082814863, 59.06604674554641, 61.100689980291556, 72.80460326902329, 72.56710375508955, 60.3736472898914, 26.049285973272017, 1.3929250884440638, 1.6671094274328602, 1.4282983709727566, 0.8162216373508977, 1.558572786950296, 1.3045604623133138, 0.13859023910857018, 0.06541296899799379, 0.13001272034260536, 0.02504031158863537, 0.05677466498567693, 0.21560747897432697, 2.572963535785675, 19.861103757735222, 50.815278330156886, 36.79535842710926, 36.18671248036046, 33.84741483196136, 17.00533978400692, 38.0449745731969, 53.20044025298088, 55.455803102062596, 71.53897208552208, 63.823528751250244, 4.264303772680221, 0.3646184443946808, 0.13669921235451776, 0.10991103286224027, 0.06987637344507441, 0.028151116942265825, 0.055935070925061746, 0.03765102280604263, 0.05324177774450472, 0.03868018915396064, 0.07841963275906541, 0.053506242787285205, 0.026740722260588122, 0.0577951975226883, 0.11704738702504866, 0.01796152701811685, 0.0314423302564049, 0.025325625714275147, 0.020532150369798465, 0.022104124486025785, 0.02110037502021559, 0.03478305008743079, 0.0753060982172047, 0.014192240365270167, 0.01777456134497639, 0.07474340663682069, 0.04053424833522689, 0.06142326735801274, 0.01739894077482243, 0.0034580294384561, 0.06350237635835525, 0.02591779444276566, 0.05752710122314673, 0.028703736381665356, 0.01670218763812896, 0.019270219697406697, 0.08432200313695977, 0.014115095311295123, 0.07816407348840468, 0.020051587245336944, 0.036497217783283804, 0.00977799099224109, 0.06503363290140707, 0.017842972996614633, 0.04320065949052092, 0.0004959182496672692, 0.02373325642228367, 0.033593767532898534, 0.021217023398006157, 0.05284333541508644, 0.08701186807405564, 0.05879870758602216, 0.03664871550074989, 0.022321930943777966, 0.09155884505279603, 0.07640436186545319, 2.1802006758028463, 57.205544979341575, 91.28764306345295, 82.43974085777037, 80.44614130450834, 64.55641185083698, 43.720738349422334, 37.62427683799498, 28.375853569276874, 40.05868019596223, 49.85989486017535, 43.60396546702231, 43.07593599442513, 34.97440199698172, 13.866612103677566, 0.6741342681550211, 0.0600134012770028, 0.027576206259489543, 0.34841344781940986, 1.1890098885182412, 1.8261319975699148, 2.2858627092453743, 4.080030821984814, 7.624422773238152, 4.246087795303715, 1.8188580846594227, 2.9010494534046423, 13.14145117036758, 25.171049641024684, 40.15647272909842, 58.92666139910298, 69.68533054474862, 71.1386549857355, 72.99264169508412, 72.63889097398328, 70.77508264972319, 67.61777862425774, 65.96331504083449, 70.64971585427561, 71.17016730769988, 64.20001745223999, 54.28620722986037, 56.86560492361746, 68.87150149191581, 69.80838314179452, 70.47842594885057, 70.83470267634239, 70.43434635285409, 65.48130281509893, 64.7464193067243, 64.4465188057192, 67.63109899336293, 66.65628802391791, 67.12673710238549, 66.37088852543985, 69.0918759376772, 66.19055363439745, 68.65088385920372, 63.92703617772749, 65.09104267243417, 61.69328558829523, 66.22064605835946, 33.48690586705362, 29.072219402559345, 71.64805320001417, 65.61636963198262, 68.45999779239779, 60.594194319940385, 55.38834617983911, 55.6340983606154, 62.94910692399549, 66.71260541485202, 72.21765195169758, 70.2349958112163, 66.6957627573321, 59.25733681648009, 56.227192109630955, 51.770081289352916, 55.716452444753344, 60.987372706013346, 64.76405036064887, 67.98000950967112, 66.14855289459229, 59.482696594730506, 51.8749576230203, 54.828345467967374, 65.15294551849365, 74.173337874874, 73.99973377104729, 66.40074560719152, 61.54002289618216, 66.7296677251016, 75.3575171193769, 76.06075886757144, 65.52713178819226, 28.629572083873136, 2.4153754499650772, 0.2576803842619542, 0.79836179892863, 1.0794397034952719, 3.444920888831539, 2.760433953615927, 0.27034161131708856, 0.3792094775745946, 0.04948750641497393, 0.13288931921124458, 0.051823645574791785, 0.08753573431843713, 2.593924927134668, 19.0294514548394, 52.4995715387406, 38.456815596549745, 38.279622524015366, 35.508507220975815, 18.953108402990527, 47.32067792646347, 58.20659268286921, 65.84334542674404, 77.28893926066738, 77.94459481393137, 9.451435342911752, 0.5242613006022669, 0.2638585462925896, 0.02962731857663922, 0.05605183038560133, 0.09098112282733764, 0.00901265383412641, 0.057954095649502935, 0.03356951318921582, 0.06304089648408756, 0.056595193567655744, 0.0915307066433372, 0.03833785893455629, 0.03695118233501431, 0.06735023681915576, 0.1288670511736024, 0.08361800663894223, 0.02389517676595959, 0.010390691834712222, 0.009563842604327346, 0.1144831451857763, 0.06566983061812579, 0.051294309462630944, 0.02774016248182424, 0.06487227180191586, 0.02992706388355263, 0.02650272938603115, 0.024593609550427047, 0.07441564357929653, 0.03424111182891554, 0.03175770950263306, 0.1514141525953047, 0.12688758722957105, 0.22209884839192515, 0.09321863582778363, 0.08397119615467326, 0.2666639602713047, 0.11853893723098502, 0.13719313988281837, 0.17789488568180994, 0.17808427793845055, 0.11044648235603688, 0.16482966982068556, 0.19521766582564, 0.20839725861385947, 0.06450448831122729, 0.17601173431161912, 0.1200624026598469, 0.11687989722216323, 0.1508660320072405, 0.13916649044521395, 0.09353064045670534, 0.12911920135300006, 0.09586213712370205, 0.24845621067910428, 0.15317479118464455, 3.778261066444459, 70.50283093606272, 99.85145584229501, 93.01077165911275, 90.97554006884175, 72.08178104892855, 45.850397079221665, 34.57805041343936, 41.15892464114774, 55.219119441124704, 73.95421074282739, 61.00747485314647, 50.62543561381679, 47.339450390108176, 18.371852367155014, 1.3441509056475855, 0.2801431547249517, 0.1630853029388574, 0.333004753676153, 0.7564156658707127, 3.0675766208479485, 4.522506536975984, 8.945917333326033, 11.331861768999408, 10.114659109423238, 7.737531671600958, 7.552692919008194, 21.61119668714462, 29.690877199172977, 41.38906971100838, 62.20907726595479, 74.20434813345634, 74.39954880745181, 72.74914879952708, 74.21378535609092, 73.64045250800349, 67.47945231776085, 64.65566350567725, 73.00594637470861, 72.9384502287834, 67.36644883309641, 56.590882116748446, 58.98416726819931, 73.08402507535874, 73.33169137277912, 72.74794855425435, 71.45032651962774, 74.44467959865447, 69.36510039914039, 68.29246551759782, 67.00408458709717, 70.50150517494448, 68.04328518529093, 69.1645025437878, 68.07547999966529, 70.8329297650245, 68.60401153564453, 70.84694831602036, 65.366330300608, 66.34155704129127, 64.30720406193888, 66.24756136248189, 39.37592890954787, 33.81676543143488, 73.42009375172277, 70.59755617572416, 70.52685937573834, 63.01312392757785, 57.8469584065099, 58.410089169779134, 66.11771522029754, 72.69233718995126, 75.30476124055924, 71.64830423170521, 70.31425122291812, 63.24581069331016, 59.01731914089572, 54.374664521986446, 57.55302775290705, 62.701354334431315, 68.45067039612802, 71.78048810651227, 70.19234395796254, 63.41718296850882, 54.24171186262562, 57.155287650323686, 67.60288146234328, 75.15951587307838, 75.34510674015169, 66.93058721480831, 63.48389856276974, 66.69608439168623, 75.51154859604375, 77.94513610101517, 68.22776209923529, 30.460026533372943, 2.036035676156321, 5.029760195362953, 6.012822851057976, 3.513670232026808, 7.019177521428754, 2.7761910951906636, 0.48465755798162957, 0.32621592763931523, 0.22559289880577596, 0.23173090250742054, 0.1650080610547335, 0.5352101679290495, 4.277884979401866, 29.21287363575351, 67.76643645378851, 48.26946789218534, 53.35985322152415, 48.45964400999008, 25.207865007462043, 54.74099036185972, 66.7189125860891, 75.80145882021996, 85.7121507583126, 91.82543139303885, 11.50069038714132, 0.6071406146211009, 0.36832373589277273, 0.17676950252104193, 0.16931433320766495, 0.17594471694000308, 0.10331257201370694, 0.1514012363529013, 0.15194736511236237, 0.31210624282398536, 0.17998170918754994, 0.19654977015189587, 0.14377944291599337, 0.12206461175435013, 0.18244213845220306, 0.13363826208777968, 0.25472022052253446, 0.14515922855465643, 0.10001799557358028, 0.15249773799892397, 0.22046749480068686, 0.14394903946067059, 0.14826517882606677, 0.11529788735412783, 0.11909536221214842, 0.19185251736592865, 0.14587833996742003, 0.10228832011982318, 0.11308727170070333, 0.14423178719176402, 0.19884948949179343], [0.0223637804118616, 0.022595546906813983, 0.014366982147968827, 0.09442940714859194, 0.033185929135088964, 0.06129114783459133, 0.02285887622424672, 0.026017996828041734, 0.05167462998220036, 0.08421455930557945, 0.025180884892301216, 0.04262646509995384, 0.06930508635817997, 0.03129461701328476, 0.07053365390146933, 0.04299105017355854, 0.030532298241591746, 0.0689738835658758, 0.05665046681139258, 0.08307622159801184, 0.021984304504228697, 0.0671123358751497, 0.08098204364819873, 0.07984229633885045, 0.3179716571204124, 22.034332175408643, 71.89807291953795, 75.15988457587459, 68.3267548776442, 49.48337870259439, 47.806000632624475, 23.49779594329096, 17.78665238811124, 30.57222200978187, 37.87541835538803, 33.946725322354226, 45.65426288112518, 28.602131182147613, 6.7154414326913905, 0.41691718322615473, 0.043089086445228714, 0.1078407185512685, 0.0750391242364722, 0.13731880894591733, 1.0658837470316118, 1.9872806149144329, 1.7291499241705865, 2.675837254331958, 4.9533323222591035, 3.1005370328503274, 7.047042039132888, 17.65562169013485, 39.77754039149131, 50.08154407624276, 64.19288266089656, 69.9442305103425, 69.20553838053058, 68.40343721451299, 67.87250518798828, 67.29251215534826, 69.86754817347374, 65.9598005971601, 68.64115638117637, 65.43317925545477, 66.31343364715576, 58.4839395553835, 51.147099079624304, 50.59427238279774, 63.525565901110255, 66.20901230842837, 66.43793752116542, 63.533677362626605, 67.81267335337978, 63.92967985522363, 65.25138916507845, 63.164029275217366, 67.43665141444053, 64.18239032068561, 65.3914060131196, 60.74649603136125, 64.22798002919843, 61.213418899043916, 67.81830587694722, 63.31332645108623, 69.83666343073692, 53.02070548457485, 66.23017741787818, 32.65435926375851, 33.19340275179955, 72.52403613059752, 60.10089351284889, 63.22885820942541, 51.653579050494784, 50.30650769510577, 46.35628084982596, 53.1455349153088, 54.96299259124264, 55.37393146945585, 53.34960014589372, 55.731835980569166, 50.0019552630763, 49.2354025379304, 46.72372848756852, 54.07243413309897, 61.04630631785239, 66.35371638882545, 66.0741533771638, 68.08894157409668, 60.034511320052616, 54.249085918549575, 48.567191477744814, 58.663242863070586, 61.72577065806236, 70.3073243171938, 64.16530055384483, 65.52841048086843, 65.56942670576035, 67.60104579310264, 71.08743667602539, 73.82722008612849, 74.89321047259916, 55.409699563057195, 9.6861558575784, 0.541075091929205, 0.5543969932102388, 0.464351968539338, 2.7790159371591385, 0.6930739228283206, 0.021889407277828263, 0.09380767317188364, 0.06791731808334589, 0.04640858372553222, 0.02601872652678961, 0.04294865869826848, 0.8601861975846753, 17.572147769312707, 59.75692518295781, 46.63169791621547, 63.52973538060343, 35.17261112889936, 29.176462273443903, 48.75742250873197, 58.848280675949596, 63.79294210864652, 70.11319837262555, 28.406657903425156, 0.7767090898367667, 0.1046877381421866, 0.031574840484667695, 0.032802831546794024, 0.05199832511284659, 0.05483062494726432, 0.06681117139035656, 0.05118116210665434, 0.03919373619400206, 0.04623700301313112, 0.006656095079491817, 0.03412493076475878, 0.023938181111589078, 0.041503441489992604, 0.018948757713059747, 0.04201985369887083, 0.02889242766785526, 0.008239596424954794, 0.04285331139521253, 0.04480663641926743, 0.030008931869580865, 0.010331325766239918, 0.045581181954231956, 0.03308487447699712, 0.04505791325843142, 0.028351718980458476, 0.0848634894035997, 0.013517655897885563, 0.10909693420774515, 0.04785655501989588, 0.0533959414479473, 0.1475564555655564, 0.02467386875181429, 0.06053842048371031, 0.007379082418347319, 0.03031970309694448, 0.03638777829286072, 0.06848392437302298, 0.05649578982904073, 0.055445291762871135, 0.028776608580242724, 0.03838090158458199, 0.0369323710460336, 0.06862902908676094, 0.042724918889542746, 0.020735282413361054, 0.05037807596607074, 0.03594017610134136, 0.028979445679954467, 0.04266253251942896, 0.0353189324209046, 0.042795900766166954, 0.031950905385817734, 0.0695499970066932, 0.28491514704881177, 27.352603289388842, 85.13455821621804, 80.948345891891, 77.04607394433792, 57.628109762745524, 56.99562365008939, 36.60108735484462, 22.947195191537183, 33.213312702794234, 41.04914926713513, 40.239701501784786, 44.58906089105914, 29.6924324189463, 8.213338707723926, 0.22457110605412917, 0.15064172146301116, 0.050137175787841125, 0.19526789054995586, 0.5581206708185135, 3.044895515326531, 4.26437339475078, 3.193545254968828, 3.1090069009411723, 1.8102457855016956, 2.7827939150794863, 8.348194206914595, 19.413063180062082, 40.65235837813347, 52.754054915520456, 66.28194485941242, 71.83551896002986, 71.78476349000009, 72.30486193010884, 70.96581182172223, 70.19234395796254, 70.98406653250419, 66.75320979087584, 67.23767742033928, 68.62659654309674, 70.77721641909692, 62.201059941322576, 54.945506665014456, 53.264547471077215, 64.97798427458733, 69.0726641685732, 68.57073414710261, 65.30455297039401, 68.04563076265397, 64.75185571178314, 66.87438749497937, 65.40931163295623, 71.22511186907369, 64.83915198233821, 66.7229526273666, 63.36554888756045, 66.60882734483289, 61.77992290066135, 69.04335621864566, 64.27354228112006, 68.54706656548285, 55.730482762859715, 67.91847536640783, 36.6472222728114, 36.586645187870154, 75.36095311564785, 62.11991786956788, 65.44811564107096, 52.549977917825025, 54.20837171616093, 47.42871176811957, 56.90465211868287, 57.78265114753478, 59.829026191465324, 55.510571156778646, 57.699869525048044, 53.49204101870137, 51.4775352324209, 49.17033826151202, 58.02717562644713, 64.22153165263515, 70.05583763122559, 70.08748331377583, 71.24326459823116, 62.89941441628241, 59.00756420627717, 51.621862765281435, 60.966995992968165, 63.697216664591146, 73.45005281509893, 66.74693399860014, 66.90950055276194, 66.68673346119543, 70.87642885023548, 75.01868709441155, 77.8503010349889, 79.59137055181688, 59.98743895561465, 12.750426165519222, 0.5485700671711277, 0.45567452126453, 0.8861068131462221, 3.7686171839314127, 1.4953848743630995, 0.9612460650743978, 0.5403151327083188, 0.11417494035295903, 0.06532172026533274, 0.045036118056985645, 0.04927947140869595, 0.6877697139017044, 17.835407449353127, 44.03290410195628, 48.784086781163374, 41.55990462149344, 40.542265292136904, 46.85839914506482, 52.84556381164059, 68.62571793217813, 69.71087301931074, 79.19469341155022, 46.878952364767756, 1.9237259607161246, 0.20776462320598865, 0.007525247206250507, 0.043506504772531415, 0.035658267236525015, 0.029005642056525237, 0.1405163833330716, 0.06332037685018393, 0.023554997338402658, 0.010471814800234092, 0.042407402258005836, 0.022114346014155496, 0.08075507477887216, 0.05371238938682983, 0.04292881702102962, 0.07585962738601432, 0.022300319603434014, 0.022133888917103894, 0.041999445116568, 0.04044183514892094, 0.02901422990215642, 0.030859080706572825, 0.016023817738788505, 0.016877317252839287, 0.03650304388194796, 0.03143650415774075, 0.06341897236603884, 0.027265706993339044, 0.06000916481078152, 0.013904964096934326, 0.1408914753025578, 0.20891324947437934, 0.1185523207870222, 0.2086984230986526, 0.1669432604384999, 0.2049914155636103, 0.10341772524219367, 0.18011001359310844, 0.16148742738991015, 0.2428705716926244, 0.1545784634447867, 0.1775453657272362, 0.21069538449087452, 0.18429015703018636, 0.17926059062442473, 0.23895727200133188, 0.1636172284282023, 0.12199705812118708, 0.12419306447789555, 0.16160152852535248, 0.10293444633604058, 0.25476465362214273, 0.1365764237820141, 0.24200685352327364, 0.5826074149339431, 37.779398733569735, 95.6845808029175, 91.02606804140153, 89.95870482537055, 68.53600548159692, 65.39491261205366, 33.88320253741357, 25.83477350973314, 45.545213145594445, 53.45420975838938, 48.81384972603091, 59.65652819602721, 40.0253322047572, 10.312913348597865, 0.646279372515217, 0.25596253934406465, 0.1974761543134528, 0.22175876664057856, 0.42089805187236884, 3.634682215990559, 7.104055650772588, 6.159881334150992, 9.84945393377735, 12.212338755207679, 7.942770671459937, 13.085116128767691, 22.539617784561653, 43.29645164551274, 53.66420561267484, 67.89819671261695, 77.16042672434162, 74.48287563939249, 73.86500035562824, 73.80148933779809, 72.48793463553153, 73.18871313525786, 66.56524981221845, 67.20560812181043, 69.72489941504695, 74.68342642630301, 65.8355712890625, 57.385111085830204, 55.87971325843565, 68.59429190235754, 72.3630855929467, 68.70483213855375, 65.9934937569403, 70.02940870100453, 67.27137842485982, 70.47233058560279, 67.70396094168386, 73.46232983373827, 66.30543985674458, 69.26033389183783, 65.65298887991136, 68.1161157546505, 63.84954191023304, 70.29950311107021, 65.98553134549049, 73.30903576266381, 59.16216050424884, 65.85953697081536, 41.84892054527037, 40.23996037821616, 74.9909245583319, 66.47400763727003, 67.52137461016255, 55.81409985019315, 55.503389296993134, 48.94875964810772, 58.817905841335175, 60.73221075919367, 61.838115184537834, 59.07071044368129, 62.085601052930286, 56.57298826402234, 53.55257495757073, 52.433271715717936, 60.21155142015027, 66.99297643476918, 73.38201538208993, 72.56144769730108, 73.8101734653596, 65.54013836768367, 61.78595942835655, 54.08908459448046, 62.699106816322576, 66.58806231714064, 76.39458394819691, 67.79008050118723, 66.22940863332441, 66.05971121018933, 71.78612847482005, 76.71224886371245, 79.92878067877986, 82.05524659925892, 64.64755988890126, 12.695281563266633, 3.2550308589012396, 6.770948363888649, 3.722983103606009, 8.342074328853238, 2.8070044998199712, 0.40970510893291046, 0.6468487290605422, 0.2739562899354966, 0.19630184877784024, 0.17916873668230351, 0.19399086794545575, 1.4047162234783175, 27.609481273158906, 82.11708668739566, 62.12223206796954, 80.27190962145406, 54.48419670904837, 44.39491925701019, 63.31835885201732, 75.93016747505435, 79.85898602393367, 88.45438172740322, 51.604925970877375, 1.699891003870195, 0.3514671049291088, 0.10279378493226345, 0.1639500783095437, 0.15573268215502464, 0.10476630811970081, 0.26723144756209466, 0.13013791443119127, 0.1603506754843458, 0.14129794623342254, 0.12553779393314354, 0.1407516948998936, 0.15388250320909486, 0.14670444321968865, 0.14780514302753633, 0.15543589969315838, 0.0946135287203135, 0.09941420337605862, 0.11230004741059196, 0.09180342628350181, 0.07206091912643564, 0.11739597235235477, 0.09643901665244373, 0.07433682079276732, 0.12636375162870656, 0.20866100736443075, 0.22853795529132892, 0.06916897551667306, 0.20022391251498656, 0.1295764792350031], [0.059414362655051296, 0.03448394637915396, 0.02106773584420162, 0.013015708386627658, 0.06620978470891714, 0.04384300506283199, 0.03351124071125542, 0.02394723818607388, 0.015275603603391398, 0.03317814568177827, 0.0580981623141035, 0.010008190837388319, 0.04239724393212988, 0.056025293099904255, 0.03130661011973937, 0.029265908937480663, 0.0518441767311625, 0.032192297775538704, 0.05241387035517443, 0.08291355048817012, 0.040012316462854226, 0.09064207529468883, 0.04345577826062518, 0.016148556962669376, 2.624182090643914, 41.71730149176813, 75.80954674751528, 76.13181652561312, 59.4215036976722, 40.39846727924962, 34.709540028725904, 17.92519050259744, 39.02206836208221, 33.3431274660172, 35.07206509190221, 48.6154797769362, 26.755349866805542, 3.515910395691472, 0.11613297681774824, 0.008839890473492203, 0.038214675826771606, 0.09590798748597022, 0.06832853875934117, 1.0564005591215626, 3.438851756434287, 1.668393881090226, 1.7802090101665067, 1.5344807313334559, 5.730217060735149, 14.007275162204621, 28.222516352130523, 51.80566503155617, 59.67751679881927, 63.932990335649066, 69.54917723132719, 66.39330879334481, 65.14238649798979, 64.12291934413295, 64.15793826503139, 67.11704884805988, 69.82434718839585, 64.11257213161838, 66.03565923629269, 67.70105838775635, 64.0205180260443, 56.36435347218668, 48.37417164156514, 48.06224515361171, 60.29789063238329, 64.3864163275688, 68.23900361214915, 62.802100412307254, 65.24090466960784, 65.40305545253139, 66.1637403118995, 65.81250775244929, 64.57443906414893, 63.23162348039689, 65.9548427212623, 64.03673310433665, 68.84077364398588, 62.9429841041565, 67.74715408202141, 62.713423467451534, 68.58971841873662, 56.03842412271808, 70.54207817200692, 31.84526647290876, 31.693929664550293, 74.15878588153471, 56.30636907392933, 62.658761316730136, 54.32120653890795, 55.23926081195955, 48.02169176840013, 48.89488981616113, 44.32101395822341, 49.73164904502131, 48.696445342033144, 48.847091813241285, 45.73946460600823, 47.17098851357737, 48.04542603031282, 60.43697003395327, 65.47299915744414, 67.258999424596, 66.88239697487124, 69.37113300446542, 59.046427049944484, 48.996581185248594, 49.25833663632793, 54.16546883121614, 63.86778485390448, 67.96041334829023, 68.38230348402455, 65.81610848826747, 62.924917667142815, 68.1024423722298, 72.34251668376308, 68.32790805447486, 69.5765475303896, 70.63463826333323, 66.3256557526127, 23.62493172768624, 1.4865703279933622, 1.5266808530976697, 3.6008223554780407, 1.0727656680730082, 0.49187352400152917, 0.2883653312681183, 0.009525662697401018, 0.06453677891723572, 0.15281970943174056, 0.03428316622551891, 0.05522909025932032, 0.9226267760799778, 27.4557125952936, 48.33941944183842, 48.443087685492735, 18.584034942811538, 10.997869987641613, 39.6213633783402, 42.63797590809484, 64.95890586606919, 65.78060319346767, 77.45634601962182, 23.528412003670972, 0.6314839470771052, 0.060477903368131775, 0.07221362343238247, 0.05161484831102914, 0.09347778805080922, 0.02621434899347444, 0.025587773341084682, 0.027005957221732508, 0.042890217680964744, 0.03325174757910352, 0.024866200870864337, 0.009593474885238516, 0.03977354600905411, 0.04320030325963613, 0.07150148341972982, 0.05002981239569284, 0.058388651363671794, 0.034269300034089435, 0.007740912448254324, 0.020142006687819958, 0.0381805083053487, 0.06043609411966416, 0.03698509704742221, 0.0549363948765301, 0.014298084030498662, 0.03341906118176637, 0.03031456456219237, 0.07755027618259192, 0.005326538953194094, 0.026836741805797624, 0.02291754898314755, 0.06793753514366765, 0.044228343458305446, 0.1572525852750386, 0.03182805361106031, 0.03631307705936413, 0.03485042368993163, 0.05375529797146878, 0.030060547043479262, 0.014550508086329267, 0.006582207335609823, 0.04021211219350657, 0.01722492964848155, 0.034967715581578594, 0.010368173637787902, 0.06519644190707514, 0.019705353807958386, 0.0026025232528486563, 0.07563743890533525, 0.06732731546846128, 0.05762611808735998, 0.08218172201586348, 0.07653121070395555, 3.9955221308815867, 58.34559755940592, 88.64841353508734, 85.91919699022847, 68.89332555955457, 52.17846278221377, 44.976783260222405, 21.52459663729514, 29.69411707693531, 24.44468552066434, 36.38628659709808, 43.595685343588556, 27.461127427316484, 3.3928926096808527, 0.14782719103799713, 0.06368274792968746, 0.06171246937986824, 0.41780541620908246, 0.6956761702895166, 2.2498117146953462, 4.554886683340996, 4.297352192863341, 3.4337776803201248, 2.0414235418842686, 3.1666789804735496, 11.79758341081681, 32.377802748833936, 54.45881112929314, 63.38437626438757, 66.88668804783975, 74.35531231664842, 70.10684413294639, 67.8257191565729, 67.13666069892146, 67.81545823620212, 67.7876486316804, 71.26157422219553, 64.85043664132395, 64.90512232626638, 69.60225474449896, 67.35643894441667, 58.2058003640944, 51.71228124249367, 49.93612612447431, 61.33717360035066, 65.61021543318226, 69.39903674587127, 62.616050627923784, 67.09993162462789, 66.01399206346082, 66.9570004555487, 65.94691168877387, 65.97033608344294, 65.42196127676195, 67.1869376397902, 64.97487383504068, 71.02823242064446, 65.23791190116637, 69.48752541695872, 63.95362984749579, 70.20918661548247, 59.19460242794406, 69.57253102333316, 34.477135673646, 34.459088848483184, 74.5630959541567, 59.96934898437993, 64.84651034878146, 56.15823684200164, 58.33465022425498, 51.3794602886323, 49.83052807469522, 46.99297566567698, 51.93839411581717, 50.4904943127786, 50.80872797196912, 47.27961463312949, 49.52145314985707, 51.11588878016318, 63.883482179334095, 68.3894500424785, 70.38875272197109, 68.61100119929161, 72.22299421987226, 62.76484966278077, 50.58741607973653, 51.66851151374079, 56.3318056444968, 66.21291898912, 71.70429214354485, 70.74677098181941, 66.41332857070431, 63.96906437412385, 69.54381142893146, 74.04868495079779, 72.19731838472428, 72.85144421362108, 73.81271516123127, 72.72519880725493, 28.885732273901667, 2.610952671497099, 1.0493990057899107, 4.545928480163697, 1.6752874466680712, 2.0836723716028276, 1.5218902908025251, 0.4672483018329067, 0.33567021871286057, 0.2249385065008556, 0.06831072721510165, 0.020564333723497488, 0.7686457999290959, 27.438067813073438, 46.860234814305464, 44.117964621513124, 22.23164308455683, 15.477285365904532, 52.497206349526685, 50.291794884589414, 70.10416907648887, 68.86755558752245, 87.08664340357628, 40.5377467216984, 0.5838050248642123, 0.03605804638937116, 0.08894859963367063, 0.06177997704775584, 0.05795724810131135, 0.039138911111700925, 0.009367446388838994, 0.04536237958217821, 0.01317515713913787, 0.06396697804091439, 0.09227968016338926, 0.02569448364327752, 0.05868337687946135, 0.05355909902362093, 0.017451461847691287, 0.05085414981529598, 0.047211949488208185, 0.06837131710903299, 0.04696548368120867, 0.06170529496645736, 0.029932799966885682, 0.05708945817464302, 0.03420129057861144, 0.03756429016169521, 0.0437552918259415, 0.04897302474766489, 0.07493166508333338, 0.06174214762605487, 0.023471495669875896, 0.1939017872416204, 0.11494341081068402, 0.1588521155739023, 0.14153284411276543, 0.16429178416728973, 0.11173758565658524, 0.11006190621804808, 0.11192790487961424, 0.23232485047511517, 0.1681743024457847, 0.11167130372937649, 0.04840561023522769, 0.13260404339000104, 0.12583417036840994, 0.09712740793944367, 0.13574206210192175, 0.17411644810870772, 0.17341083516516995, 0.154417906737616, 0.14096405447250412, 0.20415737564044617, 0.09091203701832602, 0.16003346911841826, 0.24896875414396488, 6.685105821778698, 71.53914466980966, 97.36957611576204, 96.39332955883395, 79.84617556295088, 57.924593879330544, 49.1506048171751, 26.043386728532855, 53.064279094819106, 47.3507389714641, 47.12344154234856, 63.193537266023704, 37.361936953759965, 6.077186984400596, 0.45184086407384566, 0.2320305348163651, 0.11705524708715179, 0.36936153988203696, 0.5394323542714119, 4.019588323370103, 8.880636345955635, 7.554173613748244, 8.32269880079454, 6.887578570073651, 12.44244852373677, 18.854990313130042, 34.83519707956622, 55.54980270324215, 64.98602513344058, 69.9685884291126, 75.36824087942801, 72.84633728765672, 70.16262808153706, 69.6184149096089, 70.52321157147809, 72.13329745877174, 73.26298713684082, 65.90254183738463, 66.17235383679791, 73.19367101115566, 70.92872973411315, 62.52512616495933, 52.54246265657487, 51.982167766940215, 65.05863997244066, 70.15283784558697, 70.89259686008577, 62.57714071581441, 67.5566759417134, 69.44037068274714, 70.36273956298828, 70.03502553509128, 67.16128533886325, 67.31745058490385, 69.0036932114632, 67.96708922232351, 74.88227490455874, 68.27032766034527, 72.05425385505923, 68.0076700641263, 72.44874231276974, 61.72543725659771, 69.12587504233085, 38.56555546483686, 37.27416607641405, 77.03289478055893, 62.991664640365116, 66.89132428938343, 59.63859904196955, 61.616650319868526, 54.94152938165973, 54.15061873774375, 49.10637224874189, 54.92602817473873, 53.81576207376296, 54.54839021928849, 50.28218900003741, 52.601051099838756, 53.6476061421056, 66.9645941642023, 72.49472033592963, 73.62793230241346, 72.50811130769792, 75.18432878678846, 64.46593453807216, 53.279079852565644, 52.847995681147424, 59.56894559244956, 69.46889415864023, 73.23036870648785, 71.49463361309421, 66.60771339170395, 64.73973951032086, 70.49650807534495, 77.35142261751237, 74.84655780176963, 75.24256029436665, 76.78433418273926, 76.21959917006954, 29.9353349977924, 3.117513050956111, 11.626713199000205, 12.51648129955415, 3.843855598280507, 2.4838791547283052, 1.180762860082811, 0.4519691378358872, 0.2399559288976654, 0.36579466515010406, 0.2493517981061051, 0.2015970331887084, 1.6298206799453305, 38.90928845251761, 66.85122982148202, 65.07708687936106, 26.967903106443345, 17.47954257072941, 55.725077736762266, 57.856662350316206, 84.18075546141594, 77.57725700255364, 100.2536556797643, 39.356509254824736, 0.8049733828633063, 0.22252868500448045, 0.220281028999917, 0.2717320302561406, 0.23955492783458004, 0.20219810577409886, 0.09897836829505621, 0.15165989827965537, 0.18607092841017633, 0.19249313540997046, 0.1289979909216204, 0.13399859920384424, 0.10409351438283922, 0.12121143495483745, 0.14011256306642486, 0.224938583109648, 0.10499772795986746, 0.1450560977982898, 0.1291136089111528, 0.1453589017112409, 0.1406127571939461, 0.17083273479534736, 0.12055325817557112, 0.15358616507822467, 0.14427393734935792, 0.12679894319585255, 0.15329056239176184, 0.16084414335989183, 0.08278260307927286], [0.01806827370948609, 0.03839169193299548, 0.014151455759401283, 0.04323021516263966, 0.031316565432315396, 0.05797115259713704, 0.029323083994489525, 0.05214575490343475, 0.03935418564886336, 0.04663751761038457, 0.08560028978653493, 0.03183953918426508, 0.06693369183208674, 0.022537268683194153, 0.03410026273359695, 0.0011457498476374894, 0.05101910769759167, 0.017722116880899957, 0.03899503596908143, 0.04882684751083294, 0.09436111807102159, 0.08426530496968378, 0.13003476835306615, 0.04072552516816124, 21.875113364188902, 71.07923892236525, 69.16865241143012, 66.42774720345774, 53.41660991791756, 22.87791044481339, 41.28752346961729, 51.50216771710304, 40.08341073989868, 59.18570649239325, 56.48615875551778, 30.102728028451246, 3.605147258889291, 0.21230260631249798, 0.03514057949125286, 0.056347781642069744, 0.06911504292680372, 0.17611363932730692, 1.0451520594858354, 1.2826308584020985, 3.278474375124901, 2.8021213941035734, 2.338199139602723, 3.276565161443526, 14.64834047902015, 44.47418251345235, 62.578572380927305, 71.05898380279541, 66.12526186050908, 70.09759518408006, 68.04771746358564, 66.09626770019531, 62.35927658696329, 60.39709129641133, 62.71237619461552, 67.51570286289339, 66.98976009122788, 64.11128951657203, 65.19950405243905, 63.57542314837056, 61.797306845265055, 52.09032320207166, 46.828498917241255, 49.212138960438395, 56.96042037779286, 64.41490450213033, 65.92950420994913, 63.29038450794836, 61.61481072825771, 62.40620382370488, 62.623946359080655, 62.00219969595633, 65.66955697151923, 64.19207073027088, 67.51824455876505, 63.83195400238038, 64.35924606938516, 59.85175240424372, 64.20637561428931, 58.79258301950271, 65.17401649105933, 61.824959554979884, 70.14466362614786, 31.97550681329543, 34.48268190506966, 70.86868609151533, 58.319215697626916, 64.70286530833091, 57.96165243271859, 64.82955002015638, 56.462220530356134, 58.77374779793524, 51.57971297540973, 49.56285376702586, 45.11865931172525, 46.77886916745094, 45.21388269239857, 48.76473380673317, 52.68455836080736, 60.84086825770717, 65.12004467748827, 63.87023633526218, 59.37758099648261, 67.59022789616739, 54.19711451376639, 50.446759885357274, 49.15691198841218, 55.755138781762895, 61.34711680873748, 68.07663317649596, 66.2925744825794, 66.8164776217553, 61.509295048252234, 69.25163407479563, 68.0252815062, 66.53937785856186, 66.9473357354441, 71.28180580754434, 71.75021525352233, 74.88700528298655, 36.996819203899754, 1.7199698619304167, 3.0879964799650255, 0.6941032998504177, 2.669218009518039, 0.5211207078349206, 0.19298761452157653, 0.08385753935022701, 0.10008232397658211, 0.04971700720489026, 0.05192565018190973, 0.024335399615548314, 0.9964861708783335, 34.92786699725736, 35.846470402133086, 42.07653960874004, 37.63207058752737, 21.354040215092322, 38.99812229218022, 52.12677771045316, 63.2056652345965, 63.09160663235573, 67.34322840167631, 12.764877157826579, 0.8796473436297909, 0.0916078593581915, 0.1072615790631502, 0.07969172941821237, 0.07554786790522837, 0.05735235273717873, 0.04556340488394903, 0.08737159998066003, 0.027886916199819218, 0.07726737523391362, 0.03581039314608901, 0.02147413782715317, 0.016062479323497223, 0.017269786011667985, 0.07518587603924737, 0.06443134223621699, 0.11368524929087971, 0.02737715746456337, 0.038767304842270194, 0.058454289777024146, 0.0356176186112627, 0.03352663907853346, 0.03376131096193868, 0.04203337132029476, 0.015007207571949451, 0.08353363737584123, 0.059697819017474694, 0.018922611132204052, 0.03241190070947332, 0.03384847644596331, 0.02141166910258753, 0.007119550502994248, 0.055575752705936475, 0.06323769298051635, 0.028055603015086347, 0.02496336763274045, 0.058594690710907026, 0.045481870146167856, 0.03747042140833313, 0.0491437474415908, 0.03627933854717882, 0.12201473176960023, 0.028333677609841672, 0.04859503696582491, 0.029915767917109114, 0.06377037689690629, 0.028048934219705484, 0.014527922856711574, 0.071076741291871, 0.05303366995987393, 0.041880632540391344, 0.02705548863647686, 31.3230852542385, 86.44373555337229, 75.9972478497413, 73.49456387181436, 62.28614791747063, 41.3732547144736, 49.131291066446614, 39.36600139064174, 38.602257082539225, 49.005473198429236, 47.055812035837484, 27.16902263702885, 3.0467480997885428, 0.11619673065480687, 0.07382145046346611, 0.038577514219908945, 0.2410871802919334, 0.542255909212174, 1.650816514607399, 2.3289749506981146, 3.6520990104444566, 4.323310928960001, 2.3968143040134064, 3.4072756959546, 17.816482013271703, 46.152882422170336, 66.73037375173261, 75.83689351235667, 70.98549427524691, 72.01415938715782, 71.88014768785047, 67.07212202010616, 65.96323659343105, 63.57385420030164, 67.28096469756096, 69.75420736497449, 67.90693575336088, 63.9459498466984, 65.97445457212388, 65.36901320180586, 65.09527098747992, 55.28888271700952, 49.93887570596511, 49.9722864550929, 60.88227279724614, 67.47034457422072, 70.01368784135389, 63.93811687346428, 62.01952088263727, 63.781296591604914, 65.38502431684925, 63.84557247161866, 66.94488033171623, 65.90757816068589, 69.08718478295111, 66.30573795687768, 67.9500896699967, 62.9014148250703, 65.89663474790513, 60.90961171734718, 67.87276406441966, 63.670509246087846, 72.32132804009223, 35.693831366877404, 36.86114049726917, 72.51783094098492, 61.71864763382943, 66.43704322076613, 60.40782290120279, 67.60279517019949, 59.941186366542695, 61.12143147376276, 54.03617966559626, 50.35658459509573, 46.93259469924435, 49.51558920644945, 47.921294781469534, 50.74674667850618, 55.08167174554641, 63.93945832406322, 69.35986011259018, 65.80995821183728, 63.556623228134654, 68.66880124615085, 56.26756506581461, 52.69694912818171, 51.62473394024757, 57.25884606761318, 65.18716035350677, 72.13630199432373, 67.86211090703165, 65.91884320782077, 62.98326292345601, 71.34392046159314, 71.32839572045111, 70.26428807166316, 70.72929290033156, 73.70404981797742, 73.85779888399186, 76.67289964614376, 43.26285262261668, 3.623138435425297, 1.262785258793062, 0.6475615585523268, 1.6792753939667058, 3.2071039080619816, 1.3496158704642327, 0.670477148265608, 0.15254531205902178, 0.13084415556682696, 0.04223559171922746, 0.048206921501625935, 1.5921460692920995, 34.67216376335391, 40.19098174187445, 28.54542547656644, 32.470139265060425, 35.705402358885735, 50.752700836427756, 61.6746307957557, 69.015821180036, 64.91507337939355, 77.84097363871913, 26.578329378558745, 0.862686402134357, 0.017234387003906795, 0.06145109167142261, 0.05669195047249237, 0.04262564538587486, 0.024336410851608363, 0.10351947704029661, 0.06064232115844085, 0.024298533549412124, 0.042520254670131596, 0.045928472592946024, 0.029440260972947847, 0.038442579323365804, 0.033447303013094974, 0.045008676787537914, 0.03189148377597092, 0.09283422822913817, 0.007879285164357675, 0.006595718253764414, 0.09380909043454355, 0.007907232051835427, 0.03926160392321406, 0.023764420879043402, 0.040024570039203095, 0.033113238882393606, 0.04558192505951851, 0.03428992695145069, 0.00708830034014799, 0.1216670351042863, 0.14902008186665275, 0.13892279787650033, 0.07017926162769718, 0.21633365371775246, 0.24549615419199391, 0.14108339564934855, 0.17648626449367694, 0.25515805509301925, 0.13020218920803842, 0.161495026982119, 0.11034054771786737, 0.17814101441012276, 0.1825179964784653, 0.12303346783042916, 0.10707875218002066, 0.17154643762736552, 0.12879157619130227, 0.1535279117524624, 0.11470447564798017, 0.16567187624112253, 0.20534689568223494, 0.21650056895469466, 0.19983507692813876, 44.820002202064764, 101.11633393072314, 87.96092402550482, 85.2452475024808, 73.5108809317312, 36.1727802215084, 54.06027478556479, 65.58388848458567, 56.885726682601444, 76.46315482354935, 72.23501236208024, 41.13275850972822, 5.530310032829162, 0.4732573422933779, 0.18043393088925272, 0.1946140957936164, 0.27805139761297937, 0.49113921340434785, 3.0197335106711236, 3.7893770635128026, 9.660229971331935, 11.374381242259858, 7.421857358947878, 7.00935100355456, 19.147793285308346, 49.56259096822431, 67.47506710790819, 78.26851983224192, 71.77032132302561, 75.61306738084363, 74.5793031877087, 70.44571338161346, 67.71310006418537, 66.16544262055429, 69.05314645459576, 74.5803386934342, 69.66418896951984, 65.22335990782707, 67.08497954953101, 68.53529161022556, 66.41492889773461, 57.80773862715691, 52.04292920327956, 53.70911675114786, 63.90608287626698, 69.84380214445054, 70.82005654611896, 64.50072988387078, 61.144083161507886, 65.86119221102807, 66.81501065531086, 66.71958723375874, 68.43018777908819, 69.22241241701188, 70.77614953441005, 70.04034426904494, 67.84116545031148, 65.1684114240831, 67.7304526298277, 63.88027760290331, 69.2810675405687, 66.30854637392106, 72.23589881773918, 39.57183168780419, 39.43834950847011, 72.28033927179152, 65.7945550641706, 69.15030356376403, 62.94989924277029, 70.80972502308508, 63.22322176348779, 63.357449193154615, 59.55246379298549, 53.54319657048872, 50.59121293406333, 52.13847421830701, 50.1793287646386, 53.389165093821866, 57.98049157665622, 67.1508518342049, 70.65035912298387, 67.98231586333245, 64.74681154374154, 72.44368245524745, 58.400640180034024, 54.63667492712698, 52.83013712975287, 59.598382980592795, 67.25135864750033, 75.42642531856414, 68.61815560248591, 65.59334139670095, 63.62368399097074, 74.30563157604587, 73.21807599836781, 72.06808413228681, 74.87512834610479, 77.35282682603406, 75.56690108391547, 82.4539476825345, 45.60189531695458, 4.671155541173873, 10.425424575805664, 7.160815779239901, 7.7971031588892785, 3.8583798898804575, 0.8181155905608208, 0.5993232695806412, 0.14596519901627494, 0.4003974470880724, 0.22655455365536675, 0.12777373645334475, 3.0575363337993626, 48.154271802594586, 51.96110463911488, 62.27993880548785, 53.43028330033826, 31.699064047105853, 57.92477823072865, 67.41479596784039, 81.29480884921166, 73.58187583185011, 94.36092207508703, 25.694433066152758, 1.046622948300454, 0.16700416442848023, 0.1942483500968064, 0.11007368098944427, 0.0813148015989892, 0.13761261898663738, 0.2582411912660445, 0.22336678519364328, 0.14160488702116475, 0.15999937820578777, 0.2513203836016117, 0.165528709729833, 0.12321674670543402, 0.11163917400183217, 0.1485111083715193, 0.16018213614100413, 0.30712648745506044, 0.1359789058445923, 0.18378706709031137, 0.1817431138648141, 0.06136865678033041, 0.09559736181531223, 0.10035985464891119, 0.13978014219432108, 0.11359331107908681, 0.24126122014657145, 0.18749929934499726, 0.14427841130283572], [0.00937733562633155, 0.020983027587194118, 0.03446839479429107, 0.05137470655984456, 0.055441438340612, 0.04181024438190845, 0.009358975371616262, 0.07061950937514344, 0.08299042741137166, 0.05198162439609728, 0.03717445099966661, 0.03413289041829205, 0.024050087405128345, 0.03952362131507647, 0.021847797212220972, 0.04571794780091413, 0.0472388161917127, 0.02488088103071336, 0.0655812938367167, 0.06668721070332874, 0.04388979388280742, 0.050567188600619, 0.03162444659298466, 5.387233245757319, 59.634488398028964, 69.20034516242244, 68.9807395012148, 55.31955172938686, 46.83368429060906, 15.573698205332603, 31.792406651281546, 54.786431020306004, 38.955164494053015, 41.949631321814756, 34.99611231588548, 3.2620396441028965, 0.028729792947189945, 0.06384990448432584, 0.06287238778426282, 0.020385446447518565, 0.13817258329401094, 0.5969890916059094, 1.524999259460357, 1.3869855168365663, 2.64837404412608, 3.3139230407053426, 6.581355698647038, 27.45828567012664, 58.25709319883778, 68.98251241253269, 68.48420666110131, 67.6966182647213, 68.48865462887672, 65.02690799774663, 62.67902035867015, 57.00446075008762, 56.68082206479965, 59.990600385973536, 64.97802742065923, 66.18953381815265, 65.70831783356206, 65.04398991984706, 67.15727667654714, 62.33620520560973, 59.2077031443196, 48.7835023480077, 48.411532217456454, 48.32318867406538, 57.677939553414625, 61.41055330153435, 66.73248398688533, 62.12838626676991, 62.72968953655612, 62.99549679602347, 66.22829468019548, 62.66497827345326, 63.920156340445246, 62.83867259179393, 63.631854288039676, 60.1869503144295, 60.475758352587306, 57.90165193619267, 61.685307487364746, 56.884032218687004, 63.90762829011487, 58.437145679227775, 71.85457383432697, 42.855875338277514, 36.76227715707595, 68.19380221828338, 58.0325492735832, 66.3332494612663, 60.56489813712336, 65.41742309447258, 63.21301183392925, 63.115878258982015, 58.40661394980646, 58.11354621764153, 52.3724945898979, 51.19734856390184, 46.816731806724306, 52.831003973560954, 56.641963143502515, 63.528005615357436, 64.3818820676496, 58.02638330767232, 63.210454448576904, 64.32802008044335, 48.57518526815599, 46.12422558569139, 49.963986719808275, 58.57564064764208, 64.50406782088741, 68.3589889157203, 63.84860838613203, 64.40931512463477, 66.15023951376638, 68.92581062932169, 68.27038257352768, 66.22524307620141, 61.04532180293914, 64.28193223091864, 69.54266609684115, 71.10296141716742, 71.80043728120866, 45.067417467794115, 7.124071015465645, 0.7601076580824391, 0.9202357237377475, 3.510637749587336, 1.3258954594212196, 1.2543125714986556, 0.27566411442333655, 0.0814324037562455, 0.04567361429273602, 0.081526632570932, 0.018156624714573546, 7.794857111669357, 46.452735854733376, 48.83140625492219, 30.53381416105455, 12.488701112808721, 20.24129321498256, 39.481703465984715, 51.306590495571015, 64.50951991542694, 64.06807284201345, 62.48417662036035, 9.972863466508928, 0.6418233148513303, 0.11802332175354804, 0.06113607248651886, 0.11996785974911145, 0.03667216162167249, 0.04884034598005876, 0.04117172158833954, 0.04658228650148358, 0.08623264174187377, 0.030189891413394964, 0.04840030890679167, 0.042539353242083904, 0.10466786582143077, 0.04992121177154684, 0.030779219870906205, 0.006658591089710113, 0.04278140638263957, 0.01672592295724298, 0.025988257294821165, 0.06989984637907437, 0.080659152909873, 0.04491031492849992, 0.07524166256189346, 0.025228219549922694, 0.013087393148922393, 0.07631094510396642, 0.028192004970004483, 0.018207261211148674, 0.03729606362720651, 0.04039285914792169, 0.06693936854360566, 0.024448824678397468, 0.015605244533939949, 0.010940468130302767, 0.06779950908235005, 0.1476877630357781, 0.014578057565696299, 0.04739984021251721, 0.020495439436466947, 0.0422129423297461, 0.11045093332687694, 0.029391901672727642, 0.06917139635451379, 0.024334007250745932, 0.057573985804112694, 0.1067027715485423, 0.018725077276148142, 0.027031132786144173, 0.02401684876531363, 0.08198638491693043, 7.365258047657629, 74.10475131004088, 76.6870201787641, 78.58890687265705, 66.32196872465073, 55.73323234435051, 23.63630267881578, 39.81633263249552, 49.405660860000125, 44.00851872659499, 50.954961776733406, 33.301828830472886, 2.8319331234501255, 0.08627755747687432, 0.02331409716017304, 0.1616416562108263, 0.12548017646035842, 0.8437508536923317, 2.8792771120225233, 4.106425431466872, 2.9461469044608455, 2.0120843355694125, 1.8549065051540252, 7.285201491848116, 31.854293807860348, 61.855444215959125, 72.66310768742716, 69.71236351997622, 70.72096178608557, 69.97946123923026, 69.09984619386735, 67.03812291545253, 59.36310352817659, 59.40558279714277, 64.6799978902263, 68.34462519614928, 68.52543077161236, 68.28254192106186, 64.86005821535664, 68.55902194976807, 66.25629255848547, 63.3401240841035, 50.89360806249803, 49.65625324556905, 50.71223374335997, 60.84941117994247, 65.21564460569813, 68.50374006455945, 63.00402010640791, 62.91109523465557, 62.991668562735285, 66.90040065396217, 64.61576515628447, 66.41155565938642, 65.51447037727603, 65.32844804948377, 64.42766789467105, 63.80962787135955, 59.39653781152541, 63.60016153704736, 59.72742111452165, 66.46268767695274, 62.12629172109789, 72.90740074649935, 43.15823124301049, 39.17888079920123, 66.42293053288614, 60.03051442484702, 69.5210930608934, 64.99800012957665, 67.90942253605013, 66.37619156991282, 66.40938266631096, 60.407697385357274, 60.72108299501481, 54.88024234771729, 53.2895996493678, 49.59427979684646, 55.328863436175936, 59.378902835230676, 65.69029846499043, 65.53271332094747, 60.18738177514846, 66.12436756010979, 65.07807531664449, 50.348076974191976, 48.42797871558897, 51.6207488121525, 61.80872486483667, 69.22686038478729, 70.58903678770989, 64.63371392219298, 64.42225894620343, 68.60915768531062, 71.28812082352178, 70.85936653998591, 68.89483959444108, 61.433416797268784, 66.17964944531842, 72.58673914017217, 72.78821560644334, 75.51551803465813, 48.92466845050935, 7.386368243925034, 0.6750729403668835, 1.078060867805635, 3.14722819193717, 2.8761453445880645, 1.9381764627272084, 0.6688338590245093, 0.3716612132566591, 0.10901186780463304, 0.09577396040361735, 0.10414039130292593, 7.557187464929397, 47.76017165953114, 45.69047812492617, 33.065262840640166, 19.211618092752275, 30.61314213660456, 49.13600575539374, 57.08287677457256, 73.13949523433563, 69.93182797585764, 79.1255263359316, 21.690679596316432, 0.6637900587051146, 0.09938602666220359, 0.11587474390023178, 0.09600360291979967, 0.14486160339607349, 0.03233264508326689, 0.031318268062727105, 0.012013525570622616, 0.07806088910588334, 0.04449210753063521, 0.019682438202923345, 0.05580102852095039, 0.10260020217467701, 0.03204692301580743, 0.04393240752359552, 0.013846927191010647, 0.00039664603278769423, 0.07965832798471374, 0.009807405895703744, 0.05914900895027865, 0.09635229549941518, 0.07584424434049476, 0.03203632801981463, 0.02037024343266122, 0.022429545229721456, 0.13254917617286407, 0.051817225757986314, 0.1469941010638591, 0.09992447922066336, 0.14108583180894776, 0.15639115004770218, 0.13606709788643545, 0.10009977545949722, 0.07449448934846348, 0.20517765153800288, 0.2503328043366632, 0.1096907212969757, 0.15401451548020686, 0.1808937828266813, 0.13904253741906536, 0.22178413947263073, 0.12861920640833918, 0.18407274127727558, 0.19580948406890517, 0.17169846011505974, 0.18846000424556195, 0.1762489764200103, 0.1560300928089888, 0.20701566500769508, 0.13945110743084263, 9.9774153770939, 88.64384789620676, 86.31295588708694, 89.44193255516791, 73.6216486653974, 63.10745693022206, 26.0789430141449, 39.43486252138692, 67.75290427669403, 52.661585038708104, 56.78341557902675, 47.54425302628548, 4.484147227579548, 0.31720471117765675, 0.19381990776427332, 0.30609000113702595, 0.2287434813596549, 0.549246859886954, 2.956364433611593, 6.205399459408176, 7.5208962252063145, 8.858043493763093, 9.436094953167824, 12.734194417153637, 35.7768444092043, 62.89938303732104, 75.41327753374654, 74.35861495233353, 74.46112217441683, 72.57266567599389, 71.14383251436296, 68.88771657020816, 60.23230468073199, 62.63837675894461, 67.32363224029541, 69.4162324167067, 71.23309781474453, 69.49016124971452, 66.99594959135979, 71.29197259103098, 68.96309668017973, 65.41813696584394, 53.81524432090021, 51.80457069027809, 52.964446929193315, 64.30427405142015, 67.91947949317195, 70.76283701004522, 62.81623663440828, 62.70011486545686, 65.74953802170293, 70.41555035498835, 66.08316698381978, 68.68635777504214, 67.95773829183271, 67.53136096462127, 68.20123118738975, 66.64254403883412, 64.25717815276116, 67.79972168707079, 62.75490253202377, 69.27310512911889, 65.44036895998063, 71.63248139043009, 47.14808971651139, 42.86490071204401, 67.61493882825299, 63.25715811021867, 72.0529830071234, 67.50102535370858, 70.45378561942809, 69.46009235997354, 69.68291436472248, 62.867156843985285, 62.94818908937516, 57.53749908939485, 57.29893661314442, 51.41234151778683, 59.58145403092908, 62.52203141489337, 68.65651638277116, 66.69999107237786, 61.73165421332083, 69.77311318920505, 68.48035489359211, 55.23249080104213, 51.01680578724031, 54.47523409320463, 65.2840115178016, 70.5368378854567, 72.79853143999654, 64.00097285547565, 64.336798344889, 71.0301386925482, 73.68262583209624, 74.32573764554917, 71.85085542740362, 65.06232700040265, 69.54734156208654, 76.53034502460112, 76.52821125522738, 79.39009020405432, 53.15882782782278, 10.744066161494102, 6.560137637199895, 9.506175941036595, 10.40613926226093, 3.48313678656855, 3.718928843736649, 1.2024509930802931, 0.23319549407930146, 0.30495634422667567, 0.5746203660964966, 0.1626821108643086, 12.697652636035798, 64.77704517302975, 67.82633889106013, 45.40273697145524, 22.140965730913226, 30.53179414041581, 54.00886427971625, 68.3693753519366, 83.02405634234029, 77.92836404615834, 91.575819600013, 20.135434327587006, 1.0249072361376979, 0.3181908195537906, 0.19937133326405482, 0.25496438806576116, 0.14413069422927596, 0.15838772839596196, 0.20367190572282962, 0.06468015227226481, 0.26758047722039685, 0.13929605123496827, 0.1614801495546295, 0.11551380923558628, 0.28840100032187277, 0.15140155810982953, 0.0918806479462693, 0.13428326215474837, 0.15171812096190068, 0.11600459580339732, 0.1204114169963906, 0.17624891513297636, 0.17962023826135745, 0.1401772515307511, 0.10682460251114062, 0.06373433629050851, 0.113503395339414, 0.27088746428489685, 0.12633847072720528], [0.02125770266678545, 0.00763641661896761, 0.05940780877285908, 0.05063380377607481, 0.0151544391372872, 0.011167679274935397, 0.03594289188303294, 0.04073586735513903, 0.028976051910449902, 0.04859443941724397, 0.0036068939680849476, 0.016317287827992154, 0.05030144802144459, 0.023697924447215857, 0.03766922122468391, 0.033678929697001175, 0.06548506553254782, 0.02980742584763756, 0.055223038164718505, 0.05923789430169329, 0.0449649867932162, 0.052646515936019926, 0.18913076018854497, 28.052295292577437, 75.16868637454125, 75.4176627435992, 75.0301561047954, 60.315698192965606, 39.85315976604339, 32.90004476424187, 27.72370069257675, 32.04525439969955, 43.029950126524895, 40.536311134215325, 6.804035517477221, 0.08013688012837403, 0.09007641895403785, 0.028844602713962237, 0.0802032386643752, 0.13509258808147523, 0.9517524583685784, 1.891100788789411, 1.1739032475217697, 1.3845932387536573, 1.3750662919013732, 9.81198255092867, 34.59241413301037, 62.958595137442316, 69.693693037956, 65.92768423018917, 65.55982866594869, 62.52546741116432, 64.27119278138684, 61.42902374267579, 57.196719646453865, 50.399440411598455, 56.790220891275716, 61.63573265075684, 64.97682717538649, 65.67396179322274, 62.18664523093932, 63.26674438291981, 64.17504372135286, 58.02951728144, 55.93353994431035, 46.26397963493101, 48.96246833185996, 50.28453065503029, 58.94279802999189, 62.181004862631525, 65.44210656996697, 59.94579515149517, 64.43879173647973, 63.13734931330528, 63.94070171540784, 59.00505388936689, 59.73763496645036, 58.252645231062374, 59.89591437001383, 58.89409788193242, 56.891916182733354, 55.40293347450995, 55.91029205629903, 51.31740054776592, 61.79948768308086, 60.42714449667162, 69.32100511366322, 32.592528981547204, 35.54672287356469, 66.70648651738321, 55.30854948105351, 62.52218830970026, 54.85224054705713, 60.26429553185741, 59.599402796837595, 66.25193088285386, 62.69579633589714, 64.2906242032205, 58.16419186130647, 56.57590258506037, 52.55729706056657, 56.11823651098437, 60.792799611245435, 62.976692953417384, 60.143674804318344, 54.98682491240963, 60.27703539017708, 58.3888848366276, 46.492277268440496, 47.50043622909054, 55.00653874489569, 63.08886881797545, 65.15457722448534, 68.43083889253678, 59.78009462356568, 62.43117363222184, 68.49604437428137, 65.83981529358896, 64.54376612940143, 62.13237531723515, 60.010820204211825, 58.446206354325824, 63.36471342271375, 71.08211794207173, 71.44933023760396, 72.9039490607477, 52.98545122146607, 7.27585889639393, 0.4870162814134552, 2.3630265170528046, 2.9071980137978835, 0.4520298119994902, 1.0959982343258396, 0.16152265211266859, 0.0721102015626046, 0.0632326559524142, 0.020140510901147803, 0.2562311144485589, 16.79597935368938, 43.43611548023839, 44.479622840881355, 38.03960877080118, 21.231222960256762, 30.785296924652595, 53.72321767191733, 58.86492329259073, 60.29605888551282, 59.63883046180972, 59.106455003061605, 7.227100403078142, 0.4776455552106904, 0.07202373321859107, 0.048440053548303344, 0.16075395948944554, 0.03956053526170793, 0.0628712041784198, 0.028683795112996336, 0.021544073993760734, 0.067714381392204, 0.045952198335960995, 0.03795741584091898, 0.03493002788614362, 0.029458373206697648, 0.0762778501056375, 0.05157830974748058, 0.041926417785185965, 0.03359778949450101, 0.07820628493303254, 0.09042462889826106, 0.01818036769456681, 0.05887039043309708, 0.02217165705177092, 0.013852571343792783, 0.023424394669071324, 0.045478166111053965, 0.09996367993974879, 0.0726426096873418, 0.02406954795362488, 0.038024417890776555, 0.030478386719140316, 0.04477344565994797, 0.015292934427458434, 0.05145476274793187, 0.031197911819383025, 0.006392358299044352, 0.0577360823480112, 0.01622452607168065, 0.04061295620856747, 0.05761563034367658, 0.053601816086278814, 0.04414068384756965, 0.04633068024451214, 0.037198693852030465, 0.03372795932415513, 0.014912601458960244, 0.07912143058474026, 0.024094821194246895, 0.03276114104195468, 0.1185044096482377, 34.25375669233261, 86.60133638689595, 82.76036324039583, 84.67736674893288, 67.84832769824614, 52.016680702086425, 29.594645769365375, 28.96362662315369, 27.193251117583248, 34.329372144514515, 39.3860407798521, 6.017156089505842, 0.1047785655264893, 0.040714447536776145, 0.036442691475273147, 0.14081207795008538, 0.5306979100550375, 3.975311137976185, 4.351562290422378, 2.8588172937593157, 1.7705715015049905, 1.6644539828262024, 9.430133931098446, 37.01379522200554, 64.53677646575436, 74.05811432869204, 69.06558821278234, 68.00912134109005, 66.06308444853752, 67.90501379197644, 63.213306011692175, 60.7076527995448, 50.58739646788567, 58.556836805036, 63.93718727173344, 66.79776007129301, 68.01480093309956, 64.22307706648304, 63.45188809979347, 67.42944994280415, 60.847850076613895, 58.633487762943396, 49.05915083423738, 48.478298802529615, 52.46872209733533, 63.647406485772905, 65.43095527156707, 67.66199942558043, 59.536142810698486, 63.81881798467329, 64.79060872908562, 65.32713405547604, 62.887353128002545, 62.37059262491042, 60.90678368845294, 63.53427748526297, 62.288881809480735, 60.37855809734714, 56.77455494480749, 57.55927608859155, 53.93284874577677, 62.92781237632998, 62.84484248007498, 72.02529891844719, 37.321360034327355, 36.862834961183616, 67.68408236965057, 58.31301835275466, 62.74633999793761, 56.112039166112105, 61.585796956093084, 61.45218141617314, 67.75855248974216, 63.74244159267795, 67.33587787997338, 60.11140154254053, 59.33024975561327, 55.32473710275466, 59.834905824353626, 63.286348389041045, 64.82446662841305, 59.735093270578695, 57.54186468739664, 63.84938501542615, 61.279973676127774, 47.72807490441107, 50.01737410022367, 57.97693006453976, 65.73544886804396, 67.70873838855375, 69.6860993293024, 61.002497365397794, 62.619612140040246, 71.48417657421481, 68.05327153974964, 66.70681599647769, 65.81573978547128, 63.34732555573987, 60.762958218974454, 66.44291893128427, 74.31575129109045, 73.51508571255592, 75.68916136218657, 59.46509299739715, 9.850666926753137, 0.023269332727537523, 1.6669172312944167, 5.635829144908536, 2.6525300404717846, 2.7185842250624015, 1.2052509525129873, 0.8241496667746575, 0.08955182492612832, 0.10585042212398783, 0.19136401374013196, 18.44118614350596, 43.294204127404, 36.60100890744117, 27.668640421282863, 22.84654325054538, 45.2558873545739, 63.72193936378726, 67.56074736195227, 67.42144830765264, 63.93359045828543, 74.66870184867614, 16.40779120306815, 0.7971551185173373, 0.12902298070971044, 0.1061540074466217, 0.11500763196137645, 0.045969630666677995, 0.10353021759299502, 0.044587060298410156, 0.02881159198530499, 0.10307104747381904, 0.055061236564670844, 0.07830085848728496, 0.013301071350372607, 0.03884615444187676, 0.07829882835428562, 0.04163677143233438, 0.03795639694397969, 0.06410735216171992, 0.08921478454384113, 0.016528128631292813, 0.06938723396630057, 0.08660754985025815, 0.014356943523331035, 0.07172101357531163, 0.016085515587380337, 0.05837526397719499, 0.04122627087898793, 0.13965425862660333, 0.14022159269980847, 0.06627890116144573, 0.14960566415421425, 0.19729433100550406, 0.08146182919341712, 0.17624853208901423, 0.13528070863216154, 0.09642837569117547, 0.11768546931806112, 0.1746473317184756, 0.1592334741426091, 0.20597567000696737, 0.16520273931805166, 0.17457144304869637, 0.148453391307304, 0.1720568054025212, 0.18081159691416449, 0.13982799204607166, 0.19597238500512418, 0.12965363961073662, 0.14958926987263466, 0.27878245999736173, 44.09666615147745, 95.9517099011329, 94.02508874093333, 94.35655255471507, 78.70759779407133, 55.75425624847413, 44.95846186914752, 38.813327666251894, 43.82131576538087, 57.354124361468905, 56.61781703272174, 9.643357896035718, 0.16830499704566695, 0.3878767512017681, 0.2173826732342282, 0.36565296952762916, 0.26237392918236796, 3.894226430885254, 5.315076833771122, 5.90636384102606, 7.366482807743934, 5.954364826602321, 14.164044453251748, 40.615378272148874, 67.69888539468089, 75.86056109397643, 72.402630929024, 72.08788425691667, 67.89480778478807, 69.99894757424632, 66.22907915422994, 63.72083325539867, 53.67141100668139, 62.15840416569864, 64.92105891627651, 70.49140899412095, 68.40930508029076, 63.40324678728658, 67.34290676732218, 69.67783097297915, 63.501251128412065, 61.565918384059785, 50.993938369135705, 52.51498253114762, 56.06411172497658, 65.85762285417127, 68.02853707344302, 68.74252611590971, 60.5567317624246, 66.32780521146714, 67.58175557659519, 69.51094196688744, 64.30685104862337, 65.54268006355532, 64.69076871871948, 64.75981812323293, 64.16103301509735, 63.006146031041304, 60.328857744893725, 60.84718719605477, 56.39922334301857, 64.81997943693592, 65.0305401125262, 76.30204739109163, 43.909941719424346, 40.10040244748516, 69.07156590492495, 57.82123550291985, 63.084977826764515, 57.46459791737219, 63.11078310012818, 63.36588621139527, 68.62339588903612, 66.12957646769863, 70.01356232550837, 63.51220238593317, 62.25870701574511, 56.602951249768665, 61.91193811355099, 65.35622627504411, 68.47378884592365, 61.500536395657456, 59.56514481575259, 66.7487382888794, 63.61374078258392, 51.03462903730331, 52.468110207588445, 60.60587513831354, 67.63069891160535, 71.11982760890838, 71.76146461117652, 61.17912561662736, 62.62941414310087, 73.91822691886657, 71.52474957127725, 70.16428332174979, 68.4845204507151, 67.19948137960127, 64.22881157167497, 69.87736978838521, 78.5886715304467, 75.8037494844006, 77.97751134441745, 61.55066428645965, 9.102310076836618, 4.6894092713632896, 10.28033120016898, 9.383614620854779, 4.339936385231634, 2.917080180298898, 0.8987990514405313, 0.8384372678495223, 0.20443995483219626, 0.16651766795304515, 0.49364631274534815, 26.187225926306944, 59.65164876753285, 59.70682474874682, 50.798008134288175, 34.800923409000525, 45.40167008676837, 70.27112868524367, 74.05601978302002, 77.24305537439163, 70.82929765024494, 86.59378974668442, 15.137843451192303, 1.1622149521304717, 0.1620149402128112, 0.269142285349869, 0.2472181359846746, 0.1383972768822024, 0.1276032589075546, 0.09353293105959894, 0.12734058268007734, 0.1357106678187847, 0.10861428349368996, 0.16623937885367102, 0.10941070849977194, 0.18396119887550033, 0.27321100895923955, 0.1526103222802762, 0.18065408923693244, 0.10878572631026469, 0.1612612475911456, 0.2084311043783542, 0.09118179189822367, 0.15398865235188317, 0.0871664033301415, 0.12382086832076312, 0.09475331678385697, 0.14619442784497816, 0.22855130054296988], [0.06803850553208782, 0.07157170303886937, 0.04515970336093057, 0.025450517198130972, 0.016514656975144343, 0.06695878121160692, 0.01538572203923738, 0.020706554116200537, 0.03911975891359391, 0.06287330708977196, 0.046005713407911604, 0.04219329600492793, 0.05893907021550883, 0.04566584999162344, 0.02098581997767812, 0.035406488609770616, 0.08584681688056839, 0.0313296674510404, 0.08786158981702982, 0.036101889601277734, 0.02094304928886554, 0.0734787869958147, 1.652296228754905, 43.92357980051349, 64.34865174754974, 64.08320142376807, 60.59467677147158, 56.3714058937565, 28.985774286331672, 29.19880017157524, 43.19440334073959, 56.40960977923486, 84.04653979885964, 20.405342425069502, 0.33928122010923206, 0.03040150213505953, 0.07333270168953365, 0.04788805272490267, 0.07228758922147174, 0.6263772662608855, 2.4875171530631284, 3.8180429704727668, 4.458168389335755, 0.9405927023579999, 10.691859414500575, 37.60152316862537, 59.48206117076259, 71.30719138729957, 67.19165232873732, 64.82949902934413, 63.2824299412389, 61.45681373534664, 58.319553021461736, 55.61234097326956, 47.75200920720255, 54.51947842874835, 61.598630951296904, 62.94297233704598, 65.27823386653778, 64.45404975645005, 59.21966637334516, 62.58514235096594, 61.187248845254224, 57.772339236351755, 50.40274696965372, 44.97914060469597, 47.6026806523723, 53.442932944143976, 60.920676723603286, 62.647190324721805, 64.02193792404668, 60.121744832684925, 64.32943605607556, 61.43515048488494, 57.55563220670147, 55.916163844446984, 53.702652685103885, 54.35219718563942, 57.90816699304889, 55.5940862624876, 57.80352600159184, 51.81902854673324, 52.81143134640109, 52.01117761673466, 58.15042826437182, 59.522528263830374, 64.13239971283944, 28.949233485806374, 31.41476477346113, 64.69073341738793, 58.67807334469211, 60.858052161432084, 55.69142380068379, 62.41340137297108, 54.0334536183265, 60.031714670119754, 58.588811966680716, 62.225986603767645, 64.22805063186154, 60.82572398647186, 58.61491534017748, 61.348948555607954, 63.16096982648296, 62.22537079165059, 58.25010353519071, 61.89649574218258, 62.23839698299285, 54.09071630047214, 44.424160526644805, 49.467618619242025, 58.469681739807136, 66.24083842000654, 63.587111811484064, 63.17297227921025, 59.37272510220928, 66.03768317930161, 65.77067959693171, 63.392252383693574, 62.88898483399422, 59.72475390280447, 56.240665451172866, 58.625270397432395, 58.87323479498587, 62.4781479374055, 68.4439709878737, 70.11996053880262, 71.80156692381829, 62.36947082704114, 8.521675736673417, 0.8127249669163459, 3.438003053588252, 1.1820632483690017, 0.13082811368569253, 0.9528903747277876, 0.41068306613352995, 0.18165734266081165, 0.10752454640403872, 0.00677847714659067, 2.2112773695299706, 31.764867690301713, 50.46530485153199, 51.708351027581, 24.23788639806932, 15.984365459411377, 28.262740258247625, 48.312766936517534, 53.206445401714696, 64.40389440905663, 64.19969974025604, 57.482095610710886, 2.5273245524975563, 0.397578488674856, 0.07712350392173375, 0.04793578766346459, 0.05732628659555509, 0.06351780919958988, 0.03916028879522797, 0.07959606801910747, 0.03576197255883486, 0.03262103122148303, 0.01941461194937508, 0.032702228880577514, 0.01678721573684485, 0.05116896981733942, 0.040349494740967794, 0.011799325471773986, 0.05012360070982287, 0.019543460277359814, 0.002315971895211166, 0.02521012072271157, 0.04820388013256654, 0.04902485825662171, 0.040214728383767995, 0.013085106376468415, 0.047887570089510376, 0.06127388404321767, 0.08467755220349758, 0.03375853006277354, 0.0255588190479865, 0.026443930222622813, 0.046488218565261176, 0.04379458064513822, 0.029043557663117687, 0.023818596701828704, 0.008683578851031921, 0.032746401510291526, 0.0293096563883967, 0.041301018077759974, 0.010582780720846308, 0.020082066053404443, 0.08455811143522302, 0.009421503467996035, 0.04782894904154444, 0.06404975767157252, 0.02866687223074898, 0.07101729286894684, 0.045625343092627106, 0.07641756156038854, 2.4513604996665834, 57.15791956070931, 75.71867327536307, 72.57733329649895, 69.34175445187476, 68.37205040839412, 39.04002497273107, 31.3797870374495, 39.91135204991987, 61.48368589339718, 68.29151630401611, 21.059780082395, 0.4939450257487836, 0.09160663361751264, 0.03388432553038001, 0.05424351048385424, 0.36171999669844107, 2.2510796208535475, 5.054833946689483, 3.4332937579001155, 3.006204030206127, 0.20777611452485287, 11.601186413918773, 42.02299141114758, 64.62533966187509, 74.50881035097184, 71.32562652710946, 67.75541459360431, 64.8600072245444, 61.84008029199416, 60.870258577408336, 58.98729731959682, 52.09153129208473, 56.62008808505151, 64.47442254712506, 66.35355164927822, 66.63995527452039, 65.99842025387672, 59.53986513999201, 63.824721151782626, 65.3100678228563, 61.1512924778846, 52.622667281858384, 46.71408730168497, 50.14288602336761, 55.138322537945164, 62.74344921112061, 65.03928307564028, 64.42919761903825, 59.615676710682536, 66.18184597261491, 62.51668522434851, 60.46084550119216, 56.74599224521268, 55.735079780701675, 56.963044443438136, 61.41574259727233, 58.031474544155984, 60.59491603605209, 54.425620032895, 55.9388312216728, 54.300876894304835, 59.857286868556855, 62.17027325784007, 67.508956386197, 35.038858306023386, 33.19383421251851, 64.83668088912964, 57.05527505566997, 62.02344325280959, 58.224639508032034, 63.78443841011294, 54.98941367672336, 59.450105620968735, 58.61455055975146, 65.60224909936228, 65.41195531045237, 64.75051818355438, 61.19821186988585, 63.57541138126005, 64.88443182360741, 64.21539706568565, 58.89544717727169, 64.7992261763542, 65.14146474099928, 56.500851954183275, 46.31415459417528, 51.09569249614593, 60.68163179582166, 69.10295271104383, 65.30072473710584, 62.34820373596684, 60.52993020703716, 66.81693261669528, 66.52413552807224, 66.98204086672875, 64.3331152392972, 61.81888380358296, 57.42213041551652, 61.260291222603094, 60.804229397927564, 66.31846212571668, 70.25772986873504, 71.81529521942139, 74.78671812242078, 68.71068431485084, 11.944154539415914, 0.7083186435122645, 0.8249337117998832, 1.8236824773973035, 3.0667193378171618, 3.185296020200176, 1.419984539670329, 0.42839851230382925, 0.07996120084557803, 0.010115711277561083, 1.6650717561283421, 37.1833828187758, 47.02218555635022, 42.0707501903657, 26.25947206251083, 23.573560445539414, 44.17103036757439, 56.96994781494141, 61.647068300554835, 74.47705484205677, 68.76060824240409, 73.41766972695628, 6.329604742988464, 0.5920598367529532, 0.015414863066267104, 0.08702318319269726, 0.02564042847934029, 0.045551718212664134, 0.07432212722637961, 0.04736064715431102, 0.03028498782265571, 0.02296616492282239, 0.05618661589499924, 0.021263530680669412, 0.028783641267387618, 0.04502722760662437, 0.02712186057901671, 0.029574153989913966, 0.022357904517482367, 0.013756817056527062, 0.07525116971303379, 0.041037085466086864, 0.04917278983480027, 0.01866939609059163, 0.04704279727452705, 0.022647591089949976, 0.02898222274867998, 0.01888015453944043, 0.22996490130261069, 0.12398055934857939, 0.09133592112770966, 0.06941242293725092, 0.14439690978296343, 0.18186817005757364, 0.16194999127859072, 0.24093433042928097, 0.13328668901756888, 0.26008427623779545, 0.17128514035815195, 0.11340905161153887, 0.0803607156980903, 0.16734665169590907, 0.23597060161973202, 0.10510992919725758, 0.23956811986863616, 0.14379694036418392, 0.18245108635915866, 0.19320947358444815, 0.1445228086724397, 0.1633303897875932, 3.6028033975631963, 69.37757353628837, 84.77981905783378, 86.02273971803727, 78.00713308395879, 73.73211829893052, 40.61585287893973, 42.504838897335915, 56.507021842464326, 67.0716356462048, 103.18492135693951, 29.551705621903945, 0.7943566299734578, 0.2146992510965755, 0.22200141732971515, 0.14517075051703762, 0.45559662544438917, 1.7577889874096841, 9.217135502446084, 12.091520928567457, 10.758460279433958, 4.989311733553487, 13.967441531919665, 43.81174125979024, 64.19994292720672, 75.3912651923395, 73.97827840620472, 68.28813522092759, 68.95543236886301, 65.02952421865156, 62.85887279818135, 63.48647163760278, 53.50416898727418, 59.243443781329745, 66.12133949033677, 69.3400364537393, 67.63146769615912, 66.43788260798301, 61.1660994252851, 65.21785682247531, 67.50801501735565, 63.96627164656117, 54.643499851226814, 49.72675392704625, 52.16021199380198, 58.28722876887168, 65.22388550543016, 68.02265351818454, 68.21851315036898, 60.48810205151958, 69.99636665467294, 67.07705636178294, 62.45686907922069, 59.60771037686256, 59.68988403197258, 59.56944765583162, 64.96268703091529, 61.310740747759425, 64.69591879075574, 57.52326873040969, 60.04935356878466, 57.74647120506533, 63.788427460578184, 64.7811048261581, 71.34122971565493, 38.130262590223744, 37.46020801605717, 66.65815507211994, 59.061112403869636, 62.552453317949855, 59.16784009625835, 65.23356591501545, 57.5724591747407, 60.10128574986612, 60.00195564762239, 66.52688903193321, 67.86435450277021, 66.57114905695762, 64.16947787807834, 67.18347026455787, 68.0741620832874, 66.39964734354328, 59.62619258511452, 68.40606520252844, 68.72875075186454, 59.412384187021566, 48.36514626779864, 53.170536102787146, 63.738774176566835, 72.28370466539937, 67.34722921925207, 62.92038732959379, 60.50721968373945, 68.90583792040425, 71.55117850149833, 69.24864522872433, 69.04902796591483, 66.38836660692769, 61.17517971223401, 64.79242478647541, 63.44963273694439, 70.65810972644438, 73.45538723853328, 75.7048979113179, 78.26332661413377, 73.5426050616849, 10.067033690790977, 6.3934069968039, 11.374732294390279, 7.191361236956812, 4.485667636317592, 3.40743970005743, 1.2406600266695023, 0.5214759887706849, 0.5374674306761834, 0.07704697173809813, 3.451211880291662, 48.64631352886077, 68.74415782190138, 71.62976711027085, 36.96453809738159, 26.202885989219915, 43.55898372588619, 64.18243738912767, 68.68924463948896, 83.64350841891381, 77.1260275379304, 87.45745643492668, 7.4330066961626855, 0.7417536623054936, 0.1332092681719411, 0.1795971943365951, 0.23178601487269326, 0.1878115721046925, 0.23303905892516338, 0.22467319493091878, 0.06917138869363455, 0.10846972270237823, 0.16674341874257212, 0.1522161853649924, 0.13971974382237082, 0.1466434626209159, 0.17269607513181626, 0.1604710278972503, 0.17591650958263105, 0.14242282377616053, 0.1713949667229768, 0.22848071320162666, 0.15478362179090902, 0.10586942110450999, 0.18933742006699886, 0.10796022826745626, 0.08987089288571189, 0.21615615114569667], [0.03357165440496418, 0.10143587876471782, 0.03177986668062306, 0.021758218551234856, 0.020492949650713035, 0.05840827853629186, 0.06087870907879645, 0.07574945628162354, 0.016261367239959298, 0.062004758736058596, 0.05679017443570399, 0.03169055806563026, 0.03381061255030575, 0.016678630434457335, 0.04219113563698146, 0.04257416427736321, 0.03403312278791301, 0.09365244843666592, 0.051438016065907095, 0.07224537011596464, 0.04202714685590998, 0.038473870184633045, 13.515781587170018, 70.96626681666221, 69.23958455362629, 66.47945188706922, 47.160437337813846, 29.242838582684918, 19.356920334600634, 33.22143985379127, 40.468952271246145, 32.63742050816936, 33.587636255448864, 1.5851188979802595, 0.03486825821680888, 0.13373721000407973, 0.11354900821442566, 0.08413770536501562, 0.16420710080813977, 2.457123196894123, 5.455966899471899, 4.105852275125442, 1.3089853861639578, 10.269419166349596, 41.2917164833315, 57.84962954059724, 68.71620701205346, 68.90321777712914, 67.69244486285795, 61.23216782846759, 58.85079883760022, 53.97209598172096, 53.41524885546777, 48.923593721082135, 55.24661133366247, 60.852058779808786, 64.20613242733863, 62.69321933869393, 68.38204460759317, 59.80389556577129, 66.57480470595821, 63.81231861729776, 61.338197338965635, 57.84775857002505, 50.303754191244806, 42.12031325986309, 48.51338832609115, 53.44112473149454, 61.921202751898, 61.509863791927216, 60.444595121568256, 59.654861188703975, 62.47000901929794, 58.94482981774115, 56.330523029450454, 48.45220719614337, 51.810999454990515, 50.92890547167871, 55.080024350074034, 54.019211492230816, 58.36850027884207, 50.09736299514771, 50.27076705809563, 46.16981137183405, 57.4700225553205, 58.167035579681404, 73.67836613808909, 41.17383357017271, 32.847345759791715, 62.17894169592089, 52.59113142567297, 62.054386831098995, 54.88943246103103, 58.0073441228559, 54.94531446887601, 54.8054035248295, 57.03119562518213, 57.03873834302349, 57.16150460704681, 61.4530090362795, 60.04926727664087, 63.595952833852465, 59.74524436458465, 57.12357920985068, 60.099516760918405, 64.39206454061693, 56.64342618757679, 48.79874467849732, 44.56407147069132, 52.66382863444667, 63.42354113055814, 63.712670803070075, 63.64040113264515, 58.33314795647898, 60.963163837309814, 65.83407294365668, 64.79930462375765, 60.18071374585552, 59.13328009267008, 56.53914997654577, 57.798650495467655, 60.24313042240759, 59.2314923194147, 61.03649254768126, 61.25612174310992, 65.45953366064256, 68.57715114470452, 72.83795910496866, 65.17054911582701, 14.975309256584415, 3.706272335783128, 1.151717708956811, 3.276800503653865, 2.0444411928615263, 1.0995341284621147, 0.3830179764378456, 0.10526967385122854, 0.1831609587515554, 0.012995404183804508, 8.352084217532989, 39.95023842780821, 38.13750720793201, 27.697726757295673, 29.837156111194243, 22.89848327636719, 43.11202572238061, 51.36622228930074, 52.48109717522898, 55.75514662650324, 63.88490207733647, 44.37731958204701, 0.9441579529835332, 0.003909136721631512, 0.031524564049416975, 0.022436018672681624, 0.03224230033435649, 0.03148108281405463, 0.0320678582835582, 0.007399442641349931, 0.0812556519503555, 0.04877978289920477, 0.04553261197983258, 0.02476360063038526, 0.060915534925316615, 0.02779872798841567, 0.051557315107915676, 0.051517271692113537, 0.032491252096670295, 0.0488309575725467, 0.026231850272104628, 0.046807949190899256, 0.03335043119506971, 0.0377591714383133, 0.08046455125534728, 0.04430166956397795, 0.03977384478334458, 0.03292438671773961, 0.028866909279097474, 0.02626758444333269, 0.06625279288498626, 0.017335313342271313, 0.01702631943889203, 0.051034632469377214, 0.03876146725228718, 0.05879925533888802, 0.05339029154950573, 0.042160358054623495, 0.046681119504595, 0.058619933308012066, 0.07936565175412164, 0.03513961805090789, 0.04386733218486752, 0.07079456812672077, 0.1247741268467038, 0.04289920006187693, 0.024557055665120005, 0.04735710399766122, 0.018465394537234982, 19.70966692893736, 86.69220985904818, 76.66791823602493, 76.1287727663594, 56.39796033982308, 42.98274440150107, 28.630754678480088, 38.13984101818454, 42.84488485705468, 39.22689453248055, 39.63154192893736, 2.4131916703716403, 0.0397187247571926, 0.03381969069220847, 0.2112175500200641, 0.3846397232865134, 2.0266810684434833, 4.538686313936788, 2.711826716699908, 2.9334712749527347, 0.8519185154188065, 13.46432303228686, 45.19179582595826, 62.43329563448506, 70.04834590419647, 69.16791500583773, 70.62083936506703, 64.75522110539099, 63.31279693111297, 55.788369101862756, 56.97824362785586, 50.96859593545237, 56.53120325457666, 64.24916082812895, 66.19111845570227, 65.80205855831024, 68.23879180415985, 61.32594385454732, 69.3460298353626, 64.45665421024447, 64.76623119846468, 62.59521107519827, 52.25878507860246, 46.05690594642393, 50.40649283316828, 57.339948915666156, 64.41930147909349, 63.56837857154108, 60.93100040189682, 61.69770609947943, 65.10185664699924, 61.36441053882722, 57.913446503300825, 48.55652263087612, 52.77271363043016, 53.671458075123454, 56.925856451834406, 58.12076337875859, 61.771529028492594, 54.4339942932129, 54.654145163874475, 49.02723058577507, 59.93960957373343, 61.22125579464821, 74.39140596697408, 44.72240186506703, 36.472064910396455, 63.94563997945478, 54.6580518445661, 63.18103274991436, 54.28242214264409, 60.47929240811256, 55.8740258216858, 56.027782732440585, 55.95587392007151, 56.053650763727006, 58.29592858591388, 63.78958063740885, 62.39233432277557, 66.70867519993936, 61.78111137882356, 56.93515246914279, 61.198388376543605, 65.55614163798671, 59.46022533601331, 50.39059154448971, 46.73949249329106, 54.875708087798095, 67.08900390132781, 66.7002970172513, 64.42732664846605, 56.81387278341479, 60.4086858226407, 68.92516736061343, 66.94004797166394, 62.68014215653943, 61.81022321024249, 58.7293504899548, 60.168864265564956, 63.76798406724007, 62.67985974588702, 62.54335341915008, 64.84116808060678, 67.57420893638366, 70.78201740018784, 74.77586884652415, 69.68153369042182, 20.170172799018122, 0.4139291032427742, 0.22112856739230696, 3.0939717206262776, 3.118960895845967, 3.947320123833995, 1.3163397076629824, 0.3300135174105245, 0.12530758451189727, 0.04843462964579944, 9.429718159860181, 44.507510892806515, 36.65295285563315, 24.35657928066869, 22.37983807440727, 31.00585964418227, 52.77131726664882, 61.54615748313166, 58.70058774948121, 62.48042291210544, 69.57441376101586, 61.00734933730095, 2.0249666249559772, 0.0976653318972357, 0.05611279183217595, 0.05362465699774124, 0.030639856986160723, 0.005775448761039204, 0.02649445755166873, 0.008617403218522668, 0.027284736617378173, 0.06002732492502659, 0.05947602124163701, 0.04839042254212884, 0.08917782846237383, 0.018482043543049408, 0.029790550845885472, 0.06623057633518212, 0.03767214001967542, 0.030988285265442346, 0.005451807256547674, 0.01386628527524731, 0.02293172544018636, 0.07892725793945213, 0.019650787280331698, 0.05298952031279764, 0.01592699092842879, 0.16291118647542693, 0.19809679278442938, 0.08488804252157289, 0.090046196785425, 0.093246444819435, 0.1316802486056282, 0.10843012361757218, 0.14146668475962457, 0.17487617750321666, 0.22535210204941614, 0.15892400526471678, 0.16027785116626372, 0.10032643023277484, 0.146868018313281, 0.15477675764310747, 0.22307170344696892, 0.14109906980827933, 0.25109875436511736, 0.1896531708658703, 0.18709852810828917, 0.1816980832166249, 0.16652491514480885, 26.225698494142105, 100.45249631327968, 85.23488460048553, 88.44637224751135, 63.98150220994027, 45.200648615437174, 29.748145764873875, 44.85240097968809, 51.17347701903313, 47.64714464064568, 47.017227680452415, 3.3685550382060394, 0.08765033341103023, 0.3479326203946145, 0.2547091735346664, 0.5782829405319306, 1.46567034625238, 6.763089895248414, 14.403467889755005, 12.647433550127092, 7.195072779732366, 14.48279586530501, 48.012321226058475, 64.61689087652391, 70.39953923994496, 72.68934834387996, 74.98453893969136, 66.79240995837797, 64.9948347768476, 59.25358310822518, 58.554832473877944, 53.311345269603116, 61.35887999688426, 68.20180385343491, 67.57528366581087, 68.71735234414378, 69.64980171572778, 63.44178015185941, 68.31157530507734, 65.38019587916713, 68.5073172661566, 65.38889177383916, 54.49664238960513, 47.08543377537882, 54.124311400998025, 59.748998072839555, 66.03241935853036, 64.97698014782321, 60.32047171746532, 62.273478661814046, 68.7388704669091, 66.13417348554059, 61.16338906749603, 52.49721811663721, 56.116675407655784, 55.93961177333709, 61.70370340347291, 60.628315018069365, 64.65558898064398, 57.19294632634809, 56.275433340380275, 53.16905344686201, 62.315016561938876, 66.1164757513231, 76.69074643042781, 48.122127979032456, 39.44482926399478, 64.65355719289472, 54.447871638882546, 64.35160136991932, 58.03502821153211, 61.65326956779727, 58.586333028731815, 58.39848287643925, 57.16850996017457, 56.88021967487951, 58.01527515534432, 65.65791145447763, 64.61446292938726, 67.60259120695054, 63.15398408520607, 56.09492586505029, 62.86800407594251, 69.53376231654998, 61.418978552664484, 53.18677471530054, 49.542100506444136, 57.23585705603323, 69.68577769494826, 69.0925427406065, 64.87940726741668, 58.55808411875079, 62.21167387500886, 71.38923952656408, 70.06898541604319, 66.23960679577243, 65.66119055594167, 63.127088392934496, 62.57699166574786, 66.05047010606336, 65.28814961833339, 66.97996985527777, 68.38021678309288, 71.29437308157645, 75.36227103202575, 78.52123029770391, 72.65357632790843, 19.352203684468424, 10.354952331512205, 9.240588334298904, 10.322798702024645, 6.923973262310029, 3.804688280628574, 1.6200533653459244, 0.38673181747717245, 0.29112128661044184, 0.18295598426653495, 13.83090872918406, 58.3447071813768, 51.236097658834154, 38.24879269446097, 45.91210380677254, 35.04261593664847, 58.01913476759388, 67.5370248671501, 68.54090844431232, 73.27830006999355, 79.24430354948967, 68.25267699456984, 1.7995580622265417, 0.18223014660179618, 0.16943250993086448, 0.12845190812743482, 0.17617224505351436, 0.15190408114464055, 0.1477424770353302, 0.10064859318757251, 0.22971316481069212, 0.14668388141980096, 0.13926196032233779, 0.3139742103315169, 0.17543710708137483, 0.09834213993482052, 0.26852785219107905, 0.07753258721242029, 0.08674968980372914, 0.1279411036821623, 0.17906817998136246, 0.07103896549632473, 0.07182249724264107, 0.19800801851576377, 0.15201471956266513, 0.2077691584465004, 0.16712581919085595], [0.03872572542017987, 0.07020416714611553, 0.02724509348251647, 0.0354774130298005, 0.02142633394067807, 0.06243598579819645, 0.04216845943442276, 0.03935094509694365, 0.07024086275768858, 0.017653201526451497, 0.00891170451312416, 0.0485581306800727, 0.04437743182924967, 0.047035396865178505, 0.02124510626609047, 0.020061109718235753, 0.015909084580808638, 0.046270802812350374, 0.010117428272121377, 0.02305373643344689, 0.049047369750276695, 0.4858365979406142, 37.849891570306596, 76.86468001334899, 65.07884017882809, 61.959438016337735, 39.341804289048724, 22.702223562425186, 22.002394276280558, 36.68200977386967, 40.11449160114412, 58.67369990194998, 14.47671030798266, 0.06993329377784845, 0.10395350415379771, 0.03821492863578662, 0.10001139189567297, 0.22737045261648395, 0.5328109644113049, 3.520568700567369, 2.414458105641027, 2.1152425485272563, 9.690882313636042, 42.59277843659924, 62.580835588516734, 71.40496038621473, 67.13451908480737, 68.78870810231855, 68.298137264867, 65.2294905724064, 59.041092626510135, 53.419190837490945, 49.74893100800053, 47.75921067883892, 56.08245272790232, 64.45356338254868, 64.59101500049715, 65.60740309376871, 57.07594594647808, 58.9462967841856, 66.52139771369197, 57.46940674320344, 63.86119134964482, 56.246376422143754, 55.536121476081114, 43.82270036205169, 47.78483160080449, 53.92989912340718, 63.99794870807279, 59.94838783817907, 58.08913730805921, 61.24280921874508, 64.82254466702862, 57.75728125726023, 50.68936632525537, 45.72837998790126, 47.10976815992787, 52.41615449228595, 55.77206773142661, 53.22613569997972, 54.55789019984584, 50.00110018637873, 50.45747580066804, 47.23344441383116, 55.828820505449855, 57.06444163476267, 66.09588330791843, 41.66324730842344, 30.138058777778383, 62.01752831858974, 55.30651769330425, 56.61844461194931, 54.26765049657514, 56.801242751459924, 54.38560401239703, 54.88882057128414, 54.50775054193313, 59.43318059367519, 55.68446943836828, 58.349559153279955, 57.90670394897462, 59.07758243622319, 55.73922180360364, 60.784280223231164, 62.042478515255844, 60.44406560159499, 52.62071394151258, 47.367891496227635, 43.93938302993775, 51.012546093233176, 59.46048029007451, 65.08290375432661, 63.03353201958441, 58.18278781829342, 61.93022420329433, 65.14096659998741, 61.427482251198064, 58.56090822527486, 56.262650335988695, 57.45594909114223, 59.214351561761674, 60.31727890814505, 62.36860398323306, 59.97000794256888, 61.57727756807881, 59.795313419834265, 63.71767182503978, 67.35293234548261, 68.44928187708702, 66.84736236449211, 19.24610749367745, 0.380917914932774, 2.374184434452365, 2.461956782687095, 2.422758086073783, 0.47571060097505974, 0.1633027033700097, 0.07787579460249794, 0.02563668805504999, 0.796393136824331, 20.714542865753174, 37.76337585141582, 47.59164702507758, 30.656362733533307, 21.981450780745476, 24.719316151834306, 39.6418930638221, 44.09180241246378, 57.91108915882727, 54.587837496111476, 67.04194330400037, 23.224838202999486, 0.4893670681743853, 0.07194958356839996, 0.058032566035586985, 0.08411532027586814, 0.036279599017073075, 0.06260055680609038, 0.06844630945594081, 0.0290578241354876, 0.054398091705215555, 0.022509856142043587, 0.012937871938300951, 0.01986203985589166, 0.031352144470738794, 0.08125087922258724, 0.06307822794863774, 0.01883691845221385, 0.016555251974251964, 0.014045113179412101, 0.01699988557506473, 0.08185569797792742, 0.06377837485483577, 0.013572841999121012, 0.03537094596052363, 0.028379462854636293, 0.03853103183510323, 0.03229972628516055, 0.019653727142741124, 0.029709816669985175, 0.0296001473531848, 0.08019750832670158, 0.009543362201281614, 0.02052432478165194, 0.06659075257278259, 0.0462059649608789, 0.040604801202613505, 0.009946582046517683, 0.033501109198456815, 0.07234386604038939, 0.08027280710877911, 0.0029287854962486534, 0.03239470203557322, 0.01708885328093123, 0.042079374900147806, 0.07281411379095047, 0.05532963546894251, 0.37777269499436505, 50.57446833579771, 88.48723549996653, 71.84077493606075, 68.29040235088718, 47.51168166437457, 31.788623525250344, 28.209370528498006, 33.66830764278289, 41.612076067155414, 53.20693569798624, 14.982894139905131, 0.027405150317316575, 0.08967803025077428, 0.15469942872803058, 0.28390519801647435, 1.5699900710775008, 3.582313671227425, 5.434888082165872, 2.86202579256027, 0.7290622820296596, 13.505916826186644, 47.79304896631549, 66.08478300033077, 72.24212754157283, 68.90428466181602, 70.3038412524808, 69.93615827252789, 67.91370576427829, 61.41069842923073, 55.74781571665118, 52.65779602912165, 49.44686143629013, 59.46118239433535, 66.7613761655746, 66.65792757464995, 67.37783939607682, 60.20863317674207, 61.66149085567844, 65.06078158655475, 61.18300091835761, 66.01392146079772, 61.366630600344756, 58.93987194184334, 47.20038667801888, 50.82249549127395, 56.97512926593904, 65.11931511663622, 60.882366934130275, 57.69418993303853, 61.11786603927613, 66.7716763096471, 58.39064990320514, 52.81525173494893, 47.814751440478915, 49.74413394927979, 54.75438525599819, 57.91840045682846, 56.31061700082595, 58.155213555982044, 53.16065172995291, 52.172700820430634, 48.422463863126694, 57.8990827837298, 59.544830860630164, 68.79648224000009, 45.301288789318455, 33.20110628681798, 64.73114951964348, 53.91749658892232, 58.002037156012754, 56.12049579620362, 58.41428610586352, 55.97692920315651, 55.64266873944191, 54.52810372075727, 59.86777528639763, 56.80707923827633, 58.69860695254419, 59.61874008178712, 58.86799843080583, 53.61255584224578, 59.47427918834072, 64.58342913658389, 63.24237469703921, 55.170125115302305, 49.13422892170568, 46.65400051301526, 53.07827018922376, 62.83118478713497, 64.73851180845692, 63.591865724132916, 56.75328785373319, 63.983769339899865, 67.57915112280077, 63.855135210098766, 61.9572336443009, 59.13858705951322, 58.89482744278447, 60.75168140472905, 61.914083650035245, 64.48425985151722, 64.07834552949475, 64.42470258282077, 61.419417858123786, 67.00224107311618, 69.07246020532423, 70.95304058444115, 70.14083539285969, 23.493724523052094, 0.6205883381828186, 1.2049625357312541, 2.675798030630235, 5.077719996052404, 2.1153452655961438, 0.6648546144846947, 0.2674673719992561, 0.04127502088404952, 0.6275742633208152, 25.64354423553713, 38.75296238929995, 49.93346283512731, 33.60300802415417, 23.114478395831203, 40.49214916844522, 54.17859308181271, 50.50570918667702, 65.17654641982048, 61.04757324341805, 76.50866216228854, 34.53153110319568, 0.3719678016439561, 0.06581363298239247, 0.09093760903323851, 0.08833098720999495, 0.027650564668640017, 0.024013202186794053, 0.022786266410783417, 0.012945719551475299, 0.045862370696399486, 0.05268603841203356, 0.01688513901054619, 0.07901852199387166, 0.026313515244832924, 0.022290234055910862, 0.04655985927750026, 0.04095956502902893, 0.03398715751245618, 0.030735568180980704, 0.02189677129800041, 0.05214493901979539, 0.026072548033909935, 0.02194454454095854, 0.09503342151161163, 0.03946807227968689, 0.09868242086902743, 0.19771502052824344, 0.07431577635748733, 0.1314481239645712, 0.13253193919456777, 0.1274663589954857, 0.17754717369473752, 0.125606810794242, 0.17331420083440122, 0.1268903681287362, 0.1293887417282789, 0.07725450495678572, 0.14323965736454533, 0.12780234983731664, 0.3133575401959881, 0.0956398107471966, 0.08852830081577263, 0.09480471362269695, 0.12059573775097249, 0.2132303694323186, 0.08751832113991823, 0.9546588120921966, 61.136795397727724, 99.95018974427255, 81.13832981355729, 80.4557824903919, 55.45273188621768, 36.43662629588958, 30.2497031611781, 49.89409792807795, 53.5174972011197, 73.79377011329898, 21.541047057797833, 0.203223253990854, 0.3113143837019321, 0.3752528173067878, 0.40501953132690927, 1.3375927027194732, 3.417268914561118, 12.213366416192825, 9.405070966289891, 8.438860774040222, 15.496698156479868, 49.55308706529679, 67.20978152367377, 74.02381712390532, 69.68347134128695, 73.60644555860951, 72.83174607061571, 69.05191483036165, 64.47600718467467, 57.45342308475126, 56.71742170087753, 51.67323012505808, 62.23207019990491, 70.10803653347877, 70.08776572442824, 69.42611678954094, 64.10823399020781, 62.72076614441411, 64.66657161712646, 62.26255878325432, 68.25522653518185, 63.489342812568914, 60.56687501169021, 49.69783429176577, 51.58403542733962, 58.917082971142186, 70.63208872272124, 61.69883574208906, 58.7469187859566, 62.94583566727177, 69.99588812551191, 62.95224482013334, 54.7088465382976, 50.05894337930987, 53.045957703744214, 57.950599193573005, 60.640776388106815, 58.446308335950306, 60.42827413928125, 56.735664644548976, 55.13126619400517, 49.77168859974031, 62.06907218502414, 62.238855900303015, 70.37997445752545, 49.26131763765889, 38.03336043511668, 67.7936969264861, 56.573823728869044, 57.25001288998512, 57.22981660596786, 59.39522381751769, 57.07453781558622, 58.10712529766945, 59.88339416442379, 62.38387377031388, 58.902727096311516, 60.390042797211684, 61.85231416456161, 59.86628086336198, 55.78103426964053, 62.17650198167371, 67.16266601316391, 66.60947845828149, 58.46525730625276, 50.933373051304976, 48.201799161972545, 54.64140922792497, 65.12674408574259, 68.91220000482375, 63.0990199119814, 56.918137227335286, 64.59386264124225, 70.57464168917748, 66.45190115897887, 65.13954670198503, 63.95477125721594, 62.683205527644006, 64.32529403317359, 64.66242174948415, 69.93185151007869, 66.08786598328622, 67.12841587681925, 64.55014782567179, 69.7339444006643, 73.06392685059579, 74.1993510338568, 73.23672294616699, 25.179139529505086, 2.1600271905622175, 9.131995554893248, 10.750117398077442, 6.064644715478344, 1.7763839638040912, 1.157483960832319, 0.4051809000872797, 0.09512443275701615, 1.2616933689963434, 33.02246978206019, 54.082036095280806, 65.62035083770752, 48.89562329938335, 35.39981834350094, 36.29251057101835, 54.50894294246551, 59.30014556454074, 73.76972598414268, 69.34437459514987, 87.74471513686642, 41.84872050439158, 0.6190744871574064, 0.2653358089587381, 0.3541711501536831, 0.21838254054948208, 0.1448598567156061, 0.09307883244248168, 0.15710096115306502, 0.12261352907385557, 0.13673926343119916, 0.1258527939658492, 0.08441790968420045, 0.12808779419790353, 0.14128302284065755, 0.17120548253578527, 0.11311275178506491, 0.13848537699349467, 0.08759358927847878, 0.0950811104848981, 0.1503876560638028, 0.11729669501824726, 0.1539762723710268, 0.12282443307940999, 0.18662732274782273, 0.19453695073964136], [0.03164639692723511, 0.047290802918254375, 0.08023349147650503, 0.05135070502517685, 0.04473257869962723, 0.044292840400650624, 0.017904930357490818, 0.05437380288757625, 0.04009854348917161, 0.08747659233068267, 0.0433626449516704, 0.021791819167593797, 0.015066725900396706, 0.017122164699098757, 0.023918291553854946, 0.061507786008258986, 0.009889879091192159, 0.04575088958165819, 0.10105782969584388, 0.04504389001897747, 0.11961961150049202, 3.192018472379254, 63.04011375673356, 71.23552183951102, 68.67833260566958, 55.35960697358655, 46.18915650152391, 27.337510008965772, 32.65014663819344, 35.59892569818805, 43.167135023301654, 36.58120486044115, 0.6819348205481807, 0.05416106410144318, 0.15159841206285263, 0.09675439206823226, 0.7049036686939578, 0.5176999720354234, 4.794867096408721, 5.03574965461608, 0.5579140109400595, 6.867864737587591, 44.29037632480745, 67.26263153937556, 72.89968152200022, 66.29350016194006, 69.43098052855461, 64.60614750462194, 66.97890297059091, 60.350893620521795, 56.11568697037236, 49.29565406614735, 49.88350360624252, 47.50558237875662, 57.326259843764774, 63.94968394310244, 60.924065651432166, 61.46415641230922, 61.68180088843069, 62.072806281428186, 59.00718373637046, 59.2842834995639, 61.02794570307578, 61.00285430108348, 56.27349568951515, 48.82288294453775, 43.76340981452696, 52.92582335010652, 60.81208198301254, 60.934499156090524, 59.43421609940068, 57.55680499538299, 61.3138472649359, 53.274118054297666, 45.761806426509736, 44.86254030658353, 46.751161544553696, 51.34646138837261, 55.88652249305479, 54.60161678252682, 54.03765447678105, 48.51524752955283, 46.22523838473905, 44.8732562218943, 56.081374076104936, 57.601488636386016, 66.71247989900651, 44.9630981106912, 33.94446603713497, 53.52972715131698, 50.51587989253383, 56.795833802992306, 52.08720099541449, 57.822184716501546, 56.06450003962363, 57.063814055535104, 56.288804700297696, 57.43685107077322, 58.01141946546493, 61.69268546565887, 59.827033627417784, 55.712616366724816, 49.38324843683551, 64.61822056001233, 59.25625424231253, 56.17103945824408, 47.18126120105867, 44.69884803218227, 43.86890980505174, 49.54373221243582, 61.704621238093225, 64.38581228256226, 60.5090553529801, 56.314441311743956, 60.48550544246551, 62.28084487299766, 60.701443687562026, 56.28715730482533, 51.180741248592255, 52.315518240774836, 57.84314194033223, 61.24300141488353, 59.810234115969756, 66.18337569698211, 62.44330160079464, 65.38372208995204, 59.972635930584325, 61.78861879533338, 65.2033205186167, 72.60366808983588, 60.450302170168975, 17.01131159259427, 1.0532052983199398, 1.9526603048847568, 5.6541907402776905, 0.9824610008828103, 0.3796654837506433, 0.026152696152548158, 0.061886248764612024, 0.16352791789798968, 2.768520655170564, 32.197324691280244, 27.221270568909187, 23.618089152920632, 22.3036931022521, 9.062633341358556, 14.150623083114626, 34.71170517706102, 46.858971811109974, 58.73574395333567, 57.19629210810508, 56.4832091331482, 5.668098974612452, 0.23476551467132187, 0.06282476775888955, 0.02572231944800625, 0.06959416963640722, 0.03415288531311578, 0.05998543906776656, 0.025941497203142896, 0.08502190106458242, 0.04286074627851767, 0.02274323716729639, 0.03448440220146891, 0.04700550411437308, 0.046850972688726844, 0.051246723911214265, 0.04885557197755383, 0.08568089755792772, 0.02903277306036363, 0.02385040084200521, 0.016739837029167724, 0.04826365414285853, 0.05343664369936432, 0.07545024532103732, 0.06959963950418657, 0.03614868991257202, 0.05867523719526588, 0.036861553878313115, 0.04105469016658683, 0.06734650597096452, 0.05158471807296719, 0.05259021613446455, 0.024259032140816414, 0.006740493070889986, 0.053500336249389, 0.09123257586672422, 0.031324733844808036, 0.06734338033223344, 0.05287448838052731, 0.009735102517410152, 0.07049218556212802, 0.01950311042638796, 0.043722809697952, 0.05648183553749996, 0.051385167490450606, 0.2808325112827363, 5.696078221644125, 79.27261521739345, 77.3269784065985, 78.67574030353178, 62.959485515471435, 56.05513734202231, 35.06602071946667, 29.293709762634773, 32.72467559383762, 41.926101023151034, 38.91337163986699, 1.3728984469367613, 0.11690518578454373, 0.26857219336013644, 0.6794273841284937, 1.6355323863606301, 3.7585376731811033, 5.799756271223869, 3.1422769350390283, 0.21927009937503647, 8.90141216016585, 47.119825117049686, 68.8487046764743, 73.6224566736529, 68.90785401867282, 69.81134060890444, 66.78454168381231, 70.12566366503316, 64.38683209880706, 58.9512978061553, 51.82816374686457, 51.7973849081224, 49.974737936450595, 59.935844098368, 65.77540213061918, 64.35590813236853, 62.247696922671416, 64.2417004800612, 62.81288300791095, 58.9749026298523, 61.21350519118771, 63.1205419571169, 62.93642197885821, 58.89102274371732, 49.280117557894805, 45.97578348652009, 55.25834314284786, 64.079443793143, 63.87271135084091, 59.994914993163086, 59.57010661402057, 63.03365753542993, 55.399375884763664, 48.62740378226004, 45.364811574259114, 48.13097292377103, 54.49983519892539, 58.49992713620586, 58.19986581802369, 57.08218251505206, 51.18449887921734, 49.194574586806766, 47.88604051836076, 58.06519908289756, 60.93700555063064, 70.1969252863238, 46.89792879166142, 37.173816157925515, 56.585249593181, 52.579144662426366, 58.81818040724724, 53.45238977862943, 59.697634635433076, 56.06071495240735, 59.67094290641047, 57.06760306512156, 58.720187833232266, 60.47591916976437, 65.63262785634687, 62.392710870312115, 56.518271200118534, 50.80668441710934, 66.73651618342247, 61.41263608009585, 59.15304883833855, 49.84864550252115, 47.22954950025005, 46.838214628158084, 51.25391306415681, 63.15022253221082, 67.30045103257703, 60.02205779475551, 55.4892687643728, 62.53263358146914, 65.38959780047017, 62.57795264644008, 59.73363414887459, 52.48790640984812, 55.293691542840776, 60.183255441727184, 64.27494648964175, 64.191458840524, 70.21820806687879, 64.40616938375658, 67.4651199771512, 63.42573765785464, 64.13682022402364, 69.5577044640818, 72.06726043455063, 65.19722515536894, 21.928740009184807, 1.6209797801509982, 1.4950846904708495, 3.606606625741528, 5.403126199399272, 1.480840358041948, 0.952330946681961, 0.08312154335961228, 0.09524378925561906, 2.7244712123947763, 34.92150491283786, 30.145513242290868, 34.15456387304491, 21.585185489346905, 7.993747265108171, 22.81645278776846, 45.994924652961, 54.99780754889212, 66.71346833628994, 63.89990122087541, 69.73269708694951, 10.032958099918982, 0.2997082129361168, 0.022821694146841768, 0.018900959572244077, 0.02895822887489152, 0.02647386510826407, 0.0547390774403128, 0.028306479573309905, 0.013624016672462947, 0.05119995807387656, 0.08092329236528567, 0.0424435654384715, 0.049727245969998266, 0.05497364207140862, 0.009573519252420915, 0.030156105020714384, 0.051682819462110924, 0.024121892826271155, 0.04994573424600306, 0.0957608832827499, 0.057117876206194206, 0.006419469193074733, 0.050468520306411295, 0.050625353826269995, 0.09702142733599871, 0.11241732015004081, 0.1619888779016272, 0.18704585190261566, 0.1338887728390194, 0.23518690899495157, 0.1347666329914524, 0.19537103662808097, 0.1265103042486214, 0.14014590321288956, 0.12708906069277756, 0.13921119933647497, 0.15948211563931358, 0.1085808054513989, 0.14253229774054021, 0.16901759671107416, 0.13389384434107812, 0.16157682985067368, 0.2641037557153933, 0.15076991861626027, 0.5046304201166476, 7.703852240116366, 94.37510536563013, 87.30068714387956, 90.62892021671419, 72.10549569899037, 64.54046349371633, 39.36029041967085, 47.98774365455874, 45.22325323474023, 57.723505727706424, 54.50614629253265, 1.4958043228234015, 0.22258424170074925, 0.3203905031325356, 0.9100837104262844, 2.2305528771492744, 4.066632005476182, 12.965971193005963, 13.3029822188039, 6.407445159650619, 9.662192137010637, 48.01320768171742, 72.98828786419284, 76.81964335903045, 71.00198391945132, 73.78988696682838, 67.69241348389657, 71.84148880743211, 66.271009291372, 62.12295378408125, 53.32381056201074, 53.80262605605587, 51.95622128825034, 63.40550607250583, 68.66614972391437, 66.61831948064989, 66.87634868006553, 66.86469139591341, 64.01630932284941, 58.916886852633574, 60.89596186914752, 65.05471367989817, 66.66913770860242, 62.32313979056574, 53.38894936346239, 49.14192068961359, 58.219560038658884, 66.25378224157518, 66.27206833131852, 62.88178336235785, 61.16477366416686, 67.76285925219136, 59.54779617248043, 50.33150496021394, 50.518582405582556, 50.82359767729237, 56.17120419779132, 61.4561547771577, 60.401664780032256, 59.619724596700365, 54.23250213746102, 53.0454360285113, 50.660532982118674, 61.763437178827104, 63.60588819749894, 71.56946459124165, 50.016828890769716, 41.67510463345436, 59.18811482767905, 55.70974126938851, 61.51934808300388, 55.845419976019095, 60.10641228768134, 59.31629788491034, 60.11275868262015, 59.8854612535046, 61.409270686488, 64.1011070436047, 69.2681864769228, 65.30778108104583, 58.79099445958292, 50.99025918591408, 69.16036052088585, 63.462968795530266, 61.10325128801408, 53.3759270944903, 49.06672493104012, 49.45036411285401, 53.204680335137155, 66.91175199324086, 70.27101885887885, 60.052138451607, 55.5100259473247, 64.79631577768635, 69.2424165048907, 65.3232156076739, 62.71311752257809, 55.180319355380156, 56.075208110194055, 63.62347218298144, 67.38602146025627, 66.259901139044, 72.43991697988203, 66.52775979811146, 72.91346473078575, 65.19801355177357, 66.24534130096436, 73.64304911705756, 76.88335834010955, 68.2555873932377, 22.92594967349883, 4.5605064592053814, 7.929394408579796, 13.460595800030617, 7.5188987581960625, 1.6337396180437458, 0.6751064030874161, 0.176287648538428, 0.2787027255662026, 4.7400225554743125, 48.71473143177648, 38.885122729885964, 37.478392124176025, 35.44426271992345, 18.76860011008478, 24.473012878048806, 48.493262644737, 61.726496296544234, 76.81055914971137, 72.16421358046993, 80.78651674332158, 11.596078507361874, 0.724307879084541, 0.1972447038297692, 0.23193872683951933, 0.2802859228705206, 0.10333068999311618, 0.14403864110429443, 0.14438999966988642, 0.19697876406773446, 0.12508533474418426, 0.13250218433958869, 0.14863763545309344, 0.2255400387390006, 0.13759029518452384, 0.17574130527434811, 0.12349451486501964, 0.15597709484638708, 0.13556894155279284, 0.1167033369382543, 0.19430992824416007, 0.1647236892172406, 0.13578108662078459, 0.22935373167837822, 0.1291000185113761], [0.07480146844060191, 0.03858633955279666, 0.039579718103331905, 0.1080486118312805, 0.028485334290552045, 0.015012606576595817, 0.06434831362698348, 0.012807895545847716, 0.0021392729972684456, 0.016150634976163987, 0.024053232196057518, 0.07689956876058733, 0.07180124596362153, 0.07816722977065271, 0.03929330847196041, 0.05952085270696591, 0.03867079308556934, 0.08776821902081852, 0.05466772018060569, 0.048282882949757966, 0.0359453357035114, 28.06088920562498, 81.50269446834442, 67.23686941208379, 72.68827361445274, 57.21311515377414, 37.55593738248272, 20.685064292723133, 43.21354842955067, 36.10145976466518, 58.26941336354902, 14.602086909355657, 0.02257159133742173, 0.15341638467244564, 0.16586295389119657, 0.2298888900587636, 0.14489741034565434, 3.5807361429737465, 4.57588509205849, 2.4738371516427686, 5.644152904710462, 44.14216172310614, 70.33179206232872, 68.73087667649793, 67.88872811102098, 66.4084569869503, 64.6641868160617, 66.53576143326299, 62.233082171409364, 57.888257042054214, 51.69000610228508, 50.57385644605083, 48.99455331986951, 48.04204886959445, 49.53624833014704, 57.19403282288582, 58.31403816899946, 58.82469154173329, 63.10675874833138, 60.71209292257986, 60.226130870080766, 58.465320064175515, 59.08861214114774, 58.73546154268327, 57.71925780080981, 52.479575295602125, 44.11621916678644, 44.62614690103839, 54.29871174596972, 61.11667756111392, 63.05926669028498, 60.33137982891452, 61.4161426790299, 53.39866115200905, 45.04024328724031, 43.54822074213336, 47.073709810933764, 50.9861328524928, 55.17673038667249, 55.24002175177298, 52.55763046203121, 45.84096770132742, 46.868416878484915, 45.22155877082579, 53.42891439314812, 55.14811669626544, 63.73381630066903, 42.819840523504446, 35.71385898897725, 55.17093704592798, 52.20656656449842, 55.9801886927697, 53.71709092970818, 56.54335867974066, 55.34314478597334, 56.5426879544412, 56.528861599583784, 61.944905634849306, 57.89443869744578, 58.554510839523815, 57.65970445448353, 58.025496852013376, 56.53232897481611, 64.65738542618291, 57.71310360200944, 53.98500842432822, 44.41354267058834, 45.53607402309295, 40.589812263365715, 46.77276595946282, 55.11579636604556, 60.27700793358588, 59.65601044316446, 54.51970592621834, 61.373671254804066, 63.1529446571104, 60.284499660615005, 57.92538227573518, 48.1291921677128, 50.8079081966031, 54.23101555916571, 62.6511715304467, 62.70010309834635, 67.48586931536275, 66.59173365562194, 65.83393958307082, 64.4910494742855, 67.00431992930751, 61.127738644999845, 67.41013619207567, 69.77389766323951, 56.669882574389064, 10.910843380035894, 1.1218883289444832, 3.068399828287863, 3.860053271055222, 0.033599118657049634, 2.6598511443984125, 0.4407913634373296, 0.012416843092069032, 0.044192888909169746, 8.7300879340018, 49.34042399929416, 24.2569177381454, 34.12192975321124, 74.09926783653998, 36.60672772315241, 24.458617779516405, 34.79119593097318, 52.080721239889826, 56.001483240435206, 60.718047080501435, 28.329028314159764, 0.16800295922064012, 0.03816451621992934, 0.12336644028583843, 0.041755867461043025, 0.01776609224297347, 0.15015591446670795, 0.036945601384485924, 0.03077224272513582, 0.06270541126028666, 0.05309825117189077, 0.04307463802697678, 0.046100765767116705, 0.0407974110285361, 0.074863123196748, 0.0644606067949245, 0.022213922122553475, 0.09055971318194944, 0.013417654610689611, 0.04348636049056246, 0.06197542522943789, 0.06230142628473621, 0.04828102135610196, 0.012411808936796602, 0.02569399143178617, 0.025363393848942175, 0.05910192901689199, 0.03178129351938204, 0.0325236116505919, 0.01707628752375322, 0.02688223593718102, 0.025033972211061947, 0.03719792010322694, 0.039174599317653526, 0.07870096322749892, 0.0386162706079983, 0.03895652089868823, 0.0639003130697435, 0.05839205662449522, 0.033380492485218474, 0.002349883016581918, 0.04108153771789324, 0.026059363660733068, 0.07430891220968577, 0.12649037830171087, 38.29161713200231, 91.52109469136884, 74.68322246305405, 81.17308201328402, 66.19614693426317, 46.87355910578082, 24.766670926924675, 41.60054822121897, 31.853191621841926, 51.01565653277982, 15.135845984182051, 0.09404452457543343, 0.10052135364422876, 0.14659988753978284, 0.8548006607640175, 1.9295970134196745, 5.834905120634264, 3.2020286062071404, 0.7473750929197958, 6.905280716957585, 47.042738776053156, 73.77662935564595, 70.98398808510073, 70.1829694932507, 70.17036299551688, 67.41426252549695, 71.41891617928782, 65.79264094752651, 60.3623273295741, 53.68954020161783, 53.812690857918035, 51.48084571284633, 48.5693762379308, 50.912498197247906, 60.117453759716405, 61.869349018219985, 61.42556028981363, 64.98428360108407, 64.02663300114294, 62.015775019122714, 58.34274207392047, 60.52691782674482, 60.860150629474276, 60.09295855799029, 53.953747134054865, 46.10411559381793, 46.000667002893266, 57.85972572142079, 61.98012067425636, 64.20170407141408, 63.37919089101977, 62.58493054297663, 55.88365131808866, 45.82412112143732, 45.97430475296513, 49.00108406620641, 53.89854369624969, 57.83040992675289, 57.797085469768895, 55.71153379255726, 48.508120582949736, 48.650110383187574, 47.4140577931558, 56.74057937437489, 58.84729616103634, 66.47845560504545, 45.454524024840325, 37.709404037844756, 59.55852777727189, 52.94165011375181, 59.04589752997122, 54.72465369009203, 59.09839060998733, 57.2385399572311, 56.91372456089143, 58.74437709008494, 64.11183472602599, 60.69035514708489, 60.56079926029329, 59.40975227663594, 59.88439829118791, 56.40457737830378, 65.78264282595727, 62.224201925339244, 56.79224483428463, 47.57226267168599, 48.875760416830744, 44.8154640197754, 49.08722323756064, 58.37267760307559, 62.59423048265519, 62.15648220431421, 55.65357685089112, 61.82974484659011, 67.749876206921, 62.0309232127282, 58.20077973027384, 50.86328029632569, 54.47663830172632, 56.64312024270335, 64.98029847298899, 65.05541186178884, 69.51954764704551, 69.01439343729328, 67.66134831213182, 66.52058186069613, 69.02814526711741, 63.86172871435843, 71.25642022778912, 71.35746832816832, 59.363319258536066, 15.137531622763603, 0.9411936217258055, 3.031370202379842, 5.163690995785498, 3.261674128232464, 5.857638687856737, 0.9688310709691818, 0.0262179036414431, 0.10559614988103991, 9.664548500891655, 47.30889120409566, 22.967111026087117, 33.83383950879497, 55.72091610200944, 30.7056983055607, 34.98106610390448, 42.11756367837229, 58.94779120722125, 62.553735932996204, 68.98049631426412, 37.85086824047951, 0.1640115032393125, 0.06220330191295474, 0.0738531971470483, 0.031208079721358035, 0.03253273192733046, 0.05619203596706352, 0.07336756635096765, 0.025916509330272678, 0.024840900817164974, 0.04674857737676752, 0.02127502391475343, 0.04174036184145559, 0.01445809968807284, 0.021954955675849513, 0.07112084497367183, 0.066207540071299, 0.07657969640868326, 0.017373636890683445, 0.04648618460182221, 0.10795817515181919, 0.013715322861718315, 0.03246647298275944, 0.05042199195633012, 0.22036986455561655, 0.08394454395578754, 0.14982605232827126, 0.2012156133329676, 0.12974872644389832, 0.08351311388034975, 0.13419661761051224, 0.09660870512767185, 0.08439340253150271, 0.13718331863562908, 0.2732121427693675, 0.19552754839101147, 0.23322783831146457, 0.1292325517222766, 0.15379948992161982, 0.10632946456391966, 0.1881164750985561, 0.12818965324831585, 0.18750591834466304, 0.21442994054767395, 0.29273227758465276, 46.91044899725145, 103.1407319345782, 83.52430758937713, 90.82871006381129, 70.85074517034715, 51.24972789518295, 29.499961714590754, 58.99022733011554, 47.07905207910846, 80.38155555725098, 21.776314743103523, 0.36537000729191693, 0.30268118566563057, 0.6905577223627799, 1.1586167903677111, 2.2113783705619077, 12.696923075183747, 12.968262837779138, 8.67928147315979, 8.952502992845352, 49.98205707919214, 76.62474862990841, 75.04079357270273, 73.24350080182477, 72.40799673141973, 69.85689501608573, 74.78374496583017, 67.75740715765184, 63.591210688314135, 57.201571618357015, 56.15036464506581, 53.466612292874245, 51.59868940230339, 52.43211069414693, 62.67720822365054, 63.981290401950965, 62.52039186416134, 68.6492992216541, 65.8953482104886, 62.450652122497566, 59.17853639971826, 61.95753958917434, 61.907647040582475, 63.49524597967825, 57.52037794359269, 48.464331242346, 48.99781673185287, 58.55977466029506, 65.96344840142035, 66.88608400283321, 64.7033203032709, 66.55858962766587, 59.28355393871185, 49.7455773815032, 48.15804512270036, 52.60895467573597, 56.29730839883128, 60.54600015763314, 61.60361628378592, 59.865896471085094, 50.708311373187655, 52.16878629499867, 50.659603380387836, 58.363397275247884, 62.578176221539906, 67.61057715262136, 49.12883566271875, 43.29250574111939, 61.89776266774824, 55.13463550998319, 60.99515468843522, 56.94356203079224, 60.08324284707347, 56.94438572852843, 58.14614895851382, 59.54279122814056, 65.69869233715919, 64.30473296873032, 64.90118034424322, 62.390749685225956, 61.93627249810004, 56.47958878547915, 69.1566264244818, 64.94195338218444, 58.43336059201149, 49.64747105875323, 50.51340879932527, 46.65746396587741, 51.63131959976689, 61.14820165018882, 66.48284865963844, 64.78295618487944, 56.892073077540246, 62.31589909522765, 70.86640327207505, 65.54952067713585, 63.96556954230032, 52.09308455067297, 57.02398630880541, 58.01467895507813, 67.59080840695289, 67.10483458734328, 73.84308999584567, 69.02203421438895, 69.69222607151156, 69.25390904949558, 73.39670073601508, 63.95581460768177, 76.54493624164213, 73.7028495727047, 63.0491195186492, 15.14811908045123, 3.262297049645455, 10.11750380839071, 12.022692157376198, 4.348764659896974, 5.052042690015608, 1.0053615752727756, 0.1772248958267512, 0.27232559517987315, 13.342417728516365, 67.66090116193219, 35.275400761635076, 47.271424724209695, 89.13314788572251, 50.15843429873067, 36.896359459046394, 48.59681321728615, 69.78954792022705, 71.28537516440116, 77.96028429462065, 45.68137038138605, 0.2920015522789571, 0.15442732961908465, 0.22971814438219995, 0.14628790589349885, 0.13780757304160826, 0.24575879977595425, 0.1843879711363585, 0.14961622084581083, 0.12739177267517776, 0.14526280364201916, 0.12123518368049015, 0.16079964897324964, 0.13446484031456132, 0.27514611641245507, 0.17798310836717007, 0.188630826530918, 0.22728641277119038, 0.08060957936029281, 0.11817764250501511, 0.30735612997124273, 0.15221719660105246, 0.13599847173017843, 0.16758708073006523], [0.087974518837948, 0.018874615723747882, 0.08838557097459994, 0.022889446962865132, 0.053430281339153174, 0.072970058648817, 0.04188276609526046, 0.025448203612599644, 0.01944381522104865, 0.07431301844095992, 0.03311623428617755, 0.0677497286890303, 0.040547735313133854, 0.006462825939149386, 0.05830174634954142, 0.008882119155098355, 0.04110155176491507, 0.037131304927771135, 0.07091900378826164, 0.11049486846933443, 1.1973309516906738, 58.30490689123831, 75.88222042206796, 72.20654379936957, 60.62377291340982, 58.42612381904357, 29.41622303378198, 39.10776430560697, 33.82873258283062, 40.83035553655317, 46.185261587942804, 0.4879056482065109, 0.04725606849176749, 0.0867455299463003, 0.20076604229548287, 0.681436189240025, 1.2435538778381965, 4.5239671295689, 3.7676836598304013, 1.7868774071816476, 40.50466152929491, 68.91879743145358, 68.76170650605233, 63.25775823285503, 60.95873940375544, 55.91693655137093, 54.2643557056304, 49.427751648810606, 50.52415217122724, 46.77650790060721, 47.47033988275836, 54.45701860612439, 48.95752222307267, 45.6798759583504, 48.9948945660745, 45.50607965838525, 51.2743172337932, 57.04815203143705, 60.03175781619165, 60.57992081488333, 63.303269493964414, 57.67331507898147, 57.2984149379115, 58.9792525383734, 57.56356323918989, 51.621152816280244, 46.10899894468246, 42.17130014973302, 44.086891605008034, 48.987096894171934, 56.516506133540986, 56.55011692354756, 57.411904796477295, 48.40958279948081, 42.932745948914565, 41.02335968325215, 45.62895967114357, 50.3850963038783, 55.23624450929704, 51.28962232220558, 49.97562439210954, 45.696142027455, 47.097899067786436, 45.59022234332177, 53.719358059667776, 55.4474994444078, 62.61363444789764, 46.5745803617662, 41.69749744476811, 61.35446340807023, 55.71427945167788, 60.50059087814824, 53.92690635496571, 52.071272250144716, 52.86859204692226, 57.11457737030522, 56.938035411219445, 59.10949091757498, 55.460007882887325, 54.67491411393689, 56.98864183118267, 62.38787066551947, 56.847589477416015, 57.439769314181426, 60.49411896736392, 53.724602268588164, 45.55396003107871, 43.005235272069136, 43.73984029216152, 43.68511146114719, 52.790729076631614, 59.041378959532715, 59.98176720834548, 55.89467317827287, 55.22800753193518, 63.90764397959556, 60.13619092202956, 57.84794684379332, 48.49873042875721, 47.11966822224279, 55.39108007184921, 62.06293759807464, 63.78563865538567, 61.40721928688788, 65.64237494622508, 69.66261217671057, 63.422305583953865, 65.0914192199707, 67.27407701553838, 64.62569659756076, 61.67076726113597, 66.32797779575472, 49.11678614154939, 5.5657604144465544, 1.8871531683591105, 4.237565465511815, 1.937591294127126, 1.5906267637206664, 0.42804157661814846, 0.05066854203300131, 0.0849075701027628, 0.32620750067214815, 19.324137164700417, 52.98524725821711, 60.80821452602264, 85.84867277453023, 81.8163428768035, 25.189490664389826, 24.577469518107755, 43.137756470711004, 54.265418667947095, 57.76372178908318, 49.40565693762995, 1.1101925565350441, 0.09553700174775817, 0.009912881838728585, 0.05678525998166973, 0.02379637632158495, 0.01823995018287772, 0.04232114075773186, 0.0559167537627922, 0.015332712585316792, 0.016841841636285666, 0.03710619256561322, 0.09053093891951347, 0.059390204072359114, 0.022363276709051385, 0.04957875131719536, 0.05435593771718202, 0.031247824362869707, 0.0481164618395269, 0.04972303248641472, 0.04030916787263367, 0.13741945757740928, 0.05036691406501397, 0.02264694183043415, 0.04242272784693107, 0.018680280284775842, 0.06177656029561355, 0.03204955452782733, 0.07293142483479555, 0.03884258447214961, 0.04897022469630165, 0.1004371912248673, 0.05752249320428218, 0.05936228399795871, 0.02815446857693455, 0.04174486260801073, 0.027272703291307536, 0.05249984074203719, 0.06263112371426917, 0.016024972616334357, 0.025727226241161267, 0.07090384290824014, 0.06853185083356596, 0.16683833703639048, 2.28445531379792, 71.48032480670561, 82.98318524514475, 81.80802745203819, 67.94334319330031, 65.71197740493282, 38.61032539798368, 34.965105979673325, 25.761886066006078, 40.65044033911921, 45.130638230231504, 1.2282789426465188, 0.0492892160470928, 0.08826214654911911, 0.6242602895344458, 1.730874296157591, 4.286026839287051, 2.9917295036777376, 0.3236180622010462, 3.0722599308336935, 43.09392790640555, 72.26785044516288, 70.56481222952567, 66.10590888607886, 64.0899439780943, 58.41439593222834, 56.08311168609127, 52.309760201361875, 52.03992074535739, 50.07239710900092, 49.16429388907648, 57.455231297400694, 51.00398748151718, 49.08623087790705, 50.41829132264661, 48.44213454954086, 53.50993879379765, 59.560747838789425, 64.17892686782345, 63.949377998229004, 63.19717722554361, 57.110576552729455, 57.978573537641964, 61.043121353272475, 59.18236071063627, 54.700389908206084, 47.463593406061975, 45.03704655554987, 46.57006963606804, 52.995504256217714, 57.743231327303, 59.115845157254135, 58.83219111350275, 49.738230782170454, 45.478807418577134, 43.075567291628936, 47.103233491220784, 52.29571419377481, 56.63895860795052, 54.006840336707334, 52.35804457818308, 48.58611299145607, 49.441283825905096, 47.98941850662232, 55.4503627746336, 56.043291784101925, 66.33087250494188, 48.937000382331114, 44.993680830924745, 62.815828707910356, 59.89147032460859, 62.91635121068647, 57.232362224209695, 54.030249041895715, 55.231078747780096, 58.295771691106985, 58.32716241959603, 62.47770470957603, 59.28793522619433, 57.5350123067056, 60.04840827757313, 63.53675642321187, 57.52530444052912, 58.21714385863274, 64.51945135670324, 56.86305146063528, 47.916638928074995, 44.773341686494895, 45.83776312489664, 45.192552843401515, 55.091646332894605, 60.06196398888866, 62.56677389144898, 58.045802962395456, 56.31673589829476, 65.94680186240905, 64.83030311522946, 60.16732669645741, 51.42179835227228, 49.323440136448035, 57.56046456675376, 63.65957367804743, 66.9658414779171, 63.371389296747026, 68.44912498228013, 70.6172150950278, 68.36233861984746, 66.97735755674302, 68.74784484986337, 67.08550514713411, 66.89781188964844, 68.85990696568643, 50.20787185238254, 8.587414660761434, 0.3297930066623996, 3.056104913834603, 7.823827247465811, 7.7822427691951885, 1.7645398767725116, 0.16474811210026666, 0.04002280803697725, 0.39468880502447007, 22.937669715573712, 50.97857836754092, 58.87282294611777, 85.3258365200412, 73.2509062367101, 30.542731669641313, 30.802202340095278, 50.75735276745212, 62.76726976517708, 63.19614956455847, 62.093971390878, 3.590634979547993, 0.2286320615319475, 0.06504141635471775, 0.0736156102990912, 0.11295620937861743, 0.06075168787051113, 0.045624224604257656, 0.04548736682702457, 0.011054156535875895, 0.043160635226916884, 0.07756905299761603, 0.11321254239808168, 0.02447646704592532, 0.013689772871833657, 0.009320832811476243, 0.031430360132588014, 0.029904567711656133, 0.045033942367280685, 0.049343868759610963, 0.03957713255658746, 0.08069180357720583, 0.10918576976344471, 0.03731753324128447, 0.1648809211028199, 0.10000554664481072, 0.1725614734835202, 0.12411211196693683, 0.20209085346469957, 0.13945394195616245, 0.11444097204554467, 0.14744687434886733, 0.2525095205994383, 0.1571779529894552, 0.13458232755862898, 0.2061491736000584, 0.1825808463317733, 0.17194635084559842, 0.15280875437442334, 0.13363437036112433, 0.1040062646291429, 0.1231472472089433, 0.20101656836848106, 0.30687904105551783, 3.8857695556456044, 88.0637764161633, 92.00412673334922, 91.9478250318958, 75.50713200722971, 74.52450767640146, 39.137978323044315, 58.22878545330417, 47.35117043218305, 56.033328963864236, 63.658169469525745, 1.4099185120674873, 0.119797183020461, 0.21859761207334458, 1.2771074257550703, 1.7830211044319215, 6.207435659823879, 14.490581770097057, 10.6720769405365, 4.7866423764536465, 45.93977220596806, 74.90167494743102, 73.55219133438604, 68.64492970128214, 66.50668882554578, 61.30286462845341, 59.64132116686914, 52.824602665439734, 53.58371073199857, 52.841806181015514, 52.91842575996153, 58.11457780099685, 53.2536825056999, 51.16897806044548, 53.8549034057125, 50.45075678056287, 56.96117347286594, 62.04065461312572, 65.81347265551167, 65.85992136309224, 66.5037235136955, 57.32573424616168, 59.8035974656382, 62.99089193344117, 62.367823431568766, 56.467425515574796, 49.54952555318033, 49.221285927680235, 48.530768348324685, 54.293141980325025, 61.09125275765697, 60.590699488116854, 61.7392243877534, 52.90399536009758, 47.562088043459006, 45.72876830254832, 50.95418514743928, 55.90229826588785, 59.58096373465754, 57.51447869885353, 55.3418190248551, 50.17336676197667, 55.10273095100157, 51.09741833902175, 57.642371500692065, 60.539728287727606, 68.08581152269917, 51.26404846868208, 48.38294598364061, 66.73484525372906, 62.691544486630356, 63.46943286157424, 59.3392986636008, 55.97350889636625, 56.40089819508215, 58.599633785986136, 60.61057413777998, 63.58826498831473, 63.759029296136674, 61.83502827921222, 65.13768357615318, 65.47883564426054, 58.39590587923604, 58.94450818338702, 66.31961530254733, 59.55229120869791, 50.95105901841195, 46.738735475847804, 47.55269004452614, 46.98255785049931, 56.68438357691611, 62.91742201774352, 66.05062700087025, 58.884476307899725, 56.39171592650875, 69.16953102234872, 65.21305191901423, 62.53197462328019, 54.91401395490093, 51.772383720644065, 61.09238632263676, 66.44306013661047, 70.5296128795993, 66.12225732495709, 69.71590149787166, 70.65930212697675, 69.34867351285874, 68.23619519510578, 72.8503930184149, 69.49697832907401, 69.77667470132151, 71.7073751265003, 53.551543374215406, 10.046281410801797, 4.374828319395743, 10.87940558310478, 9.29896398898094, 7.517564662041203, 1.2134822914677283, 0.24647224213807817, 0.1314060657375282, 0.672755493752418, 30.99790115510264, 67.36123208076724, 65.12391605684834, 88.87820951400265, 89.08161578639861, 34.88705081324424, 39.26387071609497, 57.92971649477559, 71.96967970940375, 71.07468897296538, 73.40876594666513, 5.129753178165806, 0.5159284703193173, 0.1779741298166975, 0.19029918216889907, 0.20284063903795135, 0.14374955016518795, 0.13845076514107568, 0.1635308903191359, 0.15932482246670032, 0.14851582747313286, 0.13410986581396672, 0.1987027989760522, 0.12083554625390999, 0.13028264376184634, 0.2154146393220271, 0.1725828320148491, 0.17499096811779086, 0.20355869324937945, 0.13376147966952096, 0.18051125980432958, 0.2558595464835244, 0.15544847885687507, 0.14113755806559516], [0.012393807785795822, 0.07228814846565647, 0.0067688349724536944, 0.029775106513331977, 0.06369424690943092, 0.01762720433274104, 0.14412263498431252, 0.0215234681438174, 0.013203691999097506, 0.0918146264889548, 0.03676392363324281, 0.012195991434817834, 0.018555700981749162, 0.0640553730960575, 0.06666747627839928, 0.06380573568505145, 0.02202250164813332, 0.033637656710080566, 0.02088950740383758, 0.04603322745571214, 6.798740317744594, 68.32762564382246, 64.28492107698995, 63.538815667552335, 41.76531522504745, 40.107933398216005, 21.04456520849659, 43.9199790646953, 78.32689254514634, 57.31721485814741, 19.550503030900035, 0.04931221017614008, 0.15764499083161354, 0.1355290436936963, 0.269850334453006, 1.3938944041728976, 2.3985896668126507, 2.0217244182863543, 1.073369590505477, 30.9024541993295, 75.68704328229352, 66.02207214601579, 65.28574912778794, 57.41232449008573, 54.770859210721916, 52.65821964510026, 56.303941126792665, 52.90408557461154, 53.0776975231786, 49.97708351381364, 49.097472390820904, 48.952007370610396, 51.19908617388818, 49.21411191263507, 53.319668539108775, 46.753962116856734, 47.3765246329769, 52.67139880887924, 59.15208393527616, 58.07722506984588, 63.23912697453653, 58.53995492381435, 58.28080000415925, 59.71524607750678, 58.22122312361195, 51.43665236811484, 46.641680348304014, 42.67281832233552, 43.80437504860663, 41.39283910874398, 46.97182624570785, 47.70546244036767, 48.96606514530797, 42.15896037317092, 41.859993396266816, 40.31221828153057, 44.69107781687091, 49.350916339505105, 52.53047981569844, 47.88584047748197, 48.77274328662504, 45.39017361979331, 46.30354850522934, 45.14201702610139, 51.543238855177364, 54.28755652519965, 64.09850258981028, 44.11391281312512, 45.298503906496116, 60.291916862610854, 52.972166153692434, 57.049085555538056, 58.26629507926203, 56.742995554401034, 46.3279378029608, 53.93630435389858, 59.66729510215021, 61.64336950548234, 54.44691065819033, 48.563229883870775, 52.65947088118523, 61.119964507318315, 56.15556963028447, 54.34773352838332, 60.41679728415705, 56.74830644361435, 49.119382750603464, 44.374244443831905, 43.0593914370383, 43.22973605125181, 46.322034635851466, 53.73423953210154, 58.248718938519886, 63.667316436767585, 57.45712580219392, 60.230574915486, 62.78752096237675, 59.47530684932586, 51.156265658717004, 46.7248502854378, 50.48700732569541, 58.826032992332216, 64.63912679303077, 60.00792157265448, 61.005270481109626, 61.7252685946803, 62.22292715503324, 61.30572403630903, 66.5893723887782, 65.1200250656374, 64.10742990432247, 55.11772224980017, 62.172783574750355, 31.09976903084786, 2.7801901967294755, 3.263018030312754, 2.058772430304558, 2.99406306878213, 0.5176364786682591, 0.07726939770603374, 0.07540194347741143, 0.052994545849580924, 5.713740164233792, 32.68796220902474, 69.47543667208764, 76.42417430877686, 75.65098885566958, 36.963031907235425, 25.505696458201257, 44.58030616083453, 50.419781823312086, 51.01058098577684, 57.713150670451505, 15.041913063295427, 0.22927456415228306, 0.10959551188974612, 0.11546803548211053, 0.05448006694355319, 0.06702711625445275, 0.09478784436660428, 0.05699128400714648, 0.0529439457421822, 0.031872344984402584, 0.02304915522765969, 0.0762592877952322, 0.04582037758683005, 0.022444541400839246, 0.04096803796147147, 0.03599049275620811, 0.0204835114474859, 0.013829039995588604, 0.06661816319871335, 0.03686863636117309, 0.032685876733833746, 0.07227258921991433, 0.033992929984965635, 0.011140807783381354, 0.012032044788582191, 0.05014243115100169, 0.04071525192909664, 0.054569699230694005, 0.04187629648273991, 0.09213349526567806, 0.07712662189958558, 0.05653233605346853, 0.04314038752307815, 0.02866962631683677, 0.018108048994514733, 0.07902666550850676, 0.06243141608372812, 0.0474472840376679, 0.06063918402839092, 0.013623321447671663, 0.0987036798089262, 0.009021200502531664, 0.07455227536059196, 11.499724503486387, 81.45444931522493, 69.58877748058688, 72.77122389885687, 50.749955177307136, 51.90754859678207, 28.873088513651204, 50.50868234326763, 61.60079217726185, 48.13882158648584, 22.442205721332183, 0.05158085315938919, 0.1494879624055278, 0.3591701802947829, 1.0482561251809521, 2.2934569081952496, 4.712848865216778, 2.030209730709753, 1.3726752395591428, 34.316549916421216, 77.93893091140255, 66.80016056183847, 68.13272306996008, 60.93187901281542, 59.010376545690725, 54.50942931636688, 58.323832327319735, 55.57634930456839, 54.45446122077204, 51.60380809537826, 50.555954748584384, 50.77618798901958, 51.67449705062374, 50.2426044402584, 55.29680982712777, 48.068517023517245, 49.207483107043856, 56.174722563835886, 61.38664253296391, 62.41500562237155, 65.11334134686378, 60.85998981229721, 56.90570331388905, 60.71049259554956, 60.77038326571065, 52.75136809195242, 47.87719165125201, 46.86913859459662, 46.727219397021884, 44.0443770347103, 49.380671439632295, 50.92679915889617, 51.336271070664935, 44.80221033096314, 44.70355487638905, 42.62758947187855, 45.75625627271591, 51.75700410719841, 56.2699890905811, 51.014189566335375, 52.851412065567516, 47.487994470903956, 48.96528067127351, 48.766949945880526, 54.2906944213375, 57.65851205395114, 65.55573763385897, 47.24728645816926, 49.04159038297592, 62.444203745934274, 54.81023196251162, 59.27634854470531, 61.380127476107695, 58.66230933896957, 47.628380021741314, 54.604754678664676, 60.40376324807445, 64.19028212947231, 56.76567862110754, 51.66508336221018, 55.90139612074822, 64.21396147820258, 55.381866424314445, 55.67664823224468, 62.53601858692785, 57.41706663562406, 50.11337803256128, 46.656691258953465, 45.32901602406656, 45.34412499397032, 47.62216698738837, 57.559134883265344, 61.333451271057136, 64.53755701741865, 57.81283378601075, 61.11543809213946, 64.38450221092471, 61.19883944911342, 54.433911923439275, 48.65191467346684, 53.42239149155156, 59.79958880332209, 66.46278965857722, 61.32103304709158, 62.684523444021906, 63.07327739654049, 63.638134002685554, 63.24122152020855, 66.82684052375056, 67.0056535351661, 66.68371323616275, 59.53011020537346, 66.14884314998504, 34.2872380441235, 4.132663146142037, 1.0500350426281653, 2.3900734657241456, 7.391611472252877, 4.581819147832932, 1.1169705347668741, 0.08872393668899614, 0.04187437743248959, 6.219556764248879, 37.27242454405754, 72.428557795863, 80.15240284704393, 84.4849274235387, 41.67471239643712, 32.78401124861933, 53.456716152929495, 58.24619293212891, 58.273453404826505, 66.55506733925112, 21.489622823653683, 0.2036079373811522, 0.11280045604273198, 0.060952759137557405, 0.07964407874932213, 0.07498300063513941, 0.07239463468713146, 0.03868977674433301, 0.07412404753267765, 0.0377752248107666, 0.01004255945689135, 0.00968258814781063, 0.03791571384476077, 0.03591063958142073, 0.014669548573663399, 0.013520496168864832, 0.07761474248142013, 0.013437244436523367, 0.04554509538255873, 0.06140844355667792, 0.05437157740215621, 0.04903297495817946, 0.033095500116506894, 0.10469565183044442, 0.10656820054376319, 0.13158883899450302, 0.1805405090412786, 0.2191899972216737, 0.17837749043058965, 0.23199610682504795, 0.11466897513356902, 0.1664452266789252, 0.10923266966616917, 0.07904803936159419, 0.1194405461090707, 0.12123830931922122, 0.16082134458326525, 0.09904909353222578, 0.278042235201405, 0.23872202172154383, 0.19902265600619778, 0.09036102061790806, 0.26011072159294163, 18.64600250797887, 95.47541649110856, 76.29579513303696, 84.98285662743353, 57.721811263791984, 56.879752912829005, 30.49550044921137, 61.18609566842357, 96.00659170458394, 77.45152934905022, 28.078622241174024, 0.19940919332927276, 0.4419027425108418, 0.3855698766006578, 1.0298678086649988, 3.3098459820593558, 11.51425394319719, 9.018878321493826, 3.3568460277972685, 36.001741347774384, 79.99771241218814, 70.17379899178782, 71.43873983813872, 62.355577791890795, 62.56399685336698, 57.16448560837777, 61.14314179266653, 57.951383667607466, 56.829742693131976, 55.48076898820939, 54.573277658031834, 53.18256993447581, 56.29076980775403, 53.04123909242692, 57.50689675731044, 50.4546909178457, 51.90986279518374, 58.573585325671786, 65.05870273036342, 64.32913795594247, 67.9313721195344, 61.71710614235171, 57.60175143518756, 62.9989210251839, 63.606829566340295, 57.012179974586736, 50.8562788655681, 48.75718716652163, 49.51396534519811, 46.724258007541785, 52.07932095373831, 52.15248492456252, 53.3543069901005, 47.25467228120374, 47.54064052335678, 45.276648459895966, 48.993635485249186, 55.25920606428578, 59.00801527884699, 53.43766912337273, 55.831781894929954, 50.1844435353433, 52.104788903267156, 50.965054035186775, 57.612008433188166, 60.66674247864754, 68.4109446310228, 50.29781180043375, 52.328442450492616, 65.58577122226839, 56.981930655817834, 63.199683620083725, 65.06296242437055, 60.58002279650781, 49.218963884538226, 56.55218401262837, 61.35494193723125, 67.1429443359375, 60.34837545887117, 51.57115044132356, 57.02315868869905, 68.38420191118794, 57.836587659774295, 56.06959912084765, 65.10188802596062, 60.8833553714137, 53.521325434407885, 48.391080979377996, 46.67056860462312, 47.21819816097137, 50.62508260050128, 59.7455777660493, 62.80843111776537, 67.80712712195613, 57.60090812560051, 62.97570059376379, 68.58413296361124, 65.84677357827464, 58.483751281615234, 51.264887855898955, 55.34747508264358, 63.905608269476126, 69.90863107865857, 64.23348703692037, 65.56313914637413, 66.64246559143066, 64.59386656361242, 66.6875728484123, 70.6312728697254, 70.33954266578921, 68.26857043850806, 62.8754291226787, 70.27868317019555, 37.458372346816525, 4.999824666207837, 9.627026127230737, 11.190812357010381, 10.453260656326048, 3.9269718479725624, 0.9033643225989035, 0.2499070892771406, 0.13162928843690505, 8.761186445913008, 47.85332402875347, 76.24507888670891, 79.66365198935233, 82.39027976989746, 47.64782321068549, 37.993356181729226, 58.332947915600194, 68.15943441083355, 65.49641178500268, 76.90915969110306, 27.832240519985078, 0.2846574657146008, 0.21187356643138394, 0.2658898437455777, 0.18924507582860609, 0.19728682334384612, 0.1568157466188554, 0.10520912992257266, 0.23312640827028985, 0.10787321600101649, 0.12593622094080334, 0.1582091379790537, 0.1322916940215134, 0.12069219588151864, 0.1346923990715896, 0.13842916146161097, 0.21897658044772766, 0.1094012856183033, 0.1455491519863567, 0.10710099937334176, 0.1740568617899572, 0.12802306742918107, 0.130625314890377], [0.03361379690167885, 0.020014696281343218, 0.0621790437388324, 0.05288786044524563, 0.0816586065376478, 0.1132589903089308, 0.017410428263247013, 0.04137141389712211, 0.026957201471011487, 0.05623780589009966, 0.009737018694830759, 0.04734927074863546, 0.06429972066994637, 0.021620069915849357, 0.06122457096353174, 0.020994875136943116, 0.022029005734610464, 0.07002831166309696, 0.09047701399052337, 0.0717550661835459, 41.59609240870322, 78.10153668926608, 64.11576101856848, 47.46332668489026, 36.88241935545398, 22.970141057045232, 22.481301946024743, 30.219951983421083, 51.69712520414784, 52.77990333495602, 3.002985480331606, 0.05739375595904647, 0.030040446811565952, 0.35000783000742236, 0.5052084487772758, 2.108217093252367, 4.225475740048194, 0.9074875303814489, 20.123290669533517, 72.57512107972177, 66.24191314943376, 65.00822574861589, 59.39641621805007, 58.5909967268667, 58.211805512828214, 63.39468425320041, 64.45281420984577, 64.79793179419734, 62.76486142989128, 56.987598480716834, 48.81026075732324, 45.681099737844164, 51.116630108125754, 56.69362075867192, 58.655829583444905, 52.742715343352295, 48.93154044305125, 50.34872416527041, 55.72754098523048, 59.788453194402884, 60.081116922440074, 61.501964138400176, 58.892921170880726, 58.943339317075676, 55.9743796625445, 52.79376499114498, 50.47229843754923, 49.69513570108722, 47.34549084017354, 47.976988515546246, 42.55656711516842, 44.463439141550374, 44.77221988862561, 42.8978996123037, 42.300703064087905, 40.60427404219105, 43.211222464038485, 46.21046281629994, 49.58455624118928, 47.655711097102014, 44.82197123189127, 43.189884770301084, 46.01363435868294, 45.25913899944675, 50.64264697413291, 53.21893815071353, 63.74099816045454, 42.64048230263495, 41.67369650256249, 62.02534167997299, 50.4441632763032, 53.826238724493216, 53.67985586966238, 60.08123067117507, 57.520856472753714, 52.84009602762038, 54.49198261384041, 58.93210172653199, 51.8871561942562, 47.959016215416696, 51.13835219414004, 58.506552019426906, 57.70140317178542, 55.227744733133626, 60.28087539057578, 56.66717613897016, 45.629720610956994, 43.559603460373424, 42.51701001198062, 43.863908783082046, 46.51446611650529, 51.518904470628314, 55.49614467928487, 59.49049426663307, 59.31892195055562, 54.887157486331084, 61.82625393713675, 60.76658641138385, 56.61028608199089, 48.87942391057169, 46.83656723268571, 51.36917191167032, 63.14413109133321, 61.77176829307311, 60.293701541039255, 57.29069963578255, 63.22182147733627, 63.934720100895056, 63.936716587312766, 63.93140962046962, 64.01443050753686, 62.299017214006, 55.23711527547529, 47.65198876780849, 15.108338402163598, 1.2711374557787374, 5.434308551972912, 10.960780055292192, 3.8793871239308393, 0.2440790294279014, 0.034178721628362135, 0.011153587087568258, 0.04993176846314342, 15.458859051427535, 31.482500183966856, 47.59985654584823, 38.584324006111395, 24.82744020800437, 22.085656389113396, 31.279131174087528, 45.825631233953665, 52.02922836426766, 59.479362580084036, 32.78139110534422, 0.8958375393863648, 0.05316215056565501, 0.08942512164433157, 0.02949610686740808, 0.029031560726223454, 0.04027144953368172, 0.02290943611202942, 0.04600432678876866, 0.06691728988962789, 0.02315212510556223, 0.03305781625151154, 0.10227050091470442, 0.0680747414909063, 0.02910427970721597, 0.04458840861315689, 0.0117314615730016, 0.004935400793328881, 0.09150138079759576, 0.04956264431858736, 0.0427352725678394, 0.061973713022927125, 0.03431175279641344, 0.03276803583327321, 0.046498258147508874, 0.07310652189076909, 0.039796398411835396, 0.008332230819148884, 0.08057030969329419, 0.04852293277039163, 0.020626279593054807, 0.0314833868234869, 0.056818132814500606, 0.11100843083113433, 0.009541726603563274, 0.04481860654308431, 0.024266512989397013, 0.011130333446236628, 0.0295845938531021, 0.026068945505446004, 0.14820056697053297, 0.0652348765382363, 0.09470519114045367, 51.810250282287605, 89.44179919458206, 70.26537064583071, 56.94750793518559, 42.15843085319766, 36.428671729180124, 32.65335317580931, 31.910260146664037, 61.7616250438075, 53.811925995734434, 4.542045333693105, 0.12288670836677476, 0.04426732967277208, 1.2436418860189378, 1.870180214605024, 4.839746855920361, 1.8258080343084953, 1.1853101128532042, 22.952670820297737, 74.18060210443313, 68.4531650235576, 67.96197445161881, 62.053339558262984, 61.75103464434224, 63.2706000727992, 66.91926725449102, 69.09836353794222, 66.58992152060232, 64.33390363570183, 60.52935361862183, 52.407819455669774, 48.36405977126091, 52.72994018370106, 59.708311327042125, 60.32416266779746, 55.324497838174146, 50.52536810598066, 51.57373528326712, 57.088874078566036, 61.47228356330626, 62.21470978952224, 63.79556225192163, 58.98046455075664, 61.5192892474513, 59.51406378899852, 53.864717175883634, 51.5225326630377, 51.76964590626379, 50.536825349253995, 49.805997571637555, 45.902184132606756, 45.86542760172198, 46.61253321555353, 45.60926545050837, 43.5419802511892, 42.265174235067065, 46.66223749037712, 49.727836501213815, 52.14649154293922, 49.55405196835918, 49.11268726471932, 45.56824138087612, 48.66083806560886, 47.83629701983544, 53.216820070820475, 56.34919351147067, 64.68765827917284, 44.44088943542973, 45.09856893170265, 64.3909780440792, 52.436021297208725, 55.62418260881978, 58.664152852950565, 63.895786654564645, 59.60153264384116, 54.29211824171005, 55.56926550403718, 61.83291804405951, 54.84419968820388, 49.88153457641602, 52.07544172963789, 60.230692586591175, 59.36805355933405, 54.76208094627627, 61.939484919271166, 60.54698075017622, 47.53041490431755, 44.958167691384595, 44.805097195409964, 45.69678137379308, 46.99243830096337, 54.69150181739561, 58.01431417465211, 63.324018832175966, 59.014922572720444, 56.05941272551014, 63.02280041479296, 62.39917493635609, 58.30699359216998, 50.69115100368377, 48.10703077623921, 53.61746272733135, 65.78694958840647, 63.380285232297844, 62.949071622663936, 60.0492908108619, 63.64998348297612, 65.43584254480177, 65.80399228680518, 66.4461431195659, 65.39902717836442, 64.24334787553357, 59.18595752408428, 53.43716705999067, 18.356086400247392, 0.7377914555611149, 0.5841036152935798, 1.0445811094776278, 8.242466718919816, 2.339608741383399, 0.23451337981368267, 0.05397414630879799, 0.060016580541888555, 19.814007859076224, 39.60747034318986, 51.175606866036695, 49.887473044856904, 35.2511134455281, 32.0495827351847, 37.52041639820222, 51.85828754978796, 59.004936218261726, 67.41532941018382, 40.93971906169769, 1.5983478268308025, 0.04537580144261161, 0.1064956290346961, 0.020410790551273574, 0.009154775593009208, 0.06187461571948183, 0.019216737184192867, 0.11014057578699243, 0.031083879631853877, 0.021076059389498927, 0.010983412146508213, 0.060326804016386314, 0.06844950404258505, 0.015003603128265711, 0.0397050156137876, 0.05428964812909404, 0.02942959702904186, 0.017661222467018713, 0.020449941474643928, 0.04489218545777183, 0.057446378538565296, 0.06447691680683244, 0.12179847280945509, 0.12951773561296925, 0.14032875307865683, 0.174481887370348, 0.1577997712358352, 0.17844447715868875, 0.17525076385467284, 0.1388330736588086, 0.10443584843268318, 0.1117059538861917, 0.1663775964369697, 0.19807115948248297, 0.13612634712649932, 0.15576528685708202, 0.23880099006477865, 0.1033622298329588, 0.15545676792821578, 0.18545795081844255, 0.1497944895057909, 0.3744325516445022, 64.91452032519926, 98.84263792345601, 80.03762645106163, 64.95633279123615, 53.58724086515365, 35.26439066856138, 35.04463987965738, 43.20561347469207, 65.5678734471721, 71.43274645651542, 5.8754942974736615, 0.2416797186578474, 0.18255211803461277, 1.4298420687836986, 2.113995970256867, 8.482157857187334, 13.105805650834116, 3.8215566787027546, 26.311878850383145, 78.73570549872615, 72.68974842563753, 70.26891646846649, 64.7896908944653, 64.88262361095798, 64.93248478058847, 70.62869979489234, 71.77593031237203, 71.15074373060658, 68.32710789095971, 63.06175347297423, 55.21428315870224, 50.08246583323325, 56.42012565366684, 62.72650457197621, 64.54531938798966, 57.71415479721562, 52.95331132027411, 54.73756221032912, 61.43713520419214, 65.53210927594093, 65.98227577824747, 65.2422147412454, 60.69723106199696, 63.279645058416556, 61.73084228269516, 56.581221319014034, 54.72650112644319, 55.559314450910016, 53.24507290317167, 52.15393620152628, 48.99318833504954, 48.5505174821423, 50.99410703105312, 48.26233702321207, 45.856115894932906, 44.75452607677829, 48.65967312166768, 52.28991300828996, 53.92793793832102, 50.45357696471676, 50.871062278747566, 48.28207046754899, 51.73061440067907, 51.234493409433675, 56.30353712266492, 57.84777425950574, 67.60393265754946, 47.1616611173076, 50.721557217259566, 68.01522454907818, 55.111807315580315, 58.52777596442931, 60.383641489090465, 65.37278652191162, 62.288866120000044, 57.03860498243763, 58.86477032015401, 64.51494063100508, 56.3669579259811, 53.93895979850523, 56.28294467926026, 63.31233409143264, 61.295478805418945, 55.654675114539366, 63.83302480943742, 63.07219090000276, 50.75112012124831, 47.240594894655295, 46.71400493191135, 48.3960113986846, 49.41098743869413, 56.97645894942745, 61.67214009069628, 64.4322374559218, 61.81449859373031, 56.27594324850268, 67.72867971850981, 65.42661320778632, 62.87487214611423, 53.68075409243184, 50.34086373544509, 56.656224881449056, 68.77807063441124, 65.62069600628269, 65.82716957215341, 63.10960638907648, 66.17964944531842, 66.22027735556325, 68.60206604003906, 68.94731306260633, 68.03533846332182, 64.9675468475588, 60.5204890620324, 57.889037593718506, 23.314736966163885, 3.1665904819965367, 13.868440908770408, 22.088184356689457, 10.402916054571829, 1.2584054421993995, 0.180124324115534, 0.10334477835004369, 0.14896820239242048, 26.293983036471953, 45.8476004292888, 54.684186597024244, 49.749480139824655, 35.52191780459496, 31.79760575294495, 43.30215477174328, 59.32298160368397, 67.27820334895965, 74.85954084704, 50.40016212771016, 1.8804581727712386, 0.2423344940067299, 0.2617601088939175, 0.09744493606229944, 0.10198943091616516, 0.18412235313125197, 0.13601432975021102, 0.21502811732071064, 0.2008471403631472, 0.0671433854187208, 0.11027923004040796, 0.15745474055649775, 0.1322594417199012, 0.045778775182102, 0.19398545936471034, 0.12443313345072732, 0.15232696167884335, 0.1876826088635191, 0.2629685359856775, 0.13202685742608963, 0.21370178929740385, 0.16287930189601837], [0.03163223387673497, 0.04593557805844373, 0.031231025969910047, 0.03584093707163007, 0.01049391069119015, 0.05405529800261702, 0.023571157963165355, 0.05976571355976405, 0.07681156824072523, 0.06032969599830047, 0.04458752378160435, 0.06339523130126538, 0.04248563515683336, 0.040004962018781134, 0.0360159421970527, 0.02097789479810144, 0.05133107402211717, 0.08422113233996976, 0.16764796939828705, 3.937957916528948, 64.28943572505828, 65.06935196538126, 58.87814952481178, 53.49861883348035, 39.85129664021154, 23.57799860738939, 30.58082376756976, 41.26448346722511, 36.71034497599448, 18.893227538754864, 0.2613163907681742, 0.15150173176680842, 0.07944001590893154, 0.29764780414200603, 1.5666940543920764, 2.9872979608274277, 2.0026310557319276, 5.252526306336926, 62.055563542150686, 70.53143285935926, 68.36528824221703, 66.92201291361164, 64.36912651984923, 65.59074086527671, 66.55829152753277, 64.74892570126441, 63.525871845983694, 64.54097340183874, 63.65220354449365, 62.40182645859257, 53.26757161848007, 47.44969644854146, 55.18379065298266, 60.00795687398603, 62.07656783442344, 58.109768975165586, 50.03749585920765, 47.931881258564616, 51.67198673371346, 53.99448487066454, 58.02802285840435, 59.08760409201346, 57.57025088033369, 56.432037891880164, 58.773441853061804, 52.82128041790378, 54.8381043249561, 52.90887086622177, 56.06500210300569, 50.7744856803648, 48.281650773940555, 43.12137273050124, 44.599498318087676, 41.97441677893362, 43.695093893235736, 41.52277154307212, 44.842732337213334, 44.514959473763746, 46.435014586294855, 44.184644914442494, 45.31376192646642, 42.85392592030187, 45.883733303316184, 43.62175733812394, 51.96638414936682, 54.84477235424904, 63.23100374590967, 39.98596337533767, 39.065826323724565, 61.736372824638124, 52.936080348107126, 48.83084143361738, 48.78206676052463, 56.914285459826075, 57.455941246401885, 57.944543054026944, 53.61487396301762, 58.08850580646146, 52.45850432303644, 46.48752335579165, 47.06105624475787, 59.080994898273104, 57.4391495796942, 54.09086535053869, 56.71755506146339, 59.8936511624244, 47.87370466416883, 45.486644314181426, 41.10280336872224, 43.6649190995001, 48.24594936063213, 51.41818192697341, 55.5509441129623, 59.22842502593995, 57.783804324365434, 53.51811301323676, 58.980213519065614, 60.90505784557712, 58.86067144332394, 49.682788079784764, 46.581381751645, 47.71071057165823, 56.98653159602996, 59.785476115442094, 61.478539743731105, 62.96447477033062, 60.26277365223054, 64.23059625010337, 62.162836443993356, 65.39139032363892, 63.77282034966254, 62.497367551249845, 61.64471095608127, 55.29099295216223, 44.11553275200629, 14.478399868934387, 0.14320469311168119, 4.125994136256557, 8.009917236143544, 2.7479921954293407, 0.24267466768862742, 0.0776112491204854, 0.28880672048657174, 2.69344158710972, 25.006190461497155, 26.28171190138786, 36.735063752820416, 26.18264459794568, 18.500508069992065, 28.845463260527584, 46.184743835080056, 53.24355494591498, 55.75714311292095, 50.10114415999382, 4.585039904040675, 0.14029506053174698, 0.0496587960139638, 0.03542990408717625, 0.09840979315941373, 0.0402817189423067, 0.02467009193834759, 0.04793961427264637, 0.02928579083433555, 0.07346506636109083, 0.03809074578326076, 0.047916317538869, 0.03882757680971296, 0.05404493666344112, 0.04300569011379154, 0.04372708063812987, 0.014973296689981175, 0.01984772358780667, 0.01951591750126212, 0.05501738952232465, 0.05713615506406754, 0.05421940935775638, 0.041772254081743385, 0.04939107509750513, 0.004422258822277429, 0.009499612835145766, 0.04683069051093152, 0.022993211656989112, 0.06085825070077854, 0.05502813773590231, 0.09857335293124761, 0.05898350714555672, 0.03824607777078787, 0.06307461967451439, 0.05869727754484742, 0.025060534394616564, 0.03126056248983068, 0.021744834995197675, 0.0351364349555825, 0.036346643201766476, 0.06574950376225096, 5.531540186174455, 75.87904330222838, 72.65907549089002, 69.83670265443864, 60.25512503039453, 50.24509514531782, 29.9422069903343, 31.507513138555716, 39.72578863943777, 41.64715774597661, 24.61805428228071, 0.18576919702031922, 0.28776444254382966, 0.31833438443080075, 0.9564154210590547, 2.92663679007561, 3.4506830957628067, 0.6124678674724795, 6.40832131908786, 65.56536313026183, 70.99268790214293, 73.14715170091199, 67.44061300831457, 67.48264512708111, 67.39782779447495, 70.08194492709252, 65.89299478838521, 64.81117371589907, 65.36803653163295, 66.25209562240109, 65.1261478854764, 57.33425363417595, 49.6016695422511, 57.77630083022579, 60.81625538487589, 64.31552340907436, 61.290791573063025, 53.28828957773025, 49.55603668766637, 54.38414489069293, 56.50153836896343, 61.31698516107375, 60.95636636980119, 59.23193554724417, 57.332806279582364, 61.182718507705204, 55.05087721732355, 56.88524030870008, 54.83680209805889, 57.48657887981784, 53.40414462550994, 49.553781324817294, 45.55311672149166, 46.639679939516135, 44.425556890426144, 45.208901282279726, 43.940022376275834, 46.23930400417697, 45.95847014457949, 48.10662284974129, 46.80848306225192, 47.59428678020355, 45.247787660168065, 48.64738825828799, 45.559902421889774, 54.11631761058685, 57.715147156869214, 66.1470780834075, 43.17490523861301, 43.13758388642342, 62.52722071063135, 54.808106037878225, 51.408705480637096, 51.67512855222149, 59.28788423538209, 59.45225115745299, 60.08450977263912, 57.04515141825522, 61.28995610821632, 54.97554417579405, 48.551447083873136, 51.15552433075444, 61.68624493383593, 58.515287137800655, 53.76623430559712, 59.029988396552305, 61.867070121149865, 50.49192990026167, 46.68731320288874, 43.0248353558202, 45.357641481584125, 49.61465650989164, 54.73727195493637, 57.54594395237585, 60.574405962421054, 60.46914131410661, 53.4608817100525, 61.358056299148075, 63.11073210931594, 59.80972420784735, 52.9823015582177, 49.08685845713462, 49.770107884560865, 58.546454291189875, 62.423646603861165, 64.4635065909355, 64.9764310159991, 62.67399188010924, 66.4964828183574, 63.25132554577243, 65.52311135876563, 66.62386571207355, 62.64435445108722, 61.79957789759483, 58.36317370014807, 50.484034169104795, 17.86946931192952, 0.4434202707582905, 0.7001835252008131, 2.8990720885415233, 4.865638421427819, 2.1697936471431487, 0.061084227486243176, 0.3412674715922725, 3.2672527192100405, 31.924492466834288, 28.268157051455592, 35.78407333743188, 27.545399550468694, 21.35383232947319, 31.587660889471735, 53.66927331493747, 59.51347543347267, 61.33423182272143, 60.76864957809449, 8.13642446071871, 0.22316440008580687, 0.09171910298567626, 0.011810947983195225, 0.04530041839086241, 0.06475155166680775, 0.04515825545475368, 0.047284099648916916, 0.05628647162548958, 0.09699306676104184, 0.03933576889516365, 0.06041776929651538, 0.01520715747779656, 0.05014589386841944, 0.03678207991704826, 0.023152228527432008, 0.038101451862002575, 0.04036704198487344, 0.042415101441644856, 0.032099767760824294, 0.02729535842644832, 0.04733026793767368, 0.11558156205160965, 0.10905083103646195, 0.09555651400718959, 0.13518850228959514, 0.14488207326541025, 0.11993273461778318, 0.1095327233234721, 0.15245157354060682, 0.2400124661864773, 0.188758609996688, 0.13900355886547797, 0.1634634899035577, 0.09678161117218195, 0.1790126539286106, 0.1511984222358273, 0.14485809471338026, 0.09564188684547141, 0.2474487590934, 0.24843978575400769, 6.941051262040292, 84.95852224288448, 80.3138005348944, 77.48585793279833, 71.21525887520083, 55.32799659236785, 32.39695960475553, 42.125843801806056, 57.107724989614184, 52.669316030317745, 30.09987842652106, 0.43312067826909406, 0.4097473969863307, 0.45488140575828095, 1.2911425242500922, 5.26134918774328, 9.770550554798497, 5.506414953739413, 7.356164032413114, 68.73598360246228, 72.79487579099595, 76.48460234365156, 72.46800115031581, 69.99327582697715, 70.8818260315926, 71.68290738136538, 68.34300917963829, 67.71519460985738, 67.60199500668433, 69.20238479491204, 68.95164335927656, 58.425307966047725, 53.002313490836855, 60.729723976504424, 64.75002788728284, 68.45030953807216, 64.92818194050943, 55.785415557123, 51.37340022671608, 56.1615590895376, 58.5422848116967, 63.668045997619636, 62.958116608281294, 59.05819416046143, 59.69503410400883, 64.15552992974558, 57.09603240413051, 58.96075856301093, 58.258564087652395, 61.595995118541104, 55.010814128383515, 51.06056767125284, 47.13986450626005, 47.57602814705142, 47.910931879474276, 47.83838372076712, 46.90469095783849, 49.85693347069525, 49.98417908145536, 50.56409366669194, 49.7441888624622, 50.01569924816009, 47.677868566205426, 50.688291595828154, 47.904483502910985, 56.832119649456395, 61.95541366454094, 68.88501013478925, 45.60117360084288, 46.56274264858615, 67.54916068046325, 58.54259075657014, 54.125288071170935, 55.51068882788382, 63.047468200806655, 63.99381452991117, 62.67887523097377, 59.932557152163604, 65.20758413499402, 57.30300018864294, 51.04846323690107, 53.12158884540681, 64.6370400920991, 61.64956292798443, 55.94470693219093, 61.30748910288657, 66.83914107661094, 53.1217888862856, 49.515091065437566, 44.98638914477441, 47.83504578375047, 52.39771935247606, 57.51018370351484, 59.915118294377486, 63.617863193635024, 63.15048533101236, 53.869063162034564, 62.64450742352394, 66.10701499446746, 62.616399718869125, 55.92365949384628, 51.61561442959694, 52.36130799016645, 62.028095183833955, 62.712482098610174, 67.9383304042201, 66.87804314397997, 64.9691197179979, 70.00976547118157, 66.01213285999914, 69.10856954513058, 69.58341952293151, 65.8855579745385, 62.47605339173348, 59.146780890803186, 52.86960401842671, 21.048160060759514, 0.8093512995589165, 10.904763706268804, 20.50937152677967, 8.419676461527425, 1.2498604362049412, 0.21442845433710084, 0.4553688828262591, 4.593228832367928, 42.09115043763192, 41.86278612382951, 48.122747713519686, 36.85856742243613, 25.509689431036673, 40.345530971404045, 60.603855117674804, 70.38204546897643, 69.03314236671694, 70.97642575540851, 11.070118085030588, 0.3492514254345048, 0.19288676670722424, 0.08109657379287867, 0.2365220317076291, 0.13932275706000868, 0.20184230389854602, 0.12741371343332913, 0.2222216829297043, 0.2149741847308413, 0.08193052944637115, 0.1105006447722835, 0.13564594871094152, 0.2065163135768906, 0.13169146413283964, 0.19555143501249053, 0.12164731600111532, 0.11987904717604961, 0.13245994225144386, 0.10496550630177222, 0.10710594064045338, 0.15869169676255795], [0.04331299862373741, 0.04352602086240246, 0.007979943371948697, 0.019556083491132147, 0.03011255100699923, 0.0383700039838591, 0.024887940530935605, 0.0335164271265028, 0.04711817266539701, 0.04341873024860698, 0.09853363127237368, 0.07731709434019943, 0.029936645728265567, 0.14419567380701342, 0.04282102461964373, 0.02042323564960351, 0.019652993613553625, 0.10860053221544913, 0.13539640323048638, 14.204111464561956, 85.9246333952873, 70.94863968510782, 64.96540915581488, 48.19902604626071, 27.772200799757435, 26.605956592867454, 45.13567847590293, 38.07083083737282, 46.40238831120153, 7.856590315218895, 0.15063032207469787, 0.0403285920319538, 0.2141621162093455, 1.1224945802842419, 1.9015960707779855, 2.162670622910223, 1.273774023978941, 39.03196450202696, 75.07425923501292, 67.59316967379662, 67.31835273004347, 65.06408422223984, 67.70286267803561, 66.85181817700787, 68.90181356860747, 62.046298903803674, 64.5721209433771, 59.324632921526515, 63.79735869746055, 61.73693372357277, 57.14370489120484, 50.91860140523603, 56.20322642787811, 60.428195691877804, 61.02421552904191, 59.416753707393525, 53.655317521864376, 49.50938009446668, 49.28047057121031, 50.703318195958296, 56.1033824951418, 60.060897104201786, 57.42689217290571, 56.94369146900793, 61.36232776026572, 55.262406718346384, 58.77764271151636, 56.85586960084977, 57.93073238865022, 54.71681287211757, 51.80948149773383, 41.215312634744954, 44.83443260192872, 41.96661126229071, 42.43800955434, 39.89507813607493, 41.765856512131236, 42.210723892334975, 44.62085170130576, 42.2272253036499, 45.04280067259266, 42.23867862455307, 46.265289706568566, 45.90123099665488, 52.20162830045147, 51.926242613023334, 63.94027025468888, 38.654404993980165, 35.6785302008352, 61.35123529741841, 54.58374646402175, 55.208368224482385, 44.26182931469333, 49.193511624490064, 54.63843214896418, 58.284592936115885, 55.661413746495406, 56.369260357272246, 53.76418682836718, 45.491280555725105, 46.48265961677798, 56.3495582918967, 57.76779713169221, 52.17859614279963, 55.45373209061162, 56.96140097033594, 48.12161807091006, 41.76219694076046, 42.32753207606655, 45.39739470328055, 51.311567983319684, 54.8160998282894, 58.03511842604607, 58.700073918988636, 56.51725138387373, 53.77052930093581, 55.738213754469356, 60.434134160318685, 59.225863718217425, 53.896535442721465, 44.72584962844849, 46.13681247157436, 52.17895700085548, 61.45839052815592, 60.40966641518378, 58.7446241994058, 58.927100704562285, 58.10417959767004, 61.20631940903203, 62.289325037310206, 64.00651124215895, 60.339091208673295, 62.85946899844755, 68.59109124829693, 66.2186142706102, 60.6203761408406, 15.478123772528866, 0.17478033990388916, 5.213857129696877, 6.881160591879199, 1.5950742411998011, 0.31809153455880385, 0.10794057811219847, 0.23013904840955812, 11.448395386818918, 33.141411735165505, 35.23722041037775, 28.488037278575284, 24.02362692740656, 24.267843500260387, 33.26183242182578, 47.57217245717203, 55.693808601748565, 58.985971558478575, 20.532093817187896, 0.3908407147372923, 0.08013333314128461, 0.03964466320711278, 0.05867255588753089, 0.015958172622166814, 0.02794220859575416, 0.012474438539826343, 0.08559848181903364, 0.06401634857719464, 0.018413451860748956, 0.05328550987366227, 0.059935708470161886, 0.043058676585074396, 0.03597967942515689, 0.02821706753644732, 0.01148513078899874, 0.02821616355269667, 0.030273984884843234, 0.04498801539622007, 0.07904862158841665, 0.03690131767202289, 0.073696723688514, 0.026504771010349357, 0.02486670074323493, 0.021480377613296433, 0.05498234099978882, 0.033972410319913784, 0.007903277122926327, 0.02404258357391002, 0.061615758440307075, 0.024104464325993776, 0.10662256214287012, 0.09813574052626088, 0.05122521599274009, 0.11419352564600208, 0.02222961351846255, 0.033403448309869535, 0.07745358056478924, 0.06614128112672799, 0.13473290980102556, 20.80493780874437, 94.95752242303665, 78.08969897608604, 74.55568267453101, 56.831727412439164, 37.42771510154971, 30.114012687436997, 32.95407933573569, 34.49698286671793, 48.27070736115979, 9.805344920004568, 0.12070005594362175, 0.21454322962991654, 0.9183399932038401, 2.223637003091074, 5.738946295553639, 1.9827425551991311, 1.1143489206029524, 40.5334674158404, 78.19986266474571, 70.27296435448432, 69.81119940357824, 67.32985311938872, 70.88021785982194, 68.09870827582576, 70.80395913893177, 64.85925412947132, 66.23322902187225, 61.33629106706189, 66.0132154341667, 63.95824255481843, 60.41604418908397, 53.58435007833666, 59.289814041506865, 62.2426841335912, 64.12082872083111, 60.497958967762614, 55.63781284516858, 50.955252032126154, 50.283452003232895, 53.09273981278943, 59.83629434339462, 61.69806695753529, 59.79546246990081, 56.74401929301601, 62.522572701977154, 58.06772116691836, 59.80933981557047, 59.78893956830425, 61.705229205469934, 57.046963553274836, 52.98484717645953, 44.529778188274754, 47.91077106229721, 42.988086669675766, 44.871593136941236, 42.583176474417414, 45.31502100729173, 45.44154882431031, 47.7156174567438, 44.851914605786725, 48.30219222653297, 45.81718637097267, 49.36887687252414, 47.71360135847523, 54.224182790325536, 54.39251130627048, 66.3740421110584, 40.58335211969192, 38.600907787199944, 64.66220994149485, 58.000338769728145, 57.375858214593705, 47.19169078334686, 51.75430159414969, 57.20283069918233, 58.947697070337114, 57.54734031615719, 60.57905397107525, 55.1235548142464, 47.16949016817155, 48.513796252589074, 57.97546702046549, 61.95033811753797, 54.36698844355922, 57.93963224657121, 59.447414875030525, 49.414168480903875, 42.95210284571494, 43.300597590784875, 48.3794197728557, 55.51540351683094, 58.194543161699855, 60.086557249869074, 59.02030798696703, 57.97804794003887, 53.04209024675431, 56.62157858571699, 63.29428726626981, 59.75718405938918, 55.048610087363954, 47.79206445140224, 48.377905737969186, 55.43726990299841, 64.47440685764437, 63.29395778717534, 60.8511919360007, 61.5790504793967, 60.782958384483095, 63.528578281402595, 64.53367387094806, 65.64943129016508, 60.53344072834138, 63.63537657645441, 69.03460933316138, 68.86350770150462, 63.341826392758286, 18.553664030567294, 0.07832881303564196, 0.5030795823662512, 3.5406747700706607, 5.095551090855753, 0.7424229780031789, 0.09736170827020561, 0.0489029047199555, 14.361474014097645, 42.566365195858864, 35.408349498625725, 23.128508713937578, 22.079916000366214, 34.62305961116668, 42.0764886179278, 55.947695778262236, 60.649927277718824, 66.35294760427168, 28.80929312398357, 0.47330876211485556, 0.05543362807422396, 0.028786833938812057, 0.04242676896073165, 0.03647596650426427, 0.054754395368358785, 0.06763615615425572, 0.0957005538587128, 0.06916541320782515, 0.03954604853905978, 0.04929204291153339, 0.021397546271703417, 0.06861708577602141, 0.06148294177687457, 0.012741146305005157, 0.04067981653215905, 0.02406355714605701, 0.0851201365191129, 0.023354253573944012, 0.022435149162887566, 0.04970161649849146, 0.1247758275618957, 0.12216444067176312, 0.08180238591927676, 0.07705300085006223, 0.1162235820365529, 0.1473061593189355, 0.17038052841540308, 0.10528930868472784, 0.1662105433042011, 0.10126567701058042, 0.1633786533268229, 0.18869036688439308, 0.10112182868103828, 0.3871693762560045, 0.1812657951227119, 0.1700224129543189, 0.1480127222114994, 0.23138050921261313, 0.21171489430050697, 28.750137898229784, 106.34745782421481, 86.83037142599784, 85.28847202177971, 66.59278485082811, 39.679504671404445, 37.76340330800703, 64.88227059764247, 50.06869046918808, 65.17946466322869, 11.85320261986025, 0.2523217984144726, 0.47689610671612526, 0.8603051557175575, 3.168229542432293, 6.965170406526135, 9.91337581988304, 3.0655418913210593, 44.73174102844731, 77.39992664706323, 75.71889292809271, 71.07564603128742, 69.78893603048017, 72.35233045393421, 70.3052846847042, 74.51988712433847, 67.38795126638105, 67.91877346654093, 64.88135276302215, 68.98577582451605, 67.09982179826306, 63.06208295206871, 56.569473820347945, 60.70090240047824, 64.4460088975968, 65.26432514190674, 63.78226933940765, 57.23948524844263, 54.130402841875636, 54.46964471570907, 56.690325967727176, 62.059093675305775, 63.773326335414765, 59.47762104772753, 59.11743763954409, 66.07082720725768, 59.16816957535283, 63.241186218877, 62.68656699888168, 62.46467851823377, 61.25282695216518, 56.214491475013, 46.224642184472856, 50.40778721532514, 46.067912117127456, 47.37836030221755, 45.563703198586744, 46.6600017393789, 49.279493901037405, 51.027666830247455, 48.24418821642476, 51.67212793903967, 48.02106418917256, 50.52323041423675, 51.32654359263759, 56.07114845706571, 57.494682496593846, 68.99693104528612, 43.750254184969016, 43.01346440469065, 68.41030920705488, 60.763275930958415, 61.56025448153096, 50.58228169718097, 52.92814147087836, 59.650138655016505, 62.230834653300626, 59.13089136923514, 62.24752826075401, 60.176567800583385, 50.10103825599917, 50.31171660269461, 61.97202882459087, 64.23655433039512, 53.9502993706734, 58.63817107292914, 62.54718557480843, 52.196031078215576, 45.35112642472791, 46.66066069756785, 52.036453370125066, 58.24379244158345, 59.7925599159733, 63.04960197018039, 61.207229398912006, 60.632021657882206, 54.098494360523844, 56.46277358455043, 63.99870180314588, 63.927432337114894, 58.21226835250855, 50.0241284216604, 51.82435120305708, 57.225458852706424, 69.27556053284677, 66.9162078057566, 62.930871825064386, 65.78203485858056, 63.89814792140838, 67.36967302137806, 66.76117220232564, 67.53581677713703, 62.39066731545233, 65.84438093246953, 73.1527606902584, 73.22013916507845, 67.39327000033471, 20.75420783412072, 0.358376880927432, 10.266234201769675, 17.968158106650076, 4.7754351842787965, 0.6621561463802093, 0.32224216828903846, 0.34899236514203014, 18.780196597499234, 48.99443957113451, 49.58420715024395, 41.964912876006096, 35.73892293437835, 36.33482902280746, 46.36046994116999, 62.42606670625749, 68.09589201404204, 73.94332224322905, 36.9939088052319, 0.5534931320336558, 0.1473926966108622, 0.14937645064726954, 0.14987325866616544, 0.186823487221714, 0.1824328228230438, 0.21850842411719987, 0.20017587880213417, 0.15554555751863988, 0.14492207837681617, 0.13477414065311033, 0.17467250536766746, 0.16621317864666063, 0.2260085474699736, 0.09184332414259834, 0.12990293994305596, 0.11594130927997252, 0.1234266777793246, 0.06724934303952802, 0.1123186480253935, 0.10745639522229472], [0.04272943114741676, 0.04859455049999299, 0.06864887076399981, 0.06072989649950497, 0.07610197930086045, 0.0417093122978845, 0.0841143090398081, 0.0016861825039790523, 0.06716017040514177, 0.02539537035890164, 0.09206800240903132, 0.014883198046816454, 0.007092509993291911, 0.03264025619794284, 0.060205693176436814, 0.03796665869172543, 0.058333983329395135, 0.06333674431868619, 0.3010143315599811, 29.451834232576434, 75.28725962485038, 57.50769299845542, 46.23578956050258, 40.314081407362416, 24.324731596054573, 26.414670444303944, 39.93303098986226, 47.180715991604714, 25.57931346278037, 0.20933324951798687, 0.0395495955261492, 0.20976877050294032, 0.4733060041983282, 0.9342341725864719, 2.6645562725682415, 2.1151935189001025, 12.102500623272313, 62.202954446115804, 63.516489536531516, 67.3454406184535, 67.93498070009294, 67.76008221410936, 67.09402453514838, 64.66648924735286, 64.43764248201924, 61.045439474044315, 63.08981803155715, 61.430867256656775, 60.99988506686304, 63.83740609691989, 60.08807912949593, 52.858954783408876, 58.32690746553483, 60.67908225520965, 61.786057487610854, 59.571106818414506, 55.873088375214614, 50.16948361550608, 50.5765393472487, 51.23607412461312, 56.979110471663944, 58.032294319522, 57.3201487910363, 53.09554822983281, 57.01602389735561, 57.20904765590545, 57.99796573577389, 56.73927714747768, 59.95610314030802, 57.22472929185437, 52.126377628695586, 45.15164644487443, 44.39151463970062, 41.91019188973212, 43.65603100868964, 42.08012857744771, 43.26598267401419, 39.973635365886075, 43.23631778840096, 41.230429449389064, 43.85859004912838, 42.0789400992855, 48.792288457193685, 45.991574948833836, 55.182264850985625, 53.26309227174329, 65.10917578974079, 37.96272247068344, 33.79227807444911, 61.03221716419343, 53.17213642981745, 58.53544027574601, 51.73395626006588, 46.883910240665564, 44.91658664518788, 53.5026353405368, 53.80343406431137, 56.54131512488089, 51.78063638748662, 42.39939381999355, 46.11659265333607, 55.5076019225582, 57.78178038135652, 54.80223817210044, 55.19603629266062, 57.667439368463334, 46.26705869551628, 44.427012089760076, 41.40202137731737, 46.09445087371334, 53.31751515788417, 58.69812057864282, 58.455133668838016, 58.197339811632716, 54.837967042000066, 55.17218435964277, 54.131724680623705, 58.56622303685835, 59.3926428979443, 54.4180969269045, 46.06038901113695, 45.02870759656353, 48.26773420456917, 53.78317502237136, 56.495666580815474, 54.78778816038563, 53.8286784387404, 53.31812312526088, 59.088145379097234, 64.8020463605081, 62.705417909929835, 59.64661636660176, 68.48081773327243, 62.38816092091223, 63.13188937402541, 64.79346421457106, 57.82730340957642, 10.649007520368023, 0.13504479951675863, 3.7039245520868613, 5.176390649810915, 0.4012303991663841, 0.10095679802038979, 0.07616685162628851, 2.8045765526833075, 18.813652453884004, 35.03290414810181, 40.41639251093711, 34.832533790219216, 22.649340206576934, 21.946182789341098, 49.12821592823152, 49.94402577800136, 57.08086852104434, 42.17189242762905, 1.3694851268683712, 0.09773734416211806, 0.010599596350784264, 0.07185844974892755, 0.03748419949965131, 0.021431522271145257, 0.06375336208410802, 0.03339621260942471, 0.03354907013295639, 0.02874668327070052, 0.0702856635795005, 0.08845874769312721, 0.011317190909457785, 0.031164638705611713, 0.0497612564433967, 0.05553442226242154, 0.04273706138314259, 0.04644107351440095, 0.021895252528690526, 0.06219917269904287, 0.04066177899198186, 0.02040596994301004, 0.011403281955168614, 0.055653054807935996, 0.0582061538983497, 0.03701603550824427, 0.06145497190675909, 0.05027393014320443, 0.021351941057571003, 0.1155923102651873, 0.0549112327186571, 0.06823806377548365, 0.029712222186067415, 0.01131733167811387, 0.045125194930381356, 0.0683638554126505, 0.04196923826971362, 0.008392112081750266, 0.042147690790795514, 0.3811269956490686, 38.805855551073634, 86.66180364547238, 66.1692080959197, 55.18261394193096, 48.107756414721095, 31.146054960066277, 26.64212084585621, 34.604957872821444, 43.378307588638805, 30.072015870002012, 0.2261475617847135, 0.058985774765812585, 0.37992129583031903, 0.8563330817607142, 3.7771000448734533, 4.309470845806984, 0.7710698246955873, 12.096339560324147, 66.49490602554815, 66.85588175250639, 67.70678504820793, 71.6457546910932, 70.89216539936682, 68.47153740544474, 69.03853954807406, 67.23719104643791, 64.0005413947567, 64.07290127969557, 65.62285330987746, 62.76215891684256, 66.08715211191486, 63.82469369519142, 56.98639039070376, 61.228822046710604, 63.40194456038937, 64.75362862310102, 61.8038179797511, 57.93770244044643, 51.59683804358206, 52.895307310165904, 54.450456480826105, 59.73328113555909, 60.20687987727504, 60.12574565026068, 53.366933099685184, 57.804412457250784, 57.68616476366597, 60.86577530830138, 58.10450123202417, 59.84404886922529, 59.7318769270374, 55.168767975222686, 45.84489399386991, 45.56526430191533, 44.64620197972944, 45.4468204898219, 44.12202427464147, 46.02745286880001, 42.50203440266271, 46.83408044999646, 43.71419191360474, 46.390370168993556, 44.91261720657349, 51.019272958078695, 47.9782985871838, 55.78371324846822, 55.89232760090982, 67.53474989245015, 39.638680642650975, 37.98821003206315, 62.749419058522875, 54.96056856647615, 61.21659994125367, 52.883398994322754, 49.29140613925073, 47.505472552391794, 56.21287938087218, 55.300324270802165, 59.67651267205516, 53.42841232976606, 44.21964422349007, 47.9929486397774, 59.00488130507931, 62.11727811444191, 55.43675607250583, 56.36718150108092, 59.93928009463895, 49.02957224076795, 45.446749887158795, 43.86022959986041, 47.84013309786397, 54.928820902301425, 61.48176785438292, 61.20164002141645, 59.236724761224565, 56.3873307166561, 55.07694921185894, 54.35655493890086, 60.38914457444222, 60.97769621879824, 57.051333073646795, 49.58126537261471, 46.20031956703433, 49.59527607887022, 55.727662578705825, 58.54569335137644, 57.17640569133144, 56.59137241301998, 55.571736597245746, 61.25126977120677, 65.01567432957312, 64.67294939102666, 58.94752448604953, 69.55760248245733, 66.37534433795561, 67.44653578727477, 66.7683344502603, 61.57778355383105, 13.446404664747178, 0.40984680455538536, 1.690349348129765, 6.987235699930499, 1.1480412223646719, 0.45932511408482835, 0.07568561817489325, 1.8497317957301296, 26.688763710760302, 35.73378855182279, 31.187447732494725, 34.67943976002355, 24.248843539145685, 27.506393540290098, 53.80490495312599, 56.011175417131, 64.0562508183141, 52.220083052112216, 2.722255563543689, 0.0674161050588854, 0.03592789571191515, 0.04774150393542744, 0.015999295264332285, 0.03897405282083539, 0.010584893208297511, 0.009962133631380576, 0.014093821049637854, 0.029986403138947584, 0.04165596576527723, 0.06921672577699346, 0.017445861744964798, 0.04381907630651709, 0.03980446148723845, 0.020107622746558442, 0.04724729678503448, 0.022866018078920823, 0.07315951985337081, 0.04522757875102182, 0.009981190068497053, 0.08909325235553327, 0.22107766851061778, 0.13593867090680908, 0.21686545663302947, 0.2696669636474502, 0.21460767294610703, 0.23696225647243763, 0.1158301116177632, 0.2307441352956718, 0.2689649206736396, 0.14549050029487381, 0.13269983502405305, 0.16569081393461074, 0.09900338872666321, 0.15562740635247002, 0.14568528581050136, 0.3101461609044383, 0.19775779887793526, 0.5691961571574211, 50.91248250776722, 94.63898674134286, 76.20906368378671, 64.27700965635239, 54.724139859599454, 34.68840237586729, 39.343196730459894, 53.99003298051896, 64.7891809863429, 40.2718061016452, 0.5046493578101359, 0.17552194365810964, 0.7524337859884386, 1.80929571390152, 4.888557810937205, 12.248466726272339, 6.148831036783034, 15.210430833601183, 65.86291020916354, 69.26215387159779, 70.22022416514736, 73.85888145815942, 72.21576136927452, 73.83343312048143, 70.58094101567423, 70.92690190961285, 64.73293027570172, 66.40436987723074, 67.09518555671939, 65.41932152163598, 69.1292090569773, 66.48140522741502, 58.093118513784106, 65.01117929335564, 66.08019382722917, 65.42449905026344, 65.23988485336304, 60.1669736831419, 53.786234471105764, 57.08396719348047, 56.07530224707819, 62.91368792133947, 63.4411447278915, 60.683255657073, 54.37924192797754, 58.652495568798436, 59.32756685441541, 62.428973182555175, 59.82903011383549, 61.98618073617259, 61.82748556137086, 56.043134889295025, 49.23195085217876, 48.21951258567072, 47.78487474687638, 49.18231718001827, 47.44553481378863, 48.389672848486136, 43.62120820629982, 50.69458307758455, 46.061475507674686, 48.24938535690308, 46.41998406379454, 52.9274982021701, 51.90587374471849, 59.145568878419944, 58.656398327119895, 69.13575941516508, 44.14150276491719, 42.42308101346416, 68.5313613953129, 59.23110792713781, 62.982415691498794, 55.09174046977874, 51.552778059436434, 49.72019180174797, 58.15112252389231, 59.17390408054475, 62.39500937923309, 56.544123541924264, 47.47110474494196, 52.02072074336391, 61.651814368463334, 63.98698960581134, 56.73175796385735, 56.99234847099551, 63.65761249296127, 51.09524534594629, 49.38763364668816, 46.43981556738577, 51.136618506523874, 57.86893152421521, 62.84618393067391, 63.19639275150915, 61.2798716945033, 57.01737711506506, 57.84526394259546, 56.53286241715955, 62.56001564764208, 63.68846585673671, 59.35597658157349, 50.828885032284646, 48.82695044240644, 52.20143218194285, 57.72385874102193, 61.384085147611565, 59.664690648355794, 59.52392854998189, 57.93711800729075, 63.375346968250895, 69.04853374727311, 66.90591550642445, 60.41871532317131, 73.46457342947684, 66.84095321163055, 72.46242353993078, 69.7901362757529, 64.76784721497567, 14.487368368333387, 0.9249530480273309, 9.325933225693243, 14.551926658999536, 2.480192371914464, 0.21407263713978955, 0.2162841797596024, 5.0113431965151145, 33.045050867142216, 48.59998249238538, 55.45306528768232, 44.69253693857501, 31.127984600682414, 32.96016293187296, 63.76338312702795, 64.81520983480638, 73.25164364230248, 58.549843219018754, 3.9465792861676987, 0.24179167474710175, 0.18441833886167697, 0.21715923603023254, 0.1337767554627311, 0.09196798196963726, 0.2306910454025192, 0.28196886482258, 0.1609317225313956, 0.11546952169268362, 0.14638205809939295, 0.16453199869682714, 0.15441890265191757, 0.11015140060936252, 0.16384566052546426, 0.18351539699060304, 0.25641794797153245, 0.11751561996436889, 0.14888829942191803, 0.15080399420713225, 0.20385736028753942], [0.03838334540506044, 0.05897549003542912, 0.03665654108889642, 0.09779881505716233, 0.03866859058278703, 0.04733989766288189, 0.022432107793828173, 0.011516769262661618, 0.046209638352475824, 0.06823155202812727, 0.06335176347244172, 0.07428932334146193, 0.0164938347053624, 0.04388155460718178, 0.012306206589264256, 0.050587712096110474, 0.04461082434582134, 0.17151611586732252, 1.6056271330002816, 47.57433760550715, 70.68003577570762, 63.36681189075593, 53.75039185247114, 28.48466404022709, 23.871505645013627, 40.3377882126839, 48.68666295082339, 41.016774023732836, 7.74810883306688, 0.1356646872215694, 0.0726407480936858, 0.1375636046812419, 0.8857826660237006, 3.1452763224801714, 5.625736396158896, 0.48289662827887847, 40.67415498918103, 68.36263671998056, 67.40047931671143, 67.46767736250355, 61.65061020082044, 65.1299447398032, 64.19371420337309, 63.7705728315538, 65.99501563656715, 59.791496953656605, 61.03735939148934, 60.414184985622285, 61.47794354346491, 61.88375196149273, 58.55364399571573, 56.47864349426762, 59.50541888513873, 59.392183980634144, 62.71600046465474, 61.0615368812315, 55.62033084131057, 52.061721278775124, 51.342691990637014, 53.69853419642295, 56.97913792825515, 60.24608788951751, 58.08778016797958, 57.45002631218203, 57.0614488663212, 55.67220810920962, 56.7958769490642, 54.85398600178381, 57.51183894372756, 58.1537740461288, 53.05761106552617, 43.11631679534913, 44.8947782670298, 39.79796417297856, 41.4696704956793, 40.42991684329125, 42.58851089785176, 41.01817430988435, 42.34057787925967, 40.81933759873913, 43.705951013872706, 46.32029702586513, 49.89537662075412, 49.45216840313327, 55.27969260369578, 53.58240458273119, 63.598910300962395, 38.94882594385455, 32.54267565665707, 57.808578014373786, 51.48557216890397, 59.651527174057506, 52.92885141987955, 55.43801907570132, 44.31650323252524, 47.2847568604254, 47.410409988895545, 48.28793833332677, 47.387911273587136, 43.357005196232954, 43.85768398161858, 55.66464577951739, 57.18447008440572, 50.93263172334241, 56.63039999623453, 55.8122367243613, 45.423729496617476, 41.77517998603083, 40.929077671420195, 47.96963014910298, 56.25829258272725, 58.816070172094534, 57.29843454976236, 54.88617297141783, 58.05499699807937, 55.30624704976236, 58.13575075518701, 59.66851495927381, 57.678559287901855, 56.60993306867538, 46.95642702041134, 45.34705892685921, 45.5436049738238, 49.88498233979749, 52.081203691421024, 52.25282307594053, 51.056049100814334, 51.649582155289195, 59.406606535757746, 60.92320665236443, 63.59437996341337, 60.704263871715916, 62.77466735532207, 61.827689524619814, 62.754871153062396, 60.12988375079248, 66.74173293575164, 46.55068920504662, 5.35421718512812, 0.3512332642511014, 4.174734488610299, 1.4325395562956411, 0.18343489647151964, 0.12376068445343165, 0.32606709207738604, 13.92202833006459, 35.897657332881806, 35.67084235529746, 59.00474794449345, 51.676756335842995, 20.258367292342648, 37.114964915860085, 43.49903029780234, 55.90715023779101, 52.40883927191458, 8.771008060824487, 0.3077920646436753, 0.017927918740878665, 0.04227197706519116, 0.026043304542620337, 0.04909278727286766, 0.015226231151891333, 0.022813661714955684, 0.015238466533651997, 0.05738298093239146, 0.10180735479920142, 0.04308436351317552, 0.0251696789411888, 0.040094885419333176, 0.008466648606343136, 0.04183108963432812, 0.03799879224970937, 0.1499110727661079, 0.04024968114531329, 0.041615504831556356, 0.004570454221984913, 0.09035873001501446, 0.030884078155542095, 0.008018776368830473, 0.0408540555696574, 0.07960696178939074, 0.021965778582999786, 0.05949140428715657, 0.05065325091803267, 0.0464929300059955, 0.03368337683740162, 0.10862279473052872, 0.05374455741877037, 0.0665869451157989, 0.03575224707263612, 0.06303929919076544, 0.074442571569835, 0.014469023144263175, 0.10319516137843171, 2.1876617593149987, 61.24309555176766, 76.80406370470601, 70.9998187711162, 59.44264919527116, 38.92702148806664, 31.469038609535467, 35.42322312631915, 39.570772647857666, 45.90970331622709, 9.983627430854305, 0.012615923488122082, 0.03941603958786976, 1.0011266412273532, 1.2169489312556483, 4.999057842839149, 3.3414374868715964, 0.36804858775388816, 42.04207766440607, 71.15725486509263, 70.14064711909141, 70.95896336340135, 64.562330707427, 66.64714105667608, 67.5984884077503, 66.26667899470176, 67.567274185919, 62.31399674569408, 65.23260101195305, 61.61540300615373, 64.58706517373362, 63.15521178707, 61.61678760282455, 59.88699882261215, 61.499842136136955, 61.125761770433, 62.994939819459, 63.30432461154077, 58.837443167163485, 54.234824180603034, 53.47450017929078, 56.096259470908876, 59.890799599309126, 62.45906168414701, 60.72830015613187, 57.25607687427152, 58.59126344803841, 57.81773282635597, 58.131769549462106, 56.24319930230418, 59.1172101420741, 59.905688916483236, 55.52022018740254, 46.19052540871405, 44.68925783711095, 43.3773583750571, 44.98780512040661, 43.023921443570046, 44.33797036447833, 44.81249086318478, 44.95994452507266, 42.04916146493728, 45.738684054343935, 48.058801312600416, 51.63782288951259, 50.54066927202287, 56.155914798859634, 55.2576292714765, 66.61329100208899, 41.37382345814859, 35.45751640873571, 59.56110085210493, 52.54005039891889, 62.88528211655156, 55.6005189495702, 55.33214253763999, 46.260496570217995, 49.24748343806113, 49.58582316675494, 51.11949343835154, 48.17004365305747, 46.19292589925951, 46.46989230186709, 57.240826699041556, 60.05327986132715, 54.10700590379777, 59.51566019365865, 59.48753287715297, 47.06387250654159, 43.2813818993107, 43.2497440615008, 49.00614784609888, 58.513341642195186, 60.59401781328263, 58.65960290355068, 56.80915809446766, 58.7520335566613, 57.710726645685014, 59.770602487748675, 61.31828738797096, 60.89509894770961, 58.884135061694735, 49.75988618789181, 47.33358252433039, 47.03463515927715, 52.3602254159989, 54.54286752208587, 55.547280619221354, 54.67977000821022, 54.03064912365329, 60.49482891636511, 64.31840242878084, 65.55062678552443, 61.70693151412472, 64.35399401572444, 63.662287958206676, 63.139851785475216, 62.955170908281886, 69.06028516830938, 50.67470058318108, 7.507806295348753, 0.6180099313778262, 5.586578884432393, 5.2506038546562195, 0.4531371461287622, 0.10606064431128964, 0.21477510912283776, 13.210182862897074, 40.627890632998565, 33.0007908421178, 49.14524293714955, 49.57560539245606, 25.506198521583315, 41.60940885543823, 50.71168853390602, 59.99476986546671, 62.89369952294135, 13.012039430679815, 0.3501113744512681, 0.04958390325848615, 0.043310305824683565, 0.011922191610679993, 0.06692309683609395, 0.04056411427295497, 0.046655497693967436, 0.08386005211861865, 0.018373515697256215, 0.03361023459283095, 0.029139508260414008, 0.06520008082471548, 0.04486171048014395, 0.020690987209579157, 0.027929301929449844, 0.06433513691468586, 0.06777452695513926, 0.2154640366713847, 0.07596232147226412, 0.017767884888716282, 0.14856789080846697, 0.1579362421386665, 0.1256630493087634, 0.1708761106936201, 0.11352744283935717, 0.13542445737027353, 0.1120568834425461, 0.124361343351343, 0.17451568716956725, 0.16338773912960486, 0.20780746284271442, 0.1354332520596443, 0.12883150469391577, 0.20798069064415273, 0.16694751988735893, 0.12937668350435075, 0.148864382156922, 0.37585119326268474, 3.55238966403469, 77.39342335731753, 88.1982195761896, 81.7928792584327, 70.40121016963836, 43.10079989894744, 33.4636579790423, 54.902168396980535, 63.56891985862487, 57.72404309242003, 12.716464323382224, 0.34724206873966806, 0.12546109321016458, 0.8515990261108646, 3.1758016780499494, 9.554126916393157, 13.833771078817307, 1.8531561474646292, 44.245665227213216, 72.84859657287598, 72.81816682507916, 71.97445715627363, 67.87801219571021, 68.10739240338727, 70.84245327980288, 69.44603458527597, 71.87926907693186, 64.18473982041883, 67.60185380135813, 63.33116146825976, 64.80521563560733, 65.03474097098074, 63.78212421171127, 62.742182285554954, 65.32934627225323, 62.44930674952846, 65.90283993751773, 66.09443203095468, 60.33879703091037, 57.46163652789209, 56.75419784361317, 59.18148602208784, 62.65574501406763, 66.07762075239613, 62.163801347055745, 60.044854610197014, 60.365386778308505, 59.26431471301664, 60.12318434253816, 57.959032289443485, 60.23740768432618, 62.34516782145347, 58.96388861440844, 48.43448200533467, 48.066873550415046, 48.69368399343183, 46.630411378798954, 46.204159567433024, 46.62607323738837, 46.85587706104402, 47.98818688238821, 45.519717739474395, 48.06697553203952, 50.56974580211025, 55.382313574514086, 55.59794587473716, 59.76047100559358, 57.957286834716804, 66.79881126649919, 44.28780717234458, 39.31220216135825, 65.61420840601768, 57.230295135128884, 64.92200812985821, 56.084974811923125, 59.96128066893547, 49.49822095132644, 51.86572828600484, 52.571962802640854, 54.56278531782089, 51.313666451361875, 49.753865349677305, 48.002036771466656, 60.697682134566776, 61.702891472847234, 56.145873531218506, 61.82833279332807, 61.45982611563898, 50.397996979375044, 45.84839274806362, 45.71685214196482, 52.03483735361407, 60.80307622109691, 64.59393324390535, 59.42827370858962, 57.674531013734885, 62.25463951787641, 60.67997655560894, 61.034798083766816, 63.29815864562989, 63.4761401145689, 61.72783382477299, 53.34540713217951, 49.644544970604684, 49.069019517590924, 56.34780499242968, 58.55606409811205, 57.90919465403403, 59.508796045857096, 57.55300814105619, 63.57694110562725, 66.84969225237447, 69.62649499216388, 62.215910034794966, 68.92195101707213, 67.60428567086497, 67.73750505139752, 65.98144423577094, 72.01783857037945, 53.402218741755334, 8.55993551592673, 2.7452335434575237, 16.807364033114528, 9.057162615560717, 0.44788861647248274, 0.25360910191891656, 0.8109763865509342, 19.88838580346877, 53.75969571451987, 49.65722599337178, 68.41711059693368, 58.85218343427105, 29.45800412085749, 50.13824585945376, 60.567949741117424, 67.6539977904289, 69.69284580599877, 14.58057761192322, 0.5667195481158073, 0.21909052836558512, 0.2762741349156826, 0.10732133392124407, 0.2665565853878375, 0.1127007190558699, 0.10878251640186196, 0.16662423078331257, 0.10539328979869043, 0.2246284553961408, 0.10987376268472403, 0.20049729865164528, 0.1891071953239941, 0.09315815318616168, 0.15946533831377185, 0.18506088744728796, 0.3060768550682453, 0.30186619068826404, 0.13708918175149348, 0.0971127373556937], [0.03561877540402836, 0.0565214844180211, 0.026436144854092312, 0.027552514990431168, 0.02140443531736251, 0.039282939471905275, 0.05757732211702293, 0.09300760158728208, 0.027409848351512226, 0.030137199885962956, 0.11824516549466119, 0.04048524935158991, 0.03455363356718614, 0.009191550686204386, 0.027211711201215946, 0.04825965516389378, 0.011465157919202842, 0.0649301037793198, 15.019177044591597, 65.575086685919, 62.254490467809866, 58.49284333567466, 37.67798193039433, 27.85605322930121, 20.855289274646392, 37.86612233807964, 51.33545521766909, 31.944120007176554, 1.295420726941478, 0.06089542894774388, 0.03159368050194556, 0.5928620840272596, 0.41975097310158516, 3.699289291135727, 1.5069195844473378, 7.036667370027112, 60.30874383065009, 69.31004601140177, 67.7936420133037, 64.14373536263743, 66.72212108489006, 64.48225944272934, 64.63683220647997, 60.17170013919954, 56.3128762860452, 48.60572876468782, 54.62059713179066, 62.84877269498764, 60.52084599771808, 63.36461144108927, 57.43620387969479, 60.69142595414193, 62.21062267980268, 58.97845629722842, 60.611931277859604, 58.94295884716896, 58.99040383677329, 53.08047848363077, 53.54704441562776, 56.13355336650726, 61.48995384093254, 58.37241872664421, 58.97966438724149, 57.67921432372063, 57.339293879847375, 57.535883072883856, 58.38333076046359, 53.53728948100921, 57.45608637409826, 56.472430459914676, 52.6212630733367, 42.85202749313847, 44.26773248180267, 40.65525308732064, 40.13133818103422, 40.31716831268803, 42.06643166080598, 41.95866061795143, 41.75243808377174, 40.99336139617428, 44.78462242311047, 48.14550922762964, 53.61372078618696, 51.1185638366207, 55.083087721178615, 52.67663125068911, 63.79435023953838, 38.02504501035137, 29.972258229409498, 50.94252394091699, 47.49975765905073, 53.95186439637215, 55.72687418230119, 59.07838652210852, 50.689805630714666, 43.8113215661818, 45.000831311748875, 46.204336074090776, 45.85686899000599, 42.77161498223582, 45.383442832577614, 55.20966260663925, 54.99062176673643, 54.340441842232984, 55.58272707846857, 55.45646598262172, 44.078027048418605, 41.67538704410676, 40.2346416442625, 47.78655744368031, 56.17141600578062, 58.48604586816604, 53.06305139295517, 58.7901040815538, 56.72658043522989, 56.58251962354107, 56.87432435251052, 60.70741353496429, 57.42040065027053, 56.7603991108556, 44.70537093377883, 44.77593437317879, 44.660973625798384, 46.31210319457516, 48.65303254896595, 51.40015863603162, 48.17881407276277, 50.77952592603622, 56.50674335418209, 62.432722968439904, 60.07823790273359, 63.89324495869299, 63.13621182595531, 57.155876005849535, 55.14418255898261, 62.17646668034216, 59.22731499518118, 63.89382154710832, 29.436176130848548, 4.6603621590522035, 2.6777329848658655, 1.2430797613436178, 1.3648312346589182, 0.2557570439192557, 0.05729339078008648, 3.43579524947751, 28.40608523738, 34.35432626355079, 35.67510597167477, 15.29458430505568, 22.806378179980864, 27.1059803424343, 46.9637853868546, 53.981384154289, 53.88367791329661, 25.85851561638617, 0.8693449932240671, 0.04410591111668656, 0.03606949557339953, 0.07371774514115627, 0.0668472234880732, 0.07401101892032931, 0.060510983044702205, 0.0378634934614022, 0.06179274773345359, 0.05896401020788378, 0.023049344834420952, 0.017168152957193313, 0.01711294100049042, 0.017733364966848207, 0.0583633283273347, 0.009112349643762554, 0.051313189699524836, 0.035909628345360683, 0.04450241907409603, 0.039514589138449206, 0.02735162183882729, 0.1039317012914727, 0.019038104632448767, 0.030262792340269497, 0.03043278342022771, 0.0615716279454289, 0.02996060512809744, 0.06164925180435662, 0.04624131991858444, 0.08407254958705557, 0.04418328982747851, 0.04190331257338967, 0.03772080575506534, 0.04082348483103899, 0.05658752119709408, 0.008359503549253269, 0.058675045673284805, 0.160716742938084, 22.2875407818825, 77.34612741777974, 68.74232999740109, 67.68221532144855, 46.61811867067891, 34.13483827344833, 25.52693020912909, 38.2483769232227, 52.53944635391236, 40.75481853177471, 1.4054745892363212, 0.03394656251334856, 0.16019765708235004, 1.1808337078940485, 2.7182454303387673, 4.633301236937124, 2.0082074403762817, 7.565141541342582, 63.865156865889034, 70.65476786705756, 71.38976512416717, 65.83831694818312, 68.35518421665316, 67.00835212584465, 67.05087061851256, 61.645644480182284, 58.61680984497071, 51.141140999332556, 57.765918316379675, 64.26282636580929, 63.86880859251946, 65.01038305221066, 60.354243324648955, 62.724421793414706, 65.32119950940533, 59.23073530197144, 63.654054903214984, 61.490004831744784, 60.311383585776056, 56.702100922984464, 56.37036254329067, 58.431732808389974, 64.61485516640448, 59.08730599188036, 61.20216169664937, 59.02138271639424, 60.20396163386684, 60.12461993002123, 59.78917098814442, 54.53650543766638, 57.43223836345058, 58.95116052319927, 54.492496444332986, 44.840449517773045, 46.41454373636554, 44.40254826699534, 42.97329541175596, 43.161879047270745, 46.44056866245885, 43.95083242847074, 43.29885998079854, 43.25572959838375, 45.67540053398379, 51.35678506666615, 57.98669676626883, 54.20801085810508, 57.80064305951519, 55.82371750185567, 64.62996413630825, 39.41455248863467, 33.46685863310291, 55.845721998522365, 51.624220109755, 59.26682502992692, 56.876720920685806, 60.806080756648896, 52.710308720988614, 46.37087991160732, 47.21145560664516, 47.67617017992082, 48.611706456830426, 45.0104489634114, 48.687635698626124, 57.29167630595546, 57.24540410503265, 56.56573580157373, 57.82695824100126, 56.73148339794528, 47.33151151287941, 44.00392170875303, 43.745190405076556, 49.791641696806884, 59.53886885796825, 59.964042017536784, 55.446656134820756, 60.04263062630931, 59.021873012665786, 56.3604114901635, 58.183403630410474, 62.033849300876746, 61.35619317331622, 59.66651455048592, 48.302694289915024, 47.148226999467425, 46.39063689016527, 47.59320812840616, 52.043101787567146, 53.482850905387636, 50.05023571752733, 52.862626121890166, 58.37235204635128, 63.66348035873906, 62.66050677145682, 64.87442977966802, 64.56079313831945, 57.89562717560799, 57.341184462270434, 64.20134713572841, 64.45093539453322, 66.3521239065355, 35.45455501925561, 5.385963868710303, 2.1322585257791706, 6.3267600440209915, 4.036337089154029, 0.4335606578857668, 0.046433539039665656, 1.8518079552919635, 32.32131277361224, 36.77904921193277, 38.88120428208382, 23.26023759380464, 28.094564714739402, 33.99003613379694, 50.16405113281743, 59.67977608403852, 61.91444843046127, 35.461991833102324, 1.0368759809963166, 0.03970588129314204, 0.04921599719372969, 0.0896212631355851, 0.04048982289649787, 0.02592400358539195, 0.01927842641429555, 0.023864064020134752, 0.08464132390555837, 0.03212337667543081, 0.07876273289683365, 0.02027313795781905, 0.0655685537945359, 0.007322044778359875, 0.022602765370280515, 0.009474280222709621, 0.06113308474361416, 0.021493054453223463, 0.02106046758502001, 0.03226072474893543, 0.1653971264679586, 0.14552848293415963, 0.16882788269750534, 0.14286310982800302, 0.10397431110182118, 0.11118826231047993, 0.17704221450032728, 0.12271963991224767, 0.11959685102826166, 0.1705864222059327, 0.21104518023710098, 0.11791651377514487, 0.17030056415786668, 0.11086544052006737, 0.15379084844983396, 0.17051771944088323, 0.14433974430205362, 0.3647442053883307, 26.63193052814853, 88.88407737978044, 76.67446074947235, 78.43894681622906, 53.807164238345244, 40.33350498445573, 31.623887900383245, 54.31842950082595, 64.9237928082866, 49.10778430200393, 2.5316099870589475, 0.21446488947877962, 0.3048528304263469, 1.8831986837810086, 4.341697039142732, 10.63876130888539, 5.5271294809156855, 8.470098530092548, 65.91817640489148, 74.05001071191604, 74.86693843718498, 70.51763396109305, 71.56956657286614, 69.74711571970295, 70.61760733204504, 65.82316875457764, 61.104667263646284, 52.619380335653986, 61.2372669096916, 67.47720087728193, 64.36728692823841, 67.14867884112944, 64.87335112787062, 64.00468341765865, 66.96742611546671, 62.2925413808515, 64.6370400920991, 64.3444195101338, 65.24300313765004, 58.642332707681966, 57.849441266828975, 59.85918529572026, 67.26993499263641, 62.88692166728359, 63.31146332525439, 61.792258754853286, 61.89020033805602, 61.67894148057508, 62.17748649658696, 54.862175910703606, 58.02734428836454, 61.69141854009321, 58.2071182804723, 46.65261199397426, 49.7962857830909, 46.414120120386926, 44.62273836135865, 44.881791299389256, 48.413579694686405, 47.060946418393044, 46.73487978596842, 46.37823827805058, 49.0468071353051, 54.80079473987703, 60.319785302685155, 56.3215761030874, 59.62722416846984, 58.49995459279707, 67.46418645305019, 41.43873868450042, 36.87151124400478, 57.52347269365865, 56.10479454840384, 61.79535350491924, 61.62142776673841, 63.27519709064115, 54.94966437739711, 49.027673813604544, 50.27300673146402, 49.6322444177443, 50.99546024876257, 47.09905616698727, 51.233191182536466, 60.07677485865932, 59.7318063243743, 57.21216986256262, 60.208303697647594, 60.68120817984305, 48.56871727974185, 46.024503246430434, 44.1540268928774, 52.57714817600866, 61.51035408819876, 62.670297007406916, 58.07261236252324, 62.20552752094885, 61.17663098919777, 59.81671779386459, 61.01806525261172, 66.49103856855824, 63.401269912719734, 62.013241167991396, 50.682623770929155, 48.082135492755526, 49.58058288020473, 51.06541179841565, 54.606056905561886, 56.51776129199613, 55.48478549526584, 55.491171113906375, 62.854911204307314, 67.43878518381428, 64.80205812761861, 66.79402597488897, 68.43843260119039, 60.978033542633064, 62.66938309515677, 66.76621637036725, 66.31241383091097, 70.21610567646643, 37.705018827992106, 7.503666233631873, 9.089342721046942, 9.941284464251611, 3.9228494369214584, 0.5734464129613293, 0.177805375968737, 4.847859788325525, 39.736288824389064, 51.100226756065126, 49.601598939587994, 22.743922279727077, 31.599639807977987, 39.00830084277738, 61.301668305550855, 67.30379289196384, 71.70190734248008, 38.45474066272859, 0.9062424229998743, 0.1540703632898869, 0.33524013695216953, 0.21792834234093467, 0.1370155913454871, 0.1947131203187089, 0.13662735330722026, 0.12589797017074403, 0.16865493068771978, 0.12839722477139967, 0.11962697360544436, 0.13961740979744544, 0.14815382028539337, 0.10195381548856536, 0.10319697700681225, 0.14793024518557135, 0.14503359013507444, 0.19952137924490437, 0.09933499754556727, 0.15602463826296792], [0.03347614239300451, 0.05539288368797111, 0.03133548205838569, 0.009146018250424777, 0.04594701575115324, 0.011925016559900777, 0.025564241035270597, 0.030755017238158374, 0.017666998769967787, 0.042726891565947764, 0.03752903479541983, 0.042960667126481576, 0.011034990931230207, 0.022759148813483697, 0.062078893064491214, 0.04637159700054796, 0.05261221434921027, 0.3194230260147203, 41.61803806981733, 69.86067618093183, 62.915433376066154, 62.23837737114199, 46.136196659457305, 24.542140729965706, 35.95813635856875, 40.822946179297666, 37.51880038169123, 21.507620619189357, 0.036135363813129165, 0.1722890066523706, 0.2849918784153077, 1.4704247491974987, 1.7578622867022793, 2.0537473838175497, 1.5638759539973353, 16.043782503374164, 73.02703303675499, 67.67885777258104, 69.20192979997205, 60.920629655161214, 57.3194270749246, 49.062508383104884, 50.46512442250406, 44.96676944917248, 47.57300007727839, 44.52980564486596, 50.59944206668485, 58.6705659281823, 61.5981210431745, 57.39547398782546, 63.93276676054924, 54.974783235980624, 61.113045446334354, 57.94677488265499, 58.40146780014039, 60.47100836230863, 56.9176822323953, 54.14845751177881, 54.82215204546529, 56.73859857743787, 59.89944450316891, 57.72868325633388, 59.672586379512666, 54.424764956197436, 56.48234228934012, 55.163241355649895, 56.78864409846645, 56.77879110459359, 56.68466206519835, 57.48812821603591, 52.74962263722574, 44.46709479055097, 43.04205848324684, 41.25397543753348, 41.98430115176786, 39.95134061382663, 42.36447295834942, 40.93873846915461, 41.90643033673687, 40.818207956129505, 48.11703674254879, 49.96649703671856, 53.422697436425, 50.024155878251605, 57.92733953845117, 51.76952823515862, 62.769348621368415, 37.58842637462001, 31.12527032052317, 55.31209922605946, 51.57758312840616, 55.86345503407141, 49.262506115821104, 55.83792824898997, 54.95323765662409, 50.806048993141424, 40.64799278013168, 44.02610663444766, 41.337345415546054, 44.38436415887649, 42.05901838118031, 55.593168427867276, 55.79787300479028, 57.38316166785456, 53.25118003352996, 50.70218463097849, 40.89984816889609, 41.43360822431503, 41.64515733718872, 46.264042392853774, 58.055518673312285, 58.74271792750205, 53.73903659082229, 57.08100188163019, 56.97794552772277, 54.219703443588756, 54.50931556763188, 56.72252078210154, 57.10645021930818, 54.45059376378214, 45.496112915777395, 44.29170208592569, 46.13077202150899, 45.34097140835178, 47.08425706432712, 48.98123295076432, 48.45265042397284, 52.54499258533601, 59.569965408694365, 61.52919715450656, 63.24796407453476, 62.87756289205244, 59.014479344890965, 52.95881440562587, 51.12783631970806, 59.703910427708784, 63.1610639633671, 64.33192676113498, 55.28444651634463, 18.456771681385657, 4.175047787927812, 4.970623110571216, 0.9649640429885158, 0.19210885038539288, 0.027959868837628635, 0.06480115585990491, 17.99852901889432, 37.87198628148725, 28.97290106742613, 34.15382254508234, 16.143645067368787, 30.909210481951316, 38.63967257161295, 49.585066149311686, 53.061592271251065, 47.518683095132154, 2.9237008960016313, 0.15823728404939175, 0.050246155625509645, 0.02744216960103762, 0.04107303797237335, 0.00589556033505247, 0.053388123520680016, 0.0396787426284244, 0.030026249287109223, 0.01113152567056879, 0.039722834818906365, 0.026584470967551874, 0.06464457514906122, 0.011293647112324836, 0.05102356632931098, 0.07673735730350018, 0.03761102535551594, 0.04870385592502933, 0.03681076990981256, 0.06922100054761095, 0.0077470947778032675, 0.017252167904629342, 0.0578365930836768, 0.025714216152987173, 0.021979164054256775, 0.079038126183854, 0.039749406578560034, 0.06522595927479767, 0.05346951653219519, 0.03749762902096395, 0.016730040679835988, 0.02663441415455553, 0.0804491988533447, 0.025019577418964718, 0.04903131254738377, 0.02122505966033186, 0.06099134698630341, 0.5143310237796076, 50.75121818050262, 76.54629338172175, 69.2084409344581, 69.64893094954952, 57.44903395252844, 34.202769802462676, 30.2192694910111, 37.65806805702948, 45.291071015019575, 24.875704972974717, 0.1349928434337339, 0.007342118197195833, 0.5598582808048495, 1.5750788560798092, 3.604241926823893, 3.846658131768627, 1.1274779515881692, 19.535878473712554, 73.88411014310776, 69.72464053861557, 70.43057303274833, 65.27473903471424, 59.96481080209056, 53.748509114788426, 52.80821108048963, 48.025586681981245, 49.30884891940702, 46.972230249835604, 53.39460542125087, 59.64246649895946, 63.861822851242565, 60.63330427292855, 65.23182830502911, 58.41048925153671, 62.02167818623205, 59.31123018264771, 59.963183018469046, 61.8405274421938, 59.500237434141106, 58.465673077491026, 57.20343474418887, 59.842044538067235, 61.917041117145175, 60.25903563345633, 60.10213298182334, 56.4164621599259, 58.75417909314556, 58.05374183962422, 59.40728902816773, 57.50586125158495, 58.41427041638283, 60.03017317864203, 55.05785511386011, 46.86520445731379, 44.904666562234205, 42.19193966157975, 45.18188007416264, 42.87973119366554, 43.946506054170676, 42.51803375059559, 45.092124477509536, 42.540603068567094, 49.62706688911685, 51.46597600752308, 55.524228849718654, 53.252619543383204, 61.110052677892874, 55.72790968802668, 64.2590569680737, 38.40842531573388, 34.49047565460205, 58.545383484132834, 53.50573009060275, 58.24031722161078, 52.6564428114122, 58.72336887544202, 57.389300177174235, 53.31785640408916, 42.91634259685394, 46.68811336640389, 43.12054511039488, 45.12690805619763, 44.15914950832244, 57.854885516628144, 56.867256241460005, 60.053468135095414, 55.63447098578177, 52.2781184411818, 44.38624689655919, 44.22816361150434, 44.53001745285527, 48.39047301200129, 59.77650957722818, 60.95267149709887, 53.04591063530215, 59.39387452217841, 59.48781921017555, 57.09039988056306, 56.455803532754224, 59.12594526044784, 59.80698639346708, 55.58333896821546, 46.99619593158845, 46.75631946133029, 46.06021642684937, 47.68853349070395, 48.132184936154275, 50.650495636847715, 50.82013814680038, 54.00262771114227, 61.00387803969845, 63.8931155204773, 63.96849955281904, 65.1423825756196, 61.590539101631414, 54.75083551099224, 53.50633413560929, 62.88629408805602, 65.84246681582543, 68.52091220117384, 58.93024252307031, 22.229195525569303, 2.173870215492864, 2.521005614149955, 3.6515594393976274, 1.4577252177461502, 0.06968549497786068, 0.09429148833958373, 19.84255486919034, 45.41054248809815, 28.707372296241026, 30.7804508363047, 17.881012847346646, 35.379147452692834, 46.76464665320612, 54.81569582416166, 58.94464154397288, 58.517342459770944, 4.956877654598606, 0.19589217559945202, 0.062380739367536964, 0.035840186305464275, 0.062454126760243416, 0.05622728367245967, 0.01614795558364882, 0.027478074226828835, 0.06685696812647005, 0.035766557595061685, 0.0804552126435503, 0.06276390590374509, 0.05620948744997863, 0.006277092231152159, 0.029751129876521808, 0.05549786454667488, 0.04611907909894663, 0.14318690455007937, 0.07803838910354723, 0.00886432484783713, 0.12878904810115216, 0.08505451342751903, 0.21102976654806446, 0.09415189945890058, 0.12567280926891874, 0.14936783981900062, 0.13080634146688447, 0.15047477558255196, 0.06198246174702241, 0.18372228669543422, 0.1973496731971541, 0.09600305133649419, 0.22963275622215965, 0.08756420980658262, 0.17041834251534554, 0.27189885356253196, 0.1442582019033932, 1.0160908511569424, 60.32360176886282, 84.70711400431972, 80.74789708660495, 78.64578124015563, 63.574258204429384, 34.925207630280525, 50.30125564144504, 55.330542210609686, 52.82656777289606, 31.451566411602883, 0.5010783155598949, 0.28091065225101286, 1.3450194654926177, 3.852817478679842, 4.4719319862704126, 9.885198493157665, 4.819278457472402, 20.130635307681178, 76.48780299771217, 72.21941701827511, 72.76429699313256, 65.77648078241657, 63.30554446866436, 53.7112505205216, 55.373433328443966, 49.48505747702814, 51.58312935982981, 49.59576245277159, 56.19411083959765, 63.603746583384854, 65.89470494178035, 61.39315366744996, 67.11700177961781, 62.305728389370834, 61.3864032683834, 61.19727442341467, 62.2696739627469, 64.01896868982624, 60.42033526205248, 60.74239323216101, 59.69459872091971, 61.16473051809496, 64.03737245067474, 61.62830368165047, 62.67011657837899, 58.58716064883817, 61.10003494447278, 59.59690032466766, 62.45289179586596, 60.70595049089002, 58.903123255698915, 62.02950331472582, 57.509458065032966, 50.09741006358978, 48.6128007981085, 45.576996111100726, 47.70160282811811, 45.49013130126461, 46.56047944099673, 45.25036857974145, 48.22387818367251, 44.541325646062056, 52.59259054737707, 55.282744207689845, 58.33314403410881, 54.985691347429835, 62.83281257075649, 57.19867690916985, 66.76775393947479, 41.92835246362994, 39.1969786151763, 61.29571414762928, 56.595271248971265, 60.28488797526206, 55.03244992225401, 60.621611687444876, 60.28791604503509, 54.57481522713938, 44.89296220964001, 47.36631470341837, 46.336927875395745, 48.957730108691806, 46.87746578647245, 59.11189533049061, 60.954181609615205, 61.45667253002044, 58.86570384425502, 55.50222043068179, 47.027978897094734, 45.84329366683961, 47.4522263773026, 51.07638659015779, 62.46360378880655, 63.229964317814, 53.27742461235293, 62.34247707551526, 62.29424368950629, 60.59933262486612, 58.996310926252804, 61.54920124238538, 61.459983010445875, 60.67239853643603, 49.61194222973239, 50.35614136726626, 50.01663669463127, 49.633989872470984, 52.73747113443191, 55.73009837058283, 53.433703607128514, 57.059122900809015, 64.5199534200853, 66.19284429857808, 68.87822443439116, 67.42261717396399, 64.47518348693848, 56.95683140908518, 57.08956441571636, 65.05814967616912, 68.39924812316895, 69.56847529257499, 62.73587511431787, 23.46801534775765, 6.371848179448036, 11.75916869794169, 7.317920432936761, 1.6759538818751614, 0.09552702728298404, 0.2314311016591326, 25.426270423396943, 53.896676648047666, 40.24595375983946, 45.633729273273104, 24.07699469597109, 43.9580927356597, 54.99031974423317, 64.99271669695455, 65.27753176227694, 67.0318785021382, 5.704680469728285, 0.34417094482529553, 0.2484316958655273, 0.2557565842665011, 0.23059703109245147, 0.22080002292510004, 0.1702992771301539, 0.12806061339835006, 0.13279631613723694, 0.13371252665115943, 0.16006156922348086, 0.14672213985073954, 0.15449473003466285, 0.10752555764009876, 0.18330639288310083, 0.22997573378586003, 0.11437288981171385, 0.3167687458617072, 0.272186289751722, 0.15808063439063488], [0.009168746163918367, 0.06412917800668268, 0.02143655163836816, 0.03499776154996888, 0.04211953705957821, 0.027855937519381126, 0.013571482193055413, 0.013285700753781826, 0.016857485151699474, 0.023414314867207603, 0.027788929723864122, 0.042960965900772044, 0.06382882174464964, 0.010997548383931, 0.038897133762798006, 0.030930593099084594, 0.05167522370034168, 6.499009949545707, 56.22363844225484, 61.01049507817915, 59.08921618615428, 42.10190949901458, 31.585111348859726, 14.818422294432118, 41.09131474648753, 40.85335631524363, 41.96981191635132, 8.066418978475756, 0.20460372910864894, 0.029723248106517622, 0.1619229483748636, 0.5921693566826083, 3.0724146193073643, 2.4036321188172987, 0.16964448645951288, 40.376572608947754, 66.97341949709, 67.47545934492543, 64.23852728259179, 63.001937327846406, 61.97283683284637, 60.21039824331961, 55.33907728810465, 50.603038880132864, 44.21772226210564, 45.38257598876954, 48.019169684379335, 57.810472519167014, 60.80792819300006, 58.69692817811043, 62.8942447323953, 66.64338342605099, 55.86626345111478, 55.82986385591569, 55.410589941086315, 58.27841520309449, 58.06171601818454, 59.14423527256135, 58.943056906423266, 59.31310899796025, 58.097841047471576, 58.36028291333107, 58.459558102392386, 54.51290453633955, 51.47268718288791, 51.87036060517835, 55.92422823752127, 56.63502447066769, 57.546916700178585, 56.799932679822376, 52.41307150933051, 43.8161382367534, 41.43688732577909, 41.73174758111277, 40.86895165904876, 41.61099741535802, 42.05689637891708, 40.31416377713604, 43.25682001729166, 41.85897358002202, 51.19503044313001, 54.14578245532129, 56.31445307885447, 53.87983006815757, 59.56343858472763, 52.801688178893066, 65.95705493803948, 36.453770975912775, 30.212538703795406, 54.505330439536806, 49.47934258368708, 56.54667308253627, 51.40247675680345, 53.04536150347803, 54.10623711924399, 56.62999206973661, 44.1412046647841, 44.44128167244696, 43.460928393948464, 41.23718769319596, 39.96690065630021, 50.80660989207607, 56.130317411115094, 56.25115779138381, 52.90407380750103, 45.69457307938607, 42.74316995374618, 41.247844772954146, 42.46781564527943, 45.167661482288, 54.94862887167162, 57.941758171204604, 56.17818993906821, 57.149349181882805, 55.546370629341375, 51.31597672739337, 49.94495145736202, 50.45067441078925, 50.319573110149754, 48.17999862855481, 44.19799666250906, 44.978101176600305, 44.43076972038516, 44.074034075583185, 43.62249082134616, 47.1874193222292, 50.780639879165165, 53.65358383424821, 57.003233048223684, 60.73038685706354, 62.98352572225756, 60.91829976727886, 58.63844171647103, 47.976364858688854, 51.58074848113522, 58.57764497880013, 63.341045841093994, 66.23434297500118, 63.87201316895024, 48.71235839782223, 10.553515457337904, 4.495073479990806, 5.784035901869498, 1.1574258607241417, 0.2539014563925805, 0.11032134189360565, 2.2021654584715447, 35.522447324568226, 45.21883272355603, 38.25880650551089, 22.349014128408125, 13.321058461743018, 27.975359962832545, 46.856453649459354, 50.172739182749105, 53.5604981453188, 12.937918401533558, 0.2697340116625832, 0.0331590547707052, 0.11015898487981289, 0.07018522179174809, 0.030375411095578345, 0.024277805125400908, 0.011462403833115054, 0.016156070369986758, 0.09885756389027643, 0.04266761168236694, 0.022237063723526174, 0.05330729358378918, 0.06337061689625825, 0.05296390999348895, 0.04902416494705024, 0.05491604758126121, 0.014264152081112468, 0.02126430825991256, 0.026853708738100626, 0.04682687922350822, 0.0432893188459979, 0.05187686953333117, 0.018689829570752, 0.12176140181479916, 0.015560085566023426, 0.038777796416393215, 0.02461994765326381, 0.01463096934340654, 0.08323585133879416, 0.03509494363360348, 0.04713611827502328, 0.05357581506212873, 0.09946286528100891, 0.0473820133465192, 0.03584759437569207, 0.04184867135219036, 8.058905678410685, 68.35676100946242, 67.96093894589332, 69.00182616326117, 49.501119582883774, 40.985489199238444, 21.04869350310295, 45.27487947094826, 39.52685386903825, 49.22576527441702, 10.189646001785032, 0.2907669249801867, 0.058564721351309176, 0.7902868644845101, 3.4593213806229257, 5.419779602558383, 1.991455119944388, 0.4838398050877356, 42.33994245529175, 69.90923512366511, 70.3994607925415, 68.59014203471523, 65.77713189586517, 63.861575741921705, 61.766841796136674, 56.10248035000217, 52.41942967137983, 48.34782115874752, 47.217672563368275, 49.81122609107725, 59.01725638297297, 63.13829852688698, 61.3156319433643, 62.92763586967223, 67.21909323046285, 59.808806373227036, 57.62044545142882, 56.80729104626564, 60.086000273304606, 60.31043829456453, 60.10063463641752, 60.28104405249319, 62.5865073357859, 61.03129148483277, 60.574421651901744, 59.94411245469124, 56.31834014769524, 53.29685995655676, 55.643476747697406, 59.12053238961005, 58.759623342944735, 57.37319884761688, 59.82242484246532, 54.21604779458816, 45.15716129733671, 43.02630232226464, 42.700325904353974, 44.332832059552594, 44.01727737918977, 45.38282702046056, 42.60616940836753, 45.0616672731215, 44.91975984265728, 53.39106352098527, 56.05993832311323, 57.793610249796224, 55.98544859117078, 61.53008753253568, 54.31768817286338, 65.0387849346284, 37.07451743464316, 33.69207328365695, 57.36657396439583, 52.065451452809, 57.27242923551991, 53.095356033694365, 55.4358539273662, 55.66699135688044, 58.6075452066237, 45.42885603443269, 45.83660994806598, 45.03279470628308, 42.01184011274769, 42.254030781407515, 52.655470063609464, 60.00781174628966, 58.40223658469416, 55.7526166977421, 48.79620298262566, 45.590230188062115, 42.89075305384975, 44.138306033226755, 46.70476382778537, 57.37762720354142, 61.12389472223098, 57.427131437486224, 59.18831094618767, 58.48649301836568, 54.129567377028934, 51.570295364626, 52.54521223806566, 53.088586022776944, 50.82829275438863, 44.887176713635846, 46.067096264131614, 47.477066747603885, 46.39593601226807, 47.035945230914706, 48.79978802896316, 52.05922665134553, 54.4589013438071, 60.21702312654065, 61.24516264084847, 64.89279039444463, 62.32620708404049, 61.61183757166709, 49.844589771762976, 54.46669117096932, 61.99775565055109, 67.37889059128301, 66.76536913841002, 66.06259807463616, 54.889330479406546, 14.574651891185393, 1.795547071003145, 1.3476741746548684, 1.9728214101445292, 0.42981191388060974, 0.31013197295608064, 2.1522731550278205, 39.78762480520433, 44.01112710275958, 35.474829750676314, 24.86018023183269, 25.29622816270398, 33.757569020794286, 54.22331594651746, 55.582546649440644, 61.3877211847613, 21.536546138025102, 0.1724020659082359, 0.02982305212607307, 0.05840493456250238, 0.052892637003453515, 0.05084658469704371, 0.0741531205694041, 0.05159571526512023, 0.07274329662322998, 0.035781308618043704, 0.05057923916366793, 0.023063934978938872, 0.057329726330335104, 0.017124478284630085, 0.05919595098783893, 0.08949409254015454, 0.06389596935121283, 0.05155313992872835, 0.05508184816027361, 0.05549787603799374, 0.10124401970496101, 0.17711051889965612, 0.12817872117363638, 0.11008059110252127, 0.28412356371841124, 0.12440974478639903, 0.10200432366541318, 0.16399766769139998, 0.11045424282670983, 0.12176769139665751, 0.12254091159951304, 0.14279929470391045, 0.12425135610805405, 0.1939574665119571, 0.22106562560844809, 0.15026359578534482, 0.1226080745278347, 10.457442883522281, 77.7817693833382, 76.82721353346302, 76.28654618417063, 59.99600933444116, 45.45502216585221, 21.79768773817247, 55.66739536100819, 54.94491046474826, 61.85095310211182, 11.972580936647232, 0.3177913200230368, 0.18102003411660272, 1.4976963761352724, 4.547973015616018, 10.270896919312017, 9.106246175304536, 0.8963470797865623, 47.43147311672088, 69.42818780099192, 71.98458471605855, 70.09717156810146, 70.02463909887499, 65.94353060568532, 65.69553875154065, 59.85301148506903, 56.89500701042914, 50.42439060826456, 50.388191053944254, 52.31090553345219, 62.187029623216205, 63.63129731147521, 63.06223592450542, 63.836472572818884, 69.77982828694006, 64.44261996976792, 56.577620583195845, 58.184082200450284, 59.543171698047274, 63.22065653339509, 61.735176501735566, 63.67569069708548, 63.845992165227095, 61.95564900675128, 62.11182209753222, 63.00412208803239, 59.50282227608466, 56.96062826341199, 57.244788292915594, 61.474542848525516, 61.30444534363286, 60.1971523992477, 63.99913326386483, 57.04166443117204, 48.368441058743386, 44.75458491233088, 46.53285026550294, 45.37823000261861, 46.85135849060551, 48.20140300258514, 45.41156622671312, 48.359184265136726, 46.66611279210737, 56.4354464315599, 59.76918258974629, 60.9895182424976, 57.795724407319106, 63.587021596970104, 56.757237680496715, 66.07250598169142, 39.29610475417107, 38.80202731778545, 58.75004099261377, 54.91615164664484, 58.92598282906317, 54.56655863792666, 56.121539146669456, 57.926304032725675, 60.42228860239829, 48.885958579278764, 49.47990740499189, 49.12021429308, 44.9634511240067, 45.10037322198191, 54.83435846144154, 62.62234995442053, 61.29743214576476, 58.93053277846306, 51.03182846500028, 47.387130721922844, 45.28869013632498, 47.92909637574227, 49.55655444052912, 60.1952108260124, 64.88539280429964, 58.550251145516675, 60.775501958785526, 62.119066715240486, 55.16088401117633, 55.831495561907374, 55.25613484844085, 54.53826658187374, 52.411204461128484, 48.707408366664765, 49.30841745868806, 50.286817396840746, 48.946504285258634, 50.350822633312596, 52.057006589828006, 56.1877840565097, 59.2686842333886, 62.60748809383762, 65.8646595862604, 68.33211283529958, 64.95359497685587, 64.26003756061678, 53.45971676611131, 57.09507926817864, 64.18817581668978, 70.11988209139916, 71.29445152897989, 68.51539734871157, 56.45610947762766, 16.133748927424033, 7.8663977115385, 13.760485514517754, 4.284151946344684, 0.7842251478183655, 0.4091569577013293, 3.2755556414204263, 49.54090026117141, 58.6936883003481, 53.1625227005251, 33.027435502698346, 23.83215250507478, 40.15768474148166, 63.628881131449056, 61.8891256086288, 72.94740107751662, 24.281573757048577, 0.35435853525996214, 0.14711688963636277, 0.2106792506791892, 0.14734526044659077, 0.14385985150452585, 0.1234448417240093, 0.18166051426481816, 0.1465667159326615, 0.25075317210247444, 0.21278087500362627, 0.13559221530393248, 0.2150896801463058, 0.1640762070253972, 0.202265536833194, 0.2530090099260692, 0.09686263263105385, 0.14433781376048443, 0.16135783595663888, 0.16775149852037433], [0.036287692735993096, 0.03296587420927902, 0.05536242403210171, 0.027301364555774678, 0.042304363432190115, 0.0637467545757611, 0.034298909332362876, 0.03814748608537259, 0.006600763421550754, 0.03811881141436677, 0.03727783456504826, 0.08889340299872622, 0.015681554552077526, 0.10641351973097171, 0.05908011083280849, 0.03758679399447095, 0.15835812675856775, 15.372883639027997, 69.07422527190178, 61.34294340687414, 59.6486089306493, 50.21206878846692, 29.268455582280314, 26.631342172622684, 29.623298683474143, 41.42677545547485, 32.57146585372187, 1.1945183671289876, 0.05272915384041206, 0.07227654989448286, 0.17709795505769793, 2.1202666144217215, 4.41044932411563, 1.2879012981730125, 10.476722313511758, 65.29869687172675, 60.8397307703572, 68.3239935290429, 70.31301959868401, 66.67531936399399, 62.44481955805133, 62.25127020189839, 62.56139239957256, 61.614908787512014, 52.384461741293634, 46.076902189562404, 44.17363874373898, 49.69420609935638, 61.21609787787161, 58.80131421550628, 55.893590604105306, 62.99167640747563, 68.21892892160724, 56.59339243365873, 58.50789739239601, 54.58870433991956, 60.39807188895441, 58.90698286794848, 59.36097368117302, 55.44457727862943, 57.57656981868129, 61.26742993631671, 56.34679302092522, 50.73428530846873, 46.485401353528424, 48.7102520850397, 54.629073373733036, 57.60850575662429, 59.71186891678841, 57.25549636348602, 51.93768416681598, 41.49487956877678, 43.521807501392985, 40.331555566480084, 42.84782271231375, 40.298337013490745, 41.664882936785304, 39.55963703893846, 42.11952094108828, 45.62168367447392, 55.733051915322584, 53.64838669376989, 58.03030567784464, 52.935366476735766, 59.49232209113337, 53.54619326130037, 63.44856192988735, 35.739240646362305, 29.02873012327379, 57.527701008704405, 48.724984507406916, 56.77657496544623, 51.23304213246992, 55.27714306308378, 50.64284309264153, 57.90988891355453, 51.51784150831161, 43.06320398084579, 42.16720127290295, 43.56442797568537, 39.319623285724276, 44.88504294426211, 49.36557423683905, 52.05159764136038, 47.85833681783369, 43.692618877657004, 40.626321684929636, 42.19778791550667, 41.89273342009514, 44.00959737839238, 51.813015553259085, 59.56001043319703, 54.168610649724165, 59.50517569818805, 54.82115184107135, 53.83892366963049, 45.91583005843624, 46.423855443154615, 44.812655602732015, 43.5519273819462, 42.09806165387554, 43.53613199726228, 43.45581362324376, 44.29284349564583, 43.604887224012806, 48.5873838393919, 46.10010693150182, 53.45055803175896, 56.111305682889885, 61.130284263241684, 62.11148869606757, 60.53932820597003, 49.44703402057771, 47.29780266361852, 51.51427607382498, 57.74250568882112, 61.72551962637133, 60.899676353700706, 61.79995052276119, 63.39517454947195, 36.96274165184268, 3.5697280110851413, 1.993643189630201, 1.6434913657365309, 0.3327230784681536, 0.12397943319933069, 0.053108432480404456, 20.10272372153498, 38.92729997634888, 34.235521593401515, 23.15609278217439, 11.23958703010313, 36.69418873325471, 45.90283524605536, 53.8055129205027, 54.89248014265492, 39.76532220840454, 1.307781953965464, 0.02004040236164245, 0.021310300348446738, 0.032347177771190484, 0.06350259469341367, 0.040898565278058095, 0.018738006925090187, 0.0293931293286263, 0.01878995917767527, 0.044475422135644385, 0.03690388789700885, 0.08221403560450963, 0.02551467514656965, 0.03698105593362162, 0.0710475686637144, 0.015262227708233461, 0.04188156333721934, 0.03162727920308469, 0.07012404967099428, 0.059231214014993566, 0.012986721534792696, 0.023059135438093258, 0.022406597065949635, 0.03808046105287729, 0.03542444571071575, 0.028223879973313985, 0.09272947336637205, 0.0708766314651697, 0.04229650720052662, 0.03770392883809344, 0.08967980757475862, 0.03643003570276403, 0.02896612532617104, 0.05536408261245778, 0.0676226576850299, 0.10852325692652695, 20.963079929351807, 81.7763739247476, 68.8055193808771, 68.15419412428334, 54.439936684023955, 35.698236188580914, 25.297975578615745, 26.528493704334384, 42.75596864761845, 39.82208282716813, 1.1647405907992394, 0.033338851776094205, 0.07940531978684087, 1.5043205239119068, 2.8863859176635747, 2.804118370817554, 0.5018897865328097, 12.72730673513105, 66.09626770019531, 61.30272734549738, 70.82666966222948, 72.08888838368078, 68.26846061214324, 66.85061793173513, 66.23967739843553, 65.04536667177754, 62.07668158315844, 54.61033228904971, 47.16421065791961, 46.915073471684615, 51.78377820599464, 63.370444005535504, 62.136399669031945, 58.28070194490495, 61.77890308441655, 69.60734598098263, 57.65168320748114, 59.61244467766055, 55.30960067625969, 60.57622986455118, 60.90017841708276, 61.343951456008426, 58.82604868181291, 57.61222024117747, 64.48166716483333, 59.03851562930692, 52.40215555314095, 48.19540962096184, 51.83659292036488, 56.329526747426684, 60.03566841925345, 60.625604660280295, 60.364869025445756, 54.78670950858824, 44.24095446063627, 45.57472113640078, 41.22646001077468, 46.43764649668048, 44.24829713759884, 44.31819377406951, 43.708343659677816, 43.754337372318396, 47.35673627545757, 59.61322522932484, 55.707764394821666, 59.22519299291796, 54.81089876544092, 61.61113154503607, 56.09422376078945, 65.97873780035204, 36.5943879465903, 31.941797964034546, 58.660799226453236, 51.772407254865094, 58.123516882619555, 53.4734489840846, 55.38317649595199, 53.92823211608395, 60.56517662540559, 53.89544110144339, 44.241119200183505, 44.343669568338704, 44.86796886690202, 40.46618307790449, 46.92470289045765, 52.06331376106509, 54.82512520205591, 49.87240722102504, 46.61383936482091, 42.044070228453606, 43.712320943032545, 43.935009587195616, 47.67951988404798, 54.0325044047448, 62.037861885563025, 56.096188868245775, 59.67478290680916, 57.507783212969386, 55.79078920425908, 47.78361174368089, 48.41011231945407, 47.87839189652474, 47.097863766454886, 46.26263033959174, 45.96372219824022, 45.20061723647579, 46.74842373017342, 46.965522996840946, 49.60800417007939, 49.4035663143281, 57.062496139157204, 57.25727319717408, 63.390197061723285, 63.180664047118164, 63.27683664137318, 52.07497104521721, 49.984665455356726, 53.62484855036582, 60.823907929082075, 62.43475867855934, 65.28070888211651, 64.00936280527424, 66.2677223451676, 40.59326394911736, 5.700104044329736, 2.411144928586099, 5.656374519871128, 0.947378954339412, 0.09235881704596743, 0.05356204080125017, 21.2776755902075, 46.085476490759085, 29.25259351730347, 26.145452683971776, 18.559992774840325, 43.617980095648, 52.8999827754113, 59.757521383224, 60.907073943845695, 50.74555035560362, 2.131443653375872, 0.13185261838859128, 0.03868146852079419, 0.057329354777691834, 0.08566832605509028, 0.030965563097608187, 0.021050073687107335, 0.040058856304254264, 0.013186340107612554, 0.02990121990742703, 0.028081144386481856, 0.03651930409814081, 0.02907930907132405, 0.060006709498984206, 0.0353390307375981, 0.0840733616402553, 0.06388016495733492, 0.04162768945999203, 0.024885402864686428, 0.11557418462489882, 0.07445947913032386, 0.15411410691036334, 0.10189669597293101, 0.1694300278059898, 0.19580251266879423, 0.14908299300699465, 0.12111062544488138, 0.2515492753516282, 0.14376436630564352, 0.20507222251786342, 0.3228223113523376, 0.15701309086815005, 0.2023510322455437, 0.1600798327595957, 0.18067340997438278, 0.23012282266732187, 28.151760716592115, 92.27788463715585, 76.6923624469388, 77.50166508459276, 64.62779898797312, 42.18934697489585, 38.469351491620465, 44.00057592699605, 57.94740638425274, 46.4129473317054, 1.9129979105726367, 0.18457477401581504, 0.22222991071401105, 2.1381947878868353, 6.305620920273566, 13.582547191650638, 4.843728551941534, 13.572451991419639, 67.94506119143578, 62.09791729527136, 72.91279792785645, 72.97983123410133, 70.52608274644422, 70.49566084338774, 69.86117824431389, 67.48153901869252, 66.36697400000789, 57.13894705618582, 50.180795731083045, 48.36263987325853, 54.01312005135321, 66.77597522735596, 64.0676845273664, 59.903939539386386, 61.41429524267874, 70.25256802958828, 62.0191208008797, 62.83417755557645, 57.1713811351407, 62.08259651737829, 64.55892216774726, 63.03628552344538, 60.94066904437158, 59.76315782916162, 65.29991280648017, 63.066758417314105, 54.36052437751524, 52.051931042825025, 54.461866655657374, 59.28294597133514, 62.863379601509344, 63.7622142607166, 63.064099050337276, 58.06843503828972, 46.46060020692887, 49.71292364981867, 42.71418363817277, 48.6519774313896, 46.99578408272036, 47.381674705013154, 45.82950653568391, 46.35333514982655, 49.797184005860366, 60.667981947621996, 57.86418153393654, 62.095716845604684, 58.058554587825654, 63.9246396095522, 58.63555485202421, 66.66912986386207, 39.26073281995712, 35.714137477259484, 61.65779206060595, 53.06135300667056, 60.46492868854154, 55.06370336778703, 59.50046885398127, 57.47067759113928, 61.619133180187596, 55.447617115512976, 46.485040495472575, 46.65344353645079, 49.24939363233505, 43.402983219392844, 49.84347974100421, 54.12908884786791, 56.899329462359034, 52.39893136485931, 50.047568505810155, 42.838758114845525, 47.602719876074026, 47.01330923265027, 48.149313926696784, 55.71619356832197, 65.59139982346566, 56.37913296299597, 61.837366011834916, 60.964877913075114, 59.96867825908046, 49.9038097166246, 50.427199025307935, 50.597720146179206, 50.5447877607038, 47.97423501168528, 48.52299813301333, 48.16673709500221, 49.25472021102906, 49.44375491911366, 54.42880499747492, 51.3831590837048, 59.35462336386404, 60.806276875157515, 65.5120934209516, 67.28114512658888, 65.53061877527546, 55.40255692697341, 52.430706485625244, 57.1155579628483, 64.9386978149414, 67.41166591644287, 67.32295759262578, 65.042668081099, 69.70358525553058, 42.34661440695486, 6.245915582103114, 5.930480043734274, 8.93114862903472, 0.9859543618175292, 0.2671769021018859, 0.11192334665646476, 25.61219665311998, 53.52764045038531, 46.430362655270486, 33.81512588070285, 16.61241831318025, 48.66153232512936, 58.73348074574625, 68.92851706474059, 70.98288197671214, 58.38184418216829, 2.3823890522603066, 0.2021459964734893, 0.11822432024224151, 0.23149456438278002, 0.17306372072667847, 0.11877919772579787, 0.1181315546554904, 0.11823273188765011, 0.09124521631747486, 0.1297994108209687, 0.14476792616469247, 0.22856939553974137, 0.08877523393640596, 0.19209800258038506, 0.20436205901205542, 0.20146312101954417, 0.12422439747399862, 0.11635561729030264, 0.0964607046015801], [0.0472255896837, 0.007495016897953446, 0.027288904135686257, 0.04120377470709143, 0.021953810374402714, 0.03984860347343549, 0.05223943596525539, 0.009255584145355369, 0.012319746235716007, 0.016331203815136707, 0.04854950836048492, 0.05067331476076957, 0.01724000242839177, 0.04186704980149385, 0.017966020123792753, 0.18723001943961268, 1.2446113243218393, 41.667452089248165, 63.57507013505506, 60.66731906706288, 49.981959019937825, 33.25136361583587, 17.277465981821862, 27.08634887972186, 53.91795550623248, 41.62659668153332, 20.551791960193267, 0.8092287867780655, 0.08105479135748841, 0.07132829392268773, 0.30697572135156204, 3.4960806081371927, 2.952582533321073, 1.2016281533625819, 53.54827603986187, 70.41131419520225, 66.80649126729658, 60.86974866928593, 62.16520163320727, 64.58164838052565, 65.71021233835529, 65.46858649100027, 62.94498059057421, 61.09519081730997, 59.383872478239006, 46.64858764217746, 43.43771972963887, 45.86781632515692, 56.29537074796615, 61.492679888202304, 61.018735977911184, 54.998227242500555, 64.09494500006399, 64.09507443827968, 61.00259150228193, 58.01195683017854, 56.991034476987785, 56.42603666551652, 57.52544172348515, 55.3718839922259, 58.46716750052668, 56.87869387288248, 55.493810869032345, 47.58374737155053, 42.31971479231312, 47.209823900653475, 54.943443498303814, 57.09438108628797, 55.440541159722116, 57.44324061178393, 51.555896343723425, 41.886630212107015, 43.88212819253245, 40.06916076906266, 43.857389803855654, 40.69304120156073, 42.66665627879482, 39.550729336277136, 43.76576323663035, 50.34243268351401, 57.152914616369436, 54.674521876919655, 58.29146885102796, 54.713706354941095, 59.03080032717798, 51.46236350459438, 61.556445860093646, 33.321636799843084, 29.463301281775202, 56.393402545682854, 49.141500996005156, 55.265607372407, 49.32163584616877, 52.695721426317775, 49.152036482288, 54.58698241941391, 55.21502056429463, 48.3819418568765, 40.82850025546166, 41.5459958968624, 40.87840849353422, 42.289951847445586, 43.60991178020355, 46.22845080591018, 42.41120799895256, 41.250433537267874, 42.31244664038382, 41.63845400656424, 41.21738364619594, 42.066031579048406, 48.02228012392598, 57.01192109815536, 57.45077548488494, 55.2264307391259, 53.81123958095428, 53.47471590965025, 46.59210943406629, 44.63195985363376, 42.902955547455825, 42.86339059952767, 42.16020768688571, 44.63981636108891, 43.9463177804024, 45.99303014816777, 44.152803113383634, 46.0224243902391, 45.808015869509795, 49.54694463360695, 52.890584776478434, 56.002095130182084, 54.30518365675404, 51.49724906490695, 46.707768363337365, 46.3799641209264, 53.343379266800426, 58.20995415410688, 59.89603988585934, 64.58978337626304, 64.00621706439604, 65.03634522038122, 54.45095462183799, 18.538798247614217, 0.814166437954672, 1.5011419331835163, 0.590060408557615, 0.06964732847747303, 0.057996192180942145, 3.4561888777440597, 42.822213557458696, 39.25715561835997, 41.709021368334376, 23.055993895376883, 20.606732599196896, 33.416518934311405, 46.51715294007332, 50.74786063163511, 47.84245121863581, 6.894261798551006, 0.3662593434414556, 0.09061973617081681, 0.0683306378402537, 0.11821051533784598, 0.07517004866273173, 0.031164870447208805, 0.06285459922266103, 0.045262481716852036, 0.03266473653756323, 0.013274069623871437, 0.09284503772974977, 0.05221206747416047, 0.03062433412959499, 0.029274404852560935, 0.09749586558750561, 0.008402302008753103, 0.04298129404384283, 0.013883127718262616, 0.031407302801286986, 0.02180258653336956, 0.009016911367765598, 0.024187385682917895, 0.08424992958504347, 0.06878007098191208, 0.08539335411642829, 0.09433173093824618, 0.044894931882980375, 0.021208584939520207, 0.04127851424498424, 0.010785618778167954, 0.015106373823307937, 0.04509980294613108, 0.029821489306707537, 0.09178302536207823, 1.5367531319779735, 55.643943509747906, 72.18723004864108, 67.81400695923837, 55.97350497399607, 44.87436233028289, 31.51948028995145, 33.95939065564063, 45.10085567351311, 46.13301953961773, 23.089030058153217, 0.3295706573032564, 0.07071568405315762, 0.2985096224133046, 3.0331475263641727, 5.012366444833818, 0.7119209727933331, 2.6391711831092834, 54.944424090846894, 71.52933874437886, 66.754009954391, 61.2959377227291, 62.83949236715994, 65.97753755507931, 67.29767399449503, 66.11917434200164, 64.3368846370328, 62.62881794283467, 63.40655726771202, 49.90975210743566, 46.49281071078393, 49.06690928243822, 59.273787236982784, 63.03747792397777, 62.23117589950562, 57.90885733019922, 62.3278074110708, 64.73208696611466, 62.64407596280498, 59.662760842231016, 60.81593375052176, 58.64334075681625, 59.21840729251985, 56.40733088216474, 60.368524674446356, 59.60147380828858, 58.56578765376922, 50.528494235008, 46.264791565556685, 49.002001900826734, 57.26438445429648, 59.52071612881076, 58.19677891269807, 58.90261334757651, 55.065613562060946, 44.53732482848629, 44.11015126012987, 41.67936824983166, 45.06276945913992, 43.380484504084436, 44.60449934005738, 42.30820655822754, 45.73946068363805, 53.503408047460745, 59.61820663944368, 56.58679500702889, 60.16764833081154, 57.63470718937536, 61.515229594322946, 54.84577648101315, 63.67061122771233, 34.16775872630458, 32.38796364876532, 58.16614912402246, 51.10365490759573, 58.46507295485466, 50.2811848732733, 53.65554501933437, 50.04701937398603, 56.72073218130297, 57.15046313501174, 50.593534977205344, 43.32925050489364, 44.422787697084495, 41.84339000332741, 45.260303943387925, 44.997391393107755, 50.06010440088088, 45.130120477368756, 42.85006630805231, 44.86281095012542, 44.25054073333741, 43.23241895244968, 45.43916402324554, 50.80172261884136, 56.98678262772099, 59.574299627734774, 60.30196597499233, 57.413991497408965, 55.247215378669004, 48.479565728095274, 45.6216013047003, 43.93054592993952, 45.317994163882354, 44.93145242814095, 46.818461571970296, 44.123561843749016, 47.08452770786901, 46.01749004856233, 47.62785442413823, 49.23553982088643, 51.170264597862, 54.975136249296135, 57.166717437005815, 56.33075052692045, 51.18782504912346, 49.61462120856009, 51.02184603291174, 54.93285702120874, 61.238412241781916, 61.31444346520209, 65.04379772370862, 64.64989762152395, 66.56459869876986, 57.78072134140999, 20.987865386470673, 1.8372782704330262, 2.616167707789329, 3.789918105448446, 0.24277159313280738, 0.14119884509953762, 3.0040160830943816, 48.85107694133636, 40.77740746159708, 34.25565511949601, 22.138745669395696, 29.581821580086988, 39.097683814264116, 52.678106061873905, 56.43225362223964, 57.925264604630016, 11.614723493975978, 0.31355724399608953, 0.06504761400602518, 0.06971092143606755, 0.05026989285984347, 0.05848663783962688, 0.07165775769540379, 0.05395346576528204, 0.06859916697947249, 0.04952632792053684, 0.027479162071681315, 0.0434965877643516, 0.09329857710268229, 0.029536588868546872, 0.0412755188412003, 0.04855456071034555, 0.025407671815745776, 0.027038410621424838, 0.05775773965363061, 0.10344541932065641, 0.11823193515620886, 0.15171954588543984, 0.13645783337133546, 0.15352889234500547, 0.11989902674911485, 0.22564525325452128, 0.30160654816896687, 0.0796642804878854, 0.1308551872329366, 0.18499823677684032, 0.1454733552471284, 0.1372410969868783, 0.17961579495139662, 0.16910448640344605, 0.20485784047313277, 2.2850255283617207, 65.59662834290536, 80.68520192177066, 77.84303680542978, 66.78301195944509, 50.23923512428038, 26.16054596439485, 40.10395219249111, 70.38679938162528, 58.1119066669095, 27.628638129080496, 1.8149010260258953, 0.15694017461951704, 0.5602369121005458, 2.8885037524084893, 13.22284427381331, 8.672583045498017, 2.6317716317792095, 57.96052279010896, 73.14635153739684, 68.99458546792307, 62.47044440238707, 65.07960504101169, 65.38537733016476, 67.27537139769524, 67.73333949427452, 67.26478099822998, 64.50239689119401, 64.40212149773875, 50.899181750512895, 48.353732170597205, 51.510557666901626, 61.12347895099271, 66.47294859732351, 64.29513492891866, 60.30786129736132, 66.19927698566069, 67.4199499622468, 66.12612478194698, 60.52622356722432, 61.34392399941722, 59.19178224379017, 61.06254885273596, 56.07804790619881, 60.94687423398418, 63.702472640622055, 59.48411649273288, 52.88699580777077, 47.9248837501772, 50.84105614692935, 59.453886785814845, 61.03581005527128, 58.17993233280798, 63.46481623188142, 57.96775564070671, 46.71880983537244, 47.19225560465167, 44.49926214833414, 48.271938985393895, 45.69565173118345, 49.345852559612645, 44.65763176641157, 48.34719357951995, 56.73954779101957, 61.65470907765051, 59.542261708167295, 62.44693371557421, 61.95039695309055, 62.50517699026293, 57.240167740852606, 63.05530901878112, 35.78260244861726, 36.84003422337194, 57.83348114259782, 53.05959970720353, 60.1596623851407, 51.91504816855154, 55.572168057964696, 52.2399341675543, 60.55864980143886, 58.49082331503592, 51.546804289663996, 44.40032036073747, 46.1377420733052, 45.183154844468646, 49.47438470778927, 48.766220385028475, 52.49076189533357, 46.56380953327302, 45.8563433924029, 48.590043206368726, 47.23507611982284, 45.925726198381, 47.246443148582216, 52.58180795177337, 59.61944610841813, 61.464583950658, 61.33162344655683, 59.72100019454957, 57.64039854849539, 50.50604651051183, 49.5679057798078, 46.24242621083414, 47.742081688296416, 46.53427800824566, 49.706557643029, 47.120793942482244, 50.859977660640595, 49.04437134342809, 51.17558333181566, 52.64474238118818, 54.209262094190045, 58.994761590034734, 59.170754417296386, 60.022214689562404, 55.59008152254167, 51.767249338088504, 52.63174364643713, 57.08834455859277, 62.76884263561618, 64.13891084732549, 69.10733792089647, 68.12876147608604, 69.90520292712797, 59.688342540494865, 22.52890971399123, 3.1393383443355565, 5.3367582251948695, 3.895148187875748, 0.2574766048740956, 0.24494406526848195, 4.4728694327415965, 58.663886131778845, 53.426035373441636, 56.93772162160566, 29.356004845711496, 30.579933389540646, 48.37265368430845, 62.845956433203916, 62.94352539124028, 68.65897963123938, 13.783859898967128, 0.5719132565202252, 0.1908823895838953, 0.19934773775598696, 0.23482672509647187, 0.1294005701258298, 0.19793903995906154, 0.08700566276186898, 0.16001109935102925, 0.19770397354037533, 0.10047669837912244, 0.17253947143833484, 0.15277691576029026, 0.06691381951133091, 0.0920357118030229, 0.13711193456284462, 0.0841898912744176, 0.29641228818124343, 0.14552423880705911], [0.03808562448548694, 0.01781821878056132, 0.060918476702945853, 0.028910394344899445, 0.08465936527617517, 0.026254899942526416, 0.010669130321231582, 0.015167826523764, 0.06179079037880706, 0.07641301099811831, 0.010403296853896352, 0.048868089854236574, 0.0891140899470737, 0.09885772476874052, 0.05245117500664727, 0.11483565288325472, 4.4083317345188515, 50.49242411890338, 65.86662077134656, 62.685845282769975, 48.57172181529384, 21.094067481256303, 15.397199392318727, 31.927030240335775, 34.15019435267295, 44.4955555085213, 15.798190159182395, 0.06481292297042186, 0.05197690912492333, 0.07778135894407188, 1.5613851263638467, 2.2761161096634406, 0.6906197448411296, 37.49263817264188, 72.1704658385246, 64.80592558460852, 71.09153947522564, 65.52069125636932, 60.219980593650575, 55.87633609771729, 56.5171847035808, 61.14515004619476, 68.24469104889901, 60.32007948044808, 59.8394714632342, 53.196141335272024, 48.341019768868726, 42.50578811091762, 50.39554942038752, 56.39468123835903, 57.72880877217939, 58.781749433086766, 55.87060551489554, 53.65401137259699, 59.16651433514011, 57.1998457754812, 57.54389255277572, 56.610101730592795, 59.152095702386674, 60.030110420719275, 55.36380390967093, 56.39432038030317, 54.89699479072325, 43.67576445302656, 42.33021889963458, 47.766906369117, 53.50997801749937, 58.70586333736297, 58.62902018331713, 57.259171624337476, 51.35573779383014, 43.21376808228032, 43.62709176155829, 40.937479388329294, 43.03044042279644, 39.96289591635428, 41.105717689760276, 39.329739078398674, 46.38315693024666, 53.94876180156585, 56.84682069286224, 53.31102755761916, 58.661795508477, 54.226771554639264, 60.55976767693797, 50.38257029748733, 61.44078693082256, 35.2863206401948, 26.323596931272938, 56.11074478395524, 49.869963584407685, 58.51765232701456, 51.30602175189603, 56.34123110002088, 50.80350729726976, 52.17393636703492, 53.9612231716033, 54.44339229214577, 41.40488470754316, 41.61680644558322, 40.88585315212127, 41.13379009308354, 41.71730933650848, 42.15474774760585, 41.18069771797427, 41.296466473610174, 40.38559406034408, 41.47124728848858, 42.711108499957675, 41.10211695394209, 45.572489307772734, 56.08288418862128, 56.525990424617646, 55.564217413625414, 56.60292379317745, 54.25538524504631, 44.64833967147335, 43.33447510196317, 43.49124047064012, 40.98877222307267, 42.64025872753513, 42.64059212899978, 43.309477836855, 45.65914230961954, 45.251443309168664, 45.222825696391446, 45.56364044066399, 44.57299486283333, 44.84203023295249, 44.207210310043834, 45.63054823106336, 43.47357411538401, 46.532159928352606, 50.35464694423061, 55.52227158700266, 57.06237062331169, 57.500244417498195, 59.27090429490613, 60.560626676005704, 63.161173789731926, 66.67189905720373, 38.10068007438414, 4.313893808472542, 4.085950904315518, 2.525751682058458, 0.046428371776616385, 0.007051697616735774, 0.03160092769370925, 23.232229909589215, 38.23670002721971, 39.82153761771418, 39.0450220723306, 17.635262627755445, 32.789127980509114, 39.83127294048187, 55.47475599473523, 54.079184532165534, 27.447750183843798, 0.6517175548980314, 0.08416537646084063, 0.047329589949860695, 0.058690570445070346, 0.0926404233060537, 0.019616997057211497, 0.030311138233951027, 0.028133368600280057, 0.03881173028099922, 0.042981102521861755, 0.03472302326812379, 0.054949131088271264, 0.033251387517779105, 0.05100305815557799, 0.024089516035371253, 0.021749349168291496, 0.04311019982842188, 0.007571783217210924, 0.03684742721698938, 0.05170755644118594, 0.028333984045011383, 0.016180158089545947, 0.052151278397368814, 0.05091614548056837, 0.03115097361226236, 0.012286544942687596, 0.03476940606149935, 0.04268201796578304, 0.025970773253169273, 0.021267420492104946, 0.0986154111582906, 0.08294129819278756, 0.056762985975271275, 0.0581130359111534, 5.896323063681203, 64.16877185144733, 72.70743047037433, 69.8118426722865, 56.69894341499575, 30.697006333258848, 18.968323276888942, 28.944563904116233, 34.82927430060602, 51.86246487402147, 15.455753514843604, 0.20279053688770343, 0.10078766112846714, 0.719931862286983, 3.338579549904793, 1.8318608643547183, 0.6803989061905492, 38.73631192791847, 75.43048889406266, 66.56361810622677, 72.32247337218254, 67.28490275721397, 61.414283475568226, 58.9096147783341, 59.142376069099676, 61.969506740570075, 67.37123412470665, 62.30793276140767, 61.632861475790705, 54.09264610659692, 50.25244566702074, 45.07036316779352, 52.44105369813981, 58.84366404625678, 60.48539169373051, 61.20686461848598, 58.562277132465, 54.09610955945907, 62.07023320659515, 58.00321778943462, 57.95677300422423, 59.054962127439445, 60.74107139341293, 61.652759659674864, 57.54105667914114, 58.846484230410674, 58.42868904913626, 45.05282232838292, 44.050021325388265, 49.24174501049904, 57.69384868683354, 59.909007241649014, 58.60501135549238, 58.5323533704204, 53.978352162145804, 46.63543201261952, 45.13469788335985, 42.55871657402285, 45.66403350522442, 40.07049829729142, 43.867689947928156, 40.81865118395898, 48.51430616071148, 56.30300368032148, 56.78451776504517, 55.520055447855306, 59.35134818477016, 55.999718173857666, 62.068648569045536, 50.95751131734541, 61.842319965362556, 35.36316379424065, 28.628103156243604, 57.894462231666814, 51.627067750500096, 60.06211696132537, 52.950950053430375, 57.890088788924686, 50.43143126272386, 55.18495167455366, 55.959839436315725, 56.096224169577326, 45.039290151288434, 43.21732959439678, 42.97763355316655, 42.649225265749045, 45.04239274609474, 43.67565070429156, 42.65957640063378, 44.5624162304786, 44.55770154153147, 43.989314802231334, 44.125593631498276, 44.31340848245929, 47.707851163802616, 58.68409026053644, 57.83510500384916, 57.007849677916504, 58.25394353558941, 56.603402322338475, 46.979149310819565, 44.293569134127715, 45.34265018278553, 42.35259602146764, 43.46925558582429, 44.88126570178617, 45.89005224166378, 46.36895402785271, 45.5104648682379, 48.01661229902699, 48.177464777423495, 45.94441236988191, 47.67327547073365, 47.492097270104196, 46.5181060760252, 47.22288147095711, 49.81976509094239, 52.460638092410186, 58.58666643019646, 57.130561028757405, 59.36769662364837, 61.04771052637408, 63.46749128833894, 63.55651732414, 66.68983213363155, 40.8479199101848, 3.896918647712277, 0.43119488644503784, 5.386941519475752, 0.5019625955291334, 0.2728850538692167, 0.05818433571426619, 26.168010234832767, 44.01036224057598, 32.69218464051524, 36.10553118490404, 26.150722388298284, 41.33503906188473, 47.478317983688854, 62.81067079113376, 61.44113209939773, 40.00498294830322, 1.15582823032333, 0.0540368429445211, 0.03782123988193851, 0.02469132406516902, 0.02499966870903248, 0.04840829154296268, 0.09959430298617772, 0.09144287466281846, 0.035935633199950384, 0.04513711142804354, 0.08700023119848582, 0.005069478150201781, 0.06734031598053633, 0.02150188553177061, 0.06805888347087369, 0.09044191950271208, 0.034327055402700944, 0.06425575871441154, 0.1727510955665381, 0.12806948469651322, 0.13996355896515233, 0.13743119404440926, 0.25354438281107333, 0.10008926473317609, 0.15242606281272827, 0.10873298115667798, 0.15304683917953124, 0.12428854201589862, 0.10276123385636077, 0.2377607192723982, 0.27484338910829637, 0.22279292405132325, 0.0868430682608197, 0.21713933306595973, 8.298215366178944, 74.98272680467176, 81.73657755697928, 79.9021948537519, 64.3978500366211, 34.93794748860021, 22.865733446613437, 44.50521238388554, 45.55839230937343, 61.66486409402663, 20.65211638327568, 0.3680303855048072, 0.1232519637673132, 1.3231529872263632, 4.08648336606641, 8.150435657270494, 1.8685771909452256, 42.751367707406324, 77.83643937879994, 70.22755899736958, 75.60025691986084, 68.30977885953843, 62.83580141682779, 60.28319351134762, 58.93290189004714, 62.981180144894516, 66.01301147091773, 65.01523502411382, 64.2453129829899, 59.02277123543524, 52.79127036371539, 48.40674300347605, 54.58135774058681, 60.543097603705625, 61.35758953709757, 62.55780735323506, 61.8624181901255, 58.45629469040902, 64.7750408418717, 63.43151530911846, 60.34624168949743, 61.792796119566894, 63.158184943660615, 64.31897901719617, 60.70453451525781, 61.433899248799975, 60.46074351956768, 46.98304422440068, 46.588269433667584, 52.158133137610655, 59.15225651956374, 62.36601129654915, 58.43791054141138, 62.57182590423092, 56.082013422443026, 50.24384390923285, 48.24696917687693, 47.50902621976791, 48.41016723263649, 42.315878714284594, 46.18878779872772, 43.421132026180146, 50.26592685330299, 58.58923558265933, 61.45535461364254, 58.3984201185165, 60.97934753664079, 58.32099253131498, 64.0723325360206, 53.63889848032306, 63.458124668367454, 37.77588428989534, 33.254336772426484, 60.54667088293261, 54.23877792973673, 63.63008529909196, 55.65673043650966, 59.05178892997004, 53.4746806083187, 58.181728778346894, 60.01704892804546, 58.0518747914222, 48.2091732178965, 45.409181425648356, 46.42918986658896, 44.88213254559425, 45.771435845282774, 46.28470151655136, 44.40261886965844, 46.23893922375095, 46.68551283497965, 45.6820724856469, 46.39638708483788, 46.048339489967596, 49.53558937195809, 62.23214472493818, 59.06705087231052, 59.56776103665752, 60.48123790371803, 59.60343499337474, 49.16279946604083, 47.69242055954472, 48.12739964454405, 44.13519167130993, 46.20542257062851, 48.6309378377853, 48.965594460887296, 50.44710505393244, 49.71196266912645, 50.41682043383199, 51.194787256179325, 48.92637468153431, 51.0708168245131, 49.16050095711985, 50.09450358729209, 49.73615977071947, 53.104506923306374, 55.300355649763546, 61.11126861264629, 61.83170995404644, 61.43874337596279, 64.37045228096747, 65.97996942458614, 68.71091965706118, 69.83529844591695, 43.952499435793975, 7.138299903561992, 11.369523386801443, 10.621569560420129, 0.2063310428732826, 0.3827046158332979, 0.12159693039833538, 30.514441574773482, 54.56381297880604, 57.76409441424955, 51.89838201768937, 27.8156037868992, 44.6517050650812, 56.52293882062359, 70.65866670300885, 70.14867228846397, 45.54084754759266, 1.6798306544942243, 0.18579374247741315, 0.14344092398401231, 0.18169439067282986, 0.21170637540278897, 0.13889190921139333, 0.16785743315854382, 0.1931269046279692, 0.15402122641042357, 0.2108564161725583, 0.12771177526202895, 0.12536227552881166, 0.09437672328203918, 0.17122964494891707, 0.23565555562175092, 0.20014892782895796, 0.2164127906003306, 0.1918572517893007], [0.01512922909891894, 0.09215847739288885, 0.019883676094093153, 0.045869989440806454, 0.018003200285977895, 0.03592471261658976, 0.028123915075294437, 0.0500842850775488, 0.044242305410725456, 0.03513217933716313, 0.04977298907995705, 0.04339894602796243, 0.02882016259395788, 0.034829505659159155, 0.03226087413608067, 0.09010184541224472, 17.651148226953325, 62.808254611107614, 59.89690672966742, 51.667146528920824, 36.0488921596158, 22.17438824715153, 26.981405865761545, 52.47463310918501, 46.6790017004936, 49.036605050486905, 3.8710611577956913, 0.15234692593015012, 0.254682406422592, 0.3134781530787868, 6.049541138833569, 3.325263838614187, 10.682516328750118, 67.66828306259649, 66.07433380619173, 67.59760195209135, 61.99874016546435, 64.11601989499985, 65.6700864914925, 64.86745188313147, 58.87920464238813, 51.95572706960863, 60.14719317036291, 66.71386057330717, 57.466084495667495, 58.51849171423144, 46.27827667420911, 44.154905503795995, 45.375915804216945, 57.1287488937378, 58.65833205561484, 59.389850170381614, 55.71672701066541, 49.532514233742994, 50.498868573096495, 54.8657178109692, 55.21702881782286, 56.340328954881244, 54.485612684680575, 53.81873915272375, 56.30009328165362, 56.83658722908267, 49.48599100112916, 41.42879155374343, 41.29333642221267, 48.474678454860566, 56.751283522575136, 59.09800621771044, 55.292993360950106, 54.862215134405325, 48.004315668536776, 44.69495704097133, 41.55424856370495, 40.74052149249662, 40.791359332300004, 40.35880034969699, 40.031043175728094, 39.51014457210418, 49.41123454801498, 54.93155479431153, 54.80378750831851, 54.32385021640409, 55.17192156084123, 56.69975142325125, 59.71928611878426, 53.93665344484391, 59.52294795743881, 35.45553168942852, 25.705217622941543, 55.94750750449396, 51.919056830867646, 58.04309652697656, 51.86782675404703, 56.93313637087422, 52.54925227934315, 53.41842597530734, 50.57639421955232, 58.29480286567443, 46.73062793670162, 41.90414751729658, 39.16350118575558, 41.669338749301055, 39.818348730764086, 41.40584961060555, 39.36394214630127, 41.582109159038914, 40.625647037259995, 43.154406932092485, 40.44102499561925, 44.82774496078492, 45.37152667199412, 58.48868170092183, 56.596679379863126, 57.55969578219999, 56.28510198285503, 55.12589646923927, 44.89654725597751, 42.979069140649614, 42.15513606225291, 42.51766112542922, 42.18488724000993, 43.02678085142567, 43.79095269787697, 43.288689274941724, 44.212062281946984, 46.39291186486521, 44.33369498099051, 44.18439388275147, 43.81287482477004, 45.25512641476047, 44.47965421984273, 46.45267309681062, 48.66236386760589, 50.32912015914918, 53.115340509722316, 55.00753502691946, 56.02103233337403, 57.89528985177317, 59.07444454008534, 61.10540859160885, 61.908537418611594, 61.024046867124504, 13.00100286160746, 1.009435630854099, 5.047928614001121, 0.5460315582252319, 0.03580991434113633, 0.2234126738603077, 6.570450038679185, 44.87002418887231, 33.1338611725838, 36.83002433469219, 14.486405426456084, 25.195189868250203, 39.16786678375737, 49.7888764258354, 48.094585095682454, 51.58480813426357, 4.296584879198383, 0.41709549785141026, 0.029161295800980543, 0.04458401509891114, 0.022755624809032007, 0.05328474378573799, 0.07187691246790272, 0.029350121152557196, 0.039358766854650555, 0.034243019387847, 0.032053842704983494, 0.07730980118316028, 0.06653431487540085, 0.03848363780566762, 0.04352752622517367, 0.07611388430720376, 0.03683144662288889, 0.04631358882292144, 0.052216932132479646, 0.08543161254736685, 0.006614382070819698, 0.030895686302814755, 0.03710616958297549, 0.050530374245417696, 0.05244560937787737, 0.025259173332503247, 0.02047499063454809, 0.0799279066643888, 0.026944199043716636, 0.034883173948694626, 0.032273453299797354, 0.06005360174082941, 0.05252149038677735, 0.12308641982775544, 22.58243045499248, 75.13901756655785, 67.23949740009924, 60.97806492159444, 44.094198980639064, 28.86572622483777, 26.767915179652555, 40.749393893826394, 42.885685351587114, 56.45714498335316, 3.970358410189229, 0.18476096402493217, 0.4319322001068823, 1.2090599416725099, 3.7067074737241192, 2.728046697954978, 12.155399668601252, 68.94045675954511, 69.49041228140555, 69.70076114900651, 65.29874001779865, 66.17571138566541, 68.41670267043575, 65.28955774922525, 59.81576858028289, 54.74059812484249, 61.637121169797844, 67.78667588387766, 61.37047452311362, 59.92735216694494, 49.30747216747653, 46.20349276450373, 48.232962392991595, 59.12056376857143, 59.78355807642783, 61.12325537589289, 56.363486628378595, 52.52515715937461, 51.14639697536346, 56.225638851042724, 55.61894624463974, 57.97697713298183, 56.98256215741558, 56.935309363949685, 57.82559717855146, 61.01225230001635, 52.460339992277085, 44.84223811857162, 42.74364063816686, 52.467435559918805, 59.91781688505604, 59.0467369171881, 57.12755649320541, 56.29766141214679, 49.13056542796474, 45.115093877238614, 44.74641069289177, 42.701141757349816, 42.69784696640507, 42.63838383459276, 43.41918260820451, 42.37582821999827, 51.83007001876832, 57.03627509455527, 58.59884146721133, 54.296797629325624, 58.72633026492212, 58.86387209738455, 60.48196746457008, 56.70506623483474, 59.24084717227567, 37.31142074831071, 27.603638902787242, 58.05095303443171, 52.697400200751524, 59.949843037513, 53.72854817298151, 58.52458707747921, 54.672097852153165, 55.5350467466539, 52.27040313905286, 58.3608595017464, 50.6040116279356, 43.37017259290142, 41.788468976174634, 42.78980693509502, 41.58915765823857, 44.4710446173145, 41.71670136913177, 43.05551613530805, 43.346854102227, 44.66306424910023, 43.19086144047399, 46.62919152167536, 47.834112259649466, 59.314846607946585, 59.18296083327263, 59.41200371711486, 57.742513533561464, 57.56277484278525, 47.02679434130269, 44.27362780417166, 43.77105843636298, 44.406941321588334, 44.136615491682484, 45.04815470787787, 44.71548280408306, 46.14393157343711, 45.42598485946656, 48.13818616251792, 45.61492543066702, 46.38637327378797, 45.14039708722023, 46.94839792866861, 46.71080427785074, 49.24923673752816, 48.706996517796675, 53.22309978546635, 55.59449026661535, 56.80760875824959, 56.884530359698886, 60.49893563793552, 59.447199144671046, 63.82967510531026, 62.90576081122122, 65.0802130083884, 15.267788633223503, 0.9892395919849797, 5.712697304064228, 2.5395677406941695, 0.1868673534162583, 0.29402681295910194, 5.815092248301353, 53.8108826452686, 30.196739396741314, 34.696325563615375, 23.607081021032027, 32.57726900039181, 47.41074339036019, 55.691898407474646, 53.816950551925174, 60.50435243114349, 7.875504474486075, 0.4486596686465125, 0.06540487910951338, 0.027867524599235867, 0.05047904252405128, 0.042370813898742206, 0.04839334899799959, 0.016387633851639206, 0.06620203189912342, 0.019814523252388163, 0.038995882496237755, 0.06845271395098779, 0.07289349582166442, 0.021364374664582072, 0.06312724608447283, 0.012940264047844516, 0.06820891412996477, 0.02590110713255502, 0.13030924233457736, 0.14956680817469475, 0.15843331062745664, 0.17004285218013873, 0.19252259915153827, 0.2800446051743723, 0.16338294341919885, 0.33791559177540964, 0.11258408216939819, 0.12355469873235111, 0.17825460992753508, 0.09890031925733052, 0.09495392456770906, 0.12424325089781516, 0.18086390539763436, 0.22150949695177619, 28.010514205501927, 85.29673253336261, 77.8078531449841, 70.88849406088553, 50.67509282019831, 32.8718174272968, 39.991960679331136, 72.33353445606848, 59.440762535218276, 63.306332865068995, 4.978348708921864, 0.3912769558448946, 0.5632588531701797, 1.169277792496066, 16.963413569235033, 8.870442105877785, 11.898231429438438, 74.59292950168734, 71.18745711541945, 74.67550323855492, 66.42776289293843, 69.54979696581441, 70.42660359413394, 66.90371897912794, 58.553887182666415, 57.21208357041883, 61.80687742848551, 68.42446896337694, 62.66167563776817, 63.87570411928239, 51.219537411966634, 48.573341754175004, 50.87096421949325, 61.78302157309748, 61.78155460665303, 64.5227579147585, 59.99503266426825, 55.28768247173679, 54.49020970252253, 59.18907580837127, 58.649926416335575, 61.74737507297147, 58.733272860127116, 60.78388014147359, 61.68428767111994, 64.60972862858927, 54.70113123616865, 47.22325801849366, 44.83469540073026, 53.996124421396566, 62.88240701921525, 62.604652220203036, 60.47858245911137, 60.25719211947534, 52.75540421085974, 48.32854663172076, 46.37982683797037, 44.444148925042924, 46.46595816458426, 44.106962373179776, 45.8391006531254, 43.9372649500447, 53.89266406336139, 59.429854423769065, 62.08870364773659, 57.81367317322762, 59.8247076619056, 61.36845058010471, 64.72127691391977, 59.14491384260116, 60.87973894611482, 39.81447342903384, 31.868361388483358, 60.57955211208713, 55.11574145286314, 61.23818474431192, 56.86472631269886, 59.39643190753076, 56.606767715946326, 56.524154755377005, 55.648913152756236, 62.4427838479319, 54.00695800781251, 46.24141423932968, 44.08340854029502, 47.49104999726819, 45.76849799002371, 46.36362352678853, 44.03986630901214, 45.22126459306286, 43.311078163885306, 47.51458814067226, 46.08944985174364, 49.63655902493385, 50.73297915920135, 63.629202765803186, 62.00619266879175, 61.150092232611875, 60.94363043385168, 59.901852838454715, 49.30172981754426, 47.623633953832815, 45.79520540852701, 47.45831781818021, 47.20349319519536, 46.947629144114835, 47.77293112970168, 49.475404524034076, 47.438878551606216, 50.90612826808807, 48.471881804927705, 48.37693691253663, 47.127297232227946, 50.20989971776163, 48.64366200662429, 51.238878619286325, 52.48086967775899, 55.30319152339813, 60.34891674595495, 59.47958615518386, 60.61911313764511, 63.757013197868105, 63.40199162883144, 65.95231671487132, 67.4798837784798, 67.8795576095581, 17.120439775528446, 3.837712185998117, 14.424334899071726, 3.7587938529829827, 0.2298082822873708, 0.3806693960101374, 8.576203546216412, 60.820875936938876, 48.92238563106906, 48.69648848810504, 21.24041699594067, 36.33576254690848, 53.44622773508872, 65.79009925165485, 62.51156260890346, 69.46842347421955, 8.874938122687801, 0.6395474208458778, 0.16370814774305592, 0.2262158202187669, 0.19177433043237657, 0.18954368157973214, 0.16429529284998295, 0.1432503519519683, 0.131711826749867, 0.08670293545771031, 0.17878589190302357, 0.20829919935955157, 0.2478665374820271, 0.17702798058669414, 0.1390655966655862, 0.15375781473853897, 0.1769885423803522, 0.07933842498929271], [0.02918040777947153, 0.009491477938999814, 0.03256857335086792, 0.04152416033790477, 0.052681346123497334, 0.07824156328194565, 0.014038953832500886, 0.032163328160682035, 0.13991134241223335, 0.03702308351714765, 0.08653981235599326, 0.03394799509776696, 0.039386717572567925, 0.03289196587678406, 0.048809602871657386, 0.17088087576050914, 30.24538855398855, 65.53458821388983, 59.81918104233281, 52.845426528684555, 31.692058693978097, 19.11578086114699, 29.233520992340583, 43.41342849116172, 43.66871987619708, 35.36237932020618, 0.1330692732646581, 0.04395366646349431, 0.22525470163072311, 1.7918544046340452, 2.003802618672771, 0.5827370370107313, 38.45639982531148, 75.82784852673932, 63.336123266527736, 63.40334484654089, 61.689928039427734, 63.633799783645145, 62.29837394529774, 66.3525475225141, 60.57597491048998, 58.80022379659838, 51.75941244248421, 58.249970174604854, 61.50102669192899, 56.40520103516118, 48.49127008068947, 44.00112113645, 43.11555193316552, 48.98526122493129, 57.78964473355202, 59.846123803046446, 49.92454336535547, 43.67969466793922, 45.74603849841703, 47.580170169953384, 46.73822164535523, 48.592667272014005, 51.90232399971255, 52.979704949163626, 53.674038994696836, 52.17281064679546, 42.784951040821696, 41.9810220503038, 40.67259388585245, 45.966793414085146, 56.02251891166934, 53.389969179707194, 56.62435170142882, 51.78342127030896, 44.19121096211095, 42.513876038212935, 40.920020918692316, 40.21021704519949, 41.65080555023686, 40.274077153974964, 41.090620486967026, 40.92180167475055, 51.89943321289555, 52.460049736884336, 55.62820696061658, 55.36617302125501, 55.71111017657865, 52.08360810433665, 55.351844603015536, 53.40138327690863, 60.48612517695273, 37.4912888773026, 26.233223561317693, 56.871268826146284, 50.061383093557055, 55.729804192819905, 50.37547472984561, 54.70603027651387, 53.16183236337478, 58.47618895192301, 50.665792880519746, 54.05071204708469, 49.40963422098468, 44.74842679116034, 39.03419240828484, 40.48775611385223, 37.98851597693659, 40.99448711641374, 39.320949046842514, 40.555311095330026, 41.61466875383931, 42.18888021284535, 42.23195568207772, 46.86815800205354, 43.58635794731879, 55.516490013368674, 56.76063445306594, 57.627129170202444, 54.266807186988096, 54.6709172187313, 43.89690768334174, 41.63698704011979, 42.62134505856422, 42.24453864559051, 41.340871626330966, 43.42210085161271, 42.06520788131222, 44.56078452448691, 43.7858183153214, 43.4659960962111, 42.389081908810525, 42.87123141750213, 42.7900226654545, 44.40574107631561, 45.60244444877871, 47.92484452647548, 44.000266059752434, 47.50291516703945, 49.00177832572691, 52.12876242976035, 49.448042069711995, 55.05622340786842, 54.50848402515535, 62.6077312807883, 58.57170258798907, 66.90871607872748, 30.636584181939405, 0.47493418618555994, 3.945574178811043, 2.8968900249850367, 0.27998800659852646, 0.13435833877132786, 0.2258824647193955, 31.19628287130787, 41.12337620027604, 36.53452865539059, 24.26651773914214, 32.22090401957112, 36.500980623306766, 45.19827165911275, 58.1220656056558, 47.73807694835048, 20.496835631708947, 0.5763264132603523, 0.033459579572081566, 0.05726857719221904, 0.035227871379785, 0.06644569382432007, 0.02671632810585922, 0.0148228207422841, 0.04050270083450502, 0.04779574679090612, 0.020836783317668785, 0.039457255118196054, 0.003030998862325965, 0.02841837629075012, 0.03748048014277893, 0.007710707037814803, 0.10231201521932118, 0.015575676412892439, 0.025610202480287805, 0.06584072185139503, 0.05793716127593672, 0.025139828325219216, 0.016557222735437176, 0.05388463659572506, 0.037165809527880726, 0.022133523110120047, 0.08195408665004277, 0.05639411463973023, 0.07530393784925823, 0.038910873549719976, 0.01792569708589825, 0.053563113324344165, 0.04281179709059577, 0.1208806305282539, 39.182297183621316, 75.71926163088891, 66.12380273880498, 60.76948896531136, 39.63266764917682, 25.387223228331536, 20.98638076936045, 37.253663847523356, 49.32422853285267, 39.2542609091728, 0.12209854178851652, 0.03678091929384297, 0.31843465001833055, 8.241911703540433, 4.275324652271887, 0.5171863254039518, 40.55176919506442, 75.93601965135144, 66.9690421319777, 66.31135479096444, 63.37984200446837, 66.0212641377603, 64.39596729893839, 68.60130510022564, 60.57257421555058, 58.52242977388444, 52.79576932230304, 61.47471151044292, 63.24756399277718, 58.391277482432706, 50.290578949836, 46.414779078575876, 44.83742144800002, 52.751615201273275, 58.722184319649976, 61.09884646631057, 51.11960326471637, 45.18090340398973, 47.08652419428672, 49.77833701718239, 49.95288641222062, 50.947262164085146, 54.054120586764434, 55.96753120422364, 57.83012751610049, 54.88066988606607, 46.61337652514058, 44.51570080172631, 42.407834760604366, 48.11824875493204, 58.914251019877774, 56.32710664503036, 58.330484667131984, 55.99594877612207, 46.365914190969164, 43.90343450730847, 44.13889831112277, 43.18589964220601, 43.64564849484352, 44.26974073533089, 42.50083807976016, 42.66551486907467, 53.35909620408089, 55.694608765263716, 57.92510378745295, 55.558918291522616, 57.43914173495386, 55.67710714955484, 59.011412051416215, 54.638455683185214, 62.403199288152884, 38.40586793038153, 28.4493411356403, 59.50215939552554, 51.487188185414965, 57.62184181521016, 53.752447174441436, 56.52817126243346, 54.762771283426595, 59.132374025160274, 54.41769292277675, 55.78047729307606, 51.71274800454417, 45.44072512657412, 41.600716883136386, 42.407870061935924, 40.924406128544966, 42.00412873298892, 42.77550989581693, 43.29771464870822, 43.121568849009854, 44.08420478144, 45.11932611465455, 48.45099518376012, 47.69544078457741, 58.80997873121693, 59.75750961611348, 60.435483455657966, 57.594753926800145, 57.011756358608125, 46.63994273831768, 45.07914535460934, 43.97844983685402, 43.2848531969132, 44.48090937829787, 45.77732332291142, 44.15254031458209, 45.70542627765287, 43.86172402289606, 45.45064872311008, 45.52766053907333, 46.63002698652206, 46.19784062908542, 46.26325399644914, 47.43840786718553, 49.56190063107399, 46.83884220738565, 48.89250893746653, 50.31732951441119, 53.07953319241924, 51.816416248198486, 57.67550768390779, 57.21359760530534, 63.18497080956737, 61.46460356250886, 68.3920152725712, 34.19588212044009, 0.7141753550498717, 3.0314351666358212, 7.098098551073383, 0.517381095597821, 0.10151814128602706, 0.08650809631592805, 34.98342737074822, 46.436348192153446, 28.865161403532955, 21.241778058390466, 34.155352269449544, 42.553154653118504, 53.60984548445671, 63.67428648856379, 54.86956565610824, 28.040016312753004, 1.0602297730022863, 0.08507564979334993, 0.10903151795989084, 0.05431896248351663, 0.03115692994587364, 0.050751988160153555, 0.038398019819250034, 0.05715012467736679, 0.08077235772244393, 0.015392109297306068, 0.023969939286490122, 0.017307050443524798, 0.010689268857541104, 0.04641871523833083, 0.05338447311172082, 0.053082772365380684, 0.04520841123115632, 0.14178516283150644, 0.20658186005969204, 0.2504092599115064, 0.10473343528686993, 0.11231042024108673, 0.13502990676751062, 0.07933462519318828, 0.11315918437415555, 0.21716977740007065, 0.14133032110910262, 0.17561117757952985, 0.11128832871514945, 0.0928732680697595, 0.1678290266183115, 0.12908141789657454, 0.3804263316335217, 48.50841476071266, 83.33770475079938, 75.67856311798096, 68.80670393666914, 48.60197505643291, 28.224334370705392, 41.498864696871856, 57.709032181770574, 59.04627015513759, 43.93426825923305, 0.7210820973400147, 0.13809019819863383, 0.3332700652460898, 5.193158292001294, 9.25950788682507, 1.6571244212888903, 43.97903427000969, 77.75847834925499, 70.73292501511114, 67.30630320887413, 67.26901715801608, 69.74458971331197, 68.55564871141988, 71.51481028526061, 61.90536029877202, 58.84470739672261, 56.381741339160556, 65.84347094258955, 66.19846113266485, 61.366575687162346, 51.51542925065564, 48.39314022371846, 47.75950485660184, 54.666284899557795, 62.36615642424553, 64.79383291736727, 54.13633346557618, 48.60459912207819, 50.30660183198991, 53.28310028199227, 51.25390521941647, 53.475021854523696, 57.76516522130659, 58.29754460242487, 58.553067407300404, 57.792625734882975, 47.10441804701283, 47.96520571554861, 45.60995971002887, 51.61853267300514, 61.92164597972747, 58.927100704562285, 60.6465305051496, 58.25057029724122, 49.94284514457949, 47.239904557504964, 47.273079964422415, 45.438477608465384, 45.059306006277765, 47.012771867936664, 45.156310143009314, 46.936144444250296, 55.86120751596267, 57.84017270611179, 61.60352214690178, 58.213919670351096, 60.374910293086884, 58.29953716647241, 59.33601563976657, 59.22273366681991, 62.05294339887558, 41.969137268681685, 31.97913108333465, 61.6660447274485, 55.389609183034594, 57.6906244985519, 55.00524044036866, 57.359599990229455, 58.54498340237526, 61.78959154313611, 56.196919256641024, 58.44041693595148, 54.26259456142303, 50.494479440873675, 43.28551607747232, 44.28963499684488, 43.61890577500866, 43.6966432294538, 44.900744192061886, 44.992880667409594, 45.737350448485344, 46.88794635957288, 45.84946355512066, 50.27971006208851, 49.0536085251839, 60.9813008769866, 62.61604278318344, 62.535230190523215, 59.66651455048592, 59.938099461217085, 48.8885316541118, 46.23202800750733, 47.128925015849454, 46.041208620994325, 45.93828170530258, 46.73082405521024, 45.46541644680885, 49.11282454767535, 47.64176314876926, 47.411943635632916, 47.54054246410247, 47.74565496752339, 48.47446272450109, 48.55425157854634, 50.65750883471582, 52.175783803386075, 49.18607088827318, 52.69013204882222, 54.24590095396965, 57.10906251784294, 54.29236535103091, 59.87825978186823, 61.38269270620039, 66.35759953529605, 65.80719686323597, 71.61785094968735, 36.87277816957043, 2.382152484309289, 12.877609018356571, 7.280087701735958, 0.9186140075325967, 0.3733912236507862, 0.8010893170872043, 39.65719422986431, 58.273775039180634, 52.8204135740957, 31.251951109978464, 42.3593895666061, 47.47985947516657, 62.25284307233749, 70.15626599711757, 64.54290320796352, 32.795329247751546, 1.183569438515171, 0.17827192351462381, 0.23200033563038996, 0.18057205654200048, 0.12171368219799573, 0.10981810639702505, 0.08391400769112572, 0.13515785877262393, 0.11892860019279104, 0.06917416959279968, 0.18164416594851404, 0.05215647630393506, 0.08411577226774347, 0.15781175285097093, 0.06800111278050369, 0.173865401095921, 0.10170438492129888], [0.02885881364495764, 0.06892067875953452, 0.020674365016842083, 0.00825241020309829, 0.07270344472940891, 0.0021823029589628984, 0.025529378289056402, 0.047192341467786225, 0.030394613089400436, 0.050402472036019455, 0.06520376570763127, 0.03776958257320427, 0.01802276617156402, 0.04356743557558906, 0.015336461628096239, 1.3448423459645242, 50.15921485039496, 65.42040017343336, 55.99594877612207, 42.61796397547568, 31.021068634525424, 22.21902874208266, 49.3078173360517, 40.24744818287511, 52.718365269322554, 17.919732524502663, 0.22281835817040938, 0.3642589040100575, 0.7641541344984886, 7.971481930825019, 0.8212219238761933, 2.769906967878342, 61.398064474905695, 64.6423117576107, 65.60381020269087, 59.935298888914055, 55.41697163735667, 59.96729758477981, 62.367450806402395, 61.30030724310107, 63.58405236274966, 60.36903066019858, 52.163997081018266, 54.79685275785385, 59.500025626151796, 57.80639717655798, 55.361936861468905, 45.00649129190753, 43.171681050331365, 42.21934526197372, 46.43580298269949, 46.161244915377715, 44.30933706222042, 42.96659208113148, 39.72172506393925, 41.33998124830185, 42.76139328556676, 42.245311352514456, 44.15498395119944, 46.37665756287114, 45.60762589977634, 43.43853950500489, 41.52492100192655, 41.772544153275035, 42.83749511165004, 41.458185795814764, 52.3257242479632, 54.91291176888251, 54.07812549221901, 44.197745630818034, 42.56083073154573, 41.74832351746098, 42.593139294655096, 39.36027865256033, 40.56855693940194, 39.95046592527821, 42.60667931648993, 43.56137637169131, 51.456130858390566, 50.86401377954791, 54.77915502363636, 53.4213795200471, 55.75536235686272, 52.347320818131976, 56.403349676439845, 52.1832049277521, 63.49896830897178, 36.67450627973003, 28.198344745943626, 59.4436062535932, 50.85723984626032, 58.48549281397174, 48.74744007664342, 54.62559423139019, 49.8133441709703, 56.047394583302165, 53.52930745770855, 53.5108527060478, 50.35360751613494, 45.46430249367991, 39.04866595422068, 42.07076587984639, 39.54503013241676, 43.17805882423155, 40.04723079742924, 42.066262998888575, 41.6749987294597, 42.1814198647776, 41.63187619178526, 45.76960017604213, 46.19712675771406, 55.981789019800004, 54.74093152630714, 56.04218175334316, 55.139016797465665, 50.27599165516515, 41.149507030364006, 42.84295112855973, 41.083724960204094, 42.46732142663772, 42.15001344680786, 43.458869149608, 41.60258785370858, 42.495570336618734, 42.20891567968553, 45.023082917736424, 42.60743633393319, 44.40716881905833, 43.35271804563461, 45.673521718671246, 43.02043837885703, 43.46419180593183, 43.00805153385286, 45.97506961514873, 44.81890393841652, 48.2218110945917, 48.601100367884484, 53.57800760576802, 54.43273913475775, 57.00099729722547, 56.96398188990932, 65.305462960274, 52.689626063069994, 5.612706772742733, 2.4197741429651938, 2.1487069850967777, 1.3258767055888332, 0.1613394958117316, 0.05012588365183723, 12.898067120582828, 43.70714341440509, 42.3819588845776, 49.28957831475043, 48.12468928675498, 44.426659076444565, 41.18797371464391, 51.51859068101453, 49.03131377312445, 44.78501073775753, 3.982733488082886, 0.14201046929003733, 0.037220764845128984, 0.017362174300116398, 0.007622828134410685, 0.018677062715493867, 0.0688091746621555, 0.06484807108438785, 0.17881060589946088, 0.07305641974052114, 0.09402115123286363, 0.12040219329778226, 0.025907659099527428, 0.03923852169405549, 0.02512949379912067, 0.059039531155459346, 0.020396706024785678, 0.04909800816207163, 0.0039012847992125903, 0.032033284735535426, 0.059245658602805874, 0.04227056363297086, 0.025541944046234413, 0.036836188707140186, 0.05351529411611058, 0.058671418246963335, 0.03798748479194699, 0.07017197613153728, 0.03508216528702648, 0.03964461341139771, 0.06705045895350557, 0.03247946583395524, 3.2097497918913445, 63.82269720877371, 70.90341475702101, 66.33029983889672, 50.11022052457256, 39.99248627693423, 27.13045789349464, 45.468836753599106, 38.77972472098566, 58.42655527976252, 19.371303666022516, 0.1718612997642448, 0.25824453140939435, 2.1629861285609584, 8.582386182200525, 1.9390127855923869, 3.270072413067664, 63.69960146565592, 68.9862229747157, 68.89735775609171, 61.446878371700166, 56.47350911171206, 61.67242642371886, 66.37122584927467, 63.36106169608332, 64.81515884399414, 60.33675739842077, 51.66959801027852, 57.35638364668816, 63.19671830823345, 61.28828910089309, 58.0687213713123, 47.25387211768858, 45.29628384497858, 44.31377718525548, 48.02272727412563, 48.27799120256978, 46.58537080211025, 44.93386076342675, 43.04110142492479, 44.219334356246456, 44.28975266795005, 44.458053727303785, 45.72752883357387, 47.708623870726555, 47.3472676738616, 46.105072652139974, 43.60687978806035, 43.56378470697711, 43.60637772467829, 43.25243088506883, 53.95866186388078, 57.001805305480964, 56.545547362296816, 46.89702664652179, 44.25548291975453, 42.670657096370576, 44.33526392905943, 42.066031579048406, 43.494048887683505, 41.876753684013124, 43.23673355963923, 46.16699118768015, 54.21337273813064, 53.54693458926294, 57.33704636173864, 54.597592430730025, 58.251790154364805, 53.260181873075425, 60.292611122131355, 53.429655721110684, 63.72747382810039, 40.85159124866609, 30.498946251407748, 59.09137348974905, 53.609217905229144, 58.98979979176676, 50.553381673751346, 56.932516636387, 52.19658413240987, 57.43795717916181, 54.57945539105324, 56.46575458588139, 51.81762826058173, 49.41825559062343, 42.07142483803534, 43.68771199257144, 42.04922030048986, 44.960160255432136, 41.92070384179392, 43.40698795933878, 44.28281007274505, 45.126998270711596, 42.174214470771055, 46.70708194855721, 48.536079237538004, 57.21027928013956, 58.12873363494874, 58.91099937500493, 57.451199100863555, 52.48618448934248, 44.10454227078346, 44.14251865879182, 43.54481612482379, 44.8195864308265, 44.02931513324861, 44.592049737130445, 42.67933337919174, 44.47557103249335, 44.021313498097086, 46.130081684358665, 45.80064573595601, 46.99248536940544, 45.58578222028671, 47.74572949255667, 44.28068414811165, 44.93166423613026, 45.323654144041, 47.66425401933732, 46.46212600892591, 49.838690527023815, 50.96312030669182, 54.35924960720924, 55.908425008097005, 61.759491274433756, 60.76152263149139, 67.29685029675885, 58.76746023854902, 6.820131453775591, 0.526870779933468, 4.142507314682007, 2.3986173685519927, 0.21050583901664904, 0.029602533717068936, 12.171696136074683, 54.68470434988699, 36.679813246573175, 39.799313468317834, 52.28823423385621, 50.79404261804397, 46.70455594216624, 56.35555951826034, 56.412253456731, 57.91564695296749, 7.181473922344947, 0.152553585808604, 0.06927410576252208, 0.027231562454553864, 0.03352074786239574, 0.058938143249120445, 0.034397447391623454, 0.03115793352105445, 0.07889135905932035, 0.07305979818826722, 0.030764859552765568, 0.0721069073845302, 0.06816016795534281, 0.040492488882474365, 0.029926006682217125, 0.05897126123008709, 0.10023075351191145, 0.16566029299170743, 0.13357836933385941, 0.1120256883422694, 0.1690787918144657, 0.18870637812201055, 0.1469357558075459, 0.12977347108385257, 0.08699335172892579, 0.19597770165531866, 0.16102564491091237, 0.1525837237075452, 0.11696845698621004, 0.14189365620334304, 0.21518003255609544, 0.15115271743026473, 5.017366486210977, 74.92243213038292, 76.74045070525139, 74.83015444970901, 58.01642048743464, 45.354680092104026, 32.795680299881965, 66.23265635582709, 55.41899558036558, 66.48273098853328, 23.37055229371594, 0.489650581993403, 0.6747716533080225, 1.5361054506032699, 14.086329552435107, 6.174995207017468, 3.48905417226976, 68.42995243687784, 70.11701876117338, 73.31986150433941, 64.3680243338308, 61.356008821918124, 64.33406053050872, 68.85458823173278, 64.17477700018114, 66.80560481163764, 61.67347761892504, 55.91351624458067, 59.14301149306759, 64.75699793907904, 64.13703203201294, 62.620506440439534, 49.66357631068076, 47.728129817593484, 47.550148348654474, 50.94051568738876, 51.14961724127493, 48.18382686184299, 46.52281684260215, 44.83278128408617, 45.68834043318226, 45.79622522477181, 47.86460476536905, 47.50944199100618, 50.40256261825562, 50.6366692819903, 47.488959373966345, 45.52693097822128, 46.33106393198813, 46.31054601361675, 46.17292965612104, 56.33051518471011, 60.56823607414, 57.72723590174029, 48.985367128925944, 47.389425308473655, 44.37903365781231, 45.6003499031067, 43.87684475991034, 45.201790025157315, 44.58891576336276, 48.21044014346216, 47.53085420977685, 55.705218776579834, 56.773841073436124, 59.761369228363044, 56.79181337356568, 60.969333725590865, 56.98662965528427, 63.864227264158195, 56.10708521258447, 65.71717062304097, 42.18251812842585, 33.094433507611676, 61.93966142592892, 56.39296716259372, 61.87875093952302, 53.08648363236458, 62.015398471586174, 54.64644555122622, 60.61188813178771, 58.11903753588277, 59.10414864940029, 55.5235424349385, 51.2688063037011, 44.40170887977847, 46.5446291431304, 44.503404171236106, 48.321211799498535, 44.38297171746531, 47.51201898820939, 46.026535034179695, 47.31985422872728, 46.44442042996807, 50.89434154572026, 49.97168633245653, 61.63167299762849, 59.053985457266535, 61.074268894810835, 60.496488078948, 54.512641737538004, 45.79565255872665, 47.10515545260522, 45.47802294454267, 47.151517868042, 45.05949035767586, 47.77471580813008, 45.22422206017279, 46.38320007631856, 46.945311023342995, 49.30626015509329, 48.27871684105166, 49.99260041021532, 47.41622686386109, 50.99767246553975, 47.374963529648326, 47.70488977432252, 48.12329684534381, 50.83331731057937, 48.140845529494754, 52.10109795293501, 54.75909994494531, 58.83482694625855, 60.44433624513688, 63.085695620506044, 63.27161596667383, 72.46674599186068, 59.29310491008144, 8.88521473253927, 8.679998286308782, 11.788910069773275, 1.7615832676810605, 0.3499631824031953, 0.27751191849670104, 15.679989534039652, 59.54328544678227, 58.390904857266335, 65.56175847207346, 52.94124610962407, 56.081856527636134, 53.82169661983367, 66.39546609693959, 63.41352731950822, 66.01505110340734, 8.623885839216172, 0.31517727480780694, 0.12023841136045034, 0.1357789415745966, 0.1507176101327904, 0.12459002825761996, 0.15221146626337884, 0.10963212323164749, 0.3372442536056042, 0.2614830302134637, 0.18081070825217233, 0.2575025292894533, 0.20016746715672556, 0.17047809737343944, 0.1416981965303421, 0.14748185392348998, 0.1344099424539074], [0.050102215365416584, 0.007570491880253559, 0.09621007893715175, 0.051497246153772845, 0.06742354377263016, 0.027698782242594228, 0.05433703066721078, 0.06043394524303656, 0.0349609510252072, 0.006020283279564953, 0.031727935495455904, 0.02100190973930782, 0.015574142321824067, 0.06872433042454143, 0.03271945819799458, 10.04874760104764, 59.13311143075267, 58.21705756648895, 58.92311165409704, 43.064765084174375, 26.661020786531513, 29.869772580362138, 31.78975512904506, 39.76474561998921, 50.151805493139456, 6.181388180102072, 0.135761474769923, 0.07757680580740975, 0.7263982572382497, 15.721905942886108, 1.6817752920812177, 16.769420985252626, 74.94220872079173, 62.03406110886605, 67.60785502772178, 55.591458274472146, 52.72393895733742, 53.98907199982674, 61.37393797597578, 58.87919287527762, 62.61131240475563, 61.922885448701926, 63.872024936060754, 59.5580021796688, 61.27136799596972, 60.665275512203095, 57.35792906053605, 50.51240467256116, 44.003113700497536, 42.54015984073762, 42.602674576544, 44.21979327355662, 44.68276631447577, 42.75564309089415, 44.0639300500193, 40.93198807008805, 41.406908650552076, 39.99409837107505, 41.39822452299057, 43.55415528820407, 42.135171198075824, 42.4892278640501, 42.66556978225709, 40.04928611939953, 44.067311133107836, 40.01918192832701, 42.629582035926084, 41.67961928152269, 44.7281716715905, 40.9167496619686, 41.587494573285504, 39.352645720205004, 43.685644903490626, 39.4888892481404, 41.78710399135467, 39.743384392030784, 41.85665153688, 43.26630430836832, 51.50630189526466, 49.549109781942065, 54.905216078604425, 52.28872845249792, 53.66269942252867, 48.73887754255726, 57.29315896188059, 50.05443657598188, 63.115874336611846, 34.321970631999356, 26.639845871156265, 59.31575267545639, 49.56518365490822, 57.11147477549892, 49.007136283382295, 51.32672402166551, 47.99553348172096, 49.656006136248195, 51.06948321865451, 51.744291705469934, 48.90561357621224, 45.929197495983495, 41.215277333413404, 40.53380866204539, 41.70612273677703, 39.852441972301854, 39.809511630765854, 41.429623096219956, 41.83434109533987, 40.721325412873306, 41.22425171636766, 43.05996410308346, 47.770075644216234, 53.425035169047696, 54.366141211602, 55.76208529933807, 53.83650356723417, 45.63799681202058, 43.834832252994666, 44.009762117939616, 41.27879619598389, 42.63135886961415, 41.645271085923724, 42.048098502620576, 41.63759892986667, 40.63020090903006, 44.13861982284054, 46.3059489957748, 47.692416637174546, 47.88496578893354, 44.087515261865434, 44.20829288421139, 43.32477508052703, 44.72830110980619, 42.853929842672045, 44.83394622802735, 46.15736176890712, 48.510391635279504, 49.11681752051077, 49.38062437119023, 56.27681401468093, 58.035855831638465, 62.89197368006553, 58.332265423190215, 66.00183271592664, 21.684068441390995, 1.7522551359668856, 4.5406421057639585, 1.8546464029819736, 0.056608266858083595, 0.09655221380413541, 0.6155651915938624, 29.42407758005204, 35.86015555166429, 34.64618590570266, 17.12356786574087, 22.416180795238866, 34.85662891018775, 42.01558989863242, 51.35607511766496, 56.983460380185036, 20.37857028745836, 0.19520949932836718, 0.006758008713668754, 0.07213659329159607, 0.011070604443610197, 0.044309905009163965, 0.04306036963938706, 0.036956410885097525, 0.08439082081519789, 0.06419892648174878, 0.023534711330167712, 0.007680747733120957, 0.06944980036707656, 0.019665838992823998, 0.038692055855907743, 0.019127913119812167, 0.08463006241307144, 0.043716960616650126, 0.017889788629667416, 0.00683173222745198, 0.01444101305453167, 0.012022511781974426, 0.039860945149895646, 0.025684371282677018, 0.08562390061636126, 0.042555893080369125, 0.06754116891252418, 0.01599769031013092, 0.027993770143497857, 0.033522306851321654, 0.08345826964585051, 0.020547439569547292, 16.584471425702496, 70.49116580717026, 63.685343650079545, 66.56431628811744, 50.272434065418864, 34.09799937278994, 29.78151336792977, 31.383938866276896, 40.84295026717648, 58.55094932740735, 5.365081169912893, 0.2465491880091929, 0.025247601574406992, 5.263949719167525, 13.926691047606932, 2.0479709582944072, 19.312801514902425, 76.99090973023446, 65.69834324621385, 69.497205826544, 59.26013346641295, 54.88261930404171, 56.442055625300256, 64.48402058693671, 60.37170179428593, 65.51099123493319, 64.46820166803175, 63.721762857129505, 59.56980066914713, 62.174909499383745, 60.73920434521091, 60.25578398858348, 53.61049659790532, 47.77183286605343, 44.10951975853213, 45.885482680413034, 44.34202217286633, 45.37413112578854, 44.17163049021075, 45.8557197355455, 43.95493522767098, 44.80053547889956, 42.64105889105028, 44.06882124562418, 43.506067029891476, 43.10052533303538, 43.89724892954673, 44.40036742917953, 42.374710344499164, 44.38066536380399, 42.424057683637066, 45.771380932100364, 44.80699170020319, 46.43997638456283, 43.296086865086714, 43.187154800661155, 42.50528604753556, 45.1366316118548, 41.02619947925691, 43.91423671476303, 42.16521655359576, 43.38043743564237, 44.06851530075074, 53.018254003217145, 50.98668590668709, 55.37737923283731, 54.169022498592255, 57.234013542052246, 50.8173022731658, 57.890002496780895, 51.592460678469756, 66.24143462027273, 37.285525260433076, 29.819152432103312, 62.43934785166095, 51.893204489061915, 57.61783315289406, 51.19421066776399, 52.08260397757254, 50.09287580367058, 52.313325635848514, 51.57264486435921, 53.28914465442781, 50.41355309947845, 47.841545151126006, 42.57539449199554, 41.8342234242347, 42.94835698220038, 41.435043811798096, 42.81534548728697, 44.05124510488203, 42.97666472773398, 43.21530172901769, 44.35404815981465, 45.72625014089769, 49.4337881765058, 55.64976038471345, 58.3616518205212, 57.97618481420702, 55.310855834714836, 49.68242329935874, 45.48152169873638, 45.01368884117373, 42.93564850284208, 44.84412870099468, 44.544392939536806, 45.06363238057783, 44.85661360525316, 43.21715308773903, 47.382973009540194, 47.15416154553814, 50.94816823159495, 49.662262316673036, 46.15979363841396, 45.17060325991723, 44.54559318480953, 47.264697859364176, 45.785034702670195, 45.08814719415481, 46.634439652965916, 51.45656231910952, 49.92271946322534, 52.94912615130025, 58.65244850035637, 60.42305738695207, 64.83759087900962, 62.509828921287294, 66.77053882229713, 26.410624519471202, 0.9137290019181468, 5.216047773438116, 4.62265053103047, 0.15529461775816258, 0.1350730375176476, 0.3006117370340132, 35.331796599972634, 39.12729378669493, 32.21281609227581, 18.330116387336485, 29.352580616551062, 40.02920750648745, 50.07518983656361, 54.47139409280593, 64.74274404587285, 30.367617453298262, 0.20918859679612423, 0.041092573214442506, 0.06923908022262397, 0.01355841847872662, 0.09037802776982708, 0.03683409345666728, 0.046077802281586394, 0.049433864938515815, 0.02033038962362034, 0.01956475943687462, 0.052580065469467835, 0.054047100861827214, 0.02857720355443176, 0.01937989667508631, 0.05383801248465335, 0.008173897682178405, 0.21090926091757514, 0.14102952434651314, 0.19026236398325813, 0.2398771597372909, 0.12855090200901031, 0.09883199953624318, 0.1086243652107735, 0.1797400544127149, 0.1579124934130138, 0.12389963748113764, 0.1850609946995974, 0.23429821635926926, 0.09395134530120319, 0.29824826385705705, 0.19990259991778483, 22.070178716413437, 82.63087795626733, 69.58300375169324, 74.57564753870811, 56.67955121686382, 39.2192655224954, 41.93555785763649, 46.5990637963818, 50.976668173267, 66.96522174342986, 7.603457214370851, 0.437203896261992, 0.17220452247608095, 3.690279606849917, 32.75546423850521, 6.712687438534153, 21.59884318228691, 80.69873409886515, 66.67965750540456, 73.22811726600894, 60.55581392780427, 57.75964252410397, 59.758070515048125, 66.22367412813249, 62.29452217778852, 66.86312244784448, 65.26070871660787, 65.05015588575795, 60.1617451637022, 66.59722497386318, 63.39985001471735, 61.388223248143355, 56.728522008465184, 49.12665090253277, 46.347012289108775, 47.925695680802875, 47.43450510886408, 47.42751544521701, 47.23654308626729, 47.33519069610104, 46.630356465616536, 47.04820656007337, 44.99306894117787, 47.01203053997409, 46.715875902483546, 46.16575171870571, 47.168125183351584, 47.42597003136912, 44.43963427697459, 48.5045120023912, 44.29424378179735, 47.41370085747012, 45.80829043542185, 48.23512754132671, 44.157576637883345, 46.07724735813756, 44.764841910331484, 46.498804092407234, 43.09739528163787, 45.560380951050796, 43.92668239531979, 45.69403571467246, 46.17175294506935, 55.3915350667892, 52.617921213949884, 57.9673320247281, 57.10543040306338, 57.86405601809102, 53.342010359610285, 61.44517214067521, 53.46429809447258, 67.88800639490928, 39.2791836492477, 32.573662381018366, 62.892867980464814, 54.36207371373331, 58.599724000500096, 54.26197090456563, 53.61441504570746, 53.768709321175855, 54.08003568649293, 54.47350040558846, 55.69727989935107, 52.51924614752493, 50.32577829976236, 44.97959559963596, 43.26859889491912, 46.87839931057346, 42.69375201194517, 44.31813101614676, 46.47804298708516, 44.88026549739223, 44.396437214266875, 46.580867921152425, 46.82326647543138, 52.3255124399739, 59.26493052513369, 59.28108284550329, 60.031467560798895, 57.72223095740042, 51.283111187719534, 49.25589692208075, 49.180960039938654, 45.15017947842998, 46.445750113456484, 47.39847421646119, 46.62173509597779, 46.10122872937111, 44.352883215873476, 49.41720439541725, 49.891230675481985, 52.67689012712049, 51.925014911159394, 49.26000364365117, 48.605469888256444, 47.62056273798789, 49.705710411071784, 48.42355820440477, 48.61704088026478, 49.34406395881407, 55.140028768970126, 52.71921250127977, 55.27657039703862, 63.29646418171545, 63.201201577340406, 66.73804590778967, 64.58537855455953, 70.04731824321132, 26.652126812165786, 4.368265213504914, 25.41827859417085, 6.531866663886655, 0.2324497228067729, 0.24332288532487809, 0.9154714535801642, 40.910454257842034, 52.113096483292125, 51.32606898584674, 21.99685588959725, 31.6728743814653, 46.15385909234324, 57.482683966236735, 64.72705064281341, 72.9771561776438, 34.601659159506525, 0.5984839436507995, 0.10430594290336294, 0.1476526302435706, 0.11140484302755325, 0.1396582269620511, 0.13744804797874344, 0.21494321945694186, 0.18585435535398223, 0.17875607576101057, 0.10531037610264556, 0.11246782832688863, 0.13280613738442623, 0.13997675099920842, 0.11295189630360374, 0.19678489785761605, 0.13896283363142323], [0.02161185936852088, 0.07289513524982237, 0.015603688417843755, 0.1346627974341954, 0.07625263815204944, 0.02501641922149687, 0.026963334004845352, 0.013681719372529658, 0.01744860433973372, 0.06584347976792244, 0.04478674494631348, 0.02366008161897621, 0.019634527064138846, 0.044237459904604384, 0.4855390187473067, 22.954959523293283, 62.90476060682728, 67.46596720910841, 51.2561958835971, 34.40021799456689, 20.16731535234759, 35.93701047282065, 50.2203175329393, 43.187205791473396, 45.9983253479004, 0.8353855412813925, 0.06108788938652124, 0.10605539660900833, 4.843998705187152, 6.890317365046471, 2.444945218101625, 42.44408138336674, 69.1421607232863, 63.8053564102419, 63.16196610850673, 56.64843897665701, 51.6112841329267, 47.16574430465699, 52.708002367327296, 57.75289212503741, 59.9134159857227, 60.83057203600484, 61.919892680260446, 60.85775013892882, 53.628594413880386, 56.099562106593964, 58.02796010048159, 53.70972471852457, 46.65381223924699, 43.633697032928474, 44.16386419726957, 45.5486765984566, 43.921371506106475, 42.38823859922348, 40.863723139609064, 42.06292506187193, 42.54923228294619, 41.50397554520638, 42.142051035358065, 40.719226944831114, 42.10468261472641, 43.20996338321317, 43.39846464895433, 41.97433833153018, 40.535452135147594, 41.3873674023536, 42.88540294093471, 41.300027985726636, 42.86684620764948, 41.04607805129021, 45.05463054103237, 42.26687262135167, 44.2426920706226, 41.98079063046364, 40.37033604037377, 39.801823785228116, 42.51069107363301, 42.50420739573818, 48.494592328225416, 49.04402617485293, 49.093455883764456, 48.46903024181243, 52.78301769687284, 47.737982811466345, 54.15038339553341, 50.402044865392874, 63.02701304035803, 35.08116891307216, 28.094931456350512, 55.2399472267397, 51.66797414902718, 54.28276731121925, 49.96648526960804, 49.14485070013231, 44.32777612440048, 44.431095277109456, 47.69153802625595, 50.57910065497122, 49.11358940985895, 47.4109551983495, 41.583356472753714, 39.85194775366014, 41.172735306524466, 41.07884945407991, 40.98112360123665, 42.61259425070978, 42.74509583750079, 41.277121343920314, 39.62779998779297, 44.20123261790122, 44.59252042155112, 52.805987096601925, 55.01460313796998, 53.77351030226677, 49.290939377200225, 42.959990732131466, 40.56068866483627, 43.03202506034605, 41.937189563628166, 41.70413017272949, 42.33733407912716, 44.02941711487309, 40.53677005152549, 43.539407176356164, 45.86045795871366, 50.29737249497445, 51.88892910557409, 51.19121397695234, 48.916474619219386, 44.69473346587151, 43.701801146230395, 45.04711920215238, 44.541043235409646, 45.1242486892208, 46.09176405014531, 51.887340545654304, 51.45389118502217, 54.123307274233916, 60.2854214176055, 59.009984308673495, 62.75752267529888, 62.12756256903372, 63.329263041096354, 49.7287033450219, 5.912692095002821, 2.50443997402345, 5.979620477845592, 0.1914585030247127, 0.054197349855976726, 0.2095025089839774, 14.735412193882851, 43.58699729365688, 38.793182373046875, 23.78690012039677, 11.597695504465412, 25.25411955771908, 40.610953838594504, 51.50712951537102, 54.42203106418733, 46.32967933531731, 1.7385371365854818, 0.12064679751112578, 0.09516666718428174, 0.06347002446531289, 0.05376020859506342, 0.07925292191606376, 0.09516418505940707, 0.03263680497184396, 0.017951933682085048, 0.010960214046551096, 0.04679273085428342, 0.03354024480006868, 0.05900485035512717, 0.11446413088349566, 0.052748803995669856, 0.035000006187587016, 0.04032425214386275, 0.05014093344910972, 0.08202616020195908, 0.07539807473339381, 0.07514402465594393, 0.01854807266124314, 0.04305620595151859, 0.03938250025854476, 0.01379258953215134, 0.02656099803355192, 0.018067492299803325, 0.01937313786437435, 0.09660809225733243, 0.012053704009421412, 0.658567238959574, 32.97365588526572, 72.53354395589521, 72.21423948964765, 59.745503241016024, 39.762125476714104, 28.06867511041703, 35.74695202612108, 45.24367309385731, 47.81249607762983, 51.34113480967861, 0.5942208788567974, 0.08095337663807216, 0.3500467166304589, 9.100994121643806, 8.89919896279612, 2.5571588354725994, 50.39392555913618, 69.6505077423588, 67.64469392838018, 63.37279350526872, 60.46026106803649, 51.34364512658889, 49.89710246362994, 54.68046426773072, 61.24995185482887, 60.67345365401238, 63.20438261955016, 63.4405485276253, 63.14944198054653, 58.62355239929692, 58.38286399841309, 60.867748260498054, 54.65650250834804, 47.690702561409246, 45.34674121487526, 46.00966099769839, 47.168199708384854, 45.3705382347107, 43.89589178946711, 42.307857467282204, 43.5102012080531, 45.254844004108065, 42.394392798023844, 43.543792386208814, 43.802476621443226, 44.357574370599565, 43.3994609309781, 44.04593029329854, 43.09788165553924, 43.09732467897477, 43.19964362728981, 44.155615452797186, 42.28869276662027, 44.154101417910674, 42.80240166571833, 44.86785511816702, 44.7502467709203, 46.454179286956794, 43.42079077997516, 42.97453488073042, 41.05566432399135, 43.60732693825999, 44.504031750463675, 49.91578863513086, 50.772367600471746, 53.44130908289264, 51.06689837671096, 55.13708699134089, 51.200294263901256, 56.70797271113242, 51.74192651625603, 64.35616308642973, 36.69473002033849, 28.005736758632047, 56.60326896175262, 52.5133704370068, 57.78824836977067, 52.274549084324995, 52.18684096490183, 45.97192387427054, 47.140064547138834, 49.76326727098035, 53.22408822274978, 49.754292888026086, 48.38356964049801, 44.398841627182506, 41.650119135456706, 43.739310772188254, 42.21455212562315, 42.366779312010735, 43.89486805085213, 44.6273079226094, 43.69542729470038, 42.916511258771344, 44.77331815227386, 47.89188484991751, 55.780041909986934, 54.98626009110482, 55.42784444747433, 51.16596568015314, 47.02287197113038, 41.98782736255277, 43.893059838202696, 44.172093329891084, 44.349102051027366, 44.94130934438398, 44.67777705961659, 43.24093441809378, 45.60079313093617, 48.61986890915902, 52.23608632241526, 54.13071663148942, 53.89608829252182, 51.17641095192202, 47.69829627006285, 44.737420620456824, 46.32822805835355, 46.48289103661814, 47.59075272467829, 48.62618784750662, 54.70266096053585, 55.20877222861014, 54.7420847031378, 60.894973431864095, 62.29822881760136, 63.967346375988384, 65.6079992940349, 63.6447863424978, 53.51781883547383, 7.38460268705122, 1.1983712378048128, 5.809811757456872, 0.6428031719500019, 0.0676979334844697, 0.39522607780752644, 15.073954905233077, 51.08964812371039, 34.49576693196451, 25.708375130930257, 20.951579540006577, 33.715281947966545, 45.330632040577555, 58.82422870205295, 59.81273266576952, 58.24035252294233, 4.620201501154131, 0.061584176465628616, 0.010986351051307734, 0.05026976645533597, 0.0129002608516584, 0.07898284527923792, 0.09253237426521317, 0.024667023756210844, 0.022944256723407778, 0.05722965992566559, 0.06841195807341607, 0.025865945612050356, 0.049946745482063105, 0.06781787220989505, 0.043083352277115475, 0.07414896071197526, 0.11739922822603296, 0.20922034347970642, 0.14996391751112478, 0.22136613125762633, 0.15778440351207412, 0.13037906358799628, 0.10780441364453686, 0.09550686384881697, 0.1715117491661541, 0.16308153378626994, 0.08106809830473316, 0.13220373180604753, 0.15034481642707703, 0.2375029613293948, 0.827553119630583, 44.3359346543589, 81.15485868146344, 82.69287493921097, 67.44726534812682, 48.39565054062874, 31.551512325963667, 50.404504191490915, 65.9985222355012, 57.76169000133392, 57.41048097610474, 1.4091964282335774, 0.12114676947314894, 0.27582284784124744, 9.605028494711846, 14.466822993370796, 4.663243139943769, 52.34892114516228, 71.8991711831862, 69.91407532845774, 66.21338182880034, 62.86265788539764, 53.94296453845117, 52.74567673283239, 57.94804573059083, 64.2319377007023, 63.32308923044513, 65.28023819769582, 65.72855334128103, 65.64702687724944, 60.34334305794009, 61.779048212112926, 62.9771871720591, 59.01895869162775, 51.120764286287375, 48.17060062962194, 47.310640581192516, 49.202744883875695, 46.67490282366353, 45.86536092142905, 43.38499915215277, 47.03185812119515, 47.982981897169545, 45.27018831622216, 46.51083007935555, 45.0418593037513, 46.47408923795147, 46.08621781872165, 47.46003581631569, 45.20206851343955, 45.585774375546364, 45.55651741643106, 46.7712950706482, 45.13956162237352, 44.38198720255206, 45.27344780583536, 48.96490804610714, 46.77443296678605, 48.1703652874116, 44.847494094602524, 45.415763162797504, 43.53733224253501, 45.80645084381104, 47.91365792674404, 52.63530908092376, 55.202963198384936, 54.779049119641705, 53.825473862309615, 58.16565098301057, 53.66811621573664, 58.672997797689135, 56.162900540136526, 66.48189944605674, 41.02707809017551, 30.561843418305923, 57.07965258629092, 55.077345371246345, 59.18815405138078, 54.579404400240996, 54.02048234016665, 48.33362610109391, 48.16739605319116, 53.81877837642547, 55.556188321882686, 52.981634755288404, 50.77654884707544, 47.45556431431925, 43.7146508309149, 47.14617167749713, 45.514814776758996, 46.253401002576275, 47.09707144768008, 47.64911367047218, 44.69232120821553, 43.23696105710922, 47.06935205767232, 50.39430210667272, 59.24058045110395, 59.02894504608647, 57.367570246419604, 53.62449161468014, 48.97498461507982, 44.55417533074656, 46.35808121773505, 46.23122784399217, 45.84381926444269, 47.060514957674094, 49.53212984146611, 44.36426593411354, 48.803020061985144, 50.32753552159956, 55.193855454844815, 55.444192886352546, 56.124288728160245, 54.62823398651616, 51.15208441211332, 48.87270489046651, 50.4602018479378, 49.21366084006525, 50.006364007149976, 51.76383295366841, 56.890005988459436, 57.26855393378966, 57.49910693014822, 63.88164258772328, 64.77635091350925, 67.54327712520477, 67.84771580849925, 67.75318668734643, 54.64291934044131, 8.242331397148872, 7.967720377829767, 15.510312703347976, 1.0113269487215628, 0.2926814399899975, 0.6440069718706993, 18.565397800937777, 59.909199437787464, 53.697361407741425, 32.657189253837835, 18.880893645748017, 37.664763542913626, 53.2334077742792, 66.11719746743479, 65.20559157094648, 67.75244143701369, 6.0701978110498, 0.2667121931670174, 0.15597473529558029, 0.11062844355981197, 0.14092711371279534, 0.19879184903637057, 0.21060040491002224, 0.1442465114016687, 0.07825081762407096, 0.10420051388322346, 0.12541815398200867, 0.2063496741316011, 0.20220408125990824, 0.2321258361541456, 0.14618020925310352, 0.17894142307341102], [0.03189165040009445, 0.04791585022523519, 0.05335593633654137, 0.05663687641161585, 0.05006215279741634, 0.04751948399409171, 0.039218492325275175, 0.08960537447203552, 0.028141632773763234, 0.0795654321630155, 0.050722934275625214, 0.016089794188437444, 0.018832205096259713, 0.07894781973933981, 3.181678124012486, 45.10747271199381, 58.08827830899147, 60.18233368473669, 49.571894830273045, 34.49633567563949, 30.299795750648748, 47.709941787104455, 37.19757395405924, 49.35411699356572, 29.621211982542473, 0.04454685600414392, 0.1645779180070085, 0.18765271611271367, 11.987041734880018, 9.271009256762843, 5.621604179182361, 45.26355951063095, 69.41077247742685, 63.797696021295366, 64.22880372693463, 60.24305981974448, 52.569123006636104, 45.791808635957786, 45.82195205073203, 49.61121659125052, 57.195848880275605, 57.74193302277596, 60.66231020035283, 60.78781427875642, 58.12473281737297, 58.08981195572884, 61.32912881912724, 52.742056385163345, 45.18869715352213, 44.0564775466919, 43.46795335892708, 41.47467151764901, 43.99742626374768, 39.513062815512384, 43.03259772639121, 40.932839224415446, 41.56983606276974, 40.625909836061545, 42.75532537891019, 40.485853764318655, 42.92716441615936, 41.076680383374615, 42.818687346673784, 39.60353228353685, 43.098599449280776, 42.757502294355824, 42.04643149529734, 40.74620108450613, 41.249135232740834, 39.33597172460249, 42.23861586663031, 40.593911140195786, 43.66836686288157, 41.17119773741692, 42.34683013731434, 40.951862719751176, 42.056798319662775, 39.9633744455153, 44.67038731421194, 45.51523839273761, 48.28966809857277, 48.35661511267386, 50.199070053715865, 45.55180664985411, 53.905109743918146, 48.60054731369019, 64.1262415916689, 31.89147395472373, 25.954841183077907, 54.82307380245578, 48.310248774866906, 58.19541392787811, 52.417350815188506, 54.520215834340746, 43.50162298448625, 45.05107687365624, 45.050461061539195, 47.97988714710359, 45.0998790033402, 45.3177039084896, 41.050471105883204, 40.68724786081622, 40.01626760728898, 41.07375429522607, 40.339753320140225, 42.17998035492436, 41.14636128948581, 41.94066086123067, 41.43287474109281, 42.57442566656297, 43.78445725287161, 43.02003045235911, 44.752200111266106, 46.17186277143417, 42.58664384964974, 43.163373470306404, 42.16326321324995, 43.71691011613415, 42.08575325627481, 43.50350572216896, 42.81323132976409, 43.18538188934327, 41.13217015420237, 47.507449426958644, 50.563744575746604, 53.247504772678504, 54.268089802034446, 55.56777108100153, 51.0224461555481, 48.14064156624579, 44.21426665398383, 43.898711973621005, 43.643859894044944, 45.36330146174277, 47.75542951399281, 52.216913777012984, 53.422807262789824, 58.0309489465529, 56.705285887564386, 62.03562613456481, 60.65430072046096, 60.79744761989963, 59.839365559239546, 64.95044139123732, 26.140475196223107, 3.34527944845538, 3.702783387514853, 0.5831763424700307, 0.05906629443709409, 0.038455652613793655, 4.1570627400952, 36.89413547515869, 37.31466847081339, 32.69740727639968, 16.357074956740103, 24.965411540000673, 43.85985697469404, 51.85543598667268, 52.440210388552764, 55.14292347815729, 12.777124758689636, 0.1793628173970407, 0.04178151225430831, 0.014199278798074493, 0.04193304827617061, 0.015188466847663926, 0.01162260143657125, 0.07438340659944281, 0.02668745233677328, 0.023798270473977732, 0.06411215170256554, 0.016317128864747864, 0.011814352286408746, 0.06534947563082942, 0.05684671555495551, 0.04396622647501288, 0.09615806922797235, 0.06812531861566729, 0.06845748667875606, 0.057244744196894674, 0.0199561863161263, 0.036371962407663945, 0.03926418563951889, 0.026212150321131753, 0.046137917201004686, 0.05078895956337933, 0.010727866282386166, 0.06424677250305973, 0.07485180041722714, 0.11343355110335736, 4.308237750684062, 56.56233118426416, 64.29571543970417, 67.04025668482628, 53.8173153323512, 43.4363704342996, 29.788754063267863, 45.33936323658113, 41.72569144156672, 57.65646065435102, 33.049349784851074, 0.09907614409683213, 0.19714135856878376, 0.499013677960442, 13.702255968124637, 10.488133468935567, 5.22282317761452, 47.49729833295269, 70.14640515850436, 66.32207855101555, 66.85930205929664, 60.92396759217786, 54.64176224124048, 48.76058393909086, 48.906958949181345, 51.9337421847928, 59.059476775507775, 61.15559531796364, 62.835722969424346, 63.177773260301166, 59.86311158826275, 60.87198442028415, 62.335538402680434, 54.18587300085253, 47.758469350876354, 44.75721290034633, 46.330506955423665, 43.4215634868991, 46.04744518956831, 41.393631427518784, 44.993963241577156, 44.53042930172336, 42.274587923480624, 43.564008282076934, 44.12871976052561, 42.19301831337714, 44.17323473961123, 43.322633466412945, 44.44514128469652, 43.57323369672222, 43.502893832422075, 43.114704701208304, 43.93707275390626, 44.249411090727776, 42.194198946799006, 41.52198314666748, 43.735388402015936, 42.77649441073018, 45.71781704502721, 42.67543846561063, 44.808160566514545, 43.560693879281324, 43.20773547695529, 42.49769626125213, 47.23336988879789, 46.78174818715742, 52.22597445211103, 49.89805559958182, 51.11731260053573, 48.185435033613636, 56.076420122577304, 50.87973463919855, 64.76338355771958, 34.069166029653246, 27.325805656371582, 54.519925578948, 50.455581295874815, 60.21270459698093, 53.734176774178785, 54.499235076289025, 45.641962328264796, 47.94132240356938, 46.74064567012172, 49.46778335878926, 48.47540017097227, 47.605681265554125, 43.481944453331735, 42.63014293486073, 40.734167252817464, 42.776129630304155, 41.64718520256781, 44.729411140564956, 42.444830556069654, 45.17580040039555, 44.36017097965364, 44.892436612036924, 46.93495596608808, 45.55388942841561, 47.99390569809945, 48.8743209069775, 45.649771767277876, 45.261833667755134, 42.646624734324796, 44.81755072070707, 44.28665791788409, 45.47178245359852, 44.54515780172041, 44.29586372067852, 43.56729522828133, 48.68702380887924, 52.69893776985907, 54.128657387148955, 57.14633287922029, 57.67475066646453, 53.11269683222617, 50.90503000443982, 46.06495072764736, 45.83942228747953, 45.68302562159877, 47.48561359220936, 51.57944625423801, 53.00287831214167, 54.95261399976669, 61.151339546326675, 59.22570290104036, 63.336464512732725, 63.12384067043182, 62.54342794418336, 61.7922705219638, 66.67720994641705, 32.09819659110039, 3.477539319184519, 3.266464322805405, 1.8288231112303275, 0.2364179050369609, 0.022981308565865603, 2.9900673993172187, 44.51899559267106, 37.95996896682247, 29.800019110402754, 18.69302192041951, 33.37611067679621, 51.26338951049313, 58.20614553266957, 58.332579212804, 64.11653372549242, 20.118911343236125, 0.12379269160690809, 0.03397492308830542, 0.026514496496548096, 0.01338713271017637, 0.0027006543278994583, 0.02832184538185116, 0.07420134580423755, 0.06006124729831373, 0.04605909824491509, 0.06522472587323959, 0.006323879135907778, 0.037807772056229656, 0.026139354731346813, 0.054128436416748076, 0.0578587866508432, 0.15757965885343092, 0.1395450451321179, 0.16438176885487574, 0.11944287501636053, 0.16670111536739335, 0.18176603521550858, 0.1597020594823745, 0.18279031009203006, 0.19498702739515614, 0.22133919560620863, 0.17510905291043943, 0.1932829107728697, 0.1518094539642334, 0.28192375756559834, 5.139027622438246, 65.71351105167021, 74.18550506714853, 77.4521255493164, 61.2883714706667, 49.58206945850004, 41.75303036166776, 59.513699008572495, 48.56313182461647, 63.65854209469211, 35.86308163981284, 0.4640397111014013, 0.3910926044467957, 0.4260392679322151, 26.53063924081864, 22.047995751903905, 7.7339216201536125, 50.87149766183669, 73.2271602076869, 68.89799318005963, 69.05470755792433, 64.25620932732859, 56.59130573272706, 50.39374513010825, 52.40694476712135, 55.79515480226087, 62.97488474076795, 63.507307267958126, 65.43128082829138, 66.35739557204708, 61.7114540069334, 61.58931139976748, 65.3191481098052, 57.46830063481485, 49.54896857661586, 48.45629038349275, 48.1043125737098, 44.56611502555109, 48.069905542558246, 42.502324658055464, 48.30534188978134, 47.17429899400281, 44.22174269153226, 46.23709963214013, 47.83834057469522, 44.84419930365778, 46.933010470482614, 46.56839870637464, 47.428201859997166, 46.117639926172075, 46.317653348368985, 46.95044932826873, 45.79471903462564, 46.56889684738652, 45.17259190159459, 43.16206339866885, 46.1154551659861, 46.07157953323857, 48.989858242773245, 44.84114769966372, 47.651161147702126, 45.01515580761818, 45.24253560650734, 44.883375936938876, 48.282297965018984, 48.49873827349756, 53.42602360633112, 54.01759547571982, 53.684523490167436, 52.56385134112451, 58.46615160665205, 53.865678156575854, 68.44560269386538, 37.63513788100212, 30.669518363091257, 54.41955212623843, 52.999563909346065, 61.19518380011282, 58.1915896169601, 58.00791286653089, 48.697480847758634, 50.13473533814954, 49.36695491113971, 52.74773989954303, 50.73158279542, 49.58375215530396, 45.20826978068198, 44.39730013570478, 43.449820241620465, 45.82223838375461, 43.74350770827263, 46.86416502921812, 44.75632644468739, 46.620126924207135, 45.9777525163466, 48.43146570267216, 49.336011332850305, 48.8960273035111, 50.1321191172446, 51.755286109062936, 47.892539885736284, 49.00966621214344, 45.235255687467514, 47.29588462460426, 45.650736670340265, 47.61303570962722, 49.18826349319951, 46.62006416628438, 47.0169884158719, 54.52970797015775, 54.860540282341745, 56.63353789237238, 57.93791424843573, 60.00996120514409, 55.77247565792453, 53.67509018990302, 49.49172942869125, 47.4096372819716, 49.10706650826239, 50.334348678588874, 54.2510941720778, 56.921063315483835, 56.69673904295891, 64.15445912268855, 61.16402056909377, 66.97103469602524, 65.03386236006214, 66.35933322291221, 64.30840038484143, 71.48438838220412, 32.26491301290451, 8.618076808990972, 11.28620538019365, 2.7403501925929903, 0.29727297264241404, 0.16932066109391952, 5.543682373339131, 49.07736239894744, 51.76205611998036, 43.351584480654815, 22.7889314774544, 36.4028468439656, 55.17929169439501, 66.48659844552317, 66.45739247722011, 71.26271170954551, 24.683871653772172, 0.4440492902311587, 0.13586587723224394, 0.08673917907740801, 0.16777527788954397, 0.05629900865437043, 0.13192792483154805, 0.25318418359083517, 0.10616575157450092, 0.12494526322810881, 0.18901782350674753, 0.0849577182182862, 0.25969917916001817, 0.13379727129734334, 0.30133087909029377, 0.1431064959615469], [0.046889621824506796, 0.028796268311599572, 0.04674397318834259, 0.06416912183105465, 0.05789973788083561, 0.029075022809387698, 0.0601474168680368, 0.004250030286775361, 0.07655293695748815, 0.026050624512736837, 0.0429047963341638, 0.07335946114072878, 0.06667681489019625, 0.22095085031563239, 9.747613514623335, 48.69564910088816, 57.3511786614695, 59.02924706858974, 39.62416002827306, 25.213921147008097, 38.82787965959118, 38.46996730373752, 38.39004116673624, 59.30521718917355, 19.980549735407678, 0.2989677429920243, 0.26550119201983174, 0.6544473406768615, 11.953234826364826, 8.081253872763726, 2.601721618444689, 52.87551110790622, 65.59003483864569, 64.89945057899722, 64.52086733233544, 62.67900859155963, 57.25882253339214, 48.818368296469416, 45.95279055256998, 44.90597663387176, 45.668316733452585, 50.27876477087698, 56.0164039365707, 59.114672368572606, 59.627447743569654, 57.189271065496634, 55.94626803551951, 47.32614963285385, 45.81112630905644, 42.902845721091, 43.78815212557393, 43.2066999712298, 42.56355285644532, 43.550154470628314, 41.78722950720018, 39.94926960237565, 42.689480550827525, 41.63888154491302, 40.72013693471109, 41.911623554845015, 42.83172138275639, 42.1219410434846, 41.93620504871492, 40.857443424963186, 42.676305309418716, 41.063611045960464, 43.16459332742999, 41.393305870794485, 42.2005610312185, 40.27684634731662, 42.80368428076468, 40.57624870730985, 42.64405558186193, 41.718815526654645, 41.81663943875221, 39.00874407060685, 41.91960557814568, 40.71112332805511, 42.580568098252826, 43.54272942389212, 47.652533977262436, 44.19704352655719, 49.66320368551439, 46.753836601011216, 52.52047777175904, 49.367507965334006, 61.915240749236084, 33.12283931239959, 27.445930204083844, 53.09275157989995, 46.57468626576085, 57.55304344238774, 52.51235454313217, 55.377787159335234, 46.155969327495946, 46.484769851930686, 40.81033968156384, 45.22187648280975, 41.8211462420802, 43.2193809939969, 41.157206643012266, 41.38798321447065, 38.902738094329834, 41.45523225107501, 39.69157772679483, 42.830827082357104, 40.52590900851835, 44.50564776697467, 41.247476070157944, 41.81247780399938, 43.24362908640216, 42.30788492387341, 40.78406764614967, 41.0942526017466, 41.15302539640858, 43.32057029970231, 41.29479946628694, 44.0530062490894, 42.749990955475845, 42.785005954004106, 39.96511990024198, 41.99460914058071, 45.01943903584635, 51.900978626743445, 52.50819290837934, 56.96382499510243, 57.39829809434953, 55.006691717332416, 55.30295225881762, 51.0613246886961, 46.17621267995527, 44.35532293012066, 43.353706482918035, 47.471775470241425, 50.58421934804609, 56.46507993821175, 55.31669624390141, 58.757218930029104, 59.3267313895687, 56.87060202321699, 57.747432185757546, 64.14271162402245, 64.27418554982832, 61.792780430086204, 57.12188474593624, 12.408409214788868, 1.219732465763246, 0.13889966202118706, 0.27590910934152146, 0.1327391812998441, 0.22189154499961486, 25.383651910289643, 41.375137452156316, 44.6957964281882, 47.272389627272084, 15.950714465110535, 27.33864945750083, 42.37377682039815, 46.54883392395512, 56.94421706661102, 34.0679814738612, 0.12430062322246453, 0.009260804076949436, 0.09615416984043776, 0.027112114025400053, 0.0034528736667256924, 0.04251983332177324, 0.007279262119423479, 0.062155478874281536, 0.0635903692173381, 0.04291640639665627, 0.0223724429510654, 0.02822738865600719, 0.02448144470221333, 0.046856201238810055, 0.07850909650686287, 0.0495724770570955, 0.04882745655073274, 0.050992842373107715, 0.05764111425847777, 0.015324122824465797, 0.015030190209677864, 0.05046793807958884, 0.010158457068516123, 0.04315395877065678, 0.0598843269530804, 0.05786956167749821, 0.12454164214432241, 0.11224252952923698, 0.26168549193009255, 13.360678322853582, 59.51119653640255, 63.737722981360655, 68.06996514720302, 45.91524170291039, 36.738323242433616, 49.44735173256167, 38.643779293183364, 37.35400199890137, 67.74290223275462, 18.998211737601988, 0.24705508183087074, 0.13723221036695665, 1.9736050261605171, 11.013249601087264, 5.9698322030805775, 4.0607334961814265, 54.836825632279925, 68.26234955941477, 67.07707989600398, 66.57043518558626, 63.790529850990545, 59.20806400237545, 49.354246431781405, 48.1177153125886, 47.162833905989125, 48.98419434024442, 52.77416882976409, 59.920056558424434, 60.04283458955827, 63.01448499002765, 58.90027953732399, 59.04379513955886, 49.576935075944476, 46.97584667513448, 44.468942226902136, 46.16271188182216, 43.65141437899682, 45.294334427002944, 44.77001551658877, 42.94229299791398, 42.79497661898213, 44.19176009393508, 43.94776905736616, 43.29330982700471, 43.90173612102386, 44.74019373616865, 43.61548546821841, 43.501889705657966, 44.07767795747326, 43.52987189446726, 43.767179212262555, 44.903383947187855, 42.49515456538047, 43.813172924903135, 41.78293843423167, 44.86935738594302, 43.16309890439434, 44.827148760518725, 43.70813185168851, 43.56226674972042, 40.65843805190056, 43.81459282290551, 42.578806954045454, 45.40694567465013, 46.12977573948522, 49.77069231771654, 46.2204413260183, 50.24470290830059, 48.81420666171659, 54.31355007233159, 49.87556472901375, 63.669116804676676, 35.44264278104229, 26.87374072690164, 53.248285324342795, 48.250185520418235, 59.43690684533889, 54.72470468090427, 58.75772491578133, 49.92349609251946, 48.80378100179857, 43.74996392957626, 47.088148055538056, 46.03827468810543, 45.1417895286314, 42.4649287808326, 42.686754503557765, 40.55944527349165, 42.59625365657192, 42.23263425211753, 44.371710592700595, 41.66266287526777, 45.32905132539811, 42.84823063881167, 43.34667367319907, 44.62136553179833, 44.622126471611764, 42.87983709766019, 42.84564971923829, 42.770355901410504, 45.229764369226274, 42.01661755961757, 45.35005954004104, 44.08064719169371, 44.57745459771926, 42.49129495313091, 44.068683962668146, 48.13639756171934, 53.90610210357174, 54.99731333025041, 60.50632538334016, 57.736735882297644, 56.499569339136926, 56.08284888728973, 53.002690038373395, 48.17879053854173, 46.01250863844349, 47.108901316119784, 48.97565926274946, 52.849776437205655, 57.245925780265566, 59.67553600188225, 60.53072252581197, 58.66629838943482, 58.42173860919092, 61.19071229811638, 65.8577169910554, 65.98301318383986, 62.507295070155976, 60.38311589148737, 15.839334841697449, 2.418171609601667, 3.051136741715093, 0.4740438081564442, 0.1857260969136992, 0.3095247716672959, 25.64329516503119, 48.240952261032604, 39.905158627417784, 37.85233912929412, 20.710902906233265, 35.96862477640952, 49.308393924467026, 52.903293255836736, 62.2059158355959, 47.139778214116255, 1.0659063006601026, 0.044338801845667825, 0.053144450104164506, 0.0220518313243144, 0.06442545102007928, 0.03539950954878042, 0.023834734343953674, 0.0619619497428498, 0.08979019318376819, 0.049895532504324956, 0.029772997856320395, 0.03450438943541339, 0.041494646800621864, 0.08717884459803182, 0.04042968499444185, 0.18434891597397868, 0.10094195123641722, 0.10662689820052156, 0.2109413600016025, 0.15369928562112395, 0.12970567230255375, 0.16663035948670682, 0.06306816921419194, 0.17805426261357724, 0.16595303050933347, 0.1536612110512872, 0.18900314526211834, 0.281361939325448, 0.27058246936048236, 15.37749928812827, 74.06862628075385, 71.8949350234001, 76.83850995955929, 52.10920941445136, 36.0044595503038, 49.87138348241007, 51.934138344180205, 51.42091189661334, 75.11739746216806, 24.073856799833237, 0.541774622134624, 0.44065248701841603, 2.004509871044467, 25.800554752349857, 15.919912092147337, 4.447975129850449, 59.94455960489089, 69.03938678003126, 70.11082141630112, 67.15931630903675, 67.99424771339663, 62.795055835477775, 53.93262909304712, 49.43347046452184, 49.68922861160771, 50.06254411512806, 55.730216041688, 60.83349027941304, 63.558298080198234, 66.33482625407558, 62.08154532217211, 61.36908208170245, 52.69380338730351, 49.0115136484946, 46.46921765419745, 48.74274499954716, 46.97244205782491, 46.024985697961625, 48.68320734270158, 45.775162096946474, 45.634498057826875, 46.165951759584495, 47.0796835807062, 44.01810107692596, 46.34768693677841, 46.215083368362926, 45.0808515856343, 45.34151269543556, 46.052312850952156, 45.793503099872225, 45.49417918728244, 47.71335424915437, 45.63306639271398, 46.364360932380926, 44.01399435535554, 47.304957066812825, 45.51883520618562, 45.74560703769807, 45.88883630691036, 44.951640867417865, 42.581536923685384, 47.37224924948908, 45.538278395129794, 48.80674239127867, 49.60491726475377, 54.264795011089696, 49.42380574441726, 54.03705043177451, 51.71002980201475, 57.345314718061886, 54.85607662508565, 65.49603915983631, 39.61516211109777, 30.385907465411773, 52.925815505366174, 49.82879438707906, 61.2863318381771, 57.28594180076354, 60.65403007691907, 51.37811883803337, 50.77562316771477, 46.13756164427727, 49.54316739113101, 47.950194804899155, 46.84847947089903, 45.525193368234945, 44.554143951785186, 43.83203168069163, 46.05836899049821, 44.69733791966593, 47.59848371628792, 45.19073678601173, 47.825000593739176, 44.47400208442442, 46.07718067784464, 46.94982959378151, 46.96624863532282, 45.304105051102184, 44.96171743639054, 45.5492296526509, 47.47043009727232, 44.863211031883, 49.13965355965399, 47.5945338895244, 46.302732652233495, 44.565040296123875, 45.914308178809385, 51.19526578534035, 56.38056070573869, 58.83656847861506, 61.86685046842022, 60.81734188141362, 58.906104257029874, 59.50529336929322, 56.906797655167125, 50.98000611028364, 48.54675592914705, 49.49749923521473, 52.527298773488695, 56.18672893893335, 61.40210451618318, 61.246841415282226, 64.1468575692946, 61.50957353653447, 59.883974675209295, 63.26457531221452, 69.03700982370685, 70.75388616131198, 64.83757518952893, 62.28035457672612, 20.00380939052951, 11.643366602159317, 5.537122209225932, 0.46410878158865443, 0.3482047348253189, 0.5358948666722544, 32.163794309862205, 56.60830920742404, 60.26234219151159, 60.05965763522733, 25.193846456466186, 40.359627969803356, 55.27384042739869, 62.08118838648643, 70.0005086775749, 55.97739204283684, 1.8516167397460632, 0.11376950364079207, 0.21989789310722585, 0.1313901004651862, 0.13181198508508746, 0.1098324322412091, 0.13733673540334548, 0.15830419416869843, 0.22129980336514213, 0.12569323317298006, 0.11425893423297714, 0.1611985203119055, 0.13727365572366024, 0.1458943512050375, 0.1520066603177017], [0.025748031273964914, 0.08757181705967074, 0.055716670749168244, 0.0824395565676593, 0.10576963049149322, 0.050090846620620265, 0.027199300576842604, 0.05707379550703111, 0.053941047480029446, 0.0570991721695229, 0.01996656872272011, 0.04656098925718858, 0.008676207169980533, 0.030849738264336225, 23.423082636248683, 55.02007876673053, 55.22035498772898, 51.665165731983805, 34.596650292796475, 18.602958417707875, 18.93056458042514, 44.72043283524052, 45.546852696326475, 54.99559533211493, 6.613770165751058, 0.2021413999459436, 0.3123489088348804, 0.9703060047280405, 8.724427953843149, 3.848564893968644, 9.899780884865793, 54.6262296553581, 65.22429343192809, 63.871393434463016, 62.05939569780904, 60.910443259823715, 57.32056848464474, 49.864452654315585, 46.58979523566462, 44.05179031433598, 43.00269357619747, 44.613065796513716, 44.86008490285566, 46.31650801627867, 48.32349461893882, 47.491669731755415, 45.687928584314164, 43.08363952944356, 43.792474577503825, 42.42141008377075, 42.08268204042989, 42.38308068244688, 44.00449437479819, 42.50354843754923, 42.97513500336678, 42.41793094142791, 43.886999776286466, 43.3982567633352, 43.45043605373752, 40.7790470123291, 42.49407199121291, 40.45289801013085, 42.51347595645536, 42.28741799631427, 42.31783205463041, 41.851062159384455, 43.50521587556408, 40.71034277639082, 41.75000621426491, 39.65535463825349, 43.610837459564216, 42.239231678747366, 40.449987611462994, 42.06126589928904, 44.66827315668906, 41.800981337024325, 43.7195537936303, 40.08914524509061, 45.698715102288034, 43.11377117710729, 48.10545006105977, 45.27960200463572, 49.529282200721006, 45.07024941905853, 51.89859774804885, 48.75821090513661, 63.914288474667465, 31.103277590966997, 32.572826916171664, 64.35567279015818, 49.97539297226937, 55.32930274163523, 50.92778367380942, 56.4900379796182, 48.04171546812981, 45.64420592400336, 41.67126071068549, 40.61841418666225, 41.0248972523597, 43.06609084529262, 42.41027447485155, 41.09770428749823, 41.7525714443576, 39.77118222944198, 40.66101897147394, 40.4729962348938, 39.57862915531282, 43.90057117708268, 42.5810387826735, 43.06594179522607, 41.27616428559826, 41.59684942614648, 41.279882692521625, 40.41775749575707, 41.424398499150435, 40.11151452218333, 39.88182836963285, 42.61898771409066, 42.52235620252548, 43.14121992357316, 43.969828467215265, 42.77799275613601, 53.07623055673415, 55.99375617119574, 56.08884226891303, 55.51667828713694, 56.157091509911325, 57.10241410040087, 55.519267051450676, 49.84536247868692, 47.80824815073321, 44.81485997476886, 45.815538975500296, 49.170440243136504, 53.381245828443966, 53.794342010251945, 58.332210510007805, 56.217613681670166, 60.24479350736065, 56.391119726242565, 60.02483483283751, 62.734549353199625, 62.131908555184644, 59.05052984914472, 70.55958763245614, 29.983697822017056, 0.8157921378170291, 1.624758616089821, 0.993419183838752, 0.10914295310935668, 0.07834360619345981, 11.227424740791323, 45.28093953286448, 38.39430086074337, 45.852464168302475, 23.625372994330622, 14.625534838245763, 29.283819506245276, 40.82730785492928, 52.053962830574285, 46.74311284096011, 3.1626075602346853, 0.22186741323000003, 0.044564104473759095, 0.007590983295813204, 0.06519572944530556, 0.07149980568717565, 0.09106841088543016, 0.02965154993768421, 0.06006443805451836, 0.021294212502036846, 0.049810554201324145, 0.05960501129588774, 0.09748987477993774, 0.03811588495849602, 0.07503609052829205, 0.0031667470090812255, 0.04399902269905133, 0.028098222401533878, 0.038562211613621444, 0.03471299900763458, 0.005392019360912063, 0.035962143672570106, 0.043048774898653074, 0.02369323598911926, 0.060166929127468224, 0.04930707738704739, 0.01920087533372064, 0.04868968712886976, 0.08737038190086042, 31.13049883996287, 69.35263510673278, 61.524404018156, 57.94007939677085, 38.441220252744614, 27.391595571271836, 21.138262787172874, 36.632658512361594, 48.63349522313764, 62.548087719948064, 6.623981566198411, 0.22676997757967443, 0.2586766969292395, 2.80216968828632, 10.673001639304623, 4.291430394495688, 10.86241191433322, 56.18319880577826, 67.43302714440131, 65.63850748923518, 65.60543406394221, 62.6492025006202, 60.046600064923695, 52.38942746193179, 47.5287792759557, 46.42118823143744, 46.3449961908402, 46.81722210299584, 47.7445920052067, 49.51907619353264, 50.027383988903416, 49.098182339822095, 47.29159355163575, 44.98090174890334, 44.92890680989912, 44.32907050655734, 44.41736305913618, 44.184064403657, 44.78525784707839, 43.093543514128655, 43.832467063780754, 45.47785036025509, 45.99940792206795, 46.25153787674443, 45.59843186409243, 42.731238103681996, 44.86055166490617, 42.49175387044107, 44.22672802402128, 43.767485157136, 44.15941622949416, 42.81211345426498, 44.60338146455827, 43.88772541476835, 42.792991899674945, 41.53724508900797, 44.17102252283404, 43.73277610348117, 43.72018921759821, 43.93511549119027, 45.26008429065828, 42.94845111908452, 46.601244634197606, 43.46726694414693, 50.750386638026086, 46.794931273306574, 50.43323555300313, 47.541162198589696, 50.94880365556287, 46.83467665026265, 55.57824380936162, 49.32323617319907, 65.43428928621354, 33.16871927630517, 32.37144458678461, 64.90959382826283, 51.386081249483176, 56.57855802966703, 53.09713286738242, 56.87112762082008, 48.775300671977384, 47.292958536455714, 43.07027993663665, 44.12061222137944, 43.33957810555735, 45.534356024957475, 42.71714110528269, 42.720271156680205, 42.67344197919292, 42.41057649735482, 43.06022297951483, 43.62650732840262, 41.77840417431247, 43.27787137800648, 43.57152746569726, 44.82824702416697, 42.42943917551349, 43.931640271217596, 41.567816042131, 41.40579861979331, 43.35327109982891, 42.514264352859996, 43.00598052240188, 42.245291740663596, 45.842481736213934, 45.79307163915327, 46.029602327654445, 45.685896796564904, 54.888314585531916, 58.54936076748756, 57.14823915112404, 57.1146087492666, 57.33462625934232, 59.80342095898044, 58.21645744385258, 53.30498318518362, 51.511612784477975, 45.75817431173017, 45.943816169615715, 50.60877338532479, 54.6960517667955, 57.41922001684866, 60.48155953807216, 59.58609027247275, 61.943783836980025, 58.669271546025435, 60.895149938521854, 63.32530929196266, 62.359609988427934, 62.15774520750969, 70.78074655225201, 36.74887049582697, 0.9669605906932586, 4.881038627316875, 0.9870620636690048, 0.19444580159841046, 0.04236593774910416, 10.156082280220526, 51.21923931183354, 40.83626262603268, 43.860488476291785, 23.190639057467063, 19.470757322926676, 33.485780146814164, 48.695641256147816, 58.08689371232064, 58.668541985173384, 7.850508680266719, 0.3648425404342913, 0.027832426280984958, 0.03465665707124337, 0.005646355763723653, 0.0934405025515345, 0.08298066745121634, 0.08358282788145928, 0.003532561174999442, 0.07905949237606219, 0.0531796709964833, 0.01193626560345893, 0.020756018498251518, 0.03990044464327155, 0.07607947163764509, 0.11568115348176611, 0.16325008845137012, 0.15824460784994787, 0.19970490326804502, 0.2587057469833282, 0.2279488643210742, 0.14114005551222833, 0.10423914003636568, 0.20959319847245372, 0.20392541953873253, 0.0977629085161513, 0.11092643644059859, 0.14924236993876197, 0.25766353032762007, 37.83553177310575, 80.425305674153, 68.99560528416788, 67.76496948734408, 45.90602021063528, 29.52562382144313, 27.21214713588838, 61.26908125415925, 59.35584322098763, 69.37409831631568, 8.65840465791764, 0.45955408244363727, 0.8507239085532005, 2.7914697076043775, 21.772770881652836, 11.307715658218632, 12.447597615180477, 58.76354179074688, 69.55238573012814, 68.4789114613687, 66.93803971813571, 68.15878329738494, 61.7249704945472, 56.08345685466644, 49.288891899970274, 48.9903328495641, 48.60241043952204, 50.37182300321518, 49.82602911610758, 50.92411625769831, 52.64860591580791, 51.32793211167859, 49.881138417028616, 46.72526605667607, 47.660198288579146, 46.11201524734498, 47.29671616708079, 46.5708972561744, 47.92286372953846, 46.19954686011038, 47.19651922102898, 47.98913609596991, 47.60245315490231, 48.82452249526978, 46.76113220953172, 44.99495560123075, 47.48796701431275, 43.918037491460005, 45.543632430415, 47.583029577809, 46.67395361008183, 45.66104858152328, 48.26563573652699, 44.96572609870665, 46.23256537222093, 42.535303946464296, 46.7316791319078, 46.7083449517527, 44.35851181707075, 47.17373417269799, 48.876168343328665, 45.78351282304334, 48.42034970560382, 45.57689805184641, 52.508934236341915, 49.19834790691253, 52.50540410318683, 51.23900413513184, 55.386275168388124, 50.1089261424157, 57.07664020599858, 52.94783569151356, 67.05101182383876, 36.5669156659034, 35.262154917563166, 69.01249501012987, 52.64854315788516, 58.00653219223023, 56.076274994880926, 61.870474738459436, 51.684546163005216, 50.490098153391195, 46.085190157736506, 45.85838694726267, 46.00348326467699, 48.3990433908278, 46.506774348597375, 46.40721674888365, 46.62147229717624, 45.4162024682568, 45.43002097837387, 44.78698761232438, 44.18886930711808, 46.764407388625614, 46.94497762187835, 47.71990852971231, 44.96235678272863, 44.933386156635905, 45.1501912455405, 43.941873734997166, 45.39406068863408, 44.05039787292481, 44.89552743973271, 45.54892763014763, 48.93293680683259, 47.92686454711422, 49.690111144896484, 46.622299917282604, 58.494984949788744, 60.95941797379525, 61.02866741918749, 59.178834499851355, 60.30064021387408, 63.028574143686605, 60.70987286106233, 54.65724775868078, 53.74038588616156, 49.16409777056787, 50.84443723001788, 54.30942373891031, 57.59251425343176, 60.029220042690156, 64.92820547473046, 58.93780877513271, 65.44107106424147, 59.52084556702645, 62.77420451564174, 66.18259906768799, 65.72465842769992, 64.0560233208441, 74.69879427263814, 39.872402914108775, 3.7271949937266693, 9.236118793487549, 2.313889760163523, 0.2074255680124606, 0.13408728154195895, 14.437647423436566, 58.13378172536051, 52.129448844540505, 61.39638177810177, 32.57096771270999, 23.37613578765623, 39.651463647042554, 57.5394053612986, 65.03747486299085, 68.35120693329843, 10.126486036085314, 0.5128441084056131, 0.1770674341147946, 0.14966286027864104, 0.20239019466023292, 0.1813719442655002, 0.1441861130297184, 0.13882090818257103, 0.16395203949462983, 0.15767597142727147, 0.16785364868419786, 0.1912328748092536, 0.19244456543557106, 0.13292409960300694, 0.1983153576692266], [0.06074694195582021, 0.07356903215329494, 0.03991554423625912, 0.05208853579637024, 0.07221172353433025, 0.06545801496794147, 0.023321706328480955, 0.07925754908712641, 0.010270490724172805, 0.05467217498188538, 0.012680305517278613, 0.01893860896328284, 0.07650281182460247, 0.7107599512223275, 35.77249057831303, 61.12826816497311, 57.06159399401758, 52.20533101789413, 32.94249657661685, 15.57480529431374, 48.09163547331288, 49.688561808678415, 46.00927268305133, 46.9449423205468, 0.5029976722453872, 0.03941290245781984, 0.0802864434738313, 4.522692359262898, 7.005058949993503, 2.4179838261296673, 15.319426636542044, 55.73497387670702, 63.67556518123996, 62.8794534744755, 62.448302622764345, 60.22850390403502, 53.53464580351307, 47.77482955686508, 44.88465070724488, 45.02631495075841, 43.850666861380304, 43.01516671334544, 41.35088543738089, 41.28622908746043, 42.60452201289516, 42.6575759918459, 43.110154751808416, 44.22710457155782, 41.74297732691611, 42.75160304961666, 41.816274658326186, 39.98148402860088, 42.13038982883577, 43.81156083076231, 41.40539069329539, 43.99572395509289, 45.35973994962631, 46.91540295077909, 47.878650772956114, 42.2462684108365, 40.595711508104884, 41.42089190021638, 42.65394779943651, 40.89688677941599, 41.72535804010207, 41.62290965357135, 42.221604547192975, 40.757556346154985, 41.81768278921805, 41.90191961103871, 42.426501320254424, 40.93952294318907, 42.1194895621269, 39.598354754909394, 42.748602436434844, 41.98577596295265, 46.652306049100815, 46.08100498876264, 47.855634304784964, 44.95153496342321, 49.12709413036224, 44.58581316855646, 50.2141829459898, 45.70308854503017, 54.42660847017842, 49.213264680677845, 62.93369985395863, 31.547807647335915, 36.35722967886156, 60.26862190615747, 48.49409026484336, 56.4959607585784, 48.807048336152114, 54.035991391827984, 47.44542890979398, 46.22309677062496, 39.88125570358769, 41.67674418418638, 37.635314387659875, 41.002123971139234, 39.504665020973455, 41.15821469214655, 37.74374831107355, 41.573268136670514, 41.952914345648985, 40.37349747073266, 40.93327852987474, 42.376294982048776, 42.02305809144051, 42.058543774389456, 41.64107414983934, 41.95235736908452, 40.76215336399694, 41.54478388447916, 42.425250084169456, 41.334850788116455, 40.00650090555991, 42.22900998207831, 43.083627762333045, 43.64135349950483, 43.155673857658144, 51.50392493894024, 54.0699944188518, 55.037819647019916, 51.98876127119988, 55.80838887922226, 58.3036046643411, 57.18460736736175, 54.64662598025415, 50.513702977088194, 48.104849938423406, 44.20740250618228, 44.08333009289157, 46.551877683208836, 51.40681489821404, 55.70590126898981, 52.20966915930472, 56.00903380301691, 55.31768075881466, 55.926640495177246, 60.25751767619964, 62.22007166954779, 58.99427913850354, 59.73042565007364, 67.81531703087592, 47.89643087694722, 0.282202061986731, 2.9402805095718754, 0.574283409983881, 0.09092130668220982, 0.09961717837159673, 2.1580223691078926, 42.4367622406252, 41.623435251174435, 34.302484296983295, 44.95688899870842, 23.758029514743438, 17.676002325550204, 43.10618531319403, 54.518760635006814, 53.79487937496555, 20.92123216198337, 0.22550702034946413, 0.045211613478679816, 0.12728573844557808, 0.024728013931082624, 0.04760716275702562, 0.02154739306969268, 0.04986478939592358, 0.015775064201725107, 0.04584807549573241, 0.17272314867906033, 0.025561069431264075, 0.025528612201132124, 0.005835381255770523, 0.036871332990666555, 0.06288656807174126, 0.07920055214555995, 0.007154780492607144, 0.05117464269841871, 0.07998756193105253, 0.026975350093937693, 0.05480076283997586, 0.06327149661017523, 0.06158455567915113, 0.06550499147945835, 0.13091281236660096, 0.04709226357179785, 0.07147038025000403, 1.2822380085145275, 48.05626353909893, 68.20678526355375, 64.03621142910373, 59.186679240195986, 44.86253638421336, 19.83358048623608, 38.8666993571866, 48.25345285477177, 52.92491336022654, 48.61890008372646, 0.6329533037158751, 0.07277553360308371, 0.1980350154542154, 3.933518283790158, 5.769356431499605, 3.7832623335622975, 16.499989455746068, 57.76498086990849, 64.36516100360502, 64.44658156364196, 64.67118432444911, 63.00018010600921, 55.35264868890086, 50.74534639235466, 47.86810744193293, 46.565554987999704, 44.98019572227232, 44.93563367474464, 44.60796279291953, 43.13437146525229, 45.19380407948648, 44.20504123933854, 45.00018412067045, 46.20406543054889, 44.16080474853516, 44.9934886347863, 43.936009791589555, 44.164511388348, 45.16247218655002, 47.05104243370795, 44.0496761568131, 45.11525861678585, 48.31533216661023, 49.31996883884553, 49.76794665859592, 44.93084838313442, 42.926901617357814, 43.6920383668715, 43.188190306386645, 44.092504516724624, 43.094057344621234, 42.98515273678688, 44.099137244686005, 42.98607841614754, 44.37835901014267, 42.87889572881883, 46.01831374629852, 42.22001206490302, 43.694791870732466, 41.32674717134045, 45.49974110818679, 44.775408775575706, 48.239775549980905, 48.473482131958015, 49.95261184630856, 48.99907189030802, 51.27895347533688, 48.83305365039457, 52.53259789559149, 47.63945679510794, 58.41615315406554, 50.6398856255316, 62.63081442925238, 32.11792807425223, 37.00849217753257, 62.5066400343372, 51.699965000152595, 58.344711103746974, 52.30055439856745, 57.124104807453776, 48.47059918988136, 48.10739555666524, 42.30513534238262, 44.14378558435748, 41.56847892269012, 42.841468472634595, 41.22708366763207, 44.11909034175258, 40.378596551956676, 43.38556005108742, 42.543274202654445, 43.040356174592056, 42.25217157794584, 43.286512359496086, 43.60735047248102, 43.1622830513985, 42.89318100098641, 43.490428540014456, 43.1965135758923, 43.75163878163984, 42.44550128136912, 43.93268362168343, 41.00870570828838, 43.2929568136892, 45.31366778958229, 44.305497061821725, 45.03610126433834, 53.31529117399647, 56.21329122974027, 57.931881643110714, 53.20983825191375, 57.245529620878166, 58.662246581046816, 58.91818515716061, 57.50542586849582, 52.39895882145051, 48.52455923634191, 46.70214368451027, 46.18969386623752, 48.21296614985312, 54.372224807739265, 58.28527542852587, 55.858893317561, 58.42889693475539, 55.88366700756935, 57.33907030474756, 62.15972992681689, 63.56372664051672, 61.60252194250784, 62.072002195542865, 68.52543077161236, 51.68867249642649, 0.5605484340940753, 4.560609421422405, 3.7816580841618204, 0.583904248572165, 0.030247114350899097, 1.8592527364530873, 47.17880971970097, 44.00542789889921, 38.37146874397032, 49.33147707293111, 27.22907216318192, 21.539189815521244, 47.9873239609503, 57.57452626382151, 63.49934093413815, 31.435547451819147, 0.3513221917373519, 0.09761159082934742, 0.06209609173839131, 0.031449610006905375, 0.03846237886576884, 0.021801946849952784, 0.04727461164997471, 0.004536177533032794, 0.020780211554900296, 0.026147793189832763, 0.01167626302283738, 0.05936126510101942, 0.022711346842228405, 0.030604934868132396, 0.17245080442197863, 0.1847598761800797, 0.1700168817995056, 0.19314476979836342, 0.2202264069309158, 0.12204540593008842, 0.32140884848852314, 0.28657409512708265, 0.10931313188085634, 0.16068662036090128, 0.12546851660215086, 0.12243213477514445, 0.19011112290524668, 1.4953177037738985, 59.63814796939973, 76.87894959603587, 72.89761051054924, 67.11726065604918, 46.77150295626733, 23.106580703489243, 63.268787937779585, 64.4209998653781, 58.49889555285054, 55.7672667503357, 0.8344301989962979, 0.23028704127477062, 0.33509562212613325, 11.275209015415562, 14.861826262166424, 6.071245083885809, 20.004617398785008, 60.50811006176857, 68.48965875564083, 67.51400839897894, 65.72310124674152, 65.06139347630163, 58.31287322505828, 54.47250020119452, 50.60213673499323, 48.819619532554384, 47.7649647958817, 48.77888179594471, 45.5933641618298, 44.724119863202496, 47.827322636881185, 46.77855930020733, 47.879721580013154, 48.113192819779925, 45.362493453487275, 46.3744806474255, 45.42306661605836, 45.00596961667461, 46.60111519598192, 49.90550418053904, 46.75857090180921, 47.72745909229402, 50.84511972242787, 52.032958538301536, 52.42251265433527, 47.05968733756773, 45.722445441830544, 45.35961051141062, 45.85329571077901, 46.37191933970298, 45.52482466543875, 44.53740719825991, 46.92201214451944, 45.351934432983406, 46.25606036955311, 45.69485941240865, 48.037800942697835, 46.08674733869491, 46.15253725359517, 44.21016777715376, 48.41085756978681, 45.9687977452432, 51.55032265570856, 50.60459606109127, 52.77951894267913, 52.0331899581417, 53.4012459939526, 51.63015857819588, 55.92560106708158, 50.986878102825536, 61.201847907035585, 54.12540966464628, 65.00031432797833, 36.1567847959457, 40.90448833280995, 65.18098262048537, 53.662220893367646, 59.69918004928097, 54.3513774102734, 60.1283226474639, 52.307995134784335, 50.40538280240951, 44.34515614663401, 46.69033342792142, 43.411526141628144, 45.24452032581453, 44.897194447055945, 47.67831963877524, 42.58760875271213, 45.98871161860805, 45.969472392912834, 43.45141272391043, 44.70356664349956, 45.51318307076731, 46.28473289551274, 45.98078058611962, 45.72621091719597, 45.37025974642846, 46.429613482567575, 45.07058282052317, 46.553517233940866, 45.40668287584859, 43.21279533447758, 45.95202961275655, 47.14776808215726, 46.56853206696049, 47.95881617453791, 57.08700703036401, 58.903990099507, 60.506105730610514, 54.153831158914876, 59.84882631609517, 63.88822040250225, 62.963231378985995, 61.11680307695943, 55.202319929676676, 51.452102584223596, 49.70367470095235, 49.41508239315402, 50.288123546108125, 55.88907595603697, 60.34391964635542, 59.70007042731009, 62.556622797443026, 57.38615051392586, 58.84290310644335, 63.53019822028376, 65.7377238427439, 63.83985365590742, 66.84368318127048, 72.37300134474232, 54.97775639257124, 0.9317293102222105, 8.298677225266735, 3.8500068553032416, 0.44894030197493495, 0.29267748697630824, 2.787330871628177, 53.027130326917096, 55.52403665358021, 46.85651640738211, 59.003194685905214, 34.51782634181362, 27.400734693773334, 58.833006966498594, 67.12584280198621, 71.84224190250521, 36.72721509010562, 0.5501276771387746, 0.3837302543463246, 0.23377321630475983, 0.16351538469954846, 0.11942410586221565, 0.11345416652939974, 0.11103152838205138, 0.07500549297659628, 0.10301686973581392, 0.2829318986304345, 0.07150880722028595, 0.21124336718311235, 0.12320748470242947, 0.14382565333958597], [0.010797939387210196, 0.030817914971961614, 0.032304085325449705, 0.028421222307388822, 0.028774473110153794, 0.03688743232839531, 0.09037028262091261, 0.026373411829192794, 0.04891281789769569, 0.04920596910280086, 0.03829925959449142, 0.08367581563370843, 0.16222164605654057, 4.41764687338183, 51.20581696110388, 59.589894971539906, 57.25752815123528, 31.668342082731186, 14.750318181130195, 24.45663109902413, 36.1593343365577, 32.23606594147221, 56.70517213882939, 27.27521884825922, 0.0600647674723258, 0.007083866606286217, 0.36570739241377004, 2.472399602974615, 5.534362331513436, 4.388384521007538, 19.47527981573536, 56.03911838223858, 59.92812487386889, 63.739860673104566, 58.82065542282597, 57.85870198280581, 57.12832920012936, 55.530061414164884, 53.26960340622933, 52.44494468935075, 47.757986899345156, 43.13403414141747, 40.592801109437026, 43.96087369611187, 43.71552159709316, 44.39898283250871, 43.297545986790816, 44.24747736223283, 41.581485502181515, 43.02094828697943, 42.32391565076767, 41.01419702652962, 43.12863696006037, 42.38875242971605, 40.85037531391267, 43.52447471311016, 47.323835434452185, 48.01040710941438, 52.97502948391823, 49.87934589385987, 44.76675994934575, 41.14985612130935, 42.884328211507494, 41.00507751587899, 41.65551631681381, 40.47145866578625, 41.90259425870834, 41.27574459198983, 41.45680904388428, 39.53896222576019, 40.67407654177758, 41.206965831018266, 39.116228780438824, 40.06060607971684, 47.328491287846724, 48.24119544798329, 52.00427032286122, 47.49075581950527, 48.62261064590947, 46.076313834036554, 48.091227546814956, 48.049905377049605, 49.43594940247075, 43.76766558616392, 52.093755275972434, 51.143102184418716, 59.60341930389405, 35.22249583275088, 37.652533592716345, 60.3159962930987, 47.73444091120074, 53.091276768715154, 44.956457537989465, 48.665474307152536, 42.04008117798836, 40.875898176623934, 39.241411224488296, 41.62257232973653, 39.85753320878552, 39.39882378424368, 39.92160512555031, 39.68441547886018, 39.573055467297955, 39.68894189403903, 40.73308860102008, 39.58421853280837, 40.63105598572762, 41.232320031812115, 41.88494359293292, 42.39823672079271, 40.373446479920425, 42.12369434295162, 42.600933044187485, 42.34699879923175, 41.77191265167729, 40.341039857556744, 41.025120827459524, 42.24546824732135, 41.04165361773583, 40.5023669427441, 44.86500355505174, 52.12073333801762, 55.76763937550207, 53.030766364066835, 52.550652565494666, 55.9535518769295, 53.377613713664395, 53.37404043443742, 50.81683551111529, 47.37892120115219, 44.05455166293729, 43.37769569889192, 41.66281192533432, 47.44956701032577, 51.046298088565955, 56.28152478125788, 50.31057911534464, 42.36061334609985, 48.80233364720499, 62.773506333751065, 59.023320367259366, 61.871380805969245, 53.03899941905853, 64.86446303706016, 60.939970862480905, 65.47064965771091, 3.7789026191157684, 3.9834115678264252, 0.04282457926761239, 0.5325918019779268, 0.3199851813335573, 0.06751925879788977, 30.200493104996223, 48.968234216013265, 32.368263544574866, 69.3889170308267, 35.326783810892415, 23.39721852733243, 39.08430853197652, 45.777213496546594, 50.45872311438284, 36.730858971995694, 1.5315660425732214, 0.27017800557997923, 0.004357228012410023, 0.05206271097244275, 0.02990982690525632, 0.03264380318503226, 0.0610917121652634, 0.01701261412592665, 0.07900921402559166, 0.058883264540664615, 0.06261886247704107, 0.06285099860941691, 0.024061387202011484, 0.0031649680092795604, 0.02840880593735605, 0.08234541968352373, 0.04606425784708512, 0.012219705686513937, 0.013255604989676466, 0.1028282129235806, 0.04271902001252578, 0.004204833493267577, 0.0672297771539419, 0.05445395866709371, 0.09607597524600645, 0.028909622511315732, 0.13795571912440563, 6.646081180341783, 63.09123008481918, 66.09987628075385, 63.12538216190954, 39.71356261161066, 21.183124896018736, 17.689897321885635, 38.49622757204118, 36.78659977451448, 63.71949180479973, 31.739338944035193, 0.1342680170050552, 0.12095362338567935, 2.090540196626417, 4.19855700385186, 8.506293181450136, 3.8446246279824168, 22.66306261862478, 57.75011900932559, 62.0143747329712, 65.77692008787587, 59.92923098225748, 59.93630301567816, 58.59152624683996, 56.425009004531375, 56.284705823467625, 54.7810338389489, 50.059025749083496, 46.337673125728486, 43.44831797384447, 46.39639100720806, 45.07589763210666, 46.428546597880704, 44.77684828542894, 45.705453734244074, 44.11782341618692, 45.0758780202558, 44.26543005051152, 44.252815708037346, 46.09147771712273, 45.21473776909613, 44.4000183382342, 45.97004505895799, 50.336811927057084, 51.37334139116349, 53.31067062193348, 51.56200739645189, 47.6548207190729, 44.51291984127414, 43.47139719993838, 42.90510500631025, 43.84554424593526, 41.56909865717734, 44.308156428798554, 42.92999636742377, 43.09733252371512, 41.735819001351636, 42.52643938987486, 42.15104895253336, 42.60065455590525, 42.400405791498, 49.38989685427759, 52.0993564205785, 52.90526228566324, 49.19713981689946, 51.26456229917465, 48.894493656773726, 50.123709555595156, 49.48699905026344, 53.07006851319344, 47.58762659565095, 53.647602219735425, 51.07943427178168, 63.71187456192509, 36.72637962525891, 39.29413964671474, 62.76704226770709, 50.53931213194325, 54.85826138527163, 46.28906711455315, 51.37844831712785, 44.16327976411389, 43.857283899861, 41.07199707338887, 43.05986604382915, 41.21750523967128, 41.42017018410468, 40.48515558242798, 42.73534482525241, 41.71522263557681, 41.79076356272544, 42.41027447485155, 41.83119535446167, 42.82379427263814, 44.440457974710775, 42.87701299113613, 44.092253485033595, 43.698361227589274, 43.77281565820017, 43.8627673733619, 44.26915237980504, 43.25758487947526, 42.936848748114805, 43.116057918917754, 44.51455939200617, 43.119089911060954, 42.35389824836485, 47.62469299377934, 55.66598723011633, 59.147726182014715, 55.98589181900025, 53.8434696966602, 59.17825006669568, 56.55509833366641, 57.135530671765736, 52.39368715593892, 49.02395148431101, 47.110023113989065, 45.05103372758435, 44.39635484449325, 48.97683989617133, 54.33433078950452, 60.009145352148245, 54.146896408450225, 46.077314038430494, 50.78189895999048, 63.778476407451016, 61.22200496735112, 63.429793388612815, 56.191227897520996, 65.35659890021047, 63.36743554761333, 68.17204090856737, 5.845955908298493, 5.820905691192997, 3.2006908328302446, 0.7806106837045762, 0.03861188092419217, 0.06426068082932504, 31.80430712238435, 55.53736094505557, 34.68182063871814, 63.10921807442943, 35.209638303326024, 29.72452917406636, 46.791220711123565, 50.72451468436949, 56.88735446622295, 49.99363983831098, 3.599919720042137, 0.2451400458812714, 0.08741038701226635, 0.024941903764321923, 0.044954755688987436, 0.03652545578417279, 0.0552988502257053, 0.032406017154214845, 0.015555776321449348, 0.01772728988960866, 0.03216841881493888, 0.028714363936394937, 0.030505165322533542, 0.028339335169162483, 0.137034360499632, 0.19161336003772675, 0.21273015998303893, 0.074198204843748, 0.15438038375108473, 0.2315214081036468, 0.24143089330004108, 0.15891156399682646, 0.1424188094754373, 0.13599258817491994, 0.17841164263025408, 0.20864813708730284, 0.4368390545489327, 8.44304496242154, 72.27891937378915, 73.12782226070281, 74.24118703411472, 44.775408775575706, 25.116797377986295, 36.046201413677586, 50.32487615462273, 45.26110018453291, 70.2076647358556, 34.90904746517059, 0.2600768911502054, 0.19069716484556276, 3.6382736361795858, 11.975605084050088, 16.684038831341653, 9.619747188783462, 24.523538889423495, 58.97747178231517, 62.841077004709554, 67.53028623519405, 63.493830004046046, 61.863979293454086, 62.036151732167895, 59.046513342088275, 59.13146011291012, 57.338882030979285, 53.957147828994266, 47.44355009448144, 45.72494399163031, 48.7958852706417, 48.05807567411854, 48.97123482919509, 49.11196947097779, 49.12636456951019, 46.106033632832194, 47.52883418913811, 47.14306908269083, 45.34772572978851, 48.5683407322053, 46.77012620433685, 44.99802681707567, 47.287251487854995, 53.26261766495244, 53.06918990227484, 58.058978203804266, 54.00937811020882, 49.555295359703806, 45.94866814151887, 46.86764417156097, 44.964655291649606, 46.04229903990223, 44.818696052797385, 45.57703925717262, 46.452935895612164, 44.985479154894435, 42.67510114177581, 45.55566626210367, 43.749434409603, 42.7639389038086, 44.507350075629454, 52.619682358157256, 55.0793065563325, 55.233487083065896, 51.95364036867696, 54.404082298278816, 49.9563184861214, 52.95871242400139, 53.33202400515157, 55.672572889635646, 49.570682817889804, 57.277979389313735, 56.12794829953102, 65.46022792016306, 39.84890399440643, 42.5478986770876, 64.7891809863429, 53.13345793754824, 57.283670748433764, 49.3145755798586, 53.6294847919095, 47.48574303042504, 46.26329714252103, 43.832145429426625, 45.81508790293048, 44.17955367795883, 44.74917988623343, 43.70379371027793, 45.58499774625225, 43.728775285905414, 43.563459150252804, 44.12686840180428, 44.4319111301053, 45.50500492895804, 45.47586956331807, 45.619946064487586, 46.20821137582102, 44.36912967312721, 47.40548349195912, 48.75995243749311, 47.060389441828576, 45.57589000271213, 45.1962241818828, 44.59776070810134, 46.06943399675431, 45.26144535310807, 45.75087085846932, 50.63910507386731, 58.021323450150035, 60.87690699485041, 57.099362496406805, 55.09739652756722, 62.334683325982866, 58.93940517979284, 60.41061562876548, 54.676749783177534, 52.44836499614101, 49.493321910981216, 47.70123020295174, 45.748540970586966, 52.94023806048978, 55.88815812141665, 62.730375951336285, 53.169198574558386, 50.7610397954141, 55.68188459642472, 65.82847179905062, 65.17532264032673, 66.97616515621063, 58.54705049145607, 70.65627405720373, 65.7241249853565, 72.93885031054097, 5.7371204322384255, 10.578572538591201, 7.098396160910207, 1.623919719169217, 0.6312512402092257, 0.2785275672231951, 35.43014218730312, 63.84058321675947, 44.10240850140972, 77.11406430890484, 44.41567251759191, 36.84487442816458, 53.930177611689416, 61.91371886960922, 65.85441435537031, 58.24549082786807, 4.391943581642644, 0.3659103444266704, 0.23208049907078668, 0.1069748093704543, 0.19991045997988796, 0.1428443866391336, 0.12625689002414867, 0.10954631372324883, 0.1766061878973438, 0.13740828801547328, 0.15790850975580756, 0.18770830345249948, 0.1662860489300182, 0.10810958476917398], [0.09900576359922848, 0.026996825453675082, 0.05258086603134871, 0.08152097884205081, 0.05209477175207389, 0.09220408260702126, 0.06010138264466679, 0.018071207826236085, 0.033696791036955775, 0.08994436837852963, 0.07803273537466604, 0.08746344626190201, 0.21045566025760867, 8.99861143481347, 60.52462324019402, 52.56909947241507, 59.38438630873158, 31.068803879522513, 30.177994389687818, 29.66295384591626, 37.30274054311937, 42.42577568177254, 62.052680600074034, 14.747588211490264, 0.04885047749285737, 0.011708640771347189, 1.9511269032955172, 2.94924067393426, 4.279251925406918, 5.764221558647772, 23.259813977826028, 60.01958670154695, 56.75938713935114, 64.63413753817159, 58.64541176826724, 61.43780985186177, 56.939569057956824, 62.03792856585596, 58.62638435056133, 58.68731837118826, 55.95688589157597, 52.95919879790276, 45.575893925082305, 44.626652886790616, 41.55145583614227, 42.100473911531516, 44.15821598422143, 42.75597256998862, 40.62802007121425, 43.53910907622307, 41.06290501932944, 41.72453041999571, 40.57954742062477, 43.96583157200968, 40.68187813605032, 44.914237145454656, 47.598515095249304, 51.2053737332744, 51.91946867973574, 54.697342226582194, 49.797148704528816, 47.332711758152136, 42.80098961245629, 41.617284974744244, 41.13085616019465, 40.20017185518819, 42.087945861201135, 42.898272237470074, 40.42289972305298, 41.364994202890706, 40.744718428580995, 41.91646375963765, 41.42267657864479, 46.03519562752017, 54.323218714806345, 53.87176959745346, 50.19047221829815, 50.455240049669825, 49.68743216606879, 47.730192984304125, 47.81861105272847, 47.3663382376394, 48.113800787156634, 47.57627525637227, 52.510130559244466, 51.72358159096011, 59.22886825376942, 36.24517933014901, 35.88414869000835, 60.959971027989546, 48.36971975141957, 50.18683618114841, 42.97640192893244, 42.75226985254596, 38.357356056090325, 41.31337581142303, 38.78910310806767, 42.23273231137184, 39.54913685398717, 38.76987564948298, 39.614558066091234, 39.61509543080484, 38.38960186127694, 40.360985109882975, 40.186380801662324, 42.50826704886652, 40.85579210712064, 42.70626045042469, 39.78152159721621, 42.79962070526616, 38.963260266088675, 42.33850686780868, 42.98475657739947, 42.67002559477284, 40.33364226741176, 41.36140131181286, 41.6560144578257, 43.65223023199266, 39.841263217310754, 43.20322475125713, 49.5858427786058, 55.12266051384711, 54.44814620479461, 54.19595349219538, 54.34563113797096, 54.35553120028589, 49.976824637382265, 46.96124369098295, 41.755324948218565, 44.00168203538464, 44.50431416111608, 41.69055877193328, 44.47271946937808, 44.66841828438544, 53.748030585627404, 57.72103071212769, 58.18896555131482, 52.84285345385152, 56.74583927277596, 63.24902311448128, 58.672680085705174, 57.41618017996512, 48.68649036653581, 63.19896974871236, 61.51029525264617, 72.80108098060855, 21.83873534202576, 2.963626211689365, 4.600468056817209, 1.6720901021072943, 0.2923729517046483, 0.12631708155235938, 15.910650395577955, 54.22717163639685, 43.02455686753796, 105.19668932883971, 40.50797593209052, 19.3704132879934, 30.427596376788234, 47.50343291990219, 48.686659028453214, 54.464988862314534, 7.616733456811598, 0.31327477205664883, 0.032260904779597636, 0.06753664899377093, 0.09227754277808052, 0.016505848879234928, 0.020369954234469804, 0.012936083122997755, 0.041483657269348065, 0.02429972290091457, 0.04482533279505949, 0.02196008463450257, 0.01658206122116216, 0.04281616379176417, 0.11845852864245254, 0.033477096172470244, 0.09882802353991617, 0.0030730760021645937, 0.01648289113936405, 0.03716990426783601, 0.04897317796524975, 0.042567618056050235, 0.026704518860506437, 0.023215174141730514, 0.023338475993143457, 0.08017257216476625, 0.24564051580044532, 12.695217824751332, 69.84915225736557, 58.561371064955196, 65.13844451596661, 36.10006340088383, 24.914010840077555, 27.864739318047803, 39.33609331807783, 44.15306198981501, 69.47124758074361, 15.598980822870809, 0.017661094147291397, 0.0007235391017128413, 11.468949587114396, 18.142621209544522, 7.192103545511923, 6.981029529725352, 24.152888636435232, 60.649640944696245, 58.54467745750182, 67.33904715507262, 61.64643679895709, 64.96103179070258, 59.96901950528545, 63.19607111715502, 62.24977970123292, 60.766127494073686, 56.073192011925485, 55.81108746990081, 47.880482519826586, 45.39195829822172, 42.61123318825999, 44.97721079857119, 45.36211298358056, 45.38700434469408, 42.49999477017311, 44.7133098110076, 43.705260676722375, 42.650633396640906, 41.66672645076629, 45.02920573757541, 41.79360728110037, 46.25928063546458, 48.465872733823716, 54.057580117256414, 55.69636598710091, 56.530516839796505, 51.863720032476614, 48.66780027266472, 43.995198357489805, 43.577685586867794, 44.110194406201764, 42.10833041898666, 43.46748267450641, 44.50704020838584, 41.38402946533696, 43.30132322926676, 42.49418573994791, 42.84272363108974, 43.20761780585013, 49.23029168959587, 56.37985467910767, 56.62152759490475, 53.21381553526848, 51.12074467443651, 52.169664905917266, 49.73757574635167, 50.37648670135006, 50.39111321972263, 49.861565789868756, 50.38982275993594, 55.63127425409133, 52.37565994262696, 61.56355319484588, 38.20635657156668, 36.91970540631202, 63.20292349784606, 50.737407515125895, 52.38359881985573, 45.62780649431291, 45.90638106869113, 41.396569282777854, 44.28563417926912, 42.90957650830669, 45.47492819447672, 41.53156157462828, 40.81199492177656, 41.0616224042831, 41.305287884127715, 40.85098328128938, 43.06978964036511, 41.56653734945482, 44.34945506434287, 41.782071590423584, 42.99704536314934, 43.02630624463482, 44.3585471184023, 41.18209408175561, 44.7710314104634, 44.06379276706327, 44.007695028858805, 43.49382139021351, 43.03056201627178, 42.43457355806905, 44.86331301350748, 42.42363406765846, 44.25685967168501, 50.78977507929648, 59.421884167578916, 56.24290904691143, 56.35666954901911, 57.760250491480676, 57.230024491586995, 52.36055881746354, 48.41635281039823, 44.19657676450668, 45.981039462550996, 44.79077662191084, 45.0290096190668, 45.421450599547356, 47.32487878491802, 55.6869601434277, 58.694657125780665, 59.85832237428235, 59.73348902117822, 58.94897968538346, 64.04536231871575, 61.11864659094042, 59.19297856669272, 49.57088285876859, 65.76517651157995, 63.29295366041122, 76.94351180907219, 24.968824002050585, 1.9500594057383078, 5.2712948476114585, 3.0647625653974475, 0.24145735397694573, 0.18755649546942404, 16.561001923776445, 59.42961123681838, 43.22938696030648, 92.30764758202338, 41.30843362500591, 26.714510148571385, 38.763623391428304, 54.19711059139621, 55.89642255536972, 66.40127120479461, 11.438610053831532, 0.2944688150478948, 0.057305487308410875, 0.06497958539834907, 0.08992967481214194, 0.049767683921081406, 0.04549952081194328, 0.0988097370211636, 0.024964966841282386, 0.0031210125176115867, 0.0306936344432254, 0.03308517325128759, 0.09559920808720974, 0.013987046587581356, 0.21494187114219512, 0.12041983630267844, 0.20442440324733335, 0.19866109314945438, 0.10533781737209329, 0.16342199858157866, 0.1537600210717609, 0.09371061749275654, 0.06729487930574725, 0.1563648272666239, 0.20859699305747786, 0.20774421462368584, 0.2910170067221888, 15.708899363394707, 80.57874095055365, 63.14877517761723, 76.53247879397485, 42.44281053543091, 44.911118861167665, 38.77958743802963, 52.82878391204342, 56.789738439744525, 75.19666856335056, 19.321862190000473, 0.24126855926888607, 0.12669307750559625, 5.228606222137328, 11.706593248151965, 11.242247377672504, 11.382768250280812, 26.8562057710463, 62.31959789030014, 59.533742320153024, 69.93633085681547, 63.705469331433704, 65.68907076312651, 62.89843382373933, 68.54912973219349, 64.60315473618047, 62.30615200534944, 58.69684973070699, 59.43544380126461, 50.50154755192418, 49.27339069304928, 45.913327586266306, 46.72514054083055, 48.181230252788914, 47.18329298880793, 43.62962953505978, 47.94430340490034, 44.90219154665547, 45.19246262888755, 44.726634102482954, 48.06947408183929, 44.25815405384187, 49.33391286480812, 51.21990219239266, 56.72594501126198, 57.767255844608435, 59.236116793847856, 54.25711893266248, 51.08680832770563, 46.30077146714734, 45.9943990553579, 45.98467157733056, 44.883411238270426, 46.643696446572584, 48.2625880549031, 42.46887468522595, 44.60848839052262, 44.78367713189895, 45.54602115384994, 46.273581597112845, 52.185640719629106, 58.502861069094756, 59.68623622771233, 54.279197954362445, 54.19035234758931, 54.51278686523438, 52.53242531130391, 50.72155329488939, 53.509201388205256, 52.861504324020885, 51.86487320930728, 57.9478653015629, 54.42104654927408, 63.42548662616361, 40.09992391832414, 39.31312784071892, 65.12133905964514, 52.972503477527255, 54.16850866809968, 46.59443932194864, 47.46618609274588, 44.82872947569817, 46.31286413438859, 45.3822975004873, 48.2050351173647, 45.354362380120065, 43.01153459856587, 43.3216764080909, 44.534877269498764, 43.47542939647552, 45.46478102284093, 44.62206371368901, 46.778418094881125, 44.72207238597255, 46.00265172220046, 43.55567324546076, 46.065558695024066, 43.307689236056426, 46.09111685906687, 47.91785094045824, 47.55436489658971, 44.37303635381883, 44.88702374119913, 45.2300585469892, 47.394936238565755, 43.40348920514507, 47.58294328566521, 53.94981691914221, 61.97394294123497, 58.068588010726444, 57.010006981511275, 60.21674071588824, 60.984987904948575, 54.12624120712281, 50.66501625122563, 45.64471975449593, 49.24151751302904, 48.259583519351104, 46.73926499582107, 48.94599829950641, 49.91463153593002, 59.37226618489912, 63.179165701712336, 62.788195610046394, 60.493287424887384, 62.47447659892421, 68.93327097738944, 62.74148018129411, 63.22335904644382, 51.95379334111368, 69.48318727554815, 66.65198910620906, 79.65538363302909, 27.368157448307162, 7.587796661161608, 15.581411546276463, 3.209752243372702, 0.6095177548066263, 0.39074406508476506, 19.494999531776674, 67.86343666814989, 55.714522638628566, 107.89458182550247, 47.46265203722062, 31.12676670474391, 42.15439473429034, 62.963894259545114, 63.72742283728815, 76.23499055062571, 14.288708163845925, 0.4328846925448987, 0.17521028376875386, 0.16117651826672016, 0.4302437729652851, 0.2534499394917681, 0.13088308815513888, 0.14281047958760493, 0.13905222077042828, 0.1524341373794502, 0.21101018534071986, 0.10829772830249802, 0.1963228395869655, 0.15600612957871732], [0.07988858337123549, 0.017250358021908233, 0.019335023074921583, 0.07754516637613697, 0.04593820574002401, 0.059918299122082616, 0.06055281527580754, 0.026881567525467085, 0.19473199672516317, 0.07462376668568581, 0.052530671950549855, 0.15517481692856358, 0.23029543759842075, 21.829764881441672, 58.92728113359021, 58.62234038691367, 46.64535560915547, 27.3300535832682, 28.43036274756155, 24.093137210415257, 46.15580458794871, 43.45191086492231, 56.61282385549238, 6.978275045271843, 0.09512260180687714, 0.3131252929808632, 5.721541268210258, 6.421670615673066, 6.016339255917457, 5.61263224770946, 32.0087645899865, 56.77499817263696, 57.47033242256411, 58.68297238503733, 61.16724867974559, 62.87398961282546, 62.32992941333402, 57.566422647045506, 59.90375126561811, 61.0468005364941, 57.99576136373705, 58.09444819727252, 55.5649705086985, 51.405551895018554, 45.30733708412417, 43.47179335932578, 42.340358226530014, 41.9046260464576, 40.54754480238884, 42.154888952932055, 42.58917770078106, 43.796950001870435, 43.10551851026474, 43.18499749706638, 41.291096748844275, 40.03198454456945, 44.48063089001564, 49.83664697216403, 51.636787383787095, 52.261393454767045, 53.12662516870807, 52.7797503625193, 46.52178133687666, 42.19568552509431, 41.05413459962414, 40.467473537691184, 42.333329339181226, 41.143019430098995, 41.52497983747914, 39.55267090951243, 42.402288529180716, 38.065594473192775, 43.5047177345522, 54.98979806900025, 56.07463152177873, 54.68611640314902, 52.92174016275714, 48.840745418302475, 49.26551457374327, 47.354712332448656, 49.937247922343595, 47.198468639004616, 48.864648342132575, 46.823454749199655, 50.839899047728515, 49.491313657452984, 60.934106919073294, 38.58116649812268, 36.76288120208248, 59.90948969318021, 50.830705012044604, 52.41163984421761, 42.20825672149658, 44.16018893641811, 40.78783704388527, 42.49047910013507, 39.87680381344211, 40.925049397253225, 39.70573748311689, 41.117900571515484, 38.21153017782396, 40.055499153752486, 37.82152498922041, 40.49584011877737, 38.74676112205752, 42.48065356285342, 40.89713388873685, 42.85955452149914, 40.94201364824849, 41.81190513795422, 39.80357708469514, 41.851450474031516, 41.27381086349487, 41.10789460520591, 39.76443183037543, 42.60995841795399, 42.32893236221806, 42.434361750079745, 40.1117459420235, 47.67031408125355, 51.08810663223267, 55.481686822829715, 53.11146913036224, 53.04410634502288, 56.391135415723255, 53.712282103876916, 46.75560951232911, 40.92452379965013, 42.98038313465734, 43.63298708392728, 42.403629979779645, 44.855978181285245, 44.511786276294345, 43.861861305852095, 47.57947198806271, 56.41619543875418, 57.87152028852894, 60.10938152190178, 60.11414720166115, 57.813806533813484, 54.87411560550813, 48.02912858224685, 48.44127162810295, 57.27074653871598, 62.97467293277864, 67.24758532739455, 52.01615118211316, 1.5476771780560095, 2.4661980905840477, 0.7908043721991201, 0.11581822193317837, 0.03897011129846496, 4.232182012450311, 52.797914858787294, 46.17583613241873, 46.37139374209989, 28.902178772034187, 17.963059025426066, 32.15750478929089, 47.55006990125103, 48.68961649556314, 59.148726386408654, 13.118527858488022, 0.24108716497017493, 0.09146726690232755, 0.008205213441303181, 0.05426218004656896, 0.039887838666477514, 0.061524505877206405, 0.028561964150398012, 0.0714313021049865, 0.016618766408834248, 0.0443631366285826, 0.1051167167362667, 0.03769141862228994, 0.000255602572583631, 0.03155599089129077, 0.06402213637146258, 0.06025017607176016, 0.05801370112045158, 0.08460187803833716, 0.007545011317087038, 0.05338553414349595, 0.046580543651455836, 0.058002351527853366, 0.05852773079588529, 0.057289905080031005, 0.10262119298380229, 0.08522358903240773, 29.661012272680964, 70.66928063669513, 62.341441569789765, 57.070980225839925, 30.486349559599358, 34.43312275794245, 28.210115778830748, 39.352053442308986, 50.67513988864038, 63.79791959639519, 6.957244767296699, 0.1486206436229329, 0.10683092273651593, 5.886947618376825, 10.896397290691253, 7.39841825539066, 8.464685659254751, 33.007090168614546, 59.83174831636491, 57.465390236146995, 60.318698806147424, 62.658710325917895, 65.83790117694487, 63.12289537922029, 61.361052989959724, 60.76746894467262, 64.23269079577538, 58.13426025452153, 61.23337199611049, 57.92381725003643, 54.47945848588021, 47.82673820372551, 46.545747018629505, 43.716349217199514, 42.297977016818145, 42.556198412372225, 45.368110287574034, 44.257734360233435, 45.861481697328635, 46.570689370555264, 44.35542883411531, 43.949153654036984, 42.69199479010798, 47.25094995191021, 51.917150558963904, 53.91874390263712, 54.07266163056897, 55.69270249335997, 54.78440707729709, 49.5232339059153, 44.42614916832217, 42.23858448766893, 42.07021282565209, 44.51270803328484, 44.82478749367499, 42.995539173003166, 43.15750168215844, 43.64565633958386, 39.534047495934274, 45.831408885217485, 57.20814551076582, 56.718374836829405, 55.61358828698435, 55.30419957253241, 51.45580137929609, 52.83628348381289, 49.98617556787307, 52.71602361432968, 49.992121881054295, 51.753132727838334, 50.417126378705426, 54.373668239962676, 52.61960391075381, 63.63645130588163, 40.61129116242932, 39.08416732665032, 62.536552029271284, 51.793764560453354, 55.54625295823621, 44.574775618891564, 46.92080797687654, 41.61702609831288, 45.25123542354953, 41.73148478231123, 44.29999789884014, 42.26487613493397, 44.271035117487756, 39.69296232346566, 41.745166009472264, 39.864028653790875, 40.99399682014219, 40.23871306450137, 43.03950894263483, 42.63866624524517, 44.63109693219585, 42.459817932498076, 44.08394198263846, 41.99410707719865, 43.91827283367034, 41.24559333247524, 42.64050191448581, 42.5401637631078, 44.002242934319284, 42.844908391275716, 43.905454527947214, 41.18253730958508, 49.238916981604795, 51.538975238800056, 57.11345165006576, 55.831978013438565, 54.16109931084418, 57.41466222270843, 56.354057250484345, 48.62918453831827, 43.02995797126524, 44.80466965706118, 45.945632227005504, 44.05784253151187, 46.07805536639306, 45.82352492117113, 45.93743839571553, 50.555040836334236, 57.759854332093276, 58.63608829436764, 61.878033145781494, 61.44219113934425, 60.69065324721798, 57.30854249769642, 50.627157534322436, 50.26767623039984, 60.08571001791186, 65.04979110533192, 71.2404561811878, 54.278699813350556, 1.2758571702626444, 4.477567451615488, 1.7533330523198651, 0.3028208281724684, 0.05394448721480947, 4.031735903793766, 56.51968717575074, 50.90165676609163, 51.09000505939607, 28.58578862682466, 21.746206629660822, 38.10042119795276, 54.123966232422866, 54.76379894441175, 66.84518937141665, 18.528329441624305, 0.36839544172248534, 0.03803809256022496, 0.02903145538913387, 0.09986308493441153, 0.0411924940624064, 0.06009851747582998, 0.038245702387704965, 0.045632663062743606, 0.0078111378130533045, 0.04554067888567525, 0.033120076217117815, 0.024791786920339353, 0.02628383891386611, 0.15450778417289257, 0.16263424569079954, 0.16084752946851716, 0.20874448030466036, 0.12623632822426098, 0.2032021865729363, 0.33642386536925073, 0.16475649310215829, 0.2532479221061353, 0.21027769803279833, 0.1699716519684561, 0.19360126627068366, 0.3276352127713542, 37.33946961741294, 80.86387372786, 69.93075324643043, 64.73336173642066, 38.46759426978327, 41.18715786164807, 33.69297150642642, 62.85479745557232, 56.018459258540986, 70.7942081266834, 9.791850986019258, 0.46229422573120366, 0.8551534289313901, 9.666036059779506, 9.373600809804856, 14.876503771351231, 8.959424995606946, 36.17746745386432, 59.514860030143495, 58.232770581399244, 59.641136815471036, 65.24576056388118, 66.02078560859927, 66.28876978351225, 60.83002682655089, 60.972703041568884, 64.38724002530499, 61.34423386666083, 63.140867679349846, 61.784080613044004, 56.428150823039395, 49.12188130040323, 49.108968857795965, 46.05109691619874, 44.74587725054833, 44.626884306630785, 47.64280649923509, 47.2947314477736, 46.391495889233006, 49.458008812319854, 47.557706755976525, 47.02963413730745, 44.634783960157826, 49.42636705213978, 54.604758601034845, 56.855096893925825, 57.0724864159861, 58.91748697526994, 56.619605633520315, 51.112331190416896, 46.05422696759624, 44.48715771398237, 44.17175992842644, 46.83582590472314, 46.92378113346715, 46.194192824825166, 43.50951871564312, 45.29054933978666, 40.875415725092736, 47.6889806409036, 59.74397351664882, 58.939671900964555, 58.8503203084392, 58.45629861277919, 53.972398004224225, 54.747705459594734, 53.06837012690883, 56.18220252375449, 52.66902577492499, 53.38545060926869, 53.172713018232784, 54.71152551712529, 53.72293526126493, 66.36092570520216, 42.421916069522986, 42.94825107820573, 63.33952396146713, 56.04278187597952, 56.799673803391, 47.662567400163226, 49.933753090520064, 44.912491690727975, 47.556651638400176, 45.10426421319285, 46.589336318354455, 45.637439835456114, 48.303702339049316, 42.884685147193174, 44.30865064744027, 43.07994465674124, 44.690873853621945, 41.96608174231745, 45.796888105330936, 45.63999722080846, 46.95564254637688, 44.06884477984521, 46.727913656542384, 44.98527911401565, 46.71553073390838, 43.76599073410035, 44.303214242381436, 43.29284698732438, 47.34123506853658, 45.0809221882974, 46.40223533876481, 43.39350677305653, 51.39721685840238, 55.158840456316554, 59.99346371619933, 56.57592219691123, 54.4267535978748, 60.65640703324349, 57.9974126815796, 50.69617555987451, 46.27943769578011, 46.64231184990176, 48.72848718397079, 46.51778836404124, 48.55491053673529, 47.276488504102154, 50.110769656396684, 53.50195677049699, 59.945571576395345, 61.5794191821929, 65.02657851865216, 65.4244480594512, 63.96446343391173, 60.17962332694762, 52.57843471342518, 54.87249174425679, 61.20433076735466, 68.08039080712103, 72.22071924517232, 59.82393887735183, 4.123292113504102, 11.504160704151278, 4.4684508827424825, 0.34744808510426556, 0.1592071973268063, 5.032193535758603, 65.09592210092853, 57.46265242176672, 57.42946524773875, 37.81874010639806, 26.218846113451068, 43.86348124473326, 63.71396518522694, 61.65123778004801, 76.98333171106155, 26.389667295640518, 0.3868875784739372, 0.26611826052108123, 0.07889698980556381, 0.2517029066239634, 0.2241154982438011, 0.1709163915966788, 0.13767543819642838, 0.1646361560110123, 0.1496329981713526, 0.11688581908181792, 0.10448388214553557, 0.12219165211483357, 0.1895950401141759], [0.009575915192404102, 0.037318414242397395, 0.06067574557457721, 0.024915808894401117, 0.09759669041922016, 0.012173157226624749, 0.04469128273006889, 0.01445468102071074, 0.025930925189787825, 0.04652236693448598, 0.04162281331035399, 0.01791989971553126, 0.05524943372414959, 33.21990228468372, 63.77341654992873, 56.73073422524237, 39.63749216448876, 30.83464034142033, 17.25960546924222, 34.76115842019358, 45.834542858985166, 51.677466284844186, 52.77985234414378, 1.8516183332089458, 0.09514954511917408, 0.17915172953038447, 14.31735715558452, 18.2229023210464, 6.677079671813596, 12.54431934125962, 40.3922934685984, 61.496527733341345, 63.60223647086852, 60.59377854870212, 59.9054535742729, 59.47502443867346, 58.46545734713155, 57.25243691475161, 57.101037348470385, 56.15689539140271, 57.65275009216801, 55.89679518053609, 55.69537362744732, 56.0249037127341, 54.58700987600512, 45.717715063402736, 42.35101922865837, 41.15022874647572, 42.68776647506222, 41.83028928695187, 44.05186091699908, 43.507690891142815, 46.17908777729158, 43.374600948825965, 44.90714550018311, 43.864516750458755, 45.667904884584495, 48.76557319395004, 52.79425136504635, 54.36845148763349, 53.859367062968595, 53.93020114591045, 51.117826431028305, 45.519807953988355, 43.06646739282916, 40.50287685086651, 40.79803912870346, 41.682572826262444, 43.09288847830988, 40.14367011285598, 41.55405244519634, 39.04567710814938, 51.018233529983036, 56.123178697401485, 52.717490580774125, 53.42896930633053, 54.77396965026856, 50.982779225995465, 54.227783526143725, 49.129882935554754, 51.42629338848976, 48.236747480207875, 50.00683861394083, 46.650148745506044, 52.30980334743377, 50.45655796604772, 60.293022970999445, 41.324240776800345, 37.28552918280325, 59.438252218307994, 51.90789768772741, 51.131711621438306, 42.851113580888324, 43.71479988098145, 40.92393152175411, 42.36223720735119, 41.73043358710505, 41.87797746350689, 39.86259698867798, 38.65650346202236, 37.17602052996236, 37.03925140442387, 39.26718511889058, 40.05534618131576, 38.04573943538051, 41.928454445254424, 41.51548770166213, 41.36919898371543, 40.68458849383939, 40.54392445471979, 40.2837771754111, 41.838526264313735, 40.02783467692714, 42.269061303907826, 44.28732079844321, 44.44784772011542, 44.75163921233147, 43.307779450570386, 48.488100805590236, 51.83194098934051, 52.843304526421335, 54.85056961736372, 49.77600712930003, 52.246915986461026, 55.96203596361222, 53.04487905194683, 45.00472622532999, 40.408696820659024, 42.29618841601957, 41.50959630166331, 44.10611514122256, 43.280546434464, 44.34210062026978, 43.20569976683586, 42.69245370741814, 47.21486022395473, 52.208335553446126, 49.75949395087458, 47.7892638790992, 45.89717918826688, 44.83477384813371, 44.746085136167466, 47.1908631632405, 50.36482941719794, 61.50122281043761, 60.23184576342183, 69.03666465513169, 8.620898954329952, 4.354538879086895, 2.358759958897868, 0.4451101687887023, 0.0958455743027791, 0.3551504863125663, 38.51214455020043, 47.85701105671544, 34.80142155001241, 33.64564026555708, 17.057930923277333, 20.835855891627652, 39.15180075553156, 54.14643749114006, 54.52912745937225, 17.608945485084288, 0.28148852769405613, 0.09650348295127192, 0.023487541381449952, 0.009026341910113492, 0.10371883610083212, 0.04763074294333497, 0.011485386470843469, 0.0334834776848795, 0.04557296566124405, 0.026484607576182293, 0.08980222842505864, 0.016536450261370312, 0.04263294620379325, 0.09744423126140911, 0.0322418560033604, 0.09467960380378271, 0.003080949949611339, 0.053185451129872, 0.08478945466659724, 0.03691735955315732, 0.008581548388446531, 0.029670181196002714, 0.1113142378087486, 0.04216501586920312, 0.01754925297122569, 0.2862666793648274, 43.415856438298384, 69.86584586481895, 61.89966109491164, 45.51259863761164, 34.24070696676932, 29.643665590593894, 34.43566837618428, 45.16500603768134, 57.39825494827763, 57.733076310926876, 1.6434833984221182, 0.13752376810917932, 0.7519758492708207, 11.020544229015227, 7.8374579741108805, 5.8778938074265765, 14.634219946399813, 40.84341310685681, 63.37913990020753, 65.0410089185161, 62.209473425342196, 62.659349672255985, 62.03653220207461, 59.49773103960099, 58.56244971675258, 58.09353820739254, 57.64328149057204, 58.67375481513239, 58.58796865709367, 59.54028483360045, 57.99753819742511, 55.42231782790154, 48.55260810544414, 45.45365718103225, 42.517927846600934, 44.25305889498803, 45.79989264088292, 45.20493184366534, 45.88665154672439, 47.886118965764204, 45.385721729647734, 46.36707521254017, 44.45845773143154, 46.84312543561382, 50.21326903373965, 54.5522419867977, 55.92098835975894, 56.04085206985474, 55.55789063053747, 52.72961854934693, 47.64512069763676, 45.13519602437174, 42.84408469353953, 43.106589317321784, 42.00757257400021, 43.16424031411448, 41.84419016684256, 43.21132052329279, 40.62215612780663, 52.859256805912146, 55.93787024098059, 55.79858295379147, 54.48573427815592, 56.436870251932454, 54.2767817743363, 55.8321152963946, 52.00841234576318, 53.86192837069112, 49.845162437808135, 52.60133351049116, 48.85581516450452, 55.25604855629706, 52.81312973268571, 61.353043510067856, 41.11364087750835, 38.604002537265906, 62.29830726500481, 52.54901693713281, 51.366398795958496, 43.66513875222976, 45.25882913220314, 43.737008340897106, 45.16638278961182, 44.672885864011704, 44.557301459773896, 41.58272497115597, 42.002100867609826, 40.75548141233383, 39.43754934495495, 41.54810220964494, 40.871634560246626, 40.02325727093605, 43.74299387778006, 43.58150989778581, 43.92594891209757, 43.209818255516794, 41.82007935739333, 41.91787973526986, 43.870918058579974, 42.476315421442834, 43.2884656998419, 46.374135478850334, 45.80289717643492, 44.34048460375878, 45.83592745565599, 50.27814503638975, 54.060055132835146, 56.06077771033011, 58.316313143699404, 51.14290998828027, 53.40668239901143, 57.92244834284629, 55.97543085775068, 47.42013746692289, 44.4198537641956, 44.65388198052683, 43.9428464827999, 45.32480732087166, 44.71628296759821, 46.32040292985978, 44.87203636477071, 46.57285451889039, 49.851402928752286, 55.32965967732092, 52.88232426489554, 51.16634222768968, 47.91499153260262, 47.721759888433645, 46.612042919282, 49.526591454782796, 53.01763034635975, 65.07389014767062, 61.795953627555605, 72.56393447999032, 9.83586194053773, 1.3731518075350793, 4.648721054677041, 1.0108178986176368, 0.12618094772821473, 0.42928365029154286, 43.49467646691107, 52.42811379894134, 41.59635520750477, 34.899300375292384, 22.584864285684404, 27.519935523310018, 46.70204954762613, 58.95752652998894, 64.18781495863392, 27.940707783545218, 0.08470621155274492, 0.05167512410891153, 0.023045843812606992, 0.03356935614119134, 0.062872203923161, 0.04963837594034211, 0.02385991565402477, 0.056940339160181826, 0.04075866230132599, 0.028443783596758882, 0.01766047361607273, 0.050067009794856274, 0.00854450612208776, 0.1599069267150856, 0.14294514252293494, 0.17948215857388514, 0.11464618401782167, 0.2624343275543182, 0.15534329498487134, 0.13675043299313516, 0.11489556095893345, 0.17877741897058103, 0.2984798675583255, 0.14456630714478033, 0.0821250468312252, 0.46716703522589903, 52.48187772689327, 78.28983399175829, 72.65999332551034, 52.85506379219794, 43.467451295545025, 26.89764168954665, 48.94559821774883, 62.03929355067592, 63.20506118958997, 64.16962300577472, 2.5402056161434423, 0.31885461941842114, 1.0561050330438921, 29.42137114463314, 30.890710623033588, 14.232877146813179, 18.36292701382791, 45.037289742500555, 65.5671948771323, 68.2791922169347, 62.846956637597856, 64.06108710073656, 62.59191236188335, 60.76420553268925, 58.463551075227805, 59.96151601114581, 56.94562519750288, 58.899381314554525, 60.7374628128544, 60.911553290582475, 60.68742905893634, 59.1927981376648, 50.72627190620669, 47.426527007933586, 44.11946688928912, 46.49801177363242, 48.6009003270057, 48.121127774638516, 49.008866048628285, 49.833026624494984, 47.60072731202649, 50.33150496021394, 48.878360948254986, 51.03221677964734, 53.38706662577968, 57.52321381722727, 59.25131990063576, 56.57251365723149, 59.23848198306177, 54.44178804274529, 49.84994772941836, 47.007425677391794, 46.29138131295481, 44.37722544516287, 44.84134774054251, 46.26880022787279, 43.054888556080485, 45.4722099919473, 43.13916852397304, 56.21704101562501, 59.3489476942247, 56.2118987883291, 55.18250803793631, 59.34168346466557, 55.66757579003611, 59.4378678260311, 52.71667865014846, 56.757296516049294, 52.44499568016299, 54.10098114321309, 52.315977158085, 56.31455113810878, 56.36906031639346, 64.98280878989928, 44.64315429810555, 41.2972705594955, 64.05784330060406, 55.75356983369397, 54.06156132298132, 46.29098907593758, 47.47225007703228, 44.93786550337269, 47.08407271292902, 48.17390326530703, 47.64698382346861, 43.890706416099306, 43.07281771013814, 43.1993612166374, 43.55672051829677, 45.010229310681744, 43.67568600562311, 42.00778045961934, 45.82103421611171, 45.30942770742601, 45.61344669711205, 45.017073846632435, 43.75474137644614, 42.8706548290868, 46.18416332429456, 44.709771833112164, 46.407024552745206, 48.28112517633746, 48.33706209736486, 48.11345169621129, 46.72622311499811, 54.07158297877158, 56.69698615227976, 58.5033788219575, 59.662403906545336, 51.24923367654124, 55.47841948847617, 61.133351556716434, 59.828386845127234, 48.380172867928785, 45.86249366883309, 47.679457126125214, 46.27713918685914, 46.92032944771552, 48.591023798911806, 48.7886877213755, 47.56320199658794, 47.4596082779669, 52.43059665926042, 57.58126097340738, 55.50580155464911, 54.821085160778416, 50.41453369202153, 50.02670934123378, 49.220019002114576, 51.8756950286127, 55.409201422045314, 67.21881081981044, 66.58529312379899, 77.55145565156015, 10.645141043970662, 10.230852461630299, 11.765084612754084, 1.7433935211550806, 0.32430754133289863, 0.6187594105159083, 50.14507862829393, 58.9014680154862, 47.83789734686575, 45.32447784177719, 27.747940940241662, 32.14103475693734, 56.64750937492617, 68.67763442377891, 74.41650129133656, 34.01814776082193, 0.35846145703427257, 0.23196704144920074, 0.11311112767866544, 0.10027373870534283, 0.24704313085925197, 0.22399767392104675, 0.12049058452248575, 0.18291326720387707, 0.15819435248211508, 0.1331967043299829, 0.16241053269515116, 0.12152752283239558, 0.1463705974240457], [0.07364965524644622, 0.03648483397198781, 0.01973177426524701, 0.10663491148020952, 0.02791300532408059, 0.05244010120570179, 0.04212015376035725, 0.031678534315658674, 0.06864818128486795, 0.07125259677488958, 0.06958832438554495, 0.034074058696146936, 0.9062828111552423, 42.1223097462808, 59.869104969886045, 53.89704535084387, 45.1823115348816, 37.4375484835717, 21.993835664564564, 39.329056585988695, 35.91228385125437, 59.277564479458725, 37.37617515748547, 0.08499039186825676, 0.03795036017113636, 0.3467793822769196, 3.4968618952458908, 7.254727127090578, 7.866500183459252, 26.46172711926122, 54.61306225868964, 62.71479237464167, 59.88225667707382, 61.56722453332717, 58.919150060223, 59.71803880506947, 60.44045309866629, 61.39635824388074, 58.582430270410356, 58.499868300653276, 59.17495527575093, 55.347961456544944, 53.36499544882005, 57.0406210807062, 57.1022964292957, 49.75776026325841, 42.43767223050518, 42.06337221207158, 41.94896844125564, 42.005415270405436, 45.6533803478364, 50.17559074586438, 50.73128077291673, 53.10362439001761, 51.59387665410196, 50.84582967142905, 50.29487002280451, 53.02836587352138, 53.19534509412704, 54.42531016565139, 51.41841726918375, 56.141900170233946, 55.93672490889027, 48.99963671161283, 43.52065824693249, 41.47940581844699, 42.026545078523704, 43.004486099366225, 41.34052253538563, 41.050169083379934, 40.176610177563084, 40.662886019675966, 52.16028651883526, 54.98283193957422, 55.97621140941497, 54.02016462818269, 54.459956461383456, 50.454883113984145, 53.078438851141165, 52.00477238624327, 53.889459486930605, 50.103740769047896, 53.812651634216316, 51.34594755788004, 54.80388556757281, 50.18577714120188, 60.173163183273815, 41.57889673786779, 35.651520759828635, 59.29785097798994, 50.788414016846694, 49.24087424432078, 43.25531774951566, 43.39762918410763, 41.64276861375378, 43.502556508587254, 39.66131664091541, 41.58226605384581, 40.24374154306228, 41.33197176840998, 37.15494171265633, 38.079758151885, 35.737938419465095, 39.80767988389538, 39.37988265868157, 40.24484765145087, 41.79000654528218, 40.79876084481516, 41.07524479589155, 41.678199383520315, 40.48738348868586, 40.75762302644792, 42.369897596297726, 45.671635058618364, 47.54326851137223, 49.7076206053457, 49.3089509010315, 51.6940422211924, 52.61379488052861, 53.62836299404022, 56.700045601014175, 52.697149169060495, 48.393454013332246, 53.99923486094321, 56.446209415312744, 50.871756538268066, 44.148825830028905, 40.45091721319383, 43.1379408221091, 41.0870825090716, 43.45660594201858, 42.065929597423924, 42.665558015146566, 40.91032874199652, 44.41413102611419, 42.50326994926699, 40.973133733195645, 41.89491425791095, 45.575878235601614, 45.626900426803104, 50.767715669447384, 50.79083411924301, 53.06083525380781, 48.89541541376422, 59.64988370095531, 60.04062237278108, 70.95391135061942, 26.60384047415949, 0.9287715366771145, 1.0193113622165497, 0.4026448426227416, 0.08522185767369886, 0.039228750242581295, 20.60740920805162, 55.113097775367, 35.95100548959548, 36.90852272895075, 20.767235986648068, 19.3142076846092, 34.70849275588989, 43.216305855781805, 58.04251601619106, 36.756970190232806, 0.09167369695440417, 0.048328461350813035, 0.012136192526668312, 0.031025902097744328, 0.04189674336943896, 0.01775683790084816, 0.0417891884553096, 0.053410156209382324, 0.01556430288004659, 0.031034627839201884, 0.05011146970754189, 0.011702324376411496, 0.025644835400124712, 0.016895946595937978, 0.05303096183906159, 0.031401153030474825, 0.03628418022286027, 0.03270294900322634, 0.03164002116048529, 0.06713285170976194, 0.022496648786228993, 0.06346946522112816, 0.0434386906694741, 0.040206374194953716, 0.024426780498376297, 2.02343248792233, 50.97041591521233, 66.76680472589308, 61.20746081875217, 50.41684396805302, 46.47025708229312, 24.87574419667644, 36.41919528284381, 39.72188980348649, 64.90862892520043, 40.12609004974365, 0.06472396484065442, 0.055320668409788804, 0.8274628438295857, 5.417679173331107, 6.261078484596745, 5.5027235131109915, 24.577714666243523, 58.10071222243771, 64.53205393206689, 62.50448273074243, 62.16598610724173, 62.235482661954826, 62.17934962241881, 60.37507111026395, 63.78513266963344, 62.64502517638668, 59.60564721015192, 59.071224274173865, 56.54839892541209, 55.992144077054924, 60.368116747948434, 60.117645955854854, 50.587859307566, 43.36634828198341, 44.715529872525124, 43.86823515738211, 44.22244087342293, 47.70673721067367, 52.697717912735484, 53.09070802504017, 54.23893874691379, 52.31292163172076, 52.61415181621429, 52.682922732445505, 54.34418770574755, 55.72803128150202, 56.61842107772828, 52.2087356352037, 57.17267551729756, 58.1549076111086, 52.29152510243078, 45.41508067038752, 43.04739682905136, 44.00089363898001, 43.95186793419623, 43.70960274050313, 41.17993677816084, 41.93327896056637, 43.45222073216593, 53.806611184150945, 56.6927303806428, 58.82076917156097, 56.21280093346873, 55.971355515141646, 53.79210625925372, 57.25252712926557, 52.91690388033467, 54.27546778032857, 52.97566883025631, 57.24853807880033, 51.738992583367136, 56.27907722227035, 50.19307274972239, 63.467695251587905, 42.9595043582301, 38.048944011811294, 60.48504652515535, 53.249552249908454, 52.09481823828913, 44.5821810537769, 47.0681361229189, 44.942176188192065, 45.89321367202267, 42.81733412896433, 44.07279460660873, 41.29072804604807, 44.54069022209414, 40.43093273716588, 40.564261944063254, 39.4892854075278, 41.29303832207957, 41.775560455937544, 41.13328018496114, 43.447823755202755, 43.95507643299718, 43.8908907674974, 42.79924023535944, 41.97995516561693, 43.00713369923253, 44.74098997731363, 47.69517798577586, 49.084473656069854, 51.73240692384782, 51.40859565427227, 54.30750177752588, 54.742516163856756, 55.931068851101784, 58.19168375384424, 54.25622463226319, 47.374649740034535, 55.841411313702984, 58.225420059696326, 53.81120035725256, 45.67363546740624, 42.73650976919359, 45.21555754446214, 43.77181937617641, 45.70831706446987, 44.16176965159755, 44.78611292377595, 42.35065444823235, 44.78573245386924, 42.284409538392104, 42.43576203623126, 43.415338685435636, 47.28635326508553, 47.211553665899466, 51.798785194273925, 51.25384246149371, 54.52004717242334, 50.57555875470562, 61.78449638428227, 64.06408771391838, 73.50431488406274, 29.97394680976868, 2.0502592935677497, 3.7826195551503092, 1.7864328310374291, 0.183975386823858, 0.08148405340410049, 20.784164936311786, 61.5329469403913, 41.23625024672478, 37.696589654491795, 24.267527749461514, 25.600302065572432, 40.74917031872658, 48.94920679830736, 63.53814886462305, 46.681951322863185, 0.7516809973505236, 0.08223468933494822, 0.06389522241548666, 0.039840605515506, 0.0629639123085766, 0.00552067329408601, 0.06342163835201534, 0.06499155169172634, 0.11299135749258342, 0.042604635424551465, 0.04791312678266437, 0.020479974036495534, 0.06513272637441274, 0.11056858144940869, 0.2561306037128933, 0.09486004815346773, 0.18509490175112603, 0.15798861190917032, 0.12799064658822554, 0.14690046979775354, 0.13377010581954835, 0.1526348217720947, 0.2294484201458193, 0.09079779798705732, 0.19094577569875026, 3.387503763360362, 61.59001350402833, 74.17711119497977, 70.09115465225713, 57.16827069559405, 47.41373223643149, 29.497080733699185, 51.30859482672907, 49.27764646468624, 70.47804155657369, 45.22217066057267, 0.27750723003860445, 0.22040125883875356, 0.7343763581687405, 11.205480060269757, 16.93997348508527, 14.99284911540247, 30.867223470441758, 59.80935550505116, 66.46065588920348, 65.66113564275926, 64.71123172390845, 64.85870107527703, 66.88442091788015, 63.99236717531758, 67.15900251942297, 64.38352946312197, 62.97385315741263, 61.5589169533022, 59.905634003300825, 58.172652413768155, 62.120070842004594, 62.862124443054206, 54.594666342581476, 45.723426034373624, 45.9899510875825, 45.199683712374785, 45.623048659293886, 50.49424017629316, 54.87463728074105, 56.364879069789765, 57.9537880805231, 56.70590562205161, 56.783376355325025, 54.332130339837846, 57.37645833723007, 57.39078675546954, 60.01883752884404, 54.83597447795253, 59.47897818780715, 61.50620422055645, 54.60224828412456, 47.518361460778024, 45.478532852665076, 46.27376594851094, 46.974548370607444, 45.645245352099025, 42.935460229073804, 43.526941883948545, 45.22868179505871, 56.846040141197946, 60.38879940586706, 59.91612634351177, 56.708106071718284, 56.763352655595355, 55.30471732539516, 59.52772148193852, 56.56655949930991, 58.45802445565501, 55.90192171835131, 57.937474942976436, 54.968805543838016, 58.53580113380187, 53.322437732450425, 64.81944207222232, 45.336323399697584, 40.651566059358665, 62.37795491372386, 57.709334204273844, 54.08769607543946, 47.141810001865515, 48.810205844140825, 47.33186844856509, 49.1714326027901, 45.0045693305231, 46.76773355853173, 44.99249627513271, 47.82926028774631, 43.07342175514468, 43.09708541439426, 41.046835068733465, 45.03084528830744, 45.08740978856241, 43.80410440506474, 45.25703268666422, 45.83250322649556, 46.51708233741022, 45.71930754569269, 43.72494705261723, 45.747399560866825, 47.61294941748343, 48.427594323312086, 52.562847214360396, 54.47199029307212, 52.975978697499926, 56.08006008209721, 57.24941668971893, 57.743239172043346, 62.2561574751331, 55.273989477465236, 47.85500280318722, 59.17431985178302, 60.24585646967734, 54.967118924663914, 48.48993255246071, 44.337958597367816, 47.480902825632405, 45.90264697228709, 48.16028479606875, 47.32096425948605, 45.87596701037499, 44.70414715428507, 46.635671277200025, 46.19067053641043, 45.62390373599145, 46.07858488636632, 51.65275143038843, 50.134904000066946, 55.500176875822014, 55.39787361698767, 59.34039300487888, 52.6349207662767, 65.55182703079717, 66.62125341353878, 76.0172519376201, 31.293792993791644, 6.387366056442262, 9.29305591890889, 2.357976955752219, 0.560975666007688, 0.18986464177648868, 24.881641480230517, 65.43481488381663, 50.193045293131185, 48.71303304549187, 31.15749651385892, 30.09196112232824, 50.26985706821565, 59.293595206352975, 71.03096239028439, 56.75915964188115, 1.1999189805599952, 0.23036878285629137, 0.11097761877481976, 0.10597309578330287, 0.23119897701807562, 0.10448693117547421, 0.06471511652512897, 0.19951149671068116, 0.1502559502278605, 0.1523935806847388, 0.11431511912134387, 0.10709252644089923, 0.20460060346991787], [0.018353176062866565, 0.021896204392936443, 0.024256574913799286, 0.015331318305294602, 0.010473507854546751, 0.027673591356424075, 0.057280371115813335, 0.019182680745518977, 0.05343066438311531, 0.04029527486812684, 0.05304850908296724, 0.09287381199218574, 3.025139517361118, 48.404401348483184, 58.96343754183862, 52.22208738327027, 37.86591445246051, 25.079364238246797, 41.408261868261526, 39.75715583370578, 39.323302468945904, 63.75648760026502, 24.60384745751658, 0.05796585892958026, 0.06198010985709487, 0.8266290950198328, 6.7021529328438545, 2.732887638192023, 12.569347004736624, 43.871314217967374, 59.49633859818982, 60.81334106383785, 58.510258659239746, 57.276951728328584, 56.333213775388664, 56.11159593828263, 57.59896655236521, 56.77100127743137, 59.19467303060717, 58.815458282347656, 59.36941069941367, 58.372948246617476, 57.146336801590465, 57.593039851034845, 53.98404744363601, 47.203300999056914, 42.89565601656514, 42.66015298904912, 44.49332367989325, 45.530323828420336, 51.41263961791993, 53.58742129418158, 54.832373742134344, 52.98294090455579, 54.325195589373195, 52.941163739850445, 54.45533590932047, 53.94659273086056, 54.47667360305787, 52.76966594880628, 55.17368662741877, 56.13494580791843, 56.77746142110517, 53.884929149381584, 46.580507063096576, 39.642442195646225, 41.216736455117505, 41.86986207962036, 42.18553835345853, 39.12680349042339, 39.723490130516794, 41.36778300808322, 52.316891070335146, 52.238894739458644, 49.41399589661629, 52.43615858016476, 54.5253227603051, 52.88971401030018, 55.527755060503566, 53.71980128749725, 53.40562728143508, 54.40568654767929, 55.120059982422866, 53.50972306343817, 55.55509790297478, 52.56132533473354, 59.0250305206545, 37.586696609374016, 36.08948084615892, 59.1747042440599, 48.170730067837624, 49.881083503846206, 43.436248840824256, 46.072269870388894, 43.2316227113047, 45.45000153203165, 43.07828549415835, 42.7730348802382, 38.891359298459946, 41.16762838056011, 37.65209820962722, 37.973442308364376, 37.131972312927246, 39.08749741892661, 38.55983272675545, 41.329983126732614, 40.61994391102945, 41.73286545661188, 40.71757170461839, 40.33564267619964, 41.72782913331063, 42.96346202973397, 46.85297058474633, 52.04119943803357, 53.94450602992889, 51.52475664692541, 53.63157149284117, 53.19783972155664, 53.91316236988191, 55.571846423610566, 53.02035639362951, 50.96266138938166, 53.36422666426628, 54.63530994230702, 53.77044693116219, 49.48728930565619, 42.026701973330596, 43.42032009555448, 42.29108541242538, 43.87840194086875, 40.601916697717485, 42.138771933894006, 43.423430535101126, 45.113897554336056, 43.92056349785098, 47.48371908741613, 49.082971388293856, 51.03619798537224, 54.495112665237926, 56.288035915743926, 59.77407770772135, 59.9718043881078, 61.58613820229808, 57.268816732591205, 59.94335151487782, 57.840976791997115, 66.96710448111257, 45.586072475679465, 0.7100969480891383, 4.001954572816049, 0.8319426808626422, 0.3302835174385579, 0.02761739114629886, 7.486046456521557, 57.73621420706473, 41.12859687497539, 37.06009487951956, 22.298029199723278, 15.581989115284337, 30.142226296086466, 48.57012933300388, 56.862176772086855, 42.30473918299521, 1.2203005965678924, 0.1464572572900403, 0.03734381388752692, 0.07399739021615637, 0.02385460666470951, 0.011053093588880954, 0.06041719856101179, 0.09266840083704841, 0.01422572702605037, 0.045080612443627856, 0.12350591425333293, 0.015518533914620358, 0.010337758989584063, 0.03457369740992304, 0.03552487217670968, 0.05349670882306753, 0.03782078022918394, 0.020174887181530078, 0.06552079587333626, 0.008514950449969019, 0.035594789191119136, 0.031299200134291764, 0.024059489219179078, 0.033466382432849176, 0.05358105510353081, 4.964419391847426, 58.68764000554239, 62.57020596534976, 58.15541359686083, 41.68302389883226, 26.5235750521383, 32.52528778968319, 39.81404981305523, 43.7348981057444, 70.36120199388074, 27.073295231788393, 0.04388509776383158, 0.021572921034549514, 1.7532531340276043, 7.269392378868596, 2.890519360380788, 12.39453677208193, 44.4673889683139, 61.640278677786554, 61.083698272705085, 59.88135845430436, 58.97468297712265, 58.43551397323609, 58.652283760809134, 59.5702438969766, 59.41474153149513, 61.41548764321112, 59.21158236842002, 62.10803701031593, 60.40321411625032, 59.151130799324285, 60.04549003416493, 55.26643891488352, 50.432156901205744, 45.98461666414815, 44.959061991783884, 47.490120395537346, 46.17858571390952, 53.85322463127875, 56.10644194387621, 58.62210896707351, 56.163826219497196, 56.91053567394134, 55.01228893956831, 55.922545540717344, 54.98748387059858, 59.36153065773749, 52.62889208332185, 54.90340786595499, 57.27699487440048, 58.58094369211505, 54.72817597850677, 48.18325419579783, 42.763738862929806, 42.724103312338556, 42.60337668080484, 44.155274206592196, 40.67244091341573, 41.58392913879887, 42.85490651284495, 54.82979674493113, 54.68682635215021, 50.0279684220591, 51.2325636033089, 55.094619489485225, 54.58404848652502, 56.69903755187989, 54.54607209851665, 56.31632012705649, 56.21823733852756, 58.762369002065356, 55.651360711743756, 57.25504921328638, 54.70137834548951, 59.69177461439564, 38.52018933142386, 38.45289322637743, 60.74488393722042, 51.06372125687138, 51.35700079702562, 44.843814911380896, 47.226458672554266, 46.085782435632524, 48.73321756239861, 44.4597952596603, 45.21845617601949, 42.66549917959398, 44.61552120024159, 40.42366458523659, 39.71531198870751, 38.58360228999969, 41.867947962976274, 41.78397001758699, 41.87031315219018, 41.95709559225267, 43.95002442021524, 41.91620880557645, 43.875840633146225, 42.280667597247714, 44.8619205720963, 47.96082442806613, 54.43807748056228, 55.82873421330606, 55.780151736351755, 56.16171206197431, 57.3110253580155, 57.555742033066295, 56.91901976062406, 53.83421290305353, 50.62630637999504, 54.89251936635664, 56.58734413885302, 55.18352785418111, 52.61685432926301, 45.04742514702582, 45.25740138946041, 43.565059477283114, 43.9551313461796, 44.925984644120746, 43.760456269787205, 46.77486442750501, 46.520698762709095, 45.496540454126176, 48.97836569816836, 51.67561884849302, 54.56129873952558, 56.09760484387798, 58.65158950128863, 62.57128853951732, 62.796487500590665, 63.12916332675565, 59.91844838665378, 61.38270055094073, 60.49349531050652, 68.22610685902258, 50.1307305982036, 0.643067135205192, 1.2517409675544309, 1.4804479984506485, 0.3735363819906789, 0.036525153179442695, 7.656924513078506, 62.53176673766106, 43.46672957943332, 38.57131742661999, 23.983173562634377, 18.83301131186947, 36.70761500635455, 57.69286809429046, 62.12159664400163, 53.705041408538825, 2.473131125011752, 0.235414850795942, 0.018924248645142205, 0.039096619227841016, 0.033755569132946195, 0.021327728848724116, 0.07305789062933576, 0.09415737698755919, 0.035490003684836055, 0.07366195095763092, 0.09805731610545228, 0.04427896271790228, 0.06855814297112726, 0.0891109949518596, 0.17341106499154724, 0.16211359701570005, 0.20564680378283226, 0.13385492707452468, 0.11766863836636467, 0.1784629398776639, 0.1780962748753448, 0.23319488120896203, 0.17609370571951713, 0.39680323833900116, 0.2740102531688829, 7.811000606706066, 69.89345150609171, 70.46444662155645, 68.18236458686091, 49.5853760165553, 36.394511807349424, 55.1855557195602, 56.01008107585292, 53.383622784768384, 75.37245350499308, 31.196553514849757, 0.22751256192643798, 0.12706034771737554, 2.5833281538178845, 16.031143646086417, 8.641893440677274, 16.58581287630143, 47.408095790493874, 63.57689795955535, 65.77801442915394, 61.543502038525, 62.64917504402899, 60.967031294299716, 60.590162123403246, 61.00727873463785, 62.44803590159263, 64.52801781315958, 63.11745897416146, 64.37888145446777, 63.77486782689249, 60.17746210098267, 61.78259795711887, 57.87195174924789, 53.020819233309844, 47.1613081039921, 46.91674440137802, 50.448752449404815, 48.633848236453154, 57.07706774434736, 59.40683011085757, 60.1921788338692, 56.14872509433378, 59.962469147097686, 57.49208980990995, 59.655865315468084, 59.68011733024352, 58.798803898596, 54.454488677363244, 55.54648437807637, 58.83802367794899, 60.9782688848434, 60.351466286566954, 52.41873148948916, 45.59541948380009, 44.74347283763271, 45.601958074877345, 45.465769460124356, 42.21047286064395, 43.65169286727906, 45.294099084792606, 56.600668430328376, 56.524174367227864, 50.35762794556157, 53.03687349442513, 58.51648738307338, 55.134631587613015, 58.28846039310579, 57.60430097579957, 57.87323044192407, 58.50563810717676, 60.97059280641618, 58.3486177844386, 58.87947136355985, 56.9081469505064, 61.78737148161858, 40.96892895237092, 41.71766234982399, 63.20686547986923, 53.41180109208631, 55.30710997120027, 48.82811146397745, 50.13148761564686, 49.12503488602177, 50.598936080932624, 47.41776051059846, 46.78493315173734, 45.279876570547785, 47.19076510398619, 42.30426065383419, 41.08869068084225, 40.68680463298675, 44.56809582248811, 44.19584328128446, 44.08296923483572, 44.984110247704294, 46.24253211482879, 45.21962504233084, 45.74883514834989, 44.38252064489549, 47.04260933783747, 50.94653652560327, 56.133329791407434, 57.961385711546875, 57.47303493561284, 58.64166982712285, 59.47158059766216, 58.717265667453894, 60.43082760226343, 54.90749105330437, 51.619097494309955, 56.18740750897316, 58.80113770884853, 60.09221330765755, 56.89991389551471, 47.68548580908006, 48.013427334447066, 46.86092515145579, 47.35532814456571, 46.715915126185266, 46.475646418909875, 47.8343201452686, 48.99043483118857, 47.81276279880155, 51.89942536815521, 55.124739370038434, 56.051152213927246, 59.35329368037563, 62.10542863415134, 64.39360995446482, 65.72213242130896, 66.95863216154038, 63.07664279014834, 65.16884288480206, 64.04174589341687, 72.92525537552373, 52.68385625654652, 1.8537117757143515, 11.324600481217908, 4.328380102111447, 0.6569746340955458, 0.10826986568469195, 9.910303623445573, 69.71441884194651, 53.672564183512044, 53.27380818705405, 29.621898397322628, 26.75350831400964, 43.13579920799502, 66.33371230094664, 70.00541948503064, 64.64026035801058, 3.6510794393477903, 0.35760233539246744, 0.324819288066318, 0.21859085517785243, 0.14898556194478466, 0.10632951052919512, 0.1895806683047164, 0.2063381981344954, 0.14178729255593595, 0.188672884757961, 0.18660688352200294, 0.09045416924862132, 0.17636883853664323], [0.04599584236500725, 0.014253860647459666, 0.04766934611383946, 0.07603620299168172, 0.05126439372918779, 0.0621053958762317, 0.05962696354535799, 0.04762805780516036, 0.04056792939081788, 0.04520870234456755, 0.07190913412599795, 0.1188276527870086, 6.867334237021785, 56.19198491496425, 52.830058682349424, 62.18548420936831, 40.21191935385428, 30.732868563744333, 28.32289568839535, 33.853467049137244, 43.060630906012754, 62.590355180924945, 16.849333393958307, 0.14711048514131578, 0.09501067636113975, 1.1489134594317407, 4.076565653085709, 6.470003041528887, 24.688433370282574, 53.906376669483805, 64.32363487059071, 60.57070716734856, 57.05768731332595, 54.376002050215206, 52.832215985944195, 50.43064286631923, 48.190765534677816, 49.36272267372378, 50.672123585977864, 52.10665202909901, 54.01888593550652, 56.08552002137708, 56.74117165227091, 52.92922404504592, 46.65351021674372, 41.71190038804085, 41.17146838095881, 41.84622587696199, 42.71060643657562, 47.499228139077466, 53.62562517965994, 53.49922287848688, 55.733420618118785, 54.09839237889936, 54.78620744520619, 53.42817698755572, 53.178922130215554, 50.3592674962936, 53.08992747337588, 50.70409874762259, 53.44207394507624, 50.45308274607505, 50.98242621267996, 52.39526002637802, 46.73491508729997, 40.792018290488954, 41.462924018982925, 41.4286817273786, 41.87735380664949, 39.8448561083886, 39.837929202664284, 40.57282840051959, 52.411451570449344, 54.44141933994909, 50.68106658997075, 50.10783572350779, 52.399413816390506, 53.15701961517335, 55.110254056992076, 52.50609051796698, 54.430934844478486, 53.91655129771079, 56.49356811277328, 53.3045752586857, 56.365196781773726, 49.14540375432661, 52.516531867365686, 38.85484987689603, 34.22905752735753, 57.99026220075546, 50.372109336237756, 49.67826166460591, 47.02832798804007, 51.015491793232584, 47.997220100895056, 50.431513632497484, 47.12818368788689, 46.50859040598716, 44.15059089660645, 41.875828004652455, 39.24061498334331, 39.105014724116174, 39.715892499493016, 37.18343380958804, 39.30828371355611, 40.24796985810803, 40.02859953911074, 42.0025440954393, 40.93173311602685, 41.676685348633804, 40.416890651949, 44.96529071561752, 50.34928114183488, 54.116803984488214, 53.884038771352465, 54.58545661741688, 53.49112710645122, 52.74979914388349, 53.81952362675821, 55.066170538625414, 54.15055990219117, 54.21201952042119, 53.995838088373986, 54.85744945464596, 50.76156931538736, 41.54526241364018, 42.08508645334552, 43.989420706225985, 44.741629323651715, 47.1922516822815, 45.338814104757006, 44.26883466782109, 41.49083560512912, 46.53880050105434, 51.005152425458355, 56.3381677289163, 55.7506319784349, 58.87838486702212, 59.06501516219109, 59.450140922300285, 57.67475458883471, 59.922519806892645, 58.97230602079823, 62.02406690966699, 61.70017327031782, 65.4241499593181, 64.3488831673899, 56.4172270221095, 2.913066124723804, 2.7926675013957487, 1.1367691885079108, 0.10072265090721269, 0.025581305643783945, 1.717681404083006, 53.94310966614754, 45.48704831830917, 45.20263725711454, 31.79141821399812, 18.93596176178225, 29.753123252622544, 43.41218902218727, 55.90309058466266, 49.185415852454405, 4.561409094641286, 0.32534218903991485, 0.061771519437071785, 0.11331558888477665, 0.01920208192220138, 0.06212886497979203, 0.11294369916281394, 0.05611131328248209, 0.07315045703322658, 0.0320741746784939, 0.027485756173489556, 0.036117598234165105, 0.015354545133548881, 0.029060243058108517, 0.030460971625401612, 0.09202752998399158, 0.059052018388625116, 0.009775935961384206, 0.014627712512118442, 0.011970524097822849, 0.05401872879555149, 0.0690249969521838, 0.06940734377431293, 0.020713071609216354, 0.1335560302099874, 11.583658322211235, 66.98314697511735, 59.757144835687455, 66.9959339018791, 46.31115790336363, 37.4168344466917, 33.101121148755475, 39.3333633484379, 47.220881062169234, 67.25367284590199, 18.190203482104888, 0.2809217145606395, 0.1475752093979428, 3.3904982478387895, 2.308857604380577, 6.157418085682777, 26.73606357266826, 54.56122421449231, 64.28998485688241, 62.865427078739295, 60.34016593810051, 55.4518924990008, 54.07500328556184, 51.90116297814154, 50.91640880030971, 49.428394917518865, 53.08899787164504, 54.13492533468432, 56.24248150856265, 58.79670935292398, 58.16365057422269, 56.16263381896481, 49.21184478267547, 43.78539077697262, 42.69314796693864, 43.641008330929665, 45.66786566088277, 50.41438464195498, 55.08767689428022, 56.17067075544789, 56.63419685056133, 54.469425062979425, 56.91707818738876, 53.98427101873583, 55.1103913399481, 52.87701337568222, 53.729112994286325, 51.64898203265283, 55.684324310671904, 52.5077889042516, 54.27521282626737, 53.9877893847804, 48.18182253068494, 43.44569390819919, 43.30436698852047, 42.083792071188654, 44.345430712546076, 40.95568310829901, 40.44528468962639, 43.44628618609521, 54.33467595807968, 56.21739795131069, 51.10404714461296, 50.81812989327216, 53.60722926355178, 54.47688933341734, 56.64174741314304, 54.791686996336914, 55.76778842556862, 54.29038847646406, 56.695680003012384, 54.46196079254151, 56.752515146809245, 51.340624901556204, 53.041964730908795, 38.853688855325025, 37.345627738583474, 61.074876862187544, 52.7293400610647, 52.29115639963458, 48.48648478907924, 51.833647220365464, 50.365229498955514, 52.31573789350448, 50.74229871073077, 49.08205355367353, 45.199828840071156, 43.86730947802144, 41.489454930828465, 42.074252866929584, 41.60928726196289, 38.94013004918253, 42.3760361056174, 41.221937517966, 41.345241146702925, 43.0837611229189, 42.46277147723783, 43.53115058714344, 41.61297821229504, 46.392688289765395, 52.925917486990656, 55.55294452175018, 55.25347548146402, 57.6426068429024, 56.22109674638318, 55.9399373300614, 53.82468546590498, 57.07371804022021, 55.60095433265933, 57.71698282610986, 56.34041132465486, 56.389480175510535, 52.792227422037435, 43.822280668443256, 44.06907227731521, 46.82450202203567, 47.067630137166674, 48.73959533629879, 48.1857802021888, 46.7952960537326, 43.78371592490904, 46.63347082753336, 52.22717469738376, 57.52759902707992, 57.614969822668264, 60.148809186873905, 62.50028579465805, 62.72277047557216, 61.00372506726173, 61.21721575337072, 62.37749991878387, 64.26971012546171, 63.53285366489042, 67.06359478735155, 66.23920671401486, 59.627694852890514, 3.665835886232315, 1.3189419551241783, 5.486100998616988, 0.41539980819629085, 0.06578383216213796, 1.6574010709601066, 58.67318999382758, 52.5229057188957, 43.889906252584154, 23.63344523214525, 21.49743422385185, 33.764539072590495, 49.77580316605107, 61.29159173657818, 58.67249181193691, 8.220518116028078, 0.4372828033181929, 0.0799436038059573, 0.11023080562271419, 0.07826812355028046, 0.06786703973287536, 0.03248337288236907, 0.08466532544022606, 0.006929945178149689, 0.05747747021697222, 0.03697952375777307, 0.02214240206916246, 0.03792286144509431, 0.08027885154250168, 0.08534258546968622, 0.17624998765607036, 0.1780226844693384, 0.14286888613095208, 0.26456711633551505, 0.11989032399029502, 0.1183527855262641, 0.19419185877326997, 0.09377571198368266, 0.158608622188049, 0.2660214270074522, 15.582796142947291, 77.81682752793836, 67.21331165682885, 76.95603201466223, 52.44603118588848, 44.85612330898162, 40.58388556203535, 45.55922777422013, 54.17514139606107, 73.56389568698022, 20.630362918300015, 0.4477717727422715, 0.29293866167145394, 6.605798928968369, 10.084581394349376, 10.775729494710124, 27.64379416742633, 55.8902487447185, 67.53355749191778, 64.34557268696447, 61.28020509596794, 59.0594453965464, 57.285733915144405, 55.295260490909705, 53.27889550116755, 52.32268833344983, 55.223559564159764, 56.544100007703236, 59.235885374007694, 61.27562376760668, 62.27720099110758, 57.18776095298029, 51.26886121688351, 46.17904070884951, 46.713189078915505, 46.026323226190385, 47.123947528100786, 52.33793458630962, 57.89694116961572, 58.61255015096357, 58.57029053472704, 57.85947468972976, 59.14661222888578, 56.984652780717425, 56.74351330726378, 52.94235221801266, 55.145061169901204, 52.14942155345794, 57.88680968746063, 56.33345303996917, 55.97861974470077, 56.2915111357166, 50.24432636076405, 46.332091592973285, 45.08553489562004, 45.08937489601874, 46.3854750510185, 43.4588260035361, 42.81076415892571, 45.32474848531908, 56.979910635179095, 59.102136473501886, 54.456626369107155, 52.49361345844885, 56.431057299337084, 55.20628936829106, 57.709906870319, 55.92598938172864, 57.56132748819167, 57.80493805485388, 59.05608392530873, 57.18445439492503, 56.71674313083772, 53.90680813020276, 52.64091022552983, 41.18456517496417, 38.70358759357084, 62.10598953308598, 56.9290727953757, 54.925894814152876, 52.685633090234575, 55.610764180460286, 53.12975522010557, 53.91955975563296, 51.89302013766382, 50.93960569750879, 50.054001192892756, 47.25676290450558, 45.56993584479056, 43.9131070721534, 46.33812812066848, 41.14427458855414, 45.398406674785, 43.70024396527199, 43.88969836696502, 45.47385738741967, 44.3851407881706, 45.56185576223558, 43.56173722974716, 48.799776261852635, 56.89345767421108, 58.061704251074026, 57.74711839614376, 58.761035396206765, 57.23336242860364, 56.37602644581949, 56.26024984544324, 59.21481832381218, 58.379420157401796, 58.23804224691084, 59.621634790974284, 59.63246445502005, 55.54762971016669, 45.30757634870468, 47.78445113089777, 48.243093875146684, 49.29595216628044, 51.39249432471491, 51.36727740687709, 48.80757001138503, 45.72108045701058, 49.57800196063135, 54.66319407186201, 60.97662933411137, 59.13642975591845, 64.20963118153234, 65.10242146830406, 62.79154923654372, 63.03586190746677, 62.74694404294414, 65.11827568854055, 68.21335131122221, 66.49332138799852, 69.43826829233478, 68.67884251379198, 62.01713608157251, 3.5762766532359587, 6.523808644663903, 6.125366928115969, 0.4019042194610642, 0.11501931480222172, 2.3548513170211547, 64.99936511439662, 59.04096318829445, 60.28796703584733, 39.79965471452282, 29.05521788904744, 41.764613120786606, 60.15135088274556, 68.83414483839466, 69.53715908911921, 10.470305315909847, 0.7283683902313633, 0.23922610757572038, 0.2514753631886936, 0.16265057868534522, 0.12485901704959332, 0.19370850325832445, 0.184932031458424, 0.15264150205879443, 0.19176709856237137, 0.1593443270652525, 0.1229308503529718, 0.1033547681365763], [0.06541900577083712, 0.011017948347744683, 0.055390600745956746, 0.02956607942319205, 0.07881478091040928, 0.08910495051813704, 0.04119893303140998, 0.05560774836809405, 0.01522421346782076, 0.06630029799717088, 0.008358701072152584, 0.062125279688306397, 21.806760180381037, 60.20383611802132, 58.154644812307055, 42.11173895866641, 22.402083796839563, 17.896459141085227, 29.8699765436111, 34.05817554843041, 45.848326067770685, 61.50500789765389, 7.657688884965836, 0.03306663775395963, 0.1972380848301034, 1.267896842571997, 4.037121808336628, 9.171486958380669, 34.08440836014287, 59.971988739505896, 67.46311172362297, 57.098931035687855, 59.14999331197431, 54.4224036893537, 51.09435496791717, 49.621940351301625, 48.73025617291851, 43.29099562860305, 42.21267723268078, 43.32834443738384, 43.182412655122825, 42.637156132728826, 43.769160009199574, 42.07501380674301, 41.65093498845255, 40.98649332600255, 42.379668220396965, 41.280580874412294, 43.73752217138968, 48.77253147863573, 51.54781626116846, 53.786305073768865, 53.595615125471554, 53.04986046206567, 54.72678745946577, 50.60728288465931, 50.90648520377375, 49.62199526448404, 53.549460595653905, 52.70037727971231, 53.898869252973995, 53.617046956093084, 52.949596835720925, 52.277169227600105, 45.370228367467085, 38.13017629807995, 41.85418828841179, 40.69484156946982, 41.5278039440032, 38.55002680132466, 40.856658950928725, 41.99411884430916, 46.19327106783467, 51.83734601543796, 54.8230581129751, 51.03190299003355, 56.221449759698686, 52.659333598229196, 50.72818602285078, 50.38930500707319, 48.95675736088907, 50.82036564427038, 55.357410446290054, 52.23525085756856, 56.201735927212624, 49.63975967899446, 56.13255708448349, 42.25113607222035, 37.143060853404386, 58.55877837827129, 49.409732280238984, 51.13086831185126, 50.119002711388376, 52.31263922106836, 51.353855056147424, 51.01676656353859, 49.51625993174892, 49.33689386613908, 46.09286231379355, 43.34075481660905, 40.98330836142264, 39.07688348524032, 39.85988270851874, 39.54857203268236, 39.30267864657987, 39.277673536731356, 41.10706306272938, 42.8173537408152, 42.09604555560697, 39.80976658482706, 38.6159186978494, 42.190794329489435, 51.83377665858115, 50.979962964211744, 52.7606797987415, 53.32304962219731, 53.3506513410999, 50.628495062551195, 53.03297858084402, 52.97113849270729, 55.483330295931914, 52.8069245430731, 50.429281803869436, 48.27071520590013, 41.604443134800086, 41.48061783083024, 44.96747155343333, 48.9095869371968, 52.12082747490176, 50.242388709898925, 48.275986871411725, 45.272141656567975, 45.19320003447994, 51.17449683527793, 54.789663053328, 57.51150161989274, 56.974870389507664, 58.87815736955213, 58.54934900037704, 54.04282808303834, 56.74341524800947, 58.23164093878962, 58.61747272552983, 59.9839323566806, 63.90920116055397, 59.97516978171564, 66.54089973818871, 66.58415563644903, 9.284493384822722, 0.3205580925268512, 1.880475946011082, 0.3654001605126166, 0.0849273811364847, 0.5526649603439916, 38.22872977102957, 53.90237977427822, 44.39561743890086, 50.65248035615491, 26.349366903305057, 36.231862883413996, 45.38897729689076, 51.39029387504824, 54.523071319826194, 14.580868847908514, 0.6147727502449867, 0.1591678050857398, 0.07301431554820269, 0.03826300065303522, 0.039281054895611546, 0.0808679425127564, 0.004606950650697634, 0.04828503182638557, 0.030080176131319136, 0.06230814104539253, 0.011438650319412833, 0.01055821515394435, 0.040318640549817396, 0.01464760494268229, 0.03913518792438892, 0.057870048143330126, 0.08117226327979758, 0.05788028690843813, 0.042740543252758445, 0.05045208005955623, 0.006699324942254011, 0.037298584056477395, 0.08150441602112786, 0.023397993363980806, 27.942906272026804, 68.57668046028384, 62.868827773678696, 48.065688994623, 29.501462021181663, 24.95558600271902, 36.0690099962296, 40.663815621406805, 52.52949922315536, 65.29422536973031, 8.110289217964295, 0.2460948519048191, 0.6038593681108567, 3.636695862777772, 0.7578733166859997, 9.005510883946574, 35.36057502992692, 61.28800669024068, 66.12418713108187, 60.850576123883656, 58.247726578866285, 55.89826606935071, 53.90994994871078, 52.49718281530565, 50.16575344147221, 45.26810161529049, 45.85956758068454, 46.376414375920454, 45.62254267354166, 44.742876637366514, 45.624225370345584, 43.01608847033593, 44.549527322092366, 44.843779610049346, 43.81991940159952, 43.77358444275395, 46.5668023017145, 50.366206169128425, 54.44442387550108, 57.556153881934385, 56.237762897245354, 55.67703654689174, 54.458850352994865, 50.954483247572384, 49.9866384075534, 51.003065724526685, 54.77595044720558, 53.6626523540866, 53.13646247310024, 54.88955013213619, 57.73790082623882, 53.714121695487734, 46.5538663248862, 39.890088881215746, 44.35156922186575, 43.003419214679354, 44.05108036533479, 41.47984904627646, 42.842719708719564, 43.38194754815871, 49.821145765243045, 52.71250132591494, 56.252165840518096, 53.09856453249532, 57.38430307757471, 54.70218243137483, 51.69743899376162, 50.57818674272107, 51.004116919732866, 51.70040430561189, 56.06027564694805, 53.995426239505896, 56.783074332821755, 50.57527242168304, 55.78707471970589, 43.19754908161779, 38.87855668221751, 60.48123005897769, 52.60315349025112, 53.53268069605674, 53.5729673600966, 53.408651428837935, 51.574900227208296, 52.527624330212994, 51.62547919058031, 51.27789443539035, 48.48713590252785, 46.51132429799726, 43.42533680700487, 43.21169707082933, 41.69489299097369, 40.4568596040049, 41.39421193830429, 42.743875980377204, 43.43601349861392, 46.39266475554436, 42.32539046195246, 42.249735786068825, 42.334702168741536, 45.21745204925538, 54.72239440487277, 53.72593587444675, 54.70004081726075, 54.243402404169885, 54.12354653881442, 50.94051960975894, 52.482591598264634, 56.39509700959729, 55.02549948230867, 54.18944235770933, 52.80189998688237, 50.28165555769398, 43.42089668396981, 44.176635434550626, 45.25706406562559, 50.29668215782412, 52.74247215640161, 52.86268887981292, 48.89060266556279, 47.46256574507683, 47.883428219825994, 51.506866716569476, 56.954564279125584, 59.27452856494535, 60.165032109906605, 60.71794902124713, 58.982476726655044, 54.672705819529874, 56.567351818084724, 58.578904059625444, 59.260506091579316, 62.755267312449796, 63.94728345255699, 62.929432315211145, 66.45815341703354, 67.51683250550302, 11.006862021261647, 1.2797585802693523, 1.210166172635171, 1.407180329965007, 0.08828456228178355, 0.544064918593053, 44.107766459065104, 59.36234651073333, 47.004409374729285, 43.604887224012806, 30.845244469181186, 41.04119862279585, 55.18956045950613, 58.617319753093106, 63.390000943214666, 20.033854746049453, 0.5991041684342969, 0.05922291728277361, 0.05632194149638376, 0.09264274455246427, 0.04248945793557552, 0.05360430970247235, 0.049618289114967476, 0.07180270153067767, 0.03319253664343588, 0.00821167060489496, 0.0187207737772335, 0.03639968712964366, 0.13373388518248835, 0.15868480197123944, 0.15044947935929223, 0.1221507276979185, 0.3143995729905944, 0.1281538079943388, 0.11211227159947158, 0.11046817030517325, 0.12188471132709135, 0.14908521466197508, 0.15360327948245311, 0.12425834282992348, 33.53505688328897, 78.18201588046166, 70.56824822579661, 55.95749385895268, 33.374051432455744, 27.33373276648983, 41.396785013137325, 49.09182810014295, 58.16665510977469, 74.96386020414292, 9.256146415587395, 0.31858428231170105, 0.2990757001023139, 3.42774115262493, 9.466166784686427, 11.067444989758155, 37.46611510553668, 62.12026696051321, 71.0437257828251, 62.573202656161406, 62.305869594697036, 58.64198361673663, 57.08612841944541, 53.8451131697624, 53.10406761784708, 47.87008823886995, 48.19635883454354, 48.03227040075487, 48.840992527623335, 46.88009769685807, 46.83467665026265, 45.51044917875721, 46.8492207988616, 47.298398863884714, 44.651701142711026, 45.81535854647237, 47.48480166158369, 53.70450404382522, 57.3356774545485, 59.75082197496968, 57.716496452208496, 57.977949880784564, 55.71583271026612, 52.278149820143184, 50.27538761015862, 51.7448212254432, 57.88990443752658, 56.33014255954374, 57.319968362008375, 57.68611377285373, 57.361596476647165, 56.99081090188796, 50.604568604500066, 42.807791002335094, 46.97844328418855, 45.207426471094934, 45.046860325721006, 42.482073460855794, 45.4354848400239, 45.909817064962084, 50.50114747016661, 55.10668470013527, 57.30121551021453, 54.43196642783381, 59.74092583502493, 56.25297384877359, 54.92432586608395, 51.70913942398564, 50.06310109169253, 52.830717640538374, 58.73602636398808, 55.32549019782774, 58.771837603661325, 52.32300996780396, 57.981083854552246, 45.403694029777284, 43.33913487772788, 63.46273345331993, 54.48511062129852, 54.85999507288779, 56.5818214416504, 56.7770613393476, 55.16455927202779, 56.2191669402584, 53.764696736489576, 52.95647667300317, 51.223295042591715, 48.28225089657692, 45.850950133415964, 45.34972221620622, 45.17962078894339, 43.06789905794206, 44.25323147927561, 44.81444028116042, 45.46471434254801, 47.04151107418922, 46.18855637888755, 44.67937738664689, 42.01877486321234, 47.174204857118674, 56.08281750832835, 55.40645184055452, 57.57691106488628, 57.53236078446912, 57.85939624232631, 53.95917569437335, 58.618547454957046, 57.56066853000272, 59.89426697454145, 56.56284501475673, 55.605202259555945, 53.57573263106808, 46.26812950257332, 45.597502262361594, 49.37577239928707, 53.8846859624309, 57.998652150554044, 55.39841882644161, 53.76383773742184, 50.6343315493676, 50.655488814077074, 56.10160173908357, 58.52385751662716, 62.07843096025529, 61.720177358196636, 62.733443244811035, 61.33436126093711, 55.2852859035615, 59.03135338137227, 60.07937146771339, 59.691480436632716, 65.05583155539729, 70.06314892922678, 66.70457240073912, 68.37802025579637, 71.42011642456055, 12.7359281047698, 2.6034401068764352, 8.507637573826699, 1.879644403534551, 0.14772795200828584, 1.3546376074514082, 49.72283155687394, 65.88286722860029, 61.149060649256555, 64.6779033445543, 37.407452137239524, 47.84984096404045, 62.244849281926314, 67.26935448185091, 73.60905001240393, 26.102216397562337, 0.7621659831173959, 0.1650202265309711, 0.1239757100120187, 0.20632086922564816, 0.11416849755351582, 0.17709705107394727, 0.1378012604771122, 0.20794252414376507, 0.13812468747698492, 0.1796711984300806, 0.1266649544178959, 0.15241193615140455], [0.028860497123171246, 0.06265800956997179, 0.06037591791321194, 0.0052678518301446835, 0.002145942989661689, 0.005016060754461515, 0.03146603876244157, 0.06425495432209104, 0.0521637503087761, 0.0399897245299672, 0.009422990636179044, 0.22488501824198232, 30.06774440888436, 62.006984987566554, 50.818345623631636, 35.23522784633022, 17.854770229708766, 27.114405593564435, 45.467373709524836, 35.86609009773501, 54.00698938677388, 48.47397242822955, 2.4429367194252634, 0.4235842012830319, 0.7503321310204845, 4.16259769470461, 1.2632522659917034, 19.139303315070368, 45.43610065214096, 61.69840428137011, 58.1412773747598, 61.30821474136845, 55.934202824869466, 55.16654399133498, 53.81251827363045, 51.59257834957492, 48.23964611176522, 48.07545569635207, 43.19349335085961, 42.57029148840135, 43.425799646685206, 41.947815264424975, 41.232582830613666, 43.4973083772967, 44.45318214354977, 44.073963472920084, 42.80371565972605, 42.01329923445179, 46.138871715914824, 44.78964305693104, 47.53445886796521, 51.672935947295166, 53.86768641010408, 56.36042717964419, 54.3357781440981, 50.618406726467995, 50.49286734673285, 55.09602369800691, 53.186319720360544, 54.46410632902577, 53.52050958141204, 53.955527890113096, 52.265739440917976, 46.51445434939477, 42.77295251046458, 44.5625142897329, 41.499531499801144, 40.348876753161036, 42.142890422574936, 39.582198512169626, 39.29428477441111, 39.099715602013376, 45.2042571959957, 50.41328245593656, 50.12660426478232, 55.23951576602075, 56.1131021284288, 50.79003395572786, 56.3182185542199, 53.172285479883996, 55.47918827302995, 52.70740224469093, 55.59694567034322, 53.647900319868526, 56.918996226403024, 54.847341506711906, 57.33665020235124, 47.24746688719719, 34.81678939634754, 57.7210581687189, 54.54336566309775, 55.6788839832429, 51.64096863039079, 55.44032542936264, 50.60361546854819, 53.243366672146706, 51.63144119324223, 51.08095222903837, 47.1398566615197, 44.83760579939812, 40.652421136056226, 39.02402954716837, 40.09401682884463, 37.82490999467912, 40.270295989128854, 40.722113809277936, 40.603681764295025, 41.381075920597205, 40.06305363870437, 41.416216434970984, 39.14369321638538, 40.74143540474677, 48.03317646826468, 56.39620704035605, 51.449960970109515, 52.71615697491554, 52.243032839990434, 48.667400190907145, 55.49667419925813, 53.37646445920391, 51.75362302410988, 50.296999869808076, 45.34615285934941, 41.741741780311834, 40.648537989585634, 41.86433938241775, 48.07354157970798, 54.51514028733777, 55.96751551474295, 53.22451183872839, 48.95159159937213, 47.860854979484316, 46.79622565546344, 51.624000457025346, 56.30005798032207, 58.23101335956205, 53.482172335347826, 52.9102554628926, 55.05425045567175, 56.85241399272796, 57.60574833039315, 59.14318407735517, 57.5577816655559, 59.766236889746885, 55.52425238393969, 59.85745160810409, 61.57736778259278, 54.63408224044308, 16.777661884984663, 1.0057268459950726, 4.200401988721663, 0.8346135698018536, 0.10985117075183701, 0.07265260713475366, 26.17225031698904, 62.78307299460135, 40.042433738708496, 34.54010932676254, 18.411534986188336, 24.895307017910866, 44.47741062410417, 52.444842707726266, 59.0944133266326, 22.17486285394238, 0.332452159134611, 0.042322174976429636, 0.015605836336861457, 0.0031729709946610517, 0.08138360395546883, 0.13191081042731964, 0.027374970283539548, 0.015411179140961219, 0.02465882278498142, 0.06881113584724165, 0.08186040175778252, 0.03853894169292143, 0.014897947154578664, 0.07836050609306944, 0.027251199203272982, 0.05108075862329814, 0.03401852115207622, 0.09053194249469428, 0.02965657547446749, 0.10018529385448464, 0.0179094732588818, 0.046699413684226816, 0.040252236048540765, 0.3563622229041592, 36.90662037941718, 67.68102292091616, 58.470717245532626, 42.02257956227949, 22.507191550347116, 25.671612716490223, 46.05344641593195, 38.918674684339955, 60.66567559396068, 52.472730759651434, 2.5156459404576212, 0.277168067592767, 1.4433564726383457, 3.928449110638711, 1.843877658247948, 21.295345867833785, 44.593418644320586, 64.0567175803646, 60.377722632500436, 63.274420461347034, 58.84561346423242, 56.41301439654443, 56.38032144115817, 54.0704611809023, 50.59491172913582, 50.06057900767173, 44.34943937486218, 44.807623201800936, 43.853090886146795, 44.65719246095227, 42.558998984675256, 45.66272343358686, 45.8829370621712, 46.31809657619846, 44.11739980020831, 42.510895036881976, 45.54362066330449, 47.98385658571797, 50.43312572663831, 53.10754676018992, 55.85074263234293, 57.693130893092004, 55.14695567469443, 50.23152374452161, 51.489223895534394, 57.83144151010821, 54.56911210090884, 56.00466820501513, 56.61573033179007, 57.07518500666465, 54.05845872817501, 49.64071281494633, 44.110990647346746, 43.568479784073375, 42.469898423840924, 42.41562458776659, 43.140843376036614, 41.626016170747825, 41.638657969813195, 41.25281833833264, 46.679990137777025, 52.50284671783448, 52.723213318855535, 55.1455867675043, 58.53747206349527, 53.45014226052069, 58.22327060084189, 56.268569192578724, 57.0980877261008, 55.35577874029837, 57.34029408424132, 55.393370736029844, 60.12365110458867, 54.20970924438969, 57.60989819803546, 47.2547624957177, 37.95542686216293, 58.41811826152187, 54.48491058041973, 59.14212111503848, 52.490130393735825, 56.20463455876997, 52.57282964644894, 53.795201009319676, 54.36366619602327, 52.064678745885054, 49.65020102839316, 46.36762042199412, 42.40555586353425, 42.829826877963164, 42.209978642002234, 39.209412528622536, 42.15541455053514, 43.47334661791402, 43.9181943862669, 44.73009755534511, 43.0246784610133, 43.3209115459073, 41.4874662891511, 43.1650875460717, 50.04647024216191, 57.42050655426518, 54.119439817244015, 55.23223584698093, 53.916821941252685, 52.50112479732883, 57.52064858713458, 55.768188507326194, 55.12725753168906, 52.973891996568256, 46.36549449736073, 44.54893112182618, 43.59602266742338, 42.76625702458043, 51.14241969200873, 56.17956276862852, 56.777594781691036, 54.494508620231386, 52.017323970794685, 48.76577323482883, 48.440361638222974, 55.52380131136987, 59.17249594965289, 59.613915566475164, 55.480302226158884, 50.8621310418652, 56.34955044715636, 59.451266642539736, 58.24745985769457, 60.9822500905683, 59.47778578727477, 60.23528175969278, 57.63560148977465, 62.571225781594556, 58.880804969418435, 57.394344345215835, 16.856593701147265, 2.050482623519436, 6.381177046606618, 3.6094503441164574, 0.11176102794706823, 0.047208617005737565, 28.70516400183401, 68.25080994636782, 43.58294940763905, 37.90855061623358, 24.118554169131865, 31.777111368794596, 49.9949263757275, 58.29185324330484, 68.11648445744669, 30.228512556322162, 0.5875702550814998, 0.030976435800473538, 0.06360571012802183, 0.11088995533364435, 0.022616878625065572, 0.05901928728206023, 0.041199059435917486, 0.0516279062796985, 0.06431695764824268, 0.02637060603217012, 0.06717992015182972, 0.025849039966781295, 0.09505375348512204, 0.17330485456172498, 0.22704484992690627, 0.25232518452309793, 0.07389474975606126, 0.223396371509279, 0.18738748115156928, 0.31587990000844, 0.1359935840892215, 0.13680698560370555, 0.17460329698458796, 0.6299105863417349, 44.94163097873811, 74.46488764978226, 67.42909692948865, 48.09139620873236, 28.098753806083437, 36.47176681026336, 56.03913014934909, 49.343475603288226, 67.6154879600771, 58.29164928005588, 3.047797824105909, 0.6931322680846338, 1.9949372040648616, 11.822148234613481, 4.133265720259759, 22.739962647038123, 47.08203700280959, 64.91922716940603, 63.935488885448834, 67.2658400381765, 61.60742882759341, 58.20284681935465, 60.29863588271603, 57.737037904800914, 53.57190047540973, 52.62719761940741, 46.93178276861868, 47.91606233965966, 46.94462853093302, 46.10393124241983, 45.20903856523576, 49.165462755387836, 48.8987611955212, 48.89796495437623, 46.69469510355304, 44.697734079053326, 48.84056106690438, 49.78007854953889, 51.00085743011967, 55.36717714801912, 58.06010392404372, 60.27111653358706, 57.09481646937709, 51.38460251592821, 52.293498054627456, 60.38988590240479, 56.37070771186583, 56.86293378953011, 59.483535981947384, 59.10671387949298, 57.35395569955149, 50.839240089539565, 47.42291842737506, 47.78452565593105, 46.71560133657148, 43.89694298467329, 46.085013651078754, 42.23631343533916, 42.6799335018281, 44.74734421699278, 48.529803445262296, 53.086589536359234, 54.81747265784971, 57.74853437177597, 58.89525105876308, 55.81628068800896, 61.70015758083713, 57.68334850188225, 59.64937771520307, 58.429038140081595, 60.47712725977744, 59.01878218497, 62.52875043499855, 58.02415147904427, 60.45663287562709, 50.944822449837964, 40.36249914476949, 60.48195961982974, 58.02721877251902, 60.542026796648585, 56.28831832639633, 58.7179873835656, 52.12922526944069, 56.0407304763794, 55.99236765215474, 54.88855385011243, 51.60256470403364, 49.094079540621856, 45.0108451227988, 44.300417592448575, 44.560333451917096, 41.86842256976713, 45.07047691652852, 44.75245506532731, 45.24314749625422, 45.11403483729209, 45.42101129408806, 46.6804333656065, 44.51006043341852, 44.67545501647457, 52.85942939019973, 62.45393122396162, 57.27639082939395, 58.583214744444824, 56.77938338248961, 54.178130242132376, 59.395682734827844, 58.77248871710993, 56.918639290717344, 55.4015802568005, 48.16746665585426, 45.55397179818923, 46.227207414565555, 45.31124768718597, 52.71564706679314, 58.77664250712241, 60.726409573708814, 56.777206467043975, 53.732180287761075, 51.73599981492566, 53.01595941666634, 57.68028513077767, 60.55717891262424, 61.01855947125343, 56.093764843479285, 51.82031508414976, 58.998499608808956, 60.430372607323434, 61.693442483102125, 64.67487135241109, 62.733392253998794, 61.50543935837285, 58.97050565288913, 65.57388644064626, 62.21449013679259, 60.18936257208548, 20.992652639265984, 3.4750236090152495, 9.965071678161621, 5.0683053270463025, 0.3322617709636689, 0.19655456586230188, 32.716432732920495, 74.14398285650438, 53.581208259828635, 47.60182949804491, 27.17112110507104, 36.678118782658736, 60.348218564064275, 66.40999455605784, 76.67499419181578, 37.72961208897252, 0.7827572007813762, 0.14821709914793893, 0.15714704900258974, 0.19633920322502815, 0.24016857958368718, 0.26354791296105234, 0.15001846297133356, 0.16461351045197056, 0.1271661138162017, 0.190760244525248, 0.13463806811599963, 0.1370216587618474], [0.011841765785169218, 0.0915535590461185, 0.04062143680188925, 0.047531496252744436, 0.01744513396143673, 0.033108879842104456, 0.029392813317357536, 0.10168759227399865, 0.03532147966325283, 0.05700543748154756, 0.0576288951560855, 1.4781855263056294, 43.31640474257931, 55.32265824656333, 54.68751276693037, 41.55447606117495, 23.63912090178459, 40.83914556810933, 50.827833837078465, 38.069034391833895, 60.56583558359454, 38.89683884959067, 0.5621552575499781, 0.0547670511408679, 2.1881856408811386, 4.156577837082648, 3.6698617089179257, 36.836900249604255, 47.46310703216061, 49.128953333823915, 57.58964700083579, 60.36832463356757, 60.243389298838956, 58.55120428146855, 53.08121588922317, 50.41152131172919, 46.43609323809224, 45.85499801943379, 42.38790127538866, 43.246292375749164, 43.33490656268212, 41.68567542106875, 40.805954471711196, 42.2987340342614, 41.77748633969215, 40.105168127244525, 39.49566318142799, 41.360236367871686, 39.75934843863211, 42.205534596597, 43.374032205150975, 47.98264457333473, 52.61620321581441, 53.70957566845802, 55.08870455526537, 49.44350388742263, 51.54943620004962, 52.90626641242735, 51.25675286016157, 48.54450448866814, 48.359831456215154, 49.96790124524025, 45.13567063116258, 39.93643560717183, 40.774387236564394, 41.42898767225204, 39.006276899768466, 40.18381557156963, 41.147620370311124, 41.043857989772675, 39.472501585560465, 39.145732848874985, 44.69478837905392, 48.30928387180452, 51.574472688859515, 53.56365565330752, 52.09346502057968, 53.852534294128425, 53.49996028407928, 52.29398050615865, 52.51473934419694, 53.590319925738925, 51.43478139754265, 53.540721554909986, 55.287827599433164, 51.746660817054014, 55.75134977217644, 50.10672569274903, 33.51616282616892, 54.98177289962769, 50.27471296248898, 53.55726218992665, 53.80841939680038, 53.88454475710469, 51.60931902547037, 53.70800672038909, 50.86985418873449, 47.86407132302561, 43.66549176554526, 42.46318332610592, 41.2819262473814, 39.85593680412539, 38.553262756716826, 39.865079848997055, 40.22830309406404, 39.38396584603095, 39.63005927301223, 41.96053943326397, 40.82903762017527, 40.78210253869334, 39.87354040145874, 40.13417797703897, 42.6743519690729, 47.64047661135274, 51.65469300362372, 51.67849002345916, 50.9854385929723, 54.596717742181596, 53.67996961839738, 53.677286717199514, 51.950969234589614, 46.62177431967951, 42.602592206770375, 43.43916708423246, 39.43717671978859, 45.619377320812596, 54.21574577208489, 57.06343358562839, 55.31806907346172, 53.57012364172167, 49.56925899751725, 47.86919393847066, 51.490918359448834, 53.14723330159342, 57.6412614699333, 56.010849860406694, 53.844760156446895, 57.489493200855875, 58.55374989971038, 58.49104689013574, 57.03443942531463, 58.34561717125678, 59.4300897659794, 63.40450194574172, 53.803916515842566, 59.74221237244145, 48.667808117405066, 58.12272456384475, 19.00808238214062, 0.9872933609351036, 1.710044181635303, 2.3291431223192522, 0.22059320982906128, 0.05268661680841639, 11.721900297749428, 62.40424263861872, 47.647313302563084, 35.93596319998465, 16.587097452532863, 21.733123563951064, 32.91669522562335, 53.72950915367373, 60.44114343581661, 31.192640950602872, 1.1523000583533318, 0.04304998914801306, 0.07559818456009512, 0.05045194216372986, 0.037343124408395066, 0.07582016619703463, 0.015001600765953622, 0.019878916772863558, 0.02739374709856366, 0.03119582614500917, 0.028765630540287787, 0.0269863223882332, 0.07304963986239127, 0.07620595275394379, 0.03729733916360044, 0.0217729025415235, 0.030295366398809902, 0.03641064601740049, 0.06633412077902787, 0.009547487584753864, 0.04867482502313872, 0.023333532810812036, 0.027404711731979926, 2.112356419524839, 53.75174114781042, 61.64509927072833, 61.78122904992873, 48.03583583524151, 30.847599852469664, 39.18814935991841, 43.6387372785999, 40.881303202721384, 67.24128600089782, 43.13659937151017, 0.7389240399483712, 0.15709610415562508, 2.364757262891339, 2.8173024375592512, 4.408514615028135, 34.50001485886113, 50.650817271201845, 51.69379118950137, 58.80751548274871, 60.81937366916288, 61.388564494348344, 60.30051469802857, 54.73145507997083, 53.61597222666587, 48.33758377259778, 48.17454653401529, 45.45282171618554, 44.07040196080362, 45.39767711393295, 43.21657649932369, 44.97658321934362, 45.338512082253736, 44.952711674474905, 42.7062173043528, 42.92248502854378, 42.859421160913286, 43.82186881957516, 44.3697258733934, 45.64816359550723, 49.859906627285866, 53.10707215339907, 54.29497764956567, 56.26433303279262, 50.02337140421714, 53.982862887843964, 52.555057387198175, 52.64498949050904, 52.337538426922215, 51.359911195693485, 52.44013586351949, 48.73324894135999, 42.091601510201734, 42.049094784644346, 43.73991873956496, 41.64010532440678, 42.27310134518532, 42.45279296751946, 42.846744060516365, 41.61383721136278, 39.69876350895051, 45.32775302087107, 49.53936661443403, 54.064675684898134, 56.22721956622217, 53.368078431775494, 53.717545924648164, 55.268839405428984, 55.77413482050742, 54.610477416746086, 56.596604854829856, 55.22545799132317, 55.94157295842325, 57.41087713549214, 53.094414664853005, 56.63740927173246, 50.68476930741341, 36.20507701750725, 56.34350607472082, 52.72359771113242, 53.02085845701156, 54.73003910433862, 57.68686294555665, 53.784559619042184, 56.13858968980851, 53.782508219442065, 49.94372375549809, 46.96875502986293, 43.4782652701101, 41.6502054276005, 42.27924377687516, 42.414020338366115, 41.33639227959418, 42.23491707155782, 41.09519004821777, 41.391183868531265, 44.28655593625961, 42.84037413135652, 42.496511705460094, 42.34942674636841, 41.95838212966919, 43.93742184485159, 50.14566306144961, 53.56052560191001, 53.37778629795198, 53.596403521876184, 55.31746110608501, 55.1629001094449, 56.264560530262614, 53.58548756568663, 49.637625909620716, 44.72919933257565, 45.68966227193033, 43.395111022457, 46.90035281642791, 55.374810080374445, 57.152898926888746, 58.51087839372697, 56.75804961112238, 50.89365120856993, 49.03166286406979, 53.58562092627249, 55.51666259765626, 59.84690827708091, 57.43081062070785, 54.20253130697436, 57.14462272582516, 60.54492542820593, 60.72065545666603, 59.219768354969645, 59.557539339988466, 61.28969723178495, 64.2623007682062, 55.933096716480875, 60.67170427691553, 49.1921466396701, 58.2092716616969, 21.89700803449077, 1.3225439166830433, 5.982006259502904, 5.170371772781496, 0.4167000432648967, 0.09248617916337906, 12.239521761094371, 66.32532627351823, 53.37090253829957, 39.27595946096605, 20.436607637713035, 26.178541798745435, 36.55809425538586, 59.50788605597712, 65.47390522495394, 39.484390289552756, 1.546572540556231, 0.059763101199942256, 0.02178284636278066, 0.03568211172316824, 0.07369165984733451, 0.019346476089389577, 0.010123217981609126, 0.025669557057441245, 0.008822828737808572, 0.08588299155235292, 0.030006714045040073, 0.08045797822095695, 0.14238277269947913, 0.24706819725613444, 0.09932836322414298, 0.15304005164052212, 0.13588351257626088, 0.10299134368617689, 0.13372475341443094, 0.16326596179316122, 0.13975196548046606, 0.19288730296877124, 0.21670787234700498, 3.172816509200681, 62.18721005224413, 70.38117470279818, 69.49513481509301, 54.10055752723448, 34.517045790149325, 49.32772728704637, 62.39614686658306, 50.151719200995664, 72.57658020142587, 48.30144697620023, 1.137895521617705, 0.28739819122898963, 4.874870700220908, 10.717575453942823, 4.969793529279771, 39.243697966298754, 50.005559921264656, 55.85309213207614, 62.631328259744954, 64.743430460653, 64.85746160630258, 63.55890996994511, 57.88207146429247, 54.754655899540076, 50.237650486730764, 51.36026028663882, 48.35630916780042, 46.76145776625603, 47.370954867332216, 46.572128880408506, 46.346463157284646, 47.930422136860514, 47.27745340716454, 43.79688724394768, 42.96327767833587, 46.27546433479556, 44.27922110403738, 45.75829982757569, 48.17505251976752, 53.22340965270997, 54.692737363999896, 56.73277778010215, 59.55143220963017, 50.81880846331197, 53.7634886464765, 56.09131336212159, 55.326011873060665, 54.55244987241684, 53.877174623550914, 53.35781358903455, 49.83661951557283, 43.49225244214458, 44.592390983335434, 45.59262283386723, 43.27856955989715, 45.1141760426183, 45.322077351231734, 43.76520626006588, 41.971220047243186, 41.46166493815761, 48.88869639365904, 51.64922129723334, 54.67057205015614, 58.72625573988884, 55.79281314726799, 56.04922633017264, 58.01097231526529, 56.79786166837139, 57.11105900426065, 59.298000028056485, 56.23621748339746, 56.59846405829153, 60.98423088750532, 55.64983098737655, 56.93636055915587, 51.47079267809468, 39.1029711692564, 57.26640055256506, 53.92123460769654, 56.33637520574755, 56.67153781460178, 58.821271234943026, 57.0641553017401, 59.69617943609915, 54.89362155237506, 52.427905913322206, 48.04825405920706, 45.767764506801484, 45.4308956669223, 44.71487875907652, 44.3041556112228, 44.72322556280321, 44.61315993339785, 42.79361555653234, 44.69898923750847, 46.76436816492389, 44.94364315463651, 44.55195526922903, 44.45081695433586, 43.86443830305531, 47.806624289481874, 53.42461939780943, 56.019279033907004, 57.179622034872736, 55.47820768048687, 56.96647651733891, 56.874442023615686, 58.54414009278821, 58.668204661338564, 49.04040974955405, 46.475611117578325, 47.924464056568766, 45.14200918136105, 49.57035333879533, 58.493702334742395, 59.296823317004794, 59.06603105606572, 57.975686673195135, 55.54551163027364, 51.29786714430779, 54.76377933256088, 57.67679422132431, 63.04149443103422, 58.51380840424569, 56.03664728903002, 59.54747061575613, 63.18599847055251, 63.925255421669256, 61.603851625996256, 63.08850011517925, 64.74420316757696, 68.1247292795489, 56.33096233490975, 61.838648626881266, 52.05098182924333, 59.97144353005194, 21.92305845599021, 3.1024854702334252, 8.06247748674885, 3.1803136294887913, 0.45415549148474976, 0.1411393353895795, 15.415609036722492, 74.46104372701338, 60.84218617408507, 48.67926928304857, 24.813019614065848, 31.342377431931038, 46.908723154375636, 69.23636036534464, 76.23808922306185, 48.56367311170025, 2.4854074082066937, 0.14179633239344244, 0.22592470680754032, 0.1677320398870976, 0.17529619286858267, 0.1973925741209138, 0.09160625057355051, 0.11627448091824209, 0.10755701321026973, 0.12179900907100209, 0.06970074012755387, 0.20193106284545315], [0.0454036487386592, 0.07116472648997461, 0.01555793860461563, 0.04875708371400834, 0.05029438469078272, 0.03198412487343435, 0.02204287384125975, 0.00980536139855582, 0.06908661340393367, 0.02972223112479814, 0.04035417936862477, 2.768413280287097, 49.16329760705271, 54.40298403463056, 45.58474671456122, 26.77237883690865, 15.633122113443191, 37.26659982435165, 55.34452546027399, 36.28302235757151, 62.35308708683137, 32.7057776143474, 0.8708669954249937, 0.15135268170026042, 1.1475783826843386, 2.1983891965881472, 11.82856523221539, 46.40787178470243, 41.88644978307909, 56.79366080991684, 60.78673954932921, 59.8395420658973, 58.30747604370118, 57.19083216882522, 53.195749098254794, 47.33820699876355, 42.933781454640055, 43.190363299462106, 41.341181493574574, 41.88136639133577, 40.65496283192789, 40.2258712245572, 39.324263449638124, 39.555189071163056, 39.18606265898674, 41.869477687343476, 40.464798481233665, 40.132248170914195, 40.70027012978831, 41.668985735985544, 41.233939970693285, 44.128162783961145, 48.97838923238939, 53.79794274607013, 55.620770146769864, 55.34212889209871, 51.25612920330417, 53.583204746246345, 53.120741613449596, 51.42815651432161, 47.642818266345614, 42.02421126827117, 37.93973738147367, 40.40513530854256, 40.552977285077496, 40.52183758827948, 41.56776505131876, 39.80232977098034, 41.53044762149934, 39.7487933404984, 38.50156984021587, 39.02173103824739, 40.196218106054495, 46.58315858533306, 51.549604861967026, 55.10892829587383, 53.643872045701556, 51.61113900523032, 54.01957627265684, 53.5068008976598, 54.124005456124586, 51.195803150053955, 54.08453856745074, 51.64953508684712, 51.98189320102815, 52.054284464928415, 55.96471102006974, 50.80293070885443, 26.87748855160129, 51.10558863609068, 54.71621274948121, 51.994636981718, 51.002602884846354, 51.87821711263349, 52.25165028725901, 52.77602803322577, 53.34218294389787, 47.656813283120435, 42.0012261790614, 41.049278705350815, 39.05649108271445, 40.10572118143882, 38.96453895876485, 39.617444930538056, 39.89027323261384, 40.48240207856701, 40.408622295625754, 42.497602124367994, 41.48647392949751, 41.5865885057757, 43.969953983060776, 41.18446319333969, 39.45236413709579, 41.973930405032256, 43.833745756456935, 50.457915106127345, 52.87533460124847, 53.35815091286936, 51.66740148298202, 54.23525956369216, 51.917287841919936, 48.169835767438336, 42.32230355662685, 42.95505639045469, 41.738709788168634, 49.27381038665772, 53.20889296070222, 56.35466914023123, 55.54762186542634, 53.904074238192656, 52.33824053118306, 54.396186567121944, 55.07685115260463, 54.3605165327749, 56.19747623320549, 55.15532209027199, 55.74842368402789, 58.924056945308564, 53.96614574616956, 56.127940454790675, 48.49395298188733, 51.90883121182842, 55.85386091662992, 59.86417455057944, 59.62421963291784, 53.323826251491425, 52.87462072987711, 70.4188294564524, 21.35193390230979, 0.8274129561839566, 6.925906990804981, 4.323179039262957, 0.07371454289363277, 0.032717826430715864, 4.394011161019725, 55.992218602088194, 50.13529231471401, 42.140234977968284, 34.75242722419001, 17.359200331472582, 34.00043433712375, 52.21580374625422, 58.634770377989746, 35.99233942647135, 1.6810366607481435, 0.08347882378485896, 0.0781757103639745, 0.059299303909703616, 0.021817632500202428, 0.07130994611690122, 0.04025191046117295, 0.019759981622619015, 0.012006952536232289, 0.041852754600826776, 0.05044850242894985, 0.014118364591511988, 0.11503324228068514, 0.06816342382902099, 0.044530128474317254, 0.029183069935008406, 0.031690529337333094, 0.025958998481773084, 0.040117990631129474, 0.062153341488972794, 0.04463599033413395, 0.06429364559270682, 0.14468218560420698, 4.358306315637404, 59.718140786693944, 60.569106840318256, 54.86254069112963, 32.44365542165695, 22.349718193854056, 41.96126899411602, 51.44936084747315, 40.34386788645099, 66.42667247403052, 39.17254224900277, 0.8274147335079409, 0.12470769936278944, 0.8108961618235035, 1.2871852204684289, 12.079652817018571, 48.13493451764507, 45.51917253002044, 56.780968020039225, 63.073555884822724, 63.80372862662039, 60.62673430288992, 58.553867570815555, 55.267788210222804, 49.031451056080485, 45.16516293248823, 44.21942064839025, 42.5147311149105, 43.459877198742284, 42.175959925497736, 43.38585815122051, 42.92120633586761, 40.9652772257405, 42.557108402252204, 42.04952232299313, 42.82457090193226, 42.35831483717888, 41.95814286508868, 42.54426263993786, 44.039466227254565, 45.436316382500436, 52.0457140861019, 54.22195880643783, 57.95342722246724, 54.9011956491778, 51.72935531985376, 55.1611860336796, 54.35691971932688, 54.787160581158055, 48.87958080537858, 45.27928429265177, 40.429626587898504, 41.76386002571353, 42.19619151084654, 41.168295183489406, 43.16311067150485, 41.22014499479725, 43.16911974260884, 42.035852862942605, 40.55528363873882, 41.03905308631159, 42.56199959785708, 49.22421986056913, 52.27994234331193, 56.6961742216541, 55.886047886263945, 52.16409906264275, 55.90251399624733, 55.519980922822036, 56.39333978776009, 53.22289189984722, 55.373845177312056, 54.50952737562118, 55.49800780511672, 54.02967245348039, 57.8367994677636, 51.63196679084532, 27.546268355461862, 50.73468931259648, 55.04108305900328, 52.351368704149806, 52.590303805566606, 54.93037808325983, 55.34125028118011, 54.998439050489864, 53.353848072790335, 49.989125190242646, 44.907498513498616, 44.34326556421096, 42.08740849648753, 42.28914383919009, 40.51805642343337, 41.58663949658794, 41.10547842517976, 41.94826633699479, 41.683902509750865, 43.88380304459603, 43.48573738528837, 43.10324353556479, 46.72389322711576, 42.79943635386806, 41.17684987283523, 44.340633653825336, 46.827200612714215, 51.293430943642896, 55.46286729074294, 54.426051493613954, 52.51152300065564, 55.26041807666902, 54.20054658766716, 50.13501382643177, 44.264618119885846, 44.99852495808756, 44.43511178416591, 50.5054424655053, 55.62519458032424, 58.98842303983627, 56.293013403492594, 55.63675380522206, 53.83039643687587, 54.8825643908593, 56.933595288184385, 57.759038479097434, 58.43834200213033, 57.007975193762014, 58.61859060102894, 61.3448614458884, 56.091858571575536, 57.56001741655412, 49.84930838308027, 54.80092810046289, 58.19784579738494, 62.01814020833662, 60.392164799474905, 55.839285389069595, 56.83893672881588, 68.48463812182027, 22.047403474007886, 2.876354701096012, 7.27691940722927, 7.038791333475421, 0.6553904255551677, 0.04564832573035552, 5.005683706652734, 60.552903529136415, 54.55691745204311, 44.8401592623803, 33.84137438189599, 22.734785118410667, 40.303239976206136, 58.96306491667225, 65.40168262297108, 44.94381966129426, 2.8281259729016215, 0.11486785921959147, 0.07151131998867759, 0.04382052421269398, 0.03555059740920702, 0.0034485917140339175, 0.06886953472970955, 0.016775471608965628, 0.04469124442567268, 0.06360096038289129, 0.049166170835134484, 0.00910802316221018, 0.20208469411778837, 0.20649155361517785, 0.1304218419376881, 0.09752346773541744, 0.19653389681010477, 0.13062890018186263, 0.12764143306882153, 0.11753092640109601, 0.13981490726432494, 0.16915952215992636, 0.36193964942809076, 7.1381841936419095, 69.57207602839317, 68.86604155263593, 63.578035446905325, 39.11381260041268, 25.639790527282226, 47.904055964562204, 67.7467461555235, 47.96918692127351, 72.97893693370204, 43.4716207750382, 1.2645010505953145, 0.39617762029651676, 3.517476401982769, 5.520254546596158, 13.035542272752332, 47.13114115499681, 51.02310119136688, 60.14698920711395, 65.65140031999158, 64.92675027539654, 62.94347440042804, 62.97708911280479, 57.81717977216167, 52.788916941612, 46.499392447933076, 47.789095217181796, 45.2702824531063, 47.30475310356387, 43.834087002661924, 45.30698407080866, 45.07668210614113, 44.10859015680129, 44.578411656041304, 45.48430658155873, 44.726261477316584, 44.904184110703014, 43.85504030412243, 45.83288369640228, 47.04898711173765, 48.65892394896477, 55.42499288435906, 58.26285516062091, 59.691445135301166, 55.788604444073094, 53.407941479836744, 58.360039726380386, 58.43703977523312, 56.7067293197878, 52.27296052440521, 45.70788168138074, 41.782334389225134, 43.80575180053712, 44.579855088264715, 42.856946145334554, 45.49419879913331, 44.36417964196975, 45.39135425321518, 44.20745741936469, 42.204306894733065, 43.47006359407979, 43.32798750169816, 51.675685528785955, 54.337727562073745, 58.30978631973267, 57.30339634803034, 54.40313308469711, 56.66235554602839, 58.01687548237463, 59.33238352498701, 56.80233317036783, 57.287451913279874, 57.48720645904542, 56.74629819008612, 54.57900824085359, 60.28271105981643, 53.53404568087671, 31.3137343237477, 51.43984909980528, 57.596001240514944, 56.27647669084611, 55.38933069475236, 55.53354055650773, 56.361148895755896, 58.57126720489995, 57.88106341515818, 54.1426916276255, 46.896210793525945, 46.67060782832485, 44.41463701186642, 44.36263030575168, 43.38047665934409, 45.35953598637735, 42.803900011124156, 45.341842174530036, 43.89080055298344, 46.715726852417, 46.23380091882522, 47.35010354749618, 49.30522857173797, 44.0492799974257, 43.99456685589206, 46.69616991473783, 47.726094107474054, 54.10237358462427, 59.047905783499445, 55.69054911213537, 53.358217593162294, 57.93128544284452, 56.414940280299035, 52.61664252127371, 46.56657872661468, 47.887833041529504, 46.350758152623335, 53.69512957911338, 57.80147460199172, 61.839578228612105, 58.67852049489176, 59.58844761694632, 56.40523241412256, 57.93561181714458, 59.888626606233665, 59.87909132434476, 61.29415696667087, 58.32391469709335, 61.61104525289228, 64.04423267610612, 56.632227820734826, 61.04933046525525, 51.974468154291955, 57.917192366815385, 61.50511772401872, 65.39777594227945, 62.553912439653956, 57.13861365472117, 57.325620497426684, 69.20029024924003, 25.408674670803933, 3.1553276411948668, 13.563539385795595, 11.804811358451845, 0.7488795057419808, 0.10742976600604673, 6.171524890007512, 64.30811012944868, 62.027679412595695, 58.927406649435724, 46.064476120856504, 27.588445601924775, 48.677292408481726, 70.41247521677326, 75.82779361355689, 56.19808812295237, 4.693384593532932, 0.23500499375645192, 0.1316593650488123, 0.08306368839957061, 0.13643740946727415, 0.15939190112535032, 0.14590135324866543, 0.14155522920191288, 0.07882490093188901, 0.14653532164952449, 0.13018902781749928, 0.08825943459786716], [0.06819602087019913, 0.01702274946916488, 0.05795227619068277, 0.0063460880248326695, 0.04006452918533356, 0.05112190903615087, 0.07055815339328782, 0.04994066657438394, 0.026598540172281287, 0.048820772433593396, 0.05302151980539484, 6.738178431987763, 56.20368142281809, 55.08222872211088, 47.253770136064105, 36.820536121245354, 34.7172906321864, 42.90996090058358, 53.97728527745893, 40.39624329536192, 64.98716654316073, 25.039585521144254, 0.11275521088992396, 0.11706313779277187, 1.4089175722291394, 2.05214558589843, 20.436382101428126, 41.90556741529896, 52.78212731884372, 58.1308360253611, 56.66509728277884, 60.65548135388283, 57.33639132591986, 58.049333095550544, 48.60976096122496, 44.53301414366692, 41.11004014169016, 42.88039407422466, 44.58402849012806, 45.14679447297127, 44.27776198233328, 43.324021985453946, 40.619567363492905, 41.771979331970215, 38.29109937913957, 41.90974473953247, 41.36909307972078, 41.53990053361462, 38.776508377444365, 40.29073938246697, 40.88813989393173, 42.10535334002587, 45.87901861436906, 52.623361541378884, 52.181075080748535, 53.10317723981796, 52.15288892869027, 51.625161478596354, 52.126597281425234, 53.3430850890375, 47.65624453944545, 39.34449503498693, 40.96212364012196, 41.34018521155081, 41.667965919740745, 40.414933389233006, 39.31317883153116, 40.99683269377678, 40.54415979693013, 40.50933699454031, 39.068571982845185, 40.09005523497059, 40.72556549502958, 43.259361713163315, 51.068031941690755, 50.19078993028211, 53.83244783647599, 51.00430911587131, 49.48952505665441, 52.15434805039437, 54.73771518276584, 55.14081716537476, 53.72627319828157, 53.0912140107924, 51.20914705338017, 52.03056197012625, 54.82437210698282, 48.36966091586698, 29.261289411975493, 53.90210128599598, 52.70375444043068, 53.26199400809504, 53.62889643638365, 52.87045125038394, 53.26912095469814, 54.254255602436686, 53.605275923205966, 48.33592853238506, 43.376099294231786, 41.9240927696228, 40.382703273527085, 41.564725214435214, 40.62445463672761, 40.9001305795485, 40.387355204551454, 40.746110869992165, 39.88066734806184, 41.24587182075747, 42.962202948908654, 41.134464740753174, 40.97517728805542, 40.86362900272493, 41.64963276155534, 41.07679805447979, 42.118752156534505, 50.782977611787864, 53.49423754599787, 52.25936951175813, 52.69346998583887, 55.100448131561286, 51.05132264475669, 46.51346983448152, 44.22553170111872, 41.90754821223598, 43.0259963773912, 48.58349284818096, 51.5918448663527, 55.19320826376639, 54.304140306288204, 55.746952795213275, 53.39127925134475, 53.633964138646284, 55.30429763178672, 58.663262474921446, 54.86206608433878, 57.08084106445313, 56.23138512334516, 56.72439175267374, 53.2741415885187, 47.513705607383486, 47.04579822478756, 56.968072921999045, 58.47297653075188, 61.19661154285554, 55.92778974963773, 56.15593833308066, 48.90274240124611, 64.6966326621271, 27.396374979326804, 1.7111827721518857, 3.009438269561337, 8.545742419458206, 0.42365412978876027, 0.11915548479244595, 0.9113204827712429, 43.842837810516365, 59.08178721704791, 38.89199080005769, 36.25248278340986, 16.615487567840084, 27.55875522090543, 43.61610520270563, 57.12668572702716, 42.73030850195116, 5.587183419735202, 0.04906444201966928, 0.09771681300574735, 0.01710536822135891, 0.030892156552703633, 0.06459163847349345, 0.051400715244873885, 0.056253575810020974, 0.09954330451305836, 0.04822803871525873, 0.04764151030911073, 0.02453953906473133, 0.0265195794899257, 0.03156021778141299, 0.07114836285191198, 0.018121687274786736, 0.02933688698366525, 0.013619549422254486, 0.01785014166436609, 0.039896449494746425, 0.02532702765517658, 0.02425888466889099, 0.09222462908515046, 9.992322344933788, 65.26455656174691, 60.50899651742751, 51.61037414304672, 41.15184868535688, 40.44717919441962, 47.65170635715608, 53.383297228044086, 43.701173567002826, 71.74544565139279, 27.867131963852916, 0.09184027511265971, 0.07270411122590303, 1.6701615217231935, 1.8761438107298267, 22.160002954544563, 43.99717130968648, 55.898760287992424, 61.23118331355434, 59.47922921949818, 61.579929090315304, 58.70361974162441, 60.00057889569191, 52.10038015919348, 45.361403034579375, 43.878778488405295, 45.663358857554776, 46.51906705671742, 46.8210542586542, 46.50217733075542, 44.94309010044221, 44.14157336758029, 43.428812026977546, 40.176143415512584, 41.910909683473655, 42.78075410473732, 43.60068636555826, 42.00132816068588, 42.61053108399914, 43.46542735253611, 44.474704188685266, 47.688725686842396, 55.10496670199979, 54.10336986664803, 56.55236836402648, 53.87684906682661, 53.95546513219034, 54.88620042800904, 54.78249688302317, 49.502829736278905, 42.59821484165807, 43.70413103411275, 41.94379483499835, 43.34848188584851, 43.13415965726299, 41.19119398055538, 43.093096363929014, 42.206648549725934, 42.3793661978937, 41.49483250033471, 42.145047726169715, 41.935675528741655, 46.15712250432661, 51.90989025177495, 53.194607688534646, 53.826219112642356, 52.101941262522054, 52.339499612008375, 54.64254279290476, 56.309573650360115, 56.01306599955405, 56.23276579764582, 55.48074937635853, 54.34681177139283, 53.403819068785644, 58.445704290943766, 50.492114251659764, 31.802089022051906, 57.202673804375436, 54.467730599064986, 57.37882744881415, 54.864188086602, 55.37662613776423, 53.64488009483584, 55.8939318503103, 56.14518711643835, 49.16839276590655, 45.947793452970444, 44.44991088682606, 41.845782649132516, 43.02762023864254, 43.269434359765825, 42.394000561006614, 42.251712660635675, 42.19368119393626, 42.548408585210005, 43.41768034042851, 43.00948712133592, 42.574009895324714, 42.464050169914, 41.60805171535861, 43.354114409415956, 42.417832882173606, 44.15735306278352, 51.924740345247336, 56.80759699113908, 53.61712148112636, 52.70233062005813, 57.38844902284684, 54.59036742487262, 48.972674339048325, 45.59561952467888, 44.60440128080307, 45.0712731576735, 50.70502442698325, 53.69599642292146, 58.816674217101074, 56.437631191745886, 58.64139526121078, 55.536866726413855, 56.94954364530502, 57.02979926140078, 59.545168184464984, 56.91814114970546, 57.74337645499938, 57.91854950689501, 60.262142150632805, 54.793522665577555, 50.09566068649293, 49.285577497174664, 58.23432383998748, 60.151951005381925, 64.93188073558193, 59.48884294879053, 57.68227769482521, 50.80852793109033, 65.51903209378644, 29.175260066986088, 2.1608109291522735, 8.362120582211404, 14.816067891736186, 1.4250117924905594, 0.09194319902528679, 1.0755789880791018, 47.588171805104906, 64.40885228495445, 44.01031124976374, 39.16741571118755, 23.305972430013842, 35.84564278202672, 50.35445082572199, 63.41380973016063, 52.52299201103949, 8.700076899220868, 0.0880599223197468, 0.03304223785357129, 0.017699270223778103, 0.011422171768161559, 0.008162782704007, 0.02146197809657503, 0.05641046295603437, 0.05441249798863165, 0.01381783212925638, 0.05303180070533868, 0.031517713308154095, 0.2816991405861993, 0.07786932115953776, 0.2067504300465507, 0.13199278183521765, 0.11546801249947279, 0.22961983997975627, 0.20018657338955712, 0.16334036425236734, 0.1380496568256809, 0.18612562708796995, 0.25056624664895, 13.548533378108857, 73.73846469386932, 67.60101441414126, 61.83364760491156, 48.522386243266446, 48.35902344795966, 49.905994476810584, 64.27265190309095, 52.492158259114916, 77.04437948042347, 32.33522149824327, 0.4263677357906296, 0.24649067421353635, 4.112887536325763, 4.892525778662774, 23.423310133718676, 49.04420268151068, 59.34245224921935, 62.934205839710856, 62.57193180822558, 65.68314013942596, 62.12908444866058, 62.99716772571687, 54.01751310594621, 48.648055061217285, 46.05109691619874, 47.361399973592455, 48.584461673613525, 49.58960040923088, 49.817690157121234, 46.408216953277595, 44.62716279491302, 45.906196717293035, 41.32782190076767, 44.61030052554223, 45.91418658533404, 46.402423612533084, 44.26499858979256, 45.07031609935146, 44.52623236563898, 46.981059505093484, 49.60382684584587, 57.42704122297226, 55.50748032908286, 58.19251921869094, 56.60642254737116, 55.17136850664693, 56.75170713855375, 58.309731406550256, 51.583976591787035, 46.1440178655809, 44.93387253053727, 45.2039316392714, 46.1962285349446, 43.03614747139716, 42.714477815935695, 45.70368474529636, 44.13042991392074, 45.31560544044741, 42.30356639431369, 45.17574940958331, 43.60786038060343, 47.37584998530727, 55.66450849656136, 55.74265387750442, 54.105323206993845, 51.43870769008514, 53.14883362862372, 58.447665476029925, 60.01140071499733, 58.98768563424388, 57.86757046176542, 59.28178887213431, 55.409644649874785, 56.2010455900623, 60.086376820841146, 52.01512744349819, 34.8962370041878, 58.23842271681755, 56.033470169190444, 58.36771188243743, 56.79339016637495, 56.516310015032374, 57.01494132318805, 58.08648186345255, 59.25755254683956, 51.87340828680223, 47.61928796768189, 48.124442177434126, 44.465808253134455, 46.66135495708835, 46.55740038041146, 45.5483510417323, 43.952146422478464, 45.3643879582805, 43.99976791874055, 45.78244593835647, 46.25924533413303, 46.04307174682618, 45.724241887369466, 43.09160586326353, 45.583048328276604, 44.27687552667434, 48.025676896495206, 54.83135000351937, 60.17333968993157, 54.27463231548187, 55.21704450730355, 59.69364950733801, 56.734295737358835, 51.00698417232883, 47.96247574590868, 46.586237645918324, 47.747522015725416, 52.86297129046533, 56.80884430485388, 60.95805298897528, 61.206801860563225, 59.835643229946015, 57.81024502169702, 59.80160490159066, 61.42488171977382, 62.56340457547096, 57.69739058709914, 60.387155932764855, 60.496688119826786, 62.1553211827432, 57.821702264970355, 52.718114237631525, 51.942979366548606, 61.13792111796718, 64.27402865502143, 66.88776277726697, 61.28496685335713, 60.55510790117326, 56.70088891060122, 64.83977956156578, 31.193241073239236, 3.4571515744732273, 11.190193603115699, 20.53303126365908, 1.802760432324102, 0.19429218564783374, 1.541705614616794, 53.17172850331953, 70.4106552370133, 52.69391321366834, 48.09088630060996, 27.404066747234715, 41.329747784522276, 61.861649405571725, 69.47474633493732, 63.71777772903443, 11.911480215287979, 0.1789509225636721, 0.1636329791959255, 0.09376945304534129, 0.20142627219038628, 0.16198518535783216, 0.1273784121017783, 0.13516351250150513, 0.1989854854201117, 0.23299389038114782, 0.20689255467826323, 0.1546847045181259], [0.03971221684027584, 0.04583248943691293, 0.033531457771577185, 0.040197889771192305, 0.05506363825031346, 0.1389997131040981, 0.013646905464420636, 0.026968401676464467, 0.06995559459732426, 0.02529155203862296, 0.04768348043604244, 12.261664521309639, 59.196143919421786, 52.8913967071041, 48.69777110315139, 24.041222679999567, 30.198426015915413, 54.2957660459703, 44.798570371443226, 44.3455836849828, 62.96782447445778, 25.74995029357172, 0.13318982486042286, 0.1669888733135116, 0.5096674175752748, 2.23791933348102, 25.194534832431426, 50.6030624143539, 58.4657907485962, 59.08066541917863, 59.36471562231741, 56.167340663171586, 54.339457327319735, 47.202802858045025, 43.19351688508065, 40.96355138286468, 44.69749481447282, 49.944449393979966, 53.58542480776387, 48.59272218519642, 47.29106010929231, 44.92478832121819, 42.50896523075719, 39.54669713973999, 38.01473702153852, 43.10587544595042, 44.277722758631555, 43.11677571265928, 42.65449300889046, 41.80576662863455, 39.10154734888385, 40.306307269680886, 40.98477925023725, 43.30358643685618, 49.18470982582339, 53.89941446242794, 54.358359229180124, 51.968937612348995, 55.20894089052754, 53.56617381495815, 49.60968294451314, 43.71157961506998, 38.50137372170725, 40.94713234132336, 41.403523645093365, 41.13130331039429, 39.68321131121728, 40.536522942204634, 40.2921082896571, 40.74176488384124, 38.29715944105579, 39.616283908967056, 40.68867952592912, 40.96036249591459, 48.58088447201637, 50.57523712035149, 50.933463265818936, 51.31240737053656, 51.59256266009424, 52.17237134133616, 55.00495410734608, 54.06903343815958, 55.34860864762337, 51.63153925249654, 52.292097768475934, 53.427231696344194, 53.58062774904313, 56.18546593573786, 34.71618060142764, 53.35196533510762, 53.05687365993377, 54.18038952735163, 55.46697401231336, 56.112415713648645, 54.57983193858978, 53.51901515837639, 51.3956126090019, 47.793092112387384, 43.75882456379552, 40.22322362469089, 42.85456134426979, 45.23373380784066, 46.200131293266054, 42.92506987048734, 39.91287392954673, 38.95390933559787, 40.2038824173712, 41.35524319064233, 41.46053137317781, 41.2650796674913, 41.71836445408483, 40.75813293457031, 40.01456137626402, 40.16967542709843, 41.24669944086383, 50.15085235718758, 54.78886681218302, 51.038418046889774, 52.91730003972208, 56.53480399039484, 52.54667528213994, 48.718622422987416, 42.45173392757293, 42.15655988262546, 40.393179924257346, 44.13006121112455, 44.60248716415898, 52.75181131978189, 52.00312106840072, 53.68089529775805, 53.730128888160955, 58.00256667598602, 55.85825004885274, 53.25962097414079, 52.06076814282326, 59.60549031534503, 54.902223310162945, 53.325681532582934, 42.38291594289964, 45.8170961564587, 54.894963002973995, 60.30803780401907, 55.41113515054026, 60.407014892947295, 55.036415438498224, 58.08421865586312, 42.0252703082177, 53.98069773950885, 40.98617953638877, 4.291569638636805, 6.984193901861868, 5.72256451652896, 1.252971611195995, 0.029858060428992878, 0.34778237523090455, 34.43208725221696, 61.507455456641416, 42.72001228024883, 46.727913656542384, 23.94542467209601, 25.55473393009555, 44.10464425240794, 55.49772931683449, 46.64124888758506, 11.86233978117666, 0.372032857830486, 0.06542921772286778, 0.13646690385235896, 0.013552849019517102, 0.02026530087835366, 0.033257412799303575, 0.12148133539144071, 0.07760366485003503, 0.0739501302521075, 0.002751054055425489, 0.07089697109955935, 0.05081227161891518, 0.05749738084212427, 0.025395443137254448, 0.028631952027940465, 0.0650771466955062, 0.04909772853997927, 0.026619153683103865, 0.08582666876815981, 0.018998001844832496, 0.047837318552117196, 0.03483014917301555, 16.890471212325558, 66.15697030098208, 59.84426459958477, 53.082255317318825, 31.027444447240523, 34.117874022453066, 48.60497959198491, 48.52442979812623, 48.098668283031834, 69.60072502013176, 25.274360948993316, 0.018647811563325026, 0.30516119613762827, 1.638196288577972, 2.5113698215253892, 28.32718872254895, 52.81512229673324, 58.895992386725645, 61.11632062542824, 61.18495033633325, 59.7095194170552, 57.78038793994535, 50.36710046952771, 45.087476468855336, 43.031876010279504, 48.61587201395343, 52.56804827720889, 53.93233883765436, 50.005544231783965, 48.84960213015157, 47.116510714254076, 44.73103107944612, 42.903226190997714, 41.45179233243389, 44.690869931251775, 45.194619932482325, 46.01570144776375, 44.03187644097113, 44.575093330875525, 43.34225316201487, 40.81655663828696, 42.062093519395404, 46.62665767054404, 52.51859503407633, 56.33485724849086, 56.53280750397713, 54.089723940818544, 55.26793726028935, 55.64636361214423, 51.948364780795195, 45.496383559319284, 40.28624042387932, 42.80617890819427, 42.04609024909235, 42.720934037239324, 40.331249621606645, 43.20240497589112, 41.39579265348373, 41.64794222001107, 39.515875154925936, 42.08037568676857, 42.71002592579011, 43.867085902921616, 49.41200333256876, 52.76401381338797, 52.889600261565185, 53.31714645508797, 53.74363360866424, 53.04176469003001, 55.35592386799475, 56.25099305183657, 55.88918970477197, 54.771812346673784, 55.250266982663064, 55.46401262283326, 57.774833863781346, 55.7788416647142, 38.62548143632951, 54.50104721130864, 54.644747164941606, 55.317547398228804, 58.558307693850615, 57.31310813657699, 55.676659999355195, 54.747921189954205, 53.07212383516374, 50.14971486983761, 45.53719189859206, 42.22743711163921, 45.7206529186618, 47.789075605330936, 48.00309188904301, 43.70182468045143, 43.328532711152114, 41.78429165194112, 42.4190801958884, 42.17226505279541, 42.51072637496456, 44.665821675331365, 42.98171674051593, 41.89428667868338, 41.58821628939721, 41.47213766651769, 43.96008922207741, 52.66784514150312, 57.47424302562591, 51.71512496086859, 52.678466919929754, 57.95788303498299, 54.79040830366073, 49.90058160597279, 45.19835795125654, 44.60366387521067, 41.73135534409554, 46.64714420995405, 47.35684217945222, 55.22601104551747, 53.74442984980922, 55.71104349628572, 54.25682083252938, 60.47964542142807, 57.01318410135085, 54.64060514203964, 53.58033357128021, 60.32096201373685, 56.29495889909806, 55.19897807028986, 44.68788500755064, 48.935517726405976, 55.50858643747146, 61.933958299698375, 59.50809786396643, 62.92243480682374, 56.341556656745176, 60.272340313080825, 48.90712368872858, 53.63478783638247, 44.53629716750115, 2.3824606355159514, 5.350505152056295, 6.445510781580403, 2.5183266353222633, 0.019138236154591846, 0.34313645033586415, 34.93005567981351, 66.95504711520287, 45.80882780013546, 43.75915012051983, 26.99826225157707, 31.122971811602195, 51.567518326544, 61.97196606666812, 56.26568625050207, 17.142348174125917, 0.37470855780186196, 0.0813507387835172, 0.10003478056000126, 0.025156241758996924, 0.15269416294270946, 0.12482111101909993, 0.05492692219934637, 0.04762136602714177, 0.06982660071263391, 0.05237816299702372, 0.055470132163815924, 0.15877883160306563, 0.14667219091807643, 0.15624438292316853, 0.11309427374433126, 0.2767241962494389, 0.2110486735980357, 0.17623794475390067, 0.23142072882863784, 0.1547363694877394, 0.2030707871721637, 0.15400516920753066, 21.797803448092555, 76.097942936805, 66.5450103821293, 63.131779547660585, 34.81783666918355, 39.9968401078255, 61.24848096601425, 55.96032973258726, 55.96541704670076, 74.691985038019, 30.964188383471583, 0.23226708744562444, 0.3454664914358047, 2.025939250184644, 3.4305093653740424, 29.888080243141424, 54.2028372518478, 63.10111838002359, 65.48007511323499, 63.33903758756576, 61.66658601453228, 59.99812741433421, 50.41777749215403, 47.6310746900497, 45.45709317730319, 50.662337272397934, 56.99870663304483, 58.08592880925825, 51.91716232607442, 50.71157870754119, 50.12185035213348, 47.04191507831697, 43.95371537054739, 42.6089503688197, 47.90878634299002, 48.03753814389629, 49.99651101327712, 45.93981142966978, 45.5417771493235, 44.22611613427439, 42.72775111659881, 46.424839958067864, 48.70742797851563, 53.6738742551496, 59.36741029062579, 59.845394242194395, 55.469299977825536, 59.32879455627934, 56.22519562321325, 53.57318309045608, 47.53106994013633, 42.56831069146433, 45.36055188025198, 45.2055045097105, 45.08858257724393, 41.666969637716974, 45.11200304954283, 44.60389137268067, 43.52374907462828, 41.63106818352976, 44.32183765595959, 45.482796469042384, 46.51087714779762, 51.860405629681004, 54.39613949867987, 56.46570751743933, 54.77497769940285, 52.971275775663315, 54.13148149367302, 58.231021204302394, 59.15539441570159, 60.10210552523213, 56.764796087818766, 58.44812831571026, 56.828334562240116, 59.777788269904356, 59.53602513959331, 41.05473472226051, 56.804110004055886, 58.27375934969995, 58.40759454234954, 60.12653404666532, 60.10980513788039, 59.210586086396255, 57.84103954991987, 56.59736579464328, 52.55292361782443, 49.93522397933468, 43.222973885074744, 48.27433163119901, 50.719458749217374, 50.84253880285448, 46.25125546609202, 44.52582836151124, 43.16820975272886, 44.106146520183934, 43.32563407959477, 45.819857505060014, 47.21518185830886, 47.047214200419766, 44.92289381642496, 44.44095611572266, 44.83425609527096, 47.878062417430264, 55.588959724672385, 60.19698765970046, 54.402693779237815, 54.67522790355068, 61.775863247533, 58.82284802775229, 51.446254330296675, 47.53861658034786, 47.38385162045879, 43.48220332976311, 50.01573454949164, 48.6865335126077, 58.42577080572806, 58.25291979697443, 58.13746875332248, 55.24010804391677, 59.611985760350386, 60.101976087016446, 55.31940267932031, 55.33004799196797, 63.617702376457956, 59.404880692881925, 58.44446089959914, 47.495399905789284, 51.53842218460576, 60.01201652711438, 63.855299949646, 61.673811020389685, 63.61776121201054, 59.088266972572576, 62.322151353282315, 51.68546791999571, 60.25521524490849, 44.88882410910822, 6.340330464224662, 15.292915336547361, 11.52260761107168, 3.0494167823945326, 0.11191979966937535, 0.49421303394821386, 40.14745520007226, 71.6695007201164, 56.525547196788175, 57.11669545019827, 34.913919048924605, 38.460832103606194, 60.789500897930516, 71.29509479768815, 66.89171652640066, 22.29894115078834, 0.5585580763797606, 0.31210268817601666, 0.35156010800311643, 0.10510750069853761, 0.2517914204227348, 0.2279472708581917, 0.2532277739937267, 0.1422193967887471, 0.16056380114488064, 0.1044055343335194, 0.14472439704883486], [0.014444251691231565, 0.02228850844286142, 0.01971112436524803, 0.01408935858747892, 0.03923469508487371, 0.09030648281857853, 0.031445354388485995, 0.0438030957124166, 0.011607407040203051, 0.06470433766803434, 0.03961370942453223, 19.643776993597708, 58.362181340494466, 54.22938385317403, 42.620721401706824, 24.304496088335593, 30.329909747646703, 70.82482614824849, 46.653302331124586, 44.994437848368, 63.00647158776561, 18.84319966839206, 0.06420682484824812, 0.3344682267596645, 1.3825547094306638, 4.2607304934532415, 28.111601529582856, 55.14080539826424, 59.3105516126079, 59.78198520598873, 55.71174952291674, 54.5435578592362, 45.02415764716364, 42.71778829636113, 40.83641952083957, 49.05292603277391, 53.5794000471792, 54.16067569486557, 56.22547018912531, 55.86972690397694, 50.08724328010313, 46.26361093213482, 42.6206821780051, 40.539001880153535, 42.7517677891639, 44.74213530940395, 46.50940233661283, 47.826859797200854, 46.20172769792619, 47.62838786648166, 45.100545806269494, 43.51267622363183, 43.301487968813994, 38.94932800723661, 41.68653834250666, 49.32129459996378, 51.07247598709599, 54.37047543064241, 50.60671414098432, 52.16320083987329, 52.88495617528116, 45.60134226276029, 38.428292120656664, 39.980927052036414, 39.7514723193261, 41.21448893700877, 38.71693541926723, 41.3833861966287, 40.41493731160318, 39.11311834089218, 38.40596206726567, 39.337862307025546, 41.32644907120736, 41.298996402371316, 45.264296916223344, 51.61761483838482, 50.49804095299014, 49.67939130721554, 50.83504707582536, 52.356365803749334, 53.97794815801806, 56.630745164809696, 58.07387536571872, 55.993250185443515, 51.82065240798458, 53.846438930880645, 55.21322019638554, 52.92906715023903, 38.3387993228051, 55.39725780487061, 53.92887930716238, 49.06239071199971, 51.28588430343136, 52.64418932699388, 55.50624086010841, 52.685005511007006, 51.87089012515161, 46.2693650491776, 45.41227617571431, 43.15921183555357, 45.930531101842085, 44.67147773311984, 47.64309675462785, 45.54017289992302, 41.83287020652525, 40.86369176064768, 40.29289276369157, 40.21624572815434, 43.13553640919347, 41.85494138348488, 41.8391969896132, 40.688165695436545, 40.90626908886818, 40.2570697569078, 40.25479085983769, 48.691130530449655, 56.85589705744098, 52.30144477659657, 51.45185155253257, 52.82421435079267, 53.49138990525277, 50.137900690878595, 40.96287673519504, 41.31107338013188, 41.01491089790098, 41.56186580657959, 40.53573062342983, 48.343302588309015, 54.47649709640011, 51.82521804686516, 52.57449665377217, 48.84591117981942, 52.060148408336026, 54.22572428180326, 59.47924490897887, 55.43607750246602, 54.95439083345475, 46.59864018040319, 43.523858900993105, 52.300562243307795, 58.26445156528104, 59.27378331461261, 60.01697440301219, 57.85816854046237, 53.870832150982274, 48.14071609127907, 48.982017424798784, 39.82014909867318, 52.451957887218846, 9.46204339304278, 7.387303729211131, 42.345739718406435, 2.5030379718349827, 0.20187484731356944, 0.0710317642698365, 24.196946659395774, 65.92951989942982, 47.64286533478768, 51.48674495758549, 28.974772037998324, 20.20791776718632, 36.93818761456397, 48.4717837456734, 60.27651763731434, 22.28252407043211, 0.24128801790216278, 0.021727456290635373, 0.03829710688742419, 0.04112009109268266, 0.030541232742008664, 0.017427058116863334, 0.01811388466927794, 0.07356879466603841, 0.07907711239832063, 0.027988378799730734, 0.019945363408976027, 0.09042828313765988, 0.021161089403434627, 0.03017766848056307, 0.04631682554440153, 0.037020700983703136, 0.03168218855505749, 0.03336028308577595, 0.04905123849429431, 0.05056887399405242, 0.031038328043876157, 0.12612630267657582, 24.456087850755264, 65.22970630276588, 60.380076054603826, 48.647737349233324, 31.20852262743058, 29.933697408245457, 63.26083337107013, 52.816098966906154, 49.924782629935976, 70.5022974937193, 20.22013987264326, 0.14634732367290607, 0.10680427053763021, 1.387871849921442, 4.005851447582245, 32.234598975027765, 55.77288358442245, 61.06597700426656, 61.91631940103347, 60.20975497461135, 56.57884436268961, 47.40483630088068, 45.10023201665571, 42.61939171821841, 50.17540247209611, 54.73188261831961, 57.127011283751465, 59.04356371971869, 56.535686523683616, 51.30639829943257, 47.58884253040437, 46.606214277205936, 40.98514795303345, 43.992417397037634, 47.15434981930641, 48.61587985869377, 50.09033410779892, 48.919761565423784, 49.34219298824188, 47.52487259526407, 45.426655584766024, 44.23882853600287, 42.69863928517988, 44.22062089366298, 52.3302153618105, 52.72201699595298, 55.04621351918867, 52.887235072351274, 54.91574372014692, 55.858701121422556, 47.0539253757846, 40.88102863680932, 41.30906120423348, 42.490561469908684, 42.46296367337627, 40.03565196068057, 42.65865464364329, 41.74115734715616, 41.27606230397379, 41.253995049384336, 40.99936262253792, 41.989102132858775, 44.43702590081, 47.21028674033381, 52.578968155768614, 53.53227669192899, 52.67743925894461, 53.89266406336139, 53.21859690450853, 56.22113204771473, 57.88996327307917, 58.5594294917199, 58.57595443725587, 52.920179059428555, 56.614828186650435, 57.14201434966057, 55.64691666633853, 39.0160906699396, 57.008951863934925, 56.314052997096894, 52.55631254565332, 52.12582065213112, 55.014575681378766, 56.30218390495547, 53.785500987883545, 51.90031182381415, 46.602080099044315, 47.32202329943257, 46.045911542830936, 48.58983532074959, 46.32138744477303, 50.80591171018539, 48.03304703004899, 43.76005226565946, 43.778671756867446, 42.472906881763095, 43.1486528150497, 43.5410741836794, 42.55954027175904, 43.45984581978091, 41.10663552438059, 42.733909237769346, 41.414698477714296, 42.46316763662523, 51.900049025012606, 58.80575041617117, 54.39275841559134, 53.25454934950798, 56.29162488445159, 55.57775351309008, 51.42200231552125, 43.69084596633912, 42.56784392941383, 41.40670468730312, 42.582407689863636, 41.94859189371909, 49.970388027929495, 56.097938245342625, 55.1696583532518, 53.59051996661771, 49.49389849939654, 51.520296912039484, 54.11506637450188, 60.04167356798726, 57.056679264191665, 57.39840007597401, 49.275045933262, 47.70940834476102, 54.331953833180094, 59.69988999828216, 62.4761083049159, 61.82142549945463, 57.77997609107726, 59.680215389497825, 52.013562417799434, 53.11344992729926, 42.589644462831565, 55.003930368731105, 9.790632109488211, 1.8866025656461718, 33.02049682986352, 6.522616734427791, 0.08849452399919111, 0.08489955682307483, 26.166539346018148, 70.57860328305152, 52.42379526938162, 48.72513747984364, 29.39520109084345, 26.523561323842696, 45.81269133475519, 55.10233479161417, 67.73311984154486, 28.802652551281838, 0.3185290320506019, 0.023241853153693582, 0.11202330580882489, 0.039862787591353546, 0.010731799186267441, 0.03989181849324415, 0.06513529276895909, 0.010380601499139542, 0.016652344042555462, 0.04287111527857281, 0.05712821839317199, 0.25711905631807547, 0.12727784007907877, 0.154794821996362, 0.11150660248653543, 0.1254865656336469, 0.15390614468243816, 0.10573272037530139, 0.08789225631663877, 0.16439422544452453, 0.2037277075672342, 0.10523587405200928, 27.14836939688652, 74.8208192086989, 68.54157524724161, 56.18128861150434, 33.973005202508745, 41.154641412919574, 76.35996510905605, 57.821435543798636, 56.61276894230997, 77.2262833195348, 23.99512306336434, 0.18593821133817398, 0.7824761997307501, 3.9151012849423195, 6.062996339413428, 31.798235293357607, 60.07294270300097, 63.7923223741593, 64.54058508719167, 61.802743250323886, 59.56302281348937, 49.256426442054014, 46.3196772913779, 45.541180949057306, 54.54015324192663, 58.19112677727976, 60.425450032757176, 59.709060499745036, 58.75086469034995, 54.525511034073375, 50.047564583439986, 49.21798329199515, 45.18734785818285, 47.82103115512479, 50.12361541871102, 50.38805377098822, 52.961771872735795, 50.51193398814048, 52.78586533761794, 49.8149601874813, 49.180975729419345, 47.49148145798714, 45.24070385963687, 45.76616025740101, 54.24380248592746, 55.25474240702968, 58.129612245867335, 53.231878049912, 56.118440474233324, 59.00273969096523, 49.036581516265876, 42.78740644454957, 43.74848911839147, 44.654662532191125, 45.196961587475194, 42.30506866208969, 44.140792815916, 43.357346442437944, 42.140501699139996, 42.13655971711682, 42.662671150699744, 45.50482449993011, 45.66072694716915, 48.366891722525324, 54.844246756645944, 55.24475213020079, 54.882466331604995, 56.690686825783025, 55.577714289388354, 55.55234832148398, 59.9738871666693, 60.229288378069484, 60.181933602979115, 55.45044122203704, 59.40289205120456, 57.56744246329031, 57.04466896672403, 42.663130068009906, 62.21731032094648, 59.43502803002635, 54.67862859849007, 54.34770214942194, 56.666638774256555, 59.27541894297446, 57.475231462909335, 55.6990881120005, 50.13606109926778, 49.61759828752088, 47.872975103316776, 51.40114707331504, 49.973761266277684, 54.970182295768495, 50.88801084026214, 47.48093028222361, 45.04217701573526, 44.432683837029245, 42.8855323791504, 48.145446469706876, 45.466055793146936, 45.50935483747914, 44.00456497746129, 44.98745210709111, 43.437923692887836, 44.01351190382435, 53.24401778559531, 62.25111722946168, 57.0303915392968, 53.52434958181074, 58.85646274012905, 57.596695500035445, 54.22186074718353, 45.81264034394295, 46.055650787968794, 44.85949654732981, 45.365717641768924, 43.965137312489176, 53.76009579627745, 57.79673637882356, 55.25173394910751, 56.17052562775151, 51.378562065862845, 52.936688315483835, 56.91516799311484, 64.25074938804873, 59.655563292964814, 59.22514592447589, 51.12043872956307, 48.91770232108332, 57.05540057151549, 59.92443392353674, 63.64484125568021, 64.71089440007364, 63.62844182598976, 62.81428329406246, 58.12530156104796, 59.80935550505116, 49.22274112701417, 59.49404793400919, 12.235045356135215, 12.518875906544348, 59.427536302997225, 8.38661970630769, 0.5482729476305747, 0.19756575595707665, 29.857399463653568, 76.11456594159527, 61.862912408767215, 65.68303815780148, 37.7962923819019, 32.147757699412686, 53.86777270224787, 65.3012111110072, 77.88924232605966, 35.93800283247425, 0.6471965329781656, 0.13609489155632837, 0.25598035854918344, 0.14331510170332848, 0.1410428849199126, 0.1516006796831085, 0.16520627864426182, 0.1788225109058042, 0.12245153978226647, 0.1392575782994109, 0.15816151795368041], [0.07601315140604012, 0.050406336949597445, 0.08007041434006346, 0.0504095315362417, 0.04864122440677978, 0.036997955833231254, 0.06548520342837419, 0.11609484862175681, 0.04441076814527473, 0.06920141167938709, 0.06872311234474182, 21.08556966627798, 57.54874060230871, 50.98706245422364, 36.27723293919718, 22.140165567398075, 25.35784859811106, 33.80528465394051, 47.08825003716254, 46.46085908336025, 64.36445889934417, 14.436251059655222, 0.11032642871742288, 0.1251273623277103, 1.2576805391619283, 3.8377163535164254, 34.51249976311961, 60.86167250910113, 57.93554513685165, 59.44169998168946, 54.46945251957063, 45.72050779096542, 41.009537250764915, 42.76711994601835, 50.07255008143764, 55.38444734388783, 54.80831392349736, 56.41311245579874, 56.84408680085213, 56.30802823651222, 50.995452404022224, 46.17275707183346, 43.57728550511022, 41.40933659768874, 43.206146917035504, 46.38303533677132, 48.28723622906593, 48.784188762787856, 49.24791097640992, 50.46294750705842, 49.83101444859659, 50.80027526424777, 49.40187577278384, 45.389734314334014, 40.470560443016794, 41.768241313196, 50.051114328445934, 50.96212402466805, 51.877318889864036, 52.15421861217868, 52.61766233751851, 43.58963312641267, 40.28203956542477, 40.88597866796678, 38.42108280427995, 39.20612558241814, 41.187232386681345, 39.86047498641476, 40.598633673883256, 39.67561368019351, 41.83129341371598, 39.152828416516705, 38.89559545824605, 40.40309175368279, 41.19388472649359, 47.54917952322191, 50.09956736718455, 52.88542685970184, 52.69041445947463, 50.80339747090494, 47.191941815037886, 47.64589340456071, 51.55006377927719, 55.558722173014, 57.95215245216124, 58.74890742763397, 52.36333977791571, 51.27054391368743, 38.56888947948333, 51.91903329664662, 51.93326757800195, 47.145108715180434, 44.5088170420739, 49.549784429611705, 51.32049137546171, 48.98943462679463, 46.78436833043253, 45.9688683479063, 45.218260057510875, 45.287525192383804, 50.18209403561008, 50.75872167464226, 48.638092240979596, 46.64400239144602, 42.324684435321444, 42.3412956730012, 40.52875272689327, 41.8083514705781, 42.1343945687817, 40.290959035196614, 42.29019503439627, 41.14110531345491, 39.95644361742082, 40.653727285323605, 42.1233570191168, 45.581510759169056, 54.49381043834072, 56.07186625080725, 52.254439092451534, 54.92401599884034, 53.59690166288807, 51.66806436354115, 43.334753590245406, 40.79698008875693, 40.84859455785444, 41.20920550438666, 40.83592137982769, 43.487329867578325, 50.46869377936087, 56.87394780497397, 49.2621099564337, 48.21746510844077, 55.19210215537779, 57.62803523771225, 56.48656275964553, 53.990346770132746, 50.7619184063327, 43.78697149215206, 50.64216844497189, 56.247404083128906, 59.53855899072463, 58.96255893092002, 50.4106270113299, 48.93420373239825, 53.48876583960749, 51.77052059481221, 48.95248982214159, 37.38206655748429, 41.212672879618985, 22.062743863751813, 0.5412210776440559, 13.63173665538911, 9.260952299641026, 0.21570313271255265, 0.15769130850751556, 11.7284643842328, 65.20265763805759, 49.20937368946691, 44.5471425210276, 36.68710885509368, 21.051627435991843, 40.38298176180932, 51.37081146240235, 55.51730586636452, 28.078626163544197, 0.6740732262692144, 0.07459639436415128, 0.0543754767896908, 0.08677693189031656, 0.02103853640296767, 0.06985179734446349, 0.061328954273654576, 0.046104259128051425, 0.05532452566248756, 0.023406025795866887, 0.1174784647000413, 0.08873948827385904, 0.017404389575183872, 0.07434399137573858, 0.10480649709220856, 0.0369626353494823, 0.05418317339893791, 0.03638908830321124, 0.013254192515066075, 0.03214466242840694, 0.042831343823983785, 0.019509658562920747, 26.922925287677398, 65.64089621267011, 56.473097262843964, 43.348838821534194, 28.605835860775365, 32.140546421850885, 41.329355547505045, 51.725017178443174, 50.70232975867487, 69.95312644589332, 15.443527487016494, 0.1842744522277386, 0.3828039314718016, 2.524778443959452, 5.915122983917113, 36.94603235490861, 61.748010496939386, 59.66354531626548, 61.33175288477252, 56.774425506591804, 47.82638911278018, 42.884328211507494, 45.19256461051203, 52.56870723539784, 57.166893943663574, 56.96016150136148, 60.291097087244836, 56.92868448072865, 56.903471485261, 53.33217697758829, 48.47894991597822, 44.511892180288996, 43.08803650640672, 45.48462037117251, 47.779948249939956, 50.780781084491366, 51.971773485983576, 52.88371278393654, 51.6391957190729, 52.73774962271414, 51.001332036910526, 50.93929583026517, 47.756025714258996, 42.984611449703095, 43.6008785616967, 53.41963798769059, 53.53412020590998, 53.45998740965321, 53.275722303698146, 53.94109356787897, 47.05651414009833, 43.00549414850051, 42.30331144025249, 42.406340337568714, 40.691966472133515, 41.94537555017779, 41.32915158425608, 42.669943224999216, 43.31128997187461, 42.4968921753668, 42.32344496634699, 40.03728366667225, 42.637477767082956, 42.46528571651828, 49.19772032768496, 52.38037070920391, 55.732494938758116, 53.81402054140645, 51.969600492908114, 51.308889004491995, 50.59034609025525, 53.94752625496157, 57.006331720659816, 60.7847430629115, 58.43369399347613, 53.851267368562766, 51.69712520414784, 41.14636128948581, 55.15491024140389, 54.45402583768291, 48.50316270705193, 48.66554098744547, 50.66621649649836, 51.379628950549716, 51.5316717855392, 47.75459012677593, 49.279795923540675, 46.54475858134609, 48.77844249048541, 52.42998869188371, 53.139125762447236, 51.029200476984826, 48.23790457940871, 44.016269330055486, 43.05683012931578, 41.32717470968924, 43.360460804354766, 41.63175067593975, 42.11340596598964, 42.03127153458134, 42.552150526354396, 42.777843706069454, 43.3294976142145, 43.71780049416327, 47.42575430100965, 55.12566897176928, 56.658256669198316, 53.55674051469373, 55.19727183926491, 55.60405692746563, 54.754353877036806, 44.97726963412377, 43.78262550600114, 44.780543158131266, 42.79314094974149, 42.197215249461514, 45.99303407053794, 53.777193407858576, 58.16404281123992, 52.81175298075522, 51.00489354902699, 55.85976016136908, 58.7543006866209, 57.18569778626966, 55.55610987447924, 52.19396006676459, 46.59460406149588, 52.53198208347444, 57.08851714288035, 62.381889051006695, 59.68666376606111, 53.64898681640626, 54.56572317307996, 57.64145758844192, 58.81572500351937, 55.132756694670654, 41.96032762527466, 42.26520169165827, 25.599605844866847, 0.6517288317122768, 10.146164567239824, 15.192179064596854, 0.8875498776474308, 0.021967772326822725, 12.737185224410027, 70.29554936193651, 53.396546994486165, 46.376394764069595, 41.430242830707186, 27.77390310841222, 48.543547430346095, 59.907042134192686, 63.20809710410334, 33.45382851939048, 1.0250054179660737, 0.019149802167028673, 0.02853738038890785, 0.04632074791457384, 0.03732062440605895, 0.07377609039746946, 0.03538118089519201, 0.01943763480671952, 0.054318016364930145, 0.03456218693886073, 0.07848591468627415, 0.1851936504845658, 0.11251524150852235, 0.14281535190680336, 0.2840896719886411, 0.09488792609303229, 0.16491931742958485, 0.126489436013564, 0.1797915968082605, 0.16725862819340923, 0.1206170579779052, 0.1343474450010446, 34.28150746130174, 74.45161434911913, 63.3099453679977, 52.94092447526994, 32.333825134461925, 36.15652199714415, 43.13468133249591, 58.8952902824648, 56.590081953233295, 76.20337624703684, 18.05348534737864, 0.31574776516326014, 0.6325625375874582, 3.6076904256497664, 6.08102600420675, 36.06808823923911, 63.20602217028218, 63.754957875897816, 64.78262670578496, 58.97920154756116, 49.81582310891921, 45.25192576069986, 47.47626658408873, 55.4630712539919, 60.33753010534472, 60.83254498820151, 61.29669866254253, 60.26185189524005, 60.31993827512188, 54.935610525069706, 49.8212516692377, 46.82702802842664, 44.660993237649244, 46.27788443719187, 50.80998705279443, 54.748117308462824, 53.93616314857237, 56.11060357862904, 53.4291575800988, 55.393798274378625, 53.97759906707272, 54.07259887264621, 50.51635057695451, 45.049198058343705, 45.56802172814646, 56.10600263841691, 55.631588043705115, 54.96354172306677, 54.91934445596511, 57.09251011571577, 48.5372128025178, 44.716294734708725, 45.26734852021741, 42.54322713421237, 43.55953678008049, 45.62127967034617, 43.34899179397091, 44.29602061548541, 45.229474113833525, 45.34009279743318, 43.815153721840154, 42.73078310874201, 45.695985132648104, 44.33502858684909, 51.20149058680381, 55.10895183009487, 56.05000295946675, 57.047889232635505, 55.43612849327826, 53.93093855150285, 52.522682143795876, 55.69824088004328, 58.26917409896851, 60.300365647962025, 58.81379127502442, 55.95648188744822, 52.460018357922955, 44.636301917414514, 58.95069376114876, 55.56989700563493, 50.77745491458524, 50.79448584587344, 53.65278759310323, 54.99598364676199, 53.152301003856046, 50.83734558474634, 51.66964900109076, 49.41638462005123, 49.73945456166422, 55.14202133301766, 55.60033852054227, 51.773399614518695, 49.94480632966565, 47.050779634906405, 46.72778029595652, 43.445305593552135, 45.9994157668083, 44.528213162576, 44.017889268936656, 46.64243736574727, 44.865031011642955, 45.109673161660474, 44.86038692535893, 46.32001461521272, 51.10224677670387, 60.66993921033798, 59.406877179299634, 55.740873121446185, 57.66559193211218, 60.318694883777255, 57.90573120117188, 47.59424363413165, 45.350993064142045, 45.63536097926479, 44.77074899981099, 44.528436737675825, 47.64575219923451, 55.63218816634148, 61.1886412866654, 55.48329891697053, 52.49842620665028, 55.52144396689631, 60.67264564575688, 60.57851660636164, 57.568274005766845, 55.60735171841037, 50.90784234385337, 54.86809476729363, 61.17268900717459, 64.00050609342514, 63.69396894208847, 60.92693290402813, 58.49564783034786, 61.33054087238928, 61.61122175955004, 62.199118368087284, 49.83902392848846, 46.52547228720881, 28.313168210368005, 3.00308084295642, 18.682968885667865, 17.077430986589004, 0.9770200605834685, 0.296888641652561, 15.036963032137963, 76.38952409067463, 60.29144617819018, 57.46198169646725, 50.314199463013686, 32.59416264872397, 55.10805752969558, 66.86092592054798, 73.11021866336947, 43.24949302980977, 1.3060824645142401, 0.10618556260822282, 0.12957162223756313, 0.15732294279000453, 0.1536517115610261, 0.28458796621811006, 0.15590388748434283, 0.07523897359327925, 0.18381509058658155, 0.13654297638324, 0.18110592789467306], [0.06079058981530609, 0.004267736493925294, 0.07961251592684178, 0.02363650717832629, 0.039345199437511545, 0.017959908657376806, 0.05763415434968568, 0.04347705252228245, 0.07744165257580819, 0.06333959799620413, 0.08018194908095945, 23.69268282767265, 58.9086224186805, 52.29673401001961, 37.606414364230254, 20.923783663780462, 29.22371114453962, 27.462741482642393, 43.14443234474429, 51.258474780667214, 59.98855683111376, 10.441861268012754, 0.20498000085353854, 0.07841592489351189, 1.6102951212275414, 3.5780179404443313, 34.77456508144256, 60.934867858886726, 56.4082722510061, 59.026815199082904, 50.271520153168716, 47.45247348662346, 47.58837969072404, 51.83451014180338, 53.01839128617318, 55.253259751104544, 59.16825194512645, 53.31223172526206, 49.03714241520051, 54.920191687922326, 52.12005869034798, 47.65233001401348, 42.09621029515421, 41.48026089514456, 42.188319313910704, 46.51893761850173, 48.82155326104934, 50.53384827029321, 48.40116539309102, 50.958083983390566, 51.241855698247115, 53.18692768773725, 50.98457959390456, 50.75743905959591, 47.339368020334554, 44.80298696025726, 45.32821586055141, 49.56414422681255, 52.34140196154195, 51.34166825202204, 48.87801970205, 44.43900669774702, 38.09560844975133, 39.35590913218837, 37.50573104427707, 40.51367121358072, 39.82607972237372, 40.02275912992416, 39.890057502254365, 43.20723733594341, 39.8829540898723, 39.32481650383242, 39.390280862008375, 39.237955616366484, 38.99536486594908, 44.330800271803334, 48.68286217412641, 52.970812935982984, 52.095885122976, 51.510294868100075, 52.662636233914284, 51.346006393432624, 52.74483342324534, 51.58024249538299, 48.715715946689734, 57.6235362791246, 57.087830728100194, 50.814478166641734, 41.01629157220164, 52.2923997909792, 54.830353721495605, 48.1922128892714, 42.60810313686248, 41.641282035458474, 43.5788897545107, 43.65837266368251, 44.719271813669515, 41.835890431557935, 46.39083300867389, 48.59007850770028, 49.266287280667214, 49.28206305350027, 51.5707621266765, 47.22209699692265, 40.78786842284664, 40.45759308722712, 42.107895035897535, 42.20445594479961, 41.89043883354434, 41.72467162532192, 42.81635745879143, 40.72392594429755, 40.02447712805964, 40.58484262035739, 40.84915937915925, 40.94846986955212, 49.36777076413555, 54.72797593762798, 51.06745535327543, 52.28855979058051, 53.85546038227697, 52.57779144471692, 48.43342688775832, 41.626055394449544, 41.791857904003514, 40.96686970803046, 41.62690654877694, 41.73624653970042, 47.51995002069781, 54.98604436074534, 54.819959440538966, 58.78331053641535, 54.184586463436005, 54.71872698876166, 53.998905381848736, 45.52165539033952, 41.40219396160495, 47.36715016826507, 54.830459625490256, 57.161618355781805, 57.60104933092671, 48.30255308458882, 49.35988680008919, 57.961777948564105, 59.51668393227362, 58.09524836078767, 58.95153707073581, 46.443392768982925, 33.559905098330596, 30.35975898465803, 0.6635530004578253, 3.187825703813184, 6.086353563493298, 0.4751500697626222, 0.04543784690359908, 7.462692664515588, 60.921445508157056, 54.40838906072802, 48.75503378529703, 33.61668140657487, 24.88713279847176, 47.160727593206595, 55.47527766996815, 52.24305637421147, 26.95716169572646, 3.645229224235781, 0.037156815655649676, 0.07484830705629242, 0.01686124089774826, 0.021705073116707708, 0.06760230272888176, 0.04407336387122351, 0.029057465989383, 0.02978521504349286, 0.04195167953448911, 0.06356105486291551, 0.05097804921528986, 0.06477319365066868, 0.05012429784983397, 0.03884617742451449, 0.009916828149148535, 0.015598928139004258, 0.08073171675806085, 0.024051447211193944, 0.006270859627083185, 0.012619302893478065, 0.11390714665814755, 31.11830419109714, 65.81417083740234, 56.87785840803578, 43.660992806957616, 21.90649428675252, 28.90300443095546, 32.46499899894961, 48.21250331017279, 56.36855433064123, 65.88158069118377, 11.63721436454404, 0.5271499423730759, 0.7773579969521492, 5.111836281514937, 4.53660402567156, 36.50215341198829, 62.26876005049675, 59.6818627849702, 61.00818480214765, 50.409552281902684, 48.851794735077895, 49.741666778441406, 54.771631917645855, 56.336281068863414, 57.760485833691014, 60.35338432558122, 53.99791694456532, 50.93229439950759, 57.42532714720696, 54.49619916177566, 49.80487577376827, 44.528115103321696, 42.317875200702304, 44.67143066467778, 48.44470370200373, 52.26029911348897, 53.393444399679865, 50.66574973444785, 51.2577687540362, 55.08610402384112, 56.26756506581461, 52.17483066743421, 54.99010793624386, 50.369077344094556, 46.26390510989774, 47.48128721790929, 50.742079058001124, 55.18485361529935, 53.88374851595972, 51.02246576739896, 44.2532197121651, 40.56992584659208, 40.715838017002234, 40.88104432629001, 41.743753956210234, 41.25877249625422, 41.9029825733554, 41.99811573951475, 45.328619864679155, 41.561497103783395, 42.213077314438365, 43.21900444646036, 39.68561572413291, 40.08340289515834, 45.44006616838517, 50.96389301361577, 56.53216423526887, 55.097329847274295, 53.02458470867526, 52.7878265227041, 50.85769876357048, 53.75770707284251, 54.427188980963926, 51.18036077868555, 60.38074285753312, 55.983424648161865, 53.74401015620078, 42.35195275275938, 54.73549119887814, 56.90777432534003, 51.14936228721373, 43.81888389587403, 42.20354595491963, 44.672630909950506, 46.44725630360265, 46.35082483291627, 45.38414101446829, 47.82437693688178, 49.87355647548553, 49.60277957300986, 52.66685278184953, 52.1096997107229, 48.417521676709576, 42.96771387900076, 43.01557463984336, 43.777161644351104, 42.14426325213525, 42.822393986486624, 43.06479254076558, 42.44157106645646, 42.58875016243228, 40.8811306184338, 42.831999871038626, 43.79942893981934, 42.54813009692777, 50.78496625346523, 55.98316969410066, 53.590406217882716, 55.10117769241334, 54.427636131163574, 54.889012767422585, 50.04086909755584, 43.28989344258463, 43.84070404114262, 43.537461680750695, 43.01722988005608, 42.83104673508675, 49.04070784968715, 57.368868550946644, 56.87370069565312, 59.78396992529593, 54.93163324171498, 56.474768192537375, 54.44032499867102, 49.12877290479599, 44.52111367256411, 49.855646933278734, 56.46753534193962, 59.68291398017638, 58.85454470111478, 53.15470149440151, 54.7764289763666, 60.25500735928936, 60.80750849939162, 61.12821717416087, 63.79602901397213, 51.76260917417465, 34.57727770651541, 33.72136946647398, 0.49786727334703174, 3.635701296790954, 6.515733465071648, 1.3137196869619432, 0.1644469782589905, 7.291216446507362, 66.00259365574007, 60.328481197357185, 51.41144329501737, 38.4238951436935, 29.495851070650165, 54.49906249200144, 61.593014117210146, 61.27041093764767, 36.066401620065015, 4.194964112774018, 0.03944330848753452, 0.03947123239237455, 0.027191419447321567, 0.004776362855468066, 0.011316585699997602, 0.029886650830327027, 0.043486218764296466, 0.013827931083318208, 0.07360096269797894, 0.08593990422424772, 0.139191449589787, 0.09488217277272094, 0.21319633980672206, 0.12268482121608912, 0.07956402256123482, 0.14216160311573936, 0.2647871061438515, 0.10139581236627795, 0.119409098199779, 0.11135243495265323, 0.2872827264570421, 41.92259442421698, 74.83510448086646, 66.40721751797584, 51.00236362026584, 29.769508954017397, 42.625875396113244, 38.1826066201733, 56.875638346518244, 61.096285158588046, 74.36940931504773, 12.804812769736014, 0.37730535071703697, 0.2695733783466201, 4.1276498667655455, 5.628143750852154, 37.09380765115061, 63.17250943952992, 61.43959845266035, 64.60531596214541, 55.01037874529439, 52.92628618978685, 52.13865464733493, 57.12427739174136, 57.47088547675841, 59.860977818889005, 63.18215454778364, 56.98315051294143, 52.81137643321868, 59.26237313978134, 57.42737462443691, 52.38784282438217, 46.589693254040135, 44.83989254120858, 48.11523245226953, 51.1490406528596, 55.365055145755896, 55.21626787800943, 53.06278074941328, 55.3546412529484, 57.360878682905636, 58.57316563206335, 52.20236178367369, 55.93112768665437, 54.104946659457305, 49.29038240063576, 49.33728610315631, 52.91753538193242, 56.37508115460796, 55.7003628823065, 54.753553713521654, 47.7551745599316, 41.46837611352244, 42.30829285037133, 41.12782416805145, 44.96848352493779, 44.24099760670816, 43.38945496466852, 43.35904875109273, 45.98467157733056, 44.11025324175435, 43.57652456529679, 44.6310341742731, 42.53320940079228, 42.0654236116717, 47.50467238887664, 53.57942358140023, 58.49982123221121, 54.71924474162441, 53.58178877061414, 56.80463560165898, 52.63486585309429, 56.87942343373453, 55.344356798356586, 54.794879805657175, 61.25134037386987, 57.35069228756813, 54.69431807917934, 45.75939024648359, 56.774621625100416, 60.01780594548872, 52.68205196626725, 45.661307457954656, 43.99771651914043, 46.668513282652825, 48.70536481180499, 48.264341354370124, 47.63560502759872, 51.210888585736676, 53.486773275559955, 54.29365188844743, 53.1446994504621, 55.615722056358095, 52.204507320157944, 44.886702106845, 44.838774665709465, 47.26895363100114, 45.094752465524984, 45.42380009928058, 45.16624942902596, 45.96188652899958, 45.59091660284227, 43.120243087891616, 44.839057076361875, 44.246665431607155, 44.05874859902167, 53.92902835722893, 59.65020141293926, 56.21956702201598, 57.86684874565371, 59.0593747938833, 58.36145570201259, 52.27607096395185, 46.103695900209495, 47.15187872609785, 45.022992703222464, 45.61505486888271, 44.89941450857347, 51.477743118040024, 60.299388977789114, 59.82555881623299, 63.490444998587336, 58.27857209790138, 59.719564607066495, 57.97701635668355, 50.95005881401801, 46.70879210195234, 52.76728114774151, 59.217112910362985, 61.7343645711099, 62.32519119016586, 57.768275660853234, 56.70149687797793, 64.70560704508136, 62.903776091914025, 63.75018827376827, 64.086045142143, 59.38343709514987, 38.376571747564505, 37.24160648161365, 1.2775545759547142, 9.933998661656535, 12.566870027972806, 2.0311680147724767, 0.28287104060572965, 9.420098547012577, 72.12928095171529, 66.4651587701613, 65.0582516577936, 43.208441503586315, 35.541380605389996, 64.31472716792938, 68.54579571754702, 72.31061212478146, 44.32696811614498, 5.7116318902661725, 0.24627039329178874, 0.16068688083079555, 0.15192075121787288, 0.1526499596694785, 0.18847354868006325, 0.14478497928188694, 0.18226006999611857, 0.09652026027681367, 0.2299787521722817, 0.14651989263872947], [0.07387125383942358, 0.03297444673315172, 0.027010300940263177, 0.02275458867511442, 0.04058025574551956, 0.015807073270421357, 0.013564334592721878, 0.05924577351599451, 0.04076386786877148, 0.07495126161243647, 0.24764329946089178, 21.871928399608983, 54.85854771829421, 49.04788970947266, 41.490702244543264, 23.98224788327371, 29.557785295671035, 31.55311461417906, 39.51720876078452, 52.89018077235068, 57.32266695268693, 7.237091660499574, 0.4031270490058007, 7.978739786532618, 1.2575985371105134, 12.773475973836838, 41.38772041566911, 63.726454011855594, 56.62424579743416, 55.52904944266043, 50.75597601552164, 53.997814962940836, 53.90804759917721, 52.62231819091305, 53.97287261101508, 59.57855147700156, 52.06454930766937, 47.41537963190387, 53.97047604283979, 55.234075438591745, 52.09419065906156, 46.696640599158506, 41.927560144855136, 40.50299452197167, 41.28451501169513, 45.91336680996803, 46.72542687385313, 51.033585686837476, 51.706778157141905, 53.46446675638999, 51.480147530955655, 52.7007891285804, 53.9962185582807, 52.81621663801132, 53.03218233969904, 51.31291335628879, 48.35720346819971, 49.55266344931818, 49.39260328969648, 50.08416421951787, 46.34181907100063, 43.203005098527484, 39.84396180798931, 41.49933538129253, 40.1740724040616, 39.66976542626658, 39.573628133343114, 41.726264107611875, 40.65178571208831, 43.05228017991589, 40.70046232592675, 39.418059087568714, 40.06304971633419, 38.31716352893461, 40.15240130885955, 42.49718635312973, 50.68405935841222, 52.210155533206084, 52.204217064765196, 49.172295524228005, 55.58989324877339, 55.41045658050045, 54.68707738384124, 56.50893988147859, 55.91024498785696, 47.06546891120173, 57.45400751790693, 55.859736627148045, 41.16522789001465, 53.00039545182259, 53.902991664025095, 53.382591201413064, 50.07780605746854, 41.689668393904164, 38.3350730711414, 43.80061349561138, 42.57179375617735, 44.920014796718476, 46.57880867681196, 48.21592361696305, 50.62515712553456, 52.13079029513944, 49.461487954662694, 40.63735138985419, 39.38850795069049, 43.1566152264995, 41.25073948214131, 41.0569037929658, 39.01680846368113, 41.58193265238116, 42.39064693450928, 41.404821949620406, 39.578707602716264, 41.484018525769635, 41.821915026633974, 40.04763087918682, 44.22775568500642, 50.1114756830277, 52.30807750455795, 54.55092407041981, 53.86158320211596, 53.78723859786988, 50.434278903468964, 46.28011626581992, 41.2807926824016, 44.30606188312654, 42.81293715200117, 41.73439910334926, 45.00880549030919, 54.17631810711276, 55.60436679470924, 55.82121895205591, 53.21730644472184, 49.848943602654245, 45.601707043186316, 40.04184930555282, 43.03957170055759, 52.824457537743356, 54.265810904964326, 57.216068698513894, 48.34338103571246, 51.427019026971635, 54.533642107440585, 55.310608725393976, 58.45919332196636, 60.046996224311094, 56.10643409913587, 55.604613904030096, 38.09780105467766, 38.13209825946439, 2.9303309273335243, 4.052416600527303, 14.908838810459262, 1.8056460710302478, 0.05771208081334349, 3.0062145715759647, 53.78619132503387, 55.761645993878766, 46.103433101407944, 33.90585030278852, 25.10857609010512, 36.29534644465293, 47.847699349926366, 56.861172645322746, 41.16910711411507, 6.6977020232908195, 0.1108687193763833, 0.02214016509242356, 0.03136738962043197, 0.033494306337689204, 0.06451649290900077, 0.008984938688245753, 0.02381156018424419, 0.05446660677872358, 0.02219784959790207, 0.049842159158640334, 0.03492579908080159, 0.009007820776934105, 0.029049667214313825, 0.036159043590868675, 0.0481101262923931, 0.032482411442024094, 0.03655286257966392, 0.05781588189664388, 0.029807232410436677, 0.03081468399614096, 0.2868055149672493, 30.787424810471077, 63.902933213018606, 54.51972553806921, 50.01121205668296, 27.389497103229647, 33.91839796496976, 40.256100931475245, 46.96821374277915, 58.58181053592313, 63.30332440714683, 7.311487745854163, 0.48534685325238014, 8.394785100413907, 3.8532403592140447, 13.412867419181334, 46.290840025871034, 63.21752255962741, 60.45240063821117, 56.68901981845979, 54.16475495984478, 55.536615694722826, 55.32315246520504, 55.077098261925485, 55.986135005950935, 60.888893758097005, 54.99461081720168, 49.031788379915305, 53.285563530460486, 56.3003090120131, 54.02476164602465, 48.587744697447754, 45.33560168358588, 41.57331128274241, 43.92829448946061, 46.89349259099653, 49.687185056747936, 53.911746394249704, 53.13740384194159, 55.50218905172041, 53.97987404177266, 53.9524958979699, 54.39193079548498, 55.086935566317656, 54.91820304624496, 53.33032169649678, 50.53373452155821, 51.487902056786325, 51.49760992296281, 52.49729264167048, 49.72066248616865, 45.022400425326445, 39.37701932845577, 43.516033772499334, 41.00200630003407, 41.240678602649325, 41.48628565572923, 42.944069831602036, 40.60238345976799, 45.32983972180275, 41.957138738324566, 42.18206705585603, 41.124619591620664, 39.93402727188603, 40.76990788982761, 43.91458972807854, 52.33604792625674, 57.81005282555857, 54.36848678896504, 52.397044704806426, 55.98912777439241, 57.351770939365515, 57.137797801725334, 58.50167259093254, 57.03931493143882, 50.57362894858084, 58.57637020849413, 54.97470478857718, 45.93032321622295, 53.78907034474035, 55.554442867156006, 54.492245412641964, 51.78678274154664, 41.72821352558751, 40.553193015436975, 43.171614370038434, 45.453111971578295, 47.80829129680511, 48.74862071006529, 50.56401914165866, 52.059081523649155, 53.59727428805444, 50.86583768167804, 43.0372182784542, 41.769210138628566, 42.64902914724043, 42.83659688888058, 42.258808228277395, 42.377828628786155, 43.12774658203126, 44.81677801378312, 42.59191943753151, 42.64508716521725, 43.404175619925226, 43.377381909278135, 41.5082509286942, 46.1732199115138, 51.49245985092656, 54.53165346576322, 54.46622833128899, 56.476678386811294, 55.73581718629407, 53.44368996158723, 46.450382432629986, 43.09340623117263, 45.98457351807625, 44.287540451172866, 41.98962773046186, 47.09120358190229, 53.75063503942182, 57.9903837942308, 57.523723725349676, 55.94887248931393, 51.896271782536665, 46.301693224137836, 43.40390497638334, 44.61537999491538, 53.86172440744216, 57.467069010580744, 59.9732635098119, 53.715600429042695, 55.7667136961414, 56.69249896080264, 57.99065051540252, 59.63712423078476, 61.894844424340036, 59.55407196475614, 61.68696272757746, 41.42347674215994, 39.42975559542256, 3.2036213336452364, 2.450140887691129, 15.73320629135255, 4.087474990275599, 0.05582481938143892, 3.5374145450130587, 59.86453933100547, 61.939347636315134, 49.73986248816214, 31.125480167327392, 28.94241640644689, 42.295301960360625, 55.40506724388369, 65.66504624582106, 49.41469407850697, 8.911583846615208, 0.14628546973389966, 0.015079999331294771, 0.04855620013850351, 0.057698674274668585, 0.002198575863486997, 0.04041982161241674, 0.05779998174177543, 0.024401049520219528, 0.035435458224627285, 0.032251470406810125, 0.19733600618858493, 0.14018292058139079, 0.11110849723580385, 0.10778771292778755, 0.17668938504592066, 0.18196091266168704, 0.12054289300595561, 0.15213905563277585, 0.1421562558220279, 0.11706876853901534, 0.4324815770791423, 38.2527268317438, 71.11022564672655, 59.840044129279356, 55.65908385861305, 35.086566094429266, 41.09271503263905, 44.18516266730524, 53.08388702331051, 62.84667030457528, 70.86306141268823, 8.801106368341754, 0.5475591988332811, 10.696094593694134, 7.27007830335248, 17.98886625997482, 50.993224497764345, 65.64245339362853, 61.63281832971881, 60.05955173123268, 57.17107911263743, 58.37164994209044, 58.59589968958209, 55.87108796642673, 59.44776788834603, 64.18929761455905, 57.073631748076416, 51.51773560431696, 54.35897504129718, 60.03342090114471, 57.35702299302625, 51.30237394763578, 46.84640453707787, 43.91300509052892, 46.46773892064249, 50.47391837643039, 51.16389859107233, 56.911433896710804, 54.80340703841179, 57.52528090630808, 55.96544058092179, 54.527899757508315, 57.02106806539721, 58.06008823456303, 57.581896397375296, 56.90262425330378, 53.78854082476709, 53.83851966550274, 54.65440011793568, 55.496219204318145, 51.61530848472349, 49.39135205361151, 43.47843000965734, 46.7410457518793, 43.07468083596999, 43.24175419345979, 42.52101867429672, 45.1255234595268, 44.464149090551565, 46.734973922852554, 44.20124438501174, 44.15482313402238, 42.67051981341454, 43.063874706145256, 43.935315532069055, 46.941031717485004, 55.517651034939675, 56.71513495906707, 56.56112309425109, 53.94018750036917, 59.7430125359566, 61.34847787118728, 57.84649164445939, 62.81082768594066, 59.78893564593408, 56.18781935784125, 58.96343361946845, 54.71728355653825, 49.25656372501005, 56.22053584744854, 57.942777987449404, 58.89997359245055, 54.24725809404927, 46.29662159950503, 42.23437186210386, 46.95652115729548, 45.68956029030585, 49.34080839157105, 51.70247531706288, 52.65683112605926, 53.95932866681007, 56.70264221006825, 51.91971186668643, 44.30139034025131, 44.525389056051935, 44.97079772333945, 45.84179924380395, 44.600302403973, 43.02638861440843, 45.188524569234545, 47.68232045635101, 45.800292722640506, 44.512284417306226, 45.531002398460146, 44.659832216078236, 43.63101413173061, 48.88538983560378, 53.695380610804406, 56.33964254010109, 58.10949440925353, 59.323777844828946, 57.46939497609293, 55.02245964542512, 49.151628555790076, 45.93194707747429, 48.976024043175485, 48.29947402400356, 45.459615261324, 49.08782336019701, 58.94188804011191, 60.068996798607614, 60.64846423364455, 58.66340368024765, 53.67820455181984, 49.802518429294715, 44.94896188859017, 47.27398210956205, 56.49439181050947, 60.36520634928058, 62.5895393279291, 57.87680372115105, 57.66576843876993, 60.05753563296411, 61.674258170589326, 62.44159144739952, 65.01423874209004, 61.210779143917954, 64.31831613663705, 44.768262217121745, 43.69180694703133, 4.411349017773905, 8.679378551821555, 26.984843823217577, 4.674320403606662, 0.2143313909970945, 4.015751264749035, 65.79517087628766, 66.09500469699984, 60.1017564342868, 42.64943707373835, 36.12626091126473, 49.68526701773367, 65.91110829384097, 74.15791511535645, 58.04719540380663, 11.202622613599225, 0.21639422062904606, 0.1791860962346677, 0.17521190787515334, 0.14473352881689228, 0.1655053746916594, 0.09792504336444602, 0.13453404869764082, 0.1755735320189307, 0.1966462972303552, 0.17915874689577088], [0.04256160809628425, 0.09236489212320698, 0.006111023521366259, 0.06356210440337177, 0.04097338908562257, 0.022237611476392038, 0.01625637617713261, 0.02189214987259719, 0.10089967084387619, 0.12334300565623468, 0.19797064874681736, 32.4784311556047, 55.780720480026744, 53.00499639203472, 36.30486211469097, 19.517135427844142, 25.29541427089322, 23.935130411578765, 40.96303755237211, 54.50440476017614, 51.49434651097944, 5.132221329596735, 0.3500213131548897, 36.368530027328, 31.283618365564656, 0.7835724409068785, 23.476775961537516, 57.316489219665534, 59.045548439025886, 55.92991567427113, 55.80725531424246, 53.45007558022776, 59.98901574842392, 58.93305878485403, 55.960196372001406, 52.25572955223822, 47.589070027874364, 49.93212138452838, 54.96542838311965, 58.067642719514915, 51.676042464471635, 45.47641869514219, 40.73704235015377, 40.52347713901151, 42.77602764867967, 45.733404544092, 49.10972195286905, 52.4464391123864, 51.10179178176388, 51.79832627696376, 52.96314862466628, 52.84925083960257, 51.295356827397505, 52.06218411845546, 52.16054539526663, 53.56650329405262, 51.42821534987419, 50.37423526087115, 48.176499874361106, 46.58100520410846, 44.31294172040878, 40.63200519930932, 40.55455800025694, 39.33387717893047, 38.61634623619818, 41.09619417498189, 41.58887524758616, 42.22615841896304, 40.83639598661854, 39.456494392887244, 41.302063695846066, 40.0036689542955, 38.454466096816525, 38.40588361986222, 40.36668431374335, 37.79356241226196, 43.476206025769635, 49.95591448199365, 53.751093956731985, 54.54069845138058, 54.47198244833178, 50.72032559302546, 50.88708908327165, 49.13047913582095, 53.22180540330949, 53.92237993978686, 45.72939588177589, 60.08825563615369, 44.482996079229544, 52.246127590056396, 55.40882879687894, 53.4734058380127, 54.025808918860655, 50.51662906523674, 41.782334389225134, 41.5822817433265, 44.71797743151265, 47.6785392915049, 50.54817276616251, 49.69244103277884, 52.5304719709581, 52.924187721744666, 48.227137673285704, 40.50539109014696, 39.34413809930125, 42.109640490624216, 41.57311124186362, 39.660661605096635, 40.35560754037673, 41.21874470864573, 42.09788514721779, 39.726145575123454, 40.907422265698834, 39.69418218058925, 40.02453988598239, 40.65422150396532, 41.0168642382468, 45.136451182826875, 52.877852762899096, 53.12914725272886, 53.13385409693564, 53.2873325194082, 51.57402553865987, 47.553945202981275, 44.03638716666929, 42.87767194932507, 41.82766129893642, 42.004152267209946, 41.85194469267323, 43.94102650303995, 46.92690334012432, 46.22467356343424, 43.80499870546403, 41.098610355008034, 41.91153726270122, 41.02199469843219, 47.90005122461627, 52.311725308818204, 57.167074372691495, 51.659815619068766, 48.03262341407038, 59.01063934449227, 56.348958169260335, 57.09665998335808, 59.028168416792354, 63.797927441135535, 59.85410190397694, 61.45733541057956, 55.08606087776923, 55.64673231494043, 10.26751289444585, 3.9316431456996552, 26.510442956801384, 5.786747730547383, 0.19107058674337404, 2.1720063542166064, 44.5704492445915, 58.92003651588195, 46.01492874083981, 55.26414040596255, 20.547094921911917, 33.281079492261334, 56.26114414584253, 52.438068774438676, 50.40581426312847, 11.454079881791147, 0.09853881768762104, 0.04869680408568633, 0.012819529548587819, 0.03274947352286789, 0.04629915955686762, 0.0539653248063499, 0.03648528979430276, 0.04084947819430982, 0.09475461913332825, 0.041437033158276355, 0.04451039787982741, 0.025761983650285872, 0.0330624089486176, 0.06600506303291168, 0.025819357890155048, 0.027348080597397302, 0.049138970883382906, 0.05576502238850921, 0.0927262787797278, 0.06150567926646722, 0.38730292070296507, 41.04292054330149, 63.592603129725305, 60.07330356105682, 42.873235748660186, 23.355692394318122, 24.631649217297955, 28.216915207524455, 47.42797436252717, 56.12107630698912, 57.80021944353658, 4.726738958589492, 0.24739012272367555, 30.327872076342185, 22.69063884212125, 1.6908531275487717, 25.649621948119133, 60.987945372058505, 62.014237450015166, 59.325542911406494, 57.629980733317716, 57.390618093552135, 60.32730056393532, 61.42322255719093, 57.889418063625214, 54.01827796812981, 48.53505157655286, 49.378961286237164, 56.13444374453638, 58.720725197945875, 53.98487898611254, 47.81777951025194, 43.58485960191296, 42.12231366865097, 44.545714778284875, 48.144893415512584, 51.09857936059275, 54.31299701813729, 54.530625804778076, 52.21969865983533, 54.204198314297585, 52.769442373706454, 51.76251503729051, 53.50256081550352, 52.564792709965865, 56.62580690076275, 54.9275069082937, 52.75793413962088, 51.46877265745594, 49.998056427125015, 45.947738539788034, 42.160344969841745, 42.482089150336485, 41.777094102674916, 40.97624417274229, 40.77661906519244, 42.60820904085713, 44.21169750152096, 43.43305210913382, 40.919844412034564, 44.125593631498276, 40.941864598181944, 40.934765108170055, 41.98560730103524, 42.49083995819092, 40.42952068390385, 45.709638903217936, 53.516885311372825, 54.65820089463265, 55.764583849137836, 56.504217347791126, 51.98840041314402, 52.78256270193285, 52.26507656035885, 55.618985468341464, 56.24188923066663, 49.75303380720077, 60.33716924728886, 46.115372796212476, 53.742574568717714, 57.37224178929483, 55.39847373962403, 56.19232616116924, 52.37314178097633, 44.67846347439674, 44.46729090905959, 45.99166124097763, 48.86306762695313, 53.381300741626376, 51.75878486325664, 53.88289343926215, 55.6229902082874, 48.64485832952684, 43.94698850570187, 41.363872405021425, 44.06912326812745, 42.82050732643374, 41.27263415244318, 41.58366241762715, 43.16368725992019, 42.992919029728064, 41.98319504337926, 40.98219833066387, 42.39680505567982, 42.43754671465966, 41.53041624253796, 43.20101253447994, 47.54621813374181, 54.65349405042587, 55.44326328462171, 53.95343726681125, 56.19480117674797, 53.2908038170107, 50.44678341957831, 44.453699896412516, 45.04246727112801, 42.07594340847385, 43.85364786271126, 43.4878711546621, 45.31659387773084, 51.18563244419714, 49.30448332140523, 45.327494144439704, 43.50336843921293, 43.36004111074632, 43.26193478799636, 50.69193940008841, 55.27835507546702, 59.53187134958083, 54.64114250675325, 52.84082166610226, 60.12399235079366, 58.87153640870125, 59.922268775201616, 61.83636972981115, 66.19205982454362, 61.36423795453964, 65.22349326841294, 57.30209019876296, 60.52662757135207, 11.42266954145124, 1.1667948096029221, 34.600627576151204, 11.564928024045884, 0.11490001192977352, 2.0710011547611606, 49.98025278891287, 63.16537464818647, 51.99118529596637, 56.167752512039684, 30.254865000324866, 41.79647453369633, 58.964931964874275, 61.73938912730064, 58.78342820752052, 15.44155159304219, 0.15928831071622912, 0.008269864558843116, 0.0553239434356651, 0.031447681380555995, 0.01642263640889958, 0.06355848463792955, 0.03136924163798892, 0.040528812941404126, 0.03795027973190431, 0.09903861344942162, 0.14966259980874677, 0.17473158606838796, 0.09775425172260693, 0.13612159738136878, 0.09036472848346157, 0.11002664319089345, 0.2101518757521145, 0.13830287952817258, 0.2477645405357884, 0.17017812798580817, 0.5371001987688003, 52.64085138997724, 71.79470277601673, 68.0761468025946, 47.78138383742302, 29.400531591907626, 34.734890307149584, 36.56463284646311, 52.93076945889381, 63.47363372002879, 60.99218545421478, 6.452000343030499, 0.1912540954447562, 46.26943172947053, 42.92817246529364, 1.1460504969281535, 31.093075506148804, 62.265618231988725, 64.34934600707024, 62.2898074888414, 60.402323738221206, 57.00970888137818, 64.70603066105997, 64.21403208086568, 60.631652955086004, 56.38999008363294, 48.960887616680516, 51.09380583609305, 58.005084837636645, 62.12198495864869, 56.857877854377996, 50.52866681929558, 46.018545166138686, 45.33756286867204, 47.32064654750209, 49.692284137971946, 55.36248207092286, 56.577244035659305, 55.6209348863171, 55.574054718017585, 55.38921694601736, 55.694518550749756, 53.87305613486998, 54.99743884609592, 55.39691263629545, 59.67190388710269, 57.18592136136947, 55.10766921504852, 53.916127681732185, 52.62419700622559, 48.82809969686693, 45.00290232319986, 45.529719783413796, 42.908697897388095, 42.606761686263546, 44.25347074385613, 46.0706538538779, 45.91085649305775, 45.673878654356926, 42.6777801206035, 46.074372260801255, 44.1022829855642, 42.304056690585234, 42.14077626505206, 45.60815149737943, 41.694355626260084, 47.25598627521146, 53.488095114308024, 56.51936946376678, 57.92497042686709, 57.85733307561567, 54.245751903903106, 56.04519021126532, 53.61719600615963, 56.945382010552194, 57.21555094565115, 53.030872268061486, 61.41033757117487, 48.331413884316724, 56.50748860451483, 59.48989806636688, 58.66514521260416, 58.66500400727796, 53.87720208014212, 46.571846469756096, 48.69693563830469, 49.28715428998394, 52.13635613841396, 55.33532357984974, 53.87032616523005, 56.14278662589289, 58.670307051750925, 50.826033469169374, 45.133438802534535, 42.87608731177546, 46.33058148045694, 43.82959981118479, 43.10952717258085, 42.6857150754621, 45.96808779624201, 44.12105544920891, 42.72746086120606, 44.708787318198915, 45.02553047672395, 44.11643489714592, 44.61319915709957, 45.75256532238376, 49.17937540238904, 57.668525865001065, 58.19224857514905, 56.30266635648666, 57.754719949537716, 55.442055194608635, 51.85216865231914, 48.15803727796001, 47.06984235394386, 46.22416757768201, 46.81107574893583, 46.03590557652135, 48.24302719485376, 52.601270752568404, 51.11745380586194, 47.921079051110056, 46.45037066551947, 46.22770163320726, 46.375151372724964, 53.69541591213596, 57.01086990294918, 62.98005834702523, 58.9706233239943, 53.812031899729085, 62.61447383511452, 61.164710906244096, 62.07619520925707, 66.12454798913771, 68.58203057319888, 65.1542869690926, 68.98377541572818, 60.27218341827393, 60.09155042709843, 13.526582814032032, 6.3244066219176025, 36.57273254086895, 8.669043106417503, 0.24689607262130708, 2.722137647290384, 56.85461444239463, 69.75896127762334, 60.41826032823133, 68.32273837058776, 31.221138931089836, 48.13061206571518, 69.87218441501741, 68.74323214254072, 69.43037648354807, 18.62370579473434, 0.3430255514479453, 0.10565473262460963, 0.17184472162156336, 0.19150883500133792, 0.11083421477627371, 0.1636929332368797, 0.20579467407397686, 0.16268728961867673, 0.1909574662004748, 0.24657889689889648], [0.007231506113443645, 0.040172130064738375, 0.016708594048395753, 0.02212230183724915, 0.0576225596089517, 0.030688620397760987, 0.012414551531565527, 0.032591245722987, 0.07708565151739506, 0.1415863170498802, 0.985360367884559, 31.123438573652702, 62.31401243517476, 50.69726597878241, 40.149687028700306, 27.745805209682835, 41.74631918630293, 28.596157412375177, 42.19871751723751, 54.17669857701948, 51.043999579644975, 2.514466532776433, 0.025426674626707554, 4.395207483922282, 25.942944634345274, 4.27180677652359, 5.179454020915493, 59.71821138935705, 56.72410934202133, 59.75455214900356, 58.2527825140184, 57.84201622009278, 51.21295175244732, 54.250890208828835, 50.99468361946845, 55.61100736741097, 54.22030748859529, 55.50873940990817, 54.4912765872094, 56.194475620023674, 48.56211985311201, 46.04497801872992, 39.41113610421458, 40.248683729479396, 39.2870323119625, 46.09800061871929, 49.232676490660644, 53.15589389493389, 53.26694011688233, 53.9937396203318, 51.733854278441406, 52.2145172088377, 49.15888494060886, 51.18872327189292, 51.19486962595294, 53.130300429559526, 52.923709192583644, 50.279282523739724, 48.88040058074459, 44.731748873187655, 40.32910016275222, 39.63955140882923, 39.174362228762725, 41.154178573239236, 38.601409850582, 39.17424063528738, 40.70190183577999, 40.88604927062988, 39.003907788184385, 40.10476412311677, 39.96496692780526, 43.6560780771317, 38.46506434102213, 39.93372524938276, 39.665313536121005, 40.06875676493491, 38.62309663526474, 45.9281345336668, 50.54252455311437, 51.53475084612447, 46.264866090589955, 47.33087608891149, 47.209164942464525, 51.769924394546024, 50.976303392840975, 54.80901210538803, 51.255780112358835, 51.31208965855261, 47.82959761158113, 42.522395426227206, 52.13152770073184, 52.0039604556176, 53.42510184934063, 54.14033820552211, 50.429513223709606, 44.00222724483859, 46.215797239734286, 46.980518218009706, 48.664642764676, 49.079162766856534, 48.75717932178129, 51.64957823291902, 45.243080815961285, 40.59171461289929, 39.95243495510471, 40.142697365053245, 41.47067070007324, 41.6708488618174, 40.94807371016472, 43.35173745309153, 40.68667127240089, 40.82586834507604, 40.51462042716242, 41.72302815221971, 40.260435150515654, 40.87972640991211, 39.635201500308135, 42.104474729107274, 47.68372074250252, 53.37728031219975, 53.848557010773696, 52.44911809121409, 51.3923688088694, 50.97615434277443, 45.37455866413732, 45.21720493993452, 42.9685728780685, 40.75355552857922, 40.742937672522764, 41.75448163863152, 39.27013081888999, 40.72709521939678, 40.073561668395996, 41.735089440499586, 39.84068270652525, 44.29673840922695, 47.79671246005643, 53.77379663528935, 51.69445407006049, 47.44033375094014, 59.11660609706756, 57.49748699126705, 58.45516897016957, 57.16705868321081, 57.81119815764889, 61.483548610441154, 60.2299944047005, 64.06404064547631, 60.67857626945742, 61.18119270570817, 23.86218805466929, 0.7714819187118162, 17.557252568583337, 36.093077659606934, 0.10368316704707761, 0.9023062019578872, 39.93436851809102, 62.11545421231178, 46.13501210366526, 41.192637412778794, 10.706887975815805, 25.511005386229485, 59.0793945712428, 55.19152948933264, 51.52565879206504, 17.18895377651338, 0.07870555209416537, 0.07299941513807544, 0.014179637261305847, 0.013520168666277203, 0.04128090826974761, 0.017854362808828874, 0.025350121375654015, 0.03996732028862161, 0.03443617313619583, 0.022963225060412963, 0.02549323617600866, 0.06831076551949786, 0.07371151684633187, 0.09625579140359357, 0.05649280208613604, 0.06395979596662425, 0.002333284764092476, 0.024594647599564447, 0.05596243558571704, 0.1114586683651132, 1.225965111967056, 42.89063538274458, 65.32840490341187, 58.69669675827027, 44.181165772099654, 28.77900262032786, 34.778660035902455, 29.584216187077185, 46.10037365267354, 59.42811681378273, 57.254092154964326, 2.9696649457177813, 0.131104426278222, 5.636830820191292, 38.871551329089755, 3.8589241187418666, 6.359309832895956, 60.136328204985595, 59.07737847297423, 61.25922433791622, 59.76666835046584, 60.05245616359096, 53.93392739757415, 55.251153438322014, 51.0197828662011, 56.799312945335146, 54.992861440104825, 58.61056543165638, 56.4049421587298, 57.52033087515063, 51.22023559385731, 48.38363632079094, 42.40373196140413, 43.18812362609371, 41.46144920779813, 48.93156397727228, 50.67798360701531, 56.02502530620944, 54.70899558836415, 55.74075937271119, 51.93290279757593, 53.845477950188425, 50.60254073912098, 51.521151988737046, 52.64817053271879, 54.093414891150694, 53.228406752309496, 51.11838732996295, 50.052934308205884, 47.397219058006044, 41.941700289326334, 40.39623937299175, 40.96193144398351, 42.432400564993586, 40.03543623032109, 41.01803310455815, 41.34264846001902, 42.23883159698979, 40.66328217906337, 41.1479067033337, 41.15812447763259, 44.082161226580226, 39.987540168146936, 41.172041047003965, 41.98085338838639, 42.052111087306855, 41.18716570638841, 48.69253473897135, 51.054460540894546, 53.05341412944179, 48.07690697331583, 50.15160937463084, 49.45010523642264, 53.43739847983084, 52.8357147401379, 57.62157117166827, 51.89845654272264, 54.16837138514365, 49.117770656462646, 44.66111090875442, 54.62801433378651, 53.35526404842254, 56.64637973231655, 56.974489919600956, 52.15081791723929, 45.711635389635646, 47.324498315011304, 49.32979829849736, 50.63939140688989, 52.38042170001615, 50.97360087979225, 53.58922558446085, 46.78869470473259, 43.65460718831709, 42.32122098245929, 42.24716271123579, 41.817847528765284, 41.677858137315326, 42.93250276196388, 43.54002298847322, 41.744095202415224, 41.72691522106048, 42.712857877054525, 43.432522589160556, 39.76232159522272, 41.4539300241778, 42.141019452002745, 43.966474840717936, 48.5604920694905, 54.65632992406046, 54.01997243204425, 54.80950240165957, 54.448193273236676, 52.35941740774339, 47.23322083873134, 46.84938161603866, 42.9924326558267, 44.61040250716671, 42.4248186234505, 41.98465808745354, 40.920275872753514, 42.93942574531802, 41.20740121410739, 43.158898045939786, 42.1656362472042, 46.159962300331365, 51.399970362263346, 56.14206883215136, 54.83458595891153, 51.249363114756925, 59.857894835933564, 58.93384718125867, 58.72360029528218, 59.081387135290335, 60.43464406844109, 62.47344501556889, 62.26612814011113, 64.09848297795942, 64.80310147808444, 63.03366538017028, 27.55513487323638, 0.8269471134389601, 15.331484002451743, 34.10582057891354, 0.11578133479962427, 0.8548605381961792, 43.66420522812874, 65.68842749441824, 52.387831057271654, 46.736076108870975, 14.928175114816236, 30.834540320980935, 66.25080908498457, 63.38343097317604, 61.220475242983916, 22.37016550956234, 0.13043702580034733, 0.11595743543077862, 0.06606480256924707, 0.005938203182942685, 0.04486156875387796, 0.043046599208948114, 0.03630411383065005, 0.04284891405052716, 0.04732227764062343, 0.07170723165355383, 0.10962735816475846, 0.1872039111631532, 0.2473048111724277, 0.19721003069031626, 0.16753296427909406, 0.10868229677960758, 0.08953368396408136, 0.09587648595052381, 0.2333662397558651, 0.25172130805590465, 1.9481359734650583, 54.24695999391618, 75.14006091702369, 65.64730928790185, 53.09543840346798, 38.82321203908613, 54.6720507837111, 40.25965459885136, 54.66861086506998, 64.41999966098417, 65.53950294371575, 3.0626300217643863, 0.18604281298335523, 5.6365072246520755, 37.724501240638, 6.403164873200079, 7.234523488629249, 64.7003157677189, 59.06091236299085, 66.66305803483533, 62.37187916232694, 62.69879302670879, 55.7088077452875, 57.47820461949995, 53.81765265618601, 58.68762823843188, 55.113325272836995, 60.64308274176813, 57.26827544550742, 60.94261846234722, 53.6275863647461, 50.55703340038177, 43.81116467137491, 45.2667405528407, 44.41163247631442, 50.87357259565785, 53.2776128861212, 57.930952041379875, 55.66355143823932, 57.611369086850075, 53.31523626081405, 55.27827662806357, 51.992989586245635, 52.862912454912745, 53.9838356356467, 56.66733695614723, 56.509590994927194, 53.52974676316785, 52.63336750768846, 49.77490886565178, 44.07111975454515, 43.765480825977946, 43.880814198524725, 44.55357128574003, 43.647743040515536, 42.58250182674777, 43.88852950065367, 44.24538281656081, 43.410043485703014, 42.751544214064076, 44.2496346658276, 47.27226803379674, 42.343437287115286, 43.25242304032849, 43.05821080361643, 43.66548392080492, 43.7041663354443, 49.890767835801654, 53.81279283954252, 55.01334797951483, 50.384872728778475, 53.80681514739991, 52.64397359663441, 54.54906094458796, 57.41089674734301, 59.61124443238782, 55.46729564666749, 58.06408512976862, 49.565779855174405, 46.979792579527825, 55.04446806446199, 55.3946102050043, 59.05800196432299, 59.04493262690883, 55.103695854063965, 47.883996963500984, 50.08115968396587, 52.38072764488959, 52.9348801028344, 55.14587310052688, 52.052197763996745, 56.53635724898308, 49.12719611198672, 45.569939767160726, 44.2642141157581, 45.12953996658326, 43.55023291803176, 45.887545847123675, 44.96580454611009, 46.759398521915564, 45.30113581688174, 43.81647556058822, 44.29846425210276, 47.024001613740005, 43.81323960519607, 44.150751713783514, 43.84342224367204, 45.77859417084725, 52.41053373582902, 59.568259177669404, 57.53842084638534, 57.36169453590148, 57.000969840634255, 54.871005165961485, 48.931791474742276, 49.26027820956323, 46.38795791133758, 46.38181155727756, 44.43199742224909, 45.61813785183815, 43.08869938696585, 45.360532268401116, 44.76292387131722, 46.80896551378312, 44.931621090058364, 47.72596466925837, 53.46942855465797, 59.275285582388605, 58.29982349949499, 54.60724146135392, 63.99610911646197, 62.63088895428566, 62.13734888261365, 63.59264235342703, 64.60617103884297, 65.53539229977515, 65.72265801891204, 66.83717989152478, 66.77022503268334, 64.88695390762823, 31.082671419266735, 1.8720945763972499, 25.804175100018902, 39.42229132498465, 0.24900117498492044, 1.2359231518160914, 48.01976588464553, 73.82633363046955, 59.76472677723054, 52.46907903302101, 18.19124291020055, 38.07095243084816, 76.07571878740865, 73.8220739364624, 71.00808712743944, 31.15163257045131, 0.39050590367086474, 0.2679756560152577, 0.185640586179591, 0.08178183178026831, 0.18775907976012077, 0.05224867115518259, 0.20263676771954184, 0.19422473926698008, 0.12412729582959607, 0.17728797550643646], [0.02895361127992792, 0.09499147819775729, 0.04451417469329411, 0.03675256637976535, 0.07944311856502488, 0.05690057919691167, 0.03804450088571157, 0.06900998928974714, 0.09035183522369593, 0.04483109377625008, 1.1156860811095084, 41.57067152761644, 61.71336027883715, 49.09669183915662, 33.96134007361628, 24.0836097732667, 22.785585695697417, 24.3862186708758, 49.20470999133203, 50.17076623055243, 50.59238572274485, 0.9887505827411529, 0.21448459326019212, 0.5267357033106589, 41.92565779532156, 8.048237321838256, 12.032020534238509, 60.77862808781286, 46.2828972262721, 61.163428291197754, 48.818921350663715, 56.95536444264074, 51.66735441453996, 60.14470246530349, 54.634529390642726, 60.06711798329508, 52.77091326252107, 56.36560078590148, 53.80534033621512, 52.969899023732836, 44.8103767056619, 41.88390808720743, 40.91740862015755, 40.33714102160546, 38.52441764646961, 44.33536591068391, 48.407943248748786, 50.45086268455752, 51.76974004314792, 53.440438316714385, 52.48218367176672, 50.662192144701564, 49.669232368469245, 52.438013861256266, 52.040112941495835, 53.60257733252741, 51.85241183926983, 49.874705729946015, 45.0447500905683, 41.060935989502944, 38.93315999738632, 40.00186858638641, 38.92531525704169, 38.74423903803672, 38.34828753625193, 40.01390241807507, 38.9393259632972, 41.346472770937034, 39.738893278183475, 41.14962470146918, 39.45167772231564, 42.59779907041981, 41.2213138611086, 38.72605100754769, 37.82557287523824, 40.09358536812567, 40.185663007920795, 39.62152419551727, 40.85886332296556, 41.78815910893102, 38.89236342522406, 41.017005443573, 43.414503220588934, 49.09535823329803, 51.00250482559205, 52.23831422867314, 54.919411136258034, 50.60398024897422, 39.56782694785826, 42.39157653624012, 52.6356856284603, 53.323767415938846, 55.39112714029128, 53.49677924186953, 47.786675114785474, 40.9988840933769, 44.40557633676837, 45.723884951683786, 43.76093087657806, 48.02839117665445, 44.630343837122766, 47.979341937649636, 41.77310505220967, 41.42145279915103, 39.1212768708506, 39.29384154658164, 37.40723248450987, 40.77150429448774, 40.4785503110578, 41.98189281648205, 43.702766049292784, 42.24310698047761, 39.03025434863183, 43.1101155281067, 41.04156732559204, 38.74100700501473, 40.76494609155963, 39.70924800442111, 40.72019577026367, 49.46320595279817, 50.6657850357794, 52.89491899551884, 51.45020807943037, 52.18313824745917, 51.33137203031971, 49.48096252256825, 46.2676509734123, 42.791677905667214, 40.48147639920635, 41.98935708691997, 42.68972766014838, 43.228818216631495, 39.45171694601736, 41.317447231661895, 41.2906260644236, 46.56495486536334, 51.25361104165354, 55.33294270115515, 49.65963040628741, 53.802222051928126, 58.14444272748886, 58.12122229606875, 56.77205639500772, 58.48732848321238, 58.133750346399125, 58.49700497042749, 61.163267474020685, 63.9281540532266, 61.847085645121915, 42.20457361590478, 34.56169805219097, 0.5648794049216855, 6.348936634678995, 14.860488733937665, 0.9145563768763697, 0.04834331579566483, 33.90342627802203, 66.40710769161102, 49.22537695976996, 48.08297095760223, 36.885514105519945, 27.203772875570483, 41.50987478994554, 50.17790494426605, 54.352012834241314, 23.24711726557824, 0.21171262668025112, 0.08424946227140966, 0.02440466928566175, 0.08310584621804376, 0.02465425307051309, 0.013254614821034334, 0.08106614478052625, 0.031221725662509282, 0.04824029229160759, 0.08531576473145716, 0.023623324720369234, 0.03459962565572031, 0.01726168654708853, 0.011059587141649138, 0.01984955070750608, 0.03236302813034385, 0.05253329580169051, 0.048432473108292594, 0.012661793002588375, 0.0645966946537937, 1.7395834288289471, 54.57089677933724, 66.9466846219955, 56.650235422195934, 41.05302456886538, 28.30329756582937, 24.676601540657785, 24.27673355225594, 53.27942109877064, 56.072513441885675, 55.41108023735785, 1.137612375520891, 0.13542104061813126, 0.886397620122279, 37.15119977151194, 7.2317739071384555, 12.975926168503301, 63.3588259450851, 48.141614314048525, 64.23065116328578, 50.446379415450565, 58.722741296214444, 53.784324276831846, 61.87058456482426, 55.67999793637184, 60.47394621756769, 55.90727575363652, 58.51631872115597, 55.71890000374087, 54.176223970228634, 46.94481680470128, 44.17021451457855, 42.930110116158765, 42.54955391730032, 40.153558408060384, 45.85155025605233, 50.52515629799136, 51.968780717542096, 52.47002432423254, 54.48424769986061, 54.359763437701815, 52.46686289387365, 51.01528390761345, 53.88828669824908, 53.54602459938296, 55.3282162450975, 54.352063825053555, 53.131908601330174, 46.98238134384156, 43.02598461028069, 40.18649455039732, 42.742683579844815, 39.94868909159015, 40.73741105294997, 39.54818764040547, 43.52343920738467, 40.447489061663234, 41.625753371946274, 41.72532666114069, 42.97438975303404, 39.59866854452318, 44.1066760401572, 43.197392186810895, 41.10592557537941, 40.218846259578584, 41.57016554186421, 42.18035298009073, 42.117092993951616, 42.99520184916835, 45.37271515015633, 41.811873758992846, 43.14502070027013, 45.95985081888015, 53.069327185230875, 51.77598837883242, 55.05270111945368, 54.28205736221806, 52.12547548355595, 43.41364814389137, 43.69653732545915, 52.518524431413226, 55.25553080343432, 57.706247298948234, 56.01476438583867, 50.02327334496283, 43.41645656093475, 46.025377934978856, 46.366341729317945, 46.38324714476063, 49.65763784223988, 47.7974106419471, 51.183643802519775, 45.084746499215406, 43.950232305834376, 40.80751949740995, 41.30481719970703, 40.553797060443515, 42.92451289392287, 41.299012091852006, 44.073178998885616, 45.24831325777116, 44.42703562398111, 43.13744268109722, 43.4685456368231, 41.38095824949203, 41.10976165340793, 42.09703007052022, 42.36414347925494, 41.9957152489693, 51.35430220634707, 53.295961733787294, 54.756318984493134, 53.609594452765684, 54.12608038994574, 52.486047206386445, 52.34123329962454, 47.60563811948223, 46.186332394999845, 42.57331171343404, 43.56827189845424, 44.811423978497906, 44.964161073007894, 41.05661353757305, 42.73022613217754, 43.183714882020034, 48.07125483789752, 54.569135635129875, 55.462400528692434, 54.95282973012617, 55.869115014230054, 58.919095147040586, 61.594014321604085, 59.37397633829425, 61.09135081691127, 60.898429039985906, 61.385085352005504, 63.27773094177247, 67.32420490634057, 63.249909570140225, 49.05086286606328, 39.586179717894524, 0.32114969626549755, 1.6310461754760437, 10.794121488448113, 0.862780048722221, 0.14455138375201534, 36.11853776439544, 70.18074943173316, 52.81598129580098, 50.208977960771136, 34.182718646141794, 33.41838598251343, 48.88928082681472, 59.1080278735007, 62.9323152572878, 31.13573128177274, 0.46540417498157877, 0.12871303685730504, 0.05305983952336735, 0.04135597339500824, 0.05308128232436796, 0.010449838610516201, 0.02362183659457632, 0.09453210123484174, 0.03890273769596412, 0.07590323311066435, 0.1535047146101152, 0.19379297211285562, 0.166265471808372, 0.20472553708860952, 0.1687190062817066, 0.1623468401451265, 0.09421369211087305, 0.16263888818362068, 0.28265206203345333, 0.18349432957268533, 2.2570867307724494, 63.41873622709706, 75.14325372634396, 65.94932002405967, 46.1173104470776, 35.88704339919552, 31.838596482430738, 36.459121088827814, 60.34833231279927, 61.345563550149244, 60.351391761533684, 1.5064561318966652, 0.36069874020834125, 1.5570417142683461, 51.97819832832583, 9.92516940639865, 15.408657616184605, 66.9029031261321, 51.96268535429432, 67.74210206923946, 53.023957129447695, 60.58874614777104, 54.15550208860829, 62.38963180972684, 56.29899501800538, 64.96878239416307, 57.549344647315245, 60.71057888769335, 57.96802236187843, 56.85432418700188, 48.34818593917355, 45.94480852926932, 45.43434343030376, 44.90886349831858, 42.43760162784208, 48.837607522164625, 53.89444089704945, 53.20001663700227, 56.070054115787634, 57.59575805356426, 56.57500828466108, 54.20415516822569, 52.61397138718636, 56.6206842853177, 54.75580515400056, 55.59247024597661, 55.42199227117724, 56.09712239234678, 48.75100158875989, 46.005660180122625, 42.603231553108465, 44.18995580365581, 42.24261668420608, 42.92577981948853, 41.542497142668694, 45.301590811821725, 43.25917343939505, 44.28843867394232, 42.785825729370124, 45.641236689782914, 41.250182505576845, 45.88876570424726, 44.62748050689698, 44.10035317943942, 42.56804789266279, 44.290470461691584, 43.80895245459772, 44.25781280763688, 45.628751785524436, 44.996999156090524, 44.38072419935658, 46.15143114520658, 48.851751589006, 53.91169932580764, 54.19125841509912, 57.27681052300238, 56.95842389137515, 56.40422436498827, 45.26269658919304, 44.46496494354741, 53.52735803973291, 56.663089029250614, 60.37740492051648, 57.88815113805956, 52.155403167970725, 45.656584924267186, 48.9510581570287, 48.897898274083296, 48.677990590372396, 51.78020100439749, 49.44006396878151, 53.935080574404815, 46.61023862900273, 47.07953060826948, 43.84732107962332, 42.02719619197231, 41.4664972982099, 45.09882780813402, 43.51866568288496, 46.050622309407885, 47.809366026232325, 46.701688689570275, 43.92910642008628, 46.59087780983218, 44.54727195924328, 43.27496490170879, 44.29664427234281, 46.2940759812632, 44.07810549582205, 54.07261063975673, 55.68106482105871, 57.04779509575137, 54.69815415720786, 57.26939724337671, 54.7719810085912, 55.606645691779356, 50.684298622992735, 47.596181284996774, 44.92392539978028, 48.244164682203724, 47.08389228390109, 47.64757217899446, 42.08442749515657, 45.71886824023339, 44.50502411011727, 50.763526578103345, 57.1373624186362, 59.37407831991873, 58.049050684898134, 58.73741880539925, 62.083110347870864, 64.38940125126993, 60.26541732972669, 63.46141161457185, 63.28443035002678, 62.51828947374898, 66.53541626468783, 70.93903772292599, 68.27974134875883, 48.02775183031636, 39.930418691327496, 0.9879271301531023, 12.743821874741586, 21.430838261881185, 1.782957856212893, 0.17443048287062876, 40.67238600023332, 78.3672223552581, 59.64330196380616, 62.29220405701668, 47.68493667725594, 40.21270775025891, 56.53667888333721, 67.61050654995826, 72.09021414479902, 42.569805114499985, 0.7940191222775368, 0.3147615648565754, 0.18680703165310045, 0.20442503143943128, 0.14314404959159513, 0.06695727967927534, 0.22602477321220985, 0.20195016907828472, 0.09829341674283629, 0.13446462580994253], [0.03574368987052191, 0.0867751315836945, 0.008670799546845017, 0.04636983116788249, 0.1154890799173905, 0.024004522410611955, 0.08373530236102882, 0.07632857278710412, 0.03990163207955418, 0.04973095383555178, 2.194732076698734, 53.352479165600194, 56.84094498234411, 51.86020166643205, 50.01537761380596, 20.432002775130734, 20.975600134941843, 41.67341801428026, 43.84790943514916, 55.99448965441797, 43.71381144369803, 0.691520051369744, 0.2825431549741376, 1.996776427953474, 15.31690259133616, 1.1574984245723294, 21.492903886302827, 25.80117644802217, 32.17026229827635, 56.13317681897072, 57.11585606298139, 58.057981921780495, 58.85167744851882, 61.24254249757337, 56.85120198034472, 57.55495363666166, 55.345678637104655, 56.225085796848425, 48.940707022143954, 44.86391313614384, 39.320678403300626, 39.695190229723536, 38.31928160882766, 40.002817799968106, 40.31019041615148, 43.06629480854158, 47.76353313076881, 51.76474686591856, 52.19133207874914, 50.69361032978181, 50.029149055480964, 49.956157668944336, 53.58242027221188, 53.026220337037124, 52.35635011426864, 50.594982331798924, 48.8862645241522, 44.888208296991166, 39.59943340670678, 37.56413905851303, 38.759320551349276, 39.92987740424372, 39.873528634348226, 41.33622361767677, 38.672224321673, 40.539802043668686, 40.96495559138637, 40.468646326372706, 37.96841382980347, 41.177783396936235, 39.98761469318021, 39.70536093558035, 37.7637759331734, 40.12104195933188, 37.3072277345965, 39.46530795866443, 37.513101177830855, 40.44029935713738, 40.87180714453421, 41.64255680576448, 40.753900697154386, 42.888391787006015, 44.37378944889192, 51.71197137525005, 50.26030609684606, 51.94897667054207, 50.73085715693813, 51.923442040720296, 39.213746747662945, 46.772840484496086, 55.56784952840498, 52.08745594947569, 52.22842593346873, 51.78037358868507, 42.43930785886703, 40.35709019630186, 41.7160737899042, 41.66891905569261, 41.30275011062622, 42.54176801250827, 42.167154204460886, 43.64492285636164, 42.576841846589126, 44.32808206927392, 43.62965306928081, 39.69103643971105, 38.66982383112754, 40.55056502742153, 40.2228823784859, 42.317337835988695, 43.653022550767474, 40.02427316481068, 41.47370661458662, 41.502681163049516, 41.31653331941174, 41.38531600275348, 41.49838224534066, 40.67679082193683, 39.813520293081964, 42.32173089058169, 48.387907781908595, 49.865613675886586, 53.3343578154041, 50.928383796445786, 51.264887855898955, 48.914007448381, 46.23655050031601, 43.791211574308335, 43.1728656061234, 40.928901164762436, 42.042622873860026, 39.91463899612427, 39.708420384314756, 40.521512031555176, 42.93602112800845, 45.95342989890806, 49.8833231772146, 52.00880066041024, 51.206377860038515, 54.3921112245129, 57.4825898293526, 57.630478874329604, 56.34110166180519, 57.00480984103296, 57.59552663372409, 55.47704665891586, 60.47525628920525, 63.48314154532648, 65.9072800605528, 69.19479893099877, 64.38383540799542, 2.029462519191927, 2.7609646993298687, 4.236536823934125, 0.45520294818185997, 0.00656284733615335, 21.71614362347511, 66.28416492092994, 49.429877573444, 41.541885252921816, 23.54804346638341, 18.204906486695815, 40.827817763051684, 57.136868199994495, 53.768387686821725, 34.06994658131754, 2.0148389425969895, 0.1050169567667669, 0.03582650014469701, 0.05518797048998456, 0.013293207457829869, 0.08180211778850326, 0.028156418270701845, 0.10856448777861173, 0.038540485360088854, 0.04739462315375286, 0.021387677144018874, 0.008027225361025382, 0.0739376889842172, 0.052994507545184706, 0.10380268442414461, 0.029726463760579788, 0.06343707119324996, 0.11518044607533563, 0.01636549199540769, 0.050608120678413304, 3.1264729701703597, 60.7839782007279, 63.11364643035397, 58.336438825053555, 58.87960080177554, 33.6343163828696, 20.047318281665927, 43.687272687112134, 49.537291680612874, 62.51239415137999, 47.48775912869362, 1.0879953734336363, 0.23813170501061026, 3.78350037240213, 14.617277268440494, 1.5075352739903236, 24.482752123186668, 25.58346921397794, 37.06642558497768, 59.36896354921403, 59.41689099034956, 61.09703040892079, 59.51061994798722, 63.0700179069273, 60.04465064694805, 58.16017535425002, 57.25693587333926, 56.660574789970156, 51.664969613475186, 48.533459094262895, 41.26416575524115, 40.772029892090835, 40.185360985417525, 42.03231880741735, 41.549961413106615, 45.53910209286598, 49.17476661743657, 54.58597044790945, 54.03945484469014, 53.814581440341094, 52.63338319716915, 51.735517363394464, 54.42991110586352, 52.58782094524753, 54.169822662107414, 53.0081735118743, 50.15204868009014, 47.98217388891405, 41.951953364956765, 39.49688696092175, 41.71966275861187, 42.51273462849279, 41.82254652823172, 41.51153003015826, 40.221517393665934, 41.96434805470128, 41.59997555517381, 41.52474449526879, 40.5676979403342, 43.26743002860777, 40.61624119358678, 41.81770240106891, 39.587191689398985, 41.51173399340722, 40.51677380838702, 41.15012676485124, 40.22127812908542, 43.654195339449, 41.85050126044981, 43.81637750133392, 42.7731760855644, 44.74375917065529, 46.080769646552305, 51.79544333488711, 52.00001847359442, 54.85834767741542, 52.646036763345045, 51.82247631011471, 42.73916129143008, 47.74732197484663, 57.36711525147962, 54.342901168331025, 53.45675929900139, 53.34009232059602, 46.40337282611478, 42.178870324165594, 41.419977987966234, 43.900492729679236, 43.5461889543841, 44.6400164019677, 43.81187854274627, 44.37285592479091, 44.724351283042665, 44.065546066530295, 46.55419188161051, 41.59076975237939, 41.11326432997181, 42.03176183085288, 41.32447611901068, 43.295463208229314, 44.88809454825617, 42.691410356952304, 43.004454720404844, 43.090848845820275, 42.331780002963164, 42.03263651940131, 43.64459729963734, 42.09918737411499, 43.16637016111805, 44.318797819076046, 50.29909049310992, 52.29987582852764, 53.99872103045064, 53.06361621425998, 53.53430063493791, 51.30859874909925, 49.16314071224582, 45.834844881488436, 45.89588480611002, 42.95324033306491, 42.45519345806491, 41.35111293485088, 41.5321538525243, 41.31739231847948, 44.898928134672104, 48.371688781246064, 52.09143323283042, 51.714673888298776, 53.1881397001205, 57.07316890839608, 60.20012163346814, 58.98958406140728, 58.002394091698434, 59.15454718374438, 59.53894730537169, 57.140739579354566, 62.00544349608883, 65.57942874969976, 67.66762410440754, 70.98682003636515, 69.16767181888704, 2.8374781291331015, 1.3741374256149417, 3.9304728084994904, 0.24101829366578212, 0.10819822114201323, 25.082168732920003, 73.3383515573317, 56.398929165255645, 47.171941649529245, 25.085643952892674, 24.627087500787553, 48.13602493655298, 64.88325511255573, 61.413934384622884, 43.47261705706197, 2.596830667987947, 0.11133470001720613, 0.040875513692416494, 0.017031917626398708, 0.023678046380800587, 0.029450365672669107, 0.017188990548733744, 0.05938762235605429, 0.026634010043175473, 0.038307418430885004, 0.14059406464859364, 0.18796705730980445, 0.1870628437327762, 0.12705270215989123, 0.19591705813523264, 0.308195884910322, 0.1795307285482845, 0.20484244210585473, 0.09682637368959766, 0.25172034278512, 4.171185724196896, 70.89517777965915, 70.82496735357469, 67.18042650530415, 63.68605752145091, 32.60704371236986, 29.178227340021444, 56.48442899027179, 52.97723385595506, 67.34766852471137, 54.002788528319336, 1.3650746667577376, 0.4759278328668687, 5.758839086178811, 21.77273558032128, 3.033422092276235, 28.39799927126977, 27.47226695860586, 37.43737982165429, 62.394585763254476, 59.96736034270256, 63.050963032630186, 61.83368290624311, 67.78793104233281, 62.14938271430231, 61.52258011602587, 58.51625596323321, 60.22615832667197, 53.93309585509762, 50.32198144543556, 42.669923613148356, 43.60365167740853, 42.134943700605824, 44.60674293579594, 43.39324397425498, 47.762964387093824, 51.21239869825302, 57.806797258315555, 57.102837716379476, 56.72463886199459, 55.51267354719101, 53.3405630050167, 56.31773218031853, 56.1264342646445, 56.461965576294936, 54.08549954814296, 52.32676367605887, 48.68849862006403, 44.364952348893695, 41.36746529609927, 43.26055019132553, 43.25233282581453, 42.976735330397084, 45.33216176494476, 42.74015365108367, 44.510895898265225, 43.985749367744695, 42.812050696342226, 41.06729415155227, 45.23340040637601, 44.65410163325649, 42.90147289153069, 41.835266774700536, 45.29880200662921, 42.8932672931302, 43.550397657579, 42.10737336066462, 44.34758801614085, 45.09515254728256, 44.46718892743511, 44.76655598609678, 46.67263961607411, 49.4688973119182, 55.20609324978244, 55.55511751482564, 55.7109336699209, 55.92409879930558, 55.29038106241534, 45.9696763561618, 50.963861634654386, 58.35606244302566, 56.72109303935882, 56.59268248465754, 57.181849941130615, 47.817873647136075, 44.23171335651029, 43.718683027452045, 46.523460111310406, 46.82867934626918, 46.816927925232925, 47.29187596228815, 49.065414859402566, 46.417399221850985, 47.807369539814616, 48.62463851128855, 43.95347610596688, 42.752179638032, 45.14879488175915, 43.85397341943557, 47.60529687327724, 47.01348181693785, 44.38320705967565, 45.25715035776938, 43.88552496510167, 46.126359355065134, 44.60057696988506, 45.11861224328318, 43.89928856203633, 45.22492808680381, 46.32227390043197, 54.320237713475386, 53.90665908013621, 57.57420462946738, 54.66069944443242, 57.66432500654652, 54.06442857557728, 51.10705168016496, 48.641724355759166, 48.83111207715927, 46.85255873587824, 46.93398321828535, 43.292325312091464, 44.600804467355054, 44.32898813678373, 48.10174342124693, 49.76997452397501, 55.136714366174516, 55.751408607729026, 57.96768503804361, 59.948101505156494, 63.194890483733154, 60.266919597502685, 60.6744852373677, 60.37141938363353, 63.900524877732806, 61.1806788752156, 66.47722398081135, 68.13605708460655, 72.33833543715939, 67.67053450307539, 66.12158267728745, 3.3415480486808287, 7.034238932594177, 11.89858542334649, 0.7427552763012149, 0.22349063096748245, 26.363185413422126, 81.12960646229406, 61.93519776867282, 55.13075628588277, 34.61533646429739, 31.5307512206416, 55.142935245267815, 73.53275991255238, 70.24150694570234, 53.27311392753355, 3.5239865558762706, 0.2034228965039215, 0.1447929925615749, 0.17383958393287274, 0.12142262241292386, 0.10053788582163473, 0.16048477151461188, 0.16812826056153546, 0.0649145675162154, 0.1460074257826613], [0.10496078720015865, 0.014957373552475006, 0.013886959115493924, 0.05823798485160355, 0.10347081513534631, 0.048115419959949876, 0.0373448136322681, 0.0369600229896605, 0.15350249295513477, 0.1134245036049716, 4.91449301281283, 56.25199325623051, 52.758228317383804, 52.11225317370508, 29.74576488617928, 18.184861213930194, 45.17849506870393, 44.215074662239324, 42.197195637610655, 57.416078198340635, 44.33508742240168, 0.8735330426885236, 0.1389920369030968, 4.365058185592774, 1.8408325506794838, 2.5920321383783897, 25.56493209254357, 18.51078664102862, 36.45176272238455, 62.020956470120346, 56.23736281548777, 55.19564013327322, 55.18002125524706, 56.07470996918217, 55.56604523812571, 49.830955613044004, 48.23268782707953, 46.31081665715864, 41.50216341018677, 39.66315231015606, 38.679363035386615, 40.40314274449503, 40.291437564357636, 41.14058756059216, 39.78731493796072, 41.530384863576586, 44.065640203414425, 48.20289350325062, 51.947348886920565, 52.580784213158395, 49.44133481671734, 51.65330448458272, 49.593514934662856, 49.220713261635076, 44.98265112600019, 42.8495720894106, 41.00099432852961, 39.70964024143834, 38.3108877366589, 38.53636126364432, 38.561750765769716, 38.98732400709583, 38.053937189040646, 37.673533962618926, 40.85603137170115, 40.076005305013354, 40.244212227482954, 38.441624256872366, 40.398902662338756, 39.64009661828318, 39.559472299391224, 41.11030686286188, 39.31974095682944, 40.21675171390657, 38.76349003084245, 41.36464511194537, 40.40127177392283, 39.96912856255808, 40.13892796731765, 42.187440702992106, 39.92426057015696, 43.32715203685146, 43.742774225050404, 50.04437177411972, 47.422534035098174, 52.46730219933295, 51.577485069151855, 55.81122083048667, 44.09858026812154, 42.028063035780384, 56.09304704973775, 49.367582490367276, 51.368736528581195, 44.61894542940202, 41.24166703993275, 41.61327631242814, 44.0197249381773, 43.78845807044737, 43.49656704933413, 44.217871312172186, 46.85450030911354, 45.994230393440496, 52.896644838394664, 52.546879245388894, 50.44257471638341, 42.55773598147977, 40.10907088556598, 40.57463269079886, 40.30643670789657, 41.00104531934185, 42.531420799993704, 39.75312755953881, 41.74289103477232, 40.35739221880513, 39.880749717835464, 40.761423803144886, 41.10623152025285, 42.92610145384266, 41.06928279322963, 39.60453248793079, 42.21379903055007, 45.861073770830714, 48.38501307272142, 47.56887766622728, 49.00632435275663, 47.95590185349988, 47.98462929264192, 45.218314970693285, 42.9820462196104, 39.48710849208217, 39.43044201020272, 40.22188609646213, 42.1780191698382, 41.95932742088072, 43.819986081892445, 46.473289074436316, 49.766664043549575, 50.27807835609683, 54.149285131885165, 53.51655190990817, 53.00483165248748, 54.48441243940785, 57.37850581446002, 54.41457463848976, 58.32165933424427, 51.05420950920352, 59.74483251571656, 58.818800141734464, 67.88432721168765, 57.54029573932771, 73.34636888196393, 14.92433903678771, 0.8767604178959324, 2.0661303064515515, 0.11842249952737363, 0.134642465460685, 16.427591327698, 64.07570185199862, 51.60092515330161, 59.004528291763805, 60.61440629343833, 32.536790140213505, 35.155933210926676, 55.98277353471326, 53.68089922012822, 43.03681427432645, 3.2493620534097, 0.11807183044091349, 0.022743838546316952, 0.02426202562938054, 0.012001896355932039, 0.03010807705352143, 0.04174160290389292, 0.02617392061849035, 0.009546617117349901, 0.024261056528156324, 0.060593659253490556, 0.030359028305317608, 0.043616940177256064, 0.013026750586446256, 0.025512371137137377, 0.03905358040825494, 0.024031013731033574, 0.06391448569634268, 0.07902744691818953, 0.1729326124393171, 6.058177707656738, 66.23385660109982, 59.50966288966518, 59.97823707519039, 36.65158002607284, 19.898683986356183, 40.315003164352916, 51.431439538155836, 45.748172267790764, 61.274498047367224, 45.93031144911244, 1.0562304263153384, 0.22598257708934047, 1.0396988617797052, 0.8986860381499414, 3.1550908280957133, 30.017679276004916, 19.968258988472726, 42.80297040939332, 64.34401550600606, 57.353410490097545, 58.28519305875225, 57.11864486817391, 59.318200234443914, 56.366106771653705, 53.62549966381442, 49.91540424285397, 48.789115259724284, 44.169398661582704, 40.4462888163905, 41.82657088002851, 41.026885894037065, 40.7526808400308, 42.53406055511967, 42.642435642980764, 44.038826880916474, 45.004828206954464, 52.90560745423841, 54.21745592548002, 55.548045481404955, 51.95076134897048, 52.87163580617597, 51.41519308090211, 50.79059877703267, 48.32824460921749, 44.94999347194549, 42.341672220537745, 40.715606597162065, 38.60705806363014, 39.89260704286637, 40.343832585119436, 40.14490173709008, 39.542445290473204, 39.957710542986476, 41.567580699920654, 42.276137259698686, 41.34499795975224, 40.55608772462414, 41.61526103173533, 42.29092851761849, 42.23991809352752, 42.52638447669245, 41.805617578568004, 41.73450500734391, 41.67765809643654, 44.66064806907408, 40.749456651749156, 42.00831782433295, 41.673563141976636, 42.91167105397871, 41.44505370047785, 44.81332240566131, 47.01533317565919, 50.61173085243472, 49.620528298039595, 54.57071242793914, 52.927506046910445, 57.10202578575381, 46.85585744919316, 44.7847322494753, 57.79484187403033, 52.873804876881266, 53.590712162756155, 46.444910726239605, 43.843194746202045, 42.71573297439083, 45.67369430295883, 44.58394219798427, 46.06817099355882, 44.75165097944198, 49.294092962818766, 47.20288130544847, 53.53921144239364, 55.568280989123934, 51.149240693738385, 44.809678523771225, 40.67080528505387, 42.25863564398981, 41.99880607666508, 41.279262958034394, 44.2662968943196, 41.23030001117338, 42.92286157608033, 42.740863600084865, 41.96877248825566, 42.576418230610514, 43.06079564555999, 43.017986897499334, 42.725103516732496, 41.15078572304019, 45.33054182606359, 47.54729286316903, 50.077555025777514, 50.075840950012214, 50.71695627704744, 49.84648819892637, 50.558731786666385, 46.20143352016326, 44.537579782547496, 41.32861421954247, 41.75478366113479, 42.44750953489735, 45.0357678628737, 44.55453226643224, 45.5828090636961, 48.37091215195195, 51.88162957468341, 52.079030698345555, 56.6823596339072, 53.035422217461374, 55.13906386590774, 56.19407161589592, 60.660152896758056, 57.23029905749906, 60.60982496507707, 54.59563516801404, 61.82850145524549, 61.13189243501233, 70.96250918603712, 59.64452182092975, 76.40529201876733, 16.25705255616096, 0.8619363101259355, 1.2390322430479912, 0.20759257517995375, 0.04874751144539445, 17.799706036044707, 68.40877948268768, 56.411512128768436, 52.51432749532884, 48.723560687034364, 37.6008249867347, 41.64290981907999, 63.81818648307555, 61.15283004699215, 52.08736573496173, 5.104880448310606, 0.17436937969778815, 0.06963754553467998, 0.03962731897650708, 0.04734230700940375, 0.047896391591958465, 0.06777016025397085, 0.06396086848971826, 0.025955342327154456, 0.019392577345452962, 0.19167731305764568, 0.09363295915987223, 0.12692407599740452, 0.10451236529456032, 0.23371359934249233, 0.15337113951963766, 0.1247175359317372, 0.15651292738414582, 0.3343752849726908, 0.42028159624145883, 8.674499123327195, 75.90481327426049, 66.35206114861273, 70.3831829563264, 41.84475498814737, 27.77307744949095, 55.91943117880053, 56.19765666223342, 54.73760143403084, 67.78878611903038, 52.915331009895574, 1.490871942331714, 0.3605226012727907, 8.341206504452614, 8.225360772302075, 4.952650320145392, 32.78224225967161, 22.57443078102604, 45.761680910664225, 67.06125705472886, 61.338817073452866, 62.086675782357496, 60.560748269481046, 62.098407591542895, 59.9895570355077, 54.86886747421757, 52.776392813651796, 49.3575059213946, 46.64783846947455, 42.860742999661355, 43.48825946930916, 42.77700431885258, 42.736996143094956, 45.99834888212143, 44.255082837996945, 46.501675267373365, 47.24187750970164, 54.80113206371185, 56.54268403207102, 58.35527012425085, 54.70475550620787, 54.25373000483359, 53.81211426950271, 52.638976497034875, 50.402080166724424, 46.68885469436646, 45.53511696477091, 43.77722440227386, 40.78542478622929, 41.82094227883124, 42.476954767780924, 42.736996143094956, 40.80431492097917, 42.556845603450654, 44.50701667416481, 43.203699358047984, 43.05761068098007, 41.925763699316214, 42.89132964226508, 44.86750210485151, 43.83969206963816, 45.321237964014855, 43.727080821990974, 44.38536044090025, 44.15179114187918, 47.895979804377404, 43.62220448832358, 45.50185918807984, 44.147056841081195, 44.699287337641564, 43.907894242194395, 47.94108706135904, 49.83784329506659, 54.30915309536842, 52.750575773177616, 55.58917153266169, 55.89367297387893, 59.224832134862105, 50.36560996886223, 46.74587026719124, 57.90227951542024, 55.44741315226401, 56.001228286374, 49.35598796413791, 45.6726784090842, 44.68893620275682, 48.98120549417312, 47.20133589160058, 48.02917957305909, 47.01843577046549, 51.410078310197406, 51.00966707352669, 57.72007757617582, 58.04728561832059, 54.98151010082614, 47.21775101077172, 44.56046681250296, 44.89740233267508, 44.37836293251284, 44.85510349273682, 46.90510280670659, 42.36702249896142, 44.50947992263302, 44.176156905389604, 44.432523019852184, 44.46305474927349, 45.140514758325395, 46.688136900624926, 45.66400997100338, 43.98388624191285, 47.03352905088856, 50.756093686626805, 52.185911363170995, 51.82379422649261, 51.959010093442856, 53.617415658889286, 53.29338865895426, 49.91454132141606, 47.85403790012483, 42.772795615657685, 44.14528785213348, 45.760092350744436, 46.371848737039876, 47.29506877160842, 49.93884040463356, 51.68038060588222, 54.36240711519795, 54.75685242683657, 58.38210305859966, 57.12632486897131, 55.46718582030266, 59.58289746315249, 63.19990719518354, 59.70780141891972, 64.64036233963506, 56.83555956809752, 65.14034686550018, 62.97694398510841, 73.15969544072306, 62.874201420814764, 78.52582731554585, 18.98947269685807, 1.9945680109723924, 8.002561811477907, 0.22433020204545992, 0.1557353941062766, 20.235982325769243, 78.16417694091797, 63.26742295295962, 73.78740018413913, 73.99336384188744, 46.654279001297496, 49.98294745722125, 72.18038159032022, 69.05469186844365, 63.08519747949416, 7.137590935153346, 0.2182187815947879, 0.19891443842601395, 0.17209716291437227, 0.1905024865822446, 0.16615296413581218, 0.10562371372455552, 0.08465060889120064, 0.090362943498598, 0.14217516287199913], [0.028887308285301252, 0.0357976301212705, 0.16529686088042875, 0.06260902207765369, 0.012111219017946673, 0.016715337537349235, 0.03137623027507817, 0.09048667435924854, 0.10733366027594575, 0.23865589301191995, 7.364146546010049, 58.029438834036554, 46.74081433203913, 42.683510703425256, 30.89583912203389, 48.52812074845838, 63.159432257375414, 54.16329191577051, 40.463766897878344, 58.302863336378536, 40.94202933772918, 0.7191881441300916, 0.1109665641260724, 1.8639594580857985, 1.0230381041765213, 3.147397099002715, 46.57005786895753, 50.83866742349441, 60.60962492419828, 56.197809634670136, 56.47822380065919, 55.075329272977775, 52.37247105567686, 47.62821528219408, 46.71173780195175, 42.9281646205533, 42.15188441738006, 39.431124502612704, 40.329590459023755, 41.83636111597861, 42.91374991017003, 44.61272062793855, 42.254638748784224, 39.34985691501249, 42.66360467480075, 41.24580121809437, 42.41938221839167, 48.78619701631608, 51.483446244270574, 49.73342980107954, 49.321831964677386, 53.937575201834406, 50.31009274144327, 49.32032969690139, 41.568306338402536, 39.12006878083752, 39.83104936538204, 39.159178733825684, 40.2629219332049, 37.5740469655683, 38.12526156825405, 39.57491859312981, 38.232554081947576, 39.85260671184909, 38.473328774975194, 39.82774280732678, 39.93254461596089, 38.6226494850651, 37.26969849678778, 40.34161644597208, 40.4839906384868, 39.970693588256836, 40.73165301353701, 41.97387549184984, 45.76286154408609, 45.54306368674002, 44.15811008022678, 45.20058977988459, 42.98623923332461, 42.16120789127965, 38.510905081225985, 40.56501896150651, 41.310708599705855, 43.71557651027557, 45.365756865470644, 50.97179266714281, 48.06651269235919, 56.79579065692041, 48.362431987639404, 44.54279653487667, 56.050406963594504, 51.12603595179897, 45.656137774067545, 39.746039836637436, 42.71726662112821, 44.330815961284024, 48.156409494338504, 49.21979542701475, 49.83777269240349, 47.82893080865183, 52.31496126421037, 55.83953249839045, 55.44848788169123, 52.729669540159165, 53.76177849308137, 46.39663811652891, 40.07284387465447, 41.10709836406093, 40.623309304637296, 41.28329515457153, 40.338953156625074, 40.36077722426384, 41.883884552986395, 41.37834595095727, 40.56898447775072, 40.21710864959225, 39.924895994124874, 40.96198243479575, 43.61665825689993, 39.93045007028888, 41.268900056039136, 40.22940920245263, 44.795365795012444, 44.25117615730532, 46.11903628995342, 44.419045755940104, 46.08570398822908, 43.315769318611395, 40.736838386904815, 39.65122438246204, 39.20532541890299, 38.35075862946049, 41.70467145981328, 40.75225330168202, 41.77221859655073, 44.969291533193285, 49.19039726257325, 49.45828730060209, 50.02705843217912, 51.003685459013916, 52.50474122262771, 52.79945635026502, 57.27198600769044, 54.00187853843936, 56.575620174407966, 53.77752288695305, 55.03118299668836, 58.58182622540382, 67.11763720358572, 62.880100665553925, 75.96472355627245, 39.686349207355136, 0.15185160412182733, 2.0197814967363112, 0.45004729902552026, 0.0797897044028486, 14.017158554446313, 65.12011920252155, 56.69465234202724, 63.81289520571309, 68.95145508550829, 44.841073174630445, 32.682719961289436, 51.79595716537968, 55.546351017490515, 52.40755665686823, 4.721034361470131, 0.28697561712995656, 0.09279573231094307, 0.02585112372593534, 0.03570617454486989, 0.008457252537951836, 0.07366885340982869, 0.003470996194781976, 0.026462515515665856, 0.02663501553357609, 0.05490053430079453, 0.06334081607600374, 0.02602121439732371, 0.036349535183680635, 0.0415821876677294, 0.02307157479076376, 0.013594638158176697, 0.049856121111060345, 0.08966418704198253, 0.14963613913184212, 9.46200809171123, 65.92142412739416, 52.492515194800596, 51.6020744077621, 37.999361330463046, 43.10487524155648, 63.70877981185914, 58.42207985539591, 44.70314694989113, 63.05630137843471, 44.67296038904498, 0.7539275348667176, 0.19036967757969134, 2.0365761052216254, 0.9895923601523523, 2.6554872624335752, 47.81488480106477, 52.60280439930578, 62.442791692672245, 57.658594423724765, 57.96442947080059, 57.33241796493531, 54.71429078809677, 52.09068406012751, 49.29463817227272, 44.45289581052719, 43.03783016820108, 40.94839534451885, 43.769567935697495, 44.14016523668843, 43.9531466268724, 46.17999776717156, 44.22040124093333, 41.99137318518854, 43.63913736035747, 43.62812726728378, 45.71215314249839, 50.22227087328511, 53.466824100863555, 53.444799992346, 53.028695352615856, 55.197165935270256, 51.32087576773859, 49.80953162716281, 42.3732590675354, 40.68764402020363, 41.746323108673096, 41.40430027438749, 42.1369597988744, 39.68705131161598, 40.58138701223558, 40.7337083355073, 40.74223164589175, 42.61190783592963, 40.78507961765413, 41.92151185004942, 40.92195464718727, 39.19337787935811, 39.76554970587454, 41.992047832858184, 40.91614169459189, 40.50400257110596, 41.350893282121234, 42.325774854229344, 46.39921119136196, 46.61196447187855, 46.10930881192608, 47.725592044092, 44.01238226121472, 43.605495191389515, 41.23254360691194, 44.03486920941261, 42.05001654163484, 45.657424311484064, 47.655903293240456, 53.01433163304483, 50.85072871177427, 58.32043555475051, 50.51231445804719, 46.4931833359503, 57.5127685454584, 53.54067448646792, 48.58297117294804, 40.902268271292414, 43.283394075209095, 46.880415408842026, 48.67140493085308, 51.96779228025868, 52.77590251738026, 51.67337133038429, 54.5246716468565, 57.302619718736224, 55.89456335190804, 55.25892757600354, 55.55480764758203, 46.96295384437808, 40.444194270718484, 41.51813137915827, 41.71599142013058, 43.671387087914255, 40.853328858652425, 41.983940293712, 42.21774885731359, 43.18773531144665, 42.8986370178961, 41.72753887791788, 42.88410855877785, 43.4237600141956, 44.930624808034594, 41.435330144820675, 42.88358688354493, 43.380288385575824, 47.558149983806, 48.255857267687404, 49.22446696988998, 47.058942087234996, 48.79654030646048, 47.03097166553621, 42.297674994314875, 42.40236697658416, 41.72313797858454, 41.57548819818805, 44.321990628396314, 44.03941523644232, 44.295942168081964, 46.05890635521182, 51.37904843976421, 51.660392207484094, 53.15321883847637, 53.66125599030526, 55.20068037894465, 54.55576427521245, 59.46268858448152, 56.125143804857814, 57.617032989378906, 55.807945651392785, 57.89864740064068, 60.647036490901826, 69.34446873203402, 65.37287281405541, 78.65805041405463, 41.92049595617479, 0.05119071905350974, 3.264169981402736, 0.73052262947444, 0.10022054155988079, 14.93257503355703, 72.75300841177665, 60.12867958314958, 69.77649427229359, 75.22030476600894, 50.83880470645044, 39.39734897305889, 60.59876388119113, 60.56385086428735, 64.20964687101304, 6.385968221772102, 0.18659746064053429, 0.08404390555956671, 0.08633240937225281, 0.0544561228654798, 0.10308008731132555, 0.0052521915565575325, 0.022251318704577226, 0.025889981620674653, 0.045567331084560965, 0.16971361823379996, 0.19844010742681645, 0.20383466876322226, 0.10875431670536918, 0.1224833477528826, 0.20645559344801212, 0.11896891940024593, 0.1349556115606139, 0.19620216541713287, 0.24112514760946077, 12.003817712107013, 77.40709673973822, 58.63395060262373, 58.932552799101806, 42.58168989612211, 66.2387046506328, 72.60158138890421, 65.72548604780629, 50.32719819776474, 70.15472842801002, 48.613938285458474, 1.2136516888295452, 0.4923888866699511, 6.74521271259554, 9.179969083878303, 3.73347397292814, 51.650547058351584, 54.42851474208217, 64.32851429908507, 60.57810083512337, 62.33488728923183, 59.20574195923344, 57.42446814813922, 54.52978249519102, 51.67020597765523, 46.742638234169256, 47.54812440564556, 42.99083625116656, 45.881344579881244, 46.62981125616258, 47.85140206736904, 48.999362145700765, 45.94321604697935, 44.1573138390818, 47.319108978394546, 46.09345459168958, 46.65875050329393, 52.607883868678925, 55.24313611368979, 55.762842316781324, 53.32971372912007, 57.963135088643725, 54.7084778355014, 52.642930246168575, 44.430028392422585, 42.77864779195478, 44.95219784398233, 43.36883114230248, 43.63375586848105, 41.38142893391271, 42.16655800419469, 43.19616056257679, 44.05416727066041, 45.170356150596376, 42.053479994496996, 43.91204018746653, 42.321295507492565, 41.56288170045422, 41.295858506233465, 43.94711009917721, 43.48502351391701, 43.06884042678341, 44.776840440688595, 45.59239925876741, 49.13427599014775, 48.705321665733095, 48.80668747809626, 50.94964696514992, 47.07664766619283, 45.80291286591561, 43.568091469426314, 46.039800490102465, 44.442364246614524, 48.578546739393666, 51.72844925234395, 55.223724303707, 53.43799468009703, 61.125330309714045, 54.01276311566753, 49.40413505800309, 59.41969940739294, 57.27001697786393, 50.305358440645286, 43.634501118813795, 45.38092859329716, 49.445955368780325, 51.62952315422797, 54.45981133368708, 55.96007870089624, 54.21973090017996, 57.05960142997004, 60.14976232282577, 59.69881526885494, 57.08067240253572, 57.12790558415075, 48.978805003627656, 42.08597290900446, 44.49293536524619, 43.02907543797647, 45.79926898402553, 42.69072394217215, 45.154705893608835, 44.213125244263686, 46.40098802505001, 44.318405582058816, 44.16257373748287, 44.557391674287864, 45.785944692550174, 47.9187217066365, 45.156521950998616, 45.19858937109671, 45.54008268540906, 49.90999529438634, 50.36926561786283, 51.13266867976035, 49.122144099204775, 51.54509805863904, 49.855697924090975, 44.070970704478604, 46.0203847577495, 44.05634418610604, 44.784591044149096, 45.93099786389259, 46.48731547017252, 46.819622593541304, 49.992117958684126, 53.755961618115826, 53.31307111247894, 54.82962808301372, 57.06775995992846, 56.05731033509778, 57.979448226190385, 61.61678760282455, 60.62812674430109, 60.07600999647572, 59.27725461221511, 60.09828121431413, 64.6591701046113, 72.97979985513996, 69.6861542424848, 79.93117332458496, 46.322556311084384, 0.22470452792702184, 11.677294123557306, 1.5477335621272366, 0.16344291278191153, 18.609742156920895, 79.01694728482154, 67.46143294918922, 76.93471785514586, 74.50944577493976, 55.4726065358808, 48.084543828041326, 68.94882709749284, 68.39207018575361, 73.8670321433775, 9.212175665363189, 0.4817375066059251, 0.210464883956217, 0.14592504068728418, 0.17538841453290757, 0.1326594315469265, 0.1637867330423286, 0.25758741183146355, 0.10979922232969154, 0.18748825235712915], [0.05350860233809199, 0.04076503615285601, 0.04270566326956596, 0.02893518686534897, 0.0271747091544732, 0.05317690158863703, 0.05219738922953125, 0.10230552645460253, 0.17414750531315806, 0.20428889761528662, 10.66427436567122, 62.03714409182149, 50.00060204536685, 37.60922278127363, 19.21433629528169, 41.270398401444965, 65.8237414206228, 50.73177106918828, 40.58543097588324, 62.40618813422419, 37.44866055826987, 0.5292513521928941, 0.15023235471979265, 0.03919294712344005, 0.9614737464054939, 5.973481478229647, 57.25787724218061, 61.03379395700271, 57.1154873601852, 56.78760467037078, 56.09532594680787, 46.71293020248414, 43.56369449246315, 40.21359028354768, 41.91258453553723, 39.855152330090924, 39.57279266849641, 42.76477044628513, 46.30020272347235, 48.66197555295883, 50.64542401221491, 50.162968558649865, 52.8184013981973, 48.768699322977376, 47.02680610841321, 45.5362505297507, 44.76060575054538, 47.60196678100094, 48.61321656934677, 48.89592924425679, 48.946861220944314, 49.99478124803113, 49.599347499109086, 44.99518702107091, 40.901017035207445, 37.1465439181174, 39.075291002950365, 39.61713506329445, 37.406491156547304, 41.05890027938351, 39.64220685343589, 36.730286305950536, 37.64013890297183, 38.92221658460556, 38.92300105864002, 40.76454993217222, 39.19558225139495, 40.1680790224383, 37.95189280663767, 38.787510625777706, 38.671894842578524, 41.7471311169286, 41.065070167664565, 42.74445256879253, 45.66634378125591, 48.95396463332638, 48.802463085420676, 46.83127203295308, 45.80672148735293, 41.760263212265514, 39.888916092534224, 38.37670510815036, 40.86346034080752, 40.78007859568442, 47.36846808464297, 52.392290792157574, 52.87708397834532, 57.28187038052467, 47.334214025928134, 46.39696759562339, 54.569814205169685, 50.10896536611742, 46.50737447123374, 39.409575000886, 43.382786935375584, 47.564378707639634, 50.11330742989817, 54.543106786666385, 55.58584536275556, 55.071893276706824, 55.80747104460194, 51.327469271998254, 49.33591719596617, 50.973345925731046, 55.01615639655821, 45.12562151878111, 39.89828663487589, 41.70908412625713, 38.665513146308164, 39.124661876309304, 39.88521337509155, 39.518871845737586, 41.131373913057395, 41.02291645542268, 40.093455929909986, 39.164505312519694, 40.83447010286393, 41.30310704631191, 41.86749689040646, 41.33193254470825, 38.90049842096145, 39.86563682556152, 41.1264984069332, 43.24362124166181, 42.164694878362845, 43.75237226486207, 43.81181186245334, 41.51624079673521, 41.866555521565104, 40.44558671212966, 40.407606401751124, 40.78986490926435, 40.40373502239105, 41.49299683109407, 41.28347558359946, 44.71970327438847, 44.938269507500436, 48.65917890302597, 48.037177285840436, 49.63667277366885, 50.11421349740798, 52.01850460421655, 53.09353213156424, 52.99046793291646, 53.22614354472007, 51.411047135629964, 52.42050047843687, 55.78949089973204, 60.81490216716644, 61.434589585950306, 64.73089456558228, 62.53183341795399, 1.3819178145739341, 3.426544584574238, 0.3635161358021921, 0.05057823558848712, 8.077619796799075, 63.98286327239006, 56.139087830820394, 45.84218755845101, 28.153582657537154, 49.67910105182279, 52.03268789475965, 39.48454718435965, 59.45779346650647, 53.06954683796052, 6.208622176801005, 0.21405345429816555, 0.11157702894941454, 0.039492905019752444, 0.06842040802322089, 0.12531591954851343, 0.012173364070364305, 0.07701691044794937, 0.02085987512292641, 0.017413935030720407, 0.08699649268941534, 0.02971830109374658, 0.05581445804226303, 0.027575062873262553, 0.04380575020707423, 0.039456577130383065, 0.03706328015053465, 0.02703702400228189, 0.060153852006600755, 0.20641925023688426, 13.54642608473378, 70.36611280133648, 56.2675807552953, 48.24564733812886, 29.393292857754616, 48.260509198711766, 72.48297675963371, 60.34891674595495, 44.41348775740593, 67.18248182727446, 42.358844357152144, 0.4381118943133662, 0.15798609914077869, 1.2794011542874, 1.3499878827602634, 6.006631389740975, 59.15281741849838, 59.611185596835234, 59.31198327772079, 58.66355665268437, 56.77704172749674, 48.67053416467483, 45.82149313342187, 42.931059329740464, 43.31934652020855, 42.06283092498779, 42.27265419498567, 44.46932269680885, 47.41694073523245, 51.11774406125469, 53.21231326749248, 52.37438124995078, 54.01345737518803, 51.766033403335086, 47.778253786025516, 48.2662711604949, 45.789298319047504, 51.00148893171742, 51.440798313386985, 51.19741916656495, 51.25084969305223, 51.590091566885675, 51.40075875866798, 46.74613306599279, 41.24957061582997, 39.48379801165673, 39.60063757434968, 40.91894226689493, 40.7218078644045, 42.90790557861329, 40.91472179658952, 39.65607243199503, 37.47821561751827, 40.85585094267323, 41.02944720175959, 42.778573266921505, 42.29612958046698, 41.47546383642381, 41.288068679071245, 42.27734142734159, 39.951544577075595, 42.15783857530163, 43.42972986159786, 44.33343218218896, 47.47750605306318, 51.356204555880645, 49.18004220531833, 48.50991702848866, 48.42397789801321, 45.156435658854825, 41.0957117234507, 41.5491416377406, 41.88593987495669, 42.37678527832031, 48.765545737358835, 53.96251363138999, 54.397312287361395, 56.873998795786214, 51.35678114429597, 47.832331503591234, 55.83279386643441, 52.37279661240117, 46.89591269339285, 41.86843433687764, 45.804697544344016, 49.5478860024483, 50.98889420109411, 55.85501801583075, 56.17690340165169, 56.14985865931357, 55.52517414093018, 54.89215850830079, 52.14446759993031, 52.94838874570785, 56.70126938050794, 48.903895578076764, 41.985442561488, 42.808379357860936, 40.38237379443261, 41.38181724855977, 40.597527565494666, 40.629565485062145, 41.97410298931984, 42.929074610433275, 40.70767948704381, 40.99203955742621, 41.89037999799175, 41.83705929786929, 44.33263594104398, 41.56254045424923, 39.94087573020689, 41.353391831920995, 42.87448306237498, 45.69222750202302, 45.666602657687285, 46.66498314949774, 45.922882480006066, 44.851447843736224, 42.61288058373236, 44.72754016999276, 42.32978743891562, 43.075163287501184, 42.51452322929136, 43.374640172527684, 43.23917719625658, 46.36917368058236, 47.499067321900405, 52.089056276506, 50.4987548243615, 52.78454349886987, 52.14261624120897, 54.10751973429034, 55.4233572559972, 55.161017371762185, 55.30357983804519, 53.65000271028089, 54.93720300735966, 57.97313321021296, 64.3578810845652, 65.20642703579318, 66.6647054303077, 67.21473939957158, 1.4780962923842094, 2.265304586579723, 0.36704093698532353, 0.021634520249321096, 9.105497983194168, 70.71964386970767, 60.307586731449256, 55.89810525217364, 37.446746441625784, 52.46559204593782, 56.84944868087769, 46.83004433108915, 65.59742850642051, 63.78212421171127, 8.921012243916913, 0.32093375140140135, 0.17199859804203435, 0.04215210345723937, 0.04271274958286555, 0.021222949088100466, 0.02719315463647006, 0.04624570194151133, 0.02460492658428848, 0.06490107670786881, 0.18037953864662878, 0.11510667946910667, 0.15355245720955635, 0.19729587850311112, 0.19341536737497778, 0.1701361310457991, 0.10217894574687367, 0.23504479968499756, 0.29191777290355775, 0.33758494822729024, 17.027212881272842, 80.25941295008506, 64.40617722849693, 53.674615583112164, 28.57067769573581, 53.291894235918605, 71.25360396600539, 60.013836506874334, 52.372427909604966, 72.07208494986259, 47.159750923033684, 0.9341816495983832, 0.35267059841463644, 2.510338728466342, 3.0422204588690116, 7.809796929359437, 62.66057345174975, 63.194713977075395, 60.84091924851941, 60.98988302292363, 60.40370833489203, 51.71092018004387, 47.1503411569903, 44.16333075492613, 45.46242367836737, 43.77121533116987, 44.65927523951377, 47.55687913587017, 51.775521616781916, 53.79795843555082, 55.98119281953382, 54.908518714289514, 57.62697619776572, 52.87971588873094, 52.90708618779337, 51.50127733907392, 47.47530168102634, 53.71234878416985, 52.155097223097286, 53.5994904272018, 53.500752602854085, 54.433554987753595, 53.01435124489569, 49.71077026859407, 45.131724726769235, 41.01046293012558, 41.987180171474336, 43.90604680584323, 40.60380335777037, 43.413856029510505, 42.637046306364, 39.70324677805747, 40.72361607705393, 43.53595549060453, 42.93129859432098, 45.095889952874955, 43.01995984969601, 43.30627718279439, 42.481214461788056, 43.14100027084351, 42.3553220687374, 45.68381794037358, 45.45117824308334, 46.736182012865626, 49.48891316690753, 54.00791506613455, 50.928646595247336, 52.38160625580819, 49.57218900803597, 47.274111547777736, 45.355986241371404, 43.21286985951085, 44.54993132622012, 43.551311569829146, 50.90364933013917, 56.40127474261869, 56.46936316643992, 60.89547549524615, 52.8260382529228, 51.418225073045306, 58.92274687367102, 55.159299373626716, 50.899789717889604, 43.832035603061804, 46.38027006579984, 51.48519562136743, 54.82250898115097, 58.146407834945194, 57.89341495883081, 58.01201566573113, 60.50647051103654, 57.08874464035035, 52.25304272867019, 56.89672108619445, 59.999339426717455, 50.85494525970952, 44.38742360761089, 43.58373780404368, 40.91225462575113, 43.02536095342329, 42.56250558360931, 43.187994187878026, 44.18925369939497, 45.94636963259789, 43.31550651980985, 43.16889224513885, 45.53980419712682, 44.10279681605678, 45.74528540334394, 45.0380624494245, 41.345562781057055, 44.70794400861187, 45.81909264287641, 48.87781573880104, 46.983142283654985, 48.63992398785007, 47.803980611985736, 47.293703786788456, 46.914124258102916, 47.271671833530554, 45.75773892864105, 45.75942947018532, 44.560870816630704, 46.69236913804085, 46.54092642568773, 48.988948252893266, 51.34661436080933, 54.43440614208099, 52.00492535867999, 54.79551522962509, 55.32518033058413, 57.52458664678759, 59.78070259094239, 58.823930601919855, 59.030184515060924, 57.088893690416896, 58.02080961965746, 61.293784341504505, 66.0816607936736, 67.546446400304, 69.7112338773666, 70.76329984972554, 2.003697082400322, 5.947175612372737, 1.3300999950978065, 0.16679240240445062, 10.991278444567035, 76.4735883282077, 67.25909356148013, 59.57359360110376, 41.082689454478604, 61.52650248619818, 62.1476137253546, 57.52016613560339, 72.18988941561791, 74.95867483077511, 13.61322306817578, 0.6491439284816866, 0.28582314510018597, 0.17313168804732063, 0.17520436956997842, 0.18081047842579503, 0.06726225928193139, 0.2214446399481066, 0.17158691771328452, 0.10751929870175739], [0.020331010154839006, 0.044210581709781004, 0.012421161912742161, 0.11556373518561164, 0.061433682323343335, 0.013789378666138698, 0.0808966861316754, 0.09774780892316373, 0.032475397907077305, 0.09587988738090762, 15.05449014325296, 58.50339451143819, 47.47982809620519, 40.850292944139056, 20.781736989175123, 45.90402764658774, 61.62074527432842, 43.94008513419859, 44.18251114506876, 61.86409304218908, 37.993034547375096, 0.470579466632297, 0.0576159023048897, 1.0714803563971673, 0.5386480028110167, 12.277762909089367, 63.10219703182098, 56.618891762148955, 55.84919329612486, 51.8513527993233, 48.08234730074483, 43.49503340259675, 45.05774882531936, 44.87618623241302, 45.686198819068174, 47.24476045177829, 51.096433824108495, 51.521030395261704, 53.192003234740234, 51.41942139594786, 54.165602191802, 51.71006510334631, 53.55622668420115, 52.27226234251454, 50.414953385629964, 50.25324190816572, 48.767275502604825, 49.113012821443625, 48.46617083395682, 49.035553855280725, 48.78860535160188, 51.12907186631234, 45.4906294422765, 38.159319508460264, 38.0786402763859, 40.53745254393547, 39.54344941723732, 39.59365575544296, 38.81931712550502, 38.983503618548, 38.13009392830634, 36.645582722079375, 37.99985162673458, 38.1182405256456, 39.910736237802816, 39.16964361744542, 40.974302599507, 40.56086517149403, 38.62943126309303, 39.8507357412769, 39.94525701768937, 40.66941676601287, 41.11954404461769, 41.291135972545995, 47.17380085299092, 49.12663913542225, 54.21077220670639, 54.90986016488845, 46.01586226494082, 45.28414018692509, 40.507728822769664, 38.96565683426396, 38.53041495046308, 43.3713649934338, 51.0183943471601, 55.894555507167695, 52.54477685497653, 55.66318273544312, 48.12484618156187, 47.59811109112155, 53.628790532389, 49.18344290025773, 44.957112573808246, 41.489988373171904, 46.14579469926896, 47.72624707991078, 49.49110184946368, 54.30723113398398, 53.671846389770515, 53.45116599913567, 57.37730949155746, 51.928862756298436, 49.291633636720725, 54.16535900485132, 53.194074246191214, 43.02883225102579, 38.325478953699914, 40.771837695952385, 39.62463463506391, 40.90182504346294, 39.23793208214545, 40.46279415007561, 39.381796775325654, 40.234747548257154, 39.095832455542784, 38.905158196726155, 39.43441929355745, 41.2566073479191, 41.21281016257502, 40.443817723181944, 39.92941848693356, 39.34214945762388, 39.34034124497445, 40.49866814767161, 40.601257739528535, 41.900856648722005, 41.363229136313166, 43.143918514251716, 42.365743806285245, 42.82402961484848, 40.787535021382, 40.05024710009175, 38.52820665605607, 41.059657296826764, 41.540747765571844, 42.62069786748579, 43.82215515259774, 46.94323608952184, 45.83402510612242, 46.269694528272076, 46.869377859177135, 47.56538283440375, 47.91239100117838, 49.2834751067623, 44.505792894671046, 48.77580665772962, 48.41957699867987, 51.69313615368259, 54.3111966502282, 63.99277902418568, 65.29832424656038, 71.92509805002521, 8.271343208128407, 2.85269447392033, 0.5870310517568743, 0.03864676473782428, 5.70807675200124, 60.51513894911736, 59.55456226102768, 51.56950696822136, 29.357297266683272, 52.80383763774749, 50.59402919584706, 43.32086055509506, 55.29784141048309, 55.813880197463504, 8.971948142974608, 0.23118629060204954, 0.01747985115094531, 0.10764772568138377, 0.04826807830062124, 0.04141690036762626, 0.08434983511124888, 0.039716955094087514, 0.10825725587745828, 0.08794712353377573, 0.03115203464403749, 0.008743561620283271, 0.05006947276753284, 0.07832774051254796, 0.07254932316080218, 0.03371697362332094, 0.007093255013798274, 0.1273532997396204, 0.04492942116133148, 0.052800154869234374, 18.40065040896016, 67.47018767941383, 53.707645862333244, 46.78810242683657, 22.29462850478388, 51.39634609222413, 69.89212574497347, 50.18590657941757, 48.65546834084296, 66.19294628020256, 41.894423961639404, 0.3794004173288423, 0.06333669835341073, 0.28872358462502884, 0.624438879951354, 14.114591210119187, 63.991417961735884, 58.151044076488866, 60.17441049698861, 55.444840077430975, 49.944731804632376, 46.20683854626071, 46.2985670951105, 47.544013761704974, 46.55528622288858, 50.15898343055479, 51.51275027182795, 53.185315593596435, 54.166131711775265, 52.84359478181409, 55.759857393080196, 54.10777468835154, 56.02147948357367, 53.700036464198945, 53.433715374239036, 53.41111859967632, 49.35177926094302, 51.182541616501354, 51.891176623682824, 50.349273297094534, 51.725711437963675, 52.37793099495673, 48.02991305628131, 41.962669280267534, 40.46142524288547, 40.66651813445553, 39.868288347798014, 41.25672894139444, 40.228291326953524, 39.37433642725791, 39.28383558027206, 39.749891604146654, 39.4883087373549, 40.466673374176025, 40.7256047187313, 41.02245361574235, 41.77215976099814, 41.07744132318805, 40.472909942750015, 42.00182630169777, 41.33853389370827, 42.722051912738436, 42.90366549645701, 44.30006850150324, 49.76286718922277, 51.26511927573912, 54.990398191636615, 54.65062287545974, 47.0208284162706, 47.287914368414114, 41.991906627531975, 41.51905313614876, 40.50843484940068, 45.56399737634967, 52.39939420453964, 56.562342951374674, 54.17212509339856, 58.281082414811664, 49.9620569136835, 51.230104277210856, 55.674090846892334, 50.611542578666445, 47.13365931664744, 45.09169301679058, 47.84421236284318, 48.21792010338076, 52.161145517902995, 55.27992402353595, 55.54899469498665, 55.64935245821553, 58.3512104711225, 51.93010222527289, 50.07295800793556, 56.58925041075676, 54.20574372814548, 45.07972194302467, 41.5904559627656, 42.2189373354758, 41.33797299477362, 41.5389552424031, 40.16973034028084, 40.86263664307133, 41.42056242112191, 41.81010477004513, 39.550592053321104, 40.455373025709584, 40.21393545212285, 42.15199032137471, 42.96960838379399, 42.444599136229485, 41.49273010992235, 41.818863422639915, 40.9498897675545, 41.41517308450515, 42.43881364022532, 44.011637010881984, 43.8443479230327, 44.80658377370527, 44.24078972108903, 43.980654208890854, 42.121376222179784, 42.597795148049634, 40.202301702191754, 43.503176243074485, 43.214379972027196, 44.869541737341116, 46.2622812486464, 49.672268282982614, 48.241058165027255, 49.56354410417619, 48.143771617643296, 51.8713019740197, 50.3504264739252, 52.20705686076995, 48.30625972440166, 52.41610350147371, 50.18712643654116, 55.33889293670655, 55.78495663981284, 68.24334175355973, 66.23125999204575, 78.85056818685224, 9.52127314382984, 2.1828176321521884, 0.021000073043509357, 0.15414972999884238, 6.0107224218307005, 66.62021006307295, 63.61726699336883, 57.22627470570227, 42.41310642611596, 59.39038753509522, 58.35193610960438, 49.515271494465495, 63.11644308028683, 66.40648011238345, 13.166623961540962, 0.3469322014960551, 0.10280402752781108, 0.046834942298911275, 0.02076172968372703, 0.07986421411436412, 0.03025685324363651, 0.014753774195278605, 0.05057235969410789, 0.05006605601539055, 0.09674227255727015, 0.1268073625021404, 0.1769052839447414, 0.1861435688671566, 0.14539034195965336, 0.14469318662679967, 0.13117521280242553, 0.2756850133019109, 0.20581520523034758, 0.2797399166851275, 22.842465946751258, 76.71513572815927, 61.390953217783284, 54.54535430477512, 28.8919335411441, 56.69277744908487, 65.169274345521, 55.55406631961946, 54.736024641221576, 71.40343850658786, 47.38576181473271, 0.6243658258068947, 0.1878101625029118, 3.7927333866396262, 3.190441924718119, 16.056127182898983, 67.67409601519185, 62.04890335759809, 62.054335840286754, 59.527894066226104, 51.62010162107406, 48.248204723481216, 49.473015800599136, 49.917063405436856, 49.93483174231745, 52.612516187852435, 54.282284859688055, 56.67922566013952, 57.44328375785582, 55.163602213705744, 58.03461244029384, 57.18947895111577, 57.75224101158881, 55.911186356698316, 55.17429459479548, 56.213157869154415, 52.568836673613525, 55.72364607164937, 52.420241602005504, 50.98050032892535, 54.518419388801824, 54.73717781805224, 49.43467855453492, 42.32553166727866, 42.43314189295615, 42.2490454489185, 42.41513429149505, 43.46587450273576, 40.84842197356686, 41.33465074723767, 40.4548748846977, 41.07143225208406, 41.988443174669825, 42.60707547587734, 43.08827577098724, 42.971612714952045, 44.72232341766358, 43.2119990933326, 41.9307098081035, 43.27304294032436, 45.38055204576062, 44.448620427039366, 44.94272139764602, 45.68480245528683, 51.254779907964895, 53.08060792184646, 57.669879082710516, 56.53836942488148, 48.297932532525834, 49.5243949274863, 45.65565532253635, 45.16637886724165, 44.85393462642547, 46.95111613119803, 57.70411745194466, 58.482931506249216, 55.330522598758826, 58.20635734065887, 52.97573943291941, 53.8369664069145, 58.25328065503029, 53.33671908224783, 49.98000567959201, 45.90871880131383, 50.60394494764267, 52.027502521391845, 52.86944712361982, 59.68961338843069, 58.29979604290378, 57.05896992837229, 58.56703104511384, 52.35931542611892, 52.29359611388176, 58.26092535449613, 57.40073388622653, 46.93845864265196, 43.55490838327716, 44.70048366054412, 43.746782887366514, 44.5400587204964, 42.65283776867775, 43.44628226372504, 44.35522879323652, 44.7215271765186, 41.61184072494507, 42.344810116675596, 42.64192181248819, 45.74539130733859, 45.79723719627627, 43.62600134265038, 43.33220797200357, 43.594120317889804, 42.45086316139468, 43.87328324779388, 44.819645266379084, 47.97575296894197, 45.19033278188398, 47.780038464453916, 47.92054953113679, 48.71046781539918, 44.88179522175943, 45.345486056420114, 42.98368184797226, 47.64899599936701, 47.77251143609324, 48.241199370353456, 49.84407201890023, 54.04531486572758, 50.717815276115175, 52.11102547184114, 50.78302468022993, 53.84757249586044, 52.23944387128277, 55.68903507724885, 49.83472893314977, 55.333162353884795, 52.652508674129365, 56.90494629644579, 60.036511728840495, 69.34081308303341, 70.03766921258742, 81.26056655760735, 11.728355538460518, 4.627734903366336, 2.350013073413603, 0.31811185121055574, 7.005065814141305, 73.97419914122551, 69.11555920877765, 65.12553207335934, 44.420163631439216, 63.52197693240259, 60.85734613480107, 58.373607204806426, 71.68863404181697, 78.14860513133388, 19.402198214684766, 0.38295914088526084, 0.12791111133992672, 0.22795692356603764, 0.08785976652777003, 0.16762553834386412, 0.16342296385236327, 0.12140902435226787, 0.3302011783084562, 0.20708418391164274], [0.03952122729031309, 0.004937773271869388, 0.029079684454406944, 0.0496508133777928, 0.06770452184061851, 0.023398742214926792, 0.0447373322751974, 0.024483549528785294, 0.03286659687517151, 0.09508150118973949, 18.670523205111106, 54.98505984583209, 52.22135782241822, 45.345093819402884, 29.033127100236957, 37.84942088588592, 42.48482304234659, 38.75706911087036, 44.93024433812788, 61.410278735622285, 35.47168008742794, 0.0986353294443219, 0.014574418648055967, 0.41893530396684525, 0.47086996717318413, 28.048559234988307, 61.53636332481139, 56.80987196583902, 55.62525341587683, 54.01959196213753, 51.59546521402175, 52.37389095367924, 50.82536666624008, 51.66978628404679, 52.51602195924329, 53.5419806357353, 55.23927650144024, 52.70855149915142, 55.68199442278955, 55.580797272343794, 54.540467031540416, 52.145597242539935, 51.61584977180728, 49.521135437873106, 52.834102645997085, 52.71858099968203, 53.70697905940395, 51.843857149924006, 50.28504448552286, 46.53491343221357, 49.0874428902903, 46.91939200124433, 41.7645150615323, 39.01460409164429, 39.163022656594556, 40.106223244820875, 38.514705857922955, 39.9412718895943, 39.890037890403505, 38.95720804891279, 36.14246814481674, 39.805785379102154, 37.255950589333814, 36.273765563964844, 38.68940822539791, 39.67237772480134, 39.97076811329011, 38.0219228036942, 39.19421334420481, 38.79853640833209, 38.558079427288426, 39.47945987024615, 39.99740100676014, 42.40739937751524, 47.58755991535802, 50.003547745366255, 46.87773250764417, 54.59777285975795, 47.57681262108588, 45.982306388116655, 40.91958553560319, 39.33619529970231, 38.64150824085359, 40.44450021559193, 51.38832092285157, 55.36335283710111, 52.03417055068478, 55.538235633603996, 46.74263038942891, 48.91521553839407, 54.13678061577582, 52.732073953074796, 46.03416404416485, 40.74113730461367, 43.625001138256444, 44.85534275731733, 50.211551035604174, 51.02457992492184, 52.532056608507716, 46.769400565854966, 45.942992471879535, 50.593303557365175, 55.612956785386615, 55.136557471367624, 50.98976104490219, 43.66569180642405, 38.85085690406061, 39.31820731009207, 36.913810083943034, 38.995847317480276, 38.50504506018854, 40.45188996099657, 41.17973673728205, 41.50687417676372, 39.709632396698, 39.23222111117455, 38.607909217957534, 39.56744255558137, 41.400452429248446, 41.48765848528954, 39.39908266067505, 39.63507206209245, 39.683054416410386, 40.63030681302471, 38.34388271454842, 41.4347182550738, 40.07160440568001, 41.87553382688954, 38.419325582442745, 41.81598440293343, 39.42862203044277, 40.52117470772036, 40.183560617508434, 42.72655871606643, 38.36256496367916, 40.82002401351929, 41.92740717241841, 43.43220879954677, 41.67662651308122, 44.106530912460826, 42.98476834450999, 44.86065364653065, 43.80578710186867, 47.267698472545995, 44.70901481566891, 45.951480480932425, 46.422568905738096, 53.56490296702231, 57.74935022477181, 64.69228667597618, 59.540433883667, 73.66515559534874, 10.577967512992121, 0.6964989487201937, 0.35149336642315315, 0.07411645560134804, 5.295008517080738, 60.28593524809807, 57.851406374285304, 56.25330725023824, 28.268663037207823, 23.48361461393295, 30.687708354765373, 40.347382330125384, 56.450594625165394, 56.18667402575093, 11.483872244434973, 0.16542726436689978, 0.037419940044562665, 0.034047808693421465, 0.07038437400854404, 0.014451210642413748, 0.032865359643173796, 0.061144909310725436, 0.04147377473512485, 0.09010421262393076, 0.04790766074532463, 0.09091022138994548, 0.057372324649364724, 0.07099855435831894, 0.07379505873447464, 0.02754178401383181, 0.07169718824086652, 0.06277535125733384, 0.046234214453086744, 0.1045327279115877, 20.7779715138097, 63.00168237378521, 58.0773074396195, 51.24227146948538, 30.798689857605968, 47.885565911569905, 50.22735818739861, 41.42999572138633, 51.68746048404325, 66.86003946488904, 39.98810106708158, 0.07195183586689734, 0.10626361164594851, 0.8086072749668552, 0.7338581762967572, 30.433987878984023, 63.57030053292552, 58.76836630605883, 58.755846100468794, 56.46819430012857, 53.36739201699534, 53.82469331064532, 53.194125237003455, 53.92623170729607, 54.14795937076692, 55.396006568785644, 56.34549079402801, 55.86047011037027, 56.501550136073945, 55.76931814993582, 56.271636486053474, 52.9227521342616, 52.95304067673222, 51.4327339203127, 54.97978425795033, 54.98862135794855, 54.379343909602014, 52.76388437517228, 52.98624354024088, 49.64541573678294, 50.705295070525146, 50.34083235648371, 42.439711862994784, 40.678752007022986, 39.86833149386991, 42.014974086515366, 41.879071804784964, 40.4425194186549, 41.14019140120476, 41.21909772196124, 39.89990657375705, 39.208933999461514, 39.256339765364125, 39.551874668367454, 39.45529414761452, 40.74729934815438, 41.147632137421645, 40.14702373935331, 40.19998750379009, 41.08234428590344, 40.98129226315407, 40.24578902029222, 42.930627869021514, 43.93920652327999, 51.72562514581988, 52.08987605187201, 51.19862725657802, 55.12454717389999, 48.67978703591132, 49.04674045501217, 43.98411766175301, 41.50495613774946, 39.63442094864384, 42.1564265220396, 53.56811538819344, 56.990128409477975, 54.47365337802518, 56.87280247288366, 49.29567760036838, 51.87827987055625, 57.34479696519914, 52.76855591804751, 47.1916005688329, 41.74187906326787, 45.08412676472818, 45.5714459573069, 52.621306219408595, 54.5758193539035, 55.1360083395435, 49.272680744048095, 49.133377767378285, 53.61492103145969, 58.58652522487026, 55.49535236051006, 53.80797224660074, 45.873307643398164, 41.304879957629794, 42.89548343227756, 38.63393022168068, 40.68199580715549, 40.12028101951846, 41.56716100631222, 42.26095376476165, 43.02196418085406, 41.04606236180952, 41.91009383047781, 40.201991834948146, 42.98472912080827, 44.53679530851303, 44.1891360282898, 41.56148533667288, 40.09529944389097, 41.307766822076616, 41.319428028598914, 41.13093852996826, 42.61122926588982, 43.21419169825893, 43.20802965471822, 41.27645846336119, 43.14337722716793, 41.77406603290189, 43.75646721932196, 41.8097125330279, 44.2048490432001, 42.23196352681806, 44.144777944011075, 43.7382831112031, 44.06063133670438, 43.83086281438028, 48.64119091341573, 45.832048231555575, 47.15298091211627, 46.26881591735348, 49.7025489807129, 47.467300045874815, 48.23073840910389, 46.98473476594495, 56.280979571803925, 60.331387673654866, 68.14846746383175, 62.54006647294568, 79.10654206429759, 15.351855812534211, 1.0274618022864865, 0.6507748377419288, 0.12139118216451138, 5.935863006499506, 64.97919628697058, 62.541580507832194, 60.45179267083446, 31.904982597597186, 32.9667015229502, 36.311008468750984, 46.638452237652196, 64.19760127221384, 63.312804775853316, 15.192890974783129, 0.08816417922536213, 0.009158011356879388, 0.06050062170552631, 0.0375897204503417, 0.039181551565566373, 0.0423161190513882, 0.054509913729083155, 0.02082158221803125, 0.03399428979103123, 0.1328076695602748, 0.11923924884608678, 0.15456836640594468, 0.2650379233302609, 0.16768887849344363, 0.11077996042947616, 0.17154237736136685, 0.102972857984564, 0.1763134810232347, 0.34340761481754245, 24.85067044534991, 73.11232105378183, 64.94833900082496, 59.05704490600094, 40.034569386513006, 45.420038546285326, 45.961411922208725, 49.055557943159535, 57.54208826249646, 72.75695431617, 44.322092610020796, 0.2566442503443649, 0.20438404573548227, 3.0424246672661077, 2.01333912630235, 32.65624592381139, 65.75149528441891, 62.86291283945884, 60.77583536025017, 59.123317272432395, 55.6514823052191, 57.09605201598137, 55.08890459614416, 55.98279314656412, 55.720939636230476, 58.8518225762152, 59.873329362561634, 57.553996578339614, 59.991937914202296, 58.16595300551384, 56.58461416921308, 54.05228883989396, 53.32314375908145, 51.206448462701616, 58.333622563269834, 57.21659037374682, 57.48159354732883, 55.41943880819506, 52.88163000537504, 52.308728618006555, 52.17083377222861, 51.9370291309972, 45.65269393305625, 43.4372765018094, 42.103953053874356, 44.66037742553219, 42.977374676735174, 44.48098390333114, 43.61193964558263, 41.70263574969384, 39.719956074991536, 43.55656754586005, 40.61165594285534, 41.207856209047385, 41.958672385061945, 42.9717892216098, 43.8762407149038, 40.29761921974921, 42.241196786203695, 43.27907946801955, 42.252697175548924, 42.552617288404896, 45.505095143472, 46.929660766355454, 52.501999485877256, 53.47036992349933, 52.15435981750489, 56.06906567850421, 51.46070041964131, 50.963041859288374, 46.40127435807259, 43.465686228967485, 43.82492826830956, 44.70448840049006, 53.842175314503336, 60.19782312454716, 56.9476059944399, 57.3936265514743, 49.485536006189164, 54.3557979214576, 58.91258009018437, 56.206442771419404, 49.58763922414472, 44.13916503229449, 47.48905351085048, 49.31408528358706, 54.57448182567474, 56.088669684625444, 56.320003232648304, 52.20594290764102, 51.1933869700278, 55.19778959212765, 58.249150399238836, 57.86182418946297, 56.30765953371602, 48.42948882810531, 43.687912033450225, 44.99361807300199, 38.78125836772304, 42.322170196040986, 41.69357115222562, 44.622765817949855, 44.198581095664736, 44.661130520605276, 43.48687487263834, 43.65772547260408, 43.00801623252131, 44.400234068593676, 46.13804801817864, 44.59365790890109, 43.5566303037828, 42.85352976091447, 43.73021087338848, 44.22412749259703, 42.1263184085969, 45.349902645234145, 44.60750387560937, 45.64945013292375, 42.63256695962722, 47.50888501444171, 43.66160861907467, 45.717930793762214, 45.18940710252331, 46.20586187608781, 43.78388850919662, 47.480134041078635, 45.99664657346664, 46.923345750378026, 46.38334520401494, 50.39105046179987, 47.765388411860314, 49.35003772858651, 47.62442627260762, 52.13389288994574, 49.730511557671335, 51.442759498473144, 50.475903095737586, 59.947960299830285, 62.56365952953216, 71.41400537183209, 64.11164252988755, 81.97508119767713, 19.619183732617287, 1.954531888327291, 1.6875598074928408, 0.1859380734423476, 6.712053485455052, 69.90769755455756, 66.29393946739935, 68.93342787219633, 39.077393393362726, 37.22550907442647, 41.447144323779696, 54.48817007003292, 73.8646944107548, 75.15747624058878, 19.357051734001406, 0.24907899419626883, 0.1714092312801269, 0.12161521691708796, 0.11681587525433111, 0.19245334480318332, 0.16618619702996748, 0.15549387722726793, 0.15298025081715277, 0.23267688319808055], [0.05011113262885521, 0.05087858802008052, 0.1445275890610872, 0.09948391737716814, 0.032563651235954415, 0.015914177150285293, 0.04239391144965926, 0.07333160618380194, 0.04174578957439911, 0.135209416489928, 15.74644232949903, 59.31585465708087, 54.91997203519268, 43.48942833562052, 22.187122221915953, 27.204355347541075, 41.159438471640314, 36.29793913133683, 45.56704898034373, 61.975931582912324, 30.907714097730576, 0.06909305620337687, 0.045125417095879396, 0.6250305449770344, 0.9007075296774988, 39.742831337836485, 59.56423482587261, 58.280815693639944, 55.994976028319336, 54.857472988866995, 55.05739227417977, 55.97489349303707, 53.38015933190623, 54.44156839001564, 56.79166040112896, 56.86275728287236, 56.545421846451305, 55.54451927062004, 53.95415113818262, 53.00682029416485, 48.69882229835757, 49.630887277664684, 48.08569700487199, 49.70819719376103, 49.617798328399665, 49.72732659309141, 50.435345788155836, 52.05145643603418, 52.21196374585552, 48.96527674890334, 46.51364634113927, 41.370077594634026, 36.854139066511586, 40.99722493079401, 40.05427537425872, 38.637185788923695, 38.827052039484826, 38.1220373799724, 39.07785623304306, 37.89547343407908, 37.88172944899529, 38.00114993126162, 36.18439435958862, 38.47914564994074, 37.491065302202784, 37.92834681849326, 38.96203648659491, 39.08935662238829, 38.921310517095755, 39.82057271465179, 38.34584389963458, 39.41199902565249, 38.219206256251184, 42.81480420020319, 48.631836060554754, 52.43213030599779, 49.25761099784605, 51.506925552122055, 51.274819297175256, 45.95369269770961, 42.63893688878706, 39.09585206739364, 39.76739321985553, 39.33426157120736, 46.08055391619283, 52.68339733923636, 53.9349550585593, 55.30215209530246, 50.77507011352047, 49.61193438499205, 54.38767502384802, 51.136900917176284, 50.291830185920965, 44.37194201254076, 40.61493112194923, 42.752795450149044, 45.9054789235515, 49.481060581822554, 53.489464021498165, 56.62836820848527, 53.4093927568005, 46.94740949138519, 42.411631614931174, 53.830925956849136, 54.9183246397203, 46.74407382165232, 41.326001921007716, 41.08645492984403, 39.29714025989656, 41.473498728967485, 37.9728578752087, 39.70541977113293, 40.509466432756, 41.60121502414827, 42.32845383305704, 40.34709207473263, 39.20142266058153, 41.20540080531951, 39.390920208346465, 40.63238959158621, 40.54821160531814, 40.24932307581748, 41.470556951338246, 39.9386360568385, 39.86377369972968, 39.70377629803073, 40.75301816386562, 40.27098240390901, 38.383969337709495, 39.45368989821404, 40.15074606864683, 40.405668750886, 40.66194857320478, 40.57981414179648, 39.339595994641705, 39.94530016376127, 40.58238329425935, 42.6593332136831, 40.58122227268834, 43.213167959643954, 42.83053290459418, 43.78381790653352, 43.66588008019232, 44.94511404345113, 45.45941129807503, 49.09389126685358, 55.930621700902144, 63.28343799037319, 61.229888931397475, 67.54016276328795, 67.77347318587765, 69.0548252290295, 12.193072072921261, 0.8867166804209833, 0.07910053936704513, 0.03518294798390519, 5.537637020311048, 59.562144202570764, 60.99103619975429, 58.89166209005541, 49.88102074592344, 36.393174279120664, 29.43236162585597, 45.16871267749418, 54.90930711069415, 54.451864611717966, 10.472085091375536, 0.11426192963676107, 0.038496626826423797, 0.02776294402147253, 0.021828920805766698, 0.014530167494329714, 0.0498767480284216, 0.04381121241397435, 0.02689028752126521, 0.09784836562410479, 0.04956078655537098, 0.058442557140463786, 0.015785241679799174, 0.11144325467607669, 0.037404564659922354, 0.04065976035030138, 0.03892470909763248, 0.049467189763222015, 0.06726850289851427, 0.05295684666282708, 18.107468928060225, 66.75975230432326, 60.938009677394746, 48.226584619091405, 25.225041066446614, 30.760939005882513, 36.983569437457675, 41.266158319288685, 51.13856400212934, 65.23097322833154, 34.89360509380218, 0.0913785232771789, 0.09544240521086801, 0.29404906015242305, 1.1937548532601328, 41.47768389794135, 60.29749055062572, 61.728061322242986, 57.90872789198353, 58.1586613193635, 58.06406551791776, 57.8327476593756, 55.51644686729678, 56.2440465342614, 56.63221605362431, 57.55025463719522, 57.847142757907996, 56.600440932858376, 54.76690938395839, 53.16480551996539, 48.02787734616188, 49.864134942331624, 48.81360261671005, 48.71686520115022, 50.59468423166583, 50.37179554662397, 51.200564907443145, 53.34164165681409, 53.97869340835079, 51.75131667044855, 47.46982997463596, 42.812909695409964, 39.19826515259282, 40.94590463945943, 41.22364374899095, 40.21466109060472, 40.78585232457807, 39.60635246769075, 41.342656304759366, 39.39542701167446, 38.56524951996342, 40.64901259637649, 38.28367825477354, 39.264823852046845, 40.37356022865542, 40.23300993827082, 39.68609033092376, 40.279121322016564, 42.199619662377145, 40.49824060932283, 41.3842216614754, 40.73301799835698, 39.233252694529874, 45.06185554688977, 49.45940909847137, 53.475810250928326, 51.142764860583895, 54.64133470289169, 52.44612140040244, 46.89329255011774, 43.65412081441572, 40.243694474620206, 41.75032784861904, 42.181596371435354, 49.787774239816976, 54.56698225390527, 54.87373905797159, 57.71411949588407, 52.89043180404171, 52.626566117809666, 55.137875387745524, 52.06303135041268, 51.61001328499087, 45.4489307249746, 43.734745133307676, 44.87089103268039, 47.41696426945348, 52.30528085462509, 56.1427003337491, 56.24241090589955, 54.38965974315521, 47.832311891740375, 48.45678067976429, 58.4720665408719, 56.30536102479505, 48.58788198040378, 43.27164657654301, 43.01649639683385, 41.0723618538149, 43.43946126199538, 40.383644642368445, 42.82027982896374, 42.183447730156686, 42.62821705110612, 43.517073200595, 41.37849892339399, 40.86919092362927, 42.893973319761216, 40.61229528919343, 42.498382676032286, 42.429658828243134, 42.89502843733757, 41.601364074214814, 42.637356173607614, 41.608542011630156, 42.0673926414982, 42.70150653777584, 41.86658297815631, 40.116703817921305, 41.47295744188371, 41.31686672087639, 42.70318923457977, 42.62632254631289, 41.77341099708311, 41.471874867716146, 43.45814743349629, 40.54717609959264, 44.6970162853118, 42.908380185404134, 44.894931239466516, 45.11500758509482, 46.93877635463592, 45.537046770895685, 47.64924703105804, 46.49912964913153, 52.403089077241965, 57.842749703315, 65.59101935355895, 64.60618672832366, 71.3761152759675, 68.48275538413756, 71.53604599737352, 20.21797864667831, 1.2937999300418364, 0.1912080842040239, 0.05087203030744868, 5.6435022815581295, 63.78790578534527, 66.71183663029825, 62.94116412439654, 46.3052115901824, 40.24325909153108, 35.883630937145604, 54.339080779783195, 62.33473039442494, 64.24205741574688, 13.797353832952439, 0.17186180538227483, 0.08586858909937643, 0.04588407396729435, 0.034862006939346754, 0.05751316225336445, 0.045718997341370395, 0.0900684822831423, 0.02779058447378057, 0.04681400511594069, 0.1789393852795324, 0.2468047242972159, 0.1849452388142386, 0.23037227621722609, 0.1351862346693393, 0.16672555357217791, 0.12319361085012076, 0.20785302975245062, 0.22134419049947496, 0.28473569861342835, 22.60818277635882, 78.35548662370252, 69.08781236217868, 56.30803608125257, 32.92569314279864, 36.45674021013322, 50.60121105563257, 50.52624279452909, 55.9728067921054, 70.4554408596408, 39.430159599550315, 0.18246772578887402, 0.18490259836037315, 1.2616053608156022, 2.3400755034339045, 42.87991554506364, 61.91486812406971, 64.2896318435669, 59.595692234654585, 61.30224489396619, 58.722039191953606, 60.5742726018352, 57.137107464575, 57.87084171848913, 58.442923330491595, 59.94743862459737, 58.48700684885825, 58.39879274368287, 54.72569704055787, 53.37335401965726, 49.417482883699485, 52.592139474807254, 48.98455912067045, 51.37421607971192, 52.82054301231138, 53.214074411699855, 52.88324602188603, 53.45672792004001, 56.06376263403124, 54.11046935665993, 48.976008353694795, 45.603452497913, 40.44237429095853, 45.40876957678026, 43.40308127864715, 42.96385034438103, 42.57519445111675, 41.706605188308224, 43.82102943235829, 40.5168483334203, 41.07929268190938, 42.67644259237474, 40.414933389233006, 41.18633416391189, 41.625694536393695, 41.12601987777218, 42.923210667025664, 42.35072505089545, 44.323575265945934, 42.98068123479044, 43.93227569518551, 43.332027542975645, 41.39942869063347, 46.754868184366536, 51.46430507782967, 54.34820813517417, 53.95770088318856, 54.32593691733576, 52.180576939736646, 49.355368229650686, 46.27249117820494, 43.343633836315526, 44.70610833937123, 44.80101008569041, 51.43461665799541, 55.737272385627996, 57.62738804663382, 58.038295545885646, 55.94282419450822, 54.703508192493075, 56.016976602615856, 55.06339350054341, 53.79695038641653, 48.454905786821925, 45.32009263192454, 46.68028823791012, 50.08256389248756, 53.51340224665981, 58.72280013176703, 58.3714145998801, 58.454172688145796, 53.63485059430523, 49.57029450324274, 55.77271100013487, 57.572482708961736, 51.40004880966679, 46.08423702178463, 46.32782797659598, 43.05000912758612, 45.436583103672156, 42.42274368962934, 45.83624124526978, 44.758209182370095, 45.13463904780727, 47.07440799282443, 42.048059278918856, 43.387097620194965, 45.47462617197345, 42.06404685974121, 43.81835829827094, 43.78789717151273, 45.26414394378663, 45.0336850843122, 46.16114293375323, 43.87786849852532, 44.34260268365183, 45.29841369198215, 46.200951068632065, 41.92299842834473, 43.31459652992987, 44.13932977184173, 44.575058029543975, 47.78397652410692, 44.12082795173892, 43.17277146923927, 45.3570060576162, 44.89726112734887, 48.03372167771863, 45.13453314381261, 48.67962229636408, 47.711883360339755, 48.84066304852886, 48.560735256441184, 50.661886199828125, 49.77905873329409, 54.90828729444935, 61.04292915713403, 68.91078795156172, 68.21296691894531, 74.4151206170359, 72.81058880590624, 74.43603469479469, 30.345422721678215, 1.5439644095397766, 0.7957005933407815, 0.13856877332493184, 6.1686718560034235, 72.48472613673057, 71.03394339161535, 72.88284670922064, 61.696898091223936, 47.33860315815095, 42.906721022821245, 60.570056053899954, 70.51212695337111, 76.6113890371015, 19.38094485190607, 0.33934655208741465, 0.12757737279659317, 0.11191869650276438, 0.08786875273912184, 0.1615990770439948, 0.23958675112695466, 0.1911834927816545, 0.12489854718648619, 0.17221782176244646], [0.014876869202951991, 0.08235160967395191, 0.027654879658873525, 0.07586378724344316, 0.09237288242025722, 0.01813035555964997, 0.015317789192551808, 0.0715899818967427, 0.11871914409341351, 0.18845222079225127, 13.94795225512597, 61.75862835299585, 54.84387805384975, 49.323424446967344, 23.288121723359634, 21.71625933339519, 27.275860155782393, 35.6943569644805, 46.72538765015141, 60.396283288155836, 27.88162119926945, 0.029044011570212823, 0.10766132374203975, 0.8207253150401578, 1.426763743642838, 43.813298440748646, 54.291412215079035, 56.365141868591316, 57.4490104183074, 60.083078107526234, 55.897120737260394, 56.535227606373454, 55.915430361224765, 56.72938100753292, 54.46750702396516, 55.25257725869456, 53.943368542578916, 51.69320675634569, 48.76246667677357, 48.37470508390858, 50.778929725770034, 50.58092847947152, 51.64238460602299, 50.125957073703894, 50.353015238238925, 51.75242670120732, 51.02349735075428, 49.77815266578428, 50.235014653974964, 46.11878918063256, 43.61159839937764, 37.923306572821836, 37.52652352856052, 37.5241465722361, 36.984177404834384, 39.27744996163153, 38.9104220174974, 38.880702218701764, 37.703630308951105, 37.530057584085775, 36.61032453660042, 36.98741728259672, 37.9327477178266, 39.75380612957863, 35.3099960665549, 38.251793307642785, 39.285396683600645, 38.37042539350448, 38.304223629736136, 39.157786292414514, 39.85901978708083, 37.87177839586812, 39.27064464938256, 41.141324966184555, 45.69878962732131, 52.784115960521085, 50.731845594221554, 50.71224158810031, 52.85904892029301, 47.935466304902114, 43.95666499291697, 39.072294312138716, 38.103284528178555, 40.873117216171764, 42.26928487900765, 47.728608346754505, 52.16046302549301, 57.23485292926912, 52.041764259338386, 50.28108681401899, 54.70398279928393, 52.693705328049205, 52.089511271445986, 52.15801154413531, 44.40693347684799, 39.456674821915165, 41.20672656643776, 46.64779924577283, 47.980604940845126, 49.030439084576024, 52.70515864895236, 55.089328212122766, 48.01354500555223, 39.79454778855847, 55.49605054240073, 51.336345595698205, 42.23275584559287, 40.445210164593114, 38.975705946645434, 38.554337486144036, 39.45504311592349, 41.19665784220542, 40.513561387215894, 39.397074407146825, 42.282452275676114, 39.09474988137522, 38.493827081495716, 40.04045686414165, 40.440146384700654, 42.19378709793091, 42.13482602950066, 42.125153464655725, 40.13735509687855, 38.56092314566336, 38.605987256573094, 39.33817609663933, 38.552321387875466, 39.44494301272977, 39.72554545248709, 40.725000673724765, 41.03060037859025, 41.90486138866794, 40.2593368868674, 42.678427311681936, 42.54704752276021, 41.66518888165874, 40.51071766884097, 43.52349804293725, 43.33311796188355, 44.781527673044515, 43.60781723453153, 41.39234881247244, 41.577700414965236, 45.671560533585094, 46.02018471687071, 57.003303650886785, 61.72919488722279, 66.25634747166788, 63.163848846189445, 65.78555322462513, 60.54762794125465, 64.50794704498784, 18.328080677217056, 0.8903825643562502, 0.23508483543992045, 0.058721757884467804, 3.937855934904468, 56.415261914653165, 60.21187697687457, 55.94286341820994, 51.83894634246827, 37.33354683845274, 26.304292986469886, 41.924441860568145, 58.31448531919911, 61.438586481155895, 10.125493676431718, 0.1372309080174854, 0.046733588866528966, 0.04319247001061036, 0.0908751805282889, 0.049577092736839294, 0.022735865486245004, 0.03519471892486176, 0.05360958421783102, 0.07289852901932693, 0.05467199495122318, 0.0738192824346404, 0.03504156645747923, 0.043332610474598986, 0.12311502555084806, 0.03858319859230711, 0.02415918407120532, 0.04932182841002942, 0.09354140399204147, 0.20601458727352082, 17.346662475216775, 70.38187288468885, 62.697985018453295, 55.87828551569293, 31.932323478883315, 23.939607797130463, 32.38994836807251, 42.966584236391135, 51.8752831797446, 67.2260279809275, 31.126213650549616, 0.053806491797008825, 0.05834136075610596, 0.6309015363935502, 1.844964522507883, 47.41733689461985, 55.00307136966337, 58.18889494865172, 58.374250473514685, 62.28043694649974, 57.11849581810736, 59.06054366019465, 58.533561460433475, 57.92484883339175, 56.29364490509034, 55.45807807676254, 54.28765850682413, 51.48847864520166, 49.57376187847507, 50.4002131185224, 53.19920078400643, 52.68538990328389, 52.80183722895961, 52.706507944291644, 51.17913307682161, 53.20104822035759, 53.87903774938276, 53.264084631396884, 52.35327105368338, 47.98273871021886, 44.58071408733245, 39.54242175625217, 39.07152552758494, 39.448739867056574, 39.92263278653545, 40.75887034016271, 40.50883100878808, 40.522418099064986, 39.86713517096735, 40.17713577516618, 37.79153454688288, 39.85525038934524, 39.368656835248395, 41.0692867155998, 38.052529058148785, 40.23794035757742, 40.54420294300203, 40.842793372369584, 39.76256085980324, 40.74162367851504, 39.808436901338645, 40.62945565869732, 40.539998162177305, 43.81880544847058, 48.831539615508056, 53.33743295361919, 52.89123196755686, 51.76945763249552, 54.526754425418, 51.893137808768984, 45.53382258261404, 40.49651476644701, 40.568843272424516, 43.47333877317367, 43.149017595475726, 50.52128099626111, 53.751466581898356, 57.94373112340128, 53.797017066709465, 53.70753211359824, 57.04714005993259, 54.39462938616353, 55.407240236959154, 53.38364631898942, 44.743731714064076, 43.2627937870641, 44.590029716491706, 50.31760408032326, 50.701890453215576, 52.86163768460674, 54.88090915064658, 55.31664917545935, 47.33580258584792, 45.7448813992162, 58.60445437892791, 52.41005912903817, 44.96291768166327, 41.3118068633541, 41.12088549521662, 39.969481575873594, 40.866272680221066, 41.78139694275395, 43.629688370612364, 40.95087428246775, 43.253176135401574, 40.1977046843498, 40.377992506950136, 40.88248775851342, 42.73132439582579, 44.4430467390245, 43.38796838637322, 43.38534432072794, 42.45384416272564, 40.7743715470837, 41.195806687878026, 40.71742265455185, 40.5128945842866, 41.66454169058031, 41.88640271463702, 43.44730207996984, 44.378880685375584, 45.44404737411007, 43.10323569082445, 44.18917917436169, 44.18480965398973, 44.27277664984427, 43.78043682344499, 45.4217996904927, 45.68893271107828, 46.51530942609234, 45.63514524890531, 45.19921695032428, 44.092363311398415, 46.58793603220294, 48.06923873962895, 59.20329047787575, 62.85485236875473, 66.1651288309405, 66.74845587822699, 68.13078541909495, 62.58995902153754, 64.0425342898215, 26.310929636801443, 1.2706349021004093, 0.4826732370401583, 0.07831886155350555, 3.805448484997596, 63.815327075219926, 64.6578521882334, 63.367290419916955, 51.24205181675573, 47.98913217359974, 31.57768826330862, 48.92788087168048, 66.49799685324392, 69.74954758920978, 14.006963333775921, 0.0837522482259139, 0.058180804048935254, 0.030686488758111675, 0.06674029293560213, 0.05842391439082642, 0.044688881044426275, 0.015375756192952396, 0.048424402372010296, 0.05952736062388267, 0.14173415669750783, 0.15127765104895638, 0.14137552029663517, 0.21834742307903307, 0.2743385984532295, 0.1122904789724177, 0.08753299938454744, 0.12913139747275462, 0.19911572036723937, 0.29886226800660937, 19.747970834855114, 78.93687602012389, 68.96877627218925, 63.87188373073455, 34.67061050476567, 31.12270901280065, 38.093713944958104, 46.31974397167083, 59.54059077847389, 69.06565881544545, 35.15605872677219, 0.14209953467211417, 0.7396807509564585, 1.9240582590141606, 2.7326817137579766, 47.628340798039595, 56.19526793879848, 59.7544893910808, 60.407658161655554, 63.50442824825164, 60.05599414148639, 60.739545591415904, 60.181988516161525, 58.78999425518898, 55.11090517044068, 56.45865117349933, 56.13778952629336, 53.669265470197125, 51.5988149181489, 51.36202927558653, 55.20341819332492, 55.561648261162546, 54.12374657969321, 53.801386587081424, 52.51004818947085, 53.81311447389665, 56.98523329150293, 54.20026025464458, 55.53403477514944, 50.5795007367288, 47.51735341164374, 40.50811321504655, 42.637050228734175, 40.549517754585516, 42.21597202362553, 43.75116417484899, 43.09480259495397, 42.52166194300498, 41.59067561549526, 41.543167867968165, 42.02900048225157, 40.01900149929909, 42.2685121720837, 43.95364869025446, 40.30441276488766, 42.66127086454823, 41.7086918892399, 42.78135422737368, 41.91904860158121, 42.92182607035483, 44.189794986478745, 41.89363948760494, 42.192877108050936, 46.17602832855717, 50.33414079296974, 56.07396079647926, 54.26262986275458, 53.09452056884766, 54.5349011882659, 54.49869378920525, 47.95690205789382, 44.10842933962422, 44.12631534760998, 45.656820266477524, 45.15733780399446, 50.952165126800544, 57.513756982741825, 61.274639252693426, 57.485876775557, 55.84516109958772, 58.90772811828121, 56.65425192925238, 57.63334220455539, 56.68025332112467, 48.060072160536244, 43.797624649540076, 46.538631839136926, 52.01836732126052, 53.5238592855392, 53.154313179754446, 58.01855425680838, 57.81711701423892, 52.16684472176337, 47.037996630514826, 56.814610189007176, 55.08122851771694, 47.18152792223039, 42.9332362451861, 42.974660396575935, 42.22704487462198, 41.535432953988355, 45.61702782107938, 45.31148695176648, 42.92516792974165, 46.11338415453511, 41.89149002875052, 42.53791624499906, 43.175375923033684, 42.98974975462883, 46.69081980182279, 45.57610965544178, 47.51018724133892, 43.61067664238715, 41.4668228549342, 43.73316441812823, 44.21794975957563, 42.98133234823904, 44.861755832549065, 44.530040987076305, 46.314535064081994, 46.769314273711174, 47.173953825427645, 45.88745171023954, 47.40450289941604, 47.49880844546903, 46.00246737080236, 46.01598385841616, 49.37408578011298, 48.62954539637412, 48.76258827024891, 47.7468865917575, 47.15589131078413, 46.595412069751376, 49.36348753590738, 50.64642421660885, 62.64465255122032, 67.0797549524615, 70.33345514728178, 68.02463039275139, 69.77150501743441, 66.06870912736463, 66.9212676632789, 32.56190115405668, 1.6894991743949153, 1.1207665310752009, 0.13087075413955798, 4.215613920842448, 69.81465893407022, 70.45322079812327, 70.99175437804192, 64.16875616196664, 50.80329548928046, 37.366055442440896, 58.221411397380216, 75.65215772198093, 80.98671451691659, 20.22323070033904, 0.36519831166632716, 0.2051696689018319, 0.13231748054104467, 0.21017044572339905, 0.2957103371379837, 0.08069138222884747, 0.1162246009334922, 0.1377161787522416, 0.21027170722523045], [0.004965654563068623, 0.03664273618450088, 0.057811676073939576, 0.01619634169694637, 0.04974125388769373, 0.0259369159973557, 0.03725700846482669, 0.015697655805026092, 0.03524934099386296, 0.11353510371859997, 11.674249383711047, 52.428851204533736, 48.756312477973204, 39.261062299051595, 20.827942509805005, 24.35280792174801, 24.1236924740576, 34.87287536744149, 45.87900684725854, 59.915655659091094, 29.193469670511064, 0.05029311681526804, 0.11653333436697723, 0.3914154032545705, 2.8372442578115775, 47.96977527679936, 54.83280912522347, 54.588147363355084, 54.334075835443315, 53.46861270166213, 53.827913576556796, 54.758774388221006, 55.984107140571844, 54.548955040593306, 52.867176071290054, 51.36349231966081, 53.9577518740008, 53.897872970950225, 53.225237477210264, 54.041000258538034, 53.16833957549065, 53.17841614446333, 53.83733903208087, 52.85087470085391, 52.646715333384854, 53.85755100557881, 52.66226753111809, 50.45339653568883, 43.01757897100141, 39.86122415911767, 38.61961357055172, 37.86591053009033, 38.59798562142157, 39.39792163910405, 37.19153742636404, 37.47008846652123, 37.90292593740648, 38.57850320877568, 37.15047021065989, 34.59338295844294, 38.148886003801906, 38.39505003344628, 38.618232896251065, 38.523174255124985, 38.500761831960375, 38.21942983135101, 39.28186655044556, 38.4876532708445, 38.20390509020898, 36.66796768865278, 37.62553984119047, 38.60586566309775, 39.134212847678896, 38.50868894207863, 46.87805806436847, 51.37400427172261, 51.26532323898808, 48.87965140804168, 53.589464849041356, 49.20339207495413, 44.57179069519044, 39.558483862107806, 38.344926065014256, 39.78443199588407, 41.83404299520677, 45.700084009478175, 52.21986339938257, 56.552854737927845, 52.653218623130556, 46.959357030930065, 50.02052768584221, 51.92303803659255, 53.6193689992351, 52.29748318272253, 50.544862285737075, 41.992420458024554, 42.208641113773474, 42.12469846971574, 45.42454534961332, 49.45635749447731, 54.25098826808315, 50.91219225237447, 56.3168574917701, 45.3777632405681, 47.30384703605406, 52.995523868068574, 43.13250833942045, 39.68086573385423, 36.69880536294753, 38.30304691868444, 40.842456048534764, 38.27079326875749, 40.06952162711851, 38.92908857714745, 39.69247987193447, 39.523602224165394, 38.251542275951756, 38.87015496530841, 39.4988638354886, 43.13989808482509, 42.577575329811346, 42.78033048875871, 39.33367321568151, 41.40371191886164, 38.24541945611277, 40.19092682869204, 38.59810329252674, 39.023539250896825, 40.99298484863774, 40.85281502815985, 40.972439473675145, 42.91835085038216, 40.33425023478847, 41.80344850786271, 42.53504507003292, 43.02769084130564, 41.15402167843234, 41.18927594154112, 40.21566521736884, 41.91758555750693, 40.58289712475192, 42.84832085332563, 43.00529802999189, 45.221688209041474, 45.18467280172533, 57.41385813682311, 60.3020405000256, 64.44427128761046, 64.07068121817805, 66.04213114707701, 61.01950476246496, 68.0368132745066, 30.46413325494336, 1.0976798279631523, 0.4533153688234668, 0.04923926711442971, 1.9773473350271105, 49.748997688293464, 65.29213082405829, 55.07051260240617, 49.18920486204086, 20.110980310747703, 27.395584621737083, 42.76644922071888, 53.273035480130105, 58.51023904738888, 11.876061212631965, 0.14144549476763896, 0.05183374644407342, 0.049664300355699756, 0.07459351387355598, 0.12066158300806439, 0.040960139594972134, 0.017322866328721567, 0.03046115357128363, 0.07810051117332713, 0.03291859509303205, 0.05369291926223425, 0.053004899527877576, 0.028359967832183166, 0.04151245068398215, 0.0033696690966720667, 0.027685871745850292, 0.05992042118563287, 0.03454178601743714, 0.016248272882113536, 15.445359233886967, 63.22663030316753, 54.25703264051869, 46.438136792952015, 21.00439033200664, 24.41944899097566, 22.289041088473414, 36.061341762542725, 50.968227232656176, 67.60653711134388, 31.980572554372976, 0.002609901397766906, 0.14258797701087692, 0.49477549570222057, 3.453766323866383, 49.60910635609781, 55.01439132998067, 54.96051757566391, 55.984067916870124, 55.400713412992424, 55.88352972461332, 53.658047491504306, 55.5493712425232, 57.880949666423184, 52.85484806183846, 54.61606679424163, 54.90556516954976, 55.571634615621264, 55.8310523340779, 54.77773512563398, 56.149478189406864, 55.22183764365412, 55.599338316148334, 54.64568461141279, 54.235467449311294, 56.67955121686382, 55.75091046671714, 51.063913453009825, 46.797017974238244, 43.113151442620065, 39.96770081981536, 39.15196157270862, 40.49119603249335, 41.2169639525875, 39.451218805005475, 39.355156037115286, 40.61735122434555, 41.29422287787161, 40.227012634277344, 37.970265188524806, 38.51309768615231, 39.35574047027096, 39.50670465346306, 40.52026864021055, 40.708883654686716, 39.60978454159152, 41.65182144411149, 40.24141557755009, 39.910661712769546, 38.527594766309186, 40.776901475844845, 40.84577829607072, 42.40908991905951, 39.24577290011991, 49.275822562556115, 53.85175374246413, 53.44001470073577, 52.65116330116026, 55.73520921891736, 51.0783399305036, 45.78775290519961, 42.14960552030995, 39.85214387216876, 42.08971485014885, 43.388509673456994, 46.238421470888206, 54.39540601545765, 56.5552552284733, 54.01031947905018, 49.29561484244562, 51.728829722250666, 55.363670549085064, 55.43739149647375, 54.815613454388036, 51.748731828505, 43.10927614088982, 44.65689828318935, 44.983533659288966, 48.25697514318651, 51.46297931671143, 56.24318753519366, 52.19210086330291, 56.77872834667083, 46.43049209348617, 50.45710709787185, 55.20928998147288, 44.672132768938624, 41.701733604554214, 38.73271903684063, 39.72941683184716, 41.75022194462438, 40.88764959766019, 40.36691573358352, 42.144106357328354, 42.00831390196278, 41.41103890634353, 40.0101016413781, 39.72785180614841, 41.770551589227495, 45.38733774615873, 44.57392838693435, 43.59674830590525, 41.90402592382124, 42.33717718432027, 42.36097420415571, 42.47549956844699, 41.33355640595959, 41.77179498057212, 42.19806248141874, 41.83324283169162, 42.68717027479603, 43.97659455576251, 42.97046738286173, 43.380217782912716, 44.076748355742424, 43.5863697144293, 43.21317972675447, 43.67838459630167, 42.52523522223196, 44.0182932730644, 44.50170186258132, 43.81439278202672, 46.34485890788417, 46.95356761255572, 48.74849127184961, 59.917185383458296, 61.75589053861557, 66.86234581855037, 65.16828983060776, 68.14322717728155, 64.66958399741881, 68.30686846087056, 34.05206841807212, 1.298775579179487, 0.20794086939384862, 0.06839366389378425, 1.8672986208431184, 54.74655228276407, 66.91609013465144, 59.30960632139637, 50.24860174425187, 26.313253641128544, 31.976277559034287, 47.717370756210826, 59.67434360134987, 66.68939282817226, 15.910339547741799, 0.21249665638371823, 0.05886852500900146, 0.05700978503051785, 0.05473981288472011, 0.06212187059704335, 0.01211694935562029, 0.03725109043561163, 0.009066717616552788, 0.0641800845492511, 0.15314707412354409, 0.3081200115623013, 0.28990216493125887, 0.17757331261471396, 0.15579778430683, 0.11943345979577112, 0.11980245370538005, 0.18668323184453672, 0.13815971301688304, 0.1826909178447339, 19.010586815495646, 71.52684411694928, 62.51443770623977, 51.69454428457445, 30.175464460926673, 35.284994879076564, 34.24460188035042, 46.201645328152566, 56.55224284818096, 71.99068007930633, 35.81691142051451, 0.1835581293750194, 0.43044338483483563, 0.9415159915243426, 3.743286517358596, 53.24129566069573, 55.4254400345587, 56.92015724797403, 56.108261923636164, 57.002715295360936, 55.8248039983934, 55.46071783188851, 57.144359927023615, 59.85290558107438, 56.328918780049975, 57.712040639692745, 56.8610941979193, 58.39404667577436, 58.32969627072735, 58.05390265680129, 58.7400193368235, 57.54721872268185, 57.78329833861321, 58.18553347741404, 58.17787308846751, 58.709832775977354, 57.97157210688437, 54.463984735550426, 47.98989703578334, 44.05239828171269, 41.59263680058141, 40.8238483244373, 42.15514390699325, 44.32116300828996, 39.709738300692656, 41.70399288977347, 42.24047114772182, 43.274835463493105, 41.78732364408432, 39.59481677701397, 42.18738186743952, 40.527199468305035, 42.942320454505186, 41.99314609650643, 42.846602855190156, 41.76358545980146, 43.2970517681491, 41.62947177886963, 42.27376030337426, 40.40767308204405, 41.75447771626134, 40.94625373040476, 43.202742299725934, 42.008019724199855, 51.23000621795655, 56.20965911496071, 55.783909366976836, 53.17755714539559, 57.99682040368357, 53.58781353119881, 49.17522553474673, 43.76810881399339, 42.541991587608095, 43.636564285524436, 46.123766668381236, 48.89294039818549, 58.386303917054214, 60.20825270683535, 57.94233083724976, 52.10178436771516, 52.243083830802675, 56.90319299697877, 57.25923830463041, 56.587481421809045, 54.09302265413346, 47.25832400783416, 47.87313592049384, 48.77214708635884, 49.005492810280096, 53.31081574962985, 59.16617308893512, 55.977686220599765, 60.072879945078206, 48.699849959342714, 51.19301042249126, 56.73149124268563, 48.406790071918124, 43.04778514369842, 40.05425968477803, 40.237830531212595, 43.81604409986927, 41.339467417809274, 42.56729871995988, 43.56432991643106, 45.07343438363845, 44.65956941727669, 41.801946240086714, 42.68888435056133, 43.714725355948175, 49.54890974106328, 48.169337626426454, 45.79402085273497, 42.543827256848736, 45.30920805469636, 43.9679535742729, 44.40440354808685, 43.55100170258553, 43.25646700397615, 46.37007190335182, 44.68020108438308, 45.35401328917473, 46.97421889151297, 44.54825255178636, 46.319186995106364, 45.89192321223598, 46.65464378172352, 45.421274092889604, 46.894143704445135, 44.49379044194376, 47.74337999282345, 47.02591965275426, 47.80036810905703, 47.050869849420366, 50.51440508134904, 51.526874726818455, 63.67773425194525, 64.62567306333973, 68.76875892762216, 70.17944720483595, 70.97120900307932, 67.87387801754859, 71.5795607720652, 40.994989179795795, 1.6428862175633832, 0.5893429825382849, 0.19326130709340497, 2.3701679273959133, 61.3786526649229, 75.3176030805034, 66.96264082385649, 63.35920641499182, 29.47328567504883, 42.15359849314536, 61.03425679668304, 69.44015103001749, 78.28849254115936, 22.496171651347993, 0.46100903662943077, 0.15961449563262925, 0.18483506004896857, 0.2001703936125963, 0.19129148053546108, 0.060214277191628376, 0.14716237993730655, 0.1117928818829598, 0.15926990928428789], [0.01996501164901401, 0.06318455712208826, 0.01706809421340304, 0.05786815973659677, 0.04591319679973587, 0.03951211084401415, 0.05744514130656758, 0.03170256457862354, 0.02883208866771912, 0.13642092325514363, 13.254837086123805, 55.38944052111719, 48.1432617095209, 41.39481598331083, 28.967707849317982, 52.20735888327322, 68.77923950072258, 48.95489031268705, 45.024542039440526, 56.398587919050655, 32.84345084621061, 0.16650968531687416, 0.03318576442618524, 0.1953126760500093, 2.8896088802045394, 42.9623519989752, 55.897995425808816, 50.86927760031916, 53.77126670652821, 55.87941123593239, 53.56020004518571, 54.85302502109159, 54.39461369668284, 54.86190526716171, 56.16820750697967, 57.02828914888444, 53.18769647229103, 54.34549385501493, 54.06417754388625, 52.44374444407802, 49.08373232810728, 47.80249011132025, 45.83776704726681, 45.96899386375181, 45.190203343668294, 43.15890589068013, 40.64203862221011, 41.016848548766106, 38.7537350962239, 38.61591085310906, 37.51267756185224, 37.759594686569706, 38.53078365325928, 38.846267730959006, 37.27150670943722, 38.90748416223834, 37.42958214975173, 37.493885486356675, 37.19128247230284, 36.377374972066576, 37.30526262714017, 37.31317012540756, 38.46120865114274, 36.9947717266698, 36.9989529732735, 38.23234619632844, 37.91752107681767, 39.33224155056862, 36.86406266304755, 37.32283092314197, 38.28050505730414, 39.202728809848914, 40.74951940967191, 38.57665185005435, 43.76535138776226, 49.94973282660208, 52.327038241970925, 47.889609875217566, 52.34741887738628, 52.09348071006037, 44.69886764403313, 39.83834889627273, 37.057984644366854, 39.96029538493003, 38.80866789048718, 46.69192983258156, 51.69237521386916, 52.659549328588675, 53.25588295536657, 47.41604251246299, 45.69421614370039, 51.13911705632364, 55.93579530715943, 56.623276972001605, 50.240019598314845, 41.68111762692852, 42.277372806302964, 42.78116987597558, 43.028075233582534, 46.58674363167056, 50.101010799407966, 52.29222328432145, 50.38242909216112, 52.982540822798214, 50.16839711896835, 50.3561923580785, 45.05905105221657, 39.21192284553282, 38.637181866553526, 36.732996663739605, 38.28319580324235, 40.30993938446045, 39.10068442744594, 40.493521998005534, 41.270684734467544, 39.96986596815048, 37.927072048187256, 38.46151067364601, 38.94398181669174, 39.729350151554236, 40.01680497200259, 40.3019416716791, 41.255336499983265, 39.56948611044115, 39.75505344329342, 40.155390154930856, 39.60688591003418, 41.44332393523186, 39.821753348073656, 40.683513764412176, 41.71467350375268, 40.66651813445553, 41.74895501905873, 41.85665938162035, 40.56666243460871, 42.16042341724519, 40.33558776301723, 42.4247480207874, 42.77332121326078, 43.12964893156483, 43.394836456544944, 45.83935952955677, 44.763218049080145, 45.628524288054436, 43.45916332737092, 49.573126454507154, 54.58103610623268, 57.45359566903884, 61.06619665699621, 66.3935519802955, 62.3866625755064, 73.33104810407086, 25.238965480558335, 0.9358859807252885, 0.5132972647345836, 0.09852413944299183, 1.8876590315372714, 48.736163262398016, 63.888510657895004, 58.000021057744185, 53.113363635155466, 27.921896096198793, 24.0810739609503, 42.4951780996015, 56.077898856132265, 54.64442945295765, 13.834209403684063, 0.056212502005960674, 0.01874760026112199, 0.05477359353174126, 0.038712843651733095, 0.04117749789128861, 0.058881000750848365, 0.03129607066512108, 0.0412388998384197, 0.041271293866297895, 0.03352645521743163, 0.03067781472758901, 0.08139805237372076, 0.025235702313723105, 0.03936642773389336, 0.018737857537944953, 0.026507251220004215, 0.040609428373676155, 0.02478145622468043, 0.10248604741307998, 16.397573428769267, 61.44176360099547, 52.74324878569573, 44.48391391384987, 38.239096595395, 50.34717875142252, 50.85504331896382, 45.81299335725846, 51.05679435114707, 62.83461293866558, 37.1450141937502, 0.0856030400421831, 0.0412225783351929, 0.2626313960119601, 3.304971946823982, 46.31307202000772, 56.674730623922045, 52.629527507289765, 54.695788967993956, 57.985563201289025, 55.29577432140228, 56.88551879698231, 56.57382765123921, 54.94047818645355, 57.444550683421475, 59.39640052856938, 54.63106986015074, 55.62933268085603, 53.72575152304865, 53.11308122450306, 51.428333020979366, 50.47335747749575, 49.466532122704294, 49.71866599975094, 47.72625100228095, 45.87698290424962, 43.96295647467337, 43.976673003165956, 41.22833882608722, 39.258355863632694, 39.33621883392334, 39.963849052306145, 41.38613185574932, 39.95082678333406, 39.52604586078275, 41.09305627884404, 39.47951870579874, 39.92952046855804, 38.22177933108422, 38.617911261896936, 39.208039699062226, 39.38781761354016, 40.3016867176179, 39.937067108769575, 38.24525471656553, 40.72514972379131, 40.92551615930373, 41.917381594257975, 38.32731854531073, 37.273993492126465, 40.940150522416644, 40.222952981149, 40.40836341919438, 40.22136049885904, 44.83325589087702, 52.72051080580681, 53.41808865147253, 52.42325005992767, 53.4824312117792, 53.47578279433712, 47.2052857183641, 41.94101387454618, 39.7991055826987, 41.46389284441548, 41.92557934791812, 48.439326132497484, 55.66335139736053, 55.85515137641661, 55.55808674904608, 48.4603500366211, 48.464680333291334, 55.37347647451586, 56.860482308172415, 57.210628371084894, 52.53866187987789, 43.170680845937426, 42.58649087721302, 44.92106991429483, 46.5914700877282, 48.84251832962037, 51.75046551612116, 53.14080845925116, 52.74532371951688, 54.10468386065576, 52.6040203340592, 52.13854482097011, 45.535587649191584, 41.53755887862175, 39.9455786520435, 40.08392849276143, 38.69492307786019, 43.24810451076877, 40.59744911809122, 42.13883076944659, 41.22899386190599, 42.341993854891875, 40.501221610653786, 40.485908677501065, 40.798811835627404, 41.79280319521504, 41.90389256323538, 41.79508601465533, 42.52226991038169, 41.09333868949644, 41.808684872042754, 42.81635745879143, 41.758372629842455, 42.218411737872714, 41.70196894676455, 43.20670781597015, 42.5592617834768, 43.35802893484793, 44.42374083303636, 43.32339048385621, 43.520795529888524, 44.39265604942076, 44.43984216259372, 44.65174428878292, 43.98292526122063, 46.31744154037968, 46.21589922135877, 46.39862283583611, 46.367891065536014, 47.723862278846006, 46.72451688397316, 51.7915052752341, 57.35438323790028, 60.520830308237386, 63.76671714167442, 69.93841755774714, 64.11126205998083, 73.57761613784298, 28.441733698691095, 0.7141570915137568, 0.10416019467576858, 0.1060613337904215, 1.8099990439030433, 53.34244182032924, 68.03940203882033, 61.831360863101104, 57.09003902250721, 31.433631373989968, 31.6659317862603, 51.091652454868445, 63.53114351149529, 65.31257029502623, 17.23102904135181, 0.1116439773731174, 0.013615269863587475, 0.046292230291592504, 0.06538483058853496, 0.044973383116866314, 0.013586490813101973, 0.05379584317486133, 0.022318789983288418, 0.04059918577812853, 0.1792619082956545, 0.20213424468473082, 0.22547256171462998, 0.17433971677336002, 0.12980475811468017, 0.12324917520726882, 0.22167169308710485, 0.1273744361054513, 0.11322663841588844, 0.24146031107633348, 18.725754099507487, 72.23376504836544, 64.12421764866, 53.605350448239236, 41.32272281954366, 65.278853601025, 79.61175903197258, 59.308425687974506, 58.20967566582465, 65.62721890787925, 42.15493209900395, 0.3539928355284276, 0.1492257151872881, 0.658221212365935, 3.7878215985913433, 48.66712562499508, 59.42086435133412, 53.95755575549219, 56.090340614318855, 59.81085385045698, 56.35049573836788, 61.7794482938705, 58.339804218661406, 59.28712721793883, 61.082074411453746, 62.420493018242624, 56.47561934686477, 59.10210509454051, 57.6861333847046, 56.74723955892748, 53.98683232645835, 53.148288419169766, 50.87309014412665, 52.22138135663925, 48.85877655398462, 47.80713419760428, 44.89015771496681, 46.41552432890862, 43.161733919574374, 41.15018167803365, 40.52205724100913, 43.3629632765247, 43.175697557387814, 43.278867660030244, 40.13820625120594, 43.994178541245006, 41.48453235626221, 41.947171995716715, 41.29521131515503, 40.05544424057007, 41.2103469141068, 40.65639057467061, 43.13453620479953, 40.93133695663945, 40.064202893164854, 43.17173988588395, 42.25410922881096, 44.2674579158906, 40.844805548267985, 39.838015494808076, 42.892886823223485, 42.31389007260723, 43.833514336616766, 42.323029195108724, 48.01901278957244, 53.45062863442206, 55.87063297148674, 52.88143388686642, 54.7533497502727, 56.35658325687532, 49.26709136655254, 44.36858446367326, 42.141698022042554, 43.71656102518882, 44.35990033611175, 51.68799784875686, 56.26560388072845, 55.79967729506954, 57.6679257423647, 51.172543494932114, 51.60529467367357, 57.962542810747706, 59.90630472860029, 61.129766510378936, 55.5889008891198, 45.890315040465325, 43.35068625788535, 47.356763732048776, 49.47369044826877, 51.12482001704555, 53.3595629661314, 55.07171677004907, 54.58569588199739, 54.57604685137349, 53.31151393152053, 54.512053382012155, 48.85351665558354, 43.94209338772682, 42.20149847768968, 42.290171500175234, 41.475781548407774, 45.152030837151315, 43.15550519574074, 43.78288830480268, 42.78975594428278, 43.963070223408366, 42.62243547747212, 43.031499462742964, 42.72381697931598, 43.8743148311492, 44.77347896945092, 42.75281506199991, 44.62370326442104, 43.08931912145307, 43.60765249498429, 44.69406274057204, 43.09059389175908, 45.98043149517429, 44.86296000019197, 46.41282181585989, 45.6556200212048, 46.827251603526456, 48.12595228995047, 45.64268796674667, 45.712921927052165, 46.74485829568679, 44.8965629454582, 48.99907973504836, 47.767047574443204, 49.3749330120702, 47.60700702667237, 49.52351239419753, 49.96976829344227, 50.9138318031065, 49.41166600873394, 53.644174068204826, 59.76933556218302, 62.96594958151541, 68.62738886187154, 73.60817924622567, 66.46118933154692, 76.89437235555341, 32.183782708260324, 1.0427418855890151, 1.9556953613796544, 0.19075891153225977, 2.184921003157093, 60.13583790871405, 75.79249228200605, 71.19097940383419, 68.98153181998961, 39.93228181715935, 35.73628710162255, 61.4167231898154, 70.89249487846129, 77.95683260886901, 24.37102537001333, 0.14920490823926466, 0.12379420080011892, 0.10353302913567713, 0.2665981379968505, 0.19283493319826742, 0.2055249651593547, 0.2425363734965363, 0.10034506915197258, 0.19998061831199354], [0.009863012387687642, 0.06554057626354118, 0.07033599555612573, 0.029294215886282827, 0.053421942472097375, 0.06898568131990972, 0.024837625791288676, 0.03309301033075298, 0.10909495004002126, 0.14165255301181348, 12.044455428277294, 59.53660565037882, 52.38109634768579, 47.75169541758876, 14.992832445329237, 55.82572575538389, 76.90205235635081, 55.04100068922966, 39.26882466962261, 49.848496452454604, 40.46082904261928, 0.5648916010414401, 0.0991551890488594, 0.18225682178331962, 5.130837223222179, 43.6867117881775, 53.734172851808616, 58.56046107507522, 59.29246164137318, 58.953541401893865, 58.0025549088755, 54.79462485159598, 55.74142617564048, 56.50784554020051, 53.49946998780774, 49.12705098429034, 46.651321534187566, 44.7373813967551, 42.51167951091644, 41.73326161599929, 38.646921111691384, 37.46524041698825, 37.819975653002345, 38.54808522808937, 38.02255430529195, 38.6785707166118, 37.45570905746953, 38.00957518239176, 39.032290058751265, 37.813986193749216, 37.45737606479276, 38.57328253407633, 37.96892373792587, 37.97116733366443, 38.66913741634738, 36.752679117264286, 36.97990594371673, 37.83517875979024, 39.86585647829118, 37.882996374560946, 37.15787172317505, 37.95849415563768, 36.36777300988474, 36.993159632528986, 37.86693034633514, 38.14885854721069, 37.819371607995805, 37.304423239923295, 36.86043839300833, 38.66363040862545, 39.53040361404419, 38.615467625279585, 40.454780747813565, 38.00606073871736, 40.283200586995775, 50.277548836123565, 50.32376220149379, 46.971335949436316, 49.51751116783389, 51.719506248351074, 44.782504343217425, 39.711185655286236, 38.14605013016732, 39.201108870967744, 38.96957135969593, 49.62237965676093, 53.171732425689704, 54.35453884063229, 52.88508953586702, 47.81443765086513, 55.89745413872504, 50.557806107305716, 54.308384310814645, 50.32560963784495, 45.578012004975356, 40.320019875803304, 43.65667819976807, 44.81415787050801, 45.67972298591368, 44.802135805929865, 48.24330568313599, 50.85434513707315, 51.871223526616255, 51.87423198453842, 46.70053943510979, 47.931559624210486, 42.609617171748994, 40.25828176929105, 37.73807264143421, 37.18922322796237, 38.34904847606536, 39.160241696142386, 39.9196360957238, 39.36584449583484, 39.921805166429095, 40.138653401405584, 38.67660560915547, 37.17273750612813, 37.50164785692769, 38.80918172097976, 39.377301739108184, 38.550168006650864, 38.18380686544603, 40.37378380375524, 38.97382713133289, 39.81600707577121, 39.57844872628489, 40.49977033369003, 40.59887293846377, 41.83121104394236, 39.46115416865195, 40.071423976652085, 42.37136456274217, 41.81570983702137, 40.113887556137584, 40.83988297370173, 41.096947270054976, 43.27373719984486, 41.86864614486694, 41.460962833896765, 42.923551913230654, 42.776004114458644, 44.360673043035696, 45.99390091434602, 44.45922651598531, 46.61891098945372, 46.517851121964, 52.26562961455315, 54.42587890932637, 62.46892252276021, 60.59631239983344, 74.03913790179838, 27.07171451660895, 0.6085578159939858, 0.21815792357008304, 0.05041985074058176, 1.070437251079467, 45.746513105207875, 66.67095768836238, 56.0549843695856, 42.03386029889507, 21.979699442463538, 20.915256431025846, 43.6531598337235, 49.123979768445416, 64.1627980816749, 17.877757280103623, 0.012341361406499581, 0.03147840150631964, 0.03660404108344548, 0.007721142112953409, 0.10404715074166175, 0.06085419043477985, 0.043809595968454115, 0.029894566433804653, 0.021350883856235493, 0.05331915262485704, 0.14736592949878785, 0.056557448415626446, 0.061860596310467496, 0.047781014920122204, 0.09464073250250471, 0.027045845504729982, 0.050674230235839085, 0.07532654510390374, 0.060377335175871856, 14.429639904729783, 66.61478150275447, 56.62772493977701, 53.92580024657711, 22.63683176809742, 58.677794856409875, 76.57247128025179, 58.21705756648895, 44.16002419687087, 57.33332795481528, 43.57897212428432, 0.424073854040715, 0.1240988433240883, 0.14104513721840997, 5.085774583201255, 46.12426873176329, 56.44721746444703, 61.12790730691726, 60.696293615525775, 61.081682174436516, 59.530922135999134, 58.20152498060658, 57.40343247690509, 58.79983155958114, 57.021252416795306, 53.71410600600704, 48.75793633922454, 47.81357080705705, 46.05997716226886, 43.68094982639436, 40.66801647986136, 41.00585414517311, 38.79275875706827, 39.573322188469675, 39.286895029006466, 40.77766633802845, 39.41701573710288, 39.28951909465175, 40.797403704735544, 39.77715207684425, 39.90302485804404, 40.129988885694935, 39.231056167233376, 40.22074860911216, 40.04252003085229, 38.501581607326386, 38.305239523610766, 39.950136446183734, 40.931419326413064, 38.764121532440186, 37.885353719034505, 41.00259857793009, 38.7723663545424, 39.82827624967022, 39.786063701875754, 40.676041649233916, 40.718971990769916, 39.5593350164352, 39.12854894515007, 39.71502957805511, 40.3986830096091, 39.443389754141535, 43.59885069631761, 40.09087893270677, 42.10745573043823, 51.50110475478634, 53.78063724886987, 51.188174140068796, 52.03378615840789, 53.0831378506076, 46.33719851893764, 41.19754037549419, 40.4221466279799, 40.63250334032121, 39.8784904326162, 51.96973385349397, 55.05544285620413, 55.541895204974765, 54.63056387439851, 51.67615621320663, 58.32021982439103, 53.75723246605166, 55.10810459813764, 54.08491511498728, 49.05662875021658, 43.353008301027366, 46.21493824066655, 45.745760010134795, 44.88734929792343, 45.99433237506498, 51.37171360754198, 51.86955651929302, 51.97131849104359, 56.061530805403194, 50.3422365650054, 49.57751558672998, 43.675505576595185, 42.229665017897084, 39.91638445085095, 38.61110594964797, 38.3870287864439, 41.15884227137412, 41.38772041566911, 41.06912982079291, 41.72491873464277, 40.87024211883545, 40.43487864155924, 39.29093899265413, 39.40172241580102, 41.048972760477376, 42.76269551246397, 40.374497675126605, 40.1686595332238, 41.48253194747433, 41.188981763778195, 42.432404487363755, 41.596064952112016, 42.57434329678936, 42.07198181459981, 42.4652974836288, 42.255062364762836, 43.170629855125185, 43.1368935492731, 44.121867379834576, 42.745068380909586, 42.6741244716029, 43.06323928217734, 45.30230076082292, 44.78718373083299, 43.14585616511684, 45.59223451922017, 44.86328947928644, 45.942741440188506, 47.63348694770567, 46.85936404812721, 48.94841840190273, 48.768718934828236, 55.03565842105497, 58.81099462509156, 63.696824427573915, 63.25276505562567, 75.14047668826196, 29.1753287084641, 0.6983112063138717, 0.8649418875575067, 0.04978916885691786, 1.0431152461997926, 51.28855935988888, 71.83835875603461, 60.129522892736624, 51.18354966563564, 23.898436638616747, 26.15646277704547, 53.653238665673044, 56.942491223735196, 70.89171040442683, 21.49226453996474, 0.15541028171297044, 0.03987538207682871, 0.044365078661470644, 0.019802149017191222, 0.04675944050353381, 0.004425145058532156, 0.004853878025671528, 0.025911968344101505, 0.0457228814071465, 0.18382933982197316, 0.18223324159701026, 0.2694956663875811, 0.12045126889021167, 0.22580066185084083, 0.15679800402252905, 0.12215947642201379, 0.09173538235406722, 0.1754695126005719, 0.21132713123675317, 16.168549176185362, 76.60996913909912, 65.61219230774911, 63.30584649116763, 25.656988159302745, 65.16648161795833, 80.80030779684745, 65.16851340570759, 52.371055080044655, 63.07172413795226, 50.10462722470684, 0.620669788650928, 0.3199807073800795, 0.3149716874524471, 5.689094931848588, 49.75885068216632, 59.420319141880164, 64.56850059570806, 63.612214980586884, 66.24051678565242, 62.72422175253592, 59.929129000633, 60.35297247671313, 61.03419403876028, 59.43716964414043, 54.14482147462907, 52.081274294084125, 49.281239355764086, 46.31469980362923, 45.048821510807166, 41.1483891548649, 41.78449561519008, 40.99218076275241, 42.43322818509994, 41.57362899472637, 43.373459539105816, 40.976436368880734, 40.894258791400546, 43.39140046027399, 42.67344197919292, 42.061811108742994, 42.47194982344105, 40.605215411032404, 41.951184580402995, 42.367881498029156, 40.92996412707914, 41.066752864468484, 42.13720690819525, 44.91018925943683, 41.26031791010211, 39.60665449019402, 43.11605399654758, 40.33941991867558, 41.718756691102065, 43.33509875882057, 42.696223105153734, 42.837047961450395, 40.835572288882354, 41.19190785192674, 42.06714945454752, 42.046423650556996, 40.606246994387725, 45.74292805887038, 41.77774129375335, 43.13942347803424, 53.82032771264353, 54.25614226248957, 49.986877672133915, 51.44338707770071, 56.40409100440241, 49.32763707253241, 42.61060560903242, 43.006823831988925, 42.91507174891811, 43.2283632216915, 53.507385330815474, 55.67541660801057, 57.2889934047576, 57.257367334058216, 54.04831940127958, 60.13424150405392, 55.44514994467459, 59.553691494849424, 55.06834745407105, 50.734395134833555, 44.63646665696175, 49.54481870897355, 48.567222856706195, 49.199697202251805, 49.00125272812382, 53.8316672848117, 53.581353387525006, 55.00395390295214, 54.69761287012408, 51.1300406917449, 52.61341048825172, 46.40983689215876, 44.74141751566241, 40.860993169969134, 39.72407848604264, 41.59082074319163, 43.35658158025434, 43.74255849469093, 43.834977380691036, 44.73507896546395, 43.29211742647233, 42.43392636699062, 40.927391052246094, 40.8917288626394, 43.606762116955174, 44.35341665821691, 42.19217500379009, 42.94693316182783, 45.53677220498362, 44.652662123403246, 46.150831022570216, 44.02247059729792, 44.75497322697794, 46.35019333131852, 46.07688257771154, 45.10002805340675, 44.57485798866519, 46.43138639388546, 46.17396908421671, 44.4560258619247, 44.685272709015884, 44.82901188635057, 47.52137776344053, 46.825235505257886, 44.43429200879989, 47.43256353562879, 46.4131316831035, 48.626878184656945, 50.8856927194903, 49.91712616335962, 52.005113632448264, 51.90881552234773, 58.44511593541792, 60.957299893902196, 66.99656932584702, 65.23658221767795, 78.31762006205898, 31.831118483697217, 1.3336414050671364, 2.6217310995824876, 0.15202017410868598, 1.0588950639770878, 55.623833517874445, 77.56345810428743, 65.98668452232116, 58.31821941560315, 33.05014210362589, 30.875884063782234, 62.13029253867365, 65.43133966384396, 83.3231919811618, 27.15377442298397, 0.2339139006911747, 0.11618554577111237, 0.08813010363449013, 0.07939109353408699, 0.3224569793430067, 0.17502243900972028, 0.10420924728556026, 0.10623142829224949, 0.1303243189449272], [0.028749412458930767, 0.02327541546565631, 0.030366580017031203, 0.11868342907438356, 0.042766892846914074, 0.03297448120710831, 0.009127145674410126, 0.04110560053959489, 0.05289066049660887, 0.08573919684896547, 4.851014354536611, 54.4932887631078, 51.95189883632045, 42.9234185526448, 30.711521064081502, 22.618241694665727, 51.577485069151855, 38.695252556954664, 36.46340039468581, 49.02673244476319, 46.010418015141646, 1.721403733376534, 0.07420162925676954, 0.1556805422108981, 3.0201610490199062, 45.150928651132894, 58.288260352227, 59.350234231641224, 54.74605806412236, 57.62868242879068, 53.792635779226984, 50.9783822490323, 47.063707766994355, 45.47180991018973, 43.374349917134936, 44.67684745788575, 38.33293930176766, 39.31952522646996, 39.29432007574266, 38.02665710449219, 37.89147653887349, 38.42655451067033, 39.916529578547326, 39.6824856727354, 37.04467604237218, 39.02277438871322, 38.51387039307625, 38.28257606875512, 37.42175702125796, 39.091251127181515, 38.86294564893169, 37.352699772004165, 38.089344424586145, 38.43605449122768, 38.09505931792721, 38.02829665522422, 36.31532699831071, 35.976728393185525, 36.75455793257683, 37.04841013877623, 36.63695743007045, 38.48347986898115, 38.27556287088702, 37.735028882180494, 39.25297437175628, 36.920654619893725, 39.019797309752434, 39.3142927846601, 37.49514064481182, 37.196118754725305, 38.73793971153998, 38.73036169236706, 39.965363087192664, 37.8489698133161, 39.87132818468156, 48.40697834568639, 51.47479349567045, 42.07631211127005, 50.8657866908658, 50.65708129636703, 44.1768237083189, 41.60958928446616, 38.50380559121409, 38.12928592005084, 36.94114900404407, 46.64915638585245, 55.05241086406093, 55.44716604294316, 48.65884157919115, 50.70324367092502, 54.059643283967056, 49.906739727143325, 50.48189255499071, 44.39080076832926, 42.11351971472464, 42.13380229088568, 42.407638642095755, 42.561336717297955, 44.25321186742475, 44.64794743445612, 48.54022518281014, 47.474952590081, 50.79339542696553, 47.0983854416878, 46.527457006516, 48.67903001846806, 39.535094768770286, 39.50624965852307, 39.00622198658605, 37.80760057510869, 38.88057278048608, 38.215225050526286, 39.083116131444136, 38.19569164706815, 39.53569489140665, 39.796599188158595, 37.66414773079657, 37.893433801589474, 37.58987765158377, 38.8450361067249, 40.104175767590924, 38.42890008803337, 40.14434868289579, 39.09786816566221, 37.920478543927594, 39.53476921204598, 39.31797196788173, 38.946146965026855, 38.470508590821304, 39.437988650414255, 39.29107627561016, 42.23708221989293, 40.5196096820216, 42.92855685757053, 41.90201374792284, 42.427678031306115, 41.0937270041435, 42.637034539253484, 41.174076757123395, 42.72186756134034, 42.008772819272934, 43.503960717108946, 43.31148609038323, 46.82724375878611, 45.05556798750355, 49.206043597190614, 44.69610629543182, 51.587651852638494, 48.40842177790981, 62.3747464149229, 59.02909409615302, 75.604289116398, 26.033708280132664, 0.4313219344664005, 0.3603853796037936, 0.051288552311879974, 0.8189012290489289, 41.17941118055775, 62.85918266542497, 55.87875227774344, 46.99632144743397, 28.411366708817024, 23.39903066235204, 31.66663192933606, 53.20828891569569, 52.098297380631976, 17.40770436102344, 0.17421061563636028, 0.04203133352641617, 0.019329627900714838, 0.0829419493675232, 0.05728465737774969, 0.011194607265473855, 0.020505492425253315, 0.030810296227554643, 0.02093402668833733, 0.06660252734417878, 0.01371603245065818, 0.009651265685416518, 0.12999539143375813, 0.04182025332063918, 0.03628766592291575, 0.023163447885083097, 0.09362707560461375, 0.06446622988028873, 0.25394590481394724, 6.704822596042388, 63.63998143903671, 58.0070185661316, 50.38291938843266, 28.46422653044424, 32.73073761693893, 59.81927125684677, 47.8128687027962, 45.205712395329634, 54.08048283669257, 50.326272518404075, 1.828275082572814, 0.19688042902177383, 0.1729955389014175, 3.440836230593343, 48.34323983038626, 59.38274283562938, 62.18943011376166, 57.186717602514456, 59.40986210300077, 56.58015443432716, 54.19361183720251, 50.558002225814334, 49.9227390750762, 45.76177504754836, 45.972873087852236, 40.498334746206964, 40.82163218528994, 39.8691551916061, 40.904492255180116, 40.11665674947923, 40.42470793570242, 41.05310301626883, 40.50572841398178, 39.48586902310772, 40.48712461225448, 40.17255052443474, 41.23687390358218, 38.44791181625859, 41.31963591421805, 39.48766154627646, 39.32848391994354, 39.00069536701326, 39.78342002437961, 38.787118388760476, 39.82253782210812, 37.264273858839466, 38.47655688562701, 39.430642051081506, 38.987975120544434, 38.754864738833525, 39.836501459921564, 40.12732167397776, 39.96197023699361, 40.86040089207311, 37.325317705831225, 40.26581664239207, 40.20330582895587, 38.86960191111411, 38.691310574931485, 40.01799737253497, 39.881498890538374, 40.656488633924916, 40.23456319685906, 41.05465627485707, 52.29477282493345, 54.35920646113735, 46.25755087021859, 52.719130131506155, 52.173340166768725, 44.82355979181106, 42.72895920661188, 40.418071285370864, 39.475568879035215, 39.45095208383376, 49.54172003653742, 55.83618279426329, 56.149686075026, 49.86257776137322, 52.53677129745484, 55.10159738602177, 52.79052511338265, 53.26692834977181, 45.61862030336934, 44.50798549959737, 43.24004404006466, 45.67458860335812, 45.35481737506005, 45.633819487787065, 45.81539384780392, 50.60518441661712, 50.962775138116655, 54.487024737942605, 51.42235925120693, 49.091263278838134, 49.40896741805538, 40.595464398784024, 41.22631880544847, 39.97516116788311, 38.68620364896713, 39.14984349281558, 40.703431560147195, 40.22796577022922, 40.54019820305609, 41.08824745301278, 42.46148493982131, 39.9257000800102, 40.1977046843498, 39.52893272522957, 41.989498292246175, 41.03306362705846, 40.350822248766505, 42.40097845754316, 40.02966250142744, 40.48872101691462, 41.26815872807657, 40.89320367382419, 40.74549505787511, 41.17497497989286, 42.39641674103276, 42.840401587947724, 43.129641086824485, 43.11788182104788, 44.53340638068415, 42.519900798797615, 44.625178075605824, 44.52561263115176, 45.326886177062995, 44.1481041139172, 44.67914204443655, 45.00945268138763, 45.655427825066354, 45.9533396843941, 47.992015115676395, 47.566594846787, 51.544435178079915, 48.954129372873616, 53.86295210930609, 51.24547212354599, 64.42236877256825, 61.2328032524355, 79.03904591837238, 28.89634228521778, 0.6933785193870146, 0.5263706164494638, 0.05236159251522153, 0.561926473052271, 45.91064076269827, 69.42810150884813, 61.43242835998536, 55.02727239362655, 29.719181022336407, 30.249132456318026, 41.61486487234793, 60.08408615666052, 63.14861436044017, 22.171122873983077, 0.13902179175807586, 0.10153271227834687, 0.018690656945710222, 0.05728154323033749, 0.04200315298212152, 0.02813127334980715, 0.03998422401867086, 0.046427793380233555, 0.03489143620695799, 0.17260743875897702, 0.15505752886735624, 0.09005455480467889, 0.23522312963201156, 0.20219396889930774, 0.16463064017795748, 0.17862119832106177, 0.20488500595092776, 0.2436204491964271, 0.4482751231520407, 8.859875240633565, 72.12335032801475, 65.03948311651907, 56.16676407475626, 41.24275745884065, 31.944673061370853, 59.883884460695334, 51.09494724581319, 52.47910068881128, 62.567358324604655, 55.37533175560736, 2.396122495974264, 0.37124136643063643, 0.17090444062506, 4.466421056178309, 51.534986188334805, 61.60803679497012, 65.6264462009553, 58.72411804814493, 63.91744206028601, 57.855077712766594, 56.60097045283164, 51.33466289889429, 53.096352315718136, 47.55217229166339, 48.81432825519193, 42.55908919918922, 42.64832704297958, 42.9477450924535, 42.795702257464015, 42.49371505552723, 42.458343121313284, 43.98157204351118, 44.444235217186716, 41.583870303246286, 41.651813599371145, 41.16940913661834, 43.89399728467388, 40.65088356694868, 43.20396215684953, 42.28152659631545, 42.190845320301676, 42.42210826566143, 43.16336954793623, 41.00926268485285, 43.33298460129769, 39.94497068466679, 39.137586086027085, 40.45811868483021, 41.078959280444735, 41.52820794813095, 41.08926726925758, 42.524391912644916, 41.147404639951645, 43.023333088044204, 39.94344488266976, 41.55813955491589, 42.42404591652655, 41.18785996590891, 40.279046796983295, 42.25900434678601, 41.590683460235596, 43.18601731331118, 41.560536123091175, 42.821483996606645, 54.1608835804847, 56.288679184452185, 46.89899959871846, 55.9216590850584, 53.86089286496563, 47.73385647804507, 46.1452651792957, 43.52311365066036, 43.137721169379454, 41.1938690370129, 51.46617997077204, 57.12013536883939, 58.341180970591886, 51.40865056745468, 55.766388139417096, 57.10465377376926, 53.98606354190458, 55.38638499475295, 47.762050474843676, 46.90125103919737, 46.25747634518532, 47.83086061477662, 48.36080028164772, 49.63958317233671, 48.62859618279242, 52.311042816408225, 52.31223129457044, 54.731392322048066, 51.59965038299561, 54.68012302152572, 52.52543957002702, 42.87319260258829, 42.80117004148422, 42.311081655563854, 39.62308922121602, 42.32175050243255, 41.87537693208264, 43.583118069556456, 42.36359826980099, 42.91808412921044, 45.13109714754167, 42.48008089680826, 42.44230454967868, 40.71038592246271, 42.64130600037114, 43.59470475104548, 43.11093138110253, 45.23843672967727, 42.74955949475689, 43.44313652284684, 44.19017545638546, 43.5460477490579, 43.96468231754918, 43.28779889691261, 45.630124615084746, 45.32340703472015, 44.81747227330362, 45.21003092488935, 46.69681710581626, 44.28578715170584, 47.15033723462013, 46.213945881012954, 48.025602371461936, 45.63434508539016, 47.45552116824735, 45.99228489783503, 48.57895466589159, 49.082885096150065, 51.64398101068313, 50.71729752325243, 55.93070407067576, 52.399382437429125, 57.7142567788401, 53.71562004089356, 67.49928382135207, 64.33414682265251, 79.8142788487096, 31.350790915950654, 1.135007921726473, 1.6758970075076627, 0.12495793432237641, 1.1416092707264809, 51.10007770599858, 73.39792451550885, 68.18634187021564, 62.5489467190158, 42.98005757793304, 36.09174797611852, 48.52374338334607, 69.44783103081488, 73.73745272236486, 29.52433140047135, 0.1862485688780585, 0.24162931007242974, 0.10254678286371693, 0.18831967225959226, 0.10757110156719724, 0.0731581562168656, 0.10145054934846778, 0.19281113850733927, 0.10383963284473266], [0.02920296906884159, 0.044053449415631836, 0.06127987868122517, 0.05406174846293946, 0.024102302042827494, 0.032605142557933446, 0.07362716290498934, 0.12037130463267527, 0.03577657802511127, 0.1380732829772657, 2.3538219399990576, 47.26240327281337, 57.92315044710713, 42.59291571955527, 43.17368538148942, 31.4031506353809, 41.9691058897203, 34.4622306669912, 40.71767760861305, 51.04095582039126, 50.908968064092825, 3.1398583035315237, 0.1266378578880141, 0.12482822031503725, 1.998454589516886, 46.676279575594016, 56.20626626476165, 57.20004581635999, 53.23198003153647, 54.119851666112105, 46.20653652375745, 43.81622845126737, 42.55468829985588, 40.40019704449562, 39.69565306940387, 39.678539768342056, 38.29004033919304, 39.522315686748875, 38.44138499229185, 40.582873590530895, 37.785105782170454, 37.56533145904541, 38.138852580901116, 39.67129515063378, 38.91998475597751, 39.19532337496358, 38.53876567655994, 39.09842906459686, 37.00712327034243, 35.91707698760494, 36.60923019532235, 37.27608019305814, 36.33128712254186, 37.89857602888538, 37.061820722395375, 37.18048810958862, 36.654784602503625, 35.368415847901375, 37.02602909457299, 38.070175801554036, 35.91044818201373, 37.50589578382431, 36.60601777415122, 37.867397108385646, 37.186042185752626, 38.767843861733716, 38.73193456280617, 38.841494206459295, 37.98367184977378, 39.56113930671446, 37.229651097328436, 39.17353460865636, 40.415255023587136, 39.67840640775619, 38.229761354384884, 45.055081613602184, 49.85455259200066, 45.45237064361573, 49.277407200105735, 50.31300314011113, 41.676881467142415, 41.73557973677113, 37.97205771169355, 39.20590985205866, 38.08442577239006, 44.39642544715635, 53.84385016656692, 53.50493384945778, 52.096873560259425, 50.36169544343026, 53.78428505313013, 50.64392566680909, 44.31962543918241, 41.43203927624611, 42.843806205257295, 41.291206575209095, 41.924265353910386, 44.02747554163779, 47.302191795841345, 50.30838258804814, 50.10817304734261, 52.23918107248122, 49.15009098668253, 44.32426560309626, 50.27531700749552, 44.868027702454604, 38.80295691951629, 40.47828751225626, 38.790326887561434, 37.398112973859234, 37.138589351407944, 38.39949015648135, 38.92330308114329, 38.94932800723661, 39.51039952616538, 39.745843718128825, 38.59902897188741, 37.82493745127032, 37.078577087771514, 37.1629080464763, 38.57054864206622, 39.5189973615831, 39.1252149305036, 36.455485051678075, 37.07730231746551, 38.21487988195112, 38.95123820151053, 40.36971238351638, 38.76666322831185, 40.24101157342234, 40.57168699079945, 41.329249643510394, 42.106608498481016, 42.529137980553415, 41.30296191861553, 43.86385386989963, 43.08694216512865, 43.90192439479213, 42.1896097736974, 43.71193655075566, 44.13066917850126, 44.82633290752288, 42.596241889461396, 46.582130924347915, 46.76570177078248, 49.54590520551128, 45.94432607773812, 52.396923111331084, 51.17071174806165, 64.7606300538586, 61.83665606283373, 78.31228563862463, 25.187409847013413, 0.6109200634302632, 0.3619109058091718, 0.1422985030278083, 0.5023020337666235, 41.153645130895804, 65.02649222650837, 57.929347791979396, 46.350416906418346, 24.88281426891204, 22.146274658941454, 39.0858696353051, 49.451344705397084, 53.131904678960005, 15.039351755572905, 0.07658675207846588, 0.03572249221765707, 0.07401413689818113, 0.03408094582658622, 0.04184591343566295, 0.012562985854944395, 0.028594459684926177, 0.011250115123637503, 0.02978817788854001, 0.023922388209030036, 0.08199124191437038, 0.040960495825856924, 0.05722643469550437, 0.0247024342552909, 0.06410829061942716, 0.05178185547852228, 0.035296953358356996, 0.05192183123360719, 0.18947010649548424, 2.6800074692695373, 54.33387579456453, 64.187634529606, 50.72418520527501, 41.9572328752087, 27.407404684251357, 51.14539677096952, 39.21737101770217, 47.631961145708644, 55.53362684865152, 53.97279416361163, 2.981438675234395, 0.1508904242467496, 0.14396834487636245, 2.5402850441394316, 48.20244635305097, 57.1999163781443, 59.000786350619414, 56.23460146688647, 55.054740751943285, 48.53376896150651, 45.65131718112577, 42.965246708162375, 44.22428046503375, 41.52692141071443, 43.182538170968336, 41.26155345670639, 42.44829793130198, 41.517797977693625, 42.654347881194084, 39.950265884399414, 39.739764044361735, 37.31981854284964, 41.06940830907514, 40.707550048828125, 41.568325950253396, 39.614005011896936, 41.212849386276744, 39.444691981038744, 38.05702801673643, 38.41792137392106, 38.84162364467498, 37.683379111751435, 40.28273382494527, 38.021934570804724, 40.67682612326838, 38.52797915858608, 37.88314150225732, 38.899325632279925, 40.099445389163115, 37.29958303513066, 39.696923917339696, 38.88781739819435, 39.3373445541628, 38.30143482454362, 40.103901201678866, 39.54490853894142, 39.47425880739766, 39.533816076094105, 40.10254013922907, 37.139569943951024, 40.72440447345857, 39.51407478701684, 40.39021461240707, 40.42446867112191, 46.50999853687902, 51.26229516921505, 47.74381929828275, 51.28029492593581, 51.450906261321045, 44.31442045396374, 44.18160507755895, 38.787369420451505, 41.42493978623421, 39.55109803907333, 47.21118888547344, 55.667462041301114, 55.595129612953436, 53.44737698954921, 52.415942684296645, 56.82947989433043, 53.37433068983017, 46.43888596565493, 43.96942838545769, 43.53682233441261, 43.37172585148966, 42.83441997343495, 45.60484886169434, 48.08872507464502, 52.108660282627234, 52.900476994053015, 54.61128150263141, 51.773505518513346, 47.15112563102476, 51.13179399121193, 46.89329647248792, 41.64220771481914, 42.91375775491038, 39.92300541170182, 39.18845138242168, 38.953489641989435, 41.136759327303984, 40.93307848899595, 40.52260245046308, 41.25082969665527, 41.92945072727819, 39.90108720717892, 40.118127638293856, 39.43041063124134, 38.99955003492294, 40.13613523975496, 41.671696093774614, 41.67467709510557, 39.287177439658876, 39.35921176787346, 39.9827705660174, 40.43285469855032, 40.50464976218439, 41.583513367560606, 43.31694602966309, 42.20851167555779, 43.979010735788655, 43.60280444545131, 45.35093422858946, 43.22537045325003, 45.8050819366209, 44.01804224137337, 45.73407134702129, 45.13196399134975, 44.90048139326034, 44.821461323768865, 48.303423850767075, 45.94510662940241, 49.65187195808657, 49.14363868774907, 52.25433711082705, 49.17488821091191, 54.5291196146319, 53.95118190396217, 66.2072786208122, 65.0218677520752, 80.6100885329708, 28.148432585500903, 0.6271537729809362, 0.7011658950678764, 0.04141814909094284, 0.509749205122071, 44.38311292279152, 71.15113596762382, 63.56723716182094, 51.51629609446372, 25.501701524180753, 24.786090581647812, 43.592602360633116, 57.30862486747004, 63.62637865927912, 19.061183429533436, 0.04863730203660746, 0.08319089729939738, 0.02820095287696008, 0.03595551701202508, 0.07336201221351663, 0.039212907544307174, 0.057900641864586266, 0.043369773399805835, 0.0158923618390315, 0.11813305618782198, 0.20633511846103977, 0.2820769138634205, 0.15916178363465494, 0.11745863834456091, 0.16475954213209693, 0.15605892835845872, 0.22974351721425212, 0.164791917007777, 0.28512579058447196, 3.1847662550787774, 62.23583175290016, 73.97556412604548, 55.92879387640185, 53.03024076646375, 41.507588048135084, 54.4850282515249, 47.15113739813528, 55.86935427881057, 61.69664313716274, 61.0680401709772, 3.3067983004354664, 0.3549860838440157, 0.3638830612744055, 2.607240883573409, 54.047895785300966, 60.307300398426676, 61.625777675259506, 58.81065730125674, 58.73781104241648, 48.71258197292205, 48.36823317312425, 45.683829707484094, 45.567190185669936, 43.76395502398091, 44.27756194145449, 43.86677211330783, 43.98643578252485, 42.69241840608659, 45.35287972419493, 42.39826809975409, 41.39216053870417, 40.22230971244074, 43.566930447855306, 42.307210276203776, 44.278432707632746, 39.82792323635471, 42.579913062434045, 39.85571715139574, 38.926750844524754, 41.33028122686571, 41.086466696954545, 40.279333130005874, 42.797808570246545, 40.01386319437335, 41.58134821922549, 41.19464174393685, 38.91946308074459, 40.74841722365349, 42.90692498607021, 39.19557832902478, 42.10426292111797, 40.73193934655959, 40.242392247723, 40.144497732962336, 42.488937608657345, 41.10353685194447, 42.289975381666615, 42.73823168969924, 41.652778502433534, 39.75765397471767, 42.451369147146906, 42.69843924430109, 42.28130302121563, 41.56452125118625, 49.893654700248476, 52.711359916194795, 50.85869896796442, 54.11344251325054, 54.309313912545484, 46.80114038528935, 45.91690871023363, 42.352192017339895, 43.77484744594943, 42.32977959417528, 47.41089636279691, 58.42230343049573, 57.758434434090894, 56.48734723367999, 54.180554266898866, 57.393399054004306, 56.34551040587887, 48.3407961937689, 46.115282581698516, 47.45831781818021, 46.0796792276444, 46.192321854252974, 47.81574772250268, 52.141317936681936, 55.413119869847456, 54.62386054377402, 56.27146390176589, 53.46633772696219, 49.553530293126265, 55.05657249881376, 48.301729386852635, 43.53244104693013, 43.75518852664579, 41.11478228722849, 40.30757811761672, 40.876306103121856, 42.47633895566387, 43.41754697984265, 42.19900385026009, 45.50014903468471, 44.34344991560906, 41.80960662903325, 42.504317222103, 42.16831522603189, 40.96003693919028, 42.7539211703885, 45.155149121438306, 44.92279967954082, 40.72922114403018, 42.084239221388295, 41.29621936428932, 42.516531482819595, 44.37362863171486, 43.14808799374489, 45.49872129194198, 45.849612605187204, 45.619608740652765, 47.4276017373608, 47.706246914402136, 44.61116736935031, 47.8882448903976, 46.09933814694805, 48.464158658058416, 47.50140897689327, 47.127512962587424, 48.04297847132529, 50.79730603002733, 47.69440527885191, 51.62370627926242, 51.1534611640438, 55.27041227586808, 50.27888244198215, 57.37233984854914, 56.591850942181004, 69.98789433510073, 69.32206415360974, 85.03567526417395, 30.77419269469477, 0.9301440598022555, 2.7953352034091954, 0.15003114938735962, 0.6804975170281626, 50.147012356788885, 76.51485166242047, 70.01356232550837, 59.986466207811915, 38.06410789489746, 38.872653515108176, 55.771091061253706, 66.382569343813, 75.53573393052625, 25.919532006786717, 0.19249744082410492, 0.13322175540510686, 0.15953082350953934, 0.22444827151635002, 0.16476646756693242, 0.07280475985739501, 0.12440433620565361, 0.06060967049110801, 0.10229460970168153], [0.013035862244695667, 0.014942134148441257, 0.013119592781989806, 0.04021876566712895, 0.06927126357632299, 0.03925676607797223, 0.06293327262204501, 0.017611647002218712, 0.026740509671189135, 0.053622331920891046, 0.2714779955004492, 32.52947099747197, 60.21365381056263, 45.467801247873616, 40.50906242862825, 34.174301239752005, 37.329706838054044, 40.0618730052825, 43.86196328747658, 56.31323322173088, 52.21352092681393, 4.802832939932424, 0.18600627058936706, 0.19580983646935035, 0.5721321125184337, 40.31210453279557, 59.16487086203791, 58.16533719339679, 51.33109746440765, 48.964613868344216, 44.91906166076661, 41.944642066955566, 39.85706644673502, 39.57570306716427, 38.97214835689914, 39.89159507136191, 37.712204610147786, 40.34288729390791, 38.39739168843916, 38.159017485956994, 38.25654722029163, 40.532957507717995, 41.958566481067294, 41.40943857931322, 40.58180278347385, 37.73628404063564, 37.60401779605497, 37.991430297974624, 39.65819051188808, 41.33535677386869, 43.24694741156794, 43.03848128164969, 42.443202772448146, 39.43811808862994, 36.901474229751095, 36.62178570224393, 37.75005940468081, 36.84945183415567, 36.88849902922107, 36.49159831385459, 36.23508707169564, 36.013684964949086, 37.06202860801451, 38.40430682705295, 37.278053145254816, 36.45704223263648, 38.392437734911525, 38.68838840915311, 37.37115060129474, 38.11040755241148, 39.65831210536342, 38.23773161057503, 39.80520094594648, 39.91245815830846, 37.079753798823205, 42.813403914051676, 47.37789746253721, 51.48226953321888, 48.85979244785924, 45.97337122886412, 41.99649580063359, 38.088469736037716, 37.49842759101622, 38.055184502755445, 38.16170038715486, 42.23991809352752, 50.386924128378595, 54.30992972466254, 50.93522441002631, 50.623501885321836, 53.01424534090104, 50.09934379208473, 45.020796175925966, 43.313094262153875, 42.95190672720633, 43.396566221790934, 46.118549916052054, 47.76913427537488, 52.48855360092656, 51.04972624009656, 52.43749610839352, 50.45496548375776, 45.85728868361443, 50.51029835977862, 46.976674295240834, 40.50083329600673, 39.18752570306101, 38.913681507110596, 39.505092559322236, 39.1903615766956, 38.37688161480812, 39.32371824018417, 37.78481160440753, 38.32716557287401, 38.90415014759187, 40.12557621925108, 39.25445310531124, 39.06399457685409, 38.43936497165311, 39.162595118245775, 38.101201749617054, 38.01427810422836, 37.039090587246804, 37.41622255694482, 36.5350228740323, 38.66414423911802, 36.65217230396886, 37.72168890122445, 37.76554099975094, 39.444335045353064, 39.13593476818454, 39.76978194329047, 40.53713483195151, 40.53622484207153, 40.83380329993464, 42.16949978182393, 41.07646465301514, 43.756424073250066, 39.263823647652906, 42.940343579938336, 40.617390448047274, 44.04006634989093, 44.31078441681401, 47.343482586645315, 46.99788255076255, 49.945732009026315, 48.781964778900154, 53.059525182170255, 52.65395210635278, 66.60924311607116, 59.319000397959066, 77.45884849179176, 21.915433368375226, 0.49130202241001597, 0.5304634258631737, 0.08296618838944743, 0.35258510300228674, 37.80625520213958, 66.82905274052774, 55.52542517262121, 58.13248734320364, 26.83040442005281, 22.534746200807636, 49.90373519159133, 51.3384715203316, 55.507060635474424, 14.992903047992339, 0.04917980336974706, 0.07338236716966476, 0.04317848507555262, 0.03326668246318737, 0.030187681249733415, 0.09386617164578169, 0.06086916745369954, 0.0438057272244365, 0.03150511116179968, 0.042538548849763415, 0.03949681206816628, 0.029560737875140006, 0.00855967945103804, 0.02633783853642883, 0.042407609101745396, 0.06172990937146449, 0.021090341183627327, 0.0187413738815174, 0.023548466438848167, 0.3473328348369368, 39.15228320706276, 66.73136218901604, 49.9409310279354, 44.30873301721389, 44.912848626413655, 50.006952362675825, 45.300163069079005, 52.97574335528959, 58.736053820579286, 56.34622035488006, 4.736005558121589, 0.22883838433171474, 0.09370648061796542, 0.5308858161011051, 41.9984491409794, 61.94727082406322, 61.599270297634995, 52.50978931303948, 51.64227870202834, 47.32639674217471, 45.806803857126546, 42.49527615885581, 41.19741878201885, 39.46497455719979, 40.40653951706425, 40.44029935713738, 42.291222695381414, 39.50142906558129, 41.006026729460686, 39.623202969951016, 41.87597705471901, 44.52677365272276, 43.78811290187221, 41.495868006060206, 38.83008010925786, 38.92720583946475, 39.32344759664228, 41.87256851503926, 41.530326028024, 44.0343749907709, 44.814314765314904, 43.50586698901269, 40.70479262259699, 38.748416362270234, 39.22465485911216, 39.434937046420195, 39.24943247149068, 38.65248303259573, 38.25486844585788, 38.216527277423495, 38.53393331650765, 37.74514075248472, 38.52234663501863, 38.84628342043969, 37.852923562449796, 40.06108853124803, 41.247527060970185, 39.50298232416953, 40.21084854679723, 40.828582625235285, 39.404134673456994, 40.94012306582543, 40.66636516201881, 38.579028806378766, 44.87185201337261, 48.87863551416705, 51.68755069855721, 49.982653279458326, 47.413194871717884, 43.87982183887113, 40.73425746733143, 39.270597580940496, 40.4680658155872, 41.238019235672496, 43.18652329906341, 52.726637548015965, 55.1316584310224, 54.54247528506864, 52.88577595064717, 54.721766825645204, 51.688499912138916, 47.308287159089126, 45.05919225754277, 43.80150387364049, 45.82413288854784, 47.83880733674573, 50.8707171101724, 52.392663417323945, 53.87903382701259, 54.3312164275877, 54.05607392711025, 48.497608630887925, 51.424610691685835, 48.97041505382907, 42.849991783019036, 40.471713619847456, 40.69389627825829, 42.44230062730851, 41.040167039440526, 38.69160867506458, 40.03217281833772, 40.62708654711324, 40.707114665739, 42.22229096197313, 41.28688412327921, 39.483715641883116, 40.271629594987445, 40.08148485614408, 39.41170484788957, 39.63431504464919, 40.39567062931676, 39.40185577638688, 39.433513226047644, 40.122163757201164, 39.851673187748084, 39.1309965041376, 40.874611639207416, 40.345527049033876, 42.17632470592376, 41.61308803865987, 42.568467586271225, 41.691445227592226, 43.00263081827472, 41.4150946371017, 45.03572863917197, 43.37290256254135, 45.220613479614265, 41.94330061635664, 44.98818559031333, 42.6958740142084, 48.002197588643725, 46.98878265196278, 50.81498807476413, 50.65105653578236, 52.361190319061286, 51.085929716787035, 55.23362436602193, 56.92365992453791, 66.68003405294111, 62.490695599586736, 79.287810479441, 23.951975030283776, 1.0868870587118211, 1.6874281629439325, 0.12294460163121262, 0.34242883024196474, 41.76365998483474, 73.1148313706921, 60.83978568353961, 60.978512071794086, 32.457230744823335, 28.4805828140628, 58.161367754782404, 57.6719932402334, 64.87896403958722, 19.526398105006066, 0.0446692883457628, 0.09557070195554726, 0.01195999900735314, 0.029627048530645912, 0.029644670468124173, 0.058752546958144636, 0.032570231931223985, 0.025388906492040526, 0.0863078715760381, 0.09774546469411544, 0.17255382792603585, 0.11583329088264897, 0.1284320434675582, 0.16080108921854727, 0.1331116072833538, 0.27303575868568114, 0.09747810000854154, 0.15227204849643095, 0.13997514221456744, 0.7520653283403766, 44.346356391906745, 76.96183712251725, 58.94866589576968, 55.81282507988715, 45.63949907979658, 46.608159772811405, 54.64493543870988, 57.70825947484663, 66.37670147803523, 64.0527795207116, 6.20708853006363, 0.48721767060699006, 0.23887042827423544, 0.7458599548666709, 45.02619335728307, 64.03638401339131, 65.40019996704595, 54.805999725095695, 54.15583156770276, 50.823056390208585, 48.01661229902699, 45.06920999096286, 43.62888820709721, 41.87816573727516, 43.16459332742999, 41.70847615888042, 46.313911407224595, 42.744303518725985, 44.54782109106741, 43.67216763957855, 44.32310065915508, 44.7666815019423, 44.9513663015058, 44.84810206197923, 41.52871785625335, 41.397710692497995, 42.82542990099999, 44.973747345709036, 45.42153296932098, 48.42453487457768, 48.170726145467455, 47.43976108489498, 43.44050461246122, 40.7779565934212, 40.795069894483014, 41.557131505781605, 41.71773295248709, 41.322883636720725, 40.01544390955279, 40.756489461468114, 39.3487782632151, 40.849618296469416, 42.08190933350594, 39.000930709223596, 37.95447764858123, 42.614069061894575, 42.167903377163796, 40.79578376585438, 42.65313586881084, 43.09825820307578, 42.615712534996774, 42.47259701451948, 43.39651523097869, 41.119932359264745, 47.206066270028394, 49.01525558963899, 55.121742679226784, 52.336342104019664, 50.582752381601644, 45.73276127538374, 43.22984587761664, 41.12244267617503, 42.5523897909349, 43.23430561250256, 46.785658790219216, 54.72108041086505, 56.56046021369196, 53.85931999452653, 54.2860895587552, 56.7091808011455, 54.100581061455514, 48.359419607347064, 48.03425512006206, 47.11684411571872, 47.094117902940326, 49.5969940770057, 52.132853461850075, 56.90660545902868, 56.29763003318541, 56.7092945498805, 55.29852390289307, 51.68043159669446, 57.18641165764102, 50.55782964152675, 45.38754563177786, 41.68856620788574, 42.416534577646566, 43.14370278389224, 43.12786425313642, 40.69320201873779, 43.258863572151434, 42.37058008870771, 43.0144214630127, 44.11779203722554, 44.41724146566084, 41.536397857050744, 41.99332652553436, 43.088334606539824, 43.496206191278276, 41.30035354245094, 43.811482383358864, 41.00573255169777, 41.83405083994712, 41.89627139799057, 42.52152858241912, 41.82273872437016, 41.84340569280809, 44.0667776907644, 43.249394970555464, 43.59481065504013, 45.47970956371677, 45.369443893432624, 44.79132183136479, 44.33746045635593, 46.376465366732695, 47.30022276601484, 47.9100493461855, 43.02723192399548, 47.76043445833268, 45.25842120570522, 50.014695121395974, 50.83818497196321, 53.608664851034845, 53.794326320771255, 55.86983673034176, 54.53585432421777, 57.38221637664303, 58.53423218573294, 70.49018521462718, 64.70847037530714, 82.27227134089317, 26.459458028116536, 1.3642559945583346, 3.511891927449934, 0.21661836263393203, 0.6249239055379745, 46.51425038614581, 79.12114112607895, 68.01800943190052, 72.68457089701008, 40.70826392019949, 35.25439646936233, 64.27410710242488, 66.24524716408023, 75.92581364416307, 26.786301289835286, 0.15109883080567085, 0.15516841243351662, 0.11929360278431447, 0.11502777241290578, 0.12425553128724137, 0.12583914993991777, 0.15530765657463383, 0.15189019963145256, 0.15013170608830068], [0.02793937407043432, 0.02751938551814566, 0.043174486096587875, 0.09368267826615803, 0.03360902800435021, 0.06089391592409342, 0.02911097148523456, 0.032246253348045775, 0.17066074805634637, 0.1533603223581468, 0.048730726458973465, 21.189439911996168, 59.21784639358521, 50.443774961656146, 33.88084911531018, 8.387345344789567, 25.30315506842829, 36.958987943587765, 51.72522114169214, 52.560352586930804, 56.59866802154049, 6.792397845175959, 0.09438391684764817, 0.09584777297512179, 0.15336344799687787, 38.85295144973263, 61.53181729778167, 55.17124299080142, 54.77600143801782, 48.11140814135152, 45.997121180257494, 41.76679395860241, 42.994331082990094, 43.53310000511908, 47.299375534057624, 49.28649533179499, 49.40465673323601, 49.346844919266246, 49.328645121666696, 43.53912868807393, 38.87987067622524, 40.88929699313256, 40.641830736590975, 36.18486112163913, 37.99483883765436, 41.66187447886313, 44.995359605358495, 44.450385493616906, 47.6778450319844, 49.703141258608916, 49.0868192334329, 48.379886534906205, 48.481597515844534, 44.64304054937055, 42.61231576242755, 36.430115161403535, 34.33113328872189, 37.01611726514755, 37.57011282828547, 36.01057452540244, 37.24871381636589, 37.025291688980595, 37.150638872577304, 36.96060003772859, 36.62246819465391, 37.96901003006966, 38.72354069063741, 37.8399875856215, 37.634208279271284, 39.0928122305101, 39.15028279827487, 39.426719680909194, 38.698692475595784, 38.11145482524749, 37.59213693680302, 39.358580266275716, 44.41819460161271, 46.66370445682157, 45.81502514500772, 45.34089296094833, 42.3936200910999, 40.275771617889404, 37.76158725061725, 38.9444407340019, 38.00326016641433, 41.79723547350976, 50.1706289475964, 54.79366387090376, 52.08995057690529, 49.83406605259065, 54.75163959687757, 51.83245874220326, 44.18201300405687, 42.358954183516964, 44.82694871963994, 48.30637347313666, 48.20772978567308, 51.31109729889901, 53.47897560365739, 52.369572424119525, 50.47851147190217, 49.85658830212009, 50.13124442869618, 48.38094949722291, 42.59960728306925, 38.46501335020989, 38.62959992501044, 40.71397881354056, 37.85928172449912, 39.57947638727004, 38.643904809028875, 36.805129051208496, 36.800265312194824, 38.74592173484064, 38.21516229260353, 38.410676756212794, 38.03859679929672, 38.50742593888314, 35.938591188000096, 38.265356863698656, 37.823725438887074, 37.373076485049346, 36.410856323857466, 37.28828268666422, 39.01695751374768, 38.35523797619728, 38.61487142501339, 40.94582619205598, 39.28405131063154, 39.09980189415717, 38.93669797528175, 39.46285255493657, 40.974737982596125, 42.21524638514365, 42.97933586182133, 43.27172894631663, 41.781067463659475, 43.228551495459776, 41.91863283034294, 41.785809609197806, 41.575954960238555, 46.90987633120629, 47.72399171706169, 51.834392470698205, 48.331394272465865, 51.66498530295588, 46.87503783933578, 54.39037753689674, 54.761343540683875, 66.6437364393665, 60.17638344918529, 78.29181086632514, 17.60796489254121, 0.7042263856818599, 0.30582242194683323, 0.04084871210638554, 0.18553765460608468, 37.353558771071896, 67.4051861609182, 54.869593112699455, 44.74607336905695, 24.798434280580093, 14.815500128653744, 34.92724334039996, 56.445923082290165, 51.76854372024537, 11.393020345318703, 0.0869978103606451, 0.015463941531526226, 0.10935191125158342, 0.043862555626659624, 0.01151283061312091, 0.04209943874288471, 0.058834993340555704, 0.026211144830731135, 0.026594960626455087, 0.06719632209428857, 0.03769258690637447, 0.07025676674299663, 0.01183864493448768, 0.027666811478294195, 0.013227977943907102, 0.03263137723890043, 0.048307662063668814, 0.04911583885850926, 0.0167541149928565, 0.033393830075980194, 25.78044083810622, 68.50472850184288, 54.1968713268157, 42.99829267686413, 13.51562273117804, 28.360983863953624, 43.538689382614635, 58.29735240628643, 59.21160982501123, 61.840131282806404, 7.223549677479652, 0.17022395536543863, 0.025315229901142662, 0.3243053962867106, 43.00962832666213, 63.15075205218408, 56.21269110710391, 55.95577978318738, 52.04154068423856, 49.039331097756666, 43.9892481219384, 43.945545073478456, 45.29648388585737, 47.84274147402856, 49.69213116553522, 51.47171835745535, 50.11087948276151, 51.9369585283341, 44.1919130663718, 40.54086108361521, 42.574900273353826, 43.019446019203436, 39.52071928208874, 39.237457475354596, 42.201263135479344, 44.155686055460286, 46.35271541533932, 48.74087795134514, 50.15812835385723, 52.609594022074056, 50.6738611959642, 50.10600005426715, 46.87621455038748, 43.1467818444775, 37.61394923733127, 38.027104254691835, 40.50025278522123, 38.56461409599551, 39.123014480836936, 38.588171851250436, 38.41723103677073, 36.65669479677754, 37.989629930065526, 38.7048113730646, 39.067552166600386, 39.891963774158114, 41.93549117734356, 39.332355299303615, 39.4188827853049, 40.729817344296364, 41.09637460400982, 40.527093564310384, 40.97655011761574, 39.57964112681728, 41.958331138856956, 45.42052099781652, 48.6587631317877, 48.22974997182047, 47.78243895499937, 44.41870058736494, 40.94077417927404, 39.3454913170107, 41.561516715634255, 41.33024200316399, 41.98153588079637, 53.052747326512495, 56.89339491628832, 56.19380097235403, 52.50170530811433, 57.03776951759093, 54.58966532061177, 45.641256301633774, 44.16553904933315, 45.87195834805889, 50.53899441995929, 51.19244167881628, 52.38020989202684, 53.93364106455157, 54.33441708164831, 52.607185686788256, 51.74804541372484, 52.60024701395343, 49.836337104920425, 44.845121060648275, 39.72798908910444, 41.13721824461415, 42.02220301474295, 39.57728770471389, 41.402131203682195, 40.05711517026348, 37.77178541306527, 38.439596391493275, 39.017424275798184, 42.06301135401572, 41.10765141825522, 39.61884913905975, 39.53215299114105, 38.53380387829196, 40.0671995839765, 39.63377375756541, 40.07566013643819, 38.374896895500925, 39.758230563133, 39.14447376804967, 41.29395223432972, 41.4296309409603, 43.47942629168111, 41.25377931902486, 42.47087117164366, 40.964896755833784, 41.6150100000443, 42.869889966903195, 44.69632987053164, 44.75741294122512, 46.10465295853154, 44.448589048077984, 45.057901797756074, 44.74661073377056, 42.731500902483546, 45.69066639869444, 48.961103347039995, 50.82893210072672, 52.84097463853898, 49.85314838347897, 53.31815058185209, 49.537734908442346, 56.88589142214868, 57.34429490181708, 68.85261135716593, 63.58394253638483, 80.06169411443895, 19.311387500455304, 0.9796980588186173, 2.0877516365820363, 0.06826314549412459, 0.31195017539205094, 41.9873135320602, 71.98520445054578, 60.07811238688808, 54.77959432909566, 35.364956317409394, 21.04035650530169, 41.0719225483556, 62.340260936367905, 62.154830886471665, 15.037832817723675, 0.12567705339601926, 0.03214144102868534, 0.015318098500551236, 0.04143078188081423, 0.044267352655409806, 0.060205643380721735, 0.0780700821609747, 0.008438334954271634, 0.011117933355572244, 0.1743070661060272, 0.11691279303763183, 0.22133970122423866, 0.19128306889005248, 0.12550188739213253, 0.14167729765176773, 0.18451961568526684, 0.29821017396546184, 0.2758444208771952, 0.23448045335469708, 0.11427013443843012, 29.341417551040653, 76.96915626525879, 62.1257229774229, 48.120896354798354, 16.209868404173083, 36.55514463301628, 49.698650144761615, 64.96667215901037, 62.5620670472422, 70.17149263812651, 7.811057481073565, 0.24142943773298498, 0.24823255897048982, 0.5979989793512129, 43.92770613393476, 66.09005466584237, 60.69719968303558, 59.80950063274753, 54.41169954115345, 50.295270104562086, 47.0214795297192, 47.15248669347456, 47.73038518044257, 51.15344155219294, 52.80503788302022, 55.001561257147024, 54.426137785757746, 53.585295369548184, 47.661324008818596, 42.95748825996153, 45.563503157707956, 45.838218119836625, 40.083257767461966, 41.76537013822987, 45.782634212124734, 49.552871334937315, 48.39657229761924, 51.96504662113806, 53.737797121847834, 54.30139072479741, 53.89947329798053, 54.182146749188824, 47.987308271469615, 45.709748729582756, 41.091491253145286, 40.099002161333644, 43.39816262645107, 41.28208314218829, 40.73042531167307, 41.125455056467366, 39.87578791956748, 39.41484666639759, 40.699113030587476, 40.00319826987482, 41.16643598002773, 43.04787143584221, 42.64231012713525, 41.82293876524895, 40.59508392887731, 42.63875253738896, 42.44495999428534, 41.54121452762235, 41.84793995272729, 41.65597915649414, 45.12219728962068, 48.180583061710486, 49.2862246882531, 49.207181084540586, 50.01959808411137, 46.25861383253529, 45.282233915021344, 43.68205593478295, 44.173034698732444, 42.607934474945075, 44.8386569946043, 54.93950936102099, 58.549231329271876, 58.62268947785901, 53.741342944483605, 58.260968500568026, 57.478934180352, 47.918906058034594, 45.80772561411704, 47.64813700029927, 53.455751249867106, 53.11073172476984, 55.79785731530959, 57.79366908534881, 56.70306974841703, 54.55680762567828, 55.239492231799716, 54.1078099896831, 51.46259884680472, 46.64482216681204, 42.20784487262849, 43.29739693672427, 45.494634182222434, 41.863594132085005, 43.48197190992294, 40.9412330965842, 39.49814996411724, 40.106952805672925, 41.450858808332875, 43.975123666947894, 43.10245121678999, 43.25683962914252, 41.970529710092855, 39.83061398229292, 42.349571874064786, 42.54399984113632, 40.88585707449144, 40.25010362748177, 41.70994312532487, 43.35696597253123, 43.477484718445815, 41.71430872332665, 47.219343493061686, 44.69592586640389, 45.23911922208725, 43.520721004855254, 43.63122593971991, 45.952264954966886, 45.69784825847995, 46.75247161619125, 47.835716509049945, 46.31819071308259, 48.37561507378855, 47.24975362900765, 44.522145255919426, 47.95316011674943, 52.81747571883663, 53.81048648588119, 56.45958861997051, 53.797232797068936, 56.64159836307649, 53.389059189827215, 58.80598968075168, 58.44721832583028, 72.96640103863132, 66.37185342850225, 81.92153300008466, 21.39148904431251, 1.4040045584401777, 2.9123083718361396, 0.1502550002788344, 0.32679030972142376, 47.23440931689355, 79.74761424526092, 66.47019509346255, 60.696689774913175, 36.85933228461973, 27.804848647886708, 52.14863707942348, 71.53838372999623, 71.07210805339199, 21.69556098599588, 0.302409193808994, 0.09323205002733777, 0.21023252948878274, 0.13645210303366184, 0.17301072276407675, 0.1495865579213827, 0.1683011206407701, 0.22046527314570644, 0.14649962195225302], [0.10690315716689634, 0.040233934208029704, 0.04774601236286183, 0.06580501449324432, 0.027692220699522766, 0.05172048034446855, 0.03775129222401208, 0.005090957819183748, 0.02960169293557204, 0.048311362268343094, 0.12788018437042353, 10.053529950880236, 55.079522286691976, 51.58025818486368, 44.552147465367476, 37.45365765786941, 46.117263378635535, 36.69935057240148, 45.32469357213667, 53.61601929510794, 58.303851773661954, 10.770954009025328, 0.2772515405329966, 0.21025848454765736, 0.45715190650474646, 27.584652669968147, 58.414776402135054, 55.021671249020486, 53.72022882584603, 51.749747722379624, 49.40315446546001, 49.68196045967841, 48.43248944128714, 50.11434293562367, 52.61946662779778, 53.93180539531093, 52.939382983792214, 55.06160882211501, 52.20231863760179, 48.96946976261754, 38.26503130697435, 38.72383486840033, 38.800238716986875, 40.64194448532597, 48.68314458477882, 51.20313405990601, 50.52114371330508, 48.48894411517728, 49.05251026153565, 49.218289236868586, 49.069764767923665, 50.56267769105973, 47.43815683549451, 46.80432927223944, 45.140067608125754, 40.187518289012296, 36.0751171265879, 35.70483753758092, 36.561687146463704, 37.795001922115205, 36.86639647330008, 36.35419376434819, 36.816825559062345, 38.88023545665126, 37.63360815663492, 36.793793401410504, 37.279343605041504, 38.47728252410889, 40.684870904491795, 40.17978337503249, 38.52075807509884, 39.47256826585339, 39.002856592978205, 38.99502361974409, 39.90103621636668, 37.90935862448908, 39.814661702802105, 44.894754732808764, 45.625637423607614, 42.84389641977126, 40.09724493949644, 38.558993339538574, 38.42209085341423, 37.677585771006925, 39.74455325834213, 40.78611120100945, 48.17256965944844, 55.208344690261356, 51.7338974245133, 51.15170001983643, 51.58984445756482, 52.30643010908558, 43.13863900399978, 43.55444162122665, 46.57468626576085, 47.65254574437296, 47.69198125408542, 51.016272344896876, 51.21496785071589, 47.53298797915059, 48.65578605282692, 50.34960669855918, 47.068547971787, 43.11297493596231, 40.3214515409162, 37.63728341748638, 37.175204676966516, 40.32018069298037, 37.47710950912968, 38.95493699658302, 38.92389928140948, 37.73997499096779, 39.1344521122594, 36.60307599652198, 38.03829477679345, 39.0025310362539, 38.41667013783609, 37.394061165471236, 38.497874967513546, 37.54435854573404, 35.79572277684366, 36.560651640738214, 37.44289859648674, 39.043876740240286, 43.11254739761353, 45.08265587591356, 45.270070645116995, 44.445243266321, 42.18226317436465, 41.86974048614502, 40.45607512997043, 39.468418398211085, 38.25596670950613, 40.04172771207748, 41.9451480527078, 41.17392378468668, 41.31052817067793, 43.60068636555826, 41.71561879496421, 43.308403107427786, 42.22110640618109, 45.181123056719386, 44.693933302356356, 50.69840738850255, 51.06532942864203, 53.13498373954527, 50.65861494310441, 52.69769437851445, 56.46754710905014, 64.13576902881746, 62.49441792888027, 69.59565731786913, 11.324444567003559, 0.6094721572533731, 1.5924719937386054, 0.06987147814323826, 0.05827866412038284, 34.245719755849535, 67.04740324328023, 54.638828308351584, 46.54182072608702, 36.107013840829175, 17.925572933689242, 27.546036935621693, 51.79598069960072, 51.858817069761216, 6.130278225867979, 0.01905479577309903, 0.08482523863354037, 0.04352488705227452, 0.005762176287751044, 0.06824437633997972, 0.024300065725260687, 0.031213693230623202, 0.03660870272846472, 0.027058853677684264, 0.06962397811754097, 0.04647590370187837, 0.036630233629576625, 0.016842789670091965, 0.030563820844456076, 0.023619913713886373, 0.08992980504708906, 0.04657077986086088, 0.03641183345368312, 0.02511285245418549, 0.1463666444103564, 13.073043073377303, 64.62921496360534, 56.25431137700235, 48.907743423215805, 30.098580121994022, 40.610365483068655, 41.30065948732438, 51.98886325282436, 57.46089127755935, 63.918461876530806, 11.257559330232683, 0.2855870674454397, 0.11865366655852526, 0.8999986225558866, 32.12351941293286, 58.59820212087324, 58.42042853755336, 56.21468367115144, 54.585162439653956, 50.53711560464675, 51.57507281149588, 50.85189757808563, 52.61512848638719, 54.433143138885505, 57.7053882998805, 55.50174190152077, 55.03127321120232, 54.43130354727469, 51.519422223491055, 40.94404935836792, 40.027332613545084, 39.691024672600534, 42.84215488741475, 48.167929495534594, 53.3922912228492, 50.97232218711607, 50.998570688309215, 52.770885805929865, 49.73846220201062, 49.94648902646957, 51.67950591733379, 49.919879667220584, 48.764561222445586, 46.4172972402265, 42.155991138950476, 38.62579914831346, 38.87694066570651, 38.01520378358903, 38.3264870028342, 38.04535504310362, 38.76664753883116, 38.09618503816667, 40.55331853128249, 39.997024459223596, 38.59036053380659, 39.49426681764665, 39.1660624934781, 42.66513832153813, 40.521939569903964, 40.15037344348046, 40.46867770533408, 39.63378552467593, 39.815199067515714, 39.57547556969428, 39.553675036276545, 41.206789324360514, 46.274024824942316, 47.38549509356099, 45.39164450860793, 43.320460473337484, 40.889830435476, 39.58513636742869, 40.31383037567139, 41.04423845967939, 43.81619707230599, 50.74071015081098, 55.29308749783424, 53.6243268751329, 52.38717602145288, 53.785575512916814, 54.2322785623612, 46.92005095943328, 46.183245489674235, 49.750445042887044, 50.0058933227293, 50.35220330761325, 51.93326365563178, 52.63015900888751, 49.638892835186375, 49.93524359118555, 50.79505066717825, 48.80381238075995, 45.097223558733546, 39.492187961455315, 39.66451729497602, 40.16954206651257, 41.817580807593565, 40.14526259514594, 43.03919515302105, 40.13686480060701, 40.02291994710123, 41.21124121450609, 36.84516468355733, 40.767785887564386, 41.17684595046505, 39.70367431640625, 39.156805699871434, 40.46096240320514, 39.99441216068883, 38.344110212018414, 39.1892280117158, 38.802858860261985, 40.5903535504495, 44.85040057090021, 47.3235216448384, 47.31689676161736, 47.92407966429188, 44.97573990975657, 44.10886472271335, 41.12816149188627, 41.67019774836879, 41.70967640415315, 42.11288036838655, 45.13154822011148, 45.01057447925691, 45.043012480581964, 45.921117413428526, 43.23168154685728, 46.365455273659, 44.93485704545052, 49.06197886313162, 47.96651578718617, 54.4260593383543, 52.863681239466516, 56.75416646465179, 51.641808017607666, 56.10114282177341, 59.13786142103134, 67.15176966882521, 63.270392187180065, 70.43262835471862, 11.621241492609824, 0.6260928944233926, 0.8286826396661421, 0.11316331358806742, 0.1072947047049961, 37.57724369725874, 73.35943821937808, 59.54703131029683, 50.65715189903013, 30.669075135261785, 21.615625043069166, 37.75992024329401, 58.21668101895241, 61.49832417888027, 9.790240853063523, 0.10256286304924758, 0.0597759408335532, 0.019320994089808197, 0.041732482627154364, 0.02534164461277185, 0.0351487115145691, 0.022373360341354724, 0.06240739922730192, 0.016568474651825045, 0.18990961113764396, 0.12436800831628424, 0.11294799691606915, 0.13572065760531735, 0.08691261372258587, 0.11531377601767741, 0.18481986086455085, 0.12361659097575373, 0.16996445074196787, 0.18877886536140598, 0.3720471070658776, 14.477906630885217, 72.66300570580268, 63.578608112950484, 58.72700491259175, 49.62624319138066, 58.098417635886904, 46.52640973367999, 57.71149935260896, 62.03779520527009, 69.54020284837293, 12.969889640808107, 0.40712501673448476, 0.3988017778723471, 1.1457759310160915, 33.34904240023705, 60.420170522505245, 62.22380576595184, 58.65017352565643, 56.02901043430452, 52.062035068388916, 55.1688503449963, 52.833145587675034, 55.678907517463934, 58.06042163602768, 59.00434001799553, 55.98422481167702, 58.096844765447806, 56.03060291659448, 54.7244458044729, 42.37277661600421, 42.55048351903116, 42.39616570934173, 45.604040853438846, 51.24790399305282, 53.941285764017415, 53.92191710010652, 52.60261612553751, 53.70476292025659, 50.37319975514566, 51.34444529010404, 54.73013324122275, 51.6088757976409, 51.57901087114888, 50.133484102064564, 44.52031743141913, 41.59785747528076, 41.548694487540956, 41.5894086899296, 41.74481299615676, 41.80872801811465, 39.48748896198888, 40.4270339012146, 44.42442332544635, 41.237313209041474, 39.92991270557527, 40.01205105935374, 42.514856630756015, 45.11312484741212, 42.84979174214025, 42.22169476170694, 41.725958162738436, 41.395980927252005, 42.10281948889456, 43.538352058779815, 43.1016981217169, 44.070680449085856, 47.72115976579728, 50.81463506144863, 47.080177799347915, 44.5958387467169, 42.84187247676235, 43.48728672150643, 42.003026546970496, 43.29933850995956, 46.07767881885652, 52.982807543969926, 58.5883608941109, 54.32241070655085, 53.50904449339836, 55.35875581925916, 56.42930399987006, 48.11959020553097, 49.753257382300596, 49.913250861629365, 51.599591547443026, 52.80662252056984, 54.55042592940792, 55.849966003048806, 51.33660447212958, 51.72169100853705, 53.33822135002383, 51.367704945225874, 47.3099188650808, 42.879284043465894, 40.6690166842553, 40.93771080816946, 43.061678178848766, 41.295215237525206, 43.49951274933354, 41.83306632503387, 40.89649454239876, 43.29126234977476, 38.871586630421305, 42.4213747824392, 43.59558728433425, 40.668808798636164, 41.32480559810516, 43.3361577987671, 42.4858977717738, 41.16724006591305, 41.011451367409, 43.34223355016401, 43.89571136043918, 47.968198483990086, 51.061328611066266, 50.03527972006029, 50.78478974680747, 47.19061213154947, 46.12258995732954, 43.50177987929314, 42.94888650217364, 43.323096306093284, 44.02186262992121, 47.34321978784377, 46.866667501388065, 46.62675965216852, 49.200034526086625, 46.933112452107096, 49.36434653497512, 47.216013400785386, 51.686452434908965, 50.181384086608894, 56.39360258656164, 56.08890110446561, 60.315305955948375, 55.19027433087749, 58.88546474518315, 61.79306284073861, 70.20280884158227, 68.07316580126363, 70.75768301563879, 13.587881615084987, 1.4813475695348557, 6.216860134755412, 0.18108325169211437, 0.2941622573041147, 42.243656112301736, 79.51663371055358, 66.0070651577365, 63.59048504983226, 48.681532490638, 29.189815982695553, 47.50244840498894, 65.48148716649702, 76.36102414900257, 15.573734487256697, 0.16389222334950201, 0.2500092241192057, 0.1009902684018016, 0.09232696311007585, 0.14170028028949616, 0.0857278740694446, 0.29116529070081254, 0.17419612125283288, 0.1485686875399082], [0.07574865188930305, 0.06980650622638003, 0.03784383564526516, 0.028041533810356935, 0.03595550552070622, 0.032414750556551644, 0.017493378348468293, 0.04898397214410286, 0.1067173578626206, 0.03605645675692828, 0.08773667918097589, 3.464926692747301, 56.73856719847649, 50.83224258115215, 49.139539810919, 28.200421640949866, 33.264299592664166, 39.14727434035271, 45.92977016202865, 52.799981947868105, 57.87423849105836, 16.99140948633994, 0.15970775917653116, 0.14512538279016174, 0.7664827966401655, 12.171049925588793, 59.84096588626985, 57.82786038614089, 54.93305313971735, 53.66491556167603, 53.71275671066777, 52.07193905307401, 55.3976421971475, 55.9127474600269, 55.64085268205213, 54.92895426288728, 55.62131143385365, 54.052316296485166, 53.557587746650945, 47.282901579333895, 37.5850139125701, 38.69563694923155, 40.85922418102142, 47.3226430339198, 53.11354798655356, 46.71928051979312, 48.462840741680516, 49.91552191395914, 50.427214714788626, 49.7265068177254, 50.3319638775241, 49.9731219199396, 46.96767637806554, 46.98930040482552, 45.45871703855453, 43.47906935599543, 38.619197799313454, 35.78983137684484, 37.07793774143342, 36.97988633186587, 38.43928260187949, 35.53091179940009, 35.17092058735509, 35.422470031246064, 37.912629881212794, 36.413605905348255, 38.90176142415693, 36.947467942391675, 38.22835322349302, 39.87640373168453, 40.89342724892401, 38.77797534388881, 40.26240418034215, 37.22024525365522, 38.54182904766452, 37.7851136269108, 38.38485971573861, 40.11548396079771, 42.20795862136349, 40.15575493535688, 41.13149158416256, 38.30407850203976, 36.26077075158396, 37.40115281074278, 37.410182106879454, 39.99779324377737, 48.010007027656805, 52.91174988592825, 52.09465742111207, 51.23711747507895, 53.585966094847656, 49.78081595513129, 44.41264837018905, 43.07977599482383, 46.1519096743676, 47.128246445809644, 47.92918266788606, 48.42904560027584, 49.63195023998138, 47.88466768880045, 46.91550493240357, 43.697062923062234, 43.18742152183287, 41.88268038534349, 38.250094921358176, 37.88204716097924, 38.554337486144036, 37.34652988372311, 39.288193333533506, 39.472132882764264, 38.43197914861864, 37.50407580406436, 39.674570329727665, 37.798704639557876, 37.65577347047868, 37.326729759093254, 36.97326144864483, 38.29181325051093, 37.792362166989236, 37.883627876158684, 38.69778640808598, 38.08511610954039, 38.044397984781575, 40.94089577274938, 46.33984219643378, 48.512046875492224, 51.188727194263095, 52.13316725146387, 48.68176391047817, 48.36843713637322, 48.14957280312815, 44.21708291576755, 42.84787370312599, 42.923944150247884, 40.69044851487683, 41.915012482673895, 39.93143066283196, 42.31243879564347, 40.2337355767527, 39.74663603690363, 39.32413008905227, 40.875258830285844, 43.014688184184415, 50.14558069167599, 50.49296148361699, 53.25082702021445, 50.83332123294954, 53.564377369419226, 56.14308864839616, 64.83765363693237, 61.80072322968514, 67.30212980701079, 7.04876248874972, 0.291560837217877, 1.866089305089366, 0.08198830013674113, 0.047966178371420795, 31.81986716485793, 65.79552781197333, 57.78577727656211, 48.08252380740259, 38.80270196545509, 33.07693581427298, 37.20440672289941, 51.96322271900793, 56.98446450694915, 9.853103699222688, 0.06400162053685035, 0.0780710474317593, 0.06594483320030474, 0.00979614248799701, 0.04033858564892604, 0.08987821668626801, 0.02121602173804516, 0.04927516216412187, 0.07286043146685248, 0.05504063646038694, 0.0036990490785214093, 0.027087269794015635, 0.04580464597130495, 0.04337649965178102, 0.031191934418353825, 0.05295682368018935, 0.02470565948545212, 0.07231760454634506, 0.03899916901343292, 0.10630928580799412, 4.6831329887913125, 63.975920677185066, 58.88902233492944, 54.86054812708209, 32.89623810398963, 39.190373343806115, 42.56041888267764, 49.73921921945388, 58.62879660821731, 65.08559842263499, 17.756112813949585, 0.24933842221094718, 0.09458221104596892, 1.1832945048809052, 14.421122477900598, 59.382809515922304, 59.837604415032175, 58.09289886105446, 54.25505184358167, 56.133557288877434, 55.57411747594034, 57.26139168585501, 57.65645673198085, 57.38750765400549, 56.06061297078287, 56.70627432484781, 56.3588386197244, 55.76045751571656, 50.580002800110854, 39.83025704660724, 39.78114897204984, 42.26330718686504, 48.96977962986116, 55.82701621517059, 47.28643563485915, 49.56080236742574, 50.48948626364432, 51.77356435406593, 49.65649251014956, 53.75731483582528, 54.091167373041955, 48.9065549450536, 48.92336622361214, 48.612259511024725, 44.522396287610455, 40.64538832633726, 38.68917680555774, 38.84569114254367, 38.15343987557196, 39.38329512073148, 38.09947590674124, 37.14143699215305, 38.69440140262727, 39.36573859184019, 39.248848038335005, 40.25992132002308, 37.8303817010695, 39.81505001744917, 41.433223832038145, 43.099176037696104, 39.92029505391275, 39.45375265613679, 40.07393429356237, 40.027866055888516, 39.25562981636294, 41.986344706627634, 43.000104811883745, 42.956958739988266, 41.90305709838867, 43.05903450135262, 40.13746492324337, 40.56624274100027, 39.8248637876203, 39.440110652677475, 40.87363889140468, 50.23149236556023, 55.9523477092866, 54.96684435875186, 53.028071695758456, 55.19485958160893, 52.49485684979347, 44.333596921736195, 44.62944953672348, 49.531961179548695, 48.35562275302026, 49.6876714306493, 49.42731626572148, 50.27613678286153, 50.9666504398469, 49.68871085874496, 46.92772311549033, 44.638455298639116, 42.44679958589616, 41.38974435867802, 39.476569083429155, 38.96273466848558, 39.28027014578543, 41.37124253857521, 41.613805832401404, 41.093201406540416, 41.646769431329545, 40.224686668765166, 40.602701171751946, 37.54338579793131, 40.51078042676372, 41.098822162997344, 39.72132890455185, 38.43082597178798, 38.88837045238864, 39.115263877376435, 40.75665812338553, 40.66405096361714, 44.18541369899627, 49.189157793598795, 49.95876212273875, 53.440865855063166, 53.44496080952307, 51.29312107639929, 50.79254035026797, 48.4962240342171, 46.222449579546534, 44.1703478751644, 44.92674950630435, 42.17249647263558, 44.248944328677275, 43.873702941402314, 42.97747273598948, 41.479860813386985, 43.380806138438565, 41.68541654463738, 44.30295144357989, 46.641680348304014, 51.8944674922574, 53.5781527334644, 56.120793896336714, 53.43455868382608, 56.4946702987917, 57.26354506707961, 67.50437505783574, 62.80296725611534, 69.89477726720995, 7.861773237105339, 0.7380203013458561, 2.2434383534616043, 0.0679916822381558, 0.03329747536730382, 35.185229393743704, 73.95811742351901, 61.187833278409904, 57.310817472396366, 41.24213380198325, 34.369964753427816, 44.88096760165307, 58.74968797929826, 65.73307583408972, 12.690074616862884, 0.0652454179080744, 0.11789554594865731, 0.01443744595763424, 0.06356038453598177, 0.008509251713422279, 0.03942493386867066, 0.07288529868087462, 0.013314414686793763, 0.05283848990896537, 0.10772253416718976, 0.10652347633074369, 0.1489664557119531, 0.08504977134326774, 0.09121964430256237, 0.11120712339517572, 0.1854310611323003, 0.2225069893944648, 0.19024754784280257, 0.0988315552052471, 0.23884546912966237, 5.951851567914409, 73.32627850194132, 65.4341676927382, 63.82840425737443, 37.86379245019729, 45.813150252065356, 50.70207480461367, 57.79236293608143, 61.10426718188871, 70.33381600533762, 20.151184605013942, 0.25720813702191075, 0.3992292549340956, 1.2315717724061783, 16.775204520071707, 62.18062047035464, 62.265276985783736, 60.722361687690984, 57.832135769628714, 59.49595812828311, 58.61873180635514, 60.23533667287519, 60.36761860693655, 59.73930981851394, 58.12273633095526, 56.642065125127, 58.279458553560325, 57.13007465485604, 51.197497613968395, 40.6786225688073, 41.34808878744803, 44.356927179521136, 52.05776752964143, 59.160116949389064, 47.35031927785566, 50.9183229169538, 51.189154732611875, 53.207888833938114, 52.38577181293119, 54.437442056594364, 55.05302275380781, 50.8580360874053, 51.74376218549667, 51.18220037029636, 47.21569568880143, 43.09915250347507, 41.055907510942035, 41.40657524908743, 40.92122508633522, 40.505536217843336, 37.60947773533483, 38.59973107614825, 38.86957837689308, 41.87026608374811, 39.75079374928629, 43.613088900043124, 39.80728764687815, 42.07472355135026, 42.25097133267311, 45.76360287204866, 41.609577517355646, 43.589876313363355, 41.73346165687808, 41.94447340503816, 40.172880003529215, 44.435535400144516, 44.43795942491101, 45.11554494980843, 43.93163242647725, 45.8270432872157, 42.17471261178294, 42.24915135291315, 42.442634028773156, 41.35719653098814, 42.6272560704139, 52.12113734214537, 59.054291402139974, 54.877512378077355, 54.81597039007372, 57.76630270865656, 54.24551263932259, 49.1988342808139, 46.733993330309474, 50.70982540807417, 49.08086115314115, 51.55405282974244, 50.814478166641734, 52.83138444346767, 52.3614138941611, 51.69257917711812, 47.98815158105666, 47.044091993762606, 45.66134668165638, 42.39170989682598, 41.08598816779352, 40.14748265666347, 41.89092912981587, 43.13926266085717, 43.00728274929909, 41.74852355833977, 41.669111251831055, 42.86424567622524, 44.0761717673271, 40.93366292215163, 43.24581384658814, 43.18556231837119, 41.88385317402501, 40.681105429126376, 41.17626936204972, 42.62742865470148, 44.23030522561843, 43.43686857531148, 47.14605400639196, 51.9622068251333, 53.01582213371031, 55.78461931597803, 56.27491166514736, 53.15849050398796, 52.44950640586115, 51.89160416203161, 48.0695995976848, 46.99830224437099, 47.19569944566297, 44.97103306554979, 46.84700073734407, 45.61633748392905, 48.00756731340962, 44.46464330919328, 45.55587807009297, 43.14277710453157, 45.14425277709962, 48.555510659371656, 55.82624350824664, 55.06641764794627, 59.38529629861156, 55.86180763859903, 59.476816961842204, 62.716149514721295, 70.26631201467207, 66.44739827802105, 72.31152995940178, 9.635146414079975, 1.720015091761466, 5.250727409316648, 0.16604863828228367, 0.20047089926177458, 39.3350342781313, 79.03587664327314, 67.30428711060556, 64.54127150197183, 55.26130845469814, 48.07320425587316, 54.69957797758041, 68.58522338251915, 77.87989139556885, 19.812797807878066, 0.16829869980292936, 0.2431566748888262, 0.2185158398483069, 0.12623592985854035, 0.1453357964994446, 0.12704918581631877, 0.16121076239693552, 0.1757338742214826, 0.19881397365562378], [0.04022173425783554, 0.07103472136922422, 0.07665154779510153, 0.07709750289758367, 0.04807219727926197, 0.09467922075982056, 0.04824229561152959, 0.01461067184385273, 0.013970821802955002, 0.0161165785374901, 0.04681127784293025, 0.7105586846028605, 43.8130081853559, 50.33212469470117, 48.718143893826394, 32.61793221196821, 40.76748778743129, 34.43791981666319, 45.445443737891416, 52.12100790392969, 57.61858624796714, 26.989442802244618, 0.02566282697502644, 0.056861290377714944, 0.28210939599141, 3.3080397305950044, 40.95663624425089, 60.6076245154104, 55.296951032453975, 57.66281097166, 52.85320066636609, 57.63572700562016, 54.932170606428585, 54.616878724867306, 46.63962110396355, 47.42931189075593, 54.01435167558732, 51.441563175570586, 48.009010745633034, 40.365942985780784, 36.80148909168859, 40.93607125743743, 46.600405246980735, 52.44890236085462, 49.68235269669564, 49.122806979763894, 51.63215898698377, 48.58709358399915, 49.99665614097349, 48.55257280411259, 50.5174135392712, 47.072152629975356, 45.71756209096601, 44.13196748302829, 45.43826972284625, 42.29333685290429, 37.93051588919855, 36.78849820167788, 36.69081157253635, 37.35390393964706, 38.12233155773532, 35.356001546306, 37.67300444264566, 38.19840984959757, 37.9111276134368, 38.84065481924242, 38.98479800070486, 36.46771892424553, 38.86551480139456, 39.48233888995263, 39.044967159148186, 38.334676911753995, 40.5091683326229, 38.28280356622512, 40.27934097474621, 39.63463667900332, 37.50635470113447, 39.291225325676706, 41.12519618003599, 37.84101916897682, 39.45374088902628, 36.681845034322436, 37.95093574831563, 37.85290002822876, 39.39192825748075, 39.11491870880127, 47.70911808936827, 51.685240422525716, 54.20274311496366, 53.02831880507931, 53.45644158701743, 50.53027499106623, 42.00991422899308, 44.00299602939237, 44.55432045844294, 46.40672645261211, 44.291894282064135, 45.280982678936375, 44.776377601008264, 45.05575233890165, 43.200133923561346, 41.08277966899257, 42.036135273595015, 39.26418450570876, 39.32855844497681, 39.37939236241002, 39.10484213982859, 40.52332024420462, 38.89100628514444, 39.07487915408227, 37.4504844604, 38.354535871936434, 38.53477270372453, 37.19858200319352, 38.77259777438256, 38.25555878300821, 37.45272805613857, 37.177930724236276, 38.55177617842151, 37.80737700000886, 37.63376112907164, 36.898034311109974, 39.552729745065015, 42.03792387439359, 46.25114171735702, 48.67601763817572, 50.07403273736277, 49.757466085495494, 50.274999295511556, 51.63666579031175, 51.86333171782955, 51.10745960666288, 49.45027782071022, 47.62499893865278, 40.57994358001217, 42.94707044478386, 40.87384285465364, 41.88374727003036, 47.6098075989754, 48.52761868507632, 47.09120358190229, 42.942571486196215, 40.481484243946696, 45.16339394354051, 48.27941502294233, 53.61682338099326, 54.444019871373335, 56.323192119598396, 57.28209003325432, 62.29693835781467, 61.81943293540709, 63.18801456882108, 3.0748070199643416, 0.057267282503627004, 0.0830559738941731, 0.006894819568016477, 0.02385879141999589, 31.737924929588075, 67.74043113954606, 55.3198576742603, 54.70057033723401, 25.866011265785467, 26.9928317300735, 48.81719943015806, 56.22257155756797, 49.68995817245976, 8.515254816701336, 0.041751006633163466, 0.07665651204485087, 0.018844156067878492, 0.09989683876835531, 0.026246503618876302, 0.02348073469024272, 0.011356436636208767, 0.052524336403416055, 0.07604776325845912, 0.05290639977301321, 0.07725472712228376, 0.030054990990808415, 0.041638338082139535, 0.016777561113779104, 0.01480437047223771, 0.09973474988533605, 0.039689839412007606, 0.009354804022868556, 0.06092480458920041, 0.024661124879193884, 1.4376537141300019, 50.2325592502471, 57.32268264216762, 55.1664420097105, 33.76519410840927, 42.164890996871456, 45.169944301728286, 49.64413704410676, 56.77264475053357, 63.4287186591856, 28.228615637748476, 0.04817340132449904, 0.03832904126254782, 0.9710553000050207, 4.3367543624293425, 42.00898070489207, 62.22396266075873, 58.52195516709359, 58.7222666894236, 54.23107047234812, 59.26860578598515, 55.25014538918772, 55.58704168565812, 46.70812922139322, 49.203364618362926, 57.02817540014944, 53.300472459485455, 51.050400887766195, 42.825496581292924, 39.67187958378946, 42.29610996861612, 48.14878832909369, 53.77459287643433, 49.382358058806396, 49.05422433730095, 52.632414371736594, 51.72116148856379, 53.79453028402021, 50.30353061614498, 52.2927410371842, 50.10954195453275, 47.91498761023245, 46.869593589536606, 46.09317610340734, 44.17155988754765, 40.75708958410448, 39.147352787756155, 38.9133128043144, 38.871982789808705, 39.26735770317816, 37.351385777996434, 37.899489941135535, 38.232267748925, 40.439946343821866, 39.633330529735936, 41.64916599950483, 39.612592958634906, 40.06316346506919, 41.57547250870736, 40.992086625868275, 40.505300875633, 42.70257342246271, 39.8858017306174, 41.48164941418556, 41.78047126339328, 39.658896538519095, 41.27801956668977, 43.00718861241495, 39.48705750126993, 41.83898518162389, 38.961852135196814, 39.37640351633872, 41.42690489369054, 40.325275851834206, 41.41482007118964, 49.37095965108564, 55.68992937764814, 57.703219229175204, 55.91137855283676, 55.08454292051254, 53.48958169260333, 44.623071762823294, 46.62830114364625, 47.58843460390645, 49.705447612270234, 48.40647628230434, 48.78764437090967, 46.89128037421934, 47.755880586562625, 46.00907264217254, 42.83352175066548, 43.09084100107993, 41.62841666129328, 39.91157954738986, 39.482331045212284, 41.463229963856364, 41.527643126826135, 41.737321269127634, 40.71102134643063, 38.41887058750276, 39.54886621044528, 39.836999600933446, 38.281195394454464, 40.69075838212044, 39.441699212597264, 39.409214142830145, 39.449559642422585, 40.57671154699018, 39.68721997353339, 39.72775766926427, 39.03689099896339, 39.84000021411527, 45.1595853221032, 48.800952972904334, 51.34025227638983, 53.44600808235907, 51.30171498944683, 53.25794612207721, 53.90216796628891, 53.819731512377345, 52.56682057534495, 52.19013183347641, 50.700215601151996, 42.947364622546786, 43.01577860309232, 42.42308101346416, 43.6099039354632, 47.8835262790803, 49.34147519450034, 48.57589521715718, 43.67642341121551, 43.08691078616727, 47.63724065596058, 51.64644033678117, 56.236656788856756, 54.930958594045336, 57.83035501357048, 60.57946974231351, 64.97282635781073, 63.50149431536275, 64.93189250269245, 3.9617694001044, 0.6377686872597664, 1.4390723863917014, 0.04939302862171204, 0.058937074556466074, 34.8516357329584, 70.78524943320983, 61.63204562279486, 56.657687925523334, 31.902625253123624, 36.55527407123197, 57.51515726889334, 61.85194938413559, 58.99523227445541, 11.043227295721731, 0.028120331699028615, 0.06487562726702421, 0.037193833024150906, 0.050955690939219735, 0.02179227115946912, 0.019238672196684826, 0.006752794048929167, 0.05014826874098471, 0.04055209818386263, 0.1450959190485939, 0.152495562309219, 0.24043255816063575, 0.14736700202188185, 0.13206551422274884, 0.20301420391807634, 0.1589017427496372, 0.11619670767216914, 0.12596018417107482, 0.15420459721597934, 0.14828396330197013, 1.872409591751714, 56.98837511001095, 67.86956341035905, 59.72414201305759, 45.781237848343395, 51.980512526727495, 45.27744077867078, 57.911681436723285, 61.449871140141646, 68.80806107674876, 32.55649024440397, 0.11234365313524201, 0.15328230396393808, 1.741305104186458, 5.236710819505877, 44.71544750275151, 63.68041715314312, 61.354184919788, 61.9700558723942, 56.9231931624874, 62.16668036676223, 58.415949190816576, 55.48381666983328, 48.78404755746165, 50.379455935570505, 57.916015655763694, 55.91982733818793, 53.45054234227827, 44.18861043068671, 40.65212303592313, 45.98807619464013, 52.753678367983916, 53.414354555068485, 50.956707231460086, 50.74225948702905, 55.19008213473905, 54.60074993871874, 56.661967231381325, 53.55806627581197, 55.18495167455366, 51.7308222862982, 50.773654137888265, 49.95403566668111, 48.89550170590801, 45.716377535173976, 41.39512977292461, 41.29618798532794, 41.10894580041209, 40.944767152109456, 43.104651666456654, 40.093687349750155, 40.16492151444958, 42.223973658777055, 41.791265626107496, 41.63303721335627, 42.62279633552798, 40.48607733941848, 43.23152072968022, 44.50603215925155, 42.35869138471542, 42.80498258529171, 44.784406692751, 42.60438080756895, 42.47186745366743, 45.13905955899147, 41.06161848191292, 42.256780362898304, 44.93701042667512, 41.19933289866294, 43.19712546563918, 40.65130718292729, 42.09752036679176, 42.88983129685925, 42.484885800269346, 43.0439765222611, 53.92652588505899, 57.55891130816553, 58.819541469697036, 57.985276868266446, 59.48219453134845, 55.973336312078665, 45.855813872429636, 48.2162138723558, 48.39960036739227, 51.978496428458925, 50.486332678025775, 50.79625483482115, 50.250590385929236, 50.343621161676225, 46.165775252926736, 44.91478627727878, 46.88422795264952, 42.6936068842488, 42.43578164808212, 42.93569557128414, 43.60345163652974, 43.78686951052758, 44.25387474798387, 42.25341496929046, 40.2672012390629, 42.41187087951168, 41.581069730943256, 41.77117916845506, 43.038465592169, 42.61185292274722, 41.69197082519531, 42.48161062117546, 43.53413943321475, 41.63600644757671, 43.729218513734885, 41.41947592458418, 44.248324594190045, 48.233032995654696, 51.696740811870946, 53.97581438864432, 55.31989689796202, 53.59749786315426, 55.01782732625162, 58.24425528126379, 57.23597080476823, 55.89093515949865, 54.14824178141933, 53.769956634890654, 44.73064276479906, 45.82351707643079, 43.48576876424974, 46.20165709526309, 50.9822928520941, 52.343547498026204, 52.44785116564844, 47.34227449663224, 45.40847932138751, 48.99687536301152, 53.081109985228515, 58.94805792839297, 60.15842291616625, 61.30658303537677, 63.35018496359549, 69.01687237524217, 65.13749922475508, 67.95647528863722, 4.9044203662103225, 0.6406290757079279, 2.2808467332393896, 0.15553386701691538, 0.1520511547043439, 38.88020407768988, 78.46849010836694, 66.65511915760656, 68.23786612479918, 37.672557292446015, 38.483562238754764, 64.24481091960784, 72.63285052391791, 70.97881840121362, 15.426021948937448, 0.17030166732447763, 0.1869683850917124, 0.1495176866169899, 0.17349884334591129, 0.12515651197322916, 0.08739705708238386, 0.0859978894192365, 0.19355925400891613, 0.11346067061587689], [0.04350033393430133, 0.021497394341314514, 0.06492906189974278, 0.04219436852802192, 0.030626613241169724, 0.02168367053532312, 0.07518010739717754, 0.036950975491274754, 0.024326549384803064, 0.018508881518256762, 0.049585753360823284, 0.10787641824853998, 31.7718122466918, 55.832193743798044, 46.31751998778313, 32.39259792912391, 37.3589716419097, 30.032131248904815, 42.135708562789425, 55.72094748097082, 57.83136698507494, 36.766423102348085, 0.15199296266561554, 0.08991071413601599, 0.6534918758176989, 0.514387101415665, 20.231132315051173, 55.221880789726015, 58.36031821466262, 56.95926327859202, 53.94386276122063, 56.55188983486545, 53.41508019355036, 52.701887392228656, 50.99838241454094, 53.28766592087285, 51.40008803336851, 48.47055212143929, 39.528344369703724, 36.865247218839585, 38.95025760896745, 45.51421073175246, 50.643454982388405, 50.363284003350046, 49.2618118563006, 45.05400688417497, 48.34373797139814, 49.45751851604831, 47.74252883849606, 47.55421976889334, 47.28068151781636, 47.1950561769547, 43.00057157393425, 43.01276622279998, 40.774799085432484, 41.48815662630143, 38.41061399829003, 37.472951796747026, 36.277774226280954, 36.765819057341545, 37.791185455937544, 35.46694186425979, 37.65484779111801, 38.537400691739975, 38.17506782470211, 38.02173060755576, 38.26065001949188, 39.59682503054219, 39.176715650866115, 40.251433310970185, 40.480327144745864, 38.139068311260594, 38.795429891155614, 38.56969356536865, 40.280615745052216, 37.59757334186185, 35.8610616191741, 40.02796411514282, 38.29784977820612, 39.3958310158022, 38.89342246517059, 39.247745852316584, 38.25871236862675, 39.13362841452322, 37.98386404591222, 42.33849902306834, 50.34050679975941, 54.34986337538689, 52.897397933467744, 51.16802492449361, 55.72779201692151, 51.03944570787492, 42.072005348820845, 42.8741261266893, 43.792513801205544, 43.53914829992479, 42.255136889796105, 41.690303817872085, 41.10945963090466, 41.31323068372665, 41.163627562984345, 38.773766640693914, 39.735539651686146, 40.874329228555005, 39.100609902412664, 39.513419751198064, 40.499044695208156, 39.74831088896721, 38.77241734535464, 39.34111395189839, 38.693361974531605, 37.68046871308358, 36.88006593335059, 37.836951671108125, 36.5951253521827, 36.55312069000737, 37.01454047233828, 36.62043640690465, 36.975885514290106, 38.723827023659986, 37.76810230747346, 35.98406322540776, 39.27168015510806, 41.437271718055975, 42.74593130234749, 48.45503914740778, 49.98657172726047, 48.64574478518579, 47.373920179182484, 48.685960846562544, 50.800769482889486, 48.298983727732015, 48.97650649470668, 50.53333443980063, 45.744085158071215, 44.290501840652965, 43.50614155492475, 48.2780461157522, 52.595171466950454, 56.65050606573782, 57.005547246625355, 53.74079773502966, 49.44963847437213, 44.72223712551979, 45.00870743105489, 49.98585393351894, 53.74650478363038, 56.78901280126264, 58.32355776140767, 60.97165969110305, 66.01791443363314, 48.67164811780376, 1.0913896945215042, 0.22458163210220877, 1.9985906467322383, 0.026082361620219967, 0.12217001779185188, 30.248224427623136, 67.83430130250993, 55.50647620231875, 51.02891022159208, 31.172334840220792, 16.934919511118245, 35.271266583473455, 54.61534507812993, 50.98230069683444, 6.177647219550225, 0.11146721024546893, 0.02751461087515758, 0.02128648842054029, 0.02095228256357293, 0.10071445376642289, 0.006112699338700623, 0.02966129457608106, 0.059304670355613195, 0.08597863762969933, 0.05371352319695777, 0.01504903501500526, 0.092704514221799, 0.06548108187534156, 0.04014244798811213, 0.044976512586037, 0.022117013915351803, 0.02999226371156833, 0.06060850603746311, 0.046184997134391344, 0.012033649742783559, 0.07353039833927348, 36.72931748051798, 62.45269175498717, 52.26499026821506, 37.37474741474275, 42.52650999253796, 35.70480223624937, 47.94050655057354, 60.17434773906585, 63.73757000892394, 39.875293700925766, 0.019801262270418868, 0.04546359511873415, 0.9460945619690804, 1.0667211730634014, 22.0965939183389, 56.387020849412494, 58.77160226145099, 57.63569562665878, 55.26297938439154, 56.8613491519805, 55.04562124129265, 53.78914094740345, 51.41703267251292, 53.276491088251916, 54.60462916281916, 50.74527578969156, 42.72387581486856, 37.25978666736234, 40.33883548551991, 48.139935539614775, 52.78306868768508, 53.66631192545737, 50.14913828142228, 47.199719875089585, 50.7312297821045, 52.31436506394417, 49.25894068133447, 49.0025588773912, 49.05299663543702, 49.2175361417955, 45.396986776782626, 45.18167218854351, 43.54058388740786, 44.10720163776029, 41.29364236708611, 40.19765369353756, 38.192530216709265, 38.95257572973929, 39.47379204534715, 39.00650831960863, 39.385609319133145, 40.35065750921927, 39.80721704421505, 39.830421786154474, 40.96011146422356, 41.190888035681944, 39.72815775102185, 41.838938113181825, 41.09543715753863, 40.073953905413234, 39.11871556312808, 40.41378805714269, 41.05869631613455, 40.22224303214781, 39.32673454284668, 41.06308937072754, 40.14969487344065, 41.61002466755529, 40.76059618303853, 40.71988982539023, 39.692840729990316, 41.22480084819179, 42.16276507223807, 44.31548733865061, 51.014562191501746, 56.46668026524206, 55.60504144237888, 52.93892798885223, 57.87148498719739, 52.18615455012168, 43.54009359113632, 44.15393275599326, 46.23497762987691, 45.87133076883132, 44.63506244844006, 42.65387327440324, 42.70340104256907, 43.29694586415445, 44.51147248668056, 40.65324091142224, 42.429588225580034, 43.35305144709926, 40.662211372006325, 41.204988956451416, 41.72625234050136, 42.31813407713368, 41.14429027803483, 40.671644672270745, 39.148706005465606, 40.40515099802325, 37.98753538439351, 40.036891429655014, 38.434391406274614, 37.86724413594892, 39.24565915138491, 39.64966720150363, 38.39180623331378, 41.44961933935843, 38.624006625144716, 37.99597240263416, 40.916047557707756, 42.42670136113321, 45.40286640967093, 50.32406814636723, 52.60457731062367, 51.91555415430377, 48.658665072533395, 52.61441853738601, 52.23330143959292, 52.30479055835355, 52.5879111597615, 51.951557590115456, 49.31452458904636, 45.87854008520804, 44.225284591797866, 50.30491913518598, 54.96349073225453, 58.92500223652009, 58.05005873403242, 55.3851729823697, 50.565937180672925, 48.22432533387215, 48.970316994574766, 52.672151903952326, 55.459729394605084, 60.47697820971089, 60.5949434926433, 64.10775938341695, 67.45238011883151, 51.415487258665024, 1.2973068966980905, 0.7376694943635695, 1.3308165630986615, 0.11627361523888766, 0.006955020672326247, 34.06417285242389, 74.48867290250718, 60.05880648089994, 58.085540494611195, 30.24929523468018, 18.793442441571145, 42.1767012534603, 61.918398257224794, 58.29796037366314, 8.750054759363975, 0.09271749175123631, 0.02230019511414632, 0.04575998687575902, 0.010626223651812443, 0.048272475645306616, 0.01685209380793235, 0.0035471908209259596, 0.025524632374365485, 0.039979435969144106, 0.1978771400547797, 0.15279850411799648, 0.29398492327140224, 0.16247758071028418, 0.17663865470357482, 0.14699924917471024, 0.20098845294165998, 0.13961057629316084, 0.18752537697793978, 0.1607571004499351, 0.19422242568144876, 0.3390547645188147, 41.37605920914681, 71.61735673104563, 60.75738845332977, 44.544538067233184, 48.68279157146331, 43.63537188499205, 54.040090268658055, 66.19740993745866, 68.89816576434721, 44.67032455628918, 0.3087459666834724, 0.26345120202149114, 2.7883781444641853, 1.583298673072169, 25.11910177046253, 58.33799992838214, 60.220890583530554, 61.098050225165586, 56.79677909420383, 58.24871501614971, 55.15902480771465, 54.39522950879989, 54.129708582355136, 57.23951270503383, 56.783003730158654, 51.74035364581693, 43.90503483433878, 40.5792453981215, 42.92452858340356, 51.508835746395974, 56.54093857734435, 54.74901160886211, 51.17240228960591, 49.39829464881651, 53.56915089391894, 54.29121217420025, 52.595277370945105, 51.74071058150261, 50.62891867852981, 52.4143619691172, 47.865561823691095, 47.996082613545084, 46.815268762650035, 47.09184685061055, 44.3255207615514, 42.93459338526572, 39.92919883420391, 39.912415012236565, 41.14582000240203, 39.38511902286161, 41.36240151620681, 43.154799169109715, 42.025031043637185, 42.84370030126264, 43.43204013762936, 42.66583258105863, 42.839632803393954, 44.337001539045765, 45.093822863794145, 41.26841368213777, 41.299674972411125, 41.40024846599948, 43.98741637506793, 41.91667556762695, 39.061884341701386, 45.03804675994381, 41.8855554826798, 44.10122002324751, 42.3780208249246, 43.019179298031716, 43.0206697986972, 45.03681905807988, 43.80763453821982, 46.929586241322184, 53.49642622855402, 59.38265262111541, 58.09760570526124, 54.903133300042924, 62.720985797143754, 56.383812350611535, 46.154757315112704, 46.714044155613074, 48.57431450197774, 47.36025464150214, 47.52839880604898, 44.87067530232091, 44.59239882807578, 45.07913750986899, 46.07113238303892, 41.930235201312655, 43.92269726722471, 45.01586967898954, 43.49605321884156, 43.159113776299264, 43.55449261203889, 44.04015656440489, 42.259114173150834, 42.36120954636605, 40.84500558914677, 41.921947233138546, 41.01884895755399, 42.767268996084894, 40.95855820563532, 41.2299705320789, 41.48858808702038, 40.53829977589269, 40.28939400949786, 43.981003299836196, 40.559751218365086, 38.73030677918465, 43.79068597670525, 45.47595977783204, 49.0065126265249, 51.87337298547068, 53.76111169015208, 52.85291041097334, 51.51026741150887, 54.435410268845104, 55.25897464444561, 53.390769343222345, 54.083750171046105, 56.57038381022792, 51.49678230285645, 49.97771893778155, 46.492187053926536, 53.666821833579775, 56.852064901782626, 62.393460043015025, 61.326018379580596, 58.94659096194852, 53.48161928115353, 50.71578741073609, 52.3191072094825, 52.929863391384, 59.23899973592451, 63.91963466521233, 64.06589592656782, 67.17554707680979, 69.3151137136644, 55.16514370518347, 1.7284376462621076, 1.3851719109281417, 5.632270084273431, 0.26267662584300966, 0.16105494011313687, 39.059119070729906, 80.3726282427388, 66.90724911228304, 65.59953089683287, 45.28244180064048, 28.235354269704512, 50.41774219082248, 69.22665642153832, 69.07896349506994, 12.294294718773136, 0.20445276382229022, 0.138201265625896, 0.1315527715750279, 0.11960082702458867, 0.2707906307712678, 0.09740988753976361, 0.13213685233025782, 0.11337057101510226, 0.2127905583549892], [0.06580974125573713, 0.04814660356890771, 0.06597850276457687, 0.031078767910179113, 0.026186338903742935, 0.03749286778451454, 0.03922005131420109, 0.05764297585213377, 0.04420467134144518, 0.02582941087894142, 0.1556690508920339, 0.2170425761611231, 14.540365472916635, 55.90687174950877, 43.47728075519685, 31.488968172381004, 48.523543342467285, 37.99473293365971, 37.861215452994074, 54.46292961797407, 56.73644127384309, 42.88060588221396, 0.8307701373292554, 0.0912896264344454, 0.19347771161025573, 0.6426405774489526, 4.9569590437796816, 37.231290648060465, 46.55267000198365, 49.39642367824432, 52.54337656882502, 55.59401173745432, 54.50010192009711, 55.33266813524308, 54.08099274481497, 52.4077174740453, 44.854617118835456, 39.564496855581964, 36.25508723720428, 38.77797926625898, 45.329655370404645, 52.07891302724039, 50.81459191537673, 50.73258692218412, 51.2850998293969, 48.07664025214411, 46.08434684814946, 48.54660295671033, 46.69620521606938, 45.80175184434461, 45.047825228783395, 42.79129351339033, 37.887420808115316, 39.4379964951546, 37.5354665325534, 36.73309080062374, 36.9659540730138, 36.73776626586914, 37.22241824673068, 38.025323498633604, 36.513332166979396, 37.23310670545025, 37.27731573966242, 38.86538928554904, 37.18850151185067, 36.858685093541304, 36.552916726758404, 38.85296321684314, 38.29689664225425, 38.756468988234, 39.981350668015025, 40.511545288947325, 40.040311736445275, 41.58094029272757, 40.36181665235951, 38.254699783940474, 37.77227963170698, 40.07864898250949, 39.282988348314845, 38.3020035682186, 37.80133262757332, 38.190514118440696, 37.27219704658755, 37.64375140590053, 35.59257930324924, 43.05495523637341, 50.543454154845215, 53.68666510428152, 52.82521455518661, 51.933338180665054, 55.374810080374445, 51.436111081031065, 43.13488921811504, 42.58507097921064, 41.8832883527202, 42.515252790143414, 41.94867426349271, 41.36611207838982, 40.47381208788964, 40.73500664003434, 38.95434864105717, 39.359953095836026, 38.48913592676963, 39.990054407427394, 38.344502449035645, 40.031502093038256, 39.81076286685082, 39.578919410705566, 39.433889773584184, 40.59106742182086, 40.149133974506015, 36.984608865553334, 37.32814573472546, 36.061749689040646, 37.47166133696033, 36.091465565466116, 36.81155389355075, 38.16192396225468, 37.71670749110561, 38.721120588241085, 37.39077814163701, 36.117514025780466, 37.76263060108308, 37.07168548337875, 41.50279491178451, 46.52884160318683, 52.048475434703214, 50.78863759194651, 50.04042979209654, 50.61617489783995, 48.94287217047907, 52.075320136162546, 49.86057735258534, 48.50209974473523, 45.11253256951609, 44.678298734849506, 43.567212858507716, 46.526260683613444, 52.69378377545265, 55.50688412881667, 56.92314217167517, 59.45517724560153, 55.580652144647416, 56.34485144768992, 52.70662169302664, 49.35434449103571, 54.217816783535866, 54.844011414435606, 60.13119382243003, 58.87720815597042, 64.95465009443222, 38.63425185603481, 0.2983908481415241, 0.08219836144557885, 0.5377065113955929, 0.21115698310877049, 0.04573467533074079, 30.579421520233158, 65.2807677176691, 57.933364299035844, 48.46094231451712, 35.68413919018161, 39.507465593276486, 47.16571292569561, 55.066150926774554, 41.99569955948861, 1.7309162164888077, 0.0226076491807978, 0.06906389123609952, 0.06608969276590694, 0.046656899634868874, 0.05601595448810728, 0.024936943345012206, 0.03577807189656362, 0.034712677250706384, 0.048938615908545834, 0.04251084711042143, 0.03390551169192599, 0.05087204945964679, 0.034277493344439615, 0.004972809824281403, 0.06851643714452944, 0.03560844087792981, 0.07866540908693306, 0.04297198607556282, 0.01297505688853562, 0.07699251820844027, 0.12557741600058733, 19.34284490923728, 62.258095125998224, 48.82624049340525, 37.71729584663145, 48.41188130840179, 38.21243232296359, 47.29060903672249, 59.496067954647934, 59.183525654577444, 46.05043011326944, 0.6175417597255399, 0.0319705325584378, 0.6423716499440132, 1.1558473518779202, 9.03975611732852, 38.59365924712151, 49.884845056841456, 49.38565677212131, 52.51417060052195, 54.54145939119401, 57.50968164013278, 56.051477770651545, 56.476125332616995, 54.83275813441123, 46.1599858345524, 41.18018388748169, 36.70298268718105, 39.786973691755726, 49.16187378668016, 54.08442089634558, 50.93915854730914, 52.79997410312776, 53.126503575232725, 48.59716230823148, 48.95781247846542, 50.459272246206964, 49.16193654460292, 47.80600847736482, 47.16611692982335, 43.653395175933845, 41.71727403517693, 41.077696277249245, 40.681144652828095, 39.29610083180089, 39.797720986027876, 39.89733742129418, 40.60233246895575, 40.21570051870039, 38.9868611674155, 37.67981759963497, 39.128635237293864, 39.96772043166622, 38.49177960426577, 37.52242465173045, 37.70502667273245, 40.17219751111923, 40.02483406374532, 40.814014942415305, 41.93172177960796, 41.744699247421764, 41.64736955396591, 42.39180011133994, 43.03092287432763, 40.576742925951564, 40.32125934477776, 41.18818944500339, 41.86802248800955, 40.81684297130954, 41.18499271331295, 41.27177907574562, 39.68284653079125, 39.169714220108524, 38.79744598942418, 46.00145932166807, 52.76559845093758, 55.48530717049876, 55.97425806906916, 54.19609077515141, 56.487264863906375, 53.500360365836855, 44.20646505971109, 44.06603636280183, 43.48658853961576, 41.85468642942367, 44.973288428398874, 43.755855329575084, 43.028196827057876, 43.513142985682336, 41.2195997853433, 40.36426028897686, 40.04589719157065, 41.24824485471172, 40.209660068635024, 40.97864466328775, 40.26393782707953, 40.95571840963056, 39.087862199352635, 41.83757705073203, 40.7108409174027, 38.251722704979684, 38.20817262895646, 39.04247645408877, 38.49683161704771, 38.180798407523866, 38.32348638965238, 40.60089295910251, 40.2936105574331, 40.67890105708953, 39.90671973074637, 38.676425180127545, 39.488814723107126, 40.767699595420595, 43.163730405992084, 49.70621639682401, 54.90866384198589, 52.53348827362061, 50.450129201335294, 51.64150207273422, 50.78151849008376, 52.20387189619003, 51.02144987352433, 51.248915964557284, 48.85745079286637, 47.65166713345436, 46.94902943026635, 49.40897134042556, 53.89171092740951, 58.2228587519738, 58.439432421038234, 62.16169111190304, 57.66561546633321, 58.603736585186375, 54.00257279795986, 53.16377393661007, 56.17280060245145, 58.13754327835576, 62.51134295617381, 62.61188899317096, 65.93140263711253, 41.765593713329686, 0.6831508778756665, 1.1601519079939013, 1.5570183026213802, 0.094856018530986, 0.04314101954561569, 34.02654555536086, 71.72484536324778, 62.23367837167556, 52.606864052434126, 36.38561194942844, 40.322137955696356, 52.04428634335918, 62.6783614004812, 50.65719112273186, 2.937078629770587, 0.035473954142822374, 0.0178331594103046, 0.0042556945493655105, 0.03825931193967981, 0.03899741850252594, 0.027660265256981217, 0.09081434548622178, 0.025298241901421742, 0.04213948215868685, 0.16827813800304167, 0.16701564042558595, 0.1613698328935331, 0.1601039032421766, 0.11820073239505292, 0.1491529061909645, 0.12775281459213267, 0.1630726165228313, 0.19285166455853373, 0.09757747693407921, 0.2994570893145377, 0.30755362743812226, 23.765897789309104, 70.98081881000151, 55.419007347476104, 43.26637491103142, 57.32985665721279, 51.2612400516387, 50.61472362087619, 64.30445448044809, 65.88675821981123, 51.92926676042619, 1.0979416461721545, 0.1888120522902858, 2.4971973175002686, 2.821970058064307, 6.850400384395354, 41.00125712733115, 47.17806446936823, 51.07053049149052, 53.07074708323325, 57.24947160290134, 58.93415704850228, 58.73699126705047, 57.711118882702245, 58.32152597365841, 46.93401067487655, 43.73920094582343, 39.488030249072665, 43.01801043172037, 52.0121072184655, 56.249353501104544, 52.29807153824837, 55.35035802472023, 55.189823258307676, 51.923406739388746, 50.28390307580271, 52.87298117914508, 51.79962065912063, 51.21478742168796, 48.49039539214104, 45.93459075497043, 42.71711364869149, 42.802264382762296, 41.8891405290173, 41.610546342788204, 41.015797353559925, 41.57233069019933, 42.959865216285955, 43.30198218745571, 40.78136905547112, 40.39028521507017, 42.17452826038484, 42.20034137848885, 41.18212938308716, 38.74446653550671, 39.775300718122914, 41.22261216563564, 43.11806617244598, 42.273658321749785, 43.79813455766247, 45.32470926161736, 44.38949461906187, 44.19193660059283, 44.656302082923155, 42.36999957792221, 42.22863343454177, 43.1181053961477, 43.19856105312225, 42.981791265549205, 43.44818853562878, 43.792278458995206, 42.23727049366121, 42.012922686915246, 41.89978191929479, 49.117186223306966, 55.25148291741648, 58.4329761997346, 57.41542316252186, 54.63025792952507, 58.1944804037771, 57.03787934395575, 46.4507354459455, 46.11793018156483, 46.15256863255655, 46.023808986909934, 47.812041082689845, 45.96434585509762, 45.52352243854154, 45.506220863711455, 42.68896279796478, 42.17155118142405, 41.99287937533471, 43.42998873802924, 41.95586004564839, 43.55450830151958, 42.90428523094424, 42.0785713964893, 41.362515264941806, 43.68305221680672, 44.36816869243499, 40.1764375932755, 40.67976005615727, 41.13226036871634, 40.64777312740203, 39.80006656339092, 40.541425904920025, 43.801244997209125, 41.44249239275533, 44.57981194219282, 42.470557382029874, 40.921805597120716, 41.75088090281333, 41.929521329941295, 45.358253371331, 51.94556028612199, 58.74977034907187, 56.17075704759168, 54.60867704883699, 53.69194461453346, 52.697168780911355, 54.98989220588438, 52.842841686741004, 54.254471332796165, 50.88568879712013, 51.959241513283025, 48.30885241108556, 52.36701896113735, 57.53318055983513, 60.36326085367511, 59.38838320393717, 66.19482117314493, 59.61189162346625, 61.174003001182314, 57.511132917096546, 55.41735210726338, 59.767907819440296, 61.06231351052562, 65.71437397310811, 65.45306567222842, 68.6304561553463, 44.29986846062445, 0.7944464767652174, 1.4896563753004999, 2.792797184759571, 0.40345919408625175, 0.12394915740456312, 37.80633364954303, 78.3998094066497, 69.4373583024548, 63.915002346038825, 48.87842762854792, 53.45478242443454, 63.65493351413358, 69.68377728616038, 61.96829472818683, 5.527604578002807, 0.20644584880961528, 0.12454897360575777, 0.125542099347278, 0.23564351271958123, 0.18997457539362295, 0.1548859711375929, 0.17285289332991646, 0.19558774758010142, 0.12723821801163498], [0.03094882599168247, 0.06654058147462145, 0.07943513592885387, 0.028419508185658245, 0.06594094913452864, 0.03804309511437051, 0.04144886155582724, 0.021466505676207524, 0.07927043468601282, 0.06958637086133804, 0.05482692474259004, 0.0639058059201606, 6.063626370122356, 53.9104716239437, 47.090042560331284, 32.90144701157847, 36.28555620870283, 31.720170321003085, 31.04694058818202, 54.43932479427707, 52.42489745540004, 52.538140204644975, 1.7289567474396, 0.06127625508534332, 0.13126472251549845, 1.212777613151458, 3.133316770676644, 21.964698337739517, 45.5514261799474, 50.45088621877855, 58.96812085182437, 56.160139191535215, 55.675836301619015, 51.39296500913559, 44.92082672734415, 39.49706346757951, 38.30454134172009, 39.164238591347974, 42.97397398179577, 49.40873992058539, 52.08910726731824, 54.26283774837371, 51.160113503856046, 50.21304153626966, 48.9067667530429, 47.224050337268466, 44.40696877817954, 46.05851019582441, 42.0289965598814, 41.65659889098137, 37.833794163119414, 37.89247282089726, 37.46972368609521, 37.87024867150092, 37.07587849709296, 36.38596496274395, 36.798515935097974, 38.85918409593644, 37.62772067900627, 37.54047932163362, 37.18484586285007, 36.974563675542036, 37.69180436288157, 37.36740473778018, 36.54092996351181, 38.7957005346975, 38.70531735881683, 39.44224834442139, 39.33126488039571, 39.650251634659305, 38.72105390794816, 38.588744517295595, 40.12771783336517, 40.072031944028794, 38.32571429591025, 37.425530341363725, 38.18234774374193, 40.2553988272144, 38.94890046888782, 36.71166289237238, 38.828424869045136, 37.35440600302912, 38.01213649011428, 37.588140041597434, 38.28572180963332, 41.864661016771876, 49.746161814658876, 52.18933559233143, 56.09358049208119, 51.29024990143315, 55.48426382003292, 53.633587591109745, 42.679749150430005, 40.18822823801349, 41.68945266354469, 40.866755131752264, 41.95814678745885, 40.04797212539181, 39.852132105058246, 40.35862384303924, 38.926303694325114, 38.6681568238043, 39.4822447530685, 39.20537640971523, 37.3364572371206, 40.66382738851732, 41.91306306469826, 40.17928915639078, 41.84053059547178, 41.05316969656175, 39.35459906055082, 38.37713264649914, 36.404674668465894, 36.957579812695904, 36.28579155091317, 37.87384156257876, 37.95830195949924, 37.67600113345731, 38.21047506024761, 36.8269060504052, 37.38809524043914, 37.70647010495586, 38.29423727527742, 37.71608383424821, 39.9395146677571, 48.495266975895056, 52.594241865219615, 49.6276120985708, 49.168263327690866, 51.7067507005507, 51.72021619735226, 51.69234383490778, 50.19301391416981, 47.58921907794091, 45.7339850548775, 44.013151045768495, 43.40935314855268, 44.828882448134884, 49.43676917783676, 51.24145953885971, 54.678942388103856, 57.79563027043497, 57.58330060589699, 58.955553577792266, 56.54555520703716, 56.36571845700664, 56.29177001214797, 56.49128921570317, 61.007502309737674, 60.49520546390165, 65.27549212978732, 25.791339143629997, 0.6668775769010667, 0.6197897068435146, 0.5557348278741683, 0.16506881182712896, 0.010417790279813833, 32.81744553196815, 68.63066011859526, 53.23290571089714, 54.717785619920306, 38.80716170034101, 23.920735313046364, 42.31585125769339, 54.98891945808165, 42.553825378417976, 0.7350574409769428, 0.12686340949468075, 0.027443276598088207, 0.007597016238216912, 0.06860433807296139, 0.0818430039010221, 0.023178108892734015, 0.040645668162934245, 0.032354754380761616, 0.02872849442815829, 0.04392928571530408, 0.03856271723165147, 0.047673153570823135, 0.06030913036797316, 0.06096263401090138, 0.027933069166817495, 0.09375249951957695, 0.055429387777563066, 0.07181355699656472, 0.0457576388162711, 0.04132979234019595, 0.13654121438101416, 8.974161340344338, 62.79728766410582, 52.80750897622878, 39.38807648997153, 42.46023370373634, 35.22847352489349, 39.15132222637054, 58.966967674993704, 57.56141770270563, 55.06670005859868, 1.8767139027195594, 0.007176237657756335, 0.65960421557388, 2.7177372382533167, 3.719339466864063, 22.61486649513245, 45.906090813298384, 50.95859781388314, 61.113971125695016, 58.272735611084975, 57.20874171103201, 53.73416892943844, 48.53952700091947, 43.10484778496527, 38.99611011628182, 40.32405599471062, 43.527993079154726, 50.52799217162594, 53.403913205669774, 54.28250843478788, 52.52059152049404, 52.30211157952586, 50.6735356392399, 49.68014047991846, 46.035803594896876, 47.8283267636453, 44.81093368222637, 44.694172566936864, 40.898165472092174, 39.046998946897446, 39.80380850453531, 38.90253413108088, 40.25800328100882, 39.338183941379675, 40.22777749646095, 40.43720460707142, 38.911206491531864, 39.41566251939343, 38.27398215570758, 37.485291573309134, 39.073329817864206, 38.80422384508195, 39.274700380140736, 40.65232699917209, 39.60947075197774, 40.58837275351248, 41.12976181891657, 41.82956757084016, 39.31175501115861, 41.584866585270056, 41.47369876984627, 41.09866919056062, 41.403790366265085, 39.27505339345625, 39.74760093996602, 41.64714990123626, 39.62202233652915, 39.678167143175685, 40.73800725321616, 40.598888627944454, 40.58537606270083, 39.626395779271284, 39.13951981452204, 43.24849282541583, 51.57090725437288, 53.95537884004655, 56.20124563094109, 52.54088978613577, 56.96277379989625, 54.06872749328614, 45.35573913205055, 42.201671061977265, 43.70057344436646, 42.87873491164177, 43.26828118293516, 42.015225118206395, 42.49240890625985, 42.833353088748076, 40.234802461439564, 39.30877400982765, 42.19488928394933, 40.250131084072976, 40.17743779766945, 41.303295320080174, 42.23086134079964, 42.13211567171159, 43.91886511156636, 42.1950775577176, 40.74408300461308, 40.59326002674718, 38.092254823254, 39.552337508047785, 39.15874335073656, 38.686207571337306, 39.92172279665547, 39.99662437746602, 40.79523463403025, 40.800769098343395, 40.058872392100675, 41.527533300461315, 41.478629189152876, 41.39461986480221, 42.34547691960489, 51.137328455525065, 55.684379223854314, 53.52014872335619, 53.07277887098251, 54.6241468767966, 53.15521924726425, 53.629312207621915, 52.360766703082675, 50.032306563469675, 49.53245147582024, 46.06109503776797, 45.96858985962407, 49.39654134934949, 51.77852615233391, 53.361924232975134, 56.92658209031629, 60.116751655455566, 59.379098953739295, 61.05917169201759, 59.06589769547986, 57.608231190712225, 59.64058768364691, 59.6881385772459, 62.53434373486427, 63.833067955509314, 68.08540359620126, 28.657122811963482, 0.8146900130856423, 0.89124315688687, 2.302193252309676, 0.05565591231589356, 0.057820229445614164, 35.70990131747338, 74.33805388789024, 58.37199903303578, 63.18395491569274, 43.27732224618235, 30.18689032523863, 50.044375696489894, 61.00361916326708, 51.64661292106875, 1.1165673886576006, 0.047973946502973, 0.01542169752816159, 0.05508319647502034, 0.05374533499801352, 0.03540833105122851, 0.027130724216300636, 0.009439126363084202, 0.012333051267740949, 0.036531622791963245, 0.1791068827432971, 0.1203410288379077, 0.27399033488285157, 0.18461614276372618, 0.16363399043198557, 0.1150123127585938, 0.17132965006655262, 0.12440868758506353, 0.15256470940526456, 0.09387767828640439, 0.14029116880509163, 0.27853433944044576, 11.339317214104438, 72.0558463373492, 60.796439570765344, 45.35936732445994, 44.51789732902281, 43.12552259814355, 42.32564933838383, 65.9695359199278, 61.234027031929266, 62.61653307945498, 2.4854804623511533, 0.14588131238856625, 1.0630216425465, 5.3065005713893525, 4.314936668642106, 25.552227535555442, 49.18546292089647, 54.03034710115003, 64.1987975951164, 60.68560123443604, 59.19143315284484, 56.85285329818726, 49.096150552072835, 45.2542438814717, 42.18615416557559, 43.76114660693754, 46.91288478912846, 53.94438051408338, 55.108814547138834, 56.0122658360389, 54.143989932152536, 55.07286210213938, 52.359872402683386, 51.95331873432283, 48.10293189940914, 50.393521555008434, 46.7856195665175, 46.30422707526915, 42.03687267918741, 42.235791760106245, 41.2298999294158, 42.36719900561918, 42.73391708250969, 41.61810867248043, 41.443331779972205, 44.09608171832177, 41.19991340944844, 41.661674437984345, 40.95472604997697, 40.38597845262097, 40.87765147609096, 39.75024069509199, 40.688079403292754, 44.12987685972645, 42.08691820021599, 43.8188878182442, 45.108425847945675, 44.011974334716804, 40.74132557838194, 41.93959789891397, 44.27762077700707, 43.41475817465013, 41.898107067231216, 40.78537771778722, 41.75547007591494, 44.695894487442516, 41.83652193315568, 40.541978959114324, 43.92554883033999, 43.10894666179534, 42.1582543465399, 44.11672907490885, 43.13503434581142, 46.16633615186138, 54.29289879337434, 55.77902993848247, 58.37168132105182, 56.76659645572786, 59.66012108710505, 57.882961842321585, 47.10126053902411, 43.440602671715524, 45.52491487995271, 44.806913252799745, 47.24039877614668, 42.470035706796956, 44.68965399649836, 45.210136828884, 42.21195943893925, 41.04905120788082, 43.63537972973239, 43.0419368897715, 42.04641580581665, 44.83797842456449, 43.92858082248319, 44.53746211144232, 45.832746413446245, 45.01847413278396, 42.96870231628419, 43.15974135552683, 40.08780771686185, 41.61802238033664, 41.44794056492467, 40.7007682708002, 41.814564504931056, 41.88275098800659, 42.88264551470357, 42.34183696008498, 42.871862919099875, 43.17390503421907, 42.81391774454425, 44.37858650761266, 44.96782064437867, 53.102024062987304, 57.69839863623343, 56.24962022227626, 55.36530225507675, 56.36601263476957, 55.54830435783633, 54.469087739144605, 53.57472458193379, 51.390788093689956, 50.7429890478811, 48.75649290700113, 47.741046182570926, 51.78205236311882, 54.96336521640901, 56.034862610601614, 58.64968322938489, 62.07359467783282, 61.23377600023824, 64.9072600180103, 59.868140066823656, 60.27048110961915, 61.465846953853486, 61.860253041790386, 65.42227114400556, 66.87634083532518, 71.79763670890563, 31.990894271481423, 1.0357583506453423, 2.6378944516181946, 4.514831439141305, 0.6494860327051533, 0.1763478936927934, 42.174218393141224, 80.5899824634675, 64.65611457824707, 67.99467917411559, 51.83525539213612, 35.717969632917836, 57.8817694417892, 70.02194050819644, 63.98494212858139, 2.8240756354024334, 0.3136831582073243, 0.08783358930339737, 0.15016595021851603, 0.16494744817816442, 0.18050837931373429, 0.12281481101508103, 0.10158314384640225, 0.11689983849083224, 0.1008155390680317], [0.021618922699182745, 0.041144808919559565, 0.10030317946427292, 0.09003299709048965, 0.05749821587796173, 0.055704895977772055, 0.05666310726214321, 0.02995945408099121, 0.031989146579778006, 0.018911759496756622, 0.06557894194678915, 0.09719696872296835, 4.420873022848561, 45.96648746921171, 48.39362267524966, 34.04368631301388, 22.382383692649103, 40.455510308665616, 33.55702215625394, 56.22488575596964, 49.1534956039921, 58.338294106145064, 5.1566125885132825, 0.07296652698348607, 0.4704852378176105, 0.91542910423971, 2.1755565895188242, 12.714645324214814, 52.10932316318635, 57.84290267575172, 56.479404434081054, 52.25943619205106, 49.273539743115826, 40.063598848158314, 37.61188214825046, 38.285917928141934, 43.74495114049604, 47.603312153970045, 53.78592068149198, 51.6734262435667, 51.80252321304814, 49.27531657680389, 50.42744221225862, 48.28755001867972, 46.18446534679782, 46.65104304590533, 45.039698077786355, 42.53561381370791, 40.05975492538945, 37.00791166674706, 38.748808599287464, 35.54347515106201, 35.88679628987467, 36.97512457447667, 37.47700360513503, 35.40771799702799, 36.88191729207193, 35.86866317256805, 36.71570685602004, 37.77759836566064, 38.18426186038602, 35.70239782333374, 36.522624261917606, 36.50274961225448, 37.27321294046218, 36.80424651791973, 39.13846861931586, 37.605151361034764, 38.57368653820407, 41.042445936510646, 37.73601731946392, 39.070588081113755, 39.28920138266779, 38.540656258983, 39.03521614689981, 39.26294111436413, 38.57393364752493, 39.40207150674636, 38.865436353991115, 38.69660185229394, 37.95551315430672, 38.68115948092553, 36.78421105107954, 37.04533892293131, 36.96598545197518, 37.85460625925372, 45.83228749613608, 52.485082303324056, 54.29282426834107, 54.4454554588564, 55.355861110071984, 49.479366117908114, 42.66704851581205, 41.2934305590968, 41.23310450584658, 41.721792605615434, 42.17076278501942, 41.51349513761459, 41.69699538138605, 39.248153778814505, 40.726106782113355, 40.53079235938288, 39.33114720929054, 37.88711486324188, 41.34039701954011, 39.712719302023615, 39.5198328264298, 39.65666078752087, 40.00129984271142, 42.268653377409905, 40.08142602059149, 37.698586140909505, 37.11236438443584, 37.56036573840726, 36.11193249302526, 36.936006776748165, 36.61742010424214, 36.87010311311291, 38.83262180512951, 36.89437081736904, 38.43290482797931, 38.410319820527114, 39.066791226786954, 40.56450905338411, 41.85592589839813, 49.97910353445238, 50.70787206772835, 48.047622557609316, 48.80778574174451, 50.69172366972893, 48.96803417513448, 51.649707671134706, 50.50818420225575, 48.10976466824932, 46.7544484907581, 44.67989513950963, 43.63161817673714, 46.0634994506836, 45.33142043698219, 50.677665895031346, 51.65982738617928, 57.06468482171336, 57.694852813597656, 59.72247892810453, 58.00901505254931, 58.2348455152204, 59.20546739332138, 61.348575930441584, 60.98644310428251, 62.29056450628466, 51.014617104684156, 29.873455685953942, 0.7896528501183756, 0.8603532047521684, 1.4780125742958439, 0.08979528000758541, 0.10802368333022441, 34.63183003087198, 64.79493118101551, 54.30780380002914, 42.84567717582949, 39.186164640611224, 29.213393349801343, 43.489859796339466, 58.56190058492846, 46.83647701817174, 1.806818001693295, 0.0969160825855309, 0.027699021645070567, 0.016654596341052846, 0.016672595576833815, 0.020363212660736135, 0.011156260734423997, 0.06258711579345888, 0.019573376010802966, 0.04480747528554452, 0.01871061736657735, 0.03899945629640453, 0.04873756762413729, 0.023667577789315296, 0.10546753137943246, 0.013465594477771271, 0.05356378748171753, 0.011909871959247658, 0.06137905642390252, 0.043781695046251824, 0.08390911238928957, 0.15158371849646493, 5.754211179671749, 55.17639306283767, 54.79233810978552, 39.34404396241711, 26.353385371546594, 41.27252824844853, 39.124265716921904, 62.791921861710094, 53.556234528941495, 65.01108123410133, 4.930434996081937, 0.12973283778034872, 0.4189320863975633, 4.455071678084712, 4.528746537623867, 12.723543220950713, 53.800398149798, 61.57180978405861, 58.17622177062496, 54.033512453879084, 51.829595411977465, 43.03079343611195, 41.51186735399308, 39.795226358598285, 44.16321700619113, 47.53513351563485, 55.068233705336056, 54.54240468240554, 53.5258283153657, 50.06887482058618, 52.82138632189844, 50.042077187568914, 50.83302705518661, 48.49980515818442, 46.29150290643015, 44.42680812651112, 41.55442507036271, 38.4409535315729, 39.652032390717544, 38.01507826774351, 37.64744627860285, 38.57261573114703, 39.75211166566418, 36.63806746082921, 38.92293045597692, 37.76969086739325, 38.908904060240715, 39.422083439365515, 38.873069286346436, 35.836582106928674, 39.268887427545366, 39.29578704218711, 39.63662139831051, 38.7912800235133, 40.0726830574774, 40.818847302467596, 40.55235755059027, 42.41621686566261, 40.939311135199766, 39.49487086265318, 41.03669574183803, 41.52373252376434, 40.56574852235856, 40.36019279110817, 40.718316954951135, 42.125581003004505, 39.15673901957851, 41.259827613830566, 40.96683832906908, 41.397071346159905, 38.910931925619806, 39.39697634789252, 38.739732234708725, 40.05800554829259, 49.51383198461225, 54.52800566150297, 54.62649637652982, 54.85312700271607, 54.690744799952355, 51.54249360484462, 44.96552605782786, 42.84788154786633, 42.43206716352894, 43.049236420662176, 44.777193454004106, 43.521823190873675, 42.7951805822311, 41.54430535531814, 42.22253414892381, 42.082113296754905, 40.83862389287641, 39.305753784794966, 41.796043072977376, 40.306201365686235, 40.5776725276824, 42.723569869995124, 41.981959496774984, 42.072578014866004, 40.93121536316411, 41.375443397029755, 38.41316746127221, 38.7769280710528, 40.28226314052459, 40.18260748155656, 37.97247348293182, 38.906389820960264, 40.66883625522737, 38.8772113092484, 38.59866026909121, 40.471592026372115, 40.82170671032321, 42.757443458803245, 45.00973116966986, 53.29321999703684, 53.788976207856216, 52.72227195001418, 53.167186398659986, 51.9355700092931, 51.26056932633924, 53.567464274744836, 53.28304144643968, 48.50836376990042, 47.88869596296742, 46.53913782488915, 46.563056438199936, 48.42227558935843, 49.323102812613214, 52.73085409595121, 54.377896555008434, 58.6428386934342, 59.14949517096243, 61.239698779198434, 61.27425878278671, 60.38376308256581, 60.734411208860344, 61.8635792116965, 62.50969556070144, 64.2299686708758, 56.692130258006436, 31.982843606702744, 1.003760880520267, 1.307532638311386, 1.7845786531125347, 0.14154801265366618, 0.05781945569681064, 37.63198429538358, 70.80568498180759, 59.03440106299616, 52.5237411837424, 48.35522659363286, 36.23402018700877, 51.70977877032373, 64.5127401813384, 54.620608898901175, 2.8216729385237542, 0.14476804873876034, 0.11784346729156472, 0.07079620755487873, 0.004966214764863253, 0.06432644947762452, 0.04374477343874113, 0.037562689037933465, 0.03363327468715368, 0.035152729645731955, 0.17591908363805664, 0.14180356426344765, 0.21110773897699772, 0.1304663363243303, 0.18173934471222664, 0.1162581785672134, 0.14566708356142044, 0.17970990119201524, 0.12527819737912188, 0.3261601564384276, 0.1542569363429662, 0.28297299158669287, 6.21336579322815, 62.85442875277612, 60.84534368207378, 46.71829208250969, 31.10775301533361, 52.43400127656999, 45.25838982674384, 68.52569749278408, 57.72011287750737, 72.1777065338627, 6.2282992370667, 0.24358116420767, 1.9703576713800433, 4.98291777987634, 4.8459461619777064, 14.510821200186207, 54.48150596311016, 61.93268745176254, 61.99127197265626, 58.66264274043422, 55.011743730114354, 44.11633291552144, 41.85168189387168, 43.02337231174592, 48.050011281044256, 50.56721195097893, 57.63740185768374, 54.5349011882659, 55.19325140983828, 52.040128630976525, 54.119894812184, 53.1254013892143, 52.61208472713348, 51.38497121872441, 49.504837989807136, 47.04417436353622, 43.48205427969656, 41.160756388018214, 41.24484023740215, 39.79366917763987, 38.94862590297576, 39.90557832102622, 42.048882976655044, 38.170945413651005, 41.24642879732194, 39.11063940294328, 40.7195407344449, 42.45328718616117, 40.88902634959067, 38.359336853027344, 41.9483643962491, 41.78742170333862, 39.672122770740145, 41.675861650897616, 42.60411016402706, 41.16185072929629, 42.40559508723598, 44.72519851499989, 42.560873877617624, 43.23484297721617, 43.54460431683449, 42.795863074641076, 44.10114549821423, 42.85620481737199, 42.552687891068004, 44.196921933081846, 41.148773547141786, 43.51992476371027, 42.737313855078916, 44.16111853814895, 40.751441371056345, 43.69589405675089, 42.59828936669135, 41.5667805364055, 50.51081611264137, 55.277876546306, 57.493666602719216, 55.70692500760479, 56.65735452405868, 52.15252807063442, 46.31361722946168, 45.65507481175084, 46.46221622343987, 46.207062121360536, 47.18947072182932, 45.6620095622155, 44.678012401826926, 43.962022950572354, 44.22180937182519, 44.14398562523627, 41.62247427048222, 41.7933052585971, 44.68763789822979, 42.6769446557568, 43.76044450267669, 44.33438924051101, 44.353793205753455, 45.15081882476807, 41.95980595004174, 42.790677701273275, 40.52693666950349, 42.12704404707878, 40.45728714235368, 42.08571403257309, 42.92705458979453, 41.292685308764064, 42.25905533759825, 40.69951703471523, 42.06217588916902, 43.2272728027836, 42.121176181300996, 45.081859634768584, 47.56423357994326, 55.253040098374896, 55.71824496792209, 53.55497937048636, 54.25223558179794, 54.62105997147099, 54.02344372964675, 57.34860558663645, 54.18892852721676, 52.70132257092384, 51.52066169246551, 47.95410148559078, 48.810452953461684, 50.45120393076251, 49.97996645589029, 56.065076628038966, 56.910241496178415, 61.285374779855054, 61.717561137291696, 63.03312017071632, 65.46507596969604, 63.21647920916158, 64.33088341066914, 66.30948774276241, 66.62318321966356, 68.00761515094389, 56.928225563418486, 35.530362667575965, 1.6441144097235896, 3.688953600583538, 3.556279184356813, 0.49875057272372714, 0.2116305480200437, 42.827277337351155, 75.97119546705677, 64.99919645247921, 57.16212434153403, 51.494766204587876, 42.479272888552764, 61.826042129147446, 73.05795700319352, 65.1308233507218, 4.058289614415938, 0.2740170560296505, 0.1879072564864351, 0.22300494654524713, 0.1297937877356045, 0.2594402720851283, 0.23100328751869742, 0.14654589366287957, 0.17902838937457533, 0.13947678669806451], [0.09797224204146093, 0.04746163286448968, 0.027946868325553598, 0.04641258653493659, 0.04851380483277383, 0.09838498723242553, 0.02298995961375054, 0.0008595790800867573, 0.0921202572663465, 0.023580167157154892, 0.028111293776741916, 0.039278932832061283, 1.3491759521345938, 38.71282085295647, 53.02733429016606, 42.812231125370154, 24.428246867272165, 38.35846608684909, 36.22594794919414, 54.06529149701519, 50.61364889144898, 58.5068069734881, 12.150791864241324, 0.1873834208855706, 0.2724085778238312, 1.475015148039787, 1.7378242458066635, 7.3602021125055135, 53.87437797361805, 54.4126565994755, 56.33726558377666, 46.63043099064981, 42.88614034652711, 37.62273534651726, 43.083914095355624, 47.42154559781475, 51.75471344301778, 53.36786270141602, 52.850953148257354, 51.96433667213687, 51.828454002257324, 51.008451138773275, 47.9342778267399, 46.622354830465014, 45.17105825485722, 40.61753949811382, 41.006669998168945, 38.702897256420506, 39.17139691691245, 37.23428341650194, 35.37507603245397, 34.82534016332319, 34.87413837063697, 34.41466408391153, 35.5840128467929, 37.14710089468187, 37.07782399269843, 36.920227081544944, 37.91090403833697, 36.377951560481904, 37.99840819451117, 36.8984696941991, 36.93781891176778, 35.755475336505526, 37.36446688252111, 36.97644641322475, 37.058145461543916, 36.931888288067235, 38.568383493731105, 39.18240308761597, 39.395376020862216, 38.29586113652876, 39.785083109332675, 40.350845782987534, 39.58024517182381, 38.96733560869771, 39.70339975049419, 40.34340112440048, 38.87075901031494, 36.12877907291536, 37.350652294774214, 37.33803795230004, 36.53090830772154, 36.33452307793402, 38.569222880947976, 37.18200998921549, 44.705402312740205, 52.45362097217191, 54.67534557465584, 54.93419062706732, 54.33422880788004, 50.24666017101657, 42.567683112236764, 37.48680953056582, 42.541991587608095, 41.767162661398615, 43.792847202670195, 42.456844775907456, 39.33459889504218, 38.591690217295, 39.75895620161488, 38.64921569824219, 39.82472650466427, 40.60607441010014, 39.985469156695956, 40.37076750109273, 41.43509480261034, 40.581877308507124, 40.20645549220424, 39.87583891037972, 38.91292448966734, 37.06730419589628, 39.876454722496774, 37.86317663808023, 37.94775862847605, 38.290656151310095, 35.650610769948656, 37.93102187495078, 39.02878345981721, 37.88011343248429, 38.00599405842443, 37.804737244882894, 37.78002239042713, 37.87228438162035, 44.13086529700987, 51.098677419847064, 49.209432525019494, 48.88471126556397, 51.38129988024312, 51.76644132983301, 49.73588520480741, 48.807444495539514, 50.02713295721239, 47.320470040844334, 46.11442750500095, 43.80148426178963, 43.3419942855835, 45.01406931108044, 50.59212292394331, 51.50550173174951, 53.76257081185618, 51.51511938341203, 54.81757856184437, 55.57051281775198, 56.957509979125, 54.69300408517161, 57.68008901226906, 60.651939453617224, 59.9460461831862, 53.432652411922334, 56.43934918988136, 33.662828091652166, 1.322226940143493, 1.623515102171129, 2.269678274469991, 0.11507782859787827, 0.05204843109353416, 36.81409166705224, 66.45183055631577, 53.41233453442974, 45.653360735985544, 35.228908907982614, 24.104243401558172, 43.45589207064721, 58.96759917659145, 33.836263533561464, 0.3775975979383915, 0.07883304444652411, 0.032933767464372425, 0.04484413642316096, 0.04670726608545069, 0.048991027813885486, 0.04572368962990661, 0.02901056991709817, 0.07393189735950963, 0.006015957276817532, 0.059009538813223766, 0.044840719671018665, 0.04878858524945475, 0.059715519478965196, 0.016902094451530326, 0.022143855720998782, 0.0705786232626246, 0.03748921737555535, 0.046797656799636544, 0.019368326832209865, 0.015476260225348657, 0.02299241875598748, 1.9862555279847116, 45.74090803823164, 58.276230442908506, 47.05526290401336, 26.91901860698577, 41.709899979252974, 39.34429499410814, 61.59319846860824, 53.52579301403415, 64.29069088351342, 13.72190704268794, 0.1213831842065819, 0.3593112630469184, 4.41092687268411, 2.276285016728986, 7.266942368399713, 54.44681259893603, 54.89269195064422, 58.455227805722146, 49.33129664390318, 44.42382712518015, 40.05728775455106, 44.53083330585111, 47.51783194080476, 53.704013747553674, 55.14390407070037, 54.56602127321305, 52.4517382344892, 53.79734654580393, 54.293016464479514, 50.61135822726835, 48.27134278512771, 48.08900356292725, 42.84174303854666, 44.3704201329139, 39.764188643424745, 41.54153616197648, 37.84700862822994, 37.37904633245161, 36.761649577848374, 38.27922636462797, 36.78470919209142, 38.1260185856973, 38.09106634509179, 39.108917482437626, 39.08421831746256, 39.97699683712375, 39.40846104775706, 39.70204261041457, 36.847169014715384, 38.15919791498492, 38.45360317537862, 40.273841811764626, 39.398517839370236, 39.09727981013637, 39.16617231984293, 41.4312038113994, 41.74251448723578, 41.04255968524564, 40.40610021160495, 42.0084237283276, 40.2711118421247, 40.92854815144693, 40.17360564201109, 41.19444562542824, 41.72171023584182, 40.255300767960094, 38.30250563160066, 40.51696992689564, 38.804518022844874, 39.73728118404266, 37.323427123408166, 40.47212546871555, 39.439781173583, 47.939957418749415, 53.24811274005521, 56.52502944392543, 55.34451761553365, 55.69263973543721, 50.373337038101695, 45.15972260505923, 40.60367391955468, 44.14628021178707, 44.799550963986306, 45.32493675908735, 44.20799086170812, 42.117685271847634, 40.22386689339915, 41.60026973293674, 41.60684754771572, 42.24657043333977, 42.19001770019531, 41.2907672697498, 41.35890668438327, 42.96818064105126, 41.776074286430116, 41.519547354790475, 41.917134484937115, 41.69117066168016, 39.212322927290394, 40.79415990460304, 39.193691668971894, 39.28090949212351, 38.84034495199881, 38.39326927738805, 39.747055730512066, 39.947622206903276, 40.05363995029081, 38.94613127554617, 39.56806621243877, 39.30894659411523, 40.794050078238214, 47.00400537060153, 51.86135876563288, 51.74518208349905, 51.43305555466683, 52.991632876857636, 53.493621733880815, 51.69624659322923, 50.026936838703776, 51.531224635339555, 49.23699502022036, 48.4226482145248, 45.599035909098966, 45.20078197602303, 48.67580583018642, 51.01963773850472, 52.810250712979226, 55.30583912326444, 53.40166960993121, 55.68533628217636, 58.351092800017334, 57.04743423769551, 58.345797600284705, 60.29449778218424, 63.78583085152411, 61.19411691542595, 56.922365542381044, 56.92148300909228, 36.7430575432316, 1.5528773828860254, 2.13019143669836, 1.686897172081855, 0.10817018998486382, 0.06789684055312988, 39.6575354760693, 71.22668081714262, 58.72946423868979, 50.11087948276151, 36.54868448934248, 30.794694923585464, 50.83905181577129, 66.79844256370299, 42.66975887360112, 0.5795231449507898, 0.01244942672670849, 0.03583798763312159, 0.048093659232460687, 0.034619329437132806, 0.034011691478231264, 0.030890298789487253, 0.03104470189540617, 0.018177412510398897, 0.00893526075918588, 0.2389364803750669, 0.20749983257584034, 0.23774723612493087, 0.16910978773188207, 0.16894800528403253, 0.2126782039000142, 0.21303529280327985, 0.06945618187948581, 0.2217156205686831, 0.08991621464731232, 0.0845944393245924, 0.14825635349317906, 1.983589174286012, 52.893722672616285, 66.09782095878356, 55.68633256420013, 33.72764918111986, 49.79665840825727, 46.68816043484596, 66.0962990791567, 57.33676787345641, 69.75575277882238, 16.141418141703454, 0.202928310140006, 1.6808779273302326, 5.032089102652765, 3.2895506581952496, 8.182416702470473, 58.91740068312615, 59.149863873758626, 62.183303371552505, 51.21272033260715, 48.31122152266964, 41.09185603357131, 48.541268533275975, 50.618422415948686, 56.10285297516854, 55.92815453006376, 54.7764289763666, 55.60983065635928, 55.811620912244244, 56.230129964890025, 52.03068356360159, 50.951949396441066, 49.02769734782558, 46.570030412366314, 46.18951735957977, 41.49960994720459, 44.61804720663255, 41.23981568121141, 39.53223928328484, 39.08168054396106, 39.56100986849877, 39.13835879295103, 41.40591629089848, 42.18438909899804, 40.890889475422526, 41.63000129884289, 42.14047424254879, 40.272712169155, 41.80567641412058, 40.62335637307937, 40.12096351192844, 38.556973318899836, 42.38348076420446, 41.25745457987632, 39.7361554638032, 40.724392706348056, 43.54089767702165, 43.02425092266452, 42.406587446889574, 42.11305295267413, 45.448922880234264, 42.859989904588275, 42.312203453433135, 43.60842912427841, 42.745017390097345, 44.563934187735285, 42.069993172922445, 39.49769889154742, 42.410133269525346, 41.03307931653915, 41.73942758191017, 40.973404376737534, 42.74316603137601, 42.497602124367994, 50.64857367546328, 55.81693572382773, 59.28016108851279, 57.366675946020315, 57.839780469094556, 52.21190883267311, 48.10587759940855, 42.49217748641968, 47.52756726357245, 48.31307680376115, 47.87004117042788, 45.64828518898257, 43.60973135117562, 42.22686444559405, 42.84084873814737, 42.9355033751457, 42.24362473334036, 42.793654780234064, 43.60598941003123, 45.034473480716834, 45.67937781733852, 43.66291084597188, 44.35162413504816, 43.31227056441769, 43.3839754135378, 41.07755899429321, 43.35152564510223, 41.4746166044666, 41.66840130282987, 41.39085046706661, 38.70317966707292, 42.5590774320787, 42.706315363607104, 43.14748394873835, 42.32430396541473, 41.42361402511597, 41.025120827459524, 41.9919458512337, 49.13924563315607, 55.22827033073672, 53.57867048632715, 54.98819381959977, 56.51187773673766, 55.5895951486403, 55.6948519522144, 52.17366572349302, 54.71263162551388, 51.500751741470836, 50.16472578048707, 47.57764808593258, 46.4976744497976, 50.67136656853461, 55.140366092804946, 55.431970780895604, 58.04341031659035, 57.00619836007395, 57.635597567404474, 60.59905805895406, 59.27093959623768, 58.650424557347456, 60.7497045301622, 65.61358082679011, 62.54427517614057, 56.40102763329783, 58.06142968516196, 39.15873942836639, 2.5617605111291333, 5.880804696390706, 4.684218504736501, 0.43115783843301964, 0.08051803185334129, 44.93592000776722, 77.3773337948707, 66.70630608835529, 59.72676607870287, 46.481102435819565, 36.967742673812374, 61.62183177086615, 74.59128210621496, 54.76155534867318, 1.287022442106278, 0.17554514080045686, 0.1655710590702872, 0.1518406643862686, 0.12154678228281199, 0.15816370896514387, 0.14826177739568297, 0.1851142071668179, 0.2216636491638999, 0.13241393101071158], [0.009471811504373628, 0.04064388700851029, 0.04698750104815249, 0.017409572159991633, 0.09509820956736804, 0.02193183514229473, 0.03863286407243821, 0.05421077171641012, 0.07830340189919358, 0.05745385555670627, 0.04073171515858943, 0.015261523864953028, 0.2420971906113048, 34.30854043652935, 53.278185552166356, 52.55175082914291, 29.80591835514192, 27.397175142841956, 36.3495732122852, 48.566563898517245, 50.7900849465401, 58.079590259059785, 19.590134659121116, 0.06130523236107923, 0.14296336009377433, 6.844069188640964, 5.529510849906552, 2.9089267984513314, 54.014649775720414, 52.67398757319297, 54.06560920899915, 40.244655455312426, 41.66364346781085, 44.43621004781416, 56.62014692060409, 53.26703033139629, 54.59396031595046, 53.22863424977949, 53.806681786814046, 49.93328240609939, 51.92017470636676, 46.328490857155096, 47.19948845524942, 43.31562811328519, 41.267421322484175, 36.09558405414705, 37.96612316562284, 36.00936643538937, 37.65792685170328, 36.54067893182078, 35.85181267030778, 36.361050067409394, 37.58928929605792, 35.29163937414847, 38.10356301646079, 35.80361066326019, 36.99859603758782, 36.70596368851201, 37.44192584868401, 35.88136772955618, 39.43050869049565, 36.453092405872965, 36.16652011871338, 37.40065859210107, 37.40792674403037, 36.0387606774607, 39.05713827379289, 39.58091981949345, 38.82766392923171, 38.73346036480319, 40.29320655330535, 38.81499075120495, 41.04818436407274, 39.932340652711936, 42.18104723961123, 40.52269266497704, 39.83831359494118, 38.58276682515299, 37.536066655189764, 38.03372913791288, 38.217315673828125, 36.85422928102555, 37.20709746883762, 37.22579932981922, 37.06633144809354, 39.675586223602295, 42.69264982592675, 50.75279497331189, 53.88650986456103, 54.365631303479596, 54.41603376019386, 51.290630371339866, 42.175924624166186, 40.586941088399584, 41.99628399264428, 41.999982787716775, 42.783315412459835, 42.662153397836995, 41.05751568271268, 37.74445433770457, 40.88366054719494, 40.84476240219609, 41.035067958216516, 38.416293590299546, 39.616876186863074, 38.13082348915839, 39.76961720374323, 38.64710154071931, 40.78569542977118, 38.4590317356971, 37.44600119129304, 37.42513418197632, 37.21528737775741, 36.99829009271438, 38.86396154280632, 37.90277296496976, 38.03354870888495, 37.02742545835434, 38.63476960889755, 38.772782125780665, 36.55190867762412, 37.576890683943226, 38.14199832177932, 38.26216013200822, 43.966851388254476, 49.65581394010975, 49.8272019047891, 48.57385558466758, 48.19460161270634, 52.29775382626442, 49.76448712810394, 50.655916352425855, 47.58120567567887, 49.76243180613364, 45.73711902864518, 43.27076012088407, 38.69784524363857, 45.58887697035267, 49.449057963586625, 53.758707277236454, 50.77480731471893, 46.996815666075676, 55.721798635298214, 54.97242196913689, 53.93888527347196, 54.66153098690895, 55.223524262828214, 54.815491860912694, 54.855472580079116, 57.47623558967345, 56.06263299142161, 37.928691987068426, 3.6538657930589493, 0.45213746267461014, 0.25196210481226444, 0.22965685734825753, 0.18001483482939584, 36.48642470759731, 68.13775154852098, 51.63248454370807, 48.21353097115794, 41.467258238023334, 29.654646265891294, 40.720403655882805, 59.54066530350716, 30.51160962350907, 0.4464129166256997, 0.04405666315447419, 0.12164768372331897, 0.00979266157599106, 0.07128618973036928, 0.16278614560442586, 0.025872262006986047, 0.04518427180066224, 0.08358981460332872, 0.0053292169092944075, 0.06202331721602429, 0.077253409451054, 0.006179100009537633, 0.033366859950605905, 0.052369448746885025, 0.028460645191972295, 0.017335186937763807, 0.052811236331059094, 0.07119717797444713, 0.05054256653473262, 0.038697870463253035, 0.05577977724193085, 0.40993677392121286, 39.42943396106843, 60.714736600076, 55.153815900125814, 35.80110819109025, 37.03256768565024, 41.81519992889897, 54.95139022027293, 55.22302219944616, 62.895021361689416, 21.002546818025653, 0.07488079684516115, 0.3674796295742835, 9.229117362729966, 1.4540730008194525, 4.087310495876497, 57.215460731137185, 56.755723645610196, 56.20096322028868, 43.22875545870873, 44.82656432736305, 46.348479255553215, 56.50528423247799, 55.42097637730261, 55.178432695327274, 53.99013103977327, 55.31793179050569, 52.57555177134853, 54.5964196420485, 49.04507737005911, 50.725463897951194, 46.69060014909314, 43.642679260623076, 39.065379173524924, 40.16700429301108, 38.939318118556855, 37.876226363643525, 37.26362666776104, 38.31892859551215, 37.75684118270874, 39.46619833669355, 36.82075577397501, 40.07447950301632, 38.573411972292014, 39.53409456437634, 38.7927822912893, 39.23348411437004, 39.18013595765637, 40.777234877309496, 37.58490800857544, 38.81362576638499, 40.374678104154526, 39.24809494326192, 38.239904603650494, 39.66826708086076, 39.63225187793855, 39.48576311911307, 39.980817225671586, 43.12213367031467, 41.42253537331858, 42.757749403676684, 39.47447453775714, 43.051519240102465, 40.97915457141015, 40.608780845519036, 40.915565106176565, 40.13515464721188, 38.55214880358788, 39.092161117061494, 39.91631384818785, 38.792072342288115, 40.2056396392084, 38.26445079618885, 41.04438358737577, 44.878708316433816, 52.44626652809882, 56.649274441503714, 55.54835927101874, 55.66263360361899, 51.94404625123548, 43.459837975040564, 43.4249641818385, 43.945105768019154, 44.80666614347889, 44.892150279014345, 44.17895747769264, 44.02042312006797, 40.488595501069106, 43.181145729557166, 43.40104949089789, 44.05526553430865, 40.8463470397457, 40.5144243086538, 40.58483869798722, 41.18431806564331, 40.4742004025367, 43.639333478866085, 40.74824071699574, 40.273731985399806, 39.5036099033971, 39.346260101564475, 39.512525450798776, 40.01001142686413, 39.91517243846771, 39.538114993802964, 39.03252932333177, 40.05504023644232, 39.70452939310382, 39.06442995994322, 39.42859849622173, 41.60909114345428, 40.52654835485643, 45.265987457767615, 52.66404828717632, 52.38775653223838, 51.57241736688922, 51.46047292217132, 52.637854699165594, 51.36045640514743, 51.95964551741078, 50.665455556684925, 50.85392544346472, 49.03230221040788, 46.01767047759026, 42.548302681215354, 46.03831391180716, 50.717046491561405, 56.917639086323405, 52.783900230161606, 49.09546413729268, 57.63516610668552, 55.51129679526053, 57.047877465524984, 55.190415536203695, 56.540075655906435, 56.38798183010471, 56.23702549165296, 58.77971764533751, 57.57971555955949, 39.89929468401017, 3.511092254231053, 0.6591516108282152, 1.0534837866021742, 0.10343630287435748, 0.15252551634705838, 40.72683242059524, 74.26283851746591, 56.017349227782226, 52.25609825503442, 45.74008041812528, 31.711788215944846, 47.362113844963815, 66.06058982110792, 38.25201296037243, 0.5299443859727152, 0.039855555721348336, 0.0372334742437928, 0.026126568723890572, 0.07115551045224552, 0.14023437104638548, 0.061699262024053646, 0.026440417709489985, 0.03328683440603557, 0.04081389724066661, 0.10131557997796806, 0.14150459079011796, 0.11885965994048504, 0.1319968880664918, 0.25125292189899956, 0.08719046615184316, 0.11210267251778035, 0.13709465161927287, 0.17927885416053957, 0.19825572538520062, 0.1727229954614755, 0.1528762160770355, 0.6319157142312296, 44.22886571576519, 68.52052780889696, 65.41105708768292, 41.74298124928629, 36.87954033574751, 49.316042546303045, 60.402912093747055, 59.03351852970739, 69.08494903195289, 25.134024427783107, 0.20689846887703867, 0.4812151265721168, 16.912913053266465, 10.722185219487837, 4.4152934512784405, 59.998876587037124, 57.96919122818978, 59.82987734579272, 45.256946394520426, 47.70912985647879, 49.69453165608068, 60.55724559291717, 56.111344906591604, 58.5436027280746, 55.962745912613414, 59.18556136469687, 54.30235170548963, 57.37959623336793, 52.74167591525663, 54.613870266945135, 49.21945418080976, 47.50765731257778, 40.691876257619555, 42.78838703709264, 39.918706493992964, 40.400942294828354, 40.15346034880608, 40.68327842220184, 39.74205863091254, 42.083164491961085, 38.19849221937118, 43.08115666912448, 40.34749607886038, 40.46611639761156, 39.56832508887015, 42.1391837827621, 42.15652065892374, 44.12945324374784, 39.85335980692218, 40.61556654591715, 41.96290462247787, 40.474533804001354, 40.43833817205122, 42.13173520180487, 41.14837738775438, 40.928030398584184, 41.39932278663882, 44.86805123667563, 43.219679094129994, 45.46392594614337, 42.616245977340206, 45.95525380103819, 45.163476313314135, 42.64429876881261, 43.23904775804089, 41.878181426755845, 41.239988265498994, 42.07385278517201, 42.47999068229429, 41.50204966145177, 42.761444276379, 39.41550562458654, 44.2279008127028, 46.5767768890627, 54.25365940217049, 59.19783446096606, 56.94551929350823, 58.06137869434973, 54.54527585737167, 46.84687522149856, 46.25725669245566, 47.7893070251711, 46.6937223557503, 47.213962001185266, 45.63794189883817, 45.37087948091569, 42.47395023222893, 45.24458700610746, 45.145633451400265, 46.087904437895745, 41.84670440612301, 43.06282743330925, 42.475738833027506, 41.93992737800845, 42.398923135572865, 45.38565897172498, 41.816937538885306, 41.403433430579405, 40.6326602351281, 40.63267592460879, 40.25377888833323, 42.78335071379139, 42.425269696020315, 41.90018592342254, 41.056229145296165, 42.57523367481847, 43.061682101218935, 40.69448463378414, 41.5341228823508, 43.27858524937784, 41.5784848889997, 47.41025701645882, 56.02481349822014, 54.21621645650556, 52.31087415449081, 54.23294536529049, 56.00103216786539, 54.090724145212484, 54.536603496920684, 52.33082332918721, 54.64588072992141, 50.38358226899178, 48.62776464031589, 43.58337302361765, 48.36164359123477, 53.412734616187315, 58.43054040785759, 56.4570822254304, 51.55226422894386, 59.60001860895465, 58.30970787232923, 57.326793286108206, 55.458227126829094, 56.31206043304936, 57.14484237855481, 57.48495109619633, 58.89689453186528, 59.5197473033782, 43.34749344856509, 4.726829173103456, 4.112842919365052, 4.454417132562207, 0.47780986574869005, 0.4510636219093877, 45.29690750183598, 81.49275518232777, 61.353474970786806, 62.719860076904304, 54.725916693287516, 41.034212881518954, 56.50457036110663, 74.82919739138696, 48.19260512628863, 1.1804483350246184, 0.126686412540655, 0.15803955675613496, 0.1507149288250554, 0.27460406324075115, 0.2774024904975968, 0.11222497079401247, 0.11063772854545426, 0.21709894491059167, 0.175953327768272], [0.016383360996241533, 0.09763257397759346, 0.055719853844493634, 0.040825714146898645, 0.03511095104078132, 0.043352980752505606, 0.038363132175178304, 0.02119842852886406, 0.06273750651387439, 0.06774891663583056, 0.0748260598629713, 0.12041648849844934, 0.044397196897696105, 21.510986012797204, 53.82192803967384, 46.095745255870206, 27.121930660740023, 21.206821895414784, 37.78556077711044, 47.507520029621745, 53.68133852558752, 57.87058284205776, 27.65215273826353, 0.05893110673153593, 0.5730115201684737, 4.186526604237096, 2.6335391498381093, 1.1360390147855206, 47.304294186253706, 53.832228183746345, 50.8375064019234, 43.16224382769677, 46.658672055890484, 52.31905229630009, 55.93465389743928, 50.94566575942501, 54.55909044511857, 53.33987659023654, 51.716242836367705, 47.65853520362608, 48.08516356252855, 45.05029239962178, 43.345936267606675, 37.19968418921194, 37.515580115779755, 35.59836872162358, 36.854103765180035, 36.41776754010108, 36.64204474418394, 35.98271393006848, 38.98163657034598, 37.10943045154695, 37.817014263522246, 36.26643857648296, 36.129316437628965, 36.89095835531912, 38.89010806237498, 38.88864109593053, 38.860054862114694, 35.77906054835166, 38.55567893674297, 36.112505159070416, 37.113250840094786, 38.18393630366172, 37.4455540410934, 36.43117420135006, 39.69156595968431, 39.43316413510231, 37.9683393047702, 38.600852874017534, 39.97651046322238, 38.5456298243615, 41.0312593367792, 38.48627651891401, 40.25455551762735, 39.24674172555247, 39.96713207614037, 39.112067145686, 37.80803595819781, 38.3239649188134, 38.86141984693466, 37.37331574962985, 36.7120433622791, 36.45635189548616, 39.29190781808669, 38.10399055480957, 43.3443751642781, 51.73533301199637, 55.262096851102775, 54.43875605060209, 54.19618491203555, 49.25898382740636, 42.14117634680964, 40.22896205225299, 42.64452626628261, 43.66963378844723, 43.15413236618043, 41.88591241836548, 39.66427410802534, 38.71677852446033, 39.085065549419774, 39.79238656259353, 39.557883739471436, 40.101512478243926, 39.83064928362447, 40.28706412161551, 39.922471969358384, 41.383158699158706, 40.26737382335048, 39.11300066978701, 38.98630026848086, 38.460165300676906, 38.65439714923982, 37.32461167920021, 36.42302743850216, 38.09298830647623, 37.07789459536153, 37.915340239001864, 37.54244050671978, 37.52846510179582, 37.952300733135594, 38.2086903818192, 37.59627895970499, 35.65597264997421, 42.65100602180728, 49.203756855380156, 51.76009885726437, 48.26696934238557, 48.543618033009196, 52.83819760045698, 51.695901424654075, 51.9217985676181, 48.33340252599409, 47.79322547297324, 44.01502986108103, 45.04633080574774, 39.31703452141055, 42.978759273406, 49.96994872247019, 57.97910305761523, 45.49086478448684, 45.77668789894351, 59.196061549648164, 53.620482952364036, 55.79190707975819, 53.686417994960664, 55.088257405065725, 54.6385851214009, 55.721320106137185, 59.28805681966967, 55.82427840079031, 42.56914615631104, 5.397522113015575, 0.21377560952978752, 1.0449218653863477, 0.08414441629523232, 0.14023383478483847, 33.967066734067856, 66.88777062200731, 53.379767094889, 46.101201272779896, 20.286045497463597, 27.787874590966013, 46.149230695539906, 60.819558020560976, 25.504341279306722, 0.09852754853425488, 0.03173190191568386, 0.08707569085902746, 0.14108549473026108, 0.07249783439141128, 0.02870935180615033, 0.06976741275960399, 0.028994568255579764, 0.07075991796990556, 0.03701027069661406, 0.06879664146371427, 0.0209763128265378, 0.048641071189194925, 0.03478925156917784, 0.012171778268361045, 0.052319021009269266, 0.0789460807197517, 0.03608815747523501, 0.12694787834921192, 0.12294201225402857, 0.055251862222869555, 0.05789133389630626, 0.026277959189047257, 27.476965958072295, 59.66594972918111, 53.97903857692596, 31.916382966503022, 21.67466259771778, 42.09551995800388, 52.72102855866956, 58.617551172933275, 62.89260910403345, 30.409735864208592, 0.06550340567745509, 0.6185173880188697, 6.106362064038554, 3.0773465095027803, 1.5943851297901523, 50.163698119501916, 57.26017575110159, 52.38127677671371, 44.00479247493129, 48.473611570173695, 55.151262437143636, 57.8575841073067, 52.03483735361407, 55.306368643237704, 54.51444602781727, 55.138746153923776, 49.53018434586064, 50.392666478310865, 48.08061753549884, 45.404086266794515, 40.50451247922836, 39.32611873072963, 36.88699283907491, 40.14513315693025, 38.37265329976236, 38.534368699596776, 38.03737694217313, 38.87511284120622, 38.77944231033325, 38.81759520499937, 37.84077205965596, 38.49951059587541, 38.52264081278155, 40.06133564056889, 39.21229547069919, 40.6938531321864, 37.92183960637739, 39.115440384034194, 37.7401005068133, 39.566975793530865, 39.85198697736187, 40.074059809407885, 39.39632915681408, 40.737391441099106, 40.30398914890905, 39.27229596722511, 41.34932041168213, 41.347021902761156, 40.94731277035129, 42.90965495571014, 40.84050270818895, 43.06926796513219, 42.06987550181728, 40.819812205529985, 41.668005143442464, 40.22912286943005, 41.42128413723361, 41.12591397377753, 40.166035467578524, 40.25849749965053, 39.417309914865804, 39.9443313383287, 39.25533171622984, 46.26222633546399, 54.40619645580169, 57.24809092860068, 56.66047673071585, 56.56783819198609, 51.491149779289, 44.53935661623555, 41.2191879364752, 45.91106045630671, 44.766175516190074, 45.34633721074751, 44.58568765271095, 41.509278589679354, 41.531475282484486, 41.720364862872714, 41.1197401631263, 40.966034243183756, 41.78801005886447, 39.63406009058799, 41.65667733838482, 42.2044441776891, 43.45214620713265, 41.23114724313059, 39.40973581806306, 39.5884507702243, 41.64549858339372, 39.010360087117846, 38.542676279621745, 39.0206955325219, 39.077895456744784, 39.83640340066726, 40.43576901958835, 38.67860601794335, 39.687031699765114, 39.67508808259041, 39.90043609373031, 40.78671132364581, 39.06897206460276, 44.09160629395516, 50.402829339427335, 52.63738401474492, 50.140057994473366, 49.230444662032596, 53.11059444181381, 52.23796121535763, 52.87560132242019, 49.97419272699664, 49.136099892277876, 45.16005992889405, 46.830189458785526, 42.51488800971739, 44.51591653208579, 52.05539841805735, 59.599724431191724, 48.775010416584635, 47.917996068154615, 59.45842104573404, 55.63516524530227, 58.43304288002753, 55.24388528639271, 54.784681643209154, 56.69882574389058, 57.14948646483883, 60.483426586274184, 58.90011872014692, 45.429063920051824, 5.918223617538329, 0.8764619500406328, 1.5717938710604946, 0.07338465011167912, 0.2069651951352435, 38.65822930489817, 72.22712055329355, 57.40248326332339, 52.94438400576192, 27.86739476265446, 33.139670202809, 51.53343685211674, 69.62698921080559, 31.442817564933534, 0.06377307352639976, 0.06919907511121805, 0.015347972099158554, 0.027203259336191322, 0.05192522883355137, 0.053168018799155, 0.028652251442714084, 0.07186902176228262, 0.041070544356179815, 0.01131059489242973, 0.2692953803606572, 0.13432525909475743, 0.11192842581940275, 0.11886178966491454, 0.2281043342044277, 0.1308480472934823, 0.168200088965316, 0.13060919640045013, 0.16567513977567996, 0.17676518178514897, 0.2674059011042118, 0.09009332651452673, 0.07124092159492355, 30.59225355425189, 67.96083696426885, 59.70849567844022, 37.78258762051983, 30.981499764227102, 50.90733635810114, 58.81989448301254, 63.77452265831732, 68.05769597330402, 33.869207520638746, 0.19873935669179887, 1.242495941058282, 13.41719183229631, 3.865498746595075, 2.02423976073342, 54.35327191506663, 59.28626429650092, 55.884690746184326, 46.152670614181034, 52.301507534519324, 57.08091951185658, 58.56375194364979, 53.59937275609663, 59.79382684153896, 57.53892683213758, 57.26456096095424, 52.404250098812966, 53.896896300777314, 50.549569129943855, 48.968861795240834, 42.21563862216088, 41.89629100984143, 39.41073994482718, 41.757035101613695, 41.271582957237, 40.5059951351535, 39.404813243496804, 43.1583724483367, 41.11840263489754, 41.01457357406616, 39.626129058099565, 40.59514668680007, 41.029580562345444, 43.42177921725858, 42.63727772620417, 43.20933972635577, 40.55238108481131, 42.13400233176447, 39.623504992454286, 42.817059563052275, 42.473303041150494, 40.89038741204047, 39.94440586336198, 43.50452161604359, 41.72546002172655, 41.3694304035556, 42.51884568122126, 43.00321917380057, 41.60964419764858, 45.796539014385594, 41.62350585383754, 43.93501743193596, 43.834922467508626, 43.01914791907034, 44.62463286615188, 42.33492966621153, 44.10576212790705, 43.492413259321644, 43.060932928516024, 42.9987084481024, 41.880264205317346, 43.367556371996486, 42.071652335505334, 48.334151698697, 57.259493258691606, 59.794266146998254, 57.44398978448684, 57.546689202708585, 55.307113893570445, 46.4327278444844, 44.384925057811124, 46.5885361548393, 47.623241716815585, 48.451913018380445, 46.448491850206935, 43.8048888790992, 42.81660849048246, 43.27734578040339, 42.975393879798155, 42.87615791443856, 44.17914575146091, 42.90395182947959, 43.45656671831685, 44.12126725719821, 45.71727968031361, 44.399508430111794, 43.10380443449944, 42.78543349235289, 43.8923930352734, 42.26444075184484, 41.221392308512044, 40.160971687686065, 42.26066743173907, 41.33155207480154, 43.64698994544245, 41.51021995852071, 42.13781879794213, 40.629279152039565, 42.64572651155534, 42.43421662238337, 40.59810807628017, 45.718001396425315, 53.736514506801484, 56.29362921560965, 52.10398089501166, 52.01721806680003, 55.89636371981714, 55.45106487889444, 55.90984490609939, 53.827591942202666, 52.8108076895437, 46.75799431339387, 50.26439712893579, 45.25633058240337, 47.97104220236502, 55.4997964059153, 62.12635840139082, 50.7808046187124, 48.014066680785156, 61.43690770672214, 57.815316646329826, 60.458197901325846, 57.555847937060946, 57.15458946843302, 55.838591129549094, 58.00880324456, 63.149073277750325, 60.25021814530896, 47.70354440135341, 7.097696017834449, 4.620573145727958, 4.491842917857632, 0.3330448966833853, 0.281355596117435, 42.29404287953531, 77.36417816531274, 63.96387900075605, 60.93000804224322, 31.966952123949607, 41.17759512316796, 60.70836667091616, 78.07992442961663, 39.46730836745232, 0.2644087506398078, 0.08615306818917876, 0.23447732771596602, 0.14070001460852163, 0.18986657231805787, 0.18880275198288504, 0.14507400893395947, 0.10938135201051351, 0.21355732043664302, 0.07516169064347783], [0.020643752143387834, 0.05885048363838465, 0.01945238582970154, 0.08682994517467676, 0.01883385601573654, 0.03453774490363656, 0.07415794692332707, 0.05869361564456936, 0.04841610947022996, 0.05691101714487999, 0.014773727912876396, 0.027798793105889234, 0.0657595165314213, 8.761573779967524, 51.28513120835828, 44.91506476556101, 42.103560816857126, 37.19063528122441, 35.419206619262695, 42.06512158916843, 53.58874313292965, 54.931939186588416, 40.331300612418886, 0.8799108165887095, 0.8866704087103567, 6.7658590885900685, 5.6195988674317645, 0.551044040870282, 37.6885840969701, 58.72092916119484, 48.66503892406341, 44.61733333526119, 50.64995434976394, 56.17599733414189, 53.565699208167295, 55.25012969970704, 52.91635867088072, 50.769978877036806, 49.23699894259053, 46.14901104281026, 43.40085729475945, 38.700277113145404, 37.590634669027025, 35.85125961611348, 36.49024509614514, 36.66174288718931, 35.963247206903276, 36.650701415154245, 34.81637362510928, 37.57455295132053, 35.803865617321385, 36.803662084764056, 36.22977226011215, 36.855080435352946, 38.9513127265438, 35.92044630358296, 37.49460720246838, 36.935257604045255, 38.308934396313084, 37.62019757301577, 37.48989251352126, 35.35772738918182, 37.545990251725726, 40.50034299973519, 39.502939178097634, 38.41574445847542, 38.262921071821644, 38.03492153844526, 38.752621143094956, 39.970693588256836, 41.678552396835826, 38.75790849808724, 40.38941444889192, 38.64684266428794, 39.818991999472345, 37.20808590612104, 38.589442699186264, 37.4362031106026, 38.572949132611676, 39.494839483691806, 37.30730618199995, 38.45010049881474, 37.82592588855375, 35.82829806112474, 38.43938458350397, 37.389907375458755, 42.55096989293253, 53.82392452609155, 55.12566897176928, 53.959556164280066, 53.61904736488096, 51.01209109829318, 40.9597937522396, 41.68666385835217, 42.348410852493785, 39.632169508164935, 42.80530421964584, 41.03184376993487, 40.46122520200668, 37.60175458846554, 38.546598649794056, 40.42577482038929, 39.231519006913715, 39.71513548204976, 39.29639893193399, 39.05078011174356, 40.30667205010691, 41.09132259122787, 38.97184633439587, 38.617515102509536, 38.97008126781833, 38.1279876155238, 38.558989417168405, 37.95781558559787, 36.174015768112675, 38.805604519382605, 38.7464237982227, 37.32218765443371, 38.854649836017245, 37.27416607641405, 37.73657429602839, 37.55359180511967, 38.091682157208844, 36.20817568994338, 39.053988610544515, 47.25451146402667, 51.05017731266638, 51.101846694946296, 45.905412243258574, 50.172986292069965, 52.32452792506064, 49.94357078306137, 48.341094293902, 47.04940288297592, 44.421846328243134, 42.7115438830468, 41.14702024767476, 41.73423044143185, 51.316235603824744, 54.18257820990778, 55.10525695739254, 47.74018326113301, 52.73144637384723, 55.34130519436252, 54.19375304252871, 55.29546053178849, 52.98043451001568, 54.60810046042166, 57.8982473188831, 57.827534829416585, 56.431469148205174, 42.67715254137593, 6.617169880097912, 0.1492718183585713, 0.3810804481467893, 0.02794687215599322, 0.2606791894762747, 35.41691987745224, 63.7343732772335, 53.60936695529569, 42.74378576586324, 29.453303160205966, 36.394617711344075, 43.881861471360736, 57.35978826399773, 22.628798753984515, 0.10835746017795418, 0.009253680416863532, 0.0580673617491078, 0.036310698356359236, 0.04366958573941262, 0.14025431997593374, 0.01320448011204961, 0.06713731800236049, 0.07509940003435459, 0.04868987482041121, 0.0654719271246464, 0.04778812804649915, 0.046628424146723364, 0.10733847130811024, 0.02711538522083673, 0.035459605316000606, 0.02911815738996431, 0.06956891937842292, 0.09743415720520482, 0.026738335896703987, 0.020561794142028498, 0.0538040173330134, 0.08168532002356746, 12.10173870286634, 60.71261852018295, 50.60197591781617, 42.78733584188646, 37.0165918719384, 45.70459865754651, 47.6273915844579, 58.88884975064186, 60.015009295555856, 44.42206598097279, 0.4223207077912746, 0.04318465208334308, 4.964947440931875, 4.04403988872805, 1.5914706861780537, 42.448839218385764, 62.27876209443616, 50.24183565570463, 49.56434819006151, 52.606365911422245, 58.508783848054954, 55.52158517222251, 56.36651077578145, 55.12197802143713, 53.28662257040701, 50.92042138499599, 49.23594774738435, 46.71468350195116, 40.96770517287716, 40.055142218066806, 37.13091327298073, 38.33575164118121, 38.14190418489518, 37.64663042560701, 37.11491784741802, 37.81084437524119, 38.81091148622575, 38.17768796797722, 39.07165104343046, 37.76692559642177, 39.04524172506025, 40.8334542089893, 37.07271706673407, 38.83861126438264, 38.82175291738203, 40.666969207025346, 41.65176653092907, 40.98355547074349, 36.660503418214866, 38.684195395438906, 41.46921550073932, 39.71781053850728, 39.586191485005045, 40.0524083260567, 39.83041001904396, 40.37781207792221, 42.21332834612939, 42.27197954731603, 40.45125845939883, 41.76300494901596, 39.4415383954202, 41.96426176255749, 39.81301430732974, 40.93810696755686, 39.889414233546105, 41.53082024666571, 41.08704328536987, 39.554028049592056, 39.7213916624746, 39.84982182902675, 38.25805733280797, 39.73089164303195, 40.708758138841205, 43.37010983497866, 54.664923837108, 56.706607726312455, 54.91237048179873, 56.54482172381494, 52.4273685486086, 43.22909278254355, 41.75041414076283, 44.22859114985312, 42.132194119115034, 44.477340021441066, 43.19346589426841, 41.54195977795509, 40.274375254108065, 39.946892646051225, 40.90255852668516, 40.463657071513516, 40.656649451101984, 40.30909999724358, 39.11231033263668, 42.675203123400294, 42.92651722508092, 41.864002058582926, 40.30940201974685, 40.0901532942249, 39.5045316603876, 40.8808050617095, 40.710079977589274, 39.1831208813575, 40.68976994483702, 41.29467395044143, 38.28775751975275, 41.05584475301927, 38.557867619299124, 38.59602443633541, 39.51512205985285, 39.83410489174628, 38.129705613659276, 41.69596772040091, 49.924104059896166, 53.10398524807346, 52.62074924284413, 48.51230182955342, 51.485227000328806, 53.42140697663831, 53.33104733497866, 50.310492823200846, 48.41313646685693, 47.69587616766653, 45.57839639725224, 41.87390212089785, 43.18261661837178, 53.633893535983184, 55.75903761771418, 56.789416805390395, 49.59433863239904, 54.436214354730424, 56.58563790782806, 56.2171273077688, 56.49543908334548, 53.89964588226811, 57.52347661602882, 58.301906278056485, 60.4484429667073, 58.790088392073116, 44.937222234664425, 7.520168625539349, 0.33992574520168767, 1.0631862595196695, 0.0669162173665339, 0.33584464161146077, 38.671216272538715, 68.75712517769107, 56.79464924720026, 49.34077701260967, 30.412824730719294, 38.15258479887439, 52.39074145593951, 65.20385788333031, 28.791817003680816, 0.017430457632027326, 0.03149377689095995, 0.011974547017035226, 0.0345011527139333, 0.00749788110918035, 0.07458996688646656, 0.02363593261238308, 0.08326275634669489, 0.09510392458328316, 0.05324249403671392, 0.09169097223709669, 0.09678924140790779, 0.15597295797159597, 0.3204495531897391, 0.1619432956701325, 0.08297663016785538, 0.13111513618740345, 0.1555141172702274, 0.20367185975755417, 0.16918011460333102, 0.1019893849508897, 0.15632217149099997, 0.18774060171938714, 14.656380357280856, 68.00736411925286, 58.00942297904723, 56.396877765655525, 47.373947635773696, 48.77577135639806, 53.41907316638578, 66.03414520140618, 66.39350491185343, 49.0714317752469, 1.0638385987089527, 1.657978762542048, 12.839392385175152, 8.524253714469172, 2.494026081215951, 45.04886857924923, 65.18950985323998, 52.19512893307594, 49.8835781312758, 54.59816901914535, 59.961100239907545, 58.556632841787035, 58.56769784804314, 56.26611378885085, 55.938109505561094, 54.27565997646701, 51.378295344691125, 48.26839316275812, 43.1164187769736, 42.87369074360017, 39.75248036846038, 41.07233439722369, 40.986952243312714, 40.15907718289284, 40.91285082601732, 40.59320511356477, 42.161768790214296, 39.42802583017657, 41.40097802685153, 40.19312727835871, 40.4985426318261, 44.37963770281884, 38.78352157531246, 40.499656584955034, 41.03514640561996, 42.500751787616366, 43.41536221965667, 43.6201060202814, 38.24140294905632, 41.49124745399722, 45.30544257933094, 43.266790682269686, 41.89631846643264, 42.296055055433705, 41.34897524310697, 42.23172033986738, 43.80334346525131, 46.48075726724441, 41.35331338451755, 42.57982677029025, 41.59257796502883, 43.48106192004296, 41.15819508029569, 42.42392432305121, 41.70786426913354, 42.730896857477006, 43.63298316155711, 42.14250210792788, 43.59486164585237, 42.31037562893283, 41.29866300090667, 42.38985461573447, 42.52523914460213, 44.98193725462883, 58.20471386755667, 57.36191026626095, 57.04786962078464, 59.611919080057454, 54.94107830908991, 45.82938494220857, 45.327031304759366, 48.356603345563336, 43.49686122709706, 46.866938144929954, 46.26244598819364, 46.1461712468055, 42.065784469727554, 42.867230599926366, 43.20098900025891, 42.76423308157152, 43.23811815631005, 42.3080849647522, 41.88806187721991, 44.98886023798297, 46.218652725219734, 44.21864009672596, 42.021234189310384, 42.081756361069225, 41.14572978788807, 43.136238513454316, 43.956649303436286, 40.04617960222306, 43.63913736035747, 44.46857744647611, 40.10128105840376, 43.421665468523585, 41.30597429890787, 40.3490375703381, 41.31659999970467, 42.96370913905483, 39.932289661899695, 43.64401286648166, 52.51329591197353, 55.36437265334591, 54.41561014421525, 51.38229616226689, 52.39646811639109, 54.8035757003292, 54.56155761595696, 52.67258728704145, 51.64806812040268, 49.709240544226866, 47.850586214373195, 45.95022532247728, 47.13109408655475, 56.56964248226535, 59.061135938090665, 57.493576388205256, 50.357863287771906, 55.60557096235214, 55.620071964879195, 58.86926143400131, 58.392932722645426, 55.14657912715789, 55.70562278070758, 60.211174872613725, 61.10383964353993, 59.93895453791465, 45.82549787336781, 9.681157777386328, 0.9851599592835674, 1.8934278574682053, 0.2665380460600699, 0.7191114127635957, 42.77285445121027, 75.69265227163993, 65.39518717796572, 56.98710426207512, 43.609437173412694, 49.773920428368356, 59.9447282668083, 74.78754966489731, 37.36891877266669, 0.3046135658458356, 0.1335974602449325, 0.210229603032912, 0.17429036538927786, 0.11555042057748764, 0.17498595790276605, 0.12137552332733909, 0.22180618748309153, 0.1614696081847914, 0.1583280807901775], [0.041233158009427215, 0.04112717740598225, 0.0587989297515202, 0.060513603065403244, 0.024455863111201796, 0.037762182163855726, 0.045385967429366805, 0.089462997031308, 0.040047353494071194, 0.05043518782082585, 0.04066848226131932, 0.020276656216611306, 0.12142985428292906, 4.814853533621758, 46.533191511707926, 49.40925375107796, 40.53453822289744, 19.317431872890843, 31.40296236161263, 40.060598234976496, 53.842465569896085, 53.97217050675423, 46.610940733263575, 1.181976711077075, 0.2885718072854704, 2.7268261053869804, 7.445852948773292, 0.6059988371787534, 28.4949347665233, 60.00512492272162, 49.132895315847094, 52.43574673129667, 55.72788223143547, 55.24748994458107, 50.734375522982695, 52.63297527067123, 47.54397061563308, 47.459153283026914, 41.262110433270855, 40.06394009436331, 36.4476324665931, 37.675499070075254, 37.04237361108103, 36.40124259456512, 35.760221404414025, 35.755404733842425, 35.11752928456953, 37.610599533204116, 37.64492811695222, 36.931205795657256, 36.867777147600734, 38.02817898411905, 37.429899861735684, 37.22055119852866, 36.08049861846432, 37.74564281586678, 38.34767956887522, 37.81423330307007, 36.24396339539559, 38.04146797426286, 36.33932405902494, 37.40648331180696, 36.7449128243231, 38.35752471800774, 38.84674626012003, 37.035697737047755, 38.849676270638746, 38.5877953037139, 39.711024838109175, 38.34540459417528, 41.48519523682133, 37.86589484060965, 39.091623752347886, 39.17341301518102, 39.071921686972345, 38.18371665093207, 38.96083231895201, 39.34131791514736, 38.20406198501587, 38.705462486513206, 38.78527879714966, 37.196844393207186, 35.61885133866341, 35.84386594833867, 37.22962364073723, 37.145343672844675, 42.27190502228276, 53.716310378043886, 55.05151656366164, 53.64197361853815, 54.55301469372165, 51.11901490919052, 40.639190981465006, 39.31737968998571, 39.173063924235684, 40.7337083355073, 42.10822451499201, 41.87342359173683, 38.053866586377545, 39.47370967557354, 38.76448239049604, 40.10483864815005, 38.47849061412197, 40.95287469125564, 38.793213752008256, 39.97437277147847, 40.45421592650875, 40.52792510678692, 39.74680469882104, 39.204207543403875, 37.95894130583733, 39.191228420503684, 38.4554898354315, 37.61509064705142, 36.30768229884487, 39.609886523216005, 38.97129328020158, 38.72198743204917, 38.43881976219916, 38.35138620868806, 37.651533388322406, 38.900533722293, 36.75142003643897, 37.97475238000193, 37.98375814191757, 45.9140649918587, 51.70088675714309, 50.35254847618842, 47.18747815778179, 46.83222124653478, 47.77160144621327, 51.8351730223625, 51.681372965535815, 49.88657089971727, 44.65285431954169, 42.345778942108154, 39.580770769426906, 37.697480032520915, 47.44800198462702, 52.0763046510758, 55.21764855231009, 58.24530647646997, 52.27329000349968, 54.890577793121345, 55.27596242966191, 57.337862214734486, 59.027866394289084, 60.177905328812145, 58.2701390020309, 60.15602634799097, 58.69704192684543, 38.774527580507346, 3.909333439603929, 0.17044313312057527, 0.6200813718380467, 0.11568140629078112, 0.4044633208503647, 39.663638684057425, 65.53837722347629, 49.75496753569573, 44.19641202495944, 26.909997155589444, 33.00845907580468, 42.80637110433271, 58.28058819616995, 18.960735451790597, 0.0696238938478693, 0.03576144395816711, 0.02313960531365968, 0.03705447396984504, 0.053373977707158175, 0.012150029032190722, 0.0805793112264045, 0.02800569238681947, 0.08833725380921557, 0.07031892711717276, 0.010411573476308297, 0.027952096875636812, 0.024252200551751642, 0.09207113570864163, 0.00832078833838985, 0.025215937245276668, 0.05490577817263623, 0.0798130777454184, 0.04071002720945305, 0.028052272447835536, 0.05593170779907415, 0.03586048763545771, 0.06016603663503643, 5.900743574865404, 55.042169555541015, 56.086151522974816, 48.42023595686882, 25.80867994216181, 38.012003129528416, 45.52973939526466, 59.82345642582063, 58.87550192494547, 50.400067990826024, 1.124181812328677, 0.6219005548665602, 2.0139008832554666, 8.608606246209915, 0.8879958633934298, 33.90672891370712, 63.18529636629167, 51.18415763301235, 53.41381719035488, 59.43565560925392, 55.42325919674289, 53.62149100149832, 54.714008377444365, 51.08549041132773, 49.371610764534246, 44.67360758012341, 42.49720596498059, 38.5832610437947, 39.16410523076212, 38.435834838498025, 38.5881483170294, 37.82469818668981, 38.50304857377083, 37.88619310625138, 39.509532682357296, 37.35427656481343, 38.96257385130852, 38.85500284933275, 39.72178782186201, 39.05748736473822, 39.430944073584776, 39.597087829343735, 40.262588531740256, 39.694017441042014, 38.87852138088596, 39.09990779815182, 38.78871479342061, 38.25285626995949, 37.67777796714537, 39.67817498791603, 40.44594364781534, 39.46537856132754, 39.91295629932035, 39.091659053679436, 40.742298326184674, 40.789358923512125, 41.38038950581705, 43.841641487613806, 41.155496489617136, 40.464547449542636, 41.11069125513877, 40.72149015242054, 39.90350730957524, 41.695085187112134, 42.15049589833906, 40.652032821409165, 40.28129039272186, 41.12040304368542, 38.99485495782668, 38.23099690098917, 38.53450990492298, 38.98477054411365, 39.150329866716945, 44.21287421257266, 55.00389114502938, 57.67315033943423, 55.337139637239524, 55.83177012781943, 53.727332238228094, 43.062929414933734, 40.644847039253484, 41.81915760040283, 43.86104545285625, 46.5291710822813, 43.871023962574625, 40.400918760607325, 39.25415500517815, 40.13491538263137, 42.19620327795706, 41.15054645845967, 42.834372904992875, 39.67773176008655, 42.97085961987896, 41.75460323210686, 42.68514633178712, 40.54614059386715, 40.093334336434644, 41.083309188965835, 41.31259525975874, 38.78391381232969, 38.74241905827677, 39.35051195083126, 40.71854053005096, 40.92755579179333, 39.82596989600889, 39.91666686150336, 39.788950566322576, 39.82496184687461, 38.17003542377103, 38.72139907652332, 39.23663377761841, 39.683929104958814, 47.584037626943285, 54.100455545610004, 52.946098081527225, 48.606870174407966, 47.623959510557114, 47.98849674963182, 54.74711318169871, 52.313455074064194, 51.936974217814786, 48.43910647976784, 44.56116107202346, 42.202683033481726, 39.498891292079804, 49.61387595822735, 55.29769628278671, 57.9489557204708, 60.973699323592655, 54.153795857583326, 56.88474216768819, 57.43569789394256, 58.73774043975338, 59.46061365066036, 62.54486353166642, 58.69389618596723, 63.260088120737386, 60.25361884024836, 42.664145961884536, 5.009148630403704, 0.2997473447072891, 1.2693041154453832, 0.19555471386880646, 0.47558925264785373, 42.87281605505174, 71.24105238145398, 55.43773666504891, 48.770287882897165, 30.57954115252341, 39.24362736363565, 48.67423688211749, 64.95819199469783, 25.264592286079164, 0.08469238366571166, 0.0077498498215009615, 0.03208669830083607, 0.014374536732512136, 0.05107092205435038, 0.04761915586348023, 0.056386407795211965, 0.06987252768369452, 0.03722209783811723, 0.050568249632394126, 0.0911392203922714, 0.09386636316776277, 0.11351946020318616, 0.23442451361446615, 0.10874435756235354, 0.09394375336987358, 0.1058333077197594, 0.14519477503434305, 0.16391505276964558, 0.14583139409942014, 0.14289071963679406, 0.15825914819875073, 0.1887959797656344, 6.9423907514541385, 63.26184142020441, 64.0163524689213, 54.27471076288531, 28.926723003387455, 44.053037628050774, 50.90849737967215, 64.98067502052554, 64.84977376076483, 57.37397155454082, 1.8261687697902804, 1.2043539554842058, 8.65949115445537, 9.9588547214385, 2.192033240872045, 37.36016404244208, 68.67361007198211, 51.97376212766094, 58.50247667681787, 61.54714984278525, 60.02794527238416, 55.09825552663496, 57.35611300314627, 52.70722573803317, 53.435786385690015, 45.12571173329508, 44.546656147126235, 39.7898684009429, 41.8408679193066, 41.228166241799634, 40.44195851972027, 39.69330356967065, 39.502915643876605, 40.700172070534, 42.067278892763206, 40.78569935214135, 40.72189807891846, 41.11158947790823, 43.21545077908424, 40.92202524985037, 41.305613440852014, 40.53406361610659, 42.18030591164866, 42.97702166341966, 41.99804513685165, 40.51287105006557, 40.542688908115515, 39.48017766398769, 40.02443005961757, 41.27261846296249, 42.0441133745255, 42.86799938448014, 41.68544400122858, 42.33318421148485, 42.57021696336808, 42.89701707901494, 41.36620229290378, 46.386934172722604, 43.52314110725157, 43.09342976539366, 43.25343501183295, 43.69664715182397, 42.81083476158881, 43.685342880987356, 46.422537526776715, 42.62786403779061, 43.78663809068742, 43.92261881982127, 42.56250166123913, 41.13090715100689, 40.63592364711147, 41.723267416800226, 42.19925880432129, 47.338493331786125, 57.6905107498169, 59.68507520614132, 57.126442540076475, 58.16986360857564, 56.84107049818962, 44.31604431521508, 44.51298652156707, 43.7632489973499, 45.10144010666878, 48.35426561294064, 47.87510887269051, 42.347755816675004, 43.029573578988355, 42.442155499612134, 45.394280341363725, 42.383625891900834, 44.717663641898866, 43.54324325438469, 44.13643506265456, 43.97131504551057, 44.19437239246984, 43.803029675637525, 43.354655696499734, 42.25141848287275, 44.483757019042976, 42.1540887894169, 40.6735784007657, 39.54123720046013, 43.561333225619414, 45.41029930114747, 41.37024233418126, 42.41301228923183, 42.662773132324226, 42.341636919206195, 42.61304140090943, 40.35046139071065, 42.071397381444136, 42.5683303033152, 49.13733936125233, 57.056463533832186, 54.168951895929155, 48.09373394135506, 47.638433056492964, 50.01085119862711, 56.820882058912716, 55.995654598359145, 54.91548876608572, 51.202934019027225, 46.02934345122307, 45.63423525902533, 41.263785285334436, 52.62064333884947, 57.575444098441835, 60.26249516394831, 59.268848972935835, 56.96753555728544, 58.99876632998067, 59.062685274308734, 60.6495624972928, 62.02811479568482, 64.60400981287803, 62.8952645486401, 65.73900645779025, 63.76935297443021, 44.66590404510499, 6.372683153998468, 0.8920476717814323, 3.1177736434244343, 0.29261892721537625, 0.5253891658879096, 47.085920149280184, 76.56214760195824, 60.735980156929266, 58.383291536761874, 39.65253837646977, 45.07571720307873, 55.65782477778774, 74.82115653253372, 31.883335036616174, 0.3567993833172706, 0.13897666917933574, 0.1545954859184642, 0.09627821479713726, 0.09975502823269176, 0.1301242474226221, 0.20205437235774534, 0.2062398937320517, 0.19026616377936256, 0.2658019887824213], [0.0406423663239806, 0.022156951994064356, 0.11935416969560808, 0.03940851277401371, 0.06692718008473035, 0.04495589332955499, 0.0533901076884039, 0.035781764440358646, 0.021508209587585543, 0.0811053301778532, 0.04558229278172216, 0.03977179166770751, 0.05907695838100007, 1.4156460305375438, 41.830218684288766, 52.13533632216915, 36.22404559966057, 20.924152366576656, 34.28238607222034, 37.132917604138775, 50.53724504286244, 51.35326670062158, 56.48716288228189, 4.658473047517962, 0.09347167466917346, 2.4754516972649485, 1.6669888145500615, 1.3452554205732963, 13.520274662202405, 59.93422023711666, 50.71646990314607, 56.26339166395126, 52.718329967991004, 53.78075099760487, 48.62203797986431, 50.6356926118174, 43.613767470082934, 39.79119416206114, 35.52932716185047, 38.44693122371551, 36.51886663129253, 38.744113522191206, 35.13600757045131, 38.29451968592983, 37.91939204738986, 41.20978601517216, 39.69552363118818, 40.182972261982584, 39.15155364621071, 41.33557642659834, 41.169993569774014, 41.73621516073904, 40.47711080120456, 42.614284792254054, 39.1829796760313, 41.285005307966664, 38.03714944470314, 38.407699677252005, 37.5681947892712, 39.02716744330622, 35.955033763762444, 37.857791223833644, 36.90258033813969, 36.96907235730079, 37.9134928026507, 38.68306967519945, 37.56701807821951, 39.3878686043524, 38.35634800695604, 39.02764597246724, 40.5973236022457, 39.85886289227394, 37.45654452231623, 39.44759061259609, 40.260843077013575, 38.900416051187825, 39.82228286804692, 37.818124294281006, 37.685014740113296, 39.42163628916587, 38.565033789603945, 38.038177105688284, 37.34206230409684, 36.28930207221739, 36.01708565988849, 37.301893311162154, 42.76574711645804, 53.87600575723956, 53.984659333382886, 54.079380650674146, 53.840967224490264, 50.56831805936752, 40.654672576535134, 41.22224738520961, 40.534918692804155, 43.612590759031235, 42.998375046637754, 41.52841191137991, 39.31177462300947, 36.707752289310584, 37.283062011964866, 39.16108500572943, 39.9577772232794, 40.4149490787137, 41.33669430209745, 40.46775987071376, 41.67442998578472, 40.10772551259687, 40.925994688464755, 40.78651128276702, 37.75698238803495, 39.546226455319314, 39.105528554608746, 38.88915492642311, 39.3437340951735, 39.06195102199432, 36.815876345480646, 39.18604696950605, 39.01809107872748, 38.090803546290246, 38.0640176803835, 37.85801872130364, 37.220347235279704, 37.77188739468975, 36.11896530274422, 42.949918085528964, 49.203082207710516, 51.57300572241507, 40.948740513094016, 45.09347377284881, 47.91616039891397, 49.289048794777166, 53.874001426081506, 51.92312432873634, 48.731060258803836, 43.559019027217744, 42.55230742116129, 39.85468556804042, 39.295096705036784, 49.02962323158018, 47.49390156038346, 52.34009188990439, 54.378355472318596, 55.209717519821666, 52.482764182552216, 55.31433105468751, 54.107264780229144, 58.36688426233108, 56.32621626700125, 59.52541120590703, 57.56723850004135, 34.68033798279301, 1.6667937992080566, 0.14586205293814983, 0.21224642142413125, 0.19595409082549234, 0.5826141565076767, 41.38805773950393, 62.976069296559984, 47.00464863930979, 36.540023896002005, 33.135296760066865, 35.86151661411409, 42.75060284522272, 55.275381918876406, 9.030183572922985, 0.2644895882375779, 0.10122914993835073, 0.0036365171517020157, 0.014549760192993188, 0.029738772878303166, 0.017778464562950597, 0.07598015599914136, 0.04297282877227953, 0.0348769954495853, 0.008651026817519338, 0.06497970797241696, 0.008536136611514996, 0.0892596849570832, 0.030492197369195284, 0.11860058432625187, 0.031738243208477096, 0.08152526127354753, 0.06700981798912249, 0.001958628866216919, 0.061975911695269816, 0.018900317973607493, 0.019675227400336056, 0.1163327036004874, 1.8708363535904118, 49.18601597509077, 58.012411825118534, 41.77672539987872, 23.400330928064164, 39.04299812932169, 41.46839180300313, 55.80725531424246, 55.61310583545316, 60.43806045286117, 4.904016852378845, 0.3631408446498456, 1.029736654412362, 4.892077157574316, 1.701784160348677, 17.93124075858824, 64.26342648844566, 53.74357477311165, 57.67256198390838, 55.28897685389365, 56.98440959376674, 51.57009924611738, 54.15607083228327, 46.70378715761247, 43.90703132075649, 38.86154536278018, 39.80478909707839, 38.586124374020486, 41.53896700951361, 37.362007556423066, 39.11944512398013, 39.82398125433153, 42.81929139168032, 42.593103993323545, 41.974648198773785, 41.204200560046786, 41.50514048914756, 43.48475287037511, 43.767802869119954, 41.68963309257261, 43.632147696710405, 41.88486906789964, 41.41942885614211, 39.31531652327507, 39.40367183377666, 40.1638703192434, 40.008132611551595, 38.35331993718302, 38.39394000268752, 38.58342186097176, 40.213013695132354, 37.11684373117263, 40.750994220856704, 38.524170537148755, 40.25788953227382, 40.664156867611794, 40.23333157262495, 42.17164531830819, 41.11790841625583, 38.82966826038976, 41.24941372102307, 40.9870542249372, 40.242568754380756, 41.062771658743586, 40.38125199656333, 39.11421660454043, 40.690679934717, 41.47109823842203, 39.204937104255926, 38.945731193788596, 37.54971258101925, 37.810871831832394, 39.342984922470585, 44.46137597483974, 55.13567101570868, 55.1354552853492, 55.308596549495576, 56.295115793904955, 52.66877082086379, 42.66264761647871, 44.05919574922131, 44.967310736256266, 44.946847731067294, 44.99662653092415, 44.12524846292312, 40.14237180832894, 39.42094202964537, 39.42529978290681, 41.714340102288034, 40.75164141193513, 41.48816839341195, 42.36887778005293, 40.80635847583894, 42.53408801171088, 41.88067605418544, 42.64834273246027, 42.04451345628308, 40.72461628144787, 41.380201232048776, 40.114048373314645, 40.685835807554184, 40.877200403521144, 41.17176255872173, 39.28806389531782, 39.58000982961347, 39.30505168053412, 39.26089755950436, 40.00279426574707, 39.98502200649631, 39.16343058309248, 40.040652982650265, 38.66687813112813, 45.13726311345255, 51.234830733268495, 54.158004560778224, 43.39584450567923, 44.1275312823634, 46.77261690939627, 49.65957941547517, 56.17453036769744, 52.60353003778766, 51.07030299402053, 45.87941085138629, 44.38146944968931, 41.16042690892374, 42.02958883777742, 50.42918374461513, 49.16547844486852, 53.0303466704584, 57.327652285175944, 56.33281369363108, 56.91213207860147, 58.84275013400663, 56.54450793420115, 60.70919036865235, 60.36496708470007, 62.45641800665087, 59.645365130516794, 36.096815678381155, 2.2373572088056997, 0.23563796624300942, 1.2976668967354683, 0.0327173859301594, 0.5080930762473614, 45.40915789142732, 69.57460203478414, 52.77716944294592, 47.507182705786924, 34.40967090668217, 40.67763805389404, 50.42267653249925, 63.039160620781686, 13.336529270295175, 0.08079475047247064, 0.05393641647852717, 0.04515005448352426, 0.053198861498986526, 0.03786318702623248, 0.057383015406348055, 0.03763849726848064, 0.0641816780121336, 0.017269167395669128, 0.028445725629646933, 0.13024060085656183, 0.12189885331017357, 0.22888818004679298, 0.13528124489370855, 0.3037331776032525, 0.18071499322691273, 0.1570363492975312, 0.13410998838803462, 0.18483518262303647, 0.2083850931376219, 0.19418710902813943, 0.1163955381320369, 0.22913346607838908, 2.300803997824269, 56.19553073760002, 67.10033170638546, 50.62532578745196, 32.47393219701706, 47.16597964686733, 48.69193461633498, 64.0230950232475, 60.165871497123476, 68.52912564431468, 5.943485642633131, 0.8960180909883593, 6.310826395788501, 3.2424233805748726, 2.4168644797417427, 18.251694479296287, 67.97963296213459, 53.99864258304719, 62.1306690862102, 56.54470405270977, 60.25764711441533, 53.019281664202296, 57.99093292605493, 49.59041233985655, 45.96110989970546, 40.48259427470546, 41.78458975207421, 41.524360102991906, 43.65196743319112, 38.874602933083814, 41.33683550742365, 42.98262673039591, 45.96147075776131, 44.37804914289906, 45.325336840844926, 42.99774354504001, 43.120337224775746, 46.21828010005336, 46.99766682040307, 45.09481522344774, 46.27951222081339, 44.29183152414138, 45.036560181648504, 41.327378672938195, 42.21510910218762, 42.186122786614206, 42.8373735181747, 39.81568151904691, 41.06733337525399, 41.49941775106615, 41.313207149505615, 39.551553034013324, 42.91128666170182, 41.17424149667063, 42.242173456376605, 43.129444968315866, 43.3125098289982, 45.04085125461702, 42.969616228534335, 39.274304220753336, 42.21965120684716, 43.49898715173045, 43.41247143283967, 43.817220810920965, 41.67265315209666, 41.965713039521255, 42.99129124610655, 43.310242699038604, 41.36790852392874, 41.91093714006486, 41.052914742500555, 40.547827213041245, 40.63570791675199, 45.897689096389286, 57.60164160882273, 57.83533642368933, 58.21293515543784, 56.97747484330208, 54.01367702791768, 45.96063529291461, 46.4558776732414, 46.77773560247114, 47.86284754353185, 48.45065001518496, 46.37242532545521, 43.34911338744625, 41.26192215950259, 40.8849274727606, 43.303394240717736, 43.20671958308066, 43.85367531930247, 45.16162887696297, 43.40744687664894, 46.484738472969305, 43.78335898922336, 44.6112536614941, 43.916292036733324, 41.81956552690075, 43.53257048514582, 43.00335253438642, 43.15516787190592, 42.97353467633648, 43.20539774433259, 40.18839689993089, 41.810571532095636, 42.28067544198806, 41.49479719900316, 41.77004168110509, 40.87713372322821, 42.40458311573152, 40.77461865640456, 41.15411189294631, 47.912610653908025, 54.53914519279234, 55.76851406405049, 45.521769139074514, 47.84326707163165, 48.62330490542997, 49.554514808039514, 56.196546631474654, 55.931355184124364, 54.36845541000367, 48.414599510931204, 47.38527544083134, 44.554073349122085, 45.10895536791894, 53.269999565616736, 52.23164227701003, 54.88943246103103, 56.453842347668065, 58.85824741855745, 58.03103916106686, 61.98154057225874, 56.656617118466286, 61.965533379585516, 61.831964908107636, 64.79584117089549, 62.56565601594987, 38.49213261758128, 2.9187555226587483, 1.4576760655449283, 2.279698214223308, 0.318391565233469, 0.8321318126493885, 49.937565634327555, 75.31207253856044, 58.73069194055373, 50.27450899924002, 43.0458749494245, 51.583870687792384, 57.67894760254891, 74.31239374222295, 18.35929293786326, 0.31478828600337433, 0.2537265125541918, 0.11486110998497856, 0.1761042011240798, 0.15350687497806165, 0.18186922725890914, 0.19488978019404798, 0.19410320707867224, 0.10133084044941973, 0.13207049379425664], [0.04312762449825964, 0.029628333643138893, 0.017941631714723284, 0.05475856288666687, 0.046620613880335324, 0.016232506792631843, 0.04061558005970813, 0.027212061686441306, 0.04335606042596121, 0.015020472384358366, 0.052453297070197524, 0.05194758327918188, 0.03219641549813171, 0.2626167484108479, 28.204591120443038, 50.99100051387664, 42.8511449598497, 19.552289670513524, 26.537309231296664, 33.22173403155419, 49.43010114854383, 50.82890464413551, 56.13572243721255, 11.680114307711202, 0.26670272432027325, 0.5520184434229328, 4.624060132811147, 0.8886117367975174, 4.177879739192225, 50.553491500116166, 54.73070590726791, 57.87776862421344, 53.72512786619125, 54.48970763914047, 48.76510643189954, 48.06600278423679, 43.07773636233422, 43.218423935674856, 40.75997252618113, 44.17750227835871, 40.57222043314288, 41.20284341996716, 39.51205084400792, 41.700058752490634, 42.46059848416237, 45.36234440342073, 44.35162021267799, 46.92512258406609, 44.412789575515255, 44.32338699217766, 45.22648919013239, 48.223105476748565, 44.19283482336229, 44.928290997782064, 46.76059876718829, 44.72655565507951, 42.37477702479209, 40.79948256092687, 37.96446792541012, 38.36560872293288, 36.355362630659535, 36.625492342056766, 36.611462023950395, 38.26876148100823, 37.09409790654337, 38.86600117529593, 37.848801151398696, 40.055216743100075, 40.206969322696814, 38.92001613493889, 39.283098174679665, 39.637217598576704, 39.08184920587848, 38.574412176685954, 38.09664395547683, 38.57871893913516, 38.62330452088387, 38.901020096194365, 38.778151850546564, 39.78477324208906, 38.876921053855654, 36.767066371056345, 36.74454019915673, 36.800135873979144, 34.81978608715919, 35.59294800604544, 42.76477829102547, 53.61038677154049, 53.63531343398556, 54.5122455781506, 55.025001341296786, 52.1522613494627, 41.46184536718553, 39.432050181973366, 41.48574044627529, 43.09509677271689, 42.156293161453746, 40.32134563692155, 37.06018117166335, 39.131094563391905, 39.31194720729705, 38.1745030033973, 38.967323841587195, 38.900129718165246, 38.710490965074115, 39.70410185475504, 40.5586725665677, 40.15993618196057, 39.40329136386995, 39.16074768189461, 37.257696044060495, 37.463949957201564, 38.57347865258494, 37.91434787934826, 36.9657697216157, 37.9148107190286, 36.312750001107496, 38.48036158469416, 37.36549062113608, 37.51192838914933, 38.52954418428483, 39.008559719208755, 37.7905539543398, 35.38474075255856, 35.72038973531416, 37.96672721062937, 47.3128802545609, 51.43151798555928, 52.127271929094874, 52.803955308852665, 51.24674297148182, 48.26982090550084, 51.252442175342196, 53.88110483846357, 51.78846151598039, 48.22287797927857, 44.35852358418126, 41.895118221159905, 40.311692683927475, 42.35565939257222, 44.5414472395374, 43.50634159580354, 46.601032826208304, 48.254237328806234, 47.570148514163115, 49.086254412128085, 52.634912921536355, 53.42059896838281, 55.28930241061796, 58.234441511092655, 55.90424768386349, 24.911014149265906, 0.3236888180817327, 0.3541257364615318, 0.3778432976574667, 0.05208019309887483, 0.7320081046031368, 45.499019392075084, 65.4212042593187, 48.46436262130738, 33.511432447741115, 23.490084563532186, 38.08176248304306, 47.03658065488262, 50.655006362545876, 7.9232441321496045, 0.06725418471520947, 0.10046678520138226, 0.04403297188541582, 0.060377028740702145, 0.003110384962882006, 0.06147105975316898, 0.03399161997461512, 0.052212121100315166, 0.0397640235361553, 0.025009409516989708, 0.08520105072567541, 0.036662907279547186, 0.02865196415974248, 0.0030037658730326525, 0.04301867530410809, 0.014879622331429875, 0.016047015838745623, 0.07495523760876349, 0.06584419222969203, 0.049140518380989956, 0.011262246125918484, 0.03249779065710402, 0.0736433886472256, 0.25472501623294047, 34.539065976296705, 57.562464975541644, 47.866989566433816, 24.467853000087125, 32.182078438420454, 41.38999931273922, 55.29520165535712, 54.43908552969656, 62.1339128863427, 11.991124922229398, 0.2447790958948674, 0.8805117359565151, 4.504708292022828, 2.0820857728681257, 5.05243149495894, 54.46868765738703, 56.60581065762428, 60.25996131281699, 55.29338559796734, 56.631066799163825, 51.313348739377915, 49.760619671114036, 45.06213011280183, 44.79276134121803, 42.79983251325546, 44.72029947465466, 42.438127225445164, 43.04853039403116, 39.466512126307336, 43.24893997561547, 44.2994644564967, 48.3491704540868, 47.18437948534566, 48.19173828248055, 47.772695787491344, 48.499067752592026, 46.03254802765385, 49.29375171661378, 46.55055976683094, 46.770643957199596, 48.38650749575708, 46.264548378606, 42.67260651434622, 41.53740198381486, 39.957075119018555, 40.249487815364716, 37.86851498388475, 37.651788342383604, 39.127454603871996, 40.41058348071191, 39.171832300001576, 40.16596486491542, 39.380137612742764, 41.35828302752587, 40.82026720046997, 40.608368996650945, 41.24548742848058, 40.32072590243432, 39.547736567835656, 41.03200850948211, 38.40773105621338, 39.970371953902706, 41.89319625977547, 41.40601435015279, 39.40628020994125, 41.866947758582334, 41.18864836231355, 38.479788918649, 37.82158382477299, 39.999985848703695, 38.012163946705485, 39.91789848573747, 45.25849573073849, 56.40456168882309, 54.67311766839797, 54.93952505050167, 56.26018708752048, 54.065546451076386, 43.61719954398371, 41.79925941651867, 42.88308482016287, 43.88504643594065, 44.6362195476409, 41.153233282027706, 39.5417235743615, 40.406464992030976, 41.09644912904309, 40.83683921444801, 41.025528753957445, 41.5846469325404, 41.32440551634758, 41.03926097193072, 42.34808137339931, 42.048078890769716, 42.088730335235596, 39.42325230567686, 39.79466153729347, 40.10981613589872, 39.34581295136483, 39.691950351961204, 39.33928220502792, 40.24133713014665, 39.60061796249882, 41.41893071513022, 38.93600763813142, 39.75359039921915, 39.92879875244633, 39.63403263399678, 39.397305826986994, 38.651035678002145, 37.64375925064087, 39.496569248937796, 48.282297965018984, 52.04404707877867, 52.83738566983131, 54.372687647419596, 51.038190549419774, 49.62069303758683, 50.779623985290534, 55.95288899637038, 53.55018231176562, 51.7607460483428, 46.59134064951251, 45.00928401947022, 43.228782915299945, 44.47492384141491, 45.94001147054857, 45.802716747407, 49.86371917109336, 52.44143024567635, 50.74528363443191, 53.53169225877332, 54.71915844948062, 57.175079930213194, 57.78898185299289, 60.42346531344999, 59.251500329663685, 27.127000324187744, 0.3530804860976435, 1.3196341308855242, 2.976152300834656, 0.20485805497775156, 0.7840387739481465, 51.03908092744889, 69.86549285150343, 54.42458452716951, 42.002979478528424, 32.909717329086796, 44.19313292349539, 52.62687990742346, 58.741635353334495, 10.700228771855755, 0.052802836176969355, 0.049678495964936675, 0.047285566707291914, 0.07192935118631971, 0.06887181767172391, 0.07148994613559016, 0.003286257682878885, 0.032750611163435445, 0.03719347296282649, 0.03884151577949524, 0.1728274132455549, 0.19645923388100442, 0.12315965017243741, 0.1648910487851789, 0.07849176759801565, 0.05274988417964309, 0.16690310210950915, 0.20750611449681944, 0.1104363393519194, 0.1460156229234511, 0.1406465110278899, 0.20691575182061042, 0.12225247949602143, 0.4020495923055757, 39.5894705864691, 67.17709249065769, 57.47576882762294, 30.3279975921877, 39.02532392932523, 47.54874806250296, 62.769097589677386, 60.56467848439371, 67.98936044016193, 14.383872708966656, 0.5503069417130563, 2.812525480985642, 10.602787290849994, 1.7510509683239845, 5.8642317018201275, 58.48297465232111, 59.91381998985045, 61.96692189862652, 57.72087773969097, 59.1816899853368, 54.85510779965309, 52.27507075955791, 46.95674865476547, 48.396089846088046, 46.601742775209495, 48.12170436305385, 46.159660277828095, 45.582471739861276, 42.0032383549598, 47.093498168453095, 46.84475321923533, 49.48804632309945, 49.383071930177756, 50.885704486600815, 49.97323174630442, 48.622010523273104, 48.34249458005352, 52.28222908512239, 48.658378739510816, 50.486638622899214, 51.79697698162448, 47.991324778526064, 46.23028647515082, 45.56061237089096, 42.287280713358236, 42.57077786230272, 40.24423576170399, 38.51005392689859, 41.100516626911784, 43.24031468360655, 40.211072121897054, 42.80013453575873, 41.828186896539506, 42.949682743318625, 43.2266922919981, 41.7061266591472, 41.78465643236714, 42.73290903337541, 42.25425043413716, 42.667927126730646, 40.862487593004786, 41.121964147014005, 43.88674089985509, 42.19474415625296, 42.755819597551906, 45.856900368967366, 43.31921708199286, 41.212229651789514, 40.24810714106406, 44.231709434140114, 41.61754385117562, 42.54550995365266, 48.48667306284751, 56.6074933544282, 57.678116060072384, 57.39390503975653, 58.37272859388783, 55.6862658839072, 46.49344613475185, 43.39646424016645, 44.130155348008685, 46.59731834165512, 47.15745633648288, 43.37420086706839, 41.01632687353319, 42.33274098365538, 44.06811521899316, 42.42397531386345, 41.86430015871602, 43.126307072178015, 42.81140742763397, 42.88463415638093, 45.55249698700444, 44.64659421674667, 44.686218000227406, 41.49174167263893, 41.696850253689675, 42.31759279004989, 41.73292429216447, 41.57040480644473, 41.33872608984671, 42.28739838446341, 41.27894524605044, 43.99123676361577, 41.567415960373424, 41.45915462124733, 42.0119656285932, 41.95568746136081, 40.82755496425014, 38.08625359689036, 40.48581454061693, 42.01363263591644, 51.29076373192572, 56.848428864632886, 56.98325249456591, 55.71389113703082, 52.223287628543, 50.461641357791045, 52.93377791681598, 56.960589039710264, 59.049953260729396, 53.06623635753509, 47.802360673104566, 46.08791228263609, 45.28593271009384, 48.384926780577636, 49.52952538767169, 48.240450197650546, 51.893883059101725, 53.10855873169438, 51.87640497761389, 55.03708224142752, 57.982480218333585, 59.43307861205071, 60.94142998418501, 63.513355562763834, 59.997895994494044, 28.569261720103604, 0.6590481583149203, 1.210704763089457, 3.65316221790929, 0.24056882988060677, 0.9504312937778812, 54.61045780489522, 73.57813389070573, 59.40410406358781, 46.60829705576743, 35.212897792939216, 50.89001124905002, 60.93721735861994, 67.16358384778424, 15.556189725475928, 0.2146255687600182, 0.25608960268718584, 0.17623201523336673, 0.2023970588080345, 0.1622834540302715, 0.22637928806004987, 0.23487394675612452, 0.16203937841759575, 0.1367105657775556, 0.10967674019235758], [0.00980385986622423, 0.07296348561442668, 0.06643530567206683, 0.056324948391486565, 0.062378621134426326, 0.04006999139223368, 0.07419083507791643, 0.08288410206836078, 0.08889177889232674, 0.052693519260614156, 0.034177442261528586, 0.02872922795734579, 0.034873754897665594, 0.007879672996369342, 18.452817932251964, 51.42482249967514, 44.258860080472886, 28.496474296815936, 27.40646527659509, 34.953197663830174, 48.0263868454964, 52.38239857458299, 57.079393709859545, 26.48042701905774, 0.03391472006877584, 0.6052988779640968, 3.4600614828448144, 1.1184096768979104, 0.3801805706274125, 29.893618629824733, 50.578167130870206, 55.91619130103819, 51.64971159350488, 54.69043101033857, 47.862353324890144, 48.2518054592994, 42.531883639674035, 43.372608384778424, 44.429349822382775, 48.01463150208997, 45.64290369710615, 46.98520152799545, 45.75503641559232, 48.195029151055124, 49.72192156699396, 48.83740748128584, 47.66903538857737, 46.885585092729144, 47.75714358975811, 46.72421486146989, 44.09764674402053, 47.217668640998106, 45.7909849382216, 46.19050579686319, 46.10937941458918, 44.21434510138727, 45.5967923133604, 45.244559549516254, 39.54530469832882, 37.91282992209158, 36.38245444143973, 36.88341955984793, 38.070748467599195, 36.7649051450914, 37.7666235739185, 38.1311765024739, 38.811684193149695, 37.47084156159432, 37.7615794058769, 39.42562141726094, 38.19180850059756, 39.799650792152654, 38.88166712176415, 37.728980587374785, 38.08436301446731, 40.107792192889804, 38.91344616490026, 38.62807804538358, 38.47270904048797, 40.0516434638731, 36.78828639368857, 36.57172449173466, 37.793472197748, 35.667210240517896, 37.72243807392736, 36.513018377365604, 42.707900001156716, 55.37739099994783, 54.73829569355134, 52.86346550910704, 55.24872549118535, 53.481733029888524, 42.817436110588815, 41.64721265915902, 42.48614488109466, 42.29358003985497, 42.48086537084272, 40.770751199414654, 36.55007300838348, 38.3202112105585, 38.186077917775805, 39.67161678498791, 39.726981039970156, 40.20170157955539, 40.780592426176995, 40.632491573210686, 38.682700972403254, 40.805068016052246, 38.59407894072994, 40.39843982265842, 39.081425589899865, 37.06832793451125, 36.459497636364354, 38.18833328062488, 36.3862826747279, 37.83373140519665, 38.124908554938536, 40.254783015097345, 37.93206914778679, 37.824988442082564, 37.52548410046486, 38.65539343126359, 39.081064731844016, 38.58189605897473, 36.19276077516618, 37.278629733670144, 37.10553553796584, 45.94895839691163, 47.504338987412, 49.84031046590498, 51.698972640498994, 53.952052670140425, 51.90892142634238, 52.518830376286665, 53.156952934880415, 53.139427784950506, 51.55845372907577, 48.481597515844534, 46.15223130872173, 44.66822216587682, 42.90168469951999, 42.33510225049911, 43.48261125626103, 44.636745145243985, 42.2946390798015, 45.3963238962235, 48.05383559196226, 51.414447830569365, 53.526761839466715, 58.154272187140684, 53.295302775598344, 17.764812630991784, 0.14644328384630143, 0.4682097421778787, 0.424447613017213, 0.11327867110770558, 1.3921229637438253, 45.888118513168834, 58.46310000265799, 49.050494163267075, 44.0256751737287, 27.946152033344394, 38.03055594044347, 51.61639498126123, 45.73383992718112, 4.217343195792168, 0.11326821400753914, 0.06863544890356642, 0.057771808858360016, 0.01773189790847321, 0.05426106538863913, 0.02122137669263588, 0.00930028441812723, 0.0785293059063054, 0.023446988517178163, 0.012159689400915899, 0.004950089092862102, 0.015109090562609416, 0.10019439497902509, 0.04689164429662689, 0.034467291627680106, 0.09089795632227775, 0.008636243235800535, 0.059453222465010426, 0.043454284389172836, 0.0596930769332234, 0.11226716691688185, 0.07176707078131937, 0.020059679049037157, 0.021883602246582028, 22.48910746266765, 58.08788214960406, 52.26315067660425, 31.567091980288108, 29.284315686072077, 41.5802695674281, 53.73472198363274, 57.267804761086744, 62.28676372958768, 26.582336079689767, 0.15289075642583833, 0.6673281591746115, 6.699618101119996, 5.072504224315767, 0.7386346425740951, 34.9129698353429, 51.32251924084079, 58.30372233544627, 53.370463232840265, 57.04431595340852, 49.67118963118523, 50.985167949430405, 44.96719698752127, 46.093889974778705, 46.13065435040382, 49.97087440183086, 47.87835659519319, 49.37571748610466, 46.909739048250266, 50.23696014958043, 50.746162245350504, 50.837816269167014, 48.75425323363274, 50.17385313587804, 48.65070658345377, 48.640696694774014, 46.84833434320266, 49.900338419022106, 47.029814566335375, 48.272668546245946, 46.73753523057508, 48.58839188852618, 45.58708444718392, 46.58202109798309, 42.289987148777136, 38.84101959966844, 38.29058162627682, 38.53020314247378, 38.798834508465184, 39.18381906324817, 40.412611346091, 40.22158407395886, 40.6313423187502, 39.27850115683771, 39.79760723729288, 40.28611883040398, 39.258348018892356, 42.349411056887725, 40.680446470937426, 39.28688326189595, 39.537875729222456, 41.84117778655022, 41.7801574737795, 40.35139883718183, 40.32312639297978, 42.75185015893752, 39.373465661079656, 39.18147348588513, 41.70860559709611, 38.21211461097964, 38.774959041226296, 39.82047857776765, 45.13161490040441, 56.04422138583276, 54.91377861269059, 55.334586174257346, 55.937481926333525, 54.48851523860809, 44.96126636382073, 44.277436425608975, 44.61963184418217, 44.80821155732678, 44.94444331815166, 42.60005051089872, 40.88773196743381, 40.73972917372181, 39.07030959283152, 40.762600514196585, 41.23499901063981, 42.65864679890294, 39.99037996415169, 41.65100951348582, 40.96372788952243, 41.78826501292568, 41.29920428799045, 40.85812983974334, 39.54502228767642, 39.88558600025792, 38.94349936516055, 39.89193631756691, 39.32009397014495, 38.928194276748165, 40.17148363974787, 42.20584446384061, 39.4602402564018, 40.32983364597444, 39.749715097488895, 39.58603851256832, 39.87605856310937, 41.36865769663165, 38.216688094600556, 38.89210062642252, 39.88435437602382, 48.76500052790488, 51.38033889955091, 52.903081447847434, 53.5391329949902, 53.104844247141195, 51.964266069473766, 53.71675360587336, 54.70907795813776, 56.40749169934181, 54.74570505080685, 50.08735310646796, 48.16646252909015, 47.16348501943773, 45.43236655573691, 45.23109405271469, 45.48789162789622, 46.350491431451616, 46.77427214960898, 47.6829166566172, 51.22779792354953, 53.23356859145626, 56.30781250615274, 60.58590635176628, 55.728702006801484, 19.73514860676181, 0.1919305817254128, 1.7721432687774783, 3.2389876294520596, 0.0917187505852311, 1.4936833011527217, 50.18620467955067, 67.4112658346853, 53.50153315451838, 46.09720437757431, 27.397237900764715, 42.774811713926255, 57.09265132104197, 54.76048454161614, 7.359453920395144, 0.07169705800591938, 0.02287442206345018, 0.07460174165786275, 0.023397472424192295, 0.03826784998959592, 0.0335092680348504, 0.012979459978880422, 0.031350388214172374, 0.01801802217209291, 0.023121054494573225, 0.12610624649471816, 0.14633828383539954, 0.2419609955001262, 0.16021446505140874, 0.14862902462482452, 0.20522732467901325, 0.23396924288282472, 0.2263635832576021, 0.1637244500940846, 0.24358401405474833, 0.161924664411814, 0.214950543257498, 0.09921916505141605, 0.08881460319483474, 25.79126265741164, 66.21945365782707, 58.43995409627115, 41.9758641335272, 40.05390667146252, 48.56115102767945, 59.9920791195285, 64.80760435904226, 68.39230552796396, 31.60270121789748, 0.2274767549768571, 2.8208401703065444, 9.721099272851022, 3.763580615482023, 0.7743449425024371, 35.56609938221593, 54.32502300508561, 58.96956036167761, 56.21723321176345, 58.99653057898245, 52.19168901443482, 53.42094413695797, 47.87647777988065, 47.713397395226266, 48.81922337316698, 52.67889838064871, 50.729743203809186, 51.560516895786414, 49.95518884351177, 53.51750504586005, 54.60630009251257, 53.15195583528089, 51.88964689931562, 52.41778619827763, 52.73582373895953, 50.58853787760581, 47.60582247088033, 53.017540131845784, 50.666416537377145, 50.42805017963533, 49.89667492528116, 49.08726638363254, 48.66195986347814, 49.0905729416878, 44.56370669026529, 41.37712609383368, 41.04374031866751, 41.95246327307917, 42.086996647619436, 40.89754573760494, 42.46718022131151, 42.520045926493985, 42.678070375996256, 41.654884815216064, 41.274230557103316, 41.65730099524222, 40.763283006606564, 43.15108076218636, 42.55993643114644, 41.610256087395456, 41.44530865453905, 44.24111527781333, 43.6282527831293, 43.056422202817856, 43.55172734106741, 45.72051955807594, 40.459091432632945, 40.76920186319659, 42.65820357107347, 41.49500900699247, 43.15138278468963, 41.50247719980056, 46.10296241698727, 59.30048681074574, 58.36933574368877, 56.9804911459646, 59.741851514385594, 55.382368487696496, 46.77399366132675, 46.104276410995, 47.33272744763283, 46.97484254837037, 47.22163807961249, 45.97424199504238, 42.01411508744763, 41.23076285085371, 42.00836881514519, 44.0332688823823, 43.350266564276914, 45.14861445273123, 45.347619825793856, 43.54084276383923, 43.23799264046454, 43.22046356816446, 43.239267410770545, 44.52354554207095, 41.67357883145733, 39.72452955861246, 41.22596186976279, 42.39342397259128, 41.09500961918985, 41.39279988504226, 42.988333778996626, 43.97086789531093, 43.22330336416922, 42.085541448285504, 42.570142438334805, 42.82505727583363, 42.29275634211879, 42.91731534465667, 40.15498615080311, 41.61415100097656, 40.89075219246649, 50.67706969476516, 53.52728351469963, 54.24599901322396, 55.686752257808564, 55.9848641580151, 55.33535103644095, 54.92642433412614, 58.59391889264507, 58.53075696576027, 58.15926928674021, 53.03424942877985, 50.0681491821043, 49.89687104378977, 48.34621690934705, 48.549254478946814, 47.92308730463828, 50.36367231799711, 47.74800054488644, 50.039778678647934, 52.881955562099336, 55.742214572045114, 59.24416549744145, 64.34955781505954, 57.80873490918068, 20.471546150022938, 0.3625108445844343, 1.8472251560418838, 2.37401724342377, 0.2883417970470844, 1.673607569067709, 56.46053783355221, 72.63827123949605, 62.93576694303944, 57.24037562647174, 40.08024146479946, 52.25383896981516, 63.61835741227674, 64.50394622741207, 10.192723101185216, 0.19747134328128832, 0.17464077400584377, 0.13316728655369053, 0.09604235164700978, 0.10390825134011046, 0.11350905672917444, 0.14280343157870157, 0.1584378305462099, 0.1444923336948118, 0.15967613506701686], [0.005837149961265706, 0.025583500485687007, 0.04272596076911977, 0.04303379404929377, 0.011819235139316129, 0.06930762210920935, 0.0568867321576803, 0.030925596290598475, 0.05086811176771599, 0.03281593548073884, 0.07362730846169495, 0.028909701035327973, 0.016549050492504915, 0.1229172139879196, 9.236289416590045, 48.0612410268476, 48.044539574653875, 29.631771003046346, 18.71045489465037, 32.89928186324335, 43.22863778760357, 51.856800971492646, 51.597120454234464, 40.96639902360978, 0.6283455606429809, 0.923815928399563, 1.515700055226203, 2.3736416764797705, 0.035502222787228324, 10.7201926554403, 42.49424457550049, 56.72761201858521, 52.119556626965924, 52.43966125672864, 48.11060013309602, 44.78996861365534, 44.037097115670484, 46.174408389676, 46.45651309720932, 48.586105146715724, 48.001926945101836, 48.73514344615322, 48.97321954850228, 50.544203327548125, 49.42613955466978, 48.055969361336004, 47.66880396873721, 47.90256546389672, 45.97974508039413, 46.842956773696415, 46.01193205002816, 47.46401309967042, 45.865674711042836, 46.27266376249252, 49.03029003450948, 46.701994634443714, 49.82294221078196, 47.998420346167784, 45.38212883856989, 39.89718052648729, 36.638185131934385, 37.8580383331545, 38.48912415965911, 39.49873831964309, 37.32572170995897, 37.94449913886286, 37.988182575471946, 38.759595117261334, 38.88404407808858, 41.2960232457807, 38.62920768799321, 39.48326849168347, 36.41124463850452, 37.975317201306744, 37.87932111370949, 39.937388743123705, 40.35244218764767, 37.10254276952436, 38.56589278867168, 37.266556678279755, 37.77629613876343, 39.35289675189603, 36.19607517796178, 36.283477352511504, 36.17940510472944, 35.97169206988427, 41.503359733089326, 53.722656772982695, 52.87295372255387, 47.47667058821648, 53.23266252394646, 53.15894549892795, 43.039575622927764, 43.10149023609777, 43.115473485762074, 43.90422682608328, 40.81570548395957, 38.12573225267472, 37.089771532243304, 38.460435944218794, 41.405480907809356, 39.20105003541516, 39.103375173384144, 39.90502134446175, 37.37085250116164, 41.01405582120342, 41.382931201688706, 38.894618788073146, 39.40780993430845, 38.96926541482249, 38.416611302283506, 38.14821920087261, 37.572987925621774, 38.73777889436291, 39.032646994436945, 38.01930658278927, 37.84114076245216, 38.991430728666245, 38.51225829893543, 37.83428445939095, 38.655511102368756, 38.01712966734363, 36.64772825856363, 38.73785734176636, 37.956650641656694, 38.736241325255364, 36.41562984835717, 36.282834083803245, 44.00378834816718, 49.07658184728315, 48.13895102470152, 49.5480703538464, 51.511561793665734, 52.402500721716116, 50.360448129715465, 54.25332207833567, 54.13450956344605, 54.021439398488695, 52.407599802940126, 52.95844570282967, 48.63443266960883, 47.09390217258085, 46.41155096792406, 43.54005828980477, 44.770956885430124, 44.49794815432641, 43.93314646136376, 49.08749780347271, 52.95018911361695, 59.260360963882945, 46.36643586620208, 10.032287374619516, 0.17523346558934258, 3.4126956760883336, 6.66067631975297, 0.1240505951066171, 1.3405734589022975, 46.332821153825336, 49.07959814994566, 45.68357083105272, 38.66172021435153, 25.516616336760986, 35.896551224493216, 52.47342894154211, 36.077192060409054, 1.9972020051171704, 0.03967606898156866, 0.07605850381115753, 0.1149824966165808, 0.019693862489094178, 0.022346018663337155, 0.11576439659561842, 0.09235749171385843, 0.039478966049970164, 0.035875579567566034, 0.05683455007871794, 0.06186762516717277, 0.013549548138173358, 0.05818547335483375, 0.025697942530255646, 0.03459049388766289, 0.1002216370656125, 0.02830239057901406, 0.02881693927901647, 0.015273102326318623, 0.051313147564689, 0.0489399335797756, 0.07658197935069762, 0.06701752483364075, 0.1250373240139696, 11.519931574021617, 56.82089382602323, 54.460564428760165, 35.226908499194735, 26.474841563932358, 43.26057764791673, 50.7341911715846, 55.965813206088164, 56.83137439912366, 42.984662440515336, 0.6279851315963654, 1.1026603800635184, 4.212465238186621, 5.943705785659052, 0.6504345108424464, 14.39161252590918, 43.98670250369657, 57.6425362402393, 53.44511770432996, 55.57294468725882, 50.487705507586085, 47.97874965975362, 45.68888564263621, 48.23935977874264, 48.60639556761711, 49.28260041821388, 50.92879956768405, 52.3681015353049, 50.03194178304365, 53.54152171842514, 50.45238456418438, 50.90972115916591, 49.14618038362073, 50.49092969586773, 47.28932642167615, 48.499616884416156, 46.35915202479209, 49.979072155491004, 46.721602562935125, 48.27317453199818, 49.7692528078633, 48.55089010730867, 50.49242411890338, 50.99023172932287, 46.161978398599935, 42.436664181370894, 37.7097374393094, 40.09953168130691, 39.330805963085545, 40.6796698416433, 37.28134793619956, 38.66598775309902, 39.18596067736226, 40.57597021902762, 41.274124653108665, 41.98106911874587, 39.42430742325322, 40.16966758235809, 38.38806036979922, 39.92231899692167, 40.91013654585808, 41.42424944908389, 40.23667735438193, 40.54834888827416, 39.382914650824766, 40.36821796048073, 40.29012357034991, 39.43418002897693, 39.43669819062756, 37.4454402923584, 37.56005979353382, 39.43667465640653, 45.46822094148206, 54.958270057555175, 56.664638365468676, 52.02392924216486, 55.364415799417806, 56.4931405744245, 45.06970813197475, 44.93094252001855, 46.80376445093463, 47.53748693773824, 43.905289788399976, 40.751829685703406, 39.02550828072333, 40.65715935922439, 41.664596603762725, 40.1317931759742, 40.24498885677707, 41.08027719682263, 40.56862361969487, 42.77403508463214, 42.20124744599865, 41.09287977218628, 39.942401532203924, 41.36584143484793, 39.24890687388759, 40.306573990852606, 39.69764171108123, 39.80604425553353, 40.42757911066855, 40.92045237941127, 40.18956576624225, 41.50645056078511, 40.04893310608403, 39.32061564537787, 39.77109985966837, 40.08223795121716, 39.2385478942625, 39.15569959148284, 38.70958881993448, 39.69064420269382, 38.42513069029778, 40.1049876982166, 47.439914057331706, 50.04363436852732, 51.02081444955642, 52.61407729118101, 54.683539405945815, 52.83673063401253, 51.81381179440407, 55.75215385806177, 55.99117917399253, 56.08976010353335, 54.03282603909893, 55.84179570597988, 49.80369906271658, 48.88501721043741, 47.73715126898981, 45.832495381755216, 46.681006031651656, 46.17180785825176, 46.19043519420009, 52.58499291635329, 55.592544771009884, 62.346450436499815, 50.11329566278766, 11.847284743862769, 0.17565066175114724, 4.334962819853137, 2.0440141448090157, 0.15441220704345934, 1.6974129239397666, 52.12284357317033, 55.382278273182536, 54.778743174768266, 47.082158596284934, 37.104017580709154, 43.265990518754535, 55.84591419466081, 44.34184174383841, 3.5511796128365303, 0.026812539173049793, 0.13087003401690914, 0.06936474928572293, 0.017604440030071045, 0.022585009367415504, 0.020098270728222786, 0.03464161876528975, 0.003394376389840017, 0.02771424764256564, 0.026970033443743185, 0.11752223896403467, 0.16163586458611875, 0.13831726665939056, 0.14845847813112123, 0.15221004133983967, 0.12783753625567884, 0.08985455989116624, 0.1455327577047771, 0.17459532967017544, 0.1185647237505163, 0.22154666753786229, 0.16579474142241865, 0.16486662590215284, 0.15725955667514957, 12.697473187600414, 64.10984608434862, 60.85463969938217, 42.14940940180133, 29.121862880645264, 46.61687920170446, 54.94879753358903, 61.84472045590801, 62.48226250371626, 48.52778342462356, 0.8532365543707725, 2.583356345853498, 5.791781112071007, 5.185047320781216, 0.5584098843316878, 14.863933555541502, 45.82594502356745, 58.606368495572, 55.191698151250044, 58.43446277802991, 54.50468324845838, 49.62668641921013, 48.3702806503542, 50.130860036419286, 50.58337603845904, 52.716792398883456, 53.8161386212995, 54.98540109203708, 52.40789398070305, 57.06905826445549, 53.571884785929036, 53.189061457110995, 52.55848553872878, 52.33514185874693, 49.08199079575078, 51.97857879823255, 49.02749730694679, 52.485031312511815, 48.89397590391098, 51.040167423986624, 53.616992042910674, 49.44006789115168, 52.32960739443379, 52.90539172387893, 50.14820475732127, 44.35442470735119, 39.75071530188284, 41.645451514951645, 41.23546969506049, 44.7972563774355, 38.795127868652344, 41.67667358152328, 40.96621859458185, 42.846516563046364, 42.934832649846236, 43.67019860975204, 42.24291478433917, 42.69819213498024, 41.05277745954452, 42.63686587733608, 42.312811420809844, 44.37702932665425, 44.538297576289025, 43.25560408253824, 42.13618316958028, 42.246205652913744, 42.149574141348566, 44.213721444529874, 41.73078267805038, 41.28574271355906, 40.45632616166146, 41.54776096343994, 46.93633664038874, 56.9279549198766, 57.515094510970584, 53.64513504889704, 57.99140361047561, 58.08994923868487, 47.88187888360793, 48.25691630763393, 49.43936578689083, 49.540013805512466, 45.44672243056759, 42.760459761465754, 41.04166146247618, 42.02821208584694, 45.961949286922334, 41.95509910583496, 42.45177707364483, 42.59677140943466, 41.80112254235053, 44.13078684960642, 44.349054982585294, 43.69605487392795, 41.90366506576538, 42.9516556955153, 41.95345955510294, 42.41870757072203, 40.819796516049294, 42.283146535196614, 42.87036065132388, 42.787539805135424, 40.76762507038732, 43.344202579990515, 42.0424424448321, 39.599762885801255, 42.34897175142842, 43.00256806035196, 40.61963404378584, 42.4955468023977, 41.38178586959839, 42.711877284511445, 40.23887388167843, 42.10948359581732, 49.07647986565867, 54.40460005114156, 52.68941817745086, 55.02740183184224, 56.60097045283164, 56.13831512389645, 52.64868828558153, 57.53100364438949, 58.717175452939934, 59.07039665406751, 56.713562088627974, 59.45988801217849, 52.51118959919099, 52.119250682092485, 50.752096791421216, 48.096295249077585, 50.288782504297075, 49.60490157527309, 47.627685762220814, 54.31467187020087, 58.33029639336371, 64.5579101962428, 52.19659589952039, 14.413468953101868, 0.2081658540954513, 9.692222783642432, 16.19590280517455, 0.2698302016623559, 1.8140687481049569, 56.69444053403793, 60.85754617567986, 65.1098818163718, 50.83882039593112, 37.62900721642279, 51.664275353954686, 66.03958945120534, 53.94518067759853, 5.512988355851943, 0.1453903266378949, 0.2491223700945416, 0.26076725894405, 0.09495141946019665, 0.1374454126362839, 0.19924120556923652, 0.13194263371969425, 0.14029219536291015, 0.13633726645381222, 0.17853104509413245], [0.03411112202992363, 0.03502069056154259, 0.042119422146389564, 0.0762209527555012, 0.02639617613186279, 0.004742972434483348, 0.020988189104583957, 0.025319881970062855, 0.088522853930631, 0.056936133337477525, 0.017931858348029277, 0.03238548982828375, 0.018078864875039267, 0.03426122546736752, 3.1383249019422843, 47.74886346632435, 48.82678962522938, 32.608420464300345, 18.29441301284298, 31.872132747404038, 43.897998102249645, 55.65848373597669, 52.50383123274773, 49.11184787750245, 4.280938054284742, 0.4085985102480458, 5.009777680520089, 10.08003438672712, 0.5839912148733294, 3.2767970715799644, 25.903938624166674, 52.08871895267118, 52.768814794478885, 50.93545582986648, 47.15112955339494, 44.4368415494119, 43.00630215675601, 45.512002437345444, 45.89761064898583, 47.95207754258187, 49.381095055610906, 48.27995238765594, 48.55341611369964, 50.68240411819951, 46.84988367942072, 49.3218868778598, 44.67858114550191, 44.31851540842364, 43.95135802607383, 43.10517334168957, 45.43509260300667, 45.00510277286653, 47.23663330078126, 49.23137034139326, 49.87177964179747, 50.384284373252626, 49.90262123846239, 50.31955742066907, 49.218253935537035, 46.17965259859639, 39.85166926537791, 37.47263800713324, 38.116691189427534, 38.008453384522475, 35.84054762317289, 37.05045761600618, 38.504754804795795, 37.89083327016523, 38.066720193432225, 40.633542768416866, 39.229581356048584, 39.23545314419655, 38.97200715157294, 38.2627720217551, 38.17306741591423, 40.39234053704047, 38.91446990351523, 37.41739534562634, 37.86525157190139, 39.08588924715596, 37.51641165825629, 37.58248006143878, 38.96562153293241, 37.782787661398615, 37.22072770518642, 36.889220745332786, 43.143545889085345, 51.622647239315896, 53.64808467126662, 54.508311440867764, 54.161409178087794, 50.267672308029674, 45.16457065459221, 43.06190567631876, 44.103416550544004, 44.631359730997396, 41.2814869419221, 38.7322561971603, 37.84742047709804, 38.53492959853142, 39.269938622751546, 39.73852065301711, 39.26077204365885, 38.8429533281634, 39.94240937694427, 39.55444774320049, 40.5706593298143, 40.6009086485832, 39.18857689826719, 38.67444046082036, 37.82426672597086, 38.06013845628308, 36.55401499040666, 38.19382459886613, 37.26315990571053, 38.26419584212765, 38.171423942812034, 39.673209267277876, 38.90400894226567, 39.172150011985536, 38.22878076184181, 37.95647805736911, 37.65674621828141, 38.663500970409764, 36.70506546574254, 37.173490601201216, 37.69543647766113, 37.200825598932084, 37.039906440242646, 41.79785128562681, 47.825588949265025, 47.591780385663434, 48.584587189459036, 51.02746678936867, 50.504983548195135, 53.591375043315274, 54.49140210305491, 52.75369013509443, 51.90126888213619, 54.70444956133443, 51.98590578571443, 51.76618245340163, 55.530465418292636, 51.44952558702039, 49.37332091792938, 49.54976089539067, 45.260013687995176, 46.723669652015936, 54.05813317145071, 56.64052755601945, 37.96429141875237, 4.252690124896265, 0.028940400093673702, 1.0611659937327909, 2.163005250115549, 0.273257403243934, 2.840353716765681, 51.56225842814292, 57.87128886868877, 47.967060996640114, 42.11329221725464, 22.978534929213986, 32.9308275253542, 57.0062062048143, 26.345575932533514, 0.8469120389030826, 0.07089762227429498, 0.03631544044061053, 0.03954654266577094, 0.020263102206010974, 0.08031638985079143, 0.01589559185724225, 0.04674750485367352, 0.04180274821156937, 0.06572531836648142, 0.0529749799639948, 0.01670582464054948, 0.01762723497625801, 0.04774262625423651, 0.04013570258393884, 0.06697332156040976, 0.06825309442055803, 0.02602599861641084, 0.033466148776032274, 0.04320086633426048, 0.07065033675321648, 0.07010492811640424, 0.04090734464567035, 0.022036576598522165, 0.06540215183650294, 4.979198882656713, 53.43638258595621, 55.56179731122909, 37.54793182496102, 20.62553644180298, 38.23880634000225, 46.34683186008085, 58.85469375118133, 56.021808962668146, 53.48250573681247, 4.082471516824538, 0.34988114970826334, 1.3092226895593828, 7.3246002293402155, 1.5220609139050207, 3.912111213130336, 31.610942117629516, 52.76199379274922, 54.851711027083866, 52.82476740498697, 51.14703632170155, 46.213055502983835, 46.20911744333083, 48.00832433085288, 48.96297431761219, 49.840867442469445, 52.00380356081071, 51.06219545487435, 50.927618934262185, 52.019269466400154, 50.16722433028683, 50.75856870220554, 46.53840434166693, 45.89217032155683, 45.43920324694726, 45.22270802528628, 45.89111520398048, 45.94665596562047, 49.02959185261881, 50.44044094700968, 50.88102509898525, 51.80417845326086, 51.859903566298954, 51.5057723752914, 51.78603356884372, 47.35283743950629, 40.516393338480306, 39.301282282798525, 39.77652057524651, 39.39805892206008, 38.17186324827133, 38.59574202568301, 40.10057503177274, 40.05420477159562, 40.7648088086036, 42.83282356877481, 42.212363443067, 40.777521210332075, 40.62170897760699, 39.574404762637236, 40.045642237509455, 41.566792303516024, 42.3489756737986, 40.18491775758805, 40.37994584729595, 40.70771086600519, 40.642156293315274, 39.51125460286295, 40.76105510034869, 40.122391254671165, 39.8240283227736, 38.16290847716793, 44.22606514346215, 53.72976018536476, 56.01632548916725, 56.410802179767245, 54.441274212252715, 51.64527539283999, 48.31944673292099, 44.9522723690156, 45.926914676543205, 45.62785748512515, 44.81136514294533, 40.019895799698375, 39.98620656228835, 41.912211910370864, 41.03881774410125, 40.783589116988644, 42.09135832325105, 40.97638930043867, 42.14329442670269, 42.30293881508612, 42.087737975582, 40.275214641324936, 40.249295619226274, 41.015369815211145, 40.26414963506883, 39.384573813407656, 39.13575826152679, 39.46492748875772, 39.18947512103666, 40.294038095781886, 39.838372430493756, 40.59177737082205, 40.7699941819714, 41.146329910524436, 40.53790753887546, 39.737092910274384, 40.057840808745354, 41.83499613115865, 40.23259416703255, 37.924969657774895, 40.11356199941328, 37.92408712448613, 38.16670925386491, 45.586143078342566, 49.154931191475164, 50.42655183422951, 50.28251455676172, 53.98277659570017, 51.117041956993845, 54.19844811962497, 55.15230970997965, 55.446887554660925, 53.757742374174065, 55.94407543059319, 54.65006589889527, 55.821407225824174, 57.67224427192443, 54.436532066714385, 50.94921158206079, 50.92689329578031, 47.62237879537767, 49.78322429041709, 55.873194279209265, 59.32013396293887, 40.14830243202948, 5.482382591693632, 0.15499598136351955, 3.029880682306905, 3.0522161289568874, 0.1327867860034589, 2.856748978937826, 55.31605297519315, 61.84282987348495, 55.94872343924738, 42.06141494935559, 23.53484469075357, 39.38268715335477, 64.8052627040494, 33.29014016735938, 1.8913876121082616, 0.07471893012763993, 0.04225295893247089, 0.014105769148426912, 0.026799590371909644, 0.04715569182148865, 0.0421124124418824, 0.039592327910565564, 0.006111678526541519, 0.06637580362298796, 0.0793574852568488, 0.08229071334485086, 0.13565477404382922, 0.10454122382666796, 0.223113669743461, 0.18966683787443947, 0.2765634097158909, 0.09115117902476942, 0.0937414831752258, 0.14081218520239477, 0.12873027383560134, 0.11677295900881292, 0.16348463393026785, 0.07999628767251007, 0.19935602682732767, 5.878762122123472, 64.73278514800533, 62.73475723881876, 48.08040180513936, 30.99865621136081, 43.42699204721759, 56.71278938170403, 65.32017184842017, 62.54684040623327, 58.029026985168464, 5.505247068020606, 1.1005245269306245, 12.199567517926617, 19.633621977221583, 0.815389849726231, 4.151543965262752, 30.243733313775834, 55.147324377490634, 58.806009292602546, 56.515651056843424, 52.53625354459209, 49.57595056103122, 47.310005157224595, 52.07724209754698, 50.00399881793607, 51.50499574599728, 53.820818008915076, 51.802142743141424, 51.81010515459123, 55.3322837429662, 51.888403507971, 54.02538922525222, 49.46309612643335, 48.34392232279624, 49.011827438108384, 46.9827578913781, 49.51476158634309, 48.56847409279116, 53.258679605299434, 53.69011286766299, 52.818930918170565, 55.54886917914114, 55.52586447808051, 52.24721408659413, 54.189987567163286, 50.52793725844353, 44.330082478061804, 41.65644199617448, 42.03269143258372, 41.60113265437465, 39.51556136531215, 41.3017342167516, 41.15746944181381, 40.989697902433335, 43.17206936497843, 45.81490747390255, 43.96319181688371, 43.4389905775747, 42.30210335023942, 42.086694625116166, 42.01908865282613, 44.611410556300996, 43.361123684913885, 43.535982947195734, 42.22027486370456, 43.532307686344275, 42.83912289527155, 41.84013051371421, 45.328972877994666, 44.343402847166985, 42.78492358423049, 40.88828109925793, 48.335442158483694, 56.00491923670615, 58.9817314763223, 58.83022208367625, 57.291209543904955, 53.84154773527577, 49.81015528402021, 47.431806518185525, 48.08932911965155, 48.58816046868601, 46.25390698832851, 40.806028996744466, 41.48060606371972, 44.029142548961026, 43.959967628602065, 43.80683829707485, 45.373640829517, 41.955534488924094, 42.94042594971196, 43.63442267141035, 44.83574659593644, 43.572849304445334, 41.96305367254442, 42.36020934197211, 42.65285345815843, 40.20355293827672, 40.505806861385224, 40.851367673566266, 41.16377661305089, 41.606212123747795, 41.61390389165571, 41.93895070783554, 43.485313769309755, 43.082058814264116, 41.984701233525435, 43.27066598399993, 41.21843484140212, 44.4596815109253, 42.14830329341274, 40.79548566572128, 41.736426968728345, 40.78549538889239, 39.866021217838416, 47.47939271311606, 52.08483580620059, 53.14269904167422, 53.79047455326204, 57.00469609229796, 54.322524455285844, 56.18859990950554, 57.90496633898828, 56.890951279670965, 54.787105667975645, 58.559182382399044, 55.73049060760006, 56.562876393718106, 61.441775368105986, 56.003377745228434, 54.63343112699447, 54.60749641541512, 50.24356149858045, 53.621232125066946, 59.50512078500564, 61.68569187964163, 41.581093265164284, 6.093307925808815, 0.4614646750832758, 7.01215991089421, 6.615292535674188, 0.4167403701332308, 3.303298075352946, 63.08374228016023, 67.23203705203149, 61.161627923288655, 53.71982089934811, 33.495586072244954, 46.6176950547003, 72.63008133057626, 42.91665246409755, 2.612486808530746, 0.25613075693047815, 0.15413471467552647, 0.17222024260028718, 0.16040633943292404, 0.17148531913276643, 0.09356559704869025, 0.14919125655245397, 0.11192078026191843, 0.18504761880443943, 0.30009775332385497], [0.028426473840109767, 0.031045780164159598, 0.0333748770607335, 0.0780289892047163, 0.022899124568568605, 0.03139082616525552, 0.040601457228824016, 0.02761948831199158, 0.007043778182818525, 0.0357483055502657, 0.02936499666482691, 0.018668898133440845, 0.03503480956198708, 0.0382115233749632, 1.4191457653237929, 33.913726422094534, 51.826602643535985, 33.31994625829881, 21.69671024045637, 37.14788536871634, 41.46899192563949, 54.68581830301593, 48.84121218035298, 57.424883919377486, 8.600895847043684, 0.2707401915423332, 0.719540115566023, 5.10134345100772, 1.7903711358385703, 0.36601100837992084, 10.507896331048782, 39.485002179299634, 56.76541582230599, 50.55970845683929, 50.14384700405983, 45.02258477672454, 42.09968943749705, 43.32213924777123, 44.85566439167146, 48.61920995097007, 48.82820167849141, 47.790805370576926, 48.93452144438221, 46.486719269906324, 43.59511659991357, 40.28981762547647, 42.12693814308413, 41.94144141289496, 42.45830389761156, 44.304430177134854, 45.879524600121286, 48.2987876092234, 49.3032556195413, 50.39685949202507, 50.717509331241736, 51.334576606750495, 52.83225520964592, 52.52472177628548, 50.8840217897969, 48.78560866079023, 45.83048320585682, 38.722740527122255, 36.33251874677597, 38.31040528512771, 37.32276032047887, 37.643229730667606, 38.17582484214537, 36.820230176371915, 40.79012378569573, 40.22605165358513, 40.414858864199736, 39.84359310519311, 40.24996634452574, 37.93604643114152, 40.152130665317664, 39.24083463607296, 38.895336581814675, 37.87628519919611, 37.68996869364093, 38.346549926265595, 38.72263854549777, 38.67618199317686, 39.62634086608887, 35.111563359537435, 37.25802552315497, 37.17907213395642, 41.11964994861234, 52.8874586474511, 54.137196387014086, 53.92984421022477, 54.24690508073377, 52.1791099732922, 45.4736416570602, 44.55192389026765, 46.48551510226342, 46.1065709975458, 44.66769264590356, 38.810401578103345, 37.917783875619214, 40.023233736715014, 37.434339984770745, 39.1935073175738, 40.814422868913226, 40.79834115120673, 40.423009549417806, 41.68549891441099, 40.190193345469815, 40.04451651727, 38.257425831210234, 41.43576945027998, 38.63428715736636, 38.15838598435925, 38.515698217576556, 37.099326425983065, 37.3733941970333, 39.333873256560295, 38.547347822496974, 38.87513245305708, 38.185846497935636, 38.640872816885675, 38.14677969101937, 37.974367987725046, 38.46742953023603, 37.945828822351274, 36.174796319776966, 38.376912993769494, 37.48933553695679, 37.88540078747658, 38.2108869091157, 39.32354173352642, 42.24624879898564, 43.50600427196872, 46.2223554426624, 46.90980572854319, 48.444923354733376, 51.11865405113467, 51.48970634706559, 53.20201312341998, 53.30164132579681, 51.80215451025194, 51.25147334990963, 52.14203965279364, 53.67880859682637, 55.52410725624331, 53.01630066287134, 55.01778025780955, 50.30431509017945, 50.26289486115979, 52.44288152264011, 56.98585694836032, 27.19303538722377, 1.1686605094901978, 0.24009961634874347, 1.9867179999428413, 1.4037835573957813, 0.14337376871656987, 6.952882601368812, 61.29976595601728, 50.74674275613601, 38.46351500480406, 36.17450214201404, 34.91279332868515, 35.056791382451216, 52.036582808340754, 17.951448809716013, 0.4433020787133325, 0.06914027786302952, 0.02463885087279543, 0.05253585836579723, 0.06133785621533471, 0.03761315507994544, 0.03895954694598913, 0.10936137243744828, 0.038426188872225826, 0.0031391154146648103, 0.04622718942682109, 0.04530424500004419, 0.03550978024460135, 0.024128182408129497, 0.06164558224319931, 0.04329631322874658, 0.04338821696658288, 0.029847450111241593, 0.04445580645434318, 0.029429062682714675, 0.09135273675764762, 0.021076327520272425, 0.06652575001240739, 0.0662941080067427, 0.06630264988709843, 1.7448813251910673, 44.4632508677821, 57.92932425775836, 38.65107882407404, 24.339465979606878, 41.866947758582334, 50.58177571142874, 60.31576095088836, 53.81914707922167, 60.55112669544836, 8.812756788346077, 0.13806398266986494, 0.42935045315854015, 6.3858368223713295, 3.2317349218553115, 1.6747101228083334, 12.72809022857297, 41.71432441280734, 59.30475827186339, 52.612182786387784, 52.079281730036584, 46.00288314204062, 45.39726526506486, 43.99634761195029, 48.99243523997646, 50.82430762629355, 51.95225184963596, 50.82482930152647, 50.5708283762778, 50.01528347692182, 45.377343546959665, 43.81134902277301, 43.657890212151315, 45.1900464488614, 43.205805670830514, 45.196228104252974, 49.202317345526914, 49.038013181378766, 51.83356485059185, 52.68824931113951, 53.83313425125615, 54.74079816572128, 53.91588841715167, 54.75102378476051, 53.25138399677893, 50.73663480820195, 47.57938177354875, 39.3336889051622, 39.18113223968014, 38.62535199811382, 39.948928356170654, 39.91048128374162, 39.82144740320022, 40.68656929077641, 42.82530830752465, 41.46630510207146, 41.66294920829035, 41.5383315855457, 41.70539317592498, 39.27532011462797, 40.23377087808425, 41.61356656782089, 41.493553807658536, 39.126191600676506, 38.98536282200968, 40.96328466169296, 41.80410746605166, 42.56016392861643, 39.86244793861143, 37.967915688791585, 39.05775408590994, 40.08576416200207, 43.215662587073545, 53.92610226908038, 56.93923957886235, 54.344572098024436, 54.731482536562034, 53.57466966875138, 48.06390823856477, 46.89443788220806, 47.823898407720755, 47.75562171013125, 46.497321436482096, 40.432352635168264, 39.27002099252517, 40.8453703695728, 39.10354775767173, 40.950635017887244, 43.016755273265225, 42.67716038611628, 41.82653165632679, 41.619956108831595, 41.70844085754887, 41.828080992544855, 38.5492854733621, 42.19026480951617, 38.93160281642791, 38.85213167436662, 39.41687060940651, 39.52680287822601, 38.94275411482781, 40.23974857022686, 40.884707820030954, 40.783636185430716, 40.568753057910556, 40.18720449939851, 40.0872625074079, 40.56042194366455, 39.44175412577968, 40.07806454935382, 38.15478132617089, 40.11219309222314, 40.06508150408345, 39.16009264607584, 40.56751751130627, 40.17368801178471, 45.92877780237506, 46.41484183649863, 48.63662135216498, 48.783141489951845, 50.65491222566175, 52.997281089905776, 55.10479804008238, 54.88063458473452, 55.433390678897986, 52.91724120416949, 52.26981478352701, 52.59792497081142, 55.37118188796505, 55.52325610191592, 56.6487096201989, 55.43410847263952, 53.48143100738526, 51.98443489689981, 56.62518324390535, 58.22314900736655, 30.971615391392863, 1.4022530975841707, 1.3007981738736554, 4.7909844402344, 1.7960865194759064, 0.25238783519354563, 7.040777523671427, 66.19445247034874, 56.215836847982104, 44.47032682357296, 39.49487086265318, 34.265115876351636, 39.39226558131557, 60.61284911247992, 25.067465728329076, 1.0036550990996822, 0.10065238532279769, 0.02283069567995206, 0.015043857218247029, 0.07471871562302113, 0.046938030920442075, 0.03357029076845896, 0.032023758432197, 0.031005234960767052, 0.0573613312876513, 0.011776061296733397, 0.13587438080820347, 0.14692849329402372, 0.09869225743797519, 0.17233103423589663, 0.1365743859881355, 0.15478679339491552, 0.23256048379886538, 0.14649542379042796, 0.1166139038339738, 0.10481630301763935, 0.12685637680753586, 0.2013611853603394, 0.13340779219663915, 0.23263798125328558, 2.2090217615327528, 50.528568760041274, 64.34271720147902, 46.9798671045611, 33.20689178282215, 49.23689303859588, 54.682809845093765, 64.57663166907527, 57.88449156668879, 66.40228317629906, 11.991046474825952, 0.7614469636351832, 4.142682350450947, 13.095878131927984, 4.645429695806196, 1.9024065305148403, 13.764812869410362, 42.44481486658896, 59.565635112024125, 56.60825821661181, 54.50992745737876, 49.624952731593964, 48.549450597455426, 46.12183686225645, 51.64702476993684, 54.44237247590096, 52.85108650884321, 52.685119259742, 53.929801064152876, 51.265476211424804, 47.10781874195222, 45.60619031229327, 46.84572988940824, 47.389154664931766, 46.77049098476287, 48.86394231550155, 52.13568149074432, 51.99847305974653, 52.696384306876894, 54.35826509229599, 55.600836661554155, 55.62600651094991, 56.01604700088502, 56.50230715351721, 55.44669143615231, 53.46713789047734, 50.13225247783046, 42.439833456470126, 39.765851728377804, 40.56974541756415, 41.92276308613439, 42.25731380524174, 43.21513306710028, 42.743036593160326, 46.08493520367531, 43.460049783029866, 43.951895390787435, 43.89444443487352, 43.039681526922415, 41.33495669211111, 43.318903292379076, 43.83418113954606, 42.31959319883778, 41.08611760600921, 40.95285900177495, 43.70225614117038, 43.19032015339021, 44.53757586017732, 43.55162143707276, 40.19041299819946, 41.63373931761711, 42.78712403389716, 46.136945832160215, 56.87808982787594, 58.51725616762715, 57.70267794209143, 58.12978875252509, 54.56133404085713, 50.325346839043405, 51.524858628549886, 50.181576282747336, 50.685655763072354, 49.37174020274993, 42.53817119906026, 42.39594605661208, 44.76436338117046, 41.16107410000217, 44.35549943677841, 46.0125360950347, 46.10136993469731, 44.200703097927956, 44.437728005070845, 43.25095999625422, 45.661472197501894, 40.594962335401966, 45.083106948483376, 41.25042569252753, 41.511431970903956, 42.021179276127974, 43.051303509742986, 41.107431765525575, 42.9485099546371, 43.095751808535674, 42.563976472423924, 42.993672124801144, 42.12700482337706, 41.90054285910822, 41.272143856171645, 42.012440235384055, 41.74129070774202, 40.34577415835473, 43.16255761731056, 42.08473736240018, 41.89414939572735, 43.40571711140294, 43.54098396916544, 48.464821538617535, 49.38886134855209, 50.694512474921446, 51.64545189949774, 53.45483733761696, 56.74556862923407, 57.377870390492106, 57.45539211457776, 56.24081057886924, 53.488236319634225, 52.14556978594873, 53.554485151844645, 56.689161023786, 58.40627270360147, 59.34097351566438, 59.62061105235931, 56.455603491875436, 56.744066361458074, 57.69058135248, 60.04452905347271, 32.179252370711296, 2.237230467219507, 1.4450764319589062, 7.9917699002450515, 4.170200228691101, 0.6814515109985106, 8.711645930044114, 73.42796987102878, 61.393392932030466, 50.56228937641267, 49.462590140681115, 46.765533108865064, 50.63417073219053, 66.52898357760522, 34.16306364920832, 1.6642576191694507, 0.3246219744605403, 0.14666676701557252, 0.18484668926365916, 0.17580459945865218, 0.13664088241996306, 0.11072372191495473, 0.20059880530161245, 0.13248300149796471, 0.18218310880324534, 0.10456589951870904], [0.06613173567119145, 0.03561174654732308, 0.03784775035455823, 0.021243189131059957, 0.054950299372355786, 0.053902356209413665, 0.07633551354369811, 0.03327988598856234, 0.05721023193590584, 0.09079444252194897, 0.03884491720987905, 0.027169666380711624, 0.04945974721903763, 0.037517482189521674, 0.4086210332330196, 25.04481011821378, 51.61600274424399, 44.259413134667184, 27.55888269793603, 31.42306450874575, 36.98049429924258, 56.430837646607436, 49.1594458395435, 59.53682922547864, 17.10878837493158, 0.01508893191649188, 0.8254304432099866, 1.8898844863137894, 3.527403920888901, 0.6955096534182948, 3.740513646794904, 25.284082543465402, 53.882077586266306, 50.42588895367038, 50.958640959955034, 41.25714079026253, 40.79517579847767, 41.33582353591919, 44.02969168078515, 43.515049257586085, 47.396058036435036, 44.64773170409664, 43.477967169977006, 41.073683692562966, 41.49691135652604, 38.98198566129131, 39.62092799525107, 39.923248598652506, 43.8099055905496, 48.80895068568569, 50.29299905223232, 49.595978183131066, 51.24042011076405, 50.52468561357068, 51.329481447896654, 50.70351431446691, 51.20731138413953, 51.21634460264637, 52.1794080734253, 50.26791941735053, 49.81516415073026, 42.61346109451787, 37.82700061798096, 37.846043725167554, 36.47590883316533, 36.07031614549699, 38.804749442685036, 36.35012626647949, 39.170043699203, 40.01277277546544, 39.49547490765972, 36.798837569452104, 39.204654693603516, 38.38189832625851, 37.53061848302042, 40.918899120823035, 39.98051128079815, 38.17095325839135, 37.866993104257894, 39.20511361091368, 40.227040090868556, 39.23393910931003, 36.58340923247799, 36.509751043012066, 36.4283344053453, 38.45923569894607, 40.29509713572841, 52.32300212306362, 54.30616817166729, 53.35699381366853, 54.40163081692111, 51.493946429221864, 46.898222969424346, 45.765819011196015, 45.68510840016027, 44.31392231295186, 43.41823731699298, 39.3137397304658, 38.22544674719534, 37.206156099996264, 37.81951673569218, 38.690612393040816, 41.35254459996378, 42.464881712390536, 39.139578650074625, 39.594714795389486, 40.13348371751847, 38.96323280949747, 38.701061587179865, 38.66719584311209, 38.780073811931, 38.78008950141169, 38.71023601101291, 37.213553690141254, 37.89432810198876, 34.95916358886227, 38.87686221830307, 40.03967239010719, 39.52821885385821, 39.31990177400651, 38.08149576187134, 38.028834019937825, 38.69936320089525, 38.48871623316119, 38.45517996818789, 37.114556989362164, 37.13100348749469, 38.330397605895996, 36.905216170895486, 38.37042539350448, 36.80537223815918, 40.10043382644653, 42.25174011722688, 41.95506772687359, 43.31866010542839, 46.963279401102376, 49.068442929175596, 50.77927881671537, 52.18931990285074, 55.50147518034905, 53.065534253274244, 56.95038695489207, 55.20175118600169, 55.494563964105424, 55.98781770275485, 54.41713986858245, 52.15654850006104, 53.12668008189048, 54.89315871269473, 52.86784679658952, 15.140347884547326, 0.2539845462888479, 0.5204418313599403, 2.0226198218522535, 1.5061803402439242, 0.24775585309872705, 9.30288145619054, 63.861289408899125, 49.22754210810508, 41.155068951268355, 25.184703411594516, 23.744248267143007, 38.07705171646611, 53.29908394044446, 12.42517734727552, 0.5823729307420793, 0.046224397036337087, 0.03018359034021776, 0.05166245301464393, 0.04309054201228484, 0.0035620617845486253, 0.06800812248501086, 0.07061763245972895, 0.020382977729182572, 0.038715475163752996, 0.06301692942337644, 0.07841966340258237, 0.047576660966320385, 0.06557836738084594, 0.02195473351035147, 0.07068805892260806, 0.025174005422741178, 0.029496909344508767, 0.009730551955139926, 0.036997683872018135, 0.08961198581082207, 0.05963252534368827, 0.04261855524213564, 0.07257150906708933, 0.05448179830226207, 0.43045073927890876, 31.79975325061429, 58.27998807353359, 50.338722121331, 30.61699978766903, 35.49744221471971, 44.915005930008434, 59.037029051011615, 55.30490167679326, 62.2254688509049, 18.760937759953162, 0.28236508549701783, 0.14619360047001995, 4.89584949708754, 6.758174184829959, 1.6899742714820372, 3.849535925734428, 31.271129538936002, 56.69759804202665, 53.12077299241097, 52.695136993162095, 43.876444678152765, 43.58156481096822, 44.578858806240945, 46.27165963572841, 46.852213567303075, 48.17018485838368, 48.02155056307393, 44.759295678907826, 44.75659708822928, 42.74349551047049, 40.45485919521701, 42.84461029114262, 40.684549270137666, 46.39503778949861, 49.07934319588446, 53.29928005895307, 52.31456510482296, 51.61495939377816, 52.35806811240412, 52.49204451037992, 50.96276729337631, 52.22226388992802, 52.5463693372665, 53.17602349865822, 52.26928134118357, 50.72270647172005, 43.87007474899293, 38.49880849161456, 40.10897674868184, 38.358548456622714, 38.12635198716195, 40.846731432022594, 39.26019937761369, 40.95812674491636, 40.72787577106107, 41.010325647169545, 38.59716584605556, 41.304417117949455, 40.161791463052076, 39.82821741411763, 42.188158496733635, 42.84393172110281, 38.84021551378312, 40.92554361589494, 39.76499272931007, 41.7355405130694, 40.33785489297683, 39.31116273326259, 40.092102712200536, 38.175616956526234, 39.57841342495334, 43.15690548189225, 53.13919636511034, 55.36612987518311, 54.598643625936205, 54.967703357819595, 53.7212251078698, 48.9425701479758, 47.97057544031451, 47.75042064728276, 46.39011129256218, 46.401784266194994, 40.88084428541122, 40.32189869111584, 39.7883661331669, 38.529838362047755, 41.23178658946868, 41.748637307074766, 43.43325999475295, 40.74059209515972, 40.38679038324664, 41.17346486737652, 39.95682408732753, 41.39579657585391, 39.4979577679788, 40.63396246202531, 40.072008409807765, 39.99211757413803, 39.75554373956496, 38.57034075644709, 37.57235642402403, 39.87574477349558, 41.56812198700444, 40.242521685938684, 40.45727145287299, 39.04479849723078, 40.45494940973098, 41.902480509973344, 41.61969331003005, 40.26847993173907, 38.96228751828594, 38.686552739912464, 39.40505643044749, 39.352198570005356, 40.22849921257266, 39.737092910274384, 43.72531183304326, 44.67400766188099, 45.2946521389869, 45.743457578843646, 48.41763934781475, 51.828885462976274, 53.18347207961544, 54.11873771298317, 57.70426257964104, 54.89891675210769, 58.31613663704165, 56.76907147130659, 56.144845870233354, 57.00876359016665, 57.77656755139751, 55.87881895803637, 55.53182648074243, 56.57447876468782, 55.178926913968986, 17.439428490977136, 0.4881310312738342, 2.3372629188722183, 3.7834591875153207, 1.7941599002768918, 0.28367586193546174, 10.427380857929107, 69.12734985351562, 52.77165851285381, 45.779986612258426, 32.41960933131556, 28.802242663598832, 43.457908168915786, 61.466753021363296, 18.223741708263276, 0.5899883350056987, 0.08172810603413852, 0.03755258050777259, 0.04120228466607871, 0.01780895677755677, 0.010498389432717477, 0.05167817313885016, 0.01771452686479015, 0.04305821693231983, 0.047015432613871755, 0.06164142238577047, 0.18737240454121945, 0.20777646692529803, 0.1404844221448706, 0.12718303669844905, 0.1449779721517717, 0.16613470059969734, 0.12721626959260435, 0.11704594677975101, 0.14208675632553716, 0.2963420532403454, 0.1133368784681924, 0.09586509422308977, 0.1713254059394521, 0.13550976892152142, 0.5016622277757814, 37.13813827883813, 66.64509357944613, 57.885189748579464, 40.13072236891716, 41.72989622239144, 48.58100214312154, 66.69295434028872, 57.41726275413268, 70.53598280875914, 20.839870437499016, 0.3843800501236993, 1.4170455812446534, 9.373001667761034, 10.620891970972862, 1.1541944405724927, 5.890519917011262, 32.466936649814734, 62.89987333359257, 55.496285884611076, 58.04489297251548, 45.458587600338845, 46.27691953412948, 46.9250637485135, 49.56880400257726, 47.23394255484305, 51.790818860453946, 48.99842469922958, 48.22963622308547, 44.86963587422525, 44.33533845409271, 40.951917632933586, 45.23306308254119, 43.80458685659593, 49.834018984148585, 53.307603328458725, 55.5322697085719, 54.45044471371559, 53.84474054459603, 53.36118682738274, 54.76791743309268, 50.87390207475232, 53.63746289283999, 53.26389635762861, 55.12564935991841, 53.712960673916726, 55.08834369720952, 49.192974259776456, 41.0635482880377, 41.347296468673214, 40.28735829937843, 38.96196980630198, 42.78150327744023, 40.84618622256864, 43.28976792673911, 43.63739190563079, 43.3450694237986, 39.123587146882095, 44.25703225597259, 43.819268288150916, 42.13481426239014, 44.2575970772774, 43.86361460531912, 40.305930722144346, 41.8868027963946, 44.13519559368011, 45.78007682677239, 44.48742051278391, 43.03016585688437, 43.031636745699, 41.422774637899096, 42.82335888954901, 44.79405180100472, 54.82523110605056, 58.409104654865885, 57.092553261787664, 58.402279730766054, 55.830926818232385, 51.14904457522977, 49.132946306659335, 50.58807111555531, 49.34101235482001, 48.8195175509299, 43.56178429818923, 43.39345970461446, 41.29536428759175, 40.752104251615464, 42.77023430793516, 45.49754850326046, 45.178091064576186, 44.02549474470077, 41.62739684504848, 43.901030094392844, 41.53044762149934, 43.3685448092799, 41.32542925496256, 43.093822002410896, 42.33339994184433, 42.69551707852272, 42.384626096294774, 40.79253212098153, 38.494340911988296, 44.20182097342707, 43.99874418012558, 42.657658361619525, 41.77408956712292, 41.79747866046044, 41.599453879940896, 42.929913997650154, 43.7588990888288, 42.63040573366227, 40.40930871040591, 40.60048111023442, 41.966391609561065, 40.57467583687075, 42.04335243471208, 42.17748572749477, 45.799214070843114, 48.21261705890779, 47.92913167707382, 47.24241095204508, 50.91554195650163, 56.090803453999186, 55.43387313042918, 56.88169056369413, 60.79557272695727, 56.60790912566647, 59.795705656851496, 58.4337842079901, 57.66999675381569, 60.41598535353138, 59.25823503924955, 59.152464405182876, 59.80209912023237, 59.52177516875729, 55.89936825536913, 19.530891180038452, 0.9839054136987656, 2.3317242870407724, 8.205500341230824, 5.637340238017421, 0.3340848150753206, 11.324149408648092, 76.84549962320636, 58.25327673266011, 52.510722837140484, 36.899438519631666, 37.27271087708012, 51.234791509566776, 69.88031156601446, 24.132458971392726, 0.902200052815099, 0.15393802926184671, 0.1080419545272185, 0.16090987370379511, 0.11011390826634823, 0.13600653097514184, 0.18078885942457185, 0.1342957953531896, 0.09644703759301095, 0.14337048986025397, 0.18299093319764062], [0.0199208754084764, 0.0577921370014308, 0.042008875658915895, 0.08586069073287711, 0.027146972941174626, 0.016551490482543747, 0.022914160959302418, 0.075250418946868, 0.03811483924847938, 0.009104515437126882, 0.003821930539185903, 0.04246809557380696, 0.08643384707430679, 0.0757446529103383, 0.05068566026766935, 17.206806444352676, 55.139926787345644, 40.976852140119, 33.45769205401021, 40.30149844384963, 38.52659063954508, 51.62411028339017, 49.63458999510735, 56.79681047316521, 24.703620787589784, 0.03469540579845348, 0.009058674650957749, 3.9107123978676337, 4.65887067779418, 0.4798421744377383, 0.2927830232487571, 10.193237912270332, 49.096397661393695, 52.344328049690496, 50.16731062243062, 46.5179217246271, 42.59211555604012, 40.96001732733942, 40.97024294637865, 43.03439809430031, 41.93548333260321, 41.96863128292946, 40.402260211206254, 37.05652160029258, 38.224105296596406, 38.64284576908235, 40.83201469913606, 46.97354424384333, 49.01473783677625, 51.48051623375186, 48.914144731337025, 52.69404265188402, 49.65968531946982, 49.8263664399424, 51.71146146712765, 48.755830026442005, 50.737889966657086, 49.442586052802305, 50.828422192604314, 48.96176622759912, 52.65592505854946, 43.37787220554967, 36.38043049843081, 37.38780106267622, 39.518891457588445, 37.57155233813871, 36.67399637160763, 37.95928255204232, 38.162049478100194, 40.19546108861124, 40.94162141123126, 39.25957572075629, 36.964922489658484, 38.285988530805035, 39.13839409428258, 42.09325282804428, 39.12673681013046, 39.329680242846095, 37.138816848877944, 39.23024423660771, 38.84835443189068, 38.29831261788645, 35.81409123636062, 36.099898661336596, 37.030080902961, 36.43495928856635, 39.98999164950463, 52.77786370246641, 53.96835796294674, 53.37545248769945, 54.2504705152204, 53.39739030407321, 46.491794816909305, 45.77624074874386, 47.51993433121712, 45.24086075444376, 43.43547221153013, 39.095667715995546, 40.00928971075243, 38.89748996303928, 37.43423408077609, 38.48790038016535, 38.92655864838631, 39.42557434881888, 39.28497306762203, 39.69978332519531, 38.31717529604512, 39.9575222692182, 38.89643092309275, 39.83968250213131, 37.56348010032408, 37.58942657901395, 37.450260885300175, 39.68791815542406, 38.02607659370669, 38.68164193245673, 40.21465716823455, 38.146905206864886, 38.16702304347869, 37.7651644522144, 40.3343443716726, 42.09120142844416, 40.31159462467317, 38.602900351247484, 37.709372658883375, 36.3900520724635, 38.023931057222434, 36.049786460015085, 38.00600974790512, 38.41448145527994, 38.04498241793725, 37.074564503085234, 39.36014529197447, 38.818171793414706, 38.23283257022981, 41.972879209826075, 42.65137472460347, 47.812449009187766, 49.07521294009302, 49.93500432660503, 51.8306387624433, 52.09231184374902, 54.41231535327051, 53.8692985042449, 56.17428718074676, 55.739821926240005, 52.953574119075654, 57.7880875525936, 57.17533880664457, 48.64710192526541, 7.720323253062464, 0.024962618781794465, 2.1687733406020753, 4.071138073359767, 1.1067764172630927, 0.03452847523975276, 13.700790962865277, 62.725367084626235, 50.09904176958146, 43.53453951497232, 24.763138832584506, 32.09137558937073, 38.02289947386711, 49.283879110890055, 10.594654256297696, 0.3628945933474649, 0.0421199469166177, 0.029465097543453018, 0.08007482700650731, 0.07437827381035013, 0.02215368271384749, 0.02484684565945739, 0.02166916274525706, 0.037500589950791294, 0.03536556802329517, 0.029447697771472797, 0.029360453763435927, 0.0404413448526494, 0.08609761108434008, 0.020625479031173934, 0.013876294213978034, 0.030821011882395517, 0.019217064686780496, 0.06630748390190064, 0.022727049729456345, 0.04749535988535612, 0.025591488867517442, 0.0787660347357873, 0.04080415643270939, 0.032873464853412686, 0.055174472020758744, 22.31965911003851, 62.164723104046246, 49.11394634554463, 35.49904646412019, 40.495302754063765, 46.24923936782345, 57.29379046347834, 54.316848785646506, 64.02437371592369, 25.260207076226514, 0.029863384740066626, 0.2059564871653434, 5.298333706394319, 8.043061754395886, 3.402043744441002, 0.5642169533718018, 13.804511177924372, 54.948377839980594, 53.204017454578036, 52.07021713256837, 48.02240171740132, 43.38086497399115, 41.63783427207701, 44.3663683245259, 46.1184440120574, 43.356522744701756, 44.05612453337639, 41.51229881471203, 40.163666355994444, 40.196571119370006, 40.37439961587229, 42.558500843663374, 46.7486394605329, 50.74290667810748, 53.16657058654293, 51.874200605577045, 53.33594245295371, 51.29949885029947, 52.94046948032995, 52.21638817940989, 49.5947269470461, 52.106338239485225, 50.09717472137944, 52.01280540035617, 52.71921250127977, 54.07238314228674, 44.79415770499937, 38.372849418270974, 40.553993178952126, 40.02443790435791, 39.9699208813329, 39.59679365158081, 39.18988696990475, 38.87144150272493, 40.929881757305516, 43.104718346749586, 40.61957520823325, 39.691471822800175, 41.39666734203216, 41.0542405036188, 43.755251284568544, 40.00705003738403, 39.89954963807137, 39.62099859791417, 39.513113806324625, 41.661690127465036, 40.336631113483065, 38.600193915828584, 39.53281979407034, 40.4614919231784, 40.14801217663673, 41.98380301075597, 53.94172114710654, 55.86563194951704, 54.28597973239038, 54.39373900813442, 55.72553273170225, 49.292327896241225, 46.242151644922075, 49.40381734601913, 46.86265099433161, 46.07552543763192, 40.99191796395087, 40.0377582734631, 41.85736540825137, 40.35167732546407, 39.49164667437154, 40.787185930436664, 41.749582598286295, 41.669021037317094, 41.54849444666217, 39.98826188425864, 40.352842269405244, 41.29501519664642, 41.41374141939225, 39.52344925172868, 41.16068578535511, 39.53376900765204, 41.26436579611994, 39.82618954873855, 40.15506852057673, 40.88482549113613, 42.38561061120803, 40.19013450991723, 41.63273126848283, 43.11952921652025, 44.06322010101811, 41.93231013513381, 41.58935769911736, 41.100873562597464, 39.651393044379454, 40.23490836543422, 38.38169828537972, 39.74933070521201, 39.54657162389448, 39.26158005191434, 39.46872042071435, 40.47989568402691, 42.58816965164677, 41.05135756154215, 43.28194279824534, 46.36596125941123, 50.94095891521823, 51.5200537250888, 52.21211279592207, 53.441862137086936, 55.132274243139456, 55.71065910400883, 56.60961535669143, 57.63949640335576, 57.77759129001249, 57.30415728784377, 60.47468362316009, 58.49181567468951, 50.43257267244401, 8.916466216887198, 0.06589252471683488, 3.342183472648744, 4.713110193129509, 1.7222345404086576, 0.1315969442047419, 15.310689556983212, 68.72482053695187, 55.689368478713504, 50.09746497677219, 28.264785774292488, 36.32424254571238, 44.42505482704409, 56.61525964736939, 14.031798801114483, 0.42664073888332615, 0.027831405468825853, 0.02081497279446452, 0.033033952612670205, 0.0731162971726829, 0.004676559793522521, 0.019870367231628588, 0.04957434631163075, 0.013925624530642264, 0.034195824541271694, 0.027065497575207587, 0.12256271446183806, 0.13305900768647272, 0.22484424704265213, 0.14255034677203626, 0.05619630690724139, 0.10630081287555157, 0.09626120764521823, 0.13513388022059394, 0.17270053376353559, 0.16302101284025178, 0.09836843973326106, 0.2250518875136491, 0.20442126228684382, 0.16711242797393955, 0.12838986266644734, 26.827776432037357, 69.08132476191368, 55.88123121569234, 43.98346262593424, 52.01692388903711, 52.16914323068435, 62.787673934813476, 58.763353516978604, 69.67644245393815, 30.497316506601152, 0.12160280629271462, 0.7592443689223259, 10.077548584630414, 11.927558010624303, 2.7477029206291324, 0.5037414823328296, 15.741119673175199, 57.09191783781975, 55.5967926979065, 54.5622597202178, 51.37612235161566, 47.02267585262176, 44.035865491436375, 46.03045348198184, 47.37355147638629, 46.0264487420359, 45.08254212717856, 44.90676110790622, 41.872097830618586, 43.84956467536188, 42.534896019966375, 45.823850477895434, 50.86517087874874, 52.7712348968752, 56.10106045199979, 52.51977174512802, 55.3396931002217, 51.89251807428176, 52.202844235204886, 53.90574124551589, 50.013000657481534, 54.61026168638661, 50.35359574902443, 52.419719926772586, 54.36749835168162, 55.68673656832788, 47.012344329587876, 39.852187018240656, 42.68988847732545, 41.76681749282345, 42.889819529748735, 40.10974553323562, 39.503009780760735, 41.25936869652041, 42.0965515413592, 45.08286768390287, 44.38911807152533, 39.908292601185465, 42.401860990831935, 41.93227875617243, 46.24268900963568, 42.02124203405073, 42.651900322206565, 40.97228257886825, 42.942163559698294, 45.38906751140472, 42.313913606828265, 41.33153638532085, 41.121913156201764, 43.597238602176795, 42.160325357990885, 43.607330860630164, 55.67841329882222, 57.77928575392693, 55.14128784979544, 55.56517447194746, 58.21300183573077, 51.91412248919087, 47.994141040309785, 52.4306280382218, 49.24674995483891, 48.607164352170884, 42.54186999413275, 43.27840089797974, 43.68203632293209, 42.64302007613644, 41.81657275845928, 43.011248265543294, 42.5695619275493, 43.333404294906124, 43.233901608374815, 42.79601212470762, 43.98492174763834, 42.58562403340494, 45.16851263661539, 40.84104007290256, 41.73705847032609, 40.74622069635699, 43.112653301608184, 41.263675458969615, 42.12095652857135, 42.47859039614278, 42.984183911354314, 41.421080173984656, 43.56856215384699, 45.41630837225145, 46.3542490620767, 44.7312036637337, 43.42640369169174, 42.68905301247874, 41.73601119749008, 43.82932132290256, 41.084168188033566, 42.53602174020583, 41.564117247058505, 42.233442260373025, 41.142054527036606, 42.863327841604914, 44.26371597474621, 43.235007716763405, 45.75101206379552, 47.715291900019494, 54.08333047743767, 54.142550422299294, 55.32384672472554, 56.27961850935414, 57.00403713410901, 59.52974934731761, 59.01595023370559, 60.55220142487557, 59.96505006667107, 58.331677067664366, 62.297028572328635, 61.776981123032115, 53.9590266443068, 11.21771687461484, 0.1917558983569184, 5.782855758743902, 9.757138990586805, 4.066747960544402, 0.17748518185990472, 16.123632154157086, 74.30708285300963, 58.76797014667142, 56.77437059340939, 36.58528020305019, 44.010103364144605, 50.76767644574566, 66.2011597233434, 18.961315962576098, 0.45783807613676597, 0.12612270972421094, 0.13558795585507347, 0.16374216204689396, 0.14308109248597778, 0.10588951559076387, 0.07872219152388074, 0.0749343540519476, 0.11098327250370096, 0.15099059790372849, 0.19184386057238426], [0.01471377099909249, 0.03473177199221907, 0.04570152287581756, 0.020758491047027133, 0.005409492390050043, 0.030170909669851104, 0.0793470511393201, 0.049267769415652564, 0.022823881327865586, 0.07314127163901445, 0.008249933823883053, 0.08163074391984171, 0.03865018532040619, 0.028221671724872246, 0.09554177447552643, 7.9809647510128645, 45.0151950313199, 41.849034294005364, 36.3265920454456, 32.66275509711235, 34.783378647219756, 50.0413005582748, 55.22253190317462, 54.304673748631636, 31.201985997538415, 0.09625143236330441, 0.19273921817300782, 1.7691448619288785, 7.888224230658624, 4.421878130205216, 0.35582498076461977, 5.304585474152719, 48.562570925681825, 54.84317987195907, 51.88525384472263, 47.027374852088194, 41.61883823333248, 39.83134354314497, 40.60701970131167, 39.020256227062596, 38.38989603903986, 37.93368124192761, 37.44252597132037, 39.001966214949086, 42.09379803749823, 47.09433755566997, 47.58810904718215, 49.45336472603583, 49.0692352479504, 54.13966748022265, 51.89641691023304, 49.40591973643149, 51.586632036393695, 50.75783129661314, 51.626479394974254, 49.0713611725838, 50.55861019319104, 50.883955109503965, 50.6574970676053, 48.926657092186716, 53.45366062656526, 46.544334965367476, 36.895033697928156, 36.64521794165335, 38.1332161349635, 37.51470150486116, 38.220324131750296, 38.33928961907664, 37.586575015898674, 39.21823393914008, 41.09531556406329, 38.40460884955622, 38.036337514077466, 38.50531178136026, 39.93829481063351, 41.80995571997858, 37.90301222955027, 37.657585605498284, 39.16641550679361, 38.68470138119113, 37.38765593497984, 39.9953378400495, 38.325157319345784, 37.69334193198912, 38.21906505092498, 37.650490037856564, 40.55022770358671, 51.50629797289449, 54.6936002854378, 53.18474292755128, 55.21116879678542, 54.17339594133439, 47.88213383766913, 49.098178417451926, 48.36272224303215, 47.124555495477495, 43.470463675837365, 37.431986562667355, 35.84305794008317, 37.002914567147535, 39.23056979333201, 39.891787267500355, 39.2936768070344, 40.082543896090606, 38.88196914426742, 39.79663056711997, 39.71911668777466, 37.968951194517075, 39.94602187987297, 38.93065360284621, 38.86347124653478, 37.91377913567328, 40.32811957020914, 39.65604105303365, 41.188303193738385, 41.54331691803471, 38.761626905010594, 35.51350824294552, 38.829707484091486, 46.84934631470711, 48.18583119300104, 49.790053136887096, 50.38700649815221, 47.19610344979071, 40.176931811917214, 39.55394567981843, 37.58975213573825, 37.647865972211285, 37.09402338151009, 36.92553012601791, 38.30265075929704, 38.582037264300936, 34.92117935611356, 36.61703963433543, 36.645084581067486, 38.322823509093254, 38.159409722974225, 40.24479666063863, 42.17015481764271, 46.38716951493294, 48.476565114913456, 49.6931549041502, 51.54853013253982, 52.82856818168394, 53.04681278044178, 55.305846968004786, 55.770365422771825, 57.241666086258434, 51.667448551424094, 31.329376735994895, 2.821477065163274, 0.04746540584751675, 2.750859202877168, 1.7416083524304053, 0.9749621032707154, 0.023540081606516917, 15.930159284222512, 60.77698069234049, 47.20230863940331, 38.42679769762101, 33.68136129071636, 30.185599865451938, 42.86145687103272, 47.28068936255671, 4.125404800138166, 0.17342689236806286, 0.09066532606319075, 0.060653705224995656, 0.036246534662261125, 0.0628589965673464, 0.04365494962961924, 0.016405523919890967, 0.05944072374052579, 0.07298046978370798, 0.06048744499322869, 0.0316518706254541, 0.0182122235456782, 0.04951923777679763, 0.030849251798504305, 0.02265841782753987, 0.04227963794443396, 0.02867234401374815, 0.05149628471342787, 0.04559456934070876, 0.027532022138456666, 0.0067831296943158155, 0.03249936496778842, 0.01456734095324552, 0.0431264179097789, 0.04331236660119988, 0.0840695848267886, 11.105648875236513, 53.616066363550004, 48.308519009620916, 42.36730098724365, 37.46156123376662, 39.387444988373794, 55.52245986077094, 57.90504086402155, 61.602396426662324, 32.7244088726659, 0.0924494069430136, 0.1889797489369108, 3.143300183357731, 8.702862762635755, 4.866176276437698, 0.5254605039954185, 5.632811861653482, 52.53992880544355, 54.710999919522195, 54.03519515068301, 48.28346683133034, 44.852557874494984, 41.165980985087735, 42.39415353344333, 41.806386363121774, 42.05404873817198, 39.307522773742676, 40.31914910962505, 39.847519397735596, 43.849043000128965, 47.88236133513912, 51.092276111725845, 50.93817403239589, 52.44320315699424, 53.18942623753702, 53.85549176123835, 50.84260156077724, 52.9652000242664, 52.239820418819306, 53.59954141801404, 53.3075366481658, 51.235132755771765, 53.16849254792737, 51.2559409295359, 52.439641644877774, 55.48151423854213, 47.96578622633412, 39.05412197113037, 38.28510207514609, 39.577778000985425, 41.112903471915956, 39.76080756033621, 38.406417062205655, 41.182831487348004, 39.4511874260441, 43.24286030184838, 39.405864438702984, 40.27360646955429, 39.767095119722434, 41.2417729439274, 42.40611284009872, 40.5737619246206, 40.684125654159054, 42.829167919774214, 40.42642985620807, 40.67240561208418, 42.19698775199152, 41.10651785327543, 39.980393609692975, 38.84515770020024, 40.17657879860171, 42.14717757317328, 53.244170758032034, 56.626006941641535, 54.090986944014034, 55.01583476220408, 54.80829823401667, 50.97397742732879, 50.1835649244247, 49.55476976210072, 48.05342374309417, 45.81121260120023, 39.15739797776745, 37.974085577072636, 39.63602912041449, 41.500170846139234, 41.53010637529435, 41.386728056015514, 41.64526324118338, 40.24885631376698, 41.360216756020826, 41.09346420534196, 39.54544590365502, 42.006933227662124, 39.458953718985285, 39.91418400118428, 39.92902232754616, 40.84899071724185, 40.04652084842805, 42.21389708980438, 42.72952010554653, 41.025226731454175, 37.90149819466376, 41.15954829800514, 47.78867552357335, 50.24751917008431, 52.4050816412895, 50.77810602803385, 48.9644608959075, 42.76037346932196, 40.846821646536554, 40.105685880107266, 39.86303237176711, 39.92033427761447, 38.638252673610566, 39.74012882478776, 40.85966348648071, 37.175083083491174, 39.911661917163485, 38.53471386817194, 40.47069380360265, 41.55559393667406, 41.51634670072987, 44.72170760554653, 50.44703052889917, 49.86005567735242, 53.205339293326105, 53.619219949168546, 54.265081344112275, 55.335229442965606, 57.650824208413404, 58.501798106778054, 59.20974277680921, 53.14498186111451, 34.948043669423754, 3.8489701238370713, 0.5690501101555363, 4.913730111814314, 5.148879635718561, 2.0902739657509715, 0.062247248546731096, 16.435996966977275, 66.79859945850988, 51.65755633384951, 45.53012378754155, 33.41784077305948, 34.765461260272616, 48.78196085652998, 53.98757365442092, 6.101007538457071, 0.21002511884416306, 0.02440917196743671, 0.030523865528765227, 0.03294295285858455, 0.05019943958388702, 0.012064222396621782, 0.053977088086427226, 0.02478909795172513, 0.014772752108382843, 0.06125203138517757, 0.010407036320576745, 0.100311889883972, 0.13056853245342934, 0.12442112885295384, 0.10524172696375078, 0.08561616312832603, 0.11453404406746549, 0.16051843341800476, 0.16076258563947293, 0.18548108667375582, 0.17254529370655938, 0.08485883158902008, 0.2808001823723316, 0.21672681004049318, 0.19666742593530687, 0.2630119884927427, 13.15225730019231, 64.3745590025379, 56.68300682498563, 48.092015943219586, 44.44947550373693, 45.899756185470096, 59.65788141373665, 64.46431852156117, 64.24284581215151, 39.110219709334835, 0.20877193689586657, 0.5923973444488742, 7.1156692985565435, 16.931610991877896, 10.674563723225749, 0.8001738113741722, 8.457018406160417, 53.437229817913426, 58.28605205781999, 55.890805721282966, 52.336683350224654, 46.555246999186856, 42.820719134423044, 43.72834382518646, 43.8745972418016, 42.53205622396162, 41.42970546599358, 42.329226539980986, 42.375259476323286, 45.85228766164472, 51.952306762818374, 53.50195284812681, 54.602405178931456, 54.31999060415453, 57.07588318855532, 53.561294386463786, 52.44704315739294, 55.661539262340916, 56.03859670700566, 55.289769172668464, 53.14571142196656, 52.97955589909708, 56.21715084198983, 54.07179478676089, 52.89575838273572, 58.32467563690678, 51.31001472473145, 40.53640527109946, 40.36087528351815, 42.271610844519834, 42.43253784794962, 41.46509308968821, 41.03939433251658, 42.41406740680818, 41.210017435012325, 45.38918910488006, 41.58159532854634, 41.47856643123012, 42.674901100897024, 43.41114174935126, 44.332153489512784, 43.32811301754367, 41.566078432144664, 45.21276873926963, 43.079905433039514, 43.193199173096694, 44.45162496259136, 43.039575622927764, 43.75197610547466, 41.895686964834894, 42.386367628651286, 45.25859771236297, 54.101914667314105, 59.34258168743503, 55.90497724471554, 57.899416185194454, 57.050293645551136, 54.2446614849952, 52.353118081246656, 53.136897856189364, 51.29063821608021, 48.707584873322524, 41.74207518177648, 40.928685434402965, 41.78858272490963, 43.83387519467262, 44.66224055136404, 42.55814783034786, 44.37205576127575, 42.88055096903155, 43.776286955802675, 43.59130797847625, 40.50768175432759, 45.01934882133238, 41.66301981095345, 41.00416360362884, 41.18490642116916, 43.158439128629624, 42.915228643725, 46.90520871070124, 44.647139426200624, 43.20566838787448, 39.88275404899351, 42.721592995428274, 50.532012601052564, 53.58528360243767, 56.18018642548592, 54.165257023226836, 53.18659428627261, 44.04988796480241, 44.30076276102374, 42.70993963364632, 40.60162251995456, 41.76069859535464, 41.376996655617994, 42.22442473134687, 43.19445825392201, 38.55011701583862, 41.50468941657774, 40.070011923390055, 43.96917735376666, 42.63084896149174, 44.37362470934468, 47.23985356669272, 52.503941059112556, 52.441336108792214, 55.038713947419204, 56.42554244687481, 57.56479094105383, 59.14671421051026, 60.97880624955701, 60.05182858436339, 61.25250531781105, 53.01012685222011, 38.168929315382435, 4.264522935113599, 0.991361165238965, 8.466007498002822, 8.894632343323, 4.68083595075915, 0.14561126639525737, 19.789979419400616, 73.12073846017161, 56.79745374187347, 51.552350521087654, 44.76903884641586, 42.86596759673088, 56.82966424572853, 63.00695796166698, 8.108824703001208, 0.45414090517067146, 0.2534440559365096, 0.15045963768516818, 0.11387774420361366, 0.21136211081137582, 0.14534961672559862, 0.1940895247483446, 0.22070300555036915, 0.08000329737701724, 0.14698210412696486, 0.15959473056418283], [0.043386378355564616, 0.05594397286674189, 0.13355077484682684, 0.027443613676774888, 0.02710001175141623, 0.06216188719976814, 0.04921169177959523, 0.04518603380288809, 0.03107124492676268, 0.020453657001076687, 0.05301702286927931, 0.046061109225716323, 0.04249156084692767, 0.014946916452308577, 0.062249979650181156, 4.022616883439403, 38.915211231477805, 45.66167616075086, 39.891069473758826, 35.610324105908795, 34.60348698400682, 45.23032134579074, 47.04214649815714, 55.904428112891416, 41.930964762164706, 1.3996460697343274, 0.05345835846157805, 1.5643911328046554, 5.155375571020189, 5.429078561644401, 0.5451740913333432, 4.1672015766943655, 49.187035791335575, 55.20992148307062, 51.05152660800565, 48.4771534704393, 40.83413277902911, 40.13910839634557, 40.789323622180575, 39.28115660144437, 37.735440731048584, 38.044750998097086, 41.5376647826164, 45.33160871075046, 46.18646575558571, 46.11032470580071, 51.43731917104414, 52.75415689714494, 50.966893626797585, 50.4173146524737, 45.16879896963797, 50.389548194023874, 53.15651755179129, 48.225800145056944, 49.67420593384774, 49.74293370400706, 48.10697978542697, 49.12243435459752, 50.84790460525021, 49.5019942714322, 49.27183743446104, 39.743882533042665, 37.31286810290429, 36.51253592583441, 35.649904743317634, 37.029653364612216, 39.74868351413358, 37.239009872559585, 38.4376234392966, 40.21121724959343, 39.475427673709014, 38.074494331113755, 38.48233061452066, 38.72539204935874, 38.734899874656435, 41.43866808183732, 40.27388103546635, 40.736697181578606, 39.64012015250422, 39.953348867354855, 38.72822400062315, 39.430924461733916, 38.09289809196226, 37.33636310023647, 37.876795107318515, 37.7554448189274, 42.01607627253379, 51.22087886256557, 54.381050140626975, 52.80313945585682, 55.143735408782966, 52.98372930096042, 49.94313539997224, 50.73999627943962, 51.22469532874323, 47.89982372714628, 42.900570746391054, 38.587371687735285, 35.47645753429782, 38.62607371422553, 36.894876803121264, 38.73327209103493, 38.50442140333114, 40.14077932603898, 40.49312583861813, 38.31047196542063, 39.923876177880075, 40.20278807609312, 39.51909149846723, 38.001036182526626, 38.28797325011223, 39.17197742769795, 39.17608414926837, 38.15851150020477, 39.189463353926136, 36.366486472468225, 37.0681082817816, 37.86682051997031, 45.2870858869245, 52.35201981759841, 52.00670219236805, 52.73133262511223, 49.040205786305094, 49.93514945430141, 47.938051146845666, 45.93633620969711, 41.48213186571675, 39.298999463358236, 38.66377553632183, 38.608579943257, 37.44658170207855, 37.37153107120145, 36.56193817815473, 36.931456827348285, 37.65738164224933, 36.993053728534335, 38.00978699038106, 36.97090410417126, 36.789443492889404, 37.16166857750186, 41.75812944289177, 41.83192491531372, 45.185708307450824, 47.99123848638227, 50.47595408654983, 52.933158182328754, 56.89216721442438, 54.77125929247949, 51.76848488469278, 17.010580070557133, 1.0428198426961899, 0.15837243728099332, 1.9349715185742227, 3.9817435799106478, 0.6757086094829344, 0.027132666249188687, 22.301680926353704, 60.99533119509297, 47.62448510816021, 37.98475834631151, 23.2089820215779, 35.70284105116321, 50.55739033606745, 38.59163922648276, 0.8169350797130216, 0.10403994185429427, 0.034751265099452394, 0.05225320639569433, 0.020090443224856452, 0.09703031395592036, 0.052524497281880154, 0.03775459023252611, 0.007645290311155541, 0.06998458336437903, 0.005719215034567301, 0.031308977331425396, 0.1050699164249724, 0.02162739371640548, 0.06587138069012473, 0.03871891489853302, 0.06197956593466863, 0.028065236570734172, 0.10612249825029604, 0.01289617473019227, 0.05009422123792672, 0.0183976206537937, 0.037811319043319074, 0.015327474459134524, 0.014077809812020392, 0.023982671667791666, 0.011855948945477366, 5.498519222582541, 47.30359600436303, 55.03499554049585, 44.640114461222005, 38.1344634486783, 45.128355410791215, 50.840255983414195, 55.33672386600126, 58.80982575878021, 44.71265477518882, 1.1152787674819271, 0.07533425960930125, 2.0678615425863573, 6.717902229678247, 4.524809458563405, 1.1826366498585672, 4.470187512136275, 50.35730238883726, 57.479298960778024, 53.84231651982954, 50.55968884498843, 44.981776437451764, 41.449415376109464, 42.57213108001217, 40.016228383587254, 40.053839991169596, 39.32749940503029, 43.64323231481737, 45.122930772842906, 49.270597965486594, 49.7412000163909, 52.82441046930129, 53.28124892327094, 53.00809506447085, 51.42611295946183, 49.14806704367361, 51.13005638122559, 54.72357111592447, 51.34191928371307, 51.48737253681306, 51.75362302410988, 50.75622704721267, 49.89534131942257, 52.22317780217817, 51.04381130587671, 51.51564890338529, 43.4710402642527, 40.26164324052873, 37.241488810508486, 37.70307333238664, 38.396234589238325, 41.1806781061234, 39.59106306875906, 40.02318666827294, 41.36245250701904, 41.00739563665083, 40.33823144051337, 39.328805554297666, 39.09774657218687, 40.59769622741207, 42.641792374272505, 42.78708088782526, 42.3298619639489, 42.29716900856265, 41.35448617319907, 41.43979380207677, 42.74688051592919, 38.988594855031664, 39.76933479309082, 38.39161011480516, 39.73450806833083, 43.449263265056, 52.750968010194846, 55.745685869647616, 52.65154769343715, 56.51996958640314, 55.85899529918548, 51.577936141721665, 51.68633084143362, 53.575932671946866, 49.150114520903564, 45.17050520066292, 40.19079346810618, 38.60134317028908, 38.89422655105591, 38.00369162713328, 40.49431431678034, 40.9066770153661, 42.41697780547604, 41.56159124066753, 40.934357181672134, 42.096076934568345, 41.27548963792863, 40.78180443856024, 39.38033765362155, 41.02708985728603, 40.26263560018232, 42.722628501153764, 39.5316626948695, 41.42314334069529, 40.04791328983922, 37.84974252024005, 39.7251179141383, 46.81146406358289, 54.09634097929924, 53.64019286247992, 54.396935739824855, 52.01954403231221, 51.95320890795801, 49.972670847369784, 46.27771185290429, 42.4509023850964, 41.245103036203695, 40.86799852309689, 39.348401715678555, 38.14743472683815, 39.74079170534688, 39.010669954361454, 38.826569587953635, 39.06677945967644, 40.46437094288488, 39.421318577181914, 38.09793833763369, 38.22785508248114, 39.20965179320305, 44.655427394374726, 45.305956409823516, 47.045609951019294, 49.689546323591664, 51.91347137574227, 55.286721491044574, 58.87764353905955, 57.0882974901507, 51.780173547806285, 19.61328644906321, 1.1481327851933818, 1.630825542153851, 5.949590811806341, 4.8199673237339145, 1.7995215351543121, 0.0719315498586624, 23.321489326415524, 66.6219751296505, 52.96295642852784, 44.838056871967936, 31.604056396792014, 39.70765159976098, 57.44902610778809, 47.37706199769051, 2.0435806003309067, 0.1693710237140617, 0.025778569453846545, 0.06166120277597539, 0.03361123050713251, 0.10573790679054876, 0.021338065290042472, 0.01773971200530087, 0.02922594404569076, 0.03615576473455276, 0.017280086063809933, 0.03555824679713096, 0.1865783084424273, 0.18858188883431498, 0.2398540545254946, 0.1767490632952221, 0.1602138981463448, 0.1738420813795059, 0.13806407460041586, 0.2094215794556564, 0.19307427438757113, 0.10134736496594646, 0.21036444982934385, 0.11439556601427256, 0.13343771559096154, 0.17523331237175774, 0.17776319516762612, 7.000387407118275, 56.93513285729193, 59.36167578543387, 51.96164200382849, 45.90727144672025, 46.83870884679979, 57.09059992144185, 58.38987327391102, 64.02642903789398, 51.43998638276131, 1.8104832114711886, 0.43476246597786106, 7.4188876344311625, 10.784786247438001, 10.652743577957155, 2.217776736905498, 6.003897497730871, 54.82678044226862, 58.948834557687086, 56.365451735834924, 52.93821803985104, 46.53316797748689, 44.32737996501308, 44.38619198337678, 42.79476481099283, 43.91430731742613, 41.6333588477104, 45.79148307923348, 49.66241921147993, 51.122317544875614, 51.42844676971436, 56.27051861055436, 54.67423162152691, 54.26452044517764, 52.31349822013609, 50.060398578643806, 54.05968643003895, 57.32385150847897, 53.594348199905895, 54.49275532076436, 55.57660425862959, 52.269344099106334, 51.432722153202185, 55.199593882406916, 51.851556762572265, 53.48633789247083, 44.6851432708002, 42.348736409218084, 40.51563632103705, 39.02458260136266, 40.579292466563565, 41.989608118611, 41.34289556933988, 41.06753733850295, 42.408121093626946, 42.7895127573321, 40.574271832743, 42.22127114572833, 41.91826020517657, 42.604016027142926, 45.8154252267653, 43.33593814603744, 44.33351847433275, 43.567679620558216, 42.57090337814824, 45.011009862346036, 46.13038370686193, 41.160862292012865, 41.280545573080744, 41.67554786128383, 42.93810390656994, 45.48777395679105, 54.06500516399261, 57.41239901511901, 55.49436000085647, 59.50954914093018, 58.07615818515901, 53.675945266600586, 53.20287604485789, 56.86517738526868, 52.55738727508053, 48.155177870104396, 41.407602910072576, 40.077268308208836, 42.76450764748358, 40.362393240774836, 42.40554017405356, 41.5491416377406, 43.55816395052018, 43.512660534151145, 41.27602308027206, 43.34230415282711, 43.80332777577062, 42.95689205969534, 40.755524558405725, 42.370697759812884, 43.16472276564568, 44.274388743985085, 41.68591076327909, 44.57390877508348, 40.55707616190757, 39.889378932214555, 42.41693465940414, 48.76551435839746, 56.45057109094436, 56.61160792073896, 55.8751436971849, 53.18489589998799, 54.64985801327614, 52.626369999301055, 50.1914135871395, 46.29711189577657, 43.14544039387857, 44.33388717712895, 42.70644872419296, 40.44306462810886, 42.40741506699593, 41.02342244117491, 40.47722454993956, 41.636943894047896, 42.170099904460294, 41.62916191162602, 40.370273282451016, 40.38300921840053, 41.480005941083355, 45.64496686381679, 46.10495105866463, 49.75563826099519, 50.97128668139058, 54.782414513249556, 57.03929139721779, 63.16871258520312, 59.6435647626077, 54.98778589310185, 21.21882434814207, 2.0779893475194133, 1.4543278323065851, 8.40607858473255, 12.513870962204473, 3.773687827971674, 0.11399618905758667, 26.82952973150438, 73.66810521771832, 58.442268294672814, 50.592358266153646, 35.03449663039177, 49.96746193978095, 64.99412090547624, 54.91186057367633, 3.3018654296475076, 0.29670664980526895, 0.1080649524867054, 0.10195998249635582, 0.14634275778887734, 0.16120399017968487, 0.13989978980633522, 0.07724248503725376, 0.10794997801102939, 0.15547104780712437, 0.20065414749326246, 0.10551912740113274], [0.03509132386816125, 0.009979210688822694, 0.05969527560556608, 0.01855225167087009, 0.028422599350432717, 0.04411456024935169, 0.027536526735451435, 0.018270712443477204, 0.0830839820686848, 0.025215659538404118, 0.0037070123230918284, 0.05604041950596918, 0.053826138121827, 0.05318902493003876, 0.06867748414797169, 2.0324886277798684, 31.98077455643685, 42.47862177510416, 53.60537790483045, 27.9237651055859, 28.146177222651822, 41.496405370773815, 49.36536242884975, 56.229098381534705, 51.49302467223137, 8.601398891018285, 0.3144530765712261, 1.4522558402630592, 4.524623636276492, 2.432074695825577, 0.7517401393382781, 12.461783847501202, 49.86438989639283, 54.97266907845774, 51.90949409238754, 48.30604791641236, 41.82259751904396, 39.973384334195046, 42.0735272284477, 35.886054961912095, 41.21111569866058, 41.565419473955714, 46.37847754263109, 48.01949524110364, 51.888893804242535, 54.04388320061469, 54.2065203574396, 50.50731343607749, 50.434612304933616, 49.478546342542096, 46.59266248826058, 51.22815485923521, 49.522453354251006, 47.365161526587706, 43.841963121967936, 44.06267881393433, 44.997411004958614, 46.31571177513369, 48.72294095254714, 48.46594333648682, 44.33396170216222, 36.79074964215679, 36.48673849721109, 37.39075460741597, 38.22461520471881, 39.756237999085464, 39.58130421177034, 37.53538024040961, 37.886565731417754, 40.06137486427061, 39.261760480942264, 38.018247542842744, 39.05677349336686, 38.004734977599114, 39.277873577610144, 41.211386342202466, 39.27863451742357, 39.391410504618, 40.52906651650706, 39.04492401307629, 37.97310106215939, 39.47654162683795, 38.25695122441938, 36.98954712960028, 39.79419085287279, 39.463746855335856, 44.36220668977307, 48.89197941749327, 54.423482341151086, 53.9714527130127, 54.730643149345156, 53.427655312322806, 51.30035784936721, 53.37060836053664, 50.107435641750214, 49.96264526920934, 44.177863136414565, 39.92471556509695, 38.52778696244763, 37.45709365414035, 38.36593035728701, 38.127744428573116, 40.50192763728481, 39.67478606008714, 38.44730384888188, 40.00594000662527, 39.79315142477713, 40.510525472702525, 38.79291957424533, 41.520276915642526, 38.623567319685414, 37.333821404364805, 36.07780395015594, 37.73432285554948, 38.587760002382346, 38.962989622546786, 37.48628393296273, 38.964029050642445, 49.44579847397343, 50.8709720642336, 47.64777614224342, 50.945536321209325, 54.06563274322018, 51.37532611047068, 49.37842392152356, 49.79097881624776, 45.737028814131214, 45.87389599892401, 44.390326161538404, 43.617831045581454, 44.4252940916246, 42.908038939199145, 39.845770020638746, 38.735060691833496, 36.287097700180546, 35.141671472980136, 36.98555415676486, 37.53329746184811, 37.71967280295588, 38.36552243078909, 36.40815773317891, 39.27053874538791, 39.90443691130608, 41.264071618357015, 44.64530375695998, 51.551103207372854, 51.74385240001064, 56.29873221920383, 49.046681619459584, 12.175690089502643, 0.03111691142792904, 2.2873147216535386, 3.755263964976034, 3.152010541769766, 1.412744702350709, 0.1396933750760171, 28.574007788012107, 61.5021877135, 43.643091109491166, 36.84583540885679, 27.950858877551173, 34.15325380140735, 50.636932080791844, 24.310089388201316, 0.6982716148899448, 0.0074297931296901125, 0.02188335901366607, 0.014627342874694978, 0.04596060998136959, 0.04287690307284075, 0.032206665754558585, 0.06006053483654415, 0.046431574024139874, 0.006285719338789463, 0.04795262627604027, 0.04909505106268391, 0.016351629634417834, 0.04571086914849378, 0.038822673846997564, 0.008454097213313706, 0.032918392079732114, 0.006973474294007306, 0.04336431885378496, 0.07923453580588102, 0.02733526203120428, 0.0479430731596245, 0.06218020053159806, 0.030278221351064505, 0.06673738180148987, 0.04943271197618977, 0.023461218600371675, 2.446369773918583, 39.660571390582675, 49.562587045854144, 56.60999974896831, 34.81661681205996, 33.59371592921595, 45.83044790452527, 53.95907371274887, 60.51337388253982, 56.0757690091287, 7.831089515839854, 0.26295827040749215, 0.7151072856880004, 6.070788618057005, 5.442771065619684, 0.7686184659119576, 14.115957175531696, 51.61568895463021, 57.097652343011674, 53.21720446309736, 50.53886105937343, 44.28047626249252, 41.8889561776192, 43.98528260569419, 38.889543241070164, 42.15575579674014, 44.12872368289579, 49.333532394901404, 50.94547356328657, 52.745515915655325, 54.14133840991605, 53.92960102327409, 52.44980842836442, 50.860205158110595, 50.814242824431396, 48.69590405494937, 53.43213858142976, 50.38734774435721, 47.53953049259801, 46.840638652924575, 47.64946276141752, 47.39300643244098, 50.207020698055146, 50.27227717061197, 49.79419908215923, 47.89182601436492, 39.81695236698274, 38.1706355464074, 39.49859319194671, 40.98918407194076, 41.52939642629316, 40.43607104209162, 39.7257141144045, 41.27386577667729, 42.19328503454886, 41.28592314258699, 40.757517122453265, 41.4256497352354, 39.86460916457638, 40.77329289528632, 42.58147416576263, 41.57520186516547, 42.39548713930192, 42.86796800551876, 39.80661299920852, 40.50959194860151, 40.875953089806345, 40.55891967588856, 39.33286912979619, 41.59998339991416, 41.81850256458406, 46.12055032483993, 51.251696925009455, 54.8268549673019, 54.803328591008345, 57.26733407666607, 55.48391080671742, 53.221507303176395, 54.46246285592356, 51.852894290801025, 52.100870455465014, 46.993481651429214, 41.32628433166012, 40.807903889686834, 38.7672515838377, 40.81869825240105, 41.90267662848196, 40.92238610790622, 41.14958940013763, 40.62342305337229, 41.092797402412664, 41.77333647204984, 40.69306865815194, 40.78780174255371, 42.90495987861387, 39.8372898563262, 40.55879416004304, 37.76397205168201, 39.79867412197975, 40.6897307211353, 40.25812879685433, 38.03597665602161, 40.43053265540831, 51.57738700989754, 52.87925697142079, 50.374407845158736, 51.765001819979766, 54.636314069071126, 54.95674817792831, 50.848834206981046, 52.241444280070645, 48.37126124289728, 47.06806159788563, 47.69825312399095, 46.60868537041449, 46.67165117879068, 44.36445813025198, 40.22317655624882, 41.2657033243487, 38.23606068088163, 37.815594365519864, 38.35948982546407, 39.7543199600712, 39.1806850894805, 39.267126283337994, 38.591435263233805, 39.81073541025962, 40.70580851647162, 43.000673555558734, 48.07337684016074, 52.91046334851173, 56.00581353710544, 57.104512568443056, 50.955318712419086, 13.161433685210444, 0.3055060582776224, 4.38862378558805, 7.698914956661963, 6.082340488510748, 1.0037176118743036, 0.013077139062055898, 30.69278978532361, 66.1137536264235, 49.01493395528486, 42.336251504959606, 24.606853954253662, 38.72693354083646, 56.30166222972255, 32.635816258768884, 0.7791617356481091, 0.10938456191891625, 0.031939661130309105, 0.03122794246601482, 0.09333426913907451, 0.033037955422074564, 0.05168764964647351, 0.022985167733784166, 0.038132907432173534, 0.023752171133134155, 0.04092979485229139, 0.07269129457492983, 0.102827531105328, 0.19386319173199518, 0.1411905407064384, 0.16022004217149752, 0.1551730089610623, 0.08663191144625026, 0.09386499953125754, 0.21957392984580612, 0.11079862233131163, 0.1857578282755229, 0.1503390860894034, 0.14738783961342228, 0.209790404825922, 0.18567109180073585, 0.16530269847041176, 3.5352513578630265, 48.00373908012144, 55.451633622569425, 62.36176729202271, 37.97752157334359, 40.14816122670328, 53.595399395112075, 59.34895553896504, 64.39140558242798, 60.13364530378773, 10.97570663498294, 0.5805446772325424, 4.209311652568079, 18.448373886846728, 11.025791379713244, 2.075719520930321, 18.50284972498494, 53.29750714763519, 57.887955019550944, 55.50763330151958, 53.156631300526286, 46.79593147770051, 43.15935696324995, 47.20132804686024, 39.25822250304684, 44.70628484602898, 47.02322890681606, 51.20606407042473, 54.00718942765267, 56.152596473693855, 57.59190236368487, 54.7961937996649, 53.92857728465911, 52.29366671654486, 52.65885899143835, 51.130805553928504, 55.6171380319903, 52.93207953053137, 50.68639316866475, 49.34774706440587, 48.976400590712025, 49.05087071080362, 51.91239272394488, 52.81835432975523, 53.52445548580539, 50.535738852716264, 40.54521491450649, 39.7555241277141, 41.60596893679711, 42.109977814459036, 43.33631861594416, 42.673026207954656, 41.665114356625466, 44.661083452163204, 43.18639386084772, 42.22986898114605, 41.19854842462848, 42.77519610620315, 42.180737372367616, 43.22156183181271, 44.7299288934277, 43.151716186154275, 42.52860061583981, 45.404713846022084, 42.19581104093983, 41.13830474115188, 43.52263512149934, 41.823978193344615, 41.49735850672568, 45.043510621593846, 44.322594673402854, 50.653559007952296, 51.25132822221326, 57.520836860902854, 55.91884674564485, 56.52522948480422, 55.78278364673738, 54.703582717526345, 56.6970096865008, 53.71097203223936, 55.210364710900095, 48.18606261284121, 43.33992719650269, 43.91548010610765, 41.50332835412795, 43.81191776644799, 44.43071480720274, 44.60428753206807, 44.08542071619342, 42.52623934899607, 42.93397757314867, 43.74031489895236, 43.77979355473673, 42.45066704288606, 45.480799982624674, 41.70487934543241, 42.071315011670514, 39.31180992434102, 42.601537089194025, 42.834231699666674, 41.8438018521955, 40.5685765512528, 43.06466702492007, 53.4766927842171, 54.691580264799065, 53.184997881612475, 53.585577780200595, 57.33164525801136, 57.31437113977248, 52.793153101398104, 54.49036267495925, 48.61144758039906, 49.12740399760585, 49.51714638740786, 47.90593477987474, 49.22537695976996, 47.72803960307952, 43.75485120281097, 44.15791003934799, 39.50303331498177, 39.44289161312965, 41.65277065769319, 42.223832453450854, 41.709060592036096, 42.19536781311035, 41.4307370493489, 43.37452250142252, 43.82251993302376, 45.99704273285405, 49.7219019551431, 56.092176283559496, 58.016138076782234, 61.80051926643618, 54.166614163306456, 16.395449465320958, 0.49379557731651497, 4.506169865208288, 10.175117542666774, 11.657204724127247, 4.2860346840273955, 0.1915674254057869, 36.42222727498701, 73.0822443193005, 52.69609012911397, 49.2101542411312, 38.33026032293997, 47.06379798150832, 64.60755171314364, 39.06850530255226, 1.3553593235631145, 0.22263034487203245, 0.11002965391643586, 0.1536477125820614, 0.20372125710691177, 0.1584357008217804, 0.22519557496472714, 0.12215563832151315, 0.2729871274242478, 0.10621923217249495, 0.10712528436054146, 0.17205554901832537], [0.00774608402054817, 0.005256701420406781, 0.023336606738608212, 0.1117651571609801, 0.013626113838155665, 0.005232261300402424, 0.06889036466037074, 0.041602121275519176, 0.05037990691620977, 0.014579306289012876, 0.039861106028359745, 0.04798970876201507, 0.06353519939547105, 0.04869475097004925, 0.08092507735014924, 0.8147380621202531, 24.80912077811457, 41.86770477602559, 52.29505523558586, 33.65279074638121, 38.06760664909117, 41.16476505033432, 55.723936327042125, 54.16325661443896, 52.74968147277833, 19.248500139482562, 0.06245870413559099, 0.7651954012051706, 2.6746485310216106, 3.823047914812642, 0.4057372637814091, 17.299254748129076, 50.340181243035104, 55.711780901878114, 52.629386301963564, 50.87483559885333, 44.83281658541772, 41.238372248988, 38.31180557127922, 40.617857210097775, 43.90634098360616, 48.1270387864882, 48.97417268445415, 53.460493395405436, 52.64643292273245, 48.93385071908274, 45.52279287768949, 46.85080935878139, 48.0604330185921, 48.38810782278738, 49.26085479797856, 49.39518813164004, 50.397357633036954, 43.986780951100016, 39.88614689919257, 37.31059705057452, 39.169980941280244, 38.95267771136376, 39.659861441581484, 39.45126195107737, 36.95949785171017, 37.19368688521847, 35.90030101037795, 40.08580730807397, 38.99034815449869, 37.30994593712592, 39.586658247055546, 37.03908274250646, 39.37094749942903, 40.764420493956536, 38.58838365923974, 38.6659328399166, 36.89896783521099, 38.579315139401345, 39.89639213008266, 39.94290751795615, 39.6373744933836, 40.44756750906668, 41.09833578909598, 39.88013782808858, 38.98401744904057, 38.77254286120015, 37.1155297371649, 40.803573593016594, 39.38214194390082, 42.24613897262081, 42.13060163682507, 51.32153864829771, 53.516936302185066, 54.801010470236506, 56.81253525518603, 53.37954351978918, 53.3197352194017, 51.58462770523564, 52.546271278012185, 51.223365645254816, 45.077509726247484, 38.86587565945041, 38.24613724985431, 37.203567335682536, 37.45466962937386, 39.0554085085469, 38.55273715911373, 40.06319092166039, 39.30317678759175, 39.118558668321185, 39.65650389271398, 39.60921972028671, 38.369495791773645, 39.52200189713509, 38.67484054257793, 37.84986411371539, 37.75189507392145, 38.97998525250343, 39.030348485515965, 38.80320795120732, 37.78002239042713, 39.82561688269339, 48.63441305775797, 50.53886105937343, 47.94575860423427, 44.13689005759455, 44.92448629871492, 51.95798635482789, 49.20552976669804, 49.05052161985829, 51.474044322967536, 48.07016441898961, 48.80572649740404, 49.6742255456986, 48.81725826571065, 49.13535856431531, 50.170385760645715, 46.57313692954279, 44.2626137887278, 43.100297835565385, 39.74631832491967, 35.38781196840348, 35.20200929334087, 35.94369419159428, 38.712612967337336, 39.38025136147776, 41.33096764164586, 39.98793632753434, 45.325262315811656, 52.30231946514499, 54.13303475226126, 55.549700721617675, 51.39488304814985, 12.215235425579934, 0.24921485222876075, 2.7877297276450745, 6.664843347764785, 3.347073442512943, 0.9250182574314456, 0.22149331717481538, 34.9713856943192, 59.55243633639429, 43.46112059008691, 28.303974174684097, 36.78803928436772, 44.0353516609438, 45.53784693441084, 16.793596513809696, 0.21672581412619163, 0.029497570095343456, 0.04138547544097228, 0.03858078924578525, 0.0122491761313511, 0.09007761405119974, 0.02454128574519869, 0.04065317965503182, 0.1106436810486259, 0.037943767984547926, 0.03841246057662272, 0.05020419315945718, 0.022765181755887407, 0.02115536289620063, 0.06352031430710228, 0.03607184363288745, 0.02107363663643839, 0.03981906695351486, 0.0537082486815991, 0.03653451860431702, 0.02671886385688859, 0.03963293823143167, 0.013600839639923746, 0.08746470264609783, 0.05057301852972277, 0.07153757382184267, 0.052864195989264604, 1.0579296706184265, 33.16583241185835, 46.56053043180897, 62.43287201850646, 33.30458625670403, 42.91528355690741, 52.09176663429507, 57.12723878122146, 58.2346337072311, 58.0955699951418, 18.846800404210246, 0.05612564295710576, 0.304990052095344, 4.250375926494598, 4.090733008999979, 1.1655774039606894, 20.66986510830541, 51.94641928518973, 58.6051368713379, 54.352899289900265, 54.47665791357718, 45.366553106615626, 43.12491070839667, 39.51857766797466, 42.341154467675, 45.50935483747914, 48.95032467380647, 50.5033165408719, 52.51274285777923, 53.96569467359974, 51.74852394288587, 46.9496883884553, 48.922538603505785, 51.15513209373721, 49.83772170159125, 53.04692652917678, 51.864253474820046, 51.76898694807484, 46.82949127689485, 41.66697356008714, 40.95169798020394, 40.9408369371968, 41.697811234381895, 43.43308741046537, 43.066871396956905, 39.08519891000564, 40.46188808256581, 37.81014619335052, 40.871854212976274, 39.87974951344152, 39.59269085238057, 40.253355272354625, 39.914387964433246, 40.4947026314274, 42.0241367432379, 40.34389926541237, 39.93176014192643, 40.00433967959496, 39.07211780548096, 41.20499680119176, 40.74241599728985, 40.65440977773359, 41.31696870250087, 43.72099330348354, 41.54700002362652, 40.989305665416104, 41.7076995295863, 40.96813663359612, 41.70420469776277, 40.48836015885876, 43.718145662738436, 44.60675078053629, 53.98996630022603, 54.685022061870946, 54.46678923022363, 57.01244277338828, 55.39565355547013, 56.65468338997134, 54.65375684922742, 52.259910798841915, 53.297687576663115, 46.564660687600416, 41.95813502034834, 39.619672836795935, 39.97650261848204, 39.88350322169643, 40.61306799611738, 40.80231843456146, 42.90364196223598, 42.295819713223366, 40.605089895186886, 40.186129769971295, 41.55279336437103, 41.20601661743657, 41.862613539541925, 38.827283459324995, 38.74685133657148, 40.621548160429924, 39.601331833870184, 39.65787279990412, 41.22162765072238, 39.39836486693352, 41.3873674023536, 51.05096570907101, 52.97906168045537, 49.947944225803504, 47.015976444367446, 46.79757495080271, 53.01961114329677, 51.91061196788665, 51.1989135896006, 52.585102742718114, 50.059265013664, 51.69220262958158, 51.39703642937445, 49.36822183670537, 49.693252963404504, 50.306393946370775, 47.36026248624248, 45.439187557466575, 44.51241777789208, 40.13242467757195, 37.716468226525095, 37.67376538245909, 39.00288012719924, 40.263341626813336, 42.11683803989042, 42.51227571118263, 43.111759001208895, 47.67118876980197, 54.33131840921218, 57.25009918212891, 57.922185544044744, 53.31512251207906, 13.794909215742543, 0.5395051019807016, 6.9402260934152915, 12.504880889769524, 4.597577270000212, 1.281927773548711, 0.1713608911321048, 38.17785270752446, 64.48075717495334, 47.66010022932484, 38.83361808715328, 42.47311084501205, 46.585127615159564, 53.26355511142362, 20.449306311145907, 0.2088895620357606, 0.018624913195268284, 0.043262823695136655, 0.0649076957075346, 0.0745562743395567, 0.056932218628184456, 0.01749713600973689, 0.029726396727886413, 0.05746715484307178, 0.016010539519840914, 0.017986034170814583, 0.02961237603167613, 0.14929447923937153, 0.09050945781411664, 0.1091594393214872, 0.20541345340109643, 0.10700671693250056, 0.13346578505250717, 0.10952015948151389, 0.09061296395356618, 0.18050019749470297, 0.18783758845060103, 0.07136783938133909, 0.22673915020160137, 0.11578118924291865, 0.13936636278465872, 0.22599593766273993, 1.3668193860400109, 40.38941444889192, 55.06191084461828, 63.60870838165284, 43.13282212903423, 51.7104063495513, 51.975468358685895, 64.67681292564639, 62.6635975991526, 64.79359757515692, 24.353637503039455, 0.17594165258830594, 2.7271359726305935, 12.772965085121895, 9.924114288822297, 1.1807942390441895, 22.503198577511696, 53.66786126167544, 60.906540501502256, 55.62871686873898, 57.56165304491597, 47.76003045420493, 44.815648371173495, 41.75471305847168, 45.281590646313084, 47.587532458766816, 50.22538131283176, 53.32564623125138, 55.827486899591264, 54.09685873216199, 52.06014056359568, 47.50125992682673, 50.44614407324022, 52.1616554260254, 54.914025722011445, 55.00080031733359, 53.809643176294145, 56.78247813255557, 47.5429468770181, 44.39587239296206, 41.62646724331764, 42.294337057298236, 43.873447987341116, 46.34712603784377, 45.23775815963746, 40.33334024490849, 42.10842063350063, 40.76267896160003, 45.230760651250044, 43.08409452438355, 41.02597198178692, 42.95744903625981, 41.58122662575015, 42.3404876647457, 45.17833817389704, 41.12429403489636, 42.64436937147572, 41.93213362847605, 42.090350274116766, 43.093437610134, 42.383625891900834, 43.459284920846265, 43.31564772513605, 45.62307611588509, 42.571997719426314, 43.14363218122914, 42.31961673305881, 42.31297616035708, 44.67753779503607, 43.69871031853461, 45.738986076847205, 46.48354607243692, 55.20828977707894, 56.06760263442994, 57.03588677990822, 56.850586168227665, 56.42659364208099, 59.219415341654134, 56.59513396601523, 55.187740479746175, 55.95578370555755, 48.60966290197065, 42.9031712778153, 42.679160794904156, 40.84550765252883, 41.26077682741227, 42.641596255763886, 42.569730589466715, 44.28494384211879, 42.74980660407774, 42.102744963861284, 43.74244082358576, 42.74224819675569, 40.719579958146625, 44.44078745380525, 41.3233974672133, 40.098806042825025, 42.774847015257805, 41.847834048732636, 42.11023669089041, 42.918558736001295, 41.08276790188205, 43.65395999723866, 52.877123202047045, 55.36298413430491, 52.556041902111424, 47.92043186003163, 46.06948106519638, 53.530346885804214, 53.58205941415603, 52.59103336641866, 56.08065235999323, 53.691458240632095, 54.178134164502545, 55.52516237381966, 52.86110424226331, 53.47855198767878, 52.2805267764676, 50.12120316105504, 48.07551060953448, 47.39961562618133, 43.89981023726925, 38.744654809274984, 38.68667041101764, 39.72585139736053, 42.085129599417414, 43.00146979670371, 46.04699019462832, 45.43243715840001, 50.27231247194352, 56.84475360378143, 60.806045455317346, 60.213798938259, 54.72437912417997, 16.330555812005077, 0.9208465716050518, 7.018622996345644, 19.06298379744253, 10.756427511092156, 3.330267066917112, 0.3549767988583734, 42.826547776499105, 70.19032785969397, 53.63142244277462, 41.999304217676965, 49.02506151506978, 55.40721670273812, 59.52542297301754, 25.027963538323682, 0.40354959246131683, 0.16303489435343974, 0.16037580316826222, 0.2142133368479629, 0.11322606384994523, 0.30773013409587646, 0.12874594799453212, 0.13300064710840104, 0.16725841368879044, 0.10155225518129526, 0.12134510963674515, 0.09897085297251902], [0.029501906152994885, 0.06920501995351046, 0.03534668395596166, 0.015336635913099013, 0.08667550184914181, 0.03600865287045318, 0.0570673335553898, 0.00894684209338119, 0.03912224869934782, 0.0297017670011208, 0.034066926417571884, 0.05125071522929976, 0.04939497065460009, 0.011164369775102505, 0.030026435063430862, 0.8331225175530681, 20.050111009228615, 48.27408452187815, 33.99999895403462, 37.795554976309504, 37.43253961686165, 30.574051795467255, 47.00748843531455, 51.39992721619145, 54.7464346116589, 35.140318255270685, 0.18758320129446446, 0.10871660219685686, 0.8982439747741147, 3.09068575501442, 0.7276980326541009, 17.938608930956935, 54.16324092495827, 54.57342670809839, 53.65782783877466, 49.874686118095156, 43.154618740081794, 39.03359620801864, 41.5288669063199, 45.48140402763121, 51.313348739377915, 50.406857613594305, 54.968448608152336, 48.55111368240849, 45.200448574558386, 46.59282330543765, 50.983453873665106, 49.69830889855662, 49.213123475351644, 49.24408274312174, 48.367636972858065, 48.89726285011538, 45.44884443283082, 42.38885441134053, 39.38225177026565, 37.36817744470412, 37.14977595113939, 38.816069403002345, 35.32696423992034, 36.59089703713694, 38.981942515219416, 38.2772377229506, 38.26373300244732, 39.78272184248894, 36.92046242375528, 36.71098824470274, 36.395155076057684, 39.54806996930031, 38.82295708502493, 39.03375702519571, 39.125352213459635, 39.74216453490719, 38.22453283494519, 38.90637413147957, 38.38900958338092, 38.56458271703413, 38.50736710333055, 37.45212008876186, 38.64610918106572, 40.90400588127875, 41.33746308665122, 39.166411584423436, 39.98104472314158, 42.09189568796466, 41.55581358940371, 43.33220012726323, 46.407648209602606, 51.37885232125559, 53.944639390514745, 56.0572083534733, 54.44270979973578, 50.843664523093935, 55.52581740963844, 56.39262983875891, 52.166370114972516, 49.95806001847791, 45.409130434836115, 40.33686253332323, 39.233872429017104, 38.60374366083453, 38.0842924118042, 37.65539300057196, 38.55423942688973, 39.952262370817124, 38.38174927619196, 37.22546592835457, 37.837571405595355, 37.975317201306744, 39.069980113737046, 39.62152419551727, 38.00648435469597, 37.800077469118186, 37.9515633275432, 38.27829676289713, 38.3838124429026, 37.775852910933956, 35.907125934477776, 37.546229516306234, 47.23142439319242, 48.758732580369525, 50.79407007463517, 48.054184682907604, 45.97519905336442, 47.3637455509555, 50.48514419986356, 51.24035343047112, 52.0409405616022, 49.77680337044501, 49.85609800584855, 53.57587383639429, 51.947768580529, 51.192578961772305, 49.798721574967914, 49.747338525710575, 50.90851306915284, 51.495601669434585, 50.25286536062918, 44.870204617900235, 39.113122263262355, 38.220253529087195, 36.8076511352293, 40.90639068234352, 41.37191718624484, 40.82538589354485, 46.49487387749457, 51.05789653716549, 54.81219314759778, 55.943526298769065, 48.15968075106221, 9.268638183993678, 0.8041061100459869, 6.194510469513555, 8.695221985540083, 2.7663290308367823, 0.43853845206960557, 0.39364533198456614, 42.086235707806004, 53.85693519346176, 42.399115331711315, 25.14626810627599, 19.40853088132797, 37.793397672714725, 42.73577236360119, 8.634925350066155, 0.08220318013862257, 0.11973613347377508, 0.030325914154790586, 0.0264530734819991, 0.016327465306066217, 0.06595224893141179, 0.025636454398233085, 0.0343330423798292, 0.039312069965226036, 0.045443515954238754, 0.03309538520331825, 0.02598056960250101, 0.04575248687498031, 0.07185147068793736, 0.028807560447603468, 0.0033707394651437722, 0.04994197658473446, 0.04954161903550548, 0.024716922893158855, 0.03442536746602386, 0.042535637715651144, 0.031630406757035566, 0.058887378432818, 0.04043012549499831, 0.010134458406678131, 0.02346421974981504, 0.03674139681782934, 0.9957735865346848, 26.435202090970932, 56.57909539438064, 45.04881366606682, 40.394537064336966, 42.629970350573146, 39.33135509490967, 54.0665505778405, 55.30288165615451, 59.94135110608993, 36.24921937142649, 0.21263214669400649, 0.4080762834318223, 5.228542483622029, 4.557560759205972, 0.8952679376929038, 19.44297713618125, 54.646100382651056, 57.000220667931345, 55.80503133035476, 52.579662415289114, 45.463984781695956, 41.95185922807263, 42.04867901340608, 45.94393776309106, 53.07717584794568, 52.14233383055657, 55.22907049425187, 51.775074466582275, 48.02840686613514, 46.241849622418805, 51.12496514474192, 52.965674631057254, 51.67276336300758, 50.92738359205185, 50.77305793762208, 50.095217458663456, 46.06231881726173, 44.83070242789484, 40.09500134375788, 40.473160974441036, 39.683376050764515, 41.41836197145524, 36.573348352986, 37.68926266700991, 41.239592106111594, 38.68586240276214, 40.18508249713529, 40.5388371406063, 37.53878485771918, 39.72575333810622, 38.03449400009648, 40.72352586253997, 39.53180782256588, 42.41259259562339, 41.6252395414537, 40.14968310633014, 39.752029295890566, 40.329504166879964, 40.410775676850356, 39.9855476040994, 40.989050711354906, 40.715924309146025, 40.556491728751894, 43.254905900647564, 44.493460962849284, 40.964237797644834, 42.4632578511392, 43.37720540262038, 44.37391104236726, 45.39331936067151, 47.8429768162389, 52.68807672685193, 55.757849139551965, 57.1879727609696, 55.26598391994354, 52.272211351702296, 55.59420785596294, 56.88550310750162, 54.803297212046964, 52.24091476009738, 47.28207788159771, 42.8286030984694, 40.00702258079283, 40.569482618762606, 40.57053381396879, 40.13997916252383, 39.84177312543316, 40.0755738442944, 39.380706356417754, 39.52357476757419, 39.07156082891649, 41.604478436131636, 40.90557482934768, 40.24512221736293, 39.566293301120886, 40.48899950519685, 39.48152695932696, 39.758450215862645, 38.748930192762806, 39.082139461271225, 37.574482348657426, 40.113373725645005, 48.831131689010135, 51.70120446912704, 51.29521169970113, 51.060755945021114, 46.57189353819817, 47.99705536134782, 51.45191038808515, 53.14192633475027, 53.04975848044119, 51.51629217209355, 51.682479073924405, 54.383015248083304, 53.72402175780266, 54.71616960340931, 50.517495909044825, 52.338605311609086, 53.90114030530376, 52.687005919794885, 51.40613632817423, 45.64348028552148, 40.707193113142445, 40.78227512298092, 39.010685643842145, 41.56216782908286, 43.36915669902679, 42.44936481598885, 47.97770238691761, 53.64784148431594, 57.41522312164307, 58.146247017768125, 50.55586845644059, 11.464074080990208, 0.568178424671773, 7.034867982710562, 10.036588253513461, 5.756485664075421, 0.3904908270605149, 0.39624331999690304, 46.50256172303231, 58.472447010778616, 48.01020314616542, 29.680249537191084, 24.50578428083851, 44.30463414038382, 50.46128049973519, 11.963132927494666, 0.10600378526554954, 0.046417830406778285, 0.07709160402056671, 0.022917499187432473, 0.03347069550786288, 0.07730659127475754, 0.04539352488673983, 0.030828714896474155, 0.03192363648615297, 0.01315016735104784, 0.030070282105777054, 0.0544421264391032, 0.11967778055658264, 0.2261597272609511, 0.09777213221475964, 0.06706627866914196, 0.194630490075196, 0.2147771928819918, 0.21261984332194253, 0.08538645932510977, 0.22076432322782857, 0.18805486630768548, 0.1704653496703794, 0.1664679794902763, 0.15132151724350068, 0.22191127942454433, 0.13531481486655053, 1.240142886677096, 33.549761849064986, 64.00488738090762, 48.76196461339151, 50.226538412032596, 49.01189804077149, 43.199012125692065, 56.85480663853308, 60.05427222098074, 63.75310259480631, 43.56794241935977, 0.3981250464435547, 1.0177354274257537, 8.876955201548915, 7.991752739875548, 1.9815345877601256, 21.59516792143545, 56.50453505977508, 58.414721488952644, 57.24066980423466, 54.665606329517985, 47.536988796726355, 42.79231332963513, 45.390216765865205, 48.66628231540803, 55.69507944968439, 54.77827249034759, 57.57842902214297, 50.26436574997441, 49.68873831533617, 48.56408496056834, 51.85810712076003, 54.414637396412516, 54.79503670046407, 52.77781663402435, 52.8868624471849, 51.608079556495916, 48.0889682615957, 47.824486763246604, 42.5268316268921, 40.529870602392386, 41.119002757533906, 44.55689745564615, 38.235550772759225, 39.72929523837182, 43.707645477787146, 41.83329382250386, 43.94261114058956, 42.82424142283779, 40.89644355158652, 41.377349668933505, 38.615216593588556, 42.2704968913909, 42.02354446534188, 44.38427394436252, 42.401237333974535, 44.18512736597369, 42.06681997545304, 42.46166929121941, 42.81664771418418, 42.04518418158255, 43.020285406420314, 40.35687446594238, 42.763362315393266, 45.24599121462914, 47.6403118718055, 43.14603267177459, 44.92376458260321, 46.990877197634795, 45.48435757237096, 48.94104826834894, 50.17279801830169, 54.22738344438615, 58.16258368953582, 57.4851119133734, 56.22939255929763, 55.068233705336056, 58.406802223574736, 61.069616963786466, 56.48231483274891, 54.03212393483808, 48.79999591458229, 44.409400647686375, 43.55160966996224, 43.03450007592478, 43.98149359610773, 41.33694533378848, 41.932925947250865, 44.05759542219101, 40.8123283232412, 41.681623612680745, 40.33227728259179, 42.5021206948065, 42.82159774534164, 43.09899168629801, 41.016719110550426, 42.421594435168856, 40.99119624783916, 42.03767284270256, 40.489831047673384, 41.881213418899044, 38.29972467114849, 43.0360141108113, 51.37916218849921, 52.080595724044315, 54.801010470236506, 52.84994509912307, 49.64694153877997, 49.97683640449278, 52.10276888262842, 56.4642091720335, 56.43081803475657, 53.27426710436421, 52.791187993941776, 56.97918891906739, 55.52908474399198, 57.416325307661495, 52.49087956643874, 53.79007054913429, 56.19990418034216, 55.33458225188717, 54.08955135653096, 49.5443715587739, 42.348716797367224, 43.43922199741487, 39.935694279209265, 44.98173329137987, 46.76100277131604, 44.51623816643992, 50.36018925328409, 56.435120874835604, 60.02124586412984, 59.849085192526545, 51.28566072833154, 12.663944767367456, 2.7497180383051596, 14.107596643509405, 16.632328264174923, 10.40769644321934, 1.7787343215557838, 0.6156414326640868, 51.67410873597669, 63.2849520252597, 53.84021020704701, 35.68875581987443, 30.22639447642911, 50.658536495700965, 58.482829524624734, 14.388964926042865, 0.23457460556059118, 0.1953040192564649, 0.1509625744074583, 0.24526622056240038, 0.14458440214155183, 0.28404585175937225, 0.20236033255294447, 0.15592709994844853, 0.09920800315035928, 0.10051507172324967, 0.0645459566505686, 0.1370720520255066], [0.08013982956688251, 0.03229496504871115, 0.023268892226981062, 0.028733694249944344, 0.05224192958144892, 0.037362621346068, 0.05806400628399946, 0.042785098926434596, 0.012076498955608377, 0.12783601940158876, 0.08286177826624724, 0.08508061404309927, 0.033976788512401046, 0.009448576057630201, 0.04156387050545985, 0.05582506069913507, 17.491564635307558, 41.799683032497285, 42.06341928051364, 49.655409935982, 64.41060950679164, 49.84649604366672, 33.17166889867475, 57.77992510026502, 46.68858797319474, 48.345659932782574, 2.112047532873769, 0.23721039235111208, 2.4947642222527535, 1.8051733028504158, 0.7267904329684474, 19.86335127584396, 53.48150945478871, 54.77335383815151, 54.002200172793486, 50.500488511977665, 42.330477776065955, 40.822110714450965, 43.30514754018476, 50.7647660470778, 48.80394574134581, 55.83947366283786, 47.91134765071254, 41.0486432813829, 51.1082205464763, 53.30379862939158, 51.0228854610074, 47.760712946614916, 49.11447978788807, 49.01785612106324, 47.328950205156886, 48.81200228967975, 45.29835093405939, 44.2375066972548, 38.840446933623284, 37.664304625603464, 37.21723679573306, 35.43023240181708, 37.45849786266204, 37.63340419338596, 38.129721303139966, 38.25275036596483, 37.65478111082508, 37.0994911655303, 37.427758247621604, 38.14301421565395, 37.936732845921675, 38.685246590645086, 39.454297865590746, 40.13349156225882, 38.43909040574105, 37.85641447190316, 36.41402167658652, 38.230432079684356, 40.11085164162421, 39.92105599372618, 39.20457624620007, 38.98348008432696, 38.67649186042048, 39.41337577758297, 36.636188645516675, 38.15848404361356, 40.698363857884566, 40.03094119410361, 45.8105222640499, 49.17648069320187, 46.47282231238581, 52.27749870669458, 52.628084075066354, 57.414619076636534, 50.0319064817121, 49.25657941449074, 54.82377590671663, 53.732431319452104, 56.29481769377186, 51.3975973283091, 45.862874138739805, 40.86180902296498, 40.40022057871665, 37.32038336415445, 37.643410159695534, 37.09455682385353, 39.33702291980867, 38.63761724964265, 39.98881886082311, 38.31248414131903, 38.57582815231816, 39.58747017768122, 39.22534127389231, 38.22889843294698, 37.71925703171761, 39.224745073626124, 38.28530211602488, 39.24770662861486, 39.32362802567021, 39.968195038457075, 38.05112877199727, 36.94266303893059, 43.40128483310823, 48.56301023114113, 47.44113783682547, 48.6061563030366, 52.11146869967061, 49.869998885739236, 47.74112462997437, 50.04028466440017, 48.54797970864081, 49.11512305659633, 49.72019964648832, 50.65771279796478, 47.74833394635109, 51.318691007552616, 50.62283900476272, 52.13230433002595, 52.87928835038216, 51.97166365961875, 51.15708543408302, 49.79335969494235, 49.77584238975279, 45.53771357382498, 42.703389275458555, 40.1416265579962, 42.4643051239752, 43.3618297115449, 47.39351634056338, 52.356146151019686, 55.34248975015456, 56.19074152361963, 43.11903892024871, 6.418862688925959, 0.1518431005458678, 6.356261660975795, 9.4692595735673, 3.5289937065493677, 0.08555954923072169, 1.0935793576701995, 45.81815127403506, 51.05309947844475, 38.97230525170603, 29.212973656192904, 34.49755161039291, 47.01974584210304, 36.45117828922887, 1.8091730172595673, 0.03459395660508064, 0.014101460861462741, 0.0237760002980189, 0.05299464161057146, 0.005335301083828053, 0.09789911894908837, 0.057874820871098395, 0.06884138865937149, 0.11014596138510013, 0.05917663791126782, 0.0317106104170483, 0.04370441209645041, 0.1190286742583398, 0.028886270236163854, 0.04051691176550042, 0.0035369355370470836, 0.040895784378892956, 0.0366301033946295, 0.025693309613533562, 0.069345788609597, 0.07060637096724204, 0.04845134951474686, 0.026109067445260384, 0.02809705603266916, 0.02354552657643874, 0.017350162041463682, 0.03046588224899625, 0.11099644921599858, 22.77664073051945, 51.59365307900214, 45.123362233561856, 50.31405825768748, 53.78234347989483, 46.98255785049931, 43.29188600663216, 61.12087841956847, 52.13299074480611, 51.60026227274249, 2.064851123479105, 0.4900779671246006, 4.4340590507753435, 4.297681671957816, 0.926295601792874, 22.146158949021373, 54.83756696024249, 55.75530352131013, 55.51510149432767, 51.43567962031211, 44.66430371807468, 41.845359033153905, 45.79298926937965, 52.18095348727319, 52.493695828222464, 56.04117762657904, 51.108502957128714, 44.27470253359887, 49.56872947754399, 54.31389916327692, 55.549437922816125, 50.64078777067123, 50.940790253300825, 50.904975091257405, 49.97427901914043, 50.488007530089355, 47.949516234859345, 46.91916842614451, 41.154072669244584, 39.11848806565808, 38.77829697824294, 36.97762704664661, 38.38734649842785, 39.18334445645733, 40.32138486062327, 38.46986532211304, 38.499855764450565, 40.12087329741448, 39.51387082376788, 40.949811320151056, 39.84585631278254, 41.28529948572959, 39.69780252825829, 42.187550529356926, 39.739799345693285, 39.12521885287377, 39.40275399915634, 40.651299338186945, 40.501205921173096, 40.57273426363545, 39.952097631269886, 41.01885287992416, 41.26942565364223, 41.12612185939666, 40.38949681866554, 42.156493202332534, 41.53643708075247, 43.865948415571644, 46.77088714415028, 49.52125310897828, 48.04195865508049, 53.080058790022335, 54.22656366902014, 57.069980021445986, 51.34410404389905, 51.84943476030904, 55.581173819880334, 55.57500785396945, 56.99497253664079, 53.74051924674742, 45.88917755311536, 42.77645518702846, 42.10372947877453, 39.181869645272535, 38.891237704984604, 38.7171236930355, 40.788272426974395, 40.492396277766076, 42.42472448656636, 40.60603910876859, 39.04193908937516, 42.10099166439426, 40.93876592574581, 39.9278260046436, 39.51013280499367, 39.438400499282345, 40.54354398481308, 40.00020157906317, 40.30978641202373, 41.470058810326364, 38.80149387544201, 39.22118356150966, 45.2125177075786, 50.5478472094382, 50.95398902893067, 51.14977021371165, 52.642843954024784, 50.57047928533247, 49.794493259922156, 50.53149092581965, 51.94511313592234, 51.734270049679665, 51.0211282391702, 51.156332339009936, 49.65153071188158, 53.256471310892415, 53.86605862648257, 55.07251301119405, 53.34383426174041, 53.69280753597137, 53.22977565949964, 52.92297178699125, 51.01473477578933, 47.17176906524166, 43.61964318060106, 41.13826943982033, 43.90795307774698, 44.325661966877604, 51.92010018133348, 54.41708495540004, 58.22042688246697, 57.02156620640909, 47.015552828388834, 8.041246187302376, 0.48194937588226416, 7.7106251928114125, 10.542220992426719, 6.702719715333755, 0.22642638714563465, 1.0860280596440839, 50.94197088672269, 56.07356071472169, 45.576572495122115, 33.06313299363659, 33.377510962947724, 50.27130442280924, 43.481356097805886, 3.1752459272261593, 0.07191995128748879, 0.04486498167558063, 0.08233191355341866, 0.08740607393725265, 0.028181074810544812, 0.0328593994791229, 0.08773785129550003, 0.07098036743099652, 0.06139869891828107, 0.09278264752919636, 0.023105665703394243, 0.08937924063854641, 0.18115598407964553, 0.16148016487638797, 0.13539419689726445, 0.08166237569023525, 0.21539521133226736, 0.11359829065059462, 0.20975669695725366, 0.1333623785044878, 0.14547959120283205, 0.20282061349961067, 0.1373492839235452, 0.19831532702570964, 0.07888715323661605, 0.09997820496679315, 0.1203317361913862, 0.18668493255972865, 26.407918084052305, 59.04269295354044, 56.51767499985234, 62.144973970228634, 71.51206462613999, 58.655704067599395, 44.31596979018181, 68.43829139586418, 55.1485481569844, 57.190765488532286, 2.94437914125381, 0.6854803980358186, 8.692819533809539, 6.873020202882829, 1.543175155116666, 24.147105101616155, 57.640300489241085, 56.94371500322896, 57.29817175096082, 56.28244653824837, 46.794040895277455, 45.40238003576956, 46.63178028598909, 54.874335258237785, 54.25647174158404, 58.09062780872468, 49.672087853954686, 45.11254825899678, 51.76281705979378, 57.90413479651175, 57.55882109365156, 53.50828747595511, 54.1175570795613, 53.00683206127536, 54.064695296748994, 54.084303225240404, 48.85914525678081, 49.669055861811486, 42.938527522548554, 41.24453429252871, 40.4021543072116, 39.544994831085205, 40.99127077287243, 41.10211695394209, 42.332595855959006, 41.137598714520855, 41.29511325590072, 42.01034568971203, 41.92340635484265, 42.41354573157526, 41.66330614397603, 43.20135770305511, 42.417052330509314, 43.1184034962808, 41.6710606698067, 40.86018123934346, 41.52985926597349, 41.13338608895579, 42.75849073163925, 43.72396646007415, 43.37961766027635, 42.170186196604085, 42.48855321638046, 43.02715739896221, 41.740078695358775, 42.83416501937374, 44.181338356387236, 45.25301225723759, 50.02573267106087, 53.76749338642244, 48.86046317315871, 53.90956947880407, 55.99756087026289, 58.61360134616975, 50.56383871263074, 53.548601596586174, 58.027120713264715, 57.6294590580848, 61.14891944393035, 55.01510520135203, 49.433509688223566, 46.50378550252607, 44.66558633312103, 40.96262570350401, 41.39207032419021, 41.59340166276501, 42.73228537651801, 41.861668248330396, 45.14073833342522, 41.106757117855935, 41.65947791068785, 44.66214249210973, 43.05286461307157, 42.89603256410168, 41.732449685373616, 41.619403054637296, 41.532581390873084, 43.24423705377887, 42.449608002939534, 45.179816907452, 41.445367490091634, 40.67826563312162, 47.832386416773645, 54.542145805974165, 52.82225708807669, 53.52161568980063, 54.93282171987719, 53.77018413236065, 49.546772049319365, 52.20809628886562, 52.8294389478622, 52.27992665383124, 52.17880402841876, 53.263476664020175, 50.391615283104684, 55.98929643630982, 54.90724394398352, 57.66862784662555, 55.549077064760276, 55.56014207101638, 57.246553359493134, 54.540435652579035, 54.22794434332079, 49.96941920249693, 46.21980590205039, 43.83905272330008, 46.421231377509336, 47.7742882697813, 53.023317783109604, 55.80256415951637, 60.70243212484545, 60.29922423824188, 48.69866932592085, 9.895658473814688, 0.6547753488825214, 13.402671217918398, 16.47661997425941, 12.570488414456769, 1.866322808688687, 1.3693279869133428, 56.00667253617318, 60.71318334148776, 51.55229953027541, 40.653335048306374, 46.02327946693667, 59.377408412195024, 52.10057627770209, 4.613041214404568, 0.17852594294855673, 0.15189798308476327, 0.24457203765069288, 0.1960003318926019, 0.10738005456064018, 0.18121615262521854, 0.13158922203846518, 0.16891549251252608, 0.17272461956787497, 0.22092618228447056, 0.08288145140414277, 0.14157372256440504], [0.008185863017945761, 0.054919349420214855, 0.020064062987183853, 0.013873477883246398, 0.030669992969882105, 0.023228527054250724, 0.08014416562453394, 0.025053681738133875, 0.04545715998017019, 0.028334422630348036, 0.021771952592497392, 0.020848831965497906, 0.0889154663309455, 0.040834190909780806, 0.011700658135176187, 0.025428509407286203, 6.533360106329765, 42.121674322312884, 40.73859953111218, 52.12394968155892, 58.321067056348255, 66.21586861148958, 41.759996491093794, 48.53389447735202, 54.768066483159224, 48.27561424624536, 5.796906669293681, 0.525843364096457, 4.378732548606012, 4.018850672629572, 0.4122201143012893, 17.41702195136778, 51.901355174279985, 56.49266204526348, 53.84963566257108, 49.38726102152179, 43.667609845438314, 40.51179239826818, 49.62279935036936, 51.26731972540579, 54.608716272538715, 54.681970457876886, 41.364837308083814, 48.690899110609486, 52.16889612136349, 49.402366069055375, 49.078468507336034, 51.203365479746175, 47.454179717648415, 47.23896318866361, 47.753370269652336, 46.22755650551089, 47.35518693923951, 44.17233651684177, 40.906382837603175, 38.32469447966545, 40.13886913176506, 37.85819522796139, 37.33409989264704, 37.42098039196384, 37.38504755881525, 37.5023264269675, 40.57981806416666, 38.65195743499264, 37.01414039058071, 39.405076042298354, 39.1214180761768, 39.02987387872512, 41.29976518692509, 37.93592483766618, 38.12664616492487, 37.674906792179236, 37.09507457671627, 38.84221984494118, 38.809954427903705, 38.24509389938847, 37.220080514107984, 39.43212470700664, 39.248118477482954, 38.55638104100382, 39.22591393993747, 38.579421043395996, 39.12038649282148, 43.216537275621974, 47.607003104302194, 49.500758724827925, 52.085785019782286, 50.86511204319616, 51.895487308502204, 55.30426233045517, 46.98516230429373, 48.9478692700786, 51.97669213817966, 52.90924349138814, 53.34181816347184, 50.28187521042363, 46.4244673329015, 42.038061157349624, 39.898525899456395, 38.74161497239144, 37.356586840844926, 36.38673374729772, 39.46866158516177, 40.563889318896884, 39.956306334464784, 37.442467135767785, 39.23073845524942, 38.949124043987645, 38.96419379018968, 38.81714805479973, 40.046960153887355, 37.95079454298943, 38.167179938285585, 38.28097966409499, 37.231223967767534, 37.86591837483068, 37.6469285257401, 36.496081582961544, 40.02397114230741, 45.73835065287929, 46.2816499125573, 48.08860740353985, 50.34136187645697, 50.17845407609017, 50.973275323067945, 50.79030852163992, 50.97344790735553, 51.54282700630927, 51.26204021515385, 52.15844300485427, 48.542249125819055, 47.574125797517844, 47.7284396848371, 46.81319382882888, 49.2453065226155, 50.798737695140225, 53.52900543520528, 51.86733645777549, 51.4372956368231, 52.45331894966864, 51.27760810236777, 46.364964977387466, 43.07677538164201, 42.89496567941482, 47.53102679406443, 53.17213250744728, 53.50861695504958, 55.17273349146689, 40.960331116953206, 4.6414171111199165, 0.4741838490290027, 5.75193424378672, 8.741509875943585, 3.62813774135805, 0.010062901006500808, 2.0029588187894514, 48.863259823091575, 48.651087053360484, 38.676244751099624, 24.577999038081018, 29.672185144116803, 47.2963043182127, 29.757992875191476, 0.6693598856368373, 0.0737852221655269, 0.16064511371716378, 0.07236010710438413, 0.012036832838108944, 0.0035457989349285323, 0.034808602950145165, 0.02392988246414931, 0.05475222350909345, 0.011311901072340627, 0.02852091524419525, 0.09705388648135048, 0.035704125259672446, 0.028221290596129916, 0.0700856456833501, 0.021749119341914213, 0.02172207069252768, 0.0468707952137676, 0.03502815991880433, 0.07265551826886593, 0.09510794654488565, 0.017734448981261062, 0.02771634672347817, 0.03266856697718463, 0.029796152863831773, 0.014581661051770133, 0.08888821658347884, 0.031336091098285494, 0.028251658321448395, 10.909159702639426, 48.96626518618677, 48.26530233506234, 58.45963654979583, 63.13171286736766, 64.93806631334367, 43.08156851799258, 56.41605815579815, 56.94055357287007, 55.46055309234127, 5.475441467377448, 0.43431703181516745, 4.361251035044271, 5.573378147617464, 0.5662829392860013, 19.70328131029683, 53.16020065738309, 60.277443316675004, 55.61179576381561, 52.330031010412405, 44.95939539324853, 43.329764335386216, 50.06231661765806, 52.34111562851937, 53.95546905456051, 57.07622443476031, 44.43071480720274, 47.41983936678979, 53.357625315266276, 50.17894437236171, 51.18019211676813, 53.650253741971916, 49.28524017333985, 49.67177798671108, 49.47232938581898, 47.3668481457618, 48.0636062160615, 47.02661391227476, 42.5533821505885, 39.19315038188812, 41.959617676273474, 40.211174103521536, 39.0977857958886, 39.49226248648859, 40.55174173847322, 39.61408345930038, 40.569184518629505, 40.63145214511503, 39.31514001661731, 40.6345155162196, 41.15313914514358, 41.163180412784705, 42.658462447504846, 41.065356500687145, 40.10088097664618, 39.62390115184169, 38.46394254315285, 41.121960224643836, 40.20603187622563, 39.77395534515381, 39.712397667669485, 41.135472789887466, 41.7379919944271, 42.17947044680196, 41.532773587011526, 39.89692949479626, 39.926461019823634, 44.76297486212946, 50.063308977311664, 50.69165306706583, 52.022521111273, 53.8318084901379, 53.53308077781431, 56.199060870755105, 49.52421449845838, 49.121536131828066, 51.78693963635353, 55.82401167961859, 55.64696373478059, 53.915488335394095, 48.06290411180066, 43.77178015247468, 41.85360385525612, 38.71289145561957, 39.00161320163358, 38.93784330737206, 41.080759648353826, 42.100462144420995, 40.01158037493306, 40.22775003986974, 39.34964118465301, 40.539900102923, 39.24518062222389, 39.92220917055684, 40.352912872068345, 39.22041869932605, 40.149847845877375, 39.44953218583138, 39.02508074237455, 39.78576952411283, 38.58257070664437, 38.53418434819868, 41.72571889815792, 47.85014298654372, 48.716853434039706, 50.09273459834438, 50.82156196717293, 51.3869127919597, 51.78316631624776, 52.219047546386726, 52.483230944602724, 52.291062262750444, 51.00854919802759, 51.80970899520382, 50.733057606604795, 49.78147491332024, 49.06833310281077, 49.58268527061709, 52.82204528008738, 53.32530890741656, 54.63001866494456, 55.09387031678231, 53.2804605268663, 55.00280072612148, 52.893095093388716, 46.99246967992475, 45.7802023426179, 44.730148546157345, 51.01329134356592, 55.673271071526315, 56.873339837597264, 57.1961626698894, 43.864642266304266, 5.953038575187807, 0.7645523163580126, 9.421326248876511, 8.344890590636961, 6.33181695976565, 0.12892245465228636, 2.417031180474066, 55.13137602037, 52.622392715946326, 44.49808151491227, 28.4888001795738, 34.92362691510108, 54.45039764527352, 36.71032536414362, 1.561370907771972, 0.053734058183768106, 0.04574141307403484, 0.04620206557334431, 0.053977766074240215, 0.011989137161553148, 0.060781201407794035, 0.03025245398373133, 0.03757395053042039, 0.029617527972966916, 0.012682381615553413, 0.06641721067529532, 0.05565074888328391, 0.09942112115001488, 0.12013728775444532, 0.10437078458527405, 0.13242364500559148, 0.10203896616134914, 0.1443694531917572, 0.1454637791480749, 0.14224565828279143, 0.14383866151254024, 0.1295810451190318, 0.07938521763970775, 0.09274040544105154, 0.18060213315390772, 0.20763406650193278, 0.13069715861591602, 0.18952043847210948, 13.046871058402523, 62.4270002303585, 54.73557749102193, 62.724421793414706, 65.27884183391448, 71.6557724245133, 52.756247520446784, 57.786953987613806, 62.59868629517094, 59.90808156228835, 7.354103317183833, 0.9423198935485656, 11.451280290080655, 9.69535969918774, 0.9219311069576972, 22.24223348402208, 56.02668839116251, 61.77645552542902, 58.31166121267504, 52.395424765925256, 47.866773836074344, 46.39729707471786, 53.991346974526685, 55.11516486444781, 57.79314741011589, 55.601444628930864, 44.88174423094719, 48.65535851447813, 55.35214270314863, 54.10042024427845, 54.03879980887137, 55.19593431103615, 52.033389999020486, 52.08927200686548, 52.733270275977354, 50.653845340974875, 50.46481847763062, 48.885311388200336, 44.588354864428126, 41.522936282619355, 43.65946308259041, 41.84856360958469, 41.980316023672785, 41.910180122621604, 42.470090619979366, 42.260196747318396, 44.76611275826731, 43.0185438740638, 41.11123646459272, 41.95082372234714, 42.47801380772745, 42.96707845503285, 44.45414312424199, 41.289033582133634, 42.49264817084036, 41.22642078707295, 39.04224895661877, 42.250987022153794, 43.14333015872587, 42.038218052156516, 40.00459463365617, 44.384940747291814, 43.73258390734273, 43.26444510490664, 43.46503511551888, 40.75022151393276, 41.99278916082075, 46.83239775319254, 51.19006080012168, 53.244202136993415, 53.24710469092093, 54.634227368139456, 55.656440181116906, 57.20045766522808, 48.883958170490885, 49.797278142744496, 53.316656158816436, 57.624128557020626, 57.16817263633975, 53.47450410166095, 49.355693786374985, 45.209403345661784, 46.00265956694081, 42.79349004068683, 40.79942372537429, 41.50617207250288, 43.95518625936201, 44.47445707936441, 42.367030343701764, 40.5437675599129, 43.32618713378907, 41.91702073620212, 40.578574672822036, 41.339126171604285, 43.39540127784976, 40.95830325157412, 42.17749357223511, 41.53435430219097, 40.187106440144206, 41.1880600067877, 41.578488811369866, 39.94888128772859, 42.30285252294233, 50.27051994877477, 50.04522292844711, 53.39416611579157, 54.13568627449774, 54.9491701587554, 54.09521918142996, 55.32324660208918, 55.161656718100275, 54.16057371324109, 53.799009630757, 54.88905591349448, 51.603180516150694, 49.703753148355794, 49.319447163612615, 49.75186101851925, 54.12497820392732, 54.009585995827955, 56.0023343947626, 56.55203104019166, 56.505452894395404, 57.24885579078429, 54.70187648650139, 50.65155467679424, 47.91251651702389, 47.08649281532534, 52.69243448011337, 58.258156161154474, 58.48431610292005, 56.839693746259144, 45.5391413165677, 7.765691837956829, 1.2897331676175519, 14.924321386121935, 20.582400175832934, 13.118860279360126, 0.8334307300467646, 2.602388176225847, 62.100188347601126, 55.47447358408282, 48.83499522362986, 34.84532463935114, 40.76947642910866, 58.81768618860553, 44.89674337448613, 2.186767213767575, 0.17408532961722345, 0.20847817282042197, 0.18808920236845172, 0.18632879360548912, 0.16792883255308674, 0.16657262710073303, 0.11762448871928839, 0.2548453226805695, 0.10563423211175589, 0.11794921040775315, 0.22375174437559422, 0.20965109939777085], [0.08164267190882275, 0.04070311326593642, 0.01948707046047334, 0.028345506007392562, 0.03936005388236335, 0.02514633815735579, 0.012214955941383398, 0.06399926481648319, 0.0009570893845164158, 0.02409933728256053, 0.027743182783465714, 0.06490211858744584, 0.04074982547711942, 0.01159430789430776, 0.0625084423940749, 0.0719769941943307, 2.647260581293414, 34.902544175424886, 37.99400337280766, 33.77285057498563, 55.81746916617117, 78.62736963456678, 50.71663464269331, 46.25807646782168, 48.43309740866385, 53.210061827013575, 15.003080617996956, 0.1607708440672967, 2.9055690044356934, 3.2018655826968536, 0.11339857152873471, 11.024678407176848, 51.15727370785129, 55.218244752576275, 54.4792898239628, 49.24413765630415, 42.434330371118364, 44.3726441168016, 50.5071565412706, 50.61579835030341, 54.88024234771729, 46.15596540512578, 45.65572592519945, 51.50734916810067, 49.93094075110651, 51.390450769855136, 48.058020760936124, 47.815481001330966, 47.00165194849814, 48.64402286468014, 47.992160243372766, 49.53612281430153, 47.813237405592396, 46.882674694061286, 43.873969662574034, 38.47758846898233, 36.26059424492621, 36.263885113500784, 37.56369975305373, 38.18519146211686, 38.018529953495154, 37.70865486514184, 38.08288428091234, 37.570724718032345, 37.50270297450405, 37.82312531625071, 39.28978973819364, 38.84352207183838, 39.79886239574802, 39.12172009868007, 39.3149870441806, 36.76275960860714, 37.47675649581417, 39.67909674490652, 38.58623027801514, 37.68886258525234, 39.18113223968014, 37.6342906490449, 39.0618255061488, 38.37062543438327, 40.35965542639456, 38.96313475024316, 40.00555561434838, 45.382191596492646, 51.61944266288511, 51.306194336183616, 51.47722144280711, 54.30328915196081, 58.50190793314288, 50.38618280041603, 47.80682040799049, 50.11562162829984, 49.58288531149588, 51.46922373002576, 53.51577135824389, 52.73309769168977, 46.92314178712907, 42.085678731241536, 39.11263588936099, 38.56160171570317, 37.96107507521106, 38.601578512499415, 38.296775048778905, 38.55679288987191, 38.54936784313571, 37.455658066657286, 37.39062909157046, 38.01505865589265, 39.98526519344699, 38.105120197419204, 38.47539978642618, 39.802765154069476, 37.52710011697585, 37.95654473766204, 38.01928697093841, 38.50513919707268, 36.51827043102634, 37.410962658543745, 38.12436726785476, 43.53302940245598, 47.01489779257005, 46.95135931814871, 50.927544409228915, 50.01008241407333, 50.28083578232796, 49.22018766403199, 49.92534745124079, 49.799309930493756, 48.756363468785445, 50.71646990314607, 50.0683609900936, 52.26422932840163, 50.67051933657739, 46.03318345162177, 46.59008941342754, 47.42885689581595, 49.4670694874179, 54.98427144942745, 54.10381701684768, 49.89571786695912, 51.10335680746263, 49.66180732173305, 49.67036593344904, 45.79227147563812, 49.32032577453121, 50.23570106875513, 56.03984794309063, 50.61170339584351, 39.16490931664744, 3.469769594169432, 0.7161996044939565, 5.266128105501975, 5.661260322217019, 4.801304196157764, 0.1599271514362866, 3.9373585293369913, 50.45207861931094, 38.334280752366595, 33.51129516478508, 26.090400257418235, 28.77112061746659, 45.12670801531884, 20.378081952371907, 0.06069198663857195, 0.034397937687894994, 0.12760895860171126, 0.044133003816128745, 0.05589483981771816, 0.06011892222769319, 0.007725658201267042, 0.012067074158919916, 0.056180835761610544, 0.023312141720746315, 0.08176827968488778, 0.04760446612753215, 0.03651508678411765, 0.06315119782342546, 0.08177011063502682, 0.03326276775389429, 0.10914535096455967, 0.0283056732657696, 0.018451513024047017, 0.04589376114909688, 0.04973349341702077, 0.047329984485141696, 0.10283960465101466, 0.011715053884883322, 0.0036501300553115268, 0.02627165237021062, 0.04612327343033207, 0.02004881592227086, 0.09817917005068834, 4.2520395017439325, 45.119173142217825, 42.244275846788966, 41.63133882707165, 60.029451462530325, 74.77895967421993, 50.03072977066041, 50.62997771847633, 53.31454200129355, 55.94882542087186, 14.28890722413217, 0.3118802468863226, 2.7253812022747534, 3.9039901908366916, 0.5836803670371733, 12.75647936328765, 54.61358785629273, 55.490245434545706, 57.8553875800102, 50.23154335637247, 44.55615220531341, 46.30221097700058, 53.833655926489065, 52.292376256758175, 57.36880579302388, 48.45616094527706, 46.38031321187174, 52.15222604813115, 52.99934817898659, 52.72977152178365, 51.188531075754476, 50.51034542822069, 48.77816007983301, 50.4770209712367, 49.45389032363892, 51.88406928893059, 51.02926715727776, 48.504057007451216, 46.06250316865983, 41.74117695900702, 39.37138680488833, 38.94049875197872, 38.66048074537708, 39.45065790607084, 41.05882183198006, 39.414740762402936, 39.957749766688195, 38.48241298429428, 40.786985889557876, 40.437255597883656, 40.55974729599492, 40.85297976770709, 40.24882101243542, 39.03587902745893, 39.91878494139641, 38.44941016166441, 40.30834297980032, 40.03110201128068, 40.79357547144736, 38.55576130651659, 40.55920600891113, 40.00830519583918, 41.92659131942257, 40.76483234282463, 41.424559316327496, 40.95414161682129, 42.426995538896136, 44.843155953191946, 52.536179019558816, 53.32779569010581, 53.77412219201365, 56.01087339462773, 57.14671727149718, 53.845493639669115, 49.32451878824542, 50.04547003776797, 52.722519059335035, 54.168308627220895, 55.741943928503225, 54.065970067055, 46.29906523612238, 42.81900898102791, 41.303738547909646, 38.94867297141783, 39.73255472798502, 39.31665405150383, 39.07236099243164, 40.31156324571179, 40.20680458314958, 40.256426488199544, 38.80183119927683, 40.47446712370842, 41.10279944635207, 39.38570737838745, 40.94563791828771, 41.60199165344238, 40.240501665299945, 39.525579098732244, 39.459938233898534, 39.490579789684666, 38.32726755449849, 38.97862026768346, 39.60090821789157, 45.62823403266169, 49.565638649848204, 49.30132973578669, 53.02787165487967, 51.34348430941182, 51.9532520540299, 50.74501691326019, 52.881955562099336, 51.64752291094873, 51.265229102103945, 51.283177868012466, 51.24862178679436, 52.748689113124726, 51.720616279109834, 47.10854045806393, 47.489586953193914, 47.851013752721975, 50.92170007767216, 57.171436048323116, 56.58157433232954, 53.82939623248193, 53.9722607212682, 51.759494812257834, 51.740541919585205, 47.0644098712552, 51.74648431039626, 53.34606216799829, 58.224298261827045, 52.18672329379667, 40.93132126715876, 5.2184443416134005, 1.9695463536247133, 11.756321057196587, 8.962332452497176, 5.347566806500958, 0.19087731808183656, 4.425330306253126, 60.54512546908472, 43.88937673261089, 44.1045501155238, 28.415828404888032, 30.94269379492729, 52.300899567142615, 26.301196275218842, 0.060435412301411556, 0.05302914621068105, 0.07736889720563928, 0.009775012825435449, 0.04755583869653845, 0.08081987815638704, 0.02338742709628517, 0.0353172853318674, 0.012177684806257248, 0.049356195114312634, 0.05277215818604154, 0.029004389502769037, 0.02703765602481942, 0.15374652260253507, 0.14123653662541222, 0.13539700077906733, 0.15599561885239618, 0.14598551566802687, 0.13101526896559423, 0.19607271187968794, 0.25803649257267675, 0.112741329376736, 0.18301635199496824, 0.13239897697442962, 0.2051836883108462, 0.11993258906107758, 0.12543657839658762, 0.13233085643620263, 0.20681764660102708, 5.241848143839068, 50.018131117666925, 50.31883570455736, 45.87839495751166, 63.24460652566726, 82.04005918195172, 56.88562862334713, 57.032972458870184, 56.932614695641306, 63.100671229823945, 18.29917477023217, 0.471446157222794, 7.755089671381059, 9.348768284243922, 0.8807772926745877, 14.28124781577818, 55.08083628069971, 57.18206174911992, 59.2811377586857, 53.893577975611535, 45.58660199565273, 49.12849833888393, 55.74148893356324, 56.08944239154939, 59.22627948945569, 47.59944077460997, 47.326706609418316, 53.17305818680794, 56.14746993587863, 54.32374431240944, 53.84703513114683, 53.403619027906856, 52.43907290120279, 52.84772895997571, 52.24577065437071, 55.22083351689001, 52.70103623790126, 50.80503702163697, 47.865934448857466, 43.736459209072976, 40.9871522841915, 40.09391092484997, 41.038205854354366, 41.773438453674316, 43.24935574685374, 40.85145396571006, 42.500736098135675, 40.72448684323219, 42.77743577957154, 42.037774824327045, 42.89360853933519, 43.20524477189587, 42.537661290937855, 41.480900241482644, 43.0763792222546, 39.21741024140389, 42.61448483313284, 41.8134387846916, 41.69343386926959, 39.59560125104843, 42.65274363179361, 41.31323460609683, 43.8572564432698, 42.60141157334851, 44.397864957009595, 42.84743047529652, 44.421524693889005, 49.447237983826675, 55.14230374367007, 55.23771932048183, 53.77594609414378, 57.23824577946817, 58.74025467903384, 55.26002191728162, 48.646219391976636, 50.3415423054849, 54.004090755216545, 56.34454158044631, 56.35203330747543, 58.325915105881236, 49.66071690282514, 45.78943167963336, 43.39378133896859, 42.03807684683031, 41.614072553573116, 41.191241048997455, 42.10350198130454, 41.411474289432654, 41.72347530241936, 41.358145744569846, 40.8318107358871, 41.81058722157633, 45.29456976921328, 41.77817667684248, 43.45200500180645, 44.36571328870712, 41.60728293080484, 41.49008643242621, 41.88199789293351, 42.53622570345479, 39.465496232432706, 41.349414548566266, 41.120963942620065, 46.11657696385538, 52.501520956716234, 51.779946050336285, 54.96102748378631, 52.34707763118129, 54.140722597799, 52.098873969047304, 55.535085970355624, 53.688500773522165, 51.99900650208997, 54.12548418967955, 54.06568373403242, 55.09854578202771, 53.906929723678104, 47.518059438274754, 47.34630277079921, 48.83321446757163, 52.16460897076515, 55.97949051087903, 57.46899097196518, 55.665496933844786, 56.750769692082564, 54.172713448924405, 54.12929673348704, 50.064791633236794, 54.80781578248548, 54.571257637393096, 60.1304328826166, 54.25268665436776, 42.14753058648879, 6.632574988949684, 2.247156515236824, 14.098414374936013, 15.904688392916034, 13.107235354761924, 0.5398345197881422, 5.14487587636517, 65.29164052778675, 48.1792769124431, 47.52263292189568, 37.165343838353316, 40.51080396098476, 59.19024859705279, 32.57700816277535, 0.38678547427538906, 0.12311743872780954, 0.25145857054139337, 0.1081751618954924, 0.2085923812081737, 0.1637432958570219, 0.09735221644082377, 0.12401542401001339, 0.1076721409035306, 0.07816541414227217, 0.13973406966655486, 0.11147589002165104, 0.11469876829294429], [0.051601698411808866, 0.08140375972875664, 0.05106470142040522, 0.08189259277236077, 0.027528735621261503, 0.0846623760017176, 0.03310963826914949, 0.023158299774231932, 0.03575931806417723, 0.038139120405239445, 0.03966242495563723, 0.10739111687026678, 0.018555974858182094, 0.008301290443107005, 0.004263964468508118, 0.09285295907888683, 0.5331234057103434, 20.71516848379566, 48.962350660754794, 39.72915795541579, 39.74966410667666, 55.358249833506925, 52.62146311421549, 47.05647883876678, 50.47024703794911, 56.664944310342115, 25.061754757358184, 0.08953965944989074, 3.119268801904494, 2.316231660304531, 0.37600070298198734, 10.407985718019548, 48.67094601354292, 53.63260307619649, 54.40090910080941, 47.57031325371035, 47.17324779879662, 48.91840050297399, 52.729312604473485, 52.376828808938306, 51.19456760344967, 46.164614231355735, 50.98432071747319, 51.86993306682956, 51.85311786590084, 47.30063853725311, 48.66373277479603, 46.47990219054684, 47.93572518133348, 47.30539637227213, 49.9925611865136, 48.47285455273044, 49.3082997875829, 48.26201931122811, 47.88230249958654, 40.124124942287324, 38.31981112880092, 38.31423351841588, 37.69827235129572, 37.6748126552951, 39.497483161187944, 36.69246681274907, 36.75424022059287, 36.96585209138932, 38.497090493479085, 38.57172927548809, 38.589387786003854, 40.554761963505904, 40.43437657817718, 40.27210420177829, 41.26427558160598, 37.22959226177585, 37.107100563664595, 38.581954894527314, 39.6549427893854, 38.70621950395646, 39.819972592015425, 39.24594548440749, 39.809915634893606, 37.94471486922234, 39.10423809482206, 40.15237385226835, 41.63363733599263, 47.68197528777584, 54.13997342509609, 54.38842027418075, 53.916182594914595, 52.28356269098098, 62.66500965241463, 45.02781329616424, 48.75772453123524, 52.28633972906297, 51.848548304650095, 55.009476600154755, 51.14204706684236, 50.13471964866885, 44.045063449490456, 44.39330324049919, 40.83071639460903, 39.01313320282967, 38.988700759026315, 38.2409950225584, 36.005142042713786, 36.22112735625237, 38.64166121329031, 38.21198517276395, 38.906107410307854, 37.68948231973956, 37.81148372157928, 39.949155853640654, 37.224626541137695, 38.86167087862569, 38.68023380156487, 36.55379141530683, 38.03084227346605, 39.12980410360521, 36.69305124590474, 36.83107945226854, 37.02562116807507, 39.987151853499874, 47.13260812144126, 47.75826146525722, 48.68831034629576, 49.95698921142086, 49.547332948254, 49.885080399051795, 49.19544927535519, 47.90092983553487, 48.25827737008372, 46.37633592851701, 50.2830126977736, 49.187573156049176, 49.17715926324168, 51.98316012659381, 48.20478800804385, 47.664940434117476, 48.544245612236764, 43.487310255727465, 49.23566925910212, 54.67626340927617, 53.99897990688201, 50.61690053632183, 50.55009864991712, 48.94951666555097, 48.17953971124465, 52.01111093644173, 56.34572613623835, 52.85129831683252, 28.66417915590348, 2.123220894605883, 1.7357466153560148, 11.791810662515703, 6.170889466039597, 4.4533330875058335, 0.142228007617016, 4.449433270962008, 50.68380048198085, 35.000579895511756, 24.908090022302446, 24.76652187685813, 38.11841310993318, 45.48768766464726, 10.282573815315, 0.18680097955849864, 0.08379529470637923, 0.023519977544163986, 0.08047768966324868, 0.040527533574570576, 0.06509937090618957, 0.05641723134284539, 0.08244969957177678, 0.043352674317335894, 0.021335554436870643, 0.06789785945006917, 0.04670913917042556, 0.07993572076121647, 0.07070157271359237, 0.05750998298847868, 0.026230331502794742, 0.04594280992844894, 0.06292271593044843, 0.029852027486589168, 0.002829961829833807, 0.030844517375132254, 0.013607517053793757, 0.02497120471220584, 0.06437773140327585, 0.046866593221502925, 0.04885228929079829, 0.031769562798041495, 0.017254178885430578, 0.04687757126145786, 0.8570119582356945, 27.486373762930594, 53.45993641884097, 39.594608891394834, 47.882231896923436, 67.6200928226594, 58.132875657850704, 53.51530459619338, 53.787626912516934, 63.43535923188733, 26.211136694877382, 0.10443057774776414, 2.5558480283906384, 4.3348294592672785, 0.4240397478063261, 11.647360555587277, 50.05143204042989, 55.02722532518449, 55.91977242500552, 49.86160501357048, 49.36768054962159, 50.02206525494976, 54.498270173226636, 53.78411639121271, 52.39659755460678, 48.51371780518563, 50.040147381444136, 54.51692888813635, 52.655109205553615, 49.99719742805728, 50.41045050467215, 47.483291549067346, 49.6874164765881, 48.038408910074544, 52.22617057061965, 50.19484173867011, 50.51980618507632, 50.379863862068426, 50.19283348514188, 42.06956955694383, 39.74188996899513, 40.264604630008826, 39.10418710400982, 38.832100129896595, 40.440036558335834, 39.154111031563055, 40.29689358126733, 39.324263449638124, 40.51572261318084, 39.992564724337676, 42.36553984303629, 41.448234742687596, 42.68127495242704, 41.50988263468589, 42.19476376810382, 38.80791871778427, 40.628231879203554, 40.217453818167414, 41.706977813474595, 41.033608836512414, 42.40540681346771, 41.207232552189986, 42.015472227527255, 40.48468097563713, 40.789951201408144, 40.12270504428495, 43.09841509788267, 48.44258562211068, 57.237688802903705, 54.206422298185295, 57.082072688687234, 53.2394011559025, 55.64697157952094, 48.31765420975224, 48.61160839757612, 51.76943409827448, 53.3669448667957, 56.33179779975646, 54.43055437457178, 50.30346001348188, 45.62048735157136, 43.39234575148552, 42.4673802621903, 41.86616720691804, 40.985559801901545, 41.561391199788744, 38.24971445145146, 37.45333602351528, 41.21122160265523, 39.78092539695002, 40.574067869494044, 39.849417824899, 39.813877228767645, 39.68004988085839, 38.883126243468254, 39.27285294378958, 39.745506394294004, 38.06537482046312, 39.5690821063134, 40.5743424354061, 38.86122372842605, 39.442821010466545, 38.424083417461766, 41.99323238865022, 47.46121252736738, 50.70658945268201, 50.54652929306031, 50.69419868530766, 51.3757065803774, 51.09757915619881, 49.65173467513054, 49.64537651308122, 49.930148432331706, 48.980836791376916, 52.62092182713171, 51.22740960890248, 51.25823159371653, 52.55528488466817, 49.26406721914969, 47.36898191513554, 49.146513785085375, 45.631497444645056, 50.443116003467196, 55.89754043086883, 55.459117504858206, 52.57168431435862, 53.2293834224824, 53.048989695887414, 50.90934853399954, 54.58635484018634, 59.4994019692944, 55.07899668908889, 31.756387525989165, 3.774329625791119, 2.1949848244267125, 12.242643967751535, 7.997797602607359, 1.817929340947059, 0.11960533162158345, 4.464686878265874, 55.87051530038157, 37.91042550917595, 34.79210592085315, 25.917721832952193, 41.304734829933416, 53.12897859081146, 14.309062323262616, 0.11346621709244867, 0.03747826614867776, 0.038452404400994705, 0.09754527059774246, 0.03056424602325405, 0.04264985759472174, 0.11070790219931834, 0.08000571821485797, 0.030772068440133048, 0.074350725288593, 0.0658763679225118, 0.02189042617476756, 0.07437375389159688, 0.15193074100440548, 0.15797718187734006, 0.1884750808559118, 0.21674547194232865, 0.18265794542047287, 0.20260495974892573, 0.14777031667049856, 0.0892015005792341, 0.11552996602990936, 0.11766929720197955, 0.1585863596729694, 0.18018548857540856, 0.12282827117991064, 0.13545848699587007, 0.22634417058960085, 0.19838643530684136, 0.7962872941167125, 32.37161913225728, 63.665680808405725, 50.72393809595416, 50.8359766775562, 64.39961510319864, 61.53160156742219, 55.82141507056452, 59.053914854603434, 66.94402525501867, 31.64644152887406, 0.2950138712842619, 7.646165941992114, 7.898505253176536, 1.0705106729461302, 13.943606268975044, 52.36375162678381, 57.77492800066548, 59.30879046840053, 52.074998501808416, 53.33364394403274, 52.56534968653033, 58.05127074641567, 54.8431053469258, 53.038520889897505, 47.1689724153088, 51.499720158115515, 54.705861614596465, 56.94082421641196, 52.59430854551254, 52.69822782085788, 49.78083556698215, 51.68538947259226, 49.370218323123076, 54.32400711121098, 53.27338064870527, 53.26097419185024, 52.78752450020083, 52.82304156211115, 44.644695789583274, 42.420386345155784, 42.56323122209118, 41.557056980748335, 41.804370264853205, 42.25380720630769, 39.78212956459292, 40.938922820552705, 41.9507727315349, 42.11874431179416, 42.13015448662543, 42.44453637830673, 42.745786174651116, 45.192266510378936, 44.02236077093309, 44.28466143146638, 41.26119259865054, 41.68574994610202, 41.77743534887991, 43.46041456345589, 42.604584770817915, 44.08336539422312, 43.806987347141394, 43.999850288514175, 42.8204563356215, 42.988655413350756, 44.09956870540496, 45.245822552711736, 52.70589213217459, 60.13484947143063, 56.55746744525049, 57.82413805684736, 54.97596386940249, 56.08339801911385, 51.680443363804976, 51.83449445232269, 51.26952017507246, 56.18126899965348, 58.31347334769465, 56.25994782293997, 51.74473885566958, 47.05710249562418, 46.51502701543993, 45.650740592710434, 44.114254059330115, 43.66615464610439, 43.54576141603532, 40.25802289285968, 39.60631324398903, 43.40437958317418, 42.086878976514264, 42.761687463329686, 41.820326466714185, 42.35382372333158, 42.83505931977303, 40.68183106760825, 42.39015271586757, 42.45134561292587, 39.07398093131281, 40.59711571662657, 43.922316797318004, 41.277250782136, 40.35896116687406, 39.437043359202725, 43.320515386519894, 49.974118201963364, 53.16871612302719, 54.26577952600295, 52.50304283634309, 52.309148311615, 53.01426103038173, 52.41045921079574, 52.40898832198113, 53.27120373325964, 51.01007892239479, 56.17361253307712, 53.2049431339387, 51.89938614445349, 55.06330328602945, 49.18688281889885, 48.278104951304776, 48.12915686638125, 44.80969029088175, 49.81561914567025, 58.274504600032685, 58.923088119876006, 52.88106910644039, 55.138283314243445, 53.96097606228244, 53.68368018058039, 57.25577877413843, 61.60733469070927, 54.83136177062989, 34.77216066852693, 4.081863059151558, 2.950436506540545, 26.43720053857373, 13.820540924226085, 10.295235226231238, 0.30077662979883535, 5.8972619810412015, 64.43426924367105, 43.5622981286818, 36.09632145973944, 35.33424808133033, 49.347190087841405, 58.68000707318706, 18.36044611469392, 0.25413823884821707, 0.24036708828662676, 0.15528570049472395, 0.21554694270655034, 0.12540968104956612, 0.22916081541728592, 0.31788539562013846, 0.16144389827405253, 0.20047339670840772, 0.1501292392851845, 0.15648381604302317, 0.19849598588001346, 0.13897211861706552], [0.02852989570988763, 0.036476698118231954, 0.03642090393470661, 0.04577003028844634, 0.02678147239250041, 0.07942614971750206, 0.08119808810372507, 0.07912238819464561, 0.037147408095939506, 0.026901085530557943, 0.05868786232425802, 0.07508020953185136, 0.06334368124484055, 0.01838632085691056, 0.06529259360245158, 0.06589307630014035, 0.1330742681579244, 6.07355143754713, 43.46275229607859, 48.55144316150297, 31.227473558918124, 31.424564815336662, 37.22266143368137, 40.49007423462407, 43.582851348384736, 50.35298778164772, 33.372105936850275, 0.6750256267766799, 0.5092935666682259, 2.1060637120277654, 0.04864656403961201, 5.49912718995925, 49.375639038701216, 52.46440749014578, 54.04122383363786, 49.4306855816995, 52.06295290300923, 50.010235386510054, 54.105715444011075, 51.76431932756978, 50.24942936435823, 46.31917130562567, 52.66921012632309, 50.830042131485484, 48.62347748971755, 45.44693816092707, 45.48451446717786, 44.687108378256525, 47.42036104202271, 49.03677763477449, 49.50537143215057, 49.81887863528345, 49.84224419439993, 50.17554367742231, 48.46110313169418, 46.64639895962131, 40.47488289494669, 38.12857204867948, 39.32864081475043, 39.39228127079625, 41.19183724926364, 40.03941743604599, 39.46284471019622, 38.38289853065245, 37.97079863086824, 39.85642317802676, 37.860591796136674, 39.9182201200916, 39.58594045331402, 39.171459674835205, 39.66491345436343, 37.754656422522764, 38.49934585632817, 38.36381227739396, 39.6324989872594, 38.88338511989963, 38.801207542419434, 38.24663539086619, 37.715507245832875, 40.209589465971916, 40.16395268901702, 36.569120037940245, 39.180838061917214, 49.09351864168721, 54.193337271290446, 55.32539606094361, 51.54654541323262, 57.16018669066891, 75.61927257045623, 38.720422406350416, 45.79162428455968, 53.03861894915181, 51.41212578742735, 53.06731893170265, 51.01097714516425, 47.87266523607316, 43.78774419907601, 43.080988007207075, 41.31173233832083, 36.70925847945675, 38.30061112680743, 37.87917990838328, 36.48505580040717, 35.193415380293324, 38.3875386945663, 38.5067081451416, 38.26351334971767, 38.12112346772225, 37.72039059669741, 37.561538527088786, 38.42693105820687, 37.963122552441014, 39.18724329240861, 37.89016254486577, 38.81920337677002, 37.113019420254616, 36.47421044688071, 37.08225627099314, 38.19815097316619, 40.162026805262414, 47.88846454312725, 47.72980859202724, 51.40864272271433, 49.1358410158465, 50.41748331439111, 49.07374597364857, 47.59864845583516, 45.75618174768264, 45.369620400090376, 45.78533280280329, 47.43666241245885, 44.96811482214159, 47.24859260743665, 50.40703804262223, 49.40046764189198, 49.169459650593424, 50.517731251255164, 49.22931501942296, 46.057823781044256, 46.81550802723054, 51.21777626775926, 55.52904552029025, 53.138753137280865, 50.64256852672946, 49.60875726515248, 53.22783800863451, 56.219202241589954, 50.603752751504224, 32.20008996225173, 7.8876701958717845, 1.7254182792478994, 8.303339942809075, 6.0098634227629635, 1.2928037705921358, 0.1379088805087151, 6.590713983581913, 52.444505383891446, 39.51538485865439, 29.582021620965776, 27.797403989299653, 42.83660473362092, 40.89614152908325, 4.602495431900024, 0.07694152739620017, 0.04423489351005805, 0.07845693358009861, 0.08385023087142937, 0.0430236701973744, 0.015216135070659222, 0.058355410808637265, 0.010316634115072028, 0.05532799221034493, 0.03183340090477178, 0.026402241633003278, 0.019560182061527046, 0.043637999934294534, 0.025830228677800587, 0.027437350907993895, 0.011559471961170917, 0.009752606668870055, 0.08214999831491902, 0.029031752248204527, 0.010238802454794848, 0.08264759540437691, 0.01550390833853594, 0.019284792604946324, 0.011794369840513796, 0.0783747093631856, 0.004314742691349238, 0.02306151414109815, 0.04088036685941681, 0.12285460162186816, 0.17690519201419047, 12.08779859927393, 53.42113633309641, 53.349407949755275, 34.12891941685831, 39.88799433554373, 46.8810155314784, 45.15845960186374, 52.39151416286346, 56.18312820311516, 37.685767835186375, 0.622946172952652, 0.6282557751382551, 3.5498678251620266, 0.7429135194228542, 7.218156418492717, 50.668750347629675, 53.71561219615322, 55.93237500036917, 52.527945964567124, 53.0824435910871, 53.10998255206693, 57.185627183606556, 54.22002115557271, 52.17448942122921, 46.528394452987186, 53.60753520842522, 53.55240629565332, 50.31261874783424, 47.87724264206425, 47.534619685142275, 48.30828366741058, 50.425433958730395, 49.901142504907426, 51.03324051826231, 53.30299454350626, 54.3444779611403, 51.33890298105056, 51.40617162950578, 47.66665843225295, 41.108200550079346, 39.305330168816354, 40.82575851871122, 40.3016161149548, 41.548592505916474, 41.171076143941576, 42.515731319304436, 39.508693295140425, 39.52342571750764, 40.886523877420736, 40.082496827648534, 41.71620322811989, 42.92675256729127, 39.9091516002532, 43.31982897173974, 38.635738434330115, 40.261862893258375, 40.20146231497488, 41.38377451127575, 39.82893913022934, 42.173826156123994, 40.2496172535804, 38.6783589086225, 41.363268360014885, 43.55969759725755, 39.10441852384998, 42.17203363295525, 51.9972453578826, 56.451359487348995, 54.75828801431964, 54.06424422417918, 51.86160979732391, 67.2234784403155, 41.25409703100882, 46.83669274853122, 53.45204853242444, 52.91689603559433, 54.425157193214666, 54.073163693951024, 49.191621042067005, 45.93654409531624, 43.78875617058047, 43.14024325340025, 39.43367796559488, 39.232911448324884, 39.73701054050077, 38.58255501716368, 38.77457857131958, 41.32658635416339, 40.6082474031756, 40.52123746564312, 39.59749967821183, 39.242466342064645, 38.606304968557055, 39.38811179130308, 39.39445818624189, 41.45794260886408, 39.56230032828547, 40.63600993925526, 38.07725960208524, 38.7490439414978, 38.75548055095058, 40.25445745837304, 40.81991418715447, 50.0188999022207, 50.9927067449016, 53.84696845085391, 50.25709367567494, 52.20588407208843, 51.093382220114435, 49.92593972913681, 47.53994234146611, 48.91759249471849, 46.69979026240688, 49.634825337317686, 48.4234836793715, 49.48644991843931, 52.589652692118, 51.52357209113337, 50.360397138903224, 51.60085455063851, 48.40572710960142, 46.11629455320297, 47.08218997524631, 52.7250176091348, 57.84627591409991, 55.45757601338049, 54.15049322189824, 52.251034475141964, 55.14084462196597, 58.811932071562744, 51.57054247394685, 33.909713837408255, 8.757896557930978, 6.266404572994479, 11.367039545889824, 9.253871440887451, 3.13903215431398, 0.2096245161467983, 7.143014592509116, 60.17332792282105, 41.64760097380608, 32.8570673542638, 30.507457794681674, 47.679492427456765, 49.16980874153876, 7.1635217243625275, 0.20035505144586488, 0.02876138449796746, 0.03510602892586782, 0.018802411936884447, 0.1057905829962223, 0.04624899611958573, 0.06623476683612793, 0.021685966883876154, 0.042568606309472554, 0.060060925541385535, 0.05359577165255624, 0.07479904760276118, 0.12271789323178031, 0.08076032248115347, 0.08703163314250209, 0.12534151454606365, 0.14720295195377645, 0.17399457884171318, 0.2328715614613987, 0.13068939048436382, 0.21800747922351285, 0.13860545361474638, 0.1290135425064833, 0.14232003009848057, 0.19295119470165623, 0.19974342216887783, 0.16735644229958135, 0.2422522161636622, 0.22588195910136546, 0.30850685532054595, 13.653269487042582, 61.324916193562174, 59.59605701508061, 43.317781494509795, 43.25734953726492, 48.83121013641358, 51.913479220482614, 56.241900997777144, 59.325080071726155, 42.61457897001698, 1.1120244259795835, 3.808698658981631, 6.542197206327993, 0.9839320122714966, 7.217958829095287, 55.34839683963407, 56.13997036410917, 58.961064507884366, 53.92853413858722, 56.64011570715136, 56.05846743429861, 57.35818401459725, 57.69339761426372, 52.89551911815521, 45.95397118599185, 56.65942161313949, 54.94742470402872, 54.89474335024434, 50.87995036955803, 49.09149862104847, 50.16005423761184, 51.95360114497524, 52.08376107677337, 53.87753940397694, 53.93365283166209, 54.94099201694612, 52.58868778905561, 54.18200554386262, 50.390932790694706, 45.334020968406435, 41.39820883350988, 43.27782038719424, 43.52583185318978, 44.4173316801748, 42.2568941116333, 44.55891747628489, 41.79220307257868, 39.94500598599834, 43.580831327746, 41.11235041772166, 43.11216692770682, 44.75225894681869, 41.67794442945912, 45.32964360329413, 39.75567710015082, 41.59582960990168, 41.69666197992141, 44.722374408475815, 42.52670611104658, 43.59207676303002, 40.56291657109415, 40.518570253925944, 44.37806091000957, 47.63912339364329, 40.832293187418294, 44.53266897509175, 54.97123741334485, 55.996725405416186, 57.962472208084606, 55.552360088594504, 52.88722330524076, 71.12396963181035, 45.693937655418154, 52.045514045223115, 52.21679218353764, 55.53229324279293, 56.695307377846014, 55.70757219868322, 53.953119554827296, 48.383220549552675, 47.798065677765884, 46.915732429873565, 40.499652662584865, 41.70669932519236, 42.136700922443026, 41.05289120827952, 39.63080844571514, 44.086518979841664, 43.03242514210363, 43.101082309599846, 42.087549701813735, 40.755540247886415, 41.469360628435695, 41.637391044247536, 41.18267067017094, 44.228014561437796, 41.66389842187205, 43.81258064700712, 39.91965570757466, 40.188122334018836, 40.943253117222945, 42.60821688559748, 44.01361388544883, 53.333608642701186, 51.707527329844815, 54.28318700482769, 52.264923587922134, 56.84777382881411, 53.40315226585635, 51.99013017839002, 49.586407599910615, 50.88522987980997, 49.91946781835249, 51.618477759822724, 48.70818107358871, 51.721698853277395, 53.55731318073889, 53.18817500145205, 52.0742924751774, 51.773117203866285, 48.61072586428735, 48.45935375459733, 48.342216091771284, 53.0715903928203, 60.18989993679909, 57.57525974704374, 56.02259735907278, 52.56056439492011, 56.70837671526017, 61.14949995471586, 53.05685797045308, 38.771107273717085, 10.57008158776068, 6.626413435705247, 20.29852059579665, 17.008593390064856, 7.2214090439581105, 0.41157797940315743, 8.558114555574234, 64.36516884834536, 49.632012997904134, 41.975146339785674, 38.12271595001221, 53.52233348354217, 57.181653822621996, 9.44631959161451, 0.39882089942693716, 0.09393779320582267, 0.18663423286089975, 0.26089666651621946, 0.2160378212049123, 0.1158398102908846, 0.1809848400373613, 0.15828991428978983, 0.19821146082493568, 0.14692472414143626, 0.15057787569540163, 0.17961343540058983, 0.16718267823659605], [0.05854291082810491, 0.0351699551327094, 0.07229226235780986, 0.009181547493133093, 0.0349773989329415, 0.016892093173678846, 0.012088559094756361, 0.04193239327099535, 0.02550626350116105, 0.020175044229554556, 0.06278286657987103, 0.07638784500980571, 0.02960481665908329, 0.019633002549169526, 0.031802705676865675, 0.012996053443320338, 0.05611323233273241, 0.3925022062274718, 26.14425636106922, 48.131255334423436, 36.305889775676114, 36.25712294732371, 33.585702526953916, 38.033219229790475, 49.37538016226984, 53.812957579089755, 41.35792216947002, 2.6717621568710577, 0.7758991203961835, 3.8699317603342, 3.9505362222271585, 20.37298090996281, 33.25511340172061, 52.30570054823353, 52.52474531050652, 52.11124120220062, 51.6479661387782, 54.02107854043284, 54.85123642029301, 46.50513872023552, 46.74024166599397, 48.6037479677508, 53.30996851767264, 51.71448953690068, 48.334838113477154, 45.57563504865093, 45.337998251761164, 45.460509561723285, 48.43603918629308, 45.84640802875642, 48.25239381482525, 49.10039063422911, 48.69520587305869, 49.767311234628, 50.84394301137617, 48.61970024724161, 44.11607796146024, 41.709397915870916, 38.35761101015153, 39.352037752828295, 38.15674251125705, 38.30138775610155, 39.63178903825822, 39.63680182733844, 38.80737743070049, 38.69861010582217, 36.78943172577889, 38.83845044720558, 39.12047670733544, 38.44884141798943, 38.889166693533625, 38.385075446098085, 36.90976612029537, 39.018424480192124, 38.60595587761172, 37.07172862945065, 38.313711843182965, 38.80051328289894, 41.45133341512373, 41.88104083461147, 40.35001031814083, 38.470630184296645, 38.59093319985175, 47.38058036373508, 52.69296792245681, 54.54661338560043, 52.29140743132561, 48.82617381311233, 39.047210754886756, 45.151301276299264, 38.13917813762542, 50.9935147531571, 52.15954519087269, 52.329332828521736, 50.3411304566168, 46.200519607913115, 46.33136987686158, 43.22732771596601, 42.18117667782692, 39.48552777690273, 40.40583741280341, 37.810832608130674, 36.53723116843931, 36.526170084553385, 36.274491202446725, 38.09541233124272, 37.85706558535176, 39.73468849735875, 37.606163332539225, 37.807482904003514, 38.63034909771335, 38.82315712590372, 37.02476609137751, 37.949609987197384, 40.13655493336339, 39.20970670638546, 37.004695323205766, 37.1321213629938, 37.05930648311492, 39.009328503762525, 48.44518615353493, 50.2377446236149, 48.92320540643508, 50.20932705171647, 49.791449500668435, 48.79680702763219, 47.57039562348397, 43.227876847790135, 39.93187389066143, 41.582815185669936, 42.567432080545736, 46.357210451556796, 46.99719221361222, 47.90264783367034, 48.19220112216089, 49.615162495643865, 50.39866378230434, 51.497225530685924, 49.79001391318537, 50.630707279328384, 48.990642716807706, 50.13083650219826, 53.42669825400076, 55.142256675228, 54.58770805789579, 54.28996093811528, 54.77817835346345, 43.2792285180861, 25.64658799479085, 6.228580176830293, 3.2470583963778714, 9.778334498405457, 5.686757199225887, 1.1377928045488175, 0.1614809769295877, 6.3768050747533005, 50.662298048696215, 39.07731494595928, 28.070157766342167, 19.693338101910008, 38.72842011913177, 33.523627096606845, 1.638526380542786, 0.07799240084545267, 0.018286083997677893, 0.038510749657307906, 0.05337699609357984, 0.017436427372177283, 0.04846107117050598, 0.028587040123379523, 0.022128834652023453, 0.011747152968910674, 0.061817848604292645, 0.05529068755887209, 0.09506610282246145, 0.029468587073948116, 0.04450267571355066, 0.10383293723627444, 0.04431099285401645, 0.035193608097371556, 0.008763967329756388, 0.03982916016191725, 0.03591076981636786, 0.04872372058490592, 0.0416625464605468, 0.024867533863852584, 0.023936894083876285, 0.04636134674412109, 0.018692773263601047, 0.05024628203001715, 0.06720412086935774, 0.010930656459212545, 0.0488141342817295, 0.8419231517661003, 36.860948301130726, 58.290064642506266, 39.88293055565127, 39.3721555894421, 42.85120771777245, 45.821297014913256, 53.32005293138566, 58.01647147824688, 44.681032626859604, 2.5456449629799014, 0.7782741155355208, 2.28656358776554, 4.15605616184973, 16.29347960795126, 37.60406878686721, 54.03278681539721, 56.031524673584975, 54.86969509432393, 52.95343683611963, 56.171176741200114, 56.53989914924868, 48.25846564385199, 48.96806163172568, 51.14361601491129, 54.719342800878714, 53.24296659038913, 51.807990997068345, 47.57408657381612, 46.322611224266794, 47.299912898771225, 49.833148217970326, 48.49468646510955, 49.66050901720601, 53.29512626894059, 50.68656967532251, 50.75228506518949, 53.15981234273603, 50.09610783669257, 46.04114586307157, 41.21250421770158, 39.89524679799234, 39.92732001889137, 41.21350834446569, 41.28824126335883, 40.97700511255572, 42.5538920587109, 40.60079097747803, 40.60046542075373, 38.47747079787716, 41.6867305386451, 41.74626427312052, 41.53116541524088, 40.24515359632431, 41.39583187718546, 39.544955607383486, 41.17793244700278, 39.385111178121264, 39.683678073267785, 39.34038831341652, 41.71421066407235, 42.53468421197707, 42.606671471749586, 42.032232515273556, 40.10375607398249, 40.913266597255586, 50.09136569115424, 56.84915842548494, 57.319003458945986, 52.299687554759366, 50.26563267554007, 45.15655332996, 44.9928649779289, 41.30922594378072, 53.46478446837395, 52.703832887834125, 53.91926165549986, 52.89557795370779, 47.48378184533889, 48.5802137467169, 45.1139053990764, 44.26193129631781, 41.52802751910302, 41.642701933460856, 39.91823580957229, 38.6188094846664, 38.240171324822214, 38.07466299303117, 39.56339466956354, 39.915125370025635, 39.853830491342855, 40.12707456465691, 39.83504233821746, 39.828440989217455, 40.21457479846093, 38.19091812256844, 39.58825465171568, 41.3491556721349, 40.635484341652166, 38.05000697412799, 38.924381732940674, 37.432002252148045, 40.64068148213048, 49.918079299311486, 52.665715294499556, 51.38479863443683, 51.41329857610887, 51.90771333632931, 50.939382122408965, 50.19430045158633, 44.84767060126028, 42.95054566475653, 44.86167346277545, 46.26079074798092, 49.706228163934526, 49.72778943277175, 50.07742166519166, 50.20537330258278, 52.66991223058393, 53.51903084785708, 52.801374389279275, 51.122137115847686, 49.70286669269685, 49.23599481582642, 50.96951769244287, 56.019208431243904, 56.38184724315521, 56.20900015677176, 56.93121048711962, 56.95443876328007, 45.70454766673427, 29.870545287286085, 6.7084625555622965, 4.415128711731204, 11.051187745986446, 9.845049112073838, 2.4985108212117226, 0.06465927637632816, 7.563777046818887, 55.577482869548184, 45.5129869522587, 36.94587546010172, 23.95014916696856, 46.37722630654612, 40.59161655364498, 2.805421578307306, 0.13450495267827667, 0.06740878891920851, 0.04586831170825228, 0.053691276003636663, 0.07103477499537891, 0.049977120868260824, 0.02301306482554684, 0.047006036545480454, 0.03883388554376941, 0.050105831300419186, 0.04248615609662187, 0.01739402632078817, 0.05509484867234865, 0.19424468819652835, 0.16674328084674575, 0.29570574061043803, 0.14062388079060664, 0.11817882994129775, 0.13434602007750543, 0.1110413726118784, 0.15960043025833948, 0.13022200024176028, 0.08946494289463566, 0.2385671034214958, 0.1690162790398444, 0.10932163545681585, 0.1051000543239136, 0.11379627841374568, 0.12155364643061355, 0.14942235463569242, 0.9341993615511925, 42.04893396746728, 64.65253345427975, 48.76913862843668, 46.494273754858206, 47.55464730724212, 49.08038262398013, 63.721586350471746, 63.77511493621334, 50.84342525851343, 3.242256679842549, 1.3356653480760514, 10.739556416388481, 5.680720181234422, 27.893488330225793, 43.48826339167934, 54.791561480491396, 59.74348322037728, 55.80495680532148, 56.25299738299463, 58.16089707036173, 59.47163551084457, 50.054593470788774, 48.600633605833984, 51.8041431519293, 57.8558700315414, 56.78187408754903, 54.40501582237982, 50.448254308392926, 48.79717573042839, 49.146458871902965, 53.775463642612586, 49.70242346486738, 51.30183658292217, 55.863961019823634, 52.04608671126827, 54.14392717422978, 54.95948206993842, 52.85294571230489, 47.372151190234774, 46.031135974391816, 41.87205468454669, 42.87661290937855, 43.74019330547702, 41.98248901674825, 43.049326635176136, 44.394013189500384, 42.603553187462595, 41.33558819370885, 39.980676020345385, 42.69653689476752, 43.89928071729599, 43.41935911486226, 43.21574887921734, 42.88360649539579, 40.782051547881096, 43.54347859659503, 41.02046105169481, 40.58187338613695, 41.70418116354173, 42.63582644924041, 47.3780269007529, 47.06874409029561, 45.82297971171718, 43.34101369304042, 42.47919051877914, 52.485082303324056, 56.68806276013775, 57.75831284061555, 53.625264321604085, 52.66023574336883, 51.81797342915689, 44.778887917918546, 45.215714439269036, 54.22932893999162, 53.970609403425655, 57.42972412417012, 53.15787469187091, 51.81894617695963, 51.668503669000444, 48.91618044145646, 47.528893024690696, 44.11379906439012, 44.3803947202621, 43.21239133034983, 40.230126996194166, 41.14705947137649, 40.32408737367199, 41.39572205082063, 41.65952497912992, 42.556484745394805, 41.6757635916433, 43.28606128692628, 41.916667722886615, 43.454919322844475, 39.62258715783396, 42.46165360173872, 42.72543299582697, 42.12507109488211, 40.877824060378536, 41.757819575648156, 39.01353720695742, 43.577685586867794, 52.44962799933649, 54.854068371557425, 53.35013358823715, 53.33869987918485, 52.79924061990554, 52.473279891475556, 53.04855431279829, 47.07687516366282, 45.05155932518744, 47.84098425219136, 48.49409026484336, 51.704565940364716, 52.705947045357, 52.35810341373567, 51.46227329008041, 54.33803742931735, 54.98484803784279, 54.68813642378777, 53.15547027895528, 52.74273103283298, 49.51815443654215, 50.02559146573467, 55.18251980504682, 57.47645132003292, 57.97963649995866, 58.01771879196168, 56.22195574545092, 46.50894341930267, 33.073393914007376, 8.710915388599519, 8.683559798425245, 17.712419571415072, 14.47230842805678, 4.544722841631982, 0.28713232807574735, 9.22968904818258, 62.59663881794099, 51.726319405340384, 40.20562787209788, 29.096143899425385, 52.87103568353961, 48.35357527579031, 4.166321004590681, 0.4297837524885132, 0.19856278874701072, 0.1748599517609804, 0.14265370735478017, 0.2497294794527754, 0.24489721133103295, 0.16236798417183662, 0.11025892104953529, 0.1295033331599928, 0.21640997139676926, 0.22125835800843857, 0.09460972126332984, 0.17875062121498972], [0.0246287691557119, 0.013267118333568497, 0.09020833929459895, 0.06378217848137983, 0.02377728158007226, 0.026267978978613694, 0.050837556350856065, 0.03512933715096405, 0.012421122650736043, 0.03311368704382931, 0.03989946405072847, 0.008010963229612719, 0.030279935472795082, 0.07700079195802251, 0.0222117253654306, 0.0863784052912266, 0.09689928993823067, 0.07542875655476125, 8.404837154573011, 44.46754978549096, 46.483471547403646, 30.591418089405185, 26.999619391656694, 39.3755288277903, 51.1479776905429, 50.89419641802388, 51.39449081113262, 9.27648292433831, 0.4373971649235295, 1.8459107943119544, 3.8035973714243982, 34.147593821248705, 28.708607842845304, 41.432525650147475, 54.95364558312201, 56.73394272404333, 55.514207193928385, 53.53292388300742, 47.85321812475882, 52.57195103553034, 48.98923850828602, 47.61060776249055, 52.01653165201987, 47.823486558852665, 45.28906668386152, 43.69517626300935, 43.80274726498512, 45.693616021064024, 47.10770107084706, 45.97873310888968, 48.810523556124785, 49.250378147248306, 49.865272429681596, 49.83957306031258, 48.029638490369244, 47.81907781477898, 49.65287608485068, 47.08997588003836, 42.2245345577117, 38.38146686553955, 38.17398132816438, 38.48191092091222, 37.71205948245141, 38.07697326906266, 40.38651973970475, 39.50984647197109, 38.330252478199625, 39.35953732459776, 39.62723908885833, 38.816767584893014, 38.72125002645677, 37.134588533832186, 38.424318759672104, 37.441666972252634, 37.58077383041382, 38.46484468829247, 39.43337594309161, 40.71869350248768, 44.226751558242306, 42.65602665562784, 42.70944149263444, 39.00614746155278, 39.15244794660999, 40.717014728053925, 51.04549008031046, 51.381554834304325, 59.81744735471664, 40.73614804975448, 29.126518734039802, 49.759976402405776, 40.05055304496519, 48.59171413606214, 51.63944675076393, 51.94238708865259, 48.85934922002977, 48.11733484268189, 47.94280505949452, 46.158197233753825, 43.14648766671458, 43.81949970799108, 41.349645968406435, 39.01589455143098, 35.14446420054282, 36.173709823239236, 37.784129111997544, 37.066166708546305, 38.12757184428554, 38.586108684539795, 37.408683761473625, 38.68705088092435, 38.44922581026631, 38.51172877896217, 36.572885513305664, 38.396520922260905, 37.27578993766539, 38.77051499582107, 37.65506352147749, 38.439274757139145, 36.52557388428719, 39.11411070054577, 45.704614347027196, 48.49597300252607, 50.32946925009451, 49.79775274953535, 48.233750789396225, 45.40786743164063, 45.19448264952629, 43.09269628217144, 40.78582094561669, 38.76511389209379, 38.89382254692816, 41.28906103872484, 43.333368993574574, 46.6639554885126, 47.96761405083441, 49.24509079225602, 48.23092276050199, 48.56890555351011, 50.72133756452992, 51.93335779251591, 50.99699389549994, 52.79560066038563, 48.98920712932464, 51.2095118338062, 53.57331645104193, 55.432006082227154, 47.92568783606253, 32.05211266394585, 4.985924766909692, 0.27814651508965804, 10.650039103723342, 6.2760629192475355, 6.188808323875551, 3.1088343166535903, 0.0906138449546791, 10.944960155794698, 52.04400393270677, 29.98665136675681, 21.002654683205392, 22.884331364785474, 45.093877776976555, 20.994821709971276, 0.16258772883203723, 0.036337097746229945, 0.0513040196270712, 0.03722515835937473, 0.018991873141438253, 0.06667288485914469, 0.02239913153912752, 0.019130569529689608, 0.02803704261990084, 0.01480905414228478, 0.024946322176425208, 0.01605861632513904, 0.0530171990695019, 0.023838344533296845, 0.03942614811803064, 0.008569267999020316, 0.078930850891817, 0.04520102997400588, 0.050150214604312376, 0.009681899626288683, 0.046646875374379664, 0.04149989450290319, 0.03965651075686178, 0.022074658829238147, 0.013756075866460321, 0.11882763746525012, 0.017131507141335357, 0.06214879475714219, 0.04813000627402817, 0.06439725898446576, 0.0645061354002645, 0.09676078124152077, 13.302444854090291, 52.1168109678453, 48.86784899619318, 36.77156925201416, 36.65047784005442, 46.03699599542926, 57.829813726486705, 57.41778050699542, 54.015626445893325, 9.10366133336098, 0.40650264690479926, 3.371442883245407, 4.487778852062841, 39.370080655620946, 34.026898568676366, 46.12007179567891, 55.74225771811701, 58.60857678997902, 56.24241090589955, 56.516184499186856, 50.411242823446955, 51.397836592889604, 48.06351992391771, 50.773544311523445, 54.15188174093924, 50.262698742651175, 49.08779198123563, 45.62981867021131, 46.21902927275627, 47.50609620924919, 49.64636495036464, 47.986684614612216, 49.98086467865975, 52.65765090142527, 52.427105749807055, 49.98644621141496, 51.4989003827495, 50.70713858450613, 49.109286569779925, 48.10184540287141, 43.08010939628848, 41.50122596371559, 40.56756457974834, 40.24376115491314, 39.594361782073975, 40.46777948256462, 40.65126011448522, 40.742635650019494, 38.50508820626044, 41.325864638051684, 40.457149859397646, 40.46491222996866, 41.464743998742875, 39.398337410342315, 39.663779889383626, 39.31855247866723, 39.19168341544367, 41.07760214036511, 40.79708991512176, 41.44794056492467, 44.18995972602598, 44.09876854188981, 45.938964197712565, 41.19832484952865, 42.36853653384794, 43.964341071344194, 53.301358915144405, 53.859076807575846, 61.20067511835406, 43.82910559254308, 30.74970337652391, 51.078175190956365, 40.320372889118815, 50.99255377246488, 53.85789617415398, 52.30194683997862, 50.79377197450208, 51.06401543463431, 50.040112080112586, 47.14683455805625, 45.15723189999981, 46.10401361219345, 42.881672766900834, 40.60044188653269, 37.894767407448064, 37.83743412263932, 40.07764093337521, 38.721618729252974, 40.93305103240475, 39.02549259124264, 38.792574405670166, 40.56983563207811, 39.112714336764434, 39.38946893138271, 38.184277549866714, 40.00502609437512, 38.81743831019248, 39.500173907126154, 40.21118979300223, 40.0768917606723, 39.01331755422777, 40.596782315161924, 48.71369592605099, 51.00561134276852, 52.71579219448952, 52.50766338840608, 49.47454160259616, 47.19540919027021, 47.53230940911078, 44.18174236051498, 42.17614427689583, 41.46603838089974, 42.147507052267756, 43.17841575991723, 43.812761076035045, 48.09074117291359, 49.96042913006198, 51.419872468517674, 50.663635576924975, 52.13952541351319, 51.03614699456, 54.401144443019746, 53.03066830481253, 54.181519169961255, 49.739191762862674, 53.84378740864416, 53.89725715883317, 57.55694227833902, 50.728923428443174, 37.41757969702444, 7.924018309962365, 1.0746667918659027, 12.676079600088059, 10.622007885286886, 11.061725193454373, 1.9843415339146893, 0.08733095135539772, 11.625021676863394, 55.93597573618735, 37.46873524881179, 28.06606281188227, 21.5296604171876, 51.16771113487982, 27.4813433231846, 0.46715931305962227, 0.09408881977921534, 0.03730075208530311, 0.025653337060864416, 0.008513224836919577, 0.057456873943127935, 0.06938997656106949, 0.026412041812774636, 0.01849305797218075, 0.013278839478809989, 0.11086470507566007, 0.016444653775843403, 0.02974040464558188, 0.031126307496320338, 0.2269283432753817, 0.20133080231326245, 0.13024109115283336, 0.0854793321641703, 0.2205925509934464, 0.15294246736072725, 0.18898414628159618, 0.1321599881855711, 0.11397787189531712, 0.10565810341147647, 0.1977269102128283, 0.3085133823896608, 0.16202203418699004, 0.1653416310587237, 0.18829817583243694, 0.23563114806048333, 0.14605355959746147, 0.19569645545655684, 15.41755453232796, 61.645589566999874, 60.32779086020685, 42.149593753199426, 36.43381003410586, 50.63443745336225, 61.870796372813565, 61.801280206249615, 59.23061763086627, 12.103615556993793, 0.8561095679479261, 9.68975757398913, 10.36953668440542, 39.04329622945478, 37.855814349266794, 47.18552089506581, 56.92055340736144, 61.15521877042709, 59.3254291626715, 57.50004437661941, 49.34492688025198, 51.58931493759156, 49.818419717973285, 53.682064164069395, 56.99789470241916, 52.74460200340518, 50.08182648689517, 49.07698192904073, 47.59669903785952, 49.687918539970156, 50.960276588316894, 50.74069838370047, 53.08878214128556, 56.246745124939956, 53.58895886328913, 53.545000860767985, 53.61001022400395, 54.093740447875, 53.05621470174482, 50.79609009527391, 46.4128767290423, 42.70424827452629, 41.62260763106808, 42.38913682199294, 40.50231595193186, 41.502661551198656, 43.218965222758634, 43.37691514722763, 41.33587060436126, 43.49191511830976, 43.306747867215066, 43.331262680792044, 42.84903472469699, 39.32378884284727, 41.219109489071755, 40.459538582832586, 41.430517396619244, 43.07322563663606, 43.351941416340495, 44.43046769788189, 49.219822883605964, 46.78004980087281, 47.62373201308712, 43.20379741730229, 44.19220724413472, 45.48950764440721, 55.1673206206291, 55.69942151346515, 62.64558215295116, 47.05897738856655, 36.63156809345369, 48.9750159940412, 41.96042568452897, 54.753071261990456, 56.21642520350795, 55.29275801873977, 51.81489436857162, 53.52873479166339, 52.353620144628714, 50.65836783378355, 48.02630447572278, 47.732562095888206, 45.24453209292504, 42.344672833719564, 38.98168363878804, 40.30736630962741, 43.46712181645055, 39.69060105662192, 41.93119618200487, 42.238541341597035, 40.63262885616672, 42.00084963152486, 42.10299207318214, 42.00793343205606, 39.19243651051676, 42.39980174649147, 41.56558813587312, 41.84606505978493, 41.571393243728146, 42.544952977088194, 40.721348947094334, 42.30532753852106, 50.49696622356292, 53.115697445407996, 56.81363351883427, 54.44871887083977, 52.12136091724519, 49.967481551631806, 50.14854992589643, 47.210039631012954, 44.04473789276616, 42.88032739393173, 43.06871883330807, 46.12075036571872, 46.35809298484556, 50.22892321309736, 52.01737496160692, 53.827595864572835, 52.29671832053892, 54.72873687744141, 54.13903205625473, 57.143218517303474, 54.7056576513475, 55.347463315533055, 50.16073673002182, 53.5343437810098, 54.58744133672407, 56.67177315681212, 49.263898557232274, 43.844571498132524, 9.16191049160496, 0.8462378202426819, 19.13965632838588, 16.809080070064915, 17.180106870589718, 7.509162945132102, 0.23996277772370847, 14.153221653353784, 63.50850751323085, 39.816960211723085, 33.10808335581134, 32.88540255638861, 59.956671883983, 34.005772682928274, 0.6511768806845911, 0.2157781327203397, 0.1933096165979101, 0.18014510042004048, 0.11695004023251035, 0.20490910707702562, 0.18646826757298363, 0.10925890817757576, 0.1714047573266491, 0.0998738025044722, 0.24040419758567888, 0.05360371598433103, 0.14274808938705152, 0.14639739517963704], [0.05382785032833776, 0.03127399392636313, 0.07567765852135998, 0.09757645037626067, 0.08373576201378338, 0.049625034519140764, 0.014028612603133005, 0.0557651449625771, 0.05469627610798325, 0.04858355330783994, 0.00860711082725996, 0.03898875021766271, 0.0056695466816064815, 0.031058665763045994, 0.00821826949475273, 0.04289167324802087, 0.018608179919782187, 0.03122936738955398, 0.656111957805772, 28.819867833968136, 53.10844890532955, 30.476537750613307, 25.57145695532522, 41.025407160482104, 43.50707115665559, 50.85891077595373, 52.300275910285215, 16.270555315479157, 0.31518579370552496, 0.5562879433554988, 5.256508002358099, 2.9234275558302483, 4.1070351148805315, 27.45960750887471, 54.151567951325454, 53.495598608447665, 53.32198273751044, 48.61846470063733, 50.78738635586154, 50.24785257154896, 48.759450374111054, 46.45652878669001, 50.630793571472175, 46.22339879312823, 44.61080258892429, 43.06048577831638, 44.65110494244484, 43.755949466459214, 48.65245596055062, 44.70202515202184, 47.454728849472545, 48.546151884140514, 49.795815098670225, 49.31246926707607, 51.112354724637925, 51.303005449233524, 50.858820561439764, 50.747535074910815, 47.43735274960918, 38.40014911467029, 37.21787614207114, 39.941134606638265, 37.898121033945394, 38.89446581563642, 39.48313905346779, 39.362110399430804, 37.199794015576764, 38.975294097777336, 39.35721920382592, 38.7499656984883, 40.13691971378942, 38.095443710204094, 38.1320119673206, 37.842850915847286, 37.693859684851866, 38.10144493656774, 40.46439839947609, 43.34073520475819, 46.517505953388834, 45.83560189893169, 45.32874930289484, 42.49807673115885, 43.85022363355083, 39.39027301726803, 45.24075485044911, 49.65559036500993, 54.080984900074625, 52.34211583291331, 51.583313711227916, 48.32947231108143, 43.789120951006495, 44.87167550671486, 52.944191809623476, 55.99999273976972, 54.70243346306586, 51.20628372315438, 49.26832691315682, 49.857643419696444, 49.35636058930428, 48.098001480102546, 42.89985295264952, 40.25858379179432, 37.772252175115774, 35.92539241237026, 37.21174155512164, 36.1205695521447, 36.99155538312851, 37.62177044345487, 38.3767286423714, 37.883674944600756, 38.04452742299726, 38.32182722706949, 38.232432488472234, 37.897120829551454, 38.39434792918544, 37.37103685255974, 37.43714055707378, 36.64100531608828, 37.87347285978256, 40.014800640844534, 43.70062835754887, 45.43877570859848, 45.97669739877024, 46.86627134200066, 45.868612566301906, 45.32425426667737, 43.15654854620657, 42.10660457611084, 39.0358829498291, 37.25345203953405, 38.30239972760601, 37.51569778688493, 38.28186219738376, 41.608561623481016, 40.629212471746634, 40.90053850604642, 44.02904448970672, 45.34215596414382, 48.85094750312067, 48.09824466705323, 47.96256988279281, 50.81469781937138, 51.11200171132242, 52.97896754357123, 50.90421807381415, 52.14019221644248, 39.335983491713, 10.436653341016463, 0.1337048810936751, 3.6788794830922162, 7.460651070840898, 10.401411825610746, 10.536929715064264, 1.2719655661813676, 0.015807063694322304, 13.221327297149166, 50.48926661091466, 28.001985011562226, 28.823421501344253, 26.639928240929883, 43.01344479283979, 11.575189925009205, 0.04809510330819795, 0.036975946127166676, 0.030726942030953306, 0.028470309391137094, 0.04809946234848711, 0.029849062726322203, 0.029214253543966243, 0.017292764818956776, 0.045061804985086766, 0.036142549717858914, 0.027055115168613773, 0.005686571549308757, 0.06366343102267673, 0.07626294969551026, 0.03360672207969812, 0.13856310427429216, 0.03663563071900318, 0.05018227921438314, 0.05647769483226923, 0.009234231359685862, 0.058104949853112625, 0.03389231199699064, 0.05383946422126986, 0.03335192123608243, 0.02833937538877851, 0.037169528884753104, 0.023381765706524737, 0.045556307079330574, 0.018560431574681596, 0.018433697649367878, 0.0579328635226815, 0.06195254601357926, 1.5772672934878258, 37.92736230358001, 58.79895687103272, 32.52307165053583, 27.933041511043427, 47.64717601960706, 50.71389682831303, 57.03453356219877, 55.780865607723115, 17.958332569368427, 0.5069912273076274, 2.4485663012150796, 10.401576565157983, 4.351142106517669, 7.715227603912354, 30.7941516753166, 55.656687290437766, 55.35435099755564, 56.18488934732253, 51.723267801346324, 50.63176631927491, 50.544203327548125, 48.83378713361679, 48.122716334558305, 53.26987404977122, 48.92123245423841, 47.402529947219364, 45.093305110931404, 46.84083084906302, 46.18484189433437, 48.908990736930605, 46.71428342019358, 49.23934844232375, 49.14483108828145, 50.753022470781886, 52.48489010718561, 52.40823130453787, 52.77050141365298, 51.979869258019235, 52.295302344906716, 48.86310685065485, 39.99481224244641, 38.795429891155614, 39.886115520231186, 40.17071093282392, 40.572181209441155, 41.327625782259055, 40.26746796023461, 38.6560720013034, 41.27450512301537, 41.9317727704202, 41.026619172865345, 41.24627582488522, 40.70913076400757, 39.88410334433279, 40.024673246568256, 40.47361596938103, 39.29333163845924, 41.32253846814556, 45.411570149083296, 48.857144847992934, 47.27877916828279, 46.79541764720794, 46.2071523358745, 43.54380415331933, 42.45072587843865, 47.705627179914906, 52.17361865505096, 55.93659547067458, 52.86864696010467, 51.49347574480119, 47.619978304832216, 43.87319303327992, 46.648556263216086, 55.27924545349614, 56.691506601149044, 55.64239809590002, 55.50151440405077, 52.29262336607903, 50.750939692220385, 51.55071489272579, 49.22825205710627, 45.60917523599441, 41.80719437137727, 38.49280726525092, 38.46012215460501, 39.21058139493389, 39.06425345328547, 38.0960516775808, 39.28869147454539, 39.2868479605644, 40.27249643879552, 39.85428156391267, 39.71899901666949, 40.1698637008667, 38.632333817020545, 39.42229132498465, 38.76637689528927, 38.34329828139275, 38.71872009769563, 38.42983361213438, 41.378793101156916, 45.969472392912834, 48.42540956312611, 48.76428665653352, 50.448179783359656, 47.67311857592675, 47.511332573429236, 46.08909291605796, 43.77070934541764, 41.23143749852335, 38.531905451128566, 40.79597596199282, 39.55928794799313, 40.23623804892264, 43.70770431333973, 43.77183898802727, 43.915789973351266, 46.74912583443427, 47.32603980648903, 50.349661611741595, 51.53673556543166, 50.01508735841321, 53.80588554566907, 53.70877942731304, 52.21567038566836, 52.68620967864991, 55.00178090987667, 41.88165272435835, 13.914315969713273, 0.42027932862120293, 4.4471470194478195, 7.180666404385721, 4.846623751424975, 5.563418759453682, 0.5317224454014532, 0.09593328370922997, 15.133935789908133, 54.14867324213828, 34.69056360183224, 27.982475142325125, 28.563109482488326, 52.12551470725767, 15.581172281695952, 0.026458861276267037, 0.06911339583776652, 0.028426203794116457, 0.030260478754738168, 0.04525212037767615, 0.023226780373783364, 0.023033050144271507, 0.018573409104118907, 0.023745128869890206, 0.028591912442577944, 0.014154703014590328, 0.027869874573943597, 0.016211544711803718, 0.01442290273600168, 0.12331166499925238, 0.17508171889330112, 0.207501272821138, 0.13359407413630717, 0.15813933204739325, 0.09017837759588035, 0.11606173830166941, 0.25407342780982295, 0.1260653067560446, 0.1797054425602959, 0.10010045727774983, 0.14959472441865554, 0.11890642194738311, 0.1614216970460069, 0.16892384287090073, 0.07024339850871794, 0.28115993726157373, 0.11501908497584444, 2.0710545970547587, 45.36829071660196, 65.626575639171, 41.92714437361687, 37.4219923634683, 52.36324956340175, 56.43462665619389, 63.409789300734005, 62.53644612527663, 21.104393120734922, 0.5730061269094867, 4.458185549705259, 10.620141817677407, 3.752299143422035, 7.1779138811172984, 33.605314377815496, 55.455693275697776, 55.75688815885975, 54.835813660775464, 50.17710085838072, 50.48534424074235, 53.11069250106812, 51.14316886471164, 51.383943557739265, 53.37845310088127, 49.67895984649659, 50.758050949342795, 47.60566949844361, 49.16148547203311, 48.64093203698435, 52.02600025361585, 47.772515358463416, 51.006431118134536, 52.947223801766675, 54.04464414042812, 55.09413311558386, 55.28764324803507, 55.572987833330714, 55.0270958869688, 55.157699046596406, 51.94336375882549, 42.062575970926595, 40.53487162436209, 42.45791950533467, 41.33931836774273, 44.04409070168772, 43.18909637389645, 41.17508480625768, 39.37611718331614, 42.17985876144902, 44.03968195761404, 43.01221316860568, 43.44350130327287, 41.69172371587446, 42.519312443271765, 42.658231027664684, 40.71787764949184, 42.014158233519524, 43.011067836515366, 48.05375322218865, 51.03006732079291, 50.494569655387636, 46.88575375464655, 46.68295544962729, 46.82581993841356, 44.20019318980556, 49.600614424674745, 53.327729009812884, 56.0045583786503, 55.25023560370169, 54.08309513522733, 49.40722588569888, 42.843111945736794, 47.81606151211647, 54.61147369876985, 58.57024738865515, 58.96512416101272, 56.83979572788362, 54.10985354454287, 54.24187660217286, 53.31566772153301, 53.061447143554695, 48.3123040968372, 45.32593696348129, 42.09019730168004, 40.72244328837241, 40.35538396527691, 40.34189101188414, 39.467331901673354, 41.9373974492473, 41.373646951490834, 41.64010924677695, 40.07987668437343, 41.96103365190568, 41.620152227340206, 41.23725045111872, 40.54190443408105, 40.11127917997299, 41.1878050527265, 40.258222933738466, 42.174128178627264, 42.79966385133805, 47.442126274108894, 49.22928756283176, 50.79786692896197, 53.373726644823634, 47.88593069199593, 48.28949159191501, 48.25066404957926, 46.596306370150664, 41.98803132580173, 41.33632559930125, 43.2518974427254, 41.35932245562154, 41.70367125541934, 45.078564843823834, 45.40434514322589, 45.016999321599165, 48.05895820740731, 50.53350310171805, 53.678777217865, 54.381532592158166, 51.616849976201216, 56.02428005587671, 53.584169649308734, 53.75065465127268, 51.620062397372344, 57.14493259306877, 45.31272249837076, 18.03676232214897, 0.38538285921658244, 7.938591386041335, 14.186965803946219, 20.24550780173271, 18.069072846443422, 2.7783454570078083, 0.21336674840459902, 16.919989009057325, 61.974484228318744, 37.82469818668981, 42.71095944989113, 35.881818802126, 60.30346039802798, 20.837271867259858, 0.12486424176923691, 0.10745232729541679, 0.09527949661376978, 0.16298764205027014, 0.14709784469056517, 0.12670109844616345, 0.21613050252199176, 0.11732536968925308, 0.11205685279902913, 0.15668954129420942, 0.1599371565445777, 0.05249515228394059, 0.20881037918790696, 0.20917431691721564], [0.09035673818641132, 0.039753432370602124, 0.026470488575737805, 0.06237607772251772, 0.06536031577495799, 0.03939632048469879, 0.11841146020038475, 0.10106670099400705, 0.019086992533336726, 0.06844696063067644, 0.04909746807008501, 0.027935252517401695, 0.07161751509674134, 0.0222874665632844, 0.06368986105606442, 0.016870483748554703, 0.047077987523328875, 0.03654533576580786, 0.05987182439815614, 8.828261917637242, 46.81974026464647, 45.870326642067205, 30.895062492739772, 29.938059083877075, 44.967295046775575, 49.667859538908935, 54.59990270676152, 18.20802673216789, 0.02769922274315069, 1.3464100682927718, 0.6081263552750311, 0.18283201591862788, 0.28806300232968024, 19.302775936741984, 49.881762073886016, 53.09157486884825, 50.71479112871232, 50.60956962646977, 52.82178248128584, 53.169508441802, 49.522296459444114, 49.16576085552093, 53.31478126587407, 44.65221105083343, 43.32747367120559, 42.52208163661342, 42.669802019673014, 43.21770614193332, 45.296436817415305, 43.90745885910527, 48.59565611808531, 46.57931466256419, 50.91862493945707, 50.64589077426542, 50.868497048654866, 49.5242537221601, 51.96392482326877, 51.57328813306747, 50.70001948264338, 44.01831680728544, 36.67720879277876, 38.49003414953909, 40.1673416168459, 39.40585267159247, 43.1888061185037, 42.051860055615826, 39.11363217138475, 39.46135028716057, 39.989607257227746, 40.84178924560547, 40.42455104089553, 37.25966115151682, 39.088109308673495, 37.802717224244155, 37.36260767905943, 36.693416026330766, 44.24316275504328, 48.351394437974506, 50.142980160251746, 49.4279360002087, 50.99070241374355, 47.546724119494044, 43.83566771784137, 41.0375076724637, 41.08895740201397, 46.475360085887296, 51.44338707770071, 52.26347623332855, 55.413963179434504, 51.32207601301132, 46.61218804697837, 41.90956431050455, 41.30014957920198, 50.995095468336544, 51.43107475772981, 52.25022646688646, 51.68482072891728, 49.5902358331988, 50.82886934280396, 49.90439414978028, 44.12032981072703, 39.70197985249181, 36.8980029321486, 36.52298904234363, 36.94854267181889, 35.84226954367853, 37.805451116254254, 38.56637524020287, 37.024573895239065, 37.61066621349704, 37.83144858575637, 39.023786360217684, 37.77676682318411, 39.719065696962424, 36.13107365946616, 36.36654530802081, 37.46887645413799, 36.475218496014996, 36.332522669146144, 39.90682171237084, 41.58227389858615, 41.8257942507344, 43.48643948954921, 43.33146272167083, 44.68567279077346, 44.87870439406365, 42.78342916119484, 40.56050823580834, 39.93518829345703, 37.53707470432405, 37.52249525439355, 37.84749107976114, 35.98051740277198, 37.32213666362148, 36.3784065554219, 37.144272865787634, 37.372507741374356, 36.39142097965364, 37.276166485201934, 40.50768567669777, 44.765375352674916, 46.417203103342366, 49.67167208271642, 52.20368754479193, 50.542438260970584, 43.40564258636967, 19.55644346052601, 4.241162278959829, 4.488735420088615, 2.9026620378417354, 8.833372765971768, 4.096529291522119, 3.979537001540584, 0.5823410614844292, 0.053248572944393086, 17.332277182609804, 40.74587552778183, 30.527685457660308, 36.74592871819773, 31.207345916378884, 43.3847677323126, 4.079365244796199, 0.1022139406432548, 0.030428531632247954, 0.029261109396635048, 0.010345616178857464, 0.04751643496415308, 0.07014933057249555, 0.11548406204148648, 0.054541503364640864, 0.014761619893233142, 0.029274408683000557, 0.08087345068493197, 0.052005848096263026, 0.013133879364167732, 0.015998784858252735, 0.024371708352719585, 0.03360942637007083, 0.0350908680458463, 0.027014945348304127, 0.007672901077556514, 0.05941245509611984, 0.005906439741187159, 0.03757183229730975, 0.030564632897655812, 0.06512261401381224, 0.034094923100764715, 0.035965981773070754, 0.07523323559472639, 0.043327355111438426, 0.041054012178773844, 0.02640999635801681, 0.03876204947910963, 0.07793685947094234, 0.042187412449669455, 14.302721811879067, 55.463361509384654, 49.03467132199196, 31.22976226191367, 41.28721360237368, 52.72981074548537, 55.35018544043265, 59.998876587037124, 19.64896236696551, 0.07805870575529915, 0.17955023314683669, 2.3591436157303476, 1.879783892823804, 0.5500938466960384, 23.15706749116221, 51.73274032531246, 54.05777231339486, 52.33702851879982, 51.61575563492314, 52.00200319290162, 55.0561410380948, 50.35263869070238, 49.79971001225133, 55.14811277389527, 48.086791346150065, 45.53486593307988, 44.79490295533211, 45.201307573626124, 45.98360077027352, 48.17328745318998, 47.085457309599846, 48.670553776525686, 48.768252172777736, 52.899143388194425, 52.42661153116534, 52.57421816548994, 52.58656970916256, 52.34772482225972, 54.15191704227079, 51.335204185978064, 45.73809177644792, 37.80327420080862, 40.41771827205535, 40.97760131282192, 41.591558148784024, 43.10306310653687, 43.173014656189956, 39.72242324582992, 40.94775599818076, 42.226703628416985, 41.54057910365444, 42.15378676691363, 39.88726869706185, 41.51068279820104, 37.48911196185697, 39.015478780192716, 40.254441768892356, 46.03071235841321, 48.90999486369472, 52.06594959382088, 51.81700068135416, 52.07710481459095, 47.02262486180952, 46.203590823758034, 41.864645327291186, 43.834812641143806, 47.996259120202836, 52.83326325878021, 55.5957297355898, 57.2546922776007, 51.84686560784617, 45.247356199449115, 43.5886799904608, 44.03018197705669, 52.47735915645477, 53.81418135858352, 52.696878525518606, 53.50322369606265, 52.039465750417406, 52.80832875159479, 51.15479869227256, 45.18263316923573, 40.91095632122409, 38.30496888006888, 38.134647800076394, 37.65183541082567, 37.38631840675108, 38.78083475174443, 40.46441801132695, 38.93076735158121, 40.134636894349136, 38.82648721818001, 40.910128701117735, 39.67794749044603, 40.415023603746974, 39.27789711183117, 38.58552425138412, 38.93723926236553, 37.28719619012649, 37.458364502076186, 40.94069180950042, 43.11096276006391, 44.4697973035997, 45.88005412009455, 44.92955792334772, 46.28248929977418, 47.53689073747205, 43.86714081610403, 42.18156499247397, 41.895094686938876, 39.44213067331622, 39.35358708904636, 40.15223264694214, 36.83974396797919, 39.93025002941009, 38.01627851301624, 39.731758486840036, 39.96134658013621, 39.46116593576247, 39.86828442542784, 44.479764046207556, 45.851287457250784, 48.23254269938315, 52.08720099541449, 53.62181263585245, 50.418393304271085, 50.01954317092896, 23.26834317176573, 6.689977405532715, 3.2497998879801844, 6.157843172550202, 5.838170493802717, 1.8417893638533933, 0.5067694295317896, 0.27118869005672397, 0.036738133283271905, 18.416110430994344, 49.16452530891665, 35.54711511058193, 35.63405444545131, 32.80262289508697, 51.138614992941584, 6.4770118267305445, 0.02541125902245122, 0.04296686094734938, 0.03099965209501886, 0.013109502446417128, 0.0279103584903022, 0.023124544025068323, 0.05954823651981931, 0.019686454418866385, 0.0034603973683495558, 0.06839560209623269, 0.07342414194417578, 0.04468322731554509, 0.03167354708327161, 0.0061192862584345765, 0.16445155946477769, 0.16767361802199196, 0.10552065191610206, 0.2984378859400749, 0.17519088642251107, 0.11266599229026227, 0.16148728949408378, 0.2711730618630686, 0.14515380465215252, 0.17857046797871592, 0.15048393799412638, 0.11033080307947052, 0.13530882405898265, 0.16310272377825555, 0.1620854356236035, 0.14650919805130652, 0.10547973516006624, 0.1939084215630447, 0.19308746642162725, 17.81209876460414, 61.359852744687, 55.53051640910488, 42.08574148916429, 42.29607466728457, 57.173205037270826, 58.50036251929499, 65.20821955896193, 22.724055474804295, 0.18178385442062733, 4.3351584480654815, 1.7416211001334654, 1.1209655913614458, 1.0959836480117615, 25.576157915976744, 52.059897376645, 54.65746348904025, 53.08333789148639, 52.63756052140267, 53.127786190279075, 54.94209812533472, 51.60560846328736, 51.63924670988514, 58.50812881223617, 49.08597592384585, 46.6442612678774, 47.03641199296521, 46.182280586611846, 48.838035060513405, 49.575173931737105, 48.84587980085804, 52.05514738636633, 51.32409211127989, 55.388785485298406, 55.520377082209436, 55.271588986919774, 55.18435939665764, 56.941043869141616, 57.53375322588029, 54.646708350027765, 47.547453680346095, 39.575424578882036, 41.670711578861365, 44.66944986774076, 43.90352079945226, 46.848879552656605, 45.28688976841588, 41.98228505349929, 42.037527715006185, 43.83029407070529, 44.92347824958063, 43.019093005887925, 40.38819459176833, 42.737545274919086, 39.4998405056615, 41.48696814813922, 42.72479364948888, 48.68824366600283, 51.50393278368058, 55.5776789880568, 53.96386684909944, 55.14702627735754, 51.584027582599276, 46.80101879181401, 44.377825567799235, 45.35479384083902, 49.54455983254218, 55.39209204335367, 57.00191905421596, 59.4851912221601, 53.25212924711166, 46.59791846429148, 43.388843074921645, 42.529389012244444, 52.6369329421751, 54.719036856005275, 55.81301335365542, 55.818265407316154, 53.82828227935299, 54.566750834065104, 53.84976902315694, 47.1374914723058, 43.461975666784475, 40.89506679965604, 41.23776035924112, 39.81879195859356, 38.345710539048724, 41.81129717057751, 42.170578433621316, 41.719505863804976, 41.75600744062855, 40.80664873123169, 42.075484491163685, 41.11088737364739, 43.430832047616285, 40.84331896997268, 39.84829602702972, 40.99143943478985, 39.03323142759262, 40.11870814907936, 43.40536409808744, 45.60562549098846, 46.71341265401533, 47.345479073063025, 47.400051009270456, 49.988234812213534, 50.357027822925204, 45.855139224759995, 44.025043672130955, 43.130390259527395, 42.348179432653616, 40.66549831821073, 43.00148156381423, 38.691934231788885, 42.25568602162023, 39.7775835375632, 41.34496265842069, 41.949635244184925, 40.49917413342384, 42.53130312888853, 46.1897252451989, 48.9429819968439, 50.545470253113784, 54.38232883330315, 54.03609729582264, 50.8049193505318, 51.28659425243255, 27.702386533060384, 7.723979392359334, 9.144745219138361, 10.680186440867763, 17.686755503377608, 12.788602594406376, 10.21235848626783, 2.0181760215951554, 0.2875667918593653, 22.134234943697532, 52.4110750229128, 41.78041635021087, 48.148047001131125, 40.8649782980642, 61.026667010399606, 8.941822378866135, 0.2224707074703709, 0.14736484165393537, 0.10551712791165037, 0.16996117188565193, 0.11277330588669547, 0.11339541524648668, 0.2593253282529693, 0.17050218317777882, 0.0996099235189538, 0.12898836885729145, 0.3231155085227182, 0.1583629990777662, 0.1508125897136427, 0.09729982368768224], [0.04546695824472174, 0.04929904495516131, 0.03338293247525731, 0.03912494149840167, 0.035699712593228586, 0.06479219263119083, 0.057088243925283035, 0.02491515388922586, 0.04261243803006026, 0.007985226984601468, 0.10972684234260552, 0.10269977828307499, 0.09440362828993991, 0.030589228150464838, 0.02818114950411743, 0.0559572721531074, 0.044585099113324, 0.028769537588701617, 0.09522552571950421, 2.962716466957523, 34.866407379027336, 45.62413123346145, 25.00886747913976, 28.10590820927774, 38.7578143612031, 45.62437442041213, 55.81371545791627, 33.22180855658747, 0.10419074626218888, 0.49904092004702943, 1.6611622562331538, 1.245377044523916, 0.196082778275013, 7.8546845336114215, 37.035325111881384, 50.03023162964852, 53.643483731054495, 52.238624095916755, 51.17978811264039, 46.74414442431542, 51.52555681044056, 53.510856628417976, 49.96201768998177, 45.48746408954744, 44.383924853417184, 41.20715802715671, 42.96278738206433, 45.181036764575595, 45.10380529588269, 48.30942115476055, 49.461805666646654, 49.21536314872004, 50.477668162315126, 51.50776886170911, 50.27071214491322, 50.20339642801593, 49.41546286306074, 52.87101607168875, 50.467368018242624, 47.99754957998953, 45.04185145901096, 38.890378705916866, 38.613133815027055, 39.0528001323823, 40.75098637611636, 38.357693379925145, 38.89488550924486, 40.1927036623801, 38.49939684714041, 41.03240859123969, 38.72676487891905, 37.411731443097516, 38.81137040353591, 37.5578240425356, 37.10337038963072, 40.04705821314166, 47.11588313502651, 51.445242358792214, 49.72354150587513, 51.26542129824239, 50.1072826693135, 52.45209517017488, 49.693390246360536, 45.88971099545879, 42.16187861657912, 42.58752638293851, 48.63949252713112, 51.58619273093439, 55.99081831593668, 53.23527874485139, 50.229644929209066, 42.94571722707441, 44.10100429288803, 50.958280101899184, 49.18757707841935, 53.51139791550175, 52.93819058325983, 52.24439390244023, 50.8612524309466, 49.36023196866436, 42.95664102800431, 38.6463249114252, 36.56035354060512, 36.460313489360196, 38.20701160738545, 38.44417379748437, 37.82854603182885, 36.51739574247791, 37.0612794353116, 37.13793431558917, 38.549112889074514, 37.913716377750525, 37.69502070642287, 39.6596182546308, 39.156386006263, 36.966726779937744, 35.644072178871404, 36.151387614588586, 38.46649992850519, 42.53684936031219, 46.39825021066974, 44.97001324930499, 45.05312827325637, 46.82906373854607, 45.425761284366736, 45.240586188531694, 42.85873474613313, 41.53105166650588, 39.94490008200369, 38.97229740696569, 37.38475338105233, 35.52947621191702, 36.05564255868235, 35.129178723981305, 36.027036713015654, 37.098757682308076, 36.323752249440844, 39.39961218064831, 39.5565854349444, 43.130731505732385, 43.948596677472516, 46.70220252006285, 49.92019345683437, 52.54264700797297, 47.81047997936126, 37.7023555386451, 6.997765302658082, 1.3133671639427063, 6.815526100897021, 2.9358438186107145, 2.097205529289861, 1.230694632376394, 1.1842830647383968, 0.14198488195336637, 0.10402791427388307, 21.08085301614577, 38.085920195425714, 25.39566613012745, 25.83690335673671, 34.130084360799486, 35.02472600629253, 0.9789173845802585, 0.055911797173922105, 0.01978965795358583, 0.024095993308771043, 0.06834042078304677, 0.11375374521218962, 0.027977327981422988, 0.0037819520014548496, 0.04640799766827015, 0.07296718581910096, 0.011591368989508239, 0.019908437971025705, 0.008448459763800906, 0.04683607610903921, 0.01954260417410443, 0.024264469449858994, 0.017284730471850886, 0.03832994524629847, 0.04421967517344221, 0.0046308468482757536, 0.02024066732114842, 0.03399663402007953, 0.038782607448557695, 0.023131867825624444, 0.05775530349403139, 0.06965135809995475, 0.015453903864498342, 0.024603405899758783, 0.07335081200806365, 0.06051319320836376, 0.01300382157487254, 0.03886941287125792, 0.017402679283892917, 0.028298282432520104, 4.2775501070484045, 43.9134757749496, 51.380182004744015, 30.100521695229318, 34.2439821458632, 46.888060108307876, 50.48858804087485, 60.64413785934449, 33.5134603131202, 0.029401167506171815, 1.3300314761938588, 4.45480642780181, 2.1303203846177747, 0.38946632235761613, 11.281163173337138, 41.15994445739254, 51.53327995730985, 54.457889372302645, 52.68422888171289, 50.93532639165079, 48.26750670709918, 50.83452932296261, 53.359947358408284, 53.3931698337678, 47.41877640447309, 47.12698736498433, 44.68799875628564, 46.01732138664492, 47.189804123293975, 47.8031922155811, 49.85936141783192, 51.23290877188406, 51.36783438344156, 52.29821274357458, 50.94300639244818, 52.823943707250784, 52.19273236490066, 52.82725418767622, 55.2146008706862, 51.12838937390236, 50.471792451797, 44.79888808342719, 40.21672817968553, 39.35186909091088, 42.05973617492184, 43.12162376219227, 39.97492582567277, 40.10393650301042, 42.73720010634392, 40.27444193440099, 42.20053749699747, 41.65950928964923, 39.15357366684945, 41.526768438277706, 39.231589609576815, 39.44804952990624, 39.97140353725803, 49.898679256439216, 54.11412108329035, 51.88848980011479, 52.07953668409779, 50.37008147085867, 55.212070941925056, 50.2328416608995, 47.15168260758924, 44.39088313810287, 44.47328429068289, 50.341569762076105, 52.86418722521875, 56.10581436464864, 53.57706623692667, 50.50779196523851, 42.37532223424604, 43.877813585342906, 51.711002549817486, 51.6949482887022, 54.40067375859907, 55.35195835175053, 53.19388989479312, 54.248799585526996, 49.00870915382139, 44.27781689551569, 39.5786605342742, 38.862886813379106, 37.986833280132664, 40.73364949995472, 38.6668114508352, 39.48679078009821, 38.57429450558078, 38.41096308923537, 39.09616193463726, 38.92808052801317, 39.31829752460603, 40.052576987974106, 42.34726159803329, 41.23894491503316, 37.642606073810214, 38.06594748650828, 37.78498811106528, 38.55232531024564, 44.99919960575719, 48.060189831641416, 47.010312541838616, 47.250400820086085, 47.71067919269685, 46.68421845282278, 46.200841242267245, 43.85724075378911, 41.45722873749272, 42.00665866175006, 40.8155878128544, 38.76621215574203, 38.173867579429384, 37.69646806101645, 36.8925900613108, 37.538420077293154, 39.12515217258085, 37.76876518803258, 40.31995319551037, 41.6082949023093, 44.32465784011349, 46.4311549740453, 48.48479424753497, 53.24590836801837, 54.53561898200743, 47.284596043248335, 40.649518582128714, 9.292598962783813, 2.904769576364948, 8.005887981384031, 0.8601632149469468, 1.6533013361115612, 0.31003697805346986, 0.5956725848297919, 0.1457828700902962, 0.08641803501954964, 25.012403495850105, 42.468251028368556, 33.11059759509179, 33.146612798014, 38.82745996598275, 44.153262030693796, 1.6559007643691956, 0.11590266014419257, 0.04466192241037085, 0.02986068619535335, 0.025590759168769565, 0.06780739212709089, 0.03242490505198798, 0.03493338335125196, 0.027046835673372113, 0.06868457812215052, 0.05169726788036285, 0.012012026911120743, 0.07467658078718571, 0.019216287107537353, 0.043496790777651534, 0.11674495083430123, 0.16059289716424482, 0.17275569209408376, 0.10445580502311069, 0.13758237383538677, 0.12403446895581101, 0.17423928264648686, 0.240571771658236, 0.09510072233575968, 0.2324209791878539, 0.3118451907029075, 0.1861644217804555, 0.16941371013320264, 0.1667600581722875, 0.111521702079523, 0.1732668412789222, 0.0935144913232615, 0.09611669281918196, 0.09142561470188441, 4.979387646721256, 48.570772601712136, 59.90608899824081, 38.12281400926652, 39.980338696510564, 50.826727728689875, 54.10062028515724, 66.94542161880001, 41.02004920282672, 0.21213057360822157, 3.3060863902491913, 13.02934688906516, 3.3945336313016954, 0.5461728861255031, 12.667868118132315, 45.78424238389539, 51.3392795285871, 54.82396810285507, 51.92010018133348, 53.07701895313879, 49.01976239296698, 54.26025290643015, 55.71402841998685, 55.980627998229004, 50.8300107525241, 49.19560224779191, 46.9398275498421, 47.228047232474054, 49.037314999488096, 48.950705143713186, 51.850917416234175, 52.90887086622177, 53.71602404502131, 55.57679645476803, 53.969664112214126, 54.50500488281251, 53.17396425431775, 53.25581627507364, 58.38983797257947, 53.209693124217374, 52.239388958100356, 50.313116888846125, 43.433969943754136, 41.62126618046915, 43.355706891705914, 45.76461092118294, 42.249735786068825, 42.978516086455315, 43.695435139440725, 42.47796281691521, 44.54113737229378, 43.5915276312059, 41.11428414621661, 44.07280245134908, 40.9262849438575, 40.04094716041319, 42.27457223399993, 51.44237118382608, 54.78589757796257, 53.753517981498476, 54.09823548409247, 52.69252861699751, 57.8362464135693, 54.162119127088985, 49.54601503187611, 46.33610025528939, 47.576228187930205, 53.80822720066194, 55.88348657854142, 57.34151786373508, 56.10041326092136, 51.75602743702551, 44.30939982014318, 46.51126154007451, 51.73136749575215, 51.59569271149174, 55.99194011380596, 57.620355236914854, 54.3144404503607, 56.07636520939489, 52.035311960404925, 46.93207302401143, 42.71551724403135, 40.58514072049049, 39.92614330783967, 42.15903097583402, 41.86448843248429, 42.338377429592995, 39.65016534251552, 40.51151390998594, 40.835250654528224, 41.067050964601584, 41.0936995475523, 41.84039331251576, 43.82283764500772, 42.88286124506305, 39.15154972384053, 40.427645790961485, 39.68664730748823, 40.999696024002574, 47.38454980234946, 51.1400858817562, 48.88599780298049, 49.844217146596606, 51.263605240852606, 50.222086521887014, 48.91288957288189, 47.16335165885187, 45.85998335192281, 43.54445918913811, 42.00632133791524, 40.47960150626398, 39.80058039388349, 39.660626303765085, 38.27160912175333, 38.69104777612994, 40.67051110729095, 39.76370619189355, 42.453440158597886, 43.38227310488301, 47.666689811214326, 48.915890186063706, 50.91291396848617, 55.92971563339234, 54.82344250525198, 49.36513100900958, 43.64959047686669, 11.741012046414038, 5.18746595228872, 12.216792606538343, 7.528657124888513, 7.56496258320347, 3.151410419133402, 2.609883825625143, 0.7946478659587523, 0.2557641685369515, 27.036013103300526, 49.75027638096964, 36.15082279328377, 38.80660080140637, 45.21132138467605, 50.7519438189845, 2.472101502841519, 0.22196924163689538, 0.0989057738033514, 0.09995107779339438, 0.21299606910155666, 0.2439136004015323, 0.16267457255913367, 0.14290139890245854, 0.21669556897494102, 0.328887521379417, 0.10067381280203981, 0.13492990164987503, 0.17545802128170768, 0.08509432701694389, 0.12909398173853276], [0.02990397590873463, 0.05315525194389686, 0.09442297967090722, 0.04615821087011888, 0.030891210434117147, 0.030450447492541808, 0.023644089533556855, 0.07714519953174938, 0.05143627704631898, 0.11731609236449005, 0.033658743280196385, 0.05881285722998362, 0.03980685934244145, 0.044632857034523646, 0.038661768569821314, 0.03553142988934152, 0.07919723498484782, 0.039082998184547316, 0.029011263226669644, 0.14617887626011528, 20.935072245136386, 52.83160017382715, 28.36550831794739, 24.92208896144744, 34.879115858385646, 36.048554835780976, 54.50848010278518, 30.865740814516624, 0.2936890907585621, 0.6629985979487819, 3.2580704506366485, 3.080410861199902, 0.10775503927781697, 0.8764476701617242, 23.120975802021643, 53.95232723605249, 53.77492627789898, 51.05739839615361, 52.32699117352886, 48.111819990219615, 50.27488554677656, 54.93953681761219, 49.030741107079294, 47.71489181826192, 41.05696655088856, 41.75215567311933, 44.23278808593751, 46.7345424621336, 47.78454526778191, 49.307570226730846, 51.595582885126916, 53.37929248809815, 53.02772260481312, 51.24029459491853, 47.72490562931184, 48.154538523766306, 48.64614094457319, 51.75415254408314, 51.13576342982631, 53.29082342886156, 51.412898494351296, 47.47451328462171, 40.34179295262983, 38.62847028240081, 38.43663892438335, 38.53627104913035, 39.324961631528794, 38.99327424264724, 37.52216577529907, 39.626505605636105, 38.46068305353965, 38.70925541846983, 38.16271235865932, 37.14009161918394, 36.01248079730619, 40.400012693097516, 50.31214021867322, 53.02628309495988, 52.42211649494787, 53.844995498657234, 54.570794797712765, 50.14407450152982, 50.705279381044456, 51.7928937942751, 47.4022122352354, 44.81108665466309, 47.03408602745303, 50.56721195097893, 51.74382494341943, 53.36099070887412, 47.491940375297304, 51.991012711678785, 52.87730755344514, 51.65070395315848, 53.743680677106305, 51.30049513232324, 54.123628908588046, 50.99380108617967, 49.535628595659816, 48.08121373576503, 41.543575794466086, 38.947355055039935, 36.14404101525584, 36.71583629423572, 37.65480856741629, 38.15687979421308, 37.43880364202684, 37.65767974238242, 39.72658095821258, 39.4574632183198, 39.36571505761916, 37.44236907651348, 38.000043822873025, 36.700033064811464, 37.52709227223551, 39.01653782013924, 38.22361107795469, 35.79553450307539, 35.8265329945472, 46.45181802011306, 50.01872731793312, 50.451227464983546, 48.77624596318891, 50.62185448984946, 47.276716001572154, 46.83089940778671, 46.626206597974225, 44.90561969818608, 43.44419556279337, 44.511645070968136, 40.586725358040106, 37.77996355487455, 36.091520478648526, 36.191536995672415, 36.74348900395055, 39.32545977254068, 42.25951425490841, 46.63619687480312, 48.049548441363925, 47.15740534567064, 49.06508145793792, 50.956338528663885, 51.76727287230953, 51.4049360829015, 42.45309499002273, 17.58313628935045, 0.8388596580874536, 1.3320613027580324, 0.16421476168738258, 3.6128588837962, 0.7934986727852976, 0.23295884951949122, 0.15807369363404092, 0.03583438318943785, 0.07681491604495434, 23.549786959925008, 33.388399462546076, 23.855663191887643, 22.44775587512601, 39.19287189360588, 19.181321705541304, 0.1214633629687371, 0.02312680206922514, 0.07213632516082256, 0.004670242919781876, 0.01596558260761442, 0.04410858859398192, 0.034541916252384265, 0.06869532633572817, 0.033058471256686796, 0.03978358559130181, 0.005176687367155307, 0.010831412641451725, 0.021664784552769798, 0.05057062067451978, 0.043828736675242265, 0.026802905617401968, 0.036125374026596546, 0.05257682491754813, 0.03190843538651544, 0.043845157769899216, 0.012904204289248634, 0.039880851944608074, 0.02355183148005557, 0.026463329484085404, 0.019020812112777945, 0.023518223202817386, 0.020039952284986937, 0.020393026887529322, 0.010957798954369801, 0.0729602680451447, 0.03647325072257269, 0.021283094651035724, 0.039010223662180286, 0.03369975196678312, 0.4333128131205036, 27.651395720820275, 54.57157142700688, 33.21035915805448, 27.50077670620334, 41.88510833248016, 40.439644321318596, 61.81902500890917, 35.66100112853512, 0.20105393813742747, 0.17935811361718565, 7.2981747311930505, 6.194775719796458, 1.2246892384944426, 1.6657455457795052, 29.490212663527462, 55.175541908510276, 53.27331004604217, 51.69418734888877, 52.4952922328826, 48.776438159327355, 53.459371597536155, 55.35552770860734, 51.06141882558023, 48.611635854167325, 43.91102821596208, 44.837343000596576, 45.3745194404356, 46.90241990550872, 49.376819672123084, 49.61393479377993, 52.152732033883375, 53.84140652994956, 54.16754768740747, 53.75887201678369, 51.063823238495864, 51.88287296602803, 50.54674894578996, 53.419559540287146, 51.93993952966506, 54.11713346358269, 51.65791719190536, 50.10102256651848, 42.11385311618928, 40.03539700661936, 40.2571129029797, 40.48996048588907, 40.98542251894551, 39.94841452567808, 39.300109494117, 41.520135710316325, 40.006277330460094, 40.0667602785172, 40.54883133980536, 38.925479996588926, 37.33586495922458, 42.309194995510964, 52.41233410373811, 53.56044323213639, 54.44454546897642, 55.65764827112998, 55.56127955836635, 53.58868821974724, 52.52832643447384, 52.041517150017526, 48.59445195044241, 45.284779533263176, 47.71873574103079, 52.390898350746404, 53.74878760307066, 54.242335519483014, 47.89954523886404, 51.87676191329957, 54.719017244154415, 53.11016690346503, 54.10781391205327, 53.272011741515136, 55.17990750651206, 53.25896986069218, 53.0825847964133, 50.695245958143666, 45.42318036479335, 39.57100799006801, 38.13668351019583, 37.81053450799758, 38.22859641044371, 39.80354178336359, 39.61253804545249, 39.83294779254545, 40.35203426114975, 40.55165152395926, 41.26627991276403, 40.16639632563437, 39.58791732788086, 39.30319247707244, 39.33293188771894, 39.71253495062552, 39.12823515553629, 36.85878707516578, 38.653122378933816, 48.352002405351215, 51.26777864271595, 51.88281805284562, 52.37272208736789, 50.94561476861277, 50.689291800222094, 49.92612800290508, 50.45489095872449, 47.847358103721376, 45.74591298257151, 45.36428597665603, 43.58332987754576, 39.365946477459325, 36.735585428053334, 37.80492159628099, 38.11748350820234, 40.956800983798125, 44.39657449722291, 47.657523232121626, 50.485587427693034, 48.96698690229847, 49.978585781589636, 51.84139390145579, 53.84571329239876, 52.41446002837151, 45.744014555408114, 19.73974366341868, 1.9793215129644641, 3.2326696716970016, 1.0614355341080697, 1.1569777299319546, 0.6612272800937776, 0.04333370981077033, 0.07344167769676255, 0.05259881164097498, 0.059413033492502675, 25.077185361616074, 39.49915016851118, 29.105082981048096, 27.439258252420736, 45.16762618095645, 27.469990022720832, 0.39890035806644353, 0.032120287425876144, 0.13333913539686512, 0.035525040716053016, 0.03303235148890846, 0.02175042552182511, 0.021606998540641322, 0.02449878510237942, 0.026770551809139793, 0.06159652580296802, 0.04295432391846853, 0.020708925158326185, 0.03757727918245139, 0.05872101094874163, 0.028700534134141864, 0.09916818956093443, 0.11487519834190608, 0.1312324089268523, 0.19621952496949704, 0.10227992379617307, 0.10079975765679153, 0.10802778956149856, 0.17471241854852246, 0.10060774537944987, 0.21073189624134572, 0.11374789230044811, 0.11635311218279025, 0.11931499962003962, 0.16406687607447948, 0.15457958193315616, 0.15360522534578078, 0.14475785976936742, 0.09654456824665109, 0.1624300985807373, 0.511204588317102, 31.73617163012105, 66.84395774718254, 40.706083082383685, 34.89535054852886, 43.59984697834138, 45.062000674586145, 65.55193293479182, 38.307545877272084, 0.5448894743477145, 1.8213198622388227, 8.51982633913717, 9.730849304506856, 1.6612098149714933, 2.131966064053197, 30.12326751985858, 57.00947353916784, 54.69064281832788, 52.556645947117964, 53.07880755393736, 52.40090039468581, 56.242716850772986, 58.58593686934441, 54.969774369270574, 51.02088897458969, 46.738735475847804, 46.884694714700025, 49.703164792829945, 49.4983817685035, 51.72525252065351, 52.69635685028569, 54.011154943896884, 54.068735338026485, 55.83797923980221, 53.85147917655207, 55.131795713978434, 52.742750644683845, 52.19630956649781, 55.435975520841545, 54.90046216595558, 57.180551636603575, 55.86534169412429, 52.73083056173017, 45.120651875772786, 41.30111840463454, 41.71292020428566, 42.71671748930409, 43.4318361743804, 41.8872421018539, 39.34065111221806, 44.20100119806106, 43.00355257526521, 42.39118822159306, 41.89489072368991, 39.962472300375666, 38.11453780820293, 44.94098771002985, 53.4728253272272, 56.447354747403054, 55.96446783311906, 56.96380930562174, 58.31875678031676, 56.11614981005269, 53.1869629890688, 55.3245331395057, 51.396424539627574, 48.032148807279526, 51.00128889083863, 53.393781723514685, 54.91337460856284, 55.60804990030105, 49.51962924772694, 54.48961350225634, 56.49984782741916, 55.38084660806964, 57.36770360700546, 54.36491350973807, 55.75247157004572, 54.49704639373287, 54.05945108782861, 53.06505180174305, 48.46827714673935, 42.13565757197719, 40.423950918259166, 40.513243675231934, 40.6793874309909, 42.62680892021426, 41.109373338760875, 42.35484353957638, 41.41658513776718, 43.10575777484525, 43.38161022432389, 40.529925515574796, 40.75171985933858, 41.38127988384616, 40.43150148084087, 44.03744620661582, 41.132731053137014, 39.50319805452901, 39.591667113765595, 50.71598745161488, 53.59878047820061, 54.579514226605816, 53.02992697684996, 54.87772026369649, 52.63512865189583, 52.371572832907404, 52.22422899738435, 49.604658388322406, 47.88188672834828, 48.55571854499079, 46.181354907251176, 42.0011830329895, 39.73369221533499, 39.23989718960178, 40.16317213735273, 42.72043589622744, 44.5637341468565, 51.045921541029415, 53.72747736592447, 51.00973767618979, 52.11317493069557, 56.6010332107544, 55.38719300300845, 52.59752881142401, 44.87644118647422, 24.743844693706883, 2.0567872207010947, 2.9312210602145043, 2.782332055991696, 10.078472302805993, 3.962563680064294, 0.8434317321065934, 0.37779751624311175, 0.21811355175750874, 0.3354125067351326, 29.927103903985795, 43.79576152370822, 35.4507307083376, 33.677003537454915, 52.98013248751241, 32.97734683559787, 0.5658859218801222, 0.13886082136342603, 0.2703706307276603, 0.117093336978747, 0.0937910414030475, 0.0806855676215022, 0.12271211692883123, 0.11484895216962022, 0.12546734448762673, 0.11979102367354978, 0.13808728706452156, 0.08020281731601685, 0.09501982345095566, 0.19467133788331864, 0.15606168627498612], [0.07362399130098282, 0.017277502432285298, 0.016730257099674597, 0.030788225234456124, 0.036140760902555726, 0.02736577148278875, 0.03880545219045974, 0.05836320192282719, 0.04184555337433854, 0.07088190215008874, 0.015132589352076814, 0.024808665752531062, 0.033913888863378, 0.033202744765026916, 0.07343218586738072, 0.06982353636093679, 0.04631838836376706, 0.1054814282143789, 0.10037116210667357, 0.03315459230854627, 5.913416262595884, 46.6139256569647, 39.55430653787429, 23.65655387601545, 41.03411874463482, 41.31568216508435, 42.245993844924435, 39.96952472194549, 1.076844810478149, 0.38803597491595054, 9.630516056091556, 2.9702096648754615, 0.7904011648028129, 0.16078962854320006, 6.519041003719454, 37.602103679410874, 52.15197109406995, 52.95381338365617, 49.63113046461537, 47.953846531529585, 51.96145765243038, 53.98063498158609, 46.105123642952215, 45.27166312740695, 42.22460908274497, 42.837353906323834, 45.05098273677211, 47.060087419325306, 49.30974321980631, 50.67421420927971, 50.02415195588143, 53.06624027990526, 52.26636309777537, 50.48509713142149, 51.4819125975332, 48.218986988067634, 48.42198533396567, 49.535044162504136, 50.333332784714244, 52.04109745640909, 49.07228292957429, 51.655026405088364, 47.6477643751329, 39.85735670212777, 38.99674946261991, 38.20004155558925, 36.72908213830764, 39.206207952191754, 38.09876203536987, 41.0980494560734, 39.051152736909934, 38.92841392947782, 38.078824627783995, 37.81608858416158, 37.742975604149606, 38.49416832770071, 48.700956067731305, 52.47437031038346, 51.35969154296383, 48.806903208455736, 47.57983676848873, 55.157844174292784, 53.299687985450994, 51.66371053264987, 50.85165831350511, 47.951528410757746, 49.52018230192123, 51.29447821647891, 52.883971660367905, 51.777200391215665, 49.8766355360708, 51.39448688876245, 52.33230598511235, 51.94439534218081, 52.97326049497051, 50.16284696517452, 54.170697350655836, 52.78876004680511, 49.988713341374556, 43.223809349921446, 36.459921252342966, 37.628948380870206, 36.44101935048258, 37.20723475179365, 36.98210247101323, 38.42478159935244, 38.943366004574685, 37.97446604697935, 37.27001228640157, 37.53183049540366, 38.88322430272257, 38.51243872796336, 37.39557127798758, 39.64004170510077, 36.91007206516881, 37.31735921675159, 35.27138425457862, 37.16546543182866, 35.36858450981879, 41.1863459310224, 51.897217073748195, 49.96672061181838, 51.11720277417091, 49.14130487749654, 51.16891530252273, 51.04564697511735, 49.565136586466146, 49.537503488602184, 47.3405094300547, 46.957768471010276, 43.774863135430124, 41.8319288376839, 37.131705591755534, 37.24315581783172, 35.47059751326038, 38.552913665771484, 41.19149208068848, 45.081714507072206, 47.419753074646, 48.86269500178676, 49.3211494722674, 50.5583042483176, 51.120799587618926, 47.96079304910476, 33.91099253008443, 3.9152093952701943, 0.1576414208618864, 0.6950083254806457, 1.0352712412995677, 0.7765067200506888, 0.27845638233327097, 0.03331199273346894, 0.15482785570765698, 0.10730177569653719, 1.2228291770142894, 29.19671347064357, 29.393922398167273, 25.958273256978682, 28.831389796349313, 35.49133508436142, 7.940402050172129, 0.039405390965722265, 0.002627867356603665, 0.04959801459805139, 0.002547459965083568, 0.025286428825629335, 0.014841846535883605, 0.09612817647716693, 0.13132602487119938, 0.08210038646094261, 0.08231264644212301, 0.015849162140981327, 0.03242140403017402, 0.022696258740559704, 0.03808660890846964, 0.05131792412289689, 0.023115395020032604, 0.014237274843898994, 0.0868346412936526, 0.03989445000526406, 0.0652160844014537, 0.013514328203464468, 0.04640660721868758, 0.03510736957973531, 0.028892069521750656, 0.06324000273560805, 0.05999099703565721, 0.060674163603013566, 0.03161458321095955, 0.008311444938543343, 0.017977168618310845, 0.030919092204121333, 0.037239388442568244, 0.08998708544118751, 0.04942692418192183, 0.06490722073302155, 9.91384062074846, 56.70722353842951, 42.23283821536649, 25.7256825893156, 43.41719788889731, 44.99790522360033, 49.366692112338164, 41.72760948058098, 0.8581919175001883, 0.23960973376468306, 4.172602190125374, 5.383051018561087, 0.5100091234330209, 0.5594119273366467, 10.361633108508203, 41.60245841549289, 55.22214358852756, 53.54444388420352, 52.21096354146158, 49.5573506816741, 53.260001444047504, 55.82341155698223, 49.4177064587993, 48.28037600363455, 43.54489064985707, 45.82252471677719, 46.752644200478834, 48.17647634014007, 51.42501469581358, 50.44970950772686, 51.98708249676613, 53.02643998976677, 52.26011476209087, 50.880444588199744, 51.16170990851618, 49.14267770705685, 50.357349457279334, 51.06766323889456, 51.91833511475594, 53.79733477869342, 50.256030713358236, 53.33915095175467, 46.73134180807298, 41.770892835432484, 40.58128110824093, 41.30780996814851, 40.07987668437343, 41.43544781592585, 39.72297630002422, 42.533201556051935, 41.17156644021311, 40.773422333502005, 39.764863291094386, 39.76157242251981, 39.64386209364861, 41.65294324198077, 51.70084361107119, 54.7151929332364, 52.6484803999624, 51.48144191311252, 49.98891730462351, 58.9852459199967, 56.01112050394858, 53.801708221435554, 51.88840743034117, 49.931611476405976, 49.38919867238691, 52.045459132040705, 55.49107697702224, 53.93186030849334, 50.82743375532089, 52.66306769463324, 53.34561501779864, 53.139031625563106, 53.879010292791556, 51.7705794303648, 55.02847263889929, 54.42499245366743, 51.25041823233328, 45.61370557354343, 38.50287598948325, 38.76229763031006, 36.74954906586678, 38.735896156680205, 40.04856440328783, 38.2005161623801, 40.021700089977635, 38.59840531503001, 39.041742970866544, 38.61900952554519, 39.73288812944966, 38.6238811092992, 39.5386209795552, 40.181042455857806, 38.990018675404215, 37.93381460251347, 37.391797957881806, 38.799156142819314, 37.30578822474326, 43.934958596383375, 53.261833190917976, 50.40214292464718, 50.860350285806966, 49.16980874153876, 50.77052800886093, 51.76337403635825, 51.644145750230365, 49.78722903036302, 49.015514466070364, 47.23117728387156, 45.39741431513141, 42.23730579499276, 38.96520576169414, 37.917356337270434, 38.56734014326526, 41.36191514230544, 43.83938220239455, 48.058318861069225, 48.55496937228788, 50.20265510005336, 53.33785264722763, 51.201600413168634, 52.45241680452901, 47.61414574038598, 36.4021525844451, 5.165372711996879, 0.6010709306405437, 1.8182294022652412, 0.7929959352458678, 0.5501319672311507, 0.07973799346795968, 0.068054286943328, 0.06832535949445541, 0.12199092941779284, 1.225077185419298, 33.217054643938624, 32.84982862011079, 27.039262786988292, 32.13278405127987, 42.97010652480587, 12.450178534753862, 0.05387060186495224, 0.039744572563757824, 0.04993814231467344, 0.0688033600548102, 0.08562335669393502, 0.0049263532949431295, 0.05233995819223985, 0.06892179724790397, 0.02745260371856632, 0.09309838300630932, 0.004096185946236215, 0.0470723720988439, 0.03079577886138953, 0.015045701574924734, 0.032968214607887694, 0.10745827979858845, 0.06429055059749274, 0.1971641879889273, 0.17657369044759583, 0.20824192662633237, 0.16030120152619579, 0.0850540767574022, 0.15378090462857677, 0.1940277627398891, 0.11763833958895938, 0.1649784747390978, 0.15969159472132885, 0.14166177671042182, 0.13139151006696687, 0.17240235702164713, 0.1758642930297121, 0.20334716105172712, 0.2508330291077014, 0.20763153841178264, 0.11003901551087057, 10.356834088602374, 60.679023419657064, 51.95290296308456, 35.85375816591325, 52.17861967702066, 50.452819947273504, 50.69067247452275, 49.68039151160948, 1.6226792696022219, 1.257452183673459, 23.029984658764256, 10.602839262254777, 2.7621458230480074, 0.8991767021436846, 10.125501521172064, 43.44055168090328, 52.90093983373335, 54.60359365709367, 51.6789803197307, 53.6798950933641, 56.807083160646506, 58.147423728819824, 51.501108677156516, 50.54751380797356, 45.53655647462415, 47.59630680084229, 48.16888263148647, 51.48996130112679, 53.18012629785846, 54.014947875853515, 52.31595362386396, 56.98976362905195, 54.56087904591715, 53.789992101730846, 53.47317441817253, 48.919385017887244, 50.892658848916334, 51.715921202013575, 52.75773409874209, 56.226066389391505, 51.39074494761806, 54.50525199213336, 49.97394561767579, 43.57542630164854, 41.97202021075834, 42.192041643204234, 42.42138262717955, 43.67183816048407, 42.12133307610789, 43.58665996982206, 41.97788807653612, 42.248166837999904, 41.725836569263095, 40.281898360098566, 41.62555725343766, 43.62143570376981, 53.48471795358966, 56.844294686471265, 54.586162644047896, 53.38174004708567, 49.70266665181806, 59.408959957861136, 57.10703465246386, 56.182155455312426, 53.04808362837761, 53.59860789391303, 53.103149783226755, 53.83917862369169, 56.72164217118294, 54.934829973405414, 51.871239216096946, 54.62653952260172, 56.43170449041552, 56.32647122106245, 56.720139903406945, 53.32613652752292, 59.22784059278427, 58.28536564303983, 54.66986602352512, 47.551285836004446, 40.66217999304495, 41.99414630090037, 39.18485849134384, 39.760748724783625, 41.44606959435248, 41.59729265397595, 42.10255669009301, 41.67466532799506, 39.57111781643283, 41.1975678320854, 41.40770489169706, 41.422719724716686, 42.307818243580485, 42.519975323830884, 39.83146905899048, 39.54914469872752, 38.732240507679606, 40.96715604105304, 39.60496002627958, 44.59013562048636, 56.08247626212336, 51.74770416751985, 52.91088304212017, 49.99442823471562, 53.02110164396225, 55.01795284209713, 54.33128310788063, 53.01608493251186, 50.752347823112245, 50.95717007114042, 47.462149973838564, 45.112328606267134, 40.220662316968365, 41.22856632355721, 38.715233110612445, 44.678726273198286, 44.55968626083867, 50.04494836253505, 51.20434999465943, 51.83751859972554, 52.54030927535027, 52.85099629432925, 51.68831163837064, 48.464766625435125, 39.4107085658658, 6.595561052522352, 0.27297444100822177, 1.0894906544877638, 2.9034999541697966, 2.9851462956397765, 1.236551589062137, 0.3039002460577796, 0.34120970856278177, 0.2850181092658351, 2.4592709397116015, 37.61978964651785, 40.46184493649391, 37.65038805623209, 40.265679359436035, 52.295145450099824, 16.579968544744677, 0.13385875751414608, 0.1974389837273667, 0.15380860636791877, 0.16888930762727417, 0.15572404068323875, 0.08227094061552517, 0.212410670675097, 0.1960033349572651, 0.14964306456667764, 0.14509742058092548, 0.11199663828818068, 0.24664439741642247, 0.12958438526238167, 0.09083057888933728, 0.08838693461110515], [0.03408503673610187, 0.014760182520765212, 0.04845084772715646, 0.015603912498561606, 0.008686588618964439, 0.07489588877726948, 0.05216220281116905, 0.05006328660754427, 0.06307499122715766, 0.04211851050175967, 0.06818799992963191, 0.09046484085340654, 0.03014734863573986, 0.05959220230579377, 0.04241676768288017, 0.016765820816339507, 0.020520902283850218, 0.05721848653328996, 0.03204297000211814, 0.007378724272242718, 1.003704557736074, 29.13139816253416, 46.413661203076764, 27.80744721812587, 31.18752814108326, 33.01368367287421, 35.82172416871594, 50.526254561639604, 1.747662653365443, 0.16153235078578995, 0.016148168173047806, 6.309991911534341, 0.5349704743393007, 0.25497454639163714, 3.3612550170190874, 21.41658829104516, 49.1537780146445, 54.388149630638864, 52.47637071917134, 54.42632998189619, 54.2973820624813, 50.40201348643149, 50.35720825195313, 42.45547979108749, 42.10426292111797, 42.38560668883785, 43.61213184172108, 45.25558533207063, 50.7589138707807, 51.55291534239247, 51.18008621277348, 51.21417945431125, 50.08547429115542, 50.27257919311524, 54.09283045799502, 54.07022191632179, 53.80643467749319, 51.31503535855202, 50.71555991326609, 49.0147299920359, 52.37329475341305, 52.127703389813824, 51.706507513600016, 42.55139743128131, 37.183622083356305, 37.395614424059474, 38.94280902801022, 39.05227061240904, 40.47951129175002, 37.253899189733694, 39.91696103926628, 38.318952129733184, 38.471669612392304, 37.86383559626918, 39.85133194154309, 36.43839136246712, 49.58989066462363, 49.283502563353515, 54.30725466820502, 47.22221466802782, 47.538949981812515, 28.42637565828139, 43.405085609805205, 56.881769011097575, 50.51191437628962, 50.769249316184755, 51.25728630250501, 51.39067826732513, 51.97311885895268, 51.888462343523585, 50.55390727135443, 53.8690435501837, 50.729633377444365, 48.91090093120452, 48.47891461464667, 48.81355162589781, 47.78621619747531, 45.23644416562973, 41.71006864117038, 38.341792091246575, 37.324811720079, 37.18659131757675, 36.94691488819738, 36.7490509248549, 35.58877852655227, 36.87019332762688, 38.61983322328137, 37.943742121419604, 37.976317405700684, 37.83576319294591, 39.73071905874437, 39.217759332349225, 37.46737026399182, 38.69436217892555, 37.72816865674911, 36.9631495783406, 36.38358800641952, 36.556925389074514, 35.550562873963386, 35.60198514692245, 43.72169148537421, 50.304487674467026, 50.25473633120137, 51.22760180504092, 50.6485854425738, 48.90058117528116, 50.325009515208585, 48.30175684344385, 47.976576666678156, 49.081904503606985, 46.81531190872193, 44.566303299319365, 41.50149660725748, 37.17860537190592, 35.686410242511386, 37.11996201545962, 39.669114312817975, 43.8358050007974, 46.03768633257958, 49.690362176587506, 51.91523251994964, 51.046745238765595, 48.74451398849488, 45.599216338126894, 16.730132564421623, 0.09019544603483332, 2.256449100471312, 4.477177175783343, 0.6964714921289875, 0.011176860838707899, 0.15031181335929902, 0.12840349137062027, 0.008955981522317856, 1.3593530318429394, 7.468337935786094, 26.88780046278431, 34.74565329090242, 35.19862428788216, 31.775656169460667, 31.143756451145297, 2.229378127282666, 0.006924606024122407, 0.02512102278189794, 0.01696262880408716, 0.04287062881274089, 0.0145577265497958, 0.030310701563834187, 0.06536920239487964, 0.022600658628488743, 0.05002643011750714, 0.017072393881878065, 0.01779079091765227, 0.04190476047956655, 0.05364518432367233, 0.040937402105379495, 0.044640644318273956, 0.04835320982120691, 0.04207765886319741, 0.03676594993580253, 0.06591165393230415, 0.02946247943797179, 0.013452760589819764, 0.08185629552650837, 0.0368178638839914, 0.04114103593653248, 0.07333375122998992, 0.05789425269129777, 0.07065317893941557, 0.03228881336267918, 0.11334033352473091, 0.05122748361299596, 0.011806664594088592, 0.04798143501243284, 0.069742392327997, 0.038545824992921085, 0.04076078053443663, 1.542364817953879, 35.91837921450215, 51.413757493419034, 29.85436747151037, 41.57724149765507, 42.436040524513494, 39.30603619544737, 53.2892309465716, 1.911620913494018, 0.18830588267695522, 0.5894224105342742, 0.8997274274306913, 1.0942260584523602, 0.30500515934921085, 3.6866023848133707, 26.17035188982564, 51.297761240313136, 53.606260438119214, 52.42042987577377, 56.015231147889175, 56.03851433723204, 52.23758859019126, 51.72334624874977, 43.50657693801388, 43.67345809936524, 44.91191902468282, 45.34704323737852, 46.33222887592931, 52.86815666383313, 52.820931326958444, 52.65788232126544, 52.94973019630679, 51.43017653496035, 53.831871248060665, 54.58669608639133, 56.070873891153646, 54.02060785601216, 53.09314381691718, 50.07889255400627, 50.658944422198886, 54.395704115590746, 54.02060001127182, 53.42192472950105, 44.71765187478835, 40.407696616265085, 38.217951097796046, 39.29880726721979, 40.35247356660905, 41.7736110379619, 40.24347482189056, 42.71482690688103, 41.23655226922805, 39.48789296611663, 39.30451039345034, 41.39140744363108, 37.86225488108974, 51.09530418149887, 51.85917008307673, 54.97522254143992, 50.42385716592112, 49.45729101857832, 32.63083092627987, 47.41362633243684, 57.83744273647186, 52.88663494971491, 52.8546872446614, 52.772509667181204, 52.252481829735544, 54.41488450573337, 51.079136171648585, 52.217713940528135, 55.078008251805464, 53.21935784432196, 51.03372296979351, 51.60843256981143, 50.298211882191325, 50.506085734213556, 47.73318183037543, 44.967240133593165, 40.73856030741046, 38.72039887212938, 39.38557794017177, 39.639727915486986, 38.20792944200578, 39.08220614156416, 38.81251573562622, 39.82101594248126, 38.773711727511504, 39.71822238737537, 37.54788083414878, 40.98995677886471, 41.208248446064616, 37.95658788373394, 39.887719769631666, 40.20557688128564, 37.498984567580685, 37.04650778924265, 38.454552388960316, 36.88862454506659, 37.99137146242204, 45.434108088093424, 51.23779604511877, 52.14523638448408, 52.18458167968258, 50.453443604130904, 50.401166254474276, 50.83306235651816, 49.92352354911066, 50.096272576239805, 49.466971428163596, 50.44933688256049, 46.449295936092255, 43.21004967535696, 38.475537069382206, 37.959478670550936, 38.07796170634609, 43.016021790043006, 47.455105397009085, 49.72568704235939, 52.31720093757876, 52.15167299393685, 51.715513275515654, 48.13242420073479, 47.425024740157596, 19.137677492633944, 0.6053300117773395, 3.1311655957852644, 6.212551901417394, 0.7250247535205657, 0.16947769379663855, 0.09097821935410462, 0.027694530454614473, 0.09520043633998403, 2.1536778538457813, 9.205440955777323, 32.05776479936416, 42.595116169221946, 34.14560517957134, 35.19203470599267, 39.029917024797015, 4.0888796890935595, 0.03657781023291811, 0.0347211808266659, 0.03703312309939535, 0.04904114145545229, 0.032067670592016755, 0.04169155437979968, 0.036733257133633866, 0.06894667212280535, 0.06272232648165477, 0.03040703137465302, 0.043266945248169285, 0.0451246127035589, 0.03781996051510496, 0.06144478293736616, 0.02843904534294721, 0.1548540099493919, 0.11782003266196098, 0.19152339067189925, 0.0950656125261899, 0.12577650693034934, 0.1293895997467541, 0.2072999295928786, 0.13708262403886165, 0.17916348131914295, 0.17223584015042553, 0.12006354413085407, 0.20836111458559192, 0.16694494583193334, 0.2774206008161268, 0.16613853103931875, 0.14553562287361393, 0.06924125591232892, 0.17999631082338674, 0.09718813572920139, 0.1326879759829852, 2.036835717097406, 41.372968381451024, 57.498926501120295, 39.59381657262003, 41.5420146911375, 42.076676891696074, 43.566181275152395, 58.6505030047509, 2.770078326425245, 0.4123600632432969, 2.2358635212144544, 17.181728770655972, 3.4134490163095537, 1.6507668721099056, 6.788635801884436, 28.411317679189867, 52.60359279571041, 54.67507885348413, 54.29118471760904, 57.55154509698191, 59.6654123644675, 54.565825154704434, 53.654266326658195, 47.05858122917914, 45.4458987328314, 47.982016994107155, 47.4700221707744, 48.69122858970396, 55.981447773595015, 54.499113482813684, 54.88777722081831, 53.33038837678971, 53.8855645733495, 55.46843313401746, 56.64017454270394, 56.37052336046773, 56.64837229636408, 54.84503515305058, 52.176976203918464, 51.76241305566604, 55.841411313702984, 56.721049893286924, 54.9761599879111, 46.72985130740751, 43.38223780355146, 39.99970343805129, 43.25697691209855, 43.58421241083453, 43.41985333350397, 40.748354465730735, 43.9232385543085, 42.12961712191182, 41.12935389241865, 41.006132633455344, 43.917374610900886, 39.11138857564619, 52.93523703852008, 54.68517503430767, 57.647756914938654, 52.51696332808464, 50.504979625824966, 31.68167814131706, 46.83445307516283, 60.722502893017186, 54.742449483563824, 53.738828705203154, 55.954740355091715, 54.03872136146792, 55.210148980540616, 53.184032978550086, 53.77148635925786, 58.450968111715014, 53.926647478534335, 53.75605575499996, 52.76066018689064, 52.146244433618364, 51.738604268720074, 49.17818300185665, 45.42083870980048, 42.25838853466896, 40.62852997933665, 40.85228943055676, 40.88323693121634, 41.051883159145234, 40.2999294957807, 39.8269465661818, 41.888877730215754, 41.62617306555472, 41.762012589362364, 38.47425837670603, 43.08121942704724, 43.50859303628245, 40.17191117809665, 43.67506627113589, 41.17968574646981, 40.30944908818891, 39.46871649834418, 39.967057551107104, 38.9319440626329, 39.779289768588164, 47.13913102303782, 54.9610863193389, 55.95574448185583, 54.358606338500984, 53.18790043553999, 51.17741115631596, 53.211705300115774, 51.82928554473385, 51.18178852142827, 52.736765107800885, 51.41302008782664, 48.889716209903845, 45.53758805797946, 40.07324395641204, 39.823789058193086, 39.88650383487825, 44.8601790397398, 49.02011932865266, 51.822801866839015, 54.06542877997122, 56.61012526481383, 53.31443217492873, 49.414164558533706, 48.39135946766023, 20.9878477358049, 0.8153236597295731, 3.6180793133474167, 13.031963109970095, 1.1854940965290994, 0.828830709140147, 0.4417635596567585, 0.2685968307477813, 0.23888905953255393, 5.119328008544061, 15.403740925173606, 36.35318179284373, 47.27378206868326, 43.51264876704062, 42.49859448402159, 48.59153762940438, 5.3797346545803935, 0.17196211693508012, 0.20675073648172043, 0.11490165901881073, 0.16996556923033732, 0.09333257608476186, 0.17259603937066373, 0.1619388217166547, 0.18488408967612252, 0.11923130451431198, 0.19308034180393144, 0.14585259941316422, 0.16332406190133866, 0.2538115636355454, 0.08553784595982683, 0.15377845314721908], [0.031937703775662574, 0.02411619504733432, 0.006008649755629801, 0.04396891927406673, 0.03843914724946503, 0.0656974863921923, 0.060171395420066776, 0.050172013636197776, 0.033624028005907615, 0.10038594760361219, 0.032614308799947464, 0.13041686236618028, 0.033436466699406024, 0.017399151449001605, 0.04079468375552566, 0.030957794966055985, 0.06547983315202498, 0.005380028648482215, 0.024449035352576646, 0.046043083176858006, 0.14387619982083, 14.788104334185201, 45.776621218650575, 35.411593298758234, 23.6832259931872, 42.22356965464931, 31.925490710043142, 48.046696878248646, 4.011532755628709, 0.35155119073967783, 0.02116683123242711, 0.5036627284942136, 0.06278828665193531, 0.09174628378522974, 1.1302096372650516, 4.926951441072649, 33.944854351782034, 53.96797749304003, 54.54193399798486, 55.94128662540067, 52.33918974476477, 51.011781231049575, 47.55717331363309, 42.8812530732924, 42.39995864129836, 43.49053052163894, 45.237891520223315, 47.85813285458473, 50.13601010845554, 49.78209072543729, 51.68702902332429, 51.92994925283617, 51.36725387265606, 50.57151086868779, 51.32153864829771, 51.847406894929954, 53.47448056743991, 52.96170519244287, 50.921947186993016, 51.70614665554416, 51.96987898119035, 51.28074207613545, 51.227609649781265, 44.80261433509089, 39.37042190182594, 37.61927581602527, 37.35144461354902, 39.428967199017926, 40.06673674429617, 39.035694676060835, 40.64289369890767, 37.46732711791992, 38.83455945599464, 38.12704232431228, 39.70629445968136, 36.523444037283625, 41.02399902959024, 48.90816311682425, 52.687660955613666, 50.979335384984175, 55.238013498244754, 28.91045693428286, 39.366923147632235, 54.817574639474195, 51.310924714611424, 53.311560999962595, 50.53162820877568, 54.234184834264944, 52.0046547151381, 50.33929870974634, 50.40325687777612, 51.38439855267925, 51.027098086572465, 48.66744725934921, 43.25776530850319, 41.58396051776025, 40.373167991638184, 38.89154364985805, 36.69907992885959, 38.669270776933246, 37.571987721227835, 38.46581743609521, 37.53146963734781, 36.25365557209138, 36.82272088143134, 39.35905095069639, 36.544111005721554, 36.179789497006325, 38.328220690450365, 38.46310315593597, 36.75632299915437, 39.11928430680306, 37.54407613508163, 36.98297715956165, 37.74801584982103, 37.97710580210532, 36.84980484747118, 36.56262067056472, 35.66099720616495, 36.49186111265613, 35.57681137515653, 41.5044540743674, 47.06314686805972, 49.28649140942482, 49.58011219578405, 49.51787987063008, 50.189656365302305, 48.525598664437574, 48.79869368768508, 49.84844546164236, 47.08457477631108, 47.58217842348161, 43.05910118164555, 42.31347430136896, 37.42634619435957, 37.48316172630557, 37.394955465870524, 41.14756937949888, 45.286222965486594, 47.06661816566221, 49.0101251294536, 52.25206213612711, 51.36617914322884, 35.14290701958441, 5.737357245337579, 0.18372107627651385, 3.738568396337571, 2.9745289298795887, 0.22001158055518905, 0.15077969389817408, 0.14978796243667603, 0.023802765494873448, 0.11481629384140815, 0.8799744938169757, 9.688634795527305, 27.16127399475344, 28.031367486523045, 47.713060071391446, 33.24398955991192, 23.964946308443626, 0.35695226382344003, 0.06872639886193699, 0.03751246814405726, 0.012746563504239725, 0.05746062777395691, 0.08199920922878288, 0.06500003228504812, 0.05554143579736833, 0.05461928427159306, 0.024184790560074394, 0.13322684222892409, 0.03385451704924626, 0.03612723945069217, 0.06457424061673303, 0.03826491970328554, 0.04310359615051458, 0.0958060748094032, 0.014117284407538754, 0.021955428735142755, 0.045933662838633024, 0.08599774386253088, 0.07125195326103319, 0.06618331637113326, 0.028430179790443474, 0.053401284911219156, 0.052342210490737236, 0.038624283887686274, 0.01554649325102688, 0.03277976080895432, 0.028133330295883843, 0.007160882382924038, 0.04481595970930592, 0.04370369963468083, 0.04879417386086238, 0.018408301834677978, 0.014577267537524384, 0.2475517213104233, 21.078815344841253, 52.43182043875418, 37.17645983542166, 27.84564522004897, 45.881109237670906, 35.85338946311705, 52.868262567827784, 4.184966481501057, 0.4177208401022419, 0.1573446690435371, 0.8670121635640822, 0.6185453961933813, 0.6695288539894166, 1.8157749791299145, 8.240319221250473, 38.889649145064816, 55.938807687451764, 53.60906493279242, 57.52617520670737, 56.05312124375374, 53.02847177751603, 51.436448404865885, 45.053544044494636, 44.00929143351894, 44.03527321354036, 47.01226195981426, 49.110412290019376, 51.74011045886625, 51.83361191903391, 53.74128018656085, 53.15710198494696, 53.98967604483328, 51.3255786895752, 53.79083933368806, 54.04327523323798, 56.232255889523415, 54.357712038101695, 52.81169806757281, 53.33138073644331, 52.483305469636, 53.838770697193766, 54.24223746022871, 46.841176017638176, 39.70452154836347, 39.788597553007065, 39.18685890013172, 41.90281391143799, 41.106737506005075, 40.8335248116524, 41.35457246534286, 39.47693386385518, 40.35771385315926, 39.467743750541445, 40.72986049036826, 38.95373282894012, 42.89410668034708, 51.62001925130045, 54.77593475772489, 53.081537523577296, 54.44362371198593, 31.123436612467614, 38.92377768793414, 55.02408742904664, 53.47719092522898, 54.44467490719211, 53.090315788022934, 54.987401500824966, 53.5995610298649, 51.32273497120027, 51.76108729454779, 52.662612699693256, 51.94161438172864, 50.658842440574404, 45.77106714248658, 44.584561932471495, 42.103902063062115, 41.65979170030163, 38.348185554627456, 39.82155330719487, 39.59137685837285, 39.42708053896504, 38.65207510609781, 38.8419609685098, 38.48026352543985, 40.25453982814666, 37.59205064465923, 38.13187860673474, 38.488677009459465, 40.94394345437327, 37.64893677926833, 40.249311308706964, 40.63050293153332, 39.20321910612045, 37.672180744909475, 38.664156006228545, 37.763885759538226, 38.69686465109549, 37.917477930745775, 38.226352814705145, 37.82222709348125, 44.00885997279998, 49.134927103596354, 51.16289054193805, 50.146227882754424, 50.150522878093106, 49.82962985192576, 50.762545985560266, 50.46616385059972, 52.46606665272867, 49.83834928081882, 49.8592790480583, 45.57470544692009, 43.748971569922666, 39.80187085367019, 39.49529840100197, 38.94706479964718, 42.44302234342022, 46.66639520275978, 49.91296845097696, 50.03821365294918, 54.21676951069986, 50.43430243769, 38.942075544788, 6.21152522102479, 1.0286812916878731, 5.427664056901009, 8.498630831318518, 1.2389937547906753, 0.16248996069114055, 0.038990983363961985, 0.08894267777401595, 0.5807567303699832, 1.62519620551217, 13.33751476580097, 32.780022198154086, 35.67778887287263, 48.29421412560248, 36.625331524879705, 32.21158054567153, 0.6356029873413425, 0.00326623956601496, 0.01586140997167076, 0.01764162785313543, 0.020260376848220345, 0.005615796037619153, 0.0972802194976999, 0.05860450812765668, 0.04016425851131639, 0.03884033600409185, 0.08359651021178692, 0.022482313365945895, 0.028520945887712222, 0.01007646938124972, 0.0641377198870384, 0.02614267763771838, 0.13461531530464851, 0.1314539921980712, 0.1783940838950296, 0.21126255002473632, 0.2583510789179033, 0.20532307034778982, 0.15753334117752893, 0.14968671625660313, 0.15967955181915916, 0.2526888004954784, 0.06784152134411758, 0.1845915360195983, 0.14334732336142372, 0.17242147857623716, 0.15385150729167849, 0.1936581099946653, 0.10162730115435778, 0.1203559369089142, 0.09611086289007818, 0.1375466894598738, 0.41175096205645995, 22.472280494628414, 60.387034339289514, 45.13581183648879, 34.36157480362923, 55.155879066836455, 41.753991342359974, 57.052847108533314, 5.846186837842388, 0.7113143537313708, 0.17252061035363905, 4.511531745233844, 2.8639450573152114, 1.9506889461509644, 3.2872702902363193, 8.02697660461549, 39.93709848773095, 55.38706356479276, 56.38071760054558, 58.57534646987916, 59.310065238706535, 55.68704643557149, 53.977046012878425, 47.736578602944654, 47.707145137171594, 47.044613668995524, 49.25976437907065, 53.00115639163602, 54.32441896007907, 53.708395035036155, 56.58375909251552, 56.344247402683386, 57.367711451745805, 52.87459719565607, 56.689906274118734, 56.79546902256628, 59.067250913189305, 57.87783922687654, 54.91130751948203, 54.35915154795493, 54.560294612761474, 54.8502322935289, 55.90347105456937, 48.04619089249642, 42.6962270275239, 41.786684297746234, 40.259650676481186, 43.60598156529088, 43.31526725522934, 42.95261275383734, 43.753913756339784, 41.444739910864065, 42.55772813673943, 41.8198714717742, 44.17270914200814, 39.101943508271255, 44.671579714744325, 53.19267003766952, 57.20298367161905, 53.77074895366546, 58.68254876905873, 32.46960778390208, 40.22894244040213, 56.59428281168784, 54.49861141943163, 55.559792980071045, 54.506985679749526, 58.09424815639373, 54.47628136604063, 53.38891798450101, 53.12101617936165, 53.51434361550116, 55.043867941825624, 52.8585547016513, 46.93747805010888, 45.33265990595664, 44.22712026103851, 42.85766786144626, 39.50426886158605, 42.674006800497736, 42.43818606099775, 42.38158233704106, 40.90608865984025, 40.11822961991833, 40.51420857829433, 43.96075994737687, 40.11423664708292, 39.38330296547183, 40.997115104429184, 43.00886346447853, 39.28130172914074, 42.284229109364176, 41.966803458429155, 40.05970001220703, 41.05049464010423, 40.75060590620964, 39.45967935746716, 40.61784152061709, 39.470897336159986, 40.50395158029372, 39.14851380932716, 43.64481695236699, 52.50300753501154, 52.794847565312544, 52.62584440169796, 52.647766528591035, 51.26912401568506, 50.48700340332524, 52.798695410451586, 53.02576534209713, 51.84178221610285, 51.89478520424136, 48.95341157913209, 45.82738453342069, 40.84613915412657, 41.4169930642651, 41.00542268445415, 45.239495769623794, 48.21188749805574, 51.9910676248612, 53.556250218422186, 56.28658071640999, 52.885622978210456, 39.994259188252116, 8.735305666923523, 0.47456707685224475, 9.279474712187245, 10.235851522414915, 0.6432220075399645, 0.31084369928125416, 0.4034368856058967, 0.22434756159782412, 1.3388304556569746, 4.155051054493073, 17.40040679131785, 38.962546394717315, 37.21859393581268, 53.16222852276218, 45.10532717550955, 38.45605857910649, 1.3233091465888487, 0.15141194626208276, 0.09984780914120137, 0.17555482415181978, 0.1421985132319312, 0.14397464211910002, 0.18045872149448242, 0.14923097055044868, 0.16858477235561417, 0.19056257851902517, 0.21917927199073378, 0.14771823801340597, 0.10598489353733678, 0.21420829598942112, 0.1972328754322183, 0.09625910090342646], [0.01457710378623057, 0.053792146800626675, 0.027324651713452996, 0.044834617780701774, 0.05311557241985875, 0.019068476188206868, 0.04622860285904139, 0.017219477017680486, 0.05929752658571928, 0.03166872264456845, 0.014852107326019437, 0.026120053146094568, 0.059967604540889306, 0.04565552695684376, 0.03296616532269024, 0.05775935609915084, 0.1014965299456831, 0.04664743461856439, 0.009265948357360979, 0.06624037459973367, 0.016186160388432683, 2.8865057951019657, 37.46398918090328, 45.08869632597893, 31.53857046558011, 35.25216856310445, 34.57448497895272, 42.889089968896684, 6.635873702264602, 0.8845506740673896, 0.631045438349247, 0.1207531305150159, 0.610923495504164, 0.11672733847292201, 0.14509360546306257, 0.8719485890000098, 9.94380360649478, 40.614005442588564, 55.215016641924464, 58.08685056624874, 53.23037970450617, 50.76078876372307, 46.998294399630645, 42.9756135325278, 42.3741808245259, 43.07183319522489, 44.91768883120629, 44.426980710798695, 45.35513116467384, 46.46029033968526, 46.21468328660535, 46.53284634313276, 45.92445927281534, 45.545213145594445, 48.43826317018079, 49.131577399469194, 51.395891097284135, 48.42054582411244, 49.07094932371571, 51.47115745852071, 54.873699834269864, 51.608291364485225, 51.02701571679885, 49.903743036331676, 37.9326771151635, 38.47033992890389, 38.82907206012357, 40.218359885677216, 38.197558695270175, 39.87330113687823, 40.38185211919969, 38.18798811204972, 40.19096605239376, 39.51736957796159, 38.86116881524363, 37.743332539835286, 37.551736524028165, 41.81236797763456, 52.45654706032046, 49.39182273803219, 52.37308294542375, 57.74248607697026, 47.55680068846672, 46.369012863405295, 48.261093631867446, 51.20495796203614, 53.03829339242751, 52.74537471032912, 51.511169556648504, 47.42409906079693, 48.9191222190857, 51.732183348747995, 49.81567013648249, 46.125818067981356, 42.011463565211145, 40.25555572202129, 39.41767469529183, 38.382259184314364, 37.75163227511991, 38.006013670275294, 38.824914347740915, 36.64516302847093, 35.387709986779, 36.55962397975307, 38.07095635321833, 36.4289580622027, 36.63354496802054, 36.355111598968506, 36.881203420700565, 37.11704377205142, 37.307129675342196, 38.27982648726433, 39.14715274687737, 37.038568912013886, 35.49561046784924, 36.95618344891456, 36.95575591056578, 36.67962889517508, 35.80299092877296, 37.38904837639102, 33.67303017647036, 36.155490413788826, 40.052435782647905, 44.33900587020382, 48.80504008262388, 48.12544630419824, 50.287405752366595, 50.27139071495303, 48.55498506176857, 48.68327402299451, 49.55109842361943, 49.030741107079294, 46.09065401938654, 43.995551370805316, 40.72822093963623, 38.17847244201168, 37.765121306142504, 39.34384392153832, 40.10398357145248, 46.89688151882541, 48.01805180888022, 50.73162201912173, 50.67602242192915, 23.392958833325295, 0.43168729711924836, 1.1300235698300025, 4.223946505977262, 6.232753088397365, 2.0382019276580503, 0.07754949477290915, 0.07005181524061388, 0.12231611841989141, 0.1868281756798106, 0.45888504253760465, 17.184560721920384, 29.02430372853433, 28.97759222215222, 44.21585129153344, 32.85525718042928, 9.47642574387212, 0.06185709528865353, 0.06883151378602752, 0.02220281576287122, 0.08932956749753607, 0.03565246795093821, 0.07837769710609029, 0.04833786508008357, 0.028005311258077144, 0.04967407563761358, 0.026203269446869532, 0.03665689731978121, 0.04692426049000314, 0.05173987769071133, 0.038578816569380225, 0.037275000039728425, 0.0433781965365333, 0.04596885691787447, 0.031481262844716834, 0.061828834305126826, 0.0759500947089926, 0.03107053054977329, 0.08510270035795628, 0.03729440887729007, 0.04602194298058749, 0.021503764362404906, 0.07656444359811083, 0.022962932031781926, 0.03127735896757053, 0.042265775583444104, 0.14914375910114858, 0.01500107599572549, 0.029969493663238905, 0.07984573607363048, 0.030723226504520546, 0.03282602485870162, 0.15642695699728307, 0.06832214958605266, 6.096992011993162, 46.93562276901738, 49.50069204453499, 31.290541348918794, 45.94335725230556, 40.05697788730745, 48.84159657262987, 7.221519360619207, 1.9620206735787855, 2.088636621352165, 0.05068861736705707, 0.4155312688840974, 0.742981915752734, 0.19373854922671474, 1.3644262499386266, 13.76123566781321, 43.91337379332512, 58.51351030411259, 59.033408703342566, 55.16663420584894, 52.89380504238991, 49.553247882473855, 44.31395369191324, 45.4284441855646, 44.94580045823128, 47.014838957017474, 45.93430442194785, 47.89045318480461, 48.71973637611636, 49.72547131199991, 49.66026583025533, 48.58009215324156, 49.22638893127442, 50.67330814176991, 50.922468862225934, 51.771956182295284, 51.05483316606092, 51.18997058560772, 52.67932591899749, 56.70934554069274, 53.64502130016204, 53.50044273561048, 51.37521628410586, 41.63249592627249, 39.924107597720244, 40.142818958528586, 40.09695468410369, 41.35867526454311, 40.638230000772786, 42.502681593741144, 39.99357277347196, 40.53738586364254, 40.38374270162275, 40.840506630559126, 39.06162546527001, 41.1751397194401, 44.92516486875473, 54.28105715782412, 53.08409883129982, 53.65654914609848, 60.995805801883826, 48.51138007256293, 45.74380666978898, 49.20094843833677, 51.54429789512388, 54.12207957236998, 54.50445182861821, 53.956563395838586, 48.557707186668154, 51.7227892721853, 54.07889035440261, 51.20859399918587, 49.37547822152415, 43.36369283737675, 42.49553503528718, 41.45986457024851, 39.38209095308858, 39.159672952467396, 38.92861789272678, 40.828421808058216, 38.47669024621287, 38.27774370870283, 38.38200423025316, 38.77056206426313, 37.36757732206775, 36.96193364358718, 38.234946727752686, 38.041562111146995, 38.24155592149304, 38.44222045713855, 40.56394815444946, 40.366456816273356, 39.07746399602583, 37.91384581596621, 37.222237817702755, 39.18952218947872, 39.1176643679219, 37.50287163642145, 38.58503003274241, 35.69002274544009, 37.152258811458466, 42.10663203270205, 47.161994518772254, 49.620241965017016, 50.63610446068549, 52.21850625930294, 49.90451966562579, 48.95410976102276, 49.13453486657912, 51.646585464477546, 50.62791847413587, 47.07508656286424, 45.06184770214943, 42.0579279622724, 38.97239546622, 38.72683548158215, 40.29779180403679, 43.18830013275147, 48.959777585921756, 48.772515789155044, 51.569357918154815, 51.09885000413465, 25.307542239466024, 0.8618486696673978, 3.483584427064465, 7.844574134196005, 8.863852523988294, 2.2979992580029274, 0.06775172051763342, 0.048973377148110064, 0.10487179842687423, 0.13953209824619756, 1.5302681057683885, 19.567930121575635, 36.104428998885616, 32.01805276255454, 45.65003456607942, 37.675550060887495, 13.74406353119881, 0.048320589797391046, 0.07005769113499312, 0.0223054351555484, 0.08713540741272512, 0.09534764013463452, 0.06374241468767006, 0.04222082154404733, 0.04529042860432979, 0.02029778300634315, 0.018323760201794007, 0.027737850811512723, 0.04626283166749824, 0.07013929482068747, 0.03900340164921457, 0.02228234335029077, 0.009491177249489533, 0.10382781976894026, 0.14911867738250764, 0.10286567462307793, 0.12316626151122394, 0.2052464155900863, 0.22668284273916678, 0.1762947731561238, 0.13712976908972188, 0.1605200728461627, 0.1678536333624394, 0.13951993276996, 0.11736273945819949, 0.13247069812590076, 0.19180682788212455, 0.12410531676704846, 0.12931547307920072, 0.20255615994814904, 0.10213614441454412, 0.11195234308439879, 0.27925688292711015, 0.1988596478176694, 6.529223966983057, 50.316525428525864, 57.73706143902194, 43.61106887940438, 44.78492052324357, 43.486525781693004, 53.69064631000642, 8.669959960445281, 2.9776697677950708, 4.717611603198513, 0.5755359330965627, 2.5526535030334228, 2.1436468824263546, 0.6426573088092189, 1.693379379087879, 16.205318454773195, 43.98493351474885, 60.443226214378114, 62.141322243598204, 58.11788828142228, 55.22000981915382, 53.04965257644654, 44.949628691519464, 46.57756136309716, 47.107563787891024, 49.32467568305231, 47.477513897803526, 51.092993905467374, 50.964344086185584, 52.83188258447955, 49.95538888439056, 50.40947383449924, 50.818686869836625, 51.85040750811177, 52.85500103427518, 55.39302164508451, 52.48380753301805, 53.90955771169355, 55.10164445446384, 58.55987271954937, 54.77585238795127, 54.785736760785504, 53.1414556503296, 43.28065233845865, 41.78062815820017, 43.191614535547075, 43.1261815563325, 41.67667358152328, 42.71769808184716, 44.01991713431574, 41.022559519737, 42.97754333865258, 42.1726494450723, 41.71480686433854, 40.243678785139515, 41.37801647186279, 46.29097338645689, 55.94995898585166, 53.53625397528372, 56.66825479076755, 57.90679808585875, 46.98031425476075, 47.72915355620846, 49.493074801660356, 53.012452817732296, 54.00840144003592, 56.252558077535326, 54.52129840850831, 48.8452757558515, 52.27612587713426, 54.44369039227886, 52.91373460523544, 51.19588551982757, 44.87546059393114, 45.050817997224875, 42.467219445013235, 41.63615942001343, 42.51486447549636, 41.03180846860332, 42.75356815707299, 40.677991067209554, 39.19224039200814, 38.78457277051864, 42.264479975546564, 39.77393573330295, 39.715570865138886, 39.27415909305696, 39.50689292723133, 39.3081856543018, 40.81556427863337, 42.45576612411007, 41.858887287878225, 40.561732015302105, 39.66036742733371, 40.433313615860484, 41.485140323638916, 40.45953466046242, 39.266075088131814, 41.12460782451015, 36.51710548708516, 39.13215360333843, 43.340441026995265, 49.08885494355233, 51.906383652840894, 51.468717744273526, 55.56273475770028, 52.922728600040564, 49.95693429823845, 50.51478162888558, 51.55582181869015, 51.933926536190896, 51.09565327244421, 47.54384117741739, 44.53969786244054, 42.50561160425986, 41.454157521647794, 42.53777503967286, 45.182852821965376, 51.10021891132478, 52.061164302210656, 53.717828335300574, 53.9397011264678, 27.83267394188912, 0.5976566299796104, 2.430581988826875, 9.387966490560963, 13.387753463560536, 7.28354674193167, 0.2605309667846849, 0.2245740325099999, 0.18105766435544338, 1.4592717347606536, 3.303324306203473, 27.616061049122965, 41.279584592388524, 40.9367694393281, 51.481434068372174, 47.20112800598145, 16.6378431166372, 0.10842651534344881, 0.1812829401704573, 0.12467573051370921, 0.18315270032373168, 0.14924267637393168, 0.21781047205290488, 0.1546573551792291, 0.13005542208350476, 0.1326951925312319, 0.09892726256962746, 0.11948833467378733, 0.1477518539515234, 0.11560038483190922, 0.07727859842200434, 0.24010231297823692, 0.10015887914285546], [0.032123418810266646, 0.04944177096589439, 0.029297826075625998, 0.08569108652732066, 0.05171124132410173, 0.05125123233864865, 0.08393785600820858, 0.013028042402208574, 0.01365028486977662, 0.030338732720983606, 0.03858773383281885, 0.021950504705009442, 0.039767601166761694, 0.0691451425213487, 0.026105796249823707, 0.03759506008317394, 0.10383534275235669, 0.04093845547627538, 0.018652540241037647, 0.07586100634427802, 0.049307759205300006, 0.27438934411733384, 16.236364014687076, 50.618049790782315, 29.93267563081557, 34.20465254014538, 36.18106426731233, 40.65859494670745, 14.636268404222305, 0.10306966851555532, 1.2764865881012333, 0.14660992329159092, 0.19423819177093046, 0.14631750753089307, 0.05988895412414305, 1.1419019776005899, 0.6722718777675784, 17.24791092257346, 50.716799382240545, 53.88497621782365, 55.99365418957126, 52.24397028646162, 48.64960439743535, 42.98633337020875, 42.52953413994082, 40.78450695160897, 42.95003183426396, 43.273941163093816, 40.16962443628619, 40.675010065878595, 39.67226397606635, 39.1836464789606, 39.62930617793914, 38.036357125928326, 40.27784262934039, 41.21815243074971, 43.8792021043839, 47.92231852008451, 48.50344119533416, 48.54184512169131, 52.646817315009336, 52.574920269750784, 51.08365474208709, 48.25248010696904, 40.078817644426906, 39.462574066654334, 38.55306271583804, 37.755044737169825, 39.38234590714978, 38.445248526911584, 38.81553203828874, 38.74421550381569, 39.44490771139822, 40.41398809802148, 38.22930243707473, 37.584468703116144, 38.11279627584642, 38.677652881991484, 45.376382566267445, 50.028580311805975, 51.2303239299405, 53.18956352049305, 52.027647649088216, 53.61155956022201, 53.45719075972035, 51.60005046475319, 51.560689480074, 50.649138496768096, 48.611278918481645, 46.199515481149, 50.948866413485625, 49.76649145926199, 49.99947240275722, 47.73606477245208, 42.15440650140086, 40.982261088586625, 38.04990499250351, 39.29341008586269, 38.07740472978161, 38.68001807120539, 39.04843453438052, 38.051403337909335, 39.00867346794375, 39.39450917705413, 37.21118457855717, 36.23572249566355, 36.820940125373106, 37.75694316433322, 37.90646783767208, 37.18156283901584, 34.93658642615042, 37.850817249667266, 38.900682772359545, 37.2107413507277, 38.470473289489746, 36.67812662739908, 36.621958286531516, 36.18819121391543, 36.39628471866731, 36.32265398579259, 37.63414552134853, 36.36145014916697, 36.10378573017736, 37.55978522762176, 42.241247777015936, 45.79703715539748, 47.4427342414856, 47.14711304633848, 49.94213127320813, 47.37331613417595, 48.86593880191926, 48.98839912106914, 46.06525275015062, 46.79071864774151, 45.423050926577666, 42.600450592656294, 40.16510194347751, 39.20771021996775, 41.88689301090856, 45.709532999223285, 48.39931403436969, 50.090208591953406, 45.158463524233916, 9.082063782599665, 0.15933806046603188, 6.744786154839301, 6.703099204647926, 9.630004186784069, 2.5779770603103023, 0.10933526416098881, 0.03140239983857159, 0.12113846508004975, 0.3520009762817814, 3.311715481742736, 26.969387723553567, 29.663004836728497, 30.498503023578277, 47.1965152986588, 27.412703806354155, 1.3803807357626579, 0.08037709465791142, 0.04777294035340029, 0.05625184828175172, 0.012415662359055734, 0.053040798408009356, 0.03141956020807547, 0.0910669323357363, 0.05201383456287365, 0.030947113785171704, 0.04411641418212845, 0.009768330623515913, 0.039812294736264214, 0.02697040882682608, 0.019621832987233516, 0.09474506601691247, 0.06412530926266505, 0.05632114093450289, 0.020236499802840334, 0.09106720046650979, 0.024591824565563473, 0.10646485528277774, 0.08147898956292099, 0.02815421768313935, 0.04393797315236542, 0.04148738811753931, 0.01637629958079948, 0.026162894698040142, 0.0448942385734089, 0.05935947628571622, 0.02857304752744254, 0.039859209960747155, 0.019604153593160936, 0.056848347322234226, 0.0561159136404674, 0.006665272812824697, 0.08274547845846222, 0.06702483331243839, 0.781149764455134, 23.889613266914125, 58.7528415649168, 34.436696037169426, 35.36034753245693, 43.035743467269405, 44.32320656314973, 14.193373976215241, 0.13678601011633873, 2.5289864117099397, 0.36640143742965114, 0.09698647840489304, 0.3566837653277382, 0.2670967693050062, 1.473575883334683, 2.154485862101278, 20.95926738554432, 53.20892826203377, 56.73512727983537, 56.57913069571219, 51.46195165572628, 49.928348064422615, 45.66041315755537, 44.06899382991176, 42.58653010091474, 44.70811659289945, 44.08096098130749, 42.33661628538563, 41.62755766222554, 41.97679765762822, 41.03961006287606, 42.3219701551622, 40.77132778782999, 43.949526279203354, 43.60792706089635, 46.42366716938634, 49.40166004242436, 49.981296139378706, 52.16732717329457, 53.52158431083926, 54.747885888622655, 53.60275383918516, 50.553813134470296, 40.70729117239676, 39.70998541001351, 40.69964647293091, 40.119021938693145, 41.38298611487112, 39.52596349100913, 39.95030510810114, 39.83431669973558, 40.96609700110651, 41.10567846605855, 41.30380522820258, 38.5249863901446, 39.62869036582209, 41.03413443411551, 47.561036848252826, 50.59072263779179, 53.60475817034322, 54.66863047692084, 53.56886456089636, 52.550279940328295, 53.09201025193738, 52.99073465408818, 52.41131428749331, 51.94915317719983, 49.60815322014594, 47.554659074352635, 52.85662489552652, 52.37635812451763, 53.41384856931625, 50.192041166367076, 43.436001731503396, 43.35351428677959, 41.24254565085135, 40.72527131726665, 40.051953331116714, 40.12780804787913, 40.625541133265344, 39.88064773621098, 40.30073358166603, 40.87248571457402, 38.76537669089533, 38.83889759740522, 39.412422641631096, 39.05190975435319, 37.973991440188506, 38.836755983291134, 38.548202899194536, 40.61009091715659, 40.50576371531333, 37.667317005895804, 40.81320301178963, 37.70890981920304, 39.1706673560604, 38.45487794568462, 38.234766298724765, 37.9461936027773, 39.04748532079881, 37.51743931924143, 37.40101945015692, 38.55101131623791, 43.2497009154289, 47.46778641977618, 49.65149541055003, 50.16180361470869, 51.89119623553369, 48.52313933833953, 49.82364823741298, 50.23748574718353, 49.720725244091405, 48.43068515100787, 47.45728231245472, 43.42330109688544, 41.418444341228856, 41.10048132558023, 43.20918675391905, 47.39101386839344, 51.44080615812733, 50.859581501253196, 46.95822346595026, 10.065614773381142, 0.721359727603774, 6.895055097918357, 9.633467639646224, 9.643891338379154, 0.6291967762574073, 0.13795461595779465, 0.07420945101447644, 0.19547562295150375, 1.478853432401534, 4.512010274394866, 32.655745821614424, 34.97093854411956, 32.748802092767534, 49.89051288174045, 33.94960826443088, 2.9749648032649874, 0.09996946390357711, 0.019508128302292, 0.043426019575206504, 0.0134622169876351, 0.03582867966484159, 0.029450967051689664, 0.0060242525726226315, 0.05044710048804841, 0.16161191667760574, 0.017409250403063434, 0.017498576255034537, 0.01920808996674755, 0.013277380081314235, 0.010462074949886772, 0.035220919131872155, 0.11063640321334524, 0.2903329514928403, 0.26823542110862275, 0.14189137326132867, 0.2870157294936719, 0.1841703255570704, 0.13903933517154188, 0.1704890983960321, 0.22616254646451245, 0.19324688931867, 0.16139561941306438, 0.15634910714241768, 0.0859239389519057, 0.10318505667871046, 0.10642177815879546, 0.12152843447702548, 0.13380643370891773, 0.19193945302357598, 0.24786063860501015, 0.11530711105273617, 0.13081861419543145, 0.1518298165812608, 0.776511806874506, 25.49625139082632, 66.15608384532314, 40.82922981631371, 42.37840913957165, 46.64959961368192, 50.40411587684385, 17.95379634826414, 0.47866858902477455, 6.429418277355933, 0.8565019888262596, 0.46492399107063975, 0.7705705192300581, 1.1182049782045427, 2.063540071249008, 2.6205335509392524, 20.274360756720267, 56.20199088127383, 58.046053994086485, 61.170614073353434, 56.67807248330886, 51.20299677694998, 48.14249292496712, 46.6716197998293, 45.43457485014393, 46.876532262371434, 46.10911269341746, 43.589413473683024, 44.631304817814986, 45.15653764047931, 43.89874335258238, 44.02418467306322, 42.95238525636735, 46.46135330200196, 44.32802715609151, 47.95815721634896, 51.86176276976063, 53.991966709013916, 54.02767204469251, 54.295581694572206, 56.792503710716005, 55.00782135994204, 52.22767283839565, 43.648103898571385, 41.73345381213773, 41.99700570875599, 41.79983208256383, 43.334361353228175, 41.51674286011727, 42.07741429728847, 41.92725027761152, 43.106463801476266, 44.630359526603456, 42.335274834786695, 40.288123161562034, 41.6293070393224, 43.56542033533896, 48.679594839772875, 54.1184356904799, 56.16281817036291, 56.77394697743078, 54.06262036292784, 56.78167012430007, 55.008390103617025, 55.18655592395414, 53.44363504840482, 51.46236350459438, 48.54173137295631, 50.3088415053583, 55.5298182272142, 54.81064773374989, 54.61478810156546, 52.178831485009965, 46.095353018852975, 44.290168439188314, 42.332972403495546, 43.95359377707205, 41.15771655113467, 42.68531891607469, 42.55476282488915, 41.80788863089777, 42.08460007944415, 42.66968042619767, 42.37048987419375, 39.87634097376178, 41.370042293302475, 41.8594991776251, 40.72418482072892, 41.24935488547049, 40.298854766353486, 42.740220331376605, 42.44908632770662, 39.945523738861084, 44.15350129527431, 40.5235359745641, 40.33111626102079, 39.751762574718846, 40.48610871837985, 39.69694745156073, 41.494463797538515, 40.9748831102925, 39.02782640149517, 40.82855909101425, 45.55963962308822, 49.31052769384077, 51.3920707087363, 50.64353342979185, 54.266430639451556, 48.5066379270246, 49.99032935788555, 52.86949026969172, 51.865375272689334, 51.50039088341498, 49.31882742912539, 45.168900951262444, 43.43975151738813, 42.52851824606619, 45.07647029815182, 49.871834554979884, 53.24455515030892, 51.987231546832675, 47.881161089866396, 10.284883110753952, 0.4710801204125728, 10.869863437068078, 15.77028347599891, 19.48257738544095, 7.243854807269189, 0.3826763625106504, 0.12922827695165912, 0.4953935447960131, 3.586010259966697, 9.36593649848815, 40.04639925495271, 40.55999440531577, 40.831932329362445, 54.96944096780593, 40.11653123363372, 3.0065357156338233, 0.18535826745773518, 0.18795490715532534, 0.0771103042267984, 0.07481279888100202, 0.08936629375262607, 0.1689484496150286, 0.13639512141385388, 0.13061897168236394, 0.17686537076388636, 0.14544124084134258, 0.15509708964776608, 0.1065603634642978, 0.17429574332650632, 0.14637171591241516, 0.14776716038825052, 0.15585223783648786], [0.0463680615047774, 0.02945658247617464, 0.018409979567232154, 0.03425844073776276, 0.03841751292648335, 0.038033794806969744, 0.02719085637269722, 0.0049579606462840835, 0.05764581037745361, 0.02266361573410611, 0.047286275338621876, 0.04967366961101371, 0.05031177871710351, 0.040622773625317125, 0.04021254503318379, 0.04280243549616106, 0.05536833056999792, 0.025282539014193802, 0.06179226892850092, 0.13516775662860564, 0.03666891723931317, 0.04389172825481623, 3.344232911063779, 32.976640808966856, 40.77790952497914, 35.92004622182539, 35.26138613300939, 39.20873395858273, 21.33031575910507, 0.24336586285743023, 0.6530667276632401, 0.38128582099753044, 0.03194575344452695, 0.07263065871572302, 0.46520401152872276, 1.4633318781852724, 0.06424870304462892, 2.2122013328536867, 34.20146365319529, 54.78725079567202, 55.426495152135054, 51.09486879840974, 50.45606766977618, 47.48765322469896, 45.33422100928522, 43.248131967359974, 43.351286380521714, 40.45219982824018, 42.02587435322423, 44.896888502182506, 46.122468363854196, 48.59314187880486, 46.47126905379757, 46.581617093855336, 43.94254053792646, 40.389528197626916, 41.28871979251985, 43.16201633022678, 46.89361810684205, 49.45428648302632, 52.755517959594734, 51.54779664931759, 54.60788080769201, 50.82726509340348, 38.654812920478086, 40.46958769521406, 38.99619248605544, 37.86360809879918, 38.319516951038, 37.84154868895008, 38.356336239845525, 40.06614838877032, 39.59167103613577, 38.127940547081735, 40.031133390242054, 37.19615797842703, 37.05818468524564, 37.580079570893325, 39.57169440484817, 43.760456269787205, 48.88153022335422, 51.143055115976644, 54.19619667914606, 49.626145132126354, 52.79781287716281, 52.374659738233014, 51.79906760492633, 52.85493043161208, 51.25321488226614, 46.47836854380947, 48.86877859792402, 53.06442030014531, 51.79927941291563, 48.58903907960462, 43.397919439500384, 42.116736058265936, 44.37605657885152, 44.78280244335052, 46.058502351084066, 45.762700726909024, 44.93154264265492, 39.03640070269185, 37.37215865042902, 37.33195827853295, 37.04096940255935, 35.98675004897579, 36.62515501822195, 35.914825547126036, 37.41767383390857, 36.79566044961253, 35.72080942892259, 39.269263975081905, 39.611953612296816, 34.88927087476177, 37.98405624205066, 36.549257155387636, 37.14342955620059, 38.85163353335473, 40.546183739939046, 38.3401878418461, 38.35563413558468, 37.29001637428038, 37.07730623983568, 34.62175738426947, 36.54201646004954, 38.368813299363666, 42.273089578074796, 45.40448242618192, 47.07951099641862, 47.46240100552959, 47.143131840613584, 47.68501512465939, 49.53609143534015, 47.460592792880156, 49.59042410696707, 45.47768169833768, 44.247500896453865, 42.767017964393865, 45.983663528196274, 46.993928801628854, 49.42849297677317, 51.033942622523156, 31.22691854353874, 1.603552812049466, 1.0699067505136615, 5.379097269427392, 6.357410915436284, 5.271725327737871, 0.29784674185418314, 0.08624019536880717, 0.03327389135055485, 0.46618252031264773, 0.23688650569848477, 6.2946726045300885, 33.43832731246948, 27.270408061242875, 39.813237882429554, 35.86010848322223, 10.183544754981995, 0.08366984014789905, 0.023497475626608057, 0.0013497306926799338, 0.04302634001379052, 0.03720758430239174, 0.03742561292564196, 0.05108949968651418, 0.02661697799339891, 0.03164265841816462, 0.06460728198890725, 0.019671373978076924, 0.005311997167976393, 0.029445945345346006, 0.052848177090767896, 0.060260682967641664, 0.05254502077737162, 0.032657818763606974, 0.02648342397033928, 0.027248782195871877, 0.058160234588168325, 0.04070207904723864, 0.013136808692868198, 0.038023188319658084, 0.048951482355234124, 0.06625990218092358, 0.030244917593776222, 0.020759887242269133, 0.03421853138734737, 0.00955507185520424, 0.05626505946800594, 0.04909094866184939, 0.05406152629744142, 0.08715556318601293, 0.03463673878521208, 0.011092104701205127, 0.07170689457486715, 0.13963250172955377, 0.027448830735539238, 0.013414684104763213, 5.971064317610956, 43.00698857153616, 40.446990920651345, 36.7537263901003, 42.171504112981985, 45.48882122962706, 25.998818797449914, 0.6120927908247518, 1.5808554041770198, 0.48029076488267997, 0.07667110601980841, 0.21953427713484536, 0.2142070396052253, 2.2401129189998876, 0.7009348429499135, 3.1010756233046135, 38.60984294645248, 54.2350124543713, 56.01436430408109, 52.58673052633963, 52.731701327908425, 48.22764758140811, 48.35611697166197, 45.19390606111096, 45.339139661481305, 41.346939532987534, 42.77130511499221, 43.429369003542014, 47.7889108657837, 48.02893246373823, 47.62006067460584, 47.53305858181369, 44.364971960744555, 41.321012666148526, 43.35248270342427, 45.81802968055972, 49.517052250523726, 50.38930892944337, 54.29375779244208, 53.11574451385006, 56.54066008906211, 53.003611795363895, 40.474463201338246, 40.78400488822691, 40.47387876818257, 40.44090340214391, 39.90036941343739, 39.76548694795178, 40.13278161325763, 42.57156625870736, 42.096053400347316, 39.961511319683446, 40.7691155710528, 38.797567582899525, 39.984990627534934, 39.081959032243304, 42.27613333732852, 46.30596860762566, 50.926916830001346, 52.66602516174317, 55.96439723045596, 51.77137959387995, 54.52436177961288, 53.38152039435602, 54.12671973628383, 55.31802200501966, 51.21576016949069, 47.39579523763349, 51.40006057677731, 53.795201009319676, 52.73443129754836, 49.98927816267937, 44.928004664759484, 44.52106268175187, 43.35259645215927, 44.662346455358694, 44.801104222574544, 46.89466537967805, 45.09015544768303, 39.53962902868948, 39.010058064614576, 39.868362872831284, 37.915018604647734, 39.540142859182055, 40.816760601535925, 38.19882169846566, 38.70377978970928, 37.69329486354705, 39.23220542169387, 40.57878255844116, 40.67850097533196, 37.71425993211808, 39.01905598178987, 38.589419164965236, 39.17285603861655, 39.41779628876717, 40.76473036120015, 39.36459718212005, 39.24393723087926, 39.12241828057074, 38.52331938282136, 36.58120093807098, 38.51774177243633, 40.637378846445394, 44.75620092884187, 47.24671771449428, 49.427006398477864, 49.41234457877375, 48.282403869013635, 49.44804991445234, 49.1121381328952, 49.61039289351433, 50.60852235363376, 47.14845449693742, 47.44594666265672, 43.75070133516866, 48.375764123855106, 48.41824339282129, 50.75535628103441, 52.53022878400741, 34.56549882888794, 1.8486032562871135, 2.5333792211547976, 8.225109250314775, 8.976677540809877, 5.61353684433045, 1.333276502067043, 0.1336992426865524, 0.10528474280069913, 0.5980149752670719, 0.48825323761951545, 8.696151587270922, 38.11644800247685, 30.250744550458847, 40.25531645744078, 43.79034865287043, 16.842928163466915, 0.17415279131983558, 0.054872981948597785, 0.025677170056188782, 0.02523899266135789, 0.07312738246494725, 0.02246146811352622, 0.06176903348175749, 0.05804676547526352, 0.04276118166143856, 0.025391629934611342, 0.07290576088933215, 0.04960210550756705, 0.02021515084761045, 0.04713707971536825, 0.03732186163805666, 0.03580118093879954, 0.04477679346417708, 0.14758484678403025, 0.2071759918884885, 0.12581069743440998, 0.1259122653714111, 0.17506072808417583, 0.11392239946871997, 0.19550003051277132, 0.10024376168486573, 0.12397220132932549, 0.15124224246509615, 0.09227894471898195, 0.11965512733666167, 0.19471210908264885, 0.14416826318108267, 0.16285967472339832, 0.22855635672327013, 0.15139261020287392, 0.12553715041928715, 0.2500523701911011, 0.33703253754685003, 0.10063801351333819, 0.0956730972675066, 7.183843033929025, 49.43314883016771, 52.668143241636216, 47.15645220971877, 44.84559566743913, 49.44407263109761, 29.080321058150265, 1.2744698769623235, 1.8253389433506997, 1.2014528724455065, 0.4276498298971884, 0.6565409057563352, 1.5859526467900125, 4.895764675832564, 0.6531856857961225, 3.7471196536094915, 38.87619933774395, 56.37101757910944, 59.523277436533284, 55.06411129428495, 55.28863168531849, 50.537268577083466, 49.93124277360978, 45.604829249843476, 49.995722616872484, 43.430169167057166, 46.11314881232477, 47.03014796780002, 50.86044834506128, 52.230069406570934, 51.84896407588836, 50.58319953180129, 47.63490684570805, 44.29909183133034, 45.72815249043126, 46.47264188335788, 51.76745722370764, 52.92619597527289, 54.948805378329375, 54.240405713358236, 58.57678597973239, 56.02189525481194, 42.551369974690104, 43.20394254499867, 42.32499038019488, 41.28693511409145, 42.54569038268059, 42.519351666973485, 40.70429448158511, 45.38642775627875, 44.05564208184519, 42.33785575436008, 43.23856138413952, 41.64611831788094, 42.3191931170802, 41.97578960849393, 43.474652767181404, 47.49817302150112, 51.82539063115274, 56.41030011638519, 59.08958096658031, 54.818767040006584, 56.93195965982253, 56.33974844409574, 57.26125440289898, 57.174848510373025, 52.53897959186185, 48.28730683172903, 52.45912797989384, 56.1533691806178, 54.720213567056966, 54.075226860661665, 47.95457217001146, 47.51848697662354, 47.50033032509589, 48.35303398870653, 48.13327927743235, 49.09161236978347, 48.66862397040091, 42.113668764791186, 41.21289253234863, 41.31449368692214, 39.96024439411779, 39.271829205174605, 41.63540632494035, 39.926719896255, 40.208985420965384, 40.535291317970525, 40.361628378591234, 42.77529416545745, 42.831184018042784, 38.886295518567486, 42.087941938830966, 39.09755437604843, 40.11437393003895, 43.17961208281979, 45.33886509556925, 41.54072423135081, 41.82101288149434, 42.86350827063284, 41.28752346961729, 38.13627558369791, 40.20070529753163, 43.67759227752686, 45.609426267685436, 47.70363461586737, 49.80887659134404, 51.52727873094621, 48.44873589854087, 50.10605496744956, 50.94530490136916, 52.291791823602495, 53.89873981475831, 51.18775836883053, 49.023249380050174, 47.2549468471158, 50.09667265799738, 50.61783013805267, 52.04655347331878, 54.97051569723315, 33.571621218035304, 3.1010584629351094, 2.3620692135826236, 11.442060758990626, 17.4037996415169, 15.756791503198686, 3.6134712638393527, 0.4195923009707082, 0.3171581023883435, 1.395808275668852, 1.7569780373765578, 12.167839465602754, 49.10232044035389, 38.10353948223976, 48.97989542253556, 47.5790052260122, 17.503567088034846, 0.2716438995013314, 0.19900531177559208, 0.08878641882010045, 0.1439354030956184, 0.23520226139695416, 0.17340755630885402, 0.17629120318639666, 0.2197382250620473, 0.2134014828310859, 0.16450325507790814, 0.08285998562050444, 0.1393977877113127, 0.14680621033955008, 0.18573156678147856, 0.1606227286280163, 0.15609784562501217, 0.1180087277785905], [0.06611049205305115, 0.06984384535180946, 0.039114492059114485, 0.06760953459888697, 0.054478665002651756, 0.03347996900218629, 0.021444155061016643, 0.08888698318192075, 0.02216715628521577, 0.007191536433604216, 0.007147437539852916, 0.03540329785356599, 0.06371221167125529, 0.015522755059083144, 0.07562806965002129, 0.04279176389137584, 0.06943923601460072, 0.06623555590668995, 0.035024570796879075, 0.019667857634504477, 0.04140938121464945, 0.06736976440034567, 0.25311650738360425, 18.522957755673318, 41.159046234623084, 26.448177291500954, 34.50751443063059, 35.90934991836548, 18.81158144243302, 1.1259370729807885, 0.2955662206776681, 0.14706258932428976, 0.1234935572551143, 0.026573801277986458, 0.06932757869963685, 2.067670572188593, 1.4996211567232687, 0.0706221677002407, 12.514592678316179, 47.14979594753635, 55.023487306410274, 54.135772566641535, 51.70168692065824, 48.10710530127249, 46.18294738954114, 45.25877421902072, 46.81881066291563, 48.719838357740834, 50.1837492758228, 50.34840645328645, 51.47329515026462, 50.47715825419272, 52.12537350193147, 51.90580314205539, 48.31798368884672, 39.684011474732436, 42.259074949449115, 46.47175150532877, 49.25350819864581, 52.15729375039378, 51.74182845700172, 51.350803452153365, 52.915684023211085, 47.04215826526765, 38.76082281912527, 38.9446250854, 40.06720350634667, 38.661002420610004, 39.735900509742, 38.04511970089328, 38.135087105535696, 38.615416634467344, 38.299148082733154, 39.04457884450113, 38.53992277576078, 38.3779328100143, 38.094510186103086, 37.92950391769409, 38.5511682110448, 39.09555788963072, 45.18131133048765, 49.03570290534727, 48.29706176634758, 51.006540944499356, 48.54806207841443, 51.30329962699644, 52.47233067789386, 50.86136225731143, 54.095121122175655, 49.371912787037516, 46.91386538167154, 54.15753779872772, 49.755206800276234, 48.97228994677144, 45.66088776434622, 47.307973369475334, 48.262650812825854, 48.562500323018725, 47.71185590374855, 49.836482232616795, 49.60788649897422, 46.32993428937851, 38.47590577217841, 36.960235257302564, 36.95785437860797, 37.25162813740392, 36.84154433588828, 36.12174234082622, 37.452826115392874, 36.873378292206795, 37.66090000829389, 38.024142865211736, 38.231824521095525, 38.58370427162417, 38.00934376255159, 35.36554467293524, 40.105811395952784, 47.11216472810315, 46.89573618673509, 45.454021961458274, 43.47334661791402, 42.05761025028844, 43.1681195382149, 43.37651898784023, 43.31964462034164, 40.64473721288866, 42.99251894797049, 44.82088081298336, 46.15063882643177, 49.80075728508734, 45.222092213169226, 45.53623091789984, 48.626219226467995, 46.80255636092156, 48.23336247474917, 47.350990003155125, 48.81852126890614, 47.02283274742865, 48.22514510923817, 47.98953617772749, 49.310641442575765, 46.79227975107009, 18.040149288792765, 0.06518960074191132, 3.1774250490050164, 5.319828785234883, 6.414825589426103, 3.808369670183428, 0.19553386095550754, 0.06965666708927001, 0.009512169016224724, 0.09123768567317918, 0.4960435244344896, 11.639124558817956, 42.99516262546663, 27.806003785902455, 38.4873826273026, 26.756242206019742, 2.324266145306249, 0.06097545066187459, 0.01857853040189272, 0.03146009583536896, 0.08347940601168141, 0.053410535422904845, 0.016452801120918126, 0.013679184579110194, 0.08274655864243546, 0.028089887364917708, 0.02690738277329553, 0.03372126371569691, 0.019408339604495034, 0.04127034391727179, 0.010424263722774003, 0.059450590952990524, 0.04876177217210493, 0.06737475163273274, 0.03366595599800348, 0.030149210229395863, 0.037901977888278426, 0.06790004280065337, 0.06991068652320294, 0.042547519739356734, 0.04147844787146296, 0.055412089512232816, 0.01794891721088319, 0.04011484967063993, 0.030518234782521764, 0.02710503345775989, 0.01586834498260531, 0.026838241422909404, 0.1421663681826284, 0.019878060669608174, 0.06979329887056543, 0.08500660994961377, 0.11013237098532339, 0.022778862170995246, 0.056194625344247594, 0.024420404731626474, 0.8793660974310291, 25.299383709507605, 49.71581443663567, 29.212402951332834, 38.74753382898147, 41.982689057627034, 23.208254421910933, 1.5718353010954396, 0.07107606713449763, 0.21936783687241618, 0.15354285046698588, 0.07018906755312797, 0.06965531111364404, 2.9671359975491804, 1.2567660140414394, 0.18002398191921173, 15.665758194461947, 51.879907654177764, 55.919121311556914, 55.439846900201616, 54.40441177737329, 51.47782156544348, 46.58822628759569, 46.910405851179554, 48.74355693017283, 50.7070719042132, 51.017609873125636, 53.42773375972625, 53.04022319855229, 53.4693540296247, 52.48225427442982, 55.8340843262211, 49.205776876018895, 40.9420685614309, 43.72265246606643, 48.45820057776667, 50.41553389641547, 54.802901052659564, 53.190238168162686, 53.96660858584989, 54.127370849732436, 48.96690061015468, 40.561692791600386, 40.295685491254254, 40.32533860975697, 40.260988204709946, 39.971262331931825, 40.24131751829579, 40.066591616599794, 39.26991508853051, 41.144855099339644, 39.69874781946982, 40.48292375379994, 39.8340029101218, 39.94670437228295, 40.390528402020855, 39.82922154088175, 41.83494906271658, 47.26683162873792, 50.48452054300616, 51.35998964309693, 52.05937177904191, 51.400327297949026, 51.809893346601925, 54.12082049154467, 52.19688615491314, 55.440898095407796, 49.700987877384314, 49.70294121773013, 55.78137159347535, 51.806582866176484, 52.27316841002434, 47.00735507472869, 49.88981469984978, 48.13074542630104, 50.39856180067986, 50.44228446099066, 52.124993032024754, 51.93668788479221, 47.42010216559134, 40.187447686349195, 40.0933970943574, 38.953026802309104, 38.86345163468392, 38.032524970269975, 37.87306101091447, 38.40757023903632, 38.6430222757401, 39.13678592251193, 38.82096452097739, 40.59790803540138, 39.661646120009884, 39.679590963548236, 37.922812354180124, 40.373430790439734, 49.60752956328854, 48.02911289276616, 48.00765752792359, 43.45972422630557, 43.60990785783337, 43.9391908337993, 44.55925480011971, 42.72010641713297, 41.86142506137971, 43.60436554877989, 46.69707990461781, 49.98453993951121, 50.845343297527684, 45.978564446972264, 46.22483045824113, 48.63993183259041, 48.18951037622268, 50.681250941368845, 49.94529662593719, 50.528317728350245, 47.72282677312052, 49.187216220363496, 50.68451827572238, 50.22761706382998, 47.35575176054432, 20.793139319266043, 0.5855093559911174, 5.325087212747143, 8.986373639875843, 9.07600470127598, 4.681424796581268, 1.681173453407903, 0.014227128966951804, 0.21418160548613918, 0.1286054474692191, 0.22893514123655137, 14.346969089200421, 47.5930747678203, 31.114862311270933, 42.87915068288004, 33.27345048227618, 4.610354881132803, 0.016721705643219814, 0.025891630624931668, 0.033878510923034726, 0.06884610010010582, 0.03419319685969142, 0.05099491081050327, 0.0187714945434803, 0.04008017653118699, 0.08906879882899024, 0.016212935161386288, 0.05222169719936867, 0.04598237070885878, 0.03838965796955651, 0.06149647472005698, 0.06745535174324628, 0.042075973469764, 0.02225354418999726, 0.27696980403796323, 0.15710661488194622, 0.13973005536583163, 0.27191855734394443, 0.15029272244822595, 0.1497865988001708, 0.16895172847134454, 0.1618164774751471, 0.1397944986820221, 0.16406165135483589, 0.09381620739136012, 0.10772380587314406, 0.14186330379978304, 0.13363357362968306, 0.2346203716531877, 0.16514770356157135, 0.16128430683766642, 0.2233434654772282, 0.2029087442544199, 0.13388221512638754, 0.14296624058436963, 0.2151151449089089, 0.9895269056001018, 28.56332129047763, 55.58495498472645, 37.34669854564052, 44.225504244527514, 47.15528334340742, 29.28328606390184, 3.5913096272176315, 0.8884539226851157, 0.7138877962866138, 0.37448709710471095, 0.4213325769430207, 0.4483334377648369, 4.524863881449546, 3.2228139811946503, 0.24034117919302758, 16.055308388125514, 51.93271844617782, 58.2508134841919, 57.28854233218778, 57.65449946926486, 52.39793508283554, 48.55602448986423, 49.584983779538064, 51.38692063670005, 53.050660625580825, 53.90979305390389, 54.424015783494525, 56.03161881046911, 56.09725575293265, 55.65242367406046, 58.21309597261491, 52.81897406424246, 43.14957064967002, 46.11709079434795, 50.8319954718313, 53.62296581268311, 58.03724042830929, 55.59432160469794, 53.7999588443387, 58.326079845428474, 50.61463340636223, 44.153579742677756, 41.1142292330342, 43.65752150935512, 43.23458802315497, 43.878370561907374, 41.7661153885626, 41.31453291062386, 42.107965638560636, 42.11612809088923, 43.162538005459695, 41.609530448913574, 41.111091336896344, 42.098732379175004, 41.22696599652691, 43.35553430741833, 42.31303891827984, 48.48472756724204, 52.74533940899757, 53.551115835866625, 54.92835414025092, 52.76368041192332, 55.50820596756474, 55.582213247976, 55.06492714728079, 58.1015633767651, 51.449996271441066, 50.83805553374752, 58.96925441680416, 53.62928475103071, 53.195909915431855, 48.25388039312055, 51.4735108806241, 53.22908139997914, 53.068546633566584, 51.12510635006813, 54.70462214562201, 53.64458591707292, 50.393607847152225, 42.90564629339403, 39.971799696645434, 39.66893780616022, 40.58538390744118, 39.49025815533054, 39.049211163674634, 40.138296465719904, 39.4317481594701, 40.69480626813827, 41.27707819784842, 42.67981583072294, 41.52587021550825, 42.36183320322345, 39.11782126272879, 42.924779615094586, 51.58662419165335, 50.2179091976535, 51.21583469452397, 47.203336300388465, 46.50584082449637, 47.16337519307291, 48.256390710030836, 46.79051076212237, 43.45139703442974, 46.89297483813378, 48.854061865037494, 52.477614110515965, 52.80662252056984, 46.460078531695956, 47.37823478637203, 50.13474318288988, 50.00628555974653, 51.58095636675435, 50.881852719091604, 52.58420059757849, 51.359997487837276, 51.647872001894065, 52.90175568672919, 50.556041040728175, 49.90680248506608, 20.417148759288175, 0.551548739594798, 6.821057133136257, 13.869158702511942, 13.671477129382472, 12.433807542247157, 2.4963275319145573, 0.22051693811531992, 0.3021631570112321, 0.3473609655855164, 0.9146149059937847, 20.246358956060103, 54.40377635340537, 38.824039659192486, 48.507289040473204, 40.39076766660137, 5.0733421406438275, 0.17507732154861574, 0.14205782884551635, 0.11561153907208674, 0.19422666980854927, 0.11292997852809007, 0.16299381671893984, 0.18709897243928525, 0.27324370559184785, 0.10858981464538844, 0.15064662442572657, 0.1717616317252959, 0.14665578131473836, 0.13282401787657894, 0.10098345788015474, 0.1652758394277865, 0.1751334757934655, 0.11540520861144028], [0.009196367464028299, 0.05175727171703212, 0.04347453592345119, 0.01664895601871033, 0.05347364957654669, 0.03960054037311385, 0.044221161384015314, 0.01876419947122134, 0.014266201366309919, 0.009864968784724273, 0.0318570098193783, 0.08990835458520921, 0.08768313729594793, 0.03483409835626522, 0.057961143658406315, 0.032030067166253444, 0.026760014269741315, 0.09206675368571475, 0.03016026870858285, 0.0875797384088078, 0.01825628126220357, 0.061437263784389344, 0.014538438371082228, 4.974411629861401, 36.061353529653246, 40.53804874420166, 31.952653123486428, 37.110611084968816, 25.75419822046834, 5.410731184867121, 1.4773998265304875, 0.12959863449777329, 0.03548906905756843, 0.1514823037770487, 0.0333195042255665, 0.7664394054201342, 1.794412035134531, 0.08965245057498256, 1.7706675995742123, 30.935647256912727, 55.19573034778718, 55.28208132713072, 52.07026420101043, 51.59157422281081, 51.08739668323148, 50.156210314842966, 51.79456080159834, 49.72516928949664, 52.673026592500754, 54.04193770500922, 54.685716321391446, 51.16963701863443, 53.80502654660133, 54.738436898877545, 46.64420243232481, 39.97614176042619, 41.419797558938306, 47.47019083269181, 51.70243217099098, 52.96477640828779, 49.96033891554802, 53.15986725591844, 53.74247258709323, 44.96869533292709, 37.09889496526411, 38.76381950993692, 38.89010806237498, 40.623807445649184, 39.33642671954247, 37.93772912794544, 37.50387968555574, 39.592020127081106, 37.989896651237245, 37.56668859912504, 37.513885651865316, 37.04802574649934, 38.44121240800427, 38.59598913500386, 37.1975504198382, 36.64140932021603, 39.616236840524984, 43.235917706643384, 43.598309409233835, 44.56556197135679, 47.63025883705386, 48.20603139938847, 50.089459419250495, 50.579932197447754, 52.5961559818637, 48.69208366640153, 47.081605542090635, 55.617400830791844, 50.88915224998228, 49.69682624263149, 48.0030369758606, 48.83797230259065, 51.41359667624197, 52.064498316857126, 51.28577839943671, 52.89015331575948, 51.15436723155361, 49.302188734854425, 39.3488488658782, 36.45478294741723, 37.34258397932976, 35.59364226556594, 38.503542792412546, 37.545319526426255, 38.78063471086564, 37.55054804586595, 36.206642043206, 36.9770190792699, 36.69834252326719, 37.21765256697132, 38.785996590891195, 36.68368462593325, 46.70048452192738, 49.37953395228232, 49.485124157321074, 48.764117994616115, 44.70856374309909, 42.56373328547324, 46.035752604084635, 48.72275660114904, 47.05234073823499, 46.290467400704664, 48.49486689413748, 46.74432877571353, 49.31808610116282, 47.097495063658684, 46.085245070918916, 47.599581979936175, 48.091619783832186, 47.49479978315292, 47.38309068064536, 50.114974437221406, 48.69163651620188, 46.23123176636235, 49.31607000289425, 50.111797317381836, 51.801766195604884, 32.10802605075221, 5.532648255748134, 0.463640763153953, 6.470232990480239, 7.738937351011462, 7.251003817204507, 1.7930073363165704, 0.97392653625819, 0.17677138709733564, 0.03766021969157361, 0.050059191867589, 1.0079229442823319, 24.30898524099781, 31.123181658406413, 27.459254495559204, 43.33849160901962, 15.957652157352818, 0.45424307065625347, 0.061153439699762294, 0.10365550361213186, 0.09485921311763026, 0.010338356538165, 0.045328851744172075, 0.0251775351728523, 0.05377804312194067, 0.06148307584226132, 0.06139157430058526, 0.03203175255968686, 0.06409521732899932, 0.043389013698024136, 0.026694067505999442, 0.012941996364163296, 0.024558419301625223, 0.025865939866390922, 0.01718207085955768, 0.04746402305881343, 0.07883165016650193, 0.00939616894034008, 0.017170841925807537, 0.02851236570296028, 0.05568072973420063, 0.0391247499764206, 0.05009895183085915, 0.059810993186528646, 0.020272145873957106, 0.06100959520065977, 0.03851484056682356, 0.021742437139994675, 0.01775109607185568, 0.04265984738125436, 0.05212690147961821, 0.06820476193341517, 0.00437936268656725, 0.0346481075300084, 0.007991920199034917, 0.07152767596586097, 0.04063865462798746, 0.03654100736903568, 9.044393339464742, 42.1666286068578, 43.02017165768532, 36.243273058245265, 44.457002532097604, 28.082823099628573, 7.381864872670944, 2.381831830547702, 0.17846292455590543, 0.05809638882055879, 0.18956646503460026, 0.07067134288410026, 0.3493920485338857, 2.385971647116446, 0.43586403912594246, 2.2500806422002855, 34.764021750419374, 55.26537595256683, 57.50469630764377, 53.70423340028333, 54.32895321999827, 50.77849826505108, 50.4333532241083, 52.094594663189305, 52.55517505830335, 54.035720748286096, 54.314036446232954, 54.38441161186465, 54.32235187099826, 54.70350034775273, 55.56515878246677, 48.52013088041737, 41.879801365637014, 44.204248920563735, 49.57349123493318, 53.27842873911704, 54.01946644629202, 53.287226615413545, 56.04410763709776, 54.590281132728826, 46.73646442351803, 39.19633534646804, 39.70597282532723, 41.689056504157286, 40.409697025052964, 39.98087606122417, 41.077747268061486, 39.67059304637294, 40.0212097937061, 41.93467140197754, 39.642814820812596, 38.653977455631384, 39.41117140554613, 39.348327190645286, 40.14760425013881, 37.70225355702062, 38.8942422405366, 42.65013525562902, 45.521753449593824, 46.1090224789035, 47.573839464495265, 50.92717962880289, 49.43343516319029, 52.252658336393296, 51.362284229647734, 55.528614059571304, 50.31362679696853, 48.17649595199093, 56.84594208194364, 53.94710263898296, 51.432773144014426, 49.40624137078562, 50.675740011276744, 53.108515585622484, 54.16837530751383, 52.63539929543772, 54.39860666951826, 52.87058853333997, 50.90165676609163, 40.81390511605048, 37.043224765408425, 38.21805307942052, 38.03271324403825, 39.55317297289449, 39.98498278279459, 39.01017181334957, 40.07853915614467, 37.56308394093668, 38.85863496411232, 37.926915153380364, 39.180532117043775, 39.96706931821762, 38.063935310609885, 48.05438864615656, 50.485140277493386, 51.6503038714009, 49.662176024529245, 45.431789967321585, 44.62031041422198, 47.702759927318944, 48.98526514730146, 48.61369117613762, 48.45683167057653, 49.39428598650041, 47.43457178915701, 49.84269134459957, 49.46564174467518, 47.036925823457786, 49.47219994760329, 49.51516951284101, 48.74609470367432, 47.726058806142504, 50.74369115214194, 50.87239196223598, 50.451858966581284, 50.53806089585828, 51.18482051357147, 51.61805022147394, 35.586911478350245, 6.450434336739202, 0.6916336775306733, 9.02025213164668, 12.067516023112882, 10.248242289789262, 6.204269816798549, 1.386402431995638, 0.2911161078560737, 0.09888413181949048, 0.0367748748601204, 1.5402892712623844, 27.93170790518484, 40.06631705068773, 31.504436039155532, 47.573768861832164, 23.082540496703118, 0.4927106742416659, 0.04315264492986664, 0.06856187381931851, 0.014725852205658392, 0.06866030079583008, 0.06210480598853, 0.049166327883158965, 0.0067649700588757, 0.03235210371654361, 0.026806839478893146, 0.036576806657737305, 0.023229003943983587, 0.027050183477601217, 0.024505953770130876, 0.0634304904979804, 0.07169404728037697, 0.07643162693467832, 0.07081355944636368, 0.12635304938040434, 0.21148565015004528, 0.11852516297010646, 0.11822462667741122, 0.12837395102026003, 0.07577636128952427, 0.1565546944977776, 0.11184066278679718, 0.20931081846356395, 0.08237539670400082, 0.1659659927170123, 0.17648868533151765, 0.19819715030251012, 0.10673514642422238, 0.1417834008292806, 0.11953164162414691, 0.19265831928820382, 0.18311813443658814, 0.11163728942553844, 0.1428437431252772, 0.24693728815163338, 0.13405605579816526, 0.15273413741059844, 9.393823569820775, 48.281599783128314, 51.641898232121626, 42.948686461294855, 48.16881202882337, 37.275652654709354, 13.161417015137213, 3.9055108447228712, 1.1359503937344397, 0.4900475993992821, 0.694017804438068, 0.13703760871243093, 2.3060876755945148, 6.387440091179264, 0.26511070168306755, 2.6419523887095915, 34.13208869195754, 60.33433337365428, 60.45361265059441, 58.361039930774325, 56.98425269895985, 55.088881061923125, 53.72302547577889, 55.85573580957229, 53.00059157033121, 58.22482778180031, 57.19822583660003, 55.357520272654874, 56.12198237449893, 58.24019170576527, 58.673707746690326, 49.68283122585666, 44.28848182001422, 46.64119005203248, 51.71099470507715, 53.98074873032109, 57.2522251067623, 53.64907703092022, 58.58983962766586, 57.58900373212753, 49.86367994739164, 42.07439014988561, 42.48303051917784, 43.21226973687449, 43.717369033444314, 42.1465656834264, 42.184412633219075, 41.335509746305405, 43.08793452478225, 43.04015221134309, 41.16967585779006, 41.39919334842313, 41.12374882544241, 42.47818246964486, 43.571264666895715, 39.1735581428774, 40.24837778460595, 43.2725408769423, 46.65256100316202, 46.60152312247984, 49.313387101696385, 51.0733663651251, 53.16269920718286, 53.92831056348739, 54.74383015786448, 56.32221937179566, 51.79444313049317, 50.18339626250729, 60.1416547836796, 55.30465848984257, 53.833263689471835, 51.89278871782365, 52.89820201935307, 55.810852127690474, 56.93381494091403, 55.13030521331295, 55.40774622271138, 54.40980111399005, 53.301896279858006, 41.76717442850913, 39.43606668902982, 41.167946092544064, 39.54514388115176, 41.688789782985566, 40.741278509939875, 41.68282778032365, 40.94893663160263, 39.90869660531321, 40.44712035886703, 39.9997308946425, 42.06251713537401, 43.291109377338046, 39.74223513757029, 50.85570227715277, 51.98270513165382, 55.08608048962009, 52.69769437851445, 49.1648861669725, 46.89255906689552, 49.82779026031495, 51.518312192732296, 51.09877940147154, 49.87578830411358, 52.912726556101155, 50.916451946381606, 52.50925194832587, 50.146051376096665, 47.065315938765, 49.704514088169226, 51.04165007991176, 50.52399919879053, 51.44982760952365, 52.48990681863601, 52.97044423318679, 51.31055601181523, 53.288026778928696, 52.13972937676215, 55.66399466606879, 35.200879650731245, 7.18079339112005, 0.7428623447495123, 11.713707447052004, 17.134723086510938, 18.509529521388394, 8.162969100859858, 2.367876527770873, 0.3599059617807788, 0.16952375100264627, 0.25429468932411364, 2.8811451408170887, 35.105095371123284, 42.54048147509175, 37.273491428744414, 52.21000648313954, 26.15072827185354, 0.6310342841090695, 0.23158611188973152, 0.20168939274885964, 0.21854210134235122, 0.18460950844230192, 0.16671249943394817, 0.10193111630336893, 0.13263402807135738, 0.16212902602649507, 0.10492049863622074, 0.16587023172647725, 0.14596392731032065, 0.1536489536444987, 0.09579701198925895, 0.14348558690999785, 0.15168525578994907, 0.15632367302333156, 0.09864306693235714], [0.04800306933541452, 0.020285351314551888, 0.05598568635421896, 0.08185918367798291, 0.051482521943868174, 0.024989876190140366, 0.03595225730790727, 0.04549304736898311, 0.011358715747783502, 0.026125509607335253, 0.08946636015729559, 0.05697592394426466, 0.01192364430490641, 0.07234345235291027, 0.04395831278675506, 0.023688390482998183, 0.025518099559591185, 0.008384333416489104, 0.013718700351854487, 0.05878984011829861, 0.03974554932586128, 0.05443241627466294, 0.034655557735072035, 0.4114024226944293, 17.437692842175885, 37.0892616241209, 28.122821469460767, 30.724923802960305, 33.562352657318115, 11.220262492856673, 0.2897235745143506, 0.11641377868551402, 0.15323886677863138, 0.03566316636880079, 0.048314415128721346, 0.09237041561714104, 0.8229149781888532, 0.6761937576436228, 0.055933642171082966, 8.6987756529162, 39.6512871403848, 54.018391716864805, 54.68302949782341, 53.63142244277462, 51.56861266782207, 52.721479631239376, 52.44214019467754, 54.100259427101385, 53.99486534057125, 54.90342355543568, 52.26715541655018, 53.34356361819852, 53.400485054139175, 49.787699714783706, 42.8111760077938, 39.22116787202897, 46.17423580538842, 48.8729323879365, 53.67722788164693, 52.979689259682935, 51.43921759820754, 52.54959744791831, 51.65570889749835, 42.9701026024357, 37.160672295478086, 38.771715241093794, 39.958981390922304, 40.60855334804904, 38.50080497803227, 39.3187407524355, 38.525880690543886, 38.60950562261766, 39.03049753558251, 38.765725781840665, 37.90973124965545, 38.3112564394551, 36.95271607368223, 37.67447533146028, 37.60968562095396, 37.3584460443066, 40.90355480870893, 40.702090109548266, 41.683494583252944, 42.6360970927823, 42.019037662013886, 43.856711233815844, 49.125458502000384, 49.15744935312579, 50.891333087798095, 50.14612982350011, 44.85812764013968, 53.49725384866038, 49.50340240232406, 50.01929213923793, 49.08941584248697, 52.96578837979225, 51.463457845872455, 51.14969568867838, 52.59240619597897, 52.260589368881725, 50.45336907909763, 49.482523625896825, 38.696982322200654, 37.5785380794156, 37.40262762192757, 36.532018338480306, 36.67150958891838, 35.50552621964486, 38.10444162737939, 38.16066095905919, 39.092353313199936, 36.26326930138373, 36.89817943880635, 37.789259572182935, 36.94198839126095, 38.45734903889318, 46.215777627883426, 49.20347836709792, 49.438808810326364, 49.48171169527116, 45.792189105864495, 43.62657400869554, 45.99058258918024, 48.006421981319306, 49.219787582274414, 48.55815825923797, 46.95151229058543, 49.75304165194112, 47.4765254605201, 48.42447996139527, 47.97877711634482, 48.860231753318544, 48.99015242053617, 47.60274341029506, 48.193028742267245, 48.96711634051416, 50.75016698529644, 50.21418686835997, 50.96590518951417, 49.06627778084048, 40.11132624841506, 17.76074709430818, 1.201096549630165, 0.9586550331404133, 6.154264009767964, 9.555634087131871, 7.521531158877958, 3.0060490965843205, 0.6894658325660614, 0.01854548136883926, 0.03117552481501574, 0.02442340013541041, 4.789249772025693, 37.99673726481777, 29.066357420336818, 32.52879831098741, 33.62034097794564, 3.876769922433361, 0.060544200617099, 0.016667188911308205, 0.07312233394552624, 0.03595022717490792, 0.0396755557026594, 0.07209066632053546, 0.03616259057795809, 0.02888875044581871, 0.14488317643202123, 0.04435689684243933, 0.018319709511894374, 0.07064247669111337, 0.05104739932463535, 0.05728674113690373, 0.013067153105962903, 0.07770725525915623, 0.07180400388014894, 0.06869176402688026, 0.0563700020223135, 0.017279593852318583, 0.0842381931180435, 0.07527559259605986, 0.05802697742417936, 0.06138192542317895, 0.09457009153500681, 0.05201045611512758, 0.04766374601111297, 0.00980484045876731, 0.013406924591700157, 0.015511305875054773, 0.03910726784998852, 0.05064494269449384, 0.049723618543676795, 0.07405074057920326, 0.04172721194223531, 0.04288614209320757, 0.036530983108546466, 0.01879163691022944, 0.025532760567242102, 0.07598369532535154, 0.022052524633885875, 0.9910812060679159, 25.14611709502436, 43.26557474751627, 31.828867043218306, 38.67720573179184, 37.30874569185319, 13.687688285304656, 0.4347165313459212, 0.5654717441047392, 0.1420702241481312, 0.19403145528368412, 0.028289771195681348, 0.14074610245804633, 0.9633841245405136, 1.8450517952442171, 0.233315218300108, 10.984215236479237, 44.23184671709615, 55.87184498386999, 57.006531761538604, 55.13814603128741, 55.10760645712576, 52.67891799249957, 54.50279266603532, 54.1698383515881, 54.91228418965494, 56.94176558525332, 52.80385332722818, 53.6843587506202, 55.1984054042447, 53.96566721700854, 43.84422240718719, 41.42847776412964, 48.65070266108359, 50.22957824891614, 54.86681999698762, 55.12034239307527, 53.42496848875477, 54.70650096093455, 52.30766957806003, 44.11667416172643, 39.36246341274631, 41.46713664454799, 40.91905209325975, 42.82164873615388, 41.243090860305294, 41.41287849795434, 41.56068517315773, 40.74250228943364, 39.95718494538338, 41.60780460603776, 41.14649465007167, 39.95172108373335, 39.57554224998721, 39.088501545690725, 39.827405483491965, 39.48226828728953, 42.16928797383463, 43.08359638337166, 43.35282394962926, 44.54427919080181, 45.723547627848966, 46.04436612898304, 51.51209523600917, 51.83313338987289, 55.33649244616109, 51.296317808089725, 48.86209880152057, 54.123130767576164, 52.38672887125323, 52.283943160887695, 51.54325062228788, 53.64336213757915, 54.614956763482866, 53.521360735739435, 53.60840989697365, 54.41557876525387, 51.98738059689922, 50.84748883401194, 41.81891441345215, 38.40454609163346, 38.95007717993952, 38.053293920332386, 39.422299169724994, 37.4839501227102, 38.21130268035397, 40.22687142895114, 40.616892307035386, 37.55003421537338, 37.91081382382301, 38.53071697296635, 38.40091789922407, 40.41390965061803, 47.39261419542375, 49.05017645128312, 52.00902031313989, 51.260200623543035, 47.06624161812567, 43.90303442555089, 47.53501584452968, 49.14686287603071, 50.806441230158654, 49.64687485848704, 48.13294195359754, 51.77450964527746, 51.23184580956736, 49.66194852705925, 48.91083032854142, 50.33317588990735, 50.63799112073837, 49.6867222170676, 49.59267162507581, 49.664258803090746, 51.228766748982096, 51.525144961572465, 53.810584545135505, 51.468682442941976, 41.94170813406668, 20.073927640914917, 2.2564780279513332, 1.7108513318723249, 10.184831292398515, 11.807690378158323, 10.057778858369398, 6.78743310513035, 1.6095259689515637, 0.1790823985732371, 0.21213731518195522, 0.02551947851785489, 6.022487080866291, 39.69626888152092, 33.23017889453519, 35.54200033987723, 42.33546310855497, 6.652490333203347, 0.13044350690418674, 0.012098421519171568, 0.011700239659647548, 0.004553409244474625, 0.07959899447497823, 0.012575748879762908, 0.0261186990856884, 0.02627411342766737, 0.04948667904001571, 0.0183000267978998, 0.059688101192155195, 0.021200573575052045, 0.04133970551793614, 0.06462445001929037, 0.031969370020012704, 0.04356367791432046, 0.02578732392360126, 0.05990835147038583, 0.1513225744448362, 0.09427238210675218, 0.18034713312743172, 0.17960802681984442, 0.14586335528762112, 0.19314369727526942, 0.27824742419104426, 0.17792033512265454, 0.08897489177123194, 0.118592195663481, 0.14813206338834378, 0.12909133107431475, 0.121125947203367, 0.14206483088914426, 0.1521430392899821, 0.16181165112122414, 0.14254381970292138, 0.07787318224267614, 0.17572722457829984, 0.20679288663931433, 0.16013630876137366, 0.1707226019953528, 0.1504982485165519, 0.8866826661171452, 26.240546626429406, 50.3880851499496, 40.4587854877595, 41.803138640619096, 46.76491729674801, 23.115258947495494, 1.4588005600437042, 1.050227974211016, 0.6210015966526924, 0.5217509224049507, 0.2086368909165744, 0.24566679261624816, 2.6027836001688436, 3.0970341111383135, 0.5135536896845987, 10.853791525287013, 43.326140065347, 56.25422900722873, 58.55096109451787, 58.26895052386869, 55.32509796081051, 56.552890039259395, 55.68171593450732, 57.061390030768614, 56.23957110989479, 57.733115534628595, 56.49711393540906, 56.869056609369096, 56.68080245294879, 54.780688670373735, 46.20062551190777, 44.12473071006037, 50.40591624475295, 52.71268567731304, 57.13117291850429, 57.95157194137574, 53.96752249810004, 57.117511303194114, 55.34253681859663, 47.10406503369732, 42.87971550418485, 43.89329910278321, 43.681781368870894, 44.30027638712237, 42.62433390463553, 43.77141144967849, 43.44658820859848, 42.57543371569726, 41.79336017177951, 43.47954788515645, 42.905736507907996, 41.760475020254816, 40.28349868712887, 41.22981755964218, 42.86447317369523, 41.40757937585154, 44.69531789902718, 45.200330903453214, 45.718876084973736, 46.86515738887172, 47.44161636598649, 47.670898514409224, 53.783151488150324, 53.64333860335812, 55.900290012359626, 53.53200212601693, 51.13373556444722, 55.390303442555094, 53.85704109745642, 55.192376721289854, 53.78237485885621, 55.523228645324714, 57.074737856465006, 55.06424857724098, 56.20011598833146, 56.96445257433, 53.794844073633996, 53.12776265605804, 43.90092026802802, 41.012051490045366, 40.45620064581595, 38.763870500749164, 40.64844777507167, 38.85002143921391, 40.08114360993908, 41.21561857961839, 43.04260369270079, 39.01334893318915, 40.06871754123319, 42.17666987449893, 39.84790771238266, 42.188354615242254, 50.179760225357555, 51.085843424643244, 55.03723129149407, 52.99005608404837, 50.0934249354947, 47.06177011612923, 49.626356940115656, 50.81188155758766, 53.23219968426613, 50.354725391634055, 50.266424994314875, 53.402536453739295, 51.89922924964659, 50.51452667482438, 50.95042359444403, 52.97894793172037, 52.5846516701483, 50.47764070572392, 51.460802401265795, 50.04411289768834, 53.75502024927447, 52.510377668565326, 54.98427144942745, 50.87749104345999, 42.66530306108537, 20.249745922703898, 2.2281734693434934, 2.942536117569093, 13.814823089107392, 19.33276245670934, 16.603830283687962, 10.97042320236083, 0.9367981156514538, 0.11421869163431468, 0.24780483676060555, 0.1060917781245324, 9.228506453575628, 49.73260218097318, 38.385114669799805, 44.81682900459536, 47.083033284833355, 8.311662231722186, 0.22796965594733917, 0.21348572185923978, 0.2282011830398152, 0.11855144744678853, 0.2687645120726478, 0.27034332735403893, 0.14589209890654012, 0.1297686294081711, 0.31705336284733593, 0.1315651362341258, 0.17676026350067509, 0.27746910950349224, 0.13238003928094141, 0.12131153966390318, 0.09761572770413854, 0.2665269837504433, 0.09725011224227567, 0.18298877282969414], [0.011426787447905349, 0.0565000799214167, 0.029261249207681226, 0.010370454664582448, 0.0536578860614569, 0.021369840701921813, 0.009550366160129348, 0.054631748522121104, 0.05465360501060083, 0.005542348315488668, 0.022523913855454134, 0.011027074370142675, 0.08449170693394639, 0.024506852008222092, 0.039073552320440935, 0.027782241776285153, 0.04781369623097201, 0.0393921721185888, 0.016260126177521966, 0.021094479973638253, 0.008067585745706193, 0.01846194905679553, 0.02580395569243739, 0.08947006036196986, 3.4973487594435295, 31.394476313744825, 36.331651902967884, 24.546186654798447, 35.06384772639121, 19.344496227079823, 2.894262036969585, 0.12856207157094635, 0.02263520344821436, 0.03769669313764861, 0.05329694756637177, 0.14311251741263176, 1.240859577252019, 0.8951693268552904, 0.41412693778834037, 0.8532011917521878, 13.724061404505084, 41.1525547119879, 53.6166625638162, 52.944191809623476, 54.528080186536236, 55.84136424526092, 53.60501704677459, 53.171732425689704, 53.775145930628625, 49.54936865837344, 48.53321982968239, 47.854351689738614, 46.40623615634057, 41.60292125517323, 40.96934472360919, 44.137305828832815, 47.7773908645876, 50.76804514854185, 51.87422806216825, 52.67458769582933, 51.594229667417466, 52.11260226465041, 53.34513256626745, 44.39960648936611, 38.47465453609344, 37.570724718032345, 39.37756453790973, 41.85388234353835, 39.211322722896455, 38.482275701338246, 39.767557959402765, 40.37486245555263, 39.80611485819663, 37.12890109708233, 37.624523947315836, 37.26532113167548, 38.85905073535058, 37.28426225723759, 37.955972071616884, 36.33841406914496, 39.71431178431357, 40.21473169326782, 41.264785489728375, 40.35131254503804, 42.80905008316041, 43.48244259434362, 46.55563531383392, 50.81415260991743, 52.117128679829264, 50.06267747571392, 44.25041521749189, 54.27936661627985, 50.66155279836347, 50.30251079990018, 56.13701289699924, 51.29076373192572, 49.825303477625695, 51.151966741008145, 51.28067147347235, 50.29954548804991, 49.93130160916237, 46.764175968785445, 37.4256480124689, 35.978771948045306, 36.00201983605662, 35.66965387713525, 36.907283259976296, 36.75004328450849, 38.902075213770715, 38.121507859999134, 37.93504622674758, 39.09923315048218, 36.68848952939434, 38.27163265597436, 37.64533604345014, 38.15825262377339, 47.086759536497055, 50.33274050681822, 49.3783611636008, 48.37489335767685, 44.96845606834658, 40.61457026389338, 44.447463327838534, 47.80338048934937, 47.4176702960845, 50.21617551003733, 49.66024229603429, 47.7944217958758, 49.52061376264019, 47.686246748893495, 50.22373783972956, 48.42626856219385, 46.929621542653734, 45.81333460346345, 46.87777565371606, 46.060789092894524, 50.253818496581054, 49.730597849815126, 50.461249120773815, 41.48810955785936, 27.28672512115971, 5.651880954542468, 0.3147299407470611, 2.4273551039157377, 9.361212984208139, 10.502754103752876, 7.894295569389098, 6.091263390356495, 1.2947849352513592, 0.6333734876205844, 0.28640831370026837, 0.07269570724137368, 14.31312393757605, 34.005149026070875, 23.952686940470052, 42.355294612146196, 20.327353938933342, 0.33570122995203544, 0.0046335798669456234, 0.05344255406770015, 0.04582294015093677, 0.02914150583467657, 0.05556927926297631, 0.0825776132724939, 0.04851061024612958, 0.02619135294920735, 0.04438458326002283, 0.02165654719236397, 0.05322193223682623, 0.02965690680749474, 0.06940691476507534, 0.05986502153738853, 0.03547022329463113, 0.051733622582809585, 0.04382432400879841, 0.029496221780596726, 0.01756424531190386, 0.051625765063950134, 0.0259322984023921, 0.014056068236729311, 0.032880788653968804, 0.01602015871134016, 0.016820224550282283, 0.037269392276122686, 0.03236334605683242, 0.012242896125591811, 0.03860012913543371, 0.006947061497597926, 0.00657342988321738, 0.02888830803004244, 0.03609162019265275, 0.06641635265682014, 0.04382684826850892, 0.005545267589285129, 0.0206225736427211, 0.013620043548965647, 0.03339922333496713, 0.029542464762926105, 0.07735425726540628, 0.021367473490235787, 6.084267352857898, 38.22903571590301, 38.782662576244725, 28.959115897455526, 45.261653238727206, 25.200434077170588, 4.469352537585843, 0.13049802172087854, 0.006249712248738375, 0.04237988054932606, 0.16163394936630804, 0.5336058572415383, 5.303855913300668, 4.009657372390071, 1.3637940128964763, 1.062074267575818, 17.71492596595518, 44.60681746082921, 56.15827998807354, 55.8002499611147, 56.91593285529845, 57.125371733019435, 56.24777670829528, 53.69958146925896, 54.859128229079715, 51.06807901013283, 52.34805822372437, 51.16960956204323, 48.97221934410834, 44.65030085655951, 42.24651944252753, 44.82119068022698, 49.37652549436016, 52.08839339594687, 54.22239418952696, 53.37826090474283, 53.92982852074408, 54.08719793442757, 54.38862031505954, 47.57456510297714, 39.38095738810878, 39.540484105387044, 40.18296049487206, 43.409137418193204, 41.234155701052764, 40.397263111606726, 42.35917383624662, 42.403284811204486, 39.72805576939737, 38.825965542947095, 40.682517482388405, 39.0809392159985, 39.942185801844445, 38.96614320816533, 39.084865508540986, 38.999848135056034, 41.49228295972271, 43.05924238697175, 43.28930900942895, 42.33683986048545, 44.43809670786704, 45.74664646579374, 48.39682725168044, 51.78680627576767, 54.723975120052216, 50.794266193143784, 47.568065735601614, 54.63387827719412, 52.621396433922556, 51.80692803475165, 56.83904263281054, 53.388400231638265, 50.75506602564166, 52.901171253573516, 52.40411673822711, 51.75400741638676, 51.51809646237282, 48.78365532044442, 39.44587261446061, 38.19706447662846, 36.79840218636298, 37.668454493245775, 37.78035579189178, 38.17940204374252, 40.26575780683949, 39.769307336499615, 39.43347007997575, 39.88477406963226, 38.877685916039255, 38.56630463753977, 39.257355659238755, 39.96799107520811, 47.88860574845345, 52.96843205728839, 51.696062241831136, 50.84283690298758, 48.85625839233399, 41.64801282267417, 47.479906543608635, 49.39573726346416, 50.50456777695687, 52.5819452347294, 51.188793874556026, 48.86597802562099, 49.79492472064111, 47.569795500847604, 49.57942970337407, 48.96431576821112, 48.09574611725346, 47.959655561754786, 49.307895783455145, 48.13743698981501, 52.85732307741719, 53.0912140107924, 51.467525343741144, 44.76828967371295, 30.126509358805997, 8.07688582328058, 1.1000900018599726, 4.370145009409997, 9.30380811614375, 11.662514632748021, 8.597507899807347, 9.956193393276585, 2.314063815339919, 1.1603152992263919, 0.09073291800075, 0.11204280274649782, 14.703262486765462, 46.94979037007978, 28.600556350523426, 45.83192663808023, 27.48741319102626, 1.1021597875702767, 0.04386349408436687, 0.09625445074972608, 0.035079694653470675, 0.032515376205405885, 0.06781767302703473, 0.10052850890544154, 0.06125347163047522, 0.021398701149249272, 0.02857039494800472, 0.04008836218065793, 0.05075309132676452, 0.019408169149931882, 0.005302960682104552, 0.07089615138548036, 0.034214593695416566, 0.0858057622287062, 0.025442502003223188, 0.0222223203614234, 0.17453367491402935, 0.22788442100488374, 0.1433627676939772, 0.14851572022082346, 0.196734382019889, 0.20901101761527602, 0.1254982484744922, 0.20700526153368337, 0.1350366483412443, 0.19569288548682967, 0.1185142538780647, 0.1384744832232114, 0.21970762751035153, 0.10216177005561129, 0.1314645182461508, 0.09854991064076463, 0.18887939141883006, 0.09073613557003199, 0.19582984668593253, 0.12804040399890754, 0.10813541725398072, 0.11205365821238487, 0.1030450387887897, 0.21990674908363053, 6.416085650843959, 44.452276076039965, 48.33095888937674, 35.26228435577885, 47.818124678827104, 34.80721096838675, 7.973068529559721, 0.2897022772700556, 0.1503830595362571, 0.13623882415554217, 0.22517703563695957, 0.5363481455752926, 6.507192013725159, 3.5090592407411147, 1.0705691407765112, 1.3771668437027162, 16.99194488986846, 48.528093291867165, 57.11160029134443, 55.61127408858269, 57.90648821861514, 57.908708280132664, 56.056969088892785, 54.92478086102394, 56.610729309820364, 51.56047374971452, 52.34372400468396, 52.79343551205051, 50.11807310965754, 45.92497310330791, 44.82949433788177, 47.677013489507864, 51.59275877860285, 53.74782662237845, 56.882733914159964, 56.134271160248794, 57.02339010853922, 55.3874832584012, 57.753417722640506, 50.902602057303156, 41.31911423898513, 40.931717426546165, 41.34824568225492, 45.04085125461702, 43.02942060655163, 42.42874099362282, 45.80065750306653, 45.33578995735415, 42.20376953001946, 40.621081398379424, 43.38873324855682, 40.90390782202444, 42.11736755986368, 41.4607588706478, 40.127490335895175, 41.24344779599098, 44.099317673713934, 44.26159789485317, 44.01535149543516, 44.01771668464907, 46.46462455872567, 47.78375687137727, 49.479154309918805, 55.18259825245027, 56.40724066765078, 53.03179402505198, 51.182612219164454, 56.927284194577126, 54.658169515671275, 53.73266273929227, 57.56471641602055, 55.76117530945809, 53.25307453832319, 54.207548018424745, 53.04918189202586, 52.458484711185584, 54.14707683747815, 50.506442669899236, 41.23706609972062, 40.62150501435803, 38.407840882578206, 39.94535115457351, 40.280011700045684, 39.433250427246094, 42.43424407897457, 42.13178227024694, 40.811967465185354, 42.90980792814686, 41.244298950318374, 41.18704803528325, 42.05716702245897, 41.44212368995913, 48.64028092353575, 54.19754989685551, 52.476217746734626, 52.071840993819706, 51.25394444311819, 42.859134827890706, 49.0363932424976, 52.21712166263212, 51.02703140627954, 54.6307207692054, 53.07163746126237, 50.74143186692269, 51.513624960376376, 47.49946740365798, 51.61167636994393, 50.20969967688284, 49.81426200559063, 50.20411029938729, 50.39756159628592, 50.05054950714112, 55.64701472559283, 54.69619297212171, 51.22925312288346, 43.86405783314859, 29.598334758512436, 7.711854855860434, 1.1128574393449293, 6.072045247400961, 18.525750483236006, 22.61989301250827, 17.665513907709432, 17.665598238668135, 4.986473408437544, 2.87625222917526, 0.9663563005385861, 0.1740361774160016, 21.517589322982296, 47.526488611775065, 32.684249685656646, 54.426765364985314, 31.55346566630948, 1.4282699337890072, 0.13078679090305684, 0.2709750434564006, 0.12681030427976964, 0.10000677238548956, 0.20888973057510393, 0.2617997309613613, 0.1418954794926028, 0.15935926577977597, 0.12244694325472079, 0.20870685006581968, 0.10282226042040896, 0.07399421095127061, 0.15861973046295105, 0.11304587230927522, 0.221181228276222, 0.22247426211833957, 0.174062377623012, 0.1303788490833775], [0.0071790089808224196, 0.01830041750274118, 0.027576838282027075, 0.06769600294290051, 0.02037117614470903, 0.02718618323635911, 0.020661954392468738, 0.05226200874594431, 0.04112389471922671, 0.06605010134198012, 0.07279620265528079, 0.006249331598800998, 0.0445881060084268, 0.08582649256793723, 0.04812918272950957, 0.06830397798048873, 0.030302925771402738, 0.03457241804308949, 0.026040073566799684, 0.03468813945449168, 0.08457538671791555, 0.0825386883450612, 0.04903849845211353, 0.05102821265257174, 0.3957907765382721, 12.737695132532428, 33.055119591374556, 24.9462233051177, 27.644774759969405, 33.47120461925384, 8.627356156226128, 0.0158024097101823, 0.0576272135930917, 0.02474698609852743, 0.21738593676878562, 0.20259228865465811, 1.530422916816127, 3.067520481924857, 0.8767047692691127, 0.5662549923985236, 2.045053082608408, 18.436547940777196, 40.67544937133789, 49.67000507539319, 53.2162356376648, 51.473565793806515, 50.83715338860789, 55.30700014483545, 52.335302675924, 52.239106547447946, 48.247459473148474, 42.509792850863555, 42.22578187142649, 43.41197329182779, 44.632677647375296, 47.762740811994, 50.10197178010018, 52.32512804769701, 55.138977573763945, 51.89622863646477, 51.07521772384644, 53.9562221496336, 51.33438048824188, 47.86507544978973, 41.842040707988126, 39.01590239617133, 39.976020166950846, 39.83823514753773, 39.8130613757718, 38.973101492851015, 39.83813316591325, 40.19446872895764, 39.31059006721743, 38.11844448889456, 37.647685543183364, 38.15920183735509, 36.88058368621334, 37.810205028903106, 39.47702407836914, 38.466927466853974, 38.135306758265344, 37.57325856916366, 39.40668029169883, 39.49714583735312, 42.7322304633356, 46.18746595997965, 48.694750878118704, 50.74807243962442, 53.059913496817316, 50.670711532715835, 42.1909551466665, 54.60910458718577, 49.262235472279215, 57.53170574865034, 52.5281616949266, 49.44542977117723, 50.5684631870639, 50.24008627860777, 51.05741016326412, 50.95593844690631, 48.6515812720022, 45.95369269770961, 38.111611720054384, 36.131724772914765, 36.904184587540165, 37.49077504681003, 36.39788896806779, 38.618072079074004, 37.11864802145189, 41.82184442397087, 42.548000658712084, 41.86674379533337, 38.35486142866073, 35.77396146712765, 37.290765546983295, 37.17640492223924, 45.146610121573175, 48.9532821409164, 49.99592265775127, 49.02085281187489, 46.22707797634987, 44.23383143640334, 39.5336042681048, 44.16990856970511, 46.650807703694994, 47.648313506957024, 48.58601100983159, 48.44127555047312, 48.280740784060576, 47.104927955135224, 49.67822636327436, 47.489261396469615, 44.89992833906605, 42.246652803113385, 44.24772054918351, 45.082608807471495, 48.553745592794115, 50.398373526911584, 45.36468998078377, 30.85651932224151, 12.95087497080526, 1.1748945040087546, 1.5815806749366945, 2.5237632855292293, 7.539676533591363, 9.991425102756871, 5.330688357353211, 6.731536878693489, 4.138118672755457, 0.7117564783942315, 0.03779256138049307, 0.3366453567099187, 27.93776796710107, 22.19359609388536, 25.836481701943185, 42.75641579781809, 4.812598170772676, 0.08044079486881534, 0.03551847534254193, 0.05570028029802827, 0.05787297459920088, 0.03922807991564755, 0.0434487838778765, 0.08841822164193278, 0.04278206521825444, 0.0261018757948712, 0.039946543984115124, 0.04035066302505232, 0.05473173831799819, 0.02155099942859623, 0.049884883882177454, 0.03452281001955271, 0.02274850210655601, 0.04696817264982289, 0.023521825731281313, 0.03456478014648442, 0.0630828206457438, 0.023493610713030064, 0.02475703525687418, 0.06442008074373007, 0.03558150905695173, 0.03975688359670101, 0.0069642587350831646, 0.06391962997675424, 0.09787514805793764, 0.06561693990783346, 0.013658681193426734, 0.03316509920442778, 0.028829602712404825, 0.11516706251929845, 0.015053841259120213, 0.02976672742666016, 0.07257028332641048, 0.029861027104479652, 0.022767543221914002, 0.05467451538049406, 0.04789989261377243, 0.04952747705242327, 0.02085449527047815, 0.04573742941682858, 1.1789333195455614, 19.645781324755763, 40.28678955570344, 26.06327706767667, 34.49055017963533, 39.12479523689517, 9.400663202808751, 0.2824556370896678, 0.1312434865582374, 0.09170491503731859, 0.7608514988133985, 0.4255106979079785, 5.685011744499207, 7.415409472680862, 3.229556780668997, 0.912678909878577, 4.216884768778279, 20.701342128938247, 44.960215168614546, 51.65197872346448, 51.636799150897616, 52.26923035037134, 51.22540920011459, 56.62601086401171, 55.180931245127034, 53.85009850225141, 49.88729261582898, 46.33031475928522, 43.58646385131344, 45.000882302561116, 46.304423193777765, 48.154056072235115, 51.649868488311775, 53.10953932423746, 54.32143795874811, 52.45660589587305, 52.83647175758116, 55.9245498718754, 53.73900913423108, 47.87648170225082, 42.81456885799285, 41.988553001034646, 43.242746553113385, 40.95998202600787, 40.42644554568876, 40.9050609988551, 40.971796204966886, 42.86351219300301, 41.622376211227916, 40.310335543847856, 39.416682335638235, 40.35427393451814, 39.10598354954874, 39.24117195990778, 41.07313848310902, 40.98855257034302, 39.97408643845589, 40.26001937927739, 39.6475608887211, 41.69814463584654, 44.13010827956661, 48.23653567221857, 50.9196682899229, 53.33298106347361, 54.304250132653024, 53.29555380728937, 45.50223573561638, 53.55934104611797, 51.47984943082256, 56.761336557326786, 54.8033913489311, 49.38455066373272, 52.91067123413087, 52.73813009262086, 52.89321276449388, 52.826042175292976, 50.75834904947589, 46.76259917597617, 38.728106329517985, 38.09626348557011, 38.62146885164323, 37.726917420664144, 37.717429207217315, 39.333265289183586, 38.56248817136211, 41.797953267251295, 43.94413302021642, 41.60072472787673, 40.28938224238735, 38.23188335664811, 38.87029224826444, 39.0064416393157, 46.60536312287854, 50.31234418192218, 51.739565249412294, 51.34117403338033, 49.17328396151143, 45.56178123720231, 40.66104250569498, 47.06986196579472, 48.996243861413774, 50.883888429211034, 49.390120429377404, 49.59240490390409, 48.85283808554373, 47.87818008853544, 51.468949164113695, 48.053113875850556, 47.281834694647024, 45.884607991864605, 46.2178917854063, 46.259833689658876, 50.244800967554895, 51.191061004515625, 46.86351783813969, 33.03732772027293, 15.318448985776595, 2.0835850988664935, 3.0227748184434833, 5.319804270421305, 8.011011087125349, 7.138268524600614, 7.668253789024969, 9.295869238914984, 2.0461607844598833, 1.1220764801386864, 0.10882172478182663, 0.2826011018647302, 32.70788000475976, 27.516981978570264, 25.947078812506895, 49.21544944086383, 8.512472875656622, 0.06781097741857653, 0.0299913635582573, 0.06979766557173384, 0.06384460315588983, 0.018660233679017233, 0.07602758450253357, 0.052188291935430425, 0.02538824191076621, 0.014271361926089854, 0.002876629033351257, 0.03944590935603746, 0.07005202208435343, 0.06479625289718952, 0.01909760859674744, 0.07973725802355236, 0.01845643513896052, 0.06047452875082532, 0.07859996219556178, 0.020019235352294582, 0.1206346320348882, 0.15648953105893829, 0.13431024377144155, 0.20963386241947451, 0.16557487418815015, 0.20013552129028306, 0.08558725097006367, 0.14001286438395902, 0.1985249899688267, 0.154783652434426, 0.1376420827282052, 0.06714876335594924, 0.15653587937835725, 0.1779512544312785, 0.09171002484377354, 0.14254012715912637, 0.15484680872290366, 0.10478858595653888, 0.125853008470468, 0.12012204260475214, 0.12039687664758776, 0.1914920423540377, 0.2610495776659058, 0.1381793555112616, 0.8292068276674518, 20.862765312194824, 47.58296289751607, 35.12048282930928, 38.61339269145843, 48.01905593564434, 17.340631831076838, 0.4993153020979897, 0.323998348246659, 0.1687669327422496, 0.5603748079269164, 0.4683026839648524, 4.3702528745897355, 12.765312540915705, 3.1281181593095106, 0.5565381170280519, 3.2908041006134403, 21.04468091841667, 45.594097645052024, 52.717455279442575, 52.09258640966108, 51.753968192685036, 51.53762986583095, 57.07780122756959, 57.2206304150243, 56.886224823613325, 52.28400984118062, 48.332802403357725, 47.15997057576334, 48.59459707813878, 49.76604823143252, 51.074645057801284, 54.638490984516764, 56.073815668782885, 56.43520324460922, 54.364721313599624, 54.999953085376376, 58.34222039868755, 55.764281826634566, 50.25234368539626, 44.42777695194368, 43.19700779453401, 43.515621923631244, 43.533896246264064, 43.51219377210064, 43.197678519833474, 43.39276152272379, 44.28711291282408, 43.42485435547368, 43.006914046502885, 42.95063980164067, 43.413856029510505, 40.545756201590265, 42.592852961632516, 43.73826349935224, 42.81378438395839, 42.23070444599275, 41.99949641381541, 41.78635481865176, 44.28857203452818, 47.816842063780754, 51.940880898506414, 53.47621425505608, 55.449899934953265, 56.093478510456706, 54.47149607443041, 47.162833905989125, 53.77926441930956, 54.025400992362734, 58.74828769314674, 57.5832417703444, 52.181079003118704, 53.84040240318545, 56.62244542952507, 54.486573665372795, 55.59774583385837, 51.77003814328102, 49.54093556250296, 41.29099476721979, 39.98870118971794, 40.89612191723239, 40.34267156354843, 40.3615342417071, 41.60916174611738, 40.68905215109549, 45.79414244621031, 46.86470239393173, 45.04451867072813, 43.03158183251658, 39.82344388961792, 41.19625776044784, 40.622328712094216, 48.20304647568734, 52.404834531968646, 53.62870816261538, 53.92788302513861, 50.59453910396945, 48.01129356507332, 43.43336982111777, 48.82935485532207, 50.636837943907715, 53.7178244129304, 51.392823803809385, 51.250288794117594, 52.0607759875636, 48.09106280726772, 52.3250299884427, 50.02535612352433, 49.073702827576675, 47.17726430585308, 47.763340934630364, 47.255825458034394, 52.28696338592037, 53.72127609868204, 48.59727997933665, 34.05944247399607, 14.374767907204168, 2.8284856052167955, 3.315463306442384, 6.3238653348338225, 15.332353788037455, 20.045643429602347, 14.345694318894418, 15.823617904416977, 10.512302133344836, 3.54696600667892, 0.4962825745103821, 0.7200243444212022, 39.69744951494279, 31.559931693538545, 35.960234826610936, 55.24772528679141, 10.092395736325173, 0.1835509741138066, 0.11544867644026396, 0.18877089804699346, 0.11212360970075093, 0.18307276670971226, 0.1328286297258831, 0.1815573222214176, 0.17530229092845995, 0.11709489979811254, 0.11662911834015001, 0.19474019386595298, 0.1499503730766235, 0.16301082387085886, 0.15212076145314402, 0.2726194358641102, 0.12836627481925872, 0.20929197270062663, 0.14920515338740042, 0.09984731884492982], [0.0465343447191821, 0.05752188416438238, 0.014812318634452119, 0.07361194839881313, 0.04404195809676763, 0.030581283818690047, 0.0288949231992686, 0.05672246758495608, 0.06605463658249186, 0.00724077960776706, 0.033380626550605225, 0.07991081524279811, 0.013698811751730261, 0.026491783904812993, 0.06560461355313178, 0.04074872614094808, 0.03476999594920105, 0.03708612489243669, 0.01014230601985248, 0.03388057169955104, 0.02372224199315233, 0.017727058148011565, 0.045868576008586154, 0.015709080091196925, 0.07776282727718353, 1.8791591327997947, 26.045663664417884, 39.428916208205685, 25.456780579782304, 40.65827723472349, 18.692651256438225, 0.6596158601103291, 0.13111467653464887, 0.23592256790687963, 0.5932434119524495, 0.28831844668715234, 4.153564966494038, 6.38737831384905, 3.571007929501995, 1.8623313067420837, 0.06240079554939463, 4.282710475306358, 23.917397376029726, 39.18815328228859, 54.43714787883144, 49.42857534654679, 55.535819453577844, 53.87290316243326, 52.30215864796793, 49.981939408086966, 47.02688063344648, 45.00307098511727, 43.46710220459969, 44.08813107398249, 47.05023442545245, 49.86125592262515, 51.29448213884908, 52.156117039342085, 52.59541073153096, 51.28892806268508, 53.68294277498799, 53.89273074365432, 52.05970910287673, 46.92840560790032, 41.61160146036456, 38.85952141977126, 38.18056306531353, 39.423122867461174, 39.019561967542096, 41.08752573690107, 39.78605585713541, 40.31542678033152, 41.06930632745066, 38.90933552095967, 39.93927540317659, 37.62496717514531, 38.288604751709975, 38.3270675136197, 37.79421352571057, 38.13010961778703, 37.25274993527321, 38.15736224574428, 39.380471014207416, 38.12875640007758, 42.93565634758242, 44.92887935330791, 48.52991327162712, 49.30424797919489, 54.51181411743165, 49.3606359727921, 45.23606369572301, 52.50055213128367, 52.58840537840321, 54.54877068919521, 48.380314073254986, 49.4691954120513, 49.82943373341715, 50.73225352071947, 51.85164305471605, 48.93262301721881, 46.88722464346117, 41.708382021996286, 37.831566256861535, 36.60821037907755, 37.52045169953377, 36.465145849412494, 37.61108982947565, 37.378199100494385, 37.80588649934338, 42.768979149480025, 50.434259291618105, 47.47130086345058, 42.77319961978544, 35.523710327763716, 35.29711500290902, 37.88776989906065, 40.448610859532515, 46.88829152814804, 49.70693419056554, 49.765616770713564, 46.872857001519975, 47.34158415948191, 41.71142185887983, 38.043433081719186, 40.186718125497144, 45.06398539389334, 47.114624054201194, 48.00313503511491, 48.25971295756679, 49.05472247831283, 47.65051787899387, 46.84387068594656, 42.56029336683212, 40.89669850564773, 42.511542227960405, 48.283862990717736, 46.791256012455115, 48.27775193798927, 36.380320672065984, 18.246973906793905, 3.167626968314571, 0.4889465165474723, 2.8584809505170394, 4.6003204776394755, 4.867717277619147, 4.56795209838498, 5.154145417674895, 7.57249451452686, 0.5472950517169891, 0.4121242920237203, 0.1641882244016855, 4.543148500304069, 33.798804898415845, 23.195651846547282, 38.58766194312803, 25.897413761385028, 1.2343570229507264, 0.04443811748417155, 0.046708101121288155, 0.06285391740440842, 0.0923875530040072, 0.06474779017509953, 0.010971442022691331, 0.05532734103560929, 0.080642651375984, 0.01996627186364945, 0.038966391941592585, 0.041285884010815815, 0.02722993834815439, 0.0820795871737984, 0.06192536138358617, 0.03406230307694885, 0.07739838392984483, 0.03178607582324936, 0.06594323973742224, 0.03423117566853762, 0.039578668562875646, 0.06610390369690235, 0.05491472991003145, 0.06198012900929298, 0.02074813736873048, 0.06421044078325072, 0.007927225031439335, 0.022567211229714657, 0.042612422708301775, 0.039130744614428094, 0.023253306168161576, 0.04198418081467671, 0.025648769261615894, 0.018104934847102534, 0.03508470869893509, 0.07300077111370142, 0.09321915676757213, 0.018912858832927964, 0.03488942139571713, 0.040625837977014245, 0.050532883183369716, 0.0716035646356402, 0.07373093717521237, 0.027357465174469738, 0.027221195369718537, 3.7224418165222293, 34.02893820116597, 39.729746310941636, 26.14179115141592, 48.637649013150124, 22.84028510893545, 0.7093817284030299, 0.12878972225852553, 0.26562422574047123, 0.642322926752029, 2.603137839225031, 6.324782188861601, 7.5541383124166925, 6.217040563783338, 2.496031883262819, 0.7536065746699611, 7.778761665667258, 26.34728216355847, 42.76442920008014, 55.88436518946002, 51.78236615273261, 56.446966432756, 55.08127950852918, 55.001545567666334, 51.69072781839679, 47.809334647270944, 45.71476936340333, 45.32777263272194, 46.19011355984596, 48.202697384742, 51.64391040802003, 51.94694880516299, 54.77352642243909, 53.936790727799945, 52.81533410472255, 55.8947398585658, 54.591136209426395, 51.58058374158798, 48.59042367627544, 42.65271225283223, 40.69737149823097, 40.422833042760054, 41.26789592927502, 40.10486218237108, 41.81425071531727, 41.72243587432369, 42.85921719766433, 43.31745593778549, 41.31597634284727, 39.464143014723255, 39.403511016599595, 40.262486550115774, 40.26827596849011, 38.98379387394075, 39.88572720558413, 39.50785783029372, 41.059421954616425, 41.38884221353839, 41.35935775695309, 45.36989888837261, 47.19782929266653, 50.75465809914374, 50.83600805651758, 55.38988767131683, 51.80807336684197, 46.36799304716049, 53.907074851374475, 53.00392558497768, 56.00196176959623, 49.71541435487809, 50.61684562313942, 52.11018216225409, 50.994295304821385, 52.86823511123658, 50.554491704510106, 47.62030386155652, 43.30317851035826, 38.70135576494279, 37.50353843935075, 38.794837613259595, 38.19034153415311, 39.11432250853508, 39.47857341458721, 40.23323743574081, 44.27263152214789, 49.47785600539177, 47.83847001291091, 44.26830122547765, 37.040494795768495, 37.25183994539323, 41.17435524540563, 43.278244003172844, 49.23848159851567, 50.6171594127532, 50.782193137753396, 48.659308341241655, 50.06254803749823, 44.36032787446053, 40.06388910355107, 42.12378847983576, 47.69560160175447, 47.11916223649056, 50.39199967538157, 49.72399257844495, 49.48992906078216, 48.993478590442294, 47.77646518522694, 43.30859138119606, 42.4518515986781, 44.50960936084871, 49.37457607638452, 49.24258439771591, 50.64313727040445, 38.54665748534664, 21.344457864761356, 5.469342672055768, 1.539807432601529, 6.916566846832153, 6.431282383780326, 10.700480784139327, 6.561410936617083, 8.303632159386913, 7.798340176382373, 1.1061321679622897, 0.13741334419577353, 0.09936548018407437, 4.530395403985055, 43.104788949412686, 24.524513598411318, 39.29033887001776, 33.99692381581953, 1.9018108205449198, 0.0868553486502459, 0.021909873316725417, 0.04257740482928292, 0.03260987315086588, 0.02342777120159759, 0.031171922286551808, 0.04918539198115469, 0.018674609318916357, 0.03958120048346539, 0.029041642443306988, 0.021317641385981155, 0.08096654568949053, 0.030021876840281393, 0.027089320994432897, 0.03831155530567612, 0.03783373860642314, 0.03254765915053506, 0.0456292616323598, 0.021010003458227844, 0.1896287786263612, 0.18413395170242558, 0.13698465671510468, 0.30529173751992567, 0.13641482519526638, 0.193160658461913, 0.13619998349778115, 0.13958010131553297, 0.11299199334556058, 0.11727858469971728, 0.06799247896959705, 0.06838115367798075, 0.0826923885653096, 0.11789639630625326, 0.15700353009085502, 0.1857754942630568, 0.1718593845444341, 0.11913672329918032, 0.19173758885552808, 0.13453944195662776, 0.13751362510506185, 0.12294922114139605, 0.2202371474836142, 0.10142597324785688, 0.1684048336239592, 3.2687944558358963, 39.200128278424664, 50.56670988759687, 36.54945327389625, 52.79335706464706, 31.12977320148099, 1.6359949808928276, 0.6629772087739361, 0.34728975005207524, 1.9371253900950955, 4.152729991943606, 11.042945865661869, 15.421630855529541, 11.838880085176038, 3.946766334195291, 0.5938591627824692, 6.311746191593909, 27.036632837787753, 41.54473289366692, 54.80283044999646, 50.71534418290662, 58.70411788263629, 56.604312312218454, 57.073831788955204, 54.316550685513405, 50.338863326657204, 48.485390447801166, 47.60763068352976, 48.278587402835974, 51.469321789280066, 55.5377100360009, 52.928772972476104, 56.220327961829405, 56.43222616564844, 54.10322473895166, 56.8996746309342, 57.483684170630674, 56.212608737330285, 50.92478698299777, 45.09907883982505, 42.11542990899856, 42.295231357697524, 42.71159487385904, 42.30151499471357, 44.0603881497537, 44.022207798496375, 44.75594989715084, 45.56962989991712, 42.98068123479044, 43.24286814658873, 41.36261724656628, 42.72799038117932, 41.738835304014145, 40.278156418954175, 42.363763009348226, 40.45489057417839, 42.34724983092278, 43.40527780594365, 43.22737086203791, 47.01275617845597, 50.19660680524765, 52.15418331084713, 53.246700686793176, 57.38140444601736, 52.80870529913133, 49.777254443014826, 53.634819215343846, 55.25762142673616, 58.091122027366396, 51.92162990570069, 52.10779343881915, 54.239652618285156, 53.292251171604285, 55.82414111783428, 51.10882459148284, 51.78441755233273, 44.86691767169584, 40.48365331465199, 40.07357343550652, 41.952216163758315, 41.02967862159976, 41.40332360421458, 42.141819615517896, 42.8633866771575, 45.561451758107836, 54.37517050773867, 50.21610490737423, 48.595071684929636, 39.14079458482804, 39.081386366198146, 42.90577965397989, 44.635642959225564, 49.97419664936681, 52.83366334053778, 52.49341733994023, 50.765170051205544, 52.001779617801795, 47.0299675387721, 41.437220727243734, 43.42474452910885, 48.65053007679601, 50.23915275450676, 52.80544973188832, 50.94400659684212, 52.66704890035814, 51.41351430646835, 50.5310869216919, 45.91185669745169, 45.34362293058827, 46.834900225362475, 51.86998013527163, 50.020500229251006, 52.60857420582926, 38.90058863547541, 21.947169265439435, 5.015046404254052, 1.829997738522868, 8.405464733800581, 11.298501030091318, 13.947545309220592, 13.500184282179802, 14.56033229827881, 18.80030070581744, 5.840554804571214, 1.4734018281582864, 0.3969374875868521, 7.301567091095833, 45.820979302929295, 30.33449499837814, 50.043928546290246, 36.99873332054385, 2.713014949713984, 0.19070675626637476, 0.18771578047064044, 0.20173932635976424, 0.22215858792826054, 0.12830437491497687, 0.19860043430760985, 0.1732698137000684, 0.2006835805913133, 0.12177234155035789, 0.08559343329961262, 0.1792892729563098, 0.1355713164253581, 0.15280549083986592, 0.25073046525639875, 0.19946755390734444, 0.1262679216902583, 0.09369005569286885, 0.1597218705160964, 0.15871639543723676], [0.036327318633876504, 0.020383891289032275, 0.06237741071550597, 0.0710986131021092, 0.03104988064977431, 0.04918542645511128, 0.0368139989704134, 0.08483425548840916, 0.049301523249596364, 0.06581905688489638, 0.01897531415095493, 0.03747807079625707, 0.020595113221075267, 0.050641617872902465, 0.07974543984258368, 0.00705229468651176, 0.024214729276155273, 0.0205659999647328, 0.07658273011686341, 0.026320854367147532, 0.02269188054807244, 0.063929324819436, 0.08938288721706598, 0.04179706383917121, 0.10326943360269071, 0.252819158016674, 7.010151657365984, 36.908942422559186, 25.55586749507535, 36.66426104883994, 27.072004772001698, 0.6443403120483122, 0.07785679562197578, 0.26515807656030504, 0.8299334467418733, 1.3673355454398741, 8.458959979395713, 7.254156912526778, 4.174849217937839, 2.604833774028286, 2.6735210947452055, 0.7832976298466806, 8.353953226920098, 25.642469506109915, 42.3492306278598, 55.69101587418587, 56.23082030204035, 54.31193405582059, 52.086141955467966, 51.291885529795, 47.17974324380198, 45.098333589492306, 43.23674140437957, 45.468122882227746, 46.46167493635609, 50.23300247807657, 53.50027799606324, 53.27222354950444, 53.07778381532239, 51.05654331945604, 52.11688549287858, 52.05119363723263, 48.43652163782428, 45.03753292945124, 40.65426465003721, 40.36751585621988, 39.59524431536275, 39.27606144259053, 38.26975384066182, 40.0689842624049, 41.82705333155971, 43.602729920418035, 41.58109718753446, 40.01336505336147, 40.220552490603545, 38.13996261165988, 38.327934357427786, 37.71307537632604, 37.644759455034816, 38.978004455566406, 38.47715308589321, 37.87340617948963, 38.05189755655105, 42.34735573491743, 43.7550590884301, 45.23912314445742, 47.16329282329929, 49.168122122364665, 53.59694480895997, 49.95734614710654, 42.29169337980209, 49.82305595951696, 50.563854402111424, 50.49336941011491, 50.94231213292768, 51.59424143452799, 51.0271216207935, 50.17560643534507, 49.71693623450495, 48.68720423790717, 43.84102959786692, 41.66848759497366, 36.671238945376494, 35.86903972010459, 36.391228783515196, 34.5323508785617, 37.26627426762735, 37.525688063713815, 39.63048681136101, 46.86661258820565, 49.5940326875256, 50.32172256900419, 47.845898982017275, 40.879800934945386, 36.19647918208953, 35.81509144075456, 36.495524606397076, 44.62887294830815, 49.39145011286582, 49.96027223525509, 49.83591348894181, 49.57867268593081, 47.185842529419936, 44.01226851247972, 37.21313399653281, 37.07897324715891, 39.0721962528844, 44.7132666649357, 45.89660259985155, 45.62124044664445, 45.59775721642279, 44.708732405016505, 39.548717160378736, 40.13588420806393, 43.74664168204031, 46.01406974177207, 46.36076804130308, 45.212199995594645, 28.071065795037057, 9.387632108503773, 0.8302430688373504, 1.0079595939286294, 5.705894443296618, 4.29905891418457, 8.949879907792615, 2.9202114574370848, 6.279818588687528, 6.149693467924672, 0.3302057748360019, 0.07576583524144466, 0.13129674499073338, 15.810639762109327, 32.11590217005822, 20.25079711791008, 40.945359430005475, 11.331573474791742, 0.08155304728256119, 0.07572884851646039, 0.05832314318526657, 0.008695506840012968, 0.05244094007197888, 0.060371386503139814, 0.021234720029057037, 0.020405766929710106, 0.03789181190152322, 0.053880017085541645, 0.06351115572596751, 0.03610632525035932, 0.09902317677774737, 0.08101320044407923, 0.04783942912434859, 0.08972481524031009, 0.0036222451730751467, 0.07126896041295222, 0.05326739189425304, 0.041560028574519584, 0.042979451602384935, 0.07308799022388074, 0.07667603196516153, 0.011554154353366505, 0.045848251695954995, 0.048748721864314816, 0.07911287338262604, 0.014988584932120097, 0.026695262603161317, 0.03095710740214394, 0.04005055574159469, 0.011150157886497196, 0.04670453498200063, 0.039967848889289365, 0.06577661561389124, 0.0318979591341509, 0.03986757181044068, 0.045848546639805844, 0.04684193285122033, 0.009704754901899686, 0.03669221397309053, 0.03121759070293798, 0.027863494976754152, 0.026710166843728195, 0.04872072135068236, 0.2717793132028272, 13.145045042037966, 43.26164845497378, 27.844019397612545, 41.69942332852272, 31.18404115400007, 0.7457424063355692, 0.08662020562276726, 1.0997092868051221, 1.7404804258577287, 3.4579350679151477, 10.098978454066861, 9.47967444696734, 7.196341176186839, 4.764098553888259, 2.027283029690866, 2.128518790968003, 12.24392266042771, 28.253240277690274, 44.31581681774509, 54.93620672533589, 56.508967338069795, 56.30788703118601, 54.08691160140499, 52.98151708418324, 49.67685745608423, 46.940745384462424, 46.82041098994594, 46.65741297506517, 50.36946173637144, 52.70387603390602, 55.826984836209206, 54.917049869414306, 54.640946388244636, 53.93432355696156, 54.95131177286948, 53.440826631361446, 50.887234210968025, 47.21015337974795, 42.446579933166504, 41.284107085197206, 42.0629015276509, 41.023194943704915, 38.978612422943115, 42.933887358634706, 44.3947192161314, 45.29552290516515, 43.12804860453452, 42.19128462576097, 42.18069422629572, 39.904958586538996, 41.19494376644012, 39.98680276255454, 40.68055237493208, 41.11941068403183, 39.76935048257151, 40.298074214689194, 40.58679203833304, 44.44136011985041, 45.144511653530984, 46.90775432894307, 50.55217750610844, 50.906347920817716, 54.02145116559921, 50.898165856638265, 45.57927500817084, 49.797721370573974, 52.95803777633175, 52.10736590047037, 50.73424216239683, 53.835903444597804, 51.2147246637652, 51.08304677471038, 52.132853461850075, 50.870426854779645, 46.52728049985824, 42.75605886213241, 37.76112048856674, 38.718335705418745, 38.11320812471452, 38.91292448966734, 38.97154431189261, 39.34834288012597, 42.1361517906189, 47.037773055415, 51.45586021484868, 51.19705046376875, 49.68766358590896, 41.69792498311689, 36.35715123145811, 38.38231801986694, 38.27296626183295, 46.68767013857442, 52.473636827161236, 51.71119082358576, 49.901413148449315, 51.48645077982257, 48.343643834514005, 45.34816503524781, 39.09864087258616, 39.15231458602413, 40.87113249686457, 47.819120960850874, 47.89525416589553, 48.968269517344815, 47.010524349827925, 46.800100957193685, 40.60053602341683, 41.40483371673092, 46.67163548930999, 48.5028410726978, 48.207667027750325, 48.00268788491526, 30.039732802298765, 11.620340328062735, 2.380454588320948, 2.9029782789368785, 5.780693061890141, 6.429864446963034, 7.843261611077094, 5.924047356651676, 8.365907630612774, 3.750559327102477, 0.5880431458353996, 0.09285615366553107, 0.028594515226300687, 17.199771673448627, 38.79253518196845, 20.875836610794067, 47.22174790597732, 16.228396700274562, 0.21708763745282927, 0.05334496212702605, 0.08104218155025475, 0.05132040624777156, 0.03662989272045032, 0.038628796145560286, 0.04674049514916636, 0.01903564740543164, 0.02870159325069718, 0.03986583279085256, 0.10609041448802718, 0.03597335919978158, 0.08372659194132975, 0.05618740113512163, 0.0801745486716109, 0.03247108483206361, 0.030711612611588453, 0.019959890351240194, 0.041150025978323915, 0.020497050136327744, 0.10212684410714334, 0.14778265068607946, 0.16769969565493448, 0.14441502010149343, 0.13787649031127655, 0.17492165248240196, 0.13248877780091378, 0.15291645101481868, 0.08718538698890517, 0.14070470306661823, 0.08624642366363157, 0.1556835146320443, 0.1422018227317641, 0.10165841198496281, 0.2571164822626499, 0.18294617834110416, 0.13221969707838951, 0.13648260865480671, 0.1580759459325383, 0.14271088815744848, 0.12097659070164928, 0.1748994512543563, 0.2280217958914657, 0.1988849746844461, 0.21080580840428031, 0.47521797579623043, 12.834130525588991, 50.35060298058295, 36.251227624954716, 46.72255177651682, 39.250456210105654, 1.3199449787216804, 0.8299792894432623, 1.2787288355250515, 1.833026911462507, 5.728172034986558, 18.09276984583947, 16.737757652036606, 11.739618624410323, 7.570161684866875, 5.053465039499345, 1.2778594176615439, 10.80064929300739, 27.889797379893643, 45.28719179091915, 56.13215700272591, 58.084222578233295, 58.28868004583544, 55.708874425580426, 55.227693742321385, 51.80015410146406, 49.89081098187355, 47.951069493447584, 49.44245661458662, 52.009000701289025, 55.57813006062662, 57.48595914533062, 57.70163851399576, 56.86667180830433, 54.66411975122268, 55.681959121458, 55.96936295109411, 54.45262162916122, 50.57528811116373, 45.43294314415225, 44.026043876524895, 44.08616596652616, 43.72921459136471, 40.799486483297045, 43.90064570211595, 45.730890304811545, 47.78304692237608, 45.28885095350204, 44.4053449169282, 44.555771735406694, 41.41371396280105, 43.27028551409322, 42.60747163526474, 41.654131720142985, 44.36443459603095, 41.96652889251709, 42.72518588650612, 41.14302727483934, 46.81358998821628, 47.296449445909076, 49.64223469457319, 50.1089535990069, 54.71913099288941, 57.21936741182881, 53.82302630332209, 46.41750120347547, 51.142196116908906, 54.015340112870746, 55.3108323004938, 54.382050345020915, 55.078498548077, 54.46849546124859, 53.601926219078806, 55.048339443822066, 52.70148731047108, 49.15124808588336, 45.46725603841966, 39.065218356347856, 39.26816963380383, 39.53201963055519, 38.876022831086196, 41.18573796364569, 42.708472667201875, 43.81767972823113, 50.07646460686961, 53.786320763249556, 53.265135826603064, 51.79810662423411, 45.43949742471018, 38.90965323294363, 38.88682111617058, 39.7246236954966, 48.02335093098302, 53.20533144858576, 52.739863780237016, 51.039343726250436, 54.51917640624508, 50.07404450447329, 47.83387691743913, 40.80275381765058, 41.09923793423561, 41.99420905882313, 49.27775629105107, 50.15561411457677, 49.807295876164595, 50.20907602002544, 49.50503018594558, 42.71771769369803, 45.080898654076364, 47.36096066813315, 50.23839181469333, 48.64249706268311, 48.369045103749926, 29.56884834074205, 11.91162436239181, 2.1009124142508355, 4.079910209102016, 11.459526092775407, 12.027513730910517, 17.62658046137902, 12.165024184411573, 14.607843968176073, 13.595934241048752, 3.262898398022498, 0.14911720649369303, 0.2209105847343322, 24.293566403850434, 42.09823423816312, 28.345251237192464, 54.5645699962493, 19.08657097047375, 0.2891286306323544, 0.2193021218502714, 0.14545276280372374, 0.08862023136668629, 0.18788421256167276, 0.1724862742928728, 0.1259908353489253, 0.13277290449027093, 0.125542099347278, 0.18111326701698766, 0.2528779322822248, 0.2429503367673005, 0.26662927181009327, 0.2249478527735318, 0.12042470096099762, 0.2721629393917899, 0.15251785546781557, 0.16593268321406457, 0.18426481484165116, 0.12394871307356704], [0.040573667389370745, 0.010850335013181453, 0.08672384199716392, 0.06425368644657635, 0.09336834472994651, 0.01747965771374443, 0.05436366371389839, 0.04364205253941398, 0.02844999848504461, 0.05641475304841034, 0.06878923339348647, 0.04564749069451805, 0.08963512166613534, 0.045891700372580564, 0.09445063544497376, 0.046989883581597, 0.03500217804685235, 0.04729671328659019, 0.07669649417361907, 0.047400472235054746, 0.043231245550897815, 0.047106440028836655, 0.028061302709242994, 0.043966146035780834, 0.01149466666843622, 0.054194829426705844, 0.46366674885634457, 20.89447963622309, 34.486263029036984, 31.198797110588323, 43.34633634936425, 3.3181682709724676, 0.09598101098691264, 1.149026840444534, 0.34550507162367144, 4.829343749630836, 6.368612224055875, 5.654992374681658, 3.9148448599923045, 7.774080316866598, 1.6328551235698885, 2.1528855350709732, 2.3163461444839357, 12.151446900060101, 30.71822047233582, 49.447598841882524, 56.16056280751383, 55.73599761532199, 52.00394868850709, 50.91831507221345, 47.34475343458114, 44.92656907727642, 47.10823843556066, 44.92239959778325, 48.81527354640346, 48.99341191014936, 48.50200168548092, 47.82880921517649, 48.38824118337324, 46.12413537117743, 46.41255901705834, 42.25297174146099, 40.60559980330929, 41.20637747549242, 40.76055695933681, 39.50248418315765, 41.11712786459154, 39.54887013281546, 40.464692577239006, 43.389451042298354, 45.667285150097264, 45.93278254232099, 44.41517045420986, 42.37838560535062, 40.18700445851972, 38.970693157565215, 39.07959384302939, 37.628556143852975, 37.48200070473456, 37.71427562159877, 39.47594934894193, 38.39651699989073, 40.93409830524076, 41.841985794805716, 43.44175584854619, 44.73658515561012, 48.184168108047984, 49.25458292807303, 54.1517601474639, 48.014356936177904, 44.06796616892661, 50.30686855316163, 49.29026865190076, 49.866507976285874, 48.87026125384916, 50.73960404242239, 48.64183810449416, 50.33215215129238, 48.27649285716396, 48.357493723592455, 44.417939647551506, 40.12229711778703, 37.75591942571825, 36.5695946447311, 36.245018512971946, 35.42472931646532, 37.27824141902309, 36.012508253897394, 40.31565820017169, 48.83436372203212, 50.68269829596243, 50.49986093275009, 48.47819682090513, 48.208059264767556, 37.11531008443525, 35.72512011374197, 35.713333391374164, 39.59118073986423, 48.023805925923014, 48.336881668336936, 49.929418871479655, 49.90056983886227, 47.51767504599787, 48.250244355970814, 45.89335487734887, 42.961434164354884, 37.348122366013065, 35.818252871113444, 40.09694683936335, 43.35815052832327, 39.94166020424136, 39.29611652128158, 38.81859933176349, 42.08270557465092, 43.39247126733103, 47.350668368800996, 49.25008789185555, 42.28884573905699, 19.18022148070797, 4.267755948728131, 1.1091468771619182, 2.6205357572724743, 4.8948978320244825, 2.8815177659834585, 6.704553913685584, 3.884899524911758, 6.685924126255897, 2.1747274985236507, 0.22885592774518076, 0.05919216268305337, 1.724621180084444, 32.73177312266442, 26.191130645813484, 32.825304000608384, 29.63659747954338, 2.8727181736500036, 0.051767081472902536, 0.060079426564756906, 0.04858644145931448, 0.08184416835466701, 0.10169133078306915, 0.18012404832388126, 0.06907730543565366, 0.036471435094192144, 0.023636373112939542, 0.07208733383806483, 0.05695545024448826, 0.05157623364920578, 0.04734288540578658, 0.15307207411575705, 0.016718926659274488, 0.030220479388991674, 0.03159183806048767, 0.03998265736886571, 0.022706099139947086, 0.019067455376047763, 0.06559043326565335, 0.043288943462915, 0.05255532849039282, 0.032257376944706324, 0.0395992954802369, 0.049599259490928346, 0.06614774690880891, 0.044591005651220206, 0.0355859408755937, 0.09867964763074152, 0.00751822840444924, 0.1180559954035186, 0.06181799033055864, 0.045595534611493356, 0.05803443529012223, 0.023561020704707312, 0.05203999263504821, 0.03769265585428765, 0.06142640065762305, 0.051856024280911496, 0.018342849197647264, 0.052792402059440656, 0.01784134889021516, 0.0312948027896064, 0.030357116915946527, 0.11501389856059706, 1.5599213468451656, 30.37666047773054, 36.15579635866227, 35.856366542077836, 51.04047336886006, 3.055996313210457, 0.11384358434306999, 0.8290916693306739, 0.9439954810565518, 1.9742594491089545, 5.6983997744898645, 7.7727369050825805, 7.204622770509413, 13.837085481612915, 6.666371110946902, 2.8529710010174782, 3.1506720329484637, 15.491601036440944, 33.571817336543916, 52.237251266356445, 58.65808494629399, 56.137107033883375, 52.7175651058074, 54.20525343187394, 48.93079127034834, 48.49809500478929, 47.91956893859371, 48.10348495360344, 50.21898000471054, 50.50481488627773, 50.23301032281692, 51.30255045429353, 52.176674181415194, 49.52557948327834, 47.831366600528845, 46.37388444715931, 42.97599008006435, 43.393302809807565, 41.80178934527982, 41.5670080338755, 43.931659883068455, 41.14885199454523, 41.400864278116536, 44.41856722677908, 48.157162589411584, 48.85776066010999, 46.56944597921064, 45.03818404289984, 41.086019546754905, 41.41069766013853, 39.438663298083895, 40.36768451813729, 39.20753371331, 41.22847610904325, 41.090902897619436, 40.87844379486577, 42.01793939836564, 44.012080238711455, 47.16469310945081, 46.89274734066379, 48.852171282614435, 52.051126956939704, 54.33460143304641, 51.36083687505415, 44.988048307357296, 51.74089493290071, 51.44264574973814, 50.236811099513886, 50.50414416097826, 53.46485507103705, 52.71873397211875, 52.69915742258872, 50.281863443313114, 49.4079162228492, 45.76565427164878, 40.692323407819195, 38.62980781062957, 38.111929432038345, 37.74216367352394, 37.85444936444683, 38.35345329776887, 38.59782872661468, 41.205271367103826, 49.40561771392823, 52.761456428035615, 52.8806572575723, 49.49231386184693, 49.39353289142732, 37.20864288268551, 38.494007510523645, 37.53941243694675, 40.97376915716356, 49.161132458717596, 49.415792342155214, 50.88915224998228, 50.473639888148156, 50.635037575998616, 50.667357906218506, 47.94699415083855, 43.68826112439556, 39.94364492354855, 38.43248513437087, 43.10684819375315, 43.75292139668619, 42.285229313758116, 40.509654706524266, 41.64127419071813, 42.56293312195809, 46.00609164084158, 47.48885739234186, 50.98401477259975, 42.948725684996575, 21.215462876904397, 5.569917146236667, 2.1201347247246773, 3.2137871365393362, 3.770260166737341, 7.530443274205731, 9.176385018133349, 6.493405372865739, 8.148941234234842, 3.449970450132124, 0.34363354946817126, 0.09428145258777565, 1.3454937045612645, 40.0850385235202, 28.56469019766777, 31.09581724289925, 39.19921044380435, 4.704999712205702, 0.029266215372650378, 0.022279376674803997, 0.011816503078256164, 0.03194381907251814, 0.029626887652181813, 0.028127408436229153, 0.02791246906253359, 0.029056575412171024, 0.026921986324352123, 0.03700518387279684, 0.03383851347250804, 0.023838321550659115, 0.030096172047178113, 0.024110361287790923, 0.04071235994718248, 0.03935051608770605, 0.07022534181634266, 0.021546418222809033, 0.10934038162832299, 0.009471425587581772, 0.20136323847597648, 0.19750491325413028, 0.14060777762243826, 0.14066921787396555, 0.2618467381163951, 0.1876590746424852, 0.16922434852007898, 0.17657640239884778, 0.22287674939199803, 0.28069602505814645, 0.14913318708779352, 0.22127200969524924, 0.19462564839951454, 0.12676211734933238, 0.2215226889858323, 0.10295978852457578, 0.14946098078883466, 0.1392166845260128, 0.19409314068334718, 0.11953305122592758, 0.18211707202417238, 0.16648815824620186, 0.09339459856311161, 0.1359442020616224, 0.14241764502179238, 0.16120870928129843, 1.9828705225260028, 33.938598171357185, 46.85335889939339, 40.590416308372255, 55.05552914834792, 5.682735298910449, 0.2386309032238299, 2.7276667183445347, 3.074599869789616, 10.222190887697282, 13.626845459784231, 13.08209982610518, 12.495999663106858, 14.088904588453232, 4.078330719663251, 4.287456052918588, 2.9211945014615215, 15.475098644533466, 33.730183032251176, 51.60351391761534, 60.02039863217262, 58.654719552686146, 55.67627560707831, 58.95962499803113, 50.774262105264974, 51.436856331363806, 51.735462450212054, 49.60860821508592, 53.4199910010061, 52.71322696439682, 51.526392275287265, 54.155364805652255, 51.58825197527486, 51.755784250074825, 50.38710455740652, 48.25700652214789, 44.74431222484958, 45.379626366399954, 43.19579185978059, 43.840962917574, 45.76491686605638, 43.48594919327767, 43.827007124500895, 46.50996323554747, 50.35612960015574, 51.21543069039622, 48.680685258680775, 48.497604708517756, 44.4587597539348, 45.41835977185158, 41.938150544320386, 42.287104206700484, 41.64445523292788, 42.6642636329897, 44.30515189324656, 42.609330838726414, 44.70134658198203, 47.124928120643865, 48.256516225876354, 49.47773048954625, 51.796145439147956, 54.25325539804275, 56.71692748223582, 51.59029553013464, 48.112447569447184, 53.78960770945395, 51.738510131835945, 53.84152027868456, 53.004666912940245, 54.87872831283077, 53.35661726613199, 53.29388679996614, 53.24402170796549, 50.66692252312937, 48.12420291285361, 43.37083155109037, 40.53440878468175, 41.052306775123846, 40.08544252764794, 38.64614840476744, 39.99645179317844, 40.19235064906459, 44.332114265811065, 52.86192401762932, 55.206638459236395, 54.116823596339074, 52.43615858016476, 52.742856548678496, 40.64436066535212, 39.35511289104339, 39.33583836401663, 43.352996533916844, 50.747676280237016, 51.30704156814083, 52.32096641294418, 52.20811982308665, 51.89269850330969, 52.63778801887266, 50.364499938103464, 46.47039828761932, 43.362480824993504, 40.11054177438059, 44.857080367303666, 46.729000153080115, 43.66707640309488, 42.567592897722804, 41.84042469147713, 45.423482387296616, 49.60752956328854, 49.90887349651706, 53.56653859538417, 44.20060503867365, 21.64954766150444, 5.863625695628505, 3.449214903577682, 7.404665610482616, 11.085065257164741, 11.823186682116601, 18.828153456411055, 12.746083121145926, 18.91617928781817, 8.697389095060288, 1.0491874429487413, 0.21594396011242944, 3.1316904579439475, 44.30247683678904, 36.056972242170765, 42.84974467369818, 42.60842869358678, 5.985080907421728, 0.14908290107644376, 0.25129424468163525, 0.19049831906393652, 0.12471794961921631, 0.18961796146487037, 0.19334715490619983, 0.1402840595091543, 0.137365999962053, 0.1473380132548271, 0.12548478064878335, 0.1701988736467977, 0.1477648314809607, 0.1370389263836607, 0.2141781887339969, 0.18457371681447954, 0.1545118137953743, 0.1584541482189971, 0.13058947729727916, 0.1314916684021873, 0.08387567265139473], [0.01831904301540025, 0.03097996363536485, 0.0669774277916839, 0.0333840049983513, 0.05785036734455536, 0.057271806252819885, 0.03849429791913398, 0.0629574848308919, 0.050284536630516095, 0.0358698990256075, 0.024619876790130814, 0.06458659761495168, 0.031435596343550476, 0.017633930584716222, 0.01718258988412638, 0.01694132389891292, 0.04217717368456145, 0.08065015137676271, 0.024989983442449765, 0.058827746148792014, 0.030624050677063006, 0.13579847681666576, 0.027790195684158997, 0.04953919819766476, 0.03258398703990444, 0.0778747680446794, 0.07868312103974243, 8.023143468364593, 38.644532388256444, 27.893625613181825, 43.58045085783928, 16.569340882762788, 0.06550598739375992, 1.0651089563485117, 2.080179991260652, 1.7973508709861388, 4.600886279536832, 6.31353332150367, 10.779030169210127, 16.94560012509746, 5.133140635105872, 1.9151485951677447, 1.1328556436684825, 3.8781474098082516, 17.572216410790723, 39.74840110348117, 55.94678578838226, 56.20949829778364, 54.017375822990175, 50.511651577488074, 49.94612816841372, 45.10937506152738, 42.75547835134691, 43.432577502342966, 43.96012844577913, 45.80106150719428, 43.951930692118985, 43.619972659695534, 42.24466023906585, 39.845417007323235, 40.655111881994436, 38.6067795753479, 38.95268555610411, 40.70846788344845, 39.09713076006982, 39.961832954037575, 42.290187189655924, 40.46384534528179, 41.252073087999904, 43.111460901075795, 49.550157054778076, 48.53833460038709, 49.1642625101151, 42.585600499183904, 39.94012655750398, 39.49483163895146, 39.06788556806503, 38.1605472103242, 37.81981875819545, 37.89350440425258, 37.969092399843284, 38.93114782148792, 39.82017655526438, 40.04568930595152, 42.47667627949869, 43.96036771035964, 48.25715949458461, 51.03394654489333, 53.960148442176084, 51.21802729945029, 46.15259216677758, 51.78064815459713, 51.04069694395989, 48.524582770562944, 49.58019848792784, 51.66608356660413, 50.926901140520656, 50.024854060142275, 48.1548366238994, 47.866597329416585, 45.70578321333855, 43.0107658140121, 38.01426241474767, 37.22830572435933, 36.06724100728189, 34.811819753339215, 35.44745945161389, 37.4809887332301, 38.79413550899875, 49.06250053836454, 50.63069943458804, 51.11417078202771, 51.07879100307342, 48.37743505354851, 43.241993458040305, 35.328070348308934, 36.64434717547509, 36.71711890928207, 39.34715832433393, 46.134933656261815, 49.3709792629365, 48.15788430552329, 49.2477148579013, 48.33480673451578, 48.710671778648134, 47.70529770082044, 44.39821012558476, 40.1805050911442, 36.657510649773386, 35.78074716752575, 36.442329422120125, 36.22579497675742, 39.89655294725972, 41.508670622302645, 45.50478527622838, 45.99442258957894, 49.29531674231253, 35.996697179732784, 13.611059881025746, 1.547573235246443, 1.8078788802508385, 2.363296180002151, 2.3542499686441114, 6.351927441935386, 4.3470074380597765, 4.480897053595513, 5.796912062552668, 1.6361730810134643, 0.023134083734945427, 0.023874230006889954, 11.350601873090191, 34.448302330509314, 28.69449515496531, 38.31780287527269, 13.80866300675177, 0.22957139257942477, 0.034123302827919685, 0.04894680155801678, 0.09236372000868283, 0.0442497402940306, 0.023555476143355333, 0.009875383750054865, 0.013665922639530995, 0.04714382128910192, 0.024189387087620074, 0.04937278474831293, 0.022941956544415127, 0.033686839554819374, 0.019288050393844326, 0.021008360199630264, 0.012025206496248083, 0.02298664628347803, 0.06979187394702627, 0.07267234922056237, 0.02412641849068384, 0.0581291429097614, 0.020978097811401374, 0.050785584946072874, 0.030767326355881752, 0.052746927080255364, 0.08089192106478638, 0.012895065817921873, 0.02921831189474512, 0.08503788165868291, 0.04513485529910653, 0.07246291610382258, 0.04764368216837606, 0.03676550177436683, 0.02469285049535815, 0.018502415736175833, 0.05633810595158608, 0.05445799212001505, 0.025496367560399157, 0.006927041704916666, 0.02253020535253229, 0.03307877641711985, 0.052392350945381395, 0.04305724017021637, 0.0215824933031634, 0.04662865780354027, 0.1240412335121824, 0.026719842534211856, 0.16513783634910661, 12.467212407819687, 44.480407314915816, 31.124891811801543, 52.32481425808322, 17.435545344506544, 0.0462778048559783, 0.05539001468869467, 0.7851118486254447, 1.1572158913458548, 3.3230871683166874, 5.626172269544294, 6.388390285353507, 17.94366486610905, 10.222607639528091, 4.258081912994385, 2.0289705068834367, 5.382542581327501, 19.016440952977828, 42.26171078220491, 54.633815519271366, 56.86498518913024, 54.556246726743645, 53.13929834673482, 51.72931609615203, 46.879846665167044, 44.06058819063249, 45.78759993276289, 46.522000989606305, 48.261364275409335, 46.79015774880686, 46.97189684837095, 44.8544680687689, 43.33267473405407, 42.341001495238274, 39.93702788506785, 40.528678201860004, 43.49706911271618, 39.444048712330485, 41.08895740201397, 43.4632896607922, 42.26837881149785, 41.895184901452836, 45.48594613229075, 50.97262028724917, 50.19681076849661, 49.610993016150694, 44.33995116141535, 41.183502212647475, 41.197716882151944, 41.156677123039, 40.49385147710001, 39.50341378488849, 40.33713317686512, 40.22607518780617, 41.42529672191989, 40.28978232414492, 42.005364279593195, 43.54485534852551, 46.56570403806625, 49.73415936193159, 53.347356550155155, 55.7569940628544, 52.241656088059955, 48.332229737312566, 51.995182191171956, 51.87906042222054, 50.118841894211315, 51.67872144329933, 54.01517929569368, 52.75499236199164, 52.71078332777947, 50.203137551584554, 50.145262979692035, 46.46873128029608, 44.58358526229859, 38.886797581949544, 39.36941777506183, 37.32239946242302, 36.91362573254493, 37.9096959483239, 37.72226941200995, 40.545489480418546, 49.24673034298805, 53.07382614381852, 53.75502809401482, 53.08347517444242, 50.44021737190985, 43.62662499950778, 36.9016585811492, 39.338172174269154, 38.21878264027257, 40.141399060526204, 49.17726124486616, 50.758855035228116, 49.15236596138247, 49.39365448490266, 50.711041342827585, 51.1074282277015, 50.102383628968276, 44.5262009866776, 40.580559392129224, 36.80287761072959, 37.73835897445679, 38.89937662309216, 38.38096872452767, 40.871214866638184, 44.15238734214537, 46.83822247289842, 47.52742998061642, 50.629812978929095, 36.91686168793709, 14.769497590680277, 3.2012107920262123, 3.13898116350174, 4.390899740880536, 6.250040934931848, 7.318609789494546, 6.972712143774956, 8.179066017750772, 7.133270934704812, 0.5269754581874417, 0.1447654133963008, 0.08183437009011546, 11.993385188041195, 40.9232254951231, 29.23013794806696, 43.54063095584993, 19.358089200911984, 0.4960138615100615, 0.011624484097645169, 0.038856921807652524, 0.06408329700089752, 0.06099934877467252, 0.034437230337531335, 0.0631174669721194, 0.06663389098379882, 0.0319355970338708, 0.03334608747653904, 0.04996896203186724, 0.022632977962794325, 0.023452586704684843, 0.03560558720041187, 0.056322328370785525, 0.04135172160702848, 0.0372847140346083, 0.0035744204585846035, 0.02833757316693664, 0.01924604962339565, 0.03672288813357873, 0.09863441013881276, 0.16210667158086456, 0.12074144001329139, 0.24252367175875172, 0.17606016639019215, 0.1375935280755643, 0.17472593233950678, 0.2555173656512653, 0.13039634653156804, 0.1191373821347952, 0.121093196944604, 0.17685928802576759, 0.20525763111729778, 0.11466500679812125, 0.19255523449711262, 0.17328250011609447, 0.13107744466152885, 0.27751087661712404, 0.1434330639219092, 0.17974639762072794, 0.17123251011775387, 0.23811299714349934, 0.1537740711242922, 0.1863608620459995, 0.1711852271710673, 0.11820244843200331, 0.24784645065665248, 13.330354479051406, 52.04713006173411, 38.73740234682637, 54.72649720407302, 23.877865768248036, 0.21484280065182718, 4.12370200118711, 6.091819386328421, 5.4652540914474, 11.142226938278446, 15.941705761417268, 23.54035365966059, 22.995897300781746, 11.844828359542355, 5.819895680873625, 2.232413551499767, 5.732672464463019, 18.86983452304717, 43.615155989123934, 56.751820887288744, 61.27477653564946, 56.99532162758612, 55.41001335267098, 55.46409891497705, 51.32997174416819, 45.7259088946927, 48.17124782070037, 47.63835853145969, 49.89332129878383, 49.27533226628458, 47.92921796921761, 46.724238395690925, 43.719412588304095, 45.38052066679924, 41.79378771012829, 43.31964854271182, 45.89905800357942, 42.27388974158995, 44.16953202216856, 45.730603971788966, 44.01912089317076, 44.413589739030414, 46.16452401684177, 54.091740039087114, 52.74442549674742, 54.05177108703121, 46.90044695331205, 43.90677636669528, 43.77673018363215, 43.55353555371685, 42.623216029136415, 42.252481445189446, 43.48193660859139, 41.66019962679955, 44.32466960722401, 43.70773961467128, 44.06491456493255, 45.223610170425914, 49.63298574570687, 51.836585075624534, 56.87359086928829, 57.685745070057536, 54.48296116244409, 49.30020009317706, 55.31530380249024, 53.52090181842927, 51.4355109583947, 53.45559827743038, 55.88473389225622, 54.77506006917646, 53.626240991776996, 52.678251189570275, 51.672261299625525, 49.704835722523356, 47.75646894208847, 41.939048767089844, 41.79336017177951, 40.049721502488666, 37.510320217378684, 38.83354356212001, 40.113193296617084, 43.86734085698282, 51.15236682276572, 55.917120902769035, 54.08685276585241, 54.99445784476496, 52.82876037782239, 46.65245902153754, 39.353661614079634, 40.20696540032664, 41.44517921632336, 42.71800402672061, 48.44196980999362, 53.79203173422045, 50.28745282080866, 50.97378523119035, 51.652614147432395, 53.28596361221806, 51.731179221983886, 48.46787706498177, 44.1640720828887, 40.08947080181491, 38.535227698664514, 41.39404327638688, 40.85374855226086, 43.797875681231105, 45.98803697093841, 47.928813965089866, 49.51322793960572, 52.28306062759892, 39.07001933743877, 15.320494501821457, 3.1968101378410094, 5.359532977304151, 6.490131174364398, 7.8751857819095745, 12.164158321196034, 12.570004001740488, 11.036439634138539, 13.112417786352097, 4.898855503528349, 0.27145832236255374, 0.23594947291478036, 16.082344305130743, 46.95033165716356, 38.50691995313091, 48.32553032905825, 25.23240923881531, 0.7088744556230884, 0.14702777828901045, 0.12119813566847194, 0.16047130368890303, 0.10449845313785538, 0.15041328936574921, 0.12466555686607478, 0.18033381851930774, 0.18654689883753178, 0.16062755498193926, 0.14874536273700578, 0.19992651718278087, 0.16747092647898584, 0.08441626259516324, 0.18397425301373008, 0.11318836466319139, 0.14176800246200255, 0.19406920809659267, 0.1419140188203704, 0.1265221709505685, 0.19403249716326115], [0.05996379708390563, 0.032174313861516216, 0.011216867865333635, 0.13224130075785423, 0.04498708076895245, 0.02011561687404831, 0.0864289977377461, 0.01910574062006368, 0.032701723262547486, 0.07955832286707817, 0.06320856248719559, 0.019549740283119104, 0.0189699572811444, 0.03853680047717306, 0.027205371823642525, 0.06578295882190428, 0.04725948907434941, 0.011123177227413943, 0.02230013957277181, 0.00861848627532562, 0.03624525146498796, 0.04235261931054054, 0.0740568692825975, 0.04822829535471336, 0.035169177553466255, 0.05471745077821036, 0.02221957010577523, 0.9852572218064339, 32.0421596496336, 33.32423733126733, 37.578832257178526, 37.67135704717329, 2.6033670527319757, 0.17866400731427057, 0.06369941417248019, 0.32127870547194637, 2.2174634375879845, 3.362208888415368, 2.486935171388811, 9.99853047632402, 9.347889673325325, 2.410174632264722, 1.7400516617682673, 0.7652270253146849, 7.116473384441869, 27.289170718962147, 54.10169501458445, 57.814822427688114, 53.18117357069447, 53.96156049543812, 48.895509550648356, 47.91177126669115, 43.01801043172037, 43.53581428527833, 42.36887385768276, 41.58960088606804, 38.35675985582414, 39.57304762255761, 39.74180367685134, 40.80479345014019, 43.71732588737242, 45.323877719140825, 44.898159350118334, 46.011292703690074, 41.25398328227382, 38.46538989774643, 40.51265531970609, 39.79696789095479, 39.53282371644051, 46.94675053319624, 50.64618495202834, 51.936295647774976, 49.77751724181637, 46.296472549438484, 39.88874350824664, 38.92254606370003, 39.43047731153427, 39.22907537029636, 39.69479014796596, 36.350847982591205, 39.15183997923328, 39.1378959532707, 41.26192215950259, 41.348610462680945, 43.519257960780976, 44.872914975689305, 48.45756123142858, 52.85937055464714, 52.78751273309031, 52.85969611137144, 44.600769166023504, 52.271928941049886, 51.3982915878296, 51.63999980495822, 50.145925860251154, 51.358632503017304, 50.26759386062623, 50.07014566852201, 47.98594328664964, 48.54055858427479, 46.02034945641795, 42.56384703420824, 38.05472950781546, 36.52835484473936, 35.342363465216856, 36.957877912829005, 36.824576162522845, 37.03088498884632, 38.55151337961997, 46.67563238451558, 49.48606552616243, 48.40565650693832, 50.78632339354485, 50.15730465612104, 48.25634756395894, 41.63540240257017, 35.372852048566266, 36.2726947569078, 35.61161456569549, 40.020358639378706, 48.44202472317604, 50.40948952397993, 47.6098075989754, 51.125933970174486, 48.274253183795565, 49.23966223193754, 47.8795882194273, 45.83402510612242, 45.381869962138516, 39.592416286468506, 35.550080422432195, 37.944291253243726, 39.26782838759884, 43.19609780465403, 46.19128242615731, 48.13276152456961, 47.578605144254624, 29.818034556604204, 6.84486395889713, 0.8758295291373808, 1.2901157212834204, 2.087922259684532, 3.8498695723472105, 5.425307693019991, 7.504559553438618, 7.2744380177990084, 5.649073518091633, 0.7722474550527911, 0.11073660751384114, 0.6664998649108795, 30.236812291606782, 58.6187945642779, 31.221637072101718, 32.17225878469406, 4.790906973423497, 0.05457587006892409, 0.10404562622669244, 0.009697978854209427, 0.09589618973193631, 0.058498872263777646, 0.032370945649041284, 0.014917592521786932, 0.07484049295946475, 0.09504579383158877, 0.042937753436666344, 0.05705146787447795, 0.015604219891341224, 0.0806834225753142, 0.04334208698222234, 0.03797431574052861, 0.07181466016317568, 0.02044606315452726, 0.021880526403566043, 0.05425936850388685, 0.010360154612440496, 0.03859613015646896, 0.03108375514256618, 0.04415892057060715, 0.07769603973194476, 0.12183328384473441, 0.017979867163024122, 0.019119614472372398, 0.026258092613950856, 0.011487229869911268, 0.018910658245365468, 0.05919915323536243, 0.05418910291947184, 0.04457514380074797, 0.026079052120387077, 0.016221856255264535, 0.019888050456140793, 0.031201960594062845, 0.06852778290668804, 0.015567056966134378, 0.05905372293425664, 0.04737553224267979, 0.027853152789776365, 0.007562132903389754, 0.07499497458939591, 0.047545619083628546, 0.03309898964700199, 0.020626741161029187, 0.036308262196760026, 2.2288012937191994, 39.85603878574987, 34.58864081290461, 40.45412571199479, 40.75231605960477, 1.5085977460107498, 0.15470701299848097, 0.15309240608926744, 0.28507142898536497, 2.3188787698745728, 5.400380049982379, 9.70425465414601, 11.566919607500877, 9.390148308969314, 5.80579819217805, 2.0581411738549513, 1.7414389550685885, 9.233210356004777, 29.40544632173354, 55.00759778484222, 58.13753935598559, 54.8398184007214, 53.97080944430444, 49.29284564910397, 47.82811887802617, 42.60258043965986, 45.08030245381017, 43.92818858546596, 43.219247633411044, 41.92322200344455, 41.409195392362534, 40.772637859467544, 42.80107590460008, 44.53874864885884, 45.37018129902501, 46.24424226822392, 46.531089121295565, 41.7287116665994, 40.98052347860029, 41.946889585064305, 43.105679327441806, 42.02647055349043, 47.02867315661523, 52.06459245374126, 52.28884220123292, 51.56620433253627, 47.45297555000552, 42.54429794126942, 40.931701737065474, 41.522634260116085, 40.23969757941462, 41.503183226431574, 38.43362262172084, 40.17704948302239, 42.872592479951926, 43.930761660299, 42.513483801195704, 43.960807015818936, 46.83242520978374, 49.638853611484656, 52.94085387260684, 55.22989419198806, 53.22315862101894, 44.869510358379735, 52.2140347573065, 52.21633326622748, 52.53400994885353, 52.74738296385735, 53.04747958337107, 51.65390460721908, 53.75831896258939, 50.58934196349114, 51.28879077972905, 49.1589359314211, 44.715149402618415, 41.036103463942005, 39.036820396300286, 37.59021889778876, 37.815998369647616, 38.47921625260384, 38.898741199124245, 41.95374981049569, 48.41955738682901, 51.5309069233556, 50.45069402264011, 52.99972472652313, 52.8379818700975, 50.30394246501308, 42.59146052022135, 35.871114653925744, 37.81243293516098, 37.43708564389137, 43.1075071519421, 50.336203959680375, 52.34417899962395, 49.012533464739406, 51.25556045962919, 50.21677955504387, 51.29423110715805, 50.57495078732891, 47.527524117500555, 45.6069943981786, 40.043414331251576, 37.49065737570486, 40.276320749713534, 41.155088563119214, 44.76417118503202, 47.494485993539136, 48.583288884931996, 49.09019639415126, 31.46983288949536, 8.185897315702132, 1.3367305167259709, 3.733293053603942, 4.159178368506893, 4.210694288053821, 9.831833666370763, 8.298178103662307, 7.239906941690753, 3.385285908176053, 0.4793506830690369, 0.020213226051700693, 0.4335309949613387, 31.484796731702744, 52.827740561577585, 33.428270355347664, 37.62930139418572, 8.185612943864639, 0.05433354879759493, 0.04134350914448019, 0.024986378998766025, 0.015715204006541642, 0.030770206846477046, 0.006570413890820478, 0.034971220433832176, 0.04413576556309577, 0.0563520870562042, 0.020620786742637717, 0.06180199441469966, 0.0684392384643997, 0.03652112355696098, 0.09051112788579158, 0.03663956075005474, 0.06688732053003003, 0.07562028619671061, 0.049871764626474156, 0.041102490222622315, 0.038277180940513654, 0.04936901942616509, 0.13634177105080697, 0.21008475112818906, 0.18041376745508564, 0.31104346436838953, 0.10360959196282972, 0.12118786242940735, 0.2158163605077613, 0.10726341767416847, 0.08908078044412598, 0.18786464667608663, 0.18985572451305008, 0.14622997432466478, 0.08739400039156599, 0.1221691597733767, 0.11418309918935261, 0.19441293642645885, 0.11028152064330156, 0.16667215724385556, 0.11961683060132688, 0.17577118270339506, 0.13552657689058012, 0.0573314423672855, 0.3233409222335585, 0.17036722912903757, 0.09461930502326259, 0.18554923785549982, 0.09644932053502529, 2.4886036496008597, 45.17966785738545, 44.615352538324174, 48.47636115166449, 46.48837843248921, 3.747844311498827, 0.9720404890756454, 0.4262943445674835, 0.672672449821426, 8.34951114269995, 10.407217914058316, 11.139430288345585, 19.104635446302353, 19.670052951382054, 5.7162176312938815, 2.87798150412498, 1.449008608056653, 9.006787615437663, 31.11081050288293, 56.76799674187937, 60.701357395418235, 56.97197960269067, 57.29374339503627, 51.77989505952405, 51.61554774930401, 47.67985328551262, 47.91333629238991, 47.542068266099506, 45.39691225174935, 42.6980705415049, 41.03214187006797, 42.77361146865353, 46.408220875647764, 48.01240751820226, 48.64861203778175, 49.30312618132561, 49.36812377745106, 45.5842956419914, 42.33769493718302, 45.62317025276923, 45.41291944442257, 43.237361138866795, 49.85207757642193, 55.244273601039765, 54.54694678706508, 54.33757458963702, 50.08486632377871, 43.61996089258502, 43.66284024330878, 43.60564031908589, 42.74812390727382, 43.280632726607784, 39.73209188830468, 43.32006039157991, 44.56926861116963, 45.678118736513206, 45.05350089842274, 47.62512053212812, 48.69698662911692, 51.94514843725389, 54.659279546430035, 55.62803045395882, 55.05999672797419, 47.72297190081689, 54.10372680233371, 53.496940059046594, 54.96079606394614, 55.45790941484513, 54.36834950600901, 54.475520426227206, 55.81978728694301, 53.98545557452787, 52.85666019685807, 50.0902242814341, 47.82534968468451, 41.652884406428186, 41.005881601764315, 39.68656886008478, 40.48486140466506, 40.04700722232942, 39.70814581840269, 42.56323122209118, 50.19304921550136, 52.512731090668716, 50.89127032987533, 54.92055646834835, 53.42607851951353, 51.93905307400612, 44.71274891207295, 38.04586495122602, 39.335779528464045, 38.876454291805146, 43.94628640144102, 52.22163238833028, 56.49955364965624, 51.004744498960434, 53.34381857225972, 52.60914294950424, 52.15368909220542, 53.09711325553156, 50.2195526707557, 48.334873414808705, 43.604691105504195, 40.21375502309492, 41.75825495873728, 42.74484872817994, 48.52809721423734, 50.726974010467536, 50.890944773151034, 51.800801292542495, 32.28614676383234, 8.848391521361567, 1.8788701031477222, 5.1649133043904465, 6.863308414336174, 9.61154257097552, 12.01795099243041, 16.350138245090363, 16.45620011514233, 12.941999627697854, 2.552098977950312, 0.20846332603644943, 1.0885974572550867, 39.90679425577964, 65.13659315724527, 36.99621515889322, 44.64764148958268, 9.675109482580616, 0.23478010098540017, 0.15656833086282979, 0.046924647364404895, 0.14673968326420556, 0.1911563273038595, 0.0974309319750436, 0.1562476004924505, 0.20951066015949174, 0.3657620298045297, 0.18055592273031512, 0.2512553580585988, 0.15411942356055783, 0.17228810266861994, 0.21631735136672375, 0.11341996070358062, 0.23295966157269096, 0.11620882718313126, 0.16874773457886713, 0.15493235010052883, 0.11766726706898022, 0.11061726633699671], [0.036683622297019734, 0.05440304446364603, 0.036511248683617, 0.04172811209554634, 0.005424451214381524, 0.03080807648779404, 0.006296331571760558, 0.021302028514084317, 0.06448444745112812, 0.07983996743156065, 0.05855962686661271, 0.02602484373886499, 0.02361623840706964, 0.04735801564229112, 0.07960328456735419, 0.06764706524629747, 0.0880922818736684, 0.07078307680785656, 0.03746697784311349, 0.003845164070709519, 0.051036329354129495, 0.022133222420609767, 0.04252098628409928, 0.017767203070463675, 0.02701090614972336, 0.02878415454629689, 0.09428150621393035, 0.05070733672548687, 15.601378371638638, 38.78536116692328, 24.458833509875884, 44.57980801982265, 16.957251525694325, 0.08743235075305547, 0.19314593425200832, 0.1631200067218273, 2.851442992687226, 2.3162706388581187, 6.4818642889299705, 6.057233887334024, 9.246315975343029, 7.853986351720749, 1.3254633858319254, 1.1081162743991422, 1.9301984843707856, 13.318404978321446, 43.98619259557417, 57.235068659628595, 55.09985193129509, 54.645586552158484, 53.1771021504556, 46.442361185627604, 46.24209280936949, 43.930126236331084, 40.88952449060256, 41.27682324378721, 40.74481256546513, 43.46139907836915, 46.85060147316226, 50.37244273770241, 50.29057502746583, 53.378256982372655, 53.29949186694238, 52.92362290043985, 51.42101387823782, 43.05542984316426, 39.13577787337765, 40.41299966073806, 40.831332206726074, 47.231400858971384, 54.28750161201724, 53.08572661492133, 51.97728441607568, 48.19122052961781, 41.14065031851492, 39.74790688483946, 39.92324467628233, 36.6852221950408, 38.56938762049521, 38.60290427361765, 38.12424567437942, 39.13642898682625, 42.65214350915725, 42.50677262583087, 42.670798301696784, 45.13225032437233, 48.37918443064536, 50.06215972285117, 53.442419113651404, 53.001348587774466, 47.868201578817065, 50.75974149088706, 50.797113833888886, 51.841131102654245, 51.94634083778628, 50.38020903064359, 49.94663415416595, 49.850936166701786, 48.103320214056204, 48.62386972673478, 45.88633383474043, 42.624890881199995, 40.648910614752005, 35.480960415255645, 36.72159433364868, 37.00825291295206, 35.421826762537805, 37.655334165019376, 36.66143694231587, 44.01447680688674, 50.27960808046403, 50.16161926331059, 46.85655563108383, 50.54368557468538, 50.932215952104144, 49.905763056970414, 44.28528508832378, 38.64621900743054, 36.25360850364932, 34.11432427744712, 40.57571134259624, 47.90367157228532, 47.37504589942194, 48.66343467466293, 47.085316104273645, 49.59953577287736, 50.35459595341837, 47.1476347215714, 46.759096499412294, 46.523652307448856, 38.963978059830204, 40.404397902950166, 41.859173620900805, 45.10629600094211, 46.14845406624579, 47.616201062356275, 42.42441461932275, 20.636793644197528, 2.8072141014760543, 0.7494375241860267, 3.748824413745634, 3.581957716134287, 5.233930839646248, 8.237600038128516, 4.916666986480837, 6.5467648063936545, 3.0233313047116805, 0.08346242184240012, 0.03765536269413368, 6.236179769039155, 42.32775957353654, 32.69859771574698, 30.187521826836374, 21.673811443390388, 0.5012643523514271, 0.07005851850995133, 0.03704608147663455, 0.06702736140258851, 0.014299065580651646, 0.029819271482166745, 0.028105289562635367, 0.02990477264017588, 0.04142846446484327, 0.014114707479283456, 0.09971359819774667, 0.04070213650383296, 0.05582137198577966, 0.05493258741954642, 0.13293818029905521, 0.09716883031350952, 0.01370042245159106, 0.0753867979191484, 0.03520278966114406, 0.031770279090250694, 0.0600089464757231, 0.007377451129873554, 0.03200046361363944, 0.04224186214888769, 0.06609468765917324, 0.04163901990039214, 0.11125907947820042, 0.026875199419596506, 0.05894842797950391, 0.048528647786306764, 0.08773824200034143, 0.10531642819724737, 0.03818670978709575, 0.03289257491668386, 0.07143315603776325, 0.04519969315057801, 0.030272247780474926, 0.05321163984556353, 0.03109462593021172, 0.022453722964611747, 0.09907483408648161, 0.027157623478541934, 0.013132124065211224, 0.04244277636790949, 0.005776848307915874, 0.04420749820588578, 0.040951513444944736, 0.027881758512869, 0.042451563396400986, 0.07867320786200224, 20.86995501672068, 43.14824881092195, 28.16523798050419, 55.414441708595525, 14.868483504941388, 0.028949562505248095, 0.10027807476299425, 0.339285510201608, 0.9230171131991571, 4.391742069875041, 9.125726626765344, 5.795348017446457, 6.501534975344136, 7.262526269881957, 4.036364545745235, 2.1398009984723987, 2.921501426927505, 15.113745389446137, 45.7426142692566, 58.72490252217939, 56.0190240798458, 56.5369769834703, 55.135216020768695, 49.140453723169145, 47.4407926682503, 46.65808762273481, 42.58148985524332, 42.5572652970591, 42.110303371183335, 44.12287935133904, 47.01441534103886, 51.58053275077574, 51.90823108919206, 55.0375097797763, 55.40995843948857, 53.668637890969556, 53.370553447354226, 43.85965693381525, 40.98908209031628, 41.80504099015267, 42.20242807942052, 50.377761471656065, 54.80658023588119, 54.78818824214321, 53.44186998182728, 49.46178213242562, 43.727155347024244, 40.72423973391133, 42.310246190717145, 38.42432660441245, 40.377635571264456, 40.54063358614522, 39.908563244727354, 41.13504525153868, 44.42607464328889, 44.45538651558661, 45.591512803108465, 46.81358606584611, 47.853959452721384, 51.89615411143149, 53.43823786704771, 54.88541595397457, 48.13786060579362, 51.93716249158306, 53.05976052438059, 53.69143078404089, 53.699981551016535, 51.79758494900119, 52.27902843106178, 51.99855935189032, 50.54982016163488, 50.44391616698235, 47.13255713062902, 43.8424926419412, 42.585047444989605, 39.46193864268642, 37.06163637099728, 38.26507837541642, 37.977113646845666, 39.02553965968471, 39.740207272191206, 46.32591385995188, 52.65135157492853, 50.38769291293237, 47.93110462927049, 52.01918709662653, 51.599575857962336, 50.11819078076271, 45.32982403232206, 39.272562688396825, 36.607739694656864, 37.44156891299833, 44.23095241669686, 49.23940727787633, 50.74472665786744, 50.337702305086204, 48.764584756666615, 49.40508819395497, 50.59438613153274, 47.96503313126103, 49.26824846575337, 47.44033375094014, 40.288480097247714, 41.3315716866524, 43.49279372922836, 47.49054401151596, 48.5034921861464, 49.402577877044685, 43.81553419174687, 22.461878368931433, 3.8184352074899985, 1.5232050202546583, 4.555529952049255, 4.402130957572691, 8.038503469959382, 11.030620797987908, 7.421304304753581, 4.149836753645252, 0.9178716376904519, 0.06199119514935921, 0.06688361266447652, 5.67645215219067, 49.986650174663914, 44.56123559705673, 31.95949373706695, 27.46857208590354, 0.8366036210809985, 0.0371976443115742, 0.061811647122545596, 0.052817993226551244, 0.016884600833779382, 0.045784379115268115, 0.022547162708736235, 0.05460089050053109, 0.022054439853696574, 0.0416086751577114, 0.03487884172148282, 0.023220496537584453, 0.006035474803103435, 0.12786019713647906, 0.03701239659060394, 0.044814603733679945, 0.06037964110052394, 0.08208922455988585, 0.012329864341975942, 0.09693742579510135, 0.0265437763770141, 0.021680516168294896, 0.1685473719431508, 0.17711062615196552, 0.14541117955119381, 0.09383571198991231, 0.22137302604894485, 0.15200321292204244, 0.14901095009859533, 0.19750669057811462, 0.1431917921910363, 0.1541785502265538, 0.16994640171047182, 0.19182090857817283, 0.17999712287658648, 0.19076620468929892, 0.3172931177241187, 0.16431737150396072, 0.20045378485754614, 0.20222707921939514, 0.17847452312707904, 0.11838654702108715, 0.11968993071106174, 0.1367874350398779, 0.11928377387624596, 0.12970057015697803, 0.18408509061461498, 0.2200798083457255, 0.1194677115868657, 0.12301487487650688, 22.86893802304422, 52.31457687193348, 33.73005359403549, 57.17295792794997, 22.66726347707933, 0.18926202169349118, 0.6459865430670401, 1.486235210491765, 7.14894570650593, 11.396859365124858, 16.13684661926762, 12.830755326055712, 17.98023900678081, 17.174099760670817, 5.1696549596325045, 2.1552330736191045, 2.871775088771697, 15.552781185796185, 46.971657583790446, 60.999406537702015, 58.895474633862904, 58.61217360342703, 57.57423208605859, 50.917718871947265, 50.22139618473668, 48.480063869107155, 45.5992437947181, 45.44884835520099, 44.84434050898398, 47.66481099590179, 50.15518657622799, 54.65714969942647, 54.814240624827725, 59.19135862781156, 58.69802251938851, 56.235907616153845, 56.624363468539336, 47.05544725541146, 42.66035695229807, 44.06851922312091, 44.00710275096279, 51.83894242009809, 58.811041693533625, 57.13903727069978, 54.1097358734377, 51.67274767352689, 46.41246488017421, 42.78790458556145, 44.74686568783176, 40.53435387149934, 42.89834676250335, 42.31075609883955, 41.371677921664336, 42.50367395339474, 46.768329758797925, 46.755727183434274, 47.55488264945246, 49.32683690901726, 50.37248196140413, 52.762221290219216, 55.29291491354666, 55.83991689066733, 50.29513674397623, 51.582372342386556, 54.32479942998579, 55.71518944155786, 55.31670408864176, 54.49111184766216, 55.107261288550596, 54.22423770350795, 51.65597954104024, 53.23560822394587, 48.74813433616392, 46.41343370560677, 46.28248929977418, 39.05244319669662, 39.91722383806783, 39.69807317180019, 39.27765392488049, 41.01157688325451, 40.6981598946356, 47.87129632888302, 53.07123345713462, 52.301201589645885, 49.50515177942092, 54.516705313036525, 53.81251042889011, 52.585522436326556, 48.334747898963194, 42.898574259973344, 39.48592393629013, 37.22368909466652, 45.048484186972345, 51.49573895239061, 52.728222185565585, 51.95762157440186, 51.4649679583888, 52.44405431132163, 52.833765322162265, 49.85959676004226, 51.564117631604596, 48.21568043001237, 43.37677001953126, 44.64826514644008, 47.39888606532928, 49.13466822716498, 51.950682901567035, 51.909800037260986, 44.41171092371787, 22.31044154013357, 3.4741067549874707, 2.2289760843400033, 9.115586319277364, 7.192504607862042, 13.81866014772846, 15.93361096997415, 8.863679939700711, 15.71354344967873, 7.777397661439835, 0.4440923443725033, 0.1871356833726168, 9.659420982483896, 53.7134039017462, 40.00998004790276, 38.82575373495779, 32.81025974981247, 1.1533724588732566, 0.18524148501455787, 0.2179484444880678, 0.200190955412484, 0.15144263574432942, 0.1294160144583833, 0.11458088268315601, 0.15599469954688705, 0.10456346335910982, 0.12443379994722144, 0.23752246592794699, 0.12190498967444706, 0.10880353019362497, 0.22056616692533418, 0.2661701093517965, 0.24521778848382736, 0.179792148391566, 0.13100996763715822, 0.10316957404176075, 0.2520794388387473, 0.17608088140766467, 0.07510350626562873], [0.0100031404027475, 0.012051244867184471, 0.08758685536562436, 0.0376151698911863, 0.03969627838101118, 0.05526921411435451, 0.07719405295868075, 0.018220533684436834, 0.004939026783235492, 0.0499091420562998, 0.04012930958021072, 0.0141481117856118, 0.022577582144989602, 0.05545760662625394, 0.032968321860197096, 0.04130806991710298, 0.07000072483694361, 0.041746777827821435, 0.06121797494650368, 0.04167810570628893, 0.02845003487422101, 0.021833967409967896, 0.10380739586487894, 0.04676322880831938, 0.06809255303514582, 0.05594312633958556, 0.06361176222262364, 0.03766545973297569, 1.4668144526020175, 29.63110616130214, 27.962010175951068, 31.686392830264186, 40.72924860062138, 2.014165398093962, 0.15934227394961542, 0.06205411012014074, 0.33362914597795856, 3.356523903146867, 6.365766054199589, 4.565638880575857, 5.238728388663262, 4.477180117560971, 3.04373596464434, 2.2554096723756483, 0.6661620507797887, 3.2978396069618965, 27.364172320212088, 56.579970082929066, 56.972905282051336, 55.796053025030325, 52.20602135504446, 51.89426352900844, 46.49139081278155, 42.03753555974653, 42.908682207907404, 47.124269162454915, 50.253818496581054, 53.296675605158654, 53.99697557572396, 52.901618403773156, 52.76460216891382, 54.1953847485204, 55.36410200980402, 54.41181328988845, 52.73268976519185, 46.20188851510325, 39.41275212072557, 38.80000337477654, 40.032219886779785, 49.83197935165898, 55.015018909208244, 53.48290189619988, 53.11240265446325, 50.73164163097259, 45.800873233426, 39.75056625181629, 40.786919209264944, 39.364557958418324, 38.4366742257149, 39.43430946719262, 38.058942133380526, 40.32234191894531, 42.638995724339644, 44.899853814032774, 45.78185366046044, 45.00483605169481, 48.361627901754076, 51.32700643231792, 54.128676998999815, 51.58714194451609, 43.910337878811745, 50.68449081913118, 54.68870124509258, 51.09217805247153, 48.462271998005534, 48.6232578369879, 50.22322008686681, 51.19230439586025, 49.789649132759344, 46.37191149496263, 47.452877490751206, 43.39425594575944, 38.108666020054976, 36.05514049530029, 37.24730568547403, 37.622782414959325, 37.49934150326637, 37.44795453163886, 36.24284944226665, 42.61346893925821, 49.13038892130698, 50.24287900617046, 50.398420595353656, 48.662124603025376, 51.09285662251135, 49.95131354178152, 50.22354172122095, 48.99216459643457, 44.14467596238659, 38.45872186845349, 35.30970973353232, 38.819866257329146, 44.49726566191643, 48.971211294974054, 47.5698386469195, 47.71529974475984, 48.99523581227949, 51.37120762178975, 50.097413985959946, 46.419666351810584, 43.14516190559634, 43.588699602311664, 43.27632988652876, 44.69281934922741, 47.497074757852864, 48.79673642496909, 35.61490151189989, 9.975121771135639, 0.42148288339376455, 1.2148526695466813, 3.6742020566617293, 2.7471930125067314, 4.293483264984624, 10.254820104568235, 9.86629561070473, 2.5046853673073555, 0.16939590624984235, 0.10297497238723502, 0.20227462263597598, 18.30427973501144, 40.12740796612155, 16.48448040408473, 36.50468726311961, 8.414997073911852, 0.09362057151813662, 0.04875020807488792, 0.04030654785193263, 0.012922677541932753, 0.02455641789692304, 0.021479331903279792, 0.03548642988466928, 0.02102911352149902, 0.01132467654608791, 0.03762939614394019, 0.05755826184946684, 0.003692070735738643, 0.10510718660248865, 0.013789703295896611, 0.028952739854914047, 0.08265900245356946, 0.06599981533063036, 0.06495197558955801, 0.04602526397173924, 0.010652078161647004, 0.015850486515480426, 0.009410156748227535, 0.02111813293830041, 0.007906688129409187, 0.07578704055518874, 0.06292658084402643, 0.021134912179061965, 0.05825790313763484, 0.05902279213431382, 0.041862242599768985, 0.02291577357438303, 0.06833374049634704, 0.0252092492976977, 0.03306173479124423, 0.024380051050215, 0.05754567119443128, 0.05425559169042015, 0.057419722509239955, 0.01498667928840845, 0.042047972956131545, 0.033343586199466264, 0.04833197386394586, 0.078339415692514, 0.11525310185407439, 0.06171663689817633, 0.010794075431242105, 0.03940936313160966, 0.0890626548038375, 0.03503171456677299, 0.07191147835504624, 2.8939943352053246, 38.98824576408633, 27.698911313087713, 39.620724032002116, 44.55764270597889, 0.9600743182724523, 0.060342976132467877, 0.10246350910634765, 0.3491016399235495, 1.9965980826847016, 7.188972023225601, 5.593875473545444, 5.827488408934686, 5.4909519899276, 4.267311740306116, 3.1374705606891267, 1.4774878347112288, 4.746919553126059, 30.348693978401926, 57.499707052784586, 57.199790862298784, 56.57087018412929, 53.58074934251847, 53.24931298532794, 49.14265417283582, 44.852965800992905, 43.3676387417701, 48.300995903630415, 50.85673778287826, 54.798566833619155, 56.00573508970199, 55.58571200216971, 54.094607291683076, 55.414959461458274, 56.396646345815356, 56.20317935943604, 54.76083755493165, 48.08015077344833, 40.35525452706122, 40.446810491623424, 41.94754069851291, 50.22951156862321, 55.41853274068525, 57.17287948054653, 55.66008798537716, 52.99604946567167, 48.418466967921105, 42.14940547943115, 42.37806789336666, 41.6802978515625, 40.822149938152684, 40.95862488592825, 40.18794582736108, 42.752097268258375, 44.232709638534054, 48.30152542360368, 48.413740511863466, 46.83279391257994, 49.90518646855509, 53.418171021246145, 55.81631206697034, 54.39592769069057, 44.75855827331544, 51.15285319666709, 55.4051927597292, 52.91110661721999, 49.612648256363414, 52.12587164294336, 52.046565240429295, 53.26204107653711, 51.06723962291595, 50.484249899464274, 49.24922889278781, 44.87816702935004, 39.56525779539539, 37.98851989930676, 38.6341812533717, 38.71588422406105, 39.568646723224276, 39.96276647813859, 38.29786546768681, 44.59670951289516, 50.677646283180486, 51.89645613393476, 50.83459208088537, 51.222706687065866, 52.94858486421647, 51.800479658188365, 52.07535151512393, 48.78520073429231, 44.65209337972826, 39.56131581337222, 36.32969071788173, 41.65765400855772, 47.00309930309173, 49.55833127421718, 49.66761635195825, 50.26689175636538, 49.17565307309551, 50.09197758090112, 49.86827304286342, 48.16066134360529, 44.257483328542406, 43.28896384085379, 44.911154162499216, 45.72768572838076, 49.12247750066942, 49.80169473155853, 37.66657175556306, 12.627453977061856, 1.204356897261835, 2.7690857216235134, 4.271921505851131, 3.6252143498389953, 5.149403762432837, 9.315218290975018, 7.184874126988073, 2.0478155343763293, 0.45867712627495494, 0.039589129493481694, 0.12164134051530592, 21.130588669930738, 47.27681406082646, 20.432259690377023, 37.52018497836205, 12.332348573592402, 0.0884168120401521, 0.041496439446364684, 0.06467388567304419, 0.01335692203288237, 0.024055677931755785, 0.02653406046691441, 0.0442599407547424, 0.028669260509852922, 0.008863431397795437, 0.028745547545352773, 0.014845937445399263, 0.04983970384684302, 0.059476304694168994, 0.05363319887809696, 0.06402984321598085, 0.07976994699528141, 0.03007679768357306, 0.05059998099421782, 0.052559001881989746, 0.01828328777675427, 0.02408642678581659, 0.02808647252799523, 0.08540189599678402, 0.11291870171384466, 0.15433244196878326, 0.17564229607101411, 0.1887821288959634, 0.15374741126452723, 0.13614975877346533, 0.11775518331917063, 0.14634626647157056, 0.1259329574062459, 0.09547554617447239, 0.1858975167476362, 0.1343470006700485, 0.13655875779448018, 0.14686829410493374, 0.0873290514573455, 0.18232489635627117, 0.10615121122569808, 0.08818515471272892, 0.18690539734257808, 0.15545192625253432, 0.25195289643541463, 0.24551090904541556, 0.18641952905924092, 0.14223150097795073, 0.19321881985712439, 0.09213469036283994, 0.1386366333932646, 3.5823001880799574, 47.55607897235502, 38.41437162891511, 41.7624322829708, 50.52466992408999, 3.152500838041306, 0.2795279861217545, 0.4350920676464035, 1.023996878535517, 8.956934290547526, 17.633779971830307, 13.697229450748814, 14.62338734057642, 10.507323665003623, 8.387175702279615, 4.8409593585998785, 1.540033214034573, 4.326564044721665, 30.72414129011093, 59.80341703661027, 59.5708244077621, 60.49407582129202, 56.55034049864739, 57.23047948652699, 53.68936761733025, 47.03123054196758, 46.300751855296475, 54.00374950901155, 53.62609586408062, 57.30287075042725, 59.36467247624552, 59.4816061758226, 55.45606197849397, 58.65149928677467, 57.377913536564, 57.36090613949684, 56.67516600701117, 49.949689680530184, 42.23662722495295, 41.300628108363, 43.92954964791575, 53.21965986682523, 58.15755913334509, 58.766079564248365, 57.005959095493445, 54.254808656630985, 51.3807076023471, 45.320916329660726, 44.81581311072073, 43.5545906712932, 43.09503401479414, 44.201256152122255, 42.1774386590527, 44.98377684623965, 46.5087119994625, 50.70196105587868, 51.156657895734234, 49.47106638262349, 53.32190429010699, 57.02178585913874, 58.75421047210694, 56.349864236770145, 46.63512606774607, 51.559198979408514, 58.746714822707645, 52.35686002239105, 51.42027255027525, 54.88412157181771, 54.79500924387286, 56.57924836681735, 53.69963638244137, 50.98896872612738, 50.86387649659188, 47.05574143317438, 42.00496027546544, 39.83686624034759, 40.22608695491668, 40.49614606365081, 41.600720805506555, 41.089459465396025, 40.41174842465309, 46.98283241641137, 52.75119943003501, 54.41990513955393, 52.260271656897764, 51.90996085443805, 55.68957636433264, 53.96410219130978, 53.279719198903734, 52.396366134766616, 48.61330286149056, 42.83758924853417, 38.5528273736277, 42.855283060381495, 48.057769729245095, 51.72044761719243, 51.78225632636778, 53.21705933540098, 51.348144085176536, 52.190563294195364, 52.207641293925626, 50.87751065531085, 46.00201237586237, 47.06729673570203, 46.686375756417554, 48.70206609849007, 52.52339993753741, 51.89975484724968, 37.81189557044737, 11.170757278319329, 1.1238568684747143, 3.659932964271115, 7.627464571306783, 8.960259479861106, 8.074917774046622, 21.616125145266135, 21.129963051888254, 7.929260067401394, 1.6897012990328575, 0.21236700366341302, 0.3800306318988724, 25.74403535935187, 50.191299838404504, 25.080487997301166, 47.692895166335575, 14.784989972268383, 0.23950496358015846, 0.1530166399935561, 0.1566983053400632, 0.1962599437683821, 0.06714473373346752, 0.12345762773146554, 0.1693363352528503, 0.1047095716480286, 0.11161141863633549, 0.15638682931180925, 0.09842170582663629, 0.10469755172849664, 0.16821099805735773, 0.08166491144126461, 0.16589247891979833, 0.16438619684307806, 0.18910747111564685, 0.12363492345978176, 0.15106639464295682, 0.06205818187745829, 0.10637346865429033, 0.17096563572845153], [0.021380608067697576, 0.02687494278014187, 0.07051479281677354, 0.047817082339597326, 0.0213013811697883, 0.02759250669529842, 0.0955246217669018, 0.0476430080110027, 0.048635340851521304, 0.06624052781731853, 0.023880849006555738, 0.07113592158402167, 0.045779717470248865, 0.07696956621422883, 0.05660010802169001, 0.016146306579391805, 0.03358936635777354, 0.12355598576006391, 0.06793496108824207, 0.010691621705078551, 0.0453087036317635, 0.026085276584771853, 0.030876972690044396, 0.042659265154431907, 0.08005416561518947, 0.08364499591651463, 0.02720191676710402, 0.03612777571223917, 0.11305475892919688, 17.05876442693895, 35.265936082409276, 24.852878739756925, 50.71192779848653, 13.205776080008476, 0.06673286188273661, 0.20855904106170903, 0.07760343502365774, 1.019140555252952, 7.073991663994328, 3.5455419411582336, 3.0235053598880772, 3.1767964891849028, 3.979735081234286, 3.0230822342057384, 0.6979987037277992, 0.5849035949476304, 6.927387195248758, 43.337358044039824, 56.98583341413929, 56.777951717376716, 54.398006546881895, 50.62693788159279, 48.77347284747709, 45.38348205627934, 50.78839440499583, 52.88735274345645, 56.59470642766645, 53.10561303169497, 53.44985592749811, 53.02340015288323, 53.24916393526139, 56.42614256951117, 54.7720790678455, 53.49384530898064, 53.60464049923805, 44.89003612149147, 39.70074430588753, 41.160850524902344, 41.50370097929432, 52.097858075172674, 54.807658887678585, 54.02300442418745, 55.28563107213667, 51.91911958879041, 46.518627751258116, 41.685310640642726, 41.40244107092581, 40.28844871828633, 38.66201046974429, 38.47197555726574, 39.0941576034792, 40.560731810908166, 41.56264243587371, 45.537352715769124, 46.02705670941261, 45.54092599499611, 48.71835962418587, 50.24223965983237, 53.1321596330212, 53.467255561582505, 47.57300007727839, 54.551324152177386, 51.101564284293886, 47.275809934062345, 50.12754955599385, 50.46154722090691, 48.28842078485797, 48.92943413026872, 48.93927927940123, 50.22069015810567, 46.461419982294885, 43.764715963794345, 38.153577158527995, 36.47153146805302, 38.374900817871094, 38.98974018712198, 37.263187362301736, 37.75278937432074, 37.75512710694344, 45.63854986621488, 48.92281316941785, 49.636002048369384, 51.50960453094975, 51.21317924991731, 48.717229981576246, 49.834968197730284, 49.085309120916556, 50.922570843850416, 49.75808974235289, 44.89742586689611, 42.763381927244126, 38.91238712495373, 36.78457583150556, 40.61035763832831, 45.2813906054343, 46.73353833536948, 48.650749729525664, 49.15542541011688, 49.0488624572754, 49.43954229354859, 44.682334853756814, 44.048593582645545, 45.04502073411019, 45.790420116916785, 47.89356754672143, 45.44037211325861, 23.35632193473078, 2.6086396988361114, 0.6565255227108157, 1.4601513262717956, 3.229191019650429, 3.000824744662931, 4.474098115198074, 9.76954838921947, 3.810144787834537, 1.3666374861232697, 0.03234007230569278, 0.04736325951413282, 2.0378089551964114, 36.00530678226102, 33.99039306948262, 28.18144717524129, 30.511480185293383, 0.5638242260582986, 0.10061922137655559, 0.06290691536701014, 0.046242959346742406, 0.06761667453834126, 0.05679421554950457, 0.015915748588139975, 0.07372982634772217, 0.07664499008246968, 0.047174357553763736, 0.0014973638556717386, 0.026252431224190423, 0.1344807596216279, 0.05220928274455571, 0.023993678436043765, 0.05169998366205443, 0.005349345869504877, 0.06013302973681881, 0.08569408193110459, 0.05472738693858828, 0.04421570300755482, 0.03880127318083279, 0.04211008736503221, 0.046183644989204985, 0.028541463637544263, 0.03212744268708893, 0.05226249521177623, 0.0007680200219657573, 0.031192644964903597, 0.09742126394543918, 0.07048254817604058, 0.04852663680550553, 0.04064636147250572, 0.010470624491121742, 0.030411737069727916, 0.03188738903601564, 0.039431702255481677, 0.056332796962270816, 0.046556825569320115, 0.049313355477586876, 0.02886361893146269, 0.10486535562743103, 0.06346928902090558, 0.0907546442542826, 0.010031338184020452, 0.042390843267522516, 0.019452973802183426, 0.0757855849881326, 0.07692985987711339, 0.06545929433477503, 0.028677568733391744, 0.01637628042860137, 22.785928903087495, 38.73034992525655, 27.379553894842825, 56.521887625417406, 12.278578762085209, 0.025835246553704626, 0.09864927224454381, 0.1398421033856369, 1.0639264843156262, 5.3462474192342455, 3.931652951625086, 4.125713686789236, 4.103648883681144, 4.300375849969925, 4.58466874976312, 2.6883407898487586, 1.103239174812071, 9.378900912500198, 46.01972187719038, 58.61968101993684, 57.804851762710086, 54.9730299365136, 52.673705162540564, 50.32395047526206, 47.47112043442265, 52.468427919572406, 54.35531546992641, 57.92030672873221, 54.2202211964515, 54.48107058002103, 53.72013861133207, 55.193514208639826, 58.350253412800456, 55.80901645844983, 55.436658013251524, 54.45300994380828, 46.981694929061405, 41.30568796588529, 41.692214012145996, 41.97713498146304, 53.987157883182654, 57.714715696150265, 55.10229164554227, 56.20354413986207, 54.98560113291587, 48.68365449290122, 44.321221843842544, 43.732576062602384, 40.94716764265492, 40.7089856363112, 40.37224231227752, 41.1100205298393, 41.72330271813178, 43.31563988039571, 47.63049025689402, 47.23131848919777, 47.39134726985809, 50.53963376629738, 53.26431997360722, 54.02836238184283, 55.416367592350134, 47.76280749228693, 53.128943289479906, 53.50363554493074, 50.65501028491605, 50.725483509802054, 50.25277122374504, 50.10791024854107, 50.65516325735277, 49.668824441971324, 50.795454671306, 49.767774074308335, 45.02176500135853, 41.413666894358975, 37.41478304709158, 39.06125284010364, 39.08993713317379, 39.47458436412197, 37.64744627860285, 39.27285294378958, 46.6698351214009, 49.157531722899414, 51.543238855177364, 53.21434897761191, 50.1606975063201, 50.33735321414087, 50.4804765793585, 51.929290294647224, 51.349481613405295, 51.64767196101528, 47.20086912955008, 42.912479062234205, 39.5114311095207, 38.73502146813178, 42.62775421142579, 46.44789957231092, 48.16081039367184, 51.120407350601695, 49.20693005284956, 49.78410682370586, 50.82553925052766, 46.461400370444025, 45.49754850326046, 46.04729613950176, 47.20012387921734, 49.49158822336505, 47.55440412029144, 26.289076151386386, 4.026382603952962, 1.7180186053437574, 2.6195647255066903, 3.132083675553722, 4.369064886723796, 6.98273281897268, 8.145175758869417, 4.275244733979625, 0.7510819165937362, 0.14503738993117887, 0.054029913679245985, 1.9356292510224928, 38.8125902606595, 39.251934943660615, 27.697297257761804, 38.251652102316584, 1.717980607382713, 0.03176334407931614, 0.06320424558174226, 0.04561425780036277, 0.04585580149244878, 0.07158610549184584, 0.016019877174027985, 0.03803257289673052, 0.01317495508344784, 0.04913298773669428, 0.03495267344518535, 0.04057340691947649, 0.13949744042850312, 0.015417318378064423, 0.0334538760474853, 0.016970697625149644, 0.024153350311661922, 0.012079792176072877, 0.018681312588253812, 0.030355215102674502, 0.009706666291270767, 0.012233686791132055, 0.11846529319882394, 0.11400879886482032, 0.14771759449954958, 0.16321619672159995, 0.20756251388980498, 0.11862113846526032, 0.04201862412775236, 0.20371315189667288, 0.15531634401169517, 0.1479212513133403, 0.1119013216286417, 0.07595055436174716, 0.20557938804549558, 0.132524753289838, 0.17607341971128218, 0.1565045463822542, 0.13150418627887003, 0.23292025400986596, 0.19910030667820286, 0.16663874048859845, 0.12050281128575727, 0.1287261676043272, 0.13524015193745015, 0.07879838662882967, 0.1303537980082535, 0.1562847710785366, 0.19378791593255537, 0.14951132808721837, 0.15563457693544128, 0.19796026059456412, 27.19879342663673, 48.55962522568242, 33.9113220091789, 59.62834988870929, 18.217695374642652, 0.15758235548292437, 0.8377289123112156, 0.32038504858651473, 3.8101668511667564, 12.805191278457643, 9.230909885898713, 7.41253633652964, 10.283042538550593, 11.098277761090188, 7.691126110092287, 3.7052539904271407, 1.5871988573381979, 9.096964866884294, 45.574987857572495, 61.41481691791166, 61.69158720201062, 57.15765676190777, 55.494203106049575, 53.44840465053436, 50.29059463931669, 55.335264744297156, 58.110180824033684, 60.89047447327645, 55.58988540403305, 56.996510105748335, 54.24994883998748, 56.41364982051235, 61.10764826497724, 57.08429667257494, 57.98253905388617, 56.91375986222298, 48.700932533510276, 43.19838062409432, 46.764336785962506, 44.73204697332075, 56.94154985489384, 60.57446872034381, 57.104904805460286, 58.63954390248945, 57.79182164899765, 50.570659714360396, 46.07398786852437, 45.58058900217856, 43.49204847889562, 43.57758752761349, 42.520689195202245, 43.66879832360053, 44.87173041989727, 46.35044436300955, 50.4410606814969, 50.89387870603993, 50.132852600466826, 52.376597389098144, 54.14548435518819, 56.08974441405266, 57.34238078517299, 50.75626627091439, 55.065009517054406, 54.83515862495669, 53.91663758985458, 55.13290966710737, 53.02879733424033, 52.92914952001264, 51.35431005108742, 51.96282263725035, 53.14533879680019, 51.06472146126532, 48.09449880353866, 42.07258193723617, 40.118668925377634, 40.76542462072065, 41.5333580201672, 40.2339199281508, 40.70272553351618, 42.55823804486183, 49.57056906915481, 52.50507854646253, 53.64083220881801, 54.52491483380718, 51.97096940009825, 51.29481554031373, 50.74402063123642, 52.38232012717955, 54.519039123289055, 54.720817612063506, 48.66432897506222, 45.8623642306174, 42.818401013651204, 39.859619909717196, 44.09634843949349, 48.94419400922714, 50.75184575973019, 53.01938364582678, 50.07926125680247, 50.5017436704328, 52.007219945230794, 49.564975769289084, 47.8446908920042, 50.039755144426906, 49.86023218401017, 51.51506447022962, 49.51591868554392, 26.336407392255722, 3.6437656898652357, 1.5659315211157647, 4.343464557201632, 7.332668054488398, 7.758371224326472, 12.122372331157809, 21.6090315388095, 10.887319945519971, 4.236265199799692, 0.4942762208802085, 0.14081842115809842, 3.771948256800252, 46.826165106988725, 45.03754469656175, 35.99404173512613, 42.56984433820171, 2.1029777872946958, 0.3400179209007371, 0.2375954741071309, 0.15768617571842286, 0.1260868568093546, 0.14809434121895224, 0.07629321782939857, 0.16706568128879995, 0.12773907863565032, 0.1582237089713735, 0.1602089798618709, 0.13787465170025826, 0.421124630036854, 0.07389746936819247, 0.1336431344069781, 0.12537782711367454, 0.07398674159400886, 0.17597238803582807, 0.25635238616697253, 0.17897885412939135, 0.08546067792321406, 0.30216839705263415, 0.23207499855949035], [0.029872058770589294, 0.009735083365212045, 0.048352045367562005, 0.038207187317311764, 0.042797658937953176, 0.10196973479563191, 0.026455436863245505, 0.022616608579072262, 0.010360559681430459, 0.08822486871072362, 0.042247159646884094, 0.027986473156019088, 0.022552349123983614, 0.06751667708158493, 0.04871060899008186, 0.03240564177113195, 0.04541827718757334, 0.03152922377921641, 0.024332758527429357, 0.04260314155309912, 0.04843055022760265, 0.04567985024843966, 0.015893756119053692, 0.01090013551630921, 0.029545149901100708, 0.018549099219061674, 0.051237274216668266, 0.08999219524764246, 0.10442153791025763, 4.258848736363073, 36.70784642619472, 26.788170299222394, 38.329950455696356, 37.660735268746656, 1.9562550345736167, 0.11965330404740189, 0.20941489916895667, 0.4412699845289031, 5.127851809224775, 2.9640128102994736, 4.016211898096146, 2.5085783197033793, 2.4521332065905295, 3.235068201057373, 2.2521026240241144, 1.1044342719739484, 0.217484041988369, 16.208216105737996, 58.00158216107277, 57.22469791289299, 53.98340809729792, 54.14523332349716, 51.47239692749516, 50.72683280514133, 51.65827412759104, 55.744689587623846, 55.14053475472235, 53.09746626884707, 53.864073907175374, 54.816213577024406, 54.06316165001162, 53.78263765765775, 53.136450705989716, 50.20742077981272, 47.102641213324766, 42.20485602655719, 41.91169023513794, 41.35771428385089, 46.79294655399938, 54.05711335520591, 55.22656409971176, 54.28315170349614, 57.742882236357666, 53.170218390803186, 48.641441945106756, 42.929823783136186, 39.56583830618089, 40.142414954400834, 38.92656649312666, 39.39445818624189, 39.83636417696553, 41.895059385607325, 45.350832246964984, 46.253204884067664, 46.89153140591037, 47.65428335435929, 49.8592359019864, 50.83368209100539, 53.76071553076468, 52.77952678741948, 43.20864938920544, 48.9801307647459, 44.381642033976895, 56.963758314809496, 55.429346715250325, 51.770493138221006, 50.302028348368985, 49.706353679780044, 49.29168070516279, 49.557931192459606, 46.11117193775792, 42.01882977639475, 38.31876777833508, 37.553787923628285, 37.05935355155699, 37.69060411760884, 36.68807768052624, 37.06436634063721, 43.35816621780396, 50.270206159160985, 51.66595412838844, 49.088803952740086, 50.03720952618507, 51.986552976792865, 49.17829282822148, 51.67073549762849, 51.1125429984062, 52.621431735254106, 48.91201488433346, 49.41098351632395, 48.151702650131725, 45.6004205057698, 41.4864190163151, 41.52861587462887, 40.346491952096265, 45.07243810161468, 45.93749723126812, 49.68123482119653, 49.20723207535283, 49.86495864006781, 48.540856684407885, 48.528642423691295, 48.78497323682232, 46.47230063715289, 49.49682850991526, 33.959775047917525, 10.473394182420547, 0.7339451425979215, 1.5108339873052414, 2.05385573929356, 2.4259347156170876, 2.47007952101769, 4.225511531676016, 4.8121858316083115, 2.646584462734961, 0.35966446022352866, 0.03592065235059108, 0.06477953685868172, 8.791234743210579, 43.757102643289876, 24.188943063059163, 31.155994246082923, 11.960422569705594, 0.04400535824618513, 0.03500698907901684, 0.04450094435484179, 0.03462846120519023, 0.03241315709366914, 0.03654572647064924, 0.020630307300316713, 0.04983027713493474, 0.01970148697916058, 0.06714920002606607, 0.02996003056215423, 0.05505098630824397, 0.05723933561614925, 0.03520677714878994, 0.04597097898142473, 0.03793770822906687, 0.08986924579667468, 0.025653315993446498, 0.03740984683616027, 0.09239221847946606, 0.009783235821692694, 0.06060990414792492, 0.009546429425808451, 0.004861501079323071, 0.006512477533936862, 0.05306838906460232, 0.05099860718473793, 0.057725223051684524, 0.05307906449982717, 0.06171163434403078, 0.03110830634531956, 0.040640562186918916, 0.09256061226610215, 0.015386548456585696, 0.00564532058741597, 0.05586630687297833, 0.04279825648653411, 0.06531155427857753, 0.07775903514195835, 0.03254085245932783, 0.04839666615871172, 0.019754138286976565, 0.054664828198691534, 0.01024887363816942, 0.06877405719170648, 0.029234484010826678, 0.023089102882471298, 0.017257697144222837, 0.012786191317342944, 0.053838598541915424, 0.0972924615827299, 0.12597289356973865, 6.755833020133357, 44.49261373089206, 27.687218727604037, 51.400684233634706, 39.915690191330455, 1.2353926512502855, 0.0778018901004426, 0.07846006687970893, 0.2347704789210712, 1.6135262962310546, 5.144336550466476, 7.036392313818778, 5.0930344000939405, 5.537651729199195, 5.432820012492519, 4.501741018987471, 2.3369005899275503, 0.9642911113558278, 20.389547040385587, 58.627392399695616, 56.74824760806177, 57.48475890005789, 53.76245706312118, 52.01885369516189, 51.75699626245807, 54.13714931857202, 56.79472769460371, 57.09976650053456, 54.599357497307565, 55.63594579696656, 55.648167902423495, 54.07019445973059, 55.05615672757549, 54.7227160392269, 52.298883468874045, 51.106961465651, 44.04296498144827, 44.20859098434449, 42.02573707026821, 48.265416083797334, 56.778598908455145, 57.630780896832874, 55.316923741371404, 57.42257756571616, 56.03836920953567, 49.74050967924057, 44.12829614454701, 41.872329250458755, 40.951509706435665, 41.522920593138664, 40.72985656799809, 40.394768484177135, 44.04655787252611, 47.75527261918592, 48.212872012968994, 49.32361272073562, 47.90836272701141, 51.03434270428073, 52.987816410679976, 53.616168345174486, 53.858280566430864, 45.4422430838308, 49.99447922552786, 46.793362325237645, 55.56343686196112, 56.53021089492306, 53.44788689767161, 52.544502289064475, 50.75599170500233, 51.2590866704141, 50.076197885697894, 47.931779276940134, 43.13467741012574, 40.66432160715903, 39.91755723953247, 40.44545727391397, 39.040150488576586, 38.67785684524044, 37.76480751652872, 44.89308380311535, 51.36450821353544, 52.86300659179688, 51.605243682861335, 51.82970916071246, 51.994750730453006, 51.451816251201016, 52.95034993079401, 50.78184404680806, 52.5836318539035, 50.49538943075365, 51.56959326036515, 50.140630660518525, 46.495524990943174, 42.332941024534165, 42.79242707837013, 43.01065206527711, 46.80162675919072, 49.45313330619566, 49.26270223432972, 48.524543546861224, 49.714465141296394, 50.732720282769975, 49.7478170548716, 50.00313589649816, 47.407056362398215, 51.917095645781494, 36.0368347937061, 13.046154245253533, 1.227665582010823, 2.6905375622933914, 4.590091916822619, 4.1202307035846095, 4.625107405647155, 6.612438521077556, 4.612366076438658, 2.0963435884444945, 0.4204146810356648, 0.052392527145603975, 0.126263179606007, 8.633196565412707, 51.51743750418387, 26.928871600858628, 33.34892865150206, 16.92964392323648, 0.092345173020036, 0.04852380611062531, 0.04651013251033522, 0.04774433846074728, 0.032960128549846916, 0.00887762413420264, 0.04313497128145349, 0.016768797067925334, 0.015727686451657886, 0.024689632926076174, 0.023682087494601167, 0.0508756653946494, 0.015884131181895012, 0.036771687934355396, 0.009349218284290646, 0.04726610041313595, 0.09179379655829362, 0.09124442724691284, 0.03525390304745205, 0.03878703926719966, 0.005074328923177335, 0.01926525544765736, 0.009481201827105497, 0.15009537819893132, 0.061254360292467384, 0.1929899893941418, 0.14163197589016732, 0.1027919693038829, 0.15881597154563473, 0.26451655453251255, 0.16980018616924364, 0.20482725824319548, 0.20807070597525568, 0.10336782993568529, 0.06176718337942035, 0.09483738727266751, 0.1859307496417915, 0.13962174585509685, 0.222564829032748, 0.11947292864563004, 0.1732802478175971, 0.13947266514503187, 0.23950318625617414, 0.10214377465026994, 0.2261047987567802, 0.27667718909440503, 0.12989244453849333, 0.11311343360331752, 0.0862614619695852, 0.2198401300777351, 0.30304875465170034, 0.274948128649304, 7.1543090574203, 51.96763146308161, 36.78147715906943, 49.26004678972306, 47.76846355007541, 3.817607097087368, 0.3848032677365888, 0.5113512788328433, 1.0314492592888496, 12.41616472121208, 10.851034099055875, 15.233949365154391, 10.806424983086126, 8.746297128738897, 10.15863770438779, 6.736620760733082, 3.5575252723309303, 1.0417398425840563, 18.781498824396444, 62.19159526209678, 61.182502777345725, 59.876447646848625, 58.45732235139417, 56.591580298639116, 55.71137689775037, 56.31664960615097, 60.677007321388494, 60.28133430788594, 56.16512060165406, 57.27314702926144, 57.41048489847491, 56.48292280012562, 56.45622322636267, 57.767934414648245, 54.76415195772725, 53.02524366686421, 45.95599512900076, 46.89464969019736, 45.29218104577834, 51.60522407101047, 58.54921171742102, 60.96773732093073, 56.9894027709961, 58.89561191681893, 57.22776520636774, 53.21911465737128, 46.1592915750319, 43.612484855036584, 43.87861767122823, 44.07527746692781, 42.124384680101954, 44.01029163791288, 46.389660219992365, 51.977711954424464, 51.80755561397922, 52.581015632998565, 51.482571555722146, 53.48265086450885, 54.706132258138354, 55.76438380825905, 55.660131131449056, 47.17806839173841, 48.32556170801963, 49.51121968607749, 60.17637952681511, 56.34227445048671, 55.61488659151139, 55.30389362765897, 53.83519741796679, 54.04988050460816, 52.44994571132045, 49.07412644355528, 44.32781142573203, 43.6150187061679, 41.46419486691875, 41.80225218496015, 41.119983350076986, 40.12329339981079, 40.47947991278864, 47.46402486678093, 54.4719510693704, 56.063346862792976, 52.44873762130738, 52.374977450216974, 55.249815910093254, 52.851823914435606, 53.41765719075357, 53.085585409595126, 54.439171821840354, 52.737600572647594, 53.143138347133515, 53.38623900567332, 49.283914412221606, 45.45918380060504, 45.4055061647969, 45.219656421292214, 48.12497169740739, 51.9483922373864, 51.94374030636203, 50.72966083403557, 51.5048937643728, 51.76278960320258, 52.885485695254424, 51.93625642407326, 50.2833382544979, 51.94173205283381, 35.5341830561238, 12.229359880570444, 1.483246732142664, 3.986645316885364, 7.412455437644836, 8.286372750036179, 7.481516609268804, 12.685333451917096, 11.054332506272102, 8.73271199964708, 1.2376325697668138, 0.15790858636459998, 0.3372528644338731, 13.191797733306887, 57.23571585070703, 32.142923378175304, 42.13467697943411, 19.369834738392985, 0.12304883555419023, 0.19233884530202036, 0.1879647590460316, 0.1138054638079578, 0.1294291145618885, 0.2301145029524642, 0.12317362361617627, 0.09144094412124927, 0.12701849633407208, 0.14917904511094093, 0.18138884416510984, 0.1301983434466585, 0.12216914445161821, 0.11071144152552852, 0.15518010293524112, 0.204230475750181, 0.1844524757395829, 0.14174060715783027, 0.11434676621349589, 0.157616829439517, 0.08923860221740701, 0.17079001773268948, 0.15167250808688904], [0.039112550026226434, 0.013988084636718757, 0.05196358302548047, 0.01771026550071134, 0.03240439687825499, 0.013701618506362843, 0.051442850080709306, 0.03593871287340599, 0.02489754344306646, 0.07990317734619302, 0.021673548598623565, 0.046996203806972316, 0.023257546464822466, 0.06561281835480083, 0.024151712798723773, 0.01741855454090382, 0.0790152891028312, 0.09654836804275552, 0.05846020780623921, 0.0303499712308328, 0.05362084954075756, 0.016308797658571315, 0.05426005415257908, 0.00448102303292422, 0.05450269718083644, 0.005785722000103805, 0.03415028444461284, 0.14645837577840976, 0.013870795617901511, 0.13982216977784712, 22.880395266317553, 38.49994597896453, 25.893091309455137, 47.428025353339414, 13.910374968282639, 0.1634753029793501, 0.024992390873751817, 0.05965699802242941, 0.4665713558994955, 3.7238977513005658, 2.1752776109403182, 2.367844903661359, 2.296985815609655, 3.6534470800430547, 2.789429339670366, 1.6371001086888777, 0.49135567920823253, 1.4325863795895732, 32.859787517978305, 60.65750529689174, 56.3546024599383, 53.85785695045225, 52.6148578428453, 53.43950479261337, 53.03100562864735, 54.52365967535204, 57.72679267391082, 54.30235955022997, 53.787673980959006, 54.96818973172096, 53.01624574968892, 51.743005168053415, 47.93751378213206, 47.69315404276694, 42.690943594901796, 40.68364320262786, 42.03400542659145, 40.479048452069684, 49.192083881747344, 56.799618890208585, 54.49674829359978, 55.8943280096977, 54.035348123119725, 52.14729955119472, 46.59553758559689, 41.820326466714185, 39.946802431537265, 39.470238377971036, 40.32225170443135, 40.23708920325003, 40.56981994259743, 42.11379820300687, 46.131917353599306, 47.575855562763834, 47.86039606217415, 48.06729324402348, 50.007972178920625, 51.34157019276773, 53.23825190144201, 49.99356531327771, 51.496319463176114, 48.988203002560525, 46.22875675078362, 57.46267595598775, 46.811668026831846, 50.48339874513688, 48.98956406501032, 50.229931262231645, 50.03884515454693, 50.897326469421394, 46.32087753665063, 42.12591440446916, 37.5518306609123, 38.739712622857866, 37.57124247089509, 37.423016102083274, 36.62892441595755, 40.57821381476618, 47.84591074912779, 50.332391415872884, 49.983241634984175, 51.339016729785556, 49.582571521882095, 50.0713929822368, 48.48661422729493, 49.15311905645555, 48.984512052228375, 49.47462789473995, 48.995635894037065, 52.21422303107477, 48.712201503015336, 48.09352605573593, 46.165724262114495, 44.76577151206232, 41.362883967738, 41.03919429163779, 44.782900502604825, 47.22641552648237, 46.453092790419056, 47.517612288075114, 49.28637766068982, 48.05909156799317, 49.799560962184785, 48.286573348506806, 41.26953940237723, 16.02013159182764, 1.8685034013563588, 0.2975354650087895, 2.8703706351018723, 3.2467561287264672, 2.9090427535195507, 3.6991630398458053, 4.632792309407265, 3.6025553076497974, 0.6243858666669938, 0.13275434984074486, 0.05424125052447762, 0.5689358711242676, 20.2678672729, 35.4135113377725, 23.332652391925937, 31.92012098527724, 1.8739945970235334, 0.009216101888957764, 0.02069760620924494, 0.055887094668803684, 0.057873702382728945, 0.026891091913585703, 0.06024802719513255, 0.044614984203250184, 0.022044377288811152, 0.047801446485062765, 0.03691610699940113, 0.02005835180170834, 0.04858889294067218, 0.05240979859785688, 0.023625042672539433, 0.011942728512710141, 0.032907061639332005, 0.03419670554238462, 0.04515935479092502, 0.010970761162048627, 0.026018663324535857, 0.02849772767794709, 0.024274746519363215, 0.04587532141275945, 0.043188693197143656, 0.014765312437028175, 0.053379980006044915, 0.051820952775737936, 0.0644531604203005, 0.010594019230695502, 0.046033169999117815, 0.05085442943738834, 0.08988495059912244, 0.03873132552290636, 0.041184825522284356, 0.03299713059658966, 0.0034072660585685124, 0.023029342278717987, 0.02421865739198702, 0.03274489231708069, 0.08993129125766217, 0.008428055011937696, 0.02444472993844219, 0.02323176952139024, 0.0502712220223921, 0.08595873466542653, 0.01941895375268594, 0.06395610342282923, 0.025861760856763973, 0.05014813084515834, 0.010968338408988091, 0.09774138910635825, 0.026630229399269147, 0.2724600895758598, 30.120855262202603, 40.52352812982375, 29.5454494414791, 55.32524308850689, 13.190801451283118, 0.11445877592890494, 0.08680533843054887, 0.15814351488745984, 0.2503700974968172, 2.270244811811755, 4.221266546557027, 4.579808933119621, 5.030858949307473, 5.371412855963554, 5.28323209093463, 2.817876084196952, 1.5577052076978068, 2.3076772161068457, 40.02450850702102, 60.75632941338324, 59.04270864302113, 57.736394636092655, 56.11256868608537, 54.62588448678294, 54.85789268247543, 56.1276109756962, 58.98077834037043, 55.52615865584343, 53.85471513194423, 57.303992548296534, 55.32297595854729, 53.552578879940896, 51.07519026725523, 48.859215859443914, 45.61301131402293, 42.990997068343624, 44.26455536196309, 42.404908672455825, 50.84547273574337, 59.069259166717536, 56.430433642479684, 57.51766758580362, 56.94886507526521, 53.63472115608954, 49.11040836764921, 43.915005499316806, 42.513307294537945, 40.59443673779888, 43.14473828961773, 40.69175074177404, 41.98635255136798, 43.91466033074164, 48.112569162922526, 49.69899923570695, 49.41374486492526, 48.750087676509736, 52.319530825461115, 52.63613277865995, 56.72793365293934, 52.26703774544501, 50.72879006785732, 48.30811892786334, 50.05788433936335, 58.773461464912664, 49.705714333441954, 52.496845491470836, 50.74616616772067, 51.554543126013975, 53.09255546139133, 51.14245499334028, 47.642194609488214, 44.48431007323727, 39.399796532046416, 39.95907552780644, 39.84977083821451, 39.29982708346459, 39.69930479603429, 43.01414689710064, 49.508207305785156, 52.17974539726011, 52.33914659869287, 52.25296820363691, 51.41296125227406, 52.784378759322635, 49.98647759037633, 51.051130448618245, 51.92470112154561, 51.64137655688871, 50.06575653629918, 54.05168087251725, 49.16058724926364, 49.89738487428235, 46.970500484589614, 46.43921152237923, 42.868246493800996, 44.456359263389345, 46.45096294341549, 49.129702506526826, 47.723101339032574, 49.02775618337816, 50.314795663279874, 47.07226245634018, 49.43734184388192, 48.92550391535605, 44.446412132632354, 18.6903174461857, 3.574129891011023, 1.070090366467353, 3.5726729756401436, 3.911809190627068, 4.031553758728889, 6.619086448223361, 7.051631212234498, 2.3968746104548058, 0.20749946485363668, 0.100139933788488, 0.07063159058170934, 0.480121459451414, 23.67713062993942, 45.56564084945187, 24.26074597143358, 36.43675181173509, 4.188807952788569, 0.14741428496856845, 0.035207891806719765, 0.07321866950200451, 0.031064995564520363, 0.004905728292801688, 0.09426945565088142, 0.0449314283116931, 0.017809433667289636, 0.04689280491983218, 0.06404713382043185, 0.049121205304418845, 0.058833281134044936, 0.03251041195565655, 0.04580216384643028, 0.03735873344985228, 0.022236872201545105, 0.026930700574490814, 0.034318873583669626, 0.030806594107660557, 0.05133747085628491, 0.02876856465703778, 0.01130693682259129, 0.11512599254567778, 0.10451363700051462, 0.07488427488433738, 0.15738298876150963, 0.20419739607361057, 0.18606323688741655, 0.12868682132853618, 0.19244553070635567, 0.17909487048464437, 0.22525422665621006, 0.16986363357113254, 0.08896607409922347, 0.08512937553947972, 0.08733344114115162, 0.20820006758214968, 0.09786674407340827, 0.1457143205428316, 0.18772786933808558, 0.23666096941357662, 0.15604749832662845, 0.18375406402253336, 0.18524647990782417, 0.13127129554988878, 0.15987675817262742, 0.14694752291806285, 0.09398129167816333, 0.26539715727971447, 0.15637993452049073, 0.2746933584492053, 0.1150320548444025, 0.5630479644863837, 34.67927894284649, 50.772638244013635, 34.8819988004623, 58.94948174876552, 19.524054488828106, 0.508210686065497, 0.46662035488313247, 0.4828990491167192, 2.3580755053027986, 10.819712012044846, 9.824451765706463, 9.844354852553337, 8.379581013033468, 11.038987213565457, 8.377174638932752, 3.4393680384082184, 1.7567080067050074, 2.219178984242101, 36.4837614182503, 62.76545763015748, 62.13614863734092, 58.25450443452405, 57.78753842076948, 58.858106213231245, 56.8614197546436, 57.41829825985817, 60.383661100941325, 59.180885899451475, 55.873268804242535, 59.796329313708895, 57.54105667914114, 55.610905385786495, 53.193913429014145, 50.18253726343955, 47.35036242392756, 44.04431819915772, 46.519251408115515, 43.40832156519736, 53.82660742728941, 62.52516538866105, 59.17073088307535, 57.86011403606784, 58.39499196698589, 56.787047693806315, 50.080728223246915, 45.87231528374457, 43.67738046953755, 42.96441908805601, 45.90689882155388, 43.91375034086166, 44.4623448002723, 47.59220792401222, 51.21690550158101, 52.62931569930046, 52.585330240188114, 53.05229233157251, 53.40936922257947, 55.44696600206437, 55.74776864820912, 52.51349595285232, 52.47939094420403, 48.93309762400966, 49.5019942714322, 59.11704540252686, 53.97687342859084, 54.03317905241444, 54.6469162356469, 53.91675133858958, 54.07780385786488, 53.81811941823652, 51.17470864326724, 45.75008638443486, 41.7890259527391, 41.794654553936375, 42.1344651714448, 40.998574226133286, 40.855466550396336, 44.25858159219065, 51.685099217199514, 53.74451221958284, 53.60740577020953, 53.44430969607446, 53.29949578931255, 54.3275176325152, 51.19522656163862, 53.60890411561536, 54.12835928701586, 53.143691401327814, 51.59794022960048, 56.12233146544426, 52.7891287496013, 52.20888468527025, 49.825479984283454, 49.303757682923354, 45.73892331892445, 45.577678603510705, 49.868163216498594, 50.917079525609175, 48.343628145033314, 49.025622414004424, 50.66000738451558, 48.550340975484545, 53.497971642401914, 49.509493843201675, 43.28411186895063, 18.46071758577901, 2.855687242361807, 1.1419011195821147, 6.0791766066705035, 7.927871058064123, 7.9436610494890525, 12.501637089637018, 14.26499645556173, 11.448398328596546, 2.4526411535278445, 0.6332014549163081, 0.23047506989490604, 1.3351299445475302, 28.25673510951381, 46.483863784420876, 31.877139652929, 44.19462734653104, 4.802429426100947, 0.2791247174384133, 0.09340395249666707, 0.16189998105889367, 0.12318222678356594, 0.0886061123662418, 0.22919838436909262, 0.15594858105384535, 0.12031880462722433, 0.11272511895625822, 0.18173623439525405, 0.13732619403350738, 0.13385457467407952, 0.12487305944124538, 0.11674532621738412, 0.15752443923584877, 0.07134849566125101, 0.06095113886159755, 0.1920347237178395, 0.08468111451234549, 0.14247467260687582, 0.10609530978986334, 0.13402156651981417, 0.26303987409318647], [0.03842104459181428, 0.02310874537684985, 0.09755269398972874, 0.034885993152255976, 0.026179754378033743, 0.04216073726814601, 0.034382719351279165, 0.024242944294406522, 0.03567145160970188, 0.1337570516813186, 0.00653588343524344, 0.02448723249648127, 0.050464375770740935, 0.03736629856810455, 0.019524920949592225, 0.021093259978618835, 0.07349930283042692, 0.03287690075775308, 0.07092163913072118, 0.03640127676208654, 0.056767624637652794, 0.0393525462207054, 0.00809990029196225, 0.06813002239552236, 0.09071869940887536, 0.04897629977354119, 0.020304919115357825, 0.023047364497136687, 0.0823101949607653, 0.06515889593790616, 5.700349682761777, 37.5878615533152, 31.747466095032234, 38.13249441885179, 36.59404670038531, 3.3425328087422157, 0.025089881307775938, 0.07135375868529081, 0.21904425665495858, 1.9558781193148707, 2.261202032527616, 3.5849502394276285, 4.0748917816146735, 1.9200014250893749, 4.515420284963423, 3.6068311814338934, 0.9892609811598255, 0.15636577721565, 6.936663600706286, 49.41562368023781, 56.278229990313136, 57.39543868649391, 55.009939439835094, 54.62371933844782, 53.90152469758065, 57.20303858480146, 56.06985407490885, 58.172244487270234, 53.761311731030865, 53.61215183811804, 50.91014869751469, 50.40915220014511, 46.69033342792142, 46.89433590058358, 42.546412098792295, 42.318781268212106, 41.276105450045684, 44.043227780249815, 51.55903816223145, 54.66508465428507, 52.907231315489746, 49.78369889720794, 52.91585268512849, 52.65431688677881, 47.58177049698369, 43.92558413167154, 40.41565510534471, 41.37714178331437, 39.95282719212194, 41.28036906642299, 39.71527668737596, 43.592261114428126, 49.65136204996417, 49.14811411211568, 49.26108621781873, 49.34045537825554, 51.97980650009648, 52.986341599495184, 54.05274775720412, 51.53312306250296, 48.14756062722976, 48.319289838114095, 48.82937446717293, 48.958997034257465, 48.33036661148072, 52.620557046705684, 52.33838565887944, 52.42392470759731, 51.89906058772918, 49.41476468117007, 47.35144107572494, 38.928515911102295, 36.78084957984186, 37.253989404247655, 35.651881617884484, 35.861006705991684, 38.53635734127414, 42.235077888734885, 47.65964523438485, 50.84253095811414, 52.450475231293716, 51.40115491805538, 48.58330065204252, 45.906855675481985, 45.4132410787767, 43.51834012616066, 45.563307039199344, 48.92550783772623, 48.89769823320451, 50.65792068358391, 50.244459721349905, 48.19519389060236, 49.77298298189717, 44.66559810023154, 44.72419831060594, 41.927011013031006, 45.04038449256651, 47.54664174972042, 49.96861903898178, 49.732488432238185, 52.174744375290416, 51.34998759915752, 49.49975067569364, 39.52276283694852, 23.147161545292025, 3.1742020864640517, 0.6790942278119826, 1.1371761344132887, 1.377619754883551, 3.011218290175161, 2.228735594018813, 4.270040239057233, 5.590327689724584, 0.7799042893513557, 0.28414366586554435, 0.19636621548523828, 0.05187368643800578, 4.131036833409341, 36.603597671754905, 34.41710772052888, 28.328779243653823, 18.623468491338915, 0.13555861468757355, 0.053849894508358934, 0.056181460123268835, 0.022809785310058825, 0.06810330124872346, 0.055554237126583056, 0.055909483588390776, 0.03308480552908394, 0.01563337528251953, 0.05167947548832144, 0.034773615714643276, 0.05882386974389515, 0.08330473030406622, 0.02293292628300767, 0.043425303282997305, 0.004928046828060742, 0.1232973161724306, 0.07191533943818462, 0.031068770462767254, 0.022691269592952826, 0.04668567006686523, 0.0425323550288956, 0.0915075631271447, 0.09241250448770101, 0.018640872721950856, 0.06547270087344993, 0.012035281510062277, 0.029806044974154042, 0.026771921191304445, 0.06564441182079815, 0.010841926240602569, 0.04434408402190574, 0.006069431171542215, 0.024911560936860984, 0.06530603844552271, 0.018257683203105005, 0.010531084150105957, 0.0299845262235331, 0.10172137675145942, 0.02502835104091754, 0.04805239390641932, 0.05873225328903045, 0.09437034943050916, 0.007303256472016895, 0.04494012340963368, 0.027731549738335515, 0.029537527326254115, 0.10746938807349052, 0.09585587052448143, 0.012702997999205705, 0.011632551961097748, 0.028614805064975258, 0.05496006316295075, 0.06843684827007594, 9.943530021175262, 44.19127372003371, 29.62516377049108, 46.193000424292784, 39.169624005594564, 2.636169344186783, 0.08099575662204335, 0.07727328943268907, 0.05676169128667924, 0.2904296624324014, 2.759934586863364, 4.017602378322232, 5.087334215641022, 5.676698771215254, 4.414086832154182, 4.262611269950867, 1.9911647419775687, 0.5864298872409329, 9.403259811862823, 53.253031392251295, 58.24247452520556, 58.87146972840833, 55.90016057414394, 57.09176486538303, 56.04691605414114, 58.422652521441066, 56.83027221310524, 57.18977705124886, 57.40081233362998, 54.41901476152482, 54.01983907145839, 51.578595099910615, 47.80986808961438, 49.55776645291237, 43.78827371904927, 44.1197963683836, 43.2147761314146, 45.27115321928456, 53.65784352825534, 56.18194364732312, 55.28461910063221, 53.693529252083074, 54.44757746111963, 53.20479408387215, 50.29091627367082, 46.115282581698516, 41.83083841877599, 42.08905981433007, 40.71119393071821, 44.20894792003017, 40.9863168193448, 44.12091032151253, 52.02448229635916, 51.281361810622684, 52.04551796759329, 51.86635194286224, 53.90791816096152, 55.62302158724878, 55.2852153008984, 52.357754322790335, 48.98528475915232, 47.560005264897505, 52.56975058586367, 51.346222123792096, 52.35079603810465, 54.3740761664606, 54.10134984600929, 54.67061127385786, 52.79558497090494, 49.617068767547615, 48.02516698837281, 41.581807136535645, 39.35602680329354, 38.464927058066095, 38.06347247092955, 38.83174711658109, 39.53631462589387, 43.944423275609175, 50.89280397661271, 52.80797573827928, 54.521286641397786, 54.713686743090236, 50.05163600367885, 48.95673774903821, 47.42213003097042, 46.025323021796446, 47.30272131581461, 50.02268891180716, 50.05214198943108, 52.2478691224129, 53.5174972011197, 49.57418157208351, 50.36013826247185, 45.715294961006414, 46.43686594501619, 43.54171353001749, 46.43890165513562, 48.41237944941367, 50.79774141311646, 49.49716191137991, 50.5514754018476, 52.48552553115353, 50.247507402973795, 42.27087343892744, 27.34063417680802, 4.712192358509188, 1.4046278475753724, 2.130598872900009, 2.6419754326343536, 5.652578646136869, 5.122837058959469, 5.722998428729273, 5.2924982001704555, 1.1613497017852723, 0.04879669812057288, 0.05774862703777129, 0.016482297421222734, 3.4458367622667745, 39.26087010291315, 37.18152361531412, 28.40107244829978, 25.34520091549043, 0.42578719436160983, 0.06149398876474269, 0.008147312515986063, 0.06997632493655528, 0.010187358693069509, 0.0382205976864263, 0.024034196826358958, 0.08411404856991384, 0.0335746651305066, 0.07080002267274164, 0.0156845384645426, 0.0955955308651732, 0.015653667036413906, 0.08154751612774788, 0.04017917424320214, 0.031570092654756965, 0.03997202023803707, 0.08786998614067994, 0.03563093704982631, 0.04535045542363678, 0.031945010339240396, 0.05807175143291393, 0.10099809782038774, 0.02112299376617997, 0.11596789253094505, 0.1628527646103213, 0.1779512544312785, 0.06226919313532211, 0.07937879782290229, 0.1532456543176405, 0.09195930219345516, 0.15801153325986478, 0.06848893458804778, 0.2914353213723629, 0.17769735757141344, 0.10465742404302282, 0.17303790356363022, 0.16077708002300034, 0.18575186811147198, 0.12524011514840588, 0.11387394440750923, 0.174693756646687, 0.1583677794664137, 0.11523987917650132, 0.15870671208587386, 0.1430374101525353, 0.1883122718502437, 0.19588751778487237, 0.1969784116672893, 0.1083244264666592, 0.12015788019784998, 0.1762272654882362, 0.32003994129838487, 0.32634079997097293, 11.769362938019539, 50.98869023784515, 41.84982661278018, 48.13684863428916, 47.47641955652545, 5.155386357538162, 0.23421589255092606, 0.21176239175181236, 0.5388815676973713, 6.0573643061422535, 10.51865048946873, 11.802117670736006, 12.581558323675587, 9.016333683844536, 11.880023787098548, 7.287201410339725, 3.1519975489185703, 0.42751659188539753, 8.583226550009943, 53.43850458821943, 59.937028654160045, 61.36228461419383, 59.71502642477713, 59.44294729540425, 58.10380305013349, 61.50099139059744, 57.668117938503144, 61.45112629859679, 58.01357676905971, 57.90227951542024, 55.1728472402019, 55.34764766693116, 50.80582149567143, 51.949918039383434, 45.71143534875686, 45.08542114688505, 44.98125868458902, 49.41592570274107, 55.915375448042354, 58.42371548375776, 55.65525562532487, 53.95023661275064, 56.785368919372566, 55.499949378352014, 53.060180217989036, 49.165788312112134, 43.78426113436299, 43.435946818320986, 44.41474291586107, 47.42696631339289, 43.52905211910125, 46.74502303523403, 54.93721477447018, 53.73880517098212, 55.093305495477495, 53.418206322577696, 57.85470900997039, 56.088701063586825, 57.89569777827109, 53.798393818639944, 51.0939823427508, 48.04959158743582, 50.54079478786838, 56.6599589778531, 51.311705266275716, 58.108294163980794, 55.10780649800455, 56.63120800449003, 55.67771511693155, 52.67423468251383, 50.618347890915416, 42.60165868266937, 39.45705136945171, 40.2400113690284, 38.8526298153785, 39.47538060526694, 43.42284610194545, 46.699013633112756, 51.81147406178137, 54.89557489272087, 57.043504022782855, 56.35267657618369, 52.0752416887591, 50.73993352151687, 49.623987828531575, 45.88014041223834, 49.14025760466053, 53.27331004604217, 53.02965633330807, 54.83730416144095, 54.53707025897119, 50.13023637956189, 52.800982152262044, 48.319858581789084, 48.96636716781124, 46.53328957096223, 48.253680352241766, 51.43728779208276, 53.87133421436433, 51.5289378935291, 52.29822058831492, 51.194202823023645, 49.321318134184814, 42.00317951940721, 25.28106624080289, 4.033992492383526, 2.1702483969350017, 4.727771522537355, 5.610926016684502, 8.321189668870742, 8.700697614300637, 12.398182615157097, 16.0873237540645, 4.455114333860336, 0.5611220807317765, 0.6500243167242696, 0.1551616248945075, 5.928608582865808, 46.191698197395574, 43.39342440328291, 37.83283710479736, 29.2197181717042, 0.4431195965697689, 0.132901637905067, 0.18438835418032062, 0.18428312434304148, 0.16787520639838713, 0.1784988081142787, 0.18589958518503175, 0.1763333073787151, 0.09152815557054936, 0.1440517565295581, 0.07721039361410564, 0.16049690634733246, 0.25159648168952237, 0.1554655626175865, 0.08804424816081602, 0.11730674609181382, 0.3291592374444008, 0.18727010115981105, 0.10143253096048871, 0.1890169195229969, 0.10509495983921713, 0.1338037983664582, 0.14342290559603324, 0.21291224376088191], [0.024057732962612665, 0.012631886845244276, 0.02642141681374802, 0.02388055980836432, 0.04292957544807465, 0.01884595445928074, 0.07724161169702008, 0.0699160491386729, 0.05989184993649683, 0.015385624363027034, 0.05327221058729676, 0.016250312591211933, 0.02933360812734933, 0.03371950937435031, 0.04272260913445104, 0.03508475849465017, 0.03160204809729851, 0.04692143362556254, 0.011858373613757713, 0.04882557580487863, 0.05363015367859795, 0.08478688061117165, 0.10006575349477992, 0.07690411166197832, 0.0727405616893403, 0.06048952492194311, 0.045285560115570986, 0.03651591798951549, 0.02031730675709344, 0.07005288010282863, 0.219025717327191, 26.010762414624615, 33.448215607673895, 23.839201004274432, 41.5356251501268, 21.76286493578265, 1.8066701773674259, 0.04970165480288768, 0.023473874372880787, 0.06218044951017346, 1.8858243428891706, 1.9001059378347092, 2.519152539391672, 4.2275859752009, 2.337971151836457, 3.761526519252408, 3.5151818154319643, 0.18476225105264496, 0.4302590640802538, 20.18361476159865, 57.018863693360366, 56.774213698602495, 56.186473984872144, 52.82857994879446, 57.712146543687396, 56.036019709802446, 55.30796897026801, 55.941172876665675, 54.84079507089431, 54.512959449521965, 51.80029138442009, 49.806907561517534, 49.835376124228205, 47.84570678587883, 47.30015216335174, 42.149574141348566, 41.188836636081824, 46.12736348182925, 54.566911651242165, 56.056655299279, 52.210135921355224, 52.510095257912916, 54.36021451027163, 52.8579310447939, 51.74548410600232, 42.07260547145721, 41.82486464900356, 41.662976664881555, 40.61129116242932, 40.46841098416237, 40.59930047681255, 44.51353957576137, 48.05278047438591, 51.31001864710162, 51.52272878154632, 51.44996881484986, 52.78572805466191, 53.25390608079972, 54.70432012311874, 52.342955220130186, 44.74265306226669, 46.52320515724921, 51.45079251258604, 52.215411509236986, 50.55900635257844, 51.037829691363925, 52.461908940346014, 51.77353297510455, 50.10609026878111, 47.085849546617084, 44.05087247971566, 37.1773188344894, 37.389334709413596, 37.713828471399125, 38.25493904852098, 37.88309835618542, 37.215514875227406, 40.27656785903439, 47.52131108314761, 49.044712589633086, 49.063292857139345, 46.9069149417262, 46.56678661223381, 42.09813225653864, 39.92875560637444, 37.24796464366298, 36.61813789798368, 39.22008529786141, 44.76388877437961, 46.56815159705378, 48.3546539275877, 47.34202738731138, 46.28673330430062, 44.60600553020355, 42.770477494885846, 40.3408202048271, 44.02827570515294, 46.775013477571555, 50.49917844034011, 50.354529273125436, 46.00099255961757, 44.67687883684712, 41.133766558862504, 26.393609277663696, 4.854388083181074, 0.1410886663342676, 0.325761545569666, 0.7989706856108482, 2.5375369335374525, 2.901089902847044, 4.344704026176084, 3.352783432891292, 4.5540855392333, 0.6245942425823982, 0.02467563841491938, 0.017293322147921692, 0.750499751058317, 16.282496971468774, 41.61677898899202, 26.03334742207681, 29.43722144249947, 7.654558343272056, 0.024856592213074048, 0.02913364002691402, 0.09241696311942033, 0.0482198722179859, 0.06978059713278087, 0.07169786239823989, 0.044197504588913535, 0.07790321288930793, 0.03270021789977628, 0.05280139210123209, 0.06054585536701545, 0.09060934035768432, 0.08159452328278173, 0.05877608500961816, 0.011804128843059224, 0.09224401110963476, 0.029434929000994856, 0.09923276311207203, 0.04383006200735127, 0.024825469891150153, 0.01775063833432092, 0.029138412754682284, 0.07901036315747807, 0.05462987543714624, 0.03233033149773556, 0.013194095790235987, 0.04842907933878803, 0.025552732479428093, 0.05110347696069268, 0.021179860472799312, 0.06088241694434997, 0.012832868096959448, 0.023337321115597602, 0.02351979942872159, 0.05323687861222894, 0.03240231311910095, 0.08476434996531856, 0.027432922919791554, 0.05016423401332671, 0.035997720795773694, 0.062487612463413715, 0.009485893158031809, 0.0197383051648015, 0.020674907024048512, 0.019732011752503536, 0.04570227364198335, 0.022694571431906476, 0.0753266446953339, 0.07622386388961347, 0.043957791846966555, 0.04633247672069458, 0.04133387941927199, 0.026540600942567955, 0.014601136922025153, 0.763994052765831, 32.86856578242394, 37.116337745420395, 28.760118369133245, 50.76373446372248, 22.78746843338013, 1.6024782051963191, 0.0786191143936688, 0.01342082429947632, 0.0358009587733015, 0.36631064068886543, 2.319481098844159, 5.725480798752078, 5.839635008765805, 4.90236847631393, 4.50102714761611, 2.645226832359068, 0.8670491809325834, 1.3012013199829287, 26.241119292474565, 59.503449855312226, 58.039758589959916, 58.516710958173206, 54.2615786675484, 57.63328336900281, 56.71817087358045, 58.29042550056212, 56.35212744435957, 55.090591215318256, 57.2119031413909, 54.30366962186752, 50.36944212452058, 51.10228207803542, 50.65649686321136, 47.55614957501812, 44.431973888028054, 42.77708276625603, 48.68379177585725, 55.57333300190588, 57.363910675048835, 53.91133062301144, 53.20482154046336, 57.099982230894035, 55.76742364514259, 52.660816254154334, 43.1220866018726, 42.98751400363061, 43.930161537662634, 42.57801071290047, 41.958797900907456, 40.47525159774288, 46.24422265637306, 50.47066673155754, 53.73921309748004, 52.06127020620531, 53.828611758447465, 54.43395899188135, 55.27682927346999, 58.016369496622396, 52.40029634967927, 48.218469235204886, 49.56761160204488, 54.09743532057732, 54.213219765693914, 51.81703990505588, 53.28946236641177, 53.57200637940438, 52.34205699736073, 51.513519056381725, 49.711115437169234, 45.501533631355535, 38.987775079665646, 39.51624778009231, 39.54505758900797, 39.69670034223987, 37.97642330969534, 39.79960372371059, 43.94616088559551, 49.822824539676795, 49.88252693606962, 51.00611732852075, 49.93263521502095, 49.1761786706986, 44.468000858060776, 42.1944539008602, 39.723929435976096, 40.52339476923789, 42.859793786079656, 47.970642120607444, 48.927641607099964, 49.77263781332201, 49.05867622744653, 48.57527548266996, 47.0952553902903, 45.107727666055005, 41.63679876635152, 44.537262070563536, 48.50514350398895, 51.752987600141964, 51.99993218145063, 48.554408473353234, 45.238268067759854, 44.06157662791591, 28.53471152244076, 7.937967729183936, 0.3135299099789512, 2.5725458033623236, 3.647405404237009, 3.8492799910806843, 7.531716573622919, 6.860871151570351, 4.717124248704603, 1.645333041106501, 0.26042684011401673, 0.10729917865847388, 0.0488379021595803, 0.5510505985829138, 16.295470210813708, 47.02987340188796, 29.25712973840775, 33.37335325056507, 11.044495201879933, 0.1055836396652364, 0.03939671118954017, 0.007583670986575947, 0.06436525949186857, 0.03792089259912891, 0.049902729900373574, 0.028711360871731758, 0.04987231620977964, 0.0395621057419527, 0.022607028649579135, 0.0412439292056426, 0.013545791434514667, 0.047968771579044486, 0.019948967852659767, 0.07142140424900478, 0.036828091157780546, 0.023324956456499717, 0.036574213450113614, 0.04504758639321212, 0.014818337212707249, 0.03392190214306597, 0.024732407445328373, 0.07048757371282385, 0.03529530243888017, 0.12409294444707133, 0.07766122869666546, 0.09944277079475504, 0.13453293020927137, 0.132377848269478, 0.13838765481787343, 0.16641462912722943, 0.1367857496464445, 0.16584585480872663, 0.16812835249208635, 0.18920687868470148, 0.08551778977796917, 0.14612388646891042, 0.1515025284982497, 0.0831585607281135, 0.2316959229327979, 0.16382745827638334, 0.07876582789204775, 0.11053941648213134, 0.10167382567399934, 0.1994519257136891, 0.14605188952578654, 0.17268962467149382, 0.15073063362750316, 0.17220268386506266, 0.18961734859453094, 0.1250679828526993, 0.13973491236327157, 0.07055441488421733, 0.13891795620081887, 0.9071164986779614, 37.833562743279245, 45.96578928732103, 32.89995258854282, 51.34180945734824, 30.255096420165035, 2.697607879677127, 0.29085701692008203, 0.18062471742591552, 0.5821518071236149, 6.79074211466697, 9.165666161044951, 10.508289548658556, 10.790775706691127, 8.230528985300372, 8.169547405935104, 7.111464517731821, 0.8788205202548736, 1.1447684947521457, 23.91007431091801, 62.99065659123083, 60.45493056697231, 61.78229985698577, 56.8013604225651, 61.55986224451373, 59.98798024269843, 60.79384296171127, 59.04657217764086, 58.03988018343526, 58.91561208232757, 56.64980396147698, 53.912883881599676, 52.99978748444588, 52.56217648906093, 51.385587030841464, 46.85328829673029, 44.49810504913331, 50.615959167480476, 57.847052543394035, 59.73404599774269, 55.45070009846842, 54.896320143053615, 59.027348641426336, 56.731569690089074, 56.11272165852209, 45.970233332726266, 45.14258576977638, 46.36083864396619, 44.963282462089296, 43.83826824926561, 43.948953613158196, 48.426543128105905, 52.37043534555743, 56.01506248597176, 55.15182333607828, 56.01140291460099, 57.530050508437625, 57.06970545553393, 57.53685582068659, 52.791548851997625, 52.15514429153935, 51.27665104404573, 55.935006910754794, 55.931657206627634, 53.62393463811567, 55.809867612777225, 56.82550653334587, 54.746760168383204, 54.210756517225704, 52.12545587170509, 47.66300278325235, 40.211464358914284, 41.61124452467888, 42.23292058514011, 41.33723166681106, 40.749778286103286, 41.27843926029821, 45.4787564277649, 51.17572453714187, 52.67444256813296, 51.8855558672259, 51.58650652054818, 51.25865128732497, 46.774303528570364, 44.170469468639745, 41.17270784993326, 40.822522563319055, 43.794557356065326, 49.88942638520272, 50.136084633488814, 52.64491496547576, 50.00350852166453, 49.721415581241736, 48.502613575227805, 47.0871792301055, 43.724495980047415, 45.82679225552467, 51.76084410759711, 54.296793706955455, 51.523062183010964, 48.385056218793316, 51.11259791158861, 47.526825935609885, 29.17325769701312, 7.024129513771304, 0.38535203183850936, 2.0812941895377253, 4.516042961228279, 6.106771461425289, 8.181535640070516, 11.97234461384435, 10.935856334624752, 10.646746273963682, 1.8200865219677649, 0.33809776748380355, 0.16860654457442223, 1.5376322331928438, 20.659066823221025, 53.21735743553408, 33.74778662958453, 41.391305462006606, 13.31079165781698, 0.21098242231434394, 0.16420201398432255, 0.18530693956680838, 0.21800580915183793, 0.20046417300979938, 0.19555053102873987, 0.1192187253505953, 0.11456585969896087, 0.12687598865839744, 0.26293547163086556, 0.21579012965723393, 0.19252089843634637, 0.193120745281058, 0.10612986035524838, 0.16905125861446704, 0.14507177195722057, 0.08096706662927905, 0.16661270882093138, 0.14264269101042903, 0.09396698881661701, 0.14898985203716064, 0.11176652845836456, 0.2978227479803947, 0.1473195965011274], [0.0181458420270393, 0.03825381908926272, 0.013994740983170849, 0.05924764277052976, 0.030580207465156436, 0.05974413286293707, 0.0414274838723002, 0.05120228315072675, 0.02590421936474741, 0.02432479121301684, 0.12093463972691568, 0.02686458335618579, 0.05945928222049148, 0.0376603422656415, 0.03315677948957009, 0.041612517088651664, 0.0656959465554645, 0.029645089901262717, 0.008241194675886824, 0.019565391459412152, 0.026816030618764704, 0.007727040032360463, 0.04728380470506607, 0.02334354174954276, 0.0624488445840055, 0.06823623282534462, 0.03840276573394095, 0.04790667632234193, 0.009017139278923073, 0.04288629914123205, 0.04981150798078987, 7.929683683380005, 37.72371284423336, 26.05544605562764, 34.41773529975645, 36.286595636798495, 14.685513761735733, 1.7257617317861127, 0.14754330949677577, 0.08176274086919524, 0.17243591167273062, 1.199823372787045, 3.690301915330272, 3.3869570830175957, 2.5538807146010862, 3.150675955318636, 1.0171323630117601, 1.1678962601769356, 0.23346187817233227, 3.4964588717106855, 34.746143587173954, 53.29458105948664, 58.072455467716345, 56.05182293922671, 56.94382090722361, 57.22814959864463, 56.60628134204496, 54.83881427395729, 54.66885797439083, 54.3217517483619, 54.10316590339907, 51.809697228093306, 53.09519129414713, 48.675119415406265, 45.89967773806664, 41.9435045796056, 41.813834944079005, 49.523171147992535, 54.11911033814954, 55.36159169289374, 55.98667237066454, 50.643329466542895, 54.105715444011075, 53.24608095230595, 53.79846834367322, 48.237100493523386, 42.087322204343735, 40.51445960998535, 40.15632367903187, 41.86858338694419, 37.97537995922951, 43.98991884723787, 53.054532004940896, 53.4660239373484, 55.475430642404866, 54.38987155114451, 53.57253197700747, 53.86968289652179, 53.27453382553593, 48.02714778530983, 44.35775479962749, 51.336341673328036, 50.40837949322116, 51.68680544822447, 52.49824969999252, 50.91860924997638, 48.90844552747665, 50.07217745627127, 46.10379788183397, 41.70725630175683, 38.53494921038228, 37.59538858167587, 37.16614007949829, 37.72044943224999, 38.410641454881244, 37.917466163635254, 37.99066935816119, 38.7108047546879, 42.79305857996787, 44.798515458260816, 46.04470737518803, 43.67564285955122, 42.323060574070105, 39.85595641597625, 39.09065100454515, 38.44031810760498, 39.36251440355855, 37.99514870489798, 34.963748839593705, 36.05786654257005, 40.64609827533845, 41.20938985578476, 41.73615632518646, 40.38042829882714, 39.0056767771321, 42.1974584364122, 48.944146940785075, 46.77822982111285, 50.44630881278746, 49.91684767507738, 47.47064190526163, 39.99110952500374, 27.383913609289355, 4.587530609100096, 0.4586205276991091, 0.5364259188213657, 3.377252648915014, 1.7410286996633777, 2.2399285676017886, 7.0414590354888675, 3.22228200974003, 3.492220505591362, 0.7468642042048517, 0.06154811287659311, 0.05508067221530984, 0.19109920778822517, 6.6624457989969565, 30.592863482813684, 30.80655420980146, 25.189237671513713, 23.834386294887913, 0.9341666342750673, 0.033503568340693755, 0.03945800205392223, 0.06244525163164062, 0.06961855421503706, 0.030092496740361376, 0.04408240370873002, 0.029150126239044533, 0.06966077332054416, 0.015080983754277471, 0.030556853274784745, 0.03379127266065728, 0.04866783064039004, 0.05857231711307841, 0.012962010411185124, 0.046857553383996414, 0.04543393985518525, 0.01247455441062489, 0.05013268268216522, 0.03280267449876955, 0.06813953720754193, 0.044865460480533303, 0.08990523660735739, 0.043390231777823744, 0.03809269930746767, 0.03832548278413954, 0.027793763738666332, 0.04993542270254224, 0.10735629817410823, 0.009818946052673123, 0.024575855462781848, 0.03402448131612713, 0.052864456459158854, 0.03210517442634991, 0.0293123051373949, 0.04309152643526754, 0.05423899822598023, 0.04363517306985394, 0.009620966908011225, 0.02669944544322789, 0.04667279212885807, 0.006198744419135995, 0.013185928335353253, 0.03761128965584982, 0.07736496717458771, 0.015944132145734567, 0.06888545403677611, 0.02367691065545284, 0.06162749107686743, 0.09271879410070759, 0.0785621480956193, 0.05576981809891521, 0.03523347148251149, 0.013368307057047083, 0.0519519001846352, 0.09080218767086345, 11.55492696069902, 44.396527428780836, 24.753066185982, 38.93590173413677, 43.894346375619214, 15.686242772686867, 1.4555223165981233, 0.1939886769339923, 0.05577181375795796, 0.04626730179053642, 0.7764625320992162, 3.451418540170116, 6.755325073196042, 3.5111091694524212, 5.535031585924087, 3.4813427925109868, 2.335377729708149, 0.9794660261081112, 5.339043005820244, 40.86980673574632, 56.357336351948405, 59.27006490768925, 55.93356347853138, 57.56332397460938, 57.902750199840916, 59.1332761702999, 55.161244869232185, 56.23502508286507, 56.22432877940517, 55.11674165725709, 53.14434643714659, 52.78324519434283, 51.57228792867353, 48.56229243739959, 44.06525188876737, 43.54763630897769, 50.74735072351272, 56.78558857210221, 57.208220035799094, 55.876830316359005, 54.18092296969507, 55.89694815297281, 56.16912141922982, 56.13727177343061, 48.797081593544256, 43.66063979364211, 43.097748294953384, 42.21361860152214, 43.67524670016381, 40.92475129712013, 44.280382125608384, 54.029499869192804, 54.60117355469735, 55.16310799506403, 54.84997341709753, 54.92218032959969, 54.24701098472842, 53.94884809370964, 48.536899012904016, 45.97406548838462, 52.032978150152395, 53.22601018413421, 54.58844154111801, 54.090786903135246, 52.501807289738814, 51.62414950709189, 52.919520101239605, 48.35704657339281, 44.56961770211497, 41.16068578535511, 38.74779662778301, 38.96897908179991, 39.67324456860943, 38.258857496323124, 38.99527465143512, 39.99306286534956, 41.22403598600819, 44.73840513537007, 47.278449689188314, 49.236226235666585, 47.82336496537732, 45.77089063582882, 41.90071936576597, 40.74760529302782, 39.77568118802963, 40.55864118760632, 39.13867650493499, 36.61159146216608, 39.83540319627331, 42.70869231993153, 44.99034289390811, 44.401842240364324, 42.793831286891816, 42.10095244069254, 42.81842847024241, 49.50757972655758, 47.9161564765438, 51.60366296768189, 50.4748950466033, 47.75850072983773, 42.735854733374815, 33.925528833943034, 7.388737845805384, 0.638978677170892, 1.897018419638757, 2.8684677952720277, 5.857324898242951, 6.106022779018649, 6.924386582066936, 6.71914218894897, 4.035181951138282, 0.393146087806071, 0.12396852410728894, 0.08265368580337494, 0.12230322516012578, 5.192439517667217, 33.33613387999996, 36.485950100806456, 26.66467643553211, 30.83149067817196, 2.210057022110109, 0.02437887319003142, 0.04994249369408335, 0.042165931344272635, 0.09927851388291006, 0.11229686048482695, 0.0567919479292487, 0.03573293399606501, 0.003031027830025602, 0.06949037238354645, 0.022908216117010004, 0.09610661110209842, 0.04113614063469633, 0.04683631742673536, 0.03000012568889126, 0.04545340997978084, 0.03807893270746835, 0.05754417732297894, 0.026289429440493547, 0.035075488830766374, 0.05028012779451186, 0.026379946559186906, 0.06390235086362209, 0.004431984787281122, 0.07457715023549334, 0.18676655156718147, 0.10723350194072533, 0.11080105849091085, 0.14579433076564344, 0.10925826466371936, 0.12419736989203001, 0.1740519281837248, 0.16808693777889977, 0.08769856630674294, 0.12268838352493702, 0.2583533158946422, 0.07612170606491066, 0.17588491611663373, 0.1345539976271891, 0.17013826077022862, 0.05165075485204017, 0.10303245962507303, 0.16498578321789542, 0.16426610490006788, 0.13819308380686468, 0.19957572552225283, 0.13085534045052144, 0.1478176302607021, 0.18960858454867718, 0.19465439201843357, 0.2219476992444646, 0.22894765911323411, 0.16466920504406576, 0.1021658686260062, 0.15570157898529885, 0.14251313022067472, 11.127936763148154, 51.01799818777269, 35.84905524407664, 44.05373580994145, 48.61203201355473, 20.64332635171952, 2.715701282985749, 0.46610385840458257, 0.2531149292424802, 0.7777830225325401, 5.959043233625351, 10.086459229069373, 9.17867862409161, 9.83824085804724, 10.970004489344936, 5.819769674731839, 3.5764443345608252, 1.1918148734877188, 4.3440896849478445, 37.82729871811406, 60.0115458426937, 62.008463721121515, 59.62758110415552, 62.60450709250666, 60.93405592826105, 59.640277816403305, 54.33662145368515, 57.52448074279293, 58.8546270708884, 56.43491691158664, 56.383471104406546, 56.526900414497625, 53.01941502478815, 50.56801995923443, 45.91470433819679, 45.9043885046436, 53.0325431977549, 59.21956439172069, 58.000413294761415, 56.985052862475, 53.16174214886081, 56.98213069669662, 57.29517506014917, 57.94819870302754, 51.93505617880052, 46.1337883241715, 44.04474965987667, 44.361312389373786, 47.05731430361348, 41.84549631610994, 48.04308437531995, 56.98561376140964, 57.29011912499705, 57.45516853947794, 56.74559216345511, 57.132879149529245, 57.149333492402114, 55.10743387283818, 48.294920152233495, 47.558648124817886, 56.775849326964355, 52.943462248771425, 56.60478691900931, 57.26233305469636, 55.56750435982981, 53.72897178896012, 54.22867782654301, 49.4558907324268, 45.07254400560933, 42.09640641366282, 40.709542612875666, 41.31980457613545, 40.330947599103375, 41.180936982554776, 42.28522539138794, 42.16672274374193, 42.85761687063402, 46.32517253198932, 49.93889924018614, 50.29299905223232, 48.42846508949034, 45.97566189304475, 43.87518951969762, 43.078650274584376, 42.36347275395548, 45.661362371137066, 41.89422784313079, 38.38681697845459, 40.53884106297647, 44.282139347445586, 46.191286348527484, 45.48545191364904, 45.53705461563603, 43.93506057800786, 46.25438551748953, 53.429369388088105, 50.940668659825484, 53.17060278308008, 51.57246835770146, 48.527610840335974, 41.96192795230497, 31.348288443780717, 5.882446698604092, 1.0685464235082751, 2.519836747838605, 7.67732132827082, 6.968744176049387, 8.661457242504243, 19.277588436680457, 10.167393415204941, 12.228867623113818, 3.319121652072476, 0.2802027870089777, 0.2842199682228027, 0.410671268379496, 8.764577334926976, 37.76359550414547, 42.012248039245605, 34.16739002350838, 36.43088786832748, 2.6134159199653135, 0.1518459963582216, 0.2271633024417585, 0.14338201182263513, 0.17158270422970096, 0.26524639117621607, 0.21618939936161044, 0.20524693652987483, 0.16202866850841433, 0.08811567819887593, 0.06809428439385469, 0.22357182096569772, 0.16013212592130707, 0.15812266197416092, 0.1315362700411389, 0.1246812233641263, 0.15223680845191404, 0.16682119198864506, 0.13136619852194864, 0.10629377252752743, 0.15570813669793068, 0.13344856339596933, 0.29620581216389136, 0.08262553207215764, 0.29163827338526327], [0.018974565300008944, 0.03130409735134773, 0.02656852676262779, 0.029866814898747592, 0.12551064377710705, 0.02673175711665423, 0.059091533203759504, 0.05878752653276729, 0.06057669040596774, 0.05216679167783549, 0.025481126241145596, 0.02380601562289221, 0.035859817308523965, 0.046393273458365476, 0.06658656973271601, 0.022413440146333268, 0.08249368834038896, 0.01909610131875642, 0.04062054430945747, 0.060195469733087294, 0.03215998418689255, 0.04368357067447036, 0.04613792486188393, 0.016082849601403843, 0.028245219352444815, 0.03862999124272216, 0.02758693532086909, 0.01768607435928237, 0.017585291662403656, 0.047715361185011365, 0.10204925472217222, 0.48737622016379917, 19.768896679724417, 38.393116304951334, 33.64432627154935, 38.63409103885774, 35.61190089871807, 15.018774021056393, 2.6710137196125525, 0.1306079553380128, 0.06722852076974607, 0.5813322769057366, 3.5726631697147124, 5.773728403352923, 1.9560974043223167, 1.9633422671787202, 1.5441732757514524, 2.243096616960341, 1.1394319875586418, 0.5057045979605568, 10.827148825891557, 35.83506022730182, 51.13002500226421, 59.32682160408267, 58.73195886611939, 58.29022153731316, 56.46782951970255, 54.13265820472471, 54.765336513519294, 56.21992788007183, 56.042421017923665, 56.38859371985159, 53.30939585162748, 52.504764756848736, 46.47105332343809, 42.49117728202574, 42.49011824207921, 47.96173049557594, 52.05364511859033, 57.225855012093824, 56.50406045298423, 54.61672575243058, 52.6806281458947, 55.20690910277828, 56.243983776338645, 55.40029764175416, 48.35543840162216, 41.557664948125044, 40.07157302671864, 41.60820076542516, 40.212778352922015, 43.698749542236335, 52.38641508163945, 56.789456029092115, 55.60386080895701, 53.16840625578358, 55.269427760954834, 53.97141741168115, 49.787735016115256, 51.447952716581284, 44.13175959740916, 50.34994010002383, 54.55672133353449, 53.369910178645966, 51.37372186107021, 47.49259148874591, 44.62343654324932, 41.65461024930401, 40.3386942801937, 38.05904803737518, 39.26651047122094, 37.62970932068364, 38.0978951915618, 38.60015076975669, 40.25826607981036, 40.264941953843646, 40.12638422750658, 38.86465972469699, 38.54494733195151, 40.53719758987427, 40.39374082319198, 40.033714309815444, 40.17819873748287, 40.93124674212548, 43.07469260308051, 47.44351087077972, 48.58740345124276, 48.353661567934104, 45.2910239465775, 38.06213494270079, 33.76647280108544, 37.2774608673588, 38.68668610049833, 39.22272505298738, 39.02910117180117, 46.071567766128055, 47.261850218619074, 49.336619300227014, 52.96495683731572, 50.73756048756262, 46.87529279339699, 27.658742320153024, 3.6356289780909017, 0.1378582114534032, 0.17148698920444136, 1.6018701152455423, 2.35030994780602, 6.792106609190665, 4.470538564266698, 7.141622641394216, 13.47896327895503, 2.3918034761182727, 0.5831182423618533, 0.14526842672738338, 0.11636963669931698, 3.9369726661712896, 21.712587994913903, 35.76379076127083, 28.362131157229026, 28.68514422447451, 12.53130687821296, 0.14203852342982448, 0.05735176284947703, 0.052515419139977426, 0.018930944253600413, 0.018869151601627953, 0.015810797415343265, 0.029202948001423673, 0.05428058147851018, 0.07206737724763733, 0.05953539305576875, 0.09141917190244121, 0.046165412096607114, 0.06136498338873349, 0.054843211771860245, 0.11382102305369993, 0.09603600843899673, 0.03477529727763707, 0.00992081659440432, 0.03843529765764552, 0.05725711268643218, 0.03362938296049833, 0.022253126672078526, 0.031122808389726187, 0.05335109466085992, 0.03230238077981818, 0.003805646382745416, 0.03597505608453386, 0.027842036853995056, 0.05315019193315699, 0.05417502988430281, 0.012503702140923952, 0.007298950579077487, 0.010876402112415001, 0.042742266950588075, 0.0531273931565304, 0.04462872015973253, 0.04813781270997659, 0.009553779081832017, 0.08853411542311793, 0.08856441420052322, 0.03213743821928098, 0.03815682852760919, 0.06391127961837957, 0.08431044287018238, 0.05233771355462171, 0.00830840165426414, 0.03694335674686778, 0.03285173476944047, 0.030629512883963126, 0.07727848350881569, 0.0300323837361629, 0.03199124374547072, 0.060080215635318915, 0.04249335732311011, 0.16363866356832368, 0.07651940528904239, 1.0676075061482768, 27.452515863603164, 39.30523603193222, 32.905869483947754, 44.74754425787157, 39.55680116530388, 13.799867091640351, 2.385569113877512, 0.13196671952403363, 0.06656868157968407, 0.04837708495136711, 2.1070697999769643, 6.205804444128468, 3.8895183609377955, 4.5770191473345605, 3.4537653432738398, 2.8054625180459793, 2.3506161378275965, 1.0691760864949997, 13.220677164293106, 41.91154510744157, 55.789902748600134, 60.04008893043765, 59.77572510319372, 59.187612764297, 58.357364669922866, 54.62534319969916, 55.82828314073625, 57.349040969725586, 56.32523567445817, 59.62190935688635, 54.9458400664791, 54.03170031885947, 48.36719766739876, 44.732870671056936, 44.41716301825739, 50.6504132670741, 53.93024429198235, 57.041260427044286, 57.16354031716624, 53.14236564020957, 55.01224971586659, 55.29142049051101, 57.32304350022347, 56.66397156253938, 48.11608752896709, 41.5387277449331, 41.0337382747281, 43.648711865948094, 41.36566100582, 45.22252759625835, 54.203751164097945, 58.68274096519717, 57.434423123636556, 54.17167009845857, 56.481526436344275, 55.12700257762786, 49.96790124524025, 49.71783053490424, 46.30179128339214, 53.74681857324416, 56.30277618285149, 54.9824514696675, 52.71273666812528, 49.74970763729465, 46.80586291897682, 44.08904106386247, 42.5381790438006, 39.161704740216656, 40.19675154839793, 38.59203538587017, 39.824091080696356, 40.3342306229376, 41.686722693904755, 41.25495210770638, 43.248481058305316, 40.397623969662575, 41.4000758817119, 42.413365302547334, 41.71660723224763, 41.08028896393315, 41.44705410926573, 41.93888010517244, 42.8222841601218, 47.41824688449983, 48.73568865560716, 49.72829934089415, 45.36360348424604, 39.48975216957831, 36.07263034389865, 38.989006703899754, 41.221141276821015, 41.582677902713904, 41.1709310162452, 49.058319291760846, 48.401883186832556, 51.2675158439144, 51.81231344899824, 49.75258665700113, 47.792719487221014, 32.33345643166573, 6.9909957820369355, 0.7701542576955211, 1.3523361567528018, 3.1893647438095463, 3.064896906575849, 7.894559348783186, 7.189082830182969, 14.43948603445484, 13.046893612031015, 1.764199611160063, 0.3298876644863237, 0.09967574579340797, 0.22781974786231596, 3.1508627581980924, 23.72771743805178, 40.26418885877056, 32.20070185199861, 31.72001538738128, 17.66096199712446, 0.18809819624068277, 0.07403662923963801, 0.1555261601723971, 0.010866081950465038, 0.012507512470737342, 0.04358158521955052, 0.034205159322629054, 0.035240760809111024, 0.013620247519875487, 0.04975752942564507, 0.004233070057741697, 0.050830680711735646, 0.04523484892542324, 0.06661643950088371, 0.05129216058600334, 0.12819932127792028, 0.030953443586646073, 0.03380154589972189, 0.031113864313210213, 0.03794860966022938, 0.03879977547894082, 0.017716486134656498, 0.0510266651549647, 0.04385080000746154, 0.022741465588971492, 0.1596213597804308, 0.12917892556757699, 0.13420607113549787, 0.15532990376795494, 0.35201847372997197, 0.05917130976975445, 0.13185724555965395, 0.1975699387971432, 0.08343119609860644, 0.1417075734465353, 0.09384326561684571, 0.1822687574331799, 0.09014938116794632, 0.21538074759225692, 0.22092923131440917, 0.1740294818075434, 0.1165984748231788, 0.09426194798922348, 0.12616945640935054, 0.15155869806485792, 0.21568322974827983, 0.10323654544810135, 0.1102507622131417, 0.12737059800495065, 0.11715385792476517, 0.09344831664836215, 0.11459196031454111, 0.10877095613508456, 0.15088109329583185, 0.2887858216079974, 0.2939679774065172, 1.0732453004006417, 29.08575942439418, 49.766036464322, 44.439799016521825, 48.59989620024159, 44.32148072027391, 18.759904215412757, 4.254855273231383, 0.22344347059486375, 0.20465042982851306, 1.5020404011011126, 12.606346722572082, 19.84832859808399, 8.44187903788782, 7.311372526230351, 6.214417478730602, 7.9428133272355605, 3.6175760242246815, 1.046036308811557, 12.128324527894298, 38.97234839777793, 54.33099677485805, 62.787995569167606, 62.673897743225105, 61.32810900288244, 59.456044089409616, 55.74177526658582, 56.83232361270536, 60.34828132198703, 60.368434459932395, 63.18408435390842, 57.048944350211855, 56.324494346495605, 50.84745353268039, 46.290267359825876, 46.74099083869688, 51.88127263899773, 57.57310244344897, 60.292968057817035, 59.79366994673207, 54.703402288498424, 55.906122576805856, 59.27520321261499, 60.92289678512081, 59.33210895907495, 53.69616900720904, 45.12143242743708, 44.58223596695931, 45.3939861636008, 43.05853243797056, 46.428919223047075, 57.27346866361557, 60.051914876507176, 58.88233861615581, 55.076062756199995, 58.57421682726953, 55.527864886868386, 50.52702334619338, 51.07448816299439, 49.66709467672533, 52.56700492674305, 57.587281811621885, 58.479546500790505, 56.08810878569081, 50.99844125009353, 48.506077028089955, 45.55612125704366, 43.686256793237504, 41.62331758006927, 42.60782857095042, 39.789170219052224, 41.49742910938878, 42.50285025565855, 43.690638080719985, 43.72129924835698, 45.048715606812515, 41.886649823957875, 42.64233758372646, 43.767787179639264, 42.464403183229514, 44.206104201655236, 43.53053085265621, 44.78578344468148, 44.806187614317864, 51.19394786896245, 52.34891722279211, 52.090240832298036, 48.71901466000465, 42.18258873108895, 37.097224035570704, 40.787421272647, 43.388172349622174, 43.903599246855705, 42.66674649330878, 51.5939276449142, 50.84324090711532, 53.96602023032404, 54.758527278900154, 50.49402836830386, 48.98636733331988, 29.883971560385923, 4.5745480541260015, 0.583661490630719, 0.970045718694887, 4.342022105570763, 6.74315837121779, 16.122594687246508, 10.246056549010738, 14.362182982506292, 22.971219708842618, 5.018851103321199, 1.0810062000828407, 0.3301434459224824, 0.5107710744825102, 5.215019622156698, 27.253996864441906, 46.26568586595597, 39.14081811904907, 39.57770347595215, 21.399535786721017, 0.22356602934099015, 0.1296467294976596, 0.24553936155092335, 0.11919760430652289, 0.1395202238833712, 0.10935109153750444, 0.1519558840100804, 0.12526548798045806, 0.20442625718011012, 0.15556135425163856, 0.2343076698842549, 0.15264657356085318, 0.1172092384208114, 0.15953485313202106, 0.1345360864915194, 0.2481921401716048, 0.13920663345244624, 0.06727607184720617, 0.16554161065047787, 0.19364321724541728, 0.12179471897862612, 0.10878629321532865, 0.10090599873013074, 0.1699408705556585, 0.07596724741761723], [0.05207310678557523, 0.07934102968823525, 0.06302236481719921, 0.016033668671884847, 0.019719911393739527, 0.030705384316764055, 0.06882553063933888, 0.015537421812393494, 0.009908971917485038, 0.08796693456749763, 0.03872020575668543, 0.07260825830481707, 0.021649370863733274, 0.037602621370986584, 0.04617119606043543, 0.06799042585395998, 0.040149568775368315, 0.03100741065047201, 0.06371583143669753, 0.048860191487737244, 0.011201851584407832, 0.05043147229439309, 0.05181618387840929, 0.05904767467009445, 0.05917259296702762, 0.034084270648177595, 0.04500069415136691, 0.02004496633045135, 0.03962264584016897, 0.0510196669417764, 0.04403910058881006, 0.07575887150221294, 2.843259212470824, 27.232257127761844, 34.163373516451934, 23.93609139227098, 35.065918737842196, 36.14845760406987, 17.952486276626587, 3.176126254181708, 0.035396403062247464, 0.1252475615230299, 0.4334301471469864, 3.7314061484029217, 2.057838661055411, 3.5411883554150982, 3.402120475807498, 1.0480781476343832, 0.8033286227333931, 0.2040927944284293, 1.0505364931398824, 15.479362260910774, 32.280590726483254, 47.7620465524735, 57.05977401425762, 55.68743475021855, 54.35457021959367, 55.262846023805686, 55.936877881326986, 54.83797488674041, 55.52847677661527, 57.01918140534432, 54.47870146843695, 51.522434603783395, 46.83357054187406, 44.96147817181003, 43.7439509361021, 46.99408177406558, 49.45074458276072, 54.37964985447546, 55.791310879491995, 55.104841186154275, 52.88253607288484, 54.697106884371856, 57.36711132910944, 56.561734983997965, 53.821225935413, 46.9338341682188, 41.00676413505308, 40.442103647416644, 39.88608414126981, 41.33207375003446, 51.69847449948711, 55.911492301571755, 55.55470174358737, 57.226835604636904, 53.57035898393201, 56.10476709181263, 52.33217262452649, 51.00176741999965, 48.25445698153589, 58.3592434852354, 53.54591477301813, 52.48820058761105, 50.50679568321475, 43.33817389703567, 41.79921234807661, 39.16449746777935, 38.744188047224476, 39.99536137427054, 37.16865431877875, 38.383027968868134, 37.58686134892125, 39.37326954257104, 45.13018715766169, 44.2649515213505, 43.057438096692486, 41.03416189070671, 38.6584097339261, 38.23327187568911, 39.68320346647693, 43.53224492842152, 44.446584716919936, 46.191517768367646, 49.212103659106845, 49.397357202345326, 51.72578596299695, 50.71472052604922, 49.788633238884714, 47.42850780487061, 39.604077492990804, 37.69032955169678, 40.11240097784227, 40.40176207019437, 44.92223878060618, 47.01295621933476, 47.2603871745448, 47.8359204722989, 50.242322029605994, 47.93498777574109, 26.680875824343776, 3.1930966338803692, 0.26949499223020773, 1.7913539347148713, 2.437368424669389, 2.117226287241905, 0.8364835597815052, 4.784683152552574, 8.304499003194994, 8.919303071114326, 8.102304743182275, 1.1760161793039692, 0.0873091867974689, 0.11789301785850718, 1.8369447463943114, 15.184205866629078, 28.267625570297245, 36.26783886263448, 25.46713955940739, 26.405392077661332, 2.717058913361642, 0.10285029923843761, 0.030065999674280326, 0.01753029229509975, 0.0720343511972216, 0.061005952452579816, 0.06651487922476185, 0.019204985395434405, 0.009891406478991192, 0.07061256861854946, 0.07836288096563471, 0.061880648661885536, 0.01135088154114783, 0.11759834979931194, 0.02983752735740235, 0.03074016853896601, 0.012250041810705537, 0.01969851455801437, 0.04646446217872924, 0.039624974747458776, 0.02935313570853924, 0.02257189394215182, 0.019259509788225257, 0.06007389157950398, 0.03156142820033335, 0.05303558517968463, 0.007130784224793916, 0.04545049501522895, 0.03148006583233515, 0.008657843084825624, 0.03763673909669442, 0.007714952122525222, 0.05571126982930207, 0.050537188597504175, 0.015924209071653747, 0.031898031912503705, 0.08445882644023626, 0.016898122285642934, 0.038864831665470716, 0.07143894000159157, 0.07814311332279637, 0.05043504609455986, 0.036768110303749005, 0.05718082182049271, 0.08010318758146417, 0.02974050615223185, 0.0020689164399124325, 0.03490322246967304, 0.035410583349725896, 0.04180821807934873, 0.05444269717460679, 0.09738613115323168, 0.034083443273219376, 0.013989285479540066, 0.023276160486162673, 0.019710982638982036, 0.039962727591515555, 0.04346220190787027, 5.399850039712844, 35.81413046006234, 40.46288436458957, 28.903908537280177, 43.24491562381868, 42.66494612539969, 16.682377707573675, 2.7446932369662873, 0.015307565749202286, 0.10448640257480646, 0.23707234330715674, 1.2692993350567356, 2.8450892433043453, 4.1315163431629065, 5.5328806561808435, 3.45495161510283, 3.0400418273864256, 0.9334215678034291, 2.380916447408738, 17.72278247341033, 36.9307311888664, 52.86581500884026, 58.495730200121486, 57.31739528717534, 54.70627738583473, 54.14065983987624, 56.582245057629, 55.830801302386874, 56.37601467870898, 57.97749880821475, 56.161049181415194, 53.219495127277995, 50.273128324939364, 45.171301441807906, 45.00025472333355, 49.39208945920391, 51.609377861022956, 55.6765737072114, 57.33669334842313, 56.04989313310193, 52.35118043038153, 56.9652174365136, 58.62280714896418, 58.13044771071404, 54.30986304436961, 47.90258115337741, 40.865805918170565, 43.524180535347234, 43.585169469156575, 42.999853780192716, 54.46127045539118, 57.8883158776068, 56.91709387686945, 58.35045737604941, 55.0380628339706, 53.60976703705327, 50.779392565450365, 50.689750717532256, 50.38329985833938, 59.5733464917829, 54.67634185667961, 54.18538270458099, 52.080689860928445, 46.595004143253455, 43.49815560925392, 40.905119834407685, 41.36935587852232, 40.45642814328594, 39.81347322463989, 39.34456171527986, 38.4034635174659, 40.45824027830555, 45.513332120833866, 45.27362431249311, 44.83529160099645, 42.24266375264814, 40.35607430242723, 39.97902470250284, 41.2530223015816, 44.071661041628936, 46.49458362210182, 47.45078294507919, 50.605054978401434, 52.815526300860995, 53.807933022899014, 51.31412536867204, 51.81910699413669, 47.69723723011632, 39.91669824046474, 39.23990503434212, 40.897577116566325, 42.337769462216286, 45.84885166537377, 48.7419605255127, 49.054361620256984, 49.952878567480276, 50.6737905933011, 48.42864944088844, 32.01020213865465, 5.794110999953363, 0.6206475414576069, 2.755180919362653, 5.341325825260532, 3.517195217071041, 2.836486259775777, 4.1218432880217035, 9.180265222826312, 10.275547869743841, 6.275872193997906, 0.4975724827137686, 0.05690747781866982, 0.11633940686982487, 1.7572800598798262, 15.850465547653938, 33.56517676384219, 38.76807135920371, 28.480767165460897, 31.540568913182906, 5.461110107360348, 0.04960631899115059, 0.051906842723368644, 0.022319852930283355, 0.0716595656629051, 0.009645999788546996, 0.05528458949899482, 0.008954563302048033, 0.02881533240959529, 0.06717986652567502, 0.05088150681507203, 0.09772026806228584, 0.06839845960419025, 0.0775581822099705, 0.03136974342557932, 0.04774829913531581, 0.08491387500637963, 0.049649871089645935, 0.036107853595768256, 0.04336005174404672, 0.02471544242824518, 0.02200916597259141, 0.0387185548372086, 0.02992454919994118, 0.015223460786435154, 0.0756783250178541, 0.11090473316970373, 0.15428442357768937, 0.1847398353199805, 0.07986049092705212, 0.12704168581554007, 0.14147319650698092, 0.12999283270009104, 0.12003782655923598, 0.09812669302787512, 0.24444612343945812, 0.13969642410595573, 0.09705085277317033, 0.12553713509752867, 0.16545778530980312, 0.15303361650195815, 0.2139517331435796, 0.10700104022098166, 0.167061896814454, 0.22443342473237748, 0.1173426985981003, 0.12734846572481817, 0.10018760744001597, 0.18947556104150512, 0.185281781239375, 0.12387565126822841, 0.1930216135036561, 0.19170365116048246, 0.08533440365065491, 0.13873568856187407, 0.12659907085640779, 0.0952444404303547, 0.2101878512410387, 5.206399723406761, 39.54653632256293, 48.464499904263405, 33.210013989479314, 44.75978989754954, 46.46342431345294, 23.692414145315848, 5.019874841936174, 0.24592818181601264, 0.4122597363687331, 1.6357672382746975, 9.58296614308511, 7.3097780827553045, 9.319247545734529, 8.95362969367735, 5.916339408966803, 3.6946143161865974, 0.5978312367393125, 1.8140171444223774, 17.40396830343431, 36.25947244705693, 51.13733630026541, 60.94550924916422, 58.844577958506925, 55.6250023841858, 55.31091859263759, 56.52310748254099, 57.000557991766165, 59.26361653112597, 61.109731043538744, 57.271291748169936, 55.19411040890602, 51.40226102644398, 48.72583958410448, 49.06628170321065, 51.864418214367284, 52.587683662291504, 58.89028141575476, 59.285036594636985, 58.353018683771936, 53.843410861107614, 57.5478345347989, 61.300828918333984, 61.700875374578665, 56.5313679941239, 51.286586407692205, 44.363528528521144, 45.023149598029356, 44.63894951728083, 44.01476706227949, 56.8643379980518, 60.581234808891054, 58.88890858619445, 60.951451639975275, 56.82599682961741, 57.01831456153624, 52.83691106304046, 51.191543456046816, 52.346630480981645, 61.8643166172889, 57.183795436736084, 58.0795745695791, 54.651383815273164, 47.87692100771012, 45.55745094053207, 42.53087559053975, 44.25112516649308, 41.991992919675766, 40.77405383509975, 41.41205872258833, 41.29590557467553, 41.581069730943256, 48.67411528864215, 49.29563837666666, 48.103441807531546, 46.210003898989775, 42.01509567999071, 42.40217085807554, 43.454825185960345, 46.76671374228693, 49.201728990001065, 50.761922328702866, 53.470389535350186, 53.0653852032077, 57.18178326083768, 53.44573743881718, 53.75247855340281, 50.93755429790866, 42.409066384838475, 41.78869255127446, 43.54836194745956, 43.98253694657357, 48.824036121368415, 51.37240786706248, 52.90448565636912, 51.18992351716565, 52.0108324481595, 49.278034779333304, 31.678446108295073, 4.395055492078105, 0.6281873788083754, 3.8053286075592045, 7.524622967166286, 7.245071232318879, 5.328282473548766, 10.943872678664423, 17.978966197659894, 15.888147757899379, 12.148332538143283, 3.520513051940549, 0.31083413850395913, 0.34252692013978964, 2.66656379065206, 20.170190449683897, 38.184508969706876, 47.303156698903734, 34.57348869692895, 37.83104065925845, 5.96327547104128, 0.27878071331689436, 0.12095722399892346, 0.09065156712407067, 0.2761340940431241, 0.15196048053762606, 0.18273305268056933, 0.12869546280032204, 0.08629183735578291, 0.1785329143486677, 0.24777396341725705, 0.16423633472333032, 0.13347378301043666, 0.19858719630827829, 0.10760548359323895, 0.20624324919716006, 0.2671301400949878, 0.24427764538315036, 0.15387611403580637, 0.1777257334681288, 0.13700265978132525, 0.08486265436776223, 0.13580402329323754, 0.13768162818685656, 0.16147895445746763, 0.16177141618344093], [0.011896892514590536, 0.062301809328698346, 0.011995707323113758, 0.09183045386547044, 0.08276889010542825, 0.07556839140071984, 0.05642668103739139, 0.024012880429865855, 0.028791987795322656, 0.00653005590016443, 0.105062362798039, 0.011505311460144097, 0.07058700426451622, 0.012271661769538637, 0.039235526290271557, 0.050705743262604366, 0.030492151403919827, 0.005949064873294124, 0.031534553835949594, 0.07202833740701599, 0.028071535728691567, 0.00828862892493846, 0.04351533393585875, 0.026495091489426074, 0.064768060861576, 0.049927049361529856, 0.03212517698205287, 0.05369640496228972, 0.020333218403280746, 0.052850283832559665, 0.022123632915017587, 0.05440041295162613, 0.08292545549451344, 8.222259158088315, 29.429604199624833, 33.09171138271209, 27.905935971967637, 34.86719969780215, 38.92941805624193, 15.96992035065928, 3.0102587803717586, 0.0910740033272774, 0.03074159537772498, 1.3893310941996113, 2.3122835495779595, 3.2665815036143027, 3.1348212447858628, 1.4524323469208134, 1.9691946886239515, 0.9329381356796912, 0.5891925228699562, 2.33933687210083, 10.169274191702566, 25.195101614921327, 38.971795343583636, 48.31919570122996, 52.92043401348976, 52.95238171854327, 55.35874797451881, 56.603880851499504, 56.69665275081512, 58.516624666029415, 54.92367475263534, 51.71104177351921, 46.549312453116144, 42.62163923632714, 43.54121931137578, 45.084424864861276, 50.50247715365503, 53.846886081080285, 55.894535895316835, 58.00330800394858, 55.75471908815446, 54.478842673763154, 56.54752031449349, 56.37267281932216, 55.297704127527055, 51.275317438187145, 43.30391983832083, 41.529706293536776, 42.66224753472113, 39.35836453591624, 44.43289172264838, 54.013343626453036, 54.26441454118299, 54.58836309371456, 56.37142942797754, 57.665760594029585, 54.35753945381411, 52.88490126209875, 48.38803722012428, 54.619039950832246, 55.68233566899454, 53.77254932157455, 52.09537129248343, 47.930461360562234, 45.067025230776885, 40.90842639246295, 39.10974510254399, 41.046136886842795, 38.321250638654156, 38.485982341151086, 38.95369752760857, 45.2649833310035, 47.141347162185184, 47.28105414298273, 44.941250508831395, 44.49171158575243, 38.4142892591415, 40.23787367728449, 44.003290207155295, 47.00875536088021, 48.08934480913224, 49.06695635088029, 50.2758151485074, 51.855714474954915, 51.25131645510274, 52.13836046957201, 50.95349873265913, 47.6489410861846, 42.295960918549575, 40.608651407303356, 43.36665814922702, 44.447479017319225, 46.254220777942294, 45.72321814875449, 49.433137063057195, 50.66431806933496, 50.4861875503294, 31.591179255516302, 6.561890446370648, 0.26682517581409027, 1.1803405924189476, 2.264975352633384, 4.568529177096583, 2.11119270132434, 1.9912684396389995, 3.313479567727735, 4.617562726620705, 9.758586345180388, 3.7124208961763694, 0.24444731853662, 0.04033853202277134, 1.5724926658215062, 12.781086352563674, 29.57775212103321, 41.17624582782869, 29.70722956042136, 28.91017060126028, 13.205781963563735, 0.09946289592452588, 0.08085566978420942, 0.06316616335102627, 0.03794051211086973, 0.040778661026589336, 0.03451453626997048, 0.03177031164898748, 0.03687022599361597, 0.01855607636483206, 0.06660235880483543, 0.11931272433890451, 0.04489131211753815, 0.0482573147652851, 0.04557031499702604, 0.04352587530569684, 0.10939673505603306, 0.06361749639073688, 0.023811516134188544, 0.02213937985230117, 0.04481316731882192, 0.03483075438247573, 0.05360404923257809, 0.05166773136044222, 0.025229834080223116, 0.11011033829662109, 0.03839155786760873, 0.010580995735982734, 0.020218571430192362, 0.02028164344899837, 0.027135276693790674, 0.03457324541804772, 0.01812699243366238, 0.05281850267502089, 0.04723343825448425, 0.06357668305657084, 0.012482292856270028, 0.09197689157219664, 0.0181000069865296, 0.06398847063763008, 0.029997733579347693, 0.07494954557548608, 0.06545826011607725, 0.008417254129815246, 0.03869578670409899, 0.06756452693333549, 0.024582537664701382, 0.0510043298615323, 0.06692580112646665, 0.024006648304601832, 0.07113366928552428, 0.01682529413712121, 0.1436051272697026, 0.03634159468234547, 0.014813226448642391, 0.04503151769900034, 0.04366279053952425, 0.02409256889574951, 0.07682853708824805, 0.10760764396118541, 12.976969518969137, 37.73172232412523, 31.061469047300278, 29.62216119612417, 43.18721755858391, 46.14931306531353, 15.92779213382352, 2.4361071375108536, 0.04832923126917693, 0.05994597787878687, 0.31920564090532644, 1.3528648187075893, 2.6895790330825315, 7.341732161660349, 8.51020182332685, 4.773352896013568, 3.0058995562215007, 1.6413801499912817, 4.0235141256163205, 14.03719598247159, 28.337273136261974, 42.792026996612556, 52.29362749284314, 53.97867379649993, 53.562490709366344, 53.93118958319388, 57.60000205809071, 60.6570856032833, 60.45872742129911, 57.01322724742275, 54.53929816522906, 47.9020437886638, 44.91400964798466, 46.473489115315104, 47.864192916500954, 53.02059173583985, 54.9979095305166, 57.195386040595274, 58.45177219760034, 55.73160063835883, 54.694933891296394, 56.88803695863294, 58.871442271817116, 57.07724817337529, 53.41407998915642, 44.179738029356926, 43.11832504887735, 43.95737101954799, 42.09560625014767, 47.05032463996641, 57.382239910864065, 54.97932141826999, 56.312978267669685, 56.26721989723944, 58.98517139496342, 54.583185565087106, 52.234007466223936, 49.30200046108615, 56.945503604027536, 57.391798726974, 55.67988811000701, 51.235917229806226, 49.77730151145689, 47.5171180694334, 42.44548559188843, 41.21482626084359, 41.71809381054294, 40.20459236637239, 40.72302772152809, 41.04443850055818, 45.73000777152277, 49.03943307938115, 47.92690377081595, 47.08131136432771, 45.4211760336353, 40.511957137815415, 41.51473068421887, 44.81604845293107, 49.17746913048529, 49.109859235825084, 49.75130404195478, 50.825299985947154, 53.78319463422222, 51.44776052044284, 53.47000122070313, 51.857636436339355, 49.415239287960915, 43.87713109293292, 41.620124770749, 44.186366834948146, 46.205261753451445, 48.54479866643106, 49.51559705118979, 50.13732802483344, 51.346986985975704, 51.172927887209006, 36.662186115018784, 9.541426281775198, 0.9916302766050062, 1.9650804900353955, 4.284060260941906, 5.447379850572156, 3.0894543759284483, 5.3867414785969645, 5.002218782901764, 6.684267905450637, 4.021005524742988, 0.4360009543597699, 0.2435816238604246, 0.058747647825868866, 0.9330760927930956, 12.588475423474467, 32.48114935813412, 39.34534226694415, 33.452424310868786, 31.708016857024166, 19.56162687270872, 0.5092023409182026, 0.04309071438206781, 0.03783284994443098, 0.07593729337977786, 0.024051196317398743, 0.013756420606026247, 0.057895869136818, 0.044320990301428304, 0.03820235713294918, 0.050746552766330784, 0.045580867858183, 0.05746308308575423, 0.025466476724813544, 0.028959669120189165, 0.018787174448070508, 0.07660545228469758, 0.035545843833636855, 0.01184842213162131, 0.019913047905110066, 0.015367822394886566, 0.02345192020819072, 0.055821352833581556, 0.02753389139299191, 0.04958468083772929, 0.037590796803875316, 0.01977572281424317, 0.09249290541535424, 0.16016678373900153, 0.11391171254217626, 0.1356113675020395, 0.10474601445058662, 0.13688121952356833, 0.15515235523062368, 0.1641862019295654, 0.1666998896267145, 0.07038802824794285, 0.1712399105271024, 0.0896281885704206, 0.13197169909554143, 0.08939585708562406, 0.17074872559357077, 0.14076933024391053, 0.17415269938928468, 0.10241401216555988, 0.07586862125824537, 0.1175418584757755, 0.2533385043423022, 0.18557068831737966, 0.1525459249293612, 0.15340176771485037, 0.10598855543761485, 0.29321586292597557, 0.15192758472215745, 0.14443501499631714, 0.0869776928917535, 0.21861055895926493, 0.1371346567306788, 0.19130874815727436, 0.18219692902939935, 13.585227151070873, 44.58440896003477, 43.757298761798495, 36.743014397159705, 44.542416064969956, 49.8030440268978, 22.054202902701594, 4.06090313869138, 0.13913627593748032, 0.16988460905849936, 2.6361698344830544, 8.479781881455454, 8.539760804945423, 10.985285062943737, 8.037312050019542, 4.8209160470193435, 2.768494914616308, 1.577420511072682, 3.1268696198540353, 11.900924136561732, 26.88429778622043, 42.08818512578165, 52.343492584843794, 55.29642151248071, 55.309079001026774, 55.26300291861258, 59.60396843571817, 60.79915385092459, 63.197263517687404, 59.35664730687296, 57.752048815450365, 50.01488339516425, 47.01510960055936, 48.443228890818936, 50.81947526624126, 55.90617748998827, 58.013604225650916, 59.39936584041965, 62.735439731228745, 57.73688493236419, 55.50338145225279, 57.44901826304775, 60.34309594861923, 58.547846732601045, 56.18741143134333, 47.50849669979465, 45.74597574049427, 45.71763269362911, 43.580160602446526, 47.453481535757746, 59.73150037950086, 57.15872756896481, 57.85690553726689, 59.63993657019831, 60.049953691421024, 55.59947167673419, 52.95903798072569, 52.90909051895142, 57.04392763876147, 59.57906530749414, 58.82093783347838, 55.254628658294685, 52.19064174159881, 50.40351575420749, 43.90196361849385, 42.266029311764626, 45.20472395804621, 42.6419061230075, 41.89050159146709, 43.40867457851287, 49.41366641752182, 51.62238444051435, 50.85643968274517, 48.94217791095857, 49.909116683467744, 40.81012002883419, 43.55713236716486, 47.27842615496728, 51.14970353341872, 51.52228947608702, 51.9734993288594, 53.149802454056285, 54.37078529788602, 55.097616180296875, 55.015591575253396, 54.61783186081917, 50.922127616020944, 46.86893855371783, 44.04729920048868, 47.36028602046352, 48.50440217602638, 50.357580877119496, 50.69903104535995, 53.06389862491239, 53.65714534636467, 51.762471891218624, 34.47979504062284, 8.066045372716843, 1.0234456016652047, 2.693772046796737, 5.792032143762035, 9.237082715957396, 5.912665128707887, 7.6662097438689205, 10.407585636261972, 15.131785350461161, 21.397529494377878, 7.034637543462939, 0.7200204833380638, 0.2689808859459816, 2.166322349540649, 16.75344713272587, 37.88373378015334, 51.808359699864546, 39.264380624217374, 38.902451761307255, 22.12734922286003, 0.6587485872930097, 0.20553136965440166, 0.2520497299490437, 0.11214485331889122, 0.11194907188896211, 0.09453351849750166, 0.2208467236449642, 0.07693801871350697, 0.11627087264411873, 0.1357097331915171, 0.17345149911219077, 0.07831896880581495, 0.1730066165328026, 0.1751913920405411, 0.11792900866918987, 0.20302004150805936, 0.13446831835373757, 0.13058773061681178, 0.10527092257454511, 0.0994426941859626, 0.13156826187285686, 0.22753828715893532, 0.10303292693870683, 0.14194290033511578, 0.21775450166915694, 0.15378999043135874], [0.045991697829336896, 0.030160642176445936, 0.04606558700963374, 0.008466964617611901, 0.0478335608908486, 0.019573504330530282, 0.05280424577875003, 0.08527363755650098, 0.051108196062306245, 0.05926064711304442, 0.027250785515793872, 0.02830141764735022, 0.04263746612254651, 0.022501170620202057, 0.08141931897449879, 0.0697161538165904, 0.06493220286023232, 0.029012354901961745, 0.048136778491278814, 0.046228185341122656, 0.0649164827360261, 0.06398800332399626, 0.016376948840315306, 0.05509772533250432, 0.02286286179667279, 0.03505048755135748, 0.08320877013067085, 0.020410706281601902, 0.03918188481381343, 0.06472033358389331, 0.03721259834785615, 0.04999435784655714, 0.009120655952081566, 0.389822093589652, 18.73164942187648, 36.07516811740014, 33.0480004895118, 23.438166110746323, 29.65146326249646, 41.26578961649249, 15.907755686390786, 3.7477261500973857, 0.02966512310048265, 0.24410467805160632, 1.035644847058481, 0.9629773012092038, 5.131543740149468, 6.9597957787975195, 2.876628286415531, 3.641747875559715, 1.0532344709480963, 0.6822004385532872, 1.4135099322565141, 5.422223729472007, 15.02159518580283, 29.09773049816009, 41.03174178831039, 53.27045456055672, 56.06601799688032, 56.90466780816355, 57.546598988194624, 55.99312074722783, 56.04800647304904, 52.45756687656526, 49.79632500679263, 47.0287908277204, 43.537300863573634, 45.591834437462595, 47.942793292383996, 51.558198775014574, 56.557706709830995, 56.87031176782424, 55.22265741902014, 54.865886472886615, 55.634337625195904, 58.5711181548334, 54.88820475916709, 52.66557801154352, 42.969702520678126, 40.33445419803743, 40.67366469290949, 40.255496886468705, 40.408335962603175, 44.811227859989295, 50.695744099155554, 53.76969383608911, 52.999709037042436, 55.850248413701216, 55.40210193203342, 57.638072582983206, 48.55624414259388, 54.53217906336631, 56.28613748858052, 53.47304890232702, 53.51623419792422, 53.00196832226169, 53.17528609306582, 47.615114565818544, 39.60867843320293, 40.068121340967, 38.762023064398, 38.28472944997972, 41.08545864782026, 47.20443064166654, 49.870799049254394, 50.6477774343183, 48.527218603318744, 45.660217039046756, 40.348257018673806, 44.02469065881545, 47.64346937979422, 50.455279273371545, 51.88811717494842, 53.100902265118016, 50.85545909020209, 51.68072577445738, 50.60227401794926, 50.805084090079035, 50.44654807736797, 48.40005928470243, 42.730543844161495, 42.55792033287787, 45.2555186517777, 47.53211721297234, 47.68108490974673, 49.345527002888346, 50.07706865187615, 50.922570843850416, 33.33867165350145, 8.056512052013028, 0.23342795579904513, 0.8060810847147819, 1.0122305034629762, 2.6548748823904225, 3.2596680810374603, 1.3801852301243813, 3.8038260946350717, 2.658937232148263, 5.11909511781508, 2.0654514912636053, 0.10063142515718938, 0.10179062343893513, 1.5701617973466075, 11.642436019835934, 31.694304250901748, 36.430115161403535, 26.531541385958274, 26.56840774320787, 24.72917110689225, 2.5994213934867614, 0.030372318015584064, 0.05301258722019773, 0.030884541638736284, 0.04308015769047122, 0.09041587251328653, 0.02017579691094016, 0.03662461820509165, 0.028135994366640528, 0.06521672025443086, 0.009871315823176937, 0.018172875354667346, 0.04051601544262902, 0.03437754825779027, 0.03789504479256369, 0.05961253044886455, 0.03190542083053339, 0.010827375358090767, 0.056970021236808076, 0.02027486740130811, 0.06920827582718865, 0.06201880112771065, 0.02173638504539286, 0.033095695468927586, 0.04225049979023395, 0.03659725354443635, 0.030120830502240892, 0.013664267889614548, 0.057005119555058985, 0.012148361833345507, 0.05376469403986008, 0.08039711253537286, 0.015248067530563042, 0.015116554174211719, 0.006233946638061635, 0.04395154056950443, 0.009814065114985551, 0.021655158658001213, 0.06891107967784328, 0.04229215199067708, 0.05789586530637838, 0.020470034045677994, 0.08036328209263664, 0.02200894763753299, 0.04331619704082128, 0.041328275486105875, 0.040869174314843076, 0.06752331140300921, 0.059548022015200514, 0.08878946018915984, 0.07627288585588818, 0.03812055809483413, 0.014453280995029115, 0.040592279495491136, 0.03181934510658105, 0.0074439293671128975, 0.022104404108118147, 0.03271336396855693, 0.015891178233188488, 0.04562335892490322, 1.053438189048921, 23.20826226665128, 42.44258696033109, 33.374600564279866, 27.119769434775076, 42.25045750218053, 46.59656916895221, 17.737618838587117, 2.5739549148467282, 0.13114613210481982, 0.17059989003164155, 0.47956387001660566, 0.8992280606781283, 8.416444428505438, 15.880878625377534, 10.546755252345916, 3.3623836790361716, 1.9514182618548794, 2.0853050581870543, 2.1770044344086803, 8.625975481925472, 19.196105118720762, 33.43049826160554, 45.31822950609269, 54.28845474796911, 54.316762493502715, 57.050583900943884, 58.39392508229902, 59.757999912385024, 58.67508842099098, 54.99855279922486, 51.400135101810584, 49.26586366468861, 45.83148341025076, 46.923879192721465, 49.00602233025336, 54.96594613598239, 58.002017544161895, 59.05923358855709, 57.29030347639515, 55.08600596458682, 55.58884205356721, 59.27525420342723, 56.958306220269975, 53.877978709436235, 45.09321881878761, 42.032428633782175, 41.540406519366854, 42.453067533431515, 43.03711629682972, 48.63915128092612, 53.38859242777671, 55.11429409826956, 55.11480008402179, 57.2638157106215, 57.36441666080106, 57.948014351629446, 49.483488528959214, 56.992497521062056, 56.484934976024014, 54.960752917874245, 54.896406435197406, 54.77881769980154, 53.406760846414876, 48.29519079577539, 42.37847974223476, 40.71361403311453, 40.599202417558246, 40.511902224633005, 41.67118618565221, 47.58961523732832, 52.37004703091037, 52.22722961056618, 50.04978464495752, 48.10172380939607, 41.33197176840998, 44.80214365067021, 49.118841463519686, 52.024474451618815, 54.093877730831025, 53.69515703570459, 52.485600056186804, 52.300899567142615, 52.181483007246456, 51.90565801435902, 52.301201589645885, 48.533902322092366, 45.002439483519524, 44.05160204056771, 47.053505682176166, 49.838423805852095, 48.797313013384425, 50.598971382264175, 51.46040624187839, 51.72827666805637, 38.36063123518421, 10.863207174885659, 1.1053403394837533, 1.8308856650706262, 1.7472843897919503, 4.168473895519011, 4.882464408874512, 4.19577653369596, 4.447324016401845, 5.852677870181299, 5.479065737416668, 1.3567781183988818, 0.15956650788505233, 0.06905579368673986, 1.0827291011810303, 12.178319058110638, 31.491957018452307, 37.599338408439394, 34.53961510812083, 28.87270804374449, 31.388598642041607, 4.671700260331554, 0.03620601244150631, 0.02103979278716349, 0.013566538053114089, 0.03384252011235203, 0.005476631378124078, 0.057495611179019177, 0.08331360926310863, 0.026062684651884823, 0.04433236287666425, 0.043935096492209745, 0.03581507011286674, 0.060711414628331704, 0.06252844878021749, 0.06783843400978273, 0.014014444764583342, 0.03416386718351034, 0.008169759849777386, 0.02639609569263074, 0.055064408168677366, 0.0033827275441463797, 0.026770316237103076, 0.05227565277187575, 0.014725992016704574, 0.10613007485986718, 0.09873247705399991, 0.05101738016932242, 0.11090315502857971, 0.15300809045232114, 0.18280540202413836, 0.11010486076796248, 0.13163993705905255, 0.13429838473037367, 0.21851246906144006, 0.1358226085862806, 0.13574820612707447, 0.10957572383866196, 0.11133014179405668, 0.15065273780736232, 0.16692302039554044, 0.1509868747164165, 0.13099398704305773, 0.1516762772394765, 0.10059454568451452, 0.1426861588392527, 0.1990327377232813, 0.20485566478342782, 0.16941211667032013, 0.13218571341806842, 0.19879526578851286, 0.18354751139638886, 0.11974929486431422, 0.08598174028579267, 0.20197396376921287, 0.12088849059035703, 0.15886305530946102, 0.09168671278823769, 0.16205065523184117, 0.12322410881038635, 0.08780221034201884, 0.9235790540133754, 25.42888468311679, 48.2819135727421, 43.39084740607969, 31.86774753755139, 39.126101386162546, 52.50933431809949, 21.461430788040165, 5.9366293395719225, 0.22231223452235424, 0.5319107191697244, 2.848107752300078, 4.752597674246758, 12.09153171508543, 13.198688357107102, 8.39399572341673, 7.786104832926105, 4.28160289602895, 2.64283737347972, 2.3442886192952437, 7.287707396091954, 18.444547614743634, 32.59992461050711, 44.30528525383242, 55.42537727663594, 55.80623942036783, 59.18490240650793, 58.491576410109005, 62.145185778217936, 61.649833571526315, 57.93401541248445, 55.12860682702834, 51.991012711678785, 48.23509223999516, 48.508873678022816, 51.50924759526407, 56.80393741976831, 60.62520850089289, 61.503321278479795, 57.88395420197518, 56.594537765749045, 56.76297218568864, 61.8282308117036, 58.37955744035783, 55.52913573480422, 46.766564692220385, 43.656231049568426, 44.388431656745176, 44.75575377864223, 44.7680700209833, 48.88988487182125, 54.310078774729085, 58.02908974309122, 56.418023263254476, 59.80811995844687, 59.88505724937686, 60.47316174353323, 52.83576965332032, 56.531160108504764, 58.1900598925929, 57.194436827013575, 57.754096292680316, 58.13721379926128, 57.09015277124221, 50.99511115781723, 43.80141365912653, 42.68209472779305, 41.78796299042241, 42.32545714224539, 45.79673513289421, 50.30453866527927, 55.37086025361092, 54.46396120132939, 53.195498066563765, 51.75420353489538, 43.9510363917197, 48.116550368647424, 50.78697450699345, 55.47140629060807, 54.58649212314237, 55.287058814879394, 53.23333324924592, 54.15462347768969, 52.80605377689485, 52.92898085809524, 53.832408612774266, 50.948976239850445, 46.15820900086434, 45.7369464443576, 47.92490336202806, 52.32779918178436, 51.85860526177191, 53.28709717719786, 54.225928245052216, 53.03765404608942, 36.09304628064556, 9.842916323292641, 1.063235534294959, 2.0455631133048766, 2.8484136971735188, 6.678951132682062, 10.367359768959785, 7.780957702667483, 9.117275880229089, 7.3301062564696045, 11.591069640651828, 5.406542093523088, 0.489263002790751, 0.26513877114461315, 2.3972987167296873, 16.46093245475523, 38.97563142161216, 44.29382801055909, 34.844708827234086, 37.39018978611116, 35.963408024080344, 5.307038426399231, 0.1529153631699662, 0.17239305671424637, 0.08445126515242361, 0.166600865101622, 0.21301610996165585, 0.1728957789319177, 0.2731070048626392, 0.10503108342809063, 0.20896146704833354, 0.17714686211078398, 0.1064014538461643, 0.23373895685278603, 0.1758963614702225, 0.2185980257608237, 0.13090700542013492, 0.12980051398757966, 0.14877458133043783, 0.1265421811671507, 0.0882865387886282, 0.14065806363378802, 0.16078774396690632, 0.10960224580260054, 0.13747743511151883, 0.19284290051267994, 0.13747718996338307, 0.1955153675930154], [0.036675934604699575, 0.03487658176210619, 0.07216528328436037, 0.03142214575481992, 0.031229715959559527, 0.052073964804050424, 0.03854216692308265, 0.02829155426532511, 0.03306444291205656, 0.03392255714824123, 0.018423031790242083, 0.04045881165732299, 0.028520629876443458, 0.04457135932640203, 0.059068527583393364, 0.020251806239567457, 0.026880234532478838, 0.11984756862324093, 0.0619238828338923, 0.0928992920765473, 0.05803366920219795, 0.10163123118540934, 0.029189236942798864, 0.02986478859618787, 0.042943924274896426, 0.0589680053564089, 0.05378511411348178, 0.03312494470587662, 0.05987852000661435, 0.03633224457922963, 0.05122182988411477, 0.018732483431156126, 0.038195385732838226, 0.07034915694666487, 2.0005314845231275, 19.919101884288175, 36.08234997718565, 29.90147513727988, 23.374158913089385, 34.299201273149066, 41.089373173252234, 20.47975959316377, 3.4214933072367026, 0.07400171861292855, 0.024474896565680544, 1.0963996643981626, 12.017593076152187, 29.358762271942634, 16.35069816343246, 3.110541528271091, 1.8254805163991068, 1.5189573385061756, 0.6024484793024679, 0.4562944396128578, 1.875574944480773, 6.413120338993688, 18.721425764022335, 34.739648142168605, 48.09221990646855, 56.3974621988112, 57.679932117462165, 61.175371908372455, 56.11794625559161, 56.886958306835545, 53.17862010771229, 49.330610229123025, 44.29764839910692, 45.048111561805975, 45.90611434751942, 50.451176474171305, 55.03658410041563, 58.22081519711403, 58.56463447693856, 54.55648206895398, 55.65281198870752, 58.09359312057496, 57.15598583221436, 54.30760375915035, 44.44155623835903, 40.565015039136334, 41.460358788890225, 41.12012455540319, 40.05887631447085, 41.81986754940402, 44.69658874696301, 48.56877611529443, 51.825516146998254, 55.34991087452058, 52.553021677078746, 58.87743565344042, 46.38411398856871, 45.740590326247684, 56.36216086726035, 57.86799407774403, 54.200507363965436, 54.42309402650403, 54.55751757467947, 53.900936342054806, 49.3558193022205, 40.448289225178385, 40.56810194446195, 39.65111455609722, 42.562603642863614, 50.429069995880134, 52.892636176078554, 53.995022235378144, 49.29864683458882, 47.417556547349506, 41.29822369544737, 42.69816075601886, 48.67109898597964, 52.71418010034869, 54.08937484987321, 51.02266973064792, 50.517142895729314, 52.1758230270878, 51.57570823546379, 50.92222175290508, 49.35370514469762, 47.52948922495688, 44.86507415771485, 47.02057738457957, 47.27657871861612, 49.07332628004013, 50.31759623558291, 51.932192848574736, 50.523591272292606, 35.79790753702964, 11.981769088775883, 0.8963543116565674, 0.7076044044186993, 1.8223098929851287, 2.3586908271235805, 3.485999381349933, 2.623158597177075, 2.559174688593034, 5.282436340085922, 5.694593114237632, 4.855866816736037, 0.3896628085884356, 0.15315724777117853, 0.7934734838143472, 12.333725325522884, 28.044936926134174, 40.20756944533318, 38.755170683706964, 21.981319381344704, 30.822739870317523, 8.421916134895818, 0.08063045525622946, 0.09808835032726489, 0.07241438443381941, 0.04362356683780109, 0.029583617090998642, 0.02171078621740303, 0.053290451140773874, 0.02869217036922853, 0.01606279533476599, 0.0488860278029836, 0.03936263176822855, 0.07554737760895684, 0.05006263160236901, 0.04730451589209899, 0.02914787394054715, 0.037087906046860644, 0.04667593691978724, 0.03682794560107493, 0.02763856007086654, 0.04661580667861047, 0.04805271183290789, 0.10156884098485594, 0.06425553654891349, 0.003957323173263801, 0.04758424523677077, 0.03705421349995079, 0.010723147180772597, 0.023846838533157305, 0.059734192872119535, 0.053563519350944035, 0.018592930939649383, 0.041761195602556395, 0.03960762285597382, 0.061059858229371815, 0.022537898790511875, 0.07824756175039277, 0.05888527169102623, 0.012531005514545307, 0.01506643670220529, 0.06771127107523142, 0.06283000396985201, 0.033676937868398045, 0.024892033355671073, 0.03781192425277926, 0.12968543225959425, 0.04313997000515942, 0.025546408423613158, 0.04322850678656851, 0.019869568584967526, 0.07103590880550685, 0.05573080507137122, 0.07193945588604098, 0.077995786954078, 0.03231352735911647, 0.026054608169943098, 0.08892713385003229, 0.03296372533265141, 0.03416795043214675, 0.0324681124109174, 0.030884461199504235, 0.04076862910522088, 4.171287705821376, 25.440322314539266, 41.405002378648334, 28.483738360866425, 24.66908039585237, 48.446762946344194, 47.11286290999382, 21.84855107338198, 2.7436996515720122, 0.17078067146001324, 0.0478094712560696, 0.22603827168143567, 2.624527749515349, 9.024618710241011, 7.965643482823526, 3.2237283837410713, 2.811223744384704, 2.336482857504199, 0.8331565931439401, 1.4328978402960686, 2.531466820547658, 9.266050400272492, 22.23676766118696, 39.78273753196963, 50.61955598092849, 57.213103386663626, 59.33981249409338, 62.94302332785822, 58.09957865745791, 58.37126162744338, 55.091285474838756, 50.94449297074349, 47.48830826051774, 47.22656457654892, 47.61604416754938, 51.89859774804885, 55.932653488651404, 59.27185350848783, 59.424257201533166, 55.96954338012203, 55.76454462543611, 59.42373552630025, 58.29929005715155, 56.68972584509081, 46.194388943333784, 44.40862794076243, 43.80416324061733, 42.393608323989376, 42.87584804719494, 45.09870229228851, 48.200642062771706, 51.972416754691835, 54.250388145446784, 57.738210693482436, 54.498183881082845, 59.758015601865715, 49.326895744569846, 47.284262641783684, 56.588407101169715, 57.7670205023981, 55.791295190011304, 57.17052605844314, 55.6088069177443, 55.8833336061047, 49.3749330120702, 42.904042043993556, 41.872101752988755, 41.03343625222483, 44.37141641493767, 52.75102684574743, 54.00266301247382, 54.674145329383116, 52.088977829102554, 50.17393550565166, 43.81709137270528, 42.935138594719675, 50.987776325595, 53.83491500731438, 56.04657480793615, 52.74695542550857, 51.7119360739185, 52.97311928964431, 52.43605659854028, 53.30856823152112, 50.82860262163224, 49.7870486013351, 46.354841339972715, 48.91248949112431, 47.52372334080358, 50.783032524970274, 51.353941348291215, 53.74684995220554, 51.74219323742775, 40.51141977310181, 15.900588535493421, 2.149523573537027, 1.1663398146629333, 3.9960359613741603, 5.216467957342825, 2.884979993104935, 3.9334569967562154, 3.8149798445163237, 4.988347320787368, 4.28581650218656, 1.0459186377063876, 0.10563807021225653, 0.10734880583420878, 0.6895433606639986, 10.063751647549292, 34.691924664282034, 45.91848942541307, 39.551392216836255, 22.879873591084635, 34.602369108507716, 13.53001488793281, 0.37075517639037103, 0.0484145236682267, 0.08451859662008863, 0.04027785785916833, 0.0627350052368016, 0.05903827860170315, 0.06440810678947358, 0.03631640954183475, 0.034309883541878194, 0.0389328028165525, 0.06586281582713127, 0.05209279907566886, 0.03207175192543336, 0.11441550728294159, 0.05889176811662413, 0.029423571747517394, 0.036523651647111105, 0.04869682706832405, 0.013162227490195825, 0.0526637107794804, 0.026452487424737024, 0.030430086790734244, 0.005016755979252799, 0.09843168795228967, 0.028688521875489145, 0.022621973109762036, 0.059853139513682936, 0.1694549256635289, 0.18533307848678482, 0.1581045976209064, 0.13849702152994373, 0.1491063740104437, 0.14741535749166243, 0.14497287000619596, 0.13498737356595455, 0.2130597003645474, 0.17622990083069573, 0.139198895964411, 0.1291131952236737, 0.1352807699191955, 0.20041063878565066, 0.16154895957198837, 0.11119347170836504, 0.11653528789118414, 0.20886219737510528, 0.12777459447181996, 0.18168490650432725, 0.10761872159257051, 0.1719365755636846, 0.24197732849467188, 0.10312234472122886, 0.25905551208603766, 0.16232186567879495, 0.16504366882145405, 0.12630221944662834, 0.10714856577256035, 0.09493940720154394, 0.1273515990244285, 0.14779938204634577, 0.10636315711082951, 0.20145546014030136, 2.980168317594836, 28.511206719183154, 48.77851701551869, 39.91590592168993, 32.96125335078086, 44.085267743756695, 51.430725666784475, 27.202498105264482, 4.808933206142918, 0.3866468430046113, 0.4174157838907934, 1.8870145370883329, 19.103888234784527, 44.20280156597015, 25.748398996168568, 7.8619198356905295, 4.320758446570366, 5.369148667781584, 1.5705687432519853, 1.2685372920766955, 2.7595729933631037, 7.603136560609264, 21.230271785489975, 39.42599012005714, 50.626180864149525, 57.504005970493445, 61.54707531775198, 66.43497220931515, 59.53180859165808, 61.58611074570687, 58.05232978636219, 53.3544481954267, 49.2697899572311, 50.054271836434644, 49.241929361897135, 53.310097955888324, 58.8988753288023, 62.285477192171165, 62.42226592956051, 56.513313324220725, 55.64630085422147, 60.99663342199018, 61.74657883182649, 59.862280045786214, 48.58571683206866, 45.134093838353316, 46.579087165094194, 44.013794314476755, 44.684005783450225, 45.104695673911806, 48.48179755672332, 51.98516838012203, 56.528324234870176, 60.424112504528416, 57.26785967426916, 61.79366688574515, 50.74171819994527, 48.269228627604825, 56.743097536025516, 59.95724455002816, 57.707298494154415, 60.074021354798354, 57.52075056875906, 58.82374232815158, 52.16764488527852, 44.42836530746953, 46.15732646757557, 44.06739350288145, 47.18630536910027, 54.32330108457997, 56.670129683709916, 56.70676069874918, 54.427028163786865, 51.71070837205457, 45.95370054244996, 45.151230673636164, 52.69800032338789, 55.175847853383715, 57.30094094430247, 52.5752301369944, 52.63639949983167, 52.784684704196074, 54.06737035320651, 55.19539302395236, 53.65891825768256, 50.96303401454803, 49.57096522854221, 51.64538129683464, 49.53132183321061, 52.43561729308098, 53.860720280678045, 55.462027903526064, 53.57085320257372, 38.98501765343451, 14.104588185587238, 1.5479535825790898, 2.1537842481367053, 4.536533423008458, 7.232264203409995, 8.552038804177316, 7.754910713241947, 8.078872994069132, 10.552414251912026, 13.303194026793204, 9.586611005567736, 1.5846623095773882, 0.4317734973324884, 1.3032310239730345, 16.17141740937387, 36.846023682625066, 48.31670891854071, 47.14863100359517, 31.5627008868802, 41.787060845282774, 14.592139778598664, 0.38584821166530736, 0.2732998751584561, 0.28447673025150455, 0.15943746803508652, 0.18401272594928744, 0.2246001254647009, 0.26961496159915005, 0.12755550098635499, 0.21813063551822018, 0.12569514073191151, 0.18438938073813918, 0.22856999308832232, 0.14185320676094101, 0.25345376993138946, 0.14192267561391478, 0.12119821227726438, 0.1829622049004801, 0.11292006535034989, 0.1157701192724128, 0.12706258469411444, 0.17909968151680886, 0.2356077823787928, 0.13295279725665046, 0.14500486183791392, 0.17858804203569892, 0.20232665532779312, 0.08482195211634522], [0.04794720620397599, 0.027616263081830357, 0.007255780088129424, 0.053339913607605045, 0.019683522217336203, 0.0450793139245962, 0.10304024307838372, 0.02388527699475808, 0.06521836734346806, 0.01254963868808362, 0.02285258855760819, 0.014648969536797415, 0.09551853136790377, 0.037685741910771016, 0.014303128719480048, 0.019168402781830202, 0.03639722032652747, 0.015835325635458915, 0.01679522327087339, 0.039697186195201455, 0.062473711798027645, 0.04948305161369424, 0.08911336216354564, 0.05964181032933055, 0.027852379040972843, 0.03592314979722423, 0.06309831477401238, 0.04427430873376228, 0.059828620869666345, 0.014230417399366778, 0.08213942630156394, 0.025714896056019974, 0.03414659956169706, 0.08984169727491756, 0.10615167087845265, 3.4934925792678713, 23.571038361518617, 36.63871857427782, 26.668296783201157, 24.02560772434358, 35.12427576126591, 39.178143393608835, 23.52923374022207, 3.4773809534888116, 0.4356954691390838, 0.05553225040315621, 2.269739071207662, 6.6979358946123435, 9.065766334533691, 0.3084745876971753, 1.4465774739942243, 2.296068226137469, 0.8046061509559232, 0.5349718839410813, 0.12487790877780608, 0.7523561966034674, 4.46874947317185, 17.0165499179594, 34.072523578520745, 51.13921511557795, 57.00985793144473, 58.456847744603316, 59.119912655122825, 56.77813999114498, 55.25127110942718, 53.11804302277104, 50.58315246335922, 46.52222064233596, 48.42651174914453, 52.36133544675766, 56.48834743807393, 57.05385908003777, 58.86411136196506, 55.5385180442564, 56.312507583249, 57.895921353370916, 56.16822711883053, 54.31391093038744, 44.46182704740956, 42.15726983162665, 41.953267358964496, 41.42549284042851, 43.279346189191266, 40.4676265101279, 43.37311829290083, 44.75826801792268, 48.15916692056964, 54.82205006384081, 55.12588862449893, 57.36243194149387, 47.87479508307673, 44.63881615669497, 54.15740443814186, 57.3498607450916, 58.67648478477233, 56.61372600063201, 56.20672125970164, 54.39826150094309, 49.40640218796269, 39.515812397003174, 39.61409914878107, 39.89752961743263, 44.005612250297304, 51.11754009800573, 53.93846165749335, 55.129889442074685, 52.56907593819403, 50.080033963726414, 42.14152936012515, 43.926953038861676, 50.349363511608495, 53.410769508730986, 53.21543939651982, 53.2392599505763, 53.632979623733036, 52.9142366686175, 50.60458429398076, 47.96393486761278, 45.99466185415945, 45.67219987992318, 47.89319099918489, 47.857740617567494, 49.97986447426581, 51.01961420428369, 53.09439897537232, 50.011925928054325, 37.048288545300885, 15.281689513114193, 2.2062986560406226, 0.16751034936356932, 0.927161219860277, 2.7367771585141463, 2.6870562136173253, 1.7189148669281316, 2.646243706826241, 3.056332656452733, 2.093543996734004, 3.047322972166923, 1.0400890150377828, 0.0441047543239209, 0.9296574407527525, 9.152936108650701, 32.09060484363187, 31.112104885039795, 35.16051061691777, 51.50958491909889, 25.661871510167277, 20.031520935796923, 0.7293250808312047, 0.036341958574109504, 0.06956251488337595, 0.016479604622168888, 0.04460482970781384, 0.09905064869071208, 0.03267750722326098, 0.018284310504133185, 0.022203355854857835, 0.012414305425819852, 0.0548494324058054, 0.03932150050757393, 0.08682486601173879, 0.0021295511021068502, 0.1453504747440738, 0.03178837791746182, 0.09851718336463937, 0.03999507565411829, 0.03257706543550857, 0.018894101170101957, 0.07241961681434224, 0.12480178262077032, 0.041564341649533286, 0.017941384651367704, 0.05541993808301707, 0.014377585762450773, 0.024021682780115836, 0.05917368847275934, 0.017363852032670574, 0.02025014191355196, 0.024971137679512465, 0.04088926880109695, 0.011502698142712396, 0.06034495646975214, 0.11172359689108788, 0.052262004915504694, 0.04453839839345986, 0.057810362233149434, 0.06351844505256703, 0.05875111437372624, 0.055628857920847596, 0.007189492894066198, 0.017721396758251132, 0.05625599281742208, 0.02437396448165659, 0.03181921870207354, 0.03112868811454504, 0.05395852577602191, 0.048235485089882735, 0.014905768912285568, 0.09833084013793739, 0.04644891059386634, 0.008694825979370263, 0.008308367180307547, 0.0551332833035098, 0.024963245058672565, 0.043695310971909956, 0.05063381143695405, 0.010174843689216482, 0.028357943444843256, 0.050862864065434665, 0.03150524522718643, 0.03932948314374493, 6.696837630964096, 31.580708488341305, 40.12077916053034, 25.072254942309474, 24.857665992552235, 45.82145390972015, 48.76175672777238, 22.668999125880582, 3.071941238257193, 0.30822429145055436, 0.04075791536559982, 0.6904856488108636, 1.3815660269991046, 7.182840868349999, 3.581268849872774, 4.003432816074741, 3.5017565229246697, 2.7370948704981037, 1.453298210136352, 0.7261087372899057, 1.7988086443754936, 5.935386928819842, 19.75882991667717, 37.454359762130245, 54.23216089125603, 56.18788603813418, 60.58357646388393, 60.994432972323516, 58.95366299536921, 57.39924338556106, 56.00423674429617, 51.398974080239576, 47.65009426301526, 50.272594882595925, 52.95109518112675, 58.46967389506679, 57.93609426867578, 59.151950574690304, 55.55730227501162, 55.3753121437565, 58.521029487732925, 58.42278588202692, 56.15786813920545, 47.377446389967396, 44.96786379045056, 43.41217333270658, 43.409580646022675, 44.54134918028309, 42.99185214504119, 45.38612573377548, 47.772946819182366, 50.6989251413653, 56.50880652089273, 57.36800170713856, 58.810394502455196, 49.29499903032857, 46.86598893134825, 54.06447172164918, 55.443482937351355, 58.707157719519834, 58.911485748906294, 58.43008149054743, 56.94002405289681, 51.4736089398784, 42.89130610804404, 40.93341581283077, 41.12284668030278, 46.19316516384002, 52.94461542560209, 56.35063694369409, 57.50497871829618, 53.7664931820285, 51.288280871606645, 44.099478490891, 45.79779417284074, 53.26604189411287, 54.15715340645083, 54.994179356482725, 52.8988492104315, 54.11960847916142, 55.91777593858781, 51.58858929910968, 51.07129927604429, 48.352359341036895, 47.90027872208626, 49.44586123189619, 49.96865041794316, 50.35917335940946, 52.596273652968875, 52.68890826932846, 52.183150014569684, 39.97688701075893, 18.93829361084969, 3.8766282268108863, 0.7336458780111805, 2.0357712838918935, 3.85467202432694, 4.927019592254393, 3.2099378205114797, 4.939067152238661, 5.250369493038424, 3.4882343969037457, 1.4324571865220226, 0.3501965940719651, 0.012044460201005061, 1.0858184579880008, 7.948614512720416, 36.54153008614817, 38.71984189556491, 40.85916534546883, 52.176795774890536, 29.500000938292477, 26.009742598379813, 1.5518079241437297, 0.17954028932557953, 0.054852565705415704, 0.08444161244457768, 0.07000443270249714, 0.029482945476868944, 0.05962805139021047, 0.01931466237311402, 0.039887076408992854, 0.04623687660862361, 0.04610083471502989, 0.0744339300980491, 0.04477485909216827, 0.0612165998186796, 0.03830771720517547, 0.023538486228414604, 0.082745187345051, 0.008581517744929561, 0.020052811070795984, 0.04333210102612934, 0.06289272358821285, 0.036851751783321944, 0.021935575566585028, 0.02128521288414636, 0.045282940094869946, 0.03273389895536727, 0.015775033558208137, 0.06886243309465147, 0.17666623386884892, 0.12372687699333315, 0.16063909226607892, 0.11108530009345663, 0.12565507433347164, 0.121033311851563, 0.20719001129750284, 0.18924783374513351, 0.1813134764351191, 0.1678866211084589, 0.15820539946998322, 0.17636635641176857, 0.18799852820173388, 0.2545410478788038, 0.12931544243568374, 0.17291117729919572, 0.10708415309988684, 0.09687384815826532, 0.06386325356640643, 0.10379569004139594, 0.18608096416198439, 0.1398416743763993, 0.1853930478494975, 0.11276459546699641, 0.0881935433754998, 0.115519700451724, 0.20290188010661833, 0.11268560414112384, 0.17251040606248766, 0.1974927630996512, 0.1207712944597006, 0.1169322593317878, 0.2177924689866843, 0.16435616619644627, 0.1895939675910819, 5.796082971557494, 33.610468372221916, 48.22612570178125, 37.9756780593626, 34.68214227307227, 43.99501792846188, 48.80327109367617, 29.645585590793242, 4.9644728341410245, 0.8364524259682625, 0.21852331686644785, 5.015686731184683, 15.007332467263746, 23.39255875156772, 5.060853314015174, 4.21304771015721, 5.914713096234107, 3.279369656116732, 1.9665740550525728, 0.48392974381004616, 1.6110438036341823, 5.120323800271557, 19.18819958163846, 37.83554746258644, 53.79256517656388, 58.6941982084705, 63.071484873371745, 63.55421881521902, 62.016469278643214, 60.80776345345282, 59.10120294940088, 55.16134292848649, 50.13031874933551, 52.46052042130501, 55.85755186696207, 62.15780404306228, 58.67868915680916, 60.5194260997157, 54.707203065195394, 55.85481797495196, 60.8523686470524, 60.67826247984364, 58.252806048239435, 49.056769955542784, 46.72646237957863, 45.68274321094636, 45.7242654215905, 46.78119121059295, 45.15553743608537, 46.81530014161141, 47.782623306397475, 51.94481111341908, 58.53813494405439, 61.13357905418643, 60.5246114730835, 52.16691532442647, 46.92074521895378, 55.62285684770154, 57.889359228072635, 59.925551799035844, 59.68015655394524, 60.51424464871807, 58.75754448675341, 52.21968689272481, 44.01032301687425, 43.179412041941, 42.645142078399665, 48.222144496056345, 54.81791980804936, 58.57071022833548, 58.23115456488825, 56.145587198195926, 53.6392750278596, 46.5753452239498, 47.57126638966222, 54.22124493506647, 56.986096212940836, 57.226564961095015, 54.62181306654408, 54.80270885652112, 56.145944133881606, 53.77106666564942, 52.24264452534338, 49.206416222356985, 50.688687755215554, 51.737635443287516, 51.60983677833311, 53.333149725391024, 54.49765828347976, 56.161476719763975, 53.10824101971042, 39.14021799641271, 17.21985616991597, 3.364645660884919, 0.6651120813142869, 1.8082198813076944, 5.4956612856157365, 6.51237738709296, 5.048142383175512, 7.727629648100946, 8.326792774661895, 7.922028197396187, 8.210342016912277, 2.0508079350956026, 0.3536834279375692, 1.6079622915675564, 12.534441832573185, 39.93317611755864, 40.48925445925805, 40.70376103924167, 57.992105714736454, 37.89963899120208, 29.190078781497096, 1.5855113801456269, 0.2535571918011673, 0.1559556597062657, 0.16640160563251666, 0.1783171839891903, 0.1419000760201485, 0.1487112718243753, 0.11087122448389569, 0.1193522927801936, 0.13273138252477493, 0.15590548094722534, 0.23072378800040294, 0.11573184551971576, 0.1950910927787904, 0.2862225833439058, 0.13505279747468812, 0.32571824628018564, 0.053238376314120914, 0.14338041835975263, 0.18673258322861888, 0.11811918233551326, 0.2957950051753752, 0.1699454364396872, 0.17143811279487225, 0.1863425831881262, 0.1024533890848679, 0.16176680433413676, 0.19741713489976623], [0.02740769947488462, 0.06992754811841635, 0.02206996462548212, 0.06413128091803481, 0.04639009036304009, 0.041819973698546814, 0.020649135826275717, 0.02576265589243943, 0.01616872614249587, 0.06313440900656485, 0.12405429531129138, 0.012053367888344633, 0.005914796802831153, 0.07505845263480179, 0.018667093996379166, 0.03138791120070363, 0.0916410769305883, 0.05617526630240102, 0.04913881000491881, 0.07351387382274674, 0.07755323328197965, 0.025628636470965804, 0.054074385083250465, 0.09013484848002273, 0.03216652274732629, 0.05471666936852759, 0.02725026074556574, 0.05152541520674864, 0.04527236808151488, 0.010246882767176196, 0.052461846611432494, 0.02375242777258879, 0.032533854246139526, 0.038961791583607276, 0.04799180018204836, 0.0207176796280809, 4.764814876740979, 27.31715290777145, 35.787513256073, 28.11686142798393, 21.38429737860157, 34.37091788937969, 40.388673120929354, 25.096920767138084, 5.29311107050988, 0.4892831968684351, 0.1051586140848456, 0.6049958748682853, 2.821163520697625, 4.896668291861012, 2.9173603846180827, 1.404640963000636, 1.212814998242163, 1.6966954979204363, 0.563278710169177, 0.6668447270508736, 1.529945981117987, 6.001776476060191, 17.388239599043324, 37.10648475154754, 53.92341544551235, 60.95516612452846, 58.704784685565585, 58.391512824643044, 56.62640702339911, 55.05518397977276, 53.689053827716464, 52.532719489066835, 53.60234591268725, 58.09621326385006, 57.26666727373677, 58.92730859018142, 56.64682688251619, 56.450786821303836, 55.71684860414075, 58.89899299990747, 57.84947264579035, 56.85337889579035, 47.71636662944671, 44.05763072352256, 43.83589913768154, 43.55927790364912, 41.85454522409747, 44.087225006472686, 42.89713867249028, 43.07261766925935, 49.7919084179786, 54.3186060074837, 54.996819111608694, 59.42378651711249, 46.832527191408225, 46.51075947669245, 51.04536456446494, 55.94871951687721, 54.53749779731997, 58.08193191405266, 55.362309486635276, 56.84583225557881, 47.94793944205008, 39.60292039378997, 38.62134725816789, 39.93864390157884, 44.62798257027903, 52.155654199661754, 53.15287759227138, 53.943513670275294, 52.499853949393, 50.85114056064237, 45.998748963879, 42.959990732131466, 49.206757468561975, 52.62752317613172, 55.36451385867212, 54.933245335855794, 52.01332707558909, 56.38080781505954, 51.91418132474346, 49.22341969705398, 49.16363493088753, 49.137417808655776, 50.67777572139617, 51.38069583523659, 50.04665851593018, 52.14690731417749, 47.8237650471349, 38.77774784641881, 17.473398177854477, 2.436544481785067, 0.24837681332663183, 1.3001003597051868, 1.8121964292180155, 4.276409677920803, 4.658509819738327, 1.0488714470017342, 2.5855582664089822, 2.17091029690158, 2.572776487758083, 0.6694067089307694, 0.18412823668651043, 0.6795885077407283, 9.350636313038489, 28.241957579889608, 30.09616198078279, 22.313416657909272, 20.56603212510386, 36.53678794060984, 21.39213231302077, 6.542944417845819, 0.10831481206320948, 0.029057722628837632, 0.08688663568107352, 0.07506547766106744, 0.010928635902312255, 0.06497627589851618, 0.06370182351900205, 0.03266366401446923, 0.029127649219346144, 0.021004840025618192, 0.03138558995429307, 0.012843655572543222, 0.030657858137161504, 0.03071165474642429, 0.05342599507721682, 0.07178947119222534, 0.05685757868172181, 0.04497541324986566, 0.02272948971949518, 0.06352294198868257, 0.06679889100093035, 0.036464321967815204, 0.02862251765515295, 0.03618849201067802, 0.07751882827330021, 0.04938488127663732, 0.02506276371047622, 0.043714945805409265, 0.06329144553972349, 0.05966944312075934, 0.05347368405050328, 0.0254445091535848, 0.04653818281968275, 0.025581782533516808, 0.07565044707828954, 0.022880830388936787, 0.02515320230515734, 0.035493205932359544, 0.040259444935908245, 0.03157370284410014, 0.03896770578238272, 9.593876183639477e-05, 0.020114063630781828, 0.04359751984837555, 0.050800554304113316, 0.023256535228762417, 0.10463296285560054, 0.020982749880321568, 0.04483346481837573, 0.033504445511367054, 0.0888823023847034, 0.04613519375843387, 0.04805272332422676, 0.03596844474574731, 0.0453458052699364, 0.020695020662500493, 0.05409976557618188, 0.026951214493883234, 0.07263491050370278, 0.03871197414193903, 0.06549124786209676, 0.016937652422535806, 0.08276907396653006, 0.028593990456072554, 8.515952998592008, 34.27032870631064, 37.530696930423865, 26.88788087137284, 21.515359455539336, 40.38759839150214, 47.0838059917573, 23.928074067638768, 3.84744260580309, 0.34664412179300863, 0.03872048537877779, 0.27671540156006813, 1.331530434470023, 5.6038726145221345, 4.94648729601214, 6.431357889406144, 4.019736637992244, 2.9601252511624367, 1.1937331576501171, 0.8862530440092088, 2.1680869258219198, 7.454299282643103, 19.586016170440182, 38.45025347125146, 56.24124596195837, 61.54880900536815, 58.684137328978515, 60.92785466101862, 58.443605822901574, 56.52952840251308, 56.1068537927443, 53.818790143535985, 55.160480007048584, 58.2434041269364, 58.6697579199268, 59.04247722318096, 56.69312261766004, 55.29954764150805, 58.250507539318455, 60.96773732093073, 59.67567720720845, 57.0145804651322, 49.53583255890877, 45.06140055194978, 44.7908236903529, 45.00535380455756, 44.14627236704673, 45.720711754214385, 43.64018463319348, 44.85976326850153, 50.98036304596932, 56.65454610701531, 59.18747940371114, 60.551817032598684, 49.488960235349595, 49.89608656975531, 51.87241984951881, 57.45068527037098, 56.734899782365375, 61.25369771834343, 58.51831128520351, 59.17865407082343, 50.91067037274761, 42.53397818534605, 41.63822258672407, 40.65019715216852, 46.56033431330035, 53.33198085907967, 55.60059739697365, 55.89701091089557, 54.463290476029925, 52.785147543876406, 45.61529805583339, 44.571033677747174, 52.18976313068021, 53.47375100658786, 57.20072830876997, 56.2698478852549, 52.07548487570978, 56.304564783650065, 53.12700956098495, 51.07125220760223, 49.80887659134404, 50.07313451459331, 50.49679363927534, 51.24675081622217, 51.74790813076881, 52.60293775989164, 51.34901092898462, 44.54340842462356, 20.992119196922552, 4.044552003183673, 0.5211137211130512, 2.0043217198502634, 4.0170260350550375, 6.31860004317376, 4.780606829350995, 3.9959258898611996, 4.121286311457235, 4.731198203179145, 1.7573517657095388, 0.13349765431015723, 0.023852193487748027, 0.49489531185357805, 7.714059718193547, 29.479224143489716, 39.77557528403498, 24.45458362179418, 26.22454727849653, 47.4479627609253, 25.90742757243495, 9.388200852178759, 0.0891178131343857, 0.017566386527652224, 0.09859351636541468, 0.04332746236374782, 0.010706668629521325, 0.026799239886684284, 0.013041946898034264, 0.06202792906532846, 0.06699156977476613, 0.05622521140462449, 0.03624334007561688, 0.05131490573647523, 0.04647186258807779, 0.0457521076614578, 0.04323850806442, 0.05193415758830886, 0.032207493129516804, 0.020868882401696136, 0.030632975601380875, 0.025218162730696703, 0.03717510600484187, 0.0525818657760899, 0.028381567681208256, 0.006261885864660145, 0.019129244197580605, 0.06049483774169799, 0.05399093129521897, 0.04153197060429281, 0.11302419202101809, 0.28058383914251483, 0.13736039219844726, 0.17764524827080388, 0.2234218056283651, 0.10992262377253464, 0.10774029208527458, 0.08809581353899934, 0.06718657745589172, 0.18499682717505964, 0.1736388382531943, 0.12312820226314569, 0.10593643081524681, 0.16580122252625806, 0.18039757235636636, 0.13630297635832142, 0.30049713028054087, 0.12406345006198653, 0.3831258109740673, 0.12998373157555057, 0.19319412118244558, 0.10525266669930951, 0.37617754671842824, 0.2460048059301992, 0.10152222453466347, 0.19897695120063522, 0.07631572549261394, 0.1362252797210409, 0.21014884204393436, 0.06783706271239827, 0.154621793377784, 0.18665297137152764, 0.20812384183368376, 0.21477688644682208, 0.20723191630696097, 0.13022336387826552, 7.742597412678504, 37.07463118337816, 47.12324542383994, 37.23675843208067, 29.355806766017793, 43.18965727283109, 49.78622882596908, 32.84807924301394, 6.989763667506557, 1.0477638677243264, 0.17706800101985856, 2.0638580283811017, 6.303447436901831, 11.798018793905936, 9.618677362318962, 5.461159136987502, 2.507203283809847, 3.7282922767823745, 3.1106623863020255, 1.1034164169142324, 2.202122557547785, 6.897905190144816, 19.544499843351304, 39.67990475316202, 55.59567090003721, 63.854072247782064, 61.45123612496161, 62.80497550964356, 61.543811905768614, 59.04242623236872, 57.769879910253714, 55.83308804419733, 58.941417355691236, 62.156897975552475, 61.76205258215628, 60.665557922855506, 58.2894370632787, 57.26442367799821, 56.55700460557015, 63.06063559747512, 63.08136924620598, 60.89929196142382, 52.493072171365064, 46.65406327093802, 46.67198458025533, 48.461416921307965, 45.92117624898111, 48.39357168443742, 45.899371793193204, 45.66042492466588, 55.45566974147674, 59.086843152200025, 61.83413397881293, 62.848470672484375, 52.330156526257916, 49.1307262451418, 51.923657771079775, 57.226670865089666, 57.011697523055545, 64.12044040618404, 59.848088910502774, 62.67153255401119, 52.07370411965155, 44.15282272523449, 43.12719745020713, 42.56993455271567, 48.23623757208548, 56.16053535092262, 57.86749201436197, 56.48835920518445, 55.51487399685768, 55.507044945993734, 49.057534817726385, 46.89677169246059, 54.16617485784716, 56.95927504570254, 59.47272592975248, 55.64606158964096, 52.90810992640834, 58.80899813867385, 54.932633446108916, 53.51813654745779, 52.38770161905597, 53.38014756479571, 52.28356269098098, 55.21632279119184, 52.27800469244681, 54.426082872575336, 50.455294962852236, 43.29666737587222, 19.25363256085304, 3.1540808177763417, 0.6229229451667878, 3.355439122646086, 7.665676301525486, 10.600399548007596, 10.376191965995297, 6.23422937047097, 7.8667453315950215, 8.393524058403509, 9.271203414086374, 1.6068521382347232, 0.4744995078973232, 1.0149674598247775, 11.906192860295697, 35.10745271559685, 39.7472636161312, 30.11418527172458, 30.402905056553504, 47.96386034257951, 32.049867107022195, 9.486639595800831, 0.18309242452584928, 0.13893128613070135, 0.2228979547057421, 0.18172195451634546, 0.1847979967151919, 0.12760511284033138, 0.13368223553463338, 0.14463972901144337, 0.11642445029029924, 0.0910498945403003, 0.1560562930159992, 0.10085538330097353, 0.24318629184797888, 0.1379958927751549, 0.1343116686949807, 0.15375911708801024, 0.12070901917233584, 0.1572056547287972, 0.19304602106492366, 0.2426106074163991, 0.19255290558982283, 0.1457135697766658, 0.11929318909683537, 0.11936503282237439, 0.12699061073362827, 0.16579163110544606, 0.10394166043448834, 0.11419414617722073], [0.032826695185635364, 0.06700616374972367, 0.010743891884152208, 0.016450924205503637, 0.032299657337247364, 0.10693404583200332, 0.05912694178761975, 0.054847344816211736, 0.05923443158427554, 0.05948900260151394, 0.037976859152437224, 0.07056821978861286, 0.03871967715601768, 0.05672616012875111, 0.07392934628672178, 0.036615371523845586, 0.023563573692714977, 0.061624491842643875, 0.022957603890268553, 0.037615005182282585, 0.055190107875293305, 0.0210716697056928, 0.07563725504423342, 0.05855164040000208, 0.019691608275376984, 0.03196218986094239, 0.04199056998796521, 0.058146284127067176, 0.016407492765856367, 0.021677210498901627, 0.026078964020275784, 0.029996752986804615, 0.032630691590208205, 0.031464090983894084, 0.06306404000028007, 0.0338032312931553, 0.0651541768362926, 4.9799862984688055, 29.349995774607507, 36.557356849793464, 29.566814591807706, 21.612087065173736, 22.023065167088664, 39.57598940018685, 30.768538598091375, 7.444028066050622, 0.6767761070401438, 0.06580217230704523, 0.609271013207974, 3.9477336887390386, 6.148274550514837, 5.444275784877039, 3.967637020734049, 1.1716210409518213, 1.183343779656195, 0.2811748300108218, 1.0288595143825778, 1.745070947274085, 7.0083924743437, 17.925827887750444, 35.882434614243046, 56.614847798501295, 62.15468575877529, 59.53903751988565, 57.880247562162346, 58.18255247608308, 57.56270031775198, 55.99613312752017, 59.34803378197455, 58.690468034436634, 58.946696865943174, 59.838510482541984, 54.916394833595525, 56.60230013632006, 54.90292933679397, 60.45232611317789, 56.12126065838722, 56.45115944647021, 53.93642594737392, 49.683172472061656, 43.43776679808094, 42.32495115649316, 43.070778077648534, 43.31106639677479, 44.41668841146654, 48.647078391044374, 53.968993386914654, 57.47934210684992, 57.61094547087147, 62.272031307220466, 41.918738734337595, 53.357715529780236, 56.429841364583666, 52.91893566808393, 56.00022808198006, 56.773499827231134, 56.11422392629809, 53.57156315157491, 44.18892422030049, 37.76645098963092, 39.33307701541532, 40.20469827036704, 43.298220634460456, 50.42155865700015, 52.690285021258944, 54.40635335060858, 53.27077227254068, 49.98355542459796, 50.04862754575668, 43.92269726722471, 47.72385051173549, 53.552237633735906, 54.555591690924864, 55.84607501183787, 53.2022092419286, 55.55748662640972, 52.932232502968084, 51.17229246324109, 49.9501407531, 50.42130370293894, 50.916667676741085, 52.36377123863467, 53.07694442810551, 50.405092547016764, 37.69107087965935, 17.25735991231857, 2.5836593489493094, 0.34151476477423026, 0.16929266824116632, 0.7248502080478977, 2.935000509023667, 4.063181790613359, 3.207911426021207, 3.2122390260619507, 4.034069468898158, 6.198715740634549, 0.7946716453279219, 0.12298892747851149, 0.5710676180258875, 9.71984705617351, 26.0450380463754, 29.418256782716323, 23.778796503620764, 22.23648132816438, 22.128010142234064, 20.412451721006825, 8.383113107373639, 0.1983403781008336, 0.10955765182452817, 0.057715049404050076, 0.05933695330074238, 0.1293463923878247, 0.05853982732420968, 0.05023403611454753, 0.04516145387183755, 0.047739558072099765, 0.03339025627581343, 0.024071608730141195, 0.035728057846426964, 0.048874693532143874, 0.07133908810154085, 0.01824479951943842, 0.011725607703650191, 0.044074830929598505, 0.06260946640864977, 0.029511110699405114, 0.02755256861658587, 0.05167837232171048, 0.046468522444727926, 0.03081189735131639, 0.08629435012417455, 0.026769869990887183, 0.03250065582594083, 0.024396529601466273, 0.08522307575349847, 0.08379597652463183, 0.05908848417382087, 0.1075993548898447, 0.03769766989975207, 0.03858290364845626, 0.03704421605253893, 0.05948691501192028, 0.0564921509114004, 0.0959000354933162, 0.056858926996468544, 0.03942262794401857, 0.033834939672341274, 0.10152138183794676, 0.03956172269799056, 0.054822236284493446, 0.03942207253027347, 0.03044941327384403, 0.05491663363852328, 0.026031740445403323, 0.046121067097110134, 0.02881169157673515, 0.06256869137887994, 0.06968820692911264, 0.022864269483233654, 0.04395502243912028, 0.012421799680939125, 0.03748928632346853, 0.012056844012301055, 0.06587021623647983, 0.060137932699534206, 0.027172326621028687, 0.05909603780075427, 0.0042810640297830105, 0.02966397971425566, 0.014902482395090405, 0.024943583412095908, 0.060418795854333913, 0.10292430333192311, 9.083034569217313, 35.599749395924235, 39.341215933522875, 26.410648053692235, 22.073795141712313, 34.85043941005584, 50.17039360538606, 31.06231039570224, 6.546766767578741, 0.5163981741474521, 0.13913877338411348, 0.22704063644332273, 2.391938307592946, 4.702611969363305, 8.406107021916299, 13.25854862889936, 5.067162446437344, 4.020707424609892, 1.9498213668984754, 2.3500839212248406, 3.2276838489117163, 9.48095117845843, 20.07301765103494, 39.26261163526966, 59.49609148886896, 63.979042883842226, 58.94172722293485, 58.20499627820907, 59.60228573891425, 57.90480552181121, 58.21768122334635, 60.59509646508002, 59.620081532386045, 59.706012818121145, 61.35012134428948, 56.314174590572236, 56.9623972523597, 55.7252150197183, 61.04871857550837, 59.60837717979186, 56.7881263456037, 56.21543284385436, 49.99887228012086, 45.2890980628229, 45.643856833058024, 45.768564670316636, 46.0169840628101, 45.24401826243247, 49.64686701374669, 56.43726641131986, 57.51187816742928, 58.248652258226954, 63.2431277921123, 45.35860246227634, 54.160503110577984, 56.950155535051906, 54.51212790704543, 56.9606831765944, 58.267432566612, 58.88734356049569, 55.23731531635408, 46.59287821862006, 40.759999982772335, 41.22840158400997, 41.90020945764358, 45.615580466485795, 52.043494024584376, 55.30155981740644, 56.121307726829286, 55.09928710999028, 52.35099215661326, 51.188656591599994, 45.77877852224535, 49.744632090291674, 55.952457535651426, 55.719178492023104, 55.44848003695088, 53.80460293062272, 56.84257668833579, 54.465361487480905, 51.86146466962753, 51.49937498954035, 51.82495524806362, 52.534747354445926, 52.68030651154057, 53.290858730193115, 51.413078923379224, 40.4628804422194, 21.518656207669167, 4.6149249326798225, 0.6092973666325693, 1.0182382875392515, 2.117099790803848, 4.405635595321655, 4.190025358430801, 4.6835178713644705, 5.273468330983193, 3.3288376081374387, 3.2372076088382356, 0.09729452235924621, 0.2631012224141629, 0.34851034262007285, 8.522977963570627, 30.802341584236395, 36.19720089820124, 26.090939583316928, 23.489557004744007, 24.816355589897405, 28.84410612044796, 13.410553220779667, 0.5384342336366253, 0.15064044975705687, 0.03568229941470969, 0.09416070180915057, 0.04776131496914933, 0.06893372523688501, 0.018575757163606824, 0.0273648138728834, 0.03727729064262202, 0.01242907560099998, 0.017206198798732895, 0.06488032338600005, 0.004056603140798548, 0.028640888443577196, 0.05237067065712425, 0.027525136923237194, 0.017633666284382343, 0.03035629528664774, 0.058129307618665124, 0.019338380455249743, 0.04604968302432568, 0.04262440815387715, 0.011963678144609496, 0.0724035902549663, 0.019373570704051567, 0.04005101156390963, 0.07092625098002535, 0.04560706040431415, 0.010949611389679054, 0.10579444407936066, 0.2480864047162956, 0.10739553719758989, 0.11297974359965134, 0.100955510992677, 0.22963741403673926, 0.23346072904044585, 0.1910790443540581, 0.24610634322368333, 0.13070540172198128, 0.09403707820080942, 0.18988408508800692, 0.12746521752447854, 0.15802607360866763, 0.1482535189678592, 0.11626609225547123, 0.20219148677443305, 0.08892763946806231, 0.08798499125987293, 0.1210060161388209, 0.16951353138973638, 0.16232431716015264, 0.12780859345389953, 0.17727369562752787, 0.1519491730798637, 0.10336230644175123, 0.13691868122306564, 0.24057308932946575, 0.15964121677942816, 0.1763438487485532, 0.12620360860901494, 0.08197026642700357, 0.11383730242209089, 0.0992494178635459, 0.08888204957568839, 0.16079293804303293, 0.20757549141924228, 7.802446407656516, 39.65214613945254, 50.62559250862368, 40.55438933833953, 29.735543189510224, 32.568084770633334, 50.32473102692635, 39.96169959345172, 10.357012556445214, 1.5070159276646953, 0.26198264211416245, 2.612853304993722, 8.749753717453249, 11.715549980440448, 10.275536102633323, 10.665180433181025, 3.4760779911471955, 3.314627841595681, 3.1988514863675643, 1.9833467227797357, 2.3499147690111593, 7.743881498613666, 20.15763102039214, 38.10206074868479, 59.3430249152645, 66.00253089781731, 63.286705324726725, 61.31119574269941, 62.83761747421757, 61.966117812741196, 59.832046416498, 62.95086806820285, 63.60815924982872, 61.696898091223936, 63.47557137089392, 56.25526059058405, 56.549187321816724, 54.914041411492136, 62.283782728256725, 61.14376152715376, 59.26374204697148, 59.096664767111506, 53.9183634327304, 46.729357088765795, 47.218045188534646, 48.667753204222656, 48.9639509877851, 47.987010171336514, 53.10358908868606, 59.78360906724007, 60.600662308354536, 61.82066848201137, 65.57220374384235, 48.14916487663023, 54.56222834125642, 54.997223115736446, 55.3430506490892, 58.1729583586416, 60.71161439341884, 60.9364721082872, 58.348931574052386, 48.571631600779874, 40.50679137629848, 41.573938861969985, 44.208724344930346, 48.291515534923924, 55.59601214624221, 56.70059081046813, 58.65206018570931, 58.10939242762905, 54.33386794982418, 54.31671934743082, 48.999538652358524, 51.072789776709776, 57.062582431300996, 57.19525268000942, 56.750055820711204, 54.14245236304499, 57.83385376776419, 55.49282635411909, 54.95710119124382, 54.29913536194832, 54.84728267115932, 54.894162839458836, 54.41151518975535, 55.51275591696463, 52.14737799859817, 40.02574013125512, 20.300242516302294, 3.856069858997099, 0.7544746442187218, 1.090847917141453, 4.0293739015056245, 7.345553530800728, 6.635946756409061, 10.43692986811361, 8.02725068023128, 11.294185442309226, 13.491333453885971, 2.6385588030661307, 0.36975938466287434, 1.1278837943269362, 12.289810469073634, 34.28559064865112, 38.520746307988325, 32.80829464235614, 31.942170589200913, 35.19463523741692, 30.929561699590376, 14.305200749827971, 0.4983750057797279, 0.192478196695447, 0.09626312286502893, 0.1658214932127345, 0.20294815181724488, 0.268292601911291, 0.10113915758988551, 0.12487646853250843, 0.1715448594862415, 0.15136455606308677, 0.06751234868481275, 0.13458726116486136, 0.07961145872550626, 0.23353799666848876, 0.13402636223022016, 0.09725053359063403, 0.08292687275717336, 0.11190693705312668, 0.25496365262135384, 0.14417860536806046, 0.19473627149578066, 0.19215935090136146, 0.1194216084155825, 0.31278156465099705, 0.21436257077561272, 0.32262686700109516, 0.13343462059574743, 0.12630116990617207, 0.17596158619609573], [0.051422552581155495, 0.010188267464869687, 0.05675179726113716, 0.01004307465102043, 0.06430079319304036, 0.05578809695678854, 0.03215482458472252, 0.031937201988072164, 0.07782464291179374, 0.05930700309334263, 0.028829026231241804, 0.06167017366556872, 0.07377941521906084, 0.06641501966383188, 0.0645439341784485, 0.11667441711911272, 0.0335132057267812, 0.022897012081117402, 0.027153890715130878, 0.02739322424355534, 0.08258945699180327, 0.04298923837561761, 0.018814680834991798, 0.07420911393578976, 0.045851227947540825, 0.016925963836031097, 0.07586643790766116, 0.058409305094110395, 0.017628363040726513, 0.01919103684955307, 0.07233491047255455, 0.0016220865607817448, 0.004746789946371029, 0.0719091417868772, 0.08149748292541312, 0.06160162794854372, 0.03676933221398823, 0.022953811755043366, 5.089481223014094, 26.93369023261532, 32.60992077089126, 31.003953372278524, 18.499809888101396, 21.23610827230638, 36.24064114785964, 29.964642947719945, 10.235059203640109, 0.978301388602103, 0.12414110073399161, 1.4674091819793948, 3.2629287963913334, 13.276250285487022, 22.02824269571612, 8.272136507495757, 2.7391352384321155, 0.9675507235430902, 2.901607900857926, 0.5341861228789053, 1.6136172461894251, 6.720156611934786, 22.602375707318707, 43.4147346404291, 58.22198798579555, 61.60053330083048, 60.46771749373406, 59.184608228745006, 59.58169329550959, 61.611559083384854, 61.10247073634979, 60.36728520547191, 61.45746877116542, 57.27800684590494, 56.868562390727384, 58.69535923004151, 56.60089200542819, 60.006752706343136, 60.43116100372807, 58.26069393465596, 57.554012267820305, 57.61692708538425, 52.73249756905341, 45.889189320225874, 41.43707952191753, 45.21341593034806, 44.599910166955766, 56.176679826551876, 57.32093718744094, 58.86948500910113, 54.37553136579452, 61.19346187960718, 46.41477515620571, 52.106718709391934, 63.656820174186464, 53.87634700344455, 60.694614841092026, 55.74579177364227, 56.0738980385565, 52.13815258395288, 47.94106744950818, 44.63304635017149, 43.411416315263324, 41.58033232535086, 46.178844590340894, 47.30555718944919, 49.66319976314422, 52.14072173641574, 53.721609500146684, 50.28467578272666, 47.88714270437918, 49.426221924443404, 49.04142172105851, 50.77887873495779, 54.206171266494266, 56.34623996673092, 54.68105262325656, 56.834159281946, 53.46983255878572, 51.64342403411866, 52.09919952577161, 50.877487121089814, 51.925493440320416, 54.793240254925145, 49.049886195890366, 34.10940170288086, 15.031678618923312, 2.536896606606822, 0.14901822793387598, 0.19204938664071022, 1.7034457744129243, 1.6957924947623284, 3.281191106765501, 3.4791653867690795, 3.0690215239601755, 4.0362216243820805, 2.575322105999916, 0.8824462611829081, 0.08598103548490232, 1.001579245973018, 9.93153247141069, 29.413799009015484, 28.874680995941166, 20.984439196125155, 23.70848213472674, 23.175288861797704, 15.812852959479056, 6.562604808038281, 0.14265871756980497, 0.09894711190774556, 0.039190135580757936, 0.05021549678677994, 0.06836983855933913, 0.051549248202073, 0.07990696948141822, 0.02207399041752421, 0.06987323248458487, 0.0413452098596721, 0.04268872123512049, 0.0546757219689748, 0.01080755666348963, 0.023480253970070232, 0.03442581945789918, 0.1208824538175137, 0.03600305659816631, 0.019423408553965633, 0.037309619553026654, 0.016065737112395225, 0.019703030646328005, 0.08704479453304122, 0.0013463351276567987, 0.05863083090873496, 0.05929531642205774, 0.11390945258279962, 0.08291473792445275, 0.05081820113944912, 0.03462031002967589, 0.033524275697287054, 0.007059944553240653, 0.029889265105368632, 0.01952741648100557, 0.019634096139681437, 0.05172460955838042, 0.1274767011824635, 0.02267360743585854, 0.006454576129814791, 0.04123560182990567, 0.05756460505747988, 0.03144287609405095, 0.09546485924792868, 0.048402802522985205, 0.03819268527290514, 0.02960759564302862, 0.04607512863473066, 0.02410554450996701, 0.04064525830589476, 0.04062280426883409, 0.03323572868060681, 0.0668935794683714, 0.04056890232248172, 0.03333186888466439, 0.1498690145390649, 0.010983664955523227, 0.009432322544706686, 0.04380866517162612, 0.06432961342075179, 0.055803935824623035, 0.05123874510548288, 0.05719895129122081, 0.029738583271541906, 0.07813309289274678, 0.06000350725146071, 0.11709349019633186, 0.016911433063327305, 0.026874540583981622, 0.09118776738403306, 9.187516704682382, 33.890015694402884, 37.5557412639741, 29.03095606834658, 21.279772097064605, 33.65233967381139, 52.61145714790591, 33.826991050474106, 9.1406875271951, 0.5298058159889714, 0.040153012340587955, 0.23670535654790942, 2.3824513198867923, 10.632280572768181, 16.034020704607812, 11.534570840097244, 8.024406471560079, 2.1227872275537063, 3.3234504778538985, 1.4596737777033162, 3.240894146503941, 8.924929711126513, 25.78792864276517, 47.11323553516019, 59.07761381518457, 61.20021227867373, 61.64329890281924, 61.37331431911838, 61.21377191235943, 62.269289570470015, 62.79015679513255, 62.806862169696444, 63.34681564761747, 56.964687916540335, 55.298272871202045, 57.204886021152625, 57.90790027187717, 60.28486444104103, 60.315309878318544, 60.46778809639716, 58.91525514664189, 59.51369116383215, 53.071966940356845, 47.66898439776513, 45.49838396810716, 47.447319492217034, 46.93182591469058, 58.30105904609927, 59.13462938800935, 61.1029649549915, 58.517040437267674, 61.873094881734545, 47.291264072541274, 52.14551487276631, 62.29857398617653, 56.042013091425744, 61.34070765587592, 56.76952646624658, 59.06959649055236, 52.74505699834516, 49.41979708210115, 46.08000086199853, 44.29902122866723, 42.64181590849354, 47.7356372341033, 49.885276517560406, 51.47503668262113, 54.697091194891165, 55.16296678973783, 53.06659329322077, 50.38460992997693, 51.29676888065954, 50.425128013856956, 52.329995709080855, 55.78234826364825, 54.88216038673155, 54.7327769187189, 57.22279948572959, 55.61963658179007, 54.69825221646217, 53.059556561131636, 52.01417822991648, 53.91485683379635, 54.73084711259412, 51.6569209098816, 37.99650192260742, 19.748098311885713, 5.164401925379231, 0.47472486032112954, 0.8620702222950998, 2.5830937922000885, 3.245150653585311, 4.219819191963443, 5.39979757801179, 3.8084738581411304, 4.1249223486069715, 2.1873764068849626, 0.5454582793097342, 0.18647729208873165, 0.4112499405539805, 8.336436902323078, 31.371659886452463, 33.25045362595589, 24.078410671603297, 25.65692932375016, 28.57866168022156, 22.479478043894616, 10.863641577382243, 0.8315620270948257, 0.023640038843657223, 0.03841770827890404, 0.058962240544778693, 0.05150185034219777, 0.02099303078026541, 0.03956815783655451, 0.015451204362175158, 0.023376824439413125, 0.01890277711584443, 0.0464518906758918, 0.045433832602875854, 0.07581426732001767, 0.006758748467320637, 0.010274775070889343, 0.08809340036203785, 0.044513902732080994, 0.04045101671269344, 0.08402473803970122, 0.0343089182710936, 0.041945144804495, 0.049451642008798743, 0.010098890859573599, 0.0134536798953289, 0.04159761284808478, 0.03366893608002894, 0.1055373373110929, 0.08758708519200165, 0.020783603409185045, 0.02650027215901402, 0.06793001216025123, 0.14562098039013727, 0.13354551948366628, 0.11997485413186013, 0.18858021876264006, 0.1428044428147616, 0.17645802649278797, 0.11650781597821944, 0.11187294573192635, 0.18159855307350237, 0.10075785264733339, 0.16441550736706104, 0.14216190955090907, 0.15659731962988455, 0.1574298580207171, 0.4222494309707996, 0.11413762421016732, 0.17004698905492985, 0.17080458872500928, 0.08868284373273773, 0.23695577536859821, 0.15040166015105863, 0.10779237840324642, 0.25950063981356164, 0.14501714988821937, 0.1486033760011196, 0.24313143995260042, 0.13589661267976608, 0.16075319340152128, 0.14521170557746965, 0.1812017042069666, 0.12071537004122812, 0.19302743577188064, 0.1570891787207896, 0.2413799944183519, 0.10329411695561103, 0.1727327707433893, 0.15084369288336846, 7.859906188903317, 37.15338060932775, 45.35958305481942, 41.68773466540922, 29.09565164196876, 29.83925654042152, 49.27226105043965, 39.59884112881076, 12.989934913573727, 1.5289827940925476, 0.3159254362746593, 3.2430242386556443, 8.38519980830531, 19.462873358880323, 31.43922663504078, 16.268033231458357, 6.414139174645947, 4.459465222973978, 5.25073427346445, 1.843567545856199, 2.474400992355039, 8.905093304572567, 26.067568140645182, 47.14299848002773, 61.684311205340975, 64.68594420340754, 64.12586896650254, 62.76084100046466, 65.18052370317521, 65.87104520490094, 66.10546173587923, 64.31794351147067, 64.95188482346074, 58.770017623901374, 56.59018393485778, 58.33760769136491, 58.833273687670314, 61.47549990684756, 64.36992668336438, 63.812471589734486, 61.909372883458296, 62.66497827345326, 57.093294589750236, 51.10404714461296, 45.44995446358958, 49.27483804764287, 50.3200908630125, 60.32014616074101, 62.73538089567616, 63.69647533662858, 58.90230740270307, 62.16129103014546, 52.70761797505041, 53.16199318055184, 61.26499022206953, 55.855010171090406, 62.246630037984545, 59.082010792147734, 60.818506825354795, 56.55544742461174, 53.46736146557716, 49.48196664933236, 46.36574552905175, 44.956045689121375, 50.88481803094187, 53.276032170941754, 53.412252164656124, 56.70589777731127, 57.434246616978804, 54.30240269630186, 52.31553000788535, 52.953468215081, 52.82479093920801, 53.476508432819, 57.7521154957433, 55.04800604235742, 53.85347958533995, 59.38167202857233, 57.465154893936656, 55.53605087341801, 55.09276028602354, 54.5434441105012, 54.876994625214614, 58.04090784442041, 52.23427026502548, 38.09314520128312, 16.536494954939812, 3.7619954876361357, 0.46472477756680985, 0.7398893107329646, 4.038827303917178, 6.532999248273912, 8.491191075694177, 9.973987225563297, 9.760592637523528, 11.587246310326362, 5.876620508009388, 3.0411172922580474, 0.5551798737818195, 1.6929310031475562, 12.933615561454529, 36.605507866028816, 37.52427601045178, 29.01351328819029, 33.65919989924277, 36.03143761234899, 25.664364176411784, 10.008534481448512, 0.6880881613300693, 0.20003320258711615, 0.10284039372157666, 0.1154567203634689, 0.1801054477090797, 0.12685936455044056, 0.13827977431637628, 0.09438387088237271, 0.1720951404422522, 0.12989861920716303, 0.1686907836025761, 0.20279611400779218, 0.1759669488115657, 0.13089588182347436, 0.12657814133431644, 0.1283692778839219, 0.14250594431594496, 0.10578850689794748, 0.16099457238470355, 0.1237640935446947, 0.08598405387132399, 0.13145639771415343, 0.10910709253362111, 0.11887654451833618, 0.14317121506939012, 0.20017512803596837, 0.20501925519877867, 0.250373529570718, 0.08728165359747025, 0.14088194516877975], [0.04058054685893078, 0.031940942412362464, 0.05543742787032839, 0.05692184196725007, 0.013573393582426494, 0.016712432148896398, 0.075155385739861, 0.06637392670757349, 0.03639763018356697, 0.0708436667017879, 0.0586454248836925, 0.03340320699217339, 0.049330370290385145, 0.046190087788648186, 0.050422574183152574, 0.11235388040903116, 0.012612236689986482, 0.12011504056112421, 0.022998212295914852, 0.06122763914566848, 0.029918772896992105, 0.08854784371872103, 0.04627520015703575, 0.07361631509998152, 0.03226866908071022, 0.06126240421567233, 0.054493833543552514, 0.10658824140386236, 0.05711381594019552, 0.05221211726987555, 0.06673928169954209, 0.020259043855232098, 0.022164990171609868, 0.024188488849528858, 0.09828505872358238, 0.05242470283842376, 0.07399823291287308, 0.06718218011120636, 0.06697726691321981, 3.5825365108828393, 23.33433901110003, 34.34330832573676, 24.08150934403943, 20.13218072152907, 25.20819448655652, 32.47322617038604, 29.94691775691125, 12.7180548444871, 0.9517487811465418, 0.2688135723433187, 1.5690862099009177, 10.415395075275052, 15.84878775381273, 10.650384272298506, 11.860771813700277, 1.0569921015731751, 3.162461942242038, 2.252428916192824, 1.632985664952186, 1.0071121168232735, 7.0094995633248365, 22.41649458485265, 45.289058839121175, 58.98938402052849, 63.10683327336466, 61.87522865110829, 62.182683637065274, 59.546521402174434, 61.33099978969943, 58.292065051294145, 57.718889098013605, 57.400510311126716, 58.78151016850626, 58.72290995813186, 56.902734079668605, 57.55651866236041, 60.766327534952474, 60.175340098719445, 59.07114190440024, 57.58447731694868, 58.97719329403293, 51.43143561578567, 44.22850485770933, 43.615940463158395, 44.75010556559409, 57.37114352564658, 60.61624980741932, 60.656665909674864, 55.79902618162094, 50.11471556079004, 41.797882664588194, 46.936434699643044, 59.52308131802467, 56.522491670423946, 61.16643282674975, 57.256033728199625, 58.682537001948205, 52.94570584450999, 55.16068004792737, 52.75730656039331, 48.92693165809878, 42.17474399074432, 42.27736103919245, 45.150214779761534, 50.946481612420854, 54.526899553114376, 54.37302104888424, 52.90275196875296, 51.14493785365936, 51.486670432552216, 52.846316906713675, 54.55744697201637, 56.06049137730753, 56.967378662478545, 59.30897481979863, 55.73800979122039, 53.573085031201764, 54.410397314256244, 54.91174290257116, 54.046507266259965, 50.671798029253566, 43.0903075587365, 28.433020153353294, 12.025703557075994, 2.593192179356852, 0.4259585222649959, 0.2868165466333589, 0.8149048241396105, 1.2744687737957126, 1.1622181390562367, 2.452764953336408, 3.2164018865554564, 2.6441795595230597, 3.691203570173633, 1.897007633120783, 0.26172863800198803, 0.8368452145687996, 11.00497143883859, 26.127380363402832, 28.826602543554, 25.52325494827763, 26.253880723830193, 28.265311371895578, 13.44805794377481, 2.9161140514958293, 0.11721595701190735, 0.0378019268053674, 0.052190555725246675, 0.08829218485663015, 0.06492750674125648, 0.021609367667547157, 0.011957536034676577, 0.038431517013739196, 0.0064275351413075, 0.006221320551459588, 0.04501088312075985, 0.07349405512814561, 0.03933793692398937, 0.025658845233039993, 0.03928140346561709, 0.012505895067607204, 0.002207896520098251, 0.05053611607441018, 0.05523383617401124, 0.0724605565530158, 0.022896065962530916, 0.04712005341125112, 0.0993956410656533, 0.007454255753527246, 0.06966392194191295, 0.036388938916066, 0.07538734950245389, 0.019848468608313033, 0.01144159401226188, 0.014652911059167838, 0.03283923987539546, 0.0048162971037409965, 0.019579956706072536, 0.026268340955157916, 0.0701692948238023, 0.02126928974664019, 0.0687933013203644, 0.05807418759251314, 0.021834473027997923, 0.074680533800875, 0.03288068906253865, 0.09324945554497743, 0.024581070606326385, 0.06533586224841495, 0.027833732460895856, 0.06687407486981924, 0.049450902733951814, 0.03193173403551262, 0.053071024407061844, 0.005908774872941356, 0.025570065218714938, 0.022669911061623887, 0.03009480266501346, 0.08579205691574082, 0.013005162228740031, 0.026185664746369568, 0.0564430944711691, 0.05503001082087717, 0.07144336032891466, 0.07014444293153864, 0.04998483920409795, 0.0397925334982574, 0.044529745430355115, 0.029064609759276914, 0.03588689851664728, 0.1034410143150918, 0.07513179023179316, 0.10371915785776031, 0.05210878350020898, 0.05626785951936918, 6.8292926396093065, 31.900970012910907, 38.61859767667709, 23.323183790329967, 18.887851930433705, 31.494031952273463, 43.04794596087548, 32.47844880627048, 10.408816279903537, 0.692011941104166, 0.03896062712996237, 0.2795745336240338, 2.0369551042395253, 5.9625689541139915, 5.989287159135265, 13.449269956158055, 4.956326561589395, 4.167239329507274, 2.171788662672043, 2.9565676614161465, 2.4228002515531357, 8.828658077024645, 26.842867751275342, 49.55375779059626, 59.507368303114376, 63.14431936510148, 62.06473012124339, 62.31412226153959, 63.0546304487413, 62.19075195250973, 58.730456598343395, 56.48151466923376, 59.36883018862817, 58.19444510244555, 58.593287391047326, 56.7258704862287, 57.91902019131569, 61.95480177479406, 61.08859731305031, 61.95746114177089, 60.51161666070262, 60.19168461522749, 53.73727152424475, 46.17436132123394, 45.19619672529159, 46.74127717171946, 59.40424134654384, 60.10383529047812, 62.663523074119325, 54.94876615462765, 52.546981227013376, 45.649006905094275, 48.08603825107698, 58.90110323506018, 56.118436551863155, 60.52857306695754, 59.14155237136349, 59.19141354099397, 54.93437105609525, 54.73141977863928, 54.72177467038555, 51.087573189889234, 43.02575319044052, 44.613709065221975, 49.05274952611616, 52.36391244396087, 57.42290312244047, 54.70050757931125, 53.79669150998516, 52.04101508663547, 53.100459037288545, 54.22897984904628, 55.93284176241968, 56.98081278031873, 57.356940623252626, 57.01766737045781, 57.600774765014656, 53.477912641340694, 55.481172992337136, 55.833899974823005, 55.17976237881569, 53.068024958333666, 47.858125009844386, 31.48374357531148, 16.73182898952115, 4.1342384680624935, 1.323883651245025, 1.121730943841319, 2.151257016005055, 4.656667776646153, 3.892958034430781, 3.904613602545954, 3.2116121822787873, 2.918664327552242, 1.223419493725223, 0.5275470210659889, 0.21717020640930823, 0.672635309878857, 9.538402134372342, 33.35320403498988, 33.91550325578259, 27.891217277896022, 27.10097735927951, 32.307098104107766, 20.197123404472105, 6.211769388568017, 0.5563804867767519, 0.03174473580363537, 0.057574748061597354, 0.04111451397259389, 0.037296576906115785, 0.04424236286731978, 0.015088144761149683, 0.06270677489679187, 0.03767817679251875, 0.034141593177111886, 0.014660801764787927, 0.07710433640186826, 0.06262409868800352, 0.019812148379822894, 0.01414094407547025, 0.04034478713067309, 0.00430857376833897, 0.025194377615867604, 0.05919024746324267, 0.030928608931360707, 0.03247936624252508, 0.0037649424555110597, 0.09182599523375112, 0.04686630593853132, 0.0170825656142927, 0.07443716298908958, 0.026981907806569533, 0.048901338070150346, 0.039821384369485804, 0.008159382231233102, 0.047757139789962, 0.13045168872321808, 0.12221848051394187, 0.06984395260411887, 0.2344947025900887, 0.08226488852092335, 0.1547706595832302, 0.28786844664043, 0.23778633725258613, 0.179077694793382, 0.19288931011913285, 0.2631488730830531, 0.13045977861169847, 0.19240765531937923, 0.08517589239824204, 0.1105507928878069, 0.2888059237551305, 0.09970968348845359, 0.16362112015485764, 0.11154590279705102, 0.11174599730199385, 0.09452083208147558, 0.2518786471937933, 0.20407676786905338, 0.1684189909287999, 0.17411957374743878, 0.25691066508091265, 0.2660146854337185, 0.15690323385980823, 0.1875685690151107, 0.1575458130889362, 0.13334878810471104, 0.111358801143304, 0.14297803833840356, 0.09498929484717308, 0.17983282766034528, 0.17489398138657694, 0.29784432101634245, 0.24101901378843094, 0.22936690839067583, 6.423768103122712, 34.31967604544855, 46.565217664164884, 34.285924050115774, 28.160589971849998, 33.860327274568625, 44.45136216378982, 38.45416407431326, 15.367656100180843, 1.6870323712787323, 0.40726735587081603, 3.5949211495537914, 16.728263555034516, 25.987883229409498, 19.336251404977617, 19.683171318423366, 4.288057156147496, 7.618426940133495, 5.313589274883271, 3.8267817660685512, 1.7576925216182586, 8.348293246761445, 25.322378604642807, 50.022163314204064, 60.44210441650883, 66.33164128949566, 64.66003694841939, 65.62876039935698, 63.4231645830216, 64.64839927611813, 60.019927947751945, 58.00943866852791, 60.71203408702728, 57.79315917722641, 59.28907663591447, 56.619589944039625, 57.571058888589185, 62.57112772234025, 61.966855218333585, 65.03840838709186, 61.68115369735226, 62.977975568463734, 56.019330024719245, 50.097700318982525, 47.851727624093336, 49.767417138622655, 61.60307499670214, 63.04562860919584, 65.65022753131005, 59.35645118836434, 51.68534632652037, 47.687584277122255, 49.19733593540807, 58.86360145384266, 55.64678330575266, 62.56159244045135, 61.985090317264685, 62.836134818292436, 57.05928764035625, 59.20232557481336, 57.464162534283055, 54.714404536831765, 45.6704818817877, 45.71758170281687, 49.86720615817655, 54.566111487727014, 60.621239062278505, 59.46125691936862, 57.07987616139074, 55.25650747360722, 56.763336966114665, 56.520216695724, 58.03977035707044, 58.994451722791126, 57.396434968517674, 57.97043854190458, 58.83323446396859, 56.260210621741514, 57.29744611247894, 57.77432395565895, 56.147803337343284, 53.918320286658506, 45.672807847299886, 31.830190843151463, 14.611359392443012, 4.318625167492898, 1.1918952820762512, 0.7905193262042538, 2.3925158766008194, 6.426307837809286, 3.6085673205314146, 7.915948523629097, 12.146013436778901, 6.846568228737001, 9.133686096437517, 4.178080760663556, 0.5773623479950813, 1.3880948121509245, 14.205880453509671, 35.06836237445955, 37.16384157057732, 34.02673382912913, 35.499054308860536, 39.3270718666815, 22.219173869779034, 5.275399607996787, 0.3188565499599903, 0.10964342302853063, 0.2261101000852162, 0.23485252693776162, 0.2892617767135943, 0.08286724047314736, 0.1644641079849774, 0.3806516534138111, 0.15203246215899147, 0.1401861228289143, 0.14378393219122965, 0.20346231938850498, 0.15655955149521752, 0.12516202014540473, 0.2270833535059806, 0.15335465330750714, 0.08990882189884301, 0.13970811460768023, 0.16215671244407856, 0.26922802591035444, 0.14137130681305163, 0.08984552005365973, 0.13231150505523528, 0.18391298130154612, 0.17732378245601732, 0.15439397415086148, 0.23773753745180948, 0.17676764858826516, 0.09030226167411574, 0.1277202098900753, 0.17633614190403493], [0.10737240900315585, 0.056205155222766826, 0.037085508191657644, 0.03224225436908103, 0.09842991828918458, 0.04570592788138217, 0.029849095285058986, 0.01971508120937694, 0.04075512297511582, 0.06160830823524345, 0.020210362798083695, 0.015230819060947868, 0.03365662504708575, 0.03350066486746073, 0.03647425812819312, 0.011427159000548625, 0.046813537802306876, 0.07615463252389625, 0.05890291086548279, 0.03309156625501571, 0.03288566480360685, 0.022379904647447893, 0.04057257954451827, 0.043025378573445544, 0.02031600249240235, 0.03328657776658093, 0.08379203117182178, 0.008313515291158712, 0.03282234380622545, 0.033876335233329766, 0.03086376341900999, 0.064303305961432, 0.03619411126560262, 0.009181703583547666, 0.04407983348374406, 0.00464682839998615, 0.022446866477689436, 0.041647849063719475, 0.06728646766033865, 0.15300804448704566, 3.326264778452535, 23.568533928163593, 34.52296464673935, 28.722073339646865, 20.72112068053215, 21.353432247715613, 40.39077158897154, 36.70477913271996, 13.755913011489378, 2.606186256293328, 0.029295024109042944, 1.5814399599067628, 4.590119863710096, 7.129773161103649, 14.191795222220884, 5.139217857391604, 2.6196380247992854, 1.084700092192619, 1.1046484088705433, 0.7666609580478361, 1.262223134117742, 7.088310276308368, 20.8975665415487, 42.02737662100023, 56.25262475782826, 63.00501638843168, 62.54948016135924, 59.12193659813174, 55.471190560248594, 59.676595041828776, 59.95525983072097, 60.72564471152521, 59.12649831464214, 58.322157475256155, 58.54332816216254, 59.109734104525664, 57.80213748255084, 60.72736270966069, 61.8715847692182, 62.863642400310894, 57.444515382089925, 56.324494346495605, 45.89853240597633, 48.68421146946569, 44.852961878622736, 52.77112507051038, 57.47705536503946, 61.24132264044977, 57.56849758086666, 65.37671673682429, 42.30568839657692, 46.841211318969734, 61.7836138509935, 55.6369460013605, 62.56798590383222, 57.89469757387715, 59.54803151469077, 56.853406352381555, 58.44947761104953, 54.773573490881155, 55.57563151082685, 46.04567620062059, 44.76340240047824, 49.18581201184181, 52.35445168710525, 51.49085560152608, 52.75073659035468, 52.95541371068647, 53.965604459085775, 51.196269912104455, 51.63835633185602, 55.569759722678896, 57.710118678308305, 55.850213112369666, 56.00941035055346, 55.337708380914506, 56.04318980247744, 56.614455561484064, 53.29336120236305, 48.57893505404073, 36.818963250806256, 21.441275688909716, 6.865496606596055, 0.8656989662877975, 0.16790155982298238, 0.93683831994572, 1.8034935478241214, 2.5669537292372797, 4.218207588118892, 4.472061914782371, 1.983440982237939, 1.986284823186936, 2.181122923089612, 0.44055764533339015, 0.015222966659723993, 0.5710867395804775, 10.991132336278117, 29.710736159355413, 27.534699324638616, 25.57194332922659, 26.463762829380652, 24.536494478102654, 13.338367881313449, 2.3392503348089035, 0.027216662044426607, 0.05291278511586209, 0.0403515899914407, 0.09283516285640579, 0.028399509460394903, 0.01824586629687298, 0.053572264244599696, 0.008533457218999825, 0.013641707557854394, 0.03458945200808587, 0.016687298719320568, 0.025375965351779616, 0.019373021035965894, 0.08680759072904626, 0.042091731898366444, 0.045781173037305, 0.030318488847584497, 0.0256895404609461, 0.01970219561049054, 0.03464029726362036, 0.052176827429643566, 0.0055002058187739985, 0.047019121327227166, 0.02757431785275619, 0.032339647126894806, 0.03479163410262235, 0.013599523883913795, 0.02573712409714297, 0.020571534949985724, 0.02226690476339671, 0.05299515488948073, 0.005869313205156716, 0.05602469938176294, 0.03870387276213977, 0.03351760307146657, 0.06762404430417285, 0.05208198574461764, 0.03832687706416173, 0.024071859623936397, 0.05728951437518962, 0.013675246887179393, 0.07874288355871555, 0.0369552081270564, 0.045699255255561684, 0.028350592831209786, 0.03369230559215911, 0.04077258594934979, 0.048353707778357694, 0.06479639845389513, 0.08966678408004584, 0.05465648550119612, 0.0417655278297682, 0.012478232590271341, 0.09108673570857895, 0.05805893861238034, 0.04195637182302533, 0.025214431882505457, 0.02822386273633569, 0.08929978965991929, 0.01732871924046307, 0.04237903785260935, 0.0210157050676043, 0.008731139504591064, 0.06243340791233125, 0.03441584499312505, 0.024192595080803, 0.0380476035418049, 0.030507459755866762, 0.01785725096030341, 0.047894851755230665, 0.027076856743904854, 0.10243977570245344, 7.086169152490555, 30.08146485974712, 38.991285600969874, 26.139645614931663, 19.42197088272341, 26.979262290462373, 52.844983300855084, 42.9141225353364, 12.954814991643353, 1.7229660624457945, 0.0809893751096341, 0.49213092954408744, 1.3547680262596378, 1.1932358746567082, 6.629461607625408, 6.939420536641152, 6.097756874176764, 4.062526509646447, 3.7023940922752505, 2.1428776075763087, 2.2179125489727145, 9.320064379322915, 25.339537012961603, 45.86911070731379, 58.49321596084103, 63.43707330765263, 63.58710004437355, 60.74836700193344, 56.57340403526061, 60.39133717936855, 59.460091975427446, 60.52299153420233, 57.580758910025324, 58.5666976436492, 58.49233342755226, 58.63849270728327, 58.78186710419194, 61.041501414391306, 61.218980819948264, 63.10326391650785, 60.56164649225051, 59.766538912250155, 46.27073395636774, 49.98682668132167, 47.21971219585788, 54.366290261668546, 59.98220259143461, 63.24035859877064, 59.454651647998446, 61.18236941675986, 42.947297942253854, 48.773653276505016, 60.83277248567151, 57.6374214695346, 60.702643932834754, 58.36365222930909, 60.790697220833074, 59.72747210533389, 59.4004641040679, 55.54726885211084, 57.40560154761038, 48.3701119884368, 46.6779112815857, 50.54517215298068, 54.12268361737652, 55.13781655219294, 55.50572702961584, 54.83483699060256, 55.85423746416646, 53.289627105959006, 54.81455049207134, 57.31212754403391, 59.04539938895934, 55.2919735447053, 57.55553414744716, 55.68960382092384, 57.33349269436252, 56.731299046547186, 54.33158905275407, 51.42775643256403, 40.587043070024066, 25.474839172055646, 11.122036537816449, 2.1993207595040722, 0.6561620905995369, 2.049577046305903, 3.0848578483827653, 3.732108497811902, 4.062219093884192, 5.742582822999647, 3.300920628732251, 3.649659786493548, 0.8924286932714525, 0.4617856965670663, 0.04250658766156243, 0.7371011796978213, 9.45067342250578, 32.454871439164684, 31.489305496215824, 28.1797311382909, 27.633303788400468, 30.7708724083439, 22.178689126045477, 5.106272399425507, 0.06635307379427456, 0.041105343900140257, 0.05965577611219018, 0.06330204819659553, 0.0043014764425254644, 0.052910341295383634, 0.013376141263682757, 0.040789941671274366, 0.018152223539448554, 0.041507421316759247, 0.05804480045973774, 0.05427929828123701, 0.032990726101542675, 0.042382761039921356, 0.05673217774939634, 0.019309278690226136, 0.05208212364044401, 0.030769268388769803, 0.02030198499860783, 0.03261657642020333, 0.03006622567021799, 0.03757408076536752, 0.020262504657430035, 0.019343396415933967, 0.05224338897894468, 0.07097777039293321, 0.021405668718920603, 0.0071723219908533566, 0.033954499184244105, 0.03235381209261475, 0.02772901590252596, 0.07015290054222269, 0.166466202166292, 0.11014285106812755, 0.10285833550076331, 0.126477193928534, 0.13973034647924287, 0.09028620447122282, 0.13423144396755005, 0.10606221479153442, 0.1798602536080345, 0.1735379138300496, 0.10755259288294662, 0.1844880528627865, 0.12995674995885742, 0.2184377908105812, 0.1481141675744326, 0.07016951698930034, 0.14729299792839637, 0.24022326293972232, 0.18274077484684606, 0.10959538931567823, 0.11867799751100042, 0.19880949970214598, 0.18897403392099565, 0.2546333155084041, 0.11931359001825895, 0.14360040816808903, 0.19192190961010996, 0.05082214649225916, 0.09837556435095687, 0.11885543879602226, 0.10650093802401137, 0.1366986454494538, 0.10390691834712222, 0.08867019562110787, 0.14295965222822082, 0.11735353108134963, 0.1944868639111519, 0.18962130160822024, 0.20891761617554774, 0.15476816213659703, 5.894213318824769, 33.71447393971105, 48.11414987810197, 40.05045106334072, 30.270283837472242, 30.381353593641716, 52.36440666260258, 45.677695120534594, 18.034483425078854, 3.38474020842583, 0.19060808414172745, 3.3668865599939903, 10.390591967490412, 12.49501024523089, 24.781150356415782, 14.460469734284187, 5.575840415493135, 2.9952625786104514, 3.7892868489988394, 2.3498645136433267, 2.0718763336058585, 8.853251338005066, 23.527843259995986, 45.557066548255186, 59.471164826423895, 65.80953459585866, 62.62712740129041, 60.66262398996661, 56.40628360932874, 60.41063916298651, 61.72242487630537, 61.31061130954374, 59.18967985337781, 58.68278018889889, 58.845589930011386, 59.60923225648942, 58.748872126302416, 62.05182552337647, 63.24523410489483, 66.04499447730281, 62.94441969163957, 62.1922581426559, 49.92170356935071, 52.741879878505586, 50.67047226813532, 55.56777500337171, 63.71155292757096, 66.43859647935437, 60.69843915201003, 66.32583618164062, 47.14551271930818, 51.369164066929976, 59.36814377384802, 58.89213277447609, 61.89834710090392, 60.79551781377485, 62.61541520395587, 62.1151678792892, 61.16134551263625, 57.75129179800711, 59.743542055929865, 52.742217202340406, 50.978233198965754, 54.40473341172742, 55.43722675692651, 56.63356927133376, 55.4229610966098, 55.91296319038638, 59.36462933017362, 55.82132485605056, 55.52036923746909, 59.99248704602642, 60.00446596453267, 54.56289122181555, 57.271864414215095, 56.45769019280711, 57.80849956697034, 59.1478987663023, 54.91360602840301, 52.32878761906778, 39.34755840609151, 24.437405601624523, 8.627534624068968, 1.5150652441286272, 0.7175928426365699, 2.355042532567055, 3.62503269507039, 6.098082430901067, 8.645536341974813, 11.027316201117731, 9.003571271896362, 6.382107138633729, 7.896225865810149, 2.35550120472908, 0.3184283374538345, 1.3349106595400841, 14.74293726105844, 39.76751873570104, 35.87403289733395, 34.48962450027466, 37.37347656680692, 36.79913174721503, 22.60471343994141, 4.088025347840402, 0.1325634866952896, 0.12485252828487467, 0.1362518936155304, 0.14332709864022272, 0.11062382404962856, 0.16062006264203982, 0.10637742932885887, 0.10329320531098113, 0.09861476764443422, 0.14260579621599567, 0.16728544127075903, 0.13602939103880238, 0.08448543267384653, 0.16613116127348718, 0.15462608347015996, 0.13498415599667257, 0.12104919285423334, 0.07852798823507563, 0.09824611081351196, 0.09655824291609949, 0.1104554379238717, 0.170589808314558, 0.09932171358096023, 0.1770083227705571, 0.10512597107839201, 0.1307478736365034, 0.14742798262065457, 0.13396708234663934, 0.10591807534858104, 0.12668427515534625, 0.12860984481390447, 0.11020125761147469], [0.08268769244633375, 0.059553472730781765, 0.008065918546860978, 0.02007973331567501, 0.029219543381083398, 0.007689817256534533, 0.044846450008692286, 0.03779203277982531, 0.08301687276651783, 0.049183070734744115, 0.027077379598913175, 0.019277980168079658, 0.009676697889282819, 0.04912978548917079, 0.07933107820609886, 0.06548292048635983, 0.05459323728216752, 0.07608900943230237, 0.01598772542145584, 0.025797867208659172, 0.05278917682927944, 0.034706119538074544, 0.07074060489333446, 0.07265153461165967, 0.020076190159025214, 0.05751412369370942, 0.013567151881063418, 0.060232322392684806, 0.0728831306520489, 0.045467574945500785, 0.02013897872529924, 0.07380764555907057, 0.012311060713874477, 0.03902410517536825, 0.040816490448290305, 0.05991460657828759, 0.007348735760446759, 0.1300484506833938, 0.06356657069597034, 0.05596201040691907, 0.015278163294668402, 2.695062751731565, 21.261960614112116, 35.026930378329375, 32.568588795200476, 15.124850599996506, 15.799142314541726, 28.405761641840783, 32.882492157720755, 17.27183738062459, 4.095210884847949, 0.1987527479087153, 0.2931191519864144, 0.508208541019309, 5.153622761849435, 7.323693181237868, 5.898571562382483, 4.194021273043848, 3.903880119323731, 1.487909939981276, 0.5764909076594538, 0.4266336602309058, 5.491341775463474, 19.224620749873502, 33.99450763579338, 49.15979885285901, 59.46778374333536, 57.26535720209922, 57.79504191490912, 57.86584854125977, 58.61979084630167, 59.24267499677597, 55.697621145556056, 58.514432061103086, 59.81475660877844, 59.142054434745546, 58.67215841047226, 58.576707532328946, 58.0407666390942, 62.18463697741109, 59.89068192820395, 57.95174844803349, 52.56282368013936, 47.8146259246334, 47.123272880431145, 49.9652301111529, 52.41693896632041, 61.95133832193191, 57.161241808245265, 66.10131186823692, 44.58579747907577, 45.10127928949172, 62.320115643162886, 55.61447082027313, 60.03638229062481, 57.15065140878001, 60.68596993723224, 58.520335228212424, 61.73213666485202, 57.24083846615207, 58.02443388969668, 49.50908199433358, 46.50950824060748, 49.70490632518646, 53.26468083166307, 55.18642648573845, 54.7767545330909, 53.769262375370154, 56.17613853946809, 55.01829016593195, 55.57396450350362, 56.36010554529006, 58.66528641793036, 58.40211106884865, 57.61846857686197, 57.38816268982426, 54.59897310503068, 48.476533735952074, 44.62338555243708, 31.064969762679073, 17.860830291624993, 5.180919026174854, 0.6025461708345722, 0.3960001943332534, 0.6619942260365332, 2.6686649553237425, 4.387476492312647, 1.5451438172209648, 3.3856815772671855, 4.053094435122706, 2.583047459202428, 2.3931468879022906, 0.46180245857084956, 0.10957837450287997, 1.3021940473587283, 13.30734879739823, 33.3780522500315, 33.07964617206205, 23.104176290573616, 25.05496317340482, 28.171598103738603, 11.276545563051778, 2.5702502362189756, 0.01088517860719754, 0.02240765426728514, 0.04597357218904842, 0.008877124261832046, 0.10221459947886968, 0.11050085161602306, 0.011741794183880333, 0.051759581472123825, 0.004503457438981822, 0.03445586159584984, 0.034951892035502585, 0.007105879663985464, 0.05399128369566414, 0.028274445606756116, 0.05314869423126502, 0.05156210698788205, 0.045488056306156426, 0.04004930701827811, 0.043604464435409156, 0.06413262540234194, 0.05205700744784648, 0.02058755767892205, 0.0671350657038631, 0.06592104617025583, 0.07588114679580735, 0.029031060853852864, 0.02480873853088387, 0.03523552842858819, 0.058759112331655726, 0.08187581544681903, 0.005305204840917742, 0.04930780517057546, 0.02459716994405514, 0.04260091223723946, 0.011617838284902034, 0.03383202087734977, 0.031327577946226925, 0.021738660326527975, 0.07896175487868248, 0.023109553599609964, 0.06634284652048542, 0.07371319457888603, 0.018973427659441388, 0.04681373698516719, 0.09849174158467401, 0.015063101346904953, 0.024941530296458833, 0.044700138706473574, 0.028502732147312457, 0.024769585692293705, 0.06228290610916673, 0.015673501052773528, 0.05819608367258503, 0.035638276172140916, 0.037188336343294194, 0.14853171613668242, 0.017012870765381286, 0.06983915689371287, 0.03513771432241605, 0.013149144623668925, 0.01112559806525467, 0.013198938423527345, 0.027510968127077626, 0.05740190330412119, 0.06469338261071714, 0.02529468533823327, 0.038776160818674875, 0.06072846774552619, 0.022286671747062958, 0.03741791757244257, 0.05356992767643064, 0.07856901224342086, 0.03980917292797277, 0.08105522036672601, 5.875092254530999, 30.52371209667575, 39.16547413795225, 32.98520726542319, 18.41959349570736, 24.728451351965628, 45.65422365742345, 39.79989397910334, 16.223439804969296, 2.6378513055462993, 0.07465087087644685, 0.10193962754020769, 0.6501606190877577, 2.778258674567746, 4.914731296800799, 5.545025785123149, 4.579715776828028, 4.214967220060287, 2.8424259539573424, 0.7714163415854978, 1.228128911987428, 7.374690367329506, 23.34300352681068, 37.82837736991144, 52.62056489144602, 58.43426665952129, 59.14160336217573, 57.970928838176114, 59.455173323231364, 59.735501197076616, 60.02315998077393, 57.3482172719894, 58.37615674541843, 60.88385351242558, 59.96353603178456, 59.882672448312086, 59.04685851066344, 59.726671941818736, 63.908855991978804, 61.6193175315857, 61.627636878721184, 55.67064308351087, 49.34545247785507, 50.70649923816804, 52.097034377436486, 55.100220634091286, 64.23353410536244, 59.13590808068553, 67.4172435268279, 47.77437456192509, 47.869982334875296, 62.80033926809988, 56.98344469070435, 58.63449973444785, 59.53047106342932, 63.16299769186205, 59.802679631017874, 62.91590406048683, 58.8801303217488, 59.64267830694876, 51.99335828904183, 46.84052490418958, 50.895475110700055, 53.91056183845767, 56.393614353672156, 56.283262391244214, 55.69029415807417, 55.63430624623453, 56.36265116353189, 56.341791998955514, 58.49176468387727, 59.36041278223838, 57.4046641011392, 57.938424156558135, 58.411885615318056, 55.46791538115471, 51.62442799537413, 47.23627636509557, 34.42510151094006, 21.02979160124256, 8.191039052701766, 1.4796344743620966, 0.7252677566101475, 1.3318508430834741, 4.967873038784151, 6.2217508400640185, 5.736072178809874, 4.719017282609017, 2.7388493957058078, 1.978032278918451, 1.6255726304746445, 0.36589753543657644, 0.10169412700399276, 0.5453689228142462, 10.36017987035936, 34.74481390368554, 38.915356359174176, 25.51235664275385, 27.52498753609196, 33.16731114541331, 17.572414490484423, 4.972174898270638, 0.08689959788875234, 0.04466109503541262, 0.02516652648938039, 0.00371726066429889, 0.05162056332694427, 0.024909002203193885, 0.06229037546642846, 0.04768211296909759, 0.01920234622253526, 0.0725931050856748, 0.02164038082194184, 0.024797170603227232, 0.045703955204977144, 0.031074948961876576, 0.0572587980798656, 0.0253207495646371, 0.11122386241632123, 0.0034039129874849274, 0.04740742065252797, 0.09094851046440103, 0.06446907972736705, 0.013758268793143574, 0.05957925925031305, 0.0567108728442221, 0.046723277323068156, 0.04440553959519152, 0.04224702175105772, 0.013845546317527132, 0.12208133545373717, 0.01836266597702859, 0.008313615840198773, 0.032430348106689995, 0.062426658677718336, 0.19937617493973625, 0.1494667724135422, 0.1621201240848149, 0.06308797641747421, 0.09837060776208678, 0.17040899624266934, 0.2744304370735922, 0.17890167843189933, 0.14594817654259745, 0.13789476916914986, 0.16008465911351866, 0.17979726585890018, 0.10801859650640719, 0.15595550648868084, 0.21271424067597236, 0.13906256295740604, 0.19158279312954796, 0.18678391111954568, 0.08287224302729292, 0.1499767724664942, 0.18269951335124432, 0.13716917665254685, 0.2479145711948795, 0.13099414026064257, 0.10757501627649031, 0.09665626386601119, 0.058758817387804876, 0.0972847470773324, 0.2501831413997758, 0.1411427368199633, 0.0805280905877871, 0.09783195602076669, 0.125549576365419, 0.2508514611831596, 0.14095047939448588, 0.2046647863162141, 0.09191905193391348, 0.1598627387636131, 0.18813548940083674, 0.22181705060985782, 0.19122185846490247, 4.911054074764252, 30.907847458316436, 47.054078348221324, 45.15834977549892, 25.44208149756155, 23.71557770236846, 36.92529478380757, 42.920233588064875, 22.78988853577645, 5.000876351710289, 0.38689450390877267, 0.7036227083975269, 3.8625429955220993, 9.18158608098184, 13.59404169744061, 15.212631283267854, 9.349459601986794, 10.415532358231085, 3.052560071791372, 1.0931931267822943, 1.1132562953618266, 7.164775411928854, 21.053847497509373, 36.59145401370141, 52.69774144695651, 61.24266409104871, 59.59573145835631, 58.11857077383227, 59.991600590367476, 59.64263123850669, 59.45430647942328, 58.2816864598182, 59.007646576050796, 60.82566515091927, 59.460750933616396, 60.291932552091545, 59.11029892583048, 58.59423660462903, 64.46780943101453, 65.39642272457, 63.042741744749016, 59.46812106717018, 52.61580313405683, 51.66047065488754, 53.16358174047163, 57.22696896522277, 65.8142492848058, 61.740471701468195, 67.96966229715656, 48.863867790468284, 50.19458286223873, 61.17871769012944, 58.64357609902659, 59.63975221880021, 59.015510928246286, 64.71430686212355, 62.08593445439493, 65.06469611198672, 61.594834096970104, 61.74534720759239, 55.348063438169426, 50.17128398341518, 53.47980714613392, 56.61706786001883, 60.007093952548125, 58.56494434418217, 58.027136402745406, 58.6097691905114, 58.94825012453141, 59.04401086991834, 58.97743648098361, 59.622329050494784, 56.888166396848625, 57.97208593737695, 58.80544054892756, 56.766831797938195, 50.80442905426026, 46.37888546912901, 33.98223453952421, 20.817954194161203, 7.037685715383099, 1.5822038414978212, 0.9434134993822345, 1.9799748327462905, 6.726805519673133, 9.433632685292153, 7.144067258604112, 9.805461610517195, 9.969429431423064, 9.58880949404932, 6.762397106616729, 1.5520148291703195, 0.3184084191678032, 1.7886579180917435, 16.029667854309082, 42.02739231048092, 44.14908078409011, 31.718826909219068, 34.760777950286865, 38.96999497567454, 20.621859219766435, 4.327468641342656, 0.1239302886589881, 0.17304528865122026, 0.1784677355880699, 0.06459104092491251, 0.16594870977344053, 0.22482555449729968, 0.15083128225899514, 0.12669451775089388, 0.08254511582274592, 0.1464310877265469, 0.16640480788004014, 0.1378601419949724, 0.1452836105900426, 0.18515991197238046, 0.13469135719201258, 0.09411799240737193, 0.18095312399729607, 0.14734464757625135, 0.15006133325157628, 0.20812063958616028, 0.156641538224874, 0.1515849289153853, 0.14704357502200913, 0.3574765743988176, 0.22271204048827772, 0.1297732106139583, 0.0955831279016791, 0.21235491479596785, 0.2145983266734308, 0.18258821609760487, 0.17774631058977497, 0.13430926317889846, 0.17851792966886876], [0.01064954145300773, 0.02799478520999753, 0.02561152972761662, 0.03526242194517005, 0.04629547850439145, 0.01745468707785251, 0.03051164451115314, 0.04957698165409027, 0.08781298153823422, 0.0370158976124179, 0.04311933159647931, 0.02128430890039571, 0.05823280609723541, 0.08420639280830661, 0.04230222221644175, 0.03927185034920131, 0.014447152291634872, 0.023029924505540443, 0.11592167444647321, 0.05191613920032979, 0.002986298110749152, 0.07963552920808716, 0.025001444117797, 0.021713691605855862, 0.02633589841876059, 0.04665597266848049, 0.03455570966546093, 0.059516704340855923, 0.012671310687437655, 0.02609698623869448, 0.06040235177703923, 0.055274706964771596, 0.027992458217927528, 0.02095931908115745, 0.06326859696738182, 0.023850408502884453, 0.020800938063691703, 0.012926798137355477, 0.031290821047619946, 0.03931505004725149, 0.024573335033510963, 0.025292048080553933, 2.2016467250162557, 18.217856191819717, 31.816588063393873, 30.853983509925108, 23.25387158701497, 17.59073195918914, 25.42270891128048, 31.181250387622466, 18.873358772647, 4.921805781702842, 0.7885893362183726, 0.42453923713295694, 1.4837530856170964, 2.7411623683667954, 5.755306011246097, 2.8656547204140694, 2.890070003847922, 2.055632695555687, 0.6896773341201967, 0.41932986989136667, 0.08432303735565755, 2.8117868496525675, 12.706095537831708, 25.75552005921641, 39.64653322773595, 48.51184291224326, 52.28670058711883, 57.78309829773442, 58.38726097537626, 59.07272654194986, 60.26242063891504, 59.36304861499418, 58.50916431796167, 58.860455712964466, 58.40999111052483, 60.54307014711442, 59.9371620147459, 60.32344487405593, 61.49060103201098, 60.82010323001493, 54.20256268593573, 54.64941086307649, 51.93056506495322, 52.82845835531912, 52.45500949121291, 62.22640237500591, 58.67322137278896, 68.45318855777865, 47.354037684779016, 39.46368801978327, 63.16124047002485, 57.43998112217073, 64.32598437032392, 57.51613393906624, 62.65044589196483, 60.094045054528024, 60.38946620879635, 58.124658292339696, 58.93209780416181, 54.714310399947635, 53.964157104492195, 55.32223855295489, 56.73515865879675, 54.88130531003399, 57.17517014472716, 53.02369433064615, 56.824592621095725, 55.833256706114746, 59.07006325260286, 59.11642959040981, 59.961794499428045, 57.417753050404215, 52.42686256285637, 48.76919354161909, 42.50079885605843, 32.294183700315415, 21.737461705361646, 11.181329046526264, 3.3419836769180917, 0.36776865922635604, 0.37009842453464387, 0.7636775665225521, 1.7811305220088653, 2.899552578887632, 3.21944760699426, 5.1637748364479314, 2.8108006187023657, 1.8751932488333796, 0.9663873117777609, 0.764792561531067, 0.24700262012981603, 1.3129665918888584, 10.11063083525627, 25.567187455392656, 28.142862819856216, 21.28209217902153, 20.992623221489694, 28.801558210003762, 15.981809054651569, 2.613867973127673, 0.02125522245713059, 0.06251306573469793, 0.04783140818378137, 0.03759690635507146, 0.05794531628189068, 0.04408041954100613, 0.05138708271026131, 0.031107584307450923, 0.028586622605460788, 0.026587826432660226, 0.05739715355899065, 0.06273489798449221, 0.029345344594349305, 0.07352341161740404, 0.07554967587272968, 0.036480448118621306, 0.05418163739264973, 0.08367826711506614, 0.05429657356392953, 0.023104210136338107, 0.055070276402177355, 0.06945206798733243, 0.08014662476677088, 0.054036383291766535, 0.05793580913075036, 0.019210890018110795, 0.09807603163344246, 0.0284226682983459, 0.00944701706870429, 0.04540409306965528, 0.023270843835968166, 0.03280044901334951, 0.046312857208953756, 0.011322904010153106, 0.03031587265732308, 0.016128994907522877, 0.037431561598374, 0.07541514317234678, 0.03016040660440922, 0.034597564879204, 0.008260412949077305, 0.07360060263665454, 0.04110886790459195, 0.027409871334149957, 0.05269332007775384, 0.023837586106251807, 0.009007453054730451, 0.032196656815827854, 0.021492500954698172, 0.05191604726977887, 0.02289761729057758, 0.04123661306596572, 0.0927507629497878, 0.07614230616919457, 0.06115997826019603, 0.026011059901887373, 0.12624179809204034, 0.04759891965096036, 0.045661142381328734, 0.04096046135190033, 0.012721930904644392, 0.0872645162106041, 0.05926837310976079, 0.05342902112451773, 0.08918608689019758, 0.042001115188242934, 0.046241951941121975, 0.08318058575593656, 0.09539155229445427, 0.06417028628469956, 0.05550247639597905, 0.03629209391111809, 0.050207146428405285, 0.025160077944277756, 0.05129807478477878, 0.0987025153552813, 4.724058018576715, 26.687492862824474, 38.84233359367617, 30.987185239791874, 17.602846199466338, 17.62883778541319, 38.80241563243251, 40.71117824123752, 23.17337082278344, 4.457986489419015, 0.617386213233394, 0.15533148190907894, 0.4866539524687875, 2.007754774343583, 2.9222216721503966, 4.507150948047638, 3.9202665561629884, 4.554475324769174, 1.7578166891490261, 1.0143297069495725, 0.4231541195223409, 5.0140540446004565, 17.25384742982926, 29.405748344236805, 43.52129759327058, 50.85964033680578, 56.982977928653845, 59.79713339959422, 59.96263388664492, 60.61095460768669, 59.25449309810516, 59.62230159390358, 59.52791760044714, 59.947544528592026, 58.14595676237538, 61.11079400585544, 61.01889287271808, 62.14223615584835, 63.583420861151914, 62.53166083366641, 57.552733575144124, 55.27069860889066, 51.84199010172198, 53.6535289210658, 53.91997160450105, 64.24498350389543, 60.788947843736224, 68.33776889308807, 48.17130273388278, 41.825707958590606, 62.94765564703173, 56.57424342247748, 63.82995751596267, 58.360341748883656, 62.22164453998689, 61.42230080020044, 60.206056179538855, 60.94268906501032, 60.41934290239888, 56.47171266617314, 54.732710238425966, 56.240775277537686, 57.592074947972456, 56.54304096775671, 56.74485868023288, 54.14200129047517, 57.82957053953602, 57.320894041369044, 59.0183703361019, 57.85902753953011, 59.16952671543245, 58.11149481804141, 54.33085164716167, 50.835498148395175, 44.80204166904573, 36.17004240712812, 27.38468239384313, 14.158105984810861, 5.496031949597021, 0.7411324569294531, 1.4808092242287052, 1.835339393827223, 2.8068240707920444, 5.636074783340578, 5.245572924613953, 5.19321124399862, 5.352594304469324, 1.0922262625348185, 0.9992845368481452, 0.21579199891176917, 0.0965339732506583, 1.554800692585207, 10.854013139201749, 32.335119516618796, 35.77464003716746, 27.794395531377486, 24.26379365305747, 34.67326594937232, 23.001041489262736, 4.814164667360244, 0.11606132461419029, 0.012714738296645304, 0.0494804852191479, 0.023436194338325052, 0.06301388422387742, 0.07075529845972216, 0.03612250502732012, 0.06960439691019636, 0.05281689005994028, 0.02240633468083557, 0.02151682999195351, 0.025165800621072133, 0.05544302031217564, 0.0189579488529313, 0.07001241533866814, 0.07519817175043207, 0.02428488377782126, 0.03019583242524776, 0.084296737557217, 0.01071759591615128, 0.013069786533202617, 0.07164581438466426, 0.05863957963283024, 0.09279150350560104, 0.019685460419784633, 0.0019923561264858433, 0.06262823173235502, 0.05682364098667618, 0.04812606475165775, 0.02215174451139906, 0.04552232341900949, 0.03295655858011977, 0.0036660759360529487, 0.050946651101713224, 0.14574497938156128, 0.10997510079534785, 0.1126734080213693, 0.16814133002152368, 0.15534458201258414, 0.2031028249691571, 0.07974868805538263, 0.12313480594105299, 0.14993859064434806, 0.1367983900971951, 0.15918582347371887, 0.08329998055893569, 0.11857524979859592, 0.1433835593202422, 0.21870860289181435, 0.10760656377721219, 0.13420243987873678, 0.17369827135435997, 0.1760708609776151, 0.19324538778633843, 0.153157799354484, 0.13750118383717153, 0.2043988159106624, 0.19078037731589811, 0.1938371600643281, 0.15082251821314135, 0.1298964128739411, 0.18409020808194915, 0.19924644561063862, 0.16434341849338624, 0.18448961568215203, 0.16518104370803605, 0.13695433495506165, 0.12134034456985614, 0.16399176881438302, 0.14263979519807524, 0.20712057308804607, 0.11093327760576241, 0.14995215040060783, 0.17695440550244626, 0.1293656365164826, 0.26631983357571787, 4.097773908607421, 27.545956527033162, 45.450472216452326, 42.08097580940493, 34.05832067612679, 25.09723847912204, 34.43840226819439, 42.22125153387747, 24.5971715834833, 6.8405385651896085, 1.3084200745628727, 0.6417253781710902, 4.378955633409562, 12.648058187577034, 11.156484753854814, 11.134725405323891, 7.41709069859597, 4.376699780264209, 3.0183878925538834, 1.35748291928922, 0.33516499904855607, 3.7479161399026073, 13.872882012398014, 27.417338086712746, 41.10425072331583, 50.430658555799916, 56.94764914051179, 60.527784670552904, 61.082364666846495, 61.5609722752725, 60.43132966564548, 59.04616425114294, 61.068185298673576, 61.835565643925825, 61.87940205297163, 64.22424985516456, 62.12082785944786, 61.00913009335918, 66.26221533744567, 64.6711451007474, 58.17214250564576, 58.00072316200503, 55.48396964227, 57.71490396991853, 57.05525152144894, 64.88023488752305, 63.064424607061575, 69.53830442120953, 50.13027168089344, 45.58073412987494, 62.900281260090495, 59.146655374957675, 65.51282298180365, 59.04695656991775, 63.30635639929003, 62.39753538562406, 61.77367848734703, 62.17245409565588, 63.16358996975807, 59.30389142805531, 58.13660975425475, 59.37189748210292, 61.17179862914547, 57.46498623201924, 59.06556037164504, 56.006798052018695, 59.462406173829116, 58.853775916561005, 62.5441731945161, 59.4442730565225, 60.2463585330594, 56.84949182694959, 52.52165448281073, 50.42432000560146, 43.567558027082875, 34.50945600386589, 24.893602748070997, 13.2708482011672, 4.415881806804288, 0.7694540533327288, 1.9124866541354888, 2.44012511545612, 3.7762172664365465, 7.006143485346149, 8.19319341451891, 12.485060172696269, 9.728722399280919, 6.983685464628282, 5.609626731564922, 2.579225354617642, 0.4433958172317474, 1.8892292053468767, 13.434964091547075, 34.44633330068281, 39.51563589034542, 32.76083788564129, 31.969040786066365, 41.55785714426349, 25.052515614417292, 4.752167194120346, 0.15775228910628827, 0.11496641643105016, 0.14297529574363463, 0.2508754090916726, 0.12912931371360056, 0.21607577320068114, 0.2652339192648088, 0.1136268121040156, 0.08763652084575546, 0.18691725638364592, 0.1260080570054631, 0.13960821674235407, 0.12038561515510084, 0.1241032483296529, 0.20460702328672334, 0.20472132360502598, 0.11524285159764752, 0.12706575629812095, 0.15692525122675205, 0.1303460298767013, 0.16621900091488517, 0.14454416720376861, 0.1670410439011551, 0.16698761692931577, 0.14730887127018746, 0.09359687641863862, 0.2109358288467892, 0.14176484617975452, 0.06857025482121014, 0.12107370766781031, 0.18926879391074183, 0.11311377834288344, 0.11286093868435391, 0.10887438566574167], [0.04984984302052087, 0.04351074506919231, 0.026024022109566197, 0.06358300328194615, 0.006168691747476377, 0.05751944417434354, 0.043829989228998466, 0.04074583798947354, 0.046738323289901025, 0.09929021970639307, 0.08276873688784339, 0.017829953332341487, 0.0290179664960071, 0.012818160166423167, 0.07631243131453953, 0.051228261192239104, 0.026524379030771317, 0.02780919274946134, 0.041672107237841816, 0.09783930280396054, 0.02613865950655553, 0.0019130374177268917, 0.018311629199513027, 0.009438686820137645, 0.036137700381298224, 0.03756121431867923, 0.04871659979764973, 0.051139575023684776, 0.07283001777625854, 0.07020813548156331, 0.0746067442120083, 0.06571641642480128, 0.05205639074706743, 0.0694154260019141, 0.048534810963657596, 0.0720963660146921, 0.03311306268217103, 0.084456987829218, 0.028281489785219875, 0.02519296609886712, 0.062467809090571064, 0.0817561831565634, 0.14685775273509566, 1.6613265054841198, 12.268987586421352, 30.50904243223129, 33.07789679496519, 25.99305879685187, 26.621151854915006, 28.74907493591309, 28.69719570682895, 24.780218793499856, 7.806728164995871, 0.9930832696057136, 0.2752582103975358, 0.5724517856874775, 1.6504110395908358, 1.9524532772840995, 1.8442645020061925, 5.210080377517208, 0.9241179509028312, 0.3561294853927628, 0.3438263278334372, 0.22967224039377707, 0.9992260077307302, 7.837253030269378, 17.774616595237486, 29.982921192722937, 34.33179224691084, 42.02592926640665, 49.1642625101151, 59.27131614377422, 59.15402550851146, 60.819703148257354, 56.351809732375614, 56.4319476773662, 52.70432710647584, 58.348884505610314, 60.77337211178195, 61.81413381330429, 60.931451474466634, 63.395778594478486, 62.59721540635633, 58.332496843030384, 56.8414274338753, 60.052718962392504, 58.014890763067434, 64.67132945214549, 59.06872180200393, 70.51015792354461, 40.89819685105355, 37.42277683750276, 66.81917621243385, 58.27427318019252, 61.237753283592966, 59.52114366715955, 62.27682444357104, 58.4748435789539, 61.365438199812374, 57.68308570308071, 58.50472811729678, 58.53936264591833, 56.87457538420155, 57.46079321830504, 59.23238661981399, 60.578489149770434, 58.39314060826456, 60.50619986749465, 57.94885766121649, 61.34484183403754, 58.64270141047817, 55.84356077255742, 48.92409578446419, 43.12178850173951, 33.963340482404156, 25.992762657903857, 19.656081468828265, 11.485972673662248, 5.642047082224201, 1.2950196645913588, 0.3917012153373611, 0.11430719011132756, 0.25125964815097473, 1.8423963506375591, 2.364260347620134, 6.504851339324829, 5.455484447940703, 3.2030366553414256, 3.4671879391516414, 0.504791880807569, 0.3631702930696549, 0.4563728257292702, 2.447757802663311, 16.652822648325277, 43.12526764408235, 45.809871150601296, 27.94799162495521, 29.342035324342792, 24.885426567446803, 14.0174723440601, 3.138722287070367, 0.09115735369343912, 0.09288070678350427, 0.0224463761814179, 0.04474772425789026, 0.023318486843979167, 0.10005806963289939, 0.045531899518062996, 0.04781439720142273, 0.010240543389602775, 0.055638246328359654, 0.014950100505243868, 0.04484577968175854, 0.06927992036986737, 0.032032141349308436, 0.03630938834600872, 0.06810902392551785, 0.03595892993372775, 0.028594143673657414, 0.04782643627315279, 0.04452971478683814, 0.007598379874722131, 0.04326480786286054, 0.051834412940567544, 0.09385053579124714, 0.07918477839519901, 0.055959072459729454, 0.03701009449639148, 0.013928380531949863, 0.03425896933843051, 0.02479730275339417, 0.027985293380615693, 0.04007119031983518, 0.014309363717573785, 0.03184676339339105, 0.028118966147303585, 0.051155628396138075, 0.034852116744244294, 0.056310668512577974, 0.02617510230911355, 0.008234940525594979, 0.06279497842995391, 0.028024731586957653, 0.007768602217472489, 0.0469807556439792, 0.016147873229196957, 0.010584578154638652, 0.04276762446088176, 0.09344015015108932, 0.07137863356019221, 0.04375870857808379, 0.03532075954060401, 0.06299175577418459, 0.017316689744832057, 0.009428314947252794, 0.058732655485190695, 0.03675938456229145, 0.052170836622075695, 0.1343265767659872, 0.027640888978156353, 0.04380512584541594, 0.04583696339039072, 0.02320352769006164, 0.013230405485017166, 0.05165511389232932, 0.05689067368005073, 0.06184418287668979, 0.054107671603560455, 0.057888817297475, 0.022136897727426504, 0.06262617478627833, 0.05975844338536263, 0.04552701187710609, 0.09127042061018367, 0.0865080350288941, 0.031807210273860444, 0.05550517302547252, 0.06397986363980078, 0.17689791417890982, 3.630629181861878, 20.474015282046413, 38.877717295000636, 36.85302511338265, 21.71053659531378, 22.995742367159938, 35.494029752669796, 35.84597618349137, 29.51647097064603, 7.377486036669824, 0.7804664140266757, 0.17020114126705355, 0.6031690922475631, 1.0148261319245062, 2.6234726319389963, 2.7504593662677275, 7.312854201562944, 2.4536837685492734, 2.6151929988015086, 0.6976877946046092, 0.2849260254973366, 2.379829215426599, 11.6444952641764, 21.704513795914192, 33.7219185982981, 37.78376040920135, 45.63316837433846, 53.73162723356678, 60.498633615432254, 60.00083384975311, 60.893169141584835, 58.081249421642674, 57.968481279188595, 57.248616526203776, 59.62617297326366, 62.297601238373794, 62.354150049148075, 63.20109959571593, 64.8799014860584, 63.59916525502359, 59.089427994143584, 59.644702249957675, 60.58523170409664, 59.927595353895626, 66.79281004013555, 60.81562780564832, 70.50338791262719, 46.086919922982496, 39.63357371668662, 66.94105209842806, 57.922950406228345, 62.313933987771314, 59.37352526572443, 63.35191080647131, 58.7015801091348, 61.81227853221279, 59.25542662220617, 61.50369782601634, 60.0614187794347, 59.816580510908565, 59.19997215270997, 59.96477942312918, 60.06456844268307, 58.97953887139598, 60.66622864815497, 58.70372564561906, 59.34168738703574, 61.67651353343841, 55.73548378482942, 51.5568494796753, 46.145484832025346, 37.26221069212883, 30.790666649418494, 23.588655687147572, 15.765016713450033, 8.474560226163558, 1.8080718118336894, 1.2018231687045868, 0.969969048615425, 2.865079602887554, 3.303470414492392, 4.667054703158717, 4.166182250745835, 4.896325574767205, 4.813365484437635, 2.9778215144911124, 0.6513785763132958, 0.02402558982852967, 0.23429916630829536, 2.458444790494058, 12.047710995520315, 35.48177626825149, 37.94611515537385, 28.405408628525276, 29.745021597031627, 29.75642981067781, 22.070390524402743, 6.49947916307757, 0.30013844791439276, 0.059768858350693226, 0.025119728093305906, 0.042513934444756284, 0.03495854550912496, 0.03045728482726601, 0.03263786983405871, 0.025351596094908255, 0.029061713946923137, 0.13176054994185127, 0.07997954865136454, 0.015704556342004048, 0.027261784623166727, 0.021264507442772872, 0.06387623875672299, 0.07590453546013563, 0.10291059801895773, 0.06530276725008603, 0.07031334233620475, 0.07621638687147249, 0.03526935504088479, 0.014039823342294944, 0.023521266487096588, 0.10346117774925886, 0.056578427733432864, 0.030692661511561567, 0.08632760600096757, 0.07387867723140987, 0.019948783991557938, 0.0522892814760487, 0.03626010590983975, 0.006007808495327951, 0.04896699946614043, 0.07480257160721288, 0.052966422761880586, 0.17501971173670985, 0.1496498214621698, 0.2620457371156062, 0.14796726255407258, 0.06954082693423956, 0.1600682035449051, 0.1694184292348162, 0.13583753197904558, 0.1398529665124032, 0.21452176384627822, 0.08793066030428295, 0.16103042529955988, 0.18584379866238565, 0.11844520637344931, 0.1793798705142352, 0.15718736054916538, 0.13905461096475202, 0.08435088465170515, 0.15078154783095085, 0.17699989580339004, 0.13635764439259807, 0.09845038815852135, 0.20239047045188568, 0.16236210061657816, 0.1731448341161013, 0.13416448788296792, 0.15686597134317123, 0.2100119727753824, 0.18820667429076088, 0.1301611115735385, 0.11603467241530457, 0.31968346526545866, 0.13460900274015244, 0.26594043619209723, 0.15718647188717322, 0.25386135935062365, 0.11108360703914397, 0.1806726438864585, 0.104521221270965, 0.1165033879900171, 0.1746637413218137, 0.19595433597362813, 0.246463876457945, 2.543664166042882, 20.881329890220396, 44.89690026929302, 48.20096761949601, 37.16665783236104, 36.18657127503426, 38.56957197189331, 37.53367793175482, 31.93694599213139, 9.986110291173382, 1.8190063992815635, 0.8667338591429495, 1.543598648521208, 4.933788622579267, 5.437439583962964, 8.830846759580798, 10.114339436254195, 2.336072724673056, 1.6366047868805549, 1.5959188991015958, 0.6383084421676974, 2.257173513212512, 9.39938941309529, 20.1533438697938, 32.45982147032215, 36.80649403602847, 45.062765536769746, 52.703836810204294, 61.3891803064654, 61.291878069600756, 61.874040172946074, 58.20988355144378, 61.15284965884302, 60.678666483971384, 62.11374798128682, 60.49413857921478, 62.29083907219672, 65.4189920425415, 67.92297040262531, 67.66460387937485, 62.36405403383317, 62.16732363547049, 64.24959621121808, 62.46471381956532, 67.66490982424828, 64.65063502711635, 71.63382284102902, 47.44043573256462, 45.13001849574428, 65.36507906452303, 59.16950318121142, 60.66685230501237, 61.51768499805082, 64.34685922438099, 60.850952671420195, 63.960666579584924, 60.82855593773627, 62.64879457412228, 63.12318171224287, 60.1328412179024, 62.31113733783845, 65.01059486019996, 64.95262222905313, 61.32861891100484, 64.74524651804279, 60.868513122681655, 63.74163358442245, 61.18445219532136, 54.89062093919324, 49.69275482239262, 44.70651234349897, 36.560133887875466, 28.04716483239205, 22.396147289583762, 12.394226904838318, 8.436981958727683, 1.803529216877876, 1.1445240820607832, 0.7692551769075856, 2.7561286620555387, 5.7406569392450395, 8.087048194100781, 10.99401920072494, 12.427641576336278, 9.705150915730385, 10.911157169649679, 4.00039910789459, 1.1496086995447836, 0.6961407872938341, 3.5548592863544344, 21.66906733666697, 50.07198526013283, 51.057818089762044, 37.48515821272327, 39.62689784265334, 38.457584381103516, 25.534549413188813, 5.536020023207511, 0.34813836096755923, 0.16040407181266816, 0.08740305555083099, 0.2306406674606185, 0.1582913238915705, 0.14169822717385908, 0.17180787279240547, 0.15424268710757458, 0.15309858075793714, 0.29915856017220405, 0.15031648649563714, 0.10083420096986717, 0.17439230104848263, 0.1284542370347246, 0.22686696431088835, 0.14609230832467157, 0.24384877404137967, 0.1606559615221716, 0.18500952891284422, 0.22115545707844922, 0.10155918061613076, 0.09975145060208537, 0.12846539127490214, 0.1218590550425072, 0.16421183523151184, 0.09297762456680499, 0.1809872761969605, 0.18660548924198075, 0.16409774941782798, 0.07914851945374282, 0.13726309903206366, 0.15192661945137287, 0.2439485952979134, 0.14781494895296712, 0.15485822343297545], [0.025852531412496202, 0.05032017887119324, 0.07014222893743746, 0.05177517519182256, 0.047183730639517314, 0.04686269000352872, 0.0554157016167958, 0.004042684280824277, 0.013664769677204952, 0.06183687056745253, 0.030075577688553644, 0.031384862170765, 0.06952707565599872, 0.04538377258746375, 0.012091054626169705, 0.024346551940506025, 0.03687861465638684, 0.02727850066167453, 0.02577980668584426, 0.02520524265785371, 0.04630020526688426, 0.0575221561255955, 0.05873721370834017, 0.03004983521907801, 0.06780192225931153, 0.028724688886394425, 0.05181645967006203, 0.025861873854732802, 0.05821262351087025, 0.0637475589680816, 0.052252321564141786, 0.10460156857246354, 0.0288394239595941, 0.02452449309789846, 0.036524931013944655, 0.05811045036440896, 0.11848992292558956, 0.07650419844374542, 0.017076670567715363, 0.033906116901386174, 0.03852058622625567, 0.019998740585100268, 0.0902400246911472, 0.04965622195853822, 0.7445073500275613, 10.70284205098306, 23.48406764768785, 28.109683490568592, 34.73279183910739, 27.754909030852783, 21.753337498634092, 23.848699023646695, 25.85504431878367, 13.883277273947193, 3.42840182685083, 0.19828413192543293, 0.4983395205870752, 3.2211749207588936, 1.8830325959190246, 7.471254708305483, 2.5525846164072714, 2.966778816715364, 0.47059294977976435, 0.3810132775575884, 0.2380538398339864, 0.3127726780310754, 2.9533586723189202, 7.627171864432674, 16.397774450240597, 25.99728907308271, 34.14980996039606, 41.58406249938473, 48.150137624432965, 54.52008639612506, 56.69225969622212, 56.89947459005541, 57.74407463689005, 56.12985849380494, 55.573768384995006, 60.93871962639594, 62.396954874838556, 63.650665975386104, 61.644765869263686, 63.97056664189985, 63.275083341906154, 63.151709110506125, 63.41714374480709, 61.81751489639283, 63.60831614463561, 64.27600552958828, 37.04786885169245, 48.45939297829905, 59.815352809044626, 63.38695718396095, 65.48937897528371, 62.51306879904963, 63.469750573558194, 63.00710308936335, 61.4626855234946, 63.04959412544005, 60.63627742951917, 60.26545263105824, 60.786578732152144, 60.5188024428583, 59.932557152163604, 59.19636749452161, 61.65488558430826, 61.08946807922856, 57.57005476182508, 54.091716504866085, 43.15597980253158, 34.137266220585, 23.319585015696866, 14.608005765945682, 9.091022476073235, 5.616546282845159, 3.329988088338606, 1.9922745275881983, 0.40383234019241027, 0.10965511353025514, 0.9551040623937884, 0.850979965781012, 4.856307593084151, 1.7340880656434645, 2.518286676176133, 4.826354413263259, 4.277531966086357, 7.1405778200395655, 2.19971495770639, 0.15740180388092995, 0.3814733593213943, 3.844651839425487, 27.379975549636352, 46.856634078487275, 39.483982363054835, 41.82049905100177, 42.5628468298143, 36.085817352417976, 20.126607033514208, 5.3752778614720995, 0.20279989848213814, 0.05854442002131574, 0.022266943067792925, 0.020303279687199863, 0.04084900705023639, 0.07245434357994988, 0.015264059615982397, 0.07934776360108968, 0.04257690304169252, 0.10412425749124059, 0.11025247825009209, 0.05131914986357574, 0.019315386326202465, 0.055211952872454166, 0.09453764771141353, 0.07091124331758869, 0.044048308965659914, 0.05177412948180592, 0.04489184837908514, 0.05856994990139239, 0.027557312616056977, 0.03039919046474801, 0.05244826770297462, 0.02624652468629422, 0.04395022289827467, 0.09990486736980178, 0.015417198676826253, 0.012983081659542458, 0.0550126014727979, 0.020541276392196457, 0.011847275872564605, 0.02646908088917694, 0.02817773083675533, 0.033661302013863484, 0.06437461342542403, 0.02091681843833818, 0.10339139480023615, 0.03699691778409385, 0.02837178282319538, 0.06703179705167009, 0.006368510939571406, 0.026105895841253862, 0.10742461023431633, 0.07902637439509554, 0.02570428956870831, 0.023492463496363452, 0.045847895465070204, 0.023149411239090468, 0.030218389884178198, 0.015018018987780858, 0.027511395221095414, 0.05643714196799744, 0.03438564197671029, 0.01709063060491556, 0.04949706719226895, 0.07663565913155194, 0.040033671163743546, 0.031240035163899584, 0.09777795448298417, 0.015801592868933036, 0.041442755835070726, 0.042825820330049724, 0.06783924606298247, 0.012775274564421946, 0.05795664289185117, 0.04672392466736417, 0.10473477594073742, 0.005189207637862813, 0.02913929758623483, 0.03271164793160654, 0.023691286295351964, 0.020171985623516867, 0.08462347405692262, 0.020827768378019817, 0.04186426507188909, 0.05897836286514517, 0.027764648567104054, 0.024377499977427147, 0.06911574772769405, 0.07890557765119499, 1.847862663768953, 18.58783571950851, 34.84411262696789, 34.9495106358682, 33.19854497909546, 28.523269968648112, 25.778677732713764, 35.06707583704303, 34.332992492183564, 13.683328570858126, 1.486302381080966, 0.04259947965282106, 0.08441599446438974, 0.10507881836665255, 1.342434010678722, 2.0372926732224803, 5.153052056989362, 6.43946837032995, 2.662542380632893, 1.3470589754081543, 0.28953591361641884, 0.900926630823843, 5.760199658332333, 10.457625273735294, 18.997029142995036, 27.881870269775394, 37.45636801565848, 44.44763198975594, 51.937864595843905, 57.495568952252796, 59.05532690786547, 59.516538804577245, 58.90895582014515, 60.09621412523332, 61.099721154859, 62.459136209180286, 65.21875504524478, 66.60256724203786, 63.333965962932965, 65.53419205450243, 64.62381778224822, 64.37426090240479, 66.36243189534834, 64.63292552578834, 66.4294102884108, 64.93029609803231, 37.74600367392264, 45.14784959054763, 61.74914406191919, 61.52341558087257, 64.21169827061316, 62.80846641909692, 62.93540608498358, 62.52704028160342, 62.96143493344707, 61.752254501465835, 62.61418750209194, 60.6179678055548, 61.79221560878139, 61.21334045164047, 60.70495420886625, 60.358361813329886, 62.805203007113555, 61.86786243992468, 60.382268659530155, 57.31335524589785, 46.89618725930491, 38.80067802244617, 29.688810110092167, 19.11227426221294, 13.040553100647466, 8.155503849829397, 5.657291864195178, 3.703109189387291, 2.0406742466072885, 0.6975330448439044, 2.3696629222362273, 3.363705517784242, 4.9102053719182175, 5.909288948582065, 7.353778250755803, 4.7619392891084, 4.087720138411369, 2.084410022343359, 0.5462170740769756, 0.04935997192777934, 0.22033497691154483, 3.827111245163026, 18.50747027704793, 50.634131508488814, 53.54320441522906, 49.7175245900308, 44.224915889001664, 40.86934389606599, 25.19025552657343, 8.317321231288295, 0.4124547517107379, 0.03367781503907135, 0.024250467277822957, 0.007378303881494269, 0.04180235367628836, 0.012740298820238923, 0.01385433526123844, 0.07307620779160531, 0.018583180555593104, 0.06249604709146004, 0.09606726482630738, 0.05206538461929849, 0.02764137161354865, 0.03553470874565744, 0.06736039514503173, 0.007373283132760516, 0.03465439711186675, 0.030962793689761913, 0.0625527912240115, 0.1395016998773621, 0.12989733217945024, 0.05364184801076209, 0.07369245657877577, 0.08809785899375716, 0.002320671126419198, 0.06839352599795788, 0.025461838062432025, 0.015149554369160005, 0.05983010708023945, 0.023355963865234967, 0.07450876922737207, 0.07065582194275434, 0.02306960786001817, 0.03240912364074781, 0.09029439395113338, 0.08483499093281646, 0.16408915391131756, 0.16958267848578193, 0.08726565768161128, 0.17699857813216027, 0.12470154001587823, 0.13514457480801692, 0.17686112663678585, 0.19314593425200832, 0.132694594982651, 0.17017455801608103, 0.11188957750076249, 0.08450004197056256, 0.1845116790143713, 0.14836596535338512, 0.1254440400929701, 0.09767821749612209, 0.18907926375827483, 0.10795062152488578, 0.14016196041578247, 0.16244014965430384, 0.08348193410183154, 0.11726261176649602, 0.16359548685291123, 0.19465074543991398, 0.1330856369027207, 0.13634465154140227, 0.19958088895486248, 0.08709981496776305, 0.15880670188175094, 0.14809466297588042, 0.13751535646377072, 0.1445310977437804, 0.15742671706022757, 0.10367388972231459, 0.13584957488121527, 0.17582281702949157, 0.38404248114074435, 0.16173747848839531, 0.11830216243622765, 0.18017503913612137, 0.0928920065803874, 0.159719648861116, 0.14285388612939467, 0.2150619017981714, 1.3901905835636201, 20.20765889075495, 41.9386016168902, 45.31313434723885, 48.69579030621437, 38.43032783077609, 30.565863847732547, 34.22970471843597, 34.53925817243515, 17.747522823272213, 3.98927943360421, 0.3515004450755735, 0.6926249953046922, 7.28975389272936, 8.74073128546438, 17.0662522315979, 11.763255807661242, 6.571853266608331, 1.1704005709578915, 1.191427171710999, 1.2624970871594645, 0.8065506046818149, 4.048510410131947, 8.476533178360231, 18.07743141728063, 27.343005249577185, 36.97978042787121, 43.68913581294399, 50.77888265732796, 56.595483056960575, 58.883162313892, 59.61966576114778, 64.08275819593861, 66.31315123650336, 66.1608926711544, 61.77513760905113, 64.29005545954551, 67.87782392194195, 62.82389702335481, 67.17916350210866, 68.51126317054995, 65.56714780869024, 68.80620187328708, 66.35526180267334, 69.04159899680846, 62.94915791480773, 43.13399099534558, 51.8501486316804, 62.66683355454476, 62.614356164009344, 65.84449860357469, 63.90041505136798, 63.628186871928555, 63.96175307612266, 62.59995714310677, 64.13645544359761, 65.52431552640854, 63.446286955187404, 64.13649858966951, 63.58298155569262, 62.40700398722003, 62.21127771562146, 65.7350056402145, 63.48476148420765, 61.20980639611522, 56.04166007811024, 46.31185216288413, 37.626273324412686, 25.74022085435929, 16.01024329662323, 10.927808611623703, 7.055744797952714, 4.581711772949466, 3.1786426997953847, 1.0247478898494475, 0.37056739291837143, 2.258473533776499, 2.173142860974035, 11.285400313715781, 6.309756569324001, 8.808142119838346, 17.29748183681119, 14.293608184783691, 15.145319488740737, 5.436675212075634, 0.7463067986311451, 0.5840282322418305, 6.456625307759931, 31.82189895260719, 55.393406037361395, 44.8031791563957, 48.297858007492565, 50.20285514093215, 45.73922926379789, 29.230665506855136, 8.546799498219645, 0.44936802418481925, 0.11112950336668762, 0.13462067792011848, 0.09042152624216773, 0.15136677771806717, 0.1382541869797053, 0.10329826915216062, 0.20407963303789017, 0.13679439111823036, 0.22197892498825827, 0.17770993673513014, 0.15031873879413452, 0.1257547193897828, 0.2153195678106239, 0.23901123523471818, 0.15382192097604275, 0.12618091708469775, 0.12491187711636867, 0.15704088453804294, 0.18405820092847272, 0.36090285667488653, 0.10585474285988078, 0.13691875783185806, 0.13540928882937278, 0.1955672164237307, 0.12855240354134193, 0.1101838980591105, 0.0772342955573432, 0.1720061976342432, 0.14893077133644014, 0.21592010413446736, 0.12323645048684652, 0.1657404717538626, 0.11063925306042356, 0.17877528924615155, 0.16628850041137588], [0.07198689205031242, 0.06634267032026284, 0.10700544522654627, 0.0429271507797943, 0.03328112322056005, 0.07086708600963317, 0.030688340775668625, 0.04402400482626211, 0.058255064781875386, 0.02795042680396188, 0.01854151877905092, 0.029903596695212108, 0.052314125707433115, 0.018236682817880667, 0.02410758996472484, 0.0586702308106807, 0.07613904263463712, 0.029998836745958657, 0.017717031972302545, 0.0920917128302878, 0.09459075292632466, 0.064778157900418, 0.09013320905186477, 0.10847250360154337, 0.039576565651523496, 0.06956004808025976, 0.06075307065921445, 0.10007570497691633, 0.07231001261501543, 0.0545865569954678, 0.04619792103767396, 0.060011103013229955, 0.05182712361396802, 0.03123887262547449, 0.06130855718267061, 0.029742710570233966, 0.03188076429069042, 0.041686141968614636, 0.018072711273787484, 0.02741509796901336, 0.060206899764917554, 0.030372566994159456, 0.08930922020226718, 0.047203426760050564, 0.055861790784664696, 1.0452034180202792, 7.3628855039996495, 25.08406323771323, 35.23190559879426, 34.262193710573264, 23.02809995989646, 22.36905351761849, 21.150477047889463, 24.551593642080984, 18.25943723801644, 7.267812153985424, 0.6434570433151338, 0.7566979539490516, 0.6730356980716029, 2.675300870210894, 4.994636351062406, 8.607309902867964, 11.594543880031956, 1.1118247528229992, 0.20599306020284855, 0.4168725662654446, 0.7381741930880855, 0.8638068516888927, 3.045415229374363, 7.5872465487449405, 14.322367983479655, 18.38287030496905, 22.966601117964714, 22.812042082509688, 33.01667251894551, 41.16360010639314, 50.48937251490932, 49.91288608120334, 51.99796315162413, 50.32036935129474, 56.69932780727264, 60.8599348991148, 70.22789632120441, 63.53571699511621, 64.44373784526702, 64.8873539893858, 67.23390410023352, 61.763150845804525, 68.31559181213379, 48.970956340912856, 48.02364118637578, 48.98881489230741, 51.89803292674404, 63.58643716381442, 59.64160357752154, 64.4748971539159, 63.566852769544056, 66.81638348487117, 65.83212744805121, 60.64265520341935, 61.58151765023509, 60.842539187400575, 62.46534139879289, 60.10055618901407, 61.81540466124012, 59.29107312233218, 53.78700325565954, 40.71231572858749, 25.19199705892994, 16.346039368260293, 9.794253437749802, 5.102510356133984, 3.855012044791253, 1.7331628765790694, 0.6864744124393309, 0.03362017075320886, 0.45779125284283395, 1.4624128178242715, 1.3249384010991743, 1.1911021052829682, 3.0546095102064075, 6.625190146507756, 3.043318477369124, 5.673173050726614, 6.756921477856175, 1.4581699164644366, 2.9865049066082126, 1.5995565297142154, 0.12977872644701313, 1.4515753090381625, 7.258862285844742, 33.55713982735911, 29.268124142000755, 12.224338266157336, 12.34678387641907, 16.425286935221767, 32.39653206640674, 20.636438669696933, 5.724666416645051, 0.23908309428201568, 0.053391555594580795, 0.13984363556148546, 0.055585508835652185, 0.14533599568230493, 0.02060140663337323, 0.06318428516087514, 0.05083730354184105, 0.016135418554767966, 0.012861697900769933, 0.06311919450038864, 0.024542716414397283, 0.05800634667637849, 0.06354291007042893, 0.03471579139811858, 0.00814877765914125, 0.013586505177250553, 0.05899445454199469, 0.07773716333172015, 0.04021353328660612, 0.10682670925293239, 0.04755508409993303, 0.024222187142098145, 0.025457111299939217, 0.07093670041931253, 0.03502008918252203, 0.02454459141459196, 0.0664741386689486, 0.05305597460978935, 0.029281203882888924, 0.024771680942766612, 0.025720624478473782, 0.08639957230057448, 0.04272178942037206, 0.11776342642523589, 0.0025520071757191252, 0.08232363214295718, 0.06634666929922758, 0.03321589083380757, 0.016379758467777603, 0.05423173188201843, 0.04285548325447787, 0.007166755883278506, 0.0789595408845813, 0.03568124221337419, 0.06684047425346029, 0.03262246763634105, 0.02240772896085776, 0.014985962038589342, 0.048434920759210666, 0.0610795237063881, 0.0488259818314785, 0.02950301506526528, 0.0871491127256905, 0.08311781251142103, 0.01585745504276166, 0.009975386952470628, 0.05989041735207843, 0.055941567350659645, 0.05389334701542413, 0.06341223845318442, 0.09932647098697002, 0.12890083565106317, 0.07252757392463184, 0.01785864715554541, 0.03440963968093838, 0.031893136610667554, 0.04329986787671524, 0.04522118957773332, 0.06987801287323236, 0.06824264498127085, 0.0702192131129484, 0.059467234213145516, 0.0288717107351629, 0.04443371630904656, 0.024182308435199723, 0.01709236962450368, 0.028669967225963072, 0.015733991355274715, 0.058417620978528456, 0.06938732589685148, 0.029527340272080996, 2.5060702091263187, 13.246402029068241, 31.43992873930162, 41.7665978400938, 35.00066226528537, 19.07406449317932, 23.35142093320047, 32.460223513264815, 38.01333673538701, 22.67877563353508, 5.858253519381247, 0.6564990467121524, 0.20955567548592247, 0.5022927181374642, 0.5016566200121757, 2.862423667984624, 8.104136490052747, 11.369432191694937, 2.2783724531050655, 1.8267539383903628, 0.9416257566021335, 1.0986633622838606, 1.7933426989663033, 4.282622221977481, 9.886408544355824, 17.813379418465402, 22.788853030050955, 26.224968933290054, 28.42219637286279, 37.32697294604394, 47.64443820522678, 55.963938313145796, 56.914677696843306, 58.63291901926841, 55.37049939555507, 59.65439834902364, 65.18217502101776, 72.05903130192911, 64.1503563234883, 66.65322073044317, 67.28048616839995, 67.38602146025627, 63.97869379289689, 70.31429829136019, 53.552147419221946, 47.3110249734694, 50.62967569597306, 55.46777025345833, 65.84638134125741, 61.99364108424034, 65.36857781871673, 64.1602328515822, 66.16894137474799, 64.48240457042571, 61.098069837016446, 62.513374743923066, 61.3815434517399, 62.93979521720641, 59.0485921982796, 62.64267175428329, 61.92911809490573, 57.12233189613589, 46.795715747341035, 31.647775134732647, 22.517083767921697, 15.311719179153444, 9.31036533847932, 6.890117814463954, 3.3861963883523023, 1.7265773396338187, 1.118111944487018, 1.0448239287061076, 2.1970749574322856, 5.897133033121786, 4.079353722833818, 3.8889228961160107, 7.726656900298211, 4.119041735126126, 6.803414802397452, 4.4876905987339635, 3.58616421299596, 1.35998698492204, 0.819031157560887, 0.2070506905475932, 1.4459633779141212, 6.325130299214394, 25.693154373476585, 42.794470633229906, 28.247501850128177, 17.438392985251642, 22.161061994491085, 38.21138112775741, 29.264646960842995, 10.123667813116505, 0.8706821537306233, 0.07369467823375618, 0.11845102864167384, 0.014237618625855014, 0.00822551572890652, 0.04313967506130857, 0.11330564506351949, 0.01757481732525893, 0.061909016897721644, 0.03841952773772421, 0.028671018681639147, 0.024548584647897272, 0.04981015583560352, 0.02704275625517532, 0.0299638552561162, 0.06701363310698541, 0.032390097847148296, 0.014911676407791676, 0.035276927820016304, 0.050483566273244164, 0.06632413099249525, 0.04693009807998615, 0.04767613748328821, 0.10067812587705352, 0.03680901939890558, 0.03323599298094069, 0.07608250534582524, 0.06046606347926202, 0.03544140689735932, 0.027893054479312514, 0.03061919751006269, 0.010798159637488427, 0.04216977710565252, 0.0594753930495391, 0.06913123036464376, 0.031186663733434775, 0.07099801809677193, 0.2589559819429152, 0.09522173358427902, 0.26093757561137604, 0.11310961082457535, 0.16694211130661352, 0.235970096001702, 0.1549828506164974, 0.13913367123853776, 0.14416342150540123, 0.12254914704469905, 0.12138850851765565, 0.28607782336973375, 0.23865057636172543, 0.1840133847849023, 0.18991727201688677, 0.27591496225326295, 0.18574967710000856, 0.12215916998684408, 0.10501523306893726, 0.15102438238118926, 0.27842947732537027, 0.16808791837144285, 0.2348551009931872, 0.13509387510918802, 0.17190659088232826, 0.16404467484643384, 0.2159458446887232, 0.1544637954042804, 0.12954269475754232, 0.15797198780121344, 0.12099478528985094, 0.1280741118675759, 0.16989352632193797, 0.17288332234226889, 0.23129084628195534, 0.19109834976974996, 0.12821218389416897, 0.12920353231170487, 0.22166507408743907, 0.11554549463213452, 0.12838021761948062, 0.08819788709403047, 0.15977157430062372, 0.147688927489423, 0.15498887206758225, 2.1462912953669027, 14.733925615587543, 39.84522481118479, 49.457400844943145, 46.899489894990005, 32.870438714181226, 28.991722560697987, 29.23645296404439, 34.21276007929156, 24.08475314417193, 8.534952959706708, 1.1192236912827338, 1.3606371177781014, 1.8375179027357411, 7.913968707284621, 8.856616731612913, 17.538997857801377, 18.994032452183387, 1.3452934185343406, 1.055490814389721, 1.239265501499176, 2.534376483771109, 1.63676964900186, 4.12163540240257, 8.275846089086226, 16.89414058962176, 21.237847843477805, 24.8534631729126, 25.360910008030555, 35.368035377994666, 43.11039401638893, 53.32816831527218, 54.68873654642413, 62.19343485370759, 60.91433817340482, 65.79245267375823, 64.87945041348858, 75.48974806262602, 66.91317973598358, 65.9020789977043, 70.27856549909039, 70.7474377847487, 65.17194547960835, 69.71290480706, 55.76373269481044, 52.06936990061114, 50.548961162567146, 58.22461205144083, 64.61982088704264, 60.75840826957457, 64.36267814328595, 64.1168906611781, 67.81490125963765, 65.53305848952263, 61.91318542726579, 63.16882241156794, 62.83573473653486, 65.14238649798979, 62.25858934463994, 63.41228000579342, 62.78586964453421, 57.76881694793702, 43.38753692565426, 27.410962273997647, 18.878667700675226, 11.24961849181883, 6.661863327026368, 4.587619843021516, 3.0675288169614734, 1.2685620520384082, 0.5833861279872157, 0.8263829050044861, 3.20108110866239, 4.368697164520141, 4.8425606662227265, 5.774570732347428, 13.803009890740919, 5.614130102819012, 12.275334961952703, 17.43083457792959, 5.498098058085288, 4.554755283940223, 3.1619495826382793, 0.6268518730517357, 2.1951267651973234, 9.443520980496562, 40.70453766853579, 37.59740467994444, 18.752292856093376, 19.92188088355526, 26.162305147417133, 43.007231758486846, 30.87597231711111, 9.25594441352352, 0.572596974670887, 0.16632623790252596, 0.2836865258793677, 0.14265064300308306, 0.3041403686567661, 0.12200574555824842, 0.24299107732311373, 0.13480787916529563, 0.27659512575595613, 0.11958616410171795, 0.1919977982798892, 0.17084509945444523, 0.19628971394511963, 0.05844597389260608, 0.14525760956589254, 0.09223594420379208, 0.08723432468550821, 0.12660604991739796, 0.17977048342506732, 0.13565482000910467, 0.2109386020850751, 0.14336858996220175, 0.09060297416703356, 0.21829111561659845, 0.11111719233374442, 0.16317159508264836, 0.16390625808027484, 0.17158743865307302, 0.14416357472298608, 0.17171419556102446, 0.07422028349772578, 0.10650810860698262, 0.1831816584472695, 0.205735991738977, 0.24181969824337193, 0.08225086911190903, 0.149127334176052], [0.04301820799047428, 0.08297833088304728, 0.1088487983290707, 0.06038219217331179, 0.0486077425340491, 0.03804420594186072, 0.05999705296069865, 0.05128921497793448, 0.07430865940067076, 0.06715928174314961, 0.023536011764419176, 0.036988161399119326, 0.08017367533137722, 0.04488222248431656, 0.05977996662559529, 0.08486591790231966, 0.02163649484094593, 0.010172553086322884, 0.053155634987859, 0.0519422896116251, 0.0464928763798408, 0.06386898390408005, 0.04939288306500643, 0.049340149402738585, 0.022127501659035202, 0.059048881258575193, 0.07757083032160036, 0.027703141282883384, 0.014234077384425028, 0.0883143860846758, 0.019826847691870025, 0.08249234768652147, 0.05316752467244383, 0.04840774379009682, 0.0229677239117483, 0.05494673706350788, 0.07217132771808295, 0.0532953043077742, 0.0530859248171891, 0.029825716196829756, 0.0146968241765975, 0.08507928871099027, 0.043203528489797347, 0.04965558993600069, 0.0459525392450873, 0.08401030494320778, 0.29467838606046093, 8.524869526586226, 23.652933528346402, 38.71709623644429, 32.45121579016409, 19.894338000205256, 21.628323716502038, 17.008844421755885, 28.493018688694125, 25.22365843096087, 9.302070506157415, 1.7353927440220311, 0.9189728431163297, 0.3355124046004588, 1.9281120285872493, 12.430866745210464, 9.70172570597741, 2.3737993067310703, 1.5721537485238046, 0.3256917396380056, 0.19860621061055891, 0.5040139338422207, 0.10965855326503517, 0.24674118496477607, 0.908239031991651, 3.4589999914169316, 6.809972024733021, 8.907423192454923, 10.482482314109802, 13.099614189517114, 16.993264767431445, 28.499206227640954, 36.737401485443115, 44.7045668478935, 58.15529200338549, 60.053432833763864, 61.99381759089809, 65.72039481132262, 64.59855771833851, 64.21461259165119, 67.08404602543001, 63.581083128529215, 68.10248944067186, 41.634543403502434, 44.07896449488979, 40.53041581184634, 40.190746399664114, 65.59664403238605, 63.48613823613813, 66.77777167289489, 66.44247962582496, 66.17165565490723, 64.33290343130788, 67.36080062004828, 63.89647699171498, 59.67058204835462, 58.62482324723275, 56.46400520878454, 42.886069743864, 24.736692251697665, 13.219851505371834, 4.224463278247464, 1.786526845347497, 0.20691783557976448, 0.14384249195216164, 0.18434651045789643, 0.9884383253032162, 0.6512561861065127, 0.5199571122084895, 1.5778129932380494, 1.0460062781649253, 2.4985645086534563, 8.578551084764543, 6.130552791780041, 4.592361007967304, 5.93846942147901, 2.9874173479695476, 7.2444760126452294, 4.707990029165822, 2.323612580376287, 0.332802506464143, 0.5226649572291683, 2.6838957638509813, 12.19540588317379, 39.36687607919016, 25.684654597313177, 9.472837755756995, 20.89768813502404, 28.930515935344083, 39.66843966514834, 29.78692819995265, 6.935967380000699, 0.23604368640770837, 0.03360068913729441, 0.00869006282770105, 0.07658273011686341, 0.03414281125691149, 0.018644749126847715, 0.0319979508452478, 0.012466697221351488, 0.02828176749209243, 0.04106520089290796, 0.017419625148778, 0.08712880373481782, 0.011392159316117966, 0.04106000681678134, 0.03416410084032724, 0.019887778494927674, 0.03403798744623219, 0.05269921129389156, 0.0938802753244677, 0.07127369483632427, 0.02500570548187581, 0.029808253222595782, 0.040204776901631586, 0.08136583071562552, 0.008890105621708978, 0.09300810720531211, 0.16219783604385393, 0.082839148028964, 0.04829247437056996, 0.03552019904037157, 0.015618773646682743, 0.055518292281175816, 0.10789910977285717, 0.05019247967509493, 0.0218573771417141, 0.01995925449826304, 0.04911228038010098, 0.11344659758070785, 0.04256149701353523, 0.028937816462149064, 0.04935605338804665, 0.03470970482956018, 0.017699651352520433, 0.06461131161138897, 0.0214288811830263, 0.07713373885640214, 0.048382098996831525, 0.0544488909954746, 0.046740353422900366, 0.0477878331026483, 0.009239734743811913, 0.023749581755950086, 0.07241786247299564, 0.040030277394238985, 0.04410166698958605, 0.020265115102032022, 0.02253214355498072, 0.044865877998452035, 0.01787300364324643, 0.019263985656922864, 0.05130269046452257, 0.04401101197506632, 0.025936165231189905, 0.05722755701431344, 0.08162542726964721, 0.023298871162677967, 0.024666638797028892, 0.07078471623601452, 0.019676238636396105, 0.08683754476688563, 0.07757900447975244, 0.06526499911541901, 0.013023942874203767, 0.12313580951623379, 0.052025701264820756, 0.10607006719275829, 0.059716431123595086, 0.0311432495307658, 0.09333505820963653, 0.031676833600466775, 0.0461122379337828, 0.08753168171331768, 0.046910214267911456, 0.08177479143224417, 0.9941076823780615, 14.442510181857696, 33.29085011636057, 44.058434809407885, 32.7498121030869, 17.099047168608635, 16.74895405769348, 24.97342101989254, 40.808915861191295, 29.294923736203103, 11.448572874069216, 1.9862801653723565, 0.06760682264763503, 0.32052711193119326, 0.6964046279749563, 6.075616075146583, 10.595941774306759, 3.1782651716662995, 2.4309842769176733, 1.1284796268709245, 1.2493842359512084, 0.9580968308352655, 0.6164220456154116, 0.8337796371309989, 2.353379692762129, 4.42072005041184, 8.567984219520323, 10.955366203861853, 13.485243974193452, 15.614747770370977, 22.278937062909527, 33.28088337375272, 43.41089071766023, 50.90598314039169, 60.836996878347094, 62.173870071288086, 65.08642604274135, 66.85455599138814, 66.48280943593672, 64.45180616071148, 67.59316967379662, 64.93281425968294, 69.74287171517649, 45.79906502077657, 47.00470747486238, 44.67509808078889, 46.7485688578698, 64.99227346912508, 63.92933468664847, 65.68090046605757, 67.59400906101351, 65.84875829758184, 65.28783975108978, 63.79710766576952, 64.71447944641113, 62.692532923913774, 61.63263790069088, 58.17680228141047, 49.732096195220954, 31.38664334051071, 21.026245778606786, 8.21322250750757, 3.7193730521586637, 1.2317579624152954, 0.5748759330280366, 1.0800533092791036, 2.5730093784870642, 1.5128216483900625, 2.5254955022565784, 1.6192532018307717, 3.624340641883112, 4.051795150003126, 8.691495733876383, 5.84884669511549, 4.463336602334054, 6.555162600932583, 3.7599156508522653, 4.602491999826124, 0.8364454392463931, 0.23045107602111756, 0.46019005799485796, 0.09982342456257152, 2.974194302674263, 11.607244514649915, 32.31677459132287, 39.13281256152738, 15.58234016741476, 11.769109945143423, 21.43045190841921, 38.648038987190496, 35.50489079567694, 10.922316312789919, 0.5686923164513804, 0.01185907649942824, 0.056407490534888166, 0.020490800774085428, 0.05200942955730904, 0.024220130196021452, 0.024205946078103398, 0.09359351329265103, 0.032603361403509494, 0.09729358773197859, 0.027344365070964542, 0.06332701883248745, 0.04205312872786195, 0.0724186975088331, 0.04260650084864709, 0.055781657987784956, 0.042255659392403985, 0.043966540571061835, 0.06458736370287596, 0.0646561507375971, 0.0257996981587982, 0.03211821707326078, 0.02614904382836915, 0.024156066093353495, 0.03592386608943343, 0.07814351168851699, 0.06861114859460823, 0.08726774144076532, 0.0972844789465589, 0.013568472425122897, 0.016749547193607977, 0.11010775658031625, 0.12585792675494187, 0.026228736124692426, 0.058039713635920524, 0.02336961555204565, 0.034017728251074596, 0.03607836304112308, 0.1660375300073816, 0.14543627659159322, 0.18745175592841642, 0.16278884223391935, 0.09456161094168503, 0.18800067324792186, 0.14608527563752668, 0.2127180404720768, 0.19734458637333688, 0.18016717907401825, 0.1368551572123843, 0.1349254583399142, 0.1514768492310278, 0.15507764633624785, 0.18476598956171544, 0.273622551392163, 0.11670221844988486, 0.1030488309240149, 0.12741369045069142, 0.19540267605935374, 0.111067074861738, 0.1640164062020279, 0.12436284488367459, 0.13524651046722166, 0.1093783259632126, 0.19180051531762848, 0.11927659563239544, 0.16748866907531218, 0.1480695506137225, 0.22801880814856101, 0.07304515824803422, 0.20326656860209283, 0.1741623520971306, 0.15847207467642524, 0.07949725033775454, 0.27958066232742806, 0.24446717553561736, 0.22680019208740806, 0.10546309573035087, 0.1847236555430197, 0.2108953487608702, 0.17028849061218002, 0.10963219217956068, 0.25333147165515735, 0.1788953045803693, 0.25216974528326147, 0.9590537665832428, 13.211548828309583, 36.400018815071356, 53.14402480279246, 45.11966736085954, 28.670639299577285, 29.60518910038856, 23.32414084865201, 40.37383087219731, 31.168777250474502, 12.39091250204271, 2.3460514795395637, 1.8518591912523394, 1.7086651007975302, 4.780027299158035, 21.565201013318955, 19.852211744554584, 9.652517610980619, 3.556582187452624, 2.0021633130888787, 1.1817831666238847, 2.6711139852000825, 0.43175180172247274, 0.6355667667042825, 1.7236967264644563, 4.453424772908611, 7.78656522112508, 10.042662043725292, 11.414589458896268, 14.573367314953959, 18.767044890311457, 31.046566001830566, 40.738407334973736, 50.144251008187574, 65.65424403836651, 69.84842269651352, 66.02269972524336, 68.00185711153092, 68.55517018225886, 65.67207905554002, 68.29386188137916, 67.40662174840128, 67.30241221766319, 52.99671234623079, 49.144893846204205, 47.07720856512747, 49.867229692397586, 67.70865209640996, 64.54780224830874, 65.0269982122606, 67.50208439365511, 65.71280110266902, 65.7747039487285, 66.94764952505788, 64.18217459032613, 60.71372855094172, 60.84829330444337, 57.91789054870606, 47.531768122027, 28.192761252003333, 16.011304297754844, 5.361880515852283, 2.7796523417195966, 0.74476849407919, 0.49998866273991527, 0.6971882439909444, 2.9537163434490084, 0.7575735618029872, 1.7614554229282566, 2.237616330385208, 2.5201022432696436, 5.556760536086175, 14.923423163352476, 11.538058807772975, 12.409424128070956, 13.382707334333851, 11.130997192475105, 12.866426340995297, 9.981700566507156, 5.803148631126651, 0.6642177196279649, 0.8049739344466118, 4.302296340465546, 15.622849425961896, 46.87124490737916, 34.971985816955566, 15.347083268627046, 29.923511012907955, 38.264988160902455, 53.88634904738396, 41.04932185142271, 10.936516273406244, 0.5217925975880315, 0.15557784046376907, 0.14029939658939838, 0.12434278870181692, 0.22029938446658276, 0.16348227437946106, 0.16279924570793108, 0.16401614573213363, 0.17777749036829318, 0.19043356931257635, 0.16364451648006517, 0.15618439823869737, 0.133139094518077, 0.2346135534706616, 0.13572554524627425, 0.1033409862148185, 0.06696997375618066, 0.08120426277239477, 0.24080020375549796, 0.16041426078206109, 0.09681522711029938, 0.15435933165492552, 0.1672643125658074, 0.16821677436030683, 0.12281406024891524, 0.23490339517593387, 0.28175405376861173, 0.2371999429118249, 0.17356540106477278, 0.12664366483448014, 0.09770491566028326, 0.1894498204872493, 0.2698603242395386, 0.2407456429735307, 0.1267129574872313, 0.17247177990934542, 0.1123136378103687, 0.18385711817010758], [0.029716924050702687, 0.014202991451677537, 0.012852435897765382, 0.03491973549488091, 0.05454350285412324, 0.007346076956544553, 0.09419440201693967, 0.019955893287495263, 0.02784890674745604, 0.042593121123049534, 0.0070778509008608045, 0.03180860263866282, 0.07373956332523977, 0.026239221953156016, 0.03219358097281187, 0.012633638313761162, 0.051374687407646454, 0.0441644785384978, 0.0735500561554105, 0.05575729256135322, 0.06432549952859841, 0.02471651112089955, 0.016827477487705408, 0.047604201827198274, 0.0076728780949187865, 0.020611854157440608, 0.07182256619055426, 0.05250287828065696, 0.025705321872186278, 0.06104891466337347, 0.00966476606986215, 0.058765363609117854, 0.05763485148969678, 0.045786949340254075, 0.03464985804091539, 0.028376923273167307, 0.08849168947387127, 0.016321064641458854, 0.05820647948571752, 0.06656256053716907, 0.04315363701372858, 0.03314235405395589, 0.06068586176561733, 0.03501481849760298, 0.06064912784964808, 0.15707247800404028, 0.04026790637703192, 0.2587408644537772, 5.208990939201848, 23.952031904651275, 37.05659220295568, 34.07288835894677, 28.802281887300555, 25.43447013824217, 20.53822644295231, 34.513413675369755, 24.58896206271264, 14.585429583826373, 6.188387159378299, 0.27504459444072943, 2.409440168449956, 2.5317725202729626, 4.64931970642459, 3.373721044871115, 3.6365568637847905, 1.55931607609795, 1.6369499554557185, 0.30715979695800816, 0.5926807969808578, 0.04707690733935564, 0.12644048299520247, 0.13791591319586002, 0.45648403105235874, 0.9873966908743306, 0.8489304660789428, 1.4193507091652964, 2.0424480159436507, 2.967378939351728, 6.66562831209552, 17.66175823826944, 34.136846526976555, 56.643637995566095, 63.95141370834843, 52.513464573890936, 58.45232917416481, 64.30971437884916, 63.21519267174506, 63.64614348257742, 58.21878340936477, 33.99264058759136, 33.524199762652, 33.41282013923892, 36.796127211663034, 64.56469589664091, 56.87608549671789, 66.099060427758, 62.0451339598625, 63.24463398225846, 59.71450474954421, 54.111081246406805, 44.83280874067738, 37.43681107797931, 27.15264674155943, 14.97138394463447, 5.067395337166325, 1.079215883247314, 0.3274198807775974, 0.16773369463701404, 0.05615066721915238, 0.4866085694201531, 0.6903075486902268, 1.6840688980394796, 2.3535034925706926, 2.5704534640235286, 4.087278381470711, 2.039604542716857, 4.527706619231932, 2.952715158462525, 8.196980462920282, 3.250944974922365, 1.2902751901457388, 3.991931691285103, 1.7222657967959683, 3.4078503231848445, 0.45104836143793603, 0.7262800345497747, 0.9977381424077096, 6.927135673261459, 16.842657519925027, 47.50301322629375, 32.394578726060935, 9.57046554934594, 23.036891952637706, 29.257484712908347, 32.33831036475397, 18.179256146953954, 2.8635574781125595, 0.07262520416970215, 0.052163715834819505, 0.059736717131830035, 0.05510824755014432, 0.040843330338717475, 0.012319024197847374, 0.04444863587137192, 0.022860580769878243, 0.04017529783830528, 0.05201421760683579, 0.019345058826729655, 0.03479646811742456, 0.07885255670595555, 0.023194309737112735, 0.018395670960026405, 0.013150995683615968, 0.01243777931742971, 0.027136542654085546, 0.0650060613970122, 0.04092322181790106, 0.04414652143755267, 0.04481535833028536, 0.016315014462076848, 0.07241547993955112, 0.01929272736062206, 0.07957245718928115, 0.0334117450420895, 0.06596842104749334, 0.06164281666579266, 0.045793411291895375, 0.12055235419182048, 0.08358178600188225, 0.017060789565045028, 0.02243849122145724, 0.08181442882144645, 0.022348180946503437, 0.05642170912676281, 0.03642296854166254, 0.04057266764462956, 0.021417855262576092, 0.01371357522364105, 0.01920939806187826, 0.03436920939073448, 0.04036665894091129, 0.04362689932027171, 0.039247289570348884, 0.029814485347859805, 0.04524105806804953, 0.038377427375845374, 0.03184785889912277, 0.03982180571784416, 0.054018587069285494, 0.02608770316827201, 0.04444103627916306, 0.0570585810008549, 0.04427522803927141, 0.027157431956560864, 0.03315333975479007, 0.020552093553687298, 0.009817795963176798, 0.030309224929360133, 0.012613466261104952, 0.04730522452342895, 0.06182485447836019, 0.021695878146396532, 0.04303975421334467, 0.05357136409128866, 0.08270827722885916, 0.0004022410182862528, 0.11044660493010476, 0.06584306608044332, 0.033486936571857626, 0.03489660347000726, 0.049660385646406686, 0.05188613153633572, 0.0014817104050551633, 0.014688755355535016, 0.02891748640385847, 0.034144128928141254, 0.05282264721069125, 0.048388480509240786, 0.03788654887748342, 0.009646379002069515, 0.04284391915726085, 0.11925464721336482, 0.11908102870708513, 0.5784432674127241, 9.50805377575659, 31.23299821730583, 42.1536494839576, 30.17475647311057, 22.90477083575341, 12.811952464042172, 26.12173999509504, 39.325761795043945, 29.165279596082627, 20.0154431404606, 4.926994587144544, 0.29982763072175367, 0.5827120931879167, 1.9434826941259447, 0.4376068891536805, 2.348669416481449, 2.9118271460456233, 2.939331050842039, 2.4176119364077047, 1.8599268938264542, 1.649683562497939, 0.5024004300996181, 0.653084991199355, 0.4598667995343286, 1.0305903827951801, 1.6463470963701126, 1.6734411134835214, 2.397251157991348, 3.326239528194551, 5.6495608725855435, 11.124441931324622, 21.863871851275047, 42.363778698828916, 60.251661577532374, 66.26740855555381, 56.852763083673295, 63.74193560692572, 64.56984204630699, 65.55074837899977, 65.21412664844145, 61.37268281752064, 38.88329098301549, 38.319434581264375, 38.21721761457382, 43.24202091463151, 66.25700642985683, 60.04552533549648, 68.84524514598232, 66.29640271586757, 68.64100733110982, 61.65437175381569, 58.01720103909893, 50.281400603632775, 42.4180172335717, 33.623055258104884, 22.43054843718006, 8.538222255245332, 2.554671807635215, 0.6865696524900775, 0.2519877687577279, 0.25354781488497413, 1.471126118013936, 1.9877520347795181, 3.3635037608685034, 4.259315498413579, 6.626275172156673, 5.14068139176215, 5.2139311644338795, 8.241667535997207, 4.5714351630979975, 7.491268111813453, 6.561245216477302, 7.544297085654351, 2.99997408063181, 2.8256536539523833, 1.2337511393331713, 0.16767775489678308, 0.4908136873235626, 0.7229020158129355, 6.914782168403749, 19.520973467057754, 37.51738440605902, 46.30966348032798, 15.113686553893553, 14.493601014537198, 27.153125270720455, 39.1711498075916, 26.397080575266195, 6.9753876905287475, 0.11738358471061915, 0.01764195535572306, 0.021945617064052535, 0.04297218908886275, 0.05686939941839345, 0.026696045928063895, 0.08882673802755534, 0.023869380670329256, 0.10567388482271664, 0.07706012546775803, 0.0730955898160896, 0.053690398832963365, 0.03613475477322936, 0.030540296199521234, 0.01887830252188348, 0.02044532579490014, 0.078043682771104, 0.012566133518703284, 0.05695254677125523, 0.0742283963688439, 0.02697585954240734, 0.046321762981073517, 0.037708624957069274, 0.0388672984685869, 0.02879839420558945, 0.026352537848475962, 0.03703521068898901, 0.058014471038815484, 0.04154024052343542, 0.10268471699448363, 0.1079920362380724, 0.0159626082712484, 0.01644188436799713, 0.015134402107627643, 0.06269629864442734, 0.04259373016294934, 0.028906824375172297, 0.05782304864917552, 0.025123169743305734, 0.128304505149924, 0.08704726899703664, 0.11360760627975387, 0.1784583586718767, 0.17749913998188513, 0.07268652184716157, 0.14925278873453218, 0.07757068476489476, 0.168643515977648, 0.11779623031015359, 0.06355852677276538, 0.14486448388666878, 0.11848600821629648, 0.12444883059229582, 0.14668195087823177, 0.149614428200068, 0.16231129366543987, 0.1365093298016056, 0.13486081584086343, 0.1508745509049585, 0.17829436989080522, 0.08659382921553428, 0.21690570689257116, 0.10442354506061924, 0.1422899841300903, 0.11853230290956075, 0.1452523388809735, 0.12053265041040799, 0.13406653588096942, 0.15559467907634475, 0.15874492455153696, 0.15481443384722357, 0.1607722077038019, 0.0976784703051371, 0.09419487699145272, 0.16364401086203514, 0.1666162021818661, 0.1398264445484646, 0.12616061575470433, 0.12772373389452696, 0.09022142407634566, 0.15665215620350453, 0.2541615585646322, 0.1665296495681809, 0.1358147178806605, 0.27010844479645457, 0.18849780302374594, 0.39707207391338967, 8.306600413014813, 33.81197621745448, 52.6579019331163, 47.132400235822125, 39.20835741104619, 34.0142842262022, 27.597678861310406, 43.1213648857609, 33.815922121847834, 19.84141738184037, 7.208315682026648, 0.4154202474221107, 2.9269196910242883, 3.4209905084102386, 10.629106394706234, 11.388579241691097, 8.912277125543165, 6.306417651714818, 4.003419823223545, 1.9763019008021203, 1.3016739655886929, 0.6096231685050073, 0.524917010578417, 0.30530675284324155, 0.7716385683705731, 1.3455020395978805, 1.3166207700006425, 2.0518652590051776, 2.5173139283733987, 3.658864363547295, 8.711439025017524, 19.207852617386852, 36.78746661832256, 58.1025988824906, 70.7590558451991, 62.232458514551965, 59.41704396278628, 65.86025868692707, 64.75427189180928, 65.87139037347609, 64.03554462617444, 45.77840981944915, 40.06927451779766, 40.658147796507805, 49.008128643035896, 69.74351498388475, 60.79258780325613, 72.48071747441446, 65.61895055155601, 68.0202373381584, 61.30233118610998, 55.54406427568006, 47.581295890192834, 40.1619444354888, 31.286228702914332, 18.096135239447317, 6.582406403556948, 1.9004746406309068, 0.7170426689328686, 0.3183651198783229, 0.3529544799558578, 1.1904397150201182, 1.8839099810969446, 3.1429018176371053, 4.6590393397115895, 6.401781747418066, 7.511845846329966, 5.9582906288485376, 11.059191342323057, 6.23249372166972, 17.23178017523981, 8.62281503215913, 7.0047358447505585, 9.3887686152612, 7.587930512043738, 7.41597919694839, 1.0461423353802775, 1.2153130577456568, 1.4121054785866893, 9.035495442728843, 21.716684910558886, 54.12135785625827, 40.135852829102554, 15.471385140572826, 32.635504430340184, 39.80950378602551, 44.088833178243334, 27.769719900623446, 5.9509773696622545, 0.19549937167715645, 0.3897138300441927, 0.1478578958420023, 0.13857821152815897, 0.18061736298184242, 0.14232689424628212, 0.20873930155029222, 0.14567973933392955, 0.15824322889168418, 0.13615705193050448, 0.17094294420413433, 0.11689569395516189, 0.21285961352048383, 0.11154910504457452, 0.1640080864871702, 0.16003601253032684, 0.15099150188747915, 0.15615620620308385, 0.14471275251238577, 0.21979347532314641, 0.2666629490352446, 0.18926500943639588, 0.1423431046667599, 0.1253018618351029, 0.11439758082551342, 0.18223880339534054, 0.20533082315758353, 0.1885867611535134, 0.12934463038559885, 0.2521252815401362, 0.2492697194458977, 0.20277880042070345, 0.16404400068906047, 0.15946002166357734, 0.13228397185523666, 0.19097166947059094, 0.16883290823428862, 0.17181355716480365, 0.15309248269805986], [0.017379616206932454, 0.017980824772929473, 0.026378801257740107, 0.008774857269600034, 0.05874488990934146, 0.08406174008644397, 0.028329040862679965, 0.0448342653802566, 0.06210178760210834, 0.03313903689324375, 0.03499888386877795, 0.01411192179206879, 0.03163167463255025, 0.01444864616308722, 0.014015205106848191, 0.033346428385665344, 0.033021764153794896, 0.06827174866151425, 0.07649484451018995, 0.011126028032102173, 0.014774295775550268, 0.05059005249471915, 0.03452991548505041, 0.040101182662070765, 0.055218464619810545, 0.07775445393617116, 0.06303575603411564, 0.03438724310047204, 0.019949247474752126, 0.05968589868937289, 0.04287545899710348, 0.06718450901849617, 0.05405378114852694, 0.0499796221453336, 0.029720245041854443, 0.04135513835917077, 0.02106890987394558, 0.05582030329312529, 0.06368718357876905, 0.05150817822845233, 0.015062363029667928, 0.0219360179823613, 0.01256469040057592, 0.051554166486546885, 0.038392262668499065, 0.008559877676288448, 0.006457666336979357, 0.09964089645373245, 0.020822601114970543, 4.115238997244066, 20.57066640546245, 39.752064597222116, 39.42049095707555, 31.678365699706543, 25.480714882573775, 25.502727223980813, 21.25280580212993, 25.14787039449138, 20.57052520013625, 14.320932395996588, 2.7033350304249795, 0.379651939316142, 0.7880715833556268, 1.8515162290103975, 1.955530621832417, 2.139850518395824, 2.374347948258923, 1.7566794469471902, 1.6147416181141332, 0.959259016859916, 0.9168645078616758, 0.35133423463952157, 0.11625879909843208, 0.22107877167722872, 0.23878867137095622, 0.028024019125188072, 0.26535824001316105, 0.20273770746444503, 0.14159287476251203, 0.41151886805891996, 3.056979357234894, 18.321387152517996, 40.11451905773532, 51.328606759348226, 48.30819345289662, 53.15758835884833, 51.291614886253114, 40.100853520054976, 38.4553760866965, 38.91348146623181, 31.838690619314875, 31.892619286814046, 40.96372788952243, 61.333721914599025, 50.95991180789087, 37.02932780788791, 24.20037873329655, 19.277431541873565, 16.557524742618686, 16.61127886464519, 11.011612992132864, 5.811795986467793, 2.2620894687791027, 0.4375113120242473, 0.05123875659680174, 0.006822105853878443, 0.04517541199381794, 0.30023672167331944, 1.2485014575143016, 1.4556341041480343, 2.2172781055973423, 3.626204993455641, 5.560052875549563, 9.995701466837238, 4.697148107713269, 3.2041091784354183, 7.640633438864063, 3.784542742275423, 3.58774860539744, 5.961862927482975, 8.038667228914077, 1.8618373332485076, 2.119908452995362, 0.344999851959367, 1.1563919484615326, 3.3420094174723474, 16.822112144962436, 21.990313376149825, 41.77630178390011, 32.005222689720895, 10.323801848196215, 25.48596497504942, 29.094506309878444, 32.563397538277414, 13.861159028545504, 1.4220410873813014, 0.2681503853490276, 0.0206967577668688, 0.09242987936182369, 0.01938533206890908, 0.019817206475342956, 0.08626532305272357, 0.008373860036954284, 0.010200252910445054, 0.008099208897610587, 0.056464882011735634, 0.03603505992120312, 0.02149279589854902, 0.020557808569602428, 0.12761430589542275, 0.0694635899497136, 0.06224688848540668, 0.04741256876337913, 0.003322552295304054, 0.03414571473014451, 0.04936225103935407, 0.0368538738468722, 0.08569670195180563, 0.056591439736826774, 0.021658456666515242, 0.05708632870547234, 0.040918529529364846, 0.06855522417613576, 0.05617140138882303, 0.06351184520509935, 0.05057775295309482, 0.03838183621184961, 0.04289495976521604, 0.05766230425046337, 0.023405939610975406, 0.07623458145967416, 0.03528322123231427, 0.04455197730191773, 0.04782258668133328, 0.04767390433698893, 0.055219322638285745, 0.0294815416207477, 0.07168549007826275, 0.056503397082128835, 0.06383381280747634, 0.027634693242068735, 0.0480799347672972, 0.0242561478197815, 0.05536110636087195, 0.030261643208383076, 0.06136336311277363, 0.03070756192168882, 0.060962044123199687, 0.07636745174926135, 0.005777521028874383, 0.023929035936992978, 0.020631182555770202, 0.03386491286237875, 0.043598029296845205, 0.024411531518243497, 0.054143888410180814, 0.05518651875336805, 0.02870221952757528, 0.0366034550261834, 0.05676429981606142, 0.00896528853298796, 0.04032810173568226, 0.04068392276343319, 0.061424799533861305, 0.041806184115909764, 0.021258026338933457, 0.06154034474504091, 0.024903377202609857, 0.01582708635983328, 0.06316892509799331, 0.05862790062242459, 0.06689695025523824, 0.018374400528808756, 0.08356353012664665, 0.012775045695654567, 0.026033241977734912, 0.035781086452545664, 0.004372122676877846, 0.039389605724042466, 0.06073089624424616, 0.042761591518478054, 0.07058190977981976, 0.0075374734907170705, 0.02812527105092041, 0.11510485617984688, 8.228804123017097, 28.60823439013574, 46.41331211213143, 41.19227263235277, 28.221555371438306, 17.17382715594384, 31.654774604305146, 26.900369698001494, 33.030106636785696, 31.220454477494766, 11.96902628867857, 2.845301541589922, 0.2783025212345585, 0.42129344517184847, 0.25746925043002256, 1.183884699017771, 1.6525250745396463, 1.747840508337944, 1.9461763818417828, 3.9362688458734945, 2.418873468714376, 1.4258419866523435, 0.6464125492399739, 0.8284631095105602, 1.159024716865632, 0.7268016484956588, 0.36596715750713504, 1.6943053035966813, 1.3909236990636396, 0.8097328726322421, 2.070048999401831, 5.895957792958906, 25.36281824111939, 47.89530907907794, 58.42514322650049, 54.75208282470704, 57.50119755345007, 56.84080769938808, 50.1761830237604, 47.6349852931115, 43.63377940270209, 35.72491222812284, 36.365823591909106, 48.503272533416755, 64.13056796596896, 55.62658309936524, 45.078219675248675, 33.411596359745154, 27.866702464319047, 24.609205415171964, 21.738707057891354, 15.935104412417259, 9.66768051347425, 3.6105437048019904, 0.6971859763706885, 0.25026581760856415, 0.0563178850608247, 0.21557180992057248, 1.2828833609819412, 3.155939530941748, 3.5031523964097424, 3.9825594329064895, 6.904599205140145, 8.106465887638832, 7.974918417392239, 9.088823006999109, 8.443929456895399, 7.405556969104275, 7.276935587006231, 4.926664617753798, 3.725699099802202, 2.4207478713604713, 2.078558336342535, 0.21101351016231124, 0.15719906637264838, 0.3549778713814674, 2.89780026001315, 14.095422587087079, 25.842112264325543, 37.737472518797844, 44.40281891053723, 17.0304351083694, 17.546034589890514, 30.238730330621046, 35.80715256352579, 20.529132427707797, 2.5917727716507453, 0.14012155693865594, 0.028760710340594093, 0.095794836299554, 0.03774817807659988, 0.10342437488537642, 0.07969736782533508, 0.054010857242129506, 0.03638038171395179, 0.04061935304273521, 0.05839024099611467, 0.0338428916649953, 0.04785533310965665, 0.07825015878845608, 0.12011343943736247, 0.03201497523414512, 0.02787831686286917, 0.04839700323739841, 0.05559492405624159, 0.03771341300659603, 0.04622142461519088, 0.0445578761789347, 0.03371264139610914, 0.0806707514810466, 0.004894763659385424, 0.030220402780199246, 0.016974035853279695, 0.009053464295462737, 0.039652975261091225, 0.022201699189721577, 0.08553949304886403, 0.027785244840948332, 0.0518194972086818, 0.007506955899448405, 0.027110618238727895, 0.06777416689381485, 0.04626308064607363, 0.06196723957996696, 0.05982025901997282, 0.03179984816890811, 0.07794196161651805, 0.07435921354279404, 0.11112416373385538, 0.17744768951689044, 0.17371575348079207, 0.241531603218567, 0.1877890797632356, 0.08330425532955317, 0.16824078355585376, 0.1852842480424912, 0.12045872292571491, 0.1496937949090235, 0.15889441894908107, 0.21081005253138083, 0.04554245237921996, 0.1321062088132866, 0.18650623489051096, 0.08133191600321762, 0.17708067211412615, 0.24966641509484863, 0.14149778792935033, 0.15718746780147477, 0.07954510785038434, 0.15591494979396944, 0.17738369053169606, 0.12689557752662128, 0.11295269303504499, 0.12768155309341608, 0.10355669359165816, 0.10141704832353901, 0.12511351911891855, 0.10459572332160127, 0.11929221616517152, 0.08395687031048922, 0.18167894634027637, 0.1401787683848412, 0.17218651940986035, 0.2243030825329404, 0.12778509753726183, 0.1667280050535356, 0.11672906983163088, 0.13243227115561887, 0.20518494469504203, 0.21259811706840995, 0.1100539465645148, 0.1889871033809839, 0.13432931936075612, 0.09401227993470046, 0.21247191174376398, 0.12666007443781824, 6.3773130216906155, 29.670818198111753, 54.26451652280746, 54.400379580836145, 43.843194746202045, 36.32600368991975, 34.82713660886211, 30.796336435502578, 34.16260865426833, 28.01092605437002, 17.92514931771063, 4.119766393015462, 0.6556037044332874, 1.776808070078973, 3.609543255259914, 5.690557975922862, 8.38423784702055, 10.114077618045192, 5.797294493644468, 4.360203762208262, 3.2918592181897934, 2.630599088245823, 0.9202413621448702, 0.4973093468335367, 0.744242528753896, 0.7581994249936074, 0.28167367582359626, 1.0041797161102295, 0.8886354548796531, 0.7389197498559953, 1.567598405864931, 4.2622308000441524, 21.229455932494133, 42.87751113214801, 61.350356686499815, 58.65219354629517, 57.46362909193962, 57.23521378732497, 48.55245121063725, 48.88509173547068, 51.09719084155176, 40.096111374516646, 42.757196349482385, 55.24155147614018, 69.01695082264563, 59.83900077881352, 42.326861350767075, 28.054587917943156, 23.3903230005695, 20.781940952424083, 18.771761540443666, 12.701216109337347, 7.413027123097451, 2.7430382419017056, 0.8530463807044492, 0.14726759445282722, 0.18738251690181995, 0.194313207100476, 0.46164921034247647, 2.5255869425112203, 5.410334044887174, 4.1968453795679155, 9.927377700805664, 12.600488662719728, 18.2038454855642, 14.571688540520208, 12.163496421229455, 16.380877860130802, 8.60276681761588, 12.222501616324148, 10.546926856040955, 15.957501146101183, 6.080539140009112, 4.7679204133249105, 0.6934805622985286, 1.7499351765840285, 5.165369279922978, 21.478736285240423, 29.286453377815988, 50.22576570510865, 41.033710818136896, 17.12209893811134, 36.280947423750355, 39.98027986095798, 44.597556744852376, 21.232052541548207, 2.813883601657806, 0.39228659844206226, 0.10128663717618874, 0.22271424682149965, 0.1628937656360288, 0.1702998900004933, 0.16880096236784614, 0.148649831572848, 0.14038490732350659, 0.1431679515348327, 0.1267643390043128, 0.11186190640493748, 0.21262781063635505, 0.12411846283582911, 0.28957884518369553, 0.18432945734070194, 0.20453087414704985, 0.14183227723884967, 0.16784620230957387, 0.12221358521210572, 0.16104730987741103, 0.091051809760111, 0.1749672806791721, 0.13262201581270466, 0.05595988834336881, 0.15914424022118892, 0.17284895563798566, 0.1638754460239603, 0.12468451754220071, 0.12526547265869956, 0.13799325743269536, 0.12536490321039193, 0.1150562325792928, 0.1666528365064052, 0.12104686394694353, 0.1764784197533323, 0.18950025971618392, 0.14796473446392244, 0.17305298017398005, 0.33348156680022517, 0.21368162586323677], [0.08513561149518337, 0.04093054561845718, 0.044853218395503304, 0.09623341397532532, 0.03943673928358382, 0.020570111941666375, 0.025109834067763823, 0.01107805752150354, 0.02452784473256719, 0.053440749930638465, 0.03327437398594714, 0.05137523516051231, 0.01619781258576099, 0.02751534440434508, 0.05738476974769466, 0.011109912415005026, 0.010731626816484477, 0.13309133659687736, 0.028214790340092395, 0.044819882079478235, 0.04859108395213562, 0.07542925451191203, 0.04435216241906728, 0.03423077730281699, 0.030910241973376086, 0.05328322310120829, 0.056432576083968726, 0.0713280564354312, 0.03536201337532651, 0.018546025291265502, 0.03406506099347626, 0.02208144062258784, 0.08272932166413915, 0.054874077454329505, 0.13126536602935485, 0.011324879559387845, 0.03360284184436164, 0.052175754906549576, 0.06865730539204613, 0.08942807874371929, 0.11880708332624167, 0.03630773742653189, 0.027304001813454014, 0.040087431383829926, 0.014240102665949494, 0.02695437460657089, 0.05044261121281213, 0.04344272412239544, 0.04152211488314694, 0.08955845924755258, 2.041508117991109, 11.530062075584166, 35.08571886247204, 37.16480255126953, 39.80219248802432, 31.649803000111735, 21.37120450696638, 21.28785021843449, 22.29727806583528, 22.5068679548079, 24.443208748294463, 10.253151136059916, 2.2930161318471356, 0.32772288387340887, 0.7007443015613865, 1.349453950120557, 1.3224845908341871, 1.4570548601688877, 3.9178795487649984, 1.4474112228039773, 1.1791302960726524, 1.1298075943223893, 1.4594243394751705, 1.365411622870353, 1.010796264294655, 0.978850765574363, 1.7793246382667174, 1.0605542265599774, 0.6402391063109522, 0.3698511926397201, 0.07449597555903659, 0.5664197319457608, 5.917286171067146, 8.866751155545636, 12.698106650383243, 14.82253097718762, 11.814893810979783, 6.3714162284328095, 5.633050145641451, 17.962998228688395, 22.93453770299112, 17.251409676767167, 21.728448098705663, 21.515110385033395, 10.461833976930189, 4.344983985347133, 2.449506199167621, 2.3099747444352796, 1.0132364688381073, 0.4409127117645356, 0.111055369038255, 0.07282287783680425, 0.10340021247224462, 0.017673020221052632, 0.585818671651425, 0.3705387718735203, 0.10326455362261304, 3.2569270797314185, 2.693869125458502, 3.866453353435763, 4.643479787534283, 5.815248162515703, 5.86264314190034, 5.526618592200741, 6.727822884436577, 8.276741370078057, 6.41419408782836, 5.756777390356987, 2.9097071049674867, 4.337052462562438, 3.4489641170347896, 0.7287454893512111, 0.42596817497284184, 3.7904611085691764, 12.197645556542183, 27.947779816965905, 28.756366622063425, 33.4556955675925, 37.34637691128639, 13.397414261294951, 28.69776837287411, 36.09567034629084, 29.77919524715793, 11.860396246756277, 0.22748239338397983, 0.058854750748122894, 0.06888946067662009, 0.02694901773676036, 0.04934201865727383, 0.04683905619106466, 0.042282319252168944, 0.09821036515096504, 0.01869893069529245, 0.02644506786319037, 0.051367183576428124, 0.024232860662103183, 0.05722979016061272, 0.006465959238759693, 0.041874162927870794, 0.058840624086799166, 0.006424185900663537, 0.026423653790486917, 0.0721871780772363, 0.05519207289081909, 0.06531465693467087, 0.05596305611693571, 0.027361027483317642, 0.030791178503404223, 0.10326659141649162, 0.0339562879995473, 0.04474878145922576, 0.12298288304478892, 0.0861868143622433, 0.032582014363499424, 0.02758898077562692, 0.018284854426559423, 0.008155103630175995, 0.03924696015254144, 0.02401726245279274, 0.0479823581483816, 0.02531640776132624, 0.02530082744816619, 0.057884109687180295, 0.04504327331819842, 0.03375190723266813, 0.013107856314989829, 0.02991400208444365, 0.029042075282984206, 0.06582535412763396, 0.019143947340067358, 0.04490092652098787, 0.049946389251178315, 0.08571167897072532, 0.05073385102854622, 0.03205876098945737, 0.10954183976977103, 0.05675029572880557, 0.055234935510182576, 0.040582389300388676, 0.030698485695005908, 0.06143402323246964, 0.008935298105972189, 0.02798732542883485, 0.012479384594987477, 0.01075993376528664, 0.04904319074064974, 0.04858683982503511, 0.02251617445219909, 0.02114473534147105, 0.06774305606320982, 0.10534967641316115, 0.03377614242415275, 0.047626556272828774, 0.007760913088737477, 0.0038549022452395052, 0.06202908585809412, 0.00045877133450102845, 0.02791734329695183, 0.06740101312677707, 0.04855196750272186, 0.024040396392886198, 0.036127159011460123, 0.0314944299809154, 0.013687184452259494, 0.027334302506079117, 0.02305523413533886, 0.07485900930459462, 0.03056091928644286, 0.019703549670896704, 0.01670804246509027, 0.022624865091676195, 0.04418646143148503, 0.023258609411817406, 0.05000138670326241, 0.05268042298754858, 0.10558855028883105, 4.597666013625361, 19.52983214009193, 42.52428208628009, 43.41130256652833, 38.74895372698384, 32.90355528554609, 20.296806520031346, 23.08097743218945, 31.649589230937345, 38.118044407136985, 26.46339020421428, 9.31194801484385, 1.8357050322717237, 0.5540830810223857, 0.1925195807651166, 0.6168426585293586, 0.48246124518975136, 1.3393648785929526, 2.3515018580421327, 4.117354625655759, 2.4893930265980386, 3.3601395930013354, 2.9792031693843106, 3.202968259011546, 2.430680293229319, 2.297144671601634, 3.2890858573298303, 3.2398027470034942, 1.9069558670443876, 2.054873594353276, 0.6628854620841242, 1.58975612011648, 15.533604718023732, 17.989409508243686, 19.786264934847434, 21.142863727385, 18.930168421037738, 10.441708295576035, 9.131931816377948, 25.5966797567183, 30.10709558763812, 26.178261349278113, 31.003721952438358, 32.15840497324544, 17.72670288239756, 8.00844487644011, 4.217565790299447, 3.6771472663648668, 1.7873735870084457, 1.5507485164750008, 0.7148614633948572, 0.34525544953442394, 0.24792302880556355, 0.10532031226302348, 1.239158004041641, 1.7999767752424365, 1.9451641651891896, 4.920283411779712, 5.630418725552098, 4.649212331541123, 6.115002555231895, 8.026740281812607, 9.428451234294522, 7.944429343746555, 6.406067427127592, 4.7305220846206915, 3.1060903735699195, 2.882949185948218, 1.2896289796598497, 1.075297803167374, 0.1868290336982858, 0.1397109184894831, 0.43875966761862084, 1.819356225671307, 9.73836946871973, 26.969734853313817, 36.356966880060014, 30.4125403588818, 41.0574137010882, 20.95380352389428, 20.96535686523684, 37.908209370028594, 35.51712074587422, 18.777829447100242, 0.712556764483452, 0.08256353257644562, 0.024534904232789433, 0.0516614456090235, 0.12205105199809037, 0.05577824123564267, 0.022742057391893, 0.11829929726739084, 0.06792577569402995, 0.07532812324502776, 0.030189799482844053, 0.041766447135277336, 0.06273166126301212, 0.058074735345379006, 0.08877360216912725, 0.07804131555941798, 0.0641870444580432, 0.0360129161497518, 0.10492581528641524, 0.024069687764671062, 0.08405207205683955, 0.07078961919872992, 0.03280842398864127, 0.0900116385591607, 0.03459634679940439, 0.028977158907500487, 0.03268817116716697, 0.10773158932645475, 0.013534937883847424, 0.11887377128005029, 0.019335848534659996, 0.08133589966042389, 0.006083679928128878, 0.04814267353785615, 0.018133002393428358, 0.09323487689177837, 0.06309878974852544, 0.013163857342254733, 0.04447138102184381, 0.05222259352224008, 0.004918891598560638, 0.045842651593228506, 0.1385761584125219, 0.19212761953953775, 0.1873381757327626, 0.21888350076492757, 0.13646125012347776, 0.1627459719536766, 0.16758113588777282, 0.16668835234257484, 0.10894858894208748, 0.20823254971013916, 0.1377157650647625, 0.16634782626023217, 0.16804635044067137, 0.09515420293375369, 0.2640461152599704, 0.0892494653441733, 0.10663892578093276, 0.24589841163927512, 0.12426958900065192, 0.11457361250875459, 0.1085321971726033, 0.1119129355215738, 0.17155840392074279, 0.1928935236027164, 0.3281195948441183, 0.15767897449193463, 0.1690807989648273, 0.19356331427491483, 0.103251805919553, 0.2104345468744155, 0.17730351176954087, 0.13681712860782302, 0.30010501583737714, 0.1420698104606521, 0.21178169716750422, 0.15473970963108927, 0.12436432343336845, 0.12449423662356793, 0.12503610593417, 0.1241901916481795, 0.18918351300301092, 0.10911738109444419, 0.1564918599662281, 0.1306286090684514, 0.07026210637582887, 0.11889819416307634, 0.17561355245209512, 0.1700815396203149, 0.14248596474287972, 0.3190046500775122, 3.0515257918065597, 17.941717409318496, 48.199822287405695, 53.3619281553453, 52.917700121479655, 41.93987638719621, 30.450077441430864, 30.264743489603845, 29.982821172283543, 31.986562013626102, 30.473352786033388, 13.479712451657942, 3.3773840483157866, 0.8844212358517032, 2.1150785444244264, 3.5603959570007944, 4.478709841928175, 8.893699799814533, 10.703763807973555, 6.8532686175838595, 4.578389035117242, 4.690573725008196, 3.656734516543727, 3.3583389799441066, 2.881057377784483, 2.529027351448613, 3.429806035372519, 2.8459953108141502, 1.925096829091349, 1.1954206348426881, 0.8328168178277632, 1.472165178387396, 17.00775400284798, 15.417581988919167, 16.26253308788423, 18.80724330102244, 16.577766133892922, 9.015450169963222, 8.027727248207215, 23.506929182237197, 31.678936404566613, 25.390939674069806, 31.543424398668353, 29.054052945106264, 13.661448609444404, 6.854795890469705, 3.0392178845021034, 2.7703131783393125, 1.475598968325123, 0.816123394235488, 0.5585821008970661, 0.4077824427475853, 0.1734099158596608, 0.18832934028919668, 1.0218455810700695, 2.220051956753577, 1.3074255085760549, 7.649364634867638, 8.5549384163272, 9.028148843396096, 12.467304583518738, 18.6624764627026, 12.498023606115773, 14.998873875987146, 12.313488837211365, 16.17145565248305, 13.000103658245457, 14.295623302459719, 9.206908902814313, 10.31135420645437, 5.909827293888216, 1.8770941274781383, 0.8056198997843651, 5.452843221925921, 16.664507389068604, 36.39031094889487, 39.2269298338121, 43.02605913531396, 47.75486077031782, 21.79532647132874, 37.16402199960525, 47.798618731960175, 41.09674722917619, 17.48761873091421, 0.7415500054917028, 0.19397756865909024, 0.14082922299783077, 0.1526857512973009, 0.3432002501381982, 0.12685807752272776, 0.17534572811376664, 0.2629461049312546, 0.1866579202995185, 0.18769148016168227, 0.14434558189203664, 0.13762489171518436, 0.2140541437772974, 0.18188773594315977, 0.17842829738172794, 0.20822416870824753, 0.18420208756241108, 0.1265898931230749, 0.2106531424027297, 0.1440351477433597, 0.19778968345734382, 0.14424648075815172, 0.17623595292529753, 0.20689135958110133, 0.24212809459817028, 0.14348816096542344, 0.10192357033731476, 0.2246858353816694, 0.16583139106871622, 0.19242265532093664, 0.1314504681936195, 0.18336384947742188, 0.12395928508692211, 0.14695899891516856, 0.1263056515205291, 0.14740781918648752, 0.2082747764765255, 0.08724098198957021, 0.15758505211241786, 0.18229865018398533, 0.19235683304648246, 0.16881288269594794], [0.02319393435402984, 0.05762505322514523, 0.027803412616072644, 0.054612025588510506, 0.02316209573989674, 0.03628822899754009, 0.05765609127739745, 0.03734049289637516, 0.042708877008408315, 0.03111891091741141, 0.08018718912236153, 0.05200233175269058, 0.05779510942257701, 0.07675098600767313, 0.057449331807513396, 0.03423488736453076, 0.006708278116064087, 0.06882187639994007, 0.02894747491565443, 0.028269582863656745, 0.05907164556124519, 0.047282318494492964, 0.010558868243899799, 0.014758780579863778, 0.03515551820577633, 0.01873995661885748, 0.04492163387758117, 0.06340115699135969, 0.026202514850264116, 0.0833646460406242, 0.03563786631510143, 0.026024481762320768, 0.006017781044882272, 0.05449212899792099, 0.04035836986957058, 0.05066927364696899, 0.029681025170570904, 0.11316078549791729, 0.005797876463827467, 0.071966843529334, 0.07417008175604767, 0.04721037134708417, 0.05193611877339502, 0.0931653850561669, 0.04552859767910935, 0.11819625844157512, 0.06619954211336952, 0.04705795432410894, 0.055699590818896416, 0.029844295744213368, 0.03310919393815341, 0.7529009770481818, 7.688156875871844, 23.826045374716482, 39.12122980240853, 42.2336305341413, 27.134703859206173, 21.003760791593983, 22.211225186624837, 19.10513162612915, 25.664777986464966, 30.391192859218968, 22.84307783649814, 9.35802213607296, 3.4202709986317545, 1.0133553043969217, 0.5941393671016539, 0.48945976481322323, 2.7129009558308512, 2.484389307998842, 1.9816169575337443, 0.982034197978435, 3.6186671785769926, 2.042135329496476, 3.696752743374917, 1.6055284608756344, 2.1903353448837035, 2.6442212347061407, 1.7884312786402243, 1.924973519579057, 0.36748937421268035, 1.2048076021094476, 0.8764420317546014, 1.8225083404010343, 2.4523609492086598, 0.035512714361351345, 0.1874531502084386, 0.018436214248199138, 0.12459348331415847, 0.534495193391077, 2.659814372178047, 1.3854397352664702, 2.443701336460729, 0.83828208907958, 0.26662225444470683, 0.1333702692101079, 0.14066397783256349, 0.18618334415218524, 0.09434483104175138, 0.37260776085238306, 0.6389267670531428, 0.7141849158271667, 0.881695801452283, 0.19875428008456386, 0.9895509301174072, 1.1083506360169382, 3.8129858095799727, 7.0351665731399295, 4.335779653441522, 2.45793120514962, 4.880722386221732, 3.8297539420666236, 6.689188028535535, 5.3813134085747505, 8.062365699198939, 2.706895071652628, 2.6888573169708256, 3.4877857758152873, 0.7476022839546205, 0.14276745608977734, 0.33999996379979197, 2.2994321488565017, 9.44464473955093, 19.542958351873583, 30.32544020683535, 27.351381471080167, 24.502650307070827, 35.58731548247799, 17.724143535860126, 22.64110911277033, 35.42751812165783, 21.6375805101087, 3.5472469464425123, 0.08771194986278012, 0.014795767304848039, 0.015790893493460554, 0.07069499967920204, 0.06477109456975615, 0.02766082258594613, 0.03591268120573894, 0.04249249547419529, 0.05055772358431451, 0.031132217864656163, 0.04302632086159241, 0.042680118067730824, 0.029928195778460755, 0.023890275718464006, 0.01686992258915017, 0.07736125164815495, 0.04673596756953386, 0.02383614203051454, 0.09005453182204116, 0.06255995414610352, 0.08341506994780033, 0.02913038989889526, 0.05629122903149936, 0.020480768852716973, 0.06303255761703176, 0.05668855287254818, 0.023967460992055076, 0.006582790041237229, 0.009572839349388115, 0.05277937090384865, 0.06075371034263123, 0.0054114033006161695, 0.056394784966663974, 0.005500348023844944, 0.055030248308133696, 0.049649273541065, 0.016815204759158434, 0.08832916392073517, 0.014133084970977039, 0.003124760123976176, 0.04394908908814673, 0.03771624370147625, 0.051673664711415775, 0.023151889533525514, 0.029571579934488383, 0.0016185952347680748, 0.05518972100089154, 0.029202191489598447, 0.030110185710533015, 0.007666786738310851, 0.05855204259616233, 0.05529894215625621, 0.04233669234259475, 0.017737559298233643, 0.04954793543044118, 0.03003449047795467, 0.04021346433869293, 0.03942892901719578, 0.05415019331379764, 0.01722112219149788, 0.019268986295848604, 0.07047849557092113, 0.0053096160709467394, 0.0533972667800563, 0.03575586300763873, 0.09099796910079257, 0.05054663063117093, 0.03291473017945405, 0.0390463064034139, 0.01325980602433124, 0.11617651359448511, 0.02732846108565648, 0.03539301312318252, 0.002574333611259898, 0.06288587093173016, 0.03859691156615173, 0.018636772236336144, 0.042812727887423775, 0.06892916701373554, 0.04624476731424371, 0.039661758459143104, 0.007841447602972508, 0.03801555425349263, 0.049474486750700784, 0.046406078618019826, 0.025856993874655138, 0.08236477106449105, 0.04512714462414865, 0.015168476740889733, 0.13223849687605135, 0.04295915410283112, 0.04413367797350211, 0.02818789873873034, 0.0807828224834896, 1.6335694852375215, 13.837311017897822, 33.22853149906282, 46.63676954084828, 45.321520374667266, 28.0583082860516, 17.826744894827566, 14.477949776957113, 22.24398089993385, 38.96249540390507, 37.907585713171194, 24.52484699987596, 8.081339674611247, 2.672516722832957, 0.2669822851256017, 0.12200412911272819, 0.3031310018512511, 0.3559020798533194, 0.67277682164023, 1.5065877764455735, 1.5863635150655624, 3.984436041885807, 2.453126056540397, 5.319585107987927, 2.7313414888997234, 5.329978898648293, 4.496993480190154, 3.6350715112301613, 2.8175318962143314, 2.286686161833425, 1.1865600006234263, 0.48706586262391466, 4.64383231055352, 2.841597353258441, 0.16369054304255595, 0.5197302888958685, 0.1371820162861578, 0.4211438741655119, 1.4715987636196999, 5.752185275477748, 3.2497692444632134, 4.736591462166079, 1.7187366442334269, 0.5693646352137289, 0.36017087498499506, 0.5736280677299346, 0.6798103668036, 0.6925063436069797, 1.3845985094385764, 2.200168236609428, 2.964732320077958, 3.4025063389731995, 1.3533748494040583, 6.253776502224707, 4.117552215053189, 7.397992678226964, 10.642762126461154, 6.9596835009513365, 5.2451429347838125, 6.653941610167104, 3.0688754156712563, 6.552365950999722, 4.953738287571938, 2.7535725024438675, 2.862188570922421, 0.9929968548878547, 0.4744920921662162, 0.24430467296511899, 0.24248732854762386, 0.2521209148389678, 2.282177887616619, 7.205227796108493, 21.2599229428076, 38.03139532766035, 38.43382266259963, 27.699117237521758, 34.41285587126209, 24.599940776824955, 22.41804784344089, 39.63233817008234, 30.92174637702204, 9.204566267228897, 0.33937008630844856, 0.07004534179765372, 0.04622722390077768, 0.13207372668529713, 0.027177325344734618, 0.011046552155617506, 0.04463190708549754, 0.022805221341249925, 0.018991614586763808, 0.02789943024606234, 0.08082904056796143, 0.021513509000801755, 0.029780967085952723, 0.014592811461508036, 0.04774091787816537, 0.04074093885719776, 0.03606981349988811, 0.05006083512618657, 0.08241882622842828, 0.07211572505653867, 0.08109416061591718, 0.03378235539721866, 0.014142081716037808, 0.07005574527166544, 0.052521666586999936, 0.03509942524796052, 0.0131698471922127, 0.06524783874591512, 0.00535994517474225, 0.042864569057259834, 0.04377113452421562, 0.016778354014780734, 0.07112583220605889, 0.045920313756552436, 0.06458488157800128, 0.06868469303533917, 0.017067065740364696, 0.05016873477988186, 0.05298778895408877, 0.09850268132023274, 0.034316525524181705, 0.055907158511540586, 0.02804846499085186, 0.1860092123669963, 0.16315742245604917, 0.20195798317511238, 0.1780069337016152, 0.16548283638492708, 0.1170187736410768, 0.1459320427309121, 0.22502375676506953, 0.12367142754937373, 0.1268890427966272, 0.15713794787804927, 0.13465746546224241, 0.16267291780921722, 0.11468922283740775, 0.19473544412082244, 0.24805923923850062, 0.10748509287593827, 0.1755888844209333, 0.16098030782755346, 0.11267218994156969, 0.14154450397097296, 0.16073624753663618, 0.16548242269744798, 0.08561292257640632, 0.162563995428143, 0.15518451560168497, 0.11444614313903356, 0.22679740352736366, 0.13191621900806505, 0.17768690813212626, 0.1580074576721076, 0.16685497646610584, 0.09310304848176819, 0.11678074246212361, 0.1324341404101541, 0.12538533477533248, 0.13896133209909164, 0.26723613602019125, 0.1702013251281554, 0.16423886281348046, 0.3010988770233047, 0.19643314092630343, 0.08713459535952538, 0.2132581937457285, 0.10537976068594765, 0.1898354538265736, 0.18148956940539424, 0.10739216641072305, 0.10663160198037663, 0.17594113164851743, 0.16352751953226907, 1.1048837510808822, 10.243351094184383, 33.824476811193655, 52.69708641113774, 56.569615025674146, 37.42087056559902, 32.52621150785877, 32.92296317315871, 28.55466461950733, 35.59795687275548, 37.650180170612956, 28.799295002414336, 12.573587086892898, 4.1835019665379685, 1.7274041017217023, 1.600714241785388, 1.705007122889642, 9.76227141195728, 7.42633278331449, 5.969733653529998, 6.6570231222337295, 7.925425950557956, 7.248841610647018, 9.44131660845972, 3.3624954665860827, 8.229144388629544, 7.414302873995997, 5.944196572226863, 4.463587143728811, 2.923901672324827, 4.329182226811686, 1.4596490177416033, 8.634870436883743, 3.880322118920665, 0.1526111956205099, 0.6659236442177527, 0.2749880571519175, 0.5649234702990902, 1.0941691840848615, 4.0818061847840585, 2.9115307619494777, 4.054066692629169, 1.4022207380302492, 0.6517894445888458, 0.3726859631076936, 0.5028303892862412, 0.394444024610904, 0.4435605874225017, 1.3590100696009975, 1.7710679264799243, 2.2701357208913375, 3.08749784865687, 1.3188175424452753, 6.12761591711352, 6.928162353654062, 11.122015945373043, 20.043660671480243, 14.103814498070749, 12.700713065362747, 10.271255816182784, 11.161207287542283, 15.641107078521484, 11.975354052359059, 18.27955311344516, 7.459104676400462, 7.9939399515428855, 7.9132533650244445, 1.8901270603941334, 0.6972030141661245, 1.1112123727798462, 3.37086261760804, 11.846918002251657, 25.322902241060813, 39.361114117407034, 34.93064795770953, 32.48399699887922, 45.0182976261262, 28.56500202609647, 35.05351620335733, 50.138614562249955, 34.84579924614199, 8.961946099035202, 0.26960046721562264, 0.09919943828736583, 0.1174997466225778, 0.2610932140340728, 0.1755372194513198, 0.09568321728898634, 0.1391015874762689, 0.08231896666749831, 0.17221487998481722, 0.08403183201388006, 0.1989789889945138, 0.11933117173612119, 0.1642714062285039, 0.1074523809215715, 0.12164846513300173, 0.1534401640416153, 0.1314543905637918, 0.11556344407220041, 0.23813853851489483, 0.16910791847734682, 0.1865217558318569, 0.1418462047173131, 0.17509008457343425, 0.2319237574814789, 0.15812647709202382, 0.13520370147401287, 0.097772806372133, 0.12331002557109441, 0.1556547710131253, 0.20010596561816432, 0.1344792427675378, 0.2551417374202321, 0.15875381117145862, 0.14443126116548816, 0.16148102289486319, 0.16155282065512674, 0.13795599491605837, 0.25272911204205406, 0.18583281296155146, 0.1639718811718687, 0.20684516447926724, 0.2469234985689963, 0.11805809448443114], [0.041898704554525115, 0.031580302691567814, 0.03462915451476171, 0.04531166839203046, 0.046951330206807584, 0.050422057073803685, 0.052146394586851524, 0.043073121172886704, 0.08133046809704074, 0.05442456387343907, 0.034552752566073215, 0.08234761069498717, 0.04463763742317115, 0.033396507553275556, 0.013214660462953392, 0.0423077074059796, 0.0532760295355993, 0.06916891422963913, 0.04283408258831309, 0.05104273001873686, 0.03834723585074948, 0.06613852321020057, 0.01954593665657505, 0.026021727676232977, 0.056113569411419095, 0.031226247496482347, 0.05784344957059911, 0.04167308399994527, 0.039867893567368876, 0.02620659426846091, 0.016403204588700208, 0.045948226170073596, 0.03090708377590824, 0.01246366925883077, 0.04832998203534273, 0.09961282699218682, 0.08129882100488871, 0.09456043882716088, 0.01213080884378043, 0.09901449700156528, 0.012743287520753521, 0.0070123652262883565, 0.050339687300185045, 0.04439831155562594, 0.03427257505996573, 0.03899288709245382, 0.03259114996199647, 0.0953002269530008, 0.03106832421655136, 0.04854675810483675, 0.0267941951977029, 0.03850998356938362, 0.015338350034829591, 2.229288893361246, 13.926172314151643, 35.8381942010695, 42.48162238828598, 35.446482781440984, 27.897544060983968, 26.51790918842439, 15.79204772749255, 21.479030463003344, 27.630016842196067, 32.17577518955354, 21.18024391512717, 12.35989930168275, 3.7786189827226826, 2.2516888139709352, 0.1666537864554313, 1.1730002443636618, 1.1508612839444992, 1.1749663324125352, 2.3496835943191283, 2.9041620992845107, 2.2690551079088643, 3.5592498894660705, 4.838022483933357, 5.253752537312047, 4.152827560901642, 4.208289384841919, 0.6692554525309994, 0.8930532694343598, 3.4953937030607656, 5.530713546660639, 15.673279339267363, 0.08179696201677285, 0.06125323031277907, 0.023559597696387963, 0.12722615212682756, 0.09611480058200898, 0.016857737960714488, 0.04138754004792821, 0.09402838310286885, 0.10520781225134289, 0.1305525978246043, 0.31969486465377195, 0.3128358649630701, 1.1839678042357968, 0.7730360966055625, 2.529048679336425, 2.4132691371825437, 2.9574291119652414, 4.971409545790765, 2.0342208445072174, 5.655944039744716, 2.2787276727537957, 4.612578374724235, 3.4509679578965713, 5.808556599001731, 4.023848262525374, 7.403518317207214, 2.1302779739902866, 9.490162864808115, 4.645794966528493, 1.5075236294538745, 2.2788590721545683, 0.6271857648126541, 0.1268983354431487, 0.8893164764008216, 3.6456599495103283, 9.648615833251707, 19.71841185323654, 27.14798108223946, 31.82156751232763, 24.518545712194136, 18.48040003930369, 26.327168249314834, 22.655816039731427, 25.622573283410844, 33.945995761502175, 23.304603522823705, 3.261469919835368, 0.013476304386952713, 0.04288646385013577, 0.0390645622786495, 0.07759884615699131, 0.05401566444385437, 0.020660079392274062, 0.031231297931123166, 0.059447404027225516, 0.041790126913016847, 0.020892554518556403, 0.05835079512889347, 0.06435554549698869, 0.01579280775566135, 0.037701917857292204, 0.03235257486061704, 0.036874937434350295, 0.052733857620267145, 0.017628740339029222, 0.03804165869951248, 0.11262805561625189, 0.04217106413336531, 0.03248883891970881, 0.033515427381761616, 0.048450100791430285, 0.03646478162056977, 0.014106882848746836, 0.033524877076307615, 0.08656163820095601, 0.0505111530993975, 0.01614022958693245, 0.05776394496581728, 0.054021525016475114, 0.020531181268574252, 0.026817614505548152, 0.048621869195372834, 0.01890165096659574, 0.0166142120161244, 0.02432599014061834, 0.07603493128572741, 0.02166023016005995, 0.032205041648159106, 0.01718953064072036, 0.0647642151001961, 0.06135226249875081, 0.037029361607687133, 0.03657630870058652, 0.04021608435939397, 0.012210752991508814, 0.02117104280079084, 0.046606920058688814, 0.021655252503771937, 0.03445931282194872, 0.010826964543441371, 0.06898935854194627, 0.017039718316687692, 0.023804253620666363, 0.03961676228491049, 0.03513204527177638, 0.016470875050271713, 0.05662217135390928, 0.0045279267660882925, 0.10310473235984964, 0.047669238861530065, 0.03628519911979956, 0.029120463314616395, 0.014292003207599685, 0.019286223274144917, 0.01671655944758846, 0.06510608183640627, 0.08240390283566329, 0.05613253008754504, 0.04621384800561974, 0.025333104647635937, 0.0476871078623639, 0.06775500703482859, 0.053191974368547244, 0.043073033072775414, 0.041850100106169144, 0.008241444612072121, 0.07911537849013844, 0.01618560305946777, 0.08425644133239986, 0.007003045766689485, 0.11875293623175352, 0.03266594695648359, 0.030915524149613998, 0.0414434491446422, 0.05269047023067552, 0.07195097784842215, 0.036071089036282034, 0.04160399053005442, 0.06877882225859551, 0.04190007585190958, 0.029475466543508154, 0.019901993256362698, 0.03006200069531558, 0.26773455282372816, 5.453418339452436, 24.150397931375814, 42.95707248872326, 44.73563201965825, 34.241781696196526, 24.477119599619222, 19.646934501586422, 16.184200413765446, 29.106940223324685, 40.00453972047375, 40.668538155094275, 24.207588049673266, 13.42027775702938, 4.002450752642847, 1.3878262523681888, 0.21570333189541296, 0.24017322207650832, 0.853534164207597, 0.9171551309766308, 1.083138130845562, 1.9251454909962995, 2.24160268422096, 2.0310079330398194, 3.8062390877354533, 3.6926957868760635, 5.640032945140716, 5.896679509070612, 2.771812994633952, 3.705019138513073, 8.589685713091205, 9.96504226038533, 19.140809505216538, 0.3325362143016631, 0.8672805394857162, 0.20373343790490783, 0.45339130345852147, 0.3587275959791676, 0.24390934095267328, 0.1352109333440181, 0.396329612140694, 0.18764271100442256, 0.4512309661555675, 0.6982981521756418, 0.8799470985128034, 2.289299195812595, 2.0718687340136497, 2.7000412200727775, 4.788954123373955, 5.738787929857931, 9.197008840499386, 4.840010145018178, 7.517836286175636, 4.7638813526399675, 6.838953927639992, 4.217243175352774, 3.356819061502334, 4.282108881781179, 2.0167218028537692, 2.3822765292659884, 1.3792096631180857, 1.989216059446335, 0.058186400321222125, 0.4807940846489322, 0.23701493267811116, 0.22898348138457347, 0.7902617368005938, 1.9216038358788339, 9.572767000044546, 22.02302790457203, 33.02560767819805, 39.52357084520402, 31.536220965846894, 17.46320197659154, 24.827948154941684, 32.234910803456465, 27.04475018285936, 37.30876138133388, 31.79187320893811, 7.022871903834805, 0.0712002499870235, 0.08823621447288221, 0.03168553827450641, 0.0619045352833646, 0.03716558353194306, 0.09766228286729706, 0.04286852590138874, 0.008188162239328509, 0.04922108784798653, 0.006272590028182153, 0.05515917324491086, 0.07628710444776282, 0.008858927758410573, 0.06117612356320024, 0.07387458632189421, 0.05130408091410514, 0.04611468558470088, 0.008848048352275886, 0.03253418366394697, 0.043329216705094424, 0.04616272312799289, 0.010049636194091893, 0.05619578596745288, 0.02146980176950174, 0.08731893143586575, 0.05807516052417698, 0.040768219248181393, 0.04334184183408657, 0.03222611289651644, 0.006565844176352145, 0.02063336207591478, 0.08220246767685299, 0.016248510369370063, 0.053872095736404585, 0.052843343075965686, 0.0569297211815513, 0.033774330626211824, 0.02281643303802177, 0.04862220627405951, 0.08123843795469693, 0.03467639915705208, 0.03307514516035876, 0.046496990271994186, 0.04518990637734533, 0.21038027720585947, 0.09986318452584167, 0.17064067655273024, 0.10394725287633558, 0.14244663378884717, 0.18787583155978113, 0.10205245696969571, 0.1734222651970002, 0.0883806067248506, 0.15704387228094763, 0.1580748887312028, 0.24843056205539937, 0.1319622608923143, 0.16570497123945147, 0.10779459239734758, 0.08196340994008126, 0.1561472123308528, 0.1788059021196058, 0.14927359568255563, 0.2246925616336446, 0.16322129886717568, 0.12074736187294607, 0.16516091091738594, 0.12062601354574004, 0.21495870975477083, 0.1631896441141444, 0.16843242811099177, 0.1593948122594626, 0.1634410435273763, 0.17364936430127392, 0.16689300507066712, 0.11935375600812898, 0.1588638213973853, 0.08767584413890878, 0.0939403212959728, 0.23064724049500882, 0.17554082006456392, 0.2816473836860349, 0.10299239322663316, 0.2580681166821911, 0.14007606663771216, 0.09428398833880502, 0.09767519910970042, 0.20440918874115716, 0.19761964258167053, 0.14791299288551654, 0.16358879124445302, 0.2696209677284764, 0.17154770933331984, 0.14869222687857767, 0.11898381214949394, 0.1353000600131289, 0.1972759908605968, 3.7890323852339103, 22.51175718922769, 48.784620223506806, 56.33873647259128, 49.339059014474195, 40.62146186828613, 37.89181386270831, 24.210937753800426, 30.33113156595538, 38.680025915945734, 41.429230859202725, 26.66321731382801, 15.478296356816447, 5.708056159557835, 2.7478360360668552, 0.5281123939541079, 2.4733301852979968, 4.890431232990758, 5.079385042190552, 7.7726643412343925, 7.409525917422387, 10.120622092677701, 10.907453471614469, 12.99519677315989, 11.726553209366338, 10.736457743952352, 14.743570723841268, 3.6813748459662166, 5.361283825289819, 12.361228004578622, 20.019165469754128, 24.799867906878074, 0.18857571416564528, 0.43618803303087916, 0.19296749705268493, 0.3977834631598765, 0.3282598808648125, 0.40968041025823165, 0.1998582281052105, 0.4060092556380457, 0.2087712780602517, 0.4935032688081265, 0.869268445718673, 0.8659597426172226, 2.4796339244611802, 2.103899299137054, 5.167257410864677, 7.686234424191137, 7.073386638395249, 12.377835319888208, 5.958079801451776, 11.162361444965487, 9.435630152302405, 13.334420996327555, 8.42128953626079, 14.644240621597538, 12.031362556642103, 19.493126600019394, 10.161744221564263, 16.533425700279974, 9.770480932727937, 5.70381215503139, 4.000657984325963, 1.5156408519514146, 0.5799313165968465, 1.4535874849365604, 5.005121336829278, 12.423732934459565, 24.624135917232884, 35.83438950200235, 41.92120198280581, 32.35936760902405, 26.571237733287198, 36.285309099381976, 34.86366564227689, 38.49041854181598, 47.91557596575829, 34.16584460966049, 7.032945531029855, 0.3404589423969869, 0.16340774934618704, 0.15575025621200764, 0.16316021101609354, 0.15091354478030436, 0.18798499908899108, 0.10660422199796285, 0.10507206913203963, 0.11596413103923683, 0.114515412809147, 0.13822890607820404, 0.3572728869415099, 0.09452165179555455, 0.08989663343996772, 0.1510052914701162, 0.10788674511375929, 0.1391874046455468, 0.17003767342577059, 0.17226616191046853, 0.21485862802834282, 0.1269340734448164, 0.18455625000980594, 0.13569741449769468, 0.08196836652895136, 0.15360412217916983, 0.1212368920565613, 0.2126841793858236, 0.2908262814725599, 0.13138699014821362, 0.11993836536402665, 0.22823459979507232, 0.15367097101144253, 0.1503319614717076, 0.1652107832412566, 0.08322252140891168, 0.2081394547055806, 0.11486716207958038, 0.05408910163227589, 0.12278094992882783, 0.18093636199351282, 0.16448215701647345, 0.09819533450589066, 0.1789528071399658, 0.1267938333893976], [0.06388624769545372, 0.028439386252073512, 0.09826913175563659, 0.013379985109842835, 0.029469931558255228, 0.04355677929256232, 0.005386467617485793, 0.045960180972131996, 0.01565926426631068, 0.03494108636533061, 0.055265785870893355, 0.038442046892258434, 0.02077889005323091, 0.04537557544667394, 0.03330791331527214, 0.021401460980996493, 0.0388448559228451, 0.05074330838397146, 0.03518774369431119, 0.05765094316654629, 0.01419911025873115, 0.14485598031070926, 0.09075609982133874, 0.05507979504463654, 0.05293379507718548, 0.006644731122745022, 0.03997222325133701, 0.02240032855150921, 0.055252245266831694, 0.05062860586950856, 0.07932930854299376, 0.013932842994108798, 0.047609158416068366, 0.09102756307730753, 0.0520982651130086, 0.02460315692118339, 0.045256172982795585, 0.011820798916291567, 0.024104276634452325, 0.033973027020692825, 0.028693076268198992, 0.02724381986134235, 0.03199690896567078, 0.08003839952570778, 0.08417041731938239, 0.07257552336781256, 0.00594828729405098, 0.05367339168104434, 0.02757056593714703, 0.009697898414977377, 0.059949302700378244, 0.04090255659614359, 0.05664549107032438, 0.026348939150451656, 0.7516873099150196, 9.381574988365173, 29.185252305000063, 42.84689703295308, 39.76419648816509, 33.99620209970782, 23.337431799980905, 26.99064108633226, 22.400914930528213, 19.497454935504546, 26.14527813849911, 24.6074011248927, 24.613100328753074, 15.133657301625899, 10.202034807974293, 4.052412433008994, 0.8597671781336108, 0.05200324339732047, 1.3911537705890595, 1.1767171803982028, 1.6153513015277925, 1.6259495457333903, 3.429145115998484, 3.426534288352536, 3.510800773097623, 2.26618908105358, 2.6317309371886717, 0.9811116442564995, 4.386623376800168, 0.7846650048609703, 1.4425380455870784, 1.085730817529463, 1.1290265523618268, 1.2399243371140574, 0.39596038840470776, 0.2828437372321083, 0.5717882309709826, 0.36338660565595476, 0.21584709595528342, 0.7059199915778253, 0.5053449350018655, 0.9601308862047812, 1.3229960924194706, 2.1066258367030852, 2.6313298748385523, 1.1416808539821257, 3.8788568685131692, 8.244746596582475, 6.914748337961013, 4.085657461997002, 7.707126928913978, 3.015793980129304, 6.641813151298031, 5.7610743468807595, 2.5850552224343826, 1.865646567556166, 1.8938664274830974, 0.3371275630929778, 0.779120305613164, 1.1117882257507694, 0.29909770214749926, 1.7613465771559746, 3.2865978488999033, 6.875497669942918, 14.582485845012052, 31.274871480080392, 24.20097101119257, 25.80148631526578, 21.24810091910824, 22.78400301933289, 18.570494920976703, 26.38733936894325, 24.319554067427113, 27.694145633328347, 36.4535552455533, 20.301093670629687, 3.3082515385843094, 0.05524835354017635, 0.041717907804394924, 0.08080319276139622, 0.059903352746679905, 0.022367038200759602, 0.05487037341921561, 0.010746668952877724, 0.050148839476488294, 0.007860874156317404, 0.014137765768194392, 0.059211383829073566, 0.02425866250339295, 0.056984810564186306, 0.01685225468639645, 0.05157737895065258, 0.0377961466719787, 0.022231409994644985, 0.028022741673574336, 0.028319585422474532, 0.048634574763597026, 0.040585392365051855, 0.03888822416023862, 0.00407456694501302, 0.018692066547490897, 0.03312321717760736, 0.013139535965878638, 0.12534105489330907, 0.014747817861667324, 0.03265733229777506, 0.03665191391783376, 0.038253868884977796, 0.04990760605001161, 0.029878493909153248, 0.03528299906681623, 0.025435335250691544, 0.10948773864055834, 0.015520056514369865, 0.056469788804890654, 0.026233489700262586, 0.03537813952613262, 0.05087548919442681, 0.009203680730875461, 0.021520424859538194, 0.010888308076368225, 0.07753604226895879, 0.10124555954168882, 0.02392942089617493, 0.0032964251060489448, 0.014134420836795003, 0.040926477691579255, 0.03046314731510657, 0.10697750599994775, 0.0025911583384919555, 0.03841842074067362, 0.010241187861069076, 0.014632416291973524, 0.05277033872722138, 0.006687726849885357, 0.07354240293704695, 0.04220838027615701, 0.02850634616709525, 0.04686982228210376, 0.07862877476239398, 0.07489270185150447, 0.01498333435700906, 0.08290120881170997, 0.06436538206593645, 0.10251217101129795, 0.04942078398720873, 0.049097502544041605, 0.03430174768812234, 0.07055944808187985, 0.09035126831863197, 0.04957407435041763, 0.05726668495504607, 0.016652173587992307, 0.05155959038905079, 0.0479593601888947, 0.07666826383360932, 0.07347196115240937, 0.025022438757361907, 0.009552888504620041, 0.030604214745483575, 0.0022032126106487047, 0.04225076792100745, 0.03998581365111374, 0.020538780860783114, 0.01588241610255453, 0.03481704523907073, 0.04751532030622325, 0.027590859606261217, 0.046986451507696224, 0.05865472902153289, 0.04169009498230392, 0.011727631133380196, 0.016313007311715234, 0.03413380206292195, 0.04493420154997899, 0.08764520062193756, 2.0099006785500437, 16.27539355908671, 40.39434486819852, 49.0001936881773, 42.09987378889515, 31.96137647474966, 17.394140804967574, 18.948821252392186, 24.177144573580836, 31.012462954367365, 35.16187167936756, 36.50203966325329, 30.98434348260203, 17.80861766107621, 7.627095868510585, 2.0366539397547325, 0.9526019579460545, 0.11901264769896386, 0.49802141023739693, 0.4055416049255479, 0.5816103974657675, 0.6127963659744109, 1.8471603143599726, 0.8807080383262328, 4.163200759118603, 3.2464227272618205, 2.6478540849301124, 2.206273405782638, 8.82755785219131, 5.159108196535419, 5.03791529324747, 2.3863616778004557, 2.160007823859492, 3.487485714497105, 2.6175623555337233, 1.5687112558272578, 0.8392203935692388, 1.0243601880727276, 0.6578249916914971, 1.2123579195430203, 1.9009105140163054, 3.0733528012229554, 3.5020185862818076, 5.662466451045006, 4.222526117678612, 3.6704571737397105, 6.954772203199326, 4.185678391687332, 5.890820468625715, 5.133648091746915, 2.57381052259476, 2.4360733070681175, 3.6333319400587394, 1.5655357294505643, 1.9519982823441107, 0.8471464618079124, 1.3100353556294597, 0.20966577764240005, 0.24522898868928034, 0.4273692884993169, 0.1489779623525758, 0.3621612939863436, 2.2694066503355583, 7.520995265053165, 13.374622348816166, 24.624665437206147, 35.697020253827496, 37.20796039027553, 27.4302093444332, 27.6332567199584, 18.76548182579779, 23.540324241884296, 33.28827311915736, 30.385534840245402, 41.38796360261979, 29.398511571268884, 6.641865122702814, 0.08032470190476987, 0.015667930635954105, 0.06605475915655976, 0.03834036787250831, 0.11256987889928204, 0.03242100566445339, 0.08450157414641112, 0.020179246221819234, 0.023128481716999126, 0.03883131914922307, 0.012724919605158992, 0.019173326811963515, 0.03980333150755014, 0.03744964127338702, 0.04430165807265909, 0.01969706473661767, 0.053109478190421104, 0.0263427549056829, 0.011445102694955085, 0.0445841146903413, 0.06284075984430891, 0.05679935216903687, 0.01486962775684773, 0.04987669823270652, 0.012262237930460083, 0.03984593365701937, 0.028885783770331935, 0.11637299982530457, 0.03579805530006847, 0.024795477548914573, 0.045265802708003795, 0.002825964526686397, 0.053540084721340295, 0.030473673363186182, 0.04680680388945245, 0.04310861785685824, 0.019060411197584004, 0.04497567755019954, 0.022577315929435918, 0.04287453969159434, 0.037390415015960896, 0.021198970536070488, 0.042495850939303643, 0.03425997674405094, 0.006513793768751766, 0.23622117365800568, 0.13143749066418217, 0.12150952742705423, 0.08145614482101896, 0.290042573526021, 0.14372771665934594, 0.15652383647618756, 0.1965614606536204, 0.14220989729848602, 0.14024632201800424, 0.08707348452580553, 0.11303667925418386, 0.17546813364230818, 0.19798079175093483, 0.1453948772001651, 0.13330662262535867, 0.08918191171101025, 0.25381586904967984, 0.14957630766495583, 0.10441045261799328, 0.11246251167669413, 0.17226447651703514, 0.23768616359560724, 0.10997009058032306, 0.1822890127978979, 0.1839332213445056, 0.21289175856978665, 0.30111980654539605, 0.13075398701813915, 0.12468914471326337, 0.23457822149559376, 0.11389237648296742, 0.2469308989783449, 0.11857943263866248, 0.19537491303297783, 0.1429235848087457, 0.07484530399162924, 0.13129464590982085, 0.19116628644687517, 0.10485701292993561, 0.08415682691960566, 0.19613228287668, 0.13800363026319012, 0.1752881795888947, 0.14320918238691746, 0.13728778238498396, 0.11805466241053036, 0.2728234604001045, 0.13815556082033342, 0.09110049464769902, 0.20828528720284664, 0.08801928901624295, 0.12167171590150365, 0.14246532633419962, 1.5614996105432513, 14.9123542347262, 41.191617596533995, 59.330657682111195, 54.4618195872153, 46.91018227607974, 35.64664917607462, 37.827875306529386, 33.30310752314906, 29.79013473756852, 37.53800038368472, 35.421042288503344, 31.676408436990556, 20.043372377272576, 12.932288819743743, 5.019665485428226, 1.6465299768793968, 0.6840506941080094, 2.7130656953780883, 4.525902819248938, 7.059179323334848, 5.86859877071073, 10.921500459794077, 10.440213872540383, 10.309855861048545, 8.081589725709732, 6.460930109024049, 2.283270512857745, 12.503336456514175, 6.624630228165658, 6.488362675712955, 2.828089200681256, 2.9396320927527646, 4.108697709537322, 1.8692146986722948, 2.1661264761801693, 1.687321033208601, 1.541297933267009, 0.8184604527008149, 1.3402390768451076, 1.949511989951134, 4.2676142531056565, 6.053854765430574, 7.4087522299058985, 9.111398208525873, 6.229119012432714, 13.462637393705307, 19.5259117311047, 17.001095779480472, 12.89478801911877, 21.882805132096816, 13.433508892213146, 14.608254836451623, 12.728696234764593, 9.797936543341606, 6.482030499366022, 5.93876556042702, 2.9969661130059153, 2.588618450587796, 2.3032601369965464, 0.6172346503984544, 2.3205671050856194, 4.2407484689066495, 8.25013691379178, 18.204190654139367, 37.904161484010764, 31.746891467801987, 35.75631080135223, 31.1377767978176, 31.05535799457181, 29.536645681627338, 37.41258259742491, 38.91145752322289, 41.42283347345168, 52.392663417323945, 29.94254235298403, 5.131070604247432, 0.1269462312601747, 0.1710510392102503, 0.3418914961718744, 0.1424789626992518, 0.19436948391939365, 0.09283842639096322, 0.13506009063172725, 0.14305061750834988, 0.07030761199853114, 0.11077759321779014, 0.1379763115678103, 0.1556938568190221, 0.1996349594405582, 0.19127605152466606, 0.13718857399878964, 0.10841192902937051, 0.14233498413476253, 0.16566735632236929, 0.10679794265137565, 0.13745632172832567, 0.12750490087895625, 0.15061524546434804, 0.13110445692173897, 0.09314178954809905, 0.13164290948019874, 0.11847735908363136, 0.24656040353640435, 0.172222571507577, 0.15737764146779815, 0.16766413385348936, 0.11489398281780944, 0.15471769226414545, 0.09667864895515865, 0.13454359415317738, 0.1291669745959582, 0.19628824305630502, 0.08236741406782981, 0.10812771040946247, 0.07342723693938986, 0.14592111831711185, 0.21257573197926247, 0.11277499894100813, 0.16945848031149757, 0.1772376741733282, 0.1673410898975788], [0.0432858293155028, 0.013944728848254009, 0.017538207898577376, 0.0827358104288578, 0.0532555558358229, 0.05560159668206208, 0.14293665426873392, 0.004060332552574936, 0.043239599739712094, 0.01226343111240215, 0.045129611427264835, 0.03238856950173936, 0.04443364736113337, 0.01683627026185634, 0.036957445103795304, 0.06974718803840299, 0.08427888004770202, 0.060910145496769305, 0.10026833778547664, 0.05289659384758242, 0.03781382798127109, 0.030263043234064698, 0.021956265686200033, 0.08080120859367233, 0.060236367336925, 0.011023503442805622, 0.04983027713493474, 0.036001754248695034, 0.04457979395444836, 0.03437650254777363, 0.03940325358041352, 0.04067939518380069, 0.058312567341471874, 0.02399975925894274, 0.029124525495834892, 0.035289855553738536, 0.035062388727261175, 0.012963962977782134, 0.04097993530693554, 0.09356482329988673, 0.005944458290844435, 0.06426269947100552, 0.006041795986088654, 0.027253394045176047, 0.08692257286560151, 0.1228351200059537, 0.046338865893983075, 0.05208957767594726, 0.0771121121942997, 0.05123161282690783, 0.04809313829267218, 0.004925174955954595, 0.0481293665906114, 0.06550617891574098, 0.054076403724930944, 0.1894750707452336, 2.903123406633254, 17.886313930634532, 37.28598417774324, 42.948082416288315, 40.95513397647489, 32.54171271477976, 28.64367300464261, 20.264784289944558, 25.83876452138347, 26.342863613559356, 21.504317983504265, 27.066554638647265, 28.917860407983106, 30.007247732531642, 20.480349909874704, 12.877232470820028, 4.273683140354772, 1.3848541989441843, 0.5672910497073205, 0.2960338101031319, 1.3506088429881682, 0.3914249333883486, 2.8045086466496993, 4.3532327298195135, 3.725025187576971, 2.3387970559058653, 0.024988298049016346, 0.9191613620327366, 1.11254156597199, 2.298334130356389, 1.8491207640017233, 4.06581443644339, 3.6976960734013593, 1.2418776774598708, 0.3609442254227977, 0.9995336686411213, 0.5978447198867798, 0.6367992489568649, 1.5521150947578493, 1.874524116996796, 2.5211703536971926, 5.823467979508062, 2.3394690069460102, 2.9087674521630813, 5.508490868153111, 2.7402094775630585, 5.044956438003048, 4.318600162383049, 1.424900372662852, 0.972975790500641, 2.8322493645452687, 0.7709368931189661, 0.4981191017695012, 0.590528947932105, 0.11734060717806702, 0.4410813430384283, 1.7025296558295528, 2.851931572921815, 10.074507767154325, 14.731721243550702, 22.885157023706746, 17.867231599746212, 47.522836885144635, 52.302754848234116, 20.785828021264848, 16.665680177750126, 19.656008904980077, 24.60124496490725, 22.85264841971859, 29.269079239137714, 30.767436412072954, 28.616396842464326, 11.23271405696869, 1.4745292644346915, 0.08936304553982713, 0.06614745579539769, 0.02709077464626922, 0.01623578181850814, 0.026510420908790924, 0.03953915374774126, 0.01146601306484832, 0.030630347919800592, 0.017633112785857052, 0.011174489796582249, 0.03134570167129559, 0.042754355818033225, 0.05138321779668332, 0.024756615823735634, 0.01992242865174288, 0.051058484616899685, 0.022118105590643904, 0.06834059698326934, 0.07045896032885199, 0.043507527499910326, 0.028338521200742935, 0.05411131052120079, 0.1410703415111188, 0.04184710087194558, 0.019847721672586856, 0.014391564951849081, 0.03733201230305337, 0.023866371860006647, 0.056756589141103535, 0.021575671290197683, 0.024488450576280876, 0.004969262837191984, 0.027986930893553842, 0.044766049081039046, 0.05221041655468364, 0.02038911983911549, 0.028475490060725042, 0.0069236158554802744, 0.044804491373079444, 0.08867414863479715, 0.07395038306112252, 0.023619341063162973, 0.06632036950078703, 0.04713173625209639, 0.06196820485075155, 0.054622877223957936, 0.07489282442557235, 0.02964578129561438, 0.01444281527637354, 0.12221180022724214, 0.039991256705815756, 0.03805548658654575, 0.051322302315384156, 0.04823463473228678, 0.019620427215892463, 0.04628468432553834, 0.006973639481715979, 0.0450917168880903, 0.038825493050558914, 0.019658400279079235, 0.02376614074643341, 0.03692514683690764, 0.15890243222876904, 0.1243878499935231, 0.007706421254683407, 0.04021638696412406, 0.01114930657129134, 0.015020347895070672, 0.008301869797099742, 0.06143386235400554, 0.09251736660277651, 0.026277874919375586, 0.029207056147917628, 0.05997072634918075, 0.07719851159040006, 0.028517789605464187, 0.020023563749066765, 0.09504440721244582, 0.015727519827534356, 0.022096247186944373, 0.036794547998015924, 0.03674679007681628, 0.06741894724508447, 0.030779110703376994, 0.04029566557296822, 0.04791259818199662, 0.03425710391433489, 0.06171510855276739, 0.009958716879238286, 0.07309601882532721, 0.0031043592025525872, 0.08572294046321223, 0.051245689692516486, 0.022471388952145656, 0.072891557619216, 0.027822986162538012, 0.02635072796575485, 0.07109262229454133, 0.016531309811398387, 0.027891529964343197, 0.03389234647094723, 0.5724680267514721, 7.1229609847068796, 25.965382552916004, 45.87082086070892, 47.15444787856072, 40.98884282573577, 30.150951608534786, 23.222463207860148, 15.485636092001393, 24.62067834792599, 26.44134452266078, 30.739201230387536, 39.47434117717128, 40.11873168330039, 36.55800011850173, 18.58395061185283, 10.429306741683714, 3.468462464309508, 0.8731573531704565, 0.7597314782681004, 0.25257710487611834, 0.25131485244679835, 0.24608610318072383, 0.7109897775996117, 0.6938430138172642, 1.3941640671222442, 1.5893112988241258, 0.6496741226123226, 1.2070386952930883, 1.6533317344803966, 3.267445650792891, 1.9395499051578584, 3.7527739953610206, 2.6678812167336865, 1.9534031037361392, 0.9130742112475058, 0.6384058885516659, 0.8015972640245193, 2.1012867554541557, 1.221466888823817, 2.3831259675564307, 2.1561923382743715, 3.7414172628233513, 2.8530283656812485, 3.6898277988356933, 1.5562482923269274, 1.77612557766899, 1.7572863111572883, 2.2276064417054577, 0.1758358864894798, 0.514209246443164, 0.5642987102750809, 0.9593637564009236, 0.3866613986751726, 0.42126022759945164, 0.18947189914122706, 0.24139301791306467, 1.1097052020411338, 3.4133421317223585, 8.632705288548625, 16.503333276317967, 29.403834227592718, 30.84503266119188, 43.92497616429483, 56.343200129847375, 27.251510081752656, 18.714826376207416, 22.394403796042166, 24.059059658358176, 25.259275513310588, 35.16275029028616, 35.76879178324054, 35.34692125935709, 18.431572414213612, 3.469876723904764, 0.043670834462729194, 0.04969554142125192, 0.04287592248029767, 0.02477915796090759, 0.036898015833069245, 0.025361285191930594, 0.03409973796336882, 0.04071229866014854, 0.03923074973206367, 0.039262887120487235, 0.01683996089043156, 0.09579659830177985, 0.03907289731526568, 0.026523009648606665, 0.06061642355616055, 0.06980651388725928, 0.013943086547266333, 0.029409808977957697, 0.016216853701118982, 0.011267224739816402, 0.05052687322360374, 0.043955616157261596, 0.12893083565417798, 0.06646422549120842, 0.005342667498024962, 0.028081002660215865, 0.033017336165592555, 0.04559861428494896, 0.014767469932144929, 0.035442372168143915, 0.019699317035115054, 0.15115029659242402, 0.0370118526681777, 0.10262136152314563, 0.036109493023926215, 0.03203824898528476, 0.04420624182168995, 0.01642732486699618, 0.02331578446882627, 0.028305998853137417, 0.06365836335105762, 0.015040972897212112, 0.026363249672877214, 0.061197907273327155, 0.1453756330715072, 0.025469294013155085, 0.22399635624981698, 0.09544157017503055, 0.09164096201739966, 0.2516332692316463, 0.17499392521717858, 0.23209767476204904, 0.22384683120875593, 0.07860422930530003, 0.14390316611576465, 0.15995456206221736, 0.10729937018045496, 0.12340731107659879, 0.10759175529763584, 0.1604843118618573, 0.2761054117112391, 0.2144299865129494, 0.24690007160027183, 0.27275157070929007, 0.17011425157468166, 0.15918436790666274, 0.17686575380784852, 0.07123827859158478, 0.08883953935677007, 0.13623028993606567, 0.26887856724281467, 0.09444372533189674, 0.17055613108940665, 0.08463766966615954, 0.1857805964086325, 0.1371911786977322, 0.09334425892560713, 0.2031568035243019, 0.12911769982066848, 0.20744378558329998, 0.13352267474176424, 0.15963758552266707, 0.16981777554798513, 0.11763882988523092, 0.1714029493591478, 0.14302328349121157, 0.08199444416189387, 0.14473993331193924, 0.13734019812076323, 0.1999278654975276, 0.13592871176379343, 0.1848486810922623, 0.18509577509135972, 0.12021844710914359, 0.1936933347174237, 0.13322016194222436, 0.15989045582471356, 0.11807940705048463, 0.15466857070644058, 0.1249363459646702, 0.12104756874783386, 0.3411425992606148, 4.928701308465773, 25.599627417902795, 50.05409925214706, 57.347366117662006, 55.98798244230209, 44.7255358388347, 41.690664675927934, 31.062135850229573, 35.403834850557395, 35.70772832439792, 30.248677461378037, 37.383455076525294, 39.49252920766031, 38.06266054030388, 25.63781757508555, 15.876885652542116, 5.3793889957089585, 2.214795245278266, 1.1324070225800238, 1.3396150522655057, 3.763008930029408, 2.020311874728049, 7.300044230876431, 10.86025853310862, 8.396886510233726, 7.558325932871911, 2.215948912405199, 5.234768265678037, 4.686153213823996, 7.59702992054724, 7.767097517367333, 11.746201342152013, 9.861444619394119, 5.41369600642112, 1.9657488864275718, 4.378331976552164, 3.0103833156247295, 3.026627321397105, 5.875370742813234, 7.951144931777832, 8.813503019271359, 12.322999604286688, 10.372097992127943, 12.792765209751746, 13.294825650030567, 8.954455352598622, 13.104401442312426, 12.872302051513428, 9.574183956269296, 5.6106558634388835, 9.166558500259153, 4.146147764498188, 2.0283212320458506, 1.192539653951122, 0.5790456576693443, 0.7616448594677834, 2.43927322568432, 3.8170959632242885, 13.652368322495493, 19.519177021518832, 30.14221060660578, 24.094139375994285, 54.175400272492446, 62.38072410706551, 27.058919745106852, 23.954097032547, 29.289430456776774, 34.88652521564115, 35.473884459464784, 43.754502111865634, 45.56279713107694, 40.875364734280495, 16.291203652658773, 2.162008232647373, 0.10189201517571365, 0.14762603167083957, 0.14408970852532696, 0.1416611485183239, 0.13393481472326865, 0.07305323281475613, 0.17737835855974307, 0.11484129129037743, 0.1743067290273405, 0.12686940796312787, 0.11729618940021723, 0.1690614322621015, 0.12124026284342813, 0.11501057373900568, 0.17559456879333143, 0.17805829223605896, 0.236837292210229, 0.09165472095651973, 0.10977991691399967, 0.09082539247408991, 0.08950395209174003, 0.2019543059530758, 0.38259573941749914, 0.16712143716792907, 0.07142994612936052, 0.12540478574772998, 0.06112997059620196, 0.18122156120596394, 0.26879843444593493, 0.11758699637627411, 0.10597106565030352, 0.27733930356560216, 0.15926509825212343, 0.16045331594444093, 0.11476713397930707, 0.06939387594860408, 0.12696161430569428, 0.11979567382725016, 0.12655275318050577, 0.11697153665966566, 0.12183149119899159, 0.06981834228481017, 0.16475185060933714, 0.1153566386370409, 0.19535338596230556, 0.19746406544600764], [0.054875368312481916, 0.024646222553846818, 0.018400355587683378, 0.034050995619186473, 0.07681113157060838, 0.024245717532692418, 0.010984806426530404, 0.013118693586288682, 0.06740049218698856, 0.029294838332721305, 0.1099909817980182, 0.019874965674394084, 0.05143519303190613, 0.020347615110597784, 0.03514487341406845, 0.018913004389633576, 0.07382207099468478, 0.028327543160787998, 0.055987341104135405, 0.06880646271090354, 0.044427729331918304, 0.05564822845401303, 0.054076660364385576, 0.03385693022620774, 0.12420215794155676, 0.0443370973000363, 0.034793262039461446, 0.005960379513130794, 0.01421851430824327, 0.036039434283250765, 0.047530638234269236, 0.03349637860552438, 0.019998838261310613, 0.07594973464766819, 0.01849324949416182, 0.06242473196658877, 0.04191903652803552, 0.052758008542080084, 0.04043615077652278, 0.039740006679729115, 0.05657281613938751, 0.025961545724121314, 0.06424128731352187, 0.04210708813080865, 0.023050438424932863, 0.14446886076081183, 0.02930315038669975, 0.016406669221337766, 0.0368885048514893, 0.024433527817769397, 0.056861091194854635, 0.06358777217927479, 0.06516932239455563, 0.020681694563057636, 0.05585826678021301, 0.05595842894587306, 0.05640621116805462, 0.4942240349708065, 6.622531269827197, 24.165140159668464, 38.692487285983184, 41.886963613571666, 41.63000522121307, 33.6894884417134, 31.282200428747366, 32.08115585388676, 29.541334875168342, 21.543451470713464, 22.13415845747917, 23.093860457020423, 37.51275600925569, 35.099776637169626, 36.43994462105536, 29.30653199072807, 14.919259567414562, 8.09549697945195, 3.144161879054962, 1.227170382776568, 0.47735579011421053, 0.7788639419501828, 0.839867523360637, 0.8814011333930878, 0.4362501474397798, 0.4959648012393906, 1.0056310543610205, 1.6768983150682144, 1.3855349753172168, 2.1690520740324453, 2.2462055856181733, 1.7295477995949409, 0.7275651623645137, 0.48650238963384784, 0.8938490202830685, 2.251783931447614, 1.0318560826201593, 1.7448188124164459, 1.7383799966304534, 3.452492043856652, 1.0306091366275665, 2.0687256897649458, 1.062538087848694, 0.9608898648331243, 0.11658778023575583, 0.9048051194798563, 0.1763520305675845, 0.3064052003525919, 0.4422822624685303, 0.14490956050013343, 1.248085686276036, 3.834141113104359, 7.626831108523954, 13.843214185007158, 22.636863147058797, 26.298789901118127, 31.231274335615097, 26.34407170357243, 24.30562573094522, 25.792233444029286, 53.62796683465281, 42.355420127991714, 28.14497893856418, 24.65755254991593, 24.802448826451457, 34.714458680921986, 33.67243789857434, 27.684018073543427, 13.81875918757531, 3.1571375698812547, 0.16468445019375894, 0.05391821805988589, 0.0562094453151428, 0.019297519240588434, 0.04757212572580865, 0.06414697039872408, 0.0476925470866263, 0.07059688679873943, 0.01856071694243339, 0.048863363091743765, 0.0230002615811123, 0.062002138715357556, 0.05972673500617666, 0.054945626236017675, 0.03226858098059893, 0.03264739996783676, 0.02003028617060233, 0.041612605188762954, 0.009509527928105766, 0.029191146416950132, 0.03533602001205568, 0.01547393419088856, 0.024324842923951727, 0.03291772175279837, 0.029200326065502824, 0.07185250490663514, 0.042413837396569794, 0.012493220142899983, 0.03284569799659714, 0.034401002039592114, 0.02570483157591474, 0.006333177528088733, 0.03290634151668318, 0.0170009715046974, 0.07746957648064821, 0.05518068116338504, 0.030161651497286175, 0.06826473895700709, 0.08553971521436207, 0.030565504322669683, 0.10653819287976912, 0.1058365099672829, 0.052604507504692005, 0.08704502435941851, 0.020339871876903122, 0.05577927545434045, 0.054203467068052104, 0.0446322594859427, 0.031938071497866226, 0.007317327113161165, 0.03183569150766538, 0.023144270789118546, 0.031729362334214875, 0.04323710612351856, 0.015779557307401014, 0.059527276354211, 0.03855574966198014, 0.04017216453869497, 0.03364328745632403, 0.031103374654307004, 0.05202643670922807, 0.09253025986254217, 0.06739258615960998, 0.0765691090735697, 0.06800592381266818, 0.0008639497313960156, 0.0426008471197659, 0.07468608027744679, 0.06678498650510466, 0.05021368498883901, 0.022535897385809692, 0.012860189665169006, 0.033264954934918115, 0.0386178640708808, 0.013007512203447763, 0.047571715868769154, 0.05013221919897103, 0.08743733798544254, 0.045883618144979404, 0.08178959225094126, 0.06440115837200035, 0.029562616705774303, 0.06311935154841312, 0.034475695612209464, 0.031370237552290486, 0.019729772860544826, 0.033815032877628846, 0.03218069154348585, 0.059921168121359045, 0.016257400819731337, 0.04363382092466758, 0.07447193571997267, 0.007410731904524109, 0.0630751942404576, 0.02006498037747318, 0.0259265718951581, 0.038234333642908645, 0.07415420075337734, 0.017511775949969888, 0.06509004761615107, 0.05312104994851736, 0.04709832715771852, 0.028914410560842485, 0.005399886126284518, 0.06249416251516631, 1.9618559340315482, 13.550507310898075, 31.807072393355835, 47.72965561959052, 46.135859335622484, 43.56112926237045, 29.24796708168522, 29.62983923573648, 26.254702460381296, 20.583945589680827, 21.686266929872577, 30.410328142104614, 39.78379264954598, 48.76052902590845, 45.12193056844896, 36.40971491413732, 27.76595050288785, 12.885980336896836, 6.911945804472893, 1.9038274091097618, 0.5836738093245415, 0.32508689790002765, 0.24100730796494793, 0.4793412142222928, 0.17535882821727186, 0.555228351825668, 0.2634723766917183, 0.917807654027016, 0.1904128696168623, 0.289150295598853, 1.2133227000313422, 0.40923470030388526, 0.685523666681782, 0.8748326342432731, 0.56008773945993, 0.6193878477619541, 0.9336589324858882, 0.8732946974135215, 0.921570310188878, 0.5423556845034323, 0.9236020979381377, 0.23157969207292606, 0.9423527433987587, 0.24690365689175747, 0.325584763120259, 0.655309220235194, 0.7089659571647645, 0.1096767784967538, 0.13060286851419559, 0.23874342621814823, 0.084626009807952, 0.7702703966248421, 1.7576803867855382, 5.721989889298716, 11.861989709638781, 19.814966878583355, 29.235527284683723, 40.6474946391198, 37.8107149370255, 36.30269696635585, 25.835250077709077, 57.209432048182336, 52.03109541246968, 18.46331419483308, 17.400536229533536, 25.089232921600345, 36.65188204857611, 37.10731629402407, 36.14038144388507, 22.702058822877948, 7.708735100684628, 0.5370954796671867, 0.1463688813870953, 0.08353444942904097, 0.02785876629904153, 0.050440853041025906, 0.049581386659654884, 0.030441999457956805, 0.050223127022505774, 0.02900367895621927, 0.038255175064888694, 0.08352203114378838, 0.07753857035910891, 0.0431850849230203, 0.057705837196760604, 0.06272122714548342, 0.07500134844092593, 0.027004936409573403, 0.03836201368680885, 0.051630277321824146, 0.05500262700802377, 0.023721194367915876, 0.06614626069823581, 0.06612547673285007, 0.05342345932618745, 0.04216647143625925, 0.04511160453060462, 0.037675185219174435, 0.07779447436933556, 0.029465283319774657, 0.031117646872336348, 0.016985486952527877, 0.023950055474415425, 0.037969133155720855, 0.03013536127494468, 0.06485321919523901, 0.02898374917886911, 0.03487517599076514, 0.08158443390481895, 0.051766173658712264, 0.031193483831180684, 0.07712656061255163, 0.07105478521196112, 0.018749092217354525, 0.049895509521687226, 0.04049068474541268, 0.09356325281964195, 0.039763345548342315, 0.017169085669241125, 0.15639311123278835, 0.09399965480570832, 0.1487316957284366, 0.16370125295173737, 0.13532650536827504, 0.1186342002643693, 0.14583595998344884, 0.18803680195443093, 0.1766419795251662, 0.120143745875647, 0.14447376372352724, 0.1853181857375368, 0.10134744923561813, 0.18496638284094874, 0.27266638173211005, 0.1554031877387916, 0.17231414965804548, 0.1159977546382335, 0.11222115567614956, 0.14837431571175977, 0.2035170180662986, 0.16532414893229164, 0.18706472830906992, 0.10743488347338093, 0.20894007787348765, 0.09618021682986329, 0.1297867397267011, 0.10033043687261882, 0.16059499624515736, 0.12257834265549337, 0.2658670143254342, 0.11852071199926639, 0.22571499789914778, 0.08706907952024091, 0.13403655119961308, 0.12098251256130396, 0.11179388545814062, 0.12135470105755715, 0.1282502967684019, 0.11626149572792555, 0.1242672217889659, 0.17307148885823068, 0.15044390223920345, 0.12243494631782656, 0.15876922486049516, 0.25006638960011546, 0.09848309245200888, 0.11363668697735957, 0.11274787176760936, 0.2577469419808157, 0.19752201233660022, 0.16695104389181062, 0.14642117454880668, 0.12012997927564768, 0.17696870070311332, 0.17537886907737102, 0.2339273531951251, 1.3700097438789185, 11.454260310819073, 33.96136360783731, 52.98720059856292, 58.12983582096716, 56.39807016618791, 47.42556994961154, 44.841449722166985, 45.75912352531187, 41.08765517511676, 29.570162334749778, 30.770948894562263, 32.41770894296708, 49.48595177742743, 46.40682058949625, 47.009437853290194, 36.59872608800089, 19.162666913001768, 11.474267340475514, 4.642761503496478, 2.003694140622693, 1.0324319355910825, 2.2515140233501314, 1.6830288570734764, 3.233398251956509, 3.3685349360589063, 3.490403957905308, 3.119643633404086, 6.969717904444664, 6.813762505208293, 6.108343841568117, 8.075594382901347, 6.020073842617774, 7.275677977069733, 1.8131631708914235, 4.113015503652634, 5.933640493500618, 5.029223811241889, 6.910222903374703, 7.121745049953462, 10.325245280419628, 6.919950871698319, 7.2027047314951504, 6.537674713519312, 4.17028897231625, 2.2966193191466795, 1.709286061025435, 0.7755326852202417, 0.7123711873446742, 0.9332131306009909, 0.42502996241373403, 2.15655809929294, 6.038591352201277, 10.698875554146307, 18.85413915880265, 29.058218502229263, 35.97584193752658, 42.31938139084847, 37.732675460077104, 32.59715541716545, 33.315239414092034, 61.03945785953153, 49.69008761067545, 38.27618652774442, 33.55665345345774, 36.25061573520784, 48.022342881848736, 46.58359004605202, 40.184737328560125, 21.66558034958378, 5.481037218724528, 0.4263937214930212, 0.2128089597869304, 0.22817600939062335, 0.07880108325832313, 0.1482335240730355, 0.17789111652922246, 0.20238892295427863, 0.18016751615270493, 0.16859980300068858, 0.1913349023990093, 0.1867403513601711, 0.15126672663515614, 0.12711822566005493, 0.15468913250632826, 0.12042847011358508, 0.17544983946267637, 0.09620121529986782, 0.12847685195024938, 0.1565344697765766, 0.14847208385265645, 0.11922446334914816, 0.10192800598639636, 0.15973426581871125, 0.12921900728777533, 0.17165511486030396, 0.2162757681141938, 0.15100605755804047, 0.1315163670768661, 0.11551346449602036, 0.19409295682224537, 0.24793355485364316, 0.07398074312556176, 0.13018671423196793, 0.15778210524830127, 0.19518207338067795, 0.2425486462250833, 0.21221735604828407, 0.18511247580810902, 0.13460710284210023, 0.07869058273612492, 0.16068467449757362, 0.246052379990297, 0.1947562357470874, 0.18703299694724623, 0.12602209939711517, 0.27531447189469493, 0.1318131035734569, 0.10414968394944746], [0.07138480822886191, 0.06291804662454994, 0.02227541983067509, 0.05225245562952854, 0.022203380752715374, 0.04023566173629896, 0.02858113741592294, 0.0047394378963227, 0.006892829175828206, 0.03143674930587652, 0.11139461575376411, 0.026499875708513206, 0.007209615629812282, 0.07030422588990581, 0.01978662041496606, 0.042642755959663665, 0.05552746618406908, 0.021645023314762982, 0.00887349013224124, 0.08282234005990528, 0.04294892682904198, 0.04674178600731877, 0.13804320636535847, 0.016705125585318576, 0.08240234767717701, 0.011089535433829073, 0.006296830007716293, 0.05779373429475292, 0.03931659371441892, 0.06298332497657788, 0.040177998298238364, 0.0773683456223338, 0.026168831879453316, 0.02045084354317477, 0.02834757636000793, 0.011846761636045432, 0.03953572933471972, 0.02170505587972941, 0.02833361249236811, 0.03901154516384967, 0.027119524010847655, 0.01396068262927715, 0.09485099299420273, 0.05963361318854075, 0.022668110755001827, 0.044555417036697756, 0.03934721041831278, 0.020516629428452542, 0.010769933127918312, 0.005010927965368835, 0.035288947739548264, 0.019944748623416792, 0.04900946371978329, 0.046999796759337194, 0.03458660216100755, 0.03216002632172839, 0.02934464170867878, 0.0625391165545631, 0.025596606334851637, 2.1797748534910144, 8.509544826322987, 23.09237780109529, 29.77242131387034, 38.64067277600689, 43.01051870469124, 42.21975318847164, 33.8057396488805, 35.015112277000185, 25.63171632828251, 25.582133646934267, 20.405875867412938, 29.517692788954708, 34.4825916905557, 29.47684326479512, 43.94060288706134, 37.47874121512137, 34.03379017306913, 20.20949652118068, 14.410306542150437, 11.450568379894381, 6.1064159966284235, 1.7718445557740428, 0.7454789946636846, 0.08583388531640654, 0.17482518669097655, 0.4729490685126474, 0.9402066553311964, 0.5556200372595941, 0.11973805635446504, 0.4457240197206698, 0.5642523159903865, 0.14531391702832716, 0.142103977982075, 0.6023900114720868, 0.2547693880455148, 0.3914078649493956, 0.1640087300010266, 0.37669827200232014, 0.18341575959517112, 0.3202949260031024, 0.09628482613592379, 0.11449417685188594, 0.07465781163304083, 1.319179748815875, 2.27840579325153, 3.8306046060977446, 8.776497417880643, 18.02578753040683, 22.051359184326667, 28.225554227828983, 35.37103991354666, 37.13698902437764, 34.05444537439654, 37.77680996925601, 23.17497311099883, 21.875899799408455, 18.551189014988562, 33.22821378707886, 39.591973058639034, 27.000335224213142, 31.962190366560417, 36.47183741292646, 41.05669982971684, 29.68748434897392, 19.57917751804475, 5.869769107910895, 0.4654396908177484, 0.03421629824104809, 0.048383650324878194, 0.022239375393837694, 0.041558438942076704, 0.12391589386689088, 0.07694186447488685, 0.03475827097351994, 0.051240005320118326, 0.008487852962477314, 0.04981067677539203, 0.0023638954829244365, 0.028883110123476195, 0.05034497330686258, 0.016831018729135394, 0.04234181747080819, 0.01824029875288327, 0.043915239493212396, 0.05974070844991554, 0.020725399879137837, 0.01623506552629894, 0.04259407490251526, 0.03902992361315316, 0.022917424493859855, 0.014842942999225232, 0.043881719316085505, 0.02907054311025047, 0.02838106397839804, 0.042995102778677984, 0.04371540928860346, 0.0585541493379541, 0.04103020982696645, 0.05716075414731618, 0.08682344874907887, 0.09620850845690697, 0.05515908897523919, 0.05019539463964682, 0.05354081633530798, 0.07916214049703653, 0.05254224370864611, 0.047122137170405164, 0.05647799743699932, 0.040562938327991196, 0.03767589385050439, 0.06452505011111498, 0.03725265708541678, 0.03556495389690803, 0.04302889874745761, 0.05188267264935759, 0.02783880013251497, 0.019015646764948484, 0.010489685716287745, 0.00538289669014874, 0.05845299891887173, 0.05191806208101973, 0.02118376752121314, 0.018108387988421227, 0.03429414426547385, 0.06844586512494473, 0.05966518750233997, 0.0499021974692662, 0.034670075101237145, 0.06805755813876468, 0.05400728727240236, 0.01952354199132852, 0.11346571147441865, 0.048610960103331075, 0.050207345611265594, 0.03128643519425344, 0.03664176708327667, 0.04612493584112776, 0.04859237481028803, 0.03792131394748727, 0.03870617868679185, 0.067522200575519, 0.049780289897875446, 0.060386869140089526, 0.0568860694916258, 0.05110853314099293, 0.05300606398152248, 0.027374997096616897, 0.01159079633878484, 0.05848792103690006, 0.05061125014758399, 0.07023251239931391, 0.0078046179260127255, 0.04995424165240219, 0.0528053144714044, 0.08733897229596492, 0.017514361496714335, 0.033861722106174115, 0.03490000873083069, 0.047984533838086554, 0.020490325799572374, 0.036855317922609473, 0.0420602954803936, 0.02614032957823046, 0.031594890920865926, 0.11299611489859321, 0.007417395911855444, 0.02832835138354811, 0.019030884253762422, 0.05283425727318372, 0.041715716792931484, 0.05862286742476206, 0.09180437623252792, 0.06606268816657605, 0.014531529215615124, 0.4676599668398981, 4.997438394254254, 17.375927279072425, 35.48522010926278, 40.381346133447465, 45.02732692226287, 45.66783035955122, 43.133206521311116, 32.133419475247784, 23.41142142972639, 19.713846214355964, 18.520835753410093, 26.442572224524717, 34.1553012786373, 47.03202678311256, 45.24706594405636, 53.825505241270996, 45.98119635735789, 38.270671675282145, 25.445684194564823, 18.010721706574966, 7.4149329047049255, 2.125819709993178, 1.310997439488288, 0.13867536679871623, 0.22209642755408443, 0.25063294226363786, 0.10810401530996447, 0.26808615653745593, 0.33294469238288943, 0.3818906014484744, 0.07459908333276549, 0.1965899744461621, 0.2389577622976034, 0.1133603054369169, 0.4056924936031142, 0.2543812112942819, 0.15510300384654155, 0.1619226112961769, 0.1783529602952542, 0.11309230489836586, 0.07908979881434672, 0.05217522630588182, 0.15023509731456158, 0.15172467867453254, 0.5881451887469138, 1.7718446783481108, 3.57675003428613, 9.947221952099955, 18.354699842391476, 24.761244327791278, 32.025895541714085, 40.41137972185689, 42.03770422166394, 45.214035664835286, 43.181788998265425, 31.662776239456672, 24.220537754797167, 17.268054254593387, 22.46656560128735, 47.461290974770826, 31.33708223219841, 26.51298857504322, 35.32604248292985, 43.554469077817856, 38.23319342828567, 28.346433831799416, 11.438878736188336, 1.3758982021001078, 0.03179969686654306, 0.05827841131136783, 0.029167796057018063, 0.07827597595150433, 0.07542940772949688, 0.0023667122924610254, 0.03834196516583043, 0.05902304494332883, 0.02850856399163604, 0.14237501988968543, 0.02820723479793918, 0.06127669558589978, 0.01754501842022423, 0.04702457587324804, 0.06887357967394976, 0.04001452662651578, 0.009085519329434442, 0.05316241486598888, 0.021202791399592837, 0.034696842213311506, 0.026174052768657287, 0.05708851971693578, 0.02203126186354747, 0.07908380800677885, 0.05029471793902978, 0.10648206161755709, 0.07755965309878511, 0.0600044533700472, 0.03910364425410667, 0.027059587206871762, 0.040932139081339684, 0.03032996867512984, 0.056698772485458085, 0.07663902225753955, 0.0878881117809684, 0.029761893411857948, 0.021118764960837942, 0.03179836961921425, 0.1365313778120664, 0.06097609034529137, 0.07591964271400245, 0.04762931801979581, 0.020891767363214207, 0.03417777934021527, 0.053893044410694035, 0.0036713557182660992, 0.028802948598299297, 0.025428756470641783, 0.006706756952729437, 0.26693166203556523, 0.09561192514675279, 0.20211621097499327, 0.09062468509880767, 0.19736013795819976, 0.13556986085830197, 0.20459494974103667, 0.09568946090556922, 0.15525778425076317, 0.12881109611161295, 0.25274009774288825, 0.05287301749171269, 0.237999432269604, 0.15510789148749846, 0.12151698912343672, 0.14129498913403482, 0.12981992665558093, 0.17136717305308388, 0.1470091929959674, 0.20158633860128544, 0.11613522911624563, 0.23911062748201434, 0.2329931549367405, 0.08507630862896481, 0.22472859840960274, 0.13210518225546808, 0.23201132133122415, 0.21530303563321793, 0.1823507441628364, 0.13348872172496012, 0.10205647127041895, 0.1445758985655923, 0.1318389667017806, 0.19536656267460317, 0.2414172722567474, 0.19539573530275978, 0.1266407230568509, 0.1837060149879225, 0.1389405098293097, 0.13490138785733333, 0.09328736157547082, 0.11647457542318491, 0.15836669162156122, 0.10752287633236378, 0.16932773974633988, 0.10008109823590326, 0.1212283195326886, 0.19220117930202715, 0.2053960019181813, 0.11135942167452267, 0.11411425086759752, 0.14180855915671395, 0.09882930290674972, 0.1272069233199281, 0.14206590341223826, 0.1775312084223955, 0.14163402900580438, 0.18055219954300314, 0.4313935790090792, 3.2217407226562504, 15.735120407996641, 37.08837516846196, 46.16280994107647, 56.19729972654774, 56.37230019415579, 55.92224744058425, 47.98631983418619, 46.38960138443978, 36.181989946673, 35.65854964717742, 28.92481673148371, 40.34593105316162, 47.51915770192301, 38.80413755293816, 54.62891255655597, 50.37971873437205, 43.066455625718646, 26.30381249612378, 20.050036484195342, 13.64612881214388, 7.973615700198759, 2.2207714665320615, 0.8984182750986469, 0.2782559124452453, 0.7714377307603437, 0.8332234572979712, 2.220664581944866, 2.0245545309397484, 1.1184029353241767, 1.6788206441748528, 1.989884700986647, 1.1086835471853134, 1.4769374771464256, 2.419853080664912, 1.665103625385992, 1.6365618859567952, 0.6377321601875368, 1.6348588418576027, 0.7194860604020857, 1.1003731479567866, 0.2593140820822408, 0.6454809250370149, 0.20211527634772564, 1.921758034056233, 3.7761388190331, 5.659073600845953, 13.361799140130321, 23.628204945595037, 30.22706520172858, 35.73662442545737, 45.04325174516247, 48.880714370358376, 45.49262985106438, 47.694750447427076, 32.23907832176455, 28.63142932614973, 25.76353934503371, 43.762648874713534, 49.88029118507139, 37.158624818248136, 43.05126428604127, 49.076162153674716, 54.92643610123665, 45.240974503178755, 28.76661773650877, 9.244117486861445, 0.9242071235372175, 0.13768798671662807, 0.1999042087024258, 0.25305761054398557, 0.21887885827210643, 0.23119588202286154, 0.13711564242839813, 0.11935356448614791, 0.1686894199660709, 0.11684312500179776, 0.32309090177859034, 0.13993437101523723, 0.16131824453271207, 0.16535077814853963, 0.10648314946240957, 0.11677988444364841, 0.11578400078560076, 0.14192209338709233, 0.1738439046687657, 0.09486078359787503, 0.15475313149152264, 0.10387870332887096, 0.11235222565911471, 0.09190848758143765, 0.25845367341272296, 0.25461217148169396, 0.26201536939028774, 0.1648776269247455, 0.1634313448542549, 0.18289149498506901, 0.1470358222122154, 0.16074556316579544, 0.21541745852558844, 0.20017204836251276, 0.2679250942122552, 0.26783359267057916, 0.130271841922114, 0.18294406393843313, 0.13791939123503624, 0.23827713914215568, 0.14859396844140946, 0.20057548558519733, 0.18485137772175575, 0.13573460040553925, 0.1395369552436375, 0.11745158267477829, 0.1154307499828358, 0.08980382188794114, 0.15129700242992372, 0.1432634520554735], [0.010205011274064741, 0.03551150394243098, 0.09697190741257322, 0.040964946796696995, 0.049941061109664946, 0.02388719029934897, 0.01883428885541376, 0.013581190442275858, 0.03905810798788744, 0.00427600976470257, 0.06290156424285905, 0.04696238102511533, 0.05267629377363671, 0.046856251034525134, 0.06347110081884651, 0.08704904632102098, 0.03338484003418877, 0.04462221990369501, 0.07098707070033397, 0.1348365461754222, 0.02799997354046472, 0.024606407049202153, 0.009170986971096888, 0.029354462955868053, 0.14958045986150542, 0.05150215677736748, 0.03263774725999082, 0.04015866606946915, 0.029119549754766688, 0.04479312645872274, 0.02133027800629216, 0.057513081814132394, 0.038392940656312054, 0.013744366212537693, 0.10008684389533536, 0.05870866927228147, 0.030764363510834596, 0.047001171887161276, 0.03924792159288641, 0.03593543401709007, 0.07382779367147915, 0.03140700785743614, 0.07031853641233138, 0.022432379755041292, 0.0451982414139615, 0.05013358666591587, 0.004425359084346002, 0.006122397054212109, 0.09288400862245791, 0.0342135786289169, 0.08410215122444976, 0.07850522776284526, 0.07909731413688391, 0.026310039120876504, 0.031900921979198055, 0.04985134838329208, 0.05891344457444164, 0.03059772598076492, 0.04356172055967393, 0.016179079820792523, 0.06781630939052952, 2.7514774664755794, 7.887304925149488, 19.411223588451264, 32.431629434708626, 37.97283434098767, 40.519390029291955, 42.48792955952306, 42.05696305921001, 35.794808864593506, 33.707433285251746, 31.515318655198623, 21.802604429183468, 29.191202540551465, 21.622332296063824, 25.750581795169463, 28.79286231533174, 34.71359183711391, 28.89331617662984, 25.791433280514134, 41.41638901925857, 28.90841926297834, 22.08587996421322, 14.90208645020762, 11.405213032999347, 8.81654481733999, 4.9647420067941, 2.874383710084423, 2.3683852101525953, 1.7384597923486464, 2.206786010534533, 1.286534719890164, 2.0168274617002857, 2.4640733916913313, 1.651182520774103, 1.9243684939799772, 2.8824635474912585, 3.878232966507635, 5.395570733854848, 8.235784961331277, 11.78957393092494, 14.900243916819173, 17.39824164298273, 21.748201154893447, 23.86948758555997, 30.34961573539242, 32.55868481051537, 26.471872329711918, 27.1911604942814, 26.061533574135076, 25.572239468174597, 21.699065623744843, 22.686816492388328, 22.927593146601033, 22.945967489673247, 23.870303438555812, 29.045262913550104, 31.700558470141505, 38.268424157173406, 44.28544982787102, 43.02331347619334, 34.14574638489754, 19.16761890534432, 6.655428188462412, 1.2907987039896751, 0.09084621474387185, 0.01747348496029454, 0.04903390958544709, 0.09205947585043409, 0.0070762483406842, 0.0829869417113162, 0.03217706411716438, 0.06420437719733005, 0.03208624247852112, 0.021053850500574036, 0.0850525752250706, 0.06723447327291773, 0.026365304703734098, 0.021101206225613435, 0.06652843132014237, 0.06329747848212719, 0.055134221761217045, 0.044912931118761344, 0.0735424642240809, 0.0600655373906897, 0.04721330163339454, 0.017602806347572518, 0.037303107805670276, 0.03181088749589699, 0.054060063069506045, 0.06438467982074907, 0.013969253237930038, 0.044206506122023835, 0.020815127927269188, 0.03616706070099627, 0.05403189784696987, 0.031976477400730216, 0.010900729234450528, 0.04235941451042891, 0.023658212364440965, 0.025267117664278037, 0.04940439736650837, 0.057516870118917963, 0.08388749338806638, 0.025372274723204396, 0.06618532352149487, 0.022686985246236288, 0.05485494057798097, 0.06010158948840634, 0.03785356496190352, 0.028636874142853964, 0.024405490914960543, 0.06005849704266556, 0.062195254159310175, 0.14202157756493938, 0.028224806939702363, 0.021199918569876783, 0.055478727670326355, 0.03284048476827241, 0.016847307673625408, 0.054539507705598116, 0.056457205810734344, 0.009454323632282116, 0.03170050571732704, 0.05904614632468551, 0.01959381715184258, 0.10734971747883867, 0.04227884504343233, 0.08869148520452362, 0.0705426707563381, 0.02391791808599186, 0.07608939247626452, 0.016507833046958815, 0.06236524140882877, 0.03072878064197158, 0.03041278277974456, 0.018811423046093796, 0.0641347666180903, 0.03314724935579204, 0.02879641961396462, 0.07866382328492981, 0.01223715621181914, 0.07724210965417086, 0.046100520618980935, 0.044863062625330304, 0.04443550129391013, 0.06140257915361755, 0.06583800223926384, 0.005717408982285809, 0.027707971467245972, 0.03549568422679459, 0.03096641728564376, 0.06640335214474509, 0.04355320549239555, 0.02736448637029577, 0.009607001125151593, 0.04980400031913192, 0.021244259738934138, 0.02979756629605207, 0.02912684674224546, 0.012215897271920358, 0.05716028683368237, 0.052901075461939465, 0.030372890666307464, 0.06625990984180281, 0.011554529736449402, 0.00611537442197122, 0.067364884420268, 0.11096650283903846, 0.08333922724329657, 0.016870931909990408, 0.043245353060023445, 0.09066754005729191, 0.01818608271048194, 0.006270599157188929, 0.03821225498893088, 0.33230887004925364, 5.47935942488332, 13.897793965954936, 29.8083580693891, 42.85427893361738, 45.80538395912417, 45.853978203188994, 45.3163153894486, 38.954505535864065, 32.68118827573715, 24.982805290529807, 30.912948500725534, 26.752447312878026, 24.026629501773467, 27.901125184951294, 33.66339683532715, 39.462413249477265, 44.24738322534869, 41.548568971695445, 44.95874427979992, 40.17162484507407, 31.259270252720004, 25.872169386956003, 14.974639511877491, 11.987592827889229, 6.123110584674343, 5.546036285738792, 3.626592817806429, 3.064795170099505, 1.815757328464139, 1.7116267354257646, 1.3952326678460645, 1.6970096552564253, 1.8737690607386253, 2.116666368899807, 1.8840641792743438, 1.5187625683123067, 2.9365211629098464, 2.9458321342545175, 7.301593567094496, 12.191402123820398, 16.07118025902779, 23.21326917217624, 29.087342100758708, 36.15184260952857, 38.01304255762408, 39.81538734128399, 39.69154634783345, 36.648665705034816, 37.66788182720062, 33.893722334215724, 31.11430729589155, 28.14069178796584, 27.518294011392904, 20.98636704106485, 20.88248698942123, 21.067303188385505, 29.86654054734015, 42.45597793209938, 41.95882143512849, 44.928718536130845, 42.800817028168716, 28.951865396191998, 12.88571753809529, 3.246681848841329, 0.3112078974804571, 0.021707614613396507, 0.0359372649672291, 0.043992484138617595, 0.040377885959441626, 0.0514397704072537, 0.10542613964888359, 0.011348334298799596, 0.03384148589365425, 0.03623560641802127, 0.03095668413856578, 0.05084929281785604, 0.07045933571193488, 0.029575712978839878, 0.023110465244239858, 0.0665314267239263, 0.07091185618792811, 0.011866346673829662, 0.026739498435129083, 0.002684051526762966, 0.04622767972309263, 0.0372931256800169, 0.045749617875703884, 0.034920670122148535, 0.06485129631454907, 0.0801472376371103, 0.07030292354043453, 0.04029826261103153, 0.14915394807054153, 0.04126177139339909, 0.05516119571703096, 0.03489827737212181, 0.040226759794618816, 0.05249937342840338, 0.13640603050589561, 0.07393646324353834, 0.1302301973825501, 0.03816263164363561, 0.030979699335030975, 0.044493750789232796, 0.03414333602713962, 0.03710391728447811, 0.12513631023466587, 0.06753410558186232, 0.0628355849203804, 0.035970482539625905, 0.018504459275713852, 0.0722873670559737, 0.07578909367082581, 0.044646907087054946, 0.041816564607283765, 0.12645626440644264, 0.23268984540575938, 0.23405654626267575, 0.1061210580049984, 0.2199364579733341, 0.1840853510845092, 0.12014592156535196, 0.11409630142753163, 0.15563949521991516, 0.045214516951912836, 0.18478085166744648, 0.31767910346388817, 0.1987678551625821, 0.2160660285622843, 0.09115730772816366, 0.12562823061260486, 0.195958717996555, 0.10670481700330012, 0.11794101326696335, 0.2074489796594266, 0.17023541604078588, 0.17768297044019546, 0.10131937211319324, 0.15973993486935095, 0.28304788434217054, 0.1412794375491719, 0.17975378270831802, 0.17976443133046552, 0.19017366632338495, 0.13066421683517196, 0.168900124788765, 0.21977542629165037, 0.11573184551971576, 0.15369851953319966, 0.23526943198615508, 0.15070395844597972, 0.13115013108378457, 0.12436008696714718, 0.22441103964323, 0.0895430149149991, 0.10700559078325188, 0.11172223325458266, 0.10239210971180471, 0.12307548775307595, 0.11672208310976145, 0.15004138432202802, 0.12224865671727927, 0.1295740124318869, 0.1494557101039156, 0.20806456195010295, 0.13506674027491, 0.2180744965951289, 0.17346438471107714, 0.19357417740168112, 0.2350285432992443, 0.10097218106590933, 0.2538084533185728, 0.13936188883118092, 0.17567882314324382, 0.08723332877120665, 0.31798510962436277, 4.3117796509496635, 12.423262250038887, 27.59442525525247, 46.973677604429184, 55.16983485990956, 56.422302569112475, 59.285734776527654, 55.56719057021603, 48.49958942782495, 44.369106138906176, 43.52679675625217, 35.49734023309524, 41.18200386724165, 31.954539783539314, 35.3198294485769, 38.27696315703854, 44.03858761633597, 38.86382425985029, 36.65800094604492, 52.387227012265114, 38.81554772776943, 30.641408697251354, 21.27959559040685, 17.504302532442157, 11.67696366387029, 7.6533571174067845, 4.325944800530711, 3.64568593521272, 2.9967744071637434, 2.904331251498192, 2.1200601996914035, 3.529995872128395, 3.4147921829454364, 2.6174030092454728, 3.1620245979678248, 3.902761998676485, 5.275266247410928, 8.064832379741054, 11.426206538754126, 16.102735727064072, 21.924003747201738, 25.233931118442168, 30.76445737192708, 35.075053937973514, 40.34355801920737, 43.534253181949744, 36.36172079270886, 36.670348567347375, 36.0112177941107, 34.816593277838926, 31.036742425734, 31.968164136332852, 34.2160980163082, 33.27475270917339, 34.49621800453433, 38.90314994319793, 45.2305684551116, 50.151734890476355, 54.94126266048801, 57.588282016015825, 49.02501052425754, 28.2134380263667, 10.454017673769306, 2.0502373528095985, 0.32461511031273876, 0.1774444413040915, 0.14701968840053006, 0.19712410626872895, 0.11304868385195734, 0.2587142965245632, 0.18019100440846336, 0.13857228200762503, 0.22713152511465937, 0.2100127082197897, 0.16050950083280766, 0.15772205927679617, 0.15460899970944852, 0.09367209859192373, 0.24352998953432808, 0.21259056344147653, 0.17265956338134505, 0.11632881187383207, 0.22630710725582417, 0.21868611055035747, 0.0955651784616132, 0.1603140718033237, 0.12073071478235146, 0.08904783100250269, 0.127187357434342, 0.13011038123119262, 0.19869331480754962, 0.13450424787738632, 0.13565558609702896, 0.2413600761323206, 0.09148018314473091, 0.07888523801680535, 0.15871311658092085, 0.1349753153420264, 0.17298513542740576, 0.1155534006595131, 0.12965993685347418, 0.10161427765964501, 0.21016874500820715, 0.0794699163206162, 0.10193411936803211, 0.09130543848920254, 0.14604044417219778, 0.2487482280740815, 0.201573483645916, 0.14146977975483865, 0.11003942919834969, 0.2880335539098709, 0.15118544470639, 0.2876690186319813, 0.14165606169450667], [0.015372462972487896, 0.0691359264836196, 0.027908324526863235, 0.027234490825644424, 0.04209542444216148, 0.03848814623310201, 0.08395077225061194, 0.05289597714680338, 0.03940054929004081, 0.06317297387267314, 0.09110224132816638, 0.04622543891591411, 0.05644586387901537, 0.04015457899039311, 0.03770139691750369, 0.009193182453483103, 0.012341662096009861, 0.02479183288561481, 0.04803398864403848, 0.057397161219869895, 0.014569849891197539, 0.035433688561522195, 0.027554790271566282, 0.023050825299334624, 0.03502851614968912, 0.017256078783482794, 0.07431497962604608, 0.03630056684356063, 0.02468378384477429, 0.006593046043323534, 0.02603902211112361, 0.07679523524617957, 0.011437078881558153, 0.00978582998692629, 0.03100972806644296, 0.03611751013405381, 0.07804549073860531, 0.03462584501492881, 0.05315115720394158, 0.062683604567522, 0.04207928296959689, 0.07226962445964737, 0.08443204400640342, 0.011572942659709484, 0.03131675695429646, 0.04212773803080763, 0.009705706766145605, 0.05752032900589609, 0.0399444449032026, 0.04916798646351503, 0.03552363494471197, 0.06831006837948676, 0.05076419577122696, 0.07427525796717213, 0.06633633477312904, 0.043212495548951055, 0.06615935314086176, 0.023297517102271802, 0.03383976602626424, 0.025261140263248837, 0.041798063583912394, 0.03137000389547358, 0.07448259966387864, 0.21678043619519283, 3.8481194598059503, 12.626261576529473, 24.30092869266387, 32.83449607510721, 40.404378291099306, 45.46758159514397, 50.767570541751006, 44.02881699223673, 44.447518241020944, 39.930046066161125, 35.174462487620694, 20.46907505681438, 24.31090328001207, 26.904313641209757, 43.36394386906778, 35.71180758937713, 54.17860092655305, 43.01437047220046, 24.978829968360163, 40.163772259989095, 27.765601411942516, 29.199015901934718, 25.921404938543997, 26.3756428610894, 22.12110088717553, 23.977601835804602, 17.290184267105595, 22.903064604728456, 19.52201681752359, 17.469350291836648, 20.143918414269727, 25.956974952451645, 23.758204060216105, 26.517399280301987, 37.65539300057196, 37.15460438882151, 25.247063213779082, 22.02830937600905, 20.858850786762854, 21.75623416900635, 21.746118376331946, 21.299903661974017, 29.605104769429854, 36.495987446077415, 27.290606306445216, 29.47918295860291, 29.539001064915812, 30.40071637399735, 36.88157212349677, 35.55691711364254, 37.352793908888295, 42.9029163237541, 41.125419755135816, 45.01872124210481, 36.60757495510963, 30.339076326739406, 18.482294544096916, 6.221779277247768, 0.6884539223486378, 0.04309954354539514, 0.05285837372104007, 0.12425998225808145, 0.056394647070837606, 0.06624146244458615, 0.04985617856765467, 0.02705696910139053, 0.024297845985500083, 0.03485641832793913, 0.0692701374270743, 0.08129558811384825, 0.04830557064363553, 0.0751300435513258, 0.02632003082262893, 0.0404584554264382, 0.028138091532333244, 0.02559462791278718, 0.002827023643241715, 0.038493026213179675, 0.02646378913683997, 0.03893565649407045, 0.03420344328567867, 0.021509261043261618, 0.048812988980282704, 0.06034595238405371, 0.03500056160133212, 0.023989311734875365, 0.036527455273655154, 0.07296775272416492, 0.05705984121549034, 0.022358224359190753, 0.11752826041511952, 0.02423984163831319, 0.008736036721647026, 0.15245707405190315, 0.025145803811028603, 0.025644864128421874, 0.02363151228505998, 0.07749809027318993, 0.03326481320865212, 0.05504868421403151, 0.08075400225577817, 0.021864992055681445, 0.043766070683036125, 0.016182027344081192, 0.07052535716924938, 0.06753159281347068, 0.025897106238370462, 0.036231500186747125, 0.03342790949729181, 0.013361273412292284, 0.05276889082104449, 0.02049504681640575, 0.07948952817147778, 0.025002911176171996, 0.020020340434125355, 0.0772326331465475, 0.016784469311636303, 0.07953764615400184, 0.023143100589814208, 0.03169602601818981, 0.034880331762495546, 0.03221406616390713, 0.020806817788510554, 0.04479761956439865, 0.027232416642589435, 0.04581393095694723, 0.058070146478712566, 0.035947319871235284, 0.045434299916509664, 0.0463368664045007, 0.07036735153486652, 0.06490806342973825, 0.02762596367017156, 0.009567927768183573, 0.061031321454192364, 0.006081735501216064, 0.09300254540698183, 0.04597848281264306, 0.12094751766492283, 0.04712117956049981, 0.09073168459919193, 0.08912030292013962, 0.05811181017047456, 0.0457486717571174, 0.05335436202585698, 0.018088033032273094, 0.06332135744272702, 0.011063079544973951, 0.017881219936234337, 0.014124712587574558, 0.1412974406153925, 0.026900252409940286, 0.010486085103043627, 0.030081403787217798, 0.08220951568575637, 0.04517434330116357, 0.060236532045828725, 0.042007661409555905, 0.008779413577529692, 0.03960468873922383, 0.013430637885786354, 0.06868034165592925, 0.045156516435165564, 0.018848670240972313, 0.05777199654990147, 0.027303325740860838, 0.02829898148775101, 0.07400971657085804, 0.016122073303127003, 0.03535285096375212, 0.02190302832112197, 0.04072297792581301, 0.02908625174313784, 0.11092492724738776, 0.4807068425561152, 1.9008852637583211, 8.541080682508408, 22.2572208604505, 33.6617886635565, 42.93722921802152, 48.910347877010224, 52.07428070806688, 53.84425809306484, 45.21217253900344, 38.93438769925026, 40.486516644877774, 26.91082673688089, 19.56799484068348, 22.099031671400994, 27.308655092793128, 32.73206926161243, 29.515058917383996, 56.23371893359769, 52.10788365333311, 40.27834469272245, 48.76062316279258, 42.60839731462541, 43.575049754112, 35.14334240267354, 30.123508745624175, 24.444561966003914, 29.049808940579815, 27.397222211284024, 28.793080006876302, 30.18869657670298, 29.272009249656435, 28.084262609481815, 30.396880295968828, 37.55123838301628, 39.6371901419855, 40.89544726956276, 37.27746478972897, 41.67004477593207, 37.5186905553264, 33.974378032069055, 33.26459769279727, 27.98466774725145, 27.702339464618316, 34.88048084320561, 28.651945283336026, 24.066731814415228, 23.951865203918953, 24.646824867494647, 25.161763429641727, 33.78471966712706, 32.77634889848771, 33.62012132521599, 42.4348638134618, 44.847541163044596, 48.07791110007994, 46.63147041874547, 42.22787249472834, 29.62510297375341, 12.475617066506418, 2.3197664512741953, 0.12122285732578848, 0.026621243187917337, 0.054899323881874164, 0.07677436701112217, 0.03764485579825217, 0.050877216722696066, 0.02772670806265406, 0.03916264451559513, 0.025624223804521947, 0.05978882260199997, 0.01337913954029641, 0.03898328034988335, 0.06555624276159272, 0.013112263235774253, 0.009821116954328553, 0.043781189428221796, 0.055481251930036855, 0.040966816051232244, 0.024352067773560845, 0.011911652156061703, 0.07594707632257093, 0.03446288662211549, 0.06261071896240597, 0.019658329415946238, 0.007760091459438686, 0.034459420074258125, 0.04075739442581131, 0.04486190583256464, 0.07818907859825319, 0.06640062487173466, 0.0839000419082661, 0.03813889057886216, 0.045357503432540164, 0.04880977524144035, 0.060440594886219313, 0.051861877192653, 0.020644098798173572, 0.05180722831057445, 0.08719038954305072, 0.03955168694618248, 0.013656314939350612, 0.04526360020522149, 0.018231082715154178, 0.07192252534291438, 0.07795268684745797, 0.02331329851351198, 0.0663126856389065, 0.013089061305377514, 0.018562785379828948, 0.09242137578586418, 0.02054754107619726, 0.05585052929217777, 0.05834526780451979, 0.16403989445778633, 0.10335074617497383, 0.13686663320949002, 0.17201883808499382, 0.1577766507022804, 0.16826198886959784, 0.11521512687566782, 0.17542527868382393, 0.07012585763849559, 0.16936428214032806, 0.1441574919848673, 0.1346355706693665, 0.1232465781692055, 0.16972233631437825, 0.17553398656027933, 0.1511396786137935, 0.1278741475975802, 0.10332564147369516, 0.12654914490638242, 0.19499490277901774, 0.2239617290756395, 0.16005600742515058, 0.09288338043036, 0.15766438817785633, 0.1613773099116741, 0.07994656856622427, 0.1666120499853165, 0.17635952290748397, 0.14039492775355616, 0.13887995823977456, 0.12589699723908018, 0.247934780594322, 0.11831726969009447, 0.09318064552761855, 0.1358323838681944, 0.15235794227450125, 0.12000470857826934, 0.10426841991683168, 0.1757814482815804, 0.12299271195285744, 0.15568202842147122, 0.17172484418317197, 0.1903194834988925, 0.16068389308789086, 0.1885314036401049, 0.1594071462750435, 0.08526668147814852, 0.1656706351786852, 0.1808252026356997, 0.20114879514421188, 0.10890518240029774, 0.1283628504062372, 0.17269676461094813, 0.14692426448868168, 0.11382214920294863, 0.17979797065979053, 0.09282760922947238, 0.1535010680315956, 0.07933810323236451, 0.1931701426304156, 0.161394945255691, 0.2109182701115647, 0.2646189651662304, 0.9954754251145548, 6.55182074154577, 20.174450143691033, 34.62798218573294, 45.995497319006155, 55.40758540553432, 62.742554910721324, 67.48447295158141, 60.4196802262337, 57.086485355131096, 54.37992049801735, 47.17453433621315, 32.518531507061375, 35.36561919796851, 37.17735413582095, 54.94597342706496, 42.81058372989778, 66.71240929634341, 56.25163632054483, 36.04281248584871, 52.61725441102059, 40.39907916899651, 42.504815363114886, 36.038658695836226, 36.4815374343626, 31.40139537472879, 33.941896884672104, 27.394782497036843, 32.61914226316637, 29.368744704031176, 28.166036182834258, 28.26233429293479, 36.71813872552688, 34.09028799303117, 38.0614681397715, 52.88915311136554, 51.180368623425885, 34.859633445739746, 30.52621064647552, 26.933641202988166, 29.163224274112334, 29.50835950912968, 28.644345691127164, 38.670933861886304, 45.348157190507465, 37.73022005634923, 40.63051077627367, 40.50017433781778, 41.27611329478603, 50.818616267173525, 48.410532013062515, 51.874130002913944, 56.911563334926484, 56.719386808333866, 59.293504991839015, 54.44183903355753, 45.36680021593648, 28.43742105268663, 10.426242389986593, 1.4079818417949062, 0.2191778777107116, 0.165806079523698, 0.190367930899224, 0.20895682455551243, 0.1287697426854603, 0.1670647773050493, 0.12062366165581251, 0.19588341155359823, 0.16230254494134458, 0.17711211236253863, 0.14630529608938003, 0.13674631144010252, 0.2127996135142542, 0.10619405852330309, 0.059457945397063616, 0.14103444263098702, 0.11271912048781112, 0.1062913516896867, 0.09504590108389817, 0.08714657697466113, 0.10919376006049496, 0.11537238174388487, 0.11967590364116816, 0.15144088906386208, 0.11185642887627888, 0.11347595406996627, 0.16402878618288427, 0.15709015931333267, 0.24894480623545187, 0.13625134203222491, 0.1695633424265731, 0.1861889365940325, 0.11601772655041949, 0.14721148617325291, 0.1506435907175464, 0.13506424282827686, 0.13903250166725728, 0.09856592187838209, 0.15746460776896248, 0.12274553368408835, 0.10295414245657383, 0.20222619055740296, 0.11140999879928366, 0.13158232724714664, 0.17065935377632419, 0.10025691541452562, 0.24363949414222474, 0.14512489249389018, 0.09533074023502489, 0.22722008487870618, 0.10999647464843527, 0.15691732987761497, 0.19885138938984565], [0.06155062947542437, 0.10782024102105249, 0.029497621806278348, 0.0492224055192163, 0.005259976925088033, 0.04623467793628093, 0.05960085143845889, 0.04869638273732797, 0.03149696764716458, 0.017811174602097562, 0.06432139329732427, 0.08130644357973531, 0.038996384283828164, 0.056676724474997296, 0.049641072569835576, 0.055720298175489714, 0.08350772828224205, 0.07728957646195928, 0.014662777314022666, 0.05295610738798015, 0.019038790281141, 0.07455259711752016, 0.0332818471736485, 0.012322810587413129, 0.05854769504719204, 0.08584330053699595, 0.0778207894895346, 0.029402188318330916, 0.04861843329103244, 0.029656100499954437, 0.004737029507410743, 0.03914292541242415, 0.05117528238183549, 0.04867952114211456, 0.05519235251291145, 0.06455103581350657, 0.06263221538956128, 0.05105975249241437, 0.015905480137124898, 0.08479484792558417, 0.009366270443875222, 0.056891834303256006, 0.040241265669465065, 0.054123380236447825, 0.020882336820866314, 0.035945645969120726, 0.0221480653741427, 0.03873688732123664, 0.07966731419606556, 0.043011351503551974, 0.049662454083802245, 0.04561222766736343, 0.026007691030240348, 0.043775466751427426, 0.01841141215165056, 0.06382666137670318, 0.033960034169497035, 0.022592553418249856, 0.03164066467434168, 0.06052813958376647, 0.0681301526304695, 0.05542176520271648, 0.07551299558291513, 0.015630746643329342, 0.04687033939145265, 0.42148322047245124, 1.5450674535766726, 4.254904302858537, 9.28858441691245, 16.341443331010883, 26.226412365513465, 34.243060388872706, 41.04657226993192, 41.9831754315284, 49.50211978727772, 48.636362475733605, 44.18261704906341, 34.03233105136503, 39.13171037550896, 61.583353319475734, 79.12893095324117, 48.074969322450706, 26.205804232628118, 28.835314127706713, 23.941531719699984, 25.93281903574544, 25.10375745834843, 35.66155418272942, 42.06570602232411, 26.672487835730276, 22.191817299012218, 24.837389299946448, 28.48120058736494, 25.406840962748376, 30.888414075297696, 24.60927405664998, 22.715904789586222, 23.969304061705067, 44.216372966766365, 97.38953313519879, 39.235029528217936, 24.93236361011382, 30.557793571103005, 27.573266029357914, 29.904681674895752, 40.72172549463088, 38.31026015743133, 48.19831217488935, 44.485847642344815, 48.90302873426869, 49.640583376730646, 52.065533822582616, 43.53511218101748, 36.35581370322935, 32.20509098422143, 30.017381175871822, 21.13185363431131, 17.18278584941741, 5.840229247846912, 2.9524766293264206, 0.4333429969847203, 0.06813143199730305, 0.1295077917917121, 0.027239818967157797, 0.03522224063354154, 0.040325443410585006, 0.01860374044026098, 0.04154058143256172, 0.03726000769905025, 0.08821952907789139, 0.05908473800387114, 0.05660334474317009, 0.01944618243273468, 0.03744425567527933, 0.029259881740736387, 0.0835317527995475, 0.06357418944037731, 0.041220008110206936, 0.07939202050047536, 0.08375247805229119, 0.03630471520967061, 0.006403526903370456, 0.12306044178624308, 0.006795014590851122, 0.041072769841599854, 0.03663234420180802, 0.06989973912676496, 0.07351230334250197, 0.04674462819351785, 0.044498695886784026, 0.03996441681538859, 0.008230882174816103, 0.07639021988237098, 0.05477059046707807, 0.11392779272770691, 0.08571478928769789, 0.08877482790980609, 0.11110355596869223, 0.055880107946934245, 0.02691430246247159, 0.10345629010830196, 0.019848204307979154, 0.02747065083484256, 0.0072186583401485085, 0.05632960620606619, 0.03296300137956296, 0.007246776639799318, 0.026583260548631513, 0.05519099653728547, 0.03244668876211489, 0.0357394648956195, 0.0729072547607845, 0.0511642775288032, 0.08173178325617507, 0.0899685231307822, 0.029061034043890335, 0.05917483377420615, 0.04075767787834329, 0.006669089367102471, 0.013318623382327779, 0.061469443307648745, 0.020784103281555638, 0.08348873696259915, 0.023811812993259202, 0.018329551826501568, 0.043616311985158154, 0.0724123772834578, 0.02975326151617112, 0.029694964140353185, 0.019689729444742687, 0.047717464096363515, 0.050394439604133374, 0.053070212353862105, 0.023651844258570386, 0.04693034705856154, 0.04604529334051956, 0.041678358515303944, 0.07593409879313362, 0.10923414821586303, 0.054961334868905046, 0.05953475337235197, 0.09361824261084681, 0.014138252234026311, 0.03321924629891592, 0.03814179405209519, 0.03773018267125853, 0.055326149768887035, 0.04527013876565522, 0.04139562227552937, 0.04742900517979457, 0.04116877598027068, 0.07139980823041932, 0.007506024145010499, 0.013209005776462297, 0.018924244814702583, 0.028148441380190275, 0.004829074971513042, 0.01799867845200483, 0.0203204496328028, 0.09870050820491968, 0.04512769237701451, 0.08891437848609302, 0.07233523989036199, 0.029720471037792105, 0.0752216600061905, 0.047942766724454786, 0.04487785578314816, 0.05305457266888792, 0.01640837376696929, 0.054298312583517645, 0.004581498815828274, 0.03706947014096283, 0.0758819435272486, 0.036099173819586154, 0.09779919044024522, 0.07448924164618216, 0.010571921424519633, 0.06394511389155542, 0.02541677677072585, 0.060986738967438864, 0.08243627771134339, 1.3103889818153074, 3.8055394349559664, 10.149648612545384, 17.25307080053514, 28.356292709227535, 38.90127505025556, 46.62605362553751, 54.444969084955034, 48.760678075974994, 54.23447116728752, 45.881430872025035, 41.701984636245236, 28.042801195575347, 36.82037922643846, 47.42101215547132, 77.37530985186177, 46.361881994432025, 20.135538270396573, 33.179654844345585, 25.181443921981323, 30.090298037375177, 28.626995086669925, 41.33151677346999, 40.10995734122492, 35.567640873693655, 25.475535392761234, 33.73984382998559, 32.090810768065914, 31.72661673638129, 34.03380194017964, 35.79157683157152, 28.76659812465791, 30.521346907461847, 53.9254903793335, 81.3751389903407, 28.459988409473052, 17.395747015553138, 16.921559918311335, 17.213962808732067, 18.33482127035818, 26.190414813257036, 30.851024081630094, 45.442968722312685, 40.987858310822524, 46.64055855043473, 50.1454512534603, 53.67950677871705, 50.64111332739554, 47.94737069837509, 42.42783492611301, 40.67650056654408, 32.251137648859334, 29.240589103391095, 13.395794322413783, 7.466602777281116, 1.9679658835934055, 0.07703466070515495, 0.05759015792019426, 0.048911534700422525, 0.06308514189215438, 0.06646262436744667, 0.07666634861379862, 0.08307753160836236, 0.03457662386579379, 0.0824218369539707, 0.06058798637241126, 0.048559252998881766, 0.07049181017904513, 0.05088434517083149, 0.05478921406451733, 0.053545612045713974, 0.021298412579081712, 0.11789253522311488, 0.01588326741776039, 0.08348915065007825, 0.07183178222828335, 0.04542266687137946, 0.10319568997909946, 0.08015970188763835, 0.07709718114065547, 0.048539028277680765, 0.05537277771039836, 0.017029291860038237, 0.08859390092472877, 0.026100899032767744, 0.031571029197244395, 0.010227186646642945, 0.030174858853100773, 0.027330008583263527, 0.013752192758294124, 0.02734397628134297, 0.054301817435771234, 0.052258795007101955, 0.05997773605368792, 0.09248899070606117, 0.015582291582118601, 0.025896127561047196, 0.03972427889464363, 0.04095697948228448, 0.03418410722646983, 0.035963695000616774, 0.04451570303870305, 0.02703106383823099, 0.06645628882031288, 0.18348280761030414, 0.022976047457045606, 0.04687227376346146, 0.03583554381264314, 0.004779851428353258, 0.04203956897160219, 0.016466131050800605, 0.16832185098000113, 0.18077323123091654, 0.11809127375243172, 0.17596360866821584, 0.17690618792849203, 0.19684759449333916, 0.19037458054240675, 0.11482639088025016, 0.10216776852405841, 0.11518014730104517, 0.2279556825036003, 0.11589120712972457, 0.11412532083810338, 0.15280932127948732, 0.11475227953445528, 0.17856499811093654, 0.11345320125861515, 0.20663026149474806, 0.0962954211319166, 0.11192359180460054, 0.13002280205968889, 0.17080921589607195, 0.08792581096772226, 0.1279562262577876, 0.1977672370811624, 0.1984344077326598, 0.2001626254810441, 0.17226256129722442, 0.14545735933126944, 0.2467867978397877, 0.19545158311243982, 0.1718075510354773, 0.07133953243253693, 0.15928356097109858, 0.13314978910549996, 0.1350202234161477, 0.15549914791218697, 0.15523084859934547, 0.11088569588478535, 0.25774617589289145, 0.13642335941474285, 0.14128933540515362, 0.11155722557657188, 0.16138075730733334, 0.3341005658430438, 0.1541112723850435, 0.15201809034953195, 0.10963664315040074, 0.168652034875366, 0.20882144149753357, 0.14048973879506513, 0.18863928414160208, 0.12015963453919658, 0.1827151875101751, 0.15461462279481275, 0.17177218841689249, 0.12676171898361177, 0.11677780834537362, 0.20502671689516117, 0.16125951623243673, 0.19485262492972036, 0.11271954949704871, 0.16772215735287438, 0.14468684341878663, 0.1621208748509807, 0.7038896134303463, 2.3850744049395285, 7.281143309608583, 13.759715749371438, 25.760832909614813, 38.36231785435831, 47.9973416943704, 62.43235034327354, 61.29241935668453, 66.45370544925814, 62.271960704557365, 58.01811102897891, 47.35741092312721, 52.26252701974685, 74.33302540932932, 85.68631018361738, 55.410911575440444, 38.2545821128353, 39.43018705614152, 33.19624254780431, 37.56966175571565, 35.008750192580685, 48.25864607287992, 57.7884287987986, 38.71346019929455, 32.08353281021118, 36.481882602937766, 36.98828412640479, 37.552379792736424, 42.145494876369355, 35.308187853905466, 29.914354239740682, 32.815519648213545, 53.15066537549419, 106.5510759046001, 47.55479635730867, 31.222651004791263, 38.889860953054125, 35.270160475084865, 40.04592464816186, 50.08156761046379, 47.46037706252068, 60.42173162583382, 58.95737747992239, 65.7288828203755, 63.501156991527935, 70.0526762008667, 62.16994770111577, 55.152403846863784, 48.01051301340903, 42.39245514715872, 30.533200310122584, 26.258311040939827, 11.647574324761669, 5.843990800842162, 1.2135033742074044, 0.13409515692582055, 0.2589643169795313, 0.14947555178115446, 0.12846194387924287, 0.23243741943470894, 0.18883429948360692, 0.1639955379669705, 0.1305761167238797, 0.20922454164153148, 0.1509009656165877, 0.17123627927034132, 0.15427189037924813, 0.13616998349466633, 0.1718581894472722, 0.18546610199395688, 0.12970027904356682, 0.2305974294581721, 0.1530073703296723, 0.23893174595169483, 0.1257259757708638, 0.12367141222761524, 0.3368178184234327, 0.2758221430403571, 0.12501007426650296, 0.13456703644366036, 0.2115502620055791, 0.1573688774219444, 0.18379348690711683, 0.12296253574952004, 0.14459972390003745, 0.10203407852039223, 0.20479473014993055, 0.1167801142700257, 0.2170515240680787, 0.27457210205255017, 0.14908562834945419, 0.16403431733769758, 0.26566387845143197, 0.2823533183865009, 0.24074400354537273, 0.11506311204885283, 0.12030581943690778, 0.09477437654089543, 0.12029129440986341, 0.098006509154314, 0.13314306285352479, 0.11179264439570327, 0.21227533358239362, 0.31070077791810036, 0.14872670083517028, 0.24086005054414275, 0.17088141202205614, 0.1988683812200062, 0.20143897392817084, 0.15514015911086915], [0.020484957438442978, 0.030285483864586682, 0.01335592324575109, 0.027134794058398377, 0.013847054553128058, 0.08145619844717365, 0.050179272319280335, 0.08273105302284803, 0.011172439553774895, 0.1425325275669175, 0.007253881147687114, 0.029615848325192932, 0.06339605867622361, 0.09845338356230529, 0.037419560831040144, 0.01899293034277376, 0.036239471331599264, 0.035609272083327655, 0.09076579083358088, 0.012602654845273543, 0.03783590280480924, 0.012844010845818108, 0.08361129570872554, 0.020314753769085776, 0.1260395891844265, 0.06059676957046313, 0.07249186656648114, 0.07141003550420846, 0.0951207172305834, 0.02219411108883158, 0.08091019226178046, 0.01734546592248784, 0.081820220446154, 0.04682968693575071, 0.0737911287034231, 0.00910762192365984, 0.06962836014046785, 0.02145811318299703, 0.03482028196055082, 0.03285162751713107, 0.03923322036561947, 0.07646124389383101, 0.0020131505058792933, 0.04776587702273842, 0.017153675810644226, 0.057565007253640124, 0.07677159377283628, 0.04149296140718845, 0.059921574147958914, 0.07367063839469226, 0.0466363761393774, 0.04268231290963389, 0.07305700962822284, 0.024474030886326107, 0.024028014496810014, 0.027543547931277466, 0.041528484904237335, 0.05172873111141305, 0.025800456585843238, 0.06933969821059896, 0.03406995629531241, 0.09970414467276105, 0.09172393700047847, 0.05631302040250552, 0.015159859209351484, 0.01727352452073847, 0.0314494184849243, 0.06886325280873046, 0.16390023662919, 0.12428870289436272, 1.213578266962882, 1.6978849566751912, 1.9151702907777604, 13.544866942590284, 23.41163912127095, 30.294680979944047, 50.42220977044875, 60.156030270361136, 58.45894229027533, 52.46512528388731, 53.579909955301595, 45.579961422950994, 32.75282840574942, 38.151223736424605, 34.90786683174872, 37.930511966828384, 35.018803227332334, 36.464953653274044, 34.581443263638405, 39.51271372456705, 42.57322149892008, 36.78896888609856, 41.41811878450456, 44.653642715946326, 42.764433122450306, 31.93607718713822, 41.461947348810014, 37.47133185786586, 36.537795989744126, 89.92212480114353, 52.183522639736054, 42.42390863357052, 51.77735728602256, 47.296167035256666, 52.87045909512428, 56.82041921923238, 48.4761336541945, 49.1994579376713, 41.9742638064969, 34.07916415122248, 24.709427856629897, 17.843230616661813, 11.374743080908253, 7.070566454241353, 4.604157045964272, 1.7590578741604284, 1.467431245311614, 0.2419109699586707, 0.015457375200405238, 0.0378556372297387, 0.06890354137266837, 0.012105929180829516, 0.0766665401357797, 0.024723926852006587, 0.06371590038461071, 0.0973188073464459, 0.01702596895366667, 0.002556528530887238, 0.03544356726530579, 0.044679408367242546, 0.0666435896569202, 0.018955338408329317, 0.08018287604734783, 0.0109905147391762, 0.048878493328248306, 0.018501890965947704, 0.05531830885898202, 0.023737864441148216, 0.0033679449200374827, 0.013036562257536478, 0.05041489032127204, 0.04529912370227037, 0.05515355015954664, 0.04824617201642645, 0.028908448481571772, 0.025566500994647225, 0.029230462049224207, 0.08321911231764863, 0.021878551811941212, 0.04134717487519787, 0.022907980544973287, 0.13941061202316515, 0.030256592773742257, 0.02226971439085901, 0.046048794362333514, 0.03340432548054284, 0.08371001379864831, 0.06151390705077399, 0.05093926984456278, 0.01690513582058972, 0.01533934307630144, 0.05964075695843466, 0.04909763277898874, 0.0432584110286928, 0.039582008706225504, 0.029993989324617772, 0.10388363693510333, 0.029141076825438973, 0.03154138542501436, 0.024047053696948196, 0.02936124857965737, 0.0389886774393099, 0.056649773501821106, 0.008213386641845347, 0.05373179056351224, 0.05542834972842567, 0.034117323511670676, 0.032864118580736464, 0.03227527658905714, 0.012153022520754848, 0.03797921104236476, 0.050591105865615035, 0.018098022818805713, 0.019553576468399936, 0.03304971870215189, 0.006329949903902748, 0.06358668433442231, 0.047757764151620294, 0.07649347321280549, 0.03609248970244681, 0.01298650224212437, 0.03279737317033353, 0.041526811002122785, 0.07522519167152143, 0.0880206220092312, 0.019486976614702615, 0.036700219591899265, 0.03816743118448123, 0.037552737555797064, 0.05195515605831339, 0.05228730496920405, 0.013148827654790255, 0.10126494922705236, 0.08836024410782323, 0.03344665566879896, 0.10433012063825324, 0.06961092397931122, 0.08397963078271958, 0.09522269885506361, 0.040319590498843504, 0.03180726390001515, 0.04985373857761583, 0.09164595691066596, 0.0558884046791542, 0.04472781746317783, 0.023573155537427917, 0.05522519087178573, 0.00553201474700003, 0.004944366894872679, 0.029144740640936844, 0.03438312537787903, 0.043900342913524765, 0.06062369373056197, 0.023195924267413157, 0.02499597999567707, 0.12342149136407722, 0.05337374021990165, 0.04181315551602072, 0.011224554600043884, 0.04925515577797929, 0.053012518272284544, 0.07163285983786469, 0.01243892078843689, 0.018535859304510297, 0.055003282013199026, 0.055786074484668435, 0.029850106521119035, 0.05365758345672681, 0.07204234149427184, 0.07881250562927417, 0.043781361798004764, 0.046930404515155864, 0.08751993758543845, 0.042011288835877375, 0.34631936180014766, 0.9996200220719461, 4.458340973623337, 5.890108068143168, 8.509242803819719, 22.960552823159006, 35.61524668047505, 45.23646769985076, 58.14543508714246, 61.59308471987325, 55.42005462031211, 55.58784969391362, 66.56937614563974, 46.428938834897934, 27.76615446613681, 32.14668296998547, 25.515733803472212, 31.971358906838205, 26.735271253893455, 32.32165009744706, 40.38338576593707, 31.15402129388625, 33.50281107810236, 28.31209740331096, 29.65226342601161, 30.56827806657361, 33.31825963912472, 24.76327415435545, 25.090758723597375, 24.59482208375008, 37.51465051404892, 103.57879008016279, 42.746727543492476, 30.858158872973537, 42.06219550101988, 41.11038138789516, 48.0128703578826, 59.71080203210155, 52.261997499773585, 53.19835355204921, 50.37921274861982, 47.32311764071065, 37.46787624974405, 31.28125709872092, 21.081117776132402, 13.927342161055535, 9.033616627416304, 5.60339016299094, 4.3462283572843, 0.9688232262288371, 0.2567722329929952, 0.06148938840675739, 0.07652822296105086, 0.07225642476471202, 0.02716815335706117, 0.041821398622085976, 0.047748869870819395, 0.03825532828247355, 0.025529110158282905, 0.057320632866673896, 0.03149360835161661, 0.05760114362102844, 0.01818206457931909, 0.014613499665903229, 0.03964513435118622, 0.022154238127592592, 0.05387499537919799, 0.02786419403198506, 0.06933293365422757, 0.06279947153562981, 0.026628419516548037, 0.057515514143291986, 0.019908815269328414, 0.023337755870494633, 0.05533180349776822, 0.06402108300056669, 0.02340879137327354, 0.01609120379021812, 0.03415511079853581, 0.0419498868887463, 0.029195932551257076, 0.022381093998950337, 0.021800225067342964, 0.06236021204160587, 0.0516937323845923, 0.05952058457619241, 0.032275039101800615, 0.03539442655540282, 0.034334766077658826, 0.03045706457698778, 0.05085515339047678, 0.009523600005664894, 0.0660810053288456, 0.04425687640304527, 0.07484585557493471, 0.03986682870515412, 0.05712487441938251, 0.033715640630332694, 0.05167925715326302, 0.05615561231670361, 0.0458464092544971, 0.056941507444266355, 0.038044703899011496, 0.03133891796272609, 0.03655418791177292, 0.05973902305648212, 0.04774919928862684, 0.025242484107072798, 0.14435414675503008, 0.18134497797056554, 0.16204754491486859, 0.1648715748301437, 0.14403531628270305, 0.14674460154867944, 0.10882774623291147, 0.2226294715317988, 0.1465037894705611, 0.2253442573090715, 0.14748363124747432, 0.16442424076939785, 0.19907560800352406, 0.13670656679859086, 0.12189284718084721, 0.1198927907934112, 0.1904595856584849, 0.15110928024495804, 0.19191668489046637, 0.09990587860586182, 0.19887469378450226, 0.11129627304692423, 0.25337967390735305, 0.2215937053364131, 0.2276915047437914, 0.17982053961003983, 0.18241265938887674, 0.19844937709070024, 0.17415832247464888, 0.1140137707754489, 0.29391263521486716, 0.2630352775656408, 0.17672627984035402, 0.16805192756076015, 0.1348957494502106, 0.1067096816616193, 0.2077204965415501, 0.1673537303483294, 0.1950534012529158, 0.14246158782512913, 0.10957093578913521, 0.290141613372872, 0.17008573778213995, 0.11536564783103044, 0.1032470791570602, 0.2153383982518027, 0.13216129053504239, 0.13499791493579266, 0.16342009868352644, 0.2269119336720436, 0.26278495067550295, 0.12166784715748603, 0.10531292717543342, 0.1074592527302523, 0.15262956640893413, 0.2387870779080737, 0.15231536310766974, 0.07624297012244502, 0.15840703381165383, 0.19740250262041248, 0.10936716406215584, 0.14317887594863293, 0.190984386530134, 0.20692183455872923, 0.14933186433007642, 0.1390213167835628, 0.17235423137824382, 0.17785034532989227, 0.21457155956135643, 0.5415881869773711, 2.710549004616276, 3.904447392109902, 6.249669290358021, 20.36522638413214, 34.163283301937966, 47.565751537199944, 66.6467409749185, 77.06157515125891, 72.67373731059413, 68.55269124430995, 67.78438521969703, 60.72147523203204, 45.09967504009124, 52.543290276681226, 47.19414226470455, 51.6850168474259, 46.63946420915666, 50.65255880355836, 50.00831734749579, 52.1130572595904, 55.72578768576346, 47.43901975693242, 53.75459663329586, 55.84321168161208, 55.86311378786641, 43.5882838310734, 52.69439174282936, 48.58250833326771, 45.801865593079604, 98.89391114634853, 63.188202842589355, 55.942212304761334, 63.771843679489635, 61.30142119623, 67.57063957952684, 71.81481669026037, 65.94763340488558, 64.87691656235727, 57.92538227573518, 48.1603200974003, 36.051445622597974, 26.643209303579024, 16.717679039124523, 10.299268403360921, 6.470827719857616, 3.172417162887512, 2.7453575884142234, 0.5013591021059022, 0.22813640264493806, 0.12182924656137345, 0.17635478848411193, 0.15241536822530533, 0.16712500713765624, 0.11037327499399263, 0.16013319844440108, 0.15387471975578418, 0.11693576035360176, 0.10131338130562537, 0.0742643182316134, 0.12644471946142374, 0.16349707519815815, 0.10068303650064815, 0.12906683158249627, 0.1275723089554137, 0.1636665491687675, 0.1178858625972944, 0.22618827169700978, 0.18327657674108783, 0.1031801077507196, 0.11079039454700486, 0.10614541960099053, 0.17749524825522978, 0.22339575863893957, 0.24231610789654717, 0.09486931781735151, 0.12832606286411324, 0.12130020922350308, 0.14809955061683733, 0.10132374647524088, 0.135940877240031, 0.11074760087555456, 0.1775479244609033, 0.075902022691744, 0.2103289339931742, 0.12790244688550312, 0.14324953989876857, 0.220591371218043, 0.1824635889140829, 0.13441827749052357, 0.1113102618124216, 0.13598204680508183, 0.09930235453911367, 0.2256962440667614, 0.16519785167709475, 0.16436463912888882, 0.14138532622206595, 0.22514610100657712, 0.15535193645665724, 0.16012523112998855, 0.16802997148085028, 0.11936691739866812, 0.13174928844936434, 0.1738369639121717, 0.09354036211246446, 0.16594811222485958, 0.0951931661655826], [0.09713991049436793, 0.045175350706783995, 0.026436539389373317, 0.04882797366008163, 0.061928467870119124, 0.09124721580695722, 0.08300237838299045, 0.024961710967604193, 0.034274268114278396, 0.019708291755148002, 0.012097447629897826, 0.03648155128523227, 0.04055232034936067, 0.07151198648517171, 0.0768907051233034, 0.060367337728459994, 0.015757195200891267, 0.008806108868861151, 0.05585704486997378, 0.04635683448624708, 0.019776638289312684, 0.018508517626492728, 0.0765687336904868, 0.006935754518640498, 0.042526394864844705, 0.021302767788931247, 0.060427341565129265, 0.05132209930208422, 0.0166421493275031, 0.009681311653806798, 0.037498950522633336, 0.05394598491670144, 0.03408136334450495, 0.11945638880734483, 0.09033034645741986, 0.004595972131937742, 0.008874873878554472, 0.04125711740925908, 0.02425989782017085, 0.052855941391880476, 0.023274695343007485, 0.01849070799747302, 0.02527827190445556, 0.05973151922526379, 0.05695094564749349, 0.045595350750391526, 0.027525029670927795, 0.06080371673188864, 0.04630548744312218, 0.008273927697671518, 0.03109386558794687, 0.024718286529664072, 0.0863841126462625, 0.07185672605109793, 0.036252533130708246, 0.05753977231741433, 0.05736370616021657, 0.023178526410652746, 0.023935480651655988, 0.04273422685782275, 0.07708000544939311, 0.035094039649852825, 0.028166852388230544, 0.028135766455483054, 0.04997412546447689, 0.05191669461407489, 0.004323653730323478, 0.05812204510514295, 0.026292099256909666, 0.024532368481760065, 0.013888458732605703, 0.07624642517898353, 0.04078255275324468, 0.06921809707437793, 0.8897266092319643, 1.3318992598402886, 7.651170396035718, 15.067785016952024, 28.431937579185735, 39.587332894725186, 46.50735485938288, 54.10452696584887, 56.2686005715401, 59.14582383248114, 53.98705982392835, 59.356443343623994, 55.015058132909964, 53.37590748263944, 52.61882335908952, 61.400665006329945, 62.29327486407373, 58.36115760187949, 55.275687863749845, 58.776187512182425, 53.703543063133, 60.423218204129135, 59.88323334724673, 57.104783211984945, 55.64507315235754, 53.19555690211635, 57.211087288395056, 54.19082303200999, 48.78266296079082, 43.441618565590154, 41.10993816006569, 23.738749104161418, 17.21742626159422, 12.018760961870994, 5.897840040345346, 2.7492434315143095, 0.7642471682160132, 0.2653216210103804, 0.09667416734080161, 0.03168165995438974, 0.027069814480660905, 0.07685161165652737, 0.09308207299440138, 0.027245798283406807, 0.06634162077980657, 0.047651982731035644, 0.03881745295779359, 0.031508388102895794, 0.0336315241762467, 0.009255602339943571, 0.043994820706786654, 0.055985104127396504, 0.028147926186061198, 0.012554348213598134, 0.03617847541106805, 0.025857961060659542, 0.07438759710038863, 0.018008988080245834, 0.05509336246177555, 0.023530840670930284, 0.046627857241659396, 0.02980442469819419, 0.02384191067258437, 0.054613370072817614, 0.03804083515499388, 0.0783967420518879, 0.032904985541057204, 0.021232789487487847, 0.02105109832970606, 0.050228267472477696, 0.025657560120547013, 0.01767348178902701, 0.020342938143820054, 0.04374595704458414, 0.0728396398405875, 0.03477230570429275, 0.031219490600990194, 0.03261010297724316, 0.019447371784237125, 0.03548714234643886, 0.025859663691071254, 0.0227876415386075, 0.06355511385106272, 0.020603402292415984, 0.016033940633097966, 0.0562527216219854, 0.0670666080869494, 0.08130524848257342, 0.01602372197779797, 0.08409469718894652, 0.09622943031811908, 0.01943605283515588, 0.010595724733936931, 0.01933390075611251, 0.012277710033700833, 0.01912141477899446, 0.032185100379490086, 0.0324009073477599, 0.08222250087607293, 0.04818707982438707, 0.021570791310120015, 0.022056083112294157, 0.046110567862107876, 0.026155934789248055, 0.04232673703001873, 0.03589490030501639, 0.0384880006763964, 0.03688933988732677, 0.04638687279375811, 0.030955038964748386, 0.0033825044210384334, 0.06630494048999203, 0.04477354142093851, 0.025743930788350203, 0.03665937178377663, 0.010752656887615881, 0.022560536688674363, 0.0845200751697825, 0.05771268985324329, 0.03698920710913597, 0.07610325866769399, 0.00897636903720277, 0.07753308516957107, 0.023089150762966564, 0.12421529634945816, 0.008618855912749086, 0.024564021319571524, 0.02054002575366007, 0.09038267026264822, 0.0701039168803442, 0.031136077032574726, 0.013991685249962875, 0.04257863823084101, 0.036848771701296495, 0.04641321089659487, 0.050777096691871845, 0.027949679868235707, 0.022975233488626057, 0.063890200709143, 0.09434476209383819, 0.022961162368676836, 0.019916349744063713, 0.060924440697436376, 0.02278043456645983, 0.04486436114436196, 0.03184776888379166, 0.10575694407546714, 0.02861757255760172, 0.036421451687572465, 0.0770783736821144, 0.01683034648698184, 0.03724578910717561, 0.037270089416133786, 0.03538458615601544, 0.08151366270237392, 0.015072619989364138, 0.051501428993839415, 0.03319216126035298, 0.022162751279651158, 0.009518390607779786, 0.02480325717178564, 0.022345486232229782, 0.029377330680407827, 0.02124587618445437, 0.04546294777443813, 0.010917666480846463, 0.03243580648315049, 0.08909591834150976, 0.06530404661691959, 0.09804197902520818, 0.024913338260845314, 0.06113276298668596, 0.007556581638768436, 0.04410075534495615, 0.02758016118839864, 0.5108973257724316, 2.463727732819896, 4.153382085984753, 15.510410762602284, 27.32219315344288, 44.369039458613244, 51.68734673530825, 56.51874580690938, 61.08830705765755, 58.342745996290645, 62.60231056521016, 53.5587134668904, 60.61624980741932, 54.494434095198116, 54.6632097613427, 52.09854448995283, 57.411014418448175, 63.81839829106485, 57.69928901426254, 56.497341432879054, 59.595335298968905, 58.74956638582292, 58.63317789569978, 58.26854651974094, 55.604347182858376, 53.31173750662035, 64.07434078954881, 58.84038886716289, 57.791715745002996, 60.645624437639796, 53.568052630270685, 52.81779735319076, 37.17679715925647, 28.793258474719142, 21.82163380807446, 13.776545659188303, 8.014910413372903, 2.78943375233681, 1.1117491246231141, 0.6893741471632835, 0.061867916280583996, 0.09189796153335802, 0.0642033506395115, 0.029214856838206613, 0.015119732481487578, 0.05799945188505996, 0.03389021291607811, 0.06609300992661907, 0.033737673319035, 0.02457616189795156, 0.06138395172573867, 0.017418401323318962, 0.0746558351261962, 0.027772303700687426, 0.0541119578654968, 0.03670371678327361, 0.007761569051522642, 0.04321140770409857, 0.07121820708796864, 0.03644785107744317, 0.033120160486789486, 0.025221836122293628, 0.07819982681183085, 0.06820083956324285, 0.05614353877101695, 0.08161064943358784, 0.010149887417473141, 0.09846146578990644, 0.05898136592980835, 0.028894907877510114, 0.055432475111897916, 0.033878599023146015, 0.03226338690447231, 0.02490988894996624, 0.015626764901342894, 0.029438728797099287, 0.011335841319974393, 0.02372399633449893, 0.01185145775502127, 0.048455589811407754, 0.026746718813815427, 0.029803390479496414, 0.03062695989595546, 0.02703022114151428, 0.03482291730301034, 0.08498211811867454, 0.07669599621646828, 0.07803691055385337, 0.033180244762690804, 0.11391811703722324, 0.06907895252469086, 0.07165611826724584, 0.06807442739485733, 0.03351815082433243, 0.04590289674759392, 0.021122844379034736, 0.00033431855568309286, 0.05326608954478176, 0.003201823062901836, 0.05874320451590804, 0.03493153707935445, 0.06816880942712869, 0.06281577771709812, 0.21723927689656136, 0.14232174613543097, 0.12086579906603984, 0.1985853730190185, 0.13544779240844712, 0.18838406961050727, 0.13681208774928125, 0.11291762152987142, 0.11554113559184537, 0.18990481542723794, 0.14756981613895587, 0.13425508544089335, 0.16919830153065343, 0.1415323384947354, 0.12043424641653416, 0.11138652586528372, 0.1324985530828276, 0.1638194143531784, 0.19259908536989845, 0.14477175660431385, 0.11761591619541568, 0.09831610060627423, 0.13798905927087032, 0.13548073418919118, 0.15014411671267403, 0.13546843081712723, 0.18101533033674766, 0.13380249601698693, 0.13285581052543657, 0.07499459154543377, 0.13268166341848914, 0.10531170143475456, 0.15938241695684774, 0.15564271278919714, 0.24385605187666035, 0.11857885807271927, 0.0655168658422847, 0.22904386443476524, 0.1404890033506578, 0.17171998718573203, 0.17539187725032532, 0.08082072851398299, 0.11864196073504225, 0.31612244344526724, 0.28613417679744385, 0.15643284055254153, 0.15857695211325923, 0.13393947253784827, 0.11376818596956231, 0.11011110438454537, 0.11317326507020382, 0.06404033862054348, 0.21420870967690023, 0.17526493648127203, 0.1383009489866034, 0.10032233932325918, 0.13966532093622994, 0.1088738187606777, 0.0861390641019229, 0.16766827072828047, 0.19800239543039955, 0.2799587726833359, 0.11595023420429039, 0.20291913240667314, 0.08101065703217061, 0.21376229492166351, 0.12190862859208738, 0.1978114097108764, 0.19377668508358542, 0.18394327241807215, 0.07793598613070865, 0.15898331579181457, 0.14666005608535584, 0.35150442873277976, 1.4554097936038048, 3.103250332417027, 12.258842375970657, 22.946412678687807, 41.380471875590665, 56.19371860258041, 64.10156203854469, 72.45918366216844, 73.32914183216711, 79.01687668215844, 70.8036296598373, 77.62350959162559, 70.98069329415598, 73.30468977651289, 70.21793350096672, 77.53399325955299, 80.49483360782747, 75.85146119517665, 72.80233613906368, 79.032071944206, 73.14190356962143, 79.09635959133026, 76.39938492928782, 75.3651108280305, 73.17078005883002, 69.98030847118747, 73.11017943966773, 72.34552121931507, 70.00659619608234, 60.43447932889385, 52.765716122042754, 35.45009920673986, 24.719537765749042, 16.861131883436634, 9.884890587099138, 5.1753840715654436, 1.4281310573700936, 0.4239803606704359, 0.3591280454589475, 0.09407785706101887, 0.15557313668391398, 0.20491687520857782, 0.2197028930869795, 0.1554691938743476, 0.20062944881858366, 0.09477713445742285, 0.16612075779947544, 0.11962749454523287, 0.2542865381485993, 0.11456311710419194, 0.1627644959596857, 0.14026988688255512, 0.14369491277442825, 0.142761955578481, 0.14530185880439897, 0.10693714082721742, 0.1561521152935682, 0.18883593891176487, 0.09217472611776284, 0.18170689322775413, 0.10968871414661409, 0.24046143967538114, 0.13916710331555338, 0.1760222910032157, 0.1252858812410024, 0.14904303386086418, 0.1494660216473764, 0.1910347491502762, 0.10143983177840711, 0.1934934776997374, 0.1458720886899579, 0.13675032574082577, 0.12272240548965432, 0.12953953847529429, 0.22090762763494448, 0.14564906517344137, 0.09670275774213577, 0.14953267129678882, 0.11510491746688083, 0.0647112401202321, 0.15260653780593028, 0.1318369442296605, 0.13971186843850922, 0.13763682736504462, 0.12177432571808178, 0.15593433181845373, 0.19690863637914582, 0.1786651411243985, 0.14744993870056447, 0.17238104445559366, 0.20037956625944187, 0.14280044383579685, 0.0908000119811585, 0.10250955865147615, 0.06351893534883857, 0.15873205427440906, 0.13958157220434758, 0.12709102953874296, 0.3068645466719904, 0.1465080489194201, 0.1550527791222257, 0.18190080540314799], [0.03811227285393304, 0.0071631643673284884, 0.05542897409008396, 0.004590609516467779, 0.015912985883563036, 0.06596432247709844, 0.03666079670731579, 0.06480206750453481, 0.008484499412588775, 0.046121913624266465, 0.016878849428687847, 0.06366475635478575, 0.09191686858332927, 0.01353104424197227, 0.018604027723232587, 0.05340937863013918, 0.04231403529223415, 0.03026540086965167, 0.05575158903675695, 0.04505474931530414, 0.005841833631312776, 0.04835243607240339, 0.0440685298564213, 0.025177138722351482, 0.06694735117977665, 0.10594491140856858, 0.10165399931851896, 0.02246373190334247, 0.03955336084829704, 0.02731677441437158, 0.014360589144240706, 0.06652709832715412, 0.09581740524980331, 0.06697830879279683, 0.06310813602120166, 0.05353012940876427, 0.009796211435910194, 0.04200660037778078, 0.032457988558998035, 0.052351280971760714, 0.04914886490892499, 0.05183438229705057, 0.06539697308213481, 0.054819447724449064, 0.0357328956916688, 0.11739741259765242, 0.04393099409137522, 0.022273964263618957, 0.01611081181064008, 0.08178575415044062, 0.01508212905572427, 0.031639253157341195, 0.059934440594647205, 0.024984770214125037, 0.009259620471106423, 0.03357882498793545, 0.017709102962286245, 0.05173547268514672, 0.038660868416510286, 0.08835370937782912, 0.036322346723247925, 0.06502411042850825, 0.03065599845872531, 0.025416483742094813, 0.029653220009359143, 0.027341953809222868, 0.051477255089388746, 0.06306613525075298, 0.009141287657492345, 0.007924451314348487, 0.002144981549316717, 0.022098081967523022, 0.07269507138839654, 0.034620118507694815, 0.033889163375621846, 0.007095943503607546, 0.08757022359678823, 0.07340389424033704, 0.768311295297838, 1.8824417889118197, 2.8356743291501076, 4.883262120908307, 16.68169129279352, 23.947219156449844, 25.456096126187234, 24.62195704060216, 29.819605465858217, 36.84203463215982, 39.078409287237356, 41.63734789817564, 43.350552897299494, 32.578328040338334, 34.669496551636726, 32.03886289750376, 24.95593313247927, 27.25705631317631, 34.12740145960162, 35.10325970188264, 30.886311684885335, 40.81628991711525, 28.372264600569203, 18.16348429649107, 11.40237323699459, 5.179224071964141, 1.777541553301196, 0.3899958423308788, 0.23192979425432222, 0.028517538711668986, 0.0383987476027781, 0.05578985895901438, 0.07547185666138127, 0.025382048089898405, 0.022005057826097456, 0.040557981739121104, 0.04116142919707683, 0.06370365446914109, 0.017833923583009073, 0.11808104647864258, 0.05257157338482719, 0.05775151901968545, 0.014965500787741717, 0.026222293325249228, 0.05907063815562476, 0.0228810295717971, 0.034210617699089556, 0.01223632404881139, 0.022603862791232044, 0.07662978323717272, 0.01701236323213145, 0.083538931043398, 0.08547468967134915, 0.02735033864155412, 0.0352474142827334, 0.03959851024011451, 0.06718461627080556, 0.013606069147616867, 0.03557917248878268, 0.09655373065822548, 0.11192475625824545, 0.01126788836348081, 0.05962459633367197, 0.019315118195428964, 0.010241628361625538, 0.05586919119401325, 0.03088799478005498, 0.05427247243783167, 0.04381422696995639, 0.018083735279017882, 0.03262370103789914, 0.037751311376210184, 0.05368071931204008, 0.022642703448993065, 0.024075726452734203, 0.010759626372507023, 0.019616922363638878, 0.1100737959026329, 0.09265167713766137, 0.052123228088021285, 0.03610450962197877, 0.03944383708820228, 0.0585410300822508, 0.02206502718881013, 0.07216513006677551, 0.1053138388200633, 0.041386207054939964, 0.03395167615024313, 0.017539221049857237, 0.023383788178644838, 0.002238889564684923, 0.06845628392071494, 0.031996075845053124, 0.04251418725377129, 0.09874730851621398, 0.052287124938541846, 0.08427093571592724, 0.03989954448996052, 0.05816275884787883, 0.027392011909415166, 0.048411677651588, 0.047940001147048134, 0.0111601629947883, 0.030630384308976993, 0.05611291057580421, 0.08640783072839822, 0.04974648243777695, 0.0353333578565188, 0.04134815929818057, 0.07726757441677394, 0.08150777148623621, 0.05463333815456398, 0.021728835248899077, 0.10001573561420364, 0.042026346294029106, 0.09058399816914912, 0.025411739742623705, 0.02911605256339235, 0.01684455550275743, 0.052132160673218395, 0.07796749532703431, 0.03372294144825109, 0.03411586411417492, 0.0790446226094519, 0.015892700832937996, 0.010352728347624502, 0.06218583893872077, 0.07396532943652523, 0.0478098466391525, 0.06975020642482466, 0.0192199643295739, 0.04611082067112288, 0.03299087931912753, 0.035042776876399596, 0.05366371216012105, 0.04078990336687815, 0.05188658735865066, 0.03312994726002216, 0.02336196999456133, 0.03144698615576471, 0.019370182680206436, 0.07113380718135065, 0.03941444995542688, 0.028091183968729554, 0.05195183506716163, 0.03597851114107236, 0.01342833196113427, 0.02590133504371249, 0.031111470288446838, 0.029200986816337513, 0.007338756986428053, 0.051825419068336494, 0.016036267625167966, 0.0758919103311435, 0.03835174427818387, 0.10142466323750635, 0.06756757596327413, 0.06440528758591221, 0.03275171816048603, 0.05280195134541681, 0.02668857465558235, 0.02388397847572642, 0.02111903117639163, 0.07085082962387992, 0.01013452256654179, 0.04293278535647739, 0.053477077820007844, 0.05643705769832577, 0.019995241478506117, 0.04480980036239471, 0.044993569533671104, 0.040982302518621574, 0.042123049572711034, 0.0641604688679499, 0.10524653799591527, 0.28473012149333954, 2.127588944089028, 5.490368537364468, 10.105418005297262, 15.693044162565663, 30.85223609401334, 36.61587076802408, 40.545614996264064, 40.85494095279325, 44.78377911352342, 48.3363050799216, 53.61630955050069, 56.13936631910263, 58.45926392462946, 48.97299989577263, 49.1304438344894, 45.885537593595444, 38.79172717371295, 41.722608458611276, 47.64920780735631, 47.90359312488187, 45.03281824050411, 53.179235919829345, 44.058787822723396, 31.016546141716745, 21.0905824553582, 11.99538069386636, 5.815080481190836, 2.0437640937105304, 0.8201722608458611, 0.2598104457701406, 0.09296306889624366, 0.04240493545488965, 0.00685769398959594, 0.01676987725189857, 0.0070807639501928804, 0.041307353624893774, 0.06706966477776728, 0.095180495071315, 0.03665607760570223, 0.09441884279611612, 0.02809461604263033, 0.04874715904494928, 0.047711523084510724, 0.004088898056051544, 0.01764865096418127, 0.060583328557831634, 0.03802992606295213, 0.025030471189247987, 0.05130840931087733, 0.040936371717121334, 0.0414776856139783, 0.08814419965229689, 0.11258784366110641, 0.05610036588604412, 0.048291497608466495, 0.03021735758070023, 0.07821285030654362, 0.028781823723787264, 0.02421510082879855, 0.015217030435920724, 0.034419514554282354, 0.03294394494244649, 0.028215138910097942, 0.02233217928498503, 0.04870963605841802, 0.07143498698790228, 0.02637473333086218, 0.01968761504207167, 0.03873644682068018, 0.01610248826534277, 0.03360763755476764, 0.027108049928961743, 0.08727431447515566, 0.06844842385861181, 0.01830891341782145, 0.011271003468502915, 0.06054510460084966, 0.10205831754231647, 0.08260249580827453, 0.04576536481298747, 0.01180311186133974, 0.03354404076573349, 0.03545198274115401, 0.011646486142830504, 0.022128782941088564, 0.058272458808196176, 0.013721823117755836, 0.041839053118301016, 0.022805690570103548, 0.017556657211013862, 0.054030825323875875, 0.051210457308878826, 0.03477650386611781, 0.009060205869196404, 0.06117377933415194, 0.02016746187432399, 0.034003632233267835, 0.04131653135822665, 0.10089052375406028, 0.0649103999979073, 0.11193173531923564, 0.21839079897730582, 0.22739720440679984, 0.13874664361919128, 0.16206248362939205, 0.1335646563600148, 0.15229693103221156, 0.0950990982293602, 0.1666889498911558, 0.1871271491531403, 0.16409067076540765, 0.12498608805359372, 0.14006158757594325, 0.22211112112047213, 0.08798944223071299, 0.1219784498455063, 0.11935344957295926, 0.12138105448215239, 0.12028898082433209, 0.11221548662550988, 0.2146253848989164, 0.17453041137947192, 0.17512363922451774, 0.2731531539991979, 0.14447174125140713, 0.14170018835894524, 0.14226136308523918, 0.1810978073626757, 0.1418503722356212, 0.16593706523699148, 0.2520112570134863, 0.18345170444057834, 0.22109515063704985, 0.1164711203666464, 0.12747591977278072, 0.10308494430876548, 0.29551149135635746, 0.06258797381193408, 0.10323108324120123, 0.1614787399528488, 0.19329602619813335, 0.11562756563146269, 0.16822440459603266, 0.19794679276885527, 0.1957288609757539, 0.14043893184392683, 0.0829993446748103, 0.17838098379152437, 0.1645606503851952, 0.15291188513079, 0.25282049100966225, 0.2017956031786819, 0.11103016474554617, 0.18857746084611263, 0.09332353624725535, 0.20623836155620315, 0.09617628679881174, 0.16347672790288925, 0.08053795013937258, 0.17515440531555684, 0.10721809591256803, 0.14057203195989132, 0.13289851226633595, 0.21291023661052028, 0.133459058800532, 0.1419370321016158, 0.11894592144075902, 0.1833724449839323, 0.07352825329308549, 0.11055109166209737, 0.18890246598710939, 0.1192495986939438, 0.2208203855421274, 0.1288581032666468, 0.12752222212692424, 0.2438961489186172, 1.3273646321988877, 3.7222903149743236, 7.574766057152902, 13.002841472625734, 26.35018667867107, 33.30376255896784, 37.53470559273997, 38.14349274481497, 44.134932794878566, 48.871422275420166, 54.175243377685554, 56.56928554657967, 59.04873732597598, 48.18849840471822, 48.2621056033719, 45.46887597730083, 38.84917028488652, 40.20724388860887, 48.44061659228418, 47.21094177615258, 45.45766976571853, 55.55287391908708, 41.31446623033093, 27.59626876923346, 18.728303640119492, 9.080340881501476, 3.2120698738482694, 1.0087481129073328, 0.4052383873251177, 0.18926692465620656, 0.1036090710230412, 0.11660308667248297, 0.1722737615026774, 0.13596726130814324, 0.14938515340608938, 0.09782639422243643, 0.15565218163594124, 0.15930688068751367, 0.16660772924942358, 0.26434354123569304, 0.1192880792903804, 0.14665472411340283, 0.19611581198630795, 0.08645492215310374, 0.12122785987993404, 0.16943106968556682, 0.06443203171534885, 0.132279880945721, 0.1308810656830188, 0.09092827042144153, 0.09357279061429924, 0.18286017731072443, 0.24331919278108308, 0.1391111635753224, 0.2019478248492364, 0.14215787992842738, 0.1909807552733729, 0.07616780157531462, 0.11376113029977969, 0.15721729926524625, 0.1985404496231387, 0.08675263924223763, 0.20909481231243382, 0.15429320294530163, 0.1494011952872238, 0.14454588324071901, 0.2838204686920489, 0.11886621765311688, 0.17093496156796334, 0.12652208668089684, 0.15350177283248595, 0.2107923865438469, 0.20546205401901277, 0.07901267674300941, 0.11569739454576086, 0.06616777244714961, 0.10245611635787834, 0.32537620334375295, 0.19520433589575753, 0.17977826687837803, 0.13832186318693623, 0.1297670359452886, 0.14074168979160248, 0.13019295018767157, 0.22546931350183105, 0.155515649446076, 0.12417952004339426, 0.19598600604841787, 0.08169360909490817, 0.14459149611573066, 0.09248104637428638, 0.20033493397697327, 0.13944327801225648, 0.12648966583994128, 0.27681995723997393, 0.10287531967004461, 0.26244471570657146, 0.18696409499933644], [0.04695601866490418, 0.030972771984975667, 0.022133299029402198, 0.0169792624881431, 0.0106352721078081, 0.04952643900328586, 0.05325427263854973, 0.087043430896536, 0.014118087842249343, 0.08402675285094208, 0.017210100101487293, 0.0781704473399347, 0.06569452163192534, 0.04904767618544641, 0.05761865639097749, 0.0496793769660496, 0.038656796659192735, 0.05538155707801062, 0.04933859807469192, 0.08707140076665149, 0.03773165356007315, 0.03208474094618953, 0.07905351689025279, 0.040069374691454634, 0.056803205591296, 0.05810429484793737, 0.0661312070705237, 0.022855564809194016, 0.04127271878983706, 0.028302901942703514, 0.027254072032989036, 0.06457152866548108, 0.08047957423954241, 0.008704143523749326, 0.045079409685586734, 0.03995252713080376, 0.01921234366994712, 0.003914065061009399, 0.03258275746878597, 0.02811202730592941, 0.038791402137928435, 0.02880608955878885, 0.02482897857384336, 0.05816341002261447, 0.001742038692745771, 0.0767799900964864, 0.05772070696337089, 0.0300255827906151, 0.010204816879253956, 0.03647423897599501, 0.0473758386778495, 0.041785591672505104, 0.029258843691598986, 0.03683832992288855, 0.019811056704530795, 0.016982476226985455, 0.03686357635043321, 0.031240983197705883, 0.04010009481721828, 0.011862535386406367, 0.00853994598371848, 0.10463710739127091, 0.031234174591278842, 0.051048303308386, 0.05312493784473308, 0.05545131321395597, 0.05019294698872874, 0.09329846218949364, 0.06348290240332004, 0.04484733100980521, 0.08669296865381541, 0.02472716357348667, 0.02666869850438689, 0.03040598757985619, 0.09981854458249385, 0.06652432508886823, 0.036816370012539054, 0.10797580283495689, 0.025586367569743626, 0.041167148043431585, 0.08553573921803506, 0.08010708696899876, 0.10862012108367299, 0.34721448957439394, 0.16158441412112406, 0.5096911050138936, 0.9618998751524956, 2.045420069367655, 1.9762589998783606, 2.386566866790095, 2.087936478276407, 1.9854981428192509, 1.385956384962605, 0.7560223869739041, 0.7995358133508313, 0.8483009869533201, 0.5218366629654362, 0.5972614511847496, 0.4534262064243517, 1.2160384510793996, 0.5024030041550437, 0.16361954201373363, 0.08289056018956246, 0.07668444361057013, 0.022280307471631997, 0.015175544859601126, 0.03804707111069753, 0.04779248325634868, 0.05413909653021444, 0.03557943295867693, 0.03330588701271242, 0.03535050673470382, 0.035160528420801127, 0.029676804026108117, 0.04946962975326085, 0.06297293682432463, 0.01615735931291936, 0.025574991164068063, 0.06196910500406258, 0.025737436277972116, 0.0874924197071983, 0.03489357742270635, 0.07836604490876198, 0.04197475410276844, 0.07224775264940916, 0.07756277107663694, 0.023778668199215206, 0.07529621568298148, 0.059814781491314216, 0.02412187558929286, 0.06447217472258114, 0.047558577460867744, 0.05784045416681517, 0.02983337707607256, 0.05504873400974659, 0.043542154674087806, 0.04672646424883316, 0.02146189957256279, 0.04646265038078831, 0.07113652679348184, 0.06944743315539054, 0.07498133822434372, 0.04043437345253845, 0.015234736643070656, 0.011757556442922402, 0.047122937732286034, 0.03238436750947468, 0.06440892650355255, 0.06213905011874534, 0.026891501770625194, 0.03908307862377936, 0.05990539820143773, 0.016526169361426465, 0.055451424296705, 0.05770595594038887, 0.03348689443702179, 0.028281928370556528, 0.04047079710289836, 0.011304350318236938, 0.03775424166252056, 0.01768724838902633, 0.017931636182531234, 0.047709293768651066, 0.015660177826160387, 0.025664148476695823, 0.057139924216654994, 0.026997869248471917, 0.013887833413337509, 0.0442821879480635, 0.02852402747638764, 0.04543332315440621, 0.011531240663551276, 0.02792292424748021, 0.04227253630937588, 0.029582105982567997, 0.06381554927136149, 0.0327552919606528, 0.01677268687936087, 0.015280709579406727, 0.049113908316940076, 0.09704632519353783, 0.0530051370151341, 0.008681585107208982, 0.024112138611775254, 0.023173129321226192, 0.0821950979110214, 0.050135563172760515, 0.03864818966136344, 0.013606332490340838, 0.08912995562798555, 0.0737546552573481, 0.027589266143378713, 0.02193561578620105, 0.022858594686934547, 0.019113403414526296, 0.06381149283580242, 0.03472690350346027, 0.028391860072470965, 0.0441171036612603, 0.05194395585286041, 0.026924748071319154, 0.07256168015902081, 0.03476806157719224, 0.013988935951924613, 0.03802066405994758, 0.02594883057979807, 0.02103113024795969, 0.007210909360794411, 0.046111605911245274, 0.05586422311382429, 0.06858245860184393, 0.055118084119092074, 0.028167894267807567, 0.009193468778844803, 0.018714828934941082, 0.06237882414772626, 0.09374644742497514, 0.03270134404902497, 0.005316532408488134, 0.02545436678995048, 0.032870155353579796, 0.032410360872745514, 0.05132793306162761, 0.03524662904261101, 0.06662493541596398, 0.028954768072693583, 0.013531493361017877, 0.037724360403034, 0.017188776044114944, 0.07691305190805467, 0.03785349601399034, 0.05632265012771372, 0.022813935591388616, 0.10985743735105762, 0.03853945880227032, 0.005988513134540089, 0.048549596460596214, 0.057607188054751006, 0.020035794342777902, 0.023345336310505387, 0.11547037205027959, 0.040461316764835394, 0.07096309980918324, 0.10751274865000479, 0.058765179748016025, 0.03500550286844373, 0.013918818797044938, 0.016146536405769088, 0.002653764001274061, 0.030144000831510753, 0.11388757311168218, 0.07793145855107615, 0.050552307342689846, 0.1233211568286342, 0.021119921753603606, 0.048267752713253426, 0.025458292990562417, 0.11311661286820328, 0.3187556715021211, 1.141289597557437, 1.6565013773018316, 2.9490097443903647, 4.063027837584096, 5.664523734200386, 5.645355111168278, 6.578558558417905, 6.418191963626493, 4.823816149465499, 4.8183444430751186, 3.573097081915025, 3.1406937683782274, 3.7237854734543836, 2.9458404692911335, 2.5283004872260557, 2.0391303036482107, 3.6867538863612763, 1.6780959862855174, 1.0088857022985336, 0.2458466853826277, 0.048216172013311624, 0.11563264479440068, 0.031223430208140807, 0.07017212168824288, 0.06355490700732316, 0.06768935329971776, 0.04475581031593104, 0.14152771132367273, 0.027518579210605354, 0.002368432159851035, 0.08511521057375977, 0.08105136694446688, 0.01823194264884918, 0.04050547790323054, 0.023375179265595736, 0.08598961566965427, 0.018192537001244003, 0.046885009975202625, 0.041316638610536055, 0.1006973623448322, 0.042167386911328764, 0.05897365142441085, 0.06522133210373503, 0.051195599033587405, 0.021919131489290346, 0.011436385571986679, 0.06710410042996369, 0.06867835748820536, 0.03000962900959196, 0.03614189088224404, 0.025579591522053368, 0.0347742285849827, 0.07336672365425095, 0.10337572830218462, 0.0359357979088541, 0.09847005363553764, 0.055966871234798626, 0.06556981017873173, 0.03917715422088101, 0.08382422984727929, 0.01181026520733271, 0.04095939265924596, 0.045158657650913925, 0.014266358414334396, 0.03403653570961568, 0.05981226872292258, 0.04045224628381191, 0.02957604431186713, 0.05614591747402184, 0.004599205980588112, 0.042841651537004984, 0.02575629161700847, 0.03061392299470402, 0.05359239703524978, 0.033852912095044894, 0.025068176121661262, 0.0353566775729339, 0.056513360055584105, 0.03757226513698697, 0.014277045340878109, 0.013949510194511424, 0.02809442835108888, 0.07106115140261189, 0.04065700243377397, 0.09316520119506506, 0.051915181590424436, 0.029527755874779918, 0.012063097204982996, 0.028233666746546666, 0.04427451940794145, 0.03266630318736838, 0.026690880580234434, 0.14301864099839043, 0.19833558239042762, 0.15741542492422367, 0.11770813785974057, 0.16916696853455038, 0.13323454907344234, 0.11195920723220033, 0.09224536708526074, 0.14057380928387567, 0.14921076115100615, 0.17629244424883397, 0.20759707977694852, 0.18821621974629743, 0.12576947424320445, 0.14279931002566892, 0.1594815640560081, 0.10121021224486251, 0.11042498592888156, 0.23810290010465732, 0.09633321224922135, 0.23521214393117737, 0.158979132951748, 0.15553454117428872, 0.19756194083921372, 0.1211979671291286, 0.14429615389916206, 0.13169414544057462, 0.12187847537138771, 0.05334993403765464, 0.0738034244146078, 0.08815543050126684, 0.19752806443120205, 0.13110608102813845, 0.13113422709847652, 0.16618826546736304, 0.14796812057254777, 0.11604617905592728, 0.19381016312587648, 0.06645412079148716, 0.09782744376289268, 0.09485060228936135, 0.17384883827499806, 0.20551019498417455, 0.12275818945659746, 0.12929422180018119, 0.14352508640337375, 0.1638200731887933, 0.190756015719906, 0.11165976644523683, 0.11369709301018908, 0.12041530872304594, 0.1437858933763158, 0.1410250810365523, 0.07128769126270088, 0.18413140829051697, 0.08483559614227665, 0.11532179695824463, 0.12801788867481295, 0.1843143807303521, 0.08327479158798534, 0.12129953506612971, 0.13757737894212047, 0.17440664221442517, 0.09120510395375953, 0.09398980291500207, 0.134598829092518, 0.11774765267487496, 0.275635922387723, 0.18344485561453527, 0.1103627106415168, 0.10884679883958832, 0.20622827983911962, 0.14918275297649447, 0.13975513708447257, 0.13968695525921163, 0.17803930857729527, 0.2550859355758275, 0.15080903506567403, 0.17763495204910157, 0.0697070450311707, 0.10843310369959763, 0.19338688422595302, 0.2737394564094082, 0.3080493169686487, 0.5835117051197637, 0.9868193670145928, 1.683039766165518, 2.2199516911660475, 2.8657775396300904, 3.037675902728112, 3.6206244412929784, 3.5143907223978355, 2.7644529121537365, 2.567612687426229, 1.9568965872449262, 1.5067036089397248, 1.9541745849194068, 1.6249908939484627, 1.3680142380537526, 1.1691349937069802, 2.18896962461933, 0.9345072676097194, 0.6713593138321754, 0.1874971389770508, 0.1638827698245164, 0.16112355094763542, 0.09754931554198266, 0.2696410085885756, 0.13974015240467366, 0.08300914293936185, 0.16449757070550997, 0.1636417125982623, 0.11201335432668848, 0.07080739243857323, 0.17829668347633656, 0.14592255856240952, 0.1553757158258269, 0.10228557752505427, 0.12864795002725818, 0.18627267000415634, 0.1344633847475052, 0.16438006813968384, 0.1404963424729724, 0.13284870122949924, 0.2479652555719499, 0.1470513584753198, 0.22313553389281998, 0.12640384867066337, 0.11517410286732259, 0.08364954647878486, 0.103019175660466, 0.1135779893206012, 0.22143028346040558, 0.12296263534095019, 0.13986738428713816, 0.22872616777256613, 0.2101813394936823, 0.21259771870268931, 0.1333772712537358, 0.17073277564298722, 0.2532531621475374, 0.1675397211745862, 0.16154134465802103, 0.2549761858197951, 0.11479329588192125, 0.19215254804059384, 0.18372115288530627, 0.11639163108362306, 0.20832630355031262, 0.15552498039699372, 0.16224548671274416, 0.13477617844698891, 0.1378967763195115, 0.1325100444016918, 0.15175440288599462, 0.13705023384142306, 0.09526442000341993, 0.16683879668914503, 0.0922564906819213, 0.20016371332589658, 0.12028234650290782, 0.12808427019345184, 0.11073379597115902, 0.1384427671831462, 0.0849221027906864, 0.06783369192553144, 0.15707122161984444, 0.10484503897567911, 0.23092862458959704, 0.1612392915112357, 0.12949775603990402, 0.09508628157838699, 0.1128646235672697, 0.13647146973638766, 0.20207855009263564, 0.1573002972309628, 0.2663587814857883], [0.03967613409904223, 0.069656950541802, 0.031068690023535205, 0.03012358267310887, 0.047203330999060024, 0.045814677892673406, 0.020483358229901043, 0.035063518706949494, 0.015896066831755304, 0.052107496472496184, 0.02450621424002513, 0.04805056678671991, 0.06498334689005729, 0.058455791309355735, 0.026572885802916946, 0.03193748161016453, 0.033275718470254255, 0.1284356747243193, 0.017711238432375175, 0.03673038430391781, 0.09434074779311497, 0.051844988784362236, 0.024076117157575586, 0.010751728006007691, 0.01694457977259111, 0.01589166757185012, 0.07388880491376885, 0.015573850250802936, 0.07954198221165328, 0.0577197416925863, 0.016518336112400698, 0.032160524278879166, 0.020758314846804547, 0.06464887290231644, 0.030868047765726526, 0.07837584317331353, 0.004495501615888169, 0.014243676466116262, 0.025424112062600833, 0.02025060922718577, 0.06682226434350014, 0.04474512721982695, 0.040854381157025214, 0.051408602120054346, 0.03382239115214156, 0.019265427817440322, 0.03758558357555059, 0.031523250208626834, 0.03951184271324066, 0.018489677609214862, 0.002478565678053025, 0.05142037306101092, 0.026508160949414297, 0.020694185626663027, 0.031439363580918124, 0.010159864755076988, 0.005227957801487778, 0.08866692442567119, 0.056045000711756374, 0.02675732530112709, 0.10416643063147223, 0.026762463835879203, 0.036572183317114274, 0.14746922879449784, 0.021402922293712056, 0.08210312139483229, 0.005086295695359549, 0.017375624888846954, 0.06462884736397574, 0.018798018422638698, 0.006435349238135162, 0.009408672452874241, 0.035664836440475724, 0.051371044659566496, 0.04157391008770755, 0.0867121514954394, 0.03397832451868923, 0.039372694333113974, 0.03155743879746766, 0.020862403213076537, 0.02211731077442246, 0.04601063935326473, 0.05790163777888783, 0.031234109473805276, 0.009469136899907984, 0.0893944321620849, 0.03303907774088364, 0.055423508052744215, 0.07184203248471022, 0.06207807718085186, 0.05108580714271915, 0.059176388932692434, 0.05641350432509377, 0.03376520268859402, 0.02163026654612153, 0.03620670958151741, 0.022550349634501244, 0.03772848195606663, 0.043773919253820376, 0.047053212239857645, 0.08771320624697594, 0.012508955588864704, 0.037043901956489975, 0.05145638302389172, 0.02568213239071831, 0.02832875932536779, 0.07153186646680679, 0.03697371681130702, 0.01736100410081206, 0.023503280657854293, 0.029290898725570693, 0.03411119097783681, 0.06587498130336886, 0.0290391392510144, 0.03467718822761409, 0.04104864956330388, 0.07874360368136438, 0.01939389693190254, 0.051734901949643135, 0.045865557622164495, 0.04905023108867388, 0.04066656704150862, 0.005902984684648654, 0.021232720539574663, 0.07425576869037843, 0.06121754593726608, 0.0032865650756585024, 0.06412788331809063, 0.04723300158436741, 0.06664480773671981, 0.0278706444923075, 0.039551323054418455, 0.02981431106285703, 0.03247219182911419, 0.012061159002534565, 0.014329127828410317, 0.08053777393915, 0.06425948190172354, 0.10159275824985198, 0.03138499815137156, 0.046302488208898616, 0.07378797242117506, 0.02583043169110052, 0.04420667466136717, 0.047390202826429764, 0.059436812861672336, 0.02731024351481709, 0.016601006575529615, 0.06897339326960426, 0.02313452423550189, 0.046294099546127745, 0.05782666841461774, 0.057739824687521306, 0.06744399832020845, 0.050758974882022995, 0.0474183259141301, 0.07119047470510968, 0.04710520279683894, 0.02555340663680146, 0.07203962188214064, 0.019175320555786454, 0.03337229534442867, 0.09347038764146068, 0.02643950223442047, 0.044504813098859404, 0.060320483791011, 0.02710891177787656, 0.058119834941481395, 0.035287802438101465, 0.02740968938826794, 0.0920966157930032, 0.03557624603291193, 0.04192553678407304, 0.014668643632302842, 0.028010283168705723, 0.020601713068542943, 0.03602655251480399, 0.06900675639870667, 0.01315434636067479, 0.06844252498159487, 0.017144409977200053, 0.07718931087442944, 0.04453358353085576, 0.010777285656771593, 0.04350026881682777, 0.05358514601304647, 0.11301733553409578, 0.06527306602126168, 0.07076357987018363, 0.058386425878251755, 0.034684320506189144, 0.09331409804402821, 0.08435841529600083, 0.043655539517320936, 0.019126239217697613, 0.03980207895379394, 0.10607225054334249, 0.0585735313624384, 0.019936438484658158, 0.05284723480262103, 0.054581826402535366, 0.08771566538921288, 0.0180338591247076, 0.06955173602628131, 0.04480243442700275, 0.0068212655511864975, 0.07897817980377905, 0.01578909605966821, 0.10211506167486792, 0.03266389767128614, 0.046563088338101105, 0.070551312228124, 0.009571110863508958, 0.056428937166328394, 0.059942706683350194, 0.03070614657424871, 0.003264271677659464, 0.03259034556967597, 0.027002923513552355, 0.05493320795076509, 0.03528366173287073, 0.0720175662108006, 0.014862096154942148, 0.10711402286805453, 0.02320024883374572, 0.01751625756432693, 0.016695729516927275, 0.07165261724543187, 0.0955381891840408, 0.031583550904366764, 0.016719112435596126, 0.020623425915536862, 0.08197893854230642, 0.07337317411457339, 0.02474343911143801, 0.01991071516738063, 0.0643539367123477, 0.031569638747661825, 0.014122744699219062, 0.0433181697172263, 0.028531734320905902, 0.022620772266940727, 0.02361708684944578, 0.043885005833280664, 0.04553002643308813, 0.026690428588359107, 0.056156861040020184, 0.06337083906175629, 0.04719549775003426, 0.010628668429900803, 0.03632864013554589, 0.13779006027165921, 0.08022364724667803, 0.04251354757035452, 0.042172033234589526, 0.03872189498055847, 0.03643025020738283, 0.006032672357715426, 0.026213184539829532, 0.05785801290203968, 0.041012110999755325, 0.10044770195118843, 0.047354514620477156, 0.045320792499208645, 0.014661155122843002, 0.014474684534023606, 0.05696606822311879, 0.016527965837608904, 0.0208102441167519, 0.023545394426271803, 0.015958570030277536, 0.051370454771864804, 0.10370263334123359, 0.03407250353766065, 0.004343877493914578, 0.07361578649931377, 0.04443080900537391, 0.05446689789213481, 0.03488014790139372, 0.040079276377875964, 0.043863857976130904, 0.07818708676965007, 0.01566975200999408, 0.021674605799959074, 0.022877961389660355, 0.061701414731120875, 0.08744502950820231, 0.038031082855717796, 0.009609258211698503, 0.04570849810636813, 0.07360552092112842, 0.03725885473672421, 0.016659830636795492, 0.0410409925145007, 0.05280537958887797, 0.03773001796235481, 0.09744575577637843, 0.06474227434204471, 0.020832431938258872, 0.03424928598706761, 0.060115593575662186, 0.06415433633411605, 0.010231576330449072, 0.015326590585191886, 0.036651232099581155, 0.0819090636627328, 0.04622477624985961, 0.024220247024429903, 0.04025278763184625, 0.06325928899910181, 0.04914426455093969, 0.007450011626426732, 0.03180006841918634, 0.08048011050108941, 0.061704268408638824, 0.026849723165674556, 0.08278090236408096, 0.08425602764492074, 0.028281137384774706, 0.0639367328896638, 0.06449167932113332, 0.018928379774273887, 0.04470123804264492, 0.00704843599739815, 0.044224811792974515, 0.02099816165413828, 0.01078064782514928, 0.07235432314055582, 0.04856495269303841, 0.025489750475953185, 0.07495018908934248, 0.04077883722681192, 0.038829610773151925, 0.03148223769160048, 0.03358702212872525, 0.006069926255863281, 0.042957028208841244, 0.039735616995922984, 0.028650661810271205, 0.03970367495992011, 0.008115908656749994, 0.02995819386635577, 0.04874020296659681, 0.020444259017465577, 0.061467164196074016, 0.016375366868751667, 0.027997968305322914, 0.026675779072027055, 0.02462868871647985, 0.03021077305499104, 0.009952373671225243, 0.04676841905400638, 0.09838164708907567, 0.12911796029056274, 0.11116807589367514, 0.10299499026469647, 0.1120124426820586, 0.15650669142844217, 0.1554427944844769, 0.12114301564231997, 0.18553947789534447, 0.22125275024483282, 0.19776716047236997, 0.11925702208593009, 0.1624312323908652, 0.15058437212099954, 0.07633900690463281, 0.11430893679179492, 0.23815333933359195, 0.2772680267451271, 0.12270892234218699, 0.17617523279641906, 0.22102264807589594, 0.2063886526851885, 0.12755930844333865, 0.08818290241423153, 0.14292133251024833, 0.17847608594644457, 0.12415033975435842, 0.12755778392836933, 0.17454663712170818, 0.08185100951983083, 0.1835508975050142, 0.07083225199171612, 0.17822848632931712, 0.11538254006976083, 0.12363493878154025, 0.1828426185754999, 0.0910735896397983, 0.14420387094780324, 0.1687631023026282, 0.10048894046415245, 0.14319986675775823, 0.08526663551287306, 0.12988899714283406, 0.12729616490222756, 0.15083008716183324, 0.12543558248228606, 0.16484041037338396, 0.20189145609976786, 0.13043307278665806, 0.14867177233099937, 0.11240049685922363, 0.15553556773210728, 0.1328475827411298, 0.14829661907447925, 0.06873929978258188, 0.13342098423069523, 0.11033648745186868, 0.1306224343997817, 0.0614088342615193, 0.14826732387225475, 0.28820046914681313, 0.10779414040547226, 0.14654071490851142, 0.18369584134028805, 0.15300551639689555, 0.1572281164267371, 0.13912217991967357, 0.12508366467250934, 0.14522820711135864, 0.12140101873345914, 0.08766132677274366, 0.15671232474907754, 0.14421588320645595, 0.16170675836263165, 0.08578271830394384, 0.29646827388674984, 0.25136797298346797, 0.16044441400276077, 0.07495198939596454, 0.14367531624532517, 0.12123915967681717, 0.13983672544840844, 0.1507788205579404, 0.16299876564693067, 0.16565106929309908, 0.2753570970268019, 0.15183557756245136, 0.12931305224136, 0.3530926209303641, 0.14971354465571143, 0.1275648855634274, 0.15692491414806536, 0.16543504782021046, 0.19325907011666607, 0.18717173547033342, 0.12838436981603024, 0.18897161308315494, 0.13694236866168438, 0.10232822563979896, 0.16022466934256016, 0.25932143652631395, 0.11255906173779119, 0.17163971649302592, 0.07349548005168477, 0.2233284348321538, 0.21674599288211716, 0.23222276159832556, 0.11980225452251973, 0.10573490372588558, 0.16838048734972555, 0.21175709042337634, 0.1285444209051709, 0.09268568378062018, 0.12367786268793768, 0.1683728571139997, 0.11442497612968569, 0.14448847261167344, 0.11937632495837829, 0.13880426875285565, 0.13298356334768957, 0.15701589474995292, 0.13435268504244668, 0.12877682133788063, 0.12210247948044732, 0.0965366239148763, 0.2224767595649727, 0.09781948410935941, 0.14785440248106757, 0.10414453583859629, 0.22064554895604813, 0.08666724342131808, 0.19862205330883304, 0.0830013518251719, 0.11658115357521082, 0.09152345945157352, 0.10338002605543983, 0.14916228310715768, 0.13404148480584546, 0.29066089841146625, 0.12307489020449501, 0.20322598126386443, 0.162534715547677, 0.1691307632192489, 0.1466628752889172, 0.19429908043915228, 0.213474843410715, 0.1834306676661776, 0.10652423475778873, 0.19490321737623986, 0.10765350964521209, 0.1426268789556719, 0.1162893736674901, 0.07724053917392608, 0.12780933655918608, 0.13396129072193178, 0.1234406742057012, 0.17566066685943835, 0.104922620699771, 0.16021711571562677, 0.17581150957172917, 0.08868040757313853, 0.11108545331104148, 0.1632189239946104, 0.24651561803635091, 0.17060123834638827, 0.15692620117577816, 0.11453726163674748, 0.11635651361317405, 0.1364582317370561, 0.09585468308819879, 0.13828685296879661, 0.15023771733526262, 0.0737673263516157, 0.15230123644634602, 0.06103726246604516, 0.14321770128463546], [0.06186687823144659, 0.02098726213819558, 0.002379263446087979, 0.060098904350231734, 0.015696235669536457, 0.05713935731159103, 0.02209910661012175, 0.0480698224066967, 0.01757971454231489, 0.09637736189629763, 0.01612163471779035, 0.05976050033143932, 0.010379346072553627, 0.04963816143572331, 0.06716937878199163, 0.028924210740613843, 0.022175177225782987, 0.040264217663676515, 0.030883589774490367, 0.03923395581002678, 0.02664828800686425, 0.036178111519304015, 0.002310253527661365, 0.015068766567105008, 0.03267532004223716, 0.0303116170389037, 0.04313669497928312, 0.050117295806206046, 0.022895811238296093, 0.031245792314650554, 0.051938240836945274, 0.05285256677457402, 0.04380556251553278, 0.01923122007640139, 0.03650887381105173, 0.03677875126501726, 0.016567605142030987, 0.06153446502022206, 0.009792802344647147, 0.04060964670873458, 0.04231035807019761, 0.0314061785672581, 0.09000943988681802, 0.07224306419131256, 0.06383331485032555, 0.014327419452339172, 0.04879391339096812, 0.07326938452259188, 0.02773398589793473, 0.027085818057399125, 0.03675307199779538, 0.02637146022020569, 0.03294763748624152, 0.12822440299656124, 0.021505417197101542, 0.04240544873379892, 0.011591909081494857, 0.05607593534213882, 0.04382922314107419, 0.0020749776318083487, 0.03865008572897604, 0.12159170567869179, 0.01710890371712946, 0.06181576101469898, 0.06654028270033098, 0.06686737926136102, 0.101442068755146, 0.027024994506650878, 0.026618069668691006, 0.028780552017832958, 0.023792241362013647, 0.023890143568297068, 0.02700517006639031, 0.041925988775948365, 0.059723911972175685, 0.020700517343357205, 0.002340866640518089, 0.015259844217179044, 0.1001695737302784, 0.021308572820177483, 0.02074064502883102, 0.0319734494382095, 0.06761833694913695, 0.030973066928826516, 0.0582732517091978, 0.018315436656496698, 0.027009808728771827, 0.026060888175702384, 0.01159414318540404, 0.031212507709560376, 0.04847447770918089, 0.07407573036729329, 0.04145174587686216, 0.04992136115869207, 0.031405866386428956, 0.035896658476802616, 0.05421277120589249, 0.04410176275057658, 0.05463175618300035, 0.02856440222521703, 0.06816425120397922, 0.06413910267574173, 0.026294393690242886, 0.08740521591877745, 0.03498506364262393, 0.05298641765670431, 0.04046114056461281, 0.05560592507883426, 0.009426877574784862, 0.04496907004185262, 0.03495520919621472, 0.08830651070081419, 0.01802951732139674, 0.03322950421622203, 0.10944430911613089, 0.028956233215848767, 0.021412170890177933, 0.03178282761045041, 0.02758330023366838, 0.01289827955676423, 0.050506939615813956, 0.01753636354189967, 0.03456496400758624, 0.039621335829818444, 0.033404773641978545, 0.11023570858542958, 0.13068388997306749, 0.022651063383466775, 0.0785616118340723, 0.037606765906656944, 0.025209538495889115, 0.020409428829988165, 0.026305381306296876, 0.026045976274256265, 0.03979767394822933, 0.035629849204973835, 0.023166613743430185, 0.028741544735948407, 0.0435418137649615, 0.03507303734940868, 0.03073239083131475, 0.060083031008440646, 0.020641767975663947, 0.037184387160044526, 0.013676868120749152, 0.03704699695170407, 0.07264148353809312, 0.03236099416690488, 0.014377073441151411, 0.05756081675269431, 0.013273501761197565, 0.0274767259120821, 0.06555446543760839, 0.033152037405318795, 0.016286519821733236, 0.027049930668586207, 0.09355117161307605, 0.023205291607507297, 0.03508340251902419, 0.023192898220112248, 0.03737903477984571, 0.04947109681163584, 0.05871494353238133, 0.038224711578579686, 0.03415237969508575, 0.043617725417378454, 0.17527728581861143, 0.07331657553872756, 0.026516664525373813, 0.04167178931135324, 0.0392340668927758, 0.060404044831351894, 0.049757127229484825, 0.0614227234355865, 0.06634690678648411, 0.027422634358968467, 0.07400376406768638, 0.04560047204816534, 0.02464467505623977, 0.018530190253870624, 0.07812582271834535, 0.030990357533277526, 0.012601964408531787, 0.047548143343339046, 0.036316160563259356, 0.08972391891743868, 0.022106711947990042, 0.020253692731080998, 0.026686963955721548, 0.04093917942936382, 0.041812910367884946, 0.06513188367769604, 0.04929514556762673, 0.09409163898277668, 0.0718176708887181, 0.010641707246372057, 0.042872662776179855, 0.047428411461653254, 0.023122829903337746, 0.04899386616964494, 0.030777306566315315, 0.11544882199696957, 0.06024223557042499, 0.06461249138679236, 0.04785010839001306, 0.06721866887903984, 0.045855901083878936, 0.05317240848296112, 0.01937202512166433, 0.019523626261000192, 0.028984840854161212, 0.02867645982112135, 0.06840866389534167, 0.056434422355866244, 0.03229267061537793, 0.03587267609433301, 0.04806085917798262, 0.10347065425688222, 0.040695797126259536, 0.11586816320496222, 0.010002958456865482, 0.015152933774515988, 0.020673083734788725, 0.06416277479260199, 0.02979889928904032, 0.028618003482059128, 0.024125788383366122, 0.013371565803554992, 0.032249336851941, 0.023943164513536522, 0.02363790720400791, 0.04381522671469758, 0.05284569879633285, 0.021848004055960525, 0.06057756757664104, 0.0561754041982274, 0.08148013103392818, 0.05105800964238663, 0.02963229240248761, 0.011029304643612235, 0.03932148518581544, 0.034559949962121826, 0.10539729643853442, 0.02036589971413055, 0.05161332762649944, 0.04947218848692794, 0.010929307186855905, 0.11417227436698253, 0.018638649151750633, 0.04129482425689217, 0.03129406159953966, 0.03735302992525601, 0.01820416047027515, 0.047633849429867925, 0.01621947563703983, 0.01798980140818223, 0.05547493170466154, 0.021718720973078764, 0.02471060649822316, 0.04472195306011746, 0.01721771310023483, 0.040605758812518856, 0.051990308002719, 0.030725951862311175, 0.06040976750814627, 0.04587397692845233, 0.005100034524671613, 0.023033954128022158, 0.03074607124642259, 0.05343852061477881, 0.014504029531963171, 0.03391832451245958, 0.09675793905532169, 0.003728314834241305, 0.04135631430413454, 0.03130382922057423, 0.08524027442739857, 0.07351355972669779, 0.0611499501692672, 0.06148389172590068, 0.05470498652768232, 0.05924139532350725, 0.003709087224354247, 0.03786790612784605, 0.058428817353541815, 0.023733537959595843, 0.01675922479931145, 0.01548724784140265, 0.03943049183656131, 0.015587209866592481, 0.11344954701921633, 0.013922604229000789, 0.010787657529656446, 0.06072791616222071, 0.05240923552323253, 0.06244188467521341, 0.03484871148342087, 0.02650030280253099, 0.03516519772669962, 0.049148995143872116, 0.0314843712464696, 0.05518236655681845, 0.08404317011515941, 0.0158543121670523, 0.016489161569024288, 0.09465101340244855, 0.06430758839292873, 0.026653212036997564, 0.010490987108149117, 0.0034194913854251707, 0.056364964994211356, 0.02232046771584259, 0.060097065739213466, 0.06760313776471923, 0.07362343971767733, 0.015002692441245722, 0.014261130821861088, 0.020521038264456778, 0.027799534295955976, 0.035188494460476984, 0.04385863708692693, 0.03129072528662941, 0.06465626565078575, 0.0357149807255595, 0.060685873256936196, 0.023312873334714004, 0.05784007878373227, 0.04530165562286012, 0.03602032421997959, 0.05188014072876784, 0.010248377596238449, 0.035475980445382096, 0.02265579397639921, 0.028273673773172404, 0.04085677135134897, 0.011492215187078523, 0.04551147561400168, 0.05285058260685014, 0.04503543240829341, 0.062398190850452076, 0.07131477247082418, 0.02190048682443317, 0.03483216015381679, 0.08240328996532387, 0.051729612112525976, 0.013263051364300473, 0.02189323771744967, 0.06708098755728814, 0.019059924731752085, 0.047303156086033395, 0.07288563575956129, 0.024248103896576553, 0.17674773030223387, 0.09924240815903872, 0.15387642047097608, 0.10135951512042554, 0.18543222558594522, 0.21297403641285437, 0.058183290004249544, 0.1289822554756557, 0.09509784184516439, 0.23603473850075277, 0.09034152368023511, 0.1348321947960123, 0.1312426285397622, 0.22355368000365075, 0.1556200672301554, 0.12637485224272937, 0.1376452696539702, 0.2732261162131064, 0.12453152212284266, 0.10726458978869262, 0.12192351368045616, 0.16182590035661576, 0.1147715236631132, 0.13955229232388158, 0.07259046974321527, 0.16433365853323093, 0.18372153592926843, 0.1819503253265735, 0.20188324363721957, 0.21051403615743886, 0.11438418194771775, 0.17177597289123844, 0.09972344242757368, 0.05881047086609949, 0.18285351234578318, 0.11563328830825707, 0.13077537619298504, 0.15350837651039326, 0.10518931122797151, 0.13489381890864144, 0.19152778801658463, 0.11681485635739182, 0.14930693582902033, 0.28853543343082555, 0.18568236861498127, 0.10593792468669916, 0.13384887497992287, 0.29582325849802266, 0.1303288082201635, 0.11242904895616156, 0.10021325606372088, 0.17698866495442006, 0.11913169776239704, 0.18758074981310677, 0.2046895922432023, 0.12193281398785692, 0.167542080725393, 0.09402312007882903, 0.1332662038264736, 0.13090133636949525, 0.16169016489819174, 0.15989834653033366, 0.1532983764885895, 0.22112026299920776, 0.1623970648694423, 0.20699816755950454, 0.20416917339448007, 0.07013999962157781, 0.21672074262413288, 0.13379008539261358, 0.10078648135306374, 0.14670232881701764, 0.2237037413062588, 0.14010897777493925, 0.1462006484789233, 0.16521147272038847, 0.11095845891583352, 0.10260582526004124, 0.15682189064400812, 0.08421126512750503, 0.18082209231872715, 0.14747546475020148, 0.1242643566201291, 0.07557357015508799, 0.14409004560401364, 0.16050373985161706, 0.14701680790993477, 0.15960980717453266, 0.1680538887458463, 0.18301760837916406, 0.12206279612596958, 0.13594274649456625, 0.06108289832369455, 0.12605989817529917, 0.08621365808311009, 0.11604021889187636, 0.21472866887286787, 0.29939751831754563, 0.1791143291179211, 0.16400099251299136, 0.13358763899774323, 0.34176028063220365, 0.1291978632610652, 0.2755531236048668, 0.19603298255993476, 0.18363001906583387, 0.11897898579557097, 0.19137316082994785, 0.12020165446184336, 0.15490930617576645, 0.09009544857807698, 0.196069463666889, 0.17109243860167844, 0.14056286954831693, 0.1872714035092823, 0.1493437846581782, 0.12741969658001778, 0.15366102719018537, 0.11644383231478354, 0.08457344851546711, 0.13375360428565933, 0.12580183379712606, 0.16273720790782284, 0.09985949964292588, 0.0917540442559027, 0.18155741415196852, 0.22088147339320954, 0.057050169355446295, 0.1836663929204787, 0.31301016528760234, 0.15271864711276947, 0.0886071312631811, 0.1910051628346405, 0.16937154465385024, 0.15459672698090154, 0.132256974916785, 0.14646222153978963, 0.1561192194780996, 0.1351430119886514, 0.2214358912240113, 0.11432073454582885, 0.17180874613263916, 0.1781049929559231, 0.11325986364916449, 0.0950019506196822, 0.12802519715361058, 0.14995650178001774, 0.056145492295223864, 0.1160429997910415, 0.15749636977430315, 0.15814968955612954, 0.10137551869716376, 0.06852674868799026, 0.28667907981622603, 0.12649755654556136, 0.13381032543557306, 0.17172153468333906, 0.07424554907746854, 0.1955957608597894, 0.13182116281842032, 0.1522847502342155, 0.17287031416931462, 0.16643379664709493, 0.24316003035393455, 0.15548849929003947, 0.20427426533593288, 0.24725952005434423, 0.1475294126618293, 0.12787827681149208, 0.140785341481528, 0.10496653285959076, 0.1556463593677167, 0.1041687518778828, 0.14380179736162388, 0.2787433895132234, 0.10610693134367467], [0.03455831053396387, 0.01991871695574974, 0.029454052470804706, 0.02528993367788292, 0.06627101045582565, 0.007319076187653288, 0.05701509018939349, 0.0322393853698046, 0.051305590107315974, 0.04806956576724206, 0.06573867127900163, 0.043475053032800075, 0.03660058219646735, 0.017326279250424237, 0.0618827898776339, 0.03148352471931327, 0.01296588107042255, 0.023230524628513285, 0.050771374015077475, 0.027770693000826626, 0.05151418052733906, 0.006324846800717135, 0.036008767783641815, 0.053587126350330735, 0.05859743330567595, 0.007903190938034847, 0.11049680667178285, 0.041034400327912265, 0.04899985697721282, 0.02491553884840781, 0.012622246586327112, 0.02103531691846588, 0.041432804352934324, 0.021632089835381316, 0.054652574622342666, 0.028696791794631752, 0.039057832196234696, 0.04510239998419439, 0.043331687338650234, 0.008081564935104502, 0.06599969275656246, 0.04488277023718242, 0.08461114770222096, 0.057490087685085116, 0.01374058748385118, 0.025188999678639155, 0.019963383712174914, 0.01947680105184836, 0.027568403653980746, 0.009819619252436585, 0.03908436182105253, 0.09047368916893199, 0.018439136873630267, 0.033650369939184, 0.030509549260680235, 0.09872246428482956, 0.02853661813142319, 0.03509821482904015, 0.033198745786062175, 0.09452166711731304, 0.10528681889897394, 0.02880268429796542, 0.03362425400184528, 0.027706531221948327, 0.017846931755963354, 0.039714967095924, 0.013864632440550674, 0.03028632656130339, 0.034139907783678466, 0.06720910810174481, 0.029471925302078168, 0.024774006019616802, 0.07694721176859833, 0.031172493022055398, 0.029111038517927932, 0.06977190203484028, 0.0660263832598444, 0.07133547982741749, 0.02569721091628796, 0.048590084207394434, 0.06698819132702005, 0.01925722493099109, 0.028065403194857702, 0.039276799277192166, 0.04469512083056954, 0.017886979002205115, 0.02389528210304918, 0.01935746370544357, 0.026956783953092756, 0.027811441217519106, 0.006584328920355128, 0.0835708769098405, 0.03636722798429189, 0.057319560343579906, 0.010295016071458739, 0.035064380555864305, 0.003147363069377119, 0.09074771115856786, 0.012481336203974583, 0.02659096356271015, 0.06230075595780246, 0.08037626728295319, 0.07253537269970102, 0.005368326176633878, 0.032774206671503284, 0.022742331268325932, 0.04027208155621925, 0.028450523255272742, 0.04877678749542083, 0.06090446878525038, 0.05527173454362539, 0.027446693350230495, 0.0030140024835183738, 0.03300288774734063, 0.04470394616345725, 0.03468140937207687, 0.017197591800903602, 0.01888135921270136, 0.016058746560086167, 0.007401945354837565, 0.039924296790794025, 0.04971267880811807, 0.07398975998043053, 0.06590596955990599, 0.0666632934383327, 0.05742896919048602, 0.032620100424655026, 0.05428849899720761, 0.032773122657090425, 0.05127208525194757, 0.024363559092425054, 0.05355630280269731, 0.03661377040008384, 0.04651556407371837, 0.015708745885339957, 0.017078909459674073, 0.04684575946040211, 0.03814869650429295, 0.050245037137140194, 0.044085372299436605, 0.03652673515100633, 0.027503042947500948, 0.04188991752603362, 0.03557921079317889, 0.0389037719146619, 0.036640774999414726, 0.027229894298098745, 0.04578198509050473, 0.011364174124244, 0.1228982073465182, 0.0900723280445222, 0.01714724258730008, 0.0767069895781817, 0.051613116952320265, 0.05528910175686883, 0.05159613278303897, 0.034008638617853006, 0.041890721918354114, 0.0786676000983965, 0.06732084968638036, 0.011383461345347666, 0.041572182559438293, 0.05984657797061148, 0.04451785191533066, 0.11754671547321544, 0.07403931820825224, 0.026943341025241443, 0.04540608489825841, 0.05958401282588321, 0.011077799924439, 0.0353452590324225, 0.026786758399177945, 0.04230069004059319, 0.08925334174907015, 0.03397597262876169, 0.03921230999572624, 0.07417159861013775, 0.03672242848082416, 0.044292250512948925, 0.022926404959552234, 0.032646944145521814, 0.03699849975565749, 0.02374295126496544, 0.02305160670901739, 0.051295094702753334, 0.0653115466176983, 0.052577874458004395, 0.03088755810993814, 0.019699883940179023, 0.021268832009105433, 0.04390615369043043, 0.026423805092851964, 0.03919072163802001, 0.03215412361427181, 0.07985981676967875, 0.019810432342872508, 0.04254264358971869, 0.03647881635134259, 0.023221701210845384, 0.052723821868459066, 0.08811157962848103, 0.0076399650424718865, 0.038292322668337056, 0.027182216816131147, 0.049154729311985355, 0.07153618720269973, 0.04590681528732662, 0.05037496947953778, 0.06992171052843332, 0.0536110129718098, 0.05857231711307841, 0.0031993177159869626, 0.024283052827682228, 0.0342371320021489, 0.017787148169572317, 0.09765045446974617, 0.022457158868952144, 0.008798140596838729, 0.019456080288716385, 0.05467981287849046, 0.060337640330075264, 0.0009831742593838324, 0.03734123217122209, 0.025330760418587638, 0.026371002482670932, 0.07146092672501841, 0.052324165289680806, 0.10987606860937611, 0.011370492434399504, 0.06603874025806304, 0.048677621244062344, 0.022569507578267686, 0.03749982003242739, 0.04285274065970894, 0.033957797192758134, 0.18361417636755975, 0.11144399012048399, 0.019872791899908936, 0.06890554852302998, 0.037667125974211006, 0.03861281555145979, 0.05026557595439015, 0.03860369910516086, 0.034916797547691295, 0.04836491564468992, 0.03341756731031403, 0.03125798651918529, 0.032723422703002734, 0.07511455325349685, 0.043636314540861115, 0.00926833950929464, 0.09123675104591156, 0.06608916416523919, 0.05940822246033819, 0.039032440211984425, 0.0708279695602194, 0.030696850097287568, 0.013365227383591477, 0.01674900710162136, 0.018229140682266127, 0.06402896987574716, 0.03986294846981764, 0.02610714456457044, 0.046085562752259356, 0.08097018460713087, 0.09039368660699937, 0.028060008020650958, 0.007273073565410151, 0.02911952677212896, 0.028192286507316658, 0.02848676687497045, 0.04167850024156994, 0.010480256131549757, 0.043449944501081784, 0.01725112410983251, 0.03056610378647043, 0.06608119685082667, 0.09661923117575147, 0.086299728061403, 0.04524154836432107, 0.04886950711689649, 0.04982902458117855, 0.06461662060070424, 0.02171802383306767, 0.027002241695299748, 0.0073586819757286825, 0.0743793233508064, 0.022068016846934636, 0.04018951643017992, 0.03464714608966343, 0.01957278420788146, 0.08143973521768086, 0.01621592290429098, 0.04153970809232804, 0.050179567263131185, 0.019616878313583233, 0.06184303374480336, 0.027552424975100066, 0.06954929220580286, 0.10584453856872936, 0.027769729645261844, 0.08738458517097658, 0.03947389454791143, 0.022750480528620463, 0.06197501920283802, 0.07516893783524152, 0.026597720458202308, 0.07049320445906732, 0.02742618709171732, 0.01953124883584678, 0.07090709878191834, 0.04133078059361827, 0.015390365489668425, 0.012643662574250373, 0.02370195598491738, 0.02650117422754486, 0.012727350976708676, 0.04853068558018535, 0.01200725514096238, 0.0929115494833358, 0.07018267071896023, 0.004864999228307317, 0.0795238029452101, 0.009702878944095104, 0.03018280318487556, 0.037005720134343834, 0.07102693791591352, 0.0015195976424541686, 0.0649065159321312, 0.04967421353343995, 0.03371255712643747, 0.071298201989022, 0.022356914348840233, 0.035558043783831025, 0.10331091726379049, 0.020511536858975887, 0.023871839812566197, 0.039661486497929985, 0.01128590196341036, 0.01084431547731642, 0.012268347481656219, 0.08986014467213424, 0.008277143351733685, 0.047840788930414185, 0.03523745130927813, 0.010057923350212796, 0.0347314540657305, 0.023476088366981958, 0.07353588352881132, 0.12151503559922981, 0.03949645200684186, 0.09170649317844261, 0.1337317248145419, 0.10601500845364026, 0.14153799222361657, 0.1308655907069483, 0.1516143007264022, 0.15580909176459237, 0.1166233190545632, 0.07888146120333865, 0.16143444474906693, 0.1701219890627169, 0.13615103047941962, 0.1634846645737848, 0.10880120128633515, 0.08212052691247194, 0.17025343442876495, 0.09187857950887374, 0.0871660279470586, 0.1447158168640829, 0.2361199887649667, 0.13399155119494086, 0.0860249859491183, 0.11177021334128034, 0.10210173174498544, 0.10345933147736135, 0.3526353890136365, 0.1164509492716001, 0.2551574575444383, 0.0811597760466318, 0.13189478386794368, 0.21691489994766253, 0.15147927006886852, 0.08769187069828473, 0.2416549127308592, 0.11054643384751775, 0.19219014763591752, 0.08031268198523792, 0.14034468770748185, 0.12279027321886633, 0.11947114366076647, 0.14287414149411265, 0.17089013010263446, 0.13681783340871334, 0.21158576251999026, 0.13981841594701813, 0.12808195660792052, 0.08939957261205682, 0.15858628306417696, 0.10692579506505882, 0.17853093784182303, 0.13571929396881213, 0.2198336183303787, 0.22118066137115802, 0.1643556146131408, 0.09109619689444381, 0.09829164707973119, 0.1278838845750978, 0.06048712323630049, 0.15254290654293953, 0.2210912589103945, 0.36440712670164727, 0.22784732702759006, 0.12820711239211022, 0.17822428816749206, 0.2023563795392552, 0.1395629256242706, 0.17577948709649427, 0.1010712898606735, 0.1425254948797726, 0.2063868447176872, 0.13731431967068103, 0.10062581739358364, 0.1214798491808676, 0.17216045709867633, 0.10801828241035824, 0.10198232928110708, 0.14647297741424653, 0.14599265560748118, 0.237416515968019, 0.16709869967833643, 0.16525084963969647, 0.13481935516240137, 0.1231810393472833, 0.13650505503098811, 0.1912445806327366, 0.21644064555725745, 0.12856527381846983, 0.13317390555335631, 0.14851346792232606, 0.14554040326226145, 0.1874774351956383, 0.13822665377970667, 0.07662213001880916, 0.20365229387196804, 0.19392945833744543, 0.1261382919525908, 0.09410084735962654, 0.1242870864488425, 0.1313963823861653, 0.14267489734676578, 0.14773541370466833, 0.1477017977665509, 0.23600211847693692, 0.16812208589286576, 0.11973127647633515, 0.13583082104882888, 0.0957860492710625, 0.14433796697806928, 0.14741753318136738, 0.10833403320922967, 0.11701588548960225, 0.1399872004384956, 0.10968128309374857, 0.07173827353624568, 0.1203299129021264, 0.20525775369136565, 0.1381790184325749, 0.1203727755214899, 0.17532965558911526, 0.09341894483734524, 0.11783712408355168, 0.2061435505146942, 0.0865163547437518, 0.15503656870174795, 0.2518308892725937, 0.2671755231436222, 0.18749079576903777, 0.16508489967353884, 0.12560556973180464, 0.09914300058998408, 0.14241098005685116, 0.08910794592192096, 0.2019498473213565, 0.1605792761209511, 0.16943073260688013, 0.20089987785585467, 0.08227465614195793, 0.13934514214915616, 0.19742658842475186, 0.10869519770025246, 0.2174125506632751, 0.07923562365073351, 0.11431037703709257, 0.0987396169934542, 0.2110223967822329, 0.1900159288197756, 0.1012634706773585, 0.15406386686428902, 0.12884845055880087, 0.13095330777427844, 0.18813239440562265, 0.22743583055994204, 0.07583290623921542, 0.1860641255494087, 0.14392682291086645, 0.12940470700062093, 0.1691627703727253, 0.11941632240890496, 0.16425473615527153, 0.2666792820297903, 0.1830285327929643, 0.1488908887991021, 0.08644100233551957, 0.11464464418109387, 0.1424435081501161, 0.1871500398603178, 0.19297324271211702, 0.11607329090756756, 0.18571774655532453, 0.1646530865541389, 0.17993655596529284, 0.14178220573211872, 0.14206308420867692, 0.1534445460645422, 0.24663359557669012, 0.13489222544575893, 0.13918244039579747], [0.010663068650530712, 0.11113302737113931, 0.026240882448731895, 0.0372307546316616, 0.07276231858638987, 0.044169615158030105, 0.025910418931274645, 0.049193727017770854, 0.06359078673525684, 0.021956009046745398, 0.015496923531886312, 0.07066571979873604, 0.047851652057180484, 0.0561150019958375, 0.012783093449299135, 0.02251755915612223, 0.04136528519372787, 0.035952264968786514, 0.03865615697577596, 0.01972030784424034, 0.12315833250120764, 0.0260509041348292, 0.06391326378610346, 0.02951363878955524, 0.029849254248303272, 0.07973853739038592, 0.01141959483990626, 0.08350127016104038, 0.01572542840750107, 0.02386726052199881, 0.04830020036728633, 0.08184406876323685, 0.025732761226414193, 0.06912800513448254, 0.06487614054593348, 0.02818033362047807, 0.03570108389061305, 0.08807735082002417, 0.03811607265003747, 0.06257840537375982, 0.08377924516436555, 0.027490760642854918, 0.05911728141889457, 0.07908259758785849, 0.012630500226101328, 0.024561340011836543, 0.01798876144382502, 0.048547642936389294, 0.009713782290477428, 0.12318670073704374, 0.022879472498091, 0.029991051377428156, 0.025015557372582056, 0.02548856878532998, 0.03866078797727823, 0.015643276011330948, 0.04128484213123879, 0.042292898926403255, 0.034682424438576546, 0.05652225816682462, 0.036750482620611306, 0.04399557913383169, 0.04818194320485477, 0.025371667598524404, 0.104066057791633, 0.04579901139462187, 0.011620736970085532, 0.014481440471905856, 0.019104823229774352, 0.02335825446812857, 0.04791540589423911, 0.03336741153391139, 0.04733063182943771, 0.05685031999863925, 0.059242215037586234, 0.020403637205280607, 0.03814057597229558, 0.01761342049576342, 0.05938994743290448, 0.045859061196566596, 0.06460558893459459, 0.006042894843455044, 0.05812320955878785, 0.03731220893021073, 0.024216956676795118, 0.012298549540461072, 0.08365072625418825, 0.03203708644685967, 0.024673614027579466, 0.022006224194962173, 0.06351192181389179, 0.03676848185639228, 0.006525376060556982, 0.04833744373172522, 0.0739459244294032, 0.03281133512275354, 0.021914540707404097, 0.07698959175256953, 0.05403343385325805, 0.07656618261769896, 0.06123867081177812, 0.07610435417342572, 0.03475635192326961, 0.03946254112487359, 0.10391090200432848, 0.009372634719306184, 0.02957459832091005, 0.006991515664624111, 0.012361409927478001, 0.06074542127129051, 0.007029928749562392, 0.034895197698666204, 0.040925577538268226, 0.07356456586069639, 0.025241783136622082, 0.013367910606546268, 0.07362714758323086, 0.05501766914441701, 0.017772671023023226, 0.044356280141660286, 0.0194438956602807, 0.021067958009699662, 0.023098998823233192, 0.029838138312521963, 0.05252511015221958, 0.008258684463198147, 0.023939027638745405, 0.031095411170334108, 0.05386159650140232, 0.051632207863393335, 0.04544151646475639, 0.06661958812225251, 0.045753038458285794, 0.08555971777006503, 0.020404709728374597, 0.014176904242635976, 0.04188382712703559, 0.03807957239088513, 0.02486910625931717, 0.05749911986171238, 0.0489663138174482, 0.05007003967259681, 0.011689626469066548, 0.06485383972645768, 0.028349007029206525, 0.027951560614089814, 0.036017746334114385, 0.02518671099096537, 0.004541076665308568, 0.02827647573975546, 0.01461915722522404, 0.013558493172299239, 0.055818824743431424, 0.06287475116550922, 0.04899959267687894, 0.03093005875275741, 0.014106911577043996, 0.01854864148152692, 0.04081382446231381, 0.0331671791331422, 0.05474066324231606, 0.05932354676206747, 0.0777863385155797, 0.03358086661225365, 0.03009075772077326, 0.04951289839922421, 0.0455698247007545, 0.021265466967898033, 0.02589157891399678, 0.03788516225834047, 0.009118581769026576, 0.013767814248680108, 0.0505561109692339, 0.018976015121405645, 0.1154889879868396, 0.014975297137073454, 0.03089613446425046, 0.05314009106387535, 0.01791315239613816, 0.043794159296779864, 0.016867534310046225, 0.07506487245160727, 0.02460358401520118, 0.035986302255262295, 0.050082829510492664, 0.023784071034301194, 0.06254359433848052, 0.03708729317652122, 0.030053518186773986, 0.1485563382025688, 0.06342128978200978, 0.07388346528093662, 0.04949291499571935, 0.04378081021469928, 0.03813178511336446, 0.05108657323064343, 0.0711663352746156, 0.016393084567220464, 0.06238671102290673, 0.020657055260192965, 0.044513186439871795, 0.0284894788262224, 0.012172409333288671, 0.0291456637768856, 0.0179989772262953, 0.03194737180526699, 0.020477122274197398, 0.08195594824369877, 0.04902764298622647, 0.09052266516993124, 0.03537796332591003, 0.03556857749278988, 0.013519137320409139, 0.038386888561710235, 0.008927107668451725, 0.04379486026723058, 0.05782570314383315, 0.014246570363250232, 0.07509036019684807, 0.09476237194312197, 0.07285393504125458, 0.027396949346087156, 0.06486079580481015, 0.06995771666087451, 0.02730600896381563, 0.03501571099003477, 0.03252929219255044, 0.05126837738639405, 0.011431864695623519, 0.04244648806390263, 0.025834239148084196, 0.02516327636136163, 0.06700837008294559, 0.04244370716473749, 0.05155235851904558, 0.07852643307658934, 0.010477799862142532, 0.04302115742898276, 0.030124534537354787, 0.03089438586856329, 0.05261570771014499, 0.04393390139504787, 0.13341897708033362, 0.02611776445842078, 0.02888080036838449, 0.029831258842961925, 0.04217133226413881, 0.05545882853649317, 0.0292277405218732, 0.06506517274124969, 0.054063077625488086, 0.05105021469775708, 0.01520581873914888, 0.03168252180330455, 0.0417467356929856, 0.013214378925641219, 0.02349070723979704, 0.04076545367077474, 0.013701879933867003, 0.06993415179632365, 0.0456297442677521, 0.06325600631234628, 0.017202891214119814, 0.019282613084801746, 0.013925463652178166, 0.013973955102565308, 0.07746340947285776, 0.03848678642703641, 0.1148981809796345, 0.058722960642508926, 0.028822131439923283, 0.057354608866115736, 0.0469348669773148, 0.04048431089388267, 0.055678569366254156, 0.02606401764487307, 0.04125941567303192, 0.05289937474674756, 0.07922355776592609, 0.04701115784325427, 0.060611585710918715, 0.0365251187054861, 0.03526735555140242, 0.032344469650378155, 0.015354302858242826, 0.03138836319257896, 0.029373220618694063, 0.04664446219741818, 0.09115494051647764, 0.035103129283074415, 0.017665399561425852, 0.039707325368879304, 0.10982787401805963, 0.04064784002219958, 0.05284952540551463, 0.046256212667832454, 0.008788769426304967, 0.03978965683810173, 0.03209818387404084, 0.05442631821478567, 0.08336060875726324, 0.03179661336264784, 0.014404949465496166, 0.011212271337787951, 0.03485241168809514, 0.057771241953296054, 0.017843187501233433, 0.044379492605765986, 0.03235582690385561, 0.02511302099352883, 0.06378326249579269, 0.14876197152320417, 0.042290435953726696, 0.03304984893709902, 0.023639357025404612, 0.020528586145730752, 0.022609319252472733, 0.04207464047677575, 0.03686675178487936, 0.036776092939920006, 0.022796926524249778, 0.028245313198215542, 0.05860289168213645, 0.01472525752990717, 0.008561170449660671, 0.06970691479622357, 0.029479101630708868, 0.03732784861518491, 0.04645694302575243, 0.006765169720540965, 0.014083608139997289, 0.017342095135621006, 0.06243716940403946, 0.015825824229978025, 0.0833191327570427, 0.030923956862440517, 0.02055691224673102, 0.09196016021193036, 0.00934071279311132, 0.009916872199204181, 0.07836900200814971, 0.019138824127073732, 0.018233045815460144, 0.056461323533327355, 0.008248909181284328, 0.016839378663609107, 0.03456640425288389, 0.05926570329334467, 0.017460275689260136, 0.06185954293957161, 0.07381403473235908, 0.02664517577467186, 0.10401620078952083, 0.18761048934632735, 0.08285180380147311, 0.1640241590118216, 0.15816873450192714, 0.17376867483460134, 0.15050515862962893, 0.29107473910816256, 0.11177043550677838, 0.2567199704748008, 0.1135107497834871, 0.22902362439180576, 0.14199851831841853, 0.21110416900727058, 0.06144808094588019, 0.10469619575287066, 0.17613044729636562, 0.1304548756489831, 0.1620452006858203, 0.11598407230790585, 0.2572585762508454, 0.12143576848170451, 0.12881927793064427, 0.11396609712392093, 0.1986232790495119, 0.18061702590315573, 0.11132695486829167, 0.2310938237895889, 0.11443649043118763, 0.15264979113013516, 0.10293501324110454, 0.18066106063704337, 0.09823552347839841, 0.17781406340579833, 0.10832023596571339, 0.1606462475272917, 0.1019316832084329, 0.20261635913723902, 0.07772325883589445, 0.2087526314801747, 0.14800348319113255, 0.07659147118007945, 0.176316897775377, 0.2333661171817972, 0.17983406872278263, 0.060902124556202086, 0.13688079051433072, 0.11267310924707882, 0.11119819847085785, 0.22437736241807862, 0.09442087292911545, 0.08543292255771738, 0.15951151809384748, 0.13292823647779803, 0.12331161903397692, 0.10340859347413625, 0.20373115496289348, 0.1948198823318366, 0.14319626614451408, 0.23817696548517675, 0.17377728566287026, 0.16426293329606134, 0.15044734963486273, 0.05981965764095226, 0.14799934631634146, 0.1446427627196235, 0.18644928391421997, 0.07879480899822328, 0.12710148663890938, 0.06813871749346295, 0.15709339220437313, 0.12941409923857258, 0.13467130101015493, 0.14063141909578156, 0.1068601796343442, 0.17418127446886034, 0.1566847609055619, 0.1499446274171914, 0.13761543819019872, 0.2104869166449193, 0.14273762462600587, 0.10197521998516976, 0.17416026833797657, 0.17270824060805384, 0.15708487330665513, 0.1663566209496029, 0.16809775494039061, 0.14128236400504268, 0.08434099445660269, 0.13058056003384053, 0.2562531624590197, 0.16752251483980687, 0.26177803535134564, 0.21009061936168902, 0.14062248651058445, 0.1833646768523801, 0.10980976369952965, 0.13001189296764712, 0.18882187353747507, 0.2283300083851622, 0.10341363433267801, 0.15196149177368612, 0.22422132562966118, 0.1294252688005086, 0.21694589586507892, 0.17468111619593638, 0.06823997899529434, 0.12208219347221237, 0.17309223451922018, 0.1433276502235282, 0.11281020068112882, 0.12424233159230602, 0.1751550028641378, 0.12474689242099563, 0.1596085661120953, 0.21162323954124607, 0.2571164822626499, 0.1561900213240616, 0.12194956833076094, 0.20692960269028143, 0.20386897418047153, 0.05687251739624528, 0.15678110412291943, 0.12466446902122229, 0.273286085575819, 0.08589656663037117, 0.15628086403012276, 0.09111921017568919, 0.16113864287974375, 0.13583163310202861, 0.13656143910221516, 0.15474619073492868, 0.08920023653415904, 0.21140360213335485, 0.15956604823229775, 0.20928481743941385, 0.0803837672837319, 0.06416187080885134, 0.1175810898383779, 0.1493002708640791, 0.07910880545574812, 0.13446675553437204, 0.12416944598718999, 0.08877837489689551, 0.11095658200041902, 0.16833420031734053, 0.10614430111262108, 0.09044416414033021, 0.10599287617350779, 0.1540333305996272, 0.09863456335639763, 0.08531292254525809, 0.1302645947303503, 0.16138539980015448, 0.12222981861522123, 0.21117895451043883, 0.1007167826737127, 0.10183869545618374, 0.19733327891557448, 0.14362913646524952, 0.11022830817608104, 0.16616630938745316, 0.13047260292355092, 0.156146997826234, 0.14510335010145942, 0.11230000910619575, 0.12095738487738757, 0.10962823150499214, 0.134794196834968, 0.12789913738567021, 0.12504680818247219, 0.14545458609298353, 0.14021408503815053, 0.16181244785266538, 0.20999920975056388, 0.0978054493785866], [0.05762387344974184, 0.12087699161061358, 0.05451530698807009, 0.022127942159591664, 0.07190196354302668, 0.07378343718066331, 0.02080303905982404, 0.011134352535009386, 0.06815222362356801, 0.031146955481099508, 0.015999935905358965, 0.04787358898489226, 0.11134609174464019, 0.03798595261609843, 0.05087119527161122, 0.06100380740639183, 0.048083117862622586, 0.00650908759487192, 0.041088528270202304, 0.055522463629923524, 0.030530028706116062, 0.042227475017669706, 0.07387329163330217, 0.0299856006618469, 0.05128733806251999, 0.0591847584432652, 0.028355484302606315, 0.018497064612024737, 0.007261721099982219, 0.070800980282647, 0.045251902042617725, 0.0202044217862309, 0.0015343365756111341, 0.017360195878051946, 0.01856325652390238, 0.044369552614948446, 0.05511892681580879, 0.007311671469060164, 0.061608277591726476, 0.019545511477777076, 0.0387433416119987, 0.021354683652339924, 0.0424367472559454, 0.042222962759795694, 0.04161575764057137, 0.031529152916083415, 0.009275836637243629, 0.05982014027634456, 0.016876365388593367, 0.11258202139288188, 0.03231864865689028, 0.011198483670370714, 0.05447536699413773, 0.049784859612343774, 0.020815336686228553, 0.03675335161988774, 0.009446133194761652, 0.06229836193303909, 0.023487717581672535, 0.02830600651401666, 0.08508718707748959, 0.08207585632560715, 0.021944176818754886, 0.03663624741978223, 0.014038621541863729, 0.0316482029795166, 0.0343516391641911, 0.03737327379865512, 0.03827177235976823, 0.014608907926407073, 0.02033435221340868, 0.03737094489136531, 0.026438607826768875, 0.03977372987015594, 0.043516594150494185, 0.03679971909150481, 0.07303522208765631, 0.044504368767863324, 0.07143864122730109, 0.03650302089931023, 0.045889704713537816, 0.029886809793571313, 0.037338290393592856, 0.032782396151413845, 0.013900668258898923, 0.02160530931676828, 0.0744227605361131, 0.06689139611778722, 0.013152697356417777, 0.04107996340720885, 0.10411632082034504, 0.03773307848361231, 0.05080238142381272, 0.02261608189362432, 0.07824959188339212, 0.03471402556545312, 0.0207619575948845, 0.019246641426317154, 0.07135539045256954, 0.04764309611111399, 0.015832448975303243, 0.012925638471760098, 0.09224431754480447, 0.035786096667570454, 0.04045306216745127, 0.07686194618262591, 0.025625148855690515, 0.035971578045357624, 0.025849656667560342, 0.018315501773970264, 0.03178701236573679, 0.028766720300360073, 0.10244885384435616, 0.046774800566415635, 0.02766426040550634, 0.020310348763521162, 0.01987861799857309, 0.0531181579666032, 0.0076444749063211345, 0.016964312282300765, 0.03734137006704846, 0.01371521465179901, 0.05424673571401546, 0.01563919563552425, 0.04917421092789981, 0.04957667138848094, 0.0740859882845994, 0.02891900517316836, 0.08595755489002313, 0.023754168707396717, 0.017084318040419492, 0.038284424301837726, 0.017032697120861664, 0.009848539071578172, 0.039034788271472345, 0.05608594428086954, 0.02661674050614238, 0.012060347906944734, 0.021389839427185156, 0.008010863638182562, 0.027280586336048383, 0.05090782959615031, 0.060369095900246215, 0.0177350101406656, 0.031102980119026, 0.04697584118994494, 0.0435943597356879, 0.043794733862723076, 0.039307703264057636, 0.02565378713751993, 0.021402717365192312, 0.039498941792595776, 0.04977667013243322, 0.11414510888918755, 0.03084429520963421, 0.06212565890182892, 0.06056678871954642, 0.026559693768860835, 0.009239724210102954, 0.04431968029107779, 0.01665239192305073, 0.04988026437199405, 0.04664777935813031, 0.060595222072856086, 0.05802780096869796, 0.038541040773833954, 0.04738470614557305, 0.052273457929972685, 0.02310218383377839, 0.05817997284353741, 0.11609969029743826, 0.059789243950358326, 0.015017390795682949, 0.047596042990804686, 0.052721385708859855, 0.033747915914582635, 0.0234028599375198, 0.05669321834800705, 0.03512974700800354, 0.032610589443075086, 0.03782338875856611, 0.06147381766969639, 0.04188652375652906, 0.01612086096898683, 0.02586369139833316, 0.08931651335930632, 0.017828493934845733, 0.02376646633380123, 0.026483106043850704, 0.06070009184881084, 0.027764305742757938, 0.019168992669531898, 0.024146526383476394, 0.04197016140566238, 0.11919460124185971, 0.06320646340628305, 0.0594217362513225, 0.04109346570687429, 0.038667207794083704, 0.030858490818871126, 0.05731403301920622, 0.03184078407714204, 0.012581399735814382, 0.032956083605606715, 0.08662132411113671, 0.07461335555079483, 0.03821384845181339, 0.049999494466089436, 0.018317219726140463, 0.05544919881128496, 0.00866140730889334, 0.035305924247950315, 0.06559762683126234, 0.08979579328649467, 0.011064363699857027, 0.06431070637078055, 0.021606623157558423, 0.008570750379153799, 0.03814826366461573, 0.07474503074322017, 0.02183012356380782, 0.026408318625462633, 0.04850660743672521, 0.019187422829770276, 0.012442391166733879, 0.11962979280900572, 0.08082245221181263, 0.02646263425929412, 0.0437528403445838, 0.020907575587531733, 0.025182231291828137, 0.03379770779922124, 0.028140387880886276, 0.09871708634760111, 0.01581788755908248, 0.08632490171059486, 0.045698922007314624, 0.012555499260704364, 0.013494505678423712, 0.013656755439907074, 0.037930729168076674, 0.00829816288915613, 0.044174621542615276, 0.03029005740949464, 0.03332712296997348, 0.06089648614907938, 0.049940126482397325, 0.06991716762704235, 0.033505437595229, 0.03182450662397089, 0.060904499428767356, 0.014927453030982326, 0.0668177827291431, 0.04778144775979942, 0.04720816884430186, 0.04904342056702703, 0.14054436086406633, 0.06836947849801472, 0.096569144347262, 0.06638039248965441, 0.018282897071912885, 0.023627896350057378, 0.07979017937736166, 0.05495385402032445, 0.033821322459487185, 0.06158826354470465, 0.0004801401601364506, 0.05476428939390087, 0.06305961201207773, 0.060209159724294185, 0.17207290857068955, 0.025868709274237196, 0.02644673601964549, 0.03764352663570354, 0.03144271330036704, 0.0649049224692487, 0.03084820608848766, 0.02391802916874088, 0.02950992134790267, 0.04552038138612144, 0.07674864943950407, 0.031368383619513725, 0.03789035633446709, 0.08772121186578467, 0.0489041572737117, 0.04580305633886207, 0.04110991361460859, 0.039224188188992204, 0.10070764324477605, 0.022874671042025573, 0.03368384415103543, 0.01830369061339767, 0.03277735146243246, 0.09156428427705843, 0.07563229079448408, 0.07276230326463139, 0.02085977361627644, 0.048570587269721494, 0.01896868174475047, 0.010623179409923333, 0.026681381089973356, 0.0669877699786617, 0.06288004866350563, 0.05075681451407652, 0.03167202065308248, 0.03352565848599038, 0.018983304448005174, 0.03373342153105525, 0.04535071206309142, 0.011450412641880254, 0.06868987945058654, 0.0632088880745634, 0.038568321164817586, 0.015178841910505248, 0.09458251748113863, 0.07572411409308834, 0.05957937033306207, 0.06037925422612218, 0.043230644171877254, 0.027137260861514557, 0.03887272620153043, 0.05901511593331253, 0.016126669830672683, 0.038691967755796454, 0.05081397233410709, 0.061640717584880135, 0.021239351030559312, 0.03653546472290351, 0.04216298573620377, 0.08021439290455273, 0.027256075352911028, 0.014989061821852962, 0.07568033982909496, 0.019845726013544108, 0.027967891693415663, 0.014190340467217951, 0.020499264130428917, 0.03752637647032257, 0.042778077730608564, 0.05254246204370453, 0.048825717531144626, 0.046642681042994225, 0.05654452451234383, 0.052069410411340576, 0.06223550824929149, 0.0544864216428851, 0.08771260869839499, 0.01672639601653622, 0.07595773260559767, 0.02311929057712757, 0.06241707874822521, 0.016022925246356717, 0.15564300390260835, 0.21920772449624157, 0.15293652251843484, 0.09384302046870995, 0.16297661038416048, 0.193375714664017, 0.1310223476180146, 0.11383066810066662, 0.12440854968923716, 0.14600347276897202, 0.07747572816668019, 0.14769223698925588, 0.16291034377871022, 0.19615187940578308, 0.13167696974931226, 0.10487219679259485, 0.1404889267418654, 0.10349103985654731, 0.36859336819860244, 0.16955447112840993, 0.14612353406846523, 0.13051397167146206, 0.1288701155252995, 0.2754140633248514, 0.06568388833153634, 0.18814178664357434, 0.09083203445639342, 0.1326199473753091, 0.15684232986982793, 0.19199013740064638, 0.17437005385516152, 0.11961045674979688, 0.09744102135300638, 0.11412538212513733, 0.10719761072147278, 0.136502526940838, 0.12215731605406731, 0.23419438080201227, 0.16896891948436538, 0.15476154313693125, 0.08934132694717377, 0.13310924773254704, 0.12975503900839438, 0.17617183136603526, 0.1274078528607084, 0.11485715697128927, 0.10772569044943779, 0.12392266608414151, 0.10916585147741342, 0.26553186618032, 0.16508954216636, 0.1867123278639009, 0.14448245116058858, 0.10834425282213958, 0.06448895204812288, 0.09385262721128042, 0.15077017908615453, 0.2974615834893719, 0.1246536978250069, 0.20554589468144602, 0.19432541854198904, 0.18401669428473522, 0.14874252821168593, 0.13613911015131783, 0.12871303685730504, 0.10806709753289338, 0.12620500288903713, 0.13319278195981057, 0.11458857420591578, 0.17696430335842794, 0.11046608654601921, 0.1874429459172872, 0.1314608869893897, 0.15042891755940455, 0.2186819123885324, 0.1113853767333973, 0.12917383874375976, 0.1614020085863529, 0.20859081838880816, 0.12328082996030008, 0.2561009254667067, 0.12151708871486688, 0.1316103813869338, 0.1393512708525504, 0.14854585811976465, 0.13290468693500565, 0.2495176101764364, 0.1852711326172275, 0.15379780452818642, 0.12409996947333699, 0.17169749484427516, 0.09514615134966951, 0.19264776259660724, 0.16632387835171916, 0.22669396633582733, 0.10157616478541207, 0.14719561283146182, 0.13791588255234305, 0.13188102492882361, 0.12811723495683364, 0.196295153169382, 0.1092018039836999, 0.19796003076818683, 0.08978800217230475, 0.1793839307802339, 0.17827728613009378, 0.10183979096191545, 0.20419137462252573, 0.20755983258207, 0.09739239775245229, 0.1292966579597804, 0.12053969841931136, 0.184175550276714, 0.23545117868531137, 0.18919325764140776, 0.1748798853687702, 0.1338029709915, 0.21933095739974132, 0.14690903466074698, 0.21593936358488378, 0.13211828235897327, 0.1868272257307845, 0.1368289723271324, 0.12129224190909056, 0.13198700553226855, 0.11028458499499869, 0.2285869389532074, 0.18742053018462274, 0.205789725145986, 0.13799878858750866, 0.06743768575571238, 0.11306386005373732, 0.11534751452986272, 0.25551793255632926, 0.18419847162740846, 0.1533983356409496, 0.11208237884866615, 0.07749571540062467, 0.18093335892884962, 0.12958254665136337, 0.1432262967911459, 0.16069838747141824, 0.15731390295249803, 0.13102898193943885, 0.13119157644048815, 0.1751560447437148, 0.1095125369066673, 0.1614156449514051, 0.1321687215879079, 0.21182150309604986, 0.08081917335549671, 0.11389723348040735, 0.12475898894932001, 0.24738865183486095, 0.08657401052093314, 0.21136886770686797, 0.13885812473393258, 0.07451457617383811, 0.09533150632294918, 0.13138671435656088, 0.12601430828292526, 0.1308902127728347, 0.1355132929259731, 0.08366695965730375, 0.16845685099401783, 0.1710767337992307, 0.17790538108637258, 0.14146034155161152, 0.12337761750865368, 0.14891275294846104, 0.2171443739245015, 0.22355545732763507, 0.18567950344614445, 0.07931549597771899, 0.17206717823301593, 0.1193949791993345], [0.01541217409765288, 0.06558399046621015, 0.05056102542326816, 0.03347264520163017, 0.019107824379217722, 0.04000434914844171, 0.03854456094784602, 0.00799236261481119, 0.03896173795745258, 0.09223841866778751, 0.020449246249852643, 0.0366929417566186, 0.05579336381126797, 0.015734518040722657, 0.053950949166450775, 0.057767009317514405, 0.021969381111463713, 0.1398550809150742, 0.008757859693780061, 0.0573227281171468, 0.06227230728273431, 0.05650489095358118, 0.045887421771523454, 0.027679605146629677, 0.03262378913801044, 0.06445866859247608, 0.041539681279250694, 0.07264544421266164, 0.028404701621301716, 0.050922343131875804, 0.012006453621471602, 0.016476557507450064, 0.04449948878778566, 0.015553821839632527, 0.040806711335936864, 0.03192631779388795, 0.028924618682433522, 0.025497861431851506, 0.05551991255713567, 0.06464753224844895, 0.07160562541215651, 0.1126738217088484, 0.028551844128918265, 0.03576742327441612, 0.02994047233744735, 0.04867281787277711, 0.030861873097056826, 0.026407933666280685, 0.030317169261134924, 0.05687681131906087, 0.0175567357350261, 0.03932302502254325, 0.05563110638890536, 0.029854141889260184, 0.050285226109647946, 0.036425657510276765, 0.03265490762949471, 0.054327994660143895, 0.04765397072919915, 0.07849758220536095, 0.048589678180794564, 0.02022075095033694, 0.02318732876090273, 0.012218399506603039, 0.01163900242142019, 0.053345793332423896, 0.05381059802828297, 0.014359066544491199, 0.06107733269492465, 0.03318873684733145, 0.02933899564067683, 0.042937883671613476, 0.03311673607376795, 0.001326859616505493, 0.055631661802650466, 0.05507684943656768, 0.06439851536866158, 0.05474301896268322, 0.054709077437197974, 0.07345244889297793, 0.028648894062385927, 0.043821749953372825, 0.03211008888038416, 0.12856836881368391, 0.026772767718460773, 0.04099405430738003, 0.07331929515085875, 0.028420783722052173, 0.07290543913240395, 0.09529425146719141, 0.01500421121055561, 0.009173750633283729, 0.02376624991396262, 0.049497683893048, 0.09231958568336503, 0.05579693378099511, 0.0476106139831245, 0.03306701696748215, 0.033591553538797364, 0.04674015040960043, 0.048943545684338584, 0.002859986491403693, 0.034058779072497165, 0.02394212646439912, 0.013544743809278214, 0.03573161249439563, 0.014794890134174739, 0.03834031807679323, 0.03385355560890129, 0.029305075182609504, 0.03327783287292527, 0.035826875527779904, 0.057165239592112845, 0.017021671200411457, 0.046760800309599414, 0.03097870725116903, 0.036812148868076267, 0.029784632816670403, 0.010124474365804947, 0.04011679936440722, 0.007425966041703379, 0.04879785108289892, 0.03308642580504379, 0.04339421160459038, 0.12192124606020029, 0.06097506761791245, 0.002780959494562159, 0.04100905047849782, 0.023705108436725797, 0.02947815168168276, 0.028348459276340665, 0.017282773117204348, 0.04026171638660374, 0.006333094216026967, 0.048166609955050295, 0.008497456832218074, 0.053446740738206336, 0.03689786644592401, 0.09397254295406804, 0.05100684646036356, 0.12877907363637803, 0.05281233949767006, 0.04350210742784604, 0.03457498826807545, 0.022647859220723474, 0.05632974793233218, 0.025638587953102206, 0.060792409274126255, 0.024042411204127055, 0.019937350129288052, 0.02883100082286664, 0.11756161588334268, 0.035654417644705505, 0.1513461239876286, 0.06927035193169309, 0.03805165997736397, 0.027085218593598376, 0.010985242139037338, 0.05900991419630666, 0.01809550430475464, 0.023119246527071924, 0.008841089401093703, 0.051142861540879936, 0.04261726438398323, 0.020355205126707594, 0.03591594090985675, 0.03505757386465708, 0.03707157305231498, 0.024459687805163766, 0.0198734296681059, 0.07152911621115862, 0.03057645171910765, 0.04129963528905665, 0.030843400801982612, 0.039366469868729194, 0.015340330372113856, 0.030191743430951913, 0.017317835046278856, 0.07570071776788082, 0.03412763888557111, 0.01370012176208078, 0.004552983586871696, 0.03641786639608684, 0.031366167710192745, 0.01757487478185325, 0.07328484417690385, 0.05834603389244407, 0.044408033211385055, 0.04626606838897832, 0.02022381338681425, 0.04072244932514526, 0.06608772391994154, 0.007741660341590404, 0.05753426797567837, 0.040781392130039396, 0.034081233109557824, 0.028947769859505278, 0.04574641179774077, 0.03202737628241941, 0.016661290034291246, 0.03758064230843898, 0.01667361830421273, 0.16597593653826945, 0.021010275419440963, 0.045036918618866516, 0.04431832048501219, 0.006193312376947894, 0.008569487291688641, 0.04723292114513536, 0.09854437948595132, 0.09768771698638316, 0.03558354685083032, 0.06683325770521356, 0.014877699450739931, 0.0415022770363477, 0.050694600513745705, 0.04842426447618393, 0.05955020153534509, 0.0340949192703251, 0.018498546992158218, 0.08406209248688915, 0.019628245143159744, 0.028760030437561295, 0.05955353784825533, 0.02940544610722892, 0.018742176358618082, 0.023232596896348462, 0.038239623480025804, 0.0198501635778455, 0.08621407943146844, 0.05247383205700786, 0.016594339695368564, 0.03324273455467436, 0.049087757905644756, 0.03111530264328805, 0.1002931896777403, 0.047130318989436475, 0.011644092118067127, 0.06093881250689588, 0.023315453135799018, 0.036053641383806546, 0.01754881247066923, 0.03997486625467578, 0.04044285787629985, 0.017954662870315295, 0.025694638776082187, 0.02242772577090129, 0.037454482949068474, 0.08144587158195435, 0.07125479544723226, 0.048925741800978306, 0.031075567577875433, 0.0894139597432748, 0.03952306590133137, 0.04507034686544249, 0.0734591521623154, 0.0178925599527335, 0.05431202938780189, 0.04625952982854459, 0.025406256468305667, 0.021268475778220643, 0.018796859714653225, 0.044854754401791486, 0.043761297955267855, 0.14362495362518296, 0.0494178805139757, 0.02417423578369762, 0.04252398551832284, 0.07604096805857075, 0.05430732943838643, 0.03609442790489524, 0.07126208094339218, 0.09923113900567256, 0.002776160193119018, 0.010361045189652472, 0.02799454580752119, 0.0577849242836237, 0.030654675041836117, 0.07780568989654703, 0.039562569225146886, 0.036624120247940865, 0.010715678781120768, 0.01150218677902294, 0.04409424359759977, 0.030535046582020102, 0.019689645175071015, 0.10101921120358091, 0.01648649558304779, 0.04992961575607619, 0.013111060477733133, 0.06379533221103972, 0.07926528657516164, 0.09001515490273315, 0.040056994710598266, 0.029681883189046097, 0.051808871569172035, 0.002905270666815341, 0.011940699337320703, 0.05285902489577571, 0.043979430000387856, 0.019485044157913616, 0.0530231247595962, 0.046649889930361704, 0.022882902656771967, 0.022272524018321308, 0.058748436896430875, 0.01667044861542602, 0.032052565253369754, 0.047504583583964456, 0.08993723609995458, 0.06880851582654061, 0.023796276730154792, 0.0037034090764204706, 0.0434213119649118, 0.046564455805045944, 0.031052368520308408, 0.08204302179717249, 0.03909960314030609, 0.03587907675894038, 0.06351954055829875, 0.01567909445223068, 0.03581734539400186, 0.050408623722051425, 0.027376563746422052, 0.0456351145441013, 0.03237747271815616, 0.06598205741254554, 0.03055064796259807, 0.051942848855809826, 0.051823243378631534, 0.08122997268313363, 0.07180392727135651, 0.03223825539011629, 0.04560377388711899, 0.01831732314801024, 0.055329819330044334, 0.050426485062006025, 0.041503181020098354, 0.03543803611049249, 0.026486377239287383, 0.05548117149080481, 0.05513105781808977, 0.037806274354337685, 0.04390138096266216, 0.044798845305077495, 0.056062333451043216, 0.02954513457934222, 0.058675957317914695, 0.09520916208144158, 0.03224815707653761, 0.03435141699869306, 0.004337030583091321, 0.08999567328681869, 0.07862397905198798, 0.21256868397035908, 0.13302962055369733, 0.06201705827768292, 0.14487081177292332, 0.28997203214995326, 0.16597071181862585, 0.10565918359544971, 0.1395551421709599, 0.12828824876417078, 0.17126120777139742, 0.19643448924105014, 0.10847841013943958, 0.16854344957297848, 0.30548595613048923, 0.14563107742897927, 0.2204548849934532, 0.12019009419506597, 0.17654460974999014, 0.1674661767338553, 0.11315610470069994, 0.11014603033301332, 0.0956762688715131, 0.14048955493396328, 0.14670723177973302, 0.2508635040853293, 0.1202286667220535, 0.12736780944490625, 0.15628492429612145, 0.08138588689748319, 0.06560744041757238, 0.12481170345938976, 0.24810019429893265, 0.2707556052313697, 0.14104944263254443, 0.3047427282698693, 0.13591331339651538, 0.10130780418553662, 0.16264559911383739, 0.1687596855504859, 0.24433298757480038, 0.09371755824935052, 0.0782067982119418, 0.1201699460826574, 0.09691165459732856, 0.10879992191950161, 0.08592816009636849, 0.14976429031981578, 0.1574138161395827, 0.10446335098916486, 0.08479755987683613, 0.10883007514020128, 0.13031310341771574, 0.15030243644310584, 0.10609872654200563, 0.14282183301064277, 0.12097935627905593, 0.0741916164875992, 0.1718892160082056, 0.1048726717671079, 0.11070224847043715, 0.1410117970719453, 0.18612443199080808, 0.13879873759804234, 0.11071570097438752, 0.1411800146583588, 0.1539065430481588, 0.115069868944345, 0.09494391945941795, 0.09893110067012811, 0.12454229331905804, 0.08469316507539443, 0.16708946065796962, 0.09281424865607293, 0.13769970786186958, 0.18548157697002735, 0.18274670436738, 0.16114798915241996, 0.2542260631678566, 0.14364091889752498, 0.11383980752960329, 0.08930889844533899, 0.17099110049105462, 0.1499822116907566, 0.09017415645141756, 0.1351993041293275, 0.1029322323419394, 0.353082079560526, 0.1539003683794891, 0.07701072811840043, 0.07904649952486639, 0.171229736879468, 0.18412949307070625, 0.27117912927942894, 0.1530698831042936, 0.16827803075073228, 0.16243930695758713, 0.09536702981999806, 0.2023945920049183, 0.13538049924517834, 0.1612306653612083, 0.13558309885763353, 0.12406862881635466, 0.22390439505538634, 0.09898070486322527, 0.07463876668724322, 0.09447285965565713, 0.1374002747357853, 0.1504042648500012, 0.15125330477472276, 0.14609172609784912, 0.24289154717999123, 0.11016240163195519, 0.16680406226265818, 0.17116350091753468, 0.1524928963232425, 0.2895906735812464, 0.10528298079847329, 0.07775178795019466, 0.08670157182120508, 0.13146923734776436, 0.11850242548051382, 0.14569521431000004, 0.22587961487231717, 0.10501857321228712, 0.193596133481591, 0.10621794514478215, 0.140320050319837, 0.16452567081057257, 0.13817198574543, 0.19795860584464767, 0.16271257052017798, 0.16669975173088813, 0.14059001970435345, 0.13221572874294174, 0.12830827430251146, 0.13747093868592095, 0.15926359671979182, 0.20903352527849137, 0.2473168234310804, 0.19813730351386533, 0.11324401329001112, 0.15067550594047194, 0.06412265859844704, 0.157106829386565, 0.16482613049447536, 0.11602564023867731, 0.2050687291569287, 0.11829867673617218, 0.1558635759377672, 0.16303688618204287, 0.1950252705043362, 0.523047449608003, 0.13918648534003766, 0.1620976777086335, 0.08067010796719021, 0.1530887135454724, 0.15281013333268706, 0.15068776334726042, 0.21006227410849065, 0.08452284840806838, 0.16700698363204158, 0.11223784107114039, 0.10275001066827005, 0.18934174080289182, 0.08539119374848182, 0.08429215635142981, 0.114555609442534, 0.12274984675910204, 0.14439525503304698, 0.15907546084734703, 0.18852878361940387, 0.08114824642337139, 0.09453478254257672, 0.12761182377054808], [0.03255288003973904, 0.014066000566667607, 0.029298191882609844, 0.07080125607429974, 0.04340022539479598, 0.06166212974236377, 0.06453167677166001, 0.03411460006909986, 0.02817648211343875, 0.0026981056491363676, 0.01664969337833745, 0.10876932436780584, 0.07681455598362992, 0.047737650513168306, 0.043152759843055284, 0.04226387568539189, 0.019461904472160726, 0.04295987422547994, 0.012957284606302218, 0.028427605735017892, 0.0619967071519744, 0.03964199339069667, 0.08694095131490501, 0.05382595426072517, 0.060488153624558644, 0.028692268045438875, 0.03132493877332778, 0.05406882328492019, 0.01681800672574149, 0.079127291157361, 0.021646578473249273, 0.0848159536478981, 0.012371546228326136, 0.07784184158569382, 0.06433433252236535, 0.027405152232536388, 0.01917449318082823, 0.041885577637942574, 0.04418397930661037, 0.024815424563243024, 0.04007056978861651, 0.05261268932372332, 0.04946955697490804, 0.058114644695794394, 0.06390347318243116, 0.026376414893855973, 0.02283385962307934, 0.016832989490320607, 0.027506088146999962, 0.04858930279771167, 0.022824116899902304, 0.03568461300024102, 0.012831931554472015, 0.027237442179372715, 0.07768159131369284, 0.07295816130335293, 0.028570272373936834, 0.029974551758758967, 0.06563420752964674, 0.06478149804376787, 0.05449173446263998, 0.04151405180774389, 0.08640222296479248, 0.020355620729406516, 0.016894288015581908, 0.04888767872246043, 0.015574883511890809, 0.04949493363739983, 0.05694700412512307, 0.0714356534843964, 0.04767387369347196, 0.01959168742741308, 0.043422104865913434, 0.06532127593433665, 0.050318244499184435, 0.05072849607395549, 0.01674796905248396, 0.04506039155286647, 0.0820290636751921, 0.01072252473433412, 0.02235987527866758, 0.08214751619004435, 0.09409095716452408, 0.015918298703317922, 0.04957466423811932, 0.03181159229678733, 0.019207837157732537, 0.025551430129956816, 0.03427722904410574, 0.01121073533149977, 0.036129901606229045, 0.017912698489043023, 0.03920721551102977, 0.06111338862308091, 0.07494721666819627, 0.03120893007895399, 0.052124438506941644, 0.020561591128728563, 0.06673263205635933, 0.02345992008134002, 0.004640039903367119, 0.0290703343512911, 0.03151315508500463, 0.035568110179156065, 0.04299225293159966, 0.07677690276215154, 0.05291771489165483, 0.04020483052778629, 0.009117683530935358, 0.051430657791394385, 0.06721795641727026, 0.09705529608313115, 0.013904899937070668, 0.05832075299094281, 0.06543336225853813, 0.044970023821318345, 0.0513162080859465, 0.03874022363414688, 0.06494777742773294, 0.014390950166289846, 0.026567594050579978, 0.04219411954944653, 0.013160226085493642, 0.013889354097867205, 0.08712132671667684, 0.05066521721140993, 0.03752171865574295, 0.04623092793589158, 0.06170068694759281, 0.06778996362681351, 0.024632691525884216, 0.02017282065935433, 0.03869572541706505, 0.02394674214414291, 0.03955489685458522, 0.057828284860137975, 0.08555020295804547, 0.03227953220747652, 0.10125684401681347, 0.040710758823420734, 0.04716126511113779, 0.004002867100362276, 0.05972892218720048, 0.02406620781027502, 0.11099027454732888, 0.05125695501544303, 0.018898827932594765, 0.019034933028442245, 0.046217758884473194, 0.059027338866144426, 0.10846727122102054, 0.02563395312116031, 0.024256025245713613, 0.03239208584531181, 0.0269183129327552, 0.03351625092628022, 0.038841197853006666, 0.031240498647093776, 0.01728941318428805, 0.039267242330336766, 0.02203672981610702, 0.040530153595271616, 0.024814066672397238, 0.082849528520338, 0.013012499435834829, 0.039306251527441126, 0.036465279577720555, 0.043918897563050834, 0.030917839650365136, 0.03079133363620889, 0.022423320765336676, 0.03608271059009337, 0.03580319958048002, 0.05845105688598368, 0.032004659860244686, 0.016147317815451853, 0.056016433293059956, 0.03684108400897634, 0.014769318119262256, 0.024456512370717623, 0.007871739198303512, 0.06385884856084181, 0.05702668109968786, 0.029155103895332546, 0.035844625784985484, 0.05740456162921845, 0.0036110559801360775, 0.03967549441562545, 0.05023336578761378, 0.07148964736129969, 0.07512290361187152, 0.0673157015755292, 0.03190229327658252, 0.018449812308855115, 0.050117418380273934, 0.09394778299235529, 0.09521735922223139, 0.05098468353671413, 0.1340727411931561, 0.02896254578034484, 0.009731612986915055, 0.0509838561617559, 0.011218358863956265, 0.02894695397586592, 0.15552108867033837, 0.055110404087651166, 0.014230728622586017, 0.046999157075920416, 0.08886500411937315, 0.04876304004761962, 0.09977121567053181, 0.043850742550867225, 0.014536687860175248, 0.10391415787800666, 0.02433781853816923, 0.024200864999945608, 0.01740094600996423, 0.04249943240034965, 0.0795131390013041, 0.03971481004789953, 0.03678000381877346, 0.024864781692984606, 0.04629711410210979, 0.03328580401777741, 0.011410381675006883, 0.04475736547441733, 0.029205133267227682, 0.022941416452428507, 0.027206055557114944, 0.039134494614817446, 0.0969463813629362, 0.011645649191773227, 0.051909795992316744, 0.03722669819610254, 0.03245052686261554, 0.023377117468044165, 0.02308342425573257, 0.04588908418231914, 0.028325417266798117, 0.0531040198139606, 0.020439158787109682, 0.08505030760481473, 0.08142959221356338, 0.03394383524033812, 0.023755231654391657, 0.0031576884981815616, 0.06696954474694307, 0.03719455314679973, 0.027793382609924002, 0.05611177676567628, 0.0450139704550947, 0.020135899051843632, 0.05546082802597554, 0.013942053286178459, 0.03798386885694439, 0.032901304488581036, 0.03502355956081902, 0.02149861050589431, 0.07742433132784021, 0.011710184438514614, 0.023209439973617275, 0.01026676370642118, 0.022434381159743475, 0.015295652124369818, 0.05948611061959978, 0.04708039686985074, 0.02833109780875666, 0.02361673444900061, 0.07544853694496617, 0.07316456837279182, 0.10816619866677832, 0.03767385605662581, 0.0853294087573886, 0.0869814697052202, 0.06069263398286797, 0.026969681043298017, 0.015664839471179633, 0.025635251640191963, 0.04697910089406276, 0.02285603786848726, 0.026788637229812243, 0.07065795932806308, 0.04534002513654771, 0.006064752768349624, 0.016944631483526002, 0.04727069311024201, 0.038217640587038575, 0.06844024970045975, 0.02646421814607757, 0.038488575242339604, 0.04282153023767375, 0.04791039184877469, 0.010878941693883992, 0.02528387200718205, 0.03899439628566465, 0.03748595384099791, 0.023472342197032228, 0.0894790159298047, 0.03312401007860899, 0.021155749770602392, 0.044644287066353906, 0.07420479319989681, 0.02102801993098711, 0.024182850442406152, 0.045788316807198914, 0.03261568392777155, 0.05629502116672455, 0.017683320273194584, 0.05306158237339509, 0.034853675733170206, 0.056839931846386006, 0.10193942069646814, 0.050275558080043525, 0.025823722676103635, 0.07578225250566199, 0.033721995329664606, 0.037839131865410075, 0.0443651591007027, 0.03875833012223725, 0.031642202595849676, 0.048663180486689654, 0.0280919443109944, 0.0803534148801719, 0.0074476712278180555, 0.057314691854821104, 0.039757461993083845, 0.03634549406988006, 0.010959089812522214, 0.006004072380282226, 0.046898454818273747, 0.02682829377121262, 0.028684289239707495, 0.047921756763131394, 0.03162353877879439, 0.029212405356848915, 0.06893668999715198, 0.022782298075335643, 0.05381981023557244, 0.01848199949299376, 0.04139961742405449, 0.04363994962806183, 0.0391105581976233, 0.03196662551002397, 0.04458239865339091, 0.034236381235983104, 0.03997779654098615, 0.04566345979729968, 0.007966722609595427, 0.06303223969054318, 0.019140861920952316, 0.024515054894671328, 0.09822892746137035, 0.18784969263980467, 0.104709142638791, 0.08798434008513728, 0.1553222735322291, 0.11745871495335333, 0.2268570051678727, 0.14935185922490013, 0.12963559057924057, 0.12369657055504861, 0.14586140942429343, 0.09798475991814368, 0.12596122605065185, 0.1601974885430067, 0.09101101557814306, 0.21759754557523037, 0.13050672447969838, 0.20202405059770231, 0.269922653153058, 0.10865985040342617, 0.19726476001162685, 0.16393918453926043, 0.12406987753967125, 0.23482980476992749, 0.12499946394875167, 0.10002404766818208, 0.2266612850249775, 0.18914438123183866, 0.09380663895318586, 0.25887063974815033, 0.1746459680819704, 0.08558640061246772, 0.15268596580191968, 0.14458895270382205, 0.15516167085978294, 0.2047153327974581, 0.20444291193158398, 0.09638188181505089, 0.1617444039232308, 0.16037724341355986, 0.14619787524063743, 0.1126901087381186, 0.11459980505488573, 0.1825724959733986, 0.1340668729596561, 0.2352642838753039, 0.12852925236427015, 0.14400969830251512, 0.12298079928563488, 0.09005463141347132, 0.12359402968638367, 0.08660162032972421, 0.13984692973955987, 0.10526623411644852, 0.09885105214292005, 0.14731791110769396, 0.10120800591164059, 0.07933514613297679, 0.24352963713388293, 0.08952821409630199, 0.17489856259236414, 0.07051898331771936, 0.11624454220216121, 0.23465486093153878, 0.16895226473289152, 0.15273283506112714, 0.14895994396459672, 0.16707182531395268, 0.13051519741214093, 0.17420244913908745, 0.1844783695114236, 0.148224989853559, 0.21658611033231984, 0.120665988013629, 0.2215483222877787, 0.2497763180684659, 0.14053135269111203, 0.1251147295378389, 0.13699558112890492, 0.1962101940185793, 0.15121873888757922, 0.12884451286687007, 0.13011411974026313, 0.20034081753223174, 0.1759772603550265, 0.1269638742650709, 0.12171089363795136, 0.05391121984669759, 0.2191027857723736, 0.12324874619803122, 0.12081240273771748, 0.10754145396452759, 0.128385940296275, 0.2172852268502597, 0.13445766973159007, 0.14135177157098247, 0.09870420074871472, 0.14719101630391615, 0.22374170862378615, 0.2080643934107596, 0.10869689075456512, 0.14453261459787048, 0.10054517131779464, 0.22761961505297693, 0.17855847104182168, 0.12726822567562904, 0.1844764389698544, 0.16799361294796392, 0.08654718978270408, 0.10994335411176567, 0.10665794774409264, 0.1772636598757198, 0.267189557874395, 0.15168717100975976, 0.12360372069862582, 0.11788188660096739, 0.09255057651429408, 0.11243806581103033, 0.09380267061773809, 0.1847571948723447, 0.21820785718098765, 0.08724391610632021, 0.18996573473897674, 0.11014323411208969, 0.09544730051270417, 0.18694367109527513, 0.24598876404906475, 0.13282093820312332, 0.10909840509655977, 0.20332371876124414, 0.20183830491958127, 0.12067778576766292, 0.13433665848307072, 0.23519384975154556, 0.128417334579412, 0.10715902287272677, 0.17402316924304734, 0.16367620187661341, 0.13336346634934027, 0.19248208842210232, 0.11271138299977589, 0.10970475602774851, 0.1400857959543505, 0.16761236163156648, 0.062317728635764895, 0.18265619874000552, 0.13494297110986325, 0.20401963303166054, 0.1304017244687965, 0.17522005905066768, 0.2808139413114517, 0.2642304973015862, 0.07849507709784855, 0.10177066684850763, 0.14639595493433938, 0.09681407031753371, 0.0927405050324817, 0.11384120180962548, 0.10962812425268274, 0.1415313885457093, 0.19207595456992427, 0.10802818792721919, 0.13606671484247332, 0.1433126502219708, 0.12751777115608418, 0.1669929948665442, 0.07997257725125359, 0.0977188278169882, 0.17119933851063254, 0.110482549775512, 0.2005028298064586, 0.10255195395720583, 0.08149928323203519, 0.16441244301536392, 0.18502388540054523, 0.15267208428873172, 0.12702372871459494], [0.053299782091691617, 0.026703499963567145, 0.04865584519481467, 0.0713835901490623, 0.03374413910111593, 0.042298816955618324, 0.04208543082518924, 0.06009290588178462, 0.023010262858963782, 0.04270704222782966, 0.07709565662568615, 0.06687109478779378, 0.029555693186158617, 0.06504087243229151, 0.01319584821636278, 0.030488054748744737, 0.0409619590537923, 0.07991112167796782, 0.054898435219882004, 0.03512087187940075, 0.014139124616650085, 0.03614644144451426, 0.04178027885275022, 0.027965769629865408, 0.06394817441281292, 0.03656834138617401, 0.023970873913757747, 0.04116285795105561, 0.02221131933883073, 0.035077653029152465, 0.017781237801236492, 0.02366613945923746, 0.010425315178450077, 0.07180955801759997, 0.04803515692812301, 0.05506332032382489, 0.036306615107722824, 0.05395867899360676, 0.04986175568774343, 0.06907005058301073, 0.014276055172235977, 0.06669694768084634, 0.029129212038711678, 0.06845010159116599, 0.02297780179839221, 0.057726379844450185, 0.03538027691144136, 0.04624563299359814, 0.032029758815863923, 0.04975759071267901, 0.11249329308949171, 0.009876674608207278, 0.05161075740151348, 0.07417536010184596, 0.057591601995931524, 0.005586830732007061, 0.04986449062163311, 0.052918262644520694, 0.03114646135438835, 0.07424068441914936, 0.011825147422871763, 0.09649612084631959, 0.029305898727128105, 0.016907414932164456, 0.11793041827097056, 0.02536174484468516, 0.09376899339258672, 0.047256225539791974, 0.029701016234955, 0.03190915933960388, 0.03168722366793983, 0.06912800513448254, 0.038883393975876035, 0.06304664214351965, 0.03181298657680952, 0.01571050214190637, 0.023012459616086656, 0.01888739981598431, 0.0646873994640285, 0.02399574495821951, 0.018201369995010958, 0.04360892689756809, 0.06557839802436291, 0.028483424816400777, 0.036543838063915896, 0.08669070869443879, 0.028790482432551445, 0.024113806768230373, 0.014947394299651346, 0.029217545806820837, 0.045508269536038565, 0.02176806086584205, 0.019030233079026786, 0.049020602638202335, 0.08727127310609625, 0.05809815848366388, 0.06670219538312766, 0.030548550796905355, 0.016225273007406824, 0.08090554976895933, 0.04338446696619353, 0.0342421077432171, 0.06859394992070814, 0.09644852380358404, 0.048304413850869865, 0.07335684112002773, 0.03773433103736851, 0.10880882386118175, 0.05783488470760565, 0.02078079952738218, 0.03135664523729394, 0.03543607109496671, 0.04825847155805077, 0.06001115663938465, 0.015982636682418807, 0.057591169156254306, 0.03904541391098211, 0.039887800362081303, 0.006387371545462239, 0.05799842532724143, 0.0858112550791233, 0.049701658633327296, 0.014893951048443635, 0.045517998852676926, 0.018646269811377413, 0.03889034622378888, 0.0304431619963819, 0.11436319113859247, 0.053706268344314835, 0.07262924911394235, 0.06777191459531746, 0.0154780040329863, 0.02967396567034866, 0.03069463418796659, 0.04833280889978332, 0.08223208463600568, 0.04546408541500569, 0.03181798147007583, 0.022778345061646357, 0.0024412478594439888, 0.035095292203609026, 0.03910801478571469, 0.03244057538047914, 0.010704123302392904, 0.04037759867647002, 0.046835547508371454, 0.012423861415065345, 0.021791794269736257, 0.028409148761702162, 0.09872679268160174, 0.018710580977400946, 0.04002571151021027, 0.01800512891232727, 0.04587695318003816, 0.022879822983316356, 0.09090500433118114, 0.06605652881966484, 0.07779613678013125, 0.03952975001847071, 0.016459374155308452, 0.015141972971539346, 0.038351445503893404, 0.015917286509647965, 0.05815688678393922, 0.05159195377341202, 0.05337172923910041, 0.017099386989890088, 0.053855329902181705, 0.02556457811395728, 0.05611483345649416, 0.016679930868708802, 0.03041811666691736, 0.06501804301214796, 0.0351031101308763, 0.02810715498673099, 0.021732265407580043, 0.03381027930205868, 0.02428745974846665, 0.08735093092846294, 0.06851239986116849, 0.014924784172176114, 0.032066933232389634, 0.03341120111966326, 0.0355690831108199, 0.04924746425521951, 0.0057667680272472, 0.10563043231565146, 0.045303187798708684, 0.06014588852262786, 0.03195327259750376, 0.014897491332263717, 0.038382996835054896, 0.0733448978092882, 0.07951837904270619, 0.044184622820466764, 0.04795968960670214, 0.01419378020199797, 0.10077284498801155, 0.04292900854301068, 0.026458112425321055, 0.08055498793480859, 0.06440124264167202, 0.019521094340410446, 0.04347866130692344, 0.006266857296483772, 0.061609694854386395, 0.05707221736590709, 0.04914467057753955, 0.042468271774029544, 0.02703385239827537, 0.041504065851650895, 0.025543210006529288, 0.024551704540968906, 0.07618748237408939, 0.034393954030688734, 0.025619204013398098, 0.010482540031174018, 0.03777658844727182, 0.05010463620325731, 0.05442818746932092, 0.0493212346918881, 0.06630599003044829, 0.0600992375984788, 0.05116184903008323, 0.025461064313628504, 0.0853156115138723, 0.045312809863037644, 0.06326361356543438, 0.05663708708579502, 0.030155681757136222, 0.08852454698494366, 0.030617663418994318, 0.01446009343189578, 0.02390591157299857, 0.05380918076562305, 0.03876050964238183, 0.06476799957454205, 0.06629849002966959, 0.024387135448294784, 0.04745402944184119, 0.044291783199315114, 0.06465672530354032, 0.0927435310797826, 0.032759785066328706, 0.006599652115255595, 0.031055492243819663, 0.06234634585017639, 0.02741818913378783, 0.050935493031096075, 0.12041766061297349, 0.0236936726592361, 0.027010140061799078, 0.010334393948376661, 0.05187375538591897, 0.04237980394053363, 0.05027188085800698, 0.028394210047178695, 0.03942343233633907, 0.03226876867214038, 0.03597545445025448, 0.09342123544023884, 0.08668829551747731, 0.0560994848849312, 0.026284285160082004, 0.01079885486227971, 0.014471195961138415, 0.08993645469027181, 0.04308810585268563, 0.06323953542197425, 0.046441288019019755, 0.03482303987707823, 0.05979897709743631, 0.020645313047533555, 0.04035786425154056, 0.0065010058460757145, 0.029055347756272363, 0.04486238846795694, 0.036237651872779095, 0.10575176532109899, 0.059037811288069335, 0.05205074467906549, 0.017039687673170722, 0.04116208803269171, 0.023392885472745668, 0.0592829977282353, 0.016987790961960153, 0.02569549679455738, 0.0320975671732618, 0.04308517939681488, 0.022954579758187457, 0.04117676244688131, 0.017987708072929133, 0.06102816134150471, 0.010783482350469118, 0.02250656004874937, 0.05881392592263799, 0.05553763983170352, 0.03628010080466348, 0.0367858452391961, 0.1456987536362102, 0.03303796691339343, 0.02141090301466325, 0.0635600857616913, 0.04335954229557707, 0.060263705184502955, 0.010252193671711271, 0.038605453446507454, 0.07520407062744902, 0.033407052753553275, 0.053728818142366026, 0.04231440684487743, 0.022264208133903243, 0.009323961323037023, 0.013203004435185465, 0.01628570393809388, 0.02876185181160127, 0.05092389062948285, 0.06753770619510643, 0.007966954351192521, 0.0300462001318773, 0.02311046907467948, 0.06613391902177565, 0.03998728070948874, 0.03568361708593946, 0.06843883243779983, 0.02141729793361118, 0.022243542912145777, 0.055738891129412, 0.013974222275728901, 0.06588188375556661, 0.07178616169239245, 0.02785409124748361, 0.0309879903215915, 0.055516495804993383, 0.07185635832889427, 0.006426588065111109, 0.04646990140299163, 0.033564786426723, 0.06021561784549587, 0.047381959720364505, 0.028785749924399202, 0.03419428087410427, 0.023737510125483238, 0.03815289083567839, 0.024318672085721648, 0.03635420832001875, 0.037578186996641665, 0.02653450479791049, 0.01971274081076826, 0.012852927151646827, 0.038413326255977154, 0.07583867488128525, 0.1171637251372299, 0.13038516164787356, 0.11891257363341509, 0.20168254392281657, 0.14402039288993806, 0.14232366135524166, 0.1081856343174173, 0.19350922846746063, 0.16632360256006642, 0.1575545311695145, 0.2034252254112113, 0.19893328418895123, 0.21659076814689945, 0.15198073590234404, 0.13114387980632244, 0.14219333447756308, 0.16548318878537224, 0.19960854472892903, 0.13937907984420178, 0.14828063848037876, 0.1456999180898551, 0.1507098420012382, 0.16617993043074686, 0.19056568883599775, 0.12383642756650526, 0.2111535510348697, 0.18194759805356303, 0.171099839011027, 0.10155035528324305, 0.14136813520904512, 0.17041521687661448, 0.11282020578941993, 0.13335801180331938, 0.16234270327033537, 0.15668270778992485, 0.13246718944320757, 0.15699399995707697, 0.2215040577275138, 0.10579136440590506, 0.10771240648483077, 0.07190409326745618, 0.2312897277935859, 0.15102951517028196, 0.12581976791543345, 0.15891884183210714, 0.17784816964018732, 0.12899814413920527, 0.14082634250723547, 0.12929013089066552, 0.15575632362836794, 0.18761697045016676, 0.2132315645294805, 0.12285382787306463, 0.17795460989638684, 0.18382756249798884, 0.10587492927668557, 0.12051296961163321, 0.2588382189071948, 0.1016087465048317, 0.1833740384468148, 0.16943229542624566, 0.1311063414980327, 0.13654887526025697, 0.13966339039466075, 0.11689911836818342, 0.06569252980332221, 0.2728159220949296, 0.17858764366997829, 0.13539674030917306, 0.11065999872141308, 0.12852647912598428, 0.12820932638621138, 0.07962482695978496, 0.24695912165747536, 0.1408960718301035, 0.09162576283298193, 0.07006483873532665, 0.13496434496295068, 0.10542859879112053, 0.19682936160074127, 0.07800499533092783, 0.1376166486091191, 0.07954455626707885, 0.08546401040568467, 0.1672007425898506, 0.21485882721120314, 0.16710997649258183, 0.074681859132984, 0.19185101583359704, 0.12345986470820443, 0.1663840775408091, 0.13405901289755298, 0.12441502313219732, 0.20574797335411274, 0.17718406334038705, 0.12288408068519448, 0.20935033327869831, 0.11863767830354553, 0.1309353353515748, 0.12855931365441892, 0.08700865816565291, 0.1209804977500631, 0.1739460241890723, 0.1962884575609238, 0.09976990566018129, 0.14316073498658596, 0.22744529940668615, 0.20130011283101576, 0.15092761015459416, 0.1476683810112938, 0.10436169112161284, 0.10860240913086361, 0.16527262185850453, 0.10829575179565339, 0.1632120138815334, 0.2058058436359129, 0.14064444259049433, 0.14140555094326698, 0.1297739613801241, 0.192626174238901, 0.15660134925236627, 0.15716872929084688, 0.11214134463619803, 0.16764082945883277, 0.07931400210626664, 0.21681471096892513, 0.17224708632115396, 0.2111679381660877, 0.23269580556981026, 0.2230501304110212, 0.13907580095673763, 0.16492867902401956, 0.12692120316768848, 0.2006581311504687, 0.16964399616324133, 0.1697267643025806, 0.12474889957135725, 0.14994090422987938, 0.0912829001824702, 0.09179015764065328, 0.18055722507978642, 0.15928435770253982, 0.094842451113847, 0.17497923165079088, 0.20555640540776715, 0.1442305154858097, 0.11525615854489228, 0.11429693985490069, 0.2628481376074976, 0.19152329874134835, 0.19833354459654903, 0.2180998541054226, 0.07724490587509449, 0.200721180186637, 0.13548195992987003, 0.3274845692419237, 0.11720661840011036, 0.2111418452113867, 0.12361416247703376, 0.14429656758664117, 0.1311141402731019, 0.08725702387070464, 0.129626612028768, 0.07914194641935249, 0.13584605087676357, 0.08897266245537228, 0.16137844372180202, 0.14019264989802915, 0.08813198054990462, 0.13641836452147654, 0.14412516307446266, 0.16256796376359078, 0.11901277793391098, 0.16418911306367767, 0.1379697998204539, 0.20747776924362107], [0.06189502430178466, 0.02099740322709324, 0.08340714093778404, 0.011185004353342999, 0.009242449567893581, 0.040769437327980995, 0.012278954926577788, 0.05304839800021822, 0.03746227789369803, 0.044040234398938, 0.040782464653133385, 0.03151475046310694, 0.018306055909863884, 0.021037596030040615, 0.0355767248378646, 0.046789823550610773, 0.06952960374614886, 0.06774385279465107, 0.026236490849705956, 0.03956977428207475, 0.03732927353872407, 0.008907421124017528, 0.011420910595916213, 0.02553188148134899, 0.019214408276903055, 0.040697731498268344, 0.07255595748222644, 0.013318480698451882, 0.00797285466462434, 0.008526088410778152, 0.021080146468574965, 0.04542879557477371, 0.03616932449081252, 0.07073607731370196, 0.0633944996872977, 0.06691653146258285, 0.02387340263193173, 0.017573675854251753, 0.04472332052706231, 0.03269834864524103, 0.0965286259569468, 0.0939867845285804, 0.027293619406860203, 0.022828437635795246, 0.044607997481380744, 0.004190349164644196, 0.04665829391489106, 0.033303408718277375, 0.0457633653235051, 0.05416895863750289, 0.05548104891673692, 0.09852302095462238, 0.032161125657899726, 0.06583997874610847, 0.03626586306059072, 0.017916783652899247, 0.02153516439120135, 0.05743200289866617, 0.02955247370165683, 0.043142440638715224, 0.08464622686827376, 0.10843908684628625, 0.047754515938821344, 0.021703021916290446, 0.02522025415072999, 0.056986381044431086, 0.010671223656484678, 0.036099380663325714, 0.03751431441595478, 0.018811082136967493, 0.0862478409262915, 0.10278598615719427, 0.07202711932721638, 0.05153866086695945, 0.02282686524033066, 0.025042159775752696, 0.0064542797495490845, 0.04603178721041449, 0.019231122400191043, 0.01871575398610965, 0.0027603155796250872, 0.0731939325229295, 0.04653801044989978, 0.08389822627988555, 0.05626736922309764, 0.16283868391427303, 0.030899482268479564, 0.04498690456872986, 0.0033136125280326537, 0.07542206860718227, 0.06908856692814058, 0.031944506636430184, 0.05179227044385287, 0.025926305679604415, 0.011833244014621503, 0.05780799885190303, 0.025081245581649488, 0.024772027597552346, 0.07920633610938826, 0.12419723199620364, 0.02911521561233507, 0.046670505356404095, 0.041886684634993156, 0.02862183775212015, 0.0710010901093483, 0.023544229972626896, 0.024654490557769616, 0.06856247136789946, 0.050920263203161384, 0.05505661322404781, 0.04241524316791085, 0.03043780512657137, 0.03091459909844543, 0.07711151464571876, 0.023965718142027338, 0.016656346851959825, 0.041338916447374134, 0.05174751558731641, 0.04511189181357623, 0.05783366662780604, 0.13415385458257892, 0.0674754002642247, 0.021676367802184918, 0.03234706285800184, 0.035019369059873205, 0.02665636640402579, 0.02237976483640171, 0.023167759044876984, 0.049161689220777446, 0.0704084215084872, 0.01372792692329254, 0.06180293670284653, 0.04414987690266102, 0.03296705015424279, 0.041446459870184624, 0.025540547850992412, 0.0797979015436384, 0.03487722910640221, 0.03749414715134809, 0.06041919422005454, 0.03900867999501286, 0.0717872265546072, 0.03371896545192407, 0.039916536320121064, 0.19032740484802954, 0.030767879854407043, 0.002868674886074939, 0.04775999729791957, 0.06089669682325856, 0.03888371956324385, 0.04787941891399603, 0.05358772006847205, 0.010979443811060441, 0.05744536730250525, 0.08818991977961795, 0.03812287551080508, 0.06575043072863933, 0.04323702951472613, 0.05666227605674536, 0.18612141360438642, 0.10517071061316999, 0.00571523808063038, 0.047837391330470005, 0.04452517188544716, 0.016487347855863553, 0.07381849336407839, 0.014887608798040498, 0.05012504095512052, 0.02409014039702954, 0.020861451348830617, 0.018188739120359385, 0.018582525550417842, 0.05251387164237038, 0.056131675899509466, 0.04540408540877604, 0.07370135852045591, 0.05349521495161518, 0.09221278536584109, 0.10823797344440415, 0.06606923821832865, 0.06875983859983183, 0.1474540449318386, 0.07076761715354458, 0.06121638148362118, 0.03634154105619077, 0.06003866302630594, 0.030928574457404115, 0.02643028811191119, 0.0653832984126864, 0.05842714728186688, 0.038766921798308054, 0.029584915610030297, 0.051869162688812906, 0.06422497730161394, 0.016328168191736745, 0.019519870514951406, 0.027563929700502948, 0.03956107535369454, 0.0861023378468329, 0.04661313686219435, 0.027287500279565013, 0.044672138192841125, 0.05545451929191909, 0.007678239752778844, 0.00911351026696784, 0.022558104359514775, 0.06507284128137174, 0.060868688648746866, 0.045246711796930725, 0.048964088332028165, 0.05918998699334841, 0.04393897672754623, 0.06579291030404068, 0.0967657991174248, 0.009137667892050118, 0.04674923238194278, 0.143112272264496, 0.08047424226758942, 0.04696500104581637, 0.06472680702685349, 0.04105835972774414, 0.14468221624772395, 0.0071107060179084304, 0.07681421890494324, 0.04172796653884073, 0.046178879922315966, 0.09009174071252347, 0.07946898935422783, 0.018678395708482114, 0.009010306732248395, 0.014574350657752685, 0.019316322868689895, 0.02742963065693696, 0.0668002622983148, 0.041551685877024166, 0.10447052923301536, 0.05643968921034567, 0.03673665856401767, 0.06786389877238581, 0.04037325495793935, 0.15222228342486968, 0.04168070274435225, 0.020780075574293736, 0.006910818835510122, 0.04367617409556143, 0.007568018373868038, 0.038697353353904146, 0.02620821071398114, 0.026883634047642834, 0.03864244783237096, 0.022212221407361572, 0.04829740797680232, 0.03480762235760208, 0.05707682155433202, 0.0186495965481886, 0.012018767527244505, 0.022102621038474386, 0.03279203736794091, 0.05226955088155885, 0.053346632198700984, 0.03371838322510162, 0.027297227680983565, 0.020669155618956974, 0.056802830208213105, 0.07250934103203398, 0.03772709533692368, 0.040345840501568975, 0.056098734118765405, 0.045947203442694685, 0.09143027251646405, 0.02965891970351579, 0.08164064943670266, 0.06194935908781425, 0.026184084690025738, 0.0461597545372863, 0.05647261566933125, 0.056892462495353915, 0.0267517788245553, 0.05624477345977099, 0.01919860962868458, 0.12090002787449669, 0.012210575833676324, 0.011691313777719776, 0.035530698275373834, 0.05450583814132599, 0.010174555448634971, 0.05362807758032315, 0.0433666707437125, 0.02611544512723002, 0.018692876685470827, 0.048521209072562, 0.07683280419798628, 0.08888300718559373, 0.03660224077682342, 0.022421849876522057, 0.06816268838461369, 0.07616405540536489, 0.012709405367082406, 0.07943244696023964, 0.027142489411597772, 0.021896518488985398, 0.025944890972647457, 0.03584187552933732, 0.046455793893866004, 0.03064867465816919, 0.01367328474448333, 0.013794159054786209, 0.06906363076620525, 0.028292630618858724, 0.04625636588541731, 0.0020573482728533207, 0.04994337852563589, 0.07533727033484368, 0.016941067259458285, 0.07187434607335637, 0.03727754345163703, 0.016661556249844934, 0.032172528876652645, 0.08548711561748097, 0.0278517451032155, 0.019334804739863164, 0.03732640453944764, 0.02901778646534489, 0.0724865805598036, 0.0032057076074828907, 0.042765567514805064, 0.05712335373485281, 0.025036521368629994, 0.0624473775256305, 0.03728715785508675, 0.029861525061630437, 0.04616530484429771, 0.04960411265792866, 0.0038144724338405557, 0.06383505003947405, 0.03127643008596234, 0.04675590117732364, 0.023521678259355888, 0.04650350201935057, 0.051208243314777656, 0.0818963006379143, 0.011101519921794535, 0.0507440859632146, 0.08065783523864324, 0.015786709695784076, 0.04075069498691348, 0.02282146432046448, 0.051575153465232546, 0.03424288149202063, 0.040557993230439966, 0.05632612433645034, 0.05319660920048914, 0.13489938070697172, 0.1651168761834983, 0.15862334639795367, 0.11659036195206067, 0.13109535579719853, 0.2873737377024466, 0.11725072208191119, 0.10690498045615612, 0.13244877268950786, 0.11752858217204772, 0.14378714976051163, 0.11783428955823184, 0.18365871671947742, 0.09905452509560893, 0.09639950183730933, 0.17690712255575966, 0.24678063849287651, 0.15352325393788277, 0.1377750602701018, 0.08581035875625188, 0.12193010203660497, 0.07112987715029909, 0.1852119293424391, 0.1173526654019952, 0.23885136800667933, 0.15617112959584883, 0.31908116693938937, 0.10233382574252545, 0.060635177388546936, 0.08999442456350212, 0.19521732874695333, 0.1904233956649419, 0.2358310357216866, 0.12645568984049943, 0.23369072395707333, 0.14143078587949276, 0.14232056636002757, 0.1494108786385867, 0.10790323132588979, 0.0897200731560588, 0.2136847821454848, 0.27288407327667363, 0.21646974157662163, 0.13095358356593118, 0.14047754267531057, 0.25840249873938104, 0.14764553626939175, 0.13686949837832682, 0.18031039155058323, 0.16381993529296693, 0.16574785684145268, 0.16724255566875781, 0.09967121055289622, 0.11557600791415862, 0.09928274268825209, 0.1296829041694441, 0.07938158638294666, 0.13585905904971785, 0.15317661447390435, 0.1096485021914686, 0.1374337068128009, 0.18132326703879142, 0.12888827180910495, 0.16227746322270364, 0.3243312594150344, 0.17057313824132567, 0.08408790964993738, 0.11443478205511648, 0.13023893078488688, 0.11159015203555746, 0.1488390399683868, 0.20566629305962594, 0.1277306976337587, 0.14795236980482457, 0.13144357340230098, 0.18499123473321238, 0.19946292673628177, 0.11317347191394338, 0.17563491098342404, 0.1871261992041142, 0.1507205825539366, 0.16420512430129514, 0.11301865320532553, 0.12113714740881998, 0.14914282447388097, 0.2256224544778947, 0.12145190229338985, 0.14524478525404008, 0.1907491975373799, 0.19794279378989052, 0.17584590691952937, 0.16816650367071553, 0.13909794089774932, 0.15631947486150652, 0.16165745294382497, 0.28158860942048414, 0.21234610478483865, 0.11094919691282897, 0.17546283231387216, 0.1867166026345184, 0.14042976943235244, 0.1512307817897489, 0.18412621421439035, 0.08242287117266849, 0.28263854824246903, 0.11907681522350158, 0.10813422981769809, 0.15763176815404048, 0.18153562661140196, 0.1799159328783712, 0.2610586481469293, 0.15600649730092095, 0.15138239058996403, 0.11797313533362844, 0.1564900519987268, 0.13257836412277915, 0.18766007055678677, 0.15409656349689732, 0.15809067014244296, 0.27581806745259996, 0.19208821197671277, 0.16614798456430438, 0.16262039482112856, 0.10691877769967241, 0.1345916891530637, 0.11628349011223163, 0.06885098008018348, 0.10301083296297059, 0.08967995313146422, 0.09519315850470336, 0.19914650178003698, 0.1739302734213491, 0.12014446599829583, 0.16006805032732027, 0.17668080486116872, 0.1604911300443834, 0.1882837427359435, 0.09794521445949232, 0.17465107022754608, 0.08676867346249281, 0.17687627985592813, 0.17341363904697282, 0.13322912517093843, 0.10626827712140738, 0.3229777352704156, 0.1441909393836414, 0.11480100272643952, 0.2653679540080409, 0.12709356528977234, 0.1326656215373547, 0.1412180432629201, 0.13151318015110108, 0.1246910675939533, 0.0746849924325943, 0.16387912324599682, 0.10940159205347301, 0.08566551451240817, 0.13807964150703725, 0.0985667109489441, 0.27967835385953227, 0.12750988045046407, 0.07176033686846495, 0.11239128082149452, 0.15749106844586713, 0.20424709985813788, 0.17744315427637872, 0.24464797228574756, 0.13179718426639034, 0.18022500339054293, 0.07252574297449282, 0.13980183780433672, 0.1451651427534319, 0.0965065396420898, 0.1612781628125137, 0.20783349451038147, 0.21368528776351484], [0.027928470724052, 0.026917830297362902, 0.06846020629088725, 0.014162907816259371, 0.05503489463139446, 0.024583447394111467, 0.07271839876569088, 0.022007377157288215, 0.04498672453806766, 0.018445120020318898, 0.015472452768364982, 0.06790306118707504, 0.025981291640369643, 0.07097307427395737, 0.049667314911681804, 0.04734193545676047, 0.024124411340322227, 0.06494003993969771, 0.005812394308797535, 0.07963785811537698, 0.022223787419798396, 0.016893138883695487, 0.07494628204092865, 0.039878817981169115, 0.044137412652132973, 0.047533997529817205, 0.08150334349803387, 0.0010522223625054224, 0.0222687280526565, 0.03642555408840699, 0.04758846638123355, 0.05293556090985095, 0.023019722129608837, 0.047013919590221304, 0.02586582303798247, 0.019795164210541595, 0.06244736986475126, 0.04219893441205064, 0.07143190731444667, 0.07038465746107601, 0.08379656641233353, 0.06114515062842158, 0.0016729421106227225, 0.095040752973047, 0.07295043913707619, 0.04425077451272838, 0.04742135962231025, 0.08247326443632765, 0.06034206448783798, 0.025925788570255525, 0.0813543010923651, 0.07642155287847405, 0.04558257623425415, 0.028408059001629873, 0.02804458284029557, 0.02735986877533217, 0.04470401894181006, 0.04482423728932777, 0.03384325938719896, 0.05572023305801615, 0.03463351355505086, 0.030301437645609823, 0.027559097600920547, 0.034150303596810955, 0.03349206170007106, 0.060134381882005164, 0.0678635387110614, 0.046394778821136684, 0.0404196530730734, 0.10492510282464566, 0.012663439134015672, 0.09085354620530721, 0.058143281062404, 0.009360533402932268, 0.0374277847849073, 0.06278052235082274, 0.007951347224955118, 0.034346724710156845, 0.04012993777230863, 0.012028310109951324, 0.02512773945777407, 0.04481374571520475, 0.030202173718040994, 0.01268399710346374, 0.03605363755336693, 0.01942793996403775, 0.023543306836678136, 0.01994731693318294, 0.12330120789908594, 0.032612474019368815, 0.026858096506686944, 0.05690599543853633, 0.049276269161172455, 0.049924211005770394, 0.03154084916346737, 0.024372087566242106, 0.049485633329999064, 0.02939241495163691, 0.006964456002723667, 0.07042429485027829, 0.04850698665024773, 0.09418525492712375, 0.05594525223357543, 0.04193195660087851, 0.006439064285762969, 0.039482765846074595, 0.024779722950751745, 0.027207005506141052, 0.025715068425802935, 0.05417263202909982, 0.06547552007701128, 0.0496737040849703, 0.07780234975319716, 0.09962436427632648, 0.049274694850488056, 0.07070993839372551, 0.03524993088156466, 0.035363468942382646, 0.015194246981052623, 0.04108634108917848, 0.056645774522856365, 0.024934953431628888, 0.042102024289629156, 0.04613987838609084, 0.016487081640309865, 0.03796300445232661, 0.01376220744268428, 0.06511445517741865, 0.03132132475354499, 0.03348755710307629, 0.04138769709595269, 0.028960933165264227, 0.07903379012620257, 0.019798812704280983, 0.04546267581322501, 0.03376839344479865, 0.010531488261486014, 0.0167527724237692, 0.03752715404956572, 0.044633435430906476, 0.028764839554505966, 0.019661311413191503, 0.008629418350005103, 0.02060535964706252, 0.050998572710781336, 0.06609821166362494, 0.042589332818263964, 0.017180333755189375, 0.021683613078728802, 0.044903764876747326, 0.03580510713941148, 0.017107685637329857, 0.022499182622038552, 0.07140121783219999, 0.018014249189065832, 0.033332746055337696, 0.029572187059168375, 0.12736732680951396, 0.10094913714114698, 0.09259284924595587, 0.03729161648680607, 0.01913898692075764, 0.09231646004463397, 0.060412632676983075, 0.027728876091479778, 0.03524817654021806, 0.06894618182653381, 0.024212540179911642, 0.0462485249755123, 0.043289701889960036, 0.0756029419661049, 0.06393468743490596, 0.03034996931561299, 0.021654124439303434, 0.05608220194135943, 0.011567754329242294, 0.023794173818802642, 0.06740642936840173, 0.09273699634978849, 0.05546308798535217, 0.09228250702782985, 0.06092819835870497, 0.025502331554889682, 0.029048864737213142, 0.0750743642809891, 0.01407565997778288, 0.02615411533042789, 0.014470710452916402, 0.042853728913131266, 0.035452089993463415, 0.08106861158364242, 0.0848339413923602, 0.047043751053992784, 0.04091393300181916, 0.016994618720585303, 0.022142714249991605, 0.05392152755971878, 0.02909906456367143, 0.045369492708555156, 0.04978431185947792, 0.005667471062136634, 0.031667272823171756, 0.043523557889725895, 0.057469878285642595, 0.016556265125531825, 0.054633801637758175, 0.05486137188610531, 0.02918411947546467, 0.07537527595676723, 0.02367366052743408, 0.06672417444567527, 0.03539179504338292, 0.10828137232531464, 0.0568413797525629, 0.15039131796408087, 0.028627181215392008, 0.059721249816638816, 0.02416137891310838, 0.03406573515084963, 0.017300768522545695, 0.08184635936613045, 0.010203723288742046, 0.042733824661662506, 0.09854549797432077, 0.10132213769059989, 0.022775213677255858, 0.07676475260767245, 0.07309428746661834, 0.03102208123422198, 0.025691574424385064, 0.016253687208518386, 0.057886974856017105, 0.03814224987441013, 0.012970646137311574, 0.01024132096884592, 0.06921805110910247, 0.030589766327231645, 0.08384683710192481, 0.0443253378503986, 0.02359900525921295, 0.021054764060423743, 0.06119429516876417, 0.04835438959661031, 0.008032711508173135, 0.02815344967999526, 0.02217696221064656, 0.02123831489664172, 0.09939182594779039, 0.03695517365309981, 0.058404494061945915, 0.03337931270981508, 0.014502555770318837, 0.07005772943938933, 0.03633099202547343, 0.02499562568001209, 0.011837412490539495, 0.08138708965552431, 0.0238822566931166, 0.04500121509115543, 0.04692412259417677, 0.018294283053687504, 0.003358968763589679, 0.048729201944004145, 0.047921484801918275, 0.03973337235830484, 0.029666362247700175, 0.014179293479349826, 0.011288544009139222, 0.058458361534341696, 0.024030414267232823, 0.02859307689622285, 0.0282031936841386, 0.03883356378684121, 0.0457629899404222, 0.06355334418795763, 0.03641175301445108, 0.06132285238333768, 0.09387242292324383, 0.024921596688669057, 0.058406045389992584, 0.02832728077567393, 0.0745283887391129, 0.013852325238047108, 0.09769527061331658, 0.03066628510432859, 0.08009613957256079, 0.026512793866136385, 0.04620869606432896, 0.041493547464450525, 0.02614268529859762, 0.026757309979368604, 0.043308313996080434, 0.04984787034411585, 0.02000768083117662, 0.012799695532228197, 0.0232289886222251, 0.03898251809239869, 0.02977161698283688, 0.013248878737701284, 0.024062145629056522, 0.07099440216176933, 0.0440932821572548, 0.04259689027563699, 0.09852456845222943, 0.06363882810898847, 0.006205457264572503, 0.05802659438021722, 0.08737995033903469, 0.028472661281064637, 0.020098686330921708, 0.019769534739034793, 0.029394810891620098, 0.0341136041547983, 0.017548862266384305, 0.04331492533486697, 0.04555226596552999, 0.03321954507320639, 0.025455548480573683, 0.034760626693887096, 0.08190022300808661, 0.03127120536631875, 0.025459346361458305, 0.03463009297246895, 0.029660266103042714, 0.040570480463605736, 0.028012018357854218, 0.06170095124792668, 0.051933023778180924, 0.023372584142752235, 0.01873807395778356, 0.039744028641331586, 0.04201637949013422, 0.03904265216401508, 0.023433677739493793, 0.0739962870495454, 0.06420079956672366, 0.059106563848833886, 0.02581031422220892, 0.02484979892840549, 0.012663484141681225, 0.06069037019305172, 0.04127897772817843, 0.04426609244077437, 0.014888846030038212, 0.02125344321792645, 0.045384653588576664, 0.021508228739783652, 0.05177384219883431, 0.019549742198338913, 0.04640046702397447, 0.04960166883745021, 0.045334670181956985, 0.08026749811946385, 0.1752827710081493, 0.19231672068276714, 0.08361170173532541, 0.30981622215720916, 0.09041940417861746, 0.15091124651653154, 0.19833031170550855, 0.08841480488979048, 0.10683052437079531, 0.09423125850697679, 0.1665951194421899, 0.09476890667311608, 0.1322584764491166, 0.2654987098949571, 0.1283745715514787, 0.09027144961780117, 0.12779475790598702, 0.1117138292700533, 0.1821152180913956, 0.1142275705933571, 0.13175466638659278, 0.14345549497633212, 0.08393854548734042, 0.1636379740891918, 0.13373780755266068, 0.16904105432331565, 0.1294593443913806, 0.12715863679806072, 0.1994645048774058, 0.20025002079144602, 0.1302449675577302, 0.13132521281799964, 0.12151550291286362, 0.15485007225746109, 0.12350027584621023, 0.18249003426922908, 0.13006847622173448, 0.2584780350087151, 0.15076356008648872, 0.1551306289770911, 0.1329182620130239, 0.08212546051870431, 0.2110759310063816, 0.16734784679307094, 0.12983940061061613, 0.15432320294841645, 0.1838846666918647, 0.13534119893466273, 0.1346639772095988, 0.1933131252806033, 0.17866535562901728, 0.16062052229479437, 0.13375371153796875, 0.09683689973767727, 0.17464854213739597, 0.24435575570791002, 0.20376642565092734, 0.1273998012766242, 0.15461597110955946, 0.12768333807827967, 0.15466668613014684, 0.09439031368181591, 0.0919274329358051, 0.08089834854247109, 0.18505045332975928, 0.13153145900897442, 0.2091275242668006, 0.22188593723600913, 0.1954352194743772, 0.05808107855339205, 0.1715797930955887, 0.2039775135175836, 0.16594336247972905, 0.10699332571558415, 0.126777439107818, 0.09651811523062569, 0.19118980534615057, 0.1693182402560788, 0.0917770422153896, 0.14641621029905735, 0.11635878123342992, 0.1309418624206897, 0.16353239185146748, 0.12880346587588712, 0.13395900777991743, 0.12734352445770658, 0.12873689283526715, 0.24328611310451265, 0.10312982940024908, 0.12620465048859197, 0.27555520736402084, 0.14953319223657732, 0.23930590329391344, 0.14161337527536577, 0.15212912713327717, 0.18891449356752057, 0.10249895599460411, 0.1718236082383702, 0.1448949128990212, 0.1553416708784719, 0.194245055918732, 0.11352355877358107, 0.16508678424983256, 0.13168194932082009, 0.1769526281784619, 0.16582958310121493, 0.20307723763248614, 0.08636274645405431, 0.18635795091188725, 0.20457573625589573, 0.15152590950169872, 0.20212678298834832, 0.14757153217590627, 0.1584272891763718, 0.1409654793960433, 0.1383633391871568, 0.12473327903858117, 0.09891687441737422, 0.06630692465771591, 0.131737414086538, 0.12371573041403487, 0.12193041613265393, 0.19034592885403864, 0.14863964260345505, 0.11744504794478418, 0.10296335849430292, 0.15166438755489167, 0.11731299736927595, 0.12791340960369957, 0.12205637630916412, 0.20793910739162277, 0.16567245846794498, 0.16413668200613993, 0.06787601828334794, 0.1784916988183414, 0.10722661481028604, 0.1200646932627405, 0.08803154642303145, 0.15096858053678466, 0.13273927323039503, 0.13999470810015358, 0.14225927932608512, 0.25808028215842865, 0.08730141100503745, 0.18583987629221332, 0.13783473851940325, 0.11497740213188434, 0.14080441707084257, 0.12535282966470526, 0.15098077665653922, 0.1658391745220269, 0.14288065324146904, 0.17850358850292622, 0.15580048093632345, 0.16671110515392598, 0.11694410305109718, 0.20007774293903383, 0.29579267626808536, 0.13125940586530394, 0.2077458540518438, 0.09894275286745641, 0.20876980717143706, 0.12306417263443432, 0.17951928319469576, 0.12270399639683387, 0.11994914422112128, 0.0989654443917736, 0.09989008187286316, 0.18276956443104053, 0.16862140668015327, 0.15807786115234898, 0.10665004937759331, 0.11285815012430954, 0.18910871217808417, 0.11746969299330828], [0.028577858559607018, 0.04789531523842485, 0.066368326604847, 0.04218130289847332, 0.03468106463251095, 0.009799993037426425, 0.0662436381342911, 0.0801095078068395, 0.034115894757691896, 0.06128671218550975, 0.044275404239494, 0.06204634581902816, 0.05650213303705377, 0.010417212841040906, 0.06790714443571146, 0.047728756232367414, 0.025239617023016178, 0.039653860092643774, 0.06544699862359032, 0.042312112411544214, 0.060852256062771046, 0.017609408110260003, 0.026761109775473035, 0.0782448651208993, 0.03305770516876252, 0.027083106106147174, 0.05095796238991523, 0.039065531379873716, 0.04084827926670832, 0.04370464192282769, 0.07911650463938713, 0.07875245199688981, 0.04318702695590835, 0.0701282401719401, 0.10372418339454359, 0.051239342654063824, 0.06269036529345379, 0.04730052074357387, 0.025806213736594207, 0.023750857292344014, 0.0133739655739778, 0.06813613577715813, 0.047249460983420574, 0.027307634985434915, 0.06168752172661405, 0.09249948611062381, 0.029735059267090216, 0.054713750573536085, 0.09563058704858828, 0.02018068455189707, 0.014653385076070986, 0.038777612555291385, 0.05519936604785824, 0.05238987265094634, 0.028657464671038815, 0.06352606762741363, 0.0653303387544809, 0.00258011661747831, 0.06027056167142526, 0.032719117288868275, 0.03539164182579806, 0.039024714215268055, 0.0467368524010864, 0.029025826558110215, 0.05977589869871736, 0.03953063101958364, 0.0647960537143292, 0.03412137994722974, 0.012692807114592964, 0.09169625058289498, 0.05203586725157596, 0.05825362070613812, 0.008705394162285713, 0.13392784332315769, 0.03687987104058266, 0.028197384822452744, 0.014238829044775378, 0.017998802941292524, 0.03492804754885935, 0.03273745360333593, 0.04911557455817538, 0.02671135044957121, 0.06267316661955369, 0.050682285650362896, 0.01008780173686964, 0.04787003816736322, 0.03262892958798236, 0.037698999062300696, 0.05965827738926296, 0.06414427759967024, 0.23671805828569398, 0.02690790371308404, 0.03721823675497886, 0.08536310130429846, 0.056895722199471734, 0.01414528204834149, 0.01704063570697702, 0.02962906525710658, 0.02627162938757289, 0.046501039046674006, 0.0689095781455117, 0.019982777227978074, 0.008899320701828167, 0.0274410204691512, 0.09798669812059212, 0.04428098519002238, 0.08414377278137593, 0.04077036429436938, 0.03625169043399153, 0.07813362149341453, 0.05059558747997207, 0.09258024709960146, 0.06057023228476606, 0.03516178863543657, 0.016830834868033568, 0.03868253721344856, 0.036568747412773876, 0.024074014246223435, 0.03723936929037014, 0.07136365654127252, 0.052579804999573584, 0.034904800610797065, 0.04694944180007424, 0.02545196510430786, 0.030192440570963007, 0.10598639506966838, 0.0636585931774349, 0.08809085695012923, 0.05873837050110583, 0.04447308939791495, 0.011921214848576535, 0.025460286734385357, 0.08682888797334126, 0.06037776035466983, 0.04009716453090791, 0.03655858142601867, 0.02600720264918862, 0.016480872497683572, 0.019587077493328723, 0.023018940719926072, 0.0587885492601462, 0.03021309430140161, 0.02428147085611859, 0.08221435736143783, 0.03682647088182069, 0.051941718876121507, 0.020764211808601697, 0.06327910386326333, 0.06373470018227255, 0.042991360439167875, 0.03170618051362615, 0.047158660412195234, 0.0806518520919546, 0.039608848596652674, 0.004177961522908581, 0.036021940665499824, 0.0709761769300507, 0.06321863654339988, 0.01738558594708241, 0.05078244398558333, 0.11512518049247804, 0.02780315214617839, 0.0228825330193485, 0.024519209006440737, 0.04365119579879027, 0.030006581894873135, 0.0255558121528837, 0.06252854837164765, 0.04277076159093169, 0.038434987392036185, 0.023688298552447272, 0.08172940072273055, 0.04022620055043409, 0.007124915512488976, 0.044277181563478325, 0.06719953200269131, 0.05847091388498103, 0.029584687698872823, 0.03710026304507929, 0.045975694252598676, 0.020754574422514247, 0.1301393546764889, 0.02206781000319508, 0.05689399084076286, 0.05147303777536558, 0.060582026208360354, 0.059350654783268134, 0.044094772198267525, 0.0039283322515867415, 0.011286263939954582, 0.0472059931545969, 0.027514649179553794, 0.01878805544918343, 0.03754509965919199, 0.10073576633247638, 0.06133552347760528, 0.031125459053944197, 0.02057988530836038, 0.06844845450212879, 0.05964693162710436, 0.040684738647072546, 0.02635236356347319, 0.030168502238549055, 0.007842367387286598, 0.0358902846252726, 0.0362721411511302, 0.014515856971904157, 0.03198733095139746, 0.05233018291032603, 0.034107494603602156, 0.04983101640978167, 0.01831630808151057, 0.075612947074396, 0.013883455220850245, 0.020777913291127454, 0.0013096660897586375, 0.027270680819187435, 0.016489094536330913, 0.051062495087183295, 0.01948887651275483, 0.0291237574926908, 0.04537748683604502, 0.050537031549479694, 0.019753096407399546, 0.035535164567972385, 0.08577404618864098, 0.02158696917186101, 0.028177204151307384, 0.025682318167039947, 0.03223941218288195, 0.024702562575018214, 0.04129034647297475, 0.04728097017974623, 0.05104619273615461, 0.030781190632091417, 0.008980989504996087, 0.04811563829500829, 0.03322522944560455, 0.07983597611347515, 0.019957055825920358, 0.043282975637984854, 0.05521829991090683, 0.04763200698841003, 0.059600426259660916, 0.02225215374041469, 0.0678746163424465, 0.06552702416816066, 0.022436124009771213, 0.01007142564987824, 0.030770180033399697, 0.11039997315815381, 0.020787713470898812, 0.041890695105276765, 0.010452379149595096, 0.032091118628159165, 0.04952481489688639, 0.048091632929900964, 0.024035010794778506, 0.004011334526547862, 0.03715646708564412, 0.012553876111914795, 0.015149740145481644, 0.11174484817010742, 0.058107497095460856, 0.07209480319532656, 0.022763126725030523, 0.0377376405372014, 0.07709601668701058, 0.031592150241316806, 0.044183163422971, 0.0847684178921965, 0.0406093824084007, 0.04040193345938479, 0.03157016926354939, 0.016457301887473273, 0.026770496267765283, 0.01340620925710086, 0.056371729550582755, 0.045093432925040686, 0.010548677359287058, 0.015735818474974125, 0.03080906282599655, 0.08668342319827887, 0.059111064615389036, 0.07223889667300448, 0.04135685056568154, 0.012584595280068537, 0.06813579869847144, 0.018239511597541072, 0.09061435057270913, 0.04157469915826956, 0.06410395839221536, 0.11211181960759625, 0.048573919752192114, 0.05556484744433434, 0.023958821435489004, 0.013213634862744761, 0.04189296655597226, 0.04044254761069052, 0.018067871513325843, 0.010730398202975912, 0.03403235286954911, 0.025523782016769535, 0.01860676265712227, 0.034250527049504945, 0.02514396711523014, 0.05292720672103667, 0.08091614476495212, 0.02576205834385849, 0.04396215088725571, 0.00526834691446575, 0.030414427953561952, 0.031706580794566584, 0.041025988682503664, 0.030211598514729453, 0.05458126332791102, 0.013714369082252586, 0.021032970774197773, 0.07302819706139065, 0.048749622017625845, 0.04239242523908616, 0.0362177680607044, 0.02719566548964189, 0.08427149496011196, 0.04545770390259643, 0.015760011531622903, 0.02545715151955524, 0.00966095382482895, 0.032592728103120486, 0.033694289759883, 0.023936436346341527, 0.06840751476345525, 0.028494431584652875, 0.0005402399373481111, 0.05204456234951654, 0.01789715839549899, 0.033786457798053185, 0.058277492005858696, 0.005936153418940282, 0.05332167305412793, 0.019014578072294112, 0.02350764161336326, 0.01589044853444061, 0.04320485382190636, 0.09975346541332622, 0.05160640985254319, 0.024733292276880915, 0.0413291028610641, 0.02146941489509998, 0.057089052148043155, 0.03757267116358684, 0.03411266569709105, 0.20789540973642182, 0.10214774298571772, 0.12976749559804318, 0.13153505962221854, 0.10288621344032789, 0.2637873920461824, 0.19666181817170114, 0.19090308927960936, 0.19588384056283584, 0.21220119159308173, 0.09584059473127128, 0.1516522067568956, 0.11428415384744445, 0.09622486443409035, 0.0967297700023459, 0.13413936019905154, 0.13484414576763107, 0.2027878862234854, 0.25343909168676026, 0.1717451455131654, 0.14207903415926043, 0.19394363096404463, 0.136298609657153, 0.18155574408029357, 0.1257163460456556, 0.10896116044492492, 0.12601557998887955, 0.12090369743565399, 0.17987447219990915, 0.1424839882360351, 0.1792085732543661, 0.21255051236479514, 0.11963303336092543, 0.24351129698897564, 0.16379572691455965, 0.21476721841721766, 0.1990661851220554, 0.13886950880048737, 0.12487338885905282, 0.0895575476029227, 0.089479498565197, 0.265609547495842, 0.10442956651170408, 0.11339769052762179, 0.07395661135594692, 0.10824581818474878, 0.11777188403591995, 0.19533457084288522, 0.19170582685018742, 0.13221330790510102, 0.0868448609065625, 0.23566724612347542, 0.09314884521788167, 0.11954414417907117, 0.124615807116272, 0.23600826250208964, 0.14686645549391547, 0.1177750786225642, 0.1579414668583101, 0.1589996794298772, 0.18013512595526635, 0.08211896409310641, 0.1504463230770442, 0.0904175119414445, 0.2127693836847621, 0.1721651762002899, 0.13059578986177522, 0.1892338909449116, 0.1668710949560327, 0.2084111707705644, 0.194370694338314, 0.13887485609419886, 0.24014432524000448, 0.16063281034509982, 0.17214789325671812, 0.15928869376019125, 0.08838535646998114, 0.1897518736340346, 0.06349908218028084, 0.11180944470388275, 0.12575066678466337, 0.07740930068276583, 0.1118604968031568, 0.13854957516154937, 0.16436171267301808, 0.1310688644767769, 0.2691963711573232, 0.12247096011114698, 0.19436284959796937, 0.13986347723872433, 0.33976308941360445, 0.11258723845164623, 0.1471265576659672, 0.11556119943458228, 0.1761780673217389, 0.1027186087242538, 0.15645378539639135, 0.16311089027552836, 0.1323438646091569, 0.15077014844263756, 0.22939438030364054, 0.15395713549467827, 0.18016586140278848, 0.11014069836106032, 0.13759872215169092, 0.12083984400716521, 0.1930037330115034, 0.16313612521175416, 0.12251419811359338, 0.19115464191042608, 0.14218771139219885, 0.25741727902523936, 0.10916297864769736, 0.17396840927821977, 0.20761065485496677, 0.19083550500292934, 0.28016494226551825, 0.19170991775970306, 0.18702841574145904, 0.2146519681498889, 0.12254016849422648, 0.09210321181003125, 0.2153328670969894, 0.1152653439391044, 0.11320485087532191, 0.278107168813867, 0.17348454814524422, 0.2877620217059889, 0.12364322785288097, 0.09755490032295067, 0.2027557411741826, 0.13812202149100844, 0.12896082033553433, 0.19507774752714943, 0.18743648013520628, 0.11058089248235188, 0.15629430121231466, 0.10881288412718043, 0.08632856361087292, 0.14296014252449238, 0.1348367760017995, 0.17216450204291653, 0.1679222748404549, 0.15240573083921788, 0.17628384874232356, 0.12982276118090078, 0.1487127580349484, 0.1401286049475593, 0.14886099604829667, 0.14369546435773373, 0.141017435479068, 0.14894292149091923, 0.29702687455761817, 0.15412774327541554, 0.15089810044775087, 0.1829235787473379, 0.15564422964328722, 0.10217169855510998, 0.1593648888651402, 0.13171826188843097, 0.27337246965016093, 0.12123903710274928, 0.09428785708282264, 0.1368151367792199, 0.09037500172252617, 0.127991734433078, 0.121620771054539, 0.13760722572765044, 0.2043877229575188, 0.17139371033878098, 0.14690414701979007, 0.13603335937425015, 0.19884166007320728, 0.19453013255711527, 0.18304508029212876, 0.1685137253615164], [0.025412517321866848, 0.06357342718289265, 0.004012636876019139, 0.031119657853137583, 0.04143400328053583, 0.02594820813335959, 0.04099294731032945, 0.05318404152809132, 0.021995989260293787, 0.020913181435917656, 0.017936632991017356, 0.052635101225948146, 0.026872121661360708, 0.01934757925600054, 0.03310374322257215, 0.04493575287802566, 0.017585132699159366, 0.033601087503015034, 0.03835344499337577, 0.026794616546061252, 0.0608783949827475, 0.02894264090085222, 0.02386873141081343, 0.021712854654798587, 0.02965856921829043, 0.015086545552607748, 0.05193272117345084, 0.0178453114800035, 0.054175700211236556, 0.03313408030437366, 0.038746007597975196, 0.06830937890035492, 0.05259965816813131, 0.029628980987434907, 0.041040000430638754, 0.04707436392744703, 0.10302610875618073, 0.013530920710294478, 0.03829998354757986, 0.06686223115050985, 0.033472522627562284, 0.06719560197163975, 0.02768578556095881, 0.07434978300044615, 0.03949139582654161, 0.019980804551573052, 0.03670296601710781, 0.007269471515751174, 0.021267430068204002, 0.10404469159942481, 0.0699999510881401, 0.009086153267191784, 0.04622420551435602, 0.033541731010641784, 0.05994515050382865, 0.039955913239429076, 0.041595701458713705, 0.03650809623180859, 0.0471836923351211, 0.019783169188867175, 0.06659859731312721, 0.05459743544399258, 0.03933342083567574, 0.039991218401419545, 0.023287912274921135, 0.015135435368715516, 0.011719444526299354, 0.016727443641772675, 0.01706087574993651, 0.07373776301861772, 0.013139736106348856, 0.012473108419667811, 0.02423451924245925, 0.03934013559633205, 0.025661423118905197, 0.02815219329579944, 0.07411736724597794, 0.05234826258533905, 0.039101453242643226, 0.05587958700714573, 0.05103896469658902, 0.07034163396324843, 0.09131948088085459, 0.02629519808256338, 0.020059759488269206, 0.034012331161648035, 0.06143555923875782, 0.06560386278696599, 0.06436381924657092, 0.05229824087432316, 0.06654852580639624, 0.0029727680403964537, 0.03828280402587787, 0.022270629865928523, 0.017202519661476536, 0.07368786771210932, 0.046108591355263226, 0.04139634622861782, 0.05352066056202016, 0.022193570996844963, 0.04061718118346987, 0.054154824315299915, 0.039320826350200566, 0.05079767381351802, 0.02445484229904269, 0.043913270647246996, 0.04486635297296509, 0.06056725603318023, 0.07979246231937602, 0.05800657650275577, 0.08431201335042716, 0.04634995501668704, 0.061967906076461084, 0.07366306944600037, 0.04455855416674768, 0.04541747279525284, 0.0767448573042789, 0.06746899576917773, 0.04041060557468765, 0.06224193189653659, 0.04295920772898582, 0.01923531481635667, 0.05366233703229697, 0.0535687210879499, 0.03084230338103108, 0.042879304758483366, 0.021325706376604015, 0.027107280010597843, 0.040566339758375, 0.005090354524943377, 0.027070036646158948, 0.05629010671269029, 0.05576200783252717, 0.04897263021238389, 0.04671227630047549, 0.04446059067343031, 0.04077599887105246, 0.06983874320623375, 0.012726453696227363, 0.03362087172365958, 0.026823335267122717, 0.02361269141998022, 0.033020002151569056, 0.059655155580971515, 0.033771545896607066, 0.021688073625667922, 0.11154293803678406, 0.06950642192556013, 0.012151276797897393, 0.02566881203693488, 0.012689554113744488, 0.017831022024995858, 0.019216015146324233, 0.031013652351835085, 0.03678835034670849, 0.06882421296810912, 0.024471531524473143, 0.026469463933139082, 0.05100096673554471, 0.03676697649362107, 0.020966541375063603, 0.034062628664316676, 0.03980160014884126, 0.09311087023947509, 0.009906196763979332, 0.047999395943817594, 0.033328321897574974, 0.05954747426233465, 0.014429537057425949, 0.00830353891116477, 0.0500773941166699, 0.0683807323296224, 0.05084913960027118, 0.0257173168938607, 0.03462857228793925, 0.049368850886821754, 0.026386854757044106, 0.07641588382783436, 0.05232485859925228, 0.07626430567113623, 0.03830250397685074, 0.03211223584179196, 0.03163571574635083, 0.0604861234915593, 0.020263902767891848, 0.048324734333061406, 0.022377156307019537, 0.04893930921811731, 0.03078365935042741, 0.05052639441865106, 0.08873283096979703, 0.038202694211635864, 0.1281931849136468, 0.03344257242016254, 0.05922723418822693, 0.14234581661801185, 0.018239419666990157, 0.03939232150573404, 0.05441742010354515, 0.0077728027733223095, 0.057271132095446514, 0.03138182463214523, 0.008439670820089598, 0.07142734143041796, 0.036451627890909874, 0.043003380358699834, 0.048822205018011794, 0.03278190968558192, 0.02831947625494532, 0.04130677905895057, 0.009655200504517604, 0.07163129701849914, 0.08575592820923175, 0.024788513809682864, 0.02717862003332665, 0.047510662491643624, 0.007117548619487113, 0.026595223011569153, 0.03838399274935646, 0.08248664799236483, 0.051268289286282756, 0.03710386748876303, 0.04825493223184059, 0.02010866079569584, 0.0501251443769903, 0.006065627066193209, 0.06975171561803549, 0.016938332325568604, 0.02989726306329812, 0.03274736678107612, 0.04272522532471246, 0.03320452591945087, 0.027626492270839312, 0.02757486177518243, 0.020570449020353057, 0.008158740632596516, 0.07196992320278961, 0.00478546972566795, 0.03634249100521688, 0.005594224916891225, 0.020723735553122336, 0.04270387062382314, 0.028420437067266435, 0.0294936400642919, 0.06777318630127177, 0.0529169028384551, 0.055502028234543345, 0.04135543330302162, 0.07092173106127209, 0.017399835182474028, 0.023764238933161385, 0.03607648612570859, 0.03222063919829746, 0.02568562958209265, 0.06199112620144602, 0.0464216263724431, 0.06049805914141959, 0.02824962244278962, 0.05240739308177464, 0.0878405377208706, 0.01958881459769703, 0.030955743765638723, 0.019997227561449813, 0.009601552324790147, 0.024242346745825583, 0.025903526055175933, 0.02796132823512439, 0.047667419402709896, 0.04652707454478068, 0.012353618813288069, 0.025686987472938436, 0.08103749309215816, 0.007742300982617083, 0.024166766426435882, 0.05291638955954583, 0.0541974532778465, 0.024915942959787867, 0.016097820874664093, 0.07248884818005948, 0.03365320063406422, 0.08299287889272937, 0.045543268262859316, 0.02112859003846684, 0.07704433639563861, 0.03911698567530802, 0.05663585751467655, 0.06781980275146424, 0.045015441343909314, 0.04431979520426643, 0.06481400315439509, 0.005176213350252159, 0.030185735386405742, 0.046935123616769436, 0.012538496896834865, 0.059694743174458706, 0.017421816160241445, 0.03348337426300972, 0.025181424984287833, 0.01834955821264415, 0.04581740133524422, 0.02177860989655939, 0.03764372198812423, 0.010172182491289513, 0.04870703518991509, 0.04551911351060675, 0.049920468666260286, 0.01712066699720679, 0.04894578266107748, 0.11897001490597764, 0.05614171931219678, 0.022408424185649044, 0.08992322435181949, 0.05967156135386998, 0.08521913040068843, 0.011767603686049342, 0.02818461796719461, 0.02197953177646043, 0.02601312450884331, 0.04379503646745317, 0.06119368995930399, 0.010357782612704943, 0.09868935396474215, 0.04841951856149301, 0.026782138888994535, 0.02974003692337823, 0.021721978761976766, 0.05309388064028275, 0.04677314198605957, 0.0450917896664431, 0.11306159243348146, 0.053628472115604155, 0.02539481302993673, 0.11303117108200827, 0.01730711173055874, 0.04731727125603826, 0.019809256397908735, 0.02601073048407993, 0.056454830938169075, 0.04200232560716329, 0.005796192028003955, 0.0559498640828796, 0.023382196630982142, 0.03206700601074244, 0.05518741890667908, 0.03914234701604132, 0.0356521615157685, 0.0509920341503476, 0.011253691796633986, 0.07935746993509032, 0.046064085477302154, 0.06502057876317732, 0.04924794306017218, 0.08648175055221205, 0.18071211273631743, 0.15060642013146033, 0.153634290721628, 0.2180521574712569, 0.1542094235699023, 0.15037993389752605, 0.19778625138344305, 0.0754132662569323, 0.11404870438479608, 0.15782197246388083, 0.14779723700015776, 0.16330264208297576, 0.09311929720664218, 0.1416426398340733, 0.08006204865993032, 0.20866981737555998, 0.1340114081939382, 0.10460865488576312, 0.2816872202580975, 0.1907791209317023, 0.09479580402013757, 0.11526427907688964, 0.10760808063130226, 0.24397631235901387, 0.1447280589491129, 0.20861226885068804, 0.20623915828764441, 0.12688586353174142, 0.08618722038884317, 0.0977181306769771, 0.2445094942325546, 0.12467278873607998, 0.08418949290869698, 0.18209958989774028, 0.2278482616548577, 0.18721950871329154, 0.10556143077631151, 0.13800272627943946, 0.198884560996967, 0.1710331587180976, 0.11156229707863062, 0.1087317324333614, 0.18095165310848146, 0.13031552425555645, 0.08549348946901099, 0.1390434567245745, 0.13956949865866092, 0.15911332091256497, 0.17422377702689942, 0.11962222386031382, 0.10751504691377764, 0.08373718693732254, 0.10756172465100404, 0.1200836999041419, 0.16615556883475474, 0.13029597369172882, 0.12582350642450396, 0.12140124855983643, 0.05897246781856783, 0.1798007592198349, 0.1648825145657024, 0.1702587817224764, 0.13267887485844473, 0.09358910062620718, 0.06985574269727354, 0.1000487999690156, 0.18825830861685738, 0.1522733508459022, 0.187793446464404, 0.09259078846943956, 0.10969996031734253, 0.10149679041557735, 0.13200831809832206, 0.17047060503353997, 0.14729400916445642, 0.18574239926472788, 0.13829580087575222, 0.17651470167742622, 0.1770042931480754, 0.12035545427352191, 0.11355383456834864, 0.16705373031718118, 0.21022857647509346, 0.06370322545990348, 0.14920418811661584, 0.13264577986011583, 0.13319527940644374, 0.16277676868823268, 0.1380622206676391, 0.1356352234800016, 0.1808452588175574, 0.14779329930822696, 0.13776044331250653, 0.06550709822125013, 0.19391813555792456, 0.19946154777801808, 0.11263083651541703, 0.20685729931198782, 0.07221307184907698, 0.1919613478164519, 0.10724589724334017, 0.15512312131543315, 0.14553050540627974, 0.14820099597977054, 0.22641360879905764, 0.1746807637954912, 0.24362481589759552, 0.19323866153436323, 0.10249782218447617, 0.1620804254085787, 0.12349471404787996, 0.10689600190568356, 0.14959193585861116, 0.15806758025240514, 0.1480847804416572, 0.24512201217153382, 0.10595811876438319, 0.1782768417990977, 0.12806986007959614, 0.23210484534502032, 0.12964340467606822, 0.14134484613614698, 0.13559434502836198, 0.0971958885389951, 0.18633145959146563, 0.08002755938157921, 0.10408168598528832, 0.10837372422458665, 0.11498608956894568, 0.06506891891119942, 0.13957288476728624, 0.19013796662611349, 0.16475617134523007, 0.12226231606496919, 0.17682875176110577, 0.19273146536321412, 0.3442529468767105, 0.04997995156314104, 0.1478578958420023, 0.10826244229270567, 0.07310159594541596, 0.14917906043269943, 0.16395023152712854, 0.08479930655730349, 0.19664306433931475, 0.2455907354071256, 0.13629385991202247, 0.10680302181431364, 0.11020224586489702, 0.15868328511714935, 0.12229262250325373, 0.16565175877223093, 0.19998933639257185, 0.25362371887651186, 0.15418368301564647, 0.2026043468785863, 0.12794143309996975, 0.1692718306496259, 0.1996027990694969, 0.15732694176896928, 0.2118716052462978, 0.1135268223081385, 0.23218114770227866, 0.1460405361027487, 0.12202324300643899, 0.16692872008969709, 0.1369160458806061, 0.12163911119944627, 0.10726226854228205, 0.13711276193780286, 0.13923254254604542, 0.20642141060483074, 0.12922453844258863, 0.09864079165122203, 0.1737968515484564], [0.014045528782111023, 0.06391688355154569, 0.040853074977114316, 0.025107840323940884, 0.05491196050218517, 0.036241302281738295, 0.05066926981652937, 0.012535106000160019, 0.0348954466772416, 0.08431405880518499, 0.04315874298974391, 0.14656578130539388, 0.057123231160784924, 0.043126103813729944, 0.028402947279955112, 0.039363271451645324, 0.022341749638379104, 0.11407706495975295, 0.04889813199218723, 0.028710353466111328, 0.03213504036407798, 0.04083525577199556, 0.012899244827548824, 0.02958080363309672, 0.010962856092279958, 0.03561202233897583, 0.03841571261986129, 0.028975103876643607, 0.031591594827571706, 0.05766129684484294, 0.014714863631994495, 0.05742366786205, 0.02550284100335933, 0.0257107668421081, 0.0478997087526706, 0.022737405322972807, 0.008090167144884267, 0.061379761224792856, 0.03985342216647921, 0.046558277305936625, 0.05678629036992789, 0.03768514053175046, 0.015624051992481035, 0.09861092954393356, 0.011055634127959851, 0.043225990187737255, 0.09620211162273923, 0.026112786802132765, 0.06622188889812078, 0.0357840818563296, 0.07741156064214245, 0.04830514546483756, 0.0039153537645395245, 0.06513988163562552, 0.014973600252321171, 0.029201586280138265, 0.041032519582058155, 0.04304473378485249, 0.03285417092903968, 0.02874731146279843, 0.023718166405395157, 0.020477041834965348, 0.09345993820217349, 0.09830955821540087, 0.03649971906035658, 0.04568593681699807, 0.05764678330911745, 0.03694230720641152, 0.01044328281310417, 0.02924358513536713, 0.051377403189338026, 0.06664421018813887, 0.039146637108417294, 0.02104586020352379, 0.017107082343089487, 0.013764126492934603, 0.021423941831134503, 0.03563160354632043, 0.0407288997854677, 0.03566564466323584, 0.015591472188281197, 0.02217919918738546, 0.08143258761734733, 0.08624732764738222, 0.03631444069586935, 0.05694977736340896, 0.011890270642095037, 0.03424893358662244, 0.03437998441738948, 0.025851501024238048, 0.06975880193133509, 0.034119181274887056, 0.013946968697822623, 0.03562432571103977, 0.05455229371305435, 0.043422327031411474, 0.0526924352462013, 0.0761466958530007, 0.04661138252084775, 0.020930937438782667, 0.0242863948862519, 0.04185126072937443, 0.036358663121298436, 0.01817308028318709, 0.028689483315834118, 0.0361891508462929, 0.0625083542939636, 0.05013264054732938, 0.04582469066184375, 0.05327240977015707, 0.015090963964711036, 0.023964975036740787, 0.0729280693696872, 0.020921102785054716, 0.03025813261047006, 0.02969932318064234, 0.035047258490756635, 0.006938466469892451, 0.044187905507222305, 0.02232488421272607, 0.020302247383721897, 0.05751322354039839, 0.06193979064963999, 0.012769105641411678, 0.03211478116892038, 0.08678835426126758, 0.08921584174517663, 0.04904794048578028, 0.008678892308155136, 0.0223631005088288, 0.04564368323753438, 0.04469825029974023, 0.016002165221218622, 0.016941318153253487, 0.034083592660364606, 0.04972513922820649, 0.037735231190679536, 0.09356854648719873, 0.062320264386794264, 0.012764256304850983, 0.04209384630103746, 0.05487873526890913, 0.021217866094722863, 0.035282474296588096, 0.02660543113316019, 0.013296849248299917, 0.0031870878404832536, 0.09373267316409657, 0.08222918882365189, 0.05620158525303968, 0.04965360193783718, 0.05141767643151745, 0.06316299174701975, 0.023067246393991575, 0.08912487646504756, 0.06397152860318461, 0.047143013066341805, 0.0302894598609137, 0.03415231457761219, 0.04378390137947375, 0.025752694834203973, 0.0026784329900457976, 0.04262640764335952, 0.03309928459085284, 0.03495955291474539, 0.007158685146996211, 0.004809503340267487, 0.0836674882579715, 0.06379810544932563, 0.026984594859963944, 0.05103039217271632, 0.03986969770443055, 0.016434878493929585, 0.028602553403846202, 0.015749223098429223, 0.025533609009618242, 0.020521461528034943, 0.0255201967252839, 0.015145289174641575, 0.01610330606420194, 0.068926562314793, 0.0373827732889162, 0.002776808255622464, 0.022106618102219318, 0.02542634137846049, 0.01792708753548082, 0.01553067928104992, 0.0498498851553567, 0.06650871987785063, 0.031450768714890845, 0.01370218158098719, 0.03559778076446345, 0.01067999536321769, 0.02342083427544323, 0.1431641210952113, 0.015916507972794917, 0.07019216254834207, 0.053873593438296556, 0.026086012029179165, 0.05788459232257259, 0.030149606679896676, 0.05253037317625938, 0.03630335540360501, 0.03136520052418834, 0.04661066622863855, 0.05499433027580381, 0.02553234687976299, 0.055498151829646486, 0.03576664952561259, 0.026951591792185942, 0.06276083389116872, 0.007619898326905265, 0.028927568120942004, 0.05716786727369313, 0.03253494975187125, 0.04586379561993865, 0.06435078043009966, 0.05254931853062684, 0.012880112739249825, 0.02636894553659424, 0.022286175705131986, 0.0056255670102883975, 0.10666147174854433, 0.010671794391988267, 0.0278650961005159, 0.009249418095174817, 0.024316337432772405, 0.015143850844563737, 0.002433611878058723, 0.023244798761762442, 0.05691494334549193, 0.07846684675783881, 0.052406427810990044, 0.01584773434461245, 0.033786074754091046, 0.025466620366299347, 0.032071401440208, 0.027356563105938897, 0.11748594937906151, 0.024756646467252605, 0.03397544019765431, 0.02489609553688957, 0.08083539909773296, 0.01958540742165379, 0.05775547969425398, 0.005315923368588331, 0.012729813949385238, 0.02357952555851831, 0.031849908184320215, 0.031227758604912993, 0.014236204236024811, 0.034359480074096116, 0.02057192757004692, 0.020472202074503707, 0.043019506509505936, 0.028761424717583486, 0.038883370993238305, 0.008816379235096036, 0.07872327170785397, 0.009284205190206488, 0.13814239942979428, 0.09570139655542952, 0.03537404861661696, 0.044585880523006764, 0.07503288061988932, 0.019380159060200377, 0.019390472518881003, 0.007171049806094098, 0.010528741836277469, 0.027136349216884664, 0.040660553251303015, 0.06587623002668543, 0.019110101575572646, 0.028830167702248985, 0.0060288524518029825, 0.025717653972547383, 0.02657962354621099, 0.03840926215953885, 0.04008249011671832, 0.012857452816059513, 0.019126099406651432, 0.021745327206689025, 0.04180762053076779, 0.04508228251530279, 0.002188422325660565, 0.028245516211515474, 0.011006654296520977, 0.0536844271775936, 0.09548853136478894, 0.09728436403337026, 0.03150367474694166, 0.051005168727809386, 0.03336349682461831, 0.013370639794776517, 0.03484779983879097, 0.023477057468206174, 0.026049504109147577, 0.10657972250614436, 0.02550677678007032, 0.05216771098334463, 0.040627511879128796, 0.06481552766936441, 0.010770591005923287, 0.08172136446040484, 0.016529660807141376, 0.03925854340195656, 0.03330926929089812, 0.054209285505837014, 0.04558824528489382, 0.02695021474914205, 0.060487598210813544, 0.03662561411939321, 0.02563679913779901, 0.03226380059195142, 0.04048687728842901, 0.03246070817112923, 0.04598338194491883, 0.07135492313893572, 0.04231061854009186, 0.0915352878491244, 0.05663304980243406, 0.035046752872726614, 0.016262474237009883, 0.04764536756180948, 0.059843862188919905, 0.04120163349134307, 0.03877035004176921, 0.027006370909211617, 0.04463606694292638, 0.004527881758422741, 0.03139801206998527, 0.034741424700065006, 0.02263523409173133, 0.059457995192778695, 0.05019063723363704, 0.03466498061654068, 0.040487988115919214, 0.017125809362398523, 0.09269156733587866, 0.041565571220651756, 0.02907614129775715, 0.010997681491707843, 0.026621825414739793, 0.021082115314540364, 0.12388862879766573, 0.016779715736066143, 0.022911200029475075, 0.03646213478679138, 0.06926485908127601, 0.018551742222400445, 0.04748837316348668, 0.02721914416930128, 0.09913828914924976, 0.11572440680597099, 0.17652348104503848, 0.09586664172069681, 0.0993728039846305, 0.15761229419900527, 0.14825613898856027, 0.09495187911295122, 0.13144351211526703, 0.11877914409964316, 0.09695019648079911, 0.2980093669987494, 0.26601511444295606, 0.11212796874104008, 0.10814159958352966, 0.15346069519798602, 0.08855737385249908, 0.22893708709987903, 0.2653457068147198, 0.09648417753558006, 0.17613499785863584, 0.12917363956089944, 0.20801225346663307, 0.19671048007665143, 0.08591168154511722, 0.06060340772232702, 0.10890568035744852, 0.09744281399874918, 0.16377452160081557, 0.27337072296969356, 0.15557074648959024, 0.12456431068600186, 0.14977228827774525, 0.15059966323596818, 0.13509484037997263, 0.09477011709203643, 0.21281904150401393, 0.17505944105646304, 0.12107233637042585, 0.10269257705658676, 0.19686178244169683, 0.14243952449290984, 0.12525658603877793, 0.1942955411129421, 0.11686467505510777, 0.19342950935806, 0.2918769557389521, 0.1148084797445805, 0.21248495056023523, 0.09454481063350555, 0.09748504076513553, 0.11532791800075963, 0.10661455652406139, 0.11462423559879104, 0.07859463788448803, 0.14068159785482193, 0.10788573387769923, 0.10938587192926677, 0.12448477543770306, 0.1444707300153471, 0.12139157286935276, 0.06728557133746725, 0.23027974811773147, 0.22183382793539957, 0.23086336922020684, 0.11476621467379794, 0.14619404480101603, 0.11723922310216774, 0.24695965791902236, 0.08875289481253394, 0.15500724285600648, 0.234144110112421, 0.13329450311439653, 0.09238146260500917, 0.07164252786746911, 0.18430560136273985, 0.09590466266437885, 0.1692441442320424, 0.1324477614534478, 0.23659690914134826, 0.1052970844771593, 0.10932875241363242, 0.2799939207973019, 0.11953175653733554, 0.22738529940045651, 0.11507828058975358, 0.1167010463353607, 0.16837681012768901, 0.16324178405827092, 0.1209144916145071, 0.12578045994403864, 0.10901310120619113, 0.07711224242924683, 0.13029998799245204, 0.20085472463359758, 0.1459893307858898, 0.18139938553494794, 0.12186280887333617, 0.14371342145867888, 0.1647969425445603, 0.13107007489569727, 0.10291396880582457, 0.14071619438548244, 0.11010423257586457, 0.09533431020475204, 0.1125121005480328, 0.11157433231992107, 0.11245331096072352, 0.11646721331823258, 0.16659265263907372, 0.15179325886551412, 0.08282092279724537, 0.18168973285825024, 0.15247913738412244, 0.12893941583892993, 0.16916442512264177, 0.09920568190394871, 0.13427603028474316, 0.12378071765265158, 0.13337414561500474, 0.1462764911834271, 0.20245393317553306, 0.20384525609833581, 0.13818666399005922, 0.10268863936465594, 0.11176205450488676, 0.22249467070064238, 0.20375845833651482, 0.11153834150923837, 0.18371916105670316, 0.08716657186948484, 0.20990449063960584, 0.11456674070007379, 0.0938580664355428, 0.11177146206459693, 0.13183250091969967, 0.14691484160721302, 0.32805144366237426, 0.19218530596023609, 0.07453033460244056, 0.15983872956806616, 0.18350042763256258, 0.10669764642032886, 0.16588278024667696, 0.2282031289031429, 0.10881803223803159, 0.10100012029250784, 0.20855079795564377, 0.16091174295833036, 0.22679413999280623, 0.12755760772814675, 0.2109428615339341, 0.1441731201785226, 0.07235119750182475, 0.13963498385442843, 0.11291876300087861, 0.13643164848608358, 0.14045626075277406, 0.10508068762118779, 0.1349912499708514, 0.07124430004266963, 0.10549203087125095, 0.09686911373489326, 0.09491300015079399, 0.13505763915036956, 0.1124708467133103, 0.10788534317285785, 0.29732911156550534, 0.18681440141893205, 0.12605386140245584, 0.13288908938486732, 0.18373698026182192, 0.13465807833258184, 0.11408275699303036, 0.20026076134414444, 0.12737500301051524], [0.052203265123910485, 0.06318751039103636, 0.08126404827400562, 0.08352900254389933, 0.05419200639270487, 0.03675862230480679, 0.02926879325851558, 0.0765093312328381, 0.05901396680142611, 0.042263078953950636, 0.04437647804978394, 0.04685394510987305, 0.03359623433601472, 0.09863647857620832, 0.052833280511080265, 0.020359416695071325, 0.04118249661499455, 0.03271365125152854, 0.03290768217055067, 0.061827275316200914, 0.013960549521500306, 0.04847092689165185, 0.08342185748680946, 0.03899576758304912, 0.03897866083969993, 0.02104839595455316, 0.04610279206967643, 0.04922799413062392, 0.028662545749196605, 0.036940740556606365, 0.014752525471962027, 0.019779377053641987, 0.010179611628935223, 0.05640969303767047, 0.04159471320529138, 0.06753044368158426, 0.013391300228484457, 0.011166562701785758, 0.0401620215345775, 0.0411598127515566, 0.044657486761289264, 0.07299137887574973, 0.08378944945551696, 0.016245319613165433, 0.025487343044651133, 0.018670279006924362, 0.019164076300277826, 0.031840102258889426, 0.0677142205137399, 0.025715698533120657, 0.03194009396998632, 0.04104889471143965, 0.05486584967002273, 0.009563359011325144, 0.045432369374940475, 0.07028788523448092, 0.03632195601840654, 0.0413943390782562, 0.018843840056609724, 0.00605664803691569, 0.046089841353316466, 0.06665190171089865, 0.05646023568847487, 0.034732246966732126, 0.030933431454844056, 0.007084134737059715, 0.057716466666709994, 0.023420081594057625, 0.030286006719595006, 0.10131187211241453, 0.04360081402644996, 0.025761981735066063, 0.044065837057367455, 0.019856296111679366, 0.03865573179697798, 0.043537937360064644, 0.03062048453777548, 0.12261446370112321, 0.007398968145641829, 0.04200424465741362, 0.011813838049889573, 0.05383364578348495, 0.02032127509254121, 0.05434828832925809, 0.04875322263086996, 0.06475738925679077, 0.06552007575068744, 0.04473540173362821, 0.05524386426494007, 0.04347703720052396, 0.01711535034701228, 0.07890350921379943, 0.004924233146612683, 0.05089597438552207, 0.037888019766298034, 0.038348530539341515, 0.07772739571068557, 0.03905395579133784, 0.03880240699096072, 0.05456419105851843, 0.047177088657213796, 0.012712526217763944, 0.08051410948316898, 0.008342536616950266, 0.016712081663671042, 0.05921504572935163, 0.03568297357208306, 0.06952118443986101, 0.06520907469694653, 0.01514571626865936, 0.02142377903745059, 0.039013360792230216, 0.017825676646504193, 0.017601147767216448, 0.03197592773264454, 0.02460468335137252, 0.04219886163369783, 0.03875739549496963, 0.01988519869384266, 0.07700466836291937, 0.03910815268154106, 0.013465165468533675, 0.008797318009930033, 0.04989337979725773, 0.02574018078796085, 0.008693035248847259, 0.05697580903107601, 0.034754930830170075, 0.022897412362057838, 0.021234712368177793, 0.03249360781703745, 0.09188641658833913, 0.014575964230443201, 0.01578662829894212, 0.007188732551801349, 0.056243609006126086, 0.06036047358065844, 0.06148483401404754, 0.03453666855010294, 0.023679601539286877, 0.0085344550485212, 0.0408364623604763, 0.027254638938053, 0.022430822681335193, 0.051150342389460535, 0.026958019269870657, 0.07470515586676137, 0.04664820070648867, 0.007997802317878533, 0.019250686370557355, 0.040751966692867785, 0.0015910904039628806, 0.042449288115265875, 0.07636329955271176, 0.018529066019841743, 0.030798990685012073, 0.1273825796200864, 0.04458679216763666, 0.06789563013420952, 0.031070111116634744, 0.01818553304239627, 0.01724541483957681, 0.021689144233542106, 0.0187241388184409, 0.03149822211614059, 0.038177007283534736, 0.06450598218267964, 0.08920733816921712, 0.02796187215755063, 0.07121668257299932, 0.057667046334714665, 0.008423804181567844, 0.027604729628130317, 0.06436902864445603, 0.0534692484014217, 0.017328110200563268, 0.043543031844761104, 0.055850977453613476, 0.051680440759106036, 0.029740605743662007, 0.008967551365194303, 0.03255802048971096, 0.0851907238604561, 0.033486580340972835, 0.03184676722383067, 0.07575442819225212, 0.020813588090541384, 0.008910164676396357, 0.059028813585398666, 0.07212886346444007, 0.01881117981317784, 0.07236186144573074, 0.025900848577880574, 0.0842771563498724, 0.01234168507864759, 0.03494634938937041, 0.044484737764803634, 0.06806196314432929, 0.011237391360825109, 0.09241041306766773, 0.014063997246745615, 0.05838297082171325, 0.028702773026100574, 0.020075590695224462, 0.008378678729998009, 0.10641798602357026, 0.030842450852956504, 0.07111689962086178, 0.042602222247589985, 0.03793560914815434, 0.029325671456453782, 0.0299020377062862, 0.06587174075144915, 0.07051591896602223, 0.03534587190276192, 0.05533257724657174, 0.05454454856413988, 0.041184959587671106, 0.04933071886039069, 0.08091183168993843, 0.09283046673742995, 0.053984224195441896, 0.05386655309027242, 0.09251406476382287, 0.03736160244912871, 0.008431424841194624, 0.03866742995958175, 0.04174435315954109, 0.01160461848015867, 0.02203650382016936, 0.01698828125823169, 0.024420056161620927, 0.025126946556772438, 0.06059735945816483, 0.14500146040753012, 0.009728931679180073, 0.07095068152393065, 0.05861365138703297, 0.04790808592412261, 0.00381400871124389, 0.014322189944646051, 0.03270080395703835, 0.03272698118141101, 0.018503911522847992, 0.040347265425108136, 0.09631728528127556, 0.02615218095841908, 0.053787914164845026, 0.04226441577737851, 0.055915991505307544, 0.03484365913356024, 0.0709778776452426, 0.06944313540213531, 0.04419380438423926, 0.03871768532741455, 0.006006587063893677, 0.010401972479397252, 0.04959504983778443, 0.009480218361732701, 0.057659592299211415, 0.030609765052494985, 0.09523772183925876, 0.034293224959964716, 0.04250530063384964, 0.05622482069978311, 0.029437616054389267, 0.08284710002161803, 0.022301361483011036, 0.035819528744586056, 0.005558224530109475, 0.01853943501989688, 0.026668152666740844, 0.03643281277148955, 0.08700314999347733, 0.02606909106215162, 0.009976523635428279, 0.03275227740467076, 0.005950119680604868, 0.032479925486709804, 0.04988045972441474, 0.03214878015099995, 0.0066559490439812505, 0.05140559905539117, 0.06898999439492341, 0.07193863617196199, 0.06576948333531618, 0.012042155233962883, 0.014732287344222349, 0.029105009405963847, 0.11805767313607278, 0.028423436301489993, 0.01286130719592855, 0.09705346513299212, 0.028429279637132442, 0.017369210817700913, 0.06007664183515215, 0.03347564060541411, 0.01871233531874755, 0.03661664706023951, 0.02929902691844731, 0.04081803028501811, 0.06145986337815562, 0.033895698105615955, 0.049882026374219894, 0.06995983872442477, 0.01872056501827413, 0.04628812789075798, 0.034531102921333046, 0.043330913589846705, 0.05326126319085879, 0.04757088466337131, 0.03609959516794451, 0.057920671233366576, 0.05100730228267851, 0.05676400487221057, 0.08389382127432093, 0.014287624057502517, 0.017891510412277236, 0.05272580986662258, 0.050680427887146516, 0.027296706741195054, 0.04507086397479138, 0.02072963634535911, 0.02550265522703769, 0.02305266965601233, 0.028367205447847807, 0.050789438368332, 0.05347572950526111, 0.015509156998427165, 0.043054704419187004, 0.012978645052850969, 0.028399731625892946, 0.04123569376045658, 0.028994323107443994, 0.08305066490485784, 0.016082137139634262, 0.046116252234506036, 0.026175092733014497, 0.05099870294572846, 0.06965607720156831, 0.006786137068223569, 0.028065326586065274, 0.013731988146901132, 0.0568542845036474, 0.04523459611640823, 0.0050681216957708525, 0.022455873756459164, 0.061564507158172715, 0.07022360279675453, 0.013822944808541047, 0.043797081922211, 0.02617110907580824, 0.21236302000620674, 0.10662959483001502, 0.2487107510528257, 0.10574811108170018, 0.16612327056786708, 0.13336826205974625, 0.19627149637428024, 0.26307048696664076, 0.12518511003544255, 0.12033226479205394, 0.11473825246456171, 0.09243883492965853, 0.13381695975699734, 0.21555884771289366, 0.20423499566893424, 0.18866962122340358, 0.12029723159127659, 0.14937850376290662, 0.10843976100365962, 0.1462066392864912, 0.0958071320107387, 0.24283041336363365, 0.1424192078411579, 0.15328765125764957, 0.12389675699054234, 0.14498964733173772, 0.2021545000494488, 0.13774821654923503, 0.05913023596569415, 0.20575359643947697, 0.0682804897247303, 0.2336304788027079, 0.10870008534120937, 0.11491410028670104, 0.1019149671699251, 0.17135295446120924, 0.2867876497968551, 0.11787130692673307, 0.10732877263498884, 0.21107750914750562, 0.1589273913733421, 0.15841616557971125, 0.15734200305756063, 0.1319337317780141, 0.11134426079450116, 0.12208808468835008, 0.17665936972104734, 0.18823865080072036, 0.14620181293256823, 0.16892883776416703, 0.19211528552395685, 0.23637175590040224, 0.13838797657480165, 0.06146281664710372, 0.10448037346284236, 0.2225271375068734, 0.14240779313108615, 0.22268659104743313, 0.28628825240077516, 0.048098052746706435, 0.16852893986769263, 0.1521396378595983, 0.1779556211324469, 0.1425777727197255, 0.1014101228887035, 0.12023931534420099, 0.1797837214243989, 0.09638700694326433, 0.1858343911026755, 0.17426323055499987, 0.10471690310946397, 0.15849301952027506, 0.11024935261136103, 0.15230779415897786, 0.1498036365956068, 0.15812496023793376, 0.13915856909607688, 0.25497758009981725, 0.12970531990210857, 0.1426010005055897, 0.12381974217151442, 0.18754520333342015, 0.1328601312613295, 0.16362069114562006, 0.15635629304714743, 0.25801277449054105, 0.16148903617455115, 0.15038489814727538, 0.1754815248592246, 0.1379227467001446, 0.18921754262860746, 0.13906596438778987, 0.1227517543180335, 0.15295736010997527, 0.134383742246897, 0.08564348948458511, 0.13880578560694573, 0.14438062275369323, 0.21085526704067187, 0.14486722648143768, 0.1347918526059197, 0.13131526899674248, 0.20940290223206245, 0.16044306568801403, 0.07816557502073627, 0.15973818818888358, 0.14665461686109343, 0.1478430950233052, 0.20052216586566743, 0.15876324937468575, 0.12511423158068813, 0.14776987233950248, 0.12321516090343076, 0.1699256560494823, 0.11552893181121159, 0.1332675061759449, 0.19497513771057132, 0.16039130878784966, 0.11300182991450834, 0.09946435149158202, 0.18314413546073824, 0.15810825952118443, 0.14602524498778005, 0.13217512608295487, 0.1068948987390726, 0.2276081390558712, 0.2100587347822805, 0.10409252612941688, 0.20332145114098826, 0.11589961877513318, 0.1446479874392671, 0.13048245481425716, 0.2616039495314321, 0.1698845784149824, 0.11008573921337245, 0.1621044805694011, 0.13751385493143914, 0.09655589102617196, 0.13686085690654096, 0.13376753176412276, 0.09182587265968324, 0.08242329252102683, 0.16661888348960108, 0.11128830573251171, 0.11797182532327792, 0.15987046092988985, 0.14173519857708486, 0.13868877333739113, 0.10209314389935426, 0.11222767508438519, 0.1261104982826979, 0.1394044986415294, 0.0956950763300542, 0.09291731812540563, 0.11473552519155127, 0.20664037385534859, 0.2332086554698406, 0.09515474685617993, 0.16537540021442598, 0.07217889666677484, 0.07892894333288555, 0.09082221320920414, 0.1725092722523597, 0.19036514233917962, 0.13596013669044743, 0.10382886930939653, 0.13422099452826286, 0.27962625988068124, 0.14405673610106592, 0.18741234836559142, 0.20307231934801226, 0.14700828901221677, 0.13975817079265274, 0.1122898354585613, 0.09916805166510806, 0.15644663013517857], [0.013438010524447649, 0.06026083618522652, 0.0712404466204105, 0.019225256081910867, 0.0655466819842977, 0.04774480960482071, 0.08003757215074955, 0.044078707334495364, 0.061990356283082124, 0.03893980486018043, 0.02313775712654235, 0.05323486763142771, 0.07458664206487518, 0.04104419093158457, 0.029280324796995813, 0.012296571118396618, 0.08054909671867087, 0.009123782548422535, 0.1041803657708149, 0.01389744973200704, 0.004686939327286616, 0.026000742612767126, 0.04896589246908984, 0.03199725179001689, 0.09145967497099793, 0.007367795549197904, 0.006264512588630521, 0.008349214988430182, 0.023565293560104988, 0.08997668196717579, 0.02821536873647523, 0.07629193080168578, 0.029675928770654628, 0.06799196569068779, 0.03268353250478545, 0.028551667928695682, 0.026612199519971208, 0.04391330129076396, 0.03868294707048805, 0.03736152584033628, 0.051304149862018325, 0.02286198845643911, 0.025075509498316436, 0.09230577311809025, 0.03637500377672334, 0.01776347605271205, 0.03698167263440067, 0.07883892034090335, 0.04117795754404318, 0.036401399336154425, 0.02589352669254426, 0.03588122563556798, 0.07036222640665309, 0.07122993589408937, 0.015091480116450019, 0.05194900820272104, 0.04484180751587114, 0.006798905838701514, 0.04554545927432276, 0.03154580192189784, 0.025078453191165483, 0.019286880194539988, 0.03265157514702409, 0.03923616597368833, 0.09087849002812179, 0.08677205957111814, 0.01790957285031196, 0.02845716140713663, 0.055266341284638455, 0.003091989276600221, 0.012201847219389054, 0.07557523256588368, 0.007778491933769997, 0.05843338323757053, 0.03919321908465317, 0.04585878540491385, 0.04493364230579427, 0.04287092375659174, 0.09174231544978197, 0.07252552846987402, 0.0333833423322968, 0.03484326076783961, 0.03143873921925983, 0.01019052838185622, 0.07398492596562832, 0.00575057628016258, 0.03524699293437504, 0.014765444587195113, 0.003096079707310926, 0.044428403489291675, 0.10121734452343757, 0.05189429420316893, 0.03733494258936375, 0.030364396666447004, 0.03229128016579536, 0.03589911761903956, 0.08851204443001941, 0.08194103251181303, 0.05051595264024312, 0.031134249912875316, 0.010058642515251714, 0.030899692942658742, 0.00729451445119095, 0.045960663607524294, 0.08266335383297936, 0.052013374910119085, 0.04626877267935103, 0.029187413653539076, 0.03207745736524944, 0.039737608824526115, 0.02377479945519759, 0.018634979590593327, 0.03717746555564865, 0.0502485458198334, 0.052516905350550536, 0.030862386375966094, 0.03242245740106991, 0.04610717026216369, 0.02395673767633496, 0.1405779001933913, 0.06589852318528198, 0.03625541362130354, 0.06244996690281457, 0.02398028721912734, 0.023318090393478354, 0.06422378603489169, 0.06955329884564684, 0.06127559624972844, 0.06922467010876826, 0.019119068634726347, 0.052538742686832146, 0.07396782688315838, 0.01857464825133643, 0.06113662406982434, 0.047791349446220745, 0.01430911761182811, 0.004763950794679864, 0.013244057171827844, 0.06073749992215346, 0.0273945591517634, 0.03508182054746055, 0.02478255173041215, 0.0115719611095565, 0.01853206716928511, 0.03345696721225977, 0.01320725430794541, 0.03694278984180382, 0.01559721593249349, 0.004130885898766499, 0.04404021141630027, 0.06603131686607677, 0.024525864395282926, 0.018435858017314347, 0.025978349862740408, 0.039981638471926415, 0.04013671381999889, 0.017259710040243886, 0.03660851503692327, 0.022269457751404376, 0.02835563752019117, 0.021761286733371597, 0.02778361881932905, 0.03127704678674138, 0.03367507627474205, 0.06430676867884975, 0.09236207291964563, 0.027510196293493914, 0.034126639140829924, 0.07989349399483012, 0.05494699370296252, 0.005684120546756012, 0.019480876639605533, 0.021909972908155575, 0.04055177642693443, 0.028454552877754457, 0.0398471019411039, 0.03792437829918439, 0.03555443550970766, 0.05748641812392781, 0.010171719965705229, 0.09800441007340148, 0.04472075796295558, 0.02643534429221144, 0.03354386456551091, 0.004785897298490689, 0.04138411563490668, 0.040237488855998364, 0.07764386148342202, 0.0016532951872983588, 0.008588135786985439, 0.054882148190611796, 0.024323848924869974, 0.021996785991735036, 0.054440360606437734, 0.009708514478388093, 0.02394546086208955, 0.05928387489890861, 0.05030301467124974, 0.014456567512224279, 0.08701094876854651, 0.10011492867863948, 0.04302536708212668, 0.025240928948586507, 0.02634171494132569, 0.08207811628498378, 0.03409497672691941, 0.03958597704167328, 0.06270241585650271, 0.04486242294191353, 0.053347011412223505, 0.013696942497195016, 0.02225365718796609, 0.07856531203874657, 0.058865671331483516, 0.029583212979618582, 0.017609772002024036, 0.03881877062902336, 0.020050357674218474, 0.030407090746467153, 0.032932036105663545, 0.055967487935577674, 0.028853684686304584, 0.03379243328386257, 0.07605583016430179, 0.053650849543872385, 0.061508709144207745, 0.019522982747143796, 0.06545416920656158, 0.04175873262987983, 0.046045040531504544, 0.032009468977189356, 0.08646797629133349, 0.020731676054457505, 0.05903619101210948, 0.011164706853789189, 0.03098114341076824, 0.02337202106812789, 0.02489492150714561, 0.04400529695915119, 0.021001534356224923, 0.049696380287529006, 0.049786491379622495, 0.041495688680198886, 0.023950796664482164, 0.05670885037210199, 0.012770616749842322, 0.06968722633656955, 0.001568242908932359, 0.013043388100941817, 0.04904026045433937, 0.0090330729501382, 0.05619657886845451, 0.010055943012928531, 0.076665950248078, 0.039516312836278836, 0.05373422289267183, 0.06450595920004192, 0.018430914834982926, 0.02720478385116064, 0.035189452070382335, 0.03363495625014748, 0.05214974622152025, 0.05334809542663636, 0.04400218664217861, 0.06018139286747864, 0.00876031500557738, 0.07694701258573802, 0.05640764758291264, 0.04940930415966338, 0.04487384148242493, 0.08781924813745484, 0.035470162007597186, 0.04320467762168377, 0.09056139857538285, 0.03975192317739129, 0.02850790324080135, 0.038667514229253415, 0.036417268847505894, 0.02174905422444065, 0.1423920883286384, 0.011591117138103133, 0.05924391958321776, 0.036268417963818196, 0.029409272716410702, 0.025513185105556925, 0.042265576400583794, 0.03934376302265352, 0.032458543972743135, 0.023259318043147365, 0.04159262944613734, 0.05440446555674557, 0.09304578340942822, 0.015657827851452654, 0.05003930805551429, 0.057466813933945475, 0.028736480894768913, 0.016959631485083414, 0.02236036749015893, 0.017113078896316792, 0.07104770655954076, 0.09104647012727876, 0.046223650100610914, 0.015268695405534199, 0.012371866070034524, 0.015169339547414454, 0.019994471560142214, 0.04165563251703017, 0.06766270110083204, 0.05891257123420796, 0.06068244118303542, 0.002673714127834706, 0.055090512614697225, 0.02088634154549049, 0.014072669362048469, 0.050140079261074146, 0.07157912643085565, 0.05534703715614254, 0.03611834133945165, 0.030427432296076612, 0.05099399533543376, 0.070543046139421, 0.003859675930617678, 0.01811719225389102, 0.038261039467949065, 0.020098843378946185, 0.04452051024042791, 0.08920370691245602, 0.14679050553710232, 0.021383055718615655, 0.06018012116152433, 0.01738397141678199, 0.026157579963065447, 0.04147350660435135, 0.010819196411889168, 0.022158210293479988, 0.028369116837218888, 0.031160842739946903, 0.031120816561123057, 0.029966053928458886, 0.035396575432030425, 0.01040807341210424, 0.041829507662764484, 0.03832033850372799, 0.07334265317167006, 0.007100536200713607, 0.051249455014664325, 0.021106007681678862, 0.08115530209315401, 0.015009566165146329, 0.021466078582189737, 0.033321687576150706, 0.03419940600231771, 0.10346412718776735, 0.13738248617418353, 0.23448414589849212, 0.11500300479031379, 0.22123519150960833, 0.10606777658986469, 0.1409636867503005, 0.09865989022317434, 0.09060169480020001, 0.13199503413371502, 0.11495101806377211, 0.14767538305492173, 0.15113886656059375, 0.19146380435314872, 0.14065199621742772, 0.09540701194876626, 0.2156665596750475, 0.2167949152569617, 0.20826186023412213, 0.09844966037499328, 0.10051444353115174, 0.16535257079428242, 0.1491907049691485, 0.11549254263480825, 0.2367123892350543, 0.17451504365571086, 0.20512275367734895, 0.10709666331569034, 0.19971199724222385, 0.1713712026755656, 0.11660436603931651, 0.16191085950741846, 0.16187523641893942, 0.1344908566604699, 0.17567529913879212, 0.10811249590328625, 0.18444064734203203, 0.12053811261730811, 0.10675053713062119, 0.09195348758610988, 0.0933200735298376, 0.19298995875062483, 0.10606876484328702, 0.13800341575857134, 0.14834814614826633, 0.08546953389961874, 0.09297671292217509, 0.19258970845370524, 0.15158557242924167, 0.19329146031410466, 0.11911911859868035, 0.23537126039305042, 0.15291422935983828, 0.1930348974682631, 0.08496946234616541, 0.15485054723197414, 0.09322242030212957, 0.1814457338543669, 0.11134609174464019, 0.14022726175044814, 0.10152971687456293, 0.0880467685900869, 0.09903179526689554, 0.10736576702085235, 0.20333147157103787, 0.12510315394930302, 0.16348040512492581, 0.12042154467874959, 0.12196174146787775, 0.19716156796822626, 0.09857418796708507, 0.1282062313909973, 0.12099532155139793, 0.11571566574275495, 0.09169703199257774, 0.1308105702722265, 0.14077354372749407, 0.15582090484038477, 0.15301745204675585, 0.12513506151134932, 0.2515960220367678, 0.12785976812724145, 0.12956535563834254, 0.14612362599901615, 0.08892293568820724, 0.1481511083341414, 0.07617300331232048, 0.2243518210466831, 0.22955962546890785, 0.24935440280504767, 0.20230287595862345, 0.16936846498039462, 0.1431020373298276, 0.1730206512635754, 0.21337865341094234, 0.09401086267204055, 0.16862349043930733, 0.17004081438626015, 0.1885612044603594, 0.13611490177291055, 0.09251513728691686, 0.174953016122022, 0.08251644881261934, 0.2153944146008261, 0.13901442199224426, 0.10770490648405207, 0.11896135045155404, 0.13687525935951741, 0.1839435635314834, 0.09974752057103381, 0.15442123155920737, 0.09058596701511452, 0.16875842916629008, 0.13338064204060263, 0.15595474040075658, 0.1335643652466036, 0.06522697817173696, 0.11071462845129353, 0.1396582269620511, 0.2552865433596796, 0.14363048477999626, 0.1630186379676865, 0.17013868977946622, 0.1953309549078826, 0.1476642288147442, 0.14349174625690908, 0.1356668322677574, 0.14099252229977038, 0.19446506104882688, 0.14468862074277095, 0.20785640053931745, 0.3037810734202785, 0.07023246643403847, 0.1416670320735824, 0.16225987384396215, 0.18622498869174914, 0.10311620069607612, 0.09883124110919815, 0.09607963714628451, 0.12327216550587647, 0.09531704258293876, 0.11684972867970506, 0.16889261712710704, 0.08753461583006768, 0.21204441936025697, 0.06925088563753713, 0.14392935100101656, 0.07951996484470945, 0.09509946595156386, 0.07109855181507527, 0.22694642295039472, 0.13839219005838518, 0.19230544386852175, 0.12828602710919035, 0.15053123626257145, 0.13032595837308517, 0.13590923780875822, 0.15739233503418584, 0.09509257116024533, 0.16081890842366606, 0.13411369625358813, 0.13807346683836755, 0.09021735614946774, 0.2143211867059431, 0.13881088775252143, 0.18775635248711034, 0.12457413193319114, 0.14576462187593983, 0.13583013156969703, 0.09266220318574099, 0.17370895062002445, 0.17135906784284502, 0.07733351926529601, 0.08316679617329951, 0.17686581509488244, 0.1398232576226996], [0.041527328111471674, 0.03774707107954929, 0.032277145843592384, 0.05904182941923219, 0.05167561440518306, 0.009424115827817832, 0.059937872668547984, 0.03927369279065921, 0.03153181507162029, 0.01840590397947498, 0.10606518721268063, 0.029214404846331286, 0.0505845136790266, 0.016913673870505828, 0.007780177327203415, 0.0716608373688594, 0.03940983044524347, 0.04153252218759829, 0.05739775876845083, 0.024784537813355847, 0.08381457713943335, 0.004535846678810495, 0.008294674316270938, 0.035549643629741286, 0.036730196612376365, 0.048744343671827554, 0.04759066122313661, 0.02644479781719706, 0.024725568195384358, 0.02673982019205728, 0.03535714871700733, 0.01199332383205934, 0.036956621559276696, 0.05221475644277469, 0.026191649808278008, 0.030075797938831875, 0.024584265192970637, 0.03755900032457806, 0.01589419087395072, 0.04388298336116057, 0.033944877119915146, 0.03769086320854483, 0.037912461801522204, 0.08632133174086772, 0.10477698738536528, 0.06071335283078014, 0.0023559403780382127, 0.03374171060239596, 0.06677282102886709, 0.02084001237826963, 0.027520057760299216, 0.12106207079224049, 0.04192061849959916, 0.06734820668615642, 0.05495825519544944, 0.025665977511615045, 0.0299542446831061, 0.06961167474547703, 0.052338632860130845, 0.01158529295465879, 0.061878438498223984, 0.04919060903991904, 0.11321047396068612, 0.048237024926610535, 0.06179041882616378, 0.027179096923059514, 0.03100880684571401, 0.08193602229678824, 0.06082346647857659, 0.06563486636526163, 0.07078714473473449, 0.09910586064741497, 0.012616973028578346, 0.029762402860327598, 0.009824607442433556, 0.056016410310422225, 0.038296336969060284, 0.011219280084685214, 0.026802955413117047, 0.06217876028630042, 0.07938782233865031, 0.08094741647402126, 0.016406514088533098, 0.008828812842107108, 0.046042527763112906, 0.009104152502972753, 0.05002078021906557, 0.05268638315159948, 0.0823719569692208, 0.039813164246058276, 0.04315861275479679, 0.013788738982721925, 0.02592233734415664, 0.07348998720126768, 0.016341475138981498, 0.018087567633859093, 0.08580419174846142, 0.02181785275048066, 0.03232699901526494, 0.011016490865468739, 0.04097962121088659, 0.012556959615810024, 0.056485987734049566, 0.030726195095227133, 0.03315992811093888, 0.0408018313558592, 0.09073411309791189, 0.05840574661570211, 0.028882367018189643, 0.04139648029400457, 0.014612362982945578, 0.04975069975180011, 0.034991801385917974, 0.0180323020510015, 0.06536582394713356, 0.03717674160256021, 0.018862523025863113, 0.06252538442852036, 0.02490068440355601, 0.04610718175348255, 0.010085356001171374, 0.030986393028269374, 0.06260502309868894, 0.008794547644473853, 0.09925123349192644, 0.027797201558226542, 0.041259312251162146, 0.03168387586371072, 0.048810096998368545, 0.04313147409007915, 0.03079133172098908, 0.08078275353557642, 0.04620413784117949, 0.07903720687834487, 0.04479192370068162, 0.023527521594998338, 0.07477522226831607, 0.029211970601951884, 0.023529048025187467, 0.026931715640990485, 0.039348665985368916, 0.02992069386246224, 0.022944687647865187, 0.024587819840939298, 0.02471207930225759, 0.025670602767457886, 0.06164971528755081, 0.05876502653043117, 0.019296869981072603, 0.07562965545202456, 0.039798390240438526, 0.016452306994206963, 0.012686920686504774, 0.03906411794765342, 0.021263714541771242, 0.03971903119236231, 0.03623176065664138, 0.04123148410731266, 0.023955636424943808, 0.08882787183768327, 0.009168676258395276, 0.04625812022676391, 0.06764786197773873, 0.032053499880637375, 0.07399115426045272, 0.07879552145999286, 0.07008533158730115, 0.029329187800026232, 0.023431862111113245, 0.007826793298590928, 0.03057845503902964, 0.01631905366065762, 0.03501694822203248, 0.034290949678829605, 0.05892869738501407, 0.019251396917107127, 0.030649277952409563, 0.015140734781931727, 0.04242886421120456, 0.029526440118769967, 0.06693675618378386, 0.031816681035824364, 0.09594805388441009, 0.038999149861234816, 0.04120760514671284, 0.01695407734763238, 0.028353128582239154, 0.0561575620104709, 0.01177674024215629, 0.037223764079352545, 0.027345156056746363, 0.02978396057451685, 0.045949306354046836, 0.052185154805380496, 0.07168062541994356, 0.03395234264673726, 0.028965152394507202, 0.020171083554986025, 0.014536611251382819, 0.05907843693069393, 0.04330673202451679, 0.059013947649228, 0.0749934883788228, 0.012420071195059968, 0.050087307294410084, 0.04811420188015027, 0.024330678598714933, 0.057880999370207714, 0.023237553485218557, 0.05505887701386406, 0.012666388572524152, 0.0214646038629355, 0.07797977571646053, 0.018915515242805405, 0.03768742347376482, 0.030550601997322617, 0.0610852885180183, 0.050316080300798344, 0.029635917913589268, 0.05786051034867283, 0.07832837636552512, 0.031000703550694935, 0.05755533156315646, 0.09062977958350413, 0.03556671206869426, 0.05870617182564832, 0.02983998649963929, 0.10270801372826101, 0.024486732624110677, 0.09062262432229135, 0.03192404059753303, 0.014567953823584945, 0.08621009577426218, 0.03361030737118375, 0.0231193135597653, 0.004534250821903228, 0.08258338957544296, 0.0860105068873494, 0.05373434929717934, 0.0458544455168228, 0.02154313170561387, 0.04848806044807838, 0.03097736276686192, 0.03959053909526237, 0.03236255698627041, 0.037909029727621425, 0.059415883339581, 0.0599420631694938, 0.017302576490047, 0.07098782912737901, 0.04641057555413535, 0.03771716300698538, 0.014279425001492905, 0.0784268263246744, 0.030012628243815516, 0.02288127088949325, 0.1092334127714557, 0.04955033328564418, 0.04334268070036366, 0.027685163114520333, 0.026666304479623516, 0.07196589358030789, 0.02660461907996045, 0.00952877876003303, 0.0936951654993238, 0.10422701286452432, 0.0788859274959372, 0.0579989041321941, 0.018928684294223785, 0.02398159531425805, 0.03833475244802333, 0.056555885596260916, 0.04822801190218137, 0.07767015362098333, 0.015880363944527364, 0.044555727302307085, 0.027553514735172355, 0.028361528736328887, 0.013833893162588921, 0.025549016952995333, 0.017860671542885325, 0.004868820570634618, 0.040991625808660066, 0.026249880151402567, 0.034966099136058366, 0.03618790978385556, 0.045900249913815534, 0.05131713505233488, 0.0479569623336917, 0.0703525124117732, 0.05073068708541894, 0.038391006284303246, 0.031833370261254816, 0.016967317262183756, 0.027588988436506163, 0.03751007794973351, 0.02913658563498288, 0.037156030415527286, 0.02622207690541062, 0.03529339104950909, 0.03950014072019727, 0.08203291709745124, 0.040008493684112065, 0.00583107823566083, 0.0434399240710322, 0.06569526473721189, 0.03228988205533355, 0.016106014185014273, 0.026154073195592053, 0.10290423182830696, 0.08333060109326917, 0.030869897868063663, 0.03008818558056749, 0.015159416793575211, 0.0500505657175616, 0.0714290498064891, 0.031068856647658735, 0.03013043724481137, 0.04348059567893225, 0.005393996825366612, 0.061410354946048996, 0.02914257644255075, 0.03902201758577459, 0.019278250214072968, 0.014462034507173926, 0.01598439293898522, 0.04261682005298715, 0.015458877690346732, 0.051883086336836706, 0.004548965455708845, 0.06579366873108572, 0.037287893299494064, 0.0439532719282133, 0.04147745195716139, 0.01711578127146969, 0.07435928249070722, 0.03696100358220358, 0.05575470318416915, 0.057406852232112046, 0.05687759272874363, 0.022979979403316978, 0.049157115675869494, 0.058159985609592936, 0.0187757903815157, 0.02152821788894794, 0.047317796026266394, 0.02756486624299038, 0.037705744466473984, 0.041418141430063594, 0.049801916559977885, 0.08469829020360786, 0.024548373973718094, 0.1323151056684794, 0.0977846347696839, 0.09475239747834784, 0.1928435899918118, 0.13449258801917877, 0.21166296886099925, 0.1302592474366388, 0.13899574476865031, 0.19924191037012687, 0.10135353197373691, 0.21578695805322742, 0.20940993491920734, 0.10460328460941393, 0.11738054334155976, 0.23201251642838602, 0.20585914803368432, 0.13322170943983142, 0.11146220769132338, 0.2560964515132289, 0.14477472902546007, 0.21632706536160362, 0.135059293900286, 0.11569973877480916, 0.12361156543897045, 0.137580550546127, 0.12319475232112793, 0.1814023885996111, 0.09495793120755304, 0.16738294894176145, 0.149789065603287, 0.12358194081893853, 0.1087050649127172, 0.16337975649343384, 0.1635772846038303, 0.10342422932867082, 0.08293347643508066, 0.14706474969223624, 0.1676881736925533, 0.11540153138940373, 0.14723771702378027, 0.17424067692650905, 0.09063711870581874, 0.0937028953264798, 0.26642846484338084, 0.15777870381791748, 0.2301039309391091, 0.0723461949476792, 0.17496357281361857, 0.1914598973047349, 0.11081279495791083, 0.12581757690397002, 0.23947776745884652, 0.1329550035898724, 0.25654579272433636, 0.21973480830990502, 0.13846092346695163, 0.1614933415886856, 0.15942554770698472, 0.17333419572922493, 0.13039228626556937, 0.17779025339311172, 0.14577718571789805, 0.18931134243405637, 0.14191671544986387, 0.11522512432307967, 0.07961751848098733, 0.1761000336057717, 0.11827424619226687, 0.1040959275598007, 0.16840615129518896, 0.1952461030093893, 0.1999256285207887, 0.10984660486780828, 0.09453747151119095, 0.12960795012693252, 0.17728796018467796, 0.1341707085169131, 0.1706586030101584, 0.10117875667469156, 0.139135034875043, 0.3132081836942704, 0.22003143755418642, 0.13762135238897416, 0.07147571222195703, 0.2777840942144394, 0.15592080270571096, 0.17204536004893242, 0.17993678579167013, 0.1871251420027787, 0.18288178099018915, 0.11340250922066551, 0.13676203156430877, 0.11724039521669188, 0.15940956711288423, 0.10739382116063949, 0.12812921657196938, 0.10402388465140136, 0.09765766335711365, 0.11528171523804627, 0.11409020336765437, 0.11076846911061196, 0.11210911531722355, 0.17830805222113288, 0.1196765011897491, 0.15119050088669025, 0.2347093757482306, 0.11530714169625314, 0.12762085594717534, 0.08605928370548833, 0.1498867111701158, 0.12729749023433656, 0.21150771348226458, 0.08655670459472364, 0.1410265825688839, 0.16443432248648138, 0.14267174106451774, 0.17602425218830187, 0.14137671539379706, 0.10288905562652696, 0.14633307443751445, 0.10413020999441225, 0.12138434099934756, 0.20073149173009783, 0.11949265540968027, 0.14670041359720692, 0.1359427924598417, 0.10557195682439113, 0.12746584571657643, 0.15425080763957194, 0.10682159178559819, 0.1253199415101159, 0.18279996279987598, 0.10073952016330535, 0.1731718616980699, 0.23409304269138845, 0.12349060015572656, 0.11222592074303858, 0.11700238702037644, 0.07244078382369011, 0.20918183990063208, 0.13217262863632173, 0.11234333137831382, 0.1903775989288284, 0.1384474403194843, 0.15263200256853335, 0.16267328553142088, 0.21730601847652467, 0.14465722645963394, 0.12753747493749665, 0.19267714972938263, 0.1615635152425497, 0.1919086562890199, 0.12735441056711058, 0.13326323140532742, 0.09942909612530663, 0.12422288828078779, 0.09512929741533534, 0.1195558576634334, 0.12578108813613653, 0.2762708560593667, 0.12952164266138308, 0.18984787977270542, 0.18627147490699447, 0.15942233013770274, 0.16605683542307348, 0.20331671671761622, 0.19223314049022813, 0.12342456337665358, 0.15590594059997992, 0.11332138817036345, 0.11328617876936352, 0.14630771692722075, 0.09685481087334695, 0.24047420270019965, 0.1799085937560566, 0.1203179772522661], [0.07651358302081786, 0.0671499201487149, 0.07142787769196496, 0.03958778117873496, 0.05098789344511686, 0.0467538901965224, 0.05380758347230093, 0.1390923178123851, 0.02940820593897614, 0.022126737486330733, 0.020074418580700314, 0.028701192969756744, 0.04539540563259394, 0.06628178165204103, 0.053085760108285376, 0.04990925313904882, 0.08460923248241026, 0.06112487994194512, 0.016875244985004107, 0.05714637084653782, 0.029657925704434037, 0.08235004685458638, 0.04990825722474725, 0.025214267173601736, 0.04605959237162625, 0.15670720728174334, 0.06945977483185069, 0.016746484757130666, 0.009378147679531287, 0.021541325653332378, 0.09286255049969881, 0.03136820167363171, 0.04525492425947901, 0.02555045719829298, 0.046845487499188994, 0.03381693277568106, 0.025637934863146757, 0.06067753055944078, 0.04902480080002739, 0.0526290069965105, 0.03957514455842395, 0.07521468094520031, 0.027934114876834136, 0.06499804045644499, 0.05057779125749104, 0.06617303547118941, 0.06578338017026264, 0.04860935131869009, 0.03152827574541012, 0.0498439249913058, 0.061728208656272585, 0.05507943881375175, 0.027801683172583583, 0.07172564840725354, 0.0728646602721945, 0.05096437071540183, 0.0267175595921975, 0.06594141644816245, 0.061332524243381724, 0.06118150533086831, 0.03712107765398199, 0.0544105559557436, 0.03763508817721759, 0.04189698468713511, 0.03470321989528114, 0.03903243255110518, 0.02544188147200452, 0.07154897321015596, 0.03744259326448364, 0.02409555280821458, 0.01719258350109862, 0.017793175366316593, 0.05682884272368205, 0.03560591661821931, 0.038787468276437254, 0.05383608194308416, 0.03246346991809626, 0.008490869433679169, 0.0333791365095925, 0.07220196357417492, 0.024176648960659103, 0.03318331677526717, 0.0358140244028501, 0.026621808177761497, 0.03565417632700936, 0.06330490187411347, 0.021968180268642404, 0.03994164102139973, 0.056909917808708646, 0.01753360371015245, 0.007955037374725386, 0.03976790377149179, 0.1286710245955375, 0.0581256878532229, 0.04157546907663346, 0.06542930965341869, 0.05082298535853625, 0.0017686118888142971, 0.054668076411490484, 0.04363377112895251, 0.04417110902948245, 0.020055961607384588, 0.05118492742880218, 0.029616961067902948, 0.05754074907951778, 0.05248826132306168, 0.03957179292375523, 0.058228864574864994, 0.04565110662952066, 0.054074113122037346, 0.08091439042360553, 0.028133657798471472, 0.14638705299265925, 0.040678847430934834, 0.03785891608605462, 0.027097353426318978, 0.04445900870186668, 0.011618477010708905, 0.038154116576357235, 0.02198116354373915, 0.03474027939861821, 0.036815937172861836, 0.03726197654501565, 0.04330498917448906, 0.06146136874092683, 0.03134766477160156, 0.0466630972861763, 0.021147703932177637, 0.016604231805690838, 0.018753836216825633, 0.03969710958640903, 0.053725140920329484, 0.01575798522906318, 0.04027874269072087, 0.017668687993840828, 0.012961350617960337, 0.012286312243480597, 0.025046174076475927, 0.018616350247494636, 0.040694345389643026, 0.01710256242433623, 0.039794812609832135, 0.03335048099078479, 0.02211814964069955, 0.060413234056003635, 0.10689508260017443, 0.017435967719422716, 0.016402216335277886, 0.06736338288793642, 0.027370952152376695, 0.024453160736048897, 0.11385329833794987, 0.06147597803764286, 0.02657166963833715, 0.014083970116541512, 0.008122210687537107, 0.037576340724744146, 0.05593911203886232, 0.01118792506355432, 0.02281563439136071, 0.03903813224526183, 0.0664826039405119, 0.02202443410492232, 0.012658857928228476, 0.07291130736590394, 0.03307150241227881, 0.05520075266700118, 0.08213368064213185, 0.07485050572863511, 0.045671538194461216, 0.07256246922958283, 0.022324934008441145, 0.018720624390088262, 0.027865283792057348, 0.029315218186726975, 0.019050145619398644, 0.03360647693156235, 0.13195902800127385, 0.04357320804809851, 0.023819556226953868, 0.03454236441381997, 0.04431362053559673, 0.10787891569517313, 0.0836932058295896, 0.06920970841160706, 0.007509296776862034, 0.06333960565708338, 0.0401409387949013, 0.05058186301480859, 0.03624508675608424, 0.010124907205482165, 0.016804847250422163, 0.022904234375023556, 0.046548410093471895, 0.04146466211926553, 0.08419879321609774, 0.02229345354041265, 0.08284951319857951, 0.04224792956524799, 0.019893935926619078, 0.01908255305381552, 0.0713673031197921, 0.0680795755057085, 0.08370121144839833, 0.054249930300659714, 0.06448725899381023, 0.10686022559961966, 0.035195232203771035, 0.03550480067309353, 0.037325795499547836, 0.04637959878891707, 0.05418675485998393, 0.016684739985653473, 0.017282355599285617, 0.035339766182005405, 0.04957064610695647, 0.05362436971476963, 0.06869293614140443, 0.03862635615552145, 0.08251875473727142, 0.033227680926962246, 0.03932077272404586, 0.013050717647157371, 0.021541503768774773, 0.07777976548118938, 0.05455797042457327, 0.03276520513839299, 0.07417801842694322, 0.035210090479062456, 0.037696988081499454, 0.06473351029619094, 0.10147757693043641, 0.025030189651935816, 0.05803280735328313, 0.040235163779148174, 0.00552182960804672, 0.03149588171753191, 0.07168088588983783, 0.026898490407714443, 0.014921967841444478, 0.10243455864368908, 0.03097400730175357, 0.04706446224102571, 0.059933862198264375, 0.02815897125870951, 0.04822921849066212, 0.026104202786941203, 0.030773288435152465, 0.010768868265703562, 0.10977728923241939, 0.04039277870868964, 0.031328905193555745, 0.04382747646060683, 0.01390683718190919, 0.036233629911176624, 0.031641601216829116, 0.026046163965797713, 0.042191262041488965, 0.016877642840207104, 0.06104361333493745, 0.057338632102454865, 0.035823098714313203, 0.01974547000211333, 0.06684441194539109, 0.020332348893486688, 0.09285348767955458, 0.03170062254573549, 0.024740880377770915, 0.05923122933675205, 0.08787328031875434, 0.05451486265707401, 0.02109218170986541, 0.05412604622242432, 0.023244183976203207, 0.0727582966247874, 0.033953549235218, 0.030239487945612882, 0.023382688842473492, 0.0577537828095017, 0.017889817357964573, 0.02250661175968426, 0.009333337281620311, 0.023294272719912475, 0.01032463781866095, 0.06364187330848749, 0.08054170397020156, 0.024025584082870234, 0.015789351741512938, 0.06718145998855753, 0.043700650604742194, 0.04170031842565344, 0.048987499978994174, 0.12662029915278958, 0.0903624608632057, 0.020229775466084964, 0.024926541786220287, 0.009790978097777453, 0.04776357492852596, 0.043445083673202226, 0.06129099078656686, 0.06229726642730737, 0.09182477715395151, 0.061529167522225654, 0.054207833769220504, 0.042838330545853225, 0.05616667845676984, 0.06185026944524819, 0.03191654825763356, 0.022971290051035827, 0.07046112069679845, 0.013990001771749269, 0.06824479002745883, 0.06069379077563363, 0.047434452064936204, 0.02270829972750958, 0.033539773655995246, 0.011416740204778411, 0.008813628979447869, 0.022705302408505833, 0.00307100014329227, 0.0629724810020097, 0.03066352718780118, 0.014026267416474801, 0.060772046657098885, 0.03635706965841594, 0.055275101500052604, 0.0810254195464715, 0.06017423377582624, 0.06346398386202994, 0.01883465083195798, 0.02013777405203831, 0.03308991533553889, 0.015917733713473766, 0.07095066620217216, 0.030024071682184458, 0.03296539923476596, 0.036406172063922694, 0.022477402742351257, 0.044857696179420724, 0.035665931946207444, 0.023334925175614418, 0.027866044134322195, 0.023275375246040286, 0.05740789411168906, 0.019385178851324226, 0.06061297999094091, 0.04448358097203797, 0.007901952269622276, 0.03833908850567476, 0.04605407653857143, 0.022225637522135532, 0.03771918164866586, 0.1973718284599243, 0.2706311925524666, 0.18914303291709195, 0.13532524898407922, 0.1402757397942966, 0.21369635007314144, 0.1458405871545115, 0.1838176186767317, 0.13141291456357126, 0.10745069552813807, 0.10899835401364874, 0.1383621594117534, 0.14325090353527378, 0.14347156750098353, 0.12033259420986138, 0.12121508919423628, 0.25384943902252183, 0.22826754157581639, 0.0959056739004389, 0.29489172622561455, 0.14099596969542966, 0.1909413630323064, 0.11030442667223754, 0.15890345878658757, 0.12668785278595265, 0.21292842353784272, 0.20939905647068255, 0.0937900914540214, 0.0971556536012119, 0.1609204303953917, 0.17014452736944924, 0.12440389187465753, 0.09629308456374754, 0.11264389831452601, 0.17332694853746122, 0.17924847111346262, 0.1467870121761676, 0.20725419414379906, 0.1469752246574048, 0.17560278125587972, 0.20057620570784618, 0.16664742792565979, 0.08947024422307169, 0.2633228976159327, 0.10583764377741084, 0.23297312939839981, 0.13150121385772384, 0.20872666109954158, 0.1943938148718688, 0.20996563977772192, 0.14978497469377133, 0.20931466422494382, 0.1085568575428859, 0.19345600067848162, 0.1487981155514717, 0.18160886461696318, 0.11584505033228668, 0.18862118914483056, 0.10340272524063626, 0.19047912090055405, 0.12964723511568962, 0.1839907239041021, 0.0862990309213919, 0.1958934473054063, 0.16010669180222098, 0.13880642912080213, 0.09286183037705, 0.2044469415540657, 0.1545343980673821, 0.14544350846159845, 0.11874223398345134, 0.1765670254826546, 0.12589092216184064, 0.12072745890867327, 0.10800337433935174, 0.16975330158827767, 0.13111332821990215, 0.12654166788824145, 0.08231496002765433, 0.14004585212997853, 0.18380231224000457, 0.10767198002506649, 0.1560995310184456, 0.1130652160293633, 0.21020988392974102, 0.15024367749931353, 0.10983239393681289, 0.14739767618237004, 0.21097779514328127, 0.24078967770741833, 0.1296867652525825, 0.2142595472715555, 0.19416182812663818, 0.2673257070202982, 0.13793624516937042, 0.15047140479568513, 0.20236739588360633, 0.10359836877473902, 0.18888706761983134, 0.15178694630101805, 0.15498737053525063, 0.09435623809094391, 0.1160098894709541, 0.15064386650919914, 0.12799517416785802, 0.17785017679054893, 0.13797349236424894, 0.16074052230725366, 0.12805150461293038, 0.17743063639969597, 0.07741412703668879, 0.11325617110536945, 0.222655855599911, 0.1044987059468704, 0.1310484099291986, 0.2660361971826323, 0.33225971784803177, 0.21406753499421383, 0.10455572587107459, 0.07193043903117219, 0.08846511388377798, 0.15680771801740895, 0.19108963168917165, 0.21539446056610156, 0.1374975985456859, 0.12320331718412139, 0.09297659034810721, 0.20308546541679293, 0.1414867715849992, 0.21628687638909588, 0.1769652073421786, 0.13175586148375465, 0.2098951750104466, 0.12998065190209498, 0.14642544931942417, 0.13809041270325262, 0.1424821802685338, 0.09122481539605126, 0.07114725968530101, 0.13357127535968058, 0.07742863674197467, 0.1093829071689998, 0.09893871558409545, 0.1481870072142732, 0.15305126716773357, 0.2828311427466331, 0.06666923061974588, 0.1742863051232792, 0.1321692272059379, 0.15673850963432945, 0.26972114138545533, 0.18456665348381768, 0.1406180738441406, 0.0690872109525146, 0.05794703231884107, 0.0777223701739023, 0.11500879641502135, 0.19363790059522276, 0.09042420754990271, 0.17182081967832583, 0.19200654700398448, 0.1602810534137872, 0.09693224704073322, 0.14895254355524817, 0.1240927605859695, 0.08854173033708528, 0.2215770046196638, 0.32540393572661186, 0.11729644220923224, 0.12713758470190148, 0.19819200219165897, 0.21469721330269692, 0.11474521620379341, 0.12311576865613462, 0.1320263518080596, 0.1633493734463569], [0.05403537971658572, 0.06269580068727655, 0.05832844834414221, 0.02491977722984889, 0.06343150173404044, 0.015701167360549013, 0.12066238740038489, 0.020679202862083912, 0.05264920490463415, 0.009910467704157195, 0.016317519569589246, 0.017491744665969765, 0.029993809293955568, 0.09800922110556595, 0.08277732473347457, 0.018521083383670738, 0.02726952019598215, 0.07631613918009304, 0.09984600883457931, 0.0329568688457291, 0.04842681171853216, 0.04624501246237948, 0.033904998413016724, 0.017814214055937146, 0.02434765319189718, 0.04024060300341056, 0.027782134523975755, 0.028970637584045052, 0.06296387783462001, 0.02560601197934199, 0.06420290247807581, 0.04029222200774858, 0.0429214587465169, 0.05717796048209552, 0.020937495151414506, 0.02839793706493032, 0.0328221024885293, 0.033647167691660505, 0.010203098927083756, 0.011135863643440028, 0.07041635817938274, 0.037881347140477556, 0.04369444529255552, 0.05371588274776455, 0.01612684028523584, 0.0402808417716334, 0.040674208768553315, 0.03333704763903253, 0.0627930976840998, 0.012032374206389631, 0.07867654034447286, 0.06407959679622324, 0.0938965087275832, 0.059939274609449415, 0.03144059698247621, 0.019937872984296372, 0.12830701791831564, 0.07990788878692735, 0.08685580064212123, 0.03963162056020191, 0.07572855740304917, 0.04271182261647717, 0.017589554941702275, 0.06310360078068991, 0.00456892348255121, 0.02345554763451219, 0.012922857572594959, 0.06162982764503649, 0.059572035041187084, 0.04653286616948824, 0.1202635850096422, 0.017092438572416865, 0.05892181408501441, 0.033457932483044364, 0.0386323967588044, 0.03674202500992725, 0.04116055202640353, 0.012345154499334675, 0.07851543971487591, 0.012588025438749503, 0.09973548532974336, 0.04256336626807048, 0.06072945216850889, 0.06458318852368863, 0.05079813346627259, 0.02267794732394959, 0.06939852610230446, 0.0504262475747495, 0.07831923693658845, 0.0539775132652252, 0.03156907758825729, 0.1197656661632561, 0.018900383091081056, 0.027037652194379803, 0.026891293011665828, 0.09477362577472964, 0.018304688442919045, 0.05473141273063037, 0.028134374090680675, 0.025199816840129997, 0.04717197885075885, 0.1120123890559039, 0.03928752450813209, 0.03712570099460502, 0.006237138830681122, 0.05795897179914098, 0.025784694326801166, 0.056999412200023095, 0.029183286354847016, 0.05405138329332394, 0.06544896746955572, 0.029210137736593044, 0.06398924055599398, 0.026745987199847738, 0.050858321164043686, 0.06902307407149384, 0.010116633455899936, 0.019661261617476423, 0.02003343670719093, 0.008800905216635476, 0.019971751307527867, 0.035088604256030054, 0.06496632441637978, 0.053869119484818755, 0.06595226425317026, 0.07753832521097315, 0.04505135171535996, 0.03745432973148362, 0.03610445599582407, 0.07122333987706131, 0.059756191086865244, 0.040257725068518234, 0.019322874835662304, 0.07015103894856668, 0.059538265885484803, 0.05661043871734893, 0.03145014243801275, 0.010955707534336516, 0.04946742342003892, 0.063899650403689, 0.056344100589593576, 0.012543466892243635, 0.028617132057045257, 0.009613233250415614, 0.009150422298379484, 0.022693487417493618, 0.04600029333584732, 0.017566240970946608, 0.10098348086279246, 0.018778013951715924, 0.049534272252311634, 0.045768570890950586, 0.024646643902205174, 0.013904451775634962, 0.0659499430067597, 0.04493294899622279, 0.0371293667253227, 0.04476709096061607, 0.05826214726473536, 0.04087676241573307, 0.025737597156436216, 0.051661794179029046, 0.03044116442211934, 0.029811329065611767, 0.040222404584769285, 0.05733202076366833, 0.05972681927584833, 0.060035548878893744, 0.055762823716166525, 0.04063498123639053, 0.036667741294349396, 0.019665111209295934, 0.0382689033604918, 0.03931991470557067, 0.03776757925328228, 0.05464326665406266, 0.04854514932019576, 0.02102755836301273, 0.04360536841915981, 0.015898577684927133, 0.01674564397563377, 0.06139860315729053, 0.07939867014365812, 0.057271541952486, 0.06739109994903689, 0.018526208511884176, 0.047709898978111245, 0.033097465132032676, 0.02312410352451186, 0.049126472158898274, 0.07184194821503855, 0.031650510819388494, 0.04438963944032308, 0.07962118038126538, 0.0795301921184986, 0.03798322151264837, 0.08035749046792907, 0.0465209381805072, 0.030287563793301105, 0.028832578963990656, 0.003900663549786494, 0.02466367595198174, 0.024120967775102586, 0.02171812917015726, 0.02754642650665295, 0.022534514597106366, 0.08714980986570159, 0.0326396394971638, 0.03103516410074888, 0.040293758014036764, 0.020868009061462457, 0.0371309946621618, 0.08208088952326968, 0.016148355864589254, 0.03534376133053053, 0.04276899958870584, 0.052759889287934195, 0.050368890571858616, 0.03370534823906999, 0.018932363431480144, 0.058072521351277835, 0.07191581441269768, 0.013576363130742985, 0.019784724347353465, 0.06332799942503053, 0.06629594661776098, 0.045328380600098646, 0.06928915939023418, 0.039858286824798396, 0.04140011155076566, 0.036842374867128755, 0.02493365299737742, 0.11399284125335755, 0.10236730378481651, 0.027960744093082128, 0.00924211823486633, 0.04137501834080585, 0.04274478354941934, 0.030459592667137905, 0.09649543902806698, 0.025510346749797467, 0.019099443377326095, 0.015282779932022096, 0.013858197301986718, 0.030297208840267795, 0.1068691811674545, 0.06588277241755879, 0.0581946817316836, 0.02546599791986087, 0.022921570944750023, 0.04352936866663156, 0.030922666004288103, 0.046373692251020865, 0.023562108549559792, 0.01686323081113158, 0.014728210798855272, 0.04907033706624662, 0.07502112883113085, 0.01953149015354293, 0.04454349670859595, 0.07257919292896986, 0.05075317942687581, 0.06625234089311093, 0.028914709335132956, 0.0462930883100677, 0.055790525455508506, 0.036048428155481815, 0.016799737443967212, 0.04630818790305526, 0.06960821968893852, 0.06535190412954939, 0.05681870355000419, 0.026708504432932507, 0.04153513071698047, 0.05156610213640717, 0.06447828044333766, 0.01753742648889461, 0.13584491706663562, 0.07149433581939629, 0.0977833477419711, 0.036640035724567796, 0.014742857442357609, 0.07326937686171263, 0.055594280542385195, 0.029080504168485923, 0.010348176827744372, 0.07277767864927169, 0.01985002376679932, 0.10880368341120983, 0.06937323753992397, 0.018765666529596336, 0.00889088798900165, 0.011400985606615583, 0.015622432674131086, 0.07216670820789953, 0.07021509155991577, 0.06680525719158112, 0.03854181069219786, 0.030455061257065787, 0.010354650270704542, 0.034612358037021854, 0.019612735693132686, 0.035598041234357704, 0.013386127219775753, 0.06119346779380595, 0.06569017025251543, 0.02031556007662608, 0.03510301436988577, 0.014453036804503251, 0.0668384517813402, 0.024445681802688107, 0.06186625003934868, 0.06356828673292073, 0.07366348313347948, 0.010313541035077745, 0.02166260694784503, 0.05987879579826709, 0.03469881872015615, 0.031240048570438262, 0.02892411114918369, 0.04622260439059427, 0.035640639553387324, 0.014662363626543554, 0.013265674257831228, 0.026394582668980284, 0.034695329189661055, 0.050239142090562856, 0.06393993130674766, 0.04797149885205492, 0.03536948273258825, 0.03776752562712758, 0.09068680716858757, 0.08416733764592679, 0.058668131729768175, 0.008566561793427794, 0.058879300035656466, 0.002328031555554199, 0.024494284335824273, 0.023458163824773604, 0.07157846759524077, 0.043245870169372334, 0.08367738611395321, 0.06848826043067441, 0.09116518311202527, 0.046002798443359715, 0.04673931537376297, 0.06283053257051976, 0.05826730303646577, 0.0701283091198533, 0.037120981892991456, 0.011949560101774913, 0.024392427200631752, 0.13901955478133696, 0.1670886026394944, 0.1785374955544549, 0.1337670567896097, 0.1366640335970348, 0.07483830960888056, 0.19184952962302393, 0.08961827539268041, 0.18078967147777159, 0.09468208592865737, 0.14929732908644985, 0.12811256948137476, 0.14166150091876908, 0.2177795833877979, 0.17509745433926585, 0.10117444359967787, 0.07134619739747818, 0.14593351361972673, 0.24236599554217633, 0.1520381618531481, 0.17417785771671804, 0.1843015104532242, 0.20308690566209056, 0.22182757665793743, 0.08615571119251751, 0.19862216056114246, 0.10196245696035125, 0.1094784230113991, 0.09155044872914592, 0.1607034130082015, 0.19663950969134608, 0.16560453711257828, 0.11909638110908771, 0.1561150519597915, 0.10176077665340516, 0.13655860457689534, 0.12698550092717334, 0.09989247206718692, 0.20556930632841205, 0.15274467878043652, 0.12693130786740972, 0.13520520300634448, 0.1390762759312507, 0.1288890838623047, 0.13480807834815595, 0.14685861075357085, 0.10395353479731469, 0.17891882347964472, 0.1588988469372834, 0.11514457783872083, 0.1492856845500008, 0.13824654142222098, 0.16743516549468043, 0.23157342547370544, 0.12106118979112757, 0.2120621619565833, 0.22636388969277182, 0.22365883323213748, 0.12639056470605636, 0.14364721614026255, 0.2398559850670638, 0.16089139566306146, 0.19703170074330223, 0.18758269567643443, 0.12647723989380946, 0.09661468061348123, 0.10755174252535067, 0.11156017501508037, 0.14920818709558056, 0.19822022487078944, 0.16895298485554036, 0.10142736752787906, 0.16790341375575912, 0.1445582632215754, 0.14695005100821296, 0.12314648112101902, 0.2077070746811167, 0.08947451133280994, 0.1716895581733796, 0.14959355996501061, 0.25455888240568103, 0.14608797226702014, 0.11812755567652565, 0.09696257646165549, 0.14603908053569256, 0.11095639047843796, 0.16022105340755757, 0.16470151863271193, 0.18954054061924258, 0.1970786925765776, 0.14335241018524095, 0.16264285651906846, 0.1273633048479115, 0.1278343416690346, 0.17904751092916538, 0.23015338957550066, 0.18038275621591077, 0.17833575396047485, 0.15336061347155802, 0.12290439733694639, 0.11333662565917739, 0.30415516947546317, 0.22608207658894602, 0.1136636992375697, 0.12261678494753377, 0.16989099823178785, 0.1851545493569105, 0.1291292983918421, 0.18131491668041677, 0.15224531202787353, 0.2326376594963574, 0.145095827118043, 0.17566193856539267, 0.13008744455873966, 0.08958175598132996, 0.14453814575268378, 0.21274080860518643, 0.09858300563909354, 0.1542413541145863, 0.16190557350074092, 0.1022819156247762, 0.10662644620864623, 0.2528227739516766, 0.11954470342325589, 0.19500829399593417, 0.186215519845005, 0.15214457146583066, 0.14726707351303872, 0.20975767754979674, 0.17377481885975407, 0.13437176063176126, 0.1875047079257427, 0.1378119090992597, 0.24030624558368038, 0.15857788674052686, 0.18026899215915512, 0.19454796708399252, 0.14677228796626293, 0.08894049442343174, 0.15522343286823842, 0.21250080858026782, 0.1397404281963264, 0.12756893816854686, 0.14268358478382712, 0.08457398477701411, 0.0891213754432336, 0.16426271879144255, 0.14313666450400508, 0.17256066143032045, 0.09642850592612259, 0.10993213092367496, 0.1576804147372323, 0.1555645105338866, 0.1368697282047041, 0.12307561798802308, 0.19378874330751358, 0.1968249795778144, 0.18059586655468712, 0.18410660236352877, 0.11162377563455414, 0.10121975770039905, 0.2267990889207971, 0.1182835388387884, 0.11214677619958117, 0.16771962926272424, 0.19121968277519752, 0.15237733962074404, 0.15575188031840712, 0.12874207158963527, 0.09793374612326584, 0.1617025755225651, 0.08924551999136325, 0.2125546032743108, 0.21560306630788312, 0.0703792488803306, 0.12731153262598863], [0.014720743356813348, 0.005790330018968352, 0.022065322132660978, 0.015599167541480594, 0.005813414163346733, 0.034852645344912045, 0.10495892560650265, 0.035201540937827486, 0.0716577423736453, 0.02093990832837599, 0.046927340163458744, 0.02011966181828851, 0.045919329333569736, 0.013617912866926242, 0.0450866338947127, 0.09162632207716666, 0.07214994620411627, 0.008459347788424743, 0.014372082378324724, 0.06046591409211678, 0.03642005357711065, 0.00886038907112614, 0.03990082385679407, 0.014541027748266296, 0.024694499499615163, 0.04908872317642935, 0.061418709134863275, 0.020566459617487366, 0.03309897815568313, 0.019349992432962024, 0.004807568010648773, 0.046960419840029174, 0.05367255664520687, 0.0737878192035902, 0.049522485989596576, 0.05887196474378148, 0.08942584942785964, 0.033289592322562976, 0.012732993214271002, 0.05166922906233419, 0.06280850754269669, 0.07556613144134322, 0.029265424386868556, 0.03886088631266067, 0.03296530730421505, 0.05366731277336517, 0.05428687489080814, 0.051402818156226035, 0.036275144215793385, 0.037302100400049845, 0.04870435771261973, 0.016391081247298468, 0.06913935089664114, 0.012060943540305862, 0.042039545988964463, 0.0508199708025542, 0.05246252842968511, 0.037403614710896246, 0.034379287277378386, 0.08257035841985096, 0.02443000572853752, 0.02991537338182811, 0.0388969537321358, 0.07292790849122309, 0.025528024228650237, 0.03383886587295321, 0.029396766331046823, 0.1270371812185453, 0.024578716801179033, 0.07776555455019397, 0.037651321580333096, 0.041314397803357536, 0.018609348203866713, 0.04348846340191461, 0.013437435000894532, 0.028793788101944714, 0.020801464749139645, 0.11719649837863062, 0.03343746261370759, 0.014224629605098838, 0.038229250649531046, 0.061131502772050525, 0.045191120626705314, 0.0506411582201479, 0.07323129463099665, 0.012906972739485004, 0.046084045898169286, 0.08717230220715846, 0.049855002622690894, 0.0610480260013813, 0.06846291058125996, 0.038095384445642276, 0.03621715902080459, 0.03757727535201177, 0.05258239437675765, 0.023743751826846314, 0.03503716145191462, 0.034633417794060324, 0.08287382882929618, 0.04669079902551828, 0.07776718631747269, 0.009771139293368305, 0.017961511696358363, 0.026244745447090077, 0.04036500419099485, 0.11508986383916871, 0.027278102295953902, 0.04840372948937359, 0.011506979616599218, 0.029233440216029846, 0.005989662745231462, 0.027840550643421953, 0.026473953208375364, 0.033717632458935824, 0.03219257739763106, 0.03212794638989914, 0.07900526867278161, 0.025109150334291404, 0.0445362035515568, 0.031792928479732044, 0.05330906324689427, 0.036215531083965496, 0.026991010846329794, 0.01788904169394124, 0.04065142148324559, 0.026970406911606272, 0.01601065730585927, 0.034638067947760705, 0.06301373866717182, 0.013627125074215716, 0.05212063104995797, 0.008721673530676674, 0.026953215898585417, 0.007555181613086813, 0.028848956008591962, 0.026396419364778746, 0.05448068747477186, 0.039847121093302004, 0.005163406275378, 0.06419781565425858, 0.015431457488316924, 0.013230598922218046, 0.027010791236534718, 0.057003483957340645, 0.03834998610639765, 0.032605353232112624, 0.02140557487314988, 0.014647401929382357, 0.07318081709766582, 0.060552700362618894, 0.009303916632498225, 0.03455870506924487, 0.08691846663432737, 0.03960370814668075, 0.07286411634976826, 0.0780784018758324, 0.031855663419851375, 0.02512367727655557, 0.046863233925954956, 0.08105614733311438, 0.022591425353781353, 0.08243986300282902, 0.041872098320914854, 0.06621134752828269, 0.023309249738832156, 0.11158992220918018, 0.043767166188767845, 0.026556516419194882, 0.11055495274523575, 0.03246153937652707, 0.05192980620889895, 0.056811552119231036, 0.045767831616103656, 0.014890393527645259, 0.06156539198972526, 0.022627699616996032, 0.039687246204383915, 0.01223858783862764, 0.0173247509050153, 0.06944070690341535, 0.055304894659427874, 0.08950143932334839, 0.03823609947557411, 0.09304777523803134, 0.029402462194763848, 0.041756292639841, 0.04349479894904841, 0.013811853770617277, 0.07812389983765541, 0.018565843985866637, 0.030406816870034225, 0.05052893016968043, 0.01954410570643602, 0.006417348087134381, 0.06948016809239503, 0.03789343983836232, 0.031768582205498413, 0.012183083810903614, 0.05267046384453293, 0.058324832409139604, 0.05381404542394223, 0.05480234864197912, 0.009936081853905513, 0.03371796953762251, 0.04425790679130343, 0.026936271948920145, 0.03389354922898835, 0.04022040509528691, 0.03119415798855405, 0.026050394686359554, 0.04644869991968717, 0.047154044732451446, 0.019571539315004504, 0.007333745813793353, 0.03236228885549692, 0.058647183055478724, 0.03611554894896765, 0.0907703030914549, 0.0302812454831456, 0.05792102363381175, 0.006349322831092944, 0.15939219223876155, 0.017807581649732687, 0.04072763957083225, 0.037286943350467956, 0.041828090400104566, 0.02736748943495895, 0.03184513162611233, 0.03736128835307975, 0.008413583611048037, 0.01321450437253882, 0.06496974882940132, 0.04455941218522288, 0.0565971547527419, 0.07929302661889985, 0.05393574232115381, 0.030588810632546103, 0.014952443776682261, 0.032608769984254916, 0.07985703587051361, 0.027593280444101944, 0.06447566808351586, 0.05926972525494714, 0.039984365744936856, 0.0069957310634274645, 0.035789735585210786, 0.01089275808959839, 0.05552828589814806, 0.05402545121708705, 0.0409626025676487, 0.042544884396897215, 0.031815574038773775, 0.017591303537389445, 0.04160759114329854, 0.04025717348521275, 0.03680337333090363, 0.020150274691742756, 0.04900359931672293, 0.03973953553565568, 0.05789098915674033, 0.07549432602020041, 0.019917673160952908, 0.03907306968504864, 0.05921578500419856, 0.013495453712230009, 0.06728184815015524, 0.02858405046525502, 0.06897149337155205, 0.049953487055796775, 0.0417901192521376, 0.08810407196682307, 0.05914555389374014, 0.0210083487083114, 0.02335853409022093, 0.08534007270129458, 0.0691018508927476, 0.07482402206909272, 0.011179199322096763, 0.0598951019797354, 0.09680451720111793, 0.02407137315810448, 0.10627039918495763, 0.02157206301607432, 0.06859545911391897, 0.009584236822481598, 0.04639619991423623, 0.028633951517422835, 0.019395622544951977, 0.030626226366767963, 0.0895153821235703, 0.03328124962506756, 0.02481243298989871, 0.057725529486854235, 0.08092073363161857, 0.05935220994175442, 0.0409741283604695, 0.01262913850481592, 0.04559705912646267, 0.035811595904130133, 0.08483761861439675, 0.017806020745586966, 0.03166405716910958, 0.040690794572113984, 0.030976091060907613, 0.021153708146284186, 0.04291359102353454, 0.033230569078436786, 0.05950131746489675, 0.009342601199844673, 0.024896610731018648, 0.06590309673018994, 0.032484659910081856, 0.08114954877284267, 0.017118257650684927, 0.0519398917564221, 0.025270582296915596, 0.016828239745190068, 0.04292874807311643, 0.04122273538321738, 0.05470963285094308, 0.018024692882693583, 0.09255893453354798, 0.03635746419369694, 0.039666860604718815, 0.0546794260040887, 0.02714911032648337, 0.07800834313515695, 0.018364646314312855, 0.011345076509901594, 0.022491249781582626, 0.04007520845099803, 0.05341354614844727, 0.06317847438396947, 0.018053819545574726, 0.016775733994079695, 0.04428753141133536, 0.06559361253053912, 0.05800892456224369, 0.06764605401023742, 0.07635016880568958, 0.02480438140581452, 0.15332237036237795, 0.025660676183179024, 0.01900899712176573, 0.04199317085646814, 0.026657940714710185, 0.03693856103646179, 0.020101877087126338, 0.010970054445938479, 0.04025825749962561, 0.05282366993807016, 0.043210070880670706, 0.0569205932439335, 0.10783313428081813, 0.1304815814740235, 0.12016693535711497, 0.20813874990469028, 0.15154294729713472, 0.22203586064279082, 0.20330346339652616, 0.2457330592216984, 0.13900795621016335, 0.13045843029695173, 0.1405406683202713, 0.10985407422507003, 0.15058395843352043, 0.16937463964906432, 0.15344258487945603, 0.16205503725476805, 0.11557790781221083, 0.1495443924420303, 0.17298367986034963, 0.10270816694584586, 0.14311763487996595, 0.1547110272992042, 0.1480250255835633, 0.15612982213497162, 0.1420705305833009, 0.09415783664031376, 0.18581231244869773, 0.14527205798414447, 0.1744977453903806, 0.12040729544335797, 0.1445497290020989, 0.1274729473516345, 0.14190811994335345, 0.14805755367682827, 0.1764741603044733, 0.220078720500873, 0.09343472624858541, 0.14388546948471378, 0.12143004580491013, 0.1455960059238057, 0.24094808936840106, 0.13596712341231687, 0.09854271707515563, 0.17426727549924007, 0.29008679212101046, 0.07531872334619684, 0.08416636471426295, 0.16868486940380067, 0.13152059588220813, 0.09752689214843897, 0.07173231337219477, 0.23415246047079566, 0.10259933649532257, 0.10736857090265521, 0.23188906902026749, 0.13565664329836447, 0.11491814523094124, 0.21966791351235684, 0.1735410088252637, 0.08731002183330637, 0.1179180765945104, 0.08138076943014899, 0.1630162171298458, 0.15663769246349413, 0.10081681077398601, 0.143933150797121, 0.20554258518161314, 0.10373954345742542, 0.1133639213719195, 0.1297379858911999, 0.13246453877898956, 0.15299761036951698, 0.10192953816224491, 0.1571702767884539, 0.10712746005024641, 0.07675057998107326, 0.23617902350041176, 0.12513800328897853, 0.2703536235757413, 0.13235878800192188, 0.10400326156447973, 0.10911693676344811, 0.09214504021069697, 0.1501001739093373, 0.13202068275741993, 0.13533362998597084, 0.1937895860042303, 0.11122613769745636, 0.23991212399015505, 0.18051317502414027, 0.24021791564601086, 0.1327182977430282, 0.1442249996527549, 0.14188126090072817, 0.19192118948746115, 0.13035759780435793, 0.11862761190822048, 0.16876366920769217, 0.22361273006085428, 0.1695969890082075, 0.13827108687931491, 0.1305864589108575, 0.20041066942916763, 0.0768103654826841, 0.22020566126992627, 0.18181353266681397, 0.16238515986309898, 0.17154202496092166, 0.1875347079288575, 0.13296376763572618, 0.08677428888697779, 0.14157617404576273, 0.15093188492521165, 0.14708345755934715, 0.15414433673985545, 0.24684436168641816, 0.21029377055744972, 0.13167130069867258, 0.11433711350564996, 0.08658159479138353, 0.11446391637887686, 0.13462251653113674, 0.1233216930901812, 0.12102426435317724, 0.15121723735524764, 0.1205129849333917, 0.15901582856332103, 0.12089988997867032, 0.12937476828454003, 0.2443338455932756, 0.09743698406964542, 0.0942035720893933, 0.1605662985915138, 0.10236954842243465, 0.21754103892993545, 0.16423300990173895, 0.11985577342490997, 0.19217523956491103, 0.14411367175559844, 0.11117824188043034, 0.0883717124440497, 0.16544070154909166, 0.1153576575339802, 0.1062226795681542, 0.12518433628663903, 0.2645116209262802, 0.09972462986385632, 0.11242638297018506, 0.14771019409020103, 0.15399816716390272, 0.11671982315038482, 0.2061653993422947, 0.1248861289012336, 0.15677951066003692, 0.13904816050442959, 0.11890794646235243, 0.11746489728290228, 0.1442400915848632, 0.16936120246687245, 0.10239803923233863, 0.18371752162854518, 0.16480670250471563, 0.17372810281813147, 0.1405352290960089, 0.24632287031460195, 0.11061102272041383, 0.1058056366239344, 0.17653728594943402, 0.09002457012332256, 0.10160611882325142, 0.10707205657156245, 0.12772657608072605, 0.13593275670803365, 0.17201384319172752, 0.07918196685251691], [0.03271651258992572, 0.02460426966389341, 0.05608538886712444, 0.12965187760851077, 0.02960006691395275, 0.07481636118984993, 0.00670507155929602, 0.05313804560911752, 0.008510399887698793, 0.035361492435538, 0.07530209157736072, 0.04903965524487919, 0.05516763085559492, 0.11509954719053161, 0.06634378114775305, 0.08608498595534794, 0.10784657146301001, 0.00844450675011162, 0.037754594062965725, 0.06268855349551286, 0.04768171843381659, 0.03113518070970332, 0.04335302671778106, 0.019198301278295058, 0.0065973433177737946, 0.0356755540105364, 0.05270991737263338, 0.04580806655388686, 0.057931806321345994, 0.03820692684741751, 0.027117043801192797, 0.037263979864937645, 0.04551038393870958, 0.06295851138871043, 0.022229738007750244, 0.036803281400352716, 0.04338215338066221, 0.036276615104608, 0.027852183688552152, 0.06353592717899911, 0.05385388582644444, 0.06557704204873693, 0.06368197035044432, 0.038590035927031315, 0.023339701733822306, 0.029659961583092812, 0.04311548966553904, 0.04480361420240614, 0.048555502998492414, 0.04080676113165194, 0.04319316715062146, 0.05484414256868824, 0.009830259256094936, 0.030463153060766, 0.06140159473063485, 0.03951344383700241, 0.04549331933019623, 0.03332672460425285, 0.008503672678113706, 0.005511232696834111, 0.01759180149454023, 0.07933025083114063, 0.02174026528072934, 0.01806270233505676, 0.03909591442695068, 0.018426647725244685, 0.054743003640924735, 0.04113881045111245, 0.06718032617842959, 0.021702805496451837, 0.06072088347507581, 0.016046796546077297, 0.06534255785687317, 0.01515714534287972, 0.032215276582827496, 0.031004451635864475, 0.024665495410801905, 0.04569042992267398, 0.03680344610925644, 0.03520442908930202, 0.018370876524357066, 0.054064039065833056, 0.026668277156028538, 0.042567349925276735, 0.02953064977191389, 0.021996975598496296, 0.10920673758993227, 0.026933184614585295, 0.050683074720924905, 0.0455051975234622, 0.05063282701397135, 0.047521966118966384, 0.041730858520754886, 0.05008877435278508, 0.028084308329609134, 0.013630159740005771, 0.028847027382242586, 0.0433216056215667, 0.06858077320841051, 0.007662531598696426, 0.02013217777975144, 0.08689785886916422, 0.0641165107428547, 0.05325090568212252, 0.09427385299556679, 0.04039267911725948, 0.04913264299712835, 0.047372119320977124, 0.04194328704127862, 0.07158446606368789, 0.05141788710569663, 0.023336392233989412, 0.013968740916630674, 0.039096753293227766, 0.012772953318011378, 0.04054086733489268, 0.04049890486884021, 0.017677898285910487, 0.024351887742898638, 0.058419612807131586, 0.027482728210968838, 0.030718089884988246, 0.08797046623282856, 0.053308423563477494, 0.10205020467119832, 0.055589515475496176, 0.0868937373161316, 0.06642914632515562, 0.033950454240003904, 0.008855910329598813, 0.03126386049834471, 0.07227704785163365, 0.013162846106194682, 0.05168799055559982, 0.029652563088964072, 0.07418559503651435, 0.02181007121238978, 0.02575143270434872, 0.022012848940287388, 0.032034996942046194, 0.02600812386991757, 0.014273504099448123, 0.039630057740836375, 0.01930734240299752, 0.014490264847183661, 0.034166885569932005, 0.07125443538590785, 0.024065799868455338, 0.036713051564630964, 0.006496558705675266, 0.05347840315211685, 0.011241623038996854, 0.050607726143132296, 0.07062103389011276, 0.1494273801724757, 0.05560029050215118, 0.05932545432099893, 0.08872537693429379, 0.0775454038633935, 0.08921358178580001, 0.043633728994116674, 0.03752235833915972, 0.005057465412744111, 0.03487333737974686, 0.054984482215537187, 0.011477425859700288, 0.05505139233484384, 0.07227330168168392, 0.036175924338280194, 0.060581459303296385, 0.05000093088094747, 0.03077169114183034, 0.04902690754181916, 0.01603680675954468, 0.021685476587604613, 0.05794021030587535, 0.023523175961247856, 0.036183267291034424, 0.027714329997017503, 0.05208212364044401, 0.016477794739447774, 0.048520849011237585, 0.018458909602955948, 0.06903326304088678, 0.0146219955809835, 0.03339777925922986, 0.13718267512177268, 0.044949515647585356, 0.07760803155120342, 0.08573620910606078, 0.039707876952184785, 0.05792518349124059, 0.06456294848072915, 0.041548560238293106, 0.06744195286545061, 0.03945022243105116, 0.05049521847057247, 0.019332357088945085, 0.038453660785190524, 0.0429018966913704, 0.005827185551395581, 0.012207732689867338, 0.0714858015999198, 0.01826196371938192, 0.020254054707625223, 0.05112641746358526, 0.02153020971755107, 0.04290473887756948, 0.013482210924848916, 0.029657981245808547, 0.014974532006759078, 0.031727948901994575, 0.06579477955857593, 0.023179857488421184, 0.03296851721261779, 0.011684175753485293, 0.025371456924345226, 0.07682712748646736, 0.0416792624990546, 0.08544973818765533, 0.020865057707734166, 0.06189634963389366, 0.028391980731319037, 0.029861354607067285, 0.07230419800767014, 0.008145707561784695, 0.01868436161819245, 0.012943495981275074, 0.025813146832308946, 0.0188662251457572, 0.02820158106905799, 0.03419957071122143, 0.012736828441941931, 0.025986315261933114, 0.040312465881147695, 0.028461327010224906, 0.03968996198607549, 0.0686815520748496, 0.014080265123817711, 0.03639348947833623, 0.11860775490922314, 0.009454173287526976, 0.053466164897526466, 0.06445118391345586, 0.06530342608570092, 0.04949433608881889, 0.07880468387156725, 0.037123222700169975, 0.015894440810136017, 0.03844939367545228, 0.069689164539018, 0.03563954787809522, 0.06411613919021142, 0.006394302725957166, 0.028556867750481735, 0.07609054160815093, 0.0662214981932794, 0.022363799564059705, 0.035457973548721884, 0.04865938069058522, 0.0601285902572976, 0.11054153088480236, 0.022839088173162554, 0.011359549826011063, 0.016456667949715932, 0.027845386573443973, 0.046486659576335264, 0.04386941977446118, 0.02540211384785512, 0.008610417454263136, 0.08518144653569307, 0.03374425018386495, 0.04358803567987296, 0.05179479470356338, 0.058863890177059564, 0.009410844312139578, 0.04639398592013506, 0.0205482458770876, 0.07494782187765645, 0.05729485400802186, 0.035325110920013926, 0.03251921430590653, 0.024502766844365868, 0.03348226726595913, 0.021856925149838773, 0.05852702599499495, 0.039340526301173434, 0.008172977419059363, 0.039941189029524406, 0.10451447969723134, 0.09751201472094945, 0.05950705929388923, 0.03398321982052538, 0.04476213054130635, 0.05488713159255924, 0.04904211821755575, 0.012298115743173948, 0.03001825899005898, 0.019631386103649295, 0.02492496556031608, 0.0797113489299532, 0.019053412984395703, 0.01235941235321544, 0.07546276319772005, 0.03515420053454657, 0.037705150748332666, 0.04473739356223134, 0.1541529169246074, 0.08618417901978379, 0.05355645218984254, 0.04806891842294605, 0.028909733594064752, 0.021980031648831024, 0.04683184730369718, 0.08586447520722305, 0.016079371562227607, 0.017750058022718278, 0.031064589537920493, 0.10618075157605833, 0.07496822279908004, 0.05294477311714042, 0.0722271219016083, 0.06893456027272248, 0.0370594228978359, 0.0526176612343519, 0.022591517284332265, 0.05291809410517735, 0.03164830448616657, 0.052165941320239544, 0.0282549524995228, 0.07155249721460766, 0.04656506101450613, 0.043064567801212116, 0.08943180959191054, 0.04608337557123554, 0.04383863070078435, 0.037449170129313585, 0.01843859678164365, 0.09103691701086299, 0.03486675668447729, 0.08116670914234654, 0.09803839373372256, 0.004074561678158541, 0.04947718721063388, 0.03203903805584677, 0.08124481180622693, 0.021090036663677425, 0.0428457884117961, 0.11463823202516764, 0.02282402305413158, 0.0678047644455106, 0.06292291511330875, 0.18133409952204074, 0.08513460792000256, 0.11152739411280041, 0.287261521143298, 0.1272603656135259, 0.17677101937513198, 0.057200935458944696, 0.21729403686138893, 0.1531099188592165, 0.14722657810536124, 0.30212304464751677, 0.11753334723893674, 0.17727199491233597, 0.2102547153950699, 0.11316160521199627, 0.188110729439124, 0.21216760629848128, 0.14697560770136697, 0.15472976580983208, 0.20988890841122598, 0.15851503688721888, 0.10502271008707824, 0.11246869400624307, 0.11951932293032447, 0.15513438280792008, 0.12071988229910213, 0.19151914654479874, 0.10896610937291577, 0.1401729001513412, 0.12278868741686307, 0.10163665508791324, 0.0987363074936213, 0.10098709679779508, 0.12631354988702845, 0.1681545067338213, 0.16520735116735583, 0.12145570208949429, 0.1343246615461765, 0.15400783519350714, 0.14727769149166925, 0.15229778905068675, 0.1932670221093201, 0.17088833745689164, 0.16344194751112692, 0.10254114445659424, 0.1583241430982467, 0.09326924359606159, 0.10434601696268206, 0.18174219455930496, 0.11582802785860917, 0.14306947859304567, 0.12193773993321004, 0.26728672846671075, 0.10401391018662723, 0.10756689574449294, 0.1366168885461746, 0.18651107656619242, 0.08529083623040108, 0.0735912180595821, 0.12322905773837721, 0.11861643468540524, 0.16152884210309676, 0.19274821204523887, 0.15267948469808026, 0.16861017583118332, 0.18430238379345787, 0.09440047200769187, 0.15813646687855645, 0.26032770833661484, 0.14872303893489225, 0.1367981909143348, 0.11498811204106578, 0.11238280788905199, 0.07062529333897176, 0.23543142893862343, 0.1071918880446784, 0.13617021332104362, 0.0997755823717002, 0.11214109182718301, 0.1851619038009836, 0.1382284157819325, 0.22945753659211823, 0.09760954537458959, 0.15666047591836224, 0.11894502511788761, 0.21340152879636134, 0.16011527198697292, 0.07880888203339231, 0.1579439030179093, 0.18236378297930766, 0.1393007856583403, 0.18764815022868497, 0.13475838988538713, 0.1050875824125063, 0.13554549926230985, 0.14168390132967504, 0.08803273385931408, 0.161611104624406, 0.20549452082524378, 0.0877131296381835, 0.14556243595096374, 0.1514790708860082, 0.16476069126398335, 0.21154876047324753, 0.10607500079899065, 0.26828297984696203, 0.11537455743358982, 0.17004567138370008, 0.20349671673630515, 0.24662415737346297, 0.12867946688446308, 0.09707311528824991, 0.11700062501815059, 0.24288212429852257, 0.1744703807297253, 0.13145340997124874, 0.16976742824960142, 0.1389201778557993, 0.13283132635537656, 0.1392999429616236, 0.0926672363834035, 0.1450939885070247, 0.18257936012120018, 0.10895262622544843, 0.19225190964437303, 0.15861769266907247, 0.18799281318581876, 0.2165522952113421, 0.14224689934522877, 0.1543402867091279, 0.15368564925607175, 0.15444560847695799, 0.11248355611197411, 0.13305631105697927, 0.17278500261806673, 0.19035161322643682, 0.07974719418393028, 0.11668053050074847, 0.13088483483560626, 0.11111891603157406, 0.06510939133623916, 0.11098302735556519, 0.18131473281931493, 0.2016426000984446, 0.17238063076811452, 0.16351022126693882, 0.17591007444406712, 0.14389962678955448, 0.10049228060750232, 0.08931480498323519, 0.18599773636989056, 0.1629758289744777, 0.09309852090213569, 0.20433581283976956, 0.1950354288302122, 0.18766794594064837, 0.2209442313159666, 0.1389222922584703, 0.09419977995416812, 0.1514671505579064, 0.14248665422201157, 0.12205771696303161, 0.155508708689482, 0.2815385072702362, 0.1365638446182974, 0.1413525223371483, 0.11631116120805664, 0.16062744772962986, 0.062091315180183425, 0.1982970481678363, 0.1509657000461894, 0.11419629888428796, 0.18185068793114156, 0.07360214247338234, 0.1237776762835922, 0.15074738030952795], [0.0471433884494247, 0.03813129864753254, 0.022176406796901457, 0.025408956928238757, 0.07839135645378022, 0.03195212729605696, 0.03702644281269562, 0.032132684643710815, 0.026605367930906437, 0.027087319589730714, 0.08660953401798203, 0.06646126073094145, 0.08252950295084908, 0.07175078375204917, 0.048318230246584264, 0.08175267447387019, 0.06029541356368892, 0.09474244599621143, 0.06577993277460337, 0.03013896571862842, 0.028095318928300857, 0.022641987156783863, 0.05337631044488761, 0.04672405873275092, 0.025413279579351508, 0.05666473902942193, 0.050160093308095975, 0.03959112515252444, 0.02237178411545052, 0.0020224419553884336, 0.055104941880751046, 0.05499609227802965, 0.03933333273556444, 0.05484983843240527, 0.07460629988101221, 0.04712800923434477, 0.015464093791501177, 0.020490831417602398, 0.056956036301750335, 0.08024139750388362, 0.03528284967967099, 0.02653731059493317, 0.09387834478289851, 0.02562526951453859, 0.04548487704127066, 0.0297901084301092, 0.08578777448424409, 0.04526720847934485, 0.01913767499518731, 0.04553985534115665, 0.019092611788261323, 0.03028667513130894, 0.11866036982786272, 0.03654491824788913, 0.03569601238855431, 0.004633924127706597, 0.029212702215919574, 0.03614614650066342, 0.032370290643866026, 0.05510409918403434, 0.05103237634044021, 0.03411480691283941, 0.029974659011068366, 0.05330079715819128, 0.04818270546233943, 0.031910950070126884, 0.043762983348701275, 0.05392847980763163, 0.03844778489081129, 0.04284448606232482, 0.05051601009683744, 0.02801634100896697, 0.072655709790847, 0.008924079705931006, 0.03323996514682809, 0.05082039215091256, 0.041762509443346536, 0.13056914532376876, 0.05360787201132025, 0.042575516422549566, 0.01783198346534083, 0.07289198662845359, 0.05078510231068058, 0.016129538829949115, 0.06765605145764929, 0.06142758426346606, 0.03738552354456436, 0.015983069522096025, 0.03696866829188601, 0.05472936344543292, 0.043882592656319185, 0.024820042158206625, 0.025362869078714042, 0.053695945309535156, 0.039516868250023936, 0.102759127114569, 0.04823394525315493, 0.027942120495642868, 0.06499704454214343, 0.06634332149499847, 0.028978411461256688, 0.021971985810406266, 0.01463618640217089, 0.013929414750647642, 0.07264771949379675, 0.04350940441532482, 0.03808217325938806, 0.06449286675741596, 0.051593348053434206, 0.026711947998152148, 0.014180263538183946, 0.05519609102198193, 0.03667238761761016, 0.05182136646321705, 0.026992100606402083, 0.0536231286523323, 0.05262215817046743, 0.044771744944756074, 0.07612684651488259, 0.03408927320232315, 0.04172641138035444, 0.02602178704804711, 0.007229922705465147, 0.054696651491066145, 0.012779039886569785, 0.07677489561178992, 0.06056319959762116, 0.09380250973927398, 0.055390562441560535, 0.06023756243408688, 0.0706038428770919, 0.025931507416610277, 0.04942650283356348, 0.04173720172876793, 0.061629747205804435, 0.017977107331276904, 0.045219270527483, 0.006305219628097069, 0.06015288290537654, 0.029291015553979144, 0.0336179222851511, 0.05296066944156924, 0.028342976002022627, 0.04582579382845471, 0.0249441369106212, 0.037072722184201407, 0.04148752601336568, 0.048797291838714195, 0.07135012742852972, 0.07783511533371865, 0.021702361165455753, 0.0032863723566650504, 0.017541982796824267, 0.01087637529933765, 0.042992616823363694, 0.0036027872580058516, 0.020607803467540972, 0.0029836294913454164, 0.11032584649060043, 0.017181869761477557, 0.050736612775513244, 0.04423111286615172, 0.02096793182464617, 0.02448870721573551, 0.04176769968903354, 0.07764226802053951, 0.05846661613172582, 0.004335497449632854, 0.08804152854868481, 0.059807955647908875, 0.08779576754257565, 0.04297669368585752, 0.05013884202907643, 0.09174588541950911, 0.0409438104308661, 0.08755206731298278, 0.0540778631224267, 0.09764650911693612, 0.030059660296706908, 0.03450247038516306, 0.05838001755276515, 0.04529342783855335, 0.09598667237667308, 0.07678713003594069, 0.049736201537833105, 0.03296451440321342, 0.07700517398094939, 0.08426469976022359, 0.009531151717378488, 0.07496833771226868, 0.010354427147596594, 0.0295033406526331, 0.0711100124904225, 0.08974595160614099, 0.06807553822234755, 0.03426199538573142, 0.04128407221287489, 0.03475066755087145, 0.021107516874889695, 0.01331915677104506, 0.025492483494623054, 0.013373223426301154, 0.07483477794354962, 0.030238706535930117, 0.10270457399348099, 0.02374587772083619, 0.031963476888655175, 0.018784330346651616, 0.0522645828013699, 0.018416809241077112, 0.07559179538680662, 0.03339796695077131, 0.09105669740106791, 0.0627654457404729, 0.04676977886007198, 0.014561310883671527, 0.0677139523829664, 0.014106585989676177, 0.041658884560268734, 0.05718595460958539, 0.08114511312376108, 0.040888713387351845, 0.03726687950773105, 0.02750094769702804, 0.03316409945968659, 0.056477242840393904, 0.02540891287818311, 0.008498255478879137, 0.03630500632308183, 0.03124285628268075, 0.017951596603398363, 0.021229014589240956, 0.03423536233904381, 0.028876075521111492, 0.05859007120072361, 0.047200067464502594, 0.03711714762293043, 0.020610264524997726, 0.03641114397455127, 0.026353755928275567, 0.05222671507527271, 0.03043966288978775, 0.0065410061694321136, 0.009794736716655955, 0.03077953205173535, 0.03902038964893549, 0.033765903659044735, 0.02953742581960415, 0.1349848914410799, 0.014366554096341135, 0.036534453486843456, 0.028368747199795423, 0.05800749963870453, 0.1476510061371711, 0.06291989672688708, 0.023238116559842904, 0.04615950938915053, 0.07648575104652874, 0.04241250440358155, 0.05700585116902667, 0.05311037068285289, 0.036740703508257866, 0.03391367818919882, 0.01933941275872771, 0.0175615142084538, 0.04971612237333771, 0.011306709869043722, 0.010512102406562097, 0.03196603753754208, 0.047254762311856595, 0.014679367905632864, 0.018847268300070878, 0.02235485548754373, 0.022632736645098177, 0.04608204257824729, 0.0214122187706732, 0.02045480804818292, 0.0337931725587095, 0.002261682116847125, 0.01906288566157943, 0.046240366139118715, 0.03476721888047553, 0.04554780350337106, 0.03298262855218303, 0.03518650646231348, 0.093167660337302, 0.032611638983531345, 0.053525950399137316, 0.04078180964795813, 0.06252392886146423, 0.028502812586544503, 0.02973894716330594, 0.09878488512889994, 0.04180521501468555, 0.044924322846195394, 0.023984751596506086, 0.07148726482785518, 0.04936312821002738, 0.07478394800977362, 0.013985822762122319, 0.03906920094103102, 0.08167353759129202, 0.025435540179211288, 0.08137175257528022, 0.04765606214923244, 0.018096528947353363, 0.050557918936735204, 0.011250343034794975, 0.02994789955987325, 0.008707352474542155, 0.02476040221330139, 0.009007213652254114, 0.009286388540790688, 0.0485279391549768, 0.06119994506720574, 0.008374492059491815, 0.015532098458929649, 0.03720153986866917, 0.02495299097180607, 0.01876289712175006, 0.03473066499516849, 0.043211242995194854, 0.025071031714399016, 0.0757573240046059, 0.01433593643483736, 0.06106421726966097, 0.027747739091395374, 0.03158910312659798, 0.051225319414609866, 0.014462348603222881, 0.06573899303592982, 0.037396198979789214, 0.010891209634381437, 0.04533577334856795, 0.019353870753078692, 0.04704155621208972, 0.04569172844170563, 0.0349887638472982, 0.08833802755801909, 0.045082018214968905, 0.043300967212886586, 0.05852198130601357, 0.03304272814984283, 0.04633346880455652, 0.043300565016726335, 0.044446142255178386, 0.09695678483694793, 0.010329459384534388, 0.053394631437596776, 0.05290141254062614, 0.05997277946481782, 0.042849833356036295, 0.13317520790282758, 0.21444198344984364, 0.1305154425602767, 0.14462972390315226, 0.1259946274841505, 0.12349939484509731, 0.14901176215179507, 0.25332888227797323, 0.10803555003217152, 0.11327320890080546, 0.20495962291475267, 0.18437183732467313, 0.12771958169797737, 0.15853002156701781, 0.10616879294356031, 0.1193498412988359, 0.1401770523478908, 0.2016024417694538, 0.15698960261239162, 0.11447609717687292, 0.13758068844195337, 0.19041322201730745, 0.13133305755834426, 0.17298184124933136, 0.1342863265064455, 0.188430663078062, 0.20906357124688166, 0.16633377620770087, 0.1587634332357876, 0.1657173665420663, 0.08827821907377051, 0.10289885389107851, 0.29667113396909933, 0.09951588622624837, 0.1810478277864956, 0.14239023439586163, 0.2100464620537335, 0.10936096641084841, 0.14836389691598956, 0.11101593849279227, 0.11675662601426726, 0.10747237581639521, 0.11537464170326149, 0.14920300834121245, 0.16679318381413338, 0.17153451729926372, 0.24940251312669248, 0.10977359668862437, 0.18601341052882134, 0.12234232628778105, 0.07567565137099835, 0.08158425004371712, 0.17631501319908327, 0.07973685199695249, 0.0869549094368854, 0.0665603312213094, 0.15494051659780164, 0.10746171953336847, 0.13133636705817717, 0.15600213059975257, 0.17755032997698555, 0.1399824200498481, 0.12153562804263447, 0.1455355156213045, 0.1576176874579922, 0.11591395228019646, 0.21261953688677282, 0.1581382288807823, 0.16001037922838043, 0.11808138355732926, 0.22025594728127604, 0.07429063335181245, 0.21736865382521384, 0.13892365589497552, 0.16250264710716664, 0.17614796006631467, 0.2157510898166126, 0.27129410375510493, 0.205651844641374, 0.13122171433942934, 0.1257870253175497, 0.2763611318603639, 0.18004112696695715, 0.2114331271619566, 0.12605905547858248, 0.17757597860069047, 0.18129852239883718, 0.11477298689104858, 0.11025378059956337, 0.21413249925019281, 0.09823899385669539, 0.19309373302084787, 0.1526660015506129, 0.09435831418921871, 0.09955559256336383, 0.14369652155906926, 0.13783135241077793, 0.13344868597003723, 0.1705833425324771, 0.18275189844350662, 0.10490589700038395, 0.1417906326992858, 0.0788445664089053, 0.12093694565156776, 0.18944482559398299, 0.13347228147810505, 0.1964040908722147, 0.11445877592890494, 0.1938756023563685, 0.20146502091759638, 0.14983613404535479, 0.16086881139105366, 0.0920687148708009, 0.21586857706068024, 0.07211961678319401, 0.13645168934618274, 0.21520857699215415, 0.1459570631625191, 0.1600179788205893, 0.18392968201829543, 0.22117577373020111, 0.15445046547439792, 0.13905215948339433, 0.0860399476462795, 0.14441733368702475, 0.17964597881561328, 0.19240019362299673, 0.15326814665909738, 0.1680167028380017, 0.11528026733186938, 0.09996087605794592, 0.13196529460049447, 0.2034256390986904, 0.06857054593462138, 0.18693947293345006, 0.10260822311524423, 0.09455654710050553, 0.16830553330721396, 0.11697073226734517, 0.10173263824394635, 0.1338470057253876, 0.14083746610389603, 0.135983471728621, 0.11340807867987503, 0.11043887510294877, 0.1323216940246282, 0.12418037806186946, 0.11276175328079732, 0.17403930305473267, 0.13247059087359137, 0.1339324092071864, 0.09670066632210247, 0.10938485303232748, 0.10339558530118197, 0.14752435648152906, 0.22405290886038737, 0.09638916731121079, 0.12080021427884219, 0.1903637787026744, 0.16733358223592082, 0.15961256509106006, 0.09794729821864637, 0.1154634849198403, 0.14986343741897615, 0.19884170603848275, 0.1637004868638131, 0.1317887419774648, 0.18240285346344595, 0.1969040704951171, 0.16693385287878976, 0.17938846602074562, 0.18815439645080798, 0.10976882396085609, 0.19785176722272751, 0.26116231516484295, 0.16941510441322483], [0.04116166668433336, 0.0800129883892594, 0.009147324430335675, 0.03602115925581705, 0.10753585386180109, 0.0362576084632066, 0.02838359972942741, 0.05453932001405666, 0.01574430768678506, 0.03488744105843287, 0.04036130015588096, 0.07831075634326666, 0.0223933111861228, 0.019155295017445763, 0.02803884101130309, 0.05227702789969983, 0.020393499946822564, 0.1148663959916561, 0.03113679332478393, 0.03057178815886859, 0.00809571074862634, 0.03609501779259693, 0.023017500474628423, 0.013390390499074374, 0.02728077211237002, 0.03958267903315925, 0.011615754525747993, 0.015114802705694833, 0.021712448628198718, 0.08088516416929423, 0.04930602018571189, 0.057401577716753374, 0.02851888702641572, 0.0779359937915879, 0.03519052842391595, 0.004635446248651152, 0.030473901274343653, 0.04249560579116787, 0.02489301394821415, 0.03043963799193021, 0.02063414923125698, 0.02310243855801321, 0.06619257071325857, 0.0947945399750625, 0.047361689033888044, 0.024592188457327507, 0.041017818354791215, 0.030446500224511952, 0.039767873127974813, 0.03994695001071499, 0.028307525283326546, 0.0589087829294224, 0.06767430733288489, 0.044834813133122466, 0.08196664283112173, 0.0369073506144266, 0.03455475588599521, 0.02076585698241909, 0.05247859712389689, 0.023737829967191624, 0.029392928230546178, 0.024153034300393155, 0.030443841899414698, 0.016892903311658772, 0.03187971666545397, 0.02062401771845837, 0.03538308845412347, 0.030809016860721093, 0.04337864852840862, 0.010970291933195006, 0.10393976819731536, 0.02383546212748174, 0.12687196669679496, 0.025392748422980792, 0.04121806990775851, 0.0700226272906988, 0.14777416243187844, 0.04647377014700924, 0.022463689768506635, 0.06372139706546742, 0.02592763484215304, 0.040481430403287375, 0.009199979568591282, 0.04802178486340469, 0.08501538165634678, 0.009985005186359969, 0.03326398966413352, 0.05100190136281233, 0.06235763798618029, 0.03283543241841178, 0.018906167054909374, 0.0897251216754798, 0.029912738039368586, 0.04125370831799604, 0.06463748883576163, 0.058783152170719645, 0.041673202743573536, 0.04209069384922905, 0.0667254691342673, 0.04068915131351641, 0.06911786213036507, 0.0682027088177781, 0.03824155019115537, 0.0522480467935243, 0.022869411848425385, 0.04501441478609078, 0.004672669503282035, 0.02071853190089666, 0.015035981834385426, 0.06966851080857939, 0.04455880697576269, 0.06020054506558565, 0.013995327040432923, 0.023840930080041293, 0.02465515705426374, 0.02914080869466547, 0.05299096821897453, 0.03323349553430754, 0.08468348938491076, 0.0526052046447031, 0.027675724911293196, 0.05962599444413378, 0.01797897850103196, 0.07572938477800739, 0.014918851778812468, 0.018254536496956023, 0.047899773870144165, 0.05806453105422759, 0.02178778188423284, 0.022689986395679658, 0.07803549329119344, 0.028522050969542998, 0.055461889057750666, 0.04647627908496126, 0.03213288765701075, 0.0797934965380738, 0.06072914573333918, 0.02204060622100388, 0.024867688996657252, 0.02723540055505451, 0.009277444464274713, 0.07263565360898934, 0.022962211909133102, 0.0409707460822838, 0.011583659272160263, 0.025558280871219696, 0.07484349602412793, 0.022495135762578538, 0.038141330568901, 0.026940500754262173, 0.03247483866289258, 0.017308519417119604, 0.04020990969072427, 0.014761730018372258, 0.027421908490660212, 0.00750031870519442, 0.00830070055540531, 0.052482929351108695, 0.023159157792707125, 0.04303558286459696, 0.04583122156139824, 0.02353113369956132, 0.031253263587132096, 0.009962299297894201, 0.012265232376634114, 0.05262893038771806, 0.05021525163864417, 0.05900804877221104, 0.009794783639541317, 0.03881842205901781, 0.046310091631547104, 0.06259491073808844, 0.05089995804272833, 0.09962275549168549, 0.03183266546036447, 0.039993470699916926, 0.0033995012786509774, 0.08795041771185014, 0.03342504049801538, 0.07042152927287164, 0.05706249954058759, 0.06781988702113591, 0.03456918515204903, 0.01603673685402159, 0.04031878993696263, 0.019466347782121553, 0.020021037574136452, 0.06646706001652826, 0.09071043332017238, 0.0930625147696945, 0.03472976484185746, 0.02141566042067303, 0.07204213465053229, 0.06399322038276062, 0.06702580624410222, 0.06800033903170018, 0.05559113958189565, 0.03259006594758361, 0.047274343519201206, 0.05209301358028766, 0.0289590485889705, 0.04260281979617092, 0.04882412406826212, 0.028606504502315677, 0.04798968960981696, 0.04132822952083042, 0.10663568522901305, 0.08053983471566632, 0.023824951401160612, 0.018179999972363154, 0.0689141976556951, 0.04853467306783123, 0.05205298165580438, 0.04516249575141457, 0.007074186606557981, 0.004215036348004135, 0.04345317739212225, 0.05156829314787061, 0.049222658328231306, 0.032648395882138324, 0.0451201923762358, 0.057274602473743504, 0.01979738778074182, 0.019715305290094787, 0.033248051204868866, 0.07350858015518996, 0.05410763329916424, 0.06782837527533693, 0.06255596665845764, 0.05265803023752186, 0.012254231354041446, 0.019776479326068394, 0.03754949317343774, 0.07274778589846627, 0.05846090494625031, 0.031002406181106647, 0.022616911183802352, 0.05713674112132961, 0.04638693408079205, 0.03624413297661851, 0.052230070540381056, 0.015385923137317504, 0.021372793970869917, 0.05542882853337834, 0.02463658325253956, 0.07430729576416555, 0.07123865397466768, 0.05763209740360899, 0.12358434633502077, 0.04330908008400471, 0.05096101141985386, 0.04732243468864791, 0.021793646287293206, 0.021343558140459563, 0.008513453705686956, 0.09464533669092963, 0.04227303426652666, 0.05969147197902203, 0.023767253489143426, 0.0680656327054866, 0.09691763008313795, 0.0809814460996178, 0.01522042133259557, 0.020567225705411647, 0.09157975925312889, 0.03878453415968726, 0.047657088707050974, 0.05002584022980544, 0.10617921940020977, 0.03239418492622433, 0.04308959589369836, 0.045436379845224084, 0.01724131626918191, 0.01631646811391317, 0.063905235184657, 0.04268238568798669, 0.030352939821539388, 0.022974670414001714, 0.05398827680056134, 0.026899949805210197, 0.045480629083730524, 0.061864656576466184, 0.031021138946075114, 0.027140445872059753, 0.04326099657543725, 0.07201834762048337, 0.08015495214250781, 0.019180968539008213, 0.00598738028202206, 0.017169922620298404, 0.03177621818688368, 0.0007726044596863851, 0.02859864635543237, 0.039200680781035654, 0.029775995175324144, 0.047053308000848185, 0.032853845341671864, 0.09340735392705088, 0.061643893019326275, 0.08513969474381979, 0.08087857581314542, 0.018866041284655372, 0.014058526421356347, 0.07708728328467378, 0.050558558620151975, 0.02095621067940468, 0.03205544765918486, 0.03416982734756124, 0.009920037099941364, 0.04892172750025507, 0.03805526442104771, 0.030675033828423872, 0.0179735814116054, 0.016781939306266366, 0.04717285602143215, 0.11175328279815375, 0.034003410067769795, 0.026722897309809927, 0.03992459556508449, 0.05277439899322006, 0.04264346459099362, 0.08725300956998142, 0.009707762754612393, 0.03891953034326434, 0.021370555078911207, 0.05304089033856027, 0.013894307813907584, 0.016600952949374914, 0.07102774230823403, 0.012930521324667479, 0.022477508079440846, 0.027663507724120736, 0.07911634376092304, 0.018684907455838496, 0.044212596521021864, 0.005746321140548155, 0.02228512041901629, 0.02346481538317617, 0.009298647862798985, 0.060685946035289, 0.03896800072623357, 0.019359771545315464, 0.08077172953034602, 0.03088979891711666, 0.05746987445520298, 0.056779211717507536, 0.012795379584384783, 0.03454550920474914, 0.03710977019621961, 0.05270456624848228, 0.004336492406324514, 0.03461487080541349, 0.21831503288159448, 0.18049365510382961, 0.17193352653374597, 0.2403292282214088, 0.2688501300590654, 0.12020307172450329, 0.10418184432050875, 0.17226446119527664, 0.17880613194598308, 0.06562180456615264, 0.13006680615005956, 0.1918024152156807, 0.2173829796693979, 0.215504179678617, 0.09706465001668661, 0.13198516692125029, 0.1941118638722166, 0.13221494733325898, 0.080155273899436, 0.12385364922304308, 0.08723443193781762, 0.1196426937296506, 0.2260404780146576, 0.10919157670991075, 0.24334254314101514, 0.1481640858635787, 0.1141078387116713, 0.08996839289583507, 0.0924138987677232, 0.1523415020276462, 0.17981649466579963, 0.16757971096423366, 0.10268840953827867, 0.13164074911225226, 0.10321120325956615, 0.08111780975013971, 0.16769609504169034, 0.15189798308476327, 0.0730629085052398, 0.13396006498125293, 0.07218986704585052, 0.22703173450164257, 0.11229365823730347, 0.12828088665921844, 0.12210914444538856, 0.15592135428901643, 0.0976592108547207, 0.1258696555610626, 0.1166101270205071, 0.1759646045825174, 0.21820853133836102, 0.11965750220922694, 0.15473857582096132, 0.18607037682687083, 0.1384915056968889, 0.18265771559409558, 0.08108520504808234, 0.1489136722539702, 0.26626973142546995, 0.06714808153769664, 0.09264304332675473, 0.1817792272495647, 0.08539111713968939, 0.10797497545999866, 0.1422179871869664, 0.097338403875549, 0.10604968925397243, 0.2961415527088027, 0.13952103593657095, 0.197934826475478, 0.23440508562470638, 0.20151061847084956, 0.3358985129142961, 0.08516686788249402, 0.17783085605309856, 0.1531358739180911, 0.2255631439507969, 0.09809108526115456, 0.1341723019797956, 0.18742135755958098, 0.13617047379093786, 0.21384261157964507, 0.0980203063978303, 0.1171079386145838, 0.17255120790533482, 0.11456753743151504, 0.18358701088976476, 0.1680389959965983, 0.17630165262568384, 0.14177573995003778, 0.14528973929343686, 0.2221651149973754, 0.1429716031998396, 0.12958257729488035, 0.18986422808900957, 0.11181171998501786, 0.1372743145592751, 0.11008939345277126, 0.12961604001541294, 0.1594824373962418, 0.2102644293899498, 0.15481074130342853, 0.1689754925187557, 0.26251694247607266, 0.16244663075814325, 0.16195422008393273, 0.04972817676682627, 0.20564220725528656, 0.16659537991208417, 0.14433251243204842, 0.15904618096688103, 0.1140088295083373, 0.09289450402702056, 0.14135978485067047, 0.1271062670275569, 0.0863615973221679, 0.11270190649215253, 0.08715289720003644, 0.10665067756969122, 0.14355704759157475, 0.10215171132116549, 0.3491726715958888, 0.11173776185680782, 0.25477338702447955, 0.14847579171820996, 0.0861041994404889, 0.13122384406385884, 0.1648640058814518, 0.1217583834283775, 0.11376588770578946, 0.2081569368320127, 0.14516341139472302, 0.10993395421293475, 0.1574636271764194, 0.0992055899733978, 0.24867111366362343, 0.13779920736147513, 0.19011444772683805, 0.10619806516314707, 0.17479944613672074, 0.15683807042096892, 0.14743363634953577, 0.12722478849032234, 0.16928038019086086, 0.09718064338930192, 0.20539606320521525, 0.2700006102602328, 0.14077844669020947, 0.13198591768741608, 0.16196561947224603, 0.1200539910144383, 0.07668924698185536, 0.1519948472419093, 0.15010009730054488, 0.11166329044968852, 0.10786878035193491, 0.23159418645645344, 0.09842357508117154, 0.10999095115450122, 0.11626532616754694, 0.11332203168421985, 0.11969831171295336, 0.08272859388061109, 0.10933333361941962, 0.12616944874847127, 0.15386431628177244, 0.26284819889453154, 0.13370863492450408, 0.121552619872795, 0.1455789681283697, 0.08114761057039423, 0.18583141868152928, 0.14208134774479175, 0.2404246214897402, 0.09966433874421543, 0.143129846321479], [0.029354976234777324, 0.015409055162191152, 0.034614863144534255, 0.03781296230191666, 0.04704273598749311, 0.04378556379026944, 0.03525383409953887, 0.06391007302989883, 0.036371985390301675, 0.026644566734772057, 0.038238539465612946, 0.05295531831741814, 0.021447625439313632, 0.06491816046858026, 0.11282896217439445, 0.02110734258988692, 0.07655954829627469, 0.016777746890100743, 0.028552575742885954, 0.042753398208127874, 0.07319765571024149, 0.03933016879243716, 0.05099908215925098, 0.04302086631557153, 0.02868252340704203, 0.07115581688741524, 0.02911473872260221, 0.06357571395534663, 0.0077824923491496, 0.04317919370688258, 0.05885113864355992, 0.09075223107732112, 0.06046006118037528, 0.014236075916297495, 0.031691205409926274, 0.06813744578750865, 0.021082383445313862, 0.10498448229965665, 0.02587603882045275, 0.0805464537153321, 0.01729536185702009, 0.03463750870357599, 0.022474173681750413, 0.019002171278360392, 0.060794167445912484, 0.058020117106817426, 0.0339041174119038, 0.014320114803981158, 0.024392099698044123, 0.058604519618975545, 0.035747367092558456, 0.028671302134171132, 0.03850691155680726, 0.043773183809413065, 0.043556059169913494, 0.05383783245399114, 0.02886178989654347, 0.07316066132437798, 0.019357356453134168, 0.07494936171438425, 0.05904487844917083, 0.04195823341668133, 0.0382091255197602, 0.007193893590386236, 0.061926828441961165, 0.05436252224289122, 0.03923927246022128, 0.013851630013255824, 0.006829128964924284, 0.0592398822998568, 0.0578574076925795, 0.042033578164034316, 0.06267893526162352, 0.026523450149163127, 0.03635555280432586, 0.035321242175996304, 0.022617464682327646, 0.0650976931736354, 0.04376309826188991, 0.01752871606919554, 0.02889415519612451, 0.023403486214397896, 0.04520788263048857, 0.03670180156346291, 0.0516111902411907, 0.059349777612594835, 0.049689064147852124, 0.06717039767893092, 0.06185238384791921, 0.009595750166373629, 0.05160884218170278, 0.027049737231385325, 0.049798066968158375, 0.06961915942449724, 0.05924010829579446, 0.02125221173158817, 0.03435918129980564, 0.06078521953895689, 0.019439504061254765, 0.04781131752796712, 0.05258468497965125, 0.00793284907441346, 0.014652314468196806, 0.01601514753870546, 0.022169523496901797, 0.024049834596113335, 0.038881942239259525, 0.03992335833308678, 0.03868234569146749, 0.024246460637978973, 0.03672828522300528, 0.04741647198135334, 0.07871101430106549, 0.028789273928850893, 0.050658766751087485, 0.028678390362690535, 0.04561146540987877, 0.05886552194433828, 0.05141767643151745, 0.018842150832736687, 0.08924814767294353, 0.033140975095692186, 0.03653416237343223, 0.026865640557521296, 0.06507342350819419, 0.011665064732604211, 0.03011050363702159, 0.025393265532329682, 0.10035140469910638, 0.049850570804048935, 0.04246966605405173, 0.030482692133274772, 0.08199343292583382, 0.023164507001638416, 0.05677664915340082, 0.029080234122492617, 0.05558877237020962, 0.05846616030941087, 0.06451834684177753, 0.032940214094255245, 0.05887959114906769, 0.025807364783700437, 0.0718051223685184, 0.029369334637698148, 0.04416301148012281, 0.08781057602215199, 0.04513328864930138, 0.049751393061371586, 0.03385776909248483, 0.07870351430028677, 0.04955234043600579, 0.13028138737765052, 0.03269692755214149, 0.043569454217269536, 0.10645568521032411, 0.035282895644946445, 0.09126646759649439, 0.0065745550748561666, 0.06370426350904089, 0.009332502245782845, 0.06167369383958079, 0.12858859353488492, 0.046249716242234555, 0.026578156487835992, 0.06566364828857683, 0.03760209277031883, 0.01374096861259351, 0.044782064149096135, 0.003175349937068419, 0.023232953127233252, 0.04074057113499411, 0.038434972070277705, 0.13744124511797584, 0.060100674013336824, 0.050023112956795006, 0.01635320202988242, 0.039047030356502345, 0.010218754891426334, 0.05649913380283022, 0.06671092878546446, 0.06221701105635974, 0.017508543058929425, 0.0682640954431507, 0.033781918727101824, 0.051287640667250084, 0.049760658894815755, 0.049786269214124455, 0.03817968859126972, 0.01517920197182966, 0.0596068307547079, 0.024698525291657256, 0.0457825519955687, 0.04117691183402654, 0.022067340774341457, 0.05843530228782085, 0.047433701298770406, 0.05893307557750133, 0.011554825637910155, 0.024968310815071868, 0.008891866666324919, 0.059783892826207226, 0.04953241831953487, 0.010947287270438769, 0.06838578850992265, 0.05039086197352698, 0.08602799667466073, 0.0335903967460317, 0.04817517481804375, 0.02773068405898108, 0.06546474121991666, 0.054519321288793325, 0.11617585475887023, 0.11110173267943245, 0.05228849623592631, 0.014496425151704781, 0.06678158507472085, 0.04451330135306043, 0.020374050889644894, 0.012296608465182926, 0.03780107261733182, 0.042395026107589086, 0.03644253059680905, 0.01607678218504354, 0.006808638985779498, 0.023279630864459663, 0.0578913415571855, 0.027790678319551294, 0.0056991430521462, 0.049827921414567586, 0.013811170037144856, 0.0453982248361553, 0.04341954230180672, 0.04372780459121831, 0.037389235240557504, 0.04541988980265395, 0.05732638235654562, 0.02912310631795516, 0.016860549503396598, 0.044264927987129464, 0.015329819645792728, 0.03881120551077109, 0.04757415585880799, 0.02102260943502188, 0.03495607104512953, 0.05086278745664224, 0.009096540461835122, 0.09314654695410883, 0.021840226348309268, 0.0687890954976601, 0.05293780554746909, 0.052992209281411864, 0.029260450561020165, 0.014053601433613129, 0.0910194502061894, 0.006952674528058138, 0.05902558452479782, 0.01988012527656411, 0.01734384373130818, 0.019370586791586493, 0.016990100717051856, 0.06626073721676104, 0.02406028403540052, 0.030097158385380626, 0.09857624108272214, 0.019143338300167553, 0.010119170164539209, 0.035473486829188564, 0.05572664138350276, 0.05661317365123861, 0.049081498967303384, 0.03661062943959429, 0.03131194783735179, 0.04098167815696328, 0.06069078771097045, 0.006591614895319987, 0.07449890201490733, 0.026027063478625594, 0.05305209820489249, 0.010304834445818298, 0.020667056538044445, 0.016417132067163626, 0.02981980199805431, 0.05372232554720775, 0.03534456955329065, 0.07892033250461664, 0.024509175169852473, 0.014650718132484586, 0.018250545178870523, 0.05058836327084611, 0.023825836232713154, 0.037952394134575324, 0.014049834196245479, 0.07192670818298094, 0.029184483367228703, 0.017074713213068825, 0.0323050505962343, 0.05508147660763033, 0.028648424833532304, 0.029685761509162766, 0.07000621002648147, 0.03271459737011502, 0.014325757999153388, 0.027498467487373182, 0.03887007553731242, 0.0755243566668322, 0.023536819987179294, 0.06711088796897281, 0.01874151177734377, 0.029806676996691577, 0.0371688470665005, 0.02877422604679821, 0.03674471014810186, 0.05030229837904054, 0.023921218009725697, 0.05346933650153299, 0.004151791480610207, 0.06963655728125764, 0.040375476612919764, 0.02147501691304628, 0.0747445710904656, 0.062095831268497055, 0.03832928258024397, 0.057874958766924764, 0.03293785837388808, 0.028124901413496946, 0.01546627618447547, 0.05666006206264419, 0.035169215857862465, 0.01609248698749129, 0.026886830549506892, 0.08251486301061609, 0.03189696896550877, 0.05566423969163049, 0.058534660061160405, 0.02188247992777296, 0.028640829071763064, 0.03609174659716026, 0.10631117038428785, 0.009626282600595826, 0.10915146434619542, 0.09018594654457224, 0.021044372077730876, 0.035781714644643574, 0.038251359947025776, 0.019380718304385102, 0.005621056188829244, 0.03896975506758017, 0.04650321090593935, 0.06276722689489685, 0.04905876913858999, 0.03419884292769336, 0.060372317299967816, 0.1424401986502832, 0.1207566545194676, 0.11679542070675282, 0.24628850361031873, 0.23149074926491708, 0.16745702964403938, 0.12087497679937272, 0.1367856423941351, 0.12728716336911725, 0.10059538838123122, 0.12175454532787686, 0.1405616131641211, 0.12289289835720293, 0.14201376346811173, 0.1281843442590006, 0.1155803363109308, 0.32195313863696595, 0.08565013146688862, 0.13561973318217263, 0.17012238742843752, 0.13894222586626007, 0.15814107872786062, 0.08706166378913388, 0.18393306812692076, 0.11664838545144567, 0.19511747684690262, 0.12178410099999559, 0.13945173562294053, 0.09243067609326494, 0.13561463103659693, 0.17039709123632601, 0.16360714671111878, 0.18988483585417273, 0.11247979462026589, 0.15238063379881844, 0.23206231214346426, 0.20760970490594066, 0.16415057884108636, 0.09881209657197038, 0.23917818111517739, 0.09165168724833958, 0.11904067885611327, 0.09011643172632303, 0.13994839042425156, 0.16321777486272399, 0.12469882806462627, 0.11555579851471609, 0.1604579277937451, 0.14673713985229694, 0.20953874494279587, 0.17566869546088482, 0.10013739803745862, 0.13212819553671346, 0.17577567197863134, 0.14308584223110832, 0.16203999128793517, 0.10218781704503684, 0.140753380293327, 0.2015577175564343, 0.26879975211716467, 0.22600482428266158, 0.10330529417842628, 0.209119112621392, 0.07811079207327097, 0.13604434507508434, 0.15344612420566622, 0.24973462756362655, 0.10102217596384788, 0.14419480046677974, 0.17238934884869284, 0.14355117935807477, 0.20043153766422503, 0.16676385796839194, 0.12928095315733265, 0.13032821067158254, 0.11113035372428356, 0.10451295518226202, 0.18707053525553596, 0.11996381480487124, 0.12915310840452873, 0.11604830111947753, 0.13039011057586442, 0.1078772992496529, 0.1489008785856347, 0.16047671226964844, 0.17435519174943048, 0.0951620783176153, 0.1355598251064939, 0.19234773192194202, 0.09823206076098066, 0.14199343149460134, 0.2030565226150136, 0.1409680228079519, 0.12331350361027064, 0.1781998499627075, 0.10970720750910622, 0.11303691674144038, 0.12110936906068556, 0.05775235022508329, 0.19758844748139384, 0.09330900355933175, 0.11096759068389093, 0.10655297837670773, 0.11804982839572815, 0.16451641646844728, 0.1273959478543651, 0.17065440484833333, 0.08525545062917857, 0.1273877890179715, 0.08767931451720577, 0.22603882326474115, 0.11445949605155377, 0.14249256842078703, 0.2080348070951239, 0.20181991880939854, 0.13051381845387722, 0.1186439908680416, 0.24270060742574356, 0.13886768551122758, 0.14077311471825646, 0.2356578232420068, 0.1324531853559517, 0.13230113222474052, 0.26273282605313486, 0.09476963445664414, 0.15790588973510652, 0.18313100471371607, 0.12263678750323674, 0.2446457965960426, 0.12621803404462914, 0.18998690940920385, 0.10654313414688073, 0.2519417421952371, 0.12853925747256126, 0.1400988041273048, 0.1200758091985218, 0.18626577521283783, 0.10583837922181814, 0.14415733876728243, 0.1537670231153888, 0.19270238466560843, 0.12314125640137542, 0.1351479915601592, 0.1890700400596665, 0.14444407015558214, 0.2388236356238204, 0.10011708138570671, 0.10638875210837972, 0.13028915550920273, 0.1723335010390128, 0.12604675976739776, 0.15390557777737418, 0.11387344645035845, 0.11790712153719318, 0.2187828521334356, 0.15076451003551483, 0.1851061172783375, 0.12501958141764327, 0.16986001763612996, 0.09987493631460014, 0.15090910147034353, 0.21570887837198474, 0.1575803330108043, 0.11617964689409542, 0.30813444465879475, 0.16266173292552272, 0.1203826197513169, 0.07627117747981703, 0.10721431143822209, 0.10765995244465529, 0.18791576006239463, 0.1109175957859524, 0.1715591240433916, 0.20941224850473866, 0.12813558276262016, 0.11910162881136903], [0.07331076093138227, 0.02629886189806125, 0.03509678990550099, 0.05948613360223751, 0.08412662007275128, 0.021280095416812167, 0.04394116773900967, 0.06252279888177592, 0.03057587715316444, 0.0217538595109457, 0.01625434795935308, 0.04433099540971941, 0.05219699852468987, 0.04270510785582085, 0.023105039426516143, 0.017262609683037285, 0.024176242934059233, 0.030039058277203195, 0.04049126697223514, 0.05107073053236931, 0.01581451581460574, 0.013462647912092509, 0.05272140103061834, 0.04454502888444451, 0.02667682861248332, 0.011626293022756376, 0.030499523084971215, 0.04639434215101985, 0.04055131677417986, 0.01756465708416316, 0.015108580156529864, 0.04099606528818127, 0.030442466771590616, 0.08708944979814753, 0.07827118790197758, 0.03743919566453945, 0.04146923566417348, 0.009657190417900923, 0.04635094327010936, 0.03195107200994127, 0.10949804252313991, 0.06509426876061386, 0.015252894842095915, 0.09613460395485164, 0.04746489256860749, 0.027704464699772578, 0.047214634626382784, 0.022173279242950584, 0.03068067798120601, 0.0507479508767926, 0.027464146748365417, 0.035587446238364906, 0.049802387704051314, 0.0268016051831505, 0.022799927673693147, 0.009494878411773712, 0.03600534337062029, 0.01495614493896644, 0.030943566798082286, 0.017631827673364072, 0.09214739976150375, 0.05969663541163168, 0.02513834594508573, 0.010493907818360435, 0.03393173488157411, 0.05172891114207526, 0.039625097321526664, 0.015462228367405554, 0.028244932069473212, 0.03836704688447137, 0.05692360396947592, 0.07396878449306374, 0.03476071096355877, 0.017178728800988006, 0.04565824656897495, 0.02408926131113643, 0.04886088862774834, 0.048077843347263914, 0.04135033498788553, 0.054899787365068356, 0.02702243194254416, 0.012837264484034912, 0.03815512015153805, 0.016852405988761497, 0.049077722153836684, 0.06554683520188255, 0.04237250695305486, 0.07147128423375469, 0.049300293678477894, 0.05477215711688323, 0.04095104996175055, 0.04011918572829135, 0.0813861933326529, 0.029423414699492917, 0.02563469239600724, 0.03797515843724532, 0.03880062200609715, 0.035998345157431985, 0.02924188825061485, 0.020527563418351838, 0.03860187964634069, 0.028898592760425904, 0.06925974161394181, 0.0479628152454332, 0.022298906171213717, 0.04130643431938464, 0.07630030414269817, 0.030081941963984605, 0.013294927325219879, 0.035575047105310426, 0.022889400997589675, 0.04148961743339896, 0.05597091234859921, 0.04229361904905208, 0.054542966592576236, 0.02370115159259689, 0.12771461744822804, 0.03253909811798123, 0.07605322546535924, 0.05931194053001462, 0.07016101341334081, 0.06858417463879432, 0.0902868633068377, 0.014074363373971034, 0.016234119407712452, 0.0594323312473153, 0.028192173509347825, 0.05856770526377424, 0.02242654982593752, 0.013627166251441645, 0.018388868099258795, 0.004653327219608811, 0.03172367221615728, 0.04212775335256611, 0.01999986290390934, 0.02893862085446956, 0.03530567909981455, 0.030375790309100866, 0.14427275757395452, 0.047719394637932705, 0.047595797842668916, 0.04169264605509178, 0.039233944318707914, 0.07632767646423272, 0.093525139945409, 0.010658926030080165, 0.08365927579542322, 0.015227273031468353, 0.05706934836663066, 0.018710908479988575, 0.03992674827215172, 0.06343025301072387, 0.0526748075630636, 0.04274800111870131, 0.051049184309498924, 0.07122812792658806, 0.05074692814941368, 0.035326984004988786, 0.04644873822408338, 0.0017742165401878377, 0.02585248927766037, 0.030089160427451137, 0.009074828572451107, 0.04039307365254049, 0.0105079329730342, 0.05397043078236523, 0.02983697960453649, 0.019275574651997418, 0.06709164384031488, 0.052516821080878864, 0.03646065623709752, 0.03876456990838051, 0.008499213088784487, 0.04634694046070499, 0.019489407028642394, 0.028376695362009832, 0.030139362169129234, 0.031866294805020574, 0.046761635345436876, 0.04638465496921732, 0.07300933597669487, 0.030222672315674926, 0.06871540550022356, 0.06510793576918303, 0.04228616501354883, 0.029959095934886607, 0.032103098328075105, 0.05888779978117636, 0.06346136767176852, 0.04249605012216395, 0.03808501927602676, 0.02511599916033447, 0.01677957209458034, 0.014626109473136886, 0.06142316776658259, 0.11393664104323234, 0.07766127466194092, 0.028810584579684564, 0.1076068702123819, 0.042284016136921225, 0.014472095156839539, 0.024240345341123404, 0.05423420634601386, 0.04621565980356067, 0.019559224451621695, 0.04056325242404015, 0.03268170155464642, 0.07606185927626587, 0.05447145611528428, 0.011206886697290166, 0.08153212542134909, 0.10578742671397426, 0.05568783519969833, 0.06982103125342438, 0.04823169295465754, 0.06137149513608987, 0.04567034692773896, 0.017697178803744818, 0.04218254396091065, 0.07965644340842001, 0.08961169469741084, 0.009642450886237766, 0.0612220045689854, 0.0693501016846107, 0.05590540800063361, 0.053171711342950026, 0.048744983355244326, 0.036243631189028104, 0.042678520774408694, 0.03182284995883463, 0.030743788304408232, 0.03316726340281387, 0.13864263952259095, 0.040372167113086874, 0.024884033482521776, 0.03804562320452064, 0.07876080235526448, 0.054998965107745705, 0.06073445472265444, 0.051735564615697636, 0.08134637974322804, 0.058668882495933966, 0.03866488271723351, 0.08503517736831019, 0.06245477027409981, 0.007909974167799398, 0.07552845523722711, 0.05618275864230049, 0.0342820898719853, 0.01600911076586213, 0.028285613253472314, 0.022505874400057142, 0.054244088880237074, 0.04242501461938505, 0.011863783152113038, 0.019440892595617522, 0.08144776381912731, 0.11909423606289972, 0.015092790126800539, 0.014994089273856053, 0.0548144796442601, 0.06773899579721113, 0.03748087467805993, 0.006326768723797174, 0.044514810546271266, 0.0747567595493409, 0.04162926760111605, 0.04581598790302392, 0.033057226363809845, 0.026213088778839, 0.033437546883379264, 0.019134212277769562, 0.05535772025224663, 0.059603797046527754, 0.026228705481175455, 0.013698269744523832, 0.03809414721364456, 0.04055467990016745, 0.025654532158026294, 0.035256963568709554, 0.08340162510472922, 0.030897373611467983, 0.01943930104795483, 0.002218670828545827, 0.021278877337012562, 0.014861645120676729, 0.01932835810998034, 0.005565991704051774, 0.036523383516337604, 0.035183940067767136, 0.01746048253299969, 0.018355005097785787, 0.020763091405012438, 0.02349814212310218, 0.03578887756673559, 0.024185809457013686, 0.04085426241339695, 0.05420072064284356, 0.032338739312704534, 0.02716238854543096, 0.014045402377603516, 0.07931377227988937, 0.07353628189453194, 0.03851932984205984, 0.022274127057302865, 0.057390607337677674, 0.06174806948570956, 0.023602761005261735, 0.005918121145617578, 0.044977033525825515, 0.04492289792265623, 0.015531881081481135, 0.008760544831954665, 0.051614813837072546, 0.061462502551054767, 0.04766216403954933, 0.028652027361996235, 0.037272222971002904, 0.010036007489918942, 0.08300584110040819, 0.04574810102161381, 0.017736379522830248, 0.03586641332555202, 0.019946422525531343, 0.052075600401768764, 0.06112280384367032, 0.05510391915337213, 0.1260755646733507, 0.05817763244492873, 0.06090590903054803, 0.06886951174707183, 0.03460327223423989, 0.0420764216311997, 0.029547383047399983, 0.05618206916316863, 0.01659143622213554, 0.08487288164155138, 0.04175225535648004, 0.03617078388830827, 0.07090496905748883, 0.01962321003027741, 0.05219116476514647, 0.0694226578719193, 0.00869569357394451, 0.029319561905257648, 0.05205273267722899, 0.04959383175798482, 0.03192881715574092, 0.0976068640668546, 0.08271291206080107, 0.08562079796026792, 0.029680701498422894, 0.10630605291695365, 0.08312601731309006, 0.1792955548772889, 0.1451376555187087, 0.16496476176525318, 0.1637161610227439, 0.09825172623799694, 0.22338491083393175, 0.1329136961289952, 0.10690297330579451, 0.10494009516532384, 0.16301010374821004, 0.12024841646874145, 0.11266486614101356, 0.1313274038294631, 0.19834770190138973, 0.11548069125461964, 0.16183946011287553, 0.16403085462027983, 0.15166202800408488, 0.18479539201624934, 0.06417456105531705, 0.18807248632994392, 0.1012023521827594, 0.11176502692603296, 0.07026167736659128, 0.13979508090884457, 0.2557092247110221, 0.1525304039880153, 0.11479494297095846, 0.04616527037034112, 0.1251180390376718, 0.16197242233301365, 0.1726712232395526, 0.1810919391291757, 0.1853847434563983, 0.15147841205039334, 0.15835273349958082, 0.16706546678418116, 0.1416138962151543, 0.18033729655848396, 0.14103321689030818, 0.21598379668449202, 0.2050922633779626, 0.24045308931700646, 0.07223602384328842, 0.21396607430952214, 0.20513432160500558, 0.19343122539501037, 0.11792188405149406, 0.10097917544865802, 0.11539403138862503, 0.15870484283133862, 0.1215170197669537, 0.17332685660691033, 0.11312035903815301, 0.20664892339658356, 0.10014462990746384, 0.14980405028308594, 0.12365540098999778, 0.11233589266456905, 0.15993064479722133, 0.08116348391218532, 0.19048339567117153, 0.16743144230736842, 0.13578378325027807, 0.13353897709279292, 0.16366190667594635, 0.1822040383253367, 0.16905507373232997, 0.1543270793533133, 0.26712254050277895, 0.131629855341969, 0.07610259217119987, 0.12677586862757323, 0.146700857928203, 0.18742509606865146, 0.1808628022310234, 0.14104627102853792, 0.21019439363191206, 0.15393160944504125, 0.18389718456854745, 0.10522144861639508, 0.13580722554076102, 0.0925863911247542, 0.15846324934353753, 0.1306266785268822, 0.15349878508958126, 0.1330784969632664, 0.1656191081048981, 0.14630270671219597, 0.15530114482727744, 0.1258334808892781, 0.16687150864351183, 0.1309107592509639, 0.11916657774558953, 0.16413423052478224, 0.17878475809289565, 0.11004411765644628, 0.13255495247581314, 0.05586346851721887, 0.09969047000331265, 0.17252186673783487, 0.23463241455535735, 0.2719662692998686, 0.09528341132306284, 0.17206089631203683, 0.1474222063177055, 0.18673783859177945, 0.05987965764718191, 0.11632368674561863, 0.14387776264019553, 0.18891855383351927, 0.0814941504429425, 0.1129337783241945, 0.05736325416834124, 0.2045633103097639, 0.08605333120231667, 0.10565208196039162, 0.06721811729573435, 0.11161237624624085, 0.16402932244443125, 0.1159180202070744, 0.14082859480573287, 0.1205304517380653, 0.220480656191226, 0.18996158254242715, 0.13299266447223004, 0.29309141960355545, 0.1648381274313696, 0.21299629892793395, 0.0611519190152326, 0.13946961611509323, 0.1386149224614905, 0.13850324216388887, 0.1932106073945761, 0.12053951455820953, 0.1400388347645921, 0.27531931357037637, 0.14324229270700486, 0.141583313985217, 0.24583733910995148, 0.09990590158849956, 0.17018935883477812, 0.23276515184871613, 0.15783963845141474, 0.27646829223921227, 0.15337126209370552, 0.10751227367549174, 0.11453055836741002, 0.18066265409992588, 0.1826689770865825, 0.19102851319457256, 0.14000405437282978, 0.14972728827307302, 0.13505665855782648, 0.17676343510468162, 0.1395563372681218, 0.12233209135311267, 0.13038612691865814, 0.08842910009045755, 0.09346861031747634, 0.18483021837328711, 0.12387371306577999, 0.14627419291965424, 0.2246876433491707, 0.16115926596666538, 0.11401951643488101, 0.12164220619466036, 0.1697349920868874, 0.1599949808611024, 0.07174008150374697, 0.16203959292221456, 0.13080065709448632, 0.18412558602229243, 0.13310933966309796], [0.03154001029719028, 0.03500984275653478, 0.042239571545994094, 0.05388571677969829, 0.0308560872180087, 0.016903046315776247, 0.0493969050266089, 0.03959683250756033, 0.06415347831564085, 0.017470897498330282, 0.06994988724228836, 0.0316672632470727, 0.10204352438449861, 0.09212687626601228, 0.02277308778326598, 0.052559434721666964, 0.009158426001968404, 0.04714004064519559, 0.032325466839416374, 0.013669330773184137, 0.029946566566885, 0.0848727054413288, 0.0357618538152066, 0.018190784575117212, 0.03377834109649543, 0.05582868429501692, 0.045502619637597, 0.03501414434022961, 0.02516275925201274, 0.018238691883462093, 0.024489831449764392, 0.01477031211834401, 0.047043233944643895, 0.03644593968807209, 0.0654437197672744, 0.019658580309741443, 0.002650434631035633, 0.0636746465498882, 0.004718099953606725, 0.017024268238474766, 0.021669042086408987, 0.006794056980945771, 0.02651568010239111, 0.03339350065817276, 0.010991765377712587, 0.04841397591536084, 0.041562487716756524, 0.02277920691056117, 0.05855251757067539, 0.03438176557181343, 0.016323960453812635, 0.0734679774952031, 0.06327552240221732, 0.049415620554599075, 0.04148506304068912, 0.05146754492494849, 0.020304302414578777, 0.008387442775851777, 0.018683126301414544, 0.022812642818016392, 0.017353502184813543, 0.016565959968213594, 0.02944843896153954, 0.042337726561292525, 0.01838672688351043, 0.028867508742898226, 0.030754827631397114, 0.08144982459564364, 0.01790215137354549, 0.039191097021102905, 0.10599826177161549, 0.025343038892794042, 0.02991004140987512, 0.068813702241788, 0.027766655717465668, 0.03859301983949639, 0.04106022132140014, 0.0367806549935091, 0.03495510194390532, 0.007923499928907523, 0.011351631349703718, 0.09667763005821936, 0.06380328803413338, 0.06895070174528707, 0.046725767108822064, 0.03877952394466247, 0.05059449580467997, 0.024943068217966827, 0.009945912677193842, 0.02965378882964292, 0.04240092498460605, 0.05485801642099696, 0.024961502208644827, 0.03920241980062377, 0.009247076738956235, 0.06378859446774568, 0.03959546887105511, 0.06493667681371013, 0.055764620192348964, 0.012846692153553088, 0.047193436973517945, 0.023965844546534845, 0.027584434043796315, 0.049111498970418214, 0.040645484301832416, 0.0445063874095438, 0.05172397370540327, 0.01341169827707833, 0.05791566867922103, 0.06617341851515156, 0.01908661906547364, 0.00923484135719557, 0.0199633817969551, 0.008215509663005511, 0.022346265726692738, 0.0424334722300691, 0.03298761961500972, 0.026097141371499148, 0.03680312052188862, 0.0439790086520295, 0.0801654552079497, 0.017624155302802404, 0.04663575943859835, 0.07578876425301836, 0.07347513275641589, 0.07674589918385591, 0.1008464124113802, 0.07909282486164763, 0.0019491085479403998, 0.09807956329877339, 0.02402813515565809, 0.022377478063947732, 0.055593675332925016, 0.03759359302479894, 0.009603746209083306, 0.030556315098017938, 0.03235760039740032, 0.05092801218251548, 0.03790503840953593, 0.021571800630960255, 0.05026166124509708, 0.05253881163474533, 0.014725959457967792, 0.0258420072796364, 0.010759011586947788, 0.03859763551924018, 0.06716779297998837, 0.13590842575555848, 0.053235055322969155, 0.025628220868266882, 0.029495641468994083, 0.03530098298083871, 0.012448895253211021, 0.11092857382590733, 0.03852488397951088, 0.019763499881411274, 0.01764329984003017, 0.11537657990570992, 0.03506263770583657, 0.02843585650196239, 0.01569207868493733, 0.022121930284605875, 0.07259735687365455, 0.09235461888414237, 0.11107970765160938, 0.05277838265042632, 0.06440325745291288, 0.013712000912956655, 0.04636936002380906, 0.029288263383111166, 0.027059409091429367, 0.07188727763751823, 0.04151058909032614, 0.020050844140050393, 0.07408457868281873, 0.025888920588899526, 0.04291705757139191, 0.048363548177745075, 0.024278410334861087, 0.016855636964582147, 0.021677141550988443, 0.06717625059067242, 0.03925886132844514, 0.03155353174905383, 0.03722312056549615, 0.056645322530981035, 0.07211259175692836, 0.02938611004802008, 0.029975698975425576, 0.022673109478707758, 0.03097192928825896, 0.009348633184638477, 0.024922625161707405, 0.050787821922811775, 0.0185130049865092, 0.056924052130911625, 0.024047272032006614, 0.06253592579835845, 0.0679624023576898, 0.06576465698139322, 0.0794282334766561, 0.06960324777830994, 0.030535925667913213, 0.04297105910917444, 0.027059834270227342, 0.04277096843467124, 0.041500729538740656, 0.016106653868431048, 0.07492155272273288, 0.03815573302187747, 0.011484004639750047, 0.09399855163909736, 0.0421639931418242, 0.029590783843530283, 0.03929849871764741, 0.041108925361186266, 0.05595504666768736, 0.06854588556433878, 0.0507024031192545, 0.038665530061529535, 0.015252889096436482, 0.046299155726427996, 0.015399417776103704, 0.036862806432069316, 0.02259814011443767, 0.027267246830066847, 0.039703188494088194, 0.022495989950614113, 0.01416291834996833, 0.03340760433685876, 0.01564181565622529, 0.03538676567616002, 0.017737783378951492, 0.013511551134738953, 0.03719118619037252, 0.01252492469164633, 0.04487492932727741, 0.05286928281308182, 0.050598180687595765, 0.03069655706865653, 0.018758511268383554, 0.026327687871432113, 0.05084478822086127, 0.019319032904722037, 0.03648523999858768, 0.019120089446885452, 0.026167598477895224, 0.028540613279948314, 0.06660762182887524, 0.023623163841905135, 0.0638549453428676, 0.07526197921364539, 0.0342725329251299, 0.04086766129119262, 0.023125978524706537, 0.006581468060762892, 0.020418307789030577, 0.043773884779863784, 0.005807431016658103, 0.07029107982112516, 0.1522549340922025, 0.02203364056655236, 0.040547252677741556, 0.016541887570412892, 0.023778388577122844, 0.06350741721689701, 0.053686821202356974, 0.06083512250634451, 0.027287749258140405, 0.06053082089150145, 0.06867962153328043, 0.05747501107473528, 0.06041992966446185, 0.016096635353601268, 0.015611780221543968, 0.03558453893469226, 0.06359408857421049, 0.06233758946520187, 0.018716002964685043, 0.09878784222828765, 0.009154335092452746, 0.03450296451187423, 0.04599445191542468, 0.035188674491139195, 0.043376859713105426, 0.042960927596375834, 0.07336966543188018, 0.006146284154496126, 0.07310050810056348, 0.11063212844272775, 0.04413559319331281, 0.053298690416399515, 0.0443036460708226, 0.07480773503982252, 0.05075827008113266, 0.06227789972458155, 0.0235953989003094, 0.017317398376162016, 0.06207216681251603, 0.05806014137042146, 0.03623374482436526, 0.05436602326470518, 0.06077137633016514, 0.057798614274830594, 0.06315256912080992, 0.019816233543679118, 0.01867331271510451, 0.056485922616576, 0.08100819022905442, 0.04087282855424189, 0.03719496683427884, 0.05045604456456439, 0.02457337525312699, 0.022021990284443866, 0.024952378101466645, 0.01132821491468818, 0.08719536911455855, 0.04006500799028624, 0.016065056251752523, 0.02410859928556508, 0.04488218034948072, 0.024081226964030537, 0.021760593423800125, 0.0602505591157223, 0.0466654951413793, 0.04570203998516645, 0.09396803069619403, 0.031225471832459013, 0.021702449265567046, 0.020821045956484253, 0.029660139698535207, 0.035784801978978424, 0.03487256746138296, 0.07792469399470477, 0.014976280602446247, 0.04325398304049046, 0.06860653674530406, 0.009323803317402641, 0.015792293519142176, 0.13949857423863105, 0.03151201935965688, 0.058292649055440585, 0.032546732184146686, 0.06543932242258903, 0.12081002786515221, 0.09318695043123539, 0.03954430568903204, 0.035318951573102705, 0.04291842503833675, 0.05457002864850145, 0.07312524507963851, 0.04832395675381826, 0.17919806252804496, 0.17151812301768413, 0.15112881548702717, 0.16945786744115815, 0.1642848127671788, 0.1549279987211189, 0.13606539717124355, 0.1397262555697272, 0.17760374162706638, 0.2061359968877608, 0.19051184817667932, 0.10787245757397144, 0.1400356631605856, 0.15391958186463003, 0.144328176374397, 0.16308810682066027, 0.1332444009641486, 0.2681858092546463, 0.147461062297225, 0.14011000433275778, 0.09399847503030494, 0.14272294638137664, 0.13001638224288342, 0.14950388171259435, 0.14174710358342818, 0.15062840685488718, 0.14063270612349435, 0.12669563623926333, 0.11099104063525317, 0.15252412206703617, 0.20919118617330829, 0.09610337055017872, 0.06736446307190964, 0.08644777455277021, 0.10035928008296799, 0.1532074265302189, 0.15789487339075536, 0.14754776812849507, 0.19936180313027677, 0.16030261112797647, 0.13220273589174594, 0.17650213783546803, 0.1156233981131546, 0.10570305745087324, 0.1605606601843911, 0.10041066926092872, 0.10697991917690924, 0.15744501123985938, 0.12319374108506788, 0.16141023637065965, 0.06964057158198088, 0.1399370676447307, 0.15932808600125775, 0.12468547515210607, 0.12038177705460018, 0.10889176820074359, 0.100758534465586, 0.06694791808484063, 0.1424213835308629, 0.10565576684330741, 0.1819307134757119, 0.11508404923182343, 0.23195381877162766, 0.11008024636295535, 0.09430592143607718, 0.17661073845961403, 0.12225005865818071, 0.15482042465479146, 0.14312474417590326, 0.1573768294145984, 0.21283445519305047, 0.18406570859013066, 0.19553044420336524, 0.177642475032518, 0.21516281089955763, 0.13025780719134117, 0.16818965484778728, 0.11619964944979838, 0.10953720493782913, 0.12525748236164932, 0.11662644469329428, 0.19951004114362503, 0.24955910149841543, 0.17138816386220918, 0.23521533085694238, 0.11772772672796443, 0.2263540378020656, 0.0965922495590583, 0.19029699115743562, 0.12575133328115748, 0.13870312982509214, 0.1999241423102156, 0.08812282579920946, 0.17884452827274802, 0.1185071675647651, 0.14362754300236702, 0.08511105837721018, 0.17265512007138423, 0.10059955589953931, 0.11638983843788026, 0.1254579982149505, 0.11791213175221799, 0.08659812696878949, 0.18212352248449482, 0.1664495780583351, 0.12341697144532397, 0.15691458728284607, 0.13561155136314132, 0.14185640900846452, 0.12447857778639564, 0.14641132265810045, 0.13565229191895456, 0.10982969730731942, 0.13434750628807854, 0.15275534272434252, 0.12516989552926633, 0.10633946201133151, 0.14738256892850324, 0.08287991156741496, 0.17873814930358242, 0.12216424148890281, 0.13703567817086174, 0.18958756309603492, 0.1952024819629808, 0.21605073744731568, 0.13499100482271564, 0.17609600398328998, 0.2720884450020329, 0.20387778419160074, 0.15078174701381117, 0.10893762622389103, 0.2282645538329117, 0.2041740457136785, 0.14035309935289045, 0.13829180189678747, 0.16185092078822275, 0.213849077361726, 0.10612386954768051, 0.1968241215593392, 0.15317839179788867, 0.18570771080351647, 0.1816160045564175, 0.13544497320488577, 0.12416917785641648, 0.1018360064875695, 0.14250114860553897, 0.2578386273835936, 0.2584869829156707, 0.11186322407616724, 0.09830342185112739, 0.1439750864500961, 0.10360464303483886, 0.12317329419836884, 0.16247206487722937, 0.16737443004404345, 0.14618433080613613, 0.19884625660075297, 0.13443364521428464, 0.09746005097704549, 0.19493634301808574, 0.18915622495114806, 0.16207726912633066, 0.1740971886582913, 0.33720202683921785, 0.20040311580223424, 0.13795219511995394, 0.15945689602484628, 0.15730518487191972, 0.23062238860274517, 0.21468996611093322, 0.1647871366191295, 0.19992970410854588, 0.23805993789386368, 0.18952376329370085, 0.12804688510274695, 0.2024162263279], [0.02658243891933272, 0.06399700485710656, 0.0499219395550749, 0.00413413985722488, 0.02762044975233655, 0.02317006496952907, 0.034129944810223196, 0.00901101632118826, 0.017039229935635964, 0.060952625072170655, 0.03364492305404237, 0.05376401988248672, 0.052625505974696535, 0.03349576190474533, 0.02044708396668636, 0.04750855958029147, 0.030317031365308552, 0.03869256530437739, 0.014044616179871223, 0.046572338849786794, 0.09541191491148165, 0.023373970761895183, 0.04618956301842005, 0.008721123862591003, 0.025609300411756963, 0.11924883260601953, 0.0391209731629539, 0.03204251992546263, 0.0496092914122968, 0.01206974493294594, 0.05258334049534413, 0.0405268402649991, 0.050764931215634274, 0.05264628227920302, 0.08798422517194864, 0.07444334531863851, 0.03200776251633802, 0.07935222989368824, 0.03993515991756032, 0.05046682725209863, 0.07659190785019629, 0.007129768679489292, 0.055252823663214524, 0.020671337054321365, 0.0381388790875433, 0.05766174117583902, 0.0191094312486389, 0.03816687960117575, 0.05850858625865752, 0.034146247161251884, 0.11037631636305202, 0.07951880805194378, 0.023115866164106037, 0.0641487630444669, 0.02109262029520206, 0.05940396301147919, 0.043531100025340434, 0.06558386023126303, 0.02696272879538517, 0.07054712938805742, 0.08517074428739087, 0.05252575749651559, 0.055105190859326435, 0.010583699068745539, 0.020654123058662783, 0.021884019764500762, 0.028232707221421505, 0.04580932293808268, 0.02218911044990584, 0.014231859559884236, 0.010785692514130666, 0.019990246585239808, 0.017239914328280478, 0.021586957680542144, 0.049240519668185906, 0.03545426185272875, 0.05861419530945921, 0.054509718376662464, 0.0223171946051861, 0.05114202650504247, 0.0030003436146334057, 0.0677084748543078, 0.06116193178440295, 0.05195073956142991, 0.03868472056403276, 0.018241403834714044, 0.024321043127847296, 0.06118465012179748, 0.02578685852518726, 0.049847234491138696, 0.009736226751439033, 0.016974420812461647, 0.05323500169681446, 0.041006342357685494, 0.034439187692177874, 0.021870666851980552, 0.007930149093285323, 0.050327357115043755, 0.04763234406709672, 0.04141525327858906, 0.04248416043757912, 0.06376530922528717, 0.028512051606911327, 0.010909491365084486, 0.0411808073911215, 0.047693623440159906, 0.030179644987407713, 0.03751701870632749, 0.06367759215795706, 0.018765088133213502, 0.022093853162180994, 0.045060069795938275, 0.024562002677891045, 0.04448560344415807, 0.03382215366488503, 0.044553536290843646, 0.014296642827591109, 0.060127268755628224, 0.04247575262261014, 0.06399665245666139, 0.048159757298567606, 0.07366344482908327, 0.04097620828918392, 0.04189536058073563, 0.03614305916632857, 0.038954950418443456, 0.05054961071319638, 0.021293714544886065, 0.06318074966510458, 0.016015597615360973, 0.07581055945446415, 0.04433457687076542, 0.03990237518484074, 0.029716987252956437, 0.04064433900038562, 0.02055433627608563, 0.030743688712978078, 0.056216091127885934, 0.024994292687023842, 0.022695098117354418, 0.05972888771324389, 0.03584094090206969, 0.005015061488525281, 0.009728318808840649, 0.010476395048411384, 0.035591395421614574, 0.04046275317969342, 0.0553751296003259, 0.030343817629581018, 0.029330543775652206, 0.00496812567542938, 0.011090751598408867, 0.056555667261202494, 0.04678247293697731, 0.018384231352097085, 0.1270798829594447, 0.005309059220786777, 0.014245286208367156, 0.08922367116376277, 0.04883426324193997, 0.04566566230008199, 0.012313394409213817, 0.08833673286942706, 0.019857650172085534, 0.013441369819995618, 0.04694438561977399, 0.03470001381731803, 0.04582041972166589, 0.023551004105097344, 0.0565356953490165, 0.04356501856818796, 0.027291102808028943, 0.061460732887949676, 0.051442873063347036, 0.029289736187145598, 0.02325671525942462, 0.052681380597453926, 0.03492199928469716, 0.05256483564153314, 0.07241310506698585, 0.0409534746300309, 0.03805909869110873, 0.01802239461892074, 0.010620341054163875, 0.0489627706607984, 0.0684561153813716, 0.058590829627768654, 0.02030427560150143, 0.05102746188640595, 0.029858836093016212, 0.023747739314492193, 0.07137923110877314, 0.05908822753436624, 0.039265851880754196, 0.028591339791854544, 0.012295210354721114, 0.058946876651457245, 0.03222599032244856, 0.06793452441812524, 0.02964688063178572, 0.036988751286821026, 0.060719251707797094, 0.07253533439530481, 0.07725055194309643, 0.07336503059993829, 0.017019213973394325, 0.056543118741002776, 0.03396598667266869, 0.058849629450349085, 0.03376675784708031, 0.10191852181789376, 0.060993675893593224, 0.009524254053230248, 0.10094506921426905, 0.04278878380935039, 0.030557644260566563, 0.08017284795641899, 0.05114834289997817, 0.06489730755528135, 0.01401016520591633, 0.040555005487535274, 0.09214044368315129, 0.04643900890744502, 0.05162610980351606, 0.115029672310958, 0.06139056306452521, 0.011405878035622019, 0.07385696629963576, 0.09493409055134944, 0.06539390873043768, 0.025563993971915017, 0.059205098077654846, 0.03806844879422457, 0.061702349358388496, 0.08975007315917362, 0.044362642501871434, 0.07086313299594388, 0.028482275684514356, 0.013148341188958336, 0.014605379133905857, 0.05389191443100572, 0.14249506586742017, 0.03898562840937127, 0.09877363129729226, 0.035700229702577475, 0.040812280795146386, 0.06935034683274646, 0.028349820997626073, 0.004730462697484801, 0.03194384397037568, 0.019730040991318323, 0.041624992830498565, 0.03920469891219851, 0.046425196342170245, 0.042694141307184776, 0.030229534548256668, 0.038873442493739634, 0.041259741260399746, 0.04956617598391829, 0.04491961906634031, 0.04864859417261136, 0.015282145994264754, 0.04723962441447282, 0.07610419329496161, 0.034606041642086166, 0.021368285543435526, 0.02638435156475152, 0.03566673633852794, 0.049212116958393205, 0.02608077964865633, 0.045656319857845386, 0.03187375841662288, 0.035219624443280126, 0.05727630318893541, 0.041186154684832985, 0.013535798775152335, 0.04438878908272713, 0.08384666856258147, 0.042547381843530366, 0.03152448361018493, 0.041729950706564614, 0.04695457075872729, 0.019829869908731312, 0.014644425677796526, 0.06514092351520254, 0.05402566572170585, 0.030841276823212544, 0.13306686774857585, 0.020676538791327227, 0.0809220283202106, 0.02342403652296672, 0.013122892705723645, 0.011755682400337631, 0.09249760153433008, 0.07384297753413839, 0.020546594957610773, 0.020094449864700437, 0.03041041556805853, 0.01839241700156802, 0.02930020286341108, 0.051875387153197686, 0.015447431379148077, 0.0571373118568332, 0.03549044035495289, 0.03326912628366582, 0.034756336601511124, 0.02666087674667999, 0.049205275793229385, 0.025574836031263395, 0.017767796788604993, 0.015631585509606426, 0.02166337495098912, 0.05737129809154619, 0.05807988345623017, 0.02404572836483919, 0.04077660025007302, 0.0518093312219266, 0.019735240813104377, 0.01821216417386407, 0.011766548399933645, 0.029168703871208335, 0.02783243585708401, 0.02815840052320592, 0.0389150295767092, 0.012252971139406005, 0.03450493335783963, 0.0220984535201663, 0.03453750741638003, 0.03689145428999778, 0.06503446793724453, 0.020865482886532144, 0.030587718957254005, 0.03910903751309361, 0.015654199467521283, 0.11539020860988287, 0.007829262495731876, 0.023281632269161846, 0.052583263886551705, 0.0282890108534165, 0.030614842300213156, 0.04064459180940063, 0.03197888100159264, 0.06448756542897995, 0.017926141416894335, 0.033690865346861464, 0.048292715688266104, 0.025707591407661958, 0.04274127103628651, 0.014552912644801602, 0.06991355169203974, 0.02590753269501992, 0.018909011156328263, 0.20559535331783757, 0.2038756085018958, 0.1326155653523822, 0.18110176037636497, 0.2755154014354752, 0.10658336142378469, 0.13064641295181167, 0.148240449507871, 0.14078808407629692, 0.1780589970369493, 0.17369136124128298, 0.10680988596211519, 0.20235302407414685, 0.1970856026896546, 0.07990985763289275, 0.28197916104428233, 0.28298794562297486, 0.10986279996652758, 0.13291153576104872, 0.1262476969690573, 0.1791918725376168, 0.09771458368988768, 0.19505173118124086, 0.1072923451541893, 0.10660591505227551, 0.28725784392126147, 0.09992805685126975, 0.15473436233737778, 0.21759489491101236, 0.12190447639553778, 0.12660303919185556, 0.1268979064339111, 0.141260729682061, 0.10543918612623408, 0.1907731301241344, 0.1628623407093748, 0.1349812601843188, 0.17822335354022442, 0.14279578602121723, 0.17279980343676385, 0.16904793379287567, 0.15172985742890066, 0.12959226064624327, 0.11493191183094056, 0.10684712549611446, 0.14133044368317052, 0.12765969660493637, 0.196698697644376, 0.2055499702692032, 0.12954949761830992, 0.28753663863866563, 0.20418706920839128, 0.17280236217043093, 0.2082686018078558, 0.13112034558528854, 0.22086733141012732, 0.1749069282724973, 0.11671498147470337, 0.16980200945850343, 0.26509142691089266, 0.17477145328396754, 0.13606335937736497, 0.11573091089244812, 0.07802533496531748, 0.15429640519282511, 0.2051431622596518, 0.13565984554588795, 0.21616349026801127, 0.11951406756716391, 0.1452167770795284, 0.1997798573105566, 0.11796896015444111, 0.18212871656062143, 0.1274471914756202, 0.15570144108947248, 0.10086764836864126, 0.10265873129209203, 0.08545506249872908, 0.13576686802890994, 0.23939003506975792, 0.06364124128594995, 0.20813444449055582, 0.16588872508896937, 0.14052025973796844, 0.09815221141663291, 0.1426268636339134, 0.09931805934156142, 0.12993179081428435, 0.11789543103546866, 0.18636574968695643, 0.09387741015563089, 0.14596470872000342, 0.1863325321145596, 0.09879681311788098, 0.17088496667002478, 0.09909503582504489, 0.18109105046718352, 0.13277938559411034, 0.11550387307520836, 0.135838144849385, 0.2736796709077974, 0.2439181509638025, 0.11170157186326482, 0.20876888786592793, 0.11656577052969126, 0.18950212897071916, 0.10446375701576473, 0.08598397726253157, 0.1615858543664217, 0.12473425963112425, 0.12309015833682592, 0.19300934077510912, 0.10835100971763173, 0.18532402332751982, 0.08273074658767832, 0.14020095429112836, 0.08501433977676977, 0.19554728281594094, 0.13849786422666044, 0.15038336597142682, 0.06389244917720076, 0.14013375305841047, 0.12120809481148759, 0.16898814829126482, 0.13973282860411754, 0.1225828932177636, 0.13524695479821774, 0.17426911411025833, 0.15233056229208747, 0.08618966420932163, 0.1762032103274138, 0.1356531959027052, 0.10513231428640504, 0.18544711833519323, 0.06387571781693448, 0.13776641879831591, 0.14225148055101597, 0.1585046947002411, 0.12862260783872298, 0.11450761403407782, 0.14454563809258325, 0.1465013379892034, 0.0976344432321287, 0.22738753637719542, 0.15379815692863158, 0.11872360272513283, 0.13917802772935361, 0.09859260472078478, 0.12657847841300313, 0.08074494709651317, 0.13960950377006687, 0.05238038082156451, 0.08601558605028738, 0.15681562404478752, 0.07561565136476871, 0.178544313736981, 0.07247431549213587, 0.1720814887554415, 0.25020961739843894, 0.10641746508378176, 0.19980527610788423, 0.11894597506691372, 0.15984743232688597, 0.08342448516838974, 0.12451069985306072, 0.1567992297632079, 0.1580422840291454, 0.09732561786809275, 0.19623743610516672, 0.11232442432834257, 0.19124773691498465, 0.11534788225206638, 0.1859834411692235, 0.07990676263767867, 0.15607284051516365, 0.13101153045652375], [0.051616564347979524, 0.09184096459179156, 0.0374700766687672, 0.05695050897737665, 0.05040008567213532, 0.04655153190176334, 0.03256975312627131, 0.01365935343558029, 0.036498313289015524, 0.029683348332201282, 0.022099414960511272, 0.0920559365242239, 0.03678087332856752, 0.04580768350992472, 0.019383351731624816, 0.010796041404377791, 0.027461243275132392, 0.06674679702207928, 0.022515653512410583, 0.002517365876795544, 0.061628747461063255, 0.031125694625980915, 0.035593486841647856, 0.02719653691465576, 0.02219394829514767, 0.03616299660455796, 0.024458239898986878, 0.02667199076724149, 0.02602550065926006, 0.012626126821663593, 0.08043233725813129, 0.016028863385379795, 0.028583043059634588, 0.042118322810218226, 0.026189897382151217, 0.03784451363307815, 0.02135374136419306, 0.03218398572156026, 0.0820433282323422, 0.039341139171512864, 0.058807486953634414, 0.02585482010016999, 0.020618934725080768, 0.014428550719223438, 0.023429571508219647, 0.046715417260965036, 0.0535095714393162, 0.01979681896045804, 0.04320674988951895, 0.054292861867936394, 0.029194295038318926, 0.033930512971334884, 0.06260147611159952, 0.026618146277483434, 0.025984189367943236, 0.008155852481121979, 0.014546645087971082, 0.04807400141632365, 0.035062055479014115, 0.0240240921266377, 0.042491005433182565, 0.019766728942012115, 0.07999601188085734, 0.08307425275204644, 0.021765894752236146, 0.05390532863055987, 0.12255660874108154, 0.032455862665008155, 0.016027953655969714, 0.08278707703275066, 0.029052473011336503, 0.02039845653569266, 0.04416678063271027, 0.054495630019734946, 0.008846001939908152, 0.07502490564459756, 0.04724680648876294, 0.04238698984526339, 0.013783641625195743, 0.06630518563812779, 0.03640793406614854, 0.028372845770190322, 0.03897976017587128, 0.02542268713906167, 0.02477206398672875, 0.012049276978828976, 0.045011626226046396, 0.024995773151937514, 0.014511542939280551, 0.02412275467518597, 0.08340958475826249, 0.06974762470851983, 0.03997001691811508, 0.029301194947273023, 0.06645294867696301, 0.03130882411384054, 0.032601120596330975, 0.018543608283864397, 0.09030102061167841, 0.023374909219602426, 0.05107226653865749, 0.030967625789344314, 0.015294829537461122, 0.06079846902960732, 0.03138511497978001, 0.03584999606133469, 0.009782031148431763, 0.011130943443746337, 0.10659397174153598, 0.017781655319155227, 0.10014914216533785, 0.019613905892437025, 0.031154355890448057, 0.02794449919864776, 0.05091977290688984, 0.025881535501309463, 0.05417710598257761, 0.09456286732588084, 0.05321393427889674, 0.039636328170496615, 0.052340306762245395, 0.03002449877620224, 0.042581618312866464, 0.01861340655464559, 0.057080123393285664, 0.04553876366586455, 0.05908870250887929, 0.06769912858163157, 0.05774006600521746, 0.030434016821785804, 0.05129880256830685, 0.025381948498468247, 0.03585889800301483, 0.0357746321617836, 0.07575543176743292, 0.07243300803125867, 0.05779102617394059, 0.010836969651732474, 0.04059750421513473, 0.04830832856016294, 0.04487193392349347, 0.04832348560974483, 0.037269537832828305, 0.05176624643706507, 0.01446616946674523, 0.04047978331425017, 0.04673252783475384, 0.022410394946834254, 0.07971012318927435, 0.0018499968803465188, 0.04311061734634061, 0.00882533767576059, 0.03953164991652293, 0.07747510763546152, 0.020479422453190052, 0.05003145948473004, 0.06179370917379857, 0.06179355978665333, 0.034646445119212714, 0.03315690206363797, 0.00962427161979459, 0.028399501799515663, 0.029021722242055886, 0.02137507308244465, 0.06037275397008466, 0.015182725018671444, 0.06568820906742927, 0.030039502608199275, 0.03443682431093147, 0.024098536720679655, 0.02700697420345199, 0.04536453995012468, 0.035890288455712224, 0.02605341690322084, 0.03629883165441213, 0.03888663452779574, 0.0486383822205807, 0.04643184981579262, 0.04869423386070037, 0.04736287263973106, 0.025668653073690595, 0.05914406385272742, 0.0452894288595886, 0.019905997980986873, 0.04364271520546848, 0.020319126215913606, 0.0766587183780728, 0.06665619946415387, 0.0035410704966183874, 0.012253636678290224, 0.04269482312543739, 0.04015498501699298, 0.031884954791636236, 0.10202650957170034, 0.016148654638879722, 0.05577899200180846, 0.10475315439004092, 0.021989462191178914, 0.028009287254404158, 0.06882383758502622, 0.009914707043208182, 0.06751991763350464, 0.02030310923263671, 0.021099149279536742, 0.029368287012461695, 0.08439612980451315, 0.07153002019490927, 0.05985324293555272, 0.04136241619445143, 0.04953848190545555, 0.00902057709848328, 0.02076662115512356, 0.03175354198432498, 0.048747603375945366, 0.019185729775457613, 0.08047541438211357, 0.025294999434282223, 0.015484419061742244, 0.04197974133515551, 0.025769062302706223, 0.05484220819667943, 0.047220338150979056, 0.012624550595759385, 0.05491207158493419, 0.049188188202078306, 0.05137936437442418, 0.05739368318069366, 0.026394310707767165, 0.016937594965941483, 0.0319139780326476, 0.01892566399258231, 0.014963990636920978, 0.06034817786947374, 0.029645268016705112, 0.0843726032443585, 0.024256856451111457, 0.04308150600521796, 0.04480302431470445, 0.054599737538205045, 0.02861063946188698, 0.0538210015022947, 0.04708627276422997, 0.026945916995886835, 0.004464358226546357, 0.028033802067981135, 0.029396959768247702, 0.039036500477983106, 0.03229270891977414, 0.038259208517810034, 0.034665735213146094, 0.014746296219527723, 0.04540004046453584, 0.06305256400317436, 0.04627879310940062, 0.054006122818757454, 0.010207647574134171, 0.08550804513957232, 0.048331564006906365, 0.046754192801252495, 0.011729723511023388, 0.00945759961576832, 0.005399670185250861, 0.05353554948082855, 0.06043500627481169, 0.05342442842741167, 0.028702637045494014, 0.07403876662494675, 0.016133802109247735, 0.0833667604432952, 0.030937045474626848, 0.08011081015631076, 0.04857296597272639, 0.059905003666156725, 0.05089772872686867, 0.03727547501424148, 0.04992916759464049, 0.0357556791465369, 0.0633125474315978, 0.00971317420818753, 0.04649707071122624, 0.020498446331569747, 0.010161641121451414, 0.010158045296256822, 0.01988432535360898, 0.041469672334290324, 0.021991731726654598, 0.05565027773921048, 0.022906274084121953, 0.033772223884420055, 0.005339940703819476, 0.03341872410307969, 0.03832729841252008, 0.016304589920647202, 0.023954669238939404, 0.024974165642033183, 0.031019300335056843, 0.015643959744803367, 0.02337087576668109, 0.07800715569887431, 0.029037312131314993, 0.0303291202327537, 0.058092401332912914, 0.03652230333236437, 0.046323735657478535, 0.028293398622002815, 0.05733426923172609, 0.05243948450492275, 0.02869563883230571, 0.048001939355726206, 0.043569193747375286, 0.04882948668373208, 0.03306818142112705, 0.04409786719348162, 0.08000944140216998, 0.031091469647963683, 0.01452081356077425, 0.030377866407375664, 0.08614469484816636, 0.035596758037084536, 0.017551836602750327, 0.017752421403964682, 0.0169383495625469, 0.028216847286169088, 0.0461462598985001, 0.049856879538105386, 0.07069277802422162, 0.05236297913436448, 0.02780104923482624, 0.0586293523590411, 0.10417956903937364, 0.04153684292349123, 0.06989371001480088, 0.021730020769961902, 0.05231154016068867, 0.06041993349490147, 0.015291843709776239, 0.06808904435245261, 0.04366296673974684, 0.044092780369664394, 0.0009183874006398143, 0.06831790545895215, 0.019914942057502848, 0.04722413411664386, 0.029715177370235327, 0.019900587485021642, 0.09130635779471168, 0.03642868738801729, 0.02774821981156786, 0.053223881930593527, 0.02985328770122461, 0.050951630673221046, 0.030014097217410326, 0.179352413923029, 0.13920333927437184, 0.1478384065652086, 0.1414225427734275, 0.10911014922443898, 0.16726990500765462, 0.1195653954580907, 0.16457784139821607, 0.22930926793525297, 0.13837836983223117, 0.14239408015724153, 0.20590638501509545, 0.11286564246420899, 0.12536624386425943, 0.09871396836974929, 0.16286540506107194, 0.16910479283861576, 0.12200884821434176, 0.1273740224179722, 0.12406744904095128, 0.20373588938626552, 0.07108188940272217, 0.10509634645836008, 0.07233020669269948, 0.1600650166191401, 0.11427594138489616, 0.09576891188419635, 0.15046477047426088, 0.11615844924123057, 0.16191159495182578, 0.2245013460877442, 0.16404372489740773, 0.1361948200651715, 0.1677318100607203, 0.12945438014163127, 0.1645186074799107, 0.06374186310436457, 0.18657418688939464, 0.15965005743407434, 0.1730056665837765, 0.13484393126301228, 0.10373031209793784, 0.16324651848164298, 0.1138372871003324, 0.1584535047051407, 0.18478154114657835, 0.18361256758291877, 0.1867247844535497, 0.16161095140682114, 0.15217094021218439, 0.23543958011413776, 0.08627520558694679, 0.17564266379321777, 0.08434382898192253, 0.10123664993912944, 0.12264542131414338, 0.12009326068143691, 0.1801347735548212, 0.1883084260888638, 0.11774720834387888, 0.1650681223479971, 0.1616940413030886, 0.16688618688814102, 0.15448896905347226, 0.153375000602776, 0.19804391739589555, 0.17803103482771307, 0.05233456876369254, 0.14793228297944994, 0.25438787625922316, 0.21744022175910013, 0.1944986616651858, 0.18588818579671845, 0.1539248219060321, 0.12373307464464058, 0.14556986700382926, 0.09963028613598117, 0.08874559399461554, 0.1108270901585779, 0.1076335377330261, 0.18230174517919942, 0.13018407888950842, 0.11523045629503266, 0.17906399714129587, 0.06703968009641094, 0.11602174851202196, 0.1344498862782794, 0.1392126395817726, 0.18732139840722087, 0.17680181610968806, 0.19308051034327478, 0.1308960503628177, 0.1294753249854811, 0.10000031426428788, 0.19996869798389175, 0.14187116386188617, 0.14637370774101827, 0.08980428154069571, 0.10626466118640478, 0.13658241458958195, 0.15660717152059078, 0.24848820251082224, 0.11402772889742929, 0.1351882418197009, 0.09108780823167294, 0.14168004024653666, 0.06818781606853008, 0.17095005350007167, 0.1888258725164398, 0.06830981557047175, 0.20409573620605856, 0.08780787173177927, 0.10339620583240064, 0.14939946392851491, 0.11838234885926209, 0.09681122047045539, 0.11818551788887671, 0.16084279504514512, 0.11884898067482057, 0.1337764490275614, 0.1453235390926561, 0.07455364665797642, 0.18954400333666033, 0.13118486551027145, 0.15423925503367378, 0.19364971367101516, 0.19837100629604634, 0.10201964542389878, 0.11354531567063063, 0.1340982059557592, 0.19827314622459874, 0.10647538133085736, 0.15485594049096107, 0.13995045886164711, 0.16296430701209655, 0.18949235368880535, 0.12572261264487622, 0.1195252141464622, 0.1219655259422237, 0.13642610200951177, 0.14964729337201965, 0.21986320464601442, 0.09747883545294886, 0.1367301316631417, 0.1736026329378928, 0.08880220023134063, 0.09144706516376427, 0.12620663465631585, 0.13031667338744288, 0.15024766115651977, 0.08334663531352436, 0.08462818549765695, 0.1358101519966318, 0.20039887167513373, 0.14306575540573369, 0.12043603140139773, 0.13694193965244678, 0.13832835961253415, 0.12617504119031853, 0.1831547840828857, 0.15620500600386053, 0.08045515135651635, 0.1780413463711739, 0.12191001521123034, 0.1503982893641918, 0.09665687673635061, 0.15794054755280096, 0.10030851909710516, 0.14149579610074722, 0.26171573708134316, 0.12813508480546937, 0.11050531790862161, 0.19071829355051442, 0.07324966541942089, 0.2259655086503875, 0.09181468777598874], [0.026239478592610648, 0.03263664026294024, 0.04973837339709844, 0.0572397378123095, 0.014590743981722384, 0.08046385411533617, 0.011496502406624778, 0.02946930145093751, 0.009898033139536218, 0.023392037030369527, 0.021017905655166796, 0.05235070640581751, 0.02068932288356366, 0.0349871703844157, 0.06801618172997428, 0.05800212936235532, 0.037437456644951336, 0.0017139427772264989, 0.024740277083530545, 0.057010470679210085, 0.027160984689309716, 0.005291537353543626, 0.03220512208739116, 0.048418901860713966, 0.009990466435650184, 0.03319973786992412, 0.05879912510394089, 0.01947428253779729, 0.0237052348412333, 0.08236313929721233, 0.015011778244027689, 0.03191597369169036, 0.046254255313185916, 0.09221871488637502, 0.05458327047827263, 0.042338025335583, 0.024796933115970705, 0.04466738461727097, 0.030468576963269905, 0.09116326023133532, 0.05141400687036015, 0.04696375615293941, 0.06601781839685095, 0.058703253030656814, 0.01573199665384187, 0.035041757979460304, 0.055401980982071934, 0.040274318532958146, 0.01988356501134413, 0.031079836602833484, 0.06890164147461615, 0.011386641567843336, 0.06820541310815081, 0.03147195679165664, 0.052171070278892596, 0.038914972120114875, 0.09976858032807227, 0.07359592183943718, 0.015981078651102803, 0.10109823317297044, 0.062565159713549, 0.08190135681821455, 0.0534535167858966, 0.029411708876009912, 0.0684918916874355, 0.04921238125872709, 0.01798526233723087, 0.05094404640277067, 0.05542230912514272, 0.0738925357619601, 0.10097526073936494, 0.07760062348097563, 0.04906200586007007, 0.0393874645082941, 0.05456013079251974, 0.030960014705816587, 0.008616021387429248, 0.045901923815930085, 0.050102793761799415, 0.09175591351043794, 0.029346915074594082, 0.03946988407762782, 0.05054393783211709, 0.05000002306675719, 0.04843160742893816, 0.057667551952744686, 0.018494877431000915, 0.06920046173036098, 0.01755471134768619, 0.037517639237546155, 0.12741329974585003, 0.07074037506695717, 0.03491392088753562, 0.013781179610129087, 0.02412722671344396, 0.02889606275505597, 0.04717124723679116, 0.04522303584963084, 0.03205464709730398, 0.0886204841757013, 0.058115529527346936, 0.06018922994694403, 0.05158090678554389, 0.025888125772678086, 0.060039965375777216, 0.02665252638830533, 0.04164619048336341, 0.0096748152282089, 0.036122608449189894, 0.01960844943119634, 0.017295687444387906, 0.06388303395661135, 0.06894751481952206, 0.04001625032434541, 0.03635169555162711, 0.03592314213634499, 0.025575071603300113, 0.03742861982074477, 0.013177542545412098, 0.037123555948417035, 0.028311702377733686, 0.050236510578542955, 0.07434481108981757, 0.03386960898135458, 0.037697585630080396, 0.05373619556907685, 0.12672241101221693, 0.03625971137455875, 0.032712831537449555, 0.011776963365264239, 0.059293979598629865, 0.05148988404882051, 0.06543323968447025, 0.07699460962847357, 0.05858618713494751, 0.051768939236118916, 0.054743903794235764, 0.06289446260780096, 0.055232943681579445, 0.01853236785879539, 0.047594828741444696, 0.1003522320740646, 0.03421940472758105, 0.011444995442645685, 0.022845096217708725, 0.0303444764651959, 0.007838872111132069, 0.029153194421181278, 0.030993992620478236, 0.03664741315127861, 0.09723537271061251, 0.0340269634410018, 0.05763707697511681, 0.04771184484143892, 0.06258808106424348, 0.023363086567710967, 0.049521107031332876, 0.0042165757059269855, 0.04794304634654715, 0.007609925777350943, 0.04821028462761352, 0.05450856541433642, 0.04355885539083712, 0.017425782580469406, 0.03693188458020168, 0.12043023211581093, 0.0020147331956503613, 0.04002663081571941, 0.058821288027590325, 0.05849920934246433, 0.08080239602995497, 0.031148365082880183, 0.04750756749642953, 0.029364937293012778, 0.04806765054743137, 0.039163414433959036, 0.04453815707576372, 0.0928938681740434, 0.06920090606135708, 0.025953601392346527, 0.026915409459522175, 0.029043553832678065, 0.038219425571902145, 0.029470655511343674, 0.08760792278354207, 0.04084774300516133, 0.0225514508858924, 0.03819930427257092, 0.006875126799117895, 0.013766448696955078, 0.041563690474797646, 0.009767390250588858, 0.012529831484801347, 0.0157658634857545, 0.08467775904723714, 0.027919708593418042, 0.0365847701417102, 0.0363505847241369, 0.015381594740545318, 0.08658707998092137, 0.04273842885008743, 0.03911277985260372, 0.027963463705213323, 0.04075660918568892, 0.05670413893136767, 0.07416852659756139, 0.03120669693265471, 0.03778407695673166, 0.04075007828613443, 0.01954076556308616, 0.0511994447949673, 0.05139822162868035, 0.06602021625205394, 0.08230364490901271, 0.08774313730217757, 0.03263862443066413, 0.06882003778892179, 0.0034232011661984993, 0.016141399786236788, 0.0492380490346301, 0.014801901753901716, 0.019900623874198047, 0.012415908464801409, 0.02218534321253819, 0.05071035128146891, 0.01942501542338681, 0.0545765174132201, 0.028146531906039007, 0.02101152222753773, 0.03379597644051237, 0.037163633838175766, 0.025859985447999452, 0.11229247080102084, 0.0850032851280224, 0.016849127132445574, 0.027930655989856012, 0.05775602361668022, 0.017262303247867573, 0.0023533521978665265, 0.04198079087561177, 0.014107444965761277, 0.07736137422222285, 0.04281211118664473, 0.03916315396406478, 0.03176154951835352, 0.05112137660504349, 0.03689538815148896, 0.02459572778353768, 0.09643469591655078, 0.03831517507111834, 0.027813415809143937, 0.037245329454421036, 0.053281342355354186, 0.048652416951353514, 0.013548017877544607, 0.08357969458184897, 0.016422234212739334, 0.08511341792801697, 0.020917785624342582, 0.05813670802801367, 0.09471845212242297, 0.06371308501148898, 0.006902350691117107, 0.057231716871742284, 0.01725262181172448, 0.05316475909503718, 0.05439405825229422, 0.0356451633025802, 0.016660305611308546, 0.04699284068098472, 0.01805764615475651, 0.08432583357658117, 0.05511530321992694, 0.044776149950320684, 0.0341448720334278, 0.042483045779649294, 0.015768906770033703, 0.04771252665969153, 0.052146072829923326, 0.014600922417406355, 0.05225903632479811, 0.029936207142928918, 0.027136768650023207, 0.039984970954397035, 0.070762645242916, 0.05789648200715742, 0.027190865948796276, 0.023311151552104184, 0.02024902534040232, 0.07387182074448756, 0.09748880991772299, 0.027342269820491635, 0.05449852583208873, 0.04273363697012106, 0.015936616823197376, 0.023660566169588317, 0.007467201681837681, 0.049319989799011144, 0.059069266858240294, 0.03212887335628752, 0.04555934078751072, 0.0687151603520878, 0.07148585522607451, 0.035843262148480264, 0.014408174695657387, 0.04275748911764353, 0.13331357870371113, 0.04979445869403501, 0.04637893995330219, 0.032351299324223114, 0.09611073265513105, 0.03199664275011709, 0.05930521427803944, 0.02823435814089833, 0.03541434484143411, 0.06023763904287931, 0.05345370064699843, 0.03866038578111799, 0.04780356854861302, 0.034419897598244494, 0.003390097788782911, 0.038794048971706824, 0.05031561298716453, 0.059313587619051825, 0.06915521657755298, 0.042358035552165205, 0.032694414783749855, 0.056654078915955565, 0.07410133302572273, 0.026586470457034248, 0.034568817429845376, 0.030717950073942065, 0.03196648378375798, 0.016278964279580022, 0.01994944474239263, 0.021922621019785444, 0.012249193368329397, 0.0522124849920792, 0.05353318993002177, 0.011228293109114372, 0.03828859948102505, 0.042171408872931235, 0.029870317835781365, 0.018554366073541103, 0.010739835448593143, 0.058711051805725986, 0.025237157880779237, 0.07070810744358648, 0.029483025916100993, 0.009151373205015497, 0.016452159522281542, 0.024706678382391413, 0.16839159562462763, 0.1329037982730135, 0.21064178897969185, 0.10779626246902252, 0.12753791926849273, 0.13728097952421636, 0.13800189890448125, 0.17309771970875804, 0.16228472573622582, 0.13269022828148258, 0.14500907532149745, 0.18267233255169085, 0.17130078387356576, 0.1352720365168587, 0.14400142455293288, 0.13559854319018705, 0.07087957324279894, 0.12392737752487584, 0.17570336860033775, 0.09742381501822703, 0.11054967439943746, 0.1452621141628873, 0.06333866336893651, 0.23839815039067502, 0.2575706804711973, 0.16521257588699942, 0.18399685260749635, 0.20082092483437833, 0.3935724923447255, 0.15362998530749353, 0.12460923408188167, 0.1206156253934868, 0.14019396756925892, 0.20469121634960177, 0.11461673559801233, 0.08768741972744466, 0.10337537590173945, 0.18297525903870984, 0.320065344773954, 0.16993540068787916, 0.17183508423547592, 0.2425189066918627, 0.12125692525578123, 0.18435691393190817, 0.1032647987707488, 0.10429867272896153, 0.09910126411986929, 0.1729160036531187, 0.23617629622740133, 0.11568693744559443, 0.2947650152829386, 0.10407043215368064, 0.13668271082062877, 0.07434989791363478, 0.22372182098127183, 0.11704207037485416, 0.32332382315108854, 0.3051535965454194, 0.1972862257952652, 0.12631633844707282, 0.1575713697820902, 0.14614181292633857, 0.135377113136553, 0.07039506859596699, 0.15915265186659752, 0.19412995886898812, 0.11397905933159976, 0.23567096931078743, 0.18182900764288443, 0.2408237686200488, 0.11668670516941818, 0.2114974479040792, 0.17497083532714075, 0.08944145463887723, 0.16110404634908324, 0.07444627177450927, 0.15013241088919102, 0.13253575431243067, 0.13518056561869962, 0.19926126175109418, 0.07306270166150025, 0.11194811427905677, 0.18513962596414552, 0.169445242312166, 0.16494187105807567, 0.11450230504476255, 0.08053998027237193, 0.1726820863663189, 0.11026105843484403, 0.16675627369794155, 0.3405504745821799, 0.1946707556564962, 0.09133127097400928, 0.1052096202188442, 0.1290405854102104, 0.22765847103249645, 0.17270365940226665, 0.17589469139854755, 0.12292783196655013, 0.12325193312379623, 0.13469865034905174, 0.15451037355007666, 0.12222837836992358, 0.07988502872326682, 0.2223731691558515, 0.06956077586378782, 0.19016557643490453, 0.14121261936041618, 0.21222095666152818, 0.09679346255237058, 0.13154678076746004, 0.09775770677914543, 0.14388900881092395, 0.10884925798182526, 0.23033746518194678, 0.13996109216203614, 0.12024815599884718, 0.13567342062390622, 0.06991762727979692, 0.15118141508390828, 0.08603204161890092, 0.12423084793432106, 0.19418911617850104, 0.11421967988773701, 0.1340438903219277, 0.1701775610807442, 0.25610628808217667, 0.1903658931053454, 0.0986130822510008, 0.0821197148592722, 0.24054261435183788, 0.11699912348581899, 0.2317259229359127, 0.20334778924382504, 0.18882043329217743, 0.12442571005874103, 0.09330593154675539, 0.1943937995501103, 0.1097908030234037, 0.1787572402146555, 0.10504412224456187, 0.20373518458537518, 0.15519756973991472, 0.12456559771371466, 0.10515784033604207, 0.1353887423512436, 0.2060680602106356, 0.09205118677909337, 0.08515019780926167, 0.12086847271289557, 0.14783764047728432, 0.17704207660450091, 0.16311983818248396, 0.31821738748300465, 0.11563696553029361, 0.09122950385414785, 0.13284663279210368, 0.08504949555161499, 0.11277217973744678, 0.11045946754635343, 0.14365990255628863, 0.10148032718608457, 0.0988043667448144, 0.10952835662230369, 0.1887136866008082, 0.22137587589602317, 0.11719053055370048, 0.1183032272984424, 0.05748328865475713, 0.1289948959264063, 0.13575548396235512, 0.1734488944132482, 0.13334483509102177, 0.1338877003159254, 0.15867689594386086, 0.17239359297579335], [0.006355629649929583, 0.045436513910610835, 0.028142707212077036, 0.03578668655527215, 0.007589260076788525, 0.027721734236805674, 0.03622145294362018, 0.016664792971325018, 0.022015386606536565, 0.029360015178099278, 0.049990661472322485, 0.06179871938882336, 0.07704819747877699, 0.014697172746603048, 0.04107219527565664, 0.03498265812654169, 0.030167579102600296, 0.045595572915889566, 0.04596186636556541, 0.07276667762667903, 0.03440633784198473, 0.011349308188073339, 0.040413340508577325, 0.014532661110523247, 0.09180119696764216, 0.05933743210569505, 0.06153731869774, 0.03321505196753048, 0.03782283717526063, 0.06913241014004716, 0.0758856820363191, 0.013980447697723586, 0.009004087055913143, 0.05097550580338125, 0.026029886512626565, 0.07136923366136129, 0.04410696065714283, 0.037818328747826244, 0.020154400075215007, 0.04556248557843989, 0.09799799791747525, 0.05337516131300119, 0.08839762919852812, 0.00904653694540743, 0.03614635717484259, 0.040631127814131404, 0.024564613122493032, 0.07095864883834316, 0.06564667944105403, 0.11757551271828914, 0.025037101680232633, 0.13755033603839337, 0.017585600012793176, 0.05461754525200494, 0.04420031613159565, 0.021979068293266242, 0.05676662489291161, 0.06044670826785507, 0.08151092010760501, 0.020048438623968153, 0.008823954887057265, 0.04328256195050575, 0.06504382953167924, 0.11258106378297653, 0.09822362613293434, 0.025330817875181957, 0.05741225315197822, 0.002484725743171669, 0.07332803621407478, 0.010545493306351766, 0.09624066116708903, 0.07828650966046319, 0.045080482208680724, 0.04507873935865299, 0.040880592855354475, 0.029364921971254294, 0.03779345770336447, 0.04079169601262097, 0.0529969590265424, 0.04764480065674551, 0.07683760756927152, 0.04570639519501598, 0.057876276438154524, 0.044657992379319285, 0.004584474109804198, 0.028356980089278474, 0.033309694469696095, 0.06071195855075794, 0.09979983671538292, 0.07376352655551127, 0.011020924599330512, 0.04067319370205364, 0.037310343506115104, 0.03253208075259482, 0.042897326976902066, 0.02303377792779957, 0.008244176673132085, 0.03988207002440768, 0.016829580399057558, 0.008716947725793768, 0.03378973282392948, 0.035956225643355044, 0.026779844455661315, 0.04761504197132684, 0.026768211410531116, 0.01939137267219203, 0.035428042493520245, 0.05975961549988678, 0.023432808229699734, 0.01454625629834951, 0.04591354920018104, 0.03060332608349141, 0.05526894215314139, 0.018959325895975196, 0.03393604029570857, 0.062605892608483, 0.03793379735021341, 0.024149320689180208, 0.03740329678440767, 0.015707809342852524, 0.03259116528375495, 0.04947262132660516, 0.00970276690373618, 0.02248645407117663, 0.018097812144626534, 0.06333823435969892, 0.024330289809093363, 0.04358234747703518, 0.02709089147467767, 0.04205808914717167, 0.024171857080692728, 0.05312522129726507, 0.056576750000878695, 0.0354135557708721, 0.030089350034212394, 0.07703563363681878, 0.029877180068363107, 0.01649935628407665, 0.028669051750893557, 0.011316375025818426, 0.018314297100709333, 0.045963850533289295, 0.046185943252977826, 0.07576984954216788, 0.0919787455049734, 0.041387176156164183, 0.0194912513853201, 0.08035477085579788, 0.016578207798903028, 0.0428920179875868, 0.04441950537805115, 0.03952017008897759, 0.03864439369569864, 0.06080380483199993, 0.07734226032851205, 0.03442795684320792, 0.01734390884878174, 0.07734045236101074, 0.014673533188479563, 0.029585536141248963, 0.045082263363104676, 0.026517011180159547, 0.03549688315439609, 0.05267773018849473, 0.05594907884275722, 0.022264066407637253, 0.07994253894374256, 0.011298912051584453, 0.040759865059367115, 0.06130078139023916, 0.029952894453139558, 0.04195510394751065, 0.04111590442217646, 0.022703126718800877, 0.05190393925013562, 0.056794747980611945, 0.03572159206434604, 0.047221100408463716, 0.015760658875918918, 0.035824768785988136, 0.06223718215140605, 0.05267432492767131, 0.024707126543827118, 0.016260174058017232, 0.005472156945841327, 0.0635113166044316, 0.009838055158334394, 0.04947638281831338, 0.05949587441019474, 0.0705061053797122, 0.07538330455821368, 0.0878567711239861, 0.010522802739644484, 0.027756811487638665, 0.031482653294299404, 0.025073672802517974, 0.04848906785369881, 0.06800721850126021, 0.02702508452198198, 0.0024817906688117696, 0.022095000378847606, 0.10758299125178207, 0.04381705766483661, 0.03710584782604729, 0.014085699560030574, 0.07809157092725078, 0.02520045269310715, 0.023272017865712126, 0.04169329722982742, 0.04914928625728335, 0.054415190787685495, 0.013168475894828238, 0.027325235855495258, 0.07064036228844235, 0.0070364208659157166, 0.07022226214288704, 0.027010733779940396, 0.0360770070654971, 0.023640816422900366, 0.053550591617221796, 0.0427072643933277, 0.0659431784503883, 0.04556664543586873, 0.10981576216797675, 0.07345503060928277, 0.10379928299376082, 0.0020903633107551404, 0.061476184881382415, 0.05090518276237192, 0.06901716753359764, 0.03991676614649835, 0.05091296238524299, 0.022516764339900786, 0.053398910038653886, 0.006370339974490625, 0.07688521227288632, 0.011008527381495844, 0.01002314774649999, 0.0129471157467173, 0.05132895578900653, 0.018253511854357297, 0.030911138296247493, 0.05982525008279951, 0.02216584244442563, 0.02466124553804196, 0.0464602142211891, 0.014454387992079702, 0.009156267549241743, 0.0165737644889422, 0.040847796631316026, 0.048329078051592075, 0.0222279587685461, 0.048102185791057926, 0.081155838354701, 0.03516058970783507, 0.06268200727419988, 0.012745325314632107, 0.06512789235961053, 0.12165424143595081, 0.1075961679640797, 0.013024909102598266, 0.03551968959190192, 0.04047195389566403, 0.0306051321357729, 0.02288886665126249, 0.05206529651918719, 0.017477683122119596, 0.049154422876815644, 0.025899302995493336, 0.031347097866537596, 0.033809712396994714, 0.029309564457845785, 0.02955624859990372, 0.02983148866933921, 0.14723555665583382, 0.015230790332650707, 0.028834321814018394, 0.06384438865127103, 0.03848896211674137, 0.054049249738454826, 0.043320100258795485, 0.1207927525824597, 0.07498767377147753, 0.0603806178626274, 0.046668486714723616, 0.027141437955921697, 0.014005434612983899, 0.07383690245689885, 0.04368181250268414, 0.01826698542572558, 0.05151869278521307, 0.04292271513071272, 0.004509814053533539, 0.07789336865948093, 0.05481320027742655, 0.020044541151653376, 0.02076806714608064, 0.05053764825025874, 0.07611199973091003, 0.003372434674078719, 0.021971845999360088, 0.14046211366451558, 0.0148504899228893, 0.009417295730071924, 0.04005998628394258, 0.0565425135315426, 0.02311470171046113, 0.034762495948422345, 0.004550906530986991, 0.022219424549069618, 0.0144835960518028, 0.01207626146835185, 0.08172170919997078, 0.049220210677313234, 0.05834087045983442, 0.04535189566893443, 0.012792248199994286, 0.12412783975202231, 0.013976056098697648, 0.020269928049416314, 0.05847054616277737, 0.01742975283113699, 0.0172645268180678, 0.08946400826736804, 0.009719908121041954, 0.06736745081481434, 0.05283619547563215, 0.038123706716202924, 0.059636286835396485, 0.008174258701112724, 0.05746351209499183, 0.027931401010362372, 0.014115518574873287, 0.07302284976767917, 0.04520433564339915, 0.11674141150809104, 0.03739078656860417, 0.05147978317953887, 0.06406619791842758, 0.0788455853058446, 0.019702312438898993, 0.05619500072733049, 0.10026623870456412, 0.044098449420304074, 0.024061718535038735, 0.08305443405744531, 0.04910819330102494, 0.021674527275946834, 0.05008125136936865, 0.05008243880565128, 0.045843268294007554, 0.006710028148166115, 0.14543486698981256, 0.12664869803214265, 0.17282528352112542, 0.09946995925518776, 0.18909608704909203, 0.17490982408485106, 0.1189426962105978, 0.11913424883518489, 0.10791640803818742, 0.17557281189628188, 0.19065372766025607, 0.14081230777646267, 0.29485048005177134, 0.1315418318394692, 0.1504827122534475, 0.23363519790432147, 0.1200602729354174, 0.16001420966800184, 0.11895643982795939, 0.26030264193973235, 0.14147586249295743, 0.13778865066987855, 0.10936786886304618, 0.08687553506705069, 0.14931562326608167, 0.23658839024363026, 0.21295296899493665, 0.1111332418757581, 0.1609305427559922, 0.15389468400709092, 0.13260185237853758, 0.2267758611349329, 0.14302404957913584, 0.1175916848343707, 0.1558993369220726, 0.19734734428986428, 0.13744536667100846, 0.19092320674850097, 0.16509870457793438, 0.11634117653292995, 0.10432209969768602, 0.2011649749211727, 0.12430296745151283, 0.11521690419965214, 0.11306503216826147, 0.23178112723173636, 0.16446171779065363, 0.2000931259845534, 0.11392364819203654, 0.23321489142554425, 0.1824159076016757, 0.2540475493597408, 0.14232428954733958, 0.1808187215318603, 0.10858627531917826, 0.11805496884570008, 0.16139215669564663, 0.18658688862717923, 0.1439787330286157, 0.12287778344245688, 0.102864257360418, 0.09608123060916701, 0.08429734276667719, 0.2687306509863946, 0.18500340020944997, 0.13191035077456506, 0.13676860459869908, 0.09584117695809373, 0.19188521399853692, 0.08232016942553944, 0.18560951365338219, 0.2362818171780917, 0.29984666034579277, 0.08685476642342345, 0.09115685573628834, 0.10224294473206806, 0.1554745258463006, 0.18879950377008609, 0.1485352707846511, 0.24315479031253248, 0.14638219599521932, 0.19653584267343246, 0.16315166147485857, 0.29961425991308305, 0.07757732674719826, 0.09898861855148308, 0.14897451495691655, 0.11761167206831517, 0.10741756222541295, 0.2427804950744875, 0.08147159681445168, 0.11045522341925292, 0.0747320072485074, 0.1228677093862526, 0.17648202036657643, 0.12523606254328645, 0.10679934459227709, 0.11788679722456202, 0.1897483649513414, 0.11035901809772176, 0.13461110182106495, 0.1224601889149316, 0.11387609711457646, 0.19155109241124124, 0.0836378483161811, 0.2427428188703714, 0.11501602062414731, 0.144839218306926, 0.13616932465905143, 0.09286399840587571, 0.07620293436752212, 0.14400340105977752, 0.10501959210922641, 0.14109405959325452, 0.14956807988064905, 0.13460480457832738, 0.1485888356523168, 0.15101158871285378, 0.1314930320386925, 0.130407546737021, 0.07636415757118695, 0.12769546525012102, 0.15281163486501864, 0.13640207749220634, 0.11391518292047324, 0.22473362394638602, 0.10213464288221252, 0.15812558843003166, 0.08243072357389235, 0.11171709280461074, 0.14188692995136784, 0.1303951361126477, 0.1943656994450477, 0.09949697151539788, 0.11243214395137564, 0.14375520389406912, 0.16817307670510587, 0.11591345432304567, 0.13450912019658473, 0.14006754773999416, 0.10239949479939477, 0.32478607049392116, 0.07044654970447864, 0.2518364357491655, 0.20245583307358528, 0.11275211589470988, 0.08955902615261656, 0.21525474145047127, 0.0889107778728489, 0.11902798477920795, 0.14104057133438128, 0.173217520538357, 0.14486610799306823, 0.13989168459609633, 0.08890900054886457, 0.1262129242381742, 0.13704559134860195, 0.11752675122190868, 0.07820394070398423, 0.18162201068574385, 0.15774456694001154, 0.17300388925979215, 0.1797525263241222, 0.18359972794930782, 0.12806045251988596, 0.12339893773558641, 0.1990190400711952, 0.10310204339123542, 0.0982597012132887, 0.1469406434485028, 0.13909119932401565, 0.14530860037813265, 0.1522889024307651, 0.19329133774003676, 0.1569733309048799, 0.14429350323494405], [0.06340254744094226, 0.08936333665323835, 0.051207396787621325, 0.02945111452361509, 0.02552671230307991, 0.03380679743244283, 0.07321257910300648, 0.0407244258319899, 0.05502831010568527, 0.014062825132221466, 0.06846831916200538, 0.04160336999883575, 0.030445303212130265, 0.019136345832638683, 0.03202296170075575, 0.02965304955479599, 0.1043648703864986, 0.046971233171080394, 0.04666872420198014, 0.06626688124191377, 0.06824104385750909, 0.044064841143065886, 0.08849103829913563, 0.04977653223660685, 0.04573994218522022, 0.05831978772015822, 0.004352484970548821, 0.03803261886200598, 0.01834250637330115, 0.06384499003029158, 0.01992658659395191, 0.021410259500806852, 0.021352435184282162, 0.10939386222631702, 0.050777414618360425, 0.04525468677222248, 0.03751996814483597, 0.02519171737555054, 0.02037767448552674, 0.06545829075959421, 0.087605080597343, 0.04464590734231376, 0.06696052789207428, 0.019858222822808934, 0.027781205642367565, 0.019969523906888022, 0.061806089154654936, 0.06390599744214166, 0.037667731183671185, 0.022451317448529507, 0.10310033501516427, 0.04966048906827646, 0.047989785370807496, 0.08256825167805919, 0.013628595963030333, 0.028406373608196457, 0.02213186069932436, 0.03392425786343313, 0.03215453730175092, 0.03534975979897765, 0.018002796174597838, 0.0364777629804467, 0.03890695117954766, 0.06288829560001051, 0.05024256267314477, 0.030150855403213255, 0.07426453273623221, 0.05135435926457567, 0.053811999969184406, 0.02690356382499299, 0.02238230824831032, 0.04555382878489552, 0.0425080853634544, 0.0036723008792426803, 0.04292509383371761, 0.023735037576707623, 0.021333321290571364, 0.04605844707017945, 0.08913812978613762, 0.05216894821534234, 0.04826629331575767, 0.024065535568121462, 0.07796557244634436, 0.0333673081120416, 0.0285368345512618, 0.05408764606521976, 0.008534733713003657, 0.054370520200820706, 0.02855680071778836, 0.012314600040084653, 0.05278845670663061, 0.048352167941629894, 0.04765164182190934, 0.054030737223764586, 0.04862148998185031, 0.020305396005090688, 0.04491577713540004, 0.01960269611088499, 0.04265677919911762, 0.06275555554537043, 0.038199334916087894, 0.0363671207319825, 0.055050852242857225, 0.05122204438873357, 0.07575456608807848, 0.017289010988127802, 0.021616488454803344, 0.045130128536613724, 0.11253926602582778, 0.0496805222674964, 0.08652706465293324, 0.03924486107162891, 0.041224447589728146, 0.0381184053877669, 0.008978438432208233, 0.04318201674088355, 0.04074516766253979, 0.05197336979871316, 0.07518279636579175, 0.0238016297695257, 0.044052108761764346, 0.055211412780467546, 0.05260135122244397, 0.023721642529351578, 0.023166778452333905, 0.050322251139028426, 0.024179772684170354, 0.05978880728024149, 0.05691019360036139, 0.07442024010684221, 0.021246684407214486, 0.02948749603913917, 0.040204137218214815, 0.05313547538413156, 0.03349174377358249, 0.01424085343211529, 0.016237915373377262, 0.09226396770006226, 0.03022691261233582, 0.03194611925151079, 0.0627423405286766, 0.10948078256220588, 0.03413263377883742, 0.037215237520755305, 0.07069257118048207, 0.05721116273273384, 0.020433796171639717, 0.08110249565253336, 0.014020075510826804, 0.05273445133840846, 0.030635760330985633, 0.03412728265468632, 0.08853501940686857, 0.03379904462264911, 0.06512814516862554, 0.020021345924525973, 0.04281951159599327, 0.050907113303941105, 0.025901921100974567, 0.11263605357418138, 0.05380173439099904, 0.04265284916806606, 0.035446309860074715, 0.02913147965896755, 0.061546167013265436, 0.0458369059337964, 0.03630447389197446, 0.03974611623092525, 0.06074535998425657, 0.018859353337076404, 0.02896235617358358, 0.08511243733547388, 0.028308670584773345, 0.03211788382501372, 0.03258936497713289, 0.031022665376264243, 0.050369679642420624, 0.08303199534214313, 0.0376782572317508, 0.06870889375286718, 0.04323646644010179, 0.038776789010772784, 0.051502034203299595, 0.018278415457555847, 0.048935474948056286, 0.02350433402875018, 0.03230842138310114, 0.04696895022906604, 0.06170765451726414, 0.028519536285931547, 0.07827255919936203, 0.016578634892920815, 0.06511942708804723, 0.04082292558685426, 0.021015848709090103, 0.07504992607620455, 0.034495537289448326, 0.07549405022854767, 0.027062465782247247, 0.052252149194358825, 0.04437507227844289, 0.004117377853441623, 0.01101515212682106, 0.005543230753016448, 0.02702761835779154, 0.0328187202103436, 0.06770714952219879, 0.05593366515372069, 0.03999335578672829, 0.07400166498677385, 0.013798830275904509, 0.05287807750245256, 0.050935477709337595, 0.06477122480470328, 0.030526564073478504, 0.028445785001461065, 0.03756766094856205, 0.079962304012189, 0.029993910800605535, 0.014879570620494985, 0.02223093118969231, 0.010555756011707409, 0.04136688248704999, 0.04231226945956869, 0.04395979133644893, 0.05658001736587575, 0.06918422832724548, 0.02716907649300993, 0.01754747947768098, 0.018082130324816512, 0.04349539266718973, 0.07655873624307495, 0.010694294394324384, 0.042006592716901534, 0.035624153341256806, 0.00892160141149596, 0.05446479498078266, 0.054735894344987414, 0.056932222458624074, 0.06254889183647691, 0.051889732149579836, 0.028256423388337417, 0.1438983091183247, 0.048042679911539446, 0.0952043510492771, 0.06009074551383815, 0.04302724782798079, 0.007273001265862296, 0.07404890196818499, 0.019200000078267148, 0.023332320476671862, 0.04194694894155668, 0.033074367581115614, 0.024991818223028414, 0.02439665792119359, 0.059754517184750694, 0.061182282910111456, 0.05422077682470122, 0.034218542878666235, 0.03966561571184186, 0.008092778547096157, 0.0526978055225505, 0.04388752626255155, 0.06346653110437817, 0.0285507409623073, 0.02432940306232101, 0.009795472161063265, 0.0448208243676251, 0.07887881819999988, 0.13391521819416555, 0.057105614968966094, 0.0034820558709813465, 0.05997135454127866, 0.038457188620081836, 0.057776187050847284, 0.06005142605112446, 0.05007043803831743, 0.025942627182831208, 0.009893807207023906, 0.029285505466583758, 0.04625454642659715, 0.038082874229838776, 0.03945738535314318, 0.08128475563059892, 0.07115154977767699, 0.011383952599229112, 0.01661505471284111, 0.07391774771554817, 0.04154955232215505, 0.04582657140769786, 0.02892100466265073, 0.0804873193884569, 0.102187096922388, 0.02977663485874092, 0.07166789303864203, 0.02655052944206663, 0.0014142097995406197, 0.03897596804064609, 0.021283098481475346, 0.038946960121393204, 0.0385000282568076, 0.06274554660663971, 0.052680633661727753, 0.014273172766420872, 0.06900543872747691, 0.047730184986346194, 0.03675679135466776, 0.02911799651150021, 0.04089990210148596, 0.030988448059126258, 0.028610930575298208, 0.02014324391981767, 0.04966912670962272, 0.027947483111112833, 0.03441911618856173, 0.021255124780920245, 0.05930822117314224, 0.05075859949894009, 0.028666707521845258, 0.021174438485515215, 0.0028229650530603627, 0.03853622208079023, 0.029405426955030813, 0.011789825023903001, 0.013684142125590194, 0.03172522737464357, 0.0030393494601030986, 0.045470800175662004, 0.03460863484970985, 0.03314807290031064, 0.06825682526874928, 0.0493285546620046, 0.03389742563388521, 0.11955329892976631, 0.01488194262023054, 0.03521703889653568, 0.0441289512110093, 0.013696999953789337, 0.028458490569685257, 0.04631300276565937, 0.07640666779010527, 0.031752354548042344, 0.014366393217877036, 0.018114574148409793, 0.04656418001339321, 0.030391742174904195, 0.07569815137333448, 0.07342893765458176, 0.025604004828980374, 0.034660345784598784, 0.008594129467383027, 0.02598663893408112, 0.1031994361490492, 0.19513051566337386, 0.15021465808874176, 0.22304613143205645, 0.09344022675988176, 0.15174318735878314, 0.1838962959065553, 0.15397215081799417, 0.17391985462557885, 0.17567453305086783, 0.1321806265942512, 0.1757117189587124, 0.07616688226980549, 0.12663670109524844, 0.2208556409084028, 0.12893131062869104, 0.27678410432511763, 0.11928801034246722, 0.08399155111082139, 0.26221351037102364, 0.14311377379682758, 0.2260939203082554, 0.18841325756042235, 0.14959193585861116, 0.11679647024720909, 0.107592643959628, 0.09792822262933178, 0.13731111742315755, 0.12794728601171126, 0.18322154098460752, 0.14564376384500535, 0.09180193241204947, 0.12107155496074308, 0.15136447945429435, 0.15307173703707036, 0.1338568116508184, 0.15528217649027226, 0.10479532753027256, 0.09726666740231937, 0.09320787995332673, 0.24651859045749713, 0.15651053718982205, 0.15804911753342998, 0.1190929260525492, 0.11262310668826105, 0.16290571660764758, 0.1162798511945913, 0.1851318578325933, 0.2284149828577234, 0.20593641566172724, 0.2429531866143788, 0.10871763641555464, 0.10651283536947544, 0.12847620843639299, 0.21812174889829852, 0.1346896105115452, 0.15596123682635446, 0.1307835120467409, 0.08699817808284875, 0.17212644279483827, 0.17721993157700186, 0.16338317324557614, 0.16867538523529807, 0.19236860015699941, 0.1739605032508412, 0.15574045028657685, 0.24622675692362173, 0.1596756600925038, 0.16437789244997889, 0.0805973372752628, 0.1661229488109389, 0.14058810448454273, 0.16645071186846302, 0.13818421250870153, 0.1486104393317815, 0.13357930396112705, 0.130192521178434, 0.24548064857240648, 0.23170194438388272, 0.22950445181660115, 0.15358311604828606, 0.14331767575875407, 0.17531923679334505, 0.15500119076140467, 0.07451040865553003, 0.17603180581523528, 0.1543622427890378, 0.1369617353644102, 0.1623133774245939, 0.08623683224281958, 0.1034538999139782, 0.1660338068200696, 0.17005359273283713, 0.1892333546833646, 0.17159073283114742, 0.06817142944782972, 0.1465460622022229, 0.11380428403255441, 0.2776275977732674, 0.14832140967970894, 0.28590781313757746, 0.14329156748229457, 0.10047538836877193, 0.12594027354592277, 0.22988193398041112, 0.12667665258049965, 0.10376097859754678, 0.21917928731249225, 0.20993825979530814, 0.1412273895355963, 0.12607873627735725, 0.14839932082160828, 0.08737957495595179, 0.15986067032621754, 0.17658377216467935, 0.1309302638495161, 0.19251645512638554, 0.15965540472778583, 0.18610649021162143, 0.16480244305585662, 0.14405662884875653, 0.13212119349308554, 0.08377012105718737, 0.09600431538156926, 0.11118023370903347, 0.12005423616257407, 0.1165426729787742, 0.1053857821370325, 0.18244866552131792, 0.12100643748717925, 0.14682914701200303, 0.23108564197055756, 0.15109981139821393, 0.11704745597296184, 0.2193501555631238, 0.13527721527122682, 0.158563882653271, 0.18160773080683526, 0.09763101115822793, 0.09768649124570432, 0.17307833768427375, 0.16058108408845242, 0.18826773149832604, 0.147975321799036, 0.13956658752454867, 0.1303907387679623, 0.11021927599945378, 0.15082228838676406, 0.08496261352012235, 0.10066150176909663, 0.12927399707898019, 0.1540459097633439, 0.15720312663864705, 0.15213338658213615, 0.10900815227820028, 0.09947774270849843, 0.11677144215472283, 0.2535171560462444, 0.07513496949667893, 0.21628463941235698, 0.16031911266186546, 0.1308905345297629, 0.12867559047956623, 0.10779434724921182, 0.19076364595563183, 0.11959703488936348, 0.11441383721126665, 0.10398008740477024, 0.13234348156519476, 0.1707041699198946, 0.11518909520800076, 0.1694307632503971, 0.10626343544572593, 0.11120482513140287, 0.11247271596784554, 0.09166736906814961], [0.04260588031742842, 0.036048232803061124, 0.031210709318158128, 0.03735818952742604, 0.048033835426453626, 0.04614339089922367, 0.035341474558076555, 0.016994182050468463, 0.0499479252574665, 0.038321353570227666, 0.011564710087353184, 0.03098178500940483, 0.005021946703744752, 0.038974956804586035, 0.006929822125276852, 0.09181778277120284, 0.03602615414908336, 0.0367105694397563, 0.035385834879332015, 0.1052427305389316, 0.07746146360953009, 0.04565333594538031, 0.06875473645425613, 0.020231717498973012, 0.04767678482758422, 0.03452477503507849, 0.05211232282641915, 0.006167452121453901, 0.03581482113429135, 0.022417795356182803, 0.04346655711771981, 0.034119204257524786, 0.0516508506130307, 0.026719229663872433, 0.02004917023793584, 0.038421381670500965, 0.02925704338497693, 0.016892227239065596, 0.015789591143989277, 0.031941321625884984, 0.018696460061736645, 0.007480657058617762, 0.03188248990373987, 0.09317349026640577, 0.06082064727501524, 0.05260720413418547, 0.042883966403502616, 0.03757307719018671, 0.03846853438224043, 0.11003107117909579, 0.06715511422484152, 0.06332467843387878, 0.045696880382996415, 0.021877297342965202, 0.045169520777680224, 0.01207207192501594, 0.05260372609500924, 0.023727805706702416, 0.02767146929287382, 0.04210241116403092, 0.04691478398237978, 0.03067281408866327, 0.07034397819229672, 0.057450722257095965, 0.05142465166206803, 0.03460969205104536, 0.025823220888513233, 0.07709041658428407, 0.039093087562510086, 0.017503004243236878, 0.023588391111022042, 0.00606249520299776, 0.0199128219091724, 0.012228078069916416, 0.05739366019805593, 0.04141040777246799, 0.02433585543786326, 0.03602736456800373, 0.025696224578085448, 0.02210340244815715, 0.020145819890463067, 0.04869564729292066, 0.031463550891907464, 0.016507070789474155, 0.025988634593123873, 0.023973105144837213, 0.028452582116569244, 0.05020465664265137, 0.021769956933454643, 0.03626944835207636, 0.040803976402047186, 0.058469397030890956, 0.04997163567872298, 0.07227195336693717, 0.07618478574459592, 0.03537450826937153, 0.06163467315115756, 0.10117737771642786, 0.0610670326427827, 0.012397919762729397, 0.05220913718785009, 0.08490733261550627, 0.029706191158883517, 0.018820183261507945, 0.024238342021201408, 0.03891775684971963, 0.008330759930334265, 0.03493059479120759, 0.030193501602738138, 0.006320449934836718, 0.036213500950966156, 0.013437344027953524, 0.021231881673297575, 0.021509988826789686, 0.05243631290091623, 0.027534638328718084, 0.016681154694167838, 0.029143874961582404, 0.039071476222166134, 0.048557333948631445, 0.026561961389116706, 0.06989249193500127, 0.06204401308129873, 0.035889970529223644, 0.045867281319994124, 0.06263867734120258, 0.052427043237032435, 0.029216009800532655, 0.02037573053741888, 0.07962295770524971, 0.05252164743480183, 0.036121512943458174, 0.01503454733474721, 0.016084150035655307, 0.034566925192672404, 0.05311723100021482, 0.04184903141351477, 0.046424828619966586, 0.023934839053019404, 0.025033386153799873, 0.07602130258155447, 0.04441346094432858, 0.04844390697056248, 0.0750444945128214, 0.06061654996066805, 0.04523114489030935, 0.06162882406985568, 0.08221032007807687, 0.056918762293794466, 0.037323359339948625, 0.03185623224013515, 0.024999381426060875, 0.03729931184000546, 0.07081127650434933, 0.01732735560395785, 0.04580516308065384, 0.03594693682727314, 0.0210517858936181, 0.02576960047947303, 0.05052819472527312, 0.02067438608426, 0.042511142054272276, 0.07151670558678527, 0.017047072760760784, 0.024615228551650242, 0.07649046248726307, 0.007339379432866531, 0.02978847091717105, 0.04862514039080951, 0.015300474647853165, 0.02992864968555589, 0.03784252563491464, 0.0321604055352509, 0.0344636756926775, 0.02760960386254855, 0.02843167366189582, 0.08231532774985799, 0.04052613929454838, 0.07358192541306058, 0.04151685951998638, 0.10678115766495468, 0.028770956766581344, 0.023994057649566282, 0.025553559854386315, 0.07659430570539928, 0.03888155536485776, 0.03531609023470552, 0.03462635446339846, 0.012840600796945155, 0.12267017361497688, 0.08869791268220834, 0.05925551049351212, 0.035436097908044056, 0.02856490975846687, 0.05945446735788738, 0.09254239469526276, 0.08204555754820186, 0.049605066437394395, 0.02896061332355584, 0.011660755488030132, 0.07217436908714234, 0.02374418275130372, 0.011642034214380528, 0.03355562018470899, 0.036518323505597736, 0.028894540155306462, 0.01978813343861651, 0.023434371049065265, 0.03779796613079887, 0.017555157593902082, 0.054245207368606524, 0.03394668125697682, 0.087668688877696, 0.013784416331609171, 0.027349802380007122, 0.11845306643555242, 0.020072884489631942, 0.053889439967010296, 0.027608081262799043, 0.031866907675360004, 0.0164125278787387, 0.09448709356929026, 0.0821042322223225, 0.02820165767785042, 0.03263046559427054, 0.0879555811444598, 0.05209199851378799, 0.04772294545546175, 0.07264395800208853, 0.12250632272973178, 0.02371721837158886, 0.03999465047532032, 0.04958974850934841, 0.047476927809897936, 0.04250516273802327, 0.018015147427157048, 0.03682631766423583, 0.05598868941888214, 0.008917647440196767, 0.030354385812496467, 0.04537967018662922, 0.1212339043136566, 0.020286058030662038, 0.012209096326372557, 0.07431180036116032, 0.05117517129908647, 0.050348960794508464, 0.08277200042240082, 0.0822584533823594, 0.013780583019158053, 0.07084553595632315, 0.027428316816146818, 0.01952241584207983, 0.057899657441603566, 0.02567156995346229, 0.04345646007887779, 0.018852073586575927, 0.0263277031931906, 0.014591372173820293, 0.032694207940010295, 0.04765302461061267, 0.024758364419422807, 0.031084358436806552, 0.04551825932257118, 0.031066972071365006, 0.13294066242392988, 0.07022768604539095, 0.05914801686641671, 0.04427343922396822, 0.09066960083380823, 0.03372670677039893, 0.05025376670903737, 0.030081993674919493, 0.13617317042043134, 0.02592736862659935, 0.012530514260663862, 0.0656523484916937, 0.0776214687333953, 0.0645693299931384, 0.0776058788441362, 0.018472473189655333, 0.04362908650129553, 0.04011995181621563, 0.03393528952954277, 0.04515230295158202, 0.028826339177847392, 0.05229035016870307, 0.03829459411903255, 0.023195393751525593, 0.021316091973154296, 0.040087959984497684, 0.08308748309049876, 0.018746001052580053, 0.05096155151184048, 0.03420172341828866, 0.0337636590214266, 0.06221959660310419, 0.04997268138873962, 0.06325185794623629, 0.05278034000507286, 0.1370494524317403, 0.019601964496917302, 0.015947564219635342, 0.06001616685440945, 0.03638999611740151, 0.005189996708424823, 0.04360535309740132, 0.04920600740719707, 0.08977966713568858, 0.023274704919106538, 0.008078072531779688, 0.028473607399651123, 0.009743312107128723, 0.058268226172414526, 0.03690918156456563, 0.01178894593800989, 0.03302087166136311, 0.014611067336743638, 0.044534001048774495, 0.07068658803379343, 0.033098231219956954, 0.0838129913374301, 0.07931023295367919, 0.028854975544456995, 0.02746287695763092, 0.116159598373117, 0.04767127665540865, 0.05846813298581589, 0.03796909485132464, 0.02620872590811022, 0.024478704022664218, 0.05196498879682153, 0.04467728630369229, 0.0410283214202331, 0.03178702768749528, 0.04674485035901589, 0.01526655514739574, 0.009037996980271513, 0.03244508763835315, 0.04270176388203137, 0.038884612055675644, 0.05832093302160502, 0.011992505075590265, 0.05147217209601114, 0.021164329955354336, 0.03985007436225011, 0.02369995649543501, 0.03425444941967726, 0.05159817440735717, 0.04847509057952031, 0.018048535454117002, 0.022171672373529405, 0.2311447992800705, 0.09618331948595663, 0.16924710133143012, 0.11717452697696225, 0.1309597275910839, 0.14328914664445386, 0.17869546288444152, 0.15925838732190672, 0.14885993884696117, 0.16090803509277685, 0.10696903306750521, 0.0879786863562561, 0.07428733917373805, 0.14848613390518775, 0.30993272880873374, 0.1873146415117287, 0.1463448262262729, 0.09891554908526522, 0.15520595074180635, 0.20842307577690772, 0.23765061711592061, 0.19412173108468134, 0.10956739646292503, 0.047589439312897386, 0.18524148501455787, 0.14240938659396865, 0.14561759428151194, 0.09459250726767125, 0.1575991634519831, 0.12364682846612508, 0.16081570617614255, 0.17671845042176787, 0.177250667024524, 0.08028892559870597, 0.15359077692752884, 0.09575707582576622, 0.22361587102134384, 0.11648452690532131, 0.09955287295123262, 0.20811904612327778, 0.17439688225426983, 0.1544914818218639, 0.09478056653132362, 0.2187821166890283, 0.2184618459714036, 0.2572708949446678, 0.11649441710042378, 0.1338696053191539, 0.17877004920474945, 0.2498876766091393, 0.12784625433625715, 0.17596743910783724, 0.10922408182053797, 0.29306920305375134, 0.11539522648578691, 0.0812668904602047, 0.11560429188032305, 0.10632047835256785, 0.11731145753254814, 0.11256600249438517, 0.14934311050080484, 0.17408139192529265, 0.14198316591641597, 0.11339321657414399, 0.21133100764165003, 0.18638029003575926, 0.09470091636983619, 0.12776715575807518, 0.17839419114733898, 0.15420226830868952, 0.10913046587619091, 0.13799391626831026, 0.1656516821634385, 0.05897390040298624, 0.22606650968232464, 0.1057090099540449, 0.09869615682550976, 0.10011498996567342, 0.11688899068582444, 0.10378016910005002, 0.06916225692557712, 0.11756406736470039, 0.13763466699709817, 0.08013618298836293, 0.24758723714659292, 0.11417682492925275, 0.152847993397905, 0.1341629403853609, 0.15576824395646974, 0.21780772945813595, 0.21042820366640247, 0.1465101786438496, 0.18949138841802077, 0.14767064863154966, 0.13129237828956497, 0.16553736652337736, 0.21637774973867402, 0.3175058756624499, 0.13784930951172306, 0.16296294337559133, 0.2069477130088114, 0.2675276171536215, 0.1981159449825364, 0.17812411451051313, 0.09935917528045755, 0.15301518442649997, 0.10330063636384665, 0.12640400954912748, 0.0819427255661257, 0.09809101631324138, 0.1396719705794127, 0.13976295118130025, 0.07777433391780623, 0.1089751875148185, 0.16857214722662203, 0.14794792649486374, 0.10665497532294643, 0.09301926144548962, 0.11090999619374353, 0.17824034537038497, 0.13439036124656278, 0.18155995756387713, 0.13627021843867917, 0.14399270647235457, 0.3066982749489046, 0.22745049348281277, 0.14946798283246257, 0.16422786179088777, 0.09090294355466481, 0.14983688481152058, 0.1259434298281708, 0.15804563949425376, 0.169776376156557, 0.14392340615872415, 0.11307349743982477, 0.147511639421986, 0.11168063468029422, 0.11600820407752069, 0.10146909633711462, 0.13546190374801237, 0.2264661471089048, 0.09556873310958186, 0.14915069985774257, 0.16092815256166845, 0.08798405663260529, 0.24437222659828203, 0.1572676005983545, 0.11517053289759545, 0.15040185933391895, 0.16243164607834432, 0.14026472344994545, 0.12926409922299847, 0.1662744197153276, 0.11615570664646165, 0.24720871310320594, 0.12174666994401526, 0.09504639904104895, 0.1031062798574567, 0.127013003483655, 0.1337506471862716, 0.08801646215180237, 0.13499017744775743, 0.1504801841632974, 0.16230677374668662, 0.11753968278607053, 0.2077180603819509, 0.13778390092474802, 0.08653124749299981, 0.14126799219558317, 0.10108347065866956, 0.16780662620740552, 0.13048527401781854, 0.18665222060536185, 0.16015216678140626, 0.19158506074980383, 0.11932974681258203], [0.028087464611857172, 0.05750374703277504, 0.02181220093681928, 0.02446565563009391, 0.07352848311946278, 0.06664087004478901, 0.03779780142189514, 0.05441719793804711, 0.03242913768776963, 0.0575645552617648, 0.08618529750815324, 0.04810374477998384, 0.14022942211839462, 0.01845142875437535, 0.06371116979167828, 0.037707820564748785, 0.049199369255333185, 0.06993373810884453, 0.04695844716362415, 0.023671400568057454, 0.05391543716072075, 0.04466471480085485, 0.03681111081893887, 0.08633039456101195, 0.05223565149090944, 0.037552331529197194, 0.03359472897324351, 0.019362397311675935, 0.05569042840732202, 0.05959601359321706, 0.03833341945503508, 0.03883423028333534, 0.010006831988932626, 0.034569767378871484, 0.04502964078358585, 0.013897178728403825, 0.007756174834925802, 0.06779842889837681, 0.0702830512196787, 0.06328474227038604, 0.08220648197757621, 0.054054439984141826, 0.016798414027078018, 0.016608274834711226, 0.025892084532026804, 0.006891303224444029, 0.012197463281242358, 0.04754083103410179, 0.029058540427696802, 0.09368738204601312, 0.042607378019320394, 0.022243251798734553, 0.033407887789390744, 0.024532615545115644, 0.03424048363681763, 0.022977548989377195, 0.07387716037731978, 0.018476859043021838, 0.0924941694604293, 0.053284556094196536, 0.04125589932945948, 0.027555242263441606, 0.056532539066768465, 0.07730793958950428, 0.03983833023437089, 0.010717294269031095, 0.028245240419862733, 0.09664166989105363, 0.04873602395696987, 0.027455311839378653, 0.04908920198138203, 0.07048825553107647, 0.025237749683700746, 0.04012732158204721, 0.007811541924433363, 0.02078534242877316, 0.055814948338534565, 0.04013174957024955, 0.054614515374264413, 0.013796657459029268, 0.027549820276157513, 0.05596176908922292, 0.0594261565786456, 0.047099403511252136, 0.05439750564795348, 0.039195697379088214, 0.04861884697851154, 0.033860561482968836, 0.025143379142748255, 0.030551358509147843, 0.013335888131311344, 0.026492421673009955, 0.047333282493655725, 0.09593565858179524, 0.10163194364717892, 0.0214569621358908, 0.06218202382085785, 0.04460429727670647, 0.03654578775768319, 0.05363185439378985, 0.05690763486669429, 0.10421800367053478, 0.02552551337547841, 0.051161151890072136, 0.011718018645150288, 0.04430357329246979, 0.027687869320112853, 0.015070194363473885, 0.018760240711872617, 0.03216145507570717, 0.04875247186470417, 0.03768308741611339, 0.02603082113989419, 0.05456795638066627, 0.016191685797586557, 0.042164207646443, 0.055432907951575135, 0.007404869416683553, 0.023851973237469796, 0.04906652194838371, 0.03958642903354861, 0.019774600495434096, 0.022832474919156204, 0.04292902003432955, 0.03172154249172778, 0.016636821185989727, 0.02817856012693336, 0.03344920291114719, 0.054673952305869716, 0.07743785277970376, 0.017486611876877087, 0.06193661521519385, 0.01452940044879553, 0.015103848605987527, 0.016289103453257875, 0.08473857110666652, 0.045932751194003134, 0.011315229724371626, 0.013324959887071483, 0.05326048944205527, 0.03818466816277754, 0.06005383156720669, 0.008794471035681425, 0.023916952815207265, 0.08285552698878512, 0.025751662530726003, 0.08083764373535111, 0.024184168113635916, 0.05973992320979315, 0.027239677240891803, 0.053810440980258493, 0.047473706410176335, 0.06912970584967444, 0.06589905178594975, 0.053180092344841653, 0.05402971832682529, 0.04145292182182593, 0.023593548797972264, 0.02584042339285295, 0.0491717747683006, 0.005565166244313362, 0.020604225836934584, 0.0019166733428362698, 0.031159488679540735, 0.02318716788243863, 0.07815399943220039, 0.06736051771909961, 0.12257330945783085, 0.03629781275747284, 0.05505507721775963, 0.062140869577565504, 0.0011384941570858863, 0.0811358817642735, 0.018463605721931786, 0.0876192225804252, 0.05949338462444083, 0.062253338945729125, 0.08822420987510875, 0.04552222765801896, 0.01525808413017301, 0.011862266298022964, 0.034280741557238564, 0.042401568498462446, 0.06920293619435641, 0.020060002721185168, 0.056109413384429874, 0.03829357522209326, 0.03645613248790464, 0.07035761455734892, 0.01957786528603925, 0.04533596487054902, 0.026796704135654915, 0.05262475520853074, 0.029354891965105653, 0.036693784453335314, 0.07253521948211616, 0.03570682955004516, 0.06284213114169336, 0.04533885302202356, 0.01877704676571152, 0.022120543665462927, 0.05644229773972785, 0.033739071429496816, 0.02984023356299487, 0.028893078842590895, 0.0814799395119471, 0.036025093117308234, 0.064168217847304, 0.11850177430577817, 0.027551402247721152, 0.027217774787136627, 0.01784195026923572, 0.024759898510491176, 0.0341665982869604, 0.052685674520269524, 0.023735209946490587, 0.04961779498825631, 0.008828275622950207, 0.030372270135088798, 0.061102077334878914, 0.03448503422400644, 0.005285627464012754, 0.04552940207142984, 0.04480988463206638, 0.08244674247238906, 0.13817580086329292, 0.04432605797304742, 0.05175654776394368, 0.06114613122096466, 0.02900639090747122, 0.044783224772301414, 0.042772554236674504, 0.07280836047063913, 0.07563676474796188, 0.03372576065181244, 0.024756167662299933, 0.025090609091304006, 0.06027577873018961, 0.08490650524054805, 0.04168148415403501, 0.07653698700690463, 0.02559688978738362, 0.07368458119491417, 0.09749074812017142, 0.0383534679760135, 0.014046468197428172, 0.08333385696694737, 0.05233960196135506, 0.014673432639439501, 0.03043742208260923, 0.050168018487672654, 0.04217024441928633, 0.03667165600364247, 0.05612868432616515, 0.060467580333352096, 0.05540197332119269, 0.03225297960002096, 0.05261920490151933, 0.04591324659545095, 0.053555092383776946, 0.0795800184770938, 0.023381526304048397, 0.026191172918545145, 0.030116980910421382, 0.03865900299241466, 0.05570963806202335, 0.013595974981604565, 0.03789079300458393, 0.07620618258032107, 0.030061403146734642, 0.08413374469044708, 0.01994389635060103, 0.06781321439531542, 0.036208088539781115, 0.00359152959595855, 0.02184012101121968, 0.0867649502751808, 0.11657317859991906, 0.03243565709600526, 0.0019339336628740233, 0.049785717630818974, 0.08634193950603086, 0.033992351588582805, 0.005159729053341454, 0.011186041444870494, 0.03931226914808635, 0.04963766347857253, 0.06488193217064105, 0.03736447910928438, 0.022851841621882012, 0.03944089531057304, 0.04237438769890897, 0.046856469369583556, 0.04178607813833703, 0.02571688213896367, 0.06035399630725865, 0.01710313507505963, 0.02326260839078215, 0.03908859062639456, 0.03976653247410732, 0.05268123887118794, 0.03089697716096717, 0.04911490423124164, 0.05237530931950577, 0.05049374375131823, 0.06689455240003525, 0.026555570300608396, 0.02175788147254817, 0.03423722010226019, 0.025576519509477, 0.07084388120640671, 0.026017217333578778, 0.026529075149747155, 0.041123293340206146, 0.053673203989502885, 0.04725645536616926, 0.07700404017082146, 0.0401786303207759, 0.013495472864428116, 0.05952946353523482, 0.11150662546917317, 0.013983174013124119, 0.06815573996714047, 0.08020523049297833, 0.043893494087481694, 0.07490942555089151, 0.05745726464796932, 0.025981379740480936, 0.12074699415074241, 0.02300504196975981, 0.04524727104111545, 0.030724911897953962, 0.031695484010983384, 0.02872049838544861, 0.043058381641223546, 0.0698592437190875, 0.0352917286387134, 0.0458325737065846, 0.02449722228301389, 0.05246320258705847, 0.024015831783594146, 0.043081800949068806, 0.030362860660158822, 0.04368918992939495, 0.051169011952175256, 0.016660638859555606, 0.03846848075608573, 0.03936563866333135, 0.08968244291721814, 0.03626763272369581, 0.023734338521476717, 0.05854637737596228, 0.16328053278548105, 0.20277029684474393, 0.17844999299174358, 0.1335419801574561, 0.2012055469376426, 0.09223259639956298, 0.1417027777361293, 0.2282095180764314, 0.12662710967443644, 0.13971703187111886, 0.13362252664181495, 0.09717974706643051, 0.2009286061530152, 0.0752382687923889, 0.2076095670101143, 0.11420001441072072, 0.15612013878360873, 0.14280747652294176, 0.0747434449412169, 0.1175968023017049, 0.13324613232285748, 0.17591151468936475, 0.17905489601675542, 0.10218042429656753, 0.13187469704256904, 0.1493185650437109, 0.10303258219914091, 0.11567748392060881, 0.12826138206066626, 0.18433756255094083, 0.15770342801847767, 0.14543062286271205, 0.1566652869505267, 0.08752454943474262, 0.1546572479269197, 0.122864346260265, 0.0926401015491255, 0.11593298956511483, 0.1629814827033589, 0.1807879401190627, 0.2250905136667913, 0.14008784906998759, 0.06007890179452877, 0.10400428046141902, 0.08508236072356663, 0.10796276401848563, 0.14195865110283898, 0.19576551062205147, 0.10591963050706733, 0.2899578135580786, 0.13061665809683262, 0.16712891418607007, 0.1675464321048029, 0.1311718113720417, 0.18326709257258525, 0.12502459163266805, 0.18080214338917888, 0.12644159382269268, 0.13971393687590478, 0.15591271281723054, 0.077093159179053, 0.19725812569020257, 0.24775395320067484, 0.17146302597416987, 0.1360016586559434, 0.10659440841165282, 0.1885473689124469, 0.14146625575038696, 0.12437287297460342, 0.13625357900896382, 0.12923034538905467, 0.27248059008871356, 0.12345188973291267, 0.08973426110441647, 0.15444874943744752, 0.1227807277633298, 0.21873561515202447, 0.1519849340641691, 0.14373226722161617, 0.23133524873804664, 0.0757772269688787, 0.07971546282210658, 0.08275673229006991, 0.2222099311409458, 0.14531917239148773, 0.14052514737892535, 0.1933796523559478, 0.08679593087083871, 0.09056397263080844, 0.17481751048997526, 0.11054182199821358, 0.06848952447574946, 0.24196073503023197, 0.2223229444315357, 0.28589258330964273, 0.15201412201408418, 0.12698632830213155, 0.09494162119564512, 0.14757185393283445, 0.14291151126305904, 0.230229691932759, 0.2320097738336171, 0.10371897399665848, 0.16769379677791751, 0.07296402953685292, 0.16974937921810537, 0.14159966230152116, 0.16992965502844704, 0.1448582785744821, 0.08979599246935499, 0.17429362892383532, 0.14771249235397385, 0.17842607572674754, 0.2334749476323205, 0.07452343981112204, 0.2729370559175169, 0.1880823075771332, 0.09341011184357828, 0.07311088093105825, 0.12059059730100057, 0.13515188328681454, 0.10240649684302269, 0.0925368712013287, 0.09628858762763201, 0.07039136839129272, 0.09560697621876195, 0.13987320655536267, 0.2655575148040249, 0.10674921945939142, 0.17623627468222575, 0.08496930146770132, 0.14817946890909828, 0.23351426326459457, 0.11279822672687231, 0.10738765415284904, 0.10439663239183927, 0.10341843770396325, 0.14264497395244338, 0.14875656294245876, 0.15355385148957854, 0.13842386013317493, 0.146332997828722, 0.06076080048637045, 0.10244517662231961, 0.18856210844411006, 0.1124645647923312, 0.24413170563357495, 0.2388399226530906, 0.14114760913916174, 0.1577686680661094, 0.13446819577966967, 0.1394647591176533, 0.18429620912478817, 0.154180480768123, 0.17810002870617375, 0.23441460043672593, 0.1015281004290427, 0.08942244799747583, 0.12870686218863533, 0.1619083773825438, 0.08668774393417182, 0.09611097014238758, 0.14588255345100357, 0.14135108209185063, 0.08991324222616612, 0.13293874720411916, 0.13768846169114113, 0.20810479688788616, 0.11678811988883442, 0.10558077449639959, 0.11541437868389393, 0.11492967485420166, 0.20336441335178193, 0.11958656246743857, 0.09049031327688888, 0.23220500368024075], [0.032025428503871925, 0.03309120236325168, 0.055841087258511016, 0.05715569030613669, 0.04844091922765778, 0.12304954801595981, 0.051732393011691115, 0.043026091035215125, 0.051796943580190984, 0.06440143416365308, 0.06667152122263947, 0.03907823311765829, 0.06729417450485692, 0.029232289168923616, 0.03620680151206832, 0.04441359117927571, 0.0780105188248619, 0.0322235465019701, 0.01154853222561219, 0.035646864017772104, 0.04279723758959482, 0.05165217977557933, 0.04899884957159239, 0.07484295976258094, 0.02250213206054703, 0.02578623033308935, 0.03299189821606682, 0.0665662377592056, 0.07314185386583691, 0.020135992897614356, 0.026494526499581915, 0.04626868840967936, 0.03980165760543558, 0.010343987284408463, 0.015390302287414672, 0.0299589331412027, 0.0136468451349966, 0.004685524458651461, 0.020763122048529408, 0.06732769085154419, 0.0689480051157936, 0.0025363095553456658, 0.06135567159001386, 0.039315846778692744, 0.017821493806437622, 0.047674088198090755, 0.02550651247973644, 0.014917186495187062, 0.03582186914319473, 0.030293225183061538, 0.023892499288664232, 0.017805718140856876, 0.04983144924945889, 0.07526119780396262, 0.0540085283348397, 0.07891996478241298, 0.041300056637415004, 0.04016625800079877, 0.02313471958792258, 0.016649061355799917, 0.038333128341623855, 0.03339078487648118, 0.07559259211824787, 0.02836385189795927, 0.023589955845607385, 0.0729621449605592, 0.04496162366722861, 0.014483926427220146, 0.03387384544757586, 0.024302819811348474, 0.016539359480262767, 0.050118931403924386, 0.02219476417878703, 0.03777671868221895, 0.04519108615274872, 0.02296266964666786, 0.07731928535166287, 0.036271539772109646, 0.029294974313327865, 0.027247386000629877, 0.09383257102942276, 0.012545139836748282, 0.011857111483902462, 0.09534194810135711, 0.08718117350532163, 0.030920978695634874, 0.03931316164051814, 0.026377165660021767, 0.02652060413252442, 0.02401844605863575, 0.021305970036454742, 0.03545460276185505, 0.008553146636263739, 0.05300639722976954, 0.04033997992894823, 0.0595420235467534, 0.0556416554196227, 0.03223434068082321, 0.032837692377788406, 0.005090799813549365, 0.04025035913312628, 0.0572065202399127, 0.04988973321873815, 0.04173322573244091, 0.04422562001573463, 0.04384211640083983, 0.05140679798299267, 0.027934084233317166, 0.0637121580451006, 0.03704840655348474, 0.0605299705339055, 0.04370630433362338, 0.013080025298310625, 0.0464169915405012, 0.013972328123336118, 0.019453544537687016, 0.042534944406079675, 0.013517134958097051, 0.06878545658001978, 0.04069981525742239, 0.08682022351891765, 0.0161078623721316, 0.044927322080418955, 0.023714332135334134, 0.08833061182691206, 0.036750471129292445, 0.015681873436176007, 0.04353827443875132, 0.05682147295785047, 0.030798958126275294, 0.026215570903713667, 0.02701807098703519, 0.016029627558084267, 0.06797847488234121, 0.07805530432491534, 0.04446187004026386, 0.06261759460152638, 0.057193726571577216, 0.01671374982012616, 0.039113216522720554, 0.02189739374443889, 0.027977699534066265, 0.03723320994345892, 0.04478875975755434, 0.05507723631096944, 0.06258974347503916, 0.023837285416741526, 0.06138443053069134, 0.07439021712108966, 0.08712266737054433, 0.018796622227396698, 0.05903816368851451, 0.012054720033530988, 0.011097920266160322, 0.025434680245516282, 0.034148323259526686, 0.018190550918300307, 0.014172749173256659, 0.020444146019496748, 0.028310405773921844, 0.03535083998295088, 0.07337809239904727, 0.09286063527988811, 0.025619305520048066, 0.02205786809715773, 0.02389976563262603, 0.05175122345286993, 0.05202634860911677, 0.06006125112875335, 0.05210123753415481, 0.013730991274989663, 0.044876668346865524, 0.05479322070436132, 0.022279991460363233, 0.03914173797614152, 0.047670935746282346, 0.058295893437799916, 0.01634003872412347, 0.020564956169935967, 0.023767843376845125, 0.01834506893740787, 0.06169527836684739, 0.029642659487322937, 0.03115644156482191, 0.07016947102402488, 0.03200551787871988, 0.031351749935457786, 0.04911587333246585, 0.045572460043214025, 0.019961939636437644, 0.026443991509656754, 0.017812206905575532, 0.02783284188368388, 0.030037999160647876, 0.03471495636228112, 0.04140763453418209, 0.045160044270056876, 0.022338306073159463, 0.06387489427241587, 0.024018574378363067, 0.03696634704547544, 0.12613733434268545, 0.047321212778408686, 0.04821041869300027, 0.11212500398077312, 0.06541579586243437, 0.04127662966869051, 0.07068733879995924, 0.050811118656589147, 0.04635162891880159, 0.04052145083645179, 0.029615940255743843, 0.02944939082578546, 0.03527847914806297, 0.01791016082279384, 0.015500430299359706, 0.038692473373826475, 0.02624237632018424, 0.05213478452435905, 0.03616268633894863, 0.002877903612135279, 0.06314084797556843, 0.02593755376555266, 0.02380997246702112, 0.024930027486275763, 0.0324815534235489, 0.02874280686580366, 0.014043351177186256, 0.06022176570108822, 0.04555443016391608, 0.018811277489388184, 0.0644812222209669, 0.013237755141040732, 0.05264702155404995, 0.013126246255612182, 0.03593407804146409, 0.028381954555610017, 0.03577741306094873, 0.11430855374783279, 0.05103301602385698, 0.054175366962989496, 0.09430470335627757, 0.06830204743891954, 0.05182029777056268, 0.02398648678565458, 0.06199049417890849, 0.01698172354559985, 0.0362844368623149, 0.03973455596414786, 0.03180659548830121, 0.00736091512202796, 0.05648596092097222, 0.012876336883393028, 0.04360184824514774, 0.002824248010931056, 0.06594431226051624, 0.0441745717469002, 0.03352909055989116, 0.01304324924750554, 0.020617362329616182, 0.09867988511799805, 0.062046954858927965, 0.01738223431241368, 0.009309484176487933, 0.02697936439466092, 0.029282247677685756, 0.06266394292094535, 0.043619177153994965, 0.031727232609785376, 0.014267895378232484, 0.05162985214302617, 0.0437640980066311, 0.015618174182881993, 0.0077108554673501325, 0.0465722507496755, 0.024132560600616762, 0.08449235044780277, 0.03392883140834109, 0.0488400127318117, 0.05843539421837177, 0.027193327006253026, 0.02014790939527654, 0.040306379312589284, 0.06648764479905367, 0.029898460075679808, 0.05209459938229092, 0.06376981765272156, 0.04517795157528693, 0.02679723273632267, 0.03755805420599157, 0.03458486314141943, 0.036929398624887394, 0.05959864893567659, 0.03178526377004962, 0.02568948108913197, 0.0535735895767087, 0.03808621437318864, 0.01630625041622308, 0.022699711881878398, 0.049759233971276594, 0.07463169569570212, 0.04758882261211834, 0.045512858402705005, 0.042383266657951384, 0.018017568264997775, 0.022395040629611864, 0.007742144413397558, 0.040312025380591233, 0.038777122259019844, 0.09496927696971164, 0.015793529793529982, 0.04033817962232617, 0.04113465059368361, 0.09634455801137994, 0.05631994966778064, 0.017033991809453697, 0.044353893777776154, 0.033929072726037235, 0.026357919616144032, 0.0018845992763676953, 0.07069654717680908, 0.06381310162044342, 0.023333174664707437, 0.06264646079451328, 0.02786141696325954, 0.0838488212696487, 0.030446726220449617, 0.021428890759125355, 0.04561985024221001, 0.052433463053837906, 0.043895076059045336, 0.07293763780786146, 0.018738010755529808, 0.01834070606667909, 0.01903387965754636, 0.00431230892577479, 0.07240722151172739, 0.011228502825683644, 0.032204574334525296, 0.0388803104719808, 0.062134714061093915, 0.016577648554718303, 0.0774351944546065, 0.03651948795924264, 0.0070452461988034275, 0.019688909730663704, 0.01159249130831731, 0.06254925955868056, 0.07502529634943894, 0.057495032782636346, 0.031595252897410143, 0.022493618908488465, 0.34303587831316457, 0.10657879553975598, 0.12963894604434892, 0.10127138436561632, 0.1604664313697046, 0.25598780492380746, 0.17064282159891822, 0.0925351168599821, 0.14716791109211985, 0.09413154450275245, 0.19958144053816798, 0.12488296495810633, 0.2653513758653595, 0.13810210320497715, 0.16974530363034818, 0.15836226363335887, 0.10387691068312815, 0.15452814678991997, 0.08277429868617366, 0.1312266632674202, 0.20755286118195904, 0.1549461243614074, 0.16730640143636735, 0.19742602151968788, 0.08342685238007577, 0.2852772921323776, 0.09085523159874064, 0.1707994406141581, 0.23443442679220633, 0.1105112397682763, 0.12355934122517226, 0.16186805051420966, 0.12891680092340516, 0.09177213159179495, 0.13126686756168643, 0.10048353954428628, 0.16769002762533006, 0.12593446659945673, 0.1136982421420755, 0.11299493512318981, 0.1743438076828757, 0.11828020635631778, 0.14343122531089092, 0.11544198083180575, 0.11619837008296482, 0.19456111315277316, 0.11426283362051172, 0.07578343994194463, 0.12921790412116435, 0.13801363537148123, 0.18348666869344252, 0.07720924448221922, 0.10878216400141678, 0.1664684391430309, 0.19038732824546678, 0.11805974157346834, 0.1233752043316922, 0.12958219425091821, 0.07549802622487468, 0.1190074842663542, 0.09035914370249357, 0.14391212934447875, 0.17694122879014862, 0.15630306525816842, 0.1373203411217659, 0.178864783637466, 0.18391526424356047, 0.0970769610496298, 0.11490162837529376, 0.2309596511505304, 0.10644839205328496, 0.1404624047779268, 0.14727047494342252, 0.1354059640077814, 0.1333245644045453, 0.20603203875643594, 0.2615012631060616, 0.12845506440968285, 0.14449611816915775, 0.14012250688768205, 0.19890475507465102, 0.1498406233205911, 0.09722386606998983, 0.15622541458616335, 0.24305047978076244, 0.22896560089242077, 0.06966201438298149, 0.10402431366063895, 0.15358556752964375, 0.07765529917613154, 0.129536121723152, 0.11224224607670501, 0.11014206965844478, 0.18816708286683406, 0.12637678278429856, 0.14501714988821937, 0.21337057884422042, 0.13259414553401933, 0.16046794822379468, 0.19915229340474452, 0.21283436326249955, 0.1796294619599658, 0.19752942806770726, 0.2299665100872517, 0.10124044207435462, 0.09153549469286397, 0.12538823058768628, 0.15162032217748705, 0.169128495598993, 0.150973039168504, 0.13709154130230028, 0.13535622957973711, 0.1441610006675605, 0.12014845731638132, 0.1699552576868765, 0.11357060423301113, 0.10290117513748909, 0.13321027940800115, 0.2004471045708464, 0.18186208731945486, 0.16345277999437627, 0.06551275195013131, 0.10923679888008103, 0.13482926834014156, 0.11536446805562704, 0.10370710729471139, 0.18597528999370916, 0.16309907719973596, 0.13440082600760844, 0.16075311679272883, 0.10226540643000796, 0.09429547965766923, 0.10321018436262686, 0.1930635491566312, 0.24316517846478572, 0.1474760776205409, 0.11252464906823252, 0.23432164332799374, 0.12994829234817337, 0.13005710747693816, 0.1148401038540948, 0.10799513889416572, 0.14946916260786597, 0.09444655985721657, 0.1791086753890399, 0.14394329380123846, 0.07273961940119344, 0.20568503157025386, 0.21467911830592543, 0.19261639895698718, 0.15628164543980555, 0.1131431578147796, 0.16511014993152312, 0.13821569872238945, 0.09278293098172835, 0.17167108013264595, 0.10448439542444483, 0.11571930466039528, 0.09317394991916034, 0.21196085448947646, 0.1723469228994462, 0.16529578835733477, 0.16764465989845415, 0.10483547053750485, 0.14481574537292605, 0.1001007407302818, 0.17208337333173523, 0.12816299338855092, 0.24764864675460324, 0.12108566630030833, 0.1163201550802877, 0.18551589770903512, 0.1221700024700934, 0.1314388389789289, 0.0990597268326148, 0.08590634957316422]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.026756700939468803, 0.02129417036720101, 0.08242740641318022, 0.055944792580820864, 0.11282923796604719, 0.03557490537904444, 0.010121420547816782, 0.04589892458170653, 0.04720755214352281, 0.028877839438557148, 0.021236497353041367, 0.04960581337312057, 0.003689212030768695, 0.06817132985639958, 0.04205132459080027, 0.03153246624635593, 0.04090826395117948, 0.01634812095172463, 0.04574752262523098, 0.027664890512824062, 0.05735292347268232, 0.12024609522233087, 0.031674977752470204, 0.07289600859005606, 0.05815048611933186, 0.026278983831645984, 0.060639858185764284, 0.041048929185396245, 0.03672502934932709, 0.0038993714946216995, 0.026150826898012913, 0.04976299163254519, 0.07349135849865214, 0.049856316463481036, 0.0476732914666495, 0.03668362995789897, 0.03935928779443906, 0.0048112988588400185, 0.03907637535444191, 0.09202453458020765, 0.022729248401799032, 0.06732664131108793, 0.07985034792293465, 0.037322102955752806, 0.11723622769838381, 0.05126300711004485, 0.02891032156654664, 0.06219087596682291, 0.028700350273040034, 0.00726128634508519, 0.03203200536870188, 0.026559467772923173, 0.008296894056031541, 0.014544305646972311, 0.014278753716949255, 0.025853600105150573, 0.014053052723137362, 0.037865014145931894, 0.02483387004523989, 0.012473840991245403, 0.029516456077896783, 0.010570639184856368, 0.040926810939826315, 0.045628836453561826, 0.025681385454992135, 0.03695243105833088, 0.08035186738256486, 0.08495073149641676, 0.07327923641329812, 0.05977384941351991, 0.0804079450186222, 0.05755628917306181, 0.020817684745716474, 0.03796736732305538, 0.01805792386162906, 0.08665683994730634, 0.00932135853931428, 0.05869833474618293, 0.044639659895291256, 0.05136313863218792, 0.042423221973642226, 0.058114656187113256, 0.02359846708244614, 0.022308997464396303, 0.03145073998659369, 0.060954555613739844, 0.04227760015055538, 0.031996073929833314, 0.03186375139311197, 0.01661565992230129, 0.007292581036792047, 0.01415448659475172, 0.010610805174726392, 0.02818934281446761, 0.0448106047547152, 0.09245383493121594, 0.03134928696278123, 0.04779201211227525, 0.05630211131046376, 0.020728694057212244, 0.04891375635540293, 0.06625008859461354, 0.007315542128297591, 0.043347051231971676, 0.0478378548136642, 0.056581645302714846, 0.03818759078820867, 0.014896186109962723, 0.035200916576169194, 0.04167325636972824, 0.030841173401342768, 0.004228466826926677, 0.07160507382885103, 0.06148175051015231, 0.07499484435444878, 0.03199125906722921, 0.054142842700164166, 0.023061345601754806, 0.0986130822510008, 0.02502779945761206, 0.04935311161041741, 0.025702776545057857, 0.058507781866337025, 0.026881259175077565, 0.03216947218583476, 0.033858274710514856, 0.03512220870282862, 0.06335386638379385, 0.04375230025259718, 0.022441930956237262, 0.04981143520243707, 0.037534677032982154, 0.06832901373385422, 0.0584234623989511, 0.004083981686797474, 0.04701744359467299, 0.027543295122262453, 0.01819643255833897, 0.01862911135709334, 0.027947490771992073, 0.07182884811153335, 0.022301493633177974, 0.012880876911954295, 0.03560599322701174, 0.0012822026755818497, 0.01372791064392415, 0.05589099022589865, 0.04997704042902878, 0.07752401468854758, 0.029201528823543942, 0.029464507655751322, 0.017628171518745444, 0.06827762455589349, 0.019408852883404302, 0.057164818243754495, 0.02067384024661395, 0.045182471494040186, 0.012136058461281561, 0.08094921678064332, 0.0880866434665457, 0.04254148679695303, 0.09325210620919544, 0.016655586509694977, 0.021319008852925994, 0.025126381566928282, 0.023582268153287234, 0.032071962599612536, 0.009353791829198599, 0.029703783727581465, 0.06937712160570007, 0.09093225407864779, 0.0670556377078737, 0.044620741354001146, 0.008792812455325358, 0.026135786676839478, 0.03753474598089534, 0.06981412880122662, 0.056141554603293065, 0.08189104527475373, 0.03854724991646025, 0.16430548181937588, 0.0010601328188298092, 0.03461701202116186, 0.07429945868470016, 0.04233954985055231, 0.013489413108947057, 0.08013046031156856, 0.05777594956359076, 0.06127908194978392, 0.09178542321728123, 0.010525230280754548, 0.030116316329147068, 0.02517251346650864, 0.10905054758392996, 0.03660363122640598, 0.023616387794214874, 0.02839722843360036, 0.08851534626897305, 0.07722123375823421, 0.01778595307241044, 0.03522403710972398, 0.010069415626686909, 0.037804378286725095, 0.08206264896979255, 0.05345751959530096, 0.03449967799467906, 0.034414829926625375, 0.0620014837101823, 0.0369337308520992, 0.006095167416553464, 0.02154570384581964, 0.010734221939327977, 0.031611267965467225, 0.027715101830601215, 0.024788509979243242, 0.056704257674995935, 0.04130524305266239, 0.03159734240222362, 0.06983699652576639, 0.05342104997966559, 0.02778843176671334, 0.025093478090580434, 0.0530098790993854, 0.05110025173053146, 0.029148375728137554, 0.07340483652848391, 0.054737296285888845, 0.019134771521954287, 0.024294057680714517, 0.01824993996941034, 0.06878161847951912, 0.07199804629048995, 0.06277317556762887, 0.041947799299152634, 0.017750303170854048, 0.040960384743107904, 0.04473830137642161, 0.017427609700168815, 0.0153509694181623, 0.0008795478201899378, 0.015832744876763994, 0.07011117939386638, 0.046046113054598534, 0.022932066349312667, 0.04120896495277843, 0.06056525271325823, 0.06000782798735365, 0.06105995782080197, 0.05385715319144149, 0.011411491544887183, 0.015230072125221695, 0.028289598825898384, 0.013360894198769764, 0.06336883191139468, 0.02231608952335533, 0.02146373626836125, 0.018365873970211517, 0.041535632504570874, 0.03152158396739153, 0.04660873568706936, 0.04375103620752212, 0.0484822649929312, 0.011541391328547992, 0.021689795408277743, 0.03656761743308556, 0.026137203939499396, 0.03070510277945188, 0.013460764293408683, 0.017473360471006845, 0.015026861557646867, 0.06157232508543999, 0.0610659945936453, 0.06129633041939909, 0.0666444476753954, 0.04149603725020443, 0.03789763416974776, 0.04101257065250989, 0.007482307499289634, 0.02256484401802863, 0.040091219688615495, 0.06283942685132066, 0.027054274387116876, 0.05888722138479353, 0.019158284675570268, 0.04821465515922155, 0.031249130542780605, 0.03981364688145057, 0.04845742842242603, 0.06409170864630612, 0.029348667500720873, 0.051643208885986, 0.01701539502509179, 0.06698072963063756, 0.015186437672274488, 0.0601196231981439, 0.033554141635015126, 0.058085855111599936, 0.06440941679982409, 0.03522899369859407, 0.007146412897254191, 0.036781298507365494, 0.027953381988129793, 0.054123824567443905, 0.06436247859270343, 0.06571938118506825, 0.020046992633011074, 0.06468110222129092, 0.0313616133174829, 0.023571111997889898, 0.03519092295919696, 0.01261064897276341, 0.027525272903843757, 0.001635367532857814, 0.02583223008250277, 0.0539997949325029, 0.045087170156259695, 0.025193454479918848, 0.018019761191681027, 0.046986585573082974, 0.02341458491320091, 0.033270168163242846, 0.035728620921051314, 0.032037053888122884, 0.031681326706142675, 0.016453940676705494, 0.019287253662403074, 0.019482475848147468, 0.03484298114574725, 0.09687817655503751, 0.01598917524285254, 0.01773714369553472, 0.04798304762751345, 0.057094541168020624, 0.02408858332332344, 0.01716319636832322, 0.038062848691498084, 0.0600075675174594, 0.034715335575803634, 0.042738953620315566, 0.06698226180648612, 0.04432742160955264, 0.005323693415360345, 0.0294805935869414, 0.0624940705846154, 0.043393897508541425, 0.004943585963994866, 0.01879190121056332, 0.03292478125302061, 0.0901949787211995, 0.04285757467451115, 0.053322232298312656, 0.02160461792241662, 0.15262611901327489, 0.18286987598384583, 0.2033166401088238, 0.09883782180446772, 0.25987164087353215, 0.12208120521879005, 0.13673503462585712, 0.16574074754551535, 0.11686413113268153, 0.09425341376974698, 0.14188409542604802, 0.13564285371572743, 0.17326443576283995, 0.21117814245723912, 0.13108247019831212, 0.1648066258959232, 0.114524467968412, 0.22144422626062749, 0.18538311934999882, 0.15807364766876544, 0.108585762040269, 0.21285045110890943, 0.16065056826318466, 0.15577576693988618, 0.072179785328767, 0.12277750253316858, 0.12699098611671117, 0.1993166192645027, 0.11203713369585815, 0.14871134843316772, 0.14590040329963933, 0.1262956617339965, 0.2135832448520007, 0.10813963073756426, 0.15809731978562572, 0.07799571034528556, 0.17399028874933722, 0.10582442109983776, 0.08370520276648384, 0.20305114467778515, 0.08114104519688314, 0.11225909235015993, 0.1510398880007767, 0.12392061296850444, 0.18749583662757952, 0.17600585075636066, 0.17188788301521735, 0.186416250202925, 0.09952802871984821, 0.10118945892299376, 0.18595397742765565, 0.12131926949105917, 0.07741702284904257, 0.1428895245396322, 0.08601628319029847, 0.16972670301554665, 0.1925222467510931, 0.11196840794817095, 0.10537818254482363, 0.09649990532066553, 0.11210899274315565, 0.1140474173570833, 0.13939366615828008, 0.1437763019555038, 0.10626336649781275, 0.12508543433561442, 0.18903737407057516, 0.1413031862748246, 0.15001218105035444, 0.17982469180658942, 0.2033838260197832, 0.23760840567129277, 0.192572915806405, 0.12420315385585833, 0.1283073703187608, 0.2602602619557612, 0.1401354231300854, 0.1150023612764574, 0.1653992408706296, 0.09790883294396824, 0.11679313010385922, 0.1649084083375431, 0.13268535596228417, 0.09238654942882639, 0.16602513470476674, 0.22392282713084455, 0.07400715783719095, 0.06155489658516261, 0.12430720391773409, 0.08228373428386065, 0.07528023508888099, 0.08377123188467757, 0.11752420781000007, 0.17470958402320264, 0.1997543159391611, 0.14492601606874697, 0.11649706010376254, 0.110871707119288, 0.17184248464482446, 0.11147597429132271, 0.1309182056255879, 0.1546021968486809, 0.1457921244324215, 0.18453996298053574, 0.09425549752890103, 0.1939366289204167, 0.10577801149338485, 0.21877876122391995, 0.15051484198099183, 0.15891723304746613, 0.11637520615852649, 0.1607449656172145, 0.22298413959722366, 0.1255020789141136, 0.17818406855146732, 0.12233973691059698, 0.14197158266700086, 0.13477317538232575, 0.13738458525509606, 0.12972315442898583, 0.23734692454097733, 0.1352926902472973, 0.14477653699296136, 0.12406138162459097, 0.10568945939021726, 0.11980996902791724, 0.14766494893739301, 0.09849287539480195, 0.1183754770505813, 0.08152654064038108, 0.16283322936825215, 0.1512424110044395, 0.11472720547669357, 0.12697411686061852, 0.07887381564585433, 0.18863059670454074, 0.12062557687562321, 0.16064762648555542, 0.11059762384261816, 0.12163443806310817, 0.1070625264377844, 0.16777325541742388, 0.17144038041512813, 0.10101456871075977, 0.15304748269338764, 0.12015738990157844, 0.16559583435375846, 0.1830851007252932, 0.3240226791991342, 0.13522803242648804, 0.11641282873648791, 0.12038867184591871, 0.13131261833252447, 0.11972909312575095, 0.12575412950208112, 0.09218624041926476, 0.15317094542326468, 0.21141276454492924, 0.23059661740497236, 0.18015144362805352, 0.2100542301852857, 0.2370336099017051, 0.10930350981652738, 0.14133361528717703, 0.1417820065492584, 0.11075516982424645, 0.10565608093935637, 0.14073264995409598, 0.12686613676769118, 0.11656478227626894, 0.17626334822946982, 0.22362227551639083, 0.2548384738545264, 0.14012292057516115, 0.13554850232697305, 0.113420098599407], [0.049844706400988564, 0.04684074158449808, 0.03698162283868559, 0.02408156595793703, 0.0336242042061302, 0.02348944894038141, 0.03375992817323535, 0.10919922992827431, 0.03598773867012032, 0.0022923727961061823, 0.047589833848178394, 0.03324780222629348, 0.05833901269661804, 0.039797149178001194, 0.07384029622640341, 0.017583541151496674, 0.05109953160788264, 0.02205712690709099, 0.02513563399383378, 0.02722281373045858, 0.03011929832639233, 0.015232176951793654, 0.06928846225022309, 0.017865978616980777, 0.07401713996284431, 0.05754317757823775, 0.07832256175817982, 0.04087157217004607, 0.07310207858080826, 0.05415362538769842, 0.04631367692303273, 0.06930065836997763, 0.027323824338494774, 0.04128111511348717, 0.03758410119541711, 0.022331572160305038, 0.00377648979455473, 0.014318653491265593, 0.03900104592884741, 0.040320942644029856, 0.04208143950710374, 0.016723789402373856, 0.10366930851652738, 0.0952020068202288, 0.04338312248188642, 0.027506229873265953, 0.04152147136929055, 0.07338514040795065, 0.05772277157032683, 0.06866815319705395, 0.03383973538274727, 0.0457552945872228, 0.10504844298045482, 0.021276483312249187, 0.01506647596421141, 0.012479531109302998, 0.03760433357749735, 0.043468299967747544, 0.017992764253229383, 0.014953170602600423, 0.01689996855754045, 0.014483014782590252, 0.0816967117510015, 0.03027946432872165, 0.051004394979005864, 0.0730568410888795, 0.04743587315803574, 0.0340184636954819, 0.01803817411494111, 0.034205982867147655, 0.09403829628060903, 0.06995733361691236, 0.03988378223091845, 0.045148702338337905, 0.034144584750456196, 0.003980187067363953, 0.0507065553158041, 0.038834640140374826, 0.05744022685253332, 0.06757871488169317, 0.013033717198507681, 0.040701630885802934, 0.07896554701390766, 0.031965947522210984, 0.046026581642969, 0.04424962155040234, 0.06060647207402414, 0.07151633020370238, 0.06634498390579416, 0.05959827355259369, 0.008876828360371292, 0.030813236089964068, 0.014193701677985731, 0.05041704302833927, 0.04890648235056189, 0.021203080597784252, 0.10415012828044354, 0.04963242726761007, 0.06489739948583227, 0.037874670684217446, 0.05250162955734038, 0.029721072416812665, 0.029180313933700807, 0.08354528957316953, 0.0272728756610905, 0.05023653356118068, 0.03752630752240939, 0.010951138777478088, 0.014981840485556713, 0.039316191518258665, 0.049156391722781044, 0.014204238259774304, 0.03117662989684651, 0.06883953472659474, 0.04137271624659339, 0.007301263206998908, 0.011455487974378611, 0.02962346515438009, 0.04787278842301138, 0.016292386140013417, 0.053885935114756714, 0.030805791630559874, 0.02121336724338753, 0.01899208190039762, 0.004711631298696082, 0.0749923775513326, 0.0623318859406056, 0.04546895773420411, 0.0177241470138993, 0.021610512968993956, 0.09037703951640476, 0.048636080126368234, 0.05110907706341917, 0.015029633838322856, 0.009927143523048972, 0.051949222707339836, 0.07054992560898105, 0.013119825481196806, 0.05263232032678301, 0.0223420713953073, 0.03236138104130665, 0.07163822245333465, 0.013066526829084803, 0.007595316480634915, 0.0489954328194501, 0.085810488991199, 0.039795601680394144, 0.08642210294642756, 0.010795552065716156, 0.023385640196201783, 0.02178925660348708, 0.025674881368514993, 0.08150643083236872, 0.02986942725856939, 0.019062165538930607, 0.03918193843996814, 0.027172301723171147, 0.05595180994620728, 0.05977903199832767, 0.021727191990301497, 0.061967894585142215, 0.04419208068640963, 0.04778243601322175, 0.02851719205688325, 0.03365313551659065, 0.030927678134532708, 0.027362203428281412, 0.07370969355707208, 0.030597930909284664, 0.056879174700307275, 0.030676889676420443, 0.03789725878666486, 0.028653103715529846, 0.016194472442411127, 0.03628339498273788, 0.0038902418811865634, 0.05654221858769175, 0.015144204202618812, 0.014407719830952346, 0.024037485258773934, 0.029359536373146602, 0.019730565761546456, 0.0975009294286851, 0.10371495969593526, 0.046561996662809, 0.039102870505303144, 0.07211099829404585, 0.03128049801284027, 0.03267246636471922, 0.06033323149407103, 0.0878020954288302, 0.09570902679115535, 0.0633135701589767, 0.012537138048379172, 0.025921577001891793, 0.0492583618559424, 0.01604166758742424, 0.016365488164968068, 0.05911951456519385, 0.02602102287534264, 0.04542667351122345, 0.03834889443110555, 0.05213136394177714, 0.04044568857118007, 0.07011417479765031, 0.017674809036355828, 0.010362610881847721, 0.06349676859474952, 0.03367000477268331, 0.011248997592877959, 0.04538247023799247, 0.07170223676028752, 0.0671176678471027, 0.026106968364347855, 0.02213634805934083, 0.056302314323763696, 0.036777448915545984, 0.027082477914049264, 0.1372515464261655, 0.020798511480191545, 0.03475980697980812, 0.06831382221031575, 0.0712932454001519, 0.027347465811838067, 0.03136282948206269, 0.038170721532116016, 0.04369203594603366, 0.07215046714390479, 0.010205593500887195, 0.01979378333705808, 0.011968356068997134, 0.0715738021197819, 0.04522646409309199, 0.028316007791868145, 0.0629387654724621, 0.04238626206173532, 0.08984951137174522, 0.011690658772544516, 0.049476294718202085, 0.05646749437155743, 0.07474196639152304, 0.0811258613342239, 0.07861942082883851, 0.02138745306330102, 0.021500479760429552, 0.03137913757875081, 0.052275254406155124, 0.023089698515832428, 0.06178839252360406, 0.01318398055680577, 0.11552111005350468, 0.01568918861824298, 0.035799832624052806, 0.009115843004697274, 0.06271062065817176, 0.04691937284904623, 0.022497876442127654, 0.034139421317846544, 0.012330772156166214, 0.038758460357184374, 0.01384729108277468, 0.062493863740875844, 0.025095581001932585, 0.0709884879629939, 0.019922602936745654, 0.05474583050536533, 0.06148466164426458, 0.022178758686829, 0.08163920153052577, 0.043750840855101426, 0.011011050683596443, 0.012068105504787978, 0.04571903947620623, 0.056332762488314224, 0.035600546341870105, 0.05010705321065841, 0.04690498954826786, 0.06078069578976401, 0.03376175146249514, 0.03837720137990771, 0.024018183673521685, 0.05588506070536472, 0.032594428818312385, 0.020168683784563216, 0.011637029745015166, 0.07212710146221422, 0.048006639305141666, 0.06025553102635088, 0.05629825788820463, 0.049205091932127555, 0.05055981883478742, 0.023254179508395256, 0.035067984999548045, 0.05479097223630356, 0.04270160683400689, 0.020499597378675977, 0.03819214518091852, 0.019606909594468532, 0.10010546749277462, 0.030926741592045275, 0.09007039750295301, 0.05193639456504776, 0.012313968975157028, 0.04484912748598764, 0.02361577875431507, 0.023964781599539905, 0.05177474235214534, 0.06584323461978667, 0.0485234996754556, 0.04048537958653704, 0.015599732531324751, 0.03454591906178863, 0.025760777061805133, 0.04098938500148155, 0.07811740341205752, 0.023321016849349105, 0.05244032337119984, 0.10716496005413995, 0.038512856399099675, 0.03800036656039377, 0.053147426355750337, 0.06095521444935472, 0.013686543811232814, 0.06158979189011359, 0.02873217931107408, 0.04337194525907117, 0.04418678318841323, 0.03760793802118109, 0.13345820078205678, 0.08552728926823025, 0.034355385334140835, 0.07180153707703275, 0.047078148401792974, 0.06835593406351344, 0.029459520423364256, 0.006457708471815192, 0.05086078030628063, 0.026797269125499075, 0.07799737275608125, 0.07743321794776187, 0.04165040013650733, 0.031278937108694546, 0.01002186837966644, 0.008702710939330921, 0.01109354398889287, 0.071265198921244, 0.07012549757717118, 0.009181533128984514, 0.004335239852568316, 0.061785902737850146, 0.05656968667021683, 0.00671804525829371, 0.2122725909876247, 0.12249286256490216, 0.09442327078431846, 0.08526188576774252, 0.13060990120134047, 0.0783469693194474, 0.1140306476924208, 0.2226859781770937, 0.11099572143247051, 0.06671876586492985, 0.24304502523474156, 0.13391773096255719, 0.2118769218964923, 0.08511645163619712, 0.24464392734150736, 0.14652101112709892, 0.16896234644997507, 0.1327927308457513, 0.1508542189314481, 0.135610279657187, 0.12286816903900717, 0.08311520015159923, 0.2911420935584653, 0.11172358156932939, 0.14160401368093106, 0.12563218362629414, 0.21168083403139346, 0.14563824801195055, 0.2391447337164033, 0.09002554305498639, 0.15325331519688332, 0.14321920281696704, 0.1001120328662857, 0.12329408328139013, 0.10565959728292881, 0.1465374360521955, 0.09089152884459303, 0.14833427995683687, 0.1564581980628352, 0.12352148115995432, 0.1401243608204588, 0.1126768783996663, 0.3090757522131166, 0.15841584382278306, 0.15691434213471028, 0.18372023357979714, 0.2382407959310278, 0.14962994914141395, 0.16839242299958584, 0.26722510435408164, 0.11132731492961608, 0.1492743770922384, 0.17903638733250482, 0.10621167854556154, 0.08051683675617942, 0.1224372982077541, 0.15734955668449402, 0.1379053871477804, 0.24245723661395813, 0.14972181840529367, 0.15085734457017916, 0.09921183358998069, 0.13444469220215274, 0.12212972156703474, 0.25206782494581514, 0.13930633213491211, 0.13239183703497534, 0.11068091292174594, 0.15106550598096463, 0.09584724437445404, 0.1276237517595291, 0.09237110509627289, 0.21368475150196783, 0.10702799119415785, 0.15167177264248172, 0.2277131390667731, 0.15768939328770484, 0.16123544574985582, 0.17361033978241106, 0.08377624209970237, 0.05203885882492027, 0.2555407926199898, 0.15805562928078637, 0.14338745104689754, 0.13052998290907952, 0.12648365971061493, 0.1610127439902675, 0.21580745856608116, 0.11333330083758601, 0.13373236832839827, 0.1491934628856759, 0.09673515560045358, 0.18293525392730392, 0.23557192946393646, 0.1562591071330732, 0.11463344397564089, 0.22610271499762613, 0.19045474398280346, 0.12308471145168429, 0.09707188954757107, 0.14489400891527054, 0.15569666070082497, 0.07937593265406548, 0.15177779921120213, 0.1927002855846959, 0.1575907518065745, 0.16612202950542973, 0.11908498172077442, 0.07480632543804185, 0.16269398522713494, 0.09800819454774742, 0.10398263847755809, 0.07692776079620085, 0.12063821732637384, 0.09281125325228899, 0.07725207645806574, 0.1274612185455138, 0.142880683884986, 0.1063953711080455, 0.09772779104570228, 0.14162341102717385, 0.08650115555933408, 0.13957850785265047, 0.07964109866729668, 0.15236715065135112, 0.15143252338372892, 0.21353804566446813, 0.19294457570199045, 0.10520657118890556, 0.17171859290570984, 0.20971399521635425, 0.1296971993701112, 0.08485895416308796, 0.07469341939976139, 0.0797565940827612, 0.12149465766044394, 0.1344820006840652, 0.21228828046831394, 0.183828451159981, 0.09045016260877733, 0.19245141426161413, 0.2013846123290639, 0.08793702649493372, 0.08064797568705775, 0.1307957541317709, 0.19635457094878922, 0.15455097621006353, 0.09676298757474269, 0.19431319177871753, 0.18712210829459852, 0.1542418903761333, 0.11215121184866275, 0.2412155919498013, 0.23202950825854657, 0.19586635843640376, 0.15467538888896668, 0.1109370161148329, 0.16717460366987413, 0.10682955910001071, 0.12608363924007263, 0.13355227637915842, 0.16117566024824498, 0.19582676701247695, 0.09829006893860717, 0.10703362960128054, 0.1316474447207105, 0.08460347916209891, 0.12287215269621342, 0.1350067249469219, 0.11750821955502035, 0.19699759450891327, 0.19533689975017504, 0.12816835600402088, 0.25614019513370534, 0.19840301344952277, 0.09974334539184648], [0.03024177280284705, 0.07452808996482242, 0.016921369223705223, 0.04728825950634576, 0.04521069034273106, 0.044108745642006404, 0.05075410256282457, 0.025683356216177348, 0.039604148647237214, 0.03403890675174133, 0.06722175621337469, 0.04778800547243126, 0.03142251922268301, 0.04198428423654649, 0.11310001174288412, 0.07231159075613945, 0.06750973632499095, 0.018648956864771825, 0.03384437021468917, 0.008629208633435831, 0.06141871679574252, 0.03469239507291106, 0.038844878905482834, 0.028293241573978337, 0.08254020519915127, 0.040995728209494584, 0.04465248803758333, 0.047857137246718334, 0.015398461123808257, 0.012490149087933524, 0.06463797147115392, 0.023938477970659736, 0.038362825740008585, 0.037224009227488315, 0.06000524244060921, 0.04193888586615363, 0.049519360350865516, 0.015969964630541303, 0.06528797409226818, 0.01265334113756375, 0.03088708696586471, 0.024702219750672102, 0.03910229593935994, 0.04052800088820439, 0.019007915022572684, 0.06511673811943301, 0.0806518520919546, 0.04272597226043863, 0.02196533042156408, 0.014701219606063059, 0.010243885448172448, 0.009001615464747434, 0.055223666356816414, 0.04752616811123106, 0.040647575721865704, 0.07603417285868237, 0.0703115803339789, 0.014655748457317392, 0.05278448837118284, 0.05924738996151475, 0.0812310758497446, 0.03861303388651821, 0.05245773271927911, 0.045029954879634806, 0.017227865680451357, 0.02262952673669544, 0.032173180051388285, 0.0673081479485958, 0.07282884566173439, 0.060831782362994656, 0.03650326987788562, 0.029052191474024328, 0.07613666010119262, 0.03855378081601474, 0.011227978055455513, 0.06486450367036366, 0.02961783249291682, 0.04616879437479281, 0.0266899076485706, 0.08623665604259699, 0.005748180340179393, 0.0638269333379163, 0.05243134865116689, 0.08930312980326915, 0.011501241618046358, 0.03562013521009395, 0.018878997746674765, 0.056516558472667976, 0.10726223023788584, 0.055232376776515484, 0.029656592711445787, 0.025873671608766722, 0.027173506396432078, 0.024802795603811264, 0.029374329530964458, 0.022426884989404393, 0.024041447848562273, 0.05362793968449678, 0.019463331310919697, 0.055617404906379606, 0.015015669013073128, 0.018548415485589255, 0.0764084451140896, 0.02325295951337584, 0.020366876476234006, 0.058712875094985774, 0.04906043154938568, 0.09443656240980472, 0.021067450476449825, 0.028128199422010974, 0.049637606021978205, 0.013272421577224329, 0.02519963297902817, 0.021751168627111662, 0.04768711169280353, 0.02524087723765162, 0.028532425715257565, 0.03935244662927524, 0.018542595132584536, 0.08292871136819163, 0.08091734752299325, 0.043349046891014424, 0.038964595465410146, 0.04207614583954696, 0.0022088840553131438, 0.10679477104736913, 0.042396516148601814, 0.008954305704983493, 0.022103747187723077, 0.006792425213667054, 0.03643478927833419, 0.032171272492456826, 0.044775816702073624, 0.04451253909557577, 0.04198860114199981, 0.02426114654348743, 0.03526716785986097, 0.007473231751411673, 0.031655059466438915, 0.039010629688780156, 0.04935634067101825, 0.05257158487614605, 0.0638245354827133, 0.06135855208060915, 0.022985654199616085, 0.04551756601299971, 0.03772197786958949, 0.005132617201701168, 0.05648144483265858, 0.02761938872056142, 0.04130055459456579, 0.04466062772177881, 0.01521490166910113, 0.0380225831101979, 0.03370029588920936, 0.03656316646224549, 0.028499355614786188, 0.03340697997520047, 0.0013790920896891265, 0.0574998744583178, 0.0027562926604127094, 0.04304176902458553, 0.05414205362960216, 0.016866057675572175, 0.03399144377439253, 0.045603816021954825, 0.047471921425312764, 0.02890464677024753, 0.03798405271804622, 0.07078938171147339, 0.031066184916022806, 0.09218231804909245, 0.07634461466823855, 0.09646582972979355, 0.07292396313841305, 0.08729911274126462, 0.00792823147944986, 0.05236475262790919, 0.09869567419011747, 0.05787666331255629, 0.0064980238488304524, 0.02434825457091774, 0.03986055827549389, 0.06867489477078761, 0.09187766786424384, 0.04623257502492878, 0.02374186150489315, 0.05913572498567163, 0.06687758355251243, 0.026574015782605258, 0.02632592012354684, 0.05118394300581948, 0.04009708409167586, 0.04835409465275946, 0.025493609643871748, 0.04047791405971493, 0.06859758117746922, 0.06496393422205603, 0.03451868463608046, 0.02916065420234396, 0.08712446001628715, 0.08302880841637812, 0.03291995872953727, 0.051448469335633906, 0.034798659128888, 0.043058837463538495, 0.01813115420631103, 0.02726956807647742, 0.03295643600605188, 0.012570601726521649, 0.030360296180832292, 0.03533539181995777, 0.05670696962624789, 0.012504894365256113, 0.041257822210149425, 0.017000337566940055, 0.07967006445171372, 0.010809864503361527, 0.037904134425785274, 0.04258174854781359, 0.03151940636246676, 0.017921690446054264, 0.06380255258972607, 0.08711863008718337, 0.04217957920064369, 0.04172729621190698, 0.03318218296513923, 0.04681760189874519, 0.03491360679148667, 0.1038040787041668, 0.07845540140425006, 0.018776571791198467, 0.03445423748945037, 0.018103525245321855, 0.05201676484918402, 0.04102955482179119, 0.04745812418179647, 0.03394981455658713, 0.02194185940278394, 0.10161934916170375, 0.07128265040415911, 0.028286406154473944, 0.09265371493153995, 0.0706588556509345, 0.02654178837885059, 0.08280333341850389, 0.024895777610400995, 0.011959981770374844, 0.08926097964567524, 0.043836569924268036, 0.026422083310242143, 0.03999240583770218, 0.053538671289119995, 0.05309658110021584, 0.04006951641772063, 0.017711012436437513, 0.01914737175308889, 0.039894714305597934, 0.12837506184775022, 0.03413266059191477, 0.06070281146094204, 0.047955169687948884, 0.06313743505386576, 0.012536903433952362, 0.006324489133417487, 0.03941868259120853, 0.046762313333249865, 0.022973892834758567, 0.0728562486267859, 0.027307742237744313, 0.05625006712732777, 0.04800804507648272, 0.03505950440622626, 0.0687757808895361, 0.015786530622731776, 0.022105062943733027, 0.030794597170766325, 0.05389818486066596, 0.06889080133048758, 0.036196240990032116, 0.019655286131667036, 0.008768472884361063, 0.07954467884114674, 0.014320665429676733, 0.023934714563731706, 0.04057026212854732, 0.02613898892436297, 0.04247499036512548, 0.0784044182528892, 0.015422201230971804, 0.04061777107117157, 0.028249455818666086, 0.05096156683359897, 0.026888477638544097, 0.02681047073565424, 0.01625915707629775, 0.08554198283461795, 0.037033494652038625, 0.03452091395194012, 0.03602684362821522, 0.021388192338147954, 0.019000872759328737, 0.09656173627703421, 0.079649816747875, 0.01706344980536209, 0.02111938740727642, 0.03271702203839537, 0.05505641787162712, 0.04149486130524067, 0.01765965773243337, 0.06572472081790048, 0.08140633378418223, 0.06029738240965432, 0.02599070303051943, 0.09012642151285565, 0.013094473716562555, 0.03457856972912147, 0.0228754275538508, 0.03878504743859653, 0.07844762561181862, 0.039870555722905744, 0.022324535642720522, 0.03360859133423336, 0.02083523965050136, 0.0774399365388578, 0.04276830244869475, 0.022690922938167088, 0.011718998280083461, 0.029134465486652432, 0.01832376977789306, 0.042167406063526876, 0.06011697636436551, 0.045957725660334674, 0.021612112177535895, 0.04159247239811286, 0.02061964910207016, 0.01959169317307251, 0.009596528703226678, 0.030821098067286997, 0.03421743205117603, 0.04666415448751181, 0.01575537765729091, 0.026877878812111677, 0.0711186922666046, 0.049615868277126746, 0.08899505520539899, 0.01264424384346292, 0.020503079248291832, 0.024626853935901197, 0.03754444082357711, 0.033322587729461735, 0.05413854494690896, 0.09526291847108834, 0.15067527611409465, 0.26604477736738424, 0.11520845424984733, 0.11603471838058003, 0.11407695004656432, 0.17418116721655094, 0.10953108389531413, 0.12154668269138183, 0.14846474473034182, 0.1432591926066145, 0.1295883842413464, 0.09123511927863283, 0.17197570733485684, 0.24404152176312863, 0.12765146115975035, 0.18315648479807764, 0.08884429676277984, 0.16070551208911404, 0.12951666308987525, 0.19413564324138627, 0.1531065021070742, 0.1325156828088145, 0.10043499255252462, 0.20352150734153487, 0.20919184500892318, 0.14632005094280168, 0.12375931315604718, 0.13432758800204725, 0.0979961976108532, 0.09921197914668631, 0.1259129088852675, 0.1022354523921686, 0.07801206632246895, 0.09458340614313081, 0.10666663518115398, 0.19422809473208844, 0.09022228209482086, 0.25359549619738136, 0.13003866007972148, 0.26021644172649233, 0.12030229543245609, 0.11790653931037073, 0.16127290744935313, 0.161703173071146, 0.14480495885495218, 0.1676066159721344, 0.28332205188851206, 0.1123406270879411, 0.1292141349685769, 0.1848390896714503, 0.11530880410704883, 0.14828051590631086, 0.17769364970585994, 0.15633573124725975, 0.20875181942697496, 0.14803864662685703, 0.12900782749056816, 0.1796783230477764, 0.09800311538480944, 0.2095951290140229, 0.17231413433628698, 0.17176514040798913, 0.1493022626926822, 0.11223307600425136, 0.09756798510469737, 0.1621357982437457, 0.16195161538499017, 0.17999358355037628, 0.12378159865376451, 0.13019930871744312, 0.15148614953842857, 0.18726987133343376, 0.21123665625289564, 0.13067999824641213, 0.1840136146112796, 0.1463210775006202, 0.1939930589569192, 0.11121583381487478, 0.24824011259742323, 0.12507056456900414, 0.18307759306363522, 0.24429494364848062, 0.16491550231172195, 0.08809310158774739, 0.1467835954240253, 0.1612917991775659, 0.1490520583766122, 0.1263120943199723, 0.19030782364068494, 0.10288864959992709, 0.08358399999598343, 0.08899387542999561, 0.10400018955190336, 0.08666548907997147, 0.18024541197284577, 0.11023884188503989, 0.1692805487302042, 0.11505283114890899, 0.24476369752758936, 0.11868935093403825, 0.14124307901628558, 0.17086950701571282, 0.0936795756100647, 0.10818011082348325, 0.10197153510225397, 0.13681020317298753, 0.2334587372118427, 0.11542197061522354, 0.23679763949926824, 0.12186740540088185, 0.13213159696709725, 0.14999664478725003, 0.0977841368125331, 0.18182577475184397, 0.16273186061411135, 0.1968416956163222, 0.14622012243395852, 0.10949625753827634, 0.230749789024553, 0.1833843653120341, 0.18893229745088086, 0.1820559382078148, 0.0851545338669131, 0.11653738697209667, 0.22770072844239975, 0.23687354349080594, 0.15148886148968052, 0.09193985888193693, 0.1889819705918912, 0.14258721092295262, 0.21013465409557666, 0.11675130936407274, 0.11078036645607603, 0.14591451463920457, 0.13099717396882274, 0.14085899317456832, 0.12366025032655847, 0.2182148592246156, 0.14706756889579758, 0.20692082332266917, 0.12223661381510958, 0.18547615306752344, 0.25648723296340437, 0.12024512229066704, 0.118324953551975, 0.10665215611938508, 0.1314828124257826, 0.20222877993458704, 0.11073916624750822, 0.19121614344898732, 0.13434174530688794, 0.16787042600973962, 0.09042881173832763, 0.10943686274150688, 0.14421482600512045, 0.22381018156245833, 0.2084752770080682, 0.11818501227084668, 0.11463962630518984, 0.21194562466154176, 0.13093870613844166, 0.23870444766456084, 0.1629834132449281, 0.08304611434258762, 0.13882564260594307, 0.1240892519032763, 0.13473678620592242, 0.15855646692216396, 0.23725323198783785, 0.1466575279952057, 0.17238970124913802, 0.14015976940431904, 0.22702359864788674, 0.11879445053637029, 0.18377271060261036], [0.05273142146066793, 0.008938600902535744, 0.022337323565396573, 0.024059502625717752, 0.06534451904195933, 0.06981586782081474, 0.036246519340502645, 0.03144800505270401, 0.028286103549743855, 0.03894812840547773, 0.0704388658425981, 0.051726708639292955, 0.06563567075758212, 0.031227500050238548, 0.01787710795930076, 0.012078208289289427, 0.058224068864458994, 0.015744416854314266, 0.0420756517128358, 0.03026979821433704, 0.041716919550972606, 0.011447541727384013, 0.028277839376260678, 0.04606338450685144, 0.06536605377351085, 0.087035448260365, 0.051025393449010394, 0.018335835662700476, 0.025525095857559674, 0.07115310493616328, 0.044269455566761956, 0.05717476206501165, 0.03172910186432062, 0.010262780049214921, 0.06347338376086085, 0.04806530248794345, 0.04462892700347208, 0.012754562419779118, 0.050714469004061916, 0.016264655672374274, 0.01580975840859596, 0.04770334509591903, 0.024270833725289955, 0.01276741450231883, 0.06331944222291631, 0.058007829056511966, 0.023581751043938344, 0.002769347277447401, 0.0913531810886437, 0.0692231226111612, 0.03003994885441517, 0.06471974369619163, 0.07936633357237424, 0.08979318092667288, 0.01823805794570475, 0.04957065376783571, 0.009696158437779354, 0.07659290376449786, 0.15035289099379895, 0.024940932747877897, 0.021722338823301178, 0.05085677749687626, 0.035547663292457024, 0.02938280629384662, 0.016139469244667602, 0.009941658973994275, 0.04680189709629744, 0.025793069583033363, 0.07963523809467593, 0.027249094376701023, 0.040680360454585285, 0.040068440064187014, 0.03233154957753516, 0.0247619248130509, 0.011214279445759472, 0.04619896291725097, 0.023355305029620087, 0.039702476032318613, 0.020179276865336205, 0.03795773376740756, 0.03294553840532899, 0.030477201198077494, 0.060795764739234606, 0.05982602000116341, 0.05746586398491937, 0.024286400631911332, 0.003839666671645377, 0.02629337479330359, 0.03761625773603878, 0.04437670787616123, 0.04214592495813005, 0.0932887711772515, 0.02337470237586287, 0.0010592718078236607, 0.04003475900859602, 0.05309032599231409, 0.033181600738316774, 0.05798727874794315, 0.058217055329512206, 0.029420036251746842, 0.042767471243296905, 0.04304318628724545, 0.004854750408295302, 0.030916797770788113, 0.07667039355803883, 0.026508570806453788, 0.033194072649724064, 0.009901731428990682, 0.09334134013061562, 0.05301568221541182, 0.06355012661867565, 0.04174701531507796, 0.05231009991539102, 0.07530878718581892, 0.07822847083931969, 0.052180654038825346, 0.0988282610271727, 0.011601834708163816, 0.03468195329450312, 0.03018889932953302, 0.011302958911044464, 0.06741307901158448, 0.006335950766374628, 0.06593357936869707, 0.0630288957167537, 0.03462872167508449, 0.03803212473529481, 0.059554208175189076, 0.08645420969133416, 0.035801188599678783, 0.02847245252210527, 0.023425666375025626, 0.0038826772417392464, 0.026102546121804945, 0.039508023764938116, 0.05212672910983524, 0.041601657792324984, 0.03100804075778973, 0.05964803096327571, 0.010479353105409012, 0.07713475009246219, 0.061656947157556014, 0.023427165992137407, 0.047255524569341255, 0.0906119680392646, 0.02097189058399489, 0.02757002776038022, 0.013311696989882379, 0.01323847239085984, 0.0191256818887327, 0.024436325953912832, 0.04396099792492967, 0.08700268267984353, 0.041844856234327446, 0.01931177039119986, 0.024325660722810897, 0.01949045656909866, 0.026528207555172906, 0.026451386173345873, 0.06350204694054781, 0.047930616569975694, 0.033099644652177254, 0.07802842996053158, 0.06383012792456054, 0.034269300034089435, 0.05831670421626299, 0.01492037533617188, 0.03997437595840424, 0.03524761729603333, 0.012006375097459363, 0.026516214448718295, 0.03030689602207032, 0.04280888978692313, 0.10389463029681675, 0.044323139178055915, 0.013379395222141138, 0.07236026798284824, 0.059990326708723465, 0.01193827179621064, 0.04390434955336875, 0.024097171168954625, 0.04267126209132614, 0.043406993781607, 0.05475678939312216, 0.08684125263243915, 0.03131450274057927, 0.0638755416167119, 0.0422795728269604, 0.023321614397930044, 0.07561865442943189, 0.03302600062001617, 0.01588166437877883, 0.015538413896255437, 0.05812700169401304, 0.04557547076875645, 0.01868176649534895, 0.0420083049234123, 0.021052017635215196, 0.03374397822265183, 0.05364219275032801, 0.035681678883491025, 0.059383362907195286, 0.026417927283252922, 0.046903338628791036, 0.02186558194338314, 0.02778496904929559, 0.04694652683552235, 0.009385568198687848, 0.08634843593162876, 0.039526474992594415, 0.05536569139709877, 0.052213718393637296, 0.08671510859482712, 0.021984622430717273, 0.014025833619187677, 0.032193703546879754, 0.060707476936400905, 0.04382148182259933, 0.049408744915478656, 0.059769796808400465, 0.049973711776997776, 0.029491383935354894, 0.05474591094459738, 0.02605019167305962, 0.055316458756644885, 0.060263816267251975, 0.011314574719196367, 0.04857480075330504, 0.02303480065517849, 0.052061646110227996, 0.015327138338057746, 0.0483534051736276, 0.052331692103536866, 0.041183335481271635, 0.029890875805229433, 0.04407380437177997, 0.016298694874069864, 0.033753738182807164, 0.12983157119202998, 0.014580554054719547, 0.04829111839494398, 0.10003496442110309, 0.011446199158296711, 0.010693757175167483, 0.02334692594294827, 0.06781764238351776, 0.07378679264577166, 0.03360505966890243, 0.012834645420943779, 0.030594544800659342, 0.019627149637428024, 0.03256540557730102, 0.08036478362496823, 0.05104243507488601, 0.018257305904802297, 0.022920599928305998, 0.051350007885165756, 0.0459397608985103, 0.020699305009217035, 0.033768389614359025, 0.03136414140763302, 0.04415854135708463, 0.09587331434651729, 0.026738923869185874, 0.02242513447849741, 0.04025332389339324, 0.04020904784180945, 0.06046582599200549, 0.01011084087358247, 0.027838664151908412, 0.02242521683294927, 0.03298575036047447, 0.03574080554948699, 0.03581867455655048, 0.051363797467802806, 0.07688335834010955, 0.030834498860302473, 0.02780492755494291, 0.04463973267364406, 0.0751405849211639, 0.05746089973517003, 0.014586263324975248, 0.030762992213450135, 0.026330367263947285, 0.025159685324216564, 0.050213642854003177, 0.019145937253450675, 0.058431226700063676, 0.022424389457991047, 0.03331671566552213, 0.05567683034666604, 0.027673420901860923, 0.007810069120398933, 0.04876252293827073, 0.057823646197756456, 0.0575825774801835, 0.04665634422112377, 0.043897182800837105, 0.07615408094059076, 0.03795078534993433, 0.09875489278666436, 0.05033852284654014, 0.07091426936488959, 0.008504137118917801, 0.04010328557342291, 0.02284338592641777, 0.008296817447239114, 0.03428435749224117, 0.01741438510737592, 0.05123224867988498, 0.041191459843708624, 0.06011594980654698, 0.03136566975304196, 0.031821760198762344, 0.01664384621225538, 0.025992246697686856, 0.05734172326722934, 0.020838614267807816, 0.055123136468952706, 0.027546775076658498, 0.06302232268236338, 0.03136290034519569, 0.033816312244462396, 0.06139469993931632, 0.015086531188459167, 0.05894486567065601, 0.06242082491817494, 0.04551803332663352, 0.048716630441166704, 0.09128758097968756, 0.005901501346905266, 0.03560886605672779, 0.02250475208124807, 0.022727342758087382, 0.02285786881862629, 0.058511436105735844, 0.03242772425554934, 0.06457762672535836, 0.010529275224994748, 0.07283573279217367, 0.047792084890628056, 0.05850012098709422, 0.02889194503246296, 0.011635365418999667, 0.023059510821176153, 0.028358889563429742, 0.01258207580840756, 0.04651130845529899, 0.03842413958702837, 0.012623900378633653, 0.03442323774159436, 0.020772916482641332, 0.14133871743275275, 0.1979302452696908, 0.07767281194608058, 0.16239819867957025, 0.12644928534545247, 0.15783672731730247, 0.20846177853884237, 0.11288073439631732, 0.1775538999467127, 0.19201836007977688, 0.14859629734869928, 0.17092748454982237, 0.15573076693521393, 0.21499445541731774, 0.09385173088840901, 0.10731077722964749, 0.10810144891541813, 0.17490846044834585, 0.23252228665496075, 0.10979880864221243, 0.19679568437558992, 0.10482048585770593, 0.15229549078691393, 0.20915141088827965, 0.19016056621987976, 0.16545645231681486, 0.08164483993764847, 0.16950705028589697, 0.07033449402379413, 0.15692872926592827, 0.1000425563524327, 0.13997673567744995, 0.13252084624142418, 0.13768666904539834, 0.18384075453204496, 0.2075027743534696, 0.1389910716323122, 0.11371320383923669, 0.16739598775823272, 0.16636187631276347, 0.10224478334308633, 0.13132954887565107, 0.0861594650233465, 0.17680566187106794, 0.11904857722261261, 0.11528895476893072, 0.08815566032764413, 0.1373488702360661, 0.19244340098192617, 0.15950471523307985, 0.12678954329702163, 0.1342835379464011, 0.14566006619603405, 0.1853189518254611, 0.1430262252688408, 0.18145455918725462, 0.1204138148515936, 0.13821560679183853, 0.14171446823785383, 0.12654916788902015, 0.11587101305204055, 0.09231708057585264, 0.19614455560522695, 0.09343958324602536, 0.19595281911953805, 0.2201306612621392, 0.08995767532577438, 0.1245333913773779, 0.13948858445209844, 0.10898995768999863, 0.15989238636628275, 0.08827317055434951, 0.14648762501535878, 0.08315992436461872, 0.1858913420789665, 0.12105974954582992, 0.13346584633954112, 0.15870707980807752, 0.08246604022720168, 0.14968582759461097, 0.10751244987571433, 0.12657329965863498, 0.11898335249673937, 0.2273785884702398, 0.18578928384569385, 0.23886091346221588, 0.09944105475780465, 0.13865704197556744, 0.1109458567694791, 0.11757878391372582, 0.13156254685694171, 0.16088165102466462, 0.10255522515264251, 0.08087323618031318, 0.1582746384965797, 0.16297178403023752, 0.14609635326891177, 0.2521346890998464, 0.1605351188129956, 0.12485539345371148, 0.11016900530986248, 0.09066115854488266, 0.14334271151211955, 0.17485828168930548, 0.4049342810626953, 0.06706596457309301, 0.14160307905366346, 0.0894530302274131, 0.24350435623238165, 0.1543345410496958, 0.15946512380915304, 0.11347131157714514, 0.1378874913338692, 0.1418129871449163, 0.26053617618257, 0.24884308508086592, 0.1453956432880894, 0.11764260669869762, 0.09326463174675742, 0.1289689561892902, 0.15706952090465254, 0.13753928905052526, 0.21324523153804967, 0.12146476490963852, 0.15158499020241922, 0.10404108332530146, 0.10475302415509379, 0.13608399778604507, 0.13680134719658282, 0.09221058669349841, 0.10996074430764684, 0.10395786319408687, 0.09249228488413558, 0.19234226205416266, 0.15137359590059327, 0.12652004888701823, 0.0876667200317306, 0.12028315089522831, 0.11401406954973937, 0.0806489332969631, 0.15821154349513594, 0.13162631601575883, 0.08473430399692829, 0.20724245767679908, 0.18218249593290592, 0.08453780244435034, 0.13581787416290853, 0.11203504227582486, 0.058511949384645115, 0.1568486271125655, 0.16924340878763508, 0.14034724644114896, 0.12814104496952028, 0.20256308538298454, 0.09997849608020437, 0.10924560123033102, 0.19700059757357646, 0.09521971877303817, 0.12954637197957886, 0.19063459078390754, 0.20094380533743292, 0.16734565578160748, 0.13937403898566, 0.1261461137102977, 0.15228530181752098, 0.2372518070642987, 0.20189018439381354, 0.16779887339761182, 0.055629509095583236, 0.1076644110763746, 0.0811450824802441, 0.13661603052769938, 0.16862068655750445, 0.1789671942711838, 0.11782983858739177, 0.0875570468844906], [0.10810445964096055, 0.01039235424550791, 0.030943515087147395, 0.06234555677961438, 0.049094928488616026, 0.005064750908904019, 0.02421832605895977, 0.027287389196815993, 0.040469460279470494, 0.03077298199998275, 0.01741375116961858, 0.03149465023119363, 0.04004331238027062, 0.029850705984919786, 0.027054682328936555, 0.016658120345504537, 0.04945854063055689, 0.03629473691445686, 0.09169989716141455, 0.09807590905937458, 0.01057455197892963, 0.051913706871170195, 0.03390119861691229, 0.09136065810678468, 0.013691825029860823, 0.034288689719452974, 0.009190306750937335, 0.05771163265190779, 0.04032600265476973, 0.03632699304650869, 0.030719602908638698, 0.01649648920002003, 0.03509408178468866, 0.020577004817765088, 0.04335021900553857, 0.03044957989796756, 0.019787957238393928, 0.020263866378715443, 0.04995550186703763, 0.05668894740782919, 0.05690109247582094, 0.03194346667207297, 0.048513850798049284, 0.029434572770110065, 0.007476276950910688, 0.046606866432534116, 0.052747206702347726, 0.03687114146868548, 0.06175542776022227, 0.025541898080958955, 0.07481482901400135, 0.04015061448538496, 0.07733413979651467, 0.025206891662110726, 0.033523754757498546, 0.021226584175301176, 0.019795252310652888, 0.05651398058680277, 0.036684840376819336, 0.05489172812010493, 0.012563832382100725, 0.06567395983203765, 0.0674747184459721, 0.018668626172227726, 0.05336924711422575, 0.08212592017145888, 0.054989346873856364, 0.07062755329834838, 0.09182054068773024, 0.01022799295418325, 0.03978282716425677, 0.0869623558115094, 0.010583447217340431, 0.03171958896752087, 0.02732023713178933, 0.027891907262645906, 0.02227900320694091, 0.0645642125258042, 0.06031292250319835, 0.016127602542720495, 0.0973037537187338, 0.04723812288214122, 0.0588810428856842, 0.035289081804935014, 0.035213376996257616, 0.05372948463886015, 0.08664206211124698, 0.09512609516781184, 0.04459847883892156, 0.023660096940734697, 0.023721117759123448, 0.01438492296954557, 0.05675838178684635, 0.025421922966357202, 0.052448547325066985, 0.0681123640688677, 0.0566363133369915, 0.07021429482847452, 0.08321076962015322, 0.04271638850050588, 0.020804923636117773, 0.061581253840197483, 0.03406524485457809, 0.060829277255482254, 0.058682633774174806, 0.011011038234667673, 0.04775237472307298, 0.06823961893396993, 0.07266104176279999, 0.01681742449891904, 0.013212619796245089, 0.011077709909107898, 0.060797745076518875, 0.053444438643993876, 0.047169975530836857, 0.049991205394748724, 0.08218605041263566, 0.0193408070387499, 0.06608364067130512, 0.019062134895413634, 0.03130966298011763, 0.03354131732316267, 0.06054689341615285, 0.02047636001671274, 0.016411122107397647, 0.03709676968414457, 0.08400494998861706, 0.03580337195026298, 0.07073331939717455, 0.020991105984355656, 0.03345748432160866, 0.039662444107835336, 0.07122731587338833, 0.041566015551647836, 0.025345817876739368, 0.010679142132792021, 0.0329031584213578, 0.030427296315470052, 0.05173181078486866, 0.07367524258311718, 0.028687460843714017, 0.05338177265178773, 0.013798061315150512, 0.05724572478943775, 0.022663188640088327, 0.03373367817050988, 0.017534103582523042, 0.02507666820630191, 0.014755794752178895, 0.05149535391659987, 0.019001696303847338, 0.058306059424555114, 0.062002471963604616, 0.06683070663242571, 0.0035890575259878875, 0.042922975600606976, 0.027238867102911877, 0.04826307191603607, 0.04018729094475989, 0.12777853982463, 0.04471297067920527, 0.025896901309850718, 0.05408234856722336, 0.03909750022895394, 0.039540329692705024, 0.04682114888583461, 0.028545883964867364, 0.07742030936623774, 0.04669511210053198, 0.06127772980459756, 0.021076570753188386, 0.058180172026397727, 0.044859013850650484, 0.030360129556708762, 0.03212750014368325, 0.05189867239565619, 0.05276119546784509, 0.016032513794338992, 0.05530640002219908, 0.014342318904856521, 0.03617709645280435, 0.050625304030554916, 0.01929297442397764, 0.046681985183949434, 0.032143137913437626, 0.03460585395054471, 0.04438915297449116, 0.02461269088540106, 0.06039409717965511, 0.06898037233059445, 0.013939709057130161, 0.031197015496511615, 0.05337428414232789, 0.05775235788596254, 0.021556695292313254, 0.044345045462250716, 0.018324005349929777, 0.030990192824373805, 0.12328430799947632, 0.03386811510990224, 0.02302918140025389, 0.059026760469761595, 0.037687733739374146, 0.0554441043265885, 0.0737288304334206, 0.00653263857407916, 0.012440369652223685, 0.03991255649335442, 0.06353981890565445, 0.039300620781197664, 0.027306621834155054, 0.032067473324376254, 0.030768839379532203, 0.02731163587961947, 0.02094908223126925, 0.0461602371726786, 0.019644514935451652, 0.0776408124534834, 0.009647444821894169, 0.022512252082026774, 0.05101055049547746, 0.030050779422444683, 0.00896815082899505, 0.027468021238042463, 0.028870891021083922, 0.01318463556198103, 0.005840168826492323, 0.027581708686005686, 0.04669485546107735, 0.07633317697552905, 0.019154571064357317, 0.012140307376431602, 0.029709621317564484, 0.018571821386895834, 0.0857426365837455, 0.024446411501435984, 0.027270897239026044, 0.023832340319190296, 0.02119422653659938, 0.01375402658126287, 0.05431802402580938, 0.022979644239850106, 0.08102553445966014, 0.07001651390906304, 0.041512883523659366, 0.01912363068831544, 0.07099214986327194, 0.014760648876789116, 0.04455901381950225, 0.05268133846261809, 0.03155414653461307, 0.021493108079378164, 0.05561371236258457, 0.013498922175307189, 0.06563063755991959, 0.023310766592922232, 0.05287232418214122, 0.03827408594529956, 0.08779419706233087, 0.04278751210339608, 0.0269461257548462, 0.05440530442302266, 0.04366363323624096, 0.01320764980083632, 0.03974667164467035, 0.06638655949744486, 0.00766803929206705, 0.0452248361562529, 0.05527660686282381, 0.039603286798322396, 0.030683681045869188, 0.010003116462499866, 0.027848590736187277, 0.02823787448447078, 0.05624982580963162, 0.02710350128191133, 0.03354415567892213, 0.16540228990056824, 0.020164554570651343, 0.02731635881167266, 0.05574125451065841, 0.05359454591187739, 0.06258330450603558, 0.05130315394771676, 0.0472570184407936, 0.010644955459171006, 0.03108460550016213, 0.05880127781100812, 0.024714695492519007, 0.03300098401884879, 0.059762549616636775, 0.014989392197270308, 0.05253121587297609, 0.0292746136115203, 0.035498174012548504, 0.004172081798089728, 0.06537451904507414, 0.023656494412270766, 0.023497081091327053, 0.06664792571457163, 0.03969036801267536, 0.06099677088880732, 0.10246389981118903, 0.013216221367099113, 0.01902005943139234, 0.00660798954589653, 0.04905382021059913, 0.06251494648055204, 0.04422359371317491, 0.03255264638292213, 0.020481038898710283, 0.022559498639536962, 0.023826435696513906, 0.03272920283639143, 0.08426646942332869, 0.07200448908993314, 0.03770286397587869, 0.045221262356086124, 0.022113250508423776, 0.013882559855588743, 0.063349989978897, 0.012376997901517297, 0.01933657057252863, 0.044886593015924584, 0.03494356082932603, 0.0038476540958659066, 0.056842038588177775, 0.03752509710348902, 0.06447588258813466, 0.03492733125665015, 0.037956354809143854, 0.06303651446116067, 0.09207077564731722, 0.06212367090366541, 0.07343307452937288, 0.049365296238853086, 0.04104985615178462, 0.12486377445560311, 0.020821520930997307, 0.045850538468408975, 0.09169055088873833, 0.059061835805374774, 0.01636003361894719, 0.008897242688333556, 0.027938449019265753, 0.03317213189157267, 0.029171212809160355, 0.04265491760546162, 0.05331862785462892, 0.04181332788580368, 0.03341315464387017, 0.005947921487067136, 0.11904606445422096, 0.1387450195127918, 0.08870989429734408, 0.17316688212656206, 0.19823994397396044, 0.13340128044928276, 0.14874197662838046, 0.12102274749908717, 0.1495336365675734, 0.16715299999040945, 0.18909093893824086, 0.08619393131905988, 0.1339096257523183, 0.13989154670026996, 0.14761624106716725, 0.11147968215687622, 0.10460827184180099, 0.1271831362898792, 0.13765663839876652, 0.12882768957605287, 0.10073386643442417, 0.18280969211651435, 0.21248153380809293, 0.19598930022649227, 0.2574824577858371, 0.14782542903577128, 0.10167744926988118, 0.11339692443969751, 0.12071481845792263, 0.06943054857753939, 0.0931463094668523, 0.1667750428520864, 0.1992331463242731, 0.12621520718018855, 0.1335253713712577, 0.1217297470617679, 0.08634063715655958, 0.12252759699138904, 0.14919386125139653, 0.17822312371384713, 0.14125158259224507, 0.1788937264392453, 0.1574476312605604, 0.10953971004534153, 0.11554557124092696, 0.0704827473589009, 0.0993236594442879, 0.11352619411604059, 0.1939436462858031, 0.11874710630264976, 0.15138235994644705, 0.12313492085424163, 0.16588520108451768, 0.18512940635123562, 0.19582187937152004, 0.14418234387713094, 0.1399579205580296, 0.09416762724398606, 0.21892614121879303, 0.10194366482356865, 0.11408431215151665, 0.0896374429125459, 0.13689508571499778, 0.1041714025421008, 0.17287422121772844, 0.17057808716931652, 0.14999043947506338, 0.2937644125232774, 0.17135551319487635, 0.09757345497247674, 0.13631921742231617, 0.11388028761552227, 0.13912633211622316, 0.10726874964612146, 0.08232535584078682, 0.13129199524560284, 0.16824162625257047, 0.11831445814741236, 0.10592007483806341, 0.07912913742925852, 0.22995900242559372, 0.10283122364912303, 0.17908563146427756, 0.1504870023458235, 0.16591155450911294, 0.16180163069117456, 0.2824697331074746, 0.16075034355444295, 0.156158734293234, 0.16823774984767362, 0.1156226626687473, 0.14493416724426134, 0.1013521683372317, 0.12546838636720373, 0.17079374092000146, 0.14019456511783984, 0.09469487959699285, 0.15788465377784547, 0.1626039239307565, 0.06337031812196778, 0.1693527295344299, 0.30667621161668535, 0.10838920686153636, 0.15212031712214794, 0.20938512899221914, 0.1076933155737577, 0.1045300466038527, 0.1502011902630329, 0.14564034709286305, 0.09345351838536801, 0.14004785928034014, 0.26163260121980025, 0.15226256432792834, 0.103512674179529, 0.14769530134095302, 0.12861315431373735, 0.15963023107859398, 0.11792540039506652, 0.2520002406691351, 0.10612429089603886, 0.10644689052095337, 0.11545123517393105, 0.2106117276895431, 0.24225056141374574, 0.21309725399459564, 0.11183326237744863, 0.18364324174340696, 0.13827306338615958, 0.08965751441616206, 0.26081264199268434, 0.20063715566310192, 0.13106069797950406, 0.17138638653822486, 0.09397211394483045, 0.11144115559516415, 0.09362955006860918, 0.12504326885626202, 0.1699159726981194, 0.14030662845940362, 0.16900252010072433, 0.14244016800676623, 0.15541550643261404, 0.16183950607815098, 0.20369027651125388, 0.1219777680272537, 0.11445263190375221, 0.08593952118028557, 0.15655429613205696, 0.18031901770061065, 0.1373731552232658, 0.16975762232417063, 0.12010751757770778, 0.09116774184569236, 0.11503677394601608, 0.2001137643932335, 0.1157070472536068, 0.2162392563637226, 0.11654967502240213, 0.17038291860972682, 0.2181966416537762, 0.14723209393841608, 0.28876899831718017, 0.11615258866860984, 0.10957246796498377, 0.2227237769552777, 0.1362887271229298, 0.11765330128612057, 0.13552008046498223, 0.20754755985352302, 0.10795210007457964, 0.13302234271841665, 0.10658843292584343, 0.14272974924214427, 0.2776617959382073, 0.10584640782326461, 0.07505665998905897], [0.03621512505736563, 0.02968939851158329, 0.03385525249365357, 0.0604364043852735, 0.03150573552345797, 0.02275188821518133, 0.043789283147141825, 0.008119553320049759, 0.016126424682536916, 0.04887616059051887, 0.05203672143961153, 0.03226276637325364, 0.05601798845154624, 0.08224678586327261, 0.019396790829036507, 0.04024739437285931, 0.04296530961930271, 0.018788608947708722, 0.017496936826876575, 0.044466305689345446, 0.08848682481555209, 0.015221422992556568, 0.008563334648046763, 0.005381916097605662, 0.014386996194990653, 0.04287598759777123, 0.048143481760616266, 0.1132012349403193, 0.03764678633982136, 0.015214306035740002, 0.03787375137870831, 0.04290711375013475, 0.0673680330416368, 0.026911824168036544, 0.024906225134468368, 0.028520700739576455, 0.012004679170316987, 0.08981113802761802, 0.06795784413454033, 0.05252996714965952, 0.0362883745542457, 0.045947965700179345, 0.04960527711157357, 0.03442169024398731, 0.07123575050143466, 0.04795473301783205, 0.048620233597654494, 0.03576917761576272, 0.0181112646485769, 0.04699141192700594, 0.027178819216186964, 0.039321431559660745, 0.008410999979523402, 0.023221978917717937, 0.01450709867170982, 0.012272947839641524, 0.06243865944505219, 0.018998404040992744, 0.037236779913186066, 0.02928357684023438, 0.026961210026075284, 0.017887978746946302, 0.1122815463872206, 0.041255673333521814, 0.02945824871740995, 0.09046751450026229, 0.04943497959644564, 0.04632077855809082, 0.07674689509815748, 0.08329841773957015, 0.14516989249856244, 0.044078435373282245, 0.014843555869564656, 0.04119606403213355, 0.08585607888357294, 0.03088420647526941, 0.10863871403759527, 0.09362197345903805, 0.0563996764380605, 0.06292773763679209, 0.06414295609800086, 0.022982329378024708, 0.13186913524423877, 0.03981910908835069, 0.02642643660487187, 0.034958488052530635, 0.01314154790428978, 0.00736708979069766, 0.04964053630828858, 0.053707091888833436, 0.01652618085274533, 0.03697087079466831, 0.027476294987624692, 0.030147249044309703, 0.04709694819945482, 0.021893687794105183, 0.040927056087962085, 0.031590033923425985, 0.04235563003608296, 0.02233417302880797, 0.0354322215031472, 0.014879915360060912, 0.018460282815560218, 0.029456452241227515, 0.04127840316223522, 0.058622675902780995, 0.10524871368562022, 0.03950466063895053, 0.04167998262170342, 0.018404277957855694, 0.021838929744497425, 0.021148512154937755, 0.02003908277519288, 0.03388232987133726, 0.06002075955151551, 0.04534840613843934, 0.03083074694469331, 0.10477116511714075, 0.04009633332551007, 0.12264552856645278, 0.07801840186960275, 0.07586248489397188, 0.0172107819197399, 0.034281687675825054, 0.06090248078708688, 0.05818424378371528, 0.03130460105415794, 0.02216523340452583, 0.013496671792029614, 0.04484119464553172, 0.04043323198153127, 0.06380358297798423, 0.060454035898850816, 0.054403565403434544, 0.07474870030437747, 0.09440844698298363, 0.03368422719499758, 0.019977596558390126, 0.03943239939549277, 0.05708474290346908, 0.05044294063061957, 0.025532088325088544, 0.07702044977415955, 0.05602425505076686, 0.04737261727812791, 0.008995342162257482, 0.031214055207167423, 0.02350433211353037, 0.07987463291013434, 0.04889766850899305, 0.04037993141419945, 0.03239105928749327, 0.02514459530732805, 0.021706187774637536, 0.027591593135448716, 0.03862569731990657, 0.03305397432057127, 0.03811509588793401, 0.04190640756860376, 0.013738014386035504, 0.03319232213881708, 0.031004882560321884, 0.02529670781035337, 0.0046562120194486795, 0.07447986472998896, 0.03145629412404472, 0.03996470792879982, 0.05202812976354072, 0.04090943223526401, 0.030141629789385106, 0.01875243236070439, 0.06874990243945392, 0.08278690083252807, 0.00741410747944047, 0.017494791780688593, 0.05011992731822595, 0.027673227464660045, 0.07323889422320551, 0.027522972724851102, 0.05520777003238759, 0.032427199485321204, 0.04348739853969986, 0.051369148591953906, 0.03259009276066096, 0.03637188962931114, 0.017150429513065085, 0.042153432619787996, 0.017828683541606993, 0.031682023846153776, 0.05271555194931646, 0.01865956718252311, 0.07692153250137646, 0.018260724572164398, 0.07261667761110491, 0.015769071478937424, 0.042140566173099706, 0.03307098913336954, 0.012014447748961469, 0.03127629027491616, 0.009990891614448159, 0.03093948546466568, 0.037644074388569405, 0.09618241550220598, 0.04637500992225063, 0.02521454871091391, 0.020447118440642953, 0.0095258743291901, 0.014748447968985045, 0.07285503054698629, 0.045593412547943094, 0.0057502368074511334, 0.03031019403058435, 0.03289331419153079, 0.037469923451182344, 0.04938958122605278, 0.03559168270458618, 0.052947833638397925, 0.019849813092620145, 0.06578703440966145, 0.048020834914378585, 0.056606286520799326, 0.03378694043344548, 0.05048810917463514, 0.06183548394830958, 0.011741209084228163, 0.043538849004694534, 0.09735911889302154, 0.0312647357537982, 0.02999875822194642, 0.05985645667439508, 0.013793385305982685, 0.01601433452789582, 0.051851485209960135, 0.0473367681937112, 0.06342907706576009, 0.02089161223040954, 0.020143106023991303, 0.06105447263126412, 0.019393485159643235, 0.04476149085788958, 0.02784748182391688, 0.030940153876379616, 0.0455779145892349, 0.019980482794644854, 0.05270669597291178, 0.03954471171563191, 0.05854363478119335, 0.022610386029907295, 0.01139767227634307, 0.023348969482486288, 0.02987560575767871, 0.054415953045170155, 0.07611821270397595, 0.025972577390230955, 0.05621177805287223, 0.017094001391782396, 0.061650224736020456, 0.049642635389201106, 0.04498172964480135, 0.07276555913830958, 0.0426400057040155, 0.027788956536941474, 0.0436825402862122, 0.006547005595489135, 0.046416662122693755, 0.01937172826259367, 0.04917549412517298, 0.04501813031252354, 0.03699171604708799, 0.02881589931465926, 0.020832950962827574, 0.018707348086360483, 0.023339669175085523, 0.0051196061559171694, 0.06638564785281498, 0.04573725704704562, 0.007940319868090052, 0.023389786647091952, 0.010466434947785833, 0.04023111883490797, 0.02153016566749542, 0.06067192279583505, 0.04712772578181279, 0.04674582329067973, 0.04326115362346173, 0.025167844160610152, 0.030420014649749767, 0.033149884698251565, 0.02207439261368446, 0.041686980834891724, 0.04515566224712999, 0.0821070437650046, 0.011510966146635193, 0.061985472472564834, 0.030449463069559108, 0.04602306529939656, 0.043816532894608476, 0.0563851973762916, 0.016022693504759624, 0.047907806302030245, 0.05638912357690354, 0.03132887071959915, 0.06626215447942096, 0.01573486373789849, 0.022497380400196682, 0.0478551990442699, 0.0820267194461438, 0.07933063387510278, 0.019605199303177577, 0.049087742583886276, 0.052725457466177406, 0.04181724642553637, 0.10352725283272805, 0.05529421156332378, 0.0460156993640046, 0.08831424052797018, 0.021916388894521424, 0.1161164139968253, 0.03544924397682471, 0.06105230077199879, 0.020200034017644582, 0.018275659456248247, 0.05248266505077482, 0.10738405353960492, 0.030105029938802607, 0.023526297769539302, 0.041675899373067, 0.051384845733522415, 0.062156712275839625, 0.055310429644680796, 0.03391575428747362, 0.05830921187636353, 0.03000905444364875, 0.07368524003052905, 0.04744316631507489, 0.012960067420687168, 0.04112809671149139, 0.010697768603060997, 0.03788006394320438, 0.02320144967656703, 0.04949873343350426, 0.039673502587022326, 0.06074486585754541, 0.04011856136663307, 0.11262890597384785, 0.01563335804554123, 0.033142070601423906, 0.023794602828040242, 0.014337473398735447, 0.05517548708725841, 0.024934181598045176, 0.0069886437925179646, 0.11733537479754418, 0.1021757664819879, 0.060972478240728385, 0.20485249317942128, 0.09415835758010227, 0.14621924909372486, 0.22729571307859114, 0.11897663390564343, 0.11106064738405329, 0.09059684546363932, 0.13348476871127082, 0.13901943220726906, 0.1551021917933418, 0.21424044103872394, 0.06420056207946713, 0.1534981109322079, 0.15172895344515003, 0.21463434812763046, 0.12176897076349105, 0.12588512287625384, 0.161944889133015, 0.12541325868017253, 0.08608123212451897, 0.1831531293329693, 0.1411340340611435, 0.15220195145135926, 0.23457091301679614, 0.2445252603220363, 0.128040449964183, 0.09954434639263539, 0.10853979676481217, 0.21068591564413042, 0.15327830498497333, 0.1378437477133928, 0.16963713201543978, 0.08373224567021094, 0.17218808222922588, 0.14543022449699142, 0.16789308689053983, 0.09911747454034706, 0.10614272297149706, 0.14699612353597918, 0.19627114397383508, 0.13681936558456192, 0.17924643331958404, 0.17611360868378995, 0.1358488854020834, 0.12282467822754577, 0.11438366100792924, 0.11493060182059005, 0.18352547870768657, 0.09586723926927775, 0.11097332102156456, 0.10150953811863739, 0.09882014049517532, 0.16137041512035555, 0.14252054595178174, 0.1608633568450328, 0.10667159943090332, 0.12993304719848017, 0.1652262122520516, 0.1379848151437698, 0.3797412038810792, 0.15925797363442762, 0.1540217167066951, 0.1702107939748995, 0.09006413856461164, 0.16672238196817138, 0.22744298582115482, 0.14540696606761025, 0.23280226114776828, 0.09894739536027755, 0.05637990753917445, 0.07827617513436465, 0.15882196235320262, 0.1134012911408659, 0.16202506789517018, 0.18833359973805566, 0.19176783400677866, 0.13168070825838274, 0.1532938718915947, 0.14777754854050376, 0.2064732747573045, 0.12032995120652261, 0.09663709634614569, 0.11973822489380838, 0.1271274570195425, 0.12691107548532948, 0.14739079671281, 0.1896022873059396, 0.16894981325153383, 0.23845347726056654, 0.11906186884809887, 0.09669273731208618, 0.19150744072131573, 0.11477558392911189, 0.09988016869512298, 0.11797334983824723, 0.21659321962825714, 0.12922804712528183, 0.1131220750751034, 0.2089782443738753, 0.10464343527752547, 0.17121041614201762, 0.16402448076874981, 0.19124237429951468, 0.14969759470512792, 0.17037876641317723, 0.12504565138970652, 0.14751125637802387, 0.10443216354976739, 0.18116384414174866, 0.09424965227803878, 0.11442317582306363, 0.19864430050215415, 0.16081052742177443, 0.13918754254137317, 0.2135145574087097, 0.127961948934582, 0.18019203096628192, 0.18765198066830638, 0.11969355430694358, 0.0942903009033011, 0.1656327291481918, 0.2139977137407949, 0.14923308495311968, 0.11576153908766086, 0.11845760933694341, 0.09338378906250001, 0.13557134706887508, 0.15480574641016223, 0.13090078478618977, 0.1297411574952064, 0.162736518428691, 0.16133859182798094, 0.18562662805761063, 0.2005821505501386, 0.10041931839359385, 0.13404746029165485, 0.1234594816642423, 0.1587284996264404, 0.18748560169291115, 0.13664025422786513, 0.26685318398860197, 0.1801432771307807, 0.12307306691523522, 0.08978450881137003, 0.19688186926707146, 0.11684161580858693, 0.09202199882917828, 0.14246295146163435, 0.13951941183017147, 0.13870181215386237, 0.09894906543195249, 0.18528869135245202, 0.23793921775875554, 0.1969854137109172, 0.21518452183133174, 0.1936764041742971, 0.09588274488886518, 0.1482131767777666, 0.08291384160158136, 0.12090000489185895, 0.11870923857655256, 0.1986789429980901, 0.13298178602370525, 0.16387975143809475, 0.16227703421346604, 0.21143150305555714, 0.10665403303479958, 0.09223107188459366, 0.16807005320104862, 0.17801673962704598, 0.14474175660119903, 0.09108740986595232, 0.13526707226710935], [0.04641505716849239, 0.04587360154536944, 0.02762404653514105, 0.046463753547399275, 0.03828837348508739, 0.04362266285405044, 0.06840428953329403, 0.029710410388126492, 0.03318557673464379, 0.03719281795765123, 0.06930163130164146, 0.05008547634427106, 0.07541210180328739, 0.035058784283577435, 0.015467824639692424, 0.012419059958999917, 0.032332399935131116, 0.06087600478842374, 0.08854173799796451, 0.06280384589767744, 0.07014261198139961, 0.014606584764776692, 0.015864626583342832, 0.050251728915158785, 0.05952642216617542, 0.011111264560191382, 0.0539811100480297, 0.04948329676183001, 0.020599522057079503, 0.01645357295450184, 0.06443515735407991, 0.030562380599158428, 0.022025272971199408, 0.053903945841856545, 0.0888831450814201, 0.018714537821529854, 0.03161717258814362, 0.052868623977466944, 0.05973379833683853, 0.004886594289282878, 0.03496148345631457, 0.06171437310836008, 0.09076662586941835, 0.05065477543300198, 0.043850914920650186, 0.10677016430324125, 0.05782843424728321, 0.013311161685945287, 0.06368003597843551, 0.07401088102450294, 0.05435890630788861, 0.09453160327769096, 0.05541464058502067, 0.06054770546935259, 0.024267018607427037, 0.032187904261292956, 0.033677071933784795, 0.01697308973469321, 0.04976371941607326, 0.04794234154565681, 0.05547464825212956, 0.04615677828570047, 0.05415013585720332, 0.09344493053973683, 0.014364335314190436, 0.03339904713474455, 0.055165554757320115, 0.08077280205344001, 0.05592506581677064, 0.046793228811434204, 0.04020816301025691, 0.12763182632625103, 0.036110044607231696, 0.0518528565073446, 0.039951757212439855, 0.031193254004803397, 0.008135213114831957, 0.042820308327434525, 0.038689937622797106, 0.03578036632989684, 0.0038014367296014947, 0.06761162601892026, 0.09090590065405255, 0.015853141967747963, 0.04080519065140717, 0.05969347912938364, 0.05777924757210478, 0.027966987709665013, 0.04072164493282476, 0.01919287354535153, 0.058435532114198135, 0.03340714085366457, 0.030436874329743367, 0.050788806345794475, 0.07243524500799757, 0.0528355059965003, 0.034580730097067934, 0.06197445229777406, 0.0989191803420263, 0.031738798622222196, 0.020808974326017405, 0.08166851971538798, 0.05761502130377678, 0.0346172878128146, 0.037871384167022286, 0.04803843961487855, 0.04952907434574539, 0.057759861717180866, 0.06187484554585911, 0.04082254637333174, 0.08756128335071188, 0.028885709076759317, 0.03540600597437832, 0.04851485054279047, 0.03927970658086481, 0.030230892439102455, 0.05413509755124969, 0.03694862360134721, 0.07520700474419902, 0.021063824965348168, 0.026798466137880762, 0.03563606983891899, 0.05041716943284677, 0.04094909260710401, 0.07408980340246232, 0.02238823202318482, 0.030890865694551222, 0.04306216228512987, 0.02228004317129812, 0.0071772833677729775, 0.0383135394734, 0.030413889776795145, 0.02211074731613119, 0.0924206633240946, 0.06458489689975977, 0.09715766841245276, 0.05759070950349974, 0.02592250205306036, 0.011005594222355756, 0.05845364626316775, 0.04320571950126079, 0.03818733414875404, 0.022071155892204375, 0.038309475376961694, 0.04827282804575178, 0.06118632785435166, 0.02859621977193221, 0.023037121901589058, 0.06070339751820411, 0.026956715005179568, 0.12940522794040943, 0.04026476158610275, 0.06546641129159159, 0.043931959362159816, 0.01112412526122024, 0.03525534712318932, 0.018738121838278828, 0.056383554117694024, 0.03015748206375828, 0.015791618404158905, 0.07623992875338563, 0.049138821496237675, 0.041134734863355275, 0.06522583670072979, 0.048439716469616666, 0.006752666208006803, 0.055830591853948376, 0.008372145915223707, 0.04982341681757281, 0.021604359367742174, 0.04947259451352781, 0.05214007436147621, 0.030525608378792965, 0.07861397394369687, 0.05270794852666798, 0.027812011953022693, 0.022670947195541476, 0.01656684863020576, 0.05172792288865294, 0.032932158679731434, 0.044658421388556885, 0.030617247816295396, 0.058534487691377445, 0.01430507266758791, 0.03718789201229811, 0.06573340059408257, 0.06405515476099907, 0.03276284175714658, 0.02635755763959981, 0.014124351568640241, 0.00825544199605863, 0.02974741243486924, 0.06583742767332063, 0.01007373253214023, 0.058951932831757495, 0.05066379228787077, 0.03990153631856365, 0.02460069586372664, 0.029332455165023287, 0.015148868720467775, 0.029435049659842928, 0.06638268309254801, 0.03785788569779646, 0.06405015986773276, 0.04697174644998966, 0.03102099147414969, 0.05062040106783952, 0.03918358935944496, 0.013466265762314923, 0.022724167323641242, 0.06555669475346804, 0.034927610878742514, 0.01327437797426096, 0.03224050385817405, 0.04417137716025595, 0.01169447676323715, 0.012650328496801517, 0.041380855930788864, 0.0018158578478182938, 0.05989122174439892, 0.04611029590089475, 0.023976684690663413, 0.006094199272939155, 0.0125131068278044, 0.01941990753215167, 0.04901194967509759, 0.05001917143442458, 0.023305032424808993, 0.023673564766443545, 0.049320234947146914, 0.03418903700226257, 0.03527782031244809, 0.011552282226001544, 0.06141298262762928, 0.035269581036822456, 0.07783767406738575, 0.043518011413154103, 0.06039256500380655, 0.03123458444831833, 0.12592903503607358, 0.021882899360911503, 0.012040037958462153, 0.025769336179139155, 0.042353975286166516, 0.03900489935110654, 0.03194456026258488, 0.042969400528818376, 0.01763529230600163, 0.056410627664938096, 0.02440567860650199, 0.07176818926968882, 0.07734500292328096, 0.05106375913225836, 0.00948159253194688, 0.03516166606136868, 0.05176428908241853, 0.02959233517157695, 0.046604100855127464, 0.02563852092040883, 0.044011034957704046, 0.05156064375994667, 0.05528351697590082, 0.05294488803032906, 0.09477073762325511, 0.046754047244546876, 0.03183146270232336, 0.04819135459500456, 0.0264966179196152, 0.032807715357311314, 0.027837911470522805, 0.11441935304432146, 0.04524331036654692, 0.07219571229671279, 0.1009535421467116, 0.12199088345251738, 0.03460345226490209, 0.04816470622655846, 0.056762947670875065, 0.005993781425434375, 0.03266293240050155, 0.04285486655369882, 0.05531914389481949, 0.0292249481313892, 0.05375869557141297, 0.042969488628929665, 0.032258173676147577, 0.015406099020413335, 0.02053538709127855, 0.0680107961318666, 0.05861538657618146, 0.05113339652457545, 0.03931330336678413, 0.040346418897951805, 0.03214908275573004, 0.05411345939782839, 0.03448874591999958, 0.036834357757001154, 0.1317119646456934, 0.023700487011322574, 0.044807034784988056, 0.04929155644570147, 0.04172847598731037, 0.01251902006896994, 0.057265080000844695, 0.04064122868341304, 0.044206483139386105, 0.03174923657019052, 0.04840831835604003, 0.034587088626839464, 0.01670767474288662, 0.008264836149230119, 0.0815366376792231, 0.013837641247758463, 0.0547990161595085, 0.04555366790643142, 0.0372086874690027, 0.008959528509407275, 0.03362120497190664, 0.03170517693844534, 0.08244842020494324, 0.02634160577379648, 0.045049283277964404, 0.07802022515886253, 0.008602783388097682, 0.10717110407929267, 0.04473472374581522, 0.0193020774637379, 0.08023708442886991, 0.022906777786932165, 0.02917745451052343, 0.005252483627578665, 0.01275150381374143, 0.051221224674654585, 0.028923762579178138, 0.055591537947616274, 0.02504582933691, 0.06869021652927322, 0.020160519202510198, 0.04314503001589929, 0.011254229973400793, 0.030821417908995386, 0.02005919066798543, 0.012054794727103605, 0.08886563231147106, 0.03092366957946891, 0.08269605046558766, 0.05298182112915863, 0.08450546587306647, 0.03481760065281584, 0.052827362481865196, 0.04444731820014216, 0.05597625198143144, 0.09342445300952082, 0.06604967233274253, 0.18239649493367444, 0.11783637331738589, 0.1800276438194898, 0.14272346732116517, 0.1792943751018855, 0.1162997158544679, 0.11912445823151259, 0.13844394695854959, 0.2120857114993757, 0.14510768615911085, 0.08765493759945517, 0.08118601455803841, 0.10421122379240491, 0.11923587805921994, 0.1400971034121129, 0.20544230427232482, 0.18054835378162323, 0.13965905433700931, 0.1386685792597071, 0.09688455806744677, 0.11262008830183938, 0.07472322788089514, 0.16499531335167347, 0.15341495974890648, 0.17153713731996476, 0.19643661896547965, 0.14632924399789304, 0.09698568933433104, 0.1856770059995113, 0.12835287594146308, 0.08726107647582408, 0.118604974010058, 0.1443968178524125, 0.3021387034846891, 0.15959211054348177, 0.14768278346427027, 0.08992123252321636, 0.13336838463381415, 0.15094814131096487, 0.1778872401243256, 0.16672792844474318, 0.18095758262901537, 0.20443652275829546, 0.13861191939682732, 0.14267053064559737, 0.12299795199425952, 0.1392918530731432, 0.11142974854597162, 0.1314458716660738, 0.18204202605110986, 0.24181298731315523, 0.14615780884219756, 0.12687342992473033, 0.08437917627874883, 0.0853256319439219, 0.14616623580936464, 0.09484275754901672, 0.15688446470566336, 0.16280597195990626, 0.14530178219560655, 0.23628708786301075, 0.21244638569412694, 0.10041065393917023, 0.17864408902823928, 0.09629782664799884, 0.12383343982360057, 0.20319745214956425, 0.20847578262609823, 0.09068656968133104, 0.27707920139355047, 0.09290413375222877, 0.08135018720021171, 0.14176575016350518, 0.1770791552600361, 0.12645261016704384, 0.11743023946520784, 0.15634299376078192, 0.09467421820567501, 0.14807762518044443, 0.11621822708196218, 0.16575298963054536, 0.19556432061137694, 0.1634815849003292, 0.1464733451364502, 0.18597532063722613, 0.1376563472853553, 0.12873643318251257, 0.14490166979451335, 0.15993902579911295, 0.13210361943610255, 0.14280493311103315, 0.10153943086944281, 0.25512849942090055, 0.167033153195535, 0.09358154699927376, 0.16269138052819238, 0.22937639255917844, 0.15115565920789398, 0.21214105369102573, 0.21369633475138297, 0.12959265901196387, 0.1338156114422506, 0.1225161363160418, 0.12217067662746676, 0.15369724782724536, 0.19235816603947073, 0.2443890039238238, 0.2175714219770124, 0.18922086745019884, 0.08751302747236145, 0.17671529413951984, 0.14741489783890788, 0.0906678235098239, 0.13446251140727153, 0.15468519481439746, 0.14660371797940425, 0.23119275638413048, 0.09848288560826933, 0.08730193194482597, 0.19103887070330883, 0.1856738190737463, 0.11455711863574483, 0.17055772455228915, 0.0821062546944426, 0.13195351216821902, 0.18176082581762346, 0.13879809408418595, 0.16651071187469269, 0.1515574416806621, 0.105476540573422, 0.11172680679949061, 0.12982351194706657, 0.33147922747077485, 0.23791097975786657, 0.1317828737439648, 0.14314093927462257, 0.0828759279102087, 0.17044504834038599, 0.22849349154820367, 0.1703293997073366, 0.21266157979205733, 0.23552411025570286, 0.10189296512473976, 0.14407889136383611, 0.1908819758964162, 0.15900476625369442, 0.2584856958879579, 0.10667365254654039, 0.15546041450673537, 0.24438607746795302, 0.11134899521787321, 0.09960508184327234, 0.07298993096957285, 0.12224268123146989, 0.12334180289819358, 0.14816180292156436, 0.13196051421184696, 0.08332735288047022, 0.2128164368050714, 0.09646988999579223, 0.17960785828050108, 0.22086100352387275, 0.14554899876877186, 0.13109434456113847, 0.18572456473785062, 0.14300030085348314, 0.1951863787948124, 0.13923477952278432, 0.12206350858773916, 0.18581261888386744, 0.19548689976574915, 0.19378823768948356, 0.1736048699146317, 0.14318633764501543], [0.010447413942235853, 0.016028299353145543, 0.03828971413895488, 0.09644057181093002, 0.026007344375454614, 0.020023651849178058, 0.021205225643972238, 0.061746364940078034, 0.045396129585682385, 0.09115446554196459, 0.024703290358546282, 0.028624333283533494, 0.06508436324375291, 0.04906911515600739, 0.09610888638323355, 0.01714713533499068, 0.07028084488645678, 0.024454466915959795, 0.03800068448688235, 0.06415972193222373, 0.01898121302797189, 0.06778427925441535, 0.03761459532524309, 0.03649928622067936, 0.053709393983045896, 0.071865153018265, 0.01744379330756924, 0.028980667590193694, 0.0212349460249947, 0.04663156893765254, 0.06515649042182392, 0.04540713443871468, 0.032752331030825456, 0.041525704005072196, 0.012976255816137119, 0.050631838760549025, 0.09596229545892247, 0.040302514399011294, 0.0005153092218191183, 0.03930838508231025, 0.06530024682081516, 0.04141493535210048, 0.09090681229868243, 0.0637526955876139, 0.04435325026391976, 0.018960547806214423, 0.044774353474138245, 0.009848102401461332, 0.03524676693843738, 0.024312543382327405, 0.026971948663553885, 0.023902408635964798, 0.018791552640557773, 0.02926701401931144, 0.07155922346658285, 0.051886495428099755, 0.015929542001216643, 0.014963248489244331, 0.01779303747049022, 0.044198891208056486, 0.05297416408035544, 0.04923945480597116, 0.045442772848952206, 0.03851063091367964, 0.011205842902493334, 0.02911238874789448, 0.051046981806716615, 0.04583211788426965, 0.10353356539722412, 0.03693345889088608, 0.026968522335312543, 0.02894194950650056, 0.04180853983627693, 0.03644218968768274, 0.026633586779597308, 0.07592483679012907, 0.03191391483039385, 0.044941778159550125, 0.07018011964617238, 0.04100230124388491, 0.04043940281976135, 0.015386795519941278, 0.02103659245485981, 0.07700252331673138, 0.01936162739331203, 0.04446225691466563, 0.00813677401897768, 0.06158101635294096, 0.014546589546596572, 0.06541873764006362, 0.08501162016463858, 0.025488677952859192, 0.026803589350874388, 0.020703357614336476, 0.05317625424434101, 0.05108622083019826, 0.03843876420550289, 0.03647957860882725, 0.024565109164424004, 0.02043419070692072, 0.016625858467793273, 0.042867633408956954, 0.018707905415325396, 0.03723589891207315, 0.023379174414120858, 0.031331513722937916, 0.03023978097424392, 0.05689351203581018, 0.05723053709633889, 0.053508410816110914, 0.06371757045628564, 0.00719638002450548, 0.024751479204203335, 0.038226140332558466, 0.07527264315755137, 0.0150166840795728, 0.06586280050537278, 0.036612510185448394, 0.014447091962210836, 0.04358330125650091, 0.028369319850518823, 0.06543913090060796, 0.022765252619020404, 0.039681868267155467, 0.06041891459796218, 0.04288616890628492, 0.03343467405366321, 0.023744217225260312, 0.044295671095530835, 0.023354830055107034, 0.03642561154500131, 0.08608453396347263, 0.015606899283856395, 0.027981627649898012, 0.04068446285541981, 0.06596411563335888, 0.07075363604892647, 0.054439655805547396, 0.062247248546731096, 0.008784448690412026, 0.04221924340292331, 0.04804132776635309, 0.04994176208011566, 0.046916588119441466, 0.0144762760816863, 0.03738214892725791, 0.07454161141668597, 0.05162248237719459, 0.12861350671418253, 0.0708896779425202, 0.012856567026897064, 0.015480561809043492, 0.034106782141832576, 0.03384071980572997, 0.025006075119299274, 0.02145075682370413, 0.008551954411931576, 0.0497041292668831, 0.06526103077997124, 0.05197574084083881, 0.0104345541988169, 0.05987984916916298, 0.020750205806126038, 0.022904864482341275, 0.06501972840558137, 0.059391184664902195, 0.06491253738321605, 0.02078779007969124, 0.02585126736742114, 0.060659623254210725, 0.030697572135156205, 0.045636600754674406, 0.03455029725427589, 0.0027998038210846005, 0.00395774619743949, 0.001142309274948803, 0.07306050298915756, 0.08891039482888677, 0.044431850884950934, 0.07564074840516814, 0.036073031069170085, 0.021314803030221693, 0.003425294022646643, 0.03632641081968623, 0.04635585772414361, 0.03137697338036472, 0.046520696862811045, 0.011850546110391378, 0.000605856984029449, 0.009581665639885733, 0.033707466472180626, 0.029185668888291525, 0.057959665108712456, 0.06474445769262892, 0.03447265041271045, 0.06900622779803892, 0.05591753900291459, 0.022631327043317502, 0.035147443639054414, 0.08389690860865578, 0.01942872711937995, 0.04459251484443103, 0.04613207195014243, 0.01984283786206957, 0.010063880641433981, 0.06131734038072248, 0.028243329030491655, 0.01921194147378687, 0.0585066135822525, 0.01776374226826574, 0.026111859835744388, 0.002461260470050958, 0.025927236476432414, 0.003957412949192428, 0.046856787296072136, 0.03354771798777004, 0.12431324069057742, 0.07190709633211936, 0.04186411568474385, 0.028277799156644655, 0.04670601353169449, 0.06499935046679552, 0.02356024312546417, 0.03886396598611628, 0.05239302893319438, 0.017042642857338634, 0.04967642752754112, 0.015851966980394098, 0.010214064518109927, 0.007591912177421394, 0.07089379949555283, 0.0672116821571704, 0.033801871487089706, 0.0194074566881623, 0.009912166504129287, 0.017038938822224736, 0.05413309806176732, 0.024837815398049932, 0.020802548763552503, 0.03483877149260333, 0.044115276541560895, 0.06770354124807543, 0.028282445479905414, 0.0592779147348577, 0.06560868914088895, 0.03926706229967456, 0.01511855366369409, 0.04872341414973621, 0.02692855552830283, 0.07520183365071013, 0.045048961521036206, 0.008534085411097734, 0.08905204448608622, 0.0617416879733003, 0.023044026269006635, 0.03957485344501273, 0.0735887665782244, 0.017184962841471838, 0.026830950181090066, 0.06639453447273662, 0.030734445862171632, 0.09492276011094933, 0.055755971059683836, 0.044754423696788094, 0.006898923405265857, 0.04294868551134583, 0.08406998319250923, 0.021907645916085572, 0.02802223797076412, 0.02698974297081511, 0.010257436585943065, 0.01870663179415128, 0.015064914102455782, 0.029567454551016132, 0.02044085184142234, 0.022046166104114345, 0.032382777877031796, 0.01793134889955963, 0.04225405826864224, 0.09205756063062338, 0.03973639840560575, 0.044079618979125254, 0.025401658025540175, 0.019809411530713403, 0.025322429212411086, 0.010212725779462245, 0.04295169240644863, 0.032502176510470535, 0.02498300821189919, 0.03699891727357622, 0.08855915883736265, 0.04144040777558281, 0.09785547492004211, 0.0186282092885625, 0.014180708826789934, 0.039648742625309576, 0.013123778494886093, 0.03784148758577724, 0.03824278359271346, 0.07251499476091516, 0.0027908386771507082, 0.04782095491405457, 0.05078507166716361, 0.02480361340267043, 0.07345251018001188, 0.013748013748667173, 0.023627861876100786, 0.0726944585180571, 0.005491842532665619, 0.024009611149648988, 0.0011350291653446133, 0.02448100420165687, 0.03647441900665722, 0.05187769690828939, 0.007782024556710836, 0.02182338199007415, 0.03455488612094233, 0.022288707625721733, 0.022012454405006383, 0.021986190995742238, 0.0185907322673067, 0.026843891321350972, 0.013293675729073586, 0.023134633403031096, 0.032921161487578385, 0.0720698440507535, 0.022282536787491654, 0.04192485496582043, 0.08379897958929501, 0.030829850621821902, 0.04454060472668179, 0.058015938097190474, 0.046990653499960906, 0.030162383111253865, 0.02203298939181672, 0.04726952482615748, 0.04603756734380319, 0.0452382426949278, 0.06613718255633308, 0.06910765783921366, 0.02893722465922756, 0.05499262189973266, 0.1116740616459039, 0.008865166586943933, 0.05002901566425159, 0.05058069090028444, 0.04103376830537473, 0.03184298849514416, 0.01822805666785327, 0.08664067549210402, 0.01899367919371974, 0.11321415884360192, 0.1291478223978512, 0.12635122609114455, 0.11732962913811208, 0.19709631259883606, 0.12082708864322594, 0.13543368106888187, 0.10470243170857431, 0.11485557116928602, 0.23819956507894302, 0.22182967573884996, 0.19162370222470454, 0.10053219378835733, 0.20020624652745264, 0.11976081682669541, 0.1563511909015717, 0.10741884159224649, 0.1756741500069057, 0.13149036605271602, 0.09846367212312837, 0.22425874136388305, 0.08297115263919677, 0.12600453300101142, 0.18884775198755727, 0.1459861438601248, 0.15632393349322582, 0.1945367975220565, 0.19799648123162408, 0.1346148862954109, 0.12960608087239728, 0.16303539997146976, 0.11881036984343683, 0.1637668147562973, 0.14705141976235375, 0.10006447412794638, 0.10240229102031839, 0.23085687279460892, 0.14616481088582547, 0.15702567003186674, 0.11238925834937442, 0.22355282198517556, 0.2171788632028526, 0.18465332867157075, 0.13315319053588376, 0.15169228847709396, 0.1264206183353259, 0.15650902033573197, 0.05381034904970758, 0.0904328873260848, 0.1341657749106807, 0.04998623731455976, 0.1639546595153309, 0.12894453330626413, 0.12166273735103109, 0.194889749550531, 0.18921492260790643, 0.1263157638811296, 0.12091145024544771, 0.08749501674526161, 0.0857945773450117, 0.14205153160277875, 0.13847388567463045, 0.12948303182999935, 0.12858263337083403, 0.11767034674243582, 0.13121169390937976, 0.19322758390297815, 0.17975208199312612, 0.10060272750354583, 0.2811183846525608, 0.07919945663982823, 0.18561409485916938, 0.22671593773749568, 0.09326509906039124, 0.13050090221147384, 0.1363856066018343, 0.15638497537903248, 0.2491478042136277, 0.11686329609684407, 0.17480612642342047, 0.109599641103658, 0.17403775555712564, 0.09978155785750958, 0.11560934039974406, 0.16387878616731014, 0.2159380305918955, 0.1892610411009481, 0.1540278913753648, 0.23400768517486512, 0.13893671003320526, 0.13958259876216614, 0.3426605565173011, 0.07743959946017112, 0.1403928746379191, 0.11222880123363388, 0.10881420945928943, 0.16796926667373027, 0.15869724323912976, 0.12529440779959963, 0.18623101014283397, 0.08933728966381281, 0.15010961211256443, 0.0714877704458852, 0.14069400847919528, 0.11186032826381345, 0.21013214132718502, 0.1368958364811636, 0.11165371435063501, 0.1625542201462292, 0.20108507195067024, 0.13310101994824025, 0.1935186360271708, 0.11227942432367033, 0.1394627519672917, 0.16214348976650547, 0.1532428810793546, 0.11451067838577494, 0.16886442509149352, 0.12541527349141338, 0.06703936600036199, 0.13353471764393393, 0.3526303328333363, 0.19108028541649544, 0.15362966355056534, 0.09106230516467365, 0.1842986299626289, 0.14804770178612203, 0.2423107452810772, 0.15656624710367573, 0.1464490601492505, 0.08501448533347539, 0.1684164321951328, 0.22577188758840486, 0.15991425051564173, 0.1346154072351994, 0.11324933760108487, 0.18296936016169288, 0.13852381928553506, 0.1583953586316878, 0.22088734162670953, 0.17805671409493495, 0.1779585629100761, 0.10855121147488395, 0.15620217147854068, 0.16417167690252105, 0.11827979266883866, 0.08748452900157822, 0.19014647020207298, 0.09785243355098272, 0.2443166852237717, 0.17128569194145743, 0.16388027237788325, 0.1454268383883661, 0.17253662159125652, 0.13000797059747482, 0.10900167883524012, 0.1958493972497602, 0.16834840358745667, 0.2444507352887623, 0.14704892231572061, 0.16135728437333338, 0.1281715122862689, 0.1309865406684337, 0.11255339268715152, 0.17156324559642425, 0.11243586713868765, 0.16980338841676715, 0.18472423776984218, 0.07737024552038602, 0.13934819117909478, 0.1806369901544625, 0.11114195229545717, 0.09047277752430209, 0.15444234494240056, 0.2392553414909109, 0.059114006393018274, 0.25776618610947366], [0.06559478464506327, 0.06423000666883684, 0.032719251354255026, 0.006959885330645428, 0.03207197600615121, 0.042465896901464274, 0.06950651385611104, 0.06484692961338066, 0.052756974323382305, 0.025876958125961885, 0.05151297776929794, 0.03285900877428151, 0.00843852743386261, 0.0055764138514566575, 0.038770698611774755, 0.01308371305405613, 0.007540722182320972, 0.11086260599474754, 0.014744506446614623, 0.048715400870048234, 0.02584940194332552, 0.03236213946835168, 0.006985678074641094, 0.01819600163388156, 0.020972453658619238, 0.023871820660368092, 0.05026715026507455, 0.01867994895174859, 0.05685964328867774, 0.08522234030909116, 0.09647051818789014, 0.0466825329368153, 0.055420137265877384, 0.01681139538695495, 0.024567608526276968, 0.015270464111029383, 0.03285895897856644, 0.05541345314873804, 0.039965707673541004, 0.0770109196403815, 0.02536786205676054, 0.04893311156680988, 0.03874493124444158, 0.01220080150937241, 0.02044098973724871, 0.0763833710563279, 0.04959205443400049, 0.03259364357819, 0.05941389917185711, 0.0126620122952567, 0.055212807060489734, 0.023992448864925294, 0.06472462367626929, 0.016140294704406012, 0.046613201979667916, 0.09597970863744136, 0.0632106079419534, 0.039384683609128966, 0.050536426340019515, 0.015847676888018126, 0.030302891297446146, 0.0197347620081517, 0.02916043969772516, 0.10119165759533645, 0.050146552704034314, 0.06900483351801673, 0.04938075206272545, 0.05376623770702751, 0.028296409347545237, 0.03355758903067439, 0.07603875406446957, 0.04230021506608014, 0.04890852014444048, 0.024982247869634343, 0.0314585100333657, 0.043687194270352205, 0.03121917650494124, 0.03734517369359251, 0.01918459021967025, 0.05589115876524199, 0.06625159778782437, 0.04912972803257647, 0.04742250109331743, 0.00481495357704379, 0.15862996539761945, 0.03236952455594175, 0.09888783968504399, 0.01080595266689817, 0.05377659138532416, 0.035978147249308326, 0.05244354477092143, 0.025830190373404373, 0.0625642633906776, 0.014540481910620247, 0.042313736517943686, 0.014785943184829047, 0.028327372706224842, 0.044017393487475576, 0.021086135360923026, 0.07305584517457793, 0.027251748871358655, 0.11580437872438662, 0.057014565419165365, 0.059019800560969504, 0.0659097999995274, 0.042464728617379745, 0.12322017111845555, 0.018499383943215496, 0.015511978117208329, 0.03786284611710618, 0.05697667471043045, 0.004818877862435916, 0.03397340240377573, 0.05030821257781598, 0.07465420335891747, 0.0617720595290584, 0.028383509714096308, 0.0145945772941735, 0.04141565164430969, 0.052841830052315235, 0.02302775264627511, 0.016141834541133816, 0.07762614953061266, 0.010283304502316301, 0.06667030314283987, 0.01503292035551802, 0.020827712836645303, 0.01677031966767484, 0.050048815206654614, 0.06016127156814741, 0.05117190776452903, 0.0025726415145571435, 0.016725719943943045, 0.07438582743728354, 0.03644541874828358, 0.02742336980337578, 0.05230817703470107, 0.04525050393215591, 0.03662867847109034, 0.07714426490448176, 0.04403122520494846, 0.028025039937347177, 0.02380967943839008, 0.07733302130814522, 0.053352634497587724, 0.027938318784318628, 0.009917732132899185, 0.05597985259467556, 0.015042255136875377, 0.051221381722679066, 0.03836459157267406, 0.025314892822455977, 0.03501536625046884, 0.04229307129618622, 0.013722433115265543, 0.07400338868460349, 0.006340927943857688, 0.01948111795730168, 0.06558517024161355, 0.015424837531041236, 0.02229186582318958, 0.032050374241906314, 0.046791321252502745, 0.04590486942399894, 0.03578246924124899, 0.031916161383231806, 0.03713032433522805, 0.018762586856140726, 0.03155712470141871, 0.023855533631097887, 0.06847211129723058, 0.03747196890594017, 0.014343553264024518, 0.011173234369996335, 0.04171078701713874, 0.03473426177797299, 0.054985003155325694, 0.054127084271561716, 0.028342403351299228, 0.02458452183242527, 0.050837238424367485, 0.06799754281077655, 0.045483999870597355, 0.04214682128100146, 0.03449816497102861, 0.06612353086952241, 0.03789765715238549, 0.016939870247076598, 0.04769614769987041, 0.026054954824728832, 0.06840180740841935, 0.022085904999966585, 0.02070538200167639, 0.0714108475574082, 0.01446789124935505, 0.03281170667539681, 0.08528635461604403, 0.04660413532908406, 0.07566163196198403, 0.020914460802751205, 0.022534020470395204, 0.04060265998686514, 0.03162821383035231, 0.0346647163162068, 0.0167086917246061, 0.011641987291495166, 0.038080955179588455, 0.015883146758912312, 0.08514735562306258, 0.0134225029896404, 0.010156279463591355, 0.006566646174647876, 0.056641495921799255, 0.04358210232889941, 0.04641598413488077, 0.065456390861542, 0.040223722255999045, 0.030735970377140952, 0.07815065162797129, 0.06148850740564447, 0.008195667985766646, 0.04673215245167094, 0.060248057838649526, 0.05128603571304872, 0.03419896550176125, 0.052067537326365716, 0.020509924243895278, 0.06810867918595191, 0.058665929226985866, 0.04826186915799495, 0.04040646103901729, 0.09272140646052938, 0.042248917818670316, 0.012859488694718289, 0.0372609461567575, 0.0807402279948996, 0.04438845200404044, 0.012206252224953666, 0.013733738657808112, 0.1601513853717235, 0.0317305478552777, 0.039637779907113126, 0.0407650170006579, 0.07470933870682794, 0.049814097357973944, 0.023278357243285547, 0.022762963931346615, 0.048573402642843225, 0.04880048642535845, 0.06553791027756468, 0.022365741596947757, 0.09315764756813165, 0.026324150460441748, 0.024715042147304744, 0.07118426939292301, 0.07904935703282395, 0.03351678718782721, 0.04427211389185921, 0.009889894412950644, 0.05371150455527729, 0.05199102046448858, 0.010455188777057395, 0.015209394454535459, 0.03266028556672316, 0.0660651856132092, 0.06257553637448339, 0.045041358098387725, 0.09940435914623161, 0.05768055629525935, 0.03058760212884555, 0.013373436015700142, 0.049216912668799205, 0.03067352846565266, 0.03359773969878593, 0.01906980152031587, 0.04156010901375164, 0.05029901186184538, 0.02331212639898783, 0.03539998452329347, 0.011233581031011719, 0.046507914685794426, 0.04138757452188481, 0.10301965063497906, 0.08200309329455899, 0.0830566710341842, 0.030829894671877547, 0.07632878729172292, 0.06888341624289751, 0.025083342747342204, 0.0576290560345496, 0.07159176688160628, 0.057631752664043065, 0.016117218220906875, 0.07417759707858486, 0.030223708449592514, 0.013779101596634476, 0.009734865987763531, 0.020040090180813305, 0.04965866194857706, 0.022067606989895145, 0.08437937546160915, 0.028943370599600098, 0.09460487192676914, 0.08015641537044318, 0.028426561940221057, 0.06782536454979451, 0.09774792383635238, 0.015908384567967827, 0.054790834340477185, 0.020699804881587625, 0.08020359106482038, 0.03114739981209559, 0.02445545899982174, 0.07156509936096207, 0.02072411859708448, 0.05923232101204415, 0.05555257854622699, 0.019421150509808815, 0.03122021646929845, 0.058087494539757895, 0.06319688730722954, 0.026678885558560014, 0.012759603278320885, 0.029022813917347984, 0.04453973904732735, 0.055250360690537965, 0.03566185635845027, 0.0342755934463874, 0.03765390712707754, 0.06886606435141257, 0.1038761139516869, 0.08625689608555648, 0.02729798036236917, 0.03509708867979146, 0.030944968738983718, 0.04735951334418309, 0.056554805412287676, 0.039497911404337616, 0.06404588126667565, 0.06101866568168325, 0.01585111566518824, 0.062300273322410164, 0.07590055180292937, 0.057601331312569885, 0.054394809018460014, 0.03100014622173002, 0.05587125197052956, 0.015027674568456509, 0.053363459319957805, 0.06234643778072731, 0.028191905378574328, 0.015179711420299306, 0.15252533248595654, 0.21272789236278306, 0.12450925960776307, 0.09744404740030728, 0.23718664362545938, 0.13377585147898044, 0.15100205857907573, 0.09713915206732289, 0.16276042037192853, 0.19571442787926044, 0.20583697744915563, 0.11323406180787472, 0.251299821801724, 0.1825458974006676, 0.13267610162015886, 0.12220743352607374, 0.1430793458055104, 0.23611651072579048, 0.10224554177013137, 0.16538185067474842, 0.1529368902406385, 0.12921172945249465, 0.15974410238765901, 0.11529542055101165, 0.10552668102806616, 0.20634087944223037, 0.1956554084655739, 0.124808524194504, 0.10976363754560871, 0.2640500989171767, 0.18920933016605918, 0.1113259589539901, 0.1973527681923682, 0.11781421039373645, 0.1434932324674822, 0.1197308015018221, 0.26736410334706306, 0.1751625411693127, 0.15947905128761647, 0.1692308296239184, 0.12146215254981672, 0.18391626015786203, 0.1459287638745962, 0.14230640905518688, 0.07750746718938313, 0.11254874253345114, 0.24037396775618677, 0.23513296108332374, 0.131348256742762, 0.07951254145272317, 0.20116587890492332, 0.12436749503737497, 0.11626150338880478, 0.0825458819106702, 0.19029855397680115, 0.23727229225539395, 0.13815068850113502, 0.15438429079949856, 0.13788117876937314, 0.0903323765904192, 0.1438263581404763, 0.1431793049578705, 0.15929031786659073, 0.3114691334626367, 0.08262342533036586, 0.10821954136894596, 0.15656224812471098, 0.18474679139833297, 0.1467483553795084, 0.08770221288526252, 0.1446592948970295, 0.15567396917650778, 0.19279783922097377, 0.2340791611782005, 0.09892491834057916, 0.23593896218845922, 0.09791317666249891, 0.07664780162515179, 0.08501901291310789, 0.28626802767957416, 0.18381671469298103, 0.11444063496685798, 0.12709124404336178, 0.20724800415337088, 0.3126888986556761, 0.21503784663734898, 0.2501475489548137, 0.10401040916481327, 0.12932489596066937, 0.09577012230311671, 0.10369555468881324, 0.18453437053868849, 0.18097147946396183, 0.1077128048505514, 0.14356118446636584, 0.11025179643183948, 0.07709440790236959, 0.0931984800544958, 0.09021993020489331, 0.15168001574854698, 0.1430199433478617, 0.24838438227532372, 0.1367222562792801, 0.138429130818094, 0.16514152889290165, 0.1442032887209808, 0.23297518251403687, 0.11403391122697823, 0.1134953054509336, 0.13822237900908918, 0.13899664875240098, 0.09962406550203601, 0.11435261146435816, 0.16217866852398843, 0.22933146916329863, 0.1243431794066583, 0.11683405452077428, 0.14850720132310546, 0.13907174069073894, 0.1369152951144403, 0.1502278194792809, 0.14545342163933864, 0.1342387218028307, 0.12489765086361479, 0.13765812460933963, 0.20418815705324375, 0.2673886181606401, 0.1436998617024191, 0.11709529816383317, 0.1639640057880071, 0.1366926699636444, 0.17530697938655654, 0.13064576943795528, 0.17646066183524747, 0.1952919763542952, 0.12649978586142102, 0.11609582155342064, 0.21208439382814595, 0.06473987648684172, 0.1897868991739327, 0.09191756572334037, 0.16007571120656308, 0.0961809522742706, 0.19872572032674668, 0.20000330983631073, 0.09309794633619248, 0.1260923343380132, 0.14346252766347703, 0.12756736002742283, 0.16017315759053155, 0.09680390433077851, 0.12486144554831329, 0.16038714126954157, 0.14767259449487732, 0.22692543214126942, 0.21336048180537842, 0.13499166365833054, 0.12152694826645237, 0.16691928188646996, 0.1438935440514357, 0.09991907830079717, 0.0900165951480308, 0.10688336145493293, 0.14198224661090683, 0.14644038803394765, 0.1171099457649454, 0.16684998157283953, 0.16106624757089924, 0.09621089099035149, 0.08333507504674696, 0.18759551998828689, 0.10906070590980592, 0.1447015523069328, 0.1743288842901107, 0.1908410974447766, 0.09323160569634169], [0.017841938777916858, 0.03187794700234888, 0.04684294408728038, 0.031189228212761304, 0.006567777111946095, 0.03478571607340728, 0.03309685609213287, 0.01726124987697169, 0.012903452565472935, 0.04260327178804625, 0.0031786828983439916, 0.01738215004274201, 0.022162381642227693, 0.02685442694552964, 0.024801895450500232, 0.08088354006289475, 0.010349963727827755, 0.04774114770454265, 0.03721288563082776, 0.04287684178580681, 0.030974248619449717, 0.03184342899570062, 0.02166990585054361, 0.029055592904408133, 0.04792092555773355, 0.06158678116457117, 0.059565944642189055, 0.023298273614097028, 0.07306510717758248, 0.02698865321074282, 0.0758597499600822, 0.03764715023158539, 0.013591613068485693, 0.014021743667281926, 0.036960141733288765, 0.05449736903932306, 0.014365979530397924, 0.07224852639821268, 0.057239389242303956, 0.04200430977488718, 0.04425531358367974, 0.07576306966403801, 0.022606657096935857, 0.04535366916247914, 0.04274808921881261, 0.0508160139584253, 0.030865033209744482, 0.016388723611711495, 0.04761571229826059, 0.0323879144965641, 0.06331617102747963, 0.07100185619727259, 0.015265796720350703, 0.02276614319623238, 0.03010113821214726, 0.02957478792767131, 0.04448633505812576, 0.02039676922703943, 0.08044282500181468, 0.006251827130214342, 0.07880385649660904, 0.06412124133578713, 0.03342836531960676, 0.041496144502513835, 0.03003238948182233, 0.04021639845544293, 0.03545875495840465, 0.033009709760306344, 0.05413058146293606, 0.0537336100223324, 0.049869148436212735, 0.06309971288447419, 0.028035581307185274, 0.08612561925885179, 0.004545893443132481, 0.01832939477847709, 0.05818222131159517, 0.011205151508141671, 0.015377279750311808, 0.004512055818321965, 0.06429710064924533, 0.04983360195652612, 0.024379106846848325, 0.02238145406027475, 0.031602262601917314, 0.03978569999397282, 0.01545577024620387, 0.0180627636220907, 0.06189899646767205, 0.04154291033985154, 0.04160791290022674, 0.024952786043286327, 0.09341535188498036, 0.03429528190604141, 0.09818439477033193, 0.012360419758835868, 0.0305340085328827, 0.06468981264098998, 0.036108546905339725, 0.016719719560276118, 0.0429809493042769, 0.024123664404596054, 0.032324612651380806, 0.030098089182208625, 0.012000727114237606, 0.028012391825717305, 0.01994513358259874, 0.05669714454861899, 0.030745557967513323, 0.04466850693608004, 0.028776438125679572, 0.11469537452343972, 0.05778863214917722, 0.05156502578287356, 0.01717890117077097, 0.034453796988893906, 0.01010145725411994, 0.023668048933388728, 0.024263596109625314, 0.05648389631401628, 0.032135243377377914, 0.07055357218750062, 0.032844939569552103, 0.023487001289463332, 0.053936286243580045, 0.0718908705898831, 0.022586844147994153, 0.07920596072630537, 0.013631173848895537, 0.09233159794201774, 0.030504868463462884, 0.019416144125223644, 0.02044986295063169, 0.028240140189506838, 0.049591636916081754, 0.013371471957784268, 0.051333265033580606, 0.0591303700310809, 0.053250614568711295, 0.009869888984417964, 0.13257985033335226, 0.11453276470063195, 0.06816753006029515, 0.03233377889339482, 0.042405789642925226, 0.050955311725697214, 0.023782307116855538, 0.03922430310218085, 0.04484523958977192, 0.04000254118094041, 0.02097508325541933, 0.03269519619343262, 0.021637088559087247, 0.05332292943832375, 0.03939148263945695, 0.03625892996487599, 0.09718937679163872, 0.049930680618290944, 0.04506292730389584, 0.03946117748836837, 0.03782206342645711, 0.1034699188124749, 0.01142725476153916, 0.014346338951239183, 0.011959921440950805, 0.027894144239384803, 0.008078711257586557, 0.012182534142817942, 0.029141927183034922, 0.0330504541465592, 0.018454690373712973, 0.013431674019703943, 0.03952842851680133, 0.02949771373682926, 0.027360466323913108, 0.018745378606141578, 0.03270036345648189, 0.0548398218327953, 0.03578746413451529, 0.027855498934044477, 0.008319348093092201, 0.03982262926236276, 0.03865202776186409, 0.028986486027978604, 0.019166887842959935, 0.05451260269769738, 0.006990849168129987, 0.02836764594840427, 0.04354598894414883, 0.04840529230873912, 0.030359486042852366, 0.0419352661007114, 0.014015163929622262, 0.01277654914320597, 0.032097390973039215, 0.027375186703378157, 0.05019524525250158, 0.03786909356412869, 0.03529451336831816, 0.021003692808951584, 0.041531840369345686, 0.02947807315767052, 0.05894809856169647, 0.032434714807858395, 0.030559565226036697, 0.07511028614375861, 0.029026617543892037, 0.009016058137339931, 0.04293320670483574, 0.02499284286562714, 0.08370472013109154, 0.038802031607877825, 0.004686987207781885, 0.08316420679611546, 0.021667868056665027, 0.042233565416667736, 0.0361038890907601, 0.024695095132976293, 0.05676268720098081, 0.032688033271340594, 0.02784508205349407, 0.04361092638705046, 0.06344444095908154, 0.007387047817540025, 0.04070582521718837, 0.03443998825405875, 0.07741698454464636, 0.006477246107909108, 0.03588970622888977, 0.04812996796963196, 0.10678227615332413, 0.007902850028908542, 0.01476588796058129, 0.01731878308008515, 0.03568555911882751, 0.037868840755113674, 0.03258183816327684, 0.07736383336445979, 0.06204844873038031, 0.010381081261702124, 0.04071161301145631, 0.02072289860206506, 0.004714103847471697, 0.018350795444641865, 0.05267286169973593, 0.00882663332196253, 0.07246605706431213, 0.03761278735774179, 0.0267983473942525, 0.018116876242622253, 0.04581625603379742, 0.08092033526589794, 0.030635959513845946, 0.0463232989873617, 0.06473191683330844, 0.06252704683931605, 0.0870700064866293, 0.04107378490809952, 0.011324945634471313, 0.024276056529713735, 0.04353948868811131, 0.012081196989804026, 0.04861602777495019, 0.04162135774329786, 0.048644319401993874, 0.06696199112000965, 0.036605335772037506, 0.0316235406940142, 0.0903489470722214, 0.04775252027977859, 0.02411040342262676, 0.03456802835928337, 0.04530442120026677, 0.05614157758593079, 0.04864777062809275, 0.07712023272629707, 0.05569390261605863, 0.04587284694876402, 0.038769641410439246, 0.009567044851850838, 0.05019613008405413, 0.007148121752130289, 0.0016394481480669892, 0.030063419873195312, 0.039827988047393105, 0.016766307282171423, 0.03487351741040907, 0.03825368119343635, 0.09665061013712999, 0.040055519991344025, 0.046811886882830056, 0.04167186592014567, 0.02901168074458838, 0.0282320981815217, 0.01382227065116768, 0.026980955942323612, 0.021476508869278817, 0.07924774316169562, 0.025941087346103404, 0.04851648997094843, 0.016562244441780834, 0.02428735058093744, 0.036093983573899154, 0.007544523414840261, 0.017645636408199227, 0.02844891064019213, 0.06396029392377504, 0.02911999408576277, 0.03497428095508968, 0.04054546386243836, 0.04897877806797624, 0.04727140940245121, 0.06044167123975293, 0.05856899612192666, 0.11908862063841474, 0.059320539866964665, 0.018534277332946658, 0.044168665209004, 0.027127002944208445, 0.037198253351474, 0.03040272787573838, 0.05756598401574358, 0.03822727031224678, 0.01664996342433076, 0.03001063641521239, 0.03231602480574962, 0.0030856582781134717, 0.05318090439804139, 0.07039031118995721, 0.013007015203906885, 0.08244109640438711, 0.049896700788409486, 0.05128025941009964, 0.025706371412642544, 0.04817970239767625, 0.004505542634550723, 0.012961092063285893, 0.037781250092291066, 0.025938607136448546, 0.05951209632199138, 0.02405569708395389, 0.0539284031988392, 0.00844810449052602, 0.03073702566325665, 0.03762353940175907, 0.018360005736711527, 0.05727115890852386, 0.022102768510399808, 0.056890053148832054, 0.04916598697403266, 0.020052468246449868, 0.08131883888235016, 0.165637846615526, 0.1380873483515555, 0.09326063276779267, 0.19902878470959204, 0.07493832238739537, 0.1352560712445167, 0.08791176857607019, 0.095808687169225, 0.20591255968376515, 0.10920009560762875, 0.08827392898139455, 0.09508698637927733, 0.12989776118868782, 0.1977563739543961, 0.08887579063734702, 0.17923477346137648, 0.09602309219659337, 0.15530563410251372, 0.2057873196299038, 0.1660825759773293, 0.1010838537026317, 0.15717196218188734, 0.09226425115259425, 0.10502452571545878, 0.1338259536292284, 0.16758695815599736, 0.16649139113724234, 0.21313014981006423, 0.16542551768643243, 0.1280038462831609, 0.11408387548139981, 0.12866725544295005, 0.15617200293608252, 0.06599505026374133, 0.15854083872850866, 0.14268300255700467, 0.14191651626700355, 0.12252554387575197, 0.13206359900293813, 0.12631220923316094, 0.1018454370299174, 0.10258007704490617, 0.1637360486652582, 0.10572649974135623, 0.11766332937704942, 0.11553580361989238, 0.24483558721840384, 0.0930342537861678, 0.12320324823620821, 0.10173970157460821, 0.21869357224673996, 0.12610100645331607, 0.13486991696540387, 0.10162511014289434, 0.16297837238638632, 0.19480491297379618, 0.15239103727283018, 0.13506321627045834, 0.1671056557566889, 0.16269637542145868, 0.10928636476878198, 0.18041922200110652, 0.12131654221804873, 0.15741737078755133, 0.11681192990152106, 0.17037179501306626, 0.09193784407069606, 0.1403306989419845, 0.15479423976953954, 0.09634472655072328, 0.16073192680074325, 0.12231840902278501, 0.10016983420017267, 0.18676327271086557, 0.10931468703934263, 0.16425603850474282, 0.1517042854139882, 0.1123240183017427, 0.1548740201659741, 0.11254135744586108, 0.312557008958632, 0.1185079183309309, 0.12604330471085926, 0.1335162242814418, 0.1322854274222928, 0.15653756477179068, 0.1880038295301699, 0.08709631394594909, 0.10905873706384052, 0.11117462594542774, 0.09160543852035077, 0.11607231797590373, 0.12185584513410447, 0.12207775016225154, 0.1677562176219879, 0.12796664505355781, 0.08442039180907511, 0.14269858478538452, 0.17154266847477806, 0.14477298234499272, 0.14694084263136312, 0.10382164510027056, 0.10567537103328975, 0.20058919855904198, 0.09718927720020856, 0.16751379675922856, 0.13440969730577162, 0.1569866301912454, 0.0786084504497628, 0.11599426127729878, 0.1225019253850464, 0.23041445701833696, 0.17269319464122096, 0.12068647320472425, 0.10452827694074762, 0.13980085721179364, 0.18202449795940231, 0.1484160215383576, 0.16886773459132642, 0.12688495954799076, 0.08723572662640965, 0.1844767760485411, 0.10005453796756845, 0.11079394153409428, 0.20700849442472383, 0.12181108261668876, 0.10131098345042237, 0.15644361174875693, 0.06820650095300329, 0.1739567647417707, 0.11759226706119315, 0.10313721448783914, 0.13838017779973247, 0.16299818342010822, 0.18692372216572686, 0.23150938052323558, 0.16243310164540045, 0.16966688687041884, 0.2576218245010222, 0.12301721144467594, 0.19577545444330863, 0.17779423705031797, 0.20697503170419126, 0.12325747960036802, 0.09847143259380134, 0.1891640390479757, 0.13321205673198547, 0.11537176887354544, 0.18944409014957567, 0.1342961171101178, 0.09438738722594515, 0.11985305381277878, 0.17232662156945275, 0.10765941618310829, 0.17265580955051607, 0.11729825017673355, 0.1454016953826912, 0.1380879918654119, 0.17936116264712426, 0.055096036108631286, 0.22668875693794222, 0.3165317795449688, 0.208266809162113, 0.23271926318205174, 0.13301327223739318, 0.1496794997083564, 0.08725197535128364, 0.11871120742251796, 0.15141619038918328, 0.15057888693146168, 0.14046019844470486, 0.26728234644378385, 0.1670605025344318, 0.09558680512371565, 0.217183766165568, 0.16713985392162878], [0.06495553789840591, 0.016717126352652427, 0.02239380339761415, 0.03806215921236623, 0.059650087909352396, 0.00548305502536917, 0.0446183511596774, 0.0507297141537551, 0.03509166094684794, 0.056799386642993464, 0.04712696352432813, 0.07506458899907528, 0.0075358230500451985, 0.048790707313005006, 0.015842189783260466, 0.054438008716510194, 0.03236894615955892, 0.07928250057082023, 0.03527692015913706, 0.01973371246769544, 0.02535601259179173, 0.033095071107269294, 0.05956191501970734, 0.061091574269437024, 0.07271407802979793, 0.016988777300162662, 0.010134995625835034, 0.08516232498110303, 0.06508974884186061, 0.025799483654179403, 0.015247136733735041, 0.09135931745291719, 0.06270206728649717, 0.022884842774440205, 0.01828593461053266, 0.03569098685177104, 0.0481076748110354, 0.06509307366345199, 0.05206292164662192, 0.07193526538509516, 0.029798370688372565, 0.04946952633139107, 0.009310415930925839, 0.014647564723066267, 0.018440983145527782, 0.029440341412179896, 0.015215566250375442, 0.04591179485883444, 0.02789454068988562, 0.014334188796760095, 0.05439007842552759, 0.036523567377439434, 0.049559319496995984, 0.05499866633345524, 0.04514607848719724, 0.056691207367205815, 0.07488303382190005, 0.04330028539463397, 0.05493645233312442, 0.020388863199660857, 0.02110392583774463, 0.028035380209105152, 0.11752034672686171, 0.030503012615466313, 0.046145237171121185, 0.05963526793845719, 0.04486826053189655, 0.06373406432929539, 0.05911080414549478, 0.0080399357172991, 0.025934836068641276, 0.03626490162024575, 0.018050128916999506, 0.05710915812561589, 0.025151359863699447, 0.06333200606487452, 0.01848412730220345, 0.018575314747830553, 0.012989941019294484, 0.04655774104438963, 0.0779150566086173, 0.012696243018933363, 0.07469297506876531, 0.03545191379324083, 0.009101377349467048, 0.0317229597543877, 0.01752167380595159, 0.014155302478391078, 0.010957194702519525, 0.005152106478494863, 0.03302771282652694, 0.026800904212699785, 0.033427717975310745, 0.023437157693889835, 0.13648584154584717, 0.03622648614128271, 0.06411923035498589, 0.038033990159390435, 0.019348105941448483, 0.04265383742148838, 0.023029438039708524, 0.0263604553671734, 0.035895972828110384, 0.060614941176027066, 0.05513248657206855, 0.03477636980073106, 0.09296180485116859, 0.06060710026612205, 0.03428295938177936, 0.015506277465441776, 0.021424177403171218, 0.023074750225209904, 0.04112459185923781, 0.07855970427514085, 0.010620591947959076, 0.048700105924639976, 0.06640974897891283, 0.03139862685554451, 0.03833280275425604, 0.025237069780667944, 0.05040768526434418, 0.05136931713129725, 0.03642056685601992, 0.04471887721710148, 0.08775767765098041, 0.05044802362399717, 0.026571108478932615, 0.02659799624985505, 0.08540199558821418, 0.016465223236610333, 0.004706995030339327, 0.04279695796750246, 0.04599765033250855, 0.050898008348961035, 0.01673570206959642, 0.073620084252569, 0.04120767409462602, 0.06083662786911573, 0.07395775282695409, 0.013545051202057831, 0.007032338096084254, 0.038476417426981276, 0.03326159180893052, 0.0419952392938637, 0.02247192329847284, 0.01214217375813713, 0.07944659660420111, 0.03579067787335765, 0.031624440847325234, 0.010173737649775801, 0.07457981622146984, 0.060543162567961606, 0.024934156700187636, 0.05509422048025074, 0.01988902530302444, 0.03018171342480327, 0.042520748796842756, 0.04133954846991166, 0.042673843807630965, 0.049726054703276006, 0.062267683942111275, 0.022724199882378022, 0.015639606450173645, 0.06862011948420156, 0.06459250415284788, 0.052577361179095124, 0.11439774936485676, 0.009589214478769611, 0.025729737094333096, 0.045415760588742075, 0.041418765791721886, 0.04672456818122057, 0.08324588709060224, 0.030871320876383015, 0.0361260098795737, 0.012047584882126221, 0.06040512884576475, 0.023300468456000093, 0.02240011021645079, 0.049310961452823494, 0.04640141314256095, 0.02805201389316109, 0.026489504793238257, 0.05987036500066038, 0.051509304377701015, 0.0639515183866024, 0.023197184482048598, 0.08131061875892263, 0.023954567732289437, 0.05605224024264082, 0.03558320977214364, 0.04301282239236659, 0.07424792395003381, 0.0698676553644961, 0.07849713787436485, 0.023550780024379495, 0.05389054313362126, 0.02213205605174505, 0.07305987479705965, 0.008642799033212566, 0.006123777927695624, 0.04636537253616318, 0.015886818235289427, 0.09707093959854496, 0.01892658904375088, 0.06450733049742638, 0.004455930780574319, 0.08964071410798258, 0.030418181784390926, 0.008537467689283432, 0.057730608649792216, 0.07453319211039813, 0.08620271068667212, 0.05070768146505279, 0.03767167270604161, 0.04400306764329153, 0.030906394296776385, 0.05702004677826359, 0.02301856150640355, 0.01245386524861979, 0.006953678103238946, 0.002129753636601832, 0.014878926149028686, 0.0670456325995826, 0.08510616307537403, 0.0320142915006727, 0.056182103637125225, 0.01276442580180423, 0.05814339597559264, 0.03617031657467446, 0.06422279012059012, 0.019471834886879213, 0.022480378993937088, 0.0755360624903152, 0.029454332092897068, 0.013007791825540125, 0.052320832807210185, 0.041564648084703, 0.0056400331443235766, 0.03785910377759607, 0.03354277289021881, 0.044347313082506584, 0.07204669287368175, 0.09009885766934003, 0.03587553360229058, 0.0036525947038054227, 0.0397593695520153, 0.030362740001310746, 0.024110792212248332, 0.049221413435354355, 0.04915477144682119, 0.04393860517490295, 0.026722410843978008, 0.028363681443396117, 0.02798618395782767, 0.041902760990084185, 0.032188819736362465, 0.017000994487335126, 0.046089044621875214, 0.06457214919669975, 0.045096926285975406, 0.03835471669933008, 0.09381577072124328, 0.0222087548595042, 0.040255457448262366, 0.011538519456441845, 0.030100354887244683, 0.053327897518512704, 0.08734619650509089, 0.03695178371403487, 0.018468003066617156, 0.029434373587249752, 0.03769585810181114, 0.030430939063550006, 0.032605927798055837, 0.07278622819050666, 0.01862914200061031, 0.0388810612381466, 0.046096594418369, 0.041745548256702965, 0.015247309103518005, 0.12644665766387217, 0.045688426602751984, 0.03218626483313499, 0.05104993890610434, 0.10083354979513154, 0.013795745814399374, 0.03840615950344551, 0.04119378492055882, 0.04530455526565352, 0.061735796757162585, 0.027380677638575438, 0.06378636515188603, 0.07114234140082713, 0.05486696432795256, 0.09798183346227293, 0.07026943783726423, 0.051044423073049516, 0.05575991641249388, 0.041445892965120655, 0.0745323800571984, 0.0311557061204146, 0.02103566357325162, 0.08513263141315791, 0.05184891881541379, 0.02232800793623732, 0.01632504063778587, 0.04187683657472653, 0.04006470538555615, 0.013755846997692943, 0.01858117915089092, 0.014774180862361626, 0.027813235778481733, 0.038627850026973796, 0.06040004968282677, 0.029955981787474408, 0.006790807331731964, 0.03217916319807691, 0.033965373802329266, 0.05058586199377334, 0.024266223791205598, 0.02968511608008656, 0.057120005930623705, 0.05565300501222092, 0.029255721883307544, 0.02202039873678117, 0.03163693574137025, 0.02106347639534262, 0.02607620035808894, 0.04079833799492448, 0.03572417378065086, 0.07227963722881771, 0.04911121168744661, 0.006737038014351481, 0.03901426477598087, 0.032804329248685996, 0.02437213736195718, 0.031850199297731446, 0.07084158294263386, 0.03895657452484293, 0.04462061111905402, 0.032227836594346075, 0.024410240660091082, 0.011475404345190093, 0.024401624086162737, 0.012736891644195685, 0.04963049672604088, 0.04681932559657482, 0.03563087959323199, 0.06987330909337729, 0.0528008941440813, 0.018345630096812404, 0.12535378727461063, 0.178070503677572, 0.08226610660072296, 0.127974191019612, 0.2093323455342362, 0.07787860614518005, 0.15139159896681387, 0.10814169151408058, 0.17470382304201204, 0.14975069992003903, 0.08239009027038852, 0.16687825021724548, 0.09974444855845745, 0.14982890217534958, 0.09354086773049447, 0.13557932970504608, 0.1539400517339668, 0.12059846502398291, 0.2486892393039119, 0.2125105072533892, 0.12138229554458974, 0.11422645976586689, 0.18288950315646588, 0.29735102168013977, 0.12061975460739867, 0.15543812134813878, 0.10686858361887355, 0.1748419486947598, 0.08799306582659484, 0.1733104623253307, 0.1714880157622599, 0.20795844345083161, 0.1504085089771017, 0.1145933009684086, 0.13138928841198647, 0.1350337525288905, 0.2052253481721686, 0.1949631254519186, 0.13682786916052142, 0.20521345848758377, 0.10142314638341628, 0.1962818538830165, 0.07667309784841153, 0.12932201547007408, 0.15600245235668075, 0.10753829768227954, 0.10380975541568573, 0.12099649366592208, 0.11812082176367122, 0.16559277000206132, 0.1519948319201508, 0.1844707852409732, 0.15215344276399384, 0.12406753331062295, 0.14900463753409926, 0.15328521509805035, 0.14500380463657842, 0.149449443504695, 0.1390203668345367, 0.2230561671838645, 0.13711574968070755, 0.10167905805452217, 0.14906715030872053, 0.2183175762935031, 0.11162556828029695, 0.20828743224903462, 0.15336784534156322, 0.18055117298518458, 0.2336556064866243, 0.04077655428479757, 0.14523488739805837, 0.21583635540258503, 0.10714598405625551, 0.20009585325756382, 0.1334484101783845, 0.122094044852401, 0.09852248469307538, 0.13255550405911862, 0.09106215194708879, 0.14503427961420629, 0.1595191330078148, 0.1355295646334848, 0.12496552625370604, 0.1657214114863065, 0.13132207185751008, 0.10444262064993383, 0.15583985785563148, 0.09099582405460459, 0.13181615260339555, 0.1500653475522995, 0.15771790708024658, 0.14123745593092135, 0.1559073195582436, 0.1722930515966108, 0.2104425295105865, 0.20862556813705355, 0.1415973640377483, 0.1045521482404682, 0.08852205719918975, 0.17457073824780603, 0.11875393980693434, 0.09869666244353979, 0.10809001888358787, 0.14547396811746782, 0.1842499680576786, 0.20037026595204108, 0.2275558612159183, 0.17484000283143214, 0.23639697551486955, 0.17058764794661155, 0.14416870751207875, 0.05090351269069699, 0.11746898819241794, 0.22648911442487474, 0.17117079407457383, 0.16665872006166368, 0.1304447173231071, 0.09281163629625114, 0.19866850888056142, 0.20604041975832757, 0.1402679716627444, 0.21198173804629236, 0.209368244414368, 0.1719156920068687, 0.14748465780529285, 0.12530458144723408, 0.10033944606660836, 0.2847856169025744, 0.16769269361130654, 0.12109402431956223, 0.14473300787710375, 0.10923519009544004, 0.13899678664822734, 0.18346365541219714, 0.0770139456876824, 0.18564339006139388, 0.09558807682966995, 0.19967021480683358, 0.1890830329108623, 0.16134259080694568, 0.09788195091870525, 0.1000080134479269, 0.1417420627248864, 0.18660519812856952, 0.1485054699643966, 0.11334193464849265, 0.19819149657362894, 0.1555849344379479, 0.09453695823228168, 0.10901840253462715, 0.20807458238015253, 0.12475498230947603, 0.1501639583899129, 0.16318402102878019, 0.1248262438081926, 0.1558436423299774, 0.17641494170792643, 0.10807933961792339, 0.23632307867369345, 0.2025315225605042, 0.2364022308780301, 0.07172239253357535, 0.15483832046870263, 0.1323521536804976, 0.16814681521106153, 0.13701845651432393, 0.2334130783715556, 0.08709338749007833, 0.11975684849124764, 0.10258732423666986, 0.11752783140588192, 0.11496303798330408, 0.2560130858253087, 0.12729265621953434, 0.10501661968808021, 0.13477772594459597], [0.02659144619810245, 0.052209600671044284, 0.020188684425046368, 0.05920590246997534, 0.016574203074278853, 0.017061542246430632, 0.0075793210435808915, 0.048066658463569424, 0.03483252404558082, 0.04560644753397473, 0.06254409612607091, 0.052333304718617475, 0.026967047616058303, 0.05849544018987687, 0.010647136894535395, 0.028368400545009685, 0.04182013074657129, 0.017229744511085655, 0.027256444990334493, 0.06686724902641389, 0.024086987945221128, 0.03378069681686259, 0.08604868870949553, 0.03416826069775609, 0.06927762976697377, 0.04139215189723238, 0.03046601822960281, 0.012968521200931601, 0.017929263225185777, 0.07106006355775941, 0.04800607623051732, 0.026564342007341406, 0.01499756444020257, 0.00635585468825734, 0.028311022474700888, 0.057403228636230194, 0.07754937985972052, 0.019795495543568846, 0.03419894634956314, 0.005126121254908222, 0.07180003554470117, 0.06687984351188907, 0.02235258212162843, 0.050471205444585894, 0.037358074614237395, 0.026464396261519967, 0.03845962861012067, 0.024583112230644594, 0.03631457093081648, 0.009226214249558266, 0.027294546373248584, 0.08684122198892218, 0.031206919098152753, 0.059031387640824245, 0.003826533051793494, 0.036862243357444965, 0.008860533670221847, 0.008352749526590831, 0.07380973697910387, 0.09022749915358522, 0.02505006388791146, 0.0359146423908251, 0.03146571700551337, 0.059156263802921584, 0.07476473452463266, 0.03251659428520549, 0.045067500848803795, 0.017008645790478876, 0.06273778996640636, 0.040722836199547016, 0.027398692196114894, 0.031731333095400084, 0.07552421877100583, 0.002842071525294394, 0.08380330032518796, 0.016513867904582334, 0.04378091746700868, 0.10558602219868092, 0.05635885927345484, 0.05213780674122034, 0.005393927398648474, 0.03248348396511809, 0.09303597748399743, 0.033543650060892105, 0.030382614237286394, 0.017609226164377986, 0.008820112956116998, 0.04044521742710664, 0.06369225508082779, 0.05291551238887253, 0.027685392940897616, 0.03815640717925083, 0.043727482834290114, 0.06729059687425053, 0.033628773920598536, 0.03416682811333768, 0.007579410101302089, 0.034194541343998526, 0.021287656704624815, 0.015816716402168238, 0.038714651619234396, 0.03120033648766337, 0.035037709204780484, 0.02859593823462004, 0.04834659082154113, 0.06434255264579289, 0.015190260451016648, 0.028235022722172643, 0.01976638420244619, 0.0449541581404065, 0.04770733258356491, 0.010477993299343414, 0.03518824931234121, 0.031147983954137856, 0.0742915909617178, 0.026216597461532203, 0.1018153680788894, 0.04529789030071228, 0.03669477270675763, 0.045622221284335664, 0.07553223971157305, 0.060164814724797205, 0.009282133879981214, 0.09091177654843177, 0.007611999960405933, 0.011699915029889634, 0.06112074689759363, 0.0466677321181182, 0.05517471716889451, 0.0583063428770871, 0.07361741826659249, 0.054824787357281295, 0.08781548664574662, 0.030283532255599578, 0.05651391163888959, 0.04506223016388474, 0.023937903404716524, 0.019884078290253397, 0.05586996877325639, 0.0959235697143501, 0.01920137329087142, 0.052918262644520694, 0.014122623082761084, 0.06224012009859566, 0.03685089759528637, 0.044622158616661065, 0.025873231108210264, 0.01908241515798915, 0.012908290410714765, 0.03465316371030865, 0.09182968777754615, 0.04885455308061454, 0.0564810005016625, 0.04980490430288258, 0.07504702260297152, 0.013265082454909722, 0.03478725974057471, 0.054486007955405986, 0.036806196364904606, 0.054194867731102055, 0.06553834694768153, 0.018133080917440595, 0.05873925150221875, 0.009545589601921459, 0.05550476316843302, 0.03238979907285783, 0.04889184624076851, 0.034064513240610404, 0.029680812581171914, 0.014903942750196063, 0.020003766121883548, 0.012561288970192114, 0.03322060993542114, 0.020846953134863608, 0.010235997615382075, 0.05651633247673031, 0.00865623142735492, 0.021853142590712638, 0.05341260002986078, 0.02849769703443012, 0.09345120479983669, 0.028531431716175813, 0.06147010214326363, 0.03335059590397343, 0.030486369355311318, 0.053589256074760235, 0.0466315804289714, 0.04683989505734175, 0.031157684542479056, 0.06307591436310642, 0.10206379507097507, 0.050687085191208514, 0.034188378166647694, 0.0443015699725478, 0.023367863125918854, 0.06525716203595362, 0.015530169832580274, 0.008840240001107657, 0.03669751530152656, 0.031674793891368375, 0.037655688281501495, 0.0625504125210066, 0.02677423094639615, 0.04541518602279886, 0.08355455157617409, 0.050453007025944616, 0.01448870394303794, 0.03622242587528402, 0.046607310763530196, 0.02884471571193107, 0.04332173968695345, 0.02847875934094191, 0.07289353412606063, 0.044695879257614576, 0.05697925259629565, 0.03031609865326074, 0.05395268818603889, 0.014000501006751532, 0.0023497578090867933, 0.03487162900367572, 0.07533778361375294, 0.014443320894403564, 0.023604191674460328, 0.02675961973446031, 0.03992093366480643, 0.02521736216881583, 0.025184956649618766, 0.07838702039612878, 0.061501251278264876, 0.027231893787581115, 0.026624121763292822, 0.06674609222118894, 0.05497761423729601, 0.03076592249976051, 0.05139092081076196, 0.04662311132696848, 0.04089128744277743, 0.05211061061990838, 0.011549454403951043, 0.031397586891187296, 0.09227608721102439, 0.00984341107053502, 0.03982146480871786, 0.00877186569625572, 0.008637311928454907, 0.034988982182356625, 0.04670438942529502, 0.0323992794109208, 0.10658992679729577, 0.010544235006936136, 0.03813218730952471, 0.004630723795402916, 0.027836005826811158, 0.009489604854024947, 0.059687116769172495, 0.02728813804776198, 0.015267210152571, 0.06998823760377784, 0.0216104133775638, 0.012429582176639909, 0.008298648397378143, 0.0407519705233074, 0.028905251979707714, 0.019008813260663903, 0.0035199611832673152, 0.0469121907747561, 0.021192225131897197, 0.027721333955865235, 0.02431157236588338, 0.025931200981440566, 0.04199710854839894, 0.016929064576904622, 0.007443975332388355, 0.02551606751137203, 0.0693117666448797, 0.033912107708954045, 0.03964840171618327, 0.060977814043121, 0.04882304388428888, 0.03000029614345441, 0.061676823308751474, 0.04345673587053053, 0.037311362403054396, 0.0006607487997708603, 0.021103983294338952, 0.007020067282757092, 0.07080710898604124, 0.010271537391799352, 0.05413047421062666, 0.06671869691701666, 0.013776387730162713, 0.044737780436633096, 0.02015516616313929, 0.027103702379991452, 0.052462340738143654, 0.03758757540415372, 0.03482886214530276, 0.02040432476919265, 0.03941180312164849, 0.024476053358446208, 0.07578312584589567, 0.04694743464971262, 0.013321328630310394, 0.029802496071844816, 0.01367631462222386, 0.027767716749240796, 0.04175078446766542, 0.048730826050403624, 0.017576694240673416, 0.028186048636393204, 0.049333924938353806, 0.015151736762134299, 0.0811405549006116, 0.05738385810306477, 0.08007324886538329, 0.04601160845448894, 0.06608948592216739, 0.04588341513167947, 0.027480383981920542, 0.08822551988545926, 0.03554768244465513, 0.07385528856708158, 0.024924398655252113, 0.05293215564902752, 0.0995054597695989, 0.024215819036227562, 0.07953444390647835, 0.05107047389291468, 0.036037024936728904, 0.05521904301619338, 0.06187900923372758, 0.06405833402588483, 0.03814198174363664, 0.012354448103466103, 0.04890537918395093, 0.10295729873882187, 0.06449842855574624, 0.0434562647264571, 0.036487101592243686, 0.07749479609511553, 0.04586469194281005, 0.07957218905850764, 0.11984383777504969, 0.03460653959923694, 0.03353869347202201, 0.031090839540645964, 0.057104714815655065, 0.03844130378697188, 0.020801246414081227, 0.03209915872092449, 0.029585053505856666, 0.0489252400133879, 0.1105550140322697, 0.12377038312655304, 0.1315369135549953, 0.10485369576922349, 0.14892133313321299, 0.09257363576081493, 0.15982697777930768, 0.10503241642107887, 0.15085670105632276, 0.178541632429246, 0.16950492056146746, 0.1961212205670534, 0.14077967243088832, 0.12219509184961358, 0.202121818738599, 0.26311550229307146, 0.12923720953685622, 0.13218206683954886, 0.1046606952384595, 0.1506519104324041, 0.21176818337651993, 0.12361242345744565, 0.17862509004771712, 0.08729590283286187, 0.16915590622492377, 0.1398865977722791, 0.1281586956352957, 0.12397426976672105, 0.11400971817032945, 0.15106196665475446, 0.1483951533033002, 0.0983656894776129, 0.12578612133379907, 0.08048219426024346, 0.21899266829413755, 0.17998641296740503, 0.1912097695974573, 0.07726793447809835, 0.22448115201006014, 0.10173960198317805, 0.1592364772072723, 0.14585187929051538, 0.23663832385453487, 0.1454682377797942, 0.14438037760555744, 0.13615325213440005, 0.16479400076693104, 0.16765262721286667, 0.07444847044685195, 0.06537758339677127, 0.11153078788230497, 0.13052094307157303, 0.19526235939514255, 0.15038054676786547, 0.1498106846045102, 0.09818108527049904, 0.1931902447775487, 0.20180110368997822, 0.11516012942358372, 0.1427101067477657, 0.23139141830465487, 0.1416712762006829, 0.15061584301292896, 0.16063204425717556, 0.145063865929842, 0.09239917455781853, 0.11749140392508238, 0.0637081131008604, 0.163432831064828, 0.12854838924061868, 0.13597999368944477, 0.16138181450866884, 0.20450082817865958, 0.14699327368890086, 0.2342775166635552, 0.11513549203593886, 0.12096666986302984, 0.23899317088146366, 0.11526994046665008, 0.1336595133667992, 0.10070929799469248, 0.16716810724427625, 0.15563888234957574, 0.12038913149867328, 0.16162999635261877, 0.09827203522886961, 0.09281424865607293, 0.13962413604942062, 0.10778841006779864, 0.10223631807152303, 0.1264344002570837, 0.17391254614678123, 0.14118727717188098, 0.15179673690469037, 0.16997702990568456, 0.12110040583197149, 0.09932296996515605, 0.14394747664130506, 0.0966929364949465, 0.1350411069729636, 0.1194807044380615, 0.21735654963601023, 0.12597697681837505, 0.09453921053077906, 0.15270818235172381, 0.20736158434902469, 0.07476363901890094, 0.08949789233625897, 0.0772401484690847, 0.1416294324782587, 0.12986354770198946, 0.0954320936674072, 0.18294395668612373, 0.08887689380395798, 0.10827048621591061, 0.151784356923834, 0.24537249227925656, 0.14029144459674436, 0.09207822968282046, 0.14723794685015756, 0.24238663395085644, 0.18842707778657639, 0.13969830868224944, 0.16004871426811143, 0.10196362141399615, 0.10128077660356799, 0.17411707630080564, 0.19876684392652205, 0.10966210025212458, 0.14630598556851188, 0.1936549996776927, 0.14115101056954554, 0.15441828978157815, 0.12095209120983079, 0.08211960760696281, 0.15436431122643335, 0.11465975909583992, 0.14628022969249757, 0.14042405441643732, 0.2484822729902883, 0.09957731881689641, 0.16919690725063125, 0.09733828896236035, 0.24535015315538455, 0.09644535986045677, 0.18032692372798922, 0.09083947317013819, 0.14821259455094415, 0.1767580112021777, 0.22221737751556983, 0.23922451411283788, 0.23545107143300198, 0.13698796621493756, 0.22525877721848028, 0.23033365006408385, 0.13350540711995096, 0.13243207197275855, 0.16082139054854072, 0.20207522527104427, 0.18695064249538607, 0.26296544099046343, 0.11715979510617834, 0.08798411025876, 0.1773353963489494, 0.24460592938046305, 0.18905231278509865, 0.1529718085282272, 0.13589766988110158, 0.20590373435087744, 0.10885216145505829, 0.17242898623789513, 0.1698585927125908, 0.07462235708390513, 0.13871783871323834, 0.12811487540602684, 0.08911829576977799], [0.10078166266002002, 0.07331248462921189, 0.031002507687756614, 0.06404572038821156, 0.029701678901009505, 0.05765591890761449, 0.03609609031569093, 0.029335776156175043, 0.08537420957920053, 0.050385744506192785, 0.05021558871733085, 0.06298884464007232, 0.026431088673792062, 0.032473566956938274, 0.033642961868956205, 0.02545788887918236, 0.0501932266108211, 0.03808299680390666, 0.036732655754613305, 0.09159171788562691, 0.03388765801285063, 0.03806359562722426, 0.021191282843750332, 0.04818470878226142, 0.029403910100940737, 0.08354983247456052, 0.07735080986974702, 0.018733810678484942, 0.04468474416963516, 0.01233480177864793, 0.05974265431324321, 0.027292378344422868, 0.06184568057858175, 0.0013422707918160145, 0.021481549727820584, 0.021456487161377748, 0.05554485637995024, 0.03817679277891594, 0.024972417046346014, 0.05323265363732654, 0.07085701195342888, 0.0031660453204230797, 0.07333450965703496, 0.0264531271081538, 0.01779997439664458, 0.0351229403167963, 0.06854467514541841, 0.010143600708444514, 0.044021266061932816, 0.030369728638399995, 0.05828085896228591, 0.007000768091529609, 0.04184746476370962, 0.01410801857409458, 0.0004978420281164994, 0.01846757597259937, 0.01245754151304643, 0.01322625424607747, 0.06214866069175544, 0.04335525986408034, 0.0554110667848539, 0.009452189119803089, 0.025129336751096194, 0.04724757257668723, 0.0368593858494874, 0.03933132941564245, 0.017448755642098766, 0.0249004679837174, 0.047768749852454474, 0.02690997789613903, 0.006120664737893329, 0.03659995783480906, 0.07356600610599404, 0.16021797373410196, 0.02650786217512383, 0.05690428706246519, 0.03801269291509544, 0.016985239889172297, 0.029131494980726032, 0.026820190476193547, 0.03204874822028703, 0.022613965575733495, 0.07507100881588075, 0.03913385110096105, 0.02555482198424157, 0.006330452170298105, 0.04229161189869047, 0.07276442532818164, 0.03472235294119005, 0.016135575602792444, 0.024588032430338285, 0.035741598450488625, 0.03254494336884349, 0.03857499762107769, 0.01713263329058405, 0.026895004707658966, 0.036674482868083065, 0.03446416598894904, 0.04488804858298071, 0.03904948183786004, 0.07731124908933718, 0.019901324844648762, 0.023821877473364436, 0.033422918434465126, 0.04254865737992429, 0.05574903030308986, 0.08314803468003389, 0.024990196031848752, 0.037351654797431924, 0.0752388586800906, 0.02978991499290832, 0.0609000867623235, 0.007785170784054865, 0.02762853581037733, 0.049944569792358146, 0.033350733799799796, 0.013390114707421633, 0.062002410676570675, 0.08935913849141329, 0.02202426748079879, 0.021054426981737057, 0.009153958751759943, 0.08113739095748433, 0.028094629449169004, 0.03329154201633027, 0.01159273262601346, 0.04534555246092139, 0.04027983436601297, 0.05157336464992935, 0.018341491306801478, 0.035116551143507806, 0.04651625738328984, 0.02186464923133533, 0.016133112630115885, 0.024602563203042074, 0.05482457668310212, 0.005530798582420234, 0.019097872897081317, 0.05974855319026017, 0.039562370042286576, 0.01534756319972897, 0.018932531970823487, 0.06557122744139164, 0.05386888582800185, 0.00729894052417348, 0.05717434454709292, 0.014066164317961424, 0.041376351333794095, 0.050085066487231565, 0.023756779151998704, 0.0406316104495237, 0.029572391987688122, 0.12522781177634193, 0.03534804759246688, 0.05821272693274002, 0.09842295454995287, 0.0394492456689477, 0.08323783550651805, 0.06343111869007831, 0.04749676565669718, 0.03838853565074744, 0.013439735179887185, 0.002958079262058281, 0.08833665626063462, 0.04389973770406458, 0.0367672331330757, 0.018325608388911334, 0.07254570722579956, 0.01082500814640474, 0.005295857610631614, 0.0712525278269764, 0.028146556803896546, 0.05932240529106029, 0.030857807085398706, 0.03005480712970659, 0.03009916745096205, 0.02593946132448412, 0.03281902664551332, 0.032715757993320306, 0.03252021788108734, 0.07358582480059517, 0.06087177215264209, 0.016900929997885422, 0.02816012230581574, 0.07078414167007131, 0.01961768653634335, 0.029783029777688846, 0.06330962480616666, 0.019080057522402178, 0.03368380967707884, 0.08299992690163274, 0.09357082942921309, 0.07587329439458347, 0.06599741747542735, 0.030153751215567032, 0.06326425324885115, 0.029485410364765315, 0.05598728364754108, 0.013272771104839782, 0.059588628505626996, 0.013088580585205027, 0.017162273232374462, 0.03616865416387877, 0.0051471379195009515, 0.02561729262402702, 0.020200223624405843, 0.024645866322962028, 0.030657501906276714, 0.07984988827018008, 0.030524457331686735, 0.02608856501718683, 0.031033162696046696, 0.03770271075829383, 0.0450162802101864, 0.0937478187223596, 0.03151428314947313, 0.014442168889687428, 0.025299812381666516, 0.028925934438443476, 0.05518291430968431, 0.033926046678736325, 0.02519551334121535, 0.05638289911251876, 0.037072480866505254, 0.07646865962493805, 0.05781991534956521, 0.030517853653779438, 0.033551533105632955, 0.02446985762235859, 0.03501436650572765, 0.03814154890395942, 0.0500781640350338, 0.029091982080811457, 0.047089291150651635, 0.02361083557198365, 0.003075119062897659, 0.023744435560318734, 0.025929249372453462, 0.054666329731023124, 0.03559733260302775, 0.10232801113518016, 0.01647769897845724, 0.07606084804020583, 0.033899643458426, 0.05697837159518273, 0.05018073937765533, 0.06609569123435406, 0.03809978179032764, 0.10294539373247855, 0.033034691887517134, 0.027077699440621564, 0.03898206227008374, 0.020467685986190073, 0.013853466709054286, 0.048154432987493855, 0.05586502367570516, 0.024339534575119618, 0.025426500341704777, 0.015355102462513794, 0.04836566641085571, 0.00585097641188411, 0.008766521275373957, 0.02780555574704082, 0.06093944069899379, 0.057232946442860755, 0.048050578278038776, 0.045688932220782005, 0.020334583955005776, 0.04385766032482347, 0.0849566610169507, 0.03300852998490295, 0.0419800975660403, 0.015852080935972835, 0.03125981172366488, 0.020413274591368054, 0.04896973823046973, 0.008129135164762697, 0.07450258689782313, 0.02313821677929692, 0.06449354857566857, 0.036439768849842014, 0.026944310126465656, 0.04489942115821666, 0.04536082442369192, 0.013960037200200944, 0.026196068220381296, 0.027323119537604433, 0.07290422105260434, 0.011549163290539817, 0.04312250320048582, 0.036114706252250946, 0.04029696409199988, 0.0458147851449828, 0.04498604271981505, 0.058200795113319354, 0.026085535139446298, 0.036222314792535, 0.08599994253487357, 0.05664201686158777, 0.04326823227588208, 0.0964686489333549, 0.012015752971262462, 0.12253555664492231, 0.025113563000735258, 0.008676129603578199, 0.010637400874627695, 0.015319628761179987, 0.01934411079292336, 0.03606961814746742, 0.021765655349759806, 0.035715003708197225, 0.03492633534234858, 0.03176511565764104, 0.02227889212419189, 0.009799429962802078, 0.019664620913024393, 0.003786563850759018, 0.04589618581737723, 0.08045171162173634, 0.02658261894999493, 0.04578974939161732, 0.0272825762494317, 0.02886738616883034, 0.08140674747166135, 0.03639083881411822, 0.052116877219129, 0.09678674396127464, 0.04172239324919159, 0.03797693193079003, 0.007943987514027546, 0.029410345239504695, 0.03466587693941209, 0.02779233306946774, 0.06020388903937513, 0.05546821694400522, 0.04690632637169573, 0.10450361657046503, 0.03351742687124399, 0.027872410324972965, 0.03290458717533658, 0.03595658953511908, 0.033171595630025676, 0.0363402578589176, 0.06346632426063861, 0.043645047943197915, 0.022436091451034434, 0.054257529892868576, 0.013326057308023016, 0.028774484601472656, 0.03567004966880045, 0.023274471262289632, 0.08357037895268972, 0.1988886978717581, 0.1606777643844966, 0.1459956127068689, 0.14226361538373655, 0.11741581402959363, 0.16148128336475742, 0.14122536706347621, 0.11344311188065237, 0.2643988834273431, 0.0996909449778257, 0.22164281157235946, 0.16706208067555584, 0.10423135658305499, 0.15929569580381917, 0.10835288663304622, 0.17573531446678026, 0.23142095865501514, 0.13681623994583084, 0.09229111785609877, 0.2115811659924446, 0.1813718676567078, 0.1857419549337318, 0.16368108951757032, 0.24850758453530652, 0.08091399971876415, 0.15515142060335607, 0.21181381157329007, 0.14420109770951733, 0.16836899603086133, 0.07989350165570937, 0.18573597944792242, 0.11649047940849297, 0.1325117604386422, 0.11881844441015875, 0.11792628139617944, 0.14704760464449085, 0.14987192567317717, 0.2046629477051958, 0.1416744631264479, 0.23584761386436803, 0.21385160545187615, 0.13583874239796592, 0.18207368080414113, 0.126629178111832, 0.07015660074689696, 0.1260185447491465, 0.12008384546084751, 0.0624402184339781, 0.15675223792993254, 0.09739916996970292, 0.11757041823359267, 0.16898995625876612, 0.15108105756582754, 0.1766073676727472, 0.1517299340376931, 0.14624160353935536, 0.11043115293667202, 0.23932078072140295, 0.115696705066629, 0.09459266814613536, 0.13864487649932986, 0.0769490657013751, 0.16667676909315973, 0.16521692726640932, 0.11161000903455481, 0.11321233555434213, 0.12889634637582686, 0.12732607297479145, 0.2175142564961026, 0.10594486544329314, 0.20608327471681182, 0.13809240453185576, 0.2244345432207469, 0.20718254960112034, 0.15852202360908832, 0.14144443756630345, 0.07340713479225675, 0.21936019131493187, 0.2265786854249816, 0.14683340646086201, 0.2759499571496441, 0.18450322140368725, 0.18033991657918502, 0.11915163903106606, 0.2301465407494576, 0.09919179272988152, 0.18569123991314443, 0.1632473458566012, 0.14485840114854998, 0.08091563148604286, 0.18501460041490295, 0.10819552451251976, 0.14592755345567582, 0.26731611559948615, 0.16098442938058607, 0.11886365125857054, 0.10790819557563913, 0.19510500493549532, 0.12424413189892808, 0.13524370658541882, 0.09719004328813284, 0.16643353617720066, 0.07531493121097166, 0.16821193268462536, 0.1330716787807403, 0.15369101187154172, 0.15913988884177901, 0.15039686444065264, 0.13217636714539222, 0.10189357799507918, 0.09546203238348808, 0.23504657700898188, 0.06895393463632754, 0.14272469306184402, 0.19263313031725346, 0.08679411524245817, 0.12289669049242813, 0.13708614804331334, 0.16872102875382672, 0.14727913173696688, 0.13038517696963203, 0.1679146292829706, 0.14203185846488323, 0.17374655021534813, 0.218515717274239, 0.16989219332894973, 0.3055002972964318, 0.19689944332405446, 0.10788362713590746, 0.13969812482114763, 0.09890365173980113, 0.15328593522069917, 0.09747075322534769, 0.09830338354673117, 0.1065423603980772, 0.11703178947491032, 0.13924495317041874, 0.11963887861178768, 0.11480857167513141, 0.09293051782034098, 0.13762181204172874, 0.1163765697950317, 0.14524930517279333, 0.1668482348923722, 0.15809880599619883, 0.1499916958592592, 0.1374347793358949, 0.12278514809065288, 0.14835727791632378, 0.11285313990928474, 0.1620464417482576, 0.08700612241462355, 0.20861619122086034, 0.13827405930046113, 0.132913374372067, 0.1599336478618845, 0.17447269431525664, 0.11457463140569388, 0.13111299114121547, 0.13090121379542735, 0.21003523120476356, 0.09348784678525503, 0.13765768027834355, 0.13955368660390377, 0.1113799911352896, 0.16295603326251432, 0.10716234003343891, 0.12687942073229821, 0.0929836766614068, 0.09683010453778891, 0.14632978025944005, 0.15506926533435622, 0.18248822630172779, 0.10028604207740677, 0.1396171186840342, 0.16810699396075743], [0.007813761664193966, 0.08867745813463004, 0.04227972604454525, 0.01522616794963758, 0.012081671006707175, 0.03113251663894663, 0.07410971402761436, 0.04928503703746585, 0.0355863354108747, 0.017419694096691186, 0.01089390913670462, 0.03683780898310004, 0.015680012800129914, 0.03983037058083762, 0.10099445890274741, 0.04852599329164913, 0.007910133131043686, 0.041299271397292614, 0.023480721283704046, 0.06036795442923904, 0.03467192903401391, 0.030608297994119987, 0.045396891843167045, 0.05422623520116172, 0.011911018218304361, 0.037403442341113285, 0.015786368786657772, 0.024938389335969285, 0.03720915861307614, 0.04750449548385317, 0.006209571635530841, 0.039244669549647844, 0.04457409042985209, 0.017399737506263682, 0.04196351559291925, 0.005760967305245539, 0.041334339072026556, 0.010203855438908983, 0.0269394320616078, 0.039209816379532705, 0.018853098229174654, 0.06500141124331182, 0.047515753145900466, 0.013407096003873215, 0.05156231766206123, 0.08123957176482485, 0.028877889234272223, 0.019625356991685206, 0.007638448667186763, 0.025156163234984683, 0.095366018583938, 0.021438152762129906, 0.04406158526938769, 0.052097594786074855, 0.02527786587785569, 0.02287390112366167, 0.027945447232454058, 0.0333149038675812, 0.03716546095787518, 0.005421849388268687, 0.07216426438742107, 0.011331371196936215, 0.05027861477086141, 0.04424719305168237, 0.030794375005268285, 0.03091771707629725, 0.06509226161025225, 0.02120168440254225, 0.05297746591930909, 0.019904638174921274, 0.020706462185649623, 0.14184208316428049, 0.05597835106234397, 0.0913019757717848, 0.013621353559316167, 0.05058925959371752, 0.019413095095285007, 0.025454927949355017, 0.023648710958960078, 0.021408870966444095, 0.027158858795319835, 0.04114544477253672, 0.021267652233702042, 0.02612811622149762, 0.04220016015272948, 0.027673782878405148, 0.03478154472465958, 0.07124844457833998, 0.07321795704023493, 0.013765338827074777, 0.0350765498625415, 0.022814669120576114, 0.022550179179938092, 0.022946834609272982, 0.004117392696395156, 0.08981412577052271, 0.08357613227300106, 0.04109264599279531, 0.04936012131492457, 0.03386402036994696, 0.018206148468438658, 0.06795275731072312, 0.03386213962409285, 0.031228214427227938, 0.03874814498328394, 0.06678382205145975, 0.022661436213961533, 0.014517669727454984, 0.038391251432439016, 0.004950185811462542, 0.012240489651899666, 0.05851450428787259, 0.057141850927784565, 0.02304707338372546, 0.04607568787891538, 0.04923907942288826, 0.06845347237803283, 0.02011141488178363, 0.01810364398895012, 0.025606958097928477, 0.010555381586234416, 0.024828204825039835, 0.0262169728446151, 0.024923058001384623, 0.03648514040715752, 0.011362943595515625, 0.05085582754785015, 0.03895431839590592, 0.041473249964896715, 0.08204139002989377, 0.04992699190493553, 0.07964062369278363, 0.027864632617321708, 0.023462095771044977, 0.012232304002428728, 0.07328224713884054, 0.026820508402682124, 0.017283548781227683, 0.04266131827006898, 0.03437547982039471, 0.06748918984686175, 0.13001621370354008, 0.059724352472732146, 0.014747913622657859, 0.034876892027715524, 0.03940345659371346, 0.03245652150062304, 0.017292588618734193, 0.02186445579413445, 0.006988911923291463, 0.02398314855752453, 0.046893448433688575, 0.038351368895100976, 0.09236741255247786, 0.03310275113871021, 0.0364926710514532, 0.045105747788423495, 0.023137573265440525, 0.04632946216471253, 0.026544251351527152, 0.04014682618059939, 0.029315813820088105, 0.016075033589356368, 0.022526533876155174, 0.02525685017087287, 0.004003344708302569, 0.03763278991344475, 0.030944602931999875, 0.07368193053069615, 0.046032568620097254, 0.025057075507638436, 0.02292050033687584, 0.06325022234851796, 0.025983559260625514, 0.10292850915462741, 0.03728642624111907, 0.06346844632418887, 0.07536062069477574, 0.03006281466373513, 0.08586846652530855, 0.03331495366329628, 0.0287041922039803, 0.019139703212966843, 0.05759634791062244, 0.026763411869685498, 0.029250039426129193, 0.02272919669086414, 0.04021996076429083, 0.017240098189382304, 0.018154456685747833, 0.16072818829167276, 0.07626635112589406, 0.034985588412852056, 0.07657149926789346, 0.02741668951667605, 0.05265270975688773, 0.07875481154769659, 0.018732680698796626, 0.05141112637976485, 0.02376207281955548, 0.09360213944267842, 0.01942499244074908, 0.058083089534193284, 0.011389633141187652, 0.043665889365177964, 0.031233427655552665, 0.020309481168946913, 0.025766174151231686, 0.06730438645688758, 0.028632373376298818, 0.011914873555783304, 0.006418460351039446, 0.00612055030350964, 0.0698940011282121, 0.04138184418421119, 0.07306508419494476, 0.018578593604146473, 0.04276063773901232, 0.015544231376430441, 0.014454638885874904, 0.0803878122279721, 0.06760968781647182, 0.03803223964848346, 0.00741451015440567, 0.033222245533139474, 0.037469329733041026, 0.0708330180796404, 0.019136545015498996, 0.020684320329418106, 0.017001264533328436, 0.05066353564841613, 0.0529870956445173, 0.056946613420281685, 0.031898424532564904, 0.018979858967565724, 0.02933536629913555, 0.047038917039190574, 0.035957700362609285, 0.02716610790230334, 0.032567401236343774, 0.06414154266578055, 0.026498975555202173, 0.023103572368141145, 0.1433217053812358, 0.08664909479839188, 0.05555286965963822, 0.01654448077803658, 0.01478872312638428, 0.04447048086853278, 0.03173196894837724, 0.005298424483982907, 0.005848090175629384, 0.07681446405307901, 0.02150639970486443, 0.024239644370672685, 0.06925876868227798, 0.03285424370739249, 0.07210090125520384, 0.043968984391540296, 0.03794598963952834, 0.03922879237741713, 0.03789996690747719, 0.04704822500747058, 0.030270056769011483, 0.03486268492715974, 0.03072599591236682, 0.06660901610889743, 0.02960748072983998, 0.025112904165120378, 0.019558109793691866, 0.023995292966344187, 0.10913526924747614, 0.003925344029877095, 0.0630003321284969, 0.011352272948340304, 0.07625885112511535, 0.029254712562467304, 0.04806682317247314, 0.010606870355625308, 0.04696484016735227, 0.0408077378937554, 0.01850756767746662, 0.004176301027332703, 0.03977048165735699, 0.09956828664026915, 0.026413049218395067, 0.03592511098231039, 0.03706403091670044, 0.015898774952567633, 0.10943539185269226, 0.061284992318119735, 0.055858914124509024, 0.013598504986974501, 0.019523055525496602, 0.027030971907680074, 0.041100249415443796, 0.016452117387445706, 0.070661774445926, 0.03289427563187576, 0.024444247303049893, 0.04240788872383776, 0.020337537223953876, 0.060417267508924975, 0.0854742146968361, 0.04907911260341925, 0.09037641898518609, 0.06822476448911814, 0.07190825312488502, 0.038837670018115354, 0.06229032567071338, 0.024297690852695418, 0.03513542754996208, 0.014217229195750289, 0.028653775957683404, 0.028665995060075677, 0.016460088532297842, 0.03321933439902721, 0.06425194742698824, 0.07164557689740773, 0.027929265540273442, 0.08735851519891331, 0.04930293285137704, 0.05560342763220111, 0.045750292033077254, 0.039845615730530796, 0.02321093384506962, 0.026038437969081348, 0.05095527725174062, 0.04042678918208807, 0.04246225415338432, 0.04272779554969842, 0.011263617423302945, 0.06211272733766706, 0.038924322223230716, 0.0576099612930369, 0.0337736641297177, 0.03853378592119102, 0.0731453089223754, 0.0260442104415908, 0.06634057890022955, 0.04856630100778515, 0.07331799280138747, 0.03933482660701679, 0.02156752011468334, 0.09493929228835529, 0.022336413835986488, 0.04221182384137665, 0.01344485839288081, 0.08407462568533036, 0.06189562951124484, 0.09070055844682841, 0.024703481880527352, 0.13855460069833264, 0.1825637932145788, 0.18436019278822408, 0.10557814681481932, 0.11049411770316864, 0.09383562772024064, 0.17731875691923404, 0.14245210365662653, 0.1897922311458857, 0.14459921828200742, 0.07434021456227188, 0.12121419287136487, 0.14220238963682807, 0.1153110717273047, 0.2763928172569121, 0.14244836514755604, 0.11670856931877714, 0.18141988604780168, 0.11662446052557039, 0.11446339543908836, 0.2999386521837404, 0.07634619280936257, 0.10940051186949977, 0.15107532722815392, 0.16975984397915103, 0.14457870244739518, 0.10725882114662279, 0.1344960507365965, 0.13010483475462084, 0.10776374203663681, 0.11727129154267812, 0.14650728283149583, 0.11284520323838919, 0.17412688222623643, 0.08144476841534339, 0.15804093571439867, 0.12214836048623248, 0.11462275704909718, 0.11401044595385752, 0.1313796663476575, 0.11341455978371444, 0.12598193340724514, 0.1815596664504659, 0.16879042099800803, 0.14118658769274914, 0.1687132606222745, 0.17374417534278286, 0.12618184405108615, 0.08471192656866006, 0.10460402005382123, 0.25423919391487876, 0.12979999304779116, 0.11693499426567748, 0.0839165970683098, 0.15563123679209143, 0.10306914757576682, 0.1332432211887452, 0.1496449031776959, 0.07787089930066178, 0.16426843380735767, 0.11566169484848939, 0.08213960250178653, 0.13469224585400474, 0.12521243639170163, 0.18833381424267448, 0.07998912475041806, 0.11316019561021559, 0.2534131519496441, 0.13212978899959596, 0.0648415669979107, 0.10845776406988021, 0.22969111680023133, 0.17683155564290864, 0.2119804050533041, 0.10654118828355305, 0.17678482427952752, 0.16360844906059005, 0.11160626286460508, 0.09859081973592121, 0.14496386081220644, 0.14756996935654074, 0.3255299725119145, 0.11672228229262176, 0.13496016212288411, 0.1166784237589567, 0.1972531001534193, 0.11391758077567625, 0.19169916188524616, 0.19677308478182365, 0.1551162418458731, 0.1658445064939799, 0.11545167950492714, 0.08030757217878297, 0.1815902333586447, 0.159836232121433, 0.18737595918918812, 0.2123927748611858, 0.14255546423937046, 0.18664079057353158, 0.18059284816826546, 0.1824020873755217, 0.12765961233526468, 0.11675871743430054, 0.09884879984442266, 0.15799697758930345, 0.22767993681613477, 0.09680934355504091, 0.16386032344833498, 0.1867899325706305, 0.11599971582331967, 0.15545728886800428, 0.13386269520607688, 0.2215066317829394, 0.16842266815083642, 0.07676192574323186, 0.16269799952785816, 0.11943519115448, 0.09219953970563027, 0.16578453713126723, 0.0859386861444481, 0.14659846261624368, 0.1524208074495677, 0.11687498659856858, 0.09862310268105039, 0.1145404868669087, 0.11448989442038922, 0.19001335476435002, 0.1425469146981355, 0.14343289538256584, 0.11485336483606409, 0.23522216436122698, 0.1187212508352053, 0.1220415908122255, 0.13566281796703417, 0.12801273290308254, 0.1712380259508087, 0.098933337646867, 0.0743029750282726, 0.1428759034963385, 0.1627807983107144, 0.23909951920711228, 0.1819328432001414, 0.14343384533159195, 0.13038977349717773, 0.19654244635133974, 0.10071149666703517, 0.2276527560165813, 0.12567894563319223, 0.1801851208532049, 0.10031588886293674, 0.08585073158986146, 0.14922862632140038, 0.22573813375446106, 0.19821316154012758, 0.14004424334533755, 0.09046498641011216, 0.15170316692561875, 0.11022972543874096, 0.13360921203369094, 0.09435197864208492, 0.19407286999687073, 0.20271483207902602, 0.09166916937477167, 0.1438909853177686, 0.15792631363916784, 0.1078466940370779, 0.1582143626986973, 0.08847030029902536, 0.17737733200192454, 0.13762113788435537, 0.1520570076160854, 0.16936779082302125, 0.25272584850749663, 0.19416945836236402, 0.27396054938435555, 0.08654236342878112], [0.1017534988181245, 0.07241090639464318, 0.027220749123502645, 0.0411056924701458, 0.0496234487171375, 0.008571027128416444, 0.028890284536887082, 0.06912920023164443, 0.03037184878673044, 0.008275062465409358, 0.02268923371429405, 0.02920592233778969, 0.0926420167689362, 0.07371343206614256, 0.045521381130862626, 0.025942701876403827, 0.03937133069660875, 0.016209051095610185, 0.025865886240236224, 0.03161772800188872, 0.050156400764300946, 0.0584818268074624, 0.07939944389246165, 0.0720011872509795, 0.03291640791200823, 0.030290802430001, 0.016073187317458854, 0.09142959069821144, 0.06258369138043735, 0.03159429337228498, 0.05004843599313209, 0.031381114085595456, 0.059251649410373745, 0.02851825883431781, 0.025962798277877515, 0.06291380249744942, 0.023344267617851015, 0.0212283423470874, 0.027900994980647683, 0.04088762554249937, 0.0052363258756456844, 0.05730979655298495, 0.03207018719084802, 0.05084673791462856, 0.07816890750320689, 0.051875486744627844, 0.03859834415057013, 0.07914154805363187, 0.02042306519504036, 0.05400858579143401, 0.03598285485960303, 0.042230861126295025, 0.014157921541482212, 0.041706416485530716, 0.09349502502910553, 0.026862342549007268, 0.016573657236632802, 0.07424202507301685, 0.03081930542154418, 0.08756406424987702, 0.035148757479844556, 0.05788185355824329, 0.01667509493868678, 0.08218778943222377, 0.0740004928722497, 0.05556563651489635, 0.0006625950716683762, 0.022163187949767998, 0.011796586707444682, 0.08931438363487683, 0.048492626332107096, 0.043861789538735346, 0.01980959347659542, 0.0860773174152259, 0.06616283118003799, 0.03461905364548007, 0.08901323447184217, 0.021059230353022297, 0.05027085046974882, 0.03150306379182204, 0.1019249186520615, 0.02688681905818803, 0.050736720027822646, 0.04127728084342615, 0.05637699257462256, 0.04920692671270621, 0.04601518991553495, 0.046012983582313025, 0.0383919638942086, 0.026432544240848194, 0.018451823289656354, 0.01602027649735852, 0.03662538812345555, 0.046202517565219633, 0.04965925183627875, 0.07176165453969471, 0.010448953778963658, 0.10647523577415174, 0.09483844447400301, 0.0678020601551379, 0.061798780675857305, 0.06596363299796659, 0.02806033935367821, 0.05541634130021257, 0.021725922199567, 0.037778273840705236, 0.05337280942307365, 0.06343089269414064, 0.04264611142477201, 0.04095722463042025, 0.013223513566528358, 0.04645423490494009, 0.01391020701116612, 0.0742028396756899, 0.006006176249244281, 0.019918994662622293, 0.05654871884372927, 0.04145376834898226, 0.08266606578423132, 0.025440125215438106, 0.029463802854860985, 0.026360275336511196, 0.02510554397538785, 0.06659907994851952, 0.025613310882040573, 0.05698096480280642, 0.09713952745040579, 0.03482988104224205, 0.024062245220486677, 0.02252567202724036, 0.025473781373171557, 0.01646409134170221, 0.031980867084536346, 0.009207474781320462, 0.024356250613627416, 0.04432382482674815, 0.08820180946420278, 0.06510908490106945, 0.09939591685730605, 0.04599239879978761, 0.02158461919715328, 0.04085063115663586, 0.0555914345257465, 0.06325419068396573, 0.06910404190421104, 0.045100446459987474, 0.05029383310747724, 0.004148947379191316, 0.05684658148956876, 0.022118848695930456, 0.027017670706094756, 0.038503261147848064, 0.033212784347274614, 0.06127402576948367, 0.01830820478649149, 0.037933199801632476, 0.04743449419977204, 0.005221427380738239, 0.03579214493173265, 0.01769806746573698, 0.03443909576162696, 0.023439907949538003, 0.04391927294613373, 0.04804870136262429, 0.02892867894843221, 0.050057142582391544, 0.030742120147953113, 0.043056523878007166, 0.04585702723312763, 0.008295303465978754, 0.016189081098644004, 0.1081532747634957, 0.03271777280456117, 0.058645275496547265, 0.03187550701231005, 0.04594228132778118, 0.08080224281237011, 0.031823727129507935, 0.019569654738710775, 0.05163866981503464, 0.02113105109592359, 0.04121606658783652, 0.0339736475519115, 0.02468973251750633, 0.08399163538049306, 0.03152712086786426, 0.03384397184896854, 0.049584156067501155, 0.043195285383732095, 0.055958972868299296, 0.023580910262441444, 0.03508259046582445, 0.12243277828900084, 0.024364256232436148, 0.03355532907129776, 0.0482464324863207, 0.010392702815513457, 0.03181117669408841, 0.052645497039080634, 0.12597186701192012, 0.039286432832839994, 0.025825884959269917, 0.018384528211167744, 0.0237953650855249, 0.10021267383689843, 0.010850683583187, 0.034364586050111445, 0.022588596574120948, 0.08731797382596039, 0.011524558461631739, 0.08619979955255987, 0.024149776511495153, 0.040284170423664396, 0.008639029880625107, 0.02832937985658646, 0.017712828064818057, 0.07138136849408189, 0.09020057116304675, 0.041869719617909966, 0.003633939744641764, 0.05075962988719825, 0.008585516723894305, 0.009356890654852314, 0.09317486156379023, 0.00887832414704345, 0.014395207699929035, 0.015010798609094515, 0.03522908945958461, 0.044211194580120426, 0.04455520253207895, 0.012831355073308993, 0.02814564324404684, 0.02852080033100661, 0.020777534077604933, 0.07144265552802433, 0.06631922036890062, 0.0549123780201039, 0.035039739337779825, 0.04190241242007863, 0.04268602843606665, 0.025770391465254852, 0.016967642849551576, 0.05513863059722128, 0.05145850125700236, 0.005260722903204301, 0.08696368880449765, 0.028253359036640297, 0.02947023416298532, 0.036144185315577254, 0.03686977400174064, 0.05671882866731575, 0.007922185609312429, 0.053547937122564164, 0.04080896363443425, 0.07910906592564237, 0.02334602387441743, 0.10958347664845568, 0.03286587292208307, 0.04395283525809646, 0.07480342962568806, 0.05306073201579913, 0.04399717642715381, 0.036953223959332517, 0.022022974707426566, 0.028436341052574497, 0.06385826250357975, 0.07248408311317045, 0.06090667128803269, 0.0489925868028114, 0.02484422372353654, 0.09621276790576597, 0.029714102931921522, 0.013417116433922804, 0.03796371308365657, 0.0434023053235104, 0.007741755144971033, 0.04518575418079573, 0.035211335371939406, 0.03553999475233498, 0.026371559811635848, 0.012819971006754185, 0.0631372971580394, 0.042619765661056006, 0.027527172801895972, 0.024832659626319527, 0.025924424933750304, 0.0344859228859986, 0.033757143443630594, 0.024480441127032525, 0.02584913381255202, 0.019545683847560037, 0.10391618035012677, 0.060645883467288754, 0.02122478961433855, 0.07824093508984774, 0.09647793391899717, 0.04565539289145701, 0.10209977822077852, 0.03814549042632984, 0.07159738230609125, 0.013960372363667817, 0.13833154653829915, 0.060579647505355466, 0.055416065508559834, 0.031328773043388804, 0.020292115870923288, 0.024349825051162514, 0.052696955164954554, 0.005825871710605439, 0.05685129293030309, 0.043740640394389636, 0.039843968641493595, 0.08133196196849309, 0.020738233767089345, 0.05272782850830306, 0.02272394324292339, 0.024126621503983776, 0.05215386394411326, 0.03559392734220432, 0.03538039182463, 0.08078050889795826, 0.06296590796761936, 0.018459470762360482, 0.04519739871724479, 0.054617552912884185, 0.05426741625753142, 0.07517420085928134, 0.043923015285643845, 0.025905703660100702, 0.03769481622223412, 0.05982087572075187, 0.01638860103764361, 0.05212524289926214, 0.03483813180918655, 0.03282260810655933, 0.07596326376041097, 0.0470377410942268, 0.08816882171818326, 0.023424233790607225, 0.0725935340949124, 0.024978151214459253, 0.02137174443041365, 0.059538978347254384, 0.06982604912932842, 0.05784599681294734, 0.031976329928804795, 0.00690841667106255, 0.019912448441309315, 0.03800084153490682, 0.01234948481132667, 0.033376504997572595, 0.045678306581272234, 0.20599762608687724, 0.11702102593957417, 0.1361466024912173, 0.18209894638388388, 0.18659048924042335, 0.09493287247154983, 0.14596712955784413, 0.14130485634649956, 0.13526609167456627, 0.08879075487775188, 0.07880470685420499, 0.14403661863217432, 0.16861759156229036, 0.11257282833779052, 0.16426779029350128, 0.1274965658423401, 0.2384680022876109, 0.07803527878657465, 0.13310440605686558, 0.07175308967670126, 0.24673727791636224, 0.1376149325721687, 0.15545379550706956, 0.17054986449018603, 0.10401858332296533, 0.20242713541994173, 0.1368626035870083, 0.17960004418367342, 0.17910792462287412, 0.10200004889479569, 0.1704330973687672, 0.12115578632801773, 0.14040050487364494, 0.16625416435060963, 0.25235490873456, 0.1709629084554411, 0.12916034027453394, 0.14827624113569338, 0.10025187455598386, 0.14238278802123763, 0.15156197692117385, 0.1748627096775078, 0.11615941451201517, 0.09179943496541632, 0.153021022016483, 0.1377901675239686, 0.10966849708629232, 0.2357254994492377, 0.13480205689707112, 0.10840629828312706, 0.07605960697776849, 0.18016025363918275, 0.12195712961857358, 0.1412844477641967, 0.14441459109225582, 0.15203100659193533, 0.16666763732510229, 0.17818242912330937, 0.27489490086032503, 0.1562906393120366, 0.10636132616069048, 0.1516651842863329, 0.1559619569490033, 0.2815148504751344, 0.17177946625217316, 0.16261316295112335, 0.16512574748166148, 0.09277517051105538, 0.15789925541368224, 0.2120335409117322, 0.12794970684955198, 0.12620938491196404, 0.08690791760361002, 0.13488226630274328, 0.15124066432397212, 0.13844983051380805, 0.14185152136750762, 0.15042049059223744, 0.21037246310903182, 0.12833739330451335, 0.20437508250676817, 0.15502432661671794, 0.09851565118879081, 0.13317048880121402, 0.11082386492841667, 0.19445082713519374, 0.09197450137787289, 0.19761006648261703, 0.13398710788498003, 0.17242788307128415, 0.13242899229930294, 0.19867871317171282, 0.17442046244057918, 0.19158959599031558, 0.2339096565640742, 0.1830301262558468, 0.13145356318883358, 0.16660264242560635, 0.18794681726684495, 0.19687318183001012, 0.17590207648613762, 0.19138722620423765, 0.1717554723783847, 0.07517229330034987, 0.1094153356708346, 0.12087447884222194, 0.15629226341843605, 0.1823507594845949, 0.13127664284360024, 0.09742249734699727, 0.1255577581844503, 0.1501916448074964, 0.1510781157881983, 0.1399207806154605, 0.20821810129188723, 0.15017721171100296, 0.19967582257043934, 0.13830960578014775, 0.19622197645085473, 0.15381562373330518, 0.14326864613160012, 0.19614653211207161, 0.1070702409431819, 0.20168105771224346, 0.06295895955014615, 0.22642880798347537, 0.2298429707485822, 0.12511704312337021, 0.14627469853768427, 0.12155788289683482, 0.09817752296165114, 0.08317374459077274, 0.10029105995331081, 0.20072547027901297, 0.12326913945857557, 0.11506799968980974, 0.2321986451504692, 0.10772308575049525, 0.22573451781945847, 0.16168331607214867, 0.11697124554625443, 0.14264103626051258, 0.1384370062019556, 0.1229100357440691, 0.15676066489709964, 0.1386678284935413, 0.16685044122559411, 0.08814701885585824, 0.10562236540980878, 0.159204853097758, 0.16787229526427486, 0.2652005791183441, 0.15558223780845443, 0.16417028262249886, 0.197879989901858, 0.16303768291348414, 0.14205384518831007, 0.07572471164166927, 0.1516447603822716, 0.18736321148612808, 0.0977124386436997, 0.16727679979897317, 0.13631287421430313, 0.1405064701553314, 0.2199494661462884, 0.1202863148383556, 0.12470972183490954, 0.17616683647276896, 0.1498278143304971, 0.11590184809099283, 0.14692138399808638, 0.17980239864799286, 0.13927075501170852, 0.2770223270260519, 0.17047287265379585, 0.1755409579603903], [0.08131264889192197, 0.01786596712566191, 0.04111149175573261, 0.022868779825887853, 0.01252146867749792, 0.014421023905367382, 0.0855637397316675, 0.05660025357839562, 0.036223778020470374, 0.0533078336757758, 0.06612939144214315, 0.09128641652604265, 0.027704372769221667, 0.01405476301442832, 0.06872841367317785, 0.039684361883349, 0.022776473891891302, 0.03417088071845713, 0.09198956266646424, 0.04034461476089012, 0.03898011257631644, 0.022142013279540886, 0.06256727794665964, 0.07966885403279336, 0.06633071168776482, 0.03638065367516491, 0.04339839444465695, 0.05150998619595363, 0.04284462395815119, 0.04673360418828745, 0.018138742307201028, 0.025735658953987786, 0.09258433800911711, 0.037630016675158855, 0.017364185280917634, 0.05727044644675428, 0.04706856081142061, 0.07062916974386863, 0.041496673103181586, 0.03576802465343668, 0.00848029454749438, 0.05347221316168866, 0.04011243649367844, 0.08018931118591179, 0.012153200636197244, 0.06831223640831248, 0.05830777163106588, 0.03742660117906429, 0.02864277876553036, 0.023862709959728584, 0.009495665567115912, 0.020396453215770667, 0.01986867800775555, 0.030946025940319224, 0.058710385309231866, 0.02640783599007034, 0.03445610674398561, 0.06653688126994718, 0.0266564219454003, 0.06379542031115101, 0.03501325950867707, 0.052408526891902577, 0.032994843824135686, 0.025807872316950274, 0.07415813844530814, 0.05565423458333939, 0.03859580073866152, 0.08482016713148163, 0.11592511418125323, 0.03706426840395697, 0.06802489214967336, 0.04849988118475003, 0.02523216681795255, 0.06374796116424185, 0.046900385359842936, 0.05306631679676714, 0.028670949733725963, 0.022104124486025785, 0.020906872701861208, 0.038899052813048327, 0.02503703273231945, 0.03755291758645927, 0.06050086685366208, 0.09227445544374567, 0.030155019091081717, 0.04344525221254557, 0.03299032773582205, 0.04699842546195273, 0.0038849178095152906, 0.031927738886987495, 0.0791003018797886, 0.04222448727476501, 0.06239306955267826, 0.07512944600274486, 0.07439395563016016, 0.062005536315301736, 0.0211590975748315, 0.04256834967001792, 0.10081579187704671, 0.05781910329636547, 0.05655424233766333, 0.07275511735990163, 0.054249769422195615, 0.029334471891483957, 0.03035804771277453, 0.023843324104804667, 0.042449782241977034, 0.006588759302582231, 0.09163992779870188, 0.021254274423324296, 0.041463198891330155, 0.054070018382082065, 0.03299012855296174, 0.016940553980549018, 0.026243676754435705, 0.05379868536106041, 0.07226374090438889, 0.05086713500561253, 0.034435717313880884, 0.0349689336613782, 0.02932664438811762, 0.07982497509088247, 0.018389122823493618, 0.06942018340792387, 0.07399506130886656, 0.035367935234981204, 0.04659424130354197, 0.025717828257550156, 0.06548397768769534, 0.05028599219757223, 0.023333764552409132, 0.011126270307408226, 0.033945520633771535, 0.02768020844087005, 0.03830714263923226, 0.06402952528949227, 0.027367271099900527, 0.031823652435935317, 0.03098728935114078, 0.011444558772528845, 0.04644189705891956, 0.0749737999191688, 0.03157562572479008, 0.07212055141046163, 0.0383770021970474, 0.029925801753697377, 0.0808233944999595, 0.030882752823433092, 0.04608401908509193, 0.004378912131106782, 0.02776384800522318, 0.045435594605101694, 0.05822300017180462, 0.012793445212375975, 0.034459393261180776, 0.04412041316109319, 0.06676758864834424, 0.03489341654424225, 0.04156808015860377, 0.017139901549765663, 0.09738026291973169, 0.04954032051647383, 0.042277852959570386, 0.03644304770615794, 0.057434584614970995, 0.04605440212593925, 0.10847058072085343, 0.054242070238556594, 0.016671166822855032, 0.06322972183566421, 0.037752782265024806, 0.05996890305992096, 0.04219249927348668, 0.021410127350639914, 0.052577679105583704, 0.0285967368812811, 0.05076947794746488, 0.021642491394173236, 0.01742286761591752, 0.017611016894900994, 0.05241584303157945, 0.021930601740736636, 0.07914628247700392, 0.012738238043722608, 0.023789391514935324, 0.08082309572566902, 0.09648674393012639, 0.06226619773153817, 0.014567946162705701, 0.02423960606627647, 0.09579667491057227, 0.01939007606838019, 0.07680605240767041, 0.06653600026883426, 0.06297723457757985, 0.025193737932450833, 0.03202531359068329, 0.03090531602802296, 0.037607206407213406, 0.11422616099157643, 0.08110107838987343, 0.012071597908112791, 0.0824942858889699, 0.09864237745322528, 0.009827285877338821, 0.03109492853494181, 0.018420141723547733, 0.007859138009559003, 0.04587390415009953, 0.026088388816964243, 0.0860264338552952, 0.028102307565390106, 0.11772767310180973, 0.0705873949693576, 0.07273339876724828, 0.022086590648658817, 0.05004572021144052, 0.039566541391034285, 0.06469973347960942, 0.04665694176970471, 0.009499844576742862, 0.040865374518738645, 0.07208669798508768, 0.022206500645787008, 0.06559258597272058, 0.02920769200089478, 0.03262664281552838, 0.026503675504617637, 0.013337912518651256, 0.03014819516289619, 0.04550858746252714, 0.04521154453076663, 0.08467985812814967, 0.059329506926118374, 0.0331541326557917, 0.06847362815132065, 0.057411529198889776, 0.0205250334129819, 0.0309413681257396, 0.031227051888802843, 0.06400605235549231, 0.12877938007154774, 0.05897998697154465, 0.071351966039548, 0.05394266009511006, 0.02385065365102022, 0.008535384887739295, 0.049491340685034954, 0.06215025032419832, 0.01140818874832363, 0.07009308439709487, 0.005295166216279951, 0.02017781363740083, 0.03389920295786954, 0.017095587193785657, 0.06296489673155932, 0.016374033875763416, 0.02621740759951213, 0.10025010489287878, 0.03568762755622307, 0.05095285258346027, 0.027982368839964755, 0.03833516230506282, 0.034387951731801994, 0.013041194216648658, 0.045979076530784375, 0.03834086966009871, 0.0662778592818687, 0.029430322897350116, 0.027258444479816867, 0.0863693654537201, 0.048408904413302103, 0.03190706408913097, 0.08365896169937427, 0.051897998238282825, 0.04242213412878975, 0.009303474216721952, 0.005923301815205524, 0.04611512225481772, 0.09643229040046854, 0.02327678676304077, 0.018839666792642207, 0.0472737153271033, 0.01963664338202967, 0.02091102872885043, 0.055276419171282364, 0.0208688038776839, 0.03689926838682544, 0.05154495044881779, 0.025306232198471987, 0.07967043217391738, 0.05538511938685852, 0.009884040543599235, 0.04089552007855908, 0.02450501339720382, 0.047247220176242055, 0.031090176874591462, 0.051369692514380144, 0.05672434066993095, 0.11392979987806852, 0.0519193989044476, 0.05893142848846413, 0.06738870209383388, 0.009315708640872711, 0.029325945332886714, 0.053357663864810626, 0.037695842780052655, 0.04149933525871846, 0.06602480511872039, 0.04275563518486677, 0.03004907296159335, 0.011249842204814477, 0.012481715417497102, 0.03605566385592665, 0.03112272986571395, 0.01812400086031806, 0.017636393557392785, 0.056195127131837996, 0.04204688511127907, 0.06576774431572807, 0.06581328824282655, 0.04861184876532324, 0.05246393420102616, 0.006853407248854638, 0.036320688142891855, 0.06781731296571032, 0.038624456257469235, 0.030713357376836004, 0.02122585256133349, 0.05047925319823046, 0.025952413956063892, 0.02267229742550802, 0.08072670654303606, 0.03209926597323389, 0.035581639291898864, 0.04417468666008884, 0.0366584716304656, 0.04883096523342594, 0.017846272920348474, 0.046061220308465343, 0.07073027802811516, 0.05476318622728991, 0.033572891636961893, 0.016326337241597714, 0.024683435274768743, 0.051162174617451046, 0.026006124380435196, 0.050902329084853974, 0.03547783437815886, 0.02494285371334803, 0.04846776294852457, 0.011156292335550872, 0.3132800427415679, 0.14039601559840864, 0.1674103748894507, 0.10553931381793753, 0.20749235555769938, 0.15371142045384453, 0.2444449743075717, 0.14375986170864877, 0.1453110825030073, 0.12405393524996697, 0.33222257790546267, 0.21143225382172295, 0.10932675292415005, 0.07291860052294309, 0.1511432792270376, 0.15728949539123044, 0.1382935945425303, 0.16075659483190508, 0.14075855904769513, 0.06570746851784569, 0.13383076466139288, 0.10211255656735552, 0.07055600834709984, 0.21637869968770013, 0.115438518114388, 0.21956864383912858, 0.1496066753902743, 0.18764729221020976, 0.11930684078364603, 0.09488786480599835, 0.09469593679832836, 0.11133646201943198, 0.19239018851470566, 0.13164886964424966, 0.22027477772245485, 0.1134976496799819, 0.21374272903607738, 0.17928835365080065, 0.15744606844119488, 0.15903422999526226, 0.12508340420261507, 0.1688623413323395, 0.20884765702630245, 0.14681961687822498, 0.10931213596655477, 0.15552441349192975, 0.22007384818167458, 0.07924746737004289, 0.09634366168850854, 0.1339992733612176, 0.09944726773087056, 0.18371099455943032, 0.11023368611330948, 0.08644013665616514, 0.18058834357127068, 0.08563182962637755, 0.14277289531403972, 0.18365847157134166, 0.14958278876879524, 0.1346640997836667, 0.16501659527420998, 0.1633687401490827, 0.15161399429123248, 0.16913016567066794, 0.1835721794275507, 0.20129332529200664, 0.1478984678584722, 0.2366115567424605, 0.15366680349313444, 0.05895875101428359, 0.26321757584810257, 0.14490926938672222, 0.11527834445117943, 0.11611606925725938, 0.18165979414216935, 0.11846933814306414, 0.16619972614271028, 0.16876481833957857, 0.12067717289732349, 0.16373149810298798, 0.09119161314541295, 0.11912278049895841, 0.18195823135395206, 0.3092197460993644, 0.13557125513832416, 0.1313777358060883, 0.17265277584233593, 0.20120035286151594, 0.09219255298376085, 0.10542430869874456, 0.1301761115750959, 0.12540382813782464, 0.19900724231716127, 0.17529634608616754, 0.18029453353055064, 0.1901326346541605, 0.10190158361388792, 0.18936587257250664, 0.1735551354865874, 0.12030693792527723, 0.09495267584439247, 0.1952907352918579, 0.16563557899527012, 0.14702445346741908, 0.1080816148990585, 0.16587565562898116, 0.11243093353245528, 0.06405063867268544, 0.187271204326422, 0.12389723962593464, 0.1898757040861153, 0.13992165395569417, 0.137471949921981, 0.1132268299378695, 0.18559273632784046, 0.19907272751292876, 0.14238160824583423, 0.09921097557150549, 0.16654826550474092, 0.2155493329008741, 0.13530724591785862, 0.1899848409718083, 0.14038363561755227, 0.24031566846514904, 0.1382136302849939, 0.11715434056015746, 0.18642277727203985, 0.12808928040847664, 0.14162711889272736, 0.1928075991811291, 0.16016217188969736, 0.16075740688510481, 0.11255609697752422, 0.14811461190542868, 0.11479534133667908, 0.11879848781973125, 0.13544106615647195, 0.12772522010510007, 0.15805388260031902, 0.13644476391134724, 0.1033254882561103, 0.2214682967432084, 0.10694861682432313, 0.4730567191877673, 0.12838154295158963, 0.2269379346961937, 0.22293558494458277, 0.08053261816741959, 0.15190117001052827, 0.22153485446206986, 0.14025804316324575, 0.15195358574630755, 0.14295291065448715, 0.1695824793029216, 0.12740405306460398, 0.12256466798604497, 0.12730625428019032, 0.10635275363681779, 0.11578890374831616, 0.1381839980040827, 0.1520443212000593, 0.16401568607937905, 0.12088416219358483, 0.15328942858163389, 0.18794589796133582, 0.09935371307355743, 0.2530032489448786, 0.12209081962223976, 0.13184374709042812, 0.22383394560986952, 0.12479809007697529, 0.1906408880266451, 0.2175813045112356, 0.06815715722980038, 0.13169590744280046, 0.11933807418831896], [0.02370146185820622, 0.03359561763523567, 0.03395522696777217, 0.06590108191894908, 0.06747298708726322, 0.0654049557183058, 0.017196283705772895, 0.04485963055142953, 0.056556908323639826, 0.039722808005829016, 0.03305326951968093, 0.028862481290895133, 0.014698994120643025, 0.04000891503247042, 0.032191213761125846, 0.11725691973321861, 0.06889529826660311, 0.01312508275957718, 0.007808804117713965, 0.005820869156459888, 0.0138740869231462, 0.05706680495472205, 0.018711825870277903, 0.05397394712593767, 0.07016238471072528, 0.03335808824387289, 0.01824354888090203, 0.03514571228034554, 0.03616704920967741, 0.04865006889186559, 0.05363675735650524, 0.006247043868737116, 0.0513309552784889, 0.0710793000255381, 0.014896452325516412, 0.05789838573564926, 0.0630189442346173, 0.025079518053380233, 0.07505035508544215, 0.012289753893480427, 0.045747400051163095, 0.01918025416201882, 0.029284210777991725, 0.057332737055877526, 0.009931526503585761, 0.03151795462585025, 0.03556037652156046, 0.034222269896417856, 0.03979923676759486, 0.025314812383223927, 0.06107295067199777, 0.023547127700200485, 0.0864114773069178, 0.03771660759324028, 0.05324329076815517, 0.06642781333216737, 0.036523529073043216, 0.12360090149506447, 0.03230081413001303, 0.02222193731746126, 0.009129267737960384, 0.02265495511012212, 0.01495981737295346, 0.04745801309904745, 0.040840587743948546, 0.18277124982447396, 0.08672933484758101, 0.08569840266699753, 0.06422721427835285, 0.05866127141240624, 0.05061879228319853, 0.04113097720208668, 0.027943643095392375, 0.024553778724023895, 0.03768094620036502, 0.05756763110478079, 0.04011725518672217, 0.07672283993733507, 0.04554902158317067, 0.024961362397598646, 0.006855716525141391, 0.023345326734406334, 0.030166234618293184, 0.04628559213972861, 0.02432392744888221, 0.05146176479155979, 0.04775910097504816, 0.0656981835322034, 0.09758229562712294, 0.011994449981308032, 0.017832188393860575, 0.059161649401029276, 0.0664831555238174, 0.030919620804789088, 0.1152058725335425, 0.02975370201672758, 0.08214541710913181, 0.037496146640830466, 0.027109199060848164, 0.09768292893685641, 0.026546019099412427, 0.07354186667549996, 0.06337337481278567, 0.012126422990413924, 0.024820137919197162, 0.02542992666994612, 0.05039470773490687, 0.06704920256930975, 0.050560661531504125, 0.03689323544442173, 0.0344676478585649, 0.027946600194780097, 0.03924339401325391, 0.07095182299493782, 0.0029027262972968243, 0.023024282267978115, 0.07725498759217801, 0.05419256946732921, 0.052769434743470726, 0.048676724921190934, 0.03330523583797678, 0.07848890242917884, 0.052050242891475085, 0.04581463575783757, 0.08039928056419858, 0.037361479875060825, 0.07973552666484349, 0.016885242432415966, 0.05706291705850632, 0.02580706792462978, 0.009210035430207368, 0.043892766303953626, 0.006363799498837081, 0.02519103364207812, 0.05836907398676681, 0.07443092703338593, 0.034170011208663066, 0.027562906973124034, 0.054009704279803464, 0.0102431605374741, 0.0227297616807083, 0.016351736886727235, 0.031163388067075325, 0.03375727367857772, 0.019400533168546615, 0.10464113701375262, 0.06684474902407778, 0.02246855634204563, 0.02336559933610261, 0.021129078419518568, 0.03983030546336405, 0.023073796445744175, 0.045010530720314676, 0.023016983365279534, 0.06801706273108721, 0.05520280578263825, 0.05321796390137846, 0.02659131021749589, 0.022904310983815984, 0.04914078268132383, 0.04135832145449616, 0.019875201246430798, 0.004042120248590026, 0.023054351219006126, 0.06937843927692983, 0.042845156389258565, 0.036106271624204614, 0.046147083443018704, 0.03548842171327241, 0.04743561268814149, 0.07877263075281536, 0.023036652672735435, 0.0803912672845106, 0.0228331720591673, 0.09894982385899752, 0.033860737683191415, 0.022275550065622218, 0.03964825615947766, 0.03698350741497932, 0.06359545604115532, 0.03306301415807778, 0.07519916766473363, 0.02582015079115668, 0.023598470912885763, 0.03707606232755127, 0.026306428931533333, 0.016044902393684512, 0.028141799397886764, 0.0589338033610294, 0.11945320188157982, 0.053501680733696114, 0.04716143365048113, 0.021318960972430728, 0.03586287782978147, 0.01674733511472662, 0.043701991258609685, 0.030543638258090908, 0.035073519984800974, 0.01977228499468296, 0.046878007931574706, 0.05159626684842571, 0.03358095088192532, 0.08599664069591992, 0.05939688052861922, 0.007561081926518632, 0.04170991367690506, 0.043206765211277434, 0.0503361173304579, 0.03362585512560702, 0.09810584011457621, 0.018141678339170835, 0.042290868793403914, 0.019133637711826353, 0.041331657764291575, 0.06181964125003546, 0.041611287517533194, 0.12047684090512416, 0.05147342464976734, 0.06581043839574822, 0.04042619929438637, 0.0370251328023451, 0.06613698337347278, 0.02280913796576281, 0.055123347143131884, 0.04240292830452804, 0.019384744096427195, 0.016904059467056108, 0.018042864488257516, 0.02900611320059867, 0.0768934783615893, 0.05168755005504336, 0.07398976764130978, 0.009161243290309946, 0.08816662304584058, 0.06118465012179748, 0.08873487642455487, 0.05901120505445908, 0.0716307530960729, 0.017599554304333947, 0.025389186114132888, 0.01920648501254618, 0.06777515514723717, 0.021863758654123353, 0.0780322450783945, 0.03635893508251156, 0.004481032130218322, 0.031979258299895355, 0.06036071489835459, 0.014749614337849763, 0.12593176230908404, 0.09954251544249636, 0.03333049758727993, 0.0715884956861696, 0.03766020820025475, 0.04813236582483496, 0.01906231492607584, 0.026655648196596774, 0.010478700015453563, 0.043827484121486064, 0.030507000103112192, 0.04144933269990068, 0.06781535944150341, 0.010849109272502605, 0.04583691742511527, 0.02712849298522117, 0.018521263414332946, 0.04109922668806488, 0.029739217209299246, 0.04872147211684816, 0.03007846392480837, 0.027533897138651342, 0.02438174027408804, 0.01803137316939331, 0.038391768541787906, 0.06996126364796393, 0.08836030539485716, 0.05588226831488072, 0.09071295374944326, 0.08599068053186902, 0.025193937115311146, 0.034462101381993106, 0.036597016057179826, 0.035708005495008924, 0.03520041478857879, 0.014302774403815069, 0.08752705454225503, 0.012368298973137093, 0.0448470437268336, 0.02438914451387621, 0.04862117205536173, 0.021656221604996154, 0.03018796853270502, 0.008802752446142897, 0.045199202854306474, 0.030066537851047133, 0.03979103196592581, 0.05889233885212772, 0.023226711425870177, 0.05648527144184036, 0.0028988925060407533, 0.06563417688612977, 0.047331106803950765, 0.04176437869788178, 0.012152898031467152, 0.0399725258560671, 0.008699029886854753, 0.06336736485301968, 0.013467667703216356, 0.03131144604976139, 0.05831180891442684, 0.07919249290059652, 0.01779969477455222, 0.01587497260076024, 0.047264920637732556, 0.04883487994271902, 0.054698536067359874, 0.017727923827366005, 0.04152986386250104, 0.03859084414979143, 0.017999953988398758, 0.04113657347437355, 0.0861187857545672, 0.06643224898124896, 0.04121979743602776, 0.05095630380955916, 0.03909193843062367, 0.058573224927268686, 0.011483766194883616, 0.03490886470723537, 0.023631880007263635, 0.012365164715916881, 0.03867175452591431, 0.060899064034944585, 0.008927052127077215, 0.08616949311427533, 0.015690032272569595, 0.018380783956437823, 0.05560428182023668, 0.01802109993032871, 0.05237866478461412, 0.009541701705705737, 0.023293297873028827, 0.010024161855389756, 0.015182955802658634, 0.048120119909365336, 0.01559179107237968, 0.006489256451342015, 0.021482340713602402, 0.038676247631590215, 0.04095241742869539, 0.02350124669441533, 0.06641259116511192, 0.07481251542847003, 0.18843912068874608, 0.18847026982374732, 0.17973317494315488, 0.14170404944208362, 0.1648065186436138, 0.11004217945399786, 0.08639278476156535, 0.1909473538398743, 0.13334054499864578, 0.14553759938045857, 0.09441757875104105, 0.11799731306851872, 0.17825523811963298, 0.12929198482344229, 0.27208455327537756, 0.17021342931735903, 0.14128772662051264, 0.08834009599541465, 0.0848401160610299, 0.2485653169212803, 0.16281936317682266, 0.07915760525652478, 0.21348693227816015, 0.16569613058480526, 0.10547064935728427, 0.1782324393430064, 0.10773353518978243, 0.24419682310713878, 0.14585491299869555, 0.17056164692246145, 0.15300741629494777, 0.13817053017837388, 0.2696403344312022, 0.20270859612332237, 0.141005193394038, 0.13666506015485333, 0.19037265000083756, 0.16540363821531498, 0.1687880308036843, 0.1671004463588038, 0.12270435645815828, 0.09211644214848358, 0.24802419837684403, 0.15385512322668107, 0.18236784324530633, 0.12707806733106414, 0.10286401987316147, 0.11438145467470731, 0.07616973211688381, 0.2454911592987276, 0.1282098090216037, 0.16573360760606107, 0.10428823861143283, 0.1500509910645985, 0.1409196979816883, 0.14195713424874892, 0.16233657456694112, 0.11175447023443638, 0.14841393777920356, 0.14031245072762813, 0.16052316784137682, 0.15414334082555387, 0.1434483703586363, 0.15109895337973872, 0.24867970917013385, 0.24725084793904137, 0.1694070298465029, 0.1863782215983637, 0.11174270312391943, 0.18372190365147206, 0.22023953767793797, 0.14994369278992378, 0.16685866900990087, 0.13553515707533206, 0.13534509066131808, 0.16982847013540808, 0.10878094592161718, 0.1653156453563321, 0.1300268163604121, 0.07277146567620578, 0.1114770468144167, 0.11441683261505059, 0.11433299961349658, 0.2645148384955622, 0.18881254258655733, 0.16869007880168577, 0.19502606723577748, 0.23537127571480893, 0.13065353756950748, 0.1552017372582228, 0.13623480985481895, 0.18278274114333815, 0.1385125118277727, 0.25690544036126906, 0.07238518882302508, 0.12459292406997374, 0.10357594538119533, 0.23737531575945117, 0.17300186678767207, 0.15608617044504614, 0.21822402163618998, 0.23672607156538197, 0.13144361936757643, 0.10893934226084141, 0.2433574971772971, 0.1587003841996193, 0.14689829410804858, 0.09394962160337357, 0.11922134537129633, 0.16468772905007487, 0.10194911170871028, 0.16463630922859715, 0.1710700994778064, 0.11644673578801656, 0.12749579209353656, 0.19174529570004634, 0.13206606580605432, 0.1212711668302936, 0.17250170330366782, 0.12623718624273617, 0.1553614359469183, 0.17981488588115863, 0.11591797424179894, 0.20128509750769985, 0.16231693207256256, 0.10116526586634499, 0.1493957560629614, 0.16950942515846223, 0.07535539597513215, 0.14000174078729846, 0.1439378239334591, 0.15476263098178372, 0.15611810098973014, 0.1997940299371558, 0.26338632969606307, 0.1565624626293298, 0.0767590529135158, 0.1379185791818365, 0.17906264882654915, 0.13798000411160533, 0.15186105764681293, 0.13705728185032645, 0.08005423456310265, 0.09794550557290355, 0.1682987610899633, 0.10797607096573038, 0.11381615839538076, 0.1615298686609153, 0.13223498819335816, 0.1189498897762068, 0.09420094440781301, 0.10616542981757272, 0.1338554326925547, 0.12928171924525692, 0.12980570806370628, 0.18471705186511242, 0.13316308839186547, 0.22340957886509358, 0.10718072614362163, 0.14918305941166418, 0.19060978485691935, 0.10365721964908224, 0.15315881059054406, 0.09885577890541285, 0.1988646273891772, 0.15578439308991357, 0.10545596345177582, 0.08856250664159175, 0.19586147079544683, 0.11304942695724388, 0.12467087351626928, 0.15288712516907724, 0.1441209649126376, 0.2456958120268199, 0.1886569348073775], [0.019184885163521095, 0.05281232417591157, 0.0429450121197489, 0.047963975868638486, 0.05704271915038267, 0.03373704895737671, 0.046582930015339974, 0.056232389648475, 0.022706811601716666, 0.12400058488692008, 0.012405633310516997, 0.03452207074470578, 0.02125035779881141, 0.04242150593669184, 0.03188127373916007, 0.053758661097456376, 0.007145955638524386, 0.05266822303735441, 0.005584507570376681, 0.041222946057396556, 0.0314418820949692, 0.07248409077404969, 0.03322878026313359, 0.08098879288281165, 0.033856937887086984, 0.029477540726563143, 0.008386202671024348, 0.011182609370969718, 0.034313622050948685, 0.03795461578955574, 0.021352435184282162, 0.02200099756009877, 0.01830178496968602, 0.0066706483560283825, 0.03132201997833627, 0.01959617095698993, 0.04255539895365796, 0.03662168791878127, 0.11731061483583144, 0.009073091468082802, 0.003993795182923937, 0.045198501883855755, 0.03245512722060084, 0.03616807959793556, 0.015126345735493929, 0.04017953047408693, 0.056270153952702406, 0.009305948680717378, 0.04345425757609549, 0.07697862137349383, 0.03608036636104507, 0.041586941243299556, 0.024728180555206154, 0.0700816543652646, 0.038229120414583914, 0.05128215930815186, 0.08703197788206801, 0.05515200266193959, 0.03241338692004642, 0.059728029694768696, 0.07458597556838105, 0.023267926956196467, 0.05941822373818967, 0.15568290176170488, 0.028239343458065586, 0.05807023074838424, 0.040110019486277335, 0.032495756693665064, 0.01503782427584332, 0.050090011584782795, 0.06023588470153271, 0.017263153605463526, 0.04756910733938698, 0.04936063842427346, 0.04078724121134128, 0.05894429493515242, 0.04006746330208356, 0.025209751085288105, 0.02939141329167591, 0.030682030126392364, 0.04689614123274242, 0.03083260087747007, 0.09322140140519028, 0.037094797007739544, 0.02015828605621092, 0.018162299510872653, 0.04286666430773274, 0.0636767762743177, 0.0203909469588149, 0.01757858264740677, 0.015437157182473571, 0.0613595633166692, 0.039770615722743735, 0.018153949152497996, 0.023823727575701573, 0.046028286188600526, 0.07033670801789531, 0.01565495980978613, 0.06922638614571865, 0.0667348996766152, 0.017090140308644024, 0.034095118453185407, 0.010100985152436601, 0.010659593484184195, 0.08128715348580191, 0.009838899770270913, 0.040250156119826346, 0.05144038327759312, 0.04337612426869812, 0.022808256964649887, 0.012089282090234901, 0.06224244517544585, 0.07016629942001835, 0.037716818267419454, 0.03586901036361533, 0.023670988795798154, 0.03367891054480307, 0.05021569213920063, 0.054121254342457945, 0.03517230702263694, 0.06451640097844986, 0.01997817495477296, 0.062001859093265194, 0.013339929245111924, 0.060912508878015706, 0.07585870808050518, 0.02131683507844085, 0.03584505479422308, 0.05282719777296147, 0.07950901744827148, 0.025869879473541534, 0.020666997166230314, 0.04204885395724447, 0.05722314817830921, 0.05818135180180112, 0.046246479520754474, 0.02231973418665509, 0.0798509837759118, 0.021391331383417693, 0.010357319129510753, 0.04472021787096897, 0.03785430040631083, 0.06308874250539849, 0.048055910249991764, 0.06527667429538504, 0.04547507494627949, 0.005854254789395078, 0.0019778735933810355, 0.04433021016959702, 0.010890422479039239, 0.03527401668590403, 0.03908959037113575, 0.049227231873139266, 0.05219646992402212, 0.01953910698273009, 0.06496873759334126, 0.02693872151505803, 0.0915291131804547, 0.03012091477191256, 0.06335299304356018, 0.034388748463243246, 0.09065784904504977, 0.03246903554686616, 0.05164130515749416, 0.03522623961250629, 0.01730798315557261, 0.023327404107417793, 0.05006947276753284, 0.0032870443594161304, 0.047935940881049445, 0.062337470721573605, 0.06297258059343984, 0.01816351567545245, 0.02159686128218328, 0.04345285180475443, 0.04026166659088866, 0.011527446613106276, 0.018048767195714098, 0.0029793420323966854, 0.05567712912095651, 0.0440021483377824, 0.02955739390135052, 0.01855665093077527, 0.04945724211152523, 0.01706920312567344, 0.04920752043084753, 0.028383071128759655, 0.04014262035789509, 0.013733106635270581, 0.017135211176449255, 0.06426268414924703, 0.014765886045361479, 0.032634629282139005, 0.018784730627592054, 0.023501938088766994, 0.04745271560105105, 0.08590739911362048, 0.03370562020028311, 0.01610305325518693, 0.04528808054484187, 0.039567476018301906, 0.02267264982595319, 0.06531729993800964, 0.08675173525848696, 0.05642082429521027, 0.06115794429675706, 0.02329208362366884, 0.013089427112361357, 0.034166812791579196, 0.02308593893934402, 0.10546496498488611, 0.05262416149038942, 0.006515207200972063, 0.05843698002037503, 0.04732888131853073, 0.034660073823385665, 0.013736080014026694, 0.10185314387443567, 0.09048350275524202, 0.01648591335622534, 0.02252867317668373, 0.036493057925854964, 0.046696019914722255, 0.047060643292723164, 0.04003097453425008, 0.03225160064175725, 0.04686776533602707, 0.024908896866104296, 0.032224699464296146, 0.09738613881411091, 0.053139799950464126, 0.058877718064092824, 0.01606916344063657, 0.06444743774350613, 0.010017493060008894, 0.034815516893661795, 0.031130262425229437, 0.03890987380497879, 0.01782117013428961, 0.014879802362092081, 0.05046862372828107, 0.04989594619180407, 0.005992294736056319, 0.05950375362449597, 0.04367157373757612, 0.033669774946306026, 0.024979009232934446, 0.06451840812881147, 0.060214330817783074, 0.021739409177473957, 0.03202422766105062, 0.03347981195416182, 0.03437340372211991, 0.01837849909920366, 0.04766640433621022, 0.02172294020232174, 0.11014611460268499, 0.024258267968111945, 0.04406146269531981, 0.012595594387441393, 0.11431180196063173, 0.009310734815024322, 0.06980518855515026, 0.02908117449541967, 0.054759367278987364, 0.05214340684394683, 0.014206738579237174, 0.019679586440625212, 0.035796523124219916, 0.030160611532928965, 0.04060170620739941, 0.034787631293217984, 0.03419087178284123, 0.07783576650845428, 0.006600373674319276, 0.023319138018714807, 0.05683956795462197, 0.028981983346203645, 0.040697643398157055, 0.01588374430749325, 0.05946865530624505, 0.009883421927600378, 0.03751897606097403, 0.06149007022501, 0.03818263419933858, 0.06387432736735191, 0.06565790262914474, 0.008334869034438124, 0.026738929614845305, 0.02848416792168733, 0.031657989752749284, 0.01498667545796883, 0.03581110177741897, 0.01909378007234585, 0.03649171344154785, 0.03760951616230511, 0.013430537336746292, 0.005383852863639233, 0.01701097086732907, 0.01925031098747446, 0.01136994946958317, 0.03720423649816263, 0.006613131432283309, 0.09574054364836025, 0.06393422012127216, 0.022061738756395156, 0.09320085492706107, 0.04463397169245347, 0.029126450291744647, 0.012449874888144195, 0.057880455447781476, 0.017167655000042532, 0.04118101040442144, 0.02666939564439799, 0.03944361492270424, 0.01663221316712518, 0.027463158494943095, 0.034438632278432774, 0.015347665663988841, 0.015001934014200686, 0.11666127105033207, 0.03410421957772586, 0.031182457910730477, 0.018155255332408894, 0.023191519261848544, 0.06862693766672766, 0.029248426811048583, 0.052667326714483, 0.05093148256081247, 0.025204978357519836, 0.10429138723280161, 0.07394488254982619, 0.06335529513777265, 0.024504666742418083, 0.028845596713043993, 0.04400475303672495, 0.02477074440027918, 0.012662922982276689, 0.04016001055377626, 0.053572402140426065, 0.03666353930208472, 0.06794799224383409, 0.06194668927139813, 0.036478567372767196, 0.06590115852774152, 0.03861570753337395, 0.022562886663382093, 0.03219936493664019, 0.03567086172200019, 0.03804561937408101, 0.04740701079548848, 0.04658828880037031, 0.09569067132448959, 0.15200263069521996, 0.07083070449410908, 0.1384705455312806, 0.13498912024642193, 0.19021497378426214, 0.15925150785234668, 0.14125404939536126, 0.11786412868288257, 0.22755841994958542, 0.09394491016263924, 0.093068903942983, 0.23708561195000527, 0.10161503608669005, 0.17132652442782156, 0.22823476833441567, 0.17435047264781692, 0.19165256841769143, 0.12575993644854716, 0.25339211517524335, 0.2663414372551826, 0.14699947900108754, 0.1547020793922486, 0.11842017828096306, 0.11941341893567194, 0.09263489215124039, 0.1262141959441285, 0.18695795097418372, 0.1660097516592472, 0.14379566865822963, 0.08451797608886996, 0.15342586884094825, 0.12283944074184665, 0.1334133693167279, 0.19594551064074042, 0.2194273312606158, 0.09339037741864882, 0.14085729245937642, 0.1776181900453183, 0.1465787281913142, 0.14503369738738384, 0.24923904528540952, 0.1236614530845996, 0.10193389720253407, 0.2143007474801233, 0.17001610038982284, 0.09910910119933468, 0.15211055716199262, 0.1029155852513448, 0.1464100969174216, 0.14916217585484828, 0.2198916418297637, 0.16927708601278646, 0.1826599219273175, 0.1350533337362351, 0.23367937053403548, 0.16063494006952933, 0.16779285194652696, 0.11191807597154572, 0.13105286856091794, 0.21458380164638644, 0.16548597734541665, 0.20818123714097087, 0.22709990100514507, 0.11735204487077652, 0.214266442062874, 0.08852844637247825, 0.11889355167025521, 0.2475845864823749, 0.10237026854508346, 0.12704681860463274, 0.14786636877444484, 0.12746396114028272, 0.12357158331020225, 0.17164204540031572, 0.17125841921135304, 0.20092437734767316, 0.16080099728799638, 0.15345502614734635, 0.09010811201146535, 0.1324146511333604, 0.09774701985260172, 0.13084649979587526, 0.12449641997415213, 0.20282979123294356, 0.11767036972507355, 0.1455182939647667, 0.16100168168064088, 0.15058581236629717, 0.08510782548616971, 0.13934014725588983, 0.15092814641614116, 0.21402878626700372, 0.18433314988449698, 0.1307725723111822, 0.2078485711207313, 0.1272151894086311, 0.09577461923923224, 0.24205209867608166, 0.17268542650966875, 0.11417729990376581, 0.19451758403691555, 0.10201126442200716, 0.09716175932196841, 0.191533763502394, 0.10792524103195437, 0.1815120464250926, 0.1301326590680307, 0.15321255931931158, 0.0874119345098734, 0.11744400606520715, 0.14165906475916987, 0.18475462081691912, 0.19973118008384783, 0.11070415602936862, 0.0588392336372166, 0.14052444257803504, 0.09263803311172994, 0.1040036675910796, 0.13769411542002233, 0.12687316179395686, 0.10695119087974872, 0.1528837390604519, 0.12241579411971955, 0.17818987549793336, 0.20106939779173946, 0.12053683325047455, 0.21696763744036998, 0.15137407087510632, 0.24021768581963357, 0.10327947701537803, 0.14570426946926504, 0.142815750272524, 0.19313985151388954, 0.14693183343737357, 0.12301770940182671, 0.0875775933626198, 0.10619090224105505, 0.0915267306470102, 0.10489993683633306, 0.14645083747323484, 0.12068183837278236, 0.1350973225048473, 0.23097601478859303, 0.1691708755829642, 0.13495472289862173, 0.145910301155621, 0.07025519626275187, 0.2007889023591434, 0.14657920316582726, 0.08643781540975456, 0.14715828902779088, 0.1103397126820299, 0.14160857956495979, 0.175703123452202, 0.21600446573668913, 0.15995704418709203, 0.14507118973039812, 0.11503432246465838, 0.1289877713087105, 0.14804679780237137, 0.15971194201659772, 0.10313515371132283, 0.11131890328420747, 0.17287388413904176, 0.10573722497229615, 0.15413454613618313, 0.1379082369948587, 0.10770820832300572, 0.12666529915746183, 0.15421132346795452, 0.14907879484516962, 0.18467134705954985, 0.17212069713540618, 0.07591386641105337, 0.1695424741915157], [0.02065829249219068, 0.0884490643417643, 0.008244516624648484, 0.021185611877890847, 0.08113440321457964, 0.0529617534559821, 0.04973834658402109, 0.048513463923647526, 0.06858756840829888, 0.04627485541746982, 0.05642476198714107, 0.024755874633668892, 0.026906852257407965, 0.01351089038390426, 0.015787383853157443, 0.03710515834691544, 0.049655245196434765, 0.007366766118549652, 0.015570004489423047, 0.09091604365817002, 0.017046639921083566, 0.07584271982552544, 0.021875202092492295, 0.04932609935020728, 0.010336291931209066, 0.013066879229529971, 0.05123299178517154, 0.027650060965829802, 0.05954883406840025, 0.022709623144398776, 0.12506190011458052, 0.029099110528946887, 0.06869122776533328, 0.044562311828016274, 0.016528371864208774, 0.041223267814324754, 0.028651425982975674, 0.06011835915306884, 0.04514019493193877, 0.06671500437322163, 0.05868599690016239, 0.019728514561129194, 0.021048135484658906, 0.040743344373280005, 0.14989801862787816, 0.04823513651987718, 0.007582118700919373, 0.04648363735947398, 0.036079945012686715, 0.037263152489979426, 0.010179370311239075, 0.06126378700437565, 0.026529822085473328, 0.0336026388310617, 0.09470934333700327, 0.03645551961756522, 0.042877891326263066, 0.042632214589825565, 0.075893503794026, 0.048133997592113675, 0.031647274097908414, 0.04739260451207238, 0.0542402814232534, 0.07002747662725949, 0.029505811286188906, 0.052243308539712624, 0.10708583849332026, 0.046748868490178744, 0.0314909385352005, 0.06717764487069461, 0.02563352028148309, 0.06863936361285948, 0.01790913618019512, 0.04285642171218511, 0.022546530686198704, 0.024276027801416578, 0.0613752413060396, 0.055365760345011956, 0.029898184284027067, 0.05254775571126131, 0.01778584773532085, 0.05344602061555751, 0.040372940861890395, 0.06713275211833178, 0.028519390729225935, 0.053174446276839704, 0.021566012836692315, 0.06300767125081151, 0.022662317215074456, 0.013738203035186858, 0.05410268437117339, 0.06911625334572408, 0.051024202182288134, 0.054134277837170716, 0.06090684365781565, 0.0649614061319059, 0.06546403641902632, 0.03493425669148564, 0.03807561554675622, 0.04984057335663707, 0.054739843528237075, 0.04857693813861378, 0.007740517434168368, 0.025814485570956624, 0.025183943498338905, 0.018235328757474502, 0.019676838100196856, 0.012735283817164602, 0.04470863079111423, 0.0583055729587232, 0.019076878257516413, 0.036093596699497396, 0.023076223029244333, 0.047690831049675905, 0.022533752339621706, 0.004600026173472044, 0.03431357608567323, 0.021675977097343535, 0.05063086965932481, 0.05611249305788548, 0.022689390762318528, 0.10403540661378254, 0.045658683239091793, 0.0411185052906794, 0.010484320227988066, 0.029217518993743488, 0.034365298511881026, 0.06788577058262403, 0.07417507664931398, 0.08341213583105034, 0.024439851873584335, 0.003108037621601515, 0.02693049756119088, 0.04673077732384686, 0.06229930422118595, 0.045111704122034774, 0.056716461455629724, 0.02729978641465066, 0.023078255077463486, 0.040321149487769416, 0.02734936187945066, 0.08221307033372503, 0.1017084681699353, 0.09533788783535843, 0.041899983921358665, 0.03790142247453332, 0.038457916403609904, 0.05420245200155243, 0.048889800786010684, 0.06708005293002052, 0.0445631392029745, 0.03925833272777739, 0.03841740567417395, 0.05361744811037376, 0.036335940953464284, 0.049274890202908754, 0.03306612447505036, 0.06418749644991852, 0.038418344131881194, 0.016564454605442383, 0.02710001366663604, 0.02662061308059962, 0.04733414434257054, 0.07020403691116842, 0.021628625202743758, 0.009879845254603895, 0.060246154110157685, 0.08239217402954256, 0.022672004396876982, 0.03487023089321391, 0.031346153663170916, 0.0483557302504778, 0.022930515021265998, 0.049621491362490965, 0.023517416895277077, 0.029522605848708944, 0.0011703239133273582, 0.0540467752744594, 0.011872983868083647, 0.0102431787320623, 0.06688012696442104, 0.04930045838738161, 0.09444865127724987, 0.030529186009399356, 0.03111191270422311, 0.05624663122298737, 0.046750492596578215, 0.012990177548941106, 0.008708967962452482, 0.08764327008036837, 0.020873488505340872, 0.00847336815504898, 0.01863692162348138, 0.04101385384978306, 0.07098058193561531, 0.027152952257423636, 0.04523837676031455, 0.02730996580794454, 0.005331930775766171, 0.031100425215798522, 0.057297293998060696, 0.03858872591668079, 0.06607238683969745, 0.034896756687592116, 0.06929689687826941, 0.00841555628745306, 0.022673764483883016, 0.08181850440920362, 0.049227197399182666, 0.038357409498383926, 0.019981325491361564, 0.02079598530526123, 0.03643117334333159, 0.03286411091985722, 0.06832938145605788, 0.1250138970452451, 0.033623215952707876, 0.04279752870300605, 0.01939016225327167, 0.027612181748413754, 0.04969677865324963, 0.12712241616100073, 0.06244129478751172, 0.03854493633092892, 0.06537891638975951, 0.030044334707781676, 0.07471578150627113, 0.09146367394996267, 0.03993745435089354, 0.0697700787455805, 0.025013894961786368, 0.06819426652885253, 0.042691188038236676, 0.028861667322475585, 0.06317770829604519, 0.035058562118079395, 0.03423696729324518, 0.023300479947318955, 0.05764989362609002, 0.10156625926855112, 0.03100042584382238, 0.036326035436603336, 0.09843415475540584, 0.010757082002988506, 0.044252996167708794, 0.023106606076321295, 0.028103780369424534, 0.07831064143007802, 0.04372703467285441, 0.04486585884625393, 0.013235936639830472, 0.021512423071169087, 0.08233573633216082, 0.05623368433706703, 0.022537538729187463, 0.07763572562966617, 0.12842390761380235, 0.037113343996386376, 0.04198022014010818, 0.006128697648584362, 0.02502629792528047, 0.04294774705363859, 0.054880462797178384, 0.04787239771817, 0.05415465577595657, 0.009104251136793005, 0.02540672569715929, 0.044693197949879596, 0.01563608723377148, 0.06368900686802884, 0.047390486278961745, 0.018474915094913977, 0.04362075146467936, 0.06100894402592413, 0.03756773755735448, 0.16450549205464704, 0.01825471844283804, 0.01467985915951431, 0.027964829256938353, 0.10660346357091781, 0.030351919009380286, 0.009373481246462513, 0.04831964750924418, 0.035590905125343034, 0.06622814783646215, 0.06871486923867656, 0.027026442412827766, 0.07425469616728445, 0.06565068608089801, 0.021681245867042773, 0.0328047429361651, 0.06989104402882439, 0.042008864167597026, 0.007882054093398996, 0.035426314965251, 0.060246226888510494, 0.03175603751573832, 0.005586987780031538, 0.05049985713295398, 0.038479554557031205, 0.021857392463472583, 0.038695338542663285, 0.031216029798792257, 0.04560874579774757, 0.02392267740722145, 0.026803183324274518, 0.03792523631765958, 0.02591364799187549, 0.018404381379725474, 0.027104610194181724, 0.0038250841880066986, 0.032582320798669136, 0.033251326230745164, 0.018335693936434486, 0.04579929484715385, 0.03156935912556946, 0.0419255291231938, 0.060435412301411556, 0.03339703232350369, 0.031138622359703147, 0.024738105224265207, 0.04585630328003918, 0.0281836852551468, 0.02604885101919213, 0.05172781180590392, 0.06180728808225644, 0.01310180900843754, 0.03341577849501083, 0.05041073429428282, 0.04060669343978648, 0.05758672584629348, 0.024220978638397592, 0.019093385537064845, 0.05145284369768155, 0.06294582880312397, 0.12821480391487, 0.030005748774255478, 0.0379664748306236, 0.011964894309189292, 0.012400550317139396, 0.03320030094454846, 0.03700440629355369, 0.07082658294107645, 0.038827925379718506, 0.02624092075312811, 0.03584633033061701, 0.05040818705193458, 0.10666069033886157, 0.02029560157097876, 0.03096534859298939, 0.022599126452640183, 0.03520749344099914, 0.07198034199855982, 0.1941394430374907, 0.19628124101267708, 0.15836302972128316, 0.16869156501225888, 0.08627637004059169, 0.15734880591832823, 0.17327957366022373, 0.13036669892889838, 0.20540449017238235, 0.16719792338628925, 0.11271122978219103, 0.09749000501488486, 0.14879102157729288, 0.1076876235404803, 0.11118715148298972, 0.13287638764708273, 0.12312688459191592, 0.1611636173460753, 0.13317600463426885, 0.13258135186568384, 0.11204130887504547, 0.09287257859062764, 0.20414033784501015, 0.13354319057637645, 0.14450292102992535, 0.21249224371727438, 0.15177697183624392, 0.12347727788672333, 0.0487852834105011, 0.19996365712535, 0.15600370874087657, 0.1834466482602781, 0.12752867258724668, 0.09242301521402213, 0.16964768870703636, 0.16265085447699795, 0.20346012837704153, 0.10341580236150373, 0.17432923669055586, 0.14594900391755566, 0.1342633132252001, 0.1337973172626188, 0.10440765639706966, 0.2558282441309383, 0.20397875458002093, 0.2173295220540416, 0.1629504867859425, 0.12150342170629772, 0.11019196496495318, 0.12961369578636464, 0.15440719682843457, 0.1047750568437961, 0.10531494198667427, 0.2130896084371113, 0.15350040919598074, 0.13597024905104793, 0.12412230093632975, 0.38869303320684745, 0.19093895751622417, 0.16029289713309658, 0.14414382497629813, 0.22273938982717453, 0.32976144383991923, 0.16511828578527898, 0.0831034023975653, 0.20450513359279404, 0.12363624113101153, 0.1695113863435484, 0.11723187631897389, 0.179519574308107, 0.180851525416778, 0.1550536524624594, 0.16158344885033948, 0.0961308731066604, 0.10041300582909778, 0.18213165833825068, 0.15557304475336306, 0.13789136773876606, 0.12107599060982467, 0.2886945652144571, 0.11794226199027993, 0.12746190802464563, 0.2570729684685507, 0.14053077046428958, 0.1806638185535708, 0.15950747314960728, 0.19806830963540464, 0.25163549088662673, 0.11678017555705963, 0.16039193697994755, 0.12894935966018709, 0.1792721432303229, 0.20734802459276494, 0.17407541643948327, 0.1578605679735061, 0.19361876371887424, 0.11838835498858845, 0.18305009050715357, 0.22125570734422054, 0.1306617347102973, 0.09978110586563427, 0.13114291453553786, 0.2742973216358693, 0.11011226117731103, 0.14792310524611704, 0.09029433266409943, 0.10416774830270199, 0.18168201069197348, 0.17476299567328346, 0.10120664227513537, 0.1933846778927311, 0.14898608288457318, 0.15783567011596697, 0.09534577854097852, 0.1604385304475023, 0.11805053319661848, 0.1594565436244011, 0.10511356045401866, 0.1512470994625361, 0.13925347206813676, 0.18859725655807605, 0.15828358640353526, 0.16029462849180545, 0.04284445924924747, 0.11919341380557708, 0.19631694070994857, 0.1780982820257064, 0.1677126425408548, 0.20330154817671547, 0.23531224097936387, 0.06968191734725429, 0.21470092116825043, 0.1543853326790756, 0.1213532071861048, 0.1059051284626607, 0.10627947732686036, 0.13414361964791052, 0.1423034825993161, 0.1172701424107917, 0.21602234622884184, 0.16830032390932884, 0.22473920106647477, 0.1930480282152853, 0.26414785173631483, 0.13921291537342534, 0.110018331136915, 0.14359264003653682, 0.1368026801895711, 0.09450356445966229, 0.1747580620670511, 0.14759894280183702, 0.08694701107038606, 0.09523564574098396, 0.1421356940221402, 0.13485911512567153, 0.10225208416100472, 0.14481787509735555, 0.13066303705976856, 0.18457863509895342, 0.08144012592252224, 0.15397215081799417, 0.14126030067282339, 0.11252764447201645, 0.060433949073476184, 0.09179604119591175, 0.24328917745620976, 0.14922602162245782, 0.16012613511373922, 0.15920244758167576, 0.12758565420705464, 0.24373223674633812, 0.10701959487050773, 0.1286584607535793, 0.09193294110798067, 0.11427768040448429], [0.035407572624183474, 0.06386247981760292, 0.049884991134486856, 0.06703761931989463, 0.05729241784842265, 0.012073490145285765, 0.019994686064761014, 0.01422740571621445, 0.04675782022757396, 0.030422063934947216, 0.06704369439713417, 0.027269529772081205, 0.04724834632549075, 0.05888453624661892, 0.08209373681775986, 0.035928102555654706, 0.05718803070786019, 0.017645758982267112, 0.04149874537101677, 0.036313034924528295, 0.08445403839070952, 0.009272783776865372, 0.06061528974603261, 0.06593355638605934, 0.02250862848614493, 0.04069952797445078, 0.03604680787952196, 0.0037003021110825606, 0.05271714541219896, 0.01243891408516755, 0.040860295355800665, 0.03982076383826714, 0.09384399340037378, 0.033536785913090554, 0.025251981682114066, 0.0463815369913655, 0.03137595639864524, 0.026585049363934708, 0.022731125317213517, 0.04126290903396664, 0.10410644594700107, 0.018972221070960648, 0.05790834104822529, 0.019925694101520126, 0.041772376655811266, 0.04631081175419592, 0.04072801112347553, 0.01158358362097774, 0.0850490665423774, 0.07230789821234442, 0.040486214622374506, 0.07630327656384438, 0.04940573418993623, 0.038108978675858635, 0.054331687203938925, 0.0356031050755372, 0.015160043070453311, 0.03179176019564752, 0.04242479245388701, 0.020474289664097374, 0.09124998904524312, 0.11024936793311951, 0.06826011944682368, 0.035584898996016676, 0.10984854307025672, 0.021020876161093195, 0.026351674084341335, 0.048541897276957194, 0.02678518600371336, 0.07292837580485691, 0.031990378066116286, 0.045826069620107455, 0.00511837131794422, 0.022016497434026772, 0.01929144799378851, 0.01446572034769962, 0.008193890661782315, 0.04503802178547748, 0.03431281765862819, 0.028096031390070438, 0.07863370836862633, 0.0174343723413204, 0.025900003965944055, 0.009725194127719489, 0.045787382179931294, 0.03872223205924515, 0.035866447799508615, 0.0289081669442596, 0.05318987528763471, 0.05683025615590234, 0.026509515009820465, 0.03542327742663122, 0.03323394752618286, 0.043746324766787796, 0.029177588575910178, 0.0060514716765723165, 0.06957279578331979, 0.07157449159891376, 0.02118146734222049, 0.08660486088164392, 0.017447912945382057, 0.05305752593783602, 0.06348657579491697, 0.03113671288555188, 0.03845532702642583, 0.044449467076769764, 0.043620161576977665, 0.0634188766050483, 0.04432366011784442, 0.06618513966039305, 0.03431768614738699, 0.04223834580531524, 0.07241397840721954, 0.014558093314389548, 0.03822756525609763, 0.013469587711076583, 0.04565463446441197, 0.02448805029534044, 0.06493689897920817, 0.017486583148579926, 0.0682694657194999, 0.042446779177313855, 0.09038787199965409, 0.05927802581760672, 0.06491340306257048, 0.08317625735916438, 0.04151096064296942, 0.02840872741334381, 0.06864223644257554, 0.07118381740104768, 0.09913192295859899, 0.08576303750516907, 0.09091183783546572, 0.027858963566682035, 0.023470944086570415, 0.05317700884094643, 0.05906868080097822, 0.0780014100394422, 0.038255221030164155, 0.0326231379632748, 0.06436322935886922, 0.07113464987806736, 0.013713576181250955, 0.0354055731347011, 0.051132419762471994, 0.027384714921936396, 0.04870402446437267, 0.026903029478665803, 0.062225487819241906, 0.08557838733277975, 0.03089250320748937, 0.060874399834222374, 0.046661120779331655, 0.05787876622390844, 0.022117500381183722, 0.04893658960598612, 0.030565383663821607, 0.01733341727465872, 0.038440365329264634, 0.05583569399952408, 0.04454819282757179, 0.051552860306635986, 0.09223620467368635, 0.03301780730966599, 0.03015109480568959, 0.037065379231447176, 0.06427869155642486, 0.02290252025329298, 0.046379154457920985, 0.13441584133092435, 0.0418858151251991, 0.016731069152874332, 0.0612612895577425, 0.06738626593423468, 0.011311722956898232, 0.04601488348036524, 0.00776320800087565, 0.04134246726490317, 0.010759409952668414, 0.041678358515303944, 0.018194371781822656, 0.04272134508937598, 0.024587356357745106, 0.03220945048416334, 0.03125949762761593, 0.05722463438888231, 0.04692898342205633, 0.04849869757890702, 0.02604495354687735, 0.04125802905388898, 0.03482500489260401, 0.01264820260281164, 0.01702474129776801, 0.03859890722519448, 0.013365082784495769, 0.04948815375926995, 0.04566951955278074, 0.03315291457599209, 0.049656045758315635, 0.033761368418533, 0.007471440542083715, 0.021144066929757115, 0.041223930480379256, 0.01855727146199394, 0.06796706017226943, 0.016949888761906375, 0.03992876308339258, 0.046844070236529076, 0.07735359842979139, 0.04851787659009138, 0.04362209977942609, 0.03192663572037653, 0.06519812730050857, 0.018929549973578225, 0.029138552565728466, 0.02777457515138292, 0.1186130102723837, 0.029329011599803646, 0.027700440822950298, 0.03871662812607904, 0.01065285095284062, 0.028211863884221644, 0.024308795297157862, 0.02092857597275607, 0.010426331202559655, 0.0104029655208691, 0.05001460938083549, 0.08551335412888758, 0.033710174592992956, 0.03195549425248417, 0.03298024984917814, 0.015925075708618088, 0.10010087862610818, 0.04949632791742202, 0.04800526800775721, 0.06737524958988352, 0.04955115299972315, 0.07371810520248068, 0.06943122273491276, 0.03641516976659337, 0.03851135869720771, 0.04851803746855548, 0.038823570169868975, 0.052163470686683734, 0.08054423972123093, 0.04007462239373596, 0.018558075854314432, 0.02983731668322317, 0.06955916707914683, 0.03274724420700823, 0.03850385486598938, 0.016561148936049114, 0.044595215304364125, 0.05016139565756725, 0.0465687420669823, 0.02299050545139659, 0.05184471682314912, 0.027473563884174632, 0.043198472309497096, 0.0054243386952176455, 0.021220656569987055, 0.023277706068549908, 0.07864238814480844, 0.031715695325645714, 0.04504150365509334, 0.04135578570346679, 0.02177439832819566, 0.053093214143788627, 0.012442493630993753, 0.02683796180081704, 0.032870216640613736, 0.01539603645552791, 0.0387434488643081, 0.047055449216596545, 0.026439452438705394, 0.058793869740780325, 0.05552164774628417, 0.03522133664979089, 0.06637733579883653, 0.032689665038619316, 0.02509294757469287, 0.004876051004224968, 0.026419844418283434, 0.025045126451239474, 0.07659205340690191, 0.038222072405680534, 0.07363690754338618, 0.02713166075878807, 0.06627702424603124, 0.023400398880063046, 0.033376148766687805, 0.037448587902491136, 0.05426473494979644, 0.06256702513764463, 0.07713425979619065, 0.03070441330032003, 0.093943040908104, 0.034809219650924206, 0.04024497353501859, 0.16373709054483523, 0.013805736558541898, 0.03606538551168577, 0.01082170439223128, 0.014790036967174422, 0.05997493983276429, 0.04263589947274135, 0.13322455928690974, 0.0395385715209188, 0.03553542503786664, 0.024843248876652894, 0.03414739629313831, 0.04497693010395573, 0.039246282164728453, 0.05556804203097859, 0.023581335441239422, 0.05429214557572719, 0.04944255237557715, 0.052363208960741765, 0.10378958432063942, 0.008494320659778051, 0.009065796395823842, 0.054890069539748856, 0.10992423255717564, 0.03772979962729639, 0.03906597954130942, 0.06564508597817152, 0.04632195833349421, 0.04703104165532897, 0.07979063136923699, 0.0985748544635792, 0.0324536869753032, 0.04407473516860797, 0.019856637020805673, 0.051464082207530744, 0.03491564458536525, 0.043012420196206345, 0.03487508789065384, 0.03835511889549033, 0.05328489317288322, 0.02220962245407845, 0.047335362422370145, 0.01960023313820843, 0.05450264738512136, 0.024067182657158664, 0.06300832242554714, 0.04804150779701529, 0.040679015970278176, 0.006828854609686401, 0.11569072958081962, 0.037893723290894306, 0.033659677907464006, 0.05981956187996173, 0.11540725406619812, 0.12897709204304603, 0.22862061617835877, 0.07929399188968443, 0.20162940806438848, 0.12033310748877064, 0.07036745878717593, 0.13053770507535628, 0.1596621463015195, 0.27300532967332874, 0.14677648612808797, 0.09774276040374272, 0.11627193750633348, 0.13030219432567397, 0.10333505669428457, 0.12928113701843447, 0.14091516274117655, 0.14512647063501422, 0.12957058035798613, 0.19065043348218166, 0.12923719421509774, 0.14059948855109755, 0.11618900082765088, 0.18809344649555224, 0.12858270997962645, 0.06107435644333882, 0.1277111930352065, 0.15874409717657875, 0.20363566976401115, 0.08255620111501025, 0.09595786747072013, 0.16021193696125863, 0.19075308926403525, 0.16129719243655283, 0.09823570733950024, 0.1821988136056931, 0.14976655794007165, 0.10902014921509451, 0.12200195342302324, 0.07999093271791935, 0.21536081398446716, 0.13126613211727914, 0.12443660382902431, 0.1240086441318835, 0.1599194905570438, 0.12502570246015826, 0.11006548384865446, 0.13729748105810535, 0.14247739987988628, 0.1126098380454125, 0.1046655982011749, 0.2696570964349855, 0.10432395363046278, 0.12110789817187095, 0.18159104541184443, 0.1380427467126039, 0.14311867675954296, 0.10824230950205557, 0.12952705124212852, 0.25573124207796594, 0.2405728595030885, 0.24165431518227826, 0.14253297189791359, 0.10631081798384268, 0.17209763788888532, 0.12651154531105874, 0.08302983497419665, 0.0971166750476245, 0.10554781739389706, 0.2329029710662942, 0.1399141769375532, 0.11896003278032427, 0.22004064593103626, 0.17052599319046544, 0.101021517128233, 0.07765328436489068, 0.24790507170461842, 0.16131613013004104, 0.14003975407010125, 0.08000610125882011, 0.12861670896170602, 0.08732158210008376, 0.1333626849396575, 0.11590143440351372, 0.0912017178451342, 0.18706344128135713, 0.21342906199636, 0.13389548376923607, 0.15998531283149797, 0.11954582957250458, 0.11076292263404017, 0.16201544583084124, 0.11424128356720172, 0.10272439268808212, 0.15723818282206214, 0.09126958557434621, 0.11297746831851621, 0.11501737659977329, 0.11311482788333971, 0.2247672858497789, 0.12819251841715268, 0.12857567729248157, 0.26124732028092107, 0.10642773066196712, 0.17536478838132274, 0.129580830614413, 0.11688048710986493, 0.1818754632146128, 0.14541196096087658, 0.2055620131713729, 0.2059344238331241, 0.16354999655196745, 0.2443636617352886, 0.1098866253009727, 0.17345831729471686, 0.07643070762916919, 0.10402209966653779, 0.15061691553602297, 0.2146443379141631, 0.2288459073151312, 0.13823713386251082, 0.10953627797144075, 0.18888706761983134, 0.21912446606063077, 0.15553622656772215, 0.18239900770206607, 0.10926069316243935, 0.10400619568122972, 0.13331875745807925, 0.11752351066998898, 0.30079192091380397, 0.14180975425387585, 0.10656640023714113, 0.09146902890455338, 0.12151119749872916, 0.25029059289203537, 0.1152991897035991, 0.22678718391445377, 0.11187883694806408, 0.13473344606257256, 0.15850881625327373, 0.119481761639397, 0.18380589753149018, 0.16375536940270857, 0.16702641162180132, 0.16329268293996013, 0.17618516129591774, 0.18452834908760365, 0.16636310205344232, 0.14418458085386984, 0.12493397875298416, 0.12559204061906185, 0.14238458066698045, 0.1122833390329634, 0.09017985614557421, 0.17614457395768937, 0.13751383960968064, 0.23899617394612682, 0.15777891832253627, 0.18766616861666405, 0.14928550068889895, 0.11746774712998061, 0.20373340726139086, 0.12325760983531514, 0.18113160716189494, 0.14602322251565997, 0.20955811164552168, 0.10205903766496528, 0.12305923902820196, 0.23142986059669526, 0.08314886971587136, 0.10482699760506231, 0.18293232747143318, 0.15381867276324382, 0.1546191273918075, 0.10495965339003072], [0.022233424805885842, 0.041359926408697525, 0.020528580400071317, 0.028636431727077694, 0.008537872758273397, 0.03563996539601395, 0.01037226263208375, 0.010676027027769916, 0.018160246395235582, 0.07297691513573931, 0.10602195687111347, 0.00862170575982741, 0.018090130197965813, 0.03606621671708361, 0.06837530842711849, 0.11446747102684553, 0.023837249027565125, 0.0199278736216647, 0.03294247405363187, 0.02241218950779688, 0.06568317586976676, 0.04431414530582486, 0.049631025326708635, 0.021456372248189106, 0.058852513771384, 0.04605699150312332, 0.08706582364656272, 0.008474446423802405, 0.06925994845768137, 0.0584678303810858, 0.053423244821568655, 0.07801544477021502, 0.039084626121386405, 0.07745140487508428, 0.07127780106759841, 0.07291237988899793, 0.04121022133697425, 0.06456090302597131, 0.00667915624123247, 0.04137585337664332, 0.05643234625759144, 0.0759659527290252, 0.08651326740941695, 0.0801087417189152, 0.04648893102703076, 0.022757974783739737, 0.03635538426498252, 0.03006447515931101, 0.030648190107557084, 0.030615531779345007, 0.034585943325392665, 0.03155565764304371, 0.02661581162453419, 0.02914350340893913, 0.06557937095602674, 0.07272481858249634, 0.04192219281028356, 0.044997821321650866, 0.04564344191983823, 0.0527345662515971, 0.03976578936882077, 0.045700557605032964, 0.030028095559006738, 0.02497311993201654, 0.026868463591522267, 0.06393257303223496, 0.05291086223517215, 0.03653112866525208, 0.05148122725527614, 0.027222461330013412, 0.05503653788999204, 0.03182454684358691, 0.032884795293812795, 0.07368377680259366, 0.01844876468361866, 0.05688901126925504, 0.04511435478625279, 0.03455844842979024, 0.04360179461899304, 0.03409510313142692, 0.0566273654300359, 0.08466914821896823, 0.03757507284922946, 0.0706655895637889, 0.09520619732117462, 0.03040764807543207, 0.09219224654859112, 0.03890589780865177, 0.028161035865665447, 0.04128610234587424, 0.0103584548548585, 0.01783678875184588, 0.02119812592413397, 0.011679184690658605, 0.03771600621421972, 0.04814951470301998, 0.03251035449906223, 0.02393704155580171, 0.05791927695334439, 0.03932695888403443, 0.034908002858320554, 0.051797839903062394, 0.00911126945978932, 0.04163413992031448, 0.10302731151422186, 0.06646417186505373, 0.08849712103725442, 0.009404277981018588, 0.07513688471648963, 0.05587606300269404, 0.02019878912476763, 0.04573107088705705, 0.029031011058137785, 0.014742501211472818, 0.05378962254091617, 0.03619822132731638, 0.06096495525731195, 0.04651403955874905, 0.02291344466709322, 0.06610697570947871, 0.07305306427541279, 0.09285713425807415, 0.018433395044637785, 0.07183439458810514, 0.027240906812010274, 0.06330980100638925, 0.06539840566655321, 0.07756591969800573, 0.0448627753423587, 0.04963062696098801, 0.03995410144148816, 0.03797800828432364, 0.07466432338039722, 0.040913921510500294, 0.03244961521798565, 0.025704797101958145, 0.036898804903631253, 0.06750939924630427, 0.01171118226803599, 0.05872718561741133, 0.06952421048716192, 0.01654756428193181, 0.017804789259248686, 0.0513300244816609, 0.02168633652129962, 0.11593923318169772, 0.019305586146431106, 0.018688885367385322, 0.06732045132065974, 0.02150372414278888, 0.057158114974417036, 0.006668134151221884, 0.05950144769984388, 0.029075392446811163, 0.03212474797281527, 0.08496462833136322, 0.01105369401029161, 0.053890018363393126, 0.06513256549594865, 0.06213415864734881, 0.011471740529692222, 0.046137181756597374, 0.07585730613960374, 0.054640776868308746, 0.042948045827929056, 0.02097462168744495, 0.07904062363048715, 0.027107871813519348, 0.03694644408120263, 0.046513403705771894, 0.014155537092817888, 0.01346300988863673, 0.0008268440832316336, 0.04250375313624259, 0.005236346943063601, 0.011613157487684682, 0.027760180359285687, 0.018892865853324052, 0.022093270935358542, 0.043413088011044654, 0.024546949050178932, 0.04216411571589209, 0.018042778303366036, 0.01065334316433197, 0.033755090327993516, 0.05310071031412771, 0.06223747709525689, 0.07603640217454204, 0.04769588339953654, 0.03921842337736199, 0.08501804764232329, 0.01759038997753974, 0.04465294002945866, 0.03263956671881099, 0.0014331427049793064, 0.03796505756796368, 0.02057075928596239, 0.06629025458448357, 0.014905936494019004, 0.030989698697662646, 0.01574449250549679, 0.04635049510867365, 0.01571583507146927, 0.026403046025323774, 0.05551983211790362, 0.04173250560979209, 0.019966691296787995, 0.022057170957146634, 0.009258709784086433, 0.0282296275479659, 0.0652436635667278, 0.06744054326366994, 0.0572690713189302, 0.014406231705159431, 0.01830060902472225, 0.006429025182320226, 0.09300607707231276, 0.06348558754149465, 0.061254900384454004, 0.07150520660704182, 0.03264746891574995, 0.03848593606944046, 0.02135318978088758, 0.07079172594052169, 0.041733233393320156, 0.017909239602064895, 0.04302904813460285, 0.05739066096383238, 0.015219455104201071, 0.05719394107619601, 0.0903037938499643, 0.029234968561438784, 0.01993961583432411, 0.0190348889783866, 0.04026111117714355, 0.02526829743968143, 0.023146888894599774, 0.03405978264767797, 0.0747845532192338, 0.011382975837125654, 0.0035756720547308967, 0.025086443488215728, 0.010660581737606516, 0.026702415949154287, 0.027155798274062337, 0.02653234634518383, 0.061911809288205645, 0.07181321991787804, 0.04510770131263041, 0.019794815640536048, 0.011931194101400193, 0.026358940428303137, 0.009200813646818842, 0.009598857610516492, 0.026933876008936958, 0.038999326061457396, 0.042637875979585994, 0.018382865800372055, 0.042685074656600916, 0.02257767790598014, 0.09067375303035782, 0.0468808347960153, 0.08529327239000029, 0.04858911893660984, 0.0443175352448898, 0.03421115779107617, 0.02259923562016939, 0.05563502875907768, 0.03415046447527505, 0.06825219043680737, 0.07311904742833107, 0.08454372430400503, 0.05460396634354707, 0.021641876608614, 0.04102390492334962, 0.04997163567872298, 0.03645459265117684, 0.04704818287263474, 0.00887556623051604, 0.021408026354507576, 0.03702347422198903, 0.04710604549355565, 0.017924590088847666, 0.04442348520481779, 0.13424475857567403, 0.03661877295422939, 0.03653737994271421, 0.04469984376262273, 0.0038100803560096653, 0.029521652069243214, 0.010372819003438758, 0.03976077915379598, 0.036688272450720115, 0.0475890294558579, 0.03016761166133708, 0.015273419295197294, 0.056995152751164097, 0.026920266456962116, 0.05680218669435671, 0.01958480412741342, 0.004723374468965396, 0.060222608397804925, 0.07087456302777415, 0.03564431294498425, 0.08820373234489272, 0.015744950243031547, 0.039436930805564895, 0.05921046069312481, 0.04828781272555071, 0.022301083776138486, 0.01122762852784006, 0.01564174766592201, 0.029652702900010253, 0.08177652279095304, 0.06604841594854671, 0.03351330531821136, 0.014682686981564809, 0.039007285714990673, 0.0346283654441997, 0.07267411122278822, 0.09028967484951982, 0.05420407227751228, 0.01223027291181948, 0.036881115933459614, 0.021768482214200403, 0.017023364254724116, 0.07244387881890421, 0.036246902384464784, 0.030182745728281238, 0.0554661370152908, 0.0270798004367539, 0.039431997199332526, 0.04048008208854064, 0.127595130714678, 0.04712009937652657, 0.03679950841732564, 0.030562928352024288, 0.029988950381295818, 0.04502810860773729, 0.014850198809478073, 0.04718577992471476, 0.0183385782574694, 0.05219951512352113, 0.015013798800927979, 0.03232408405071305, 0.05513175495810086, 0.033195367338316094, 0.00939654145059326, 0.046132772920593146, 0.026282350788073196, 0.01618297346266768, 0.02675554797714276, 0.12454007166407763, 0.1767446046635028, 0.10306457403085886, 0.11764377881322177, 0.08562147211764129, 0.16774524724291218, 0.11025985567680291, 0.10994703899468146, 0.19009474394542558, 0.08828711335457141, 0.21744907773550481, 0.2480850104362734, 0.10102005390029761, 0.1137513243743489, 0.1965966853763788, 0.14777233914261864, 0.12731679565002843, 0.1265938461367642, 0.09834004085390799, 0.12386137138931982, 0.1833089669385264, 0.11275475889804865, 0.18637209289496948, 0.10858426050793742, 0.16477170760833448, 0.08314784315805282, 0.22886475307806847, 0.11064067798396272, 0.13753841571029157, 0.15745421961670922, 0.09994874122522532, 0.1585334689626771, 0.12811737285266, 0.14269832431549026, 0.15025023521194536, 0.1483626711753107, 0.14467671573642762, 0.20104615468411677, 0.13225265418089208, 0.14038489200174809, 0.3066296028273721, 0.1578678764523037, 0.21706502253730453, 0.2177976937063279, 0.15798865787444577, 0.17338078919677966, 0.11630805089108406, 0.17160585540677273, 0.09807803878380407, 0.12442883569747211, 0.2119649607207506, 0.16103223326706118, 0.12321614149597385, 0.14138181753937276, 0.15788171200021622, 0.11710583187279203, 0.24686939743978364, 0.13733814500512617, 0.2067326568067074, 0.12877895106231013, 0.09405456798812074, 0.0999257585874969, 0.20523656369938006, 0.11763194275479164, 0.12416340921434665, 0.13143176032650855, 0.10788768740190614, 0.10643394363503303, 0.10530186486580681, 0.1499030901299369, 0.19421864120710283, 0.09114314276244372, 0.11149007030912947, 0.17767180087825946, 0.07774702288330564, 0.07515502567853659, 0.08923562213538155, 0.1020362771927349, 0.14807319719224207, 0.1057824241598287, 0.10624679601601056, 0.13270774105143163, 0.06878035443444407, 0.20165485750523307, 0.2132316564600314, 0.16348684026348978, 0.2204838277952325, 0.2478274669978888, 0.23142789941160913, 0.16175306071677517, 0.1270715785663455, 0.12083453501784995, 0.1913489524515406, 0.13209890033448898, 0.1558099038177921, 0.22262642250186016, 0.13116048859252086, 0.0717685799745302, 0.2192245018217833, 0.11267425837896525, 0.13589878836947103, 0.13103535579096887, 0.1303714946393044, 0.2338899681044202, 0.24248657778145807, 0.12383287291853659, 0.13029436490708782, 0.12139117450363214, 0.24325966774936647, 0.19321999963252776, 0.14634956064964497, 0.13743087228748108, 0.0805676437073177, 0.08205838952093356, 0.20392898950845967, 0.15183775325215634, 0.191419325288265, 0.1388489163570827, 0.06636702425537572, 0.1133729229050298, 0.18584675576177337, 0.1548287750131661, 0.1260476560902692, 0.17563213774513814, 0.09303292845405879, 0.17301570233558455, 0.1989901738782083, 0.1355052030374927, 0.14484641953341423, 0.04799987857920989, 0.18422272597109118, 0.09619246657577255, 0.21435999672018716, 0.17320101900446802, 0.14624790078209293, 0.1520609453080162, 0.1454448414545867, 0.2123893581090435, 0.18324832341844038, 0.12516905283254962, 0.13771745045819592, 0.16339009868041163, 0.12598031696172493, 0.1409933649964871, 0.12837368288948653, 0.17441450227652827, 0.1198624537116097, 0.11739768838930516, 0.13432962579592583, 0.12877691326843155, 0.18062773581233718, 0.15871143118748743, 0.10843668899108326, 0.11869875083286917, 0.1844802847312343, 0.13871527997957123, 0.19547963725222697, 0.24609201737949926, 0.26561527783351563, 0.17539193853735927, 0.11547544355233831, 0.125451861850677, 0.10872196481232682, 0.23542844119571874, 0.11177381395452446, 0.09246392430917871, 0.1388346671216911, 0.14945407067575764, 0.15821013389335525, 0.12828222731308592, 0.15364094036481074, 0.08144158148957838, 0.1732228678320685, 0.1737678627814016, 0.23072093815332462, 0.08174120613764371], [0.03906358551654605, 0.08049706402685373, 0.05692733098722755, 0.042201274810659314, 0.05780909435763475, 0.054664640507150086, 0.07484913443125064, 0.041774824306729345, 0.02927061846299518, 0.03850003208724722, 0.06303139316338686, 0.0034899142572671297, 0.022992478127801613, 0.12825352199856313, 0.030643103283739863, 0.012434730287491074, 0.04682734653714203, 0.04889812433130799, 0.020204684171344967, 0.023054996648082332, 0.03482536878436804, 0.013490915598888552, 0.06558975144740074, 0.060160053488347805, 0.02953671527305438, 0.04871724714194575, 0.02316577104671348, 0.03769377051221748, 0.036907611084320856, 0.03972900565713644, 0.049605311585530165, 0.08509076470809598, 0.07207148347891147, 0.02848225461709644, 0.01108481920504522, 0.04933192927931105, 0.005182653755670594, 0.02403417958938066, 0.023196952740451502, 0.06497217732812129, 0.03524541862369065, 0.049712410677344575, 0.08800530791162484, 0.07944357821777945, 0.02692136962357308, 0.015186826461896062, 0.012180409206437969, 0.00991491580216755, 0.03406507631523475, 0.01601919439816547, 0.11226319858143408, 0.06559437095758415, 0.047794953889904485, 0.03659200584215503, 0.04818456705599543, 0.021326361381779277, 0.006544327639388822, 0.08543666872766711, 0.021984672226432352, 0.026469580761547533, 0.049502077407293746, 0.04211202939792026, 0.05960565097930451, 0.026463806373818267, 0.07379400919401839, 0.05162961848620927, 0.05080282958524843, 0.06955852356529044, 0.06770672817384044, 0.08879033352939353, 0.033684905182810566, 0.014665161762686988, 0.07739822305138074, 0.05132948438967428, 0.027973200682730927, 0.05039021079879134, 0.030903657447666894, 0.09047860745340587, 0.02023632551783756, 0.06924824263419836, 0.00045705688359204595, 0.07504146080464125, 0.02637812135470731, 0.0161612146503983, 0.09533198129746223, 0.02812679173545011, 0.03385968048185591, 0.018439161771487807, 0.02575883311369727, 0.07064424635421845, 0.02909179821970963, 0.013530676519768614, 0.05220721813759977, 0.011415790255752303, 0.046801517882774916, 0.020385230027679956, 0.027156401568302707, 0.03139115749828277, 0.029906613166413964, 0.0187027515588148, 0.061099713953632506, 0.04253222096350886, 0.0969200202774617, 0.10142657079643781, 0.03830092966616635, 0.010036475761162659, 0.03250901001475511, 0.045222652805668694, 0.013374024945791933, 0.0072056884715904395, 0.07325596266215847, 0.0458802894929484, 0.04660094457287942, 0.029948520091091915, 0.02099164224590265, 0.02365661315589903, 0.014120275980883069, 0.0625057036297456, 0.0537810729996812, 0.1246453015013568, 0.00818512565831864, 0.09460903944507723, 0.0860865870791097, 0.031638130838532126, 0.060385716177763483, 0.01757599518544251, 0.01608789812082485, 0.027342700744949044, 0.021949524112466364, 0.03997265226057461, 0.02072983552821942, 0.0017692672530932713, 0.15027378475473774, 0.018948924337183277, 0.08075131328716394, 0.027859727739386504, 0.05201338257099833, 0.07806747746203216, 0.040848470788689396, 0.06906696324867588, 0.03020706327421771, 0.03183450024094313, 0.049466661162554264, 0.040589808861935334, 0.023559341056933327, 0.057166224015095544, 0.01553371107401026, 0.03678378063224016, 0.02219804495032276, 0.021674883506831624, 0.04026176235187919, 0.02677462165123753, 0.02909458677975401, 0.02923700827053718, 0.03626605075213217, 0.05651971475491601, 0.09454553841703361, 0.02762785207690491, 0.05087704818335272, 0.010775861690842338, 0.03468945712572144, 0.04398116135909673, 0.01627578884513388, 0.004142904860688554, 0.03264766426817064, 0.012881542450838513, 0.024710886120315523, 0.046926420857949604, 0.012880744761787357, 0.04100804307287739, 0.011049820478224467, 0.0130678684405622, 0.038466799193091934, 0.010386487927227732, 0.04744774369042247, 0.0459262126335694, 0.021095447159642657, 0.014972966314563829, 0.016228368002620917, 0.031419793864892374, 0.022573868533776655, 0.026809009422938672, 0.061509138153445345, 0.053198704450962045, 0.036485086781002825, 0.02469052924894758, 0.05555935842435687, 0.054510009490073695, 0.03059852654264579, 0.02336284716523463, 0.05594390008838908, 0.03548471001727927, 0.029610430168348457, 0.12646043192475073, 0.029304787899637898, 0.021365175226462946, 0.02973012757607766, 0.036317095190526984, 0.06641041547540696, 0.0911829257083516, 0.052715138261837345, 0.05039973710212977, 0.026392184813777288, 0.05489188133768978, 0.07089134035331589, 0.024854066038143732, 0.03970820253955261, 0.08486975600282032, 0.07129244866871065, 0.05440569129742442, 0.024244472639815464, 0.01873410945277541, 0.02965517353356606, 0.017382399021317402, 0.06441327788296246, 0.051370650124285495, 0.11886535963464169, 0.016119112373299656, 0.048241724876025995, 0.06554750935925592, 0.012203348751720643, 0.05357637430631346, 0.01941952065774991, 0.04602916718971345, 0.03720050564997139, 0.031314035426945455, 0.06838646266729602, 0.057763504465260816, 0.03143211447393462, 0.0636172857165577, 0.06102291363922339, 0.010476951419766392, 0.02235485740276354, 0.024341472777568048, 0.07797618276409565, 0.057412379556485725, 0.056622845511282646, 0.045697937584331924, 0.07097950175164208, 0.013569164777084464, 0.08161454116024318, 0.046169571954035954, 0.004023732223187484, 0.043807450922266136, 0.015263393119488274, 0.07191605956083344, 0.029674526829753193, 0.014539135511093324, 0.03234627378743983, 0.036272685073556445, 0.009396971417440763, 0.02426997953725438, 0.05854569938814929, 0.03699829291191794, 0.0273170099864083, 0.03253629806661799, 0.050301612730348305, 0.048491595943848935, 0.06059056042783684, 0.037781338192402356, 0.10427802665940217, 0.04207598879152248, 0.02641649661405433, 0.025437476466439908, 0.023785459568663955, 0.08088214578287256, 0.0731537741939387, 0.0496283516798529, 0.026974804256291642, 0.0193993131735272, 0.02877247936633085, 0.04139689015104406, 0.01631331566210476, 0.007366667963534354, 0.04912896577509181, 0.04745317908424524, 0.050332340516991196, 0.017404245933698072, 0.021854720731836655, 0.019177511567249894, 0.07565130509676472, 0.046927202267632376, 0.006639438412798148, 0.010879305585648024, 0.008417104742670012, 0.06844045654419931, 0.06156048136613062, 0.0603832493746473, 0.09749247947888029, 0.05447732817922389, 0.08657040990768902, 0.03347280224965465, 0.04755766198579823, 0.043538883478651126, 0.02847646490760869, 0.12850655317907372, 0.02862754319193623, 0.026848014789603414, 0.1242182917532421, 0.07249808720042629, 0.013163300013289818, 0.05353878620230863, 0.02296949740529301, 0.07651408863884789, 0.07887907866989413, 0.003517585113689664, 0.025652017474414843, 0.04057082903361128, 0.11614492012848777, 0.04689559347987656, 0.044002730564604846, 0.06900622013715968, 0.03780555423168886, 0.025208473633674365, 0.021909237463748264, 0.020722203377273776, 0.05007481240036507, 0.016647745599789966, 0.07811560310543546, 0.060409725373310436, 0.029848809917307192, 0.03732969871752205, 0.058802047729372024, 0.0821567781930489, 0.01464061055993361, 0.01656325184740126, 0.08209132364079838, 0.0074343053875641244, 0.017132669679760452, 0.04734542498725557, 0.033866556120976325, 0.06243824575757308, 0.1011930978406341, 0.09071486896925396, 0.04703070457664229, 0.060951502753361586, 0.025670407415037195, 0.051207668748834444, 0.05228316809441294, 0.08009022537378535, 0.024007144346532804, 0.027357863540190364, 0.01352313725698379, 0.04515466633282843, 0.045698561945990215, 0.01215653599149758, 0.033006534325860204, 0.04727774111914539, 0.03309853382468705, 0.033552467732900576, 0.09637097272300914, 0.028496371702321117, 0.13337531006864964, 0.18943338024039424, 0.1496601176838721, 0.177299129746614, 0.1556872531411148, 0.10996903337898756, 0.10981639036007466, 0.12035562281286526, 0.20101479104449674, 0.18280647454723237, 0.2062641940410099, 0.0880631092455118, 0.13708432475405355, 0.29782538332285424, 0.2050135708263805, 0.11096243491216053, 0.1467359141116181, 0.20395601709042827, 0.0962716724062639, 0.12047053600150733, 0.16487693744561366, 0.10942323403733392, 0.08555279999610879, 0.3227070917285258, 0.14274415169512072, 0.15235110877021668, 0.14262640398115883, 0.1453996882323296, 0.1321958717439444, 0.2224401252404336, 0.09362051789198192, 0.23159916602796127, 0.23850125050352466, 0.10220792685304919, 0.07469090663136975, 0.13562348701300161, 0.21049872972071174, 0.09479778818786146, 0.1394761585059666, 0.16925641696058935, 0.21526234104268013, 0.1391715466255142, 0.17861303182378893, 0.16738058939095468, 0.07727020975923346, 0.14226438147166084, 0.12131858767280657, 0.13623327767897037, 0.1205588199739014, 0.24102186363550926, 0.23272264929067707, 0.20860466925847918, 0.17407521725662295, 0.10249750042754797, 0.11018516210418557, 0.12475693583368294, 0.05838581300791233, 0.11863360271578836, 0.15394087910892504, 0.11628019593415723, 0.15844622686986, 0.14920840160019938, 0.15660968428898245, 0.09484265029670731, 0.22140271961688998, 0.1161138552631582, 0.10171030678095357, 0.1731397166487671, 0.21177074211018704, 0.20575476089312186, 0.10084592977598791, 0.07318769656722585, 0.1615175040018174, 0.1403364599231751, 0.061594488009089426, 0.1459298210759317, 0.10198913980275394, 0.22918551409196472, 0.06848285951080822, 0.18688020837162772, 0.09778862608776939, 0.13700822157965553, 0.11341960830313545, 0.17006093185515175, 0.2125184132807678, 0.07767737783010929, 0.1218225969181907, 0.10877049648232999, 0.1405916438107529, 0.18295477384761458, 0.14084950900606572, 0.15340143063616368, 0.12349027839879836, 0.12195990285685948, 0.1267496990640798, 0.14472399868311422, 0.1094718193334918, 0.10972544806258333, 0.09504090619063187, 0.1264042087319878, 0.19325695571399507, 0.08588533578140121, 0.11246899278053354, 0.1910791209628505, 0.20358565954431412, 0.21832830152444302, 0.06081948282137033, 0.18601699582030698, 0.14698680790681995, 0.15276134885366888, 0.1873607446830119, 0.19018721075788622, 0.15725635442762606, 0.11724748919087073, 0.20829900017669126, 0.10505315442118915, 0.18808929429900265, 0.18615987121818528, 0.12621939002025512, 0.22669692343521505, 0.09085890882077718, 0.2087737142198509, 0.24707595006592814, 0.1572002155045348, 0.16867322486735162, 0.09487347001390112, 0.13149041201799147, 0.17044103403966274, 0.2499079166520988, 0.07742880528131801, 0.08223338698547694, 0.11054004467422925, 0.1935489731089723, 0.16642592126323333, 0.1736875920886955, 0.13672095392980885, 0.11382873755909743, 0.2076554403550202, 0.19639145042146408, 0.12638983692252828, 0.16553459328509149, 0.13608736857291193, 0.3237492470972, 0.14376390665288896, 0.12201152952207674, 0.10207329456123615, 0.22071166234391354, 0.09696790077272924, 0.10676831803134373, 0.15928365290164948, 0.180569359912507, 0.08038985002185069, 0.09104729750223699, 0.08330855308280838, 0.14282537233685294, 0.17306114667125289, 0.1522125541082313, 0.17228266344435755, 0.11944499707991078, 0.13688197028973412, 0.13084093799754498, 0.17179526298517184, 0.10986939598355563, 0.10182468370804865, 0.09259296415914452, 0.09532059723090741, 0.12187696617817688, 0.1888041769064242, 0.07906121607389181, 0.11641305090198595, 0.09627658302985853, 0.13195277672381173, 0.20470721226546074, 0.1664855535472593, 0.15455319786504393, 0.14513842160663298], [0.029305879574929996, 0.08809721547990076, 0.012400823235962422, 0.04247022912867608, 0.02709211721535652, 0.06169194588437677, 0.04707616806450871, 0.07380261236140806, 0.03647421599335728, 0.035829970522994, 0.021559707933075486, 0.03170621498758274, 0.016739630185428168, 0.0843488008925511, 0.08173436497247989, 0.05347339676753168, 0.017308408334370584, 0.01594910309875324, 0.09833592696175461, 0.0106770622040776, 0.0574286244509201, 0.05532628000383416, 0.04134527497714566, 0.0018590312115960726, 0.023796993022363995, 0.02363997564140347, 0.0431747235838444, 0.06178460038837887, 0.03853421876086824, 0.048317663341520295, 0.030873291637568228, 0.03474650003256337, 0.0671005227993573, 0.14927152724516007, 0.05634514629961022, 0.06234829171350407, 0.05821041717764832, 0.05204941551651686, 0.039877431362026164, 0.022504225395800128, 0.006549724250010425, 0.07361450713248023, 0.015205577421452732, 0.05403351046205048, 0.06789939162591774, 0.07433926461324578, 0.01216127711813897, 0.0411841896693072, 0.01810006252790411, 0.028286149515019312, 0.04358973256462524, 0.04086971057639007, 0.05417881818908838, 0.09136876331702357, 0.014524098162749603, 0.04040882825070331, 0.06360449970910145, 0.02590881972273271, 0.05710785577614462, 0.0270234240264061, 0.028243148999829448, 0.018310313443503073, 0.021633330897818652, 0.028802757076318228, 0.038311980484474095, 0.05917081181260367, 0.04813567915510747, 0.027767249435606985, 0.08689546101396123, 0.01767350860210436, 0.032207738277652574, 0.016561823093422478, 0.06166250512544667, 0.04036022763278696, 0.051909719383524316, 0.059296683889002576, 0.05856997288403012, 0.032033347937789176, 0.022555530304089192, 0.009471000408783797, 0.04748351616604675, 0.04576547206529687, 0.012475523511849105, 0.09622018363687301, 0.040537699561325774, 0.06223612111963092, 0.03946008964351589, 0.07516680811081203, 0.017869064036095818, 0.0747320608746621, 0.01586361343206297, 0.024495435382930503, 0.027900297840636586, 0.03542143881561295, 0.029574065889802673, 0.005788438260600332, 0.09939374882848033, 0.08853003217448151, 0.0680315571146146, 0.08249001877923166, 0.07250010967254639, 0.049227971147986195, 0.018627450861517462, 0.015514827964286652, 0.0459826426700719, 0.031813088083459486, 0.021240279912167502, 0.031067523654670488, 0.014235011054082744, 0.03954665374851996, 0.04991571509069012, 0.06485888824587868, 0.028324373472001285, 0.04776152947376813, 0.009108075830754975, 0.012698850590705633, 0.02673467399642593, 0.017537355625761614, 0.041899010989694827, 0.0834319775082892, 0.012778882838545308, 0.03733570101640878, 0.06345756021478484, 0.11562553549846334, 0.014127579671631177, 0.03706983020228725, 0.014298944921803572, 0.009529701895981787, 0.09553262738571053, 0.05677441217666192, 0.03190402272007158, 0.01802677664184763, 0.015634264902121598, 0.044074352124645826, 0.059262818972309755, 0.016386944372507355, 0.04763563824517112, 0.04058586350912529, 0.09825009447071822, 0.01926081022247672, 0.03835837859960814, 0.04964119514390346, 0.010746563615788136, 0.016238443974045016, 0.02816435111115777, 0.02845425984912342, 0.08909637033338509, 0.06604951145427843, 0.0448782733010669, 0.030431398716304573, 0.03942271987456949, 0.041822076609898964, 0.08500390565924107, 0.05173331997807949, 0.03366109900056355, 0.002514594553729459, 0.055369456719246604, 0.04667660341628137, 0.041423270388716654, 0.0866970289198141, 0.08464726874785078, 0.036312100297260674, 0.012533627450466158, 0.023809671777510838, 0.01806849587498413, 0.010240158430420825, 0.0149561018465207, 0.022189911011786714, 0.039322220630222754, 0.020548293757582867, 0.049987658407659306, 0.033656958295332814, 0.03556058336530001, 0.043671903155383565, 0.05063163574724909, 0.051499797226560694, 0.035285105808608, 0.07550739548018864, 0.029999729238390446, 0.01820334267141598, 0.046340930500939015, 0.02798126567335379, 0.045128420160542575, 0.05429380032564363, 0.01832231804127655, 0.036736777307645935, 0.05095372975413358, 0.027096842062629523, 0.02334346131031071, 0.05888762358095377, 0.0439593929707283, 0.03272128148725437, 0.034146676170489484, 0.03638369121378468, 0.025582052579510118, 0.021387730770173575, 0.023156970611683304, 0.05016393140859662, 0.060707748897614024, 0.026579286467524308, 0.010275632131754631, 0.07341589117723127, 0.06637265500161918, 0.0690569274968678, 0.009975975882562419, 0.07052931018293866, 0.039252184872185035, 0.027635748528184432, 0.05352280943864777, 0.07399248725344097, 0.05121617615523358, 0.05764415945797678, 0.03203130056781154, 0.07247472917961498, 0.04400846856315771, 0.021597286460981257, 0.05750293881001492, 0.04925527835204717, 0.03172059637314129, 0.038914960628796014, 0.052141265628198465, 0.040694222815575144, 0.05420829342197507, 0.06380527603229688, 0.020597861561503623, 0.06067863755649137, 0.0077421415405678415, 0.0341920132538484, 0.04894352653214047, 0.07692645078585034, 0.03400293892369636, 0.011687808925466192, 0.03318456932902336, 0.059568652763001384, 0.04000606135495248, 0.04778633157031671, 0.07041662631015624, 0.03133305164444591, 0.033965400615406614, 0.04785969214994581, 0.022595579465550762, 0.03170197086048222, 0.026170523018546166, 0.05996606087372188, 0.05316183646960605, 0.011384730178472257, 0.014361069864413191, 0.04176863431630116, 0.047645267970379324, 0.06333629998769011, 0.06439600260026994, 0.07190161114258152, 0.0240485399075213, 0.042515290420382254, 0.03172651440235636, 0.06712476948216077, 0.05454117394683342, 0.03417657275173453, 0.019070111785925204, 0.06077991438008124, 0.011842246505341703, 0.0695787942517669, 0.05536875957923551, 0.006823059154539219, 0.06903703219347423, 0.07360650917455074, 0.09703307953332702, 0.033645149049980026, 0.02943882455808982, 0.05446837261138905, 0.05267579964692554, 0.02143866412581936, 0.05109708395696456, 0.009025061585670038, 0.0524894449289047, 0.011338148202236381, 0.044382177743940585, 0.009735462578734564, 0.018418667004293492, 0.02398964881356205, 0.06733172813490515, 0.027381441811279907, 0.054215215026370944, 0.03913253342973129, 0.05401755285058772, 0.07513785764815346, 0.05791419779040641, 0.0391131705574451, 0.04921360699940593, 0.04162311591508408, 0.06105457222269428, 0.049805114977061755, 0.05044299042633465, 0.013056096541995724, 0.047955192670586615, 0.024638176715422063, 0.04953706847323526, 0.10944331320182932, 0.03425201326007805, 0.04257552408342881, 0.025375544003421263, 0.008802125211654892, 0.055540838248787396, 0.03208153678344623, 0.03932463380718424, 0.06250492605050245, 0.009532198385005037, 0.11821601584914232, 0.0548392127928955, 0.10383040914612432, 0.021746639132259354, 0.027399873886738094, 0.04321259130994159, 0.05999026925212914, 0.10073756663909844, 0.05106236485223617, 0.018534024523931648, 0.03625429130249447, 0.01564406603950286, 0.018080803077487696, 0.03033063134118434, 0.030647268886828137, 0.011380920806268771, 0.05244204706902947, 0.0906675553790504, 0.07809321801628798, 0.02718438101451724, 0.05422731155469533, 0.013354352765506314, 0.04160530437084456, 0.05099839651055875, 0.014701720436043559, 0.034185252527916626, 0.049114352647936156, 0.04092675731367162, 0.009804915152339926, 0.025679204019627748, 0.014320212480191503, 0.040048755434972626, 0.05241997990637057, 0.02976296210451232, 0.026902857108882842, 0.03670525662000141, 0.024890566297296076, 0.03495636598898038, 0.008997200883083768, 0.03949803780884512, 0.04026375801092194, 0.06100918151318066, 0.027103715786530126, 0.06686733329608556, 0.04771341149124408, 0.15999393898152536, 0.20540026136704032, 0.08090832300724522, 0.09784324049589135, 0.10776803212901277, 0.13275802706278142, 0.15170764087909652, 0.1998140554754965, 0.09918353430205777, 0.1533844847712786, 0.26278078315719483, 0.15507585369050503, 0.13566572910114644, 0.15791010321869006, 0.26246763705726595, 0.11145794058158515, 0.1971640960583764, 0.10029535770656602, 0.29901358569341324, 0.09183780064866429, 0.11839802301819287, 0.1463508936426332, 0.11623467498969649, 0.1699325814843178, 0.08457390050734244, 0.1950901121862473, 0.11869839077154476, 0.18415624486102214, 0.1043664102232264, 0.11226638550719908, 0.25929903611540794, 0.1226910112065173, 0.10024286536199432, 0.26093533863463714, 0.21631920529950052, 0.1977627784494431, 0.17663836359016358, 0.2611936634827045, 0.20731394900189293, 0.17064141199713753, 0.1321588084101677, 0.15871507776600702, 0.11486930712576836, 0.110835233673213, 0.13575888539273895, 0.20569351982445488, 0.11632775467249656, 0.16247379623593824, 0.06985869979666126, 0.13339449291027364, 0.1107302643058281, 0.16347645211123651, 0.2049083869543768, 0.17429007427586665, 0.09828319712992638, 0.17191907811549403, 0.1561891633055864, 0.18494448804807279, 0.1850216790673233, 0.1581630348077705, 0.13138087676657786, 0.13306239379509804, 0.1019915683014739, 0.07480686936046808, 0.16007008812119886, 0.20799532292350648, 0.11195582878445426, 0.12713519450757774, 0.2714092314483658, 0.17411365954866334, 0.10066789094238512, 0.17849470188300456, 0.18149533038658483, 0.131634681695892, 0.19636826860087533, 0.15106348350884455, 0.12025463710268659, 0.09470551289738187, 0.12784287588851106, 0.22643965578848319, 0.17016547221329906, 0.0910192357015706, 0.0757760625152338, 0.15274811085433732, 0.09681885070618122, 0.1443307044645471, 0.1261731412922663, 0.15596008769446806, 0.18495484555680908, 0.1292573729710233, 0.1574889693649546, 0.11466172794180532, 0.0770857511088252, 0.17065979810732027, 0.18037195437617842, 0.10130713002816324, 0.18075919650014372, 0.12471718353129203, 0.15204341721630868, 0.1788512392029647, 0.1843495135225596, 0.12176383797439838, 0.13485310899634517, 0.10390852713176321, 0.14805527073481392, 0.16565790279738365, 0.11365026971625705, 0.22103029363338025, 0.10683846870257009, 0.10479834591669422, 0.10474133365336927, 0.11083193949513859, 0.12700314393206952, 0.2187347111682738, 0.13115615253486942, 0.1379056016523992, 0.10927416864902743, 0.18355935511569824, 0.20327216104394008, 0.16347441431735793, 0.06958683817497185, 0.1755966525524855, 0.14101165917611894, 0.17863569270458915, 0.16094204939661488, 0.1145745624577807, 0.11002829794080989, 0.15487984243419864, 0.23185903837363567, 0.3209648852146441, 0.14501932557792435, 0.13682603054950315, 0.13927086226401791, 0.2068841736763716, 0.10041101400049464, 0.10668197226139808, 0.13762349743516217, 0.13042786338877294, 0.18768732796513266, 0.13927604101838606, 0.10147730113878366, 0.14196249686421888, 0.14963705843735128, 0.15495291190041652, 0.13232146419825094, 0.17629460461678045, 0.16412707526356946, 0.15659911227562737, 0.20909986849273407, 0.11417228968874102, 0.15633128793729892, 0.13772892645530163, 0.18090312909935752, 0.13049622907513572, 0.14649315617017208, 0.07663961980612048, 0.1530416604251631, 0.1885413014960866, 0.11141670206862112, 0.18781236883613373, 0.2078949960489427, 0.10455600932360658, 0.1580865945546858, 0.12625852945230662, 0.08961383974359882, 0.14270410061843936, 0.14145454992690396, 0.09271749175123631, 0.12114806416174098, 0.11263017767980216, 0.0988715373340153, 0.1724004724453534, 0.17285517627193084, 0.08740500141415866, 0.24965716075272332, 0.1259615937728555], [0.00640548569443185, 0.08227833336399448, 0.10823349949092635, 0.034664674181370966, 0.03165114667236565, 0.03115344041537854, 0.034699389455659736, 0.012443903232774427, 0.043138008820073265, 0.04052602821179936, 0.03652454413954289, 0.02590245736252156, 0.05790919906670048, 0.04050648147841135, 0.012468801090313543, 0.031076823962071252, 0.02495451931721501, 0.06307634337234401, 0.047362933926765, 0.01997662362672629, 0.02480893579852437, 0.014577206250490441, 0.006358610689564939, 0.03525911244533716, 0.06511247867057401, 0.015287560320669606, 0.015705491926881577, 0.04071150958958653, 0.04059619420478421, 0.015367623212026253, 0.10369876459721597, 0.061907787326603174, 0.021642581409504338, 0.034132725709388335, 0.13783260879497375, 0.007561134595063425, 0.08195279196145074, 0.049971053451900525, 0.10959957215574481, 0.040040083319669774, 0.019351137734408823, 0.03031541491978832, 0.022751769471553066, 0.026303814656491724, 0.05464230521371769, 0.03418586539825605, 0.032828380579068776, 0.010911984981278018, 0.03948519817523418, 0.043547973111872716, 0.07720531445116767, 0.011213416639234752, 0.03298857722491507, 0.07140011466558903, 0.0070769818698716985, 0.010136699213856652, 0.04718323651280615, 0.011849737887631261, 0.04564655989769005, 0.025292714577048056, 0.09332291571603668, 0.014745224654043635, 0.03219633888933928, 0.011424549513556545, 0.06423269563745107, 0.061210586028474, 0.03505365532492438, 0.012694519321103732, 0.04390368305687462, 0.028130662394687537, 0.04389797570183874, 0.010648633638817457, 0.04948355723172427, 0.016827492809463895, 0.07384876915884596, 0.03853935154996092, 0.07713677256458229, 0.03418774997454978, 0.03537301056747956, 0.07179765301125665, 0.05272009102026782, 0.013269318921130993, 0.026604465862375595, 0.03142757348776345, 0.049723078451690175, 0.056677218601708455, 0.027118646840174353, 0.09419651641961067, 0.0023412039586072487, 0.03873497210142594, 0.023084333985142654, 0.02361889098650746, 0.041272868176982294, 0.03864262020215392, 0.021116907197621562, 0.11701094422249064, 0.017249178246504838, 0.026420275342740843, 0.03407195195435517, 0.054420725772938425, 0.025359459987450993, 0.004546059109646106, 0.04421131332374869, 0.061843631293384306, 0.04716393109711428, 0.023154316117025675, 0.056295388888928204, 0.025215856806044618, 0.0585207517348951, 0.06459214409152347, 0.023330056686855616, 0.04463901638143486, 0.028873499550466097, 0.04698663919923767, 0.05684415682128841, 0.04078180198707888, 0.025160125824773026, 0.05254096434181256, 0.03031448603818013, 0.02210765615135672, 0.019305940462096084, 0.07981136170846802, 0.0330805384193457, 0.021737898069043315, 0.0130745085076459, 0.049618944120142734, 0.05328014725819231, 0.007638194421756893, 0.04351824890041063, 0.010237667687057007, 0.08409883406373762, 0.028405561554996718, 0.016961364759012096, 0.028489706737379876, 0.04907396066212847, 0.04211669870381875, 0.04634415190066061, 0.12510774281596945, 0.014765885087751575, 0.043175677363310135, 0.01407910354300252, 0.05471555088015814, 0.10231265107229834, 0.026831496018736113, 0.022436568340767297, 0.051947931849187425, 0.0529735129056198, 0.032207293946656494, 0.04799911249128561, 0.0538943812341219, 0.04982906288557476, 0.06166184628983179, 0.010062329313387314, 0.06378701632662166, 0.008340557237275907, 0.040782893662370985, 0.04808681040641762, 0.0854235839459204, 0.023254861326647863, 0.08581595119809912, 0.031977919561247674, 0.032500494947476734, 0.013837834684959343, 0.036309970572831175, 0.06298689494630502, 0.05191850258157619, 0.031638466001998995, 0.046312206034218116, 0.020103506939185244, 0.0546072643520611, 0.03834808237790581, 0.11031168152488048, 0.07958181112283662, 0.010771690342094629, 0.011385254948700388, 0.028961118941585866, 0.02368537784223595, 0.04354844042550653, 0.07451707362047127, 0.07860337894770407, 0.028252633168332042, 0.010374078260464294, 0.018960074746921178, 0.043779358478082765, 0.0018821803537467797, 0.09234632981280166, 0.021722331162421935, 0.061589458641866525, 0.06200474724473973, 0.05146077653813747, 0.030176643837964347, 0.031038571276792118, 0.05494415151676344, 0.026205611760698022, 0.053138654649017326, 0.019182370479909644, 0.04510903430561866, 0.02158585451393118, 0.030913076498695923, 0.055059646932227965, 0.09006159515270303, 0.051640918283092405, 0.038927087800637375, 0.003642050700540084, 0.0777665428036163, 0.031142326394817045, 0.042023098081230156, 0.06748774194068487, 0.01286668704837681, 0.05167562589650193, 0.12778784013203076, 0.019597050042883046, 0.048165491466680845, 0.015014091829559015, 0.08700266735808504, 0.04659518742212846, 0.052122910161532705, 0.03578250371520558, 0.01010506169780368, 0.03068300688849582, 0.016828716634922934, 0.020379191339616815, 0.033756285425155394, 0.020613608498787208, 0.024787420219170953, 0.028563816167954958, 0.047124301368791255, 0.028436557472413106, 0.037703626233363347, 0.05508903023456374, 0.05214719131829278, 0.007230031872994357, 0.02578891355604414, 0.03435899743870382, 0.0682221827728133, 0.014057450067822733, 0.06336256148173444, 0.04504376744490959, 0.015951085351257315, 0.05638685595664767, 0.027790946450324792, 0.04418930744812374, 0.004616567448172118, 0.0286912338267411, 0.023583940140181975, 0.03209912999262733, 0.035853037430394086, 0.06079490672075941, 0.047291515380023956, 0.026573820430184567, 0.011171979901020326, 0.03232572730931063, 0.0813888056924747, 0.030859569087624553, 0.05852076705665358, 0.04663423492362903, 0.062332123427862124, 0.03905875150174384, 0.01441602518166145, 0.023089656380996592, 0.028588315659773447, 0.02942771436796794, 0.04318054202162931, 0.051928212746016444, 0.08494636479524836, 0.048336443986984036, 0.017943931893715938, 0.03232558175260502, 0.04440326814449603, 0.05628130819287993, 0.024956229608505968, 0.05207586087166302, 0.027353395332371997, 0.10952867837923189, 0.03829231500745781, 0.0004265699657656613, 0.018132669145181295, 0.03429218308038769, 0.019333140413847663, 0.11486717740133887, 0.041587887361886046, 0.0170491335372771, 0.04874264295663565, 0.06536895724674387, 0.020054153639883287, 0.017330479327469103, 0.008629079356098609, 0.049120898869249134, 0.023259714493648182, 0.025650460400708744, 0.09884005878120662, 0.018992108713474967, 0.025195714439295476, 0.070405701896356, 0.029047081667569377, 0.029144669777803847, 0.028024597521570903, 0.0820229426326771, 0.08126253141991555, 0.005941909612081344, 0.02874351549713362, 0.004359070453867918, 0.037241334305895914, 0.013081371697837548, 0.008906241348614136, 0.06896576303387843, 0.018048301797300097, 0.1223486694957941, 0.019986082897371343, 0.012445110778865075, 0.0725120300006482, 0.030182109875304085, 0.030931763298388933, 0.0869930682763938, 0.006302448305030984, 0.08463956956421176, 0.0349696308013893, 0.02319462766360131, 0.09866000513636297, 0.03581435765109716, 0.07888175231674988, 0.02769944107820911, 0.059582564919706316, 0.023147566882412762, 0.046497691242444905, 0.046286917471837614, 0.06803498152763614, 0.028423574197316365, 0.01842054200448817, 0.02863819947496297, 0.04777672865818586, 0.015255047549163143, 0.08157801408801349, 0.0572390215201003, 0.08600956459920253, 0.010939898352409083, 0.009591650638368823, 0.01715873965182372, 0.049929512334206415, 0.08130673469314653, 0.05491384124803928, 0.09241185331296536, 0.01751855582809977, 0.02269277687094385, 0.04528252640739084, 0.03783224856541042, 0.03056892107481197, 0.05882427960093464, 0.029667733545084635, 0.034056936631039265, 0.04898730079613386, 0.03836482522949096, 0.08701525418268097, 0.24545195091876293, 0.21709482335755903, 0.1600680043620448, 0.1275531414355482, 0.1185570628712735, 0.11005141081348543, 0.13420075448530336, 0.12151797737685904, 0.22683894081461817, 0.1268082741467703, 0.12857299598474659, 0.16060159992306464, 0.10778131609361981, 0.11188196258679514, 0.09793202242543621, 0.13998271116325933, 0.15298929065465927, 0.12863966095591747, 0.18042829248213, 0.10396910170393606, 0.0951028214166722, 0.0953715650605098, 0.12434486480009173, 0.13942011151342623, 0.1086457007594647, 0.09108457534063248, 0.10679123172115897, 0.2351260969355222, 0.12567443337531822, 0.13548577504773296, 0.14905791128835372, 0.1107292990350435, 0.17405042665139323, 0.284584840579379, 0.13034131077508773, 0.15741619101214796, 0.24536051066412082, 0.13470600479312483, 0.14046268056957953, 0.16765635040017868, 0.10340000562850507, 0.08838380897237409, 0.18905366109984537, 0.08992379125688346, 0.16198644174202798, 0.09475589083928256, 0.14282912616768192, 0.11211709795339454, 0.09152268570277, 0.16185357145244078, 0.10730092533894124, 0.15946690113313738, 0.22520182624218926, 0.12929267430257413, 0.17492462490354815, 0.16292450108355092, 0.09795435388842899, 0.131129446709829, 0.20423735521974104, 0.21604934316729346, 0.12334307460414788, 0.13565812950893757, 0.1413892179487213, 0.17735614200993893, 0.17290203020937983, 0.15710100711834046, 0.10765299636630282, 0.12370694338554337, 0.06803156477549384, 0.09089636285939524, 0.18356082600451287, 0.11565339045539019, 0.15292130801225864, 0.11788741009490145, 0.17382922642413648, 0.15421748281486575, 0.1284326486770184, 0.14058975923445918, 0.10491758750210847, 0.16694044123493856, 0.11226240184999282, 0.06807239726185799, 0.097113472800101, 0.1352686044429579, 0.12493159621953966, 0.10455595569745188, 0.215522795615177, 0.21788914928272848, 0.10879410731215632, 0.07703448450493236, 0.17696683144857808, 0.15039165504276752, 0.20306303436237, 0.12888038110348488, 0.19918882047697423, 0.11964109260588886, 0.20449351969986193, 0.10521704361083047, 0.17682522775665407, 0.11043001146566485, 0.19854100120644416, 0.13570499876814504, 0.17231928244713815, 0.17175798514677634, 0.062454839222012996, 0.13667400806180893, 0.08408026409245307, 0.16304234072806376, 0.19135403927535782, 0.17655570270313373, 0.10799761335816115, 0.15946729949885802, 0.16821078355273894, 0.1563206699586684, 0.12843320026032387, 0.07977780705738453, 0.15704463836887192, 0.2302001975476742, 0.11669089567036399, 0.10241251829410754, 0.2220787922100675, 0.12684309284292883, 0.07803464293359749, 0.1678712993499733, 0.09839853932780605, 0.1119137245921358, 0.13450813960404168, 0.19206956539663578, 0.1844865513304549, 0.09697075061980756, 0.2548215586331583, 0.09919972173989781, 0.21786969064945177, 0.157018989745167, 0.16305732540786266, 0.13178641307017497, 0.2617040925448941, 0.06756225931307963, 0.20103834058728912, 0.14447586280443978, 0.10873086675400696, 0.208849189202151, 0.11202565003787318, 0.1181242002114173, 0.1564980346348978, 0.21623511948893148, 0.11669385276975171, 0.1313078992309109, 0.1727612079271386, 0.2548260325866361, 0.16448119174568884, 0.07562586331679937, 0.26003359186072506, 0.16597026748762977, 0.12123900645923232, 0.18660217974214785, 0.1735431998367271, 0.11963711660956183, 0.1448993715307405, 0.15724149232189502, 0.1990731105568909, 0.09659322249072214, 0.17202862868866614, 0.1697314680824357, 0.19921224744569874, 0.11288184522380752, 0.18399505996175353, 0.1945637331734742, 0.1671415393150622, 0.1110345544293523, 0.15467232453726953, 0.17422405281855216, 0.11905074525143831, 0.12482153236745827, 0.1740573827297457], [0.052587814448821935, 0.018925786566650196, 0.06894400613682886, 0.05427108964912834, 0.11797974667241497, 0.07475525801700932, 0.03021140124708895, 0.008307778250215756, 0.1156089190513857, 0.05639112689682553, 0.014468839283161348, 0.06616289246707194, 0.02552928252806587, 0.016350200880439054, 0.061838035021097436, 0.04358673333040169, 0.027850199520828265, 0.020296702822369915, 0.03136481364978658, 0.016660190698119904, 0.03139829935295688, 0.054491680836485284, 0.027766839578567494, 0.014029861326449582, 0.04005735094148306, 0.030571845615462914, 0.09159017038801986, 0.012571145648947887, 0.06301507932103931, 0.030630481985187342, 0.028561546632479277, 0.08964513443530568, 0.062031468391538634, 0.025521468431238207, 0.028368017501047546, 0.04043086093940562, 0.03909309522338933, 0.052333354514332554, 0.055679496332642534, 0.01949471984839728, 0.01997192750775045, 0.017010618466883898, 0.010244527046809034, 0.014831082042937559, 0.0389295086384781, 0.014681278337394039, 0.008458648733193836, 0.06284000524770349, 0.01821170069066988, 0.017618999531071995, 0.045850687855554205, 0.05717966119728743, 0.019181636950722145, 0.04290632467957274, 0.05758549244473538, 0.022175905009311055, 0.09613959118723871, 0.031764769002855305, 0.010317415524754795, 0.007438919152088104, 0.059711631582749475, 0.07356900917065722, 0.0536184938203904, 0.01866322716758136, 0.04071500295052125, 0.10683880578125678, 0.010475637578976252, 0.01760398995341553, 0.02956962832550128, 0.048371381426770846, 0.019079320162775058, 0.024354358376454444, 0.00837165274612245, 0.029456412021611488, 0.03687634320569135, 0.1119061709652024, 0.04135496981982743, 0.015292737159817932, 0.026243722719711163, 0.015443903544256765, 0.04369434570112536, 0.028023559472433505, 0.04522415816843991, 0.02922659713564621, 0.017773203454130602, 0.020138241365672122, 0.039648899673334057, 0.06698085220470544, 0.052385747267474095, 0.03681059370958998, 0.048884583727246335, 0.06761695799087325, 0.025130342241496812, 0.04971720638775057, 0.0240625535708762, 0.05308896618624849, 0.01796549343834481, 0.05389096065153999, 0.10107503603062323, 0.03720066652843549, 0.04749498450227323, 0.029451294554277297, 0.050620741976965825, 0.0179109939434115, 0.02116043439825937, 0.051864807478963375, 0.04068885636966556, 0.09258588550672417, 0.03314922969307631, 0.07670357282603942, 0.014224259010065469, 0.06332744018084581, 0.06981180755481606, 0.06660159271691116, 0.03652675047276482, 0.036876588353827115, 0.024860487770169012, 0.03610097029576859, 0.07181919540368742, 0.011427579391297075, 0.024461212320133083, 0.0741857635758577, 0.02372694577300741, 0.00980239568067895, 0.048765663898760275, 0.03020336115432363, 0.10132301869171281, 0.11213710816997675, 0.032588901493938706, 0.04425049106019639, 0.03610110819159496, 0.04361411331281547, 0.026017925964908737, 0.036947210169126915, 0.06219453403666135, 0.05074958647451094, 0.06663704726604686, 0.019617539064417926, 0.055279012378906055, 0.04567764391521773, 0.01015431157523586, 0.04711790836506313, 0.04400912356833297, 0.06895688407483601, 0.02275568801128576, 0.0136743888687042, 0.08642971019951567, 0.02728000602444574, 0.03210106436463614, 0.06993923862014087, 0.08846235596725056, 0.018073310737588236, 0.03747461190927894, 0.07320432067518273, 0.056004911330678774, 0.06644581639838797, 0.06413768924352142, 0.039590558247460474, 0.05806001496591395, 0.04940110701887358, 0.026385188515808795, 0.04310332418930146, 0.07038695572484886, 0.02871437734293361, 0.05553424606219896, 0.05130888811583, 0.06109440496431724, 0.050410726633403576, 0.06829166694754554, 0.046531644259249015, 0.02633404257076402, 0.044118869493925766, 0.08520788422996, 0.009201343205096501, 0.08198295284302966, 0.0638614762424221, 0.055251885205507285, 0.023363550050905155, 0.0240344726180117, 0.057384735273738066, 0.027019654873818643, 0.030103825265541676, 0.007644261838117195, 0.008657917778398241, 0.03570771821203732, 0.049947852479113694, 0.026355351306377884, 0.05437221708557299, 0.021436000055062677, 0.0027108002048466476, 0.021169828551430857, 0.05106839013376063, 0.04618605050528723, 0.06600051247064145, 0.0499967135669243, 0.05481944389400944, 0.029090583970349644, 0.021431623777795224, 0.021342338145440145, 0.03560087575967755, 0.025599659195229895, 0.08123717390962186, 0.012474654959664952, 0.04558307802184455, 0.08361724055101795, 0.021017317682684913, 0.06534729228024522, 0.024573340779170397, 0.02566236732227187, 0.06531243527969045, 0.04061017530940233, 0.03368249966672832, 0.03640393508718379, 0.05124852421783632, 0.04240265634331492, 0.04902161387426238, 0.06353050710693484, 0.021992335020894968, 0.04223952941115826, 0.014394450230493903, 0.04178997369543199, 0.07596246702896972, 0.054135967061043754, 0.023803749917856148, 0.03177785761504164, 0.060216506507488034, 0.05335474506981912, 0.016535506058003635, 0.023355410366709677, 0.0317931889496263, 0.02325078190845107, 0.0627873711768658, 0.034361341667752114, 0.014047445917141535, 0.0475120720934243, 0.04485799495371119, 0.020113862532701705, 0.15761846886767497, 0.019280039029376164, 0.06768808159376345, 0.02474947396906153, 0.03358422590780162, 0.062389802187681205, 0.013421271503302119, 0.04214495202646621, 0.0531994475562486, 0.028497369531842492, 0.03599664061180046, 0.0413625349380797, 0.025207548582505797, 0.05141232530736635, 0.056767804668315, 0.029980261029014667, 0.025700472535625584, 0.059783831539173285, 0.007719008558084287, 0.04970789075859132, 0.05158368768470903, 0.02250461227020189, 0.0334382516842696, 0.023793982296821573, 0.017053059737889037, 0.04529451185296621, 0.023745117378571344, 0.05177931589705329, 0.0498099566527432, 0.01374683014282416, 0.03622103542570145, 0.024768361866834666, 0.02167880396178413, 0.0019961288701104483, 0.03016057322853275, 0.02153745307887514, 0.009000427070854893, 0.06912278041483895, 0.056090847243584936, 0.05490148424982064, 0.01640673433881133, 0.06324928772125034, 0.0360448811683924, 0.030531264022893967, 0.028119159584504463, 0.029073871762281465, 0.04079268809648291, 0.02322267414250922, 0.03368385947279392, 0.04701708353334858, 0.036424722883009145, 0.06410647882148623, 0.1375976955938724, 0.02506673204592399, 0.05446769079313644, 0.013994665331988326, 0.030162494194002885, 0.04318826035746644, 0.03938667160729247, 0.02707021284638153, 0.08554492461224718, 0.03791700853335281, 0.03758006774249577, 0.04144163734670128, 0.0569166555520027, 0.07262024758083206, 0.04352414011654835, 0.04672987717053583, 0.09016289495893064, 0.023642965299527974, 0.029583500262590188, 0.09676324804463694, 0.08978572689116963, 0.10068253854349737, 0.0359103829419661, 0.035954984580917705, 0.019521699549870628, 0.027631638466470668, 0.0705035466460451, 0.066596697415075, 0.07065127904136335, 0.022632342109817172, 0.060313566017054746, 0.027685224401554274, 0.09726338088512422, 0.0664260283473038, 0.009777193303189931, 0.007993960386938266, 0.030236473389630838, 0.08286455150453315, 0.03301730169163596, 0.015254091854477602, 0.07323147083121924, 0.09112081129945095, 0.04677259806363333, 0.023263738370470466, 0.03850494654128148, 0.07576985720304713, 0.03844264444083937, 0.0548069796434814, 0.042337332026011525, 0.02486932842481521, 0.0365494228448839, 0.03223450922016655, 0.043406319624233636, 0.08159067752140184, 0.007186950439767492, 0.10141193851708405, 0.03837107650695309, 0.025932212217500614, 0.08010406092169785, 0.09057108192674576, 0.05834311126701294, 0.051264217528965206, 0.0336751758661722, 0.13720741976172696, 0.1350548199468082, 0.263197963997241, 0.10002990824080284, 0.35434548112173236, 0.14414445316839603, 0.15332430090394714, 0.06214286523660826, 0.20966427611006846, 0.11453694754069853, 0.08524853285522231, 0.17888839446729232, 0.08892541015220266, 0.07798355252992722, 0.16350625293149104, 0.09557562024002114, 0.10131066935437341, 0.18130216897735674, 0.13208698000638716, 0.1124841996258305, 0.17291586575729234, 0.16922031889759725, 0.10424643319340483, 0.13051685216205736, 0.15706970476575438, 0.19932464786594917, 0.14579954016352856, 0.14811266604210102, 0.16910552828302308, 0.20718285603629005, 0.17676725022254453, 0.21937695331871512, 0.12959469680584249, 0.14388479532734041, 0.12385973962204111, 0.1430324918680614, 0.14239116902312926, 0.2277002687896452, 0.11119850490602756, 0.10486618300238926, 0.12698953054965506, 0.15165838142556531, 0.10448985763134495, 0.12696432625694623, 0.22808720447844077, 0.2189045681828453, 0.11942951444296107, 0.1239455721130775, 0.13360539691582804, 0.15369658899163047, 0.1838610405402799, 0.21959873577279432, 0.09768223179684532, 0.2051611500041139, 0.2289885682083907, 0.1325202793363602, 0.14488653189712955, 0.15160883085862284, 0.14310078094563178, 0.07913355009570237, 0.1302491350760383, 0.30686424023682074, 0.15840870388332876, 0.11640705243353883, 0.1331224857318786, 0.26233807626751166, 0.2523069516305001, 0.10965067022029432, 0.16736876099340378, 0.10950223302408572, 0.08005007470567381, 0.16036584402524656, 0.13008801146380364, 0.1982771145600465, 0.10855814457059869, 0.31256865349508106, 0.24067396778733502, 0.1133771287277341, 0.17561105500546195, 0.14249900355935097, 0.15443469938491622, 0.22288565133367816, 0.09428394237352956, 0.12050609780295242, 0.16874490005354728, 0.1420050760310504, 0.14547746147840254, 0.18133135692727181, 0.11893010938600188, 0.21501841864758925, 0.08776823434257701, 0.11560478217659459, 0.2062462982270987, 0.2391389880569712, 0.09291292078072026, 0.21171777479110226, 0.06421034885269981, 0.1437475583365848, 0.16205364297474587, 0.08952989948973542, 0.12857484991752333, 0.13557977403604216, 0.15657029204791592, 0.13639270057601316, 0.16093176849667104, 0.15128310559497726, 0.10524879029441266, 0.11835074773238552, 0.4114633726496851, 0.1641400068277313, 0.14637409078498043, 0.12946478361564298, 0.19774374882540396, 0.22773494192909813, 0.1266527812807791, 0.13083874698608153, 0.09445756854068849, 0.1326071537069736, 0.1962902808501836, 0.14939423920887132, 0.093945155310775, 0.15348409152319356, 0.18105315975844863, 0.21191628349404182, 0.09281846980053572, 0.15662551166549807, 0.2371808979660273, 0.2038580497666713, 0.2156566464973073, 0.22446092728885914, 0.13565705698584357, 0.09551772697558326, 0.18096220980007804, 0.13912371209552213, 0.1928251732381121, 0.10255259747106223, 0.13311159196159533, 0.1229805694592576, 0.11125082871125591, 0.1360247638677397, 0.08530343071587625, 0.07773448202398517, 0.21722329630246087, 0.15365615487098694, 0.09871671862539746, 0.1995316907883652, 0.289873268094755, 0.09103469535588257, 0.0819430473230539, 0.11919876876016779, 0.19052364593071325, 0.1084295720342667, 0.10804835136138624, 0.16474106409136327, 0.2107638574295467, 0.15005063866415333, 0.1598646539834238, 0.12169414695592658, 0.13755110212631766, 0.19585701216372753, 0.13617044314742088, 0.18761539230904273, 0.15692981711078077, 0.10576897931675758, 0.15542473013122238, 0.17758055980647766, 0.1408811484373385, 0.15659102238714695, 0.2825432469046885, 0.11716515006076907, 0.2436302704436164, 0.20114219146630458, 0.18786420234509055, 0.18910860492577478, 0.11418476926102755, 0.2176599051322668], [0.037118365702730034, 0.02028900938439033, 0.046782365684667905, 0.0060589357669795715, 0.023613666266863866, 0.015117813431237255, 0.019307997408172777, 0.02987131758052255, 0.03315046692507402, 0.029585317806190545, 0.024359489250327312, 0.03549505220425706, 0.018399420960415757, 0.04623309213427767, 0.024937376184689424, 0.014203241387862834, 0.034969535040398764, 0.032774758254808765, 0.010308301951285574, 0.058300030312591025, 0.049254286268185225, 0.006604461711005218, 0.037016529634955435, 0.015658450297891133, 0.05848095346722872, 0.07784286048263311, 0.00473844293963104, 0.1290635833696973, 0.09098561976345317, 0.05703895765867445, 0.023169850464910272, 0.07911092751929838, 0.08161228120086655, 0.04655179237165759, 0.06449562467394337, 0.026300102960498586, 0.037687718417615666, 0.04874212967772638, 0.07075504565070714, 0.10864989126041051, 0.06121704031923606, 0.04834547999405092, 0.11332896477993458, 0.02531963107626765, 0.07924503121044367, 0.0854182672957259, 0.047000057229231444, 0.04425640142853222, 0.016395112784999995, 0.02548027971398927, 0.008216388748898622, 0.052173763077946446, 0.006140189446253522, 0.048156030280815984, 0.024535233650596875, 0.037348651732768745, 0.07095471114641236, 0.012354746877756572, 0.056651014564258445, 0.005931034515191231, 0.06751940435459537, 0.00938519090038514, 0.01357695301844468, 0.025268755177216187, 0.008752103500639, 0.034002291579400344, 0.022185301077702356, 0.04739484914969053, 0.08610419177960965, 0.038104788174912814, 0.07400705824576079, 0.015477955194881127, 0.04638785721674081, 0.023502244523936705, 0.01808078009484997, 0.010805470031505872, 0.08359545301045142, 0.0403280557704068, 0.03916138047052007, 0.024390333865378654, 0.034001506339277954, 0.039527915237892064, 0.0017468487673003468, 0.061494268386835055, 0.01970711389496442, 0.055113062412748416, 0.03044859930542448, 0.08330761079466151, 0.013978404158185569, 0.09168110502463195, 0.022585943994683125, 0.03828253589510437, 0.04095853847121039, 0.04017922020847759, 0.02409789703726288, 0.12858520742625962, 0.023189600211598223, 0.06303050067095507, 0.041231510920390006, 0.03134915864305391, 0.04380363197396359, 0.04657812664405473, 0.039981144345215255, 0.03739400030744653, 0.06810620472195648, 0.02422298770397902, 0.016476486644317067, 0.02745066168567827, 0.02765861242228458, 0.037231930576625376, 0.026104283226173253, 0.02476659794938901, 0.02238863613456488, 0.030006344407616608, 0.015926582986609112, 0.0319681347032348, 0.0372525345113489, 0.04733134429120729, 0.012086704204369698, 0.0925068558764554, 0.033455553780039476, 0.05527848760867792, 0.005962435022792629, 0.04848213858842369, 0.010146010054966376, 0.056780222953567584, 0.056522024510007714, 0.0184899706378459, 0.05761506343861261, 0.009462811886483144, 0.030349888876380942, 0.03576546591976958, 0.04177735239687947, 0.014619667631303592, 0.08903493774273703, 0.06236343727176709, 0.023252653078206127, 0.08772371697329706, 0.05247159124982934, 0.0488626544604138, 0.013464967243283266, 0.04365819401197857, 0.03458975844325558, 0.052552804230682315, 0.016305660528521386, 0.024493755735156518, 0.038348748874399936, 0.03264344312370785, 0.02817626760881995, 0.04436021400315147, 0.10322991878755632, 0.02749657141976059, 0.06263850880185924, 0.05450382716052475, 0.029846339283751386, 0.04342589700113862, 0.026031225251274246, 0.05161006409194201, 0.00757197761202171, 0.0020643163213296045, 0.011420942197043088, 0.013303701904782606, 0.05616266798648623, 0.04705203629489388, 0.07401308735772487, 0.03312003408228198, 0.018229257510674578, 0.05812925399251043, 0.01803585478375035, 0.08021235511067414, 0.036214512187026204, 0.047120390489937804, 0.014896708964971046, 0.030397675525877747, 0.05084131784256428, 0.025079056485405853, 0.010216740080185477, 0.008070324510035497, 0.03460640936428982, 0.03214082049746667, 0.04983205062847945, 0.03903720910931307, 0.058294702171077656, 0.030395511327491655, 0.040214739875086856, 0.051367746651052475, 0.03585466153679356, 0.034227509937819936, 0.045053600183417725, 0.04521104657361585, 0.02878001384106615, 0.04699453756573701, 0.04608523716489154, 0.04568052823625265, 0.061688460184321295, 0.0852197892363033, 0.03703698418253372, 0.05040488138254132, 0.03090881130417749, 0.030129770748317245, 0.039190124089439074, 0.033543182747258295, 0.015572850506061749, 0.06640572701731036, 0.02960101686297886, 0.0450166019671146, 0.08123840731117996, 0.040209170415877335, 0.027774538762206515, 0.021978970617055896, 0.036304523687689536, 0.03623183726543381, 0.12748217105024284, 0.051886093231939504, 0.01798173833277918, 0.08680655651034848, 0.05030619776657513, 0.07989465078759579, 0.073025431483984, 0.011869528811545143, 0.027412958668484807, 0.06817732066396745, 0.03827197154262855, 0.022737288494564356, 0.023208999473060814, 0.07814203313882313, 0.046569201719736865, 0.020039040640357043, 0.04968143391212629, 0.023861673825810996, 0.03882235975094861, 0.04126937864648719, 0.007039037056177134, 0.023391270942445246, 0.034136046700540094, 0.03864351269458571, 0.032552776617869254, 0.0221562797519108, 0.07876749030284344, 0.0486277527506313, 0.0692646598984157, 0.03683659090330044, 0.02775742244275828, 0.010055852997597429, 0.02869490147267859, 0.017096535227591955, 0.057537362970892465, 0.020713023728721087, 0.029096346866760044, 0.0502151865211706, 0.08324306022616164, 0.03767286397276386, 0.05686148189969602, 0.045652792022954074, 0.046767898114217867, 0.015707916595161926, 0.06672360754061131, 0.03883413069190518, 0.0376454878207897, 0.020480910578982967, 0.018318432060280637, 0.05663820174372485, 0.010591032445400713, 0.08892786163356035, 0.015013568974550695, 0.09926426464751845, 0.031320995335737546, 0.039674674701546474, 0.025578658810005556, 0.04138720296924153, 0.023077402804647724, 0.026084820762456908, 0.08891308379750099, 0.05605521266378703, 0.07871475281013597, 0.018434220504376198, 0.02389085986050627, 0.046646714495915564, 0.025209885150674852, 0.022204976130817688, 0.10024960693572799, 0.029567454551016132, 0.005130905952800306, 0.0662355482458107, 0.01970760036079634, 0.07901012567022155, 0.010296628686539348, 0.06267462218660982, 0.03042277831193661, 0.03112753898265862, 0.055670153890405936, 0.03647961691322346, 0.007792874276938458, 0.030097596970717275, 0.045462691134983496, 0.04423860903649081, 0.029797382434950243, 0.08854894688533199, 0.04609265289599857, 0.03014278849737058, 0.005556752204879998, 0.01823548580549898, 0.0493028907165412, 0.04315731423576513, 0.04321640259736488, 0.10305514348851097, 0.023620042033613693, 0.06686465964922983, 0.02358207663130616, 0.057116267421553214, 0.010454209142124221, 0.057011087379989125, 0.017052646050409927, 0.05866643101457627, 0.05709489356846579, 0.04305316841289882, 0.017126326471747413, 0.07111628675052235, 0.018387364651707393, 0.051978774549018954, 0.05892356459592139, 0.014957391747063207, 0.03397666976877278, 0.05736980038965422, 0.050928701661647334, 0.016559513338330775, 0.00314770158447866, 0.032144865441706874, 0.09711357239153116, 0.06507446538777122, 0.01892650860451883, 0.020079413473966624, 0.0492962142602811, 0.013718507872263511, 0.03314800778283708, 0.019667677603842273, 0.04351754409952029, 0.006020008445522118, 0.042954737605947646, 0.054892628273415955, 0.032476321043026064, 0.0672529896180476, 0.04078585076175871, 0.03798301849934844, 0.05870326069153606, 0.013962741490573654, 0.05824686381064596, 0.018042881725235813, 0.049215767367352406, 0.020585416463173686, 0.0666567050821839, 0.05034342963969515, 0.134448706502876, 0.08634331080341533, 0.144174836215473, 0.16180921496162493, 0.0891315950561435, 0.09199081138978082, 0.2383509900180563, 0.15153372359852638, 0.17115001777006736, 0.11740549482525357, 0.11166170464768527, 0.1930166032886313, 0.26601640147066885, 0.11706513728225425, 0.17987415044298097, 0.10098329700169065, 0.14779561289375828, 0.12127764793413302, 0.23074424254798123, 0.12094392471255795, 0.16297515481710434, 0.10584265399243563, 0.13160647433851996, 0.1364533440960992, 0.16034203401255995, 0.12516539859315082, 0.13830595920162816, 0.2466932278607161, 0.11667804837587381, 0.16014930161256946, 0.14873560277685044, 0.14296746632504848, 0.17097997689439406, 0.17287786779624803, 0.1792156978720619, 0.0872331755536218, 0.16472865346698992, 0.149930133033664, 0.20367598131058678, 0.17863984490113874, 0.11683132724776385, 0.12841112926722537, 0.18524651055134114, 0.05587922694582132, 0.19999646101026766, 0.18797353841364386, 0.10909602256311525, 0.10589563663327888, 0.09443780347224205, 0.08127057534312049, 0.13572268007743743, 0.18605174556855233, 0.14697032169468943, 0.2242478016283243, 0.13128061117904802, 0.10447327182778429, 0.18654875277030855, 0.06241313722585479, 0.14332985655675012, 0.04887884572869347, 0.21207748371506893, 0.07286715771882765, 0.14019191445362184, 0.14940190008811413, 0.2460686670195672, 0.1125339340538748, 0.17069980321872621, 0.13000688275262234, 0.13334036113754397, 0.11778054849034357, 0.20416439300583256, 0.16338583923155264, 0.09352595965948798, 0.13607377817313518, 0.11823336774062727, 0.07562192562486857, 0.1184741798187456, 0.15466728367872778, 0.10832420430116116, 0.0985767160572352, 0.16611674349875222, 0.11699140131954225, 0.07000538265152324, 0.17478262284590354, 0.12415667530149223, 0.13192535077612247, 0.14290279318248073, 0.231582940285725, 0.16326113543923826, 0.21592934315483417, 0.14981840677078695, 0.1093206778469105, 0.18105611685783635, 0.12873021254856742, 0.06734260658342993, 0.18981164381388696, 0.17756781210341763, 0.17856141281945093, 0.2438486514673118, 0.19680621042366953, 0.1294706365273845, 0.15960588480436033, 0.11157635479204117, 0.13598909481398522, 0.1576582441527036, 0.1880496109445249, 0.0992964556620967, 0.11380162570745715, 0.13292295047112052, 0.24564443817061765, 0.07922272273008862, 0.1816348349975963, 0.1382665363170447, 0.16344470542765435, 0.07760389467641231, 0.08336280742960592, 0.07245024500955498, 0.17790328200546005, 0.12792068743898025, 0.18144697491680423, 0.10777253672600755, 0.20537701825941765, 0.12842661190417506, 0.15075246713334514, 0.10328111644353598, 0.13981455486387978, 0.17383754613899416, 0.1793647479386099, 0.19677768130936932, 0.10277974254061138, 0.12132758920591687, 0.1368269345332538, 0.1111421897827137, 0.08700096664289314, 0.12027233373373748, 0.14019071935645996, 0.08366507508101002, 0.1554178659834208, 0.15055017395605966, 0.1701773465761254, 0.08674376794407446, 0.18960285421100356, 0.09413696840525636, 0.11326059143269256, 0.11593598496889877, 0.11939193016939587, 0.12341548523475086, 0.11289292285519262, 0.08877544844102475, 0.08999632446155434, 0.26672107978693904, 0.15442402011925174, 0.21752441482197857, 0.1292171073897231, 0.14053028016801805, 0.10830195710784006, 0.11646794876263988, 0.10523096342841465, 0.09019724634145537, 0.10753479666046559, 0.11383319619081675, 0.11978651141567577, 0.19213918746719438, 0.08749253462038695, 0.24439061270846477, 0.1772499162583582, 0.16857701954582047, 0.17037636089709499, 0.11717060460678994, 0.15176405559384054, 0.10037550582520424, 0.18912665395727082, 0.09625272705189644, 0.20686155876084683, 0.11408207517477775, 0.19120675121103564], [0.059214448180770686, 0.037718427052060445, 0.08115554724128977, 0.06561149302269183, 0.06084659084257099, 0.03572303997052293, 0.03767901948923546, 0.009087747687684193, 0.029617964643083756, 0.035837700350149986, 0.09058310950715696, 0.010796060556575898, 0.045304076460700844, 0.026937254456683036, 0.01831628509887284, 0.052637970225224574, 0.04739066247918433, 0.05145274793669101, 0.04819295188832668, 0.031492037871371836, 0.03888123743836919, 0.014078401614941899, 0.03133900797805719, 0.04069411556326574, 0.07824721701082685, 0.0629842596038455, 0.024256626624734174, 0.02202347649501697, 0.02659384979896488, 0.025295382478244366, 0.053547933292124546, 0.017286193699786262, 0.07533304152950164, 0.045810721048544494, 0.05122610082429263, 0.07346304388897074, 0.014083549725793064, 0.06880047956421491, 0.03147947785985326, 0.025796348439349283, 0.030864550574352185, 0.04697905875922692, 0.013358140112681976, 0.06601596446407419, 0.010456387704658893, 0.02755235219674726, 0.024971953563151822, 0.03743548396854632, 0.0504151699433644, 0.003503309304623174, 0.037708157643435464, 0.06078471392092686, 0.04833287401725689, 0.05438976815991825, 0.028710970166890372, 0.06080308087891149, 0.05619732580418068, 0.027039373976989623, 0.011084363382730273, 0.09157487927305122, 0.06469115329485747, 0.07097790062788033, 0.02789061640449349, 0.027223399787720655, 0.031126022128568544, 0.1117544012865232, 0.019877949586859154, 0.01444053712240871, 0.028423417149291887, 0.06227086320699704, 0.03487513768636892, 0.04723193289171304, 0.021857995757712953, 0.03476263001380909, 0.030567097785552184, 0.01611616868045061, 0.061052921303217454, 0.04996034354271908, 0.044482064117947896, 0.004282659886690278, 0.026984571877326217, 0.027516857427995534, 0.09144370969865592, 0.011125214063682625, 0.10987733265445118, 0.007003570536917617, 0.04249902637374978, 0.05928028194654373, 0.014076020996717196, 0.05420329852870876, 0.06244084662607601, 0.16107324961452715, 0.08025422181573608, 0.010258507193817247, 0.046228250458596215, 0.017680393817323833, 0.00879721363045035, 0.025754123588182756, 0.05121227293725937, 0.017855421925384193, 0.015279466601749583, 0.030330273195079742, 0.03606936150801278, 0.03784615306123611, 0.012605342856277863, 0.03245978886562009, 0.032148822285835786, 0.0446663159246166, 0.05469096328822836, 0.009935727538240534, 0.0785250464574464, 0.03637966925218221, 0.05577250706752943, 0.05698176536468729, 0.06384019048944597, 0.05914296068611646, 0.026099612005054954, 0.007289952876406812, 0.08274877263653664, 0.03881482144577369, 0.022239660761589487, 0.04048925216099428, 0.015037914291174423, 0.039450735709960424, 0.04152419864230099, 0.03639235183776867, 0.034310492581778, 0.016598279302519177, 0.041054330105262424, 0.08142093542001902, 0.021128894558416742, 0.08665125516633834, 0.05242504757798968, 0.05073547513494569, 0.04359041055243823, 0.05614743049767229, 0.028209410487644138, 0.028994596983876922, 0.03331018093552801, 0.010549677104028243, 0.005374053162672828, 0.03510068929303558, 0.07048652417236759, 0.0445309060535604, 0.046061522913195437, 0.0035045556339149877, 0.06254675828160779, 0.003567970237664638, 0.031800185247594794, 0.007664003923925902, 0.01113995359534578, 0.047514584861815944, 0.023125953626849, 0.056812770199030645, 0.04085459183120439, 0.025182145106936657, 0.030927149533864953, 0.06332201244790228, 0.01363564684476343, 0.024621619640158552, 0.05625151503350466, 0.041737282167999976, 0.029459893891227343, 0.04765007900254381, 0.03400343305040752, 0.054530640237874566, 0.04681479035606308, 0.015544947668639644, 0.01990643082066409, 0.036115889858093955, 0.03455184858232256, 0.040550837969227184, 0.026165886271384456, 0.04509009278169082, 0.04317118042719461, 0.02305280563661889, 0.0833001644200375, 0.05701994718683343, 0.055279947006173676, 0.057144919109921304, 0.034936133606900135, 0.07367560264444159, 0.012180571042511974, 0.04355055482817754, 0.020784335023152734, 0.04783288673347524, 0.023051189191098657, 0.043434764468862165, 0.010944441253800067, 0.04363834467386046, 0.00357281981362781, 0.038730854378832925, 0.04288698478992428, 0.015277540848229923, 0.014942422389022767, 0.030319011702592817, 0.02618296237121667, 0.052658857612480084, 0.048486156719586546, 0.04919097293168307, 0.054017920572791374, 0.038982272944262916, 0.06284898762861568, 0.056719031680615685, 0.014687830304366448, 0.013312962950177252, 0.05930415707670393, 0.04333261813547823, 0.04128625939389871, 0.02268699482233534, 0.05371999663991794, 0.03542512752896836, 0.053555598001806974, 0.015277052467178195, 0.03557314337681859, 0.06487000418166, 0.07613810034649027, 0.02004264699926059, 0.014582600467087281, 0.04688153193602639, 0.021091700989692923, 0.044154312551742604, 0.09286995090904737, 0.06527408491820097, 0.0336935734676738, 0.03677866316490597, 0.058176598226230954, 0.04022964411565373, 0.028948476575615428, 0.0980752885281559, 0.041043516774211204, 0.06051093707942675, 0.04670522829157211, 0.024646362364893, 0.021443917573760116, 0.07764716332237567, 0.03697162156083411, 0.08041494706225011, 0.016894954512076035, 0.024180126999835336, 0.038792830891907215, 0.032189248745600064, 0.05678757356720106, 0.012311886173612889, 0.030281994334091584, 0.03900220655205269, 0.007741903574506362, 0.05731751105838245, 0.05233608178734299, 0.026698531883378184, 0.09419248679712897, 0.07384954290764947, 0.022600505410903887, 0.030451142717333093, 0.010307868153998449, 0.024657164204625354, 0.04853447388497092, 0.04516269876471451, 0.06412524797563111, 0.06535089289348933, 0.05318447819820816, 0.10786651273167903, 0.022458666146943168, 0.05209291015841788, 0.03906805563958422, 0.0664863424495824, 0.04285516532798929, 0.07538287554897609, 0.08438469211180365, 0.07228349831195609, 0.057869791503875494, 0.021789628156130354, 0.058126614819611275, 0.030757394025943456, 0.03179642950154601, 0.04973661139487259, 0.06562279281957496, 0.025046223872191003, 0.03614883546927764, 0.10357120329694403, 0.08706172507616781, 0.012230700005837267, 0.03875274534126924, 0.07515003844614952, 0.03206231563742603, 0.030551469591896863, 0.05154060673028712, 0.030859869777134834, 0.10424732185539701, 0.06706182769830189, 0.04806290846318007, 0.04651498567733554, 0.05215002967405224, 0.05297378486683292, 0.05204297271707366, 0.04116273537698773, 0.009541542742461448, 0.06145128319340368, 0.036530075294356194, 0.0835805602612034, 0.05216080853114686, 0.039158695332345464, 0.012099124404842095, 0.04960074187106183, 0.04643236692514151, 0.06704689664465767, 0.06288882037023864, 0.033518970538411415, 0.05313981144178299, 0.03255529704714014, 0.021526718271836158, 0.07613126684220568, 0.02899562162647565, 0.08682839001619047, 0.047056701770352746, 0.05473479500881607, 0.07414475488927096, 0.021751126492275827, 0.028568690402373195, 0.06391252834169615, 0.024838072037504568, 0.059915974045232426, 0.10246164751269164, 0.027306451379591902, 0.0378894102158806, 0.018732050591478908, 0.026434737167531447, 0.03399640419370225, 0.03525412521295009, 0.03500992319576683, 0.05697650234064749, 0.017134856860784274, 0.059297400181211775, 0.03828786786705737, 0.06089717179777161, 0.12022973924514749, 0.013790224235685123, 0.06879017568163334, 0.00941242532609331, 0.041553321474742506, 0.017992139891571095, 0.038348503726264166, 0.01189223470001091, 0.017889522414113727, 0.055384989151911396, 0.02283299011328528, 0.04438433811188706, 0.07546880763144263, 0.02692544712655006, 0.04499417857357091, 0.00975896998669111, 0.021512583949633186, 0.13316702608379627, 0.1194996957577044, 0.16149171748228613, 0.20642225330154743, 0.08575721523694455, 0.08863366088799893, 0.1332487523435585, 0.10018304921686651, 0.13947203695293398, 0.1902711586726289, 0.1787686242812103, 0.15412391283579413, 0.1286218111072817, 0.10946664057912366, 0.11552202169813457, 0.16194862764208548, 0.14109954478279238, 0.0917117178980862, 0.09739695597560176, 0.13904408491667242, 0.18322924782912578, 0.1434697901769992, 0.15384197715790043, 0.17360784233577792, 0.14730291110613655, 0.14709330945005342, 0.1526269463882331, 0.15569842270305081, 0.1346900701642998, 0.13571544820743223, 0.1430268687826972, 0.10800471499321923, 0.20931854062984068, 0.1564261602658418, 0.12990070296631706, 0.147643651693098, 0.11766450149157356, 0.15967484803930407, 0.10376760525809181, 0.11323767774287732, 0.11515032349815292, 0.14064133227352174, 0.10820755209293097, 0.16051650287643557, 0.07891553679421064, 0.09246428437050312, 0.171938797218665, 0.14632775778731993, 0.19499592933683627, 0.12761222213626872, 0.18815945263110823, 0.15259259500570838, 0.12715974762555093, 0.18597936558146633, 0.1358220876464921, 0.2177809776678201, 0.10348397652588545, 0.12125409839134063, 0.2129465338563727, 0.17641095805072016, 0.13012985518622783, 0.18437977399556868, 0.09163594414149562, 0.11917384791999094, 0.09245436353188369, 0.17804937497262033, 0.09069301248077424, 0.11955518350606004, 0.10379314662948733, 0.2436957403176254, 0.12097904218300698, 0.15599342784093273, 0.10013938986606176, 0.20845002675008392, 0.23443235835481077, 0.20917183479234097, 0.1186472467417198, 0.1314198859636822, 0.09978563344526677, 0.12496187201430722, 0.15175095549033535, 0.23918878377204944, 0.19267498936143615, 0.1200866876470466, 0.19999155804755228, 0.1863712195547358, 0.15863102259895495, 0.12670913470848916, 0.08171819285639832, 0.1650754461485532, 0.16176096674415374, 0.21665847499764737, 0.2416525531800524, 0.1378489724330364, 0.1649938884281343, 0.19454556156791028, 0.15949250379156682, 0.1377814647651488, 0.1978135700788229, 0.11581993797012877, 0.13482310899323033, 0.14844877945799984, 0.10990737096196222, 0.20574708469212058, 0.21071858163322174, 0.15750625230852636, 0.08927814001517911, 0.14428199659432137, 0.11366883202666238, 0.14652766077028168, 0.11411140868139845, 0.12621763567890854, 0.15151798815256165, 0.12798077171488156, 0.2134628158303038, 0.17529481391031898, 0.13528700587489914, 0.1326346256199383, 0.17998393084253037, 0.10840395405407875, 0.1272478477368432, 0.34064825804483506, 0.11559800995934395, 0.22999384410439, 0.1703031995003262, 0.1618191281393651, 0.07206317908581227, 0.09521359773052317, 0.11080437565162299, 0.22302092713934762, 0.1906065366441204, 0.15479261566314007, 0.13732588759833766, 0.14019848748801217, 0.18348597921431067, 0.11661474653069051, 0.08518537656674463, 0.1765072706245607, 0.09577975202832492, 0.13900375804833828, 0.2558463391277098, 0.13823707257547688, 0.11965465236214862, 0.13587266477125307, 0.08883938613918521, 0.12492941286895545, 0.1870112094066797, 0.08403877277047404, 0.16880234132610983, 0.08988131168148211, 0.08037251345212422, 0.2096913803008295, 0.14393753282004787, 0.14722803367241738, 0.18418124997087065, 0.21314844398969607, 0.11866854398601479, 0.15885085918970648, 0.17838378767332724, 0.24071841620870177, 0.08829641366197218, 0.15900294296443462, 0.10913217425226204, 0.1718502221328597, 0.15000088891435057, 0.11210821133347289, 0.0987066139256762, 0.13554073419542084, 0.09283172312162577, 0.146423518777855, 0.11847189687673124, 0.09394669514750281, 0.15534023063317423, 0.12843192855436958, 0.13089326180277333, 0.08041325400793746], [0.04250943367820113, 0.047834277183057806, 0.02873392599154144, 0.0667747209269193, 0.014702731672103607, 0.04512047965920741, 0.03744509071111679, 0.037765518476765965, 0.02868140491867258, 0.0399469155367584, 0.0132904208130053, 0.015390418158213218, 0.06285329304275013, 0.06284718732199361, 0.03428249972902479, 0.029047815196756876, 0.06208463106304408, 0.014513262806670561, 0.030254440066675027, 0.016111765590105808, 0.04879690496431244, 0.032525048065449924, 0.08718732519135361, 0.022759252235353477, 0.08399125999741017, 0.03045479887195172, 0.10598465605008026, 0.0380290259096411, 0.03352873815944599, 0.05704432793502366, 0.024465280247011015, 0.037183464024095766, 0.044680025068021594, 0.022457430830165263, 0.05118502702023234, 0.05285103459872546, 0.05932129063313046, 0.08621509832840774, 0.07169794666791154, 0.056375337824706113, 0.07127605438713105, 0.06717507847614827, 0.027669623020976305, 0.035314607854572036, 0.03516480319141861, 0.08442596126828464, 0.06074876524508, 0.07576707630388199, 0.09018459822982551, 0.02080382429994643, 0.04093277493431684, 0.04877433218362351, 0.038185445742020686, 0.018164415828763478, 0.03307075547655264, 0.03254164536032946, 0.03923119023262013, 0.047515848906891006, 0.02404884251225139, 0.07360213481250309, 0.09067094914855496, 0.07093772697713106, 0.03331950805600613, 0.035095184951299624, 0.0515012298109791, 0.029188499583171743, 0.037921957461343664, 0.02000346734759308, 0.027407665000928026, 0.08113666317395626, 0.05901492058089184, 0.04404844686148628, 0.04052615461630687, 0.008021374843308643, 0.023778237274757797, 0.04256364589016284, 0.03289301924767994, 0.012614692959393705, 0.049350840159721916, 0.04591091768816114, 0.010833438944011446, 0.0321429732045339, 0.01373312961790831, 0.028051046707156687, 0.025974789469112313, 0.05412588534396022, 0.010372055788344194, 0.012993749433888063, 0.07235230066843572, 0.07546929792771417, 0.04262387955320939, 0.034068450932541204, 0.041032741747556195, 0.019914501556946386, 0.00907842631286551, 0.01009721025418971, 0.05800760306057431, 0.024772320626183383, 0.09369207816498895, 0.05409794228692209, 0.0431868392643669, 0.03213144358127348, 0.043022632148237004, 0.0714892566564583, 0.047009514584656686, 0.014099059175820121, 0.024501196364121094, 0.05593358854492826, 0.03153045143511507, 0.028376266352772236, 0.025775807706879515, 0.05542235509041817, 0.06637930464480193, 0.027612137698358106, 0.005161075452868377, 0.0249375332327139, 0.053329667181617794, 0.024856674567525907, 0.016526565811927282, 0.030751064224469087, 0.05363926629445726, 0.019923522242254788, 0.005510470439349452, 0.07117008910544458, 0.009486456232656156, 0.0470809982488713, 0.05575683673903827, 0.06174794691164167, 0.11251011638030892, 0.05235807234120946, 0.06599580869078636, 0.009721957406239405, 0.05058503461881511, 0.11191082877978203, 0.0474388723922593, 0.09431903686134085, 0.05417847727996208, 0.04519000979921511, 0.04565888625239173, 0.017986484247470097, 0.012273533896903598, 0.0551379717616064, 0.029173840490740635, 0.046531521685181126, 0.02234395214116141, 0.08966498377342379, 0.04481351205838784, 0.04050786809755429, 0.020970561421446262, 0.05625275226550237, 0.021185247986126813, 0.022152445481849775, 0.01439153813877173, 0.03756096917054346, 0.0449138006285554, 0.02740699467399428, 0.010639889702771702, 0.03138016413656935, 0.056362950182970495, 0.06208764561902612, 0.051337241029907624, 0.02019857653536864, 0.04707646683879918, 0.008137127377032753, 0.08373508785641001, 0.045574034353898424, 0.04014055958137878, 0.047101372357217536, 0.014470704707256971, 0.03739968467984469, 0.07128406766681902, 0.01588884836828877, 0.05472983841994598, 0.054720469164632024, 0.05942314968354279, 0.08199159431481555, 0.05488371867085657, 0.05209215173137285, 0.04288225419699185, 0.04722160985693336, 0.041284604643982266, 0.03774258563475263, 0.02715247345247096, 0.027096301970642903, 0.025254011815113407, 0.013425530952161119, 0.06973837802727377, 0.021546289903081713, 0.031342930348229506, 0.037863305769860744, 0.03605171084223736, 0.006097735726319615, 0.05222595281778805, 0.024805419454951922, 0.05899383784121564, 0.019017968011359056, 0.02569016482260439, 0.02548550634885267, 0.030955071523485166, 0.02656153812553854, 0.025480346746682644, 0.10180710965106565, 0.10048186947261134, 0.07607015600848584, 0.053545278797466914, 0.01239551137381744, 0.014647688254744056, 0.06950088310986757, 0.03624292255769815, 0.009981233160942793, 0.04123033497542624, 0.07900326152242, 0.028787393182996782, 0.008003010279348782, 0.01806595437829533, 0.095614644758884, 0.047994040989226876, 0.049643562355589484, 0.032165408089396455, 0.025669447889912034, 0.04056432111669452, 0.026187267785351125, 0.10086898136162951, 0.035093361662039836, 0.013394275522460381, 0.0445890368052548, 0.09762652954387088, 0.036634956561629815, 0.0644796823842391, 0.0206797908345658, 0.0642542839951573, 0.03793219622645167, 0.008605014619177148, 0.03823118119110023, 0.04125073972728945, 0.05822918633179319, 0.05581391795027641, 0.04995316146842895, 0.04468148063507773, 0.05088685793922313, 0.02853612208949222, 0.06205071252019656, 0.01849824438742813, 0.03640750122647132, 0.07657338384418719, 0.0344878189536112, 0.045123804480798786, 0.03904902984598472, 0.05048547766261524, 0.028397295466293732, 0.0526831464301194, 0.018793310812343995, 0.0405652480830829, 0.026892160606240074, 0.020649153063254013, 0.009453305692952729, 0.019181929979353182, 0.06257967707971412, 0.05556819141812383, 0.03124778222803387, 0.008515755799899419, 0.05972495385175271, 0.07347618995775139, 0.04018977690007418, 0.05573548203814895, 0.06795102595201424, 0.004665534830682221, 0.045441964626192086, 0.05238926744148616, 0.007543278043158353, 0.05504130295688107, 0.06278264824481261, 0.0660024736557276, 0.02493919372828978, 0.0026689672555338835, 0.08292984517831957, 0.07074136332037949, 0.024012688907884785, 0.02870418837354068, 0.02857851548000209, 0.044705846061509465, 0.021683687772301417, 0.033816511427322705, 0.051971561831211856, 0.04753550289258842, 0.003499723294930112, 0.04604571468887791, 0.038518257318965854, 0.0068792315939771795, 0.017957420786842704, 0.04247020231559873, 0.0714715370427697, 0.03569248072322338, 0.01844791432602271, 0.07402750513245983, 0.022332453161417957, 0.024672491708770398, 0.060964261947740475, 0.022745920390251185, 0.05325392023810456, 0.04838682958976396, 0.02509278286578915, 0.027082240426792737, 0.019630811537706086, 0.0346451351088622, 0.01710443933975072, 0.012119990724679685, 0.038142931692662745, 0.04968396966315566, 0.007739999846014525, 0.04560575039396363, 0.040781997339499575, 0.0615219624652978, 0.01741847410167177, 0.0670030917371473, 0.04262557643796167, 0.04429221220855271, 0.057151817731679454, 0.011564051251738303, 0.022357042668567553, 0.033032083358134956, 0.06626066826884786, 0.0229883240160322, 0.016249996579943166, 0.03983078809875635, 0.06310990951474636, 0.015410219615836059, 0.05925236953302257, 0.08024502876064471, 0.0409723740191229, 0.036875443052380316, 0.026482203975319866, 0.022946606698115508, 0.046499820966874404, 0.03279212163761258, 0.01684690930790478, 0.06463949598612324, 0.014371178394574073, 0.026048211335775354, 0.03261883637957996, 0.04293689158775153, 0.021805444041327126, 0.021830136970346494, 0.08779272617351624, 0.018553345261382, 0.02364686851750218, 0.04516415433177064, 0.0283372265121509, 0.01991800449398016, 0.023834939272473418, 0.011159226452300866, 0.025086489453491186, 0.16283494540520255, 0.1447828802009744, 0.1493626610646325, 0.19406516315235248, 0.1531686778030088, 0.13156870620385294, 0.10660006980141325, 0.1417264345312311, 0.1389377365910238, 0.11875816095139712, 0.1514633354400435, 0.11457081628783096, 0.15076225773701746, 0.18127880329566617, 0.1104693960458521, 0.08067492666023393, 0.2014034580920012, 0.1354532316327095, 0.14524352886984426, 0.15165038346763582, 0.08943912573158742, 0.10566426275838768, 0.12305019152981621, 0.0810482030013396, 0.12681637935700918, 0.19678609295477792, 0.18283330294634068, 0.11868100823654283, 0.09705763265130021, 0.15230249283054184, 0.09696465255993028, 0.08618131385094698, 0.1337196665906137, 0.07146587565300927, 0.11108055800920534, 0.1542341375663396, 0.08720322151578243, 0.20772578254822763, 0.2202482097932408, 0.18858820139881105, 0.15654282013495124, 0.18567581090234941, 0.13907063752412796, 0.11036720757763233, 0.12448521976869915, 0.15066386140402288, 0.2946861082267377, 0.15603044520943396, 0.11681206779734743, 0.19237080649022134, 0.14093325773794807, 0.09358573750021959, 0.12803504138343758, 0.09976632036869565, 0.10291916288195119, 0.11717941461791916, 0.09820166239214521, 0.18938537717105883, 0.0990197447038466, 0.16895629435537324, 0.19254991784691813, 0.09548289295766624, 0.1603946489311995, 0.17901355791236126, 0.11338007816624258, 0.21541011940327384, 0.11095964635211615, 0.11012377547881297, 0.1991639379411936, 0.08210590995487668, 0.24161100057103943, 0.11793507608555018, 0.18447415602784004, 0.09860348316930956, 0.11692682776840464, 0.12534074079726013, 0.12067958607428497, 0.11300241214133079, 0.13000492156753618, 0.07078637864681021, 0.19756560273949178, 0.16085880628276258, 0.19467545943635126, 0.11699882471152853, 0.193056317286626, 0.10126421378264505, 0.08379677325607308, 0.11391804808931005, 0.24755005123874835, 0.19660460672551588, 0.18368484031769539, 0.11467989188649001, 0.12239703262645392, 0.1109579916021997, 0.14823835042695846, 0.16971191751860804, 0.1696631023960729, 0.1803059635623809, 0.15827816250103136, 0.20087266641278423, 0.1265817496084398, 0.19304943781706596, 0.16694401120466573, 0.14772412156866443, 0.12574980876618816, 0.06481873757776714, 0.19732659862887478, 0.1741858863181645, 0.15858049143946942, 0.07503864926195915, 0.16501057382312515, 0.1264891142566358, 0.17595731142547824, 0.09272634772764099, 0.12043608502755243, 0.1813170004395708, 0.11760214193453712, 0.09779333752850372, 0.2614366972158032, 0.10055346038913536, 0.19004188387865023, 0.10588767697974559, 0.12082574798935845, 0.11186015206359087, 0.11724552034490532, 0.14972036283823753, 0.20093597591884677, 0.07581262023098047, 0.19204149593509015, 0.10630016170081594, 0.12811333556929905, 0.0701729107588049, 0.15722348925567445, 0.15653659950100607, 0.12828756694591817, 0.208503162608512, 0.22795540671194756, 0.17941662741284217, 0.13292874209582806, 0.12267005104090899, 0.19516152690254873, 0.2188865344731077, 0.08752643401103635, 0.14829045972756802, 0.13196112708218638, 0.1695904619390926, 0.14864302871208038, 0.11329337999585176, 0.10920520541408371, 0.16514335218216145, 0.12426604967444174, 0.157314975475592, 0.08408947246930293, 0.09113028780707429, 0.15770050156260693, 0.12293438967918197, 0.11897077333302268, 0.07999757470022287, 0.09567466774775137, 0.09070824230870894, 0.17778763337241066, 0.0631288855126308, 0.09828947905090549, 0.11543716213876203, 0.12364916503429414, 0.15655909184246294, 0.2466131716726288, 0.15068309021092233, 0.22051430277286038, 0.12003580408711588, 0.22095541619966108, 0.08690522863499581, 0.2086885405644294, 0.15081891759989724, 0.1611079380757386, 0.17996943645900298], [0.0305339185175516, 0.06199030265692742, 0.06561809670059912, 0.030044522399323124, 0.045604888545048815, 0.03770487878711955, 0.013171106449238235, 0.07629334040346646, 0.019631081583699393, 0.04918270301254046, 0.042220653004703984, 0.025981730225706295, 0.06643491496722545, 0.06342892767861485, 0.0408434069475099, 0.10653552689379263, 0.07282332982867956, 0.043350521610268665, 0.019987147759586092, 0.07098830410189207, 0.00650280567389282, 0.02191059535459405, 0.08003869829999824, 0.03607186661552518, 0.011359250094110688, 0.038629872499093894, 0.009089957851345741, 0.04976146711757587, 0.03966973343443486, 0.05446136673732151, 0.0049657244685917135, 0.05880878547266607, 0.03561261222667752, 0.008583590970374644, 0.09667019900535384, 0.056226437145303336, 0.07088636078180806, 0.01272338742931043, 0.0276087362679743, 0.02252725974446343, 0.014558823970747332, 0.03463143362633644, 0.08977333158855477, 0.03501563438124234, 0.03706241064074059, 0.016149447539881352, 0.03218531488410888, 0.03322714083497563, 0.04785510328327937, 0.057704259055636586, 0.04455208072378751, 0.029777395201005766, 0.013846259736906619, 0.02231055070766278, 0.05242189512618127, 0.054630089941765034, 0.060730187612916195, 0.07627945122939926, 0.08556382400133918, 0.03459667238677221, 0.03834694856777787, 0.049944336135541244, 0.08863336211370845, 0.047536311115348534, 0.06598131430725898, 0.10397620333899414, 0.02871819820645596, 0.08223661221563816, 0.08528573408482537, 0.02570678126968203, 0.027712703975398215, 0.0507917289712256, 0.0658569858980275, 0.018388536766231544, 0.013546886940246389, 0.04675584755116894, 0.0036406463656138872, 0.023717902105061278, 0.028811139993429668, 0.05073665491034908, 0.019138988835977453, 0.026266642155185826, 0.06074660487713353, 0.05782158542124014, 0.027437002337988348, 0.018521803506319563, 0.020991944850632743, 0.07673479856983309, 0.01381957689450393, 0.01925509520656159, 0.01075346032232647, 0.017325017120568983, 0.018770971688471975, 0.06389446398844162, 0.01640045433305204, 0.09025808904440173, 0.029165651010830077, 0.08811161793287724, 0.023143006744043484, 0.013353098296530306, 0.07160141192857297, 0.0700683014527444, 0.10927981471702938, 0.05186177760122284, 0.026479028540873722, 0.0029938277974349238, 0.08620725358806311, 0.015661004243508702, 0.05079615695942795, 0.07317120269421609, 0.036211126078400886, 0.016959541469752308, 0.06100894785636376, 0.060843580117028576, 0.07557416004278968, 0.020255822455510497, 0.01616659258762675, 0.04075578947160994, 0.017559874780295838, 0.03244489228593246, 0.06829344427152988, 0.015507476393043276, 0.0630780249353378, 0.012385378903408926, 0.030591359790114146, 0.04202225538451345, 0.06569529538072887, 0.03448734014865852, 0.03760877688745818, 0.05566742278695588, 0.011121197847739584, 0.032229265348324855, 0.04516728763138095, 0.06142066265907019, 0.08484104302741828, 0.001728425549733783, 0.03094289264070892, 0.051342136331743775, 0.08761185281459363, 0.02577074578091983, 0.017301285631894585, 0.05703485142740031, 0.056741186943385875, 0.0161396837492864, 0.017550281444264036, 0.10121419590206877, 0.07233109535469164, 0.07155451202584852, 0.05819547463268523, 0.036683009426680305, 0.03686501276529124, 0.06393468743490596, 0.030168285818710446, 0.07149884041639105, 0.04205366115896933, 0.04616735029905554, 0.07072356709789845, 0.09860051074816335, 0.0329041428443405, 0.053347861769819455, 0.043104266477448326, 0.04561890795406315, 0.050663294330719984, 0.0855039082647812, 0.0233522464235824, 0.06494764719278583, 0.06976189692654917, 0.032771153811125026, 0.049546464541626555, 0.04916643130502874, 0.016875944040235014, 0.029352641581828078, 0.08517573918065718, 0.052258166815004045, 0.056666899397368395, 0.03865851652658275, 0.052371773823735215, 0.08680512392593008, 0.04240194388154534, 0.036228972096597, 0.032471188253933386, 0.011223906298137961, 0.008907647119955191, 0.010102646605622385, 0.04637635057611812, 0.03578095621759853, 0.08127424490427779, 0.08395116295545332, 0.05996961552169054, 0.03923015601392235, 0.026280173183148427, 0.0376005107987552, 0.07139756359280118, 0.015365127680612909, 0.04129079463441045, 0.02971614072580011, 0.04642389016225935, 0.036181650845514196, 0.010115865452755845, 0.026815318156995123, 0.052607349690891085, 0.035532506242875135, 0.017183101247815837, 0.06715891402094595, 0.03472841652711073, 0.04518562011540898, 0.058462410309021516, 0.08416585909623293, 0.03932992747474102, 0.03401719965040684, 0.043726364345920664, 0.03118334274228302, 0.006594732873171809, 0.03796519546379005, 0.026506896904339234, 0.03094582101179948, 0.01489611907726935, 0.027379660656855955, 0.055808306356231054, 0.0598063851676641, 0.0015676738492461043, 0.09230244829649888, 0.018969782996141625, 0.012775425866786993, 0.026407100545663028, 0.05096580713025985, 0.016042998665192678, 0.009708255923713648, 0.021379014604815075, 0.022660482434495803, 0.019109982831944382, 0.08829818332507726, 0.07976423964024552, 0.04282940945197498, 0.020101957526358388, 0.07087084750134139, 0.06453058892680753, 0.0767821581253121, 0.06732260402772697, 0.0510798929439437, 0.012740510452028005, 0.04923585036228742, 0.0546674175758756, 0.019606524635286584, 0.06281519549027567, 0.05623943765737838, 0.028173934871090517, 0.015891830365534033, 0.05584685590058085, 0.040393606083647865, 0.045000885673347986, 0.054345051607778, 0.05091453669592739, 0.04428528294327759, 0.007521334890982197, 0.012503992296725273, 0.023840347853218837, 0.02984746734821989, 0.0494817913990588, 0.047801691633198536, 0.06261681702228324, 0.023050030483113184, 0.044810397910975644, 0.06300773636828508, 0.0416656069818043, 0.04368462787580587, 0.03144181314705601, 0.04874969096553903, 0.07201320717051145, 0.027268145068158067, 0.041815028600995584, 0.03779284866346467, 0.020794826597275756, 0.025058787714149204, 0.026352796403150407, 0.02588551915851572, 0.09297361026608175, 0.013910399490757095, 0.032143766105535536, 0.026328040271877285, 0.016562654298820322, 0.014920199135949296, 0.022906668619402958, 0.03661095502696211, 0.00535353972208536, 0.046773394795074585, 0.019670830055650686, 0.009313126924567887, 0.02929973938021689, 0.009224544177883336, 0.06573264216703754, 0.01704263519645939, 0.046027868670681794, 0.02870839994190441, 0.036067063244239944, 0.03160341173380373, 0.09115914633918194, 0.02402485821456198, 0.08084801656584586, 0.02798539105682604, 0.027156323044290467, 0.02954818743972048, 0.038877437642264756, 0.015484425765011581, 0.0307981901231312, 0.07448775543560905, 0.03147395053547958, 0.045287961801213604, 0.06746346461436442, 0.0690852957327039, 0.07489909102479297, 0.007962999422283424, 0.021589280842172525, 0.0190443386729326, 0.049006495129076705, 0.03427237970754504, 0.04325993937410174, 0.05436986136520582, 0.03681369253524369, 0.024161987953008186, 0.00739206712985892, 0.02256235614749453, 0.024307939193902478, 0.040329687537685524, 0.029414750245069305, 0.051801727799278115, 0.024091389120346116, 0.06095665086421275, 0.026503257986698902, 0.04329843912273646, 0.01575099467675412, 0.010887429948085019, 0.07037986175067003, 0.033468561952993754, 0.0451386972300468, 0.027565561467781666, 0.045381240666874, 0.03917853700958433, 0.034095501497147546, 0.053949240790379625, 0.07714424958272327, 0.05603918993485071, 0.09393267573848849, 0.038938617423897794, 0.08840640856614036, 0.04900930284131919, 0.020057593374663306, 0.017193945222384027, 0.08496269778979403, 0.01554641281179483, 0.02170010120607913, 0.01990511697987395, 0.13373932440675076, 0.16220555821013066, 0.12787009499246074, 0.1521848830124063, 0.12223514292629496, 0.21840613605754994, 0.15072534762082562, 0.1728551915936893, 0.18643558626213383, 0.08810185797272191, 0.17218777579405617, 0.11828339328208279, 0.13813061699751886, 0.13044626482071417, 0.13424452874929677, 0.28371551464642253, 0.14279065323212456, 0.16201840293022896, 0.15876795315454084, 0.10568411975738504, 0.1064688925661387, 0.11604575004668967, 0.12776717107983368, 0.13905773660348308, 0.12488855739995358, 0.16960780616969834, 0.0999403449015752, 0.18945571936426625, 0.09498004050504777, 0.11997989499040189, 0.18099852236768893, 0.2072161348957208, 0.11622339817545108, 0.09188647021449382, 0.09184604375472954, 0.1543465533083485, 0.09834592440916647, 0.21071645190879223, 0.14734477015031924, 0.15132522510905422, 0.10971781016597826, 0.15544267191040903, 0.17065936909808269, 0.21263087498805217, 0.08972872228872392, 0.17792637189549787, 0.12451182600230941, 0.09149417191022828, 0.263315083519105, 0.14560974954116732, 0.11563767033118395, 0.11688769599723241, 0.10718479407049956, 0.08560201348436457, 0.10425043217236958, 0.16694545144996337, 0.12181643757127947, 0.2348398098782186, 0.14862251287746817, 0.1992926866777482, 0.1001506360367902, 0.17231718336622562, 0.15157038856658245, 0.17037430778145793, 0.1199660977468856, 0.2283355701834925, 0.14133421283575798, 0.15134543450849672, 0.16433136026945808, 0.24239610279760054, 0.1307631034644381, 0.17549067194904053, 0.17533184660057868, 0.20008220157075315, 0.16884407779622465, 0.10268106275508482, 0.2125846339209426, 0.10158961728936243, 0.13268826709639642, 0.22950040687236095, 0.1743888230093064, 0.1546870487471742, 0.2905257298581062, 0.16632775475661601, 0.17791385401881513, 0.16982191242277625, 0.2665489551521117, 0.142354718559692, 0.23024660715412712, 0.17709300612970708, 0.12306580440171304, 0.15987658963328408, 0.1908996418839501, 0.16229960316371533, 0.05839422082288131, 0.152246936134273, 0.15025293184143884, 0.22118210161645568, 0.11907600317030184, 0.13263523849027772, 0.2480867264732238, 0.22736758744764715, 0.2131415798418945, 0.14864794699655426, 0.17978664788026966, 0.09763921595989697, 0.09901930037285052, 0.13789712871995666, 0.11484542816516854, 0.14945082246295868, 0.13246680639924543, 0.08576406406298762, 0.23021660715101228, 0.1306401157090741, 0.1048615558313266, 0.0878282266879274, 0.17770920129072282, 0.1507078042073596, 0.15274498521560623, 0.12552700741516967, 0.1521843620726178, 0.1470288967773799, 0.1852229916520657, 0.138381204357551, 0.14030106666107334, 0.17376933367021624, 0.15682624202341805, 0.09134457026037479, 0.15716499078177637, 0.13823371711036853, 0.049840485256525784, 0.14026892161177051, 0.14987347317078423, 0.1283948728814721, 0.1448289986940161, 0.08862999132684163, 0.16213564502616085, 0.11165550699637783, 0.2205556102337376, 0.18094356322000105, 0.1302311473315762, 0.1982819409139695, 0.13226344069886592, 0.11925993322004234, 0.1444440088685482, 0.20449448497064654, 0.3333924554528729, 0.1529771251784217, 0.17948244968729635, 0.1300973270929629, 0.19858808497027045, 0.11424758847081855, 0.13326010576659633, 0.16037842318896325, 0.0974975279983013, 0.2479637693613768, 0.16899469068213818, 0.12427259972619435, 0.08865810675366272, 0.07926201537972496, 0.11179069853237561, 0.18093789416936137, 0.09923703022181027, 0.20236987800848102, 0.11815680491347468, 0.17151505866598699, 0.15323903531797473, 0.19319556142774322, 0.23670702661958434, 0.13344444184293672, 0.10310410416775173, 0.16289690659651834, 0.1937094072420751, 0.16358929686248302, 0.12368036013457084, 0.21033143143980734], [0.0024991583608601604, 0.02535704681048951, 0.020056061198814742, 0.061234258145334265, 0.04800699170558684, 0.05049666254630974, 0.0421509811384303, 0.03826623737451531, 0.020655683962808504, 0.029550372705524488, 0.013549826802655816, 0.029187394501340967, 0.028873579989698146, 0.02701003855514911, 0.010218176495043502, 0.06570050477861397, 0.04499798603055458, 0.06618359982366524, 0.009171249356210954, 0.04821748202366214, 0.04064395595642348, 0.02862303284928203, 0.0841725470438119, 0.040421985810802835, 0.01687796076669568, 0.03407935619414334, 0.061937963529940576, 0.08385295814443981, 0.03481342164318889, 0.009552661551072473, 0.029145433950508316, 0.01887513091787696, 0.008280531375578815, 0.07221449677261614, 0.017620355506697973, 0.07286983902656263, 0.0396193056968191, 0.06166948418643686, 0.0520038217937033, 0.0952671166329134, 0.04747454910689304, 0.02796331814850771, 0.02493185269075536, 0.022358149665618138, 0.048237626305631096, 0.031179646368048368, 0.015692125607822693, 0.0718348159364635, 0.0679770959240775, 0.04628078493800375, 0.03122732385001596, 0.03448442901454626, 0.06816936867131342, 0.0425090697864371, 0.0192165820513882, 0.01720941062235544, 0.01189857216236452, 0.030538660601802894, 0.04649363097644622, 0.02414741887590818, 0.015453506456387621, 0.08206559840830104, 0.11370727431870277, 0.08076985261493153, 0.0288232441826333, 0.02689056331291795, 0.07449586830672718, 0.040661564487363064, 0.024434719084491654, 0.05619824894012944, 0.04851052980689753, 0.03247757742722188, 0.047065304937742414, 0.055936131956836874, 0.013034018845627866, 0.020714111573573564, 0.05933617189105961, 0.011470758021929333, 0.02776698896571273, 0.003366694520903571, 0.01551262258867463, 0.058208000170247215, 0.06772430989170267, 0.024381889661233273, 0.036784807190058694, 0.05279736247875037, 0.06959107464119312, 0.045217248055362896, 0.0050725592600722475, 0.03171916187350308, 0.032990048113729686, 0.02792057044233286, 0.04097650323303477, 0.05275016763217507, 0.016628263983875513, 0.01980506589696292, 0.02348128244310858, 0.02277070333460166, 0.020005453430536776, 0.03515310885925447, 0.03259252508982055, 0.030687902190331972, 0.026400343650170875, 0.06284022358276191, 0.06266819853936473, 0.11710515005453942, 0.014727561539339443, 0.043296543055123864, 0.04524344826237329, 0.022435635628719485, 0.07409305927614052, 0.043804344435733174, 0.05481570921537857, 0.02226534960491042, 0.008184143150555752, 0.03382397695414482, 0.016275974621455518, 0.05514400853444973, 0.02771877522219814, 0.014358733296244135, 0.047265782486647374, 0.014312856120898599, 0.04333247640921224, 0.026045819226231788, 0.03460802197937043, 0.020008538849651814, 0.01663835910749772, 0.03853275170249324, 0.059766303447465745, 0.08259248303910417, 0.02338456767310779, 0.025053001835101077, 0.04497186243233662, 0.0986707839934576, 0.017687690804802605, 0.042407180092507796, 0.03324363853842501, 0.014021590449697068, 0.0056332475205342625, 0.030240859242997346, 0.0405276638095177, 0.013552335740607834, 0.023270702109702175, 0.03608573280695466, 0.023365482507694154, 0.015636186825201636, 0.034425938201527444, 0.04152140625181698, 0.014603029159198125, 0.03729798650789646, 0.05912005082674085, 0.10195115716346811, 0.05430121222631105, 0.04846980457284278, 0.021891429749948364, 0.030009791803275867, 0.04881769659057741, 0.023247815232964295, 0.03449408172239219, 0.016235362385369597, 0.02157362008978042, 0.09139734605747847, 0.03867845013437252, 0.04188179316359662, 0.05377511666606992, 0.009638114828586338, 0.07288156017180412, 0.02667128788157096, 0.019302914414795178, 0.03079870531726028, 0.08314743713145295, 0.0658536917199531, 0.037429857052742474, 0.021624982454663804, 0.049286615178589864, 0.011519380664873508, 0.027555090961076563, 0.04210578195089775, 0.008164147298122126, 0.02153824597987677, 0.03160909227576227, 0.05552060969714677, 0.069397691066467, 0.02130591257986042, 0.027588220433362072, 0.05470544234999726, 0.013887288533301364, 0.023583401963415167, 0.01685676502905065, 0.0778153655870307, 0.08031697207761389, 0.04278881062242774, 0.0343968115386463, 0.03188772611470232, 0.00612105687914957, 0.0576005996986022, 0.042724758011078647, 0.018333125626668334, 0.01194518190928765, 0.03727204677078032, 0.013860716773647697, 0.061019853117965886, 0.046860123608982375, 0.028688334183947697, 0.025729886481478333, 0.03950688612437056, 0.02443019725051859, 0.01948770056779106, 0.033738313002451774, 0.0546605993933495, 0.04507808818391735, 0.058046305822508956, 0.03436818283291594, 0.06763174348781187, 0.030177892561280922, 0.06617203955688784, 0.04745881749136795, 0.038341923030994596, 0.04091448075468502, 0.03504560374084019, 0.008907133841045923, 0.03805748607602812, 0.03876876423976595, 0.030006210342229857, 0.04722010449416215, 0.042520882862229506, 0.037625228625632105, 0.14667248203148767, 0.04598522438637672, 0.0885594193072569, 0.03354671058214961, 0.013633156101399613, 0.032933032019965114, 0.062372963575105515, 0.055436225112287275, 0.03138573742621849, 0.06013089618194969, 0.03809482903189717, 0.0312688343241931, 0.009126124862251023, 0.034721694105575164, 0.05557505556592538, 0.02550964386412694, 0.04765862854377878, 0.017843631832229517, 0.026993113757681944, 0.014236168804458313, 0.02065802244619737, 0.03330251622584558, 0.03746373729119378, 0.062066662470780076, 0.06795354638128512, 0.03909299563195917, 0.03474871402666454, 0.037446507973776716, 0.03437646041293779, 0.05547012450293668, 0.11884542602685191, 0.011623414447380891, 0.06557734848390664, 0.042040652986015045, 0.025432115766189756, 0.10200274552428916, 0.07645234195215088, 0.06902832177377517, 0.0463059930611522, 0.05353470295367222, 0.023247217684383356, 0.025912353303283456, 0.03583652823562584, 0.05084026830210801, 0.0019191455325081705, 0.04102517279886431, 0.014309240185895996, 0.046831682594793464, 0.043854507873015064, 0.06449534122141139, 0.051109031098143715, 0.032500674978138945, 0.029845797276544957, 0.14074052533795758, 0.09056552778929473, 0.03247398064441739, 0.04128335975110531, 0.04354607704426012, 0.04544451186854032, 0.01337644961407228, 0.022151543413318937, 0.07797006172158065, 0.07565840673182281, 0.04423210111957404, 0.016160871826052185, 0.02637032066441832, 0.01724846769995507, 0.027331577148288492, 0.05967654475581743, 0.055303860440730095, 0.0541460334563688, 0.03043701797122917, 0.033255727405870156, 0.04180766266560362, 0.06960848015883277, 0.027128182719611836, 0.028059774363834052, 0.08603394917783239, 0.05738560478353212, 0.0463756304534693, 0.08859042288555254, 0.04894784726803342, 0.05228554296697821, 0.020761394520260153, 0.02325534013160054, 0.032627619577631835, 0.01305403576547941, 0.03829042277028484, 0.10449564159517327, 0.06210972810344351, 0.03262018086388707, 0.01095419068024644, 0.01693510134974795, 0.021548660945207364, 0.07426182078498025, 0.05596742664854373, 0.04714861316906829, 0.021597684826701883, 0.03802234562294137, 0.029926238423814217, 0.06502864566902, 0.02689326568807085, 0.0488331945492856, 0.033761609736229145, 0.0881356271284242, 0.010447657175151812, 0.02486337017598412, 0.05039383056423357, 0.03585682190474003, 0.015056721749715509, 0.026695992301909194, 0.03071236146253444, 0.03241809069990151, 0.05706533023546781, 0.038230752181862636, 0.03640656276876408, 0.04845550937217571, 0.04768412011945921, 0.023615091190403028, 0.05647696321830154, 0.009587911171688428, 0.07663770458630978, 0.01676069568812607, 0.08207336653985324, 0.039505798279518084, 0.07024588829447186, 0.17473255133917256, 0.12172111325086125, 0.21436447067366493, 0.16010990937150296, 0.1946618996800915, 0.12707799838315095, 0.11396089538691506, 0.15233365728730155, 0.11732452699253637, 0.06454807871411886, 0.07954243420352859, 0.15054976026858055, 0.15928230458690276, 0.15272865222106058, 0.11759865623448165, 0.15141652746786996, 0.18130725580117396, 0.12906226569846754, 0.11476350272254598, 0.10274974253749657, 0.11480640364630569, 0.16134697282987256, 0.14623267095415823, 0.14685265058951993, 0.17259118237322377, 0.24281496903108013, 0.23907252226866063, 0.11803047701476083, 0.14278257866540264, 0.14584978020960285, 0.133745989371692, 0.12746553162052748, 0.2045303991725368, 0.1549385554127155, 0.18309041737548767, 0.07934494439752833, 0.25635735041672186, 0.16536714178660225, 0.19766275801004904, 0.17568253100879733, 0.16703931254244622, 0.09724422102613796, 0.09748421339017731, 0.15374410176469436, 0.10145978070795537, 0.08518403591287714, 0.14727733909122406, 0.11755650607688774, 0.09584575050300169, 0.2744915708899498, 0.325445273831006, 0.14224564296103295, 0.13306568797317245, 0.17665892539005126, 0.15648758519561062, 0.10062789349185844, 0.09993064622845381, 0.09273034670660574, 0.13874626057522912, 0.15939855076853307, 0.23938913108600726, 0.2185074128811398, 0.19936434654218538, 0.15217037330712044, 0.12038658808676467, 0.17893000836333922, 0.14571470358679373, 0.07648669333467562, 0.16000281027968855, 0.11603173063767534, 0.16728585495823817, 0.11213771337943693, 0.15053566425077378, 0.16413643685800416, 0.1703796550751694, 0.10394388975034799, 0.24883517905348734, 0.1135398151593343, 0.11055668410394462, 0.09899873091208358, 0.21951722401765086, 0.1095294674497939, 0.09542166721075775, 0.2446311949602058, 0.14881417275436465, 0.2828072101598786, 0.20441858097910884, 0.14576013260070356, 0.06607948847475552, 0.12957479384156967, 0.08419356083557492, 0.14138215461805945, 0.1321340024831795, 0.09886673396273006, 0.17005037516355517, 0.11502049457762512, 0.1949234880627163, 0.18982311981099267, 0.14607114897620294, 0.14838415228070753, 0.10055041902007596, 0.11244243251219874, 0.1950513634590372, 0.16423900070930683, 0.19877412176180273, 0.16372481781628825, 0.07436270690372876, 0.18096285331393444, 0.1813166940044011, 0.1216823032366172, 0.1040878376713203, 0.20355431122645257, 0.1792705497674404, 0.08603727399942376, 0.14024993795300686, 0.10181922916202776, 0.08006030964034219, 0.09306672825327805, 0.1596778204604503, 0.17678545247162544, 0.16744979777403418, 0.18448425306668206, 0.15095725775726382, 0.1273646838061752, 0.2049322429323389, 0.12608929296895383, 0.08882958021375442, 0.12098001511467081, 0.20916880108416083, 0.23076837431759606, 0.15366787601622844, 0.23004374707177763, 0.23784932500172049, 0.07678033483605232, 0.17739924211655894, 0.12665635125050623, 0.1701699002015014, 0.11622125312926308, 0.1720227144898907, 0.12252336052516777, 0.13408916611825267, 0.10842273852998212, 0.14172880940379637, 0.12053322497635119, 0.11774481048867588, 0.16453337765509085, 0.27557815935823227, 0.12762365216809896, 0.14580828888762384, 0.14128945797922152, 0.28974692487428266, 0.13224376756097042, 0.1264244870793435, 0.1395877162295003, 0.13102858357371824, 0.1346266993712033, 0.1980053984950627, 0.09799497187017434, 0.2009977992143362, 0.08977169216039682, 0.1866207650351909, 0.06562352826398227, 0.11371268289944819, 0.14530898342209478, 0.14182787989416432, 0.15774499594924912, 0.1544247095983836, 0.0983116036701587, 0.16116842837823978, 0.16050766222178936, 0.12919771004348032, 0.26547888353947674, 0.15128149681033629, 0.10635611676280537, 0.1574880194159285], [0.059060924160744876, 0.03850803770605595, 0.013093221162806356, 0.029653966945085316, 0.0591807326512231, 0.018881621597815427, 0.051881389452084425, 0.09548662380585748, 0.02941268946855299, 0.03562170952077835, 0.02560998031478976, 0.029954779029433286, 0.02818484013269265, 0.03368407397741272, 0.01393040587689968, 0.05375162457987186, 0.01360728148175704, 0.006528655874482807, 0.057772628572439, 0.02041288005608705, 0.01739624031488934, 0.03805232264341847, 0.0318860043320925, 0.07023840361545164, 0.05828657780864066, 0.009240323673903702, 0.02246198522287511, 0.02226318540652433, 0.10001645573685247, 0.11400270846582229, 0.0305725944664089, 0.0901932243798529, 0.00993524011479871, 0.04031976669906609, 0.019755614921450615, 0.03738376537277814, 0.024154530087065314, 0.04262670641764999, 0.061770278374634446, 0.0504729061597778, 0.03856103183821805, 0.011607668467707211, 0.04893181304777822, 0.10535646395217027, 0.018373216922965743, 0.029631671871268944, 0.014824975364571138, 0.0507597103264303, 0.0185322625217058, 0.02530801143767613, 0.08453457721418912, 0.017538613925177245, 0.057141827945146835, 0.04878119633142506, 0.03365287121625678, 0.05085635997895753, 0.0667093966096159, 0.019781715537030852, 0.044730261283656286, 0.04894861718639732, 0.009057687355145332, 0.022478172660715157, 0.07756320008587453, 0.03822474605253628, 0.05039158209617581, 0.06371723337759895, 0.04777488621672796, 0.05487524956885365, 0.07688335067923031, 0.06525149298531395, 0.026291268051511822, 0.026566879673590584, 0.020131001834787672, 0.03795114158081912, 0.04225654039351691, 0.019352344322889563, 0.05156303778471005, 0.08087727346367414, 0.06058623586150427, 0.08416456440764089, 0.01488174056454051, 0.0675992307163054, 0.05625063786283136, 0.01660014089617518, 0.042658675266730214, 0.017427801222149885, 0.050061827210048516, 0.020735004706488504, 0.021271902106461987, 0.012790088789657721, 0.023633460063607465, 0.01792443878648262, 0.05147300713184861, 0.08251685483921921, 0.06166445098877434, 0.023365396322802674, 0.04962828656237933, 0.037842096625677044, 0.06286997460730134, 0.0499517556970879, 0.11758472875601823, 0.08935902357822464, 0.020649589733370853, 0.027830227608642275, 0.07799025579926469, 0.08358412257005131, 0.04585872411787991, 0.0264464698040918, 0.073562313562199, 0.06207434250222099, 0.017538347709623557, 0.012914840462467363, 0.0753900537928266, 0.04349982448583169, 0.04070841076393281, 0.012957272157373448, 0.007781290548718385, 0.08462662267829142, 0.03044496038778415, 0.043340826767586896, 0.07852159140090789, 0.07682880521902154, 0.03411404848579438, 0.051718691529165355, 0.029288592800918608, 0.020537633644116503, 0.01052128780077422, 0.024297598922144503, 0.01574183322278963, 0.09858456845845907, 0.05993288543616092, 0.047685748056298306, 0.06546328565286053, 0.04363105534726093, 0.027032716672927625, 0.030908554664722858, 0.01789774828320069, 0.04869913682341576, 0.015303131057730606, 0.028238496930909254, 0.03923414350156823, 0.03891581864727121, 0.04334985894421416, 0.06357728826603101, 0.03718901050066756, 0.02355685893205866, 0.04992306953476322, 0.06757794879376888, 0.05000569211739687, 0.02077884025751583, 0.042508977855886185, 0.05883145784478515, 0.050477897222604484, 0.027693247257341302, 0.05673035829057617, 0.030942002063496944, 0.02417751847045316, 0.013031695683997487, 0.04283664132198019, 0.023835010135606415, 0.04825116307925313, 0.025771350990380013, 0.015571460056479181, 0.011569298954019624, 0.04562334743358436, 0.022344298795947147, 0.06418810932025795, 0.04807301699334095, 0.043798633250257665, 0.04094653770387654, 0.03793654377542196, 0.015290882269431268, 0.03742380495814066, 0.03667730973252366, 0.048766970078671174, 0.05098759850126602, 0.05937538410146391, 0.06703611778756303, 0.016781887595331477, 0.014364066225807033, 0.10573998288882357, 0.04806924401031387, 0.008325623310801965, 0.06936087288082608, 0.01324911239451819, 0.04004529271755488, 0.011029146637977853, 0.05961291732326631, 0.04218173573815054, 0.025968051725818266, 0.019611013910522865, 0.07820243917165265, 0.027357754372661153, 0.03515400518212588, 0.005283754379037889, 0.043915940463663115, 0.02045781302806591, 0.027389409125692425, 0.023080608882610838, 0.01449129906588144, 0.03329672460113803, 0.0339019340613196, 0.07955871357191956, 0.017903995730223197, 0.04118898921015282, 0.0640804663060173, 0.023388384706190517, 0.04818213855727546, 0.03955408480138548, 0.04679242058867409, 0.008874498495471575, 0.030623606346066923, 0.02198993333525235, 0.028909302669607347, 0.07319303620005808, 0.03810343986016609, 0.006247074512254086, 0.016656588169655973, 0.039482719880799134, 0.04067716586794104, 0.017395238654928345, 0.06753701671597458, 0.007258379041412546, 0.05806027926624783, 0.033055590766091505, 0.05954719080980267, 0.038504318349183574, 0.059936103005442894, 0.036121976426652366, 0.08126713560834047, 0.013798809208486591, 0.014213172760191224, 0.0777389636383422, 0.057966226651783914, 0.020764027947499868, 0.03259170537574157, 0.049624923436391744, 0.051870285007621975, 0.03600589112348614, 0.04684085649768672, 0.024564299026444077, 0.09000049964074167, 0.046135726189541246, 0.04118741489946842, 0.0052229432772184095, 0.004062869261214209, 0.038088470502125646, 0.016936704388729507, 0.009000373444700194, 0.059179694602085706, 0.019597358393272566, 0.011512072186075873, 0.050087881860353296, 0.05429617902864853, 0.05282915129716839, 0.06540052773010346, 0.04610132501130143, 0.07537332243256031, 0.03836098712899032, 0.01726546144533542, 0.014012189593256242, 0.05981359405503158, 0.059631314924767906, 0.04569915949457115, 0.07348886105201899, 0.05331004383943735, 0.03444424770291775, 0.029711919581337325, 0.07617569994181395, 0.05933835524164381, 0.0381761416041803, 0.01753983775063628, 0.024214451569282723, 0.046022195789602496, 0.04856854564540329, 0.0332039934883435, 0.10724028947973445, 0.04890062177794115, 0.11438790513502975, 0.006854621977019575, 0.045436157679726044, 0.05761604020071607, 0.014197159607353953, 0.0483948007346161, 0.009828582481150667, 0.027027495783723654, 0.06568358189636661, 0.00943762961880214, 0.015801458803546286, 0.034716454064173084, 0.015232457531495922, 0.0874512194986305, 0.04362710616401127, 0.0805056671942434, 0.027201334540281567, 0.03253290429711342, 0.01455353509124008, 0.11336629624448477, 0.023398943313006914, 0.023720977948077267, 0.07891467877573545, 0.013995672737608754, 0.04030987650396363, 0.045683883701361, 0.04395263607523615, 0.044633657596404516, 0.014150687756257193, 0.05639593792899002, 0.04453946708611423, 0.012934048201948887, 0.03323414670904318, 0.029631589516817086, 0.06668776994751346, 0.04759447634099953, 0.01334170752670616, 0.019287527538836002, 0.03382400759766179, 0.12466198689634762, 0.08039872132001386, 0.03943277860901529, 0.02126926101834303, 0.01868895623051832, 0.013690220075659456, 0.07390603423118591, 0.09862635855472858, 0.028442741717181863, 0.09962324578795703, 0.028410198302158428, 0.028731675608263865, 0.015116515869815505, 0.037804416591121305, 0.10379601179832414, 0.058646305884805426, 0.02714217914598844, 0.024107113074991974, 0.07593212228628897, 0.05420648928491339, 0.04037657594909111, 0.02438972865591847, 0.03124786266726592, 0.013832288208387554, 0.03410112841295139, 0.008839120555128302, 0.023286667382044178, 0.025727417763142336, 0.05746761832626597, 0.026546384906396273, 0.029502949947791717, 0.04617402675531564, 0.044230568943725485, 0.024386995637248603, 0.05571301267932981, 0.13278939070240145, 0.16566623783399984, 0.14178292585476754, 0.1777976231589433, 0.1830412958177828, 0.09988219116724308, 0.14928180814510392, 0.16213699334090756, 0.05732538644224406, 0.066370441007518, 0.1262560932927074, 0.19307572995462727, 0.15379031218828695, 0.11341021606518377, 0.062243130824138085, 0.31166224890658933, 0.13893393679491936, 0.09542179744570486, 0.14258773186274115, 0.1355483184658712, 0.12189079406521014, 0.09339593155609985, 0.13469359416875148, 0.10477199249209897, 0.16754797960240997, 0.08871186314330948, 0.13785122473153377, 0.14444725708134715, 0.17846863957182055, 0.15022268669018823, 0.15333937751429697, 0.10618268211762752, 0.18284643369336284, 0.179292245377456, 0.18088806781076616, 0.11787386566040017, 0.13729660771787167, 0.19020009635677262, 0.32749848139862864, 0.17699304697734697, 0.12898636170692984, 0.16834547713158593, 0.2717181180994357, 0.23165495255060736, 0.1376763881454545, 0.11838857715408649, 0.1118262220294245, 0.18586973839950177, 0.13784825231038755, 0.17546477817719983, 0.21418070150238855, 0.13056361416895546, 0.16332472073695353, 0.2772320206126859, 0.1141373330967561, 0.13200364496198394, 0.16602000191567406, 0.16781247911914704, 0.08563449561235406, 0.14347634788963104, 0.19102088295884673, 0.14200000452899164, 0.2162909060115776, 0.12623763823461148, 0.20903455183630992, 0.13399466151191344, 0.24138442240655425, 0.10379924468936459, 0.12212952238417442, 0.15603651262579427, 0.0962604875225694, 0.10205713010603383, 0.10017242357735673, 0.1869028998959449, 0.18252689842014544, 0.09055275710359698, 0.10954958491868551, 0.18022607591363693, 0.12894611144738813, 0.1886057141687601, 0.1010017597206658, 0.2351286250256723, 0.15369499552874796, 0.09260362044217126, 0.11318404392729844, 0.12539268155852634, 0.14449043379675958, 0.158632570096562, 0.15355204352207724, 0.1543231416613825, 0.3451599949790586, 0.200299019775083, 0.14655281909771506, 0.2117112324002289, 0.13804489175879187, 0.18289950826475698, 0.10407293726119304, 0.14987874385570327, 0.1598958490837005, 0.16100566533784713, 0.29312834504150576, 0.15382694651282605, 0.1665083523238859, 0.13456286892535227, 0.21009124755378694, 0.1404612403242819, 0.14520275767051405, 0.1883872412145138, 0.08755048151097952, 0.12735846317223004, 0.14959674689077562, 0.13714441669083413, 0.21121181968239047, 0.11173471282686918, 0.14814747707738032, 0.22069675427290703, 0.10651536345962556, 0.23853174080291104, 0.14658206833466408, 0.20278739592721387, 0.11635802280638488, 0.18840876828518607, 0.11725647540222253, 0.14444275248435237, 0.16899803082548803, 0.08221668626872763, 0.11138501667207289, 0.1762103349451096, 0.11381649547406744, 0.13948475401247704, 0.14917371313898795, 0.18023742933667478, 0.17615821032274157, 0.08590828777561266, 0.12911575395734082, 0.13163386964269225, 0.12254393764681394, 0.13384662268142547, 0.11943801035804134, 0.0762039685862199, 0.10998683726234783, 0.14759204801051848, 0.2765022146124994, 0.1459464145403716, 0.23811811461083351, 0.13335496277338074, 0.14588482107125944, 0.21485568625071358, 0.16792768342120035, 0.12550699719858746, 0.21378503241125615, 0.13981225660010693, 0.19150986155915647, 0.0820002128039637, 0.1861663676437832, 0.2265008508918747, 0.16605881192991812, 0.0963612127628538, 0.0686174075329496, 0.15692275378011888, 0.10281106787583522, 0.13210394119303073, 0.11131521840129169, 0.1434324204080528, 0.1330676338365001, 0.1408070370915436, 0.16853116152267303, 0.18602785894707327, 0.11744744579998717, 0.1697063250767608, 0.0974136796749888, 0.09853202248773268, 0.13921438626223995, 0.13171795545326126, 0.08955034637643446, 0.07786601165970487], [0.031813404094728256, 0.020187416549531684, 0.046002070659831654, 0.0277823394524955, 0.025339771527796987, 0.03877839396497415, 0.012844598818299992, 0.026948847282197208, 0.052062029154190136, 0.04558432674516113, 0.027944738601124095, 0.04307880937572449, 0.05917710522490163, 0.06704512698155257, 0.016166274661138173, 0.04428729775451845, 0.05883066494378352, 0.02735293759483724, 0.05375384240441265, 0.03924309140852383, 0.04920843207547742, 0.026190485354633104, 0.059167272486393495, 0.027590218007624633, 0.01493153053395931, 0.028537336338852203, 0.0664688373405126, 0.0221930768701338, 0.013670957752413327, 0.021245977691104336, 0.017750144207609758, 0.05488538108165226, 0.038507344396484476, 0.02738869091826341, 0.06791403156615074, 0.07410064354659089, 0.004778605577866397, 0.040380234018929546, 0.010643398385464905, 0.04091704714923136, 0.03400171701345713, 0.0144377255797266, 0.045879519574584506, 0.07274973942267318, 0.01572686194952938, 0.05482935707174963, 0.02875207078402802, 0.037996528459893125, 0.02266656325739478, 0.056957204585834864, 0.03648023361400251, 0.03498190736037589, 0.04489621891069316, 0.011924842274898003, 0.016623161838299805, 0.044315807716620546, 0.01928140075066157, 0.01282207104527662, 0.02344899758275959, 0.043057397218240846, 0.046956030156223044, 0.03244070944586589, 0.04890017744694506, 0.06135752935323024, 0.03463927453624145, 0.019957856387801228, 0.01233686351277415, 0.03126816782769898, 0.02861535664828074, 0.030992085061546777, 0.04126143814515203, 0.06129358016375092, 0.03498377661491114, 0.060863019598107186, 0.0625470302428209, 0.10746871391611715, 0.050285103535580064, 0.06627120963868595, 0.04250504782483463, 0.04206496478629209, 0.09078874282779233, 0.08642460805393996, 0.013930782217592483, 0.040977502977775956, 0.07253337321021865, 0.02424222034131808, 0.06221358664333821, 0.029384947509594986, 0.05157239171826551, 0.054192910376455516, 0.023547589268174865, 0.029020686108138294, 0.012731968571672277, 0.04392232963695161, 0.07335039832058453, 0.07188535475682828, 0.02213232609773836, 0.038258844626046, 0.01587415288668126, 0.039924201029803486, 0.04577285715288693, 0.05542843782853696, 0.03447171961588245, 0.1030605367474979, 0.020973721534133922, 0.01507583277059659, 0.009501471555972052, 0.029159070315560507, 0.009639983125511677, 0.03319380834939019, 0.020538817249959516, 0.03079127809483438, 0.04386656992738286, 0.01077229172111519, 0.047182194633229126, 0.02403927598929694, 0.017875175502511765, 0.06447980495830698, 0.05628420783567333, 0.013527306690511685, 0.08646692675087722, 0.062572353279158, 0.05186691422075514, 0.04025566429200192, 0.029481311794370416, 0.05162865704586429, 0.04831748331085809, 0.056714948431979266, 0.04442736160971465, 0.037444148422969926, 0.019680685776796554, 0.0072199276520780505, 0.08102048594023913, 0.02462153537048688, 0.039214382263561415, 0.022911766934539043, 0.10989612479123378, 0.06341782323415242, 0.17163861332641495, 0.06946974163574558, 0.03882246700325801, 0.057033583551885626, 0.08031046799113674, 0.027142981623089122, 0.030293744207630237, 0.04609765928058375, 0.03360268096589754, 0.01976294063722655, 0.009136097411805344, 0.0828806316900638, 0.028104297478773424, 0.006052384757617068, 0.04363072592945349, 0.024514947642361926, 0.054760447462960604, 0.09338751991069125, 0.02374456771048567, 0.023764620061903715, 0.06642923059482729, 0.010066406816364297, 0.0742449132244914, 0.017362888677105788, 0.11596754013049988, 0.017474994153505372, 0.033174460798862486, 0.025000938499766975, 0.08580409981791051, 0.05988005984334215, 0.07003876876326338, 0.030207540163950577, 0.012455016295726021, 0.04770319953921342, 0.06349624382452139, 0.008658658968464983, 0.02903299331064186, 0.12387418804029304, 0.016049667460573538, 0.054098850101112365, 0.041625349061383356, 0.031009946401501377, 0.050958150081456675, 0.026691652413818146, 0.04076218247533806, 0.02621069475407562, 0.04196915400004195, 0.047594518475835366, 0.005301941785165259, 0.022787128259698232, 0.0394201266669458, 0.01396086361754926, 0.03630975606821237, 0.017933141545302445, 0.0406389304196402, 0.033636354360609286, 0.01978337603260673, 0.04367137838515543, 0.021990144009431525, 0.01071277051983822, 0.055261534082913594, 0.025650713209723754, 0.047793942653844436, 0.028774091981411464, 0.07839432887492642, 0.031094746589059793, 0.07442959404039769, 0.012907693819743733, 0.026000028235777736, 0.09735630735033944, 0.04708122807524858, 0.07453680804540073, 0.07472538058796237, 0.1141804102207384, 0.0336124102825359, 0.02055442437619692, 0.04195923699186214, 0.06835651629033589, 0.047952143640647975, 0.028769112409903642, 0.013047818004363968, 0.031077134227680586, 0.04561339212100833, 0.04236623652339463, 0.044246377168043007, 0.04908646321705273, 0.013340331441272172, 0.036525448123293544, 0.01663614511339655, 0.07244105195446361, 0.05988955550316361, 0.04571308697303457, 0.03057421665758856, 0.04670021424610769, 0.04610901653406121, 0.03802015078103831, 0.033365446518385605, 0.035348277418844165, 0.0676812557503581, 0.02519630624221698, 0.04367232450374192, 0.06606192973953101, 0.024692201235842322, 0.07323828135286609, 0.029562342829341372, 0.0190570997825313, 0.02688392516105406, 0.03829101648842616, 0.07596137918411724, 0.022089647339476694, 0.028093535858657093, 0.018978474263642586, 0.08104287869026584, 0.04716954652159926, 0.028096000746553464, 0.08155375208345153, 0.05760267962731662, 0.0424676742254486, 0.046360710891143936, 0.042209835843213146, 0.05083441155992689, 0.06378927245555867, 0.06426923037056001, 0.05495073604247263, 0.01767454665124176, 0.08114712793500194, 0.058916168017012466, 0.06967331417986462, 0.014760654622448549, 0.046383877389974175, 0.04961395305731604, 0.017706375689275803, 0.04322925755273431, 0.05036630885555379, 0.04653780360616023, 0.05415629520411453, 0.04740431033555539, 0.023572280281974424, 0.006080539925249234, 0.04509598016738892, 0.06091065494523895, 0.014955773386323165, 0.012670011210796094, 0.049191348314765966, 0.02239287643122577, 0.04858002547294863, 0.07642244154046621, 0.09400857973002619, 0.020851632016861153, 0.04967042139821476, 0.05970407412537645, 0.026760121522050713, 0.026545230028850418, 0.02996975413313316, 0.03344495878404668, 0.03141726385952244, 0.026712164417990757, 0.0068328976387067916, 0.05517826798642355, 0.033346907190618016, 0.07744572050268612, 0.03565791483607984, 0.0043796279445110315, 0.03465379573284619, 0.016951610544516195, 0.02316752347284027, 0.0712756866649274, 0.037138502323819746, 0.03504589485425142, 0.03389313554150924, 0.057519746779073636, 0.03539667502346058, 0.08043685717688454, 0.029130167733397216, 0.0056288573579231825, 0.025638337059307004, 0.02390639803883049, 0.03604357115804188, 0.04388122135893472, 0.015955161896624392, 0.04467765785633557, 0.034759715049257206, 0.027947626752598632, 0.020845689089788545, 0.02895763707197001, 0.023144621274343902, 0.03654600992318123, 0.05099894809386423, 0.015973634191698605, 0.009633279856174223, 0.03415870375090069, 0.025791566135481964, 0.03315545415746109, 0.02061071460165324, 0.039858803934147286, 0.025406120487699108, 0.0361275305641034, 0.037329154795095805, 0.05780260176247647, 0.05160941674764599, 0.022909794258134022, 0.03949067953433241, 0.028684203054816015, 0.06406865706066452, 0.04464043364409478, 0.04208024057950224, 0.03948638944195644, 0.01695411373680878, 0.07157695840202993, 0.02864912388876321, 0.04986864664862233, 0.012937280135379444, 0.009008158813230693, 0.06677590070232269, 0.09663487469116527, 0.183569191684646, 0.08465409459125611, 0.10585536339109945, 0.13488267999022238, 0.12564405798912048, 0.1420112506997201, 0.12913849144693346, 0.1600186223344457, 0.155862212301262, 0.06500979224520345, 0.14330577075241074, 0.2807247073900315, 0.1536117064496202, 0.10418398936669673, 0.07053686380987206, 0.09305237176557703, 0.11414938365980504, 0.12069106973226994, 0.11540068103180778, 0.10157158357962486, 0.13145435992027485, 0.144915352124841, 0.1455981509699937, 0.13426052466515573, 0.11717013729315613, 0.21158614556395242, 0.12591834810952987, 0.15877049656644945, 0.11030801196372318, 0.15486208451611383, 0.17382663704695242, 0.18873139855361756, 0.15357977590493618, 0.1492608633012541, 0.17333782698598602, 0.10984160997454198, 0.09770551320886421, 0.08775276702738578, 0.16034624749614348, 0.0910432372362383, 0.09722814850148656, 0.09798883550590086, 0.16396403643152407, 0.12563592213536465, 0.1440305971810895, 0.15277789635283334, 0.17960120863731832, 0.09553806660997291, 0.15585617552841866, 0.16022520560410716, 0.21468451156491236, 0.18888345168482876, 0.08295298869451208, 0.08009210228919983, 0.15274048061861148, 0.11601624800072563, 0.07599057479491157, 0.13405666866850469, 0.16044988387054013, 0.3020712264603184, 0.10511187506058525, 0.15913838730944743, 0.20634172213894708, 0.16969463457503628, 0.16945746907543752, 0.12111450184977825, 0.09368126866437736, 0.10422622379396232, 0.12643127461835263, 0.13727771598965893, 0.13207101473404517, 0.1359698353635688, 0.23201401796071763, 0.2850864136651639, 0.20260204861481346, 0.13708070881905096, 0.13168155095509945, 0.12278524768208304, 0.11145998603634297, 0.2203402169529469, 0.14395959615226717, 0.1639347412292996, 0.17728212259469495, 0.15566768725552868, 0.19242332947831, 0.11101544819652073, 0.15914014931167328, 0.1713706664140186, 0.1292365047359659, 0.1242112590660972, 0.1709961107060794, 0.15559774342804186, 0.11952089341056925, 0.1553267474857069, 0.18183847648962853, 0.1585581676373559, 0.14699212455701444, 0.09171353352646675, 0.14182335997541107, 0.3041759764234866, 0.1619783212100306, 0.15663661994040012, 0.18743330853119974, 0.05502660172961413, 0.08334029976639055, 0.0643737860504658, 0.11114491705572414, 0.15231352449665148, 0.24051230791355335, 0.11414398273993885, 0.14599450954025792, 0.1116784283470723, 0.08135985522981613, 0.1383210511337365, 0.12364885093824518, 0.13806320126018218, 0.18541247583925727, 0.15793264152542238, 0.11913292350307589, 0.16696676401601684, 0.13873875291357118, 0.13021665294804882, 0.10746777162797029, 0.13504040217207325, 0.18955615349113944, 0.13964187864574695, 0.16301154399350767, 0.24775222184196596, 0.08254552951022502, 0.1056466733796462, 0.11770722621511068, 0.20710181925565968, 0.16402005278054746, 0.22047569194147665, 0.14218683805196516, 0.18239179115381934, 0.2738737363007761, 0.22363120810158793, 0.1338494725285038, 0.17360520699331838, 0.22060283189339025, 0.14985084293350098, 0.0962917515707593, 0.06754080885119977, 0.15110178790505857, 0.10776800914637505, 0.11695943247046202, 0.18424281279646582, 0.12002889397403887, 0.0835536246097857, 0.19093632217376463, 0.10704524349421264, 0.1170908318712346, 0.14036190936401968, 0.2704314887523651, 0.06883780336788586, 0.12580314380747656, 0.15851754965561052, 0.09638816373602999, 0.16122116587094723, 0.10266992383666577, 0.1380976752167748, 0.12666472459151862, 0.12646106011684866, 0.18021512085631972, 0.23396460039000358, 0.12659497228601288, 0.14513877400707814, 0.15103109331140596, 0.09385089585257154, 0.10448739082822878, 0.12488404514207957, 0.07119645019091907, 0.12495146854029548, 0.22430063105158268], [0.032246969640254974, 0.01655355317427987, 0.01833608272605606, 0.07327322262309252, 0.03705240936288911, 0.009637775834679846, 0.03012429130443883, 0.048804094699481805, 0.03302495490999953, 0.05108491081984774, 0.020973507029515122, 0.03638683600471385, 0.04964212211029184, 0.11290377066020044, 0.017658767155221394, 0.008227423287837977, 0.021537552670305295, 0.022584551629880746, 0.026817210394168095, 0.02542956660862171, 0.04528577462018979, 0.018906538607552648, 0.03259853888002615, 0.04108254129307405, 0.10114144053189986, 0.008156590798359004, 0.006890160795826946, 0.07679987773900071, 0.04844890952470803, 0.09040776730304764, 0.049375466056047916, 0.012317125257405062, 0.02594721987993727, 0.020952588998742645, 0.0475805641842946, 0.04471656363157015, 0.04306509640187987, 0.054225262269497886, 0.01395487664042101, 0.010583059385328764, 0.03265422964168172, 0.09951109817672162, 0.1421699994393895, 0.015811881429756123, 0.03026790789238388, 0.01584383495707786, 0.028698948332138603, 0.02350495839040847, 0.008269722832577124, 0.029884632188646548, 0.026027099867801995, 0.045919045881037755, 0.05297555452993801, 0.06251450214955596, 0.0258076444057928, 0.016149367100649303, 0.04503951948736945, 0.05453548957443526, 0.07604805437187034, 0.06281179022945224, 0.04371689932961618, 0.038842170784670504, 0.008786640659485374, 0.02423146446686118, 0.026706363217184143, 0.03508666605358163, 0.016754810217647784, 0.0469953955842122, 0.028162372689093315, 0.05158657583618357, 0.03990130266174674, 0.04106856018845593, 0.03330423992367522, 0.12514152729343023, 0.03809454174892556, 0.06938632232167068, 0.026983279103953994, 0.018116418505087495, 0.042250518942432064, 0.0030467807523710958, 0.03947726533477826, 0.029021289402378664, 0.02434383041315502, 0.049465933379026196, 0.07988524322788562, 0.03584390183189704, 0.02799604733985278, 0.031053668954559875, 0.03162128456507719, 0.0444422428676438, 0.010967914187800019, 0.01464833655664998, 0.054823036846374316, 0.030755775665203412, 0.06749770108370051, 0.03745937059002538, 0.09301451936123833, 0.03778039207381587, 0.034335578130858566, 0.011278739041318337, 0.07755932368097768, 0.03426675662218082, 0.04068506423444037, 0.0892629255090029, 0.036537973660855524, 0.03803044700274064, 0.12982957936342687, 0.03591833493462013, 0.024447972405581705, 0.05538596208357523, 0.05033302616568343, 0.04497048347407291, 0.06877067108308116, 0.04590281630836187, 0.04429971987021066, 0.06344229208245393, 0.014933670792097767, 0.021058644295760223, 0.058068353832969745, 0.01109388585562908, 0.05989358512564533, 0.031056415379768422, 0.02638195179432871, 0.14467532145640544, 0.06869438404758131, 0.04012780804787913, 0.05371896242122016, 0.055878805597462965, 0.045228134164766925, 0.025557685237858566, 0.02802491544805948, 0.05857647697050726, 0.029641908721157142, 0.03613253311824895, 0.05018394162517883, 0.08669021073728801, 0.05907204009652619, 0.02224660917906271, 0.03641144274884174, 0.06870885544847097, 0.054939436245589494, 0.03183067746220097, 0.03566068424392612, 0.0633053347137907, 0.012540415947085187, 0.06759992019543726, 0.022409896989683473, 0.030785042139130737, 0.006110040534798417, 0.03516670308947083, 0.04607416336394606, 0.046220830897049564, 0.046573468829475106, 0.053901731847755374, 0.037224970667833285, 0.023865331895649437, 0.03753200338612642, 0.04101513321661661, 0.058635569162546634, 0.015265044996575003, 0.03281128532703846, 0.024049371112919143, 0.08477252412347064, 0.06679307639358506, 0.04796421718633464, 0.036122175609512676, 0.023091814833723252, 0.014332151960491413, 0.05409899565781798, 0.03315235150136775, 0.0177413284508211, 0.009962628715701643, 0.02969162208178351, 0.012352925503716595, 0.023101176428157958, 0.009421623169234204, 0.051420093438918554, 0.030275135931949464, 0.038396974109233394, 0.02598583454176063, 0.040831482788968476, 0.02027511063422407, 0.008468194188730372, 0.07730328177492465, 0.008403133214150947, 0.028368892756501035, 0.06498627334592805, 0.04351750579512408, 0.07924252610293128, 0.10260301371735912, 0.013037404954253186, 0.03947887411941925, 0.02922978980707065, 0.04809727516746329, 0.0378633862090928, 0.05322553668050997, 0.016679452063756126, 0.08147374952151891, 0.07846716085388776, 0.08006241638213396, 0.05709180623413094, 0.035560545060903795, 0.028522531689715483, 0.034388047492792534, 0.021209352942664298, 0.07198587315337313, 0.05088892254617907, 0.02103168374648498, 0.04643246268613204, 0.022582029285390052, 0.029021388993808822, 0.036169106155754104, 0.044332427994137814, 0.054191125391591946, 0.029013477220770814, 0.019661464630776358, 0.0323253825697447, 0.04200809424923312, 0.06966677944987051, 0.03697925179655995, 0.02806475968100131, 0.035472391323456844, 0.04588279077002118, 0.017012349825592774, 0.02109394945775069, 0.0451589219512478, 0.024535459646534537, 0.050262442654779846, 0.023287868224865487, 0.022909340351038886, 0.03684030259929357, 0.035912443718482415, 0.023199159073673432, 0.06966459609928631, 0.05543119191462475, 0.01735256947276573, 0.0642255250544798, 0.08359835648368444, 0.027197113395818782, 0.03176182339478645, 0.056403840125928965, 0.03352218810769339, 0.04647973031106015, 0.08771938091564564, 0.06073895165876997, 0.06368337229134576, 0.03671568307665087, 0.00816934711990818, 0.010595354138903562, 0.06735457287680718, 0.025701261606187593, 0.02065128470290332, 0.004682681314842475, 0.035553742200136185, 0.016693984751679724, 0.018722995432213913, 0.08044804206057903, 0.026296109727193272, 0.043482702420724016, 0.049380054922714356, 0.05024519035472505, 0.03358476216934862, 0.027318067187743805, 0.07758584564491626, 0.04591390926150545, 0.02152017013530337, 0.02285396560065208, 0.05256674703090422, 0.03307476211639662, 0.03550632135762322, 0.02792095731673462, 0.030301929857101173, 0.03330159308989683, 0.056640806442667405, 0.03235678068332134, 0.06268950727497859, 0.03481966909021139, 0.04258350288916019, 0.03519057821963103, 0.14028828831449633, 0.023586675074071656, 0.04157840319338345, 0.025359810472676353, 0.03995743009351915, 0.01639329715661945, 0.02989294041218537, 0.020277847483333562, 0.08135967902959355, 0.024768246953646024, 0.029776353321428743, 0.03654666492835649, 0.026826139148925583, 0.030416929230634725, 0.010414098693628707, 0.028634108565447312, 0.03736807206164926, 0.00465577008247736, 0.022536364699443503, 0.049885129030313224, 0.08776708521069058, 0.06666300998580071, 0.06878967006360331, 0.049129620780267065, 0.05384622111676201, 0.05937344206857586, 0.02488502748160353, 0.053398297168314464, 0.03168590982714969, 0.0331689334744888, 0.06656282100706332, 0.11860367932146597, 0.08013416817712207, 0.04687667493858645, 0.08646299671982566, 0.07554797515753778, 0.012408872904826798, 0.02445712907149667, 0.03518928736147862, 0.04283647661307647, 0.012287326352370363, 0.028664079840264978, 0.024193646536479076, 0.011348187784484078, 0.02286650262953293, 0.026250743915537195, 0.03855077775135156, 0.02907005281397893, 0.04479162875683077, 0.05121857401043658, 0.025908168547997074, 0.03772070616363518, 0.030311291451535882, 0.08827384471172288, 0.04232813897092016, 0.06270136631604645, 0.035872515215868914, 0.011686146514670504, 0.04837503183573004, 0.04947864660812963, 0.017573932493706385, 0.031327074243416714, 0.04701588077530746, 0.05283005145047942, 0.018971311341550563, 0.03405005333103961, 0.029484638531181603, 0.051967317704111345, 0.022155301074587533, 0.08062896138477711, 0.08136477351429001, 0.09359093157634621, 0.03519376514539604, 0.0964622597600664, 0.11478421007913929, 0.09507861303826494, 0.2554003533817107, 0.15432884135553915, 0.1562817986573904, 0.09096069892327632, 0.2155374278945308, 0.12855992652475834, 0.13163261325849643, 0.1473487538075255, 0.13442903336498047, 0.1506874722338492, 0.25116796274819686, 0.14026810955857077, 0.1709404314357427, 0.09388245867505189, 0.1265948880163412, 0.0901961584966029, 0.11177218218724574, 0.10277714550254807, 0.18599649530745324, 0.22792672438006248, 0.1395921135741857, 0.17470103448196767, 0.09094127859439581, 0.07982528918693144, 0.1679029234594876, 0.16186895449796032, 0.19171239988457775, 0.12785979877075843, 0.13760750151930318, 0.18062896155301603, 0.08988815284664593, 0.17380164725886238, 0.12209253565919016, 0.11454180453813846, 0.11194673532079305, 0.12916098378839033, 0.1453363480827501, 0.1282833151579384, 0.14327903428385336, 0.19004134761710323, 0.08567978673043751, 0.08110090218965085, 0.13729550455126072, 0.16466254007912454, 0.16389148790509472, 0.23054862965739545, 0.19954932613238213, 0.15282672679712697, 0.18103792993051393, 0.09724651162903156, 0.1465891776306014, 0.14331874828184807, 0.11251084416383698, 0.136342812930384, 0.17500183124455715, 0.15649705404235473, 0.0947138402731188, 0.15920957219937157, 0.1241726712173512, 0.14265427425984414, 0.10959157419781532, 0.12881408385451765, 0.0907374455803825, 0.13139184714565355, 0.1943707096600725, 0.21459808152529503, 0.16057904629457384, 0.09498449913676708, 0.14682542382469102, 0.0885433467826055, 0.19875846292463042, 0.17342056448180831, 0.17277890455818948, 0.11885033665044654, 0.07999156091001727, 0.09586821220094159, 0.09783814601119488, 0.18366081580038995, 0.10173615458751879, 0.14604517859556984, 0.1089238596238917, 0.15923267741116787, 0.14074172043511946, 0.11410178661706949, 0.19888741084404532, 0.1748272704501306, 0.15084171637652383, 0.10217055708410279, 0.13338894643370183, 0.16744788255422347, 0.1248196401302853, 0.1557383665274228, 0.1403017254966882, 0.1693926733588019, 0.18639954948617568, 0.16858331678855806, 0.10949356090878287, 0.16425473615527153, 0.18231786366912628, 0.12967846085948329, 0.20387436743945847, 0.2533293878960033, 0.13991377857183257, 0.24437231852883295, 0.14780990809442537, 0.18212615782695432, 0.13262039170630519, 0.1284606262080131, 0.18045772558018086, 0.20986975621311896, 0.08319585388826747, 0.16214325994012818, 0.10416993931416543, 0.12726759748353114, 0.10719003411190164, 0.12542248237878084, 0.12581450489139365, 0.11674138852545332, 0.11715122258230565, 0.17351303129426895, 0.24299818661905107, 0.17582358311741583, 0.21696993570414283, 0.14386748174025168, 0.12717872362343535, 0.11735676397239009, 0.14705259953775715, 0.13035992671164776, 0.16496001202012264, 0.07487128969402083, 0.14278913637803448, 0.18719727684172893, 0.16316964921932067, 0.15456982197300081, 0.18155442640906383, 0.13568074442446232, 0.2341912551632812, 0.13104782770237616, 0.19352337045054283, 0.14853274269450098, 0.09299281609034346, 0.10909518752727779, 0.1231603473124485, 0.10553047316329134, 0.11983224686475531, 0.14962389704681214, 0.13096554985930844, 0.19345436125032364, 0.2101700933229539, 0.11082109169013078, 0.12565371835784567, 0.17338229072911127, 0.18040435989537548, 0.150932053464555, 0.20305807011262064, 0.17640717357637423, 0.09111608453695813, 0.15900677340405603, 0.16481333682613988, 0.24801097569927094, 0.120497502296442, 0.15478164528406438, 0.16066495539440265, 0.25230047052666066, 0.11958503795246925, 0.26227620700674675, 0.11232841564642806, 0.1623425500527505, 0.11700178181091625, 0.22210234175285987, 0.11358153630769062, 0.1149320420658877, 0.09633788538555946], [0.05591832041259735, 0.04308006575992031, 0.029788894180749214, 0.034597875144813335, 0.08050571315951886, 0.05462879908361262, 0.02678404070226656, 0.02691044712499265, 0.07994286836155, 0.026278277115535834, 0.0431790902850128, 0.050030249065809676, 0.06586913605250659, 0.04022379886479147, 0.0097246233922159, 0.057369582054595795, 0.0054740290732062874, 0.025529104412623474, 0.01303017499946779, 0.014998731766677192, 0.047636136202321905, 0.03100432523135697, 0.033938518590143615, 0.011222134719813063, 0.04768493983353819, 0.06494855117653647, 0.05807246006424389, 0.052232456904265194, 0.05692479523619818, 0.03792978687992981, 0.07448762520066193, 0.061737704316094044, 0.06081977776522118, 0.06460253990465595, 0.06191958125019747, 0.020672290833787094, 0.020132298438599514, 0.07068309467285872, 0.040030315698635195, 0.029033362948065324, 0.10068912689964618, 0.07981029684625326, 0.07075250223879853, 0.028416325090332862, 0.039067661104303215, 0.040563532046132514, 0.0744991088586469, 0.00975558196284598, 0.07852139221804758, 0.05577039266485841, 0.013092891744998916, 0.054013848815473824, 0.04798331575828695, 0.05599230535388474, 0.057882903098699555, 0.0239712952621161, 0.03353259158170512, 0.034900878240624746, 0.032975078755689245, 0.070960410840569, 0.02537913887100595, 0.06667609476754743, 0.11016225607524957, 0.056053006330565106, 0.05638968282108826, 0.039400480342127626, 0.12792405056496783, 0.009700228279877094, 0.11089797627421157, 0.03806464899812014, 0.05994467169887597, 0.03841881910639425, 0.020655486695168, 0.018889230766123342, 0.04194006947199664, 0.09579727245915322, 0.03325347127693315, 0.03344448763997324, 0.018250539433211088, 0.048721736417182034, 0.07203552331174574, 0.05883309344250349, 0.03362532652493927, 0.06497396231298486, 0.03156604196485733, 0.019376198385631847, 0.018985058789351777, 0.05859204004668902, 0.03253006977179358, 0.06149676966390783, 0.033518775185990723, 0.009558057682889124, 0.029342762878044482, 0.043266860978497614, 0.033100579279444875, 0.055913811985162966, 0.026073838892062346, 0.03098367341613818, 0.05947604039383512, 0.07402964251776857, 0.03571159078649456, 0.021741100316566807, 0.06750318627323836, 0.03383851347250804, 0.05827215620346608, 0.0498854278046037, 0.017670358065515757, 0.040423437547419346, 0.06916912107337868, 0.041863813080013766, 0.018526311933753953, 0.03393920040839622, 0.038376500409457, 0.04957004089749629, 0.04128935055867319, 0.0692610439634131, 0.031206924843812184, 0.017077107237832203, 0.07394727274414993, 0.021915984783141364, 0.04992566657282653, 0.06225667142819974, 0.025911698298108195, 0.03525453123954996, 0.015041746646015635, 0.05872006099971552, 0.03495900899231915, 0.09540236945594512, 0.023567151323321368, 0.012341462913149548, 0.0661676115686855, 0.08334978393489316, 0.04168018180456373, 0.048891792614613815, 0.06658646248040662, 0.04574630454543137, 0.012389049422176135, 0.0393519563330037, 0.0420477852645901, 0.032178607784331806, 0.03243166194748014, 0.043495913606978236, 0.0018222619837615641, 0.051827066157373695, 0.010005485589405703, 0.03834489162170118, 0.10080102936274583, 0.014298059132641122, 0.030983501046355215, 0.0722830693027185, 0.04638742437706359, 0.08306319810329907, 0.04909691265633991, 0.05634896907835238, 0.07368641980593243, 0.0215162017998556, 0.022238502053604014, 0.05644233604412406, 0.008879999006767909, 0.03650655639508078, 0.030180635156049847, 0.04027733691937981, 0.02711611683480442, 0.0514840656110356, 0.03554980067776577, 0.012865076348516009, 0.01253411295868817, 0.028712238042405056, 0.019685052477964954, 0.04645349946053279, 0.1025641730595981, 0.0457940777883895, 0.039527175963045134, 0.08855714402612179, 0.07090315342910829, 0.12114318418166331, 0.025057454721160957, 0.023536253082115325, 0.07761078946773084, 0.01089503815878303, 0.10348789889605776, 0.06821219298628069, 0.006048231603457563, 0.0589824307920231, 0.04525509279882235, 0.10031802624824548, 0.011822944920089458, 0.05012108794143123, 0.02338871986965739, 0.025540360159450964, 0.04800614517843051, 0.026976286636425123, 0.06227697658863279, 0.028001622544721733, 0.017192162152740265, 0.023901845561340455, 0.00624444060620942, 0.01894147221689984, 0.028254287918248487, 0.012101312543475821, 0.09736313319374477, 0.03820331474285453, 0.01221344962100228, 0.07807986510376777, 0.0469712523232785, 0.023811862788974278, 0.02315083616262963, 0.02178202281826206, 0.031821354172162475, 0.09876472169473287, 0.03741280010510837, 0.02521826615256648, 0.056015019860839656, 0.04001408612595932, 0.048748882742778915, 0.05492325263818907, 0.04167139860651186, 0.03436392721449656, 0.0432096763453897, 0.023502414978499857, 0.03430552067114942, 0.056377463718695994, 0.012663864312813649, 0.02678059713704692, 0.017557040254976, 0.03948032585603576, 0.05940100974253109, 0.04347634389095249, 0.03376932041118703, 0.007737229001753393, 0.027173753459787658, 0.01741672359076479, 0.03742131900282637, 0.03213350052735017, 0.11886005064532643, 0.031108304430099747, 0.023438145947312156, 0.03463622550630281, 0.02712062526223881, 0.02372817534412588, 0.04786652182379077, 0.012942437822329662, 0.0634754483678168, 0.027074947269753586, 0.13833693979728606, 0.02965621541314308, 0.03572415845889238, 0.05191915375631183, 0.042267518433471846, 0.04288510404407017, 0.04447584731444236, 0.04441693132262557, 0.04819395929394711, 0.03652858525334347, 0.046072765253484256, 0.05487064921086835, 0.05139578929952076, 0.07363112357955787, 0.008778820816998281, 0.05796618068650846, 0.02063215548743404, 0.02633229014463723, 0.05482279552867817, 0.07192709122694309, 0.07807970422530368, 0.05205648650805797, 0.034572337603857445, 0.013949493915143033, 0.026812020148481094, 0.07556823818313499, 0.020228044107376088, 0.0328796242003239, 0.03455243847002426, 0.015068291592591954, 0.06347361741767776, 0.030195497261780887, 0.039089103905303825, 0.036463827841104045, 0.012285696500311456, 0.052312762070927894, 0.02053642514041595, 0.06723693241515467, 0.018703285905141986, 0.04751701719097553, 0.05682182918873526, 0.04317312246008266, 0.03981717088590226, 0.043051134449459856, 0.026954546976353855, 0.03393825812024936, 0.04995383562580232, 0.07867218896506295, 0.0352403815955885, 0.04071009615736623, 0.04164255922660232, 0.03665813838221854, 0.04629286614456966, 0.100468922586691, 0.013061424683509095, 0.04164873772571164, 0.02809289809046013, 0.0195100435221027, 0.022443196916532134, 0.059849201821752136, 0.025578790960172494, 0.07718356521499735, 0.0020338796480979414, 0.05439995329887156, 0.028036674897697185, 0.020298531857289134, 0.039903987799921346, 0.0553643545736709, 0.028718598487396396, 0.024578368231173486, 0.08221382876077006, 0.03347022819422907, 0.03808251033807474, 0.021406417569866585, 0.09804014807506915, 0.038071670193946174, 0.02502695676089535, 0.026677742172333024, 0.10085530669218111, 0.034104813295867176, 0.0498800766804526, 0.012354935526907926, 0.017135760844534925, 0.02210949859281461, 0.05211898396092077, 0.025746384184927713, 0.1299958510865127, 0.016477501710816737, 0.04217020994532974, 0.05234165124655251, 0.06333392894556446, 0.06490220285711751, 0.037167425973400954, 0.06980504299844466, 0.04720039305187041, 0.025747106222796346, 0.03570280375800306, 0.08390044793486597, 0.050696113537396156, 0.014416201381884037, 0.042090502327247974, 0.0331273770350362, 0.10907485555376738, 0.03459336671737894, 0.053848523210974476, 0.0646708979301395, 0.06247081215523424, 0.0877709539547082, 0.13197453362086128, 0.1374203155958845, 0.16809348016977313, 0.13659859436654276, 0.1560090253910711, 0.33403581609168365, 0.14805468850799147, 0.1255024926015927, 0.18610324199882247, 0.20869862228151292, 0.1462000202868254, 0.13945760385644052, 0.1482829214223931, 0.10407963286965125, 0.16960503293141244, 0.11026887253167168, 0.14042552530525193, 0.15340372889993653, 0.2533231672620581, 0.14915451497560547, 0.12295137384846327, 0.13179411991469323, 0.09533991796835777, 0.10205575880864937, 0.31800603914645414, 0.1870868988935986, 0.11136820104213492, 0.12410541635847862, 0.1349632571180982, 0.10857456949569526, 0.13675104586347459, 0.10845352760365895, 0.19861448436014115, 0.18212856334303656, 0.1295473066068465, 0.1343310353977065, 0.14635533695259403, 0.1333959178338128, 0.14706193048867489, 0.15660553209243283, 0.1565694646729577, 0.14998090934128533, 0.21155096680646945, 0.09104979494887014, 0.1223719892122092, 0.17164468074277525, 0.17316090664075268, 0.13748097443772903, 0.09864312821939107, 0.2644197210188835, 0.1251897908326599, 0.11942913139899893, 0.14823520946646893, 0.20050862143116616, 0.08848230489679883, 0.1548888516281882, 0.12833458176183124, 0.17382565645440934, 0.26014038451736976, 0.26884243853630563, 0.12184404738007054, 0.21693518595589747, 0.1512531668788964, 0.16338763187729544, 0.15660018479872137, 0.08685004732180988, 0.17633612658227646, 0.12881036066720564, 0.22970735786422608, 0.09680886858052785, 0.13704995804977033, 0.1530613642065756, 0.10367929830306, 0.2598609156425922, 0.18630305305123332, 0.261600885179735, 0.13011146907604512, 0.12895197968088812, 0.11134039971136278, 0.19749953531690184, 0.15019766625858125, 0.16108880119939006, 0.10438940052183406, 0.14056689917079865, 0.15286696173491018, 0.12810326151309476, 0.1233686006537849, 0.15241598109564475, 0.15026546503988006, 0.13241727115406146, 0.13497056559689585, 0.13252755717164086, 0.09523605942846307, 0.20002249267793473, 0.08280166334682897, 0.22793285308345673, 0.18143081046160192, 0.12312808734995705, 0.21032323429901756, 0.17498554421528695, 0.1864734156838348, 0.09219903408760026, 0.244567119366219, 0.1284458024066783, 0.15251241624355316, 0.15250208937833387, 0.15950070093235663, 0.20990459789191523, 0.21299568605759453, 0.11085810905863201, 0.12812953066801833, 0.09815867719871384, 0.11844917470889708, 0.13821614305338553, 0.14926838628467054, 0.23726748122322946, 0.16304002714253243, 0.22114848567833825, 0.19227731311994214, 0.1818741915086585, 0.1137546185524233, 0.17437276580641348, 0.16099553765548816, 0.10842473801946449, 0.07332630485536591, 0.16925376629637134, 0.14414917227000962, 0.24474163419537007, 0.12147525265332192, 0.09809276299370874, 0.1061570871200773, 0.22321509978463575, 0.21064512912304173, 0.135494768919964, 0.13258466136551675, 0.25530808575211034, 0.13057038638620608, 0.10628780470259729, 0.17658642282889736, 0.10941677591613225, 0.1001982254186465, 0.10253257959360078, 0.12166999986455326, 0.11397813236521137, 0.0840167324208925, 0.10668507491749142, 0.21729310223412132, 0.10818214861736183, 0.14697038298172338, 0.09856632024410272, 0.11170800700182877, 0.1422092691063881, 0.19492508152559881, 0.1560351030240136, 0.23972440180518936, 0.08326041211764659, 0.05520536451630535, 0.10752000350264773, 0.15156199224293232, 0.1420123079010556, 0.20305604764050056, 0.15157092482812945, 0.21069998101842022, 0.0814038593201868, 0.16021063461178736, 0.22415463001497332, 0.07841155053146424, 0.16850417990597988, 0.08470818039871032, 0.1077399550065879, 0.2148933624548297, 0.12852710731808217, 0.12690027364559714, 0.18216041727892815, 0.15982484805487818, 0.18326461044771059], [0.04561205529758046, 0.033541014718432585, 0.04047632059683243, 0.014394602490468852, 0.03680395555772609, 0.05633029185475842, 0.0612637410391002, 0.018517923270983082, 0.03422429619897758, 0.006722012157326625, 0.06352277344933922, 0.04247810834297731, 0.0218616902167278, 0.015429344043255815, 0.057101677277035294, 0.019871345908951857, 0.03594254331302739, 0.10043630256287514, 0.05351650836547056, 0.02446802475699975, 0.03526589615390666, 0.030777804523466096, 0.03486189968703735, 0.06118733525997209, 0.007766069339272837, 0.0209580761035003, 0.01701392605149698, 0.01663516260563366, 0.03566056166985824, 0.054984608620044687, 0.005044105796954565, 0.025328023569478143, 0.09098692977380368, 0.012182951660736675, 0.0342674499317523, 0.06853664654397196, 0.05058634845960525, 0.061434862098746726, 0.057181415538634026, 0.06340006148562798, 0.06783779815680559, 0.020007169467487165, 0.06048219346050775, 0.016254112387316364, 0.015261673252098264, 0.06670847730410677, 0.06528562220234065, 0.02132629051864628, 0.019258939052721667, 0.016737663254682577, 0.03503081441346196, 0.008111301595495354, 0.03119749238624448, 0.12403959408402444, 0.020095394068067114, 0.044300750258468816, 0.06882012205859346, 0.009406105100717998, 0.048120529766404824, 0.07316161893428334, 0.015392395622667768, 0.04081237655613692, 0.04199857560677394, 0.08864713637458702, 0.058750267846569906, 0.017890669630780336, 0.09147034657578315, 0.0646994270444397, 0.014553633725060331, 0.07383717058767235, 0.02715160585789671, 0.026267978978613694, 0.05514838672693699, 0.027293594509002664, 0.0656152468535208, 0.036274270875559705, 0.03594576471274899, 0.01111444286746724, 0.026367832793884223, 0.021882749973766265, 0.05944679881776533, 0.03366998179004558, 0.024195699652116147, 0.025333707941876307, 0.03306803969486106, 0.02497844998874972, 0.020132482299701344, 0.015430406032640849, 0.04450061876747397, 0.056100568899344054, 0.04285788110968086, 0.026704051546872627, 0.03437406255773479, 0.05444915912624809, 0.05758258131062312, 0.011178878522778471, 0.11594187618503649, 0.045112305501055334, 0.0695008677881091, 0.04775249346670124, 0.04185865730828336, 0.007852206350259123, 0.012350066080539217, 0.022951976974464716, 0.05736856698809613, 0.019309487449185505, 0.0055345595953234985, 0.019364034824614084, 0.055739473356234456, 0.048713071962758425, 0.014873637269521433, 0.016546323219494476, 0.010910457593478985, 0.0235213047914928, 0.04550864491912146, 0.07244130476347863, 0.06914654446225013, 0.04222603094193243, 0.06349461205724267, 0.03236367930507949, 0.012408546359849074, 0.07426565888548091, 0.05605981685221196, 0.0306081926570304, 0.06732392935983597, 0.021325922796442624, 0.02822709562737615, 0.05186315655948655, 0.025873729065361045, 0.05860988223444551, 0.047113514850817384, 0.06903886314361327, 0.035161428574112155, 0.0928740035141668, 0.02785775123254186, 0.06584711102468353, 0.06373938864036914, 0.0837073784561888, 0.02865065031895234, 0.014126992656759197, 0.05912361696602837, 0.031134351419525284, 0.022150241063847657, 0.03651425940915942, 0.03929530796144278, 0.024228470978297056, 0.04530449014817996, 0.06451286165223968, 0.037419633609392954, 0.075714101323918, 0.03226858481103855, 0.027992912125022664, 0.07724177257548417, 0.06985955781513645, 0.05110375275234542, 0.021152963125777823, 0.053410056617952166, 0.04263403404864573, 0.0457812458156578, 0.05167002579377544, 0.0346254658014063, 0.04977676589342375, 0.10180285020220665, 0.03041830435845881, 0.05289224629861213, 0.03785834918099065, 0.019763551592346162, 0.06096590520633806, 0.05108919325134447, 0.11146066019371634, 0.040755410258087425, 0.013746764067740691, 0.03176036782773032, 0.08381577989747448, 0.06595673820664806, 0.047911249867249886, 0.04148541161069467, 0.042948428871891195, 0.02220877401170231, 0.053598161846879995, 0.011715864980473154, 0.010304529925868397, 0.04970440888897546, 0.009898252432204543, 0.010175833857858614, 0.0275990893057878, 0.04318847869252486, 0.017134726625837145, 0.03651224459791857, 0.03200547574388404, 0.04696881999411891, 0.010876142600130652, 0.05572836508133239, 0.06361305308077606, 0.0524415337901202, 0.06349786027004162, 0.010778252842775997, 0.013425185254985287, 0.05879365906660115, 0.0687984187876986, 0.04038203815599123, 0.022264045340219335, 0.05551154304656291, 0.02694865384499633, 0.07087734392693928, 0.028171558083305438, 0.03010618864678808, 0.030855911017786113, 0.03451740526924691, 0.0222001995726098, 0.035524891328907786, 0.017328926084202625, 0.029583371942862872, 0.011329829444988601, 0.05145064502533886, 0.06682647016620444, 0.08721538699202, 0.044600895846322666, 0.11339891626830063, 0.01905069911792394, 0.024491748584794904, 0.03317158413870681, 0.018271066759142186, 0.022592915394794078, 0.034663111362005436, 0.041307250203024, 0.010036876999713, 0.002526393265373284, 0.04510248425386606, 0.05877690089325752, 0.047077137165732925, 0.06769679201346251, 0.013592376283580258, 0.06376950355667262, 0.060257369637369156, 0.04167738941407973, 0.07279394269590417, 0.04129552139690326, 0.015960463225060416, 0.09117092111057813, 0.02425459457651502, 0.034248485425186735, 0.04466608226779969, 0.013052619460429396, 0.041462164672632376, 0.01479322580815924, 0.05927552071009433, 0.0628227184736921, 0.030985546501113043, 0.06345626552619281, 0.03066243551250908, 0.07499977029980191, 0.03992426997771667, 0.013274861567263162, 0.026631774981656385, 0.011538833552490801, 0.05174098468776192, 0.033024813183733535, 0.030863003076745138, 0.07111047214317708, 0.09637907027236878, 0.02168735733345872, 0.05212703937544458, 0.055743265491459644, 0.04447852862217734, 0.08087283015371331, 0.05298655555253068, 0.03662755615228126, 0.07124319687605866, 0.011373363348895745, 0.02405195474444378, 0.042717392075686686, 0.07475708896714835, 0.01979610075302903, 0.04204965451912534, 0.06232987879024399, 0.07121659830332765, 0.0312739000805924, 0.015382894217186879, 0.05028743244286987, 0.03375102240111559, 0.00487010951356722, 0.06301923534802853, 0.04418562639564757, 0.003183133629781585, 0.055892461114713264, 0.006781788561643372, 0.018497397860271797, 0.02944330042678743, 0.028998071192613536, 0.04798270288794752, 0.043871691225156675, 0.08243345850778204, 0.02221107993635439, 0.08613208504093271, 0.07601567949619024, 0.0297612575588808, 0.038285558111965656, 0.04536413775396444, 0.010028772747084018, 0.09742317150437063, 0.04988695231957301, 0.043712153414925264, 0.03896577524081354, 0.11178286911378946, 0.050515994775078954, 0.03352661226545611, 0.07182281899956927, 0.03335348788588759, 0.0818468343406435, 0.03564590640786675, 0.06675585984222351, 0.013115999829624931, 0.06487470796151508, 0.007696088164999722, 0.031134600398100676, 0.06927622016519308, 0.017100120519077586, 0.018625771213743477, 0.016692755180561257, 0.023115103906621377, 0.059526912462446964, 0.013848332004741797, 0.03343802951877156, 0.08751707241660164, 0.06948657258744202, 0.05039471539578611, 0.034874406072401234, 0.005809585160140189, 0.00686069896947893, 0.030999380133805737, 0.018166899868857958, 0.08849401072028185, 0.04213657102457458, 0.014159793668847172, 0.051060943759136626, 0.024570441136376995, 0.02322370644598719, 0.04520142450928689, 0.06232866071044438, 0.030940557987759673, 0.03841363652158649, 0.012025516761857416, 0.03205261121864521, 0.07524289596345156, 0.07147915961761629, 0.018433946627943266, 0.059423858314872756, 0.0534839955939641, 0.025485724683911092, 0.01681174778740012, 0.03953279904840935, 0.1115432138284368, 0.14650418783628172, 0.17507168314149305, 0.11920226978198176, 0.1782659786723314, 0.20852363247784877, 0.13520598441602724, 0.11994613349557885, 0.10759266694226574, 0.09900425440601765, 0.21861138633422314, 0.1558784840087737, 0.0982647650544682, 0.11470315797675042, 0.1635306604927586, 0.086033811282006, 0.12919530452739808, 0.1844058516285112, 0.1806621025166204, 0.1928913938782869, 0.08917289485614147, 0.19911861617959317, 0.12346570229818746, 0.1929038351461772, 0.10903161755132099, 0.13537942672208433, 0.07349476758991519, 0.08748009335249664, 0.18471729701324818, 0.20711193161626018, 0.1216189477652792, 0.13018009523230215, 0.13422566766460098, 0.1468188201467837, 0.08093750329628106, 0.17840840973921362, 0.16798768342742998, 0.09984619269568114, 0.1736988842246994, 0.12248733141008886, 0.11159861730712076, 0.18047278686877222, 0.1995352914016093, 0.07838202550286248, 0.08669445486438852, 0.14808376920559715, 0.11747308676281285, 0.08866745302633894, 0.09172834200604309, 0.16607440948005647, 0.05166835955254013, 0.08623877810614725, 0.14849474473345667, 0.21694105418939746, 0.1483805823109804, 0.20894691137777222, 0.10625039662925467, 0.12360732897274918, 0.139532144211473, 0.17257290351535046, 0.12138332976328751, 0.1356102949789455, 0.14512187410746852, 0.1779876589294403, 0.12934804713774112, 0.13598679655021237, 0.1986093209275315, 0.14602516837898763, 0.09496118708123123, 0.1915097236633301, 0.216211692520207, 0.15386070034676982, 0.2174436691547594, 0.16728360265974077, 0.18892439142350229, 0.21127715166057312, 0.212252029187737, 0.15845529735088348, 0.21373278521482023, 0.13396378816856494, 0.1577824882922634, 0.12113089613135784, 0.10621544003726975, 0.1385060920109672, 0.16874696849094284, 0.05776199910248961, 0.1338389464804242, 0.1768145638127481, 0.1231404290264172, 0.203870628930388, 0.1393496467461509, 0.07551098843255351, 0.13980465700789807, 0.15867246795565854, 0.13927110741215368, 0.13048053959444647, 0.20577599685038292, 0.18499710296671237, 0.16719686618495375, 0.2231421222489688, 0.18743136266787208, 0.1272538845096865, 0.09072671268856333, 0.17931018715664265, 0.13031085111921833, 0.13177144371213453, 0.19039840587685186, 0.1286090480824632, 0.11976993327299434, 0.2030011651016051, 0.10328203574904513, 0.10071679799547119, 0.1360570468128689, 0.10047787049364659, 0.14889798277328092, 0.17509075873080762, 0.21369886284153308, 0.13588737365939926, 0.15922892358033888, 0.12503235210334102, 0.07059536228377013, 0.12870813389458965, 0.12372204297853094, 0.07519994907441639, 0.2352638548660663, 0.11105870152072561, 0.11340057867909632, 0.1188830103004171, 0.14454830407855973, 0.13096279194278101, 0.1095656191389407, 0.23414093850841447, 0.09900173397674676, 0.2319436451239932, 0.06406211083935154, 0.20883956713782204, 0.2142531427765085, 0.18054570311740523, 0.09629928987593421, 0.07934565685929791, 0.25736254970392874, 0.12205298253965956, 0.13505108143773772, 0.1161061407577607, 0.12530707889386725, 0.16869816869016618, 0.08886530289366361, 0.14217569913354614, 0.13864222583511185, 0.1354722919002656, 0.12634401720377708, 0.09415995870386401, 0.17363583518853112, 0.14813164970086468, 0.15803001130059843, 0.15690291210288004, 0.19965794207828663, 0.10562837153913514, 0.051766851646525246, 0.13244013121772197, 0.11305860469057677, 0.14998778881084535, 0.1540161855518818, 0.1151601447453422, 0.1826532109971008, 0.13969129131686303, 0.08043635921973376, 0.10864273599919774, 0.13964062226155113, 0.18975403400198107, 0.10307424972134252, 0.08875674057391383, 0.1428442640650657, 0.2273658254454213, 0.20092275324127368, 0.11750101066765287], [0.06067086559449954, 0.044402865948335785, 0.04468078349506663, 0.002051281335297972, 0.041716739520310395, 0.023483948429085078, 0.0590817426000872, 0.04351962402823471, 0.05196242623271481, 0.07582711461450785, 0.04092513320727214, 0.018085568144376722, 0.024910233689532168, 0.016141438090633002, 0.02148318341031911, 0.030015933913208788, 0.06874557404268174, 0.03666288046646984, 0.031149600399658087, 0.011807380886297795, 0.03871414600120437, 0.025010326907279033, 0.06812939420342445, 0.04407612561819054, 0.0637428168838303, 0.049285715025278835, 0.043748048464617426, 0.09087508093685874, 0.03337206934849101, 0.056067895249373494, 0.07215831188424941, 0.03780419825606289, 0.06309039725531494, 0.021632214324669014, 0.03962466065140982, 0.06762597484574204, 0.010883515238791946, 0.019488326844669158, 0.017500619794572556, 0.007721852659503179, 0.0352531063160108, 0.05591096596852426, 0.05201455468552248, 0.014255075854429556, 0.04889931942846987, 0.06966774472065511, 0.08458001388897819, 0.060260495276100216, 0.02885216974743432, 0.02932751389791168, 0.05524603229376578, 0.06086396188625406, 0.06412523265387263, 0.06820139114654834, 0.015284107179350912, 0.02755972579301846, 0.08569704669137156, 0.05502506189288632, 0.07544226268486631, 0.057916771845831994, 0.03752871686893125, 0.008667071571483487, 0.015747754124834413, 0.04093950118629202, 0.0429278479198054, 0.02455925242224288, 0.024162445690542943, 0.07934692090437298, 0.03524843317967269, 0.05026787421816299, 0.01910727279591224, 0.09749531400420013, 0.05546074758674349, 0.026081831104332404, 0.1562622021282873, 0.07120624845547062, 0.012508034368135757, 0.025613314712480195, 0.010777337367706483, 0.045975203956327135, 0.17841964058818358, 0.046739568182777975, 0.05279441304024189, 0.05570504536491729, 0.03724691908686392, 0.0035905715072482467, 0.04176319892247839, 0.08145419895769128, 0.06475840815373006, 0.02230380338826968, 0.03812485201764972, 0.09408654449808021, 0.015044850259718877, 0.024510464112785076, 0.040355546835569606, 0.09317733602778566, 0.07918715326776428, 0.043220665876663504, 0.04278778023416958, 0.028813888333858024, 0.039361547753815694, 0.0785548472777009, 0.05311034386977554, 0.04156279032148662, 0.020061766638630824, 0.0538537364392992, 0.036803181808922565, 0.03611077622119938, 0.11450135509573645, 0.032136093734973864, 0.0317920972743342, 0.024551652830034017, 0.07635345532288475, 0.01964814236177312, 0.022918878145696178, 0.009500467023181339, 0.013124102167034102, 0.06704007846213157, 0.09955822790582335, 0.03557852514448666, 0.09600333478902617, 0.07123902169687134, 0.0901131145656109, 0.03497512365180639, 0.06197595383010565, 0.049595367764273, 0.033109439086289175, 0.027676347357731675, 0.06703427917654477, 0.018658741722784696, 0.03257022427034474, 0.011234946582736749, 0.0752688203788092, 0.05630683041207733, 0.06558904664651041, 0.049181948415935046, 0.06310511763478, 0.003050669127391772, 0.07099733627851933, 0.04891012892908147, 0.018860031324889392, 0.018270978659030893, 0.04264109354886798, 0.09100770607831017, 0.029566205827699556, 0.044086640174951286, 0.05219527482686024, 0.015377409985258937, 0.059925178591642654, 0.007671335864166219, 0.04731231466716817, 0.020210071684672468, 0.08155243441222176, 0.0363731881483428, 0.05762064055870137, 0.011603770995392435, 0.0028425148986805713, 0.054542621853010315, 0.022836607963507696, 0.060579379374581965, 0.050901700892756065, 0.04371997517263217, 0.07297839368543318, 0.06044550934025358, 0.06970224165988546, 0.025527470730124943, 0.07547162683500398, 0.03863644553348422, 0.09710426442325117, 0.05552130683715786, 0.10589998801268878, 0.05561166307738712, 0.09562100328865553, 0.04845688449999979, 0.04361452316985496, 0.03570571872255495, 0.02451224909764865, 0.024256270393849384, 0.03026119121650775, 0.08030031732614003, 0.0518623789802434, 0.05145689247236137, 0.04394832683066207, 0.032335402999794295, 0.02472871298631353, 0.02841553027411142, 0.07262187934811078, 0.025711944702291684, 0.04471761317202642, 0.05026568703713918, 0.0252127215912145, 0.03367377392527077, 0.1007216320102734, 0.014318425580108119, 0.05448038103960214, 0.01745876266560968, 0.044547116474038174, 0.01586926333050454, 0.04027903380413209, 0.03878680561038275, 0.06744529300880048, 0.03825226393077643, 0.014411778181731222, 0.04366808420708103, 0.04843101754123646, 0.023553704565030434, 0.026288688250426805, 0.013738565011731079, 0.036239360248850244, 0.018748902610593268, 0.012042980693701294, 0.0359609792189252, 0.021381146244464383, 0.014505497547948073, 0.0598812664318229, 0.023933180472663334, 0.06736081649339007, 0.03215824133686481, 0.021410079470144647, 0.04584756987770239, 0.02822573199087093, 0.10245256937078892, 0.004509308914308467, 0.024452047993338877, 0.055755231784836906, 0.09935398120433094, 0.047702517720960805, 0.049003403964302236, 0.035787567556385076, 0.08328858883150163, 0.0997269894146631, 0.024337318665798635, 0.021340880663164204, 0.03575184104603625, 0.08451758538402858, 0.022205905012425878, 0.05284815793856979, 0.018583354840595877, 0.020737383409493396, 0.0346166787729148, 0.012523833016354232, 0.04491935859644606, 0.041105933787841956, 0.02638602355164626, 0.027098579166997826, 0.02697898135069878, 0.03786174678093484, 0.08564093075091801, 0.02305651924783184, 0.03919560161809768, 0.05681529828918077, 0.07386448162217295, 0.07345747442976122, 0.03249852993195096, 0.06706786447114522, 0.03393031378847457, 0.08248166075997776, 0.053372365092077566, 0.014701489652056369, 0.012982197785599819, 0.03221193643947763, 0.014257715984938607, 0.013727201054984284, 0.025068204849958423, 0.024892303401664383, 0.03584140821570351, 0.013988243599963045, 0.003694565788347034, 0.03339758390680917, 0.03821413190434537, 0.033085387755906394, 0.07228175929236798, 0.10108094256851943, 0.04367616260424257, 0.06912491780014769, 0.014606488046176253, 0.047892319834640915, 0.0399483825951334, 0.06707836753658711, 0.021715357847091173, 0.02851591077482989, 0.004893671026483419, 0.049727111904611515, 0.012065416536173754, 0.06954635042817363, 0.02737795802644424, 0.03559430272528722, 0.0523374607456067, 0.048095800448209054, 0.039875006693745815, 0.015573936435694416, 0.039831025586012876, 0.027157677104696635, 0.07010659818807918, 0.08145318772163122, 0.10605957944907489, 0.07341159342397606, 0.032292532719551556, 0.012660234013662465, 0.07003743577027513, 0.016767954371208628, 0.030961702014469815, 0.044844841224051295, 0.03833661787211895, 0.01059859181799355, 0.09992387401120317, 0.013088923409551144, 0.03448003166986089, 0.03142542844157546, 0.03456163152511563, 0.02045656047430971, 0.04888563709814222, 0.002315805749892588, 0.020631515804017266, 0.0641496746890968, 0.025219147153679403, 0.05077950986883333, 0.08612785623559067, 0.02613453603830309, 0.048166571650654084, 0.036616689195075346, 0.026616721353944273, 0.06433005009086863, 0.049307000778254964, 0.03386813426210034, 0.0566806813191262, 0.04593230686300705, 0.03442490781326929, 0.07000123811585289, 0.04933230849283357, 0.02696581612972002, 0.013528461568057539, 0.06020082851811763, 0.039513041640842156, 0.017668444760924867, 0.03184921295952893, 0.033780321433779695, 0.06273050063980684, 0.0231704460982714, 0.011881829310779371, 0.014171755174174907, 0.03625898742147031, 0.09435777026679247, 0.0010314423472605526, 0.04759190994645319, 0.03150895500795976, 0.024708465282474796, 0.019570102900146477, 0.03777959917281424, 0.03341104024119916, 0.020569455021271305, 0.0742725306941617, 0.1164002265901335, 0.08410858636301372, 0.12225172872985564, 0.1642096288982899, 0.18070115767900022, 0.13067868057518237, 0.111552307292098, 0.16591734613382048, 0.17120562043161164, 0.14410458595281647, 0.1307431851784068, 0.0811467295692813, 0.10810986822170597, 0.1942361080117764, 0.13038863968704978, 0.11872811498300684, 0.22109545707221956, 0.147942854992805, 0.09129033889621498, 0.08685439104034055, 0.1339840588550414, 0.18582571898737263, 0.1194711666434042, 0.12637587113966867, 0.19609630738775577, 0.09040008344116712, 0.10370463283071596, 0.1336119239849429, 0.15029316677922203, 0.1016831259814001, 0.2804310505668963, 0.12183341407968153, 0.24366351865953018, 0.0910349328431391, 0.11461783110374406, 0.11650167961394596, 0.10344392544920407, 0.1356499017246308, 0.1542495818988931, 0.12469884338638476, 0.22130000254800244, 0.15043797271866954, 0.13643337984479245, 0.12788901736419048, 0.11834363077556896, 0.18666912050497148, 0.1162670192218596, 0.14180282881904033, 0.09154441961718184, 0.19931045991759147, 0.13575629601555486, 0.19761881520671232, 0.1593840410632472, 0.1649432500163394, 0.18025842014580004, 0.18835180198713658, 0.1432186205901446, 0.12527256663287842, 0.14872044955770816, 0.1370924912513264, 0.14231537228390095, 0.1203934828780832, 0.18410418152568803, 0.10699671948508871, 0.1569675852454478, 0.13302373699843884, 0.0786948575067424, 0.09300175633641983, 0.12560845788327918, 0.08943442195173233, 0.16237722319220343, 0.22652775589977542, 0.16886986431575593, 0.09042455228946863, 0.2714934091894858, 0.26021515469877954, 0.11562221067687196, 0.12741296266716334, 0.11699045903139538, 0.16979929750725148, 0.24711508183710038, 0.1538672120941262, 0.14094733843399634, 0.09269915160632904, 0.12910524323101968, 0.14226522416837756, 0.2300520667866353, 0.18067857340699245, 0.13856382439694098, 0.1548264307841178, 0.18885512175338884, 0.17297592705055592, 0.14727493357514182, 0.1440876247661729, 0.19918825357191025, 0.1980948775646187, 0.26571912871253106, 0.13387397202032228, 0.14166831910129518, 0.10754007500626388, 0.13648924297623097, 0.146134979422054, 0.18462790987424313, 0.0798786012455821, 0.11631434047294241, 0.20808063447475436, 0.10682730680151332, 0.17178807708044208, 0.20758468447433365, 0.10884147452851457, 0.07439988515069408, 0.10403331519374925, 0.14307507103489292, 0.15043618007292672, 0.1631310690314539, 0.27412605501951715, 0.11479711866066342, 0.12538673671623393, 0.23105332838191142, 0.19108429971721866, 0.21802586533369558, 0.24495716537198714, 0.07621746705544573, 0.18995974393140888, 0.09507374071906652, 0.11089707995134016, 0.3595449505073409, 0.09566427193461888, 0.17161602905440718, 0.12120365916240601, 0.13273892082994984, 0.14189128133077777, 0.1776092421383627, 0.16824338825479632, 0.11858849545880673, 0.13238647441950538, 0.14064853350000997, 0.11030072646756327, 0.2263443544507027, 0.12864562111996836, 0.17370487503226728, 0.11150896969822147, 0.12988600939992936, 0.1254680569493963, 0.06940170536719023, 0.10608638486554546, 0.14115646511556643, 0.25526356072195117, 0.10556054977519859, 0.09848422626213682, 0.25938229455101874, 0.16079080831860343, 0.20969672759454097, 0.1458565524268535, 0.147205020391172, 0.16063274905806588, 0.11078729955179077, 0.2169286742085411, 0.16884398586567373, 0.18698035138508967, 0.1743544409832647, 0.14997254366115217, 0.11574098494865241, 0.08062891541950165, 0.15886993477902106, 0.11503760132097429, 0.2129027749141378, 0.07458478047121918, 0.2319137523731878, 0.1033791603760854, 0.17769104500691738, 0.10716021030900941, 0.2717009577299318, 0.14129544878678937, 0.1754946249627298, 0.12457377187186673], [0.07597155283175169, 0.040419948016924244, 0.031639385307508136, 0.02191610735720925, 0.016478585725229596, 0.003072835642078351, 0.032419718636740605, 0.05560784029864496, 0.0721694431417892, 0.10778232732967985, 0.04623552829387688, 0.04085053156520571, 0.011901761003349338, 0.12092330928651557, 0.04821633672221534, 0.018544971920369614, 0.020678702989713322, 0.042324526866357175, 0.06409132560234397, 0.05429106156131434, 0.020879655513131333, 0.0028322091008791883, 0.010344878819230343, 0.04936911518715563, 0.04603936381998562, 0.08754951624019493, 0.01442643918938214, 0.027905706421382008, 0.019796309511988394, 0.04655113353604271, 0.021132726913257953, 0.07556614676310171, 0.04086806348735287, 0.021188274033427722, 0.02906484724653344, 0.05450004268617881, 0.058593066604507554, 0.0408662976546874, 0.0727634677182763, 0.02178846944814488, 0.05472303172873874, 0.04338347105189197, 0.01649614063001448, 0.037015349859552044, 0.054929028941138144, 0.018732163589447737, 0.030139501980175416, 0.038030565746368906, 0.04545419905034285, 0.04345230022144895, 0.010841595865185223, 0.0776823880451341, 0.03490613743422493, 0.03074905515888766, 0.04666066878745633, 0.070752801013089, 0.07410047500724755, 0.018348391843779434, 0.02187485926814618, 0.06579433522757984, 0.05511732186160742, 0.03484274748893034, 0.06193674161970135, 0.017921081406154463, 0.04555381346313704, 0.033160809112051805, 0.05060245545821325, 0.031376036837877284, 0.030327770002787153, 0.06715627867848643, 0.007287523420076938, 0.06322884849543053, 0.03838907957317368, 0.015677647503663697, 0.5149179697036743, 0.6137659881384142, 2.256990877851363, 1.6141005557390953, 3.35414890800753, 1.896533884348408, 5.686386535244604, 4.196540415287018, 5.725363127646908, 6.480013910801181, 3.155214382756141, 2.0945844054222107, 1.0311083808060617, 1.5214741518420558, 1.7105941714779025, 2.8756587255385617, 1.74616014044131, 2.1047281449840916, 2.509963406670478, 1.5463210185689311, 0.8850290193673104, 1.1118150694716362, 0.5451230392340691, 0.25562697751147134, 0.1808796408435991, 0.0998242442766505, 0.0749289837755984, 0.06366944098244272, 0.04705601995210013, 0.0734005234534702, 0.006160689480302315, 0.0278987426821503, 0.036527616152119254, 0.029858129376906063, 0.01821074499598434, 0.006470805702490673, 0.03223634400074521, 0.04728198141580628, 0.026349161315949696, 0.042597844055102724, 0.06905290553526533, 0.04163309421029784, 0.043367260631414196, 0.007236408118549134, 0.024497668529229782, 0.02076085825871316, 0.01628455289098765, 0.008582257977386397, 0.018508429526381435, 0.044493000023067004, 0.05216681849091284, 0.029092493444500916, 0.17951372139636548, 0.052172449237156304, 0.030427844068335912, 0.02321125751721763, 0.009871768772662168, 0.023215235428764455, 0.026418017298584024, 0.010266864255461241, 0.05444331770582546, 0.011086898176149737, 0.03617784721897014, 0.04430436619347142, 0.034970469667666385, 0.042210107804426265, 0.05246614819512733, 0.05572398305840551, 0.04308157495313114, 0.09070408245128009, 0.07136516573448336, 0.10282078953159433, 0.05577371748644979, 0.010277958166214728, 0.03461693541236943, 0.060200292256570635, 0.009658886345043298, 0.050951297424973986, 0.020330023816636494, 0.039582410902385755, 0.031243040143782576, 0.008924097900519208, 0.07035579892896837, 0.05535952438930831, 0.04521060990349901, 0.0139132282704175, 0.07296629715710878, 0.010347866562135037, 0.006035803263300971, 0.015147247486898016, 0.02487798330313977, 0.06633643436455919, 0.025376534172063394, 0.035905261644192284, 0.022865093027752255, 0.0553210782668283, 0.044661263574755965, 0.04954090274329628, 0.03777591428989845, 0.034635765853548245, 0.028471899023579977, 0.028722553416305495, 0.02573766993478902, 0.1051242167370454, 0.055118696989431504, 0.06849195297446943, 0.036161169484858556, 0.030990194739593618, 0.03383050402325969, 0.04615366030784865, 0.08085224537118789, 0.07302240543668309, 0.09068569634109737, 0.021119343357220776, 0.02690657072009579, 0.015900239138112917, 0.054733469676707065, 0.033516032591221795, 0.030491272318026716, 0.027038860698080352, 0.019222578604615504, 0.05369097339890657, 0.03921208399978857, 0.02543557465316788, 0.0675427470536482, 0.01781018251823562, 0.04749951974278496, 0.06061374990930481, 0.015712977563511702, 0.04498650620300924, 0.06774368425530773, 0.04638573132275094, 0.0877843604933831, 0.13573585678973507, 0.052671678093892914, 0.02406724968985204, 0.019621306301785574, 0.01765544807928945, 0.02714725830892642, 0.022610908884915615, 0.054007758416475794, 0.06407010879728102, 0.0697275915092999, 0.010753377010264705, 0.06323518787300395, 0.012046332328370022, 0.041146716478491024, 0.05515036706422126, 0.029348311269836082, 0.024462143116961085, 0.03321982086485913, 0.015889573278987122, 0.014993532902501045, 0.04000643290759575, 0.04913102655160812, 0.04237200516546446, 0.05419445021318332, 0.00582177697065016, 0.045230880589975465, 0.022268419702266975, 0.044243500507887334, 0.05089800451852141, 0.04791301569991535, 0.027471905303818565, 0.027120749751526504, 0.019570348048282248, 0.03572091407653305, 0.03891868381610802, 0.03621479946999781, 0.07729144571649452, 0.06442439381874378, 0.07366658578957282, 0.0551698295279376, 0.05016707236908617, 0.09316032887586663, 0.03993349367632501, 0.43302788969970524, 0.7588299459988072, 2.259800030339149, 1.964937568672242, 2.6259890775526724, 2.176708785756942, 5.697949682512592, 4.551974813784323, 5.527730093848321, 6.148346624066753, 3.037371428743486, 2.1155833044359764, 1.1045738838372694, 1.3818401026148952, 1.777974975205237, 3.0569082642755205, 2.211201128459746, 2.7987873794571048, 2.4655366809137407, 2.1066253464068136, 1.1364174009330812, 1.4598554324719215, 0.5741473527685289, 0.26360187619443864, 0.18520414588912842, 0.1217935698467397, 0.04263889870696491, 0.08761471032255119, 0.09629717547326319, 0.10428600929557316, 0.056240793633004355, 0.05397784268303264, 0.053153076254191904, 0.057795048135543065, 0.017652314779679143, 0.03924592976428328, 0.0591981649819401, 0.02955264032578036, 0.046700807964249004, 0.015349635467564147, 0.06761994573377794, 0.030838264182450312, 0.028303784859036247, 0.05929063179440076, 0.04544396411567446, 0.06334797899809576, 0.023087181917001164, 0.03053334778204801, 0.0771921300779908, 0.07772788600695711, 0.020703627660329786, 0.040843858939385226, 0.04149571166283662, 0.028425163829759247, 0.08713564489998164, 0.008697441212021777, 0.01797969479324116, 0.02518649840156638, 0.05787115897082033, 0.06450696277522272, 0.013626424103764998, 0.03544370899157178, 0.015004119280004695, 0.03286014641484907, 0.013669239800243128, 0.09496258902213267, 0.07419676459845036, 0.03793531420430349, 0.049741100670108875, 0.020610569044947624, 0.06323331478802909, 0.03888930434421186, 0.032042466299307924, 0.061124833976669665, 0.042441565948989124, 0.058825727507111535, 0.03369905865721164, 0.04410432148424368, 0.045858053790946166, 0.012531102233145748, 0.021421406080105135, 0.0615891139023006, 0.02215743271423684, 0.07856501326445611, 0.00876915087217405, 0.02351970749817068, 0.026864162007827434, 0.026503828722202492, 0.0707754772156477, 0.04127873641048228, 0.0730154800018476, 0.0225539751456029, 0.045973752219710624, 0.05475015507169789, 0.03221687004571, 0.011186217645093078, 0.059014767363306984, 0.03952048801546616, 0.06025928485717985, 0.041699134819810434, 0.03127401307856124, 0.025663323016957413, 0.19953221172815372, 0.14485002014665835, 0.15862769777736357, 0.16855650371120823, 0.2844671388306926, 0.05590672950230299, 0.12265701988531698, 0.18371801192481674, 0.17478101406126254, 0.16338888826149126, 0.13003703597332203, 0.1311682107587976, 0.09924056954802045, 0.22927177559223869, 0.11289529772775789, 0.09129782357523519, 0.08994012425142912, 0.12339447144298785, 0.12334461444087567, 0.15099651210250395, 0.0924358931520293, 0.09150867395463491, 0.07946272275500721, 0.11499804054056445, 0.1306733332814709, 0.19495846763733896, 0.1084890970659833, 0.1749777301184593, 0.09516844450826607, 0.16693003776092685, 0.29261901914592714, 0.2133910640353157, 0.17302772991599577, 0.1362958364188671, 0.18757898781088092, 0.1904890647218112, 0.12657762805540718, 0.13208146417333236, 0.08994530300579726, 0.11909092656306683, 0.20384784547551987, 0.11971981580098791, 0.14575653198745944, 0.19160496371407665, 0.17935109625179924, 0.14259122522367587, 0.13246026400837208, 0.10220320009055639, 0.1562575136701907, 0.11481006554658375, 0.10795448260802416, 0.1227477783217065, 0.20470678325622313, 0.09741147334176688, 0.17059543139992223, 0.11108710806095794, 0.17033721380416425, 0.0858270058468465, 0.12981693891267623, 0.17945833323944002, 0.17375427238162489, 0.11824343413595231, 0.14117293600593844, 0.12212010716358501, 0.1002558199087939, 0.11383190150222472, 0.09371732076209399, 0.11269124254824654, 0.27401147890956173, 0.24304105689929378, 0.15147357037471187, 0.1600002209025045, 0.12768833297154597, 0.08494549145501468, 0.8989533721919983, 1.4492988634494044, 4.229605015247099, 4.151213015279462, 5.24446044237383, 4.32525348278784, 9.104981210923965, 8.038103388201806, 9.007804489904835, 10.385478177378255, 6.411302810715092, 3.741828376247037, 1.6540940226085725, 2.3713799397791586, 3.191308278229929, 5.69154151024357, 4.018892347812653, 5.284939302552131, 3.5995218446177826, 3.4246346354484563, 2.6137365737269005, 2.165494974582426, 1.5540538487895843, 0.5679381182116847, 0.45757662564996754, 0.3519521918027632, 0.2312828023587504, 0.15623663011337482, 0.1569427793184596, 0.1713071270815788, 0.10739140032279877, 0.21333670243620875, 0.20045859588971063, 0.22858517695098157, 0.1011913818036837, 0.11667800241059835, 0.2155977649794471, 0.06573291795869028, 0.11295773389358675, 0.1618184080167163, 0.17797310325887897, 0.13107191350671554, 0.1020064916942389, 0.1333029454033221, 0.1900922771423094, 0.19233394233930498, 0.13462815493825944, 0.09772977521342617, 0.11452853589528993, 0.14404501495582445, 0.10967652568773878, 0.12836903273578615, 0.24163197605840622, 0.15817055779118694, 0.19191052554355514, 0.13333602507989253, 0.14071699111692368, 0.10801356330874468, 0.08130698750216155, 0.15642352492338227, 0.16867916970964403, 0.0747701124618611, 0.09381541832079811, 0.16164603823375318, 0.16717641163737545, 0.1497283761179255, 0.2060731776779698, 0.1603418654732166, 0.12264660875042602, 0.09907517882604754, 0.11488381683105424, 0.2280289511526785, 0.14781314098546583, 0.07449595257639885, 0.11621353862386559, 0.10107523521348354, 0.16506465963057934, 0.1324915357174412, 0.2667033678341297, 0.10713006474918897, 0.11709775730607011, 0.12203270419230386, 0.1737327453109526, 0.13493681176295205, 0.18292495770560158, 0.09391157001617456, 0.16719044636814825, 0.13907829840337077, 0.10744201575195599, 0.18716998878986607, 0.15144452032062317, 0.19994582259847274, 0.12474492357503023, 0.10975582344878106, 0.15099896358386164, 0.1500119205804602, 0.12025531126005996, 0.1260026101203215, 0.16890400119366186, 0.15025725257733177, 0.10790773592288457, 0.18674926862360972], [0.18603286916209807, 0.00952300532991367, 0.09359421809354136, 0.07369596526146897, 0.018683968998131253, 0.07771808774240556, 0.01330686680551979, 0.07711793446252424, 0.047423048846183286, 0.046060097989656275, 0.01338603528922484, 0.02350737348258976, 0.027313945634711175, 0.04147201656333862, 0.02138499200584427, 0.07124602374049925, 0.047517561113401774, 0.013894750229683856, 0.09955075854856162, 0.023630221426907568, 0.05450001204266183, 0.047175943355767, 0.024953818346764294, 0.019574848814837394, 0.0247219963104374, 0.007578833620139068, 0.038263720775684046, 0.03776487113246995, 0.02273238744706877, 0.03758113260471052, 0.07639131538810269, 0.057158769979592294, 0.017218203396506367, 0.011919392516926653, 0.06267941406657619, 0.045569889818228064, 0.05478117014131239, 0.03039617782398578, 0.032371780684878754, 0.01922876859504369, 0.09698503049871615, 0.02750348919371684, 0.007321203518058024, 0.05428406334812603, 0.03656654107955195, 0.07021931270437856, 0.05690789533658855, 0.010278868853234717, 0.0842693345921655, 0.02914588977282326, 0.08431081059238604, 0.013520810264913787, 0.017414823692712574, 0.07047021416045966, 0.048733189431650024, 0.042254625173706206, 0.06860013225025709, 0.03403707963204192, 0.07842032223819725, 0.05393077041052523, 0.05750121511218529, 0.025878430929996317, 0.08797369912386903, 0.07600064885111586, 0.08127852733577452, 0.0616051328007973, 0.02208569624100722, 0.08577745527990403, 0.04769982109146734, 0.5560174836747108, 0.9897244949975322, 1.8691820939702375, 6.6842683957469085, 13.295843505090284, 18.083385575202204, 22.97348095524696, 35.29928015124413, 36.64553957600748, 41.8222366609881, 39.95885587507679, 46.13403935586253, 52.89925713692942, 59.67576742172242, 55.429578135090495, 40.27506559125839, 28.11948157125904, 35.64259344531644, 28.508882714856057, 40.01639704550467, 42.653433968943936, 35.74056248511038, 35.216482839276715, 50.00525397639121, 42.6730065961038, 30.799762625848096, 29.79736170461101, 22.767905612145704, 21.574012617911063, 10.887331712630488, 9.433774871210899, 4.903543226180538, 0.6403253984547431, 0.19960017904879587, 0.04681238867042046, 0.03144347938829132, 0.07697558000443444, 0.013783456806484011, 0.04874919683882787, 0.030366557034393473, 0.020731331314891577, 0.07808523538011698, 0.05791278052774649, 0.04125953824709981, 0.07935040660442845, 0.09340814299761288, 0.03683333886006186, 0.007824476361424934, 0.06569349507410681, 0.049662649436222936, 0.01450693587802591, 0.05673529189680854, 0.04975932590182751, 0.047834131626352194, 0.032285274036469004, 0.026440415794270176, 0.016501748393620216, 0.058902194573273586, 0.023834462382740552, 0.0483134038926613, 0.008807632426220563, 0.016493315680793697, 0.06158930159384205, 0.045175151523923686, 0.015537935091302761, 0.024494290081483704, 0.03716436928258308, 0.055250004459653175, 0.026698727235798875, 0.016789278428580974, 0.045074993188703255, 0.025222234488014254, 0.024681952894635262, 0.03329564824760441, 0.051777492607793504, 0.008283229920292094, 0.037661062388290326, 0.0388578487740409, 0.019254645129906076, 0.022354188991049607, 0.08022777646058991, 0.025330802553423473, 0.135264253063548, 0.06665857433671914, 0.04493068903684617, 0.004630338357416012, 0.07122999718112331, 0.0595995107845914, 0.09512416462624267, 0.032966958223691875, 0.06029992582156293, 0.07264437935044689, 0.047268268441961664, 0.0655996952686579, 0.020644704007633755, 0.02820357481288093, 0.04752966913304502, 0.034987863693987174, 0.07713391505662473, 0.046520451714675275, 0.03570106856885456, 0.08709468217867036, 0.024013567993777896, 0.037251404531660585, 0.12351173652155746, 0.04253455753167791, 0.033796076031942526, 0.018807573454274286, 0.011042150980492514, 0.022206136754022974, 0.04256769466484266, 0.03473330033762801, 0.06232522097566436, 0.03278513108530352, 0.0293461489866698, 0.016771719693356467, 0.08758811941069942, 0.05238019313002306, 0.08816658474144437, 0.043627209585881045, 0.04659954263197799, 0.013342798244388355, 0.028925465209589853, 0.03236666704798418, 0.014249406803789881, 0.008902747987679416, 0.10537828213625378, 0.08402480698761441, 0.018415089373687105, 0.037465847863425175, 0.05623842642131833, 0.012160939081842381, 0.04463014508327169, 0.03274772301196091, 0.045119464592707735, 0.06975291071519737, 0.010335157163471225, 0.07478015587454842, 0.014982663072465409, 0.026517218023899104, 0.009530074406234969, 0.10106751304720679, 0.018621008062074264, 0.04799178102985025, 0.022583865981188514, 0.007069949182726804, 0.05715326563785634, 0.011247570754118986, 0.0027998811480844576, 0.03751164459953866, 0.02516486982424413, 0.08525220241637961, 0.046765806694184585, 0.028660691816419847, 0.08795651577172742, 0.01763094475703134, 0.05760869724796184, 0.058775292108616525, 0.034055324015958656, 0.039088682556945475, 0.04576345342361639, 0.049303147355995836, 0.03146522862446164, 0.054541721699699286, 0.04836352902554697, 0.0800902177129061, 0.02503083316579221, 0.045132614491928014, 0.056539414705888885, 0.07760685177580004, 0.06254858157086758, 0.0584223170975043, 0.06079478797713115, 0.02941845044974358, 0.08141584093532256, 0.0942857733236686, 0.674226995437376, 1.3133416685365862, 2.12316426538652, 6.501901226658975, 13.768593053663931, 21.243605882890765, 25.922311006053803, 38.660841603432935, 39.7543905627343, 43.69006149230465, 42.90012359619141, 51.50853764626288, 57.09828384460942, 63.78764690891389, 60.344759033572295, 46.248921655839496, 34.59240628827003, 39.13590338922317, 35.44336057478382, 49.19535906084123, 50.442672775637725, 42.41835455740652, 43.14184750280073, 56.33349618604107, 51.745801817986276, 37.052885563142844, 38.156715054665845, 29.915801594334265, 27.32948091722304, 15.950997856355484, 13.331016379017985, 7.267061020097426, 1.4231891161011112, 0.20269689029983937, 0.019724862236950188, 0.09599640935419068, 0.05577568633241519, 0.0626261709558387, 0.011465738230805484, 0.033088609155627995, 0.06129438838651104, 0.0422989203774881, 0.06997214975736796, 0.001567941620915888, 0.06290181705187406, 0.13562963103815434, 0.015590779836319629, 0.019443799899290168, 0.01042746501268759, 0.11205481500515055, 0.06732261934948545, 0.0403421402968947, 0.0553038259667735, 0.030917240186564388, 0.010756837812462642, 0.04375118176422773, 0.05141742745294206, 0.015414958827257639, 0.015155103718561512, 0.030011628499074332, 0.03533778967516076, 0.0375712309182892, 0.044078278325257764, 0.08030463806203297, 0.016165543047170487, 0.008365140998766066, 0.061715660136072874, 0.050204204650776046, 0.005095813380208828, 0.0257222026195978, 0.015442802292865612, 0.07624689249261733, 0.018433730208104657, 0.043556461366073745, 0.06703083944176474, 0.053371702426023064, 0.05743354273539397, 0.023257178742618814, 0.02447477207639285, 0.05178766625542795, 0.03699128320741077, 0.05554993554288822, 0.14509682303234456, 0.04105588143330909, 0.041596773981807694, 0.00630337622902927, 0.06034864135266793, 0.02173061831854284, 0.09837643769119056, 0.05526875063116032, 0.06052546593691073, 0.08046284287927613, 0.017570573198158416, 0.01730828384508289, 0.010901236767700363, 0.017123606859616215, 0.0371843297034502, 0.057291291699173956, 0.08029461763198338, 0.07129310750432553, 0.02760982411282678, 0.058093531312601226, 0.01388191155368282, 0.05119621573436645, 0.10155202535491797, 0.022217702766459797, 0.022583067334527453, 0.22962149472967272, 0.10830014914033875, 0.1691622341111783, 0.1612238471786822, 0.1953783604286371, 0.17815655067322717, 0.1421184570438439, 0.15606680374232032, 0.11839777020917785, 0.16649758112767052, 0.14315063794774396, 0.189208472147584, 0.12200751522135352, 0.1395419654586623, 0.14430216002848842, 0.16856417991220954, 0.13841523398314753, 0.13583966170347508, 0.1860557292257586, 0.22826908907342344, 0.15990328013656602, 0.09429271408026257, 0.11737004027611787, 0.17593461990116105, 0.10295186717543872, 0.2878016437734327, 0.13943040773512858, 0.15579153302936785, 0.1516921505812676, 0.07427710423906965, 0.1651477648486053, 0.18383928364323032, 0.16476259116203557, 0.19704106233773694, 0.1969715934847632, 0.0858745416025481, 0.14020391139051608, 0.12458715542790391, 0.1810855499558872, 0.15147487272418317, 0.13093824648568708, 0.13882230246259322, 0.09719423378907865, 0.154777247939379, 0.14455455535602185, 0.1971515015729012, 0.13923548432367464, 0.1378387221766095, 0.22516531449171806, 0.11224089010107903, 0.13224700045201088, 0.1391246926880652, 0.20998900545941246, 0.15834076720620358, 0.16292551231961097, 0.1350061733636164, 0.17523253096207497, 0.12355979321704758, 0.176249849760244, 0.1297966222609243, 0.22125783706865004, 0.23110226607851445, 0.1382593810558319, 0.17437048286439913, 0.10575787104185551, 0.18634279769274498, 0.16130686046615725, 0.18834887553126584, 0.19844029128791826, 1.2897793780411444, 3.1410180993618506, 3.843022830063297, 11.044087275382012, 21.730421050902336, 32.507266459926484, 40.715838017002234, 52.10680107916556, 56.05529815919938, 57.55772675237348, 59.281616287846724, 70.71081853681996, 77.14199158453172, 82.29396204794608, 77.8136190291374, 60.46940019053798, 46.89446926116944, 51.04734536140196, 50.654900458551225, 67.26336894496795, 63.71886814794233, 60.91307124783916, 57.499263824955115, 69.16624407614432, 66.345534324646, 52.855161851452245, 49.97170202193722, 43.47230718981835, 37.10224074702109, 23.21680126651641, 18.594266445406024, 11.770785777799546, 2.4954555399956244, 0.2741523165135615, 0.15394942865016, 0.1558844441728246, 0.10419241633386382, 0.15289604243251587, 0.16745791830603154, 0.14926898383325146, 0.08613694969925188, 0.1262635932934861, 0.10580899974992199, 0.12351810271220824, 0.23301791489845325, 0.16179245295784167, 0.08873340553574025, 0.16484159014878735, 0.07343493612302888, 0.26456969039094064, 0.177276193074161, 0.1924072722754171, 0.13969179693489306, 0.07929304194065832, 0.1627835562272418, 0.18827595928263283, 0.14456598538785212, 0.1585344035899447, 0.14501175662923246, 0.1551230600283992, 0.13667751674450215, 0.07623438227681384, 0.13129024856513546, 0.19807250779722968, 0.050206755723563895, 0.1810253048015218, 0.16043002687154279, 0.11907481573401921, 0.12815890247903525, 0.1548882081143318, 0.12547669076030293, 0.16103460813962645, 0.09658805905811249, 0.15185692077202184, 0.1612493119412853, 0.1354119394935908, 0.32062011500520093, 0.11958443274300908, 0.1098768883234551, 0.14673474965797317, 0.24830938226753668, 0.16340738162398338, 0.3529185963974845, 0.1533463795579249, 0.16340488417735025, 0.24600477528668221, 0.20925739149172462, 0.12410397611318097, 0.1827434101893056, 0.09926100877384025, 0.1729980823133261, 0.12614910911408164, 0.12108037263275155, 0.23434329297273393, 0.05631436488681263, 0.11973762734522743, 0.11176275164489785, 0.17133944067022494, 0.22953195437308282, 0.15313826411241485, 0.14548982613750044, 0.19783819214470927, 0.08571448285252818, 0.11320105107921748, 0.27341276587497804, 0.20560443912061954, 0.07301408572182541], [0.060708055332783735, 0.022959191607491627, 0.013695814432726513, 0.05473021380302887, 0.0830501746085863, 0.005648570236629777, 0.03958026585619777, 0.0266486729660462, 0.032768706160206953, 0.03726301076371343, 0.04326095827104103, 0.061479950203530254, 0.011210976649195918, 0.04621719580984885, 0.010667832759809832, 0.022304420089048725, 0.0521103807935311, 0.017152400274250298, 0.030168613321298075, 0.07129778830154289, 0.019568212578193318, 0.012357085361145438, 0.04722177073539746, 0.04336201292913287, 0.016326396613411846, 0.01936175379781954, 0.053378306103930365, 0.03654864143520113, 0.0095626886843914, 0.021673979523080974, 0.00962071505660612, 0.010929830999474132, 0.019971010117461125, 0.0359388392779135, 0.06348825352747114, 0.024983532982127323, 0.027177511121056257, 0.020589857857914704, 0.043692495598788225, 0.03675725866830157, 0.023387691396619045, 0.020355760540452697, 0.05907547983130621, 0.007981804007994793, 0.035123242921526396, 0.0480445338443162, 0.036294545392475785, 0.013496744570382422, 0.03954150180722918, 0.07888962003973224, 0.06477781316085209, 0.032426165266623425, 0.03737171097928959, 0.031061280038087603, 0.03578646438977411, 0.040279202343475436, 0.09083474640764537, 0.0942721369586164, 0.024437883027618932, 0.0712518306869653, 0.06453044337010191, 0.03950244281440973, 0.024312212049300154, 0.0907986177011363, 0.011148015713138927, 0.263094695345048, 1.2287530591410976, 3.471395661753993, 8.122576532825347, 11.991413216437063, 31.87655325858824, 45.533979477420935, 56.90550719538043, 75.22115199796616, 74.33141723755868, 76.8966708644744, 88.54935015401533, 83.01770210266113, 85.98517125652683, 86.16250161201724, 95.07635454977714, 94.9196009482107, 98.72220546968522, 102.7427133437126, 90.38840047774777, 108.46715373377647, 94.71505718846475, 92.5097280933011, 90.2609391366282, 85.12021803086805, 81.43516694345783, 89.75314909412016, 84.46665702327606, 85.57184757724886, 90.32136717150289, 93.2046308825093, 91.22421049302625, 80.44505873034078, 73.4654991088375, 77.77996509305893, 68.9456735118743, 43.00025386195029, 13.619292936017438, 3.375163986798256, 0.8087279491366879, 0.08891024927218115, 0.09060632197126266, 0.007998361562063258, 0.029392629456255707, 0.06365165242084092, 0.10229457139728532, 0.01812505423121395, 0.03051237612512083, 0.03525513261857052, 0.03300505194572672, 0.05944883661164392, 0.1021629881354109, 0.10796936769639293, 0.047156101678528135, 0.04037153126010972, 0.0522370227882939, 0.017305414845806458, 0.010099818783571884, 0.05146474104314562, 0.04255165661414785, 0.044882754915423935, 0.016097006906244545, 0.03883419197893912, 0.04470405724620627, 0.0191801967054245, 0.060294007792347865, 0.04186191701240117, 0.03886513043976119, 0.05096736994962539, 0.03149808230509441, 0.027666646769390475, 0.0488313329556296, 0.022876569024857976, 0.019769427486725395, 0.03614135079025742, 0.02915590254199361, 0.061928636409462466, 0.11203631398177917, 0.05977738107885084, 0.02957801890349196, 0.041612160857766874, 0.07622564887447704, 0.04539365895212658, 0.05573677289630136, 0.06586575760476052, 0.04826534719717118, 0.05846712558019546, 0.047676217922520255, 0.06934208074404348, 0.05168084295526628, 0.014273363330792037, 0.0281689380626044, 0.06453144694528272, 0.01180944740847354, 0.044024740270669424, 0.04226576409212524, 0.01976553576007005, 0.06513666406634354, 0.07331091414896712, 0.07232598554823669, 0.0510362757279748, 0.0341944838874042, 0.03190503587135144, 0.007672751211606327, 0.04495659813044533, 0.0593204019711383, 0.01564296095767209, 0.04033010122516463, 0.00950235159947507, 0.10522559315206544, 0.03430559344950222, 0.04341411839930281, 0.03994903760030866, 0.060117501134593646, 0.049918599411725044, 0.026974133929357897, 0.011001214114648682, 0.04093773918406617, 0.013934604996334643, 0.06224298526743247, 0.0708273796725177, 0.06882714708485911, 0.0578778469183993, 0.016803485529136755, 0.02059825801200444, 0.055006936252597845, 0.09209474653846796, 0.15290604754080697, 0.02807022188790143, 0.029307896301390666, 0.06694212646013306, 0.07721679810915263, 0.0576734240166843, 0.014430385499802089, 0.007479603208916923, 0.02875220101897515, 0.03131238067702901, 0.017658717359506318, 0.030087193496705546, 0.029505845760145498, 0.049607215314022, 0.025273095065307234, 0.048174519812868494, 0.022620496475287986, 0.017238403219849836, 0.01846856231080188, 0.014587952548848286, 0.022999909180667133, 0.046890272999242436, 0.07366742848628953, 0.01917309507036642, 0.04389494965453783, 0.015262124286363683, 0.03885031046886598, 0.018755510118940187, 0.03178589196214753, 0.026031608295236385, 0.04081185561634841, 0.052211213286124894, 0.04792106345355992, 0.03955285906070664, 0.05325288601940679, 0.005195723215658819, 0.029461320729986317, 0.028955212403689663, 0.0358674475442498, 0.05936784962672861, 0.10804774615192607, 0.08183315201031585, 0.011299138047522115, 0.03754942422552455, 0.02572900548036541, 0.015474665804856248, 0.025868374110770323, 0.09422754298054403, 0.0322203251022485, 0.5941614917209072, 1.9761495412357393, 5.160858554224815, 10.596809598707384, 15.329630682545325, 36.90942879646055, 51.60388262041154, 64.95345769389984, 83.39098622722011, 85.16060275416221, 86.96451648589104, 97.06191324418592, 95.08944742141232, 98.15948655528408, 97.45202433678412, 107.39614271348523, 107.44913393451323, 110.76989096979942, 114.64093300604053, 100.7925501177388, 119.5261352292953, 106.50021845294584, 108.35968863579535, 104.93149003674908, 97.82425726613691, 97.12019182020619, 104.05586011948125, 98.23092860560264, 99.66897933713852, 104.77085328871205, 104.43160749250843, 104.50549710181453, 93.62547766777777, 87.93200831259452, 91.0880179559031, 81.78668975830078, 54.09975344134916, 18.66691658573766, 4.791833633376706, 0.9934609203088669, 0.10995964114103587, 0.14631186912377037, 0.02909223872026609, 0.030708948540831768, 0.07636688484419739, 0.016258818082391255, 0.012181911696379465, 0.029229797467949892, 0.03958512668407733, 0.022122018384717168, 0.06250988263937254, 0.1043369158381416, 0.10574769739422107, 0.13811264457481523, 0.012484378530643882, 0.07541122080217447, 0.04273126209755579, 0.023155218185556513, 0.07102421830378233, 0.008465839425973114, 0.02151945767353379, 0.03427103522323793, 0.013937668390421858, 0.0970773900588674, 0.049531292170286186, 0.02454505489778615, 0.057973286152006163, 0.053470941455734354, 0.03664534854432268, 0.03308123555935679, 0.07106849818580574, 0.030796790097449577, 0.049220172372917016, 0.0229646633904908, 0.007972609995293522, 0.04657774360009259, 0.024682491071402066, 0.0630430338693963, 0.050857141388640295, 0.06287393145143025, 0.006424903150482645, 0.04921063457825973, 0.03466773853306809, 0.024409104934743336, 0.0817645411758173, 0.018958458301400947, 0.060562096431010196, 0.03726397603449803, 0.013186729854844032, 0.03653428494750011, 0.02073664030420684, 0.07493032442946589, 0.030125720058417613, 0.05079517253644524, 0.024323607607173826, 0.042140688747167594, 0.05821985538087546, 0.048256154142079816, 0.05446686724861784, 0.02815178726919957, 0.06455662825535383, 0.05217338769486354, 0.05221273397065459, 0.029808942701727636, 0.048872180763752236, 0.04807637628888892, 0.04914506894326018, 0.0416943506007233, 0.040867232281955025, 0.0877317072703473, 0.021472709073174386, 0.1657941438738377, 0.1967389632256762, 0.11161416123110442, 0.2657059213567165, 0.14867379480311949, 0.10158906570605694, 0.14520576073517724, 0.12328635345423415, 0.17473173928597283, 0.22030404228116238, 0.14309312006638897, 0.15720790702729456, 0.0656851370548529, 0.1450439629655692, 0.13425189851512834, 0.16522316322211297, 0.2754743697662508, 0.09450597763662377, 0.13979213913121533, 0.19940879496355213, 0.13755309395492077, 0.1379989724486105, 0.0946078520087946, 0.1519803528583819, 0.08937203175117893, 0.13097914025908516, 0.12765041928017332, 0.15533571071442098, 0.09156976180571703, 0.12768195145913672, 0.26610652405408125, 0.1324144366287416, 0.18864263960671043, 0.1482421502230629, 0.15491324386769725, 0.2075203177669356, 0.12844480649237672, 0.14382554608727657, 0.22797486534522426, 0.2122741691287487, 0.10271181352436544, 0.12356233662895619, 0.08355444432386468, 0.2046944645624007, 0.1716734856487282, 0.13357456953775498, 0.11182603816832266, 0.1585827437379668, 0.11147158460751658, 0.17633775068867594, 0.16600489466180726, 0.05419973621986086, 0.14366669009529776, 0.13557298649703303, 0.20260715076038915, 0.16683197850661893, 0.22544861380611697, 0.1736778014850232, 0.1023703987800306, 0.1892958521362274, 0.13239940598366723, 0.21151292288014967, 0.1610273149825873, 0.22023282674772127, 0.22300513040634895, 0.8329438658491258, 3.2467088151362637, 8.072072094486606, 16.923423044143185, 24.546065061323105, 52.17122208687567, 70.06960515053042, 83.05698071756672, 104.77119845728721, 104.0046496545115, 103.26922878142327, 112.38019650982274, 109.53273619374922, 114.27208900451662, 113.78811559369488, 120.64131998246717, 120.03946365848665, 126.40170497279014, 128.7576295483497, 119.0970200877036, 138.89630533033804, 123.03114168105589, 128.31011064590948, 122.62047736875473, 116.31372190290882, 112.06570086940643, 118.61099919965191, 111.35390835423624, 115.01620969464703, 120.80609875340616, 121.91374471110683, 118.89115056683941, 109.98317333959766, 106.05360169564526, 106.24113805832403, 94.86097720361526, 65.84218440517303, 25.56065670905575, 6.239781975746156, 1.5789072119420575, 0.44267204800440424, 0.310148612385796, 0.13201314445224502, 0.1573885505598399, 0.2217300076999011, 0.15665404077979828, 0.09354777018269224, 0.15469287101539875, 0.12392338620679033, 0.13865187854295777, 0.18334632138571433, 0.29261914171999504, 0.17227351635454163, 0.2099076162783369, 0.08932533869219404, 0.17619015618918404, 0.16126605862331006, 0.15448397416020596, 0.25969396976213305, 0.19281455525948157, 0.2220391854643822, 0.14555909580761386, 0.1311243598860118, 0.18255821609449002, 0.08697890331067386, 0.24766471927925465, 0.11879235145545776, 0.11651461883898705, 0.13965160796238532, 0.1106730835031598, 0.19052071947484248, 0.07775059285303278, 0.1220409089939729, 0.08541786893000526, 0.09152275465068319, 0.2734077096946778, 0.10814324667256688, 0.21614763224797867, 0.17591012040934256, 0.11232019552300054, 0.1587601237359547, 0.21748468550222538, 0.1395279920149234, 0.1269250719117061, 0.3026759149807115, 0.11387559149654643, 0.25127590453672793, 0.2321089209327775, 0.1473879162222147, 0.18015501359778066, 0.13842770589455483, 0.1504130901828889, 0.1233880363044239, 0.10093205338043552, 0.1444057964028851, 0.19319617429808264, 0.1319987726427855, 0.1379813983916275, 0.18974870203002808, 0.2161666465502593, 0.12048322241753341, 0.14394015284074893, 0.20862585925046476, 0.09492188677071564, 0.16480199872486054, 0.2214370709994147, 0.1250230594568195, 0.19197791063737488, 0.0971118793372185, 0.20901988891343917, 0.14256792082901926], [0.005952454812359066, 0.009738702173044365, 0.038551666413343726, 0.040891528760473576, 0.0407592904934239, 0.032447362919488264, 0.03849928132108143, 0.052760333618930275, 0.03455862463001282, 0.0034534125616999286, 0.03275594313538844, 0.05130868510253007, 0.10149250798408063, 0.03391073258112996, 0.07913093773588058, 0.03874950861978916, 0.03391168253015607, 0.0922928951800831, 0.07543552111113265, 0.061082281622915506, 0.05123584546268948, 0.008667506326380517, 0.03503520409726808, 0.03669048261438166, 0.04821375883635014, 0.03742954295669352, 0.038691328072379676, 0.03279823118880872, 0.027753670527149114, 0.03893411665734264, 0.047561982721691175, 0.025476811250912088, 0.0878236991082949, 0.07916007972052021, 0.01434945788670091, 0.07541910384691532, 0.054505148662194136, 0.06585101041221811, 0.0186439236671093, 0.031980217825020515, 0.0695724587046331, 0.1041638106107712, 0.01661710591325837, 0.018257022452270313, 0.030586767093008085, 0.042785960775349414, 0.03931438738119699, 0.05711534045516484, 0.035682130875366355, 0.058282682251545696, 0.06588219019073634, 0.025958944855618383, 0.03707131258242073, 0.06200522221925278, 0.03767648756864571, 0.10014305942721906, 0.06465140099246657, 0.030907964777021162, 0.026552833451498902, 0.04993445360131803, 0.02510561866896047, 0.036049619422204075, 0.22762258747412314, 2.7298529494193295, 8.924981682531296, 25.242609362448416, 39.293296337127686, 62.01015034029561, 69.05866130705803, 66.03194867410969, 75.24008135641776, 88.22034958870181, 86.99152592689761, 89.05923474219539, 75.43591745438115, 72.6584949801045, 71.88319929184453, 73.90024677399667, 77.10409364392682, 79.8029431989116, 64.53675293153333, 56.44884524806854, 63.39792805333292, 53.69681619828748, 71.58552277472712, 63.40268588835194, 70.03947350286668, 71.19942034444502, 74.80258018739762, 83.6745814354189, 71.92827516986479, 61.56673031468546, 66.36968043542677, 64.60705749450192, 66.13061981816446, 65.19886862847113, 58.791449454522905, 74.38636179893248, 77.81847492341073, 77.58253651280558, 86.23523019975232, 90.59285794534992, 78.80236225743448, 47.959961506628225, 21.614303204321093, 3.4670969891932706, 1.1147529247307009, 0.5351545805892637, 0.27361826129978706, 0.15252159397688606, 0.04370409800040145, 0.0804672402239615, 0.023624761135227258, 0.08141118312074293, 0.027184591688696417, 0.026649033027370612, 0.07640815400067838, 0.05939951970151836, 0.03807032954007868, 0.045308309096482494, 0.017160112864427993, 0.020686666473686215, 0.03668817285928996, 0.023286489266601783, 0.055131517470844334, 0.016573429325475328, 0.06022438955222888, 0.06875223900762296, 0.0067385486439771715, 0.03653153852229157, 0.03244161342961654, 0.08026288627015968, 0.028908515514265147, 0.031042524290481405, 0.06140269789724581, 0.03487881490840547, 0.0922114830163698, 0.05747137215709495, 0.024851061058260744, 0.04130129003897309, 0.014652279994240212, 0.07248358515601966, 0.1018425565393221, 0.07372806434549632, 0.022697769848990346, 0.04823613243417875, 0.043327259350447886, 0.09962601902624292, 0.02866689521338671, 0.10098079189417825, 0.03219295661115358, 0.01408468736636062, 0.03346494601799115, 0.06473385503575688, 0.024773272490429304, 0.05564592635980057, 0.04279606164463105, 0.023347626913398988, 0.022804552929535992, 0.034158044915285804, 0.038749968272543726, 0.03447687155717323, 0.01723033631400716, 0.05007454426959158, 0.06102055791885622, 0.04005523270837242, 0.05106247593498519, 0.07346816135630493, 0.042386143318107056, 0.09685106470339722, 0.0586898273397838, 0.051776703537231496, 0.04105686968673141, 0.01918489090918053, 0.0442165227216338, 0.06489897762695629, 0.022683807896570336, 0.017545820897324912, 0.010256745191591402, 0.05214093621039102, 0.03054512063822439, 0.04872889933927406, 0.02193181024443719, 0.06367934649930367, 0.047544994721970255, 0.055721684794632666, 0.029193044399782538, 0.06760683030851426, 0.0416444169898187, 0.04522051542035995, 0.044095645538501205, 0.00583528405836513, 0.08337259037239898, 0.08006613190856673, 0.07349780129809534, 0.08323195195125957, 0.0012547295656047703, 0.018631750529992486, 0.06707724138733841, 0.05780815206948788, 0.037811131351777626, 0.016030322782875552, 0.05251310172400648, 0.05324359337288526, 0.023212496664435155, 0.035855450607355566, 0.030154212783541412, 0.06126998848612271, 0.07666127711173988, 0.039839935188572255, 0.07986365487017939, 0.02449315627135577, 0.03710338102293111, 0.0269231277953593, 0.040188317502578425, 0.021585507859145443, 0.04927462207213525, 0.08391781514810939, 0.058378883742637215, 0.007054116060551737, 0.06739710607836324, 0.03371765927201317, 0.031109641253527616, 0.054956929863340435, 0.0089713808472058, 0.03546114898316803, 0.017824671156103575, 0.03804468091637377, 0.0708045042870987, 0.04330934438433859, 0.02623669194778608, 0.04438492416914913, 0.009267631835574585, 0.040819198569102634, 0.10291706380103866, 0.026027398642092466, 0.05734700161302763, 0.020480150236718116, 0.6322955099805709, 4.928840062310619, 12.76146665696175, 29.50607276731922, 46.447526947144546, 70.39287905539237, 79.97354276718633, 75.8576899190103, 88.52445879290181, 103.19463314548616, 98.37030610730572, 100.16498657964893, 88.45409147201046, 86.20844825621575, 84.24236020734234, 86.30951204607564, 91.13303892074093, 92.80811848178988, 85.0116938929404, 75.47944791855352, 81.17628266734462, 77.26080017705118, 86.26655424794843, 82.07183822508782, 84.85511287566155, 83.78927938399777, 84.38485991570258, 96.3916115606985, 79.63947449961017, 75.16888249304988, 79.82562234324794, 74.93053574715891, 76.94337060374599, 79.39270250258907, 69.71298325446345, 86.80922985076906, 89.32178251204952, 89.75896204671552, 96.44287693885066, 103.27954461497646, 92.88095689588978, 56.72364257997083, 27.2082620282327, 5.356194549991239, 2.111810229478344, 0.45506977145710303, 0.2544084687026278, 0.06494874269851754, 0.03555038673502784, 0.1074994340418808, 0.05900101991550577, 0.00891104376228947, 0.06226589512680808, 0.05669957304733896, 0.015746650000613545, 0.028413243501657443, 0.03860040109664683, 0.03980728835167904, 0.034442926201248364, 0.06262480731933348, 0.04376355791464449, 0.0746354342047726, 0.04173368155475586, 0.012367122070563417, 0.06964658537218649, 0.040567381637952024, 0.03884698947771423, 0.043191018273993846, 0.035499131622453856, 0.05795138369825098, 0.032209902476038665, 0.009004420304160205, 0.03782361092406415, 0.06352039474633432, 0.05343481274922529, 0.023015485663387566, 0.027409679812168884, 0.025753120013001948, 0.08266536864422022, 0.023568754362302925, 0.020393961514796943, 0.05014554912885351, 0.05233082642418243, 0.10191121333909613, 0.009978101776552298, 0.042111067957575285, 0.03276235529131467, 0.06345101016303224, 0.025106484348314907, 0.03567517862745351, 0.06911309706347604, 0.0828480959359196, 0.0570754579178268, 0.009010068287381963, 0.05406496986266106, 0.04837286763734395, 0.04815702236467793, 0.0222881828554936, 0.013762609638844528, 0.09631789049073573, 0.02979401739374284, 0.015666488475436648, 0.03484308839805665, 0.03618878312408924, 0.026484688015414343, 0.02926218575016866, 0.020394110901942177, 0.05749029069838505, 0.10425804708633693, 0.045741953166021455, 0.041682560507568626, 0.046843959153780056, 0.021049658084408413, 0.039160120255884626, 0.13003703597332203, 0.08509415847760055, 0.07945014359129053, 0.13630455449944542, 0.18574327260496157, 0.13627219494552384, 0.1017205493765012, 0.13705440135973115, 0.10975000884143576, 0.09403579883397588, 0.15513401508571642, 0.14753905004791676, 0.17692359344613168, 0.12754388709342288, 0.19059092377222356, 0.12211023995112028, 0.17048837827338328, 0.1408553772395657, 0.10044297518869562, 0.19641809495947055, 0.10125346556906739, 0.09955976774255115, 0.1781308560842468, 0.1658797618602553, 0.23191249598899197, 0.09103103345560451, 0.1048985502171901, 0.12713569246472853, 0.09756744884315038, 0.11451167430007651, 0.11108589764203756, 0.18551243499161738, 0.2128067228101915, 0.14911653233631966, 0.10929297610756852, 0.2617560333061603, 0.24830553650615678, 0.15662853005191973, 0.12294242594150767, 0.10249237529933454, 0.1003735829445143, 0.24529467306790814, 0.1413505917955791, 0.12878570795780228, 0.14546742572659446, 0.0976533962473754, 0.16347628357189317, 0.24083844686467804, 0.16442868407935868, 0.13530830311919415, 0.11095396197971799, 0.08623810394877389, 0.12111828632412419, 0.14688891719185537, 0.1411822363133392, 0.2430504184937285, 0.18841135766237013, 0.12016629184325857, 0.11699438906244694, 0.17072264796062825, 0.13919056092779483, 0.10373346838018588, 1.116325427447596, 7.343323173061495, 18.568314083160896, 41.37670247785507, 60.23772931868031, 86.0881805419922, 95.42525722134499, 95.31235571830504, 103.1707537558771, 115.69495231874528, 112.04072321614912, 113.81838844668482, 99.92450606438422, 96.59129942617109, 96.27429346884452, 98.64300497116582, 103.46890095741519, 104.0876626968384, 89.78994092633648, 84.73908132122409, 88.35658919426703, 77.65480226086032, 96.53882595800586, 87.38340208607336, 91.86417656560099, 91.61552967563753, 96.45495783898139, 104.52054331379553, 95.3445505326794, 89.70713969199889, 89.60491488056799, 87.33178369460568, 90.00329432948944, 88.44481898892312, 84.08160578820014, 100.35046762035739, 103.24993072017547, 101.734632830466, 110.79326829602643, 113.6948416309972, 108.08105130349438, 70.1179365957937, 34.91518205212009, 9.196617584074698, 4.027211204651864, 1.1848807358934035, 0.5176102478177317, 0.22366217337548736, 0.1682229796724935, 0.15894341793271805, 0.16666886306578116, 0.2141492306104591, 0.09574887868497642, 0.12731619810144748, 0.18615259338290463, 0.08664792268386773, 0.1174258114770055, 0.08723116074238094, 0.12017664169111561, 0.12759723745646978, 0.14066687364491726, 0.11543458808333644, 0.12708206631002888, 0.08607999106208164, 0.1346650497326928, 0.1199462484087675, 0.12193542634767872, 0.09684749473367008, 0.11046059369560211, 0.1478770786836263, 0.10799151529828388, 0.14112577563331974, 0.22088561026800066, 0.14894331985663983, 0.22272003844620722, 0.11175576492302841, 0.07354248720671862, 0.13541797626643412, 0.14827584276997274, 0.14444566361846464, 0.2819645134431701, 0.18012194924296873, 0.14904891741612267, 0.17243105467529068, 0.1567269417066728, 0.1860794626296528, 0.1417136561846541, 0.2962303576209853, 0.11915789030852819, 0.19887100124070722, 0.1422639831059402, 0.12128199931354293, 0.08561924280178163, 0.17467998238580842, 0.16006169179754873, 0.10498694144189359, 0.10809899743406043, 0.10800908169438762, 0.18550098963802863, 0.14744321244858927, 0.0689253289132349, 0.145971542224288, 0.1498600972756263, 0.1015377454760094, 0.14119996358790707, 0.22253102923352874, 0.138669743713352, 0.21991502283321274, 0.19376412124162723, 0.17315015076629578, 0.18666093868594016, 0.20362900479906992, 0.09227365871230442, 0.295448059276227], [0.06941831415338863, 0.058731422083632606, 0.034710302378141114, 0.010420546281121431, 0.031492736926602746, 0.023437546483511408, 0.0756393464642667, 0.03278351080934367, 0.08656665607686005, 0.01820948669656871, 0.006731259317377643, 0.034644955078199986, 0.047968675818053946, 0.00866711849436885, 0.013941025770750019, 0.027824696453828967, 0.10937472534996849, 0.0482349603196546, 0.07844797801226377, 0.019588333877524542, 0.024084517311665322, 0.02682426989439034, 0.04183080235135652, 0.0277015152612641, 0.012634528890973138, 0.02489382217097427, 0.031135992762903054, 0.04510366402926945, 0.017747623778338877, 0.02436144277453423, 0.022363301606908925, 0.03277495360722946, 0.006103946784165718, 0.02045749127113771, 0.018876590315372716, 0.03657561922145467, 0.008194751553087225, 0.011907505705171536, 0.03475634043195075, 0.08526298127347424, 0.02321721576604872, 0.04667001122969293, 0.03004620587753673, 0.06889729775608548, 0.029463996292061867, 0.012392267949068019, 0.043490696548213886, 0.045201501118079315, 0.024713538699753346, 0.039418728556483984, 0.03974445382012956, 0.10311056228895342, 0.05258683385627885, 0.05445275207861297, 0.05928410472528589, 0.0183454500661502, 0.03954517902926572, 0.09782998717480129, 0.06416862004346426, 0.1878573228755305, 2.324988842010498, 12.8570322644326, 28.19447925013881, 54.12159319846861, 74.72425829979682, 84.50224076547931, 92.70938457981234, 81.36850234000914, 73.00609542477515, 65.2978967082116, 65.29902635082122, 70.42478361437398, 60.978441469130985, 65.31362541260259, 49.983190644171934, 39.379847357350016, 43.9658982523026, 32.53107132450227, 42.35718911693942, 37.33417049531014, 19.672237711568034, 28.315866801046557, 29.30647707754566, 24.48614497338572, 39.14173203129923, 37.04444070016184, 25.86178687310988, 39.54892504599787, 52.77748715492987, 43.51288018688079, 41.196591161912494, 40.21354321510562, 32.77040454649156, 46.28331299751036, 44.77397318809263, 43.279169682533514, 45.1683125957366, 46.15907192230225, 55.15362762635755, 59.98396373564198, 78.53343671368015, 75.66511723303026, 86.2270716697939, 78.30932817151471, 72.12666865318053, 45.09340709255588, 28.737953055289488, 18.464996891637004, 10.243101043085899, 4.402067709353663, 0.9104902273224247, 0.12329641218867995, 0.17238862872604402, 0.0424582053787045, 0.01878084081615652, 0.02175200749338875, 0.017611468886776317, 0.04367929973429249, 0.06201344234268032, 0.01446525494928562, 0.03777931572028226, 0.020283307775013873, 0.09121291805058719, 0.032243250283382596, 0.04191190041902085, 0.009976723775898498, 0.0015446087373645917, 0.03519085784172339, 0.04408325023588635, 0.08166015403525484, 0.05953366169705988, 0.03525168139247164, 0.0285897386680928, 0.034084626879062385, 0.06738033641370074, 0.0159777854306383, 0.1139733749592016, 0.04166099896293975, 0.09092650841921569, 0.043657768833180594, 0.013665355734467028, 0.020831725222148725, 0.03506112851262574, 0.02154679169067212, 0.0397789124549637, 0.0540307755281608, 0.050214972016551805, 0.06808702188033251, 0.030441694938006903, 0.043790784679473414, 0.04858113630043884, 0.027443519831004164, 0.04878693816041754, 0.07077691746094535, 0.053201837750572356, 0.011545355833556143, 0.0587602538026629, 0.03467601228265032, 0.02482586825687078, 0.10834232228057039, 0.008137966243309841, 0.06710644465901199, 0.08920181467528306, 0.041910674678342, 0.04181067722158567, 0.04114801116708306, 0.03547326849413014, 0.07021866152964293, 0.04221072067476569, 0.020283263724958225, 0.00172136006444963, 0.0265473559228403, 0.011803607903270712, 0.049613926244238694, 0.010265133854362273, 0.04747110171123378, 0.04751438950939525, 0.032807837931379195, 0.038841063787619916, 0.02906011856882082, 0.07373261490776654, 0.03655147596052097, 0.09727968323615291, 0.005597894478048529, 0.0586842080848592, 0.09619930008005712, 0.0473777347454621, 0.019229105673730373, 0.10772080280848088, 0.0018917059388777783, 0.010124431273359205, 0.05884093052196888, 0.06378212868566475, 0.029030543744503975, 0.08556809877195666, 0.028312458889558915, 0.0163043026376756, 0.05881710901796337, 0.06168921861136633, 0.03512976616020164, 0.010806392209844725, 0.052600251886272625, 0.019729493238452463, 0.023280818300742297, 0.04921227017597807, 0.018904943229450334, 0.019365258650073124, 0.027769850304109917, 0.018429754211777644, 0.019481152431258274, 0.0619309155210372, 0.08043897924043479, 0.025355750206677664, 0.018825593757473173, 0.017829007213755, 0.08108984754090348, 0.06487662318132578, 0.07329399126671976, 0.04302521386454183, 0.04527277027767512, 0.011619495907648197, 0.019829845010873773, 0.012850843392492784, 0.03317664414944668, 0.026526347876736717, 0.09106327043545824, 0.061716928011587555, 0.04959038819276518, 0.03617564088574821, 0.03281758640021567, 0.03629863247155182, 0.0394178896902069, 0.06988804096416121, 0.06269563597837283, 0.1069870897598805, 0.16563105907651687, 3.7195841247035615, 17.979734982213667, 36.34816508139334, 65.4205374563894, 84.54431995268791, 97.4122985716789, 103.74999369344404, 94.92883420759632, 85.68309384007608, 79.52777324184295, 75.16705466854957, 82.6932514867475, 73.55339157965876, 79.74397428574102, 62.487949940466116, 50.45179620865853, 54.831961893266254, 49.69391584396363, 56.98242487445955, 55.24050420330417, 33.04270921214935, 38.967339531067886, 43.15759581904258, 35.56163964733001, 53.059180013595096, 49.66743592293032, 43.88061415764594, 58.19022070976996, 69.00960814568305, 58.92181727194018, 57.52249994585591, 50.81957332549557, 42.99655114450763, 55.676836506012954, 58.12124583028979, 57.221532560163936, 68.6778070080665, 57.888845397580056, 66.58850946734029, 69.22335378585323, 91.63344706258466, 85.1465214452436, 97.2252485829015, 93.12706993472193, 85.08337128546931, 54.93637538725331, 36.0322730771957, 23.055044681795184, 13.1304891263285, 5.886307291446194, 1.3614643701622564, 0.21531930734072963, 0.07348398107194132, 0.09632544411766915, 0.04149037203000438, 0.01585351352039124, 0.07170427455416611, 0.045655224352113666, 0.06986646026733422, 0.06695205495963175, 0.019898381151799715, 0.022217086065680753, 0.032355321285825585, 0.0535200591829996, 0.048602077313849044, 0.02452170645307389, 0.050567671236011295, 0.009138884056629914, 0.04107195012752087, 0.05915479291410697, 0.05949607742349467, 0.06627605131436741, 0.022681955879013387, 0.05161690908754545, 0.06868256331090966, 0.02645717779805343, 0.09679191505476352, 0.0532574710556336, 0.024136768338540872, 0.012242166426843934, 0.04730202227590546, 0.004083661366284135, 0.03265575798709066, 0.049410246447810245, 0.0191853333249568, 0.053939706826161955, 0.013832315979074809, 0.08671225108686956, 0.06363098336864384, 0.05756771537445246, 0.0667403772052738, 0.05569257728394963, 0.0434074764169993, 0.12536585315941803, 0.05280405042632934, 0.044167818681847666, 0.03642848054427774, 0.07031813804661075, 0.04187976686103691, 0.04008874905505969, 0.0357135481411411, 0.061293863616282904, 0.04028584432577895, 0.03369193786995546, 0.03311969317315567, 0.059898652797264446, 0.03498479934229005, 0.026534625456758568, 0.09543900378048421, 0.03491280622960579, 0.053318520602319515, 0.04731569694535387, 0.042444492404859875, 0.09888443825466019, 0.03292355168190214, 0.052485668115438, 0.14004113302836496, 0.177813894866455, 0.18068974296892845, 0.16509041550659365, 0.20011092986791365, 0.12883772532786095, 0.19174946321835443, 0.09068393433887152, 0.2321647993859745, 0.2700415193553894, 0.15683290698835928, 0.09526759926830569, 0.35752238645668954, 0.07636077912344087, 0.04709371147797473, 0.12518563097523105, 0.18860065798845985, 0.14209276245486352, 0.18805503484702882, 0.13017477858210766, 0.12854244439832627, 0.14724013786162102, 0.10102184654604043, 0.09033956249514896, 0.1128447206029969, 0.11366590557079162, 0.13516600994813827, 0.23084970221163767, 0.10223106270836246, 0.1178048947645772, 0.11376275440617917, 0.24700743116198048, 0.10551480666523981, 0.1258641090844908, 0.11934453997039988, 0.12023513250413442, 0.10963164059625519, 0.15479155846180456, 0.13874295107539625, 0.2736272398502596, 0.13663855351267323, 0.13541858913677354, 0.11881050007838397, 0.08839194482612996, 0.14958928519439313, 0.11359770842377218, 0.1430772160810809, 0.1512566449180726, 0.15877809615865832, 0.11595165912782955, 0.13468809365745515, 0.14013962129191046, 0.10748244221172026, 0.1836109434765193, 0.0717532045898899, 0.24352022957417274, 0.24450145030934967, 0.22590797544727403, 0.23585484573437324, 0.41978897106262947, 6.163417841157606, 23.168636521985455, 47.66961982173305, 80.25801658630371, 100.20970159961333, 112.16754128856044, 115.62812297574936, 106.34916797760995, 97.34166452961584, 90.73753849152597, 90.35822176164197, 95.73901545616889, 81.84488204217728, 88.90005711586245, 70.98437247737762, 60.35849125154557, 64.09401539833316, 50.481217907321074, 64.88115272214337, 58.55768795936339, 35.802167231036776, 47.961314724337676, 49.420656081168886, 38.92523680963824, 60.87497718872563, 56.16767406463624, 45.51278691137991, 60.129899440273164, 75.90446810568534, 63.35023595440773, 61.39336547543926, 58.13518201151202, 52.214701560235795, 68.14652196822628, 65.57591038365518, 63.88743200609761, 66.88234990642917, 67.77261810918009, 80.70685340512185, 84.80261587327527, 103.1634581473566, 101.18835649182721, 108.09619165235951, 105.84767726159866, 100.56204811219247, 69.71131232477003, 48.2063530337426, 32.14036403163787, 17.966132202456077, 9.46844764294163, 3.1179628977852487, 0.557457851546426, 0.3522410988807679, 0.17039768878490696, 0.21712247913162555, 0.24233294650912288, 0.2015009810847621, 0.1736052836021108, 0.1791984455720071, 0.2337641917890118, 0.10596366524095498, 0.0949647953553546, 0.22527074351185755, 0.17582344522158946, 0.21301410281129424, 0.08336708986110265, 0.15042243645556513, 0.1306976029469121, 0.13241235286958758, 0.2217472446781974, 0.11728558674334519, 0.1775384402924007, 0.1328363059268844, 0.10457395110279323, 0.1932966084249558, 0.22236621307749904, 0.18758631161143705, 0.18015533535470887, 0.1313619850383651, 0.12590872604520092, 0.26005406173006185, 0.11360990454352672, 0.17246442546527233, 0.13265670427391607, 0.13522196501012773, 0.15024819741806678, 0.14940026065995618, 0.15120651212430772, 0.17325642248315198, 0.12421220901512331, 0.3021335247303209, 0.13132878278772678, 0.11589118414708685, 0.30642662017095473, 0.10458449247263132, 0.16974654469278552, 0.09010692457518271, 0.16113685023400093, 0.1547962009546257, 0.16330993524001491, 0.14309152660350646, 0.16587061477043938, 0.1408100248344483, 0.18377525401451897, 0.16248165629804134, 0.10050540369364525, 0.1065590917583435, 0.24897604730100403, 0.15349720694845723, 0.08989743783228821, 0.12332496428561789, 0.13110001361177814, 0.23110972777489694, 0.2348951367481101, 0.2014156848552727, 0.20607510821953898], [0.01859496873352797, 0.0240954129971684, 0.0825380984573595, 0.06722409278154373, 0.02304131431775468, 0.007974338002367727, 0.03744049801401073, 0.008407858061423946, 0.014812690187095395, 0.05098908854227874, 0.09400293366202424, 0.037934701333964066, 0.05407028268241594, 0.08492866816419749, 0.01020670049793778, 0.036519373046053995, 0.012158745197549224, 0.03842951752425682, 0.03864817817004458, 0.03986794719352357, 0.040308811641748876, 0.024119240246833335, 0.026970219220064824, 0.031468260417421984, 0.04015780039011471, 0.12907896641521685, 0.04065794472192084, 0.010822331626719285, 0.012879306431709519, 0.053509418221731345, 0.03350122794208508, 0.011044491379101191, 0.021022161273586176, 0.007056807901995678, 0.022115763276815418, 0.04101078949808594, 0.027993168764477296, 0.05015996690358847, 0.038861755822454734, 0.05443520866514695, 0.01924509967436954, 0.05528938903984043, 0.027018017360880494, 0.027910011835516464, 0.06429363793182759, 0.04994902459363784, 0.048648046419745496, 0.042926135713294636, 0.11837926152492724, 0.03491749085726277, 0.018599783596132072, 0.05294588394463063, 0.026484065568975867, 0.023114764912714882, 0.04554485023442296, 0.09061317079730573, 0.05849873053751165, 0.1777221175331262, 6.7241765510651375, 17.054677317219397, 52.95862220948743, 72.12563314745503, 83.46204388526179, 83.38781695212089, 78.42269251423498, 66.68203446172899, 64.70140618662681, 54.20326871256675, 59.67388076166953, 40.85706295505647, 41.65458671508297, 39.877647123029156, 36.0824558811803, 34.00189738119803, 21.056763779732492, 19.530728401676303, 26.523082794681674, 15.480537010777383, 18.72014707134616, 36.43084864462576, 92.79375476221885, 46.040388845628314, 18.770461274731545, 40.379941924925774, 22.87080114887607, 22.99315164166112, 21.769595722998343, 27.228034696271344, 22.129481031048684, 12.424103598440848, 16.986643806580577, 18.824488001485026, 29.0355295519675, 25.28392957102868, 16.310619385011737, 10.997676810910626, 13.200821145888298, 31.40988926733694, 31.47171758836316, 27.633054717894527, 34.73509819276872, 52.30893650362569, 53.41795921325684, 70.82199419698408, 78.41577345325102, 76.75897213720506, 73.85563373565674, 66.55004670543056, 54.387149426244925, 41.12823601691954, 17.673801875883534, 6.515949685727397, 1.61352482534224, 1.1274778290141014, 0.3444005873414778, 0.04255449113946769, 0.12732943610077904, 0.08864739684448128, 0.027141648630100875, 0.042815819052198244, 0.1128833237735014, 0.06715297683953278, 0.011012982182775535, 0.006967874191280816, 0.012189651099634508, 0.030800708637182272, 0.039654216323528564, 0.004563564218715915, 0.05924991805166487, 0.026251285922743624, 0.07378564351388524, 0.003137872197605189, 0.08944341582396338, 0.022202501666822264, 0.023409051843167796, 0.03278796561062336, 0.03615898996471398, 0.04006288209629636, 0.06207025159270533, 0.08251843298034323, 0.0318242404084172, 0.0433153237005876, 0.03254966630089668, 0.010238133085471009, 0.054707587396185246, 0.06533886531307813, 0.012128416734236864, 0.014057806298707523, 0.09996290619094526, 0.02120799696703832, 0.0432738553612463, 0.0698345986705634, 0.01970657188775799, 0.04132737150235523, 0.02532593023422505, 0.03598225348058247, 0.04510316990255829, 0.035079499301049984, 0.061140335765817476, 0.0049343397615537535, 0.05577228873247101, 0.0610570466866897, 0.05165689121631365, 0.06095715648224277, 0.05990999089854379, 0.011205980798319705, 0.0183033382129525, 0.03732169309871332, 0.05012104963703502, 0.01188262029656119, 0.0311778805353829, 0.03271303838118911, 0.025535332707447872, 0.040928530807216326, 0.0121939450224501, 0.02623786406231023, 0.04645929108524034, 0.0590411514314192, 0.056105399083706646, 0.08071524586768881, 0.0769705085023757, 0.02317610365759221, 0.04388365751853393, 0.03774050570603821, 0.059508828956994324, 0.05576767688316684, 0.011823327964051597, 0.03374092153183395, 0.020542500217655496, 0.07984348377513309, 0.012601167677090535, 0.01562170297538321, 0.0392684833927741, 0.03829262527306715, 0.053910120510526245, 0.014053436724709408, 0.024889371200134198, 0.03951871069148183, 0.0747552733387678, 0.026649481188806317, 0.038529783111786654, 0.027982070065674283, 0.013110894811219506, 0.03885548922323412, 0.10336494178421075, 0.03365066871347447, 0.0633172933462887, 0.01892841424823048, 0.019478365786433704, 0.038075469990050605, 0.04778349321455725, 0.04482924750435256, 0.004918681403186413, 0.05923707075717469, 0.038904380954561696, 0.043366452408654076, 0.007044362324860789, 0.07285669295778198, 0.06259890588661356, 0.02076682225320368, 0.03218793490480992, 0.06445387288207008, 0.027878429860838, 0.052412380314161705, 0.10411534022780196, 0.018839040515764106, 0.056027802037856275, 0.04433169638017013, 0.07279112349234282, 0.01943318575109926, 0.02898891069625895, 0.039641227302772385, 0.0587155104374453, 0.17041088081896308, 9.636481000531106, 26.240258332221742, 66.13196126876339, 84.83468517180413, 95.29061794281007, 97.10656550622757, 89.26309600953134, 80.38499155352193, 75.55308649616858, 66.4030284266318, 68.4023154166437, 54.06512283509778, 55.30800034922939, 51.88894087268461, 50.21765816596247, 46.75954757198211, 33.877252301862164, 33.47000437398111, 43.038092967002626, 26.068619335851363, 34.67865136361892, 40.24621263627083, 67.94271561407274, 52.48516467309768, 30.870977178696666, 34.812710131368334, 41.56674131270378, 36.59817695617676, 27.56371113561815, 39.446206015925256, 36.61758876615955, 26.31341445830561, 28.174239820049657, 29.50376053010264, 42.65686996521489, 38.74740439076578, 29.62908810184848, 26.112183140170192, 19.00164185031768, 42.422880972585375, 45.994787370004964, 40.657006386787664, 49.25964278559531, 68.21535956475043, 65.65084334342711, 84.74254869645642, 88.95684519121724, 89.7017817343435, 87.98654494747039, 78.37470623754686, 63.80033969879151, 50.15080528874552, 21.461405292634044, 8.934587567083298, 2.029305746959102, 1.0278476654521882, 0.23437592831830825, 0.027399247609859994, 0.01769283508521415, 0.054286491846846, 0.01108008190884345, 0.038871488969532714, 0.03964700360572146, 0.05749051286388309, 0.03262982591085377, 0.029254465499111725, 0.033301589259457205, 0.08222636962009054, 0.042230761534864866, 0.051809453795994484, 0.06662629139158996, 0.021408554955175327, 0.08785995038887186, 0.07867869305154009, 0.04159049972170784, 0.012734182565773447, 0.036502653177106575, 0.04184746476370962, 0.07700384864884038, 0.04100351932368452, 0.008101954365209227, 0.06741410556940303, 0.027081451356230725, 0.02100002516301409, 0.09507372539730803, 0.04492677432755309, 0.018010656236700954, 0.05246241351649646, 0.05074181451251911, 0.03112942738939197, 0.032013370279943755, 0.021606655716295206, 0.05340509619864245, 0.04114022388333275, 0.06248981496619602, 0.07278281143836438, 0.05579107320837437, 0.057020560057172855, 0.07988189542365652, 0.049624283752974965, 0.05763824142876172, 0.07101639654607543, 0.02527341873745524, 0.03953456488107482, 0.02293751898011373, 0.0201214142444153, 0.03878668686675449, 0.037554112683621146, 0.054003330428273454, 0.062051444134164246, 0.021750463826221325, 0.020748403584284168, 0.020203757204956586, 0.03562505732500746, 0.06904689940593897, 0.030942249126852523, 0.015749623379369658, 0.025971154381911603, 0.16486942978395572, 0.14245291570982627, 0.21900998188122628, 0.20961006772854637, 0.16537918468877194, 0.11236922515015449, 0.14430137861880565, 0.14371196589162274, 0.17270736726782016, 0.1385456068261016, 0.2665958703765946, 0.14890305427533967, 0.19585535741381108, 0.26329672805243926, 0.12342837083363727, 0.1447748056342525, 0.12171563572220265, 0.10378601435091227, 0.1353998046608702, 0.08804695245118872, 0.1717400433675897, 0.116731345112766, 0.16115137526104528, 0.10836640042403053, 0.1257251483959056, 0.19108420778666774, 0.08628968464871568, 0.12053743079905549, 0.26465570674307887, 0.14615117452077328, 0.1921830230182217, 0.1378586404626408, 0.15736222777876163, 0.10559368307792372, 0.15484513865122873, 0.14082105650055793, 0.07331281404701934, 0.14836294696696345, 0.08478417632079895, 0.14636408567668932, 0.13303119869482133, 0.13501073924764512, 0.10813137997061976, 0.08400982230781548, 0.19211047449179236, 0.11724138347011422, 0.10228622103891066, 0.17208493615110076, 0.20599733497346603, 0.09762754077993094, 0.08882590299171787, 0.1213281867544978, 0.10045446650755983, 0.17184904235745632, 0.15423191591135918, 0.1573999346263947, 0.1905069605357224, 0.4461158583721807, 12.80652488431623, 34.1293312657264, 78.87997811840427, 98.77773838658487, 110.04224423439273, 106.85127058336812, 99.7908866020941, 87.30142454947196, 85.17384467586395, 77.75669759319675, 78.46857640051073, 63.1244957062506, 64.80864770950811, 60.71741165653352, 55.91672082101145, 54.05386563270323, 34.040018896902765, 33.45148686439761, 46.69720149809315, 27.76768026813384, 32.691906152233, 53.55303387488089, 108.49700297078779, 62.30457521254017, 34.34225713053058, 58.55291835723385, 41.09091858710013, 37.010865211486816, 37.286450939793745, 40.786028831235825, 38.776186743090236, 25.941867943732973, 30.22020301511211, 33.909019577887754, 45.87178968614148, 41.638673659293886, 31.999427387791297, 25.191965679968558, 22.95655200558324, 49.70114084982103, 52.05789696785712, 47.160496173366425, 54.676055523657034, 78.03447200405982, 80.24384114050096, 97.2622836020685, 102.84490677618213, 104.19473555780228, 100.29123198601508, 91.73689565350934, 78.50661554644185, 64.25076507752942, 31.452133194092784, 14.1474175260913, 3.934199550459462, 2.267331716514403, 0.7200467754756251, 0.4499415788919695, 0.23985656729388624, 0.3262154066995267, 0.20239901999312065, 0.15691437277822726, 0.20017764080436, 0.11176492733460282, 0.13877771614540008, 0.08003462271224107, 0.09520263501232672, 0.1747802173298213, 0.12697711226440248, 0.1483177324576724, 0.13148779199729044, 0.1341548198533635, 0.25731223304906203, 0.17613541154611498, 0.2241431540178676, 0.2138403592811477, 0.14648987731385618, 0.2736371683497583, 0.173737648273668, 0.21292440923711947, 0.14014561209947834, 0.16891104920256525, 0.11643483844255248, 0.2002881566483167, 0.29946116490229485, 0.1236328013962315, 0.13599421228131942, 0.14612583233223808, 0.13090148958708012, 0.11561714683569248, 0.1941299895125051, 0.07389017621115332, 0.12238347287019416, 0.1580195158960358, 0.16343597202531754, 0.09694396818597471, 0.1468715423177327, 0.1080668294021199, 0.19594587836294405, 0.13627544315832277, 0.23695916147722354, 0.09941853943371004, 0.1367318783436091, 0.1505426816161602, 0.1337335327820432, 0.12399632543806108, 0.25322156868154005, 0.09907347811085564, 0.19152001988503242, 0.22725777640458078, 0.16958575815923754, 0.09719471642447096, 0.11659530321917227, 0.14306779319961227, 0.19285621512080395, 0.1396425834466373, 0.12929670392505585, 0.08121648187478704], [0.1059599267318845, 0.007453360867070696, 0.05367714168143369, 0.04294053816627111, 0.03505364766404514, 0.0325989947023411, 0.050738822939174796, 0.03278669773510868, 0.04601093429711558, 0.07396221911955266, 0.047316934177351576, 0.11664107697264803, 0.06477703175116932, 0.0182894145649287, 0.01935881010497049, 0.049505015354483366, 0.0458980780545502, 0.06848903417947792, 0.08542278721447914, 0.018387263145057425, 0.08044494706536494, 0.05318902876047839, 0.030536799008146893, 0.03629698921295424, 0.007890161218857694, 0.047635040696590185, 0.052944891860768686, 0.022919004550203684, 0.037602360901092334, 0.042911166355254195, 0.06455211599747981, 0.10370207409704886, 0.03010963221200772, 0.016962692006340912, 0.04283191455948738, 0.042377620589949434, 0.027043344227657206, 0.027545026480971325, 0.01010742603665999, 0.038072060898787556, 0.04581144500163294, 0.022979058182588028, 0.07458879477194241, 0.03601180532226159, 0.08585126019052922, 0.07199467550362311, 0.016091822406216975, 0.049955578475830056, 0.05209698191573543, 0.05401873262599111, 0.042479008496288335, 0.06039361837470244, 0.06962458332700115, 0.34394329413771635, 0.6220203710179175, 0.6049828820170895, 6.186625524874657, 24.98765726243296, 58.494412283743586, 84.250683476848, 84.92785715287732, 75.35772108262586, 60.84433171056933, 53.81635042928881, 46.402819771920484, 34.64886488453035, 33.20847249800159, 42.55339391769902, 43.43217742058539, 27.140901204078432, 31.021809962487993, 28.056976641378096, 17.79941774183704, 27.510135481434485, 28.49586436825414, 25.782219632979363, 21.01502387754379, 39.90273068028112, 21.917563215378795, 52.0553631167258, 99.21142701179751, 64.13966786476874, 48.26505130337131, 55.97546615908223, 54.26697584890551, 60.323080093629905, 57.58518726594987, 54.140193077825735, 40.47106642876902, 45.96002340316773, 33.2637426160997, 26.301298256843324, 17.863903468655003, 22.19734391858501, 25.50466879721611, 36.858841988348196, 65.11015638228386, 34.991381937457675, 26.09903927772276, 22.76426761381088, 15.083009696775868, 22.851452096816033, 26.67791835723385, 37.04155775808519, 64.11071685052687, 58.06453227996827, 59.06556037164504, 64.13905597502186, 72.30432064302506, 72.9852911733812, 65.65347917618291, 45.70031542931834, 34.605973766696074, 22.47001728703899, 14.794190872100094, 5.070385163830173, 1.9990756723188587, 0.20570793759918984, 0.025250342253956105, 0.09041897516937987, 0.03739082487300038, 0.045960380154992306, 0.02834251826448787, 0.05730226973912889, 0.033526685043808915, 0.04875965776943392, 0.05243860350380983, 0.08081238581648759, 0.035907759090825435, 0.00772633427386022, 0.024017854255714247, 0.08411490658838904, 0.031003346554033702, 0.04446846605729192, 0.07730823836379475, 0.034508541631962986, 0.044258029365371314, 0.06645469535743037, 0.014297845585632228, 0.054200747455920906, 0.05090735079119763, 0.06318524277078048, 0.034133415188520186, 0.06531471056082556, 0.011604175106772493, 0.10650993955712165, 0.05105542792608181, 0.012828747501536723, 0.06293883825081491, 0.04979463106381798, 0.02302185759969777, 0.03664511105706615, 0.01830639681899019, 0.007708106648116823, 0.027478802010356903, 0.07813356020638058, 0.03465320201470487, 0.04165734855398055, 0.019016215585232265, 0.021246764846446536, 0.0061779566233106445, 0.07325251526649922, 0.01878439737934499, 0.025319966239734523, 0.07933958178205837, 0.033571091330339836, 0.06755448352064818, 0.046723725484503854, 0.03763971534828025, 0.062050057515021295, 0.044248717566651684, 0.048966807944159356, 0.03631882654923586, 0.04081484718969272, 0.042171408872931235, 0.03712750130122708, 0.04858237353243655, 0.03163373540906656, 0.035321977620403615, 0.04212418338283897, 0.0485475356840799, 0.03761774394661188, 0.047592921182513244, 0.046676951986286914, 0.09319333194364464, 0.02801273465006342, 0.03834000015030465, 0.04747208613421648, 0.0446401501915628, 0.08925546381262042, 0.026562691087864583, 0.04309341101156127, 0.04156758603189261, 0.06055951471470537, 0.04125726679640432, 0.04564803078650467, 0.0802568954625918, 0.06386484702928893, 0.019013827306128318, 0.030131990488077846, 0.04200798699692373, 0.051132304849283355, 0.08096764119522226, 0.04454145125383812, 0.05592190570408299, 0.05564976062986159, 0.04464003910881378, 0.04908106995806579, 0.03945875665052764, 0.03431800407387557, 0.024332980692927397, 0.04009808766685667, 0.037462469415679094, 0.06294920342043042, 0.042524303444811416, 0.036795616690670295, 0.01545888630883588, 0.018925012817846674, 0.09813024001496454, 0.03573435508916455, 0.05853248820189507, 0.03488661751391427, 0.041493474686097716, 0.0727056970279063, 0.06272002821788192, 0.04465023956952557, 0.0802507744200768, 0.020247755549667824, 0.12974177036554585, 0.28020422725427535, 0.5854559136975197, 1.3359077995823276, 10.962134253594185, 34.40745084516464, 73.72484622463104, 94.43406643406038, 94.75703439404889, 85.20905971527101, 73.71272610079858, 66.6632619980843, 58.55543259651431, 52.83741704879269, 51.73765897750855, 56.386895333566976, 60.330944445825395, 38.10106054429085, 40.552051605716834, 30.431556009477188, 25.621963354849047, 35.87644515498992, 27.61863804632618, 34.388756828923384, 34.227147333083614, 38.559879795197524, 20.61623650212442, 53.645087980454974, 108.9945399376654, 57.788883793738584, 36.309051206035, 47.44892766398769, 46.381533068995324, 45.02262007805609, 48.63025534537531, 46.613066657896965, 46.59980904671454, 41.96288501062701, 37.703006652093705, 29.624183177948, 28.205426585289743, 31.319700248779792, 28.644347652312252, 26.769790072594922, 51.62073312267181, 49.958279671207556, 37.424851771323915, 35.16722963702294, 30.131324068192516, 42.43558552957351, 41.56028116902998, 50.050757392760254, 73.6664342880249, 72.90810677313036, 72.778488128416, 80.07805039805751, 84.87175941467285, 86.26329083596507, 75.74735364606305, 54.863034909771336, 42.74853967851208, 27.29379911576548, 15.97260815481986, 5.598918660994499, 2.3963539158144305, 0.12214008673665025, 0.08483948020805275, 0.03131595256197597, 0.11353465938760389, 0.02333763521164656, 0.005597628262494841, 0.03589025781219525, 0.026891938440742034, 0.013311928731479473, 0.03522761857076999, 0.09110001201230673, 0.05131714654365375, 0.03640942410716126, 0.01473123684615618, 0.09218740487290968, 0.044720953315376274, 0.022078558216772733, 0.08064107323485999, 0.06673594921707146, 0.07601906560481557, 0.013801856323205417, 0.016791080650422844, 0.025745248459579966, 0.043957458598719495, 0.04645294404678768, 0.020606064447952856, 0.028314393261567723, 0.03373545549449421, 0.09667884813801897, 0.011332596937615064, 0.08130678831930123, 0.007934876334583087, 0.046329826056476564, 0.011013023360001465, 0.042762464858711734, 0.0801937161914764, 0.03983476026464374, 0.06037930019139763, 0.05343254895940904, 0.05463300873675654, 0.015641377070888637, 0.08050880815473296, 0.023061246010324648, 0.0762534195617322, 0.004320609009629417, 0.07604396346235469, 0.059221262532857165, 0.0668108726160661, 0.051345690979712436, 0.06443613794662299, 0.12395337854902591, 0.036042215182415904, 0.05228314894221483, 0.058623342399275115, 0.04211817342307299, 0.02410559430568209, 0.024582081842386437, 0.05599564166679498, 0.048387572695050514, 0.22258105477498424, 0.20272705884229755, 0.17309323043352173, 0.18334265948543627, 0.13598426846006226, 0.20843228415375759, 0.25623825438801323, 0.15818094594344018, 0.2199491443893602, 0.21132883195194507, 0.15281978604053298, 0.18872766004454708, 0.1310305447588044, 0.12441024274354982, 0.11152272863734154, 0.1647768097539102, 0.11843421301173589, 0.19113317612678776, 0.1503216346064883, 0.12896316456458262, 0.2520441375071964, 0.09088977450324644, 0.10216232163891678, 0.22035518631098733, 0.1191566032808154, 0.16986407790212862, 0.15607628791082293, 0.14258837537659755, 0.16069132414075638, 0.1513110678042135, 0.15632575678248561, 0.1720614632171008, 0.11858231312925778, 0.20110918839852657, 0.11828603628542154, 0.10846394639942916, 0.11494384748080086, 0.1931466084093817, 0.11279715420377832, 0.1260515784604415, 0.12378087087023644, 0.14309134274240465, 0.1701223108196451, 0.16534500184559053, 0.23390115298811467, 0.1513424927308675, 0.13235636716408114, 0.15278567980614402, 0.11639375314717332, 0.1271121888872116, 0.16954232097393082, 0.18533628073430833, 0.2868540849416487, 0.5883273950988247, 1.2156764898569354, 2.7337358507417866, 14.054091591988842, 43.43975936212848, 88.17601111627395, 109.7278662650816, 106.73283069364487, 97.6173443948069, 82.37609647935437, 72.91029545568651, 66.67726485959946, 53.485329843336544, 51.71266955714072, 63.15800843700286, 63.01877214062599, 44.449522572179, 51.306092354559134, 46.92938227807322, 33.09448842079409, 49.06989420613935, 46.55763180025163, 39.34541286960725, 36.21445540458926, 56.78656131990495, 37.183943717710434, 69.89698948398714, 114.31367397308351, 84.74439221043741, 68.25281819989605, 78.23350875608384, 72.86554905676073, 82.58411545907298, 80.1227105048395, 77.13117368759649, 61.67622327804566, 64.596929934717, 50.2416120806048, 43.99948943045832, 28.942308541267153, 33.60624005717616, 45.59352105663669, 52.826132389806936, 79.04681221131356, 50.47122370812201, 41.68225903664866, 38.337351968211514, 29.85162965713009, 38.230455613905384, 44.73764419555665, 57.13873917056669, 87.47065128818636, 81.43361368486958, 83.84251379197644, 89.75978574445172, 99.47549666127851, 99.00900917668497, 91.48427148019114, 68.21455155649494, 56.12979181351201, 37.023809033055464, 23.285901661842104, 9.5793830579327, 3.8947282491191744, 0.4869608779347712, 0.245998585296254, 0.20023361118810795, 0.24200737446306214, 0.13319961546409514, 0.15679578236754865, 0.11882776770019725, 0.24001372257067313, 0.14616588340891948, 0.15934993482885823, 0.1403447643162743, 0.1930696472165085, 0.07777001318191329, 0.1689190931257702, 0.3024457821682576, 0.07091908805793332, 0.17400104462379412, 0.1993436621682298, 0.13192371134796452, 0.16020328016771426, 0.16610805606169088, 0.1176489575675899, 0.144829090624567, 0.18738031056859802, 0.219619297572682, 0.09085139349823998, 0.1276009606437818, 0.15292031209795706, 0.2454760367231023, 0.07765642532538022, 0.15664800400695494, 0.0983762461692095, 0.2270288386892888, 0.0896336124729245, 0.15838506240998546, 0.17895112174653238, 0.20059537322771168, 0.1219618946854626, 0.1875564341823901, 0.09746177467487513, 0.1223815653112627, 0.19078993809319314, 0.10238755148865523, 0.2837796208839263, 0.14444541847032888, 0.19071313011790478, 0.1240881947019408, 0.1556154860243682, 0.15752030236105766, 0.23689327791573542, 0.23933852331772928, 0.1524026205222453, 0.12082179497566917, 0.21845937916828742, 0.1641840875268944, 0.12376440764074365, 0.11222821134593218, 0.09042517282068731, 0.19902541392272521], [0.029667515210026217, 0.03998765992301126, 0.017223449183567878, 0.022746920134992372, 0.03889786537676569, 0.02679152538128678, 0.043622980780539014, 0.06603823464003301, 0.07040836022145326, 0.00652538467904613, 0.041054402883615226, 0.015682687404595556, 0.05353513196290982, 0.09968775805206069, 0.09044148283259523, 0.0685878595217101, 0.03414666850961024, 0.05071078412114613, 0.015936647466714346, 0.08475820594016584, 0.01595560335479076, 0.03090583505259166, 0.048874865901926835, 0.11073119893309571, 0.05223581619981316, 0.008147242610462973, 0.02859085907168206, 0.06951104909662278, 0.03280235657228097, 0.02913984342388088, 0.03937880388431011, 0.028998664910754854, 0.0229294061089956, 0.010738967854018894, 0.031950461054821654, 0.0028581684689983847, 0.01910186421516682, 0.007944028212448523, 0.0774471837306215, 0.027279590421746817, 0.031182871598209587, 0.03279695948285442, 0.031465860646999175, 0.06990820439832826, 0.04237388591131857, 0.0873980989619609, 0.05613986537942002, 0.05559840975629707, 0.021317442203120842, 0.004398252978365148, 0.04157905436811909, 0.20520124704607073, 3.86344293432851, 5.593506280452975, 13.12712569390574, 33.89838995472078, 58.6780890341728, 76.35295191118794, 84.27049929095854, 65.48069092535204, 56.43616422530144, 49.99383987918977, 27.348055301174043, 26.602289176756337, 24.1254634241904, 17.628808367636896, 18.988452880613266, 27.265461952455585, 22.5654112908148, 56.09614179980371, 49.55330279565627, 40.720705678386075, 51.47037298448625, 41.979660987854004, 56.19442462921143, 66.47320747375488, 63.85302105257588, 81.45890512774068, 66.73824987103863, 45.79055739987282, 32.59229560052195, 60.91907639657298, 60.844339555309666, 30.70152294251227, 50.12306236451673, 46.025895687841604, 42.96133610510057, 64.72065717943254, 65.64381053370815, 72.34827472317603, 55.935681558424434, 67.9785111642653, 66.71775156451811, 53.722013504274436, 44.09799191259569, 55.94635825003348, 38.197150768772254, 33.055178426927135, 34.97129547980524, 21.866164476640765, 18.26200442929422, 22.0095859419915, 17.058640872278524, 24.98870453526897, 34.092166808343705, 27.823370079840384, 29.455360443361347, 36.800888969052224, 54.04973145454161, 52.25369384211879, 68.33588615540536, 72.09486607582339, 78.56409395894697, 69.36581427051176, 54.018854556545136, 46.43793675207323, 27.307397973152902, 15.282138624498922, 2.3660322783454775, 1.7718658836618548, 0.06967226463940836, 0.06279996183190135, 0.045715515471754536, 0.025373368313716307, 0.0767823190037762, 0.012221267548269563, 0.02220052899041724, 0.06902346477633522, 0.03946660905175152, 0.07799404793448987, 0.0713058628682648, 0.09513999966363754, 0.021424301892458912, 0.04461097756340619, 0.018767001437804392, 0.07128392211011342, 0.08137686238173517, 0.060401532062960256, 0.0292887881533393, 0.029598130626724135, 0.040447071359883395, 0.036455772426580234, 0.021615636181987582, 0.009169021955571108, 0.05774925139942958, 0.02544120348419153, 0.07589047774672508, 0.02502826102558644, 0.030088229630623135, 0.02244796772908059, 0.02739005646998844, 0.025943119394322558, 0.02778531953452095, 0.019408883526921272, 0.042355721966633876, 0.02159896419353543, 0.016984379955477292, 0.05802114366463596, 0.039357104443854866, 0.02102528882753705, 0.056854889713107586, 0.025940585558513002, 0.01724005796976628, 0.03237232460730499, 0.05427585471601737, 0.04823353922655506, 0.06925683047982954, 0.026819322881619298, 0.07043924888656025, 0.051115600302094416, 0.11409758079436519, 0.0063957635598677785, 0.015922036254778504, 0.007204764856836729, 0.013187715235436636, 0.06727968012132952, 0.04774306292435335, 0.04559908925946202, 0.036721267857618874, 0.025443486426205888, 0.01669131493526361, 0.029375991941760146, 0.036683878936474366, 0.0735014631983734, 0.04370818890991711, 0.04598778312004382, 0.03280212674590369, 0.06996667988958859, 0.04979582233054023, 0.01288885092963615, 0.013154177821331449, 0.02884278325514207, 0.0590926593530082, 0.020875419046910062, 0.006503960072633721, 0.07603502321627832, 0.015263854687462653, 0.035544725345267404, 0.03144349279483, 0.0306993073243047, 0.01866494703497137, 0.03634237992246786, 0.07223300545686676, 0.048716419766987526, 0.02662263938315934, 0.04522917221390432, 0.044427518657739126, 0.06488977691098567, 0.034522515075701865, 0.0027865572032638856, 0.0678463400371613, 0.0404829204443001, 0.023796987276704564, 0.010739272373968796, 0.03936636261641979, 0.04177958171273913, 0.02529463362729838, 0.02555127691237196, 0.035735435273137786, 0.04350463551799617, 0.02530752688706402, 0.02854372359692089, 0.08772449072210059, 0.06266337601588139, 0.03967513052386142, 0.04573660587230998, 0.06632538737669107, 0.43990389654232614, 4.4984570145606995, 8.542391734738505, 18.075252540649906, 43.97645727280648, 70.78115447874993, 86.45499275576684, 97.77988741474768, 76.00208805453393, 69.48516415011498, 64.77360133201846, 42.43149841985395, 43.56370233720349, 38.84173739340998, 30.302035424017138, 24.762075870267807, 41.05952393624091, 39.93570212394961, 52.01823003830449, 47.51651010205669, 48.02062880608344, 44.00244689756825, 39.297395213957756, 48.4618797609883, 44.22566898407475, 43.11670903236636, 62.562188640717544, 49.523759503518384, 45.92867974312075, 40.56960028986777, 50.82215816743913, 48.31042135915449, 35.51803858049455, 37.37866978491507, 39.384220800092145, 36.868294900463475, 49.642866196170935, 49.58477981628911, 56.107300942943944, 42.645871639251716, 49.80522094234344, 39.7321036554152, 41.599222460100734, 47.89179463540354, 60.26673132373441, 56.346765564334014, 38.89528951337261, 40.96936041308988, 29.47790034355656, 23.8949300396827, 34.07505742965206, 30.226504302793938, 38.21678615385486, 54.23335721415859, 40.32396970256683, 45.1197575753735, 50.70855456013834, 63.81236568573983, 63.21615757480745, 84.14853711282053, 83.93345002205142, 90.24521827697755, 80.12664856449251, 65.10135458361718, 51.60332564384707, 31.369786954695183, 15.904439322410093, 2.8789258147439654, 1.8866688782168974, 0.19950227301207282, 0.09650027304286919, 0.041652104682138855, 0.033623943736235944, 0.03720016474084508, 0.04682474183819948, 0.04032801746601059, 0.038353636515356844, 0.11283177371707656, 0.059557628757770986, 0.03390709749392925, 0.029505481868381464, 0.07251510967410381, 0.0363012946270887, 0.039794406583232265, 0.04848036892531861, 0.022785546288134593, 0.034347031145326556, 0.050284092299520015, 0.04485927432054474, 0.08903447042910323, 0.02286775518328913, 0.02954042888426733, 0.02807204900760084, 0.11673391916819158, 0.02347114518465054, 0.10163464793755163, 0.03553560506852885, 0.029468305536635944, 0.01079567080934442, 0.02700956549585587, 0.014682161253726771, 0.058095465684610034, 0.0843361834244382, 0.03223057535867537, 0.024227480809654922, 0.05482652254642979, 0.055954705758561055, 0.005200923995054778, 0.005681918522778658, 0.04236515250898177, 0.030611697509283983, 0.04785534843141514, 0.13679846670598755, 0.06378308246513048, 0.11860937135474336, 0.02787449025368739, 0.029930404026902495, 0.03150206979274029, 0.013908335841411065, 0.029815324214136893, 0.024085063149311373, 0.021973613747245362, 0.031117729226788206, 0.0410112836247971, 0.032791474293316566, 0.12793994688939664, 0.15504530210408474, 0.10292144582396555, 0.12272019149555315, 0.2776612137113848, 0.15507447473224134, 0.14772223699237072, 0.27574418593318234, 0.16674446062214915, 0.12231218838883985, 0.18287283308323354, 0.1795081595980352, 0.10552749308126588, 0.24168521916914373, 0.2003340299932226, 0.17874138219462288, 0.17604937987221828, 0.14776746682342023, 0.18817521872058993, 0.25971606373786926, 0.0963473235887866, 0.158831124764777, 0.1699504619764705, 0.22582641772685513, 0.1112460483226084, 0.1411241055616448, 0.18222175027814605, 0.24102871246155233, 0.10921266711046619, 0.12124272964654431, 0.11868265532558003, 0.16156409746937214, 0.130485825601124, 0.052061856784407175, 0.2888369962813393, 0.14035837003780952, 0.09984766358449575, 0.16715871500632457, 0.13815678656101227, 0.15091590433111116, 0.1744073470153155, 0.0981713253103437, 0.10529441083030355, 0.19869244146731593, 0.09833231868763125, 0.11836352607896251, 0.22583631558283684, 0.08596923006998916, 0.18201348161505115, 0.09515108495590188, 0.24517733904142536, 1.0213782674362584, 6.8763409795299655, 12.400393851341741, 24.590195648131836, 52.99729285701629, 84.6012649228496, 100.37469217854162, 108.99854075524115, 84.96380175313642, 76.44379400437879, 71.67582358083418, 45.386149267996515, 42.7702852987474, 40.5656151617727, 27.897087104858894, 30.885780203726988, 44.35740570868216, 37.65593036528557, 74.72174798288654, 69.84582608745944, 64.49392849399199, 74.21597403864708, 62.21114043266543, 79.09505736443305, 85.51145876607588, 83.50435056994039, 99.80721935149163, 92.61458089274745, 65.39974889447613, 49.75779164221979, 77.9483602892968, 79.60094113503733, 44.415531312265706, 65.28071672685685, 61.28442164390319, 55.68898408643661, 80.8146244479764, 81.13694129451629, 94.5310744931621, 72.34760792024674, 87.6516608268984, 89.37468744093373, 72.82426218832694, 61.34430446932393, 69.50599193572998, 50.60066192380844, 47.59920151002946, 50.1251765220396, 37.23089448867306, 27.378685089849657, 33.668448848109094, 30.94944811636402, 40.78267128236833, 52.61302609597483, 45.56005539432649, 46.44609135966147, 55.637989351826334, 75.01110907523864, 74.98781019641508, 93.48073436367898, 94.31077849480414, 103.28414947755876, 94.24623981598886, 77.76520129173034, 67.213405793713, 42.73067328237718, 23.802556260939568, 6.586890162960176, 3.4660769278003327, 0.6820657296526818, 0.15108268167222702, 0.16345376058691935, 0.10381670383315894, 0.1924344224314536, 0.12686344013819773, 0.13372066250491527, 0.10633404576970686, 0.22054398101904701, 0.11442719012378685, 0.12007509673675222, 0.1775426231324673, 0.14331237443031805, 0.14111981546926883, 0.14796242087839112, 0.19788922892222482, 0.2447490805699941, 0.12082109783565807, 0.2098372434416125, 0.11214643146001524, 0.13202920165513793, 0.143259207928373, 0.15698866798512398, 0.12235181045628364, 0.28288666879938495, 0.08759900552010344, 0.2893878747859309, 0.10062499001862542, 0.08803185285820116, 0.10701395646338502, 0.10221993145082267, 0.10839226355235423, 0.2773484046901426, 0.1343184715557483, 0.14716628698572037, 0.19114114344120028, 0.09628203757587941, 0.19787917784865827, 0.11051306305753608, 0.06492188365589227, 0.1636379894109503, 0.1718156256021992, 0.13483827753413108, 0.1832369087083686, 0.14484885569301345, 0.25702776928101817, 0.08065678569818698, 0.14160094932923395, 0.17272612110020655, 0.1264194921860772, 0.20367627242399802, 0.10153767652809621, 0.07932100414989457, 0.11076314479953821, 0.13678461583631654, 0.13860261908942653], [0.027060856997606256, 0.03807472305432443, 0.05148236872628332, 0.038678955752402544, 0.03245563666907049, 0.02912659967888988, 0.06073720114786298, 0.0826691607794454, 0.0511978168581282, 0.0739138713106513, 0.029581749751683206, 0.038329144684417595, 0.12687031960775777, 0.04107215314082081, 0.05185022116488507, 0.08081898949439488, 0.12407850368969864, 0.01803139423681123, 0.03336655734587581, 0.03148735515893467, 0.014120613059569753, 0.09876194079556773, 0.013833309020546657, 0.03526907541879243, 0.07451377178151762, 0.02982848943511565, 0.06832154437659249, 0.03220983352812548, 0.0036103059321777116, 0.019324985407893697, 0.04685451584537664, 0.052547234771472794, 0.09045979999486478, 0.019040058156655684, 0.09474957061390724, 0.05905375740821323, 0.05570553183074921, 0.025198165920653173, 0.05263888570029409, 0.01430788229505021, 0.03147969236447206, 0.026417230143241828, 0.0285427583261363, 0.023903431363343716, 0.004885758295835507, 0.01777074431189366, 0.01636879574958115, 0.013073428323672665, 0.13291365016371975, 0.5285752949214751, 7.514297327687664, 24.763107453623128, 43.928325868421986, 49.32363233258648, 70.72229539194416, 76.73296682296261, 74.51528226175617, 71.72706542476531, 53.9158844947815, 44.56579339119696, 27.999176594518847, 24.285974656381917, 28.762554161010254, 25.018828338192357, 30.62770393586928, 41.87374522609096, 58.37541149508569, 38.41188484622587, 49.78218093995125, 56.14910556424049, 51.09042867537468, 39.20289354939615, 57.515882907375214, 63.26845453631494, 53.08477740133963, 73.66932899721208, 69.29030864469468, 58.717924625642844, 44.46749094993838, 30.418161115338727, 22.896647607126546, 15.477946285278568, 9.400601425478536, 6.843987309163617, 3.385451383167698, 2.8432883850989805, 3.881440239567911, 9.493584152190916, 18.525236652743434, 21.95839312768752, 32.67755812214267, 34.317177495648785, 51.23256752567907, 61.27334094816639, 53.81806842742428, 43.50542768355339, 49.15551954700101, 67.67286439095774, 65.69223611585556, 63.62904587099629, 64.6121604980961, 43.63707811601701, 28.035927241848363, 16.897568741152366, 15.457265588545031, 31.213955110119237, 17.047367980403287, 21.504357207205988, 35.61200680271272, 39.52638318461757, 50.28016113465833, 59.23589321874804, 55.37708505507439, 69.56313302440029, 81.18751633551814, 74.23595459230485, 74.19369497606831, 57.89936911675238, 43.93545281502509, 27.108223938172866, 10.698082254778955, 1.8592739417668314, 0.3003087339382018, 0.06522490207346217, 0.13555064737316103, 0.021611271396038995, 0.04500751999477225, 0.025415685095433748, 0.022828795781899846, 0.03470740273534771, 0.05207801357873025, 0.021696651895200054, 0.058291331384210825, 0.027273247213733774, 0.024588666368095626, 0.06916197347304515, 0.024971022766323823, 0.035766572916820165, 0.0271144850675257, 0.046940807989167596, 0.01131914634888451, 0.034462733404530634, 0.10634415813030736, 0.03895671625110892, 0.04643584879475736, 0.04255789640029112, 0.07759131551269563, 0.013481065623402117, 0.04922137513095814, 0.025656749982567086, 0.03328205784782767, 0.010562503331100509, 0.03745915225496696, 0.030064187876339403, 0.0547963846474886, 0.12284364656455095, 0.02471151048197381, 0.050468853554658355, 0.0677712404379441, 0.06444350771245456, 0.09359671554017453, 0.016031032371815416, 0.010272362851537764, 0.04357619962144283, 0.05519240613906615, 0.04426768973409649, 0.04778898989541396, 0.038746769855459856, 0.02432713927250476, 0.047680584623688654, 0.051299116664355805, 0.04205882459157898, 0.07500326366073663, 0.03317198633486706, 0.0703857989320832, 0.02664785325196722, 0.08110732200645632, 0.055211500880578836, 0.034527460173253095, 0.045403966665147774, 0.014391127324122337, 0.027988608626108018, 0.08634383174320383, 0.053434192218006625, 0.04172353472019877, 0.09248239468903312, 0.04588849429461745, 0.03720706719304285, 0.10041679030344372, 0.051653512768567576, 0.023104552960684224, 0.02131186699825189, 0.0394112860122996, 0.08137894614088921, 0.021639283400990313, 0.03521232745580135, 0.06639772139850163, 0.10152957897873656, 0.10468971464903125, 0.05113330842446416, 0.019789749884136745, 0.051128332683395956, 0.0311091911768721, 0.05120966823831682, 0.017920926273349794, 0.0036564258616342544, 0.03693959142471995, 0.019363102112566272, 0.014695402125888055, 0.02988406528358258, 0.019570752159662304, 0.09814101121117992, 0.03331983747381357, 0.02346273162402213, 0.032908379310561765, 0.03357123305660582, 0.025589119740611604, 0.07779442074318087, 0.06175064354113514, 0.023679683893738736, 0.06286024146022336, 0.02795900698871382, 0.0564878914625414, 0.007987462046120556, 0.16424047159812144, 1.219708931542212, 10.338941216468811, 30.327799512493996, 51.600572139986106, 60.78578641337734, 85.02568890971523, 88.94946329055294, 87.50429737952449, 79.71669812356272, 66.34303969721641, 55.8033957019929, 47.236531319156775, 38.52819488894555, 35.87875935339159, 32.49626225040805, 33.10597312065863, 36.15665928010018, 46.821085637615575, 41.30890038705642, 41.205808731817434, 64.54085573073357, 49.936479137789824, 47.54258209659208, 57.66448190135341, 58.430085412917606, 49.887845670023275, 56.77518252403506, 56.58415525190292, 49.292637763484834, 40.753045620456824, 29.711504943909187, 21.618323633747718, 15.362756079243077, 9.447566905329305, 5.815359950065614, 3.5176377094561055, 2.5320924385901424, 4.132382206378445, 8.436148455066066, 15.87267694934722, 18.126351218069754, 23.217719101136733, 27.97319285331234, 41.06662734862297, 45.166253351396136, 42.9804458925801, 34.145220787294456, 32.075211501890614, 46.82508645519134, 50.297572535853234, 50.27610148152998, 45.39400185308149, 32.24740355245529, 31.85872216378489, 25.13314581686451, 24.050434366349254, 41.1266827583313, 27.206300843146543, 30.854693458926295, 46.66797984030939, 50.00097467053322, 63.91403352060626, 68.19394342360958, 65.78661618694183, 78.75665880018666, 92.67409893774217, 85.43213275171097, 85.52194718391665, 67.86324839438161, 50.82119718674691, 32.1692915116587, 13.05093071153087, 2.6903510045620704, 0.4492454194734174, 0.15881745775620784, 0.027739256582853776, 0.06056118861681992, 0.007658612580158778, 0.02886583292556386, 0.05807268606018155, 0.01689240535450799, 0.03661568945033416, 0.04006572811293506, 0.022891967392136014, 0.013790726980885432, 0.02336943360616363, 0.0737460827334754, 0.019843071518886476, 0.06818840595623178, 0.035014446944959705, 0.05565029306096896, 0.013545823035641544, 0.0631513127366141, 0.04489183688776628, 0.036210551512457674, 0.035888013174577106, 0.027108442549022938, 0.024822376811155872, 0.05066806705848825, 0.055110147448196534, 0.01611686965090133, 0.008055118622348435, 0.012551062654012875, 0.032516804959384665, 0.041597609017645164, 0.006253396174044259, 0.026512010541233807, 0.042888505474453976, 0.06162743745071273, 0.012703409771465007, 0.04297144981401582, 0.013495899958445901, 0.06306999250345173, 0.047507548344231425, 0.038997786224729596, 0.02560696958924734, 0.030029118286385655, 0.0741956997362356, 0.023238693041005926, 0.05452794743882072, 0.03587456067062674, 0.04390511181085341, 0.07244906523415158, 0.11588685575031465, 0.06629782353317545, 0.0938254387508477, 0.025095012181648807, 0.2478939174644409, 0.16666725428114015, 0.138193282989725, 0.2686236744686481, 0.15265132330598372, 0.20578161993574715, 0.24585209396337313, 0.17449215294853335, 0.12354548269462202, 0.11636319389987378, 0.08216979402688243, 0.12083327863365413, 0.20169947446594316, 0.19622525530717067, 0.3395641823449443, 0.21952681543846286, 0.1480713739029823, 0.14397972894291725, 0.10778422722773207, 0.16162915365590205, 0.23502034615845452, 0.2549855167707128, 0.1714398901188566, 0.2097924426198006, 0.1014876509866407, 0.13094019234901474, 0.2021629270166159, 0.17432581993841356, 0.07099837815809636, 0.1686694863582811, 0.1698448490952292, 0.13481820603051495, 0.17527894056852789, 0.08668844107418291, 0.1651674686300178, 0.1800295896828175, 0.12023528572171928, 0.12789952042963237, 0.0677234748558652, 0.09480102107890191, 0.21203131925675178, 0.14140538240392364, 0.16041338744182743, 0.21705838821588025, 0.13184020776421795, 0.19333768605945573, 0.1751764073607422, 0.18524969747710615, 0.25503584874733803, 2.553435770734664, 14.883837622980918, 39.39961610301849, 62.14731954759168, 72.77888036543324, 96.93572275100216, 99.59366198508971, 95.83262674270138, 92.89646594755112, 75.62148478723343, 62.149606289402136, 42.75263855534215, 37.70078659057617, 40.39315639003631, 36.42167422079271, 43.33822488784791, 58.331516250487304, 80.97409232970207, 55.5946393166819, 68.58209333112164, 79.90967089130034, 70.99680639082386, 60.48849428853681, 78.4904710708126, 84.30406693489321, 71.46567867648217, 92.01840416077646, 90.35378948334726, 74.3323507616597, 57.19657059638732, 41.21273955991192, 30.5940794175671, 19.763891735384544, 11.692273655245382, 8.940768241882324, 4.213786096342148, 3.5965131415474803, 5.70893329958762, 12.347919402583955, 24.72891026927579, 28.854674946877267, 41.526588009249785, 47.908221521685206, 66.31242952039166, 79.44774904558736, 71.43102061363959, 57.5904118630194, 65.63158058351087, 86.0754563731532, 85.57282816979193, 83.59773435900289, 86.76966098047073, 60.22143579298451, 43.93209134378741, 30.35493446934608, 29.78742830214962, 47.75252696006529, 28.0374805004366, 37.014732668476725, 54.17450989446333, 62.11437163814422, 73.62651240441107, 80.24038161000898, 76.18148942147532, 90.23715388390326, 103.65262477628647, 96.58559629994055, 97.4686316520937, 80.19116370908677, 65.80259984539401, 43.573280765164284, 20.626269925025202, 5.618534434226252, 0.6435869105400578, 0.28920523942478243, 0.2331461580169778, 0.2283377765167144, 0.1376238651573658, 0.14564002533593487, 0.09084852066852393, 0.1475292288007275, 0.17470538586137757, 0.10626971736670503, 0.14840119007614352, 0.12967311356577182, 0.1356460559632509, 0.19564993859779453, 0.1454346065199183, 0.21012084919118115, 0.09559838837313075, 0.1544194082699476, 0.14837489793858222, 0.107346446283402, 0.15950482248538927, 0.1304345130319557, 0.1349916943018475, 0.12190803104350645, 0.24781314115370476, 0.11844198114328808, 0.11880153684966988, 0.13708381913602352, 0.14032254776647016, 0.18009096864731083, 0.1389970164746046, 0.16895853133211214, 0.09819640702898465, 0.2501901587651622, 0.18334269012895324, 0.20886402066436507, 0.13179958978247258, 0.13396947254096309, 0.17782017678743411, 0.23150464609986354, 0.23509294065015934, 0.13226365520348474, 0.18075628536603144, 0.2143844349249717, 0.17904384902888731, 0.1827236144773422, 0.23361288942396644, 0.1670788273575806, 0.2025742243014036, 0.25029373385252496, 0.21517584971602888, 0.1450250099503225, 0.1998429216684834, 0.1069738440996697], [0.016432390623395483, 0.027641528661573128, 0.052096104745062134, 0.02298992513979395, 0.05764927692531098, 0.05853892717089865, 0.07290544679328319, 0.08385037642813499, 0.03343953488154277, 0.021582499048822833, 0.05259988799450859, 0.00669650047183818, 0.04752862342302838, 0.012306945864111187, 0.05125821523007847, 0.024335049130322955, 0.04677226098494665, 0.03909578802244317, 0.024324421575593374, 0.02566211642847667, 0.053415629907601306, 0.056137141936849204, 0.07935317984271435, 0.08162581797448859, 0.08224009025481441, 0.028041905363000212, 0.020006181214064844, 0.13779424311172578, 0.02990335920795558, 0.06568257066030657, 0.049495075363665826, 0.018770483307420247, 0.02372265759585125, 0.019229651511376424, 0.10641343546130004, 0.021429744947160927, 0.02359436276639181, 0.02537285886524666, 0.035671995532128124, 0.04217075003731636, 0.04001986625934801, 0.04189514224567721, 0.04581723279590088, 0.019412631612090815, 0.047692527934428186, 0.040331112461224686, 0.3152099101533813, 2.129975461190747, 11.354727225918925, 32.12385477558259, 59.76342847270351, 73.77504471809634, 73.31201676399478, 75.50777527593797, 66.48322520717498, 52.97264076048329, 61.992578121923636, 44.30183356808078, 24.928570678157193, 31.671795729667913, 18.12249945056054, 27.810843990695094, 37.60353926689395, 49.51394181097708, 59.235383310625636, 67.36369532923545, 57.40182430513444, 69.03017705486667, 75.08071545631655, 45.32170472606536, 47.77427258030061, 50.957746659555745, 38.77601023643248, 25.17693711865333, 30.161673407400812, 18.697613054706206, 12.801204189177483, 10.013773787406183, 8.852735546327407, 4.006456473181325, 1.0761872006039466, 1.0452028051499398, 0.5401078599595255, 0.08384777939007168, 0.010786774613323712, 0.06156809628009797, 0.030751340016121828, 0.07777499275342112, 0.15885559361307852, 0.3766159328722185, 0.4557994242397047, 0.9255145598323116, 2.8385800700033865, 6.9492519574780625, 17.128200184914373, 33.453691236434445, 39.690542221069336, 39.574126274355, 49.43023843149985, 63.602048197100245, 69.49702539751607, 83.80671039704355, 74.98075777484526, 65.74309748987999, 89.17921220102619, 47.91968268732871, 29.37962143651901, 23.38631041588322, 27.95733863307584, 26.721007554761826, 26.687283016020253, 34.48367818709343, 42.331321085653, 48.274253183795565, 50.90137043306905, 67.70065830599877, 65.80757341077252, 80.62300882031842, 83.8837065235261, 70.05330378009428, 61.85593451223066, 36.99254382041193, 10.765030249472588, 1.6168847031170324, 0.17899033012649707, 0.02331789695627747, 0.008197340930271293, 0.07920274315702339, 0.06894153933371268, 0.05928136213051696, 0.0743775690094598, 0.09968304661132636, 0.06462194491177797, 0.04182209193165745, 0.011137688847919627, 0.01596342798532738, 0.025077198722189473, 0.02876851294610289, 0.045174573127540855, 0.05710627380458098, 0.06770148047155912, 0.03049877040358561, 0.041115222603923855, 0.004523887567507524, 0.010980783507318027, 0.028665468374627735, 0.06868979518091486, 0.053069365826705774, 0.02729942252288663, 0.01791632400014468, 0.022427009478692087, 0.01605927707597373, 0.022717808793869712, 0.02412242717259834, 0.046603560763140844, 0.04097804306976257, 0.0866238292186491, 0.08936007311868091, 0.02503750004595326, 0.06129940243197545, 0.07249726748634731, 0.03719937567028307, 0.1032582104146, 0.019000738693941987, 0.03175544762803662, 0.07260442020431643, 0.012946358277282168, 0.06003401287260556, 0.02411098181900959, 0.0362036835342165, 0.03324806652662735, 0.020502253788553422, 0.08812794326654366, 0.019883861870414788, 0.06364046753714643, 0.03821847945331566, 0.04016189513006999, 0.04481253912672401, 0.0500473634700381, 0.031200158372220975, 0.024035271264672763, 0.05186727811251918, 0.08580127295346991, 0.023267402185968334, 0.04716531005537799, 0.051700336062499595, 0.026990129845216874, 0.007057134446973402, 0.04695017724448154, 0.05127397748912054, 0.04997284226720372, 0.03176285569826442, 0.005686283308727246, 0.021869023593382973, 0.043579283125338056, 0.013468693303424987, 0.03862978822942223, 0.027513346830082518, 0.031603084231216105, 0.0816776514834454, 0.02789463262043653, 0.1291096865409805, 0.06550239444139504, 0.078935110340676, 0.0523825450199506, 0.04908504595439281, 0.0865423787505396, 0.021811423357576135, 0.027552367518505747, 0.03292097762647656, 0.08132649976159297, 0.027947130710667664, 0.016767077200535326, 0.049043631241206205, 0.026051905794790196, 0.05303342098129853, 0.040816329569826205, 0.05804671950998807, 0.023670661293210524, 0.05713816604486877, 0.04573925270608837, 0.012730574291650087, 0.31944778597643303, 2.1883435162805744, 14.266230040980926, 39.04931314529912, 69.6029999948317, 85.41722774505617, 83.427699612033, 85.41132065557665, 75.94853985694148, 65.37801504135132, 72.17619249897619, 58.80641329673029, 40.65351939970448, 44.97684601814517, 33.22272246883762, 36.52519733675065, 45.773271514523415, 46.585268820485766, 54.08213807690529, 52.821107833616196, 60.637356081316554, 57.15001598481209, 58.44918343328661, 48.67357400155837, 53.991397965338926, 47.54862254665744, 37.967774483465384, 30.905248888077278, 29.219412226830762, 20.72179532820179, 14.720802345583516, 11.545422077178957, 7.737938127210064, 3.5092788934707646, 0.7596326835693852, 0.6642210904148318, 0.386199937953103, 0.10373512313010232, 0.08734991203152365, 0.06628830106027665, 0.044008721372172724, 0.09582919534295799, 0.17047763772068486, 0.3628379028410681, 0.7479593422143691, 1.094630920598584, 2.688483956360048, 5.323579061415888, 12.422208113055076, 20.425352396503573, 25.92302291624008, 24.534207736292196, 38.660751388918975, 53.974480782785726, 59.16785578573904, 63.02002337671096, 52.81406717915689, 45.457905107928866, 72.48148625896823, 46.05935350541146, 24.583437404324933, 30.693658590316776, 37.909225263903224, 38.49715325140184, 32.72973937373008, 46.50337757602815, 52.8134278328188, 65.49953791403001, 63.96055283084993, 74.97640394395398, 76.96084084049349, 90.23810309748497, 94.28579299680649, 80.48858919451314, 70.11184123254591, 45.46038796824794, 15.093711883791032, 2.51507866767145, 0.23134574414260928, 0.05134300201109821, 0.049142402957283685, 0.06122881509063225, 0.07772394831502631, 0.018628770447967034, 0.06395134984725906, 0.06056958494047004, 0.06033625754137194, 0.02599502376641237, 0.011042691072479132, 0.057316695174743096, 0.08271432932346098, 0.017850114851288738, 0.05174700230840714, 0.030124936733515035, 0.043800353117647677, 0.015977186924447457, 0.05520957416944927, 0.0487566125699349, 0.017982967903897647, 0.044472863401977286, 0.04441798852396108, 0.037925171200186014, 0.03641525403626504, 0.06495952921649141, 0.005428768598639797, 0.025780344862611066, 0.02114202530543891, 0.031638159566829284, 0.0840219954449323, 0.029987937230015957, 0.0453549140553561, 0.042737049891823725, 0.048906972646833434, 0.03897671114593264, 0.031288518953407486, 0.07247862090627033, 0.05326425093376348, 0.017859924607159152, 0.03986456491533787, 0.04162858961330306, 0.0691600352705967, 0.028197911507900686, 0.057354608866115736, 0.02198543065347739, 0.06240212471194326, 0.008507088472646092, 0.05308133595052266, 0.012174018117929659, 0.05178288586678044, 0.03369012990245416, 0.09098253242911832, 0.1429330689772483, 0.09181681750041824, 0.13672735842485584, 0.21985137624846351, 0.14939765596101362, 0.19614550555425306, 0.19702048521609078, 0.11295290753966379, 0.18335695468610336, 0.1580740153909691, 0.07497666508800561, 0.10062878981472985, 0.161122938077296, 0.1604139390251329, 0.16971971629367721, 0.1355289670849039, 0.12432407317382675, 0.10550349920747742, 0.14339371764611814, 0.13779681716715136, 0.15225209956688268, 0.22125621296225056, 0.2451743972637961, 0.24183779324014343, 0.23494097944949907, 0.14009992261567425, 0.27824564686705994, 0.1340598555942697, 0.15317641529104403, 0.18855510640048212, 0.18510394158863253, 0.13005661718066663, 0.15197607808776442, 0.2819255961766166, 0.1867839877283381, 0.16434727957652462, 0.23888959579410093, 0.10727207446771284, 0.16836582442685483, 0.19098974914560396, 0.2245476331201292, 0.08115464325753913, 0.108299620539671, 0.12572059783363534, 0.1738951253073831, 0.6823239319266812, 3.6609567028860894, 20.59168246484572, 52.17828235318584, 81.96619310686665, 95.88293506253152, 93.7069139172954, 95.73572850996449, 86.52596412166473, 73.54842585902061, 81.0460364434027, 64.47264571343699, 40.55985712235974, 45.78132021811701, 28.126737956077825, 41.223388794929754, 54.728807480104514, 65.64235141200405, 78.80997950030913, 88.04738875358336, 79.33546727703464, 90.0437653449274, 97.15562651234289, 63.48831122921359, 67.2583326216667, 66.94466067898658, 52.25912632480745, 36.32384638632498, 39.32791517626855, 26.53744847543778, 18.02398127894248, 15.337888252350593, 12.193480980011726, 5.842671903871722, 1.573706761963906, 1.7641929921603974, 1.3934671109722507, 0.47369582037771907, 0.2780386192664024, 0.17776101947792117, 0.14956311563089972, 0.23954573477948868, 0.33667704210646693, 0.8150334656238557, 1.1445755631692949, 1.3661393451113857, 3.490691516668566, 9.357049388270225, 23.044615099506995, 42.02209711074829, 51.28989688811764, 51.218125358704604, 59.748248900136645, 76.19917146621212, 85.9941299500004, 100.71854283732753, 93.7037681764172, 84.52963459876277, 111.28292129885767, 65.09432177389822, 45.42381578876127, 35.56588757422663, 42.205393391270796, 41.464653784228915, 40.31583470682944, 51.73789824208906, 62.6206398010254, 69.79609043367448, 70.26784173903927, 86.95798181718396, 85.40915550724154, 101.3359631261518, 102.1279916455669, 94.14920037792575, 84.45306993299916, 59.14348217748827, 21.75978783638247, 4.574991281955473, 0.49817186990572565, 0.15110738034690582, 0.10107923419244828, 0.1359115820378065, 0.16583071691134285, 0.1364904993604268, 0.18316298122367553, 0.21110075225512828, 0.1772722707039887, 0.11937427950362045, 0.17880476830947786, 0.17586185687011288, 0.1276412185642027, 0.13328759300131954, 0.11322297651561038, 0.14775242085658735, 0.12868748016415105, 0.14736073542266123, 0.09728810254244075, 0.2455377068010069, 0.08001062883845261, 0.11434875804209903, 0.23091151018536862, 0.1748685932327663, 0.3190371628490187, 0.11810612819728353, 0.10395487545118218, 0.14223245092697684, 0.1401127316057682, 0.08156048599630594, 0.15471902525713369, 0.10629513616403265, 0.20296042454579186, 0.19398067897606283, 0.10949874732403025, 0.1899263578196687, 0.1113173481257212, 0.1811787062474797, 0.22502369547803558, 0.10766187532534523, 0.1567045872610423, 0.23454884968457684, 0.14523724694886517, 0.19694916243034025, 0.08135624695569277, 0.14740889170958152, 0.13869842604523705, 0.17789390508926686, 0.28335269540548325, 0.10413215585773992, 0.1863308467211262, 0.13489222544575893], [0.04368345959172134, 0.0036710236670314186, 0.04094412069647543, 0.030514073009873112, 0.06904564302174315, 0.011359891692747273, 0.011121713999478568, 0.04310464186053123, 0.05337034261995747, 0.045107199525040005, 0.038906878401194854, 0.024719385865835414, 0.11003584390686405, 0.04542579251011053, 0.06369842591905786, 0.05623513990412316, 0.04571627006835995, 0.09153895741028172, 0.06534691689716232, 0.04304441585836392, 0.018418069455712553, 0.06909939175051066, 0.06187363512693875, 0.01686489513714708, 0.044980492412803635, 0.04341054842957566, 0.02431348950091389, 0.011680515768427041, 0.09762950962589634, 0.02313655245328142, 0.03780304146329722, 0.040442348427830205, 0.02955229367099462, 0.01532882468910107, 0.02600152402244989, 0.08631154879807465, 0.05039019930747248, 0.08889783098692856, 0.046078254273461725, 0.026975980201255412, 0.055367583634271744, 0.009191237547765336, 0.050838100273282304, 0.06056619883184472, 0.13398646437112363, 1.5124210763362147, 8.310333528826314, 30.33345949265265, 54.500145066169004, 70.23331703678255, 72.85972041468467, 64.48737029106387, 59.7265778049346, 59.873760823280584, 40.4031035207933, 31.641954337396932, 31.975887283202145, 18.435102547368697, 19.453897014740978, 26.83252249994586, 46.45720343435965, 53.674897993764574, 53.12565634327551, 70.29706339682303, 59.20114494139149, 62.797064089006, 51.90014316189674, 55.09131685380013, 44.25012888446931, 35.63978110590289, 20.818313091031968, 12.599739490016816, 8.5611867520117, 3.172469379440431, 1.8535785377025606, 0.7877419816870844, 0.35546185508851086, 0.15953111462295055, 0.12811885140235388, 0.04447493950025209, 0.1661740315537299, 0.016069881648065585, 0.07329114141964144, 0.03842824964874214, 0.0513667315845528, 0.09426396280046433, 0.049973884146780743, 0.03363674506545067, 0.11315036670214708, 0.10037219632537135, 0.0764445431770817, 0.11895315331076423, 0.10128245433612217, 0.01812775469114704, 0.03411189577872715, 0.28930464699383707, 0.6306620266649031, 2.0548554533912293, 2.995083865619475, 9.70954102854575, 22.327156720622895, 27.32852582008608, 51.262287324474705, 60.54042646961828, 57.43408972217191, 59.893353062291304, 72.38685515619093, 60.09725747569915, 44.697624252688506, 34.61980796629383, 36.57671766896402, 22.466914692232688, 20.39433821555107, 17.96134298847568, 35.60858649592246, 45.37581774496263, 54.60458601674726, 65.52339376941805, 65.30700052938154, 70.0534136064591, 82.11559618673017, 79.17905099930303, 61.877213370415475, 31.48583027624315, 15.219379721149323, 5.122084454182656, 0.2779749113946192, 0.07911334069625986, 0.06308761252571018, 0.09031246596526715, 0.07272347792862885, 0.04005070512873992, 0.006954667314271173, 0.05185795099204106, 0.02123762924794949, 0.010403868547009846, 0.052183879268986565, 0.03051774831668985, 0.0028086834983344403, 0.007051930315942774, 0.0359074832991727, 0.03520575442141102, 0.05692569155906958, 0.03444630464899444, 0.07107915446883248, 0.06339677496843281, 0.0025960112660897957, 0.0063347920583891534, 0.0511153283408813, 0.01367373960918837, 0.07652980110217487, 0.06075015569466257, 0.15293002609283696, 0.053732817121330774, 0.10743407142018119, 0.035666054520275325, 0.03131537799603276, 0.035551769523731167, 0.06081895039026296, 0.06346305689564155, 0.062805914335073, 0.06628774181609193, 0.05458559555512282, 0.017700003752965602, 0.015214647902476211, 0.03937357150378727, 0.023283495778037656, 0.06426265733616968, 0.06862394226294372, 0.022403130518092264, 0.027445975142801483, 0.08542892357875263, 0.022635375817997322, 0.03624496418201635, 0.009069274435000075, 0.019075874682335604, 0.07501801851415828, 0.02496642049311871, 0.032398563118711594, 0.026276685567873142, 0.023917994694784287, 0.03768703659936305, 0.04479059836857262, 0.027374449343751037, 0.08285260053291436, 0.07310675171714637, 0.038321847696938825, 0.05799415055662394, 0.0826342424918567, 0.0699193433167473, 0.03997653632635071, 0.11278089015714585, 0.01848663815537528, 0.13523226123183005, 0.044080193545068466, 0.011078814033328766, 0.023629744537174705, 0.04655788277065562, 0.027541333937176296, 0.0540264088269924, 0.1091093831365147, 0.031583453228156415, 0.04264179451931869, 0.06643421782721436, 0.06383921372734251, 0.03547779607376264, 0.05183240962064555, 0.020027311834236308, 0.03835369397195117, 0.007552874730824824, 0.014145267684192908, 0.031163884109006296, 0.03627748844484168, 0.03596043529649896, 0.007290434554189204, 0.03285332440188335, 0.016097388034986875, 0.03936796374018154, 0.052658949543031, 0.08034347871979398, 0.10337146885332563, 1.5036016270037622, 11.308271654190557, 36.628092873481016, 64.82230932481828, 80.75136446183728, 82.30971428655809, 80.38004936710482, 73.93415958650651, 72.10795894745858, 56.36354546393118, 42.93466398792882, 51.74062821172899, 34.185817318577925, 33.055456915209376, 30.882193196204405, 30.501384004469845, 45.83500177629533, 44.85389932509392, 52.30333143664945, 57.54555563772879, 57.505182681545136, 51.51547631909771, 52.66517792978595, 43.176991939544685, 35.46369021938693, 25.076230264479115, 15.089411985489631, 9.007860383679791, 4.3246822876314965, 2.1063703923456134, 0.8075435159187164, 0.6193751000588941, 0.1332851721634788, 0.07163995381204352, 0.007005707922226359, 0.12609050338787417, 0.025030126449682062, 0.07371849590732206, 0.1047250542849783, 0.08533458751175674, 0.18592000908909306, 0.03891077395828982, 0.09008660026255155, 0.05509249295198149, 0.06728282874269832, 0.11256429411831403, 0.06865737433995932, 0.09805035236622058, 0.10430395107475982, 0.05437857561534452, 0.1045826462007338, 0.33869516284715745, 1.4835828302368042, 3.0621188879013066, 6.253340628839308, 13.503440830015368, 24.520516703205725, 44.23398440884006, 54.69794234921856, 55.75883757683539, 48.812218020039225, 58.58015137334024, 44.37433465834587, 42.581281969624186, 32.47669550680345, 42.23936503933322, 34.62129846695931, 32.621203468691924, 24.52653361905006, 45.750929694021906, 59.71999606778545, 59.99025521739837, 75.09297678547522, 77.07081625538488, 84.45763557187973, 94.68368607182657, 88.89712318297356, 72.38529405286236, 40.73143336080736, 18.724122393515803, 5.89156424806964, 0.27606879270845847, 0.08402134427019665, 0.032536305727497224, 0.04451140528544784, 0.07599876427482213, 0.048841181015896226, 0.04483656747446907, 0.024709332877049045, 0.040664464130156466, 0.06003814974739667, 0.098432139944165, 0.018815701647150903, 0.09366385548585847, 0.07740715563657784, 0.044398560534201326, 0.008734086070269828, 0.025324576173818884, 0.004508237348824379, 0.03219354649885528, 0.08633925819829588, 0.0338617374279326, 0.025483738600967393, 0.04483761701492533, 0.007372653504247748, 0.025621910218990622, 0.030813142244193344, 0.02649005637654374, 0.0712327167932545, 0.017077704786413142, 0.020215231286842498, 0.05601845959561968, 0.01583957167777924, 0.04671055643308548, 0.032310171894008116, 0.11547245580943362, 0.059710417333389484, 0.04356718659701367, 0.04917437563680353, 0.03672151683619426, 0.009930920336515674, 0.05092508955708435, 0.05370046905872803, 0.03092073929315854, 0.04232328197348022, 0.00823965483915902, 0.0402152301713584, 0.009830865423165022, 0.025737541615061706, 0.05274912192215843, 0.031107065282882224, 0.17106550295026074, 0.0839978866579552, 0.1044872682541609, 0.09698518371630101, 0.12473288833373979, 0.12128831953891825, 0.23239583618217902, 0.10081884090698535, 0.1389041819399403, 0.20157212000941077, 0.19062250191646238, 0.1609831117093563, 0.2292286295203432, 0.1392020062813836, 0.1460661847264536, 0.14314784938769956, 0.1341093601959367, 0.24019580634851612, 0.1777760041577201, 0.11058160494412146, 0.06552636533254577, 0.12420879992386027, 0.14876298275926422, 0.09522486688388933, 0.24123547959231564, 0.1039584224382716, 0.2429343714949585, 0.13837447810557582, 0.14872300829137527, 0.1751524288087122, 0.14499098032472596, 0.10551623158877897, 0.16275058380298077, 0.0776759835500871, 0.09435634534325331, 0.1837854429839119, 0.11728687377105798, 0.31262834706614095, 0.14186083699666685, 0.1426225888632959, 0.1109185993611332, 0.0737677553608533, 0.15653823892916405, 0.23103869610255767, 0.3648167998800355, 2.940721776216261, 15.141689335146259, 47.24412895018055, 79.30406478143509, 90.15346619390672, 93.05182318533622, 88.22605271493235, 83.01434455379363, 80.57096681287213, 60.93320477393366, 48.726714272652906, 46.9722733959075, 31.52311632710119, 30.413930839107884, 40.98274746248799, 63.35173429981355, 71.30617157105478, 70.48069307881018, 88.57384927811162, 77.80580566775414, 81.2670070894303, 67.84926906708749, 70.28735945301672, 57.357313248419, 48.09322011086249, 31.328517736927157, 19.05649423599243, 12.35509047585149, 5.507328375693291, 3.095091557310474, 1.3716087225944766, 1.1603067190416398, 0.4116467434552408, 0.24560265573522738, 0.13564231745418043, 0.31130007317950653, 0.2516633152000366, 0.11630257336242546, 0.31765134043751225, 0.2382568684556792, 0.2493670432557983, 0.2456749437917625, 0.3455358683582275, 0.44009275253741975, 0.29251801811399003, 0.26192022127009207, 0.5302722103172733, 0.30681346392919945, 0.17251883302965473, 0.1355717760781127, 0.42521342514984073, 0.7631707227518483, 3.258276620218831, 4.632766814001145, 12.852218535638626, 28.175630300275742, 35.5055340643852, 64.12233883334746, 73.32681194428476, 72.42458051250827, 80.56896640408425, 95.06725465097736, 79.43524452947801, 61.99385289222964, 50.03402456160515, 56.14839169286913, 36.50202397377261, 30.431055907280218, 29.04987954324292, 49.765291213989265, 64.65523988969865, 71.4931901808708, 84.34125884886711, 86.76636618952598, 92.89444984928255, 103.86689601405975, 100.97493248601114, 90.93749307817029, 57.60613664504021, 27.109016256947672, 8.968774945505205, 0.7543612632059282, 0.2610573611192165, 0.2522990762466385, 0.3223014941378948, 0.15691181404456017, 0.11121345128143027, 0.1742957739700233, 0.15760690094001834, 0.1764407282274577, 0.07035238217682609, 0.18908873260501893, 0.14847412164653503, 0.1901973537620037, 0.11629122760026686, 0.1679353902657186, 0.06979267067846752, 0.20197822321807185, 0.12660441048924, 0.13285204137284912, 0.30473276912685365, 0.11157172762097851, 0.24425064844469874, 0.13215088706103065, 0.16872606961236847, 0.1544719772233117, 0.3201018412026667, 0.15402496491949405, 0.148264397416384, 0.11071076736815515, 0.07705159890916079, 0.15449604770589262, 0.19951085319682477, 0.12720118532137525, 0.20737738108202336, 0.1365584207157935, 0.14204814549415343, 0.13886163341662577, 0.14938025044337397, 0.16680058422348193, 0.116914470770186, 0.09271594425362926, 0.19283113340216299, 0.1279164586336382, 0.15162689521187736, 0.11863816093893782, 0.08073681890363656, 0.1719072956832186, 0.11701747895248475, 0.16131842839381388, 0.11169178125959252], [0.06546431221067905, 0.1091950394273285, 0.02031113400364355, 0.03148699701283007, 0.01968231371363565, 0.05075899786466072, 0.019938367111007535, 0.021529646642926722, 0.02779055766070322, 0.03713981616460989, 0.05010443318995738, 0.017321655909801205, 0.004816198469920745, 0.012439573878392339, 0.09749169040831829, 0.0480532136204983, 0.08208526388531731, 0.04456442623068729, 0.04479303452817183, 0.011861738654965115, 0.045842567323556835, 0.056276516312913555, 0.01799319134724717, 0.06260995287448168, 0.014484772954376475, 0.06653173315909601, 0.07819619555506976, 0.090431094680342, 0.07551434389766186, 0.08007701035709151, 0.038632737667930704, 0.05270126440952863, 0.043382532594184724, 0.013447761866113832, 0.05382324230947322, 0.053092057351022966, 0.061519901688781485, 0.050335592560229764, 0.05733591249032367, 0.11280525941401721, 0.04300626851017437, 0.07405765835315951, 0.13234933447693625, 0.8346161438572792, 9.041534912201667, 24.797288948489776, 57.49693785944293, 64.27320495728524, 79.31911099341609, 65.988206401948, 63.154772481610706, 65.31895591366676, 47.210220060040875, 33.879962659651234, 26.71421793199355, 24.86169230553412, 10.891773796850636, 27.6766400952493, 55.247301670812796, 72.56645264164095, 112.36063957214357, 88.57028776599516, 76.58997289596066, 69.25466214456867, 50.82062059833158, 37.12971302770799, 25.34213754438585, 15.540888559433723, 9.623891172870513, 4.954588461306788, 1.9803260074507807, 0.8484485661310535, 0.04713533303490089, 0.06581790775300995, 0.11507916925174576, 0.09404677687393082, 0.1005116090058319, 0.054376583786741386, 0.2117364673364547, 0.08404851740887088, 0.060793849519423904, 0.07931174214689002, 0.06491542553469058, 0.06003959765357356, 0.14445050529414608, 0.10883917626474174, 0.10071105999691833, 0.06629429186784452, 0.07382916496886362, 0.0524814622927337, 0.10743648459714268, 0.02278288604781753, 0.06481445514627042, 0.0448279106809247, 0.12081860804990416, 0.2048075391400245, 0.18426948797798928, 0.03476300922733161, 0.06217136753783111, 0.44502779901508366, 1.8256317727988767, 2.266767385505861, 3.683339708274411, 5.65232124059431, 13.51316144389491, 27.746952502958237, 42.019680930722146, 55.853225492662006, 51.722483327311856, 58.49969963873587, 37.027339166210545, 30.84802542963336, 24.7279453662134, 36.35611572573262, 17.084261794244092, 20.29887753148233, 42.12801679488152, 47.13533024634085, 49.24926419411936, 59.73318699867495, 67.95208223404424, 62.04364345919702, 82.89541044542867, 79.00541551651494, 64.83197796729304, 33.75586278976933, 16.790105604356338, 2.0369649101649565, 0.4547796999254535, 0.14418576062927324, 0.024357514658702478, 0.14140253255684532, 0.03867243634416692, 0.05021847686880539, 0.027738327701245586, 0.10988495522929777, 0.011929358363211637, 0.030934714652117223, 0.030180160181536794, 0.04290665409738018, 0.0368191700639023, 0.034562581474141735, 0.06908578602897544, 0.039522426217914595, 0.01683091339204581, 0.0167631529151432, 0.0767816908116783, 0.06096056557350582, 0.026187080093809677, 0.04198859731156019, 0.053247837499985774, 0.03615623587862619, 0.016550590329232718, 0.042579576688548254, 0.03787377436134604, 0.027033588097941492, 0.01532921156350283, 0.07708314640988266, 0.06044650142411552, 0.037363893052022305, 0.032470563892275095, 0.04062877975464348, 0.013455382525740613, 0.026508909800360282, 0.01378660830068252, 0.04425468539158183, 0.02907164244642181, 0.038408978707006866, 0.018248043901797746, 0.037532141281952786, 0.08006263088675276, 0.016994902173117284, 0.01772859606951956, 0.04743572377089051, 0.05728515916534009, 0.02461115296389307, 0.03636641976153178, 0.08968481012890417, 0.05247896484610054, 0.08935762929820246, 0.03296531879553392, 0.024768888552282608, 0.0633300333884695, 0.04278502231764217, 0.02643422388862218, 0.03167514054615411, 0.08336610160768033, 0.08498941127571367, 0.026744209875863408, 0.024637577251621315, 0.05262121205188094, 0.03706744383840311, 0.04035850010451771, 0.019408502398178946, 0.03748291630237814, 0.03293064565608098, 0.06748458565843683, 0.036474874828972166, 0.06634996347730199, 0.03961047653349177, 0.041459766817429376, 0.0558384174420949, 0.03571080937681179, 0.07739132059918297, 0.030465269378656824, 0.05096453159386593, 0.015090740841603088, 0.015929252803025228, 0.07637276073857661, 0.02733239686236747, 0.006637964172348861, 0.030490285979824203, 0.10098197166958164, 0.04945513920017308, 0.024222983873539397, 0.03863182219286119, 0.029977493536388202, 0.04905938200892941, 0.16736356691727716, 1.177871092673271, 11.16107882991914, 32.23953331670454, 68.54842370556247, 75.8644050167453, 90.60707261485439, 74.74266990538567, 69.74444066324543, 70.69627438822101, 52.83835841763405, 52.19344231390184, 43.34177071048368, 34.31563208180089, 19.91305947303772, 34.19184992390294, 47.649788318141816, 68.93334942479288, 81.99677974947038, 74.06550407409668, 63.85162861116471, 58.685188524184696, 46.09513336612333, 36.360775501497336, 27.415451426659864, 17.286567841806722, 11.297678312947674, 6.181148425225289, 2.8838900644933028, 0.9433525187834617, 0.13306208735992833, 0.07181991552633625, 0.10082013559557738, 0.23108430897756932, 0.09565441238303339, 0.07211415457629389, 0.1249168030617218, 0.04927069970196293, 0.011265629361714087, 0.07089601348965399, 0.04333854765601216, 0.07134341649831304, 0.4987396942752023, 0.3138478058240106, 0.04175463022904531, 0.1349156830580004, 0.08091935467335486, 0.11722277519443344, 0.16428870449383415, 0.07715653763302872, 0.017214641087658463, 0.04191702937767391, 0.07685659888891444, 0.07981765129032635, 0.05927305007653852, 0.04241196048115531, 0.1336179914013032, 0.47892234798881317, 1.110982791550698, 1.890263730479825, 2.992699799999114, 5.276793030000502, 12.142992231153674, 25.592280818570046, 36.207140184217884, 47.16551288481682, 46.73507590447703, 52.11838776065458, 40.03912325828306, 30.18887504454582, 25.923995664042813, 48.97039151960804, 31.044840158954745, 28.770857818665046, 54.750913958395685, 55.98262056227654, 63.142903389469275, 67.94121726866692, 78.72857462975287, 72.69807169514318, 92.56890881446101, 89.04084667082756, 77.73876451676892, 42.988267098703695, 19.878356302938155, 2.4564625226682235, 0.3245625566811331, 0.1603942352437204, 0.03335842532255957, 0.10976353795417856, 0.05151781944497939, 0.03182973900449372, 0.03342407905767041, 0.09410669261048879, 0.02527893074007044, 0.07424784734124139, 0.059664160944521434, 0.06854976196923564, 0.045858770083155365, 0.044646095033855214, 0.02142138884312684, 0.08819011896247826, 0.05894656255540829, 0.00892342182792603, 0.024587626403738416, 0.03093664902412603, 0.05182929164279373, 0.017448690524625204, 0.01845345697215488, 0.06906930747772418, 0.06338003594728728, 0.03972177378713124, 0.046566187163754824, 0.05743281878230553, 0.02050973655235383, 0.015763088332248792, 0.10312733195361592, 0.06131999104494049, 0.02758840237924409, 0.0913291106060628, 0.02452680668342979, 0.07726752079061924, 0.07733607033808386, 0.09037291030249289, 0.023160492700915185, 0.05474719797231017, 0.011233371314442447, 0.013430662783643892, 0.04591061891387067, 0.030934473334421075, 0.02515445102847392, 0.01680445846080059, 0.03468825436768032, 0.033877959339729244, 0.1551823858772555, 0.26839519640611065, 0.11771897800386914, 0.14375751747960044, 0.060801253759212075, 0.2598279738618482, 0.14170280837964627, 0.12854360885197116, 0.18192971756141033, 0.17516618774783227, 0.21172578807079026, 0.13237640802418033, 0.14075033126338837, 0.09284135284683398, 0.18651570373725507, 0.18980701664282432, 0.20570377008088175, 0.13947703184620028, 0.18240781771319528, 0.08483313700003971, 0.1736153959627113, 0.13390559612983657, 0.09923618752509357, 0.23102115268909165, 0.11302139580009446, 0.1986124159227456, 0.13349403837515464, 0.17611435944995574, 0.18503269541167444, 0.1622752722112402, 0.10694290946928725, 0.20905696756897435, 0.14239385033086424, 0.11336927632651023, 0.11732858725853505, 0.12341353171054395, 0.17023846507072452, 0.13347569823024735, 0.27150180551313585, 0.2041262265054449, 0.19712249748408797, 0.23114804749286946, 0.31752720355026187, 2.0311639698282367, 17.12980051194468, 42.49990063328897, 83.40527149938768, 86.73665031310051, 100.49702305947581, 85.83187718545237, 80.44538820943525, 79.9626934912897, 66.51861283086961, 52.33858177738806, 40.19417847356489, 36.262335777282715, 18.405680848706155, 38.556330050191576, 67.38831996917725, 89.38789013893374, 131.1061251548029, 106.87233371119346, 97.31098375012799, 86.73166890298167, 64.52171456429267, 49.7711512350267, 35.839751382027906, 21.854128683767012, 13.904694395680583, 7.966758906841279, 3.7241828585824663, 1.6183122007116195, 0.22176740811236445, 0.31915167767194014, 0.3262325670690306, 0.608486294025375, 0.1274006899386164, 0.2103463854760893, 0.49841729383314815, 0.37117021218422924, 0.11576777504336451, 0.17553715816428586, 0.33811483592275654, 0.2566953330871559, 0.4641609674980564, 0.44177679765609007, 0.1489310164845759, 0.2459429366694343, 0.14222039270304865, 0.24748723202895737, 0.264755604608405, 0.27721786330784526, 0.21816549251877496, 0.18165412509152967, 0.22754698991775515, 0.5681998751336529, 0.27952210256649607, 0.11225097181816256, 0.4087965592982308, 0.795259326696396, 2.5369699058994173, 3.3161933575907065, 4.900967699866142, 7.102296467750304, 19.221316153003325, 36.229066233481134, 53.60288327740085, 73.53570953492196, 68.31574870694068, 79.64986093582647, 54.572061723278416, 45.6402757090907, 36.58653536150533, 54.926734201369754, 29.490818669719083, 34.35232193239274, 60.361001568455855, 63.71251783063335, 68.69553612124535, 78.53830045269382, 88.18424809363582, 83.39989000751127, 101.02815120450913, 101.9748152455976, 93.62039427603446, 56.30944421214443, 27.53590153109643, 4.001858965043099, 0.7379747037926029, 0.27960447234011465, 0.2131818301014362, 0.22521710203539944, 0.18027938031140836, 0.17962109627983264, 0.20029163468749295, 0.3114749250873443, 0.10088894561293626, 0.2187155436484083, 0.16199447034347444, 0.14095006570700677, 0.12015214219929711, 0.08403472782623383, 0.18111623943813387, 0.14137204225745895, 0.1708669636038042, 0.0810012954377359, 0.23188764409672832, 0.10073902986703381, 0.14593489257799042, 0.17240296989198656, 0.1441319352917133, 0.12487314371091705, 0.1911161076878348, 0.12046962435687743, 0.13255482990174525, 0.13866689386627368, 0.09968863905317361, 0.1073851413844574, 0.22000467044211205, 0.1468608017650343, 0.1715541444718838, 0.14658712451496433, 0.1652521826326847, 0.19496392218335984, 0.15479765652168184, 0.202951752430489, 0.17683581509176763, 0.25914253967423595, 0.09170304578278335, 0.1265552659488974, 0.212636390821107, 0.14066359478860133, 0.13369170438137748, 0.217079424990281, 0.15774372424329483, 0.11402098732369562], [0.014194574060609505, 0.006947529290036689, 0.024535616694559014, 0.029752560545720404, 0.061698166518321926, 0.042382787852998705, 0.09354995353327644, 0.036191617649409084, 0.02344265628996636, 0.06445909760171367, 0.05320627339965394, 0.042196475269813696, 0.024133820815252203, 0.030432164804228855, 0.068224917706703, 0.03661623720320002, 0.0012564469192687783, 0.02337778396453829, 0.04215316065857488, 0.05617287993851689, 0.06338740188267923, 0.040180369340364015, 0.06979857721636373, 0.08255281500638494, 0.0355983629912859, 0.02399211370145842, 0.010231741996962699, 0.12899337907231626, 0.062373013370820594, 0.07204284711230187, 0.010408811729341265, 0.03632683599848421, 0.05819562018939084, 0.04417562128735646, 0.07715142016569454, 0.0290408035770299, 0.03335392455600443, 0.12463213244993841, 0.07233556164729019, 0.07190227763907564, 0.04841369246282885, 1.0099060088396072, 6.57975733280182, 26.88206595759238, 44.486753709854625, 65.61152550481981, 60.10644758901289, 75.14660343047112, 62.30739931906424, 56.97041849936209, 62.67971854056082, 98.71352918686406, 96.69253580031857, 13.648618536610758, 21.92796730226086, 24.682702787460823, 50.994310994302076, 60.44723095432405, 77.14542758080268, 60.03405632511262, 50.13368022057318, 38.06037379849342, 27.443137476521155, 16.38374903509694, 9.236435524878964, 4.989692203460201, 2.7937900347094384, 1.6194634163571944, 0.46228892440276764, 0.3368346417142499, 0.14470833984594192, 0.0728804110399177, 0.041018714677662625, 0.09771076857202476, 0.6725769033355098, 0.07665491092108911, 0.18395010592235675, 0.04107570395834985, 0.06234142373526289, 0.0037242531318277604, 0.3165712483948277, 0.12564496197287114, 0.03398961665469312, 0.06959527280301818, 0.46156383750419466, 0.30611678357085875, 0.0617809538098593, 0.10926309101764234, 0.15982763661492258, 0.07881743923550652, 0.10316991112044743, 0.05396306101653365, 0.10408619058228309, 0.07267192021132478, 0.11965661354723478, 0.0923590085679485, 0.05873411105224683, 0.02598101201827728, 0.12625407848146655, 0.03918139834798152, 0.04647197367082681, 0.09659526028460073, 0.10331930592656137, 0.6604060951259829, 0.7596316416898082, 1.1302366035599862, 6.483757322834385, 12.18704633174404, 27.967760370623683, 31.961811857838786, 46.89563420511062, 59.51297337009061, 54.59890250236758, 16.93957144214261, 25.18302267597568, 30.627294048186275, 21.964610084410637, 27.05427173645266, 21.738675678929976, 44.86931816224129, 40.94175869418729, 50.63904623831473, 74.35288044714159, 66.71984611019012, 74.1908787142846, 70.62643266493275, 58.78878616517591, 26.435947341303674, 7.364022010757077, 0.31749401662138205, 0.1080272226564346, 0.10936888009910622, 0.04170715192993803, 0.04825474070985952, 0.03431773977354169, 0.07696340686731762, 0.02481254407264773, 0.02105044907019023, 0.01983483798892027, 0.06515498122861309, 0.04877884444149752, 0.04516119723238292, 0.024071352090686563, 0.038429437085024776, 0.09407702968606065, 0.05708183559979643, 0.034618751040749976, 0.0749572983852798, 0.0485808605087861, 0.027154327385247718, 0.050918983836327834, 0.06623259880730221, 0.03157058869668793, 0.035365598666812145, 0.0941341645234535, 0.08632173776746759, 0.06213666758530083, 0.026809350332064975, 0.021745436374218236, 0.04392131457045194, 0.04830219219588945, 0.057200115744865714, 0.042655982467676365, 0.0556497797820597, 0.056171068140575965, 0.0330080013842352, 0.09859272729485266, 0.013401223939933605, 0.06289866843050526, 0.02675585058187285, 0.019644532172429948, 0.060986750458757726, 0.03144418993484109, 0.022901892061195066, 0.05097978440443835, 0.024846644561377265, 0.043652835226948225, 0.014913184643392603, 0.023806088401245016, 0.02520644158545521, 0.04811697894887579, 0.04099761661622794, 0.013616916952624679, 0.009291566337548919, 0.025629222528227878, 0.06402295608554157, 0.04499026386427783, 0.03176087536098015, 0.025309800252979322, 0.015365746296611766, 0.10402604501934783, 0.11596558660629297, 0.05529721462798696, 0.053070078288475354, 0.06706024189629863, 0.03988193595902093, 0.04032149805777496, 0.04753379068607765, 0.07427516603662122, 0.05594301142639691, 0.045893102313481995, 0.026962242329553254, 0.022308262019988992, 0.06442967216454207, 0.0289132671746155, 0.06287730989917632, 0.031920321240660646, 0.07397924925410941, 0.03715620661574987, 0.07221263517896015, 0.0890513779895921, 0.043709816846756205, 0.09030718761946886, 0.08206248809132846, 0.016970843181855256, 0.07926701027299128, 0.021567997004416202, 1.4603969647038368, 9.310897800230212, 34.053445170002604, 55.58679457633726, 77.81171275723365, 71.78176679918843, 83.4384390615648, 71.13240272768083, 68.08719219699984, 75.46979888792961, 101.82367847811793, 95.13669629250803, 21.862418613126202, 28.07335057566243, 32.709397962016446, 33.93553480025261, 43.690963637444284, 53.866172375217566, 53.88076359225858, 52.3226647992288, 40.413705687369074, 30.807811329441687, 19.199949041489635, 11.462722824465844, 6.019250144881587, 3.2618425450017376, 1.5191494120705513, 0.4705441040137122, 0.2834508159468251, 0.04261303174820158, 0.03307646283158853, 0.10243851165737837, 0.10431114464036881, 0.9416285758056949, 0.1444399486025495, 0.20573614495656184, 0.017872565057909778, 0.06723205243507702, 0.009229927860771217, 0.21724134533395692, 0.18507435527299682, 0.05980204144913343, 0.1746289302865344, 1.1783242490022414, 0.3400227319329016, 0.28573786419245506, 0.09214605144675701, 0.3243349059935539, 0.09454075036750687, 0.2996016654276079, 0.4196469383614679, 0.10348086620891288, 0.11191326493938124, 0.0507463765661082, 0.12554750792802344, 0.07010775498084484, 0.11231922259133671, 0.04980832105502487, 0.0649578974492127, 0.04487323244252513, 0.0681802854242344, 0.05202317700511025, 0.4345087070138224, 0.7759469855696924, 1.1624077611392545, 5.288574359109325, 10.771495296109109, 24.617756182147613, 34.26163281163862, 42.91853520178026, 48.163736481820386, 46.66124513072353, 23.739127612883046, 23.606555423428937, 34.50290172330795, 32.90723054639755, 44.18203261590774, 36.16120530712989, 57.973670574926565, 54.31302839709867, 58.7651264282965, 83.24905134016468, 76.09940990324944, 84.13020395463514, 81.7749854057066, 70.5074671776064, 32.71827232453131, 9.971834824931237, 0.6986957824518604, 0.101801409956909, 0.1921317410925704, 0.03831699836037813, 0.037757014900806456, 0.03459592928148566, 0.09281189676614539, 0.019935258709254767, 0.0702377371189575, 0.06079858011235634, 0.02663583524765507, 0.024531523869823546, 0.04583447360463681, 0.01982773060820276, 0.005088245867931795, 0.07726003611159903, 0.02354011991091313, 0.04482750465432483, 0.015804456122550034, 0.029420074556143056, 0.012972052866262535, 0.0463460824422298, 0.044997013098890745, 0.03692189862410869, 0.03173046167038622, 0.04359715978705114, 0.0464870426202974, 0.04397230921313167, 0.03336399861220871, 0.04504750595398007, 0.03315745747738308, 0.050264890305697925, 0.07478430041021879, 0.011866647363339942, 0.053368638074325944, 0.027464118020068255, 0.04663465627198739, 0.040527376526546095, 0.03866415876414507, 0.03229543236234496, 0.04875996037416401, 0.0742608784968334, 0.026657666838277253, 0.02329628370071371, 0.0324462061267226, 0.0077112279776033145, 0.02795891697338272, 0.1162464191175757, 0.14935077138004765, 0.1295220410271037, 0.11583529803301058, 0.17011415964413076, 0.1593520798750462, 0.18840826266715605, 0.08254951316743128, 0.12329959145356571, 0.11549101811983895, 0.24257224173315112, 0.16142322922185545, 0.13419249605747963, 0.12188212961078652, 0.2335777872752759, 0.18271437545697536, 0.1189535057112094, 0.08967131165967834, 0.21197246838240855, 0.10310361387148019, 0.1255492239649738, 0.08316235286333869, 0.17395573818395216, 0.20953270816995254, 0.10452386427430377, 0.13055504930596198, 0.1289664740644155, 0.15017206360015178, 0.14214963682236212, 0.21769974170432937, 0.14356469314905906, 0.18513885987622125, 0.2494193210957512, 0.15721877015406088, 0.21023681958115872, 0.0974072368755456, 0.1317176030528161, 0.22959552434903963, 0.1590759051783431, 0.1333030526556315, 0.14726299792528152, 2.428598250112226, 13.499695947093349, 44.325073611351755, 67.33469332418134, 89.82130419823432, 80.49987777586907, 94.10346554171656, 81.02991550199448, 76.80375775983258, 80.53987810688635, 107.4109535832559, 102.9175647612541, 22.937402994401996, 32.7136125487666, 39.36169070582236, 69.15457894725185, 79.00789445446384, 94.95594563022738, 76.79284572601318, 64.61726742406046, 50.56873775297596, 36.880415024295935, 23.847973385164817, 13.828599433745108, 7.490602779772974, 4.627842768546074, 2.3118052655650727, 1.1293801785476747, 0.6655058505073671, 0.2662406200843473, 0.2352579100237739, 0.3192394713480627, 0.3298099218837677, 1.1574980568501259, 0.41770996165371715, 0.46397563550741444, 0.24395021940431288, 0.21686574774644068, 0.10219144064091867, 0.5414907405934026, 0.501896926472264, 0.3017996636129195, 0.31611456806140564, 1.8833170903305856, 1.0068467439663027, 0.2693529595290461, 0.36275121233155655, 0.8541038884751259, 0.3238511061476123, 0.22443256671390227, 0.3193443334631382, 0.33376416131373376, 0.20405387716187587, 0.22438865455408252, 0.1975412104999827, 0.1696003904385913, 0.2431574409767505, 0.24890371327919347, 0.21103617104311145, 0.14129621487471367, 0.3204460291852874, 0.32172677497709956, 1.1357992599087379, 1.6052762034439272, 1.956925514724947, 9.830040162609471, 16.19441818806433, 35.5920615503865, 44.27249031682169, 64.30958494063347, 80.18923390296199, 74.31493543809461, 27.343587721547774, 37.85809716870708, 46.07305826679353, 32.93783287848196, 42.247774600982666, 36.65113679824337, 62.52448681862124, 58.68239971899218, 67.86695895656463, 93.03015601250434, 84.11030969312115, 94.09027068845688, 97.51765343450732, 82.38268606124386, 43.66307558551912, 14.644793675791833, 1.4071609632622812, 0.4170353139840788, 0.3065644240667743, 0.1909576653833351, 0.11040906662181502, 0.14309302813583805, 0.14868588367056462, 0.14457151654266542, 0.14770109296566056, 0.13095035067489072, 0.2086456243189112, 0.19448194562667803, 0.08838024666352619, 0.13647534614128454, 0.1569522481652037, 0.221207321230923, 0.09960481371249884, 0.17578166278619922, 0.11209420724621705, 0.24381261469135362, 0.157954873396985, 0.1612289646460164, 0.15523398955983503, 0.1650170089616891, 0.13710082628794257, 0.2186623311811878, 0.13918487655539669, 0.21168670226489344, 0.11543065805228488, 0.14108308921417884, 0.12683602951226697, 0.09885534989617525, 0.20608404080473608, 0.1426752803907279, 0.12771798823509486, 0.1539136523440961, 0.10356608582960983, 0.23366001915306817, 0.08508226113213647, 0.20880428112802968, 0.15918914829531025, 0.16193057861058943, 0.16734659040887512, 0.16581013978969666, 0.09776044171303512, 0.11309634218172682, 0.13422519269008792], [0.036862400405469446, 0.10196839414176442, 0.04706249339506031, 0.10583152273489584, 0.018370675426276944, 0.057019548821112806, 0.01680314270479064, 0.071744057500074, 0.089722509315658, 0.018288740407555334, 0.028994252244310997, 0.042044414477723266, 0.03285865254339672, 0.023656915760629123, 0.05602709723696594, 0.05841407016099942, 0.08382724823370095, 0.07541095267140097, 0.05901076072346299, 0.09517840365128172, 0.05751906496082103, 0.03743586318206884, 0.0521564303386596, 0.01689297800523139, 0.03141561485526543, 0.026125051869800495, 0.01353969241702749, 0.06331781428607722, 0.016453756815603664, 0.046138633493213885, 0.10741763117332613, 0.08919989945547235, 0.08101661719622151, 0.020250754783891385, 0.033797370720534556, 0.009897417396367078, 0.019013126335677602, 0.0446448578018575, 0.0775223369559934, 0.4953770585838826, 8.78534040143413, 24.26808080365581, 50.34162859762869, 71.81040794618669, 71.8574450092931, 68.25445775062808, 67.22090536548247, 71.59855288843956, 50.75607799714612, 38.59584792967766, 15.00153128177889, 25.583418223165697, 42.03269927732406, 35.37839043524958, 52.18897865664575, 56.55976595417146, 68.74448730099586, 59.916671552965724, 41.39417271460257, 28.51924953922149, 16.859808083503477, 8.056866536217353, 3.6729630779835487, 1.3214650197375206, 0.5558029177688784, 0.05367755153847318, 0.03360126370323762, 0.0383146311486921, 0.03806194087730781, 0.08364745505875157, 0.024219023198970867, 0.05598473640519285, 0.07252583490504373, 0.42240427266205516, 0.16535428683123282, 0.11065308094745684, 0.02749627647590974, 0.059066014815001726, 0.16955007378372455, 0.1759439202085618, 0.13324999340599583, 0.3783989565507058, 0.11148886755108835, 0.49001119490112033, 1.0183937727443635, 0.37845485032566134, 0.1099513214261782, 0.03145555867963741, 0.014679462709013495, 0.12454780915211286, 0.36055811710896035, 0.27250259213389894, 0.05176659883751024, 0.032951448773664814, 0.084690690611399, 0.22237821001439328, 0.19543895798344768, 0.009136008354084147, 0.09804531150767881, 0.12661359588345214, 0.23819496855139735, 0.061175043379227, 0.09492930250182267, 0.04208535038595719, 0.03881764831021428, 0.0888192150441389, 0.0326251068092402, 0.5879147494992902, 1.8431297112857143, 9.299412119773127, 19.409695825269146, 40.51454982449932, 61.340107533239554, 80.91804165993968, 61.34271198703397, 43.02366256713868, 38.88362438448014, 18.39962863153027, 34.7935022846345, 44.28896034917524, 69.60358835035755, 38.949457445452296, 56.96921825408936, 51.014742620529674, 63.130602836608894, 66.81111181935957, 73.19425152194115, 68.10092833734328, 49.58329716036397, 24.600829193668982, 6.286722940783347, 0.5851885183684288, 0.048701362308835795, 0.1137465286639429, 0.03681638916473716, 0.019912992363735553, 0.03252681006767577, 0.0658142305309734, 0.04062991739521104, 0.06334292281779551, 0.007993834940040665, 0.09906064613812393, 0.0934342742567101, 0.05356319376357621, 0.01526642778527833, 0.023112481970700528, 0.056673231114062576, 0.030160054203964053, 0.03517070589887519, 0.013502197201183487, 0.014188979703542447, 0.038746340846222256, 0.0274143893376834, 0.03361741666712108, 0.02994063513113126, 0.04200973367739109, 0.018163584623365633, 0.0635457331044299, 0.01671693674589117, 0.03339906245650303, 0.03781822532595646, 0.08087126733434778, 0.05713045153947127, 0.025810637894356926, 0.006485592157039191, 0.07334406277345074, 0.015189517345730097, 0.028521746449593096, 0.0335963032839279, 0.03128464254851063, 0.03818744523150306, 0.0598914324185781, 0.03432807046920061, 0.034671086337297194, 0.03918716315961173, 0.02559167081339946, 0.07590314118011345, 0.05818165823697083, 0.03807554276840341, 0.07984002105771534, 0.017633417305806955, 0.03495529346588639, 0.09054267538651344, 0.03646947773954561, 0.04159622622894184, 0.06375749129801989, 0.010586935790225623, 0.032695142567277916, 0.033942433299436685, 0.045453567027805314, 0.034776534509634784, 0.034683619535738425, 0.04644509547600343, 0.05175136517913592, 0.01903204679218752, 0.11056663558608103, 0.04923218463156973, 0.07010816866832395, 0.06977836015604197, 0.023204253558369897, 0.08415714101565462, 0.03939381154674677, 0.05743685989610611, 0.03468507510279456, 0.024420086805137898, 0.05266397124937466, 0.050543317300898415, 0.03253133764730827, 0.03959896606242946, 0.026073618641784115, 0.04307281856815662, 0.06771549221969421, 0.029470550174254085, 0.08760963882049246, 0.11366541527452008, 0.736713906930339, 10.224843390526312, 27.99348327421373, 61.27450589210757, 84.39714477908227, 80.94770262318274, 77.84180518119567, 72.2854305082752, 79.53703788018997, 64.20579510350382, 48.42167938909223, 25.92080089353746, 44.28348864278486, 59.0409553435541, 24.079269670671035, 37.86522411531018, 46.14760683428857, 59.26092970755793, 53.488252009114916, 40.22541230724704, 27.71433995616052, 16.070561505133107, 8.871384455311684, 4.050932964009624, 1.5848006957000302, 0.6813280176251166, 0.06775711377662036, 0.043731439678419026, 0.02581250906411198, 0.05588953465884251, 0.03163209981134823, 0.13685295087916238, 0.035798901827224804, 0.05255046383207364, 0.512107468901142, 0.07636041906211646, 0.22221705575864162, 0.27538069253486974, 0.3477279217012467, 0.0661972668322344, 0.9294733345027894, 1.5613430834585622, 0.18602710818090748, 0.07893340196460485, 0.38475880399346357, 1.069319375580357, 1.6583679352075824, 0.9349449183191023, 0.06347727931795583, 0.05028460174798966, 0.253643254118581, 0.913329410456842, 0.738351435190247, 0.33644068866006793, 0.2193715600597282, 0.09367335497611955, 0.2418156532991317, 0.11526578827010048, 0.10503402520571986, 0.499324617727149, 0.424941617154306, 0.08314091772321733, 0.0507789314724505, 0.07151102887526636, 0.03252137084341338, 0.07837966595205569, 0.16099567555131453, 0.016962285979741046, 0.5296897383466844, 1.6386097309089478, 8.736554941823407, 17.479342529850623, 36.340810637320246, 46.89807784172797, 45.066476098952755, 38.7118951735958, 43.30720678452523, 36.17061899554345, 21.602765552459225, 29.38249065030006, 43.744147054610714, 65.07869112876155, 46.31815541175104, 68.24762498178791, 60.32277022638629, 71.91979500555223, 76.95807164715183, 82.226332541435, 78.42843486416724, 60.998798570325306, 32.264595300920554, 10.358494231777808, 1.0112529752715942, 0.08155364483114212, 0.10119079957686125, 0.015792760832775986, 0.06562694501612457, 0.01687836679329555, 0.03833248482776746, 0.021425286315441616, 0.019015288618843884, 0.0368551264006284, 0.03482950948959878, 0.042151046255903865, 0.034748411421934446, 0.03247492293256425, 0.03543879836797714, 0.04779263647393354, 0.07597098592668772, 0.015051719195569956, 0.02439480398841683, 0.10203454583402603, 0.07114778828596877, 0.10488459975608896, 0.03298909816470358, 0.03309564950365213, 0.03793073299851629, 0.0166937300274449, 0.03002657104403742, 0.07924645613398283, 0.034145534699482304, 0.0221934522532167, 0.06195947144841475, 0.0313344631614464, 0.08206909176923576, 0.013366218509843514, 0.035389550405764775, 0.05448919871161061, 0.028641330859353466, 0.025845874108434207, 0.05035512014141968, 0.053725696334074584, 0.07478512012429776, 0.05363466593647196, 0.018914103725804918, 0.03679616827397578, 0.04500772300807219, 0.13304311902292315, 0.23836145477910198, 0.1535583407648148, 0.15784613487701263, 0.10547903802005515, 0.1595465283119871, 0.25659990917530756, 0.16015472551507337, 0.15192353977791725, 0.16169762659457423, 0.101831478907937, 0.18437736847948644, 0.08863309398293497, 0.1143993121842223, 0.12076026279359095, 0.1464720734304959, 0.1604135253376538, 0.21930714738705467, 0.20566001113864685, 0.26542029313502774, 0.1989969920607344, 0.2090279788019196, 0.21549377620460528, 0.09495434591606741, 0.24859412182723326, 0.18098810357191872, 0.09613121784622632, 0.1673466210523921, 0.09817120273627582, 0.15274519972022504, 0.1409801576406725, 0.17269750005535542, 0.23443957490305747, 0.08762951880212753, 0.20024246716451263, 0.13920004509629744, 0.17985288384220294, 0.20826331580117827, 0.18136944681886705, 1.5007758044427442, 15.675877909506521, 40.05957841873169, 76.8353642186811, 95.94881519194573, 91.93746212990054, 87.33311730046427, 84.2923233585973, 87.24281649435721, 70.00851031272643, 54.455233927695986, 24.71005347467238, 39.44118930447487, 54.73288674508372, 51.88748959572085, 70.61530097838371, 77.0564603805542, 90.03224926610147, 78.06745913720901, 55.575411858097205, 38.41286151639877, 23.170609474182132, 11.982301550526774, 5.369310955847464, 2.596381311455081, 1.061754716980842, 0.34360492842332013, 0.3982435142801654, 0.1479931103606378, 0.09018285921023739, 0.22353290369914425, 0.26031692181864097, 0.19012413107820098, 0.2598291076719761, 0.8031698280284483, 0.5812473330766924, 0.1769508355327191, 0.2721393438837221, 0.47572671946498657, 0.7062246494235531, 0.743905021057975, 1.4736560467750797, 0.9689741149064034, 0.28892019342991615, 1.3993343638796962, 3.8754640183141156, 3.533857200414904, 2.0499846050816197, 0.4619364626705647, 0.5009846689720308, 0.3925351480082158, 0.7620438993457825, 0.6966074267702719, 0.31521049238020377, 0.4509077689820721, 0.23462927359486782, 1.0144755700903556, 0.7476387497398161, 0.6140987767327217, 0.26129539995904894, 0.3964457817135319, 0.37153027350864104, 0.190986500932805, 0.1988174670165585, 0.11103694462367605, 0.1938118331975514, 0.29442441259180346, 0.20875139041773735, 1.6541444005504733, 3.1217565651862853, 13.76104151048968, 25.56523411504684, 52.488612436479144, 77.3949295474637, 103.96923849659582, 81.53561099883049, 58.39515670653313, 54.636133640043205, 29.523552809992147, 49.42025599941131, 59.79487411437496, 83.44322435317501, 54.9086481525052, 73.58378994849421, 69.41999004733178, 83.05482341397195, 85.57954326752694, 92.5848493268413, 91.42327862401163, 74.09729096197313, 42.943626603772564, 14.45902139909806, 1.2235778594209303, 0.21917720355333822, 0.25309314170191366, 0.15139619549435956, 0.1912007144381923, 0.11027638019332964, 0.1285416629886435, 0.14729247698860784, 0.12682833798950718, 0.07211357234947144, 0.14902411148913447, 0.1709522598332936, 0.17374523254411836, 0.11271240955759441, 0.13912591842874406, 0.17638488041777767, 0.23171031006401588, 0.08207646919594658, 0.13397411503378423, 0.20736995002915784, 0.1306669441081824, 0.2089832392671416, 0.17136498204162046, 0.15652375986739514, 0.09224329098698594, 0.09820390702976335, 0.13427822129620662, 0.16500426125862908, 0.13363959508076792, 0.15432603747373627, 0.14113388084355863, 0.12577685166991528, 0.1402211177252954, 0.06129350738539811, 0.1618754509235582, 0.0996354112641946, 0.23896036699654596, 0.15265555211132573, 0.23980721590980408, 0.16698996115836406, 0.13008831789897335, 0.17901176526661844, 0.12355190251142749, 0.1165499737966926, 0.1092945312660548], [0.028960101959866383, 0.029141883132979277, 0.03776241199023301, 0.0645561762634785, 0.04214694385506934, 0.050778192197603565, 0.040675009330434185, 0.033948657763821465, 0.007279724645007763, 0.01495443560528539, 0.034439321757564624, 0.02764180445322587, 0.021876322496081554, 0.05379244557491714, 0.01754425041708014, 0.007393165508420357, 0.024340354289198597, 0.032133806962519884, 0.015909010844845927, 0.015349206458326551, 0.01295503709585436, 0.02305917182726966, 0.09702250751997195, 0.05624733985431733, 0.02926073975921158, 0.012494188286514293, 0.022070665595932834, 0.028973154182876312, 0.03292024601250887, 0.012645699410519053, 0.03251050005576784, 0.07661945637195341, 0.08590123210583003, 0.03213723903642066, 0.08278204383508814, 0.06182121173028023, 0.032100591305342895, 0.41574917493327973, 4.392317677697828, 22.02510479957827, 53.93585328132876, 62.759256362915046, 70.94978501719814, 70.17555621362501, 58.00346882112565, 72.84982819711009, 68.81482324292584, 43.711995386308246, 22.417569314279866, 25.925374377158384, 28.835896599677305, 13.606425600667155, 11.591419712189706, 43.64235762626895, 63.50851928034137, 52.63953739596952, 28.546790461386408, 11.55829333489941, 5.032096457096839, 0.9587072496933322, 0.7379669203392921, 0.11984870243336886, 0.07437217575047286, 0.11208607905334043, 0.01403225726643277, 0.03629819580143498, 0.043141456215732524, 0.06278540616134001, 0.201547926952762, 0.07221520157350649, 0.01626098994165659, 0.07314747695120112, 0.13298382381758383, 0.09888171098164975, 0.023850877731738072, 0.13273502910329452, 0.1765336700144314, 0.08213335888520365, 0.06731846715293585, 0.14657489775169283, 0.6779871388308464, 0.12031517337046324, 0.016843099935701298, 0.48304359458627244, 0.9024928209762421, 0.6632222956226719, 0.9153663463169529, 0.12947779178859728, 0.05135997851950027, 0.17591675473076684, 0.5791646158022266, 1.1655455347030395, 0.1474049693394092, 0.14345313542552535, 0.09351695046549843, 0.11876555369986642, 0.12069840885458455, 0.16308392398059368, 0.3247082359608143, 0.08129195685708716, 0.08142053705429839, 0.056760415750285315, 0.07033591128645406, 0.15674848409910358, 0.07413897092544264, 0.1232744254652531, 0.07123342159414484, 0.022768774708252282, 0.06438167675608589, 0.173334103798674, 0.7652490886469042, 3.306757115548657, 16.377633079405754, 36.844619474103375, 51.054197742092995, 67.3238754272461, 85.22725166813021, 60.90906650789323, 60.004493421123875, 107.69941253046836, 86.85370952852311, 50.07987706891952, 34.843892974238244, 32.368594984854425, 46.94455008352957, 51.989263334581935, 61.73748285539689, 64.39899144634124, 71.66431534674861, 67.56100623838364, 49.69568483291134, 31.39110503658172, 11.505009897293585, 0.6567690160966689, 0.03740961317934337, 0.1304011882072495, 0.05639170529320837, 0.03151787993227763, 0.0113569614064369, 0.011070471335833353, 0.04951544564157244, 0.09103682508031208, 0.013283278000721288, 0.0478255246285229, 0.06073186151503075, 0.08692120156821706, 0.014025927464958402, 0.05015355091722262, 0.07973592503056412, 0.06502692197119037, 0.019566295443162806, 0.03825248609627447, 0.01063726776685085, 0.02818210328358316, 0.022587008856897874, 0.05983232107434062, 0.009533043954551462, 0.03413841774266574, 0.07346938709698378, 0.057359270511134985, 0.06504314771342663, 0.03455881232155427, 0.024215087422259876, 0.03887494785651084, 0.044466933881443356, 0.022968365510384885, 0.01986037552987616, 0.019852025171501503, 0.039241750754656336, 0.06135038941377594, 0.05474229500959477, 0.006661044965092574, 0.05002865177248755, 0.05120357783931879, 0.03025968393851673, 0.019478940352376913, 0.05529950140044094, 0.07878839684229705, 0.029638028485820662, 0.038738530579834216, 0.05788864492769203, 0.1127247205905376, 0.035827021084485516, 0.03565113495794996, 0.028892153791422327, 0.009407991592231537, 0.04436105669986817, 0.01258755429467607, 0.0970246295835222, 0.056813731639375614, 0.043969562787923126, 0.03656379082390378, 0.001666189644076381, 0.04555734512846797, 0.08884058123634708, 0.025133008227473306, 0.017757776358555404, 0.007427496781137082, 0.035185453091417594, 0.06899287488551871, 0.07561220396910945, 0.009403711075954621, 0.04858914191924757, 0.04607655355826982, 0.05698827328160406, 0.011268520386018341, 0.02466733976747961, 0.028420324069297606, 0.05262363288972167, 0.027560235241488106, 0.028337622962651715, 0.06513272637441274, 0.0444437635521735, 0.47774450312699046, 5.519371032714845, 24.694968038989654, 62.7165025280368, 72.87829675982076, 81.62829660600232, 78.65186091392272, 68.60572953378, 77.4195541874055, 81.75869972475114, 54.240668512159786, 34.992186023342995, 39.496608472639515, 35.78296722904329, 18.337972894791637, 21.01088773819708, 41.23521474099929, 55.13781655219294, 44.21009325212048, 28.85926215879379, 13.480141951191811, 5.570479516060122, 1.5642292124609796, 0.91256080976417, 0.3944796630211415, 0.07519795724581327, 0.09936930296281654, 0.05565393580904892, 0.05282073582132017, 0.02413173897131797, 0.057136882847595605, 0.17115809233678927, 0.17508614688150345, 0.4436973494387442, 0.3085141791211021, 0.9520396494096326, 0.3123173460124001, 0.2876244016712712, 0.8487130809695491, 2.6632069772289646, 0.6425503629349893, 0.38874144996366194, 1.1840989584884336, 1.047892202773402, 0.07704250544549958, 0.09673882516161089, 0.24908386651546727, 1.3769012256976099, 1.2654635021763465, 2.629674634625835, 0.34577265081386416, 0.3443211899890054, 0.14387495875839265, 2.467554250071126, 2.65981535277059, 0.5283465717108019, 1.5270683097262538, 0.2744021531074278, 1.0833194178919638, 0.49172827373108563, 0.3728568926453591, 1.8903685313078666, 0.4679007942397749, 0.07285014290602938, 0.09609120507394114, 0.0871417046554627, 0.17492580467895155, 0.07854452041248161, 0.03405692897016003, 0.05788579125017409, 0.01855143387201092, 0.10601919895458607, 0.21678091116970588, 0.1986786365629204, 3.347137426176379, 14.102755458124223, 36.45906225327523, 42.23190861363565, 57.38005907304826, 73.5983419418335, 47.804392460853826, 56.340046544228834, 113.7427023918398, 96.37645552235266, 48.524649450855875, 38.30497672480922, 42.27720022201538, 58.94073094091108, 59.369061608468336, 69.8456064347298, 73.13478839012885, 80.82233582773517, 81.91582202911377, 64.02071414455291, 43.493193810985936, 16.60972560605695, 1.2715144936115512, 0.016650832934124817, 0.2506398983419903, 0.06415850385242412, 0.016903584492543054, 0.030282097755961364, 0.03560914950925977, 0.04281822456828049, 0.016675071956049052, 0.023733235354865753, 0.052121274563814365, 0.022709732311927987, 0.03836745291107124, 0.019896230359952298, 0.03692116317970138, 0.06865426402298674, 0.035920253984870455, 0.03239355673412642, 0.10954419932057781, 0.10897424522667162, 0.02203489503552837, 0.03635780510282324, 0.027171171743482835, 0.010950975026184273, 0.04744501641741203, 0.07101638888519618, 0.04115042051360492, 0.04560655478628413, 0.05642224921874943, 0.07101656508541877, 0.023862346067964554, 0.045668389573092424, 0.033116805021681135, 0.04139923821053198, 0.04650915191779214, 0.03237065836606968, 0.044990348133949504, 0.012980140839523126, 0.03733957742130564, 0.02115587425989009, 0.05062294447974813, 0.0683245167977387, 0.042266832784779614, 0.16411156964398202, 0.22739383361993298, 0.10598970456950127, 0.15323974011886507, 0.12652010251317294, 0.2753009887472276, 0.19547815104165386, 0.09412784429807818, 0.09046553799341764, 0.11988248691082963, 0.1398103720238132, 0.12735388196644284, 0.2921377627118942, 0.11591677914463705, 0.12640298299130895, 0.10965496031267029, 0.12511613913961958, 0.18477227148269454, 0.1562998936541619, 0.10930799143088442, 0.1303448654230564, 0.16645357703729985, 0.16860655989618073, 0.1864073942265203, 0.19226931516201268, 0.11045062689170723, 0.1299943495541811, 0.08933585707939441, 0.09865510983452683, 0.12893947712596388, 0.09456158795904729, 0.16224049181947786, 0.208841237209497, 0.27433844523564466, 0.14447062276303768, 0.13961532603829138, 0.11018105587291141, 0.7041180302058497, 7.959200989815497, 33.95870424086048, 76.31398708589616, 85.8835034216604, 92.72545060803814, 89.23293298290622, 80.04517309127316, 91.0886690693517, 88.00734135412401, 59.43216077743038, 36.32681169817525, 39.87187731650568, 43.27669858932496, 24.69950818246411, 25.855730733563824, 61.35389858676542, 81.60282473410331, 65.06075020759337, 37.54411535878336, 16.615819008119647, 6.808766386201305, 2.060832900385703, 1.2664152898134724, 0.5686283327879444, 0.31686131992647726, 0.18528630115812827, 0.1217572189747326, 0.16435075761570087, 0.1812716633562119, 0.2517369822148354, 0.49362691539910536, 0.21995928739347767, 0.38201528991903033, 0.34325896311671505, 0.6167455798675937, 0.27882906878667496, 0.31119729482358505, 0.5585649405275622, 2.7704124633342992, 0.3722251765429974, 0.37323150964033225, 1.138029617647971, 1.3951832704967069, 0.5337313118000184, 0.2621952468349088, 1.912995459091279, 2.6226428054994155, 3.825670264420971, 3.8983610993431466, 0.5087896340316342, 0.6563928975693641, 0.6365895247267139, 3.229843603987848, 2.8086214969235086, 0.6674539201682614, 0.9266209746560744, 0.21843529336394804, 0.5081490925963849, 0.42955073918546405, 0.9776660872082558, 3.109308678296305, 0.7878652299123426, 0.12442174938417251, 0.19513678226259448, 0.22089262763338707, 0.4536145414796568, 0.1898751525028098, 0.20778495517949905, 0.1380928641846103, 0.16894466514068265, 0.32649876730095956, 0.5860842283694976, 1.3693452698569144, 5.0429619127704255, 23.07309739051327, 48.45716507204118, 68.34711197883853, 81.53321050828504, 101.3195283951298, 78.10396071403258, 71.09448125285488, 115.07505309197211, 95.88005604282503, 65.43369308594735, 53.013900172325876, 48.05196462139007, 65.50609219458796, 72.16753975037606, 83.48623706448464, 82.68757189473799, 92.076871010565, 95.8448959166004, 82.48542078079717, 55.34062662432271, 20.033321303706018, 1.991815119981766, 0.19540829914471797, 0.33621245574566627, 0.17264519157188554, 0.18366297616833643, 0.18490770050594885, 0.13524078012954804, 0.12514127448441523, 0.15336229886499145, 0.08180906620597647, 0.22183934376845438, 0.14265318641499167, 0.16035678886598156, 0.15763425027891514, 0.08039314419992509, 0.2511957257745728, 0.1294930829035659, 0.14418416716639074, 0.10893175032951179, 0.13852532081786664, 0.08684185784189932, 0.08993621720301528, 0.17814803177550917, 0.16222156944774813, 0.1915837277568156, 0.12127386345978707, 0.11823912872181785, 0.21911735676469343, 0.12760267668073216, 0.24906705854640854, 0.18097676547063937, 0.21707824521487762, 0.0780200412977607, 0.1505721606794865, 0.16010563460088548, 0.18244511087334928, 0.11555729238616845, 0.1339306012396851, 0.11768897800075433, 0.2065336578074963, 0.14458040316258708, 0.1889786764138168, 0.12324172883264481], [0.01574546830999034, 0.01498228002850327, 0.025862178374682705, 0.04940230594647508, 0.03570613241003406, 0.04103263832568642, 0.03819078920529254, 0.07677121072887413, 0.041328164403356855, 0.06766260150940188, 0.03637449049781408, 0.034115504052850514, 0.006849534195592448, 0.03670061795761989, 0.03705204164068546, 0.04041286170362465, 0.01441722219404314, 0.04048413086322047, 0.019672683988427444, 0.07625487512878834, 0.005239891057323304, 0.03982981899753213, 0.07694661422001739, 0.026831938434512387, 0.03064741827397337, 0.04582212043685779, 0.0631179151335551, 0.0763777173274467, 0.030887299555263696, 0.044380748989961805, 0.07633376686323075, 0.01111245965735326, 0.006494929811226265, 0.016527393186885505, 0.03308183693837735, 0.07289440746629432, 0.8286266233171187, 12.31258963384936, 44.303998716415904, 65.04524115593203, 64.67753071938792, 73.4273579812819, 71.53091553718814, 64.60325671780494, 69.60560444862612, 61.36176293896091, 23.50941204255627, 18.6357690441993, 27.56362484347436, 25.795508623123172, 24.68874323752619, 58.25826990988947, 54.35832785021875, 35.221436792804354, 27.561642085352254, 11.912217620880375, 2.8933562146079157, 1.073037414781509, 0.18730690402369346, 0.09133573726660783, 0.029012655591472026, 0.05425178040299685, 0.07261695340275764, 0.05624320680996584, 0.039806560568150975, 0.12118507386936296, 0.010759558382203743, 0.1292088029966239, 0.0982381894643749, 0.1539086574508298, 0.09462708847657328, 0.12350250516206988, 0.23840080105489303, 0.16866127389573282, 0.16233001685430928, 1.1661599985053464, 1.5796527074229334, 1.2876779682213262, 0.25376224289498023, 1.0517068303400472, 0.6841939219063329, 0.44108995386669714, 0.0669026882537911, 0.2840465259167456, 0.6251886655246058, 1.035645705076956, 0.5856162405783131, 0.2169000071984145, 0.054504819244386694, 0.17895118303356633, 1.7120167661097743, 1.8281331418022033, 0.5519548274817005, 0.17429532963902722, 0.1955034779084306, 0.3665548695191261, 0.07273763523346956, 0.21560364853470557, 2.7569398572368007, 1.2012994097125147, 0.13543697524695628, 0.012184149630728268, 0.05078104970556113, 0.08651216424280599, 0.032017357767589634, 0.08688482005269298, 0.013799495814788728, 0.06942563795394475, 0.016135016358607722, 0.06249610837849398, 0.18407143892780428, 0.0302338533689298, 0.006091212487644366, 1.0407214972280687, 9.211702039164882, 24.12506530361791, 58.842510869426114, 62.43814368401805, 42.47637817936559, 23.374025552503525, 30.261023121495402, 51.09781057603898, 50.25972950843073, 31.16666505413671, 26.522041405400923, 33.72969273597964, 43.25549817854359, 49.365711519795084, 58.28704441747358, 75.04793228641634, 70.03416261365338, 81.32759201911189, 60.930113946237874, 18.60044417842742, 1.7631453516021853, 0.08269907651288856, 0.0567173884220181, 0.12001584749668838, 0.03640524509753432, 0.025785452753846205, 0.08276676038099874, 0.05094280917077296, 0.01538131416084305, 0.04458924747943398, 0.027130758690257228, 0.04950174032860706, 0.0640808263673417, 0.015911179831281545, 0.06822113323235704, 0.11466581119044174, 0.03519257387867378, 0.02768998372278387, 0.04044419469972772, 0.05192308761780301, 0.03767077255273058, 0.031625932803557764, 0.07304109798203554, 0.10490854766460196, 0.04980201998184766, 0.002251827832116115, 0.014266347880625438, 0.028786830108372435, 0.028956558803216587, 0.027482029155737935, 0.038137457994443756, 0.025215485253401344, 0.04299409537305755, 0.07431091169916815, 0.04221221837665766, 0.11923939440279238, 0.007087971879950455, 0.010412566517780145, 0.039758641768487236, 0.04800329533135218, 0.05025906803747339, 0.04519252639804636, 0.010272941247920596, 0.06056525271325823, 0.034136736179671945, 0.08041801141394724, 0.026811072114674796, 0.03377402036060249, 0.06935052303296906, 0.06338935923732578, 0.012064481908906133, 0.015431418226310804, 0.0365988010420434, 0.05126567692646096, 0.035570998330630606, 0.03501307181713562, 0.03510778709765404, 0.027845865378396648, 0.006237177135077336, 0.05575628132529317, 0.021493703712739294, 0.05629801657050849, 0.0526194692018532, 0.036482271407881094, 0.05780639006726204, 0.021030825728009787, 0.036863928750878384, 0.018846793325557824, 0.09547222135288101, 0.006047983582492077, 0.023534550451703613, 0.01685771880851638, 0.025761275018955913, 0.022032721261043223, 0.05346318481550102, 0.043612757337189494, 0.02670031878346157, 0.024128402658407728, 0.9436374422042602, 15.20863046569209, 52.11366522696711, 74.01867881897958, 75.99551416212513, 81.6170080246464, 81.35114192962646, 75.58608147405809, 75.80065081196447, 75.13991186695715, 36.814738858130674, 35.33141613006592, 40.61767285869968, 30.566110957053404, 31.344954429134248, 43.65643893518756, 44.61922784005442, 39.04362570854926, 27.751573055021225, 10.944006039250283, 3.2686235875852647, 0.9122673061586196, 0.18349849709099342, 0.10222206117525216, 0.11185740946882194, 0.07495326876279808, 0.03600003438130502, 0.08964623760191665, 0.11980093685128998, 0.14852362624820203, 0.10562896142683684, 0.43169676596599244, 0.4197528117126034, 0.6455205777479757, 1.2324719563607247, 1.4858446895114839, 1.580858345954649, 2.3217879428017527, 1.433587319427921, 2.0776566814991737, 3.9949502002808357, 4.481656032223856, 0.6911805824887368, 1.25733389969795, 1.3757824921800246, 0.5748316225024962, 0.13184906374062264, 0.4086161915573382, 0.9958753230110292, 1.9060176851287967, 1.3744259649707427, 0.6656015808543851, 0.1883135588779565, 0.10832495506732695, 1.2494457681332867, 2.4431247480453986, 2.032723479693936, 2.8913967455587084, 1.5387726623204447, 2.3726191636054748, 1.0076250892973717, 2.3290673715452996, 6.981237415344485, 2.118366716369506, 0.585120183325583, 0.20712972017786196, 0.1802384558944933, 0.1869413575097438, 0.1630289801546643, 0.19472019897112924, 0.019727779116721886, 0.12977285821351314, 0.015390832803302236, 0.09005016512087277, 0.008648701740669148, 0.03687167006935324, 0.029402312807618614, 0.6073348945186985, 8.422670210561446, 22.581245899200443, 54.900791645050056, 62.01667324189217, 45.45321395320278, 41.65872873798494, 47.041456161006806, 67.45081901550293, 53.899889069218794, 30.908592708649177, 30.641438115027647, 44.73992309262676, 55.59194464837351, 58.26922116741058, 66.1823009675549, 85.02904645858273, 81.61790232504569, 94.02637527834986, 75.60687788071172, 28.380170137651508, 2.6053024972638776, 0.06623887306740207, 0.04741494746638402, 0.15078494926133465, 0.005790911288180899, 0.01749271568241379, 0.06072758674441327, 0.06809953975701524, 0.03625642868780321, 0.06636455745225953, 0.07115190217812216, 0.04428761568100703, 0.035787471795394536, 0.03363121774107699, 0.08833198312429652, 0.045274980441336675, 0.022909257996587024, 0.015510862501668594, 0.011429861375701525, 0.04907295325650804, 0.059479522263450976, 0.020546562398873994, 0.0559834034122046, 0.03593635715303883, 0.02997520867915404, 0.011545216022509963, 0.05393715192293448, 0.03886263682356766, 0.02584673021168959, 0.06187239023406179, 0.0676905254142419, 0.022059147463991277, 0.0388359424898461, 0.0649869091989052, 0.02645058369624519, 0.04046798556021625, 0.023042859900141918, 0.021158423417458133, 0.019403227882820274, 0.02946559167016418, 0.04853662276159852, 0.02450028663471101, 0.21526221846861227, 0.16019664584628998, 0.12569134859668632, 0.18114646926762598, 0.13189107600239017, 0.10672685735288168, 0.21629907250885042, 0.19610496418130016, 0.1511691423553613, 0.15471960748395613, 0.21495406726194968, 0.11129065762243925, 0.15578705907589005, 0.1797475314308559, 0.1475652042896517, 0.16765851076812516, 0.1645435359809668, 0.20681000104354275, 0.1573790817130958, 0.16610087015696112, 0.1301145487495007, 0.2611295572452007, 0.14269337538749943, 0.1603862372857909, 0.10272595550744765, 0.14113415663521137, 0.289152501932075, 0.13276767977062734, 0.11347088256790755, 0.18290718446575827, 0.10085526838778489, 0.09250677926766296, 0.17602785280154598, 0.0789984121858593, 0.11981713195000926, 0.20003173169830155, 2.141928639142744, 21.556640440417876, 64.84698495557232, 86.14591783092868, 83.76985580690446, 91.01182983767603, 90.17040298831078, 87.68689940052649, 86.37162670012444, 78.8579579322569, 41.15983463102772, 35.47887371432397, 42.03166377159857, 39.82078060027092, 39.28973482501122, 78.69426173548545, 74.62765032245268, 51.682106448758034, 37.667187567680116, 15.505971620159766, 4.282812947227109, 1.8554522049042488, 0.4599193838094512, 0.24628168542779263, 0.26602875080800825, 0.18905504005810908, 0.13504783322493877, 0.24418706314698344, 0.2798696306924666, 0.3225074185719413, 0.1926228953825851, 0.47975318566445385, 0.264990916175227, 0.517340646155419, 0.7138231384658045, 0.867165748871142, 0.8604701404129306, 1.1359234274395051, 0.5213724749703561, 1.870921174845388, 5.5989696518067396, 6.175840968085874, 0.6322385130390045, 1.391411911576025, 2.0558442583968564, 2.109345755269451, 0.6201139765401041, 1.2464898944862428, 2.228148219085509, 5.203451081629723, 2.9506392440488263, 1.3624821026479046, 0.5087869374021408, 0.33417061692284, 5.869763224355637, 6.335856020450593, 1.034521455726316, 2.171037038487773, 0.9696960761662453, 1.1732306836112854, 0.5236999726583881, 1.1328509858539029, 11.937069758292168, 4.289851150205059, 0.3969027378386067, 0.21496667706918335, 0.18192850714248998, 0.2182059879264524, 0.14888621566276397, 0.2830960865943663, 0.13894968756264256, 0.26973618735228816, 0.0997339531538948, 0.21682658533175148, 0.2645554105120321, 0.13458853287081565, 0.23188315482149202, 1.5449459826753986, 12.630517348166435, 34.524459069775, 68.25694453331732, 78.26647235501197, 56.48600578308106, 33.72413865981564, 39.07043510867704, 64.18073115810272, 63.35165977478028, 47.59005454278762, 41.79229328709264, 51.94110447360624, 61.34305715560914, 69.21592481674688, 77.52283019404258, 93.23643345986643, 90.61254824361494, 107.96203874772596, 90.3404220458, 40.90475113161149, 3.1598155681164037, 0.2750392931122934, 0.18552619393073744, 0.41650196357119473, 0.144703452204985, 0.14951914218404602, 0.11509149560644744, 0.15244290142530395, 0.08707572916342367, 0.165237489066297, 0.11724917458430414, 0.12866976821134168, 0.1560185095595737, 0.0841166915732526, 0.18720467725107748, 0.21213950619341868, 0.14533406514073574, 0.09060929439240888, 0.15802058841912978, 0.09801626145359009, 0.15574884661022695, 0.11719870471185255, 0.2223475052103881, 0.15823386729724948, 0.14124212906725947, 0.12255970373629563, 0.17877308291292962, 0.08781819093611934, 0.1659750631980358, 0.17182707095578795, 0.14935259466930745, 0.08564201093489125, 0.29839311576178, 0.1839688903982601, 0.11710304331274764, 0.15702982222841633, 0.10903747812394174, 0.1389371083989259, 0.2040731978993262, 0.1222060315851723, 0.12034758655053955, 0.16467315805775506], [0.02935008093294117, 0.129116075714269, 0.103278971397348, 0.0815618726154489, 0.04464562005934216, 0.0064853431784637995, 0.03167493561763437, 0.018432540856602214, 0.024036209722380006, 0.08258890540849778, 0.058237069376534036, 0.016057047760114074, 0.07010613087444537, 0.01919563337709875, 0.006130870465459603, 0.005803528277488847, 0.03410576707533291, 0.031234456128591014, 0.0347082416016248, 0.027250011766990347, 0.05663786849547779, 0.013054277083175558, 0.05807843171961366, 0.01953334025588007, 0.019827636762432033, 0.04044509485303875, 0.07055181018527477, 0.03989021736948241, 0.010747514522424149, 0.010087876430442257, 0.053013613778016264, 0.058366212648369616, 0.015265546784165408, 0.04320497256553462, 0.008811448501693386, 2.2137536108493805, 17.947128318971206, 56.43058269254623, 67.61774724529636, 72.05553254773541, 67.65437433796545, 65.00109487964262, 52.15912549726425, 70.58739723697786, 49.397498407671534, 17.57231447004503, 21.369006018484793, 11.1824998740227, 13.558434421016326, 36.983534136126124, 46.71294589196482, 49.94688910822715, 42.83074471258348, 17.641561954252182, 4.069798829094056, 0.2534348475596597, 0.05574597361227197, 0.07783689265770298, 0.03973478196008552, 0.0760328168830564, 0.08010699503844784, 0.07312020422109673, 0.05567426012168008, 0.09139952940806266, 0.08225689822387311, 0.23925774700699315, 0.060004671705105615, 0.22310076882281613, 0.4687693540848071, 0.8754233186764102, 1.1143476948622735, 0.8250252133415592, 2.117051496621101, 1.823205051402892, 1.6661165774829927, 2.905956828786481, 3.6646204417751687, 1.829875532177187, 0.7983480706330269, 1.915396194784872, 0.19078261429263701, 0.4242467141199497, 0.3210888075972757, 0.16507466473887045, 0.6974221153124687, 0.8169504014715072, 0.9885494386957538, 1.0551082607238524, 0.34129361051224893, 0.1896679716845674, 2.31432514325265, 2.525019669725049, 0.5657152987776265, 4.668509902492647, 1.1141700850379084, 5.497298875162679, 2.1945727304104836, 0.7192076334068853, 1.4906151496594953, 0.5855024918433159, 0.31243268821027975, 0.161981109770075, 0.18637590801283238, 0.11176703407639459, 0.06256163953953693, 0.06890209346649147, 0.13705951882706535, 0.09484616664027977, 0.17252065631891453, 0.19972063871400975, 0.09612041600649396, 0.061580265586775165, 0.07410457357764244, 0.11544990984182205, 0.07994433925036462, 1.2033370810170327, 3.210187626461829, 18.544775939756825, 40.60677259199081, 55.40485935826456, 45.05045321679885, 14.066322522778666, 20.87205348476287, 33.04618835449219, 47.50524897729197, 33.531581663316295, 23.168265858004172, 31.194966916115057, 57.9683949870448, 57.68443107604981, 63.09829035112935, 61.81882104566021, 65.66720354941585, 72.2537769809846, 36.47779941558838, 3.255761645493969, 0.4124735361866413, 0.05578597106279866, 0.07699060298862957, 0.08288806274292931, 0.028166197383055286, 0.04320849656998631, 0.034429649897520585, 0.029099325033565684, 0.0718802755938903, 0.037250680578572136, 0.05114753467721805, 0.06908939430309881, 0.009522601218533613, 0.05916813816574793, 0.03977219769430738, 0.025040604617266406, 0.020932103807647384, 0.01446778399704565, 0.09422960375706035, 0.03535270157660689, 0.017707953830399824, 0.042638033027610475, 0.06500929428805267, 0.030124565180871758, 0.049471349620650855, 0.023045443531666553, 0.007083111052070895, 0.028617836857935595, 0.07198505343929415, 0.014567469272972837, 0.07409201739656349, 0.02898358255474558, 0.049974631082506916, 0.06900350818590772, 0.04234663616385191, 0.036563606962801955, 0.03499165199877274, 0.028972309570939794, 0.010369001012746125, 0.05090293812475378, 0.10820390551441139, 0.044835969925888126, 0.028159877157679973, 0.03299850189397412, 0.048551197584357955, 0.019985412570437597, 0.04984233535886292, 0.07312420320006148, 0.0273573330243028, 0.005212205597349713, 0.05488848756818522, 0.05014892757659958, 0.024745700986034447, 0.04985516350115499, 0.01855898941416414, 0.09646075822773481, 0.057809871936877893, 0.02712422970592255, 0.024119000844356996, 0.040809526709058595, 0.04940016090028709, 0.04601794017118312, 0.11854541833482443, 0.03041245910759655, 0.047399637199217276, 0.018375103414479284, 0.002853771124313015, 0.02618294130379875, 0.02621509209876099, 0.04696670942188752, 0.05247479349735284, 0.029943770345961376, 0.05569805864304785, 0.016964804493792115, 0.15380796285406237, 2.8276028267798887, 24.00326002028681, 65.30130917026152, 77.85420771568053, 81.120773284666, 74.31498250653668, 76.36320498681839, 61.80246476204165, 79.71021836803806, 63.06560131811327, 28.815778763063495, 29.603651531281013, 15.70329135464084, 23.5930722759616, 36.84913019980154, 35.171818810124556, 45.89456688973212, 41.753324539430686, 15.908155768148362, 4.038988611390514, 0.12489848589945225, 0.02953627668771773, 0.03652185134048905, 0.028501339782510075, 0.05817992304782233, 0.07273602644882857, 0.09883281925032217, 0.04189233453343472, 0.17029774495430533, 0.17701517159660018, 0.26231230506973885, 0.5461032640549445, 1.087383238538619, 2.099486142396927, 3.8176737773802976, 4.93242314746303, 4.022471510594891, 4.555243619026677, 3.662027509943132, 5.800639785105183, 6.189171633412761, 9.043689274018812, 3.7286244525063426, 1.1853638002949378, 1.0266410463279294, 0.8868190910547011, 0.6731029299478377, 0.4837569756613624, 0.5798237578522775, 0.9186357031426123, 0.28451567816157497, 0.5135677857024055, 0.33154177088891307, 0.5263502691541949, 0.42458970700540855, 0.6015109102572165, 0.5345491259809464, 2.116674703936423, 7.176244422312706, 3.6228623986244206, 8.274486007228974, 4.569778942292737, 3.376167868414233, 4.49181693215524, 2.3786588782264344, 0.8545721214144462, 1.0448602106302016, 1.0626262186035034, 0.9444326414696632, 0.5747752997183031, 0.45908851549029356, 0.5750903150727672, 0.2902677420887255, 0.2661284035251987, 0.45627721795632, 0.2152632450264308, 0.0623301852254137, 0.1258651969293433, 0.327927153557539, 0.0387769881936331, 0.8701918574590838, 4.191002518899979, 18.66387478766903, 40.85743558022284, 40.23373949912287, 28.697509496442734, 21.909306626166067, 35.69191725023332, 39.08790534542453, 44.57166125697475, 30.96932080484206, 26.145607617593583, 39.34316927386869, 66.45948702289213, 68.6555201007474, 72.38720816950645, 71.57450875928326, 77.82147945896273, 85.51894264836466, 52.66246757199688, 6.454938688585836, 0.6026726059855954, 0.07506921617013794, 0.07448743367868085, 0.04778440102874752, 0.05148468231181464, 0.0543057129928662, 0.022483102436507904, 0.017570498504585797, 0.035330956170876185, 0.05722487953701808, 0.04476797579216861, 0.047500339456863945, 0.06005679249703404, 0.09351069918803631, 0.10475786583077525, 0.016281208917198163, 0.024979007317714637, 0.032003221530166846, 0.049230123855053425, 0.035954701128385724, 0.040209266176867875, 0.0392695022897134, 0.03739667778474189, 0.007902770547286398, 0.060497894432515874, 0.03486784069889015, 0.10031080969999875, 0.022823957936658014, 0.05169594254825385, 0.04522713442002574, 0.034293899117338086, 0.07106791595898329, 0.035640723823058995, 0.011191800510841272, 0.02347551571625856, 0.09148389101028444, 0.027667816968694813, 0.012713288475248604, 0.0106258042186739, 0.03015218648098169, 0.23743709308966515, 0.20818837708042515, 0.26315019075428286, 0.16287855112985258, 0.11907360531509885, 0.09044698334389156, 0.16151617100882917, 0.20584215620352378, 0.1382068121024678, 0.16780610526761702, 0.23234692912909294, 0.1350809129015092, 0.1984460982343843, 0.11905073759055908, 0.11635983843476543, 0.4237878580968227, 0.25511379053275435, 0.09423479017230774, 0.123214915755295, 0.13875643422286357, 0.13159577975109701, 0.08929969006848913, 0.1886439419561817, 0.18403311920983179, 0.25289616517482266, 0.12345567420725861, 0.14525993847318236, 0.14658392226744085, 0.17266328656865707, 0.15556084863360853, 0.14534972397790802, 0.13314856336482112, 0.08454352512114471, 0.09288995346475033, 0.2125260741600106, 5.689459221978342, 36.707575782652825, 79.48581172573951, 88.59873279448479, 91.66326492063462, 88.01390740179247, 84.2334250480898, 72.51796430157077, 85.93549051592427, 67.51668345543646, 34.33351416741648, 37.12566906406034, 21.268277591274632, 20.612843651925367, 52.090385959994414, 62.383356017451135, 67.29201793670654, 56.57561625203779, 24.001647926145985, 6.097473973228086, 0.5780005911665579, 0.17897687762254672, 0.09811537024835426, 0.1976387334927436, 0.12836400719900287, 0.2289853659608672, 0.2097606959362184, 0.23071608115588468, 0.23774087759515933, 0.16531388335410627, 0.33962785957321046, 0.5064623814917381, 0.8624943285699814, 1.3508906407702355, 3.484362036951127, 3.9695815357469746, 2.864821461900588, 6.529768686140738, 5.673851620766425, 7.126434733790736, 7.9609322259503035, 17.06922931055869, 4.282117216817794, 1.909740627292664, 2.8402122662913416, 2.3767631476925266, 1.2666579864678846, 0.6822402138383158, 0.9875503987554581, 2.2044129765802816, 3.229146157541583, 5.644497092693083, 5.033724731014622, 1.1827883965546087, 0.8986963956586776, 8.3191127738645, 10.64325144214015, 5.016350102040076, 13.297787039510666, 4.6453610543281805, 10.586095644581704, 6.823323282503313, 2.257101929956867, 3.3434619201767832, 2.1451008560196048, 0.4154900839972881, 0.5211316169269624, 0.8060813298629177, 0.5913445557798109, 0.2598959105389734, 0.3130369783649522, 0.6956935145201222, 0.3569886989651188, 0.6248404325977449, 0.7466473706787633, 0.1675387865473186, 0.24095585749995327, 0.2700809269182144, 0.4231513003187795, 0.13084524341167944, 1.4994534753984021, 5.366479004583051, 26.369029744978874, 56.47951818281605, 76.02118999727311, 64.43448105166036, 23.895149692412346, 30.92745342562276, 44.49072314846901, 60.934856091776204, 48.09526758809244, 38.292209409898334, 49.358596340302505, 76.48246072953748, 79.25368585894185, 82.5155524284609, 81.9623334946171, 86.36660606630387, 99.96970745825, 66.38289882290748, 8.071734770651787, 0.6776865872163927, 0.15632880581242425, 0.2541449804219508, 0.19155783398497492, 0.11533583934989669, 0.14285957050179282, 0.11561502477214222, 0.13118952332485107, 0.1410579002432285, 0.13177758773728726, 0.23331045323321897, 0.11312030541199831, 0.10792835134892695, 0.2150966209028998, 0.18692799693634435, 0.12036882250780061, 0.11061639299676304, 0.14631281907279647, 0.19818083262972294, 0.11173250649364726, 0.09741308212640787, 0.16757001229111226, 0.13037912487503023, 0.1301411932875072, 0.15975429135705196, 0.12032601351459181, 0.1947403777270548, 0.137170095958056, 0.1531799699390127, 0.1556035656962664, 0.18770176106162612, 0.16512525718538992, 0.14904177747666836, 0.14411195571864807, 0.13723817053100756, 0.15691820321784866, 0.12255857758704694, 0.11395589283276951, 0.14325937646771633, 0.1339379250402412], [0.11844739738491275, 0.02280873385438275, 0.08470356854940615, 0.03807343219617202, 0.05186013051218564, 0.040135001613488125, 0.0248796533748147, 0.015365830566283437, 0.05474489970853733, 0.008033893198796339, 0.017449644304090933, 0.08563369888091281, 0.04832222156466977, 0.01215162153746332, 0.05624863837334899, 0.05864380843817227, 0.016666183420907588, 0.04898384190915574, 0.03259719439571904, 0.059170191281385, 0.03354465363607292, 0.07312598052404581, 0.03223876866902555, 0.01570575048155602, 0.07573126169342188, 0.06762546922771201, 0.03606455813672754, 0.025777389678443154, 0.042308745455117, 0.013098785833966349, 0.04215752352930365, 0.0327453404785164, 0.020047929175498507, 0.06259258183079862, 2.955570153651699, 25.67450350330722, 55.00660934755879, 65.89081395056941, 68.0566212438768, 51.597493079400834, 54.126978612715206, 44.855315300726126, 40.572141985739435, 33.64699348326653, 25.235902109453757, 22.04942349464663, 24.86315534960839, 47.08749694208945, 35.6585810261388, 35.57451678860572, 49.018828868865974, 34.3498626062947, 6.66959677011736, 0.307072646795742, 0.04099339164132553, 0.04525341123582856, 0.0653706809445735, 0.08882776458537386, 0.03753108025017766, 0.09847065118411857, 0.04434490756642434, 0.10710806270400364, 0.020008079196897247, 0.0804193827113317, 0.1716189861537949, 0.34667626684231145, 0.5026899806914792, 0.522338358625289, 1.8512723066153067, 2.183909521948907, 5.000700825645078, 5.710881736970717, 3.7780240081971694, 6.177488853854518, 6.810698153511171, 3.980360454128635, 4.705947454898588, 5.612221379433909, 0.8220426798347504, 1.80806482511182, 0.5889918078337947, 0.49783295260802396, 0.08355557047311338, 0.17014391449910982, 0.6749006012274373, 0.3240220050417608, 1.5542899264443306, 1.0886366809568098, 1.4106318931425772, 1.3045676941833189, 0.3724241142551745, 0.5045817888552143, 4.997327587296886, 6.208569224803679, 4.688547330517923, 8.029494766266115, 3.987867625490312, 5.145282331974276, 7.0337437333599215, 1.839647382017105, 2.9513322778286475, 1.1182032621675924, 0.770059753089182, 0.9033005227965694, 1.088899479758355, 0.3445982073824252, 0.20812496032205322, 0.1904061586866456, 0.1336633744499376, 0.1624638524146811, 0.12667965564516284, 0.022897481309971022, 0.06997268601891495, 0.014253455578469703, 0.046543993596588416, 0.07584081992747323, 0.01811481163566632, 0.5055910024431445, 4.649135845322763, 33.399574295167, 68.92860335688438, 60.66294170195057, 37.12410403836159, 20.16209860001841, 22.63148165518238, 51.166550113308816, 48.44499003502631, 26.1866081530048, 25.11878601966366, 44.210634539204264, 50.39286651918965, 56.29219362812658, 76.79333209991455, 71.12044734339561, 87.8357219696045, 48.0172202664037, 3.836035127601316, 0.8208703814494995, 0.02791511015065255, 0.012622411295230831, 0.04487934199372127, 0.035185269230315765, 0.049600983188757976, 0.025656579528003935, 0.025986845777820677, 0.07304701984169022, 0.06118858781372828, 0.06708285681182338, 0.017027296200995485, 0.06964392704708923, 0.04673865270770846, 0.06172030262889401, 0.03295804862113249, 0.09761967305694857, 0.01819787854929605, 0.06014527565228844, 0.03202884334079441, 0.06010800164433257, 0.03190820747535796, 0.06366755640614899, 0.07431052865520602, 0.03821942940234177, 0.05492643190307483, 0.034699872091052034, 0.0638701215446476, 0.027609513847217448, 0.0046306433561708665, 0.004118004609124675, 0.02403442090707681, 0.0467222660870081, 0.04573310485049602, 0.02363777122340135, 0.015881831960512266, 0.04738710783121567, 0.02047224037889992, 0.04542663137638762, 0.08349643614623817, 0.04488365889917459, 0.02307618472484812, 0.03294653431963056, 0.04799059359356762, 0.04804454916607469, 0.028508902985542536, 0.018129951448269913, 0.06310607141424572, 0.03389909570556014, 0.03317022816308084, 0.024823977934917616, 0.07095741543678508, 0.06000981215507754, 0.05962195716077282, 0.03285715867194437, 0.05198793696059335, 0.0766695661830806, 0.03960780671707565, 0.06375039732384105, 0.05826691999250363, 0.042663325420430595, 0.026331095047475352, 0.021785776649091034, 0.07308721647507722, 0.03754122325429513, 0.010570553957574792, 0.03677982378811125, 0.03332027031349079, 0.018825944242698532, 0.010544451426774746, 0.025632422860531558, 0.01966418041246793, 0.006545194755158117, 3.7944756544405416, 33.14197655647032, 68.0943230659731, 75.78696958480343, 78.73161054426625, 60.33159163690383, 64.63756961207237, 56.58981915443175, 50.384229460070216, 48.56637562474897, 48.11278097091183, 30.784628160538215, 30.67456056994777, 28.025432940452333, 18.796774495032526, 38.54462569759738, 45.729933246489495, 31.163982152938846, 7.441018137239642, 0.3703169740976826, 0.053613537231520306, 0.09257437120522223, 0.07321871546727997, 0.12047174642042768, 0.2536878251140156, 0.46544919030800946, 0.3297205653882796, 0.827277266690808, 0.9311764398890158, 1.2080905033696083, 1.2090229243040085, 1.5818129527953364, 1.656219702093832, 3.0884936403843666, 5.129346722556699, 4.4804052864351585, 8.9359260759046, 9.282872465349014, 7.7104864389665675, 6.608643137639569, 9.33866523927258, 9.736495556369904, 8.391366754808734, 3.9859696886231823, 1.4176534260472944, 2.439723807957865, 0.96250637164039, 0.5061876317185741, 0.25721913804450347, 0.48419143944498033, 0.3078660380936438, 0.4319742736556838, 0.770557894101066, 0.9081658552731238, 0.6454700159449732, 0.7775799173020548, 0.14351607720938422, 0.16581481292603478, 1.9499549726324699, 8.10423356871451, 3.0558908995120757, 9.549814270388696, 5.271714541219897, 6.3381182474474755, 5.99149251176465, 2.9227695782338423, 3.8120209065175827, 4.310744145224172, 4.5802325490982305, 2.9442967714801913, 3.2886477776112097, 1.6569333283170578, 1.1029416875493143, 1.7216792798811391, 0.7856817567540754, 0.8615921834303487, 0.5403683298537808, 0.1556416862313786, 0.05999929759831679, 0.06966340866300368, 0.11142684507273859, 0.010900824037831157, 0.02611669959620603, 0.3893901425744257, 5.034134128401357, 31.513985049340036, 54.048233109135786, 46.98850024131037, 33.071291523595015, 28.911368885347922, 32.53731769900168, 56.37546554688485, 45.002792496835035, 28.303123020356704, 40.78513060846637, 60.36326085367511, 61.99703785680956, 65.25960260821928, 83.95132034055649, 84.04830486543717, 100.45902313724642, 66.0931533382785, 9.543152124651018, 0.6671756157471288, 0.0558107118723133, 0.041748011229379524, 0.014646837897148105, 0.0835847660839077, 0.07917315684138768, 0.013268117120699778, 0.08561894402749116, 0.013914292175022346, 0.09003288983818024, 0.04213106668283863, 0.02088860533530674, 0.024570033194557316, 0.04633515802842956, 0.03261543494919616, 0.04887123464516575, 0.01234389907274876, 0.04663313175701807, 0.02346339620529644, 0.025194429326802496, 0.023508398125188488, 0.04366286714831668, 0.004479419036332759, 0.015509717200221795, 0.035251612444558454, 0.09548131481654222, 0.017701539759253784, 0.04898602909017955, 0.05665691727171502, 0.028737055460712122, 0.01616636467646928, 0.04803251392478424, 0.06294285255153814, 0.050454435779923396, 0.03609566130645333, 0.0407778489733896, 0.02389197260321629, 0.026510712022202152, 0.03499741297996333, 0.24477690488340395, 0.16388227952824486, 0.13799235344894473, 0.1031909172513312, 0.14458463196792912, 0.1612151290981039, 0.13382385454831586, 0.10889084889523445, 0.12174297740022022, 0.11478626319477636, 0.1528275235285682, 0.14115586756698548, 0.1645893173953218, 0.13754151070550566, 0.14818919822573662, 0.222497214112551, 0.10525391542262609, 0.1142028719186783, 0.11574371222166285, 0.1550536524624594, 0.13581459530659262, 0.1517559044183262, 0.09941322278351554, 0.050990356417793425, 0.13099645384617392, 0.18853016257766755, 0.12047421322354387, 0.12770953828529005, 0.13038359882850803, 0.1591340359300375, 0.10716851470210861, 0.09556531635743958, 0.08739822153602878, 0.13557785881623147, 7.537263295342846, 46.143755066779356, 83.41580698567053, 86.41165056536275, 89.22089130647721, 71.78499098747008, 77.00043324501284, 64.61990717918643, 57.36382830527521, 48.76553397024832, 42.80462172723586, 38.74467834349602, 38.452344094553304, 64.58506476494574, 52.15246923508183, 52.27680444717408, 65.92375401527651, 44.87235799912484, 10.125426015546246, 0.5387594839257579, 0.18859436074572225, 0.2253066577137478, 0.2571318653081694, 0.30227001095491074, 0.4557436530388171, 0.5660420812426076, 0.2484328756409307, 0.7811687021486221, 0.6850248515125245, 0.7015323915308522, 0.951907269416317, 1.9562339518339404, 2.178807498947267, 4.048703586862934, 6.793906486803486, 6.396821910335172, 11.811823575727402, 16.525218140694403, 8.324060843836877, 13.5437382805732, 18.536727236163234, 14.300130105787709, 12.562418137827228, 15.00636560301627, 3.25693394387922, 4.730753504460858, 3.2149817434049424, 0.8874045048029193, 0.864266443156427, 0.9069244251135857, 2.094263751660624, 3.2413493865920655, 4.205977147625339, 2.9222753595921303, 2.054564952850342, 1.8420758194500402, 2.7867817398040526, 3.449017559328387, 12.953012662549174, 13.675411266665305, 12.971059487712, 16.29338154869695, 11.800483022966693, 11.122960255992028, 16.770789892442767, 9.13235249057893, 8.083074833116225, 5.730934364180412, 4.53775082865069, 2.808992160904792, 3.108989740571668, 1.8325797612628631, 0.8197286652941859, 1.920478238213447, 0.4423228651285172, 1.0674672814146167, 0.4816404585876773, 0.2328942529857159, 0.18032556009148398, 0.24687341174050687, 0.2254695892934838, 0.17388913449981522, 0.15622285585249626, 0.9350022216958385, 7.200229715916419, 48.18134007915374, 90.34503475312265, 83.87219044470018, 53.6984988950914, 30.09525199090281, 31.541998617110718, 60.30149921294182, 63.101863630356334, 43.2178787262209, 40.24872687555129, 61.84873304059429, 69.69648576551869, 77.11736694458993, 97.4102589391893, 92.35875606536867, 107.88483081325408, 75.09667165817754, 10.057676876744917, 1.0304914655223971, 0.12770563123687623, 0.11877551284288207, 0.20185626202052642, 0.2515368034402209, 0.17984605033791837, 0.11925283158498427, 0.13599687826729592, 0.19878523003670479, 0.12717621851592295, 0.13923476420102582, 0.11104512644270736, 0.171683797192189, 0.18375366565681275, 0.09734052593909925, 0.20946642624274378, 0.21576178440403557, 0.09707194317372576, 0.11180299424356031, 0.10145530675447757, 0.1462431510369624, 0.15393321822968223, 0.16680968534802237, 0.13050505440802346, 0.10588432151463725, 0.18442918666668479, 0.11529444761934782, 0.15338253890795095, 0.11039064986811531, 0.13370886475088137, 0.10141456619866433, 0.13825982538682802, 0.1648247055709362, 0.08720852284421844, 0.13520305796015647, 0.13825288463023402, 0.22251299552379117, 0.22437540123299246, 0.11530034649636477], [0.05175709168636992, 0.033766665916529395, 0.01838699884472355, 0.04302171284272786, 0.0664876831034499, 0.04539009281283906, 0.04046803152549171, 0.07459552868479684, 0.04726052712348681, 0.016071952000680952, 0.012042014465306797, 0.04747178352948639, 0.02063049116141854, 0.06329195881863275, 0.06499221052734122, 0.06917305110443024, 0.012414227859417518, 0.05578594808016093, 0.06538077032253628, 0.10365167317251045, 0.09168190941695245, 0.16775505316834297, 0.055073585902010246, 0.12544760240181801, 0.12576213512088985, 0.13057775615203765, 0.11014828263151069, 0.06578801500220453, 0.09355417467773923, 0.036263461374948104, 0.0068104560505749005, 0.12513408857968547, 0.20670089480136672, 4.700870927303068, 26.96800312688274, 57.171400746991566, 65.02564891692131, 79.39131398354807, 62.25490623904813, 55.01236738697175, 34.138411552675315, 26.940899548992036, 27.26852728474525, 13.606804109388783, 8.022947840152248, 30.04638514211101, 44.64558224524222, 65.82441606829244, 74.23288729883011, 43.11497534475019, 25.19458778442875, 4.440118622395301, 0.5640275151498857, 0.07590811309074202, 0.16041398499040835, 0.03063234357884334, 0.08682629093527795, 0.09044204207677996, 0.2008106132909175, 0.26823882253900655, 0.18973832919953332, 0.5731082923950688, 0.7921924009438485, 0.9260799940074644, 1.2551112641249935, 1.388587314755686, 1.3449912734570042, 2.080976477553768, 5.720443004562009, 5.421806487344927, 6.744591016923228, 8.077284924445614, 6.856139302253724, 2.9961642334538126, 6.648901364495678, 6.988641379341003, 8.79968745093192, 1.7385566258622756, 1.7189555615186694, 1.1294370529151734, 0.2480509654889184, 0.7063763348325607, 0.3339975116954696, 0.17943222496298053, 3.8691036499315694, 9.65568982785748, 32.127743805608446, 32.73402652432842, 36.56888077335973, 28.34906574218504, 15.922443001501023, 3.392003702540552, 0.6283917710665734, 5.950462558577138, 3.1292681492144063, 6.844353070182185, 3.440498661610388, 7.059500467392707, 5.255480341372952, 1.740379057103588, 1.6170514038493558, 3.080530493490158, 1.834166114849429, 2.963596058468665, 2.234577228946071, 3.4297557800046863, 1.3820682129552289, 0.894762932533218, 0.3660051248246624, 0.03984845025585063, 0.1410716438605901, 0.1862263982935298, 0.21421955748190805, 0.3024904297724847, 0.05211150311234017, 0.1795423424412166, 0.07955198731994437, 0.03890281430475655, 0.07799746468663216, 0.7365195044586736, 9.700887299353077, 41.66640481641216, 66.74187414107784, 52.294874806557935, 30.457433846689042, 20.93428384873175, 40.53739763075306, 40.905814093928186, 18.2699413453379, 14.18908094206164, 18.056682079069077, 30.146525213795325, 43.9896874273977, 56.3964423825664, 71.45241322055941, 78.84593979004892, 54.99230838591053, 10.53583243200856, 0.3623229691818837, 0.11511172032764844, 0.0394523061902052, 0.05803829254282098, 0.05477100798499681, 0.10169112393932958, 0.04269887190011721, 0.040617621684026335, 0.004821022908623901, 0.02352015565960638, 0.05903544024594369, 0.06801597488623473, 0.08057884391277068, 0.06410686952632762, 0.16511920509078812, 0.17392180048890654, 0.2437643051868485, 0.13547088229848495, 0.1777327814770322, 0.07202884302504602, 0.07254180017738573, 0.0072683937258027015, 0.05976735298792201, 0.02282304437680831, 0.12143345489617317, 0.03253761190740812, 0.06955777279912465, 0.019508593700705998, 0.037609903036706874, 0.024167727866780855, 0.06505594904264135, 0.0706866876252236, 0.05473383739891072, 0.032424973999901165, 0.13097316477327578, 0.02404449687850091, 0.06892627120138177, 0.037316958675341266, 0.03427234523358845, 0.020481408536133748, 0.01655330036526486, 0.022497336350141034, 0.011161383947417622, 0.046012045124605785, 0.024341411490534103, 0.019468741806884928, 0.06524037704953263, 0.029250320963441368, 0.036862932836576816, 0.04586028310680582, 0.06714987418343944, 0.043479910030240015, 0.038536363807056224, 0.07508054661053805, 0.023191986575482354, 0.002286918010682829, 0.03989154270159141, 0.11080070609046568, 0.08983199094091693, 0.11073202630805393, 0.10743107601639726, 0.06770897281145857, 0.16446809164218365, 0.01828184944667643, 0.13882789490444047, 0.14156036199100558, 0.06263879991527047, 0.02327617963836078, 0.038747225677774805, 0.07041107217270522, 0.28010675022678994, 4.560554508239993, 32.659301450175626, 67.7276755917457, 76.31496767843925, 86.96300245100453, 71.95876767558437, 64.39686944407802, 44.78982348595896, 40.58790599146197, 38.539291274163034, 23.303689610573556, 18.23238268975289, 37.148426655800115, 50.736391621251265, 67.53704840137114, 55.587606506962935, 36.67280004870507, 23.67660503233633, 4.811530305493263, 0.18340685765349096, 0.15433248793405874, 0.04141783882533351, 0.062390675527914885, 0.11499872235881706, 0.2601482905447483, 1.0284479106626203, 1.4495177807346469, 1.210782475048496, 1.0482316103673752, 2.0952992573861153, 2.2142850920077297, 3.591719024604367, 3.225311795550008, 3.6164069127651954, 4.4432810333467305, 5.76515753423014, 7.578630572365177, 6.204701767813775, 7.827253437811329, 5.057333967378063, 7.508650585528343, 5.279184695213072, 9.559310328575874, 8.134786871171768, 5.628263873438682, 2.0135793714754047, 3.0940634060290555, 0.8429796176572001, 1.5674777929821324, 0.86828576941644, 0.6993568243999636, 4.4690706172297086, 9.260890522310811, 26.97708537501674, 29.805869325514767, 34.11933314415717, 26.86962223822071, 14.537983613629496, 3.9901803530031636, 0.919823200712281, 4.717108559223914, 8.128628259704959, 8.350803563671729, 3.925479631270132, 7.753957577290074, 3.923918037645279, 6.347440740754528, 7.294210685837654, 7.975429796403455, 7.381148059521952, 3.487363385577356, 5.466606818860577, 3.870054334402085, 1.5754728091339913, 2.2043051114005427, 2.8192324888321663, 1.5013181946931349, 0.9765623077269524, 0.63147034135557, 0.5402977271906791, 0.5264801976661528, 0.130019998177886, 0.0934229821207062, 0.05226607284238262, 0.04094573331155604, 0.0659173536264608, 0.49591987784351077, 10.00699200937825, 35.48731465493479, 57.766879297071895, 40.05142381114345, 29.8836911109186, 34.30495539019185, 54.09180279700987, 45.132387607328354, 18.19279028523353, 26.608772854651175, 29.94035367042788, 40.720544861209014, 53.59328131521902, 65.41398317583146, 78.77386231576243, 90.15724735875284, 75.34821325732817, 24.00896706888753, 0.8346949589829292, 0.2325154225071592, 0.05537422178613563, 0.11226574199334269, 0.043185605862808805, 0.008527055596782556, 0.05212493263365281, 0.008627434182281216, 0.03762618623553746, 0.05959886727073501, 0.05060560407958204, 0.03901156048560816, 0.053632091881046375, 0.046722629978772134, 0.12105874597064911, 0.0621287883709996, 0.14101161321084346, 0.1085845822648656, 0.16014024645330446, 0.07406850615816732, 0.03349695317146759, 0.01248975455265252, 0.05902880975495904, 0.045048927047079614, 0.03724352531735936, 0.03444076583330189, 0.04754703251584884, 0.007838393306179393, 0.05997367961812885, 0.053173978963205894, 0.015610018219318123, 0.007949456903001955, 0.023614150817475976, 0.01718534780065379, 0.039141224697232246, 0.10663188543290862, 0.08951646996842277, 0.030902154000115492, 0.19150212407112124, 0.12942830250868875, 0.16391445522106465, 0.14560470868262554, 0.10254269195420128, 0.19231171046774234, 0.18349353284124406, 0.1056703684791442, 0.13695883955205643, 0.10512391030187569, 0.12422649655491115, 0.16846193781783506, 0.1491013484736604, 0.1981384066804763, 0.14841085810574794, 0.15879445979672094, 0.08090459981993323, 0.16307493010836263, 0.22254648888784073, 0.24239309973293738, 0.22853856816166834, 0.25088602707030316, 0.14166484106211893, 0.188632971577106, 0.3144684902602627, 0.3080840360733771, 0.23748593885571728, 0.22425972195642613, 0.1760791500489558, 0.1676283269039085, 0.16345147764490497, 0.18089214339852336, 0.5289175217190097, 8.267115873675193, 42.45052191518968, 80.01356663242464, 85.66927925232919, 98.60639356797742, 81.37174221777147, 72.40607477003529, 48.56026849439068, 41.806186322242986, 41.338930053095666, 22.37836914677774, 15.142974891970235, 44.79321241378785, 60.73133607064525, 81.58800601959229, 91.91694028915899, 58.38098518310055, 35.77966067098802, 7.343838964739154, 0.9174698398959253, 0.32763892063690775, 0.2842120009083902, 0.19666702756958623, 0.2094704558652255, 0.3186336183740247, 1.023100187941905, 1.321120709180832, 1.5577812036198955, 1.4457611307021112, 1.7863807370585782, 2.97283667229837, 3.4686536798554086, 3.8324807247807904, 5.262988738475308, 7.755819722529381, 15.51770539053025, 18.10967133891198, 14.583080084093156, 18.43122724563845, 15.370799879873953, 14.88698434445166, 13.693904261435232, 19.897817142548103, 21.049385801438365, 9.214896809670234, 3.6419778245110668, 3.7849700354760696, 1.4293244384950208, 1.9952134860138742, 1.5632963012303076, 1.7997920561221339, 6.686252624757829, 10.292263050233165, 29.537518408990678, 27.538680530363514, 30.075083163476762, 23.175175113062707, 15.117220609418808, 4.140729010105133, 5.17914709544951, 17.121447824662734, 10.700232694225928, 19.64829360285113, 10.555039298149849, 21.747881481724402, 16.328933911938822, 11.881302479774723, 13.553204920984085, 12.243569647112201, 11.369387084437955, 9.299105194307144, 9.863270482709332, 7.48844841795583, 3.6863579721220083, 3.2026203938068885, 2.4160530394123447, 1.2818597449410347, 1.7381741947704747, 0.46730649387163503, 0.5035086528908822, 0.8423130598760421, 0.21250874525116337, 0.2874710615123472, 0.29568082743114044, 0.18785438109790126, 0.12852715328335762, 0.9774278645073214, 12.676870938270325, 55.90583624378328, 89.38939632907991, 71.84231250516831, 46.30817690203267, 33.74383288045084, 50.67298650741578, 53.66397419283467, 32.91813473547659, 22.894035308591782, 32.13497861739128, 48.56325341809181, 63.747097446072495, 77.93989581446495, 91.1121326877225, 100.73899407540598, 87.03878264273368, 23.962924326619795, 0.9472873302236681, 0.5024964362382889, 0.15699208473726628, 0.13277937027235187, 0.1746237974974417, 0.12991565700259902, 0.10340365220702465, 0.08124432917083464, 0.13766567823627304, 0.12532692823198535, 0.1662916873371409, 0.16711826556392256, 0.17987387465132823, 0.0993011058157971, 0.23344120912013516, 0.15067357539890275, 0.2301463109230803, 0.32219537563862344, 0.2177274128001544, 0.16697453214756905, 0.21998639158423872, 0.14142470314137398, 0.1652029231791535, 0.247769228993885, 0.14278890655165719, 0.10128370305943875, 0.22932048346246445, 0.1468287486462824, 0.1468036362841245, 0.09140265504679373, 0.19957581745280376, 0.16082008819906943, 0.1178437507440967, 0.15897239137801433, 0.22977238340723902, 0.22522686199555475, 0.19425224182346176, 0.12235860565617201], [0.027628227459987807, 0.01429271279653955, 0.03157231430973738, 0.026651861807031017, 0.036399357711836215, 0.14006489707577613, 0.04996415099970276, 0.057958569602980736, 0.10751320830275936, 0.06390579059840211, 0.046766618747384324, 0.04916057839328724, 0.017997847246606986, 0.05471496482289607, 0.0464853227529074, 0.18164926809408974, 0.11937591893177842, 0.10126674953367441, 0.15118268678986257, 0.39465528101690356, 0.20193438766704452, 0.19185388100243386, 0.11574119945327122, 0.2032105982183449, 0.40241385179181255, 0.46554973168719205, 0.28551735344433016, 0.18670963123440745, 0.1989151279051458, 0.020755108768841433, 0.1864433084284106, 0.33046100468885514, 6.608523505349313, 25.390196384922152, 60.528565222217196, 71.3322945564024, 63.85470374937981, 45.3695458750571, 54.59905939717447, 36.58027525871031, 28.782450383709325, 17.74071554983816, 17.224612043749904, 29.225413453194406, 40.02754049916422, 28.184283048875873, 30.427215906881518, 43.6602867803266, 44.16913586278116, 23.836112137763735, 5.638733660021137, 0.049464052633172086, 0.07228836297027527, 0.07530901701219621, 0.08485315487750116, 0.07336142232581493, 0.08946957772657757, 0.3183428726850018, 0.5347598920906744, 0.4898052398235568, 2.1996848044856905, 1.560365922989384, 2.675205017289808, 3.288026081938898, 2.398733323620212, 3.681041934797841, 1.2930931679664122, 2.8451176804880944, 3.636128099695329, 0.7798416540026666, 6.075456238562062, 5.018396598677482, 7.465803594358507, 6.24723594996237, 4.960463681528646, 8.190119256896358, 5.7997891210740615, 2.368181246903635, 2.1571484160038734, 2.4606263637542725, 0.3456284117794806, 1.0069576122107045, 0.9700469444355658, 1.6439035823268275, 19.19486172737614, 72.46728727894445, 83.03065376897013, 69.88987430449455, 78.38222934353736, 70.60046657439202, 65.38074501099126, 32.90293555105887, 9.65147033814461, 6.585682072947103, 3.106516931326159, 6.4943437999294655, 3.57244253639252, 2.2786779076822343, 1.5423844298047404, 0.49839280966308813, 1.2690546772172375, 5.233830328910582, 5.910420062080507, 4.448495824490824, 5.089339527391619, 3.4451447090794964, 2.5544582836089598, 3.690550250391807, 4.162408440343795, 1.0688474654190003, 0.2073823453317727, 0.510229358389493, 0.3825966280794913, 0.1836428893429618, 0.07193557182026487, 0.0698992258478557, 0.02953331192745076, 0.17419976783135246, 0.10182808513843244, 0.04067305963666689, 0.06220626667322171, 3.7847047851931666, 19.53161877970542, 50.30538589723649, 51.600183825339045, 37.90627956390381, 24.562258566579512, 34.695046870939194, 47.27373107787102, 38.26392127621559, 35.265975306111, 50.01819779795986, 28.73408167592941, 35.76092350867487, 69.22368326494771, 76.5843717513546, 82.2259638386388, 76.31419104914512, 28.06922620342624, 0.9252971747229177, 0.06860783143389611, 0.18934169483761634, 0.2005435856840303, 0.12283266086371676, 0.16418880662850796, 0.037846708474981214, 0.06886156741529703, 0.07452104961679828, 0.1256022525710925, 0.08916017013571917, 0.23782778260928972, 0.23969202692950928, 0.4108250375476576, 0.21436935831462184, 0.2183976478033489, 0.3070230655852826, 0.31555820436727616, 0.06857004797747059, 0.13992862535580514, 0.1306214691289971, 0.05842697874252355, 0.24330855948069405, 0.3173948235569462, 0.018780687598571665, 0.07899422168491349, 0.030718967055661545, 0.13012250074215476, 0.12799651482172553, 0.04219685448333622, 0.02055545667967489, 0.020990205831044627, 0.1422306736029925, 0.04240868545527901, 0.07123728267728321, 0.05772352233649262, 0.07596182351511332, 0.0455815649981941, 0.04007683638783713, 0.04034379121637152, 0.06204587084451511, 0.10832290961256913, 0.08435412520362486, 0.025573577731847767, 0.04333390516319102, 0.07209297224518753, 0.06308674301591612, 0.03144249879574824, 0.08366216394689777, 0.033788131700167735, 0.06939863335461387, 0.017802519723773003, 0.08104007480846298, 0.16635888856985878, 0.106731032532069, 0.03941354597167623, 0.30173632346334, 0.09683605704096057, 0.15262060318022005, 0.07107705538791996, 0.15890776420072203, 0.1934285440872754, 0.4111476218508136, 0.23501521336936185, 0.13997076019164056, 0.05828826320207408, 0.03321887857671226, 0.19961216066393161, 0.3748079653709166, 7.372903727716015, 33.17036667177754, 70.11469671803137, 81.53896070295765, 72.24306891041418, 56.950583073400686, 63.02738958789457, 48.85538370378556, 39.720116892168605, 23.315033105111894, 27.597270934812485, 28.207727055395807, 25.375034463021066, 35.631128357302764, 32.57646687569157, 48.266180945980935, 42.2030556586481, 20.715462661558583, 5.765287462742099, 0.1704507786780596, 0.06395105490340822, 0.07547085308620045, 0.27802513611893503, 0.5001750672536512, 0.6827572925436882, 1.3413763190469434, 1.6196741211798884, 2.0875535568883343, 4.997893879490515, 3.286103630258191, 4.195787320213934, 3.868074027761337, 4.699217648275437, 4.928738570982411, 5.776847177936185, 4.607838190370991, 8.72464172301754, 6.19762679261546, 7.365243829065754, 6.444391435192478, 9.299809259753074, 7.408384997998515, 7.525659943780592, 7.755253430335753, 6.640304999966776, 3.226460804862361, 2.1855865803457077, 3.9736541817265176, 1.4181861329463221, 1.372170479547593, 1.8355629689270452, 3.367392545746219, 21.48343920707703, 73.38844806917253, 97.56825985447054, 81.34800403348862, 91.4575836735387, 82.57481944176459, 70.90923555435674, 37.26715680091612, 13.281904382090415, 4.466513231877358, 2.7816404931006895, 3.3663433117251245, 2.949948906898499, 5.511953340422723, 3.0864231192296554, 4.549489992280161, 2.5261534798529843, 3.705636911815213, 3.32804185728873, 1.7343305171497407, 3.709855420935539, 4.134420367979234, 2.4030278286626263, 3.2334524296945144, 5.000844972748911, 1.3779455567559888, 1.4652662195505635, 1.5019625665680056, 1.0513011101753482, 0.5213263258337975, 0.44530098596888207, 0.15209759495431377, 0.17042926692914578, 0.14339452969931787, 0.09305083192884923, 0.06479188619602112, 0.08373287386230885, 2.7544091930312495, 16.8226553932313, 49.02713252652077, 52.72824964215679, 35.81452269707957, 32.78492516086948, 43.83940965898576, 43.97787717080886, 24.8717826028024, 29.059295192841564, 52.5719000447181, 39.53619303241853, 47.28148952607186, 75.98815579568186, 83.21798616839995, 89.9476594309653, 91.88672234935146, 44.75488301246397, 2.3735328307074886, 0.09919418292420526, 0.09260204230104724, 0.028337270562206546, 0.0631912757131842, 0.17100161121737573, 0.06520888317496547, 0.05599338553785797, 0.0420323409320366, 0.11555555336658033, 0.07101630461552451, 0.028881953330710534, 0.14223366134589718, 0.24282431530375637, 0.0599699487699376, 0.1289560705904038, 0.31897035998202145, 0.15191070014430633, 0.10308522010041822, 0.10920783309566398, 0.1309652587458972, 0.07378416496419138, 0.1915797747431263, 0.2981249849882818, 0.01094617452772875, 0.04274330499972548, 0.09290405714343633, 0.08595744763771374, 0.001463259775905059, 0.0202572722769072, 0.0033039308524870827, 0.006538624114792555, 0.08108751097273442, 0.08123525868981116, 0.0818644620237812, 0.04192202427094022, 0.06806092892563151, 0.13398355323701136, 0.11339696274409372, 0.17371538575858841, 0.12241963222022019, 0.21209139587177386, 0.19554288547125556, 0.12513828674151053, 0.23961845184526137, 0.2589077184036855, 0.14857241072722022, 0.14673638908613115, 0.13179871644223892, 0.11382726667028283, 0.1474225127528752, 0.09543229285026751, 0.35933752454096274, 0.2448914350280839, 0.1974963024258614, 0.22533175475414724, 0.44485349869055135, 0.26202756551004225, 0.28137128559812424, 0.25945240691784893, 0.36812945599517516, 0.5953475184017613, 0.635910096668428, 0.4013517474935901, 0.42422247509802546, 0.2840136760665525, 0.17424751043079362, 0.3667585569764338, 0.6411711595231487, 9.977060402593306, 44.71223900395055, 84.03220745824999, 90.51765826440628, 82.26581511958953, 64.3647530771071, 72.73545188288536, 53.8767235509811, 43.28261352354481, 26.73320612599773, 26.493904282969815, 41.538394343468454, 59.353889880641816, 44.0117193806556, 44.839327719903764, 54.42031698842203, 55.3863928394933, 34.076159615670484, 7.878628642328325, 0.29418992839993974, 0.15163898407932253, 0.20027850394047078, 0.294913666983766, 0.7053008086739049, 0.6521841330874352, 2.0278358387370266, 2.4450565153552644, 1.9849252316259571, 4.640334536952357, 5.07200510271134, 7.092726374826125, 9.09079792038087, 10.97443872882474, 9.230062653941493, 8.202560524786673, 12.471482888344797, 15.26842405719142, 9.245422655536283, 18.498074239300145, 15.767291688149976, 21.378602097111365, 17.83734510021825, 17.753090627731815, 21.2289793645182, 23.660697860102502, 10.039845781941569, 6.22861155579167, 6.186030795497279, 0.9195298196807985, 2.2607266902923584, 2.658140991003283, 4.400910119856558, 24.793272441433324, 77.3401967940792, 86.27618758909165, 74.01063796012633, 82.34834963275541, 71.50191353213403, 61.89718607933291, 36.90052109379923, 15.404190036558337, 19.676550357572495, 10.24815599764547, 14.116743610751245, 10.407926882466963, 9.914345625908146, 6.11025893880475, 8.530063725286915, 8.845719406681678, 14.672922953482598, 17.65546283414287, 15.13774048897528, 14.671211819494925, 10.287329689148935, 8.061464534651849, 8.32447269270497, 10.346625139636378, 5.384654777665292, 2.495633762690329, 1.5024138842859578, 0.8667586803916962, 0.2610324172964019, 0.3823332164076067, 0.1839258669004325, 0.1543089690347833, 0.2813207850821557, 0.30333309584567625, 0.22150123852395245, 0.20737453123494504, 5.281993602552722, 24.569858158788374, 70.0320759127217, 70.12913888500583, 55.85335493087769, 36.64148776761947, 43.930287053508145, 60.80134645585091, 51.4842934762278, 47.33981909290437, 65.61589502519178, 42.55986975085351, 53.39380525773572, 87.41621663493495, 96.06316797194943, 101.60324911917411, 105.18165096159905, 49.767966270446784, 2.5553388557126446, 0.39619217596707806, 0.36178808659315115, 0.26013303007329663, 0.28477409494019323, 0.3001422170669802, 0.17028398601518524, 0.15442507732058727, 0.21477513976635473, 0.2517413642377623, 0.20035218627702808, 0.3193581536892922, 0.39614348341861083, 0.46650795446288207, 0.39393396327091806, 0.4522995668793879, 0.5352034263553158, 0.4923112053544291, 0.21770809206270406, 0.2526775696465085, 0.3194454570691432, 0.22746538623206078, 0.4387412508649211, 0.48581042837712074, 0.09457570695949179, 0.18888610234904676, 0.15390505683758568, 0.2691845121162553, 0.23794707782085867, 0.1431892334573692, 0.13499215395460207, 0.14242676146809133, 0.23128465629152714, 0.2107951597821328, 0.19257358996377838, 0.1746099772712877, 0.19858203287566864], [0.029669169959942662, 0.03741100362892594, 0.062483490910381086, 0.015131872102257707, 0.08641490938081857, 0.07912993416069977, 0.09859884833736766, 0.08843657710859854, 0.026471641538063848, 0.10589088688814834, 0.04008040252712466, 0.09091327041988412, 0.04398515650762185, 0.04271573349533062, 0.01946882990699622, 0.04206266269207962, 0.053740726979148966, 0.11292810161267558, 0.21998933336186796, 0.0850857008669165, 0.11148289206527895, 0.11520360491328663, 0.09270842127021282, 0.15219514859059166, 0.31072596688905074, 0.530698400351309, 0.09348928703055268, 0.26491571698457966, 0.07787359593015525, 0.060939999943178516, 0.22398783735209898, 5.000955289410007, 28.39971334703507, 56.545527750445956, 70.7385967623803, 65.38871134481123, 65.99770638250536, 52.319974053290586, 31.140973529508038, 23.629634649522846, 19.41547739890314, 30.83254187337814, 26.481184036500995, 41.57477432681669, 49.441962395944905, 35.94481991183373, 48.83097871657341, 32.60502761410129, 12.965309293039384, 3.371171259110974, 0.03187418551064067, 0.0947781456934829, 0.07563079692303173, 0.41485383265441467, 0.11143075212115243, 0.33469446784546303, 0.4208377760744864, 0.5891353420672879, 2.0915521681308746, 1.8721937388181689, 1.9108963781787505, 1.6798701233440831, 3.197640209428726, 2.869218929160026, 5.407157415343869, 5.63417733676972, 4.507430907218687, 3.309186778722271, 3.9817558373174364, 6.897243290178238, 4.54339413873611, 5.724157979411464, 3.441647670922741, 4.247560155007148, 4.075424733661836, 7.583116292953492, 5.929326866903613, 7.890556570022338, 3.7656423113038464, 6.800215128929385, 3.688862405477032, 4.914733748282156, 6.04673860534545, 12.214959879075328, 47.34218820448845, 71.42993803947203, 56.960981276727495, 53.954300188249164, 56.82650281536964, 65.01230893596527, 62.81164746130667, 66.25440197606241, 43.23246209852157, 16.95080707150121, 4.119761980349018, 6.736978677011306, 2.8558671810934624, 4.427244913193488, 1.2268030282951172, 3.383638022407409, 2.8890425880109114, 6.40467792749405, 3.979312445848219, 0.9863188358083849, 6.378607894143751, 2.8032127936040205, 1.3557936034856306, 4.218758681128103, 5.096807229903437, 1.77092328907982, 0.6034206142348628, 1.6443859112839547, 0.7989823914343311, 0.4236401563450214, 0.14193900860846043, 0.3763174650169188, 0.10364477838119192, 0.2635134083609427, 0.009960006779780792, 0.06784384259052816, 0.020821691385560462, 0.08740643399857706, 0.4668126735956439, 7.836332744167698, 31.628016194989605, 54.831777541868156, 41.64600849151611, 48.926582567153446, 62.63192446001115, 95.70696184712072, 92.49308939903014, 68.11330733760711, 43.03481778790874, 40.8770082073827, 58.931097599767874, 55.00725261626705, 62.92714165103052, 75.71948912835892, 81.8186806094262, 38.86605608847834, 1.3586926027651758, 0.23276558085795374, 0.25165562367727684, 0.12271700456978814, 0.06000980832463792, 0.09108288228631982, 0.07765002083033323, 0.05896324795039912, 0.19651220120008916, 0.05745352996933845, 0.2581406805303789, 0.23175745511487608, 0.29281075563161607, 0.06839049995065698, 0.1451741825909384, 0.4771552282956339, 0.2249570305068647, 0.06497247610241175, 0.0483674360739608, 0.08655938590245862, 0.046032047680308746, 0.253571916011072, 0.21773780095240763, 0.03165896459963293, 0.09068063249991787, 0.06267145441304292, 0.015953221778956153, 0.02717712041621487, 0.07305903976122219, 0.018996258994804758, 0.0710683296464624, 0.040329859907468485, 0.06112557708195621, 0.059023416495972106, 0.030637079917435205, 0.02643221099260113, 0.03464213970507826, 0.05185708914312625, 0.07733679812161193, 0.05080638423321709, 0.04841284593567253, 0.06969316351798273, 0.05109314626503376, 0.0890145291604342, 0.11032099715403973, 0.046023685830615224, 0.04359351703897119, 0.07456194339019638, 0.015453809061117712, 0.0338962075540856, 0.07708712240620967, 0.07707654273197537, 0.075377918960106, 0.07473599090571366, 0.12278367720183828, 0.11887886576474675, 0.1337505705774792, 0.13323356848089926, 0.10307379006858795, 0.14089674598747684, 0.21318627341139704, 0.4606821315903818, 0.12340381771566407, 0.16067304528288304, 0.10655755958249492, 0.05044643399155429, 0.17058761730309457, 5.111713707447052, 36.48913898775655, 69.38950538635254, 80.16923765982352, 73.53609392719885, 74.0843314509238, 58.47700088254867, 43.22459774632608, 31.698885579263013, 26.355226924342496, 33.99950865776309, 22.16755743949644, 41.18571442942466, 50.206342128015336, 34.879115858385646, 43.49878711085166, 36.387898691238895, 15.804958208914726, 2.8014109548061126, 0.061042782129539605, 0.10209977822077852, 0.05427144204957351, 0.5746383844844757, 0.8916325134135062, 0.8518314265435742, 0.8743352286757962, 1.7210606485605242, 2.0764998274464763, 2.9610678457444717, 4.748745416441272, 4.126155934026165, 4.993146830989469, 4.2052529800322755, 5.535683189668964, 5.189410467301646, 4.022950530052185, 3.7915476051069077, 6.819750003276333, 5.741648318306093, 2.084229838463568, 6.10785452588912, 4.010031958741527, 3.8640710038523522, 3.031671734586839, 4.4613832619882405, 4.007574103532299, 4.573088442125629, 4.1317953217414125, 3.467936376410146, 3.674083895260288, 6.20429237042704, 7.479468151446312, 13.614528236850617, 53.126503575232725, 83.56648091346987, 69.93556991700204, 63.92154485948625, 66.18746280670166, 76.66039513003442, 77.49248673838954, 75.82945669850996, 49.17281719946092, 19.51503892098704, 3.0901398101160606, 2.950646108196628, 2.569018366836733, 0.4822202645722897, 1.0978052212345986, 2.6950051419196592, 1.760746699667746, 2.5785906660941342, 1.1705039008971185, 1.2968525146284413, 2.793576265535047, 1.0651346969027673, 1.461286729862613, 1.567813523354069, 2.976521984223397, 1.8026351616267235, 1.5718484165207034, 2.9880147739764187, 1.5534756669113714, 2.7682813905900527, 1.654101009330442, 0.9028526371525181, 0.5218074290502457, 1.0069746500061405, 0.17830892556136657, 0.051782142761493885, 0.04852512378185507, 0.03992761395150616, 0.4595815390348435, 7.722375142958857, 26.458973615400254, 50.544846596256384, 39.14887466738301, 46.85399040099114, 63.97561080994145, 83.36058001364432, 89.6727091266263, 73.8383125489758, 50.42571244701263, 48.623861881994436, 65.27509204802975, 62.38718425073932, 69.28068314829181, 79.56266664689588, 91.53373256806405, 55.91884282327468, 3.4679491241132063, 0.12485347057302153, 0.1934044736046945, 0.12386905525120036, 0.09181336244387973, 0.03815050064135463, 0.031095819112153786, 0.049563180580134356, 0.16585478739392373, 0.24366911110137743, 0.10269021750577997, 0.30535216653539293, 0.20789560891928213, 0.08426686778904931, 0.16950177960097793, 0.19125512200257472, 0.1119173558488969, 0.11389518036477028, 0.05565707676953847, 0.02028633382231478, 0.09668348296996086, 0.18775961602166777, 0.19868309519463973, 0.03874464013103036, 0.035147849665654284, 0.04022839922277678, 0.060167369628024686, 0.008000858529891458, 0.009538850901017507, 0.025475294396822012, 0.10528363197320893, 0.028572269948199395, 0.02286095423774133, 0.06434423037834706, 0.043047824949626966, 0.05566231681094055, 0.21300278003177336, 0.15001463253171216, 0.18206055005711896, 0.13965923819811116, 0.15214860108831238, 0.18353369117023485, 0.25715778972352704, 0.1792709634549195, 0.21954400645148373, 0.17890115749211083, 0.20980422505207602, 0.2723756666866041, 0.11073662283559961, 0.1869085842683431, 0.17177551323848386, 0.20506663007601617, 0.2224126686492274, 0.4022439947772411, 0.4445484118355859, 0.3053650368125208, 0.27880035581127294, 0.2424284163862467, 0.24319157785465642, 0.3691434499717528, 0.6442573294043541, 0.7927571609616281, 0.3467405569409171, 0.4053173250248356, 0.23012643860232448, 0.2049969467184236, 0.47687189833771804, 8.285250952166896, 48.027944026454804, 83.13997022567257, 88.43502875297301, 81.82679207094255, 83.87957234536448, 68.65335495241227, 45.717644460739635, 35.372510802361276, 32.53254417450198, 46.37642614303097, 39.03975040681901, 58.04535188982564, 63.50080005584225, 46.80629830206595, 62.11640734826366, 45.86902833754017, 20.691950013560636, 5.0023727359310275, 0.20200731923743603, 0.31464472112636416, 0.19472510193384465, 0.6846259342085931, 1.027667788007567, 1.2846535756703348, 0.893706834364322, 2.3654059248585857, 4.570412405075566, 4.80636062160615, 7.410277051310386, 7.133183171672206, 10.399704613993245, 14.529062182672563, 15.399419453836257, 16.279854274565174, 16.38960611435675, 13.056708362794692, 9.116985624836339, 14.347128925784943, 12.598834403099554, 16.613593063046856, 14.555301858532815, 15.100412272637891, 13.990435446462325, 21.304973325421734, 12.211844536565966, 19.28226390192586, 11.666235000856462, 17.36027898326997, 8.465454443808525, 8.894661761099293, 12.29501937666247, 15.115025062714855, 62.97434345368416, 83.56255069855722, 71.53215500616258, 66.19341696462324, 69.94713306427002, 79.37720914040843, 75.85247316668111, 74.73721781084615, 54.626370860684304, 25.38268308485708, 8.930929956897613, 12.41025076758477, 9.539356250916759, 9.357862299488438, 5.004042685031891, 8.722958045621073, 9.338362236176769, 17.414360623205862, 13.213071688528984, 7.275122471394078, 14.329209577652717, 7.955034452099954, 5.738488849132292, 10.495410446197758, 13.68870614036437, 5.671547228290189, 4.473308738200895, 7.546884379079265, 4.316996893575115, 3.6906598316084955, 1.5233985647078485, 1.1465106399789935, 0.4212132817314517, 0.8747776597738267, 0.3574428358866323, 0.1925757962970003, 0.1831178739666939, 0.19476346761709262, 0.919091739962178, 11.379755869988474, 43.957327873476096, 74.87951355595743, 57.34695034642374, 64.1995624573, 70.06421581391366, 99.37327184984761, 101.12634381940289, 78.26720191586402, 51.79463924900178, 55.45330062989266, 76.71352755638861, 75.90686075149044, 82.67960948328819, 89.76204502967097, 104.23097825819447, 64.24018644517469, 4.336945087678971, 0.4732012033702866, 0.48373763960215355, 0.39461143014411776, 0.18758076513486524, 0.10930806803967684, 0.1922291415112634, 0.278382929823091, 0.3352926599402582, 0.39567007172492247, 0.4492824368419186, 0.6181176126964631, 0.5268306369262358, 0.3644351961631929, 0.45081602229226025, 0.926223221805788, 0.4302033541664001, 0.22248969112913455, 0.24685689488485937, 0.287502134038556, 0.18729637797561385, 0.3610543275792753, 0.40337615015525974, 0.28494076502899973, 0.2375595752269991, 0.16951066622089955, 0.1461724411215513, 0.04880207222736171, 0.16736076303547429, 0.17692238302721133, 0.24649159351904548, 0.18554473325850504, 0.10598133888936813, 0.22154395558661033, 0.15032857536308228, 0.17736567214371698], [0.007575831513085793, 0.022605010007898656, 0.08381028704705738, 0.014558184287330557, 0.038832257606930314, 0.046860947153500976, 0.0682432655124895, 0.044899030453375274, 0.011983673997043122, 0.0482121423908299, 0.05250582771916544, 0.0614615602629079, 0.10033954565803851, 0.019129795780886086, 0.08493976111734107, 0.04017847710319104, 0.027044253957067287, 0.10390653530316007, 0.02099112322133395, 0.09622435115518109, 0.18694152604908715, 0.08508759310408946, 0.20646343818835675, 0.04348671672144725, 0.2791534304138153, 0.29026400357965504, 0.09195240740213664, 0.09565966008531471, 0.05271515741403546, 0.2528486983670343, 0.6979578252761596, 24.65269273327243, 59.51536209352555, 63.18990907361431, 67.93529448970672, 65.3558301156567, 44.71485914722566, 32.88547708142188, 29.294700161103282, 22.487487523786484, 24.513223055870306, 22.050880655165642, 47.276539494914395, 43.438033519252656, 35.43321340314804, 43.130017634361025, 20.74010495216616, 3.983549341078728, 0.3399425378489879, 0.03799182084959842, 0.2747285678502052, 0.007482856209765399, 0.06827908778382887, 0.1612687092875281, 0.37948303225059665, 0.4884204286481104, 1.1416106190412276, 1.3232561945915222, 0.08062319274270728, 3.9289342587993996, 10.164081954186964, 3.2767529449155255, 3.4199010700948778, 2.387194936313937, 2.3981851723886307, 2.761645965999173, 5.359796756698239, 3.5779495441144515, 12.130090575064383, 11.863114449285693, 6.976059886717028, 15.155297017866566, 12.71147506852304, 8.834342571996874, 12.052004029673915, 12.459744215011598, 13.42774594983747, 12.868994512865621, 11.151975989341738, 16.862953824381677, 20.397440810357374, 22.38847513352671, 23.950372742068385, 34.86488157703031, 34.79465546146516, 49.64995391907231, 42.18591882336525, 54.30916094010877, 49.253163030070645, 56.46442882476315, 48.00672792619275, 52.22004382841049, 54.029213536170225, 30.728963844237793, 15.687777400016786, 10.868464131509105, 10.604937730296966, 9.00421650178971, 6.249931598863294, 7.258988291986528, 5.128127846025652, 8.84264721024421, 5.799623400934282, 1.807036306108198, 1.7026234249914847, 0.35605704411864286, 1.642608587299624, 2.4336360443022946, 2.434452142446272, 0.9097274488979771, 0.976109090110948, 2.94930907026414, 2.1660933811818404, 2.38751755126061, 1.241726053337897, 0.9662643087006385, 0.7219390739356318, 0.20326865236124686, 0.04784420568255648, 0.02101469000110463, 0.061571999498072176, 0.019279069928151947, 0.025237132982921698, 0.20945643645621118, 3.5030116813798107, 20.334347524950584, 46.90256895557527, 60.73087323096491, 66.48870868067588, 53.54654627461588, 52.89382465424077, 104.24186675779282, 100.68611268074282, 34.6911362678774, 38.16267705732776, 48.53287466110722, 59.091444092412154, 61.47220119353264, 69.84201354365196, 79.08881295111873, 46.95314399657711, 1.741848229881256, 0.17881365492939952, 0.06505435557975885, 0.0864406499350744, 0.012280337715281114, 0.05272855629183112, 0.09764296979072595, 0.06545604612197607, 0.025401548858010964, 0.06863452959805727, 0.2288387520539184, 0.049875836383791707, 0.06281315769639707, 0.10922373708097205, 0.10896193419372845, 0.028491484061364206, 0.03495729295536876, 0.02771897057461883, 0.020291508746243293, 0.06710698092055899, 0.08883316550524005, 0.030175284031898748, 0.07600985722796572, 0.07247350343893613, 0.035773866073859316, 0.03611993097189454, 0.03723044053561265, 0.05934125105399759, 0.028536621961862813, 0.09229027515938205, 0.09525717281165624, 0.1054080676347498, 0.020934557204224893, 0.023023424249502922, 0.010203772126847218, 0.11630214435318786, 0.05106377062357722, 0.03685766598209739, 0.11479560180657333, 0.013466170958934293, 0.0029444436152135174, 0.023006032138401945, 0.12573657842773583, 0.03536541863614994, 0.08388994486942407, 0.04753228915374606, 0.038319771598664024, 0.0718030309484851, 0.026175630909781304, 0.04023996331999379, 0.05258565791131509, 0.07649400947435249, 0.06282943706478804, 0.009137415083035106, 0.056910162956844416, 0.04450150742946614, 0.050730924572675466, 0.0380566050749152, 0.06687338539068738, 0.09513112070459513, 0.15714012356775423, 0.06176308863946508, 0.22390903754820748, 0.06434645203332748, 0.26828233633310566, 1.0485366972223407, 30.81682493609767, 71.53909760136759, 72.54177308851673, 77.45109004359092, 74.95499564755347, 57.908618065618704, 47.93831002327704, 39.28586736802132, 28.23749980618877, 24.681216209165513, 20.841025575514763, 45.64690843705208, 39.90983017029301, 27.5820521385439, 34.27260368101059, 19.736484173805483, 4.592344828190343, 0.31949249486769404, 0.05117794836781198, 0.13078855290528268, 0.03673563966707837, 0.25862402072356594, 0.5385363991222074, 1.0584966982564619, 2.0192725692064535, 2.3721180808159614, 3.2708171731041324, 5.578190895818896, 3.9712475624776657, 7.051456176465558, 5.289106820860217, 3.9309988963988522, 3.4397139424277894, 3.7827524254398965, 2.308706102832671, 3.098496174620044, 3.058130818028604, 6.777826239985805, 7.4580147477888294, 6.059504939663795, 10.00918951726729, 9.181406632546457, 9.571541259365699, 11.47833287715912, 12.47699970199216, 13.216464538728038, 12.556499281237203, 12.670785380947976, 17.355956531340077, 21.352016272083407, 24.547743835756858, 27.68932700157166, 36.96780543173514, 45.21114095564812, 58.80374216264295, 50.66877388185071, 60.588471581858975, 56.05827523816017, 63.32402275454614, 55.295597814744525, 60.74244422297324, 61.712764078570956, 35.61990645623977, 20.150672735706454, 12.400184004537522, 11.437949134457497, 11.054955182536956, 7.614137338053796, 6.911562392788549, 6.654244613262915, 10.451075896140068, 8.48330613105528, 2.589928031929078, 1.5955256814918213, 0.8221963264288441, 0.3303915971229154, 1.0607192112553505, 0.5425299235409307, 0.39208928483628464, 1.0365999441954399, 2.2669671812365135, 2.3507813676711056, 3.008037493113549, 3.16304367876822, 3.312684552323434, 2.2521943094268924, 1.599513138494184, 0.7432057972877257, 0.2242259987659993, 0.23812468764522385, 0.06551118146988653, 0.017789817985988433, 0.18992919234498856, 2.975655140415315, 18.585570550733998, 39.57709158620527, 61.89151433206374, 73.09092844686201, 66.59880176667245, 69.5658943730016, 104.24645593089443, 95.42795581202354, 47.63153752973003, 51.547306353046054, 61.632845786310014, 68.05884915013468, 69.41156479620165, 75.39830976916899, 90.17899297898816, 65.88576193778746, 4.309375728330305, 0.27332579957381375, 0.032389764598901236, 0.05179898520450919, 0.05863157784446113, 0.08034524838289908, 0.01865309373956294, 0.11357496327330029, 0.06038232240825892, 0.05950238998799075, 0.05564366640042394, 0.03427414170977089, 0.06720417449551244, 0.08759774913590762, 0.10698319037234592, 0.10820924514724363, 0.11480752979555439, 0.026864083483815197, 0.09786672109077055, 0.06555130915536035, 0.11167709535408406, 0.020032885123885447, 0.03884967078544921, 0.12731318737590505, 0.03348187656111775, 0.03223144869890905, 0.024248628666804686, 0.015598524985234103, 0.11285247341279062, 0.06135483272373677, 0.07296898612572301, 0.07332004591702454, 0.049227588104024056, 0.010618132805722135, 0.06921714712535182, 0.20722661497852496, 0.14987102168942654, 0.15930943942118078, 0.27034299027535225, 0.1109313240815555, 0.06784320673755101, 0.14001603598796553, 0.2083128050810868, 0.1348401774321833, 0.16309091070246312, 0.1638024991318103, 0.1887984312469921, 0.1804795284425059, 0.08171037875957067, 0.15769155365565132, 0.23076092794297204, 0.1741669333029178, 0.2579152974630556, 0.16350686580183046, 0.2797666071884094, 0.24880744667062837, 0.3405639270861303, 0.24062314551443825, 0.21880123824361833, 0.3822365361115625, 0.4557050115639164, 0.26758743329874934, 0.32224348596026825, 0.18682478957118528, 0.5011472328295631, 2.4626892853167752, 42.11694786625524, 87.13418253006475, 82.50001199783819, 86.01201595798616, 81.62206003742834, 63.09404634660291, 47.58832085517145, 40.313245942515714, 33.36327275922222, 39.44494693509994, 34.51339798588907, 66.56586954670568, 57.23721419611285, 45.39843020900604, 52.425536801738126, 27.267044628820113, 6.407348080988854, 1.058163174217747, 0.26173207007588883, 0.4320225065513965, 0.07176386853379589, 0.2771300696317227, 0.38819853877348287, 2.3592235340226084, 3.1131001393641196, 5.05678826762784, 6.370517515367077, 8.702201843261719, 9.599057666717037, 19.971467487273678, 11.248521208763124, 10.599984757361874, 7.781949572024807, 10.44793015526187, 9.43559975393357, 14.895504713058473, 9.524946443496212, 18.015836477279663, 19.623602282616403, 15.152648437407711, 24.70408754964029, 20.99283895184917, 16.6437090212299, 20.00338185218073, 19.133423682182066, 18.98295371763168, 16.62327543381722, 14.79111965625517, 22.87126987211166, 25.43475647126475, 29.067594928126184, 34.018857709823116, 43.316000738451564, 55.32925567319317, 63.99975299835206, 56.646399344167406, 66.10425364586615, 63.49366918686898, 70.66448750034456, 62.481744750853515, 66.34348684741606, 66.81003708993235, 39.161614525702696, 24.23695875752357, 16.331085331978336, 15.509029107709086, 13.982953525358631, 10.45281546731149, 13.118791637882111, 12.00922469938955, 15.274392924001141, 9.632368395405432, 3.4808265105370557, 5.912219449397057, 4.288444490202012, 4.94522282192784, 8.627273786452509, 9.294830791411862, 4.487247370904492, 5.4447347021872, 10.047541472219653, 6.463536033707281, 8.411832701775337, 6.701284127850687, 4.25202920552223, 2.6583807458800655, 1.0912916352671962, 0.5602673104693813, 0.24188653175388616, 0.23260945213898537, 0.27056760725475126, 0.14685839624895206, 0.4546408235065399, 5.687016565953532, 29.680975175672966, 63.690548635298214, 75.75634371849799, 75.62900789322393, 61.98192104216545, 60.54894585763255, 107.91187947796239, 104.74631494091403, 46.23977468859765, 52.761542720179406, 66.03044248396351, 75.99996997464088, 83.46335395689934, 87.32979113055815, 98.97046012263145, 74.6234533863683, 4.732348438232176, 0.6259371640701449, 0.1329629862260434, 0.18132941106394415, 0.1143654510979691, 0.12297064862063817, 0.31948716289574103, 0.28203076472686184, 0.13914698584666177, 0.4409626913407157, 0.5499783819240909, 0.26817321476917116, 0.2277410246672169, 0.25546162509389464, 0.338021740918198, 0.3695415705442429, 0.3343157752627327, 0.19899259471604902, 0.2110848942350957, 0.19677614913352076, 0.3144621164087327, 0.26062237639581004, 0.14477817642111934, 0.30705907171772373, 0.13458484032702062, 0.09446257875571329, 0.1473667415519876, 0.12652431599675648, 0.16116778486438338, 0.2219993642140781, 0.333666010128875, 0.16111863266316154, 0.20588236049779002, 0.16906797465297485, 0.1344050241694335], [0.0493706665152023, 0.04645361820416105, 0.0530391053536967, 0.032754410959539876, 0.04067161556092962, 0.01702624474531941, 0.09883497961826863, 0.01525222643038198, 0.031454493817422664, 0.020816832472900712, 0.101308447699393, 0.012562022499379613, 0.04772944954193888, 0.01213292611928116, 0.05251779018210308, 0.10224026342433307, 0.10555932403451974, 0.051215846737426136, 0.06577459314177114, 0.08225349679348931, 0.06660251968329953, 0.10877814203981431, 0.06649860751725013, 0.16213872469961643, 0.16329577793517422, 0.11376307616310735, 0.0651289419000668, 0.01722992645696767, 0.08994437603940887, 0.4492044797347438, 20.12902713591053, 62.48723214672458, 66.68774543269988, 70.8393624521071, 63.79862954539638, 45.07421493530274, 49.38799058237384, 20.729296861156342, 19.55767312357503, 20.973760543331025, 25.04870503179489, 35.4344803287137, 31.600141871360044, 47.113714064321215, 56.84642845584501, 14.691419870622697, 1.1215169295187921, 0.04460409426340654, 0.13856287444791487, 0.08184236804804496, 0.06871273185336782, 0.05136634854059066, 0.45583944467286913, 1.3923522998248379, 0.6312337734045521, 1.138422344961474, 1.357924798803945, 1.754665187289638, 1.6344105884913476, 3.1380552389929375, 2.5272017332815357, 2.521361814391229, 0.9737131960930364, 2.5653867423534393, 3.053162645909094, 4.127002185390842, 5.964188892995158, 11.612269070840652, 24.155553886967322, 24.699612125273674, 20.506196368125178, 22.708883746977776, 20.591613823367705, 23.450192097694647, 30.162840312527074, 32.734224604022124, 39.20362703261837, 47.93611741835072, 53.32055107239754, 49.85647063101492, 55.530022190463164, 47.564414008971184, 44.00384718371976, 49.4740120826229, 32.67361417893441, 38.57748339253087, 41.64610262840025, 50.69705417079311, 46.90511065144693, 51.86268844912129, 46.11181912883636, 40.15939489487679, 39.69413118977701, 47.99077956907211, 32.16447876345727, 37.2381861748234, 37.97002592394429, 31.255059588340025, 32.23248481750488, 31.17702795613197, 34.04172512792772, 38.496749247274096, 48.65262462246803, 44.1284530393539, 32.15665755733367, 26.658845832270963, 16.870763263394757, 6.542182497439846, 1.4145542633148933, 0.3306199526113849, 1.1635535835258424, 1.2433098328690375, 1.4505818462179554, 2.9426594270813853, 3.182976673687658, 1.3455424890402825, 1.8990537620359853, 1.6883540874527347, 0.5980701335976201, 0.08334570834713598, 0.11330085701399273, 0.05053651827057043, 0.10132917803862404, 0.058702329894708055, 0.07753405044035566, 0.3731852379297057, 8.535191243694674, 26.091692678390014, 34.07793252698837, 32.830173623177316, 33.275337142329064, 49.90379010477374, 35.05997242466096, 15.464250349229383, 11.374463612033475, 22.50452433862994, 45.85224059320266, 47.92282058346657, 68.18829521056145, 72.14895556049963, 82.72125720977783, 39.19785330372472, 0.6249420465000215, 0.10365616244774672, 0.12361370282427919, 0.029842750161826134, 0.058390593396559845, 0.046191589320979776, 0.10500130559047384, 0.03999421380520348, 0.018469998725659905, 0.025299662994521282, 0.04435920659753104, 0.09238366127735184, 0.09631681030676251, 0.08876131411882178, 0.03783807083363495, 0.1482824924131555, 0.05081450093477484, 0.07763163472015051, 0.04565091127709997, 0.04145635772616633, 0.007765554623948711, 0.05403594279121007, 0.06617524946529059, 0.020256705371843233, 0.05104572159208117, 0.006220772798593727, 0.07651527607513052, 0.06451304551334151, 0.032733561876680584, 0.07847476044609662, 0.02241928731241534, 0.0786051026455337, 0.0796239382977928, 0.054161788054531625, 0.009107524247449494, 0.07353053623509985, 0.06473934788617396, 0.02494561737553487, 0.012903868168171857, 0.045981512690383586, 0.058939039571991855, 0.04840700068481026, 0.06494127334125581, 0.003398599449522613, 0.01565088613724877, 0.031281679703463475, 0.0927168635591384, 0.07333574305859304, 0.09566774231291587, 0.07404762260135143, 0.07237832467522352, 0.04551727106914886, 0.03215844051972513, 0.08744432470731198, 0.09152901358902456, 0.05712572094653884, 0.055642881160301555, 0.19672292134454175, 0.211542371299959, 0.14286084220774714, 0.03619507270594759, 0.048844628411555485, 0.09571874078603522, 0.5278022202753252, 24.450404336375577, 71.9118247493621, 75.780882066296, 78.9814341452814, 71.3683097593246, 54.34595669469526, 57.9227307534987, 28.32812813020522, 31.196759439283806, 28.16288063603063, 31.008944588322795, 28.52415446312197, 35.77778970041583, 45.3250152064908, 45.39899110794068, 11.951223631058971, 0.47983613766489497, 0.08033765645156946, 0.13560897730771573, 0.13527617339164982, 0.14067107180674232, 0.417077663324533, 1.7668266185829717, 1.9833555481126233, 3.0255498953403968, 3.500377564660965, 3.8864439581671073, 4.67285490805103, 4.032854269589148, 3.5233788336476977, 3.033208813398115, 2.9408811225045115, 1.840474756975328, 1.6590216227116126, 1.9478794259409753, 3.513939649828019, 6.675005718584984, 14.054739763659818, 21.700869914024107, 24.494258396087158, 22.41608665835473, 24.63277885990758, 24.11726959290043, 25.83488137491288, 31.96525569885008, 35.07213177219514, 41.74713503929877, 51.82995627003332, 56.35422591240176, 54.167398637340916, 59.45978603055401, 52.79699702416697, 47.71407204289591, 53.79755835379324, 39.811115880166334, 44.51784633821057, 47.86797800371724, 56.42023940240183, 54.600608733392534, 59.5471921274739, 54.37249937365132, 46.89075085424608, 47.08445710520591, 53.04767570187969, 36.316691983130674, 40.86307202616046, 40.58532899425876, 34.045886762680546, 35.796409191623816, 36.22478300525297, 36.214447559848914, 41.482908495010875, 52.39783310121106, 49.03063520308464, 34.984949250375074, 30.357723274538596, 18.652647003050774, 8.317707584750268, 2.0782425855436633, 1.3563850233631751, 0.9704415103600872, 0.5839080483682695, 1.174622879874322, 2.1502781394989263, 2.996393446960757, 2.7326608761664364, 4.14236169668936, 3.210049117765119, 1.6161058674896918, 1.365046474722124, 0.38768188907734813, 0.22234843983765573, 0.2739825514295409, 0.02945278651050983, 0.048253763947756066, 0.26750086536330564, 6.380726954629345, 27.923327761311686, 42.58200368573589, 38.633722336061545, 30.810154945619647, 64.65186665135046, 44.15609398195821, 18.18707735307755, 25.343088719152636, 35.305375514491914, 57.0580481713818, 55.57376054025466, 78.90967046060871, 77.71828974446943, 91.3172177345522, 53.8518714135693, 1.165210662349578, 0.10826920684907707, 0.10134489816283027, 0.011810870416792891, 0.052843687815531615, 0.03465659578420943, 0.028949122004691633, 0.06678851817043559, 0.02988234350097276, 0.01507106483087785, 0.006307431228173476, 0.02667991786203798, 0.16960736183870226, 0.03686229698359966, 0.015471914591598175, 0.0867111862246548, 0.14101706775686434, 0.04699290196801867, 0.0698768560804667, 0.026245094017095627, 0.040561229951920054, 0.00984360259251609, 0.07286550296891121, 0.03104759196210052, 0.034029832440278227, 0.03922161413356662, 0.06574177393509496, 0.008254946911737563, 0.11206852031811593, 0.027078482765524138, 0.072803970786833, 0.038479248121861494, 0.02726828679442406, 0.05709762084147623, 0.17131538550940253, 0.14502260443424025, 0.19137225684619721, 0.10729528693181854, 0.11846375336209614, 0.10149729603360738, 0.12485408344336095, 0.15590054734099298, 0.11548586234810854, 0.14283087284814927, 0.2461818641712589, 0.13791540757783, 0.2544812317336759, 0.16617277516953408, 0.28865540279976787, 0.17862421670748344, 0.23390227147648412, 0.10815404851229922, 0.1467517721316507, 0.25650672224019805, 0.19133622007023907, 0.3234959477859159, 0.3079562219640901, 0.48053373732874477, 0.3120838424130794, 0.30562648729931924, 0.136143722000622, 0.13555821632185291, 0.2849589366345637, 1.864322032178602, 33.39120787958945, 83.85560666361164, 84.1628537639495, 87.34071885385822, 80.52762462246804, 60.256544928396906, 63.6455943507533, 31.771773022990075, 28.58354699227118, 34.1336811742475, 39.00217017819805, 51.600968299373505, 45.30384225230063, 63.5703593684781, 71.29340817851406, 19.869489785163633, 1.7777955267698535, 0.3631025096101146, 0.27647647405824355, 0.2703007328654489, 0.21096512404901369, 0.3453961339208388, 1.7503867394501165, 3.9851771247002388, 5.078722161631431, 4.814404912533299, 5.921764537211388, 7.216295744142226, 8.929668914887214, 8.643963471535715, 7.6745330133745755, 8.228038280240952, 7.5131137524881675, 9.450509663551085, 8.377640420390714, 8.732792408235612, 10.026196914334452, 15.615453797001994, 29.935711545328942, 31.038540832458008, 27.265067754253266, 31.438836359208633, 26.57029636444584, 30.550488156657067, 35.843438409989886, 39.96146817361155, 44.64091854710733, 52.32754815009333, 58.79309684999528, 54.57631357254521, 60.62469859277049, 57.53181165264499, 54.33968090241956, 60.459413836079264, 47.46588014787244, 51.260839969881125, 53.61637623079362, 61.18176144938315, 60.33762424222885, 66.62909815388342, 62.08698172723094, 53.54174921589514, 52.031997557609316, 59.1387321872096, 43.57747770124867, 47.413187026977546, 41.551263640003825, 34.63591714059153, 39.93668271649269, 40.714610315138295, 39.914819425152196, 44.435535400144516, 58.3200119387719, 51.29964397799585, 37.70203390429097, 32.426198913205056, 21.31358096676488, 8.403710453741013, 4.209599456479473, 2.878752495011976, 2.753087599431315, 3.459317703400889, 6.238406694704487, 11.938572026068165, 11.666880230749808, 6.6192516780668695, 6.947434919495737, 5.830551289742993, 2.1690658023280482, 1.2441754509364407, 0.49289235965378825, 0.24240929483165666, 0.46898536023593723, 0.2691046244675114, 0.1160262990742922, 0.8392363894850978, 12.230202209564949, 37.36187811820738, 49.790700327965524, 48.60577583312989, 44.626923530332505, 59.123623217305834, 44.603189268419825, 27.675367286128385, 21.86402874608194, 34.00275638026576, 61.54882861721901, 64.89592829058248, 88.60658537956976, 87.96518371951196, 99.11962786028462, 62.54285135576802, 1.9698292545733915, 0.29063515785721045, 0.31527729524720105, 0.09212714439678578, 0.2597064723170573, 0.20557784054788852, 0.23827833423931755, 0.14686423383893507, 0.18775909508187927, 0.179326826586358, 0.3111592662190238, 0.26475444015476013, 0.3729348497525338, 0.3006458126248852, 0.2394826704215619, 0.24845136900342282, 0.31514065580502637, 0.29242216519290404, 0.12682211735556204, 0.12571307485021893, 0.15490374437743618, 0.1690339450273783, 0.12526908093282293, 0.11341403884392594, 0.1092789413767957, 0.12478537301743224, 0.24362702223081745, 0.19443613356880604, 0.17948064171979505, 0.15930340264833745, 0.1596590666280639, 0.23921645486787443, 0.1325866072288444, 0.15772642597796457], [0.12190546464896011, 0.024630391346891562, 0.03275017066287898, 0.09598125613504842, 0.02586505120439876, 0.06703449368116356, 0.06630631944825573, 0.03389814192609441, 0.04243870844103156, 0.015628442633897066, 0.05224348857037483, 0.007604383610023727, 0.027559225920647867, 0.04149656968131181, 0.014291261059923038, 0.03531821995913502, 0.053890596759775956, 0.019510711933816635, 0.02989351306290877, 0.02805178981244324, 0.153625235562363, 0.07856185698220808, 0.16299665124425966, 0.11697366638409516, 0.11715840848703539, 0.07822869300481775, 0.02322472534292648, 0.03620788552648118, 1.0846986213038046, 15.64482842722247, 66.50497867215064, 72.41444510798301, 73.1476459195537, 63.53566208193379, 42.320103106960175, 42.79813804934102, 70.10536147702125, 50.86524540378202, 26.27559300391905, 34.825281327770604, 22.50758182617926, 39.18057918548584, 44.89701401802802, 32.087508132380826, 6.593054657982242, 0.6580787812990527, 0.19743273244990459, 0.06623291290335118, 0.05202211980377475, 0.009953179978765547, 0.06082841923700706, 0.2359577466643626, 1.0279164907913054, 1.2341947348848468, 0.38171372706851653, 1.503283424723533, 1.8016354475290546, 2.4914436907537523, 4.783804051337704, 2.599859718353518, 2.941453053105262, 4.463071352051151, 5.013702011877491, 8.813383386981103, 10.333665628587047, 18.790122155220278, 26.876433434024936, 38.42424031226866, 45.70772086420367, 47.55780481523084, 41.79405050892984, 39.968838307165335, 42.83445919713667, 47.311750611951275, 53.436394353066724, 55.54252670657251, 60.40820729347968, 65.82114481156873, 69.55491173651912, 71.12080035671111, 68.11127554985785, 58.85308557941068, 56.84573027395434, 65.32022283923241, 41.562548298989576, 34.49089142584032, 53.566573896715724, 46.250961288329094, 44.04764436906384, 48.80157662976173, 43.49094237050703, 32.81828688037011, 38.57871109439481, 54.99486184889271, 40.633829101439446, 55.45914103907924, 63.591265601496545, 60.63058999276931, 61.12993909466652, 64.86332162734001, 72.53310465043592, 73.63158795141405, 69.9258424389747, 66.52107607933783, 67.19099337054838, 70.12935853773548, 69.09156214806342, 65.53965983852264, 53.18520576723161, 34.44308165580996, 13.405214874975144, 3.0678239753169403, 0.7482395465335538, 2.0884522699540664, 1.7107769294131188, 2.4344058094486116, 2.7361253096211344, 2.528474787550588, 1.4233195349093408, 0.7193120052256893, 0.2773140839511349, 0.2046960733470417, 0.16573273426582738, 0.09050814780376612, 0.10352970431408576, 0.05706590863185064, 0.03720029497579221, 0.864416535102552, 24.517735742753555, 52.6466525754621, 65.01956924315422, 25.219375202732703, 24.325027735002582, 30.821580809931604, 14.1060600549944, 17.083398872806182, 20.30172517222743, 46.72844317651565, 53.75595769574566, 62.21608261908255, 67.19569237001481, 78.28029478749922, 19.415871597105458, 0.2892683650697431, 0.0769410141172909, 0.10971112987927853, 0.04207138843353718, 0.018007026895159678, 0.04918961695605709, 0.07065083471036727, 0.04145071165816438, 0.03353540312438723, 0.14051218517124653, 0.08268405352869342, 0.03419428087410427, 0.08269572870865946, 0.11269969249805135, 0.1730159781272373, 0.0418939586398342, 0.0066616324587695066, 0.007604412817125841, 0.05918113867782297, 0.09641847783519376, 0.06745886042593949, 0.027584296147969943, 0.06872873543010605, 0.06987543115692754, 0.05341711611817441, 0.022835376477169416, 0.06374421882473173, 0.027634748783443245, 0.014452884544528302, 0.04770960786470002, 0.09298204489412809, 0.035040562882298426, 0.07269310254243112, 0.10268500810789485, 0.029811482283196626, 0.08201820820930504, 0.04132326144064146, 0.023977106039021766, 0.0597186527785755, 0.07700886652474442, 0.015204710784488389, 0.043930534438620654, 0.027681432266329086, 0.04252331136094947, 0.026709322231791677, 0.009677625813281104, 0.08542405125955421, 0.03400148718707985, 0.027107641987142064, 0.03713659476488829, 0.030768180543917324, 0.03115099467968028, 0.03848614674361964, 0.11352595662878406, 0.07303554384458451, 0.10049125404968377, 0.15996179393222257, 0.1586860123901598, 0.078359640413715, 0.05275763698943681, 0.0574105141323901, 1.1542511923659233, 20.96122072589013, 78.65001739994173, 82.84095225795623, 78.81612193199896, 70.63577575068321, 51.72518976273076, 57.039475748615885, 73.03853342610022, 44.683366437112134, 26.507467839025683, 26.30643460058397, 25.293810021492746, 41.95723679757888, 38.667952860555346, 29.09528882272782, 5.475613071072487, 0.09485575806109176, 0.06419239558219429, 0.08216711271914744, 0.17936373670254985, 0.06284544064152627, 0.8236585737716767, 0.7844159956420622, 4.03402068441914, 4.910576035899501, 3.4592576421076253, 3.6483516760410803, 4.940949889921374, 3.6175260140049845, 3.342669601401975, 3.9359599592224246, 2.0656990908807327, 2.923028699813351, 4.688587044515918, 6.661954522132874, 10.878362232638944, 19.261302755725, 29.424922850824174, 40.875113702589466, 48.45480772756761, 48.849209893134336, 44.52817786124445, 41.65619096448345, 42.772422990491314, 48.28778143851988, 55.648987677789506, 58.7912807926055, 61.88387355496807, 67.83816875949984, 71.31272977398288, 74.60154302658574, 71.88652546175065, 63.991272834039506, 62.44566679000855, 67.33404221073275, 44.58851568160519, 41.991369262818374, 58.36425627431562, 52.400402253673924, 51.1042824868233, 56.77881856118479, 49.739654602543006, 40.425009958205685, 43.65307354157971, 59.05163987990349, 45.17601613075503, 61.69013592504687, 65.91124165442683, 61.47847698580835, 63.81027506243799, 67.8243306375319, 74.00343648848995, 74.93071617618685, 73.03956108708536, 70.06737724427255, 69.45413035731163, 74.29778683570125, 71.61055534116684, 68.71156292576944, 56.755029386089696, 38.72859662578952, 16.757651913550593, 4.306376586037298, 0.6910629113835673, 0.9311524766587442, 0.8873389276766008, 1.8564182111332495, 2.740185453045753, 2.4983492685902506, 3.5713325056337544, 1.7911334239667462, 1.492663975204191, 0.823465580901792, 0.5434196886997069, 0.17077472661772083, 0.13732656175571104, 0.03625871929069681, 0.11883092398244528, 1.3042052426645834, 24.59363948914313, 51.020932120661584, 50.82384478661322, 24.196297507132254, 18.036874109698882, 27.011721864823375, 15.919057996042314, 22.95248450771455, 32.91514981177546, 58.09480121058803, 61.04496878962363, 69.95726846879529, 74.71461711391326, 87.46162199204969, 32.16321772144687, 0.6997963137203648, 0.0660235180910076, 0.09330233859439051, 0.03516784073003838, 0.021272886529444687, 0.07101088071302061, 0.04688285343769578, 0.047355966357093666, 0.08997043068971365, 0.01939945106935357, 0.018521445360214963, 0.08722604327504674, 0.16394681477498624, 0.11435955222095213, 0.14640035227902476, 0.11088107637460194, 0.05572146262913462, 0.12154689719600063, 0.032730237055089206, 0.07551686432693275, 0.011166400865711754, 0.05226929424210422, 0.04993099854477952, 0.06223657694194586, 0.006121031023682126, 0.06306196007156564, 0.07118738737077483, 0.05245068471037573, 0.051169912105486284, 0.020143722724770347, 0.06449518800382653, 0.03478368977084756, 0.0584026477900484, 0.2942599794797359, 0.12710011534152493, 0.32057326106775197, 0.23911301767633808, 0.21947148856857132, 0.14891685917973518, 0.16756967521242558, 0.15157222717760072, 0.15290108329105764, 0.17842463548144988, 0.1053357795782147, 0.08816954950171133, 0.14676050553398748, 0.15670360666849922, 0.09971670851471925, 0.13305591269125863, 0.108616367252844, 0.08021317482475313, 0.17495358302708597, 0.14554527558145985, 0.27909646411576583, 0.2505732946578534, 0.372748353308247, 0.2991836878561205, 0.327514078948767, 0.22668736265792003, 0.13402775651024235, 0.1449711539692456, 1.689890185671468, 29.944321147857178, 93.48733963504915, 90.19388229616227, 92.0313322928644, 82.48247115842759, 60.38371993649391, 54.956297105358495, 79.82516734830796, 61.27557669916461, 38.23081647196124, 46.57506673566757, 34.65251661116077, 54.021443320858864, 59.937032576530214, 42.46399525673159, 9.417058710129032, 1.0123121990792214, 0.3284566428872847, 0.19177509652030086, 0.24355566880154997, 0.22257492607159002, 0.5286675319075584, 0.9812090293534341, 4.29357446009113, 6.316643761050317, 4.570414366260652, 7.76323986630286, 8.028867187038545, 7.542929159056756, 12.711103423949211, 9.538536475550744, 10.231552604706058, 10.17541270102224, 9.788820955061144, 12.989826067801445, 15.08486988083009, 22.582151966710246, 31.175988528036306, 43.21448587602185, 51.368846354946015, 51.967050952296105, 46.21223180524765, 44.99888581614341, 46.71613870128509, 50.84887343068277, 58.006991109540394, 60.14838164852512, 62.366383921715524, 66.59156891607469, 70.66396974748181, 72.8998697957685, 76.13610759858163, 70.74684942922285, 64.40162727909704, 69.89035283365558, 51.15879166510798, 48.244678512696304, 63.614917493635616, 59.940256764811856, 55.0584081680544, 62.452315207450624, 56.55174470716908, 46.75166753030593, 48.74274107717699, 62.14065151829874, 49.99435763205252, 66.74268999407369, 66.96662595195156, 63.05648572983281, 65.96475847305791, 68.04108865799444, 76.70297638062509, 81.48509087101107, 75.59934692998087, 71.36676434547671, 71.88441522659795, 74.79097781642791, 73.70754072743078, 73.61578079961961, 63.83893974365727, 41.50819993788197, 18.840567758006436, 5.395899232356779, 2.696766286127029, 6.614137887954713, 8.126594510770614, 8.384950737799368, 10.716060438463765, 9.565135048281762, 6.321667826944783, 3.256617702784077, 2.586047827236114, 0.761091621412385, 0.43977684852096344, 0.2563730552191696, 0.3490828554476461, 0.12503690266561124, 0.3207620251322946, 2.29294577433217, 36.129669450944476, 72.01976053176388, 86.04211622668852, 39.010328708156464, 38.269369448384936, 46.37497878843739, 22.818967027048913, 27.814089752012684, 32.82983237697233, 64.76142237263342, 69.52230899564682, 81.68353142276888, 82.92237281799316, 97.12659312832741, 39.96700656029486, 1.1400793012111419, 0.17253669820004897, 0.21828599814926425, 0.17047604425780236, 0.10570232966734518, 0.21397391904986676, 0.19928438228464898, 0.14123443754449969, 0.23242955937260584, 0.1886401115165603, 0.2662712023142846, 0.13196883392670464, 0.3680499054251179, 0.19886439756279994, 0.2385354180249476, 0.20620065470857007, 0.15022205849809034, 0.20426467391512088, 0.152416241565539, 0.21664701432230013, 0.13598503454798652, 0.12521882556499014, 0.13019544763430474, 0.09084033884949262, 0.11785963940764628, 0.16890335767980547, 0.1774139663264636, 0.10433810327442423, 0.16737404700008132, 0.1945599180556113, 0.21511692223289322, 0.19163125585163795, 0.14215340597494958], [0.042333589686501416, 0.08731587474504787, 0.08986812730830523, 0.01786557450560072, 0.025384913258735212, 0.07762208926461397, 0.02423818497317693, 0.02555264820975642, 0.026803905362143155, 0.0922659059025107, 0.025218779431475748, 0.06303286022176185, 0.010883167626396304, 0.03034160746591947, 0.04996954425868969, 0.003206051868243864, 0.028247349076874317, 0.12019806150947848, 0.06587917180431467, 0.07150399618812146, 0.0963169175590719, 0.09743015822624007, 0.04854593456031815, 0.24708232391745816, 0.10891678097147135, 0.021252746077915354, 0.09956608796792646, 0.021390525075877388, 7.192026568997291, 57.93669046894197, 68.62505897398918, 71.35131805173813, 67.18575308399816, 58.71231171392626, 38.442914716659054, 20.034382304837628, 67.62799247618645, 65.53933820416852, 47.755292231036776, 56.59379643778647, 47.26452919744676, 41.43575768316946, 38.41526200694423, 6.410954700362298, 0.29497115422160397, 0.08342107607712669, 0.06358772621399934, 0.05370521497341895, 0.13795617877716018, 0.07734195389334234, 1.0396923653541073, 0.6826462404381844, 4.1788941621780396, 3.352966558548712, 1.9549540334170865, 2.6392351667727194, 4.699367678934529, 3.111880037092394, 1.7550489666961855, 4.41199375737098, 7.247768352108618, 14.932136708690276, 16.943315344472087, 28.12137019249701, 38.592843394125666, 48.858607892067205, 56.58706172820061, 64.40556926112022, 68.01635419168781, 66.81469686569707, 57.9782283690668, 56.456529171236106, 60.56671419451314, 61.66198507432015, 68.96321435128489, 71.2726588403025, 72.60870441313713, 69.04679221491661, 71.56791917739376, 68.0398178100586, 69.44111593307989, 71.48929918965986, 68.38202891811248, 65.5907290981662, 50.59168754085418, 25.64879825038295, 50.86358231882895, 45.160197211850075, 45.440293665855165, 45.14472738389046, 36.282994900980306, 47.45029657117782, 58.44138576138405, 69.94033951913157, 62.90499987140779, 67.57905698591664, 66.43062622316423, 68.56427792579898, 69.91864881207867, 71.45337027888145, 65.22235578106296, 65.64861151479906, 64.79408787142846, 64.62109957971882, 62.39868856245472, 65.91644271727532, 63.25530282912716, 65.59720885369086, 64.93074324823195, 77.1952965951735, 73.75499356177546, 57.8835972662895, 29.922096998460834, 8.43451282670421, 1.1509899867157782, 0.6542166562811021, 1.2117036191686508, 2.817887851307469, 2.9059212823067946, 2.2077719963365987, 1.0969825040909553, 0.8059026781589755, 0.24251835510855724, 0.15906881120416427, 0.06437502711290313, 0.04641927448251555, 0.02227581245073628, 0.05618563530245616, 1.192868765323393, 19.98981829612486, 41.05653901253977, 64.78044194559898, 61.063501988687825, 47.03715724329795, 51.343139140836655, 27.02461273439469, 19.287374750260387, 22.36021249525009, 33.441778998221125, 49.73174318190544, 67.00971711066462, 75.47556477208292, 57.55325917274722, 4.991030221985233, 0.13013164783197065, 0.1357243195055954, 0.0011789346218950326, 0.04024966199311518, 0.026933408695303147, 0.013189552888845005, 0.009560805065707575, 0.03011976372480633, 0.05620913121909384, 0.05206549187160788, 0.046262276253753135, 0.12800193106335017, 0.032198855488170544, 0.05475118162951643, 0.04942208633668, 0.03522680651757025, 0.0871310024071605, 0.007383450077125623, 0.05881611310366181, 0.012588237070538586, 0.049814760024028445, 0.03640400020465736, 0.04546341125763232, 0.1061419262400558, 0.03624284594890572, 0.026703448252632257, 0.029069983866065744, 0.05426891778986301, 0.03499591910851098, 0.018677773262043635, 0.0324584482117526, 0.0973219559678147, 0.06463008076553384, 0.014399449911809739, 0.115843104468959, 0.06992595465553385, 0.13151336401220293, 0.027583091474709012, 0.07232673631440248, 0.03221549108744629, 0.02615770062191352, 0.04459179855222183, 0.06777957547456026, 0.07428602916338752, 0.051942898651524905, 0.02999898613310389, 0.0405288972110758, 0.048251910014979305, 0.023327262381151802, 0.048540970310568816, 0.0541790901503015, 0.06402684015131767, 0.04431762334500109, 0.0241476908371213, 0.1035384300555433, 0.12922015641966175, 0.08390898215434245, 0.05602952956612553, 0.1135905531625594, 0.03827010994897254, 10.843868909343596, 68.58910652898973, 79.86427337892594, 80.6150620983493, 76.87956148578276, 67.4706740533152, 48.048195223654474, 29.025184300638017, 67.40419772363478, 57.32872701460316, 42.92990615290981, 43.09555961239723, 42.607295128606985, 44.03024081260928, 34.33452613892094, 5.95519244670868, 0.18831936582442255, 0.06423556080628788, 0.09392982589141016, 0.37210054935947545, 0.6925990708893346, 1.1007847516767442, 2.5015246723928763, 3.921898997599079, 5.561075143275723, 4.615938375073095, 4.228172859837932, 5.054378951749494, 3.7475896025857622, 3.293219054898908, 3.9731665820844717, 7.202848388302711, 7.965646914897427, 13.911836051171827, 19.080371664416408, 30.246888860579464, 42.459056992684644, 52.1921165527836, 59.791551866839015, 67.32939027970838, 70.69485449021863, 69.79532164912071, 59.771728207988126, 60.50260305404664, 63.76552866351221, 61.79962104366672, 70.2966554703251, 71.58852731027912, 72.06726827929097, 68.1158882571805, 73.12295852168914, 68.11100882868614, 72.32185363769531, 75.06432779373662, 70.61434392006167, 67.91285853232107, 54.318421656085604, 30.635854621087354, 54.98069032546013, 51.02095565488262, 49.74384369388704, 50.347241509345274, 44.3425085467677, 51.405681333234234, 59.51798615917083, 70.39979811637633, 67.64617658430531, 70.22059286794355, 64.84923247368106, 67.9855243621334, 71.22681417772847, 71.21181503418954, 67.9636061576105, 69.15213138826432, 67.52104513106808, 67.17863005976524, 63.93274714869838, 68.6331625907652, 68.36606487151116, 69.41357304972988, 69.80968536869173, 82.27677422185099, 76.9556946908274, 63.107351026227406, 34.034974728861165, 9.777704957992801, 2.2863971321813525, 1.1080905338448863, 1.4781301228269454, 2.4314382912651187, 3.5747628634975808, 1.4942584186792376, 2.2172812925231073, 2.0743045258906583, 1.7155624661714801, 0.6072766718364532, 0.21908812284950288, 0.01780390059725652, 0.019834242355559143, 0.07050867943513779, 0.9510950323554778, 17.780861008551813, 42.60468283007222, 54.456449862449404, 52.02516086639897, 36.862446646536554, 29.997547711095503, 24.38227668885262, 22.2941578203632, 36.24886243574081, 46.71293412485431, 57.78440052463163, 73.50427566036102, 82.03746257289764, 69.78004009492936, 9.50327044533145, 0.15414479639261, 0.15826368343926248, 0.028466159109807307, 0.031882897845559546, 0.03417662254744961, 0.05470319771237912, 0.03845656042798393, 0.05197466065686557, 0.05605838043735393, 0.03422702730242764, 0.09728621030526777, 0.057469974046633135, 0.007318137251141091, 0.021337170882390875, 0.1241230593633748, 0.06735667961859895, 0.06549569883293684, 0.028012271166869232, 0.04372477088303816, 0.057256047824217435, 0.014506397701259104, 0.06588350786196609, 0.08538380866089175, 0.0062028061215495395, 0.14769516344512665, 0.02693505769956016, 0.020745795054901994, 0.05202685805758642, 0.04067086479476383, 0.0036645198199567537, 0.04971613003421695, 0.09946302615947301, 0.18343688830012278, 0.14512841649834188, 0.25720709514233375, 0.13955710335604607, 0.2269571635030931, 0.2317792426554426, 0.1551018853581721, 0.09546034699005466, 0.15747787641181102, 0.2418937329803744, 0.16447095681102047, 0.16519305596668876, 0.13953772133156178, 0.1272886572405696, 0.12675148404894337, 0.13004596855851913, 0.20139515369890199, 0.15372429073097246, 0.10628369847132314, 0.22306877699109817, 0.21756169266037403, 0.1477455567087858, 0.20919870915672473, 0.23342907428741458, 0.21536930223866818, 0.12679263829223572, 0.197617543500758, 0.10386609352163731, 16.0070671573762, 79.33502797157534, 89.93271520060878, 89.29747166172152, 87.00077487576394, 76.17915953359297, 55.60573177952921, 30.500674055468654, 72.16097370270761, 73.31013402631207, 65.4263033405427, 74.84076053865495, 61.471530468233176, 55.84822839306247, 49.07615430893437, 8.730123235333352, 0.9132524339422103, 0.158864694737619, 0.3069015946840086, 0.40293396420536504, 0.8306294222993236, 1.207155998676054, 2.439088874286221, 4.403329731956605, 9.218210231873298, 8.78187204560926, 9.021944634376034, 10.507595289138056, 10.589902304833936, 10.374758339697316, 6.81702591719166, 12.244895408230445, 11.48274358241789, 19.902888767180904, 24.30093457621913, 35.179934194011075, 44.320421680327385, 54.13580002323274, 61.59489293252269, 69.42555196823614, 72.15722391682287, 72.10589578074794, 60.11122503588277, 63.42565528808102, 68.82227574625324, 65.85492426349272, 69.10933048494401, 72.69361588262743, 72.71831896997267, 67.77335551477248, 70.33197249135664, 67.62265020801176, 73.48067083666402, 74.70940036158409, 69.36171147131151, 72.83992029005482, 59.39125045653313, 37.54635503215175, 59.54406599844656, 56.559542379071644, 55.442149331492764, 56.60911329330937, 49.39171683403754, 56.39716802104827, 62.354848231038744, 75.04663790425947, 68.09727268834268, 69.46193587395453, 64.05587034840738, 68.46181777215773, 73.19926431102138, 75.02653967949652, 71.63543885754001, 72.50153741528912, 68.97151408656951, 69.53428791415307, 66.23813982932799, 72.67888346026021, 69.03359736165693, 71.26979551007672, 69.75350133834347, 85.40639415864023, 80.26463754715459, 66.93338778711134, 36.01534804990215, 11.447581495008162, 3.274089655568523, 5.324546906255907, 8.156235862162806, 7.280584371859028, 9.8859868895623, 6.369316289501806, 4.374004621659556, 2.5493258622384842, 2.640524155670597, 0.4123675096179209, 0.18325708746429414, 0.10336949234648098, 0.11680317351654654, 0.1676239755244986, 1.9496750134614207, 28.70074349064981, 56.184406895791334, 84.63930406878072, 83.49346991508239, 64.25433051201605, 71.08359275325653, 39.250256169226866, 31.203790287817682, 35.30573637254777, 49.477491224965746, 65.04349962357553, 85.2155080918343, 91.28315587197581, 80.841429925734, 12.400060449877094, 0.4529476466198122, 0.2647473615023398, 0.12998739347582863, 0.1817838850641443, 0.18397737865246114, 0.06832437890191233, 0.14919289598061194, 0.13580278223080022, 0.1411349686884111, 0.10550149205711581, 0.22355535007532568, 0.24329411106244211, 0.14091896253728098, 0.1594100114438803, 0.21163637028826823, 0.14920521467443437, 0.19188469305874842, 0.2879950043655211, 0.09566427193461888, 0.08516126011888828, 0.19074636301206005, 0.09978709667320214, 0.11388727433739171, 0.13964955484674824, 0.1985432228614246, 0.11255918431185907, 0.16445672289738733, 0.09408207054460242, 0.12894888468567403, 0.13461972797109237, 0.11744491004895781, 0.3115757729016966], [0.028039660725382068, 0.060699777752761884, 0.053563668738089265, 0.05239569491917088, 0.027067788178101185, 0.11683276749306148, 0.03295712165474411, 0.053185481773388964, 0.04563160203096848, 0.05035202131576596, 0.03509038158001439, 0.003602882540191434, 0.07387231104075909, 0.10622479397082522, 0.012912352591933263, 0.09625232102529657, 0.03677118231632537, 0.06031772587448359, 0.04035072048164664, 0.043938674122816136, 0.04659356714616861, 0.048336692965559425, 0.04319896260576864, 0.03242521148715769, 0.06021396692601904, 0.04970791374122904, 0.018012563795632413, 1.2372668087482452, 34.22706496331, 67.60531333185011, 75.66452887750442, 72.76990598247897, 54.02272985827539, 37.68310454583938, 23.458889953551754, 39.041542929987756, 35.86078313089187, 57.01739280454574, 45.447797159994806, 36.00404377906553, 51.31335658411826, 34.397331130120065, 5.412175107386805, 0.01024465345131654, 0.05149132812455778, 0.04748371534890706, 0.056706364416787704, 0.18040829758730628, 0.4231877661039753, 1.0857054446974108, 2.5961337118379535, 1.3900859053096464, 4.079161281547239, 4.566890116660826, 2.8022130795063513, 2.2399861774136944, 2.910037074358233, 5.060290453895446, 10.584018749575462, 19.558596841750607, 30.15265980074483, 35.83279701971239, 44.13612911778112, 56.56689682314473, 64.62153888517811, 69.01422869774603, 69.39975846198298, 68.37481175699543, 72.68754405360069, 71.8960960449711, 68.48292796842514, 67.45188590018981, 69.56452154344129, 67.93540431607154, 69.22916673844861, 72.78540718939998, 69.74859053088774, 64.2983591172003, 67.6877772423529, 70.92384246087843, 74.11657333374023, 72.46442394871866, 72.02065483216317, 60.328838133042865, 63.826384236735684, 45.05569350334906, 29.305729866027836, 49.36849640261743, 46.20761125318466, 36.4685308548712, 40.76349873696604, 65.39400654454386, 68.7693629726287, 66.41068489320817, 71.24231538464947, 73.30710595653903, 72.81648020590507, 68.57990464856549, 66.03107006319108, 61.83110198666973, 61.73023431531845, 61.712301238890625, 59.058174548610566, 60.0542212301685, 65.29682590115455, 69.20428322207543, 69.4620692345404, 71.0848871354134, 66.05154483549057, 66.96173867871686, 68.45718153061406, 73.13666328307121, 77.61956368723224, 70.36728166764783, 42.207378110577984, 16.58254554194789, 4.938285619981827, 0.7229826695496037, 1.7122361736912883, 0.9059563351254311, 1.138998565654601, 0.7934701743145144, 1.7071742324098464, 0.45739049692788436, 0.1866065004780408, 0.04960582103399981, 0.08277589980993541, 0.03644035490710409, 0.006929396467673923, 1.3756992643879307, 13.031797389830313, 30.248797093668294, 39.66684326048821, 50.15443740352508, 55.33473522432389, 44.12867269208355, 35.79860964129048, 22.697248035861602, 19.28641769193834, 38.40923724635955, 58.580896623672984, 66.86409519564721, 67.64913405141523, 36.96534218326692, 1.5836473962953015, 0.05371122110274531, 0.08425615787986787, 0.011262706736282957, 0.1342459689945944, 0.07705000544627828, 0.03596261481664354, 0.02689564056063612, 0.016367765361322992, 0.009774119375393757, 0.008827021153974197, 0.019608246417896404, 0.04241524316791085, 0.017948484371205973, 0.014015852451144208, 0.03333239748533214, 0.08143718414489301, 0.017539632822116537, 0.05430213919269943, 0.021504271895654743, 0.018649864678962097, 0.13533928371485204, 0.05203045867083054, 0.04119689906797102, 0.06356165624193608, 0.018872598997287212, 0.018959779803070332, 0.03899121319033927, 0.007785747265217887, 0.01915709532406782, 0.07914350157783878, 0.11285443459787678, 0.047210536055987885, 0.09910314869616302, 0.07595346549585943, 0.03444851864309561, 0.022725163237942804, 0.11125153351214626, 0.02608031616546214, 0.016926724178295945, 0.01144006375163313, 0.04060035789265268, 0.07653646606711612, 0.0206594780132535, 0.11343508327920591, 0.08299530739144934, 0.10724915311701837, 0.06133190371216305, 0.06554504255613973, 0.034894948720090815, 0.04533041839397723, 0.02336670441793338, 0.010225382509581264, 0.009632897769821989, 0.11403834687605982, 0.03766685018255826, 0.1049640890391123, 0.03409274358062014, 0.03889223463052223, 2.6653098579375976, 45.787411658994614, 77.02151206231888, 86.11471145383774, 78.21204554650092, 64.40239606365081, 47.13953894953574, 34.344147712953635, 37.4538851553394, 44.28615977687221, 59.98683098823794, 39.03566721946963, 42.233371657709924, 47.17501286537417, 33.07355473118444, 4.375666726020075, 0.03912532837280343, 0.06921668747259725, 0.04434509142752617, 0.48342817072426125, 0.3436612818510302, 1.7849906245546958, 2.881405733285412, 5.422363954205667, 5.157037185084436, 6.999040563260356, 4.053253781410956, 3.108244735387064, 2.962706906180228, 3.8893416091319057, 5.870684491049859, 12.95863243841356, 22.97379082249057, 33.47777851166264, 41.76205181306408, 50.717905490629136, 61.62720541800223, 65.57090151694514, 71.55421441601169, 71.3834971766318, 71.1246991926624, 74.9239932337115, 74.38148237043812, 68.55973582113944, 68.54527011994394, 69.84048381928476, 71.03352762037709, 71.28077030181885, 72.40833405525454, 68.44608906776675, 65.21659381927984, 68.51931971888389, 72.65306641978603, 74.54100516534622, 74.2405672996275, 68.83295243786228, 61.167189844193004, 67.41441157556349, 47.16252011637534, 35.461407399946644, 55.25100046588529, 51.34849709849204, 42.53108739852906, 45.13722388975082, 65.3379088063394, 70.93905341240668, 69.86134298386114, 73.95128465467884, 75.97996588676207, 71.9359237917008, 71.0171321130568, 68.57496246214836, 66.07172935239731, 64.78654123121693, 64.3928764712426, 63.66023263623638, 61.519081361832164, 67.96032705614644, 70.27610225062217, 74.09966791829756, 71.87691565482848, 68.7184976762341, 69.31077557225382, 69.65625793703141, 76.71438263308617, 80.17463484118062, 71.61960817152455, 46.01992976280951, 19.52550772697695, 6.053959688832683, 2.181754424687355, 0.29926455609740754, 0.5298774605316501, 0.9268383597654681, 1.8374449711653495, 0.8070390623423361, 2.3793791234493256, 1.0273449279127582, 0.26282077294684225, 0.22592774051572048, 0.12280903471213196, 0.05368244300986971, 0.7689347070071005, 12.128926611715748, 28.590987728488063, 42.80848133948542, 52.46811805232879, 52.57750903406451, 38.66963555735927, 43.76014248017342, 31.50004690693271, 28.60972881317139, 50.095574394349136, 63.494689003113784, 74.09056017475744, 80.39740193274714, 52.471051985217684, 2.885056479323295, 0.04209103475835535, 0.015379766663236004, 0.015156635894410074, 0.06766175881268517, 0.06094020678691807, 0.015577433627068758, 0.016439354362627192, 0.026525968663214196, 0.09920676974880119, 0.03680227782517191, 0.06115067412235564, 0.07219659329782571, 0.016479154545513373, 0.03805625267447003, 0.0519460664250918, 0.027511261155708667, 0.09751993607008651, 0.040567848951585835, 0.09150970817333268, 0.11122044566417895, 0.04209838920242844, 0.07264557444760877, 0.0340304184975403, 0.05884283042002109, 0.009105790973520808, 0.026457223763328888, 0.03477051305854994, 0.0181597484380848, 0.010091033670300198, 0.03558176952684599, 0.034815800346193776, 0.10617790172898, 0.12062484909209514, 0.19672129723814227, 0.19646375379975767, 0.13271393104185983, 0.3328075013574093, 0.10063791392190803, 0.1357418935625784, 0.09695782671652495, 0.1617469779786564, 0.09638915965033155, 0.12611011523873578, 0.19796660380257716, 0.17578483439020573, 0.20506077716427468, 0.2064321051922537, 0.14846269161470477, 0.12079372551412353, 0.14821812570575746, 0.08235501876521496, 0.1221681945025921, 0.13810047909857767, 0.21223447045251248, 0.10691413520685128, 0.2468273851780161, 0.10828565475681137, 0.16160834670787858, 4.409336841875508, 57.705607952610144, 85.96704990633073, 94.65513121697211, 88.9810226809594, 73.32858485560264, 54.398379172048266, 36.41946984875587, 53.84860407921576, 46.26808635650143, 63.89098175110356, 61.353349454941295, 47.18970606403966, 67.08738788481682, 45.54614666969546, 7.246408270251367, 0.15778662516705452, 0.11688439415827875, 0.21039405146673804, 0.31520473139901317, 0.5619964015579993, 2.2570950658090654, 3.232753267211299, 9.526370263868763, 9.066220348881139, 13.340920363703082, 12.127391984385829, 11.669446441435046, 7.208464241796925, 8.67454226939909, 11.36237584775494, 15.233686566352846, 25.529868064388154, 34.293215736266106, 41.819973453398674, 50.036742764134566, 62.896264753034046, 70.55160953152564, 75.13649940490723, 73.14812444871473, 73.10903410757743, 77.46838769605084, 75.85941576188611, 71.9975128481465, 69.58918540708481, 72.22010735542544, 70.55473173818281, 71.48475708500033, 73.10334667082756, 69.22498549184492, 65.651000238234, 67.40065974573936, 72.09048086597075, 75.4725367023099, 74.04277001657795, 72.0026276188512, 63.06177308482509, 64.75484063548427, 51.268974965618504, 39.927798548052394, 60.04201481419226, 55.24242224231843, 48.6635248891769, 49.236653774015366, 69.57024820389287, 72.98562065247567, 71.59042573744252, 74.41225728681012, 76.72209401284495, 74.69699782709922, 71.84872165802987, 72.71125085892217, 69.31593741140058, 68.98573660081433, 67.41742395585584, 65.41304572936028, 63.67528669295773, 72.10490734346452, 74.70650565239691, 74.65682491179436, 76.62791790500765, 72.79062394172915, 73.01876468043174, 73.70901553861557, 79.23332875774753, 85.32363214800435, 75.75854809053483, 49.73343764581988, 22.84861622318145, 9.147441848631829, 3.3675700329965164, 5.00242421703954, 3.24226648576798, 2.6579725742340092, 4.9460577964782715, 4.54262045121962, 2.834197556780231, 0.8381443158272774, 0.2437011642201293, 0.1811620821395228, 0.2747509989046282, 0.18324006499061662, 2.047985789756621, 19.532448360996863, 40.8872652053833, 54.05272030061292, 70.82155489152478, 74.76676110298403, 62.667425832440784, 50.929289863955596, 33.98461934058897, 31.23860328428207, 56.971587365673436, 76.19046380442958, 84.3973958107733, 87.02693708481328, 58.7402036882216, 3.338061551893911, 0.2652260745244642, 0.13871693472948768, 0.11725397029471014, 0.22236673401728754, 0.09692504581424499, 0.10482401752303686, 0.1738791293915241, 0.11009083369806891, 0.2016505674128571, 0.16842404710910014, 0.18406463606703669, 0.17561765868336926, 0.09732233901177684, 0.06930366909552006, 0.13314896173054172, 0.14488527551293373, 0.14156984615950816, 0.09594940986003607, 0.15752820838843623, 0.14928916258917702, 0.18796085199761778, 0.17772941069016535, 0.13030637716574053, 0.18324314466407224, 0.16844781115651133, 0.16433681481547896, 0.13847471304958867, 0.09884382027291483, 0.11414120950165296, 0.17188126401555154, 0.3097583978406845], [0.03381222899582598, 0.056482593964545004, 0.10635905854043462, 0.012674107865971184, 0.06422168312353954, 0.04017954196540579, 0.021804869475383914, 0.05435193107733804, 0.0712804287491787, 0.03602058468987385, 0.08134592009047348, 0.005853264141947993, 0.08859337232406102, 0.06564778260766499, 0.06084578261981088, 0.01183514965833315, 0.0527573497064652, 0.059420832267571846, 0.08596953650515887, 0.10475266409376938, 0.07891705364830072, 0.00806688190242576, 0.039161422605355906, 0.02245106080907487, 0.09232927669560717, 0.016790412238708908, 0.06848779311704059, 21.92802025425819, 57.40027496891638, 72.78824698540473, 62.96016016314107, 60.98571354343046, 41.61105232854044, 22.873713508729015, 24.841643110398326, 24.95612140624754, 15.386163803838915, 29.75770065861364, 57.384004977441606, 49.51791909433181, 34.055155323397734, 4.308859446356374, 0.18771293062356212, 0.03497084122030966, 0.2939577118283318, 0.044181746160311085, 0.044103888644566464, 0.786804412641833, 0.40961422026157385, 2.0146483399214286, 4.20594233659006, 5.069023611084108, 2.3054140085174195, 2.713953376777711, 2.144229599545079, 4.7647295651897315, 9.69627361143789, 22.61998518820732, 35.7054925733997, 47.52232305465206, 51.31936173285208, 58.79882351044686, 64.02467573842695, 70.79153307022588, 70.52567481994629, 67.96807765960693, 64.155471094193, 67.36609581978091, 68.73549722856092, 72.40719656790458, 69.31549026120094, 67.99780138077276, 70.548840338184, 69.52057530803066, 67.16410944538733, 70.88807828964727, 70.48131281329741, 70.21603507380333, 68.6102794831799, 70.28851262984738, 67.28761703737321, 69.00844712411204, 66.65115756373253, 72.93622232252552, 67.19211516841766, 65.58997600309311, 34.696113755626065, 34.48228966805243, 40.6511502881204, 38.341721488583474, 63.89735952500374, 66.07745601284888, 68.69348079927506, 62.43839863807925, 64.85905408859253, 61.84689344898347, 66.11683660937895, 61.405501288752404, 60.886501112291896, 58.608745451896425, 55.84305478680519, 54.140922638677786, 60.83586723573747, 62.08165907090711, 65.76317610279207, 69.17353968466483, 70.82420641376127, 67.34638198729485, 68.4281010781565, 60.63028404789587, 60.550228472678896, 62.682389674648164, 67.32326353749922, 65.6766603839013, 72.64236619395595, 59.626659347165024, 54.367843520256784, 37.28967120570522, 11.867726176015793, 2.397525969051546, 0.5786293961348072, 2.004569196893323, 1.0341548366892723, 1.8571456882261463, 1.0974008493846463, 0.20059762552620905, 0.0355469431698082, 0.12605899419154853, 0.010452012385001347, 0.03588908952811072, 0.6987565179024974, 7.110392730082236, 24.88276916165506, 39.101343385634884, 44.82041797330303, 62.16446422761487, 29.871421937019598, 31.892077999730265, 19.69236731529236, 40.79466589035527, 50.714053723119925, 58.50375929186421, 68.47184335031818, 70.47964188360399, 16.569891975772, 0.47101114185587056, 0.041912689489582856, 0.0307911746729646, 0.024446309994786017, 0.05579925502740568, 0.03777337470842946, 0.04627412763394175, 0.027050635469476544, 0.09265654945685979, 0.1038249469392242, 0.027139903864853328, 0.008310630970123795, 0.022570156837783517, 0.09903181058865401, 0.03565239134214578, 0.015327558728806196, 0.07343701222130368, 0.05931120508560731, 0.04838606350183968, 0.044216151168990525, 0.019953280927673466, 0.060217598182780135, 0.06786137834311494, 0.07598712739925231, 0.02268399367289197, 0.05128954439574192, 0.0224988512890113, 0.048341278001786246, 0.03277891811223761, 0.013925434923881005, 0.06592858447543075, 0.11043519022003298, 0.04377979897863923, 0.00833970592207005, 0.06920185601038319, 0.030990493513884085, 0.038568347977894935, 0.11627228990677865, 0.027437122996836424, 0.05438626330766467, 0.050454175310029145, 0.13783165884594764, 0.029450744886191624, 0.032228771221613696, 0.02315736897740393, 0.07123691495507956, 0.05410800868224713, 0.007857517254794198, 0.050741864308234186, 0.02757549188250015, 0.14430445829226127, 0.09009757064162724, 0.02873493531238168, 0.061756906309916135, 0.07183894515037537, 0.040042626731578386, 0.07805436969764772, 0.472111581193824, 30.977267526811172, 71.08418110878237, 81.68771266937256, 71.41809248155164, 68.59328777559342, 53.8760567480518, 35.38737266294418, 28.94480120751166, 28.81363714894941, 19.3594188844004, 38.627677963626006, 56.19208689658873, 48.26823626795123, 33.75014397405809, 4.364841964937026, 0.08208639769544525, 0.07604337357465299, 0.3394065827371613, 0.2689928062740834, 0.6699645435137134, 2.332870354575496, 4.958235284974498, 5.880017770874885, 3.940626353986802, 4.921166435364754, 2.1279645110330274, 0.9746741154982198, 2.391909380112925, 6.540984213352204, 12.23974729737928, 25.23363497949416, 37.018458920140425, 46.97967883079283, 51.494711291405466, 58.9042725101594, 66.21436242134341, 73.90190985894972, 73.80789064591931, 70.55633990995346, 67.01580462917205, 69.56722013411984, 72.42861270904541, 74.42804090438351, 69.36482583322834, 69.10718102608958, 69.8858028842557, 68.84256224478446, 68.28042384116881, 71.99875231712096, 71.57833699257144, 71.22213086774273, 69.37569079860565, 74.85528115303286, 68.7950623419977, 71.71144654673915, 68.59663747972058, 71.90729048944289, 66.95252895355225, 65.96692362139302, 37.216122842604115, 40.98667767740066, 45.89287634818785, 42.96954170350106, 64.90110189683976, 68.36200914075299, 70.1807180527718, 66.41025343248921, 65.3516645585337, 64.40226270306495, 68.31595267018965, 63.70038201732021, 62.16234614772182, 62.65861618903376, 58.30269075209095, 57.629211948763945, 63.363850501275834, 64.81373502362159, 69.64274144941761, 70.75647492562571, 71.58692698324882, 71.05583806191721, 70.97615903423679, 65.07398820692494, 65.59453379723334, 68.33031638976067, 71.6332737092049, 70.34682258482903, 74.88003915356052, 66.65926118050852, 58.738336640019575, 40.891819077153365, 14.25270570862678, 3.295785265584146, 0.23512868631270625, 0.9936058641441408, 2.5313386080726503, 3.0541363743043717, 1.9724283151088224, 1.3446539496221852, 0.3317433133000328, 0.21436561980555136, 0.09448584484597368, 0.08084721983440461, 0.5610174637648367, 7.293864046373676, 24.595282962245328, 40.30153766755135, 48.20550580178538, 60.110534698732444, 24.34819325324028, 29.959114366962066, 23.16751668530126, 48.329750799363666, 60.44465395712084, 65.50325632095337, 76.27422209708922, 85.85265005788496, 26.804930586968702, 0.7550899660395038, 0.05251648400219218, 0.09292854131349633, 0.018053844443432266, 0.043499027754390435, 0.007217780211865301, 0.040110459986833796, 0.037578608345000014, 0.05137259981805279, 0.09783462966762244, 0.04076718119904399, 0.042582307791998314, 0.05402449743762132, 0.0794426052861156, 0.06214186549186707, 0.057953444474767295, 0.06444579831534816, 0.08400750872228416, 0.02206217734173181, 0.04650418383760318, 0.03785854836385097, 0.021399124412827437, 0.046294049750412666, 0.07215514794112214, 0.045408379331591635, 0.051076947335874846, 0.04897801581049158, 0.1152847795897434, 0.032209963763072606, 0.05512472993183521, 0.022622371475482662, 0.17803690306121306, 0.22300917535058914, 0.1678952319367278, 0.18734127072797668, 0.21127805564432375, 0.1772194719242473, 0.22270099350040962, 0.14145085738310892, 0.15390772282356216, 0.11484826269048838, 0.30388182930407986, 0.12518396856443537, 0.13842111753840602, 0.1569527691049922, 0.3159486947040404, 0.20153855003656881, 0.08788720779721776, 0.1922187227154932, 0.1626579178076598, 0.31772283176260613, 0.203817370497892, 0.267034164599834, 0.1481098008732642, 0.19798471412110716, 0.1855866229462047, 0.18306124474733107, 0.8036224327741132, 38.940636034934755, 84.6994104693013, 92.28740815193423, 81.60985362145209, 77.7485704421997, 58.09347152709962, 37.0586867486277, 37.08302113317674, 36.81769240287043, 26.41175220089574, 44.20168761284121, 77.88990912898895, 66.76455328541418, 46.59130927055113, 6.364649159293021, 0.3854824200032219, 0.20421222753582463, 0.5153575203111095, 0.30266868311070627, 1.136387860582721, 3.7164901100820114, 5.640105999285176, 7.438469577220179, 12.033629686601701, 14.698052598584084, 12.382666699347958, 11.695808691363181, 7.502475303988303, 11.378870394922073, 15.251912839951055, 30.035067142978793, 41.181760680290964, 52.99861077339419, 55.014701197224284, 60.69417161326255, 65.84771494711599, 75.67448385300176, 73.14850099625127, 73.9075816062189, 72.03185712137531, 72.56744892366471, 74.6555462191182, 78.26687243676956, 71.23343513857934, 68.26664847712364, 70.75365081910165, 70.4731385938583, 68.40972869626938, 73.91212371087843, 74.82578492933705, 74.0852257513231, 72.91932475182318, 77.62251330960181, 70.68456219088647, 74.92236937246015, 70.44017499493015, 74.69021212670111, 69.58428244436942, 65.63383202398977, 40.780604193287516, 44.5867427702873, 51.35060341127458, 45.402085858006636, 66.93859669470018, 69.98638814495456, 72.3009160257155, 68.0330164201798, 68.73082960805586, 66.32465162584859, 69.84908165470247, 67.02284920600154, 63.9888370421625, 65.24219512939453, 61.00583530241444, 59.16165451849661, 67.63891235474618, 67.65937928230532, 71.62955530228155, 73.815076428075, 73.23175722552885, 72.91886191214286, 74.38988408734723, 67.80999829692226, 68.52477965816375, 71.32490481099775, 73.9208156831803, 71.48592595131167, 77.10465062049128, 72.13256789791969, 65.47841987302228, 44.75420444242416, 14.689625386268863, 3.9287575069935095, 3.182926663467961, 6.617679788220314, 6.079028046900227, 5.922275425926332, 2.856128263858057, 0.9421452867888636, 0.2911916134818908, 0.20426686492658433, 0.15505314684442936, 0.12490780918949074, 1.0634436650622276, 11.201227230410423, 36.179326657325994, 54.74564229288409, 59.607545637315326, 77.4632493911251, 38.711530393169774, 44.26202543320195, 29.583925931684433, 57.54184899791595, 66.5538670939784, 79.11768159558697, 84.73680634652415, 99.50364358963506, 29.294172602315104, 0.7605289451537595, 0.08084051656506716, 0.19059375829754338, 0.15205026604235172, 0.22397446145694103, 0.11432976672245611, 0.15985972037719143, 0.10656436244326253, 0.2332145083815821, 0.22536861890506363, 0.1922075378317987, 0.1425219708753209, 0.16829416456241764, 0.22774226572965423, 0.1475957711978305, 0.10755927316964635, 0.20429337156876443, 0.16811934329809683, 0.1355292735200736, 0.13156605553963494, 0.13977761410417097, 0.09513303592440583, 0.1758941091717251, 0.19722598064089977, 0.25002229357919387, 0.11731164905452922, 0.13637642886850143, 0.23171823141315293, 0.10195752335411888, 0.14101673067817766, 0.12213547488734608], [0.06835865367564463, 0.017777619951014078, 0.06524007061436292, 0.017018855827289726, 0.06169693311676384, 0.038350066545629696, 0.07080040571670379, 0.049242500005470174, 0.01603202828611698, 0.051958205088252024, 0.06253694086485813, 0.015998033134477035, 0.01598458446096629, 0.10141566170439606, 0.0541936228382251, 0.019219799620670178, 0.050638959547805215, 0.03259322989071089, 0.02667516237124801, 0.03406322238245799, 0.039198650648036314, 0.04976890583132064, 0.03132035182188115, 0.05498411832377315, 0.08283476600603712, 0.09477360279209192, 9.74466879521647, 69.59182908458095, 70.51255841409007, 67.39176381018855, 65.77333896390854, 44.714188421926195, 25.243242825231246, 19.888050440819036, 25.69930268872169, 45.13485085579657, 41.34977932899229, 30.27944061063951, 33.88431649054251, 32.24627783221583, 5.174310322730772, 0.1304135375445889, 0.012384699000376127, 0.0468321192649103, 0.09784564601197358, 0.5117390725401141, 1.3957913604474839, 1.0116378578447527, 3.9824231305430016, 4.275843876023447, 2.487327898702314, 5.275560915470123, 4.370923599889202, 1.9031580321250425, 14.453955658020513, 25.976071011635568, 45.31327163019488, 53.54114124851843, 57.003299728516616, 61.16458146802841, 66.20443882480745, 64.06914757144067, 67.98819157385057, 68.24451061987108, 65.25467611128285, 61.47646088753978, 59.12995392276395, 60.50768644578996, 66.2884795281195, 70.92891800788142, 68.14278787182224, 67.99864076798963, 68.95935473903533, 66.07932306105091, 68.77395999047064, 68.3660021135884, 65.82726370903754, 65.99776914042812, 62.70317823656144, 62.10367141231414, 63.84753757907499, 61.41649569234541, 63.41261732962824, 64.51465037561232, 65.27666099609868, 70.64340868303853, 55.37330389022828, 23.432178612678285, 29.85713274248185, 53.9159982435165, 66.20305030576645, 66.15077295610982, 66.02285662005025, 59.16239584645918, 58.93144669071321, 55.930045112486816, 57.041421244221354, 57.100076367778165, 55.13834214979603, 51.286939421007716, 53.77582842303861, 55.507413648789935, 59.724695067251886, 63.31778618597216, 67.14006531623103, 57.633812888976074, 64.62481014190182, 69.83154081529187, 68.46550480011972, 55.95667016121649, 56.9406633992349, 62.87728832614038, 64.98720184449228, 63.798747216501546, 58.746024485557314, 60.5388222202178, 63.06363621065694, 65.41992948901269, 64.1246255751579, 36.17207811724755, 11.005794155982233, 0.7298047131588383, 1.2681015412653647, 1.8124660921673623, 0.4766573324318855, 0.6628928165281973, 0.3030045054131939, 0.10964320086303259, 0.036157936593818094, 0.04504074905848792, 0.05428658377739692, 0.05109562838990843, 2.130299056729963, 15.328988394429608, 43.00485872453259, 33.65820753958918, 62.75493783335533, 46.186689330685525, 21.896145113052864, 23.999355300780266, 50.67702262632309, 54.603315168811434, 65.3969326326924, 70.18943355929467, 52.58612648133309, 2.10326902327999, 0.04447118566942312, 0.016875534183195522, 0.06422745176560937, 0.02710339402960193, 0.015922015187360587, 0.03014800747135474, 0.049977304729362654, 0.060501556332793936, 0.06454540506726311, 0.12732384365893182, 0.08106482710929648, 0.03239294769422662, 0.09502995879419389, 0.05631786973906621, 0.07635985981793174, 0.03686400919011043, 0.07232322763170927, 0.04975780138685819, 0.016202824716005596, 0.04926269025271458, 0.019286048989142143, 0.018015823499750228, 0.040977579586568384, 0.03844989163260307, 0.09044440162758674, 0.03925955080757699, 0.03170700597336456, 0.07098353137412379, 0.06811698357905112, 0.03271546687990908, 0.03874685412513153, 0.0069118085253473014, 0.010885034965711736, 0.014748406791759115, 0.028992767948957703, 0.03611490926555088, 0.04303740615385675, 0.021779330019208214, 0.08635251918026517, 0.02227384168955107, 0.03349528309979266, 0.06747203713823711, 0.05689921939084607, 0.017531845538366227, 0.02285475275599428, 0.10460667837891849, 0.030949126681192752, 0.05499490484174702, 0.08508864264454573, 0.04990756008473616, 0.04857661638168558, 0.031823520285768375, 0.04090474760760704, 0.020843494247885484, 0.055043999586374535, 0.07581313350988973, 14.517186226383334, 83.03038704779841, 77.59217769868913, 76.54266126694219, 72.48070962967412, 57.738375433029674, 33.40169237506005, 27.817833654342163, 30.02447282114337, 35.268254203181115, 44.577874291327696, 36.23443988061721, 40.03402417705905, 33.18384785805979, 5.645160463548476, 0.04928352018337577, 0.04388167718124967, 0.09078463659651818, 0.29848768165515316, 1.6427429284780257, 4.138468253997065, 3.7776481961050346, 5.106068436176547, 7.620102772789617, 6.637081792277675, 4.270160361643761, 0.6551195368651421, 3.487844856516008, 15.163496732711794, 27.955038162969775, 48.07148625773769, 55.60128773412397, 57.255978815017215, 62.536618709564216, 66.50034243060698, 65.06003241385183, 68.34988901692053, 69.65548130773729, 67.6314284724574, 64.49464236536335, 62.657729733374815, 62.574759837119814, 66.66662739169213, 71.08596970958095, 68.45639705657959, 67.30395763151108, 66.8751484347928, 68.36828493302869, 70.26110310708323, 70.23384263438564, 69.86744619184925, 66.72121893975043, 64.82448624026391, 64.2308472817944, 65.19731929225307, 62.71690653216455, 65.04868107457315, 66.70148941778368, 68.04951390912457, 70.70324051764705, 55.89573614058956, 27.592579780086396, 34.4418578763162, 57.210040015559045, 67.61636657099571, 68.0506435517342, 67.37752560646304, 62.28908969509987, 61.39237311578567, 60.87240803626276, 60.74536638875162, 60.03702948170324, 57.60441864690473, 54.95378286607804, 58.02933685241207, 58.01810710660873, 59.775772171635786, 66.91962026780652, 68.97815073690107, 61.91808446761101, 66.37610527776903, 72.51797999105146, 70.48288176136633, 59.213312133666015, 59.757517460853826, 67.01549083955827, 70.75131308647894, 70.4315536252914, 67.60849829643004, 67.01611841878584, 69.42081374506797, 69.10991884046986, 67.53376145516673, 43.02267805222542, 14.504133559042408, 1.368600509820446, 0.41463365898497645, 0.09316753010235487, 3.145748968085935, 3.035719865752805, 1.2409891380417732, 0.9420877995510256, 0.10528881072757706, 0.032890046826533736, 0.04694342034898939, 0.10970517737610687, 1.8068119955639688, 14.092995620542958, 41.682655196036066, 33.963163975746404, 45.504934326294936, 36.52853527376729, 20.261728763580322, 33.8957933456667, 56.221253641190074, 62.49133494592483, 71.03149583262783, 76.52533223552089, 67.20094050130537, 6.966131387218353, 0.07589273770610172, 0.15068368775950325, 0.12035789043312112, 0.14185692994825302, 0.048699332175836454, 0.018596232778603033, 0.12804303934136707, 0.016206478955404415, 0.057150461756053476, 0.034425198926680514, 0.05703405852639868, 0.025906619135170214, 0.024704330322903492, 0.06114462585819345, 0.02157212047266864, 0.03097233914529845, 0.042482099661062804, 0.041117647272204204, 0.04208796657621861, 0.07887936212242612, 0.01976390016235171, 0.05634580896566472, 0.008792351844960885, 0.08256642072792016, 0.06744281854480505, 0.028355131902161147, 0.05278741482705359, 0.023339538940138394, 0.08725199833392136, 0.10033155536098827, 0.1626803948273582, 0.10824458478319068, 0.1262108098355032, 0.07423978043539871, 0.11114509325594672, 0.09050787201211338, 0.16041786139530523, 0.09419708332467465, 0.14504721117836816, 0.106288647399314, 0.11678279557776068, 0.2029790098388349, 0.08003922690066599, 0.15014623111534506, 0.1930246778553532, 0.20731365788848172, 0.10594919384006532, 0.24269659312502032, 0.16877312273267778, 0.12143333998298454, 0.13913046899101428, 0.10541108602117147, 0.20056787067123, 0.17648456377848504, 0.2927494992411906, 0.2837810917727409, 19.292518938741377, 96.18410248910227, 89.08358481622513, 87.51550751347696, 82.9155949623354, 62.10089829660232, 37.91304957482123, 30.0977897644043, 38.21435036197786, 62.206033506701075, 56.75084813948601, 41.057194048358554, 46.00654663578157, 44.22985807541878, 7.991907183201083, 0.321515457284066, 0.11407446792168964, 0.18041762853822402, 0.22879007482720962, 1.7731802453917844, 4.481056399883763, 4.983089873867651, 10.545604036700341, 10.403959405037666, 8.21327006624591, 10.928658785358554, 9.428229620379787, 6.1235695019845044, 19.14551046586806, 30.014421747576808, 50.31437989204161, 56.32074063824069, 60.53347602967293, 63.55229685383459, 67.35767056865078, 64.96809597938292, 69.39748348728304, 73.56562152985605, 72.4203835764239, 66.8286761929912, 66.40523279866865, 66.93519207739061, 70.0062196485458, 75.8920341922391, 69.37998971631451, 69.03468778056484, 69.30003612272202, 68.22952716581284, 72.03927040100098, 71.86208909557712, 72.22679107419907, 70.75012853068691, 69.71453651305168, 66.9347135482296, 69.71055922969695, 66.34881342611006, 68.79940048340829, 70.99156610427364, 71.11537964113298, 74.47093594458796, 57.16340695658038, 31.873380061118837, 39.57634633587253, 58.99287885235202, 68.61477451939737, 70.8656580217423, 69.69381070906117, 64.73379319713962, 65.19941776029526, 63.44636148022067, 63.96739344443045, 62.366113278173636, 60.7301946609251, 57.72153669787992, 59.793297321565696, 61.678247221054576, 65.18793306043072, 69.53977138765397, 71.38347364241078, 63.00212167924451, 69.33716527877316, 75.6605515941497, 74.08070718088459, 61.46701582016484, 62.528385654572524, 70.29737718643682, 73.40103887742566, 74.2687063832437, 68.68234126798569, 65.93811773484754, 69.15155872221916, 70.78444142495432, 69.73054762809508, 44.12429140460107, 14.745028864952827, 2.5227915183190377, 3.515127637693959, 7.256815298911064, 6.318847152494616, 2.7165798939043477, 1.571083309188966, 0.468265819813936, 0.23234700573788536, 0.2141256963894252, 0.15002220148040404, 0.19177603114756847, 3.437144054520515, 22.34862385257598, 60.717529327638694, 49.27670509584489, 80.87843356593963, 64.49672122155467, 35.54197680565619, 37.08559420800979, 66.9441350813835, 70.897382151696, 83.36193715372394, 83.51233651561122, 76.0150710998043, 6.401769490011278, 0.17006486954708255, 0.19927482150735396, 0.19481890173929353, 0.2746964534444194, 0.15373935201956382, 0.1294530624704015, 0.16539514996111393, 0.1753551509952353, 0.17375917534434027, 0.22664248522731567, 0.2232186697543629, 0.16139387273259703, 0.1999067827578514, 0.19311994854961673, 0.158456890813766, 0.1835515256971121, 0.31297691707168857, 0.12357057207414221, 0.15380022536602714, 0.16073574191860615, 0.1368683645681989, 0.1647564624586413, 0.1057099752248295, 0.15873951597079156, 0.2037047096077473, 0.20447127250654085, 0.1910561383251221, 0.1872309387451218, 0.22979737319532903, 0.13211193915096023], [0.10572177297886341, 0.04919574565945133, 0.06291010229277515, 0.0851121002567872, 0.050259933716827826, 0.06764014747234122, 0.06309286788887074, 0.067536304254205, 0.038365457252028494, 0.04344344041460464, 0.05195898266749517, 0.03720514814279253, 0.04779127666786794, 0.034957465325151725, 0.02308528393416876, 0.05709280980931175, 0.07557313348497115, 0.07093238734429883, 0.02562981050070976, 0.016261422781333808, 0.06642199872482209, 0.0284731017816211, 0.04609535718637128, 0.08374169919519656, 0.06815527265350665, 0.8293306274760155, 36.48718564741073, 74.46836286975493, 74.82206652241369, 68.79920436489967, 56.71350325307539, 28.67448518353124, 22.30266348008187, 28.561562107455348, 25.829780332503784, 33.11849332624866, 27.86409801052463, 44.21945202735163, 36.85353894387522, 7.354529874940073, 0.36261086502382833, 0.029780622346386797, 0.056961536813046665, 0.17561278636417083, 0.5688155033896046, 0.4147273362163575, 0.9673556469140515, 1.691647039786462, 3.529272194831602, 6.485244391425964, 4.220899804945915, 5.6095683863086085, 12.379111070786754, 33.04576473851358, 54.73546374228693, 63.59036345635692, 67.94823831127536, 67.85390530863117, 71.88664313285582, 66.26230162958946, 59.7803181986655, 62.84090834279215, 67.69308028682586, 66.18563498220136, 60.697203605405754, 57.75434340200117, 56.34129385794363, 59.60545109164331, 63.44620458541378, 69.00876875846618, 66.79277081643382, 60.833074508174775, 66.03988755133845, 65.64904297551801, 64.90677364410894, 62.6587377825091, 62.78060974613313, 60.419586089349565, 62.03925824934437, 58.2816864598182, 59.74208293422576, 55.88581254405361, 60.97008682066395, 59.968619423527876, 64.25011396408081, 63.39713573455811, 72.17753394957512, 31.952543297121604, 24.9387001991272, 63.9013328859883, 59.719972533564416, 66.04532395639728, 60.78247201058173, 64.58300944297545, 58.23897969338202, 59.104297699466834, 55.971555556020434, 56.876775833868216, 53.981199802890906, 54.63874201620779, 54.40570223715998, 55.3133543845146, 62.40346993169477, 68.41296072929137, 62.69805169874623, 57.64428561733615, 58.7113428884937, 67.63142062771705, 62.44127373541556, 56.005511514602176, 52.190292650653475, 57.20238747135286, 61.94496447040189, 67.76173745432209, 70.1218197422643, 68.2055301050986, 60.590362164282034, 55.68894486273489, 60.500398682009795, 66.64100646972656, 54.764395144677934, 25.28225079659493, 3.6206381695885814, 0.5290904124417614, 1.9148561334417713, 2.5865923012456586, 0.9401393008808937, 0.25960249886397396, 0.0885945520994644, 0.0389115936723688, 0.03530151158150646, 0.04441359500971533, 0.09538877139528913, 0.5078450169774794, 7.64715486957181, 45.44862870247134, 49.62345830855831, 46.26078682561075, 36.75074538876934, 25.479953942760346, 33.00253629684448, 47.596604900975386, 60.87827590204055, 64.26903547779207, 66.219861584325, 52.607440640849454, 1.5848654148078736, 0.16126311684568084, 0.04703528195198986, 0.043886752513748024, 0.012287411579651939, 0.026500201295881022, 0.018134113220918565, 0.02904460145791452, 0.04311273557945125, 0.03927493385309654, 0.02613336009333932, 0.05047722306523112, 0.04012336090747868, 0.030214913760221777, 0.06365208143007851, 0.11693682521581651, 0.03129858726395234, 0.03562856600770066, 0.13905997358022198, 0.0629624605719601, 0.03182412549522856, 0.01953735647182311, 0.02914066122274005, 0.07080673360295835, 0.07897809553410738, 0.05656073876326123, 0.10264949227172522, 0.029270693156567794, 0.045530252429025794, 0.09237877363639493, 0.028439698432902658, 0.04391915037206585, 0.08242760559604054, 0.033148605331418016, 0.08770066538765546, 0.04101156324688946, 0.11156300187952096, 0.0921020933216618, 0.00919274674097617, 0.07015804099219461, 0.023351447776921337, 0.013793455211505776, 0.1261320483360079, 0.031018934528072997, 0.0366798225009153, 0.05689764508016168, 0.019977219260087418, 0.014602918076449105, 0.048109984566127105, 0.04025139335182406, 0.01535196245963415, 0.007700063682521784, 0.0653019015707316, 0.022901982076526172, 0.0645225833079988, 2.135023061306246, 46.85908555984498, 84.36174146590695, 82.89796783078103, 76.28610687871134, 68.20600863425963, 39.27357073753111, 30.855721119911443, 27.680864487924886, 27.657771533535374, 42.96305018086588, 36.60589618067588, 37.88315719173801, 29.612110122557613, 6.506395282283907, 0.44485659368576547, 0.03457250614320079, 0.14800657818634666, 0.750380547777299, 1.8579095698172048, 3.2575134740721796, 4.479996379344694, 4.0148280368697264, 3.5221555444502064, 3.3867195344740346, 2.7986868687214392, 4.197762723891966, 14.018349974386155, 36.48045486019504, 57.96121704962946, 66.96428037458851, 73.34500389714395, 70.79984065025084, 72.1951924600909, 67.42164442616125, 61.460406626424486, 62.854962195119555, 68.25226906807193, 68.77326180857997, 65.83637145257765, 60.11063275798675, 59.42206067423667, 61.92459560209706, 66.75016603162213, 71.74049562023532, 66.24562371161677, 61.48769847808346, 67.50047622188445, 68.32013391679334, 67.96860325721003, 63.302465408079094, 64.37099356805125, 63.03153945553688, 63.4854910450597, 60.589381571738954, 61.47925753747264, 59.16112107615317, 63.129924266569084, 61.34389654282601, 65.24540755056566, 67.4171729241648, 73.08233845618464, 35.033390522003174, 28.341066068218602, 63.193196019818714, 60.04521546825286, 69.5650000726023, 64.87110753213206, 67.33892948396745, 61.40471681471794, 60.97173029376615, 56.90977473412791, 58.174899931876894, 57.36442842791158, 56.404365570314475, 56.154377229752086, 58.665239349488296, 63.534085289124526, 69.62993883317517, 63.12256982249599, 59.71523431039626, 62.38176745753135, 68.96454011240314, 63.682292046085486, 57.82185523740707, 54.80399931630781, 58.715732020716516, 65.4422007068511, 71.23821258544922, 71.8212023089009, 69.13431598294166, 63.13030473647579, 60.73039470180389, 65.29821049782538, 70.75234074746409, 61.57117828246086, 31.213105916976932, 5.963676043095128, 0.8644182511395024, 1.266837434903268, 2.032845808613685, 2.7508008576208547, 1.3164235483254156, 0.2995572016844827, 0.07035710127843965, 0.10049851656320596, 0.05737722378164049, 0.05865493586527244, 0.5761795695270262, 7.104309624241245, 41.97390687081122, 52.69457217185728, 48.42405242304648, 36.63126999332059, 26.48808152444901, 45.54908844732469, 55.31680214789606, 70.08265879846388, 70.70883381751277, 77.17788911634877, 71.84597599890925, 3.63213635260059, 0.34568114927218807, 0.07598912688873469, 0.01760760205797851, 0.026763651272161838, 0.058499194020705844, 0.026545438787809787, 0.049513641504510764, 0.02543325340675731, 0.0174040716486953, 0.10388648678218165, 0.015767250104897445, 0.06425701509860736, 0.06896069919269893, 0.029617175572521748, 0.019133781353312156, 0.07018195825719065, 0.012996187508707086, 0.03747768775229493, 0.03704399771748051, 0.02805255973080714, 0.0675560616617722, 0.03993263182741019, 0.045933095933569056, 0.05189764583783765, 0.01629508085428707, 0.03612174660027508, 0.03111576804170205, 0.11098477403603255, 0.022958168880112713, 0.18837311455319006, 0.20604887736901162, 0.14552731848051473, 0.170157550864162, 0.19136347747858495, 0.110651035492699, 0.24774117485409786, 0.19722156797445592, 0.09171389358779115, 0.2912155767121623, 0.08239611172147336, 0.18755677126107678, 0.21082762658836382, 0.11240379869817727, 0.18955973878262505, 0.13476281787358946, 0.17616925731060967, 0.11344724109456425, 0.15128549578930103, 0.15352265638930185, 0.167069373832595, 0.1276777992625871, 0.14362348273636835, 0.11215007803853481, 0.21349428672223322, 3.4526695311069493, 63.28090413924187, 94.9661437926754, 93.49656504969444, 87.32266026158487, 76.36286766298356, 42.32802237233808, 34.8105606725139, 42.70090249276931, 40.758838961201334, 45.406027840029815, 35.91107183887113, 55.42631080073696, 46.320257802163404, 10.808365575728878, 0.8072931583850615, 0.1459958118897292, 0.17523896610063894, 0.9231331908414442, 2.2512742684733484, 3.7191732564280113, 4.610183767734036, 7.418273783499195, 10.707653818591949, 13.335854622625536, 11.178373540601424, 10.533025976150267, 16.398348096878298, 39.28180771489298, 61.88264585310414, 69.02263825939548, 75.57964094223516, 72.12520953147643, 72.71472607889484, 68.65817946772422, 62.95591615861463, 63.51931756542575, 70.41688396084693, 71.22419403445336, 67.92180153631395, 61.84837610490861, 62.9596737892397, 64.9742619452938, 68.4101209332866, 74.62551655307894, 66.68191679062383, 61.1488841425988, 69.92423426720404, 70.11009970018941, 70.78649674692463, 66.49287423779889, 67.86804937547254, 65.99073240833899, 65.55052872627013, 64.12404898674258, 65.14495172808248, 62.24911682067379, 65.0949062070539, 65.35445728609639, 67.97160779276203, 69.46053951017319, 70.95915163716963, 39.72306651453818, 34.18427974947038, 63.89857153738699, 61.15358314206524, 71.28877978171073, 66.36918621678507, 68.99853137231642, 63.03745438975673, 64.97006893157959, 61.2036600420552, 62.169539774617846, 59.475514734944994, 59.79376016124603, 59.64228214756135, 61.58967618019351, 66.76277252935594, 72.26668942359187, 64.20222182427683, 61.93416226294733, 64.02899819035684, 71.61906688444077, 66.30582424902147, 61.63102188417989, 57.61567584929928, 62.10500501817273, 68.88177810176727, 73.3018107568064, 74.5407227546938, 68.61919895295175, 64.91986259337395, 62.558619283860736, 67.60410524183705, 76.44652397401872, 63.94134890648627, 30.709149991312337, 6.15515781987098, 3.9097639197303407, 7.263813787891019, 8.110929544894926, 4.510494278323266, 0.6338397593748185, 0.15026751815551712, 0.2272689306447583, 0.12694528897202786, 0.22452532463977415, 0.179418956320132, 1.0767337583726453, 11.890694595152333, 60.3271044454267, 67.11931597801947, 62.841018169156975, 55.21831927760955, 37.390762452156316, 47.93297952221286, 63.518807657303356, 79.52290165808894, 81.22433170195549, 87.05557038707119, 78.04707850179365, 3.6576410743498036, 0.38415675081553, 0.17797463543472752, 0.3015530752318521, 0.17298954809384962, 0.26998982374225894, 0.06615858705293748, 0.13987195017116685, 0.13533136236571497, 0.18966334451350475, 0.20248324369951604, 0.2130181783990514, 0.13168833849410858, 0.09803886870823561, 0.18471533582816202, 0.23573214909242046, 0.18712160267656852, 0.12064002529387513, 0.15620961785316467, 0.15181529155421644, 0.1327481138850412, 0.1371538242505443, 0.1389666947145616, 0.11775995604693891, 0.11741723895313279, 0.1102231294217129, 0.18737695510348967, 0.09459301288570128, 0.17284517116363973, 0.15502636441059653], [0.0774825310274478, 0.025678866940941063, 0.06433949595497501, 0.026997210412857034, 0.053952557951091766, 0.01667252662892063, 0.03224135421577, 0.04325757599285534, 0.018805819112927686, 0.05563314801322357, 0.033041444952569665, 0.08951012676040973, 0.07694318214611662, 0.027642779300109516, 0.07082465239950726, 0.027371136013478525, 0.0044802291743126854, 0.010325578191588003, 0.018706093617384473, 0.03942518284724605, 0.03900301094437319, 0.022253538444337827, 0.04193416293410044, 0.1246203346959045, 0.03839964009520989, 14.591636734624064, 64.72877256331905, 68.80735505011775, 68.26345566780337, 55.948805809021, 35.955335786265714, 29.147634813862464, 24.939084591404086, 42.89581291137203, 41.59391941562776, 31.60991837901454, 52.39852736073156, 35.73731868497787, 7.036726205579697, 0.2052779324472912, 0.03210527210256025, 0.0413416130768676, 0.1501560676842928, 0.3247515352502946, 1.5607900292642656, 2.3461081087589264, 5.593626893335774, 3.038205177553239, 3.0280629088801727, 3.7252323377516965, 15.82282558564217, 33.30017751263034, 53.038948428246286, 64.32523127525084, 66.81000571097097, 66.03641233136578, 68.37087369734242, 69.00408544848042, 64.4649657126396, 70.55066816268429, 64.04619386119228, 61.23940067906534, 67.39341120566091, 60.6138728510949, 60.96980048764137, 52.22433097900883, 56.00913970701156, 55.59651028725409, 64.90391031388315, 65.95663132206087, 66.9441350813835, 63.03934889454996, 65.54964227061119, 63.18639462993991, 64.68026461139803, 59.29377955775107, 56.660892501954116, 52.50781243847263, 53.70758310441048, 55.42924865599602, 58.24867971481816, 56.47826694673108, 57.00020890082083, 52.56112529385475, 62.73072111991144, 58.46508472196518, 69.63093511519894, 44.90987546982304, 31.189475597873813, 68.29935319962041, 55.207062075215006, 61.130354865904785, 60.65640703324349, 64.16959554918351, 62.10802132083524, 67.58268125595586, 64.9015059009675, 64.48468346749583, 60.98714520854335, 57.614236339446045, 57.481597469699004, 61.62763295635101, 61.48495281896284, 64.22687784318002, 59.13946174806165, 63.09226559054468, 65.52363695636873, 64.1166082505257, 55.32626682712186, 48.18783944652927, 48.19833570911039, 55.03565057631462, 62.33290649229481, 68.31180280254733, 64.91222573864844, 62.30794452851819, 68.57977128797963, 67.89664345402872, 65.35475538622948, 63.348910193289484, 69.80386457135602, 69.26493875442013, 41.87483564499886, 7.702981473938112, 1.991433669482508, 3.6357160056791002, 1.0666666276031926, 2.8853361933462085, 0.24243365642764877, 0.14840417781904822, 0.05724168750607679, 0.03826887271697483, 0.06243152333603752, 0.03196329302755335, 0.3334664595463584, 4.933898448944092, 36.47790531958304, 37.69498148272115, 33.331819272810414, 23.523038356534897, 14.580076529133706, 40.847460992874645, 49.13473882982808, 60.054374202605224, 58.38626861572266, 62.817448646791526, 40.29091588912472, 1.7387826524434553, 0.15916040467639125, 0.05938407536896487, 0.01420664664868626, 0.12376902715092707, 0.060427180686665166, 0.053313625300483364, 0.018092219702779286, 0.060771751713248036, 0.037975702359671556, 0.06081694323990134, 0.0222350814710221, 0.008779244080576445, 0.09656355190541475, 0.03483327864218624, 0.009070350788533688, 0.008398275259101104, 0.06772453205720072, 0.039085794405470935, 0.026450432393880143, 0.05748576311875255, 0.05319714929247576, 0.0555536012736059, 0.06169824695755398, 0.0968198312987243, 0.028611146995136817, 0.0394768439864199, 0.0761825640896155, 0.051288487194406415, 0.033650438887097185, 0.05165738534302481, 0.06227058358490468, 0.015645311889989723, 0.030794510985874844, 0.010881142281446486, 0.05220083662519052, 0.015189519260949908, 0.11434212372067476, 0.06034951852334123, 0.03802249501008661, 0.10787488607269143, 0.06135063456191171, 0.005886732608139996, 0.028179431551947232, 0.06519628102861105, 0.01981344881407436, 0.015997165539902786, 0.027391140484401298, 0.04587213831743406, 0.03377655994207148, 0.016483913866742965, 0.044506299309432514, 0.07193348040023158, 0.033880050759762526, 21.942599704188687, 79.99444115546443, 76.32767615779754, 77.58488209016862, 66.48748490118211, 48.02816367918446, 36.208477712446644, 29.060262057089037, 34.67278349784113, 37.699229409617764, 29.93003783687469, 39.66349355636105, 28.841776232565607, 6.136494201998557, 0.17969292468361317, 0.08849857660431056, 0.07718280678795231, 0.3349071951402772, 1.594996774388898, 3.4659433220663383, 4.649583485818678, 4.115449334344556, 1.4998066112879784, 1.980091645832985, 2.5213350932444296, 12.187428762835841, 32.96939226888841, 59.063116735027684, 68.69847005413425, 71.13996505737305, 69.76315821370771, 70.13827016276699, 71.11256337934925, 64.68197084242298, 70.02770639234974, 66.37932162131032, 62.91995586887483, 68.34405253010412, 63.20107213912472, 64.38918552091046, 53.95598288505308, 58.828617834275775, 58.96250401773761, 67.1229951612411, 67.07005885339552, 68.0884159764936, 64.3158018973566, 67.95039561487013, 66.49077969212686, 66.68701587184783, 60.799216608847345, 59.66378458084599, 55.89139015443864, 56.909511935326364, 57.551752982601045, 60.46619169173702, 57.73795181705106, 59.86809299838159, 56.602672761486424, 66.97840090720885, 61.69694515966601, 72.01044098023446, 48.34814279310165, 34.22678255265759, 66.39255569827172, 57.3140573501587, 64.18104102534633, 62.573222268012266, 66.73685350725728, 64.00127880034908, 68.80345621416646, 66.64001803244314, 67.56271639177876, 64.16784224971649, 60.94409327353201, 60.6227844761264, 64.03589371711978, 64.0345012757086, 64.23325953945037, 58.4495678255635, 65.43281447502875, 67.17786911995181, 66.80827986809516, 58.58609768652148, 49.331567287445075, 51.798055633421875, 56.90848819671139, 64.1349414087111, 71.74462979839694, 67.75774448148667, 61.79843648787468, 67.4757182213568, 68.0113806263093, 70.0993759401383, 69.09087965565344, 72.47648131462836, 71.0631807388798, 46.643480716213105, 10.021380243762847, 1.999932342479306, 0.7637023877712988, 2.503731005614804, 5.3202685809904535, 1.224892098576792, 0.7955174676833615, 0.16534422043590777, 0.02431556368396888, 0.023264242073280678, 0.05340692331834186, 0.262771007875281, 5.739208113762641, 37.74052412279191, 41.13427646698491, 29.866018872107233, 29.61326526057336, 25.875797579365393, 49.9584012646829, 56.35379837405298, 68.2039297780683, 66.16636045517461, 68.41038765445833, 60.659035021258944, 3.5262661883907938, 0.034369148103700536, 0.03842689750355579, 0.012683225269880027, 0.043857522428997105, 0.011487331376561235, 0.10021907833194542, 0.04062574604646333, 0.032266060551328045, 0.040657711065103935, 0.024132436111329064, 0.0745828346078915, 0.023878351559922583, 0.046392695061982646, 0.04942964762449265, 0.04216487031249751, 0.024914855114935387, 0.027174973454807076, 0.05376557121053339, 0.019201248801583727, 0.08893855622098332, 0.03095683544093082, 0.028353174547514612, 0.04219042317521188, 0.01214313998653163, 0.06178496428014291, 0.03039548834485393, 0.034410030385779763, 0.04751882132803721, 0.11725996876315725, 0.1491457815732687, 0.13392746027919555, 0.11671188647948927, 0.16796741274095353, 0.15193069503913004, 0.16878795419489184, 0.08667488897880239, 0.19030144978915492, 0.22122463481801175, 0.07875927784029516, 0.12984228110121143, 0.12649276083515537, 0.14910640465396066, 0.11275460568046379, 0.21340589549752975, 0.07883433913511616, 0.10912420693784954, 0.1415616030534429, 0.14847119519066426, 0.13749222060845745, 0.1321501975818988, 0.12828474008147756, 0.2452914401768677, 0.2028894541604865, 31.193968672906202, 92.91856458110195, 84.1010921232162, 88.73489395264657, 71.90406630116125, 51.91248686082902, 41.661921547305205, 36.49476366658365, 59.73032366844916, 56.431661344343624, 40.22867179686024, 67.49074874385711, 45.58945748113817, 9.940908897307612, 0.39169189970820184, 0.1457543562977545, 0.16049610961589122, 0.5557197512638185, 1.0078370811477786, 5.705059468746186, 6.729309462731885, 12.492889223560212, 9.400746553174912, 8.889194957671627, 9.754309000507478, 22.486961926183394, 37.42499689902029, 59.25256329198038, 69.40432410086356, 72.31735860147785, 70.5374183962422, 74.00085556891658, 72.65608664481871, 66.28345889429893, 68.50015501822195, 67.88278179783975, 62.89136963505899, 69.6144925394366, 67.11935520172119, 67.38932409594136, 56.8826868457179, 61.56474167300809, 61.36547742351409, 69.72545639161142, 70.24757092998874, 69.17892117654124, 65.94532705122425, 69.11035814592915, 68.72056868768507, 70.41486001783802, 64.7882866859436, 62.99998790987077, 57.103049524368785, 59.28814311181346, 61.68550360587336, 64.3164098647333, 62.29103519070534, 63.47781496663248, 57.862369398916925, 67.74833079307311, 65.62954095102126, 72.83449172973633, 52.649084444968935, 38.26395657754714, 66.04153494681081, 59.074946603467396, 65.29315456267327, 63.65873036846038, 66.64147715414724, 66.35030392677554, 71.70958734327748, 68.4642888653663, 68.65158988583472, 67.67351550440635, 64.22498333838679, 63.72196682037846, 68.61828111833142, 66.82938221962222, 66.47075207002702, 59.54694109578287, 66.69140108170049, 70.18598187354304, 71.35324785786291, 61.14738579719298, 52.290077747837195, 55.28553301288236, 58.95946418085406, 67.70293328069872, 75.12379877028927, 68.53661737134381, 61.704350594551336, 70.00208547038417, 68.73337130392753, 72.47695199904904, 69.82442563579929, 78.3525291565926, 76.62109298090782, 50.07688430047805, 10.678895981081071, 6.583004074711954, 12.291145055524765, 8.082115813609093, 8.261157793383445, 1.3562847577756452, 0.4897364144844394, 0.22765306245175101, 0.16749772423457715, 0.19736367728440993, 0.19813048533133923, 0.6190934861379286, 8.147247750912944, 51.0190886066806, 51.99347988251717, 46.19651879033735, 38.38996271933279, 26.14318947638235, 55.54726885211084, 65.5048527256135, 78.12136034811698, 74.14373182481336, 78.83123090190273, 65.17954703300231, 3.304414725111377, 0.33946839071089224, 0.19265228251536048, 0.1142713142138335, 0.15459341748106867, 0.15216252856677578, 0.11969409056849058, 0.11584986136445116, 0.18587891613283467, 0.09169857182930555, 0.12340806950364383, 0.15110486757851418, 0.08782334670784973, 0.25913359176728035, 0.1489927478495144, 0.11928687653233928, 0.13088267446765978, 0.21053334157313072, 0.22596152499318126, 0.14375391686635633, 0.19267210887084085, 0.20332307524738774, 0.13887185302953567, 0.15395610893685974, 0.1740476840566243, 0.1755060396728016, 0.11419784638189501, 0.16132952134695747, 0.17078727513792055], [0.0546911318275717, 0.05612653161909792, 0.03743345383554697, 0.03181432340023739, 0.0321769415430965, 0.0393706412174769, 0.035171085112397714, 0.09239189672253786, 0.057258215853043144, 0.021339139728356275, 0.05192470789376286, 0.029494588098098195, 0.020542737704912023, 0.059943710258531, 0.041030328570594715, 0.04191064403482503, 0.07950839691705282, 0.026673586145343802, 0.10448961248320919, 0.016320223859961958, 0.11420693984555622, 0.027490990469232205, 0.07923494949336014, 0.021170449082649524, 1.5037140274240126, 50.72533053736533, 71.90030082579582, 66.14282623414071, 56.05366253083753, 37.34861658465478, 34.29101136422927, 26.550411908857285, 27.41848145761798, 36.891276067303075, 37.28578021449428, 62.31971163903514, 39.57851932894799, 4.353098388641111, 0.22727780194292146, 0.044020775765661276, 0.09062397263703809, 0.06774245085374964, 0.1985211748509638, 1.3414669012831104, 2.2760281014826993, 3.125851274498048, 4.661648696468723, 2.2070951423337384, 2.1733554044077477, 14.627756860948379, 37.64928587021367, 59.51187902881254, 68.92281393851005, 68.72844480699109, 64.03368542271276, 66.36928819840955, 64.50962189705142, 65.22905518931728, 69.15559876349666, 64.7442384689085, 60.17208453147643, 63.589249503227975, 66.36011769694667, 57.97283511007986, 54.16100909633022, 49.49533016450944, 54.02844082924628, 60.17048028207595, 64.7153776691806, 65.28234843284854, 62.95384122479347, 63.87418223965553, 67.50021734545308, 62.482744955247455, 59.338929960804606, 54.79471506610994, 54.71562047158518, 52.059881687164314, 54.658420547362304, 53.60131432933193, 59.50545026410011, 54.80253627223354, 58.16529796969507, 52.52229382914882, 60.324146978316776, 59.07922590932539, 69.7763373774867, 41.21928991809968, 33.15537929534912, 60.91936665196573, 52.62295753725114, 59.49864495185114, 56.8137433451991, 62.31757394729122, 59.35985580567391, 62.542451274010446, 59.16079551942887, 63.12255805538547, 62.97075056260633, 63.26968616054904, 58.94358250402636, 62.82128080244988, 62.227802661157426, 61.27918135735297, 59.312222542301306, 62.97628894928963, 61.80055456776773, 57.1394451971977, 47.45958866611604, 47.65958247646209, 52.31022696341238, 62.89890058578984, 65.4369447308202, 67.63785331479966, 65.8515118014428, 69.02822371452086, 65.11271376763621, 65.12486134805988, 71.38726265199723, 66.67037717757687, 64.05499958222913, 68.29503859243086, 71.01193105020832, 53.504851479684156, 13.851213858973596, 1.0443363290640617, 2.0312786991557767, 4.36975718505921, 1.4256989427151219, 0.5504203227258498, 0.07092458090835041, 0.16818747915808233, 0.0356547930277884, 0.05938604421493027, 0.008264101662432716, 0.49965032766903605, 10.551818051645833, 50.129769617511386, 47.64721524330878, 35.17345443848641, 28.06640994164252, 22.187522303673532, 42.094417771985455, 56.36224323703397, 65.13251781463623, 65.11039956923454, 65.93388157506143, 37.05635293837517, 0.49784692605176284, 0.09397776001283238, 0.054705446180436886, 0.035501039181385315, 0.07631900434892985, 0.06001130602652988, 0.03483764151291501, 0.10827061645085774, 0.09086429441888487, 0.04171362920333782, 0.017315730219706893, 0.008300623946612882, 0.028378348196706468, 0.021600170782016172, 0.025659425544642636, 0.046528200694029374, 0.023162162772590117, 0.016127376546782833, 0.030435301934278784, 0.055923349779820254, 0.08246839977800846, 0.060639953946754824, 0.047521238335438316, 0.034516650672641494, 0.04719569693289457, 0.06296346031670129, 0.01999992036050366, 0.014519041982449353, 0.03385224559855077, 0.07829957145957217, 0.0355741661041975, 0.006053333270228318, 0.0220382294332188, 0.03278579758179765, 0.03187042401893245, 0.039683285529815385, 0.07484627692329307, 0.0731891751169197, 0.036471343163641236, 0.06602172544526477, 0.043396134485280326, 0.03899885491738397, 0.06663256565168982, 0.02596606372765476, 0.07650511774925456, 0.08365096374144478, 0.07247658311239175, 0.031330270745280775, 0.017774251079367056, 0.03099263472963245, 0.022588523795768138, 0.0482473632831487, 3.220894961587845, 65.86552250769832, 78.17177849431192, 76.13705681216332, 65.8236002152966, 51.83521616843439, 44.37699010295253, 32.02194375376548, 33.23769807815552, 40.060351125655636, 33.972612965491514, 47.47921228408814, 29.83113527297974, 3.565757346730079, 0.06398934780830337, 0.03642760720404406, 0.22967919647212953, 0.22967479912744415, 1.5571141555424661, 2.5330352783203125, 3.3786894621387606, 2.8134818038632794, 3.4579056501388554, 2.8409820314376586, 3.4502930650787973, 15.334256137571028, 42.14400829807405, 62.935382550762554, 71.98756571738951, 71.09397134473248, 68.57590383098972, 68.32666858550041, 68.01441654082268, 68.28556214609455, 69.4256539498606, 64.37061309814453, 63.596203865543494, 64.70766236705165, 68.44032318361344, 62.12065919753044, 54.9172067642212, 49.97769148119035, 57.46528825452251, 61.35489094641901, 66.55469079171458, 66.93829074982675, 62.808325213770715, 64.46234164699432, 67.62792187352335, 64.25316164570471, 62.01246453869728, 55.79664922529652, 55.9823146174031, 52.78457880020142, 58.527199376013975, 56.27030288019488, 62.877351084063136, 57.86646043100665, 58.94711263718144, 54.58802184750957, 62.70040512084962, 62.65875347198979, 70.69560758529171, 44.7214134277836, 35.43275840820805, 62.752839365313136, 52.65768620275682, 60.17019394905337, 57.594377379263605, 61.46082632003292, 61.558410967549975, 62.53358279505084, 59.951953272665705, 66.09531064187327, 63.996481741628344, 65.01099494195753, 62.162730539998705, 63.873715477605025, 64.00753890314411, 61.81408674486222, 60.229782596711196, 65.2122203765377, 63.47703049259802, 59.639603168733665, 50.596402229801306, 48.98100153092415, 55.49685462828606, 65.50194624931582, 68.77409335105651, 69.58559251600697, 67.80619359785511, 65.71752755872666, 66.28424336833339, 66.18312466529109, 73.24344588864234, 69.74437790532266, 70.03306435000512, 71.80111977361864, 73.84286249837568, 56.447421427695986, 17.69944633207014, 1.9188337845187036, 1.0882727585492598, 6.368936309891363, 3.9425902357024536, 2.4312007427215576, 0.3202377452004341, 0.21424379650383227, 0.09291606174120981, 0.030984655923901067, 0.028283473952943762, 0.22895412489531503, 11.980043245900063, 44.700636632980846, 46.21882530950731, 32.77355028736976, 29.01165016235844, 33.124780885634884, 51.98577634749874, 64.20904674837666, 75.12035492927798, 72.56648402060233, 72.2713178203952, 53.99160977332823, 0.7287054076310128, 0.10241826395353965, 0.03504515557940449, 0.02168877076567902, 0.05160013176200371, 0.024363652938195778, 0.05909495378634142, 0.10001251038404242, 0.07256253051661676, 0.05330670369608749, 0.041594288026493405, 0.018274843572608886, 0.03726350489042459, 0.010354554509714006, 0.021457186216608654, 0.050055123940711065, 0.028786464301388592, 0.04084997998190023, 0.004101052519775206, 0.034795847586205894, 0.022830121114008853, 0.016472411056559895, 0.007561198276122131, 0.06266341815071721, 0.03537698273336695, 0.0410883137655835, 0.030653163933405475, 0.021124830461978432, 0.18735740453966204, 0.2248778323372526, 0.16817581929987477, 0.13840734327752746, 0.06923706541138311, 0.14895284999041788, 0.18514630625084524, 0.15356618550515946, 0.20992460810849745, 0.142608646063074, 0.10704247791680599, 0.1472825178455922, 0.08402152047041925, 0.12533701760994811, 0.1320074141145714, 0.1198423745471143, 0.172466907590147, 0.10447291942733912, 0.1811462547630072, 0.08940059916987535, 0.1920829412917937, 0.13057161212688492, 0.230232342596977, 0.2801744111122624, 5.196783542633057, 77.4372362321423, 89.83579343365085, 84.96420967963435, 73.34112075067335, 51.85712652821695, 46.52017708747618, 36.48800542277675, 39.32596968066308, 51.584317837992025, 49.144552599999216, 79.72775920744866, 50.8517877517208, 6.206150102999903, 0.3924522572948087, 0.16004273878230205, 0.43987588836781444, 0.2236855390571779, 2.043377985396693, 5.793909978482032, 7.419975111561437, 10.584273703636663, 12.364153112134627, 8.241985247981164, 7.5863816661219445, 20.012389575281453, 43.74566108949723, 65.41463036690989, 73.74540728907432, 74.1753775073636, 70.19385799284905, 70.66227528356737, 70.66698212777415, 70.03742602563673, 71.30797586133404, 67.23815594950031, 63.7041239584646, 66.47752208094444, 69.96522303550475, 63.05252413595877, 59.51368724146197, 53.392212775445756, 59.311426301156324, 65.04207580320298, 68.44787766856533, 69.10945600078952, 64.49181041409894, 68.17921100124236, 71.99621846598964, 67.318250748419, 65.92213799876552, 60.32693578350929, 58.72486329847767, 55.52082815477925, 60.960508392703154, 59.40433940579815, 65.8553243452503, 60.47236550238825, 61.990475731511275, 57.74476889641055, 64.87167235343688, 65.83638714205834, 72.92676941041024, 49.49687165598716, 39.72587100921139, 63.33752355267925, 53.96632617519748, 60.99846909123083, 58.49460055751186, 64.72766253256029, 61.16979429798742, 64.052128407263, 61.36272391965313, 67.38659412630143, 66.4746509059783, 66.85685450030913, 64.79687275425081, 68.04154365293442, 65.16814862528156, 62.376115322113044, 60.550185326607, 66.7300364278978, 68.27483054130309, 61.287794882251376, 52.270791453699914, 51.66806044117097, 57.37688587557886, 69.29059105534708, 71.74064467030188, 72.82871800084268, 68.60500781766831, 68.51766447867116, 67.52581473319762, 68.56765900888752, 76.60753726959229, 73.32518808303341, 74.0003142818328, 75.69576663355674, 76.82301659737864, 58.42262506484986, 18.703533872481316, 4.029580561384078, 11.687122602616588, 14.031905685701679, 5.517180388973606, 2.247752715503016, 0.22175985448543103, 0.7174186648861055, 0.327699288365341, 0.14389369726902054, 0.182628006704392, 0.7829245143840391, 17.789623583516768, 65.82564769252654, 65.19023549172186, 48.16433268208658, 41.41956613909814, 34.517151694143976, 58.97216089310185, 72.5187409308649, 84.29291955886349, 80.13899618579497, 83.54664940987864, 60.097108425632605, 1.2158096052946583, 0.2243787720198593, 0.1451177525544359, 0.09931841174200659, 0.19401412637483692, 0.20140702806172833, 0.16344789235341936, 0.15476811617132158, 0.2481275896031049, 0.08486027949519696, 0.17072702998355513, 0.07641108045654912, 0.1275124774885274, 0.12531645581006043, 0.10658684712384017, 0.18303043269101651, 0.07318260208252939, 0.1421871138436179, 0.07145024745935394, 0.11538249410448537, 0.20199400462931205, 0.1076293855364765, 0.1471534933173849, 0.13497908449461385, 0.10568110903184261, 0.10306988302017413, 0.06707180216307602, 0.09661245895850082], [0.080378596190243, 0.03792240562277936, 0.040969508850286086, 0.035578011865577394, 0.02899068418980366, 0.03117435653093121, 0.11119644412951124, 0.02829807941922017, 0.08035159925179136, 0.056146009404572754, 0.05842418252159992, 0.08757271338254215, 0.012870787533991521, 0.0640118478106395, 0.03003372247481058, 0.07119102628841516, 0.07420798012566182, 0.12036979543946444, 0.06081638782615624, 0.01912279182203835, 0.047225976558101755, 0.05280948198971249, 0.16109431703244487, 0.07563894043766684, 20.394585324871926, 69.41047437729375, 69.31559224282542, 66.25344491774037, 51.6350301619499, 21.722417454565726, 36.272749670090214, 46.2379821654289, 25.077079457621423, 27.116380506946197, 44.35120444143973, 33.73229718977405, 2.6033498923624716, 0.19708227786806323, 0.06606746089434432, 0.06220838490633234, 0.05773409434984769, 0.14648508160345017, 0.8309511179404875, 1.5490903344846543, 2.75195550534033, 2.422591140193324, 0.6159338331030262, 4.7219737691264, 20.286796631351596, 40.6209284259427, 66.70568635386806, 66.54037414058563, 66.67423678982642, 61.13182967708957, 58.78423229340584, 58.47586731756888, 65.99653751619401, 65.50899474851548, 62.94072874130742, 61.46257961949995, 60.07695136531707, 64.6497054253855, 62.54053715736636, 58.63005961141279, 50.072436332702644, 49.82377375325849, 56.88365567115046, 59.760372946339274, 64.70646996651926, 62.150124042264885, 61.88524246215821, 63.3218183825093, 62.04075659475019, 55.87012306336434, 53.82883141117712, 48.72044240274737, 49.7330807101342, 50.388940226647165, 54.08795495187083, 54.58933191914713, 57.729032347279215, 56.647611356550655, 55.13856572489585, 49.30387535402852, 55.68410073557208, 60.589648292910674, 66.35363794142201, 33.6429024511768, 27.501176787960915, 60.000194503415024, 55.494563964105424, 62.58006680396296, 56.6733342601407, 61.150002018097915, 58.73743841725012, 59.91783257453673, 55.87164102062103, 61.32166454868933, 56.35251575900663, 60.01103201220113, 59.20203924179078, 63.049268568715746, 57.81589715711532, 55.88313356522591, 60.211496506967855, 64.9624320768541, 58.69878738157211, 53.50599681177447, 46.36070528338033, 49.85912999799175, 57.0393737669914, 66.07393372443416, 62.64504871060772, 67.03028601984825, 61.473864278485706, 61.48385847768476, 61.648386216932735, 65.7554764901438, 65.5233859246777, 70.90017487925869, 66.72991091205229, 64.12409997755482, 67.23209196521391, 71.99103309262183, 60.30195028551164, 21.347234902843354, 1.081867160335664, 3.7095712942461816, 1.4413954101262556, 2.255680561065674, 0.5227358663274396, 0.1314376898470425, 0.11204608160281375, 0.004759955167349789, 0.04411203982008081, 0.041788874359260646, 0.443742334121658, 23.988745289464152, 35.37463672699467, 48.35866651227398, 27.138335973985736, 11.237114956302028, 23.34938914545121, 39.046838129720385, 52.36344960428054, 55.84161919932212, 56.009614313802416, 58.52194339998307, 23.753958094504572, 0.5051327286468399, 0.06464751692669046, 0.06288211327046156, 0.02822330157693115, 0.08552042512042869, 0.07480918294599942, 0.08942807874371929, 0.05671102223136733, 0.06459857923008742, 0.06646945787173125, 0.05374891645905953, 0.07787816947506321, 0.05592772031142827, 0.036540566868479216, 0.05041270314024822, 0.12172751774590825, 0.04029705602255079, 0.07924969668590254, 0.02518106492296342, 0.04485621762972686, 0.02580879545289903, 0.06313555047757204, 0.049950985778724, 0.09804852907696078, 0.02824340180884446, 0.012010067641254396, 0.08399093057960273, 0.04536152922458226, 0.051699508687541376, 0.05531768066688411, 0.06622715958303983, 0.07295884312160554, 0.07244356472285525, 0.056261546954873114, 0.054063165725599376, 0.08795270831474374, 0.062165778926423484, 0.1113984078889893, 0.04840924149198879, 0.028927422564236388, 0.06779330377016338, 0.008504440681257797, 0.08781554027190132, 0.057899711067758264, 0.09312945553251813, 0.028087478018395846, 0.08292584619935482, 0.05933978016518297, 0.03472534068409474, 0.15336260530016116, 0.06428269053538961, 28.196195287089196, 83.27053808396863, 77.44825809232651, 73.98642909142279, 59.3627191358997, 29.74239753138635, 37.09951077738116, 47.94869253712316, 24.4474115679341, 29.169580474976573, 47.646866152363444, 28.44291433211296, 2.2042759387723865, 0.1811154580284511, 0.07980647406751111, 0.08269764392847016, 0.24538361587591712, 1.018246377427732, 2.666956272817427, 3.246676700730478, 2.726475053256558, 4.236977600282239, 2.2321958599552034, 6.366768710074886, 21.070723495175763, 43.64062393865278, 68.31268925820628, 70.21033194757277, 69.15682254299041, 63.850071430206306, 59.75698009614022, 60.8567617016454, 67.8198826697565, 68.81869069991573, 64.06531933815249, 60.744683896341634, 61.297938131516986, 66.40547598561933, 66.52464543619465, 60.90157085849393, 51.52827501296998, 50.92074694172029, 58.248114893513346, 63.36772580300609, 67.37183816971319, 62.47730070544828, 63.0796237914793, 64.85398246395972, 64.37869318069951, 60.19731321642476, 56.04561382724393, 52.00744352033062, 53.499701407647905, 53.38656456239762, 55.226281689059356, 58.23947783439391, 58.76285929833689, 57.78034871624362, 57.74927962210871, 52.87516593933106, 59.80427603567801, 60.93694279270788, 68.88044449590868, 37.518718011917606, 31.706453792510498, 62.8764214823323, 54.95633632906022, 61.43385218035791, 58.25772862280569, 61.56764814930578, 58.90583753585816, 59.10048515565934, 56.716574468920314, 61.62112574423514, 56.804859176758804, 62.3926559571297, 59.73698385300175, 63.94773060275663, 58.608282612216094, 56.661229825788936, 61.5916177534288, 67.57536211321431, 62.417849340746486, 54.63898520315848, 48.052207808340754, 52.105306656129905, 61.43601340632285, 69.71382264168032, 65.9117986309913, 67.90614343458607, 60.652363069595836, 61.32340608104583, 64.35859887830674, 67.14519577641641, 68.30368349629065, 73.80183450637325, 68.40815974820045, 69.43215723960631, 70.03321340007167, 75.08699909333261, 62.04365130393737, 25.012158347714333, 2.0898976633625646, 1.7757671710944947, 4.257110636080466, 4.867387308228401, 2.6018289933281564, 1.2009023923066355, 0.3072729634661829, 0.2869817458333508, 0.029285407790373412, 0.11229917407035829, 0.49358137913288613, 25.024645213157903, 39.583861597122684, 45.62181311268961, 22.492641518192908, 18.01503239139434, 36.412217386307255, 53.09264175353512, 60.40112349294848, 66.47710630970617, 63.83521741436374, 69.98350128050774, 41.434365241758286, 0.4400497903266261, 0.061067339077952414, 0.023639960319644982, 0.021935642599278403, 0.015615289861847077, 0.04186000562303009, 0.03889786920720532, 0.014273147868563332, 0.030972526836839896, 0.03682560520246625, 0.023223208488836404, 0.016252128219592477, 0.04047552003495155, 0.05358477062996357, 0.022913387210498896, 0.06314988398263532, 0.050190824925178484, 0.04775839617415782, 0.05596787480997944, 0.022338013044528426, 0.07950164002156065, 0.06778494575090947, 0.017466071144407316, 0.021740322737323663, 0.08259635944400104, 0.016399345420781645, 0.04615652930712508, 0.15397414264659728, 0.2229933786175905, 0.12718621596333482, 0.09882544182361135, 0.21322146749063847, 0.2334794981945907, 0.23083013632605154, 0.21014635991905967, 0.1316459431883789, 0.12698573075355063, 0.31445252498792065, 0.1813650494741817, 0.21437456771250696, 0.11620679705013191, 0.17453105489332832, 0.13581746047542942, 0.22157361851103846, 0.2530072785673603, 0.2764501206336483, 0.21576305610998986, 0.2791382005858806, 0.13015080003007767, 0.21484439411470968, 0.1367125882496757, 35.809356935562626, 96.35774581663071, 88.09417478499874, 84.9338113107989, 66.78163128514444, 33.102403763801824, 46.60148389877812, 59.82526856084024, 35.092614389234974, 40.58982403047624, 58.99177274396343, 43.404375660804014, 4.37137859482919, 0.4167139554216016, 0.27739715852564384, 0.17960214326458593, 0.2922386411697634, 0.9216282264359537, 3.0843349474091686, 7.575833922432316, 8.05876692456584, 10.310020600595783, 8.307284866609882, 10.728626731903324, 24.40987252419995, 45.99956873924502, 70.36454385326755, 72.49348871169552, 72.11658031709733, 64.25002767193702, 61.82202954446117, 62.32107270148493, 70.55166444470807, 71.44178359739243, 62.80825853347779, 62.424889995205795, 64.32877709788661, 67.79154746763169, 69.5878988696683, 64.38421587790212, 53.68529619709138, 54.050123691558845, 60.228986355566214, 64.65985651939147, 69.11360586843183, 64.00873914841684, 63.87431560024139, 66.42582524207332, 66.91393283105666, 61.60214931734147, 59.35737294535483, 55.19755032754714, 54.39420184781475, 56.47315217602638, 59.03181622105261, 60.6583603735893, 62.05440252057968, 60.65519502086025, 60.225452300040956, 55.80236019626741, 61.477237516833895, 65.12173129666236, 73.02092198402651, 41.38803420528289, 35.10494632105674, 63.73116477843254, 56.45554073395268, 64.36408235180762, 60.43146302623134, 62.172964003778276, 60.23888249551097, 63.11306984193864, 58.32854701626686, 63.131720712108, 56.80096426317769, 62.45001669852965, 61.93213047519807, 65.88866449171498, 59.08469761571577, 57.87602316948676, 63.60281305928385, 69.50282266063076, 64.740994668776, 58.83598012308921, 51.14228633142287, 54.87666122374996, 63.91611237679759, 72.41074239054035, 67.8219066127654, 68.35609420653313, 60.55754761542044, 61.19142616948774, 65.06405284327846, 69.89099610236384, 70.40067672729492, 76.1751038028348, 72.43913250584757, 72.96301995554279, 74.11891106636294, 78.81759674318376, 66.22827899071478, 28.380644744442357, 4.629534290682885, 13.090834944478928, 9.679178941634394, 9.260821880832795, 2.112975173419522, 0.5935795713336237, 0.28993201171678884, 0.3064853025059546, 0.12112176436330042, 0.22230124882152005, 0.9014709822593198, 36.523585242609826, 50.83217197848905, 67.96555165321597, 39.63271863998906, 20.24821815952178, 34.738757764139486, 55.43172759394492, 67.32327138223957, 75.4617109606343, 72.11508981643185, 80.62515827917284, 45.39100908464002, 0.8008471107290638, 0.2634933062138096, 0.17743998267237218, 0.15175830993440845, 0.18975054064104635, 0.19505271177378394, 0.22542935435570058, 0.17925853750878767, 0.18522319083492603, 0.17613974760376638, 0.12465113909133982, 0.1289467856047615, 0.17819313903249082, 0.10550398184286972, 0.0786918314594415, 0.11684052796373445, 0.12419910125073888, 0.16225733043205354, 0.16293096686563185, 0.206248642456147, 0.18804521359983953, 0.17105004329594875, 0.1535483509782822, 0.19906359574487134, 0.19616660361568775, 0.18481080570528585, 0.12799632329974445], [0.0107666916183887, 0.07820479106158018, 0.05087391488374241, 0.027004886613858324, 0.0419628452659855, 0.06913290809719794, 0.02731868771896247, 0.034627105229564255, 0.022357140344777898, 0.032844522051633365, 0.049148772978374076, 0.03839651445647882, 0.06540340055981952, 0.035604323155336806, 0.05744939692498696, 0.045107222507677736, 0.027146486475342707, 0.03099116958647726, 0.05328416921979478, 0.04652864885546508, 0.08541704921592629, 0.10002978566673495, 0.11539895733397816, 2.2290971875190735, 50.07984176758797, 68.47050974445959, 68.56367388079244, 67.97648722125639, 39.693197665675996, 43.6689159947057, 46.32800448325373, 29.72678061454527, 56.39773676472326, 45.694376960877456, 35.850149585354714, 2.945404595905735, 0.20960271328447327, 0.044174893503828395, 0.13564645432897154, 0.04560985279479816, 0.36035262168415133, 1.0155118112602541, 1.6708328598929991, 1.0412915892178014, 1.9510496816327496, 2.3143628960655582, 6.061515644673379, 24.024954649709887, 44.165939131090724, 63.302214376388065, 68.2321394643476, 64.22739559604277, 65.36006235307264, 56.14827009939379, 57.121002212647475, 61.4469725085843, 64.75685281138267, 64.5028361966533, 66.2629762772591, 56.35463383889968, 62.352816443289484, 65.51853787514472, 61.31922091207197, 56.0432800169914, 47.61870745689639, 50.66995843764275, 59.88640654471613, 64.19300033200172, 63.72036649334816, 60.35331372291812, 63.6121992911062, 61.82380637814922, 60.924355906824914, 51.95789221794375, 47.85527344672911, 45.98751529570549, 50.04191244802168, 51.01589187499016, 56.02256205774123, 55.0618794656569, 59.545042668619466, 53.17309348813949, 57.19492320091494, 47.91616039891397, 56.56863835550124, 56.84008990564654, 67.6463334791122, 35.88688650438863, 29.520093279500163, 60.129985732416955, 55.496415322826756, 64.45870560984459, 59.31960052059543, 65.03397610879713, 60.00290093883392, 56.65373809875981, 59.55583703133368, 61.261609138980994, 56.05467450234198, 58.71967792510987, 54.89734780403876, 58.912019191249726, 55.31716692832209, 58.449430542607466, 62.79018817409393, 61.37762500393776, 54.460960588147564, 46.602405655768614, 44.90426255810646, 50.67023300355481, 61.024815651678274, 65.0871124575215, 64.74665464893465, 61.22562139264999, 60.71919241259175, 67.37459167357414, 65.05847131052326, 65.51279944758262, 64.16035444505754, 65.12132337016445, 70.81807967155211, 68.47680122621598, 64.56031853152861, 65.14996843953287, 63.56163993958504, 61.68656656819006, 28.4499785207933, 3.4476817471365777, 3.5044457979740637, 3.162612953493672, 1.7673739117960778, 0.3904174051938519, 0.10403318495880212, 0.04883074689836753, 0.05378818229561853, 0.054380509987353325, 0.08077156865188191, 3.0698829745092704, 37.42795828850039, 35.29463214258994, 51.270379174140196, 34.28063669512349, 21.069036876001668, 21.09204353824739, 47.50222875225929, 48.94844585849393, 57.04957977417977, 54.14133056517571, 60.29498807845577, 16.8411454462236, 0.7147930670649775, 0.13584226640241762, 0.0756857713924781, 0.05922546835556146, 0.03289422200572106, 0.03698426967246398, 0.08422988872494429, 0.05216745051345037, 0.014632070594797692, 0.04379287992994632, 0.013824592855188155, 0.01639793964944059, 0.07291195087976034, 0.006747769948560745, 0.03121816909932081, 0.010410304643183706, 0.044748172419325966, 0.0013869467652365265, 0.01349885610022372, 0.04598797081158527, 0.04172321679371019, 0.055637189127024145, 0.06042507011443377, 0.06607473106874574, 0.024660906544135466, 0.06080138399415921, 0.016413475912544998, 0.11813045914975867, 0.11245951627291019, 0.06091550811223927, 0.08161736036380453, 0.03234129038549239, 0.04490423985126038, 0.054750790924675045, 0.03614774762442516, 0.03511006237878915, 0.0576147570034429, 0.035957727175686634, 0.06649150588219205, 0.043080326229814565, 0.042046517389075416, 0.09653703760235541, 0.07614995938755813, 0.00854106447208793, 0.04559679865656842, 0.07497874884715966, 0.02500141538949984, 0.11391677638335575, 0.13245678596919583, 3.888440444584816, 63.511088432804236, 76.61090266320014, 76.1330795288086, 75.35088831378569, 50.91722857567572, 40.65561002300632, 50.808543620571015, 36.4893154944143, 34.37681713411885, 47.75847327324652, 34.05545342353083, 3.5775543653195907, 0.10364819513333422, 0.07296473433774325, 0.16219782072209543, 0.15387125703836643, 1.8499917753281134, 3.694190455059852, 4.291628474189389, 3.587955020127758, 3.794434469553732, 1.0053942412618668, 8.02345137442312, 25.551356769377186, 48.62495230090234, 66.17106729938139, 69.86368071648383, 67.60514074756254, 68.24400855648902, 56.720834162927446, 59.841938634072584, 63.62628844476516, 68.69461044188469, 64.73261256371775, 64.78572145585092, 56.88254171802152, 64.51400318453389, 67.17652766935288, 65.1091875568513, 59.96315556187784, 50.044175655611106, 52.19006515318348, 62.22326447886806, 65.21015328745689, 65.71926909108316, 61.91168315948979, 64.65985651939147, 63.685606448881096, 62.623875756417554, 54.69815415720786, 50.48687788747972, 50.24789179525068, 51.8260770459329, 52.90104181535783, 58.62641965189288, 56.19748800031601, 61.25252492966191, 56.69504850141464, 58.66676122911515, 50.87316074678975, 58.4998094651007, 59.14227800984537, 71.57829776886972, 39.71411958817513, 31.60867891004009, 60.80370380032448, 58.33665847778321, 65.62761506726666, 59.9502117403092, 63.61885555328862, 61.932993396635986, 59.201866657503196, 60.88809359458185, 60.964642570864775, 57.268765741778964, 60.173661324285696, 55.74415222291024, 60.05566466239191, 55.55123044598488, 59.406320202735166, 64.12358222469207, 65.43732912309709, 56.79218599873205, 48.59192986642161, 47.51799275798183, 52.81641275651994, 65.35100560034475, 67.73745798295545, 64.53554091915008, 59.84526480397871, 60.16710704372775, 69.75047326857045, 66.70550592484014, 67.75471641171363, 67.23627321181759, 67.53362809458088, 72.60847691566714, 71.16546830823346, 67.74641667642902, 69.57018544597011, 65.71086737417406, 63.623028955151966, 30.796491369124386, 4.548171585605991, 0.9993781221489754, 2.714669944778566, 3.6110845015894983, 2.2570810923653264, 0.9852053729757186, 0.6433481362558181, 0.22807591234243688, 0.08281411993647776, 0.10223688497658699, 2.503970515343451, 39.0667284688642, 41.04870603930566, 46.473532261387, 24.554268698538504, 31.382552308420983, 39.925888353778475, 62.151583163968986, 60.08214066105505, 67.34561320274108, 60.19570896702429, 72.77101993560791, 28.09925194709532, 0.6984690204262735, 0.1027185550980991, 0.11332375538204947, 0.03735256644206182, 0.04087781961706858, 0.03651631635523612, 0.07552084798413901, 0.027748947595095927, 0.03602043147228899, 0.03045119059782836, 0.011811401890290361, 0.04893064859413332, 0.03883955459440908, 0.008998890106956805, 0.02535778417011663, 0.048647196062149546, 0.020198118797833883, 0.04805821234420423, 0.030083098756750266, 0.05868440343727989, 0.037321723742230285, 0.05754185224612875, 0.03576068170068245, 0.08977762168093074, 0.031537666068141984, 0.011952603386054117, 0.13101174496114254, 0.19671818692116969, 0.1884565415281442, 0.09824295453126393, 0.16878478259088533, 0.14235179210382123, 0.17814414004885382, 0.14674561278473947, 0.13876657722698105, 0.1658366311101183, 0.16206878087212964, 0.0908658036120957, 0.27297732149881704, 0.1439594429346823, 0.1201622162555014, 0.2878551779975814, 0.10205002081009651, 0.1735739965712832, 0.1618299912661314, 0.15329358077818347, 0.18585910509911277, 0.20914814735372222, 0.49342086839099086, 5.7693696694989365, 79.35362000619212, 85.96657922191005, 87.85451796747024, 84.70370938701015, 56.18385776396721, 56.70854145480741, 55.84708306097216, 40.91974243041008, 72.11946718154415, 62.80607377329181, 47.74729451825542, 4.698082122110552, 0.5501008334179078, 0.18021637724051554, 0.6430616806591711, 0.1450335288480405, 1.490807100649803, 3.725386045632824, 6.001320010231388, 7.520362292566608, 10.32430979513353, 7.552638496122054, 11.754673661724215, 29.845277378636023, 49.05429101759388, 67.81006889958536, 73.24304580688477, 70.52121900743055, 70.25274061387586, 59.4071517452117, 62.321668901751124, 66.6615753789102, 70.60088234563028, 67.84256181409283, 65.72696870373142, 58.032717935500614, 65.78975016070952, 68.86029920270367, 68.20520062600413, 60.99587248217676, 53.46983255878572, 55.21639731622512, 65.30647885414862, 68.27403037778794, 67.09997869306996, 62.1417772385382, 66.58431253125592, 65.7994854834772, 65.50027924199259, 56.90885689950759, 51.875165508639434, 51.83794221570415, 54.28721920136483, 57.4388514795611, 63.05419898802235, 59.67805416353288, 64.61485908877465, 58.59731174284413, 63.4841025260187, 53.73734997164819, 61.13706211889944, 60.97980645395095, 71.7820413651005, 43.53829322322723, 35.88907910931495, 60.192849559168664, 60.2132615735454, 66.78992317568871, 63.119796706784165, 66.94611980069068, 64.24424217593285, 61.640776818798436, 64.02901387983754, 63.554022696710405, 58.08669367144185, 60.674045931908395, 57.06877977617326, 59.42520641511487, 56.72433683949133, 59.11291906910559, 65.99198756679412, 66.1876432357296, 60.96887873065088, 50.80053414067915, 50.569290807170255, 55.901325518085116, 68.59698264829575, 69.7225695271646, 65.90173382912913, 59.23581477134459, 60.79751037782239, 71.91318188944172, 70.63102183803436, 71.04159201345136, 70.89641724863361, 71.96753025054932, 75.1466348094325, 73.43615193520823, 69.21859202846404, 71.47378229325818, 69.63559489096366, 66.20077533106651, 33.65130024571573, 7.7363034794407515, 11.19293337868106, 10.789808842443652, 11.192214604346983, 1.816822129391855, 0.7034571721188484, 0.4351307397648212, 0.27054070224685056, 0.16016056310505639, 0.19929377452260066, 4.898517689397258, 53.91163264551471, 52.403410711596095, 68.72641301924183, 45.55231263560634, 36.10447606732769, 33.436181775985226, 63.928236423000214, 63.80850607349027, 76.18530196528282, 69.13800301090365, 85.47502779191541, 30.703674362551784, 1.0237925475643528, 0.2755061470933499, 0.24851541395389268, 0.17522583535361677, 0.16729630439752535, 0.12522564374751624, 0.2185347928635536, 0.19596431043840226, 0.10021633573717649, 0.15377347357571125, 0.14364358488350146, 0.12295805413516299, 0.15389076163691862, 0.08022537860538691, 0.11722065313088319, 0.23732116866496303, 0.1544402611832465, 0.12784928038355806, 0.1204262178150877, 0.13094146405496906, 0.17405422644749766, 0.22336126936058845, 0.12644209177984347, 0.2332743398484684, 0.12803292698076657, 0.22107524767277703], [0.06882733860684019, 0.055911663108535355, 0.027699841359149546, 0.0337495744949387, 0.011952914609273356, 0.04203334833765703, 0.051673875385594946, 0.06850231048320571, 0.1025902506925406, 0.05181609194785838, 0.057663039694870674, 0.06628208042633149, 0.06884529570778532, 0.017906198233005502, 0.08112796807601567, 0.11682747382550471, 0.09623178220804661, 0.019833405404501868, 0.06942234377587034, 0.019163848389120355, 0.09603351865324283, 0.06784338293777359, 0.08174366527988065, 19.23921588928469, 68.14825565584245, 67.6391790759179, 58.23089176608671, 49.276803155099195, 30.866525288551088, 30.874913277164584, 22.018850580338512, 43.44658820859848, 52.59268076189103, 35.67756137540264, 13.940549762018266, 0.2873567305505276, 0.05043567428665777, 0.05703276766824627, 0.08487128051778964, 0.2557964974473561, 0.840331711355717, 2.887568267122392, 2.862293004028259, 2.676062055172459, 2.2930453044752923, 5.712420286670809, 26.734445594972183, 50.19952897102603, 66.46573928094679, 66.15590341629522, 69.15826597521382, 62.183927028409904, 58.47771867629021, 49.116527265118016, 56.36190199082898, 60.28642946673978, 65.64801531453287, 63.372620920981134, 63.81842574765606, 55.251941834726644, 57.762086160721324, 61.64846466433618, 61.97166796653502, 58.373881770718484, 49.78987270785917, 50.117861301668235, 60.77442722935831, 59.38768894441667, 62.72313525599819, 58.82522106170655, 62.65805921246929, 61.46446627955283, 60.35407858510172, 47.87794866869527, 46.680045050959436, 46.823862675697576, 50.76138104161909, 50.135441364780554, 53.032064668593875, 55.62177427353398, 57.80595394872851, 51.04712178630214, 55.332573998358946, 45.240531275349284, 54.26776424531014, 55.18336703700405, 69.00232822664323, 36.77537787345148, 36.486275657530754, 65.24201470036661, 57.725965053804465, 62.36232819095735, 55.31648443591211, 60.38127629987655, 57.364302912066066, 59.52741553706508, 59.77997303009034, 63.91779115123134, 60.05157363030219, 63.33126737225441, 57.77666561065182, 58.68876180341167, 53.92339975603166, 64.30935744316348, 61.61004897086852, 60.177991620955936, 49.555475788731734, 45.7391704282453, 44.1641152289606, 51.86550863327519, 62.577803596373535, 62.811992629881836, 60.89489106209048, 56.912630219613355, 63.86723572208036, 64.43693253301805, 62.638545420862016, 62.95225658724385, 65.6850738679209, 65.34846390447309, 65.17432243593278, 66.94755538817375, 65.21044354284963, 64.60083661540862, 57.92883003911665, 57.64483867153045, 61.24562940289898, 31.759374410875385, 3.060326364732558, 3.065395292735869, 4.117211949440741, 3.6292548814127525, 0.42675436504425546, 0.31628273968254367, 0.18313333362100587, 0.03465576457881159, 0.10642684199997496, 0.045677456223676284, 7.913611281302668, 39.32809952766665, 29.543405886619325, 44.45059337923604, 26.913478259117376, 16.662840381745372, 19.46652312432566, 36.41773616113971, 46.37869327299057, 56.54491586069907, 54.05589349808232, 59.4524198193704, 7.15672915981662, 0.481250029537947, 0.08854114811026281, 0.018905609725944458, 0.03025502037827767, 0.06442081618813739, 0.08841658221377481, 0.02387045702386287, 0.07956674217336601, 0.07251955298406464, 0.013485798131554358, 0.05714040685204729, 0.01317461321671163, 0.0391703168861568, 0.07003839338018049, 0.04904058604170719, 0.008168474737284406, 0.007377297912288698, 0.03449158810619866, 0.1075667808313043, 0.09001625806934412, 0.07904325897294669, 0.014920284363230871, 0.10945255988307538, 0.04479914790980759, 0.09810655257634579, 0.0184016483610556, 0.0652539368057924, 0.018209996145038355, 0.032893183956583666, 0.011743678760174061, 0.038446612776287144, 0.027952217534484885, 0.030700686282568404, 0.04456552556685863, 0.03544242579429861, 0.030563600594177846, 0.052145716599038536, 0.05631772035192098, 0.07403676713546438, 0.027890367425918102, 0.04837280251987038, 0.05961082973367265, 0.03978125285357237, 0.08666614025470712, 0.031920593201873765, 0.03229274722417036, 0.00494170569694571, 0.14629889159433304, 27.92313164280307, 77.83742781608336, 75.11242389678955, 67.53572264025289, 61.26184448119133, 40.374160351291785, 36.70278656867243, 33.68253407939788, 33.22721358268492, 58.2224194465145, 41.091565778178555, 12.518526815599012, 0.11109825464025622, 0.019539369367844155, 0.12681511531193412, 0.18338960535343618, 1.0142622299252018, 3.1698720349419505, 5.013155331534724, 3.7861021295670545, 2.785691075748013, 1.8285056443945056, 7.104954854134591, 28.946389767431445, 51.10094454980666, 65.69062402171474, 67.44097386637043, 70.85553046195739, 64.86696943160027, 61.268473286782545, 50.581426620483406, 60.04719626518988, 64.14247628181212, 67.85232067108154, 63.21067410130655, 62.30857603011593, 56.30749871653896, 59.14208581370693, 63.897375214484434, 63.8362725319401, 59.41355697570309, 52.27900097447058, 52.29281556221747, 61.77481205232682, 61.54330592001639, 64.18987812534456, 59.07113798203007, 62.33070604262814, 62.9255570134809, 62.25931890549199, 49.81118686737553, 49.56683889512093, 49.153358321036066, 54.139745927626095, 52.57684223113522, 56.16891745598086, 57.01019133290937, 61.8031668663025, 55.4856562614441, 57.28895418105587, 46.787584673973825, 56.08110735493322, 58.58392077107584, 71.34720740779754, 38.83733257170647, 38.24624315384896, 68.02252800233903, 59.04230856126355, 64.75974752056983, 58.44417848894673, 62.909177195641306, 57.89138709345172, 61.827830729946015, 62.08715431151852, 64.35915193250104, 63.53077480869909, 63.72232767843432, 58.206114153708185, 57.08677953289401, 53.29783270435949, 64.48815476509833, 64.3064627339763, 62.123385244800204, 53.154262188942205, 47.705878211605935, 47.2827172279358, 54.2602607511705, 65.22335206308674, 63.68725776672364, 61.08487498375678, 56.95300709816718, 64.07610585612636, 67.75872507402974, 64.60921872046687, 65.2938566669341, 68.35111279641428, 67.45252916889807, 67.11777840891193, 67.06135903635334, 68.1880049551687, 67.28170210315336, 64.07057923655357, 62.890863649306766, 64.12528061097669, 36.23449087142944, 4.873420894145966, 0.6646857687061833, 3.8702001975428675, 4.070559033463079, 1.7974578781474022, 1.7041678582468343, 0.484912665260415, 0.04273166812415566, 0.05727235400568574, 0.04188825128479831, 9.015708065802052, 41.72814292292441, 37.286490163495465, 46.32125800655734, 22.858324089357932, 20.333976860969297, 29.571384153058453, 45.583169921751946, 51.96976523245535, 66.74599262975877, 60.53741801169611, 71.32969794734832, 11.50237798690796, 0.5833066387041923, 0.014508923876189418, 0.05943648727430452, 0.03441115653502845, 0.06322117612486886, 0.1077574218112615, 0.04845862351958791, 0.06828551526151358, 0.08775313474958943, 0.055741924837592154, 0.12104042114750033, 0.0303703376782998, 0.06415023393328152, 0.036182210089698914, 0.03829992226054592, 0.08344732991029179, 0.055675482031919306, 0.09099754775243421, 0.05451706515985632, 0.040930859714506135, 0.06176291243924249, 0.08305244222884217, 0.08831010365317907, 0.0386170405263622, 0.07309220370746429, 0.13974713912654307, 0.16541399572405124, 0.08374303984906405, 0.10244293198470147, 0.0894182728182885, 0.19044571946705544, 0.12445169576113263, 0.10819224565620385, 0.22142292901633248, 0.09421703225422291, 0.09320719813507411, 0.12339047246402311, 0.1363732572644949, 0.2028613540554239, 0.12570203552323003, 0.23761182242343504, 0.23024188805251355, 0.13887557621684768, 0.26794102884108023, 0.1321067450748336, 0.15318058280935212, 0.20250434176095072, 0.22368176990459043, 37.71730761374197, 89.66077727656211, 86.78497391362345, 77.33826698795443, 66.82300444572203, 45.89447275284798, 40.92789311562815, 30.01615543519297, 59.570946001237445, 67.12957689839025, 50.21693644985076, 18.112373851960708, 0.5033416457233891, 0.12388208640679238, 0.3326387168659318, 0.29434712964200205, 0.6108216977407855, 2.7260720297213528, 9.393198932370833, 11.39579934458579, 8.701730178248498, 8.138474879726287, 10.58269004667959, 31.878908641876716, 54.6422407704015, 68.2911083775182, 67.65295443996307, 73.77858269599177, 68.58297194204023, 62.79923315971129, 53.38445040487474, 63.672525344356416, 64.98082799296226, 69.48487389472224, 66.32182751932453, 62.382748050074426, 56.5948123316611, 59.213884799711174, 65.35165279142319, 68.55042411435035, 64.1858498511776, 54.192038966763405, 54.22601061482584, 66.17510734065887, 63.101577297333755, 65.80718117375528, 61.135614764305856, 64.97311269083332, 65.79522971184024, 66.27614759629773, 52.372675018925825, 51.90495983246834, 51.40256697131742, 57.712166155538256, 55.74471312184488, 57.14734092835457, 59.225793115554325, 64.68217480567195, 58.73898775346818, 58.96822675581902, 49.91142695949924, 57.965806222731075, 61.5959676619499, 72.30552088829779, 43.82445366151872, 41.47327515386766, 68.49478921582623, 62.34651711679275, 67.41754947170135, 61.570315361022956, 66.15011399792087, 61.38375174614691, 64.39865412250643, 65.06608463102772, 67.83217537787654, 67.2745555446994, 66.51713801968482, 59.584960629863126, 58.20820477701003, 54.881254319221746, 67.1180372853433, 66.7744690372098, 66.05266663335985, 54.98318103051955, 51.79014421278431, 48.953650843712595, 55.90598921622, 67.4062373561244, 67.05520875992315, 61.91588009557417, 57.86530725417599, 66.00314278756419, 70.48675706309658, 66.96399011919576, 67.52220615263909, 70.9446467122724, 71.38712929141137, 71.46534135264736, 69.7731210339454, 69.19035880796372, 71.81094138853013, 66.6912441868936, 66.40505236964073, 69.8769618618873, 38.451430182303156, 7.153946238179361, 9.455946068609915, 11.845828563936296, 11.28568958851599, 1.9425356868774661, 1.317452925347513, 0.6112015547771609, 0.17066068676931245, 0.328555345655449, 0.20158837639516403, 12.4075404097957, 56.607352149102, 45.64678684357674, 65.54823413971933, 38.51824383581839, 24.05805749277915, 29.8300213198508, 52.11309256092195, 61.09717161424699, 78.04754134147399, 70.72706499407369, 84.19074966061501, 12.42683356808078, 0.7139742722915066, 0.13076537108469394, 0.1988107714081003, 0.1390875221019791, 0.14059351306528817, 0.1925893254097431, 0.1425626654658587, 0.1127771593089546, 0.18417317540414874, 0.10866589483714874, 0.23193586167068253, 0.0749474005292981, 0.1600260533873112, 0.11411813493337362, 0.14804365684188184, 0.11475624020902381, 0.0990048902589948, 0.20599079258259267, 0.1996630595456208, 0.10409717628311727, 0.20081760001278695, 0.11897158538622242, 0.3403974102149087, 0.16559367398581198, 0.21854813811519455], [0.09748269653608722, 0.019701663179383166, 0.03666005743246886, 0.10187709944382792, 0.03642882528384367, 0.010195060749538243, 0.048377422030053796, 0.010595546618494536, 0.02963138841873696, 0.09936236220622256, 0.029259521679411975, 0.04590815211075448, 0.011222757166251542, 0.012137932503866333, 0.13625278227752255, 0.047552115509226445, 0.0486124309921457, 0.06016253178278285, 0.08079448234169714, 0.07243316124884353, 0.14316617421084835, 0.13616514181898487, 1.9964921786900491, 52.921798998309725, 73.94325164056593, 66.47974214246197, 58.34578583317419, 36.38776140828287, 24.492614922984956, 21.37619572301065, 24.302589816431848, 58.2651379800612, 43.52202715412263, 22.36007325110897, 0.44970847365836947, 0.011796318576671185, 0.0045399720622827456, 0.017957836389541626, 0.023966825139077923, 1.4808251588575303, 3.9601717697035883, 5.139142351765787, 4.759477511529, 2.3930130370201605, 10.714136515894245, 32.91662854533042, 58.36641750028057, 62.929040078193914, 66.9081041889806, 65.887299506895, 66.42748048228603, 59.15627694899037, 54.37741802584741, 49.47158021311606, 55.568367281267726, 62.789372321098085, 63.82213630983907, 64.00345179342455, 64.64168417838313, 61.81347093274517, 59.22170600583477, 60.142784426289225, 63.54104749618038, 56.28206606834166, 52.2636095939144, 43.84297117110222, 59.85878521396268, 62.08727198262369, 61.97934404496224, 61.469804625357355, 61.418978552664484, 56.95245012160271, 54.495348007448264, 48.11450289141748, 46.93158665011006, 47.581723428541615, 51.61705786182035, 53.17527040358513, 56.957270714544485, 57.641587026657604, 54.7071167730516, 52.7741531402834, 52.40425794355331, 43.513319492340095, 56.850982327615064, 56.23036922947053, 66.71109922470586, 34.77556136346633, 35.3431361721408, 68.09593123774376, 54.67687922139322, 59.77519166085028, 54.307117385248986, 58.182348512834125, 53.77840149787165, 57.55404364678168, 54.12958306650962, 58.836050725752315, 55.23893133286507, 59.2638244167451, 61.86358313406668, 56.6750914819779, 51.67211224955898, 65.38898198835312, 60.534503690658084, 56.59709515110139, 44.84368155079503, 44.50953091344526, 43.92640782940773, 53.74539475287161, 59.198858199581025, 62.24646529843731, 57.991034907679406, 58.67288797132431, 62.49275092155703, 65.7376257834896, 57.91690211142264, 57.40950430593183, 62.84508958939583, 67.80767625378024, 63.83813565777194, 58.718101132300596, 62.23913438858525, 58.313277229186035, 65.03400356538835, 63.509433192591516, 53.27325121048958, 59.804048538208015, 31.68481407626983, 4.330718815326691, 0.9759510308504106, 2.5733668044690163, 1.7153544579782796, 2.2996120875881565, 0.2600521005449757, 0.04379719683539964, 0.0641271785172003, 0.055465815258362604, 0.25281008753565054, 21.817419221324307, 42.01257359596991, 29.180518004202074, 55.35238981246949, 52.288065571938795, 32.170883993948664, 40.46325306738577, 44.68836745908184, 49.7316215884301, 53.26629684817407, 56.22661159884546, 48.87903167355446, 1.1177040179890971, 0.12552082508562074, 0.08122490884195413, 0.02314243217810027, 0.05982229298341179, 0.045519561672042456, 0.018302926440693198, 0.01434249223224939, 0.05055214646422575, 0.04745753429409477, 0.02195158488898268, 0.024092536337012728, 0.0523362618180052, 0.03997919848188758, 0.04949103424986524, 0.016545453709700418, 0.04966918033577743, 0.04884663939235672, 0.0058647861043291715, 0.0441113235278716, 0.06791373279186026, 0.027405054556326042, 0.047787492193522, 0.03484252149299268, 0.09068001962957845, 0.04386359367579703, 0.04356016923162726, 0.07498715283168901, 0.040136296302080154, 0.034433319458677884, 0.03374216642471091, 0.08615260087554494, 0.04021003226479215, 0.04060951264334783, 0.060237589247164235, 0.021377112791543047, 0.013910422473394824, 0.01681245833394989, 0.05273046002032296, 0.06362324205016898, 0.04729713463494855, 0.04441462539797349, 0.10619492420265753, 0.06972725443061321, 0.03941055056789229, 0.1086183360988094, 0.07699758971049901, 2.8707165391214433, 65.76308196590793, 81.86476061421057, 74.03280719634026, 65.47974171177034, 46.7507653851663, 33.53379780246366, 24.43927461101163, 24.124949593697828, 66.23296230070054, 51.23017095750379, 19.642721876021355, 0.47424427804446995, 0.013174090361703309, 0.09659826334926391, 0.3374340901932409, 0.44096627663220134, 3.993599188904609, 5.559353222770076, 3.3922736106380342, 2.4015655200327597, 2.3890215350735575, 11.038362576115517, 36.256518902317175, 58.96843464143815, 64.61856180621733, 66.67024381699102, 68.72839773854902, 68.12762398873606, 63.1358156665679, 57.19961435564103, 51.666197315339126, 57.95548254443754, 66.00517457531345, 66.36280844288488, 65.9134146475023, 65.4317868140436, 62.468247875090576, 59.33405445468042, 61.10906424060945, 65.81031906989314, 58.848159082474254, 53.3380409209959, 45.57802769445604, 61.59114706900812, 64.23946472906297, 64.93532065422305, 60.776074624830684, 63.53885096888389, 60.40531258429251, 57.46489993987545, 50.00619926760274, 48.32918990042902, 49.55558561509656, 55.830875827420144, 56.31158582625851, 59.281133836315526, 58.881283498579464, 57.4043660010061, 53.31732296174573, 53.3115178538907, 46.14606926518102, 58.73909365746283, 57.64211262426069, 69.32663763723066, 38.651408303168516, 37.72466205781506, 69.1946969493743, 56.615255724999216, 62.760327169972086, 57.123712570436545, 62.423360270838586, 56.33221357099472, 58.59803345895583, 56.265556812286384, 60.80355475025793, 58.1427090398727, 63.64692011187154, 63.21482396894886, 56.46370318628127, 51.82591622875583, 67.01169398523146, 62.74563397130659, 58.009097422322924, 46.93808601748559, 45.686340024394376, 45.38537656107257, 55.118208623701534, 62.59702713258805, 63.78228502888834, 58.87141873759609, 57.88038484511837, 62.993735651816095, 65.90133374737155, 60.94077102599606, 59.81245809985746, 66.06788542962843, 67.90167193258962, 65.84357292421403, 61.53304892201578, 63.86771817361156, 62.82459128287531, 65.24256775456091, 65.98342895507812, 60.542795581202355, 62.32288483650454, 34.40890996686874, 5.496920856737322, 0.7426239994745101, 7.302316754095017, 6.303483718825925, 2.5917031495801868, 1.8680875075440255, 0.3299246205677909, 0.06304782191892305, 0.01780218456030613, 0.1556411499698316, 24.562329169242616, 42.33506694916756, 28.362009563753684, 42.48939260359734, 32.08645889835973, 35.67528247833252, 53.12246745632541, 53.05164906286424, 56.70722353842951, 61.21978882820376, 65.65460489642236, 60.00934931539721, 2.2135481767116056, 0.10458732699795116, 0.02593078346352183, 0.017200140958471645, 0.025668103405604922, 0.0738097446399831, 0.014158475040007504, 0.005172066899361991, 0.08316094326155801, 0.06883416445024552, 0.034523859560008974, 0.04220676000019716, 0.025520991541505344, 0.02185451580331691, 0.06606549970925817, 0.02987030251402288, 0.058028023134196, 0.05125441926441366, 0.044872569776470625, 0.013404129328386439, 0.022597305078600204, 0.03773507797309468, 0.09389549749152315, 0.026427170134059368, 0.03137164906929097, 0.27208378718745324, 0.13528081588447094, 0.12747477830177353, 0.10406337648389802, 0.12065808198625043, 0.10077050075896325, 0.1675134443587834, 0.17033016579526086, 0.10843392341367661, 0.27105637135044225, 0.10262111637500987, 0.14543261469131516, 0.1271799263814765, 0.20176862156198871, 0.25026958676115163, 0.2824086912216679, 0.12557433632713172, 0.17686552398147123, 0.22130970122112384, 0.1709734191817622, 0.30418890798764847, 0.24901447427128595, 4.419397721367498, 80.33578149734005, 93.05288222528274, 84.91517220774006, 75.52290778006278, 52.448765077898585, 35.39587636147776, 33.467807846684615, 36.17660845479658, 71.2626567963631, 55.83606904552829, 30.838323447012133, 0.789559755113817, 0.17813156088513715, 0.28058564711001616, 0.5641588532636242, 0.3705283224342331, 5.6989356683146575, 11.77365303039551, 15.29396260938337, 11.426567396809979, 7.6384349503824795, 14.65895833507661, 39.3285741344575, 64.28484655195668, 65.7847648282205, 68.3271941831035, 71.05860725525888, 72.77053356170654, 64.77776688914146, 60.501096863900464, 54.670760323924405, 60.07189935253513, 68.43312171197707, 70.3370637278403, 68.64998171406408, 67.63964976033857, 63.36508212550994, 59.46232772642567, 60.859832917490316, 68.45958202115952, 61.56846007993145, 58.62173241953696, 48.31601465902021, 64.91512044783562, 66.8872764033656, 68.21055073891917, 63.25649915202972, 66.10722680245676, 61.82640690957347, 60.0860434193765, 52.55927001276324, 50.46717974447435, 53.512860959576024, 58.57437372207642, 59.39634561538697, 62.43442527709469, 62.44920476790398, 60.463457799726925, 56.55889518799321, 56.834684879549094, 47.83372786737258, 61.832733692661414, 60.62474173884238, 70.49599032248221, 43.84616005805231, 39.38231845055857, 71.1578667548395, 59.97345570595034, 64.22133553412654, 60.06102654241747, 64.65371801007178, 58.9649280425041, 60.93933151614282, 59.6308562832494, 63.355429172515876, 60.592715586385424, 65.97570973057901, 66.72884402736541, 58.30018043518067, 52.36074316886164, 68.02775259940856, 66.20117541282409, 61.42934537702992, 49.45641633002989, 48.05269418224212, 49.361593031114154, 58.998307412670506, 64.95708588630923, 65.15691887947821, 59.465336184347834, 57.171545874687936, 66.1028023689024, 69.89058033112558, 64.04683320753037, 62.04280799435031, 70.87236527473696, 70.82375141882127, 69.51040067980367, 64.74014743681877, 67.62847100534748, 65.23594679371004, 68.29770580414804, 69.96396787704961, 64.36924026858422, 69.61686949576102, 37.068575043832105, 7.246765696233319, 6.959751652133081, 11.660021966503514, 10.675302109410687, 4.458606223906241, 1.066616127087224, 0.44105379451667115, 0.15081960707902908, 0.1923249637888324, 0.4480464918719184, 31.118961188101004, 58.05793877570861, 39.610239536531516, 73.26541900634766, 67.92918343697825, 44.3513495691361, 53.85525641902801, 61.52144655104607, 67.45420009859147, 71.63136743730115, 73.97357156199794, 69.682584885628, 2.807022640782018, 0.3289512292512002, 0.18229656642483127, 0.10305410926981319, 0.10704603256477464, 0.18211347141092826, 0.07869611389093822, 0.08894072424980903, 0.16702854134623082, 0.13669780275273707, 0.08036369578011575, 0.1214513200665674, 0.17231012003556376, 0.1391059694991958, 0.16822664157277153, 0.08817773898162189, 0.15905211048741497, 0.09578830156955989, 0.09185023425567536, 0.25995584925816906, 0.129750641663709, 0.12994145884388877, 0.18049042221278916, 0.17260432844200443, 0.16856166714381787], [0.05231936957927481, 0.0041830186608187376, 0.053100472826871185, 0.026996700964387388, 0.024506779229869286, 0.04410467388468885, 0.032199050840591235, 0.05941453885527388, 0.047712541981450016, 0.03618857628034969, 0.05108809008473351, 0.010231552390201439, 0.05073895317412192, 0.05110280280331931, 0.032287905548488906, 0.01793799279708295, 0.043099777202212045, 0.023213368089449023, 0.08375528959497329, 0.03890833396825098, 0.042469524327785745, 0.05904342671255431, 15.40537557294292, 73.86486699504238, 65.78784388880577, 62.52822875976563, 41.43147053257112, 31.347554960558494, 16.962146643669374, 23.11809285994499, 48.52606542648808, 26.85969275812949, 41.575029280877885, 2.8081488513177444, 0.05116695883653818, 0.12027568153796658, 0.1387951523065567, 0.059894286096096046, 0.5353274713120153, 2.5944684205516695, 4.85803343595997, 3.1832735480800753, 2.5171661040475293, 16.313188537474602, 46.325674595371375, 62.79823687768752, 67.07995891571045, 66.09363186743953, 65.93643111567344, 65.58510049696892, 64.61101124363562, 54.64913629716443, 49.10570936818277, 47.47487022030739, 49.75167666712115, 54.792596986216886, 60.45330670572097, 61.93141268145654, 60.81353718234647, 64.46515790877804, 59.10832989600397, 58.562445794382405, 60.00389329848751, 60.451031731021025, 51.47072599780176, 44.0479620810478, 47.58053495037941, 54.76430493016397, 58.787648677825935, 58.10948656451318, 61.26797514577066, 54.52240059452673, 51.92253205084032, 45.59853384571691, 46.901847239463564, 46.46159256658247, 53.58888826062603, 52.993076309081054, 58.03073321619342, 53.888227862696496, 52.23761996915264, 52.170880840670684, 48.292186260223396, 43.7919685917516, 57.88742157720751, 56.98375848031814, 65.42040409580355, 37.2285371441995, 40.87756126157699, 67.47984455477807, 54.44840115885581, 58.72095269541587, 51.217505624217374, 56.10790891032065, 52.892632253708385, 53.38980051778978, 52.8106233381456, 54.5448326295422, 53.57735256994925, 57.229471437392704, 60.337149635438, 60.68695837451566, 53.90890659824495, 63.313479423522956, 57.41631746292115, 55.675106740766964, 44.18347604813115, 45.95745032833469, 43.01145222879226, 50.66446319703133, 58.058942902472715, 62.24513953731906, 58.69655947531424, 55.51690970697711, 60.526196110633116, 60.98981242026053, 59.59614722959457, 52.40695653423187, 53.473637257852864, 60.909215557959776, 65.10715184673187, 62.43176198774769, 54.416904526372115, 64.7241480888859, 64.07648632603308, 66.85104154771375, 65.66718785993515, 53.43446062457178, 48.3033924718057, 31.326680106501428, 5.78599218399294, 3.2359769651966714, 1.767379059906929, 2.360783656758647, 0.5485154604238849, 0.0663767229284971, 0.06038755478878176, 0.09884397349049968, 0.10370417317796139, 2.3391311928149197, 37.41206484456217, 49.90607292421403, 56.784341258387414, 50.8819664678266, 28.060285160618445, 7.341165869466721, 28.70844702566824, 41.51295385053081, 52.22877894678424, 56.32039154729536, 64.09526271204795, 13.678280480446356, 0.26831628934990975, 0.05528201927400886, 0.08379964608578913, 0.05021260097442616, 0.04699908812800723, 0.08439087444135258, 0.027361220920518525, 0.008664299290807498, 0.09607782151790396, 0.0844795031533126, 0.005320341780691618, 0.039897667574546034, 0.06255294444159636, 0.04337455378845335, 0.0010378667127130734, 0.12410685660377627, 0.09877975233980725, 0.04913100356897039, 0.04547774093225599, 0.011610934875094363, 0.04599026524491849, 0.041490521417149616, 0.03315737320771141, 0.00952094168056764, 0.017133500885158297, 0.038198561167284366, 0.1028385551105584, 0.050496788950817245, 0.05276563877780592, 0.017262720765786308, 0.026142263950239268, 0.023415199698760145, 0.039592745428484295, 0.029049249696395094, 0.08176784301477094, 0.02376761163524803, 0.03389390545987314, 0.095160270350114, 0.0931582987428673, 0.02102490961401453, 0.06066940619700378, 0.07271967047164518, 0.0470987523365165, 0.057491884161267555, 0.05338274558345157, 0.06178842699756065, 21.904036921839563, 85.6679456464706, 74.48420140051073, 71.71321945805704, 52.57054682700865, 39.14132018243113, 28.23454430026393, 30.807777989295225, 33.46372073696506, 33.12636944555467, 41.278525552442, 3.0521136570361356, 0.01675534264875516, 0.06343255510493633, 0.11084767494110331, 0.5338087786109217, 1.937375073471377, 3.616145339704329, 4.004029016340933, 1.0548922852162392, 1.7343044088732813, 16.731748580932617, 47.877917289733894, 65.63318091054117, 70.18937864611226, 68.77054752842074, 68.12261119965585, 66.19446815982943, 66.90579783531928, 58.52768574991534, 51.48464256717313, 49.47008186771024, 52.31399636114798, 58.60001817826302, 62.62229896360829, 65.6103644832488, 63.99912934149466, 64.29018882013136, 58.683301864131806, 59.868359719553304, 61.72338977936776, 62.890796969013834, 54.143687909649266, 46.64621853059339, 49.927030148044715, 57.11105900426065, 62.100117744938025, 59.926222524335316, 63.00441234342514, 56.82241962802026, 53.57568948499618, 46.87943089392878, 49.09473065407046, 49.87978912168934, 55.75705289840699, 55.579087118948664, 60.1737319269488, 56.901467154102946, 56.05018338849468, 54.42151723369476, 49.27186489105225, 46.649791809820364, 59.77143403022521, 60.42740337310299, 67.88974792726579, 38.78176435347527, 42.987941541979396, 69.2413809991652, 58.36764912451468, 62.37908455633349, 54.394547016389915, 58.181685632275, 57.2007949890629, 56.20675263866302, 55.011488776053156, 56.09792255586194, 54.96564019110895, 59.68182356126847, 62.82097877994661, 61.521505386598655, 53.75613028003324, 65.03490963289815, 59.80326798654372, 57.2199793015757, 46.336872962213334, 48.1029946573319, 45.52633870032526, 53.52384359605851, 59.3896815084642, 65.43813713135259, 59.281063233652425, 54.79735089886574, 61.794255241270996, 64.92436939670195, 61.53349607221542, 54.847278748789144, 56.29940686687347, 64.19152159844676, 68.15224078393751, 64.44031753847676, 58.856180329476636, 65.96038895268595, 65.50761015184464, 67.63226785967427, 65.40175322563418, 60.22211436302432, 53.670242140370036, 33.39866038291685, 6.073404348665669, 1.6709218486662836, 4.884538362103124, 6.2041006645848675, 2.8788601150435786, 0.9674175468183334, 0.10793942898031204, 0.08956509356897685, 0.08392138511783655, 3.0190397414468952, 40.312332030265566, 54.02034505721062, 66.66086935227918, 47.23377389292563, 21.10227700202696, 13.058070405837029, 41.24935488547049, 48.98936794650171, 60.18001948633502, 62.187068846917924, 75.33374755613266, 20.543094104336156, 0.3248274085983154, 0.06788849019475522, 0.08777938858275453, 0.07492676978149722, 0.03364023459594577, 0.027907395645255045, 0.07622862129562324, 0.053980045185814944, 0.09243266026098883, 0.015897348113808663, 0.032704553957427704, 0.009424318841117765, 0.0470589847123671, 0.0940733677857826, 0.04045093627346139, 0.07501149910592264, 0.05547060330788936, 0.06097607502353288, 0.09591437665925873, 0.045844103329845017, 0.024702365307377714, 0.0473381816259315, 0.027871088823303584, 0.10648134149490826, 0.22714442603530424, 0.12333535243787112, 0.19931392263500922, 0.1418172619155338, 0.1460542643983518, 0.11477533112009687, 0.09634797476352223, 0.14931041386819657, 0.2201500739301405, 0.11463944244408801, 0.1036261777663904, 0.1345958260278548, 0.17124893504285044, 0.13306096887155888, 0.1875167355061539, 0.2703350842479737, 0.14232064296882, 0.15419682908442714, 0.14472842667131655, 0.22869701046616803, 0.15552251359387753, 0.203732212164229, 28.47243409002981, 100.0147048888668, 83.12460237933745, 83.00362079374253, 58.36360123849685, 46.75830418063749, 27.034703031662975, 34.15789396532121, 63.91799119211013, 36.57529777096164, 57.44791215465915, 4.14734261651193, 0.1324164744226202, 0.3752528173067878, 0.4790250957012177, 0.4934025435678421, 1.308241974442236, 10.14527516980325, 14.793375019104252, 9.453746599535789, 7.187809040469508, 20.993695989731822, 52.62292223591959, 69.3862811980709, 72.39821434020996, 70.39535799334126, 72.05685830885365, 70.33491426898588, 69.8356593039728, 59.459393793536776, 54.07172810646796, 51.025387933177335, 55.074960570181574, 59.81787097069525, 67.05988422516855, 69.6640948326357, 64.808577106845, 67.29419877452236, 58.93502389231036, 57.594753926800145, 63.136827638072354, 68.58578035908361, 56.64784669876099, 48.63940231261715, 52.89453068087178, 59.34143243297454, 64.36370188190092, 60.719792535228116, 66.01636901978524, 61.18049844618767, 56.13764832096716, 49.842522682682166, 54.32329323983962, 54.01413986759802, 58.95971913491527, 58.697995062797304, 62.36689382983793, 61.396330787289536, 57.33666196946175, 58.036338283169655, 51.137595176696784, 48.58303000850063, 61.74375472530242, 63.81441316296978, 68.45682067255821, 43.46910261338757, 46.6174401006391, 70.07332355745378, 60.71169676319246, 64.11076784133911, 56.41615621505245, 61.22529975829586, 58.80568373587824, 58.28110202666252, 59.6730923652649, 59.185235807972575, 57.632377301493, 62.14519362295828, 66.09064302136822, 63.03858403236636, 53.63118710056428, 67.32149847092168, 63.6751494100017, 61.21485840889716, 48.950669842381636, 51.11596330519646, 47.06827340587493, 55.25699776987876, 62.83838625877135, 68.51563269092192, 59.960013743369814, 57.042468517057365, 62.96503566926526, 67.02095862357848, 64.04722544454759, 58.60455243818222, 59.89840899744342, 65.91827054177561, 69.83801272607619, 67.69756747830299, 63.044153798011045, 68.51287918706095, 68.70448696997859, 72.4403327511203, 68.92642251906857, 62.29483596740231, 57.28627912459835, 38.76483932618172, 9.96003927723054, 6.709096998937669, 10.384285776845871, 8.875753975683644, 2.8854945590419154, 0.4845379869784079, 0.33910327320618017, 0.34883877983497036, 0.1651018761819409, 4.040836538037946, 53.73247054315383, 60.98968690441501, 63.88631413059851, 65.34209789768343, 44.59432471183039, 16.261799604662006, 44.647994502898186, 56.69009062551684, 69.48164186170025, 71.7499485323506, 84.91736873503655, 26.347805799976474, 0.49964104268339377, 0.16167372465133667, 0.1541965532927744, 0.13313806796025845, 0.29025885546880387, 0.2038847555917117, 0.2006197961107377, 0.13301511084841144, 0.24264558699102173, 0.14642687424296333, 0.12336545969329535, 0.0899122003465891, 0.1689179133503668, 0.12890373146341694, 0.07203048245320398, 0.2962830951136928, 0.2428265216369783, 0.12183702235380489, 0.1686932350839338, 0.1086673197606879, 0.14627845236851325, 0.22620449743924603, 0.13864683768441602, 0.14505655745104437], [0.05027309127692735, 0.05088237632486609, 0.041238164394012386, 0.12599705598287045, 0.07342221906348582, 0.03202352094494047, 0.04354252622673108, 0.01038330004385282, 0.057281612178250674, 0.012939362936923582, 0.00910935615519843, 0.07023964467788897, 0.08222753407373544, 0.015352367528624114, 0.05213977941762536, 0.07814823845100981, 0.013642132736652369, 0.025142400465424986, 0.05402435954179495, 0.01952266482065522, 0.019480204397451975, 0.3519596688209042, 38.94552330816946, 76.95931111612629, 73.3692833685106, 59.86392744125859, 39.312868964287546, 35.57064540924565, 23.47300852498701, 21.04320218486171, 32.9755856913905, 69.27974177945045, 17.946555652926047, 0.12239979054298132, 0.004254727363361106, 0.0353901096499495, 0.08563661767590432, 0.16707931765385214, 3.0259526737274665, 3.593601762287079, 3.748848193114804, 1.714620361885717, 19.619046449661255, 54.82961239353303, 67.3531049297702, 65.73577834713844, 63.77263992063461, 62.33882142651466, 61.226233282396876, 60.82197027821695, 52.588413223143554, 53.608935494576734, 53.213219335002286, 48.47880871065202, 49.32907266001548, 48.36517372438985, 52.215611550115774, 57.84159652648434, 62.61274014749835, 62.63846697345857, 61.753164491345814, 56.8086285744944, 61.95142853644587, 56.83592827089372, 53.35456978890204, 45.71927224436114, 45.72727780188284, 44.057795463069795, 48.53136847096105, 48.73310381366361, 52.0276790280496, 51.8300151055859, 46.93034718113561, 44.68403324004143, 47.63440870469617, 50.31255991228166, 55.634404305488836, 56.21313825730355, 58.72549480007541, 51.71368545101535, 53.64509974756549, 48.247129994054, 45.189234518235736, 48.59962163432952, 59.863040985599646, 57.08610488522438, 65.27506459143855, 38.418325378048806, 45.358335741104625, 63.65379602678361, 54.62438221900694, 54.87794776116648, 52.265155007762296, 54.38116781173214, 51.91435783140121, 51.33776157133041, 47.573874765826815, 48.78505168422576, 47.122500173507206, 52.2205380470522, 57.27644574257636, 61.46289340911373, 52.2323404589007, 60.02375618104012, 59.10425455339494, 54.42648295433291, 46.26980827700707, 44.25762061149844, 43.486239448670425, 48.00787718065324, 56.672949867863814, 60.624930012610655, 59.60532949816797, 53.033174699352635, 58.52119814965033, 62.873111001906864, 59.89298828186528, 56.135694980621345, 49.226279104909594, 52.0869734979445, 61.145707022759225, 63.2531298360517, 58.4096263300988, 57.30786785002678, 66.07347088475382, 66.6283215245893, 65.45634477369248, 67.6007241587485, 57.90690006748323, 42.63554011621783, 16.141100429719497, 7.563049937448195, 4.672824999978466, 2.5765311766055325, 4.031330673925338, 0.6333309544190284, 0.03204316152409921, 0.047596131090915976, 0.07374432073124955, 0.05207131413983242, 9.829083104287426, 31.724102497100834, 27.53478365559732, 57.1465015411377, 83.3240862815611, 53.87067525617538, 10.371247818393092, 26.543792909191502, 45.4361516429532, 56.742795513522246, 59.6029721536944, 41.92678743793119, 0.5549662884685301, 0.10679113212972881, 0.13550267494734258, 0.04322105658150489, 0.020921152580769795, 0.08852968743491559, 0.04543072611634289, 0.010605610140989865, 0.08758057344464526, 0.07853721193368397, 0.024747763677770575, 0.005729740125037009, 0.01523789962858803, 0.02248751318773195, 0.0233517101620354, 0.02551903610207862, 0.05886631101490029, 0.07884863433578322, 0.07240813315635727, 0.04082324734378246, 0.0791919183346533, 0.029112427052290692, 0.021522830375620437, 0.04455356693436061, 0.005727174209295622, 0.048296821919540246, 0.03832806067000474, 0.07088097518370037, 0.017392367740432103, 0.012782957468692575, 0.04104323715211884, 0.016038012390415517, 0.05750619468369311, 0.015285867266356947, 0.021587047695873246, 0.04362706019873581, 0.03851444603154256, 0.025147065940883853, 0.02999919872250288, 0.03556779608310711, 0.08131411978073659, 0.031206225788581277, 0.07533520955832736, 0.06928888359858144, 0.009176160937415497, 0.5160455898411813, 49.11911995180192, 86.2432239901635, 81.02837793288693, 68.21398673519012, 50.56445060237762, 42.37199606433992, 24.980897057440973, 21.889677124638713, 31.714724110018825, 53.82026887709095, 17.48748537032835, 0.11670625573324582, 0.03645847288651332, 0.11967062529536987, 0.31976025791898854, 1.6469474641546127, 3.871640197692379, 2.152358711727204, 1.0650741453132322, 2.256448365026905, 20.930612510250462, 58.799968842537176, 69.2644916042205, 68.57122052100398, 66.11377716064453, 65.96571553137996, 63.86165811169533, 63.34695685294367, 55.12588470212875, 54.374025175648356, 54.76705843402494, 51.10093670506632, 50.535381917030584, 51.0133501791185, 53.41304448343093, 61.08236858921667, 65.87496757507324, 63.052245647676536, 60.19908220537248, 57.853744106908, 61.962446474259906, 60.305609856882405, 55.45301429687008, 47.68938856740152, 47.61285920296946, 46.96895899311189, 51.80262519467262, 51.03707659629084, 54.39439012158302, 54.240958767552534, 49.52827415158672, 46.529418191602154, 50.40731260853429, 52.12303969167894, 57.7967873696358, 57.717465277641054, 60.46649763661047, 56.23313450044202, 57.339846934041674, 51.13755595299506, 47.35012315934705, 49.63246407047395, 63.722480650871034, 58.427398589349565, 65.90513060169836, 40.35374049217471, 48.30356897846345, 65.61420448364751, 57.13503253075385, 57.09824854327787, 54.82558411936606, 56.115769340145974, 54.54951593952795, 54.21006618007537, 51.525839221092966, 51.55776731429562, 49.20956588560536, 55.37610446253131, 59.464335979953894, 63.45823841710245, 52.382998697219364, 61.29578867266255, 62.494888613300944, 56.42891176285283, 47.85956059732745, 46.39214308031144, 45.38122669343026, 50.230876553443174, 58.428057547538515, 61.20907291289299, 61.91790796095326, 54.64817923884238, 58.261294057292325, 65.09511017030286, 62.66664528077649, 58.000683938303304, 50.705671618061686, 53.85693127109159, 63.74364968269103, 67.34114954548498, 61.78166443301786, 60.89065490230438, 67.29423799822408, 67.97134891633065, 68.23990575728878, 68.92890930175781, 62.65518019276281, 49.83193228321691, 20.246109885554162, 4.082732844737269, 2.419192651587148, 5.777237453768331, 9.744492288558714, 3.625670325371527, 0.6033638624414321, 0.1522069157011086, 0.0676882501331068, 0.031773339611508196, 11.272467278665113, 38.775904332437825, 28.992820824346236, 58.03718551512688, 74.73852003774336, 43.6861587339832, 17.202889957735618, 37.64848178432834, 53.47768906624087, 62.56849188958446, 67.30556580328172, 50.810524417508034, 1.0818971909822956, 0.08169864229257069, 0.21934494616523867, 0.017042738618329167, 0.02951175038282189, 0.049583267405508995, 0.018099922716857928, 0.040864865070269, 0.02006749889152425, 0.05535111657433933, 0.010007218863334387, 0.006726943369534228, 0.050225295051331484, 0.040155988592173786, 0.0676413961956578, 0.05860441236666614, 0.011528450188287085, 0.05832460258276232, 0.1025115198365623, 0.019331723151187745, 0.03740470638618835, 0.04294999935213597, 0.007792961419439845, 0.07860432123585094, 0.09634180775573177, 0.11813415935443294, 0.16607120723253296, 0.21478244824515236, 0.2794633283009452, 0.11643485376431097, 0.239713630608974, 0.142274325292918, 0.11470523407502521, 0.08797569095247215, 0.11814926660829976, 0.11373507564947491, 0.1640843122356361, 0.07646243899099289, 0.13223262864255136, 0.16824420030799606, 0.13804250156446812, 0.14757972931669605, 0.120377984919375, 0.13039452324230827, 0.0945363530228215, 1.0013328108095354, 61.47822987648749, 96.347759462172, 90.61235996984666, 74.85284143878569, 54.71161180926908, 47.63513826554822, 34.63667023566462, 31.059392152294038, 46.20299070112167, 87.25866286985337, 24.66038646236543, 0.2282270614898974, 0.11105008303157746, 0.35823365312910854, 0.2554438212105344, 1.0092215552445383, 9.992334112044304, 11.494394002422212, 12.007216445861324, 5.74607765482318, 23.127486936507687, 60.96925527818742, 72.44174480438232, 71.4009125001969, 69.34932462630734, 68.71001751192155, 67.35415612497638, 65.13519679346393, 57.23657877214494, 56.596871576001575, 57.25346065336659, 53.92840077800136, 54.76573659527687, 54.131050032954064, 56.343929690699426, 64.04868064388153, 69.75082628188595, 65.64620710188343, 60.80071887662334, 57.21590003659649, 64.14368829419537, 63.08280091131888, 58.26497324051396, 50.22792300870342, 49.30095711062032, 48.31788955196258, 53.45670438581898, 51.68956679682578, 56.92695471548266, 56.207882281272646, 52.3439593468943, 49.275340111024924, 53.056477500546364, 55.42382794041788, 61.685844852078354, 61.84996858719857, 63.437563603924175, 60.84944255890385, 58.22152906848539, 53.51459856956236, 48.989983758618756, 53.56644445850004, 65.58016223292198, 61.23004974857454, 68.52249683872347, 44.137929485690215, 51.89438120011361, 68.00890168836041, 60.16383578700405, 58.31672891493767, 56.14376721843597, 59.80459374766196, 56.521118840863636, 57.578119154899355, 51.621647034921956, 53.72018960214431, 52.57672848240022, 57.270797529528224, 62.07360252257317, 66.05528677663496, 53.28431229437552, 62.8899654265373, 65.47764324372815, 59.364566572250865, 50.56145391156597, 48.77272367477418, 49.66440785315729, 51.98330133192001, 60.87554593240062, 65.59831103970929, 65.45322648940548, 56.778226283288774, 59.41333340060327, 67.85083017041607, 65.45278718394619, 61.336020423520004, 53.27405921874508, 56.52255835071687, 66.09194524826543, 69.75404262542725, 63.7466149945413, 65.82065059292701, 70.33584779308688, 72.30922360574046, 71.43913991989629, 72.04205528382333, 65.7082119295674, 52.00144621633714, 22.368902506366855, 13.478209203289403, 12.874653512431731, 9.478634038279134, 14.665217457279084, 2.19275618272443, 0.3459926712657175, 0.25946334665340764, 0.24874286545861155, 0.14652117966644226, 15.318692172727278, 46.568724263098936, 35.431079633774296, 63.844333002644206, 90.10951995849611, 70.79078781989314, 22.463041351687526, 42.56387449079945, 62.09192783601823, 72.64762216998686, 75.30100360993417, 61.818879881212794, 1.745425676626544, 0.34348345752204623, 0.5270953969128671, 0.15689647696431608, 0.11066142364495224, 0.19771066914883353, 0.12534739044044288, 0.1475129417714573, 0.12288987230990203, 0.20465868825633682, 0.12806687233669142, 0.17456488533606454, 0.10512007220137505, 0.07432077891163288, 0.19169318639943678, 0.2028012008316094, 0.09606669026036417, 0.2149803440777525, 0.2833767505663057, 0.0972690346140054, 0.223325002758253, 0.1145991002539954, 0.18456084653735164, 0.17097308210307555], [0.03070455885702564, 0.018928791546533187, 0.09431318394959935, 0.07407316397274695, 0.12848964561858486, 0.023700638313687617, 0.010525354770042244, 0.017529924572896094, 0.012700866359556395, 0.04754345488524245, 0.08167907640698456, 0.05825341386239856, 0.13080482461279438, 0.02748459363506446, 0.08925206238223661, 0.023897760397484227, 0.09154130930020925, 0.06324469885458389, 0.010120985792919753, 0.08634417648276976, 0.17897650990034306, 6.0746967696374465, 75.70103829906833, 66.79561061243858, 67.45216831084221, 47.98964208172214, 49.25959179478307, 36.17375296931113, 34.774521935370664, 42.59603400384226, 44.802080892747455, 46.397665777514064, 1.1707228181823608, 0.01423531078598312, 0.012602682615960798, 0.14921108290793436, 0.24052496368606247, 1.3439424071581134, 3.917343164643934, 1.0669584764588265, 2.0754228916860398, 20.081021247371552, 56.49740026843164, 68.8037621590399, 60.37201558389972, 60.0470236809023, 56.293723352493785, 55.94407543059319, 52.55932492594565, 49.365032949755275, 49.31545026840703, 52.94226984823904, 55.93381451022241, 58.1239640328192, 57.36167492405061, 53.50163905851303, 48.53021137176022, 51.01776284556235, 57.80650308055263, 62.02318045400805, 60.98829446300384, 55.34051679795789, 60.795066741205034, 59.20959764911283, 54.8616660025812, 49.04996072092364, 49.1055210944145, 50.25885874225248, 48.511297702789314, 47.04897534462714, 45.00773468325215, 45.84290142982237, 45.29781749171596, 44.46395297204295, 45.07045730467766, 49.716406714531686, 54.28721135662448, 57.453874157321074, 54.154399902589866, 52.8421474272205, 54.45898763595089, 44.39531149402742, 45.864529378952525, 52.36521074848791, 60.82345685651226, 58.177143527615456, 59.158916704116336, 40.8248681406821, 49.152346349531605, 62.86257551562402, 53.544749829076956, 54.231062627607784, 49.81357951318064, 53.82612889812839, 51.90866647228118, 53.70733599508963, 48.60761150237053, 46.54504491436867, 44.258393318422385, 50.54918081529679, 58.23146050976169, 61.876534800375666, 50.454918415315696, 57.47686316890102, 60.930415968741144, 54.45059376378214, 44.99905840043099, 44.71697330474854, 43.72480584729103, 46.39106050614388, 55.16160964965821, 58.83371299312961, 59.018754728378795, 54.253490740253085, 53.008750100289625, 60.093707730693204, 59.960029432850504, 58.421209089217655, 54.857724020558024, 48.172389230420514, 52.77748715492987, 62.57062958132837, 64.48779782941266, 61.022136672850586, 56.956521541841575, 62.42538813621768, 66.12417928634152, 63.21586339704452, 68.44291979266752, 60.46810188601094, 39.67035378179243, 10.034935955078373, 3.7004130501900954, 5.984095411915933, 3.979574509205357, 3.2118543886369277, 0.6122883577500621, 0.030923275044187907, 0.07273242583558445, 0.050346290978092345, 0.6406111186069827, 25.877613636755175, 64.42448293009113, 76.72104281763878, 66.42068693714758, 91.96090221405031, 33.853000287086736, 27.06952779523788, 39.16865125779183, 52.07495535573652, 53.07561866698727, 54.94224717540126, 8.691253527518242, 0.15663269757022782, 0.049669762562599876, 0.1308923424972642, 0.08957706752323336, 0.011177873032377853, 0.05436532612469408, 0.036990869519931656, 0.018247760449265762, 0.013903277745891004, 0.05549076674205642, 0.05491981290340905, 0.06571856147098927, 0.051021283387296626, 0.04089515618679505, 0.031940289322407014, 0.05396109600100787, 0.021181540120573297, 0.02465589058345124, 0.07257133286686675, 0.029715884086345474, 0.0314084691701517, 0.07606509982818559, 0.014964383256982171, 0.02679291391564954, 0.003257351988483401, 0.11845975438313139, 0.05596624687314034, 0.08669332105426059, 0.026242405048481403, 0.027530078190348806, 0.03949085956499462, 0.01499338543057562, 0.021522958695347753, 0.06099682834540164, 0.027813270252438325, 0.019680143769590125, 0.09642212441371334, 0.042458232191781846, 0.05159549693006182, 0.012384848387521363, 0.043583320408699014, 0.04347424097960034, 0.026187681472830238, 0.14863060276594856, 7.9406319991234815, 87.40222946290048, 76.6595635875579, 75.4519207246842, 55.372425279309674, 55.233859708232266, 42.81944044174687, 32.46124725187979, 35.89904192955264, 41.31039481009207, 42.591680172950994, 2.0856649356503643, 0.017515962620476083, 0.04087297028050788, 0.33773831902973117, 0.8742781091601619, 4.368148522992288, 4.366776183728249, 3.2873168683821157, 2.2030136710213077, 22.144354658742106, 59.808402369099284, 71.11967855884184, 65.1233708473944, 61.26175818904754, 59.42497891764487, 57.870449481471894, 53.71967577165174, 50.83066971071305, 51.096720157131074, 56.13326703348468, 57.81436351037795, 59.573707349838756, 60.00356381939304, 55.99058297372634, 51.437378006596724, 54.54240076003536, 60.395906740619296, 62.84130842454972, 60.59572012193742, 56.36434562744633, 63.31552297838273, 60.12639676370929, 58.14168922362789, 49.60176367913523, 51.71031221266716, 52.76009144321565, 51.59900319191718, 48.99879340202578, 46.32778483052408, 47.024005536110174, 47.641782760620124, 46.89284932228827, 47.393936034171816, 53.53528907222133, 57.45115203242148, 58.178033905644575, 55.73591524554838, 55.15845998640984, 55.84809895484678, 46.62066821129092, 47.005448802824944, 53.37610360114805, 63.415927810053674, 59.428054055859974, 62.872608938524806, 42.29902036728398, 51.37053297412012, 65.52393113413166, 55.352703602083274, 56.423585184158824, 53.00551022252729, 56.01686285388086, 54.00217663857245, 56.04490780061292, 51.474389491542695, 50.56610584259034, 46.460796325437485, 52.21524284731958, 59.85964421303042, 63.04589140799738, 51.30903413218837, 58.83190478048017, 61.97206020355225, 56.83529676929597, 47.7712288210469, 46.293691588986306, 45.78437182211107, 48.107560296212476, 57.62646236727315, 61.834518371089814, 59.94061370049754, 58.69958362271709, 53.27022706308673, 62.05796795506632, 64.2245008868556, 60.450286480688284, 57.55422015343943, 51.81726740252588, 55.60162505795879, 63.94036439157302, 65.25282083019134, 63.82478390970538, 60.94798426474295, 65.14575973633798, 66.2292125148158, 66.05556918728736, 69.19266516162504, 65.36128221019622, 45.15474511731056, 12.94130144580718, 1.3884353229115087, 1.7557234917917561, 6.4070014415248755, 6.504932728505905, 2.8654022178342267, 0.5236878378256675, 0.1044865021662366, 0.08762499888337429, 0.9061269582279268, 24.86319261212503, 53.967365603293146, 74.06143265385782, 66.20391322720435, 90.81379721241613, 35.42656106333579, 37.349008821672015, 47.29382145789362, 60.69447363576582, 60.77635703548309, 65.12614004073605, 12.264928913885548, 0.23097288914986197, 0.07078610285515748, 0.031272205111059936, 0.039519698944904154, 0.08184538643446662, 0.02682219954177497, 0.020263960224486167, 0.034475956082103715, 0.04139106788281952, 0.03632006761167319, 0.05332878235006525, 0.011049424985333556, 0.10395712774967956, 0.06312321646199112, 0.021035826366935528, 0.059546742648366964, 0.06854579363378786, 0.022708067985912486, 0.016672683676945108, 0.015666295038235765, 0.009633832397089611, 0.09506492304705805, 0.008551725543164199, 0.16436512942516035, 0.13486260848660625, 0.23281505481610376, 0.16088172763345704, 0.23235724067255376, 0.16982157534408956, 0.13274170938999424, 0.1773487109570734, 0.05792082062051181, 0.10939938572025108, 0.16556630932515667, 0.14903857522914488, 0.30373823378355275, 0.15898633417823624, 0.15648634413317328, 0.12903902259084488, 0.10530545015729244, 0.13533408963872542, 0.14215403416704747, 0.20921475103785916, 0.3745233790288049, 10.746340155601503, 99.93260968116023, 83.23720578224429, 85.84944940382435, 63.83750023380403, 63.903466655362045, 43.60927635623563, 50.6465732666754, 56.442518464980594, 59.9328121062248, 62.78182175851638, 2.351290785497235, 0.19527872303320518, 0.15909456708017858, 0.6369469507086662, 0.669716943896586, 5.394041990080188, 10.239147293952204, 9.765544629866078, 5.90396236988806, 25.54511235606286, 62.6390867079458, 72.9852911733812, 66.6790142366963, 64.89526148765319, 60.87085477767452, 61.51563752082087, 56.134985031620154, 54.36121863703574, 53.61255584224578, 59.420727068378085, 60.63898778730824, 62.511590065494666, 62.86017110270839, 57.468437917770885, 51.58713017740558, 55.95022178465321, 62.505137766561205, 67.34955910713443, 61.62648370189052, 55.62560250682216, 63.995748258406124, 64.45702683541083, 61.21433673366424, 52.42582705713088, 53.900638241921705, 56.54018548227126, 53.539850788731734, 52.58492231369019, 50.00714848118444, 49.971670642975845, 49.252911998379616, 49.63661001574609, 48.75937977144795, 55.68681109336115, 60.03277371006628, 60.91295749910417, 59.221831521680286, 57.67491540601177, 58.997719057144664, 49.87044603593888, 49.921734948312086, 56.313994161544315, 64.78033211923415, 62.932511375796416, 64.72683883482411, 44.451668108663256, 54.04902935028077, 69.45439707848334, 58.88102069977791, 59.78861401157995, 55.897156038591945, 58.84948092122232, 58.34322452545167, 61.01501364861766, 55.483542103921216, 53.494366984213556, 49.33976504110521, 54.56215381622315, 63.25238066334879, 65.81802260491156, 51.448768569577126, 59.84431951276718, 64.34880471998646, 59.22200410596786, 49.88628848906487, 48.93084618353075, 48.92479004398469, 51.50676865731516, 60.389881980034616, 62.84081812827819, 60.940578829857614, 59.806809886809326, 52.93391519977201, 64.40040742197345, 66.03860101392193, 64.76584288381761, 60.701804545617875, 54.459921160051906, 57.18780017668202, 67.63174226207119, 69.14970736349784, 67.13746086243661, 64.15978962375273, 67.66518439016035, 71.81931172647785, 69.43659736264136, 74.83231959804412, 67.36877087623843, 47.639448950367594, 14.807771098229194, 8.510853917367998, 16.24738685546383, 12.75402690133741, 9.737809550377632, 1.8482191091583622, 0.2119900117958746, 0.1558612163869604, 0.23665378350884686, 1.422948748353989, 39.548415137875466, 77.32082813016831, 81.23503977252592, 69.31410174215995, 97.8962641377603, 48.98064851760865, 40.542688908115515, 54.2348712490451, 68.4549222453948, 69.25013572938981, 75.44275806796166, 15.413808668813399, 0.2843401827398808, 0.24274816616408287, 0.3086455478783577, 0.10625066476002817, 0.1896038807688221, 0.20777599195078497, 0.1468597292419403, 0.18384513655497184, 0.0982476200067228, 0.16413484339512166, 0.15261283504866785, 0.1137791027224833, 0.21157937334670177, 0.1300075415882372, 0.0690840240267496, 0.11480513960123064, 0.2505778605418821, 0.09980542149635092, 0.20368738069890008, 0.10773725071621519, 0.06611927142066341, 0.20735058332643203, 0.07463851387822822], [0.05499396638403978, 0.03082705440089828, 0.015847030501332016, 0.05101725376481491, 0.037348540650019725, 0.06780506321980108, 0.06778644728324107, 0.012806674593218393, 0.03567645416384743, 0.011444145085049734, 0.03343620239907215, 0.042643227103737094, 0.04641091263282203, 0.024790928901864157, 0.06505082391442792, 0.06302389699304778, 0.02978186723926375, 0.04962729447851739, 0.06782976189447988, 0.10881926563958969, 0.041281739475145456, 24.10918558797529, 77.05147897043537, 65.1722082784099, 72.4550965524489, 53.07455962704074, 37.84735379680511, 23.96132007721932, 49.488567998332364, 43.566506831876694, 54.981074717737016, 17.198281172783144, 0.09136843389921612, 0.004641005174151712, 0.05919634552311994, 0.21414831130494996, 0.889578968767197, 6.080517076676892, 2.512114091265586, 0.6837372722164278, 13.378481961065724, 55.235479647113436, 66.05368644960465, 65.31781842631679, 61.36229245893417, 62.549315421812004, 61.26282507373441, 57.85881573154081, 54.68258626999394, 56.20339901216569, 52.27826356887818, 53.575877758764456, 57.96967367972098, 63.66661041013656, 62.652379620459776, 58.794752090208, 52.10047821844778, 49.774387190418864, 56.349848547289454, 58.27479877779561, 60.498437496923636, 58.59069470436343, 61.50374489445841, 56.65394990674911, 55.39193907091695, 53.67894980215258, 54.478768148729884, 56.39754456858481, 56.1359695465334, 55.95683490076373, 47.63275346448345, 43.40917664189493, 44.70142110701531, 43.91676664352418, 47.39176696346652, 50.822303295135505, 56.79846179100775, 55.89131562940536, 52.30962684077602, 51.83792652622346, 48.765153500341604, 41.800392981498476, 47.454407215118415, 55.9641501211351, 63.2605391933072, 55.75878266365298, 57.67592737751623, 40.98320245742798, 45.547974494195756, 62.723229392882324, 50.239325338794345, 52.68162442791847, 49.20612596696424, 53.86463872848019, 49.26588327653947, 52.93739434211485, 47.054184252215975, 46.41930549375473, 41.837498603328584, 48.964613868344216, 54.21247843773135, 62.22491971908077, 53.39168717784267, 57.41802761631628, 57.8834835175545, 55.05927501186248, 44.36875704796084, 43.18871590398973, 43.21923194393035, 48.59198085723385, 55.40794626359017, 60.2711400678081, 59.058064722245746, 57.64054759856194, 52.15224173761184, 56.22302655250796, 60.112299765309984, 61.651543724921446, 59.63713992026545, 52.07074665254163, 46.041443963204664, 54.24828575503442, 58.3897477580655, 60.416091257526034, 60.44202596910539, 60.42957244380828, 60.80422155318722, 64.40276084407684, 61.05516695207166, 67.03059980946203, 60.81946388367684, 37.69005890815489, 8.79376074960155, 3.8730316585110085, 9.49922255931362, 6.724884048584969, 2.4184564717354315, 0.7639728474520868, 0.10497636176765927, 0.22078295448614707, 0.25015720166265965, 4.311105983872568, 30.676286412823586, 60.88971745583319, 77.0297961081228, 64.1765812904604, 39.247800765498994, 16.37691234388659, 39.1076466345018, 55.205210716493674, 56.6224846532268, 57.910916574539684, 21.509795573449907, 0.11329085956658087, 0.03582181168660041, 0.03514046840850384, 0.11924253536328194, 0.06296462860078582, 0.025452541585470882, 0.1338290179809255, 0.03263065711625161, 0.05184170992804631, 0.010897197569119594, 0.01420895736138787, 0.1079772737237715, 0.05897635954522318, 0.08480340512769838, 0.037004195619374514, 0.05594461255015866, 0.03915147495365912, 0.1186473386722707, 0.03446170301627248, 0.0639907842231614, 0.0379954865803161, 0.08069537354693299, 0.0699801936805729, 0.046299182539505344, 0.034784003866896514, 0.024064373029696367, 0.09752958111705319, 0.11030901553890399, 0.07148608505245178, 0.05466961624821829, 0.025071951019908154, 0.03836031680205657, 0.07859332021325827, 0.029613944596701094, 0.07756268680696526, 0.020033302641804182, 0.08047221979546933, 0.06432212108085233, 0.036971824574134046, 0.02262695268126986, 0.07538460690768496, 0.06521455988648438, 0.016601661580704873, 0.05767840741863174, 30.10507360581429, 87.90457525560933, 71.84000615150698, 80.57616003098028, 60.89886442307503, 46.83437855012956, 29.726782575730358, 41.50163389021351, 41.309422062289336, 56.62884281527612, 19.2538502523976, 0.060394265718998454, 0.08273920419836238, 0.24356856972219484, 0.6148477042874982, 3.493890699840361, 5.812249510518967, 3.7331898462387825, 1.2204523432639338, 15.78426476447813, 54.56661355110907, 68.1190889112411, 68.86523354438044, 65.02853185899797, 63.90094849371142, 65.46261272122784, 61.09180188948109, 58.48301779839301, 57.32448301007671, 54.09260296052503, 56.13465947489585, 61.00240715088383, 65.61383185848113, 64.81930871163645, 60.73042215839509, 54.382085646352465, 51.96796486454626, 58.43400386071975, 61.28413531088061, 61.856832735000125, 58.544026344053215, 61.3239630576103, 58.92078568858486, 58.716998946282175, 55.92444789025092, 57.06828947990172, 58.20075227368263, 58.73471236998036, 57.03795386898903, 49.736587309068256, 44.569013657108435, 47.20366577948294, 44.85885720099173, 50.724126369722434, 53.35087883856989, 58.936800725998424, 57.34547945760912, 55.03160269029679, 53.696286678314216, 51.789728441546046, 43.22483308853642, 47.89071206123599, 57.30856603191745, 64.37776750133884, 57.449077098600334, 58.988717217599195, 42.373604236110566, 48.48235453328779, 64.32421930374639, 52.413910896547385, 56.11858952429987, 52.09971335626418, 56.37790133876186, 52.60092166162307, 53.48812257089923, 47.78254093662385, 48.96503748432283, 42.8919493767523, 51.4888551927382, 56.83116651350453, 64.73068275759297, 53.65017921693864, 58.22844420709918, 60.62545953258392, 56.86423601642732, 46.195444060910134, 45.002439483519524, 45.70495951560236, 52.16693493627733, 58.29005287539575, 61.534770842521425, 60.85672247794367, 57.44739440179641, 51.52144616649997, 56.8457498858052, 61.35929576812252, 64.25257329017886, 61.5839534421121, 54.448071679761334, 49.33651339623236, 57.50789696170438, 58.382738482567575, 63.34595272617956, 62.02281959595219, 61.66722928324054, 63.28579925721692, 65.31929323750158, 64.46466369013633, 68.21652058632144, 64.06692750992315, 44.126127073841715, 10.840372116334978, 1.5385570545350353, 1.1710138090195195, 9.357224914335436, 5.424620787943564, 3.4068714466787156, 0.43779050510737205, 0.16560976183222187, 0.04399908015564565, 4.302968046357555, 38.059601091569476, 64.34471761026691, 86.54558381726666, 66.16887077208489, 46.24044933626729, 24.969539834607033, 43.78890522064702, 62.948899038376354, 60.633363108481134, 68.27425787525793, 27.51399313249896, 0.03282909304083836, 0.06199092701858571, 0.026224604995560744, 0.042610208714200605, 0.04387023948854016, 0.05442877352658299, 0.08340666596327098, 0.06354474102056797, 0.04505915432086876, 0.004400479421395088, 0.06585130918650858, 0.023636602939316825, 0.07166802327358915, 0.034072384794032386, 0.06150528473118621, 0.05822414930369105, 0.025211834844442147, 0.05951339484102303, 0.08795834672186645, 0.05475187110864828, 0.022817863707220363, 0.09085009880964795, 0.04054790002203757, 0.169004465964052, 0.14739661898103454, 0.11952993324807576, 0.1956690141871091, 0.15757443413378733, 0.18053960505752795, 0.14796749238044987, 0.06293507292866707, 0.14559286496331617, 0.09914653991619427, 0.1198786334885705, 0.14404254815270826, 0.09675181035192744, 0.14032791038194012, 0.13647626544679367, 0.08766628336161376, 0.12781856791867366, 0.20629404082653985, 0.1481694178355317, 0.1809879043890584, 0.14471820705840666, 36.11564697757844, 98.73039537860502, 82.01869795399328, 90.19350574862573, 67.39995371910834, 53.93712412926459, 33.62203151948991, 65.63163157432311, 54.880509068889005, 72.6878970669162, 24.774823573327836, 0.2608111098168358, 0.25395273831823184, 0.2783025212345585, 0.7659411418341822, 4.28356457141138, 14.941079712683155, 10.882317942957725, 4.473439157009125, 15.66598176956177, 60.631378389173946, 71.85200860423427, 71.69083841385381, 67.06333591092017, 66.82199247421758, 66.77166062016641, 64.80114029299828, 59.74837833835233, 60.211457283266135, 56.829264163970954, 59.71725825340518, 63.43128781164847, 70.25310931667205, 67.484190540929, 64.5829035389808, 55.171246913171586, 53.912413197179, 60.489561173223684, 63.83398579012964, 63.35679807970601, 59.91280409597582, 63.65363913197672, 61.56947597380608, 61.63121015794816, 60.31998926593412, 60.59778328864806, 61.964246842169, 61.656234879647535, 61.547589148244555, 51.99972037346133, 47.36788365148729, 49.127227490948094, 47.78413734128399, 52.25318001162622, 56.22135562281455, 61.38630913149927, 61.64859802492204, 58.02302575880482, 57.32684035455027, 53.67761619629399, 46.09600020993141, 50.31779235409152, 60.63656376254175, 68.1996936182822, 61.52242714358915, 60.663455532443145, 45.19165069826188, 52.70077736146989, 66.27617113051876, 55.81803006510581, 59.000213684574256, 53.85821388613794, 59.0682158162517, 56.25995174531014, 56.605947940580315, 51.14453384953161, 51.93594263445947, 45.609410578204745, 55.018160727716264, 58.92340190948979, 68.2929362020185, 55.29508790662212, 59.46075877835674, 62.328493825850956, 59.11992442223334, 48.714500011936316, 48.081656963594504, 47.91105739531979, 54.143723210980816, 60.42528137083977, 65.51271315543883, 62.60100833831295, 58.35613696805893, 51.70243609336115, 59.10721202050487, 64.18651665410688, 68.188444260628, 66.03299986931586, 58.01031335707634, 50.99521313944171, 59.60450972280195, 63.263637865743334, 65.44315384280297, 64.8776892692812, 66.26398824876355, 66.00622577051963, 69.71306954660724, 66.48892833340552, 72.28171994609218, 66.60277905002718, 45.885906296391646, 12.94909715652466, 8.30804188405314, 17.88083830187398, 19.896932648074245, 6.185848405284267, 1.7762227789048226, 0.2529220895901803, 0.41788986974185516, 0.3467880237487055, 6.752657371182596, 45.322238168408795, 65.31092289955386, 79.5584540213308, 69.33610623882663, 51.27748650889243, 26.696904590052945, 52.25239161522158, 69.35620446358958, 73.49841563932358, 76.83649386129072, 33.378813189844934, 0.1965791419629128, 0.19880591441066037, 0.2746999774488711, 0.20416811619314457, 0.16880060996740096, 0.0721813251654948, 0.17195289323647178, 0.154686757633763, 0.13499986079912032, 0.07923127993220284, 0.13672810919102163, 0.16020127301735265, 0.13756473849136985, 0.2125694194147664, 0.10373207410016369, 0.0926481378114512, 0.17858776624404615, 0.22193341936555602, 0.16149586967883572, 0.13276893615482316, 0.0839824959515564, 0.2529839894944622, 0.11102718466352071], [0.03927784498720881, 0.06929981567326092, 0.03119476319801423, 0.04273174090250846, 0.07671507180578287, 0.030163528412700664, 0.07870948212521692, 0.0573477293965557, 0.04560013113903903, 0.017333786912082184, 0.010163994926598766, 0.020033886783846447, 0.02886554947303188, 0.07919954857037914, 0.042037209420795404, 0.03142710617412964, 0.1068960095665628, 0.04449139889930526, 0.06156628831259667, 0.029541587592252803, 0.9569036948584742, 47.726823668326105, 70.37598932943037, 63.961729541901626, 48.62699977813229, 37.28623520943427, 25.21247967596977, 28.730386803227088, 57.95026971447853, 58.204957054507354, 33.96805124898111, 1.9930840067325102, 0.11430175088706518, 0.05486162469512033, 0.07994000319271319, 0.46690999740554445, 2.5922910148097627, 3.0193483829498295, 2.2884767238170873, 8.997059156817775, 48.26130543985675, 65.5295911142903, 69.18755823566069, 68.69992917583835, 67.65380951666063, 65.6537341302441, 62.90200318059614, 63.92619286814044, 64.94666414876139, 57.277108623135476, 56.40826832863593, 56.47530163488081, 61.12173349626603, 62.86393657807381, 60.71002975586922, 58.951917540642526, 59.13604536364156, 50.498190003056685, 55.837787043663766, 59.13104434167186, 61.869368630070845, 58.50597543101157, 56.66947857026131, 58.3842799740453, 59.77536816750804, 55.97485819170552, 58.39745521545411, 58.09424815639373, 58.43106208309051, 56.62242974004438, 56.58032309624457, 46.551732555512466, 43.816848185754594, 42.83987206797446, 48.41598410760203, 52.764786520311915, 56.806212394468254, 51.87483995191513, 54.885608150113015, 47.85057836963285, 44.79891554001839, 41.638944302835775, 50.90168814505301, 57.03290970094743, 60.488274635807166, 50.76231848809027, 59.58895752506872, 40.905190437070786, 46.67641293617987, 62.4722683045172, 51.37131744815458, 48.58626988626296, 44.9698132084262, 52.33909560788063, 49.09922176791776, 50.99483659190517, 47.80063875259892, 48.35571688990439, 41.21872509679487, 44.57027666030392, 53.14549569160708, 59.800361510246034, 57.371810328575876, 55.46187493108935, 59.16783225151801, 55.84166234539401, 45.17476489467006, 40.148047477968284, 45.132948506263, 51.0406381084073, 57.219379178939334, 59.574389842248735, 58.41253672876666, 51.74151466738794, 55.21707196389475, 52.54190960238057, 57.572678827470355, 59.18984459292505, 59.54538391482446, 57.598033028264204, 47.761301302140765, 47.238614097718276, 52.767587092614946, 55.240386532199004, 54.84910657328945, 55.78092836564588, 56.163492818032545, 56.13222760538901, 62.53681090570266, 62.48420015458138, 66.04868150526478, 58.335673962869954, 29.98994811888664, 5.15406402849382, 2.9338326233048595, 6.523040840702673, 6.539539800536248, 3.4243809071279343, 0.29503912154224615, 0.20217513845812893, 0.05944974825627381, 0.13827399801342719, 9.511411324624094, 42.67457162180255, 27.89915615512479, 33.5279691603876, 15.728517097811546, 24.714501442447787, 39.05922105235439, 40.87942438740885, 53.560690341457246, 55.254467841117616, 41.99747247080649, 0.7848755258225626, 0.14261031613474892, 0.02321784204292682, 0.06445062466927114, 0.07399626406690768, 0.018003960628242745, 0.03983576767026417, 0.010780623884901646, 0.029086650108858466, 0.029242702219034397, 0.03274865763922853, 0.052972769800333254, 0.0320434641288293, 0.026343666550312794, 0.0033048214296990588, 0.07632215297029865, 0.05272295235866501, 0.0503778538005727, 0.0311079922492706, 0.022823103748622443, 0.049098065618665955, 0.033160475863804745, 0.05340749788428507, 0.022677600669163852, 0.016765001102260525, 0.023558050198780916, 0.04318275984617011, 0.032341321029009364, 0.007983632085304107, 0.08818333908434837, 0.03653147340481801, 0.033958275997710806, 0.06814613322456999, 0.09557194301798459, 0.02192922086725312, 0.0360154404094623, 0.06347198948083867, 0.1230986006257515, 0.04331065056424949, 0.04177418462331257, 0.008510131756925296, 0.13120101464371528, 0.062410754692410274, 1.5789159147008773, 56.918247053700114, 81.06519329932429, 73.00148271745252, 58.07395773549234, 47.38623642152356, 37.34859305043375, 33.15708944874425, 53.60231453372587, 63.52304773945963, 37.973689417685236, 3.0428605406515064, 0.07521741587908999, 0.02174143356481387, 0.25014636917941035, 1.452744665645784, 5.090130865573883, 3.12096816878165, 1.9308177285617398, 10.57464526545617, 48.6571628047574, 66.58319073338663, 72.07129263108777, 69.89540484643751, 70.46054778560516, 67.43460393721058, 66.95806734023556, 67.19926957161196, 66.36077665513562, 60.650601925388465, 59.15309982915079, 58.81645064200125, 62.721429024973226, 66.02590822404431, 63.87178174911007, 61.46175984413394, 62.17709033719955, 53.75743642930062, 57.86965716269709, 61.08651061211864, 63.198032302241174, 58.09148288542225, 57.477600574493415, 60.73652144401305, 61.18697427934217, 59.28294204896497, 62.64945353231123, 60.47093383727535, 61.891761441384595, 59.735716927436094, 57.5855795029671, 48.202069805514434, 45.80071633861911, 46.14852859127907, 51.4631244444078, 55.48894713001867, 59.52281851922313, 54.08717832257671, 57.12251232516382, 50.513004795197524, 47.98926161181543, 44.11857258888983, 51.68688781799809, 59.69291602411578, 62.423340658987726, 56.47454069506738, 59.91227849837273, 42.160054714449, 48.00858320728425, 63.610606808816236, 54.93499863532282, 51.03724918057842, 48.53377288387668, 54.62595116707587, 52.114363408857784, 53.594152081397276, 50.72319284562142, 50.71955288610151, 43.03411176127773, 47.107673614255845, 55.56800642321187, 64.48460109772222, 57.586156091382435, 55.360136493559814, 62.253741295106956, 57.55270611855292, 47.79989350226618, 43.512338899797015, 45.6426565877853, 54.28563064144504, 59.85239567295198, 63.207175347112845, 60.51956338267173, 53.17111661357265, 54.73491068809263, 53.51168424852433, 57.90958296868109, 62.31516561200542, 62.86062609764838, 61.95482530901509, 49.40250335201141, 49.40262494548675, 54.013700562138716, 57.172781421292214, 57.19964965697258, 57.93309757786413, 58.279211444239465, 60.40536357510475, 64.29138514303392, 66.30671070468041, 66.41237151238226, 62.36929432038338, 33.94275196136967, 8.52534511396962, 2.048716331201215, 4.386304193927396, 3.127272398241105, 4.178036143702846, 1.3045187871302328, 0.2228692264085816, 0.12354545971198429, 0.10649521534721698, 11.104780070243343, 50.46252389107981, 35.93038558959961, 43.537802926955685, 24.75318189590208, 24.422175038245417, 46.304191773937596, 46.56650027921123, 60.67756429795296, 61.47668054026943, 53.04853470094743, 1.6022145483762988, 0.12073835267895654, 0.045399734029366125, 0.04257706008971699, 0.01827542771465115, 0.06351584801450372, 0.08530212070552573, 0.01885321888802273, 0.03915530539328053, 0.06371924818883981, 0.04155261667385217, 0.02233914302421674, 0.06338457884867826, 0.052220586371878465, 0.0766262362500833, 0.033686533119649656, 0.0530752225688869, 0.05165071654764395, 0.01394011699894984, 0.04242247503791605, 0.036114388325762366, 0.013588056505297222, 0.0579797366123286, 0.12511805435943027, 0.1547361396613621, 0.09734784973965538, 0.16579748401718755, 0.14721962202700878, 0.09159528019447481, 0.12632995182948728, 0.3075314415318351, 0.13451740926792546, 0.15438743175998812, 0.16868588063986073, 0.16158999124121282, 0.12352062314147912, 0.16523097731894063, 0.23431257284697027, 0.21863202474290327, 0.19883902473074777, 0.11639458052213154, 0.19173974922347456, 0.17569701007056623, 2.503234825788006, 68.50674460011145, 88.10474949498331, 81.53284965022918, 64.93941953105312, 53.24903057467554, 34.54741670239356, 40.14525475040559, 71.48078764638593, 72.92015629429972, 48.45342705326696, 3.8309223180817025, 0.3250853350806621, 0.12974175504378735, 0.26840840376192526, 1.7869840466207074, 9.637312543007637, 13.204937673384144, 7.051676809787751, 12.70292430154739, 51.408348544951416, 66.81475177887948, 71.91584125641855, 71.9810781171245, 73.5367528853878, 71.27816584802443, 68.37617674181539, 68.16309005983415, 70.44615268707275, 62.44806335818384, 61.85391841396209, 59.85793798200546, 66.68052042684248, 67.3289195952877, 64.69454596119543, 63.32174385747602, 65.16814078054121, 57.21262877987277, 60.9228144153472, 63.62649633038429, 65.16888603087395, 59.184521936601215, 57.15925708893807, 61.615567745700965, 64.82884399352535, 59.51017279778758, 65.39269647290631, 62.94045025302518, 63.60119704277285, 61.36761903762818, 62.22050313026675, 52.032244666930175, 48.22394094159527, 48.17644103880852, 54.51758000158495, 58.26675399657219, 61.858864522749386, 56.962530612945564, 60.48776472768476, 52.14887242163382, 51.348489253751694, 46.22231621896067, 54.61888305602535, 62.414429033956225, 65.4911244300104, 60.109428590343846, 60.72024753016811, 45.749576476312455, 52.47675511144823, 67.55548354118102, 58.724698558930434, 52.73534520979851, 51.985219370934274, 56.86829959192584, 55.50392273933657, 55.836826062971554, 54.395613901076786, 54.63065408891248, 47.49269739274056, 49.3482687396388, 58.36839437484742, 67.26851509463403, 59.97298502152967, 56.500495018497595, 64.30519973078083, 60.60083489264212, 49.976251971337106, 46.0405888865071, 49.76345162237845, 55.580173615486395, 64.68621484694943, 65.61294540282219, 62.55027640250422, 52.93396619058425, 56.228529637859715, 54.600373391182195, 60.41005472983084, 64.04939843762305, 65.12391605684834, 63.756279714645885, 54.14793975891606, 52.320542796965576, 57.26765963339037, 59.68347095674085, 61.30756362791985, 59.455989176227206, 63.248411224734404, 62.56143162327429, 69.46320672189036, 68.25963527925553, 71.36193198542442, 64.02926098915839, 37.31358197427566, 9.325471366605452, 9.7758133949772, 17.716655731201172, 17.79207898724464, 9.568624977142582, 0.6443150005032939, 0.34783201772839795, 0.19417275254043842, 0.2773957182803462, 16.353390870555756, 57.59640132227252, 35.66071087314237, 47.16537167949062, 25.66693921242991, 34.44654510867211, 54.178879414835286, 55.24114354964226, 69.92541882299608, 68.07820996930523, 63.001454876315215, 2.2223727741549095, 0.3094356909634606, 0.12068627402186395, 0.11999984391995015, 0.1867503564684622, 0.10785188045232527, 0.11206383186001932, 0.138984376023854, 0.16598724399603185, 0.12371353940257143, 0.08160401511216357, 0.14273898826251108, 0.1537341426216787, 0.20397454109643737, 0.12560304930253377, 0.1442160517457993, 0.11430940410542874, 0.18422479440848674, 0.13232291976530708, 0.11352994794686956, 0.18570136759550343, 0.1583592452469372, 0.20655316240604848], [0.0481931165972304, 0.06136781025317408, 0.17120966537585183, 0.08277648203675786, 0.0186488093928464, 0.050578499888821, 0.014721106290967475, 0.03281417730895262, 0.04154244302621773, 0.05569281860164577, 0.03440058069123376, 0.06690884760070233, 0.02595342519212394, 0.024825527347744476, 0.027474199737151785, 0.03913142260224108, 0.06818911841800136, 0.08953243524076478, 0.01963577578745542, 0.14065066322443948, 8.46966314700342, 79.1263343441871, 65.4678020169658, 59.813638733279326, 54.28182202000772, 33.39816616427514, 17.02195102168668, 28.321134544187977, 28.872013784223988, 35.349659073737364, 21.553257396144254, 0.16945817387632786, 0.11644004017955835, 0.04090959311372811, 0.09793124867663269, 0.5273299423917648, 3.4670043231979495, 3.9793546113275715, 2.9063983405790026, 34.967384876743445, 65.72828662010932, 68.03253789101878, 66.44314642875426, 68.98703098297119, 71.0234079053325, 66.20707465756324, 64.229996127467, 58.39558424488191, 61.301507488373794, 62.11713298674553, 58.44842249347318, 59.22578527081398, 63.291451392635224, 61.9949354663972, 61.2782988240642, 62.861732206036976, 60.03182841885475, 54.66501405162197, 54.245022343051055, 57.57256900110553, 60.925995457556944, 59.98344598277923, 54.79437381990495, 54.96787986447735, 57.320552795164055, 56.995368696028194, 58.93398838658487, 56.31239775688418, 56.716931404605994, 58.953043260881984, 55.29152639450566, 47.585002530005674, 42.97245602453909, 45.81957509440761, 49.238489443256015, 53.438155497274096, 54.6130112678774, 52.41493463516236, 54.16919508287984, 45.7340556575406, 43.30158995043847, 44.68808504842943, 54.89299397314749, 56.90160443705898, 56.28640813212241, 51.22204380650675, 59.46009589779762, 37.919870576550885, 46.75549968596428, 60.235422965018984, 51.812140864710656, 48.8830207240197, 42.42067660054853, 46.50613892462946, 47.64339093239077, 50.73914120274206, 47.256374589858524, 45.43861096905124, 41.79415249055432, 43.265068761764034, 52.280718972606046, 59.638391156350416, 59.69265322531424, 54.79395412629651, 57.55580479098905, 55.32752590794718, 45.488072056924146, 40.7629809841033, 44.84903950845042, 53.98730301087903, 58.56477568226477, 59.980763081581365, 54.82464275052471, 54.21807173759707, 56.35140180587769, 58.97835431560394, 58.48702253833894, 57.85089254379273, 61.21008880676762, 57.480683557448856, 49.36960643337619, 45.99377539850051, 46.63348259464387, 50.875129776616255, 52.670959503419944, 50.295768245573974, 53.18329557295769, 55.32578829796084, 57.7902840798901, 61.514715763830374, 63.04640523848995, 65.53037166595459, 53.88049687108686, 27.174415896015784, 4.004095941781998, 5.856641425240425, 4.866616562489541, 7.514333119315486, 2.7124748883708834, 0.25503517458996466, 0.09021416922370273, 0.09912322786065841, 1.5344239795400252, 24.11800111493757, 39.737077220793694, 18.79224023511333, 26.42324278431554, 22.537258478903002, 20.43036714676888, 39.83632495326381, 49.652636820270175, 52.80975649433752, 47.97968318385463, 6.902402677843648, 0.19395619480600282, 0.021046302619300062, 0.09403374571833881, 0.028286574693817287, 0.029686558240604018, 0.07450416503894715, 0.058993696114949645, 0.023829779670303388, 0.01978411147701404, 0.027869181264372125, 0.04884827115963544, 0.081727048832803, 0.044257941265260024, 0.03593972027902642, 0.13258732735149323, 0.031273082281733235, 0.028731978212993954, 0.008409604741891306, 0.06075974711547456, 0.01980754610661778, 0.05548537731350911, 0.022569475019530907, 0.02771240903154737, 0.01766547617021828, 0.018104636072812062, 0.03909306841031198, 0.07517883569122323, 0.009202045133157123, 0.03335506985745123, 0.03846856119531778, 0.024613851508606347, 0.036422631462975856, 0.0999174695161562, 0.18486064738563954, 0.03021986651865225, 0.026795198772883704, 0.025627165582151185, 0.0658058188855648, 0.02956771885135001, 0.11155990688430686, 0.04901902066663869, 0.09388975949297029, 10.973430679690454, 88.66781357795962, 75.7067100463375, 69.06119515818935, 62.6307124476279, 39.22081485871346, 19.04034976036318, 24.50021843756399, 30.521139021842714, 42.78554724108788, 23.986442858173003, 0.0557695844420983, 0.03278596612114099, 0.30461445450782776, 0.6603536947119621, 3.8573836078566894, 3.470047101859124, 1.6906447516333674, 3.569244824109539, 37.01479542639948, 65.57687528671758, 68.28279295275289, 67.68147791585615, 71.06392598921254, 70.70482515519666, 70.1202743284164, 67.23865016814202, 62.5449380566997, 64.5661275617538, 64.73506404507545, 61.13883110784716, 61.37509507517661, 65.3185675990197, 64.57318782806396, 60.142815805250606, 65.25085572273501, 62.24807739257813, 57.984782649624734, 57.88146741928593, 60.43081975752308, 63.96639324003651, 60.61987015508837, 53.98969173431397, 57.10736020918816, 57.384165794618674, 59.33710998104465, 59.466720781018665, 58.841757774353034, 56.64179055921493, 61.56804823106336, 59.92206088958248, 50.724859852944654, 45.210576134343306, 47.80329811957575, 51.505144796063824, 55.123484211583296, 56.91929040416595, 55.10868510892315, 55.78832595579086, 48.61955511954523, 45.27233777507659, 45.886137716231815, 56.53712603353686, 59.434898591810665, 59.23024108332973, 54.59976150143532, 60.54901253792548, 40.324762021341634, 48.15807650166173, 61.96425468690934, 53.497328373693655, 50.598618368948664, 45.2868034762721, 48.61140835669733, 48.91860446622295, 53.404960478505785, 49.77170036685083, 48.081762867589156, 43.92599205816946, 44.707383109677224, 54.51618363780361, 63.4683620545172, 60.87068219338695, 53.88938103952716, 58.9022760237417, 57.84417744605773, 46.68906257998559, 42.532526908382295, 46.651431360552394, 56.67890010341522, 60.865073204040534, 60.753932845207956, 55.50214982801869, 56.09638890912456, 58.767393558256096, 59.13478628281624, 58.35346975634175, 63.30184959596204, 62.446215921832675, 59.995644554015136, 51.73023000840218, 47.5967578734121, 48.32268661068332, 53.72439438296903, 53.6158977016326, 53.62703723292197, 55.44079611378332, 56.15146290871405, 61.07999947763259, 63.203107849244155, 64.37780280267039, 66.73951287423411, 55.24497962767079, 29.85370851332142, 6.33825651099605, 1.1908847814606083, 2.001325029038614, 5.78828529965493, 4.418687772366309, 0.7491166252763041, 0.14909653744149595, 0.08420577993796718, 1.4590210707918292, 28.276186143198323, 34.613108558039514, 21.869527909063525, 26.52949194754324, 25.901451841477428, 27.83009694468591, 44.115234651873195, 58.44412357576432, 58.20093270271056, 59.6614037021514, 10.016051703883756, 0.2179628009757688, 0.04210255289029691, 0.048410785159156214, 0.054063621547914324, 0.07637407840980638, 0.1142337452620268, 0.029574201870409232, 0.05648496117623103, 0.04258950901848655, 0.049187475740308725, 0.0720833731634963, 0.01029481593098852, 0.022830452447036104, 0.017342782699533047, 0.013529062947078098, 0.04553023327682768, 0.05833256989717484, 0.02709688994312479, 0.03237836904102757, 0.030037916806196014, 0.06780477210638985, 0.006294480990618468, 0.2891878951941767, 0.12319365681539621, 0.18193576965601216, 0.21234244288456058, 0.21003043549435757, 0.14929829435723443, 0.15574841760098934, 0.14763956078358237, 0.18360031017613027, 0.11971941743526729, 0.1369362706018071, 0.3762706723665038, 0.0599626287998211, 0.13360602510792594, 0.13841800722143344, 0.15285943875149374, 0.16576915408574766, 0.23391066780013425, 0.10891536370881143, 0.3108582243082985, 13.338637544262795, 99.1762904197939, 81.89695542858493, 78.80750056236022, 68.3058564893661, 46.65525959384057, 23.990949661500995, 39.53963687342983, 41.95605616415701, 49.42961477464246, 30.376280007823823, 0.48665168484853166, 0.26640496126586394, 0.3120968965513091, 0.6877565371894068, 4.987031365594556, 11.771330006660955, 7.2288791979512865, 5.201658068164702, 37.97785105243806, 66.01795365733486, 69.00221055553806, 69.21261433632144, 70.77457274160078, 73.333464284097, 69.57017760122977, 68.99809206685713, 66.1010451470652, 67.4504424679664, 66.24497259816816, 66.24352132120441, 64.47977658241027, 68.37228575060445, 66.81483807102327, 63.576431197504846, 69.16629898932673, 64.3966301794975, 60.42953322010656, 60.485474063504135, 63.08694293422084, 65.76245438668036, 61.668500131176366, 54.39560997870661, 56.841600018162886, 58.41927928309287, 59.57105974997244, 60.93621323185583, 59.665416286837676, 57.10903898362191, 63.9279422452373, 61.44129291657479, 51.89947635896745, 48.38987288936492, 50.77332465879379, 53.385348627644206, 57.74675753808791, 60.0648469309653, 57.82663660664713, 59.224082962159194, 51.92565817986765, 48.82993536610758, 49.54077082295572, 57.22990289811165, 61.096928427296305, 62.631057616203066, 55.47095129566809, 61.282052532319106, 42.33039540629233, 52.24953220736597, 64.27155756181287, 57.61615830083048, 52.50339977202877, 48.45935375459733, 51.33155638171781, 51.50268939233596, 56.33307649243263, 52.692814950020086, 51.82712039639873, 47.09183116112986, 47.766416072845466, 57.7610977234379, 67.05361627763318, 64.20329655370405, 54.44334914607387, 61.65906290854178, 60.946493764077466, 50.146314174898215, 45.119836022776944, 50.08421913270028, 59.75768612277124, 63.78465021810224, 62.26741467752765, 57.0684620641893, 56.4701594075849, 61.31328244363109, 61.90245382247433, 60.678948894623794, 64.68572455067789, 67.49929166609242, 61.10496144140921, 55.78759639493881, 50.61408427453811, 51.526733521492254, 57.69126384488998, 56.83299433800482, 56.288730175264426, 58.88494306995023, 59.75719974886987, 64.69365950553649, 66.97047771946077, 67.85477607480942, 68.75055128528227, 57.685046888166866, 35.32002164471534, 8.728192448616028, 11.987949763574909, 11.621520961484602, 18.229044752736247, 8.088654404686343, 0.4139636691299177, 0.42486935974128787, 0.20330147156792305, 2.4731745162317833, 38.78185064561906, 61.092060765912464, 28.934428499590968, 35.374581813812256, 31.563577536613714, 32.439338853282315, 53.2334783769423, 67.49454559818392, 65.00004368443643, 68.54195179477816, 13.79968568201988, 0.42126329195114876, 0.1549142704255158, 0.26937600345380847, 0.12388400162660307, 0.14833685401226246, 0.22777749045241266, 0.18144250096332643, 0.11764930996803508, 0.1548863695033135, 0.1581393933344272, 0.14103952945480425, 0.15527131336350597, 0.2151386638081843, 0.11086350231761895, 0.16941807683437102, 0.10791594072455361, 0.11110851255756234, 0.11505316822759568, 0.18523471279730722, 0.146397425823154, 0.18657904388683458, 0.0987584091302368], [0.027556682508739255, 0.030014503244010192, 0.08146277148156397, 0.02698354723472749, 0.049337173151152755, 0.07099889909788486, 0.031257595814343904, 0.08100887970818628, 0.057624877024922645, 0.023517968478582563, 0.04832791359794717, 0.031156815032684998, 0.07230130219531637, 0.0462688914229793, 0.005724582916891744, 0.09255596211240177, 0.08808978442703524, 0.04886709010949539, 0.022273027721131523, 0.0455174932346469, 21.189471290957545, 74.22255577579622, 62.24681046701247, 52.43638607763475, 36.87753208221928, 22.822455975317187, 31.423617562940045, 47.6815987402393, 42.82390017663279, 49.57276167408113, 5.155136306439677, 0.12004297467008715, 0.0993034883492416, 0.05549595698774342, 0.05974309481379967, 2.0782011555087183, 2.9677829434794765, 1.4635708976176478, 20.096665620803833, 62.36176729202271, 67.1137305228941, 67.51741301628851, 69.69323804301601, 67.60865519123693, 67.2252356621527, 65.13081550598145, 65.88908026295324, 66.75152317170175, 60.277490385117076, 59.588616278863725, 63.07112401531589, 59.467846501258116, 62.99338656087076, 58.95219602892476, 60.11590834586852, 58.860192914162916, 61.82835632754911, 59.618265474996264, 55.47372441137991, 57.75830499587521, 60.641741291169204, 57.02932465460993, 56.148819231217914, 54.76734476704752, 56.56322548466345, 56.083048928168516, 54.62347615149714, 53.68026771853047, 54.41824989934122, 57.8098370951991, 57.56075089977634, 50.77699207490491, 45.08956316978701, 44.853946393535985, 50.668715046298125, 52.99511986394083, 53.73350212650915, 51.25447004072128, 50.4216645609948, 44.659016363082394, 42.76984207091793, 45.90629085417717, 59.34177367917953, 55.330381393432624, 55.827431986408854, 54.32239501707016, 60.12924048208422, 36.46917804594963, 44.46378823249571, 64.12646124439856, 49.85601563607493, 49.396533504609145, 41.91891131862518, 44.08401258530156, 42.95128307034893, 47.21483276736352, 44.779919501273866, 43.53039749207036, 41.81235228815387, 41.838259543142016, 50.38532380134829, 59.5232617470526, 57.030532744623, 54.176439700588105, 56.80830694014027, 56.22284220110986, 45.67108592679424, 42.09518655653923, 43.495441329094675, 54.92301187207622, 59.543560012694336, 57.34906842631679, 52.754015691818736, 56.15989600458453, 58.66938921713061, 57.37039435294367, 55.83504530691332, 60.43868803208875, 57.37802336292883, 58.81415605545045, 48.4155212679217, 46.21122767848354, 45.298131281329745, 46.21688373627202, 47.91424235989971, 51.725374114128854, 51.80055810559181, 53.71203891692623, 58.420142204530784, 61.695580174846036, 64.7688474193696, 63.35200102098527, 59.66456121014011, 59.887128260827836, 29.30911683267163, 7.054431784537531, 0.6519023353053678, 1.5448386077919316, 3.583728421118952, 0.6354646625057344, 0.0772448369271813, 0.08163704116257929, 0.057260969939130935, 12.475551366806032, 36.51246532317131, 40.30006285636656, 37.371331030322665, 18.295146496065204, 29.91988478168365, 39.08348875661051, 47.917584219286525, 53.69294874129757, 60.19439889538673, 22.35106945037842, 0.5953441476148944, 0.05193820636298868, 0.04817032931192268, 0.02752984836397152, 0.02950940040811416, 0.0556978517993083, 0.06042267608967039, 0.021829953109244668, 0.06547531323327173, 0.09247301777283992, 0.04227479626875251, 0.05018848069613019, 0.023931669364232692, 0.04976944592330725, 0.04558131218917909, 0.007852913066369272, 0.038679419235596736, 0.05104350759798, 0.10180487267432675, 0.012518220464698972, 0.0021857563396840687, 0.08655547119316556, 0.02719612131195684, 0.05550205887806031, 0.011062741508677362, 0.013954686076049844, 0.013289520659694269, 0.03033852013158462, 0.028417508696175875, 0.08897972578603415, 0.09228158772232072, 0.0051272545862312046, 0.06733228737908988, 0.016369354993765874, 0.07237319954701009, 0.014870105604190501, 0.01854948609346344, 0.034978096072952596, 0.06890810725669708, 0.036341564038828496, 0.030985159626711282, 0.0621404558900864, 26.295783404381048, 84.3448595846853, 69.03369149854107, 62.61870999490062, 44.39404456846176, 33.46261855094664, 32.342923072076616, 34.903493389006584, 38.540040446865945, 50.07003976452736, 6.120994956262651, 0.052189536828307376, 0.11085379598361832, 0.22822571317515067, 2.278014291678706, 3.5754134866499134, 3.2397610718204133, 1.1030361921556535, 22.788409802221484, 62.69641999275454, 68.92468098671206, 69.53140104970625, 72.97121770920293, 68.49530696868896, 67.81038268919914, 64.46021572236093, 65.91666237000497, 67.0241435881584, 62.568107497307565, 62.55232780210434, 65.23174593525549, 62.72090734974031, 64.10504902562788, 58.99505184542749, 61.27922842579504, 61.0051175086729, 62.54018022168068, 60.91095709031629, 59.75303419174687, 60.66535395960654, 60.78924594386932, 59.37443917797458, 55.99775306640133, 53.367748952681026, 56.87240239112609, 56.28817712107013, 54.91648504810949, 53.26290007560484, 54.579745646445986, 58.861706949049434, 59.26753890129828, 52.358397591498594, 47.40555801699239, 46.76714912537606, 52.72198169462143, 55.98010240062591, 55.06276984368601, 53.992574676390625, 52.783064765314904, 47.22864735511042, 45.04408721000918, 49.04682674715596, 61.744731395475334, 58.9149139004369, 60.55706516388924, 56.20138291389712, 60.662118004214385, 38.51672980093187, 47.64421463012696, 65.94491912472633, 53.03904256513042, 52.26690046248898, 43.16304399121193, 46.340348182186005, 45.70604601214009, 49.86627655644571, 47.802415586286976, 44.93674762787358, 43.57859949911795, 43.40419915414626, 52.30220963878017, 62.28069582293111, 60.39725603595857, 54.47251589067521, 59.071898921843506, 58.693033264529326, 47.58851697368007, 44.628633683727635, 46.613364758030066, 57.214440914892386, 61.39653867290866, 57.47237989979406, 53.49641053907333, 57.76712640639275, 60.93199668392059, 60.537574906503, 58.123536494470414, 61.73382328402612, 61.47330337955106, 60.29230517725791, 51.07816734621602, 45.85063242143201, 46.8664635381391, 48.35298692026446, 51.302468084519916, 54.497399407048384, 52.200098576084265, 58.78712700259302, 61.5138332305416, 63.96015667146253, 65.74485471171718, 63.94196471860332, 59.997201734973544, 61.13040193434685, 31.781267119992165, 7.492386967905107, 0.3729721735562048, 2.962991278017721, 7.246112621599629, 2.487934640338344, 0.48668340088859685, 0.22279344499111178, 0.10277796521662705, 13.29090916341351, 43.84446951650804, 39.528285534151145, 35.193105513049716, 17.114418937313943, 33.842911951003536, 46.49932969001032, 53.335197202620975, 59.47227093481249, 68.91508686927058, 30.461705307806696, 0.6185579600353396, 0.02915991684271684, 0.07240742835546694, 0.05623941850518027, 0.04038586476517301, 0.018083618450609427, 0.10010743633874002, 0.022449176232781143, 0.06431822169331775, 0.061374793144603895, 0.03389683191574389, 0.020096114190715938, 0.018939334831591097, 0.06545015490583836, 0.025812911260272228, 0.06357363785707182, 0.024797067181357456, 0.022089846522337007, 0.04956103170350675, 0.05629011054312991, 0.014946792920630787, 0.0331555997141667, 0.08389790452295735, 0.19757301847059883, 0.1083159075689412, 0.07672516118374563, 0.11408492502185608, 0.11150235835943492, 0.103529175713418, 0.20366992921598498, 0.19776881522228643, 0.10577932150373537, 0.19233366654765224, 0.14837201744798692, 0.2090305068920697, 0.13453800171133012, 0.10230758723111884, 0.08726937320804404, 0.16052345895478803, 0.1815091965780143, 0.13579306823592033, 0.10246773025081043, 32.070269315473496, 95.15331145255797, 77.80131063153668, 71.06736983022383, 51.65590893837714, 34.12817416652557, 41.98127308199483, 68.18907968459591, 56.3706135749817, 66.86946099804294, 7.7987603602870825, 0.15408717125894564, 0.4325860101849802, 0.4516866352529295, 1.7759127890871418, 6.8828682937929715, 8.545654166129328, 4.674206164575392, 22.95414367029744, 67.3681511417512, 70.35953890892768, 70.44707052169308, 74.80486300683792, 70.95853974742275, 69.26590365748253, 64.92995092945715, 64.17878566249725, 63.4716490007216, 65.31580232804822, 66.04046021738361, 67.01265104355352, 63.99224165947207, 66.21308372866723, 60.13797952282814, 61.443046216041814, 61.13009991184358, 63.42552584986534, 64.30356410241896, 62.14796281629994, 62.83112595158239, 62.227108401636926, 59.13140519972771, 56.72724331578901, 55.805498092405266, 57.74080730253651, 58.86353477354973, 56.07163875333725, 54.134203618572606, 55.673930029715265, 60.90366148179578, 62.54185115137408, 55.845168944328066, 49.83620766670474, 49.38221293111002, 55.778457272437315, 58.90082474677794, 57.72720452277892, 55.703347806007635, 54.9672483628796, 50.75091223562918, 45.96888403738699, 50.82204441870413, 64.43473600572156, 62.16671959046395, 63.57450923612041, 60.14484759299987, 61.24625305975638, 39.85100246244862, 50.875776967694684, 69.80500205870598, 55.554180068354455, 54.35342096513318, 47.76073648083595, 49.3297786866465, 47.474701558389974, 53.48337258062055, 50.13308009793682, 48.31065277899466, 47.12273159334737, 46.946342606698316, 55.901596161627005, 65.52843401508947, 61.13094322143063, 56.30995412026682, 62.89744146408574, 61.013421166327696, 51.26481333086568, 47.069442272186286, 48.72321159608903, 60.73978093362624, 63.15574522941344, 58.706051611131244, 53.74487700000886, 60.440637450064386, 63.83710015204645, 63.091092801863155, 60.48839622928251, 64.79655896463703, 63.906804592378684, 62.87843758060087, 54.107692318577925, 49.364715237771314, 49.17257009014007, 50.43505553276309, 53.44676509980233, 56.99320747006325, 57.59383216980965, 60.6805060755822, 66.16636829991495, 66.09115292949062, 69.08339577336466, 66.05625952443769, 60.69024532072006, 63.44962881457422, 34.15222221805204, 11.511483769262991, 2.968752749504582, 9.033172418994289, 12.293798538946337, 2.2200740200857965, 0.25031308523349227, 0.18420692923809254, 0.18077948250837866, 18.43405527453269, 54.405741460861705, 55.279763206358886, 51.10935018908594, 26.333604858767604, 41.406802746557425, 52.62922940715667, 63.17321938853111, 66.79397106170654, 75.18390517080985, 34.989365839189105, 0.9716208567542415, 0.14856533207479986, 0.23534824711180505, 0.11764458320554226, 0.14636854430840862, 0.09012834439354558, 0.21779732598412424, 0.15467134394472645, 0.31267045125845944, 0.23481052999775257, 0.07981470185181788, 0.0956127678434695, 0.09032650069603998, 0.13708984058710838, 0.08742031551176503, 0.11129655649945622, 0.12771398925613012, 0.1352119905453536, 0.29991196168045847, 0.11954758391385117, 0.08520341027648219, 0.10342619817463622], [0.018969761928723707, 0.035195320303882324, 0.048660043356639725, 0.01119415527359853, 0.028362792781403953, 0.04969096021546472, 0.029028996246896928, 0.028700032346551458, 0.03765117602362748, 0.0037972237248229046, 0.08905688616176767, 0.041016427905208645, 0.03179764375090599, 0.05680554598990468, 0.028286697267885172, 0.010905835210465857, 0.03186031740399138, 0.026512251858929956, 0.08050814931911808, 0.7641784654509637, 40.9579659277393, 70.47766500903715, 64.8282281814083, 52.59076272287677, 36.30681153266661, 22.289107768766343, 20.877232974575413, 39.15936700759396, 46.836057324563306, 26.180806967519946, 0.3204516982359271, 0.08083107070096078, 0.05306874529548711, 0.1256442571719808, 2.518370516838566, 3.8923765430527353, 1.3371451847976255, 3.7903245610575524, 46.30410940416398, 69.45456181803058, 68.86717119524556, 65.73420939906951, 64.94824094157066, 63.95961930674892, 64.92357707792713, 61.68503684382285, 62.64171077359108, 64.87128011641964, 71.25054451727098, 58.98266500042331, 60.62336106454173, 60.32255057365664, 60.52460362834316, 59.29827851633872, 59.2017529087682, 59.96210436667166, 60.10863627156904, 60.76922616650982, 59.856212139129646, 60.42740337310299, 58.515000804778076, 56.32548278377902, 59.77035145605765, 58.73548115453413, 58.97611856460572, 56.420572803866484, 58.529572409968225, 54.952068790312744, 52.806987300995864, 57.50472768660515, 57.019063734239154, 51.005062210944395, 48.11410673203007, 46.47536400825747, 51.47546029859974, 53.570335449710974, 53.23637308612947, 52.9695499327875, 48.55754636949109, 42.177297453726496, 42.57646529905258, 48.36490308084796, 59.85571007574759, 53.68663372532014, 58.747479684891246, 52.136116873833444, 59.31551733324605, 37.23107099533081, 41.74806856339978, 62.11451284347042, 50.1977050688959, 53.39893964029128, 42.356310506020826, 43.21851022781865, 40.36189902213312, 43.194968162044404, 41.40401001899473, 42.99335833518736, 40.216685033613636, 42.08226626919162, 47.90227520850397, 57.36400873430314, 57.255767007027906, 53.28435936281758, 58.13926127649123, 53.61072017300514, 42.502093238215295, 41.21201784380021, 44.60549562208114, 55.39258233962521, 58.18601985131541, 57.63198506447577, 51.60894247793382, 58.75543032923053, 55.652266779253566, 56.77634354560607, 52.66786867572416, 57.77806981917351, 56.31917561254194, 56.02675899382561, 46.37723807365664, 45.71016450082102, 43.94505869957709, 47.12910544487738, 50.70668358956614, 52.72879877398091, 54.62138552819529, 58.516965912234404, 58.86702568300309, 64.55172069611089, 60.67123359249484, 63.640397210274976, 64.38890311025804, 65.84751098386704, 63.73891538189304, 38.66326170582926, 1.2072833531325864, 2.0009700545380196, 3.635120786005451, 3.430310795384069, 0.17206854186952117, 0.17939431893248714, 0.047176682630613934, 0.9255404842476692, 16.108653603061555, 33.4585432083376, 36.93055468220865, 27.0902535992284, 14.745207332795667, 24.826706724782145, 52.80169994600358, 49.24288249784901, 59.434973116843935, 36.585648905846384, 2.6285346957945057, 0.09821039579448201, 0.03504089996098511, 0.08672013413161041, 0.0433761395904566, 0.02862609720097915, 0.036719310502972335, 0.062381513116340485, 0.11165893140939936, 0.023226454786415544, 0.05002804273258775, 0.06006043907555361, 0.10812040193066483, 0.03287732593655106, 0.00413555376825013, 0.0329901400442806, 0.05319421900616539, 0.03205134908878996, 0.0390306284140435, 0.09019319373633593, 0.052206375440883065, 0.02320743282325566, 0.04337328974337828, 0.1061501770070003, 0.03207784807009082, 0.03401790062085756, 0.024925415636971596, 0.13957745065131497, 0.019009989205627673, 0.08321723540223415, 0.0753692774883201, 0.03652396957359968, 0.02175891377602614, 0.0711938071875803, 0.034669768666067434, 0.06694007334449599, 0.06402158095771748, 0.030487198645489353, 0.08318235541904166, 0.03455787769428665, 0.01272703113500029, 1.0525774739442333, 50.26416570909562, 78.83986796102216, 72.02568331072408, 59.90613214431271, 41.751904641428304, 25.24160327449922, 21.34292814039415, 39.53874649540071, 48.43790231212493, 30.71790864390712, 0.3914435033596331, 0.2630432448800533, 0.18729191934389455, 0.777207046987549, 3.5791461121651436, 4.005537412820324, 2.728361958457578, 5.853173069415554, 49.72521243556854, 70.88006880975539, 70.78146826836371, 67.48190772148871, 68.07071039753576, 66.75728905585505, 66.71757113549018, 65.44611523228308, 64.43137453448388, 65.1655206372661, 70.53925406548285, 61.84541079305834, 60.531812944719874, 61.9670944829141, 61.74090316218715, 60.469733592002626, 59.28221248811292, 61.52741247607816, 59.512808630543375, 60.68085124415737, 61.48238758887015, 61.83117258933283, 59.0239675583378, 57.11003526564568, 60.457436961512414, 58.64617663045084, 59.42974459740424, 57.14684278734269, 60.33896961519795, 54.099278834558305, 53.36552889116349, 59.35758475334414, 60.04282674481792, 53.13745483275383, 49.67218983557917, 48.95640434757356, 53.85799815577846, 56.67994345388105, 56.06469615813225, 55.456783694605676, 52.12552255199802, 44.315302987252515, 45.378269226320334, 50.53840214206327, 61.92799629703645, 56.19785278074203, 60.57938345016972, 52.861217990998306, 60.64898590887747, 38.586002780545144, 44.79585609128399, 62.21727894198511, 52.47165995259439, 55.482043758515395, 44.60873157747331, 45.70639118071526, 42.96902395063832, 45.0875666833693, 42.28415066196073, 44.65834171541276, 42.62411425190587, 44.41145596965667, 51.394569258536066, 60.17075092561784, 59.33826708024549, 55.89764633486348, 59.72270250320435, 56.684485558540594, 45.752714372450306, 43.578717170223115, 47.04160913344353, 56.97436440375544, 59.6617998615388, 57.6131223863171, 53.30982338997626, 60.23995330256801, 57.13873917056669, 60.969117995231386, 56.32122308977189, 60.023693423117365, 58.69491207984186, 59.67462601200227, 48.74325098529939, 48.18458780165642, 46.20022935252036, 50.04715273457189, 52.800138842675, 55.303018939110544, 57.1630931669666, 60.398130724507, 61.334114151616255, 67.4982875393283, 61.96831041766752, 62.81966870830905, 65.57645559310913, 66.86659766781715, 65.53818110496768, 42.28779454385081, 2.5904193087931606, 1.9138380332339195, 5.147617122819347, 5.940156530949378, 1.148017810717706, 0.3169044047113388, 0.11915134791765483, 1.081678763993325, 21.520536984166792, 38.040350098763746, 34.08553408038232, 31.12234619355971, 22.830339939363544, 32.544168118507635, 56.406487572577696, 55.381352593821866, 65.97479189595869, 47.309695289980986, 3.3565746488109713, 0.031229650842085965, 0.013906546068497965, 0.026918441252482515, 0.025583856716571797, 0.045955461870518424, 0.031119981525285594, 0.04561367557354031, 0.0708989859108002, 0.0076127818488936514, 0.08209988850379184, 0.05582365109735439, 0.046319123808174364, 0.033690961107852004, 0.012398137140177913, 0.05880599308218207, 0.083587110312956, 0.08102888226388924, 0.030788719361167283, 0.0373115960598713, 0.045791844642090226, 0.03150046866897854, 0.18023012085787712, 0.2459404698663181, 0.16404623766579937, 0.10521986281439182, 0.11599393185949135, 0.36050387808392126, 0.08520881119634836, 0.1000482100813139, 0.15779951076594093, 0.17406029386385796, 0.1843308975859996, 0.1362750141490852, 0.11617889612792962, 0.12583607026646215, 0.11638176387115834, 0.188100632400282, 0.16233579315725835, 0.08239497025046619, 0.23742716459016647, 1.1849414100570064, 63.453864974360314, 86.82264435675837, 80.86758429004301, 68.59448802086615, 50.452137454863525, 31.157661253406157, 31.4744887428899, 54.41700258562642, 62.833585277680434, 38.25185998793572, 0.5123951195949509, 0.7465042041674738, 0.3827435330998513, 1.3433204663376654, 6.262435134380095, 12.38324034598566, 7.538007565083043, 4.62968873400842, 53.02984068470617, 72.074916901127, 73.60962267844909, 69.41584017968947, 69.76963012449204, 68.02323402897005, 68.44000154925932, 67.52216692893737, 69.07984995072889, 65.51442330883395, 69.58141911414363, 66.98194672984462, 62.152940304048606, 63.48039196383569, 64.37035029934299, 62.28542620135892, 61.56064279617802, 63.47175098234608, 62.132261568500155, 63.92108986454626, 62.73592610513011, 63.674412004409305, 60.65641880035401, 57.65617824369862, 63.32711358224193, 61.58204324783818, 61.798648295863984, 61.80033099266791, 62.479642360441154, 56.59200391461773, 53.15207350638605, 61.47239338967108, 62.34230841359785, 57.770644772437315, 52.3982527948195, 50.70739353856733, 56.467688314376346, 60.53861433459867, 57.68714535620905, 58.10744693202358, 54.9751833177382, 47.793860896941155, 47.87676411290323, 52.19602323347523, 64.7788102396073, 60.039151483966464, 62.4998111878672, 55.45406156970609, 60.81088173773981, 41.243000645791334, 48.091623706202355, 65.56378241508239, 56.15922527928507, 59.18443564445742, 47.14370842902891, 48.65591156867243, 45.83307197017055, 48.383824594559215, 45.28719179091915, 48.604112748176824, 45.57714516116727, 47.17471476524107, 53.26197439624418, 62.84727042721164, 61.60172570136286, 57.6754919944271, 61.93159703285464, 59.110624482554776, 48.541052802916504, 44.98729521228422, 48.60364990849649, 60.178281876348684, 62.799088032014915, 59.12318391184653, 53.825795496663744, 63.27733086001489, 59.30658609636369, 63.731054952067716, 58.80824504360076, 62.03470045520414, 61.43724503055696, 60.66421647225658, 51.81968750492219, 50.8891640170928, 49.361749925921046, 53.18533128307712, 54.59536844684232, 57.631635973530436, 61.32790503963348, 64.37877162810295, 65.10200569706579, 70.11524584985548, 63.844011368290076, 67.15791994525541, 69.67859191279258, 70.52980115336757, 69.90523430608934, 43.5696525727549, 2.413416471212141, 5.596165157133534, 11.872794858870968, 11.763769638153816, 0.7873373034019625, 0.4275747532806089, 0.10198366993497457, 1.862163993139421, 29.617244505113174, 48.48112290905368, 52.46965562143634, 37.97996128759077, 23.396053583391254, 38.81937203868743, 65.54267614118515, 64.8921000572943, 73.0658095882785, 54.208508999116965, 3.5741580830466364, 0.18930942721424565, 0.13433088218012165, 0.2291767960113864, 0.1522993365482938, 0.15407292202355402, 0.23905949877394786, 0.1397935640547545, 0.3397117615226777, 0.11462873253490656, 0.18082773072584984, 0.12420192045430023, 0.14159955504921176, 0.06967724421091619, 0.1276054575798973, 0.12595477559032942, 0.11752052292708429, 0.16401636023675242, 0.1547834226080487, 0.14112047430488373, 0.20971290737150178, 0.1140976727249161], [0.02787984712349792, 0.06015760200699011, 0.08083420400057109, 0.0176823032914751, 0.014271254673780454, 0.06544839290361251, 0.013446656784283058, 0.022123893384911844, 0.06957715482360895, 0.05755613978591658, 0.024502841537938486, 0.06169074695677527, 0.03413051554572678, 0.06365233423909353, 0.03177864668560365, 0.07772247742621169, 0.04874745398880013, 0.047472266164878686, 0.13853203174808335, 5.422440930720299, 58.68931485760597, 60.58327051901049, 61.516194497385335, 45.57597237248575, 37.84324707523469, 26.138123735304802, 42.59998775297596, 46.11253300020772, 38.49583141265377, 9.882101781906622, 0.062016728859875477, 0.008754608608151396, 0.04415396015129743, 0.6511118551415782, 2.870152453261037, 2.485770227447633, 2.571783147511944, 27.705036094111783, 70.20297358112951, 69.91336145708638, 65.34614186133108, 63.23310613632203, 63.10233823714718, 61.63773698191489, 59.46721892203055, 60.02825906199794, 63.00151763423797, 61.66929637232135, 61.46123424653084, 61.099744689080026, 58.395858810793975, 60.04075965573711, 59.9970801414982, 60.18771909898328, 59.749033374171105, 58.423684104796386, 58.15798274932369, 57.95853022606143, 61.9557039199337, 60.99425254329559, 54.00197267532349, 58.01230984349405, 58.32733892625379, 55.13973066883703, 57.562806221746634, 54.11457607823034, 57.51438848433956, 56.660057037107414, 54.14982641896894, 58.68811068996307, 56.787369328160445, 49.86054597362396, 48.06062521473054, 46.48223207842919, 51.82930515658472, 53.37013375374579, 50.648612899165, 51.29251703139275, 48.93718081135904, 40.51927235818679, 43.953923256166526, 50.42536727843746, 56.15378495185606, 52.88401872880998, 58.24319231894709, 52.74888130926317, 59.67081346819478, 34.45767679522115, 39.710491395765736, 60.846426256241344, 50.25461081535586, 52.79329822909448, 46.69325951606997, 44.81524436704574, 39.69267599044308, 43.512072178625296, 40.893352723890736, 40.39344272305889, 39.205027318769886, 40.1169587719825, 45.46855042057653, 56.081519203801314, 55.209348817025464, 55.97008858957599, 57.175185834207845, 50.10703163762247, 41.748554937301144, 42.23730579499276, 43.4503262273727, 55.32297203617712, 58.66474120847641, 54.84965570511357, 52.85795457901494, 59.72703672224476, 55.286521450165786, 50.80413095412716, 51.254779907964895, 51.95279705908991, 53.85806875844156, 51.90485785084387, 44.903917389531294, 43.41498567212013, 44.46230557657058, 49.63899481681086, 51.71602318363806, 56.224285633333274, 57.54717557660995, 60.9582491074839, 62.73303139594294, 61.38215534148678, 61.7690069444718, 63.30446973923714, 60.39986048975299, 62.42764349906676, 61.06554554354761, 63.036434573511926, 23.005012889062208, 0.22917774596041252, 5.717529664116522, 3.9388242700407585, 2.7551588560304334, 0.8769881605140625, 0.026453416306345214, 0.07456467066320681, 9.837748600590615, 36.10816701765984, 42.391360805880645, 20.40209274138174, 31.552779251529326, 38.69040842979185, 32.764522952418176, 47.36094105628229, 52.88839609392228, 52.9701735896449, 7.6207117207588695, 0.02538719811596938, 0.03621347413788881, 0.01497378794386262, 0.08020849402753577, 0.028234224075511582, 0.05702654703430111, 0.07282786506919131, 0.1388503259588634, 0.03327180376096118, 0.030501652809400714, 0.04727705930089278, 0.05238713005617742, 0.06460797912891834, 0.041175858463130655, 0.026397252485396403, 0.013365601809064468, 0.03869353823604123, 0.032780622657869136, 0.03809095262700031, 0.07564178262386592, 0.028012370758299387, 0.020905556945851254, 0.017707691445285757, 0.06362387024226689, 0.03580141459561644, 0.035097578976063, 0.07076691235265425, 0.06072043914407973, 0.05330577289925949, 0.056134678964172645, 0.028747633219726627, 0.05079811431407448, 0.032822328484466964, 0.02683883705627053, 0.08455633411123868, 0.016466648160149495, 0.015372419880042154, 0.051190454753175865, 0.13559652071806694, 0.0318216088963973, 7.559124625498249, 71.71374505566013, 68.93396915928011, 67.792692799722, 51.50718050618326, 46.010367024329405, 34.99170749418197, 33.653987069283765, 40.769103803942286, 44.46232911079161, 11.196296811103823, 0.1047764358020598, 0.033414533602133874, 0.11411175342096437, 2.092035355106477, 7.202679726385302, 2.5114872474824232, 2.1009285940277964, 29.06518267047021, 71.77579695178618, 71.92635320848035, 66.176362499114, 66.51707526176207, 64.86837756249213, 63.03809765846499, 63.354487803674516, 61.894522789985906, 65.56977971907585, 64.58244069930046, 62.42711790146367, 63.8734919025052, 59.208821019818714, 60.211531808299405, 62.440881498398326, 60.93687611241495, 61.499559725484545, 58.69308425534157, 59.2456324638859, 60.29392119376891, 62.24369610509565, 61.93235012792773, 54.793844299931685, 60.36515928083851, 60.758016032557336, 57.15217328840687, 59.72920579295005, 56.76137970339868, 58.71422975294052, 58.615876320869695, 54.585115371211884, 59.50752127555109, 57.33062544176656, 53.45254667343632, 49.83351299839635, 48.776975524040964, 55.68800349389353, 57.76826389374272, 53.60931988685362, 52.42829815033944, 49.34167131300896, 42.94444637913858, 46.15179200326243, 52.638650940310576, 59.46197471311016, 57.101037348470385, 59.611899468206595, 54.14300149486911, 60.121462422032515, 36.27041585983769, 43.21881617269209, 63.89759486721408, 52.490126471365656, 55.15326676830169, 46.933418396980535, 47.74319564142535, 42.42206511958953, 44.41804162917599, 44.220460076485914, 43.42257938077373, 41.84601014660251, 43.27560817041705, 48.090796086096, 59.74056889933925, 57.46953225904896, 57.548791593120946, 60.02801195267708, 52.145401124031316, 44.37023970388597, 44.693474385046194, 45.623727229333696, 57.605505143442464, 60.47466008893905, 56.17651116463446, 52.494154745532626, 60.834125703380955, 57.1518006632405, 53.92602774404711, 51.47154185079759, 55.100377528898186, 55.220884507702245, 54.002702236175544, 47.249027990525775, 47.292264276935214, 47.31253116361557, 51.20954713513775, 54.990025566470244, 58.34596626220211, 60.651296184908965, 65.16057452847882, 63.95331998025218, 64.50890410330989, 62.73090547130954, 65.29027946533697, 62.60202423218758, 64.65969177984422, 63.11369742116621, 64.70201807637369, 26.375966456628618, 1.9666597343260244, 3.1275678017447075, 5.10680535147267, 5.704372563669759, 1.894989205944923, 0.02785537252953697, 0.18597012656109949, 11.02605123673716, 39.64299917221069, 38.43531316326511, 20.836222633238762, 29.605285198457782, 42.17888209127611, 39.490493497540875, 52.32099779190556, 59.82551959253127, 63.19720468213482, 11.632462413080278, 0.09590565857868041, 0.007943415342109099, 0.024621623470598174, 0.01963036337627038, 0.030026256947988467, 0.04049826901586306, 0.01857713229143091, 0.059004892489963004, 0.045627522612771684, 0.04523950674000286, 0.07238342682079923, 0.05332219399391644, 0.04297108592225179, 0.01652806925947868, 0.05326481783882745, 0.025415893854393114, 0.013529793603435881, 0.08346992950405806, 0.08909811701385245, 0.0705567361306279, 0.02878400132871203, 0.2510213335194896, 0.18496979959309104, 0.1959077118625564, 0.21741057415643048, 0.11014796853546174, 0.14838329426223232, 0.1340487626411261, 0.1930979311826729, 0.15293921914792832, 0.11782194022089244, 0.1116015054585953, 0.18280572378106658, 0.233008568625777, 0.22632020735932937, 0.1527814356790435, 0.19784165486212701, 0.17092449680691765, 0.18667753215038008, 0.23896857945909425, 10.752554170546993, 84.00406837463379, 74.84466721934658, 77.82148730370307, 61.93915936254687, 49.54731333640314, 38.516596440346014, 61.83917814685453, 63.56165562906573, 56.33057009789252, 14.444218374067738, 0.16817650877900664, 0.5498485146991668, 0.6142967338523557, 2.448089978387279, 10.41309460516899, 9.41278430723375, 5.458364938535999, 30.03186256654801, 74.1833556082941, 74.11827564239502, 71.15101829651864, 68.45520465604721, 69.26564478105115, 67.14780023021083, 65.36843269102036, 64.2772214643417, 66.57303963938068, 67.3110963452247, 64.54643726348877, 64.33456259389078, 61.95372704536685, 62.80897240484915, 63.922564675731046, 63.11962412249658, 63.53052769937823, 61.12219633594636, 60.566400404899355, 62.78012729460194, 64.75648410858648, 63.11178330452212, 57.27290776468093, 59.858820515294234, 63.92052112087127, 60.20244367661015, 61.26025592127154, 58.50195107921478, 62.66360544389295, 61.37407133656164, 54.86196802508447, 63.1174393623106, 60.08847921125351, 54.26723472533688, 51.97959469210718, 50.4720042597863, 58.54350859119047, 61.065459251403816, 56.29761826607489, 55.946142519674, 53.37166347811299, 43.765496515458636, 47.55808722588324, 55.456677790611025, 62.47888142062772, 59.28415013897804, 61.06809116178944, 57.21877905630297, 60.50405825338056, 39.339646985453946, 46.5364823802825, 64.54732371914771, 54.831204875823, 58.084332404598115, 51.50165388661047, 48.54633623553861, 45.2285994252851, 48.029689481181485, 46.78865940340104, 45.09003385420769, 44.34290862852528, 45.229619241529896, 50.47292209440663, 61.870278619950824, 59.983736238171986, 60.42079025699247, 63.321237871723795, 54.257770046111084, 47.61363583226358, 47.78737329667615, 48.409637712663226, 60.33688291426628, 64.53036339052262, 57.06638713036814, 53.20700237827917, 63.34982018316946, 61.96662379849342, 55.73094168016988, 54.77470705586096, 58.33465022425498, 58.46429632556055, 57.010720852882635, 49.9042490220839, 48.69609232871763, 49.82888067922285, 54.733584926974395, 57.20701586815619, 62.07536366678054, 63.4644083053835, 67.39366223735195, 66.98632409495693, 66.4449820979949, 67.05571082330519, 69.68609148456206, 67.37490546318793, 68.17008756822156, 67.03208246538716, 68.88734786741196, 27.905259363112915, 2.8309772908687596, 10.689948239634115, 11.814241716938636, 8.81226453088945, 1.5147357650341526, 0.17289349598990333, 0.27623742398235107, 14.078690736524521, 53.09852138642342, 54.447730433556345, 28.490741752809097, 39.914085941929976, 51.273646508493734, 46.22398714865408, 62.032170526443, 65.56511994331115, 72.84698055636498, 14.046623399180751, 0.34220448905421846, 0.14907418299586545, 0.06797209336993194, 0.13068992674591082, 0.08248078741974409, 0.14365694545690091, 0.17741925233314115, 0.14484361565161138, 0.1403341156941268, 0.12670015615801658, 0.15073907591642874, 0.15639013881164213, 0.1705500177077709, 0.1197589169286432, 0.14693236969892057, 0.15665644629588052, 0.09230925881814572, 0.2936350355946249, 0.1367419907042096, 0.13092356824105786, 0.05908753805523438], [0.02608454880124379, 0.07094623821396982, 0.027125438209623102, 0.014169809310847234, 0.05911098417615699, 0.048135671494228226, 0.05942010065360416, 0.07595429287081765, 0.021826459748309948, 0.055098472268230496, 0.023123425536698872, 0.08203546050935984, 0.07255352132262723, 0.019916868768632412, 0.03305074525997043, 0.03751161395602169, 0.03747009965140493, 0.07986980655621137, 0.2041422990300963, 18.10340339137662, 61.907129287719734, 60.23061413918773, 57.88992797174762, 43.59549706982028, 29.04743982899574, 18.52639179075918, 39.68585498871342, 45.79367960652998, 26.465088590498894, 0.7454797913951259, 0.054363962488188866, 0.11607814790500749, 0.22159595763491047, 1.8714942086127497, 2.7006827727440865, 0.6360055818673104, 4.979011589480985, 53.307854360149754, 69.59171141347578, 65.80523175577964, 60.784664615508056, 60.20403615890011, 55.45486957796159, 53.41115782337805, 51.29862808412122, 55.131525070436545, 59.602003328261844, 61.680890898550714, 60.18524408340455, 63.86696900090864, 62.65409761859525, 59.03381270747031, 62.73161542031073, 58.27058222986037, 60.47935908840549, 58.7998237148408, 59.89125851661929, 55.68583442318825, 58.66638468157861, 54.31519746780396, 57.10698758402179, 57.794728125295336, 54.68374336919477, 53.91800257467455, 52.2567532908532, 52.56151753087198, 56.11523197543237, 56.94347966101862, 55.41399063602571, 56.00612732671923, 57.48633569286716, 51.76246796884845, 49.062276963264715, 48.16511323375087, 53.68186020082044, 50.650585851361676, 53.36995724708804, 50.06291674029443, 46.233914667560214, 40.719030826322495, 46.48130639906853, 54.64713196600638, 57.83808992755029, 51.95795497586651, 58.95941319004182, 51.66194938844251, 60.06347410140499, 33.43616608650454, 42.35370997459658, 60.77968320538921, 50.41626345726752, 52.88841570577314, 47.622241512421645, 47.407770233769575, 42.81170160539689, 41.21036652595767, 39.650855679665845, 38.87363410765125, 39.02635943505072, 40.50395550266389, 42.822652862918, 54.386859170852176, 55.414496621777936, 56.415187389619895, 52.50682792355938, 42.897911379414225, 40.83550953095959, 41.75855305887038, 41.76187922877651, 52.513374359376975, 58.219057975276826, 55.94762125322896, 52.97032656208162, 59.01104727099019, 56.48968496630269, 53.29864855735533, 46.991238055690644, 49.311692637781945, 48.21692774372716, 47.998596852825536, 43.39108667066021, 44.7717256699839, 45.02389092599192, 49.59153413772584, 54.48453403288319, 56.102268542012865, 58.185898257840066, 60.00690567877985, 62.53668538985714, 60.70255764069096, 62.921924898701334, 61.02231317950834, 60.57152694271457, 55.54329549112628, 62.224005806830625, 61.7053194199839, 52.5042038579141, 8.958829775933298, 1.7891005330508756, 3.956563924589465, 4.012046340973147, 0.22431140224779808, 0.04609361816678317, 0.08522354306713228, 1.0867995408273514, 25.46007537072705, 41.558480801120886, 43.73150525554534, 45.91977204045942, 38.44875120347546, 29.560330913912868, 44.8247012015312, 50.41611832957114, 59.40959145945888, 24.34070544858133, 0.7552818557427776, 0.014442001307953992, 0.09015285920712257, 0.061236154212946856, 0.013840932553003152, 0.05257356521343032, 0.06537250423383328, 0.01517900853462878, 0.07136335010610281, 0.051594282680701826, 0.05264556215655419, 0.026655295796151605, 0.04458930876646792, 0.0223214712910234, 0.05506155832159904, 0.06338949713315215, 0.05579593786669355, 0.05024304913897669, 0.027656224143180638, 0.03756810527955813, 0.0542663935301525, 0.018892837125026894, 0.028059787770372727, 0.03976742496653911, 0.017049313567939307, 0.030922156555818456, 0.018989806619262504, 0.014668138971882723, 0.05398643052866382, 0.03745856236726527, 0.04283138212838, 0.01905485706013297, 0.08223726339037381, 0.004852146666962653, 0.08757511889862438, 0.06310239036176955, 0.08715643652624662, 0.009458199079569069, 0.005556419914242842, 0.1105576646964877, 22.929362135548747, 71.22895579184257, 67.00034264595278, 64.96049442598897, 47.99668665855162, 38.35376316501249, 24.496239193024177, 46.40225495061567, 46.977019463816, 32.936601254247854, 0.9607178321288479, 0.03722486341552388, 0.5361081455503741, 0.5754489055083645, 4.536401533311413, 5.7264206967046185, 2.3788726474008253, 6.176739190855335, 55.732832262592936, 72.3562136004048, 66.7613055629115, 64.12259378740865, 64.01425792324927, 56.91794895356702, 57.421797014051876, 53.56971571522375, 57.97357643804243, 62.180255689928615, 64.74183797836304, 64.33160904915103, 62.28077819270473, 65.04245235073951, 60.89767594491283, 63.963604434843994, 60.999787007608724, 61.90731363911783, 58.92121714930381, 59.123905627958244, 58.62669029543477, 59.38337433722712, 55.78102250253001, 57.672573751018895, 60.70950023589596, 56.97867116620464, 57.24300361448719, 55.17708732235817, 54.36241103756813, 59.57574698232836, 58.15461343334567, 56.45871000905191, 57.994514050022254, 60.953000976193344, 53.5784782901887, 50.35764363504226, 50.603246765752, 55.731675163392104, 52.87882551070183, 56.024805653479795, 53.83238115618306, 47.71526052105812, 42.74587246679491, 49.126905856593964, 56.11077616291662, 59.698042561931, 55.213357479341575, 61.296906548161665, 54.458564019972286, 59.270794468541304, 35.064620433315156, 43.409243322187855, 63.828772960170625, 54.42912270945888, 55.19644814152872, 50.727954603010616, 49.48919949993011, 44.78438708090013, 44.110778839357444, 42.64046269078409, 42.108463779572524, 41.92301019545525, 43.60526769391952, 44.28701485356977, 56.51048529532648, 56.95870237965738, 58.63167955029396, 54.107280469709835, 45.608877135861306, 43.184750387745524, 44.19160712149836, 43.29183109344975, 55.57164638273178, 59.283448034717196, 58.446951604658565, 54.79169091870708, 60.37739315340596, 56.937603950500495, 55.60953255622618, 49.29609729397682, 50.207554140398585, 50.56731785497358, 50.28073380070348, 45.31655857639928, 47.01672169470018, 46.83742623175345, 52.10091752390708, 55.63983286580732, 59.67656758523757, 60.75934963841593, 62.02787553110431, 64.11256036450787, 62.0981526374817, 64.78743160924604, 63.725257688953036, 62.403089461788056, 61.22200888972129, 65.62413200255364, 68.03537768702354, 55.47552870165918, 12.729105141855056, 1.3192816078662872, 4.117670866750902, 6.666072030221263, 3.3226848802258893, 0.17863267431816748, 0.11455353334425919, 0.6737812548395127, 30.160169178439727, 40.615911714492306, 30.091243328586703, 47.32559657865956, 43.62553850297005, 35.3952762388414, 51.092648736892215, 55.575874697777536, 65.7455607383482, 33.97102048320155, 0.9870806336402894, 0.045798563233186165, 0.09877692547536666, 0.023084872161909457, 0.02514812697265898, 0.017740052914427176, 0.05023196767715197, 0.029360557185305707, 0.09180951668249984, 0.03105933800519955, 0.08228283796098926, 0.039626943593424176, 0.003546266009159867, 0.07130236950733009, 0.017322540741353747, 0.0640886634468071, 0.037520592506494255, 0.04634129822314267, 0.012665996910072865, 0.04794639032033663, 0.05420680721140197, 0.09738721899808415, 0.13611130115966644, 0.09719104686331365, 0.20613115521207934, 0.14751502553061133, 0.12278664962298448, 0.17497062082252196, 0.14033627606207325, 0.09815699180528041, 0.10055738275930767, 0.06990191481646992, 0.15567620615324668, 0.21735904708264336, 0.15622581295188398, 0.11060783579464882, 0.20486885681748393, 0.07037233110637435, 0.12640477563705177, 0.24375840630983156, 26.922411457184825, 80.79032144238873, 74.46935915177869, 76.46990914498606, 57.593965530395515, 41.06228528484222, 26.2410290779606, 54.29327534091089, 60.62741287292973, 40.37441530535298, 1.7383469016321245, 0.22172933354252772, 0.7861693563961214, 0.8496197000626595, 5.535351749389402, 11.598520182794141, 7.779124975204469, 6.7630369432510875, 57.77546536537909, 75.46697478140555, 69.73389733222224, 64.0352229918203, 67.01408663103658, 59.161936929149014, 59.3919486384238, 56.163190795529275, 59.602128844107355, 64.31311507378855, 66.11096874360116, 67.05397713568904, 62.334699015463556, 66.61588761114305, 62.140714276221495, 66.70508230886152, 63.01540282464797, 65.48422105850713, 60.9740327250573, 62.72158591978012, 59.596064859820956, 61.68963778403498, 58.28922133291922, 58.25846210602791, 63.006177410002685, 57.16314023540866, 59.54636450736754, 57.60731335609191, 56.56529649611443, 61.63148080149005, 60.785990376626295, 56.783572473833644, 59.58448602307228, 62.64917504402899, 56.80742048448133, 52.25775741761731, 53.37593101686048, 58.3334578237226, 56.314013773395175, 59.50951383959863, 55.72314008589714, 50.48942742809173, 44.13305005719585, 51.75621963316395, 59.41769115386471, 63.43103285758727, 56.97473702892181, 63.70779137457571, 56.103213833224395, 61.39652690579815, 38.253519150518606, 48.34662483584497, 65.49529390950357, 57.816607106116514, 56.26745131707961, 54.45048393741731, 51.39694621486049, 47.92301670197518, 45.92252946669056, 44.86013981603807, 44.11910995360344, 43.49553546597881, 45.72035089615853, 46.75586446639031, 60.4902671998547, 59.95282403884396, 61.595602881523874, 59.57002424424695, 46.5393300210276, 45.65541998032601, 45.87756341503513, 45.71232572678597, 57.06333944874426, 64.7442110123173, 59.88070341848559, 54.64309976946924, 63.16690829492385, 60.88261404345113, 58.88433510257352, 51.15381809972948, 54.097600060124556, 52.97512754317253, 53.40044190806728, 48.57073337801042, 49.21321761223578, 49.86785334925498, 55.593046834391934, 59.15060912409137, 62.31173353810465, 63.20835990290489, 63.21374531715148, 67.53100795130577, 64.32581178603634, 69.02951025193738, 65.79592004899057, 66.78538891576952, 62.05696775067238, 69.31136392777967, 68.79084971643263, 59.74071402703563, 11.714937110101024, 5.8630211603256965, 10.468617716143209, 13.107624650001528, 2.142959732201792, 0.22166507408743907, 0.10746237070810412, 1.3682848815956425, 38.26073631163567, 58.709471917921505, 59.807488456849136, 52.30085642107072, 47.95758062793363, 42.89399293161208, 59.768841343541304, 61.78180956071424, 76.42808883420884, 39.27479451702487, 1.511466959791799, 0.17895283778348278, 0.20053299834891675, 0.12924664774008338, 0.1679538070194183, 0.17840295519319274, 0.17243255620762227, 0.1088656216198879, 0.16463592618463502, 0.13240463070331082, 0.1558988006605256, 0.15857191125471748, 0.15591076695390288, 0.28015817004826765, 0.19312459104243787, 0.1008648444868384, 0.13506575968236695, 0.1226634320412432, 0.13843043316756526, 0.1717329953586863, 0.17075807186624697], [0.022004421973120303, 0.023849893308755372, 0.07268426954866418, 0.039875523803094705, 0.02633087288197731, 0.02443710544837579, 0.020239661830747803, 0.029895987526904193, 0.03661885339346144, 0.015541819157078864, 0.003704904623690152, 0.03477109145493277, 0.03294196843560184, 0.011980879691339309, 0.07783501574228849, 0.07359075074594829, 0.027759988837304617, 0.03371141182499067, 0.15280723752033326, 30.17496239754462, 63.61361526673841, 62.77485562909035, 52.5192500698951, 35.985589027404785, 21.813549803149318, 36.781026086499615, 41.374749137509255, 42.68334596387802, 13.972781838909274, 0.11360838768943665, 0.029798424314527266, 0.0934117972370117, 0.24343707839087134, 3.5371926859501874, 6.97444583139112, 1.3874478662206282, 18.14076396726793, 66.85632890270603, 67.95720484948927, 64.00229077185354, 60.28138529869818, 52.51968153061406, 49.90385678506667, 46.21728774039976, 47.117828630631976, 49.63909287606516, 56.6060342327241, 60.87708350150817, 63.25276897799585, 59.48155126264019, 67.31081393457228, 61.32267652019378, 57.42990455319805, 55.35451573710288, 55.78648636418005, 56.373633800014375, 60.77397223441832, 56.35450440068399, 56.72278358090309, 57.16662330012168, 57.570913760892815, 58.06443814308413, 52.055582769455455, 51.864167182676255, 45.494598880890884, 50.96875283025926, 54.24285327234576, 57.27470421021985, 55.933790976001376, 55.967201725129165, 58.25029573132915, 53.186868852184666, 50.98377943038941, 50.5374058600395, 52.992825277390025, 50.66749518917453, 53.14624094193982, 45.15899696657735, 41.81582750812654, 40.75458711193454, 46.95679572320754, 53.66664140455185, 54.924310176603264, 52.467145304526056, 60.89705228805543, 53.45475104547317, 61.47680213374477, 33.10820887165685, 39.40067122059484, 60.2843584552888, 48.769895645879934, 53.65039886966829, 48.0701526518791, 49.89098356616113, 45.468460206062566, 45.425996626577074, 39.5571384891387, 41.780341825177594, 38.81237453030002, 40.62012434005737, 37.818406704933416, 46.330255923732636, 49.79371663062803, 51.60809524597661, 45.86406653927219, 44.01915227213214, 40.77908231366066, 41.41947592458418, 41.16800492809665, 50.4978762134429, 55.57449010110671, 57.937494554827296, 52.01995980355048, 57.28740876720798, 55.82451766537082, 53.80091590266074, 46.21729166276994, 45.370640216335175, 44.014417971334154, 45.39726918743503, 43.6055265703509, 45.11812979175199, 44.70281354842648, 50.00774468145063, 54.27298884237967, 57.314888892635224, 57.38878634668166, 60.11359414746685, 59.308751244698804, 63.57774519151258, 59.007901530111994, 58.98733262092837, 54.71918198370165, 56.33185271293887, 57.87758819518551, 65.43496785625335, 60.64840932046214, 37.54793182496102, 4.716621695026275, 3.1937470118845663, 5.475613071072487, 3.8799987685295845, 0.23619799183741694, 0.16841655476920067, 0.06251117349752496, 12.14456412100023, 47.39194739249445, 44.08342030740554, 21.057665924872122, 10.975061405089594, 26.551733747605358, 37.01891391508041, 52.16771548794162, 49.25027224325365, 45.71155301986202, 4.527851746928308, 0.146163186779426, 0.021414509373566797, 0.006133791654475875, 0.0203779541076191, 0.032798867041785876, 0.03180087855716627, 0.03153822339710689, 0.051904494663880724, 0.05425116753265743, 0.018673180564937573, 0.02755066105765441, 0.04792860558917446, 0.040658117091703805, 0.02913907925117641, 0.01985741651526863, 0.030726499615177035, 0.054108851378963846, 0.11035724843461668, 0.05188073061646954, 0.038761080377885414, 0.018165670297739488, 0.02200561515506237, 0.03430693410336971, 0.027999387483202645, 0.04533274347082742, 0.02288810247855802, 0.036566031631082296, 0.015297634376873894, 0.023016165566420364, 0.03196526761917818, 0.01725970429458445, 0.04052645722103696, 0.07870571297262946, 0.051855223719030626, 0.05022485455077502, 0.05639181254551776, 0.046125652133336956, 0.01748274121763966, 0.372798394171461, 38.013285744574766, 73.7510633468628, 67.08423429919829, 62.64003199915733, 45.37245627372496, 26.43980303118306, 24.86006256072752, 36.45611655327582, 47.62926255503009, 16.520154360801943, 0.16511497628544608, 0.06706771125356037, 0.3174612587017398, 1.1256457144214262, 6.533402762105388, 4.485714704759659, 0.7947383256208512, 18.914257326433738, 68.3549802534042, 68.54481512500395, 67.7134766117219, 61.9446232241969, 55.0308221386325, 52.2057467891324, 48.721885834970784, 49.0708081183895, 52.62394205216439, 59.26220447786393, 63.467644260775664, 64.21208266289004, 60.28552732160015, 67.79536785617952, 63.521145389926055, 59.96156700195805, 58.81682326716762, 58.24980151268744, 59.65813636779786, 61.231991321809836, 58.24420429045155, 56.75694350273379, 59.390615032565215, 60.133625691936864, 59.984438342432824, 57.00366450894264, 52.9152996309342, 48.088199477041925, 53.40787872191399, 55.160001477887555, 58.87347405956638, 55.53606264052853, 58.136264585679584, 60.39422796618555, 54.468766104790475, 52.68111451979607, 51.176371728220296, 54.98829187885408, 53.48292543042091, 57.14775277722267, 48.59914702753867, 44.47266063382549, 43.253548760567945, 50.314183773532996, 55.70182984875095, 56.71964960713541, 55.44251411191879, 62.518061976278986, 55.97814121553975, 61.43364429473878, 34.820731378370716, 41.49358518661992, 62.5500528274044, 51.664557764607096, 55.76894160239927, 49.62758464197959, 51.69476001493393, 47.80767940705823, 48.774025901671386, 41.79370141798451, 45.5993143973812, 40.77450098529939, 42.55346452036212, 41.09163245847149, 48.44926541851413, 51.41841334681357, 52.547538203577844, 48.546348002649125, 45.00501255835257, 43.044784530516594, 44.598800136197, 42.4166287145307, 52.21927112148654, 59.25724660196612, 59.35038720407794, 53.524745741198146, 60.045678307933194, 59.675492855810354, 55.24071601129348, 47.55504346662953, 47.54007962442214, 45.96533821475121, 47.109046443816155, 45.93235892634238, 47.55582794066399, 47.09149383729505, 51.80874016977126, 56.75728474893878, 58.45017187057003, 59.65754801227201, 61.804775038073146, 63.25302393205705, 63.90900111967518, 60.37719703489735, 60.23664674451275, 56.65931963151502, 56.62511656361242, 59.38369989395142, 66.53027795976209, 64.17147044212588, 41.485085410456506, 6.8135556001817035, 3.2170088733396227, 5.949714366466769, 8.304201883654441, 0.615846744227794, 0.3452956231851732, 0.0190389511596051, 11.776839956160515, 49.340125899161066, 42.48600367576846, 23.938556601924283, 18.486444411739228, 34.66228331288984, 43.971483707427986, 57.88289516202865, 55.40717355666622, 57.87250872581237, 8.018105674174524, 0.2573384332560724, 0.042901793269500624, 0.011017930153156481, 0.030534598420584397, 0.06234106367393848, 0.06838018840719616, 0.03085060585891047, 0.023988241127001184, 0.021818777801649227, 0.026604561623366132, 0.015305017549244147, 0.029523599847790696, 0.028957242536689007, 0.029039895762839628, 0.03801838111793322, 0.03127089510070941, 0.05720717907552758, 0.03939157073956825, 0.04405854006988868, 0.10985051957710136, 0.13918962630052722, 0.08941880141895625, 0.18715364047356192, 0.16003782049782816, 0.19031623528609354, 0.10012814369533332, 0.134456122233983, 0.050003776897586165, 0.10007799557980993, 0.16023669692297138, 0.13382382390479888, 0.09817141724089462, 0.16109905145581693, 0.1318203354434621, 0.17190248465105412, 0.2826798557033462, 0.17536959941348723, 0.1181229131837045, 0.5413614249517841, 49.74854269335347, 83.35351190259381, 75.64643106152936, 70.41948056990101, 51.99033806400915, 32.39966015661917, 50.51610346763365, 56.67457372911515, 59.895102439388154, 21.107438841173728, 0.46112508362820076, 0.1660918456412131, 0.426221443640609, 1.4746270785408637, 9.532023379879615, 18.44195688924482, 5.685489783363958, 21.176437254874937, 69.99511934095814, 71.81995499518611, 69.22003546068746, 63.97172766347086, 56.7960181543904, 55.90029785709997, 50.103172025372906, 52.405779823180175, 54.88696529019264, 60.6050592853177, 66.29874829323062, 66.0726942554597, 60.10437657756191, 67.97533404442572, 67.67953242025068, 61.53333133266818, 61.08848356431531, 59.335184097290046, 62.10366748994397, 63.407867339349565, 61.208731666688, 60.29925169483308, 61.11683445592081, 61.522556581804835, 63.58647638751615, 58.50365338786956, 55.718660739160356, 49.096060337558875, 55.729039330636304, 58.22284698486329, 61.481622726686545, 57.91026938346125, 58.89341146715226, 63.28080215761739, 58.90731234704295, 56.13729530765165, 54.506632666434015, 59.44539093202161, 57.7116640921562, 60.280447852227, 52.328854299360714, 46.23726437168737, 45.14164440093502, 51.167566007183446, 57.26668688558764, 61.28348811980217, 56.219935724812174, 65.26279149516937, 58.77621104640346, 63.66868142158755, 37.05731784143756, 45.67166251520957, 62.96790684423139, 55.09767893821963, 59.33021837665189, 53.786960109587646, 53.11454819094751, 51.276050921409364, 51.52101470578102, 44.95924634318198, 47.66112396793981, 43.23405065844136, 44.715223927651685, 42.7361685229886, 52.011962090769124, 54.265116645443825, 56.657436893832305, 51.52421535984163, 48.406240940094, 45.16526883648288, 47.45554078009821, 44.92596110989971, 55.00297331040906, 61.925795847369784, 62.05174315360285, 52.99169955715057, 61.9016928826609, 62.215231464755156, 58.978628881516, 50.928277892451135, 49.305828694374334, 48.096224646414484, 49.342424408082046, 47.38517345920686, 50.56292087801042, 48.9614995064274, 54.82791008487825, 60.82671242375528, 61.29570630288894, 62.14688808687272, 63.98481269036571, 65.26956150608679, 67.33703105680405, 64.69781721791914, 63.89458248692175, 60.39918584208335, 60.31796140055503, 62.99629695953862, 70.4778689722861, 65.42033741551062, 45.24039791476342, 8.584740584896458, 9.643499101361922, 13.763772460722155, 10.922685015586115, 0.4481654806483177, 0.4028150367159998, 0.23228470746788288, 15.84365729362734, 63.13880843500938, 60.38821497271138, 30.435719605415102, 18.02748199432127, 37.61109375184582, 48.30685592466786, 67.71621442610218, 61.07258619800691, 66.34233367058539, 9.635427844139839, 0.44757531715496895, 0.23262108135367596, 0.10060317949542116, 0.13422195979904744, 0.20153321806461583, 0.22498494675082548, 0.08680078786827865, 0.15750890297274436, 0.14418353897429284, 0.17596180070071452, 0.08849371960687061, 0.11437306601193645, 0.10161446152074684, 0.14494467797058244, 0.10645586907142594, 0.15577556775702586, 0.19061242019937885, 0.1703346244269802, 0.21952620256812344, 0.2665441441199472], [0.02860322947643938, 0.052568118328288685, 0.030362000726463816, 0.03624671086248371, 0.06969176923796054, 0.05481090201365371, 0.07648021989171544, 0.03517479297795123, 0.024426826463651755, 0.026567188023980108, 0.019325663395706686, 0.047394715084303776, 0.03242423089461462, 0.057028837637194706, 0.03719820738619855, 0.05875813939999189, 0.0805086549371481, 0.18646639831844838, 5.150112730841483, 45.27228678426435, 59.74381269947175, 57.48731628541024, 44.20778689845916, 30.43416438564178, 22.569325816246774, 50.51905309000323, 48.525025998392415, 34.488663519582445, 3.4790901262913985, 0.12115020154704972, 0.19779069469340388, 0.3135367434832358, 0.31707677449430194, 5.494367884051416, 1.3923356297516054, 2.501919851187737, 32.89988786943498, 70.4693260500508, 66.9242565093502, 62.612606786912494, 61.55741860789638, 57.850814096389286, 50.94235135662941, 46.23843323799872, 46.95194767367455, 45.235624390263716, 50.14051298941336, 60.68180438010924, 62.26623404410578, 61.21259127893756, 60.80480206397272, 60.35409427458241, 53.942709584389966, 52.530648477615856, 50.10283077916792, 56.097546008325395, 55.35504525707614, 59.72738189081992, 58.41407037550404, 57.56047633386428, 58.20016784052695, 55.9959291642712, 51.92097094751174, 46.038800285708525, 41.87856189666256, 47.650678696170935, 54.24342201602075, 56.520087257508315, 56.04724161086544, 55.370620989030414, 54.55050437681137, 52.97510008658133, 49.72494963676699, 51.29859278278967, 50.0213082375065, 49.86569212329004, 51.202918329546534, 43.71695326220605, 43.258573316758685, 40.160685354663485, 51.2139598015816, 52.961913078062, 56.80733026996736, 52.68265993364396, 58.25794827553534, 53.74481424208611, 62.14610753520843, 35.59867466649702, 37.6119331390627, 61.379401837625814, 48.14158685745732, 53.87920248893, 46.424565392155806, 50.26193780283774, 45.77711935966246, 48.30216084757159, 40.74110592565229, 40.46472787857056, 38.75164839529222, 41.10415658643169, 38.571466476686545, 41.15968950333134, 42.35304317166729, 44.776856130169286, 40.76431851233206, 41.851324958186, 41.072220648488695, 42.854694704855646, 40.224314043598795, 46.672557246300485, 54.65838132366058, 55.83590822835123, 52.042376149085264, 56.410853170579486, 55.31835148411413, 53.7913727760315, 46.472241801600305, 44.616007574142955, 43.65900416528025, 44.49610464034542, 43.76525332850795, 44.27983299378426, 44.92366260097873, 47.64840764384116, 52.73470586346042, 57.619370722001605, 59.328253269195564, 59.76234589853595, 59.314740703951934, 59.57928496022379, 55.75118895499937, 55.07201094781199, 50.239435165159165, 54.25537740030597, 58.66697695947463, 62.94256441054806, 61.59184132852862, 48.64556827852803, 18.613601769170455, 5.777548301604487, 3.481370003954057, 8.840211418367202, 2.412388565078859, 0.1016627786861312, 0.03574989135226896, 0.5095434951926432, 27.004963621016476, 33.87733074926561, 37.98966130902691, 15.859832167625429, 17.899018487622662, 33.40568534789547, 45.97012350636144, 45.04270261333835, 57.06615571052798, 20.588826979360274, 0.08911448831279432, 0.022805623537410172, 0.10127461725665678, 0.07380296476185322, 0.030432597643906073, 0.042146139462748845, 0.061709213506190054, 0.024386648982462865, 0.04179779928357851, 0.05520194776416306, 0.04328800883564738, 0.04782752028756565, 0.015278552084289973, 0.015373033707991484, 0.05737015279009939, 0.051958500032102874, 0.07905775335647407, 0.016934159061601086, 0.0555987008697083, 0.06882821194707386, 0.05256342603975246, 0.044631937729014505, 0.0658443148037599, 0.02942445466385013, 0.030089101055637005, 0.055942107442646265, 0.04836686150801759, 0.05097429538446088, 0.02095241854417949, 0.03063397726134187, 0.014572552266350437, 0.07042231834343365, 0.0035967816074844454, 0.018343553998537602, 0.10402294236325449, 0.03243912747430225, 0.03833495163088364, 0.14315508125770476, 7.090665169300572, 56.19481294385849, 68.73351250925373, 64.93696020495507, 47.391829721389286, 38.880164853988155, 26.574618816375736, 45.42918943589734, 44.70080137252808, 44.32381845289662, 3.8008536734888634, 0.02050088057594915, 0.33766419236217776, 0.68060893685587, 3.0253861363857024, 8.287756366114463, 2.831689936499442, 1.716285653172001, 36.59580392222251, 70.83150986702212, 70.77477670484974, 65.24242654923471, 63.928860079857614, 58.58276367187501, 53.032351001616455, 49.60105373013405, 50.615892487187544, 48.73174667358399, 53.52928784585769, 62.500748634338386, 63.297597746695246, 60.982912971127426, 62.28282959230485, 64.2507415433084, 56.81107221111175, 54.73979796132734, 53.52070569992066, 57.45982439287248, 57.84642496416646, 61.24426834044918, 60.85887585916827, 58.01409059955228, 59.93742873591762, 58.7756109237671, 54.547656736066266, 48.27681841388826, 44.16195400299565, 49.49804052229851, 56.942310794707275, 58.31403424662929, 57.6127262269297, 55.77094593355733, 56.55221146921958, 53.11668980506159, 53.03826593583631, 53.1208122161127, 52.38979616472798, 53.056599094021706, 53.64764536580732, 44.823779444540705, 45.109029892952215, 42.72122429263207, 54.43149182104296, 54.55324219119165, 60.142086244398556, 54.83069104533042, 59.959813702491026, 56.81158211923415, 65.22177134790729, 38.13900947570801, 39.58970200630927, 62.97433168657365, 51.304966634319676, 57.076789256065126, 49.81545048375284, 52.78355506158645, 48.415329071783255, 49.255802785196614, 42.43753102517898, 43.65801180562666, 42.102442941358014, 44.15423085612636, 41.68962524783227, 43.733070281244096, 44.39277372052593, 46.380905489767756, 41.93960966602449, 43.856923041805146, 41.15926196498256, 44.87901426130726, 42.139717225105535, 47.98144040569183, 55.602829225601695, 59.914671144177845, 53.508099202186834, 58.7106054829013, 58.05105501605619, 55.630933007886334, 50.32752767685921, 46.452253403202185, 46.82494917223531, 45.88367839013377, 46.41535958936138, 45.693757226390225, 47.46368362057594, 49.981904106755415, 54.40390971399123, 60.253089320275095, 60.58901286894276, 62.34656026286464, 60.949431619336536, 61.464901662641964, 58.281651158486646, 55.70315953223936, 53.87251092541603, 56.78752622296734, 59.96641505149103, 65.34523579382127, 65.86887221182546, 51.427874103669204, 22.043987089587798, 4.952290442682082, 1.3907143425556923, 9.864968868993945, 6.161562560066101, 0.24926156827038337, 0.06878588558925737, 0.6607869327549012, 32.732987096232755, 37.30628636575515, 36.91888563094601, 20.49188756173657, 27.28935899273042, 41.55453881909771, 50.66729907066592, 50.74431088662917, 66.01222699688327, 31.12488788943137, 0.011133514626342203, 0.05686614354471526, 0.054469429812724554, 0.09118711620929743, 0.02464944395356842, 0.042582284809360584, 0.016702074640160127, 0.0232456510345782, 0.03804984817942304, 0.05831910207146599, 0.005685611545378643, 0.03526830166998891, 0.04859213349259189, 0.04348834082784672, 0.058757725712512775, 0.020694497807492173, 0.03913878470719342, 0.036569908035979155, 0.02481559693302599, 0.06294330837385309, 0.13178207701252354, 0.1734387820526477, 0.16797587035163758, 0.10463215080240082, 0.10973290975896582, 0.20344373409546193, 0.15100066429905354, 0.16537541553618448, 0.15072714026656844, 0.1580188723821794, 0.19367793635014566, 0.16209009343818312, 0.12123437928816966, 0.22081123845231151, 0.17508725004811443, 0.12448050832796483, 0.2080157468275678, 0.3803636656413156, 8.917713530601995, 69.08493334247221, 75.9022637336485, 73.50965715223744, 57.17194595644551, 42.95839432747134, 35.27114891236828, 67.88418600636145, 64.33431548456993, 50.78857875639393, 5.491140263695871, 0.24168454501177036, 0.6173059272189295, 0.5586131734232749, 5.078572621268611, 17.665539403115552, 8.274431094046562, 4.333628723698278, 38.915497564500384, 71.62686455634334, 71.976332049216, 68.30415418071132, 64.54730802966704, 62.39098894980646, 55.96266354283979, 50.56905938733009, 51.42232394987538, 50.6828434236588, 54.013206343497004, 65.65317715367964, 65.75624135232741, 64.12848518740746, 63.81681757588541, 65.02611960134199, 59.31944754815871, 57.21513125204272, 55.48594651683685, 61.077014553931456, 61.41306361844463, 63.94690298265027, 63.67976603969451, 61.694795700811575, 62.11730949340328, 61.314541524456395, 56.67462079755722, 50.41038774674939, 46.59358424525107, 52.017127852286066, 59.66038780827677, 61.437178350264034, 57.789860463911495, 57.272437080260254, 58.63938308531239, 57.59141206741334, 55.29455838664886, 55.86628698533582, 55.82057960571782, 54.68183709729103, 56.03884381632651, 48.2381477663594, 47.282187707962535, 44.1344464209772, 55.85069164153069, 56.732083520581654, 63.245359620740345, 57.108289810919, 62.05698344015307, 59.04559942983813, 65.95022216919931, 39.11132581772343, 42.9967825643478, 65.09216447030344, 51.33845583085091, 60.38545362411007, 53.50397286876556, 54.64094246587446, 49.8135716684403, 52.01379776000977, 45.59509000470562, 45.499199821103005, 44.81749972989483, 47.285917881996404, 43.33292968811528, 46.80880469660605, 46.9909752568891, 49.85219916989727, 44.180859827226215, 46.830656220836026, 45.28712511062623, 47.34061925641952, 44.415068472585375, 52.06933067690942, 58.4647552428707, 61.21237554857808, 54.316013320799804, 60.624945702091345, 60.810697386341715, 58.75209239221389, 52.98403132346369, 48.46483330572806, 48.301694085521085, 49.083226342355054, 48.80518913269044, 49.26812687227803, 50.61447258918516, 53.888423981205115, 56.617856256423465, 62.884415272743475, 62.99162149429322, 65.616401010944, 63.78026500824959, 65.33342553723243, 58.712041070384366, 59.65884239442887, 55.93314378492294, 60.988333686705566, 63.43262533987723, 69.37646742789977, 66.65339331473074, 51.94475227786649, 23.836820125579838, 9.283532404130506, 10.233201961363516, 15.70296677850908, 7.09983665135599, 0.1917617206251429, 0.18436621423930893, 0.8466181062882947, 37.75964175501178, 49.81735675565658, 54.05746244615125, 23.324670368625274, 28.15527516026651, 45.22482610517933, 61.77649082676057, 59.0558328936177, 74.94062408324211, 38.42591124196207, 0.167692203315035, 0.1076156572408734, 0.15638754943445807, 0.2661041951467914, 0.07655119027702079, 0.20077705863983403, 0.2245742623363772, 0.14575541349909, 0.13162718935599252, 0.21134959293469308, 0.11295632429180608, 0.14606494366401626, 0.16697684573310037, 0.1485777426991732, 0.0684676067002358, 0.1815248554151866, 0.13912335969507694, 0.16576650342152965, 0.10729455914829047, 0.12020547724058551], [0.05044209410346324, 0.07137429750254078, 0.028754769328741298, 0.0285155545439451, 0.058643800777293024, 0.008384975015125688, 0.043274288200923515, 0.04565370366758397, 0.023312656914875395, 0.030426760053923054, 0.08594644661512106, 0.007720538818713038, 0.02060180882953348, 0.09179149063364153, 0.042681788139405756, 0.017806298452459516, 0.033342777976706144, 0.05733392066172054, 17.002237189200617, 64.64582620128509, 60.08193277543592, 54.94045465223251, 38.98990884903939, 20.836824717060214, 15.464954414675313, 29.32334326928662, 38.94209123426868, 22.022529763560144, 0.4794846565252351, 0.0965368920456498, 0.14478732351093523, 0.2699158502922904, 2.37728972588816, 4.652366407455937, 3.18851555066724, 9.078207112127735, 58.9942006911001, 58.86883389565253, 71.65019481412827, 63.37681393469534, 63.67190168749902, 55.97459147053381, 57.30756582752351, 50.01120813431279, 48.351025735178304, 44.62863760609781, 50.99344415049399, 57.474125354520744, 61.92557227226996, 60.932498747302645, 59.715712839557284, 58.08783115879182, 54.57674111089399, 47.174793212644516, 49.00921121720345, 49.60340715223744, 52.86682305797454, 54.6637196694651, 58.73719130792926, 56.51745926949286, 56.98054605914701, 55.21247102368263, 52.437872655930065, 42.42374389402328, 41.74359706140334, 45.9810669191422, 56.14405747382872, 56.74075980340281, 54.71200404628631, 52.890384735599646, 59.093562172305205, 53.14089475139495, 53.37327557225382, 51.28354657080866, 51.02692942465506, 50.90434751202984, 46.70853714789114, 40.35137922533097, 42.689837486513206, 41.401060396625155, 51.4753387051244, 49.24667935217581, 53.68779866926132, 50.35663950827814, 57.46036960232643, 51.31387825935118, 62.54474586056125, 35.82026112464167, 37.649470221611764, 60.59765777280254, 50.629138331259455, 52.38800364155924, 47.07239581692604, 49.895721789329286, 46.43661491332516, 47.84314940052648, 41.568561292463734, 41.131499428902906, 39.76699313809795, 41.900413420892534, 38.37806224822998, 40.891819077153365, 40.53070606723909, 41.140607172443026, 40.54241826457363, 41.86380201770414, 40.460805508398245, 41.54991434466454, 40.80208701472129, 45.003824080190356, 51.68797431453582, 55.5700852794032, 54.44258428389027, 52.88247723733225, 55.30430939889724, 53.55602664332236, 48.2550649489126, 43.60006663107103, 43.92526249731741, 42.88557160285212, 42.698686353621945, 43.177317496268984, 43.447733540688795, 44.53021749373406, 45.92887978399954, 53.70100921200168, 56.560024830602835, 56.33493177352413, 57.7410779460784, 56.96618626194616, 53.768603417181204, 49.70552213730351, 50.05592315427719, 54.74106096452283, 60.213187048512125, 62.08875463854883, 65.76113254793229, 57.22860459358462, 37.4852954956793, 11.246045212591849, 2.805777043104172, 8.524641048523689, 3.7511060074452436, 0.4349053260539809, 0.0514813996250591, 0.05518134765987916, 9.957703505792926, 43.06807556459981, 36.406188703352406, 29.20507596385095, 12.626650871769076, 25.500187489294238, 43.934189811829604, 47.56932089405675, 48.57919785284227, 41.53585656996697, 1.582556609665194, 0.21199270842536805, 0.04082644959130595, 0.060629879890550534, 0.03855060155112897, 0.058394726440911336, 0.016672511307162144, 0.03901881916869072, 0.028730304310879404, 0.06103491440655724, 0.035538661759346724, 0.031408264241631956, 0.017429542156957814, 0.04019484457169329, 0.021414122499165036, 0.05667687386214253, 0.04174390499810538, 0.07147711416285846, 0.03604687299699553, 0.018009076180357127, 0.023348611336381688, 0.03619963475953668, 0.02631508380985789, 0.0862023659471062, 0.047050220666513334, 0.015212787266430116, 0.0378898928512729, 0.04950005110473402, 0.019245760425204234, 0.06913393465501648, 0.017820708566315232, 0.05007291633275248, 0.03557231217142075, 0.04085670623387541, 0.021597416695928382, 0.013541359615872705, 0.03857249251356529, 0.05724590482009996, 24.039298757430046, 74.78360376050396, 66.30792663943383, 62.820766971957305, 45.51722703441497, 27.3617051493737, 16.43407892796301, 32.78731192311933, 44.0069733127471, 27.837241541954782, 0.48487460601233673, 0.14426275246566342, 0.2292487623109933, 0.7646672908336886, 3.945766620097622, 1.5871684589693624, 1.2927433415766687, 10.807902736048545, 60.24835109710694, 61.16837832235522, 73.19381221648186, 64.98837855554396, 65.46313439646076, 58.93124664983442, 58.98912122172695, 51.881135356041696, 50.78602137104158, 46.38922875927341, 54.03638755121539, 59.540943791789395, 64.35661023662936, 61.239981189850845, 60.60742447453161, 61.02432535540674, 57.50184082215833, 49.177300468567886, 50.32907701307728, 52.41422468616117, 55.38845600620393, 55.99228136001095, 59.57726886195522, 60.185781448118156, 59.47058823800857, 57.62870204064154, 55.96981402366392, 45.42218016039941, 43.80824642796671, 49.45761657530262, 58.37837680693596, 59.16137603021438, 55.601142606427594, 53.32874098131734, 60.265636982456336, 54.65629070035873, 54.82887498794064, 53.09411656471991, 54.716397100879306, 52.49839875005907, 47.784302080831225, 41.717729030116914, 43.59239055264381, 43.43248336545883, 51.97115767386652, 53.20266031449842, 58.49861314219814, 53.45947357916063, 60.740683078765876, 53.42991067517189, 64.82039128580402, 38.04881065122543, 39.20815344779722, 63.270356885848514, 53.70417848710091, 54.254592926271506, 49.20703203447404, 51.951985128464244, 49.186874974158506, 51.28921831807783, 43.95932043752363, 43.26045213207122, 43.065212234374016, 43.96050891568584, 40.784012732967255, 43.264064634999926, 41.69407713797785, 42.91097287208804, 42.76104419462143, 44.77046658915859, 43.32825422286988, 43.64113384677518, 42.38550862958355, 47.734935129842455, 53.57022562334615, 56.583272718614154, 55.427938584358465, 53.53265323946553, 59.210892031269694, 56.30444711254489, 51.096782915053836, 45.444216036027484, 45.52908435944588, 46.34429408657936, 46.05916523164319, 46.13866383029569, 46.073050422053186, 45.660593586583296, 47.99321928331929, 55.564248792586795, 58.21681437953826, 60.22648388339628, 60.33976193397277, 58.67767326293453, 55.498894260775664, 52.54613791742633, 51.6556029935037, 58.069282270246944, 63.09477590745496, 63.428797106589045, 66.34654629615046, 58.35905521146713, 39.89973398946947, 11.841588481780022, 2.0487989461229694, 5.358191036408948, 9.359102749055433, 0.8518292202103523, 0.20832783572616118, 0.15510746247826085, 10.54419590580848, 46.88506341749623, 31.080572951224546, 26.69365098399501, 19.24977687097365, 32.63730283706419, 49.987575854024584, 55.492900879152366, 53.82740759080457, 54.997497681648504, 4.379799433292882, 0.28149968193423364, 0.0777209222677254, 0.08387304496981444, 0.0973348415667011, 0.02845683198932919, 0.09075030819663117, 0.03881189498990294, 0.046237635035668655, 0.07064018608821977, 0.09895514817007127, 0.03197481307471472, 0.04222489330136488, 0.08741473839167627, 0.008975051365973008, 0.022468939386007768, 0.025244956655848413, 0.1140628463678783, 0.03935853702827327, 0.029403373839393742, 0.1340316329151392, 0.12711743658949293, 0.1407966182957734, 0.15086652230351202, 0.15812131365941418, 0.12144141454970646, 0.12258727524069049, 0.09994347820118551, 0.08328167871842462, 0.12254092692127153, 0.13908361505356528, 0.15005621578424208, 0.19472721633651566, 0.2090350880978569, 0.09119446299249127, 0.08110090985053009, 0.10930465128753455, 0.18905427397018482, 29.97793782141901, 84.11343974451866, 74.57355299303609, 71.45950486583095, 54.06948058835922, 32.58854973700739, 24.350268187061435, 44.280413504569765, 54.34441128084737, 34.125663849615286, 0.9560561564660842, 0.22114623337984088, 0.37582097875495113, 1.6569753712223423, 7.541739700302002, 16.427586424735285, 7.576937579339551, 12.597277222141145, 63.401626848405414, 62.61992200728386, 75.3751285614506, 67.08009227629631, 68.18964450590073, 59.5941036747348, 60.75412111897623, 54.35609994396087, 53.81688779400241, 48.973921652763124, 55.47843517795686, 62.65485463603851, 66.24347425276234, 62.59835681607647, 63.074567856327185, 64.5940666044912, 61.565883082728234, 49.947673582261615, 53.410808732432706, 54.22695198366719, 57.37596019621819, 58.610294788114494, 61.927294192775605, 62.815416859042266, 62.69210538556499, 59.7993181597802, 56.55962867121543, 48.73015026892386, 46.143437354795395, 51.89619333513322, 59.61391948884534, 62.548048496246345, 57.02857940427719, 55.31881040142429, 62.22913234464584, 57.97650252619098, 56.433108698937204, 55.625861383253536, 58.25137438312654, 55.75353060999225, 50.90668916702271, 43.49641407689741, 47.24413679492089, 45.650309131991484, 55.86559272581532, 55.866792971088046, 59.06074762344361, 56.31690848258234, 62.306940401754076, 56.88698184105658, 65.11266669919415, 40.80786074361494, 43.07748925301337, 64.43746989773166, 55.03037498843286, 56.55313714858025, 52.03682207292127, 55.095623616249334, 52.9191396313329, 53.24511997161373, 45.86605518094955, 45.435108292487364, 45.574681912699056, 47.1923222849446, 43.8964879897333, 44.48229005259853, 43.76967383969215, 45.352632614874075, 44.03124101700322, 47.40078449249268, 46.12435502390708, 46.26601534505045, 45.27866848053471, 50.834713674360714, 56.87102956156577, 59.848426234337595, 56.027264979577836, 54.38866738350161, 61.91357374191285, 59.09607248921549, 53.318636955753455, 48.141649615380075, 48.00517074523434, 48.70800848930113, 47.73069112531601, 48.79488506624776, 47.077204642757295, 48.32386724410519, 51.349112910609094, 58.550462953505985, 61.25120701328401, 62.25666346088533, 64.3885697087934, 61.32166454868933, 59.465085152656805, 56.071458324309326, 54.49047642369425, 61.757267290546054, 64.41933678042504, 67.85689415470247, 68.31366200600901, 61.568518915484034, 42.2549682278787, 16.47484706294152, 7.509943006500122, 17.566605460259225, 9.350395087272892, 0.5831087428715922, 0.5321509643427788, 0.37938895665349504, 13.233596471048171, 59.95075694976315, 52.22173044758459, 41.21781902928507, 18.65977591083896, 35.692956678328976, 55.42564792017783, 64.20001745223999, 60.57890884337887, 63.540098282598684, 5.515533974093776, 0.39481383057371267, 0.19897053138382975, 0.318293628553229, 0.1516101485298526, 0.16007134450539467, 0.17309428763485726, 0.1526159606873989, 0.1705728930931899, 0.21703995614042207, 0.1545676922485713, 0.15487291699936315, 0.13945855380546662, 0.2141483725919839, 0.20737246279754948, 0.11271462355169559, 0.16125061429075657, 0.2289572352122876, 0.15415509261431234, 0.17663776604158266], [0.061535798013210304, 0.03969907460193481, 0.04141376323757633, 0.015373148621180126, 0.05254232031743854, 0.08442478915376049, 0.058849284710783156, 0.014975659113617675, 0.04701584630135087, 0.012215218326497463, 0.06810339317927439, 0.03820955069855817, 0.03873628211177645, 0.01712132774804148, 0.02264214803524796, 0.07571911153894278, 0.04224318365055708, 1.0510005585608944, 33.90685442955264, 56.87649342321581, 62.826062171689934, 55.279323900899584, 36.2498273388032, 17.732806090385683, 25.599596038941417, 44.407153129577644, 37.11750268936157, 11.385028516092609, 0.09257635537294612, 0.042733579513526736, 0.2378539981380586, 0.30071359608442555, 3.556683678780833, 5.8290985418904215, 2.9640194292991393, 43.47797109234718, 66.20869067407423, 59.47156883055165, 58.57622115842758, 61.857923153908025, 62.546020630867254, 61.31615361859722, 54.37487240760557, 54.977850529455374, 48.962864491247366, 44.354577679787916, 46.70185342911751, 55.39801089994369, 61.08527506551435, 61.53259784944596, 60.338393026782626, 58.21681830190844, 52.88971793267035, 45.63284281761416, 45.39630428437264, 46.115925850406775, 47.39077460381293, 51.044999784038914, 54.77785671910932, 54.96767590122839, 55.59077185969199, 52.856515069161695, 48.63236558052802, 42.38858376779864, 41.343209358953665, 45.33452695415866, 54.92166257673695, 55.209344894655295, 52.880084591527144, 52.35857802052652, 55.28166947826263, 54.45672835073164, 55.15373745272237, 51.07765351572345, 51.23934538133683, 46.675197001426454, 43.62939027047927, 39.06255898937103, 42.488255116247366, 42.90838803014448, 48.20261501496839, 48.56543425590762, 51.010075000024614, 48.01077581221058, 54.21401208446872, 49.674778599892896, 62.352263389095185, 36.06089853471325, 35.65837706288984, 62.624621006750296, 50.68198834696124, 52.774059003399266, 45.327015615278675, 49.556581897120324, 46.764179891155614, 49.23985442807598, 42.97862983519032, 42.72801391540035, 39.33293581008911, 41.12626698709304, 38.2598812349381, 40.92713217581473, 39.80646787151214, 41.039045241571245, 39.35085319703625, 40.57076131143878, 39.32621286761376, 41.47627184467931, 40.39960868896977, 42.34151140336068, 50.38786549721995, 54.88784390111124, 54.300268926928126, 55.0262604221221, 56.27558631281699, 55.53247367182086, 48.43108915513562, 46.68135512259699, 44.128464806464414, 44.10562876732119, 41.854733497865745, 43.48410960166685, 43.50532962429909, 43.469373256929465, 43.4431561346977, 44.87134210525021, 46.822634973833644, 51.58173691841864, 51.521418709908765, 50.31007312959241, 47.18660739160354, 48.79327689447711, 53.73321971585674, 60.01569963270619, 61.97839483138054, 63.87032262740597, 59.06089275113998, 57.16909439333024, 54.765748362387384, 23.545203670378655, 2.188008643927113, 4.297780221508396, 7.620509228398723, 0.8712958820885228, 0.06988607977907504, 0.03842931451095689, 0.5465614459206981, 29.962615082340857, 46.163743465177475, 37.44450284588722, 19.309149788272, 21.283857245599073, 29.029294944578602, 40.1016576059403, 46.87079775717951, 43.88539160451582, 9.401644775944373, 0.2488126560685135, 0.02393898933434919, 0.04472645765711223, 0.025796294813194585, 0.08488105579970345, 0.05314137809158814, 0.015285048509887872, 0.023808239193092433, 0.04045048811202569, 0.08889845151814724, 0.03332109768844901, 0.03893713121332469, 0.020810376266918836, 0.027816932152716384, 0.03148874752373705, 0.03761322785829825, 0.052047818223194736, 0.02797621523871297, 0.054584875432474, 0.04753770539537073, 0.020596631990385153, 0.02629905342004232, 0.02163592793588196, 0.021858110670901595, 0.04018505779846061, 0.03958816039225748, 0.033831863829325286, 0.04233707538655689, 0.03470948266406213, 0.022212290355274757, 0.02970278206762047, 0.024063610772211707, 0.05969873066210459, 0.07168748190686589, 0.040107384143817815, 0.07963324626607281, 1.3661262296861219, 44.46094451412078, 66.38125142743512, 69.40903094507033, 62.424466379227184, 45.642519304829264, 27.184916080967074, 27.16598083896022, 36.585684207177934, 44.66217779344128, 14.437742540913245, 0.13303971759253932, 0.03279077715330547, 0.7563481888463421, 5.218600746124022, 3.90020142639837, 2.512066287379111, 3.782053753252953, 46.96339707220755, 66.22932234118062, 60.75858085386215, 62.34312818896387, 62.94954622945478, 65.89889403312438, 61.21436811262562, 56.863494688464755, 57.10737197629867, 49.56879615783692, 46.96817059670725, 48.06474762578165, 57.67186772438788, 63.29663284363286, 62.348035074049434, 63.14815936550018, 60.920002075933645, 53.65756503997311, 48.39044555541008, 48.73054642831126, 47.48861028302101, 49.76938224607899, 52.100011456397276, 56.14288860751737, 57.909057371078006, 58.62451337998914, 55.849538464700025, 50.60363115802888, 44.61133210889755, 43.75611028363628, 47.76144250746697, 57.236798424874586, 57.49551403907038, 53.43321331085698, 53.02596146060575, 57.12061782037058, 56.72325426532377, 57.188412066428896, 54.35793561320151, 54.94634212986116, 51.68576602012881, 46.83976004200597, 41.36646116933515, 45.069735588565955, 44.78329666199223, 50.08401124708114, 50.878463791262725, 53.83917077895134, 49.97625589370728, 56.35973684249386, 52.353710359142674, 64.56277785762664, 38.34648716834284, 37.631964683532715, 64.76156750032979, 52.87755858513617, 56.722720822980335, 47.11468288975377, 52.14351054160826, 48.4367177563329, 50.34669237752115, 46.25512292308193, 45.88586315031975, 41.89891899785688, 43.418641321120724, 41.55669220032231, 43.731979862336196, 41.97827246881301, 44.14776679008238, 41.85699670545517, 42.77011271445982, 41.99598197014102, 44.03435930129021, 42.949435633997766, 45.22051934273013, 51.35931499542729, 57.97952275122366, 57.725788547146706, 56.18348906117102, 57.79912902462868, 57.701913079907825, 51.436875943214666, 48.224568520822835, 46.51658419639834, 45.19625556084418, 45.40194073031026, 45.07534850028254, 46.30934576834402, 45.29877062766783, 45.35049100075999, 46.64546935789047, 50.037688055346095, 52.23527046941942, 53.21465884485553, 51.24844528013661, 50.59482935936221, 51.07153069588446, 57.374771718055975, 62.81073747142669, 62.877029449709006, 65.92616235056232, 58.38570379441785, 58.07254960460048, 56.88092570151053, 27.07418364863242, 2.9225406098750333, 2.8506648925042923, 13.695778173785056, 4.245960808569386, 0.5625024485972621, 0.03189404250963802, 0.46350194802207334, 33.87732682689544, 44.36491312519197, 31.989664608432403, 18.71018228992339, 31.452192029645367, 34.621965269888605, 47.34028585495488, 52.55415131968837, 54.80151253361856, 15.473887612742764, 0.07512638931192699, 0.07249156013131142, 0.1115984104633812, 0.028698502085922707, 0.02716449720244254, 0.02434931943313249, 0.021068810282515425, 0.036559033417893995, 0.09381379421439864, 0.05294576137056274, 0.015730517146538104, 0.05480265890758845, 0.02576733668965678, 0.05449157358417588, 0.025359517444045316, 0.0629663446377362, 0.014688876971992997, 0.013135605934827078, 0.02331226237959439, 0.12945503897724614, 0.17356639697907433, 0.18518482515167806, 0.13526952374846707, 0.18297383411517068, 0.1695377857334191, 0.14693782424494145, 0.12365321763941359, 0.157693468875462, 0.15898311660895426, 0.12971483471412815, 0.17063629452980336, 0.13753110723149392, 0.15606062907365062, 0.10560619329372722, 0.22185017625170372, 0.2885765263870839, 2.170637692174604, 57.623116585516165, 75.3455146666496, 78.51463287107407, 71.72816368841356, 50.8072139370826, 29.322896119086977, 38.160437383959376, 61.57351601508356, 52.51223294965683, 17.940130810583792, 0.2002153170084761, 0.07184985424241713, 0.6201568774638638, 6.223110921921269, 14.41920541947888, 13.82713835085592, 5.425241012727061, 51.20682501023816, 67.95532211180657, 61.926827430725105, 64.31865738284203, 64.60078562459638, 67.59836289190477, 65.81561426962575, 60.011302655743016, 59.78389932263283, 51.16281993927495, 49.1513422227675, 50.11068336425289, 60.03744917531168, 65.7280355884183, 66.13520899126607, 65.16821922794466, 63.985585397289654, 56.800168022032715, 50.685636151221495, 50.42155865700015, 50.01327130102342, 53.067899442488155, 54.71004678357033, 59.652205744097316, 61.248524112086145, 60.790250070633434, 58.08537183269378, 52.923105147577104, 47.15303190292851, 45.69012118924049, 49.412477939359604, 59.08898868868428, 58.52940767042099, 55.42484383429251, 55.84764788227697, 57.77122920559299, 58.902378005366174, 60.63792874736171, 57.00274667432232, 56.57947978665752, 51.627012837317686, 48.33626585621988, 43.4228108006139, 47.25139710210985, 47.33411596667382, 52.38297516299833, 53.89974786389259, 55.60301357699979, 54.315158244102236, 56.552552715424575, 54.60098528092908, 66.49081891582858, 40.70304324550014, 39.63047112188032, 66.11498525065761, 56.86536565903695, 57.55711094025643, 48.75559860660184, 55.20364961316509, 52.22861812960718, 53.789246851398104, 49.51710324133597, 49.62608629657377, 45.53849412548927, 46.07337597877749, 44.901246255443944, 46.173690595934474, 44.852448048130164, 47.27575109850976, 44.379555333045225, 45.049468701885594, 43.79580074740995, 45.65659669137771, 44.79865666358702, 46.5337759448636, 54.057278094753144, 60.03875532457906, 58.949140502560525, 57.10058627590057, 60.69372446306291, 60.8649790671564, 55.04891603223739, 51.17281413847401, 50.32384457126741, 47.027139509877856, 47.55607504998484, 47.75944602104926, 47.26855747161373, 47.19434622795352, 47.544657030413234, 49.048940904678844, 52.4651841194399, 54.91768529338222, 56.081931052669404, 54.438850187486224, 52.22453101988762, 55.26836479863813, 59.61649256367838, 67.5966448937693, 65.8214899801439, 67.83911797308153, 61.62666805328862, 59.2218864348627, 58.37907498882663, 28.609154185941144, 4.074895213688574, 11.977034787977896, 14.455893308885637, 2.3264940515641244, 0.31926294428206264, 0.178337209527531, 1.1979226167163541, 40.331622246773016, 62.475935720628314, 49.394231073318, 26.83310497191645, 30.933864539669408, 39.624736616688395, 56.75191894654305, 61.11306898055538, 64.34293685420867, 19.743907259356593, 0.37065092714563497, 0.16136416384289343, 0.188748482314329, 0.21905527299930974, 0.2013098574694126, 0.14672874352864682, 0.17545060555060066, 0.1524546838575794, 0.22689656594828253, 0.20147885646550887, 0.14283677172516623, 0.12375283205220777, 0.15145941306987118, 0.1709197777053041, 0.14354045412713481, 0.2349976699558958, 0.26255794350178013, 0.18218257254169834, 0.16475421016014394], [0.0652939189345606, 0.051341680509428826, 0.05371880154275606, 0.009629933967164928, 0.028188203258680242, 0.024754625910352317, 0.011669176709537786, 0.03775752817971572, 0.068629220608742, 0.04418617031807381, 0.04240231926462824, 0.018664064118638635, 0.05692505187565281, 0.0690742334230773, 0.08947228201695027, 0.09570708092782768, 0.17648732169501244, 7.64347323486882, 56.53340370424333, 60.38846208203224, 62.89055770443332, 37.68456366754348, 25.44582343870594, 13.264593981927442, 24.78668874309909, 41.35489802206717, 32.01225942181003, 6.257801344317775, 0.12345955827303472, 0.2535350978254311, 0.6658269332781915, 1.864709611381254, 3.3515172427700413, 0.35902707507052734, 24.150321445157452, 64.14647709938788, 69.50058690963253, 65.50227180604013, 63.23718932367141, 62.27624393278553, 63.0077620475523, 58.77838403947892, 58.05334175786665, 56.5241979014489, 47.432677284363784, 44.66682972446565, 44.18965378115254, 50.84951669939103, 58.51362013047742, 59.590930477265395, 61.016147213597456, 58.843773872621604, 50.235026421085486, 42.530526499594416, 42.987337496972856, 44.3556563315853, 45.72339857778242, 44.87042427062989, 48.279905319213874, 50.631154429528024, 50.94402620869299, 49.62097152586907, 46.45963138149631, 41.78924560546875, 40.82130270619547, 46.478603886019805, 55.64083699257144, 54.46847192702755, 51.950435792246175, 53.81858618028703, 53.175960740735455, 53.99144895615117, 50.734736381038545, 51.1781995527206, 53.657996500692065, 44.37812366793233, 42.848297319104596, 40.48091157790154, 41.09060479748634, 42.712194996495406, 46.87775211949503, 44.83066320419312, 49.15229535871937, 46.86977794093471, 52.1694609426683, 49.17466071344192, 61.62112182186496, 40.79471688116751, 36.31669590550084, 62.770297834950114, 50.35363105035598, 52.22021641269807, 47.13649126791185, 51.68571502931657, 47.86453416270595, 48.350311863806944, 45.03016279589745, 43.17440317523095, 38.01975373298892, 40.61337001862065, 37.30283468000351, 39.901483366566325, 39.49201929953791, 41.08769439881848, 39.87863948268276, 41.976374041649606, 40.56144175990936, 42.1766306507972, 41.837584895472375, 45.37439784696026, 49.1626621830848, 55.556941416955766, 54.426392739818944, 54.76726631964407, 54.22237065530593, 53.34173579369822, 49.724271066727184, 47.63189446541571, 45.30208503046344, 43.3574092003607, 41.61505706848637, 43.22824555058634, 42.71176353577645, 44.018481546832675, 43.23246209852157, 43.36927829250213, 42.22899037022745, 43.13990200719526, 42.96403077340896, 45.172285956721154, 44.844426801127774, 49.41591785800073, 53.61835310536047, 58.38106755287417, 59.23927430183657, 60.877087423878336, 58.245337855431345, 60.49148705697829, 58.74260417876705, 47.73784945088048, 13.08685471934657, 2.197119084096724, 4.421829590874334, 3.905115911076146, 0.35342951575594567, 0.24022815058067923, 0.073986871828956, 9.586415867651663, 34.854102903796786, 32.352925116016024, 35.44098754082957, 11.26615128209514, 30.04469263938166, 39.96848921622, 49.08271643423265, 45.67784809297132, 17.209416781702352, 1.1349001791208022, 0.06191205060590179, 0.062214640014234095, 0.05066211455531659, 0.021307235996749614, 0.054275038832378004, 0.03719252684424001, 0.01963237627229143, 0.0521652709933058, 0.02115123368228876, 0.05684601841494442, 0.03201480286436216, 0.05854702855069792, 0.036797531910481, 0.07905429829993556, 0.04622916593366573, 0.02049706162764661, 0.051998271486691894, 0.06359345272123333, 0.13805773139240282, 0.03354337043879974, 0.007996464058035805, 0.029717736103902423, 0.0963695707821077, 0.023362079162090536, 0.029038095456217567, 0.020410710112041524, 0.09503827850905158, 0.031051726921671824, 0.0254348621913983, 0.01779524571893196, 0.009682891710150627, 0.07536761507752442, 0.11733181248869627, 0.10230332778225984, 0.1991717060727458, 9.428236484527588, 68.32892002597933, 67.1236619641704, 71.40633321577504, 46.604810068684245, 33.9033595977291, 18.346043171421176, 30.813051615991903, 44.80967067903088, 37.02648801188315, 5.601107833846923, 0.1676508958541578, 0.0693395066886179, 1.0972700628542131, 3.6773171540229552, 4.46667306846188, 0.9962103179385586, 28.5891834382088, 68.29009640601375, 67.89150514910298, 67.4390911286877, 63.413299822038226, 64.71402837384132, 63.60245612359817, 60.67919992631482, 59.142003443933305, 57.968622484514796, 49.404613587164114, 47.573521752511304, 46.40493000707319, 54.24467325210572, 60.748174805794996, 61.37424784321939, 62.076673738418094, 60.15150777755245, 52.700553786370065, 43.99600244337513, 45.84872222715809, 47.09543189694805, 47.219896547255985, 48.32714242319907, 49.18418815059047, 52.70165597238849, 53.99076646374118, 53.20671996762676, 47.19809993620842, 43.22152653048116, 43.36809765908026, 47.731569736234604, 58.27237475302912, 55.251777095179406, 51.99746893298242, 52.43895523009762, 55.402513780901515, 54.37102456246653, 56.20582695930235, 53.84224983953661, 55.10545699827133, 47.544123588069795, 44.839951376761164, 41.89663225604642, 42.95100065969652, 46.62514363565753, 49.00569677352906, 48.91623535463887, 51.47158107449932, 48.98318236873996, 56.50526462062713, 52.420704441685835, 64.46405572275962, 43.29620061382171, 40.23071142934984, 64.40006617576846, 54.99123365648332, 55.80788289347003, 47.61331812027962, 52.77313724640877, 49.54772518527124, 49.77075899800947, 46.33515104170769, 44.648186699036636, 40.81505829288114, 43.410863261069025, 41.78233046685496, 41.622027120282574, 39.192832669904156, 43.087118671786406, 42.596955760832756, 43.68185981627434, 42.88599129646055, 43.78508483209918, 45.527758598327644, 48.84757034240231, 51.710414194291644, 57.56584605863018, 54.896782982733946, 54.248430882730794, 56.36258056086879, 54.763449853466405, 50.58800443526238, 49.02201383344589, 47.62586186009069, 45.76005312704271, 44.697502659213164, 44.89103240351523, 43.4305182580025, 45.57551737754576, 45.88104647974814, 44.314518513218054, 44.94977774158601, 45.993445919406035, 44.49112715259675, 46.71494237838253, 45.00771114903112, 50.88508082974342, 56.400317684296645, 62.712462486759314, 61.98030110328429, 63.61723169203728, 60.58532584098078, 62.188406375146684, 59.17337063820132, 50.352995626388065, 15.271604118808625, 1.9113733138768905, 8.22265874954962, 6.974186954959747, 2.0654713482626024, 0.2312968524112817, 0.10246125680785026, 10.41789754744499, 41.62557686528852, 25.623057696127123, 30.831937828371604, 16.885954603072136, 37.23300864619594, 47.25486839971235, 54.35558219109812, 54.24760718499461, 28.744934874196208, 2.015086787362253, 0.12463440007019429, 0.025279229514360912, 0.07075347517046236, 0.008550873270348437, 0.07815871087293472, 0.03360194169105061, 0.010576496884647396, 0.024356304239782117, 0.06647488177423516, 0.03477822756394744, 0.05909608759646935, 0.05548384130722093, 0.0467480372847809, 0.0058743521484786706, 0.0116398815073133, 0.020055216586878224, 0.03328710636724869, 0.11153101004780301, 0.27017904745955623, 0.18891185822506107, 0.17399905279519098, 0.07750614185727413, 0.3078344446276465, 0.11454518298588454, 0.07760743400262249, 0.14253318640253237, 0.1278058891635268, 0.10253295497668367, 0.07358711182830796, 0.09271386815535446, 0.11215711072567972, 0.13507882914235517, 0.270976790136868, 0.2327041865717019, 0.3022906646853493, 11.458802415478615, 78.73099865451937, 75.89966712459442, 79.29443144029187, 51.98073217945715, 36.438920882440385, 20.172565444823235, 39.3959016184653, 58.00828549169726, 44.98710693851594, 8.6413727460369, 0.48185726147024865, 0.5607196700669105, 1.5419420599937441, 6.0993591623921555, 13.279979478928352, 2.877628245661336, 32.051306616875436, 67.01989958363195, 71.173948472546, 68.37632579188194, 66.32036055288008, 67.05848001664685, 67.64199533770162, 63.27436947053479, 61.54053672667473, 59.59788876195108, 52.1176895787639, 47.96510373392413, 48.402797099082704, 54.87787715850338, 62.788356427223455, 62.0417058083319, 64.76422294493645, 63.116713723828724, 55.896085231534904, 45.749737293489524, 47.9436287572307, 49.233194243523386, 49.98417908145536, 49.836996063109375, 51.36680280008624, 56.096455589417495, 56.60540273112636, 56.277861287516934, 48.44020866578626, 47.342376478256725, 45.05675646566576, 52.819338844668486, 61.16813121303436, 56.77033839687225, 56.60408873711863, 56.766706282092684, 58.44731638508459, 58.02843470727244, 57.92772393072806, 54.641377848963586, 57.74267435073853, 50.087039316854174, 46.95585435436618, 45.35788466853481, 45.270764904637495, 47.99923227679346, 51.818063643670854, 50.72477748317104, 54.93665387553554, 53.44507848062823, 59.65982298697195, 53.58550325516732, 67.5544794144169, 44.64356222460347, 42.88433213387766, 66.45446638907156, 56.620601915544086, 57.59865276275143, 51.43184746465376, 55.930029423006125, 51.691853538636245, 53.39525653469948, 49.83645869839577, 48.64006519317628, 43.5157552842171, 44.793683098208525, 42.68270269516976, 43.521309360381096, 42.4754838789663, 46.614043328069876, 46.515438864308024, 46.57086195484285, 44.7593427473499, 45.14246417630104, 48.176966636411606, 51.83256464619791, 55.33391937132805, 60.508188509172015, 55.66473599403135, 56.77623371924124, 60.20014516768917, 57.85479922448435, 53.17746693088163, 51.46020227862943, 50.21416725650911, 48.19547630125477, 48.1549503726344, 46.78732579754245, 44.170394943606475, 47.63963722413587, 48.75021711472542, 48.37142598244452, 47.79711254181401, 48.15334220086375, 48.38233409389373, 48.90436234012727, 49.18030892649005, 53.58777822986726, 58.60743538025887, 64.84548661016649, 64.11170136544013, 66.28014841387349, 61.86300654565135, 63.55132018366168, 59.642352750224454, 51.580889686461425, 17.271439260052098, 5.996522951510645, 9.554542687631423, 10.264204375205502, 0.8874054241084284, 0.4839078949824457, 0.22953765406723947, 13.113854354427708, 49.36465640221873, 46.23580917235344, 48.271331018017186, 16.294462161679423, 43.87273019359958, 52.69190888251028, 66.68025370567076, 60.600929029526256, 41.567666992064446, 1.7183955206025032, 0.23118933963198818, 0.20969029245597703, 0.17003964993261522, 0.1481181052663634, 0.19682389173296191, 0.12851987544807697, 0.1692083372824615, 0.11023763146611953, 0.16987512488999676, 0.20219688003341998, 0.1743082152379136, 0.1065413568228964, 0.1704887919608624, 0.158314750860295, 0.12993306252023867, 0.20797600218605614, 0.20876501146103107, 0.17755382333792027], [0.033012843059916655, 0.028511886898007606, 0.05470232820258506, 0.041689711938341784, 0.038998130964295524, 0.045864167172581925, 0.07521525551114353, 0.09099816062277363, 0.0660908495586726, 0.026198778256413438, 0.01913546291630595, 0.047117180581535065, 0.05441532868351187, 0.08334616033901131, 0.03770857899179382, 0.1125686914629994, 0.05401868666071565, 13.44193708512091, 63.0798787455405, 56.76358407543552, 47.92662920490388, 25.63393638980004, 19.81138183224586, 23.089051631189164, 40.699062039775235, 37.947860610100534, 33.563509756518954, 1.5160648356522284, 0.028175514927434347, 0.04676149744961051, 2.0087266641278423, 4.783123029816536, 1.7681446575349378, 9.307532406622364, 59.509815862101895, 68.0391510071293, 67.65573932278541, 61.40106901045769, 63.56853938871815, 62.18916339258995, 63.43272732150171, 59.19650869984781, 59.55475053479595, 56.02875155787314, 50.41722443795974, 45.05549738484044, 43.58973903040732, 45.222488372556626, 56.14738756610502, 60.19177090737128, 58.37914166911956, 56.163885055049775, 48.5261477962617, 41.61552775290705, 43.52133289460213, 42.72511136147284, 42.55431175231934, 42.047616051089385, 43.87925309519614, 43.63641131308771, 45.922772653641246, 45.154725505459695, 42.940912323613325, 40.62672176668721, 40.10902773949408, 43.55804627941501, 54.15976178261542, 56.1114586553266, 52.8046299565223, 49.96781103072628, 52.092456971445394, 49.41256815387357, 53.77914674820439, 51.87503214805357, 48.84380486703689, 41.22658160425002, 42.76557060980028, 40.78275757451212, 40.888147738672075, 41.74230267924648, 46.07483117811142, 42.16280821830996, 48.40365609815044, 46.652357039913056, 54.13015181018461, 51.19329283314367, 62.34585423623363, 39.43099114202684, 35.06118443704421, 63.11225791131297, 49.641854224666474, 52.63452852925947, 46.547920011704974, 47.27505291661909, 45.99843125189505, 47.03572557818505, 42.933424518954375, 41.979331508759536, 38.18297924533967, 39.51166252936087, 39.101233559270064, 40.38178543890677, 40.55267134020406, 39.8130613757718, 40.13402108223208, 40.253716130410474, 41.281290823413485, 42.86700702482655, 45.311698759755785, 50.085701788625414, 53.869169066029215, 54.24388485570108, 54.99266924396638, 57.085010543946304, 57.35395962192167, 52.09128810513405, 51.16918202369444, 48.57610702514649, 48.09120401259392, 42.96791784224972, 42.1837301408091, 43.34200997506419, 41.54268541643697, 43.76291167351508, 42.421186508670935, 42.92924719472086, 47.22291677228866, 44.08984514974779, 43.08071736366519, 43.7632489973499, 43.39988846932688, 44.88548617209158, 55.1634100175673, 59.10026158055952, 61.50594926649525, 61.05895988402828, 63.160181430078325, 59.45214917582851, 64.7422968956732, 58.131946056119865, 36.02738188159081, 4.149059634054861, 11.014415525620985, 9.839628396495696, 5.069531067725151, 0.10615534043960995, 0.0633820086236923, 0.8584563097646161, 26.860269346544822, 46.16170383268788, 34.531452655792236, 27.864668715384703, 19.346747667558734, 30.721758450231246, 44.06889577065745, 48.479565728095274, 37.328828227135446, 5.4027069960871055, 0.19382625097228637, 0.03353916844653507, 0.05033034485794845, 0.03573327490519132, 0.03719698930639894, 0.01442671498103488, 0.028324101510788166, 0.035959129116588065, 0.08044673205022851, 0.03421416085573935, 0.026348944896111087, 0.08738756525300204, 0.009395626933133651, 0.07104278061418765, 0.042428756958895156, 0.02358499734151748, 0.08951338263408792, 0.07008422075981094, 0.09144571684901753, 0.054311094760534265, 0.045881599503298925, 0.028411153996843967, 0.022135647088890115, 0.03512341912174898, 0.06196305290946077, 0.08378455415368082, 0.05588211126685624, 0.014789836826704204, 0.02346915910170684, 0.04122858829495888, 0.08226903305659372, 0.11007132143863749, 0.023284960921192845, 0.11585451151815154, 0.06007913545134568, 19.870382124377837, 72.93444941120764, 64.95084931773525, 54.053442016724624, 33.4707849256454, 26.00747154605004, 22.94946820505204, 34.52304309414279, 38.91957290710942, 38.540981815707305, 1.3259687587138147, 0.11005449814782028, 0.10463035049577875, 3.710024818297356, 5.0226950260900685, 0.6867153317697587, 11.401452460596639, 62.871702871015, 68.58466640595468, 70.7293164345526, 63.046130672577895, 67.91790270036267, 64.09134818661597, 67.38551155213388, 61.3815865978118, 62.19632171815442, 58.52054703620173, 52.4131146554024, 46.136588896474535, 46.113588117784076, 46.094874489691954, 57.59500888086135, 60.92947459989979, 61.6233261939018, 59.37974614481772, 50.22998617541406, 43.80890930852583, 44.98027809204594, 44.52958206976614, 44.29561661135766, 43.38605034735895, 46.197154214305264, 45.560024015365116, 49.79863920519429, 47.76151703250024, 44.6905404521573, 43.30332756042481, 43.130751117583245, 45.851997406251975, 55.48159268594558, 57.70121097564698, 55.13643587789228, 52.78195473455614, 55.55423890390704, 53.66707678764097, 57.40563684894193, 53.947094794242616, 51.632359027862556, 44.6549214086225, 43.656195748236875, 41.67592833119054, 43.53345694080476, 42.823127469708844, 48.36185539922407, 44.97496720283262, 51.1393484761638, 48.81686210632325, 58.18020689872004, 53.188347585739635, 64.41330025272985, 39.07364360747799, 36.802061757733746, 64.30745117125973, 52.567342250577866, 53.54604028886365, 46.83003256397863, 50.09979486465455, 47.48294638049218, 49.84054973048549, 45.186100544468054, 44.8384020405431, 40.38791218111592, 41.85251735871838, 41.534719082616995, 42.4494001173204, 41.304009191451534, 42.03686091207689, 43.02589439576672, 43.137274019179806, 44.485259286818966, 45.47120194281302, 46.858685478087395, 54.280857116945334, 56.151686483813876, 55.62767351827314, 57.69652374329106, 59.52995723293674, 59.327649224189024, 54.87841452321699, 53.44431361844463, 50.7575253517397, 51.09260559082032, 44.64906530995523, 43.78213128735943, 45.42277243829543, 43.11301808203421, 44.69599646906699, 45.268482085197206, 45.77273414980981, 47.524084198859434, 48.35753686966435, 45.4320998345652, 45.382870166532456, 45.57040260684106, 48.1182683667829, 58.39700806525446, 60.862853142523, 63.04466370613345, 61.74508048642067, 64.05245396398729, 62.50956612248575, 67.14476431569746, 60.70857063416512, 39.492525285290135, 4.881184735605794, 3.590127277758814, 9.00832518454521, 6.630333354396205, 0.6552424173681968, 0.21970087061485938, 0.6286523022478627, 33.253030623159106, 46.66988611221314, 28.0249132264045, 23.955793457646525, 28.011182969616307, 34.593939935007405, 51.20977463260774, 53.685041243030184, 51.419582213124926, 10.234163922648277, 0.1617622078065911, 0.0815309839503419, 0.06744671793233964, 0.10219911684191997, 0.04385332809761167, 0.006676189565745693, 0.04802242837726109, 0.04632172084623768, 0.03698037028492939, 0.022315147235208464, 0.03767583256347045, 0.14167959591554058, 0.04538990895173723, 0.12218807448422718, 0.028026918767981475, 0.06156332738276932, 0.01729480069761555, 0.011885923093124744, 0.09991639699306219, 0.09697708616694135, 0.09694863366143358, 0.20808481731482092, 0.12594660909305658, 0.14169217507925727, 0.18491283329504152, 0.1438683091152099, 0.13542392110872653, 0.16418836229751188, 0.12813428041314887, 0.17295841428060688, 0.12295529621863559, 0.3888769249521917, 0.14028174592362297, 0.21122611488305756, 0.17300808742161722, 25.500044322782948, 83.12980344218593, 71.14061617082166, 64.91926247073759, 39.16943965419647, 29.034117498705466, 33.64087066342754, 56.4653858830852, 49.74954682011759, 45.39295458024549, 2.037104399454209, 0.2516632232694857, 0.16138242737900826, 5.158332547833843, 12.203215322186871, 7.588149184180845, 13.629786256820926, 66.08433585013113, 69.48729791948873, 72.73464387462985, 63.97890952325637, 68.71496754307901, 65.83264520091396, 69.10608276244133, 64.22414787354009, 65.37786599128478, 60.38908573888964, 55.63961321307767, 49.068611591093, 48.17632729007352, 48.22230139086324, 60.684149957472286, 63.898120464817175, 63.82746288853308, 62.48864027761645, 52.234917456103915, 46.53577243128131, 47.91750969425325, 45.43335107065017, 46.73219688477055, 46.399466145423155, 47.951795131929465, 47.91164182847547, 51.879334988132605, 49.23582615390901, 47.33660667173324, 45.19626732795469, 45.33086346041772, 47.448362842682876, 57.6488983246588, 60.62346304616621, 57.18795707148891, 54.26298287607009, 59.044485476709184, 54.594293717415106, 58.62517626054826, 57.236370886525805, 53.65402313970751, 46.551983587203495, 46.428134749012614, 44.10660935986427, 46.8827296072437, 46.59243106842042, 51.26702162527269, 47.94693139291579, 52.99876766820108, 52.717561183437226, 60.29726305315572, 55.16252748427853, 67.17060489039268, 42.24814722614904, 40.8322068952745, 65.6719692291752, 55.16071927162909, 56.28066578219014, 51.189492056446696, 52.481658074163626, 51.59555542853571, 51.58494933958977, 48.24620431469333, 46.95385002320813, 41.600987526678274, 43.69149315741755, 43.441300853606194, 45.684186643169774, 44.40764342584918, 45.431436954006074, 45.8792108105075, 44.85775501497331, 47.96817494976906, 46.59905987401163, 50.21105289459229, 55.44670320326283, 59.106109834486446, 57.87965528426632, 59.11270726111628, 61.05193884141984, 65.26356420209332, 58.176359053580995, 57.44286798661756, 53.63834150375859, 54.1699089542512, 46.46470692849929, 46.858665866236535, 47.902573308637066, 45.62945781215545, 47.633475180595156, 45.811420486819365, 48.32716203504994, 51.636375534919004, 49.76959405406829, 48.06668919901694, 47.24252862315024, 47.80328243009506, 50.54528590171568, 62.059862459859545, 63.99670531672817, 66.94249553065147, 65.79345287815218, 69.287060922192, 63.63035594263385, 72.17599638046758, 60.98126557565505, 40.88564526650214, 6.63667582696484, 20.482921023522657, 22.091153590909897, 9.944698887486613, 0.4684826226965074, 0.3125089599240211, 1.1731305405978234, 39.17632341384888, 64.15957781576341, 49.12550164807228, 36.35914771787582, 30.064728106221846, 42.794792267584036, 61.09786587376749, 62.63128511367306, 62.46193678148332, 15.472426529853577, 0.4454300258188479, 0.27771824129646827, 0.15957183985700532, 0.21617416953367574, 0.16123150805792502, 0.09352534678914855, 0.10804205411864866, 0.1853090233259624, 0.1531672988447451, 0.17843298583982453, 0.13192867559771385, 0.2864741972617565, 0.11194026187783289, 0.23893458047701469, 0.07827658116096452, 0.10110892009951415, 0.1687637304947261, 0.13730506532855574], [0.02615657638788464, 0.04417810724267075, 0.034652286539635355, 0.019926157584714315, 0.04763367322964534, 0.0743260266139142, 0.0011420034382852817, 0.044456993890625816, 0.0514708927291776, 0.05591008496741134, 0.021613786079650445, 0.03417752270076064, 0.04620883012971571, 0.03304205399246947, 0.04998416121628496, 0.047901738885669946, 0.2647849610976635, 27.444545607413016, 63.088402055924945, 49.306468040712424, 46.00292236574235, 31.98767008319978, 22.20667523722495, 31.308219471285422, 46.55302301529915, 48.79755620033511, 21.736132021873228, 0.09009302774023625, 0.060003380846953204, 0.08246486811267753, 1.3149222611419618, 2.9625735455943696, 0.537567880124815, 36.81678241299045, 66.36148268176665, 65.37169218063354, 63.704406369117, 63.796264356182476, 66.00966176679059, 61.737318115849654, 61.728171148607814, 62.77051356530959, 60.917287795774406, 58.79795666663878, 56.10539859341037, 46.331146301761756, 43.84982355179326, 42.112637181435865, 46.18291601057976, 52.56161951249646, 56.139601661312966, 52.43820213502454, 43.93248358080464, 41.12864002104729, 42.106934055205315, 42.63739931967951, 42.69990228837536, 40.200854347598174, 40.92633985703991, 42.292999529069476, 42.93680167967274, 43.55819140711139, 42.695258202091345, 40.7219490697307, 42.266970680605986, 41.72908429176577, 51.80411177296793, 54.67861683137956, 56.628678075728885, 54.55606629771572, 56.034631190761445, 51.68828025940926, 52.747135854536495, 46.1655399107164, 44.07122565853981, 40.088447063199936, 42.06188563377627, 38.930206452646566, 43.45522919008809, 40.36692750069403, 45.19824812489171, 47.0378436580781, 49.897883015294234, 49.736355889228086, 58.34940225847306, 50.816886501927534, 63.16295454579016, 40.91523562708209, 34.23439195079188, 63.21541232447471, 48.875850631344704, 51.35886784522764, 43.96063835390153, 44.050307658410844, 39.33053139717349, 43.50302719300793, 43.708877102021255, 42.75752582857686, 39.31047239611226, 40.83579978635235, 37.39289229915988, 39.90997922035956, 38.71048312033377, 40.21113487981981, 40.19410787090179, 42.11469250340616, 41.69726602492794, 43.88276753887054, 50.39931097338277, 52.40388139601677, 53.25478076934815, 55.64987021107828, 56.0641784052695, 60.59625356428085, 55.530434039331254, 53.75156071878249, 52.792313714181226, 48.430300758730986, 45.90378053726689, 41.68316510415847, 44.17334456597605, 42.76144035400883, 43.199992718235144, 42.119105169850016, 44.60644875803302, 50.30067905302971, 50.54109681037165, 43.7707289572685, 43.12979798163138, 42.190351101659964, 43.249124327013575, 42.834765142010106, 46.8255179159103, 54.697875668925626, 59.198426738862075, 56.00180095241916, 58.88975974052184, 58.234782757297644, 63.099008144870886, 62.13849421470397, 64.74882764201011, 22.617906332015995, 7.0776517256613705, 6.029670411540616, 5.261100117237338, 0.30612052207992924, 0.17099491560891752, 0.020552696847927668, 10.050683290727678, 30.498304943884577, 43.40439919502505, 27.07842569197378, 16.90772375752849, 39.33186892540225, 44.610269146580855, 51.78690433502198, 50.950505964217655, 17.22426099161948, 0.1904256173199223, 0.04444351840403773, 0.08076565445310648, 0.024827450228434418, 0.08028012324845599, 0.09551073259283459, 0.09278586509847835, 0.052089930076392434, 0.11187649271901577, 0.08626505492195007, 0.05913091395350714, 0.06547820904562551, 0.061052182028370525, 0.05043924808682454, 0.05291122229649656, 0.02201621781193441, 0.01813617399743488, 0.0546421634874517, 0.013922104356630195, 0.03735370408262938, 0.061906507959769624, 0.033632060437793695, 0.010635059518409113, 0.09006408493845694, 0.055007560614256136, 0.037023972179139816, 0.024790492231747317, 0.05883090243104005, 0.05285150574279889, 0.05194384860055101, 0.009521656057557032, 0.03521473680232321, 0.08102837664585921, 0.07167559988316029, 0.35369127267791384, 38.064653104351414, 69.92964713804184, 57.00479807392244, 52.76560629567793, 38.65300863019882, 26.19576688735716, 32.95040407488423, 38.786957571583415, 51.05869277831047, 22.763210535049442, 0.07286076088465991, 0.045369209256023176, 0.43937612324953085, 3.077682117300649, 3.3464875384684536, 2.0958706976905948, 39.04975245075841, 69.63994872185492, 66.8345283692883, 64.765305519104, 64.26671343465006, 66.98698305314588, 62.45752019266929, 62.957257609213556, 64.86953466169297, 62.328121200684585, 60.32122873490857, 59.96103355961462, 48.194295667832904, 44.82086904587285, 44.33727610495783, 49.305095211152114, 55.02964542758081, 57.848805842861054, 54.40051294142201, 46.40279623769945, 43.31190186162149, 44.26692839591734, 44.71183107745263, 43.57845437142157, 43.006470818673414, 42.83573396744267, 43.088444432904645, 44.37666062385806, 44.336715206023186, 44.470087558992454, 43.41097700980402, 43.0460867574138, 43.30231558892035, 52.958206438249164, 55.752769670178814, 57.79543807429653, 55.99311682485766, 58.65482153431062, 54.31447182932208, 53.909534177472516, 48.25988554185437, 45.815115359521684, 41.938691831404164, 44.68220541554113, 41.011890672868304, 45.276558245382006, 42.32131119697325, 47.85662274206839, 49.16411738241873, 51.80237416298159, 51.45465604720577, 60.557002405966486, 53.31773088824365, 63.250050775466434, 42.88817213427636, 37.616094773815526, 65.06117382357198, 51.342350744432025, 52.77248221059, 45.11905547111265, 45.5722108194905, 43.16345976245019, 45.1135523857609, 45.938269938192065, 44.47479048082906, 41.73030022651919, 41.68633830162787, 41.18479659480434, 42.82262540632679, 40.45763623329901, 41.71453622079665, 43.13904300812752, 44.56923330983808, 43.14410286564981, 44.63280316322081, 52.105789107661096, 54.86604336769351, 54.963710384984175, 57.225533377739694, 57.21822600210867, 58.68698496972361, 57.66561154396304, 56.773907753729056, 54.417296763389345, 52.21887103972897, 48.93088540723247, 44.30599520283361, 46.583911680406146, 44.620894847377656, 44.93819498246716, 43.44698829035605, 48.194421183678415, 53.48654970046013, 53.36009248610466, 48.06496335614113, 46.564162546588534, 45.38525496759723, 45.56393069605674, 45.27694263765889, 48.54154309918804, 55.89068805017779, 61.645322845828154, 58.798933336811686, 62.225715960225756, 60.57263305110317, 65.39703853668706, 63.64097379869031, 65.28097560328823, 24.6641029081037, 2.3147972985621426, 5.773822540237058, 9.066936181437585, 1.6757494283299295, 0.0478465537420444, 0.1888190849774307, 10.886632550147272, 37.33329580676171, 41.020892512413766, 29.761213141102946, 24.12297664150115, 44.10086308756183, 49.84629992515811, 57.48287224000501, 59.183219709704005, 28.80408225520965, 0.033498956491389585, 0.07680831236704704, 0.07534462477891676, 0.029848463262521455, 0.05668758377132397, 0.02082773390406322, 0.09128371223566994, 0.03561004583213118, 0.09832106485602357, 0.12546452528406538, 0.093610045470057, 0.0346074627351857, 0.04280949882682293, 0.033964462157699375, 0.06959066861459325, 0.04990257668278871, 0.03759203403587303, 0.04640246651345684, 0.10205002847097575, 0.15333096586888836, 0.1075889743984707, 0.12872186219019274, 0.07191003044886936, 0.25427495489918417, 0.09651426180836656, 0.10172195897828187, 0.16901045677161988, 0.14314956542464996, 0.1677671726793051, 0.11533916417148807, 0.08926314767450096, 0.09264009388824625, 0.21154073187180106, 0.1767962696331163, 0.5292189313519386, 50.0050853144738, 80.49957967573597, 66.37736828096452, 60.56520800436697, 45.05513260441442, 32.36727902966161, 43.96997359491164, 62.57870966388334, 64.69276912750738, 26.655862869754916, 0.379818057821643, 0.10053496702664322, 1.1757628187056512, 5.462415766331458, 9.724199906472238, 2.383963638736356, 41.5741349804786, 70.12299645331599, 69.85795405603224, 67.67974422823998, 68.11606868620842, 69.38271968595444, 66.0436922504056, 65.62085682345976, 66.16648597102012, 66.5930829509612, 63.00622055607458, 60.88419475863057, 51.02180288683984, 46.51992213341498, 46.60037779038953, 50.841938680218114, 57.273719695306596, 62.28166464836367, 60.10740856970511, 47.560687757307484, 46.01541903711135, 44.977171574869466, 47.927798071215236, 46.74929449635167, 44.30352410962505, 45.143852695342034, 45.68383362985427, 46.92166305357411, 47.26487436602193, 45.9312371284731, 45.76101410773493, 44.06782496360041, 45.62856743412633, 56.22783930070939, 60.16042332495413, 60.06378004627844, 59.84416654033046, 61.08085847670033, 56.444409047403646, 57.84566010198286, 51.890458829941295, 48.08020960900092, 44.867529561442716, 46.7164917146006, 43.38796446400304, 47.687141049292784, 45.34694125575405, 51.00561918750886, 53.43752007330618, 54.78504250126501, 54.92622429324735, 62.68328789741763, 55.43181780845889, 64.93412825369066, 44.94466689325149, 41.00035105982135, 67.34296952524494, 54.025577499020486, 56.22099868712887, 47.527076967300914, 47.77099740120673, 45.63369789431172, 46.926271838526574, 49.463602112185576, 47.55142311896048, 43.27066598399993, 44.79283194388113, 42.12399636545489, 44.65445856894217, 43.36667383870771, 43.669390601496545, 45.28925103525962, 47.72972622225362, 44.96709108352662, 48.00154255282495, 54.36656482758061, 57.75892473036244, 56.7884950483999, 59.882280211294855, 60.202365229206706, 60.68375772045505, 59.79361111117948, 59.42023677210654, 58.19975206928869, 53.89697474818076, 50.41667138376544, 48.40265197138633, 48.69980289090065, 47.80449836484848, 46.8155707851533, 46.857614671030355, 49.38228353377312, 55.976062359348425, 55.230972843785445, 49.66895780255718, 48.08875645360639, 46.9628793193448, 47.81110755858883, 47.65272225103071, 51.36295103257703, 59.995613175053755, 67.50681477208292, 61.69467802970641, 64.51400710690406, 63.25014491235057, 69.53558229630994, 66.11745634386617, 68.34505665686824, 26.988738736798688, 10.557376050180006, 14.116306266477032, 16.312306984778374, 1.0911625647737135, 0.5818249020845659, 0.4522395975166752, 14.455523625496896, 45.30954537853118, 60.85656166076661, 38.076420214868364, 24.421722004490515, 51.1405957898786, 55.771255800800944, 67.1466705876012, 67.13588406962734, 36.97512457447667, 0.218878245401767, 0.18276317525775204, 0.2744023676120466, 0.16247077784951658, 0.2237162132176661, 0.33800347738208314, 0.20812474581743443, 0.17347321004396485, 0.18944847217250257, 0.17264574315519104, 0.14452031122580652, 0.1680090726022759, 0.14706274254187462, 0.1274168543938187, 0.13504775661614635, 0.16705301019453234, 0.1032753018361907, 0.18150944172615008], [0.04398311488330365, 0.03555052080041459, 0.04371359749066253, 0.043062169946009116, 0.01214830533436109, 0.04102812606781241, 0.019164484242097508, 0.18356876267540842, 0.05126032197187024, 0.022455327918813116, 0.04385862559560807, 0.03213672958795102, 0.05714530598432307, 0.020580270267542333, 0.06343352037572092, 0.016625642047954664, 2.390477469851894, 46.98130661441434, 61.44722746264551, 53.561972956503595, 36.852464214448005, 21.25061123601852, 25.2920449549152, 36.38550212306362, 42.86128036437496, 43.9240034164921, 12.163256176056402, 0.16947349563481348, 0.2705337155249811, 0.1499621861524159, 3.043137558044926, 4.727369969890964, 12.055681251710462, 54.35157352878202, 68.36212681185815, 64.57707097453456, 61.185373952311856, 59.57759049630935, 64.76803156637376, 62.50265098387196, 58.28809169030959, 58.82648798727221, 61.63975700255364, 60.51740215670679, 61.608593771534586, 53.24877169824416, 45.41402555281117, 41.27060236469392, 40.777485909000525, 43.36095894536665, 44.52766795312205, 43.11373587577574, 43.44307376492409, 43.83158845286216, 41.94730535630257, 41.03318914290398, 41.126812196546986, 40.208875594600556, 43.46443107051235, 40.88278585864652, 42.05647276293847, 42.49779824287661, 43.451797116187315, 40.5688040487228, 41.15689285339848, 40.49846418442265, 45.69584000495173, 49.63214243611982, 53.57225348872524, 49.244941742189475, 49.127223568577925, 45.395857134173, 44.16964184853339, 41.644949451569595, 42.08251730088265, 40.11603701499201, 38.85644235918599, 40.63524899944183, 44.571100358040106, 41.155869114783506, 44.429565552742254, 47.265788278272076, 52.65784701993389, 51.713909026115175, 58.352551921721435, 52.649100134449625, 57.80327104753064, 36.3141385201485, 32.65046827254757, 61.225876346711196, 49.07078850653864, 53.04777768350417, 45.407702692093395, 45.281924047777736, 42.432047551678075, 44.21706330391669, 39.53222359380415, 41.04930223957185, 38.11422401858915, 41.285730946448545, 38.684426815279075, 40.19745757502895, 40.695069066939816, 41.10044210187851, 39.60447365237821, 40.890144225089784, 41.89307466630013, 45.704720251021854, 51.577273261162546, 56.245160487390336, 58.06790159594629, 56.71201275240991, 55.057109863527366, 55.08641781345491, 52.79050550153179, 55.545248831472094, 51.04761208257368, 49.6907465688644, 42.463124490553334, 43.60912338379891, 41.80791608748898, 43.41848050394366, 41.24443231090423, 42.855283060381495, 52.22131859871649, 55.745619189354684, 54.66374712605631, 51.58479244478288, 47.54074250498126, 44.39746879762219, 40.70261178478118, 45.07320688616845, 42.29538825250442, 44.048236646959865, 48.447759228367964, 51.71102216166835, 55.50931207595333, 58.75784650925667, 61.335467369325706, 59.86383722674463, 60.97804530974358, 50.75240665866483, 5.639160708073647, 4.663982997017523, 6.034014436506457, 2.0823037095608252, 0.35120240622951143, 0.0946403188150256, 3.2504458533179377, 27.419942540507165, 33.10566325341502, 27.45616759023359, 15.677933231476816, 23.053354140250917, 37.11915400720412, 53.494531723760794, 51.30499801328106, 41.525646640408425, 4.13804954098117, 0.19729028606126386, 0.07111660850745055, 0.039873014865142685, 0.07395202248928047, 0.08405475336457453, 0.040115320814713355, 0.06248750521110431, 0.012892616251783987, 0.04034821920457386, 0.01169433216414144, 0.0532717164605856, 0.0647224403256851, 0.04163023670234027, 0.044286320992414994, 0.09642639918433082, 0.05163577017224124, 0.04036880015665966, 0.015070822555571796, 0.046654624353733756, 0.04261855524213564, 0.015718325814833085, 0.04918903089879502, 0.015397638536899563, 0.06456181467060121, 0.02844916153398733, 0.04257967244953879, 0.028204327494266535, 0.09637870255016512, 0.08480586426993532, 0.04011473475745128, 0.022597148030575727, 0.04121483318627842, 0.0279099294810646, 4.258362852757977, 58.69629275414252, 68.85181119365078, 61.427356735352554, 41.76328343729819, 28.173055264257616, 30.56695034427028, 35.42791428104524, 39.00568462187244, 50.181529214305264, 12.463205706688667, 0.0877779176939399, 0.12329203782663231, 0.5604057578790573, 4.4802376051102915, 4.7010900897364465, 12.368413786734305, 59.292810732318515, 68.8138661846038, 66.16518374412291, 63.076850675767474, 62.83987675943683, 66.29823838510822, 65.10234694327077, 60.09972464653754, 61.16025901609852, 64.73030621005644, 63.53905885450302, 63.202131179071245, 56.7220030292388, 48.15905709420481, 43.71286223011632, 42.64981362127489, 44.76373187957272, 46.00005119077621, 44.51273548987604, 43.8263403215716, 44.826132866644095, 44.05585781220467, 42.456950679902114, 42.70799413804085, 42.59441798733127, 44.99432802200318, 42.448662711728005, 44.45125625979516, 44.35511896687169, 45.70575967911751, 41.87774604366672, 44.32250838125906, 42.25374052601476, 47.357799237774266, 51.83992301264117, 55.213981136198974, 52.64709972566175, 52.210528158372455, 47.569595459968816, 46.422463001743445, 42.746998187034364, 44.330937554759366, 43.18793142995527, 41.7838405793713, 43.33542431554487, 45.860183392801595, 43.23574904472598, 46.271259553970836, 50.79592927809685, 54.546197614362164, 56.12077036211568, 61.326912679979884, 53.53579898034373, 58.121590998864946, 39.50634771777738, 34.17385408955236, 64.20586178379675, 51.54161107155585, 56.47697256457422, 47.581915624680065, 48.18340716823455, 43.68957511840328, 45.523196881817235, 42.03508015601866, 43.3223706676114, 40.44537490414035, 42.401256945825395, 41.392007566267445, 42.62208246415661, 43.364151754686915, 43.13889003569081, 41.581732611502375, 42.170754940279075, 42.7356154687943, 49.77549722117763, 55.338634060275176, 58.36582914475472, 60.0039089879682, 58.27016645862211, 55.27581730196553, 55.64313157912224, 56.1764209501205, 58.26809544717112, 53.22622199212351, 51.55954414798368, 44.346415227459325, 46.63516921381797, 44.811337686354115, 45.51110421457599, 42.905846334272816, 44.84168506437733, 53.92100711022654, 58.30798987419375, 57.59051776701405, 56.06393521831882, 49.84556251956571, 46.59650641102945, 43.06313337818269, 46.6794841520248, 45.202700015037294, 46.81355468688473, 49.79236341291859, 53.860202527815304, 56.03073235481016, 61.44791387742566, 64.29081247698876, 61.75075223368984, 63.64006380881033, 55.729678676974395, 6.417248143303779, 2.347087230413191, 6.79385696688006, 3.23236029474966, 0.8452363901080624, 0.05934556412901129, 2.737271377155858, 31.80992199528602, 34.67574488732123, 27.142287761934345, 19.837387146488314, 30.86036324501038, 42.80612399501186, 58.74417312683598, 56.38858587511125, 53.91670819251768, 9.501274939506285, 0.25434955654125063, 0.07405154497152375, 0.066639291903665, 0.06778727465819928, 0.04098889087477038, 0.06870796678647881, 0.08452475596699985, 0.0665104129321633, 0.051058641664924166, 0.01832008489497727, 0.04642516952909289, 0.007934311823543884, 0.03547307314170945, 0.08219531241564021, 0.03897363530291666, 0.020013759738855788, 0.022191448933294704, 0.10593126738263715, 0.08885155927630202, 0.12455731630325319, 0.1601409512541948, 0.11414869418067318, 0.15222245196421302, 0.11801931511370406, 0.40966064518978523, 0.13850607668920872, 0.18863168454939322, 0.2355448252731754, 0.22474627971889513, 0.0956582964488095, 0.1110894829335232, 0.14671009694856985, 0.1526338718230686, 5.73255479335785, 68.86113074518019, 77.59186390907534, 71.69887142796671, 50.909274008966264, 32.41803449969138, 33.18467547816615, 50.001570870799405, 56.8112487177695, 56.34324327591927, 14.690043118692214, 0.29807479090748296, 0.4235442114933845, 0.35433110931227285, 11.119694882823575, 9.222286555074877, 15.451702687048144, 61.64567193677349, 70.79900126303397, 69.30317401885986, 64.95346946101036, 64.89506536914458, 70.2192278831236, 66.11411448447936, 60.008376567594475, 61.60290241241456, 66.39782736378332, 65.2796459197998, 65.8840125606906, 59.25983144390968, 50.09271498649351, 46.31773964051278, 44.177612104723536, 46.641962758956424, 48.6134676010378, 47.21193805817635, 46.96472675569596, 47.813362921437914, 45.59239925876741, 45.12292292810256, 44.25288238833028, 45.198134376156716, 47.71720601666359, 46.268855141055205, 46.131489815250525, 44.8661998779543, 47.469994714183194, 43.98320767187303, 45.95475173765614, 44.48845601850941, 50.90665386569116, 54.40744376951649, 58.169212495127034, 53.35069840954196, 55.66176283744074, 50.39982872624552, 47.24051252488167, 44.5376072391387, 45.87908529466199, 44.7420568620005, 41.833109471105764, 45.092042107735914, 47.56680273240613, 47.1361735559279, 48.432677715055405, 53.747740330234656, 58.039236914727, 59.87326660463887, 64.45869384273406, 56.96919079749816, 58.393575991353686, 40.376196061411214, 37.47165349221999, 66.37172791265672, 54.88020704638574, 57.28606339423888, 50.23289657408192, 49.231107542591715, 47.587477545584406, 46.53672948960335, 44.44536878216652, 46.12044049847511, 41.96704664537984, 46.04510745694561, 43.52618878887546, 44.62837480729626, 45.97026471168765, 45.869632382546705, 42.66235736108596, 45.087068542357414, 45.30075926934519, 50.54824336882561, 57.842024064833126, 59.88484151901738, 61.721609023309526, 60.3939220213121, 57.181940155644575, 59.17736361103674, 58.16600399632608, 61.326536132443344, 56.93208517566804, 53.85939451955981, 47.5549336402647, 48.3485899433013, 45.67572216833792, 47.46777857503584, 44.850231908982806, 46.47584645978866, 57.75797943915091, 61.64023553171466, 60.058567216319425, 59.10771408388692, 53.41271108196628, 49.462590140681115, 45.000690106422674, 49.928406899975194, 47.07585534741802, 49.691272166467485, 54.00229038730745, 58.42245248056228, 60.2240716257403, 65.58241367340088, 67.44389210977863, 65.87455964857533, 65.5511131594258, 56.37146080693891, 8.084875691321589, 11.475593101593757, 14.33901648367605, 3.690233764148528, 0.5639764017635777, 0.21037667659261536, 5.206875310790155, 39.80699346911523, 47.3099620111527, 38.93467795464301, 21.779844876258604, 34.210516483553, 50.83197585998043, 67.59743721254411, 66.48098161143642, 61.40966292350524, 12.045061434468916, 0.30905381145496524, 0.25136619565948365, 0.18450001915616376, 0.2005799901821921, 0.14057180213351406, 0.17217213227864236, 0.1446590497488937, 0.18813855375253385, 0.1278825439212303, 0.11663294877977141, 0.10845276917661391, 0.13300093822181225, 0.18284571357071402, 0.21701904194008922, 0.18551002947553513, 0.10659547327386756, 0.14117635275808074], [0.04167568486844821, 0.09512211917148483, 0.042681788139405756, 0.04604615518943437, 0.0711011182096216, 0.04456598138917358, 0.04081446414573058, 0.01372907413995915, 0.03385803722325833, 0.10938845364557159, 0.05034089771910541, 0.028757128879548084, 0.09356950409710409, 0.015431845320328591, 0.0661521825578905, 0.010933695913052127, 8.161100091472749, 50.282687141049294, 55.807941729022616, 44.65624324737057, 28.834137416655018, 18.394764892516598, 23.374260894713863, 44.732823602614864, 41.684635992973085, 47.334672943238296, 2.9187393428817874, 0.10439295516980272, 0.17343265334925345, 1.046541068823107, 2.2962177665002885, 1.9336676982141312, 22.351602892721854, 63.26586969437138, 64.65716969582343, 63.04961765966108, 58.05472635453748, 60.1540377063136, 62.095822749599336, 60.951490863677, 59.584517402033654, 60.15236677662019, 58.070976734161384, 61.238373018080196, 55.83824203860376, 59.00608155035204, 50.63588480795584, 42.71199103324644, 42.914420635469504, 44.117070321113836, 44.45344494235131, 42.78736329847767, 42.30528439244917, 42.12260392404372, 41.905940040465325, 41.826676784023164, 40.65625329171458, 40.13153037717266, 42.06536477611911, 43.752948853277395, 43.703122984978464, 39.61522094665035, 43.084059223051995, 40.96953691974763, 40.74211005241641, 40.593836615162516, 40.04515194123791, 40.925476935602006, 42.36563005755025, 43.56582041709654, 41.153680432227354, 42.56596511410129, 42.819754231360655, 41.32686876481579, 40.17319771551317, 38.85017048928046, 42.32758306687878, 40.2627101252156, 41.676952069805516, 40.28274166968561, 44.62960643153037, 46.709478516732496, 52.27028546794769, 50.69534401739798, 56.24577629950739, 52.70737086572955, 59.25657979903683, 35.96531037361392, 29.612204259441747, 62.50159978866578, 48.32808379204043, 56.23093012840518, 50.25530899724653, 50.282487100170506, 44.874197590735655, 43.76985819109025, 39.820188322374904, 40.89530606423655, 39.82784871132144, 41.10345448217085, 38.94870042800903, 40.44095831532633, 39.84685259480631, 41.43387102311657, 40.78291446931901, 42.342723415743926, 41.703945821331395, 44.50400429387247, 52.443971941548014, 54.36301900494484, 53.668178973659394, 55.22948234311996, 53.17309348813949, 55.64708532825593, 55.706752423317205, 53.41129902870425, 48.47499616684453, 44.65094412526777, 40.44267239109163, 42.766268791690955, 41.950254978672156, 43.680710561813854, 40.46874830799718, 46.07250913496941, 53.55711706223027, 56.570168079868445, 57.62479928232009, 57.502029095926595, 52.285068881127145, 50.78537417996315, 44.576077845788774, 42.602929530605195, 43.81871915632679, 47.25331514112411, 43.7607975159922, 44.602228287727606, 44.2855949555674, 54.023400583574855, 54.50732300358435, 60.75103029128044, 56.47281877456173, 69.1610194790748, 23.92666397556182, 2.87836050314288, 5.864374868331417, 4.967004724087254, 0.31349825522591995, 0.09520367689190373, 0.060630703435069135, 17.11556426940426, 39.32241601328696, 32.4804570597987, 20.819962447689427, 43.42364234309043, 48.058103130709746, 47.33873259636664, 51.35979744695848, 53.17365438707414, 25.612271178153257, 0.1485447396313952, 0.024085218282116037, 0.05453465453859779, 0.04329568503664867, 0.044652725524839856, 0.057484924252475464, 0.008963342669660286, 0.01589019764064541, 0.03480864891542062, 0.0905174327894084, 0.03148235452000893, 0.026011701500523957, 0.07147951201806146, 0.06401742876116788, 0.020103575887098428, 0.13333092293431684, 0.06274261632032933, 0.04895452372429352, 0.006562041507417998, 0.03799594623307067, 0.05095495932525204, 0.06246958641455539, 0.037818930126846804, 0.10475685459471519, 0.08217861169889089, 0.10488361150266663, 0.033824505554812576, 0.07891103219721587, 0.03772883052607218, 0.0275440190753509, 0.05760396665502941, 0.019016793981615095, 0.012028212433740979, 11.200249579644973, 62.528067942588564, 61.2089866207492, 53.63114787686256, 34.10203549169725, 22.19342939315304, 24.283213307780606, 35.798021285764634, 44.856601838142645, 52.07302554961174, 2.910889454426304, 0.1475316802820852, 0.17280649904522205, 4.65267333292192, 9.954301830260984, 3.035806157896596, 26.653587895054972, 64.35004811133108, 68.22873484703803, 64.47879206749701, 60.52925555936752, 61.61240631534208, 63.28894499809512, 63.275722688244244, 61.78739109346944, 60.762009005392756, 58.27520670429353, 61.70832003316572, 58.516040232873735, 60.501932328747166, 53.40410932417839, 44.79619341511881, 43.89889240264893, 45.81993203009329, 45.27127873513007, 42.67117092686315, 44.46510614887361, 44.341975104424264, 43.82392021917528, 43.628990188721694, 43.483230990748254, 43.71263473264633, 43.65733323558685, 45.0979099735137, 43.8323611597861, 41.51251454507151, 44.69674564176991, 43.59452039964738, 42.0478396261892, 41.98772538092829, 42.469537565785075, 43.31966030982233, 45.40416471419796, 44.48322749906971, 42.21578374985726, 42.82835991151872, 44.53298668707571, 43.837919158320275, 42.93343628606489, 41.998037292111306, 43.62549927926833, 41.9068225737541, 43.25266622727917, 44.504851525829686, 47.61510279870803, 48.48321353235553, 54.82707069766138, 53.68045599229875, 59.15630440558157, 53.93758304657475, 60.90084129764188, 38.18285765186433, 31.20870109527342, 65.6848502928211, 50.72101593017579, 58.746467713386785, 52.06256851073235, 53.020226955413825, 46.94739772427467, 47.431324066654334, 41.61517081722137, 43.52798131204421, 42.443759749012614, 43.51534343534901, 40.58719604246078, 44.08172192112092, 41.03471494490101, 42.26560961815619, 42.662831967876805, 43.805112454199026, 42.64777006641511, 47.773833274841316, 53.92955003246185, 58.01644402165567, 56.44553084527293, 56.36470256313201, 55.28904353418658, 58.74151768222932, 56.2871180811236, 56.77737905133156, 52.022121029515425, 46.43045286978445, 43.01431948138822, 44.75671868170462, 43.80457116711525, 44.4730842498041, 40.747856324718846, 49.205404250852524, 56.88262801016531, 59.676081211336204, 60.20517364625008, 60.16099206862911, 53.66641390708185, 52.42676058123189, 46.178840667970725, 46.263203005636896, 46.366930084843794, 48.87155955837619, 44.88659620285035, 46.921329652109456, 46.66173934936524, 56.84301599379509, 56.35850914062993, 64.88232943319505, 59.050898551940925, 70.62022747532015, 27.95832314798909, 0.7991297254639288, 2.872932433120666, 4.509705391622359, 1.0933698785881842, 0.14294783915242842, 0.052407607586393436, 19.339534428811845, 40.656010104763894, 28.86122334387995, 18.190713390227288, 44.46371762983261, 53.654089820000436, 51.94427767107564, 57.19624503966301, 59.594358628795995, 34.58256506150769, 0.28467508573685923, 0.03764496688100119, 0.05153445504425515, 0.05937465248749622, 0.00871464275875159, 0.05560767942018086, 0.007611763909564264, 0.03793851262138736, 0.025033594912759242, 0.011099221658021694, 0.042378666299966075, 0.02392993800552382, 0.030498894892873305, 0.0407911827337117, 0.02689143282271201, 0.05919211288733829, 0.03480469590173133, 0.18549861476546337, 0.155805766943001, 0.10851604803915947, 0.1374473584996116, 0.17713034525513652, 0.11036366059054291, 0.18340944703067505, 0.18473405901703144, 0.17299396076029347, 0.12371425186434101, 0.24341377399621472, 0.1061717270603103, 0.21334496086403248, 0.21154955720468877, 0.1248577070392428, 0.1555455268751229, 17.29243766876959, 72.66222123176821, 69.51032223240023, 61.587718917477524, 41.40731265467983, 28.353382310559674, 33.650170603106105, 59.52148099099437, 56.365534105608546, 58.55380481289279, 3.819806075865223, 0.23159692905122237, 0.4637042871646343, 3.3409467003037854, 9.823284860580198, 6.534672139152405, 27.838786955802675, 67.1052425138412, 69.54020284837293, 68.09316204440209, 61.909627837519494, 65.31911280847365, 66.1201706240254, 65.05975784793978, 61.95516655522009, 62.463113492535015, 59.09319739187918, 65.49268161096882, 59.64050139150312, 63.05729766045848, 55.684198794826386, 46.91301030497397, 46.08060882937524, 47.83391614114085, 48.354175398426676, 45.35179715002737, 45.30609761514972, 46.14848936757734, 45.07220275940434, 47.10813253156601, 44.640808720742505, 45.60351917820592, 44.76959582298033, 48.572110129940896, 47.89927067295198, 43.08470249176026, 47.89931774139405, 45.86279176896619, 43.45529979275119, 45.54421686357068, 44.316016858623875, 46.535176231015114, 48.000181490375155, 46.84273712096676, 44.82973752483245, 46.642103964282626, 46.505954573231364, 45.700209525323686, 46.24727033799695, 42.64404381475141, 44.9242195775432, 44.19378011457382, 43.90832570291335, 44.254294441592315, 49.52847419246551, 52.87695846249981, 56.1919496136327, 55.77215010120023, 61.20576243246756, 56.32598484716108, 60.86353171256281, 41.29084179478307, 34.97135431535783, 65.42290656797348, 52.23061461602488, 60.24480135210099, 55.373441173184304, 56.45647425805369, 49.40035389315698, 49.677488957681966, 45.16246826417985, 45.57190879698723, 45.068221553679436, 45.47000954228063, 42.20880585332071, 45.74070407498268, 43.53534752322782, 45.223288536071784, 44.65475274670509, 47.568795296453665, 45.73853500427739, 49.531867042664565, 59.04264980746854, 58.89548640097342, 56.9493632162771, 60.9714831844453, 58.234496424275065, 59.92955653898178, 58.611953950697384, 59.48383408208048, 53.349447173456994, 47.69378162199452, 46.095568749212454, 47.15585208708241, 46.975387757824315, 46.69381649263444, 43.71825941147343, 51.33066600368869, 60.37775401146182, 61.57095078499087, 63.45419445345479, 63.88971874790808, 57.236315973343395, 55.43282977996334, 50.09305231032833, 47.981589455758375, 49.26200797480922, 52.00582358144945, 48.53262755178636, 49.77416361531904, 49.100606364588586, 60.75636471471479, 59.55007506955055, 67.19726916282409, 62.50772653087493, 73.7690434917327, 29.99619645457114, 5.287477566349891, 17.02788556775739, 17.33354606936055, 0.625684661490302, 0.24155000465050822, 0.2725433786549876, 23.059837818145756, 56.231220383797925, 44.47112698708811, 32.71679359097635, 53.5823888932505, 58.99539309163248, 60.120215108317716, 65.8938184861214, 65.44970420099074, 41.17648901477937, 0.5620719684708504, 0.1774347732744871, 0.14457694044516933, 0.11439113036519098, 0.19338417227470106, 0.1240523647697222, 0.08387229420364865, 0.1055272785766471, 0.12088546454305611, 0.188627639605153, 0.11730765773644371, 0.11922253280757897, 0.12829914253445404, 0.1315817296985657, 0.12352842957742753, 0.19847119527478374, 0.24882091449633723], [0.08193500339984894, 0.037591520756963766, 0.05894968819413936, 0.04497093929638786, 0.07255843960710111, 0.027077668797104593, 0.06313285767851819, 0.029295301815915494, 0.03262265149744288, 0.06293506526778783, 0.03883599228556118, 0.035683716677369616, 0.17676253112093096, 0.024103181128720605, 0.05270054045644018, 0.15473088429820153, 20.954085934546686, 65.03825933702531, 59.00626982412031, 50.38178190108269, 28.559245947868597, 21.434599814876435, 42.699647334314164, 46.68109232379545, 39.23682989612703, 33.56253308634604, 0.2616482907004895, 0.09397284938923775, 0.3640196700730632, 2.7525556279766947, 4.712586066415233, 3.0084022735395743, 26.474651328979004, 63.856472738327525, 66.47152869932114, 64.7353543004682, 57.03443942531463, 50.49793112662531, 59.68403577804566, 60.05235025959631, 60.862774695119555, 61.17932957987632, 56.858003370223514, 56.45365015152962, 56.48909268840667, 58.54197102208292, 50.853525361707135, 43.44832974095499, 43.20087917389409, 46.56728867561587, 43.65934148911507, 40.87184636823593, 41.698042654222064, 41.38605733071604, 43.93648832075058, 45.83347989666847, 44.30643058592274, 45.99808608331988, 46.20667772908365, 43.11431638656124, 42.41194148217478, 39.389582680117705, 43.03255850268949, 41.925869603310865, 42.471643878567605, 39.4380670978177, 40.37591757312898, 40.31136712720318, 39.627819599643836, 40.65861063618814, 41.30686467693698, 40.11603701499201, 40.77216717504686, 39.98669293618972, 41.564831118429865, 39.94831254405361, 42.397212982177734, 41.74901777698148, 42.190331489809104, 41.29633311302432, 42.763985972250666, 40.30032957753828, 45.75008638443486, 46.09222688982564, 55.79670413847893, 51.04256399216191, 63.54388336981497, 37.19999013408538, 26.507165816522416, 60.09542572882868, 51.194324416498986, 56.53304284618747, 49.753131866455085, 53.429228182761904, 46.88719326449979, 46.87675191510109, 39.83313606631371, 42.45021597031624, 38.88392640698341, 40.296807289123535, 37.88369847882179, 41.44096659075829, 39.61153784105855, 40.468579646079775, 41.176085010651626, 41.84045214806834, 40.48403770692887, 42.4410415464832, 46.85697532469227, 49.95585172407089, 51.888321138197384, 52.024443072657434, 53.670493172061065, 54.81118117609332, 53.466828023233724, 50.64991904843239, 42.394145688702984, 41.42660287118728, 41.66450246687859, 41.20241195924821, 42.25429358020906, 43.30807755070348, 40.47407880906136, 44.80756436624835, 53.222201562696895, 57.77549674434047, 56.50175409932291, 58.36592328163886, 55.71780174009262, 55.38648305400726, 51.31265447985742, 48.62915315935689, 49.33007286440942, 46.88807187541839, 45.63940886528262, 47.22014757894701, 44.50232944180889, 46.48766848348802, 53.37833935214628, 59.42945826438166, 57.03553376659271, 63.98429493750296, 47.05945591772757, 6.378928057609066, 3.268401238226122, 6.445640710092361, 3.477558685887245, 0.08443475595765537, 0.041959474479118665, 7.183970020663354, 35.14038101319344, 36.62774378253568, 27.60838693188083, 27.737321123000118, 47.390923653879476, 34.01853215309882, 56.06706526971633, 48.9654375660804, 47.41404994841545, 4.4643284716913785, 0.10062338123398443, 0.056129327840021545, 0.05283429940801956, 0.00748367783906419, 0.03881965163013628, 0.04170894457568084, 0.04491569286572837, 0.045275807816294894, 0.019749549420310125, 0.09925782950895448, 0.12127739512511801, 0.029962355639004422, 0.054500735995750275, 0.02476458505336796, 0.048243628604517835, 0.01359839007378586, 0.00520460217470123, 0.04560529840208831, 0.06449189382575213, 0.048918080921735496, 0.02787940470772165, 0.06046243222250093, 0.03414765293259294, 0.07041590618750743, 0.030583507388890274, 0.02739907140963741, 0.017866198867259007, 0.03735846148863916, 0.07662309528959375, 0.005083702008930906, 0.04068795621635453, 0.1158361407297273, 30.256720281416374, 76.20026972986038, 65.73544886804396, 55.29263250289425, 35.56268299779585, 27.390034467943256, 39.298909248844275, 43.50479225958548, 45.026734644366854, 36.667387177867276, 0.3631376883675975, 0.04716001638782121, 0.5361322313547134, 5.1978984763545375, 10.734652473080544, 3.22949230670929, 27.16946586485832, 65.23682540462863, 66.88340110163536, 65.92713509836506, 59.759749289481874, 54.15170131191131, 61.503858643193404, 61.84437920970302, 63.121597074693256, 61.8650108768094, 60.74994771711288, 59.104046667775805, 58.72172932470999, 61.05377451066048, 53.01444930415, 46.340203054489635, 46.341611185381495, 46.132509631495324, 44.529417330218905, 42.53814374246905, 42.90457548633699, 44.40311308830015, 47.425134566522416, 47.21877867175687, 46.08574713430097, 47.00797873158609, 48.11309083815544, 45.96473416974468, 43.363920334846746, 42.88032347156156, 44.23148978141047, 44.70486102565643, 43.49520206451417, 40.81934152110931, 43.279059856168686, 42.38576750601492, 40.891928903518185, 42.015868386914654, 43.52551021883565, 42.90355174772201, 42.77649441073018, 41.96089244657948, 41.995719171339466, 42.006897926330566, 44.073728130709746, 43.86961190931259, 44.3610692024231, 45.09823160786783, 45.67499652985604, 43.91332672488305, 49.163148556986165, 48.14083376238423, 58.61942214350547, 52.50636508387905, 66.43411713261759, 39.21690817802183, 27.61531383760514, 59.13360957176455, 53.115054176699736, 58.40791617670367, 52.787736308190134, 55.640323162078865, 48.908025833868216, 48.54884263007872, 43.6674137269297, 43.97946965309882, 41.51186735399308, 43.795235926105136, 40.84193045093168, 42.67068455296178, 40.86232677582772, 42.996684505093484, 42.60967208493141, 44.816397543876406, 42.59497888626591, 44.768050409132435, 47.86171005618188, 52.49509611437398, 55.81027161690497, 56.2253446732798, 55.342917288503344, 56.70911804322274, 56.11598114813528, 52.28374312000891, 45.388110453082675, 43.2962163033024, 43.78504560839745, 43.46356814907443, 43.119199737425774, 45.29270664338143, 42.36774421507313, 46.9681352953757, 56.415956174173665, 59.981261222593254, 58.655025497559585, 59.670872303747366, 58.31215150894658, 58.9842104142712, 54.23853082041587, 50.445132101735766, 50.940566678201, 49.687616517466886, 47.70764327818348, 49.212405681610115, 46.28805122067852, 49.1166998494056, 55.27031421661378, 61.30176244243499, 58.57783717493857, 63.39311922750166, 52.270913047175256, 5.6106171300334315, 0.5807043299559624, 7.12339097453702, 2.1079207091562213, 0.21006748350637577, 0.07533880251069223, 6.622577357676722, 42.276674624412294, 28.64022328007606, 26.016997022013513, 39.94154645550636, 53.69612586113715, 39.80873892384191, 61.270811019405244, 54.510292237804784, 57.680897020524554, 9.681914794829584, 0.1670856608618652, 0.05239859456196428, 0.03294864872230157, 0.007631576379701015, 0.0249902764710808, 0.013305617124593307, 0.060008031000653585, 0.03841699581713446, 0.00586645761241896, 0.028793732560570204, 0.029185689955709443, 0.08992289493401205, 0.07754932623356581, 0.017414666644688097, 0.06620621473919, 0.08146284042947716, 0.2527998832444991, 0.19802301851732118, 0.2630874634750428, 0.12117218060959732, 0.16729791318216633, 0.15988694714202037, 0.0989029469389108, 0.1934233346893903, 0.1308114282907017, 0.1490644077139516, 0.10321750050230373, 0.1275365173275913, 0.30062764101932127, 0.0848530016599163, 0.18339012629322468, 0.3568039492012993, 39.99694601182015, 83.28057150686942, 74.17801334011939, 64.38494543875417, 42.291167782199004, 32.76139290102067, 53.89536265403994, 63.77039632489605, 52.027486831911155, 40.27956062747587, 0.6492267885515768, 0.2540937597833334, 1.0420487292351261, 6.064871232355795, 11.876176922552048, 5.9927099174068825, 29.856571843547208, 69.01449541891776, 69.87712660143453, 70.11974873081331, 61.79705189120386, 54.27858606461556, 62.428388749399495, 64.0424636871584, 65.08404908641693, 65.1754520785424, 61.536359402441214, 61.8598961061047, 59.378083059864665, 63.537423226141165, 55.15829916923277, 47.489084889811856, 48.39538381945703, 49.37316794549265, 47.01033607605965, 44.660012645106164, 46.64481039970152, 46.68493232419414, 49.49287476078157, 50.73487366399458, 48.90376221749091, 49.88900669159428, 51.218839230075965, 46.81997168448664, 46.50420127376434, 44.82936489966608, 46.42449086712253, 47.36878579662692, 46.894128014964444, 43.362527893435576, 44.67458425029632, 44.8085488811616, 42.66058444976807, 44.874201513105824, 45.85570012369464, 43.26825764871413, 44.78270830646638, 45.05803123597176, 44.877621819896085, 44.72421792245681, 46.669474263345045, 44.81039631751276, 46.97024553052841, 46.69673473604264, 49.7160929249179, 45.0466916638036, 50.62959332619944, 50.68881719343124, 60.93946095435851, 56.96379753851122, 68.09280903108659, 41.77890231532436, 29.737775018138272, 60.20154937621086, 54.976458088044204, 60.273269914811664, 53.89543717907321, 58.943041216942575, 51.30973231407904, 50.658214861346835, 44.853252134015484, 47.099848485762074, 44.0924652930229, 45.6538353427764, 42.38195496220743, 45.65081904011388, 43.6898849856469, 45.762806630903675, 45.94476930556759, 46.2901222321295, 44.08530696745842, 45.96364767320695, 50.03577001633183, 54.76528160033688, 58.23653997913484, 58.92024440150107, 58.080213915917184, 58.69370006745862, 58.51997437015657, 55.54086754398962, 47.03205031733359, 45.45741481165732, 46.03847472898422, 46.10826546146024, 46.321414901364236, 47.70843559695829, 43.49633562949396, 50.42531236525505, 58.837160756511075, 63.7228258194462, 60.10359210352744, 62.31999797205772, 61.379719549609774, 60.91211811188729, 57.53792270537346, 53.12842553661716, 53.82736836710284, 51.943285311422045, 50.663996434980824, 51.379381841228856, 50.99526805262412, 50.82421741177959, 59.708683952208496, 65.63507149296423, 61.94296406161401, 67.30151007252356, 55.49736453640846, 8.00528883934021, 8.044433113067381, 16.56308666352303, 8.994147777557373, 0.29924267662629006, 0.31250733581762163, 8.977581647134597, 49.57836674105737, 49.97451436135077, 40.22819326769921, 37.030582966343054, 58.070749236691384, 46.25898645770165, 70.73605506650864, 60.881421642918745, 65.9406594307192, 12.758480752668074, 0.33512721559213055, 0.20000105753781336, 0.07890462770216888, 0.1338681191085808, 0.1497638459888197, 0.16103436299149068, 0.14318670536721909, 0.14192278286622417, 0.15809120640398996, 0.17371373100867196, 0.2682371371455731, 0.18539929912695963, 0.11719291308714498, 0.13361083614009042, 0.14383259409617993, 0.1631906859937214], [0.02955446744547977, 0.019150708065999132, 0.03252248550134321, 0.006223660471263312, 0.09872459400925906, 0.05453188896119114, 0.04841373076722507, 0.09358141676432664, 0.08059332297453958, 0.07307139675944083, 0.09575513762331779, 0.04003858944821743, 0.049580375423594836, 0.0756987106175192, 0.06937745102350751, 0.6044439238405998, 41.88802657588836, 57.47634933840845, 55.685767742895315, 40.51800543262113, 28.889633071038034, 18.70754449598251, 49.44650057823428, 40.81423067277478, 47.108418864588586, 23.797061020328155, 0.049718746224478375, 0.2640287097423308, 0.6157131997808334, 12.251506563155884, 15.072868408695346, 2.4400594157557336, 35.185798137418686, 65.58842274450487, 62.914648902031686, 61.807081391734464, 55.5808953315981, 49.51354565158967, 51.04735712851248, 56.919474755564046, 61.04869111891716, 59.96816442858789, 60.786433604455766, 59.43909552789504, 58.55373028785952, 56.31200551986695, 49.74289448030534, 43.74941087538197, 42.62776990090647, 42.8147885107225, 42.2556624873992, 40.74023123710386, 42.13049181046025, 42.51909671291229, 47.86263965791272, 46.84082692669284, 50.63219777999386, 49.48736383068947, 47.7084199074776, 43.99632800009943, 43.177046852727095, 40.397125828650694, 42.700694607150176, 41.54084582482615, 41.42686566998882, 40.48463782956524, 41.941821882801676, 40.11517801592427, 41.465312742417865, 39.22984023247996, 42.15837594001524, 41.39252924150036, 43.54975438887074, 40.309982530532345, 41.96403034271733, 40.40220922039401, 41.52654094080771, 40.548984312242084, 43.00125406634423, 41.46990583788964, 43.060897627184474, 40.25397500684185, 43.82687768628521, 40.39098339696085, 51.11440612423805, 49.86251500345046, 62.437512182420306, 35.46049741006667, 23.306851040932443, 55.990630042168405, 47.17687599120602, 55.364364808605565, 51.15353961144724, 55.62513966714182, 52.16960214799451, 52.924725086458274, 48.75153895347349, 43.9621013979758, 37.483044055200395, 41.121893544350904, 38.951850091257405, 41.736109256744385, 39.06150779416485, 40.83310511804397, 39.868857091473, 42.183396739344445, 41.24587574312764, 43.44567037397816, 41.546505804984804, 41.701180550359915, 42.571515267895116, 45.43044067198231, 46.44844870413504, 48.519318949791696, 44.29520476248957, 41.277301772948235, 41.44277480340774, 43.105342003606985, 40.559559022226644, 41.379761926589474, 42.63982726681618, 42.44065323183614, 42.93538178167036, 52.24168354465116, 53.31448708811114, 56.37037431040118, 54.770918046274495, 54.71862108476701, 55.957062398233724, 58.537393616091826, 54.80787069566789, 53.058630881770966, 48.3364188286566, 48.766220385028475, 46.787921997808645, 45.383654640566924, 45.19130945205689, 48.34935872785507, 49.68043858005155, 55.89210402581, 59.48625026210662, 63.33346389955091, 61.78253127682594, 17.851181261001095, 0.21168054291798225, 1.7935862536391907, 6.034917562238633, 0.12498447926895273, 0.048687534421802535, 1.1293875329917478, 26.26866609819474, 44.46869119521111, 30.417586488108483, 13.467314820135794, 27.5932877679025, 37.55478812802223, 43.63718794238183, 47.530944424290816, 52.757337939354684, 17.93360790898723, 0.3601679638508828, 0.004476569189254436, 0.09684274498853954, 0.04419471985930878, 0.07095566109543847, 0.04731022324713488, 0.06314541769003676, 0.057647526414403995, 0.041512285975078424, 0.02171111563521047, 0.016226012282253757, 0.0039029596589370483, 0.046687175429636435, 0.0389101266139938, 0.054613013841932824, 0.03811815257875189, 0.09653303096251142, 0.026790146423023076, 0.1399207806154605, 0.01979697409326271, 0.06038278206101349, 0.035338720471988765, 0.04801413930592038, 0.06444168442319478, 0.017423830971482302, 0.029525252682487332, 0.053808154207804514, 0.06443700362597743, 0.07207450952621237, 0.07431770689905652, 0.0498473072694915, 1.1555054928025892, 52.54249403553625, 65.47411311057307, 63.63204648417812, 46.27073003399757, 33.235128925692656, 23.74567012633047, 48.21958318833382, 42.1286561412196, 54.47504974180653, 24.46355800474844, 0.03604246799143092, 0.163446115029435, 1.663816475099133, 11.954906736650775, 9.8152724389107, 3.407955246586954, 35.90304666949857, 68.86630042906731, 63.582404967277284, 64.2302667710089, 57.05514953982446, 52.473103384817804, 52.85208279086698, 58.847943352114775, 63.30092391660137, 62.59441483405329, 62.15733728101177, 61.83743269212785, 60.50606650690879, 58.24079967314198, 52.03958734389275, 46.39298638989849, 43.985070797704886, 43.85108263261857, 44.8686082132401, 43.37774668970416, 44.56851159372638, 44.430169597748794, 49.8167174093185, 49.98033123631632, 52.492413213176114, 51.85662838720506, 50.46416736418202, 46.50796282675959, 44.952786199508175, 42.9626226425171, 44.438567392287716, 43.48191699674053, 43.301684087322606, 43.34667367319907, 44.03046831007927, 42.79802430060602, 43.313078572673184, 41.1292048423521, 42.82164481378371, 42.43172983969412, 45.08542899162539, 42.60247845803538, 42.60864050157609, 42.60290207401399, 43.515480718305035, 44.07388502551664, 44.38230491453602, 43.47651981538342, 45.072806804410874, 42.55908135444888, 45.3430228079519, 42.4595590560667, 51.9968335090145, 52.4973750114441, 64.55117548665693, 39.843330306391564, 25.242864316509618, 55.79497829560311, 47.80137615819132, 57.72066593170167, 52.500787473494015, 59.12927535272414, 54.075422979170284, 54.66787738184775, 50.611487665484034, 46.37016604023595, 40.962311913890225, 43.235294049785985, 41.071275357277166, 42.8945852095081, 41.71018238990538, 42.86703055904758, 41.01177300176313, 43.49096198235789, 42.18047457356607, 43.91790413087414, 44.12498958649174, 44.81625241618003, 44.889031994727354, 48.781713747209125, 49.36062028331142, 50.71955680847169, 46.70383814842471, 42.59040148027482, 43.939073162694136, 43.514460902060236, 42.8988645153661, 43.329623130060014, 44.24279012987691, 43.58193351376442, 44.663503554559526, 52.78055444840462, 56.446707556324625, 59.78063591064946, 54.8621053080405, 55.23194559158818, 60.113135230156686, 59.540869266756125, 58.471666459114324, 53.690838506144864, 50.60438033073179, 50.964767702164195, 50.74982573909145, 48.45759261038996, 47.24900053393456, 51.10743215007167, 53.056473578176195, 58.105297473169145, 62.65619608663744, 64.4763131295481, 65.450119972229, 20.095977244838593, 0.9737342175456786, 4.555261759988723, 7.951166014517508, 0.0578242092723808, 0.010246517917802258, 0.961143531866612, 31.046203182589625, 46.26198707088348, 30.64591746176443, 15.92507295070156, 34.96338405916768, 45.50711124174057, 50.064807322717485, 53.45272710246425, 59.60165815968668, 27.683686633263868, 0.25311941851771647, 0.11466099249739801, 0.06933359248984246, 0.04202562234094066, 0.03329859768611289, 0.0512429892325834, 0.04047620951408341, 0.08701338492814573, 0.0916667408760517, 0.01044847114357136, 0.09018025451129483, 0.04372254539761813, 0.002080447260185235, 0.05645076301129115, 0.03126631197970241, 0.056310496142795013, 0.17830780707299712, 0.17607686710694145, 0.22031225474371066, 0.05505493549149364, 0.12371048271175354, 0.11156929146137931, 0.12419038317016057, 0.16974642211871763, 0.18362624991324641, 0.19431296195234024, 0.21302465950289082, 0.12753391262864874, 0.22886107585603194, 0.22661449237456247, 0.20842134441819885, 2.267948264075864, 60.71853737677298, 72.83496241415702, 72.14124418074086, 55.593278254232104, 39.88066342569167, 26.8304907121966, 60.590432766945135, 54.701884331241736, 60.22753900097263, 29.56564768668144, 0.27755546293431715, 0.3090386429140645, 0.649782294227231, 23.61130149133744, 27.848039827039166, 5.398738047768993, 39.81133161052581, 70.1490645254812, 67.91025407852666, 67.28893495375111, 61.415334670774406, 53.97917978225216, 54.40502758949034, 60.685165851346916, 66.81093139033165, 64.16603795943722, 65.22767059264645, 64.31285227498701, 63.52799777061709, 60.934193211217085, 53.532880736935525, 48.598174279735936, 47.20095542169387, 45.95322201328893, 46.70686229582756, 44.17313668035692, 46.1238843394864, 47.9963924807887, 52.92550171575239, 51.99018509157243, 56.46874735432287, 53.90162275683496, 53.67490583850492, 48.080464563062115, 46.78871431658345, 45.42315290820214, 47.35094685708323, 45.162887957788286, 44.45318998829011, 46.03775693524269, 45.16850086950487, 44.3214964097546, 45.045652235707934, 42.41163945967152, 45.10477019894508, 45.535999498059674, 48.44877119987242, 45.55169290111911, 44.933350855304354, 45.54416979512861, 45.19451402848767, 47.0545921787139, 47.68232045635101, 45.004157481655, 47.604096628004505, 45.136400192014634, 47.901008282938314, 45.586452945586174, 54.703833749217374, 54.059627594486365, 66.74738114879978, 42.17811722909251, 26.749093686380697, 55.12610043248823, 49.76138453329764, 57.935003849767874, 55.076400080034816, 59.85412543819797, 57.247228007162775, 56.81251172096499, 51.880029247653106, 49.146874643141224, 43.880563166833696, 45.49768578621649, 43.90105755098405, 46.949288306697724, 44.214717726553644, 44.95761855956047, 43.091044964328894, 46.03542312499016, 45.60645703346499, 48.21861436290126, 46.85625360858056, 46.58435490823562, 46.985264285918205, 50.52854914819041, 51.90997654391874, 53.16597830864691, 49.506144139074514, 44.60404434511739, 46.599103020083525, 46.36203104449857, 44.36909829416583, 46.87268833960257, 47.144877295340265, 44.96294906062465, 47.38934293870003, 57.183705222222116, 59.58641582919706, 61.823622026751124, 57.0012051828446, 57.2788344660113, 61.95868099889448, 61.4524991281571, 62.8073367764873, 57.50579457129202, 53.46193290525868, 53.632336355024776, 50.990851463810095, 52.40053561425979, 49.60418770390172, 54.6150234437758, 54.38802411479335, 61.96261905854749, 65.87953321395382, 69.06858490359399, 66.67131070167788, 22.355586059631843, 2.8635219316328726, 6.041202670143497, 10.516205872258833, 0.37437619821679213, 0.17665832784147034, 1.4151552439697328, 38.46582920320573, 61.3348868585402, 43.176081949664706, 20.49494504928589, 38.27797905091317, 48.8468486262906, 59.405551418181396, 62.52957021036456, 67.10199479133853, 33.84248833502493, 0.6704111421300519, 0.20503969442459846, 0.1639060895409315, 0.18494946761958062, 0.12849721456727675, 0.14341115380727476, 0.23154682690097442, 0.2598709973596758, 0.16728447599997445, 0.15967904620112913, 0.10573879545254093, 0.11300439630905468, 0.1358989262652974, 0.11227962350653065, 0.1534145154179104, 0.20738294288035364], [0.012091859976100105, 0.06307065516950623, 0.07796580993360089, 0.025940570236754515, 0.07840077933524886, 0.004220905539114028, 0.0007066342345018301, 0.0028560736973304306, 0.01890711700393548, 0.022065961816077753, 0.08858407967753949, 0.02482330377754425, 0.041950135867321686, 0.026112179677452774, 0.041774690241342595, 5.714165741397489, 58.404358586957386, 58.407092478967485, 55.63448667526246, 39.18707070812103, 30.779385912802915, 21.46016582365959, 39.871732188809304, 38.65598570915961, 50.810234162115286, 9.460088091511881, 0.05800106066970095, 0.20427927555095768, 1.114415233173678, 5.184927198194689, 9.276274058126635, 2.85336789584929, 37.157573623041955, 65.39587751511606, 62.836370160502774, 62.86396011229485, 54.59121857920001, 47.99976571913689, 49.59939064518098, 48.380922040631695, 53.26740687893283, 57.544245566091234, 60.0875025410806, 57.956769081854056, 57.685341065929784, 50.58155998106926, 44.79590708209623, 44.28539099231843, 42.489984881493356, 41.82187972530242, 42.467203755532545, 42.07165625787551, 43.974201909957394, 45.464008315916985, 50.59514314897599, 51.68254575421734, 54.639930494370006, 54.14104030978296, 51.52215219313099, 46.16585762270036, 42.30809673186272, 40.694233602093114, 43.07625370640909, 40.637198417417466, 43.00470967446604, 39.597617349317, 41.334470318209746, 39.941848478009625, 40.744738040431855, 39.917098322222316, 41.71767019456433, 42.56754582928073, 41.63874033958682, 39.59627589871807, 39.841420112117646, 39.445119519387525, 42.53638259826168, 48.499977742472005, 51.60461218126359, 50.02596801327121, 50.78081638582292, 45.101738206801876, 49.01780905262117, 45.266379694784845, 53.92695734577795, 49.63832409151139, 62.89123627447314, 36.15847925986014, 28.434934269997385, 53.06604023902647, 46.46251824594314, 52.92473685356879, 50.84536290937855, 55.23960990290488, 50.4530474447435, 55.75832374634282, 48.77792081525249, 42.96463089604532, 39.390284784378544, 41.25928632674679, 39.82214558509089, 40.55338128920525, 41.10325051892189, 41.45280822630852, 40.22874632189351, 40.720956710077104, 39.780399799346924, 40.429104912665586, 39.9844846417827, 39.86530342409688, 40.79062192670761, 41.66079582706575, 40.21328826104441, 40.7574975106024, 39.41458778996622, 40.929489520288286, 40.39085788111533, 40.02380640276017, 41.32109895829232, 41.11401742504489, 42.65719944430936, 43.12785248602591, 50.99560537645894, 54.36872213117538, 57.4809463562504, 54.51754862262357, 54.645566940307624, 54.18508068207772, 54.1592832534544, 55.21267498693159, 56.84364749539284, 55.777390387750444, 53.824724689606704, 49.53865666543284, 47.20118684153403, 45.41273901539464, 46.13219584188154, 48.52072708068356, 58.308640987642356, 55.19945659945088, 58.893886073943115, 59.22914281968148, 64.73805681351693, 42.80266446451987, 5.351245009130047, 0.8275313627335333, 6.426315682549631, 0.09391468799402637, 0.2053810019166239, 0.07703843751862165, 14.309262364141404, 36.61307411809122, 31.766364074522453, 34.88676448022166, 14.644746607349767, 24.817487193692116, 35.361386960552586, 50.874415905244895, 52.548887498917125, 44.184656681553015, 1.0895919006678367, 0.04375999560579658, 0.061963378496828585, 0.0657339062121126, 0.03638056940549324, 0.03612112223861679, 0.038157337976078835, 0.016175144044081533, 0.01818314859373195, 0.029385947254336173, 0.045316877789915576, 0.005491416875062691, 0.04576715362829067, 0.02100923353986394, 0.03267020257490297, 0.06204421992503828, 0.04310410942942385, 0.01643981018494214, 0.04749830166298536, 0.046878207114435015, 0.12124164946257107, 0.008150659362605263, 0.03781075979913435, 0.021771356959136266, 0.026977131248361645, 0.05681804471438932, 0.06619520605571809, 0.03608197897612568, 0.03450436645277566, 0.06299121568219797, 0.04847510207083918, 9.285090565681458, 68.92333953611313, 63.86996176935012, 65.1068498242286, 45.93508105124197, 40.10851783137168, 20.702991485595703, 33.903720455784956, 45.10912795220652, 55.44136877982847, 10.42312312510706, 0.03143297057719, 0.230351070903482, 1.9375286587784368, 15.589103314184374, 11.689780008408333, 3.6790184820851977, 38.52407640026462, 67.93374907585883, 63.48640887968002, 64.89274332600256, 57.36813506772442, 50.45177659680767, 50.57080876442694, 49.91916187347905, 56.120825275298095, 60.79227401364235, 60.95541715621949, 60.83860897248792, 59.17565345764161, 53.42907521032518, 46.505330916373964, 46.4266913167892, 44.13270881099086, 42.775145115390906, 45.880787603316776, 44.07030390154931, 46.14135849860407, 47.351186121663744, 51.509898708712676, 54.13822404799923, 55.56715526888448, 57.1375899161062, 54.04964516239782, 47.53011680418446, 43.703581902288626, 42.58915416656002, 44.33868423584969, 41.829116498270345, 43.792172555000555, 42.71546625321911, 43.854412724894864, 42.37939757685508, 42.5894404995826, 42.309442104831824, 43.58928011309716, 42.97987714890511, 44.019058135248, 41.99573093844999, 42.403555454746375, 40.611875595585, 46.13508662869854, 49.93640069038638, 53.62436217646445, 51.85407100185272, 52.364814589100504, 47.79910902823172, 50.115190167580884, 47.025892196163056, 56.184191165431855, 52.57622641901816, 64.12348808780794, 38.10616354788504, 29.461446000683694, 52.99282135501985, 47.352825672395774, 54.07207719741329, 52.40736053835962, 55.95865095815351, 52.54663213606804, 56.962228590442294, 50.42872090493479, 44.065597057342536, 41.50060230685819, 43.261267985067065, 42.56558856656475, 43.21205008414484, 43.18670372809134, 42.922747827345326, 43.04428638950471, 42.99718264610537, 40.85861621364471, 42.6099427284733, 42.297051337457475, 43.0794818170609, 43.341460843240064, 43.285049315421816, 41.67162941348168, 41.2347597460593, 40.90357049818962, 41.98330486974409, 43.11261407790646, 41.97663684045115, 42.71783928717337, 44.115164049210094, 43.28724976508848, 44.256722388728974, 53.64774342506163, 57.70295643037366, 61.029648011730565, 57.46555497569423, 54.354632977516424, 55.29324047027096, 58.168620217231016, 57.90707657414099, 59.68147054795296, 59.07841397869972, 55.09946361664803, 53.15577230145855, 49.14195599094514, 48.01994631367345, 48.16932585931594, 51.78444500892393, 60.43062363901446, 58.08604648036342, 60.87376909871256, 60.93052971747614, 64.89941920003584, 44.39876317977906, 7.186712247710075, 1.1457048380567183, 7.733485746768213, 0.4855401832009516, 0.01442821651336647, 0.059377433386661356, 15.242598191384348, 44.750023195820475, 29.99800074485041, 36.26682689113002, 23.613270521163944, 31.419830514538674, 40.67949333498555, 58.69496699302428, 57.74519643475933, 57.65357771227437, 3.7125395478740817, 0.12160676696728315, 0.020042057111558896, 0.021722869339188742, 0.09324115881275746, 0.04687325052556492, 0.02257426689949728, 0.011359568020599264, 0.01988736097700894, 0.01733637437404644, 0.03773474472484762, 0.03989989689040569, 0.012862733077077616, 0.03820857776689433, 0.02679278368070241, 0.02580546488564822, 0.10414970693208518, 0.1117007444883066, 0.10417474268545067, 0.19789178765589194, 0.23989497894240966, 0.1396698102114662, 0.13382770030969574, 0.12176186912843298, 0.1492522371512267, 0.2056979631344157, 0.1722617339222662, 0.17945212792725335, 0.10510951550977846, 0.12578799058833431, 0.1697389297788182, 13.45414742346733, 77.29889423616471, 73.23426754243913, 72.38183452237037, 53.49778729100382, 43.855409006918634, 32.1699857711792, 51.93000808838875, 52.17907074959048, 63.359426067721465, 11.242551361360858, 0.25812189605447555, 0.3159942922572936, 3.5558366919717486, 16.407801989586122, 21.37563874644618, 6.119220083759678, 42.20221234906105, 69.67455187151509, 66.20472123545986, 66.67579004841467, 60.08853804680609, 51.99656286547261, 53.735102453539454, 51.76511556871476, 60.19427730191139, 64.04112615892964, 64.54098909131943, 63.4256866670424, 62.19748273972542, 56.069677568251095, 49.13629601078649, 49.029172159010365, 46.952657622675744, 44.27734228872484, 48.6065956084959, 45.91075058906309, 49.6429838672761, 49.0130865189337, 54.320594649161066, 56.47905534313571, 55.90754639717841, 60.28559400189308, 57.654601450889345, 50.42551240613384, 45.208991496793686, 45.03240639163602, 46.25642514997914, 43.581372614829775, 46.83201336091565, 43.948953613158196, 45.30014345722814, 44.58504830637286, 42.954766135061945, 44.93084446076424, 44.513519963910504, 45.66708903158865, 46.31166388911586, 43.38567772219258, 45.205178952986195, 42.75312100687335, 47.228439469491285, 53.76985465326617, 56.29970104463639, 55.61214093239077, 56.48997129932527, 49.04351626673053, 53.35450310860911, 49.9920787349824, 59.40473164281538, 54.58457016175794, 66.6562331107355, 41.87212920957997, 31.961523563631122, 52.670673170397365, 47.8998904074392, 53.26539862540461, 53.508150192999075, 57.2035014244818, 54.63849490688693, 58.87717285463887, 53.44441167769894, 46.07250129022906, 44.010032761481504, 46.90012531895792, 45.34581553551459, 45.68198619350311, 46.50051816817253, 44.83910806717412, 45.43907773110175, 45.90185465351228, 42.526819859781575, 45.18448452795706, 43.21080277043004, 44.52252180345597, 46.11948344015306, 46.66730911500993, 43.424018890626975, 43.48274461684689, 43.051962467931936, 44.875837141467684, 44.71904039382935, 43.01337811254686, 45.19959349786082, 46.628556097707445, 45.211203713570875, 45.987134825798776, 57.22163454178841, 59.551569492586204, 64.8962930710085, 58.40958710639708, 55.535105582206484, 58.04304553616432, 58.13825714972712, 58.48327667482438, 61.82384167948077, 60.66587171246929, 58.42408810892413, 55.9772979059527, 52.96591389563776, 49.76403605553412, 51.20715448933264, 53.32488529143795, 64.40516917936264, 58.66776535587927, 64.3187907434279, 62.97411595621417, 68.44917205072218, 47.358991638306655, 11.501518007247679, 5.703606230597343, 12.411981513423305, 0.32787518215275585, 0.31763209630885436, 0.21577575784777442, 18.77987692433019, 50.49702505911551, 43.59170806023383, 49.220713261635076, 22.44163893884228, 35.6494419036373, 48.406507661265714, 67.55500501201999, 66.50842251316195, 65.04005970493441, 5.740051423349689, 0.33295223068806434, 0.1681423565793422, 0.17279701487671945, 0.11071696501946258, 0.15585786092185205, 0.14383712933669168, 0.14195198613789775, 0.09380093159814996, 0.15175221187453117, 0.1580285557335423, 0.0775866040719613, 0.15180789114486787, 0.16769856184480653, 0.09775602138571202, 0.17235485957034175], [0.06401285521625992, 0.06230185529397381, 0.030551864127177867, 0.04192503499648264, 0.07649962489883746, 0.05673426916942962, 0.04499904706232971, 0.04165427271096457, 0.10897160222333287, 0.03626389804506495, 0.06895568897767414, 0.050257363491841865, 0.015885061978723015, 0.038171100745638536, 0.08214348656756264, 17.823479521659113, 59.21145293020434, 56.51553338573825, 55.261104491449174, 34.74884217785251, 11.108370019543557, 25.20796306671635, 43.26132682061965, 37.596412320290845, 52.9666316893793, 1.9978800848607097, 0.17852626470548494, 0.12289521194273427, 8.579933720250285, 15.816885156016196, 7.267818527836954, 5.841555499261426, 44.04781303098125, 65.97348966906148, 59.84073446642969, 59.28824117106777, 53.860681056976325, 47.705234942897675, 45.439846515655525, 45.59860052600984, 45.02664050748272, 45.69316887086438, 46.26405808233446, 47.239296590128255, 44.791510105133064, 43.67832183837891, 44.93900691309283, 41.54342282202936, 43.010338275663315, 41.3513796560226, 41.40464936533282, 41.705726577389626, 45.72779555474558, 46.44707195220455, 49.680748447295166, 52.89294212095199, 54.30910210455618, 55.53325422348515, 53.23141521023166, 48.51740875551778, 43.7782246066678, 41.93467140197754, 41.64112121828141, 41.23974115617814, 41.314113217015425, 40.59432298906388, 41.16036415100098, 40.22275294027021, 42.73014376240392, 39.54113129646548, 41.7050362402393, 39.44231110234415, 38.70574489716561, 38.799132608598285, 41.78194999694824, 45.07095544568954, 52.17254784799392, 53.147041105454974, 54.87010694319203, 52.05486497571392, 54.522765374952755, 50.43846015007266, 53.25112904271772, 48.49110534114223, 52.58598527600689, 46.97171641934303, 63.0202587189213, 36.205834034950506, 29.86037262024418, 57.67968893051148, 49.99185123751241, 57.91152846428656, 50.39328229042792, 53.107283961388376, 52.74346059368503, 56.258622061821725, 48.44263269055275, 41.59114237754576, 39.34511869184433, 40.95664016662106, 38.76795761046871, 40.57885316110427, 39.41678039489254, 40.86555096410936, 39.80003126205937, 41.823342769376694, 40.08170450887373, 41.68312588045674, 41.43376511912192, 42.19727800738427, 40.809041377036806, 41.52954547635971, 41.79916527963454, 41.04195956260928, 39.430924461733916, 40.567435141532656, 40.5383272324839, 42.133194323508974, 41.32069495416457, 41.537821677423295, 39.751997916929184, 46.656761861616566, 54.05323805347566, 55.232471189191266, 55.682072870193, 55.965420969070934, 56.4320614261012, 53.18857116083945, 58.122198966241655, 52.96670621441257, 57.969873720599765, 55.73495818722633, 54.50329472941738, 49.47276476890811, 46.16331984919887, 42.1577875844894, 51.80180934167678, 53.504404329484515, 56.129332896201845, 57.575142075938565, 65.60934074463384, 61.21687450716573, 64.59956968984297, 57.04538676046557, 28.47799993330433, 2.3376948698874447, 4.687117626590114, 3.187408951982375, 0.16178434774760278, 0.04242691451743726, 4.345518898579383, 46.78661192617109, 38.945397792323945, 29.112651194295577, 15.618016085317059, 27.663458970285234, 37.9379330911944, 52.18737832961544, 48.330609798431404, 54.60659427027549, 15.297387819136343, 0.351594643246743, 0.11357391373284402, 0.1186083754404418, 0.042768995758266225, 0.027851216502547748, 0.029919749659095562, 0.08908274162921215, 0.047581234511228344, 0.11687659538320957, 0.06632288993005792, 0.06812881963748126, 0.018818838777200832, 0.027704907115548853, 0.020918513407870647, 0.025381954244127678, 0.0501276686367008, 0.025170182643999017, 0.08450608640428513, 0.04687967800324963, 0.030934272236340953, 0.06072334261731275, 0.053181494285743085, 0.01310850270167594, 0.07184511215816583, 0.05933424901036967, 0.0692582170989725, 0.008284185614977634, 0.02437393958379905, 0.05948798370457465, 0.02562789336567925, 24.167756380573397, 67.6001593374437, 61.31118005321872, 63.57274809191304, 41.91654612941127, 23.553628921508793, 27.340065433133034, 39.16689011358446, 42.36766184529951, 56.85437517781412, 2.5582703371201796, 0.12409056191362682, 0.14900028615468933, 5.683820814855638, 10.326859335745535, 5.8551504342786735, 4.42247482076768, 45.35541749769642, 67.75645794407015, 63.50069807421777, 61.75991096804219, 55.82613760425199, 49.08902752783991, 47.65502075995169, 47.42744876492409, 47.429986538425574, 47.941691106365575, 49.09991602743826, 50.44708544208158, 46.26070445583713, 45.69436911613711, 45.109637860328924, 42.49303256311725, 44.32330070003387, 43.18088293075562, 44.08574235054755, 42.99323281934185, 46.35772820441954, 48.15153791058449, 51.724248393889404, 56.97468996047974, 56.92980627859793, 57.1497884873421, 55.614384528129335, 50.51403245618267, 45.33700981447774, 44.64755519743889, 44.915829627744614, 43.50814588608281, 42.786625892885276, 42.54598063807334, 42.23785100444671, 41.62019929578228, 43.99311950129848, 42.87092547262869, 45.31051812633392, 41.20544395139141, 41.39205071233934, 40.74674237158991, 45.36225418890677, 46.95819208698888, 53.452327020706676, 54.54103185284523, 56.55811855869909, 54.11842000099921, 57.99015237439064, 52.15812529287031, 54.88947168473275, 51.60160372334143, 53.61008082666705, 49.55831950710666, 63.997819269857104, 38.21928470365463, 31.01006050263682, 59.84740249572262, 52.20374638034452, 58.736967732829434, 52.21508203014251, 56.12721873867897, 54.8714993846032, 58.307813367536, 50.79541544760428, 44.62598216149115, 40.63697876468782, 41.5403006153722, 41.2286957617729, 41.66585960695821, 41.60323112241684, 42.359573918004195, 41.60350961069907, 43.185264218238096, 42.036868756817235, 43.971326812621086, 43.97787717080886, 44.72906989435996, 42.90542271829421, 42.77504705613659, 42.805633698740316, 42.61780708066879, 42.23813733746929, 42.89585213507376, 43.055190578583755, 43.07852475873886, 42.75268954615439, 43.42352467198526, 43.06758526832827, 49.33938849356867, 57.42537421564902, 60.12933461896835, 56.21045535610568, 55.81028730638566, 59.95321235349102, 55.510751585806574, 59.15474330225299, 57.158586363638605, 59.488795880348455, 58.45422367895804, 56.217648983001716, 50.540551600917695, 46.743442320054584, 45.92270205097814, 53.256612516218624, 56.83999576876241, 59.30848844589726, 62.13268126210859, 65.74209728548604, 62.02482392711025, 66.47450970065209, 60.44753297682732, 30.428659339104932, 2.034301130521682, 7.012240319482743, 6.842683121081322, 0.23148385447359857, 0.06682148293381737, 4.860594253386221, 53.071339361129276, 36.83546466212119, 30.424860523593043, 17.429377417410574, 30.347927155033236, 44.423521180306714, 57.65529963278002, 55.38219982577909, 63.40791440779164, 21.3769958865258, 0.39728504635633966, 0.05326481400838783, 0.06962433817886537, 0.03182699449450499, 0.06756732315425912, 0.040074947981103774, 0.01765159848746994, 0.03568032290786505, 0.01665078505362955, 0.061073169007056186, 0.11595107690100709, 0.031216430079732693, 0.024902687723478003, 0.04041168192822126, 0.0644882395863533, 0.2241307893587697, 0.16041556313153238, 0.31798048245330013, 0.11646997123475998, 0.1878981093966192, 0.22161638153897179, 0.19351462172644754, 0.15486920913380964, 0.18076743960620897, 0.16848289798344337, 0.13180988600417493, 0.17207675433206945, 0.06075439982176308, 0.15973662536951805, 0.40144698754433666, 31.5698278334833, 74.24809825035834, 70.43539754806027, 69.90190029144287, 46.57731425377631, 18.96349483920682, 35.736545978053925, 58.10851381671045, 50.97471483292119, 63.22442593113069, 3.349048355894704, 0.3702214888988003, 0.2051469926992732, 17.310813973026892, 30.999705445381906, 15.109012069240695, 10.303326095304183, 49.15989691211332, 71.21291329783779, 65.3060983842419, 65.26001445708737, 57.39048865533645, 51.770869685757546, 48.88999862055625, 51.21672899492326, 49.86022433926983, 50.090173290621856, 51.75960856099283, 52.111351028565444, 48.17123213121968, 47.99718087719333, 46.92604826342675, 44.9732139033656, 45.88046596896264, 47.26273275190785, 46.200256809111565, 44.610429963757916, 48.68828288970455, 49.570078772883264, 54.53859998333839, 57.32976644269882, 58.62743946813769, 59.22394567920316, 58.73522227810275, 53.46909515319332, 47.568085347452474, 45.95751700862762, 45.41034636958953, 45.50504415265976, 45.78367756259057, 43.36196699450093, 44.02271770661877, 43.61430483479654, 46.138946240948094, 42.8007189689144, 46.73603688516925, 42.82710475306357, 42.137497163588, 43.0212228528915, 47.88943729092998, 49.01129007339478, 56.23640183479556, 58.34931596632927, 58.96675978937457, 56.916391772608605, 60.03102433296942, 55.97890607772335, 56.22791774811284, 52.87383233347247, 55.571348282598684, 51.99027530608639, 66.11583248261483, 42.41431059375886, 34.091864785840436, 62.076356026434134, 55.17809144912228, 60.57909319477697, 53.43235823415941, 57.726961335828236, 58.54192787601102, 60.75615290672549, 55.21158064565351, 47.26416441702074, 43.748830364596465, 45.79162036218951, 44.236431967827585, 44.19386248434744, 43.365046055086204, 44.74791296066777, 42.96552127407443, 45.381018807811124, 43.760044420919115, 46.01488167239774, 45.74291236938969, 47.78580434860722, 45.38021864429597, 45.42025035427463, 45.56458573187552, 44.94525132640716, 45.460548785425004, 45.90678115044871, 46.518592449926565, 46.372723425588305, 46.054489766397786, 46.071285355475645, 45.64846561801049, 52.101721609792406, 60.168240608707556, 61.02724752118511, 58.39522338682606, 57.46733965412263, 61.40018255479875, 56.58591247374012, 62.16933188899871, 58.53341241036692, 61.94035568544942, 60.59295877333611, 59.76740183368806, 52.589966481731786, 50.29157523185977, 47.84046649932862, 57.94695138931275, 60.57157793352681, 61.68380914195892, 63.57426604916973, 70.53287629158267, 64.69108250833327, 68.85006181655392, 61.89557790756226, 33.66624447607225, 7.26533321603652, 8.687206622092955, 5.438634435976706, 0.41088522141498907, 0.25371079242998557, 6.468517443826122, 61.28724575042725, 50.83388213188418, 38.521750434752434, 23.406926393508915, 39.0754282859064, 49.631993386053274, 69.17207271822038, 62.588052749633796, 72.47681863846319, 25.483246772520005, 0.5085905431018722, 0.15249098110343182, 0.26306291801794884, 0.15335165024284395, 0.13413913037267425, 0.10415929069201793, 0.18517089767321465, 0.19588166487313088, 0.19478130214396985, 0.22754579482059326, 0.21207189127322168, 0.10428701287075397, 0.09017126063906378, 0.10485436992659684, 0.08023827186515255], [0.09439985913735244, 0.01575169468959493, 0.03388419912587251, 0.05468245971226885, 0.03649140317593852, 0.041185871232301, 0.015728740780163678, 0.0655436406152383, 0.04345279817859973, 0.07473639693231353, 0.0508030747333842, 0.036956893520489816, 0.025895225492516355, 0.05732307285671273, 0.8909373345874971, 34.96707500949983, 62.432613142075084, 58.43687111331571, 45.44554964188607, 26.82815690194407, 21.589258870770855, 31.993553638458256, 34.9378219727547, 50.22364370284542, 34.721750367072325, 0.038163723318927714, 0.0917012301544028, 0.05859076834073471, 1.0583643182631464, 9.406044694685168, 5.765922886710014, 2.741661980267494, 44.07598349355882, 63.31897858650454, 62.05144113109958, 56.81750489819435, 49.19414312608781, 48.54956434619043, 47.81532802889424, 46.030759426855276, 45.120616574441236, 42.855286982751664, 42.221906569696245, 41.240768817163286, 43.15561502210556, 43.25033633939682, 43.76523763902726, 41.87442379613077, 43.02259960482198, 43.2558786484503, 41.86003654233871, 42.23505435451385, 42.75891826998803, 42.861366656518754, 49.37179903830252, 54.275793337052875, 56.170196148657034, 52.58463205829744, 56.20079848074145, 52.603016207295084, 48.466355185354914, 40.3750781859121, 41.6908960957681, 40.486300914518296, 43.025258971798806, 40.44335488350161, 42.4927697643157, 40.33210862067438, 41.80410746605166, 38.64951379837529, 41.8053626245068, 39.46006767211422, 42.01338552659558, 38.699069023132324, 48.426080288425574, 49.71613214861963, 55.71061203556677, 55.568641847179784, 54.52100030837521, 50.816404050396336, 56.98682185142272, 53.63555269856607, 57.90315812633884, 52.91100463559551, 56.57618499571278, 48.33644628524781, 64.26902763305172, 33.297761332604196, 34.70700225522442, 62.7593191208378, 49.18725936643539, 55.747058699207926, 51.181294302786554, 55.31344852139873, 54.2206605019108, 52.02665528943462, 41.63797547740322, 41.79441528935587, 41.844574559119444, 40.19638284560173, 40.218128465837054, 40.48719913728776, 39.78309446765531, 41.32412310569517, 39.832794820108724, 40.10744310194447, 40.65170334231469, 40.816368364518695, 38.92044367328767, 41.04262636553857, 40.43476881519441, 40.9957814985706, 40.8290336978051, 42.12468670260522, 40.26542440537484, 42.41323978670182, 40.667184937384825, 41.07553112891413, 40.27584222055251, 40.97800139457949, 42.227378276086625, 50.78586055386452, 54.178451876486506, 53.71615740560717, 52.48077161850468, 54.83049100445163, 54.01800732458792, 54.43461402770012, 55.72979634807956, 56.830154542000066, 56.616150025398504, 56.08688500619704, 53.56957450989754, 45.78792156711702, 43.64961401108773, 48.01787922459264, 55.83954818787114, 58.686012221920876, 62.35065129495437, 58.945735885250954, 60.91578552799841, 58.600045634854226, 64.2726009122787, 60.225628806698715, 56.332339086840236, 8.076403371749386, 0.6610578827319608, 6.726892792409466, 0.030645809489332383, 0.12832793211864849, 0.5134931380950636, 35.811298508797925, 39.05979371839954, 42.3456024354504, 42.231747796458585, 21.059238795311224, 30.68801037726864, 47.1272893874876, 51.2374940226155, 57.06835223782448, 32.611462262368974, 0.8690806009596395, 0.065706058916065, 0.018998926896001064, 0.04732240021469132, 0.0632781500837976, 0.043104006007554076, 0.06780759897083044, 0.051844115444128556, 0.022136353805000265, 0.02183790893233832, 0.05309974504334312, 0.041825114148518736, 0.03748020818156581, 0.01690972468725616, 0.06303298279582974, 0.030389455402450218, 0.06089596137885125, 0.021487866122756275, 0.10231076649600461, 0.03994623754894541, 0.07847343511398762, 0.028727446802921837, 0.02285718891559349, 0.055008437784929434, 0.0863853460478206, 0.02297094339625009, 0.022969537624909032, 0.014995835954323413, 0.008450264858472492, 1.6191661742425736, 43.617595703371116, 71.30129214256041, 62.920014704427416, 54.41605729441489, 32.93819373653781, 19.145192753884103, 32.824747024043916, 37.989559327402425, 54.48889178614463, 37.80832621359056, 0.07288710664837592, 0.11199594114816959, 0.5901049642312912, 4.484457094823161, 13.280671777263766, 6.637422548186395, 5.725783801847889, 44.0071851207364, 67.62555276193928, 62.22934807500532, 59.331712799687544, 50.69521457918229, 52.36813291426628, 48.74109368170462, 48.02129560901273, 45.95286507760325, 44.140710446142386, 43.796608755665446, 43.36818002885388, 43.073927740896906, 45.577674681140536, 44.080062758538034, 42.32999924690493, 45.9096444806745, 43.83047842210339, 42.666770027529815, 43.34946640076176, 44.70893244589529, 44.98910342493365, 52.402645849412494, 57.13509921104678, 57.138943133815644, 54.996944627454205, 56.396916989357244, 55.28478776254962, 49.59871991988152, 42.09530030527423, 43.682871787778794, 43.14174552117625, 45.830302776828894, 42.92692122920867, 44.105875876642045, 42.90556392362041, 42.06137180328369, 41.14841268908593, 43.3711531854445, 41.84007167816162, 43.13820754328082, 39.5368206116461, 49.17806140838131, 53.538638776348485, 55.78290131784255, 56.34644785235005, 55.94651514484037, 53.481101528290786, 56.668062594629106, 56.18918826503139, 59.49038836263842, 54.88031295038039, 58.666667092231016, 50.24214552294824, 63.79170263967207, 34.31964466648717, 37.108775415728175, 62.78816423108501, 49.97968796760806, 57.50251546982796, 53.586252427870235, 56.87961562987297, 55.486789826423895, 55.13632605152746, 42.381947117467085, 43.05022878031577, 43.634587410957586, 42.868442612309615, 43.44479568542973, 42.68838228717927, 42.29006951855075, 42.961791100040564, 41.423743463331654, 42.99408789603941, 41.9051084979888, 42.764754756804436, 40.609259374680065, 41.99456599450881, 43.10139217684346, 43.27254872168265, 42.481022265649614, 42.20084344187091, 41.798737741285755, 45.370871636175345, 42.42162189176006, 43.37955097998343, 42.72791193377587, 44.763880929639264, 44.05072342964911, 54.654109862542924, 57.128815574030725, 56.30541986034763, 53.32003724190497, 55.96807249130742, 56.19904518127442, 56.198735314030806, 58.490238881880245, 59.350144017127256, 59.23661101248957, 58.12254413481682, 54.586429365219615, 47.781270088688025, 45.20524563327913, 51.237949017555486, 57.573039685526204, 61.315451514336374, 64.61321953804263, 61.10517717176869, 63.70433184408373, 60.95870802479406, 64.44734250345539, 63.80259113927042, 60.80280557755501, 10.549304792957923, 0.26051270324857007, 9.827442572962854, 0.2755137466855588, 0.09039013195903071, 0.525650616374708, 38.42880202877907, 44.779527264256636, 36.945687186333444, 41.69091962998913, 28.90895074413669, 35.73193719310146, 53.38669400061331, 56.915556307761904, 63.73468314447711, 40.94450043093774, 0.9437979529461554, 0.11084985829168752, 0.05843404973406465, 0.06664699108730401, 0.028272561030462388, 0.009184873272334377, 0.10519964575407006, 0.03473574415810647, 0.038462604861706495, 0.0354700202813312, 0.0073219547630287716, 0.005755004268364922, 0.09684580167935741, 0.027691412476762652, 0.0641240298958315, 0.27458258213535436, 0.1286235271442321, 0.08515991946502079, 0.23223932441924852, 0.10025997976622275, 0.15720157914104002, 0.1166296162973008, 0.14270762462289105, 0.09450874321403042, 0.19905446397681392, 0.09827156791523581, 0.13935197565344074, 0.10574169892577395, 0.1393180686019121, 1.919468963338483, 54.23441625410511, 80.02038371178412, 73.50487970536756, 59.59278968072707, 39.01150934157833, 32.093462290302405, 45.1745883880123, 49.85822000811177, 63.627900538905976, 41.07153815607871, 0.36395954749276566, 0.24177129680831588, 0.6850447697985558, 4.86357819649481, 20.355122358568256, 18.515764128777292, 5.666656032685311, 47.27884977094589, 68.20145084011939, 66.34132169908094, 62.32483425448018, 52.96178363984632, 53.91034610809819, 51.40813281459194, 50.3882695013477, 49.89265057348436, 45.899297268159934, 46.85712045238864, 44.93885001828594, 46.68474405042587, 47.69850807805216, 48.28679300123646, 44.40984387551585, 47.8390230671052, 46.64561056321668, 45.998941160017445, 45.51246527702578, 46.120381662922526, 46.73116922378541, 53.280484061087336, 59.56862395809543, 58.900024583262784, 57.142273226091945, 58.789111721900206, 58.43396463701802, 53.072378789224935, 43.385210960142075, 46.15733431231591, 44.51250799240605, 47.79862657670052, 44.67989906187981, 48.136585835487615, 45.94149804884388, 44.11478750167355, 41.230480440201305, 46.54051849918981, 43.53415120032526, 46.126786893413914, 41.357686827259684, 52.3348202243928, 55.16997998760593, 59.012729967794115, 58.761729655727265, 57.27408447573262, 54.39453524927939, 60.029718183702045, 58.26279240269815, 62.52420833033901, 58.28083922786098, 59.595586330659934, 52.50056389839419, 66.87919632081064, 36.86074826025194, 39.30960555230418, 66.12562271856493, 52.96720435542446, 60.78642575971542, 57.020542467794115, 59.312544176655436, 59.2966389656067, 57.81525781077724, 45.29550721568447, 45.80328156871181, 46.220457015498994, 45.53459528953799, 44.61192438679357, 45.13420758708831, 43.453150333896765, 45.80638416351811, 45.07514845940375, 44.16558611777521, 44.481321227165964, 45.89993269212785, 42.65735241674608, 45.08850020747031, 44.72799516493275, 45.53420697489093, 43.835871681090325, 44.351871244369015, 43.352227749363074, 48.48002072303526, 45.72170019149781, 44.53513222355997, 45.34597635269166, 46.19065092455956, 46.89350828047722, 55.844333479481364, 60.140450616036695, 57.7820235683072, 53.89262876202984, 59.74180052357336, 61.241122599570986, 59.84196609066379, 61.541595766621256, 62.35837051945349, 62.53092342807401, 59.179160056575654, 58.30243579802975, 51.559265659701445, 47.90792734392228, 52.62326348212458, 59.71427725207422, 62.757334401530606, 67.14110082195651, 62.38995344408097, 66.424452412513, 62.76003691457934, 68.22444377406951, 66.56925847453456, 66.53085847054759, 11.744378420614428, 1.4913876114353057, 12.317332759980234, 0.17349239288558885, 0.4016405932845608, 0.9932795719754313, 45.78622318083241, 53.21439212368381, 57.43528996744464, 54.23537331242716, 28.39121945442692, 41.47941366318734, 62.1858960582364, 65.20697224524714, 72.76961572708623, 46.737735271453865, 1.5908760793747443, 0.09350132993272237, 0.09577831944390651, 0.14919093479552578, 0.1092857595593218, 0.11326580083057766, 0.3987155470155901, 0.13073891040778932, 0.15308397912210034, 0.08941285657666384, 0.19800950472633685, 0.1870572972562044, 0.18312588724638187, 0.0777836878513617, 0.1825091711455776], [0.043179120928529775, 0.041445919778198004, 0.03047852461496669, 0.010747675400888248, 0.07948756698639163, 0.019509788797867876, 0.05482796279172744, 0.010863832524797369, 0.009020082014162214, 0.036066818096104174, 0.06407555185198303, 0.031838920568266225, 0.09678502792432424, 0.07248396053910255, 3.625120948399267, 55.90200016575476, 47.787687086289935, 52.15661518035397, 26.09885100395449, 36.7205431384425, 52.879923774350075, 33.77284273024529, 35.91474317735241, 51.34661043843916, 17.70387468799468, 0.24943825878923942, 0.502537835629717, 0.9902540762578288, 4.560279452031659, 5.460218258442418, 2.4663981314628356, 4.686286574409855, 41.128345843284364, 63.681240850879306, 56.810350495000044, 53.79759365512479, 55.318280881451024, 58.127937393803755, 56.97606671241022, 52.93510760030439, 49.40763773456697, 44.55433614792363, 44.77592260606828, 44.01193118864491, 44.00085441527828, 43.99857551820817, 45.10564880986368, 42.225719113503736, 42.159756614315896, 42.237203813368275, 41.39051706560197, 41.51658988768055, 43.09020949948219, 41.09248753516905, 47.503919293803555, 53.626240991776996, 58.25237458752048, 51.90568154858005, 54.25328285463395, 54.73689932977, 53.163840616903, 44.48806378149217, 42.116418346281975, 40.53720935698479, 40.610718496384166, 40.68065827892673, 40.4348551073382, 41.21345735365345, 41.68444771920481, 39.98997203765377, 42.76724546186386, 40.57262051490046, 39.89860826923002, 41.75110447791315, 52.952872014814815, 54.25223165942777, 56.172600561572665, 49.521939523758434, 50.46885067416776, 50.49763302649222, 51.84635569972377, 51.96431706028601, 55.33625318158058, 52.844944077153365, 57.66958882731777, 52.75137201432259, 62.13340690059047, 32.266083840400945, 35.442878123252626, 57.70658462278305, 47.023342655551055, 52.071793925377634, 44.6670493771953, 48.0976955352291, 41.45582452897103, 42.163992774102, 39.697865286181056, 42.37399255075763, 38.32921305010396, 39.87351686723771, 39.61200068073888, 40.17275841005387, 40.198238126693234, 41.22059998973724, 42.187550529356926, 42.74507622564993, 41.31929859038323, 41.08680009841919, 42.50069687443395, 40.889183244397564, 41.52888651817076, 40.94897977767452, 39.06421030721357, 41.59803398193852, 41.28423260104272, 38.96726108366443, 41.383178311009566, 41.66829539883522, 42.30615123625725, 42.51847305605489, 42.595794739261756, 50.583246600243356, 55.47512469753143, 54.753930261058194, 53.429314474905695, 53.850875131545536, 51.720898689762244, 49.13503692996118, 51.00798829909294, 54.2130236471853, 56.13465555252568, 54.87726919112667, 48.34546773664413, 41.91835041969053, 45.934292654837336, 51.42947443069951, 62.24043269311229, 52.08725983096708, 47.44927283256285, 61.67422679162795, 59.78060453168808, 62.997030442760845, 58.959228838643725, 62.533500425277225, 62.027036143887436, 17.611779397533788, 2.1667033097436352, 3.945191992867378, 0.6793981502133032, 0.019508005728224115, 0.27580228604135976, 24.292215147326072, 47.15633061624343, 37.98669207480646, 31.578757109180575, 10.790210885386314, 22.119716290504705, 43.98207018452306, 54.71068612990841, 52.32686565768335, 49.387339468925234, 4.175568482568187, 0.09989288575466602, 0.008559264805949023, 0.0422107934531185, 0.034214494103986415, 0.017922669123377533, 0.04369702700886034, 0.04832320598765247, 0.021632536081597212, 0.04985876794483873, 0.021899274490292997, 0.022115481739503243, 0.049518487010631836, 0.06542344908079793, 0.009618265490468231, 0.06206124239871579, 0.016232983682364706, 0.012917153090388786, 0.09001839545465286, 0.02831949732236324, 0.008160545727268102, 0.04130065035555632, 0.047553371893422264, 0.03147643457557405, 0.0503010036904485, 0.04839201983545096, 0.025458268092704878, 0.006107799727619896, 0.035170828472943075, 4.404723153960321, 66.77981915012484, 52.38164940188008, 59.58156777966408, 30.703174260354814, 40.02461441101567, 50.996895836245635, 31.224012067241055, 41.14713791877993, 56.790770023099846, 20.43954941534227, 0.24689184381596505, 0.36771806677983654, 1.4354829273877607, 4.028398947369668, 6.200249877668196, 4.704641795927479, 5.501683594719057, 43.98513355562764, 65.9431383686681, 61.28078560675345, 56.137762069702156, 57.94771625149635, 59.46086860472157, 60.354513968190844, 54.17551402122744, 50.94574028445829, 45.87144059519614, 46.80338790339809, 44.99143331281601, 46.10935980273832, 45.3988185236531, 47.23602141103437, 43.99466883751654, 43.89863352621756, 43.93481739105717, 44.19611000245617, 42.05161686866514, 43.705229297761, 42.38139798564296, 50.39700461972145, 55.19776998027679, 60.382751111061346, 52.67128898251442, 55.59355674251434, 55.66563029443064, 55.80261907269878, 46.215071601252404, 43.99131521101921, 41.716034566202474, 42.08265458383868, 43.774698395882886, 42.49089094900316, 42.58810689372402, 43.085710540894546, 41.993138251766084, 42.48485834367814, 42.48710978415705, 42.0543154593437, 43.45370338809106, 55.86344718933106, 55.481722124161266, 56.4236165631202, 50.36205237911594, 52.802402050264426, 51.836722358580566, 54.20522597528274, 53.02066233850295, 57.13905688255065, 53.78815251012003, 59.96576001567226, 53.50503583108225, 64.67945268077236, 34.465203823581824, 36.69892695642287, 59.97353023098361, 50.7427340938199, 55.61456887952743, 46.76484669408491, 48.47875771983978, 44.82637997596495, 45.02374972066572, 41.41485929489136, 44.25389435983474, 40.47345515220396, 41.837278950598936, 42.003705117010306, 40.8764982992603, 40.64639637547155, 41.944340044452304, 44.305191116948286, 44.02924060821534, 41.47500491911366, 41.419103299417806, 43.076583185503566, 43.26896759771532, 43.746178842359974, 41.902566802117136, 43.116803169250495, 43.51280958421769, 44.314020372206166, 40.91735762934531, 43.30037401568505, 44.589323689860684, 44.95861484158424, 45.44076435027584, 44.69100329183763, 52.133975259719364, 58.05103148183515, 56.57172526082685, 53.91466856002808, 56.6845836177949, 55.5234012296123, 51.97331105509112, 52.323610090440326, 56.19890005357804, 58.08681918728737, 56.38915461878623, 51.8402877930672, 44.10492666306035, 48.779023001270915, 54.05821554122433, 64.25729582386633, 52.82246105132565, 48.57816234711678, 63.475418398457194, 62.8924600539669, 64.19034488739507, 62.802829973159305, 63.9385247999622, 66.41900816271382, 21.207749535960538, 0.8345030079926214, 3.69309758467059, 1.220911015425959, 0.03797053126618266, 0.2270594055974676, 25.132027941365397, 50.92502624757829, 38.17697801897603, 33.42374786253899, 13.352608046224042, 29.586553919699888, 50.237238637862674, 61.03118558083812, 58.013015870125066, 59.542618643852975, 6.9383516907691964, 0.186476418748498, 0.06534958288313882, 0.08075609367581145, 0.08227716124947033, 0.04102360231861953, 0.008217763876722706, 0.06396749515026327, 0.01206836884751195, 0.07717067195523171, 0.030521887106700774, 0.05216366986954405, 0.023372699055940877, 0.09749757396357675, 0.09114611518358992, 0.18136580024034749, 0.09340272675598822, 0.06469032591989925, 0.11443654405734233, 0.13354107617370545, 0.0888060230100828, 0.15102018421936422, 0.10324193104620903, 0.12502400174496636, 0.12353054398009855, 0.17779469670307252, 0.22091818432654106, 0.2527815584213503, 0.14507498952650255, 5.581755840009259, 74.86413786488195, 59.013322245690134, 66.53980931928082, 38.43228117112191, 46.588591068021714, 59.65638306833083, 49.285589264285186, 51.09147594821069, 63.700531067386756, 23.37930114038529, 0.40515522082005784, 0.7098582350919325, 2.57852717272697, 13.375379366259422, 14.65867200205403, 6.890779714430533, 7.344098331466799, 46.97337558192592, 67.8786240854571, 62.46137588254867, 59.03566406619165, 59.99195360368299, 62.26255878325432, 63.4736180305481, 58.495357574955115, 53.217141705174605, 48.72780861393098, 47.7381593181241, 48.06458680860458, 48.26214090470345, 49.34450326427337, 49.974149580924745, 45.85479013381466, 46.319987158621515, 45.90188995484383, 46.240774892991595, 44.64645693379064, 45.45799532244283, 44.211077767033736, 53.88176379665252, 57.55944475050896, 63.57401109510853, 53.84691746004167, 57.697994632105676, 58.74933104361258, 57.99937386666575, 48.115299132562455, 46.65633824563796, 44.89096180085213, 43.25779668746456, 45.1836569078507, 43.9071136905301, 44.177612104723536, 45.67408653997606, 44.21436863560831, 45.70314738058275, 44.96893067513743, 44.3286665024296, 45.55891398460635, 58.55140432234734, 59.18121145617578, 58.78286730858588, 51.267264812223374, 53.094963796677135, 52.866317072222316, 54.459493621703125, 53.02280787498721, 58.136621521365264, 56.43548565526163, 61.958563327789314, 55.9497550226027, 65.74992241397982, 37.25748815844136, 40.839796681557935, 61.876428896381015, 51.478759011914654, 56.76028143975043, 49.299764710087935, 50.27852550629647, 46.382176337703584, 46.58477460184405, 45.027213173527876, 47.44618984960741, 42.53178558041973, 43.79427102304275, 44.660738283588046, 43.51897555012857, 44.376154638105824, 43.869062777488466, 46.07114807251961, 47.538306713104255, 44.01539464150706, 44.80750945306594, 46.158805201130534, 45.41334306040118, 47.14231206524757, 44.29378486448719, 45.0601650053455, 46.050371277716856, 46.17638526424285, 42.38078217352591, 45.893770648587136, 47.05927548869964, 47.10267259228615, 47.90400889612014, 46.26050833732852, 54.57299524737943, 61.67230090787334, 57.574318378202385, 57.76670671278431, 59.617245658751465, 57.366389612997736, 52.645750430322465, 56.26834953984907, 60.145584998592255, 62.52390238546557, 59.81462717056275, 55.50322847981607, 47.30951878332323, 51.776094282827074, 57.69571965740573, 66.7365946308259, 59.004226269260535, 56.5138977573764, 65.33109957172026, 67.41496070738762, 69.10566699120307, 65.38365933202928, 66.76812264227098, 71.3150518171249, 24.64049416203653, 4.080083283685869, 11.767476277966654, 2.6532196421777052, 0.13369665330936834, 0.6162164276165347, 30.275720242531072, 60.79851058221633, 52.543862942726385, 41.345492178393954, 17.092753725667155, 34.47109130121047, 56.26412122480331, 70.72800636291504, 65.2864041636067, 67.99129024628671, 8.383128796854328, 0.2729399057645952, 0.12501133065069878, 0.20652935239336184, 0.15066039868660513, 0.17171652446831429, 0.13341739893920962, 0.18773036678471874, 0.11666473376774981, 0.12178454533099167, 0.1727359423473958, 0.11245469757986647, 0.1407398358588257, 0.21073047131780656, 0.15046103196519037], [0.0366648952777107, 0.013237281124137584, 0.11698662859177399, 0.01581165734903827, 0.02858261405039699, 0.0713414246697099, 0.04265159278387024, 0.0136991947956924, 0.04034910786656603, 0.05185736876521861, 0.017623892917688337, 0.02682463378615437, 0.15880699299516218, 0.2102808083497709, 7.7067038032316395, 54.043510575448316, 61.06697328629033, 48.21615503680322, 41.67838373491841, 29.740934487312074, 12.15108702259679, 33.84067227763514, 36.63939322194746, 51.39869559195734, 7.073825943854548, 0.30172280967235565, 1.0024881939734183, 10.938643178632184, 2.9404530938594573, 9.446024433259042, 2.8061344690861243, 7.033783447357917, 36.58630001929499, 64.24772131827571, 56.433159689749445, 62.870173146647794, 59.256011055361846, 61.077194982959384, 60.14529082082934, 62.02564370247626, 55.86108200011715, 52.699839914998705, 48.47907935419391, 50.38754386286582, 48.94923425489857, 50.523701098657426, 48.310460582856216, 45.13636489068308, 43.239730250450876, 41.0314005421054, 41.28549168186803, 42.92677217914213, 40.17802615319529, 42.322382004030295, 43.14914311132124, 50.279600235723684, 54.06837447997063, 55.555517596583215, 52.49807711570494, 54.224308306171054, 54.721068643754535, 51.57240167740853, 46.62080941661712, 43.65625850615963, 41.68992334796537, 41.248452740330855, 40.95693826675415, 40.91455705704228, 40.23863853946809, 40.509223245805316, 39.37086120728524, 38.79974842071533, 40.686973294904156, 45.31282840236541, 54.697789376781834, 54.704794729909594, 51.41550687051589, 48.318309245571015, 54.81195780538744, 48.41397977644398, 49.673303788708104, 50.45711102024202, 57.905656676138605, 53.01205273597471, 57.851563269092196, 49.929418871479655, 59.324115168663766, 30.827411413192753, 36.30976507740636, 61.658317658209036, 48.57249844458796, 50.12664348848405, 39.77555567218412, 42.56012078254454, 41.16606335486136, 42.67742318491782, 42.95028286595499, 46.2201589153659, 44.54889582049462, 42.89210627155919, 39.328432929131296, 40.66469030995523, 39.53400434986238, 38.96162463772682, 40.8889949706293, 40.707169578921416, 40.42750850800545, 39.43243849662043, 39.02583383744763, 41.123693912259995, 40.11061629941387, 40.10444248876264, 43.569609426683, 40.57592707295572, 42.39322393171249, 46.11338807690529, 46.33037751720798, 46.15436507809547, 42.77492154029108, 41.49576994680589, 45.97561482460269, 52.419994492684644, 52.51093856749996, 53.5174265984566, 52.95980676527947, 54.99725057232765, 52.63468542406636, 47.16736032116798, 44.89022831762991, 45.70129209949125, 50.04429332671627, 46.2927580648853, 43.37953136813256, 41.29771378732497, 49.35164982272733, 54.48509100944766, 64.95433238244826, 40.14127746705086, 35.04131763212143, 66.38282037550404, 57.609113724001, 59.92073905083441, 54.17541596197314, 64.16406892961072, 65.70236759801065, 40.151718816449566, 1.2574416423036208, 5.244514865259971, 4.862159279084975, 0.05033141738104244, 0.09167396508517767, 7.857676811756627, 51.98769046414284, 30.462811416195287, 54.211560603111025, 48.71742217771469, 23.193145452007172, 30.9723331851344, 48.280313245711795, 53.62416605795584, 56.179892247723, 13.445942805659387, 0.0650067585370233, 0.024708043934116443, 0.0935591619101263, 0.03056719929220215, 0.051271548990400574, 0.03465938817469343, 0.04649787510354673, 0.042556069280591705, 0.03900628597024949, 0.02686571525109391, 0.0652784209758524, 0.0041234941079070974, 0.06745483080345778, 0.031801278838106704, 0.06648455746471882, 0.014657655058638945, 0.08296981198532928, 0.06581095167465749, 0.039191503047702775, 0.061322683843994336, 0.08893387542376596, 0.021609547698209365, 0.09969564875768078, 0.11265942691675118, 0.09929764309837934, 0.09133190682698643, 0.08736465922406605, 0.2016749596523662, 10.777051333458195, 63.50214935118153, 66.1258109923332, 56.445248434620524, 42.97648822107623, 39.24370188866892, 18.749405991646555, 32.242469210778516, 44.3170758985704, 57.01010504076558, 7.965323319358211, 0.7855990192582532, 1.7924080716986812, 24.154583100349676, 8.091457428470735, 9.899642621317218, 5.547401270558757, 9.140066812115332, 42.82799905346286, 63.237926729263805, 60.68264768969629, 63.470762545062655, 61.67233620920489, 62.24580241787819, 63.4847261828761, 62.807862374090384, 58.769770514580514, 54.86527458313973, 51.668182034646314, 51.85049772262574, 51.99957916813513, 51.149574095203036, 50.92409664584745, 45.27785262753887, 45.333005074531805, 43.3321609035615, 43.865858201057684, 42.81272142164169, 41.71344972425892, 42.63457129078527, 44.92555318340179, 51.920751294782086, 57.40404436665197, 55.41824640766267, 53.10547574873894, 55.4827654746271, 56.94964954929968, 52.199314102049804, 48.26569457207957, 44.06664040780837, 44.024294499428045, 42.12321973616078, 43.23034009625835, 43.1082014114626, 42.56957761702999, 41.579665522421564, 41.74235759242889, 41.891603777485514, 41.3169647801307, 47.54113866436867, 57.571219705766254, 54.97295541148032, 53.614658232658144, 49.5663760554406, 55.86388649479036, 48.583469313959924, 52.090217298077, 51.99794746214344, 59.693731877111624, 54.96589122279998, 58.46969350691765, 52.120297954928496, 61.9188650192753, 31.20015032829777, 38.55364714899371, 63.79982979066911, 50.93853881282192, 51.67248487472535, 41.39623980368338, 45.000745019605084, 42.03673539623138, 44.41076171013617, 44.392267734773704, 47.794127618112874, 45.23716588174143, 44.72146049622567, 43.47047544294789, 42.411741441295995, 41.509066781690045, 42.27856520683535, 42.966925482596125, 41.993185320208156, 42.09740269568659, 40.919738508039906, 41.97518556348739, 42.24924548979729, 41.71142185887983, 43.370035309945386, 45.20896011783231, 41.41982109315934, 44.39635484449325, 47.697084257679606, 46.304070180462254, 48.28063095769575, 42.73789436586442, 41.60231721016669, 47.175397257651056, 52.53485325844058, 55.996905834444114, 55.81690434486636, 54.82145386357462, 56.510948135006814, 55.83681429586103, 49.24222746203023, 47.25797491688883, 49.22923264964935, 53.05460652997417, 48.79174324773973, 46.35376268817533, 43.791227263789025, 51.76735131971298, 56.64031574803015, 65.85088422221523, 44.46966786538401, 40.69757546147993, 69.00033566259569, 59.91904850929015, 61.32390422205771, 56.511909115699034, 64.70992949701125, 67.70445516032558, 46.360917091369636, 0.33886489728766106, 5.443299114704133, 7.77476575105421, 0.07540112376333245, 0.0937956226088347, 8.891532690294328, 57.28497297533097, 35.70650846727433, 47.76629840174029, 37.75646071280203, 26.97259229998435, 35.08169058830508, 54.63096395615609, 58.64289360661661, 64.08130299660468, 17.523477039029522, 0.3257167141043371, 0.09596270148552234, 0.1092254990831979, 0.015566607847088769, 0.03519591019158402, 0.043793259143468835, 0.047066101669183666, 0.03298458207638995, 0.006809512326013178, 0.0447878749260018, 0.006394373589090162, 0.049323632547091094, 0.13981947314835366, 0.07352705819592362, 0.08955120439490966, 0.16645461891687688, 0.21586041056340743, 0.20324046032563334, 0.2987633200903093, 0.21148814759667844, 0.1322738901381531, 0.14722784981131554, 0.18580209283578783, 0.30267775359172977, 0.2291499676122781, 0.19674621041743987, 0.28844157233834267, 0.31109025701880455, 15.352101941262523, 71.76621852382537, 76.07975098394579, 63.78221834859541, 54.19216056023875, 39.61187124252319, 17.87929484921117, 49.01163131959977, 49.150149822235115, 65.44771948168355, 10.10361469561054, 1.103768204489062, 1.3764146066481069, 21.97254700045432, 10.549680359901922, 19.875687130035896, 11.29064844500634, 10.851819553682882, 42.46663893422773, 67.92327634749874, 62.470032553518976, 66.56248846361714, 62.72572009794174, 65.45186934932586, 63.410197227231926, 65.11189791464037, 59.910968426735174, 56.291707254225216, 52.32238631094656, 55.64116647166591, 55.395779071315644, 54.24023705144083, 53.95483755296277, 49.31335964510518, 47.0336937904358, 44.882807193263886, 45.18255472183228, 46.872394161839644, 43.71502345608127, 46.4574505436805, 48.39310100001674, 54.27372232560189, 58.902766320013235, 58.852975753045854, 54.19565146969211, 59.65058972758632, 58.57949633752146, 54.160193243334376, 49.5713496208191, 46.375363180714274, 46.51583502369542, 44.294871361024924, 45.148222215714, 44.72251169143185, 44.39757077924667, 43.530330811777425, 43.993433290912265, 43.69343473065285, 42.654112538983746, 48.91236789764897, 59.63777142186319, 59.220038998511534, 53.88189323486821, 51.547537772886216, 57.5275598033782, 51.2455701828003, 53.40576064202094, 52.61062560542938, 60.96132032332882, 57.38720955387239, 60.42233959321053, 53.84539950278498, 63.03437532917146, 33.348505035523445, 41.56103034173289, 65.7700010268919, 53.9302089906508, 52.31352959909747, 42.173908525897616, 47.51578446357481, 45.8484084375443, 47.06618670494326, 47.40006669875115, 51.14664408468431, 48.8316612089834, 46.260116100311286, 45.6785580419725, 45.61512154917563, 42.608346323813166, 43.88613685484856, 44.740664420589326, 44.720589730047415, 44.05899570834252, 42.495209478562884, 42.701031930984996, 44.2964756104254, 44.12692331498669, 44.20268781723515, 48.70512162485431, 43.07373162238829, 46.95092001268941, 51.71547012944376, 49.666172919734834, 50.45421631105485, 46.19039989286854, 45.12588431758266, 52.5376263741524, 56.835430129881836, 59.00715235740908, 58.033929947883856, 57.56499882667296, 58.97429858484576, 59.00520293943344, 51.73263442131781, 50.39198006353071, 51.19747800211753, 54.45357868748327, 52.069150247881495, 48.162771578758, 46.24742331043367, 53.7777699962739, 59.01960588270619, 70.1193957174978, 47.86505191556869, 42.47386001771496, 71.2566634147398, 64.69825652337843, 64.26721157566195, 61.64517379576161, 68.14994227501654, 74.10816377209079, 49.14366614434027, 2.7213551344410067, 11.489238046830701, 9.255220736226729, 0.1397333648656645, 0.16259975641244845, 10.348865793597314, 67.7837811746905, 43.79435731518654, 70.72529992749615, 61.189190418489524, 33.631700161964666, 44.617560832731186, 64.62521806839975, 65.87311621635192, 73.78300712954614, 22.373454416951827, 0.4362103108677172, 0.21766424118991823, 0.3227923726362567, 0.2892713068473724, 0.19076884003175845, 0.08008799605792569, 0.1518288206669592, 0.12397700470061072, 0.1566334789799106, 0.14632270160701968, 0.22213623348263004, 0.22012254073014184, 0.2609018759141045, 0.16448964935637292], [0.06196096915030672, 0.04466571071515641, 0.08652025413128638, 0.051017322712728096, 0.0673340647030742, 0.03255753785431866, 0.07385166497119973, 0.024073956789629116, 0.08109711005442566, 0.009776932833295678, 0.016739000078110446, 0.05642688405069132, 0.181830509175216, 0.17077153969195583, 18.958050589407645, 55.16692838361187, 49.59816686568722, 44.15643130579303, 33.95199698786582, 13.901056397345759, 33.1059064403657, 33.749045710409845, 43.894452279613866, 46.01568183591289, 1.7466565654162438, 0.03977335448707304, 0.5340425273583782, 5.057913007274752, 3.9030174430339573, 5.2462642423568235, 3.406300251522372, 10.476142783318798, 39.04051919137278, 63.53126118260046, 59.68777771919005, 59.81609805937737, 57.89847873872327, 59.960402058016875, 49.345370108081454, 56.16233571883171, 57.349613635770744, 57.47666312802223, 57.23179740290488, 55.78510176750922, 53.718310786831765, 53.5566032317377, 49.488156149464274, 44.07213172604961, 41.81102652703562, 42.165797064381266, 42.60111347321541, 45.20426111836588, 47.89007663726807, 44.35877461587229, 42.24047899246216, 46.059479021256976, 51.7896499941426, 53.6348545166754, 52.66847664310087, 51.549016506441184, 54.96893890442387, 52.53322547481906, 52.46911825672273, 50.31804730815273, 44.789066468515706, 41.63435905210434, 41.63952089125111, 41.46822314108572, 42.37647148870653, 40.41534131573093, 39.8329124912139, 38.79285289395241, 40.53441270705193, 45.82907899733513, 56.661414177187034, 51.650958907219675, 49.43836950486707, 47.33953668225197, 51.56047767208469, 50.819271302992306, 55.13822447869086, 53.57456376475673, 50.85932654719199, 49.789237283891254, 55.515650626151796, 49.167161141672445, 59.256568031926314, 30.644613273682136, 35.89592364526565, 59.46573626610541, 49.91787141369235, 49.165039139409224, 41.916440225416615, 46.343682196832475, 45.1722231987984, 48.65650384656845, 45.13587459441155, 47.467319657725675, 45.09655675580425, 48.00291930475543, 43.40905504841959, 41.86761456151163, 37.916783671225275, 40.653009491582075, 40.643576191317656, 41.6771246540931, 40.20190946517452, 41.09984982398249, 39.179649583755, 41.726624965667725, 39.85585443435177, 41.265620954575084, 40.471058584028675, 43.674521061681936, 47.450469155465406, 51.03828468630391, 51.738851378040934, 49.42156214867869, 47.2701068078318, 49.03389861506801, 51.70083576633085, 52.64076509783345, 54.32517205515216, 53.447588797538515, 52.58499683872346, 54.66797151873189, 53.937179042447, 49.61259726555117, 43.44354444934476, 42.08925985520886, 39.95378817281416, 41.215881378419944, 42.278114134265536, 42.22696250484836, 45.74701516858993, 57.392151740289506, 56.77452748821628, 56.93678025276431, 56.39013521132931, 61.70195794874623, 56.679778714333814, 53.093183040618904, 52.681640117399155, 61.358020997816524, 60.45122784952964, 64.64987016493275, 6.731413814329333, 1.2071650691570774, 2.295763752152843, 0.1881700246444633, 0.05482367652979109, 2.304960974762517, 45.72102554382817, 32.94525792521815, 49.43346654215167, 69.30600597012427, 25.146315174718058, 29.288967617096443, 49.8318067673714, 53.46958152709469, 48.71095026693037, 18.411870348838068, 0.1140179765981532, 0.042491763860227606, 0.017378503464222435, 0.10766615009596271, 0.027367255778142044, 0.11073462334611725, 0.06951206033268283, 0.045437498333593535, 0.04064883976694077, 0.08271524862897012, 0.031207637305581765, 0.05776193398501604, 0.03032811474235308, 0.04388534291196735, 0.07002802821056497, 0.012651889400947238, 0.038800334723125544, 0.053424340327300375, 0.043335387543324506, 0.08379842034511029, 0.07817444631889944, 0.019937528244730447, 0.04103482933714986, 0.07123092414751168, 0.021520641279376803, 0.018895844020129695, 0.059503661693945054, 0.22070623844140963, 26.40608241481166, 64.42106262330087, 57.08666186178885, 51.4571036061933, 37.83567297843195, 16.763251096971576, 28.98908280557202, 36.86991091697447, 47.65668384490475, 51.628260151032485, 1.9682983044655094, 0.06729155448415587, 0.3195953038671325, 6.128710748687868, 7.022143813871569, 11.027244617862086, 7.505007684230805, 10.996950191836204, 42.73508202645087, 63.658189081376605, 62.978763964868364, 62.02271761432771, 62.227641843980365, 61.6748857498169, 51.823370610514, 60.23450120802849, 59.234045782396876, 59.74817437510337, 60.42602662117251, 57.95565512872512, 55.34832623697097, 55.96302440089565, 53.1133597127853, 46.35965016580398, 43.16775475778888, 45.551147691665165, 42.46752931225685, 46.5806443460526, 49.71491621386621, 46.51530942609234, 44.012425407286614, 47.592219691122736, 55.05456424528553, 53.66686890202185, 52.746461206866854, 52.9903071157394, 58.81780778208087, 55.79209927589663, 54.184155002717056, 51.36488476107198, 47.2792733869245, 42.90348506742909, 42.62673439518098, 42.55886170171922, 43.86195544273623, 42.3837867090779, 41.144588378167924, 41.625443504702666, 42.08881662737939, 47.34867580475346, 58.88127173146894, 51.586812465421616, 52.68315807465584, 49.39539993962934, 52.97975593997587, 51.78209550919072, 56.09229003229449, 54.68535154096542, 53.64418583531534, 51.92575623912197, 57.57016851056007, 51.7409812250445, 60.43795062649635, 31.017077622875092, 37.37833246108025, 61.091256680027136, 51.14798161291307, 51.57358623320057, 43.30885025762743, 50.944606719478486, 49.08435598496468, 51.3152785455027, 46.84138390325731, 49.83243826896914, 46.214459711505526, 48.87853353254257, 45.66715571188158, 42.670249169872655, 40.81011610646402, 41.656249800036036, 42.32064831641413, 43.99203692713092, 42.040932332315755, 42.176477678360484, 39.77599890001359, 42.594300316226104, 41.902460898122484, 43.09419070520709, 42.43488734768283, 46.02608396160988, 50.8191575542573, 54.155741353188795, 52.27714177100889, 49.92606132261215, 48.37489728004702, 51.98526251700617, 53.59917271521784, 53.76067630706295, 58.07424406851492, 55.549010384467344, 53.561349299646196, 56.44258514527352, 54.143758512312374, 52.81651866051459, 44.93321749471849, 44.288630870080766, 42.21146914266771, 41.78091449122275, 44.41315827831146, 46.03715681260633, 48.34272207752351, 60.00884725201515, 58.080335509392526, 61.2859356787897, 61.91884540742444, 61.876605403038766, 59.10184229573896, 54.14617861470869, 54.53094351676203, 64.96961001426943, 63.125339015837646, 67.62174021813178, 8.578536375876396, 0.3614959006588305, 10.600305411123461, 1.456961091006956, 0.12079694308340551, 2.3967503203499705, 50.677469776522734, 38.79955622457689, 46.77317388596074, 66.70456455599877, 32.63139966995486, 37.28943586349487, 54.86914204012964, 57.80605593035298, 56.65988837519, 23.680129281936154, 0.24922628226059101, 0.07666562083027056, 0.039639465300546545, 0.056628491579284596, 0.06501748376796324, 0.03223391933246486, 0.06514680707046101, 0.01785468073531745, 0.0371460636116324, 0.039054082195845344, 0.008826121000663168, 0.024196494468337586, 0.014214884966701992, 0.039941618038762006, 0.16578302027717715, 0.1425782017289631, 0.12833495714491414, 0.13130029963870204, 0.22251972177576637, 0.10969815234984122, 0.107250340553301, 0.16507795891694485, 0.14680875375145866, 0.13631760863767517, 0.14431647055091398, 0.08455212062765514, 0.22075873078598132, 0.24937475010031657, 33.553009571567664, 71.5727750716671, 65.23795112486809, 57.83144935484856, 48.686156965071156, 20.955960827489054, 44.87064000098936, 49.22856584672005, 55.88307472967333, 57.3477348204582, 2.4339353701760693, 0.38835187893240686, 1.2218354690459468, 8.500396878488603, 7.757523502072981, 13.329058135709456, 9.474179206355926, 15.748330950737001, 44.14414644241334, 64.94903326034546, 62.61209687879009, 65.7494281953381, 63.09082215832126, 64.21482047727032, 52.95395458898237, 62.14455035425002, 61.5801134417134, 61.935189923932484, 62.966330051422126, 60.09561008022678, 57.11740539919946, 59.424469009522475, 55.499266885942035, 49.88051868254139, 45.417226206871774, 46.15467494533908, 45.5072485246966, 50.47311036817489, 52.004435062408454, 48.38808036619618, 47.80043086697979, 50.131679811785304, 57.494184355581964, 57.12731330625473, 54.66321368371287, 52.07485337411204, 60.29752192958709, 56.64251227532664, 56.51647867694978, 55.951065094240256, 48.39212040747366, 45.943867160427956, 45.56643709059685, 44.792651514853205, 46.2172406719577, 45.46895834707445, 43.85010596244566, 43.724103743030184, 43.93725318293418, 49.310747346570416, 60.72727249514673, 54.356680454746375, 54.65089351900163, 49.958495401567035, 55.53634505118094, 55.38303529062579, 57.42828069194671, 58.27665013651694, 55.186618681876894, 54.316107457683934, 60.23256355716337, 53.18124417335757, 61.656854614134765, 33.76737886859525, 40.9995077502343, 61.87436965204055, 53.76825040386569, 52.48918118015413, 45.7397234824396, 52.241110878606, 50.770178917915594, 53.18682570611277, 50.27280276821506, 52.935280184591974, 49.65420969070927, 51.746605903871604, 47.870252978417184, 44.64873583086076, 41.25616412008963, 44.69450204603134, 44.46844016352008, 45.96300440449869, 45.42349023203696, 45.725540191896506, 42.4974452295611, 45.136757127700314, 44.367968651556204, 44.6574003465714, 45.14908121478173, 47.9637622833252, 52.10280418395997, 56.33409238630726, 55.86204298080937, 52.442956047673384, 50.83570211164413, 54.94281984144642, 55.6894116247854, 56.86508717075471, 59.83205033886818, 57.19241680637483, 54.80814526157995, 58.78458922909152, 58.90254274491341, 56.00255404749225, 49.7686016944147, 46.903467178344734, 44.97730101308515, 44.07966267678046, 47.49707868022304, 46.80806336864349, 50.912980648779104, 63.88632197533885, 62.15327370551325, 63.151709110506125, 60.46053955631872, 66.2547863683393, 60.79425873294954, 57.532443154242735, 57.01531002598425, 67.37849050952543, 64.44491455631872, 73.56134614636822, 9.926503012257239, 6.499471808633497, 8.094686519715095, 0.8125221068339964, 0.22519906832566186, 3.549233872082926, 57.139637393336145, 45.81453484873618, 60.43286331238286, 78.59090728144493, 35.89852025431972, 40.46042503849153, 64.982848013601, 66.61848422019713, 64.02861772045013, 29.149166499414754, 0.4112389088878709, 0.1504680186870598, 0.0780094616235264, 0.17135837836371315, 0.0984184499529581, 0.14509008145861088, 0.13311018235981464, 0.12281217567262151, 0.12968425248419085, 0.1395333393086349, 0.1015686724455126, 0.15183272771537304, 0.14080837008453187, 0.15913136994406102], [0.026826855441134785, 0.03777814743619773, 0.08507680658611559, 0.07897074875091353, 0.06645569893261118, 0.04749065610550104, 0.012399719111741552, 0.01732279163514895, 0.07805592485613401, 0.05937513895332814, 0.0720006892938287, 0.04189185955892167, 0.03853274021117437, 0.7973530756369714, 36.25660127209079, 57.02597495048278, 53.32293587346231, 48.05039959569132, 37.41786210767685, 26.5706709507973, 47.7003437472928, 39.370061043770086, 51.38116259728709, 36.382136729455766, 0.30697186026842366, 0.056148257872630516, 1.1044077959752854, 2.671886446975893, 5.538147418729721, 8.81243025102923, 4.526638753952519, 21.63255399273288, 49.470309365180235, 58.62748653657975, 54.60107157307287, 62.57322619038244, 59.003920324387096, 64.42086650479224, 58.5121492416628, 56.94051042679818, 56.23969270337013, 57.84303603633758, 56.992120973525516, 57.252432992381436, 56.83030359206661, 58.28032147499823, 50.77660376025785, 41.02310080682078, 42.08330177491711, 39.301654907964895, 45.89736746203515, 52.256345364355276, 52.38907052624611, 51.53196204093195, 52.193681578482355, 51.744001450077185, 51.09914810426774, 52.82684233880813, 53.19746317402009, 49.90835966602449, 53.50507897715415, 54.31122018444923, 52.11432026278589, 57.3827733532075, 51.933765719013834, 44.045953827519575, 40.13344057144658, 40.40387230534708, 40.87237196583902, 38.36358870229414, 40.24963686543126, 38.590223250850556, 38.64352041675199, 48.540570351385306, 52.4924014460656, 51.62585181574668, 51.778749727433734, 50.74344012045091, 54.22666565064461, 52.468859380291356, 50.303542383255504, 45.66089168671639, 51.90514810623662, 50.535683939533854, 54.70395142032255, 51.203636123288064, 54.124342779959406, 33.59643413174537, 40.317309518014234, 56.53252509332473, 49.18606696590301, 50.36491570934173, 45.691701904419936, 52.097591354000954, 49.101284934628396, 47.33997991008144, 46.978737461951475, 49.05826830094861, 46.68408116986675, 48.34338888045281, 47.36456532632151, 46.566551270023474, 41.950529544584214, 39.038730590574204, 39.36062774350567, 41.536362555719194, 40.436828059534875, 40.917953829611506, 39.171243944475734, 39.76828359788464, 42.09977572964084, 40.69830109996181, 45.48145501844345, 52.22988113280266, 51.02172051706622, 56.16922732322447, 53.456269002729854, 51.15619897842408, 51.63654811920659, 52.98174458165323, 54.03185721366636, 55.69046674236175, 52.935994055963334, 50.49005108494913, 49.98537148198774, 55.20207674272599, 53.79551087656329, 49.93720085390153, 41.034801237044796, 42.150880290615945, 41.90539483101138, 44.714404152285674, 43.43800606266145, 43.19215974500103, 43.58725224771808, 53.91624143046718, 57.330448935108805, 58.36726473223779, 55.10021278935095, 55.275593726865715, 46.34141114450271, 45.45503001059256, 47.952493313820135, 59.514306975949204, 58.65992061553463, 70.92469753757601, 24.14149218989957, 1.2444632548478343, 10.654959717104513, 2.3239366662117744, 0.3051578559942784, 0.05946755213963409, 33.56068564999488, 47.49675704586891, 58.73323363642539, 66.87832555463238, 19.872433523977957, 19.642080568498184, 37.853154982289965, 49.93620457187776, 50.44044879175002, 27.520194399741392, 0.43858594952091096, 0.027943394116816983, 0.01370894134930906, 0.027352717344559012, 0.07902019972642584, 0.06220220640722302, 0.017564314259817044, 0.02232078755755098, 0.049539857033279636, 0.030420794144212723, 0.07076023972683376, 0.049711847602720224, 0.03902815395004807, 0.022374185801093138, 0.0469110454733093, 0.08349782276538112, 0.020384454363656622, 0.04793024501733242, 0.07986281983434193, 0.10351865732621762, 0.07345370527717375, 0.04099319628890484, 0.044730644327618425, 0.060124426569429144, 0.029165947869900736, 0.028169763522342812, 0.062393812657964814, 1.4032687463106648, 43.85157685126028, 64.36614944088844, 61.3297014851724, 51.23960425776821, 43.947102254436864, 24.98146580111596, 38.30970710323703, 42.17520683042465, 57.104567481625466, 40.64599629371397, 0.1586498223966168, 0.10497476830477677, 1.5574913159493478, 7.1764807451155885, 8.214202119458108, 12.63268739946427, 9.676195979118347, 20.478996692165254, 51.47559758155577, 58.962990391638975, 56.15185514573128, 61.091562624900575, 59.026905413596864, 64.96484041213989, 59.21053117321384, 57.10085691944246, 57.392116438957956, 59.2544734862543, 57.48237017662295, 59.59855948725055, 60.386245942884884, 59.61852042905746, 52.020124543097715, 42.89035689446234, 44.43033433729603, 41.83103061491444, 46.02981805801392, 53.889494788262155, 55.07902806805026, 53.82160640531971, 53.12698602676392, 52.285300300967315, 52.031946566797075, 54.98971569922663, 55.72377158749489, 50.45881725126698, 54.64412743045438, 57.51161929099791, 53.97515543045537, 56.73597451179259, 54.201072185270256, 45.42445513509935, 41.57398593041205, 41.227899520627915, 41.93584419065907, 41.38400593111592, 41.305327107829434, 40.477495193481445, 42.78113065227386, 50.13103262070687, 53.32242204296974, 54.489142817835656, 53.14899444580079, 51.73145771026612, 55.465503123498735, 53.75629894195065, 52.5182027970591, 48.272845052903705, 53.05126467058736, 52.5363516038464, 55.76672938562209, 51.95731955189859, 55.95888237799368, 34.6083781796117, 42.2714735615638, 58.37654113769532, 51.87064693820093, 52.656301606086, 47.350880176790305, 53.83943750012306, 51.001049626258116, 49.82030245565599, 50.151452479823945, 52.025404053349654, 50.12437635852445, 49.827331343004786, 49.09586814142043, 48.153773661582704, 43.676501858618956, 40.96850925876249, 39.366017080122425, 44.119710076239805, 42.97026341961276, 41.450537173978745, 40.784726604338616, 42.280808802573915, 43.70575097299392, 42.65185717613467, 47.9581376044981, 54.26802704411169, 53.585970017217825, 57.93287008039413, 55.34861256999355, 52.415675963124926, 53.40415247025029, 55.267231233658336, 55.120993506523874, 57.00934017858198, 55.53425050550892, 49.56673299112628, 51.469039378627656, 56.97902417952015, 55.33074225148847, 51.23394427760955, 43.62372636795045, 44.43324865833406, 43.790583995080766, 45.428867801543205, 46.05666275947325, 44.136380149472146, 46.07759252671273, 55.826486695197325, 60.433741923301454, 58.267569849568034, 56.908566644114835, 57.525951631607555, 48.53964859439481, 47.77436671718475, 49.7058633835085, 59.580791150369954, 60.76325239673738, 73.57689442173128, 29.417733146298318, 1.0352733250587218, 11.987493788042377, 5.1018871895728575, 0.1491848367356485, 0.074802165580613, 35.887439558582926, 50.08386611938477, 53.77333379560902, 66.83722695996686, 28.557751524832945, 28.405836166874057, 45.73086284822034, 56.69167918543662, 58.87965179258778, 36.95063329512073, 0.8094677449234071, 0.06396849489500446, 0.07197186906611727, 0.07136647574483387, 0.053992283440405325, 0.01965603881305264, 0.01794320027974825, 0.044567685934805104, 0.027180893399241953, 0.030617881754052736, 0.10326005668649751, 0.0443049714029316, 0.08978054047592225, 0.003685636315382116, 0.15656473024958567, 0.10369514866221337, 0.09286475683292074, 0.13527387512787697, 0.19963146607962348, 0.1870087426035635, 0.10554730411498778, 0.1524552047973679, 0.16967655490002326, 0.1781723933715013, 0.11477782090585079, 0.1657024584710598, 0.13078102992186624, 1.6333932237279032, 54.89141325796805, 72.77418921070715, 69.50997706382506, 60.7889360766257, 50.894388614162324, 38.51074034167875, 65.28360359130367, 50.44359453262822, 64.41995651491227, 43.84698767815867, 0.5814523994922638, 0.1606357368009706, 3.0295357588798772, 8.52550495055414, 12.997680614071509, 17.465298483448645, 11.651178982950027, 26.774975445962724, 51.584725764489946, 59.90640671022477, 57.55429467847271, 64.68240230314194, 61.596952176863155, 65.76079522409748, 59.58974592147335, 57.81855652409216, 56.88222792840774, 60.35201934076125, 59.47845651257423, 64.59351747266709, 61.1026393982672, 62.76248447356686, 55.22135519212293, 44.206982812573834, 46.71937857904742, 44.2134625680985, 48.30505555675876, 57.58026076901344, 57.249122511956, 57.36658180913618, 56.78694963455201, 56.24967905782885, 56.13989976144607, 56.982162075658, 57.51558088487195, 51.32409211127989, 55.9582704882468, 57.15267535178893, 53.19190517548592, 59.76968073075818, 58.10118290685839, 46.492422396136874, 43.14161216059039, 43.65106921042166, 43.70901438497728, 42.31334094078311, 43.484564596606845, 43.09774045021304, 43.73361549069805, 53.047687468990205, 55.40120763163413, 55.10629246311804, 55.84869515511298, 54.66032289689588, 56.675428805812714, 55.74204198775753, 53.81767226803688, 50.75814508622693, 55.19032139931956, 54.109084759989095, 56.71100078090545, 54.51070408667288, 57.136997638210175, 36.57674120318505, 44.714102129782404, 60.04583912511026, 54.88780467740951, 54.68577907931421, 50.238254531737304, 56.3881387249116, 52.70952816932432, 52.35147460814446, 51.99448008691111, 55.35479422538511, 52.32723828284971, 53.29531062033869, 50.96975695702338, 50.49033741797171, 45.31696258052703, 43.76506505473968, 42.694512951758604, 47.1598058362161, 44.4888678673775, 44.05541066200503, 42.2632993421247, 44.53789749453145, 46.050245761871345, 44.768991777973795, 50.78168715200117, 55.3065529946358, 54.3133500314528, 61.15120226337064, 59.25874494737195, 56.772036783156864, 55.27936704697148, 56.9339757580911, 59.49229463454216, 60.35715372331681, 57.71741820919899, 49.957530498504646, 50.201835324687345, 59.707617067521625, 59.31341494283369, 55.48628776304184, 46.169395600595784, 46.61927184750957, 46.72102205214962, 50.59612766388924, 48.4704658292955, 47.60060964092132, 49.734253498815725, 59.487634858777454, 63.78537193421395, 62.73325889341293, 60.11075827383227, 62.02405514255647, 52.38763886113321, 49.70931506926014, 51.18447926736648, 64.07797682669856, 63.237710998904326, 79.21250097213253, 29.11386516786391, 3.5853741005543744, 19.917321128229943, 4.729204658539065, 0.49069491305178214, 0.3575000779763345, 41.6186656490449, 61.977975137772106, 66.7628352872787, 69.67916457883774, 28.16544390493824, 29.979002744920795, 53.44625519167993, 64.38493759401383, 66.70739650726318, 43.39074542445522, 1.2466874838836732, 0.20735415329615917, 0.15688055765724954, 0.1855646668662948, 0.11507242001713285, 0.2128063244444709, 0.20801349452907042, 0.18742786930693736, 0.10982556809340754, 0.1886747999777717, 0.2056622021501103, 0.15730719202228133, 0.20324180864038008, 0.11601113053339145], [0.02932099065923643, 0.016236854341602134, 0.02480297371925366, 0.05843284314558391, 0.04179451276638335, 0.028132075826907833, 0.06073002290401248, 0.02799989310123267, 0.026876654986652638, 0.038642233327752164, 0.0919588425407006, 0.12542134856865292, 0.05104027087649992, 1.5851664567185988, 38.39317906287409, 52.46115584527293, 50.89045055450932, 38.42402458190918, 23.765072130387832, 17.274973315577355, 36.85883806597802, 35.76072739016625, 58.72662052031487, 22.99681905777224, 0.08388662770871194, 0.1282066833828726, 0.4442889531773906, 6.222781933123066, 6.28619194992127, 14.881640115091878, 17.738334671143566, 29.823357212928038, 54.338888583644746, 56.27872028658467, 60.90405764118318, 62.99180192332115, 60.27404262173561, 60.97968486047561, 59.778004000263834, 61.855228485599646, 58.212033010298214, 58.73315911139212, 54.03282211672876, 52.52595732288977, 57.86809998173868, 56.013128757476814, 44.652524840447214, 40.087607675983065, 40.33865897886215, 43.918449340328095, 52.190261271692094, 52.64992383218581, 54.92826392573696, 52.439963279231904, 55.08102455446797, 52.52132108134609, 53.63112042027136, 55.2425556029043, 53.793969385085575, 49.347543101156916, 49.35724704496322, 48.85640352003036, 54.582761949108495, 57.41938083402572, 55.445804980493364, 46.9680646927126, 39.99604778905069, 39.658166977667044, 41.30859444218297, 41.019876618539136, 38.841137270773615, 39.15206747670328, 42.35356092453003, 45.78391682717108, 51.36630465907436, 49.85565477801908, 51.86022520065308, 48.38416191839403, 50.12332516331827, 49.0388721804465, 51.17620306630289, 50.383645026914536, 53.13460326963856, 51.39088223057409, 56.22157135317403, 48.760501569317235, 56.8621846168272, 35.01481417686709, 38.41485800281648, 59.570640056364006, 49.152683673366425, 52.516355360707934, 47.795320018645256, 53.162781576956476, 49.24503587907361, 51.230963276278594, 50.1509778730331, 51.889960688929406, 47.98654733165618, 48.85292830005769, 48.97298812866212, 48.958090966747655, 45.549210040800034, 41.355725642173525, 39.211926767902995, 40.72869554642708, 39.94964614991219, 41.341942433388006, 39.16851789720597, 41.07301688963368, 39.991854775336485, 44.976367488984145, 51.73427789442001, 53.308497628858014, 54.60428007187382, 52.47675511144823, 52.96661207752844, 53.41533122524139, 53.8568449789478, 55.130811199065185, 56.7722721253672, 50.8375064019234, 50.8336664015247, 52.99745759656353, 52.834157559179495, 53.87741388813142, 52.58824063885597, 45.576623485934356, 42.973503297375096, 39.424868322187855, 44.575556170555856, 42.54019514206917, 43.183448160848315, 41.156763415182795, 40.93321184958182, 41.73839599855485, 45.69660486713533, 44.834511049332164, 46.089147829240375, 43.52402364054034, 46.898117065429695, 50.4318234997411, 54.32929054383309, 53.91360952008156, 59.83277597735005, 64.05441122670328, 51.72048291852398, 0.6604194556993823, 16.57643448921942, 3.1604980605263866, 0.12281939988174748, 0.030455760312296694, 14.159826924723966, 57.575047939054436, 41.43744822471373, 51.141964697068744, 22.870077471579275, 25.1366328039477, 41.25568166855843, 53.09914112091065, 49.19260947935043, 41.36850080182476, 2.628442520095456, 0.20914447013168566, 0.10322500816396168, 0.09521716003937107, 0.03594111455904861, 0.05682969691171762, 0.04619695193644974, 0.09491374325608054, 0.02725460829453603, 0.08590059625285287, 0.054918905089218775, 0.04151430844719853, 0.030255416828778484, 0.04257272020162594, 0.06566379384528245, 0.03175587855249403, 0.026873452739129146, 0.013347382323005268, 0.03723573803360905, 0.05483568878844381, 0.048702473136326, 0.019304368066631498, 0.042589574135960116, 0.031001358555870193, 0.049173896831850854, 0.12156068677863768, 0.028212827239786426, 2.616029444240755, 47.56910516369728, 59.62511393331713, 58.57666046388688, 44.005682852960405, 32.81596287604302, 23.932272964908233, 38.996510198039395, 38.05303112153084, 64.96346366020941, 24.814184558007028, 0.08623789710503432, 0.14977561309933662, 1.6501538791964132, 6.884491174451767, 6.654287269038539, 7.098764863706405, 9.732167220884754, 31.29248292215409, 54.963424051961596, 59.506375943460775, 62.530523346316436, 63.797319473758826, 61.201843984665416, 62.882132453303186, 61.55122910776446, 61.74222500093522, 58.38500953489735, 60.40026449388074, 57.20997725763629, 54.41692806059315, 60.67697986479729, 58.27859955449259, 46.441792441952614, 43.123922271113244, 42.4493295146573, 44.62774330569852, 53.32959605801491, 54.521235650585545, 57.47434892962056, 54.31144375954905, 57.66150874476279, 54.87086396063528, 56.63706802552747, 56.52747700291296, 54.55257146589218, 50.16901685345558, 51.43248288862167, 49.53202393747146, 52.9669141000317, 57.692126766327895, 56.67563669143185, 48.20157558687272, 42.14379256771457, 43.24576677814607, 42.6461854288655, 43.142267196409165, 43.28393536229288, 40.456722321048865, 44.15640777157199, 48.62200660090293, 53.099086207728234, 50.88445325051585, 55.02245180068478, 50.942484717215265, 51.25956519957512, 50.90080953413441, 53.88949871063233, 50.937350334659705, 54.969770446900405, 52.77380404933807, 56.48766886803412, 51.37174498650336, 59.04077883689635, 36.20359436158211, 40.661124875468595, 61.280220785448634, 51.789073405727265, 54.00129018291351, 50.43315710559968, 54.11750608874906, 50.80163632669757, 52.48552553115353, 51.88273176070183, 52.29052882040701, 49.77537562770229, 51.43549526891401, 49.81705865552349, 51.453381276899776, 48.93699253759077, 43.1355756328952, 41.18745203941099, 42.93402071922056, 40.5683215971916, 43.07227642305436, 41.08119110907278, 43.56023888434134, 41.872137054320305, 46.55811032941265, 54.23104693812709, 55.04052216006864, 56.52878707455051, 54.58437012087915, 54.440579952732215, 56.04983037517917, 55.70487360800467, 56.20924726609261, 59.143195844465694, 51.37803254588958, 52.789466073436124, 54.434786611987704, 56.034168351081114, 56.144626217503706, 54.69886018383888, 48.886366505776685, 44.34743504370413, 41.711668968200684, 46.04338161406979, 45.84212872289842, 45.27107477188111, 43.914385764829575, 43.972166199837964, 43.54532995531636, 47.29144842393937, 47.13178834607525, 49.036675653150006, 45.77095731612175, 48.692452369197724, 53.233470532201956, 56.9976907391702, 56.699351341493674, 62.323720301351244, 67.19100906002906, 54.1535448258923, 1.0747006223086388, 4.419110407752376, 1.3824038207530978, 0.3166946498376708, 0.12515332504746415, 15.24693044923967, 61.26559818944624, 47.57434545024749, 57.33062936413673, 21.23628870133431, 27.28504438554087, 46.045609520327666, 58.77387331378076, 56.98411149363364, 51.37459262724846, 3.7394322983680235, 0.24437084764001832, 0.04974934760661376, 0.00047173491874409303, 0.07837072570597933, 0.03072407877733631, 0.028204593709820223, 0.03792427487731461, 0.008416922796787995, 0.035247919900763425, 0.08615421732106517, 0.08737847178934083, 0.05095408598501837, 0.039619857280124585, 0.22096621803939345, 0.1515617011295211, 0.10606010804974264, 0.14174734873156394, 0.1976834577057631, 0.11315934525261964, 0.15127513828056474, 0.10250975017345722, 0.13380905372961877, 0.1488168847056166, 0.13921556603764335, 0.3285125060187232, 0.14779424925725307, 3.9434737495837675, 56.847232541730335, 67.76394967109927, 65.19913142727268, 51.154994810781176, 35.04954284237277, 27.102632599492228, 51.96540747919391, 47.61578529111801, 72.47788552315005, 27.759221676857244, 0.2734949517874949, 0.23979437627619316, 1.8493828273588613, 16.327454197791315, 15.131023430055189, 25.716361076601093, 26.513778932632942, 34.94352509898525, 56.54092681023383, 60.44406952396516, 63.92869534031038, 67.70552204501244, 63.0659229524674, 66.06193127170687, 63.60662560309134, 65.27986949489963, 60.21863522068147, 61.059132468315866, 57.42497805626162, 56.0182592176622, 62.083533963849476, 60.349607083105276, 48.42847293423068, 45.458462084493334, 44.360551449560354, 48.51610652862057, 56.89363025849866, 57.091247112520286, 58.87410556116412, 56.96055766074889, 60.63039387426069, 57.7495071195787, 59.276250485450994, 58.69190754428987, 55.65987617738786, 50.72466765680621, 50.47382816191643, 50.1304050414793, 54.41803416898174, 61.62942940188993, 60.776537464511016, 50.412631342487956, 44.7624021960843, 43.76556319575156, 44.08759370926888, 44.94035620843211, 45.139212531428186, 43.575418456908196, 45.9757403404482, 50.86460605744393, 55.184657496790734, 52.44842383169359, 55.72722327324652, 51.15539489253875, 53.592657658361624, 53.98910730115829, 56.247764941184755, 52.356448173522956, 57.43551746491463, 53.6374472033593, 58.59591930143295, 53.47102495931811, 60.831376121890166, 38.164006740816184, 42.62509092207878, 63.83992033620035, 53.9409052941107, 57.243231111957186, 53.221593595320186, 56.56989351395638, 52.64953159516858, 55.37527684242495, 55.374170734036355, 56.092874465450166, 51.88943901369649, 53.91664151222476, 53.19462730038551, 52.934687906695956, 51.263962176538286, 45.91592027295021, 43.31891113711942, 44.71601232405632, 42.82979549900178, 45.15241915179838, 43.53538282455937, 46.03980833484281, 43.25095999625422, 47.83458294407014, 56.13796995532129, 56.57065445376981, 59.217720877739694, 55.12652404846684, 56.73807690220495, 57.811488413041644, 57.32604019103512, 59.39861274534657, 60.79970298274871, 52.56695393593081, 52.27416861441828, 56.56819905004194, 56.806086878622736, 58.38041643942557, 56.855387149318574, 51.26209512833626, 47.01003013118621, 43.3697215203316, 49.136209718642704, 47.746043282170454, 48.04659489662417, 46.19799752389231, 47.627356283126346, 45.753373330639256, 50.13824585945376, 48.71898720341344, 50.78286386305287, 49.34283233457997, 52.126487455060406, 56.220159299912, 61.17078273527084, 58.707212632702245, 65.10286077376335, 69.70735857563635, 55.4162303093941, 2.689894538733267, 29.26116389612998, 8.104626296028014, 0.4247800032457998, 0.23932079604316145, 17.733447397908858, 74.20113178991502, 51.423241784495694, 61.34754826945644, 31.576680214174335, 34.20494279553814, 53.61797655782392, 68.08509765132781, 64.79875156956335, 60.96861593184933, 5.38585159086412, 0.29127992809780184, 0.21819969068371484, 0.14499012230625077, 0.19088744576419556, 0.19315891178144565, 0.28846100032810246, 0.16586889873348898, 0.14769026048241124, 0.15345303431874321, 0.16279193722913343, 0.11392379374874216, 0.0987017109629608, 0.16074907184848863], [0.06296389698681813, 0.06452020843543353, 0.006177831655217996, 0.008532602073354347, 0.14491795682378356, 0.15438231429265392, 0.03415867693782334, 0.04527235275975639, 0.025985602800163533, 0.030783479319765206, 0.044752937486214985, 0.080688432790339, 0.021628249819660862, 2.5912765918239473, 46.13675363602177, 57.52307261190107, 49.28882521967734, 28.651743281272154, 18.66148018067883, 28.007535165356053, 38.9229186888664, 37.042404990042414, 61.57241382906514, 16.316704942334084, 0.19511643496732559, 0.03104731808566759, 1.0211583082714388, 5.263495214523808, 7.579116455970272, 9.783462016813218, 22.27377914613293, 42.6728928473688, 55.69026670148296, 60.667840742295795, 60.53808481462541, 59.00161789309595, 55.74778041531963, 54.080573051206535, 53.98762464523316, 53.88037135524135, 57.20791016855548, 57.00173470281786, 57.42833560512912, 55.406953903936575, 56.10225677490235, 48.28317265356741, 39.957663474544404, 42.4286860804404, 43.78805798868979, 50.314862343572806, 53.05762675500686, 54.42956985965852, 52.088444386759114, 53.45008734733828, 53.302876872401086, 53.946933977065555, 50.75335587224653, 50.97137689590455, 52.02104237771804, 53.28605382673202, 53.87037715604229, 53.3997868722485, 50.3839195928266, 48.62134372034381, 55.82108951384022, 47.927586263225926, 38.96041654771374, 40.10255582870976, 40.38076954503214, 39.35315562832741, 40.23685386103969, 39.03502787313154, 40.91617699592344, 43.93628827987179, 51.592123354634936, 50.91900933173395, 55.2704240429786, 51.04142258244177, 51.9875963272587, 48.10261418742519, 48.94092275250343, 47.749859748348115, 50.585851054037775, 51.33206628984021, 54.38273675980107, 51.6043415377217, 58.65661797984954, 34.97096600071077, 36.37246808698101, 59.24228275975874, 49.135962609321844, 53.959858186783336, 48.74093286452755, 52.55066041023501, 50.95614633252544, 54.82135972669048, 52.47066367057062, 52.229226096983886, 51.45046303349157, 54.02639335201633, 48.77398275559949, 49.836819556451616, 47.84741693927396, 45.98115321128599, 40.26550285277828, 39.8764939461985, 39.12358322451192, 40.09225176226708, 40.87681208887408, 39.79976454088765, 39.94741039891397, 49.380742042295395, 56.772468243875814, 54.28359100895544, 49.669612838375954, 51.35168206307196, 52.52939331916071, 51.90580314205539, 53.94591416082075, 50.59721808279715, 51.9605202059592, 55.14428846297726, 54.659777687441924, 56.15752297063028, 54.10830813069498, 52.14785260538901, 45.976940585720925, 41.550443864637806, 45.60487631828555, 46.78307002590549, 52.54494159452377, 48.22165419978481, 44.975724220275886, 42.381303848758826, 43.808038542347575, 40.76076484495594, 43.75916188763034, 42.83242740938741, 49.72506730787216, 50.74011002817462, 56.492403168832105, 55.93734464337749, 59.412274360656745, 57.197931658837106, 64.1401542386701, 59.647094895762784, 60.121850736679576, 1.7508182001690713, 5.777037903185814, 7.751417352307228, 0.2853217558755029, 0.06490805576885901, 3.2323279351957384, 55.52751579592305, 33.51549602323963, 36.04258106600854, 25.047026257361136, 35.86153622596495, 38.90835885078677, 50.942418036922334, 51.72150665713895, 44.91681414265787, 4.335873790325658, 0.1470473288528381, 0.02497399710268984, 0.03310197738990669, 0.07000239490861855, 0.042463705890000834, 0.0532199404082231, 0.032649307526768215, 0.07903552914579069, 0.023835559803692084, 0.017448680948526148, 0.06871341367162044, 0.06998737958530266, 0.03288657261779712, 0.0851844572612355, 0.026889458231087175, 0.029225742947610638, 0.025404632361906192, 0.02726515157959394, 0.08756390337141291, 0.06929039279179228, 0.028672150576547272, 0.04721774111291574, 0.01841634384266311, 0.042239606019950686, 0.06598026476680272, 0.10893240916512667, 5.243358746651681, 55.799116396134906, 63.452833391005, 57.41719607383975, 35.37234998518421, 25.454070221993234, 27.4115643578191, 39.93561975417599, 40.55555820465088, 68.80215398726925, 16.73218200283666, 0.18279521305474544, 0.05445428042402191, 3.8099494047703284, 8.689127602884847, 9.01340759569599, 4.879015664900503, 16.792537473863174, 44.49970929853378, 57.35727794708745, 60.395851827436886, 60.0896990683771, 60.25376004557456, 58.98109997472456, 56.58563006308771, 58.115652530424065, 57.76847177936185, 59.266373957357104, 59.27037085256269, 58.59476220223212, 57.27606135029947, 58.31495992598995, 50.19992120804326, 41.2922695375258, 45.1589616652458, 45.622087678601666, 51.99519395828248, 54.88059143866263, 56.38393002171671, 55.2078426268793, 55.767172613451564, 55.21203171822333, 54.33039272985151, 52.224523175147276, 52.0303423173966, 53.262119523940555, 53.37317751299951, 55.56488421655471, 54.30805483172017, 50.45571465646067, 53.30428108092278, 57.04496314448696, 48.544884958574855, 40.803601049607806, 42.3724236026887, 43.51687708208638, 42.03370732645835, 42.76891246918709, 41.33615693738384, 43.00075592533235, 45.41632406173214, 52.27774189364526, 52.823963319101644, 55.27802559637255, 52.68808457159227, 52.94537244304534, 51.56803215703657, 51.432828057196836, 48.42671571239349, 52.35651485381588, 52.390341374181936, 55.63620467339793, 52.90913758739349, 60.2863980877784, 36.92125082015991, 37.41554790927518, 61.48719249233123, 51.18156494632844, 55.14305291637298, 50.639250201563684, 55.19995866283294, 53.727344005338615, 56.10924643854941, 55.17240401237242, 53.76372006631667, 52.955229359288374, 54.69998198170816, 51.079779440356845, 50.53344034379529, 50.071561644154215, 48.02661042059622, 42.83413756278254, 42.3954753721914, 40.30171809657928, 42.5909427673586, 41.10590204115837, 43.18981809000815, 42.377471693100475, 51.275760666016616, 58.449308949132124, 55.671133379782404, 50.59070302594093, 52.127381755459695, 53.592018312023534, 55.187399233541186, 55.46158467569659, 51.7577140561996, 51.73884745567076, 56.606022465613584, 56.54910102967293, 57.86962186136554, 55.309812484248994, 54.685963430712306, 48.21762200324766, 43.66981421747516, 47.50837118394914, 49.406413955073205, 54.622534782655784, 51.6991138458252, 45.911950834335826, 44.40497229176183, 45.665143535983184, 43.820896071772424, 45.732635759538226, 45.46453391352008, 51.42456754561394, 55.105103984955825, 59.32836701793056, 59.512863543725786, 61.81412204619377, 58.29303387672671, 65.03221888695994, 64.22451657633628, 61.18365203180621, 2.9141261452628724, 0.8936900417170218, 9.48412339533529, 0.6218067857046282, 0.033597678411751986, 3.7975441736559716, 58.24344727300829, 39.529929007253344, 41.30777858918713, 25.686896231866655, 34.390608187644716, 42.72371892006167, 58.62040665841872, 57.853885312234205, 55.02670757232174, 6.08763421735456, 0.17771845563284813, 0.06512655936662229, 0.030939416516752496, 0.04507278302504171, 0.03932715423645512, 0.04038513698164494, 0.021521269471474716, 0.04074545877595102, 0.03989458790109043, 0.06409528627691251, 0.019216465222979748, 0.032047692934171326, 0.07292148867441763, 0.1723200945003379, 0.09334580642321418, 0.15367264108311746, 0.21780670290031742, 0.20247435707959438, 0.2581476978957653, 0.2175192513893689, 0.19229222119094866, 0.18559221538805193, 0.11283267770082721, 0.14488855436924966, 0.17207272470958773, 0.17552300085944517, 7.845248291569372, 65.09369419467065, 69.40341411098358, 66.30489072492047, 42.103541205006266, 30.448469269660215, 39.369978673996464, 52.11987826132005, 47.56729302867767, 75.10289253727083, 19.59606332163657, 0.40343363739309773, 0.12366116963206761, 3.8262039519125417, 14.004050973922977, 19.087365250433646, 18.1529390042828, 26.097050636045395, 46.12915992736817, 59.69666581000052, 63.832118741927616, 63.690317215458045, 62.39049473116475, 60.16673441856139, 57.75659092010991, 60.14431415065643, 60.61826982805806, 60.323221298956106, 61.070044502135254, 61.482607241599794, 58.63096175655242, 61.889945383994814, 52.4074899765753, 43.074198384438795, 46.98725292759557, 48.23286825610746, 55.86523971249981, 56.38019200294249, 58.043339713927246, 55.222076908234634, 57.21937525656916, 57.35818401459725, 56.97334458751064, 52.35082349469585, 50.64931108105568, 53.36452084202921, 55.51867869592483, 56.20022581469629, 56.730875430568574, 52.99638678950649, 56.14262580871583, 60.41474196218676, 53.007734206414995, 41.446132352275235, 43.06980140747563, 44.43866152917185, 42.97003984451295, 44.162299171570815, 42.597061664827415, 44.70249583644252, 47.01978506580476, 55.402105854403594, 56.316653528521144, 59.088588606926706, 53.28366118092691, 54.92166257673695, 52.00351722778813, 51.3037310877154, 51.684859952619, 53.905968742985884, 55.846078934208045, 57.666866702418176, 54.70029577132195, 62.46738103128249, 38.70588610249181, 40.402985849688136, 63.031461008133434, 53.929357836323405, 57.60996880069856, 51.91223582913799, 59.46996458115117, 55.69226318790067, 60.08878515612695, 58.3386431970904, 57.02158974063013, 55.95535224483859, 58.656559144296956, 53.194807729413434, 54.55088876908826, 52.71006161166776, 50.47334571038523, 45.34365430954964, 44.03546148730863, 41.98556415496334, 44.42227778896209, 43.88123389213316, 45.41641427624611, 43.71363493704027, 56.566869366553526, 60.96518778031873, 57.12461863794635, 51.4176877083317, 52.590158677870235, 55.54231097621303, 55.472932092605106, 58.195382548916726, 51.081564118785245, 51.96538394497287, 58.16627463986797, 60.492679457510675, 61.0272632106658, 59.7452796659162, 57.37329690687118, 50.981955528259284, 45.60651979138775, 50.6916844460272, 52.032852634306884, 56.719531936030236, 53.29748753578433, 47.82947209573562, 46.9793571964387, 47.65547967726185, 46.33140517819313, 49.08451680214175, 48.18701182642291, 57.23056970104095, 56.17469118487451, 61.84515976136731, 60.009678794491684, 65.53092472014889, 60.35297247671313, 69.95200464802404, 65.19303998639508, 68.3229580233174, 2.9445490289118985, 16.612094717641032, 17.418102564350253, 0.24842587359730275, 0.15934015954694442, 4.368244130765238, 67.23825793112478, 45.04569930415, 50.81286215013074, 35.11814901905675, 47.41870580180999, 49.695316130115145, 67.83532111875473, 65.23227153285858, 67.01471421026415, 8.296925886984795, 0.25044532733098157, 0.2174596344271014, 0.23100589221763998, 0.12789432635350576, 0.1734146043177574, 0.07939182131761506, 0.12943239341820442, 0.21132749895895683, 0.09221308414013156, 0.15682133906070264, 0.12576782715416726, 0.13101269491016865, 0.12048623314307583], [0.05009496434321327, 0.0432280394729347, 0.09354846732270333, 0.11157692169710515, 0.010925137753328009, 0.042011533984013145, 0.047268440811744625, 0.024260116155229272, 0.07082356455465479, 0.05464312109735705, 0.043146757544168544, 0.04023022251203656, 0.04602451703601307, 10.021408680946598, 55.70252018590128, 54.4800272295552, 44.70897559196719, 35.39433879237021, 19.6593919492537, 39.5568403890056, 47.67724098697786, 37.5327600971345, 60.14061927795411, 7.995612842421378, 0.2139675911636122, 0.1209330692466709, 2.9198984032677067, 4.453296805581739, 4.469611904313488, 4.721118202132564, 23.119461767135128, 50.045568097022276, 55.817390718767726, 60.720596621113444, 58.13633911071285, 57.62563474716679, 56.51432529572518, 53.18864176350256, 48.30384354437552, 50.66209408544725, 49.92277437640775, 55.00146319789272, 56.63061964896418, 52.51705746496878, 48.09797794588151, 41.489043081960375, 42.945246542653734, 44.23047780990601, 52.325645800559755, 54.94516541880947, 54.17152889313237, 53.47268019953082, 52.38669749229185, 50.16256455452212, 51.40994887198172, 50.543901305044855, 51.38379843004289, 53.01976803810366, 53.946384845241425, 53.31508721074751, 52.7458453947498, 53.316609090374364, 54.131136325097856, 54.16548059832666, 54.975889344369214, 44.98341598818379, 41.10763180640436, 39.389833711808734, 40.948764047315045, 40.90759092761625, 39.059072002287834, 38.12183341672344, 40.90191918034708, 43.98627888771796, 47.317418436850275, 52.10848377596948, 54.932598144777366, 52.45371903142622, 54.92771087154266, 52.44934558868409, 53.799374411183024, 54.019085976385306, 55.54152650217856, 52.31620857792517, 52.22804546356202, 50.03458153816962, 57.38470708170245, 38.10129196413102, 34.444113239165276, 60.970773235444106, 48.76059962857155, 56.63457732046805, 50.9537301524993, 54.595042890118016, 52.813800457985174, 56.32494934143559, 51.34890502498996, 54.03321435374599, 52.51837930371685, 53.71026208323818, 49.17329572862195, 48.74519648090486, 48.24669853333504, 47.646419002163796, 44.02543983151836, 40.172291648003366, 40.05130614003828, 43.106718755537464, 39.5544320537198, 39.02056609430621, 40.87310544906124, 53.00670654542985, 53.436782667713786, 49.81684292516401, 53.539368337200536, 56.24836506382112, 53.73776182051628, 53.45290753149217, 49.06020202944356, 47.7788225297005, 51.46980424081126, 54.73210227104926, 52.41884131585398, 52.055225833769775, 48.08408883310134, 41.8024718376898, 39.85612115552349, 44.96005435143748, 52.27646320096908, 56.73847306159235, 56.34347861812961, 56.05421558503182, 48.76134880127446, 42.99693945915469, 42.40827406606367, 48.31403778445337, 51.29665120955437, 57.766330165247766, 56.86127070457705, 59.17096230291552, 58.42936761917607, 60.72758628476051, 59.78125564513668, 62.0733005000699, 63.70897593036775, 68.52958063925466, 68.50311248533188, 8.09939826688459, 0.7695844721409583, 2.372402207505319, 0.9954237601449414, 0.08624262386752714, 0.5709389152546083, 36.47014294901202, 49.34213807505947, 40.06741923670615, 28.447597642098707, 28.255934945998657, 39.76430631452992, 42.442618339292466, 49.21335097282164, 42.52825936963482, 8.84590179689469, 0.535802690973205, 0.07193234659010364, 0.10076332251511275, 0.027059516343738765, 0.013745826567643353, 0.020668766829335404, 0.04057063751163022, 0.06277186172683874, 0.038133685011416674, 0.058241991491447535, 0.04162210467902403, 0.11915611298454386, 0.05492218011509507, 0.03043723247584797, 0.01869644473997816, 0.08324700557897169, 0.05106660131845744, 0.027968255585179697, 0.12853274572520487, 0.013063204880323143, 0.038997724937695655, 0.01924280524103632, 0.1093008285087924, 0.006647613528560126, 0.07634155031654143, 0.05377348106835158, 13.542544899448274, 66.03848334281676, 59.99458943643878, 51.846124279883604, 38.49241110586351, 26.063734023801743, 44.62835127307523, 44.12592703296293, 42.19843118421493, 66.3801766980079, 7.809397337898132, 0.09142805852236287, 0.0934187762980019, 2.597530320767434, 5.291833358426248, 4.866017420445719, 6.02389766323951, 23.12056395315355, 51.17002141091132, 56.77628471005348, 62.80499512149442, 60.52911043167115, 60.669248873187655, 58.081265111123365, 55.02301269961942, 50.112067960923724, 53.029067977782226, 51.84410033687469, 58.054181145083525, 59.599151765146566, 55.85194679998583, 51.1378187517966, 42.950004377672755, 44.254114012564386, 45.21911513420844, 54.01122946893015, 56.90841759404829, 55.92763677720101, 54.205139683138945, 53.813989162445075, 49.84234225365424, 50.77323444427983, 50.12305451977638, 52.21304632002308, 54.23139210670225, 55.42740514201503, 54.76699175373201, 53.65488606114542, 55.87875620011361, 55.0186941700597, 55.48260073507986, 56.659876608079486, 47.16249658215431, 43.12822511119228, 41.87083874979327, 43.75913050866897, 41.710966863939845, 41.70789172572475, 39.63722152094687, 42.2455035486529, 45.74799183876284, 48.82850370099468, 54.02182379076558, 56.90524047420871, 54.282245635986335, 56.58845024724161, 53.69992271546395, 54.53588962554932, 54.85227977075885, 56.0380946436236, 55.19352989812052, 52.782099862252515, 50.72237307025541, 58.5432771713503, 39.23959516709851, 36.59182663886778, 63.12946534925892, 52.955676509488015, 58.091020045741914, 53.01330004968951, 57.76209008309149, 54.93530065782609, 58.87394866635723, 53.776801170841345, 56.89465007474346, 54.48511846603886, 54.46815029267342, 51.55159350364439, 51.676670043699204, 49.5499413244186, 50.76029062271119, 46.41791305234356, 41.11922633263373, 41.925959817824825, 43.991472105826105, 42.13714022790232, 41.84048744939989, 42.99230321761101, 54.48981354313513, 57.03356081439603, 50.92304545064127, 54.232235416289306, 56.036270741493475, 53.774432059257265, 54.39954019361927, 49.81085346591089, 47.478106175699544, 55.68583442318825, 58.280548972468225, 53.63831012479721, 55.321646275058875, 50.99460909443518, 45.47482229048207, 41.66544775809012, 46.47777234354327, 55.16061336763444, 57.9503442395118, 57.93736511661161, 57.497961598057906, 51.165087069234545, 44.3537304478307, 44.196765038274954, 50.095256682365175, 53.013174533844, 59.14915392475744, 59.41655366651474, 60.78562559620027, 60.62737757159818, 62.56957838612219, 62.73985632004277, 62.454025360845755, 66.06879541950842, 67.21706928745394, 70.49387224258916, 8.724373040660735, 1.2444691384030928, 5.456203712571052, 1.700876867098193, 0.13171714340006152, 0.3376775835790942, 43.32341794044741, 52.26050307673793, 43.706166744232185, 28.051197028929188, 34.27375685784125, 43.79244319854244, 51.63848969244188, 52.52998559705673, 54.01706595574656, 13.197801901448159, 0.40656902076255896, 0.08641826484592692, 0.09601967544445107, 0.040531904106178594, 0.030130565564538685, 0.03093000129616309, 0.04259125569895391, 0.04130839933491042, 0.049813924988190976, 0.07798087122219224, 0.03285612828368622, 0.020300567735947912, 0.02821475203569618, 0.10514208956831887, 0.1396759082713435, 0.21528290284256782, 0.19600947898241783, 0.09998460946184012, 0.3007211956766344, 0.10580673212966613, 0.17437032964681426, 0.1517392037015769, 0.23190287392466302, 0.103194854943262, 0.17919283780840137, 0.12521422903744445, 17.000987914300737, 74.3384696591285, 66.60102967293032, 58.18080309898623, 46.936022850774954, 29.132733729577836, 50.126937666246974, 63.00251391626174, 49.36600569755801, 73.36722020179995, 9.503758780417904, 0.39801393305101707, 0.4396286564728906, 6.4227884911721755, 10.531109898321091, 14.108769432190927, 9.859951176951009, 26.177843616854762, 52.628703809553585, 58.69529647211875, 63.391946438820135, 63.53588957940379, 61.9476552163401, 61.59546952093802, 58.27864270056448, 52.92375233865554, 53.113955913051484, 54.137467030555975, 58.94713617140248, 62.38268921452185, 57.73107197976882, 54.01497533244472, 45.425478873714326, 47.29573165216754, 50.049455165863044, 58.08536006558327, 59.46060188354985, 59.201297913828206, 55.588018355831025, 52.60833494124874, 51.89729944352181, 51.876377521022675, 52.78945822869578, 54.058341057069846, 56.79748512083485, 57.45600792669482, 57.4328580979378, 57.46060886690694, 57.1818656306113, 59.18199200784007, 58.17487639765586, 59.28958654403687, 48.375921018662, 46.182912088209584, 43.30258231009207, 44.44820073343093, 44.065726495558216, 42.792387854668405, 41.22229837602185, 45.569543607773326, 48.81862717290079, 51.18053336297312, 57.18561933886621, 59.18274902528333, 56.186826998187655, 58.91918928392472, 55.64240201827019, 55.98502497519217, 55.72589358975811, 58.054216446415076, 56.58834042087678, 56.58255100250245, 53.089617606132265, 59.18772259066182, 42.907058346656065, 38.27768879552042, 66.16330885118055, 54.36706296859249, 61.05273116019465, 55.095403963519686, 59.087376594543464, 56.78612593681582, 61.504517601382354, 55.64758739163799, 57.57252977740381, 55.901647152439246, 57.468598734947946, 54.23544783746043, 53.72071127737723, 53.14728429240566, 52.54570645670737, 49.307217213415335, 44.79057658103205, 43.20064383168375, 47.4840917125825, 43.47243662803404, 42.926474079009026, 45.17248599759994, 55.882302022749386, 58.98925850468298, 55.55680805636991, 55.61068573305684, 61.22868868612475, 56.46479360518917, 55.73602114954303, 51.237862725411695, 49.59837475130635, 54.892899836263354, 61.68049081679314, 57.342412164134366, 57.89764327387656, 53.94041499783916, 46.49146533781483, 44.01943076041437, 48.22545497648178, 57.40331872817009, 61.50341541536393, 60.25714505103327, 60.88685020323723, 54.31862561933456, 47.33673218757876, 45.94394168546123, 52.95250723438879, 55.50293430205315, 63.81553103846889, 61.08789520878946, 64.5605734855898, 62.423536777496345, 66.05967198648761, 65.4981650844697, 66.55251779863912, 69.50109681775494, 69.98336791992188, 71.28181365228468, 11.187864695825885, 3.1723784294820603, 5.9919734924070305, 3.1869902389664806, 0.18549433999484588, 0.7496215691489558, 47.78696144780805, 62.193831013095, 55.668866249822806, 39.67462916528025, 39.813586973374896, 49.126584222239835, 58.767785795273326, 60.13063684586556, 67.30411452631797, 17.658647798722793, 0.8218887268054871, 0.17793086117073414, 0.237444156420327, 0.14522118974597226, 0.0932548564648436, 0.13516018767991375, 0.1673769428124351, 0.10269666796610241, 0.1829869188969174, 0.12463899659773997, 0.14963471420830296, 0.15192239064603083, 0.18500136241557139], [0.026438883618421616, 0.0274641793071022, 0.014844011691879603, 0.06973321459466411, 0.048394053798889926, 0.09937429019520361, 0.018419662918595057, 0.031637533289951184, 0.02950781652133071, 0.021564317867159847, 0.03643683473309202, 0.060577008332456314, 0.0760413357807744, 17.8909795899545, 52.55983875643823, 54.608022013018214, 47.02850057232765, 36.69365529091128, 23.604955096398633, 24.723711167612386, 34.080309483312796, 43.236898299186464, 55.89010753939229, 3.4235854014273617, 0.06923931004900126, 0.043692112554826086, 4.788204950671043, 6.496053463028324, 5.513966006617393, 5.638892516013115, 37.128336275777514, 48.47117185592652, 56.999491107079294, 55.50325201403711, 59.464386970766135, 60.138932658780014, 58.11475038528443, 54.220742871684415, 48.565120466293834, 43.01713966554211, 43.50026584440663, 43.831074622369584, 43.33385928984612, 42.176481600730654, 41.0712282888351, 41.72962950121972, 42.40347308497275, 49.61896327234084, 55.4088484087298, 54.99573653744113, 53.079117421180975, 51.93525229730914, 55.936701374669234, 51.23317549305578, 49.24456519465293, 51.120713295475134, 51.12232538961595, 54.69682839608962, 52.533609867095954, 51.02137927086123, 49.58828641522316, 51.684687368331424, 53.775483254463445, 53.77440460266606, 49.93545539917485, 41.02332045955043, 41.011306239712624, 39.26420411755962, 39.99942887213923, 41.592644645321755, 38.78440410860124, 39.37011203458233, 39.96997187214513, 38.64068062074723, 43.34502235535653, 46.23281640391196, 48.475125605060214, 48.504060929821385, 52.65994941034625, 53.790796187616166, 54.58035753619287, 52.96890666407924, 53.5076089059153, 50.24568742321384, 52.09093116944837, 49.30027069584016, 59.74440497736777, 39.83951776258407, 31.41777127019821, 59.49529524772399, 49.715857582707564, 54.00907216533538, 52.000457779053725, 54.51612480225102, 51.417424909530155, 54.191984053580995, 48.47007359227827, 54.344591709875296, 52.406744726242565, 54.345129074588904, 48.145285652529815, 46.99071245808756, 47.79400602463753, 48.67470756653817, 45.09994960600331, 42.44724281372563, 38.45973383995795, 42.664416605426425, 40.381577553287634, 40.1060781171245, 39.747804903214984, 52.492746614640765, 51.76004394408196, 52.12389084600633, 54.38924789428712, 53.268556133393325, 53.747638348610174, 55.406008612725046, 52.111853091947495, 50.28176146168863, 55.62531617379958, 53.24595935883061, 52.97230343664847, 45.61717294877576, 41.17326482649773, 37.57889501510128, 44.07243767092305, 52.146934770768695, 53.85723721596503, 56.401392413723855, 55.37999153137208, 53.97060548105548, 49.33444630715155, 45.881168073223485, 46.10772025200629, 52.195587850386104, 55.02716256726173, 56.269996935321444, 57.60332038325649, 57.15637022449125, 54.588747485991455, 54.397990857401204, 59.01371840507754, 60.002657751883234, 57.70465481665827, 53.09163762677101, 57.31253939290201, 11.526072044526378, 0.7248243449195739, 6.776404871094612, 3.5721076640390583, 0.1392716130301837, 0.07590330205857754, 20.73040493073002, 56.5011461319462, 33.69364223172588, 33.681318144644464, 20.90484646058852, 33.5257726330911, 47.827691339677386, 53.645127204156694, 50.390399348351266, 12.41220312733804, 0.08771387274347006, 0.004367623825542509, 0.02235750615176174, 0.0852700982302908, 0.005738340419596963, 0.10547602729451273, 0.02061793114989996, 0.06079310258369773, 0.054211166251691124, 0.02730783991395466, 0.051126846472822854, 0.03678266597431033, 0.05235072172757599, 0.06767701928413684, 0.017580654915241946, 0.04869639805908646, 0.03727230341023496, 0.042076574848784555, 0.11949895265241785, 0.07119779084478656, 0.03636528978184347, 0.08545880866867882, 0.05510940434290998, 0.026090934144092665, 0.07690503096748745, 0.034444695864353454, 22.278097675692653, 60.789928436279304, 60.9605868401066, 53.32108843711115, 39.45319175720215, 28.53618633362555, 28.88961542037226, 38.76296835560953, 48.87204200990739, 60.91355369937036, 2.9905263166273794, 0.15789516450416657, 0.2949046577897764, 5.067002609852822, 4.405963603527316, 5.3142153832220265, 8.134082315429565, 36.291392695519235, 52.22438981456142, 56.99161106540311, 57.40460134321644, 61.84826235617361, 63.349231827643614, 59.15225651956374, 57.63200075395646, 50.35627865022229, 44.845795708317915, 45.48687181165142, 47.45436406904652, 46.56144042168894, 44.403819114931174, 42.43779382398052, 43.38498346267208, 43.90257550824074, 53.08427533795757, 57.51060731949345, 55.71534241399458, 55.604151064349765, 53.85528779798939, 57.9805935582807, 50.746146555869814, 48.701277702085434, 51.913102672946074, 54.41713202384211, 56.34675771959367, 55.44473809580649, 52.49765349972633, 53.34748991074101, 53.18479391836351, 54.982035698429236, 55.50634284173289, 51.39798956532633, 42.65356340715962, 43.38355964229953, 40.405072550619806, 42.205377701790106, 42.90002945930728, 40.40394290801018, 40.915549416695875, 40.96110382387715, 39.44306027504706, 45.21012898414366, 48.52217835764731, 49.488599377293745, 51.13801879267539, 54.33211857272733, 53.33718584429834, 55.42350630606375, 55.55306219285535, 54.72514398636357, 51.66062754969443, 54.661880077854285, 51.318106574396936, 59.69457518669867, 40.822828508192494, 32.53624885312973, 60.62893475255659, 52.416727158331106, 56.22136738992507, 54.030943301416215, 56.94073007952783, 52.63919614976453, 55.75102813782231, 51.89509507148497, 56.10498674454228, 55.53396809485651, 55.542558085533884, 49.98515575162826, 48.734413885301166, 49.762902490554325, 50.64711847612935, 48.195437077553045, 42.52533720385644, 40.5502002469955, 42.78182491179436, 42.16283567490117, 43.25870275497437, 42.023583689043605, 54.272729965948294, 54.91883847021288, 54.34650582651938, 57.10519898322321, 54.93143320083619, 54.70615186998921, 56.98453510961225, 53.77960566551455, 49.96422990675896, 58.742007978500865, 54.21907586436118, 53.720664208935155, 48.34989609256868, 45.495383354925345, 40.35037117619669, 46.4457187344951, 53.46319590845416, 57.33725424735778, 58.8241502546495, 57.30314923870949, 56.89012758193478, 51.980473303025775, 46.64883475149832, 47.31930117453299, 53.14864535485545, 57.82225531916465, 58.44273505672332, 60.00830988730154, 59.54983188259987, 56.16375561683409, 54.89414322760798, 59.972596706882605, 58.8596986955212, 58.417788782427394, 54.30981989829771, 56.93507402173935, 13.133017093904558, 0.57185068245857, 8.664589255086838, 5.384930324169898, 0.1751649926506704, 0.12400134331396512, 24.953295338538386, 61.80732850105532, 40.78384014867967, 34.481144335962114, 22.710131060692575, 38.4309789442247, 56.060671806335456, 61.424077633888494, 60.45027079120759, 18.066066349706343, 0.06329678517255573, 0.049337100372799945, 0.08417260833084585, 0.054956956676417784, 0.034762901975022215, 0.03093428755809944, 0.06383105489094892, 0.015391816268675031, 0.012088863614706263, 0.024128674619620847, 0.019605296979387923, 0.04012252204120159, 0.07433130495971249, 0.17963366012179083, 0.09994128718972208, 0.1292116988089777, 0.0914442612819614, 0.1469292440601895, 0.2099832291564634, 0.12737093508363734, 0.10197390997481924, 0.14515610291592537, 0.1917981710885802, 0.10866752660442745, 0.16488649822290868, 0.27169679021162374, 27.683784692518174, 69.67835657058224, 68.83001850497338, 62.448588955786924, 48.60063752820415, 31.300551237598544, 32.720888545436246, 48.678967260545306, 55.51798051403415, 63.970523495827955, 3.8901660423124995, 0.45862046641207516, 0.5559959719257971, 11.76264391791436, 15.140160591371599, 12.065749975942797, 8.980285140775866, 38.06877551540252, 54.084656238555915, 60.29256797605946, 57.971532883182654, 63.06995514900454, 64.04122814055413, 61.88098669052125, 59.848747868691724, 54.32693319935953, 46.901615819623395, 48.85817250897808, 49.106219276305175, 48.50431588388259, 45.9999256749307, 44.610712374410326, 44.2368555838062, 46.54197762089391, 54.96118045622303, 58.82007491204047, 59.306609630584724, 58.0010251845083, 54.09942396225468, 59.26055316002139, 51.66747993038547, 49.66765557565997, 53.6296259972357, 55.51639979885471, 60.14778544825893, 57.35470879462458, 54.884874666890795, 53.894699773480816, 55.09605899933846, 56.25403681109029, 57.691432506807395, 54.04425974815123, 45.76176328043784, 47.14244542583343, 42.49504081664547, 44.68530016560709, 45.50579724773284, 43.30344130915981, 44.60027494738179, 43.68385630269205, 42.27041059924711, 46.82410194027809, 50.51455020904542, 51.98551747106737, 53.28903090569281, 56.33639873996858, 57.92331518665437, 56.166254166633856, 57.95485104283979, 56.80109762376355, 55.87164102062103, 55.639311190574404, 54.43815200559555, 63.14035777122744, 44.22046792122626, 35.752733599755075, 62.16140085651029, 54.27356150842483, 57.9491126152777, 55.952402622469016, 56.73295036438973, 53.148468848197695, 57.927296392379276, 52.79917393961261, 58.965771352091146, 58.04352798769551, 57.32601665681409, 53.60450713865219, 51.66880961387388, 53.84840403833697, 53.8910323573697, 50.7403532151253, 47.0835235811049, 41.82446848961615, 46.22859593360655, 43.908482597720244, 45.05473252265684, 44.6284257981085, 57.17501717229044, 58.23340600536716, 56.8119861233619, 60.76463699340821, 57.63599372679188, 58.42288394128123, 62.41390735872331, 54.61639627333611, 52.474758625030525, 60.42244941957536, 56.9644800309212, 56.697660799949404, 50.52137121077507, 46.93724270789854, 41.47411846345471, 51.64980965275919, 58.24402778379379, 60.448395898265225, 62.200310768619666, 58.95895427273166, 58.649573403020064, 53.92545115563178, 50.01529132166217, 49.83429747243082, 57.271597693043375, 59.67530065967191, 61.94416430688674, 62.13067693095054, 61.67097906912527, 58.19843415291079, 55.36784395094841, 61.38525009155274, 61.198478591057565, 59.148671473226244, 57.747110551403416, 61.57950547433669, 15.310209066637102, 3.114126084312316, 15.509886145591738, 9.544027793791987, 0.46565364385324143, 0.22922934964299205, 27.37907144331163, 69.85809526135846, 48.17303249912877, 46.08968911632415, 30.259046246928555, 45.108425847945675, 63.359477058533706, 70.21154788232619, 69.1050943251579, 25.971574014233006, 0.17963453346202451, 0.1263146913580356, 0.164996876171039, 0.249599979950055, 0.09899441783706989, 0.17565300598019556, 0.18139376244958372, 0.18135006479438276, 0.16159806580793473, 0.10350341217652445, 0.11704634514547164, 0.11529607172574728, 0.1651961049966274], [0.09458005067802246, 0.0463553712583117, 0.05928468312166872, 0.0946563377135223, 0.03625424916765863, 0.02997319003747356, 0.14031746094265293, 0.01030839292422658, 0.055476172767098875, 0.04402009777784829, 0.06575444502936256, 0.043446317074760314, 0.474193072727611, 24.90104740665805, 50.839526422562145, 53.446910227498705, 33.943622727547925, 34.97033057674285, 18.232916132096324, 29.36212178199522, 36.8188298902204, 54.58642152047927, 44.348458782319106, 0.4718979958805346, 0.02370717112846192, 0.3384218533192912, 1.2194797180352674, 1.5113373990020447, 3.479471576790656, 12.100075617913278, 28.524242716450846, 50.77219893855434, 56.67413442365585, 59.447042249864154, 60.86334736116471, 58.09822936211863, 59.932074700632405, 56.49217174899194, 55.378767751878314, 46.72888640434512, 42.22486795917634, 42.634700729000954, 46.90936250071372, 42.885877547725556, 41.303754237390336, 41.02588176727295, 45.81872786245039, 51.544862716428696, 56.16954503520843, 54.057380076377626, 54.757581987688624, 53.008710876587905, 49.85656476789906, 48.63231066734561, 52.55255099265806, 53.940163966148134, 51.52925168314288, 50.44177063049809, 47.86970384659306, 46.7270468127343, 45.55262250284995, 45.74004511679373, 49.12821200586135, 46.14469251325054, 41.3932470352419, 37.81909704208374, 39.069905588703776, 37.97510539331744, 40.47824044381419, 39.28110561063213, 38.98899885915941, 39.71861070202243, 40.00649698318974, 38.88648379233576, 41.059727899489864, 40.735571461339156, 43.47511168449156, 46.268235406567975, 48.083849568520826, 47.98469597293485, 49.77399495340163, 46.31202474717171, 50.35081478857225, 49.57270676089872, 53.84261461996264, 50.64986805762015, 57.157182155116914, 40.52394782343219, 28.44807617125973, 53.21581594405636, 49.23480633766421, 54.22379839804865, 49.55209862801337, 53.93687309757356, 51.801460250731445, 53.64892798085367, 51.467933270239065, 54.28412837366904, 52.283052782858576, 50.081316578772764, 44.25886400284306, 47.8560539983934, 45.80215977084252, 47.96571562367101, 45.996819157754224, 41.309335770145545, 39.3399372408467, 39.95682408732753, 40.582622558839866, 41.80910064328102, 37.573666495661584, 47.78399221358761, 56.07833816159157, 53.70551993769985, 52.78977986304991, 48.022507621395974, 49.175303982150176, 54.01086076613396, 52.388419412797504, 52.65488955282396, 51.81600439933039, 54.268858586588216, 52.40144168176959, 42.28505672947053, 41.138241983229115, 43.55021722855107, 51.02830225421537, 52.79066631870886, 54.44794616391582, 52.52749881436748, 55.12884609160885, 55.453006452129735, 52.05081316732591, 47.3128527979697, 51.1234667993361, 52.64383631367838, 56.73630006851689, 56.60069588691958, 55.64284132372949, 53.13436792742822, 56.41562669507919, 55.390621154539055, 62.2237116290677, 54.15459602109848, 57.115459903593994, 59.516907507373446, 62.853585443189075, 13.863344769324026, 1.0986870190789624, 1.8745307359964618, 9.20726191612982, 5.564614592059966, 0.9336273083763739, 15.638433983249051, 53.46511786983859, 40.38855544982418, 34.79238833150556, 26.390461575600412, 30.682434728068692, 49.858459272692286, 48.789538875702895, 54.0715672892909, 21.18677270027899, 0.21564072719024074, 0.05655816853827527, 0.060401532062960256, 0.04731750491285517, 0.04542168244839676, 0.058156898275258086, 0.013656990054333884, 0.09910923909516105, 0.07283293657125005, 0.02204126122617914, 0.12551543948751304, 0.04663636464805854, 0.023353508553437652, 0.07035392967443313, 0.053724857467797496, 0.02216848736298421, 0.12336370535194875, 0.017666370577869878, 0.050754274932607535, 0.10795936258810182, 0.04988461958184358, 0.022068669936890085, 0.039524199711459304, 0.03880914856469439, 0.01040703919340646, 0.75605015000028, 31.220368185350974, 58.69276654335761, 59.86985022021879, 40.60627445097893, 43.0685305595398, 25.208782842082364, 28.74625671294428, 44.17803964307232, 60.1196934330848, 47.87530106882895, 0.6372342030367544, 0.06862928189577595, 0.35306507240860696, 4.60220419591473, 4.141839040863899, 4.085636869553597, 10.379041567925485, 33.10785193597117, 52.23501551535822, 58.62416036667363, 60.604635669339096, 62.457802603321696, 60.90486957180885, 60.97280110082319, 59.14850281130884, 57.02563370427778, 48.31901527220204, 43.37341247066375, 44.274906496847834, 47.261975734464585, 44.90709843174104, 44.08743289209182, 42.81837747943017, 48.44729638868763, 53.19801622821439, 58.25240204411169, 53.97535939370432, 57.377835089160556, 54.682900059607725, 51.778749727433734, 49.03338086220526, 53.60125157140917, 56.90080427354383, 52.7519799816993, 50.31751386580929, 48.63123986028856, 49.028544579782796, 48.23816345584009, 48.63374625482867, 51.236168261497255, 48.54552430491294, 43.526941883948545, 40.053039827654445, 41.137190788022934, 39.86855506896973, 41.80341712890133, 41.27057098573254, 40.50495178468766, 41.277937196916156, 40.75869383350496, 39.997346093577725, 42.89032159313079, 43.686276405088364, 46.44333001106016, 48.693001501021854, 51.21800768759943, 49.548929352914136, 50.47198464793544, 48.26759692161314, 52.950526437451764, 52.00572552219514, 54.933904294044744, 52.666409554020056, 59.692355125181145, 42.61264131915185, 31.505077346678707, 54.534995325150035, 49.87903210424608, 55.472151540940814, 50.02130039276616, 55.468695932819, 53.65354461054648, 54.60617065429688, 52.76024833802254, 55.96628389050884, 54.53753309865152, 51.969384762548636, 45.51184554253855, 51.363284434041674, 50.019217614204656, 49.99537744829732, 49.480130980091715, 42.87815832322644, 41.74718603011101, 42.3720274433013, 41.80407216472011, 43.856052275626894, 40.680375868274325, 49.63930860642464, 58.36040450680641, 55.09593348349295, 54.37861434874996, 51.27048115576468, 51.35474543417654, 55.34684750341601, 54.290106065811656, 51.59475134265039, 53.493908066903394, 57.5842615865892, 54.847973008309644, 44.62605276415425, 42.241926347055745, 45.567551043725786, 53.73296083942537, 54.88224667887534, 57.39763913616058, 54.059631516856534, 57.910077187322806, 56.918619678866484, 54.317511666205625, 49.615252710157826, 53.35770768503989, 56.73029491978308, 58.248738550370746, 58.04692083789457, 57.20592544924829, 53.61396397313764, 57.76842471091979, 56.93539173372331, 63.34034765920332, 55.09014406511861, 57.89918084298411, 60.670319680244695, 62.442972121700166, 17.79555028484714, 1.8239040913120395, 6.462041610671628, 16.46519607113254, 9.531558579014195, 1.0942199297489659, 16.730026660426972, 59.64734984982399, 43.24551574645504, 35.384925103956654, 36.458481742489724, 38.57496915325042, 53.16755117908601, 55.51355608047978, 61.497457335072184, 29.004397699909827, 0.3047158845490025, 0.07855041928949856, 0.08829535646063667, 0.10818542747367775, 0.02054289666815631, 0.04322057011567297, 0.03651044812173613, 0.06533500422993976, 0.06075407040395564, 0.027355684020045786, 0.05380354235850034, 0.02648341247902042, 0.015897896824284427, 0.20319998023971436, 0.2136546748900606, 0.08806823437372524, 0.2950238304272775, 0.14991021474763272, 0.14531489762087024, 0.20835733011124596, 0.14362358998867775, 0.13873795618212995, 0.1543611549441853, 0.16760229523624146, 0.13159862959817534, 0.891820113024404, 36.43201358856694, 67.95536918024864, 68.38987365845712, 49.08727815074306, 46.563268246189246, 22.9209957199712, 40.458683506135024, 52.363084823854514, 65.73552339307724, 53.86049278320805, 0.8956966404953312, 0.1498558225050088, 0.6374829058204928, 8.38281108487037, 7.804286489563604, 7.704453833641545, 13.975778529720923, 34.32475943719187, 55.96026305229434, 60.35352553090742, 64.71767617810157, 63.09097513075798, 62.189469337463386, 62.20489994172127, 62.37246751785279, 59.43291387250347, 52.285763140647646, 46.31620207140523, 47.15967247563024, 49.72880924901655, 47.318846179592995, 45.73294954915201, 44.826721222169944, 52.02879690354871, 55.615827960352746, 60.98173626007573, 56.93208125329787, 57.526951836001494, 56.083586292882124, 53.41502135799777, 49.7597606720463, 55.35662204988542, 59.320232022193174, 54.57645085550124, 53.997391346962225, 51.06705527151785, 51.09950503995342, 49.749119281768806, 51.41564023110175, 52.49192291690458, 49.70704401693037, 46.62389632194273, 44.305053833992254, 43.75982869055964, 40.85049690738801, 44.154548568110314, 44.465541531962735, 41.889038547392815, 44.42231309029364, 43.28915603699223, 42.77845167344616, 44.232101671157345, 45.58066352721184, 46.86829528500957, 50.763138263456284, 52.254690124142556, 52.2677476944462, 54.44340013688611, 48.797297323903734, 54.16223679819415, 55.232667307699884, 57.72219565606887, 55.454234153993674, 61.54163106795281, 45.29469528505879, 34.05511217732584, 54.906055465821304, 51.3695719934279, 55.39999954162106, 52.70410353137601, 57.98829317092896, 55.07017135620118, 58.65551187146095, 53.87424461303219, 57.99136438677388, 55.05197155860163, 56.08366866265574, 47.60542238912275, 53.94707518239176, 51.89429883033999, 52.67015933990479, 50.835855084080855, 45.29384020836123, 44.782865201273275, 43.257596646585775, 43.81126273062922, 45.08835900214411, 42.257168677545366, 51.81660059959658, 60.28383285768571, 57.1264111611151, 57.15012973354709, 53.32727401487289, 53.8345149255568, 57.4266529083252, 57.02329989402526, 53.12369515818935, 56.342215614934126, 60.618830726992705, 57.095848052732414, 46.144057089282626, 43.63101020936043, 47.859466460443315, 55.95688589157597, 59.20385529918056, 58.441585802262836, 55.392174413127286, 58.622222715808505, 60.09417841511389, 56.34978971173687, 52.79660478714974, 57.57456940989341, 59.651742904416984, 62.18928498606529, 60.01113399382561, 57.762854945275095, 55.74682727936776, 59.75772534647296, 57.344981316597234, 66.6607673706547, 55.0501201998803, 60.90906650789323, 59.95782506081366, 66.50115043886247, 19.663151541063865, 4.652867980541722, 10.481926318137877, 17.730187908295665, 8.887152383404395, 1.4249053981996354, 20.580731207324614, 64.03542695506927, 53.99895637266098, 44.51781888161936, 41.14880884847334, 43.02630624463482, 63.55486992866763, 62.6500811115388, 71.95966197598365, 36.133450615790586, 0.45416177340572883, 0.16035764688445678, 0.2857233698089277, 0.178525130895357, 0.15421478618537227, 0.20626722774919004, 0.12888036578172637, 0.19898530155900987, 0.16567797430099981, 0.1364558875080078, 0.17254075846604763, 0.13992698592764719, 0.1633692610888712], [0.03830299810356191, 0.11357405162867039, 0.03473623828481763, 0.06851340343634929, 0.06503978458743903, 0.02485111468441544, 0.05148496576434663, 0.04561393604343457, 0.024861043183914116, 0.05270936195888827, 0.04237651742333847, 0.036056288217584935, 1.0560075866599237, 34.425105433310236, 57.27246061448128, 49.72274526473015, 39.52375127423195, 18.41482389357782, 24.35452788106857, 40.42922258377075, 34.857048603796194, 59.39891084547966, 28.47010616333254, 0.11467993785176547, 0.09234748660556732, 0.5274634868387253, 1.8634776194249432, 1.4407080147535571, 5.503714401875773, 16.28209492852611, 49.17781037669028, 62.5949796553581, 60.01746469928373, 60.253050096573375, 55.29941820329236, 57.31004868784259, 57.52851686170025, 56.79637901244625, 52.88515229378977, 46.633337466947495, 42.13792077956661, 43.28334700676703, 43.293180388789025, 42.527659246998454, 40.43536893783077, 39.79749348855788, 44.46098766019268, 48.12485010393205, 52.17146919619653, 51.113025449937396, 52.27667893132856, 55.588998948374105, 56.331695818131976, 50.9013625883287, 49.2989763136833, 54.705469377579234, 53.80963140918363, 49.611471545311716, 44.75242368636593, 42.24919057661488, 41.02259482106855, 42.2786005081669, 40.791786870648785, 38.40344390561504, 38.76412937718053, 37.924608799719046, 39.41048891313615, 39.674821361418694, 41.75958856459587, 40.43281939721877, 41.32480167573498, 38.938584635334635, 39.07815041080598, 39.39462292578913, 38.4557879355646, 38.87062957209926, 43.08691470853744, 43.9113655397969, 46.440702023044715, 46.45352425113801, 48.81326529287523, 49.702627428116344, 49.33509742060016, 50.971169010285415, 55.081161837424006, 52.09936818768902, 57.08716000280073, 42.79246237970168, 27.224879149467718, 56.327279229317945, 52.005949097294966, 55.43961940273162, 52.261609185126524, 53.82227713061918, 52.90961611655451, 52.92020651601976, 50.1373750932755, 48.65809632885841, 48.283439374739125, 43.88069652741955, 43.982313371473744, 47.73697476233206, 49.14461535792197, 49.28331821195541, 49.14803566471223, 42.480484900936005, 38.02182866681007, 38.66983559823806, 40.3333951580909, 40.98366529710832, 40.89113266237321, 41.97984533925211, 47.87156697242491, 49.30450293325609, 47.43502286172683, 42.224703219629106, 51.1902843752215, 54.44773827829669, 56.306506356885365, 48.90584891842258, 52.17072394586379, 56.609478073735396, 49.98173936720818, 41.20063904793032, 41.49835478874945, 49.2334335081039, 55.0938154035999, 53.31524018318423, 50.48621108455043, 49.29874097147296, 55.294691747234715, 55.52919849272698, 55.500533811507694, 50.31536832932503, 55.01834507911436, 54.53419908400505, 55.87744612847605, 54.108049254263605, 54.84139911590084, 57.261705475468794, 58.575726939785866, 56.9562626654102, 61.168597975084865, 58.491756839136926, 62.60808429410381, 41.825476538750436, 46.583291945918916, 22.17868128130513, 0.5642942976086371, 2.5708893374089272, 12.997055976621567, 4.387297534173535, 0.1924384520539353, 8.750359723644873, 50.41816972917127, 48.01020314616542, 43.17490523861301, 17.80103768071821, 23.606092583748605, 54.246469697644635, 55.90375738759195, 57.94854387160271, 28.775474448357862, 0.3897797136056808, 0.07091500480929691, 0.014980188608469983, 0.06010172355379309, 0.025053068867794452, 0.06813794374465942, 0.04187576788207216, 0.024559181559109883, 0.03348633902327668, 0.09781354692794623, 0.023160027302501184, 0.07328775531101613, 0.033818687117027665, 0.01665887877254957, 0.04068598737038913, 0.037919854549991514, 0.06730613313735494, 0.1024699978710663, 0.023751293962460854, 0.10769320832144831, 0.01584969074164908, 0.007303998619693542, 0.05821014904687482, 0.07869782992788861, 0.04309006320733217, 1.844569588861158, 44.20455878780734, 63.55119466781617, 57.78127047323412, 45.32803543152348, 26.64146581003743, 17.41226019397859, 35.72571631400816, 41.4125725530809, 64.76511332296556, 32.847979222574544, 0.14283609756779286, 0.0636015541010326, 1.579344556216271, 4.032635352303905, 2.7389222047021313, 6.857956340236049, 18.13201512059858, 51.37740104429184, 62.74786579993464, 60.75631372390255, 60.21077479085615, 57.33630503377607, 57.517820558240345, 59.98806261247205, 57.92064405256703, 55.67695417711812, 48.29029567780034, 44.37809621134112, 45.20533584779309, 45.905090608904445, 44.427549454473684, 42.5920763323384, 41.237666222356985, 46.41803856818907, 50.48252405658845, 53.61978084810319, 52.08922101605324, 54.752231874773585, 57.43971047862884, 57.555765567287324, 51.450106097805886, 48.86484053827102, 56.390464690423784, 55.50886492575369, 50.650691755356334, 45.92252946669056, 45.04578559629379, 42.48231664780648, 43.18381294127434, 43.21490164726011, 39.730405269130586, 40.27886636795537, 40.349418040244814, 41.22262393274615, 39.773653322650546, 42.80117004148422, 41.464045816852206, 42.21473255465108, 39.32140796415268, 40.66694567280431, 41.4354125145943, 40.21592409380021, 42.19371649526781, 44.85935534200361, 47.36456140395134, 47.31371571940761, 49.549074480610514, 50.99453064703172, 52.12357705639255, 53.841092740335775, 53.42694928569179, 56.933489384189734, 54.375095982705396, 59.05632711225941, 45.250423492923865, 27.3066331109693, 56.59967999304495, 53.06135300667056, 56.94600958977976, 54.33930827725319, 54.53636030997, 55.25053370383478, 54.57606254085418, 51.76847311758226, 49.942660793181396, 49.373587639101096, 46.151850838815015, 45.73540887525005, 48.939765653302594, 51.35803630275112, 50.35461556526923, 49.623022925469186, 44.10227906319403, 41.010180519473174, 40.90823027395433, 42.53439395658432, 41.992616576533166, 42.57960319519044, 42.785755126707016, 49.56749393093971, 51.05122066313221, 49.13258152623331, 44.561117925951564, 53.37127516346594, 57.196382322619044, 56.88779769405242, 51.15801503581386, 52.783276573304214, 57.81128444979268, 53.5677388406569, 44.2020720051181, 42.57050721876083, 52.1271542579897, 58.73581455599878, 57.841976996391054, 52.12086277623331, 50.059296392625384, 56.101986131360455, 57.275504373735004, 56.5221151228874, 51.555131481539824, 56.51279164898781, 57.90842586948026, 57.849139244325706, 54.53644660211379, 55.730090525842485, 59.14508250451858, 60.421221717711425, 58.81050040644985, 65.04324466951432, 60.31139927525675, 63.903043039383434, 47.816234096404045, 49.08722323756064, 24.143327859140214, 1.2711194373907582, 9.618922510454732, 14.110830637716479, 4.086784653125271, 0.1151417816177972, 10.384035725747387, 55.10711616085422, 51.939170745111284, 41.42198231912429, 26.099976724193944, 32.9976176446484, 59.52223016369728, 62.54590295976209, 65.3016229598753, 36.99706239085044, 0.6325981453541787, 0.0848089899086664, 0.030222478878474048, 0.03887413963375073, 0.04085775194389205, 0.046133784156653194, 0.07374062052657528, 0.015397676841295777, 0.027764688786720077, 0.03834126802581934, 0.04321892302663576, 0.0871871643128895, 0.027911116917347236, 0.11827456028831583, 0.27283528879765545, 0.17166006378829482, 0.1971142850215397, 0.2049918598946064, 0.09852281411088283, 0.18751475899930925, 0.11105756004971844, 0.16192251936562602, 0.1764390275122658, 0.1491118132347061, 0.10725869091167566, 2.5724374478863132, 51.12844820945494, 71.78095094619259, 63.072783177898785, 52.65199484363679, 27.310800629277384, 33.25124202236053, 55.86222733220747, 45.66457871467837, 70.6726146513416, 36.139604814590946, 0.36328024200854764, 0.3245248651552585, 1.747385758546091, 8.022254070928021, 8.167763708099242, 10.569611883932545, 20.440667290841382, 53.91253479065434, 64.88713041428598, 64.51607419598487, 63.16646898946455, 58.40283278496035, 61.950950007284845, 63.51254755450834, 62.44517257136684, 57.77409253581878, 51.82694388974098, 46.118620518715154, 48.67571953804263, 47.32437672153596, 45.96588734657534, 43.956923869348344, 43.39558170687768, 47.50615896717195, 53.44367034973637, 57.1269210692375, 55.28104582140523, 57.294225846567464, 60.65555195654593, 58.78579339673443, 51.78182486564883, 50.701129513402144, 58.24571440296789, 57.74505522943313, 54.01450857039421, 48.05320016799435, 46.697562356149, 44.235698484605365, 46.48709973981304, 45.12209923036637, 41.040116048628285, 42.34240962613014, 43.540454449192175, 44.05331219396284, 43.01248773451775, 44.97636356661397, 43.19228526084654, 44.461442655132664, 42.96374836275655, 43.37553839529715, 42.50966341264787, 43.27555717960481, 43.334733978394546, 48.032329236307454, 51.418142703271684, 50.212064866096746, 52.43711171611663, 53.643679849563114, 53.76723450999106, 55.39399047051707, 55.22095903273552, 59.128020194269, 57.409892620578894, 62.52775023060461, 47.819532809718964, 30.065787146168372, 57.408590393681685, 55.48358917236329, 58.9105639919158, 55.68932925501178, 56.313048870332786, 56.59252951222082, 56.477337345000244, 53.89059697428058, 52.86989035144929, 52.94327397500315, 48.080766585565385, 49.15654720798616, 54.35362100601197, 53.22094248187158, 53.18493120131954, 52.3895529777773, 46.99314432759439, 42.590024932738274, 42.04378389543103, 45.262029786263746, 45.33071441035117, 44.48335693728539, 46.9003685059086, 53.39637048782841, 55.532909054909986, 51.80400586897328, 45.619961753968276, 57.32441240741361, 60.741989228033255, 58.28688360029652, 51.85643226869645, 58.39854563436201, 60.75140683881698, 56.18467753933322, 44.63270902633668, 45.71149026193927, 53.32421456613849, 60.603427579326016, 58.11955136637534, 53.91981078732399, 50.94262984491164, 58.106584010585664, 58.82853938687233, 60.3627940916246, 53.49007591124504, 59.41136437077677, 59.46960764546549, 60.036923577708585, 55.416755906997196, 56.744795922310125, 62.48892661063903, 63.89088761421942, 63.06802926524993, 69.26932396427279, 63.11486628747756, 65.24366209583899, 50.30829237353418, 52.82091955984793, 27.715930477265392, 2.760401103765734, 16.528397221719068, 28.10073852539063, 5.0482894720569735, 0.28735121471747277, 12.928733191182538, 63.08559756125174, 60.330885610272816, 57.723952877906065, 25.605083434812485, 36.82887900260187, 68.58203841793922, 71.4252233505249, 74.47929843779534, 47.54011884812386, 1.3298118234642091, 0.2210079085442328, 0.27513961998685715, 0.20963271328758812, 0.1303875518421973, 0.20685544537921108, 0.1275640581884692, 0.10311805462885289, 0.21296187093661678, 0.11788211642734467, 0.125566614160855, 0.17265191782386075, 0.09430602868838657], [0.03906919328015178, 0.050783776978571574, 0.028563078808327837, 0.048196353318710486, 0.13339433969268877, 0.011284380321270757, 0.14241628138528717, 0.059164901444267844, 0.018080791586168835, 0.055377673012234514, 0.024618237361972852, 0.03734882793299133, 3.4468749646217596, 44.86175975491924, 53.128147048334924, 52.7147880677254, 39.62665857807283, 27.67874248566166, 39.24488644446097, 40.92282933573569, 41.762746072584584, 66.03208203469553, 18.78340509630019, 0.024151471481027625, 0.13108158153631996, 0.8472727743848678, 2.5894627407673867, 3.3679522189401814, 5.105493318650031, 31.215125937615674, 61.687715822650546, 56.77256630313013, 59.891066320480846, 55.28165378878194, 56.86145505597515, 49.9204444885254, 48.654585807554184, 44.85413858967443, 47.38322011886105, 41.48901954773934, 41.133856773376465, 40.55729581463722, 40.4929454095902, 39.52965444134128, 41.96539924990746, 41.429230859202725, 41.64688318006454, 41.18756186577582, 42.479147372707246, 43.93672758533109, 47.41915687437981, 51.356969418064246, 52.908839487260394, 53.44232497676727, 49.59395816249233, 50.580077325144124, 54.741751301673155, 51.21033160917221, 50.69022140195293, 46.52661369692895, 41.54150086064493, 38.34765995702436, 40.4416839538082, 38.30110142307897, 39.44627269621819, 38.26888307448357, 38.643300764022335, 39.94618661942021, 41.09001644196049, 39.29021727654242, 39.788256306802076, 37.58849305491294, 38.18902361777521, 38.636150283198205, 39.30508698186567, 41.10428602464738, 42.61479470037645, 43.99675946081839, 46.043507129915305, 45.8599558953316, 48.637268543243415, 48.42613912397816, 51.89464399891516, 52.49573153834189, 54.54271454964915, 53.196588485471665, 56.06357043789279, 44.07114721113636, 25.258665584748794, 58.63286802845617, 52.22417800657211, 54.18264881257088, 50.30262454863518, 52.28797143505466, 48.44195804288311, 48.73266058583414, 44.37033384077011, 42.756549158403956, 41.093436748750754, 44.026738136045395, 47.54304101390224, 49.398298571186686, 49.62868682799801, 52.67623901367188, 47.419866823381, 43.259055768289876, 38.84804064227689, 38.93674112135364, 40.00853269330917, 40.522684820236705, 42.706358509679, 40.89654945558117, 38.86544419873146, 41.93092161609281, 38.94234226595971, 45.701437227187625, 51.5817290736783, 56.20492481416272, 49.70582808217695, 45.73115310361309, 55.347749648555634, 53.362245867329264, 50.10975768489223, 40.43840877471432, 49.13477805352981, 53.613834534921956, 56.192228101914935, 54.0784235923521, 52.46778465086415, 52.926184208162375, 51.053197537699056, 53.88913000783613, 55.26681546242007, 54.52303601849464, 56.001522464136926, 56.84658927302207, 54.9954855057501, 53.879402529808786, 59.139206794000444, 55.638024653157885, 56.46239311464372, 52.699126043627345, 55.432304182360255, 55.45313589034542, 63.02402027191655, 48.48898726124918, 37.30344656975039, 22.49466350001674, 1.1997102369223873, 9.241486557068365, 1.7156338042789891, 0.9413235502377634, 0.08470586681317899, 2.3728601442229365, 45.80521137483659, 45.17079545605568, 42.77933420673494, 37.76138720973846, 21.632608905915294, 35.800410009199574, 47.34846791913433, 59.54378751016433, 29.5403346707744, 0.6603794965532519, 0.07288970368643923, 0.04441775486714417, 0.052159460216400125, 0.015085190534591677, 0.023700619161489512, 0.018784498885994958, 0.06055737732939663, 0.05548849529136093, 0.09410368954582561, 0.08748378589629166, 0.07748992377591711, 0.06407002835804898, 0.03646376272363048, 0.03190519483459573, 0.04333282497921779, 0.0320249401228202, 0.14056840070313023, 0.04656610672452277, 0.07542978311257978, 0.02702322101310617, 0.02557943064358927, 0.031504831539707324, 0.031562770769420656, 0.08995901597964187, 4.713537731478292, 54.007126669729914, 59.4725808020561, 61.01685324022847, 45.447765781033425, 33.70665665595762, 42.12362766265869, 44.74414748530234, 43.480465719776774, 70.8693136707429, 21.292988523360222, 0.14938763553096404, 0.14432167994879908, 3.3350636353415832, 2.537936770146893, 5.787029650903517, 7.66012663802793, 33.93928458613734, 62.28835228950747, 59.22363581195955, 62.207476938924486, 57.83844686323597, 59.47810349925872, 50.64387467599685, 50.06897287984049, 47.253879962428925, 49.4831512051244, 43.81605978934996, 42.37837776061028, 41.6397483887211, 42.79503545453472, 42.55342921903057, 43.10726396499142, 43.19888268747638, 42.78875573988884, 42.5056351384809, 44.418406409602014, 46.682288646698005, 51.037868915065644, 55.080749988555915, 53.56421262987199, 55.20210027694703, 49.49995071657243, 50.5501849420609, 57.034663000414454, 53.60506019284649, 53.44709065652663, 47.64972948258924, 43.52112108661283, 40.51012931331512, 42.5729626224887, 40.9439395320031, 41.394874818863414, 42.17715232603012, 41.20569498308244, 42.550565888804776, 41.8210324933452, 41.915655751382154, 41.64145461974606, 39.631228139323575, 39.967163455101755, 39.71668481826782, 42.26425247807657, 42.534856796264656, 45.49184145465974, 45.096137062195815, 48.02149564989152, 47.996506229523696, 49.75267687151509, 48.83074729673324, 53.884717341392275, 54.44314126045474, 57.01664363184283, 54.823630779020256, 56.98780244396579, 43.650116074469786, 26.94845207275883, 58.63466447399509, 53.88385441995437, 55.64689705448767, 52.32658716940111, 54.4017602551368, 50.90548499937981, 50.53136148760396, 46.43554018389794, 44.627688392516106, 43.38577578144689, 46.894229996588926, 49.047764193627145, 50.50121022808937, 52.94464288219329, 54.976367873530236, 49.93765977121169, 45.24689335976878, 40.71247262339438, 40.64141496535271, 42.16219632856308, 43.53917967888617, 45.098831730504195, 42.4518515986781, 42.32101701921032, 43.144906951535134, 42.3335882156126, 45.74663862105339, 53.41249142923663, 57.58711314970448, 52.62028248079362, 46.16790509993031, 57.08102149348105, 56.09328239194809, 53.079419443684245, 42.71032794829338, 51.49500154679822, 56.548755861097774, 56.189431451982074, 56.46182437096873, 54.86170522628292, 53.630112371137066, 53.55884290510609, 55.729839494151456, 58.247318652368364, 58.01716181539721, 57.82257303114861, 58.82380900844451, 57.94500589370728, 55.52505254745484, 59.7954507027903, 57.35733678264003, 57.9299283027649, 55.14828928055302, 58.746452023906095, 58.68339992338612, 64.67423985081335, 52.889278627211056, 43.62060416129328, 25.803826009073568, 0.5115816874369499, 10.886753163030072, 6.193478395861964, 2.8139846026897435, 0.043638517043643424, 2.8109393725472116, 49.620810708692, 50.124313600601695, 40.51209442077145, 31.90672609113878, 27.125498056411747, 40.73197464789114, 52.082007777306345, 66.59227494270571, 40.559284456314586, 1.1688149528157328, 0.040448028969788746, 0.08948111501071723, 0.05086073817144479, 0.0342039680559068, 0.04819954790535474, 0.02522060846639497, 0.11359833661587009, 0.03333363854776948, 0.056589616447566986, 0.01844348250738075, 0.08042210998434214, 0.02482931565253004, 0.13537484551629714, 0.12514256917300726, 0.14272423340908943, 0.11340849236735415, 0.2373428336314617, 0.15108648146833145, 0.20160717619282587, 0.1411259135291461, 0.23622875792845605, 0.1501057050641506, 0.22819684698216378, 0.24493393758612297, 6.289901041215466, 63.20030335457095, 66.78829146969703, 68.93723257126348, 50.4166203929532, 36.5945016953253, 51.97557818505072, 52.7450373864943, 51.25766285004155, 76.0910552547824, 24.26892803561303, 0.23859668973713155, 0.2855148100324216, 2.3978863368111276, 7.6631860867623365, 7.418927838725429, 6.755068648246027, 34.24557070578299, 66.46449196723201, 62.09490099260884, 64.93951366793725, 59.754807103064756, 59.81721593487648, 53.905737323145715, 51.57425303612986, 47.95780028066328, 52.17197910431893, 46.021686984646706, 44.60916696056243, 46.19612655332012, 44.126021169847064, 44.32392043452109, 45.687642251291585, 46.33497061267976, 44.40550965647544, 44.37569964316584, 45.224339731277965, 48.945127533328154, 50.890909471819484, 55.72104161785495, 56.445248434620524, 56.91192811535251, 49.87022246083906, 52.77273324228103, 58.60904355202952, 57.27133489424183, 55.2877805309911, 50.21029587714903, 47.78388630959296, 43.23703165977232, 45.48582453881541, 42.34439434543733, 43.348983949230565, 43.351745297831876, 44.01773237412976, 44.89434680631084, 45.14824182756486, 44.178239683951105, 45.28624649970762, 41.503822572769664, 41.95875083246539, 43.81744830839096, 43.90252059505832, 45.20521817668792, 48.537812925154164, 49.62718063785184, 51.5321816936616, 51.261522462291104, 53.10396955859277, 53.505796770895685, 55.27344819038145, 58.483092323426284, 59.27935700262747, 58.11902184640208, 57.91559988452543, 46.82519628155617, 30.61340101303593, 60.71673308649371, 55.95406962979225, 60.429999982157064, 53.2935102524296, 56.56549261462305, 52.37125512092344, 54.03207686639602, 47.46857481618082, 47.27766129278368, 45.52245947622484, 51.067620092822665, 52.978332119603316, 51.96791779610419, 55.86892281809161, 56.01835727691651, 51.69690947378836, 48.124104853599306, 42.914350032806404, 43.05244491946313, 43.701730543567294, 45.48636974826936, 46.563644793725786, 44.793416377036806, 44.31739753292453, 46.44042745713265, 44.52893487868771, 49.10059459747807, 55.37497089755151, 60.6918691819714, 51.57041695810134, 48.898792574482584, 58.62525863032187, 58.96171954370315, 54.6204637712048, 45.06107499522548, 53.62150669097901, 59.211923614625015, 59.5507771738114, 57.354375393159934, 58.1653921065792, 56.246407801105136, 55.55197177394744, 58.491290077086425, 59.55427200563493, 59.30897481979863, 61.02974999335505, 62.96960915288618, 59.98405395015594, 57.22521566575574, 61.95843388957363, 60.3774872902901, 61.244103600901944, 59.680588014664195, 60.897719090984715, 61.07113884341333, 66.4877123986521, 57.523327565962276, 46.437050296414284, 28.97441706349773, 1.7750031669293682, 15.3192913147711, 8.396497214994124, 3.0553483866876174, 0.14645295187590585, 3.8251395187070294, 56.02172659289453, 57.003229125853515, 56.876065884867025, 50.73347730021323, 31.410375641238307, 46.93656806022891, 62.45480591251005, 73.93186892232588, 50.90953680776781, 2.2867339657199, 0.18079610661633555, 0.18682771602705603, 0.1427190699764798, 0.20991780524772985, 0.1128649989503526, 0.18400933984066212, 0.20113935694098475, 0.11352271607686436, 0.15497450025812273, 0.25359986289854974, 0.13518467184997376, 0.11391450110222064], [0.037793626242707816, 0.012661379315109264, 0.020119652242189454, 0.07537946645771304, 0.03261251615420465, 0.016365905682886803, 0.06226311039720332, 0.04623471241023752, 0.04566277414860745, 0.024951251952217954, 0.11989388629914292, 0.03277006213583293, 6.132414937019349, 49.96053895642681, 48.455015613186745, 45.1006438655238, 26.075944362148164, 20.979793148656046, 24.75672575735277, 28.388238453095962, 46.52584099000501, 59.904924054299634, 16.212063950877038, 0.13880693473883216, 0.22574685183503937, 3.840955495834351, 2.328567759644601, 2.8315394155440794, 18.890036690619684, 48.65928088465045, 65.05815359853929, 56.51212876842868, 58.99498516513456, 54.28017462453535, 50.63912468571817, 40.02055083551715, 42.23164973720428, 39.86618987975582, 42.10272142964025, 41.67726193704913, 42.54898517362533, 41.509027557988325, 43.79893472117763, 42.457072273377456, 43.826316787350564, 41.584015430942664, 40.53296927482852, 39.111486634900494, 41.404202215133175, 37.87462603661322, 42.31416071614912, 45.70346117019654, 52.725888375313055, 53.16624110744846, 53.91636302394252, 51.050436189097745, 50.893674742790964, 53.185284214635054, 53.019356189235566, 52.03424899808822, 46.16405333242109, 38.39990592771961, 40.2427884071104, 38.74871054003316, 39.849088345804525, 39.18028893009309, 39.206529586545884, 38.40962948337678, 40.639838172543435, 40.21134668780912, 40.944665170484974, 39.74539656792918, 38.97944396541965, 36.935563548918694, 39.402138187039284, 39.00845773758427, 43.30208024671001, 41.967748749640684, 46.3399951688705, 46.64677158478768, 49.44368823882073, 49.355513357347064, 52.54714988893079, 54.38911453370125, 56.78085427130423, 53.335307028985795, 53.133403024365826, 40.50943505379462, 29.03347619118229, 56.85355540244811, 52.267633945711204, 52.82199036690497, 48.96162109990274, 47.00980655608639, 49.643901701896425, 46.9189017049728, 43.750791549682624, 43.540756471695445, 48.0106738305861, 50.503630330485684, 51.74030265500469, 50.87251355571132, 58.34913553730134, 53.266116419146144, 47.48260905665737, 43.428815949347715, 37.840442580561486, 40.87594132269583, 39.298913171214444, 41.9247595725521, 40.64425083898729, 39.944558835798695, 39.864114945934666, 40.57835502009238, 40.463782587359034, 49.83994568547895, 52.898449128673924, 55.466817117506466, 44.923368423215805, 50.685632228851325, 53.6428169281252, 53.0646909436872, 45.77605247497559, 41.367151506485484, 51.57810872600925, 54.27636600309803, 57.4781261720965, 54.0896454934151, 54.73550688835883, 54.30421875369165, 55.158342315304665, 53.281146941646455, 56.258261203765876, 57.123057534617764, 57.177539256311235, 54.93277465143512, 51.06372517924155, 55.10671607909664, 57.03518467564737, 55.48055718022009, 51.87697764365904, 50.44954869054979, 52.6914813441615, 56.784231432022594, 58.23435914131903, 56.2205123132275, 53.99073116240963, 35.742621729450846, 0.09146862287795351, 10.995806820930975, 1.7186667770147326, 1.687359398891849, 0.1223704340537229, 0.74365901490373, 34.31274913972424, 53.18427224313059, 38.09086238184283, 38.44780198989376, 22.053134056829638, 31.827066675309215, 48.10766620020713, 55.03972199655349, 42.22368340338431, 1.9546370568775364, 0.14754689478826138, 0.05631179083138705, 0.04610330534858569, 0.150466762302864, 0.08163440582011977, 0.030297994080390182, 0.005212286994191668, 0.020925044307425138, 0.027803485394425453, 0.03078721399839607, 0.020679645277860186, 0.045030977607013724, 0.04439758760253749, 0.022707849650854067, 0.035264973017957904, 0.04521950801473953, 0.03177943767138547, 0.03614359542787556, 0.05497826924247127, 0.026936607112387018, 0.04442873290709911, 0.03451963458510657, 0.05822640543262805, 0.03874631020270529, 7.873687436503749, 59.44293552829374, 54.647277093702755, 52.89799413373394, 33.527694594475534, 26.917959567039247, 22.558033312520674, 30.923736979884488, 50.746236770383774, 64.95260261720227, 16.5763383911502, 0.21663397550582889, 0.27326098853541964, 2.2931982769120127, 6.521217919165089, 5.792770039650702, 18.896989091750115, 51.46196734520697, 65.97631377558555, 58.844628949319166, 60.24453855329945, 56.127924765309984, 54.12059299407467, 42.03391913444766, 42.93982190470542, 42.010231940977036, 43.27190153060421, 42.14589103575676, 44.482529317179036, 43.02043445648686, 44.18612364799746, 44.07234745640909, 46.071375569989605, 43.72629242558634, 42.29315250150619, 41.39721255148611, 43.19096342209847, 38.99403910483084, 43.934636962029245, 48.58601885457193, 54.10791589367775, 54.79145165412657, 56.164218456514426, 50.917789474610366, 50.75040624987695, 56.53955398067352, 54.9472991881832, 53.93130333192887, 47.4396591032705, 40.67359409024639, 41.48849787250642, 39.4930116591915, 42.19447351271107, 41.18032117043772, 41.293465860428356, 39.5204564832872, 41.375368871996486, 41.10507049868184, 42.15322586797899, 40.37256786900182, 40.55888829692718, 39.58675238393968, 39.88611944260136, 41.35399195455736, 44.807862466381444, 44.21083850245322, 48.70752603776994, 47.38883303057763, 51.230425911564986, 51.11245278389224, 53.67160320281983, 55.70435585514192, 58.869590913095784, 55.12829695978473, 53.77464778961674, 40.86658646983486, 30.418765160345263, 58.23500633239747, 53.54096474186067, 53.90855358492944, 51.86022520065308, 49.98168837639594, 50.31610573491743, 48.86220078314505, 45.45686175746303, 44.967887324671594, 48.599813830467966, 49.51542446690221, 54.73748376292568, 52.18938658314367, 58.3087900377089, 57.11862525632305, 49.335007206086196, 44.89859865557763, 40.53027852889031, 43.016331657286614, 40.561371157246256, 43.170057189080026, 40.76014903283889, 41.10808287897418, 41.973361661357266, 43.203397335544715, 43.08222355381135, 50.045517106210035, 55.06986933369791, 57.88749610224078, 46.27347961548836, 51.938452951369754, 56.22323051575692, 54.39580217484505, 48.202697384742, 43.74591212118826, 51.339554094499164, 55.53155975957071, 60.15921131257088, 55.971979171999045, 55.179201479881044, 57.13333414446924, 58.40231895446778, 53.82644268774218, 57.75997592556862, 58.64545099196896, 58.989693887772106, 56.47891413780951, 52.14649154293922, 57.288091259617964, 57.25536692527033, 56.85223748607021, 53.19082260131837, 52.465062525964555, 55.42498503961871, 58.793194909249586, 60.55920285563315, 59.13770060385428, 55.94473831115231, 41.21646188920544, 0.09374489992736809, 5.917212136330144, 8.789924671573024, 3.8266800295922065, 0.13204602494595513, 0.602380144259622, 38.16528935586253, 57.69575103636711, 40.56407759266515, 38.881804404720185, 27.212174592479585, 38.29114252521146, 55.948676370805316, 60.54453319118869, 52.40202611492526, 4.535602350388804, 0.2731602632951352, 0.07128559984266758, 0.06163409475477473, 0.09250134770427981, 0.05219880649219117, 0.014155294817511835, 0.06644620710322935, 0.04478009913357035, 0.04478363845978053, 0.0553149763765114, 0.04748874088569034, 0.05221677891489479, 0.15280023547670535, 0.09256921543349182, 0.09189220821304668, 0.1303901258976229, 0.09370576815619584, 0.13947087249928905, 0.14225785440254596, 0.08869154649155755, 0.1322239871707655, 0.08618067033709058, 0.20982801974300416, 0.1696837561265115, 10.043534771088632, 70.2718896250571, 61.66879430893929, 61.94084598172096, 38.352900243574574, 30.437706285907378, 31.4062395018916, 40.463645304403, 57.509140353049006, 70.73672186943793, 19.661784595058812, 0.4609471060816319, 0.40682241200439395, 9.086952036426915, 7.566598701861597, 6.279496954333398, 24.560868086353427, 51.953820797704886, 67.86316994697818, 60.94860399923017, 63.7078502101283, 58.98410058790638, 55.914771403035815, 43.553060946925996, 45.26066872381395, 44.80699562257336, 45.70161765621555, 45.71893492052632, 47.226172339531686, 45.943655352438654, 46.98332271268291, 46.02782549396638, 49.07049040640555, 46.48535428508636, 45.060537630511874, 42.84495153734761, 44.96067800829488, 41.46486951458839, 46.0792399221851, 51.28994787892988, 55.743175552737334, 58.75694436411704, 59.333458254414225, 54.04329092271867, 52.57253546868601, 57.32151377585627, 55.728803988425966, 57.96875192273048, 49.315042341909106, 41.401633062670314, 43.35857022193171, 43.14006282437233, 44.27368271735407, 44.201260074492424, 42.53264457948747, 40.19686529713292, 44.87028698767386, 43.88132018427695, 43.45595875094014, 43.275600325676706, 43.62709176155829, 40.904033337869954, 42.73942016786145, 44.302359165683875, 46.526295984944994, 48.31512820336127, 50.586549235928445, 50.17570841696955, 54.54774302821006, 53.49253915971326, 57.33611283763763, 59.230519571611964, 61.20561730477118, 59.279282477594194, 56.805392619102236, 41.627118356766246, 34.94766319951704, 59.86952074112431, 57.758469735422445, 56.58010344351492, 53.17501544952393, 51.111887962587424, 53.03817179895217, 52.12807993735037, 48.89252462694722, 47.36115678664177, 51.531742388202304, 52.71554508516866, 56.119487747069336, 56.495701882147024, 59.52970227887554, 57.90077724764424, 51.35091720088836, 46.73912379049486, 42.958562989388746, 44.677604475329005, 42.5653689138351, 44.73191753510506, 43.98600432180589, 43.21152056417158, 44.91207199711954, 45.13053232623685, 45.25312208360242, 54.25500869750977, 58.876019677808216, 58.443091992409, 46.89397112015755, 51.58416878792548, 57.69394282371768, 57.065916445947465, 51.503163999126805, 46.62506911062425, 56.044758750546364, 57.87853348639704, 62.664715474651715, 58.82258130658058, 59.90676364591045, 60.299957721464104, 59.12312899866412, 56.02050673577094, 61.37651889554916, 60.74148324228103, 60.592052705826305, 58.76322015639275, 53.3609514851724, 59.02652494369015, 60.43665232196931, 59.22241987720613, 57.674942862602975, 56.08349215599799, 59.83873013527163, 62.3634696006775, 64.66142546746039, 63.08074166697841, 60.200247149313654, 44.15245010006813, 0.8248464390635492, 18.090496832324614, 14.243727403302348, 4.720103779146749, 0.3362684414511727, 1.1087026687399035, 43.53860309047084, 66.02679467970326, 53.216533737797896, 52.68193429516208, 32.47093746739049, 45.71858190721082, 64.4748265512528, 69.77204630451818, 62.00172901153565, 6.944618657712014, 0.4192937718283746, 0.16953787766397002, 0.292990755650305, 0.23317945219816702, 0.20730265686588906, 0.15622032776234612, 0.17624840951494633, 0.1168082143750883, 0.17486263306871538, 0.15617111427409036, 0.16393840312957764, 0.12495801093116884], [0.07511609309022466, 0.03393817002013807, 0.039979841995743975, 0.021376588021314914, 0.03234987823112357, 0.10761230177576504, 0.04947550181720046, 0.08206034304514047, 0.11556951148856072, 0.05248907720670105, 0.03665007913725511, 0.07107225201663471, 10.651991463476612, 53.328548785178896, 50.31234810429235, 47.57540056782384, 25.596697407384074, 28.636397007972967, 76.12372075357746, 41.549498573426284, 43.180757414910104, 60.522367877344934, 9.521737944695259, 0.11549397521922666, 0.17980941601337927, 4.887452192844884, 2.008134018509619, 3.733201368201164, 26.157423757737686, 58.69558280514133, 58.081637736289736, 55.3847768229823, 54.48225513581307, 46.541840337937884, 43.004525323067945, 40.343103024267386, 42.786680806067686, 41.76706852451448, 41.38834799489668, 39.24263892635223, 40.83720007250386, 41.4591585436175, 46.32627864037791, 51.275925405563854, 51.6001759805987, 50.99650752159857, 48.77364543176467, 49.09427958150064, 45.30511310023647, 42.356565460082024, 42.3010717668841, 39.1294236336985, 44.470566088153475, 48.583947843120946, 52.73822815187516, 54.153399698195926, 51.76522147270941, 49.25812482833863, 55.31399373085269, 53.546358000847604, 50.53808443007931, 41.55267961563603, 39.001609279263405, 38.84336125466132, 39.42871224495673, 38.759257793426514, 40.7949443786375, 39.40710390767744, 39.538499386079856, 39.94454314631801, 41.489435318977606, 38.766416118990996, 39.249616822888775, 36.83553134241412, 37.32864387573735, 38.65496981528498, 40.59918280570738, 42.23203805185134, 45.036340528918856, 46.48315383541969, 50.24840954811343, 51.956209521139826, 55.278076587184785, 54.63736918664748, 52.73148951991912, 49.19855187016149, 47.52460195172218, 41.079351517461966, 31.725602803691743, 56.43400692170667, 52.7517250276381, 48.119327406729425, 45.19041907402777, 44.509134754057854, 45.4648712373549, 42.86994488008561, 43.57673245091593, 48.11118848862187, 47.63857818418934, 53.92157585390153, 52.69934569635699, 57.11483232436642, 57.00687300774359, 47.87696415378202, 52.371247276183105, 39.720740549026, 39.59178478487077, 40.896239588337565, 38.95651378939229, 40.51349470692296, 41.63367263732418, 39.98717146535074, 39.412548157476614, 40.974098636258034, 41.09522534954933, 49.1775671897396, 54.585699804367565, 52.12081570779124, 45.746242461665986, 54.710015404608946, 52.90776475783318, 51.274140727135446, 43.57134311429916, 44.00071713232225, 49.97098030582551, 54.85490383640413, 53.59750963026478, 54.355021292163485, 49.04577162957961, 50.960005944775, 51.32162101807133, 56.16967447342412, 52.7356158533404, 51.64937819204023, 48.9035229529104, 49.984524250030525, 53.435339235490375, 58.64410954137003, 54.848651578349454, 52.658815845366455, 46.46302030932519, 51.16714239120484, 50.47905668135613, 55.90476543672624, 56.598566039916015, 59.57236197686965, 54.815484016172356, 56.45721950838643, 1.7256707818277421, 12.096504299871384, 5.816740134069997, 5.603487731948976, 0.32851302695851176, 0.20020258462717458, 28.75015162652539, 52.74133074668146, 37.61039164758498, 33.822801959130075, 17.640767674292288, 24.12897394549462, 37.38688715042607, 53.69195245927381, 44.62124393832299, 8.855199775388165, 0.41809570224535086, 0.07063896800842016, 0.12491078927151619, 0.015342265701732569, 0.00980141125769625, 0.03855883316587537, 0.0424682104869956, 0.03466181284297378, 0.06025487602117562, 0.03603531656065776, 0.054942718932345036, 0.019370699789555326, 0.011774560722011712, 0.04818526802644615, 0.02968773801600741, 0.024611639429724986, 0.04288010148992462, 0.14526939199816796, 0.06676070151790496, 0.05268138442789355, 0.024376737719942487, 0.03708878704797357, 0.08443906903266908, 0.025587039811897184, 14.49976109689282, 64.20486550177297, 55.674181061406294, 57.69714740014846, 32.20170793994781, 26.492231392091323, 60.459802150726325, 41.855894519436745, 47.48911234640306, 67.13677052528628, 10.680351180415, 0.1451775993430807, 0.4104134338277002, 8.306123845038876, 5.762986502339763, 6.137422823136853, 31.197724342346195, 60.828222536271625, 61.530526837994984, 56.94429551401446, 57.43447019207863, 48.38836669921876, 45.51635626823672, 43.31037605962446, 43.39573075694423, 43.30257054298155, 43.08349832411736, 41.07911617525163, 43.46570976318852, 42.6822712344508, 48.452501373906294, 51.37878564096267, 51.9749153044916, 50.90708924878029, 51.25590170583418, 49.73033112864341, 46.972853906693004, 41.88378649373209, 44.26997607754123, 43.03496291560512, 46.87366500977547, 50.457558170441665, 54.20529657794584, 56.744133041751006, 52.652685180787124, 50.43186272344282, 56.05707891525761, 54.97741122399607, 52.111511845742505, 42.876926698992335, 39.75836784608903, 41.29228130463631, 41.0139028487667, 41.04053181986655, 41.861028901992306, 40.439965955672726, 40.25807780604209, 40.97417708366148, 42.38696382891747, 41.4866308243044, 40.40624533930133, 39.56413599752611, 38.93658030417658, 41.37743203870712, 42.83696559167678, 43.130680514920144, 46.200876543598795, 47.817728519439704, 53.216110121819284, 51.662545588708696, 57.27943066627749, 54.97701898697884, 54.1066332786314, 50.57209137947329, 46.52739032622307, 40.89513347994897, 35.00224690283499, 58.273418103494954, 53.63670195302656, 50.921182324809415, 46.7273017667955, 49.17538635192379, 48.103943870913604, 45.30306170063634, 45.60249151722078, 49.16351725978237, 50.4618884671119, 54.6425231810539, 52.86004520231678, 55.09292502557078, 58.22544359391736, 51.78724558122697, 54.15727892229634, 42.17852515559043, 42.43991582624374, 42.24001615278183, 40.851885426429014, 42.149578063718735, 42.727758961339156, 41.046568347561745, 41.8713447355455, 42.48940437070785, 43.62981780882805, 52.993774490971724, 57.74675753808791, 54.492727864173155, 46.69744076267366, 56.21066716409499, 54.5048205314144, 52.63401077639673, 45.01566963811075, 45.25534214511995, 51.94350496415169, 57.14009631064631, 57.02722226419757, 55.44447529700495, 52.18611924879013, 52.42775686325566, 54.61350548651911, 57.70813395900112, 53.220903258169855, 53.66504499989172, 50.84399792455858, 51.17635996110978, 53.25772646934756, 59.363585979707786, 56.113086438948116, 53.9844592925041, 49.81030041171659, 52.401061211862874, 53.007804809078095, 58.83889836649741, 58.962739359947946, 62.65762775175033, 58.414988210124356, 59.64237236207532, 3.2356658722123797, 8.520589240135687, 10.653512362510929, 3.125687270395218, 0.3177734548526426, 0.06511204200045717, 30.688337895178027, 58.880855960230676, 44.001187816742934, 37.5116499008671, 21.577279952264604, 27.237783747334635, 44.145793837885705, 60.40139021412019, 56.55865984578287, 12.832082067766498, 0.4728326844351907, 0.017831341866704247, 0.060543779268740654, 0.02342420123187044, 0.018248202865042033, 0.04961605596866819, 0.0542881197836851, 0.052270814926633914, 0.04108732551216118, 0.09027937862781749, 0.056465433595041116, 0.014348192884015941, 0.2073506292917075, 0.09741931042123227, 0.07466730346242267, 0.10690617555331801, 0.12169451467813024, 0.25005149685086747, 0.2474766446938438, 0.17779131059444722, 0.19068688394561892, 0.19049097994162192, 0.21759972126493532, 0.11330892391983541, 19.165102704878777, 74.2442935512912, 61.7163569696488, 67.02246481372465, 34.999387494979366, 39.36009430116223, 83.83354725376253, 54.357810097356, 51.808006686549035, 73.52611541748047, 12.70538656942306, 0.26904110045683, 0.4047019725605365, 12.441743477698296, 5.9428825782191375, 9.781171352632585, 31.215757439213416, 61.817573731945416, 64.59649847399804, 59.91921324883739, 58.864774242524184, 51.97895142339891, 46.13205855892551, 45.03690927259384, 46.51650182662472, 46.110630650674146, 46.993285532920595, 42.34900705275997, 45.49296325252902, 44.30836431441769, 50.98867454836446, 56.653906760677216, 54.329259164871715, 54.70417499542237, 54.68270394109911, 53.194819496523955, 49.044394877649125, 45.60912032281199, 47.088716799213046, 44.71941694136589, 48.57853497228315, 52.56186269944715, 57.62936492120066, 59.933996662016845, 54.77638583029471, 49.4944005627786, 58.717657904471125, 59.26555418199109, 56.829052355981645, 44.76917612937189, 42.44879607231387, 42.66768393977996, 41.97050225350165, 43.683934750095496, 43.75003845460954, 42.71914543644075, 43.71502345608127, 42.241483119226274, 44.5562816435291, 44.00030136108399, 43.14344782983103, 41.05768434463009, 42.275015461829405, 43.45333468529486, 45.24733658759825, 46.683379065605905, 48.82742112682712, 51.005685867801795, 56.07567487224456, 54.75613855546521, 58.80604067156392, 58.52558335950298, 56.47457599639893, 51.51465262136152, 48.869680743063654, 42.00692930529195, 36.825650891950055, 60.286888384049945, 57.49742031097413, 52.53051903940017, 48.929292924942516, 49.3530854102104, 49.928473580268125, 46.62610069397957, 47.52673179872575, 52.000547993567686, 52.94088917393839, 57.07473393409484, 55.2967353020945, 53.72278621119838, 60.32868516060614, 54.30390104170769, 55.51983971749583, 43.70747681586973, 45.380336315401145, 45.315013162551395, 41.31812972407187, 44.690783639107984, 44.1205612305672, 44.473707906661495, 43.649708147971864, 46.06429176945841, 45.89888541929184, 55.3664436647969, 59.50386954892067, 55.68527744662378, 45.76361463915917, 58.60610961914063, 56.650094216869725, 55.258390211289935, 48.524939706248624, 48.17663323494696, 54.27589139630718, 59.9944443087424, 57.961766181453584, 60.11169964267362, 54.12842988967896, 54.594560438586825, 56.19728403706705, 59.34229535441245, 55.74860803542599, 55.200166548452074, 51.14764428907826, 52.53319409585769, 55.10902635512814, 62.48469829559327, 57.15737827362553, 57.15430313541044, 50.91107437687536, 56.1155967558584, 56.44956696418024, 60.2938505911058, 63.62204051786854, 65.75784167935772, 61.567322592581476, 65.47339139446136, 4.316519345006635, 19.92256141478016, 14.353635157308272, 6.997782953323857, 0.9536540724577444, 0.28720397261842606, 35.99477914071853, 63.75542071557815, 52.357060063269834, 47.15691897176927, 26.651171715028827, 32.698438859754994, 54.47153137576196, 65.4570351108428, 66.42766091131395, 17.139967295431322, 0.5659129494620908, 0.17859279178082946, 0.15243490346737448, 0.15851923504904394, 0.11841088563444153, 0.19382062788692214, 0.14928341692974492, 0.2051332490819116, 0.13975386537851828, 0.14350529069141035, 0.13772796118451705, 0.2176128213684405], [0.04968938973521994, 0.0795396609652427, 0.053864113100233584, 0.021048742609338898, 0.042721559593994776, 0.02958312104906767, 0.017933844430972973, 0.016938037381717758, 0.031008354853838686, 0.12464020701666033, 0.06970440202783193, 0.04166525075091951, 15.544077446383817, 56.013677889300936, 50.47414587390039, 42.79617294188469, 23.71671126734826, 40.518731071103005, 42.36998388844152, 33.206374029959406, 49.90193482368223, 53.7057670470207, 6.98819471943763, 0.16826039540671534, 0.5414961338523896, 1.5471719277481881, 8.341650712874628, 7.418403712011154, 47.991607189178474, 62.165170254245886, 57.71676317338021, 54.005789141501154, 48.69957147106048, 42.739667277182306, 42.8114741079269, 45.485667644008515, 47.63489900096771, 48.66993796440863, 44.66406837586434, 42.09926974388861, 41.33117944963517, 43.57335529019756, 47.62100204344719, 52.61884297094038, 55.156628239539366, 53.06070581559212, 51.88913306882305, 52.415872081633545, 51.64358485129572, 49.468720805260446, 47.98518626920639, 47.2709854187504, 45.45063695599956, 45.47200210632817, 48.488724462447635, 49.156782550196496, 54.55371287561233, 51.126149700533965, 49.20826758107832, 53.62005149164508, 51.4543265681113, 43.958775228069676, 38.52068747243574, 39.4249899156632, 37.600746539331254, 41.22910368827082, 39.675260666877996, 40.330896608291134, 40.3974082393031, 41.11387621971869, 40.68760087413173, 39.038389344369214, 37.48608389208394, 36.62467648906093, 38.767847784103886, 38.40743687845046, 39.34330655682472, 40.45063480254143, 46.56752009545603, 50.54239903726886, 53.5201761799474, 55.1192323623165, 50.79849058581937, 47.87622674818962, 53.10298112130935, 53.1688847849446, 52.89779409285515, 48.35675631800006, 34.274780596456225, 55.238994090787834, 53.68968140694403, 47.86259651184083, 42.06788293776974, 44.66974012313351, 44.110472894484, 46.35401764223653, 45.84508619000835, 50.68513408783944, 56.23914357154601, 56.63487149823097, 54.287383940912065, 52.102972845877375, 44.029981936177904, 51.98117932965679, 50.18718134972357, 41.612146669818515, 38.50705331371677, 40.38537048524426, 40.67093864563973, 40.956730381135024, 39.14931005047214, 39.44826526026572, 41.903872951384514, 39.961511319683446, 41.95759765563473, 50.26479328832319, 55.567692633598085, 51.6637497563516, 48.44813969827468, 54.96305927153557, 51.1005562351596, 50.04668205015121, 42.61215102288031, 42.45264783982308, 48.39972196086761, 53.92818897001205, 49.92554356974941, 47.5392206253544, 45.184766938609464, 49.351842018865774, 52.43603306431925, 56.03319560327838, 49.05593449069608, 49.969015198369185, 50.90673623546478, 58.325758211074344, 55.67922130707772, 56.544837413295625, 51.062505322117964, 49.266644216352894, 46.27252647953649, 53.760774366317264, 53.397723705537864, 59.037405598548155, 53.383210935900294, 64.46794671397056, 56.43804304061398, 68.28146719163465, 10.049249664429697, 8.000668287277222, 44.63422698359336, 4.045522544653186, 0.7339823438275246, 0.17281630497065284, 17.453962833650653, 56.790773945470015, 41.21005665871405, 39.41385822911417, 25.414605294504476, 29.395571754824733, 42.26190297834335, 51.14646757802656, 53.09946667763495, 12.556982713360942, 0.28063182689009175, 0.03714065120044736, 0.013221127202644224, 0.01240139397146601, 0.04789255732189744, 0.03721886494707677, 0.02348368604397101, 0.04269065177668968, 0.009332677488395525, 0.050622327778969085, 0.00947393452553379, 0.014428004881577387, 0.019713790351224524, 0.027446015362417506, 0.014168946504322513, 0.10990183214626967, 0.016821404325685674, 0.09352271910756828, 0.05269383718710273, 0.014900163063899645, 0.006661665496311241, 0.012306240105610943, 0.12160988494513497, 0.040937356140104034, 21.569637213983846, 65.9551957345778, 57.39721944255214, 47.040228459142874, 28.54008713076192, 42.89427926463466, 58.77769762469877, 39.49025031059019, 49.974471215278875, 61.98798110408168, 7.587293617187008, 0.13283920173923816, 0.7194041809247387, 2.949668702579314, 3.3488343415721773, 11.950100852597146, 51.57751252574306, 64.37692026938161, 60.12125453641338, 56.8690840659603, 50.4387660949461, 46.02033768930743, 44.55167285857662, 44.975300604297274, 49.17078933408184, 49.14956931144961, 47.517310265571844, 43.69423881653817, 43.10792292318037, 43.653308883790054, 48.66282278491605, 53.11081017217329, 56.464856363111934, 55.483420510445875, 54.98824481041201, 54.41311551678566, 54.491833563773866, 52.838676129618, 50.970278632256296, 48.48461381850704, 46.50917483914284, 46.52654701663602, 50.39886382318313, 51.64182370708835, 55.84119166097334, 51.146440121435354, 50.31803161867204, 54.643272353756814, 54.421983995745265, 46.2994457060291, 38.76988349422332, 41.244087142329064, 40.39436448004938, 42.65756422473539, 41.10037934395575, 40.48337090399958, 41.613127262361594, 41.35869095402379, 41.09021648283928, 40.91516894678916, 39.40982211020685, 38.18006100193147, 40.45882078909105, 42.336682965678555, 41.98008852620279, 43.574594759172015, 48.82142382283365, 53.95504151621173, 56.49665894046907, 55.07785920173892, 51.91611113086824, 51.21910987361785, 53.410365504603234, 53.84809417109336, 55.40320411805184, 49.02158629509711, 35.413142634976296, 55.69053734502485, 55.987778479053134, 49.377568844825994, 45.20967791157384, 47.16945094446982, 46.28316786981399, 48.006567109015684, 47.58651264252202, 51.12077605339789, 56.64488138691072, 56.45354816990515, 56.36139600507675, 54.42625545686292, 47.30308217387046, 52.91311094837805, 52.76456686758226, 43.578626955709154, 39.80432625739805, 41.82792017536779, 41.17218225233017, 42.793066424708215, 41.31405438146284, 40.89002655398461, 42.552487850189216, 41.245063812501975, 44.10321258729504, 52.028808670659224, 56.05207004854756, 52.502623142734656, 49.74349068057153, 56.7742411551937, 53.86938087401852, 52.52824014233005, 42.83976616397981, 45.13694147909842, 50.750869089557284, 54.72002921565887, 51.74475846752044, 49.337737175726126, 46.09520396878643, 51.72442097817698, 54.87486870058122, 56.5687717160871, 50.41655371266027, 50.52071225258612, 51.50799243680893, 58.01453774975192, 58.529195862431685, 57.649965209345666, 53.05419468110608, 50.28946891907723, 48.504770878822576, 54.79877864160846, 55.13333328308598, 59.962700566937855, 55.84838136549919, 66.36793105832993, 59.5531149064341, 70.4943193927888, 13.053050752609009, 6.358700394630433, 39.62713710723385, 3.638885035630196, 0.5968591018069176, 0.04475602865098946, 19.701237755437052, 61.44190872869184, 45.903345154177764, 43.39787629342849, 26.46830101167002, 35.67912247873122, 49.00963483318206, 56.96999488338348, 62.09696023694931, 16.61153970226165, 0.35489384685793235, 0.0750859781739212, 0.07270433339140109, 0.032605058288261775, 0.07223080678452408, 0.021625660442476793, 0.049587450245575565, 0.052612187536132914, 0.04064717735614508, 0.09119190425882417, 0.042778445452812223, 0.013217951768198082, 0.1523012517681045, 0.15953834649295578, 0.10645539409691289, 0.1754645023855471, 0.12530520197845277, 0.24116852350773352, 0.10379190556705, 0.11209272869652319, 0.1088477794321314, 0.24374990273387204, 0.2766904577372536, 0.1709901811855455, 27.70735029251345, 76.33829793622418, 64.65769529342651, 56.04508822964084, 32.97509539511896, 51.065894249946844, 51.63967424823392, 43.27355677081693, 59.873725521949034, 66.18006521655668, 9.811093153492097, 0.44027878932895204, 1.448204767319464, 5.673673643219856, 13.99609934899115, 14.8314739811805, 53.693992091763405, 67.0684899053266, 61.74709266231906, 58.034126066392474, 53.16542917682279, 48.32918990042902, 47.853959452721384, 50.33507039470058, 53.338872463472434, 52.694011272922644, 49.092475291221376, 45.224433868162095, 43.41080442551644, 46.85666153507848, 50.61726923911802, 55.47816453441497, 59.8191967318135, 57.52294709605556, 55.93349679823845, 57.536918578609345, 56.69176939995059, 54.45947400985226, 52.61666213312457, 51.689468737571474, 51.048294574983665, 51.05108338017618, 52.10454963868665, 53.644087776061035, 57.16919637495472, 54.821583301790305, 51.37459654961863, 56.6145496983682, 55.32211303710938, 47.85628149586339, 41.53808447622484, 42.65750931155297, 41.525395608717396, 45.77067098309917, 43.93174225284208, 43.38175927439044, 44.19168949127198, 44.5059262552569, 43.66815505489227, 42.29950674118535, 40.69641443990892, 39.6418656072309, 44.10832735799974, 43.36368891500658, 44.200236335877456, 46.00095725828602, 51.574778633732954, 55.15534954686319, 58.96584587712442, 56.99041866487073, 54.131336365976644, 54.957897432388805, 55.20748569119362, 55.93983142606674, 57.11634243688276, 51.00970237485824, 38.82975455253355, 58.956981320534986, 58.40697873023249, 52.60217289770804, 47.35273938025198, 49.87816133806783, 49.39503123683315, 50.1280673088566, 49.63014202733194, 55.00008252359206, 58.35416401586225, 56.56504154205323, 55.336213957878854, 56.45867863009053, 52.411220150609175, 54.18286846530054, 55.51599579472696, 45.698409157414595, 40.88815558341242, 45.0494530124049, 43.69532139070573, 44.88425454785747, 44.320617798836004, 43.432416685165904, 46.1356161486718, 42.45783713556106, 47.65957855409192, 54.03943915520945, 58.965288900559955, 53.23001884645032, 49.79528165632679, 58.32365582066198, 55.515238777283706, 54.85074612402148, 45.358249448960834, 48.559197687333636, 54.49610894726169, 57.68249734755486, 54.08927286824873, 52.64491888784593, 50.138453745072894, 54.51288492448869, 57.79728551064768, 61.04238394768008, 52.66449543737596, 50.35666696486935, 53.87431129332512, 58.74827592603622, 60.06284652217742, 60.340020810404134, 55.816963180418945, 53.375507400881865, 51.48288534533594, 59.30955533058413, 58.382738482567575, 64.37038560067454, 58.85322678473688, 69.92535606507333, 61.11711294420304, 77.6438274691182, 16.833128121591386, 11.356443262869313, 57.42038888316001, 10.637206089112068, 1.511745815796237, 0.2749085985124111, 23.42265117552973, 67.73805418322164, 54.2095523495828, 51.28381329198038, 35.327693800772394, 42.20442848820841, 57.58836046341927, 65.51032443200388, 72.5302020965084, 23.223592850469775, 0.6003491532418036, 0.12891508488645478, 0.21715122275054458, 0.11463068605911349, 0.19337894755505747, 0.1944049997555633, 0.2085701186930941, 0.27277271473600023, 0.09703104173944843, 0.23013538650928006, 0.08500659462785529, 0.14586733894482737], [0.06353445629018449, 0.0354631484726504, 0.022369376684148467, 0.10846171708356951, 0.03926577527196177, 0.09210816073802211, 0.06078975860990825, 0.07190217804764548, 0.06275090922210967, 0.020411661976287444, 0.036304362809225436, 0.14949456608343512, 28.33475889698152, 54.61532154390889, 46.63119193046324, 46.860501535477184, 23.60769683314908, 36.203464923366425, 37.95036308227047, 34.85776639753772, 56.69856294508904, 51.220549383471095, 4.404853082472279, 0.2475953576785903, 0.9347132533307999, 9.635306250664497, 5.928433547096868, 16.83577964382787, 58.982229617334184, 57.122484868572606, 57.5091128964578, 48.27495921042658, 45.383136887704175, 44.0840204300419, 50.09972426199144, 53.84578781743204, 56.56330785443706, 53.728469725578066, 54.97801919137278, 45.29780572460544, 43.27103076442596, 42.68282036627493, 47.24836118759648, 53.258216765619096, 55.59702411774666, 53.94248993166032, 54.494779263773275, 53.59021794411444, 54.466946125030525, 53.152124497198294, 54.32063387286279, 53.09196318349531, 50.654633737379505, 47.55446295584402, 47.89618376762637, 49.77855274754186, 52.291454499767674, 52.338785740637014, 47.32639281980453, 50.482641727693625, 52.70006349009853, 45.929122970950225, 37.4258598204582, 40.153287764518495, 37.606535957705596, 41.45444385467037, 39.82780556524954, 39.76027411799277, 40.05798985881191, 40.56121818480953, 38.760999325783025, 37.43413209915161, 39.217363172961825, 37.66788967194096, 38.79843050433744, 39.640300581532145, 38.63653467547509, 41.37987567532448, 48.6068505625571, 51.20786051596365, 53.329211665738015, 49.37305811912783, 51.06880072624453, 53.97120952606202, 53.8263407061177, 53.07895268163374, 53.665213661809126, 52.17217914519772, 39.03349814876434, 52.83227089912661, 53.10906079507644, 45.92534180610411, 42.7677357581354, 44.20023241350728, 47.32003073538504, 48.0940398862285, 50.850724789404104, 58.16005768314485, 52.72086381912232, 49.62439183265933, 50.19764623334331, 50.74988065227386, 53.95267240462765, 55.3452746329769, 50.175410316836455, 39.4785185014048, 38.956168620817124, 38.79530045293993, 42.526000084415564, 41.5618932631708, 39.6924602600836, 40.01986049836682, 40.72551058184716, 41.23113547602008, 40.61068319505261, 48.2842513053648, 54.89787732401202, 52.00488613497827, 50.34473119243499, 55.422517868780325, 51.69232422305692, 52.560034874946844, 44.526138228754846, 41.660956644242816, 46.75928085081039, 47.98443317413331, 46.78331321285617, 41.029937498031124, 43.81033705126855, 45.887942006511075, 53.27956230409684, 52.5307700710912, 55.71127491612589, 59.09641373542048, 57.747020336889456, 57.10987052609844, 54.794769979292354, 52.09237460167178, 46.24857648726433, 46.32518429909983, 49.34512692113077, 53.69916177565052, 52.83972732482418, 55.356888771057136, 57.55565966329267, 61.772968538345836, 61.34995660474224, 66.47214058906802, 30.708895037251136, 1.912630188368982, 16.771174284719653, 4.579008279308196, 0.2908689066046669, 0.04938199312516278, 7.618456848206059, 58.861153894855136, 42.862786554521136, 40.01891128478512, 23.424592748765026, 15.928487373936562, 34.170414170911236, 48.98326473851358, 54.448695336618734, 17.38935943572752, 0.263276748479374, 0.050574340031392155, 0.049272553634739695, 0.05105236740482431, 0.023275593581098705, 0.058702169016243956, 0.03813524016990297, 0.026802390423272888, 0.007061548071027163, 0.05742749447123178, 0.0842329147722452, 0.06309141998269385, 0.06866715728275238, 0.03480835397156977, 0.06568969527800238, 0.07094523463878902, 0.04574389902934913, 0.057428053715416504, 0.022703720436942194, 0.04987556442257859, 0.028200860946409168, 0.04565307930592568, 0.011685038560010012, 0.2706685776431715, 36.382748619202644, 62.13206937236171, 52.2577299610261, 50.7147087589387, 30.72993855322561, 39.79861136405699, 37.34790271328342, 35.34471296495007, 58.64821234057027, 57.50446488780361, 5.346597490772124, 0.2188898592946991, 1.3740203673801115, 4.863869922776376, 5.296345555013226, 19.417866122338083, 61.97464896786598, 60.637779697295166, 61.51866951296407, 50.83975784240231, 47.43194772351173, 46.08910860553865, 53.129268846204205, 55.6610881897711, 58.23924641455374, 56.02011057638354, 58.51674233713458, 47.33818346454252, 43.9729545962426, 44.5237926513918, 49.69304900015555, 54.85722980191631, 56.845557689666755, 56.385079276177194, 55.591940726003344, 54.480227270433986, 56.117440269839385, 54.981306137577185, 56.4005216475456, 55.09442337097661, 51.92150831222535, 48.78601266491798, 50.79463097356981, 51.42292799488191, 53.52189417808287, 52.17253215851323, 48.30005845715923, 51.70698996513121, 55.057219689892186, 47.24778852155132, 40.298038913357644, 40.8873083514552, 40.22810697555542, 41.55479769552908, 40.70699307226366, 41.442009941224136, 40.61124409398725, 42.029722198363274, 41.02433243105489, 39.78485953423285, 42.37938973211473, 39.16341881598196, 42.1239806759742, 40.344118918142016, 40.95771489604827, 42.93776658273513, 51.31438424510341, 51.90935288706134, 54.33587620335241, 51.020606563937285, 52.33252171547183, 55.26817260249969, 55.91366921701739, 54.38924397191694, 56.18159455637778, 54.734334099677305, 40.27010771536058, 54.335680084843794, 55.19382407588344, 48.30873081761022, 44.76570090939922, 46.860501535477184, 47.84806805272257, 50.337914113075506, 51.41529506252658, 59.48615220285232, 57.028332294956336, 51.72154980321085, 54.15347030085903, 52.3355144839133, 55.11893426218341, 56.47204999000796, 52.40871767843924, 42.207605608047984, 41.412309754279356, 40.596244950448316, 43.00600013425274, 43.772290060597086, 41.11954796698786, 41.75221058630174, 41.921554996121316, 41.824393964582875, 42.02203043045537, 51.539520448254, 57.53560458460162, 53.71933060307657, 51.03124795421478, 55.41403770446778, 54.226410696583415, 52.807073593139656, 47.671930097764545, 43.25052853553526, 48.13853525346326, 51.608601231728834, 48.52607327122843, 43.66309519736998, 45.49266515239593, 48.84322827862155, 54.09622330819407, 56.5908742720081, 57.35928620061567, 58.131326321632635, 57.29141350715392, 59.181242835137155, 57.272727335653, 54.35205598031321, 47.051811218261726, 50.26379700629942, 52.16721342455957, 54.88669856902092, 54.96946057965679, 58.24038390190371, 59.36313490713797, 64.42134503395327, 61.96130114216959, 72.84102639844342, 34.64976702966998, 1.6685099587325127, 18.45483991407579, 9.255191318450436, 0.6358604541709346, 0.04350944271972103, 9.407722488526376, 63.410150158789854, 51.64313770109608, 39.50901100712438, 24.994339020021503, 20.85743873350082, 41.75172029003021, 57.75107606764763, 64.1456808582429, 25.51585147457738, 0.24536271699734274, 0.05852632885498386, 0.03299946716475872, 0.012029448708128786, 0.021935408942461498, 0.04339890006268698, 0.020314156220504836, 0.027261748233990326, 0.031235409908056743, 0.06432213640261082, 0.05960046839449675, 0.03440381358227423, 0.2248077352921809, 0.1340866993151365, 0.16034928120432362, 0.27773313404571626, 0.12162693806232945, 0.129628220813409, 0.21686035448745375, 0.184872429817915, 0.19865965290415674, 0.20731577229115272, 0.1075541097370367, 0.45775539992797765, 42.0660041224572, 72.06457753335276, 59.51538562774659, 57.811488413041644, 32.452474870989406, 46.590211006902884, 45.936971633665024, 47.04360954223141, 64.19162358007124, 62.59605438478532, 6.885824290014083, 0.24756028617341674, 1.5519398138407738, 22.878775327436387, 14.944254871337646, 19.747335410887196, 62.523321874680065, 61.014095813997336, 61.91889247586651, 53.6176117773979, 50.72141993430353, 48.89363858007616, 56.27540980615924, 58.61402496214836, 60.449713814643125, 58.26622447659893, 60.156406817897675, 49.25665001715384, 46.70346160088816, 47.924448367088075, 51.633649487649244, 56.456246760583696, 59.64216447645619, 58.32595040721279, 59.8702738361974, 57.6097648374496, 58.997099322657434, 56.53996190717144, 59.26021583618657, 56.749608670511556, 54.34245009576121, 52.576399003305745, 53.53293565011794, 54.20632816130116, 55.99757263737341, 55.07190504381734, 48.338529063809304, 52.61470879277876, 58.27034296527986, 49.364872132578206, 43.37821737412484, 43.39784491446711, 41.08018698230867, 44.556532675220126, 43.53961898434547, 42.83559668448664, 42.63574407946679, 43.581372614829775, 42.43995504994547, 42.11255873403242, 43.45234624801144, 41.2692452246143, 43.6381842244056, 42.00646646561162, 43.82682669547297, 44.874625129084436, 53.95050333392236, 53.258306980133064, 57.47471763241676, 52.737600572647594, 54.62991668332008, 58.743471022575136, 58.86114212774462, 58.49425538893669, 56.71919461219542, 55.63402383558212, 44.05949384935441, 56.33044065967683, 58.66868711286976, 49.38521354429184, 46.81251133641889, 50.34606872066375, 51.119391456727065, 52.432950081363806, 53.495316197795255, 59.69006838337068, 56.35334730148316, 54.47302187642744, 58.328809815068404, 56.23500547101421, 57.10084907470211, 60.02115564961588, 53.68092667671942, 43.61074724505025, 43.95431157081358, 42.029592760147594, 45.67792261800459, 47.446476182629986, 43.267700672149665, 42.59029949865034, 44.83300878155617, 46.50274999680058, 43.61211615224039, 54.942458983390566, 59.74269482397265, 55.847361549254394, 52.307642121468824, 58.51747189798663, 56.8403801610393, 56.825020159444506, 50.503183180286044, 45.04353807818505, 51.441225851735766, 54.37903011998823, 50.61830474484352, 44.2644259237474, 49.088713738226126, 51.046780540097146, 57.597778074203006, 59.04653687630931, 60.114064831887525, 61.69083410693754, 60.2433971435793, 61.89007089984033, 60.840111240263916, 57.60828610389464, 50.622431078264796, 51.62065075289819, 54.10343262457079, 58.468508951125614, 58.27572837952645, 61.277063277459916, 61.26238184590494, 68.00712877704252, 67.21808910369873, 75.23090301021453, 40.41022654502623, 3.11461785147267, 23.38864422613575, 13.837812100687335, 0.6642161874521164, 0.1457412408724908, 10.290421497437263, 71.72089945885443, 56.43910600293068, 52.730505005005874, 35.120373002944454, 26.649192879276892, 49.899255844854544, 63.2773151705342, 73.6470107109316, 31.69509264730638, 0.41206634513312773, 0.17102418016762505, 0.16019298394601192, 0.13238270526691792, 0.1942174001446655, 0.17555298554080148, 0.14828010221883176, 0.25367906106816185, 0.09190798962428685, 0.1739594307277472, 0.1809527869186094, 0.18030403302081172], [0.06914339584088133, 0.05457878503347597, 0.04491554347858314, 0.09695660863672534, 0.06475136780570592, 0.0739478396492139, 0.006401676322228366, 0.020088596952958934, 0.01557535465596424, 0.0071546196141430455, 0.08752656424598348, 0.9022843224867698, 36.99655640509821, 54.51650134978756, 52.852463260773696, 34.47284067830732, 17.022890429342947, 48.66452509357084, 63.07859220812398, 37.75302863890125, 48.012666394633634, 47.56427280364498, 2.517321037669336, 0.194812037591492, 1.2966793174705198, 3.2426606839702976, 0.7241006063357477, 34.45706490547427, 62.415119371106556, 56.80760875824959, 54.04673084135979, 47.002683531853464, 48.11050991858206, 54.50587957136093, 54.73485577491022, 55.623672700697384, 56.15808386956492, 54.619467489181034, 53.65974980015909, 48.23859099418887, 42.216466242267245, 41.99419729171261, 49.4382792903531, 50.600826663355676, 54.123024863581506, 52.039002910737075, 50.82379771817116, 49.86078916057464, 51.428693879035215, 52.7940042557255, 51.91662496136081, 52.733717426177, 52.88567789139287, 53.12926100146387, 50.99367164796399, 50.51804111849878, 53.1539797782898, 50.76363640446817, 48.91255617141724, 51.723640426512695, 51.40303373336793, 44.12862170127131, 38.240296840667725, 38.42796264156219, 38.380270542637, 39.9750631086288, 38.6663015427128, 41.384892386774865, 37.267160723286295, 41.03928450615176, 37.75028297978063, 39.884130800924, 38.67912769317627, 38.79067597850677, 39.3470210413779, 38.692703016342655, 39.221497351123446, 43.71243469176754, 49.94212342846779, 54.73676989155432, 52.94965174890334, 52.80484960925195, 55.572666198976584, 54.78827845665717, 52.116273603131695, 49.185431541935095, 52.82796805904758, 54.54367553034137, 38.91851386716289, 50.50568957482615, 53.09880379707583, 50.55480549412389, 42.24036916609734, 44.16633529047812, 48.91048515996626, 49.39767883669946, 53.20647285830591, 47.91331275816887, 46.84009736584079, 50.44722664740778, 54.041408185035955, 52.93234232933291, 49.945590803700114, 48.728298910202525, 42.53226803195092, 37.79954010440458, 39.796387380169286, 40.054122401822, 41.32456633352464, 41.942092526343565, 40.371842230519945, 41.21234340052451, 39.19290327256726, 39.26258417867845, 40.36365624397032, 42.545376593066806, 52.53897566949168, 55.83034238507671, 50.22423205837127, 51.898931149513494, 52.6459583159416, 50.22683651216569, 49.76091777124713, 41.05450330242034, 41.132483943816155, 41.86556316191151, 42.28262093759353, 41.12468234954342, 40.333567742378484, 44.724441497556626, 51.87189032954555, 53.96982492939119, 55.62581823718164, 53.972625501694225, 56.36996246153309, 55.49832943947085, 50.2304058690225, 42.12883657024753, 43.92996149678385, 44.67682784603488, 50.86521010245047, 51.38570470194663, 53.32524614949381, 54.91199785663236, 56.53938531875611, 58.70299216239684, 61.51023249472342, 64.83275851895733, 52.3264891101468, 1.4939134952522095, 1.9766446178959263, 3.709847576195194, 1.89802021749558, 0.06176420712783452, 3.6174206003066036, 51.169546804120465, 48.68512538171584, 48.006029744302076, 31.08747632272782, 26.949469927818548, 43.994202075466035, 51.516927596061464, 57.993757032579, 28.71848240975411, 0.11741065059698398, 0.06781246362914962, 0.01596969075410837, 0.03725777455275098, 0.03211168425848648, 0.05233532719073757, 0.04110553542212133, 0.09341334473461875, 0.03925193589360964, 0.049584707650806636, 0.05317308264033449, 0.07193541094180077, 0.06549067329615355, 0.010990311725876264, 0.04843349966611113, 0.09636172604176307, 0.09345746373817806, 0.03217875717147704, 0.03408355052552877, 0.04083910536381506, 0.020990284355056864, 0.03876343609825258, 0.019025021765921867, 1.5317046738439992, 43.77068973356678, 63.6027346118804, 57.71850862810689, 42.58373737335206, 23.144849308075447, 51.344155034711285, 59.38998353096747, 38.348577791644686, 54.29591901840703, 50.286786017879365, 2.8957736203747415, 0.18789493779261268, 5.0756352563058185, 8.97566556930542, 4.45903915551401, 35.81667607830417, 65.20528562607305, 58.39743952597342, 56.03732978144, 47.614486986590975, 48.76533392936953, 56.28387820336127, 57.14488552462671, 57.082778715318256, 58.17306818500642, 56.61629907546505, 55.4792235743615, 50.193343393264286, 42.90785458780105, 44.1971690424027, 50.19599491550077, 54.04553451845723, 55.09590994927191, 52.13993726238128, 51.62056838312457, 52.255972739188906, 55.322022822595414, 53.9830982300543, 52.62578948851555, 56.90973943279636, 55.694934321988015, 54.90668304504887, 52.64083570049655, 51.379009216062485, 55.43071562244047, 51.43975888529132, 48.62563087094215, 53.29722081461261, 53.66870457126249, 45.608445675142356, 40.430407139562796, 40.28154926915323, 39.10756818709835, 41.27744297827444, 41.440303710199174, 41.69865062159877, 39.9617309724131, 42.73328950328212, 38.90926884066674, 42.03411525295627, 39.35890974537019, 40.805299435892415, 41.08874167165449, 39.36176915322581, 40.079464835505334, 44.38279521080756, 51.74862984688052, 56.372613983769575, 53.778801579629224, 53.33534625268752, 55.90001544644756, 54.92371005396689, 53.96165070995208, 50.91827584851173, 54.50007838587607, 56.57882867320892, 39.57168656010782, 52.048542114996145, 55.164402377220895, 51.53622957967943, 44.42754160973334, 46.12528462563792, 51.386081249483176, 52.121243246140025, 54.648296909947554, 52.755015896212676, 47.88834294965191, 51.68871956486856, 54.66042880089053, 56.23103603239983, 51.67212401666949, 50.113585918180405, 44.15046930313111, 40.04985486307452, 41.40019355281707, 41.99547990675896, 42.17071179420718, 45.098957246349705, 42.261573499248875, 42.30085603652462, 40.594605399716286, 41.183204112514375, 41.81546665007069, 45.46050563935311, 54.00094109196817, 56.16129236836588, 51.78585706218597, 53.178223948324884, 56.795465100196104, 53.09843509427963, 50.91628328446419, 43.68380531187981, 43.43129880966679, 44.97907392440304, 45.009527206420906, 42.49142046897642, 42.6291976436492, 47.69473868031656, 54.606488366280836, 54.04036875694029, 57.17180082874914, 56.59775803166052, 59.93263952193722, 57.113785051530414, 52.85136891949562, 43.476382532427394, 46.33291921307964, 46.83990516970235, 53.889369272416644, 51.83363153088478, 57.31863867851996, 56.60626565256427, 58.66707109635877, 60.01673906080185, 64.56886537613408, 65.80585149026686, 59.173468697455625, 1.3314073701058666, 0.629437756874869, 12.107938008923686, 3.777439084745223, 0.04252295896050431, 3.5703440683503307, 55.21325942008726, 54.83717472322526, 46.10272707477693, 29.197170426768643, 32.221009923565774, 51.03340133543938, 57.5333413770122, 65.67421282491377, 38.542084001725726, 0.11550913609924818, 0.010941008222289385, 0.03461955926351009, 0.09588738738168633, 0.011406385568871854, 0.09028635002792844, 0.10835130083104295, 0.03313163265345558, 0.056713236225468505, 0.012245719159592786, 0.07725235224971849, 0.01845099208425851, 0.21137156433636145, 0.16934738224071844, 0.12134345488682871, 0.18145186255776113, 0.199912543739042, 0.20769253433231386, 0.1850564747808441, 0.13884474883877462, 0.17019890429031465, 0.10766754437598491, 0.1932792795161086, 2.188044925851207, 52.52750665910783, 70.5071690774733, 67.30365168663764, 46.74834920514015, 25.91009282296704, 57.05880911119523, 69.9908047337686, 48.09633839514948, 59.72378115500174, 57.163575618497795, 3.869936663296915, 0.48437330871820455, 2.1813408597823116, 5.693281081414992, 4.964981271374611, 38.37972141081287, 65.96318952498898, 61.83269446895969, 56.910347400173066, 51.17158643661007, 51.613982723605254, 60.05009097437705, 58.21241348020492, 59.5265055471851, 61.207841288658884, 57.9702934142082, 59.17117803327499, 52.63180248198971, 45.531163215637214, 46.73120452511696, 53.75159602011404, 55.40988783682547, 58.22202720949727, 53.873895522086855, 52.65683504842943, 53.03489661985829, 54.7482624361592, 57.132804624495975, 55.55876531908589, 58.678453814598825, 58.24307857021209, 57.92378587107505, 55.72748999441824, 54.548617716758486, 57.05621642451133, 53.958167645239065, 50.02254770648096, 54.894217752641254, 56.96324056194675, 49.32882162832445, 42.14362390579716, 42.56179563460812, 40.91816171523064, 42.77267794455252, 42.151166623638524, 46.091928789692545, 42.05837119010187, 44.667163125930294, 41.967105480932425, 44.69314490595172, 42.00075549464072, 44.9300286077684, 43.41658207678026, 42.31358805010396, 42.66841350063201, 48.15295780858686, 54.009891940701394, 60.48534070291827, 56.94424452320222, 56.53469416403002, 58.51134515577748, 58.4052764215777, 55.357712468793316, 53.84682332315753, 57.161171205582164, 60.10461976451259, 42.57462178507159, 53.35167507971487, 58.80487572762274, 55.40085069594845, 47.761999484031435, 49.87694148094424, 54.17514924080142, 53.079505735828036, 54.36670211053664, 53.65999690947994, 50.35199149962395, 55.440486246539706, 57.787934580156886, 59.65952488683886, 55.30473301487585, 52.42500728176486, 46.86662043294599, 41.192382458717596, 44.44002259162165, 44.249516994722434, 45.33214607546407, 46.54885353580598, 44.2912470909857, 44.50730300718739, 43.262691805439616, 43.124581229302194, 44.38933772425498, 47.68785884303432, 55.37986209315639, 60.15846213986797, 52.28722618472192, 54.61259549663913, 58.905782622675744, 55.0499358484822, 53.54720523280483, 45.774946366586995, 44.66231899876749, 47.34235294403569, 46.90860548327046, 44.46389413649037, 43.83868009813371, 50.52410902515535, 58.09904521511447, 56.61098034151139, 60.09745359420777, 59.9910593032837, 61.98227797785113, 59.44070762203586, 55.9105234761392, 45.386878828848566, 49.985881390110144, 48.972956749700735, 57.49782823747205, 55.77951631238384, 58.99227480734549, 59.94570101461103, 63.199632629271484, 63.28070409836308, 66.95236421400502, 69.12636141623221, 63.9456948926372, 2.6424588647580918, 5.936537163872873, 13.195952503911911, 3.995694470021033, 0.2927370273297833, 5.307975872870415, 61.565832091916, 60.50500746696227, 63.19769497840636, 45.32403461394772, 40.368421923729684, 58.084171587421054, 66.85944326462285, 75.11604032208844, 46.46737021784629, 0.4042298785380779, 0.2011417471353085, 0.1466652961267579, 0.15856490921108954, 0.1028397195642033, 0.2209653906644352, 0.22430884351413097, 0.13718186306857294, 0.08394580800086261, 0.16640891411131428, 0.14757108784491016, 0.1954470325501696], [0.021320297795858596, 0.08085290420680277, 0.023126125996631962, 0.025394133126903928, 0.02753817765492826, 0.03228379165633552, 0.061607270186106046, 0.04636813045269059, 0.03422201708740285, 0.021760271666871927, 0.09545689193351616, 0.8446439896379748, 42.07025597172399, 53.2001970660302, 48.15655854440505, 34.97123272188249, 20.946149018503007, 38.531391620635986, 48.07084298902943, 32.18974274973716, 54.81030256517472, 46.28908280403384, 1.5202780740876354, 0.21483870974231153, 2.904819831732781, 3.518800201915926, 4.721049070358276, 34.304896554639264, 60.6936264038086, 57.46016956144764, 53.705080632240545, 52.315808496167584, 54.22722262720908, 54.43024842969833, 56.60854062726421, 56.48640978720881, 55.257036993580485, 52.09262955573298, 58.43700447390157, 49.8111907897457, 40.66355674497543, 40.88642189579625, 44.09782325067828, 48.04641838996641, 54.45381402969361, 52.23569408539803, 50.085772391288515, 50.19005252468971, 46.00877454203945, 46.28945542920021, 50.48576785672096, 48.60749383126536, 51.58347452840498, 52.173414691802, 49.961547005561094, 51.11597899467715, 50.978339102960405, 48.33324170881703, 49.52300248607513, 51.76785338309504, 51.212167278412856, 41.502936117110714, 37.265183848719445, 39.675903935586255, 40.68438060822026, 39.007885071539114, 38.841243174768266, 38.97394088006789, 37.77624122558102, 40.855607755722545, 38.74323883364278, 39.79242186392508, 38.2092159794223, 40.80377363389538, 39.42629998730075, 39.79960764608076, 38.03265048611549, 43.568805340797674, 47.35648524376654, 50.376318039432654, 53.60675465676093, 55.951033715278875, 51.30339376388058, 51.37600075814032, 46.514438659914084, 50.917754173278816, 51.36022106293709, 55.74118691105997, 39.45554517930554, 51.57198198380009, 55.01398732585292, 49.76856247071297, 46.626740040317664, 44.493119716644294, 50.13407637996059, 51.76281705979378, 46.671827685448434, 45.43853644401797, 51.88811717494842, 51.79586695086572, 50.80131076997327, 47.92970434311898, 46.003232232985965, 39.37690557972078, 39.11308303956063, 41.12614931598787, 39.17908084008002, 41.236022749254786, 39.14015523848995, 37.85746566710934, 39.368597999695815, 40.747162065198346, 40.96139407926991, 39.38930419183547, 40.52387329839891, 40.26465562082107, 49.75660316405758, 54.02825647784818, 52.03623763976559, 52.99812832186299, 55.67732680228449, 52.18067107662078, 51.14623223581622, 46.675126398763354, 41.072134356344904, 40.609333899713334, 42.14753058648879, 41.36144053551459, 40.54234373954035, 41.713712523060465, 47.255927439658876, 48.5108740868107, 47.947696255099395, 51.005132813607496, 49.588635506168494, 46.77108718502907, 42.50112441278274, 41.59199353187315, 45.45126061285696, 47.342341176925174, 49.98340637453141, 51.4990141314845, 51.66266325981387, 52.93653534304712, 55.17149010012227, 56.51956950464557, 59.54179102374662, 62.90278765463061, 68.29393248404226, 12.716483935233086, 0.507674118083331, 8.388152372452522, 1.0280392487202923, 0.05460978095089236, 1.6203530589419028, 46.59540422501103, 49.94621446055751, 47.36741296706661, 38.109113170254616, 21.34007657727888, 36.922168654780236, 50.284797376202, 60.16494974013298, 39.73727726167248, 0.3071645467031387, 0.11124049418515737, 0.0291384510590785, 0.024667948807379412, 0.013207518608279288, 0.02381707984773863, 0.047998541755782026, 0.03680325841771499, 0.026399763338568232, 0.05174700230840714, 0.08584490932163694, 0.05428671784278366, 0.04831361073640086, 0.05964711165776657, 0.07691751820065322, 0.04692222652656417, 0.05724203224564272, 0.012981899968919255, 0.0639734055185991, 0.03713594742059227, 0.037869120377206036, 0.03561617453552542, 0.04899386616964494, 1.4817884684570375, 50.34282099816107, 61.420774998203406, 56.12437894267421, 39.66330528259277, 28.06650603971174, 46.216707229614265, 45.953461277869444, 33.76343688657207, 58.74538513921923, 50.77362275892689, 1.6596955349368434, 0.11093559885217298, 6.899122595787049, 7.625651945990901, 9.270179675471399, 40.50253168229134, 62.56652285975795, 58.90879892533826, 55.46909601457658, 53.84255578441005, 55.52897883999733, 56.60117049371043, 60.032750175845244, 58.9398209510311, 56.63041568571522, 53.879673173350675, 60.27680789270709, 51.18695428294521, 41.99945719011369, 43.43520549035842, 47.376179464401744, 51.06994213596467, 55.47979624040666, 53.21203477921025, 49.15202863754765, 49.69862661054058, 46.71403631087273, 48.29388856887818, 50.73117094655191, 48.23061681562855, 52.42935326791579, 53.530593995125066, 52.99135046620523, 53.92282316761633, 52.531397650318766, 49.6479574326546, 51.81684378654727, 53.40520758782664, 53.727669562062914, 42.99616675223074, 39.09349864529025, 41.173394264713416, 41.74191044222924, 40.846143076496745, 40.831645996339866, 40.40305252998106, 40.310978812556115, 41.04105349509947, 39.55149419846074, 42.2935486608936, 40.76303589728571, 42.333117531191924, 41.6475264487728, 40.805566157064135, 40.280929534666, 43.97426074550998, 51.19205336416922, 53.008714798958074, 55.353131140432055, 56.943954267809474, 53.47279394826582, 54.785324911917414, 49.292994699170514, 52.45927702996039, 53.383356063596665, 57.66867099269744, 40.007775675865915, 51.99761798304897, 57.13715453301707, 52.63420689490534, 49.548682243593284, 46.728784422720636, 52.42196352251115, 54.00208642405849, 49.423260534963305, 46.27740198566068, 51.26478587427447, 55.31442519157164, 54.685943818861446, 50.32224032186693, 47.32285091953893, 41.32170300329886, 40.9067476180292, 42.23927874718943, 40.70396108012046, 42.34185657193584, 41.645110268746656, 39.744914116397986, 41.43289827531384, 40.961613731999556, 42.22338138088104, 40.4071278725901, 41.37847931154313, 41.997856863083385, 52.07791674521662, 56.30369401747181, 53.17814157855127, 52.79535747343495, 56.898847010827836, 55.1374400046564, 54.81578211630545, 48.335512761146795, 41.89327470717892, 41.7230163851092, 44.049950722725164, 42.661435604095466, 43.422469554408906, 44.278703351174634, 49.197590889469275, 49.34585648198282, 51.11740673741987, 54.243971147844874, 50.89489067754438, 48.340223527723744, 45.18122111597369, 44.17803572070214, 46.4034120498165, 47.89308509519024, 53.630218275131725, 54.72774451778781, 54.33901017712009, 54.689120938701016, 58.338953064334014, 59.427912850533765, 63.88303502913445, 65.98332697345366, 72.40630226750528, 15.638456536877541, 0.5840795907762744, 13.086156537455897, 5.416096496966578, 0.027683977593457507, 1.9170964196805034, 50.63170356135215, 54.59907900902533, 46.45479902144402, 41.810395025437884, 31.14697671705677, 43.91879450890326, 58.740941093813994, 65.26812984097388, 49.247758003973196, 0.9678531137685623, 0.15451613453126725, 0.06157490680174482, 0.05378650456306435, 0.024586973313782966, 0.05179169204747004, 0.05492396509995865, 0.02680111297165915, 0.05452595177977797, 0.015253396629686318, 0.06041906781554703, 0.011402829963293289, 0.10972138779658465, 0.18636859953403476, 0.17354909871374408, 0.29584314614053697, 0.18226671963930133, 0.10437354250180145, 0.16296237647052736, 0.15114718627545143, 0.19249342652338167, 0.3228330672267945, 0.19077492276987723, 2.3401894973170374, 57.84025507588541, 67.75625398082119, 61.88161034737865, 48.65271483698199, 30.676741407763576, 48.248561659166896, 56.05993832311323, 41.05325991107572, 65.96144799263247, 55.74867471571892, 2.613077860686087, 0.3567232648211141, 5.972166993925649, 8.456370234489441, 8.22514308075751, 42.87056853694301, 64.39106041385283, 61.3722199778403, 58.171632597523356, 57.257496772273896, 57.92140499238045, 58.91036002866684, 63.68280587657806, 60.0295691336355, 56.19411476196782, 54.35047918750394, 63.43819902789209, 53.496261489006784, 43.727171036504934, 45.14849678162606, 48.40795893822947, 52.06827948170324, 56.86676986755864, 56.641586595965975, 53.30067250036424, 51.56307428113876, 47.39701509475709, 48.42143227977138, 53.62190677273659, 48.683321091436575, 53.52587538380777, 54.95564206953972, 53.041894128245694, 54.03448520168182, 54.69692645534393, 49.58966316715364, 52.645499398631436, 55.958450917274725, 57.11509120079779, 45.98038442673222, 41.14014433276269, 43.54059173214821, 44.05275913976854, 42.01906511860509, 43.25689454232493, 42.32994825609269, 42.19158664826424, 43.48971074627292, 42.0783164424281, 44.45661813982072, 43.731717063534646, 44.264582818554295, 44.143569853998, 41.96775659438103, 40.90581017155802, 45.69107432519236, 52.20191071110388, 53.48387464400261, 57.30580076094597, 61.18062788440336, 55.304081901427246, 56.015321362403135, 50.93709538059851, 54.70918778450259, 55.75825314367972, 59.53264797887495, 44.542561192666334, 54.93695589803881, 60.19464208233742, 54.63156800116263, 51.55812032761113, 49.68154861081032, 54.87277807727937, 55.18761104153049, 51.108502957128714, 49.135248737950484, 52.54725971529561, 55.552717024280184, 56.70636846173195, 52.46737280199605, 49.489172043338904, 42.59364528040732, 42.24450334425896, 45.170163954457934, 41.98808231661397, 44.93961880283971, 42.22398542588757, 42.877946515237134, 43.06714596286897, 46.08872029089159, 45.03125713717553, 42.09027574908349, 44.24870114172659, 44.21779286476874, 53.65053223025415, 56.82984859712663, 55.97837655775009, 54.49396341077743, 59.51288315557665, 57.152059539671875, 57.80514594047301, 50.1375319880824, 44.74153126439741, 44.778425078238214, 47.57133699232533, 44.5756777640312, 46.497894102527255, 46.83544151244625, 52.09235498982092, 53.0364812574079, 52.14868807023572, 56.83423380697928, 52.476594294271166, 52.05118971486246, 46.99390134503765, 47.157354354858406, 49.844664296796246, 50.97000014397406, 56.097848030828665, 57.70954601226315, 56.02122452951247, 58.78264765585623, 60.71261459781278, 62.11552481497488, 66.17329520563926, 68.13411158900108, 75.24847522858651, 18.265116830025953, 3.1024771351968092, 20.174960051813436, 3.442536087766771, 0.1728980005868981, 2.550139508901104, 58.88299365197459, 62.593995140444854, 63.3421205705212, 49.11507598815426, 32.67938398545788, 50.75941593416276, 66.46197380558138, 74.78787914399179, 58.652746600489465, 2.0666210930193625, 0.2753290888522902, 0.1647393480544129, 0.14491616417804074, 0.22253576365690078, 0.09418294134159243, 0.12222756631672384, 0.1609166765645627, 0.1453885033486351, 0.12981687762564229, 0.20397231944145697, 0.07798824864890307], [0.06928283150397962, 0.025208858592856317, 0.05626245093862376, 0.015572462674050082, 0.01145396633223901, 0.11886070948094131, 0.029828171508627075, 0.035393484267255956, 0.03065492402041151, 0.1008392877936844, 0.1861720979814568, 2.203053875315574, 48.4364902588629, 56.86769162454913, 44.86756878514444, 35.590963286738244, 18.600742278560517, 43.40633292352, 48.84715457116404, 34.673450300770426, 58.661446417531664, 42.7606794141954, 0.8460230704757475, 0.12217600093854052, 16.610423787947624, 10.905602112893137, 2.7733299712980948, 20.50291922784621, 62.38676455713088, 55.420395866517104, 59.819702717565725, 55.15171743208363, 57.789362322899606, 56.53795757601338, 56.07380390167237, 49.770119651671386, 46.16926224000993, 54.064052028040734, 53.323434014474195, 52.032856556677054, 41.13537473063315, 40.22867964160058, 45.53003749539776, 47.933222709163545, 50.106094191151286, 52.83375747742192, 55.20221010331185, 50.37721233983194, 49.64308977127076, 48.387142919724994, 49.490289918838016, 50.100708776904696, 49.67481390122445, 51.79424308961438, 48.4731722647144, 48.52459061530329, 49.62423101548226, 50.20406715331539, 50.54026919026529, 51.11687721744661, 48.23044423134097, 38.58760702994562, 37.761269538633286, 39.13873926285775, 38.72116373431298, 38.18363035878828, 38.15994708768783, 39.99003087320636, 37.49117905093778, 38.92039268247543, 38.34535752573321, 37.56429595331992, 39.576154139734086, 41.122674096015196, 41.29985540143905, 39.4986520274993, 40.29011572560957, 41.36318991261144, 45.61837319404849, 48.51857762182913, 50.82944985358946, 50.45386329773934, 48.115550164253484, 43.55638319446195, 42.291756137724846, 51.21370876989057, 51.952808826200425, 55.37514348183909, 39.46938722364364, 48.74092894215738, 54.81344438368275, 49.51005474213631, 49.65853214263917, 44.147343174103774, 51.14967215445734, 51.45124358515586, 50.25263001841884, 51.36657922498642, 51.13627333794871, 51.18531473221318, 53.9333115854571, 52.76450803202968, 50.880585793525945, 42.40474393290859, 40.11498581978583, 37.392335322595414, 38.93695685171312, 40.117437301143525, 39.72736935461722, 39.4450096930227, 39.24566699612526, 39.22612967029695, 39.86890415991507, 39.458702687294256, 39.40162043417654, 39.67676293465399, 43.04079155768118, 53.85574279292938, 54.311447681919226, 51.55747313653269, 52.55365710104666, 53.31016463618125, 51.92025707614038, 51.40053910593833, 47.12229621025824, 43.444097503539055, 43.25709850557389, 41.615280643586196, 41.71670136913177, 40.18862047503072, 40.59053397947743, 43.35012928132088, 41.303256096378455, 41.160309237818566, 42.94252441775414, 39.8783923733619, 42.51958700918382, 41.35065401754072, 44.77992734601421, 47.42735855041012, 47.86356141490322, 48.012427130053126, 50.583799654437655, 50.302973639580514, 54.40225447377851, 52.44085365726102, 61.499242013500584, 59.70561665873374, 71.25036408824306, 30.016604546577703, 0.492170735472633, 17.3316829435287, 5.081297687945828, 0.2932107454586414, 0.4689290987387781, 42.21098669113652, 52.79107816757695, 40.702392132051536, 39.54450845718384, 25.833945889626783, 42.09566900807042, 52.554257223683024, 55.250922018481845, 42.72785702059346, 2.4106318335379324, 0.14251755820887704, 0.0274377990694296, 0.024297058830157887, 0.02588715475623406, 0.03505306926766231, 0.03037482503831627, 0.05713815838398953, 0.13607607643690803, 0.05080576753243805, 0.016174715034843936, 0.04379977089082522, 0.07066767332294295, 0.04431274719536305, 0.0898691232226068, 0.027562880160046682, 0.04523540050872872, 0.026869597401650205, 0.05021752308933966, 0.04663863992919365, 0.06927959861293917, 0.09629712950798774, 0.08778020063595426, 3.3642490112012435, 56.212840157170454, 63.72133531878072, 52.615030427132886, 41.0173741463692, 18.613968510781568, 38.304102036260794, 48.79932518928282, 34.248143780616026, 62.62960241686914, 47.456101679032855, 1.0273582271991237, 0.06876586771179592, 7.516908645629884, 8.561628999248628, 3.863167142675769, 20.74689849730461, 64.66847004428988, 56.37556360613916, 62.392071523974025, 56.35655972265429, 61.13563045378655, 58.35443858177432, 58.65762210661366, 51.5532644333378, 45.99706234470491, 54.238213108431914, 56.922098821209325, 53.65312099456788, 44.17330534227433, 41.114829355670565, 47.28442345896075, 51.204899126483554, 53.79727594314083, 54.0558111283087, 56.82194109885924, 52.85024319925616, 49.5714908261453, 49.0506039896319, 49.328896153357725, 49.901393536598455, 51.77613742889897, 53.11788220559397, 50.202549196058705, 48.523759072826756, 51.09625339508057, 50.62460799371043, 53.492480324160674, 52.501430742202274, 50.2573956981782, 39.548877977555804, 39.698222221866736, 40.04172771207748, 40.68067004603725, 38.99400380349929, 40.6809171553581, 41.16938952476748, 38.92319325477847, 40.37777285422049, 40.457400891088675, 38.7376533785174, 41.46253178196569, 43.06151343930153, 44.212109350389056, 41.241145364699825, 42.14522815519764, 43.12587168908889, 46.83358623135475, 52.025082418995524, 53.8545072463251, 52.01076969023674, 49.01222359749579, 45.20402969852571, 46.020565186777425, 53.64677852199924, 54.43603784807267, 57.29337861461025, 41.70760931507234, 49.81665465139574, 56.49882408880419, 51.31501182433098, 52.55364533393614, 47.680237677789506, 51.884057521820075, 53.4011322452176, 50.64594176507766, 53.133191216376524, 51.6215136743361, 53.27045456055672, 55.71000406819006, 55.786655026097456, 52.90133991549092, 44.888690748522365, 42.384002439437374, 39.8739993187689, 41.360860024729085, 39.76594586526194, 41.617226139191665, 41.01997075542327, 42.124616099942116, 40.7194269857099, 41.66667153758388, 40.99369479763893, 40.86897127089962, 40.35726670295962, 44.58565627374957, 56.65131015162314, 56.89802331309165, 53.44132085000315, 54.22694806129702, 57.10272396764448, 53.09461862810197, 54.61032444430936, 49.76074518695955, 44.662346455358694, 45.742853533837106, 44.32892537886097, 43.67590958072294, 42.501359754993075, 42.87472232695549, 44.96504752866684, 43.080042715995546, 43.31294128971715, 45.21435337681925, 43.63327341694986, 42.04556465148926, 43.9455254616276, 46.16903082016976, 49.210107172689135, 52.14748390259282, 52.10930355133549, 53.50219211270733, 51.29018322114022, 57.04955623995874, 54.92556925742857, 62.82977273387294, 61.77437274686752, 73.37585726091939, 34.45875544701853, 0.4756555958620964, 3.3450257201348585, 3.6510058949070596, 0.40773050198631905, 0.32438844021770263, 45.43875217437745, 57.88152233246834, 45.35390738518008, 41.93657375151112, 33.47557806199597, 50.92634808632636, 58.16642368993452, 63.25325142952704, 54.275475625068914, 4.923370807401596, 0.13421282803099002, 0.07406263792466733, 0.023570204183699626, 0.02435109867233663, 0.03966562720316072, 0.02206032915461448, 0.053175537952131806, 0.01955846985501628, 0.053065240443233526, 0.03171350431418227, 0.0052094299650390545, 0.12568015605211258, 0.11314757048122345, 0.23482822662880345, 0.14321823754618246, 0.2067706700895102, 0.3040535862167036, 0.17860602978016102, 0.10801122674057562, 0.17527959940414276, 0.18100662757792782, 0.4246215149760247, 4.958071526019804, 65.33487681419619, 69.58813421187863, 61.13583441703551, 47.22078300291493, 28.71521507540057, 51.9470037183454, 60.64826027039559, 44.12529945373536, 69.92377927226406, 49.554581488332445, 1.0057085211719237, 0.21543509386960538, 25.13160432538679, 17.428316416278964, 5.405180050480751, 25.51260179088962, 67.13036921716505, 60.330693414134366, 67.34377753350043, 58.94108395422659, 64.03999259394985, 61.445450628957445, 59.052879348877944, 51.582246826541045, 47.175597298529844, 56.6466268416374, 58.703486381038545, 56.11356496810914, 44.96562411708217, 44.607986327140566, 50.00532065668414, 52.98398033265145, 56.459470948865345, 55.85034647295552, 58.16335639645977, 53.540399920555856, 49.576938998314645, 50.157924390608265, 51.47818242349933, 51.309924510217485, 51.78357032037551, 54.219923096318404, 50.41538876871909, 50.47498133874709, 50.45098820040303, 52.641325996768096, 56.11588308888098, 56.37401426992109, 53.648457296432994, 42.58890313486899, 40.89491382721932, 41.58803193799911, 42.517990604523696, 40.337113565014256, 42.07730839329381, 43.79888373036539, 40.61981055044359, 42.89558149153187, 41.58400366383214, 40.727338406347464, 44.06308281806208, 44.85720980551935, 48.04274312911495, 43.408423546821844, 43.67652539283999, 46.574042997052594, 49.26253357241231, 54.15800063840805, 57.527053817625976, 53.47594753388436, 51.86044485338273, 46.73634283004269, 46.99576054849933, 55.51108498727122, 57.47501965492003, 59.20968394125662, 46.907122827345326, 52.359433097224084, 59.91990358598771, 53.66256606194281, 54.43068773515763, 48.98190367606379, 54.88435299165788, 56.682540062935125, 54.92628312879994, 52.9665610867162, 54.13640406823928, 54.451064448202814, 58.1003592091222, 57.04741462584465, 55.44178455106674, 47.93042998160086, 43.70261307685606, 41.73726635594522, 44.172944484218476, 42.66328304044662, 43.108640716921904, 43.1907751483302, 44.69461971713651, 42.19704658754411, 44.20117378234864, 43.540454449192175, 44.492299941278276, 42.41900567085513, 48.249577553041526, 58.76598150499406, 60.905332411489184, 54.33085164716167, 54.11453293215845, 58.57595443725587, 56.848605371290645, 57.49259971803235, 52.4048698333002, 49.17003231663858, 47.485660660651426, 47.10331193862423, 46.94858228006671, 44.197263179286836, 46.69667982286023, 48.38089066167032, 43.75788319495417, 45.22473981303554, 47.12237073529152, 44.47825785606138, 44.494743577895626, 46.05918484349405, 49.85688247988301, 51.91892347028179, 55.07525082557432, 54.32069663078555, 56.37821120600547, 55.94084731994137, 59.937114946303836, 56.7137150610647, 65.41407339034542, 64.57580797133907, 76.06234350512105, 36.82908296585083, 1.0175172455849186, 28.277400116766657, 9.08023399691428, 0.5672208760534564, 0.7759509079398648, 52.05442959262479, 64.93874096101331, 56.052403450012214, 52.7472339137908, 39.08965472252139, 55.783913289347005, 69.77373292369228, 70.50276033339962, 66.8083740049793, 6.894044107006443, 0.22850018715666187, 0.18785634228298742, 0.1604007316693183, 0.06189661010378792, 0.12480595013907841, 0.14802914713659596, 0.11113531797403291, 0.1447715114561781, 0.12977146393349095, 0.1304780421478133, 0.1369772716275146], [0.11549540780364506, 0.05804748176747273, 0.04883502932986425, 0.10218160407197091, 0.057244744196894674, 0.0254904150572275, 0.05043362500146032, 0.07422390709360761, 0.11398341837188891, 0.06239071000187148, 0.06760634001224272, 5.27089378526134, 48.01891080794796, 52.68186369249898, 50.42841888243153, 33.25055952995054, 37.85275097816221, 55.64353558324999, 41.76023183330413, 37.52983400898595, 55.356500456410075, 40.63918313672466, 0.2760374443905969, 0.060705163350869576, 2.0318172896100632, 11.278835246639868, 1.3766557098396364, 19.657417035871937, 65.64562266872775, 54.82432503854075, 59.50141806756297, 54.44434935046781, 57.29068394630187, 52.448110042079804, 56.08994837730162, 56.07333321725169, 53.7039823685923, 55.81433911477366, 55.02447182132352, 47.650592404027144, 40.52588155192714, 41.96565028159849, 44.191144281818026, 50.7932581440095, 49.44039737024615, 51.80892844353953, 51.76911246392035, 48.90589598686465, 46.323748711616766, 48.70208571034093, 49.24483976056499, 52.89538967993952, 51.716941018258375, 52.582086440055605, 49.862777802252005, 52.41436589148737, 51.10000710333548, 51.2760038529673, 51.01180868764078, 48.31402209497268, 40.94721078872681, 37.14520246751847, 38.9855432510376, 39.90106759532806, 37.804058674843084, 38.4698574773727, 40.7230120320474, 38.385683413474794, 37.359920855491396, 37.91355948294363, 38.61433798266996, 38.557318487475, 39.845895536484264, 43.00536863265499, 42.63605786908058, 41.32479775336481, 39.86113786697388, 39.928457506241344, 39.000542394576534, 43.20444068601055, 42.32794000256447, 43.50813804134246, 40.886449352387466, 42.79979328955374, 43.51457465079523, 51.43535798595798, 51.11271558269378, 57.57329463958741, 40.76763291512766, 46.756437132435465, 55.95200254071144, 52.77902472403742, 50.190048602319536, 44.96787555756108, 47.88516190744216, 51.075413842355054, 54.82172450711651, 53.67130902505691, 56.08056214547927, 53.924866722476104, 52.92737268632459, 54.71045471006825, 52.37550304782007, 48.28807953865298, 44.64145591182094, 38.867613269436745, 39.99069375376548, 38.35756394170946, 40.158457448405606, 41.31399162354008, 39.561107927753085, 41.07746485740908, 40.941362534799886, 39.400404499423125, 39.60150049578759, 38.72766310168851, 39.61223210057905, 47.424063759465376, 55.48184371763661, 50.15748508514897, 53.80807815059539, 52.55561436376264, 52.08283147504253, 54.16978736077586, 52.84279461829893, 50.202098123488895, 48.603720511159594, 47.72816904129521, 47.04004410774478, 42.74034976959229, 39.905139015566924, 41.47752308076428, 39.8985533560476, 42.39826809975409, 41.81373688482469, 42.23526616250315, 40.54929417948569, 42.53417430385467, 42.29107364531487, 45.93663430983021, 47.45892578555692, 50.04136723856772, 47.7793755838948, 49.126780340748454, 49.01280803065146, 53.06799750174246, 55.428295520044145, 64.25495024650328, 65.3288834325729, 61.938825961082216, 1.7136645293043506, 6.021362831515651, 7.755358353737862, 0.026982616437899492, 0.4834821646011645, 33.53801827276907, 60.316447365668516, 43.32305316002139, 48.017565434978856, 17.799109835778516, 24.770124573861402, 47.42078858037149, 51.870870513300744, 47.6708161446356, 4.210407955031242, 0.6172452530553264, 0.0047490776764349115, 0.06248272099201718, 0.056309412128382155, 0.05099175452825524, 0.04480811496896129, 0.017663492002494393, 0.01656913923309936, 0.05466073728917588, 0.05945106209706395, 0.05390870324786633, 0.049706297295708815, 0.024399438820358728, 0.07642107024308174, 0.07756869293629162, 0.06594006813341571, 0.030806500261889833, 0.06449933253949688, 0.06655327555152678, 0.057786326224525134, 0.07182734657920177, 0.10736100195396332, 6.913341187661694, 58.01184700381372, 60.65538721699869, 55.457834889811856, 40.162113097406205, 32.2544147891383, 49.630530341979004, 46.41061352145287, 39.62968664784586, 61.1753797531128, 44.55447343087966, 0.5373306993034579, 0.15211230384245997, 7.158211815741755, 9.269825681563347, 2.4742333110301726, 20.297463517035208, 64.67914673589891, 55.82767517335954, 61.949188863077474, 57.84376167481946, 59.177532272954146, 52.723531030839496, 56.49814944113455, 55.20444585431007, 54.856849332009595, 57.24605521848125, 55.122986070571415, 50.47003130758963, 43.631453437189904, 43.553221764103064, 46.8473929743613, 51.78963822703208, 52.696129352815696, 53.72955229974563, 53.76712468362624, 48.818921350663715, 47.320411205291755, 48.523276621295565, 50.84855571869881, 54.49086866071148, 55.03482295620827, 55.88991142088368, 53.360370974386896, 52.174728685809725, 50.595853097977184, 53.427655312322806, 54.04401656120054, 51.57384510963194, 42.61304924564977, 38.31619470350204, 41.23806630411456, 41.82373500639393, 39.072274700287856, 40.5913027640312, 41.574048688334805, 40.20753022163145, 40.75529706093573, 39.94194261489376, 41.242694700917895, 40.286126675144324, 41.90276684299592, 45.13689833302652, 44.41695513263826, 42.7085550369755, 41.89558498321041, 40.58304617481847, 41.609130367156, 46.4004232037452, 45.25774263566541, 44.96708323878627, 43.13768979041807, 44.56626015324747, 46.117706606465006, 55.40967602883616, 53.477947942672245, 58.67456282338789, 41.82178558841829, 49.33514056667205, 57.52519853653447, 54.308721634649466, 52.401041600012014, 48.61311851009246, 50.48108846910539, 52.55640276016728, 56.33565348963584, 54.79565251258112, 57.52248033400505, 55.10738288202594, 54.58435835376863, 56.79859122922344, 54.951429443974654, 47.94416219957414, 47.911292737530125, 41.48856063042918, 40.9641711173519, 40.48176273222893, 41.48909015040244, 42.69359119476811, 41.05723719443045, 44.00793037106914, 42.97489573878627, 41.71426949962493, 41.755038615195986, 40.89876559472854, 42.57248409332768, 50.67721482246153, 57.1252344500634, 53.13116727336761, 55.85339807694959, 54.502820122626524, 54.33819824649442, 56.4733051484631, 53.69267809775568, 54.31377756980158, 50.768923759460456, 50.82753965931555, 47.10855614754462, 45.575250656374045, 42.49548404447494, 44.987691371671616, 42.78713580100767, 44.98836994171143, 43.787501012125325, 43.57568910045009, 42.05454295681369, 45.29316163832142, 46.513422766039454, 49.96171174510833, 49.75608148882466, 51.90914892381238, 49.42160921712076, 51.78574331345097, 51.51050275371921, 55.7397944696488, 56.94499761827531, 65.34669491552538, 66.77863459433279, 65.4228908784928, 3.2444284471773335, 1.6974711466220118, 4.209194962055453, 0.018719074977261406, 0.5202849978400815, 38.0908388476218, 65.50619809858262, 51.91539333712671, 49.896596477877715, 24.2311026588563, 32.00364589691162, 54.16312717622327, 60.21923926568801, 59.48045299899194, 8.018192456614587, 0.7484561961985404, 0.08237671437523059, 0.11638903404555975, 0.047028375669352473, 0.0455361781191201, 0.04764172864416915, 0.029117159560442935, 0.044670809030292496, 0.07895535038363549, 0.06521137296071937, 0.06416404266811668, 0.14729892744893028, 0.160991462067731, 0.14946205331192863, 0.21794064571299862, 0.13390959510880132, 0.14068688386149947, 0.1617192762393144, 0.15200534264647192, 0.23382978423708872, 0.19854014318796898, 0.1816018166080598, 8.415609944251276, 68.24226702413252, 66.367750629302, 66.78119982442549, 44.19030097223098, 53.163012996796645, 65.51617660830098, 52.2270138802067, 48.59980598572762, 65.29830463470952, 48.98892471867223, 0.6914638511596188, 0.24758250272322088, 8.093333302005645, 20.09793450755458, 6.233737113014345, 22.78274786087775, 67.27584992685627, 57.984774804884395, 64.49552097628194, 60.04347785826653, 62.18680212574621, 54.13943998275265, 57.77127627403506, 58.153268060376575, 56.50948509093254, 59.26895879930066, 58.095742579429384, 51.172112034213164, 46.6262105203444, 46.55970673407278, 49.31617198451873, 55.59936969510971, 54.33905724556216, 55.24107686934933, 53.24404524218652, 52.360892218928186, 47.71330325834213, 51.67644254622921, 52.332298140372004, 55.864121837000695, 58.411497300670995, 56.61360440715667, 55.519216060638435, 55.35975210128292, 53.29028214177778, 56.1434220498608, 55.9187408416502, 53.24549651915028, 46.13654182803246, 40.89885973161267, 43.65328927193919, 43.66139681108537, 40.40284072199176, 42.46533670733052, 44.98063895010179, 43.26106009944793, 42.64985676734678, 41.15231936977756, 43.15421081358387, 42.241730228547134, 43.78007988775931, 48.34746422306184, 47.451689012589, 45.19705964672951, 43.65160265276509, 42.783633124443796, 42.906897529479, 48.46797120186591, 46.21606003853583, 48.19917509632726, 46.14962685492731, 47.48522919993247, 49.173864472296934, 57.55946436235982, 55.638377666473396, 60.16511840205039, 45.537972450256355, 49.53499709406207, 60.25402284437611, 56.370990122518236, 55.536176389263524, 50.80993998435236, 53.239891452174035, 52.86381852242255, 57.51154084359446, 58.38392696072979, 61.37259260300667, 56.629160527260076, 57.60093165982155, 60.758192539215095, 57.244321530865086, 49.91092489611719, 51.489847552391794, 42.58091718919816, 44.35139271520799, 41.38139363258116, 45.615635379668205, 45.68204502905569, 42.253854274749756, 46.76708244508313, 45.525205135345466, 43.555363378217145, 42.87914283813969, 43.10550282078405, 44.72157816733084, 53.80772905965006, 59.776701773366625, 56.29439800016342, 56.37530080733761, 54.721088255605395, 57.41462299900671, 58.12980051963561, 56.154969507648104, 56.180021685938684, 53.195070528214984, 52.8980137455848, 51.5573868443889, 48.02910504802581, 44.658027925798976, 46.69327912792083, 43.95662969158542, 46.31552350136542, 46.1610762534603, 46.834990439876435, 45.67254504849834, 46.95014338339529, 47.95849061781361, 53.67173656340569, 52.596042233128706, 54.28598365476055, 51.39663242524671, 55.12912850226126, 54.927965825603856, 59.57051061814832, 58.88316623626217, 70.0482988357544, 68.34734732104887, 70.86694455915882, 4.146827315130542, 11.492695616137597, 15.19088762421762, 0.13558417138072754, 1.0423458487756792, 42.34044059630364, 71.82920394405242, 61.39796249328121, 62.423466174833244, 27.808767095688854, 38.70750604137298, 63.967381677319935, 67.77312017256214, 73.44006646064021, 12.963212786182282, 1.0227110152763705, 0.16795843419048095, 0.14085459582988294, 0.14867146589582966, 0.15093499524218423, 0.12655837626587, 0.08614530771850579, 0.21370292310753178, 0.22213293930455563, 0.12030492311403637, 0.13941122489350458], [0.022149718208839337, 0.014265687129790745, 0.041565192007129236, 0.024965359461343577, 0.029411168784023296, 0.04132262558766431, 0.03661401937865923, 0.025608350462730856, 0.07290856477113501, 0.032163623104532885, 0.19809110841203123, 5.568475184902068, 55.19912319798624, 52.87775470364479, 52.33696968324723, 30.466692601480794, 53.231352452308904, 60.75456826917587, 65.43128082829138, 43.027506489907545, 54.023149551883826, 35.15084981918335, 0.17848878768422913, 0.24181306392194765, 2.483146897246761, 8.22175758500253, 4.2414897968692165, 27.516532867185532, 40.45768330174108, 47.21986909066477, 52.19381101669804, 52.83936646676833, 51.27805525256742, 57.5917140899166, 57.89196760423722, 58.09833918848346, 57.08343375113703, 56.51291324246315, 50.78548400632797, 43.2124815448638, 42.95870419471495, 41.23042160464872, 42.25764720670639, 49.35430918970416, 49.55773507395099, 50.72616600221204, 53.14204008348527, 51.37642045174876, 45.394009697821836, 50.076629346416844, 49.98717577226701, 49.17843795591786, 47.90668787494783, 47.73039302518291, 50.551192991195194, 51.08923235247212, 52.84390072668753, 52.61909792500158, 49.4058765903596, 40.36196178005588, 38.00032231115526, 40.06797621327062, 37.77038904928392, 41.05092610082319, 37.41811706173805, 37.780771563130045, 37.941208270288286, 40.59831203952913, 39.61886875091061, 38.48001641611899, 37.6419706498423, 37.53727866757301, 39.88694314033755, 45.71512237671883, 42.50700404567104, 39.68053233238959, 41.06292070881013, 39.87312463022048, 37.760896913466915, 40.45888746938398, 40.11387578902706, 40.894474521760024, 41.89196855791154, 42.76981461432673, 45.42013660553963, 51.42167675879694, 51.796718105193115, 55.45450479753556, 39.66543512959635, 48.14061018728441, 55.39239406585694, 51.368987560272224, 47.19414618707473, 46.136714412320046, 44.403619074052386, 47.72355241160239, 47.93531725483556, 50.264734452770604, 52.24699443386447, 54.11885930645851, 53.41710805892945, 52.94704729510892, 51.22467963926254, 46.32329763904695, 47.82885236124839, 42.34647712399883, 36.71959784723098, 38.16852923362486, 38.3456281692751, 39.18125775552566, 40.46810111691875, 41.445473394086285, 41.38139363258116, 38.74198367518764, 39.53926424826346, 38.90974736982776, 40.15930075799265, 41.0253091012278, 48.797042369842536, 54.58408378785657, 48.710707079979684, 55.24866665563276, 50.36886945847542, 52.90808639218731, 54.47752867975543, 53.22062476988762, 53.64599797033495, 53.84869429372973, 52.03054628064556, 48.795638161320845, 44.8339815293589, 45.267340675477065, 40.91589850764121, 41.7111433705976, 40.19323318235336, 41.40508082605178, 38.84634617836245, 43.68848469949538, 43.91238143367153, 45.31438166095365, 45.414943387431485, 46.28137926901541, 46.78811419394709, 46.67020774656727, 47.23779432235226, 51.230429833935155, 55.217746611564394, 61.66748423730174, 63.945722349228404, 55.48500907036566, 8.140184542825146, 0.4614720295273489, 1.6086206368861662, 0.09076959062968531, 0.0989534551157586, 27.00398695084357, 63.50141194558913, 43.99463745855516, 44.07199444309358, 30.67291513566048, 29.41707811047954, 50.681301932181086, 53.774216328897786, 52.95982637713033, 12.661944358579575, 0.5489883511777848, 0.03283535197917973, 0.09031022898852827, 0.027194847690782724, 0.026011741720139984, 0.09952546232530188, 0.014188299800509648, 0.011598807703253004, 0.09819961693738738, 0.05936837056651712, 0.0768658072657643, 0.02774179807954258, 0.04502473782087046, 0.11691676903395884, 0.04361345830764021, 0.02227029087202203, 0.03292361296893608, 0.05201555826070328, 0.06274215283713515, 0.03386673232119891, 0.027780133119273572, 0.21599686614448027, 7.276414402069585, 63.9720336083443, 58.11423263242168, 60.87938201042914, 36.58388383926884, 56.415171700139204, 63.52402833200271, 67.49761289165866, 47.24303460890248, 61.419919921505844, 36.62153859292307, 0.2716883019574227, 0.2743335116294123, 5.840786714707652, 16.842902668060795, 2.9088968903787675, 30.619902341596543, 41.44899568250103, 50.485763934350786, 52.83360842735537, 54.941717655428, 51.409756675843276, 59.86276249731741, 57.89108114857828, 60.237788154232895, 59.03789981718987, 56.343129527184274, 52.610707975203, 45.17248599759994, 44.503439472567656, 43.670069171536355, 44.74109980367845, 50.377757549285896, 52.1552227389428, 53.773165133691606, 54.01454387172576, 52.79276478675104, 45.61702782107938, 51.59249205743113, 51.98322680688674, 51.435020662123165, 50.99815099470077, 51.04557245008407, 53.355271893162886, 53.30712872166788, 53.89421339957945, 53.46199174081126, 50.92575188606016, 43.10070183969314, 39.070619460075136, 41.21867410598263, 40.516730662315126, 41.350093118606075, 38.48975566125686, 39.72841270508305, 41.42518689555507, 42.177944644804924, 39.68641196527789, 39.457329857733946, 39.0717726369058, 40.36355426234584, 41.9622770432503, 47.638821371140025, 45.8887186358052, 43.20447206497193, 42.61402591582268, 42.454636481500444, 40.112369598880896, 41.35060302672848, 42.13993687783518, 43.75500417524769, 43.252477953510905, 44.105679758133434, 47.179354929154925, 54.22718732587753, 54.23562042174801, 57.53892683213758, 43.39882550701019, 50.546933297188055, 59.523948161832756, 53.25312552913543, 49.248362048979736, 47.907189938329886, 47.17335762516145, 50.250311897647, 51.54838500484344, 53.94564743964903, 53.254690554834184, 55.21101190197853, 54.88891470816828, 55.39695970473751, 53.26260982021209, 48.93185423266504, 50.237058208834746, 43.1131749768411, 38.93974957927581, 40.900342387537805, 39.764420063264915, 41.04067302519276, 41.76333442811043, 43.371619947495006, 42.3809390683328, 40.67257819637176, 42.22694681536767, 40.88078937222881, 41.638261810425796, 42.952785338124926, 51.529847883409076, 54.591559825405, 51.06552162478047, 54.190285667296386, 51.80013056724302, 55.67467135767783, 55.70121795900407, 56.91933747260802, 55.0209338434281, 54.862552458240145, 52.90355213226811, 52.119584083557136, 46.4483271106597, 43.9010928523156, 42.94621144571612, 43.70747289349956, 41.624321706833385, 43.29940911262266, 41.15666143355831, 45.87468439532865, 45.8177904159792, 47.72347788656912, 46.85601826637022, 48.91918105463828, 49.10955329095164, 49.33468557173207, 50.27486201255552, 53.725959408667784, 56.406150248742875, 63.742476894009506, 65.97652558357485, 58.66250937984836, 9.916649037791837, 0.5830942791315817, 0.22343452268790817, 0.11190671488762864, 0.06882114095553275, 30.622067489931663, 68.04279096664922, 51.25657243113364, 47.90494242022115, 32.325327319483605, 38.76067376905872, 56.34719702505297, 61.41866868542087, 65.00153810747209, 18.21168238116849, 0.6625547572489708, 0.01543143354806929, 0.04409225942987589, 0.04830033443267307, 0.03106616384860489, 0.07545476523979057, 0.1064517628401518, 0.022899838945557995, 0.009652196482244519, 0.03330538139468239, 0.06610850022444803, 0.06785468273465672, 0.13700098970965033, 0.2397569605419713, 0.12224289573608868, 0.12422812066131061, 0.1594087550596845, 0.24659116962744346, 0.18874733318244258, 0.20063010765419853, 0.22647664251346744, 0.3201077247579252, 9.28883642919602, 74.52162865669497, 64.80450568660613, 69.31748282524848, 40.91249389033164, 64.24764679324242, 67.11177718254828, 71.64113413903021, 52.306873336915054, 65.32516894801971, 41.31227362540461, 0.405762973692148, 0.3355966436286127, 4.840088592421624, 12.877798272717385, 8.367977661471214, 33.183035927434126, 47.3459929035556, 54.039070452413256, 55.51703130045245, 53.51661074546076, 52.78971710512715, 59.48878803560811, 60.77610208142189, 62.37765681359076, 60.86186078286941, 60.051769748810806, 56.995192189370435, 47.017333584447066, 47.12236289055117, 44.82798030299526, 46.99983196873819, 52.178815795529275, 55.6744634720587, 56.058553726442405, 55.587747712289136, 54.10618612843176, 47.39169636080342, 53.092469169247536, 53.89283664764897, 54.35409169043265, 54.06677023057015, 53.362657716197354, 55.02340101426648, 55.35886564562398, 56.55311361435921, 58.56015513020178, 53.593402908694365, 43.412518501281745, 42.013562033253336, 44.15334047809724, 41.672994398301654, 44.39712362904703, 40.31250461455315, 41.25781936030234, 42.76077355107954, 43.80460254607662, 43.20049870398737, 41.9556325481784, 40.54177499586537, 41.37693389769524, 44.5106017205023, 50.80935555119669, 47.78415303076468, 43.65647815888928, 45.432880386229485, 43.715384314137125, 41.7771254816363, 42.69525427972117, 44.05204526839718, 45.91169588027462, 46.453504639287154, 46.62985047986431, 50.28091422973141, 57.08004482330815, 56.78368622256864, 58.246675383660104, 44.50791489693427, 52.21668627954299, 60.533170084799494, 55.46734271510955, 52.770936796742106, 50.79077528369043, 49.17036179573306, 52.215093797253026, 52.74052666079614, 56.68295191180322, 55.49608584373228, 58.11169093655002, 56.484860450990745, 57.38221245427286, 55.86029360371252, 52.20349142628332, 52.463062117176676, 46.24520717128631, 39.9027189131706, 42.72745301646572, 41.5631248874049, 42.77267402218234, 45.178416621300485, 45.43823834388487, 44.90767502015637, 42.13931322097778, 42.979422153965125, 43.33481242579799, 44.608613906368134, 43.84919205019551, 54.38202288842971, 57.67291891959406, 55.27535838465537, 54.31188698737852, 52.66299709197014, 57.51739694226173, 58.946461523732836, 59.909450469478486, 58.09145542883105, 56.4568272713692, 55.2184683276761, 54.31831575209095, 47.923452085064305, 48.54816406003891, 45.03941566713395, 46.353880359280495, 43.00816920495803, 47.659484417207786, 42.671853419273134, 49.19715158400997, 49.102085098143554, 51.461908509654386, 50.16875405465403, 52.63825478092317, 52.76588870633034, 52.36408895061862, 52.94819262719924, 57.68903201626193, 60.43465975792178, 68.06154774081323, 68.80578610204881, 60.976197873392415, 13.108971984155717, 1.1694605504312825, 5.620419623390322, 0.33488179166470805, 0.2538593981655375, 35.046110768472, 76.1870199634183, 57.166109469629106, 56.64709360368791, 44.288097427737334, 43.20218924553164, 67.4579498844762, 70.88679175223075, 76.34227521957891, 24.155873560136367, 0.8986893476497744, 0.19373346240289752, 0.29361536245672937, 0.18687486107791626, 0.17673420118949107, 0.12067836799448538, 0.18871391642718546, 0.0953323183761489, 0.2524570129331081, 0.2075600624084473, 0.13200785844556748], [0.021182626050205964, 0.07132199667995015, 0.01539208631466834, 0.11281694991574173, 0.03479731847502051, 0.007789912868306162, 0.07103720349409888, 0.05046989160379575, 0.04041402232682994, 0.1146415721685175, 0.23530712351202968, 7.693511891749598, 50.14628671830701, 51.79794580705705, 50.626443662951075, 24.506804097083307, 34.831321777835974, 60.38055066139468, 54.51872925604544, 37.54716304040725, 60.568808740185155, 30.16785506279238, 0.12349640710219262, 0.1687186998465369, 9.937003197208528, 8.727015737564333, 4.3072880468060895, 25.21765720459723, 15.96883777649172, 31.416943650091852, 53.81493053128643, 55.03237539722074, 55.408001176772586, 58.79304193681287, 56.59682842992968, 55.03568980001635, 53.212485851780066, 48.88108307315458, 42.72288737758514, 40.42224860960438, 38.48305233063237, 38.02431544949932, 42.16101177277104, 47.23776686576105, 51.79929510239632, 50.09593917477516, 54.32643113597747, 53.35289101446829, 47.052493710671705, 48.98204488138999, 52.05564552737821, 47.651376878061605, 46.29413481681578, 45.345160499695815, 47.37444577678558, 49.79300275925667, 47.0432996749878, 44.23068569552514, 39.10965096565985, 36.46003500107796, 38.318061751704064, 39.400494713937086, 39.504704244675175, 39.32132559437906, 38.73705325588104, 37.967931378272276, 37.261167341663, 38.306541750507975, 39.4009889325788, 37.43195518370598, 39.193083701595185, 37.942122182538434, 44.257181306039136, 47.5913175459831, 50.03306750328311, 46.05255211553266, 42.1451065617223, 37.48900605786232, 39.89557235471664, 41.25635631622807, 39.888025714505105, 41.34287987985919, 40.233786567564934, 41.36520208850984, 46.02134966081189, 52.7925019879495, 50.63953653458626, 55.47951382975425, 40.621881561894575, 47.85811716510404, 54.17193289726011, 50.1141821184466, 44.881222555714274, 42.13271579434795, 44.77872317837131, 44.26065260364164, 50.19260206530171, 48.90442509805003, 50.04800781126946, 49.69796372998146, 49.067391733969416, 50.91896618566206, 48.97647119337513, 50.73350475680444, 54.10270698608891, 47.73441345460954, 39.399996572925204, 39.51744410299486, 39.42876715813914, 39.524331785017445, 43.181738007453184, 38.40200047339163, 39.16584676311862, 41.2198547394045, 41.794011285228116, 38.03348202859202, 38.86236121577602, 39.91955372595018, 40.69965824004143, 50.31314434543733, 54.56247545057728, 50.18029366770099, 51.158348437278505, 53.905364697979344, 55.620872128394346, 53.86265008680282, 51.57125242294804, 54.571881294250495, 51.99540184390161, 51.097461485093646, 48.14712524414063, 44.533143581882605, 40.94774030870007, 40.58670182381907, 42.13922300646382, 41.92325338240593, 42.876659977820616, 42.63857210836103, 43.904183680011386, 43.9447174533721, 44.44099533942438, 43.19825510824881, 46.48334210918796, 45.972767183857584, 51.66759760149064, 52.15297522083406, 62.38177137990152, 59.77955725885207, 67.12920035085371, 51.8705371118361, 27.298653048853723, 0.20527866789169852, 1.5371609359018266, 0.12722996724469046, 0.0706035900680769, 19.466132848493515, 61.544184530934984, 43.11329657031644, 45.3642898990262, 38.9275666975206, 12.78876635336107, 43.471106944545625, 51.73431711812174, 59.895828077870036, 19.8194521088754, 0.8004869268305841, 0.10803363481236082, 0.01628103463219539, 0.018269507770216274, 0.03925216571998693, 0.03715148368369668, 0.011028511742610606, 0.04464057537036077, 0.027806994077118657, 0.05571121620314737, 0.04906979314382038, 0.05824063168538194, 0.10362037848080359, 0.026322332916841395, 0.02025755189899956, 0.08024067738123479, 0.006125220088213082, 0.09009493529916772, 0.03140549100334606, 0.05136091697720751, 0.03723569206833359, 0.24868629752628266, 10.671523886342204, 62.65729042791552, 57.00073057605375, 59.32415831473566, 28.754152444101152, 45.67871493677939, 69.40728941271382, 62.74519074347712, 44.013774702625895, 66.55842488811862, 33.86869369014617, 0.09275756581055541, 0.11729595957383995, 2.3593306637579397, 2.867320747144761, 3.3584743017150513, 25.983186191128148, 16.87582115973196, 33.2793693388662, 55.548755430406146, 54.87761043733167, 58.02094690261349, 60.427305313848684, 57.429786882092884, 56.52942249851843, 54.69772269648891, 51.40096664428712, 44.726292856277965, 41.98741943605485, 40.21104858767602, 41.055993803085826, 44.0016741906443, 49.358345308611476, 51.969992729925345, 52.89438555317541, 55.048359055672925, 54.14253473281861, 47.363290556015514, 52.69077139516031, 53.99334738331457, 50.18911115584835, 48.935733456765455, 47.700708527718824, 50.36682198124547, 52.11126865879182, 48.34737400854788, 48.31604603798159, 40.468971883097005, 38.549575728754846, 41.462410188490345, 41.90161366616526, 40.57201254752375, 40.90773605531262, 39.37249291327692, 38.54118185658609, 38.62014701289516, 40.54422255485289, 42.24466023906585, 39.49150154667516, 41.554064212306855, 39.56956455784459, 46.29950454158168, 49.12020252596948, 51.70719392838017, 46.818657690478915, 44.61391695084111, 40.25114305557744, 42.05733568437638, 42.86935652455976, 40.99856245902277, 41.894082715434415, 42.73736092352098, 43.25897732088643, 47.73850056432909, 54.57578013020178, 52.899476789659076, 56.047806432170255, 43.38630922379033, 51.71586628883116, 56.56570050024218, 51.57271546702231, 45.97117077919745, 44.74947798636652, 46.25011405637188, 46.86412972788657, 53.32966666067801, 52.145012809384255, 52.605491222873816, 51.74746490293934, 51.18503232156077, 52.41949635167276, 51.13423370545911, 53.13041417829452, 53.985855656285445, 50.12858113934917, 41.58463516542989, 42.00088493285641, 41.12500006152738, 40.784632467454486, 44.000548470404844, 41.27415603207004, 40.235473186739036, 40.60564687175136, 42.465226880965695, 40.509866514513575, 41.022696802693034, 43.055351395760816, 42.702102738042036, 53.625797763947524, 55.84243112994779, 52.69512130368141, 53.49926210218861, 52.24393498513007, 56.19429126862557, 56.471096854056086, 53.18600985311693, 55.98335012312859, 53.07447725726713, 53.3996731235135, 49.31729770475819, 46.701669077719416, 43.80034677443966, 41.55697853334489, 43.94485473632813, 43.5453103434655, 43.624714805233864, 46.07978120926888, 46.85911693880635, 46.262508746116396, 47.40066289901734, 47.56817948433661, 47.77341358123287, 48.1063953522713, 54.611226589449, 54.712459041226296, 63.34684310420867, 62.994414221855905, 68.43199991410779, 55.58996777380667, 30.91234837808917, 0.15033246708973763, 1.2030368971247827, 0.05651016929937948, 0.16602894982262967, 23.12947753937014, 68.30171446646413, 50.166357486478745, 53.78001751438264, 42.51315039973105, 23.324660562699844, 52.86201030977311, 59.07962991345314, 68.96004507618566, 24.716723465150405, 0.7586428979712149, 0.01363951080073152, 0.027958551166398872, 0.05848065852337788, 0.06437572425291424, 0.04978364536298379, 0.14738157301420166, 0.06596467487754361, 0.030727591290469133, 0.04959905647762841, 0.020029767146033627, 0.151815751206971, 0.24155542855301212, 0.10614740376871441, 0.2270864638229532, 0.18643132681327482, 0.12224508674755213, 0.1831931344443752, 0.2469240654740603, 0.2708379137179544, 0.21670839328679348, 0.3822685892303144, 14.045923256104993, 72.51182971462127, 65.03295629255234, 65.68454827031782, 33.54567081697526, 45.37999114682598, 66.5210682345975, 61.87143964152183, 49.32981791034822, 72.34619586698471, 34.5418587038594, 0.3607846339864116, 0.5036338316577097, 17.5129533198572, 15.621128486048793, 6.215132330694507, 28.378730627798266, 17.459071720800093, 35.312184749111054, 58.44613967403289, 57.80052146603985, 60.73225782763574, 63.89196626601681, 60.19445380856914, 57.41860812710178, 55.955795472668065, 53.41390348249867, 46.773891679702274, 44.296989440917976, 42.57256254073113, 41.8164001741717, 47.16211218987742, 51.502234397395966, 55.44405952576668, 53.990542888641365, 57.62053566594278, 56.006903956013346, 49.757862244882894, 54.68450823137837, 55.553517187795336, 52.32884645462037, 50.579041819418634, 49.908736213561035, 51.00202237406085, 54.751376798076016, 51.20736629732194, 50.372254463934134, 42.04366622432586, 40.362412852625695, 43.619345080467966, 44.19086579353579, 43.761327035965465, 43.47014596385341, 42.29447434025426, 41.41409835507793, 40.59668425590762, 40.9691446827304, 44.620435930067494, 40.496781487618726, 44.037524654019265, 41.48769770899127, 48.646419432855424, 51.41944885253907, 54.06757823882565, 48.764502386893, 47.895979804377404, 40.577598002649125, 44.83649184626918, 44.169845811782345, 42.358346216140255, 45.43032300087714, 46.132223298472745, 44.20335069779427, 49.58327754851311, 56.1231198618489, 53.45309972763062, 58.64981266760058, 45.78772152623823, 54.642660464009936, 58.0739067446801, 53.95658693005962, 47.47596848395563, 46.48843334567162, 49.10147320839667, 47.6760015180034, 55.6185696971032, 54.57523099837765, 55.272989273071296, 55.38888354455271, 53.885305696918124, 55.81528048361502, 53.054488858869, 56.28394880602437, 56.93030049723964, 50.650115166941, 42.75428202844436, 44.24030726955783, 43.81911139334402, 42.48738042769894, 46.90747584066084, 43.757012428775916, 42.44839599055629, 44.02753045482021, 46.043471828583755, 42.196819090074115, 42.30841444384667, 45.24856428946219, 44.30568141321982, 55.76236770999048, 57.53168221442931, 58.47999365099015, 54.040286387166674, 53.7329843736464, 57.77854442596436, 57.64195180708363, 55.81607672476, 57.81921155991093, 55.68778776353406, 56.4577764849509, 52.21205788273966, 48.93199936036141, 45.98423619424143, 44.654003574002175, 46.042220592498786, 46.714522684774096, 46.55213263727004, 48.57834277614471, 49.9701605304595, 49.683105791768725, 51.8708195224885, 49.70563196366834, 51.216932958172215, 50.11777108715427, 57.11049810532601, 58.19403325357745, 66.30627139922112, 64.95600331214168, 71.90884374803113, 53.538705456641416, 32.777733495158536, 0.4328877875401128, 4.769286378737419, 0.5999585096874546, 0.28683621977125445, 26.40331126028492, 75.59353397738549, 59.32824934682539, 59.02145724142752, 47.10683422703897, 22.835056589495753, 60.26640184463994, 66.78991533094838, 78.80923424997638, 31.917475346596014, 1.1303172572966547, 0.23470997329681154, 0.17673913479572345, 0.19009413107508616, 0.19974561318034129, 0.17011567649822082, 0.3562086375970995, 0.1926925021313852, 0.15981996041392127, 0.12598989306077843, 0.11442204967381493], [0.004023305129169697, 0.022945507361944166, 0.05673549107966885, 0.05122312074226718, 0.060789260652757464, 0.027288410008975097, 0.04481458841192146, 0.045958127856494925, 0.020244945922205528, 0.037786244985557375, 0.06261296743046373, 5.541474078932117, 52.14450682363203, 51.23578779159054, 49.87368199133104, 30.33630713339775, 40.44391186006608, 49.2202425772144, 32.867802881425426, 35.85581348788354, 66.46194242662, 23.397283246440274, 0.10365929574735704, 0.09515403439441035, 0.8114647829244215, 4.921950419102946, 3.070751044058031, 29.74615320082634, 28.962438144991477, 43.172198803194114, 59.20007805670462, 58.64607464882636, 55.54256593027423, 56.422655582427986, 52.73937348396548, 49.106948837157226, 41.66960939284294, 38.536898628357925, 40.899718730680405, 42.654610679995635, 43.61275942094865, 42.09650447291713, 39.37648588611234, 42.42628166752477, 46.65102343405447, 48.04469646946077, 49.587027334397845, 53.358931464533654, 50.91141562308035, 47.61961744677636, 51.87337298547068, 50.474891124233125, 49.28376536215506, 44.06069017225697, 39.530999814310384, 40.04355161420761, 38.4980946202432, 36.55527407123197, 38.828726891548406, 38.65532282860049, 38.44621735234415, 41.320816547639915, 39.2593756798775, 39.424260354811146, 37.70007271920481, 38.649290223275464, 38.20644678608064, 36.93271983054377, 36.810408561460434, 39.141253502138206, 38.68786281155002, 39.47193676425565, 44.69774192379367, 51.09770074967415, 53.834048163506296, 48.8611025194968, 48.88587228713497, 46.95849410949215, 43.11981162717266, 45.406757400881865, 42.67059041607765, 41.99585253192533, 43.143604724637925, 40.771531751078946, 45.4434197948825, 55.72430502983832, 51.643659376329, 53.95528470316241, 39.88069480465305, 48.26180358086863, 54.6897328284479, 48.92142857274702, 41.56589015837639, 43.46660798595798, 44.52387894353559, 48.60088855989518, 49.034910586572465, 51.64597357473066, 50.527235154182684, 51.48132816437752, 50.42667342770485, 51.714552294823434, 51.82452378734466, 53.836421197460545, 53.05922315966699, 50.87915020604288, 39.84791163475283, 36.85398217170469, 40.06770556972873, 39.490332680363814, 41.981010283193285, 40.53879007216423, 40.63326820250481, 39.27913658080563, 39.45610607824018, 38.71469574589884, 38.900310147193174, 39.47727118769, 38.550168006650864, 41.182792263646284, 52.66123594776277, 52.06401194295576, 48.90420152295021, 49.36730007971487, 50.43100764674526, 51.9499925644167, 53.022282277384114, 54.53867450837166, 52.971452282321074, 49.958354196240826, 47.055200146090606, 44.93524928246775, 42.11503374961115, 41.08513701346613, 42.23832953360773, 42.460394520913404, 41.23918810198384, 40.677704734186975, 45.87382539626091, 46.24565039911578, 45.76630146272721, 46.30459970043552, 50.02015898304601, 52.10665595146918, 54.0323631994186, 55.45457932256884, 63.34818063243743, 61.56016818938717, 69.21109245669457, 54.48913105072514, 48.60091209411622, 3.0685751092049385, 1.085398641805495, 0.6797749428979812, 0.20395382607896484, 17.709344433199977, 58.80650743361443, 50.44495951744818, 38.114981036032404, 50.60597281302176, 34.25510206530171, 33.42402635082122, 51.540563798719845, 60.07591978196175, 25.565081142610122, 0.239469263882887, 0.029176320700395494, 0.06211008050388867, 0.030989618258430596, 0.07242827360788662, 0.018064217273927024, 0.06070602903022401, 0.06135975100821065, 0.04358654946929986, 0.029432061916938233, 0.06205519030411398, 0.0523233762191188, 0.02602534552645539, 0.03468751126239377, 0.07675553656994336, 0.024068747391744007, 0.07349472162463973, 0.07636683887892193, 0.061164287504770105, 0.0353831114367612, 0.06010134434027057, 0.13485261870007362, 9.818051438177786, 61.03852041306035, 56.48727270864672, 55.1744475672322, 32.91295720684913, 39.443193635632916, 59.37656510260798, 44.897959309239546, 40.009681947769664, 70.7720781141712, 26.554414687618134, 0.08870138306050532, 0.05250535274465239, 1.6129888089433795, 5.636618031609443, 4.697204982080768, 33.98788275257234, 31.8444957271699, 46.5671984611019, 60.28694721960253, 61.186480060700454, 59.15429222968317, 56.336332059675655, 55.621711515611224, 50.47144336085166, 42.95110656369118, 41.12842821305798, 41.85591805365778, 43.76081712784306, 43.83703270266133, 43.973287997707246, 41.79878088735765, 44.624068044847064, 49.2771718578954, 51.13694798561835, 52.82115490205827, 53.553739901511904, 51.601537043048495, 49.65934799563501, 53.589892387390144, 52.25912632480745, 50.466971858855224, 46.88092531696443, 40.84515071684315, 42.92754488606607, 41.098500528643214, 39.495537665582475, 39.70854982253044, 39.81975293928578, 41.36689655242428, 42.25518395823818, 40.44742630374047, 41.04577602878694, 39.36322827492991, 40.319643328266764, 39.5582720541185, 39.4023068489567, 39.20104611304499, 40.61219330756895, 40.59100858626827, 40.730582206479966, 47.93091635550223, 52.31445920082831, 55.02171439509238, 51.67952160681448, 51.846143891734464, 47.18837638055125, 44.256290928010024, 46.333876271401685, 43.07367670920588, 43.321546969875214, 44.14460928209367, 43.92610972927463, 47.266984601174634, 58.71382967118294, 53.66682575594995, 55.54207563400269, 42.82838344573975, 48.930740279536096, 56.51550592914705, 49.716653823852546, 43.91615475377729, 45.3130990459073, 47.26179138306649, 51.88933310970184, 51.82678699493409, 52.82681880458709, 52.79204699300951, 53.96990729916481, 53.319260612610854, 51.69257917711812, 53.827858663374386, 55.769541725035644, 54.56467590024395, 53.996371530717425, 40.55281254553026, 39.06528111427061, 41.20704820079189, 41.4499488184529, 43.90674106536373, 43.82250424354307, 42.20072969313591, 41.46487735932873, 41.10463903796288, 41.38465312219436, 40.927453810168856, 41.71253973437894, 40.18804780898556, 44.41010275194722, 54.07931397038122, 54.17916967022804, 52.653363750826934, 53.94470999317785, 51.70080830973964, 53.31957832459481, 53.584381457298036, 55.738221599209695, 55.29079291128344, 50.133213458522675, 49.633934959288574, 46.29369943372665, 44.719664050686745, 41.97554642154325, 44.8739504814148, 45.22011926097255, 43.3257007598877, 44.091563147883264, 47.5874500889932, 48.504057007451216, 50.02015506067584, 48.57465574818273, 53.45465690858903, 54.10744520925707, 57.601010107224994, 57.21649623686268, 64.89344150789323, 64.7124162797005, 69.15537126602666, 57.84624845750871, 57.51541222295454, 3.657250798517658, 1.1354963793869943, 0.32625135154493395, 0.15839909714075828, 19.62316886071236, 65.67900203889417, 54.94637350882254, 47.670290547032515, 45.38301921659901, 32.240582550725634, 43.616493517352694, 57.37579153430078, 69.19986663326141, 28.766431423925585, 0.4701208557573057, 0.03366495242282268, 0.055682962880499905, 0.016790396916950424, 0.010957464748512833, 0.04533088570761104, 0.06229664972652832, 0.04393547187529264, 0.020830468837952903, 0.06176504599411161, 0.058507532887761636, 0.18083580529257176, 0.14283081156111535, 0.14890817174267384, 0.23046933955723242, 0.14752423390746117, 0.2295704273086402, 0.1390544117818917, 0.194568743388499, 0.12520003342820754, 0.2208190985144146, 0.2786832975764429, 13.87578554691807, 74.27371132758357, 64.32392512598346, 64.95873720415177, 38.976953260360226, 52.13332806864093, 56.601849063750244, 45.980360892511186, 47.67282047579366, 76.57991593883884, 28.92547372848757, 0.31107698837595604, 0.1744873265946104, 3.6590572951301454, 14.56331329960977, 5.316115771570514, 35.79240837404805, 34.81668741472306, 51.211806420357, 62.9282203028279, 63.89456287507088, 62.52621658386723, 59.532063545719275, 57.27260574217766, 54.02211012378816, 44.4546373428837, 42.36386891334288, 43.260357995187086, 48.159602303658765, 47.52460979646253, 47.16501474380494, 43.67455244064332, 46.38314124076597, 51.04465069309358, 52.937080552501065, 52.531974238734094, 56.17052562775151, 53.89545679092408, 52.279652087919175, 55.87537511702507, 54.564503315956365, 51.88194728666737, 46.66304942100279, 41.727942882045625, 43.947027729403594, 42.430690411598455, 41.11333493263491, 42.88426937595491, 43.38493639423002, 41.710021572728316, 45.27031383206768, 42.428909655540224, 44.24521023227323, 41.61128767075078, 42.82542990099999, 40.96905446821644, 41.09660210147981, 41.13870482290945, 42.77141101898686, 43.57477126582977, 42.1491583701103, 49.95785997759912, 54.94793461215112, 58.34640164529124, 52.921551888988866, 54.70801499582107, 49.86089898693947, 46.678064254022416, 50.13027168089344, 46.368302914404104, 46.31227185649257, 47.40225145893712, 45.52594646330803, 49.97829944856706, 59.75672121970885, 57.64204202159759, 56.52364876962478, 44.407655192959695, 51.19455191396898, 57.048352072315836, 52.49125219160511, 45.62107962946738, 49.42726527490924, 48.97385105010002, 53.026989121590894, 55.7513262379554, 54.96888399124146, 55.90893883858958, 57.103677103596354, 55.23547180237309, 54.821955926956676, 53.95883444816836, 59.98358326573526, 57.11845267203547, 56.98508816380655, 43.21827488560831, 41.06696467245779, 43.09039385088029, 44.27993497540874, 45.06845689588978, 44.850788885547274, 44.239158015097345, 44.49156253568588, 42.98742378911665, 43.02243486527474, 42.265872416957734, 45.1695167633795, 41.74842942145563, 46.38520048510644, 56.19220064532373, 55.125378716376524, 55.877293156039336, 55.512853976218935, 53.30868198025612, 55.41940742923368, 54.64541789024107, 56.77594738621866, 58.189746102979115, 53.71092888616747, 53.28067233485561, 49.71866207738077, 47.41082968250398, 43.59376730457429, 47.31001300196494, 48.62408545709426, 45.991092497302645, 47.0286770789854, 50.474106650198664, 51.286621709023755, 53.05370046246437, 51.05471941732591, 56.66207705774615, 56.932238148104766, 62.15630569765645, 59.306444891037486, 69.77586669306602, 65.8656950919859, 74.64080595201062, 54.332914813872314, 55.95882746481127, 4.77241397865357, 2.6222532651116772, 1.4028511364613812, 0.26749455279880957, 23.009772685266313, 69.30001258850098, 63.722343367915, 53.57971775916315, 60.40935654794017, 45.011205980854655, 50.828045645067775, 67.08879993807885, 79.93202840128254, 38.42174568483907, 1.0490235614199792, 0.12349850618310514, 0.2651286281404957, 0.08612749617426627, 0.126546417633372, 0.08256835893036858, 0.1729187615696461, 0.2829203766680533, 0.13072201050817966, 0.1638278413203455, 0.1379982523259617], [0.034054634536826806, 0.016315382184280504, 0.022555198971061938, 0.05743438160167106, 0.07996760534062501, 0.016762836903874433, 0.03830709284351718, 0.038675531339381015, 0.07896200002681825, 0.08347755207890466, 0.08254873941862777, 12.34224275235207, 51.936852624339444, 50.26802532134518, 50.90626947341427, 35.15843960546678, 32.534989772304414, 28.93429513900511, 30.158678677774247, 41.8629430186364, 63.48655008500623, 21.701856390122447, 0.0920064855487116, 0.20569856068299663, 1.174288497817132, 0.8776949225894867, 3.732547803271202, 39.021436860484464, 56.51345452954693, 59.86027179225799, 56.466158590009144, 56.42788410186768, 53.079780301740094, 49.78374988802018, 42.73292080048592, 40.674943385585664, 43.00961655955161, 47.513991940406065, 49.94218226402037, 51.71953762731245, 50.37206619016586, 50.21150004479193, 47.38012536879509, 43.822339503995835, 45.37544511979627, 46.76248934961135, 50.79322284267795, 52.25545498632616, 50.884931779676876, 46.40985650400962, 49.6467532650117, 51.69789006633144, 47.46971622590096, 45.29154169944025, 40.313242020145545, 41.81265823302731, 37.155577136624245, 38.170655158258256, 36.87282131564233, 39.0431236451672, 38.5160316190412, 38.515917870306204, 38.017992588781546, 36.56424453181606, 38.41334396792997, 40.01875438997823, 38.51731423408755, 38.14809368502709, 39.85499151291386, 36.36932626847298, 38.19776265851913, 36.8095495623927, 47.31229582140523, 50.15121713761361, 58.98892118084816, 55.96406382899131, 50.229127176346324, 52.44701177843156, 51.94261850849275, 53.76145685872724, 48.61333816282211, 47.8434161216982, 44.41238164901734, 42.320212933325, 46.65911136134979, 53.91337810024139, 51.895918769221154, 54.01661488317675, 44.606613497580256, 46.15872283135691, 55.228046755636896, 49.92817548013503, 41.61554736475791, 43.50243099274174, 49.565442531339585, 50.856357312971554, 61.85959016123126, 52.92665881495322, 54.77600928275816, 53.72550049135762, 51.24775102061611, 52.69122246773013, 52.309991621202045, 51.10421580653037, 51.57357838846023, 50.82835943468156, 41.827331819841945, 39.425542969857496, 39.58411655118389, 38.0015500130192, 38.6815321060919, 39.875842832749896, 39.44375845693773, 39.69696706341159, 41.021374963944965, 38.90492285451582, 40.69304904630108, 39.11485987324869, 41.507693952129735, 39.18241093235631, 41.40427674016645, 49.338686389307824, 52.39771935247606, 53.499324860111365, 53.88396032394902, 51.93392261382073, 53.22637104219007, 54.48344753634546, 53.31698956028108, 49.33254003524781, 48.830115795135505, 46.405530129709554, 45.958022994379846, 45.1284573924157, 44.563506649386504, 41.07987319269488, 41.162874467911266, 41.54365424186953, 48.12131997077696, 47.324172758287006, 49.458844277166556, 49.03914282398839, 52.75304686638617, 52.160290441205426, 56.967045261013894, 57.89809434644638, 62.627939331916075, 59.705887302275634, 65.71305605673021, 61.674136577113984, 69.14128211236769, 15.444256067276003, 1.0343388203651676, 0.030644612476950696, 0.07989176263612124, 11.302338088712386, 62.389682800539084, 54.06015319208945, 49.24183130264283, 45.219978055646344, 60.64045083138251, 42.3909411122722, 47.25332298586446, 59.09382497110675, 32.45562453423777, 2.4642881414582654, 0.0381038190736886, 0.0520862375325974, 0.03922272113061721, 0.045086951821201274, 0.026234403260112293, 0.08313075939734137, 0.008114874438052217, 0.015033190401511328, 0.028572840683702982, 0.050946758354022625, 0.005226815851675648, 0.028104793520704396, 0.05045145569789795, 0.06599336487030791, 0.04385733090701603, 0.04116103849223545, 0.05618363198253417, 0.028745290905898137, 0.05376329592939827, 0.10293488300615743, 0.08766524148203673, 16.62145741524235, 62.30828969709335, 55.12388429334087, 57.9414600710715, 38.49352898136262, 37.9041693287511, 41.906861797455825, 37.80720441572128, 46.60129954738002, 70.75965204546529, 23.504201173782352, 0.036056510383082975, 0.11248584671486771, 1.389383678474734, 2.3590997342140447, 3.983758942734811, 41.41130954988542, 58.227169436793176, 62.41222858428956, 56.70007305760538, 58.503951488002656, 55.10711223848405, 53.61366587300455, 44.7785976625258, 43.543168729351414, 43.02130522266511, 49.36065558464297, 50.2216629059084, 54.80962399513491, 52.640325792374156, 52.57987814564859, 49.20933054339502, 45.20991325378419, 46.827020183686294, 49.732896358736106, 52.59852117107761, 54.05852540846794, 50.04117896479946, 47.730867631973766, 50.89531821589316, 54.42126620200373, 50.35620412518902, 48.615970073207734, 41.41887972431798, 43.4406771967488, 39.94138956069946, 38.50101678602157, 37.95802739358718, 39.467402504336455, 39.76103113543603, 39.91591376643027, 38.404365662605535, 38.93163027301912, 39.22460779067009, 40.99646006861041, 40.59735890357725, 40.45662033942438, 39.43614121406309, 38.34878567726382, 38.69251474257439, 39.74107411599929, 49.871477619294204, 53.356613343761815, 58.827299917897875, 55.11308208588631, 52.80726971164827, 53.31910371780396, 53.621538069940385, 53.71122698630057, 52.242350347580455, 50.075021174646196, 47.181802488142445, 44.729038515398585, 48.25532774771414, 56.286953341576364, 53.07464984155471, 55.267858812885905, 44.666872870537546, 47.922663688659675, 58.05230625214116, 51.09809690906156, 43.688927927324855, 45.300790648306574, 51.72156157032136, 53.662793559412805, 60.91857041082075, 55.072622837558875, 56.9093511181493, 54.761272938020774, 53.69401954835462, 53.44893417050762, 56.07804790619881, 52.42183800666563, 54.2962210409103, 54.1025814702434, 42.51772388335198, 40.85929478368452, 41.55963790032172, 41.29333249984249, 40.67050718492077, 42.00206948864845, 39.85971404660133, 41.108106413195216, 42.01262458678215, 40.96434762400966, 41.86179768654608, 40.845590022302446, 43.99312342366865, 41.77723138563095, 44.52135293714462, 51.99519788065265, 54.34506239429597, 56.58435529278171, 55.25484046628399, 53.827537029020256, 55.593023300170906, 54.64393915668611, 53.33198085907967, 52.024207730447095, 51.42393996638637, 48.75254308023761, 48.70547071579964, 48.06493197717975, 45.62217004837529, 42.988267098703695, 44.09215542577928, 43.0330958674031, 48.67418589130525, 50.1255020787639, 52.77347849261377, 51.48785498834426, 54.74439497916929, 54.56711169212095, 58.98195112905195, 61.066867382295676, 63.997497635502974, 63.67902078936177, 67.88179336055633, 66.41972987882554, 75.41603103760751, 21.485718104147143, 0.8793850964115513, 0.16922557426075782, 0.12431153231450628, 12.457546707122559, 69.04193632064327, 56.901914304302586, 53.20770056016984, 54.19916591336651, 66.81484591576361, 51.37666756106962, 54.09942396225468, 68.97586007272044, 41.294469987192464, 3.441260336868225, 0.046720634319729386, 0.007289576056909057, 0.05393294226979056, 0.012874223438331918, 0.014514126570805188, 0.05284889721341672, 0.03412648592324507, 0.007132292460394844, 0.05857055894129219, 0.019016244313529423, 0.07246524501111239, 0.08264037119525094, 0.17221854188509528, 0.16966823518516558, 0.18421278214983403, 0.11093157689057051, 0.23061322619117078, 0.11960857217350315, 0.26469471594018323, 0.3201145276186928, 0.188257634459484, 20.005364610302834, 72.28743091706308, 64.77906911603867, 64.24009623066073, 48.815018592342255, 44.60729598999024, 37.78586672198388, 42.61176270823325, 53.87643721795852, 75.63598971213065, 26.305634437068818, 0.35829304026499875, 0.4137559673718868, 5.369419801619745, 4.056619665315075, 6.35037124156952, 41.098233807471495, 59.421425250268754, 64.46136105445125, 57.86762145257766, 61.44968678874355, 57.974957112343084, 53.9419682564274, 48.55153337601693, 45.70322975035637, 46.4254871491463, 52.22508407408192, 53.68890085527974, 58.19057372308547, 54.09698817037768, 53.67743184489589, 51.31141501088297, 48.12892544654108, 50.17757938754175, 51.92252812847015, 56.34334525754375, 55.2009706343374, 52.18359716476933, 48.824734303259085, 55.02842164808705, 57.053062838892785, 52.65299112566056, 50.47287894833473, 44.66293088851437, 45.88385097442135, 40.81421106092392, 40.84730802043792, 38.725827432447865, 42.736815714067035, 42.033228797297326, 42.142176551203576, 41.56947128234371, 40.18862439740089, 40.866162853856245, 44.792078848808046, 42.41807999149446, 41.272520403708185, 42.024368163078066, 40.90879901762932, 42.37240399083784, 41.229182135674264, 51.36362960261684, 56.27028326834402, 61.125542117703354, 55.8584265555105, 56.26943211401663, 55.79509988907845, 55.45766622789445, 56.320234652488466, 52.85877043201078, 51.9322830630887, 50.052946075316406, 45.0801141800419, 52.51812827202582, 57.64278727193033, 57.32733849556216, 57.59958628685244, 48.80400849926857, 49.99268277998894, 60.12589470032723, 53.75664411052581, 45.50908419393724, 47.809385638083185, 53.82845486364057, 56.37173537285098, 61.916844998636556, 55.465714931488044, 61.03082472278226, 57.53667539165866, 56.92111822866625, 55.75712742344026, 59.05552302637408, 55.144045276026574, 56.71415044415382, 57.0598485392909, 45.58393870630572, 44.02181948384931, 45.134897924238636, 42.17251608448644, 42.518284782286614, 44.26528884518532, 42.238502117895315, 43.35069802499587, 43.545075001255164, 42.65456361155356, 43.636317176203576, 42.93995526529128, 47.30201921155376, 43.786645935427764, 46.94364793838994, 54.518756712636645, 55.22470881862026, 58.85826310803814, 58.81395993694183, 55.74815696285617, 56.253201346243586, 58.40431936325566, 55.2516790359251, 53.88347002767748, 55.03934937138712, 51.40808966852004, 50.28049845849314, 50.595853097977184, 48.94538248738935, 45.86077567069761, 46.767976745482414, 45.809357320108724, 52.24027149138912, 51.96248139104536, 55.147783294800796, 54.75467158902077, 57.067536384828635, 57.69711602118708, 60.807634015237134, 64.76263830738684, 67.84400524631624, 64.6116937360456, 70.44095162422427, 66.11857814173545, 74.18337914251512, 27.243694759184315, 1.969391174854771, 1.0242676446514747, 0.29124358488667396, 14.064914391886804, 76.13475045850201, 65.25639803178849, 61.53665750257431, 60.211818141321984, 66.42588015525573, 53.61070448352445, 64.43201780319214, 74.60379446706465, 50.75683893695955, 4.836755558367699, 0.14814102661705789, 0.11755547185818996, 0.16642596722850878, 0.10675520260608005, 0.08341478649526836, 0.13852746586405462, 0.11430657724098814, 0.09410213438733932, 0.10442810328376871, 0.14707797236980932], [0.052247732697475346, 0.037019923404459996, 0.03448525638950448, 0.024489239646842884, 0.04050868015075403, 0.013686256528261208, 0.043960867689982544, 0.07472866710515753, 0.10251155814095851, 0.2289236958829626, 0.10258032985392118, 13.209320922051708, 48.970885738249756, 46.63745595562843, 38.77586118636593, 30.14870801279622, 24.446483927388346, 30.13759986046822, 39.72274488018405, 42.47653115180231, 64.94531093105194, 17.833750247955322, 0.03191147484035502, 0.032145217842152046, 0.3578257572747046, 3.2818976236927897, 6.980198477545093, 42.512432605989524, 58.1660863660997, 56.443910906391764, 54.15794964759581, 52.68945740115259, 46.784925306996996, 42.956778310960345, 45.815452683356504, 48.057338268526145, 50.283644199371345, 50.57795924525107, 54.409577538890225, 53.478038157186205, 54.256663937722486, 54.68059370594641, 52.678498298891135, 51.47915517130206, 50.07238926426057, 50.43421614554621, 50.01658962618921, 53.509291602719216, 49.79261444460962, 47.259261454305346, 48.433783823444, 50.20001142255722, 50.954232215881355, 41.5809638269486, 38.93207350084859, 39.207380740873276, 39.82067469627627, 39.09335743996405, 41.359844130854455, 40.472023487091064, 38.623492794652144, 38.21167530552034, 38.14093928183279, 37.58262911150533, 36.871326892606675, 37.05449373491349, 39.2284321015881, 38.67758620169855, 37.90759748028171, 36.26895673813359, 36.922776622156945, 37.371758568671446, 45.52425199939359, 54.195282766895915, 49.41574919608332, 54.538419554310465, 55.61152119790354, 54.773679394875806, 53.13861977669501, 52.074927899145315, 52.372533813599624, 49.3840289884998, 48.12486187104256, 44.81548755399643, 45.8535938109121, 54.8979518490453, 52.34647750854493, 53.82042184952767, 43.87802147096203, 48.78867595426498, 55.437850413783906, 46.98357374437394, 44.58720953233781, 49.17551579013948, 53.98842873111848, 51.64266309430523, 57.92943016175301, 54.58736288932062, 50.884261054377404, 53.26218620423348, 53.96079955562469, 52.360892218928186, 53.42562744694372, 53.33503638544391, 53.05903880826889, 47.6088583853937, 38.489386958460656, 41.03649962332941, 38.734331130981445, 39.5633436787513, 38.74392917079311, 41.1856948175738, 41.02136711920462, 39.23208382821853, 39.335120570275095, 39.44725328876127, 40.7771211285745, 40.101857646819084, 40.8699950095146, 40.49527921984273, 40.39870654383014, 39.13677807777159, 44.03894455202165, 54.220648734800285, 52.52210163301038, 52.64613874496953, 52.176077981149, 52.60638160090293, 52.411608465256236, 50.34307595222227, 49.35596835228705, 49.356101712872906, 50.255085422146706, 46.382246940366684, 43.83097656311528, 42.23448168846869, 40.00150772833055, 41.027191838910504, 46.56868111702704, 48.11879788675616, 51.9972022118107, 49.23997602155132, 51.711002549817486, 53.889922326610936, 57.31967418424545, 56.523903723685976, 59.50079833307574, 60.61834827546151, 66.80696979645761, 62.227571241317264, 73.44348676743047, 25.890551574768562, 0.37969637241575027, 0.18243861444775136, 0.018334301571632107, 5.616515394180052, 57.654707354883996, 54.629430309418716, 48.14046113721786, 34.84199062470467, 25.33087641962113, 40.324495300169914, 52.040124708606356, 60.078802724038404, 43.41047886879214, 5.159958370270268, 0.0964222776312982, 0.06444896991935468, 0.03518782413354324, 0.04990569849108016, 0.011466303220649642, 0.029764785393772107, 0.005618283908153254, 0.04531131216114567, 0.0461690242011701, 0.0606653459310051, 0.06203711445954058, 0.02768024099960683, 0.022045999479990815, 0.03631779999141732, 0.03591357369817073, 0.016177143533563903, 0.04092077416698298, 0.03609694067328688, 0.09905277075426233, 0.046316243317579074, 0.11501965954178765, 17.283902591274632, 58.93344317713092, 52.60996664724043, 46.00110238598239, 32.92943116157286, 29.302119324284217, 30.162744214457852, 42.57917173447148, 47.673287237844164, 68.60361929862731, 19.157795329247755, 0.06472981775239592, 0.07934298321244218, 1.6649890186325198, 4.302589537635926, 8.285960901168085, 44.18930861257738, 58.29225724743259, 58.814034461975105, 55.26348537014377, 55.313962351891306, 48.14353235306279, 45.15916562849476, 46.84357650818364, 49.98639129823255, 51.73461914062501, 52.751219041885875, 56.78077582390078, 56.49183050278695, 55.69924108443722, 56.78322338288831, 53.8233361705657, 53.32425378984021, 50.379420634238954, 52.224683992324344, 52.50154841330744, 54.57679602407641, 49.57923358486545, 47.538020380081676, 50.07401312551191, 53.17394072009672, 53.12564457616499, 45.20258234393212, 40.683105837914255, 41.352854467207386, 40.48304926964545, 39.86693905245873, 41.16385506045434, 41.18139589986494, 40.98586966914516, 40.72356900861187, 40.07990021859446, 39.307146226206136, 37.88651474060551, 39.35269278864707, 40.29816835157333, 41.02334791614164, 39.70420383637951, 38.478208203469556, 39.470556089955, 38.47879263662523, 47.09991908842518, 56.578640399440644, 53.489518934680575, 54.580408527005105, 56.016713803814305, 56.6319061863807, 56.58702642686906, 53.51168424852433, 54.85184046529955, 51.518622059975904, 49.71415527405278, 48.096758088757916, 48.069215205407914, 53.53067244252851, 54.3467450910999, 52.76490811378726, 45.476214731893236, 49.35128111993113, 56.24123419484785, 47.75084426326137, 47.10887778189875, 51.62878967100575, 57.52722247954338, 54.70251975520965, 58.68265859542355, 53.60253810882569, 52.96342319057834, 54.493830050191576, 55.50121630391767, 53.6900540321104, 55.25155352007959, 55.666744247559585, 55.60100924584174, 50.257721254902506, 40.019864420736994, 42.35887573611352, 40.20660454227079, 41.740066928248254, 40.24923678367369, 41.68160007845971, 43.9374493014428, 40.14429769208355, 39.530784083950905, 41.1828746334199, 42.9295531395943, 41.59379782215242, 42.823888409522276, 41.78153814808015, 42.76841432817521, 41.23978037987986, 47.37686195681172, 55.15503967961958, 55.459078281156486, 54.568335471614716, 54.67338831193986, 54.77042382763278, 53.83476595724783, 51.74372296179495, 50.861385791532456, 51.54652580138176, 52.593547605699115, 49.56773319552022, 46.428024922647786, 44.33055316248248, 42.33072488538681, 43.33634607253536, 48.61968455776092, 50.92355535876367, 53.55062161722491, 52.23300333945982, 54.49898796696817, 55.46562863934425, 58.59782949570687, 60.18722095797139, 61.26168758638444, 63.21525935203799, 68.27922359589608, 66.59612671021493, 73.96536596359746, 34.818805494616115, 0.47134993657950436, 0.11622965711379245, 0.014451210642413748, 6.424901668102511, 63.77681724486813, 60.76496255013251, 53.41088325746598, 41.507639038947325, 30.137484150548136, 43.48958130805723, 59.992938118596236, 66.12377920458394, 52.15596798927554, 6.814881361299946, 0.06729193752811802, 0.0124461890476185, 0.07352780130121016, 0.0836574984714389, 0.0665981989474066, 0.05685068005996366, 0.02865381234685981, 0.05747523324023332, 0.01876899518162733, 0.058158016763627536, 0.230335641892687, 0.13001673464332858, 0.07911101944984929, 0.0881931679924169, 0.08758140848048272, 0.09182850800214276, 0.20035616993423433, 0.15050342727092006, 0.22673407869954265, 0.34689132304441544, 0.1472017108913391, 23.378973622475904, 68.87168192094373, 61.4226459687756, 53.71120737444971, 39.83428532077421, 33.13764233742991, 38.49567451784688, 53.912581859096406, 52.49554326457363, 75.9395968529486, 20.966731655982233, 0.1788952126498184, 0.19146014245287066, 4.100592867020638, 10.22811366665748, 10.1932212421971, 45.74288883516866, 61.08350999893681, 62.129551210711085, 57.17770791822865, 57.488528297793486, 51.888215234202725, 46.1447121251014, 49.18896167509018, 51.986627501826135, 54.77557782203921, 54.429667918912834, 58.116727259851274, 58.70172523683118, 58.34191445381411, 59.514593308971776, 57.24718486109088, 57.15287147029754, 54.06507576665571, 53.973570792905754, 54.55717632847448, 57.05260392158263, 51.13257454287622, 48.51972295391945, 51.018539474856475, 54.67331378690658, 56.75539024414555, 47.11001919161889, 44.17574113415134, 43.414036458538426, 42.89503628207792, 41.556201904050766, 43.0217602176051, 43.57157453413933, 43.66023578951436, 42.49825716018677, 42.734768236837084, 40.96517132174584, 40.50161777004119, 39.80240821838379, 42.56792629918745, 42.817404731627434, 40.822412736954234, 39.901499056047015, 40.39397224303215, 41.276729106903076, 50.207605131210826, 57.997295010474424, 57.92302493126162, 57.64159487139795, 54.53507377255348, 59.624788376592825, 58.26978598871539, 56.13970364293745, 56.74685908902077, 53.08593842291063, 51.77330547763456, 50.58474102327901, 49.86133044765842, 56.16666601550195, 57.169372881612475, 55.343309525520574, 48.95217995489798, 52.94607062493601, 58.38297382477791, 51.938347047375096, 50.218983927080714, 53.635391881389005, 58.277462067142615, 57.148478415704545, 61.12538914526663, 54.683664921791326, 53.45280947223787, 55.97577210395567, 56.62444191594278, 55.932386767479684, 57.48568850178873, 57.93419191914221, 58.79879997622583, 52.47298963608281, 41.932255221951394, 43.35681692246468, 42.47681356245472, 43.388062523257354, 41.86508463275048, 45.138408445542865, 46.770702792752175, 41.99487193938225, 42.06707885188442, 41.86941100705055, 44.92756535930019, 44.156917679694395, 46.13606329887144, 43.50183087010538, 45.80986330586095, 42.5827528584388, 48.895846874483176, 59.86878725790209, 55.62022493731592, 55.74507397990073, 56.11047414041335, 57.35184938676896, 57.47950292402699, 54.98740934556531, 53.86703921902565, 53.49122516570553, 57.59560115875737, 51.930113992383404, 49.66252119310441, 47.58049180430751, 45.36720422006423, 46.405255563797496, 52.54763234046198, 54.417689000406575, 56.92870409257951, 54.8910367104315, 57.493572465835086, 58.681199473719445, 62.636494021261896, 63.452825546264656, 63.076230941280244, 66.79262176636728, 72.3244345572687, 66.763957085148, 72.62095789755546, 42.31715740696077, 0.6796592942649319, 0.2758461062706286, 0.11860711139536674, 6.803163770706424, 69.25405809956213, 67.96169988570675, 62.72327253895422, 46.0188118873104, 36.52875492649694, 55.58814779404671, 67.4211423627792, 77.69182943528699, 63.53907454398371, 9.228699630306615, 0.22388179546162007, 0.4437693923471436, 0.19329507624910724, 0.1651058138738717, 0.18110312401287018, 0.19005982565783686, 0.16040027201656373, 0.22187679014619321, 0.11565619433719306, 0.19262801284991926], [0.05008187190058732, 0.1047795691016701, 0.07740602182644991, 0.08718824449686274, 0.059129148120841676, 0.04241083816234623, 0.047413503390646754, 0.06235900545312513, 0.03477879063857179, 0.10727149990176964, 0.12604553402671892, 10.388771007137915, 55.70446175913657, 45.390165775052964, 47.04455091107277, 23.779853582382206, 18.573715186888172, 34.566502955652055, 35.760503815066436, 43.21224620265346, 63.61242286620602, 17.218267609996182, 0.02174189704800806, 0.06381866724921331, 0.4284702794205758, 1.976713136799874, 10.781069801699731, 46.60087593140141, 56.90488353852303, 58.93725572093841, 53.1639112195661, 49.40310739701795, 50.025175694496404, 52.39112192584623, 51.935617077735166, 53.85700579612486, 53.883093480140936, 56.374594780706595, 51.92890982474051, 50.51386379426526, 49.83920435751639, 51.86000162555326, 53.18670411263743, 52.274176459158625, 49.6869065684657, 52.18631144492857, 51.14997809933078, 50.76722929554602, 46.61804806801581, 48.47088552290394, 47.53676129925636, 52.759848256264966, 49.59043979644776, 41.1723195352862, 39.31958013965238, 38.73313088570872, 37.08374284928845, 41.07477803384104, 39.9730509327304, 37.591438754912346, 39.09786816566221, 38.1096976034103, 38.28769476183, 36.296130918687396, 37.39553597665603, 38.04635132512739, 38.18765471058507, 36.62111105457429, 37.71129462026781, 37.37692825255856, 37.64781890376922, 38.48274246338875, 41.04695666220881, 51.75378384128694, 52.86131605025261, 42.89580114426152, 46.827769356389204, 49.64856932240148, 47.77503744248421, 53.10799391038957, 51.0566766800419, 52.40572098762759, 46.90850350164598, 47.64375963518697, 45.410130639230054, 52.13157084680373, 51.458182257990686, 55.789298703593595, 49.45480423588907, 49.63924192613172, 56.24654508406117, 47.63639734637353, 46.500604460316325, 51.89436158826275, 55.051747983501805, 52.09513202790291, 47.38105497052593, 41.0232263226663, 46.96435805289976, 48.257010444518066, 51.07996771412512, 51.47400117689564, 51.47688411897229, 51.50855333574357, 44.88764347568635, 38.56697928520941, 38.59795032009002, 38.462965872979936, 40.896329802851525, 39.81645422597086, 39.54612055132466, 39.518157974366225, 39.94975597627702, 39.02666537992416, 38.48053416898174, 37.77311117418351, 40.66542379317745, 39.10148851333126, 40.742243413002264, 39.96631230077436, 39.51490632949337, 39.72678884383171, 38.309914988856164, 41.46037055600075, 50.617010362686656, 51.96577618199011, 52.76091514095184, 50.74860980433803, 52.48711016870315, 51.450031572772616, 52.5590072139617, 51.21586999585552, 50.95726813039472, 47.59804441082863, 47.43828235134002, 42.52254839866392, 40.27928213919363, 42.35128594983009, 46.34153273797805, 49.79169268761912, 50.86490415757703, 49.93431006708453, 50.49575813354985, 50.6427332662767, 53.291325492243615, 54.53931777707992, 54.674733684908965, 53.3791002919597, 63.51332418380245, 62.75547519806893, 72.3288276118617, 32.05220876201507, 1.9910035570783002, 0.09809886105358602, 0.0858071411869699, 3.603060557957619, 53.622534351964156, 56.702504927112216, 47.94392293499362, 36.821634384893606, 30.146207501811368, 43.25146990437662, 51.85586744739164, 63.02544016991893, 38.16212792550364, 3.657484914987318, 0.03824746822037044, 0.12867816453499178, 0.031021408992068424, 0.08853816036735812, 0.06642383733584035, 0.059324550337248275, 0.05470676002122703, 0.12573148394303937, 0.043771103880698645, 0.07283770929901831, 0.06388859192450201, 0.10156213005463924, 0.040367145406743216, 0.035282294265925884, 0.02901174203162232, 0.057063441828734456, 0.0325767666612181, 0.08387011085306445, 0.014023477898820514, 0.10728664546003265, 0.17003942010623796, 15.793202865508297, 63.11498395858273, 53.35558960514685, 52.32486524889546, 31.050192233054872, 22.644841247989287, 36.90634581350511, 43.42860414135841, 47.69340507445797, 66.73594351737731, 18.044375642653435, 0.13286852758497963, 0.10726690337422395, 1.4506161669569633, 2.076364750823667, 10.917993860860026, 46.54996748893492, 60.44574437602874, 59.808861286409446, 53.30966649516937, 52.025490345493445, 50.780428071175855, 54.57679602407641, 52.57656766522316, 55.29034183871362, 54.01409279915595, 57.31480260049143, 53.32608553671068, 51.590162169548776, 51.75946735566663, 54.259801833860344, 55.28297170515984, 54.32068094130486, 52.673524733512636, 52.25061085916335, 53.239197192653535, 53.36860795174876, 46.62833252260762, 49.40912823523245, 51.78999516271776, 53.57086104731406, 50.68913882778537, 41.64084665236935, 41.46322211911602, 41.500990621505245, 38.21013381404262, 41.44838771512432, 40.96895640896213, 37.76718055048297, 40.91411382921281, 40.440766119187884, 38.41996100641067, 38.45459161266204, 38.99837332387125, 39.35920000076294, 39.37663885854906, 39.11067078190465, 39.30210598053471, 38.80044660260601, 39.12112389841388, 39.66383088019587, 43.261358199581025, 52.84709745837797, 53.126840899067545, 45.66784997140208, 48.342961342104026, 50.45952720026816, 49.75510874102193, 54.325019082715436, 52.26696714278191, 54.15824382535873, 48.43493307790449, 49.10095545553392, 48.27482977221089, 54.41684569081953, 53.3031161369816, 57.27174674310992, 51.08665143289874, 52.248167222545995, 57.55684421908472, 48.957718341581284, 47.65462852293446, 52.47793966724027, 55.33906159862396, 54.748611527104536, 49.756273684963105, 41.28143987348003, 45.17628285192674, 47.971724694775, 52.109817381828066, 53.83102793847361, 53.92232110423427, 52.8395115944647, 46.32048137726323, 39.93138751676006, 40.639265506498276, 40.14361912204374, 41.07923776872697, 40.80008660593341, 40.428787200681626, 41.84073455872075, 42.62407110583398, 41.52750976624028, 39.21417428601173, 39.39415224136845, 42.73001040181806, 41.674406451563684, 42.307641736922726, 42.80570037903325, 41.61979136928436, 40.92188404452416, 39.6628345981721, 44.304536081129505, 53.240872044717115, 54.107013748538115, 55.02160849109773, 55.101111012120406, 54.611532534322436, 54.337139206547896, 53.34969820514802, 52.43016519854146, 51.78889689906951, 50.9258460229443, 49.92264101582189, 45.36581570102323, 41.65415917673419, 42.72953971739739, 49.06205338816489, 54.19241551429995, 53.73279217750796, 53.059752679640255, 52.62690736401466, 53.536905088732325, 55.74658409241707, 58.39898886219148, 56.36668336006903, 55.63186260961718, 64.64784622192383, 65.22998479104811, 73.51983962520477, 37.40969181060791, 2.309970331768836, 0.06737481291976667, 0.03888070500726181, 4.003330099005853, 58.701164337896536, 61.242087502633375, 51.654022278324256, 41.474479321510564, 37.27702940663984, 51.55012653719995, 59.857553589728575, 68.07771575066351, 48.033035262938476, 5.091093807451187, 0.04521740510338738, 0.07212698654902559, 0.019570537655043508, 0.05527820798658556, 0.025625710015095053, 0.029395573149104754, 0.04877120271445282, 0.018818254635158568, 0.039246427721434066, 0.054589035289902846, 0.12981675505157442, 0.2513367778831913, 0.15778385192876862, 0.164393198886706, 0.13575013666864366, 0.10638357335401159, 0.13292206180912833, 0.15511356053813813, 0.12424414722068657, 0.18849651599603315, 0.34514182337349464, 19.99242667228945, 71.88527030329551, 59.416055525502856, 61.447553019369806, 35.248591361507295, 28.079532231054, 45.54774699672576, 47.38565983310823, 52.63746246214836, 72.03267297437115, 21.034319977606497, 0.24378394768122705, 0.31684192258023447, 3.477452781892592, 5.5506043761007255, 12.237312486094813, 49.84280509333457, 61.65199087512109, 63.07952965459516, 55.95969430861935, 52.82915261483962, 54.02779363816785, 57.75243320772725, 56.680492585705174, 58.452811625696, 57.85692514911775, 59.328076762537805, 54.01681100168536, 52.503784164305664, 50.71776820767311, 56.098275569177446, 56.6143378903789, 55.66563421680082, 54.16824194692797, 55.00618573158018, 54.54769203739782, 53.17124605178834, 47.008174850094704, 50.736175890891786, 54.80362669114144, 56.48206380105788, 53.071005959664625, 44.8807518712936, 42.629919359760905, 42.02675296414284, 40.11042410327543, 42.846175316841375, 42.44464228230138, 39.25588869279431, 42.77744362431188, 40.54014721224385, 39.96763021715226, 39.81795257137668, 39.33661891568092, 41.613201787394864, 41.555990096061464, 41.76562116992089, 42.4412965005444, 41.89609096896264, 41.460272496746434, 42.657160220607636, 45.37209149329893, 56.43501889321112, 56.79711641803865, 48.45090496924616, 49.394109479842655, 48.793304351068315, 50.335046860479544, 57.80605593035298, 54.407918376307336, 55.760253552467596, 50.77730194214852, 51.72858653529998, 51.968368868674006, 57.59647192493562, 54.12253064493979, 58.47320795059205, 54.84499985171903, 56.03086179302585, 61.47764544333182, 52.04812242138771, 49.568329395786414, 56.15578143827377, 59.30807659702917, 55.37295872165311, 54.5190038219575, 44.85880228780931, 48.44096960559968, 50.66181167479485, 53.4713230594512, 54.173266503118704, 55.297256977327415, 55.34828309089907, 48.784745739352324, 42.98055571894492, 43.09130384076027, 42.54677687921832, 44.639973255895804, 43.444399526042325, 44.70806952445738, 43.2497440615008, 44.47608486298592, 41.846731862714215, 42.49907301318261, 41.268758850712935, 45.08488770454161, 43.350654878923976, 44.71941694136589, 44.78868207623882, 43.52066216930267, 42.923245968357215, 40.197237922299294, 45.48977828794911, 56.17278491297076, 56.62023713511806, 57.94297802832819, 54.77777434933571, 57.010752231844016, 56.32964049616168, 57.44316216438048, 55.670419508411044, 55.7313064605959, 54.264810700570386, 52.575328196248705, 48.473807688682314, 44.414711536899695, 47.0564043137335, 51.10469825806157, 56.09283131937827, 54.85928904625678, 56.54772820011262, 55.5917485298649, 56.981711003088186, 58.236689029201386, 62.988993506277765, 59.2823850724005, 56.86212970364479, 65.67063170094644, 69.04903581065517, 75.42546041550176, 42.583533410103094, 2.9962110567477445, 0.19802024527903528, 0.19466300284670246, 4.633318887602899, 67.71811285326558, 67.61822577445739, 62.63216764696183, 50.2120570213564, 45.70652846367129, 57.012395704946215, 67.54091585836103, 76.30534218203637, 58.02806992684641, 7.301811258639059, 0.27094179524048684, 0.2662921624798929, 0.1377472819219674, 0.11213169958923133, 0.1502838358283043, 0.17217875127830815, 0.13061324134469032, 0.2537642960106173, 0.11753214448089562, 0.21939789816256494], [0.036987153993498896, 0.08240761836209605, 0.058162176621056376, 0.017612386277065645, 0.04767391199786817, 0.09510617688178055, 0.007557804027812616, 0.12311616702185524, 0.12005429744960801, 0.06085099201769598, 0.00732796615920961, 13.864548936966928, 51.568608745451904, 54.909581676606216, 43.29037589411582, 23.397506821540095, 14.955681716242145, 23.066209708490682, 37.59865199365924, 43.02218383358371, 61.98894992951424, 15.774154855358987, 0.09507311252696861, 0.060641332905018525, 0.941123877081179, 4.16891320097831, 15.056172840056883, 44.360939764207416, 59.0635678075975, 55.253400956430745, 55.46009417503111, 56.02789255880541, 55.39004064375355, 54.74375955520138, 56.43837644207863, 56.772825179561494, 54.07810588036814, 52.65694879716443, 49.913070432601444, 49.10750973609186, 50.0722009904923, 49.66126995701944, 48.577354338861284, 52.111154910056825, 51.51238156903175, 51.16868388268256, 49.55562483879828, 47.33424540488951, 49.609278940385394, 46.80773781191918, 48.78267472790134, 52.6608907791876, 41.446151964126095, 38.63867628958918, 40.067446693297356, 40.028458333784535, 39.02533961880592, 37.864722051928126, 38.188094016044374, 38.28061488366897, 38.41546204782302, 37.080040131845784, 36.27331056902486, 36.74557570488223, 37.98823356628418, 37.312856335793775, 37.30625498679377, 38.091427203147646, 38.588850421290246, 38.641873021279615, 34.900477086344075, 38.28204654878186, 36.89665363680932, 48.49067780279344, 53.04728738723263, 53.014468916000865, 43.60611100350657, 45.502941762247396, 49.8721012761516, 53.20526476829283, 51.34690069383191, 48.95435687034361, 47.04914792891472, 46.87325708327755, 44.24382171323223, 47.714095577116936, 51.243973778140166, 54.27411064024895, 51.06756125727008, 52.12504794520717, 51.10589065859395, 45.93184117347964, 45.9901785850525, 48.6275645994371, 52.90012790310768, 53.832302708779615, 53.48011701337753, 53.25642816482052, 49.374607455345895, 50.719243018857895, 52.4954334382088, 49.68298419829338, 49.01698535488498, 45.45155871299006, 42.39661285954137, 39.421369567994155, 38.27736323879611, 38.06514732299313, 39.640426097377656, 37.6351692599635, 39.47422350606611, 39.620425931869015, 40.18805957609608, 37.23486392728744, 39.245745443528705, 37.351009230459894, 39.93939699665193, 39.645434964087706, 39.78040764408727, 40.64667878612396, 39.83233590279856, 37.69014520029868, 39.74605552611813, 38.054435330052534, 38.674836620207756, 43.52678891151182, 49.56590144864975, 52.77374129141531, 54.91931307700373, 53.555752077410304, 54.01636777385589, 52.01919494136688, 51.936460387322214, 48.002621204622336, 47.20855697508782, 43.35167861753895, 41.95732308972267, 42.47204788269536, 44.68981089130525, 49.3077035873167, 48.72945208703318, 50.05182035507695, 51.26942211581815, 47.15489110639019, 48.3821262082746, 47.428770603672156, 49.9868227589515, 56.02246399848692, 63.10761382502895, 61.16132982315556, 70.70852002789898, 30.325897162960423, 0.6736562292902701, 0.25967405147610173, 0.06102603161707521, 2.4974346208956937, 51.08751043196648, 57.88214206695557, 44.78474009421564, 28.351591748576013, 19.408064119277462, 30.913177959380615, 41.63704587567238, 56.81266469340171, 42.28329166289299, 3.4119911203461313, 0.11323933249279378, 0.030222917463810697, 0.0823287189667744, 0.01718002157436023, 0.01113226303019591, 0.08986229737920147, 0.06473554809006953, 0.027816035829844977, 0.01853913816082622, 0.037361161948572245, 0.02616441729778965, 0.034076272690248106, 0.02775740712099979, 0.08044777392980554, 0.036336630432596134, 0.037201241094378695, 0.03456424771537704, 0.046259345967442765, 0.005814794558025296, 0.07098631993416818, 0.07303298511091741, 16.76220186295048, 62.40538012596869, 61.94961640142626, 50.35101090708087, 30.724005968339984, 20.555431919713175, 22.885949342481553, 44.001223118074485, 47.837214854455766, 66.02695941925049, 17.377874735862978, 0.14641195085019837, 0.1518784478426941, 1.4942362327729504, 3.536956363147305, 16.604257822036743, 46.52655878374654, 60.90346144091699, 57.24709464657692, 55.79294650785385, 57.295222128591234, 56.48617444499847, 57.16069267642114, 58.73470452524001, 58.176594395791334, 56.27056567899643, 53.336875977054724, 49.83826298867503, 47.90298123513499, 50.21057436543126, 50.41602811505718, 51.43857432949928, 54.16462552162909, 52.99918736180952, 53.69132880241641, 49.88160910144929, 47.3198385392466, 48.63799418172529, 49.87580791596444, 50.76493078662504, 53.67657676819832, 44.38212840787826, 40.27438309884841, 41.77435236592447, 41.21121768028506, 40.00764231528006, 38.849499763980994, 39.3188545011705, 38.72806318344609, 39.08489296513219, 38.643653777337846, 37.44536184495495, 37.63551835090884, 39.30465944351689, 40.503398526099424, 39.75682243224114, 40.32970420775875, 40.715033931116906, 39.862918623032115, 38.05273302139775, 39.626662500443, 38.69952401807232, 49.547466308839866, 55.997651084776855, 54.96789555395804, 44.78370851086032, 47.168215397865545, 49.930128820480846, 54.314624801758804, 53.8673294744184, 50.85950305384975, 46.94043551721881, 48.76671460367019, 46.833939244670255, 50.271775107229914, 55.09553340173537, 54.301249519471206, 52.2138504059084, 52.77105839021745, 54.191717332409276, 48.47743980346188, 47.78723601372012, 51.437872225238436, 55.15802852569088, 55.32792598970475, 55.450237258788086, 54.91039360723188, 50.60594535643055, 51.425304951206336, 53.61832172639909, 51.65689345329039, 50.370575689500384, 46.88604008766913, 44.52860539959323, 40.63661790663197, 41.034962054221864, 39.815532468980365, 40.63668850929507, 41.18190973035751, 40.700740814208984, 40.2471814617034, 41.600775718688965, 39.83085324687343, 39.923805575216974, 39.0598290197311, 42.688076342305834, 41.83633365938741, 43.458943674641276, 41.6393090832618, 41.21358679186913, 40.50886238774946, 42.31940100269933, 39.83645046910932, 40.74919777531778, 46.05382296346849, 52.71388592258577, 55.08427619934083, 55.09402328921903, 55.431558932027514, 56.62696007759341, 55.35429608437323, 54.972888731187396, 50.13124442869618, 49.88461755937146, 45.43461407384565, 43.78906211545391, 44.31130216967675, 46.77999488769039, 52.444736803731615, 50.9736361811238, 51.67672495688162, 53.49104473667761, 49.493235618837424, 50.90823065850043, 51.078940053139966, 54.129461473034276, 57.916462805963334, 63.559565005763886, 64.27036516128048, 70.05509238089286, 34.17624673535747, 0.8250514441920865, 0.12069305389999382, 0.09897348831497854, 2.845432450694423, 55.97410901900261, 62.65769835441344, 51.79094045392929, 38.30976201641945, 25.483307569257676, 37.5387534787578, 50.61716725749355, 63.97270041127359, 52.256290451172866, 5.286004716350186, 0.23897829345397412, 0.0603091188766543, 0.05110912302869463, 0.029548254472413854, 0.02290940355329264, 0.09353479265325493, 0.1131476317682574, 0.007350826222870139, 0.08786594119643973, 0.04445726202139932, 0.08906956491691452, 0.19726431568063077, 0.19016628123579488, 0.12007377140464322, 0.18631082118278552, 0.15504088943764088, 0.09749180532150692, 0.16812956291100672, 0.2405370678752661, 0.2418254592245625, 0.17550265356417627, 20.172959643025553, 73.25390292752174, 69.68240445660007, 56.717821782635106, 33.812639098013605, 25.07544186807448, 34.02907156175183, 51.73231278696368, 53.16939077069683, 72.72352787756151, 19.12710278264938, 0.204091522722475, 0.33187397725639806, 4.385304970125999, 8.579376743685815, 17.331618224420858, 49.878447671090406, 62.5775251080913, 60.204094994452696, 58.17239353733679, 60.98922406473468, 59.386676972912205, 58.7151671994117, 59.86346852394843, 59.635555282715835, 56.704842659734915, 55.196440296788374, 51.4012804339009, 49.35493676893173, 50.30540158671718, 50.830222560513405, 51.94734496455039, 54.94527524517429, 53.19114031330232, 55.68906253384006, 50.56138723127304, 47.89297526882541, 48.06758349941623, 50.840703133613836, 52.71275627997614, 54.513069275886785, 44.14415820952385, 42.372266707881806, 43.9854238110204, 45.045467884309836, 42.02172448558193, 41.39835788357643, 39.31949384750859, 41.3382593277962, 41.52804320858371, 40.05263974589687, 38.790789727241766, 40.38826519443143, 40.787221231768214, 40.85978900232623, 41.277023284666, 41.39980916054019, 42.37920930308681, 42.01396603738108, 38.87270450592041, 42.021289102492794, 40.82270691471715, 52.775341618445616, 59.77830210039693, 55.965456270402484, 47.350150615938254, 47.281230649640484, 52.58671875922911, 56.40181995207264, 54.705434076247684, 53.27514963765299, 49.48672448435138, 52.25496469005462, 48.01003056187784, 52.3528435153346, 56.81801872868692, 56.73123236625426, 56.255927393513346, 57.14350485032605, 55.01108869429558, 50.6499308155429, 50.83441949659779, 53.91647677267752, 57.72766736245925, 58.14928685465167, 57.441789334820164, 57.82077266323952, 53.44732599873697, 54.47009186590872, 55.51480339419458, 53.288242509288175, 51.6899747233237, 50.7824480918146, 47.24989483433385, 41.66550267127253, 42.51289152329968, 41.646408573273696, 44.21845574532786, 41.97445992500552, 42.8783622864754, 43.29378051142539, 43.99647312779581, 40.09487190554219, 43.217337439137125, 41.81934979654128, 44.59381872607816, 43.732713345558416, 45.457250072110085, 45.221417565499586, 42.83309813468687, 41.297584349109286, 44.60573488666166, 41.543897428820216, 41.74728801173549, 47.945358522476695, 54.80698031763877, 58.72499273669336, 59.06007297577397, 58.55378520104193, 59.72845269787697, 58.29639142559421, 57.661073361673665, 53.10773111158802, 51.71809419508904, 46.6471795112856, 46.336123789510424, 46.948307714154645, 49.52949008634014, 55.015164036904615, 52.625138375066946, 54.66786561473724, 56.97064599683208, 51.689660933709916, 53.43909686611545, 52.410274859397646, 57.45656098088911, 62.26097806807488, 67.7338101786952, 66.44944575525099, 74.954893665929, 38.85809759939871, 0.7795491309896593, 0.276537791735703, 0.19175412103293404, 2.894710412909908, 62.43158155871976, 68.71160214947116, 60.810199245329834, 40.47762855406731, 29.11041936566753, 45.62005196848224, 57.07389062450778, 73.5423069615518, 64.83395876423006, 8.800416031191427, 0.3752150644938792, 0.14511772191091893, 0.1857112960950021, 0.19309860534004628, 0.14727430538304392, 0.23809916159558683, 0.10506676014272437, 0.2051300468343881, 0.15128336606487153, 0.10867729422546203], [0.053196574726532546, 0.03195507290412582, 0.0616116292263952, 0.016343660404785507, 0.01623883276366659, 0.03465081565082073, 0.04077903640967223, 0.06960471866712456, 0.04272329095270365, 0.04614762353500532, 0.05441395738612741, 12.492405791436473, 50.067729488495864, 53.125789703861365, 44.1612950448067, 24.61183144200233, 19.388265955832697, 35.168402425704464, 36.04114547852547, 45.41055033283849, 60.3872069235771, 12.802332851194567, 0.042477054972081416, 0.07811762557755556, 0.6032369982811713, 2.501495990060991, 18.079314154963342, 47.509034064508256, 57.186380278679636, 58.306005154886556, 56.68946696865944, 55.92262398812079, 56.13431430632069, 56.883090849845644, 56.170870796326675, 53.2185027676244, 54.428149961656146, 53.96108981101744, 53.57383420390468, 55.27173019224598, 52.76662611192273, 52.293215643975046, 50.736999588627974, 50.17323732376099, 48.85477181403868, 48.419643678972804, 46.88347877994661, 50.5734642090336, 48.23605714305755, 50.70109028970042, 53.17124605178834, 45.456567579700106, 37.11207020667292, 37.827196736489576, 37.73051031174199, 38.94585278726394, 39.16146547563615, 36.20583011258033, 36.87827341018185, 38.282513310832364, 37.30249343379852, 37.70468934889763, 36.43344133130966, 38.14836040619881, 37.095996333706765, 38.998824396441066, 37.55499209127119, 36.53151627509825, 37.93132389745405, 38.47226189028832, 36.75776643137778, 37.6944205837865, 35.2580128946612, 42.912545742527136, 50.9562365470394, 48.87848254173033, 52.04061500487789, 48.62751360862486, 49.85102245884557, 53.52211775318269, 52.910212316820704, 49.194492217033144, 47.27041667507541, 44.55965095950712, 43.28725760982883, 45.441701796747026, 49.52737200644709, 53.273337502633375, 50.89653022827641, 51.37494564056397, 52.786771405127745, 48.77790904814198, 46.616953726737734, 44.93097389897993, 47.688313837974306, 52.0361513476218, 51.44412056092293, 52.281503446640514, 55.823187981882405, 52.1049379533337, 52.47111082077027, 52.76372748036539, 52.33335718031853, 53.94190157613447, 47.008135626392985, 41.80762583209623, 39.499259994876006, 38.07554944869011, 36.49762307443927, 37.124876745285526, 38.73795540102067, 37.69245939870035, 39.74701650681035, 37.90766416057464, 38.62929005776682, 38.10222156586186, 39.488799033626435, 40.80349514561315, 40.69943858731178, 40.47225882930141, 40.55242030851303, 38.098275661468506, 41.237203382676654, 40.23715980591313, 40.03862511727118, 39.45636495467156, 40.629816516753166, 43.92935745177731, 47.748149594952984, 49.07526000853508, 48.512811737675825, 48.7764460040677, 48.983049008154104, 46.76104591738793, 46.122005524173865, 41.28796277507659, 42.72207936932964, 40.46139778629426, 42.334576652896025, 49.33375597000123, 52.38511677711241, 51.71200275421143, 50.626855511819166, 48.81315546651041, 48.68798086720128, 51.13716371597783, 57.0109248161316, 58.77705435599051, 64.7074152577308, 63.61516460295647, 70.90992589150706, 30.02636144238134, 0.29620308489088093, 0.22061112096473096, 0.09352505567573732, 1.8118868071225382, 51.04106172438591, 61.66981020281392, 48.52917194366456, 34.160572944148896, 24.120831105016894, 32.074523125925374, 48.228596794989805, 51.74410343170167, 49.0755973323699, 6.525969380332578, 0.2549589181979818, 0.019453816498900135, 0.05199912184428784, 0.027036074053255782, 0.03362028183595788, 0.028047562922321023, 0.03534944953336831, 0.04278359356366339, 0.02054981444211256, 0.060726050738125086, 0.07410578399656281, 0.06927317879613369, 0.06719781596574091, 0.045158090745849956, 0.06000385582146626, 0.10399626718173105, 0.02734484962157665, 0.0828106725408185, 0.08010946184156403, 0.026937838598725297, 0.01754949045848222, 15.148107313340711, 58.84108704905356, 57.66212847925002, 51.31738093591506, 28.764733037640973, 22.502445482438613, 34.53013866178451, 39.597621271687174, 50.89651453879572, 66.31088410654377, 14.655748855683113, 0.10847569052730838, 0.043445405430130424, 1.1074236083415248, 3.6246983130132002, 19.41405357853059, 49.017848276322894, 59.35523133124075, 59.078747380164366, 58.02812484002883, 58.156037253718225, 59.169758135272616, 58.56042577374367, 57.02561409242692, 55.14283326364333, 54.27340069124776, 54.9913356381078, 53.345077653085035, 56.31877945315454, 54.14070298594814, 51.742059876841886, 50.83570211164413, 50.93864471681657, 49.26670305190548, 50.07608805933307, 47.43773714188607, 49.43796157836915, 49.76486367564048, 54.05528553070561, 53.76926629774032, 48.93668659271733, 38.36053709830008, 39.27015043074085, 39.01425107832878, 39.489097133759536, 40.58179886110368, 38.00923393618676, 37.999918307027514, 39.51396496065202, 39.418804337901456, 38.090736865997314, 38.58522615125103, 38.458490448613325, 39.160579019977206, 39.20928309040685, 38.312711638789025, 39.23854004952216, 39.677794518009314, 40.71843070368613, 38.74622767971408, 39.02796760682137, 38.869574454522905, 45.44394147011542, 53.121067170173895, 51.94875309544226, 52.93786110416536, 49.21234292368735, 51.20390284445978, 53.49274704533239, 54.776315227631606, 52.28688101614676, 51.04145788377332, 47.36564790048907, 45.01448900468888, 48.68815737385904, 51.63310427819529, 54.537136939264116, 52.910357444517075, 53.633748408286806, 54.48986453394736, 51.33891867053125, 48.60767818266346, 47.72290914289413, 50.09977917517386, 53.7622844788336, 53.66282101600401, 54.47361807669363, 57.57706011495283, 53.798519334485455, 52.88618387714509, 54.42649079907326, 54.7719104059281, 53.88396424631919, 49.31421864417292, 44.66553926467896, 41.35287015668808, 40.837749204327984, 39.519891661982385, 39.88058105591805, 40.57646051529915, 40.14286210460048, 40.574903334340746, 40.744914547089614, 40.18217994320778, 39.81511277537192, 40.86939488687823, 43.7381850519488, 42.40231990814209, 40.993012305228945, 42.226346692731305, 40.93023084825085, 42.617489368684836, 42.54365467256115, 41.39164278584142, 41.83832230106477, 43.2913564866589, 45.57071639645485, 49.45831475719329, 51.09726144421486, 51.0394770868363, 52.12147466598019, 51.144353420503684, 48.58161403286842, 48.469473469641905, 43.808450391215665, 44.59577991116432, 42.43991190387357, 45.12986552330756, 51.135080937416326, 53.61345014264507, 52.75476486452165, 53.034045465530895, 51.119642488418094, 49.784550051535334, 52.391859331438624, 58.60039472579957, 61.243793733658336, 67.44305272256175, 65.7478827814902, 72.80658014359014, 32.33504499158552, 0.5120412482609672, 0.1765735985170449, 0.013696496250979124, 1.708719768831807, 55.03955725700625, 65.72884751904395, 55.2344794427195, 39.287518685863866, 31.726046031521214, 38.09723623337285, 54.79481704773442, 59.14864009426486, 61.637266297494214, 10.280351792612384, 0.22151294434743546, 0.10768187022016895, 0.05929684093702705, 0.05986607107784479, 0.013749490383141225, 0.058525447853870934, 0.13256782275294104, 0.055423013926033056, 0.06362773132540527, 0.07222778073722316, 0.18783259355733473, 0.07026904713242285, 0.18215107100625194, 0.11257172517117955, 0.17919671421329822, 0.20319587400844022, 0.11044007020011065, 0.23004054482425415, 0.11035865803639736, 0.14938031173040792, 0.14731693051515088, 19.065031274672478, 66.08588910871937, 63.11852585884833, 57.717175022248306, 36.615972749648556, 27.94311808001611, 48.230542290595274, 44.89129520231678, 54.69898177731422, 69.8613900523032, 16.440178213580964, 0.2686110493396559, 0.22270744396073205, 3.0863591355662194, 3.924309539218103, 21.169616253145282, 50.57403687507876, 60.684349998351074, 61.369540999012614, 60.2096490706167, 59.55750011628675, 59.75745862530124, 59.68138425580917, 57.663999449822214, 55.494936589271795, 56.50903009599256, 55.44700130339592, 56.16765445278537, 59.231994382796756, 54.7780018468057, 54.886514217622825, 52.37466758297336, 53.02751864156416, 49.72267858443722, 50.84193083547777, 49.326648635248986, 51.13061728016023, 52.807195186615, 57.803769188542525, 56.32281164969168, 49.295520705561486, 38.757241695157944, 40.49083517443749, 41.38659077305948, 43.24187578693513, 42.80455112457276, 38.481295108795166, 40.4454102054719, 41.88546134579567, 41.58974993613459, 40.845056579959014, 40.75954106546218, 41.5087765262973, 41.55205203640846, 41.50671728195683, 40.95253344505064, 41.494087250001975, 43.86445791490617, 43.26469613659767, 39.92612761835898, 41.42629300394366, 40.74724835734214, 47.290691406496116, 54.8293339052508, 52.73165818183653, 56.01323073910129, 52.132814238148356, 53.20217786296722, 55.50763722388975, 57.147462521829915, 54.747313222577496, 52.3099131737986, 49.58088882507817, 47.47496827956169, 51.305802099166385, 54.32135166660432, 58.15759443467664, 55.71495017697735, 58.195241343590524, 56.609054457756784, 54.89124459605063, 51.793760638083185, 49.6044465803331, 54.40760850906373, 57.51777348979827, 56.916607502968084, 56.616181404359885, 60.75776107849614, 55.47650537183208, 55.84593380651167, 55.61945615276214, 57.44853188914638, 57.1275447260949, 51.780212771508005, 46.16310804120956, 43.09077039841683, 42.17880364387266, 41.4004445845081, 41.97810772926577, 41.83606301584552, 41.36097769583426, 43.56201964039957, 41.58319957794682, 42.38284534023654, 42.77991863989061, 42.427301483769575, 45.50475781963718, 45.20245682808661, 43.16203201970747, 45.40288209915162, 43.17477580039732, 44.678443862545876, 44.60679784897835, 43.86104153048608, 44.426976788428526, 45.728489814266084, 48.589007700643236, 52.70244044642295, 54.374542928511104, 54.36909475634175, 55.53196768606863, 53.41691978516118, 50.9231827335973, 50.10996557051136, 46.79955967010991, 47.589101406835745, 46.03961221633419, 47.60008012094806, 54.272533847439675, 57.02283705434492, 56.9510341459705, 56.36525561732631, 52.880567043058335, 51.37972308743385, 57.11938619613648, 61.446129198997255, 64.95431669296758, 69.91486764723255, 70.45678231023973, 76.25659496553483, 35.180597074570194, 0.6802586201698549, 0.37761120365992673, 0.1816165101744475, 2.182927458517013, 61.92898081194971, 72.23045456794001, 63.03712491066226, 46.735401461201334, 35.66686114957256, 44.223362630413426, 63.36191285041071, 68.58536458784535, 73.8050037814725, 14.371291706638953, 0.415977775569885, 0.18792329836756955, 0.20266103738498306, 0.1999880493648591, 0.1894076550078969, 0.10641341247866232, 0.29230529081917583, 0.21721859252260578, 0.10305541928016371, 0.22120192797193605], [0.011328772243653095, 0.034305761988845565, 0.02791661742864357, 0.020686348547197638, 0.019729341936087417, 0.043552749670080604, 0.016972067007314295, 0.03517711805480142, 0.0824620718917539, 0.05977014920884564, 0.04204340324166321, 10.922210408795266, 49.55517768859864, 53.9712252155427, 42.84772857542961, 30.49279989734773, 27.65701255490703, 20.43629777046942, 34.501858372842115, 46.49776858668174, 59.91894652766567, 15.618047464278439, 0.11465522385532818, 0.13456139803653763, 0.9874721352131137, 4.656128941043731, 23.611405434147006, 45.57285408819876, 53.35485612192462, 53.45763790991999, 55.25882559437906, 57.49573369180003, 54.44551429440899, 57.009630433974735, 55.97370501487486, 56.16367324706047, 55.027499891096554, 55.102444617978996, 52.35485569123299, 51.96773344470609, 53.22919122634396, 54.28805074384136, 54.71665597731068, 53.9059373640245, 52.616258128996826, 51.85006626190678, 51.18792703074794, 50.65995247133317, 50.14039531830819, 50.626981027664684, 44.91908519498764, 38.453414901610344, 39.463272248545, 39.18742764380671, 39.96882654005482, 40.08875300807338, 38.13486745280605, 38.483217070179606, 37.11706338390228, 36.91884248487411, 37.7067054471662, 37.4112372244558, 38.22828262082992, 36.89163692535893, 36.26618362242176, 37.814684375639885, 38.32418064917288, 36.689834902363444, 39.89435641996322, 36.82838478396016, 35.48780102883616, 36.92435733733639, 37.741853806280325, 37.57348998900383, 46.69394200847995, 49.735394908535866, 48.68655704682874, 51.971008623799975, 48.493309713179066, 52.751007233896566, 53.07763084288567, 51.05187962132116, 47.878309526751124, 47.015572440239694, 43.79048985819663, 44.25994265464045, 48.10757598569317, 55.50872764279766, 49.689095251021854, 52.10152156891362, 51.77853007470408, 49.42137387491042, 52.51452753620764, 48.26775773879021, 48.50779502622543, 44.76677956119661, 50.06281475866995, 52.319499446499734, 52.45643723395563, 53.47348820778632, 52.1559444550545, 51.6902728234568, 51.38626560088127, 52.304555216143214, 54.34260699056811, 43.91930049465549, 37.69232603811449, 38.870606037878225, 38.65001193938717, 36.75029823856969, 38.86040395306003, 37.11949133103894, 39.95989922554263, 37.575086393663966, 36.29731547447943, 37.990841942448775, 39.9554826367286, 38.46061637324672, 40.28236904451924, 40.30419311215801, 40.71244516680318, 39.20177175152687, 42.24921411083591, 40.77473240513956, 38.520962038347804, 40.35570167726086, 40.807244931497884, 40.470364324508175, 39.7257847170676, 40.28753872840635, 41.02479527073522, 40.84027521071896, 42.02119104323849, 41.28822165150797, 44.740181969058135, 42.38552431906424, 44.86085368740944, 41.99447577999484, 42.70275385149064, 45.50405963774651, 51.87726397668162, 50.37077965274934, 50.874239398587136, 45.54262045891055, 48.56059797348515, 55.86212142821282, 60.660105828315984, 60.19654835424116, 63.08819417030581, 63.33811583057527, 67.00111927524691, 29.490296994486165, 0.38338116340098843, 0.2821968832323628, 0.0025140889356994344, 0.9736621439937623, 46.54001643580776, 60.02220292245189, 53.36510919755506, 44.73264317358694, 20.386014946045417, 24.310212942861742, 45.6166002827306, 53.04450642678046, 53.55572854318927, 8.712389219191767, 0.3724580979154956, 0.1051465865044344, 0.04235915021009503, 0.06408043949293994, 0.008422329462313605, 0.045007136950810114, 0.03499930904757592, 0.03324620110253173, 0.033622331121155334, 0.0136676415493111, 0.020448589329457572, 0.04705210141236744, 0.002430528134761018, 0.03625489651195465, 0.01851105529274191, 0.058148164872921286, 0.024836832890287045, 0.022880319025247328, 0.03304445567811209, 0.07193975466033144, 0.180703547873324, 13.416325969080772, 57.74748709893996, 58.931505526265795, 48.934839156366166, 33.79184661373016, 31.01794642786826, 29.18041798376268, 36.47534793423068, 52.220083052112216, 64.25573472053775, 17.828141258608913, 0.185067766916848, 0.09168741758912803, 1.3943467024833927, 4.785189138304803, 23.08125984284186, 47.037592626387074, 53.44911852190572, 56.23960641122634, 56.41233974887479, 57.21552348905995, 56.52127573567053, 58.05498915333902, 57.19084001356556, 56.61740126148347, 56.32227820734824, 56.58658712140976, 54.92703230150285, 54.2875486804593, 54.09889444228142, 55.16004070158928, 56.88577375104351, 55.31144026787051, 52.33955844756096, 53.16627640878001, 51.96402680489325, 54.44875024980115, 51.892494540060724, 52.391267053542606, 48.28326286808137, 41.16812652157199, 40.67955217053814, 40.75153943031065, 40.07042769462832, 40.69035830036287, 40.02945853817848, 40.28765247714135, 38.449990672449914, 39.24547479998681, 38.704415213677194, 39.212303315439534, 38.19549945092971, 37.97449742594073, 37.24094752342471, 39.63508775157314, 40.02064105003111, 38.73895952778478, 40.60001827055409, 38.21042799180554, 38.37048030668689, 38.64776049890826, 38.3603919706037, 39.19576268042288, 49.974420224466634, 50.8347999665045, 51.63770129603725, 53.65167363997429, 51.94029646535074, 55.2308237937189, 54.92893857340659, 52.82063322682535, 49.950101529398275, 48.325761748898415, 46.899489894990005, 47.72971837751327, 49.76957051984726, 54.86748679991692, 52.41198109042261, 54.22333948073849, 54.27120416395126, 52.328356158348825, 52.921049825606815, 50.54938085617558, 50.12921656331709, 48.07921332697715, 53.712140898550714, 52.8573505340084, 53.46260755292831, 54.14758282323038, 55.35067573670418, 53.033512023187455, 52.085624202605224, 56.87557558859549, 56.30370578458233, 45.68266084117275, 40.73441828450849, 38.653404789586226, 39.53448680139358, 39.32928016108852, 40.65452352646859, 41.23725437348889, 42.2128027485263, 39.50561423455515, 38.69702546827255, 39.53880140858312, 41.20025465565343, 40.16706705093384, 41.22771516922982, 42.56567878107871, 43.40257137052475, 40.65218187147572, 43.12166690826417, 41.16613787989463, 40.931933156905636, 42.180580477560724, 42.835584917376124, 41.79602346112652, 42.17589716757498, 41.48744275493007, 43.18372664913055, 43.8109254067944, 44.47437863196097, 43.80728152490432, 46.393704183640025, 44.883058224954915, 46.10638272377753, 44.90354868673509, 44.22148381510089, 48.667368811945764, 52.10547924041749, 52.953876141578924, 53.01548088750532, 48.876615493528305, 51.475687796069735, 57.23215433859057, 62.81214167994838, 63.777032975227606, 67.0948717671056, 65.04932826565158, 67.4760163214899, 31.02539108645532, 0.30491445453897603, 0.36065933264551625, 0.05010172889958467, 0.9108675715904083, 50.35823591293828, 66.92020862333237, 56.88254564039169, 42.196250346399125, 24.218145108992054, 31.00692652886914, 51.47564464999784, 59.66074474396245, 60.657022845360544, 11.325398683547975, 0.39704008208167174, 0.10247291666605782, 0.041891767628370755, 0.01650708802645245, 0.01204143894175368, 0.011879093419279785, 0.020011652997064016, 0.09434712930552422, 0.03776459151037759, 0.005008885862245675, 0.1553248322658962, 0.11883480804822139, 0.10648610656179729, 0.08948267016920353, 0.17924335364612842, 0.18029385937317727, 0.15539299876939866, 0.21562445548272904, 0.12057413407150777, 0.13650272612369832, 0.2103835407404169, 17.153519084376676, 66.48713973260695, 67.47185860910724, 56.067382981700284, 41.07022023970082, 37.19582457696238, 30.36019240656207, 46.13094852816674, 55.79179333102319, 70.35969580373457, 19.40825435423082, 0.28922230786373543, 0.34931801379688326, 3.363802351297871, 8.808616726629197, 26.406182435251054, 47.74048528363628, 53.87132244725382, 55.4957289080466, 57.88945728732694, 58.40189926085934, 58.014192581176765, 60.61721863285188, 58.460856406919426, 59.5392571726153, 59.30280885388775, 58.47596537682318, 57.647651010944, 55.30190106361143, 56.61209037227016, 58.63508416760353, 60.6962896931556, 58.165768654115745, 56.47698433168473, 56.43108083355812, 53.187033591731904, 55.465809068372174, 54.31220469936248, 54.51186510824389, 48.767542223776545, 42.33110535529352, 44.16906526011806, 43.091743146219564, 44.16190301218341, 42.689896322065785, 42.15473598049533, 41.79573320573376, 40.72129795628209, 41.42321786572857, 42.20462460671702, 41.7410239865703, 40.425009958205685, 40.38681391746768, 38.91222630777667, 41.13622980733072, 42.17201402110439, 40.2706293905935, 42.28232283746043, 39.39492102592222, 39.26333335138137, 39.11163568496704, 41.536519450526086, 40.78180443856024, 52.56468288360104, 52.63161813059161, 54.564464092254646, 57.88007105550459, 52.24264452534338, 56.1909572539791, 56.239316155833585, 56.18810176849366, 51.8087911605835, 51.56887154425345, 49.15536657456429, 48.51940524193549, 50.40547301692348, 57.970642505153535, 54.04899012657904, 58.32633479948967, 55.723328359665416, 53.99372785322128, 57.629000140774636, 53.41824946864959, 54.25432228272962, 50.064591592358006, 54.62869682619649, 56.355390856342936, 55.50933953254454, 56.8637849438575, 56.565869162159586, 55.040710433836914, 56.06273105067592, 58.388033682300204, 58.19259374372421, 47.898027281607355, 41.009239150631814, 41.69390455369027, 43.738706727181714, 40.53496576124623, 42.41765637551585, 42.60849145150954, 44.24571621802546, 40.77250057651151, 39.66580383239254, 41.73462267844908, 42.85574197769166, 42.403288733574655, 43.59784264718333, 44.58003943966281, 46.65302384284235, 41.695975565141254, 47.08705371425998, 45.13885951811268, 43.16711148908062, 44.121424152005105, 44.2189891876713, 44.541325646062056, 43.85491086590675, 45.185904425959436, 45.774358011061146, 45.907946094389885, 46.01764302099905, 46.17437308834445, 49.77869395286807, 46.2073798333445, 50.4121567356971, 46.302744419344016, 46.57520009625343, 51.24276568812709, 56.35894844608923, 56.464860285482104, 55.97556814070671, 50.31492117912539, 54.03972548823203, 62.10192987995764, 65.36245892124792, 66.11826435212167, 68.01103545773414, 67.04853288588986, 68.01731125000985, 34.52019937576787, 0.7401157050363479, 1.3734306635395175, 0.12840087901079847, 1.3527104979561222, 56.75353888542422, 71.75076438534644, 67.05670710532897, 58.965304590040645, 30.369398209356493, 37.83846962836481, 61.1038004198382, 68.57548805975145, 71.94692996240431, 17.01980156283225, 0.656714531923494, 0.13151026901698884, 0.16517174340063528, 0.14269334474398246, 0.12709456886495316, 0.1899044783485513, 0.1431422722676108, 0.17485443592792557, 0.13393737345693574, 0.0931451296914489], [0.06790213422068665, 0.012076335204314562, 0.013310399428460629, 0.026562375076595816, 0.03810431320039976, 0.10569132098387327, 0.09174830625734984, 0.008796893788741962, 0.016512071428399895, 0.05230949853637046, 0.09229513981770124, 9.882566582772041, 50.37965205407912, 52.92875728299541, 45.747595679375436, 23.093103439577167, 21.576487633489794, 37.31782205643193, 41.36695146560669, 37.67114131681381, 53.25840896175754, 17.44007372087048, 0.05631122392632308, 0.02727402670819673, 0.5276499219959783, 2.5248044296618435, 19.340187503445534, 47.50595500392299, 51.54667092907814, 58.09358135346444, 54.556638963760875, 56.058306617121545, 55.44329858595326, 54.45738730892059, 51.75787879574684, 54.157722150125814, 51.498331639074514, 50.773281512721894, 49.6975754153344, 50.4478895279669, 50.94731315489739, 51.643828038246404, 50.82656691151281, 53.30797203125493, 50.789661330561486, 50.766433054401034, 48.495568998398326, 46.38594181306901, 44.925278617489724, 40.38743757432507, 36.96901352174821, 36.1616720691804, 36.83229538702196, 36.40350972452472, 37.71908444743003, 38.23353075212048, 38.526771068573, 37.58039728287728, 38.701398911014685, 35.98413382807086, 35.73465539563087, 38.429111896022675, 36.51031586431688, 36.913382545594246, 37.421160820991766, 37.50795502816477, 38.1914907886136, 36.59840445364676, 36.110975434703214, 36.660079802236254, 36.16271934201641, 37.076615902685354, 39.35157883551813, 38.36638927459717, 42.69954535268968, 45.484863558123195, 50.25145330736714, 51.72607229601953, 50.85716532122705, 50.52561913767169, 52.516849579349646, 52.2388437486464, 48.81055493508616, 44.9690208896514, 44.43968526778683, 46.71544836413476, 51.80025608308854, 53.748909196546, 51.66826048204976, 48.560880384137555, 54.49818780345302, 53.15369736763739, 55.490837712441724, 54.36922027218727, 52.21249718819895, 46.60432369478288, 46.8403797764932, 50.92384561415642, 50.55744524924986, 51.55831644611975, 52.80833659633514, 50.69965470221735, 46.3069962686108, 51.701000505878085, 55.50512690697947, 49.28693855962446, 40.65854395589521, 37.884886956984, 38.27353500550793, 37.60617509964974, 38.33635960855792, 38.412779146625155, 41.829791145939986, 38.84558523854902, 36.97332812893775, 38.86697784546883, 37.26487398147583, 35.90186211370653, 39.9894582071612, 41.463371169182565, 40.40504901639877, 41.29011223393102, 42.0984931145945, 42.223938357445505, 42.744605541229255, 41.920452810102894, 41.05786085128784, 39.72351366473783, 40.28529905503796, 38.84724047876174, 40.83968293282294, 40.833932738150324, 41.592283787265906, 39.7169005486273, 40.97295330416772, 41.797663011858546, 42.31552962333926, 41.44789349648261, 44.28728157474149, 43.16601714780254, 45.39944218051049, 46.89094305038453, 46.66279446694159, 44.10083563097062, 48.698904668131185, 57.7404111431491, 61.301950716203265, 60.6493075432316, 65.44255764253678, 60.05201293576149, 64.80190515518188, 28.968568809570808, 0.1835794266193144, 0.5321687375826221, 0.022379582890519695, 0.38090749613700375, 35.75317682758455, 64.60808907785724, 51.78346833875103, 44.541882622626524, 34.81924087770524, 24.744774295437722, 40.36898282266433, 51.50522324346727, 47.955917542980565, 9.733396883933775, 0.09728436403337026, 0.04686955798176989, 0.13213939574216643, 0.007492437096868432, 0.02155452917870735, 0.02295472914533269, 0.01734146885874291, 0.06991084740166703, 0.026751194682513035, 0.02419177728194383, 0.019854980355669415, 0.02113332063139927, 0.007333111876036011, 0.030461142079964764, 0.07491560021956122, 0.05534455886170749, 0.01148910391249604, 0.08718115052268391, 0.03724148752348077, 0.059659744447637955, 0.1386917764020543, 12.492109652488464, 57.70280738030711, 62.09586197330106, 48.23721816462856, 30.595730735409646, 25.61790958527596, 27.46702471087056, 37.9280722525812, 42.82884236304991, 60.195646209101525, 18.754191283256777, 0.05683122142668694, 0.07562885105970406, 0.9184297787085657, 4.083024571018835, 22.642801615499682, 45.86896557961741, 52.74186811139507, 57.53203915011499, 56.23740988392984, 57.67575479322865, 57.61353815755537, 55.91107260796332, 54.59749437147572, 56.442236054328184, 53.72507687537901, 53.01513964130033, 52.72990880473968, 52.93801407660208, 53.873503285069624, 53.16697066830051, 53.43456260619625, 56.175008896858465, 52.03555906972578, 53.25319613179853, 50.71355558210804, 49.11468375113703, 47.34901312858828, 42.9700319997726, 38.14613249994094, 39.06568511839836, 38.69645672459757, 39.152083166183964, 40.225635882346864, 41.551687255982436, 39.975682843116026, 39.34137282832977, 39.777724742889404, 38.42476983224192, 38.844259477430775, 40.725718467466294, 38.32186645077121, 39.194754631288596, 39.985167134192686, 38.75741427944553, 38.899047143997684, 37.255397535139515, 38.8592037077873, 37.824082374572754, 37.86534178641535, 39.00657499990156, 41.90558702714982, 40.41986380853961, 43.993170492110714, 47.33156642606182, 52.749261779169885, 52.478233845003196, 52.20543692188879, 51.65067649656727, 54.428044057661495, 52.74980306625367, 51.21153185444494, 46.05397985827538, 46.54440556803058, 48.4936313475332, 51.93331856881419, 56.03529407132057, 55.36898536066855, 51.32474714709867, 55.87646945830315, 54.80082611883841, 56.42724475552959, 57.082351176969475, 55.00611905128726, 48.32835835795249, 48.97401971201743, 52.97046776740782, 53.02182336007395, 53.80777612809212, 53.59628977314119, 51.6074872785999, 46.92649149125623, 53.09174353076566, 57.90210300876249, 51.52019100804483, 40.81030438023229, 40.5005548077245, 40.132660019782286, 39.66705114610734, 41.083524919325306, 40.124744676774554, 43.33828764577066, 40.44541412784208, 38.96917127793835, 39.61246352041922, 40.02981939623433, 40.25903486436413, 41.300228026605424, 42.93844515277494, 43.681993176860196, 43.85773105006064, 44.28774441442182, 44.26033489165768, 44.515461537145804, 41.95516578612789, 43.45492324521465, 42.10394128676384, 41.54158715278872, 40.97700903492589, 42.37108607445994, 41.612076067155414, 43.73960494995118, 41.13003246245846, 43.27197605563749, 43.588519173283736, 44.38555655940887, 43.03072675581902, 46.099275389025294, 45.275295242186516, 48.56361035377749, 49.18802030624882, 49.777866332761704, 47.119436802402625, 50.168601082217315, 57.49224278234667, 63.793181373227036, 63.13124218294698, 67.79810567055979, 61.86170039638397, 65.65222401772776, 31.135050750547844, 0.637670076422153, 0.5960229628028408, 0.0537082486815991, 0.2925868740966243, 40.70728725002658, 69.08021080878474, 58.87074801229662, 41.439142688628166, 32.49728795020811, 33.478111913127286, 47.002071642106586, 58.84280504718904, 56.757684830696356, 12.839935633444018, 0.14838612878755217, 0.01537987870359493, 0.07995299604390899, 0.08161893850492855, 0.019329212298015916, 0.05209282205830659, 0.03252938029266173, 0.11995871265929554, 0.025184519979501926, 0.004518501011789927, 0.1712120249266586, 0.07845380794136755, 0.18691768539288353, 0.17303370540180515, 0.17509731644343945, 0.40503923510832174, 0.4066471310873186, 0.10436027385895291, 0.10333416037141316, 0.1751737107312487, 0.24679569978146787, 15.746143248773391, 67.09470702755836, 66.97490999775549, 58.37441913543209, 33.68049052453811, 30.699859857559208, 50.72213380567489, 55.25950416441887, 48.480044257256296, 65.21688015230241, 21.238971602532175, 0.15188417818036773, 0.17538006417453292, 1.6824591328059475, 4.4263167823514635, 22.005692989595477, 49.06547369495515, 53.159733895332586, 60.55437049558086, 56.81638702269524, 59.77928269294001, 58.45793424114105, 58.609957464279674, 55.64597921986734, 58.64167767186319, 56.35173128497217, 55.15346288681031, 54.18938352215675, 55.40707549741192, 55.03351288457071, 56.53660435830393, 55.945024644174886, 58.14312088874079, 54.852444510306086, 56.45362269493842, 52.78007984161378, 51.23590546269571, 46.894712448120124, 43.55223332681964, 38.557028232082246, 40.140724412856564, 41.75941598030829, 40.37078319057342, 41.460378400741085, 43.95709253126576, 41.40075052938154, 41.50144953881541, 41.5808500782136, 40.021558884651434, 39.877501995332786, 43.02306244450231, 40.386743314804576, 39.92240136669528, 41.205416494800204, 41.28598982287992, 40.39493714609454, 39.17418964447514, 39.65430344304731, 40.92856776329779, 39.91694927215576, 41.23079422981509, 45.02711903664374, 42.32820672373618, 45.89749297788067, 49.67091898764334, 53.9356493180798, 56.96528411680653, 53.46631419274115, 53.159647603188795, 55.576925892983716, 54.89866572041666, 56.134290772099654, 49.45814217290571, 50.02999236506801, 50.964842227197465, 56.3122526291878, 57.96574346480831, 56.99712199549521, 52.88713309072679, 58.198928371552505, 58.670236449087824, 59.06436404874248, 58.950046570070334, 58.078037000471554, 48.792484575702304, 52.89932773959253, 55.222131821417044, 55.078361265120975, 55.22148070796844, 54.353668074454035, 53.38689011912192, 46.834115751328014, 53.646280380987356, 57.79584207842427, 53.70268406406526, 42.89296134825676, 43.42889439675116, 41.85833031131376, 41.949454815157004, 43.51199765359202, 41.779055287761075, 46.089151751610544, 42.75867116066718, 40.35448574250744, 42.199835392736624, 40.44372750866798, 41.48043347943214, 42.71487789769327, 46.56441750064973, 44.99155098392118, 46.020584798628285, 46.05113613990046, 45.599643876475675, 46.56038922648276, 46.34900877552648, 45.3546408684023, 44.42274062864242, 44.04341997638826, 41.61742618007045, 44.72167230421498, 44.12471502057968, 45.73493034608903, 43.088405209202925, 45.06725665061705, 45.76405786698865, 47.03840063464257, 46.071018634303925, 48.13579351671281, 48.7860518886197, 50.01517757292717, 50.63814409317509, 52.28258602080807, 49.083634268852975, 53.11204964114774, 62.30939580548195, 67.39427412709883, 66.03160350553452, 70.37409090226697, 64.48330671556535, 66.38709575899186, 34.72527265548706, 1.4947797261899518, 1.247657902779118, 0.38586782351616894, 0.690416946045814, 44.65544308385542, 74.73556257063343, 64.54152645603304, 60.701306404605994, 48.77342970140519, 36.71087841833792, 58.382401158732755, 70.38459500958844, 68.336333305605, 18.676708782872847, 0.2633714063032981, 0.12127888899657036, 0.16255120175980753, 0.1477531256574777, 0.09185069390842993, 0.16926188682836874, 0.10912976873617981, 0.20932871427747513, 0.132541254823727, 0.19455699159974055], [0.09994307217458565, 0.05065526955971315, 0.08712933999636481, 0.05796289799975292, 0.06324481759821216, 0.11209184769541027, 0.055036851986041, 0.07860231408548933, 0.04814546592834015, 0.0957638020777414, 0.05240846560486863, 9.426927393482579, 50.27745077686925, 49.987324822333555, 45.414551150414255, 19.429715602628647, 41.05258134103591, 72.73341225039574, 51.60576143572408, 32.155145483632246, 46.94460107434181, 22.26880361956935, 0.059131388928020195, 0.10918005474752958, 0.5785643705917943, 3.5973571865789356, 26.138155114266183, 44.30217481428578, 54.7756366575918, 55.63146645022977, 55.27373452340403, 55.429276112587225, 54.52541297481906, 51.46997290272867, 50.57284447454637, 49.067587852478034, 45.737758374983265, 44.17510571018342, 42.5352608003924, 41.871866410778416, 40.91259979432629, 41.431517601013184, 43.25485490983532, 43.51399021763956, 43.038614642235544, 41.686079425196496, 40.31218690256919, 40.93274508753131, 36.02322416920816, 36.96134528806133, 37.10415486366519, 36.630042291456654, 36.13213662178286, 36.73931560208721, 36.1993738912767, 37.04700985262471, 36.06580541979882, 36.548939443403675, 36.61565896003477, 36.58952028520646, 36.284030406705796, 37.94692316362935, 36.4637847869627, 37.55956557489211, 37.6151063365321, 37.44274170167985, 37.60241354665449, 38.13690316292548, 35.798460591223936, 36.93092730737502, 35.62187940843644, 37.526421546936035, 37.92834289612309, 36.078509976786954, 39.75070353477232, 44.945922051706624, 49.563587250248084, 51.883010248984064, 51.62014084477579, 51.221067136333836, 51.33719282765543, 51.53580204133065, 48.07704817864203, 46.0155955437691, 43.53455128208284, 48.68443896693569, 51.535821653181515, 51.53184044745661, 51.22313422541465, 46.16721476277998, 49.755916749277425, 47.40382040700605, 54.47954085565383, 51.33678882352768, 50.61377440729449, 47.73407220840455, 46.906334430940696, 49.3449661039537, 51.82854813914145, 54.346090055281124, 50.71771329449069, 51.41339271299301, 44.53484981290756, 51.223400946586366, 49.731598054209066, 49.947049925404215, 43.03449615355461, 36.58081654579409, 39.28514172953945, 36.74765456107355, 38.459510264858125, 37.169964390416304, 39.080429307876095, 38.63615420556838, 38.8463108770309, 37.900219501987586, 37.85598693355438, 38.67552695735809, 38.9674925035046, 39.15112610786192, 38.19453847023749, 38.311946776605424, 40.1058231630633, 39.03249009963005, 41.429568183037546, 41.90347286962694, 42.71555646773308, 39.022911671669256, 39.78735808403262, 40.20353724879604, 41.397032122458185, 41.14718106485183, 40.61154611649052, 40.322192868878766, 42.02281098211966, 42.75494490900348, 42.58201153047624, 43.09207262531404, 43.21959672435638, 44.29158441482052, 42.86893290858115, 43.44463486825266, 45.694577001756244, 46.174420156786525, 45.54433453467585, 50.37028151173746, 58.896243418416674, 59.196061549648164, 63.39242889035133, 66.68387013096964, 65.0919016715019, 39.584234222289055, 1.4496062792116597, 0.3918058016607839, 0.08589563200310354, 0.262492059940292, 35.50316495280112, 66.16171636889058, 48.01267423937398, 52.91298151016236, 36.56839832182854, 23.521224260330204, 46.56877525391118, 53.64459376181326, 49.01393767326109, 8.51514499033651, 0.13644150037678981, 0.016660742281425386, 0.02250325246413629, 0.04965493110038581, 0.03966785651902038, 0.1085896461060451, 0.07038571466241153, 0.04290839694740792, 0.046800276820337584, 0.0014182956816042745, 0.07571114422453028, 0.06272730605316258, 0.03615207602119735, 0.03845448049926951, 0.03046987548230156, 0.037530011557523286, 0.010379267548541389, 0.054208718600773045, 0.07567654003299053, 0.08475996794239168, 0.12059748443143985, 11.407301695116105, 59.33894172791512, 55.32030090208977, 56.6092937223373, 25.85891962051392, 35.48456115107383, 62.15906312388759, 51.549800980475645, 38.832060906194876, 53.39589980340774, 23.28426799466533, 0.10509967127995146, 0.1361359538690698, 0.8176176334100386, 1.9340672896754358, 25.591437508983, 45.76177504754836, 55.09675325885896, 57.80254540904876, 56.759038048405806, 57.03189772944297, 57.22270142647528, 52.43443665965911, 52.10836610486431, 50.852270203252, 47.83180198361797, 45.07743127884404, 43.44642346905124, 44.684021472930915, 43.60533045184228, 43.826991435020204, 44.79860959514495, 46.343948918004195, 46.12231931378765, 44.778479991420625, 42.6708100688073, 42.79874209434756, 38.43714491013558, 38.36158829350626, 38.26850652694702, 37.03733336540961, 38.62464204911263, 37.854990651530606, 37.46046689248855, 39.2193361251585, 37.71264783797726, 38.49892616271973, 39.435992163996545, 37.762536464198945, 37.79983820453767, 38.51977356018559, 38.2331738164348, 39.06841901040847, 37.858344278027936, 38.09839333257368, 38.82543210060366, 39.97235275083973, 37.37240968212005, 40.85550969646823, 39.31190406122516, 39.687420014412176, 38.64720744471396, 37.78795342291556, 41.84544924766787, 47.12523798788748, 52.92755311535251, 52.63224178744901, 51.168224965372396, 53.44648661152009, 52.38604245647308, 53.2942045119501, 49.587439183265936, 47.49997731178038, 45.09127332318214, 50.559857506905836, 54.19400407421974, 54.625386345771055, 53.1117436962743, 48.669180946965376, 51.380487949617454, 51.53075002854871, 56.95103806834067, 53.65565092332902, 53.5328846593057, 49.3703281494879, 48.62704292420418, 52.02052070248512, 53.12603681318222, 54.47239037482969, 53.59042975210375, 52.83912720218782, 45.41309595108033, 52.25169343333091, 53.96430615455874, 49.95558500289918, 45.455410480499275, 38.46174601585635, 40.04342217599192, 39.529623062379905, 40.16491759207941, 39.22640031383884, 40.35236374024422, 40.74316909236293, 38.800862373844275, 39.19214233275383, 39.940459958968624, 41.23106487335698, 41.64777748046383, 40.71349636200936, 39.75244506712883, 41.60900092894032, 41.930556835666785, 42.47177331678329, 43.29278030703145, 42.76098928143902, 44.00000326095089, 41.55584104599492, 41.174414080958215, 42.67269280649001, 43.41715082045525, 43.70660604969148, 42.49071444234541, 43.29370206402194, 43.67562717007053, 43.610127510563025, 43.997928327129735, 43.71386635688044, 45.72291220388105, 46.24601517954181, 43.8301371758984, 46.2732481956482, 47.28282313193045, 48.344671495499156, 47.863600638604936, 54.15316435598559, 60.85199209951586, 60.78929693468156, 66.33779156592585, 68.97526387245425, 66.28814220428467, 41.954714713558076, 2.0181706283361684, 0.5127355997120181, 0.05244998373992501, 0.3237164278905238, 40.31074739271595, 71.8053480886644, 53.42421147131151, 56.498074916101274, 37.50815899141374, 26.858194412723666, 52.503941059112556, 61.44001814626879, 58.987234561674065, 10.730076047681994, 0.17978369078088194, 0.09664176182160455, 0.026617688539948677, 0.0356635264301252, 0.031381592890548135, 0.04895915089535618, 0.14566740531834865, 0.03334284692461933, 0.01585088105076143, 0.010827470161471396, 0.2102091484853337, 0.1485513433093025, 0.17210482379361508, 0.15557189562147664, 0.09770198154353327, 0.15235284012892555, 0.08627842315622876, 0.11495163093411154, 0.1850563981720517, 0.2043516402162852, 0.30209359622770743, 13.964505637845686, 67.71111534487817, 60.96040641107867, 62.135293560643355, 27.05243214484184, 52.7697326290992, 79.80069960317304, 63.727042367381436, 45.47462617197345, 61.1542970134366, 26.922240834082327, 0.27383877204791196, 0.26213705479618044, 2.3699526873327073, 6.52912296595112, 27.96386349585749, 47.34131351594002, 57.81612073221515, 59.70629130640338, 59.53704887820829, 59.6182184065542, 60.58574945695939, 53.96978570568947, 55.11012461877639, 54.21099970417639, 49.985489153092914, 47.54603378234371, 45.92284325630435, 45.854386129686915, 45.56694699871925, 45.596451067155414, 46.183245489674235, 47.381098116597826, 48.69932043936945, 47.24925941036594, 44.14432294907109, 45.14184051944364, 39.57732692841561, 40.52294761903825, 40.38429183344687, 39.43454088703279, 41.838851821038034, 40.24709124718943, 39.096934641561205, 41.50272038675124, 38.845106709388, 40.3273743198764, 41.79787481984785, 40.30775462427447, 39.76447105407715, 41.947760351242565, 39.521189966509425, 41.85772626630722, 40.293383059963105, 40.49949969014814, 42.107569479173236, 41.820844219576934, 39.466798459329915, 41.6325508394549, 41.576759046123875, 41.41882481113557, 40.82876305426321, 40.1482710530681, 44.69035217838903, 47.59351799564977, 56.30550223012125, 54.63937744017571, 53.1862412729571, 54.67845209183232, 54.66910508371169, 55.73965326432259, 52.87260463160854, 50.9948601261262, 46.74614875547348, 52.90638800590269, 55.50260874532885, 55.102377937686065, 55.248215583062944, 49.11014164647749, 51.2677864874563, 55.808765426758804, 59.987019262006214, 55.108084986286784, 54.40182693542973, 52.16125534426782, 50.765021001139, 53.46408628648328, 55.29817873431791, 57.415721262654955, 52.9061605084327, 55.669027066999874, 46.47622692969538, 52.074516050277225, 53.753302251139, 53.63766293371878, 48.035463210075136, 40.88951272349204, 42.916311217892556, 42.02345425082792, 41.716089479384884, 40.536954402923584, 42.22005913334508, 42.42073935847129, 41.26060424312469, 41.72128269749303, 42.35414143531553, 43.59097849938178, 44.33556202919253, 43.20189506776872, 41.45250228143508, 42.668554705958215, 44.516230321699574, 44.05949777172458, 46.296664745576926, 45.84306224699944, 46.59050518466581, 43.338519065610825, 43.79387094128517, 44.59794505949944, 46.50030636018323, 45.19978177162909, 44.34989436980217, 45.90857759598763, 45.56083202362061, 45.69274525488577, 46.8840475236216, 46.39068788097751, 47.34239216773741, 49.823216776694025, 46.53436037801927, 48.51427085937993, 48.73390397717876, 50.87530628327401, 49.70741664209674, 56.14581077329574, 64.60664564563383, 63.433248996734626, 70.79824032322054, 72.2602802707303, 68.2623887831165, 45.99997666574294, 3.0052874213264835, 1.5508800384498413, 0.2588077898948424, 0.3622083011413775, 44.75810720074562, 78.0314439342868, 63.06795474021666, 65.56798327353694, 47.14810148362191, 35.57776058873823, 62.31374571400305, 71.5227020940473, 70.85679346515288, 16.15783522205968, 0.23423650031608922, 0.16560395488575583, 0.13676449836742494, 0.12732398921563742, 0.18651521344098354, 0.21792466511889813, 0.3381991055944274, 0.20485941861425677, 0.12301898110778102, 0.10539963300670348], [0.03960630135430444, 0.0977512946232192, 0.022025525780214418, 0.06761453715303252, 0.10505890774150049, 0.08099457684663997, 0.013336413859149382, 0.02751796825548574, 0.045990177144807194, 0.08245971234094712, 0.003386606103665526, 8.624380057857884, 50.786472443611395, 55.264199241515136, 33.80917564515145, 29.400557087313747, 53.833263689471835, 68.86368813053255, 53.33177297346054, 31.670460162624238, 55.62749701161539, 27.509957013591645, 0.10550910697108316, 0.14654518886198922, 0.21956665201052544, 2.8463196417977734, 26.951680183410648, 51.24637034631545, 55.869146393191436, 55.65374551280853, 53.56047853346794, 53.45080121870964, 51.36445330035303, 48.57887229611797, 46.11166223402947, 43.85668769959481, 41.60236427860875, 40.25826607981036, 37.90185120797927, 40.51529507483206, 38.39377918551045, 36.855778617243615, 36.17565924121488, 37.95107303127166, 37.39083697718959, 36.486789488023334, 36.24157859433082, 37.091340480312226, 38.181818223768666, 35.865387993474165, 36.00620108266031, 33.740628304020056, 35.05678746008104, 36.66217042553809, 36.57841605524863, 37.503620809124364, 37.03004167925927, 37.640052610828036, 37.28143030597318, 37.05345430681783, 38.308934396313084, 36.001027476403024, 36.838167175169914, 35.90987551596857, 38.750448150019494, 37.1526510484757, 36.98477752747075, 37.473700969449936, 36.98594639378209, 35.536336437348396, 37.30729049251926, 37.537831721767304, 37.41707371127221, 38.01668251714399, 38.05173281700381, 45.015697094701956, 50.29065739723944, 49.94429249917307, 49.2929123293969, 50.43376115060622, 52.450977294675766, 49.251044950177594, 46.52093410491944, 44.55805455484698, 44.52274145618562, 49.811108419972086, 53.62159690549297, 54.30555628192041, 49.268707383063536, 44.2386402622346, 53.46025020845475, 50.53938273460635, 55.43927031178629, 51.92295174444876, 50.44014676924675, 46.36706344542965, 47.3943204264487, 51.104721792282604, 53.598839313753196, 52.376440494291245, 53.45588853282314, 50.49389893008817, 44.57081010264736, 45.23752673979729, 42.508725966176684, 52.437731450603856, 40.48700694114932, 38.14255529834379, 38.725129250557195, 36.4824160452812, 39.55758956170852, 38.98352323039886, 38.21123992243121, 37.37219787413074, 39.56006849965742, 38.32871490909208, 37.062813082048976, 38.64578754671159, 38.73946943590718, 40.077766449220725, 39.21573538934031, 37.24232035298502, 38.49120301585044, 38.951438242389315, 37.719872843834665, 39.39690966759959, 38.36269440189485, 39.32136481808078, 40.059280318598596, 39.351449397302446, 40.31719184690907, 38.833029731627434, 41.05453075901155, 42.07996776027065, 41.42775997038811, 40.2343160875382, 42.381805912140884, 40.91023068274222, 43.66723722027194, 43.1187565095963, 42.43685245513916, 41.92496353580106, 44.32814482719668, 43.87254976457165, 46.856787050924, 44.071912073319965, 50.723557626047445, 56.60690892127253, 62.174513339996345, 62.166350887667754, 68.16679277727681, 45.24453993766539, 0.5475169107798608, 0.17359271976015261, 0.0653340466200344, 0.16699189169993325, 32.27553479133114, 65.14329648786976, 52.23882805916571, 42.70153399436705, 39.31135100703086, 36.4050708278533, 50.29945527353595, 54.697106884371856, 47.27630807507423, 10.068883088327224, 0.04224101562173136, 0.029446221136998747, 0.03493165199254309, 0.04897261872106502, 0.01654275708020695, 0.04265163108826645, 0.0531360920849106, 0.040824791010949886, 0.049705079215909206, 0.08611097165773954, 0.03443135444315211, 0.09709971386098093, 0.06148304519874435, 0.05250359457286616, 0.05791107215167535, 0.035711165607696584, 0.03040401681867098, 0.050680454700223865, 0.023306376909116105, 0.06946038770219011, 0.02568002756414635, 10.50088607495831, 58.461876223164225, 61.19290882541288, 41.16876586791008, 26.90883025046318, 52.83599715079031, 77.80209510557114, 60.44432447802637, 38.2124166334829, 58.33627016313615, 30.019656150571763, 0.07891910676393779, 0.10428326670080425, 0.722092230233454, 1.8794742707283267, 26.381363637985725, 53.52548314679054, 59.0587511370259, 56.385165568320986, 56.32088576593707, 54.33235391493767, 52.81503208221928, 50.7210276972863, 48.339666551159276, 47.40259270514212, 42.76330347984068, 42.43144742904171, 40.12006528915898, 42.08959717904368, 40.72929959143362, 38.88622883827456, 38.2120636201674, 39.499726756926506, 38.99411362986411, 39.57001563041441, 38.79463365001064, 37.53434081231394, 40.17712400805566, 39.09160021812686, 37.36070140715569, 34.94107753999772, 37.39686566014444, 39.162187191747854, 37.52376610232938, 39.41891808663645, 39.29359051489061, 40.167212178630216, 40.03099610728603, 40.32204381881222, 39.2639099397967, 37.91315155644571, 38.67496605842344, 38.448347199347715, 40.8659000550547, 39.310715583062944, 39.21090695165819, 37.98333060356879, 38.384385108947754, 38.34770702546643, 38.602543415561804, 39.849229551130726, 38.0121325677441, 40.15681397530341, 40.40873604436075, 47.351629349493216, 51.69065721573369, 50.55249129572223, 50.215398880743216, 50.79255996211883, 55.59499625236758, 51.40572447930613, 47.680202376457956, 46.330879580590036, 47.66776061827137, 52.7066413048775, 54.68433956946097, 56.38575000147666, 51.49818258900797, 46.18400250711749, 54.149893099261874, 53.31581284922939, 54.004216271062056, 54.91337853093302, 53.39395430780227, 50.34840253091628, 50.80620196557815, 53.43460182989798, 55.14640262050014, 54.28719174477362, 53.796766035018436, 51.992918983582534, 44.46679669041788, 48.06293549076204, 48.91012430191041, 53.18103236536826, 42.38259823091569, 40.025406729790475, 40.83390528155912, 38.174848171972464, 41.552997327619984, 40.57325593886837, 41.014957966343054, 39.071533372325284, 40.522794646601525, 40.667577174402055, 39.59388717528313, 39.56710915411673, 41.44754832790744, 41.51146334986533, 40.29802714624713, 40.34435033798218, 39.90520569585985, 40.181383702062796, 40.261576560235795, 40.904437341997706, 40.770762966525176, 40.81324223549136, 42.09265662777809, 41.95917052607383, 41.5787672996521, 42.163125930293916, 41.95994715536795, 44.17805533255301, 43.44152050633585, 42.98578423838462, 43.77130946805401, 43.73178766619775, 46.265576039591146, 44.68264472100043, 45.11194813636042, 44.37690381080874, 46.23256144985076, 45.89768125164894, 48.46859093635313, 48.24272909472066, 53.55097855291059, 60.580038485988496, 65.86396140436973, 63.79635064832626, 69.2106060827932, 47.26214047401182, 0.6805683035523661, 0.2852675168504638, 0.027970437020544085, 0.24693327385091016, 36.21853466956846, 71.45824970737581, 56.65275750621673, 53.976496881054295, 45.016344285780384, 43.42823936093239, 58.71002889448597, 60.33407841959308, 57.39403055560205, 13.637323091107032, 0.023792189651078755, 0.057402673222485094, 0.04372847108771244, 0.01789284149004567, 0.05967885451090913, 0.0957237663228185, 0.07846612663518998, 0.029473174025394747, 0.08642426331437404, 0.050036768474045305, 0.17792076413189212, 0.22129531408990585, 0.18378892102308814, 0.1843540027977959, 0.17068141710854348, 0.13280825178709724, 0.1722242569010104, 0.17429358295855985, 0.10806787128169691, 0.2194313608830975, 0.09596501507105366, 12.570905166287577, 66.15574652148833, 67.5782411329208, 47.851351076556796, 40.57008274139897, 61.677231327179946, 73.14006005564045, 61.620968849428245, 44.91726521522769, 67.87190114298176, 32.908626910178896, 0.21406516012164856, 0.34281506112987, 1.421760392765845, 4.296292662620544, 30.195717619311427, 55.27406792486868, 60.012173421921275, 59.25336345549553, 59.59690032466766, 56.58675970569734, 55.289074913147964, 52.716223655208466, 48.843012548262074, 49.62855738978232, 45.28593271009384, 44.22713987288937, 43.04373725768059, 44.94103870084209, 42.986247078064956, 40.88723382642193, 39.219143929020056, 41.605855188062115, 41.51157709860033, 40.89810271416941, 41.959692201306744, 41.099481121186294, 42.438158604406546, 42.137971770378854, 39.31305723805582, 36.75962563483946, 39.68275631627729, 41.06114779749225, 40.083850045357984, 42.3662184130761, 41.63776759178408, 41.39043469582835, 41.34142075815509, 44.19299171816918, 43.190739846998646, 40.55671530385172, 40.26847208699873, 39.96337836788547, 43.39915498610466, 41.26418928946219, 42.02425441434307, 40.287946654904275, 39.46253876532278, 40.94517507860738, 41.91970755977016, 41.822589674303615, 40.184400004725305, 42.84300996411232, 42.314219551701704, 48.49887947882376, 54.27366349004931, 51.98606268052132, 52.540776037400775, 53.74520255673317, 57.926213818211714, 53.151869543137096, 50.514197195729906, 47.74935768496606, 50.92776406195856, 53.64304442559519, 57.416113499672186, 58.62343472819175, 53.04874650893673, 48.943519361557506, 55.99171261633597, 56.021436337501775, 58.052702411528564, 56.948496372469016, 55.36374899648852, 52.370768747022076, 51.980583129390595, 56.078526435359834, 55.887189295984086, 56.69921405853764, 57.45349368741436, 53.83106323980517, 45.352079560679776, 48.19838277755245, 52.34859951080815, 55.347996757876494, 43.42190865547427, 42.21153582296064, 42.30902633359356, 40.26679723493515, 44.03383762605729, 44.323504663282826, 42.44976097537626, 40.57058480478103, 43.83122759480631, 42.4759231844256, 42.481426269777366, 41.42052319742019, 44.76527729342061, 45.14023234767299, 42.940108237728, 41.97776256069061, 41.7701122837682, 43.18463271664035, 43.701836447561945, 43.85338506390972, 42.72600173950196, 42.06843599196404, 43.92027324245822, 43.75138382757864, 44.823069495539514, 44.666413953227384, 44.615066205301595, 47.732597397219756, 45.6910978594134, 44.90085401842671, 46.459741207861136, 45.00784843198715, 47.64508931867538, 48.185187924292784, 46.15330996051912, 46.848055854920425, 48.18532128487864, 48.018883351356756, 51.12794614607289, 49.05500096659507, 56.36971927458241, 63.733690784823516, 68.56441128638484, 67.89360753951534, 71.34243780566801, 49.785330603199625, 1.228021169381757, 1.4438656453163394, 0.2856242073880088, 0.28859908001557477, 40.39041465328586, 76.6746097995389, 64.54219325896233, 56.76099138875162, 50.91534583799301, 49.338325531251975, 66.6918090081984, 69.42304165132585, 70.35345923516059, 19.82910506186947, 0.10882544030825939, 0.15118175216259497, 0.09504892713119907, 0.13052523316394898, 0.21380444507925742, 0.16049872963659226, 0.1409909288368879, 0.19436428984326704, 0.13814509605928776, 0.14444875861367873], [0.019529383411751162, 0.10894189333362926, 0.04976935016231672, 0.013376917885315996, 0.0822035631825847, 0.03895459035711904, 0.044626314643650286, 0.04841262377017448, 0.061237529340770945, 0.028313744002051895, 0.019749930549052455, 6.460833030362283, 54.4698957474001, 54.71420449595298, 48.58104921156361, 36.03441469130978, 36.93565376343266, 45.16886957230107, 38.88575423148371, 45.53109653534428, 58.52586577015539, 35.45799101552656, 0.19005663873207188, 0.1324652435798799, 0.48880347261025064, 0.7638798137345623, 25.761395769734538, 55.86828347175352, 55.58661806967951, 55.854170783873535, 53.5716769003099, 49.85239136603571, 45.891880066164084, 44.61900818732477, 41.36879497958768, 41.01602092865975, 38.92988089592227, 37.71158879803073, 38.10952109675254, 37.92644446895969, 37.510057418577134, 39.171651870973655, 37.371334952692834, 38.69361692859281, 37.61810302734375, 37.64191573665988, 39.46535894947667, 38.50596289480887, 36.08476223484163, 36.29931588326731, 35.679028341847086, 33.446929070257376, 36.55627819799608, 36.12085980753745, 37.87196666963639, 38.41428141440115, 37.53225803375244, 35.41229932538925, 36.145931597678896, 38.24036744333083, 38.50920669494137, 37.18572839613884, 37.23429910598263, 35.878120007053504, 38.17622492390294, 35.77888011932373, 36.289007894454464, 38.57132527136034, 36.88727132735714, 35.85366402902911, 36.18973270539315, 37.48298521964781, 38.61540486735683, 38.60941933047387, 38.479526119847456, 48.54268058653801, 49.58088490270799, 54.83860246596798, 48.96897554397584, 50.30382479390791, 52.130680468774614, 48.49067780279344, 47.20557205138668, 45.503832140276515, 44.668779142441295, 49.45558870992353, 53.07060587790705, 54.76497565546344, 50.95575801787838, 47.87138654339699, 55.148108851525095, 51.601129116550574, 52.19133992348948, 50.16212132669265, 45.20680673660771, 44.603550126475675, 49.33992193591211, 51.1507978746968, 54.15494903441399, 54.78254395146524, 55.82126602049797, 47.10120954821187, 55.48999440285468, 48.18683924213533, 45.1159607210467, 50.8068883803583, 38.01876529570549, 38.30377255716632, 38.372810194569254, 37.78021458656558, 38.16056682217506, 39.31105682926793, 38.785282719519834, 38.491885508260424, 36.27618958873134, 37.60595936929026, 37.863643400130734, 37.44509904615341, 37.63336496968424, 37.741230149422925, 37.022134180991884, 37.758794523054554, 38.353963205891276, 39.178767050466234, 40.22416499353225, 38.59747571329917, 37.55044606424148, 39.19380149533672, 40.22784025438371, 42.117983371980735, 40.49959774940245, 43.09603814155825, 41.09608042624689, 40.693959036181056, 38.81040942284369, 42.193520376759196, 40.22039167342648, 42.74819058756675, 41.324582023005334, 43.967192634459465, 44.41051852318549, 43.138929259392526, 44.86686275851342, 43.912193159903254, 45.40348614415815, 44.51609303874355, 47.39633652471727, 50.68298462898501, 61.29842450541835, 61.869027383865856, 69.52922021189045, 43.26310757667788, 0.4405890855818026, 0.20969669695102403, 0.06049138268515949, 0.09793685644023842, 29.633328184004757, 65.92529942912441, 51.03828076393374, 41.854466776694025, 26.87138926598334, 24.90604058388741, 41.76038088337068, 55.83147202768634, 50.1349667579897, 9.83772506636958, 0.12342323038366534, 0.20032880527357902, 0.06571457015290376, 0.03864877954906514, 0.06318186049259479, 0.05297485355948729, 0.06651131691591394, 0.029445539318746137, 0.01699993728599962, 0.06688711368629048, 0.026325613688377124, 0.10408733971416952, 0.03207940897423654, 0.03012631760699855, 0.054782641030127005, 0.02315788034109339, 0.022512223353729616, 0.02113613217408138, 0.050289002923114653, 0.032044741580443036, 0.04987387519870555, 7.849725677121071, 60.2921365153405, 61.65992975234986, 52.140945311515566, 40.491847145941954, 41.72505209522863, 54.93215883931806, 49.18784379959107, 47.642904558489406, 65.4544424241589, 36.48666789454799, 0.1602176060118983, 0.029543094870243824, 0.36174772908130004, 1.4652121643866263, 28.52609015280201, 58.44386469933295, 58.73085668010097, 57.86021601769232, 56.5142664601726, 51.33592590208977, 47.42307139981178, 46.04173029622724, 43.403771615797474, 41.15865791997602, 42.72914355800998, 40.442068346085094, 39.44693165440714, 39.48417848156345, 38.128972130437056, 40.750904006342736, 39.96224480290567, 40.20817741270989, 38.91723909685689, 40.115060344819106, 39.68515288445258, 39.85724687576294, 37.65024292853571, 37.25080051729756, 37.33365274244739, 35.81557389228575, 39.73794798697195, 37.85714011038504, 39.87241860358946, 39.60839210018035, 39.211283499194735, 37.80736915526852, 38.60522239438949, 40.338717814414736, 40.3343443716726, 38.88143570192399, 38.84724440113191, 37.53943204879761, 39.92141292941186, 36.92121159645819, 38.363074871801565, 40.54281050159086, 38.19034545652328, 38.25977140857328, 38.817085296876975, 38.555992726356756, 39.49973852403703, 40.66468246521489, 40.02370049876552, 49.928846205434496, 50.54041824033184, 57.3480329205913, 50.069992696085286, 51.366689051351244, 54.515457999321725, 49.567650825746604, 49.11292260692966, 47.64837234250961, 46.18089991231119, 51.97630774590277, 53.256734109693966, 56.661112154683764, 52.58005857467652, 50.87707919459189, 56.95789044903171, 52.836440378619784, 54.03182583470499, 52.952197367145175, 49.28685226748067, 47.90933939718431, 51.00901203770792, 52.419135493616906, 55.133925560982, 54.41303706938221, 56.47040651690576, 49.063328158470895, 52.74457846918414, 52.33663235941241, 47.76156410094231, 53.59124168272942, 41.14115238189697, 40.34322461774273, 40.88104432629001, 38.640249160028276, 39.640375106565415, 40.06319092166039, 39.43937324708508, 41.41226268583729, 37.82563955553117, 40.37172455941477, 38.713919116604714, 38.85007635239632, 39.32429090622933, 41.39727530940887, 38.739390988503736, 39.34355758851574, 40.41148170348137, 41.22512640491609, 41.47263972989975, 41.089906615595666, 40.09503664508943, 40.78578172191497, 42.45765278416295, 42.764025195952385, 43.190237783616595, 43.879759080948375, 43.28559844724594, 42.49263248135967, 43.56013298034669, 43.14190241598314, 42.79856951005998, 45.49526176145, 43.85274179520146, 45.74226125594109, 46.963620647307366, 45.668348112413966, 46.39485736047068, 46.15610268808181, 47.9281000937185, 46.55459196336808, 50.41640074022355, 54.65452563378119, 64.65307474136353, 63.812546114767756, 71.29759726985809, 45.26765054272067, 0.7871566905129341, 0.7594597928466336, 0.09864908072256273, 0.07960801899072625, 32.85723013262595, 72.07521500126009, 56.7481573935478, 43.681173401494185, 33.209425633953465, 31.45854234695435, 48.23844194412232, 63.43372360352547, 59.95647184310421, 13.439748402564758, 0.12010491287876522, 0.017181410108722987, 0.08274286609864043, 0.06229605983882662, 0.0025639954941242093, 0.09102803805182058, 0.05727624190190146, 0.03471781387023869, 0.03990442447003819, 0.1040943724013144, 0.08347040447857111, 0.22574708166141666, 0.1470427629688094, 0.18809320134741647, 0.1768669335832519, 0.08588995529158462, 0.14354808436286065, 0.15690312660749883, 0.13265575432488996, 0.14413729790718327, 0.20655161490844143, 8.376040093360409, 67.7578229288901, 66.42133020585584, 60.78188365505588, 46.93837235050817, 46.86945630658058, 52.620737475733605, 52.007521967734064, 57.6401710510254, 69.32076977145287, 42.57637900690879, 0.31088445515882585, 0.21541905198847094, 0.9037128619609341, 1.962214830902315, 30.998460092852195, 61.30095835654967, 61.66899042744791, 61.12982534593152, 58.11189882216915, 53.98607923138527, 51.200353099453835, 49.79396766231906, 46.90921345064717, 43.378754738838445, 44.09288498663133, 43.39324397425498, 40.62714930503599, 41.36575906507431, 40.162085640815, 43.365242173594815, 41.408889447489095, 42.0950492735832, 41.69648547326365, 42.7712070557379, 41.52080643561579, 42.14121164814119, 40.472537317583644, 38.358760264612016, 39.451964055338216, 37.09405868284164, 41.066376316931944, 39.7278949522203, 42.74366809475807, 43.272552644052816, 40.93634974571967, 40.00237849450881, 40.91989148047663, 41.25034724512408, 44.300021433061175, 41.811520745677335, 41.0826188518155, 38.83683050832441, 42.86812882269583, 39.078628939967004, 40.05809184043638, 42.98955363612021, 39.77268841958816, 39.44233463656518, 41.32547632340462, 40.088858912068034, 41.74457765394642, 43.32856409011349, 40.80659381804928, 52.41536609588131, 53.653701505353375, 56.13428292735931, 50.54503094765448, 53.91100898865731, 55.503777611640196, 52.91246767966978, 51.511204857980054, 51.28540577427034, 50.00812122898717, 54.72228065613778, 55.897477672946074, 58.243965025871034, 54.19017191856138, 53.31319270595428, 59.4689957557186, 55.427291393280036, 55.36322732125559, 56.07775372843589, 49.58894537341211, 48.77812477850145, 53.76854458162862, 54.32907089110344, 58.25208433212773, 58.136747037210775, 55.87255885524135, 51.33716144869405, 54.30351272706063, 54.052888962530325, 50.01997463164791, 53.53251203413933, 43.991028877996634, 40.38157363091746, 43.33322778824837, 41.35938521354429, 42.63421827746976, 43.13160619428081, 41.47528732976606, 43.12006658123386, 39.98867765549691, 41.75855305887038, 40.96244527447609, 42.13368069741034, 42.332258532124186, 43.37185921207551, 40.869747900193744, 41.63870503825527, 42.68492667905746, 43.06216063037996, 44.43790058935843, 44.06313380887432, 41.21648150105631, 42.86462614613195, 45.45467307490688, 46.0424441675986, 46.56741419146138, 46.99282661561043, 45.610908923610566, 45.3700989292514, 44.3881453237226, 46.13913843708654, 45.23975072368499, 47.421592666256814, 45.387165161871145, 49.03798964715774, 49.79323810146701, 47.383651579580004, 48.63163994204614, 48.772947249873994, 50.550553644857104, 50.99998666394142, 52.2137523466541, 56.30045413970948, 67.79164944925617, 67.32922554016113, 73.64883853543189, 48.28000730083835, 1.0908048936436254, 1.4517671374544021, 0.21438682511929544, 0.27752022288980027, 35.73393367951916, 79.28327621952181, 62.10377731630879, 55.17535755711218, 37.561648353453606, 36.81036149301837, 57.52863453280542, 70.33863267590924, 72.32649772397934, 18.971931857447473, 0.320044078173176, 0.23792346699103234, 0.2907076604183643, 0.09648968570775564, 0.21225199854422003, 0.1714316929780668, 0.19561883542806874, 0.28896569905261843, 0.08855624770325038, 0.23274203131516136], [0.04199858709809281, 0.09201675112689696, 0.07187414689049607, 0.03409397315173861, 0.026883494236596653, 0.06254459025278207, 0.046423844196983886, 0.06411837616695032, 0.07080436639127231, 0.02226198647892283, 0.06701908765300628, 2.92401738224491, 46.17380434466947, 50.24402433826078, 44.82843922030541, 25.516147613525394, 24.826139942292247, 29.395754145037746, 35.00764800656226, 49.13668040306338, 58.32392646420387, 36.35249930043375, 0.0979315551118024, 0.10638423218962648, 0.49830667073688206, 1.23778983229591, 30.26803828054859, 59.030204126911784, 55.78700019467262, 55.152478371897054, 52.49866547123079, 46.20605799459642, 43.384195066267445, 42.8524197301557, 42.71931409835816, 39.8174112842929, 39.194507521967736, 37.91264164832331, 38.22568601177585, 38.19484049274076, 39.481562260658514, 37.992108868014434, 37.92039617415398, 37.673498661287375, 37.4827459550673, 38.45657633196923, 35.26941522475212, 35.307709324744444, 36.515336498137444, 35.75219623504147, 35.09111996619932, 35.40052829250213, 37.07051269469723, 37.24601522568734, 39.464480338558076, 39.164489623039, 39.92085595284739, 36.92533792987947, 36.650736716485795, 35.811192604803274, 37.233557778020064, 37.512089206326394, 37.96498567827287, 37.18444185872232, 36.61851052315005, 36.64240952460997, 38.84470270526025, 37.88994289213611, 34.91746487156038, 37.21274568188576, 35.50529087743452, 36.04426768518264, 37.01205368964903, 37.74571734090006, 39.20177175152687, 49.00908962372811, 52.27131312893283, 44.35935120428763, 42.42742307724492, 53.15369736763739, 49.92304109757947, 51.48279513082197, 46.504417004123816, 43.00230133918024, 39.342965310619725, 45.047876219595636, 50.44364944581063, 51.699682589500185, 51.8500348829454, 52.02199943604008, 53.47013458128899, 52.08513782870386, 47.31150742500059, 45.5436755764869, 45.089076795885646, 47.02048324769544, 50.36714361559961, 51.42373208076724, 51.78251520279915, 53.859916194792724, 53.231458356303555, 57.66999283144551, 52.84488524160078, 41.25415194419123, 52.74923432257868, 44.13477590007167, 38.421231854346495, 36.82594506971298, 36.71379273937595, 37.24148488813831, 39.245125709041474, 38.79522592790666, 38.00586462020874, 37.076243277518984, 40.517322940211145, 38.85149232802853, 37.70317531401111, 38.019439943375126, 37.049335818136896, 37.36107010995188, 37.1088420960211, 36.86576104933216, 38.804678840021936, 38.56962688507573, 40.58424249772103, 40.459075743152255, 37.38053683311709, 39.01896576727591, 38.061817230716834, 40.17157385426183, 39.370064966140255, 40.16239158568844, 39.67926540682393, 40.22220380844609, 41.62949923546084, 41.78367976219424, 44.19156789779664, 40.5048184241018, 43.9199084620322, 49.41810261818671, 51.26577823392807, 50.584050686128684, 51.97706084097586, 48.94524128206315, 46.67101967719294, 45.88498453940115, 47.66956883092081, 51.95251464843751, 60.850611425215206, 60.657426849488296, 68.14015988380679, 44.73511034442533, 1.00991599862614, 0.39811177780070617, 0.1148306733117469, 0.0349481726786302, 28.188987931897564, 64.53472506615424, 53.32765448477961, 49.30357333152525, 35.630359572748986, 40.01414952739593, 46.15414150299565, 54.324713137842, 48.6407986763985, 7.470989948318851, 0.0677469018245897, 0.1529000567332391, 0.035833628592832435, 0.06083137250595516, 0.04796255477553895, 0.08871680441042108, 0.029493546218521176, 0.027118453402973475, 0.04040004505265144, 0.014001763136606785, 0.07397316651599062, 0.03998692447860395, 0.04122300351399087, 0.044147367964709, 0.06970547455092592, 0.051711218341464, 0.06360655665517816, 0.1267639482994714, 0.00935558543255132, 0.05515186859655285, 0.05233427381984169, 4.03906534275701, 52.612072960022964, 57.49121512136152, 53.37197726772678, 32.20545576464745, 30.47912455374195, 40.170954119774606, 43.21037915445144, 52.60221212140976, 63.015394979907626, 39.44031069355626, 0.11432872484287909, 0.018732830085941864, 0.5157842006414167, 1.090254781226958, 33.295980576545965, 60.99696290108466, 58.617731601961204, 57.49951093427597, 55.35361751433342, 47.46896313082787, 45.698962211608894, 44.971735169810636, 44.37147132812008, 42.20404801830169, 41.26395786962202, 40.47190189361572, 39.766542065528135, 39.78056061652399, 39.325083225004136, 39.35561887679562, 39.665972494309955, 38.82693829074983, 37.90709933926983, 38.3352574225395, 36.65061512301045, 37.28432893753052, 37.37066030502319, 38.33038976115566, 37.405192852020264, 36.65732237600511, 39.30349842194588, 39.12939617710729, 41.35810652086812, 40.953184558499245, 41.62670650789815, 40.48669315153553, 39.08587355767527, 38.37770139017413, 38.60606570397654, 39.52785799580236, 38.870943361713046, 39.53259621897052, 38.29932851176108, 38.45501915101082, 40.12432890553629, 38.17902549620598, 37.9734815320661, 38.712295255353375, 39.083335784173784, 37.88652258534586, 38.811782252404, 37.94699768866263, 39.102320055807795, 52.611845462552964, 53.80128460545694, 48.89202648593534, 45.16495896923927, 52.12666003934799, 51.463159745739354, 53.42333286039291, 49.307056396238266, 46.13274105133549, 41.88549272475704, 47.18277131357501, 53.1478726479315, 54.552897022616484, 54.4473970320917, 54.86853407275293, 54.012880786772705, 55.23715057680684, 49.56674868060697, 47.93620763286468, 48.1664978304217, 47.275841313023726, 52.05297439329086, 52.447094148205174, 54.37678652424967, 55.96658591301211, 51.75137158363096, 55.953136105691236, 58.93025036781066, 44.43365658483198, 53.40072039634951, 46.24061015344436, 39.49369022923131, 38.711208758815644, 37.07283866020941, 37.895159644465295, 39.84180842676471, 40.50438304101267, 40.16220723429034, 37.80492551865117, 39.1422458617918, 40.22411792509018, 40.26512238287157, 39.49911486717963, 38.76548259488998, 39.85491306551042, 39.62120648353331, 39.3372739514997, 40.31546208166307, 40.60649018133841, 43.24602957694761, 41.60089731216431, 40.368759247564505, 40.49062336644819, 40.17991673561835, 41.440413536564, 41.58224251962478, 42.46380698296332, 41.0395473049533, 44.34294392985683, 42.9925738611529, 43.72135416153939, 46.221472909373624, 44.10025119781495, 47.62799562946443, 52.579658492918945, 52.38022950387771, 53.97421013924384, 52.983686154888524, 51.9877806786568, 48.532780524223085, 48.29444946781282, 51.88031165830551, 54.49476749666276, 61.97451168490995, 63.456912655984205, 71.98717348037228, 47.341399808083814, 1.2274247239674292, 0.2942398773326028, 0.14113357440838892, 0.0582034687601751, 30.43443895155384, 71.06969971810618, 57.346958191164084, 52.64387161500993, 33.965909634867025, 37.97703127707205, 50.40698312943982, 63.51279074145902, 59.68619308164043, 10.036449009372342, 0.12867237291028424, 0.11379273142665626, 0.05316485868646734, 0.051049356679281885, 0.01161305885386443, 0.045200336664434404, 0.04873114014645258, 0.046379644754192526, 0.05127033474104059, 0.05751709611485562, 0.15257301379836377, 0.1940061437386659, 0.1302416887014143, 0.09180334967470939, 0.18310687294410122, 0.1916430076403964, 0.21771722383076147, 0.26516334724522406, 0.11181418678813404, 0.13135959484404133, 0.23414745025577086, 4.431575700159996, 61.23804353898572, 66.52518672327842, 60.29722775182417, 38.61261998453448, 36.19616147010557, 38.35020949763637, 47.2591124042388, 61.06927963995165, 68.49137675377631, 42.579587505709746, 0.24707584281361875, 0.15884638523622868, 1.2813435855411714, 1.6402516105482656, 36.12452722364856, 62.32967053690265, 61.02956564195695, 60.137222505384884, 58.595566288117446, 50.44703052889917, 47.25736694951212, 47.15438904300813, 48.33416738817769, 44.28075867314493, 43.3610923059525, 42.18504805718699, 42.65755637999504, 42.79332530113959, 42.42910969641901, 41.838228164180634, 41.86673595059303, 39.98824619477795, 40.95369838899182, 40.00039769757179, 39.169247458058024, 38.147246453069876, 39.66752967526836, 40.447077212795136, 39.76929949175927, 38.17616216598019, 41.66164698139314, 41.66931129270985, 44.90555301789315, 43.431902854673325, 43.87044345178912, 41.79374064168623, 40.08343427411972, 40.521260999864154, 40.86605302749142, 40.61228744445309, 40.981241272341826, 40.79741154947589, 40.43670646605953, 39.85297933701546, 41.39540433883667, 41.60883618939308, 38.43068868883195, 40.782141762395064, 41.05563686740014, 40.76921363030711, 41.30919848718951, 40.59800609465569, 43.470459753467196, 54.81993198394776, 57.06285307484289, 49.54164551150415, 43.55741870018744, 54.81203625279089, 52.38099436606131, 56.30134451773859, 50.921680465821304, 47.70115960028864, 43.82251993302376, 48.54098612262357, 56.11754225146387, 56.09906396558208, 56.70503093350319, 57.74318425886093, 56.92472680922478, 57.728106667918546, 52.240047916289306, 49.97815039850051, 50.2817653840588, 48.7872285996714, 54.393684094952, 54.76230059900592, 56.505986336738836, 59.80950063274753, 57.024198116794715, 57.47621990019276, 56.94740203119094, 48.573710456971206, 55.26662326628163, 48.564869434602805, 41.745232689765196, 40.20625152895528, 38.697001934051514, 40.04595602712324, 43.91299724578858, 43.19295598614601, 41.65165278219408, 39.442640581438624, 42.571476044193396, 42.76797502271591, 42.21341071590301, 41.778125686030236, 41.45575000393776, 41.733967642630304, 41.65901114863735, 43.22899472328925, 42.06004996453562, 44.60878649065572, 46.302662049570394, 45.242100223418205, 42.90584241190265, 43.708288746495406, 41.17342564367479, 45.710333162738436, 42.906046375151604, 44.482713668577134, 43.13901555153632, 47.36167846187469, 46.388875745957904, 46.78418397903443, 49.06723483916252, 46.20545002721971, 49.47630666917371, 55.104786272971864, 54.83772777741956, 56.34491812798285, 56.82416900511711, 54.020035189967004, 50.9670191426431, 51.14758545352567, 54.54743708333662, 56.2175940698193, 65.9454054986277, 66.74556901378017, 73.15651832088348, 50.08487809088923, 1.6345470134289035, 1.2775179263084167, 0.40101454623283883, 0.13158274093462577, 34.48919303955571, 75.60824286553168, 63.94238048984159, 65.10824618800994, 50.80668441710934, 50.664298457484094, 60.056123579702074, 72.48319641236337, 70.52630239917387, 16.001155164933976, 0.48375789496687155, 0.24230985661908505, 0.10133381287056593, 0.1397964139018328, 0.1297661932485719, 0.11721615619476765, 0.1361383747069105, 0.07589271472346398, 0.18894132196662888, 0.14967902473384334], [0.05077408596632942, 0.04262791300613073, 0.05476877483869753, 0.0916820626345373, 0.016796439435453187, 0.05243132183808954, 0.07426876920245348, 0.09417302816385224, 0.009834824182513741, 0.04647702985112706, 0.06040223686385059, 0.43217118889574085, 29.505009805002523, 54.220672269021314, 48.43902803236439, 37.730412252487675, 27.99641916828771, 33.541666077029326, 36.31493476129348, 46.86965634745937, 57.36707995014807, 40.85853776624126, 0.44221530638394824, 0.01553272665102756, 0.31469516035529876, 1.292679970783572, 30.295371317094375, 57.59418910549533, 57.275520063215694, 54.37391142691336, 54.483906453655614, 48.34005878817651, 44.18821819366948, 39.841651531957815, 39.82218088642244, 39.172079409322436, 37.651572612024125, 35.3716282690725, 37.47577590327109, 39.19696292569561, 37.39335906121039, 41.18146650252804, 39.87771772569226, 38.308844181799124, 36.439583762999504, 38.39975687765306, 44.035830190104825, 45.66188796874016, 45.91333935337682, 47.46690388648741, 47.143186753795995, 43.64438941401821, 41.00303788338938, 40.39809073171308, 38.695986040176884, 39.66521155449652, 38.88699370045816, 39.905888188269834, 37.24734883154593, 35.5877390984566, 36.643409729003906, 35.36175566334879, 37.194385067109145, 34.620576750847604, 36.24845450924289, 38.57907587482084, 38.05241530941379, 36.253506522024836, 36.772608680109826, 37.5784674767525, 36.3858159126774, 36.57094394007037, 36.90495337209394, 36.99394410656345, 37.40323951167446, 47.44639773522654, 52.00309361180952, 40.04961559849401, 40.75712488543603, 52.75374897064702, 50.397428235700055, 52.26805363931964, 46.26930621362502, 42.664400915945734, 38.64922746535271, 41.216952185476984, 50.60403123978646, 53.22865386163035, 51.14129789413945, 52.5642357334014, 55.5073901145689, 49.60162247380903, 45.92735005963234, 44.387670716931744, 47.05134053384104, 49.86251500345046, 50.55506829292544, 53.54751902241861, 54.049194089828006, 55.72353232291437, 59.45342002376434, 50.64887569796655, 39.78781700134277, 50.16966012216384, 46.76612146439091, 38.46953584301857, 36.73003527425951, 37.62668909565095, 37.102252514131614, 38.88400485438686, 35.581278954782796, 37.775068436899495, 38.52025208934661, 38.92552314266082, 38.10759521299793, 37.865263339011904, 37.258943357775294, 38.897419360376176, 38.04590025255757, 37.54237382642685, 36.87106409380513, 36.03198674417312, 38.32927973039689, 44.55513631143878, 44.934009813493304, 43.59445371935445, 41.06180283331102, 39.53762077516125, 37.97049660836497, 39.39244993271367, 40.81450916105702, 40.80853539128458, 39.46284863256639, 41.04782350601689, 41.22585204339797, 40.20127011883644, 39.912732724220525, 40.82951222696612, 45.30386578652167, 53.8356053444647, 56.399909757798724, 56.87425374984742, 58.74525962337371, 57.06972506738479, 55.16934848600819, 53.292933664014264, 52.134528313913655, 53.248269634862105, 62.07053130672824, 60.79237599526683, 67.46078968048096, 39.94831254405361, 0.4967908585263837, 0.4235680521495881, 0.10462345570446023, 0.0033320379002215045, 25.476115903546734, 62.70763797144737, 48.119311717248735, 45.07926694808468, 27.82194822065292, 26.20083655080488, 44.76113527051864, 51.08099537511026, 51.78681804287819, 8.54183573876658, 0.14543875871646791, 0.1020927225509959, 0.10433884637971079, 0.05914977503820293, 0.05193192061156996, 0.043053068821468664, 0.024564593970294923, 0.02306534649593936, 0.06354527345167534, 0.021743856317874406, 0.05958829142694032, 0.07472046230348849, 0.05338784389858765, 0.023150162005256263, 0.014324853057792832, 0.02604904445639301, 0.03373228772092731, 0.01501609514948101, 0.035496465636477355, 0.12321580441728716, 0.030071461881180445, 0.5374309648909877, 36.97866255237211, 59.84656310850575, 52.56499275084465, 41.826782688017815, 29.552344968242032, 34.29674979179136, 42.58334513633482, 52.24858299378426, 61.818985785207445, 44.28153922480922, 0.2767987212827129, 0.045143266944515134, 0.44713975020474006, 1.9150741927085386, 33.49733937171198, 58.172275866231615, 58.83553297288957, 57.40503672630557, 55.487821409779215, 50.485120665642526, 45.23299247987809, 42.53841046364077, 41.872137054320305, 39.849390368307795, 40.03602458584694, 37.668721214417495, 38.4142461130696, 41.31239914125012, 39.31307684990668, 41.25600330291256, 40.4343451992158, 40.71141358344786, 37.357794930858, 40.311567168081964, 45.4273106205848, 45.97318295509585, 47.45193612190985, 47.31220168452109, 47.79903058082827, 45.64355873292493, 42.575849486935525, 41.962488851239605, 40.51843297096991, 42.60736180889992, 41.46739159860919, 41.09526065088088, 40.0053124273977, 37.68465388205744, 38.20523085132722, 36.76827838343959, 39.05079580122425, 37.87053108215332, 38.51250540825629, 39.50324904534125, 39.37221050262451, 38.29580622334635, 39.47369398609285, 38.99386652054326, 39.06925447525517, 38.998381168611594, 38.52124444900021, 38.885495355052335, 40.39497244742609, 49.031239248091175, 52.605777555896395, 42.69252431008124, 43.2475475342043, 54.88547478952716, 50.93331421575239, 53.48177225359025, 46.845082698329804, 44.36685077605709, 40.336419305493756, 43.86112782262987, 53.121047558323035, 54.857794623221125, 54.21791876516035, 55.335496164137325, 54.99241821227535, 52.92345423852244, 47.92323243233466, 47.00743744450231, 48.79513609793879, 51.163196486811486, 51.86605776509931, 54.98243578018681, 55.664159405616026, 55.42801310939174, 59.79254422649261, 55.435587206194484, 42.63403000370149, 52.00741214136924, 51.55701421922254, 38.93799235743862, 38.75917150128273, 39.2449805813451, 39.284114068554295, 41.27313621582524, 37.20920770399032, 39.15358151158979, 39.972937183995406, 41.139489296943914, 40.62281900836576, 39.29838365124118, 39.31982724897323, 40.39150114982359, 39.58854098473826, 39.360776793572214, 38.87112771311114, 38.495392107194476, 40.2555400325406, 46.54410354552731, 46.1135841954139, 45.59071263959331, 43.100631237030036, 41.48452451152187, 39.969391361359634, 42.36885424583189, 42.87298471696916, 42.87912322628883, 41.15995622450306, 41.59819479911558, 43.28425307427683, 41.44360634588426, 42.5292399621779, 41.74128286300167, 46.91119032521402, 53.93004032873339, 58.17151492641818, 57.13904119306996, 61.92193231275005, 58.57340489664386, 57.4429895800929, 55.713545968455655, 53.45059725546068, 56.42953541971023, 65.17172190450853, 62.947581121998454, 69.19522254697739, 40.740439122723, 0.7150156002852225, 0.5272107391107468, 0.13868947813828147, 0.041814817926816406, 29.33958580417018, 68.54552115163496, 55.502746028284875, 50.91947609378446, 39.62670564651489, 37.61955038193734, 50.97149848937989, 57.86644474152596, 59.625663065141254, 11.025744311271175, 0.10159766121256737, 0.06700700644644038, 0.029292296836032506, 0.028269552220139774, 0.0505209781770264, 0.004677575817632099, 0.052320338680499026, 0.022703017551271666, 0.0037687106504886146, 0.023695434661461942, 0.12145480576662288, 0.24236622536855362, 0.12602021482082146, 0.1872826956452862, 0.11604496097612767, 0.17288817933970885, 0.22468298553459107, 0.16593891916976822, 0.13963924330328742, 0.1682748285032088, 0.20859838733750008, 0.5963711344426679, 42.37713044689548, 69.72906497216994, 60.346045570988814, 48.66616072193269, 39.69120510162846, 44.39150679496027, 47.21378941689768, 56.55589457481139, 67.2314408517653, 49.17239358348232, 0.6348768585631925, 0.1672319530118858, 0.6998318602000514, 2.0464063003178565, 34.83648361698274, 58.19018540843841, 61.6452169418335, 59.23257489358226, 60.00091229715655, 51.62156466514834, 48.40543685420867, 42.96071637061335, 44.31167087247295, 43.28204085749965, 41.64637327194214, 39.79733659375099, 41.33670606920796, 44.92545904651765, 41.742667459672504, 43.68267959164035, 42.55235448960335, 43.009961728126775, 38.76731826413063, 42.51038512875957, 48.57761321529266, 49.456863480229536, 50.882170431075565, 50.534095379614065, 51.664130226258315, 47.926837090523016, 43.96602769051829, 46.04609197185886, 43.45517819927585, 43.806348000803304, 43.6864411446356, 44.48204294327767, 42.49451129667221, 38.533533234750074, 39.02142509337395, 38.93886704598704, 40.21058182562552, 38.00133036028954, 40.77639156772245, 42.44355578576365, 40.562018348324685, 38.82882495080271, 41.83909500798872, 39.99871500076787, 41.059708287639005, 42.7036089281882, 40.72848373843778, 41.701733604554214, 41.972973346710205, 51.410364643219985, 54.918999287389944, 44.685005987844164, 44.6139326403218, 55.85539456336729, 53.394813306870006, 55.643084510680175, 50.03523265161822, 46.534921276953916, 42.115900593419234, 45.847008151392785, 54.513053586406095, 56.1730202551811, 56.274064433190134, 58.19324877954299, 59.0264896423586, 54.15585117955362, 50.76297744627922, 48.7430234878294, 51.552460347452474, 54.00644417731993, 55.650611539040845, 57.0785778568637, 58.85877301616054, 57.913572019146336, 58.99701695288382, 54.616098173203014, 47.26943608253233, 54.39397042797458, 52.998904951157115, 42.272716952908425, 40.62829071475614, 40.61193050876741, 41.25081400717459, 43.93142454085812, 38.86514217622819, 42.03804154549876, 42.01837478145477, 42.57123677961288, 41.596618006306315, 41.902868824620406, 42.41522058363884, 42.71873358757266, 43.55113898554156, 41.76609969908192, 41.47327123149749, 39.92971266469648, 42.446505408133234, 50.34856727046352, 49.50354753002044, 48.8795062803453, 45.37280144230012, 45.60721405090825, 42.50648629280829, 44.96274117500552, 45.446369417252086, 45.5650407268155, 43.43517411139704, 44.99547335409349, 46.23291838553644, 43.80535564114971, 44.14524862843175, 44.01177429383801, 50.67500652805452, 57.45463117476433, 59.631954546897646, 61.265762928993475, 65.11444745525237, 61.629794182315955, 61.5815451068263, 59.37784379528415, 56.312801761011926, 59.108573082954656, 68.10124997169741, 66.65983384655368, 70.13220617848059, 44.94278807793894, 0.982765781302606, 1.2290541010518228, 0.4265123119036998, 0.14361807415562292, 32.610105122289355, 77.07821384552987, 61.54498077207997, 60.77046563548427, 39.94919899971255, 37.91185325191867, 63.22672836242184, 67.69778713103264, 71.2543962847802, 16.6633600957932, 0.24394476485829203, 0.1706590166976375, 0.18774751183246413, 0.17169741823548273, 0.20289037346599564, 0.11793552807742551, 0.13007743945044856, 0.11032529490729494, 0.09771320473162398, 0.10313477832823993], [0.07860530948927326, 0.08755717711943774, 0.03430165958801105, 0.05941055902850725, 0.02101220979144977, 0.0278379287075011, 0.04834796211892559, 0.03806272228699058, 0.029132782008438825, 0.03346248687575421, 0.04351182908360516, 0.25202555221415335, 22.033732052772276, 54.877014237065474, 52.92929857007919, 29.419913984114125, 23.53649208622594, 31.742012039307628, 33.52627861884333, 46.84117209526801, 54.374437024516446, 46.38036812505415, 1.4814982130642862, 0.05169841318180965, 0.08923238924434108, 0.9532028160268261, 19.511834344556256, 58.74280814201602, 54.09799621951196, 56.5235036419284, 51.611715593645656, 47.53639259646016, 42.09743799701814, 43.27605924298687, 45.5302296915362, 46.10456666638775, 46.22613268513834, 47.306329896373136, 43.241444326216175, 40.60121459345664, 42.27550183573077, 41.81871045020319, 38.250349875419374, 38.56562606749996, 44.60668802261353, 54.11716876491424, 49.9201032423204, 49.98453993951121, 49.74254146698983, 50.67340227865404, 50.24770352148241, 49.370896893162886, 46.48626427496634, 47.025480347294966, 43.845587392007154, 43.9243564298076, 42.24535842095652, 42.92523853240475, 39.13934330786429, 37.36989544283959, 37.22884701144311, 37.222147603188795, 36.348851496173495, 35.75326311972834, 36.28981198033979, 38.96278173692765, 37.15451809667772, 36.02701710116479, 38.26878501522926, 37.68988240149714, 35.159682996811405, 36.48197281745173, 37.083801684841035, 37.283085546185895, 35.92556499665783, 44.18992050232426, 51.6801844873736, 54.053120382370494, 50.58161881662185, 51.68482072891728, 51.60451019963911, 50.674488775191776, 46.497184153526064, 42.73946331393334, 40.9969856662135, 39.80526370386924, 49.90506095270957, 53.92228580290272, 52.00373295814761, 50.294646447704686, 51.9597828003668, 50.13824585945376, 46.92812711961808, 50.41624776778683, 54.13755724506994, 56.20862360923521, 56.55663198040378, 56.05097962963966, 53.64196577379781, 52.25357617101362, 41.96326548053373, 41.06421901333717, 51.525517586738836, 49.81393644886632, 41.467505347344186, 38.31504152667138, 37.8889819114439, 38.42953158963112, 38.00048312833233, 38.31931691015921, 37.38352175681822, 38.412888972989975, 38.994811811754786, 39.58763099485828, 37.44404000620688, 37.968147108631754, 37.188772155392556, 35.83993965579618, 37.72632122039795, 35.53696401657597, 36.68849345176451, 38.391904292568086, 43.20187937828803, 46.39703427591632, 47.2335660073065, 48.3663857367731, 46.35912456820088, 44.94880107141311, 39.87863163794241, 39.76059182997673, 38.57552220744472, 38.17488739567418, 38.974403719748224, 41.049616029185636, 42.96011232560681, 41.475083366517104, 41.665098667144775, 42.3357847429091, 44.00145061554448, 52.75176032896965, 58.16297200418288, 60.436362066576564, 59.06152033036756, 59.939703710617565, 61.44507015905073, 57.949312656156486, 57.75073482144264, 59.10139906790949, 62.07295533149474, 62.53573617627544, 67.91393326174828, 29.90222627116788, 0.5377326809590863, 0.24544638912043265, 0.09054957017783197, 0.03680754467965134, 24.97417215378054, 67.54170817713585, 51.99481741074593, 45.46258449554444, 22.711433287589784, 21.780525407483502, 39.88307568334764, 51.21401863713419, 52.614551897971864, 11.006005963971539, 0.039390774008126996, 0.08110828727724091, 0.009372037170725244, 0.07163528833658465, 0.053276669219016075, 0.07561587353026675, 0.07489309255634585, 0.030724695478115353, 0.035366065980445956, 0.0629328206301697, 0.02978139992562994, 0.07026016817338045, 0.03134102853495748, 0.07209006111107527, 0.03780901311866699, 0.02718028244412234, 0.023980239338632074, 0.06488971562395174, 0.04250589435199096, 0.031485556767532424, 0.006088664766491181, 0.1238983581143041, 26.905274621901977, 62.06179226598432, 60.325857131711906, 35.65973028059929, 27.137941775783418, 33.42402635082122, 39.88609590838033, 53.304806678525864, 58.97093319123792, 50.26560521894886, 1.226941536991827, 0.11612686343611249, 0.17460266879249006, 1.4301199441955936, 21.80420671739886, 60.61097814190773, 56.58189596668367, 58.64130896906699, 52.878390127612704, 48.537110820893325, 44.18691596677227, 46.297680639451556, 46.68439888185071, 46.224944206976126, 46.81286827210457, 48.76576931245866, 45.40031686905892, 42.68285958997665, 42.28350739325247, 43.645730864617136, 38.78390596758935, 39.50253125159971, 46.85338243361443, 54.56283238626296, 52.304319873932876, 51.04510568803357, 52.82180993787704, 52.924011215086914, 51.35274502538866, 51.49853952469365, 48.06114688996346, 49.35764320435063, 45.38057165761148, 45.70763849443006, 44.86439951004521, 44.058521101551676, 40.02829751660747, 38.832794389417096, 38.05278793458016, 39.28447492661015, 38.403259554216945, 37.636079249843476, 38.36368676154844, 38.89892947289252, 37.70988256700578, 37.74942005834272, 39.03049753558251, 40.579645479879076, 37.67459692493562, 38.939926085933564, 37.25237731010684, 39.41384646200365, 38.64617586135864, 48.17496230525356, 54.58644113233013, 53.72022882584603, 51.475079828693026, 52.58844460210493, 53.62331490362845, 51.897962324080936, 49.69948168723814, 46.151101666112105, 44.17163049021075, 41.97631128372685, 51.910815931135616, 54.207351899916134, 53.544055569556456, 51.67514424170218, 55.42944477450464, 53.01528869136688, 49.34600553204937, 51.40593628729544, 55.72890204768027, 57.78662058614916, 57.96304095175959, 57.038389252078154, 56.17387533187867, 54.335750687506895, 48.52847376177388, 46.02518966121059, 50.90320217993952, 51.50694516397292, 43.584506588597456, 39.3008468997094, 39.063096354084635, 38.65093369637766, 38.71687266134447, 40.035836312078665, 39.181155773901175, 40.60930644312213, 39.60903929125878, 40.40909298004643, 39.323016135923325, 39.38744106600362, 38.92802953720093, 38.48470364847491, 39.46723776478922, 37.67562850829094, 37.762803185370664, 40.06756436440253, 44.5946777251459, 49.330676909415956, 49.19166811050908, 51.1225607318263, 49.95804432899722, 47.16549719533613, 42.73296394655782, 42.09164465627363, 39.9724978785361, 40.56448944153325, 42.318283127200225, 41.17845019986553, 44.95629279844223, 43.05453946513515, 43.96249363499303, 43.259236197317804, 45.6303285783337, 55.32662768517771, 60.246115346108716, 62.334130271788574, 61.27778499357162, 63.26854867319908, 63.029197800544004, 58.96846602039953, 61.04565912677396, 60.4708004766895, 64.70158269328456, 65.0305401125262, 71.49455516569077, 32.877020451330374, 0.328315774639768, 0.48697693513766416, 0.08034768454249828, 0.09512713704738887, 27.43219602492548, 73.02672709188154, 56.725431180769405, 51.97824147439773, 29.150962944953676, 26.762417977856053, 47.73340148310508, 58.38003204714868, 63.79402468281408, 14.092471984124954, 0.01339122745013165, 0.025846735957349022, 0.03608971646416091, 0.07235295184317135, 0.07384890705467233, 0.07577515853148314, 0.039563331482631546, 0.0074693270970226065, 0.05592791949428859, 0.046968797011481184, 0.15585396919519673, 0.23194606596183395, 0.2410074458607743, 0.25760785105728334, 0.15899289189086807, 0.06996844955269368, 0.13946383981214416, 0.13515690882359782, 0.16455309675826182, 0.07650479599232636, 0.12409141993210202, 0.35732200849921475, 30.8638031636515, 71.56331431481146, 67.37929067304059, 40.62489001981674, 33.71103402106993, 41.652598073405606, 45.54642908034786, 58.46339810279108, 63.86512548692765, 56.04110310154577, 1.5740128294114144, 0.34623705331356297, 0.31831694826964413, 1.3978968152115423, 23.095394103757798, 62.494312024885616, 58.355670206008426, 60.87289441016413, 56.2208535594325, 50.31246185302735, 45.27205536442418, 48.926174640655525, 49.247369689326135, 49.312759522468816, 51.24829623007005, 51.806704459651826, 47.07059937138712, 45.51149252922305, 45.22157446030648, 45.51084533814461, 41.86983854539933, 42.79825572044619, 49.78391070519724, 56.8496173427951, 53.431864015517704, 52.930000674340036, 53.78342213169221, 53.5587134668904, 54.92360414997224, 53.45168375199842, 51.131197790945734, 52.763080289286954, 47.45284611178983, 47.48336999647079, 46.689992181716434, 46.618483451104936, 43.14140035260109, 40.48265311025804, 39.233676310508486, 41.31260702686925, 40.23877190005395, 39.927547516361365, 40.0714082871714, 43.286759468816946, 39.59689955557547, 39.28537314937961, 43.900100492662006, 42.22221643693986, 39.22249363314721, 40.17758292536582, 39.79335931039626, 40.83604297330303, 40.33334808964884, 49.44335483735608, 55.45657973135672, 56.25515076421923, 53.007608690569484, 55.20931743806409, 56.13494188554826, 52.85216908301077, 52.093559157463815, 47.8914612339389, 47.26745920796549, 43.161361294408, 55.051320445153024, 57.83297515684559, 55.304407458151545, 52.70110291819419, 56.2680475173458, 55.267517566680915, 52.20427590031778, 56.4686296832177, 57.28827168864589, 62.55593638266287, 59.70092158163748, 58.45756553834485, 56.16736811976279, 53.15204212742468, 48.85202223254789, 49.62366227180728, 54.24046062654065, 54.70712069542178, 45.25885266642417, 40.72698931540213, 40.05040791726882, 42.208998049459154, 42.358236389775435, 43.58564015357725, 41.414259172254994, 42.83858945292812, 41.08197950547741, 43.581604034669944, 41.566811915366884, 42.65277108838482, 41.82962640639275, 39.56979990005493, 41.99277347134006, 38.98498235210296, 40.82985347317111, 42.303150623075425, 49.233617859502, 52.228837782336825, 50.93812304158365, 52.965015672868304, 51.6294760857859, 49.981586394771455, 44.25804422747704, 44.42983227391397, 43.306622351369555, 41.88540251024308, 43.666338997502486, 43.73836155860655, 47.60566949844361, 44.613426654569565, 46.727933268393244, 47.56148792082264, 49.08988652690765, 58.81958461576893, 63.55144177713702, 65.92420116547616, 62.1428951140373, 66.31471233983194, 65.12324533154889, 61.53319404971216, 64.79705318327873, 65.94434645868117, 67.84671168173513, 66.6858313160558, 74.87951355595743, 34.692136472271336, 1.1750852292583835, 1.341567534592844, 0.3968120330283719, 0.24988910153267846, 30.21021862183848, 79.35522033322242, 63.30244187385806, 61.07173112130935, 31.72361808438455, 32.288129521954446, 55.96507972286594, 68.8807818197435, 71.93895186147383, 19.378130551307432, 0.221207321230923, 0.1900642536460392, 0.17589300600511415, 0.11504130918652782, 0.18419776682651814, 0.10288583805724498, 0.17217951736623244, 0.19767725239357642, 0.1556525493581449, 0.202342206912656], [0.04759710785301943, 0.01351487404111052, 0.04393203597095224, 0.04523974422725939, 0.06420262285598344, 0.044561813870865497, 0.044315773242663954, 0.047715705924577294, 0.08966768040291725, 0.009518148332473733, 0.049454851917201476, 0.04672861312546077, 10.884723336465898, 52.89489938366798, 48.911697172349506, 48.91705905237506, 35.65365452920237, 27.805140864464548, 28.06246795961934, 46.894516329611506, 53.8531461838753, 50.53362077282321, 3.6845230383257714, 0.16072310146785554, 0.1875995496107686, 0.33982376357720745, 14.503909003350044, 49.506018623229004, 58.01814240794028, 55.738233366320216, 53.23371371915264, 48.59986089891004, 49.85153628933815, 51.63595976368074, 52.30582998644922, 53.890420467622825, 55.256805573740316, 51.849328856314386, 51.62636172386908, 44.08167485267886, 37.94141223353725, 36.38603556540705, 42.31689068578905, 47.94149498785696, 51.91133368399836, 44.54661692342451, 45.80016720679499, 47.011183308016875, 44.84701948781168, 45.982945734454745, 47.2328011451229, 50.51369513234785, 48.26215267181397, 48.951936767947295, 47.75899887084962, 49.236332139661236, 49.36113411380399, 45.336048833785526, 40.15065585413287, 37.80827130040815, 34.796255788495465, 37.097259336902255, 37.2781551268793, 36.2453362249559, 38.2160016798204, 36.49200231798234, 37.606433976081114, 36.734549922327844, 39.09560495807279, 38.690635927261845, 37.54377803494854, 38.82353759581043, 35.93497084033105, 37.039820148098855, 38.03233277413153, 38.154522449739524, 48.72961290421025, 49.72602828856438, 50.41957786006313, 49.893478193590724, 51.617104930262414, 50.480649163646085, 47.20698018227854, 45.203747287873306, 40.17656703149119, 41.581461967960486, 48.906405894987046, 53.78470866910873, 51.50382687968593, 50.84775555518366, 54.24486937061433, 49.495086977558756, 49.22679685777234, 52.450408551000784, 54.137733751727694, 49.408124108468336, 45.51052762616066, 43.729920617995724, 41.745413118793124, 41.45175310873216, 51.02122237605434, 55.419168164653165, 48.74786761499221, 42.94486215037685, 37.718194069400916, 37.389016997429636, 36.55273237536031, 36.71325537466234, 36.514014659389375, 38.77997967504686, 37.21356937962194, 39.86492687656034, 36.83084018768803, 37.489072738155244, 35.96195674711658, 39.20272488747874, 36.97638365530199, 38.24524687182519, 38.15651109141689, 36.70135490355953, 37.577459427618216, 42.816847755062966, 49.35368945521694, 51.66598942971999, 51.67812132066297, 53.957508687050115, 53.86680779918548, 50.614519657627234, 51.336286760145626, 45.36959294349917, 41.974863929133264, 40.23885426982757, 38.737057178251206, 37.17343176564863, 39.20647859573364, 40.73110780408306, 40.798435288090865, 40.808974696743874, 40.92519844731977, 44.70288022871941, 54.421219133561664, 55.65621660601709, 59.83450966496622, 55.96040425762054, 59.76649184380809, 60.36109570533999, 61.401202371043546, 60.82316660111951, 64.17494958446872, 62.12795872842113, 56.748541785824685, 18.975805197992635, 0.11571018055321709, 0.6140293385232649, 0.0746464045838483, 0.02204543832058628, 22.26821134167333, 65.79765373660673, 50.351144267666726, 42.99613537326936, 37.793307458200765, 35.36018279290969, 39.736394728383715, 46.33584530122819, 46.12051502350838, 7.345908995597594, 0.026387431238207127, 0.07522102415321336, 0.015612535775759289, 0.09499925399018873, 0.07532384081353104, 0.04578827467236308, 0.03768938465885097, 0.045880247358112566, 0.042260175480717616, 0.02400530765073434, 0.05080762529565443, 0.04730300669888816, 0.04690449159111708, 0.05925610804209306, 0.015865211682995, 0.04770076721005383, 0.07369848569073985, 0.02359220239844534, 0.08994730249527963, 0.026316190806908474, 0.019359660462566444, 0.0638038664305162, 13.862548528179047, 62.06907218502414, 56.371492185900294, 50.47935478148922, 36.17892657556842, 30.742545050959436, 35.679349976201216, 52.85495788820329, 58.14274434120425, 55.75649592184252, 3.4513638721358393, 0.21335349508350898, 0.24917814129542923, 0.7349371958163478, 14.812073938308226, 54.430240584957986, 59.37650626705539, 57.409284653202185, 53.238765731934585, 50.02933340687906, 50.30123210722401, 52.65130450648647, 54.302465454224624, 56.04886154974661, 56.597373639383626, 54.62588056441277, 53.97677144696636, 45.910299516493275, 39.46806930726574, 38.775602309934555, 42.203416516703946, 49.06526580933602, 52.35895456806306, 46.293369954632176, 45.69283939176991, 46.81114635159893, 44.46739681305424, 46.22468140817458, 47.702450060075336, 52.5403759556432, 52.1341399992666, 50.1572536653088, 51.20055314033262, 50.989764967272365, 50.139238219107355, 48.964543265681115, 41.78188331665532, 38.18963158515192, 37.44091779954972, 38.96150304425148, 40.30471478739093, 37.61995830843526, 40.37146176061323, 39.685643180724114, 39.43562346120035, 36.82927908435945, 39.98652819664248, 39.50371188502158, 40.258724997120524, 39.289032720750384, 37.70003349550309, 39.19073420186197, 39.40021622565485, 40.94411603866085, 51.396620658136186, 52.67829433564217, 52.69161862711753, 54.0155440761197, 52.03635531087076, 50.84353508487825, 49.34017688997331, 47.620802002568404, 42.70102408624465, 43.02236818498181, 50.63533175376154, 56.20197126942297, 53.936135691981164, 53.6945176893665, 55.81746132143083, 51.652045403757405, 51.767676876437285, 55.56655906861829, 55.6846930134681, 51.05114221572877, 47.96594312114101, 46.55970281170261, 44.38955345461446, 44.65976553578531, 49.36842579995432, 56.44459339880175, 53.76956047550325, 45.184837541272564, 40.303259588056996, 38.30184667341171, 37.08577071466754, 39.347381899433756, 39.578974323887984, 40.41153661666378, 39.48559837956583, 40.515036198400686, 37.759061244226274, 37.94280859731859, 38.85074315532562, 40.858639747865745, 39.77088805167906, 40.7945050731782, 39.69348792106875, 38.812758922576904, 40.00197449038106, 44.35448354290378, 49.4040487658593, 52.79478088501961, 53.03894058350594, 55.68065689456079, 54.83710019819198, 53.844940585474816, 52.38939608297041, 46.175208553191155, 44.10942169927782, 42.335545478328584, 40.35637240256033, 39.22404296936528, 41.441084261863466, 43.46447813895441, 43.992060461351954, 42.12565945040795, 42.87520870085686, 47.371437318863414, 57.35321044921876, 58.9837867982926, 62.57121401448404, 59.691715778843054, 61.11296699893091, 61.64497767725299, 65.48839446037047, 63.62018523677703, 67.98292775307932, 64.47718781809654, 60.047388461328325, 20.7241310996394, 0.2199155131294843, 0.7122633834519695, 0.024284404972868583, 0.04040856011992982, 25.17092412517917, 72.0720535709012, 56.62483807533019, 54.17489036437004, 32.82822812757185, 31.7594430523534, 47.51684742589151, 52.83704834599649, 58.02700304215955, 10.430841369013633, 0.023916659786576228, 0.04337446185790243, 0.01377052045427263, 0.037634628524463025, 0.06222189486687703, 0.04022893165388415, 0.06250331726586146, 0.022845096217708725, 0.007001616533905749, 0.02874824417484624, 0.11179561681684949, 0.20041993909305145, 0.2344176188231476, 0.18393723564522882, 0.10577952834747492, 0.1077874371361348, 0.13705414088983692, 0.11358014202766842, 0.1835337371355103, 0.09335263992749876, 0.15749368846656817, 0.37012146845940624, 15.999508750054146, 70.97355458044237, 60.71977684574743, 60.510188917959894, 48.1884866376077, 37.1016876928268, 38.76430980620846, 59.72748779481458, 62.68693962404805, 62.3009156411694, 4.338477263527532, 0.3100185306562532, 0.6188048854950936, 1.2707240134477615, 17.318943085209018, 53.870859607573486, 61.74551194713962, 59.89867571861514, 55.21565598826255, 52.796808750398704, 54.210117170887614, 55.700904169390284, 56.65154157146331, 59.353066182905636, 60.30268769110403, 56.332947054216945, 57.202885612364746, 48.75669687025009, 41.352124906355336, 40.62752977494271, 46.894496717760646, 52.71894578010806, 53.75869943249611, 46.3573085108111, 46.32470184756864, 47.035325496427475, 45.75589541466006, 47.23904163606706, 49.81778821637554, 54.197938211502574, 53.892150232868815, 54.09372083602413, 53.64023208618165, 52.80277075306062, 54.514336201452444, 50.62077976042225, 44.32189256914201, 41.10960083623087, 39.01740074157715, 41.35791040235951, 41.440299787829005, 38.16060604587678, 44.32444210975401, 41.7439853760504, 41.23330454672537, 40.570376919161895, 43.062341059407885, 42.51916731557539, 41.476099260391734, 41.35856936054845, 39.653315005763886, 40.91966006063646, 42.22542493574081, 43.409113883972175, 52.45134207510179, 55.00435398470972, 54.39363310413977, 54.88433337980702, 55.39145661938576, 53.22674366735643, 50.56334449398903, 49.489223034151145, 45.00295723638227, 44.574328468691924, 53.65887118924049, 58.77109627569876, 55.17161169359761, 57.06512020480249, 58.033212154142326, 52.717667087431884, 54.427349798140995, 56.20558769472184, 56.881392463561035, 51.67945492652155, 47.53398426117436, 47.59791497261294, 46.004001017539736, 48.842133937343476, 55.07969487097956, 56.84964872175648, 54.06444818742814, 46.33772411654073, 41.49582485998831, 40.28368696089714, 39.704984388043805, 42.32450008392334, 42.36579871946766, 42.466113336624645, 41.91187066416587, 44.385740910806966, 39.20705518414898, 38.90265572455622, 40.79046110953055, 43.618615519615915, 40.86424873721215, 43.0983837189213, 42.16867216171757, 40.457436192420225, 42.22151041030884, 47.81433959161082, 52.568930810497655, 55.84243505231796, 55.63817370322443, 58.15146377009731, 58.66093258703909, 55.531748033338985, 57.05394144981139, 50.58525877614176, 47.684050221597, 44.417939647551506, 42.25326984159408, 40.319392296575735, 42.9901223797952, 46.05041050141858, 46.36145053371307, 43.63370095529864, 44.41761016845704, 50.083952411528564, 58.89036378552837, 61.069401233426994, 65.56669673612042, 60.63000163724346, 64.93617573092061, 64.2111962072311, 66.75674776877126, 65.11272553474673, 70.38153556085402, 68.0872235759612, 61.914691617411954, 22.174656929508334, 0.3609953081655887, 2.5700249450822032, 0.32411531455093817, 0.11452542557831734, 28.461476948953447, 79.41024334199967, 63.06389900945849, 57.68489783810031, 52.94699238192651, 47.1177541055987, 54.21211757967549, 60.81589844919021, 71.19182663579141, 15.3903813323667, 0.21911020150348065, 0.13754331867300695, 0.18093420162556634, 0.19256415176055125, 0.13968861000912805, 0.11492057372966122, 0.21761812269687655, 0.1653041540374679, 0.08673183995509341, 0.11158678890956987], [0.06684944514305362, 0.06053501522288688, 0.01117782227905287, 0.030728384191470764, 0.1004207969432877, 0.008829359637363064, 0.03407314322107742, 0.09812598056610554, 0.023305124355359905, 0.047485477351132906, 0.047253739584477684, 0.09938375138106847, 4.391720496839093, 45.0537323182629, 53.03421804981848, 47.96633928052841, 26.603444314772084, 26.326252375879598, 32.41378853397985, 44.03656367332705, 50.98894911427652, 54.61500775429511, 8.378822034405124, 0.14451358497383135, 0.2886928185339897, 0.13582650031293594, 6.62984747079111, 47.30483939570766, 58.350269102281146, 53.39512709648379, 53.30646976347893, 53.28837979224421, 54.925486887654955, 57.58471265915902, 55.45591292842742, 54.02633059409357, 55.40267067570841, 52.88963164052656, 50.459574268710234, 41.50100238861577, 36.954277177010816, 41.69801912000103, 49.0545145926937, 53.85919840105119, 46.69633465428507, 42.22633884799096, 50.85736536210584, 51.937523349638916, 51.368701227249645, 50.35585895661385, 48.87187727036015, 46.346443545433786, 47.77797922011345, 48.853759842534224, 48.21219344292918, 48.2655062983113, 48.703183973989184, 45.69296490761542, 39.73930512705157, 35.973943510363185, 38.1731144843563, 37.43069610288067, 36.04187503937752, 36.70180989849952, 36.346427471407004, 36.708556375195904, 37.53587838142149, 37.1295561329011, 37.48995527144402, 37.59449428127658, 37.00693107420398, 38.87764669233753, 36.2785469332049, 37.850460313981586, 38.19953556983702, 38.1724908274989, 40.36022809243972, 44.04735019130092, 47.46361694028301, 49.7573797933517, 49.008187478588475, 50.23701506276285, 47.97337209024737, 44.112987133764456, 40.399510629715465, 40.205741620832875, 48.50693994952787, 52.335840040637606, 53.48794606424148, 51.58692621415662, 52.15430490432247, 51.63848969244188, 50.62365485775856, 53.43427627317367, 45.736005075516246, 44.90069320124965, 46.21399687182519, 50.15267233694754, 51.46646630379462, 53.01801473863664, 54.36770231493058, 50.460998089082786, 45.38947151553246, 38.05771835388676, 38.442393041426136, 37.643818086193455, 37.144076747279016, 37.787333688428326, 37.608320636133996, 37.76368179628926, 38.23335424546273, 39.121414153806626, 39.444033022849794, 37.568528190735854, 36.87855974320443, 38.61640899412094, 37.21822915538665, 38.320054315751605, 37.688442891643895, 37.10193480214765, 39.56712484359741, 45.95175896921466, 50.043163684106645, 51.02750993544056, 49.51693850178873, 44.97618705995622, 52.18406784919001, 52.079313108997965, 52.7081004265816, 53.46812240539059, 52.884916951579434, 47.25671975843368, 45.7956878600582, 42.56587097721715, 40.74209436293572, 39.064759439037694, 41.28286761622275, 40.85575680578909, 40.58833745218093, 39.175986090014064, 42.38281003890499, 53.07530879974366, 57.43994189846901, 58.440644433421475, 59.340216498221125, 56.140405747198294, 58.73223343203145, 60.46298319293607, 62.994076898021085, 60.30725725235478, 60.415232258458296, 14.733661836193455, 0.19846742612219628, 0.37562259262607944, 0.10510432143365184, 0.013157933567380233, 21.523053184632335, 65.59338846514302, 52.293588269141416, 46.99270109976492, 31.123083599152107, 35.21794588335099, 47.51489016317552, 46.683449668269006, 46.314856698436124, 6.209024710039939, 0.036928448675861286, 0.03714675692120387, 0.05588309952027856, 0.034439616701415474, 0.06686705750443282, 0.02950844471342862, 0.06923232332713182, 0.04788628306179758, 0.01399511157820422, 0.06228693190120882, 0.029463712839529883, 0.03772552868711852, 0.00943815247381046, 0.01671248385983129, 0.060358604326123194, 0.01990044575875565, 0.01446252001539594, 0.008707408973526572, 0.06287508441375629, 0.05787592786814898, 0.018147445066020857, 0.039994999045325864, 6.815606019189281, 55.402301972912205, 60.67965099888464, 55.01550920547978, 34.39769591054609, 31.30959426203082, 37.64011536875079, 51.84964264592817, 54.805627099929325, 61.41388731618082, 8.209467818660121, 0.11786040549557056, 0.23618530542139085, 0.6144096245688777, 6.678656954919139, 49.36180091673329, 60.340499339565156, 55.966829099962794, 54.85910861722885, 55.08223656685122, 55.77961829400832, 59.67405726832729, 57.98467282325991, 55.7979828311551, 56.53209363260577, 55.953316534719164, 54.1787499766196, 44.25027793453586, 39.42061255055089, 42.66267899544009, 50.4671444431428, 54.469585880156494, 45.869204844197924, 43.33485164949971, 49.69651637538787, 51.09799100506691, 50.80795526504517, 50.18589088993688, 50.182525496329035, 48.288554145443825, 49.03381232292422, 51.192096510241115, 52.199082682209635, 50.192347111240515, 51.58315289405085, 48.24871463160361, 43.38583853936965, 39.486406387821326, 38.466158682300204, 37.935089372819476, 38.41331258896859, 38.05132489050589, 39.068928918530865, 38.298481279803866, 38.859537109251946, 37.868734636614406, 39.11267119069254, 39.59548357994326, 38.517094581357895, 39.72460016127556, 38.65484037706929, 39.183191484020604, 40.828241379030295, 40.0330122055546, 42.65612079251198, 47.91967876495854, 49.263522009695734, 51.9735973881137, 52.51080128454393, 51.27490166694888, 49.55472269365865, 46.19760528687508, 42.897660347723196, 44.22069149632608, 50.3156428952371, 53.80169253195486, 53.219867752444365, 51.40959585866621, 53.9534725681428, 52.885913233603205, 52.124938118842344, 56.94749616807508, 48.26022678805936, 46.12813226638302, 46.19797791204145, 50.745891601808616, 51.235066075478834, 54.00293757838588, 57.051795913327126, 53.881955992790964, 46.55046562994681, 40.095758361201135, 39.5393426956669, 39.250919049785985, 37.00087101228776, 41.39875404296383, 39.56709346463604, 39.036039844636, 39.663709286720525, 40.33923164490731, 40.816776291016616, 40.78997865799935, 38.413532241698235, 40.707801080519154, 39.14511311438776, 39.72935799629458, 40.048940950824374, 39.07186285141976, 41.537111728422104, 48.82100412922521, 52.88071609312489, 54.02946849023142, 50.91875045530258, 48.26942082374327, 53.26126052487282, 53.39753150939942, 54.00093324722783, 55.90575387400966, 54.78856478967975, 49.648447728926136, 48.65679802433137, 43.039073559545706, 41.671711783255304, 40.843134618574574, 43.403022443094564, 43.62896273213048, 43.68453487273186, 42.01011426987187, 46.0149718869117, 55.111877918243415, 58.97118422292895, 60.65082550048829, 61.57579883452385, 59.32704517918249, 61.851125686399406, 62.881595088589584, 65.00432299029443, 62.256310447569824, 62.087691676232126, 15.945698734252685, 0.24907629756677538, 0.3110279281052851, 0.10171758461623423, 0.05598923334130838, 24.369562325939057, 72.16290350883239, 58.632773891572036, 53.31019209277246, 37.014128623470185, 39.03010137619511, 54.04158861406388, 54.119188785552986, 54.14657085172592, 8.06971327912423, 0.0233021346972354, 0.023406292011420575, 0.089996155922211, 0.08083404312210699, 0.028932055480958476, 0.020088796135819247, 0.051001859227976495, 0.03834749249020412, 0.0374451634894696, 0.05237664231249402, 0.10457393578103474, 0.1720772293065825, 0.14399270647235457, 0.07970456905182331, 0.09285046163225368, 0.12083236698902423, 0.14222554081389982, 0.23014902287433225, 0.1505638562863873, 0.09931978303939105, 0.26597245866733216, 0.24480368731723678, 8.491736285148129, 63.11063012769146, 68.89359228072628, 61.624926520932114, 38.22888666583646, 36.579761428217736, 43.28823428000174, 55.7195471948193, 58.927049713750044, 64.49579161982383, 9.928639723408608, 0.2786369645787824, 1.5568209583720856, 0.6973949038693983, 7.827335317288676, 50.95187487140779, 60.79218379912838, 57.6912756120005, 58.78838608341833, 57.97325088131813, 58.363463955540816, 63.242508057625066, 59.25072370036956, 56.55450213340021, 59.46015081098003, 58.66765552951444, 55.80293678468274, 45.59106957527899, 40.738317120459776, 46.20095499100224, 53.89002430823542, 55.3885462207179, 46.217993767030784, 43.287673381067094, 50.626871201299856, 53.62000050083284, 52.31761670881703, 52.396424970319195, 51.7667394299661, 48.9800601620828, 50.91197259964482, 51.04654127551664, 54.46618518521709, 50.96126110323014, 53.35324795015397, 50.62827540982155, 45.302826358426, 41.92109607881115, 42.14190983003186, 39.354108764279275, 41.457860239090465, 40.260097826680834, 41.399389466931744, 39.35766243165539, 42.644879279598115, 40.55780572275962, 40.54357536377446, 42.07690046679589, 40.82511917237313, 44.038591538706136, 39.88985746137558, 41.991600682658536, 42.48123015126875, 42.54417634779408, 44.74728930381037, 49.25479473606233, 50.78880233149375, 54.2706314979061, 54.43302939015051, 54.8230149669032, 52.937916017347774, 48.2777754722103, 43.300774097442634, 45.85520590505293, 52.73801634388586, 57.545351674479825, 57.44735125572451, 55.49334410698184, 55.130846500396736, 54.346945131978686, 53.16181667389409, 56.968504382717995, 48.52259020651541, 50.00974509023851, 48.93151298646004, 52.90291278593002, 53.31895074536724, 54.70416322831185, 56.84702857848137, 56.65619350248768, 48.96400982333768, 41.61236632254816, 42.03899468145063, 41.20736199040567, 39.83122979440997, 42.789328405934, 40.70752259223692, 41.59955586156538, 43.14387929054999, 43.32199412007486, 43.41173010487711, 41.702914237976074, 40.24751486316804, 44.41862213996149, 41.072867839567124, 42.36195087432861, 41.58376047688146, 42.34052296607725, 45.27089434285318, 51.91491088559551, 55.58300164438064, 56.611443181191724, 53.24342943006947, 48.43127350653372, 54.90446298353134, 54.440328921041186, 55.3881775179217, 60.3568713126644, 57.98011895148986, 53.76000165939332, 51.61898374557496, 46.87855228301018, 44.15172446158625, 43.67194406447872, 45.26974508839269, 46.443765394149295, 45.90518866815875, 44.86495648660968, 46.32279165329472, 59.054542433831, 61.01599816353091, 64.47438724579351, 63.52165529804846, 61.11133137056905, 62.769352543738584, 66.34167471239644, 67.48892876409715, 64.06207946039015, 62.416515734887895, 16.690408760501494, 0.6798695700783884, 1.584833055253952, 0.41636085017554225, 0.14689365161522744, 26.590161208183538, 77.15801838905581, 64.72641914121567, 64.05658029740857, 47.673734388043805, 48.280693715618504, 62.62568789143717, 62.11808220032723, 65.37489283469417, 12.55456849451988, 0.12071895533271375, 0.12443397614744403, 0.20225904040759612, 0.17245022219515618, 0.13852029528108337, 0.12395946894802394, 0.1861567762229712, 0.17864686226652515, 0.15239148160382626, 0.14675301319408804], [0.03187166125093016, 0.057653099704053135, 0.03967728706136827, 0.015444458000391964, 0.018930157098258217, 0.03152372135270027, 0.009965655720612455, 0.022998497663666646, 0.050448939099066684, 0.07324123079137457, 0.02135964407164964, 0.07987272535120288, 1.2511250328633094, 35.46048564295615, 51.77093244368031, 45.43201746479158, 28.427085607282578, 24.222687213651596, 29.292574236469886, 41.10895364515243, 51.05001649548931, 59.429175853729255, 13.875881644987292, 0.06733974907547235, 0.22638382330056162, 0.7349015880496271, 1.1828450257739713, 29.230787100330478, 58.568144998242786, 56.0420052466854, 55.096996445809644, 56.87562657940773, 53.98430632006738, 55.497894056381725, 46.620017097842315, 48.11229067464029, 58.57519741981261, 54.904074668884284, 48.32755427206717, 37.5072568462741, 40.29171997501005, 47.850641127555605, 54.366525603878884, 46.4995454203698, 48.611992789853005, 51.63579110176333, 52.52551409506029, 50.04215171260219, 50.21437514212824, 50.58116774405203, 52.64171038904498, 52.689343652417584, 50.64452578944545, 47.63320061468309, 45.360336149892504, 49.327558625128965, 49.96127243964903, 45.0439420823128, 40.10901597238357, 36.05735271207748, 37.284866302244126, 36.000831357894405, 36.68844246095227, 36.57545858813871, 36.438101107074374, 37.27958679199219, 36.639608952306936, 37.283509162164506, 38.88224763254966, 38.41341457059307, 37.7058268362476, 38.53122688108875, 39.311460833395685, 37.72776465262137, 35.33879803073022, 38.822470711123565, 37.90581672422348, 36.047127093038256, 38.49218360839352, 41.20549494220365, 40.45190565047726, 41.8337135161123, 41.96526196695144, 40.766824906872166, 39.62186151935209, 43.34699138518303, 51.763931012922725, 51.98634509117373, 53.64163629470333, 52.62471868145851, 55.12308412982572, 50.343315216802786, 49.745400874845444, 50.62652995509487, 49.62117548911802, 53.54476159618747, 53.14347959333851, 53.7676267470083, 53.13182623155656, 51.4979080230959, 51.484089512978834, 47.66246934090891, 38.623331977475075, 38.146214869714555, 38.44267545207855, 36.63355673513105, 37.6269793510437, 37.50088299474409, 37.47060621938398, 37.07767494263188, 36.91373555890976, 38.141774746679495, 38.88821355758175, 36.768313684771144, 39.43990668942852, 37.241826134343306, 38.40891561200542, 37.32334475363455, 38.37319066447597, 37.79655518070344, 38.50556281305129, 45.27485593672722, 49.92423349811185, 50.43294529761038, 49.679418763806744, 51.2179410073065, 48.652816818606475, 50.27766650722873, 46.87279816596739, 50.09968896065989, 53.317746577724336, 56.05391356252856, 51.56005405610608, 48.05356494842037, 45.458211052802305, 41.21033122462612, 35.92884802049206, 40.979546808427386, 39.92846142861151, 39.326079507027906, 39.19932811490951, 41.499649170906316, 46.25055728420135, 54.11121068462249, 59.14190146230883, 58.71612033536358, 61.7835707049216, 60.12891884773009, 61.380041183963904, 62.417351199734604, 50.535770231677645, 5.353724927671495, 0.35077315184377855, 0.2740555442869663, 0.02721920545633522, 0.09932329172208425, 22.925539785815825, 65.51299164372107, 51.852203953650694, 47.76484712477654, 32.74376576946628, 31.854738996874904, 51.33611025348787, 53.32672488304877, 43.651202571007516, 4.609581193616314, 0.07274816128154916, 0.060400746822837866, 0.04461828987264345, 0.01459734574440987, 0.0359627871864265, 0.01751095623589091, 0.02247421390136644, 0.04393341875965557, 0.018531666888344674, 0.05914282279029008, 0.03390974815814726, 0.03556272458104837, 0.10696131090122847, 0.0414039496512663, 0.03737109427851054, 0.08165089203225029, 0.01186315879045475, 0.018705572677595962, 0.0959721090452325, 0.06027689721855906, 0.07163814584454221, 0.06302157191619759, 1.612316367606963, 43.503337060251546, 58.381114621316236, 54.73045879794706, 32.18107038928617, 25.553333643944036, 34.63504637441328, 47.27589230383597, 55.017744956478, 63.5296961569017, 14.216177655804543, 0.05205005519993363, 0.317850737802444, 1.7797120948953016, 1.9037429555769891, 33.25652153261247, 60.28645300096082, 58.201999587397424, 57.00480199629261, 59.26080026934224, 55.12975215911866, 57.13486779120661, 48.09213753669493, 49.368386576252604, 59.868340107702444, 56.51663949412685, 50.58095593606272, 39.19195405898556, 41.050686836242676, 50.51096908507809, 56.33553581853067, 47.963279831794004, 50.258313532798525, 52.03027955947384, 54.61557257559992, 52.49794767748926, 51.14796592343239, 52.06935813350063, 53.23806362767374, 52.87288311989077, 50.177194995264855, 48.570325451512495, 47.37774056773032, 50.75306953922395, 51.66329868378178, 47.712542318528705, 41.536393934680575, 37.57390183787192, 39.19057730705508, 37.74385813743838, 39.03049753558251, 37.68346540389523, 38.718386696230986, 39.767181411866225, 38.29857933905817, 39.445723564394065, 41.48122972057712, 39.983994345511164, 39.68964792067005, 40.67270371221727, 40.7930459514741, 39.63069861935031, 38.00263258718675, 40.15247583389282, 39.04456707739061, 38.775543474381976, 40.40882625887471, 43.19734511836883, 43.429168962663226, 42.95682930177258, 44.811675010188935, 42.79859304428101, 41.27339116988644, 45.377751473457586, 55.49627803987073, 54.31420903052054, 54.007530673857666, 54.1867829907325, 56.14146086477465, 52.851023750920454, 52.47774747110183, 53.277809004629816, 50.64948758771343, 54.037128879177956, 53.708838262865626, 54.62695921621015, 55.17888376789709, 53.9908213769236, 51.23009251010034, 49.67197410521969, 41.545187888606904, 39.924480222886615, 39.84842154287523, 38.031148218339496, 39.612600803375244, 38.15745638262841, 37.988598346710205, 39.57553440524686, 38.98432339391401, 41.39064258144748, 39.74842463770221, 38.85688166464529, 40.20354509353638, 38.997918328931256, 39.02770480801983, 39.30598520463513, 40.88026377462572, 39.84843723235592, 40.234139580880445, 47.62797209524339, 51.97777078997705, 51.649852798831084, 51.26395040942777, 52.130872664913056, 51.10544350839431, 49.5540911920609, 49.709938726117535, 49.63735134370866, 56.28738480229532, 56.61474581687682, 54.06753509275375, 50.759439468383796, 46.82229372762865, 41.74742529469152, 37.889633024892504, 41.71428126673545, 40.52510100026285, 41.70074124490061, 42.51163636484454, 44.15468192869618, 51.021602845961056, 56.67885695734332, 62.794039941603145, 60.82318621297037, 64.26508565102854, 62.14729601337064, 63.869683281067886, 62.21024613226614, 52.335043799492624, 5.954317267863981, 0.7215894926940242, 1.28763776392706, 0.20324908647566073, 0.062155210743508035, 24.81592412917845, 71.26269602006482, 58.23144089791083, 53.79211410399407, 35.61159495384463, 35.59048867994739, 58.78620524560252, 60.186212908837106, 53.20219747481808, 7.51580547901892, 0.0793417881152803, 0.020771753944216237, 0.031676180510511326, 0.020652723032981157, 0.10420160172807594, 0.03724597296827743, 0.042982849202329115, 0.0357891112235525, 0.040697754480906075, 0.05092976652386208, 0.19682767620730787, 0.21542024708563284, 0.09018566309204025, 0.12434306449346966, 0.10795355564163578, 0.19355499456005712, 0.08861843106006423, 0.07766888957590827, 0.2141544553301027, 0.14523831947195917, 0.13181563166360702, 0.139991597783181, 1.8245761649262522, 48.34838990242251, 65.95781587785291, 60.59663795655774, 39.68659631667599, 35.609978937333636, 39.515522141610425, 51.332870375725534, 59.76760187456685, 70.02781621871456, 17.334881636404223, 0.217038944904362, 1.3695264343292484, 3.081095559943107, 1.9536917656660082, 34.084388748292, 59.66926413197672, 59.98814890461584, 59.8891875051683, 61.3802961380251, 57.27652811234998, 57.71859492025068, 49.834089586811686, 50.89867576476067, 62.79738572336013, 59.157924344462735, 51.950310276400664, 41.30845715922695, 43.87156917202858, 54.19806764971826, 58.33118284902265, 48.844581496331, 50.203847500585745, 54.56386396961828, 57.34680914109754, 56.23669993492865, 53.83449139133577, 54.82496438487884, 56.011665713402536, 55.25260471528577, 53.816577926758804, 48.00085221567462, 47.37876038397513, 51.609342559691406, 53.67188953584241, 49.60809438459335, 44.60037692900627, 39.45625120593656, 41.184004276029526, 39.44013810926868, 39.739265903349846, 40.22134480937835, 40.04483030688378, 41.38912070182062, 38.621515920085294, 40.913156770890765, 43.737404500284505, 41.744091280045055, 41.817208182427194, 43.29969544564524, 42.124423903803674, 41.67985070136286, 38.23787673827141, 42.350179841441495, 41.70404388058571, 40.81231263376052, 42.60671461782148, 45.152960438882154, 44.18860650831654, 45.31046321315151, 47.10808546312394, 44.141624358392534, 42.02625090076078, 46.166469512447236, 58.11982985465758, 56.80768720565304, 55.00456187032885, 55.00211038897115, 58.577170372009284, 54.70816012351744, 54.60889277919647, 54.899528641854566, 50.82785344892933, 57.23680626961493, 55.19154125644315, 56.295131483385646, 57.00881850334906, 55.42811901338639, 54.77510321524836, 52.17547393614247, 42.9854469145498, 41.52110453574888, 40.24418869326192, 40.03540485135971, 42.41472244262695, 41.0506554572813, 40.41492554449266, 41.23949404685728, 40.5230535230329, 42.30608455596432, 40.62617263486309, 40.65970497746622, 42.66515401101882, 39.3903200857101, 41.57310731949345, 42.53472343567879, 42.981881480063166, 43.57995663919757, 42.53786133181664, 48.9055625854, 55.14795587908838, 55.39916799914453, 50.97813906208162, 55.692133749684984, 52.09131556172525, 52.92485452467396, 50.06210873203893, 52.11497137623449, 57.25923830463041, 59.524540439728774, 56.693895324583984, 53.52678929605792, 47.83741881770473, 44.38901216753068, 40.02758756760628, 46.08755534695041, 43.43395425427345, 44.429420425045876, 43.81442808335827, 46.96870796142086, 52.740844372780096, 58.84776292308685, 64.19991547061552, 65.5551806572945, 68.55671559610676, 65.77525308055263, 66.76405906677246, 64.74251654840285, 55.401427284363784, 6.812432821719878, 0.8142005748325779, 2.6028390036475275, 0.4295959383729966, 0.13299157662737754, 27.55675285093246, 77.89687525841498, 63.0528457703129, 62.82011978087887, 46.29174217101067, 45.632376055563654, 67.39498015372985, 71.02712631225586, 65.06711229201287, 11.149091086079999, 0.20130046523146092, 0.2375927161906035, 0.19252433051024714, 0.1450209650060823, 0.11651421281238718, 0.2459248416726628, 0.10211341458583072, 0.07947170130547979, 0.07881755414869517, 0.1330687063595941], [0.014704968648842506, 0.004654025796034764, 0.07857914758665908, 0.07012517582024298, 0.09279446826586801, 0.02662562329562441, 0.027330803399484967, 0.04717210142482673, 0.05447272782123858, 0.06954767576028263, 0.01571710773503348, 0.023522342840630203, 0.36912203015338996, 24.903026242409986, 44.04411031353859, 53.77627165086808, 42.261965736266106, 31.42540616373862, 34.4404693572752, 45.951621686258626, 46.940160951306744, 60.658372140699825, 19.478505965202086, 0.030826039334398606, 0.03806232392126995, 0.7758172409188363, 0.3624275861488235, 9.089408420747327, 50.16716157236407, 56.640766820599964, 56.65138859902659, 55.76008489055019, 56.76940879514141, 51.423598720181374, 58.320145299357755, 54.51497162542036, 51.81738899600122, 46.95552879764188, 37.87018983594833, 37.12044838936099, 47.01852598497945, 53.95810880968648, 51.888823201579434, 50.346327597095126, 54.76167301977835, 48.86633888367684, 45.435445616322184, 46.93761925543509, 46.28029669484785, 47.755864897081935, 50.0464153289795, 51.729688721318404, 50.26589155197144, 50.171633074360514, 50.41383943250103, 51.7641467432822, 46.963903057959776, 41.944838185464185, 37.932061303046446, 37.03498386567639, 37.775409683104485, 36.25602860604563, 36.917214701252604, 36.97643072374406, 37.439309627779075, 36.879026505254934, 36.57203435897827, 38.55457675072455, 38.58947015577747, 37.757186351283906, 38.485182177635934, 37.65732280669674, 39.29868959611462, 37.996674506895005, 37.577447660507694, 38.30032087141468, 38.56098198121594, 40.120092745750185, 37.86725590305944, 36.7845993657266, 37.30317200383833, 36.81504872537429, 40.55965708148095, 39.15925718122913, 44.111594692353286, 53.38639197811004, 52.47774747110183, 52.7072649617349, 52.74664948063513, 51.3672342608052, 54.16762221244074, 50.954895096440474, 50.95827617952901, 51.74890833516275, 53.358715734174176, 52.92300316595262, 50.48539523155459, 50.095966631366366, 52.478269146334746, 53.72210764115857, 49.8497006200975, 39.764314159270256, 40.63079318692608, 39.766043924516254, 37.869726996268, 38.869256742538944, 37.92857431596325, 37.73901401027557, 36.9452400361338, 38.28278395437425, 37.428985949485536, 36.99067677220991, 37.56329967129616, 37.70847443611392, 36.75181227345621, 37.40230206520327, 37.62508484625047, 39.0860539867032, 37.391084086510446, 38.34605570762388, 36.95592849485336, 45.07810984888385, 47.44404823549333, 51.179619450722974, 51.56920494571809, 49.83252063874276, 50.227562150647564, 51.43888419674289, 53.58483645223803, 50.60740840050482, 49.70322755075271, 51.43052562590569, 56.501993363903416, 56.7569984159162, 52.16870000285488, 48.3945091309086, 45.06871577232115, 37.818269421977384, 38.92267942428589, 41.29097515536893, 42.81856575319844, 44.60396982008412, 42.58855404392366, 42.14576944228142, 46.573968472019324, 54.58452701568604, 59.88567306149391, 59.9484819750632, 61.20351099198865, 57.53098795490881, 37.971571337792184, 1.9832274582116836, 0.4168543027293298, 0.18939242517996221, 0.07459831724484121, 0.056692915743276964, 18.736430791116533, 66.29901501440233, 51.81456488947715, 47.39679544202743, 29.188307831364295, 39.75954455714072, 50.55672745550833, 55.63885619563442, 41.12079528070266, 1.5614394266759197, 0.05639768077901775, 0.015149023853272442, 0.04515495744623965, 0.055340985061540726, 0.05780592658406785, 0.10844412770482803, 0.05893459243159141, 0.02585230350133873, 0.028379981879204996, 0.06003106343409708, 0.06805125323514785, 0.053654476970193855, 0.046596118218956456, 0.04379701297429781, 0.04473773064091802, 0.01300234302517868, 0.08315604795972187, 0.07660133839254418, 0.03756971406419912, 0.04812028461826905, 0.025287440061689388, 0.024728540616530566, 0.3609157575955314, 30.39044172533097, 52.731952359599454, 59.84721814432452, 45.54254593387727, 28.33086790577058, 34.234913626024806, 52.87516986170123, 53.47385298821234, 65.70381103023406, 22.66381375251278, 0.05134521217475976, 0.05708565837853859, 2.6308525714182087, 1.468578170864813, 10.640087070003634, 51.55886557794387, 59.607882961150146, 58.95101931787307, 57.46944596690517, 56.981393291104226, 50.76387566904868, 57.143591142469845, 56.59600473219349, 54.03110019622311, 49.83609784033991, 39.85763911278018, 38.24302681030766, 47.829636835282855, 55.42034879807503, 53.517222635207645, 51.21309295777352, 56.53198772861112, 50.84420973254789, 48.58555993726177, 49.40125211592644, 48.57331037521363, 50.430156492417865, 51.3585619003542, 52.44451322863179, 53.40850237877139, 51.92872939571258, 52.227566934401, 53.95357454976728, 49.86495471769764, 44.251623307504964, 39.83015898735293, 38.5566948306176, 40.16854186211863, 39.0837162540805, 39.313798566018384, 39.14782347217683, 39.29471231275989, 38.31449631721743, 38.27082072534869, 38.5611584878737, 40.16264261737947, 39.69392330415788, 39.81230435832855, 39.49549451951058, 40.530906108117875, 40.114173889160156, 40.42692799721995, 40.890516850256155, 39.83270460559476, 42.128589460926676, 40.202011446799006, 38.274146895254816, 38.70159110715313, 38.09719308730095, 42.45089846272623, 40.49476146697998, 44.44564727044875, 56.31655939163701, 55.916105008894405, 55.038411924915934, 53.64078121800577, 53.9845298951672, 55.255271927002944, 52.73445483176939, 52.42627420733052, 53.884344716225904, 54.92263140216951, 55.15520834153699, 53.294906616210945, 52.577003048312285, 53.927985006763095, 54.754157758528194, 51.300083283455145, 40.817760805929865, 40.80940223509266, 40.56110051370437, 39.22499218294698, 39.39048874762751, 38.54343721943517, 40.05059226866692, 38.86837420925018, 39.81919204035113, 38.97630214691162, 40.064999134309836, 39.28097225004627, 40.07260461007395, 38.74658853776994, 39.09136487591652, 39.93133260357765, 40.806656575972035, 40.19382153787921, 41.276587901576875, 39.81478329627745, 46.12427657650363, 50.77243428076468, 53.11119456445017, 53.820119827024406, 51.811289710383264, 52.0920176659861, 54.09031229634439, 54.570531998911214, 51.24608793566304, 50.13571985306279, 52.89620553293536, 57.86074946003576, 57.88244016708867, 53.71702817178542, 51.91685638120098, 46.479635469375125, 38.87690928674514, 40.78917457211403, 41.84958734819966, 43.85136896564115, 46.811244410853234, 45.972531841647246, 44.544694962040076, 52.29159962746405, 58.80270273454728, 60.207040694452104, 63.516026696851185, 64.38702037257534, 60.23195558978666, 41.22761710997551, 2.5418407542090264, 1.0855652199637507, 1.3218934161047782, 0.04623139141908577, 0.011975953745986185, 21.8737679912198, 72.64347230234455, 58.43218780332997, 52.25359186049431, 39.80895857657156, 42.49244812996157, 56.69925720460954, 63.774965886146795, 51.56299975610549, 4.176311771715842, 0.12312355210944531, 0.06732643446734837, 0.04643936130789019, 0.041473127390828826, 0.033245212849109404, 0.07913222476359337, 0.03448645148666636, 0.05077418555775958, 0.0084485660585004, 0.04883917003509499, 0.14999453038457902, 0.14327146533516147, 0.17437356253785474, 0.2192700687315195, 0.16644954741481813, 0.11056753190895242, 0.1189365215419281, 0.17508179550209355, 0.13661128078256884, 0.32293520206885956, 0.15657807550122663, 0.13059438025999454, 0.41868224980369695, 33.22631535991546, 63.71023893356324, 66.52524163646083, 55.14030725725236, 42.0929233489498, 44.92344687061925, 61.20351491435882, 57.11573839187623, 71.97286467398368, 24.0992659138095, 0.12411575088457716, 0.46828080449373494, 4.226039580760464, 1.1466145827885599, 11.012626924822408, 51.79071687882947, 59.701804114926254, 59.771692906656575, 58.0002603223247, 57.030685717059725, 51.63323371641098, 58.713233470916755, 57.16851388254474, 56.50798674552672, 51.162714035280295, 41.125102043151855, 40.52060988641555, 51.10626328376032, 57.52829328660042, 53.93826161661456, 52.83028225744925, 60.79862040858115, 53.8760292914606, 49.482590306189756, 52.50261922036448, 51.69100238430885, 53.73201554821384, 53.924380348574736, 56.2797087238681, 54.858951722421956, 54.12239728435394, 52.31684792426325, 57.4031618333632, 54.29748012173561, 46.48154566364904, 41.83511380226382, 40.536432727690666, 41.761741945820475, 40.919059938000096, 41.04125353597826, 42.87415750565068, 42.625428245913604, 38.739626330714074, 40.84260509860131, 40.91418835424608, 41.51020426904002, 41.28817066069573, 43.073358997221916, 41.28365601262739, 44.686433730586884, 42.133727765852406, 42.19297124493507, 41.66439656288394, 42.13462991099204, 44.71142315095471, 41.11669248150241, 40.59972409279116, 40.04929004176971, 40.5805633144994, 45.219738791065836, 42.52213654979583, 48.80320049101307, 57.654491624524525, 55.749035573774776, 57.56010370869791, 55.26432083499048, 57.011328820259344, 57.37648579382128, 55.174157311839444, 54.47484970092774, 53.753035529967285, 56.706607726312455, 56.04229157970798, 56.01794935041859, 55.66481051906463, 55.579444054634344, 56.12525755359281, 54.15002253747756, 42.85941331617294, 44.150430079429384, 43.81464773608793, 42.50472122623075, 42.04205020781487, 40.750794179977916, 42.46101425540063, 38.74634927318942, 42.081885799284905, 41.52878061417611, 41.716850419198316, 41.546341065437566, 41.43009378064064, 41.411882215930575, 41.29788244924238, 42.051201097426876, 43.78289614954303, 42.89433810018724, 43.94507831142795, 41.877216523693455, 49.746126513327326, 52.75637695866247, 55.44821331577917, 57.09779747070805, 54.61983226960706, 55.1404719967996, 57.058142308265936, 57.99316867705315, 53.064122200012214, 50.94814861974409, 54.26959599218061, 57.56102154331823, 59.25071585562922, 57.9663553545552, 53.87151856576243, 50.833411447463504, 40.847582586349986, 42.703385353088386, 44.59100638666461, 45.97161400702692, 50.92249239644697, 47.32885999064292, 45.183868715840006, 53.609268896041385, 59.37682790140952, 64.93468523025513, 65.25559394590317, 67.44537476570376, 60.92173968591998, 42.93496208806192, 2.871661094888564, 1.9367577904655089, 2.588007541433458, 0.248141884803772, 0.1415200964097054, 24.220284761921054, 78.72578974693053, 62.56788784457792, 64.50735084472164, 47.44948464055216, 53.8930170766769, 66.31634404582363, 69.8555378760061, 63.86249357654203, 7.817049391808049, 0.22327877701290194, 0.2332713521055637, 0.11368586216121913, 0.11398441428619047, 0.1935089220322909, 0.23128603524979086, 0.1285318570632127, 0.09607109526592879, 0.15228216085703145, 0.1408938348533646], [0.009080826083288319, 0.006042440936359908, 0.025399175900665504, 0.008367320518910645, 0.031246836109447385, 0.07689187723782755, 0.009607292238562819, 0.0014303975964843807, 0.03188907251422925, 0.016303469517057943, 0.01019364635970804, 0.031088560429071228, 0.002873714547604323, 14.216438493421002, 50.21723847235403, 52.702158035770545, 40.97157262986706, 20.9679691637716, 32.09869277092719, 38.678755068009906, 50.0093646203318, 58.4139762386199, 28.24672522083406, 0.03751897606097403, 0.30856765205821685, 1.4571448295347154, 2.4456693856946887, 0.4633524076592538, 25.181116404071933, 55.433680934290734, 52.84481071656751, 53.17918885138727, 53.8715656342045, 55.92146296654978, 54.811710696066584, 53.336821063872314, 46.57557664378997, 37.07851040747858, 37.75284428750315, 44.94516503426337, 50.09348377104729, 52.702922897954146, 52.883881445853945, 52.282374212818766, 48.23832035064698, 47.23001233993038, 46.04014565867763, 44.484400287751235, 46.86026619326684, 45.274863781467566, 45.58381319046021, 46.36561609083607, 49.0269011066806, 46.725611225251235, 48.44844564314812, 47.23061246256675, 43.750152203344534, 39.26447083873134, 35.92196818320982, 36.249568462371826, 36.56601352076377, 36.83233853309385, 36.21371015425652, 37.11368622318391, 36.80346596625544, 35.47981116079515, 37.970931991454094, 37.344447105161606, 39.390622108213364, 38.74456459476102, 39.19193836950487, 36.85187978129233, 37.80692200506888, 39.482342812322806, 39.311154888522246, 37.66559116301998, 40.692519526327814, 36.759260854413434, 41.50415597423431, 39.720618955550655, 41.14754976764802, 37.211325783883375, 39.41225005734352, 40.18789483654884, 44.09348903163787, 54.14650024906282, 52.34477912226031, 53.74805411984844, 46.728447098885816, 49.286518866016024, 54.097890315517304, 51.101136745945105, 51.300153886118245, 50.46544997922836, 53.116948681492964, 53.6078215414478, 54.13904382336525, 52.77123097450503, 51.63602644397367, 50.81504298794655, 45.70740315221971, 37.63071344744775, 37.93868226389731, 38.540052213976466, 36.04515806321175, 38.58116257575251, 38.18356760086552, 37.56141301124327, 40.20070137516145, 37.3875343415045, 37.634831936128684, 38.29575131016393, 38.623382968287316, 39.46217790726693, 37.19564807030463, 36.267787871822236, 37.540467554523104, 37.928695909438595, 38.69711568278652, 39.426507872919885, 36.30903159418414, 38.60279444725283, 45.08818249548636, 44.2731257407896, 47.66174762479721, 44.93926578952421, 48.32965274010935, 47.70090856859761, 49.120735968312914, 50.2644520421182, 50.52917672741798, 48.18920050897906, 48.56643446030156, 51.81334895472373, 57.035659282438225, 55.442396440813624, 52.96958523411905, 44.049342755348455, 37.7754371396957, 40.948371810297814, 45.215553622091974, 47.5852967077686, 50.452819947273504, 52.17292439553046, 46.4439340560667, 48.562731742858894, 54.30584653731316, 57.75798336152108, 60.80284872362691, 57.2393048194147, 28.762950320397657, 0.9189110044990817, 1.0955699605326499, 1.0503543480750055, 0.050593419451146364, 0.009934062254615128, 19.043548453238703, 68.82923403093892, 48.993302083784535, 56.64756821047876, 30.629561178145874, 40.67484924870153, 58.26380437420261, 53.03906217698128, 42.5657650732225, 0.8581336335309091, 0.04948690503595337, 0.047901765698747295, 0.03072853740905562, 0.017765632590218898, 0.017779659660112475, 0.015789688820199623, 0.11573257330324381, 0.01331641321866623, 0.019021570539822983, 0.050559703921598774, 0.016842866278884393, 0.01760327940686576, 0.00513390087777929, 0.09562695579182717, 0.0503076609945105, 0.014645837194797014, 0.03597149377568595, 0.09266488449347597, 0.05804902926507977, 0.03398852880984064, 0.01090585723549368, 0.022886809705185796, 0.0561753697242708, 17.659479341199322, 57.50350390711139, 58.17454691856139, 47.2175705817438, 27.02350466482101, 39.576789563702, 49.79434028748543, 53.92625131914693, 64.64073496480142, 29.01465077554026, 0.03247512977630381, 0.11565917441921851, 2.3635972219128765, 4.7125095801968735, 1.9239039382626935, 29.007047260961226, 56.823325695530066, 54.812153923896055, 53.26412777746878, 56.13118817729335, 57.05149781319403, 57.34224350221696, 55.03631345687374, 48.93450967727169, 39.39052404895906, 40.834823116179436, 45.1188789644549, 53.69773795527797, 54.047185836299775, 52.886356461432676, 53.96960135429136, 50.08900834668068, 50.64825596347932, 47.84573816484021, 47.73747290334394, 49.825268176294145, 47.301979987852036, 48.27960721908077, 48.89163817128828, 50.299906346105764, 48.329397786048155, 50.834497944001235, 48.86531906743204, 46.34250940815095, 41.35586292512956, 37.71212224037417, 39.00510411108694, 39.01081900442801, 38.45093596366144, 38.8556186614498, 37.72307742026545, 39.20899675738427, 37.08526865128548, 38.15606394121724, 39.60561898446853, 40.003763091179636, 39.05811886633597, 39.608819638529134, 38.94635092827582, 38.53183484846546, 41.43011731486167, 41.18463577762727, 39.886280259778424, 41.42612041965608, 40.17372723548643, 43.67322667952507, 42.56250558360931, 42.42098254542197, 39.43208548330492, 41.349732260550226, 41.99839815016716, 46.563570268692516, 57.05842079654817, 55.137875387745524, 55.943777330460094, 48.42899068709343, 51.98431330342447, 56.638911539508456, 52.78046815626083, 52.60895859810614, 51.91268297933763, 54.90067789631506, 55.07943991691836, 54.904737549443404, 55.31807691820207, 55.497682248392415, 53.57728196728615, 47.48668832163657, 41.01641316567698, 41.005916903095866, 39.750781982175766, 38.58887395551128, 40.03855843697825, 39.248189080146055, 40.32920998911704, 40.59267167122134, 39.37013949117353, 39.90092639000186, 39.79978023036834, 39.9953378400495, 39.98317849251532, 38.99122284304711, 39.3390586299281, 40.23189990751205, 39.78105091279553, 40.316670171676144, 40.26552638699932, 39.45761226838635, 40.739156507676654, 46.29433878006474, 47.12100182810138, 48.09703265466998, 48.34794275222286, 49.38303270647603, 51.843841460443315, 53.17393679772654, 53.66775143531061, 53.320453013143236, 49.084222624378825, 51.797200556724306, 56.09733812270626, 58.255155547972656, 56.96578225781841, 55.837343815834295, 45.45876018462643, 40.82293833455732, 43.49526482243692, 46.31612754637196, 49.38621767105595, 52.60115700383341, 53.36029252698345, 46.73498568996307, 51.010679045031154, 57.45469785505726, 59.9138984372539, 63.14358980424943, 61.08226268522201, 30.748862028121952, 1.2709611942691188, 2.9587906647113065, 2.1686747910514956, 0.07430273754101607, 0.04444960880303576, 21.171448000015754, 74.53054812646683, 55.26223021168863, 63.43475126451062, 34.72100511673958, 47.52666904080299, 66.01976579235446, 60.25653316128639, 50.59983822607225, 2.687640891921136, 0.032764879551025174, 0.035964369157990145, 0.04598141309895343, 0.03749423908189901, 0.04064505912303444, 0.019330610408477725, 0.07591214271322375, 0.08690818573438353, 0.010833612271404315, 0.06658856156131913, 0.12512183883377623, 0.10441533259807095, 0.0868967250590363, 0.25787493995120453, 0.11166902078736214, 0.16004018004863493, 0.17331534996628764, 0.2109983109778935, 0.17069784203364005, 0.1296390532966583, 0.08244178588351897, 0.24431962700140095, 0.19379979029538172, 20.58032131964161, 67.74484772836009, 66.202744360893, 52.849811738537205, 33.04216792506556, 44.506687195070334, 50.19428083973546, 60.658070118196555, 68.40776751118322, 34.87825293694773, 0.17906562124769534, 0.6651118974531851, 7.935849158994614, 5.557703375816346, 0.9699230833399681, 29.63051388340612, 56.67858239143126, 55.288168845638154, 54.84179135291807, 59.270559126330966, 60.45480897349697, 59.553154130135816, 56.96195010216006, 50.25345371615503, 40.21908944652927, 43.323700351099816, 49.80931981917351, 54.7572172072626, 55.381156475313254, 55.46150230592298, 57.51729103826708, 52.58544791129328, 53.66458216021138, 50.19894846024052, 49.31847441580988, 53.27405921874508, 50.234689097250666, 50.63712819930046, 51.55713581269788, 52.35663644729122, 51.27799641701483, 55.156251692002826, 53.29664422619728, 48.62146923618932, 44.264853462096184, 39.33243766907723, 41.18744419467065, 41.110146045684814, 41.62436485290527, 41.035687692703746, 40.32781362533569, 40.526822920768495, 39.93347421769173, 40.8600910248295, 41.04405018591112, 43.418778604076756, 40.60483494112569, 42.10705564868066, 41.624376620015795, 40.98983518538937, 43.93369559318789, 43.39662505734352, 42.757870997152025, 45.283230197045114, 41.20565968175089, 46.32864775196199, 43.65486998711863, 44.84385021271245, 41.40413945721042, 43.04486297792004, 43.6293000559653, 48.83770165904876, 56.945397700032885, 55.76464268469042, 56.677723392363525, 48.749966083034394, 53.63516046154884, 58.47634976910007, 56.539432387198175, 55.15062309080555, 54.074940527639086, 56.92257342800018, 58.10088088435512, 56.75746125559653, 56.31153483544627, 59.82788085937501, 56.71759428516511, 50.9402411214767, 41.4289798275117, 41.91967225843861, 41.2389253031823, 39.222073939538774, 40.95026631509104, 41.49740949753792, 42.23733717395414, 44.05448890501454, 41.29552510476882, 41.8178161498039, 41.653417848771625, 41.38420597199471, 43.46690608609108, 40.53977066470731, 40.62920854937646, 41.566811915366884, 40.60390533939485, 42.88050390058949, 43.99968554896694, 41.76620952544674, 42.574457045524355, 50.11446452909901, 49.15909674859817, 52.18168697049541, 51.252018559363584, 53.36625845201554, 53.93149945043749, 56.399019379769605, 56.28479603798159, 54.8634232244184, 50.854894268897276, 53.266598870677335, 55.38081522910826, 58.857427643191436, 58.82915912135955, 59.07232253782211, 47.264631179071245, 43.39384017452117, 46.38111729775706, 49.9152159690857, 51.67610130002422, 56.764745097006525, 56.246768659160985, 50.442759067781516, 53.97652433764551, 60.29868687352827, 63.08559756125174, 65.54945399684291, 61.94234432712678, 32.97264391376127, 2.092695293887969, 4.399064154394211, 4.6826363186682425, 0.28064046836187767, 0.10307493920047438, 23.269182558982607, 79.87557764976256, 61.64283606313891, 69.67998827657392, 42.935405315891394, 53.83138879652947, 71.63930631452992, 67.99741698849586, 62.072484647074056, 6.827246142971901, 0.1724660495716718, 0.14243498925239811, 0.09530391183591659, 0.07154928730620493, 0.11655640893525655, 0.11117939101231676, 0.2688417030918983, 0.21485507338037416, 0.3082774885960164, 0.16559148297434853], [0.03576830044508942, 0.024557386998147256, 0.0264782011659155, 0.033585524426833276, 0.05582532499946895, 0.050967978989525195, 0.03591556552677386, 0.07149168515517827, 0.08521621926657616, 0.07179720101938133, 0.017011049391341307, 0.16073733538148866, 0.11387061192503861, 7.482674198765909, 48.32052538471837, 50.50321455924742, 42.91213389365904, 22.625929540203465, 22.609498731551632, 37.085174514401345, 48.62542298532302, 55.153541334213756, 35.85417001478134, 0.22781700526754703, 0.16436332145765906, 2.0429794971019994, 2.0887726785675174, 0.5966630445853357, 8.175578050075039, 45.63057176528439, 55.601872167279645, 56.94243238818262, 57.17627625311575, 54.72706202537783, 49.0644617234507, 43.3416255827873, 35.538866366109545, 38.024056573067945, 44.13997304054999, 50.81481156810638, 52.93571164531093, 52.07584181139546, 52.040968018193404, 49.25706971076227, 48.18750604506462, 44.626884306630785, 43.427054805140344, 40.410960028248454, 40.54790173807452, 41.3130541770689, 44.54424388947026, 44.47444923462407, 44.41053421266618, 46.047896262138124, 44.107209482500636, 41.6979524397081, 38.26253667954476, 36.140087266122144, 35.50420045852661, 37.06175404210245, 36.30122607754123, 37.90552254646055, 35.10020417551841, 38.079181563469675, 37.45515208090506, 35.65434878872287, 37.52749627636325, 36.42383544675766, 36.84817314147949, 38.8438593956732, 38.86662483215332, 37.84218019054782, 37.58363716063961, 38.951489233201556, 40.22343151031002, 38.74896157172419, 38.19055726451259, 42.47920620825983, 44.15872196997366, 46.66584214856548, 44.03277074137042, 40.85490957383187, 40.02760325708697, 37.939498116893155, 40.25534391403198, 53.30197864963163, 55.12160147390058, 53.724406150079545, 48.664984010881, 46.4586978573953, 53.81651909120622, 50.379954076582386, 51.20148274206346, 50.68280812232725, 50.63832844457319, 51.98574889090754, 53.05983504941387, 53.916770950440444, 52.2654099618235, 50.49420487496161, 42.69621918278356, 37.5681241866081, 38.65386762926656, 38.13417319328555, 38.318399075538885, 38.98953230150285, 39.59372635810606, 38.719053499160275, 39.65682552706811, 39.73623783357682, 39.34127869144563, 38.10407292458319, 37.61890319085891, 38.92864534931798, 38.19613487489762, 36.96263182547785, 34.978265531601444, 36.215930215774044, 37.61172917581374, 36.9992353839259, 37.462365319651944, 36.641056306900516, 38.45895328829366, 39.988591363353116, 39.88082816523891, 42.78824583176644, 43.08078404395811, 45.90998964924967, 46.46531881824617, 48.5593585045107, 50.362534830647135, 52.41185165220692, 50.637265482256495, 47.69556237805275, 48.3332024851153, 53.91372719118672, 58.2655772855205, 49.052753448486335, 42.03479382299608, 41.07369153730331, 41.602003420552904, 47.93781188226516, 51.70480520494523, 53.164640780418154, 54.7200958959518, 53.8456662239567, 56.159801867700395, 58.403166186425, 59.84178958400604, 59.61155037726126, 23.006811295786214, 0.8169112390568181, 0.9799963428128151, 1.019029932156686, 0.1938161079681689, 0.07434528606433062, 20.768222462746408, 67.27613233750867, 53.12741748748287, 45.0920303406254, 41.389328587439756, 34.48974609375, 47.00740214317076, 55.14260968854351, 43.65422671841037, 3.2423157605432698, 0.05545469549214167, 0.06047234540024112, 0.012988902012547179, 0.029898348992930788, 0.04339133111399509, 0.014089122057832299, 0.0630708122175307, 0.02485088868847778, 0.09176056366413833, 0.06115417897460922, 0.028378457364235676, 0.035361699279277556, 0.02436443051743892, 0.035184997269102646, 0.037256054685360966, 0.029609328916957302, 0.048304498120541536, 0.05957673882104217, 0.0655855379638172, 0.08762034106879465, 0.027220559516741384, 0.13092104015090775, 0.09572038021419318, 9.830222552822484, 58.2971013745954, 55.888330705704234, 48.48363714833414, 24.233724763316495, 27.010184295715828, 44.527973897995494, 54.01467723231162, 60.553174172678304, 38.32563192613664, 0.11703784156951214, 0.058330945790775364, 4.3966146342216, 6.848834378104057, 1.3224170525227825, 11.549963201245955, 46.832256547866336, 57.92180507413803, 59.52480716090049, 58.35980046179987, 56.497306131547504, 52.375318696421964, 45.94785228852303, 37.92217693021221, 38.853437823633996, 44.32594045515984, 52.379327358738074, 54.656867288774066, 52.01691212192659, 55.22036283246933, 51.37283148304109, 49.35881991540232, 47.43900406745173, 45.002863099498136, 41.94101779691635, 42.18301234706756, 43.16250662649832, 45.19904828840687, 46.92719359551707, 48.409143494021514, 46.49103779946604, 47.21578590331539, 44.036128290237926, 40.4722313727102, 36.932119707907404, 37.22716039226901, 39.169780900401456, 39.62929441082863, 38.384255670732074, 38.576530256579005, 40.02783859929731, 38.98024020656463, 38.39577567192816, 38.822113775437884, 37.798492831568566, 38.76445493390484, 40.29290845317226, 40.821843993279245, 38.3730298472989, 39.00060123012912, 40.813979641083755, 41.47088250806255, 41.43648332165134, 40.56311661197294, 43.7325172270498, 46.58784974005915, 47.52460195172218, 46.306062744509795, 43.84316728961083, 41.24789184139621, 38.782250727376635, 43.72670427445443, 55.55172466462659, 54.9649106302569, 53.3766919566739, 48.269636554102746, 48.51021512862175, 56.530822784669944, 53.31354571926979, 53.2595621385882, 52.81532233761203, 52.19929449019894, 54.171411222027196, 53.724974893754535, 53.53972135051605, 54.22187251429404, 52.02201904789094, 45.410628780241936, 39.3637264159418, 41.729864843430065, 39.52006424626997, 39.83183776178668, 39.56030776423793, 39.76981724462202, 40.79569747371059, 40.3407064560921, 41.30831595390074, 39.72712224529636, 40.388402477387466, 40.186894632154896, 41.04809807192895, 40.395148954083844, 39.69240142453102, 37.45994521725563, 38.71078906520721, 38.846150059853834, 38.914893519493845, 38.497980871508204, 40.05693866360573, 40.70653807732367, 42.27990273506411, 43.80549684647591, 45.8443291725651, 45.80096737031014, 49.687953841301706, 47.7007830527521, 51.03870830228252, 53.21007359412409, 55.10991281078708, 49.834591650193744, 49.65407240775324, 52.435680051003736, 57.220147963493105, 60.03565665214293, 52.56712259784822, 43.54330993467762, 43.13837620519823, 43.65193213185957, 50.69240223976874, 54.34198333371071, 56.053540937362186, 57.94667290103052, 55.61310975782333, 58.80846469633041, 61.92901611328126, 61.0243449672576, 64.17082717341762, 24.313633249652003, 1.945603348074421, 3.2488396427323742, 2.2849242821816476, 0.22591200506975576, 0.05356178033135591, 22.284932405717914, 72.57764708611273, 57.66525068590718, 54.57916905803066, 50.57883785616968, 40.702537259747906, 57.16572507735222, 60.623788602890514, 52.33636563824069, 4.49957489005981, 0.05864348668124407, 0.03412113479909397, 0.01962036592885852, 0.06274759972227678, 0.08854854085873212, 0.04348954741632746, 0.03366640415943919, 0.11516120194667771, 0.018141915826427362, 0.02743995943737607, 0.12356369260458216, 0.13704376805934215, 0.15009914735151877, 0.13415552465425384, 0.19249377892382685, 0.13402562678581284, 0.16222164605654057, 0.21970961933895466, 0.24459483642731947, 0.1267045075374265, 0.17470556972247941, 0.21148791777030115, 0.2835960968607857, 11.348205304914906, 66.05476902377221, 62.968899203884995, 55.83312334552888, 33.10407469349523, 32.21825249733464, 48.742580259999926, 59.60607867087088, 64.10775546104678, 43.51857154600082, 0.2941882430065063, 0.21011602283725817, 5.604232982281716, 7.514639064188927, 1.6361035815169735, 11.065876041689227, 50.16507879380257, 59.09629998668548, 61.02345066685831, 60.04076357810729, 59.73363414887459, 54.69100367638373, 46.84396874520087, 38.60416335444297, 41.69221793451617, 47.19583280624882, 55.660648884311804, 55.59080323865337, 56.53681616629324, 57.62275180509014, 53.42712579234954, 53.281872580128336, 50.05244793430452, 46.81649646451397, 43.960752102636526, 44.336785808686294, 46.279606357697524, 47.849017266304266, 49.11187141172348, 48.99277648618145, 48.49179960066273, 48.615075772808446, 45.67445524277226, 42.1271970195155, 40.037189529788115, 38.103853271853545, 41.58812607488325, 40.48409654248146, 41.99833539224441, 39.8914695555164, 41.28012587947231, 40.541727927423295, 40.229079723358154, 41.10012831226472, 39.61740178446616, 40.34939450602378, 42.50940845858666, 42.12209401592132, 40.315046310424805, 40.742400307809156, 42.38334348124843, 43.70876727565643, 43.7856339639233, 41.506387802862356, 46.10932057903659, 48.7392540900938, 51.91312620716711, 48.31895643664945, 46.31684534011349, 43.56906421722905, 42.40440660907377, 45.811047861652995, 57.509356083408484, 56.76179939700712, 56.21838638859411, 50.436020435825476, 51.995950975725734, 58.51200019159625, 55.43744640965616, 55.234095050442605, 54.52236921556535, 53.87910442967569, 55.92936262007683, 55.063836728372884, 57.30448284456807, 55.67269840548116, 54.17385093627438, 47.29282517586985, 40.78436182391259, 44.37972399496263, 41.95869591928298, 42.32606118725192, 42.13234316918158, 42.80398238089777, 42.305857058494325, 42.27818081455846, 44.36576035714919, 41.988121540315696, 39.765224149150235, 41.29536428759175, 43.70068719310146, 41.339518408621515, 40.40393898564, 39.272597989728375, 40.866857113376746, 42.49127926365022, 40.68092892246862, 42.171398208987334, 40.92796764066143, 42.73618813483946, 44.14173418475736, 46.46046684634301, 48.44564899321526, 48.86964151936193, 50.65475140848468, 49.703003975652884, 53.610877067812034, 55.64202547073365, 56.257570866615545, 53.635105548366425, 51.16219236004738, 54.075940732033025, 55.74419536898213, 62.138325552786554, 54.59533314551077, 46.155129940279075, 45.09923573463194, 45.84518424926266, 52.89661345943328, 56.61537731847456, 57.98232332352669, 61.51983837927542, 60.048435734164336, 62.54169033419702, 63.20320983086864, 65.25151468092396, 65.93717636600618, 28.31679051922214, 1.9534392630861652, 4.7143727060287235, 3.484006327006125, 0.4866452497099677, 0.2354649835897069, 25.35258281615473, 78.13105644718294, 63.06294979587678, 58.934914065945534, 54.50835458693966, 48.12273986877934, 62.29393774463285, 70.13088826210269, 62.998175774851155, 7.083812298313265, 0.13134649474053614, 0.2192389655617937, 0.10996832857809721, 0.1262620534567583, 0.27358142779238764, 0.0935243355530885, 0.19344231834815395, 0.16955336796179896, 0.2527895717010383, 0.11824322729221276], [0.06520987908926702, 0.015610682800592435, 0.06219262264729027, 0.050311280759952726, 0.09269868429269522, 0.05730615763534462, 0.02523749304424611, 0.062085228611625014, 0.05681747397888572, 0.014788207932255201, 0.03164038696746913, 0.030383594829829472, 0.041100823981387, 2.204152138963823, 39.542606107650265, 51.99640204829555, 48.519644506516, 34.14171026599023, 27.72880369617093, 36.74927057758455, 48.99560451507569, 54.80240683401785, 41.45100785839943, 1.3855504196497703, 0.11915054352533434, 1.1088258556781279, 19.7118575726786, 8.913066502540342, 3.810357821564521, 44.23425505238195, 57.478028112842196, 54.48540479906144, 48.91921243359966, 46.540863667764974, 40.60215988466817, 40.51673850705547, 42.92824699032692, 48.80572649740404, 51.14791101024997, 53.6435817903088, 51.92295174444876, 52.81906427875642, 49.142505122769265, 45.99362242606379, 43.965086321676935, 41.56591369259743, 38.378321124661355, 37.222559452056885, 38.717335501024806, 38.71911233471286, 40.38588823810701, 40.53107477003529, 40.59695097707933, 39.34511084710398, 39.33035096814556, 37.656510876071074, 36.87086405292634, 36.599640000251036, 36.38319969177246, 38.63350268333189, 37.35185254004694, 35.46614170074463, 37.06907318484399, 37.627501026276626, 38.21306774693151, 38.71085966787031, 37.667352307227354, 37.87731678255143, 38.940922367957334, 39.876254681617986, 37.1419115989439, 37.31880657134518, 38.529202938079834, 38.373218121067175, 41.57176979126469, 37.64052721761888, 39.5706549767525, 42.33924427340108, 43.68746880562075, 46.2387901736844, 48.79028412603563, 45.47742282190631, 42.650849127000384, 40.413046729180124, 38.06809694536271, 47.62606582333965, 52.45871220865558, 54.07807842377694, 49.93642030223724, 45.61879681002709, 55.72967475460422, 51.27228152367377, 51.27119894950621, 49.29432046028876, 51.6177874226724, 51.270414475471746, 52.247880889523415, 51.698627471923835, 52.249198805901315, 47.24104596722511, 38.890237500590665, 39.119598096416844, 39.46192295320573, 38.754778446689734, 37.00270275915823, 37.897744486408854, 40.51949201091644, 38.45459945740239, 38.43881583982898, 38.46295410586942, 37.94755074285692, 39.166537100268954, 37.38901307505947, 36.73997456027616, 39.25069155231599, 38.515635459653794, 36.27808801589474, 37.41605389502741, 38.66909819264566, 37.9000194611088, 37.16052324541154, 36.310788816021336, 36.81137346452282, 35.6372158758102, 38.34118804624004, 38.743423185040875, 38.928390395256784, 41.317094218346384, 44.53430068108344, 45.85047160425494, 48.000095198231364, 49.159135972299886, 55.176491122091974, 51.05929682331701, 49.644148811217285, 45.77434624395063, 53.705398344224506, 55.99814138104839, 46.92678959138932, 44.44121106978386, 42.91900980857111, 43.41946501885691, 48.094385054803666, 55.67345150055424, 55.110916937551195, 55.5182433128357, 57.212213008634514, 60.647358125255955, 59.48591686064198, 57.64530151121078, 16.26745174008031, 0.796594464730832, 2.727559343461068, 2.076567243183813, 0.18107778182433498, 0.02077443716717103, 23.506170203608853, 65.74415652982651, 51.790014774568625, 51.002763702023415, 24.062578024402743, 30.560464705190352, 45.17054442436465, 54.804650429756414, 41.103097546485166, 2.1831213706924073, 0.07100282912893642, 0.045000728625323505, 0.008151885103284112, 0.01975352733185695, 0.012837824685829542, 0.11575560190624769, 0.03666171601282493, 0.030128050880927234, 0.050475572145754294, 0.12600395077418897, 0.04731783433066261, 0.05230752585996544, 0.05524199884084444, 0.014654722857108761, 0.009701149500606042, 0.038683824241161346, 0.0356416201459304, 0.019010845308883056, 0.02318560889351272, 0.052209439792580185, 0.017132459005581278, 0.03150584277576737, 0.138182649689336, 3.5764016787852015, 48.40032992824432, 55.85573973194246, 54.708266027512096, 35.390985165872884, 27.4123860943702, 42.94596825876544, 53.9291460283341, 57.82536968108147, 44.44585123369771, 1.2127027203959804, 0.08219870618514477, 3.876775560840484, 14.04295108010692, 9.35232489339767, 4.301876156560836, 45.00535772692773, 58.79477562442903, 55.652145185778224, 51.308477155623905, 49.66503543238486, 42.68261640302597, 42.64224344684232, 43.87895107269288, 50.37001086819557, 52.423289283629394, 56.22624289604926, 53.81002756857104, 54.32433266793528, 51.52860449206445, 47.81821881571124, 45.77020814341884, 44.657302287317094, 40.24581255451326, 41.112656362595104, 41.62564746795162, 41.15489636698077, 41.82119331052227, 42.776831734565, 42.03902606041201, 43.49429599700436, 40.51376927283503, 38.71786502099807, 39.35256335043138, 39.03834227592715, 39.89036736949798, 40.84200105359478, 38.63726423632714, 37.58490408620527, 37.93246138480402, 39.603665644122714, 39.07871915448097, 39.655472309358665, 40.313653869013635, 39.75085650720904, 41.701533563675426, 42.20762129752867, 38.61017634791713, 39.87858849187052, 39.080962750219534, 40.33415217553416, 42.88122953907136, 40.02378679090931, 41.085611620256984, 42.87720126490439, 48.29123312427152, 48.59170629132179, 50.09471147291122, 48.06125279395811, 44.443274236494496, 41.41177238956575, 41.477676053201, 50.16149374746507, 54.88028941615936, 57.166556619828754, 51.24357369638259, 48.29886213425667, 56.9589691008291, 52.246790470615515, 53.13334026644307, 49.91034046296151, 53.3040222044914, 52.71291709715321, 53.447871208190925, 52.9254428801998, 53.937841923006125, 49.77508537230953, 41.53618997143161, 41.4366598283091, 41.42486918357111, 39.57085109526111, 38.56315889666158, 41.01216523878036, 42.60509860131049, 39.8229653604569, 39.74485920321557, 41.242659399586344, 38.9689241686175, 40.114064062795336, 39.095883446355025, 38.477796354601466, 40.370842026126006, 39.92937926323184, 38.2060702385441, 39.96493162647371, 40.20634174346924, 40.43567096033404, 37.89293173820742, 39.72742034542946, 38.886170002721975, 38.338956217611994, 41.091491253145286, 40.60825524791595, 40.49006638988372, 44.38860816340293, 47.98004404191048, 48.9230602787387, 50.78703726491621, 52.56269816429385, 55.20068430131482, 51.5714132401251, 49.09376575100807, 48.9718427965718, 58.15101661989766, 57.03636530906924, 49.09503267657373, 45.392123037768954, 45.33453087652884, 46.287878636390936, 51.627938516678356, 58.63290332978772, 57.22072847427861, 58.09692713522143, 59.34539794921876, 61.56569873133014, 63.94223143977504, 60.75201872856387, 18.60140319793455, 1.6007158352482704, 4.625117701868858, 1.5193325377279714, 0.08034608341873654, 0.06303551471641948, 25.121231617466098, 71.63488188097554, 56.659503982913115, 53.57968638020178, 26.260760561112438, 35.80703881479079, 51.99593528624504, 61.0545942860265, 49.19966582329043, 3.5639265804521503, 0.056317076838064584, 0.09488908288579795, 0.00830878278300647, 0.0567740865892941, 0.04164427909399233, 0.06494839029807238, 0.005414455203384522, 0.04384403162065052, 0.031194753621915178, 0.058000493764636986, 0.11688014237029899, 0.2883334007234343, 0.16757831668421147, 0.19234917216723968, 0.09866433353313515, 0.15082847837719227, 0.07466250775201667, 0.10059335824823189, 0.15759878040802094, 0.08843889069412986, 0.18462833888348074, 0.15374875957927397, 0.1408411280041741, 3.9204803253373797, 56.016960913135165, 66.22815347486927, 61.02118353689871, 45.59237964691655, 39.792284580969046, 48.57292598293674, 60.45464031157955, 62.006000472653305, 49.5718163828696, 1.5019469996613841, 0.3143661409135788, 6.543496491447573, 27.508533193219094, 17.00262942621785, 5.212150898671919, 49.292418110755186, 62.35829599442021, 60.25787461188532, 53.06883688895933, 50.37321936699652, 43.79979372024537, 44.97820315822479, 47.23002802941107, 54.7294036803707, 54.58496632114534, 57.0079634266515, 55.60665745888987, 55.98438170648391, 53.793757577096265, 51.269735905431936, 47.98144825043217, 46.84328625279088, 42.41735043064241, 43.03342926886774, 44.55912536190402, 43.193297232351, 45.226057729413434, 44.12054554108651, 43.84521476684078, 42.63162559078586, 42.55899506230509, 41.63670070709721, 42.20944912202897, 40.37540766500658, 41.14019140120476, 43.112382658066295, 41.4074577823762, 39.22326241770099, 41.58965579925045, 41.01899408525036, 41.56865935171805, 42.450608207333474, 42.30759074611049, 40.984896921342425, 43.086997078311065, 44.21864009672596, 41.99174188798474, 41.92785824498823, 41.39504348078082, 41.110357853674124, 46.28942012786866, 40.932215567558046, 43.35432621740526, 45.91062507321758, 50.67289237053164, 50.546595973353234, 52.98620039416898, 50.474177252861764, 47.194138342334384, 45.17639660066174, 43.6477901089576, 51.63484973292197, 57.195719442059925, 59.195163326878706, 53.32629734469999, 50.175018079819225, 58.57407562194332, 54.78476401298277, 57.469759756518954, 52.478590780688876, 54.728662352408136, 54.66099754456551, 55.5600400893919, 53.69437256167012, 55.74208121145926, 50.821024602459325, 44.77921739701302, 42.852647227625695, 44.40154414023123, 41.86984639013968, 40.02413195948447, 42.89968821310228, 45.21167832036173, 41.1438980410176, 41.84809292516401, 42.14228245519823, 41.185879168971894, 42.643467226336085, 41.31469372780093, 40.516307046336514, 43.60152183040496, 42.61102922501103, 40.2126802936677, 42.6213332914537, 41.432972800347116, 44.16215012150426, 41.218426996661776, 41.85691825805172, 40.23548495384955, 39.60586609378938, 43.0578617126711, 43.651347698703894, 42.514695813578946, 44.79626009541173, 49.22855800197971, 49.32767237386396, 53.71709877444852, 55.88328261529246, 57.11160421371461, 52.53627315644295, 50.64027394017866, 50.95313002986293, 58.72033688329882, 57.77543006404754, 51.93835489211544, 49.47333351258309, 48.01484723244944, 46.808530130693995, 53.82508554766255, 60.97930439056889, 59.902943257362615, 60.286711877392186, 63.72874467603622, 64.18887007621028, 67.74268258002498, 62.70484132151451, 19.411511882658928, 2.0988200749120405, 9.24485195067621, 6.017165405135001, 0.5337427724753657, 0.08918437851412643, 29.16062962624335, 75.85303014324558, 65.09875405219294, 64.16193123786681, 34.44050073623657, 43.34542635948428, 59.74393821531727, 71.12491884539205, 58.32371857858474, 5.072593948533458, 0.20900789197654496, 0.19750705830031828, 0.09921533461179464, 0.1858217046866494, 0.10734525884711936, 0.2025131824155969, 0.1582367171443278, 0.1009249977106529, 0.11111900796212497, 0.25658903072678274], [0.07720835582022706, 0.019003908382728696, 0.061513432076260935, 0.07096671574418584, 0.07782797539426435, 0.04497150620145183, 0.03983349238912906, 0.04434191599308003, 0.026415182773264188, 0.02322281778399502, 0.009254006004231352, 0.06810302545707073, 0.06149551711015164, 0.6091381429183869, 32.08982429196758, 54.503584984810125, 45.26282210503855, 41.46680716545352, 22.03456359524881, 33.67645832800096, 44.70834801273961, 52.20235393893335, 52.131853257456136, 6.190176250473146, 0.13844877331247255, 5.952746358609969, 39.49743609274588, 13.390428520018055, 4.014816269759209, 48.349809800424886, 53.07373592930456, 52.98475696194557, 45.168983321036066, 40.39827508311118, 42.1179166916878, 49.70806775554534, 50.450517515982355, 51.42373600313741, 51.96883563072451, 51.55848903040732, 54.1456530171056, 51.50765119060394, 46.89876425650812, 45.023796789107784, 39.33015484963694, 36.74765063870338, 36.07236362272693, 37.735495644231, 36.43308831799415, 36.4684602522081, 35.74409261826546, 36.991088621078, 35.841069298405806, 37.04268740069482, 35.84817271078787, 36.10782184908467, 38.85519896784137, 36.066848770264656, 36.714063382917836, 34.87044742030483, 35.68743398112636, 36.67019559491065, 35.989884022743475, 37.057431590172556, 35.36799223192277, 36.5054952713751, 35.49412388955393, 38.00579009517547, 39.89391711450393, 40.1145935827686, 38.52844592063658, 39.53018396131454, 35.42949499622468, 40.01669514563776, 40.84043210552585, 37.112470288430494, 37.211110053523896, 43.27860093885853, 47.007425677391794, 48.87996912002564, 50.835945298594815, 46.42970761945171, 44.47077789614278, 40.301192498976185, 39.36715848984257, 41.46575204787716, 52.60491855682866, 52.38463432558122, 51.53531958979946, 47.792664574038604, 54.88211724065966, 53.8435834453952, 50.34198945568454, 51.18927632608722, 52.061682055073405, 53.2559770922507, 51.698450965266076, 52.86045705118487, 52.27496877793343, 45.222331477749734, 38.5159610163781, 37.50148703975063, 40.08444624562418, 39.63490732254521, 36.7016294694716, 38.280960052244126, 37.82828323302731, 38.68300299490652, 40.29904304012176, 38.80854629701184, 37.758880815198346, 38.74061084562732, 37.59080333094443, 38.84706004973381, 36.95745037448022, 38.23427600245322, 37.77073814022926, 38.778508786232244, 37.11002665181314, 37.69337723332067, 36.116050981706195, 36.91752064612604, 36.9874329720774, 36.498180051003736, 37.450543295952585, 37.328749779732, 37.863639477760564, 40.33548578139275, 41.47296136425388, 42.6249889404543, 46.72004538197672, 49.820859432220466, 51.95599771315052, 52.91475049911007, 53.753820004001746, 54.08113395014117, 44.480693647938395, 53.06958998403242, 52.791442948002974, 51.47261658022481, 47.52499026636924, 47.18732518534507, 43.628790147842906, 45.73030979402604, 52.9879262370448, 54.76076302989837, 58.27295526381462, 58.867625805639456, 58.89370564491519, 52.474723323698974, 12.140304426993094, 1.956015279696834, 3.5714496864426524, 1.2629933895603305, 0.020417340603026173, 0.1111842863141529, 23.492755697619533, 67.87471740476548, 47.44138102377615, 46.4838049488683, 48.34247889057283, 31.746862050025697, 39.99567908625449, 54.252623896445, 29.688274706563643, 0.4677305082159658, 0.010265662455030028, 0.05222958407454914, 0.06009344597377124, 0.04591442254041472, 0.062092743934162205, 0.043258112254402334, 0.010825991611777535, 0.05958783943506499, 0.020782281907515663, 0.03176376734289431, 0.04476182410613664, 0.037734901772872094, 0.004151849416009481, 0.051311577084444226, 0.10754749839825016, 0.061675926985880064, 0.015257907929950425, 0.03607095880133491, 0.06059634056122554, 0.021606215215738744, 0.044249230845560955, 0.10614306005018373, 0.07427178758887515, 0.9184045284505814, 38.00220897120815, 61.08054860945671, 52.809768261448035, 45.58153429339009, 25.574018263047744, 36.015708907958, 52.03613173577094, 56.05499613669611, 55.88139987760975, 5.259868983299502, 0.0695937559489281, 2.972274302474914, 27.115637217798543, 13.820401680084968, 4.554163006044203, 49.33472871780396, 56.17100415691253, 55.43748563335788, 46.433378957933, 42.0913936245826, 42.627173700640284, 50.58016753965809, 52.49564916856828, 55.10870079840384, 52.37111783796742, 51.911247391854566, 54.03517946120232, 54.233310145716516, 49.218520656708755, 48.21178943880143, 41.010266811616965, 39.615201334799494, 37.896512862174745, 38.61141581689158, 38.36470265542307, 38.8966937218943, 38.37880357619255, 40.042680848029356, 38.41700353930074, 39.38162419103807, 37.6015192462552, 40.40894000760971, 40.31519928286153, 38.55345495285527, 38.27030689485612, 36.85550012896138, 37.43646983177432, 38.58586941995929, 38.36434571973739, 38.47609404594668, 38.46407198136853, 37.64694421522079, 38.05210936454035, 39.741744841298754, 41.48705836265318, 41.35683959530246, 39.56309264706027, 40.602203030740064, 37.901164793199115, 40.99023526714694, 43.29215665017405, 39.2648866099696, 38.95599211415937, 46.27286380337131, 50.177085168900035, 49.172919181085405, 53.85525249665784, 48.258355817487164, 45.897406685736875, 43.269363757102724, 40.81962000939154, 44.326144418408795, 54.145609871033706, 56.240332049708215, 52.162585027756236, 50.11771225160169, 55.5686967603622, 54.20741465783889, 52.12789950832244, 53.10429511531707, 55.290283003161036, 54.08409533962127, 54.72548131019839, 54.44407870692592, 53.50788739419753, 48.64512505069856, 41.2118060358109, 40.46867770533408, 41.85791454007549, 42.245527082873934, 38.38779757099767, 39.044370958882, 40.33872565915508, 39.53258052948983, 41.15099360865932, 39.91422322488601, 39.01245463278986, 39.76410627365112, 38.50341335419686, 40.553977489471436, 38.31486502001363, 39.08519498763546, 39.421640211536044, 39.862083158185406, 38.75722600567726, 40.07007860368298, 37.6231824967169, 38.28307028739683, 37.747325512670706, 38.526884817308, 40.00697943472093, 39.364252013544885, 40.2522962324081, 42.857016747997655, 42.35270977020264, 46.46144351651592, 49.14474479613766, 52.74296245267315, 53.49282157036566, 53.78506560479441, 53.92876163605721, 53.690069721591094, 48.33179827659361, 57.75509257470408, 53.377166563464755, 51.5801836598304, 49.409194915525376, 48.12957655998969, 46.42270226632395, 49.85225408307968, 56.096133955063365, 59.4225666599889, 59.85447452914331, 62.54124710636755, 59.40568085639708, 55.2496668600267, 12.99900637518975, 1.737825716695478, 2.528640017394097, 1.6954304109657965, 0.13587110195188754, 0.05389554185732719, 27.779894528850434, 72.54506003472113, 54.133046519371774, 52.948545640514745, 43.93691585909936, 36.725724589440134, 47.15263966591128, 61.08393753728559, 36.950233213363155, 0.8331013122393239, 0.037376296015516404, 0.07118791597144258, 0.05604125454180664, 0.06664601049476093, 0.057100003374920744, 0.012077294729439723, 0.03314687397270914, 0.03499041476677503, 0.0879113931929873, 0.04192642927650483, 0.18385216924211673, 0.1288761982634183, 0.11555752221254573, 0.11299434523548811, 0.13628026951224576, 0.17073243856430056, 0.08142720201923963, 0.16142050194884502, 0.10830869868157372, 0.08853719509657353, 0.10425340459351579, 0.19539742069619317, 0.14571554628351044, 1.0599547167939525, 44.29751111615089, 67.95628701486896, 59.09441724900277, 53.825599378155125, 36.75647204922092, 45.98789576561221, 59.33719235081827, 61.79991522142964, 61.716435417052246, 7.351625850123744, 0.22547096825174748, 9.631889866244409, 45.02975486939953, 16.82854287085995, 6.392175862866064, 54.369283030110026, 56.53113657428373, 57.86720568133939, 47.814449417975645, 44.14863755626064, 45.994587329126176, 53.12027092902891, 53.76832885126914, 56.606234273602894, 54.05746244615125, 54.51983536443403, 58.01185092618389, 55.18180985604563, 52.59335933193084, 50.39515326100011, 42.824425774235884, 40.32808426887759, 40.233586526686146, 40.81048088689005, 40.3757449888414, 41.65095460030341, 39.39497986147481, 40.52831734380415, 39.107560342358006, 42.565651324487504, 39.5863248455909, 41.27168493886148, 41.96826650250343, 40.18323506078413, 41.61873232933783, 37.326674845910844, 39.6934957658091, 41.648032434525035, 39.21917530798143, 41.415024034438595, 38.4695868338308, 40.151236364918375, 39.43030864961686, 42.095786679175596, 43.957598517017985, 44.50016821584394, 41.39811077425557, 42.569840415831536, 39.75168020494523, 44.20982260857859, 44.985534068076845, 41.292438199443204, 41.880605451522335, 46.50738623834426, 51.404320270784446, 51.53430369592483, 54.68003672938193, 50.6462045638792, 47.66399514290595, 45.22466921037243, 44.23048957701653, 45.158679254593395, 56.56188011169434, 57.26229775336481, 53.837095845130186, 53.60717042799919, 58.657449522326075, 57.135875840340894, 54.682598037104455, 55.3468906494879, 56.24026929178546, 57.01165437698365, 56.11290600992019, 58.00154685974122, 55.31742580475346, 51.116736012120406, 42.75745130354359, 43.28486104165354, 43.27025021276167, 43.07432390028431, 41.47443617543867, 41.93080002261747, 42.09516694468837, 42.27839654491794, 43.80350820479855, 40.129628027639086, 41.12580806978288, 42.373392428121264, 41.3701521196673, 43.99513952193722, 40.61015759744952, 42.92063366982245, 41.70943713957264, 42.79355672097976, 40.928810950248476, 41.60191712840911, 39.14582698575912, 41.360110852026175, 39.08651290401336, 40.14224629248343, 42.10870304415303, 41.27575635910034, 42.99557839670489, 44.97362967460386, 44.33078458232265, 48.166286022432395, 52.09372389701105, 53.673933090702185, 56.799116826826534, 56.10755197463497, 54.24867014731131, 56.17788399419477, 51.29791029037968, 59.44553605971798, 55.83521396883073, 54.63162683671521, 51.72081239761845, 52.33593025515157, 48.67965759769563, 51.36798343350811, 59.13777120651738, 60.69330869182464, 64.66972520274501, 64.48530712435323, 63.52933529884585, 57.159351225822206, 15.075258112722828, 4.489869965660957, 8.910863111096045, 3.9208585889108725, 0.21539092123989137, 0.2009955775593558, 29.449318032110895, 80.43256205897178, 58.33072785408267, 62.86463083759431, 64.17191759232553, 45.81668822996078, 55.4504608338879, 71.10895479879072, 46.92677390190863, 1.4788620125862861, 0.13355791478628112, 0.21568503771578112, 0.15474081279770022, 0.10666151771381979, 0.16147670215897023, 0.21459956773586814, 0.12143194570296234, 0.13004342514661052, 0.24576079160455735, 0.24756348842094023], [0.058122282592399474, 0.04669772446035378, 0.018201787512929692, 0.018696191930963148, 0.0044678716972890884, 0.01211565179419854, 0.028883006701606418, 0.07454521969080934, 0.1399382320983756, 0.05755998171685685, 0.04879405128679449, 0.03724200080239004, 0.034424524769307144, 0.10705855044145739, 23.99990051023422, 54.64217801247874, 42.90420678354079, 39.53829934520107, 24.32348624352486, 32.60268988147859, 44.88964780684441, 48.82929994213966, 54.78520331844207, 11.829328133213906, 0.0468123963312997, 2.8269941239587726, 24.894844178230535, 17.1112516233998, 5.731118715578511, 49.05443614529025, 54.437583261920565, 50.90391605131088, 44.02045842139952, 49.091624136893984, 50.2598471795359, 54.63426659184118, 50.05361680061587, 52.807148118172925, 55.57206607634022, 52.880974969556256, 50.81812989327216, 49.04219835035263, 45.42921297011837, 38.30335286355788, 35.69792239896713, 37.08109917179231, 35.46372944308866, 36.63285855324038, 35.27177256922568, 35.91805758014802, 36.3737585467677, 36.3392024655496, 36.992790929732784, 36.58462124486124, 37.55801231630387, 36.70293169636881, 34.64553086988388, 37.044829014808904, 36.53378732742802, 36.9114488170993, 35.394868312343476, 37.69671909270748, 37.30387803046934, 37.82428241545154, 36.59585491303475, 37.100487447554066, 37.26056329665646, 38.26337214439146, 38.05209367505966, 38.77017767198625, 39.270224955774125, 38.88891173947243, 38.515890413715, 38.87676808141893, 40.75209248450495, 38.48299741744995, 36.287027097517445, 43.01619045196041, 47.650380596037834, 55.56408405303956, 56.51506662368775, 47.04582960374894, 44.966561563553356, 40.58920821835918, 38.45419153090447, 41.69527346088041, 49.17959897748886, 55.68893701799455, 52.52971103114467, 47.66633679789882, 52.0247882412326, 53.555948195918916, 50.78269520113545, 51.3472144834457, 53.53171579299435, 52.32365715888239, 51.623180681659335, 51.73332083609797, 51.65155510748587, 40.95394549831268, 39.254402114499, 40.97993120070427, 37.79462145220849, 40.45661249468404, 37.13539654208768, 37.41653634655861, 39.816265952202585, 38.902734171959665, 39.20068917735931, 37.84683604394236, 39.00038157739947, 37.67334176648048, 37.13023078057074, 37.79124429149013, 37.117330105074, 36.716275599695024, 37.05986345967939, 36.86265845452586, 37.830511139285186, 37.593329337335405, 37.07018321560275, 36.293695126810384, 36.20579088887861, 36.10461727265389, 35.46154860527285, 37.12324896166402, 38.05804783298124, 39.848641195604884, 42.51441732529671, 42.45686438775832, 44.39518597818191, 48.650106460817405, 51.70384422425301, 54.86107764705535, 47.72967915381155, 49.63058133279124, 50.30715096381403, 47.857007134345274, 50.33154026154549, 47.66771747219948, 47.86865265138688, 52.20603312215498, 51.56214467940792, 47.46568795173399, 46.39516330534413, 52.46843576431275, 57.4422247179093, 58.775563855325025, 57.31766200834706, 45.4915786558582, 11.299844441875335, 1.5501770761705216, 2.2030808416105088, 0.35021559305248723, 0.1399215313816263, 0.0748535470976945, 24.58200377802695, 65.35834043256699, 48.61986498678885, 40.052702503819624, 21.142402848889752, 37.454073429107666, 45.69728343717514, 51.85759329026746, 24.426046417605495, 0.518442587025704, 0.01817168791838471, 0.04737071738007569, 0.03876090800810245, 0.010942277055413974, 0.03542321613959728, 0.09463497152131412, 0.04876246931211603, 0.11707951675259298, 0.04235119055656176, 0.04404851197895985, 0.02298933142165263, 0.0624761556185061, 0.024095893717340888, 0.03463347525065465, 0.05541390514061336, 0.0688720321763427, 0.06097130612620424, 0.08653458763634966, 0.12078642469620514, 0.052210968137989124, 0.02255476421616491, 0.048412937866223436, 0.06706582667726664, 0.19364717025910655, 28.140009295555856, 60.41675413808515, 49.913176336596095, 46.04881409675845, 27.16214672211678, 39.28340804192328, 53.12729197163736, 54.18808129525954, 60.65251211966238, 12.450616859620618, 0.06048491690307856, 1.3165696566143346, 25.964527476218443, 14.478307693235337, 4.542630747441323, 54.162938902455, 54.43106820506435, 53.718326476312455, 44.37047112372614, 49.91662409997756, 50.95379683279222, 55.29816696720739, 51.51265613494381, 53.53923105424451, 54.82538800085745, 54.967468015609256, 52.83352605758175, 50.16458457516086, 46.79096183469219, 40.965630239056004, 37.592615465964045, 39.890485040603146, 37.37812065309094, 39.061331287507095, 36.80949857158046, 38.68243817360171, 38.67376973552089, 38.64981974324873, 38.32096038326141, 39.31692077267555, 39.28870324165591, 38.80298045373733, 36.57268155005671, 38.865848202859205, 38.79532006479079, 38.78371769382108, 38.250706811105054, 39.13941391052739, 38.03433710528959, 39.13584847604075, 37.717331147963, 38.86601686477661, 39.94306833513322, 40.166443394076445, 38.37308083811114, 40.778541026576875, 40.20329013947518, 39.29585764485021, 39.11180042451428, 40.91038757754911, 41.267793947650546, 40.74312594629104, 38.72082641047817, 45.553999254780436, 49.0959152098625, 58.841620491397, 59.79218336843676, 49.3977298275117, 47.27025585789835, 43.24287991369925, 41.06365811440253, 42.11155852963848, 51.42975291898174, 57.699795000014774, 54.72150794921383, 50.59679054444837, 53.933809726468986, 53.30921150022938, 52.944780165149325, 51.38570470194663, 53.75019181159235, 53.65546264956075, 52.766696714585834, 54.07468557357789, 53.452989901265795, 42.806610368913226, 39.68472142373362, 42.116806660929036, 39.354716731655984, 41.9815319584262, 39.54537137862175, 39.72676530961068, 41.72241234010266, 40.31172406288886, 40.49146667603524, 38.635452101307536, 41.42267657864479, 39.73118189842471, 38.53518063022245, 38.60044494751961, 39.90302878041422, 39.52613999766689, 39.901110741399954, 37.9312179934594, 39.65407594557732, 38.44260092704527, 40.34006710975401, 38.75866943790067, 38.39494412945163, 38.876650410313765, 36.38216418604697, 37.77653540334394, 40.6986423461668, 42.05323680754631, 43.6716498867158, 45.111685337558875, 47.475874347071496, 49.23297851316391, 53.489448332017474, 56.80301566277781, 50.2398980048395, 51.77829473249374, 53.37740975041544, 48.69533923364455, 53.50965638314524, 49.79680745832382, 49.197979204116336, 55.244183386525805, 53.76249628682291, 49.42761436585457, 48.012321226058475, 54.885302205239576, 59.1473025660361, 60.55590806468841, 59.968799852555804, 46.35611218790854, 12.700371819157755, 1.5742384882703906, 3.711075032910993, 1.702587020493323, 0.025356763357957526, 0.04872793789892908, 26.300862873754195, 72.1180865072435, 53.01091524862474, 50.69769743950137, 32.88780500811915, 42.85411419407014, 50.55460153087493, 59.37261919821463, 30.00953055197193, 0.5463747043282755, 0.028039028702844537, 0.027525581254233277, 0.07481138927922135, 0.02690908157326762, 0.03673533323190866, 0.05143818077481082, 0.07149289557409864, 0.047052434660614505, 0.06034386479446004, 0.05528495722119847, 0.14753995403166742, 0.12830149442438157, 0.20355739089990818, 0.11327955976969774, 0.1419654386418481, 0.0823301132467966, 0.10620397170104327, 0.19118064293457618, 0.26475091615030844, 0.163588285626423, 0.21887158043682578, 0.17558686194881318, 0.1371257854325156, 0.278867342539372, 32.191447019577026, 67.89346633418914, 56.373574964461795, 52.18766074026785, 37.37542206241239, 42.60707547587734, 60.333329246890166, 56.47625477083268, 67.05633840253277, 14.677869062269888, 0.15233025585691776, 5.417786057918303, 30.02779506867932, 22.98970780064983, 7.617492435439941, 55.43932130259853, 56.2119693909922, 57.50902660431401, 49.00316684476791, 53.85799815577846, 54.128112177695, 56.57447484231765, 52.363508439833126, 55.45067656424738, 58.63513515841577, 57.46324862203291, 54.33657830761325, 52.2425425437189, 49.732225633436634, 43.61745842041508, 39.11549137484643, 42.153676940548806, 38.427276226782034, 41.89594584126627, 39.64008092880249, 40.95192547767393, 40.47253339521347, 40.0539105938327, 41.06151650028844, 40.71805807851976, 42.05701797239242, 40.857729757985766, 37.600923045989006, 40.71492018238191, 41.78485255087576, 41.46888994401501, 39.772947296019524, 42.65413215083461, 41.5006572200406, 41.90639503540532, 39.28659692887337, 42.250022119091405, 40.30439707540697, 42.942320454505186, 40.89418426636727, 41.93067842914213, 43.218478848857266, 41.52984749886298, 40.864527225494385, 42.4158638523471, 44.438120242088075, 43.318726785721324, 41.17855610386018, 48.33147664223948, 52.41751555473574, 57.07266292264385, 58.872724886863466, 50.41895028083555, 49.67298999909432, 46.5803893919914, 44.953515760360226, 45.256589458834746, 52.669708267334975, 59.6004226130824, 54.650811149228005, 51.28715122899702, 53.996406832048976, 56.17391063321022, 55.63393754343833, 54.79339714973204, 56.93358352107387, 55.68699544475925, 54.980329467404275, 53.99540270528486, 56.36256879375827, 43.83119229347476, 42.37982119283369, 43.62443631695163, 41.19159013994279, 43.491036507391165, 41.314097527534734, 41.285785859630955, 43.45577047717187, 42.4275956615325, 42.84925045505647, 39.774120084701046, 42.66656998665103, 41.34282496667678, 41.49529141764487, 41.519974893139256, 41.22419680318525, 41.600112838129846, 42.21880005251977, 39.05083894729614, 41.80899081691619, 41.82718669214557, 40.827249019376694, 41.877479322495006, 41.043430451423895, 39.82443624927152, 38.23033009805987, 39.92124034512428, 42.675312949765114, 44.57533651782621, 47.30598472779798, 46.16041729527135, 49.21807742887928, 53.13099076670986, 55.15695379626367, 57.44722966224917, 52.48454493861045, 53.28086453099405, 55.09207779361356, 51.81656137589486, 55.52790803294028, 52.98885583877564, 52.540152380543375, 60.21064143027029, 58.94928955262708, 52.85714657075944, 51.71693317351803, 56.315437593767726, 62.644821213137725, 64.7990143683649, 63.01438693077334, 48.384467863267474, 14.926862101401053, 4.399863337316821, 7.778437089535498, 5.691558180316802, 0.45940484851598745, 0.10622503145808175, 29.861472845077518, 77.62286632291733, 60.151343038005216, 53.87947313247189, 34.91580570897749, 51.74765317670761, 59.68110184515677, 69.6566423293083, 39.02584560455815, 1.183030725486817, 0.10368396377851886, 0.13118054477437852, 0.15408586890947434, 0.11589738945927351, 0.11551695019607583, 0.204660082536359, 0.2276587315023907, 0.22139018641844874, 0.17577973224463003, 0.14822590915906816], [0.035907046629055854, 0.02370919168536221, 0.02153851794108989, 0.09732046209636236, 0.056609446633486986, 0.014114277512435953, 0.036320894986631415, 0.09648073780080003, 0.12969073358803027, 0.0737977170595719, 0.056817535265919664, 0.06834693253040314, 0.10129564637017828, 0.0796125389094795, 14.00367932934915, 53.313859508883574, 42.34605350802022, 44.809070556394516, 32.0354857367854, 29.166034652340798, 43.22335827735163, 47.045731544494636, 56.38356524129068, 21.281505784680768, 0.05516028407240107, 0.7993398787033174, 21.48844022904673, 6.412853617821971, 3.8767206476580713, 47.471061598870065, 53.881348025414255, 53.1296806950723, 50.966140531724506, 52.87327927927817, 54.18529249006703, 56.02284839076381, 54.08422477783696, 53.95870893232284, 50.822648463710664, 51.61347281548285, 48.17752361297608, 45.41779887291693, 39.60306944385652, 38.51987946418024, 37.06585684130269, 37.05941630947975, 37.41038214775824, 36.49457539281538, 36.05697616454094, 34.236878733481134, 35.03742271854032, 36.69280021421371, 37.28429755856914, 35.512500193811235, 34.36293586607903, 35.340649389451556, 36.68746971314953, 36.75894706479965, 36.499533268713186, 37.94087879119381, 35.042266845703125, 36.55312461237754, 37.187987681358095, 36.74666220141996, 36.72696405841459, 36.08987700554633, 35.625542902177386, 38.48311901092529, 37.713114600027765, 38.50013033036263, 38.006762842978205, 38.198966826162035, 36.61498038999496, 39.11072961745724, 37.138997277905865, 36.8109380814337, 38.72368189596361, 45.4129155220524, 50.50201823634487, 49.246330261230476, 46.044970173989576, 47.255315549912, 45.05653289056594, 41.63871680536578, 39.37386574283723, 41.115221592687796, 49.530600117098906, 55.15908364326724, 53.08256126219227, 47.45019066718317, 50.152452684217884, 53.18580981223814, 51.99508020954748, 53.42662765133766, 53.69263102931362, 51.79540803355556, 51.55898717141921, 51.60545549085064, 47.555176827215384, 41.01567968245476, 39.15135360533191, 39.05653815115652, 39.29296685803322, 39.79856429561492, 36.120047876911784, 38.177056466379476, 39.78202758296844, 39.74221552571943, 38.478439623309725, 37.91547359958772, 36.39404896766909, 38.47725506751768, 37.599373709770944, 38.13650700353807, 38.01062245522776, 37.53023016837336, 36.96029409285515, 37.762842409072384, 37.906926754982244, 37.00982578339116, 36.770416075183505, 36.967723061961514, 36.64587689984229, 36.268964582873934, 36.31377373972247, 38.478463157530754, 38.04051876068115, 41.30040061089301, 44.71770678797076, 43.426140892890196, 49.38371127651584, 51.356294770394605, 47.97006553219211, 47.70328160255186, 49.40812803083851, 54.12721787729571, 50.88070346463112, 49.32034930875225, 46.385828064334014, 48.3823380162639, 49.310978766410585, 56.65435783324703, 52.68404060794462, 53.4156136358938, 50.234598882736705, 50.20658139259585, 55.71870388523225, 55.6953618603368, 54.58685298119822, 42.35637718631376, 10.558867531438029, 0.8765711022480842, 1.461115616463846, 0.9687188544100331, 0.29588616963836456, 0.028745888454479077, 25.991111340061313, 67.40454289220995, 50.347653358213364, 43.91925342621342, 29.779846360606534, 35.77463611479729, 44.11376768542875, 52.87543658287295, 23.068070873137444, 0.08320884673946327, 0.0221230085533593, 0.06957369976707044, 0.018104802696935592, 0.09664217550908366, 0.04875565496002955, 0.07836531712523392, 0.01511247379840502, 0.053376019331476385, 0.01107299272271414, 0.040371044794277805, 0.039279162658438574, 0.03895922901950056, 0.04307883235836222, 0.02871735167929963, 0.008784654576541677, 0.06405865195237341, 0.04743393112514769, 0.04495656748692836, 0.024920874650800423, 0.023049342919201143, 0.012813468835496855, 0.03804911273501573, 0.022484582901421576, 0.02136977175400863, 17.33557393473964, 59.298211836045795, 47.73514301546159, 49.711150738500784, 32.38949533431761, 35.80722708855906, 51.393498451479026, 51.417840680768414, 60.78528434999528, 22.832677671986243, 0.06720746101270761, 0.47981821120746676, 27.951172667164958, 8.856483371027055, 4.539813014768786, 50.71901944375808, 55.08427227697065, 54.93713632706673, 51.28511159650741, 55.058145369252856, 56.295221697899606, 57.34716999915339, 54.16777910724763, 55.98147130781605, 53.037187284038914, 53.093218341950454, 49.02384165794619, 49.29920381115329, 40.63952438292965, 39.85050432143673, 38.36008994810043, 39.30796600157215, 39.81304176392094, 38.18849017543178, 37.05085769776375, 36.04740558132049, 36.68572033605268, 38.62148454112392, 37.88584793767622, 38.51618066910775, 37.005977938252116, 38.04892439996043, 37.258323623288064, 38.00191871581539, 37.418791709407685, 39.20219928987565, 37.85803048841415, 39.21446454140448, 39.158978692946896, 39.30424367227862, 37.99423479264782, 38.10085265867172, 37.354645267609634, 39.37186533404935, 40.03299259370373, 40.88275055731497, 39.9771027411184, 39.64008092880249, 38.80579279315087, 40.77530899355489, 40.00803455229729, 39.28172926748953, 40.948261983932994, 45.640593421074655, 51.73496823157034, 57.09858194474251, 50.00101389423494, 48.68769453417871, 47.18821164100401, 41.71202982625654, 41.06159887006206, 44.58569157508112, 51.351176077319735, 56.90288705210532, 52.52513754752375, 50.75709389102075, 53.093018301071666, 52.800978229891875, 53.266563569345784, 54.98334969243696, 53.65846326274257, 54.17658482828448, 55.18542628134451, 54.66828530834567, 50.11340156678231, 41.320875383192494, 42.10275280860163, 40.9306348523786, 39.51490632949337, 41.0454700839135, 37.39214312645697, 39.425633184371456, 41.12652194115424, 41.6046667098999, 39.780784191623816, 41.27648591995239, 39.24816554592502, 39.671212780860166, 38.64602288892193, 39.67911635675738, 40.334348294042776, 39.014341292842744, 39.5999550819397, 39.40770795268398, 38.36971152213312, 39.59342041323262, 37.91357909479449, 39.91519989505891, 40.100802529242735, 38.636703337392504, 37.27345220504269, 39.67997927819529, 40.27357116822274, 42.95967302014751, 46.299732039051676, 48.06124887158794, 50.46962730346188, 52.71328972231958, 51.101870229167325, 50.388602902812345, 50.97158870389385, 54.081310456798924, 53.096764164586226, 50.917432538924686, 48.53922890078638, 50.141677933354536, 51.72791973237069, 58.07886462057791, 57.500193426685954, 55.61079948179184, 52.7183731140629, 52.776694836155066, 57.932917148836204, 59.00501466566517, 59.27277526547832, 43.56496926276915, 12.1647015694649, 2.241559293000929, 3.0353624397708527, 1.5046638538760524, 0.19630403978930366, 0.03081881704049245, 28.443630164669408, 71.19252481768208, 57.213460322349306, 48.499836537145804, 27.92502026404104, 42.017288284917036, 49.381754013799856, 60.738349268513346, 29.282232907510576, 0.12168532928391812, 0.06229599855179268, 0.0574173323149162, 0.07827470424555003, 0.07617138686680025, 0.04015148782561864, 0.04443740885284159, 0.07090638632014876, 0.00837851785153391, 0.018262676181151502, 0.01966805490214498, 0.20825472029466785, 0.17169334264772554, 0.09919111857250815, 0.33696322191146116, 0.17152926193610316, 0.20464921940959271, 0.1773794004393201, 0.17708932890767054, 0.18533998859986184, 0.13538216931685326, 0.11043918153811848, 0.20984260605708246, 0.10985698535918229, 0.1913377675678461, 20.140233347492835, 68.1265414145685, 54.942996348104174, 56.917513570477894, 41.68832302093506, 42.14499673535747, 55.73358143529585, 55.59699666115546, 66.9273316475653, 26.754775239575295, 0.21845700429572215, 2.8620625647806355, 29.13058230953832, 9.194539708475913, 5.485809272335422, 51.68018056500343, 56.8039099631771, 57.72924023289835, 54.5111551592427, 57.93299167386947, 58.36566832757766, 57.577691616550574, 56.5180633144994, 57.761909654063565, 53.223935250313055, 55.7105924237159, 52.224401581671934, 50.68662066613474, 42.97214615729548, 42.66083940382927, 40.36277763305172, 40.70226269383585, 42.17494010925293, 40.66125823605446, 38.4778473454137, 38.13014884148875, 38.39836051387172, 41.298568864022535, 40.213798169166814, 40.013529792908706, 38.28050505730414, 39.581484640798266, 38.91983962828113, 40.195296349064, 39.19553518295288, 41.48617190699424, 38.71820234483288, 40.597919802511896, 40.933588397118356, 39.541197976758404, 40.16312506891067, 40.26413786795832, 39.50669288635254, 40.94110365836851, 40.45922871558897, 42.352246930522305, 41.618779397779896, 42.09725756799021, 41.40621831340175, 43.02911466167819, 41.82368793795186, 40.4554710849639, 42.35241167006954, 49.30980597772906, 54.29915889616936, 54.107390296074655, 52.313482530655406, 49.430038390621064, 49.60913381268902, 45.707752243165054, 43.63474430576448, 45.47305330153435, 53.15400331251083, 60.32660630441482, 57.050293645551136, 52.233246526410504, 53.762680638221006, 55.02051807218983, 57.4005260006074, 55.97088483072097, 57.19244818533621, 56.454426780823745, 57.35131594442553, 55.262881325137236, 52.481999320368615, 43.627758564487586, 43.62275362014771, 42.72947695947463, 42.45766847364364, 44.29990768432618, 38.613773161365145, 40.20790284679782, 44.867011808579974, 43.66114970176451, 41.90725011210288, 42.311258162221606, 40.12268935480426, 42.27767875117641, 41.33795730529293, 41.656951904296875, 41.99355010063418, 40.22494554519653, 42.73140676559941, 42.687519365741366, 41.22667181876398, 41.896330233543154, 41.26882553100586, 42.58983665897001, 40.83044967343731, 40.375568482183645, 40.31844308299404, 42.77378013057094, 42.32757914450861, 44.347195779123616, 50.041822233507716, 50.05209492098901, 53.463882323234316, 54.67540048783826, 52.13739164413945, 52.51393525831161, 52.525678834607525, 55.43964293695266, 55.911970830732784, 54.25168252760365, 49.40710036985336, 53.03026037831461, 52.85393414958831, 61.15994130411456, 56.686568337102095, 59.37899304974464, 56.34060744316348, 55.19257283979847, 62.10635431351201, 61.11141766271284, 60.25158313012893, 45.94927218652541, 13.433699127166504, 3.3842643758943005, 6.2252598904794265, 2.9856755704649034, 0.775958262383938, 0.07963298579617854, 31.5565231538588, 76.11234588007774, 63.77659366976831, 59.10420748495287, 43.89083977668516, 49.943339363221206, 59.10085385845554, 70.56668712246802, 38.04423324523434, 0.3206887258396995, 0.11154324447195377, 0.28456363526563494, 0.11540554569012697, 0.2607961557805538, 0.19853645064417394, 0.18142276653839698, 0.24626017367887884, 0.1588861605212573, 0.06752685839009863, 0.14692262506052373], [0.01768224775010059, 0.007037351183938764, 0.052306254154011134, 0.06325789471907962, 0.055760092612716465, 0.0613775319089332, 0.013152440716963143, 0.03531097276737133, 0.14556255852503164, 0.04616093814312931, 0.07788602953716632, 0.05605572977313592, 0.07075577343423521, 0.048178223847982385, 7.045780506826217, 49.35514073218069, 46.79672379647532, 44.20333108594341, 35.31736227773851, 35.33675839824062, 37.6690310816611, 50.56994192061886, 56.559671817287324, 30.444858727916596, 0.09987952518126658, 0.29505015320835576, 17.961941149926957, 6.188728895879561, 2.3898530775500886, 40.99642868964903, 55.514689645459576, 56.27492735462805, 53.73975046219365, 57.35246127651584, 55.50855898088025, 54.63099533511747, 53.98471032419513, 51.5091573807501, 50.62859704417568, 48.656582293971894, 44.1406084645179, 39.97237236269059, 37.147144040753766, 38.65229475882746, 37.73423656340569, 37.16996046804613, 36.04678192446309, 35.27565963806645, 35.536140318839784, 36.55928665591825, 35.39548412446053, 36.50587574128182, 35.66611589923982, 36.38754960029356, 34.928396517230624, 37.28937310557212, 36.87967369633336, 37.97742351408928, 36.63678484578287, 38.6047830889302, 37.00674280043572, 36.53370888002458, 38.06617498397827, 37.62303344665035, 35.38342283618066, 36.44038784888483, 36.02501669237691, 39.29299039225425, 39.89767866749918, 38.10336689795218, 37.93679168147426, 36.48763279761038, 35.88358386870354, 39.51632230512558, 38.444926892557454, 36.85193469447475, 40.42291541253367, 47.33809325002855, 48.45820057776667, 41.452161035230084, 47.421498529372684, 47.95368571435252, 44.308615346108716, 41.408889447489095, 39.53214906877087, 41.31719227760069, 48.80925270818895, 53.47658295785227, 50.41534954501737, 46.52504082648985, 51.1586033913397, 54.480160590141054, 51.563721472217196, 53.96163502047139, 51.8855558672259, 52.797593224433164, 52.31649491094774, 53.412699314855764, 46.43241405487061, 38.82054090499878, 37.55936945638349, 38.031136451228974, 39.70077960721908, 39.18102633568549, 39.23233485990955, 39.29424555070939, 39.4388045034101, 38.93168126383136, 37.3315974204771, 38.12853674734793, 37.99441522167575, 37.32960093405939, 38.82524382683539, 37.927625102381555, 36.85615908715033, 36.89499447422643, 36.0826833786503, 36.74085709356493, 36.240299901654645, 36.608735976680634, 37.022220473135675, 36.061910506217714, 36.142048451208304, 36.77706449262558, 36.09283447265625, 36.36972242786039, 39.54388087795627, 41.41681655760735, 45.77122403729347, 48.557189433805405, 48.46953230519449, 45.10764529628139, 49.74223552211639, 52.11658347037531, 49.55687215251308, 52.490769740073915, 51.72010244861726, 44.90141099499118, 46.40866018110707, 47.69540156087568, 51.00525440708284, 50.921500036793375, 58.77282996331492, 57.024676645955736, 54.47149607443041, 54.01896830528013, 55.274636668543664, 55.822101485344675, 55.044974050214215, 38.31730865663098, 8.733280743322066, 1.2533812537308664, 2.8601092244348223, 0.6182384094403637, 0.05741222250846125, 0.17851224529647058, 29.54749103515379, 65.91020614870133, 47.655083517874445, 49.07595426805558, 25.265719967503703, 35.76042536766299, 47.00839450282436, 49.55762524758616, 10.245656467253163, 0.07774134617178671, 0.04568391051443835, 0.014028986070996091, 0.06891186108752605, 0.03754049164032744, 0.04200135267549946, 0.06584308140220181, 0.10255283495831875, 0.02911406648044865, 0.0979335239577678, 0.03364641309505509, 0.04417117414695602, 0.04390627626449831, 0.041796795708397706, 0.071674580986221, 0.0790088999295427, 0.0659915722245651, 0.07984107825905085, 0.04783432314833326, 0.11351019820018161, 0.01901462403756957, 0.05944822757174412, 0.05288244803406058, 0.08428013643189784, 0.017114339110952233, 8.762949551305464, 55.82951084260018, 52.02271722978162, 51.14282369613648, 38.16997266584827, 37.703257683784734, 46.2889886671497, 53.606629140915416, 62.35248696419501, 31.851110804465513, 0.15885937808742448, 0.1861881705061082, 20.565732063785678, 8.569070716058055, 2.939976525883521, 44.13348936265515, 57.582147429066325, 59.54046526262837, 55.542605153975956, 56.787353638679754, 56.1351772277586, 57.61316161001883, 55.02853539682204, 53.87235403060914, 52.15017072616085, 51.71324222318588, 46.328808569139056, 41.69053131534208, 38.99279571348621, 40.77171610247704, 39.62764701535625, 39.174166110254106, 38.33925039537492, 37.332377972141394, 38.36588328884494, 38.61729544977988, 37.39288445441954, 38.80746764521445, 36.699640827794234, 38.22241475505214, 37.62411209844774, 38.25333872149068, 37.9431616106341, 39.20369763528147, 39.40671167066021, 41.17620660412697, 39.02160552240188, 39.292884488259595, 38.685882014613, 39.85258709999823, 36.857010241477724, 38.138766288757324, 38.493787857794, 40.692696032985566, 41.5757353075089, 39.30220011741885, 40.23392777289114, 38.774213790893555, 37.31354275057393, 39.98320202673636, 41.102693542357414, 39.36857446547478, 42.26938686063213, 48.34373797139814, 52.1136103137847, 48.14240663282333, 47.69160470654888, 50.341640364739206, 46.666069646035474, 43.935546951909224, 40.918526495656664, 42.89143162388956, 49.46591238821707, 56.01246195454752, 52.29077985209804, 48.00693188944171, 53.30925464630128, 54.173337105781805, 53.41135394188666, 54.833495540003625, 52.63486977546446, 54.92078396581835, 54.54563671542753, 54.464953560982984, 47.34199600835001, 41.195771386546475, 39.027230201228974, 39.42014971087056, 39.97325097360919, 41.560763620561175, 42.06131296773111, 40.07681331326885, 40.78803316239388, 41.08636863770024, 40.44794405660322, 39.23209559532904, 39.2252157580468, 40.29345758499638, 40.653401728599306, 38.64023739291776, 39.00885781934185, 38.97092065503521, 38.28166215650497, 39.02098971028482, 38.23285218208067, 38.73053819902482, 38.92226365304763, 39.34388314524005, 38.570485884143466, 37.74656849522745, 37.74572126327023, 39.19731986138129, 42.10425115400746, 42.300738365419456, 48.63537403845018, 51.101528982962336, 49.92627313060146, 48.73774397757746, 50.77729801977835, 52.85425970631262, 51.53531174505911, 54.877673195254424, 54.319527764474195, 47.88575810770835, 48.90229525104646, 51.00372860508581, 54.00039196014405, 53.87447995524253, 60.58147407347157, 59.2115431447183, 56.72480360154183, 55.85064065071845, 56.982275824393, 59.29603492060016, 56.91138682826873, 40.901605390733295, 9.629471725033177, 1.5743310316916437, 4.261650779554921, 1.3785169970604683, 0.12628176489905005, 0.0654004281386733, 31.84699231578458, 70.98501574608588, 53.032064668593875, 52.80608515585623, 32.04938661667609, 39.661285261954035, 52.45706089081303, 60.27488593132266, 16.232479887623942, 0.027603863948775877, 0.06470679681027128, 0.01582794725113819, 0.04920326864286777, 0.10255410666427306, 0.05001961576542066, 0.04691520150029852, 0.10855784579630821, 0.03603692151485913, 0.021408800103311098, 0.02426344672248008, 0.13476384443140801, 0.1924711333647851, 0.19364110284274627, 0.18554382927475438, 0.16246195251662887, 0.08114061618764555, 0.11725748663828259, 0.22455993649219314, 0.3778571791706547, 0.21413611518519543, 0.1515568134885642, 0.20612945449688744, 0.1882650348688326, 0.16380182497443693, 10.815007129023153, 62.00682809275966, 59.25703871634699, 56.337653898423724, 47.18055909679782, 48.36326353011593, 49.67523359483289, 59.02303403423679, 68.08401507716026, 35.92346260624547, 0.3904144940597396, 1.8029167142606553, 25.933874153321792, 10.611470437818959, 3.7921109555229067, 44.55800356403474, 59.23262980676467, 62.5331356448512, 57.69386437631423, 58.49575765671269, 57.277645987849084, 61.13124916630407, 57.28931111674155, 56.72070472471176, 56.25579795529766, 53.314965617272165, 47.74863596885435, 42.87400061084379, 40.86683750152588, 42.10535334002587, 42.40894871373331, 40.726322512472834, 41.00020593212497, 39.21712390838131, 39.97084656069356, 41.51319311511132, 38.34165873066072, 41.20982523887388, 38.92428367368637, 39.941134606638265, 39.37514835788358, 41.37415293724307, 40.98780339764011, 41.559767338537405, 41.66692649164508, 43.779299336095015, 41.760996695487734, 39.988873774005526, 42.11249597610966, 42.25193231336532, 38.81452398915445, 40.553228316768525, 40.56869029998779, 44.3155030281313, 43.98383917347078, 41.26092587747882, 41.402864686904415, 39.47639649914157, 38.736880671593454, 44.84589376757222, 42.68666036667363, 41.107090519320586, 45.610108760095414, 50.775379980764086, 52.59517538932062, 45.88301550957465, 51.24709206242716, 51.49912003547915, 47.951497031796364, 46.27109873679377, 43.83441255938622, 45.10740995407105, 51.97428380289386, 55.813974334347634, 54.29253009057815, 50.474161563381074, 54.01645406599968, 58.38347981053015, 56.29804972679385, 57.88915526482367, 53.81665637416225, 56.368923033437426, 57.3662954761136, 57.187290268559615, 49.38718649648851, 43.153708750201815, 42.10013266532652, 42.98269341068883, 43.609805876208895, 43.42864336506013, 44.53362995578397, 41.871121160445675, 42.12646745866345, 41.55029089220109, 42.47249111052483, 40.852740503126576, 41.60644746595814, 42.62338469105382, 43.47177766984509, 42.00548587306854, 41.54750600937874, 42.05247586773288, 39.13716247004848, 42.50104988774946, 41.59858311376264, 41.43700891925443, 42.059865613137525, 40.62832993845786, 41.010321724799375, 40.20787931257679, 40.89831452215872, 41.01993153172155, 44.70485318091608, 44.66151099051199, 50.84466864985805, 53.381555695687574, 52.7459159974129, 49.776418978168124, 55.238994090787834, 56.38349856099775, 52.08682837024812, 58.33110047924904, 56.36210203170777, 49.242054877742646, 51.22021990437662, 54.44302751171974, 55.84546704446116, 56.01845533617082, 63.947683534314564, 62.840484726813536, 60.87663242893835, 59.492784930813706, 59.85099538680046, 61.30630846946471, 58.555063893718106, 43.204232800391416, 11.454926133155825, 3.0335897736011015, 8.758825179069273, 3.7061666769366113, 0.2708861466136671, 0.2721584041512782, 35.01383358432401, 76.37761577483147, 59.80426819093766, 63.50746024039484, 38.74809865028628, 48.6130988982416, 61.44992213095389, 68.5684827066237, 24.931469309714533, 0.15210986768286075, 0.12064031640728637, 0.12984350684189028, 0.12772980131088726, 0.2269327099765501, 0.2152695422691684, 0.1740702683286321, 0.2625033673980544, 0.1531067012899345, 0.29985137944740636, 0.11356445254697917], [0.0667293532000434, 0.02366035358018933, 0.04423903421528878, 0.019725484683388667, 0.05063659616655881, 0.02014002060487626, 0.054298718610117515, 0.041236440696182756, 0.09094810443780116, 0.08916954705191237, 0.0587633143239204, 0.045397493222187606, 0.03787322660848018, 0.04130942206228933, 2.889915070226116, 47.400392255475445, 47.166646449796616, 45.22625384792205, 28.95489346596503, 25.326357849182624, 36.497395576969275, 43.20419357668969, 56.667544841766365, 32.67102149225051, 0.9824400407172019, 0.23205742450250735, 10.991075461910619, 5.9748646040116595, 1.0340097089928966, 22.665439574949204, 48.9306971334642, 56.87963131935366, 57.17979069679015, 55.70001771373134, 51.57731640723444, 52.86846260870657, 47.74474890001359, 46.53969480145363, 42.689072624329604, 40.94066043053904, 38.25864568833382, 37.59211340258199, 36.558761058315156, 37.46193778130316, 35.27610286589592, 35.2789818856024, 35.879583051127774, 35.52408295293009, 36.59670998973232, 35.90534910078972, 34.25567865371704, 34.88713710538803, 35.46871477557767, 36.418402964069, 36.59980473979827, 36.391464125725534, 39.08697574369369, 36.63980507081555, 34.05785391407628, 37.20914102369739, 36.82353673442718, 37.51472111671202, 37.85341385872134, 38.872661359848514, 36.36941648298694, 35.57219082309354, 36.515297274435724, 38.30560822640696, 37.64173923000213, 39.53638522855697, 39.14079850719821, 38.34658130522698, 35.69427851707705, 38.10877976878997, 37.666512920010476, 38.62384580796765, 38.899808083811116, 50.717101404743815, 43.87663295192104, 38.32259601162326, 48.507179214108376, 47.647309380192915, 44.038791579584924, 41.03900209549935, 38.42068664489254, 37.967182205569365, 49.63715522520004, 52.444128836354906, 50.94208855782786, 45.75618567005281, 47.15806430385959, 53.3245244333821, 51.32600622792398, 51.18735044233261, 53.540399920555856, 50.543846391862445, 51.78721027989542, 52.611868996774, 43.7419113036125, 38.805216204735544, 38.657793921809045, 38.53144261144823, 38.89445404852591, 40.486618626502256, 37.638275777139974, 39.11367923982682, 38.83246098795245, 39.20969101690477, 37.89093132941954, 37.66876828285956, 38.24994194892145, 37.12639862491239, 38.50016170932401, 37.21054915458926, 38.85867418781404, 37.56562955917851, 38.30962081109324, 37.677550469675374, 37.044201435581336, 35.73193719310146, 36.537976418772054, 35.497344155465406, 36.741763161074736, 36.05901187466037, 36.55848257003292, 37.0012475598243, 40.60645095763668, 44.26785015290783, 45.07443851040256, 41.938813424879505, 47.154294906123994, 49.1433366652458, 52.43440135832756, 49.96183726095384, 51.5185240007216, 53.014539518663966, 53.16118124992617, 47.356763732048776, 44.52604409187071, 46.98808839244228, 51.53236212268953, 54.6812879654669, 41.26652702208489, 52.193932610173384, 58.74711882683539, 53.89001646349507, 57.277410645638746, 55.3836432580025, 54.616219766678356, 37.40091746853244, 7.199067223456598, 0.6922750463408809, 1.1592637362980074, 1.3661980580899025, 0.08275894628417108, 0.26981935385734807, 31.07327538151895, 65.86525578652659, 46.74736861259707, 39.251931021290446, 25.120119625522246, 44.682279940574404, 56.20113972694644, 53.02209400361585, 12.276119435987166, 0.09290045653019222, 0.09328900100362879, 0.01987730990344238, 0.026398451412997903, 0.037530900219515446, 0.013573203018055329, 0.047470596093203754, 0.022958867935343616, 0.01575471211840669, 0.05207196148412843, 0.03342252389918412, 0.014766989211972444, 0.021237860989546584, 0.033605699352319204, 0.038888522934529095, 0.026922723683979244, 0.031967313073936014, 0.03011607884189054, 0.04166706637930005, 0.08994247614135666, 0.006670791039904279, 0.023826895349268472, 0.04289231676187727, 0.15293074621548577, 0.06638022395031107, 3.9748178999270167, 54.06547977078346, 54.84405848287768, 49.53741719645839, 34.900885012842, 31.031094212685865, 42.38461432918426, 51.19033928840391, 61.39431468902096, 36.11363480168004, 0.7237465511406622, 0.19138914142404834, 13.823560168666225, 7.908701454439472, 1.6778592957604317, 24.68610348240022, 50.68445551779963, 59.44872886903825, 57.389923834031634, 58.68161916732789, 53.914472441519464, 55.438050454662694, 50.76340890699818, 49.75042935340635, 45.0433184254554, 45.22192747362199, 40.344409173534764, 38.34213725982174, 40.28292602108371, 39.86278134007608, 36.95098630843624, 37.7207749889743, 37.58818318766933, 37.986523412889056, 36.72348099370157, 38.19034153415311, 36.48001555473574, 36.39924218577724, 37.64266883173297, 38.85471651631017, 36.145845305535104, 36.92271778660436, 38.91153597062634, 38.67839813232422, 35.90829480078913, 38.09570258663547, 39.198837818637976, 39.249240275352236, 39.621347688859515, 39.22443128401233, 38.15337711764921, 37.49439147210891, 39.19921044380435, 38.07699680328369, 38.82975847490373, 41.062846183776855, 40.53616992888912, 40.170102965447214, 38.04727700448806, 38.83404954787224, 41.18414155898556, 40.697685287844756, 41.963826379468365, 52.46488994167697, 48.021436814338934, 44.83566030379265, 49.398247580374445, 50.72731133430235, 46.69424010861305, 42.76044407198506, 42.80150344294887, 41.01749573984454, 51.78963822703208, 55.17502023327736, 52.09073112856958, 47.63770741801108, 50.24771528859293, 55.52048690857426, 52.26683770456622, 53.07393204781317, 53.199616555244695, 53.86130079146355, 53.7440650693832, 54.921866539985906, 45.29557781834757, 41.54770997262771, 40.42838319655388, 41.07239715514645, 39.40164396839757, 41.626125997112645, 39.15226751758207, 39.74214100068615, 39.42702170341246, 40.14017920340262, 40.43118769122709, 40.03780141953499, 39.0510586000258, 39.064504484976496, 39.589207787667554, 38.23769238687331, 40.52848992809173, 39.253911818227465, 40.62112846682149, 39.492435070776175, 39.05030550495271, 37.61348639765094, 39.88134199573148, 37.811330749142556, 39.72407456367247, 38.23804540018882, 37.394684822328635, 39.82178472703503, 41.75441888070876, 46.363560768865774, 47.60305719990885, 45.85147180864888, 48.10705823283042, 51.16367109360234, 54.13251699939851, 53.867780546988214, 53.48770679966096, 55.01046895980836, 53.91298194085398, 49.575781899113814, 47.48635099780175, 50.31746287499705, 54.27539717766547, 55.06075374541744, 42.16997438861478, 53.967832365343654, 62.38881987910118, 57.22925178466305, 60.95033768684634, 57.60192401947514, 56.266662920674975, 40.26241594745267, 8.426536686958807, 1.5492457584027322, 2.9184390364154695, 1.3406684538049083, 0.12150308462761103, 0.20056295238675612, 33.41333004736131, 70.25038719177246, 52.917539304302586, 48.927571004436864, 29.43606434329864, 50.89498481442852, 62.46600035698184, 60.05017334415067, 16.08936632833173, 0.032619855276519255, 0.08516343580859323, 0.05564326037382407, 0.02949910418641183, 0.023276989776340705, 0.05798576189385307, 0.044329869260470715, 0.06121026810198542, 0.03184790486439822, 0.010693688227254297, 0.026725141947428067, 0.10502873153816308, 0.13361708741755257, 0.17944894100148834, 0.1097696666575728, 0.10567137971520425, 0.12288941265714746, 0.18262560118830976, 0.15606219189301615, 0.20390642055821037, 0.21992757135341245, 0.17222977273406523, 0.08219643090400966, 0.2976161187454578, 0.15209684418814798, 4.377122905946547, 58.971478400691865, 62.20351926742062, 56.97256403584635, 41.15486106564922, 36.549241465906945, 50.133162467710434, 53.68328794356316, 69.12094854539441, 38.75712402405278, 1.2835839943539713, 1.0588348801097562, 18.069623939452633, 13.490959848127059, 2.3912815557372187, 26.319892252645186, 50.1853496028531, 61.41224384307862, 58.56694867534023, 59.94881145415768, 55.82393715458532, 57.74197224647769, 53.12788032716321, 50.33815730002619, 46.41879558563233, 45.391248349220525, 41.11692782371275, 42.17346137569797, 42.40167271706366, 41.764236573250066, 39.31695999637727, 40.63326820250481, 39.79416339628158, 40.59684507308468, 39.46272311672088, 40.21526513561126, 38.2959827300041, 38.34657346048663, 38.89119063654254, 41.06358358936925, 40.237183340134166, 40.11182831179711, 42.662808433655776, 41.66010156754525, 37.550230333882, 40.995706973537324, 39.835536556859175, 41.36568454004104, 42.69035523937595, 41.820236252200225, 40.299066574342795, 39.153914913054436, 41.87326669692993, 39.98579863579043, 40.46674397683913, 43.27035219438615, 41.951004151375066, 40.92851677248555, 38.52530802449873, 41.052240094830914, 41.81924389254662, 42.83786773681641, 41.52184194134128, 54.96184333678215, 48.83970206783664, 43.44851016998292, 51.602117553834, 52.41245569721345, 50.06801189914827, 44.61419543912334, 43.68018104184059, 41.813191675370746, 53.62298934690414, 56.352947219725586, 53.86463480611002, 50.05063579928491, 49.68450607792024, 58.05035291179534, 54.45675188495267, 53.83407169772733, 57.55376908086962, 54.75757806531845, 55.59807923532302, 56.96664125688615, 48.0171771203318, 43.620345284861905, 43.782672574443204, 44.5850718405939, 41.85734187403033, 44.29097252507364, 41.484708862919966, 42.576575125417406, 41.73728989016625, 42.55635922954929, 42.98822003026163, 41.62506303479595, 42.556221946593254, 41.66747170109903, 43.6288332939148, 40.7539556103368, 43.62951186395461, 40.80713118276289, 42.214383463705744, 41.060277031313994, 41.45669529514928, 41.22291811050908, 43.586204974882065, 39.61547590071155, 41.39081516573506, 40.62727482088151, 40.34634682439989, 42.55797132369011, 45.677122454489435, 49.56906680137881, 50.040469015798266, 46.44400858109998, 52.190402477018296, 53.65164226101291, 56.81255486703689, 55.39657531246063, 56.005868450287856, 56.14454777010026, 58.19573948460241, 51.780765825702304, 48.6434345091543, 51.728382572051025, 55.15925622755482, 57.226188413558475, 43.79845226964643, 55.03534070907101, 62.87292272813859, 60.20267901882049, 63.49162955437938, 58.51918597375193, 59.07798644035094, 42.886093278085035, 9.760877009361021, 1.9982068673256907, 5.179268688924852, 3.093292905438331, 0.5270306165179899, 0.3400604541022932, 37.01068086008872, 77.52590533225768, 58.70565937411401, 52.59275920929448, 38.73500185628092, 59.71454005087576, 71.28417491912842, 72.94824830947384, 22.40321736181936, 0.14165230786367772, 0.22568159646564917, 0.16402379128961794, 0.15148751317493378, 0.18819332903911992, 0.16939956815012042, 0.2834611734555614, 0.1645904665272082, 0.05854830408709184, 0.12655038596881976, 0.19237102099484016], [0.05444089303754511, 0.0007503786330362933, 0.038750941204207565, 0.017714536440889203, 0.05374511283251548, 0.09414346483085426, 0.023252697128261772, 0.045167119092037605, 0.1667581429524768, 0.07002189184629148, 0.03164226196766381, 0.04188203831173239, 0.07019479789080159, 0.019960217853827823, 0.88352607743394, 30.992580459963893, 48.74103484615203, 47.69578987552274, 40.30438923066662, 33.86410451704456, 36.53650552995744, 37.77658639415618, 54.565107360962905, 42.648711435256466, 2.0296320391278115, 0.06864820426750569, 2.347238486812961, 3.6484806239604954, 0.37701644363903236, 9.115058760489188, 36.13126977797478, 52.58066654205323, 55.11588658055952, 53.5987255650182, 52.58758168066702, 51.001406561943796, 46.01591717812323, 42.35369428511589, 39.87983580558531, 37.67295345183342, 38.476392146079775, 36.21211767196655, 35.82109658948837, 36.29054154119184, 37.849432652996434, 39.43773369635306, 41.714481307614236, 43.41406391512963, 42.10617311539189, 42.97235012054444, 42.98934182813091, 43.14164353955177, 42.65171597080846, 38.20729794040803, 38.121856950944476, 37.453559598615094, 36.50638957177439, 37.350369884121804, 37.40787575321813, 36.99252813093124, 36.01616390289799, 36.97528931402391, 37.09947547604961, 36.767442918592884, 37.341246451101, 36.16660641085717, 37.06905357299313, 43.04698890255344, 37.62295107687674, 38.0232407200721, 39.0434923479634, 37.34941282579976, 37.2699652179595, 37.797351421848425, 37.94535421556042, 38.09991913457071, 40.49071750333233, 48.77379055946104, 45.06220856020528, 36.805340859197806, 50.193021758910156, 48.37252424609277, 46.56604528427125, 43.085075116926625, 39.83307330839096, 39.85306562915925, 52.71751411499516, 55.201892391327895, 51.898891925811775, 48.354120485244266, 47.04357031852969, 51.39907998423423, 50.48028046084989, 51.45086311524915, 50.932270865286554, 53.54830349645307, 51.927419324075025, 51.71592904675392, 42.54590611304007, 37.17422016205327, 37.255075900785386, 38.384130154886556, 38.729196748425885, 39.64974172653691, 40.02497526907152, 39.20321518375028, 40.05193371926585, 37.71774691920127, 36.600267579478604, 36.42354126899473, 37.607485171287294, 36.50485592503702, 38.12921923975791, 37.483098968382805, 37.226340616903, 39.03290194849814, 38.92579770857288, 37.96031805776781, 37.59426286143642, 36.63523158719463, 36.60226798826648, 35.54491466091525, 36.09844346200266, 36.908820829083844, 36.37387229550269, 35.121353595487534, 38.62098247774186, 43.896127131677446, 43.599329225478634, 44.266308661430116, 49.06419500227898, 52.59395160982686, 50.07112626106509, 52.12519307290354, 51.315290312613214, 50.932015911225356, 49.73197852411578, 48.02083669170257, 41.711092379785356, 49.867947486139116, 52.045188488498816, 55.40712648822416, 51.205358043793716, 40.05244754975842, 50.129342079162605, 54.47726588095389, 54.35440548004643, 54.740382394483014, 53.389451426844445, 35.809176506534705, 6.055125123070133, 0.3652457784741156, 2.0955196455601723, 0.7854768741996058, 0.10816625995381225, 0.595387171112722, 32.02026105696155, 65.3760773904862, 42.76033816799041, 42.58279208214053, 28.335119755037372, 45.59191680723622, 52.30211550189603, 49.44316264121763, 10.023398303216505, 0.13725493253479082, 0.07161169282851682, 0.023623770966585127, 0.027089388027126272, 0.09291210872752052, 0.06195277583995654, 0.033830511684138934, 0.12116093443886888, 0.058879487727197914, 0.026872271048505942, 0.0347022278114192, 0.023187828633273323, 0.020979258434606657, 0.03794223963913899, 0.0323606034620635, 0.04908466674087029, 0.032863969193591226, 0.042813440349193356, 0.06918432791867564, 0.03173378266153797, 0.02971511225276176, 0.0034293954658712596, 0.020576997156885844, 0.026810848033956947, 0.11071897983070343, 1.227574141756181, 39.57600116729736, 55.04890034275671, 56.01239919662476, 40.592040169623594, 36.47364170320573, 42.60400426003241, 44.018893395700765, 59.34882217837919, 44.989064201231926, 2.225000026725954, 0.5284494726407913, 4.5007834703691545, 6.767694267534441, 0.7759308670797657, 11.740648246580555, 39.923232909171816, 54.25738565383419, 55.800826549530036, 55.52078500870736, 54.059094152142926, 51.90897241715462, 46.26349718339982, 42.944140434265144, 40.610706729273645, 39.09289460028372, 39.46934015520158, 38.280924750912575, 37.943475400247884, 38.520091272169545, 39.6529737595589, 42.178995840011105, 42.95552707487538, 43.28459432048183, 41.92149223819856, 42.9103962836727, 44.34761155036188, 44.27624794744676, 44.54749161197294, 40.48518696138936, 38.54612796537338, 38.93964759765133, 38.097597091428696, 39.85691739666847, 39.871065385880016, 38.342749149568625, 36.547762732351984, 40.842181482622706, 38.5618096013223, 39.079746815466116, 37.91399878840293, 38.53870684100736, 39.51221166118499, 44.93561798526395, 41.18650674819946, 38.82700889341293, 38.82936231551632, 40.13995562830279, 38.40596206726567, 40.00253146694553, 40.26019588593514, 39.372010461745724, 43.08234906965687, 51.762562105732584, 47.60989781348936, 40.889195011508086, 51.76403691691738, 50.83685921084497, 47.241238163363555, 43.17525040718817, 42.186377740675404, 43.78733235020792, 52.92434069418138, 56.740085155733176, 53.49311967049876, 50.371289560871745, 50.78295407756683, 53.742021514523415, 54.72593238276821, 54.48376524832941, 52.09832875959335, 54.25903304930657, 55.08812012210969, 53.9569164091541, 45.06209873384045, 39.90610391862931, 39.987700985324004, 40.69653603338426, 40.99461263225925, 40.04395954070553, 41.15959144407704, 40.16162280113467, 41.568325950253396, 40.14388976558563, 39.90266792235836, 38.43895704515519, 38.71318171101232, 37.30859664178664, 39.78085479428692, 40.370026173130164, 39.728965759277344, 41.81412912184193, 40.59084776909121, 41.840918910118845, 41.17367275299565, 39.29562622501005, 40.279050719353464, 37.83372748282648, 38.35784242999169, 37.963828579072036, 37.5797853931304, 37.49346971511841, 41.0700241211922, 45.33101643285444, 45.43370408396567, 46.04746480141917, 49.71168025847405, 52.69471337718349, 53.36815687917894, 54.10764917250603, 53.823708795732074, 53.98491428744409, 52.50425484872634, 50.82089124187347, 45.238354359903646, 52.046475025915335, 56.613188635918405, 58.100233693276685, 52.35584805088659, 41.06565067845006, 53.46704767596338, 55.5705951875256, 55.13620838042229, 55.77475847736482, 57.49278799180062, 38.376501144901404, 6.966448608906039, 1.0509994553942834, 3.1730136083018396, 2.1198192190739418, 0.15583189054121896, 0.35994812726013126, 34.85833906358288, 70.57533987106817, 48.889967241594874, 44.66948516907231, 36.46718940427227, 52.833851614306056, 58.15790037955008, 56.52106392768122, 13.735364694749157, 0.05016872711900262, 0.09883062057797948, 0.027887921690219836, 0.07785095037111352, 0.031835367835517374, 0.006311999506226951, 0.016869694677992694, 0.038878314812938054, 0.08740287168972916, 0.05327729358067436, 0.04398547826455005, 0.14856940766255702, 0.12605895588715232, 0.13025005438154744, 0.15530358098687666, 0.1292495895177126, 0.19127363068682535, 0.20200474518201045, 0.16889667739310574, 0.19482093953317214, 0.17651975785772647, 0.13733244531096953, 0.09935942808947257, 0.16559889870545558, 0.2225285164651371, 1.3218902291790133, 45.90459639026273, 62.79181988008561, 59.25823896161972, 52.121549191013465, 45.69101548963978, 48.71284869409377, 50.30318936993999, 65.61231390122445, 51.600791792715754, 2.7066133964446286, 0.9452875955931602, 6.36018991470337, 10.774870495642386, 1.1372735807972572, 11.153227225426706, 41.02127690469065, 55.79095002143614, 57.90195788106611, 58.2928652148093, 56.964778131054295, 56.03842412271808, 49.80564455832205, 45.62481372587143, 43.961360070013235, 41.63941890962663, 42.463779526372115, 39.3059616704141, 39.463644873711374, 41.378491078653646, 41.62227030723326, 45.4361084968813, 46.23491879432432, 47.52639447489093, 45.975497153497514, 45.96078434298116, 48.09916642404372, 49.04714445913992, 46.64424165602654, 43.33745610329413, 40.8361174983363, 41.58104227435204, 39.38401291447301, 41.459715520181966, 42.53076576417492, 39.792323804670765, 38.40853514209871, 42.73447013670399, 42.1278206763729, 40.804530651338645, 40.543438080818426, 39.6988223445031, 40.97324355956047, 45.920368240725615, 43.100584168587964, 40.2429021558454, 43.33838962739514, 41.07916324369369, 40.73395936719833, 41.28655072181456, 41.710096097761586, 41.955554100774954, 46.4920497709705, 53.68066387791788, 49.69001700801235, 41.042089000824966, 51.570871953041326, 54.117192299135276, 49.44064840193718, 46.98582126248268, 43.92605089372204, 46.166112576761556, 56.01681970780896, 59.391897647611565, 55.20655608946278, 52.18922968833677, 50.97767230003111, 55.649772151823974, 55.44311815692533, 55.16253925138905, 53.38389735068045, 57.139331448462706, 54.99752121586954, 55.16446121277348, 47.09364329614947, 40.852968000596576, 41.96904313179755, 42.46482287683795, 43.50156807130383, 42.529459614907545, 45.064460000684186, 42.31035601708197, 45.755569857935754, 41.636841912423414, 42.13377875666465, 40.35580758125552, 40.469736745280606, 39.32381629943848, 42.086463205276, 42.25778448966242, 41.554632955981845, 42.7348074605388, 42.82975235292989, 42.487223532892045, 43.47434682230796, 40.58664298826649, 41.74680948257446, 40.760050973584576, 39.47682403749035, 40.25057823427262, 40.77327328343546, 38.39321044183547, 43.803727857528195, 48.5548242445915, 47.79042490067021, 49.7235885743172, 52.78483375426262, 56.14776803601173, 54.66647317332607, 56.873331992856926, 55.07253654541508, 57.18660777614963, 54.568143275476274, 52.987408484182055, 46.81009515639275, 54.82159506890082, 58.274261413082, 60.49955145005257, 52.22668440111222, 43.23940469372658, 54.41373525127288, 56.759697006594756, 57.16396001077468, 56.728553387426565, 56.95675688405191, 40.18480400885306, 7.6940747518693255, 2.060633594951322, 7.603280707713097, 4.16281734743426, 0.6279771029949188, 0.7393849797306523, 38.5432489456669, 76.59718221233737, 56.44534257150466, 56.40589921705185, 40.125635054803666, 58.770374559587054, 64.7955862168343, 66.47770250997236, 16.40974944637668, 0.28580537186034266, 0.1613830555711062, 0.16427172798543208, 0.21400802528425572, 0.20079329970382875, 0.2337579558333082, 0.14765138918113324, 0.30155757982884684, 0.11339743771860678, 0.252557278520638, 0.16406018046602128], [0.03151631519769228, 0.04986437187800485, 0.05185923801975385, 0.0284427838520177, 0.056230118197779504, 0.013240148208194203, 0.05938181540958824, 0.03603055915464798, 0.0391330007433651, 0.05947635448988407, 0.027154013289198763, 0.021064060537384886, 0.0301067115017964, 0.03774233282573762, 0.10960271311623436, 17.458387267205026, 52.42579175579933, 41.36537467279742, 42.639850801037205, 26.183207458065404, 32.69090594783906, 45.724959681111, 52.691497033642186, 50.65291181687386, 5.969612060054656, 0.4553915590288178, 1.2458897718498785, 3.988734224150258, 0.4157678674786322, 1.6409425605689327, 16.72957362667207, 43.62809196595223, 55.152188116504306, 55.90789941049392, 51.34663397266019, 51.410615674911014, 50.797113833888886, 51.561320981671734, 50.574366354173236, 49.199069623024236, 43.96103451328893, 42.3282184908467, 42.163643683156664, 43.614873578471524, 47.2580494419221, 50.32840628777781, 48.81144923548545, 51.72739805713777, 51.61650480762605, 49.9315800974446, 51.61448870935748, 48.429214262193256, 49.47424742483324, 47.98874385895268, 44.39934761293473, 43.04554154795986, 39.94462551609163, 37.64358666635329, 36.5922345653657, 37.116886877244525, 38.22939657395886, 37.66678748592254, 37.75014961919477, 37.94532283659905, 37.38989560834823, 37.19695421957201, 37.868256107453384, 40.47594977963356, 37.5274609750317, 38.86940971497567, 39.734649273657034, 37.329416582661295, 37.33021674617645, 38.34780900709091, 38.55546320638349, 37.83224874927152, 41.52505044014224, 48.33273964543497, 48.416705823713734, 39.02202913838048, 47.282477963355284, 48.0655477892968, 45.02950776007868, 42.60925239132297, 39.05448282918623, 39.14561125539964, 49.61782970736104, 54.46103511318084, 47.959267247107725, 46.6350240861216, 47.29362926175518, 52.86869795091691, 54.24847402880269, 53.96551816694198, 53.911409070414884, 51.266598009294086, 50.9899297068196, 48.230577591926824, 40.43150148084087, 38.41822339642433, 39.05549480069069, 36.294354084999334, 39.36001193138861, 38.45153216392764, 39.534726065974084, 40.907779201384514, 39.02766950668828, 37.53629415265976, 37.46591506465789, 37.2090978776255, 35.64186780683456, 37.59866768313993, 37.97721562847015, 38.18778022643059, 37.517898236551595, 36.607021900915335, 38.45137134675057, 37.43686599116172, 36.888848120166415, 37.757096136769945, 37.2693415611021, 36.156004244281405, 34.634234443787605, 36.24476748128092, 36.01066081754623, 36.036987766142815, 37.24530135431598, 40.992694593244984, 45.680844783782966, 48.200143921759825, 46.3484674884427, 50.909929044785045, 48.74372166972007, 51.33915401274159, 49.40279752977433, 50.05956703616727, 51.905987493453495, 48.762317626707016, 42.12118010367117, 43.98747128825034, 54.352632568728545, 55.656922632648104, 57.43368179567399, 57.72741633076822, 53.83116914379982, 55.90582447667276, 53.633713106955256, 55.97154771128009, 55.95585430822065, 33.0841725872409, 5.362883662023853, 1.5700171599465034, 2.5775951195147733, 0.5188182152567372, 0.05076337605714799, 0.7570303135341214, 36.41066020534885, 65.23535451581402, 50.102030615652765, 39.7616312580724, 19.14017604243371, 35.371173274132516, 55.824399994265654, 43.74568854608844, 2.5285498028801334, 0.03769047250370345, 0.06944583969250803, 0.013069368057673978, 0.031202772647262584, 0.04987659481083674, 0.041109331387786135, 0.06129022469864257, 0.051260885046494585, 0.028479144300123858, 0.05891154084594981, 0.0384863191134026, 0.056646134584180774, 0.10769143099746398, 0.0600037026038814, 0.047481972498879324, 0.09022261917350755, 0.01909869644159992, 0.03336411735583698, 0.09629594973258435, 0.06443982282953878, 0.01026557339730883, 0.0014493896343347227, 0.031111952923839132, 0.07538457626416799, 0.028046917493244814, 0.07683889459698431, 22.34506626282969, 58.67798313017815, 47.769091129302986, 48.214052646390854, 37.04767665555401, 38.945986147849794, 49.68912270761306, 57.946645444439305, 53.23378432181574, 5.878431172140184, 0.4379795756070845, 1.5940025761242838, 6.209557662087103, 1.2299026813237899, 2.752698059043577, 19.919090117177657, 44.109621740156605, 57.23197390956264, 56.03595695187969, 53.64904172958867, 51.581301535329516, 52.796577330558534, 52.494354786411414, 50.98045326048329, 49.328947144169966, 43.982078029263405, 42.61490060437111, 44.88650598833638, 43.72361344675864, 48.715555129512666, 51.999159474526685, 49.83372872875583, 53.490660344400716, 52.0590893683895, 51.68676622452275, 51.50550957648985, 49.835395736079064, 51.595869218149495, 49.2990743729376, 46.89262182481828, 43.88324999040173, 40.14832204388034, 39.15618596538421, 38.963064147580056, 39.37115930741833, 38.5608603877406, 38.90114168966971, 40.321055381528794, 39.02708115116243, 38.78626723443308, 38.44045539056101, 39.35874500582295, 42.9517262981784, 40.94693622281475, 41.33925953219014, 40.537307416239095, 39.838890183356504, 38.42933154875232, 41.434400543089836, 40.28479699165591, 40.00033493964903, 42.76231504255726, 50.806488298600726, 49.50776407795568, 42.3998527373037, 51.7926113836227, 50.57041652740971, 46.32558830322758, 45.06659377005793, 40.6279847698827, 42.00636840635731, 51.52421143747146, 56.87581093080583, 50.84113459433279, 47.86537354992282, 51.16592253408125, 55.212482790793146, 55.8103108406067, 55.1489443163718, 53.952978349501095, 51.84215876363939, 54.451542977363836, 50.36579039789016, 41.948670341122536, 39.9355609186234, 40.703537464141846, 38.53858524753202, 40.598617984402566, 39.479204916184955, 40.67454330382809, 42.919358899516446, 41.0202217871143, 40.12039084588328, 40.21680662708898, 38.763050725383145, 38.154510682629, 39.61983757634317, 40.3683905447683, 39.966555487725046, 39.15050245100452, 38.94554684239049, 39.585461924152995, 39.76149005274619, 39.90154612448908, 38.744133134042066, 38.79306077957153, 39.827550611188336, 39.039848466073316, 39.170282963783514, 38.43793330654022, 36.66306864830756, 39.15360504581083, 42.733807256144864, 47.74585893077236, 49.4143489099318, 49.15067934220838, 54.367949424251435, 49.474710264513575, 53.24001696801955, 52.82450460618543, 53.85953572488601, 53.54423992095455, 48.883232532009, 45.23713450278006, 46.262120431469334, 57.858925557905636, 56.89926670443628, 59.994295258675855, 58.25437891867853, 55.386616414593114, 56.28459207473263, 53.832600808912716, 57.19770808373728, 57.78767570372551, 35.48977790340301, 5.935905171978859, 1.7018941092875697, 2.117261588573456, 2.2827128008488686, 0.011375896227095398, 0.5869784674817516, 38.733566268797844, 70.30220170174876, 56.08300185972645, 46.23046690417875, 19.538992835629372, 44.359280601624526, 61.34434369302566, 51.740526230104514, 4.1940732444486315, 0.09239000448536488, 0.05534542071062231, 0.08567302217406612, 0.016193449715032213, 0.05475563643079612, 0.05142719507397664, 0.03644459137332536, 0.017583977821613514, 0.03139706595139879, 0.16611009385556946, 0.0372251698506936, 0.17517760245790406, 0.2367257344866953, 0.16744431258449632, 0.21842801552866736, 0.20963441400278002, 0.19329611812868427, 0.11662425368183083, 0.13138447737982198, 0.19184418232931247, 0.16870130965065572, 0.13159197995499258, 0.1312243343601304, 0.17195813327787385, 0.1881355353661122, 0.23306026423890747, 25.989010910834036, 68.35036754608154, 54.5673038882594, 54.49693264499788, 36.874605994070734, 47.68683118204917, 57.30166658278435, 62.726135869180005, 59.2917360028913, 7.737634143521709, 0.83427882002246, 4.31234545284702, 8.572321380338362, 2.2683816859799046, 2.78670133121552, 17.378565073013306, 46.273813016953014, 57.29456709277246, 58.098127380494155, 55.29437403525076, 55.64832479723039, 55.99412095162177, 56.98259745874713, 54.35346411120508, 53.896696259898526, 47.13340436258624, 47.1801511702999, 46.3884364404986, 47.67853536913472, 50.86582983693769, 55.56158942560996, 51.050098865262925, 56.59716575376449, 55.44940963868172, 54.193678517495435, 54.5159286837424, 53.233450920351096, 55.00121216620169, 52.29886385702318, 47.785619997209125, 47.59685201029624, 42.9089803080405, 41.32850047080748, 41.42232748769945, 40.895274685275176, 41.30993981515208, 41.06811000454811, 43.313682617679724, 42.59981516868838, 39.80013716605402, 40.37125779736427, 41.76977888230355, 42.53511567269602, 41.24294965497909, 43.898104006244296, 43.965000029533144, 41.2145124712298, 40.75380656027025, 43.80823858322636, 41.46448119994133, 42.86503407262987, 45.64611219590711, 51.98929079117314, 50.67141363697667, 44.80632097490373, 52.39278893316946, 52.4063564115955, 48.92217774544993, 46.94592291308988, 43.34328866774037, 43.67381503505092, 53.54488318966281, 57.480648256117306, 51.53422524852138, 49.57313037687733, 51.07993633516374, 54.76260654387936, 58.06995299554641, 57.01759676779471, 58.87244639858123, 54.87591205104705, 55.038215806407315, 51.709967044092, 43.749489322785415, 42.74748456093573, 43.739404909072384, 40.04310446400797, 41.90737170557822, 40.959028890056, 44.17438791644189, 46.031775320729906, 43.01472740788614, 43.171414329159646, 42.71674102352512, 41.88424933341242, 40.3983299962936, 41.48592872004355, 42.778220253606, 41.631511411359234, 43.17423451331354, 40.05269858144945, 42.63192369091896, 41.99544068305723, 41.45438501911779, 40.69129182446388, 41.334403637916814, 41.203863236211966, 40.48031930000552, 41.21410062236171, 39.51822073228898, 39.471058153337054, 41.51771560792, 46.0183451252599, 51.25590955057452, 51.40008803336851, 50.84756728141539, 56.145838229886955, 52.97198964703468, 55.04828060826948, 54.81030256517472, 55.19155694592384, 55.72449722597676, 51.895950148182536, 48.36676620667981, 48.71797130953882, 59.6178065576861, 58.80216929220385, 61.887893984394694, 58.58618790103544, 57.09647955433015, 57.566618765554125, 55.1448925079838, 56.980773556617, 59.9251477949081, 38.14217875080724, 8.145178210350776, 4.774330056482746, 6.385807404595037, 2.0561335331970647, 0.114459787164965, 0.932937155087148, 43.68371117499567, 76.64181878489833, 60.690198252277995, 53.35675847145819, 29.970463745055664, 52.52677709825578, 68.6749436778407, 63.39085209754206, 6.8583505384383665, 0.16026996046064362, 0.24596938202458046, 0.21764305119793262, 0.0995036134977014, 0.13603345130480107, 0.10669653559283865, 0.10489905583522013, 0.129658542573452, 0.17262049289720674, 0.346302017569542, 0.13071013614535332], [0.029941881939228025, 0.0556380931107748, 0.045200202599047654, 0.035803168936963045, 0.03416152295446204, 0.05928738741204143, 0.025973037042985522, 0.04344272412239544, 0.03567693296880011, 0.07656033736683669, 0.028267472291425354, 0.01735387373745682, 0.0343717183286865, 0.08612282303792816, 0.015139619166391994, 12.181644247424218, 51.417228791021536, 43.16120832197128, 45.04420488111435, 28.235379765110633, 29.563278575097364, 41.96350866748441, 48.94327617460682, 54.8305106163025, 13.803088338144365, 0.2309072967017851, 0.6192729958603459, 3.241719315128942, 0.7766093758325424, 0.8339155717722831, 6.419897704355179, 28.74464265761837, 51.44401465692828, 53.02436897831579, 55.800167591341086, 53.13293233994515, 54.2701372792644, 53.80412832383187, 52.729685229639855, 51.410686277574115, 52.73224653736238, 48.87807461523241, 50.53529562488679, 51.37085460847425, 50.10405848103185, 51.14260012103666, 50.70677772645028, 50.480182401595584, 49.65389590109549, 49.75952140746578, 48.672146258815644, 50.959280306293124, 51.11453556245374, 50.76514259461434, 51.07064031785535, 46.06032625321419, 45.79993578695482, 42.48372085632817, 38.44771962012015, 38.34955053944742, 37.49641933748799, 36.58936731276974, 36.17968751538184, 37.34612587959536, 35.979509353637695, 35.66153457087856, 37.762426637834125, 39.26360007255308, 38.44219300054735, 37.48547592470723, 38.43533669748614, 36.90374135971069, 37.04886905608639, 37.6942087757972, 36.87797923241892, 38.18332833628501, 42.9959745560923, 47.742383710799686, 51.277408061488984, 45.05280663890224, 45.70908584902364, 49.54509327488561, 45.67934643837714, 43.543525665037095, 40.630365648577296, 41.238631125419374, 49.100182748609974, 54.84611772721814, 53.4684754187061, 49.22031710224767, 43.78668908149966, 48.23259761256557, 54.0133906948951, 52.270787531329745, 52.58813865723149, 51.53938316529798, 53.83134565045757, 47.46173812497047, 38.98536282200968, 37.78753765167729, 36.43367275114983, 38.39530498750749, 40.141359836824485, 39.17298155446207, 37.57143858940371, 37.80738876711938, 38.56718324845837, 38.167532951601096, 37.20841538521552, 37.36516898678195, 38.694675968539336, 36.92772665331441, 38.13897025200629, 38.557671500790505, 38.22812180365286, 39.168568888018214, 37.781434443689164, 38.53000310159499, 37.138051986694336, 38.354500570604884, 37.547971048662745, 37.05512523651123, 36.05505812552668, 35.87800233594833, 36.046805458684126, 34.99508073253017, 35.411714892233576, 38.0567495284542, 42.01792370888495, 45.48853097423431, 50.020519841101866, 48.474501948202814, 48.79969781444919, 52.28131125050207, 50.394035385501006, 53.65989492785547, 52.054817907271854, 50.83673369499945, 45.6437470066932, 38.43779994595436, 43.58369858034196, 51.80027961730958, 49.9347258383228, 51.94377168532341, 55.92759363112911, 55.252004592649406, 60.13354332216325, 54.92488676501859, 53.57835669671336, 28.422316005153043, 4.280822344364659, 0.5378453878145064, 2.2194572273762, 4.864475928967999, 0.07269130989668832, 1.5224188301832446, 39.83827829360962, 52.97710441773938, 42.497045147803526, 34.9017204776887, 31.320386663559947, 39.250154187602384, 55.219672495319, 34.68929275389641, 1.2976466720142674, 0.05930170942578585, 0.028172052210016597, 0.04317832419708852, 0.023759519831547816, 0.06384262281860556, 0.04928969102160585, 0.01965240755629155, 0.03244039151937731, 0.047657663272994186, 0.0640876253976697, 0.01809634700147135, 0.02222655108198524, 0.10379947451574188, 0.05904892722385065, 0.07022234641255871, 0.01198478865497295, 0.051429232867855224, 0.06848580128843747, 0.08887496326238879, 0.12499044709388288, 0.031040019182969007, 0.02485291690625731, 0.04859904743610852, 0.042401744698685025, 0.07896202300945598, 0.09834277578779767, 15.956578408518146, 59.04046504728256, 50.26245163333032, 48.107650510726444, 28.938548949456987, 38.69409545775383, 49.84670785165603, 53.2643513525686, 60.279561396568056, 13.40945201535379, 0.22441559020550023, 0.2907316236486358, 3.6065708341137057, 2.680280319144649, 1.8013101359528882, 8.067816813145916, 30.15851393822701, 53.3098037781254, 53.730430910664225, 56.264364411753995, 53.26469652114376, 55.74224202863632, 54.04529917624689, 54.80648609899706, 51.52432910857662, 54.70614402524887, 50.271151450372514, 52.24192280923167, 53.35738605068576, 54.14878699087328, 53.135576017441295, 52.89582114065848, 52.398331242222945, 51.47321670286117, 52.520469927018695, 52.02758489116546, 53.55939595930038, 51.89079615377611, 52.571601944585005, 52.17061804186914, 47.43110049155451, 46.98369141547911, 42.07717111033779, 39.198775060715214, 38.861035454657774, 38.804980862525206, 39.03250186674057, 39.07203935807751, 39.252487997854914, 37.87754035765125, 37.60087597754694, 38.882514353721376, 39.602182988197576, 39.337560284522276, 39.84342836564587, 42.035817561611054, 39.16500737590175, 39.62674879258679, 37.89937619240054, 39.3764348953001, 38.98211902187717, 44.96446701788133, 49.109894537156634, 52.53037783407396, 46.559832249918294, 48.97471789390811, 50.17948958181566, 47.69667240881151, 44.657549396637954, 42.69004537213234, 42.11300588423207, 51.36217440328291, 56.475215342737016, 53.795401050198464, 49.726196950481786, 47.66315575568907, 52.53292737468597, 53.81991586377544, 53.36010033084501, 55.17516536097373, 54.02681304562477, 54.641181730454974, 49.762227842884684, 40.50764645299604, 40.18347432536464, 39.66725903172647, 39.89967123154671, 41.836176764580514, 40.99793095742503, 39.51779711631037, 39.48385684720932, 39.971587888656124, 39.156825311722294, 39.398105990502145, 39.25315872315438, 41.37869504190261, 39.64780015330161, 39.792967073379025, 39.71124449083882, 40.22476903853878, 41.25421862448416, 39.132781182566, 40.658822444177446, 39.27874042141823, 39.11776634954637, 38.89818030018961, 38.37574804982832, 38.431410404943655, 37.41141373111356, 36.161856420578495, 37.31821821581933, 37.57137190911078, 40.658092883325395, 46.486715347536155, 47.710902767796675, 51.81586319400419, 50.97172206447971, 51.80234278402021, 53.48097601244527, 52.0138212942308, 55.652698239972516, 53.969919066275324, 51.047867036634884, 46.232953686867994, 40.93635759046001, 45.81672745366251, 54.59340333938599, 53.52676968420706, 54.49023715911373, 57.11623261051794, 57.902785501172474, 60.88355541229249, 57.000879626120295, 58.22754206195955, 30.078674093369518, 4.628622829914093, 0.6500266456315595, 3.559260185687773, 3.839812615225392, 0.04099470931255529, 1.4041578985991017, 44.20798301696778, 62.404372076834406, 51.02972607458792, 39.88619396763463, 33.65041379005679, 45.80583110932381, 62.35300863942793, 43.6430440410491, 2.1180298828309585, 0.027352071915482803, 0.06192793543901175, 0.013708119720010268, 0.08533995778810594, 0.056564967568603255, 0.03363681784380348, 0.027353431721548402, 0.027440495698923068, 0.05313792686548926, 0.022181974340891166, 0.04913635852356111, 0.10267358573694384, 0.3058963341097678, 0.16786714715342368, 0.13030266930018702, 0.12807800359423124, 0.15609134919941425, 0.1532962314424015, 0.14180433035137194, 0.2855396925682022, 0.1557254656067779, 0.15147638957827322, 0.1698501810671822, 0.10745166845980192, 0.17426388939061474, 0.21327601295084725, 18.399636476270615, 67.33794104668402, 57.60169652200515, 57.2676557110202, 39.91823580957229, 42.71388553803967, 53.62704900003249, 58.57305972806869, 66.33271601892287, 17.352487194922663, 0.5585580763797606, 2.8662629329389144, 7.33104762531096, 3.3068333566188817, 1.7582436146274691, 8.90499524531826, 30.91987736763493, 55.48199669007332, 55.78267382037256, 59.417373441880756, 57.7621449962739, 59.06365409974129, 56.64142577878891, 57.59976671588037, 55.015073822390654, 56.3393718965592, 52.044709959337794, 54.331349788173554, 55.29712753911173, 55.93486962779876, 54.19227430897375, 54.87826939552061, 54.43035433369299, 52.64385592552924, 53.46230160805487, 52.78284119021509, 55.808655600393976, 56.086939919379454, 54.21998585424116, 55.37734393150576, 49.84144403088478, 50.208570034273215, 45.13647079467774, 41.6951322555542, 41.13460594607938, 40.92364911110171, 40.880444203653646, 40.86056170925018, 41.6767284947057, 38.99565119897166, 39.8530303278277, 41.116559120916556, 42.53582954406739, 41.44958403802688, 41.04094366873465, 43.597681830006266, 41.3392085413779, 42.4483528444844, 40.256446100050404, 40.544351993068574, 41.97723696308751, 47.59824052933724, 51.268080665219216, 56.220006327475275, 49.635437227064564, 50.805048788747484, 52.918053134795166, 49.28212581142303, 46.748325670919115, 45.019780282051336, 44.927698719886045, 53.22349986722393, 60.36424144621819, 58.157692493930945, 52.70797491073609, 46.657310993440696, 50.263087057298236, 57.06043297244657, 56.35524572864656, 58.63754349370157, 56.64424988531298, 58.403260323309134, 51.01961812665386, 44.11285769554877, 43.168221519839385, 41.823727161653586, 41.03389516953499, 44.00216840928601, 43.13251618416079, 41.477613295278246, 42.22592699912287, 43.123651627571356, 43.0108795627471, 41.24937057495117, 40.48908971971081, 43.721589503749726, 42.57388045710903, 43.74257026180145, 42.456111292685236, 41.54773742921891, 43.20437400571762, 41.26098079066123, 42.39902903956752, 41.66794238551971, 42.05597069955642, 38.90097302775229, 41.51438943801388, 41.626482932798325, 39.1066974209201, 40.09253809528966, 38.9340699872663, 39.33950185775757, 42.49298941704535, 48.31783856115034, 49.967587455626465, 54.3771787612669, 53.74470441572128, 52.853145753183675, 55.047986430506555, 54.58615479930755, 59.55058497767295, 58.404990088555124, 55.10206414807228, 48.7544140508098, 42.70753522073069, 47.14581866418162, 56.240528168216834, 55.0132106965588, 57.04488861945368, 59.21970167467671, 59.37404301858718, 64.23637782373737, 58.70433753536594, 58.53300056149883, 33.32248795417048, 5.7902886502204405, 1.3932523612053165, 8.684139328618205, 12.28841704706992, 0.13930308392211316, 1.7527481288679185, 47.86915863713911, 68.0694709285613, 58.6807954695917, 46.9870371972361, 43.670029947834635, 52.23104215437367, 68.2152654278663, 53.365701475451075, 3.3473808582751983, 0.1764364841003572, 0.14669898867366776, 0.1040360424667597, 0.12160687421959256, 0.1540823142615057, 0.167597989822107, 0.1750348802776106, 0.07716325622412466, 0.1250996605883683, 0.2267364688938664, 0.133816791217654], [0.02064384407393875, 0.024188310734086463, 0.054842893845371665, 0.035693694972583366, 0.047283854500781146, 0.023694909891233813, 0.022841840344030532, 0.03046517744810591, 0.01989779509453764, 0.0752657943315083, 0.03910715293679987, 0.057668425292978366, 0.011535982747802572, 0.12623966836761083, 0.04992191657243718, 6.242030474447436, 45.856798387342884, 43.62247513186547, 48.666756922198886, 38.11628718529978, 23.915167508586762, 42.15772874893681, 49.069764767923665, 57.072866885892815, 24.710500624872026, 0.14119525980805198, 0.5656078013200914, 2.298588594121318, 2.1864696039307505, 1.6284108330165188, 2.225295920525828, 15.12360034450408, 51.39301599994783, 51.473369675297896, 52.47260132143575, 49.006387110679384, 54.25589123079854, 50.65192730196061, 51.84335508654195, 52.117218894343225, 52.529385474420366, 50.58074412807342, 52.17489342535696, 49.488815107653224, 51.59834423372823, 49.734559443689164, 52.167044762642156, 49.41312905280821, 51.90822324445171, 48.639068911152506, 47.798940366314305, 45.77085533449727, 51.576563312161355, 47.99362328744704, 48.912391431870006, 48.146642792609434, 48.46165618588848, 44.007710718339496, 43.43199306918729, 36.201237017108554, 38.04492750475484, 37.51897296597881, 36.83331912563693, 37.80389393529585, 36.881878068370206, 37.72264203717632, 37.212090646066976, 37.339634356960175, 36.84229350859119, 37.753742510272616, 39.75991325993692, 38.03065399969778, 36.86369788262152, 38.41070813517417, 39.02911686128186, 38.21263236384238, 42.462528290287146, 49.47340411524619, 48.977694972868896, 49.35571732059602, 47.482291344673406, 47.01991842639062, 45.34102239916402, 43.68758255435575, 42.292752419748616, 37.37518672020205, 46.39671656393236, 54.81568797942131, 54.57640770942935, 50.09446044122019, 43.7246960209262, 48.44594709334835, 50.451282378165956, 51.62641271468132, 53.76948987284015, 51.44387737397225, 51.95294610915646, 45.593171965691354, 37.64967418486072, 36.401019019465295, 37.86532609693466, 38.37306122626028, 39.72795378777289, 39.43025765880462, 41.135174689754365, 38.80212537703976, 38.34204704530778, 39.57789959446077, 38.0103910353876, 37.68244166528025, 38.024076184918805, 36.75741734043245, 38.09944845015003, 37.97118302314512, 37.714240320267216, 39.58096296556535, 38.81640280446699, 37.81237017723822, 37.08942244129796, 38.4565959438201, 36.872091754790276, 38.191180921369984, 36.21564780512164, 37.316688491452126, 38.15629928342758, 37.02798635728898, 36.112720889429895, 35.47577111951767, 40.55336952209473, 46.148712942677165, 47.450378940951445, 50.3884538527458, 51.700984816397394, 48.7721392416185, 49.11184787750245, 48.0890820103307, 52.83540879526446, 55.242061384262584, 49.22989945257864, 43.44520361192765, 42.16320437769736, 40.12188526891893, 45.147037659921956, 44.335624787115286, 46.72334409529164, 49.23499853380265, 56.911453508561664, 57.649161123460345, 53.78927038561914, 20.497096469325406, 1.3880527692456401, 0.5935051688744176, 0.8558141644443236, 1.342281896260477, 0.08217429862387719, 1.1038986232972916, 38.26822411629462, 51.12028967949652, 42.97614697487124, 31.13757283456864, 16.312807086975344, 37.99885142234064, 54.936661720275886, 31.148382886763546, 0.1987743669099385, 0.01731273673114277, 0.029757948059047905, 0.028770686720588037, 0.034288601619341684, 0.11332589276735822, 0.09893467063985525, 0.024614585037793846, 0.04619875990395104, 0.04029959177358016, 0.05828220727703264, 0.029099246509553447, 0.03086725677994471, 0.025481967022642497, 0.049013148602699085, 0.04399625712164468, 0.03289159432414078, 0.037110800584477764, 0.03548747559468593, 0.04500688031135548, 0.05278107544948017, 0.07193163412833406, 0.023158343824287577, 0.05665618948818696, 0.01582809376545371, 0.13603786397124493, 0.028453537811254783, 8.149814451894454, 51.41743667664067, 52.07670473283338, 53.30294747506419, 36.726112904087195, 31.1176158151319, 48.42071840840001, 54.97649731174592, 62.020250443489324, 26.6149329370068, 0.04011063618705638, 0.3015558025048625, 2.3374828167500037, 4.839165854838587, 2.849817905695208, 4.2145744927467845, 17.479240548226144, 51.59863841149115, 53.64329153491605, 54.8580103535806, 52.53877562861289, 56.18250846862794, 53.54606382308468, 54.89182510683614, 53.22896765124414, 54.54422073979532, 51.6223491391828, 53.898159303972804, 51.29164234284432, 54.001113676255756, 50.965716915745894, 52.803743500863355, 51.16787979679724, 51.33466289889429, 50.582195405037176, 49.88836734525619, 49.111926324905895, 53.109884492812625, 51.29495674563993, 50.31321887047061, 49.64706313225531, 48.81117466957339, 46.49299506218203, 45.23712665803971, 39.11596205926711, 37.79588837777415, 38.60579113806448, 39.003947011886105, 38.23977516543481, 38.507269044076246, 38.634012591454294, 40.12766292018276, 39.5102269418778, 37.89014293301491, 39.16207344301286, 40.68022681820778, 39.73246451347105, 38.61134521422848, 38.857262134552, 40.27848589804865, 38.67316176814418, 44.23093672721617, 51.14123121384652, 50.1312130497348, 51.0719503894929, 50.1275848573254, 48.43445454874347, 48.122006385557114, 45.56867284159507, 44.19738085039201, 41.00098648378926, 46.55998129998484, 54.4789211211666, 57.166144770960656, 48.8660329388034, 45.47531650912377, 52.40696437897221, 52.06131727464738, 53.42639623149749, 54.18932076423399, 53.38179888263826, 55.012041830247455, 47.04533146273705, 39.402047972525324, 39.7472636161312, 40.066073863737046, 39.90538220251761, 41.33137949051396, 41.32578619064824, 41.64753037114298, 42.73133224056613, 39.73139370641401, 40.94347276995259, 40.417749651016734, 40.67447270116499, 39.511297748934844, 39.234962847925004, 39.62736852707402, 39.34268682233749, 39.859584608385646, 40.57990435631045, 40.19586901510916, 39.17625673355595, 38.785620043354655, 39.990858493312714, 37.5977929945915, 39.27142912341703, 39.12864308203421, 40.127349130568966, 39.52435531923848, 37.77819456592683, 37.63514964811264, 38.54939529972692, 43.78489655833091, 47.81891699760191, 48.77828559567852, 52.03467653643701, 52.70707668796663, 49.86916734326271, 51.078441912128085, 52.4230186400875, 54.44454154660625, 57.14442268494637, 51.14502806817332, 46.31209534983481, 44.24544165211339, 42.39115292026151, 47.934536703171275, 46.91594816023304, 50.713736011135964, 53.25088585576704, 56.919455143713186, 60.21571697727327, 56.6309844293902, 23.508158845286218, 2.420109750763063, 1.2914319216243684, 3.2724175001344378, 3.3290908461616886, 0.018968528527165615, 1.156688700279882, 41.59972844585296, 58.29958031254431, 50.671119459213756, 39.316528535658314, 22.53959817271079, 45.36833778504403, 62.31778575528053, 36.96498132521106, 0.6659104675054551, 0.021582757603497277, 0.020258239462911602, 0.028390335557501645, 0.04637386079036421, 0.0438635170670046, 0.0782780826932961, 0.03972265478824416, 0.04241960220820001, 0.05658957431273115, 0.021959136600696275, 0.03867594502686012, 0.13180643860851565, 0.169387249456298, 0.13011951299925006, 0.2863081706868064, 0.16320727945816133, 0.15159534771115551, 0.1568894289554127, 0.1321404069782265, 0.1256154063007524, 0.1351738700102414, 0.11959801548190656, 0.16977746400140947, 0.11976385053487555, 0.20787106346218817, 0.1552131213247776, 9.133332102529465, 59.9732635098119, 57.951101256955056, 57.63442870109313, 48.94060896288965, 37.63847581801876, 54.883964677010816, 60.389791765520656, 67.98721882604784, 30.99860522054857, 0.2697837767341445, 1.7031008509858963, 8.864295751817766, 8.155700948930557, 2.945711276223583, 4.142475445424357, 17.80401868204917, 54.96569902666154, 55.22329676535822, 59.17706158853347, 53.49347268381427, 60.15551251749839, 53.78597559467439, 57.14948254246866, 54.91820304624496, 58.34828046060378, 53.97526917919036, 56.257621857427786, 52.54936210570797, 55.100165720908876, 52.94243851015645, 54.43373149441135, 52.45777476218439, 54.38068143783077, 50.79420343522103, 53.04831504821778, 50.967768315346014, 55.241704448576904, 53.732411707601244, 51.53987738393968, 53.359590422722604, 52.319617117604906, 47.64346545742404, 47.90711149092644, 39.523009946269376, 40.367774732651256, 40.91034050910704, 40.745393076250636, 42.17068433761597, 39.55029787555818, 42.20284385065879, 41.4215979268474, 41.10719642331524, 40.51663260306082, 40.26801709205874, 43.03350379390102, 42.49018884474232, 40.58971028174124, 42.67679560569025, 42.83886009647001, 41.98457571767992, 47.78270567617109, 53.23599261622275, 52.71721601486207, 53.06079995247626, 53.2964010392466, 49.850689057380926, 48.56452426602764, 48.324365385117076, 45.810086880960775, 42.62552238279774, 47.928135395050056, 57.37464227984029, 58.71161745440576, 52.824457537743356, 46.42496939628355, 54.161550383413996, 56.28637283079086, 54.16225641004501, 57.251597527534734, 55.81829286390736, 56.7183473802382, 48.7361514952875, 40.93193707927581, 41.90393570930728, 43.392659541099306, 42.83069372177125, 42.653433968943936, 43.62613078086607, 45.168183157520915, 42.714909276654645, 41.75649773690009, 44.87849258607434, 42.21366566996421, 41.803852511990456, 41.551977511375185, 40.89979325571368, 42.61349639584942, 40.811700744013635, 41.65102520296651, 42.52082647815828, 42.10825981632356, 40.800145441485995, 40.22681651576873, 42.72896705135223, 39.248816659373624, 41.157116428498306, 41.26057286416331, 42.748476920589326, 42.741342129245886, 39.5240415296247, 39.39628208837202, 41.0872943170609, 44.74746581046812, 51.84110756843321, 53.05885053450062, 55.55258366369433, 54.18760668846869, 52.429266975772, 52.30615554317352, 53.577517309496486, 57.96844205548687, 60.10699279846684, 53.855405469094556, 48.57431450197774, 47.58564972108411, 45.65267432120539, 49.400918714461795, 48.67966936480615, 53.84460718401017, 54.05175539755053, 61.69705498603083, 61.96125799609769, 60.25240290549494, 24.815875099551295, 2.262264504548042, 2.3935293189940916, 6.523168317733273, 6.883100203929409, 0.3204463662639741, 1.2112663974685054, 46.49983959813272, 65.59044276514362, 57.74547884541174, 43.15493645206575, 27.657391063628662, 53.64201284223988, 69.93590724083685, 46.566994497852946, 1.5084544569253924, 0.1432367462304331, 0.11573256564236457, 0.127555470342838, 0.19536985685267758, 0.1849187015285415, 0.14942282961020548, 0.1844123327323506, 0.15872974068887774, 0.15835728406185107, 0.1634214316765147, 0.13672274657555167], [0.07738293959729134, 0.03576688701286912, 0.02046153046971848, 0.10428099141966912, 0.00954189418529671, 0.0075033232062724576, 0.044212830177838766, 0.06239533717293413, 0.028839263081130002, 0.00777274196509332, 0.10635062391238828, 0.021984865663633234, 0.04554051034633191, 0.035839741974468195, 0.04167547419426903, 2.8900570109967263, 37.61735385464084, 41.21886630212107, 49.542245634140514, 29.808834637365035, 30.062166798499327, 45.64615926434917, 51.38554388476957, 54.102628538685465, 41.24712697921261, 2.397786806668005, 0.3586902415319797, 1.2141189411763222, 3.036510713638798, 2.714414010124822, 1.4017086235746261, 7.671809907882445, 43.816648144875806, 54.18108378687213, 55.37537097930909, 53.44598847050821, 55.2625322341919, 52.1130141135185, 52.06517296452677, 52.14102375891901, 50.391026927578835, 51.57674374118928, 51.34090338983844, 51.13011521677817, 50.83023040525375, 50.80553516264885, 52.234956679805634, 51.727029354341575, 50.0337343062124, 46.478176347671024, 51.81116811690792, 48.17016916890299, 48.95005403026458, 47.934666141386955, 50.48414791783979, 49.62102251668131, 50.07776291139665, 47.66283412133494, 48.06557132351784, 44.21604348767189, 38.33341783092868, 36.236322618299916, 38.09866789848574, 36.19545544347456, 38.213624723495975, 36.33321300629647, 37.67726805902297, 37.54641779007451, 38.655012961356874, 38.997169156228345, 38.61110594964797, 38.512885878163004, 37.98371499584567, 38.17073752803188, 38.007582618344216, 37.26117518640334, 42.72587230128627, 47.459796551735174, 48.85896875012306, 49.19602978614069, 47.108277659262384, 47.24050075777116, 47.05228582505257, 44.68567279077346, 43.61671317008234, 41.75223019815261, 44.12326374361592, 53.40167353230139, 53.75551054554602, 50.879817008972175, 42.15841124134679, 47.06349203663488, 52.27837731761318, 53.21769868173907, 53.46564346744169, 51.5146133976598, 49.976820715012096, 42.55679461263841, 38.43753714715281, 36.303999193253055, 36.810369337758715, 39.06690105315178, 39.890198707580566, 39.65278548579062, 39.23549236789827, 38.92112224332748, 38.97077552733883, 38.716429433514996, 38.2361626625061, 38.492262055796964, 37.93565811649446, 36.993732298574145, 38.460310428373276, 36.97639934478268, 37.05814153917375, 37.8358494850897, 38.9912385325278, 38.987237714952045, 37.999612362154075, 37.40100768304641, 37.15392189641153, 37.81958341598511, 36.09690981526529, 37.776351051945845, 37.14624581798431, 34.85245943069458, 36.823297469846665, 34.58325147628784, 35.34044542620259, 41.483657667713786, 47.942667776538485, 50.495283526758996, 49.746965900544204, 48.663944582785334, 50.68408681500343, 49.17110312369562, 50.83707101883427, 54.204053186601215, 52.75600825586627, 52.38361058696624, 50.06899249169135, 45.28562284285023, 44.0708726452243, 43.1222709532707, 48.09537741445726, 50.338875093767726, 54.057580117256414, 56.19066699858635, 50.310743854891875, 15.265124363283958, 1.5201342947060064, 0.18327999349323013, 1.5998494817364601, 2.134156707794436, 0.028416823047483643, 1.2869628711092858, 43.880084637672674, 58.90906564650997, 41.99133788385699, 29.089671988641065, 27.197887359126923, 44.46498455539827, 51.230692632736705, 26.091196498563214, 0.11738352342358521, 0.023129663407622326, 0.018797951389945323, 0.0841270720646266, 0.06958152152477734, 0.07498137652873993, 0.019034461884368813, 0.03161763224089819, 0.0352995848703769, 0.044736746217935316, 0.09140539764156265, 0.04476955776373225, 0.02537548654682694, 0.00791434709343218, 0.029869302769281694, 0.013442980519856417, 0.01837093972661082, 0.06411689378681683, 0.026741392587521867, 0.047239605262274706, 0.00769910894544615, 0.11797514248399005, 0.05872743459598673, 0.0714378904611353, 0.02900001897116102, 0.08227143857267596, 0.0869218527429527, 3.4102978821723693, 45.586539237729966, 49.517338583546305, 54.08548385866227, 33.37211378159062, 35.871024439411784, 48.98422964157597, 55.30941240249142, 59.43898962390039, 43.11456741825227, 1.8823597868604047, 0.39905415787812204, 1.0028162634661122, 3.505713458984129, 4.798940968128943, 3.7613377551878657, 8.990825530021421, 45.50660525598834, 55.298131665875836, 56.6493332770563, 53.926129725671586, 56.85821517821282, 53.20954015178066, 54.77292629980273, 53.26910134284727, 53.01458266473586, 52.44556834620815, 52.90602714784684, 52.2013968806113, 52.28800281401604, 51.02851406220467, 53.32443814123831, 51.65929002146567, 52.041426935503566, 48.44291117883498, 52.36969401759487, 48.043076530579604, 49.84688435831378, 50.21549693999752, 52.70055770874024, 50.40455125993299, 50.84759081563642, 48.79464972403742, 47.69142035515078, 45.62334675942698, 39.7787602486149, 39.54837591417375, 40.53412637402935, 39.32913895576231, 39.257979316096154, 38.331931252633375, 40.900573807377974, 38.79977195493637, 38.7034228540236, 40.6744570116843, 39.602328115893954, 39.96975614178566, 39.68508228178948, 39.23418229626071, 39.59636219086186, 40.08314009635679, 45.418610803542606, 50.94525391055692, 50.76829225786271, 52.520567986273, 48.01942856081071, 48.75134675733505, 49.00828946021296, 48.903499418689364, 46.527810019831506, 43.644322733725275, 45.36674138038389, 55.44247488821707, 54.472543347266416, 51.71011609415854, 45.75244372890842, 47.73155796912409, 53.02883263557188, 55.29029477027155, 54.855813826284106, 53.83275378134943, 53.047546263664, 43.94386237667453, 39.484041198607414, 38.81418666531963, 39.33224155056862, 41.14410592663673, 42.64806816654821, 40.40780644262991, 41.30151456402194, 39.79938799335111, 40.248048305511475, 39.97466302687123, 40.37950261946648, 40.42932848776541, 41.121893544350904, 38.534384389077466, 40.533228151259884, 38.085312228049006, 37.6532200074965, 39.75062900973905, 39.515133826963364, 40.620991183865456, 39.24144260344967, 40.49915844394315, 39.43312883377075, 39.29710888093518, 39.738501041166245, 39.550999979819025, 37.594149112701416, 36.737687818465695, 38.66279494377875, 37.88799739653064, 38.880717908182454, 44.674807825396144, 48.28898168379261, 53.36131234322825, 53.76770127204157, 51.847351981747536, 52.411843807466575, 51.40092349821522, 51.781836632759344, 54.79356973401962, 55.964405075196304, 55.71670739881454, 52.124028128962365, 48.14681145452684, 44.7046805966285, 46.07024200500981, 49.932482242584236, 52.6846093516196, 57.20108132208548, 57.83879203181113, 52.00588633937221, 17.605772287614887, 1.7053004426340905, 1.8912628317071547, 3.1400509899662388, 2.919233806671635, 0.037008397611639196, 1.3459330100205638, 48.05148216985887, 61.55587711641866, 47.50117755705311, 34.410988823060066, 27.372246519211803, 49.558754890195786, 57.85199080744098, 31.87451754846881, 0.2613513243775214, 0.048494261929825436, 0.0828885070739254, 0.03245723779283224, 0.018145671572476145, 0.03166690893140772, 0.03109082613410729, 0.05799713063864939, 0.00624664550301649, 0.04584653565900461, 0.0580295438187257, 0.04476728631303676, 0.13722082630040186, 0.07747928281464884, 0.09637802073191251, 0.1660411459423842, 0.059937405354914174, 0.16303245819384055, 0.17852753641143923, 0.12445403999018094, 0.23048400248010315, 0.2248607638982996, 0.16286108432517898, 0.12223034721588898, 0.2165138529193017, 0.12675985738995577, 0.09730870264672464, 4.171466173664216, 53.25246657094648, 58.47177628547915, 59.75658393675282, 39.27208808160598, 44.84117123388475, 56.28779272879324, 61.41921389487482, 64.6027389649422, 49.34765684989191, 3.4011678301518966, 1.2769093460613683, 4.690861038623318, 9.384224549416574, 5.903804004192353, 3.518617076258506, 10.214016668258175, 47.663873549430605, 58.63093822233139, 58.517624870423354, 56.0108773169979, 61.04796940280546, 53.831263280683956, 56.105033812984345, 54.49024500385408, 53.35676631619854, 54.16020501044489, 53.650720504022416, 53.32591687479327, 53.8520989110393, 52.57485358945785, 55.61938947246921, 53.69678874169627, 52.38044131186701, 50.835549139207416, 54.59476832420596, 51.25490150144024, 50.320228145968535, 51.78696317057456, 55.12112294473956, 53.839413965902025, 54.30643489283901, 51.476758603126775, 53.08194152770504, 46.69073743204917, 43.84789374566848, 41.07036536739719, 42.63611670463316, 41.06527413091352, 41.44036254575176, 39.994157206627634, 41.896075279481956, 42.123509991553526, 41.60025012108588, 42.484850498937796, 41.846943670703524, 43.64554259084886, 40.92603783453665, 42.25454068952992, 42.98781210376371, 42.97216184677617, 45.527880191802986, 51.5032777478618, 52.84378305558236, 54.26726610429826, 48.84997475531794, 51.00088096434071, 52.35327497605355, 51.13603799573837, 47.61909184917327, 47.0346430040175, 48.088128874378825, 57.678720105078916, 56.94825318551833, 54.674466963737245, 44.90319959578976, 49.008505190572436, 54.88969525983257, 57.525453490595666, 58.19803407115322, 55.987915762009166, 54.65616518451322, 46.332201419338105, 42.06365070035381, 41.0180684058897, 42.23573684692383, 43.263001672683224, 43.73183865700999, 42.79334491299045, 41.59563349139306, 43.14818605299919, 42.80577098169635, 40.78501685973137, 41.68685605449062, 43.881794791067804, 43.247559301314816, 41.39860891526745, 43.449816319250296, 39.58007258753623, 39.99824823871736, 41.983112673605646, 41.70702488191667, 42.57148388893374, 42.13986235280191, 41.437969899946644, 40.89027758567564, 41.383146932048184, 41.14154854128438, 41.16604766538067, 39.57615021736392, 38.123873049213046, 42.21763903094877, 38.230526216568485, 39.965398388524214, 45.23866422714726, 52.345877385908565, 55.61390599896831, 54.88237219472086, 53.853930657909764, 55.0832877620574, 53.24087988945746, 53.806254248465265, 56.53293694219282, 57.74747925419962, 58.426559202132694, 54.984032184846946, 50.882798010303134, 47.37142162938272, 48.09295338969077, 52.728579121251265, 54.49797991783389, 58.64481556800104, 59.38507272351173, 55.637734397765136, 18.604535210517145, 3.2179958397342316, 3.7567637812706733, 7.3607267295160606, 8.22248028170678, 0.18295334892407542, 1.8260698525174972, 54.10180484094928, 67.49175287062123, 53.32821930608442, 40.51465965086415, 37.861603767641135, 57.38158879741546, 65.909743309021, 38.92546038473807, 0.648108606617297, 0.17776685706790418, 0.21561262708517814, 0.140010213719741, 0.08424656645905587, 0.13067699518174897, 0.12496891236233136, 0.08864152861098129, 0.12358258433279493, 0.11884038516831015, 0.1833456012630655, 0.14761594995375604], [0.009181992781739081, 0.08944925341394641, 0.03215465604537918, 0.04084074479197303, 0.002009000942756933, 0.027961801294417634, 0.013933465440547275, 0.039429354195993756, 0.08656677865092793, 0.023694624523482016, 0.08690489921718837, 0.07269561531082278, 0.011101660690450621, 0.013701416450672814, 0.06336874381128339, 0.8315939576395097, 18.362877984200757, 40.06827039103354, 50.67999578291371, 29.70062625023627, 26.297209185938684, 36.77315388956378, 52.80452013015748, 51.825241581086196, 51.60637724784113, 6.054952048486279, 0.1733763918520943, 0.4437343668072455, 2.4785854258844933, 3.8330698157510454, 2.5200458591984165, 2.0119430076691414, 36.886569223096295, 59.2281190810665, 53.9248392658849, 53.787964236351755, 52.58089796189339, 55.230631597580455, 52.73414888689595, 51.02295214130033, 50.50768213887369, 50.277968529732, 50.22320047501595, 51.49613511177802, 52.560870339793546, 50.80027918661795, 50.462625872704294, 51.41417718702748, 49.10936501718337, 48.89850231908983, 50.32919468418245, 47.083676553541615, 48.85333230418544, 48.32288665156211, 50.30568791973976, 49.42770458036854, 49.20859706017279, 49.11229502770209, 48.8260639867475, 46.7567156207177, 43.33292184337493, 38.35114302173738, 37.618346214294434, 37.740641793897076, 37.419364375452844, 37.22065710252331, 38.37308868285149, 37.89630889892578, 36.742441731114546, 39.395987910609094, 38.35614404370708, 36.91931316929479, 37.53922808554865, 37.58808120604485, 37.19357705885364, 38.19271849047753, 43.89295001183787, 47.66295179244011, 48.57425174405498, 50.04153197811496, 48.69130311473724, 49.277532715951246, 48.355850250490256, 45.54873935637936, 43.49204455652545, 42.040826428321104, 44.52105091464135, 52.09124495906215, 55.46694263335198, 52.63146123578472, 46.062530625251036, 47.20842753687213, 48.01796551673643, 52.22810037674443, 54.30743509723295, 51.1708882547194, 48.05052118916666, 40.68922865775324, 36.1631311908845, 37.40774631500244, 39.17054184021489, 38.62044119065808, 40.595444786933164, 39.990705520876, 39.70590222266413, 40.38142458085091, 38.093533515930176, 38.30025419112175, 38.13319260074247, 39.7285617551496, 39.07916238231044, 38.60296310917024, 37.20508137056905, 38.860498089944166, 38.753852767329064, 38.206827255987356, 38.341968597904334, 37.92789574592344, 37.64607737141271, 38.86646793734643, 39.583179104712706, 40.96550472321049, 38.9776945883228, 38.199092342007546, 38.164916730696156, 38.23994774972239, 36.113466139762636, 36.98720155223724, 37.70912554956252, 38.46651954035605, 46.417203103342366, 50.505375785212365, 52.48735335565383, 49.18326639359998, 49.21717136136947, 46.59155245750181, 49.33408937146587, 49.66245059044131, 50.97364402586415, 51.47851582496397, 52.60671500236758, 50.96440684410834, 53.32777607825495, 53.55027252627958, 54.292781122269176, 51.18568735737955, 56.54841461489278, 55.38926009208926, 46.18744242575861, 11.887494921684267, 0.007534304759540265, 1.221266725370961, 0.3420940804625711, 0.6410182483734623, 0.05347035539847228, 2.0806200321643584, 50.91185885090982, 47.828267928092714, 37.65207859777635, 32.09312104409741, 31.867816179029404, 42.22850399632608, 51.426356146412516, 19.127616613141953, 0.003987384224010091, 0.02987956068658781, 0.06670884502631041, 0.05871832581056703, 0.019918441164097, 0.020081028004267046, 0.09371584987327938, 0.031038437211405367, 0.02341242263003463, 0.07791142535185622, 0.05223059531060919, 0.025521384161566536, 0.008365784512622463, 0.051154057915893295, 0.07973144341620707, 0.10846618337616806, 0.009904575530409573, 0.04614738604774879, 0.05485616248822021, 0.03972848471734793, 0.034073319421300007, 0.024859093490146825, 0.06995718039932751, 0.014656782676015171, 0.036094312991706595, 0.05602872134336541, 0.09379258890065456, 1.20857834815979, 27.109143733978275, 48.761140915655325, 58.06763487477457, 32.98321470137566, 37.14225284514889, 46.871892098457586, 56.47796884659798, 58.18011668420608, 54.847329739601385, 6.621620789650948, 0.30741061414441756, 0.5406409345807568, 4.7713402298188985, 9.181579216834038, 4.263646775676358, 2.6204376980181667, 38.41835675701019, 60.681353307539425, 55.10972845938898, 55.5016516870068, 54.07130449048935, 57.23617084564702, 54.350651771791526, 53.15296388441517, 50.132138729095466, 51.406587400744044, 51.98788266028128, 53.20541774072955, 52.95173060509467, 53.11690553542107, 53.23009337148359, 55.023608899885616, 50.87768323959843, 51.19235930904266, 50.80579011671005, 48.373128291099306, 50.76939052151096, 49.816458532887125, 51.24435817041705, 50.812536593406435, 51.25788642514137, 49.85551357269288, 49.903994068022705, 48.60131609824396, 44.95845794677735, 38.38218073691092, 39.05044671027891, 40.64962840849354, 38.26137173560358, 39.27812460930117, 39.71462557392736, 39.46675139088785, 40.095864265195786, 39.881338073361306, 40.802930324308335, 40.12158324641567, 39.07679327072636, 39.39560744070238, 39.655480154099, 40.41162683117775, 46.125198333494126, 49.95959366521528, 50.486136559517156, 52.01699841407038, 50.404288461131436, 50.022857573724565, 50.93345149870842, 47.46953971924321, 46.187312987542924, 44.66149922340147, 46.24581121629285, 52.818256270500925, 57.147085974293375, 53.14290300492318, 48.03438455827775, 51.2805381128865, 51.62038795409664, 55.11774186165103, 57.139511877490634, 52.70545282671529, 51.121231048337876, 42.99708458685106, 37.97238719078803, 39.3164030198128, 40.3704027206667, 40.26747972734513, 40.441409387896144, 41.098857464328894, 38.72064598145024, 41.30487211288945, 40.263019992459206, 39.35645041927215, 39.82694264381163, 41.1906958395435, 40.6929039186047, 40.16386247450306, 39.75583007258754, 39.73631628098027, 40.23432785464872, 41.268296011032604, 39.59114543853268, 39.52415527835969, 39.868307959648874, 40.569768951785186, 40.508901611451186, 41.25675247561547, 40.32230661761376, 40.546238653121456, 38.897293844530665, 39.96207221861809, 38.46331888629545, 39.643756189653956, 39.492078135090495, 40.82622135839155, 48.55695801396524, 52.09581059794272, 54.428863833027506, 51.94072008132935, 52.89888843413323, 49.23271963673253, 51.196218921292214, 51.20385969838789, 52.95876341481363, 54.55452872860817, 55.818002608514604, 53.6056956168144, 55.33367618437737, 54.96023124264133, 55.26291270409861, 54.72568135107718, 58.470976121964, 57.231185513158, 48.68085392059819, 12.97776379892903, 0.677475392097427, 2.498327450406167, 4.1158739309157095, 2.2888934756478956, 0.08449134687262197, 2.0202584324344515, 56.323517676322695, 54.16341350924585, 42.89868408633817, 31.51128841984657, 34.286367277945246, 47.234146518092004, 58.57589560170328, 23.94544428394687, 0.05674659169369167, 0.04003553658783917, 0.02566490115808143, 0.04732110935653891, 0.03353371773095381, 0.04915667134487341, 0.03680176071582302, 0.040572633170672966, 0.043402224884278355, 0.10287201017021172, 0.03377213195386914, 0.029192280227078066, 0.08493138011544944, 0.1863422461094395, 0.1392398050595676, 0.2277024904446256, 0.14695092434844664, 0.12947077442321087, 0.19075289008117494, 0.2554839488960082, 0.13308209757651054, 0.1134174862395852, 0.16112574195909887, 0.15532340734235703, 0.17994312899968318, 0.1664745065593912, 0.19278838569598813, 1.3275492287451223, 31.77145923337629, 57.70665130307598, 63.452841235745346, 41.43838567118491, 39.65402887713525, 48.92100103439824, 62.36544255287417, 61.61887038138605, 60.263248259021395, 8.371713719060345, 0.6829271802017767, 2.874763934843002, 9.819666474096238, 11.231050972015629, 6.469952541012918, 3.3910155104052637, 40.93266664012786, 63.04341247004848, 57.11277308002595, 58.435529662716775, 56.71255796186386, 60.23542688738916, 56.83952508434173, 54.707932626047445, 51.25447004072128, 52.950130278064364, 52.40666627883912, 53.75184705180507, 53.75102727643905, 53.47455901484336, 54.12141276944069, 56.753954656662486, 52.61040203032955, 52.23216787461312, 52.936366681129705, 49.650965890576764, 53.23924426109561, 51.87460460970479, 53.91799865230438, 52.66591925774851, 53.40441526905183, 52.40497573729485, 52.906215421615116, 51.92998063179755, 47.034486109210604, 41.38852450155443, 41.99025923205961, 43.75251739255844, 41.65066042254048, 41.542081371430434, 41.7787964113297, 42.080277627514256, 41.23919594672419, 43.06450228537283, 43.10174519015897, 40.242623667563166, 41.65212738898493, 41.09412708590108, 41.86503364193825, 41.6348179694145, 48.18524675984537, 52.2063704459898, 52.76300968662385, 54.285293317610225, 52.471354007720954, 52.00751412299372, 52.48957341717136, 48.28060742347471, 47.79568872144146, 46.188407328821, 48.77090369501422, 55.815770779886556, 58.894690159828436, 55.64892491986675, 46.656310789046756, 49.958534625268754, 52.78690084334343, 56.60978794097901, 59.243102535124756, 54.26963521588234, 52.15345374999508, 45.48578531511369, 40.82489951964348, 41.471231599007886, 43.52097595891645, 43.01740246434366, 43.28678300303798, 44.27061542387932, 42.54223085218861, 44.07279852897891, 43.56043108047978, 42.36792464410105, 41.73790962465348, 44.13198317250898, 42.22819412908247, 42.12597716239191, 41.519919979956846, 42.929078532803445, 43.5996037913907, 42.9694789455783, 41.75284208789949, 41.09182073223976, 42.40568137937977, 42.15179028049592, 43.33777381527809, 44.9639767216098, 43.03814003544469, 42.31267806022398, 42.02760411847023, 42.03946536587131, 40.22654587222684, 42.12472984867711, 41.72848024675923, 43.41186738783314, 50.566827558702045, 54.75010202777002, 58.315367852487874, 53.55134333333662, 55.67281215421615, 50.29912579444147, 52.82252380924841, 52.42971412597164, 53.10078851638302, 55.98740585388676, 57.29813252725909, 55.62714007592971, 58.81263809819376, 58.46330788827712, 58.18380371216805, 58.66003436426963, 62.49567700970558, 59.25629346601425, 51.64217279803369, 14.96179767193333, 1.2839685092049262, 4.490805941243326, 8.060397159668709, 6.7732610914015, 0.3346280939877034, 2.5051717412087227, 64.16521818407121, 59.0150559333063, 50.22177273227323, 43.17678797629572, 43.85080414433634, 56.0507756663907, 66.1788022133612, 29.52269969447967, 0.12547839147549483, 0.17292587086558345, 0.17350072792220503, 0.19455973419450945, 0.1927588453456279, 0.1062143215489003, 0.16509072194176336, 0.164683883288695, 0.20294156346109607, 0.2701413865771986, 0.12347245153280036, 0.08511874223909072], [0.028095539178579088, 0.07183857742817172, 0.015450360707848545, 0.07968989846807334, 0.01591743206635358, 0.03454562411793778, 0.036525482597250136, 0.08967510379490354, 0.025546774230597, 0.10942418398636003, 0.04468167981793804, 0.09536935106640863, 0.010468719805019998, 0.0360453293298281, 0.056886617244491657, 0.12318866958300914, 11.53518763280684, 40.841455844140825, 54.54561710357667, 28.453375293362527, 25.85330866998242, 37.29238548586446, 51.52751015078638, 49.69729300468199, 53.590641560093054, 10.234855240391148, 0.11427638571589224, 0.6710628684489959, 1.5244354187480866, 8.824304246133375, 4.728201022071223, 0.6298171236149727, 26.1401927855707, 56.01269729675786, 52.72163260367609, 50.38197017485096, 50.45491057057535, 53.46184269074471, 54.86785550271311, 54.89222518859371, 52.55910919558618, 54.40802035793182, 53.537638571954545, 51.46870597716301, 50.91522424451767, 50.37227799815517, 49.766114911725445, 48.20671389179845, 48.181708781949936, 48.57826432874126, 50.571569704240375, 49.11817466059039, 46.41999583090506, 45.211239014902425, 47.075208156339585, 49.03347107671922, 48.563229883870775, 48.55848381596227, 47.01376422759026, 50.05959449275848, 48.08676388955886, 41.68271795395882, 38.500420585755386, 38.16856061258624, 36.26604633946573, 36.053508789308616, 36.77178498237364, 37.176612807858376, 38.89377940085627, 37.87247265538862, 37.64880341868247, 37.53885546038228, 38.376356017205026, 38.27387625171293, 38.19911195385841, 36.72313190275623, 43.47250723069714, 45.90954249905002, 47.619978304832216, 50.58902032913701, 50.48211613009053, 51.37630278064359, 49.941362488654356, 48.60012762008175, 46.35308411813552, 42.08270949702109, 44.979066079662694, 51.86613229013259, 52.037006424319365, 51.50022614386774, 45.743743911866225, 47.84654617309571, 48.592679039124526, 52.42228515686528, 51.68249084103493, 53.02769122585174, 48.43279146379041, 41.41798934628887, 38.087363627649125, 38.30174469178723, 36.84236803362447, 42.64936647107525, 42.20485210418701, 39.97784799145114, 39.749997508141306, 38.627791712361, 40.58579575630927, 38.711954009148386, 37.92930779918548, 37.429864560404134, 37.94599748426868, 38.12671676758797, 39.32691104950444, 39.94098555657172, 38.41941579695671, 38.49735329228063, 37.00782537460327, 39.10193174116073, 39.536793155054895, 38.946982429873565, 39.054008222395375, 42.61450052261353, 39.66401915396414, 38.158942960923724, 38.00514682646721, 37.613866867557654, 37.73405221200759, 36.29580143959292, 36.603738877081106, 37.257711733541186, 43.35790341900241, 50.11897917716734, 49.60303452707107, 49.89213282062162, 49.96618716947494, 51.958135404894435, 53.54695027874362, 54.60888101208595, 54.0777999354947, 54.18363724985431, 53.864497523153986, 55.12325279174313, 55.03261858417142, 54.18349212215793, 56.58891308692194, 55.864282654177764, 55.56447236768661, 53.50412976357245, 34.11186102897891, 6.278681591633828, 0.23890776739966488, 1.4437782500059375, 3.6918681667697046, 1.3108171330344294, 0.03537132134360652, 3.961024885216067, 52.42581136765019, 52.319334706952496, 37.93841946509577, 26.341214256901896, 29.95214627635095, 47.22382283979847, 47.964562446840354, 10.655312730420022, 0.13796610727665887, 0.04698166728860909, 0.025042588784990293, 0.03920863277368969, 0.043961618456148335, 0.04145843765488075, 0.018826342608419158, 0.03613536764356879, 0.03494912645809593, 0.0367698991190522, 0.04966818059103624, 0.004963542554422372, 0.05616186742460536, 0.03360481835120628, 0.07089412891336026, 0.06697931236797763, 0.04262783256689868, 0.019175335877544938, 0.03878908089151786, 0.06823748920954044, 0.042393490101300904, 0.04758761985407722, 0.049785529939277526, 0.034598763806805495, 0.03878633446630932, 0.016477880924339258, 0.06608370195833907, 0.08542841029984337, 17.49529088697126, 49.25917602354481, 59.57108720656365, 34.63456392288208, 32.05161648411905, 44.3563231345146, 55.811530697730284, 55.031516398153, 56.458207945669855, 10.682973284875194, 0.09615524236353175, 0.47305393062772294, 5.001334288427907, 7.096982146463088, 3.4368712046454033, 1.0981685307718094, 28.36599273066367, 60.40815238029727, 54.332577490037494, 52.469553639811856, 51.32779875109273, 55.50598590604721, 55.49863538434429, 56.34795404249623, 53.50531824173466, 54.91351581388905, 54.423980482162975, 54.21983680417461, 53.343469481314386, 51.7495398367605, 50.353352562073745, 51.48694892083445, 47.716625505878085, 51.11380600160169, 51.63457516700991, 50.87646338247484, 46.68557951527257, 47.11060754714474, 48.47839293941375, 51.371537100884225, 49.266338271479455, 50.746856504871005, 49.061904338098344, 51.80505706417946, 49.392897467459406, 43.78119776325841, 40.280929534666, 40.76313395654002, 38.189749256257095, 38.63136499158798, 38.89232812389251, 39.36010999064292, 39.72638483970396, 38.222022518034905, 39.47469419048679, 38.61164723673175, 39.264839541527536, 40.727036383844194, 38.578511053516024, 39.228577229284475, 43.84550894460371, 48.24672598992625, 50.987552750495176, 53.54019203493672, 52.829109468767726, 51.74732761998331, 52.12560099940146, 50.39265471120035, 48.42976731638755, 44.91235440777194, 46.31122850602674, 53.92738488412673, 55.81924207748906, 51.44440689394551, 48.746004489160356, 51.592390075806655, 51.237254758034986, 54.810514373164025, 53.07685421359155, 53.27468287560248, 49.81772153608261, 44.22319004612584, 39.6892164599511, 40.89347431736608, 38.87039815225909, 42.81405502750028, 43.101294117589156, 42.2292806256202, 41.47623654334776, 39.80897818842242, 42.489847598537324, 40.65415482367239, 39.28282753113778, 38.74180716852988, 39.562127743997884, 39.270456375614295, 41.083689658872544, 40.36725697978851, 41.48434800486411, 40.078962772123276, 40.35157926620976, 40.974361435059585, 41.015440417874245, 41.19670883301766, 41.21829363607591, 44.38178716167327, 40.60221479785058, 40.37834552026565, 39.86747249480217, 39.01784004703645, 39.008630321871856, 38.24736495171824, 39.32357311248779, 39.35199852912657, 44.96687927553731, 51.62116066102059, 50.91211380497102, 52.05073864229264, 50.35131685195431, 53.33939806107552, 55.371013226047644, 54.932900167280636, 55.042906961133404, 55.782505158455145, 54.46989966977028, 56.776276865313136, 55.995583995696045, 55.15250190611809, 58.1836546621015, 57.129525523031916, 59.31876505574873, 56.88836643772741, 37.844364950733805, 7.068088987181264, 0.47924539194472376, 2.6148713644473784, 4.24734442464767, 1.6402741641767564, 0.03524939078957804, 3.7140334806134625, 59.343224956143295, 55.799426263378514, 45.28956874724358, 30.589584381349628, 32.644718077874955, 52.65954148384833, 56.18940399539087, 14.690687367993018, 0.008959174193742295, 0.035849325734400944, 0.03120484299987795, 0.006362470815093407, 0.016127020315898043, 0.08872004496234079, 0.06169231360658042, 0.006695607979406393, 0.012911415091835925, 0.026584447984914147, 0.027820760677117976, 0.04335062120169882, 0.17440354721921106, 0.14914869270738096, 0.16599245339391694, 0.21797110536886802, 0.11152586193695185, 0.18806373760584863, 0.15477547061539468, 0.2227552938124826, 0.09457802054502311, 0.1573165689384745, 0.1168035948649049, 0.19895862637748643, 0.15656718173094336, 0.16558274957201174, 0.23209266454702426, 0.19006284404425852, 23.573472192210538, 60.239466928666644, 65.49448590124807, 41.014365688447036, 35.52791903095861, 50.1637294984633, 61.65774106979371, 58.58092015789401, 62.90181882919804, 13.316055478588229, 0.3823346260093874, 2.5045321497224995, 7.12448678670391, 16.81899582186053, 10.816495668503547, 1.7070099831588808, 31.87795746710993, 63.93986625056114, 55.89710112540953, 54.40802820267216, 54.80520348395071, 57.56006056262601, 57.83674063221101, 57.24811054045155, 52.62316542287027, 56.91640353971913, 56.32929924995669, 55.689478305078325, 54.967205216807706, 55.248231272543634, 54.392891776177194, 51.55422933640019, 49.69925418976815, 51.58036408885833, 53.565934550377634, 52.52087393114644, 47.245572382403964, 48.96246833185996, 50.67409261580437, 51.79767908588533, 51.77781620333272, 52.30856387845932, 50.38976392438335, 53.8997753204838, 50.44412405260148, 46.98297754410775, 42.17103342856131, 41.579767504046046, 41.10554118310252, 40.38770037312662, 39.91541562541839, 41.96898821861514, 43.04756941333894, 39.970885784395286, 41.08250510308051, 41.36930488771008, 41.26932759438792, 43.79238436298986, 41.161756592412154, 40.97498116954681, 45.91674397068639, 50.51054939146965, 52.701157831376605, 54.71453397504745, 53.751878430766446, 53.72425317764283, 53.679424408943426, 52.902508781802275, 51.4512945759681, 46.77196187357749, 49.47219210286295, 56.56878740556779, 55.746764521445, 55.713773465925655, 48.539075928349654, 50.81745916797269, 52.626511204627256, 56.770965976099816, 53.671493376455004, 56.55914229731406, 53.73806384301955, 45.99645045495803, 41.17918368308775, 43.55124881190639, 39.711793622662945, 45.954477171744074, 44.58786849052676, 44.019944590906945, 43.818130800800944, 43.04785182399135, 45.307976430462254, 40.833650327497914, 41.027313432385846, 41.11220136765511, 41.41238427931263, 42.44503844168879, 44.49541038082492, 44.207924181415194, 44.141730262387185, 41.437110900878906, 42.011800889045965, 44.61083396788567, 42.377491304951334, 42.47785299055038, 41.93172570197813, 46.351154312010735, 44.59439531449349, 42.899998080345895, 42.26156173213836, 41.3420993281949, 43.271089599978545, 39.77856020773611, 41.07753938244235, 41.00839976341494, 46.771663773444395, 54.024808714466715, 54.07590935307165, 52.927470745578894, 52.45572336258427, 55.8098558456667, 58.48029175112325, 57.39736457024851, 58.25072719204811, 56.66099448357859, 56.0787303986088, 57.076969685093054, 56.469743636346635, 54.803363892339895, 59.1903466563071, 58.934235495905725, 59.69794450267669, 57.96167988930979, 40.092298830709154, 7.572816639177262, 0.9709871488232767, 5.70017219551148, 8.407711271316774, 3.639353513717652, 0.19097592891944995, 5.113000735159844, 63.27857032898934, 62.708253783564416, 50.5707577736147, 37.86657341064946, 41.52028476038287, 60.85073694106072, 65.81800691543087, 19.901208031562067, 0.2791101924113689, 0.16918144759631928, 0.1041853070379265, 0.274086800674277, 0.08464498580583642, 0.13151981447252536, 0.13517151045943462, 0.22002924654272296, 0.17263694846582028, 0.12576932868649884, 0.1770291143968221, 0.10894601488666189], [0.04661442388990714, 0.017862831910831795, 0.052999552234166095, 0.09642698907203252, 0.03171627563724835, 0.07297664700496583, 0.050090256732918566, 0.031864569191971136, 0.05668797447616535, 0.08051751857443203, 0.06611142668031877, 0.058706834491702824, 0.03886861613981667, 0.009809822903104849, 0.019933050460813027, 0.14998777348908687, 9.619775625967211, 45.60385257967057, 59.26536198585265, 34.10184329555881, 23.706571940452825, 39.27977200477354, 47.283333040052845, 50.788872934156856, 57.324961539237734, 18.54634096545558, 0.16174808114526734, 0.21803248433336136, 4.255761340741189, 6.384283563783092, 2.128918872725579, 0.6888972114651435, 13.954514380424255, 56.24143031335647, 49.420244232300796, 51.776149196009484, 48.23074233147406, 50.88755192295198, 51.54180719006447, 53.50309425784696, 51.986556899163034, 52.35931150374874, 48.461287483092285, 48.008277262410815, 45.63030896648284, 49.24743244724889, 47.948194396111276, 50.43391412304294, 50.46328875326341, 50.99757048391527, 48.22347417954476, 47.55314896183629, 45.7189388428965, 52.615563869476325, 50.42920727883616, 52.09904263096472, 50.42996821864959, 48.81164535399407, 48.85775281536964, 46.007672356021025, 51.65004107259935, 46.165614435749674, 38.17400486238542, 37.146390945680686, 35.247340125422326, 35.81006296219365, 37.82743992344026, 38.488461279099994, 37.88922117602441, 37.67830356474846, 38.818171793414706, 37.45727016079811, 38.63402043619464, 38.72310530754828, 39.11135327431464, 38.59262766376619, 40.71485350208898, 45.43539462550994, 47.03948320881013, 48.923876131734545, 51.920661080268125, 52.06961308756183, 49.446649628300825, 49.32502085162748, 47.054486274719245, 45.08075744875016, 44.58007474099436, 50.59965779704433, 52.798734634153305, 53.10105523755474, 46.15063098169143, 47.04813595741026, 50.62564742180609, 51.568753873148275, 52.221777516026656, 53.719558100546564, 47.16848996377761, 39.31280620636479, 37.850146524367794, 37.303019031401604, 37.07381533038232, 37.20058633435158, 38.98653953306137, 39.433050386367306, 38.997545703764885, 39.210036185479936, 39.670039992178644, 38.473022830101755, 38.20023767409786, 40.26568720417638, 37.37998377892279, 38.28079139032672, 38.92380122215518, 37.37210765961678, 38.752193604746175, 37.519945713781546, 39.40122035241897, 39.33377519730599, 38.20212825652092, 40.54428139040547, 45.35249140954787, 48.04303730687788, 47.97461940396217, 44.003380421669256, 40.741404025785386, 38.246247076219134, 35.65465473359631, 37.56793199046966, 36.97635619871078, 39.1823991652458, 37.521408757855816, 44.67609828518283, 50.76540147104571, 50.36224065288421, 50.535683939533854, 50.03784102778281, 50.561622573483376, 52.9101848602295, 51.907791783732755, 53.70614359455725, 53.656141219600556, 55.83047574566257, 54.80386595572195, 56.01294048370854, 57.36385576186642, 55.09005385060465, 53.101365104798354, 51.011443907214755, 19.883296528170188, 2.83509528925342, 0.37401947703573013, 1.7246154191032534, 3.3916673592982756, 1.3929417585172963, 0.016078004095282768, 5.567739250198488, 56.71936327411283, 50.29974160655853, 40.07158871619932, 22.59492712636148, 30.162759903938543, 49.84032615538567, 40.65181316867952, 7.559598251696556, 0.12863347096548927, 0.029831963643852263, 0.0797045843735818, 0.027036066392376542, 0.02069565843069746, 0.015197825569268918, 0.07027772690860495, 0.02766098346441023, 0.09938484688680019, 0.0181628089593423, 0.0561735081306148, 0.07530248994308134, 0.031340521001707644, 0.02406618291241748, 0.0802640354020461, 0.029921973229295788, 0.01666526411539845, 0.04865984800421903, 0.026141442320940476, 0.009518027673625659, 0.04582974301170438, 0.08046135666870302, 0.06372970911944587, 0.033233166116500096, 0.014517936900618577, 0.035149075406333136, 0.03164801911841477, 0.1394109950671273, 12.925364855797062, 51.01692345834548, 65.14839556909376, 36.8366962863553, 27.226642254860174, 41.31931427986392, 56.5909448746712, 53.485561263176706, 61.41988462017429, 18.949821456786125, 0.1399792178023246, 0.4858898257295932, 5.558184356458726, 7.270991725306358, 3.9113929290925307, 0.5692269845354943, 17.107848967275313, 60.101407343341464, 52.94418004251296, 54.11219127716557, 48.96440990509526, 54.3591280137339, 53.60123980429865, 56.416830862722094, 53.86896902515043, 54.62161694803546, 50.691374578783595, 50.36605711906187, 49.07127095806984, 50.921535338124926, 50.49010207576137, 52.89378935290922, 51.984984028723936, 52.487023876559356, 49.37730604602445, 49.667914452091345, 47.94298156615227, 52.00301516440607, 51.77426645832678, 52.6255423791947, 52.04330967318628, 51.58745965650005, 49.7516413657896, 46.27717841056086, 51.67478338364632, 47.35413574403333, 41.16834617430165, 38.84399275625906, 37.641339148244555, 38.89324203614266, 40.83388566970825, 40.05155717172931, 38.37881926567324, 39.49132896238758, 40.20993463454708, 39.792213978305945, 39.23819095857682, 38.96924580297163, 40.90723006956039, 38.316296685126524, 42.17161393934681, 46.564594007307484, 48.300944912818174, 51.084235252872595, 53.64532724503548, 53.266347838986306, 51.38245697944395, 49.99724449649934, 47.75306824714907, 46.376677174722, 45.0869155699207, 52.15399111470869, 54.629073373733036, 54.91485334211781, 48.702148468263694, 49.25290807600945, 50.939025186723285, 53.11956098002773, 54.14066768461659, 55.22514812407955, 49.83966719719672, 40.24619302441997, 40.274077153974964, 40.16314075839135, 39.47114052311067, 39.54361023441438, 41.06626256819695, 41.54674506956532, 39.79789357031546, 41.067266694961056, 40.58589381556357, 40.29755646182645, 39.75798345381214, 41.729382391898866, 40.61413488080425, 40.48799930080291, 41.01147490163004, 41.300494747777144, 40.84754728501843, 38.76321938730056, 40.59800609465569, 40.52628555605489, 41.37655735015869, 41.102367985633116, 47.213534462836485, 48.75592808569632, 49.59985740723149, 45.97408117786531, 42.12842864374961, 40.15449585453157, 38.45052803716352, 39.56413599752611, 39.59320468287314, 39.932450479076756, 39.2288008043843, 47.30020315416398, 52.47167171970491, 52.24527251335883, 53.07964301878407, 52.920598753037, 53.68520598257742, 55.67761313530707, 53.767587523306574, 55.99033194203531, 56.507253262304495, 55.56791620869791, 56.50499397708524, 58.80664471657046, 57.85549740637503, 54.931888195776175, 54.73031367025068, 52.75513748968802, 23.69993136775109, 3.486418829810235, 0.7184863463044168, 3.2381737376413042, 4.520038385545054, 2.228671855503513, 0.02082967210651165, 6.014403075941148, 61.38710929501442, 55.04804134368897, 46.337657436247795, 27.060857395971976, 34.23709054147044, 55.107186763517326, 48.0769383522772, 10.500840967701329, 0.0924206633240946, 0.04866555918969455, 0.03880345653141699, 0.011008604947898177, 0.05819391947419894, 0.05049624502839101, 0.07879464045887993, 0.08310845091698632, 0.017709168079759807, 0.05292099757841038, 0.07082840623033625, 0.04838710155097708, 0.12958236279026156, 0.11691816331398104, 0.1535374725297574, 0.13755609701958396, 0.12086723931133748, 0.15722845350542378, 0.09809667004212257, 0.093079567886889, 0.2074932748632085, 0.1970094995152566, 0.20336516411794772, 0.21163601788782307, 0.12943351190657387, 0.09710848556771394, 0.13334337952396563, 0.246237650693905, 16.049012983998946, 60.26951620655676, 70.72912031604399, 45.42838142764184, 34.94586283160795, 50.84797128554314, 58.59975145709131, 60.69060225640575, 67.80762134059783, 22.800429905614546, 0.4605962071687945, 1.7196726198157959, 11.6204374067245, 15.877157276676549, 7.125268318960744, 1.395189644348237, 18.628567572562925, 60.99202071466754, 53.57390872893795, 56.07228986678585, 50.72581298889653, 55.33142082152828, 54.89544937687536, 59.57274244677637, 55.78741988828106, 56.154612571962424, 52.672026388106815, 50.56610192022016, 50.02101798211375, 53.6495320258602, 52.63501490316084, 55.23983740037488, 54.65774197732249, 53.73022302504509, 51.05794360560756, 48.360455113072554, 50.347645513473026, 56.09865211671399, 53.060525386564194, 55.173117883743785, 54.399022440756525, 51.81590634007608, 51.72793542185138, 48.60051593472881, 53.105130580163774, 50.72809188596664, 42.83414932989305, 40.909128496723795, 38.52628861704181, 40.21160556424049, 42.37968783224783, 42.51094602769421, 40.88940289712722, 40.312959609493134, 42.55133075098838, 41.74337348630352, 43.74942656486265, 42.212402666768725, 44.54627175484934, 42.12021520060878, 44.83253025239514, 50.29871786794355, 51.06611782504667, 52.48661202769126, 57.71059328509916, 55.31932030954669, 53.491554644800004, 52.881990863430886, 51.267578601837165, 47.3850832446929, 47.88101203979985, 53.76432803369338, 56.068751888890425, 58.08002564214892, 47.286019863620886, 49.478832675564675, 53.5546616585024, 55.855312193593676, 56.171266955714074, 59.08843563448999, 51.60758926022438, 43.22879468241046, 40.92700273759904, 42.14494182217506, 40.626627629803075, 40.839455435352946, 41.73931775554534, 42.722950135507894, 41.9885451562943, 43.12408308829031, 42.63392802207701, 43.34461835122878, 42.039865447628884, 44.215859136273785, 42.600591797982496, 43.17372460519114, 42.47676649401265, 43.301225170012444, 43.15167304008238, 39.77782280214372, 43.25751035444198, 44.116556490621264, 44.21030113773961, 44.934833511229485, 51.00148893171742, 52.65906295468731, 51.646907098831676, 47.755256929705226, 44.34208885315926, 43.797181421710604, 40.19292723747992, 41.08611760600921, 40.488579811588416, 42.33594163771599, 41.5468313617091, 49.44222127237628, 54.72286116692328, 55.684108580312426, 56.56628101102768, 52.90742351162819, 56.36855433064123, 58.40364471558602, 56.89566989098826, 57.51346672734907, 57.60381852426837, 58.410481406796364, 57.68687863503733, 61.405815078366196, 61.095465383222034, 58.92455508632045, 55.38362364615164, 54.796550735350586, 25.37792721102315, 4.313107373252992, 1.2528999053662824, 5.982495084885628, 11.103647485856088, 4.394791222387745, 0.1857877516698453, 7.219761648485738, 68.28615834636074, 60.592660673203014, 52.834408590870524, 34.244727396195934, 43.96482352287539, 61.76841858894595, 57.507928340665764, 13.973785965673386, 0.19060049987127706, 0.14154528538065572, 0.0858483030911415, 0.17153223435724937, 0.09635213462095107, 0.13145112702923437, 0.15848434740497222, 0.10276519453092929, 0.21050999121319866, 0.15640472512572043, 0.23373615297098316, 0.12036692260974839], [0.004761238843427911, 0.017066328380737576, 0.06527883466333151, 0.04031671766912745, 0.06571472337048861, 0.020780403076881365, 0.02894063949615004, 0.010507618876985245, 0.022327718738045906, 0.047259979370620944, 0.038996594958007336, 0.02261938756301759, 0.03239999187269038, 0.03434386337175965, 0.08395488614276533, 0.02278226168615924, 4.417428691540995, 38.12375537810787, 54.72295138143725, 40.433490122518236, 31.25329648294757, 49.06553253050774, 45.413550946020315, 52.39411861665788, 54.48132945645241, 29.32068390230979, 0.45167260052215674, 0.38585161309569116, 3.8285424199796494, 2.8338465046498085, 1.6855423609095237, 0.352366553439248, 14.745180856797004, 61.70770814341884, 50.70771125055129, 53.22896765124414, 47.74275241359588, 50.394749256872366, 49.31064536494594, 52.20335414332729, 49.43289779847669, 50.37485107298821, 47.41626216519264, 48.47303890412854, 43.680957671134706, 48.224242964098536, 48.59751139917682, 52.29676931135116, 51.45715459700554, 50.413596245550345, 51.27003008319486, 50.90480642934, 49.989713545768495, 50.94071180589738, 48.417682493886645, 50.60057955403482, 49.21825001316686, 50.629369751099624, 49.20298807082638, 48.940436378602065, 51.45648387170608, 48.98111527965915, 36.46808370467156, 37.524938891010905, 37.17390637243948, 37.69114540469262, 36.041549482653224, 37.52040070872153, 39.03679293970908, 38.89083370085686, 37.53420352935791, 38.182602697803134, 37.97515246175951, 38.81308447930121, 38.94565274638515, 38.05561988584457, 38.183406783688454, 38.7881068260439, 42.45262822797222, 47.8104329109192, 49.2579169427195, 50.939186003900346, 51.813392100795625, 51.78648464141354, 48.46619829054802, 47.86015287522347, 46.587053498914166, 49.81635655126264, 52.13264557623094, 53.941446581194484, 48.69832807971586, 46.69331442925238, 51.200568829813314, 51.12154483795167, 53.84669780731202, 50.82756319353658, 43.28825781422277, 38.6576448717425, 37.24739589998799, 37.43106088330669, 36.31254603785854, 37.764921265263716, 38.85668946850685, 38.87719561976772, 38.02201694057834, 37.98733534351472, 37.91337120917536, 36.711211819802564, 37.49119474041847, 38.94286001882246, 38.085971186237956, 35.64687667354461, 39.303992640587595, 39.328146596108716, 36.98347922294371, 39.1431519293016, 38.51583157816241, 39.176574445539906, 39.66733355675974, 48.083618148680664, 51.07397041013164, 54.833832863838445, 52.68675881047403, 52.02879690354871, 49.97637356481245, 44.50622043301983, 39.36059244217412, 36.30125745650261, 37.15375323449412, 38.51925188495267, 37.21043540585426, 39.94784185963292, 45.589586919353856, 46.87066831896382, 47.64884694930046, 48.66076354057559, 49.046018738900464, 48.860608300855084, 46.8522527910048, 49.894568612498624, 48.606713279601074, 50.786135119776574, 51.03292280627836, 53.60673112253989, 54.33926513118129, 54.128982943873254, 53.58955898592549, 43.0573086584768, 11.525896518461167, 0.17772495205844605, 0.5387207505203063, 1.5463891697506753, 2.593062250844894, 0.9924124830192136, 0.019178664529575937, 7.4268598518063955, 59.85767126083375, 46.26212827620968, 37.6540554723432, 30.145699554874053, 40.2164065453314, 45.26681900024415, 37.07272098910424, 3.5748822506397, 0.11014078263073199, 0.048323566048976876, 0.03057547304178438, 0.02841067519189129, 0.009534361625781224, 0.05669224924678284, 0.030137839569379727, 0.05211751690254577, 0.006127420675775578, 0.040955190666981285, 0.03117342764932302, 0.04982991324317071, 0.07271944064526789, 0.05684632485011413, 0.07461432082157943, 0.011223398764888126, 0.04341635920648133, 0.016538984097179868, 0.0361893845031098, 0.008184621955508427, 0.02865581758200161, 0.014927064241360755, 0.06052364264765094, 0.01758446237222562, 0.04447625334104223, 0.03949694613355302, 0.061584509713875676, 0.06605095936045532, 6.475424247403299, 46.826808375696984, 61.19692533246933, 48.01719673218266, 30.94943831043859, 47.935203506100564, 51.54244261403238, 57.315885174658995, 59.84149932861329, 30.71267620209725, 0.3768266376949126, 0.2612247666524303, 4.024841112475242, 6.335910933633005, 4.381876818595394, 0.8929313082368144, 16.39099757517538, 61.696933392555486, 53.16306006523871, 54.661130905151374, 50.52300291676676, 52.89394624771611, 50.54068888387373, 53.727791155538256, 52.24938315729941, 53.51824637382261, 48.874866116431456, 49.420032424311486, 45.59644322241507, 48.98562208298714, 50.065093655740064, 54.112685495807284, 52.40561900600311, 50.84055016117712, 50.31449364077661, 52.51142101903116, 52.20665677901238, 54.70797969448952, 51.73779233809441, 53.19978521716211, 51.91602876109462, 52.5977994549659, 49.617107991249334, 49.83625081277663, 52.54645562941029, 51.22556609492148, 37.476195596879535, 39.66812587553455, 37.043530710281864, 38.845561704327984, 37.81241724568029, 38.74556872152513, 40.755187234570904, 42.26487613493397, 39.458671308332875, 39.910363612636445, 40.14028118502709, 39.55555385158908, 40.084152067861254, 41.45540875773276, 39.44696695573869, 41.63098189138597, 44.78870561045986, 49.38192267571726, 51.16092935685189, 52.06255674362183, 53.4023521023412, 53.036877416795306, 49.74076855567194, 48.139190289282034, 47.72863972571589, 52.87363229259368, 52.51802629040134, 56.06755948835804, 49.5515416514489, 50.06771379901517, 53.01162911999611, 53.84898454912248, 54.3466313423649, 52.27958540762625, 46.32964403398576, 40.691574235116285, 40.8735369097802, 39.22972256137479, 38.812751077836566, 39.69313490775324, 40.054200849225445, 39.35505797786098, 39.10890963769729, 40.4149765353049, 39.65273449497838, 39.11781734035861, 39.385605396762976, 40.95433381295974, 39.05055653664374, 39.541052849062034, 40.04188852925455, 39.621637944252264, 39.0544436054845, 41.32619411714616, 40.2585014220207, 39.97623197494015, 41.60215639298962, 48.87058288820329, 52.572249135663434, 56.84688737315517, 54.08386784215128, 54.37364470574164, 51.94592898891818, 46.68504999529931, 41.39721647385628, 38.15387133629092, 38.53819301051479, 39.511529168775006, 39.62306960936516, 42.875271458779615, 47.82190976604339, 50.021249401953916, 49.50761502788913, 50.9535458011012, 52.13252790512578, 51.606867544112674, 50.744628598613126, 51.59400216994747, 52.08252553016909, 53.278365981194284, 53.68186020082044, 56.67808817278955, 57.038228434901086, 56.93830605476134, 56.24246581908196, 45.82684716870708, 13.986934731083533, 0.6009931573944708, 2.3693434942153195, 4.7110587935293875, 5.833390105155207, 1.899484242162397, 0.024824724870643793, 7.320742578275743, 63.686963588960715, 51.265154577070675, 41.193719986946356, 32.261020060508486, 44.12756658369496, 52.89728026236258, 44.872860062506895, 5.783547566783044, 0.1992138715520982, 0.0630831960288267, 0.040525480458933505, 0.057589250106003985, 0.053675647809981346, 0.07699444875000946, 0.01896499303139506, 0.028638787447444858, 0.022275109565065756, 0.06449168698201257, 0.01804388721563643, 0.00413667225661958, 0.15753844332310463, 0.12020369225572194, 0.14233332938484608, 0.14721041365015894, 0.1325397686131539, 0.20292075651307262, 0.14630823786700928, 0.18204691369206677, 0.1312554222080977, 0.22030739774627073, 0.16004131385876288, 0.16294573704081197, 0.13398156140840825, 0.1449937995282873, 0.23509914596234602, 0.150994336412799, 7.398627121602336, 52.478680995202836, 68.15335473706646, 52.730665822182935, 43.27028943646339, 58.56976885949412, 56.39951359841132, 60.662886788768155, 65.42957851963659, 35.064887154486875, 0.5843051270611825, 1.0134740786687022, 11.237575834797276, 11.913009939655183, 5.870920813852742, 1.6923313708074632, 18.561498964986495, 64.99351293809953, 54.10511924374489, 57.877505825411895, 52.762844947076616, 55.67522048950196, 51.69838428497315, 57.162343994263686, 53.966188892241455, 54.94193730815765, 50.321902998032115, 52.659494415406265, 46.224395075152, 50.15476296024938, 51.998551507149976, 57.48625332309354, 54.06769198756064, 53.025663360472656, 52.16452267862136, 54.838198461840236, 56.024162384771536, 57.24410187813544, 53.15703922702421, 55.395222094751176, 52.584404560827444, 54.72328870527206, 50.53224009852256, 53.86618414232808, 56.927142989250925, 53.53976057421777, 39.3423181195413, 41.18273735046387, 40.201352488610056, 41.458217174776145, 41.08660790228075, 41.81738076671478, 41.9712318143537, 42.89058831430251, 41.30136943632557, 42.26855139578543, 41.90713636336788, 42.18440086610856, 41.740204211204286, 42.75301902524887, 40.829367099269746, 43.23179137322211, 46.927428937727406, 51.78722596937611, 52.82605002003332, 54.635509983185806, 54.50634241104127, 57.07066251385597, 52.83858591510404, 51.049416372852946, 52.245417641055205, 53.55488131123205, 54.579349487058586, 57.551729448380016, 49.2285736914604, 50.61527667507049, 56.56701841662007, 55.27358939570766, 56.78326260659003, 53.68937153970042, 47.438756958130874, 43.49009906091998, 42.5797640123675, 42.22818628434212, 40.71370424762849, 41.62773416888329, 42.65142571541571, 42.4261365398284, 40.90632400205059, 42.946686052506976, 42.29456063239805, 41.647718644911244, 40.983010261289536, 43.12729943183161, 40.78240848356678, 39.593573385669345, 43.57577147022371, 43.855856157118275, 40.36906911480812, 44.083789010201734, 41.648303078066924, 42.801887835225756, 44.603314784265336, 50.90927793133644, 55.18948985684303, 58.47742842089746, 57.68319160707536, 55.91725818572506, 56.65831158238073, 50.63022090542702, 44.714992507811516, 40.69659486893685, 41.20997036657026, 42.86911333760908, 41.101363858869, 47.060589482707364, 49.63615894317628, 51.847085260575824, 51.001030014407256, 53.96432968877978, 54.63873024909727, 53.69881660707536, 51.93728800742857, 53.89161679052538, 53.42490573083201, 57.83839587242373, 57.26904815243137, 59.69455949721798, 58.02828173483572, 59.266409258688654, 56.585178990517896, 47.68474055874733, 16.05518091109491, 0.7849344226621813, 2.8825196864143496, 7.431298503952642, 11.363848697754646, 4.811363114464668, 0.11505774943338287, 9.415716278937555, 71.12686434099751, 57.97132107519335, 50.2451971269423, 39.86595845991566, 52.174340371162664, 58.60292857693088, 52.835440174225845, 6.669370253239909, 0.4070541689232473, 0.1856784002795335, 0.11852955265391259, 0.1016641729661534, 0.09254873790327581, 0.19338049505266452, 0.16388388831288586, 0.1281512492606717, 0.06956054603741055, 0.17476002325213727, 0.16188588504108692, 0.1379752084011993], [0.09664546202627883, 0.0352255616246933, 0.06483556086858434, 0.037793281503141894, 0.05169323442744152, 0.03454660088004124, 0.02739923228810151, 0.07888185190818003, 0.08941385249096541, 0.04532115639097268, 0.03093970571494391, 0.05737316734608143, 0.06688993288985183, 0.040676288697267735, 0.07433390965865505, 0.04621511971157405, 1.703444058375974, 32.428873969662575, 55.86152130557645, 43.966784707961544, 32.477832994153424, 41.330622473070704, 38.77757133976106, 46.689427360411614, 53.20100115191553, 36.999419735324004, 2.14326175470506, 0.2949628191849878, 2.1554108060175374, 5.9803534707715436, 3.074971269215307, 0.1425622058131041, 15.14654032645687, 55.84603186576597, 53.39011822977374, 53.33857436333933, 47.368766184776064, 47.93334038026872, 47.07148974941623, 48.66692950648647, 47.87712889332926, 48.659520149230964, 43.88099070518248, 47.84347887962095, 46.83563763095487, 49.71277459975212, 47.91270479079216, 52.65030430209253, 48.51897770358671, 51.386077327113, 50.45027432903167, 50.750633747346946, 50.4005818213186, 47.634067458491174, 47.293033061488984, 48.24086596888881, 49.28625606721448, 50.85661618940292, 51.36045640514743, 50.36536678191155, 51.85497706936252, 46.455230482162975, 37.34568265176589, 36.92979374239522, 37.46974722031624, 38.000349767746464, 35.74983104582756, 38.35763062200239, 37.309522321147305, 38.033097636315134, 38.25497042748236, 38.88587974732922, 37.827428156329745, 37.91531670478083, 37.78679240134455, 36.909620992598995, 38.4636365982794, 40.048729142835064, 37.3353236721408, 42.3580010475651, 47.97335640076668, 50.64865212286673, 51.75967524128576, 50.825158780620946, 48.45295636884628, 48.110839397676536, 47.626807151302216, 49.79363426085442, 49.05054123170915, 54.460886063114295, 48.9088495316044, 46.46250255646245, 50.34349956820088, 51.44677208315942, 52.62486773152506, 48.24698486635762, 42.98419567846483, 39.10460679761825, 39.23274278640747, 36.38883613771008, 36.68117823139314, 36.30864327953708, 37.646065604302194, 39.453929162794545, 38.31729688952046, 37.6561107943135, 38.19581716291366, 38.68061427147158, 38.97301912307739, 38.3617804896447, 37.22217113740983, 38.05647888491231, 38.41391663397513, 37.72715668524466, 37.8259886464765, 39.736716362737845, 38.34428671867617, 35.636349032002116, 47.40930780287712, 53.14515836777226, 49.1998109509868, 45.331687158153905, 49.2749047279358, 51.52054402136034, 52.63368521967242, 50.472129775631814, 46.91226897701141, 39.12183384741507, 37.812381944348736, 37.69975500722086, 36.37342122293288, 37.952598833268695, 38.67189876494869, 42.68990024443596, 42.90761924559071, 43.97698287040957, 44.3808340257214, 45.51107675798478, 43.78407286059472, 44.119678697278424, 45.476128439749445, 46.60055429704728, 47.924095353772564, 51.15209617922383, 52.65432080914898, 55.84566708533995, 55.85184481836135, 43.24474696190127, 7.09528866314119, 0.13188739878035363, 1.2139560402401033, 2.604898493136129, 3.352448070241559, 1.3028845070831239, 0.009105558274313807, 10.972010781688075, 61.43781769660212, 44.06753470820766, 35.436998490364324, 24.00677054159103, 39.55316512815414, 45.800190741016024, 26.932176197728804, 0.8357932226311776, 0.05004162547148524, 0.036944145817429795, 0.10370143058319246, 0.04198682381801548, 0.027625174599609552, 0.030496100587169492, 0.0535146544326938, 0.04377135668971366, 0.058382514999398304, 0.032888744477062457, 0.03161786206727547, 0.08051736535684717, 0.030212119454517964, 0.0401545062120403, 0.057415194929607456, 0.00996921802946036, 0.060095817015896884, 0.06073977520328857, 0.013521531345172515, 0.051636907812808795, 0.03986296762201575, 0.052667223292613224, 0.062180748284463926, 0.028405657315987255, 0.05658539147266457, 0.04590307294781651, 0.025918773120088924, 0.055546917156466556, 2.4180549190890406, 38.972050297644834, 63.53556402267949, 46.87313156743204, 35.89878697549143, 54.64974818691131, 48.42269920533704, 52.12072549327728, 57.74775382011168, 39.96011103353193, 2.009659452784446, 0.12789136159323877, 2.354941776683254, 6.457169046325069, 4.935576733081572, 0.4635556661073239, 17.859002467124693, 59.85767126083375, 54.057917441091234, 54.6160432600206, 48.89559192042197, 51.708755031708755, 50.17335107249599, 51.218195961367705, 49.4625783735706, 51.058955577112016, 45.259554770685014, 48.01127787559263, 48.18911421683527, 51.495570290473204, 50.06641941685831, 54.89770081735427, 48.31821510868688, 50.59173068692608, 52.23898887634278, 55.84402361223775, 51.76992047217585, 47.651372955691436, 48.64252451927432, 49.65024417446506, 50.39438839881651, 53.777820987086145, 51.45428734440958, 52.28999537806357, 52.25074421974921, 48.09876634228615, 39.12201427644299, 37.37625752725909, 38.696390044304636, 40.48330030133648, 37.28554879465411, 40.61122055976622, 40.06213972645421, 40.35368950136247, 40.052361257614635, 41.21262973354709, 39.97281166814989, 39.573377101652085, 39.8292568422133, 37.73639386700046, 39.18087728561894, 41.71218672106343, 40.426610285235995, 45.603974173145915, 50.952647578331735, 52.96167381348149, 54.524197040065644, 52.589907646179206, 51.35294506626745, 49.92639864644697, 51.11396681877875, 52.48488226244527, 51.81516501211351, 56.70019465108072, 52.3613864375699, 49.18565511703492, 52.00642370408582, 54.07567008849114, 55.20073136975689, 50.80146766478016, 46.66425751101586, 40.31052381761613, 39.7257847170676, 39.819725482694565, 38.56555154246669, 38.33623017034223, 39.17096937856367, 40.95016433346657, 39.917443490797474, 38.9156505369371, 39.90901823966734, 40.459844527706025, 40.67680651141752, 40.056785691169004, 39.039742562078665, 40.45416885806669, 38.73766906799809, 39.300976337925086, 39.2585402150308, 40.718936689438365, 38.655456189186346, 38.182316364780554, 49.9292855108938, 54.07865893456244, 52.267382914020175, 49.31055907280215, 50.67871316786736, 53.36553673590384, 54.222684444919715, 54.030582443360366, 47.78275274461316, 40.559931647393014, 40.34838645688949, 38.93362283706665, 38.353237567409394, 38.60403391622728, 41.27068865683771, 45.51794090578633, 47.33722640622047, 47.079110914661044, 45.94768754897579, 46.28505845223704, 46.015140548829116, 47.787318383493734, 49.30365570129887, 51.37534572232155, 49.87579614885392, 53.10608763848582, 56.8376305795485, 59.149169614238126, 58.863774038130245, 44.73560456306704, 8.856674586572955, 0.5178555798146033, 3.94437417868645, 8.90564145580415, 4.647730656208531, 1.479243217937408, 0.08402478400497668, 11.523680379313808, 67.41756516118204, 49.30038052220499, 42.50745119587068, 29.41645641480723, 46.16515944080968, 52.37104723530432, 34.38429709403746, 1.2788061797618866, 0.0878866945183085, 0.10125009478220057, 0.005123385842213588, 0.07133493590499125, 0.020033172406857053, 0.055783071420005256, 0.01749608072362119, 0.03291631598145731, 0.049687168080239534, 0.021679035703381224, 0.02643882233138767, 0.031045611624816255, 0.11192533082418865, 0.08899784376544338, 0.16156634976786954, 0.20521929607756678, 0.09281725172073611, 0.11781498414253998, 0.14649320213544756, 0.13826730240496898, 0.2797437164812319, 0.13770283350060064, 0.12153736706222258, 0.1356107239881831, 0.20094843250849556, 0.1490140604155679, 0.20952659478831678, 0.14426947871763862, 3.086281668755316, 47.0122423479634, 71.08704443900817, 54.858794827615064, 41.216269693067, 51.224044215294626, 50.258811673810406, 58.725698763324374, 62.200326458100356, 44.84543485026206, 3.0019494843098427, 1.393310216165358, 7.152997514893932, 14.803205459348618, 9.2544029220458, 0.9623481898057846, 19.645253765967585, 61.01444882731284, 55.7499102623232, 58.43460398335611, 51.49383660285704, 52.5288559544471, 51.45787631311725, 53.58982178472704, 51.45079251258604, 54.19120742428688, 47.16463035152805, 52.279557951035045, 51.107538054066325, 54.79518967290079, 51.0684516352992, 55.82682009666197, 49.46853253149217, 50.50042967642508, 54.086997893548784, 56.23293445956323, 53.976783214076875, 50.319322078458725, 51.09727713369554, 52.01369970075546, 54.86647875078263, 55.455909006057254, 53.78601481837612, 53.199667546056936, 54.47952908854331, 49.96341405376312, 41.86442567456154, 40.13817879461473, 41.56285816623319, 42.57195457335442, 39.01111318219093, 41.742130094958895, 40.92256653693415, 41.01336156168292, 42.5871459130318, 42.77963230686803, 42.21362252389231, 41.59213473719936, 41.25909413060835, 39.184344660851266, 41.26076113793158, 45.96931942047612, 41.68576955795288, 46.91909390111124, 50.77962006292036, 54.25920563359415, 56.37351612890921, 54.425015987888465, 52.59421833099858, 52.61669743445612, 53.06570683756183, 53.02777359562536, 52.76999150553058, 58.63462132792319, 51.991299044701364, 51.07562957271453, 52.915793849575905, 57.74394519867436, 56.53977755577334, 52.34850537392401, 48.35561490827992, 42.44380289508451, 43.067757852615856, 41.75423060694049, 40.97032139378209, 40.32644471814556, 40.33389722147296, 42.62644021741806, 42.015597743372766, 41.82452340279856, 41.280937810097974, 41.84037370066489, 42.789355862525206, 42.79720452524001, 40.780537512994584, 43.249179240195986, 42.1974858930034, 41.06199895181964, 41.724608867399155, 43.62263202667237, 41.58337608460457, 38.6080268890627, 52.26956375183598, 55.61088185156546, 55.64890530801589, 50.198822944395005, 50.305680074999415, 54.652788023794855, 57.49610239459623, 56.47807867296281, 50.488831227825536, 44.065903002215975, 42.05560199676022, 42.64900953538957, 41.23494801982757, 42.64115695030459, 42.52896931863601, 47.38245917904762, 49.086776087361, 47.96922614497524, 47.07778123117263, 49.0320158773853, 47.48731590086415, 50.05500531965687, 51.08841649947628, 53.51644600591352, 50.9263559310667, 56.39597954288606, 61.04807530680011, 61.5819412662137, 59.837957428347686, 48.74509449928038, 10.481689014742452, 0.8454550009581351, 3.6457217268405424, 8.130588464198574, 9.341713901489012, 5.031902299773309, 0.2076569418873518, 14.150416178088035, 74.538769414348, 53.80979614873087, 47.59825229644776, 36.0147596943763, 52.54426302448396, 58.960189819335945, 41.60696521882088, 1.8649465470544755, 0.22319674431797, 0.2971946478130356, 0.1740418158231243, 0.15460363709397856, 0.2006028042805772, 0.13729944224319152, 0.15719241672946563, 0.15856818806740547, 0.17484605492603394, 0.16359930197077413, 0.10333079724542557, 0.1886408316392091], [0.05179638050556664, 0.035936947040740526, 0.0291926977449968, 0.055051564704626806, 0.08483651544778578, 0.069753845342465, 0.018479498215920983, 0.11089707995134016, 0.034453555671197754, 0.10951657419002826, 0.03753373857527491, 0.012667407469463446, 0.03802619521476088, 0.05467444260214126, 0.03793807595127052, 0.0207100551380145, 0.573330641754212, 26.492566754741055, 52.57037424272107, 50.42421017923663, 29.00704137740597, 27.545862390149026, 34.34823874504336, 49.48998397396457, 51.55157781416371, 51.00271271121118, 6.714032321206986, 0.21924311775834332, 1.4288585344629905, 4.682637789557058, 3.1254639404435314, 0.6539607829143924, 13.597611054297417, 49.31281443565123, 56.092372402068115, 51.58778913559453, 51.654614556220274, 45.530610161442915, 48.52269611051006, 47.096832183099565, 46.110720865188114, 44.500372179092906, 46.29635880070348, 47.51676505611789, 49.30269079823648, 49.688510817866174, 51.60785598139609, 49.69638301480202, 42.189743134283255, 45.69599297738845, 48.12588560965754, 49.594840695781095, 49.17848110198975, 42.84265695079681, 45.74195138869747, 46.81244857849614, 47.26460372248004, 47.73795927724531, 49.97588719091108, 51.15065666937059, 50.73773699422037, 42.59619482101933, 37.065633266202866, 37.484059949075025, 37.27499761889058, 36.92165090191749, 37.52089884973342, 37.71842156687091, 38.69668814443773, 38.03064615495744, 38.69294620329334, 38.48089110466742, 38.509124325167754, 39.17861015565934, 39.08300630507931, 38.780003209267896, 37.589312830278956, 37.79470382198211, 38.09492987971152, 39.66951439457555, 44.71260770674675, 48.62047295416556, 50.30666851228284, 51.67989815435102, 50.137237810319476, 49.82173412076889, 49.742776809200166, 51.308281037115286, 52.26249564078547, 56.305239431319706, 46.14114669061477, 42.79591406545332, 54.905820123610965, 53.03068791666339, 52.8510315956608, 49.7230355201229, 43.568640601250436, 39.101308084303334, 40.323385269411155, 37.947468373083304, 37.52466040272867, 36.45151561306369, 37.16835229627548, 38.06496297159503, 38.07931492405553, 38.13926835213938, 38.10771680647327, 37.334837298239435, 38.19415800033077, 38.82868766784668, 37.72125351813532, 39.61644472614412, 38.12706193616314, 37.49696062457177, 36.40343127712127, 38.52775950585642, 38.334002264084354, 39.74500433091195, 48.34642871733635, 52.57761493805916, 46.38114867671844, 44.85875129699708, 51.16946051197668, 47.47287765625985, 52.73591787584367, 52.595030261624245, 50.91780124172088, 46.05451330061882, 40.4403385808391, 36.29360491229642, 37.0720894875065, 37.39808551726803, 37.13336083196825, 36.969397914025095, 37.91323000384916, 41.16485134247811, 42.73434462085847, 41.259364774150235, 38.73081276493688, 39.31571268266247, 40.11304424655053, 41.930560758036954, 42.00282258372153, 48.46099722769953, 52.46257966564548, 54.30101025489069, 55.563605523878536, 41.17966613461895, 6.2619664111445035, 0.24809216569748618, 4.191930159445732, 7.7646141667519855, 4.049980808650294, 1.470228508114815, 0.07593245936497565, 12.918219277935645, 58.76325153535413, 43.66013380788988, 30.62780199512359, 25.773004024259507, 42.643180893313506, 47.578244286198775, 16.96908139413403, 0.15018557739113608, 0.03646406149792095, 0.03184846027814333, 0.013947536560496496, 0.016149033852402243, 0.055504602289968924, 0.06722938644910051, 0.012004209941463366, 0.01897490620913525, 0.040340784321268724, 0.032182813607036106, 0.04729334633016298, 0.04398282376989242, 0.09699219342080817, 0.16467228471752138, 0.04425802170449207, 0.005574539330066933, 0.04750548373727549, 0.0697402089774128, 0.028734975531997702, 0.08429096891514717, 0.08628390834576662, 0.11015695474681356, 0.093843748252238, 0.045650723585558516, 0.06190434376138353, 0.024158209224321672, 0.08783649277663039, 0.05183920865097354, 0.9896013080593079, 32.637124369221354, 58.51852701556299, 56.999648001886186, 32.738362704553914, 35.19231711664508, 42.487133318378085, 52.09639895346857, 57.279638551896625, 52.071899829372285, 6.788717681361783, 0.12748614704656985, 1.3058668567288307, 5.937676612407931, 5.107211807081777, 1.4624782723765222, 15.333337322358163, 51.90774471529069, 56.7100162659922, 53.435782463319846, 54.0648796481471, 47.734307550614886, 51.48183022775958, 48.71024816266952, 49.53245147582024, 45.962392514751805, 48.05581638889928, 49.629000617611794, 50.15627307276572, 51.98498795109411, 51.90514418386644, 49.81448558069045, 42.39876624076597, 47.670933815740774, 52.03428822178995, 49.54023345824211, 51.20558161889353, 46.403423816927024, 48.800596037218654, 48.42488788789319, 48.82078839886574, 50.1682480689018, 52.00007730914701, 51.955907498636556, 52.91588406408987, 44.80651317104217, 38.93952208180582, 38.4848330866906, 38.684787673334924, 38.39756427272674, 37.94344794365668, 38.881482770366055, 40.41518834329421, 39.72563566700105, 39.580135345458984, 39.69311529590238, 40.76472643882998, 39.95685938865908, 41.015279600697184, 39.915854930877686, 39.032878414277114, 40.035232267072125, 39.738053890966604, 41.79141859854422, 47.71354644529281, 51.0958101672511, 53.40106948729485, 54.12410743774907, 51.79974225259597, 52.15374008301766, 51.08012853130218, 53.01633596420289, 54.24845049458166, 57.29571242486277, 48.403577650746996, 45.71526358204503, 55.11466672343593, 55.43716792137393, 55.18862301303495, 50.835160824560354, 46.0173096195344, 40.46696755193895, 41.05313831760038, 40.78951974068919, 40.5359032077174, 40.93869532308271, 39.06628524103473, 39.59649555144772, 41.52168112416422, 38.95742377927227, 38.92538585970479, 39.4008751838438, 40.08487378397296, 40.59411510344475, 38.84468309340939, 41.11100896712273, 40.03017240954984, 38.425350343027425, 38.38361240202381, 39.03126632013629, 38.566743942999075, 41.717544678718816, 50.315948840110536, 54.31202819270473, 49.35103401061028, 46.637059796241026, 50.493789103723344, 48.403456057271654, 53.62497406621134, 55.31523319982714, 52.600321538986705, 48.307448202563876, 43.04623580748036, 39.1525460058643, 39.35998055242723, 38.75882241033739, 39.37239093165244, 40.752437653080115, 40.709452398361705, 43.12904488655829, 44.40882798164122, 44.06171391087194, 41.807806261124156, 43.10670306605678, 41.47698571605068, 43.28040915150797, 44.11254782830515, 50.52366971969605, 53.76898780945809, 58.93490229883502, 56.081519203801314, 44.550704033144065, 6.755808995616052, 0.7726760965681846, 6.549834551349764, 10.000902529685728, 5.705452196059689, 0.6518538572615193, 0.012947379089441272, 13.98119140055872, 65.9022202030305, 50.78205977716754, 36.10336603656892, 27.308600179610718, 46.584256848981305, 53.39442106985277, 22.30736836310356, 0.23096801683066354, 0.061975482686032216, 0.09658449674926459, 0.03592816384268865, 0.01941635288418301, 0.06952664664676113, 0.06093780893171507, 0.0218529031882363, 0.12794118029095475, 0.02462532942093188, 0.0036713090347832134, 0.07632089658610283, 0.02294221318386976, 0.17206693308488016, 0.35397527679320306, 0.12634862905308125, 0.14292298726016475, 0.14126045389040826, 0.2943404799988193, 0.10856622679819984, 0.2504268339684894, 0.1860849171756737, 0.16166822414004034, 0.17652142792940143, 0.17009186648553418, 0.26195702413397454, 0.15908171212480915, 0.21464199368511477, 0.14219284418129152, 1.012512791541315, 37.194812605457926, 67.45421578807216, 62.68180524149249, 40.08415599023142, 39.07311408750473, 47.095761376042525, 60.80593170658235, 61.97948132791827, 62.078799663051484, 8.31153573528413, 0.6036598788153741, 5.016941399343553, 12.618143250865321, 10.067245498780283, 1.7118119448423388, 18.849532335035263, 52.827630735212765, 58.41396839387956, 56.20827059591971, 57.49458835970972, 47.89670152048911, 54.81528397529356, 49.72575764502249, 51.02385036406979, 48.19831217488935, 50.43435735087241, 51.55144837594802, 51.70796663530412, 52.8065989863488, 54.255204816018384, 50.99557007512739, 45.667296917207786, 50.459699784555745, 54.11379944893622, 53.444305773704286, 54.66105245774793, 47.23427203393752, 50.26833518858879, 49.46193510486234, 50.84411559566375, 50.864790408842026, 54.00727964216664, 54.882132930140344, 55.183975004380756, 46.7951117023345, 41.77713332637664, 40.40669248950097, 41.81548233955137, 40.290955112826445, 40.34866494517173, 41.58934200963667, 42.35546719643378, 42.237541137203095, 42.25028099552278, 41.96877248825566, 44.04751493084816, 42.337965580724905, 43.995806324866514, 40.8639584818194, 40.17182096358269, 41.88444937429121, 40.66793803245791, 42.82801082057338, 50.452816024903335, 53.02808346286897, 54.67459640195293, 55.265454399970274, 53.926627866683475, 53.885089966558645, 53.098478240351525, 54.4157160482099, 56.74469394068564, 57.87931403806133, 48.83843906464116, 46.79413110979142, 57.423883714983546, 57.889288625409534, 56.34484752531975, 53.800476597201445, 46.97038281348444, 42.40187275794245, 43.797252024373705, 43.4763393863555, 43.64736257060882, 42.60442003127068, 42.352552875395745, 42.74007128131005, 42.533115263908144, 40.938259939993586, 40.59935931236514, 40.437216374181936, 42.37846013038389, 43.26338214258994, 41.7330615751205, 43.92493301822294, 42.98666677167339, 39.89763552142728, 40.767272057071814, 42.22393051270516, 40.03582846733832, 43.77385116392567, 52.63581506667599, 54.85386048593829, 52.1492999599826, 49.03935855434787, 51.7208202423588, 47.27134235443608, 56.39045292331327, 60.61943084962907, 54.63940881913709, 51.145439917041415, 44.71022682805216, 41.99675859943513, 41.25705057574857, 41.27609368293516, 42.119214996214836, 42.06210920887609, 43.033641076857045, 45.52713101910007, 46.813950846272135, 47.02833191041024, 43.390341420327466, 43.981968202898585, 43.77339616898568, 45.99161809490573, 44.8398611622472, 52.45845725459438, 55.50689197355702, 59.71164141931842, 57.62459139670096, 45.36237578238211, 9.094158411026001, 0.5736402025626552, 9.855622841465859, 15.782174141176286, 11.820962698228898, 4.883593561187868, 0.12667849885239718, 16.326482430581127, 71.0798978805542, 55.76384644354544, 42.626232331798924, 37.94081211090088, 54.808035435215125, 62.23628674784015, 27.57261883827948, 0.5120121982068785, 0.09527953491816599, 0.3284898604596815, 0.10551255436674242, 0.14390903434926464, 0.1741774593509974, 0.16749315835054845, 0.09970666510203194, 0.1986079419692678, 0.13545503960021082, 0.10477941588408525, 0.1978731563975734, 0.09333308170279188], [0.029912303284471555, 0.051476385579594684, 0.04686420685761879, 0.018958881564979112, 0.05503245847179525, 0.06893706538023488, 0.029025631205689524, 0.11204697792568516, 0.1128111812736719, 0.03903318331727097, 0.07301724200407345, 0.049085172358900316, 0.023850962001409744, 0.020276591099137743, 0.021917001764860847, 0.05142193971081607, 0.18288536628167476, 14.577948643315224, 45.32776086561142, 42.43744081066501, 25.924332987877634, 29.30313914052902, 39.36413434243972, 52.44110861132222, 50.20980558087749, 54.634137153625495, 15.921179017712994, 0.0681108242321399, 0.3782013977967924, 4.278318891602178, 2.861825751681482, 0.3581757675255499, 10.213662674350124, 46.324658701496745, 55.165077024890536, 52.3875839479508, 50.774936752934615, 46.44636200320336, 46.453892953934215, 46.402423612533084, 44.87719820391747, 46.42241985567155, 49.41116786772206, 48.54883478533838, 49.87731410611061, 52.08174890087497, 47.86402425458355, 46.34589833597983, 48.281493879133656, 48.47356057936146, 49.01809930801392, 49.31490898132325, 45.44743237956878, 41.49398919074766, 41.51321272696219, 44.318778207225186, 45.853409459514005, 47.42603671166205, 47.45833743003107, 47.72636475101594, 47.12236681292134, 39.373485272930516, 37.86690288974393, 38.62039412221601, 36.29400891642417, 37.62057804292248, 36.81594694814375, 36.6585147765375, 38.51410573528659, 37.84708707563339, 37.41723452844928, 38.75881848796722, 37.39574386227516, 37.68136693585304, 37.94299294871669, 37.744258219195956, 39.681359952495946, 36.14981866651966, 39.975043496777936, 38.64694464591242, 38.31188401868267, 47.373257298623365, 50.973004679526056, 51.33241145841537, 49.813661882954264, 52.42788630147135, 50.07435829408708, 52.38708580693891, 51.89813098599834, 55.05202254941387, 42.20592683361423, 44.58409909279116, 52.79589091577838, 50.1248509653153, 51.351140775988185, 48.297916843045144, 42.07470786186957, 36.74853709436233, 40.04382618011967, 40.20663592123216, 38.62975289744716, 37.347051558956025, 38.51554916751, 38.02838294736801, 38.15979019288094, 37.49131241152364, 39.55928402562296, 37.63481232427782, 37.502283280895604, 36.57392494140133, 38.99451763399186, 37.837732222772416, 39.37971399676415, 35.83836678535708, 39.92554710757348, 37.31262099358344, 38.843188670373735, 37.87470840638684, 46.35536301520563, 47.5754358691554, 51.03628427751603, 51.09889315020654, 52.324665208016675, 53.314875402758204, 50.76137319687874, 51.991208830187404, 50.88196254545643, 49.39261897917717, 45.02225922000024, 41.80755522943313, 38.178484209122196, 37.29873188080327, 36.83693162856564, 36.7926755259114, 36.383791969668486, 36.13009698929326, 37.138279484164336, 37.42603632711595, 38.87261036903628, 40.167941739482266, 38.858399621901974, 40.67138971820955, 41.91332978586997, 49.887771144990005, 51.13216269400812, 54.97201796500914, 55.474042123363866, 41.02986689536802, 5.4965595083851975, 1.2364901794541268, 5.595401275542475, 13.724472272780634, 1.289474413760247, 0.23631555569027704, 0.03706798393038973, 18.008313371289162, 58.941970409885535, 40.62827110290527, 39.45359968370007, 28.349191258030555, 46.47950603115944, 45.256950316890595, 10.341531941967627, 0.05408093130456344, 0.16898629435848805, 0.06809361789736056, 0.040064379798188325, 0.02452612486517718, 0.04765947890137473, 0.034088403692529086, 0.06791115873643468, 0.030347784049808983, 0.05669255185151293, 0.05328140364238813, 0.019714793926405332, 0.0681830739842788, 0.017296143266702854, 0.04284453968847952, 0.08735031039724428, 0.05575793607520962, 0.08965886273090878, 0.05746338952092394, 0.029650839391134443, 0.04156090957563251, 0.010962906845604942, 0.060823393700223785, 0.09985930812094482, 0.05672711773865646, 0.03500607360394732, 0.017437768026044773, 0.03892028493986976, 0.014046677913997444, 0.11500109723138233, 19.78286620109312, 55.927711302234286, 51.54954602641445, 31.944312203315, 33.71709016061599, 48.751193784898334, 57.370060951479026, 52.67776481566891, 58.899710793649, 15.038960499148216, 0.10739755200883074, 0.8438324267345091, 5.998294391939718, 4.744876978858825, 1.4311934478821293, 11.619548989880471, 49.16984404287031, 57.845365924219934, 53.86248142488542, 52.263299726670795, 47.29151902660247, 49.081888814126295, 47.55208207714943, 46.721261316730136, 46.59181525630336, 50.51732332475724, 49.20565528254355, 52.05728507811024, 53.84181053407731, 49.975436118341264, 46.75786879754836, 50.4006955700536, 52.12958220512637, 52.3041747462365, 51.26301296295659, 47.387126799552675, 43.622663405633745, 44.46824404501146, 46.160554578227384, 49.02866225088797, 48.77318651445451, 49.756148169117594, 50.998237286844564, 49.14759635925294, 40.63730824378229, 39.53549485052786, 39.953078223812966, 40.45649482357887, 40.11901801632297, 40.07382054482737, 38.88630728567801, 40.671644672270745, 39.3248047367219, 39.65363271774785, 40.05960979769307, 39.95063066482544, 40.09427962764617, 40.574118860306285, 39.19326413062311, 41.365245234581735, 37.971638018085116, 41.338361309420684, 40.02721886481009, 41.46084124042142, 49.54917253986482, 52.55547315843644, 54.597039376535726, 52.5700722202178, 53.14277356670749, 52.28308023944978, 53.775416574170514, 53.95902272193663, 56.14368877103252, 46.724207016729544, 47.872622090001265, 54.38965189841486, 51.53661789432649, 51.39691875826929, 48.82922149473622, 44.63574886322022, 39.12832144768008, 41.530404475427446, 42.23847466130411, 41.61561404505084, 38.491614864718535, 39.941758263495664, 39.49734195586174, 40.929458141326904, 41.162827399469194, 40.06915292432232, 39.195492036880985, 39.700665858484086, 38.70359936068135, 40.555209113705544, 39.51055642097227, 40.68375302899269, 38.39705436460434, 39.01436482706378, 37.830797472307765, 39.378509829121256, 39.15841779401226, 48.711385650019494, 51.13940338934622, 51.32380185588714, 52.567769788926654, 53.03214703836749, 51.92781548346243, 51.549997098984264, 54.97017445102815, 50.913157155436856, 51.099712925572554, 47.09655369481733, 44.0359753178012, 40.042433738708496, 39.97460811368881, 38.29080912374681, 39.29892101595479, 38.87460685545398, 39.42437802591632, 38.71810036320841, 40.40824182571904, 39.91776904752178, 41.65122916621547, 41.606941684599846, 41.984328608359064, 44.24368835264637, 51.10367451944659, 54.0864722959457, 57.90097336615286, 57.69977538816391, 44.82580338754962, 6.971248609404411, 1.5608635737049965, 8.965787080026443, 13.280205995805803, 6.734344805440595, 0.8989575397103065, 0.01923908779938375, 19.078383022739043, 65.8223529015818, 45.105656654604026, 40.91705952921222, 32.86103875406327, 52.528989315032966, 52.39700155873453, 13.327216582913554, 0.06995865894902138, 0.09632153706925531, 0.07925658381634182, 0.013445165785660428, 0.014938174431482631, 0.04257719415510374, 0.020412652144929575, 0.05597586510702968, 0.06999221360010487, 0.07666119284206822, 0.09022788219754735, 0.0320846815743754, 0.002940447030273537, 0.2537187750661566, 0.1091898147076849, 0.2008675642672085, 0.12580538844509473, 0.18576561172883357, 0.16450533883706217, 0.17663919096512182, 0.18455582100056833, 0.3307054480237346, 0.15982584396917976, 0.153740210038039, 0.14509542875232237, 0.10481610383477905, 0.17286846023653785, 0.13053185216361476, 0.15901752927851293, 0.33490357920527464, 24.48260699549029, 62.784488970233554, 58.17853596902663, 36.405690562340524, 40.27892128113778, 50.52665072102701, 62.70486093336537, 58.52744256296466, 64.5845038660111, 19.169417312068326, 0.22985674500946077, 2.7429340539440035, 11.418592237657117, 7.740036595252253, 2.499770147185172, 14.284112126596513, 51.9079839798712, 58.742027590351725, 56.885205007368526, 53.443509532559304, 49.17563346124465, 50.76729597583894, 50.70767987158991, 48.29351594371181, 50.56118326802408, 53.475367023098855, 50.88685766343148, 52.81909173534763, 55.7095451508799, 49.81559953381939, 47.50300538155341, 52.60646397067655, 55.10260935752623, 53.02356097006029, 52.6474174376457, 49.49794638541437, 44.52475755445419, 46.803219241480676, 48.7288833433582, 51.46991798954626, 51.42205330633348, 52.1670526073825, 51.6231140013664, 52.030248180512466, 41.07543699202999, 41.51262044906616, 43.40288123776836, 42.17386930219589, 42.073346799419774, 41.36505696081346, 39.27344914405577, 41.912392339398785, 41.44861913496449, 41.64296865463257, 43.39163188011416, 41.94151201555806, 42.015311410350186, 41.48718780086887, 40.068784221526116, 44.554367526885, 38.499832230229536, 43.680977282985566, 40.64466268785539, 42.240890841330256, 51.8521176615069, 55.54575481722432, 56.2751744639489, 54.423125405465406, 55.05420730959985, 53.19828687175628, 55.52252654106387, 55.620448512415734, 57.99383940235261, 47.97999305109824, 49.23330406988821, 55.793468183086766, 52.70075774961903, 53.11442659747217, 50.47538534287484, 45.943333718084524, 41.482288760523645, 43.71332506979666, 44.545608874290224, 43.676144922933275, 42.26383278446813, 41.75259105620846, 41.606494534400206, 43.98816554777084, 43.032480055286044, 42.45178491838517, 41.57195022029262, 40.44637118616412, 41.436644138828406, 43.396993760139715, 40.82869637397028, 43.235862793460974, 39.96720660117365, 43.64203599191482, 39.89383082236014, 41.94666208759431, 41.650742792314105, 50.901197848781464, 53.001062254751886, 55.148587380686116, 54.47881129480178, 56.28039906101843, 53.77644031278549, 51.88317891090147, 56.36844842664657, 53.86597625670895, 52.40995714741369, 48.698194719129994, 46.56342906336631, 41.980778863353116, 41.537398061444684, 39.3172110280683, 41.18403565499091, 40.91636134732155, 41.30751579038559, 41.87215666617117, 41.71054324796123, 42.87918598421159, 44.93515906795379, 43.34619514403805, 44.07352416746078, 46.489868933154696, 56.40798984035369, 55.477638936811886, 61.935025184385246, 59.370112803674516, 46.6968249505566, 7.934178719597479, 4.373847236556392, 11.887577291457884, 25.175929069519047, 10.999630151256438, 2.654463278670465, 0.1304033026099205, 21.594481506655296, 72.72173927676293, 51.24651155164165, 52.72811235920076, 38.22060262003253, 60.38083307204708, 58.753594659989886, 16.239477396011353, 0.25854725871355305, 0.3569103434922234, 0.1657081275216995, 0.09793723948420056, 0.09873639176329298, 0.19603811534902743, 0.23174098422450407, 0.17198021193185162, 0.16985701457146676, 0.13519253191207686, 0.1950479620286534, 0.09941062574545223, 0.10953049400761243], [0.009565900508013946, 0.08983081882639278, 0.042815102759989045, 0.05889708859725826, 0.05659130950187964, 0.00879859163110415, 0.0538687517626151, 0.0324289883006244, 0.024011547436877608, 0.07748662193696346, 0.02566165486050229, 0.05424373264935228, 0.005789193814815653, 0.04209332153080933, 0.017919101068870198, 0.024390588589613477, 0.043483181225676695, 8.005447205035917, 32.86623589454159, 43.34318276374571, 21.210909005134337, 14.949693237581561, 31.586605771895382, 45.619483224807254, 49.98171583298714, 54.93701081122122, 21.06393583359257, 0.07333296215942792, 0.8205922608894687, 3.0162881987710155, 4.536762391367267, 0.7125473875672587, 9.57114706116338, 43.70965373131537, 57.38882949275356, 52.84610902109454, 53.531221574352635, 46.05781985867409, 45.284191177737334, 45.836362838745124, 49.41173661139704, 49.62082247580252, 51.92988257254324, 51.85082327935004, 52.371235509072584, 49.28660123578964, 47.47973395932106, 49.571396689261164, 50.45464777177381, 49.37374845627816, 50.6657144331163, 45.58571161762361, 45.38038338384321, 41.49400488022835, 40.23038979499571, 40.93813442414807, 43.62875484651135, 45.09671757298131, 46.61383936482091, 45.37021660035657, 41.701074646365264, 37.61752251655825, 38.37494396394299, 37.06081267326109, 36.173654910056825, 36.62141699944773, 37.62196263959331, 37.72316763477941, 38.93158320457705, 37.911708124222294, 37.79694741772067, 36.68349635216498, 38.13461249874484, 38.24305034452869, 37.514207286219445, 36.94273364159369, 37.579938365567116, 35.71731851946923, 39.23902250105335, 37.009406089782715, 39.715837586310606, 42.625251739255845, 49.916173027407744, 51.109891476169715, 53.28741488918182, 53.1938349816107, 53.62196953065934, 48.62856480383104, 56.10711266917568, 55.432394396874216, 38.39941563144807, 49.4914823193704, 52.93862596634896, 51.912569230602635, 53.23281941875335, 45.45012312550699, 40.25128426090364, 39.47112483362998, 39.2459297949268, 42.23531715331539, 42.264927125746205, 39.908276911704775, 38.00189910396453, 38.19855497729394, 37.61649877794328, 38.01516848225748, 37.68822323891425, 36.64864217081378, 37.63735402014948, 37.89242575245519, 37.49148499581122, 37.38270982619255, 40.08557196586363, 36.64796360077397, 37.26188121303436, 37.337080893978, 36.618235957237985, 37.42497336479926, 39.97298425243747, 47.339328796632834, 49.146458871902965, 46.97550935129966, 49.75728173409739, 49.337827390240086, 51.080155987893384, 48.805475465713016, 51.573421493653335, 48.47295261198475, 49.2890017263351, 47.01550968231694, 41.783079639557876, 41.44765030953192, 42.375173184179495, 40.297376032798525, 39.82083159108316, 40.455349491488555, 39.11408324395457, 38.356873604559134, 38.4835857729758, 40.88531970977783, 38.51403905499367, 40.69591629889704, 44.401983445690526, 48.64198715456071, 53.29587936401368, 54.51008827455583, 57.11755444926601, 38.04946960941438, 3.8749318017113596, 1.2996041798783888, 7.750296044734217, 6.8252756422565835, 4.403986728960469, 0.1963605311128401, 0.04997581851878955, 24.380064472075432, 54.56813543073593, 39.20872611384238, 31.35928284737372, 22.77454814603252, 51.550585454510106, 37.65457714757612, 3.7876370020451087, 0.038258308364499005, 0.09762527315967506, 0.04813175295449553, 0.14716610312461853, 0.09795260720796163, 0.03893441543163311, 0.012350479768018329, 0.023844350662623203, 0.04698579267208134, 0.05942465504631401, 0.05692866781065541, 0.07658422398831576, 0.06263845517570454, 0.03148873986285781, 0.0851137473458244, 0.036994213493721145, 0.015230539438855505, 0.00902362134037239, 0.011361705405908007, 0.03184287358195551, 0.016960675279880245, 0.06210070358769548, 0.0970034932176913, 0.048030024139030326, 0.06764947842325895, 0.052059248255025, 0.02619071901145001, 0.020291367019977302, 0.0394635983262091, 0.09027736381657663, 10.648689808384066, 40.28880173160184, 50.71270835015082, 28.002130139258604, 23.017154585930612, 38.68188511940741, 51.186444374822806, 55.75603700453236, 58.52332407428373, 23.670792079740956, 0.047391593276012334, 0.7601320503219482, 5.427329674843819, 6.352079924075834, 1.1550204672159687, 9.630199324700142, 44.52973111983269, 58.66550607066001, 55.189340806776485, 54.50831536323794, 48.5020762105142, 46.98409934197703, 49.027156060741795, 51.314737258418916, 51.77592562090967, 53.172752241934504, 52.758816672909646, 53.75130576472129, 49.68917762079547, 48.171087003523304, 51.035456657409675, 52.683848411806174, 52.745857161860314, 53.250587755633944, 49.3119122905116, 46.53714526084162, 43.49691221790929, 43.631096501504224, 44.62597823912098, 45.52911573840726, 48.070513509934955, 49.89064624232631, 47.2152328491211, 44.727438188368275, 40.12982022377753, 39.95729869411838, 40.4305758014802, 39.409253366531864, 39.30923684950798, 40.514592970571215, 38.91250871842907, 39.10191212930987, 39.49338428435787, 39.61888051802112, 38.3782583667386, 39.22252108973842, 39.524829926029334, 40.32477378845215, 38.368158263544885, 39.51761276491227, 38.482844445013235, 40.73918396426786, 39.01794987340128, 42.76617073243664, 45.124523255132864, 50.47352613941316, 51.78567271078787, 52.92787082733647, 54.500858937540364, 55.0018201335784, 51.99426043418146, 55.442820056792236, 54.157769218567886, 41.07661762545186, 50.928564225473714, 54.4327469794981, 53.1399533825536, 54.785928956923954, 45.7130592100082, 42.452302671247914, 40.67309202686433, 43.308654139118815, 44.1319517935476, 43.36611293977307, 40.96807387567336, 39.82219657590313, 39.73323329802483, 39.689773436515566, 39.414117105545536, 38.99228972773398, 38.147870109927275, 39.3609493778598, 40.4035153696614, 39.39035538704165, 39.60748603267055, 41.09631969082741, 38.401227766467684, 39.168745394675966, 39.90873190664476, 38.55337258308165, 38.48039296365554, 42.3512428037582, 49.972278610352554, 51.064623402011016, 47.864549852186634, 51.64449091880552, 51.8575305323447, 52.26567668299521, 50.80632355905349, 55.417509002070275, 51.95170664018201, 51.14032906870688, 48.50746946950113, 43.49732014440721, 44.08697005241148, 44.25603205157865, 41.9845639505694, 41.57190315185055, 41.89808353301018, 41.007681969673406, 40.54323803993964, 39.50877958728422, 42.636359891583844, 39.496910495142785, 43.60658953266759, 46.59557288692844, 52.2509717172192, 55.25926489983836, 56.74888303202968, 57.29098204643496, 41.08423879069667, 4.230587078678993, 2.0059155504549704, 9.754668877970788, 8.16546323799318, 7.2040937408324215, 0.5066695929534974, 0.03378885182281656, 25.65190672874451, 61.510436457972375, 42.737568809140114, 38.256143216163885, 28.092727084313672, 55.054972171783454, 46.214357729881044, 5.781914389902546, 0.14599840126691327, 0.04268906980512604, 0.027787625459173036, 0.03744703657444447, 0.060579329578866886, 0.10634231951928909, 0.06611221575088079, 0.04925988637091172, 0.007969596875726336, 0.053996711428607666, 0.04714740275014793, 0.04208335472691444, 0.06170568950173836, 0.0812334583831891, 0.25165994441316974, 0.1817415357236901, 0.11134064485949856, 0.2262915403492028, 0.11888955269129046, 0.17678361386060717, 0.17285854705879766, 0.15918223818223323, 0.20763896946464816, 0.18887609724075566, 0.19600430022804968, 0.10463042710457118, 0.19935236492704964, 0.1418493763213196, 0.11467095164041366, 0.25528485796624617, 12.816164109014696, 47.25470758253529, 59.29889825082595, 33.416805267333984, 26.871599112787557, 43.3220451108871, 56.89131606009699, 57.99707535774478, 65.12724222675448, 26.282327713504916, 0.2196814885903751, 1.8787194596182917, 9.4376285999052, 13.505685406346476, 3.9346197343641713, 12.252642089320767, 45.04897448324388, 60.074448893147135, 59.017468190962276, 56.5829393171495, 49.17848502435992, 49.3687552790488, 50.26197702653947, 53.98062713684575, 53.30965865042902, 57.42629597263952, 55.514940677150605, 55.60769296461537, 49.204082412104455, 48.399761184569336, 53.30703458478374, 56.21568387554538, 53.55777994278939, 55.96723310409054, 50.79982811404813, 48.571023633403165, 46.57148561170025, 47.011916791239095, 46.1295521643854, 47.502460172099454, 50.60427050436697, 52.69277180394819, 50.41007787950578, 47.10262944621425, 40.973400454367365, 42.12483575267177, 42.02146560915055, 40.57257736882856, 40.53603264593309, 41.038260767536784, 40.72510265534924, 42.87875452349263, 40.55095726443876, 41.3782008232609, 40.5807045198256, 41.90207258347542, 41.61124452467888, 41.78959469641409, 39.989928891581876, 42.57764593247445, 39.21246805498677, 42.588044135801255, 40.08021793057842, 44.28365730470227, 48.024374669598, 54.62024804084532, 53.351137715001265, 55.52764131176857, 57.22042645177534, 56.17533445358277, 51.46533666118499, 58.921236761154674, 56.580958520212484, 42.825637786619126, 52.76552784827448, 57.164258110907774, 54.63873809383762, 57.43045760739235, 48.80190218648603, 44.79318103482647, 42.53165614220404, 43.45877109035369, 46.910029303643014, 46.757723669851984, 43.221350023823405, 40.7393487038151, 41.26413437627977, 40.52991767083445, 42.067016093961655, 41.757803886167466, 39.502899954395915, 42.06700432685114, 43.74019330547702, 40.10854921033306, 42.27045766768917, 43.04421578684161, 39.72838132612167, 39.46973239221881, 41.94755246562343, 41.65164493745373, 41.067392210806574, 44.95689292107859, 52.511001325422725, 52.05111911219936, 51.528173031345496, 53.30191589170887, 54.23228248473137, 54.54525624552081, 51.2478373127599, 55.896940308232466, 53.78206499161259, 54.56356979185536, 51.47710769407211, 45.29014141328874, 45.38563935987411, 48.07649904681791, 44.17340340152864, 42.879284043465894, 44.64196581994334, 43.55027214173348, 42.78630033616097, 41.742094793627345, 45.16738299400576, 41.72984130920903, 45.480125334955034, 49.65859490056192, 53.47473552150112, 58.05342020527009, 58.840369255312034, 59.06258721505443, 42.07593948610368, 5.553554488766578, 3.177283108234406, 15.771096387217122, 16.05371786702064, 12.972018507219131, 1.1486240620574644, 0.14237328853097656, 29.624795067694883, 66.90058892773044, 49.238881680273245, 44.523161149794056, 34.7099087315221, 61.51689660164618, 53.435076436688824, 7.78055222765092, 0.286431051189861, 0.14287467775565965, 0.12612596559788913, 0.20818785614063665, 0.1717690934216784, 0.2868606732977975, 0.2120154152714437, 0.11980887352218551, 0.0983660648606958, 0.25597695711879964, 0.12839581516961898, 0.14822013285611907, 0.16549100288219992], [0.03511097019297942, 0.03730707997155767, 0.1061550799697157, 0.04511572991407687, 0.0333200749610701, 0.034449591166189605, 0.034647295476808664, 0.019519401286097787, 0.08541020038988321, 0.00933971400598004, 0.03452120889579097, 0.05312839673171121, 0.03798641609929262, 0.01854397409084824, 0.04461112695055143, 0.021887059218340346, 0.029777261135619015, 4.047042463094958, 31.516944477635047, 43.27956584192092, 34.574987042334776, 26.65688660836989, 38.46293841638873, 48.402581368723226, 49.543991088867195, 54.89518657807381, 37.57014812961702, 1.1301959089694487, 0.3021740048162399, 4.166630871834294, 3.7406749542682403, 0.25751395932128357, 7.533738065150477, 42.021571513145204, 56.93683516594672, 54.769400089017815, 50.8751376213566, 47.80563192982828, 47.09124672797419, 50.96697207420103, 49.43113665426932, 50.81689434666788, 51.517315910708525, 50.16329411537417, 47.66284588844546, 48.26705955689954, 47.931528245249105, 46.22272414545859, 49.467528404728064, 48.65368366241456, 47.05499618284164, 48.771656790087306, 44.62407981195758, 42.787841827638694, 38.39865469163464, 38.992395631728634, 40.42005992704823, 41.765217165793146, 42.10773421872047, 40.38719046500422, 37.496289899272305, 39.27952489545269, 36.62706521249587, 37.40339248411117, 37.00730762174053, 37.117047694421586, 36.76656430767429, 38.92744902641543, 38.92184395943919, 38.13973903656006, 38.51042655206496, 38.72755719769386, 39.594236266228464, 38.474446650474306, 38.91461895358178, 36.1479006275054, 36.25675816689768, 39.586517041729344, 39.35017070462627, 38.75377039755545, 39.184544701730054, 39.82812719960367, 43.58720910164618, 49.222976469224506, 51.96545454763597, 49.83360321291032, 55.32367021806779, 47.93310896042855, 55.25987678958524, 53.11654075499504, 37.848126503729056, 54.03300254575668, 52.296443754626864, 53.006784992833296, 48.488124339811264, 44.14834730086788, 40.921036812566946, 41.928309317558046, 40.57450325258317, 43.430494723781464, 41.208966239806145, 41.79709426818356, 39.36336948025612, 37.18038612796415, 37.13441987191477, 38.852265034952474, 38.640963031399636, 37.098204628113784, 38.11522422298309, 39.5981704035113, 37.3932727690666, 37.50615466025568, 37.29523704897973, 39.54463005065918, 37.636581313225534, 37.522891413780954, 36.69323559730284, 36.656510445379446, 36.97710537141369, 38.667937171074655, 43.40463061486521, 44.89943804279451, 46.64862686587919, 46.72337155188284, 47.97631386787661, 50.481841564178474, 49.71132332278837, 50.27681143053117, 49.305310941511586, 48.635166152831054, 48.62590935922439, 46.608214685993815, 46.620570152036606, 45.22866218320785, 46.74743137051983, 45.2791234754747, 45.22988988507179, 45.716487361538796, 44.843924737745716, 42.01776289170788, 41.312222634592366, 43.25091292781215, 47.255131198513894, 49.96582631141909, 53.109653072972456, 57.51141140537878, 54.98433028498004, 35.468283314858716, 3.3473605109799296, 0.8399893006970807, 7.50667174977641, 10.097801743015166, 3.785802068248872, 0.660294185002004, 0.16745865375043886, 29.907125311513102, 52.45318166671261, 36.788015750146684, 37.90373786803215, 33.63404573932771, 52.50880087575605, 31.932447033543742, 1.5397036123660304, 0.09832009192435973, 0.06809615364838993, 0.018490692675714532, 0.019253827331046906, 0.05439787337015714, 0.03565292377325316, 0.10133143033712141, 0.05934284834731972, 0.04740724828274501, 0.05259501567531017, 0.03950724235525535, 0.032922624715513764, 0.013111269236692499, 0.01771089752324887, 0.04119260514515542, 0.05082112759531987, 0.048012641604028405, 0.03307358617143285, 0.02460132214060474, 0.03109359362673375, 0.04065969906326744, 0.09731093196258431, 0.04400695936994688, 0.05580384389407212, 0.013654667850313409, 0.06741556113645916, 0.07916443109993013, 0.07354423388718598, 0.019851599992703528, 0.0404600833632773, 6.650794888696363, 38.9457586503798, 49.8619854834772, 37.709176540374756, 24.64671111875965, 42.895150030812914, 52.93386813132994, 53.375938861600815, 60.502395168427505, 37.26588203061012, 0.9805583449140672, 0.3927753931812702, 4.8081472612196405, 6.837231026541803, 1.3156698403819915, 8.699956286338068, 45.33284033498457, 57.88526819598291, 56.0032836083443, 52.50550216244113, 50.09881427211147, 49.934572865886075, 51.23458754631781, 52.50143466457244, 51.52778863906861, 53.933099777467795, 51.44356750672864, 48.084437924046675, 48.59966478040142, 49.26451044697916, 50.051047648153, 51.99495469370196, 52.810321315642334, 49.127796234623084, 49.23537115896902, 46.90195706582839, 43.75273704528809, 40.69064071101528, 43.013723281122026, 42.87499689286755, 44.13890223349295, 43.40543862312071, 43.40537586519795, 39.065202666867165, 41.928525047917525, 39.48358620366743, 40.08631721619637, 38.81947009794174, 37.963742286928245, 39.495533743212306, 40.469277827970444, 40.032823931786325, 40.02763071367818, 39.531996096334154, 39.64026135783042, 40.69713223365046, 38.81242552111226, 40.2502840565097, 37.826129851802705, 38.40897444755801, 40.53950786590576, 41.152021269644464, 40.47857776764901, 41.47573447996571, 40.56668204645957, 45.29492670489896, 52.022191632178526, 53.414872307931226, 52.20053788154356, 55.38307059195734, 48.554369249651515, 54.706606864929206, 51.95637818305723, 39.75157822332075, 54.525993485604566, 54.14628059633317, 54.30069646527691, 51.49498585731753, 46.09540008729505, 42.836687103394546, 43.66153801641157, 43.861610274161066, 45.33128707639633, 43.15127688069498, 42.65613648199266, 41.1405679487413, 39.3298489047635, 38.87726622243082, 40.386762926655436, 40.794693346946474, 39.24654168467368, 39.05047808924029, 41.34735922659598, 38.14262197863671, 37.74509368404266, 39.771233220254224, 40.20190162043418, 38.350205575266195, 39.39146934017059, 40.181332711250555, 38.38416153384794, 38.837799333756976, 42.29756516795005, 46.80428612616755, 48.07205500141267, 48.70261915268437, 48.41037904062579, 50.44843865979103, 51.735533052875155, 51.045356719724595, 52.46979290439237, 51.15908192050073, 51.30185619477303, 49.59029074638121, 47.7636625689845, 47.98702978318738, 47.6376917285304, 47.29717116202078, 47.437062494216434, 47.44431103429487, 47.913536333268695, 44.81585233442245, 43.54246662509057, 42.791211143616714, 44.5316138575154, 48.5905138907894, 52.41076515566919, 56.30376854250508, 58.02375924202704, 55.85266851609754, 37.45015498130552, 4.251840441457687, 1.968441470976799, 12.062060006203192, 8.792413415447358, 6.300058018776679, 0.6415261340237434, 0.09675139666444833, 32.76072413690629, 57.0591111336985, 43.78015049042241, 42.99804164517311, 35.63107736649052, 60.442849666841575, 38.539326575494584, 2.608056981717387, 0.04942845635777039, 0.07293208367041043, 0.04225084452979988, 0.030018686084076766, 0.049819165029593056, 0.004586167642921811, 0.01896490876172339, 0.02884439012456325, 0.04036852819544654, 0.02734236366626236, 0.01516386776441528, 0.04261544492516307, 0.026931332597028346, 0.11467938626845998, 0.14525791600106225, 0.22786727595713832, 0.19041239464234924, 0.14507658298938506, 0.14095645488029526, 0.17726974261383857, 0.1423459851573552, 0.1491806692173404, 0.08887059656122039, 0.16466223364395483, 0.11636468777132612, 0.1488934322110107, 0.16006299414702002, 0.1969151328047437, 0.1213727500890532, 0.12787116751555475, 7.687480267017119, 45.99164555149694, 59.272253590245406, 48.82920188288535, 39.0718432395689, 53.44273290326519, 58.87498417208272, 58.682144764930975, 63.90365100676014, 45.42259985400785, 1.3865188773601287, 1.3718677215999173, 12.522421729180122, 9.739889387161503, 1.9398334189768762, 9.793625858522232, 47.78871866964525, 59.679681947154386, 57.627250763677786, 54.99124934596401, 51.95293434204594, 51.559249970220755, 54.83311114772674, 54.930232955563454, 55.272616647904925, 54.20306474931779, 52.00000278411373, 47.16909008641397, 50.01690341580299, 53.32551287066553, 51.64280429963143, 52.600647095711004, 52.74743003229941, 49.96785417679818, 53.566126746516076, 48.90468789685158, 47.10543394088746, 41.283557953373084, 43.711269747826364, 45.639216669144176, 45.87995606084024, 45.99394406041792, 45.51537567569364, 41.25477167867845, 44.662060122336115, 41.59236615703952, 41.63265282107938, 40.61071457401399, 40.73811315721081, 40.033451511013894, 41.869999362576394, 43.81624414074806, 43.0289577668713, 40.5137731952052, 42.01000836587722, 43.251838607172814, 40.99720531894315, 42.4358836297066, 38.157946678899954, 39.55293763068415, 42.165459740546446, 42.89647186956098, 42.70887274895945, 43.288367640587595, 42.49102430958902, 46.67254547918997, 54.847027717098115, 56.88379687647666, 54.36737283583611, 57.996738033909956, 49.89015594605477, 53.48469441936862, 53.142283270435954, 42.548337982546904, 55.68152373836887, 57.58174342493857, 56.66745854962257, 53.34071989982359, 47.64156310789047, 42.806578989951845, 45.445628089289514, 44.72714793297553, 47.112145116252286, 46.13932671085481, 44.83020820925313, 41.82413116578133, 39.94605325883435, 39.7210661057503, 42.522862188277706, 42.923069461699455, 40.161916978897594, 41.01984916194793, 45.09811393676266, 40.22619678128151, 39.81743874088411, 41.59273485983572, 43.03806551041142, 41.248437050850164, 42.55932846376973, 41.8522310256958, 40.764385192624985, 40.34518188045871, 42.73850233324113, 48.222677938399784, 50.18289027675506, 51.00882768630982, 50.440460558860536, 53.13384232982513, 53.26246861488589, 52.61506180609427, 54.84463114892283, 53.83498560997748, 52.303449107754616, 53.04857000227898, 49.96827779277679, 52.25512942960186, 49.07587189828196, 49.2246630883986, 49.9518548288653, 49.39394474029542, 50.76453070486746, 47.43159078782605, 46.37734005528112, 46.122131040019376, 47.405240305008434, 51.496994110845755, 54.41383331052719, 58.882118963426166, 61.113849532219675, 57.911026400904504, 39.04486517752371, 5.201789467565475, 2.1379898440453315, 15.708442407269633, 20.57474567044166, 13.659063808379637, 2.0891909012871404, 0.22021407291533487, 37.640029076607, 64.28653317113077, 47.6749110990955, 49.881369836868785, 46.66639912512995, 68.1690912861978, 47.47788260059972, 3.683829514249679, 0.23637238409250017, 0.18889509622127781, 0.10952347664222603, 0.11959387860711544, 0.1415991873270081, 0.12320002300604699, 0.2347802695247435, 0.11184144419647994, 0.18749657207198683, 0.15879848941920266, 0.095620229539852, 0.168434297365527, 0.11995579386430404], [0.008128078921037096, 0.051290122792124755, 0.07317922363478331, 0.06389660137375036, 0.01504368580607397, 0.07390304648828122, 0.024956493908839843, 0.04531798478696616, 0.044150386351130666, 0.12915264875177415, 0.053407352327579455, 0.02549298145177384, 0.07216003558207905, 0.029383202744347435, 0.030197129029059605, 0.05875832326109371, 0.09850494894048861, 1.5714234522273465, 18.46741699403332, 48.50392364686536, 43.93338572594428, 29.310985842058738, 22.079304110619333, 30.493900122181063, 50.26536595436835, 52.54963274924986, 45.45290408595916, 5.450028431031012, 0.003398590831033465, 3.751276630547739, 5.6515686358174975, 0.9306037738438576, 6.81910575397553, 39.475549267184356, 55.986884178653845, 54.87255842454972, 51.084541197746034, 49.81497195459182, 51.313756665875836, 51.36926997092463, 51.08262708110195, 53.90237977427822, 50.26453833426199, 47.03001460721416, 46.18861913681031, 46.71986103057862, 48.78298459514495, 49.8356036216982, 50.04326566573113, 49.83928280491983, 47.582986431737105, 45.75120818230414, 44.40427410987116, 43.079313155143495, 40.35418764237435, 38.15889981485183, 38.31112307886924, 39.63352272587438, 39.33095109078192, 38.1763308278976, 37.803776264190674, 36.50983341278569, 37.45258685081236, 37.92849586855981, 37.64878380683161, 37.42143538690383, 37.575408028018096, 37.41413585601315, 39.34476567852882, 40.67115045362904, 39.964100083997174, 38.692985426995065, 38.44464448190505, 37.65747577913346, 39.9899406586924, 38.73451156000937, 36.458603335965066, 36.45558311093238, 38.28597676369452, 38.22140670591785, 39.783106234765825, 37.59745959312686, 40.498742672704886, 46.95095139165079, 52.924799611491544, 51.10811464248165, 53.807948712379705, 46.74969065573908, 60.89489498446065, 53.588625461824485, 39.51534563495267, 56.09614572217388, 50.20576553960001, 50.411972384299006, 46.18577541843538, 44.813338095142, 42.40729347352059, 44.468549989884906, 44.6423815911816, 42.91668384305893, 42.11990533336517, 42.817047795941754, 38.1296742346979, 36.63120723539783, 37.4541675659918, 37.614757245586766, 38.25841426849365, 38.01746699117845, 38.435956431973366, 39.66933004317745, 38.0126581653472, 40.50647758668469, 38.65290272620417, 37.06193839350055, 37.307863158564416, 36.26010787102484, 36.40363131800006, 37.05730215195687, 35.73056044117097, 35.57290077209473, 36.34023012653474, 39.36351068558232, 42.72648811340333, 46.169803527093705, 48.47674946631155, 50.84890480964415, 50.654931837512606, 48.79347301298573, 52.35444776473507, 50.4047473784416, 50.98799597832465, 49.368739589568115, 48.53099192342451, 48.889704442793324, 50.443472939152876, 52.65565833737774, 50.93324753545946, 50.289512065149125, 48.87356781190442, 49.45707136584867, 49.89486279026155, 50.21822690963746, 49.60388960376863, 54.50476954060217, 53.78504991531373, 57.351096291695875, 51.81747921051518, 28.829707099545388, 2.555499427741574, 1.5928549151266775, 9.582523895848183, 4.9880752063566645, 5.606151021295979, 0.2094062423754123, 0.23641133200257058, 29.711822655893144, 51.58048960470384, 31.44138001626538, 22.293689097127608, 31.300857182471987, 51.828987444600756, 22.2745910767586, 0.432870565883575, 0.030126501468100378, 0.021740269111168962, 0.08212448758704048, 0.05350889345150321, 0.040741513423140974, 0.043649954736352935, 0.01682141581700454, 0.03280305754273169, 0.026072469509897694, 0.030633004329678033, 0.04154409777613417, 0.022063322643178607, 0.07119924641184269, 0.04480872783930071, 0.05663338688112075, 0.07222025775380674, 0.031141610102607842, 0.01628128169555097, 0.05188025181151686, 0.009778685259422468, 0.062290494210056724, 0.049588518938229936, 0.09444649090930339, 0.07072949661843239, 0.0782160142496709, 0.0794401691265164, 0.03908656049339522, 0.02470460228411661, 0.013966537456238463, 0.09413790303252398, 2.6725299608322883, 26.685398317152455, 55.622907838513775, 50.39040327072144, 30.963486279210738, 29.645424773616178, 41.99941796641196, 55.471527884083415, 59.692500252877515, 49.39534502644693, 5.043636070143792, 0.17980098904621217, 5.327152340642868, 10.760461668814383, 1.2717922464493783, 8.216404530309863, 41.71408122585666, 57.19295417108844, 56.20999643879553, 53.946933977065555, 51.93879027520457, 51.94400310516358, 53.38019463323778, 53.104499078566036, 54.8937862919223, 51.20065904432728, 49.33339511194537, 47.07096415181314, 49.525897195262296, 50.29822364930184, 51.97855526401151, 52.43683715020457, 53.08646794288389, 49.698097090567316, 46.78696886185677, 46.89537532867924, 44.155897863449596, 42.17521859753517, 39.00918729843632, 40.22374922229398, 41.41538489249445, 41.765162252610736, 39.5508195507911, 41.60241919179117, 39.88808847242787, 38.7297615697307, 38.94474275650517, 38.25935955970518, 39.669467326133486, 40.55713891983032, 38.52997956737396, 42.054535112073346, 42.03828865481962, 39.74202332958099, 39.59524431536275, 41.196822581752656, 39.64689016342163, 40.87483521430723, 39.57183561017437, 39.047877557816044, 39.29084485576999, 40.16359967570151, 38.59762868573589, 40.880785449858635, 39.138613747012236, 43.08654208337107, 47.791895789484826, 52.769246255197835, 53.858974825951364, 55.00636616060811, 48.293614002966116, 58.15233453627556, 51.72356590147942, 43.19006519932901, 56.81460234426684, 52.769532588220414, 52.747583004736136, 48.96955997713151, 46.76627443682763, 43.61632485543528, 43.87762531157463, 46.27275005463631, 44.835546555057654, 44.3281840508984, 44.051590273457194, 41.10422718909479, 38.6526281602921, 40.12175975307342, 38.54334700492121, 40.689609127659956, 39.059660357813684, 40.302545716685636, 42.040610697961625, 39.167674587618926, 40.74429873497256, 38.54553176510719, 39.633565871946274, 37.66448897700156, 38.72945170248709, 39.1267878009427, 38.78739687704271, 38.311299585526996, 37.60976799072758, 39.210357819834066, 42.74796701246693, 45.31393843312418, 48.251166112961315, 49.99755044137278, 52.81535763894358, 51.18453810291906, 50.800377245872255, 55.06639411372524, 53.02243524982084, 51.99472719623197, 50.492278991207, 49.38353869222826, 50.565219386931396, 50.90580663373394, 54.516097345659816, 53.16786889106997, 51.49265596943518, 51.80819103794714, 50.48255935792, 49.59526038938954, 52.05484928623323, 50.146529905257694, 55.12449618308775, 56.03236406080185, 58.44803025645595, 51.60999367314001, 31.39762401580811, 3.4829154178019497, 2.5971971644509226, 10.281934468976914, 7.470642818558601, 5.140175406009921, 0.12190485177862069, 0.19179769611406713, 35.71639284010857, 56.91721939271497, 39.87305794992755, 32.44802101965874, 37.92016475431381, 55.84719680970716, 29.957429708973056, 0.8104695427802302, 0.031424576168759696, 0.03772453660325658, 0.15877466408475754, 0.02390830942820157, 0.07239763009091539, 0.026862865404015588, 0.01476281307517521, 0.017836329099091313, 0.06144100995433908, 0.01116215865383105, 0.029463912022390196, 0.023898428809198163, 0.00544446143096373, 0.1302731902368607, 0.2037961958276649, 0.13595986089879467, 0.20083612401879605, 0.14785182842564198, 0.17336752055393112, 0.12429210432474652, 0.17362069729114735, 0.08231948760728683, 0.2495831719809963, 0.11450335458521882, 0.15121369802903745, 0.20014169595895276, 0.13957217996639593, 0.12134528583696774, 0.08167276384248849, 0.20909082865522755, 3.028923869132996, 31.42761641933072, 64.84591022614511, 59.053287275375865, 41.457130678238414, 34.53664587390038, 42.380574287906775, 61.60475769350606, 64.05028097091183, 53.62331098125827, 7.0128973164866055, 0.376670723480563, 12.185205759540683, 14.673140645027162, 3.5878829465758417, 10.622767844507772, 42.80535913282826, 58.95711860349102, 59.3748902505444, 56.57374135909542, 54.481196095866544, 55.868758078544374, 56.46442882476315, 53.42880064441312, 55.24344205856324, 53.49112710645122, 48.556726594125074, 48.22079520071707, 52.24546470949727, 52.553684557637865, 53.142997141807314, 54.622636764280266, 54.40028544395201, 51.87700510025025, 49.769519529035016, 50.25419896648776, 47.01304643384872, 44.48286664101386, 40.893458627885394, 42.92514047315044, 43.408866774651315, 43.360178393702355, 43.18231851823869, 42.84139002523115, 40.251182279279156, 41.125706088158395, 41.22520877468971, 41.16920125099921, 42.23971413027856, 41.50286943681779, 41.13488051199144, 44.91573156849031, 43.0946849238488, 41.611095474612334, 41.94228472248201, 43.3816651375063, 41.761188891626176, 44.24668504345802, 42.149613365050286, 39.9247940125004, 40.40555107978083, 42.389368241833104, 39.56743471084103, 43.59282201336276, 40.620140029538064, 44.3272779833886, 50.513789269231985, 54.87324091695971, 55.9677351674726, 55.598840175136445, 49.51218458913988, 57.442499283821356, 53.35714286373508, 43.66288731175084, 58.05754653869137, 54.51405379080004, 54.4074280800358, 50.34137756593766, 49.093546098278416, 47.59810716875138, 47.03783189096759, 48.477941866843935, 47.34481227013373, 46.502314613711455, 46.38694593983312, 43.15677212130639, 41.09270326552853, 42.53592368095152, 42.14322774640976, 42.51690018561579, 41.36200927918957, 42.42694062571372, 42.62534979851016, 41.089177054743615, 44.11968654201877, 42.37789138670891, 41.232249429149014, 40.95709516156105, 38.250169446391446, 40.80469539088588, 41.692480733317716, 40.28848794198806, 38.38998233118365, 40.96574006542083, 44.70234678637597, 47.36602052565544, 50.14595331684236, 52.25438810163929, 54.9908531865766, 51.91136898532991, 51.00472880947975, 55.77995561784314, 55.42167455919328, 55.30095577239991, 52.62104342060705, 51.150589989077666, 53.625013289913056, 52.99952076327417, 58.06545403695876, 54.98047067273048, 53.64126366953696, 54.4209445676496, 53.55964306862124, 54.27399296914378, 55.6229470622155, 52.73382725254182, 57.73986593369515, 57.38062781672324, 60.519100542991396, 53.39805318463234, 34.47735924874583, 4.282986512107234, 4.131690888635574, 19.82479241586501, 10.654240942770436, 11.470727401395, 1.0567880157501468, 0.4552660125397867, 37.3972108287196, 62.95304498364849, 41.34611975762152, 34.080509524191584, 42.61934072740617, 65.0832724571228, 34.923760275686945, 1.0656692424128134, 0.19069207802174554, 0.1505235140962947, 0.2647533982751831, 0.2025579219503749, 0.11182838239737096, 0.0676236612602107, 0.0800439153587626, 0.18373979946538327, 0.20831384696066382, 0.14501722649701182, 0.15205153774830604, 0.1386799786480204, 0.17904668355420714], [0.05898971628818301, 0.0600478905553539, 0.07065140161543124, 0.02248424007707546, 0.011114333699938032, 0.059981125992752855, 0.010483190248299752, 0.019063033133504853, 0.01813748783822502, 0.04369156863239985, 0.04757282286581974, 0.06826502240953908, 0.04447371759001286, 0.02506099404737113, 0.08610675051327675, 0.034563259461954716, 0.03643480460009268, 0.2660323667430109, 14.867747079941536, 41.21779157269386, 39.31311215123823, 36.065244520864184, 57.22708663632793, 45.12214237643827, 38.021895347103, 49.85537236736667, 56.995407919729914, 16.413920887054935, 0.2811101721900125, 2.882902852950558, 7.5188208010888875, 0.3859528286322471, 4.739016957821385, 35.25123896137361, 55.9214472770691, 55.15531424553164, 51.4771939862159, 51.561834812164314, 52.03577480008526, 54.65655349916028, 53.81788407602618, 49.796066130361254, 47.11970744594451, 47.03661595621417, 46.398681671388694, 49.677030040371804, 51.042587526382945, 51.05903010214529, 49.94497891395323, 51.65925079776395, 47.39817219395792, 47.528414495529674, 44.18677476144607, 41.91156079692226, 38.641563154036, 35.84525446737967, 37.586253381544545, 38.01443107666508, 38.83660301085442, 37.491543831363806, 37.32688273152998, 37.32725143432617, 37.19448704873362, 38.822098085957194, 35.42850263657109, 37.484165853069676, 37.665422501102576, 39.918404471489694, 39.67771999297604, 38.558652093333585, 38.575196650720414, 36.7275288797194, 36.79088692511282, 39.65047128738896, 38.365910745436146, 37.38986815175703, 37.44973528769709, 38.825714511256066, 42.779534247613725, 42.489416137818374, 41.46046469288488, 40.72326306373843, 40.04459888704362, 43.055688719595636, 51.21321062887869, 51.84748926470357, 52.73567076652281, 46.813954768642304, 61.72391537697085, 46.432268927174235, 43.95855165296986, 56.372629673250266, 50.99460909443518, 52.332760980052335, 44.577854679476836, 43.343759352161044, 42.412969143159934, 44.86191664972613, 43.56497710750949, 46.446409071645434, 43.51655937010243, 44.25720484026017, 39.944590214760076, 37.468068445882494, 38.16939215506277, 38.308679442251886, 38.00865734777143, 38.602151178544574, 37.17207854793918, 37.40040363803987, 37.00285573159495, 38.87379100245815, 38.505131352332334, 38.98202488499303, 36.147273048277825, 37.55290539033952, 37.80793789894351, 36.79264806932019, 37.14484553183279, 36.47012725953133, 37.08151494303058, 40.672660566145375, 42.08485503350535, 45.601636440523215, 45.40482367238691, 48.145105223501886, 49.55289879152852, 47.77391172224476, 48.484998210783935, 51.254426894649384, 49.69573974609376, 51.98710210861699, 50.450089977633574, 51.85517318787114, 50.671037089440134, 42.46099464354977, 49.6391164102862, 54.03413218836631, 51.78511181185323, 50.28793527233986, 50.19843855211812, 49.780929703866285, 52.759758041751006, 53.1861275242221, 53.387988382770175, 56.47793746763661, 49.6229640899166, 24.507663096151045, 2.0571463627199975, 1.9169751939273652, 11.779237504928343, 5.305249825600655, 2.4429499574245948, 0.0745121936403936, 0.44346822786235046, 29.448841464134958, 36.907373474490264, 34.75134072765228, 30.77983698537273, 37.30728264777891, 51.53618643360754, 11.626833811883005, 0.118750837150841, 0.014516736057797268, 0.048943764019397, 0.10088828677732138, 0.007451852152664816, 0.09084589298694365, 0.03358849684797949, 0.102535268562215, 0.012806117264253479, 0.024458102003160506, 0.0017224283980002868, 0.018757595793314038, 0.03816272357418653, 0.015484638354410569, 0.026234878234625347, 0.08179821074008942, 0.04871978289297512, 0.011174547253176572, 0.05507687624964503, 0.0519717303705552, 0.04497869210618158, 0.03923858298108943, 0.13117593292507435, 0.061659674430566455, 0.06382932736267967, 0.04162712638536769, 0.052225259508216576, 0.08895670484390952, 0.0886335306530518, 0.06998390154612642, 0.07020701699319386, 0.7939999394359127, 19.277345249729773, 51.7797460094575, 48.71290752964635, 38.87257506770473, 43.14209068975141, 40.391505072193766, 45.75914313716274, 55.18117050970755, 58.92666532147316, 16.63830791750262, 0.15648193146672942, 2.4214239899189245, 10.190489311372081, 1.5886187553405764, 5.595468446131676, 38.76501975520965, 55.22227694911342, 55.81262111663819, 52.03857537238829, 53.21932254299041, 54.04119245467648, 56.18136313653762, 55.42994291551652, 51.575920043453095, 47.09669882251371, 46.4871193516639, 47.39604626932452, 50.03584061899493, 53.34353616160732, 52.71160310314548, 51.46157903055991, 53.09905875113703, 48.29795998911704, 48.44117356884865, 47.2593673583, 43.77081917178246, 40.46969359920871, 39.28060746962024, 38.793123537494296, 39.34176898771717, 40.7939245623927, 39.78692662331366, 40.01120774976669, 38.948606291124904, 38.276359112032004, 38.953489641989435, 38.91819615517893, 38.69584875722086, 39.20531757416264, 40.28339670550439, 42.07797519622311, 40.36696672439575, 39.921146208240145, 37.871217496933475, 39.67904575409428, 41.50147699540661, 40.09084363137522, 39.081405978049006, 38.31824218073199, 39.183866131690245, 43.40297145228232, 44.44720445140716, 43.42746665400844, 41.717152441701586, 41.355368706487845, 44.35555042759065, 51.51675501177388, 54.433111759924124, 54.3696125092045, 47.24826705071234, 58.81137509499827, 48.37198295900899, 46.7879847557314, 56.853441653713105, 53.41748068409582, 54.76675641152167, 46.89402603333997, 44.27851899977654, 42.41545984821935, 45.11923197777041, 46.177467838410415, 48.25815969897855, 45.156451348335516, 45.17232518042288, 42.724295508477, 38.71203245655183, 39.11141603223739, 39.63857866102649, 39.537397200061434, 39.794296756867446, 38.33652042573498, 39.57959405837521, 38.504080157126154, 40.39639626779864, 39.67443304677164, 39.92987740424372, 38.55946010158908, 39.16099479121547, 37.50882579434303, 37.76584694462438, 39.61242429671749, 38.25435069299514, 37.40418088051581, 40.357635405755815, 43.83874285605646, 48.18437207129694, 48.70684354535995, 51.14609495286019, 50.77783538449196, 47.70556834436233, 49.787919367513354, 53.14609189187327, 52.37787215940414, 54.067060485962905, 53.47030716557657, 53.1756861748234, 54.01838387212446, 45.77857455899639, 50.27430895836123, 55.76479565712714, 52.76899130113664, 52.92760802853493, 52.735019653074204, 53.00287046740132, 53.75223144408196, 53.1253307865512, 56.523778207840465, 56.18679954159645, 51.49233433508104, 26.77221998091667, 3.9882098522878464, 2.5816067236085094, 11.355976500818807, 9.200943958374763, 4.707639957627943, 0.061133854661978064, 0.4138635567599728, 31.213692311317693, 45.90409824925084, 35.20439017203547, 29.017874963821907, 39.86379723395071, 57.84455791596444, 16.559566336293376, 0.17558532977296462, 0.018549156675655997, 0.014312442433419488, 0.023531091564725486, 0.049701919103221553, 0.02930121792991075, 0.0340112318254767, 0.0035205668715324497, 0.07144796451733959, 0.01764023931877267, 0.03614638781835956, 0.0836195924409455, 0.02733771925822141, 0.05348083548127644, 0.1350368322023461, 0.3057485404274156, 0.16904667740867985, 0.13806534630637016, 0.13824871711192593, 0.15369573097315528, 0.11694083951653973, 0.18146399739048175, 0.2514523805509652, 0.13435230199848452, 0.11491424584340666, 0.14264616904960525, 0.06152564351777397, 0.24230323761941927, 0.2042022530710505, 0.2091333771785421, 0.11916534434403143, 0.9836162614726252, 24.31141907168973, 58.49691475591352, 53.897374829938336, 50.359773482045824, 66.08798365439138, 55.73356966818533, 51.65150411667363, 58.87305828832812, 67.22303129011586, 20.602553313778294, 0.6301338550063872, 6.99283488335148, 12.706411288630578, 1.4273675435012387, 6.349846134262701, 40.838694495539514, 58.547540787727606, 58.857121698318, 54.93578310935728, 55.98079273777624, 55.91738762394075, 58.77445382456626, 56.183849919226866, 50.786346927765884, 48.32983709150746, 48.26989150816395, 50.03381667598602, 52.86611310897335, 57.86738611036732, 54.66854026240688, 53.91704159398233, 56.2052542932572, 52.45315813249158, 50.987450768870694, 48.722187857474054, 46.19381235491845, 42.439284324645996, 40.59286386735978, 42.79653379994054, 42.929325642124304, 43.31520841967675, 42.884716526154556, 41.26338128120669, 40.16874974773776, 39.895458605981645, 41.965771875073834, 39.775061453542406, 40.436863360866425, 41.13390384181854, 43.48176402430381, 43.04322342718802, 41.35640813458351, 42.78026773083595, 40.82298932536956, 40.10604281579295, 44.42367807511361, 41.91729922448435, 40.92751656809161, 40.043198600892104, 40.75020582445207, 46.35909318923951, 46.52010256244291, 45.42206641166441, 45.3880633846406, 44.944258966753566, 47.52980301457067, 53.53687763214112, 54.87520994678621, 55.80187774473622, 48.24975798206945, 60.94416779856528, 52.274301975004136, 46.76712166878485, 59.27921187493109, 55.00507962319159, 55.747278351937574, 48.45878501092234, 46.53922803940312, 46.03077511633597, 48.2810781078954, 49.51013318953976, 50.35878112239223, 48.05540454003119, 47.29125230543075, 45.969739114084554, 39.896066573358354, 41.62987970536755, 41.64649094304731, 41.15364120852563, 42.29938122533983, 40.14054398382864, 40.86403300685268, 39.6255720815351, 41.11260929415303, 41.99401294031451, 42.18417729100874, 41.41283927425262, 41.48309676877914, 40.52022157176849, 40.37069297605946, 42.835690821370775, 40.49478107883085, 38.823859230164565, 45.005557767806515, 45.603079872746626, 50.88054264745405, 49.08716832437823, 50.059441520321755, 54.18642605504682, 49.598210011759114, 49.95750696428361, 55.138620638078265, 53.66509599070395, 56.65493442166237, 55.8283184420678, 56.4465545838879, 54.878469436399406, 47.992481877726895, 52.77460029048305, 58.71919939594885, 55.92030586734895, 54.24659913586032, 54.32823150388656, 54.49874085764731, 56.52980296842514, 57.79037037203389, 57.6875925064087, 58.2391248210784, 54.091806719380045, 30.252605715105613, 4.469325080994637, 4.159802515660563, 21.79517742126219, 15.579387603267548, 9.532456801783654, 1.219862271701136, 0.6771294880778559, 36.61663563020768, 49.31383032952586, 45.7779352126583, 42.32224472107426, 47.93585461954917, 66.46399774859029, 21.040905637125817, 0.3648602523871007, 0.15409941334397564, 0.06150742211649495, 0.13804553527264826, 0.11869409301828955, 0.1415179666852759, 0.1309668522087797, 0.2004092138621115, 0.1165059850280804, 0.1236284500168216, 0.19516970872158007, 0.17462113151146522, 0.19488788029599577, 0.1436744429050915], [0.04302650855313386, 0.07169471377687109, 0.0500297166347023, 0.03621213348402131, 0.07800930840594154, 0.08696806316654529, 0.030340176796720877, 0.05306330607122472, 0.016168354589852597, 0.036589282399584214, 0.045492537920513464, 0.059765073876347274, 0.02450719674778802, 0.009099751327847762, 0.019800760482828465, 0.04013342347236411, 0.09045114320132042, 0.042353756951108094, 8.67549442475842, 38.65471486122378, 43.51263307755993, 51.444830509924124, 77.35117943056169, 70.83344751788725, 43.075712419325306, 41.66997809563914, 51.327002509947754, 20.48749646832866, 0.03417614374249693, 2.240441417501819, 11.705944095888446, 2.006609442253267, 4.820250224682593, 34.601161018494636, 52.0545982545422, 57.16822362715199, 52.00916936320644, 53.7224292755127, 55.59637300429806, 55.191537334072976, 48.0551338964893, 47.37751307026033, 48.726663281840665, 49.8635858105075, 47.41865088862758, 49.56792539165866, 52.41592307244578, 52.11077444015011, 50.153394053059245, 51.20051783900107, 47.85970572502383, 48.17488385785011, 45.74580315620669, 44.96354133852067, 41.35607473311886, 39.94269178759667, 37.14038971931704, 38.29057378153647, 36.156435705000355, 36.578051274822606, 35.92701235125142, 39.057342237041844, 37.93934906682661, 38.00054196388491, 38.809475898742676, 41.676877544772246, 37.49482293282786, 39.122304531835745, 38.02929685961816, 38.09733821499733, 38.81931320313485, 36.59082251210367, 38.11770316093199, 36.14577862524217, 37.16858371611565, 38.15760151032479, 37.756025329712905, 40.91261940617716, 44.98190587566745, 45.43386490114274, 46.03009262392598, 42.61194313726118, 39.024817943573, 43.42227735827046, 47.18559934246925, 51.92652894604591, 50.245836473280384, 51.24251073406589, 49.99522055349043, 39.98059757294194, 51.7691909113238, 53.636337172600534, 51.450372818977606, 48.50606526097944, 45.557976538135165, 41.77505447018532, 42.76916350087812, 44.951499662091656, 46.95223008432696, 46.04247946893015, 46.777013886359434, 45.49925473428542, 38.922773561170025, 36.45606556246358, 35.90353304339994, 36.77097697411814, 37.13034845167591, 36.85853212110458, 37.986241002236646, 39.347279917809274, 37.33622189491026, 39.59182400857249, 37.37570447306479, 37.30179132953767, 35.39316208131852, 37.11220748962895, 36.923953333208644, 36.209599510315925, 36.628430197315836, 36.784446393289876, 38.402686888171786, 40.313045901636926, 43.76559457471294, 45.398414519525346, 46.07860449821719, 48.77486528888826, 51.20283595977291, 48.84919812602382, 49.075667935033, 47.54761841989333, 49.36296978304463, 47.49099900645595, 49.35950633018248, 48.857843029883604, 42.31927548685382, 44.681903393037864, 49.223349094390876, 52.7839159196423, 53.25808732740341, 52.53152316616428, 52.885772028277, 52.26785359844085, 51.926509334195046, 53.00252922119633, 55.05550169175672, 55.4820712151066, 42.78494319608135, 20.337342254577145, 1.299486753921355, 1.9284374627374836, 5.364298166767244, 5.8480597695996686, 3.468013598072914, 0.07010813036392774, 0.8531239088023863, 37.33622189491026, 40.26131376143425, 34.8038730313701, 28.4331613586795, 41.13521391345609, 50.88494746915756, 6.9660656875179665, 0.14058549978560017, 0.019377196215153224, 0.07486760481110505, 0.011362359453473362, 0.0037836139334455855, 0.03380631096661091, 0.014099235376042706, 0.12457972437503839, 0.03877870040014386, 0.033040544799258637, 0.03215620354298623, 0.058797830415348855, 0.012946140899833654, 0.07477378202301842, 0.06885993564801832, 0.05117347824477381, 0.04097667560281773, 0.04030379376584484, 0.07719651976179692, 0.1125398788961672, 0.009242464889652066, 0.05060445494769562, 0.029782612259770115, 0.039654672145843506, 0.04087003616375789, 0.05375473489684444, 0.032985976356412136, 0.027517409011301015, 0.09695133795180629, 0.0399904408221764, 0.05756902155436336, 0.03110806694284322, 13.062586034497908, 48.36697016992877, 48.87839232721637, 54.04668769528789, 72.8238856407904, 65.65489515181511, 44.545318618897475, 48.09647175573534, 62.03733236558976, 23.72084740669497, 0.08273543504577491, 1.8187954493107337, 9.536043809306237, 0.8205883385192964, 5.615467140751501, 35.03086451561221, 54.24293171974921, 58.36664892012074, 54.16392733973842, 56.64438324589884, 56.240543857697524, 56.22068881988526, 50.91403968872563, 49.562661570887414, 49.64979702426542, 50.7298412630635, 48.68796125535042, 49.99594226960213, 52.89873938406668, 53.79656599413965, 53.86195582728232, 53.102502592148326, 50.34443701467207, 50.174696445465095, 47.42284782471196, 45.863497795597205, 43.28235072474326, 41.20897800691667, 38.24962815930767, 39.95951875563591, 38.443373633969216, 38.19257336278116, 37.38302361580634, 40.303275277537686, 40.32970420775875, 39.071941298823205, 39.56914878660633, 42.47108297963297, 40.411011019060695, 40.92696351389731, 40.343338366477724, 39.82369492130895, 40.77746237477949, 38.51228575552664, 41.137100573508974, 39.52565754613569, 38.42156525581114, 38.747200427516816, 38.83253551298572, 42.83664787969282, 47.518730163574226, 48.849837472361905, 47.358771985577, 45.00544009670135, 42.180611856522106, 43.959806811425, 49.222674446721236, 54.3261722595461, 53.6048601519677, 51.34077787399293, 50.259396106966086, 43.196305690273164, 51.53610014146375, 55.10187587430401, 53.462776214845725, 52.00498419423258, 46.0338306427002, 45.428687372515284, 44.7594839526761, 46.694502907414595, 48.87830995744275, 50.081528386762066, 48.772962939354684, 47.166128696933875, 41.63949735703007, 38.403294855548495, 37.61117219924927, 38.40498147472259, 38.79421787877237, 37.449401886232444, 39.20183058707945, 40.133303288490545, 39.39459939156809, 40.875345122429636, 38.840564604728456, 39.211389403189386, 38.346510702563876, 38.89918442695372, 39.179155365113296, 38.35042522799584, 38.0902151907644, 38.74354477851622, 39.65129106275497, 41.780749751675515, 45.54577404452909, 47.34349435375583, 47.75992062784011, 49.59320898978941, 52.59864276455295, 49.924304100774954, 48.226239450516246, 48.49279980505667, 50.17705771230882, 49.06279471612746, 50.79382688768449, 51.36560647718368, 46.033811030849336, 47.05440390494562, 49.193880327286266, 53.146523352592226, 54.79477782403269, 54.96960570735317, 54.431542811855195, 54.628951780257694, 54.82382689752887, 55.41351995160503, 56.05032851619106, 56.909810035459465, 46.12094648422734, 24.799663943629113, 1.8237585958934601, 4.279902058262979, 6.425805284130958, 7.484191665726324, 4.7273532998177314, 0.031278247629562696, 0.8811390700359499, 38.745862899288056, 43.64721352054227, 37.81738296631844, 33.60268246742987, 44.632661957894605, 55.952637964679354, 10.547004322851858, 0.10042055179515194, 0.022356021856408448, 0.07729075623736267, 0.05950415582065621, 0.02723160650460951, 0.027102888411571904, 0.01112468354779506, 0.132279344684174, 0.04018522633780395, 0.07555592715019181, 0.03614185257784782, 0.055607430441605474, 0.018569172637897636, 0.04130573334893392, 0.2278070308027729, 0.16061370411226827, 0.13338405879274493, 0.17570454837574115, 0.15510118055728175, 0.19585903463584764, 0.15516251355649965, 0.12249654744781795, 0.13999038736426062, 0.1196204465363295, 0.22550302137049938, 0.17866771517982408, 0.13681694474672118, 0.11376513693962367, 0.1894320319256475, 0.10123198446367057, 0.19886493382434692, 0.10797050150652086, 15.637835821797772, 55.91764257800195, 59.909646587987105, 62.606986030455566, 78.91043924516248, 74.17291425889539, 52.5842555107609, 50.389026518790956, 61.357377729108265, 25.425272180188088, 0.28096179628083784, 6.157843172550202, 20.549546403269616, 4.397332427963134, 7.037388105546275, 39.36573859184019, 56.39539118736022, 63.64275455474854, 55.68062551559941, 58.26388282160605, 59.72101588403026, 57.49069736849878, 50.074275924313454, 50.39219187152002, 50.29719206594652, 51.69706636859525, 51.099924733561856, 52.756141616452126, 55.53166958593554, 56.4075505348944, 56.31077389563284, 55.097812298805486, 53.21693381955547, 53.505420223359145, 50.744577607800885, 50.03901381646433, 47.58714806648993, 44.492978511318086, 42.065619730180316, 42.26962220284247, 40.28205525490546, 40.0919379726533, 39.52307270419213, 42.92304200510825, 41.587816207639634, 42.52472531410956, 41.92910555870303, 45.01259057752548, 41.59744562641267, 44.2925650073636, 42.49060069361041, 42.41598936819261, 43.035970964739406, 39.4115714873037, 43.00481950083087, 40.92561421855804, 40.983245603499874, 41.453118093552135, 42.30781039884014, 44.81556600139987, 49.25919563539567, 49.65061679963143, 50.69091173910326, 45.47742674427648, 44.1806911653088, 47.68880805661602, 51.662400461012325, 53.98380033431515, 56.39630117724019, 51.67335956327377, 56.895603210695334, 48.88678619938512, 51.539049763833326, 57.865789705707186, 53.7522392888223, 53.217553554042695, 48.21140504652455, 49.486889223898615, 47.86186695098878, 49.533596807910556, 51.00150069882793, 51.5054036724952, 52.48097165938347, 50.45301998815229, 43.205789981349824, 39.977200800372714, 39.537110867038855, 40.22949549459642, 40.21862268447876, 40.43881277884207, 40.48876416298651, 42.747747359737275, 40.892568249856275, 43.4433404860958, 40.19646521537535, 40.42660244049565, 39.40900625721101, 41.66236477513468, 41.580340170091205, 39.811967034493726, 40.092691067726385, 40.73631278930172, 43.144349974970666, 44.95355498406195, 47.61232576062603, 49.87665907029183, 48.97003850629253, 52.236329509365945, 55.9604238694714, 51.65593639496834, 49.96746586215112, 48.26530233506234, 51.782581883092085, 50.06943179715065, 52.28724579657278, 52.831874739739206, 47.09445522677514, 47.40029027385097, 50.70717780820785, 55.51974165824152, 55.92065888066446, 56.371613779375636, 58.44097783488613, 55.60599850070093, 56.31156229203748, 57.22762792341171, 56.634808740308216, 56.425958218113074, 49.294343994509795, 27.707077687786473, 3.197706154277248, 5.528134588272342, 13.069116780834815, 15.9063083317972, 13.062841969151652, 0.3157310950900278, 1.382296078147427, 47.80755781358289, 51.53181691323557, 48.05664008663547, 38.983903700305575, 51.6454715113486, 64.07043018648702, 13.44152327506773, 0.2518000159292452, 0.14666570981423702, 0.1345862346070428, 0.14510802323779753, 0.12175751774902306, 0.11887113593759076, 0.21265733566495681, 0.2755343391289634, 0.20936203910218132, 0.1595944394507716, 0.11562130669312132, 0.14075077559438445, 0.16884452212722073, 0.18269376769181223], [0.01311794856578232, 0.01854620723714752, 0.03690682201375885, 0.040568944457317554, 0.04116967230314209, 0.038611517032428135, 0.0329961538344862, 0.03482429243083443, 0.04091392534093992, 0.031150818479457693, 0.04073901597650782, 0.016238302247779026, 0.040551021830329013, 0.01438918624884419, 0.08221634919004095, 0.014554009108143228, 0.053772565593282064, 0.058268524946704994, 2.640037291472958, 28.756415651690578, 47.14756019653813, 44.05352792432232, 52.71743174522154, 65.63573045115318, 55.27280884404337, 37.86383167389901, 47.79523764887164, 33.13304139721778, 0.0809949062644474, 0.8827742693885681, 4.227630101865338, 1.9414247981002255, 3.3980836214557772, 23.904702624967022, 52.822998416039255, 57.54760311495874, 54.64817139410204, 53.051731432637865, 53.496685104985396, 51.77886347616873, 43.801335211723085, 47.62281025609663, 50.37774970454555, 50.34616677991806, 50.142179996736594, 50.067905995153616, 50.4499017038653, 52.09024475466821, 52.752258469981534, 49.83039079173919, 49.7820475793654, 48.099946975708015, 45.84186592409688, 44.26879544411936, 43.09340230880245, 42.0033089576229, 38.23470746317218, 38.85462630179621, 38.477996395480254, 37.796013893619666, 37.99580374071675, 38.55280776177683, 38.220594775292184, 35.95568095484088, 38.724183959345666, 40.7208586508228, 35.9464123941237, 39.01989144663657, 39.4635272026062, 38.76517665001654, 36.36923997632919, 37.7965747925543, 38.02337015828779, 39.09541668430452, 36.67584380795879, 37.84052102796493, 37.375096505688084, 44.35007872120027, 50.15530032496299, 49.50154712123256, 47.599174053438254, 46.13163102057673, 43.30546917453889, 40.85061065612301, 44.83980232669462, 49.802855753129535, 52.5699741609635, 52.07884634694746, 31.400363791373472, 40.81187332830122, 50.89045055450932, 53.07524211945073, 51.07055402571156, 48.503096026758996, 47.364271148558586, 46.60166432780605, 47.21231068334272, 48.5724788327371, 47.98587660635672, 50.50101018721058, 47.679688545965384, 47.67830787166473, 42.093307741226695, 38.34860917060606, 38.11261976918867, 37.13407862570978, 37.31131876668623, 38.00311503871795, 37.596431932141705, 37.133823671648585, 38.92353057861328, 36.87261735239337, 37.99154404670962, 38.13984494055472, 36.52916285299486, 37.20415176883821, 36.66515534923923, 35.87965757616105, 35.40914573977071, 36.01211209450999, 41.40390803737026, 44.38684309682539, 44.91389589924967, 46.56382130038354, 49.71482599935224, 51.37229019595731, 50.598967459894, 48.31018601694415, 49.490042809517156, 50.662243135513805, 48.63549563192552, 48.75990536905105, 47.814229765246, 43.6300649181489, 52.04876176772579, 47.35046048318186, 46.437399387359626, 48.50257435152608, 48.536059625687145, 50.136496482356904, 51.451655434023955, 50.90593214957945, 53.59068862853512, 50.25791345104095, 50.89705190350933, 48.72900493683354, 35.030068274467226, 26.324881507504372, 5.58138664691679, 3.7387782431417897, 8.01704026037647, 6.319730666375929, 2.25709653669788, 0.058887347789301034, 2.5588626150161993, 41.30114193885557, 39.605803335866625, 26.969405374219342, 19.944609057518747, 38.732224818198915, 42.76006752444852, 3.1905154691588495, 0.05760696205881335, 0.020207798318757166, 0.07227907032375375, 0.01866437055380835, 0.007815338847708077, 0.06289751546817922, 0.09266272412552949, 0.0592929836843283, 0.0962110212252986, 0.031507183429634864, 0.04311176264778741, 0.01766290403001251, 0.045933613042917945, 0.04650284318373569, 0.028454200477309288, 0.048641021393479845, 0.03711813204591313, 0.030253128141104698, 0.04940697908281319, 0.0595536757440817, 0.04881203520081697, 0.009167162277134917, 0.038841408527185844, 0.03943163713800811, 0.08647153093930214, 0.04779703764905853, 0.04315498915891494, 0.030949913836534948, 0.07394878959824001, 0.04157971320373397, 0.05854632374980758, 0.018440381766507224, 4.081351434992206, 39.04264903837635, 53.31311425855083, 49.8701322463251, 63.76421074713431, 69.22425593099287, 57.322372774924006, 41.80665700666366, 50.84189553414622, 32.19521053375737, 0.19888158857582078, 0.9119650385072156, 7.419527961361793, 2.2283453181866677, 5.178902437610011, 30.983431531536965, 53.634285773000414, 56.98503717299431, 55.296900041641734, 54.295832726263235, 55.67239638297789, 51.31955392899052, 46.65636570222917, 47.53379990977626, 49.748550538093816, 50.33492134463403, 50.516483937540364, 51.721824369122906, 51.49055357902281, 53.48195268261818, 52.1448363027265, 52.93667654837332, 50.885598582606164, 50.49935102462769, 47.99598455429078, 47.130525342879764, 45.21190581783172, 42.80458642590431, 37.919854887070194, 38.96492727341191, 39.520534930690644, 39.77843861426077, 40.55910794965683, 39.616091712828606, 40.02680701594199, 38.29261341402608, 41.208287669766335, 42.19774476943478, 37.83857945472964, 40.855611678092714, 41.57264447981312, 40.45093290267452, 40.77323798210391, 38.78165060474027, 39.931716995854536, 40.49314545046899, 38.01763173072569, 40.52079031544347, 38.25324066223637, 45.14894000945553, 50.854270612039876, 51.428070222177816, 49.816372240743334, 49.037832752350845, 44.340170814145, 43.52367847196518, 47.86933122142669, 52.103757319911836, 53.406011673711966, 53.66167960628387, 35.01806582173994, 40.645898234459665, 51.77241117723527, 54.71990369981336, 53.22281345244377, 51.21765075191375, 49.64003816727669, 47.13322001118814, 48.755080853739095, 49.943700221277055, 49.20303906163862, 50.56020659785117, 49.93784412260979, 49.11442879707583, 43.76419036619125, 39.974612036058986, 39.25483357521796, 40.38638637911889, 38.4952038334262, 40.647894720877375, 38.375787273530044, 38.58506533407396, 39.05254125595093, 38.407750668064246, 38.74006563617338, 38.874991247730875, 38.41815279376122, 37.20869387349775, 38.747808394893525, 37.71605245528683, 37.682539724534564, 38.048320354953894, 42.11660662005025, 46.149356211385424, 47.86382813607493, 48.14219482483403, 51.05914777325046, 51.85112922422348, 52.60718176441809, 51.5157744192308, 51.19374390571348, 50.71725437718053, 50.41247837005123, 50.376776956742816, 49.321639768538944, 45.098957246349705, 50.597312219681285, 47.906805546053, 47.870641293064246, 49.722486388298776, 48.85930999632805, 52.09144892231111, 52.669778869998076, 53.120337609321844, 54.74056282351094, 52.143283044138265, 51.301416889313735, 52.52953452448691, 38.511611107857, 29.07239002566184, 4.92960149242032, 4.202302867366422, 6.552511078696098, 11.33679218830601, 3.6796232625361416, 0.055415425825143055, 2.915409495753627, 45.11901232504076, 43.947098332066695, 37.40052915388538, 27.065862340311853, 43.564933961437596, 50.54553301103654, 5.895293931807242, 0.05710005700107544, 0.07486075598506198, 0.06310748867690563, 0.03932324335760167, 0.05322423050059907, 0.023394463613869685, 0.061593086068187995, 0.05061859693077784, 0.030528073266689337, 0.038345083143682256, 0.031816140943837744, 0.08101100943261579, 0.041859411904888774, 0.0717381509621778, 0.13065977352521113, 0.18358598433194623, 0.1361420059636716, 0.15366288112296214, 0.16859837807714942, 0.14661626649960396, 0.16041377048578956, 0.15736455668605145, 0.1667739856507509, 0.09335850816099875, 0.2787093752093854, 0.14785167520805714, 0.14898026061634864, 0.10294458167927881, 0.1417005560811489, 0.19824192048080508, 0.13582741961844508, 0.13090156619587254, 5.030179398675119, 45.75860185007895, 61.76228792436662, 56.914324683527795, 62.2916353133417, 70.83469483160204, 63.55852165529805, 47.70805512705157, 58.141061644400324, 40.89767517582063, 0.2940990397286031, 2.781990074342297, 13.939428944741527, 3.135021040516515, 5.779431039287198, 34.929200603115945, 55.801669859117084, 58.86781407940773, 56.971053923330004, 56.12181371258151, 54.386223746884255, 51.296659054294715, 48.73945413097259, 47.425581716722064, 52.07945823669434, 50.95016471801266, 51.45148284973637, 52.19620758487333, 54.68304910967427, 57.08958402756722, 55.23891564338438, 54.3748410286442, 54.62057751993979, 51.940876976136245, 49.411869971982895, 50.08285807025049, 47.95843570463119, 45.86732602888539, 41.92843091103339, 43.501289583021595, 41.390007157479566, 41.35964408997567, 43.14805269241334, 41.32688445429648, 42.56097193687193, 40.48999970959079, 42.90172392322172, 43.68813953092022, 39.50546910685878, 42.43456179095853, 43.340425337514574, 42.25052418247346, 41.746499615330855, 39.8384940239691, 42.74902213004328, 43.77986023502965, 39.49385496877855, 42.38324149962395, 39.92060492115636, 48.067450138830374, 54.696965679045654, 54.085374032297445, 52.564184742589156, 51.070738377109656, 47.0902112222487, 43.70589610069029, 49.36067127412366, 52.89242829045942, 55.581542522676536, 56.25701781242125, 43.45540961911602, 44.126236900206536, 53.391145890758885, 58.21129168233564, 53.50601642362533, 52.86800369139641, 51.909431334464784, 50.58499989971038, 49.40916745893417, 54.14701015718522, 52.989122559947354, 54.346019452618016, 52.05914428157192, 51.718545267658854, 46.29710405103622, 43.07019364449286, 41.82514705965596, 42.11151930593675, 40.78991197770642, 42.162270853596354, 41.24743292408605, 40.0723575007531, 42.55160923927061, 40.59629594126056, 41.048047081116714, 41.07552720654396, 38.4777335966787, 38.86487545505647, 39.61405600270918, 40.28248279325424, 39.14779209321545, 39.76942108523461, 45.028531089905776, 49.42713975906373, 48.69258180741341, 51.244118905836544, 52.65741555921493, 54.42663592676963, 53.557870157303356, 51.91029817827287, 52.41183204035605, 52.23729441242834, 49.96244522833055, 51.16843285099153, 51.34255078531081, 46.39428077205535, 51.9442266802634, 49.481005668640144, 47.490296902195105, 50.425932099742276, 48.68407418650966, 52.04268601632888, 52.998320518001435, 53.716581021585775, 56.46591540305846, 53.27014861568328, 52.850396171692886, 51.39644022910826, 42.12662827584052, 33.21834902609549, 6.850018933896096, 8.606536215351476, 15.865958909834585, 16.516963512666766, 6.771243522244116, 0.24616113383202787, 3.893515746439657, 50.839612714705936, 50.70878990234868, 39.52382579926522, 30.2618311297509, 51.574829624545195, 56.78766350592337, 8.42779282600649, 0.23775066819883164, 0.1220750228892411, 0.10987593071354974, 0.21743145771324637, 0.12895749551394295, 0.3154937916946027, 0.15614748812250553, 0.19154490242081304, 0.14306696582465403, 0.1804061525411183, 0.14400064314325012, 0.20031365205443677, 0.2070307722615619, 0.11667751977520606], [0.025063085467404416, 0.042658418627275575, 0.08875321656946214, 0.13505584650462674, 0.04556221744766639, 0.019836494654056527, 0.022699709966658585, 0.044599336857396754, 0.07948025084671476, 0.05568909541433377, 0.027309305057109847, 0.06779406985808765, 0.016373805964605945, 0.016845026646830866, 0.03348540822644869, 0.031619557036807945, 0.022492450624403935, 0.03372352750551316, 0.12529095274306115, 15.610715573833836, 52.183965867565526, 40.365389931586485, 30.519101350538193, 39.24827537228985, 45.527256534945586, 51.500720362509455, 58.25019767207485, 42.69960418824227, 2.2687432794801654, 1.4862311655475249, 3.5195577096554542, 5.71635393365737, 21.7608174585527, 27.936310806582053, 43.74491191679432, 55.23025505004391, 54.96463214197467, 52.06755776559153, 53.043568980309274, 50.031953550154164, 49.78795859121507, 52.52595340051959, 53.27974273312477, 52.27924416142126, 52.397727197216405, 48.63296178079421, 51.51372694200086, 52.0267298144679, 50.790641923104566, 52.67126544829338, 51.39368672524729, 48.686227567734264, 47.65202406914004, 46.14353933641988, 45.893805949918686, 44.912848626413655, 40.38433497951877, 38.834430017778956, 38.17276539341096, 36.73982551020961, 38.48797098282845, 36.5299081033276, 37.97441505616711, 36.58810038720408, 37.36536510529057, 37.999098531661495, 38.03328591008341, 39.626164359431115, 37.219472546731275, 38.16252408489105, 38.42915896446475, 37.67230233838482, 37.30798082966959, 36.02566780582551, 37.66377118326003, 35.47011113935901, 37.25055733034688, 47.15871933967837, 50.02746635867704, 51.150931235282656, 49.56134757687969, 48.02461785654868, 45.23606761809319, 43.066192826917096, 42.9458466652901, 46.721618252415816, 51.35172128677369, 50.324672191373764, 41.69776416593983, 45.39347233310823, 47.8364029238301, 56.300250176460516, 49.68347057219475, 50.94577558578984, 50.55930837508171, 50.17089959113829, 48.63781375269736, 52.15401072655955, 51.07224064488565, 47.905126771619244, 47.79903450319844, 48.81234745825491, 43.806132270443825, 38.03925575748567, 34.931895271424324, 38.09382377132293, 37.219578450725926, 37.33732800329886, 39.01770276408042, 37.53800822842506, 36.83395062723468, 37.891343178287634, 37.852213613448605, 36.50854687536917, 35.904898028219904, 37.60908157594743, 36.30810591482347, 36.9003406647713, 35.611928355309274, 39.77083313849665, 45.570881136002086, 47.79629668881817, 48.85669377542312, 48.69229547439083, 47.99229360395863, 50.913317972613925, 48.76375321419009, 49.62951837047454, 49.28500875349968, 49.045767707209436, 48.27654777034637, 50.985415058751265, 50.22287884066182, 53.11506202144008, 49.409406723514685, 49.23919154751686, 49.72242363037602, 51.07419006286129, 46.54083621117377, 48.54536348773588, 47.9379334757405, 48.13379310792493, 47.689584685910134, 47.56022883999733, 47.62736805023686, 41.521190827892674, 21.436619835515177, 11.033219368227067, 2.04694562621655, 3.3354570980994933, 9.441372502234675, 6.741478125895224, 2.866632371179519, 0.04314901367310555, 3.4813577465472685, 41.84862244513727, 37.186257916112105, 31.104238571659213, 24.115231921595914, 43.74872838297198, 29.691902898973037, 1.1897977946266052, 0.061421463220951066, 0.040044377242485364, 0.04715362721453271, 0.09406365379090272, 0.07008060482480834, 0.01780064855401795, 0.06764220058797829, 0.031433382349449306, 0.029631380757857716, 0.06640981792682601, 0.033378351269470106, 0.07056810487542423, 0.04493426666745255, 0.05230314383703855, 0.05198579957528461, 0.09770612607920363, 0.03475107740791094, 0.06480851030397801, 0.04085614315925106, 0.035537455170865984, 0.05806210638594724, 0.04803560125911909, 0.008133558364915512, 0.00743059273396108, 0.024287986433914593, 0.003189139040900515, 0.06595098488633672, 0.039700878738996484, 0.07395517877152852, 0.014323865761980416, 0.0650719756020173, 0.028902530452356707, 0.33090947255972897, 22.301818209309733, 58.64697679396599, 44.815295357857984, 37.52478591857418, 52.99818715741558, 56.14632460378832, 53.10960600453039, 60.157065776086625, 44.782904424975, 2.3477949730811583, 0.5007763849871775, 2.21626466320407, 5.611433473325545, 18.504042125517323, 32.056415504024876, 46.18388483601232, 56.44884524806854, 54.308686333317915, 52.820484176758804, 52.10146273336103, 49.71270791945919, 49.2459301794729, 52.370502025850364, 52.84892920524844, 52.1795492787515, 52.604494940850046, 52.84987449645997, 52.182879371027795, 52.606781682660504, 52.40255171252836, 53.94927563205842, 50.97688782599665, 51.67957259762672, 48.826534671168176, 49.36140867971605, 47.15441257722917, 47.157377889079434, 42.753148463464555, 39.686725754891675, 39.505539709521884, 39.57942931882797, 38.660253247907086, 39.0498387429022, 39.470579624176025, 38.294598133333274, 38.8369874031313, 39.1644190203759, 38.81523001578547, 40.77250449888168, 37.762944390696866, 39.313225899973226, 39.70106986261184, 40.11644494148993, 38.61606382554577, 38.45658025433941, 40.18916568448467, 38.27837913267074, 37.76971047924411, 48.304953575134284, 52.07173508982505, 53.70961489215974, 51.07992849042339, 51.380660533905036, 48.04471608131163, 45.20401008667485, 45.094093507336034, 48.64256766534621, 53.17393679772654, 51.21610141569569, 40.36179311813847, 47.33058975588891, 48.938690923875384, 57.090913711055634, 51.24744115337249, 50.396659451146284, 51.557237794322354, 53.450922812184984, 51.1491544015946, 53.07099419255411, 52.60273771901285, 51.34009930395311, 49.93683215110533, 50.17672038847401, 45.54736652681905, 39.617711651709776, 37.37151538172076, 38.824965338553156, 39.11532271292902, 39.40766480661208, 38.89269290431854, 39.609513898049634, 38.622265092788204, 39.14415997843589, 39.21444885192379, 39.31244927067911, 37.871499907585886, 38.76459613923104, 37.041420475129165, 38.35097828219014, 36.408914750622166, 40.290974724677305, 46.83820678341774, 49.30356940915508, 49.62132453918458, 49.96798753738404, 49.49709130871681, 52.8264501017909, 50.13162097623272, 52.61248873126123, 51.313701752693426, 50.916440179271085, 51.26398571075932, 51.047102174451275, 51.09364109654581, 54.867922183006044, 50.538092274819654, 50.43959763742263, 50.009290095298525, 51.18251808228032, 48.24099932947467, 48.78976245080271, 48.520032821163056, 49.82453077070175, 49.27668548399403, 49.16681205072711, 49.45899724960328, 45.15542760972054, 27.790481005945516, 15.680013068260687, 4.171247991823381, 6.087833767937076, 11.598221102068502, 7.65272512551277, 4.055220850052373, 0.036991620286097454, 3.3050307823765666, 47.133376905995036, 43.88199090957642, 35.82660751958048, 24.930306326958444, 48.9561297816615, 36.56132236603768, 2.087395436340763, 0.0655120854536372, 0.0423794936749243, 0.0663799251760206, 0.05762833208146115, 0.0246551321564062, 0.03595010843127966, 0.040834780797482505, 0.026382225670761643, 0.05504181623579033, 0.01629417878575623, 0.09539310745294056, 0.04113299201332754, 0.0562339831113575, 0.0430463808738897, 0.08820190139475369, 0.21875519635936908, 0.15227305973249097, 0.19078482062585894, 0.14452558191072556, 0.15123369292386118, 0.15454238070355308, 0.15655725323144468, 0.11976528311929396, 0.2698203650934081, 0.15150854994933452, 0.15880343834719352, 0.18310678101355032, 0.1318850545513053, 0.17020452737567887, 0.17235801585258978, 0.11835436366738812, 0.10544003648383003, 0.40025685463220845, 26.874852718845492, 65.97007720701157, 52.40123379615046, 43.91878274179275, 50.80904960632325, 57.34554221553188, 60.9702633273217, 67.53800545969318, 51.303076051896625, 3.2982982791239217, 2.344095442564257, 11.911756742385126, 9.872901862667455, 29.701100857027118, 43.02797717432822, 47.92477784618255, 57.97919327212919, 55.77901424900178, 53.04900930773828, 53.81325175685268, 50.72467550154656, 48.61123185003958, 52.7804877681117, 53.83690364899174, 55.5852452401192, 54.41867743769, 54.11522719167895, 54.814895660646506, 55.03867472371748, 53.46019921764251, 56.783682300198464, 53.709104984037346, 51.490180953856445, 52.25464697807066, 51.23489349119125, 50.13221717649891, 49.79869411837671, 43.2520386480516, 42.27175989458638, 42.28509595317226, 41.25204955377887, 41.535115242004395, 39.90951245830905, 42.89765250298285, 40.383217104019664, 40.22789124519595, 42.00622327866093, 40.809637577303, 43.819221219708844, 40.31273603439331, 40.809186504733184, 42.647087574005134, 41.80382897776943, 40.982990649438676, 40.00151949544107, 42.73938878890007, 39.10627380494149, 39.38210272019909, 50.54114780118389, 53.99755608650946, 55.56269553399856, 53.57629745237289, 53.41177755786527, 50.09539396532121, 47.18224963834209, 46.94405978725803, 50.93591866954681, 55.421148961590184, 54.69492996892622, 44.65544700622559, 49.49884460818384, 51.17376727442588, 58.43162690439532, 53.07878401971633, 52.503462529951534, 54.35986149695612, 55.54557438819639, 53.60824515742641, 55.757872673773, 54.114752584888095, 52.067848020984286, 50.40568482491278, 51.842809877087994, 47.32875800901844, 41.72303207458989, 40.11885719914591, 42.217038908312404, 40.79553665653352, 41.329033913150916, 41.5954295281441, 41.20885249107115, 39.848821624632805, 41.276709495052216, 41.39133291859781, 39.56828586516842, 39.71431570668375, 40.260611657173406, 39.661728489783506, 40.510313664713216, 37.969574851374475, 44.064565473987216, 50.623093958823915, 51.45827639487482, 53.21126991702665, 52.391733815593106, 51.400931342955566, 54.13555291391189, 52.53821472967825, 53.72047593516689, 52.930236016550374, 53.79826438042426, 53.20112666776104, 52.44715690612794, 53.95031898252426, 55.959105953093506, 49.726145959669545, 52.463995641277684, 49.91768313992409, 53.731909644219186, 47.81452394300892, 52.821535371964984, 50.194010196193574, 50.64313727040445, 49.26045863859115, 49.98577940848566, 49.36642931353662, 47.22121054126371, 29.892449763513383, 15.155111685875925, 3.712110293488349, 9.380213925915381, 19.540901068718203, 14.77088709031382, 9.797092253162015, 0.1611019625899292, 4.018770509189175, 52.10868381684827, 47.81388067430066, 41.40219396160495, 34.19419157889582, 55.05542716672344, 43.0600856965588, 3.1848790232212316, 0.29293694563450356, 0.15452592513493954, 0.1460672419277891, 0.1433535133518519, 0.11186111733437547, 0.1418216286167022, 0.149151848989629, 0.18388045320828117, 0.12715642280395956, 0.17415283728511105, 0.13361823654943897, 0.17208223952160728, 0.15951067539713076, 0.1306726897676145], [0.02042164984760025, 0.0330837789712654, 0.07521921618571205, 0.07988820798815259, 0.04956151816933867, 0.03410462177388611, 0.048938366929970445, 0.011022281532566394, 0.011732770625742213, 0.02012794322874998, 0.03822861096611427, 0.07071596750568959, 0.0408939840722709, 0.03014098819074852, 0.02291479681227957, 0.044363783972878615, 0.02615316729662159, 0.03408102626581827, 0.06519248889338586, 3.8687950084286356, 42.47922582011069, 51.84128799746114, 35.646551116820305, 25.67986538333278, 34.11408501286661, 44.64276206108832, 51.49967701204362, 49.90712804179038, 6.210191124869931, 0.6652386390393781, 1.6357508133496008, 1.4911908800563505, 8.939258129365983, 21.42613926241475, 32.92484198847125, 51.553456629476244, 52.80309238741475, 52.51143670851185, 50.775434893946496, 54.15490981071226, 49.39370939808507, 50.43309434767693, 52.693705328049205, 50.48450485352547, 50.31652935089604, 50.29522695849019, 49.42910094414988, 49.8193806986655, 52.42143008016771, 50.935067515219416, 52.506961284145234, 50.69031946120724, 49.464692531093476, 49.21567301596365, 46.34599247286397, 45.481443251332934, 42.907077958506925, 42.14669119927191, 38.37138245182653, 38.761289581175774, 37.149497462857155, 38.249118251185266, 38.41021783890263, 36.69429855961954, 38.06961882498957, 38.48463696818198, 39.842934147004165, 38.33769713678668, 36.65584364245015, 36.82252476292272, 39.450469632302564, 37.05082631880237, 38.49470569241432, 36.56057319333477, 36.885886730686316, 35.20187201038484, 40.74534993017874, 50.40424531505954, 51.911569026208696, 49.43417649115286, 51.099924733561856, 50.11746514228083, 47.02193060228902, 42.336918307888894, 42.196642583416356, 45.67419244397072, 49.424362720981726, 50.54169301063784, 55.9365640917132, 47.43567005280526, 42.18900572869086, 53.9587010875825, 52.28655153705228, 52.12615797596594, 49.587458795116795, 53.62096540389523, 55.65173333691013, 56.072533053736535, 52.551099715694306, 50.2540106927195, 50.68824060501591, 51.27292087001186, 44.44513736232635, 37.99069289238223, 37.65846813878706, 38.04665334763066, 37.57842040831043, 37.45038640114569, 36.439846561801055, 39.18272864434027, 38.2252545510569, 39.54506935611848, 36.78146146958874, 36.88647508621216, 35.4741943267084, 37.05164609416839, 36.79814723230178, 35.4916920200471, 35.35594271075341, 43.292184106765255, 47.89202213287354, 49.22885217974263, 51.293058318476525, 49.359580855215754, 49.920095397580056, 47.59045070217502, 50.508082220631266, 51.01072611347322, 50.4641830536627, 47.21842173607119, 48.140704324168546, 48.83983150605233, 50.11002440606394, 50.767750970778934, 50.63223308132541, 50.19354735651324, 49.971690254826704, 51.630362541444846, 50.17905419872653, 49.37720406439997, 48.65579781993743, 50.23558732002012, 49.30864887852823, 47.36996250767862, 47.91039059239049, 31.51498329254889, 8.73029483902839, 1.2862536575525039, 0.9531216719938863, 5.710261021890949, 6.499161451093613, 8.79155049400945, 2.324760118799825, 0.05762616405263544, 5.398772368508001, 42.21843919446392, 33.9931583404541, 30.045114294175182, 26.511904039690574, 44.95697136848204, 21.538279825641265, 0.2597777797810493, 0.0504070264287293, 0.0528145305091335, 0.07161451203207816, 0.00935643866297699, 0.032343990845425476, 0.007664903598431979, 0.07069824789200099, 0.06131608016608704, 0.023050336918282895, 0.07788848867940326, 0.09559939960919081, 0.01156398996470436, 0.04046107161669962, 0.0878291383325573, 0.06394863789600712, 0.03704361084307875, 0.07727446920809246, 0.058897303101877053, 0.03238611802038166, 0.033788108717530005, 0.07226658309058798, 0.05642950407139236, 0.011084350933801505, 0.04389188913328033, 0.061666316412869966, 0.05381116110290732, 0.12183771949381599, 0.014564019004483859, 0.03945176226777896, 0.012758817080588592, 0.03293409305174024, 0.028557616601427718, 0.033542899294726314, 6.457850558142509, 51.35297252285866, 53.93029920516476, 36.297488058767016, 32.32479387714017, 45.450452604601466, 52.55246862288445, 57.3055693411058, 53.37722539901734, 6.704847110855964, 0.7813208165668672, 3.5755814131229156, 2.7318070252095503, 16.000231446758395, 29.009626219349524, 37.89301018561087, 51.87369854219499, 52.478539789876635, 53.20714358360537, 50.66883271740329, 55.66548516673427, 50.49351061544111, 50.783867989816976, 54.67896592232489, 51.910764940323375, 52.855585467430856, 52.57941530596826, 51.32561006853658, 52.147079898465066, 53.755887093082556, 52.37788392651466, 54.429785590018, 54.08650759727725, 51.58138390510313, 50.88460622295257, 48.89790611882364, 47.68543481826783, 44.00622021767401, 44.01876003511491, 39.96688888918969, 39.49820487729965, 39.21550396950015, 38.60319060664023, 39.31739145709623, 38.7346919890373, 38.68161839823569, 40.208071508715236, 41.793874002272084, 39.29734814551569, 39.317595420345185, 39.69284465236049, 41.113833073646795, 38.65791943765456, 40.30713881215742, 38.06706143963722, 39.55621673214821, 38.33916410323113, 40.69885023178593, 51.40400648117066, 53.470122814178474, 52.42226946738459, 54.02679735614408, 52.998728444499356, 48.01692608864077, 45.73408703650198, 44.620785021012836, 46.52289529000559, 50.12051282390472, 51.59762251761652, 57.231879772678504, 48.94253484664425, 45.20003672569029, 56.36365921266618, 53.89982238892586, 54.348204212804, 51.28814751102079, 52.84906648820447, 56.059820652008064, 57.6638739339767, 55.25324798399403, 52.258753699641076, 52.67850614363148, 53.105785615982555, 47.79070731132261, 39.9677243540364, 39.45881251365908, 39.52533591178156, 39.21781424553164, 38.96558623160086, 38.46679802863829, 39.803518249142556, 38.203442250528646, 39.22912243873843, 40.35917297486336, 39.42235016053723, 36.34168924823884, 38.884710881017874, 40.05729952166158, 38.309824774342204, 37.060730303487475, 44.67477252406459, 49.99394578318442, 50.88958371070124, 53.350474834442146, 52.150358999929125, 50.5475647987858, 49.748425022248306, 52.154724597930915, 52.695792028980875, 52.67227741979784, 49.610436039586226, 50.52659973021477, 50.76665662950086, 51.86291986896146, 51.588703047844675, 52.574041658832186, 52.974178329590835, 51.64230615861955, 53.18556662528746, 51.43830760832756, 50.603160473608206, 48.22998139166063, 50.32049486714025, 48.449057532895, 48.48214272529849, 49.423291913924686, 35.889792980686316, 11.596657056962291, 2.754785005123385, 0.8830864042524369, 5.303645085903907, 7.208263220325594, 8.836275319899283, 0.9638040632970872, 0.05417749285697938, 5.9056406540255395, 45.8586379789537, 39.98639483605662, 34.39486395928168, 28.152468704408218, 51.23097504338911, 27.878897113184777, 0.4471885040402413, 0.08380310114232764, 0.0478612473084321, 0.02298114002652226, 0.022904125207494345, 0.03452205542294729, 0.011934739173269801, 0.041081763713830904, 0.012581633392631287, 0.026304590320515058, 0.058231928926562114, 0.038449811193371014, 0.02193361629671868, 0.019577579918287454, 0.008856133452706761, 0.11915974424130495, 0.15781564457762629, 0.1767927456286646, 0.19663984677003277, 0.13170441101876, 0.1076015918665836, 0.13237210261004587, 0.33934459090232855, 0.12837880801769996, 0.10759192383697919, 0.14671996416103456, 0.18805914107830296, 0.18002960500457596, 0.09164601053682067, 0.12329606744911402, 0.19374002011552935, 0.1733828882776922, 0.19825236992009226, 0.1611797971230361, 6.419816805470375, 57.0489521949522, 62.39504468056464, 47.50069902789208, 36.21356110418997, 45.54514646530152, 54.64714373311689, 61.10228246258151, 60.03488002284881, 8.12727504199551, 1.6660878951511078, 8.559787446452725, 2.8600861805100597, 12.064507565190716, 29.367036511821134, 40.861424630688084, 52.70739439995059, 51.00594474423317, 53.010456331314586, 50.69432420115317, 56.99113253624209, 49.64672188605032, 52.2809386253357, 56.46233820146131, 53.62734317779542, 53.40616856851886, 52.47417811424502, 51.714618975116366, 53.30769746534286, 54.45759911690989, 52.609131182393725, 56.238955297777736, 55.28634102113786, 53.8596926196929, 52.7119678835715, 50.63600640143118, 49.61051840935984, 46.623849253500666, 45.895978942994155, 42.22355788753879, 41.944073323280584, 41.32885740649316, 41.53966911377446, 41.70910766047817, 41.12472941798549, 39.99030543911842, 41.98350883299305, 44.44910680094073, 42.526478613576586, 39.50688900486116, 41.29400322514196, 43.8802376101094, 41.22089416750016, 41.81878105286629, 39.996008565348966, 40.514165432222434, 40.224976924157914, 44.800335438020774, 53.52001144040016, 54.72792102444557, 55.28025742500059, 56.62960375508955, 54.00860932565505, 50.095217458663456, 46.70273204003611, 45.99757617519748, 50.601787644047896, 52.53916786563013, 54.96391827060331, 57.82122373580933, 52.29365887180452, 46.3475614209329, 57.880125968687004, 57.02233891333304, 56.5560632367288, 53.59718799591065, 55.25082003685736, 56.5108657652332, 58.53300448386901, 57.25630829411169, 53.7039117659292, 54.03945484469014, 54.2914592835211, 48.43673344581358, 43.037241812675234, 40.72790322765228, 41.83979318987939, 40.871654172097486, 41.4087325526822, 40.27550489671769, 43.302378346843106, 40.662748736719934, 43.73639645115022, 41.52547013375067, 40.62131674058976, 36.80587037917107, 40.79831369461552, 41.85952663421631, 39.9220169744184, 37.663802562221406, 47.938635580001346, 53.3131613269929, 53.06896632717502, 55.29400533245456, 53.960591670005556, 52.26018536475397, 50.874274699918686, 52.893079403908025, 54.21882483267016, 53.92988735629667, 50.808151383553785, 51.51946536956295, 52.17969440644788, 53.123808906924346, 54.07764304068781, 54.58157347094629, 55.18790914166359, 52.400366952342374, 55.065970497746626, 52.980332528391195, 52.09470448955413, 49.61401324118338, 50.18584774386499, 49.05843696286602, 49.465265197138635, 52.140961000996256, 39.828743011720725, 14.741544819647267, 3.0996128243784753, 1.7640204078728154, 15.31921188677511, 12.23001785816685, 15.509672376417345, 8.215497482207514, 0.2183356866120331, 7.180209448260646, 52.624479416877996, 45.457858039486794, 43.53663798301451, 37.18776410625827, 57.3361599060797, 33.073025211211174, 0.8636335319569035, 0.16679911333466732, 0.3519845513566848, 0.22692127994471983, 0.09396179474049038, 0.1390092892031516, 0.09808053623043722, 0.13287672472576942, 0.16250486876214706, 0.102183657187608, 0.19942293694663435, 0.30164932651865867, 0.11939005325398139, 0.13514144916928586, 0.17329756140468583], [0.041742533700720924, 0.061026487439390154, 0.04124383344465206, 0.05512553049371608, 0.07857360877096653, 0.04557274732618563, 0.1193251426241571, 0.13757281305809177, 0.03033563198011008, 0.039131702224333445, 0.022816701168795268, 0.05970638771090777, 0.05358449866875045, 0.015218822124053635, 0.00570403260832292, 0.052616688302688064, 0.008704261309767683, 0.03682544432400215, 0.05632021396811451, 0.3461800870155135, 23.4573111995574, 55.70955299562024, 33.035495973402455, 30.540203702065256, 30.8130947620638, 44.20881063707414, 48.37359113077964, 54.85658261083788, 8.679150073759018, 0.3616681478677258, 2.6239548383220552, 0.41247902137617914, 0.9054042002366436, 1.3555728475893698, 21.3614672230136, 48.68186589210264, 53.323328110479544, 54.27997458365656, 51.080830635563025, 47.29228388878607, 49.78336157337312, 51.582262516021736, 52.02331343004781, 52.58775034258443, 51.70586424489176, 51.719349353544175, 49.67539048963978, 50.591926805434696, 48.24621608180385, 48.86180854612782, 54.23680105516988, 49.558880406041304, 48.63895516241751, 49.054181191229056, 50.4789468549913, 49.056036472320564, 42.87879766956453, 43.893899225419574, 39.46158955174108, 36.9212390530494, 36.70416332060291, 38.485162565785075, 38.35871711854012, 38.64015110077397, 38.75774768091018, 38.10202544735324, 38.504845019309755, 38.80374531592093, 38.19844907329929, 37.623460984999134, 38.36873485196022, 37.563982163706136, 36.50040011252127, 37.430166582907404, 37.010041513750636, 36.55768240651777, 43.65342655489522, 51.49362871723791, 50.57552737574424, 47.36505954496322, 51.82443749520087, 50.214759534405125, 48.78922508608911, 45.28174361874981, 43.34521455149497, 45.38021864429597, 49.39401142058834, 49.10541126804967, 54.52232214712328, 47.43799601831744, 38.569171890135735, 47.37845051673151, 48.21181689539264, 54.297903737714215, 55.270282837652395, 60.48015532955047, 53.195443153381355, 49.624952731593964, 50.172915689406864, 51.6097112624876, 50.71752502072243, 52.019818598224276, 44.20961472295946, 37.10197794821955, 37.093125158740634, 37.53917709473641, 36.19749115359399, 37.6521570451798, 37.530822446269376, 37.25713122275568, 39.38936694975823, 38.64916078505978, 37.2442501591098, 39.01555722759616, 38.73355057931716, 38.49339562077677, 37.229274549791896, 36.87263304187406, 36.43386886965844, 45.433111806069654, 49.320090432320875, 49.73508504129226, 48.088932960264145, 48.68826720022386, 48.370315951685754, 49.59608016475555, 48.97064255129907, 49.81492096377958, 48.072313877844046, 47.12012713955295, 45.08375806193198, 45.92166654525265, 45.41750469515401, 47.478674919374534, 48.353002609745154, 49.308017376930486, 49.273327935126524, 47.82413767230126, 48.14632508062547, 47.525225608579575, 49.46955627010715, 50.61205640915902, 48.52132720331992, 45.94018013246598, 41.980319946042954, 17.4162257102228, 1.0381709760235203, 1.2599439918994904, 0.1920731813316384, 3.103992640972138, 5.459215112270848, 6.112121574340328, 1.9012843649233542, 0.015421769348904492, 4.606106463939914, 39.446837517523, 30.559744950263735, 28.887538525366015, 26.45909324769051, 45.008319116407826, 12.15658030202312, 0.11534500176147108, 0.03622226499681992, 0.04393800762632201, 0.03349110409016571, 0.05986632005642018, 0.042742780229497346, 0.07927267932363095, 0.050279124219331055, 0.027520546141350945, 0.07141071732246107, 0.008364512806668157, 0.03324833082696123, 0.020204117266280998, 0.011881768981355333, 0.006579524591459983, 0.022561333420115615, 0.04678587436736111, 0.09155000439814984, 0.024918103327734337, 0.12181970110583691, 0.01876907179041976, 0.06882416700283367, 0.09591555643466212, 0.07138657023108776, 0.03416503546759486, 0.009741100985857268, 0.040222971489833254, 0.11548924079585461, 0.0786601537237725, 0.05437394461384224, 0.049171445350493156, 0.01882575463593727, 0.06273924170302288, 0.021481643573591308, 0.5714705189870251, 31.598384649522846, 64.2458934937754, 39.280046570685606, 32.587420094397764, 38.92194986343384, 49.52590504000264, 51.662443607084214, 59.87638488892586, 9.176536029384984, 0.16902308190061202, 2.6550592337885215, 2.463299459026706, 0.9905611242978805, 3.2381097539778683, 27.38750453918211, 50.83949504360076, 52.745213893152055, 54.26658361188827, 50.492839890141646, 51.702141915598226, 51.60578889231528, 50.6961481032833, 52.74253099195419, 53.62630374969975, 53.906663002506384, 53.319437119268606, 50.488795926493985, 51.14598512649537, 51.155316445135306, 51.049420295223115, 54.30281846754013, 50.93923699471259, 50.38652796899119, 50.78018488422517, 51.27762771421864, 50.33023411227811, 47.52570806011077, 45.12608435846145, 42.87238067196262, 36.65112110876268, 38.448386423049435, 39.341004125533566, 39.7944026608621, 38.73211499183409, 39.55695806011077, 40.03477727213214, 41.23613257561961, 41.22238466816564, 39.53783650552073, 39.3765486440351, 38.85193163348783, 38.52449609387306, 39.51931507356706, 39.548685781417355, 38.469327957399436, 38.30822444731189, 45.48881338488671, 53.63169308631651, 51.593174549841116, 50.64721261301349, 53.817538907451016, 53.32557955095845, 51.81566707549557, 48.199375137206054, 45.57335222921064, 47.03820451613396, 50.884261054377404, 52.0673498799724, 55.41591651978032, 50.10650211764921, 40.40037355115337, 48.34502450881466, 51.17962729546332, 53.25894632647115, 54.91676353639173, 58.650620675856075, 55.05332869868125, 53.13412081810736, 51.640348895903564, 53.04720893982918, 54.82198730591805, 53.09667002770209, 46.63073693552325, 37.973265801706624, 37.556353153720984, 39.25763414752099, 37.81816351798273, 39.91436443021221, 38.265898150782434, 39.37692911394181, 40.20489438887566, 39.7261102737919, 38.34089386847712, 41.01730746607627, 41.05683711267287, 39.464088101540845, 39.29539088279971, 37.49578783589025, 38.568791420229026, 47.67120838165284, 52.083019748810806, 51.31675727905766, 49.93883648226338, 48.53321198494204, 49.373148333641794, 49.3465389743928, 50.97307920455933, 51.06163455593971, 50.515130719830914, 48.879518047455825, 47.87632088507376, 47.92255386229485, 48.63341285336403, 50.13509619620539, 50.44193537004533, 51.004615060744754, 51.280863669610795, 49.72260013703377, 51.323029148963194, 50.05750779182681, 52.16000410818285, 51.64742877406459, 49.644152733587454, 46.765815519517474, 46.51239902742448, 20.68983977840793, 2.959505271527075, 3.7775418018141105, 1.8145887073009246, 1.4638535534181905, 6.5951746990603795, 3.9815874205481623, 0.3839559438488176, 0.10388979628201454, 5.664765450262255, 46.55930272994503, 39.08467331240254, 34.44681182984383, 29.100958608811904, 51.8943262869312, 16.6997165449204, 0.14004229748200986, 0.024572197392943407, 0.017036904858785774, 0.04061161555469998, 0.018734948319052497, 0.0499932240364292, 0.0427013578554315, 0.03323162244933267, 0.035114118814348214, 0.040147205394121914, 0.03254082181581086, 0.04202911570187538, 0.07602499512534949, 0.04469509784793181, 0.021250292681337848, 0.10742552187894622, 0.24816408603181764, 0.13421671975764538, 0.11778661590670386, 0.19566739008070963, 0.11075700077438548, 0.22255782698912008, 0.28244132656724225, 0.15733945964565202, 0.18956249669915248, 0.23162513640859436, 0.19141305868904437, 0.2510430444512637, 0.15359682902213068, 0.12102322247360023, 0.1530751997544881, 0.13230646419669354, 0.2060054708272219, 0.19454577607252907, 0.8828493460051475, 35.055850013609856, 70.94103813171387, 45.331275309285815, 41.0022847883163, 42.30686118525844, 55.10388412783223, 55.897940512626406, 64.77397395718482, 11.574902611394084, 0.5841318686162272, 7.229873028493698, 5.860244612539969, 1.6859857113130632, 3.308285369027046, 28.88283952589958, 51.7921995347546, 54.30024931507727, 53.61084176648048, 51.879334988132605, 53.14669593687981, 51.30539025029829, 49.696296722658225, 54.18665747488699, 56.01547825721003, 55.02737045288087, 56.01070473271032, 52.66458172951975, 52.87222416170182, 51.729398465925655, 51.44546593389204, 57.32454969036964, 50.99437375222483, 52.88717623679869, 52.56057223966045, 55.55269349005915, 52.54909146216608, 49.1002651183836, 46.74259508809736, 43.837456318639944, 39.48573958489203, 40.32961399324479, 41.06855715474775, 41.918413177613296, 41.1629254587235, 42.23869431403376, 42.26611168153825, 44.2382715594384, 41.83435678482056, 42.312540777267955, 41.631558479801306, 43.4918249037958, 40.95980159697994, 42.041450085178504, 40.96075473293182, 41.48310461351949, 40.410336371391054, 47.467621680228945, 55.37180162245228, 54.06107494907995, 52.33999383065009, 55.66827397192679, 54.06213791139665, 53.949805152031686, 49.9731219199396, 46.08209933004072, 50.25357530963037, 52.28069151601484, 53.97928568624682, 57.78780121957102, 52.63805081767421, 42.20675445372059, 48.616036753500666, 51.11346867776687, 55.14695175232426, 55.85375501263527, 58.171671821225075, 56.88690731602331, 55.31460954296974, 53.138054955390196, 56.29602186141476, 55.22455976855371, 55.63138015808598, 49.13331108708536, 39.50442967876312, 39.84057288016043, 41.11022449308827, 39.68625899284117, 41.27028857508014, 41.49311450219924, 41.74862553996425, 42.11377074641567, 42.0249016054215, 40.48670884101622, 43.65374426687918, 43.85943335871543, 41.7021179968311, 41.96975308079874, 39.126081774311686, 41.99942188878214, 50.904527941057765, 55.48902165505194, 52.97994421374414, 50.92506939365018, 50.25667790443667, 50.11259748089699, 52.650990716872684, 51.91375378639468, 52.65921592712403, 51.972699165344245, 51.56455301469373, 48.50016601624028, 50.76098095986151, 50.942610233060776, 51.979763354024584, 53.35462077971428, 53.980470242038855, 52.063662852010424, 51.60210186435331, 54.377731815461196, 52.556783230074, 55.24508553166544, 53.360853425918094, 50.41992302863829, 50.0379704659985, 47.82740500665481, 23.95250258907195, 4.408930386266401, 5.578786605788816, 6.855230783262561, 12.273196289616248, 17.628069000859416, 16.00779966000588, 5.706724024588063, 0.28456201115923546, 6.3170315854011045, 51.716066329709946, 44.11279101525584, 40.59340123207339, 35.89824176603748, 58.6028697413783, 19.972397089004517, 0.33889707298048083, 0.1563041531030209, 0.16214273900033968, 0.12210286252440945, 0.12013983882723317, 0.11217977926735917, 0.11568218003958465, 0.1107296207919717, 0.12246885336935522, 0.18424436029407287, 0.15539463819755664, 0.10552537101771563, 0.21509573224090764, 0.102520628621982, 0.11686394727157971], [0.04294806498012716, 0.04227886802607006, 0.08690154375208002, 0.024909059659788207, 0.06783956781991067, 0.12001863605673276, 0.031182747108921893, 0.040476596388485164, 0.038874204751224294, 0.03245457180685574, 0.036046731270729535, 0.146551807861655, 0.04871608268830085, 0.015768321670381533, 0.0562747160062915, 0.04395997902799038, 0.07785140236298885, 0.06860315063667875, 0.020792361709379384, 0.06513762933712813, 3.8536848127841954, 44.359374738508656, 44.90747497927758, 27.69455748219644, 29.829719297347534, 40.05340853045064, 42.45703304967573, 58.15559402588875, 10.495341804719741, 0.050682779777074055, 2.0488330217138415, 1.482663034431396, 4.3304839634126235, 0.8113745071234242, 7.519889156664572, 41.71275546473842, 49.351163448825965, 52.16060423081922, 49.10894140120476, 47.03611389283211, 49.26541259211879, 54.71245511885613, 52.5176497428648, 51.35677329955563, 50.90266873759609, 50.31955742066907, 50.601399329400834, 50.019786357879646, 49.274147710492535, 50.50628969746251, 49.0165578165362, 50.206879492728945, 51.51586855611494, 49.93270581768405, 48.38365201027163, 47.62940376035629, 41.57283275358139, 42.27110093639743, 39.74267444302959, 37.56800259313276, 36.86570221377958, 38.91480722735005, 36.77253023270638, 37.50323249447731, 38.45919647524434, 39.05304724170316, 37.00797050229965, 38.42742527684858, 39.68908702173541, 39.64572914185063, 38.98208764291579, 37.48005520912909, 37.731388922660585, 37.28173625084662, 38.25161680098503, 36.23854267981745, 44.68119344403667, 51.58512192387735, 49.380028170924035, 46.390782017861646, 53.54421246436335, 53.651183343702755, 51.55116204292544, 47.98178165189682, 46.815037342809866, 43.60305547714234, 48.20601570990778, 48.608819592383604, 53.67296426526962, 47.3165359035615, 42.33815777686335, 47.08903058882683, 45.395704161736276, 46.3846395861718, 44.36350891667028, 45.24405356376402, 45.417241896352465, 51.38017416000367, 49.95704412460328, 51.55637487288445, 48.93929104651175, 49.02792876766574, 39.909665430745775, 37.55162277529317, 37.51519572350287, 37.7042971118804, 37.8532491191741, 38.073082277851725, 37.67661302320419, 38.20930619393626, 38.290479644652336, 38.658648998506614, 37.629607339059156, 38.44001608510172, 37.599016774085264, 36.95541858673096, 37.043420883917044, 35.417421940834295, 38.388162351423695, 48.076295083568944, 48.80899383175758, 46.892111916695875, 45.659562003227975, 49.21139763247583, 47.346765610479544, 49.83207348854312, 48.182532479686124, 49.23174296655963, 47.22416408600346, 44.189006590074115, 43.80288454794115, 43.18232244060886, 42.20221627143122, 44.27396905037665, 44.53746603381249, 45.51200635971562, 45.0531518074774, 43.43964953576365, 44.84216751590852, 45.31577017999465, 47.6403118718055, 48.353363467801, 46.284811342916186, 47.50048329753261, 31.325405336195427, 7.890058429010454, 2.3804717486904514, 3.637324912894157, 2.7901486043007147, 1.367811623119539, 2.4940189719200134, 5.326607131188916, 0.27241758701782076, 0.08264168886648071, 6.006214637910166, 32.59444702056147, 26.526026533495997, 20.099658389245313, 30.337709380734353, 43.66569180642405, 5.825349246301959, 0.0495201455909879, 0.02976547487290396, 0.03620979691585226, 0.049481741603343725, 0.08091842770696649, 0.022127199054305113, 0.018777431724893472, 0.050776935813407746, 0.031927306047310276, 0.017945431510827715, 0.025482039800995303, 0.022833187380925785, 0.011298025304812097, 0.09842430286469961, 0.03505933969732254, 0.030482288021894715, 0.004694545622764817, 0.023074857477519303, 0.03971198701389855, 0.060666108188489755, 0.06515217734681022, 0.010278315354709425, 0.030868449961886774, 0.0801345665428427, 0.04562804738299982, 0.039241360049814954, 0.05377762943446156, 0.05302841459671336, 0.01772242331606967, 0.01660737851183982, 0.03952842468636171, 0.06424315656805712, 0.031792568418407635, 0.0887761915463113, 0.05266827666350911, 6.640727635352842, 52.32203722000123, 46.32410172493228, 32.79478796066777, 31.662633072945383, 50.86933251350157, 49.15375448042347, 61.71467819521504, 11.270210935223488, 0.12998933933915632, 1.8152031711032315, 2.913926104384084, 7.291719980778233, 0.9354722319591431, 11.803730745469371, 44.27854253399757, 52.03054628064556, 52.258294782330914, 50.53125950597948, 49.50388485385526, 52.589891956698516, 53.87768060930314, 53.925541370145744, 51.850988018897276, 52.545231849916526, 52.2956592805924, 52.9490202473056, 51.59124474371634, 51.29224638785086, 52.07331972737467, 50.884170839863444, 51.861362688003055, 53.374479739896714, 51.14800122476394, 49.36333456347066, 48.67008701447518, 45.31074954617409, 43.647052703365205, 41.29725879238498, 39.174472055127545, 39.252931225684385, 41.08487813703476, 39.550446925624726, 38.50043627523607, 38.982268071943714, 40.976522661024525, 39.52295111071679, 40.43527087857647, 40.50221397030739, 40.93196061349685, 40.248350328014745, 38.36321607712777, 40.76205530474263, 40.12238733230099, 39.857109592806914, 38.39397922638924, 46.893786768759455, 52.095645858395486, 50.80156964640464, 48.60278306468841, 54.48973901810185, 55.861572296388694, 52.97510793132167, 49.355368229650686, 49.07132587125225, 47.257570912761075, 49.55131415397891, 50.71365364136235, 54.18565727049305, 50.230962845586966, 44.15799240912161, 48.16078685945081, 47.45430131112376, 46.750985037895944, 46.513905217570645, 49.312261381456935, 48.627074303165564, 52.39430689042615, 51.563599878741854, 54.44773435592652, 53.81609939759778, 50.826421783816436, 42.59845802860875, 38.761250357474054, 38.76936574136057, 38.83197853642125, 38.491026509192686, 38.0603620313829, 38.46699022477673, 38.573231543264086, 39.813214348208525, 40.6510796854573, 39.61105931189753, 39.583198716563565, 39.7664753852352, 38.19960617250012, 38.784066784766416, 37.73840996526903, 40.12265013110253, 50.04062591060516, 51.92741147933468, 48.62659969637471, 46.25080047115203, 50.229233080340975, 48.104387098743075, 50.55438972288563, 50.57530380064442, 51.530899078615256, 48.278352060625636, 45.59517237447923, 45.46510657956524, 46.45954901172269, 45.32924744390672, 46.016285880919426, 46.02160853724326, 47.503809467438735, 47.17936277389527, 46.91735236875473, 47.75837129162204, 48.561857054310465, 49.5461444700918, 51.23803138732911, 48.33761122918899, 50.403111750079745, 36.98223975396926, 11.445265335421409, 3.0640766409135636, 7.085050296398902, 1.4441467076539996, 0.4622424688310393, 1.2230382883741011, 2.0823855890381724, 0.33028278199415056, 0.049795335864708315, 7.130228646339909, 37.81663379361553, 31.72226682786019, 27.61392139619397, 33.43380089729063, 50.4998452432694, 7.648824818672673, 0.12011356201143035, 0.028197179893933, 0.09382948369508791, 0.04586987069717819, 0.05625836768998735, 0.01713784460368897, 0.03197456409613932, 0.04672441879407533, 0.09459528816683639, 0.11153489411357911, 0.054406541655020374, 0.028168145161602768, 0.018453252043635137, 0.04141626068420949, 0.0453372327460637, 0.07164733123875434, 0.10361951280144915, 0.1829916992855649, 0.10818630081391144, 0.17496413971868255, 0.297640327123865, 0.21963800543979292, 0.15715132377320723, 0.12949383366973172, 0.21239769314565968, 0.1611464569765714, 0.21792964469040596, 0.14361985147960726, 0.11075595889480845, 0.17623379255735105, 0.16192985848794061, 0.16852699400436494, 0.18676601530563447, 0.1595587550752586, 0.14081941707239998, 7.850746473958416, 59.7637265728366, 55.85906197947841, 41.92294743753249, 41.25650928866479, 52.91274616795202, 52.50310559426585, 68.47280825338056, 14.21398210910059, 0.23009101469670573, 4.228000765846622, 4.571511649316357, 6.092439611111918, 1.4487769430683506, 12.354895337935417, 47.13853482277163, 50.7969137930101, 52.30854426660846, 51.06646299362183, 49.88819476096861, 53.07949789108769, 55.01604657019339, 55.099349867913034, 52.046118090229655, 54.95506940349456, 51.719294440361764, 53.94779297613329, 53.07104518336635, 52.66729993204917, 54.65604359103788, 52.11594020166705, 51.42889784228418, 56.129046563179266, 53.02869143024568, 53.374173795023275, 51.318785144436745, 46.237797814030806, 45.48193354760447, 44.358892286977465, 40.18269769607052, 39.92300933407199, 43.2407892903974, 40.02172362419867, 40.848888735617365, 40.98008417314099, 43.49951274933354, 41.24862140224826, 42.84444162922521, 43.25265838253883, 42.565718004780436, 42.92107689765192, 40.589525930343136, 42.81115247357277, 42.351823314543694, 43.96687884484568, 40.65447645802652, 48.85567003680814, 53.88686680024671, 54.04619739901636, 50.92823474637924, 57.81717192742133, 57.03112110014885, 55.47798802775722, 51.640505790710456, 51.63420646421371, 47.30261541181996, 52.70819064109556, 51.80361363195604, 56.07394902936874, 51.543635014564764, 46.66265326161539, 47.63228670243294, 48.474231304660925, 47.7054153719256, 48.37458349043324, 51.885791209436235, 50.812411077560924, 54.10706081698018, 52.7186555247153, 54.20404534186087, 56.11014466131888, 53.25217631555373, 43.865340448194935, 41.11772406485773, 39.952242758966264, 41.03591126780356, 40.808315738554924, 41.43313753989435, 42.317447662353516, 40.62433304325227, 42.06534124189808, 42.72003581446987, 41.00341050855575, 41.62807541508829, 41.02997279936268, 39.87168904273741, 41.09200900600803, 38.33038583878548, 42.441425938760084, 53.237357601042724, 52.756910401005904, 49.637822028129335, 47.83349644753241, 51.197211280945815, 48.394344391361365, 52.561454772949226, 51.25250101089478, 52.65392857213175, 50.94456357340659, 46.78044203789004, 47.02772394303353, 46.23584055131482, 47.66571314104142, 48.18866706663563, 48.06535167078818, 49.38961052125501, 49.814744457121826, 49.293598744177054, 49.90324881768996, 51.84699112369169, 51.77690229108257, 53.2285754142269, 50.254712796980336, 49.88735145138156, 39.118668494686005, 14.956348519171438, 5.002998353973513, 12.935987614816236, 7.1780369454814545, 3.6089558803266097, 7.44693797442221, 13.05072674828191, 2.0593632373117634, 0.11859830904511676, 8.220507329510104, 43.99786556920698, 37.60169575291295, 33.02222267273934, 41.49628377729847, 59.305111285178896, 11.007303287906032, 0.20899269279212723, 0.14080326793895614, 0.1705389094328688, 0.1564115739517635, 0.2029715481424524, 0.08410313181699285, 0.12822588154625508, 0.11508349764851794, 0.2430439067463721, 0.23979445288498558, 0.25315301913407545, 0.11573972856445659, 0.11372842600629215, 0.19693120532939512, 0.18008431900412808], [0.027537015116503163, 0.06163288816629399, 0.08521985052333725, 0.028811021249801404, 0.10422315178138596, 0.07108363608318953, 0.01990352734743107, 0.04961434759259705, 0.056944399426180514, 0.07178709631966007, 0.006803921320580788, 0.08908742242642949, 0.05455682129268685, 0.06483430448438852, 0.07546285512827097, 0.12809491881559934, 0.12376128200201258, 0.04090701522786291, 0.11127705956178327, 0.01814207478967165, 0.7181767854959734, 24.60972709040488, 48.85599559353244, 34.21443885372531, 31.674284473542247, 38.8730888981973, 38.10726573390346, 54.374009486167665, 16.933111298468805, 0.07635842723351333, 0.3219556514053576, 4.607142459961676, 1.838101477872941, 0.9424414257368735, 1.3656115411750733, 22.321969386070005, 51.404555612994784, 51.91979815883022, 49.835234918902, 51.73880038722869, 50.77713720260128, 54.823528797395774, 53.93765757160803, 52.64178099170808, 50.66563990808303, 50.95424398299187, 51.343029314471835, 48.86484838301136, 49.1734016326166, 51.96341491514637, 52.54261562901159, 51.8690348440601, 49.647251406023585, 48.88522117368637, 48.681038271996286, 46.056486252815496, 43.69004580282396, 44.32175136381581, 42.201937783148985, 41.39784013071368, 37.99462702966506, 39.66110875529628, 37.90407519186697, 40.124144554138184, 38.606355959369296, 37.86066632116995, 37.22095520265641, 39.926551234337595, 36.7132043838501, 40.02841518771264, 37.86683228708083, 37.76828665887156, 36.8205439659857, 37.428868278380364, 37.38979362672375, 37.673149570342034, 43.85115323528167, 50.2689431559655, 47.77762620679794, 47.895246321155184, 51.06585894861529, 51.250932062825854, 52.67392089290004, 52.21383471642771, 48.06706574655349, 47.168164407053304, 47.960318442313906, 49.2301034158276, 53.09613266298848, 47.3117192329899, 40.43710654781711, 51.77192872570407, 52.10426722803424, 52.24616289138795, 51.07386450613699, 51.33466289889429, 54.39331146978564, 50.46796421850882, 50.096327489422215, 49.59686463879001, 49.3374861440351, 41.741165191896506, 37.20983136084772, 36.98187105117306, 36.16750071125646, 37.509892679029896, 36.512732044343025, 37.24226151743243, 37.80669842996905, 37.46944519781297, 37.5243583802254, 38.02628840169599, 37.17803270586076, 37.68130025556011, 42.21640740671466, 39.119598096416844, 36.16947758582331, 36.98621703732398, 38.1590449425482, 46.3133308964391, 47.99879689370432, 50.087055006334865, 46.69071389782814, 46.55871829678936, 46.278053099109286, 47.5604445703568, 49.30627584457398, 48.153895255058046, 46.62950923365932, 46.50915522729197, 43.91556247588127, 43.46302293962048, 41.3573024349828, 41.78597434874504, 41.48912152936382, 41.2447343334075, 40.17420576464745, 40.8724739474635, 41.07304042385471, 45.61826336768366, 46.17812679659936, 48.21608835651029, 51.011730240237334, 39.88213039213612, 18.352520965760757, 2.54414759816662, 2.4066530792943897, 8.144299109135906, 0.5745993446438544, 0.1536044899013735, 0.3643124688777232, 1.0017812480368922, 0.26218550219651193, 0.00431786066920106, 10.127471531591109, 36.448742497351866, 32.6891859885185, 22.030615729670373, 32.366855413683005, 38.53599648321829, 2.6190857060493964, 0.007043338161067016, 0.03840400296593866, 0.061316654732030254, 0.012443775870657016, 0.0034573205677236644, 0.00884901553828029, 0.10859387491138713, 0.048265270588378754, 0.05448270611645234, 0.03542785097153918, 0.04691835395210693, 0.04001094899590939, 0.01260670266234346, 0.02395818558251185, 0.04334105276352456, 0.07129365908763102, 0.06141954417070074, 0.04319284922413288, 0.06195479448163702, 0.03911704696234196, 0.03091580951736579, 0.09374205774116902, 0.012513797264546158, 0.06529315284663631, 0.05140334292645416, 0.008165622017376365, 0.0325264576672306, 0.06825233599351299, 0.10949182188919476, 0.040398083867565285, 0.031090768677512967, 0.04969200209504174, 0.007709972551017399, 0.02403146955334852, 0.046974630771024574, 1.1947469677655929, 34.13779574055826, 56.06464124494984, 38.37265722213253, 33.304127339393865, 42.54109728720881, 43.01670820482316, 60.626997101691465, 18.219878173643544, 0.08075980920224421, 0.8313950812143664, 4.022932389090139, 5.282492233860878, 2.729894869750546, 1.6684784571970663, 28.266756765304077, 52.48819666524088, 52.10874265240085, 48.285471162488385, 53.29256888358824, 51.10992285513109, 56.93583888392295, 54.55595647135089, 55.08411145979359, 53.281413662818174, 52.679145489969564, 52.20087912774856, 49.28234938652285, 49.83741575671781, 52.86430881869409, 53.911154116353686, 53.35171822578677, 52.08690681765157, 50.11624920752741, 49.728460158071215, 47.229471052846606, 46.135804422440074, 46.18421431510679, 42.90968633467152, 41.44756401738813, 39.42796307225382, 41.04885901174238, 39.29440636788645, 41.918146456441576, 41.681639302161436, 40.82629588342483, 39.22164247881982, 41.246797500118134, 40.30791936382171, 41.514412972234915, 39.636240928403794, 39.201748217305834, 38.567442124889745, 39.33020191807901, 38.104676969589725, 39.6260819896575, 47.508696740673436, 53.52197654785649, 51.49736281364195, 48.35502655275407, 53.11851762956189, 52.40320282597696, 54.47841513541437, 53.312824003158084, 49.55844894532235, 49.8911718399294, 49.54967460324688, 51.02395626806444, 53.57606211016255, 50.876396702181914, 42.7451507506832, 52.80617144800002, 53.60539359431113, 53.25793043259652, 52.542901962034165, 52.466953108387614, 53.9044076396573, 53.795130406656575, 52.2294928181556, 51.928952970812404, 50.91243936169533, 45.463949480364406, 39.09802898283928, 39.046496883515395, 38.63516184591478, 37.74283047645323, 37.84965230572609, 39.04841492252965, 39.418431712735085, 39.892089290003625, 39.18492517163677, 37.58327630258376, 38.51890671637751, 38.93881997754497, 43.06113296939481, 39.436976678909794, 37.63782078219999, 38.14638745400214, 40.135440980234456, 48.122822238552956, 51.16937421983289, 50.939970477934814, 49.16434880225889, 48.02984245361821, 47.434493341753566, 49.601371442118, 49.94918761714813, 49.8127636601848, 48.07688343909479, 49.4721842581226, 45.36290922472554, 45.18295088121968, 42.71254408744074, 42.208107671430035, 43.721820923589895, 43.54912288727299, 43.85757807762393, 43.320888011686264, 44.589751228209465, 46.455269705864694, 47.926001625676314, 51.05360546419698, 52.24526859098866, 43.5552849308137, 21.72801075443145, 4.4149237678897, 2.883842996051235, 10.377184325648892, 0.5489540917258109, 0.15348890255535805, 0.6973436066219885, 0.1502888613650876, 0.08214273580139683, 0.05289583159009776, 10.195116727582871, 40.190263948132916, 34.75869517172537, 24.35499268193399, 38.646932878801906, 45.161016987216094, 4.165640473365784, 0.056018984365847804, 0.05607101322722532, 0.03170821830750473, 0.04396126988614279, 0.034907818997218724, 0.01956278484524979, 0.13459046341238484, 0.04422036465257407, 0.02237413409015825, 0.0700780920564167, 0.07319362608775978, 0.006310546812000535, 0.01677126961670095, 0.01214595344443355, 0.0584239641865415, 0.2166245679461187, 0.1897584773119419, 0.19267777792148053, 0.12534408094060998, 0.1719950127505487, 0.19845259465998222, 0.13468528977565228, 0.1161356351428455, 0.13497894659878748, 0.15636848916690196, 0.08313367819233287, 0.19592579153756942, 0.20057151724974956, 0.21141851020436134, 0.1720123569811544, 0.1927031507535327, 0.22938094312144866, 0.10537969173803445, 0.23463475878440568, 0.1669038988409504, 1.361070784830278, 39.648498335192286, 63.51192389765094, 45.75299678310272, 43.396723116597826, 51.57672020696825, 47.28647878093105, 63.677749941425944, 21.672985784469113, 0.17174356737204138, 2.5682017783964834, 10.939055027500277, 4.451487612339759, 2.182234669885328, 3.245592410525968, 29.012597414755053, 55.75255001744917, 51.72295401173254, 50.49065905232584, 54.68962692445325, 53.73224304568384, 57.83982753753663, 55.85138197868101, 56.870284311233036, 55.58563355476626, 53.18050676776517, 53.0758696986783, 48.892552083538426, 50.76663701764999, 54.48784451330862, 56.18193580258278, 55.922294509026315, 53.58577782107938, 51.03432701480005, 51.779565580429576, 50.131824939481675, 49.5980138932505, 49.440248320179606, 46.09590999541744, 45.07556030827184, 42.92209279152655, 45.27633467028218, 41.11423315540437, 43.82555192516696, 43.0757987114691, 42.38250801640172, 41.02209668005667, 42.78859884508195, 39.66863970602713, 45.092132322249874, 40.045336292636016, 41.42871702871015, 40.57227926869547, 41.29784322554066, 41.60962850816789, 42.15122938156128, 48.14003359886908, 55.11812233155774, 53.761970689219815, 50.84825761856572, 52.9146759740768, 55.12945405898556, 57.44613139860092, 56.579369960292695, 51.65111580202657, 52.32336690348964, 50.085470368785245, 52.093774887823294, 55.779492778162805, 52.40726640147548, 45.99465793178928, 55.567673021747225, 55.42302777690273, 54.499231153918856, 55.94167494004773, 55.16622627935102, 56.57925228918753, 56.11288247569915, 54.36558031266736, 53.071970862727014, 53.3401236995574, 46.12148384894095, 41.13671618123209, 41.778666973114014, 40.242521685938684, 39.558366191002634, 40.72361999942411, 41.27149274272304, 41.46327310992826, 41.657681465148926, 41.8214443422133, 40.32506012147473, 40.70677341953401, 40.85444673415154, 45.21741674792382, 41.00963923238939, 39.92552749572262, 40.87110111790319, 42.733807256144864, 50.614484356295684, 53.50021131577031, 53.49888555465206, 51.01645669629497, 47.87259463341006, 49.368527781578806, 50.77925920486451, 50.0306591679973, 50.87976209578976, 50.77323836665, 51.79371749201129, 47.32707923458469, 47.276931731931626, 44.81152203775222, 45.32031228465419, 46.32544709790138, 45.73919004009616, 45.4571206338944, 45.19753817589053, 46.203218198591664, 49.7801766087932, 50.784260226834206, 53.129868968840576, 51.89408309998051, 43.800640952202585, 26.39839064690375, 5.812612329759906, 4.564421965229896, 21.2568340762969, 2.636722153232944, 0.974028763030806, 3.644664157782832, 3.2913299433646666, 0.6256699526021559, 0.12916749553574672, 13.174152951086722, 47.521695475424494, 43.93954776948498, 34.32800323732438, 43.33571457093762, 52.430886914653165, 4.963383395825663, 0.14924973970459354, 0.2959195097848293, 0.1494997754813202, 0.0714640217202325, 0.14020613304549648, 0.10715891562041738, 0.2830425217267006, 0.2180902780063691, 0.1146836993434737, 0.2124943274764284, 0.12628294467445345, 0.08994619932866867, 0.10841818796771188, 0.07730161170324973, 0.15062117498488198], [0.028244393892706405, 0.060964802039727095, 0.04109902750520457, 0.028422639570048744, 0.005139450705985749, 0.068778301318807, 0.03421534829202198, 0.01978490437801567, 0.02106262986818629, 0.12198931297227261, 0.04771392093971372, 0.03561093449412334, 0.029790945381166476, 0.024217107979160164, 0.11398727179414804, 0.02401308918882522, 0.023668311318502794, 0.04238073856780126, 0.07734520210614128, 0.09632460908183167, 0.02262602379966167, 11.814250542271523, 44.516277390141646, 38.37333971454252, 24.11130759023851, 38.47799247311008, 35.26788550038492, 48.232307357172814, 25.33914281475929, 0.07596561565033852, 0.5760709076158462, 3.8036699352725862, 4.748114895436072, 2.286791820679942, 0.46611654482060866, 7.358183562755586, 35.679601007892245, 51.88160604046237, 56.1024332815601, 52.43582910107028, 50.154002020435954, 55.81215043221751, 55.034881791760846, 52.0276084253865, 53.2723137640184, 52.50852238747382, 51.163769152856645, 50.50586215911373, 48.588293829271876, 50.04807449156239, 50.986344660482104, 51.77126584514495, 51.161270603056884, 51.09579840014058, 49.63251113891602, 48.97471004916776, 47.984656749233125, 48.42539387364542, 44.59239882807578, 45.95441441382132, 41.608385116823264, 41.61546891735446, 36.18253907849712, 36.315801605101555, 37.34136804457634, 37.20375953182098, 38.730495052952925, 39.48040908382785, 39.29756387587517, 42.41616587485037, 38.9428678635628, 37.14517501092727, 38.076537885973536, 36.93911329392464, 37.450931610599646, 36.59706300304782, 44.749309324449115, 49.43332925919564, 49.458789363984145, 46.82413724160964, 51.267970838854396, 51.76418204461375, 50.47955089999784, 49.65178566594278, 50.506266163241484, 46.59049341755529, 49.437416368915194, 51.1360340733682, 52.794918167975645, 46.665481290509625, 41.72996682505454, 54.949091711351954, 50.43206668669178, 49.75977243915681, 51.0448468116022, 50.822715144003595, 47.556388839598625, 49.036550137304495, 48.083170998481016, 48.4409107700471, 41.64966414051671, 37.981126231531945, 35.9622940709514, 36.33479764384609, 36.97608555516889, 37.489833677968676, 36.98594639378209, 37.878830817437944, 36.820551810726045, 38.2620777622346, 37.95471691316174, 39.27694005350913, 35.824081513189505, 36.13872228130218, 38.062048650556996, 42.58910317574778, 38.323196134259625, 37.11239576339722, 36.09885531087076, 43.75342738243842, 46.38990732931322, 49.49492223801152, 47.78366665686331, 49.27989790516515, 46.40428673836493, 47.247674772816325, 47.46273048462407, 49.640120537050315, 49.20762038999989, 47.492242397800574, 45.319865134454545, 44.86286194093766, 44.00335688744822, 41.91431037841305, 39.0181303024292, 40.0451676307186, 40.74138049156436, 41.10794167364798, 42.29616488179853, 45.37386048224665, 49.18357233847342, 50.38891277005596, 49.33104561221216, 29.949937981943933, 4.599907157882567, 0.2669179643834791, 1.506733026716017, 1.7214340091713014, 0.27583075386862604, 0.12437766868500941, 0.4079452823967703, 0.13843639333161617, 0.04775242834922768, 0.06787352849759402, 10.819539427757265, 30.683658507562455, 37.29226781475929, 36.560596727555804, 34.040379754958614, 25.0262749579645, 0.08050031223965269, 0.022571756046325452, 0.016017465912286314, 0.02691318205888233, 0.06452693468740871, 0.06335064498407227, 0.046102933795942415, 0.046559016580783555, 0.024311836666217255, 0.027351522247397134, 0.07778840695297526, 0.006909521274088372, 0.01398240984041965, 0.05243396867186793, 0.07531830965871773, 0.04585464469968312, 0.008463872495227525, 0.023352698415457722, 0.0463289910206391, 0.028200317023982926, 0.033934140397656354, 0.01594654532269605, 0.058999231100202575, 0.07472528865741146, 0.02590032189243263, 0.05928572883168536, 0.03476328118854473, 0.05258652742110914, 0.08847315014610369, 0.03714355084324076, 0.04315446821912643, 0.013136037816894392, 0.04318537986687115, 0.029680094373742902, 0.05381725916278459, 0.05429251329793085, 0.06734479759489337, 15.686707573552287, 52.32102917086694, 42.77593351179554, 28.98282074159192, 44.581835885201734, 41.329406538317286, 54.765156084491366, 27.342108987992813, 0.05524672177289763, 0.6542642150194414, 3.7079023257378614, 0.8996953130249055, 3.1410904180619026, 0.5688222449633383, 9.542432369724397, 39.924962674417806, 51.97836306787307, 55.1989310018478, 52.93249137939946, 52.323308067937056, 57.3974940084642, 57.43312481910952, 53.89566859891338, 54.416935905333496, 54.262049351969075, 53.40491733243389, 50.85226628088182, 49.34445227346113, 50.791163598337484, 51.18160809240034, 52.72254651592624, 53.130535771769864, 52.25965584478071, 52.111103919244584, 49.62590586754584, 48.51171347402757, 50.98175156501032, 47.03260337152789, 46.29066351921328, 42.42157090094782, 42.52709834806381, 38.7515817149993, 39.03630656580771, 38.35467315489246, 39.31398291741648, 41.5624737739563, 40.54528159479941, 40.20444723867601, 42.11301765134258, 40.82075357437134, 39.00045610243274, 40.48106847270843, 38.695676172933275, 37.18369660838958, 37.7111965610135, 46.96558967713387, 51.86809347521875, 51.21614063939741, 48.505700480553415, 52.75341949155254, 54.19998568873252, 51.64818971387802, 53.575665950775154, 51.42932930300313, 49.50018605878277, 52.68675096573369, 51.540956035737075, 54.47747376657302, 48.59356157241329, 43.91107920677432, 54.554054121817316, 52.64905698837773, 53.2353062014426, 53.911565965221776, 53.51845425944175, 51.035460579779844, 50.39002280081473, 49.087521337693744, 50.641674226330174, 43.56114495185114, 40.67378236401466, 36.87182111124839, 37.44795453163886, 38.301587796980336, 37.346655399568625, 39.15291863103067, 38.57907195245066, 37.57788304359683, 39.00632004584036, 38.06657898810602, 39.32496947626914, 39.2387322456606, 37.423604457609116, 39.855807365909705, 43.79075265699818, 39.7748064994812, 37.81346059614612, 37.4498176574707, 45.107374652739495, 48.540888063369266, 51.8320704275562, 49.4227937729128, 50.00617965575188, 47.21464449359525, 47.65596997353339, 49.25318264192151, 50.11676303801998, 50.19211961377052, 51.0103181869753, 47.86636983194659, 46.695628627654045, 46.826506353193714, 44.526138228754846, 42.4260933937565, 42.69438351354292, 42.67148863884711, 42.247680464098536, 44.31581681774509, 48.119915762255275, 50.943214278067316, 52.612892735388975, 49.9515724182129, 32.893363006653324, 8.601298870578889, 0.28242683218371484, 2.0754125954643374, 3.180535733699799, 0.18529111219029273, 0.1727094663487327, 0.16898171315270086, 0.09054330357861134, 0.10534891032523687, 0.018060635812881014, 11.737987899011182, 37.39355125734883, 40.318125371010076, 36.73928030075566, 38.979663618149296, 32.04487196860775, 0.2723320303184371, 0.03290321587795212, 0.05871666339977134, 0.005189290471119626, 0.05273789107318848, 0.05369165138671956, 0.061498006895905545, 0.05807970342556796, 0.042284506433192766, 0.05675639761912246, 0.04843909593839799, 0.04012034635149664, 0.07881262820334205, 0.031107578561791492, 0.04648852116999127, 0.007493033209034512, 0.10941901289287115, 0.1936251988574382, 0.16189060414270048, 0.20218653784644222, 0.11425654403865339, 0.14075733330701629, 0.12518540880973303, 0.16516091091738594, 0.14439500988491122, 0.25163129272480167, 0.11065904877238697, 0.1661875606664727, 0.1792193138070645, 0.13588622452751284, 0.20253624166211776, 0.15985811159255045, 0.1669261460342715, 0.13028794509028235, 0.20584290696968957, 0.2510659658019581, 0.33056592809096463, 18.163409771457797, 60.06185024015365, 51.71385019056259, 34.23437233894102, 48.33064117739278, 45.34206967200003, 57.58415176022438, 30.731115264277307, 0.32516721455800923, 1.268874248189311, 9.952937826033562, 13.733462345215584, 4.778466686125725, 0.9185701873033278, 10.206633787001334, 39.91501162129064, 52.97290355928483, 56.56837163432952, 52.72076183749784, 52.73314476013184, 61.34366120061567, 59.40231546278923, 55.10557859174667, 56.2917229437059, 54.526934854445926, 55.19106272728213, 52.36863890001851, 49.20239579293036, 52.03850869209536, 53.832247795597205, 53.57554827966998, 55.08051464634558, 54.61776125815607, 53.74393563116751, 52.47262485565678, 51.590966255434104, 52.95783773545296, 49.69746951133975, 50.44294341917961, 43.44992614561512, 44.238036217228064, 40.3269624710083, 39.85613684500418, 40.8091982718437, 41.25650536629462, 43.129342986691384, 42.56958153940017, 43.56030556463426, 44.185068530421105, 41.22148252302601, 41.0723893104061, 44.00252926734186, 42.005026955758375, 39.94620623127107, 39.773653322650546, 49.02126073837281, 53.49417086570494, 53.778068096407004, 52.5374851688262, 55.57536871202531, 55.98814718184933, 53.78112362277124, 54.93706572440363, 53.333255629385675, 51.08707897124752, 54.04871163829681, 53.42543525080527, 55.8816195303394, 50.34610794436548, 45.35219723178495, 55.194318294525154, 53.82406965378792, 53.90180318586288, 55.40667149328417, 56.038333908204116, 52.04209766080303, 52.64227913271997, 52.356397182710715, 52.00570983271445, 46.541624607578406, 42.16908793295584, 39.31280620636479, 39.05086248151718, 40.60247367428195, 39.18351704074491, 40.794869853604226, 42.0978969143283, 40.109502346284934, 41.4019037062122, 41.31745507640224, 42.22196540524883, 39.470061871313284, 40.52729360518917, 41.82475482263873, 45.34541937612718, 41.80345243023288, 39.88822183301372, 39.04129189829673, 47.19248310212166, 50.42107228309878, 54.05470894229028, 51.25794526069395, 51.80494723781463, 49.785977794278054, 49.4843122266954, 50.290598561686856, 52.15380676331059, 51.9689650689402, 52.23023806848834, 49.425045213391705, 49.27162562647174, 50.07451518889397, 46.08948515307519, 44.29643638672368, 42.04450561154274, 45.5965805053711, 44.82680359194356, 46.51994174526584, 50.09472716239191, 52.33387885555145, 54.23376906302668, 50.35384285834528, 34.19513294773717, 10.99968800621648, 0.6955324521949214, 4.173821066656421, 4.511240509248549, 0.5625309470680453, 0.3227884809096014, 1.1339366243731592, 0.5555067175338345, 0.2897578033228075, 0.14552477506860612, 15.999938249588014, 42.525717673763154, 46.10135032284645, 46.202002263838246, 45.79161251744917, 37.216405253256525, 0.6377492592700067, 0.11689445289272456, 0.10247032728887374, 0.09444948631308733, 0.12206031400109492, 0.2531186677515507, 0.16042475618662375, 0.10966344090599207, 0.1215106688980614, 0.1360310611104773, 0.2258624545028133, 0.19885540369056887, 0.17719166293259592, 0.11825537744669185, 0.1363035279416269, 0.08268802186414119], [0.018493810653566353, 0.05615454362404924, 0.027651323095685052, 0.01505743421148509, 0.04270238824368965, 0.050815366614129276, 0.01428331672814825, 0.05925844844070174, 0.03250266680674207, 0.028543053269987146, 0.0030848684893440338, 0.0516468784471433, 0.086369740836803, 0.02760430253411253, 0.06295993248180998, 0.06825219809768662, 0.020797739646607832, 0.025920466174401587, 0.059035164454290946, 0.046838351390174324, 0.009235609360339661, 3.4993236728252906, 32.06647049996161, 44.337907606555575, 29.063994192307998, 33.9138440931997, 33.79143476486206, 37.777064923317205, 30.15720190540437, 0.34311938189691116, 0.5949569361344461, 1.3442751957524208, 1.555840856125278, 3.7468225340689387, 0.5019300827576268, 0.5444456949349373, 17.41391739537639, 42.90416755983907, 53.930126620877175, 55.37961106146536, 55.265128843245975, 51.23861974285495, 50.44216286751532, 52.92374841628536, 53.268167818746264, 52.633948018473966, 51.22861377654537, 49.77777611824774, 51.62174117180609, 49.309962872535955, 48.96166816834481, 51.20283595977291, 53.374405214863444, 52.77364323216101, 52.856801402184274, 50.65637134736585, 48.99960141028128, 50.53338935298305, 52.126718874900575, 50.88031514998406, 47.89336358347247, 46.563589880543375, 40.60336797468124, 38.49350152477142, 38.94248739365609, 39.793284785362985, 37.31787304724417, 38.02249546973936, 37.42443207771548, 46.21905672934748, 41.38846566600185, 36.53648591810657, 38.68206162606516, 38.150584390086514, 37.50285594694076, 37.85202926205051, 42.58831870171332, 48.85234778927219, 50.333760323063025, 48.63079663245909, 48.35802716593589, 49.138010086551795, 52.72912040833504, 52.56269816429385, 52.41580147897044, 53.14321679453696, 52.02829484016665, 51.23665463539862, 54.97508918085406, 46.18339846211095, 47.00855139763125, 55.365612122320364, 50.96203773252426, 49.1902050664348, 45.76551698869275, 47.093568771116196, 46.42734243023781, 45.255185250313055, 43.20791982835339, 40.557060472426876, 37.17666772104079, 36.6780246457746, 36.178095033091886, 37.76798071399812, 36.59712576097058, 36.91317073760494, 37.625900699246316, 37.83681046578192, 36.2608648884681, 37.05112834130564, 37.375790765208585, 37.68007255369617, 34.946098173818285, 38.09061919489215, 35.812941981900124, 36.76001394948652, 37.387146026857444, 37.62642237447923, 35.78282210134691, 37.411605927252005, 41.22464787575507, 45.76707809202133, 48.8131711559911, 48.17499760658511, 52.9440466819271, 50.35572167365782, 47.56555541869133, 48.45496462237451, 48.44000862490747, 47.670004214009936, 49.352571579717825, 48.61458155416673, 46.404223980442175, 43.701530502688506, 42.690519978923184, 40.915871051050004, 39.355156037115286, 39.49164667437154, 45.56627235104961, 45.86607087043024, 49.13906912649832, 50.09524491525466, 43.48042649607505, 14.377184087230315, 0.9408670844089602, 0.3116331375654667, 0.29499300304920445, 0.8229762652227957, 0.14270005567419913, 0.07323312558113568, 0.23333432453293956, 0.0678404871254198, 0.0783107793259044, 0.19162903419665753, 19.150085910674065, 28.03106350283469, 31.947922745058616, 56.94918670961934, 35.71827950016145, 10.283878003397296, 0.2687681892946843, 0.023622692697831703, 0.10021869528798327, 0.04791801059318166, 0.014695904871088364, 0.03534763773542739, 0.06338414600900104, 0.14002669993187153, 0.04333151113842765, 0.04399496243305264, 0.04687645660352804, 0.024683816403511073, 0.06641684295309168, 0.047923737100415656, 0.04067753359014469, 0.04597754818537543, 0.025000503744869947, 0.04345667841393621, 0.01552668987818423, 0.02613253846404053, 0.03257472120646027, 0.04439844562101268, 0.013526005298650313, 0.10246939266160612, 0.08082814424509004, 0.05204572680316145, 0.03313370492129076, 0.07391328142294962, 0.07017905478395763, 0.030853285251425642, 0.07302342433362238, 0.039899364459298314, 0.0504072409333481, 0.005867098253445641, 0.07331074560962378, 0.07096093944123677, 0.04826213728876845, 5.615651982445871, 41.85772626630722, 49.80147507882888, 32.23336342842349, 40.85665110618838, 43.62748399857552, 44.251423266626176, 32.80326028023997, 0.09447007875649199, 0.10648958460097352, 1.873709489741633, 0.22634000307129276, 2.3162069003428183, 1.194212299681479, 1.7421253698487438, 22.545205200872115, 46.83572784546883, 52.83423992895311, 54.49615993807393, 55.52842186343286, 53.30068034510459, 53.36831769635601, 53.1594907083819, 53.65778469270276, 54.64038941168017, 51.03692754622429, 51.301809126330966, 52.48867911677207, 51.48275590712025, 51.561658305506555, 50.92879564531388, 53.986243970932506, 53.967777452161236, 55.32172864483249, 52.18591920791134, 51.35265873324487, 51.85069776350453, 54.37048327538275, 51.3860067244499, 49.39570196213261, 47.02311515808106, 41.443355314193234, 40.313920590185354, 40.65758297520299, 41.82923024700534, 39.076522627184474, 39.74173699655841, 39.663281748371745, 46.95303417021229, 41.870583795732074, 38.56704204313217, 40.03226303285168, 39.56639136037519, 38.867523054922785, 39.322263040850245, 45.133760436888664, 48.807726906191924, 52.248414331866854, 50.817922007653024, 49.98841524124146, 50.16925611803609, 53.739562188425374, 55.20314754978303, 54.799606261714814, 54.368165154610914, 52.00349761593727, 53.705151234903646, 54.488640754453606, 48.481060151130926, 48.685066546163256, 55.396896946814756, 51.682761484576815, 50.7308179332364, 47.68537206034507, 48.99640467859084, 46.85093879699708, 48.12182203415902, 44.97180185010357, 42.25195976995653, 38.33347666648127, 38.69478971727433, 37.60638690763904, 38.78090535440753, 37.102126998286096, 38.3180852859251, 38.31851674664406, 40.508085758455344, 37.807875141020745, 39.05868368764078, 38.29287229045745, 39.10483821745842, 37.48430705839588, 39.297807062825854, 38.245996044528106, 38.765674791028424, 38.549203103588475, 40.51562063155636, 37.03730983118857, 39.75835215660834, 45.07963565088088, 47.78925603435886, 50.57484488333426, 48.87771767954673, 52.25601980763098, 51.340103226323286, 47.427633116322184, 48.31877600762152, 49.92554356974941, 49.30794285189722, 51.91164355124197, 50.50281055511967, 48.61574257573774, 46.56876740917083, 44.280127171547186, 41.87448263168335, 42.077567269725186, 41.47076483695738, 47.921596803972804, 47.023644678054325, 51.607224479798354, 52.495582488275346, 46.068555385835715, 17.639712556715935, 1.1387564818705282, 0.8706608258428112, 0.9143609325251273, 0.7440676155590242, 0.04359884135004494, 0.125673575356843, 0.1582772891607977, 0.09193886296763536, 0.13382820592772576, 0.19189878907655517, 20.536424113858132, 38.95106169485277, 39.12135531825405, 55.89188437308035, 40.34970437326739, 14.893718073444983, 0.3010619822288713, 0.13447824685323623, 0.02551377499325862, 0.025337323876878908, 0.08578223566855155, 0.05275215563033858, 0.06124580692079279, 0.10684711017435598, 0.12178622306354585, 0.019496771048814542, 0.07555536790600709, 0.07121803088774604, 0.019216348394571293, 0.05667910700844181, 0.05516696435910079, 0.05334272515028716, 0.08329161487880253, 0.20255828967257855, 0.08400189329779918, 0.08987908236562245, 0.14157223635383193, 0.149461654946208, 0.1603968859079384, 0.24282926423174722, 0.13202521799793168, 0.24708996947494247, 0.12072988740739324, 0.1426207655740361, 0.16400483827437126, 0.10438544750814477, 0.17167164703770993, 0.17931700533916875, 0.2063978917055553, 0.14144675115183478, 0.2117137145251036, 0.13805315018661563, 0.11529000430938699, 5.747452445568578, 44.82360293788295, 55.299841819270966, 39.92542159172797, 45.092826581770375, 44.657157159620716, 48.16245778914421, 36.62749667321482, 0.5269989924084756, 1.2352831926076644, 5.687206800906889, 4.67649829964484, 9.248624290189436, 0.9003311660020583, 1.9043791149893117, 22.624025229484808, 46.56843008533601, 55.07105781186012, 54.256554111357666, 55.96999053032168, 52.949894935854026, 55.541377452112016, 55.793609388412975, 57.21518224285495, 56.7532721642525, 51.88796812488187, 50.76774704840876, 53.42219537304294, 51.66222787672474, 53.44774569234541, 52.3586093994879, 56.67321266666536, 55.40141159488309, 58.48944264073526, 54.88827143946002, 51.741879447813965, 54.40773010253907, 57.38324403762818, 55.156236002522135, 50.45371032530262, 50.69623047305692, 43.92551745137861, 43.435503590491514, 42.98766305369716, 43.58487136902348, 40.816799825237645, 41.34786913471837, 43.35314166161322, 48.86403253001552, 44.43326434781475, 41.10420365487376, 42.791642604335664, 40.771335632570334, 41.308978834459865, 41.65754810456307, 45.62551583013227, 51.74605677204748, 53.36844321220152, 53.55139040177869, 52.41773520746539, 52.930926353700706, 56.76965590446227, 56.67222030701176, 56.31439816567206, 56.75683367636896, 54.580565421812004, 55.60604949151316, 55.93552858598771, 51.003297144366854, 51.36992500674341, 57.9052605167512, 54.26495975063693, 52.189010035607126, 50.02162202712029, 52.711301080642215, 49.9221860208819, 49.31968642819313, 46.52957900877922, 43.64886483838482, 40.29401456156085, 39.93083446256576, 40.49991546138641, 41.13973640626477, 39.446582563461796, 41.55069881869901, 41.98966695416359, 42.966658761424405, 38.86439692589545, 40.448987407069055, 40.75430077891196, 41.77006521532613, 38.316457502303585, 42.69336761966829, 39.84416969360844, 40.17506476371519, 40.2513744754176, 42.32496684597385, 39.21750437828803, 40.43776158363589, 46.26299512001776, 50.7919833737035, 54.397669223047075, 50.84729271550333, 55.82241135258829, 51.942214504365005, 47.96437025070191, 49.794583474436116, 51.37797763270717, 50.493145835015085, 55.032791168459006, 52.50782420558315, 50.39155252518193, 48.16820013907648, 45.95612064484627, 44.64974387999504, 42.594814146718676, 43.239977359771736, 50.94401444158247, 48.528928756713874, 54.56020832061768, 53.98232552313036, 46.006515256820194, 20.385508960293187, 1.4872089388870424, 1.4646424401190974, 0.8870807254026014, 1.4709324509866777, 0.3331768170239464, 0.48600378896920915, 0.19477086802644117, 0.11541846959340958, 0.23620628090875767, 1.5854317070015016, 27.92518500358828, 39.89015556150868, 41.615908222813765, 61.912208757092884, 49.4149725667892, 17.291498261113322, 0.38080719990595696, 0.33508005521951184, 0.23798870703866407, 0.1233337359923509, 0.21345959826102182, 0.21361842360948363, 0.16376707522619158, 0.2609699351652976, 0.2773502126576439, 0.09641653963274534, 0.12982682144689944, 0.11903760684353691, 0.12136738747358324, 0.10420544748945583, 0.14598608257309084, 0.2576277080562807], [0.05015804402289852, 0.039641966577619314, 0.10879861190915109, 0.020113257323241523, 0.057808833887740496, 0.03856824072558553, 0.03673508425333327, 0.035254404835042455, 0.04640887866938307, 0.05407936465475829, 0.11631500696943653, 0.05491563772422172, 0.038867106946605834, 0.076064387366416, 0.035853236613254395, 0.02701331549624522, 0.04352637709328725, 0.011940046247365254, 0.01641552902818207, 0.011801518398457238, 0.026062016240170887, 0.09749349837581958, 15.604208361717964, 47.28640425589777, 38.548132296531435, 36.26649741203555, 31.781294576583374, 33.71322270362608, 29.390982581723122, 1.046200190340319, 0.13817819105761667, 1.6615823175637954, 0.3071647305642405, 0.9017573152818988, 5.200435269263483, 0.46422746392988395, 3.8951883921700143, 28.309573358105077, 51.54577662867885, 54.71489483310331, 55.78176383049258, 56.872410235866425, 52.76124069767614, 53.30726992699408, 50.34316224436606, 49.41310551858718, 52.499877483614036, 50.45920948828421, 47.430041451607984, 47.651674978194706, 48.20105783400997, 49.344103182515795, 50.68507525228685, 49.36496626946234, 50.130840424568426, 48.83007657143378, 51.79464709374213, 52.609197862686656, 49.98574410715411, 50.28587210562922, 51.2289354108995, 47.97549801488077, 45.47325726478331, 40.64626301488569, 38.3559008567564, 38.091160481975926, 38.20921205705212, 38.964382063957956, 37.753766044493645, 38.24325823014782, 38.68825112619708, 39.4368197841029, 38.275166711499615, 37.001953586455315, 38.181037672104374, 38.4160033349068, 39.62928656608828, 47.34375715255738, 48.73829310940158, 50.51522485671505, 47.036572810142275, 49.75505775020969, 48.72203880740751, 47.430767090089866, 52.56388664245606, 51.565968990325935, 52.760169890619096, 50.2099036401318, 50.005328501424486, 45.15773004101169, 45.5043577378796, 52.243425077007664, 47.36303560195431, 47.1600176442054, 43.12278478376327, 40.76406748064103, 38.16746234893799, 38.63781336815127, 38.43704685088127, 36.52710753102457, 36.46654221319383, 36.8827998253607, 37.51335613189205, 39.41176760581232, 36.919046448123076, 37.164865309192294, 37.299018213825846, 37.48901390260266, 37.98498976615168, 38.522119137548636, 37.47612107184626, 36.822834630166334, 35.74232755168792, 36.883592144135505, 35.90314472875288, 37.176149968178045, 36.57572530931042, 36.796339019652336, 37.98842576242263, 36.588496546591486, 37.702704629590436, 41.20098421650548, 44.41963803383612, 45.318457003562685, 47.97799264231036, 48.13794689793741, 50.09178538476267, 47.75273484568442, 46.44161593529486, 48.75584963829287, 48.54848961676321, 48.16907874999508, 49.44362548089797, 47.30747522846345, 43.909125866428504, 40.00664995562646, 39.65860236075617, 40.9789780647524, 45.176777070568455, 46.1890309856784, 49.59205189058858, 49.55534635051605, 30.700534505228845, 3.5933879931126875, 0.31879783698147346, 0.3382471852725552, 1.9575147282692695, 1.7820011656130514, 0.10827102247745761, 0.08302707705766925, 0.030132120723024975, 0.08821810415435223, 0.6090210846835568, 3.0089553277338705, 25.608590033746538, 26.438443929918353, 29.174495204802486, 50.57511552687615, 29.243326917771373, 1.816347154878801, 0.13187391563288628, 0.046160317611910646, 0.12910516662222724, 0.007542532065042085, 0.023186949547380212, 0.01730558530036961, 0.06527962373389352, 0.013313774045767083, 0.06127597929369058, 0.051674649134398475, 0.04173313763232962, 0.07617393027870886, 0.0814683945669282, 0.022518637424875653, 0.030578213721333496, 0.05479407489239689, 0.10911892859205123, 0.04634319429075526, 0.035899588763112986, 0.054921096100682215, 0.021761026263477343, 0.01430870775478862, 0.07023289544327606, 0.03124414139517373, 0.010573111733631983, 0.040254193403187304, 0.06379768793140689, 0.04153250303540019, 0.009356397485751058, 0.015783641513647334, 0.08742664339801959, 0.03592237604842071, 0.07707275825762942, 0.06938197094226076, 0.05180131794223863, 0.012823987222697227, 0.010589562514196, 0.3394035796724981, 21.38363645922753, 54.26288481681578, 39.866044752059445, 39.894368187073745, 37.1902116652458, 37.70686234197309, 32.91347888208205, 0.8230114439802786, 0.029542167903855446, 0.221709308004187, 0.09194060964810272, 0.5432509654952634, 4.971079086103748, 0.3241974085329041, 5.674675808798883, 32.189360318645356, 54.08713125413465, 55.33109918717415, 56.653067373460345, 56.02251106692899, 55.436297155195675, 53.12801368774907, 53.43903803056287, 52.59270429611207, 54.60681784537531, 52.1549677848816, 48.26100341735348, 49.26621667800411, 47.53720060471566, 49.737662038495465, 51.210888585736676, 50.64764015136227, 52.2821702495698, 49.700073965134166, 52.21405044678719, 52.96664345648981, 51.57031497647686, 52.75964429301601, 52.36420269935362, 51.04687075461111, 47.037584781646736, 41.419405321921076, 41.33661977706417, 39.49905995399722, 39.98104472314158, 39.74102312518705, 39.48400981964604, 40.76176504934988, 40.342106742243615, 40.02113526867282, 39.35222994896674, 39.37521111580634, 38.55363145951302, 39.36027865256033, 40.78347929062382, 47.73428793876402, 50.407963721982895, 53.055081136765025, 48.64296774710379, 52.53306858001217, 50.98802735728603, 48.73903835973432, 54.686179161071784, 53.24319408785913, 52.99576313264909, 51.362982411538404, 51.91871166229249, 45.04950792558732, 48.655935102893466, 54.25369078113187, 51.115151374570786, 48.66998111048053, 46.74404244269095, 44.573775414497625, 41.536805783548665, 41.5934173522457, 39.95017959225563, 38.417827237036924, 38.06020513657601, 37.51275993162586, 38.25807302228866, 39.84000413648544, 38.379231114541334, 38.35284925276233, 39.069521196426884, 39.745545617995724, 38.33917587034164, 40.13920645559988, 38.70654506068076, 38.81996431658345, 38.44330695367629, 39.614271733068655, 38.16121793562366, 38.626309056435865, 37.7620618574081, 38.755915934039706, 38.63344384777931, 38.377854362610854, 38.626716982933786, 43.29224294231784, 45.76463837777415, 48.13304785759219, 50.30638610163043, 50.17770490338726, 50.87927179951822, 49.29792511847712, 47.35648524376654, 49.44926192683559, 49.72897006619362, 50.33311313198459, 50.095272371845866, 50.24812321509085, 45.40702412205358, 42.66149836201822, 39.851849694405836, 43.35489888345042, 46.22295948766893, 49.912129063760084, 51.33628283777545, 51.883775111167665, 31.586739132481238, 6.831295499878546, 0.40239718171858024, 3.307352335222306, 2.6272157988240643, 1.4885463445417344, 0.03381876372582009, 0.08695436551445916, 0.06595175863514025, 0.053265453691804604, 0.7066256504866385, 4.750456060132673, 30.791268733239946, 31.94615963966616, 31.79525233084156, 57.211820771617276, 36.191572297003965, 4.076161158661689, 0.198132875525663, 0.012667156575668245, 0.02595743949284717, 0.08701272609253084, 0.08476010583821805, 0.07876666292788521, 0.027353169336434335, 0.026669989362539306, 0.04709587950680045, 0.014541784260091523, 0.02229998443996714, 0.01995652339481298, 0.019973796762285695, 0.02414242398264187, 0.027708844807479652, 0.08176745230992956, 0.21101508830343524, 0.13057985523295018, 0.18849386533181514, 0.1218158323618193, 0.11112157435667132, 0.15589383641077628, 0.1652230253262866, 0.13036855286167515, 0.11099931438483539, 0.12449450475434143, 0.18953013714523087, 0.23586354849319305, 0.15872037909444303, 0.12107062799435471, 0.1451648056747452, 0.17238723444602183, 0.21125793817543218, 0.15345044494155916, 0.15056552635806222, 0.10303923950320291, 0.08491708491478236, 0.35433349950659665, 22.773218462544104, 61.14169836044312, 49.49032522016957, 45.882023149921054, 41.152801821308756, 44.837343000596576, 35.95607711422828, 1.7973530773193607, 0.3430046832128879, 5.103994482947934, 0.7205253046366477, 3.513191948013921, 10.99089797466032, 1.2221112606986877, 6.274604778135977, 34.30824233639625, 53.33470690634943, 56.16943913121378, 57.19728839012885, 59.949297828059045, 58.251629337187744, 55.56644139751312, 55.12028355752268, 53.5842873204139, 55.84159958747126, 53.48196444972869, 49.70469059482698, 50.670872349892896, 48.905405690593106, 50.473530061783336, 52.328132583249, 51.37904451739404, 52.74623370939686, 50.895349594854544, 55.43513221125449, 54.664464919797844, 53.34634850102087, 54.072285083032426, 55.37801073443506, 52.631520071337306, 49.322851780922186, 45.25818586349488, 42.75767880101358, 42.71953375108781, 41.25109641782699, 42.793388059062345, 41.625361134929044, 41.4700823445474, 42.09996400340911, 43.581713861034764, 41.277211558434274, 40.26238064612112, 39.91823973194246, 40.81927484081638, 42.43659357870779, 51.35309019396382, 51.79734176205051, 55.74238323396253, 52.62432644444128, 53.338943066135535, 51.48251272016957, 50.03284785055345, 56.289412667674405, 54.38165418563351, 54.86990297994306, 53.35640545814268, 52.079026775975386, 48.11722109394689, 51.308516379325624, 55.07852600466821, 52.22757870151151, 51.750132114656516, 48.2716840313327, 44.760346874114006, 42.85122732962332, 42.810964199804495, 43.47046759820754, 40.87547456064532, 40.39733371426983, 39.768205150481194, 40.82101245080271, 42.625228205034816, 40.45729498709402, 40.73171969382994, 41.5816580864691, 41.045834864339525, 39.96728112620693, 42.76453118170462, 40.953898429870605, 39.92549219439107, 39.56992541590045, 41.07763351932649, 39.46357819341844, 40.239630899121686, 38.02118932047198, 39.79079408030356, 41.72109050135459, 40.05703672286003, 40.96716780816355, 45.60043227288031, 47.562040975016934, 49.10944346458682, 51.96711763258904, 51.85924853048017, 53.743053097878736, 50.01317716413929, 48.267071324010054, 49.01732660108998, 50.09027527224634, 51.110852456861934, 53.98642047759026, 51.639152573001006, 46.7221438500189, 45.28884703113187, 43.51930895159322, 44.913990036133804, 49.252378556036184, 51.16213352449479, 53.31245922273206, 53.305493093306026, 34.610413889731134, 8.313015449431635, 0.7752486811049524, 3.3044556648500505, 4.197599945529815, 3.1783323422555005, 0.27585438002021084, 0.4504672377820938, 0.19810258440913694, 0.3230356821610082, 1.528546920707149, 8.285678490515679, 34.83788782550443, 36.51144158455634, 38.546708476158884, 58.34305978590443, 42.80527284068447, 4.632207385955319, 0.34524932083102966, 0.15056744157787294, 0.2193556867179371, 0.23999369703233245, 0.1807057848500629, 0.11701755556127719, 0.2055280141892933, 0.09924214768914447, 0.193785127372511, 0.14079327815242354, 0.08555270806555787, 0.1624965184037724, 0.2060020387533211, 0.12342935908705958, 0.0970562000668818, 0.1257052147881158], [0.07780277876243477, 0.0487835826953092, 0.059247255896128, 0.04039352564441581, 0.09122073214741484, 0.014347432541751094, 0.04986618367594577, 0.018133427572226333, 0.044704505407641974, 0.04150594276706538, 0.04365705254097139, 0.011901526388922527, 0.03801533208799459, 0.03780381904254037, 0.09172830370164688, 0.0549835360969507, 0.02611967967823148, 0.0865354533157041, 0.020379411589895046, 0.009804780129343271, 0.090599580397529, 0.05750736296777764, 4.684552396497419, 41.20788366563859, 36.215086906187, 30.4897149532072, 42.580458271888, 32.89933677642576, 29.783921703215572, 2.9237903750711873, 0.060285010089677196, 0.0658879128675307, 0.35998352052223304, 0.18145809851346478, 4.527501675390429, 3.5606332603962194, 0.5413377068696484, 8.839827026090315, 39.1225084950847, 53.44358405759258, 57.42873960925687, 54.9862208674031, 55.5000788165677, 53.82272035844865, 54.166488647460945, 53.682778035440755, 52.2670534349257, 50.88186056383195, 51.247613737660075, 50.82077749313847, 51.0663257106658, 50.9790765085528, 52.13705432030463, 50.851866199124245, 50.646396760017645, 49.07618961026592, 52.85975102455386, 49.16463905765165, 49.07778209255588, 50.584799858831595, 51.87884076949089, 50.211033282741425, 46.09139926971928, 41.252516315829375, 37.76172453357328, 37.25244791276994, 37.99851017613565, 38.21130268035397, 38.76177203270697, 36.46238842318135, 38.005778328064956, 37.882039316238895, 39.1519654950788, 37.89854072755383, 39.90320920944214, 40.54533650798183, 38.60719926895634, 42.04712183244767, 48.76116444987636, 47.48572341857418, 51.306162957222234, 40.48151562290807, 46.33347226727394, 50.001535569467855, 46.64543013418875, 48.64215189410795, 48.18633717875327, 47.45665081085698, 46.05288551699731, 43.886340818097516, 46.81617483015984, 53.43056571099066, 49.39032047025619, 46.08218169981434, 42.329210850500296, 39.97444337414157, 38.03993040515531, 37.29949282061669, 36.75020802405573, 36.41737530308385, 36.78638012178483, 36.92100371083906, 37.58699078713694, 37.39717552738805, 37.96562502461095, 37.29382891808787, 36.25018427448888, 38.00595875709288, 37.4990394807631, 36.99709376981182, 38.78336860287575, 41.302255891984515, 36.29096907954062, 36.59122259386125, 35.789388149015366, 36.89886585358651, 36.691011613415135, 36.69025459597188, 36.41220561919674, 36.56045944459977, 34.51955610705961, 35.818092053936375, 38.41858033211001, 41.92730519079393, 44.23968753507061, 47.355928267202074, 47.89760366562874, 48.896192043058335, 48.4412088701802, 47.507555330953295, 45.696875510677216, 49.1682162592488, 48.96926187699842, 47.034576323724565, 45.09842772637644, 44.155152613116854, 41.83441562037314, 43.60596979818037, 45.969080155895604, 47.42828815214096, 49.36578996719853, 45.17068955206102, 18.229080054067797, 0.4673304571019065, 0.46979952783834555, 2.2515103461280948, 2.0840535769539494, 0.4104162836747785, 0.016215143409828027, 0.11039914578319558, 0.0398654459164508, 0.15632492940752737, 0.5973940763262011, 4.548909481494658, 35.183001487485825, 38.511618952597345, 32.41351789043796, 39.80736217191143, 12.756545062988037, 0.18098264902589783, 0.18363705175297876, 0.03455418898093124, 0.022549064522008264, 0.04947799543339399, 0.022589525455729138, 0.01007697212645003, 0.0627721758228877, 0.028828089688754374, 0.08172851972161763, 0.023368744127031778, 0.035515433973482544, 0.04026115714241901, 0.07548184644791388, 0.027028644915610075, 0.01772555853089979, 0.11238997847202326, 0.01827397214759502, 0.021863563301702662, 0.037056818198893345, 0.02322409715082857, 0.021794839469235272, 0.027680407623730363, 0.06890272165858938, 0.018874399303909273, 0.08462875240272091, 0.03566004456050935, 0.06364673030592742, 0.04955159733071924, 0.02840602120775129, 0.04254036830858358, 0.047114388191051064, 0.016420426245238033, 0.050198033812545964, 0.0555201155704356, 0.1497674312803053, 0.014308577519841494, 0.040597703397995046, 0.011890149025637056, 8.084618776075303, 48.70119140994165, 42.88716800751225, 31.577656884347242, 41.501614278362645, 37.46046297011837, 33.77587472238849, 2.9410247793120723, 0.10320786311621628, 0.1083091966387245, 0.2264018570102992, 0.05392448082866688, 3.9785122823330665, 3.491975602603728, 1.9051619955608923, 12.256615450305324, 42.28244443093577, 57.098989871240434, 59.10701197962607, 57.66010453624111, 54.8453724768854, 55.61496896128501, 56.13506740139377, 54.042671188231445, 53.588303827470355, 51.48486221990278, 50.89396499818372, 53.70351952891196, 52.94669035942324, 53.6277981727354, 53.0161359233241, 52.59223753406156, 51.958441349767874, 50.464779253928896, 53.93191522167575, 51.45019238994968, 49.58008473919284, 51.33957370635002, 55.184602583608324, 51.09937952410791, 47.494129057853456, 42.70480525109076, 39.498640260388775, 37.92611891223539, 39.34482843645158, 40.31316749511227, 39.92278575897217, 38.918921793660815, 41.01351453411964, 39.88831596989786, 40.950383986196215, 39.43372503403695, 40.67354702180432, 41.529761206719186, 41.06401505008821, 43.259895155506754, 50.508156745664536, 50.232904418822265, 53.711874177378995, 43.0779520926937, 49.15618634993031, 50.12517259966943, 47.81636353461973, 50.9521572820602, 48.937710331332305, 48.6673217435037, 44.794632311790224, 45.03585415501749, 47.42396570021107, 53.648457296432994, 51.12835015020063, 47.88516190744216, 42.92050423160676, 41.80489586245629, 40.32453844624181, 40.56571714339718, 38.6947936396445, 37.698546917207786, 39.65480550642937, 38.282152452776515, 37.73515832039618, 39.77696772544615, 40.21046807689052, 37.72678013770811, 37.64151173253214, 38.81684603229646, 39.27137813260479, 37.59868337262062, 39.66880052320419, 43.23541172089116, 37.90975086150631, 39.33644633139334, 36.79258923376761, 38.268588896720644, 38.88927651989845, 38.32054461202314, 38.38158845901489, 36.651026971878544, 36.00606772207445, 37.91618747095908, 41.12997754927605, 44.3813870799157, 47.1549028735007, 49.065042234236195, 50.4996608918713, 50.6731669364437, 49.35410130408503, 48.245227644520426, 46.93768985809819, 50.28003169644264, 50.60236423246322, 48.66385829064154, 47.76700442837131, 44.8812186333441, 43.83869186524422, 45.27908425177298, 48.26488656382407, 48.271844848509765, 50.32893580775107, 46.077329727911184, 21.25410999021223, 1.2832161495762489, 1.8269107106231877, 7.359671121643436, 5.642388818725463, 1.3646602438342188, 0.036318140900543625, 0.01892428694953842, 0.05909938177454376, 0.1697912842275635, 1.2550281589069676, 5.7299130770467945, 37.56144831257482, 34.55923872609293, 32.80620205786921, 46.83182900951755, 19.98672550724399, 0.42417926773909603, 0.06683631439603145, 0.04613664166461076, 0.01933706852967941, 0.07162702990876091, 0.029195616539988308, 0.007698922211514607, 0.01612868272669373, 0.03757788822235119, 0.061532768135469776, 0.07487194852963572, 0.04066248762331182, 0.015415117790501927, 0.052070456121357224, 0.04636651783760998, 0.1387774709972643, 0.009247479892726387, 0.21070010359248809, 0.11114271838338145, 0.09082119431226485, 0.06063568300657696, 0.21657590604116841, 0.07783875425135897, 0.19348405481826877, 0.13254644889985362, 0.17550179554570108, 0.17036418009909893, 0.12339349851132402, 0.11484202673478473, 0.20754297864773583, 0.10131307487045565, 0.16730385802445874, 0.1329060352497524, 0.12641215306376258, 0.16688975685786817, 0.23100508016444024, 0.18022170921246852, 0.22257028357876887, 0.12482248997736363, 8.543348793060549, 53.85638213926747, 48.527897173358554, 41.174053222902366, 51.26422497533983, 42.26353860670521, 37.741049720395, 4.580705685000266, 0.2677434088001328, 0.9899116043121585, 0.736560628058449, 1.2758207657644827, 8.190224180298468, 8.225192600680936, 2.640280233275506, 12.46394899583632, 44.35908840548608, 55.721280882435465, 59.888414798244355, 58.35390513943088, 57.90092237534062, 57.396427123777336, 58.55790368972286, 56.64036673884238, 56.31974043384675, 52.53256651663011, 52.68462504110029, 54.85753966915993, 54.92428664238223, 54.09493677077755, 55.137608666573804, 54.33169103437855, 53.55195130071333, 51.7321402026761, 54.97081771973641, 51.629064236917806, 51.70891977125599, 52.37727203676778, 57.47607085012621, 53.73815797990369, 50.528051007178526, 44.61580361089399, 41.14909125912575, 40.66715748079362, 41.26206336482879, 42.38028403251402, 41.7360935672637, 39.98943859531034, 42.57837157095633, 42.55608466363723, 43.2942472734759, 41.74082394569151, 41.87902081397272, 43.49335070579283, 41.673084612815614, 45.08373845008112, 51.97921814457063, 52.19186552109257, 54.63956963631415, 44.35950809909452, 50.568667150312855, 50.751100509397446, 48.247298655971406, 51.75977722291024, 48.931936602438654, 50.74415791419245, 45.27551881728634, 46.616079038189305, 52.526498609973544, 55.856618342861054, 54.319382636777824, 49.50596763241676, 45.390322669859856, 44.62899846415366, 43.212830635809134, 42.19571690405569, 42.16265524587324, 40.16363889940324, 41.14556112597066, 39.844769816244806, 40.51968028468471, 41.56915357035976, 41.345135242708274, 39.24552186842888, 40.64952642686906, 41.90982710930609, 41.86647315179148, 39.54719528075188, 42.44731341638873, 45.18639472223098, 40.01142740249634, 42.06716122165803, 39.30990365243728, 41.320086986787864, 41.391682009543146, 40.55029438387963, 40.69623008851082, 39.00539044410952, 37.98398956175774, 40.093761874783425, 42.282130641321984, 46.90582060044812, 48.50450415765086, 51.25918865203858, 52.454185793476725, 52.32055456407609, 51.039579068460775, 50.177410725624334, 47.475752753596154, 51.51980269339777, 52.21070074266004, 52.34833278963643, 49.217202740330855, 47.989716606755415, 46.93305361655451, 46.445248050074426, 50.09442906225882, 51.8552634023851, 54.52377342408704, 47.407201490094586, 22.851416795484482, 1.6111564492025685, 1.475660500507201, 9.951176681826192, 5.201629630980953, 1.3618308666252321, 0.24483489773927197, 0.370777576801277, 0.1727301200791713, 0.7146886952461735, 2.8411918782418777, 9.333383767835556, 47.49711790392476, 48.23653959458875, 41.38411967985092, 51.40481841179633, 22.736354066479592, 0.5402953982833893, 0.4008260886034658, 0.1874175117982011, 0.11702385280401477, 0.17746036061115805, 0.06360878980147743, 0.1682775864197362, 0.1635428106472377, 0.08342656126666455, 0.13901989186002364, 0.12519536795274866, 0.1247620456401379, 0.15442752880194496, 0.20123269709367908, 0.13678864545879826, 0.30583256495095074, 0.25778261103457023], [0.17233304138625824, 0.03082411262326904, 0.07176846506134157, 0.0601303790726008, 0.06143389682796213, 0.025214948991854346, 0.0820317832873233, 0.004627951035921973, 0.04495549879427399, 0.0892720342944226, 0.09654782412032928, 0.018000415556373137, 0.06679509120482592, 0.019054485507489696, 0.07397367979489988, 0.04802633925611454, 0.0231992069541687, 0.029909340439424403, 0.016947914170281544, 0.03620147720099457, 0.02733788013668551, 0.03428983502089977, 0.7576165853008148, 24.731553946771932, 43.18808440239199, 32.100959900886785, 33.21736058881206, 34.236917957182854, 32.053201121668664, 9.941697293712247, 0.2770932361243233, 0.18528081596859042, 0.04953357894274016, 0.050721256543071046, 0.16255304037082582, 4.055987428272925, 3.7821314652119917, 1.3112298399209976, 14.603914733855957, 46.29466825915922, 54.18666924199751, 56.97966744822841, 53.86132040331441, 52.676184100489465, 51.56776543586485, 55.585912043048495, 54.05452066852201, 53.41040865067513, 52.914279814689394, 53.699785432507916, 49.834466134348226, 51.44327332896572, 50.501202383349025, 51.8604487757529, 52.71790242964222, 52.49049909653203, 51.566933893388324, 50.68525568131478, 47.88304382754911, 47.99177192872571, 51.136312561650435, 53.50475342042985, 48.166662569968935, 43.4599752579966, 37.90311421117475, 37.854939660718365, 38.59445548826648, 37.694181319205995, 38.472348182432114, 39.43661189848377, 37.59591810164913, 38.0089319136835, 38.35300614756923, 37.081981705081084, 38.7278631425673, 38.65049831328854, 39.986543886123165, 38.80505930992865, 45.704579045695645, 48.53917398760396, 53.062270841290875, 41.48785852616833, 32.83598853695777, 45.09516823676325, 46.58013051556003, 47.40343601472917, 46.58368810530632, 44.64598232699979, 46.41087239788425, 42.608240419818515, 42.358342293770086, 53.60669189883817, 48.2893660760695, 49.45818924134778, 44.41112256819203, 44.09967853176979, 38.85619132749496, 40.96194321109403, 40.128596444283765, 42.367987402023815, 38.31383343665831, 37.48146334002095, 36.289345218289284, 38.38449101294241, 37.91723474379509, 37.208635037945164, 36.583311173223684, 36.767050681575654, 37.78422324888168, 37.9634363420548, 36.32048099271713, 38.23754333680676, 36.6661084851911, 36.26474411256852, 37.762748272188254, 38.28368217714372, 36.76161427651682, 36.46645984342022, 36.29412658752934, 35.4114991618741, 35.23583189133675, 35.052249277791674, 35.511503911787464, 35.94739298666678, 38.77221730447585, 43.19964754965998, 44.19399192256313, 49.136009677763916, 48.49273312476374, 50.41155661306074, 47.57372571576027, 49.223086295589326, 46.49370893355339, 44.87075374972436, 47.06339789975075, 45.437226372380415, 41.555346827353205, 44.6632093767966, 47.07409028084048, 49.922676317153446, 47.69786873171407, 36.75571110940749, 8.060449621369763, 0.3302597687129052, 2.0090430277970532, 5.031979276287941, 4.353016018867493, 0.44369128202238395, 0.03844746313388309, 0.07039230301856034, 0.15056402482573064, 0.24750615440068707, 0.0973495887592435, 16.14182508760883, 43.46615691338816, 31.631207043124785, 41.66016824783818, 32.886269400196696, 2.688825938009447, 0.04830215772193286, 0.05694608481961393, 0.05794527031661523, 0.05026392886535295, 0.11911135046712815, 0.006353945214106071, 0.03638666363493089, 0.051583319962505376, 0.04501807668636884, 0.1116120468284334, 0.06966595207491229, 0.045181245753361333, 0.031915757271851745, 0.0636015541010326, 0.0840151236362515, 0.03317305502752143, 0.028607316555515416, 0.05715045409517423, 0.03287551413861013, 0.07364848313192207, 0.042533825917710225, 0.024530476244587093, 0.11348518542945386, 0.07247118985340481, 0.02830283874044976, 0.015607246896252038, 0.05479993929545726, 0.062320789157022397, 0.08105904314546816, 0.012850992779638018, 0.07880700511797782, 0.044777207151656194, 0.02772590558555338, 0.050806020341453054, 0.04845052597022826, 0.01486521413279397, 0.043472773921225345, 0.04819792379895526, 0.061712339144921115, 1.3991609215736391, 31.28651111356674, 47.42389901991814, 34.04915801940426, 41.266119095586966, 38.953721061829604, 35.76978022052396, 10.164772291337291, 0.3844537477820151, 0.24085890141225633, 0.08363146680377184, 0.13187596874852336, 0.16526068620864423, 4.5113773019083085, 5.780301315169181, 2.606197778255709, 19.44689754516848, 48.241022863695704, 56.166752307645744, 58.11881396078295, 57.21828876003143, 55.310114506752264, 53.60312646435153, 55.278912052031494, 55.382890162929414, 53.916947457098196, 53.35713894136491, 54.367521885902654, 51.90996477680822, 53.65000271028089, 52.3451635145372, 54.5696141642909, 54.34776882971487, 55.762787403598914, 53.880630231672725, 51.11770875992314, 48.73681045347645, 50.99820198551301, 53.198314328347486, 54.164743192734264, 51.99063224177207, 44.618682630600475, 39.96049934817899, 38.735186207679014, 39.71787721880021, 39.932309273750555, 39.271331064162716, 41.339534098102206, 40.20579653401529, 40.798137187957764, 40.893690047725556, 38.437811713064875, 40.02833674030919, 40.28679740044379, 40.50603435885522, 40.56286950265208, 47.96701392819805, 49.33981210954728, 54.64940694070632, 43.118658450342, 36.608771278012185, 45.3643605016893, 46.53188928481072, 47.72360732478481, 46.243449949449115, 44.76747774308728, 45.71981353144492, 44.323359535586455, 44.520646910513605, 53.89321319518551, 50.552244186401374, 49.35551727971723, 46.40369838283908, 43.385136435108805, 41.35093642819313, 40.89501973121397, 41.46805055679814, 42.89041573001493, 38.950783206570534, 39.28050548799577, 38.52144841224917, 39.27311966496129, 38.7596147291122, 38.01272092326995, 38.15228277637113, 38.82948783136184, 38.04832819969424, 38.56100943780715, 38.64412446175852, 41.634323750772786, 39.06602636460335, 38.38453415901431, 38.38748770375406, 39.93436459572085, 38.167893809656945, 37.88518897948727, 37.10898330134731, 37.27276186789236, 36.75405586919477, 37.088237885505926, 35.737455967933904, 39.68971460096298, 39.9974637646829, 45.47563029873756, 46.159573985684304, 49.58087313559748, 50.05404433896465, 51.39916235400785, 49.48299431031751, 49.46243324587422, 48.19913587262554, 47.180817973229196, 49.9958049866461, 46.925287323613325, 45.51054723801152, 46.484165806924146, 49.188804780283284, 51.960935977197465, 50.091499051740094, 37.54207964866392, 10.267119676836076, 0.4395117820991624, 4.932635936044878, 10.522183564401443, 7.124751546690542, 1.333791803448431, 0.06782852849292179, 0.11112512900463997, 0.24700488775007187, 0.5325963985054724, 0.5050269472262552, 19.02372871675799, 51.64114121467837, 36.85417044547297, 44.392126529447495, 40.31807830256801, 5.472411926715605, 0.135988803700574, 0.0333649447307952, 0.1277241322602476, 0.02591594434042852, 0.12613812341324745, 0.0608975280286564, 0.06937239484320726, 0.049090232369640184, 0.05276244419116167, 0.03252877508320155, 0.0555209199627561, 0.044357042399144946, 0.01624192009800144, 0.022847277653073112, 0.04042868524970066, 0.031971409729111104, 0.01050284136116745, 0.2628023868366595, 0.11792548466473819, 0.137241970327112, 0.19207037744983552, 0.16442120706121768, 0.1672413146063205, 0.1927624612806305, 0.08334295809148781, 0.15560417856660583, 0.15753438305710593, 0.17400274533898602, 0.33618527494611283, 0.24740732905845492, 0.13419407419860363, 0.16337972584991686, 0.23953523937492605, 0.1394606069211037, 0.14059841602800355, 0.24849924949869034, 0.12265245400128827, 0.1408552546654978, 0.1632021007037932, 1.480198315074367, 36.19691848754883, 55.49485814186835, 44.382728530514626, 45.95398687547254, 45.53795283840549, 39.2426428487224, 15.55500222790626, 1.0156498909477265, 0.6436936725531855, 0.32464388457517473, 0.5349313732116453, 0.44600394824820183, 7.138829913831527, 9.44819938751959, 2.693371229594754, 18.591952247004357, 48.73864220034692, 56.43024144634124, 61.53058567354756, 60.38417100906373, 56.407075928103545, 56.842600222556825, 58.21999149937784, 57.73930895713068, 56.27629626181818, 55.018494129180915, 56.69304417025659, 52.11840345013527, 56.171937681013546, 54.38228568723125, 56.949441663680545, 56.428739178565245, 55.08853197097779, 54.82877692868633, 52.182522435342115, 49.652138679258286, 50.104242832429954, 53.65023413012105, 57.461059939476755, 52.80628127436484, 47.28517263166366, 42.70809219729516, 39.851190736216886, 43.19951811144429, 41.36553941234466, 41.975966115151685, 43.77977002051569, 41.01132585156349, 41.37737712552471, 41.250806162434245, 40.280168594852576, 42.446273988293065, 42.2497828545109, 41.90679903953306, 41.819039929297666, 49.5302745603746, 52.4024183519425, 57.68692178110923, 45.144150795475134, 35.94690661276541, 47.37005272219258, 47.909472757770175, 47.77313117058047, 46.064009358806, 45.949715414354884, 46.00802536933653, 45.473363168777965, 47.63832323012814, 54.8886283751457, 52.015241192233184, 52.64542487359817, 48.49620442236624, 45.60155407074959, 44.101843680104906, 42.9687572294666, 44.91583355011479, 46.928927283133234, 42.21164957169564, 41.35761230222641, 40.67570040302892, 40.82730785492928, 40.92309997927758, 40.95675391535605, 39.71474324503253, 39.96211144231981, 41.245405058706964, 41.18329824939851, 39.64155573998728, 41.26147500930294, 40.252555108839466, 39.76013683503674, 41.73490901147166, 42.56552188627182, 40.550572872161865, 39.59649555144772, 40.32817840576172, 37.663355412021765, 38.72322690102362, 37.84106231504871, 37.53800822842506, 40.26327886889058, 42.77118744388704, 47.27658264098629, 48.23790850177888, 52.663271657882206, 51.99635105748331, 53.080811885095414, 52.12609129567301, 50.614394141781716, 48.08901533003777, 49.744949802275634, 49.80751552889424, 50.436753919047696, 47.25599019758163, 50.248950835197206, 49.87829469865369, 54.05705451965333, 50.64049359290831, 38.83405347024241, 11.606833646374366, 0.9250682676511427, 5.455950719694938, 12.553900710998043, 12.144183651093515, 1.7116297997774619, 0.377250008525387, 0.1922517104615127, 0.5642139503071385, 2.074556293026094, 2.3012388906171246, 27.692611986590972, 54.82260704040528, 42.33347838924777, 52.47131478401923, 46.00636620675364, 5.685206392119008, 0.19331453488238398, 0.16239550205007677, 0.18840901343332184, 0.11373656952092726, 0.2974680799149698, 0.14984120554741354, 0.1805962036333738, 0.14453592409770336, 0.20185056232636978, 0.13550580058607364, 0.18419009062551683, 0.13518476378052466, 0.10089109065912424, 0.18744930444705873, 0.25116975539393965, 0.21129009854649344, 0.12944601446149812], [0.020811925679745696, 0.04557443655005867, 0.10535949766035042, 0.009202493294592827, 0.023197121279794845, 0.08013929330533551, 0.026594876356783415, 0.043217750912111615, 0.028959694018046704, 0.018682444483161937, 0.07004693526053621, 0.036039533874680924, 0.026439885278382612, 0.04680937411443842, 0.022665800999910123, 0.03577252158955221, 0.09525982347587425, 0.0318356053227739, 0.05860280358202516, 0.008668542460298106, 0.01682289628191821, 0.003816000539847019, 0.01903885731383437, 8.571884036064148, 37.032006786715606, 32.826119853604226, 24.338920770152924, 35.1715991573949, 33.411380629385675, 13.576781307497333, 1.0896404399987192, 0.102006369120171, 0.03093489085233981, 0.13981872238218784, 0.08208488850223442, 1.5900021262707251, 4.998443011314639, 0.4997337699657487, 4.6811198323003715, 31.42251733810671, 54.26627766701483, 56.14965077369444, 54.65332146613829, 54.0300254667959, 52.87143968766736, 52.65347749956193, 53.021588017863614, 51.00825109789449, 49.11927684660881, 47.99882042792536, 44.99897995302754, 46.04801001087312, 46.20737591097432, 47.298147832193685, 47.68491706540508, 49.768127087623846, 51.92241830210532, 52.21392885331185, 50.512769452987186, 49.57435023400092, 51.04929870174777, 53.15507411956788, 49.38677072525025, 42.3915373125384, 37.37437086720621, 38.215848707383685, 39.03779314410302, 37.71224775621968, 38.958522042920514, 38.60310431449644, 38.100221157073975, 39.42325622804704, 37.45241818889495, 37.22804292555779, 38.827354061988096, 38.5446806107798, 38.31906980083835, 37.15374931212395, 41.48440291804653, 48.178445369966575, 48.815693240011896, 55.002290817999075, 53.16092629586497, 50.102458154001546, 53.27404352926439, 52.344845802553245, 54.77032969074865, 49.15329948548348, 46.04923771273705, 42.745609667993364, 42.34788525489069, 54.546174080141135, 48.46424102783204, 49.15629617629513, 44.79923325200235, 43.97575124617546, 44.40127741905951, 48.23893224039386, 47.32851874443793, 49.040986337969386, 47.21539366629816, 39.66178732533609, 38.50510389574113, 37.582221185007405, 35.48739310233824, 38.217099943468654, 36.35720614464053, 37.170427230096635, 35.67946372493621, 37.2879453628294, 35.653697675274266, 35.92626710091868, 35.31461269624772, 36.19325499380789, 35.941215253645375, 36.39752026527159, 35.287148260301166, 36.98671910070604, 37.97104181781892, 35.804438283366544, 33.85490263662031, 33.66715446595223, 33.937813697322724, 36.4867228077304, 34.87964537835891, 36.948554438929406, 40.570878982543945, 44.56540899892008, 45.55621539392779, 47.36584401899769, 49.414137101942494, 50.08995756026238, 46.083566296485166, 46.42034099948022, 47.843494569101644, 46.27908468246461, 45.15381551557972, 45.524424583681174, 49.54361454133065, 50.191739143863806, 45.10579001518988, 25.140008003480975, 3.406704010501985, 0.05475093648138066, 5.241899624947579, 10.6771917112412, 9.605765900304242, 0.9980570801323461, 0.029034102222912257, 0.10444024577736856, 0.32702231178841284, 0.7114502270856212, 3.1330255346913494, 27.86303504820793, 25.865501357663064, 34.987816502971036, 42.82852072869578, 18.36287602301567, 0.1694207734638645, 0.05159858043395704, 0.007277973176490877, 0.07111522954918685, 0.08782739931296918, 0.059697056759990035, 0.03542622303470008, 0.025759675810413978, 0.049946584603599006, 0.040749273893813935, 0.0539430431390722, 0.027959868837628635, 0.05587078848733537, 0.07440448167823976, 0.055827198084443815, 0.04049602820868454, 0.030132917454466227, 0.068960354453133, 0.05144581101053665, 0.05128919199529675, 0.007122749398883072, 0.07386973698533351, 0.03184343857179967, 0.036107313503781636, 0.0513260867897301, 0.007277759150677031, 0.042119284250563195, 0.016048739536575252, 0.058489437890990134, 0.0654202391723952, 0.030322633383254853, 0.05814128923380087, 0.0715377040567898, 0.07210677714958307, 0.06022243985846158, 0.041577901405793045, 0.07040653693219347, 0.032330028893005465, 0.030856158081141692, 0.03625586178273924, 0.05341874022457389, 12.926408206262897, 46.88817385704287, 38.13148636971751, 28.7044854317942, 42.80827737623646, 39.28939750117641, 17.874870415656797, 1.0742224608698199, 0.10209056984392867, 0.009508214087315626, 0.16573858717756887, 0.011750974790042928, 1.4354885657948833, 7.474270520671722, 0.7263147230109861, 4.971058003364071, 33.996680628868845, 55.208309388929806, 56.017780688501176, 56.06514723070207, 55.30419565016224, 55.12238594793505, 52.968184947967536, 55.60481786727906, 51.45266740552841, 50.83051281590616, 50.25668182680684, 48.79605393255911, 48.32422417979087, 47.27957540942777, 50.72232207944317, 50.061100682904645, 53.04643231053507, 53.574916778072236, 53.55183362960816, 52.523254809841035, 48.62815687733312, 52.340515505883005, 55.54826905650478, 51.26728442407424, 45.254914606771166, 37.87874060292398, 38.87022164560134, 41.24097278041225, 40.29169644078901, 40.78983745267315, 40.1365117872915, 40.71996827279368, 40.57275387548631, 39.3701434135437, 39.605720966093, 39.993921864417295, 39.98999164950463, 38.174526537618334, 38.28917741775513, 43.65974549324282, 51.58208208699381, 52.201796962368874, 57.1094233758988, 54.63665923764629, 51.46907075758904, 53.15408568228445, 51.31196806507727, 55.674498773390255, 49.66122288857737, 47.0185887429022, 43.495104005259854, 46.84636923574632, 56.36010554529006, 49.46709302163894, 50.1968696040492, 47.024695873260505, 46.76811795080862, 45.02656598244944, 49.441570158927675, 47.97557646228422, 50.629742376265995, 47.09621244861234, 41.64831876754761, 39.92231507455149, 39.80215718669277, 37.923969453380955, 39.04486909989388, 38.177362411252915, 38.19921001311272, 38.11232951379592, 38.720979382914884, 37.58331552628548, 37.23609947389172, 37.326635622209125, 37.54839466464135, 36.89914826423892, 37.36852653564946, 37.74906312265704, 36.56770798467821, 38.33931707566784, 38.158107496077015, 36.22237074759699, 36.0351913206039, 35.061733568868334, 36.471049016521825, 37.874371082552024, 39.14980426911385, 43.16840587123748, 47.10544570799797, 48.22270931736116, 48.48291150985226, 49.304879480792636, 51.69423441733084, 47.4678687895498, 46.7075369434972, 48.67342102912165, 47.751907225578066, 48.87979261336788, 49.051066829312234, 52.35860547711773, 51.29165803232501, 45.68765401840211, 28.573988176161244, 5.469434847754817, 1.071233614798515, 8.847086352686729, 10.22059448303715, 4.031008058978665, 1.5338574421982614, 0.1318106520920992, 0.09037483318318283, 0.858550998232057, 1.7980765094680173, 4.281840199424375, 32.17001715014058, 36.05781555175781, 35.06819371254214, 47.34857382312898, 24.501559888162923, 0.571110580236681, 0.05140423924932557, 0.09469186121057119, 0.03726593721958418, 0.09466733107523573, 0.038714701414949475, 0.06102991951329093, 0.024723474860131264, 0.030907813474656116, 0.02583834346413853, 0.044380205067535566, 0.03650150021478053, 0.055542048667707754, 0.045765793822225065, 0.060507734831903255, 0.02476823929276678, 0.0864634870160972, 0.10371923446655275, 0.0784098957815478, 0.12551862641327804, 0.1497538408805286, 0.13503131636929128, 0.159085082911676, 0.27534021244895074, 0.08290019757564991, 0.1267566091771568, 0.1280522094138207, 0.14961758448231607, 0.16838287754404932, 0.11888052817554244, 0.10525104259291004, 0.23806415137744721, 0.1199312330854516, 0.144142905670789, 0.20947600234179728, 0.18380142357801238, 0.13483047875906193, 0.14038101559685123, 0.12699795751682214, 0.0962606484010335, 0.09988494908377048, 12.187637629047519, 50.58807111555531, 45.404105878645375, 33.80040522544615, 47.41306935587237, 44.37728820308563, 22.371322608763172, 2.109590413108949, 0.21771895518947035, 0.13518246551675184, 0.5370249382911191, 0.2093252209165404, 2.4225065640864836, 12.450614898435532, 2.2340982094887765, 7.687489582646278, 35.03278647699664, 55.728607869917354, 56.30133667299825, 57.46621393388318, 58.25665389337848, 57.751962523306574, 55.49880796863187, 56.97742385248984, 52.872396745989406, 52.547318550848196, 49.961135156693004, 49.632366011219645, 50.49780953314997, 49.96168036614695, 51.60702443891957, 52.08087028995637, 54.68936020328153, 55.90762876695203, 54.7047515838377, 53.55148453866282, 51.80325669627036, 55.22068054445329, 57.67643728563863, 54.12688447583107, 46.897120783405924, 40.08413637838056, 41.82178951078846, 43.68081254343833, 42.51279346404537, 43.910922311967425, 44.12600548036637, 42.64758179264684, 43.123957572444795, 41.1878481987984, 41.54483879766157, 42.682016280389604, 41.794297618250695, 41.11195818070443, 40.88960293800601, 45.237550274018325, 52.234242808434274, 53.9183359761392, 58.25399452640165, 51.18834672435638, 51.01745690068891, 55.93805067000851, 55.003593044896284, 56.9055542638225, 52.620808078396706, 46.18519883002005, 45.51041779979583, 51.1124998523343, 57.2180651849316, 51.86494381197038, 52.55492794898249, 48.835305090873476, 48.33783872665898, 48.59886461688627, 51.728119773249475, 51.168205353521536, 52.69380338730351, 50.94814077500374, 43.861257260845555, 41.52463466890397, 41.750421985503166, 38.94025556502804, 41.24662883820073, 39.493399973838564, 40.38770037312662, 40.153699613386586, 42.19461864040744, 39.53389060112738, 39.066932432113155, 38.81301779900828, 40.17171113721786, 39.57099622295749, 38.45343843583138, 39.25484534232847, 39.93447442208567, 41.286660548179384, 40.69098195722027, 38.43192031306606, 36.39942261480516, 37.4303940803774, 39.618586340258204, 38.239935982611875, 40.001409669076246, 44.84336383881108, 47.934948552039366, 49.51773866530388, 50.10895752137708, 50.72675043536771, 51.68663678630706, 49.883189816628736, 50.9117058784731, 50.169154136411606, 49.1364372161127, 50.83742795451995, 50.30255786834225, 54.24553225117346, 53.7863286079899, 47.264238942054014, 28.135728028512773, 6.3780827868369325, 0.6273113419452022, 11.479982233816578, 18.931951138281054, 16.852065324783325, 3.7472272736410943, 0.3123540263022146, 0.23212719979065083, 2.15984970331192, 3.907614951172183, 8.086149481035049, 39.98705379424557, 35.73903276074317, 44.167311960651034, 55.6421313747283, 27.12994210181698, 0.6150863559976701, 0.12921333823713566, 0.14050884502789668, 0.154772452228973, 0.17304055422784823, 0.1392592636928443, 0.12928225550680392, 0.3194620964988586, 0.15832562930881977, 0.20558623687153865, 0.1568158385494063, 0.12100061521895471, 0.11875603888784686, 0.15950014934905116, 0.13062315452243053, 0.1507770125904391, 0.10965128309063374, 0.19699710421264174], [0.04433114096642502, 0.04571816613597255, 0.05237875288472541, 0.007774879829207016, 0.04536333719208356, 0.028332017114265796, 0.05914204521104694, 0.04099763576842604, 0.027367033612644, 0.02507688654136033, 0.03532481214572345, 0.060029718949789965, 0.039180494364230864, 0.04016733435433238, 0.007151236857152394, 0.025185941072601466, 0.007362385532037626, 0.043096502176335746, 0.023336248592503613, 0.07227712446042607, 0.0838095745852878, 0.019747239665218422, 0.01753649760728642, 0.36080096698095726, 15.04972936645631, 40.346170317742136, 31.673719652237434, 31.767313288104152, 34.18051819647513, 15.546174933833463, 2.089464241458524, 0.27552483963870233, 0.08202270514542058, 0.019135099024541916, 0.03892477038466642, 0.72436009563746, 0.6595143687821204, 0.8047595524018811, 0.2674456763892405, 12.0045139328126, 41.334011400899584, 55.68394384076519, 54.5410357752154, 55.28495642446703, 54.15227397795647, 49.451607504198634, 49.949724981861735, 48.18981239872594, 46.250243494587565, 46.257801901909616, 48.38981405381234, 46.981071272204005, 47.275186277204945, 45.950943116218816, 46.310483255693995, 48.04235089209772, 51.165353790406265, 51.24136932434575, 52.111884470908876, 48.110572676504816, 51.920359057764855, 51.31793791247953, 48.562210067625976, 40.576531117962254, 37.75523301093809, 38.618860475478634, 41.27012775790307, 38.50434687829787, 38.31012679684547, 39.30193339624713, 38.93542320497575, 39.83025704660724, 39.03445520708638, 38.06311553524387, 38.212267583416356, 36.852644643475934, 36.377076871933475, 38.16181805826003, 39.21010286577287, 44.3661408270559, 52.18048280285251, 50.41168212890626, 55.77393870199881, 54.197067445324315, 50.65866985628682, 51.593052956365774, 52.07169586612333, 52.16012177928802, 52.427713717183764, 45.72913700534452, 44.08944506799021, 53.568068319751376, 50.94994114291284, 50.78620964480985, 46.811220876632206, 47.9145836061047, 49.210554322888775, 48.83621115838328, 53.13516024620303, 50.958844923204, 49.393646640162316, 45.026856237842196, 38.633726258431714, 36.82421530446699, 34.502285911190896, 36.51835672317013, 37.26151643260833, 38.21327171018047, 35.16293464168426, 37.42970766559724, 35.11415604622134, 37.51220295506139, 36.61760445564024, 35.608625719624186, 36.01555985789145, 35.21937362609371, 36.96202778047131, 34.607075952714496, 36.457567830239576, 36.882878272764145, 38.70691768584713, 38.12367300833426, 37.41936829782302, 36.77437766905754, 34.56705208747618, 34.55232358747913, 36.82020664215088, 37.984907396378055, 43.5916688365321, 46.376877215600786, 46.57529423313756, 49.093636312792384, 48.12621901112218, 46.29635095596314, 46.54552344352969, 46.95654469151651, 47.32107800822104, 47.407487823117165, 48.87307751563288, 44.802598645610196, 32.805074376444665, 11.702908181375074, 0.7344348259991216, 0.7924219821729969, 6.0505084933773166, 8.573786385597723, 2.5119733762356544, 1.7095868577880247, 0.15802630343504492, 0.049913554722743655, 0.34813385637056443, 0.22592127473363954, 6.619758154115369, 33.635748047982496, 36.23432220951204, 38.14162961898312, 41.332120818476525, 4.0325647496408035, 0.07213217296427296, 0.061193157528196616, 0.01410715576756986, 0.004411483795622424, 0.00996873826689778, 0.04302846973822002, 0.05625367157101151, 0.0367043947710866, 0.03960622091507239, 0.05193732536187576, 0.07200153965142465, 0.03224605033474584, 0.05879565089520428, 0.12894718397048213, 0.04588800399834591, 0.008776165364730743, 0.017564704964658426, 0.02882658815642278, 0.02491376918530272, 0.017344895186984254, 0.10700077209020815, 0.02040689690939842, 0.04844610947334478, 0.0697971216493076, 0.030221482964172482, 0.0371934921150246, 0.022197895563177528, 0.019972821915402048, 0.08421604551615254, 0.04471827966852054, 0.015394470763332663, 0.0827723911272422, 0.07692197683237254, 0.06770347230016224, 0.057921349221179565, 0.030837199320235563, 0.009665108894208267, 0.026488897668558265, 0.07405701483930312, 0.02395854372861645, 0.017168476629341324, 1.244909669603071, 23.314950735338275, 43.36120213231733, 31.37089110189869, 37.99447013485817, 41.160399452332534, 17.22215271765186, 3.4278281802131287, 0.4059635355107246, 0.1514147961091611, 0.03631059493448946, 0.1299276079742178, 1.3301381156329186, 1.1683018577675666, 1.7680592234096222, 0.8360319969154174, 12.388306087063206, 44.00767149463777, 55.63995838165284, 55.527719759172015, 56.698762985967825, 55.38479251246299, 50.23028035317698, 52.72689250207717, 48.68764746573664, 50.13800267250308, 47.674177615873276, 49.498173882884366, 48.63147128012873, 47.05428231147028, 48.22323883733442, 48.5401035893348, 51.08497265846499, 51.62673042666528, 51.28048319970408, 53.67254849403135, 49.78906862197384, 52.38213577578145, 52.67938475455008, 50.5957942624246, 45.12219336725051, 38.81313939248362, 39.824820641548406, 42.038488695698405, 38.844949814581106, 40.71076639236943, 39.52336295958489, 41.012231919073294, 41.462049330434496, 40.349418040244814, 41.08153627764794, 41.672994398301654, 38.7634821861021, 38.24242276530112, 39.78904862557688, 39.60645052694505, 47.12222560759514, 53.54098435371153, 51.834376781217514, 54.97240235728603, 57.12324188601587, 52.781389913251324, 54.41198587417603, 54.453237441278276, 52.21185391949069, 53.50616155132171, 47.67584462319651, 45.579643710967034, 53.77474584887105, 51.71359915887156, 51.4521731868867, 50.734587330972, 50.958566434921764, 51.36596733523954, 51.5794894003099, 53.45286830779045, 53.82523067535893, 52.681510679183475, 47.31000907959477, 40.05296530262117, 37.848114736618534, 36.42636145314863, 39.51935821963895, 37.888370021697014, 39.29027611209501, 36.854656819374334, 38.60435555058141, 37.07979302252493, 38.33295499124835, 38.981801309893214, 37.635992957699685, 37.95225366469353, 36.99563072573754, 37.707372250095496, 35.47572797344577, 38.93438377688008, 39.155142614918375, 40.232445116966005, 38.4167681970904, 37.31702973765712, 38.018047501963956, 36.29970419791437, 37.070108690569484, 38.78543176958638, 40.076699564533854, 44.832777361716, 49.300529572271536, 48.58083348120413, 51.66515396487329, 49.62038709271339, 46.95832936994491, 47.75414689894646, 49.37861219529183, 47.777367330366566, 49.582751950910016, 50.404151178175404, 49.33389717532743, 34.70371923139019, 13.855381377281683, 0.6695971277452285, 3.3032524777996928, 15.583438431063007, 9.09795134298263, 5.365068422209832, 0.9447434280187854, 0.1548440967716517, 0.11328700614432174, 0.8671249317065363, 0.6491057466595405, 7.8539535018705555, 38.289891289126494, 33.41209057838687, 40.84508403655022, 47.56064068886542, 7.6803346891557025, 0.1162413016502415, 0.07204788797084363, 0.008066165610216558, 0.03425398210604345, 0.03068355272614187, 0.055360347933826916, 0.05507848503428602, 0.013581716170113896, 0.03170800380288594, 0.05146941417948373, 0.09520663399129145, 0.0506335701192579, 0.0045116224998397935, 0.04759371025307525, 0.02620183303201151, 0.036991658590493665, 0.03637798385874879, 0.016213237766116377, 0.13351581059396267, 0.10525797568862477, 0.1630576318430324, 0.11399244288763694, 0.1397996314711148, 0.14175599020334984, 0.08087226324864934, 0.10218602439929401, 0.13413569829877348, 0.1096367427418309, 0.24016130174840652, 0.20489413771898518, 0.13055457433144893, 0.13143090230803336, 0.2709237462089908, 0.17545872608259802, 0.14829540865555887, 0.11697715208415063, 0.12508437713427892, 0.10509030202463751, 0.25281718150982935, 0.12419996693009332, 0.13463367077131427, 1.4002466826669633, 26.18477640613433, 51.19526578534035, 41.854949228225216, 41.96249669597995, 48.23830073879611, 24.264174122964185, 5.307278671572286, 1.0218927720862052, 0.39059896803190636, 0.48722024466241565, 0.160290859339218, 2.6043209241282557, 3.0324655242504615, 2.8688945981764027, 0.6822416234400965, 14.270269101665868, 45.112720843284364, 57.81890169266732, 56.4776550569842, 58.347495986569314, 57.239504860293486, 52.49765349972633, 54.7474269713125, 51.72154588084067, 51.168119061377745, 49.33770971913492, 53.246222157632154, 50.75478361498926, 50.776772422175256, 50.463496638882546, 49.84413477682298, 52.926184208162375, 55.924934264152284, 54.92019953266267, 56.05212888410015, 50.10075192297659, 53.22661422914075, 55.32254449782833, 52.25790646768386, 45.8169980972044, 40.90357049818962, 41.97242421488608, 44.75817780340872, 39.651816660358065, 42.6848796106154, 42.19765063255064, 42.050412701022246, 43.339127032987534, 43.01769271973641, 42.53312703101866, 42.62640099371634, 40.367119696832475, 39.89857296789847, 42.11635558835922, 41.729099981246456, 49.04610110867409, 55.605233638517326, 53.530488091130415, 58.94259014437276, 58.00783834149761, 53.463097849199855, 56.54953249039189, 55.37356668902982, 55.12537087163618, 54.69713041859289, 47.59170978300033, 49.85024975192163, 54.71015268756498, 53.80737996870472, 54.03414003310665, 51.19095902289114, 52.86034330244988, 53.16111849200342, 53.85695088294245, 54.612144424069314, 55.15800891384002, 53.75254131132557, 48.97611818005962, 41.38600241753363, 39.066057743564734, 37.128512782435266, 39.42514681047009, 40.14809846878052, 41.11235041772166, 37.253985481877486, 41.21970568933795, 39.49061116864605, 40.22178411483765, 39.91432912888066, 40.03538131713867, 40.065716928051366, 38.42161624662338, 41.153103843812026, 37.01905904277679, 40.85272481364589, 40.980209688986506, 42.95535841295796, 42.215826895929155, 41.06790996366932, 41.46517545946183, 38.459580867521225, 39.22842033447758, 41.03661337206441, 40.6179395798714, 46.02043574856174, 50.37050116446711, 48.8757525720904, 53.289917361351755, 52.77884429500949, 49.241588115692146, 49.29017451501662, 48.42970848083497, 50.25805073399698, 50.84657099939162, 51.655842258084206, 48.34937441733576, 33.48941226159373, 14.868187365993379, 1.2572929599592764, 4.213613512054566, 13.533563652346212, 16.46236215868304, 11.417267457131418, 3.335125657819933, 0.1504930544404253, 0.13002165292780246, 1.3602088439849116, 1.3809549952706983, 11.316274269934624, 42.21272822349302, 45.36852998118247, 47.64006084011447, 53.11341462596771, 8.368654270325939, 0.26173721818673995, 0.2625089751616601, 0.12995264372758328, 0.2096845621183034, 0.11747301015402041, 0.12320320227093275, 0.09333572470613065, 0.17324673913178906, 0.11351552251125537, 0.1313797889217254, 0.1435230332877367, 0.0943380511636215, 0.16062084405172258, 0.2768834812506553, 0.1456587025595288, 0.115099937895373, 0.15510694153847235, 0.09954482902802768], [0.018681375790507566, 0.057787467695532314, 0.02086951633945348, 0.06925688410598425, 0.02503004218001039, 0.058219587250101956, 0.02526032437960948, 0.017631530814293413, 0.03877738655935373, 0.051196273190960775, 0.04605568532321242, 0.03330723149701953, 0.057928040999198155, 0.011371039229655459, 0.10168698706453848, 0.058104543826512756, 0.03760341427198822, 0.06424694104240307, 0.06173564353957773, 0.05350776730225452, 0.031187732426089146, 0.07549783470289362, 0.05007468982629719, 0.041829262514628714, 5.435035661343606, 34.629421695586174, 39.51947196837395, 27.549241512052475, 39.12020606379355, 19.118116632584606, 2.0743849344791907, 0.1723265909259358, 0.02884941566134653, 0.05336306095423718, 0.10514775861895855, 0.1090838800695154, 0.4009890814702357, 0.7964030040367958, 0.2521425491619495, 2.458090061141599, 23.526213515189387, 48.68764354336647, 58.907900702568796, 55.749769056996996, 51.88688947308449, 51.07108746805499, 48.05271379409298, 47.85683847242787, 48.57831924192367, 48.68586278730824, 50.27932566981162, 50.96626212519985, 50.47025880505962, 49.4347373900875, 45.17564350558866, 48.0834141854317, 49.81559953381939, 52.34956833624071, 51.528153419494636, 51.63144119324223, 55.29177350382651, 49.811449666177076, 46.761485222847234, 40.12874157198014, 38.05527863963958, 38.814673039221, 38.575192728350245, 38.50620608175955, 39.6028733253479, 39.40813941340293, 39.50082894294493, 38.66784303419052, 38.91434831003989, 39.20450564353697, 38.42134952545166, 37.36036408332087, 36.74500696120724, 37.489390450139204, 36.96337707581059, 40.12630970247331, 46.877524622025035, 50.782765803798554, 49.241074285199566, 47.038643821593254, 48.59243585217384, 48.80930369900119, 50.05780981433008, 49.36960251100602, 53.861645960038715, 47.35521831820088, 40.66127392553514, 53.28666179410873, 51.18628748001591, 52.232332614160356, 48.81534807143673, 49.27702280782884, 50.17893260525119, 56.857556220023866, 53.625887978461485, 52.85136891949562, 49.37996933537145, 49.3467664718628, 39.610239536531516, 36.60622958214053, 36.85681804533928, 37.384455280919234, 36.88392162322998, 35.04312584477086, 35.69813420695644, 37.19863691637593, 35.879830160448634, 35.668708585923724, 37.173098364183986, 36.36925958818005, 35.97293938359907, 36.6394442127597, 36.73054518238191, 38.488014128900346, 40.512902429026944, 44.55129238866991, 45.73872720041583, 45.836915892939416, 45.10673530640141, 45.6533097451733, 42.286143226008264, 39.18888284314064, 36.41339409735895, 39.78810725673553, 40.829688733623875, 43.173587322235115, 46.975387757824315, 48.703897845360544, 45.938234636860514, 44.592104650312855, 42.559536349388864, 47.3066044622852, 50.33011644117294, 47.85114319093766, 48.310499806557935, 35.61890232947565, 17.566952590019472, 2.503329452968413, 0.20382956661764653, 5.341433690440271, 16.621106363111927, 6.556763908555431, 2.7047671858341467, 0.37836819045966674, 0.07849929824231133, 0.0698229847776313, 0.0740172089107575, 0.23746594396089357, 16.514537526715188, 32.76118305421645, 34.303661008034986, 42.70486408664335, 22.960497909976592, 0.5440130084753036, 0.024258677825151433, 0.07497735456713746, 0.03542109790648665, 0.07100258398080064, 0.053027303769223155, 0.0617726494167601, 0.03239249953279092, 0.040595960547967304, 0.023416230087018302, 0.024972696668438377, 0.05253274421838503, 0.039692195132374763, 0.02304081827582371, 0.028862410427762136, 0.024919468879459367, 0.008805709545530619, 0.029293354037368012, 0.016157491463086298, 0.051402251251162066, 0.061785592472240816, 0.04150510773122792, 0.08655846659694949, 0.0402721083692966, 0.06321236611373963, 0.05368551119200645, 0.013150440269870865, 0.07612539094782646, 0.046533007895754236, 0.09193798196652243, 0.05289875804596851, 0.04745620896198577, 0.0693834111875584, 0.0218909528602155, 0.053958242323489926, 0.015543847374858396, 0.043266228955960086, 0.02094025306794192, 0.05312434795703139, 0.030183454359611197, 0.10082729085679017, 0.05457361393998708, 0.0424003619099817, 9.135213859619634, 42.780197128172844, 41.359859820335146, 29.69739029484411, 42.97983792520339, 22.58854543009112, 3.1227410800995368, 0.12181200958307713, 0.01597321954660959, 0.24073186871265215, 0.06556046390605551, 0.22614072828042894, 0.5670531947285898, 1.8865176218171276, 1.028800678829993, 2.074450389031441, 27.290423916232204, 51.20638570477886, 58.594860261486424, 56.46483675126107, 53.95470027000674, 52.83946452602264, 50.43888376605127, 50.49682501823672, 50.23865853586505, 51.68854305821081, 51.58371771535566, 54.04356548863073, 52.094982977836366, 51.39245510101319, 46.47523064767161, 50.21143728686918, 50.832681886611454, 54.06712324388566, 52.30706161068332, 51.38839152551467, 57.17184397482104, 52.22659810896843, 48.0892663617288, 41.02543853944348, 40.94927787780762, 40.27366922747704, 40.57096135231757, 38.79327258756084, 41.8369298596536, 40.78061596039803, 40.90837147928054, 42.25468581722629, 40.710813460811494, 41.072201036637836, 40.876933682349424, 38.81556733962029, 39.36971195282475, 38.86471463787941, 38.59016441529797, 41.38194668677546, 49.36035748450987, 53.220456107970215, 52.53228410597771, 50.3497596709959, 51.13080163155833, 51.84737551596857, 52.46378775565855, 50.9069598105646, 57.13149847522859, 49.05809571666103, 43.9364569417892, 54.840912741999475, 52.483921281753055, 53.40832587211363, 50.980084557687086, 51.53936355344711, 50.645737801828695, 54.39300944728237, 55.49339902016425, 53.99659118344707, 50.54729807761408, 49.59382872427664, 40.513008333021595, 38.23399359180082, 38.56550447402462, 40.17191117809665, 39.45732593536377, 35.760739157276774, 37.66982340043591, 37.52679024973224, 37.03945536767283, 39.5640810843437, 38.84539696478075, 37.704646202825735, 37.53775327436386, 37.807514282964895, 39.138990294548776, 38.808263886359434, 40.94580658020512, 45.631069906296275, 45.98569923831571, 47.1787626512589, 47.70556834436233, 46.64093509797127, 42.686840795701556, 40.54951383221535, 37.93071985244751, 39.892799239004816, 42.53735142369425, 44.36148497366136, 49.50721886850173, 50.310712475930494, 48.55219625657605, 46.7929583211099, 45.834044717973285, 48.328256376328014, 51.13155864900159, 50.25190045756679, 49.692358663005216, 38.84571075439453, 19.311061943731, 4.739534710684131, 1.1058902067522849, 5.348576326524058, 11.981715156186013, 6.589218089657446, 6.600702789521987, 1.7143804844348662, 0.3464643362789385, 0.02695956102181827, 0.10458608593551383, 0.18606826242419983, 17.518070051746985, 40.40444104902206, 38.96498218659432, 45.81025554287819, 29.265794254118397, 1.1744088655517948, 0.04780653713931961, 0.03728810780411286, 0.03742664331390012, 0.03594374607106851, 0.020152392924853393, 0.009502398522360431, 0.03653126273063883, 0.02874892790831866, 0.048607424607560526, 0.05035745670958873, 0.0244633803489588, 0.028807660039033622, 0.0234748607110833, 0.04184988177111072, 0.04450197857353957, 0.017454045479215922, 0.02840925409879175, 0.028096019898751573, 0.11667372763998086, 0.2262082665918335, 0.09462433822092511, 0.14163940694303284, 0.12180824043048967, 0.09861767111766724, 0.14563863105591268, 0.18241785346500336, 0.15890744244379384, 0.27943041716371814, 0.2529864409758199, 0.09464218806956085, 0.2086071820268708, 0.18442163303975137, 0.21601082426646065, 0.11934359768225301, 0.19023294620696576, 0.19886493382434692, 0.1648967025140601, 0.09114500435609972, 0.0848539133045462, 0.152059551027994, 0.17621854740765788, 0.17660755153384902, 10.529641951284102, 47.65300466168312, 52.02580413510723, 37.66184137713525, 50.41887183343211, 29.678760997710693, 5.188254838989628, 1.2454345317617541, 0.14114289003754818, 0.583397466088495, 0.3670685467941146, 0.3512890048084721, 1.5390148686785854, 4.450991432512961, 1.353069517400957, 3.7841877677748283, 27.09868081154362, 52.037437885038315, 61.78439440265779, 58.905492367282996, 56.32386676726803, 56.010610595826186, 53.34836852165961, 50.118147634690814, 52.22999488153766, 53.49712833281487, 53.92370177853493, 55.52168323147682, 54.641875989975475, 54.49796030598303, 49.821789033951305, 53.59830979377993, 52.47184038162232, 56.060554135230284, 53.928106600238436, 53.52990758034491, 61.65927471653108, 52.894365941324544, 49.63424482653218, 43.61446957434378, 42.03021249463482, 42.434149942090436, 43.03134649030624, 41.34611975762152, 43.7884541480772, 44.03143321314166, 44.50763640865203, 45.17207414873185, 42.45655844288488, 43.682475628391394, 42.68066306268015, 40.93927191149804, 40.153307376369355, 40.91616130644276, 40.30479715716454, 43.94762392966978, 50.10220319994035, 54.63963631660708, 54.32645859256868, 51.54658855930452, 53.03259811093731, 53.171159759644546, 55.009759010807166, 52.31101928218719, 59.6441884194651, 50.99163201547439, 47.33320597679385, 55.87518292088663, 55.06265217258085, 55.38471798742972, 52.40564254022414, 53.85333445764358, 53.42227774281656, 55.68261807964694, 55.0917600816296, 55.42541650033767, 51.27552924617645, 53.197816187335604, 43.35202378611411, 40.472556929434504, 40.220611326156124, 41.37239963777604, 40.70307854683169, 37.82699277324062, 37.534854642806515, 40.68672226321313, 38.37171977566135, 40.818204033759336, 40.5888944287454, 40.146498141750214, 39.641018375273674, 39.3046437540362, 40.32498559644146, 41.53222053281723, 42.26630387767669, 49.22741266988939, 49.46142127436977, 48.36480109922348, 49.88152673167568, 50.2756307971093, 45.51492852549399, 42.64598538798671, 40.13960261498728, 42.560316901053156, 44.10761348662838, 48.472858475100615, 52.41109463476366, 52.29370986261676, 49.70594183091195, 49.71675580547702, 47.88595030384679, 49.98671293258668, 52.446486180828465, 51.113978585889264, 50.2778273244058, 38.69416213804676, 19.714177654635524, 4.375295081446248, 0.6858692029791494, 11.027651563767465, 25.092590470467847, 15.359857447685735, 11.11090583185996, 2.6948511888903957, 0.38314419708425, 0.23349967695051627, 0.34065049502157396, 0.40677362752537577, 24.673665646583807, 43.34576760568927, 43.93411528679633, 54.88567483040595, 33.47651550846715, 1.7980508914878293, 0.10733814955118204, 0.2254394360727841, 0.09854752810732012, 0.2654000377703098, 0.17769721967558708, 0.17464601404724583, 0.11877419517165232, 0.11354974365883297, 0.2118975756269309, 0.09437489233190015, 0.13397400778147484, 0.11786106433118544, 0.11880577331589115, 0.20831370906483745, 0.11465058902338629, 0.11556898288789297, 0.12795481665600694, 0.16868917481793513], [0.10240932370746329, 0.013722863082113046, 0.033176728419118354, 0.030778170330449942, 0.06630157736400444, 0.06627084957736154, 0.057308651251538154, 0.013775949144826062, 0.01914428441875404, 0.010143826704382176, 0.07128663406136536, 0.01447329983010047, 0.08495466152746832, 0.06725368675805869, 0.07806799840182066, 0.0839303253639129, 0.08123189556382357, 0.09031450375914575, 0.045418491692192135, 0.03407422340505066, 0.03279301796048399, 0.08717012651745351, 0.010888065801062172, 0.06399403243596036, 0.98478224729338, 18.49401850854197, 39.280046570685606, 30.012668448109782, 35.48864041605304, 34.59799174339541, 3.805576207176332, 1.7898524023832816, 0.1988169307550115, 0.17209238252572476, 0.2557488774219828, 0.14403467276884666, 0.055274917638950774, 1.495211799779246, 0.8429206595305474, 0.41235552800278513, 6.795744607525488, 29.883793092543083, 49.47398854840187, 55.703810645687966, 54.32912972665603, 51.29619229224421, 52.79467105865479, 51.17832114619594, 50.59249947147985, 52.53617509718865, 51.967709910485056, 51.27944377160842, 50.0597474651952, 51.250088753238806, 45.0367445330466, 48.268138208696925, 51.167460103188795, 52.414714982432706, 51.96153217746366, 53.06942132211501, 51.1256201805607, 48.00756731340962, 41.984842438851636, 38.9462254124303, 40.53126696617373, 38.23725700378418, 39.39301867638865, 38.17893920406219, 38.10374736785889, 39.34036870156565, 42.17601091630998, 41.922480675481985, 41.737497775785386, 39.45602370846657, 38.97933021668465, 38.286608265292266, 37.91282992209158, 37.323638931397475, 38.70494081128029, 36.648665705034816, 38.37291217619373, 40.70536528864215, 46.240943554909, 46.79173454161614, 45.02154927099905, 44.35094948737852, 45.79981419347948, 49.19483738560831, 53.08626005726477, 50.772422513654156, 42.48190872130856, 52.03346452405376, 50.31447795129592, 52.73862038889239, 49.388155321921076, 53.77365542996315, 54.82920054466494, 47.46881015839116, 46.77724138382943, 51.70256553157684, 50.47605999054448, 48.751087880903675, 36.5810558103746, 36.26554819845384, 37.80632972717285, 37.56789668913811, 36.37287209110875, 37.10191911266696, 36.887534126158684, 37.03215583678215, 35.956755684268096, 37.79477050227504, 37.298614209698094, 36.51596407736502, 35.67543545076924, 36.541985081088164, 36.79632333017165, 41.844072495737386, 45.41189962817777, 47.134702667113274, 47.430445455735736, 48.54899952488561, 47.00857100948211, 48.33120599869759, 48.05039567332114, 46.998686636647875, 42.98777680243216, 42.0896795488173, 42.49782569946782, 43.32046831807783, 44.78697584521386, 47.331076129790276, 46.90386333773213, 42.36844631933397, 45.11798466405561, 45.17687905219294, 48.809523351730846, 47.177805592936856, 36.95230422481414, 21.78239049450044, 5.861906716900488, 0.4128535157970844, 0.4948715324844084, 3.1402603464741863, 14.030627973618047, 3.2286857693426074, 3.7226065560694668, 1.1033814833048852, 0.6748954531165862, 0.09950656293620987, 0.09258432268735864, 0.659623398415504, 26.531841447276456, 31.743620211078277, 29.392906504292643, 39.15259307430637, 10.110226831128521, 0.12080676433059478, 0.00991709244948241, 0.014606415267823445, 0.037856054747657436, 0.040960357930030555, 0.04291402769365138, 0.03748215021445386, 0.03299128151528778, 0.03337018094175766, 0.05104225121378418, 0.041168672558400905, 0.050893890626368024, 0.054544701781724735, 0.054081272213689746, 0.021692361802824085, 0.018474375002927357, 0.03970981898507284, 0.06723045897219451, 0.01292327317529388, 0.06404737130768838, 0.036960708638352734, 0.03153003774763596, 0.0791671277294236, 0.09845125383787579, 0.05079165236243317, 0.051398723416270754, 0.05131630767737666, 0.08480754966336874, 0.043111142116568746, 0.051831543941291115, 0.021858763760857044, 0.034320336811605005, 0.05995582976949312, 0.049401114679752826, 0.04491266681842747, 0.11897206036073547, 0.024238543119281534, 0.0374756078235805, 0.03915335952995285, 0.004785699073240282, 0.06529329074246269, 0.051769778102396, 0.10085356767259299, 2.556710949828548, 24.661045420554377, 45.52904513574416, 32.37167404543969, 40.4835670225082, 36.20989368807885, 5.390782500466993, 2.0425683836783133, 0.6752275675535203, 0.3844735128504615, 0.12998187764277383, 0.1377460102160131, 0.1765132307886116, 2.736651887816768, 4.327423043789403, 0.8527959618837604, 6.270594154634784, 31.164588159130467, 51.40639912697577, 57.75649678322577, 55.14544163980792, 53.32477546507313, 53.697341795890566, 54.617557294907115, 52.209763296188854, 54.23960947221326, 52.8852621201546, 51.46812154400734, 54.156396389007575, 52.06181933802944, 47.711867670859064, 50.09200111512215, 52.5371870686931, 53.84465817482241, 54.26890957740046, 54.53120631556357, 52.18424043347759, 50.88009157488423, 44.66686894816738, 41.02406570988317, 40.815321091682684, 40.37101853278376, 41.11815160320651, 40.15437033868606, 40.05502454696163, 41.716316976854884, 44.692584007017075, 43.11805832770563, 43.54877379632766, 40.97788372347432, 42.28986163293162, 38.331558627467004, 40.077766449220725, 38.57371791716545, 39.07531845954157, 38.565673135942035, 40.140504760126916, 43.58471839658676, 49.61265217873358, 49.0942011340972, 48.800721553064164, 46.76281490633565, 48.525633965769124, 51.99770819756293, 53.07040975939844, 52.028255616464925, 43.2311128031823, 52.21342678992979, 51.1106445712428, 53.84367365990916, 51.73215589215679, 54.439850391880164, 56.31714382479268, 49.58254014292071, 47.56401000484344, 52.90226951722176, 51.75205799841112, 50.01795461100917, 38.86872330019551, 37.36950712819254, 38.12053118982623, 39.101002139429895, 38.504131147938395, 38.166022839084754, 38.39617575368574, 39.57992353746968, 38.67973173818281, 37.95896091768819, 38.6711888159475, 39.40886505188481, 36.945702875814135, 37.21096492582752, 39.07433786699849, 41.745624926782426, 46.77178144454957, 49.03738952452137, 48.63128692873063, 50.932714093116026, 48.88172241949266, 48.98568091853973, 48.32029788724838, 48.434266274975194, 44.52348670651836, 44.13698027210851, 42.503446455924745, 45.092701065924864, 46.29537036342006, 51.03569592199018, 48.357191701089185, 44.92815371482603, 45.429793480903875, 46.17054877742645, 50.33942422559185, 47.63231023665398, 40.2460047506517, 23.526782258864372, 8.652929029157086, 1.7340976264207595, 1.5150083697611287, 8.555801337765109, 10.603844369611434, 7.234420526412226, 6.9605930005350425, 4.2677260406555675, 1.3561352174128256, 0.05266805066757145, 0.13716983548816175, 0.8672002534712515, 30.641355745254028, 33.33254098892212, 33.56233696783743, 47.869986257245465, 15.009293652349903, 0.18145708727740473, 0.028619776975603837, 0.02203722011237856, 0.015630632687750605, 0.039871091984452746, 0.061610725242644555, 0.034926982686644605, 0.02817256548892587, 0.06243100622668863, 0.02735091129227752, 0.09328761438448584, 0.04870913427082762, 0.06486762930909473, 0.08345246269938447, 0.015253560380980134, 0.016737308939017596, 0.07255491560264941, 0.020804766588093295, 0.05881444303198688, 0.177810171679143, 0.12748443867049872, 0.09922721663550024, 0.16208787178320272, 0.2369017968134534, 0.2023124060924015, 0.11468166154959511, 0.1259975845835382, 0.23682716452787, 0.1340625215802462, 0.1589593525615431, 0.19693822269478153, 0.1378103309581357, 0.1861247231042193, 0.23589719507482745, 0.1952487536736073, 0.22902158659792718, 0.11499833165397567, 0.10476122129588358, 0.14252086770870995, 0.11347558634776263, 0.22640118285292582, 0.14954040878482405, 0.28108486064499427, 2.244409630375524, 28.61950924319606, 51.60111342706988, 41.363550770667295, 44.912130832672126, 47.08011896379533, 8.282045395143571, 4.826788815759844, 1.813178492649909, 1.1384895155506751, 0.3809121845951004, 0.4525020285960167, 1.1785298057140843, 3.8443706545137593, 2.326918402987142, 0.9815974052875274, 8.715581047919489, 32.35413908958435, 52.25357617101362, 57.25889705842542, 57.77869739840108, 55.00150242159444, 58.56156326109364, 57.42775901671379, 54.68845021340155, 56.74117165227091, 54.74579134295064, 54.39200924288843, 54.717805231771166, 56.24414851588588, 49.40010678383612, 51.62196082453574, 53.906682614357244, 56.07377252271099, 55.670615626919655, 57.490705213239124, 53.93455497680172, 51.84634393261325, 45.69988396859939, 41.80252282850204, 42.692265433649865, 42.486258629829656, 42.65538730928975, 41.52041812096873, 42.52871828694498, 43.88784308587351, 47.169960852592226, 45.24925070424234, 46.056466640964636, 43.22590389559346, 43.652026268743704, 40.67334698092553, 41.43875437398111, 39.80181594048777, 41.65007991175498, 41.31997323805287, 41.26345580623996, 44.34517575848488, 49.972706148701334, 52.24362119551628, 49.5624654523788, 48.498216598264634, 50.035322866132184, 54.64252710342408, 55.28312467759656, 55.351346462003654, 46.746419399015366, 52.82544205265661, 53.279750577865116, 54.47698739267165, 53.12123190972113, 56.68095934775568, 55.88299628226988, 50.0157541613425, 50.6158140397841, 53.6023812140188, 53.477842038677586, 53.558784069553504, 39.71997176447223, 39.40089871806484, 41.64895419151553, 40.796187769982126, 40.28252986169631, 39.743615811870946, 41.229464546326675, 42.115488744551136, 39.514741589946134, 40.74220026693037, 40.961492138524214, 40.129184799809615, 39.702862385780584, 39.46646898023544, 41.686718771534586, 44.38079872438985, 49.83128509213848, 50.85611804839104, 50.460892185088134, 53.092669210126324, 51.1063652653848, 52.14300847822621, 51.44745065319923, 51.30057357972669, 46.83569646650746, 45.168881339411584, 45.505577595003196, 47.74571772544615, 48.223180001781834, 51.895361792656686, 51.20169847242294, 46.64384157426896, 47.80512202170588, 47.38000377531975, 50.01313009569722, 49.92041310956402, 40.118413971316436, 23.5772749300926, 7.205553352832795, 1.1962255787464882, 1.7267918442526173, 6.860528924772817, 24.378387658826767, 11.136464976495313, 9.757782259295064, 3.528888292850987, 1.4753414402084968, 0.2552638824788794, 0.23213383411207508, 2.2001415154626294, 36.96824081482426, 40.189710893938624, 40.50606966018677, 52.511413174290816, 17.61302278887841, 0.32509606031160204, 0.21706457820630845, 0.16634370470719953, 0.10771013886457491, 0.17229248469154682, 0.18989214433297036, 0.1651661662805465, 0.20214942854739007, 0.17089547739634592, 0.08831032581867711, 0.2286448705220415, 0.155567268450414, 0.12661211733375827, 0.14558063820004463, 0.10000535512282964, 0.07075422593662817, 0.2002118236475414, 0.07882040399577349, 0.24411595486585172], [0.055722129125628746, 0.03959663332470002, 0.018741174698657086, 0.04750542628068117, 0.045316142345508265, 0.07469235453754663, 0.044885413240521185, 0.018407589372908397, 0.013213241285073661, 0.02575662869569515, 0.022881887590272293, 0.08696968727294477, 0.022650519461040537, 0.03715728296928349, 0.0290435059521828, 0.023293954793423898, 0.0756215732244234, 0.011380352943594898, 0.08015717379748821, 0.030223727601790623, 0.0894035792519008, 0.04284222227250857, 0.025400351845629277, 0.021248074856797056, 0.07535637656767523, 4.683525225808544, 30.65560571609005, 30.752862845697713, 26.675464914691066, 41.19554781144665, 15.358301247319869, 1.8708369664607511, 1.1608797528090016, 0.45824989436134217, 0.4640696804609991, 0.020562581297370697, 0.22394931845126614, 1.7397994043365603, 1.7779732591682866, 1.3026199922446282, 0.38035113244287433, 7.513874692301597, 29.91607027669107, 46.89980368460379, 54.33504858324605, 53.2086262395305, 52.661902750692065, 53.92478043033231, 54.63714561154766, 54.74126492777179, 51.75115977564166, 50.22193354945029, 52.47200512116956, 45.0551639833758, 45.48146286318379, 47.01878486141082, 51.91254177401143, 51.82136235698577, 53.31194539223948, 52.044784484371064, 49.81752149520382, 46.36016399629655, 42.74055373284125, 40.46450430347074, 38.65311453419347, 39.67117355715844, 39.30715407094648, 39.932344575082105, 39.151094728900546, 40.25532430218112, 44.14584875106812, 46.384345408408876, 45.057591930512466, 41.8282300426114, 39.04213913025395, 36.6417113427193, 37.831240700137236, 36.166206329099595, 37.878207160580544, 38.175616956526234, 36.907867693131976, 37.06038513491231, 36.92531047328826, 37.39995256547005, 39.03203118231989, 38.4080252339763, 46.76894557091498, 48.594326434596894, 53.44409788808515, 48.71962654975153, 40.42661812997634, 50.27612893812118, 51.69103376327023, 51.76312300466722, 53.256487000373106, 55.498537325089984, 45.328580640977435, 48.69181302285964, 52.93437411708217, 51.02712946553385, 49.99086672259916, 43.598627121217795, 35.09191228497413, 36.28229279671946, 35.9095734934653, 36.04747618398359, 36.28453639245803, 37.814845192816954, 38.55304310398717, 40.22997794612762, 41.22602855005572, 38.628556574544604, 37.4792315113929, 36.978133032398844, 37.15064671731765, 36.35357010749079, 37.27442495284542, 44.18444095119354, 47.17508739040744, 48.26967970017464, 48.82110611084969, 48.79898002070766, 48.338595744102236, 48.524865181215354, 49.465865319775, 47.86022740025675, 46.83145246198101, 44.645068414749645, 44.618109964555316, 45.344521153357725, 45.04416173504245, 45.44579675120693, 46.622711766150694, 45.135807914118615, 45.108476838757916, 45.85512745764948, 49.683196006282685, 39.81882333755493, 23.20134908922257, 8.01034281330724, 1.676468692960278, 1.7122349479506094, 2.38282173871994, 9.71884391000194, 5.93694361948198, 6.019370757764386, 6.671737893935173, 5.078646656005613, 0.9661694976591295, 0.1079131291818715, 0.10511482449909372, 2.833341254341987, 34.78520647172005, 29.762609504884292, 33.78495893170757, 24.549991353865593, 2.0687828092805804, 0.048719162361756455, 0.02269908752022011, 0.04223998140303358, 0.05725321329889759, 0.029954824994708744, 0.026115540888220556, 0.0661211866404741, 0.030378705273652752, 0.07544426983522792, 0.07406721146957529, 0.05054922766923424, 0.009881529690427406, 0.05010052614154355, 0.009272107704272194, 0.03562571999106196, 0.12311487999414245, 0.035115283267993125, 0.045302329780233484, 0.021305496977161498, 0.016535787595315807, 0.0444554157495018, 0.042699074913417144, 0.008170484760475737, 0.07013413904895706, 0.008035410052886414, 0.0373086427909232, 0.010858077289266212, 0.032045367857321136, 0.014619621666028135, 0.11356207001353465, 0.04473463947614355, 0.049743008229040334, 0.05353161178889775, 0.019572799529639945, 0.025186167068539128, 0.035189796809948264, 0.010909448272638745, 0.007724421448074282, 0.03988422273147491, 0.05032265333518867, 0.034205527044832706, 0.01314923655421984, 0.020095373000649196, 0.04661571091761993, 9.377861484404534, 39.09679735860517, 34.797962019520426, 33.32203295923049, 47.35135870595133, 15.210946625278844, 3.4128795371901606, 1.334702161050612, 0.4840639317708631, 0.42528378266480665, 0.07526341945894303, 0.39179765048526954, 2.1703636165588134, 4.080403447151184, 2.745801551688102, 0.6066299097672586, 10.151990267538256, 33.04782398285405, 47.96688448998236, 54.803775741207986, 56.4310690664476, 55.39995247317899, 56.938408036385816, 55.78509392276887, 57.29795994297151, 54.65049735961422, 52.362441555146255, 53.55902725650419, 47.87037064952236, 46.242457589795514, 49.21024053327499, 55.433425980229536, 52.34805822372437, 53.49928563640964, 53.583263581798924, 51.22434231542772, 46.605308209696126, 44.24678310271233, 42.15500270166705, 40.34798245276175, 40.847143280890684, 41.9881921429788, 42.05948122086064, 40.616570672681256, 41.065415336239724, 48.2114403478561, 47.805035729562086, 46.96131037127587, 44.05696392059327, 39.94428426988664, 38.496035375902736, 39.251664300118726, 39.564924393930745, 38.54336661677207, 40.49941339800435, 39.20238364127375, 40.378263150492025, 40.075664058808364, 39.366836855488444, 40.42693976433047, 40.719721163472826, 47.247713996518044, 51.03362098816903, 54.28894896661082, 51.073774291623025, 42.298028007630386, 51.18811530451621, 52.61304178545552, 52.60671500236758, 52.13302604613766, 56.722454101808616, 48.332374865008944, 49.15334655392555, 54.789765034952474, 53.30710910981702, 52.498916502921816, 43.977959540582475, 37.55425076330862, 37.64035071096113, 38.26337214439146, 37.86299228668213, 37.78998521066482, 37.71230266940209, 39.932983921420195, 42.394432021725564, 41.265083589861476, 40.76402041219896, 37.88369847882179, 38.82085469461257, 38.043080068403675, 38.61493810530632, 39.38951599982477, 45.380461831246656, 48.86816670817714, 51.53575889525875, 49.788362595342825, 50.54795703580303, 49.61461336381974, 49.378690642695275, 51.179937162706935, 50.41670668509699, 48.545900852449485, 46.636420449902936, 46.83715166584138, 47.01725905941379, 47.589085717355054, 48.19559004998977, 48.009720694634225, 47.399270457606164, 46.55634918520528, 46.066260799284905, 48.78726782337312, 42.70486408664335, 25.082158926994573, 11.345326285208426, 2.713707002901262, 3.1628492762965545, 3.9173669440131036, 10.44397738672072, 8.756443319782134, 6.55469976125225, 7.3565092009882775, 4.646840768475687, 2.1171860829476388, 0.2155193022542423, 0.11020510337285458, 3.260324832893187, 39.05237259403352, 32.649666147847334, 37.48412270699778, 30.91442527309541, 3.8128826022148137, 0.04008460834982895, 0.11599151868252985, 0.033572520084318616, 0.041785813838003144, 0.034797739823378866, 0.04924064607269341, 0.05135052116407503, 0.04233339816452034, 0.04666335392563094, 0.0409830954196232, 0.04016088772444956, 0.007101378897430316, 0.017525421891121135, 0.01271395880218235, 0.014336379808223536, 0.10024564626115946, 0.05940807307319296, 0.03563351110525189, 0.0319042946812847, 0.14276880440452408, 0.11473142662115636, 0.22429298549409837, 0.09793999740072797, 0.09499458085385062, 0.08808869658218277, 0.1446610875427723, 0.05635872137762847, 0.2508987288080877, 0.14021226174889073, 0.23452765969259126, 0.22787829230148948, 0.08176764383191064, 0.09879141219801481, 0.13620562190490385, 0.1986390144954766, 0.13215968175040138, 0.10492753132336563, 0.13628517247496114, 0.12433090667811134, 0.24713198173671003, 0.11142887520573794, 0.06370090038305329, 0.0872926852635799, 0.27788212282523034, 9.549663259137063, 44.36653306407314, 43.771313390424176, 38.033968402493386, 52.12688361444781, 23.309932062702796, 4.622123952834837, 3.69635560339497, 1.3526808350316941, 1.1011893686748322, 0.1812185274977838, 0.9683239207633081, 7.3577310192969545, 5.327365619520988, 2.111042670665249, 0.7779880889481114, 8.834230784446962, 34.213289599264826, 50.06221855840376, 57.6885417199904, 55.628948288579146, 56.67425209476102, 56.0793815120574, 57.947853534452385, 58.04413595507222, 55.43026847224082, 52.83174530152352, 55.822780055384484, 49.466940049202215, 49.82757452995547, 49.81880803262034, 57.71263683995893, 54.24486937061433, 56.99726320082142, 56.211220218289284, 53.588786279001546, 49.429289217918154, 46.90487138686642, 44.13898852563674, 41.55562923800561, 42.55976776922903, 43.27209764911283, 45.21036040398383, 42.36494364277009, 43.37185921207551, 51.39518899302329, 49.88207978586997, 48.395273993092204, 45.619647964354485, 42.92842349698467, 39.69188759403844, 41.18411802476452, 39.26445907162082, 41.531439981152936, 42.960849731199204, 40.857412046001805, 41.57768080311437, 40.02076264350645, 42.20010995864868, 42.46173597151234, 42.22303621230587, 50.95985297233828, 55.42311799141669, 57.887684376009055, 53.64188732639436, 44.52970758561165, 52.39396956659133, 54.43257047284035, 55.71937853290189, 54.38294072305003, 56.806710535480136, 49.74531850507183, 53.743645375774754, 56.76087764001662, 55.567084666221376, 53.65011253664571, 46.8628510352104, 39.96417460903045, 38.999804988984145, 39.82722505446404, 39.56753277009533, 39.82959416604812, 40.58316384592364, 43.07364925261467, 43.17932182742704, 44.645535176800145, 42.14327089248165, 41.435239930306714, 40.548662677887954, 40.67115437599921, 40.30134154904274, 40.50226496111962, 47.241991258436634, 51.650119520002804, 52.03320564762239, 51.980845928192146, 54.169559863305864, 51.57713990057669, 50.92731691175892, 53.932119184924716, 51.24420127561016, 50.218395571554865, 49.57897863080425, 49.084524646882095, 48.9536076976407, 48.66334446014897, 49.16966361384238, 48.984402225863555, 47.093494246082926, 49.4705133284292, 48.76687149847708, 49.51836624453145, 42.63263756229032, 25.759477730720278, 9.527237107676845, 2.5140664510188566, 4.24334752944208, 8.133541518642057, 20.24959295026718, 13.364542838065857, 14.33965975238431, 12.2165366718846, 12.999954608178909, 3.7795375527874118, 0.47041641247849314, 0.2000557408938485, 4.602972980468504, 45.24706202168619, 38.21748825811571, 44.12774701272288, 35.38302275442308, 3.7599048643342914, 0.1113259053278354, 0.1873133698057744, 0.0748819689596853, 0.23788090314595933, 0.13068209732732466, 0.20774942402157093, 0.11084748341912225, 0.1301394925723153, 0.16790402662609855, 0.2681013863653906, 0.12329835039112838, 0.09103953703156403, 0.20608987839471912, 0.12994282248039402, 0.06867515524068186, 0.2247377148559017, 0.12353861854682047, 0.18168449281684815, 0.1250406871399572], [0.0776979779343932, 0.06655327555152678, 0.08562871930940498, 0.036319604128479, 0.0050322888907225385, 0.0377807023394252, 0.06664121478435493, 0.019909190652411313, 0.05392640370935683, 0.013176666332348702, 0.04955961061040721, 0.03251428836055341, 0.005398002028795741, 0.023086346881163698, 0.05174079699622047, 0.0731874360973316, 0.05876140676498894, 0.01630525641714133, 0.03508348295825624, 0.020627673873077, 0.02685327972886303, 0.022391087615922577, 0.12356497197141572, 0.04232514356713622, 0.03760197402669057, 0.6584985974815585, 17.374470118553408, 38.815194714453916, 27.29578579625776, 35.77799366366479, 25.137268227915612, 1.077989529698126, 0.020382897289950522, 0.3116252928251221, 0.36740151924952386, 0.14729411641676582, 0.13627964132014783, 1.0450072995116635, 10.366662567661656, 2.8011336922645573, 1.0183422303488179, 0.6742751057590208, 8.252691357366501, 25.588938959183235, 44.22641423440749, 54.49020970252253, 54.16153861630348, 50.692496376652876, 58.097542947338475, 49.51050581470613, 49.984618386914654, 50.10568234228319, 46.54442910225161, 43.661847883655184, 47.74828295553885, 50.21077832868023, 52.80580274520382, 50.245797249578665, 50.537429394260535, 52.82591665944746, 50.707064059472856, 47.627120940916, 48.280764318281605, 46.831119060516365, 41.341891442575765, 38.67326374976866, 39.300372292918546, 37.87797574074038, 40.12150872138239, 41.65404935036936, 46.32349375755557, 48.305028100167554, 47.747133701078354, 44.78144138090072, 41.40232339982064, 39.54441039792953, 39.135209129702666, 37.34399603259179, 38.998510606827274, 37.42535775707614, 38.75978339102961, 37.92112573500603, 39.30819349904215, 38.26399580124886, 39.07150983810425, 42.27950265330654, 48.043237347756666, 50.49367143261818, 51.8545259967927, 48.101963073976584, 40.76900574468797, 49.31371265842069, 47.23586451622748, 50.84705737329299, 50.540214277082875, 45.928393410098174, 49.99319661048151, 52.36299460934055, 49.10407373982091, 49.67959919283467, 45.5984789325345, 38.03537653338525, 36.26731718740156, 36.83463704201483, 37.54331519526821, 36.383387965540734, 35.85183620452881, 37.44301626759191, 40.538593953655614, 47.28060699278309, 47.65549928911271, 44.86332870298817, 38.469300500808224, 37.693502749166186, 36.32776875649729, 36.415920103749926, 38.243952489668324, 46.00124751367877, 49.131200851932654, 49.375235034573464, 46.20398306077527, 46.56355065684165, 49.333638298896055, 49.55701335783928, 47.643657653562485, 48.67241690235753, 47.4049618167262, 47.354943752288825, 46.10826938383041, 48.68860060168851, 47.64989422213647, 47.825945884950706, 46.31469980362923, 47.96914769757179, 44.78576383283062, 47.9664255726722, 43.13724264021843, 26.081002258485366, 9.437031419046464, 2.533873930092781, 1.1542370963481166, 2.365817773726679, 1.0018979998365527, 8.71271477591607, 7.277645045711148, 4.805818353929828, 5.771630425607005, 4.710985739384928, 1.6849503281616396, 0.13061848138609242, 0.05165900561898466, 10.061778695352617, 35.309756801974395, 26.434405849825954, 40.00074286614695, 15.155906946428361, 0.011138878199422072, 0.03262207693149967, 0.028113530753480814, 0.09011940414746923, 0.01825286642528109, 0.06916996377009539, 0.037476293472272736, 0.013445492330638152, 0.011687898940797295, 0.056473921849242145, 0.055308514424870094, 0.04238543468677709, 0.04883199179124448, 0.02483162540762175, 0.03596578259021044, 0.03007327559434118, 0.027422245569346894, 0.13687363525311794, 0.01956483796088686, 0.05856890036093612, 0.1519039126052972, 0.021787176674772656, 0.05394383987051345, 0.01902416183222686, 0.06158502299278494, 0.015752268297928237, 0.015651336213904285, 0.01184876399835752, 0.03605437299777423, 0.046732792135087714, 0.04061688623961903, 0.013782351724653235, 0.07627215041148086, 0.025437641175343625, 0.0428534492910389, 0.041421067885934346, 0.045845271613929546, 0.030323345845024434, 0.03238128017513983, 0.03845154255207989, 0.021893578626575972, 0.03891301093502872, 0.035463113998693806, 0.046792635093292886, 0.09786057706561782, 1.1677327463703773, 23.049025804765765, 42.58355302195395, 31.2592427961288, 44.32417146621212, 30.301294096054573, 1.2717064446018589, 0.4973894489868995, 0.40544562943039403, 0.4783538188184462, 0.2615497105063931, 0.3358125578491919, 4.377681353399831, 7.996765038659496, 5.918939450094777, 1.4532701406748065, 1.7914729541347874, 12.008483371426983, 30.763770957146924, 46.368032270862216, 54.621962116610625, 53.61466607739849, 51.2726306146191, 58.67515117891374, 51.75229334062146, 52.13746224680255, 51.96245785682432, 49.27206493193104, 46.4439772021386, 49.07116897644536, 50.81867510272611, 53.651026448895855, 52.31627918058827, 53.16400535645024, 54.22628125836773, 51.227091896918516, 49.2385482788086, 49.24409451023225, 48.10313194028793, 42.63965076015842, 40.65924213778588, 41.16151340546147, 40.43446287032097, 41.46177084215226, 43.153693060721125, 48.361435705615634, 49.69346084902364, 49.85846711743263, 46.059784966130415, 42.35526715555499, 40.24921717182283, 40.31064541109147, 38.617146399713334, 39.67309551854288, 39.21003226310977, 40.281721853440814, 38.870253024562714, 39.47333705040717, 39.62290094744775, 40.22182726090954, 42.268865185399214, 48.73840293576641, 52.08858166971515, 55.01405400614585, 51.11986998588809, 44.24636340910389, 49.58213221642279, 47.942722689720895, 50.09986546731765, 52.86832140338037, 49.00935242252965, 46.96237333359257, 55.315582290772475, 51.86756395524549, 51.2677864874563, 48.52254313807334, 40.54697213634368, 38.01371720529372, 38.49822798082906, 39.37294398584674, 38.337030333857385, 37.58340574079944, 38.96854762108096, 42.64737782939788, 48.121931860523844, 49.023378818265854, 46.82312134773501, 38.57171750837757, 39.99085064857237, 37.92196119985273, 38.241920701919064, 39.8053970644551, 48.29153514677479, 49.401942453076764, 51.74180884515086, 49.428642026839725, 48.05205483590403, 51.60675771774785, 49.025355692832704, 49.51288669340072, 49.248083560697495, 48.96728108006139, 49.917334048978745, 49.10171639534735, 48.71455100274856, 47.78552586032499, 48.564885124083496, 46.5627779499177, 47.53935398594026, 47.508018170633626, 49.0764759432885, 44.13667824960525, 30.25461789100401, 13.06970121399049, 4.824872737930668, 2.9687721162073077, 4.4420753948150145, 4.80630963079391, 8.87892815374559, 6.135462618643238, 8.128886155543789, 9.452636568777024, 7.400155865376996, 1.3439791793784788, 0.10435807518661024, 0.06821582424304179, 10.336779990503866, 42.43874303756222, 29.647427143589145, 43.36839575921336, 20.475015486440352, 0.23554300198391562, 0.024120548341964042, 0.0721375125971052, 0.05503222481497834, 0.05325410409920639, 0.014534294793021776, 0.02878074545503384, 0.029318110168641134, 0.04726020919699823, 0.02663883256665882, 0.06040275014275986, 0.05001449829808647, 0.023658788845603986, 0.0357193129527713, 0.03285488722124889, 0.04376350428848978, 0.034299717555123, 0.11087251151160848, 0.022821751603436087, 0.09967509461867233, 0.24679193062888038, 0.16456774435937405, 0.22227475750109843, 0.1270331362743051, 0.14393194037820065, 0.1803148195387856, 0.18796057620596504, 0.07750896872171471, 0.22353029900020172, 0.17432889961186918, 0.15707528188584313, 0.14564005597945184, 0.22899874185602512, 0.08848114044315393, 0.15018740068039588, 0.14988576122108968, 0.2067291634457727, 0.09656836293757924, 0.13833902355644012, 0.08727747075740369, 0.14685352392975362, 0.07433443059844357, 0.181413680735615, 0.10111752326690382, 0.22553335845230088, 1.116428757386823, 24.700031818882113, 53.274459300502656, 37.89912516070951, 47.704430857012355, 34.59484600251721, 2.1459539715320837, 0.43825913641241293, 1.5294252864776121, 0.8255766127859393, 0.4771486399394851, 0.28529285903899904, 6.565765748100897, 21.7934476560162, 6.674694380452556, 2.181524475736003, 1.6475506511426743, 10.08045800270573, 28.686597462623354, 47.48488403135731, 55.07107742371098, 54.88056790444159, 51.69721149629163, 60.64722084229993, 53.36637220075054, 54.85108344785629, 54.80089279913134, 50.370379570991766, 48.68858491220782, 51.59639481575259, 53.72721456712293, 56.15145898634388, 53.62977896967242, 54.81984961417414, 56.87073538380285, 54.08227535986132, 50.46868201225035, 52.47304062689505, 50.46250427922895, 45.99584640995149, 42.77358008969215, 42.91455007368519, 42.66919012992613, 42.87879766956453, 47.378356379847375, 51.28568426255257, 51.49115762402935, 51.64648740522323, 48.964398137984745, 44.55264560637936, 42.115006293019945, 43.4351937232479, 41.257313374550115, 42.640690188254084, 40.976020597642474, 42.35056031134821, 40.709899548561346, 42.68211041727374, 41.112440632235625, 42.39787586273686, 45.6529135857859, 50.80629218009211, 55.00101604769307, 56.593525794244584, 54.21802074678483, 45.81269133475519, 49.098809919049664, 48.510689735412605, 51.29021852247177, 52.172390953187026, 51.60869929098314, 51.240804503040934, 55.50722145265149, 53.073928125443004, 53.88412114112608, 50.657587282119266, 41.534432749594416, 38.84946054027927, 40.89345470551522, 41.41795796732749, 40.22133304226784, 39.22776137628863, 40.44166434195734, 43.57244530031758, 50.42229998496271, 51.67630134090301, 49.445669035757746, 42.41412231999059, 41.14369015539847, 39.97765187294253, 40.978554448773785, 41.01776638338643, 50.30533490642425, 51.86874066629718, 51.82111917003509, 52.317499037711855, 49.16346234659995, 52.1545990820854, 52.597560190385394, 50.30187145356209, 51.33902849689607, 49.200246334075935, 52.43156940706315, 51.33945603524485, 52.061752657736506, 50.470592206524266, 50.003579124327636, 48.996993034116684, 48.79250810992334, 49.05740145714053, 50.482288714378114, 46.00860588012203, 30.11142392312327, 12.600745577966014, 3.9492148737753596, 3.1977365526460835, 5.871445430863289, 6.476987311916967, 18.906238040616437, 15.884974560429974, 12.437776980861543, 14.56511955107412, 12.501980297027096, 4.221627894909152, 0.8303029462695123, 0.16009659476337895, 14.879716192522357, 45.37232683550927, 35.9484520266133, 50.651068302892874, 23.703692920746345, 0.47959040730230273, 0.13393478407975168, 0.12568863664543437, 0.1737405287642633, 0.1400161738837919, 0.15496576685578595, 0.1135871900365718, 0.1622886940716736, 0.1399336815361054, 0.11535364323325696, 0.15634147690669184, 0.14109631189175192, 0.06564347719353053, 0.13206258776687807, 0.15449315189353882, 0.17431668817035614, 0.1786596865783776, 0.21897820455412711, 0.1283362518335062, 0.1527488462987446], [0.04333840976018579, 0.04527434458835952, 0.06583043329057194, 0.05316650194506492, 0.031558603251112566, 0.02652520832094935, 0.07377642747615615, 0.015014708530338062, 0.07994829992493314, 0.03893880511543924, 0.02647913004752369, 0.059465621598064906, 0.04198802274561698, 0.04222058022635118, 0.04032179683206543, 0.10792393102160386, 0.0393948381045653, 0.04242993290385893, 0.047769757258074905, 0.02655620806880536, 0.03166199256215365, 0.056845516627354015, 0.06533910280033466, 0.013824855240302221, 0.025459122280740452, 0.06995190971440847, 3.3331134819215347, 27.1994210058643, 32.243077178155225, 29.546683026898293, 39.36142398465065, 5.3282569781426465, 0.2791487725992357, 0.0969307225257639, 0.2367657395981012, 0.08453870642810099, 0.18528161270003166, 1.3309499236845201, 3.2195221320275342, 4.946743230665884, 0.3306178075651969, 1.079020132460902, 1.7796602460645863, 8.515525460243225, 23.203941775906472, 46.12565725080429, 52.2553647718122, 52.789481762916814, 54.9420000660804, 54.597466914884514, 49.44248407117782, 48.742992108868016, 48.7356690437563, 50.01145132126347, 48.96952467579996, 53.25626734764346, 51.1918572456606, 50.15226441044962, 53.266579258826475, 52.17733706197431, 52.745088377306544, 54.01563429063367, 51.395016408735714, 53.96613005668887, 48.02586909263365, 37.599475691395426, 40.00576742233769, 38.62378697241507, 39.9676812079645, 40.87675717569167, 48.04067604003414, 50.30425233225669, 52.86582677595077, 47.829997693338704, 42.99486060296336, 38.902765550921046, 37.97580357520811, 37.68572468911448, 37.855508404393355, 38.55990725178873, 37.93719960797218, 37.78234443356914, 36.42291761213733, 40.15884576305267, 48.08653246971869, 49.54583460284818, 49.97396915189682, 50.460288140081595, 53.04237657977689, 46.04379738530805, 41.50970220565796, 50.70785245587749, 50.539496483341345, 53.162569768967174, 46.7616460400243, 51.901727799446356, 52.300205307622115, 49.959189661087535, 48.66630584962907, 44.862912931749904, 37.78864768243606, 36.95293180404171, 34.88724300938268, 36.011100123005534, 36.61749855164559, 35.52170599660566, 35.97452009877851, 37.785443106005275, 45.22333952688402, 50.400797551678075, 51.37043883723598, 48.171777340673636, 45.26644637507778, 36.62247603939426, 36.885302297530636, 36.268270323353434, 37.667548425735966, 47.8248554660428, 49.31853325136247, 47.323925648966146, 46.64638327014062, 48.06362190554219, 49.984296752560525, 49.46778335878926, 48.339595948496175, 48.168980690740774, 47.17409110838368, 48.506786977091146, 46.13845594467656, 48.79085679208079, 49.036856082177934, 47.542695845327074, 49.171475748861994, 48.684015350957075, 45.22042520584599, 48.18787474786082, 33.38609703125493, 16.236974923841416, 2.964795323148851, 2.0119088095042015, 2.0657405209156776, 4.335735526777083, 3.992972835417717, 5.127602738718833, 4.929755935745855, 6.666360324428928, 6.516134037125496, 4.012655043794263, 1.3784321758054918, 0.42894041225794827, 0.5730185068903432, 24.137581586837772, 29.936435222625736, 28.01701553406254, 33.280326397188254, 4.43435077705691, 0.0912550528864226, 0.08898150311001847, 0.0847613852050516, 0.02374226753149302, 0.04407362051067814, 0.05998163161078288, 0.02273767919940574, 0.028671256168895674, 0.02427115356699834, 0.08015436991568535, 0.009092351876109118, 0.037702526897192, 0.048470030568780444, 0.01071356342083985, 0.04048803791163429, 0.01933594621087034, 0.13435718963944143, 0.025824565372820345, 0.011719767240837458, 0.03397577344590137, 0.032322536553106004, 0.08610927860342688, 0.015745424259934696, 0.09727838088668163, 0.03752194848212023, 0.018384491821991342, 0.08773237376684144, 0.012864240355068638, 0.02268395153805614, 0.0374593016421122, 0.009985223521418389, 0.05247052638761459, 0.06706376590075032, 0.04573078360408545, 0.03626858650316154, 0.015112855884757255, 0.03249613207674796, 0.060758578831390034, 0.023316209647624243, 0.05225809786709086, 0.02015536343077979, 0.03458557560318901, 0.02230268298468042, 0.056717579943999175, 0.041754025019585125, 0.029655989417205417, 5.976299210902184, 37.25107508320963, 32.96457559831681, 32.674231952236546, 42.05891247718565, 4.335758080405574, 0.16233565526143198, 0.45393862731514445, 0.356030231041293, 0.4077119320150345, 2.0202328144542636, 3.979144519375217, 6.0788917445367385, 6.651285675264175, 4.318454544390402, 2.7288135213236657, 2.430298842730061, 10.496678352355957, 28.14322367791207, 48.421338142887244, 54.71783268836237, 53.14532702968967, 56.000435967599195, 55.72772925899875, 51.84131545405234, 48.95772618632163, 50.35631002918367, 50.90098604079216, 52.5946968601596, 54.9436160825914, 52.44625083861813, 52.49875176337458, 56.63908020142586, 54.52933142262121, 53.74694408908967, 55.03196354835264, 54.270105900303015, 55.30497227945636, 48.61685260649651, 39.389939615803385, 41.38272723843975, 40.8920975654356, 40.7847148372281, 43.01512356727354, 50.88306080910468, 53.50589090777982, 53.671544367267245, 50.812199269571614, 45.030939425191576, 41.016526914411976, 39.59926474478937, 39.31232375483359, 39.49253705240066, 39.86435421051518, 40.555832770562944, 41.46314759408274, 38.97483518046718, 41.928830992790964, 48.85613679885865, 49.46775197982789, 52.368274119592485, 51.85244321823121, 54.9787683640757, 47.049889256877286, 45.074850359270656, 50.493216437678186, 52.578450402905865, 53.613320704429384, 50.0751192339005, 52.698145451084265, 53.936594609291326, 51.52748661656534, 50.2317943880635, 47.94171464058661, 39.74558484169745, 37.74317956739856, 36.30413647620909, 38.81255495932795, 38.08386487345542, 37.569704901787546, 38.381659061678, 41.3748275849127, 46.64097824404317, 51.714905308138945, 51.470518112182624, 50.73914512511223, 45.73077263370637, 38.06268407452492, 39.17193035925589, 37.975226986792784, 40.506622714381066, 49.95396506401801, 50.41855019907798, 48.482880130890884, 47.608481837857155, 50.78979076877717, 50.44235898602394, 50.764879795812796, 49.22130946190127, 48.80764061404813, 48.97923646434661, 49.54028837142452, 47.80372565792453, 50.70140407931421, 49.649930384851274, 48.85473651270713, 48.96046792307208, 49.41280349608391, 45.82176377696376, 46.56076577401931, 36.339225999770626, 20.063156812421738, 4.865841404084237, 2.89661398818416, 3.0818234047582074, 5.222694229695105, 6.961906994542768, 7.9872121061048205, 5.5488133238207915, 8.431087616951235, 8.087013383065502, 3.944831134811525, 0.2111612119141125, 0.16224286669204313, 0.17542627459812551, 25.32958595983444, 34.36371641774332, 28.45915294462635, 40.40855561533282, 7.214467429345654, 0.029205849559436885, 0.031045510118166288, 0.03683608145483079, 0.0616242811684647, 0.03266911856049011, 0.05250952792383971, 0.03832239928024431, 0.026637135681906537, 0.051700519923601425, 0.051234730804759654, 0.04726552967763236, 0.09328115626328415, 0.07205787775737625, 0.03299074142330116, 0.028022306918677305, 0.050757833411015814, 0.02368898228591969, 0.058936002033372084, 0.02933322508338719, 0.05034419572761944, 0.08456293012826674, 0.19658591418016344, 0.1809799064311289, 0.16851717275717568, 0.07781879766093147, 0.12946584081697848, 0.16453913863628142, 0.14178877876650903, 0.14822174164076007, 0.19338533672834599, 0.045888701138357, 0.1462370836206021, 0.17176541619964186, 0.2199493742157375, 0.12917491126685374, 0.19875261001288894, 0.12188335535146537, 0.13486268509539867, 0.15111631293210293, 0.1747536953658827, 0.144911598294012, 0.23421627559488822, 0.17819643321056522, 0.09369169512102682, 0.10249524812905059, 0.15346556751718446, 6.137686602530941, 42.50789834607033, 42.24146742974558, 36.394245086177705, 52.52976202195691, 8.501807951158094, 0.3571212015325024, 0.612724966579868, 0.7127196041326369, 0.3859318378231218, 2.1383676173225528, 5.06904322293497, 6.690898181930666, 11.783508966045996, 2.7638380806292258, 1.462121704413045, 2.8689247513971026, 11.278670507092631, 26.68675937960225, 48.84267522442726, 53.431220746809444, 54.18445702522032, 59.5536954172196, 57.62740765848468, 54.04367531499555, 51.49569580631872, 54.249211434395086, 54.33606447712068, 53.79700529959894, 58.13890041843538, 53.74544966605402, 52.47480177110242, 56.678919715266076, 55.96986501447616, 57.278626580392164, 58.11992006917154, 56.05812226572345, 57.73779884461434, 51.75431728363038, 42.07859885308051, 43.64121229417863, 42.596865546318796, 42.44516003516413, 45.27578161608788, 53.48452183508105, 56.50189138227894, 56.1059477252345, 53.33438134962513, 46.97305786994196, 43.34634027173443, 41.12561195127426, 41.023391062213534, 40.872615152789706, 42.17139428661716, 42.307818243580485, 43.78564965340399, 39.587936939731726, 44.22198587848295, 51.566023903508345, 52.819268242005386, 53.53021352521835, 54.675733889302904, 55.36269387891216, 47.719049530644575, 48.42776690759967, 49.65635522719353, 53.39185976213025, 55.666387311873905, 51.18417724486321, 56.043758546152425, 55.10522165606099, 54.56467590024395, 52.670104426722375, 48.92534309817899, 41.21123729213592, 40.4284930229187, 38.395112791369044, 41.05857864502938, 40.23088009126725, 39.38609569303451, 39.76114488417103, 42.23898064705634, 49.117900094678326, 54.1288770398786, 53.841053516634055, 50.237454368222146, 48.78812290007069, 40.907398731477805, 39.50305292683263, 40.66398820569439, 41.47939405133648, 51.24982987680743, 51.557916364362164, 49.327527246167584, 49.08093567817442, 52.62418916148525, 53.14717054367066, 52.2295634208187, 51.389827112997736, 49.96604596414874, 51.23226158080563, 51.58809900283814, 49.57687624039189, 51.658642830387244, 52.290846532390965, 50.035707258409076, 50.904241608035186, 50.77585850992511, 48.22712198380501, 48.42686868483021, 36.21649503707886, 19.248478566446614, 5.406304299831391, 3.8988501698740072, 5.129782595942098, 10.383725858503773, 8.301095366477966, 12.525490003247416, 14.006009217231506, 15.381856060797169, 15.25379950000394, 11.212030418457525, 3.2721652427027306, 1.4153357955717272, 1.0111448649437198, 30.83379310946311, 39.69696706341159, 37.443094714995354, 46.17937411031416, 8.629240855093926, 0.23238166355557982, 0.1469720377316398, 0.18418649001227272, 0.10024859569966794, 0.1704972955368219, 0.20630157913171476, 0.13270539682238333, 0.2347719651316443, 0.08313608370841512, 0.17448970146717566, 0.2047710273895533, 0.14847965280134834, 0.1459349232215074, 0.13510034089126896, 0.16867414417286075, 0.16713715729213532, 0.20549358619797617, 0.24817485722803304, 0.0817628940867801, 0.13988785415647492], [0.05669293106503545, 0.040263849941472855, 0.040507056044354554, 0.010248551881241222, 0.019778166634721622, 0.009391123293748787, 0.011031127932872023, 0.08033158137432991, 0.009086009625705981, 0.03870660386558983, 0.04031984330785852, 0.029683070625328732, 0.01640523089125993, 0.015615726531963917, 0.03388497287467603, 0.07404284221270392, 0.044702888962121747, 0.039411048525043076, 0.026964027314416827, 0.016313407592655673, 0.08149733736870751, 0.0624026877865676, 0.04700208736223079, 0.021361999792016802, 0.13739740956694851, 0.05147454313813679, 0.3066779582971527, 10.409430130835503, 34.3955268398408, 29.122376711137836, 39.64562323785598, 14.975514200425918, 0.19308130707471602, 0.11331448571816569, 0.028333240939724832, 0.13352998322056187, 2.109278094383978, 3.5879390854989333, 8.843370887541003, 6.345090750725039, 3.91920825166087, 2.7414330119086854, 0.9839584269831259, 0.7802889267763784, 7.827672150827224, 28.769887032047397, 48.20166972375686, 53.40060272524434, 56.16450086716683, 51.74354253276702, 51.45996301404892, 52.264868674739716, 50.56919667028612, 51.483230513911096, 53.3787747352354, 52.81958595398934, 49.925123876140965, 50.23246903573313, 51.0214969419664, 52.52530620944116, 53.01069559589509, 54.51725444486065, 52.37649932984383, 55.646618566205426, 50.38522181972381, 40.687224326595185, 42.47571922117665, 41.11376639335386, 40.49458103795206, 41.39045038530904, 50.39438055407617, 52.41716646379041, 55.06917899654758, 48.51771077802105, 46.054081839899865, 41.38855588051581, 39.76368658004269, 36.86395283668272, 38.75640230794107, 38.057271203687115, 39.67573527366885, 39.73352355341758, 41.84140920639038, 47.63613846994216, 50.6049176954454, 49.398231890893754, 51.74659805913126, 52.6912538466915, 50.731578873049834, 47.77596312184488, 42.532044456851104, 54.48950367589151, 51.958653157757176, 50.42015837084863, 49.794481492811634, 50.648322643772254, 48.487732102794034, 48.62130449664209, 43.728453651551284, 41.22440861117455, 37.49561917397284, 35.47679093576247, 36.72988622419296, 34.932911165298954, 35.69942074437296, 36.292659621084894, 37.87781884593349, 40.960189911627005, 47.15638160705567, 51.49502115864908, 52.67503092365881, 50.57866134951192, 48.51531420984576, 39.69971272253221, 36.0326692365831, 37.643053224009854, 37.780826476312455, 47.38333386759604, 47.62371240123626, 48.800988274235884, 48.05012110740908, 46.08834374335505, 47.26616874817879, 48.243486112163914, 47.89286152009041, 48.14160646930818, 49.18218381943242, 47.98804567706201, 45.70169218124882, 47.34212152419552, 48.16930624746507, 50.098877030034224, 49.990180307819, 48.656578371601725, 48.1599513946041, 45.27658570197321, 26.32731729938138, 9.227496443256255, 1.0202864389265738, 2.4440131648894283, 2.4310220297305816, 2.695906551614885, 5.439574824225518, 7.421739197546437, 2.9283280670642857, 7.459121836769966, 6.601413228819448, 3.1866176138001108, 0.35739089512536604, 0.08787206223895473, 4.102849455610398, 33.6716926482416, 28.166857919385357, 38.776441697151434, 19.92248885093197, 0.7073284289048565, 0.02488003450355703, 0.018392468712502913, 0.03164787356170916, 0.013844993776611745, 0.04899144916224384, 0.041119562492014906, 0.05786558568117119, 0.02709544969782714, 0.06392609192839553, 0.04955225999677374, 0.04043600521981716, 0.020748786628246307, 0.03939871833990178, 0.06191370918625786, 0.03338496260825665, 0.030338596740377047, 0.053770481834128026, 0.09279156479263499, 0.02163034507013377, 0.04884212330404309, 0.08747381143151753, 0.024968973481126373, 0.04253401743969129, 0.028610015100228692, 0.06090265315686984, 0.04497466631413949, 0.036969660375747955, 0.04877147850610557, 0.03235618696518002, 0.04281313008358402, 0.006275843986640535, 0.06799147539441625, 0.06386406945004579, 0.04410098517133344, 0.023405501025638754, 0.028696994807931687, 0.01696910799270676, 0.032123309642737435, 0.08515190618533282, 0.01065679343282095, 0.0506326929485846, 0.0791820358004301, 0.02312043204813475, 0.043505635262737354, 0.0933823564780816, 0.062433055511886076, 0.3987008687709609, 16.760883946572584, 41.14309395513227, 30.947051548188735, 44.27657742654124, 15.660197254150146, 0.3577474324453262, 0.016496420252106844, 0.10386545766866016, 0.4865468533769731, 2.3387293950203927, 5.785043460707511, 5.674988127523854, 6.805255374600811, 7.8865763448899795, 8.925795574342052, 4.85060986011259, 2.7458809796840917, 10.138462012813939, 31.4213288599445, 49.30193378079323, 54.34585079070061, 59.08527812650127, 53.79034511504635, 52.63816064403903, 56.142457146798414, 53.96926403045655, 54.979580294701364, 55.24768606308968, 53.08440085380308, 51.94579562833233, 50.87970718260735, 51.46775284121114, 54.94669122080649, 55.36165837318667, 56.01887110740908, 54.87871654572026, 56.94295014104536, 52.43531919294789, 41.90870923380698, 43.7719056683202, 41.60907545397359, 41.00336736248386, 44.54431841450353, 51.461120113249756, 52.56307078946022, 56.11086637743058, 50.64906004936465, 46.86252940085627, 43.73288985221617, 40.54539534353441, 39.36142790702082, 39.21717097682338, 40.292261262093824, 42.11710476106213, 40.07062381313693, 42.94876098632813, 49.25973300010928, 52.84213173773981, 52.09929366265574, 53.72455912251627, 54.33105168804046, 51.052036516128055, 49.87516464725618, 43.90793738826629, 55.30740807133337, 54.00569892698719, 52.519312827817856, 51.462194842676965, 53.18104413247878, 51.46318327996039, 50.960315812018614, 46.23472267581571, 43.23084608201058, 39.13149464514948, 37.20020586444486, 37.342748718877, 37.31063627427624, 36.93909760444395, 38.33200577766665, 39.48160148436023, 42.658125123670025, 49.57703705756895, 53.60709198059575, 54.259962651037405, 50.38051105314686, 50.31230495822046, 41.20401228627851, 38.385044067136704, 39.215280394400324, 39.292904100110455, 49.86666879346294, 48.590290315689586, 48.71666123790126, 48.60406175736458, 48.315136048101614, 50.76103587304392, 50.46357508628599, 49.28673067400533, 49.66398423717868, 48.764263122312485, 48.93960483612553, 47.280175532064135, 48.25857939258699, 48.66383083405034, 49.33352062779088, 51.41451058849212, 49.14068122063914, 48.95947164104831, 47.348228654553814, 28.42419089809541, 11.240740206933792, 2.3357380974677304, 2.6597712261061517, 4.886874133540738, 5.6795723976627475, 7.226196296753423, 6.606825609360972, 6.467338771589342, 8.520764766200896, 5.667999444469329, 1.7761324418167916, 0.6861205411053474, 0.10609532511162181, 3.9865070533367897, 40.65223678465813, 29.27508438787153, 41.0880591792445, 25.93348779985982, 1.0887715124314832, 0.03603112605971194, 0.052250685966423446, 0.023055002393741763, 0.07376384831243947, 0.042085109068261045, 0.05494949114959567, 0.06129087587337821, 0.039400825081693555, 0.03812523506161186, 0.0517906999636081, 0.04977999112358497, 0.020007818727002993, 0.054584044227076155, 0.0873448558512234, 0.06276019420775195, 0.07610863660492244, 0.01869026624086884, 0.030198575020016685, 0.009849830887340491, 0.06656937105881591, 0.16945405232329525, 0.1362031244582707, 0.11046980973333122, 0.12371463490830314, 0.22252534486113057, 0.15833727384526886, 0.0745571323580319, 0.1354403613555816, 0.1379195750961381, 0.18359490159538486, 0.06347143406709356, 0.12716558521553395, 0.18160809852903892, 0.15834205423391637, 0.1598972586854812, 0.18107304740096294, 0.12754362662352864, 0.19871317180654696, 0.1327682619974498, 0.060547556082207354, 0.2159263247684125, 0.1302164537651885, 0.1543266656658342, 0.12631385632219816, 0.21127060926969976, 0.13759339017973793, 0.4374625888322631, 19.179264422385923, 49.64541965915311, 38.65254186814831, 50.17993280964513, 20.828619118659727, 0.5799365259947316, 0.26449516535766665, 0.21504834204191164, 0.5845086000138714, 5.566058024283379, 12.160473254419143, 20.207458849876158, 12.902505282432804, 9.917495289156514, 7.665896444551407, 2.6665858539842793, 1.5763102351657807, 10.131703769007038, 31.20318820399623, 49.27169230676467, 55.548327892057365, 61.29892656880041, 55.866404656440984, 54.98651112279585, 57.068516977371715, 55.43587353921706, 56.71067522418115, 56.0036091650686, 53.12906488295525, 51.56019918380245, 52.27780465156802, 53.81618961211174, 56.06821844654699, 56.41129247603878, 55.62584177140267, 55.644829965406856, 58.924021643977014, 54.50333787548927, 44.14331097756663, 45.56798642681491, 43.1126219226468, 43.24191108826668, 45.939783973078576, 53.258106939254276, 56.021828574519006, 58.90082474677794, 52.02578844562654, 49.82709992316462, 47.020079243567686, 43.81200013622161, 40.62541169504966, 41.553707276621175, 41.68985274530227, 44.71191736959642, 42.887677915634654, 45.6979267058834, 51.746335260329715, 54.13109317902596, 53.70988945807181, 53.59833725037114, 58.34037296233639, 52.56198821529266, 51.4162560432188, 47.32835008252052, 58.56987476348878, 55.299359367739775, 55.22231617281514, 53.8447876130381, 54.21222740604032, 53.244547305568574, 52.165546417236335, 49.42330760340537, 44.17336417782692, 41.41096438131025, 38.69209897133612, 39.120633602142334, 38.79306077957153, 38.38956263757522, 39.67812791947396, 42.166373652796594, 44.77503222803916, 51.75083814128753, 56.22176354931247, 57.50099751257128, 53.310866740442094, 52.16573861337478, 43.68369156314481, 39.98282155682964, 41.88129186630249, 41.585407872353834, 50.57120884618452, 51.47151047183622, 51.18212584526309, 48.81408114587107, 50.559233850048436, 51.819471774562714, 51.32402935335713, 51.84391990784676, 51.04351320574361, 51.83744799706244, 51.42492448129962, 48.116707263454316, 49.561371111100726, 50.568882880672334, 52.500575665504705, 52.82930166490617, 52.389937370054184, 50.65608893671344, 47.612188477669996, 29.5348374689779, 11.865778719225238, 2.688554313875014, 5.365372405898187, 7.614923773273346, 8.686806540335379, 13.017639594693339, 16.263240095107786, 11.15439413055297, 15.81754803657532, 14.593622434523798, 8.744846832367683, 1.9983397376152778, 0.1950873695914784, 5.5052509903907785, 42.74490364136235, 36.78745485121204, 50.696085345360544, 28.673612456167902, 1.207657449187771, 0.17831235763526734, 0.20014238543808463, 0.14919220650148007, 0.12906833311482785, 0.165183219397741, 0.12356814357542223, 0.11501584442392473, 0.1066855728746422, 0.1352882162938195, 0.09595861823688592, 0.11203564748528505, 0.11301257812808599, 0.17461829698614537, 0.18888481532133397, 0.08450715126649988, 0.14024734857582277, 0.0754918362344465, 0.2653842870025866, 0.1557262316947022, 0.10318016903775354], [0.030580395156697884, 0.06357493254566385, 0.03225161213307612, 0.03580273609728583, 0.03420174640092639, 0.018867826269518946, 0.013083273511109574, 0.02068477040607362, 0.031109769573254935, 0.030493731460263653, 0.055369280519024025, 0.053266032088187434, 0.022649280313823014, 0.020854573794490388, 0.019730805164022792, 0.06739444009238674, 0.062463013380165064, 0.026617163769720543, 0.0509145750003236, 0.11982625605718744, 0.03161108793480502, 0.022689430981934555, 0.037913480698461496, 0.04542794521717776, 0.024222614236115932, 0.025356816984112227, 0.05024863008950507, 1.19293152324615, 14.508219688169419, 26.39938496774243, 29.975823663896133, 29.081503652757217, 1.3774948519083763, 0.04616271163667402, 0.20754296332597735, 1.0993744144516608, 1.659697250973794, 4.547285129947047, 4.1984746340782415, 16.898947454267933, 42.40158642491987, 12.596959510157186, 4.332401021834343, 1.2695135945273985, 1.626258677532596, 12.184684084307763, 40.2317234008543, 53.67550596114128, 54.02949202445246, 52.78686554201188, 56.20547002361667, 53.2174398053077, 54.764555961855, 53.65591372213056, 54.54738217015421, 50.401507500679266, 53.49498279633061, 52.024478373988984, 53.537920982606956, 53.07113539788031, 54.56606049691477, 53.581926053570164, 53.16049875751619, 54.6156745572244, 45.12899083475913, 41.37252515362155, 41.706903288441325, 39.46926955253848, 39.370865129655414, 43.818236704795595, 53.66156585754887, 51.99672368264968, 52.43816683369299, 53.22150338080622, 48.841671097663145, 41.55962221084103, 40.051776824458955, 38.32226261015862, 38.85236309420678, 37.3702209995639, 38.48074597697104, 39.13224774022257, 47.265058717420025, 49.83736868827574, 50.444704563386985, 50.81769058781286, 51.9398061690792, 49.52000579526348, 49.48207255332701, 48.67875937492617, 44.564295045791134, 53.42130107264365, 49.73167257924234, 49.92113090330555, 47.92518577268047, 47.72667069588938, 46.141225138018214, 44.293729951304776, 41.59290352175313, 38.35953689390613, 36.29205949844853, 36.39443335994598, 36.82000267890192, 35.25625175045383, 36.23683644879249, 35.747473701354, 37.294884035664225, 39.46627286172683, 49.530902139602176, 51.05451153170679, 50.334207473262666, 49.16132465485604, 49.08408926379297, 44.758405300878714, 35.690803297104374, 36.31363253439627, 35.10691927325341, 45.421607494354255, 49.33008463151994, 49.41227397611065, 48.60120234950897, 48.48463343035791, 48.598084065221975, 47.83523013514858, 48.66135189610143, 44.59591719412035, 47.35179016667028, 47.498161254390595, 48.15231846224878, 49.13839447882868, 49.51747978887251, 47.79653987576885, 48.31215112440048, 48.52460630478398, 47.8639458071801, 40.68401190542406, 19.59300583408725, 4.432859786095158, 1.0374263385611198, 0.9691957901081732, 2.788423496869303, 4.227633533939239, 8.087496324892967, 4.6756255722815, 4.540645047541588, 4.738341819855475, 4.606645789838606, 1.2201297283172607, 0.0164569667240064, 0.17020517088953527, 19.400472371808945, 36.00934290116833, 28.16054290340793, 31.29561689592177, 5.589747669235353, 0.05255770719339771, 0.02358641651939721, 0.05303018042937883, 0.09804338862698886, 0.03165337981866493, 0.12332812056786592, 0.028986445808362578, 0.03539904223514661, 0.049175444329457904, 0.03705914710618315, 0.12345674673035262, 0.008603371360579566, 0.03707436927323861, 0.02736582893938307, 0.02026765851394063, 0.03372007627941428, 0.04492570946533834, 0.018118249455226526, 0.041979614930648, 0.04711349569861928, 0.09210601569183412, 0.02311104172540288, 0.044259281919127515, 0.023891558915737177, 0.043637789260115356, 0.027395727435847925, 0.0038634853028211625, 0.0329675174678766, 0.08718990690765843, 0.014704761805102952, 0.044289557713895075, 0.07520086837992554, 0.0746278805778392, 0.010973538230774144, 0.047767164050451213, 0.021906318668756756, 0.03288368446632259, 0.026738483368629412, 0.042931302976343906, 0.03226491141944163, 0.06322964139643215, 0.031205333296149492, 0.02475094868831577, 0.015198312035100836, 0.08178174751059664, 0.017942056893521262, 0.0554562391593091, 0.07572274279570387, 2.2221906290900324, 25.901671494207076, 29.245190043603223, 37.27376991702665, 31.017067816949663, 1.3137909024953842, 0.2797153712280335, 0.2861145036595483, 0.5709567497814856, 1.2765933501143611, 7.240060894720017, 8.224918525065146, 17.94992300771898, 33.34901102127568, 14.75845709923775, 9.793096338548969, 4.39222893407268, 2.6709058544328137, 14.976676202589466, 42.25102624585552, 56.86032541336552, 53.943709788783906, 55.10729658988215, 57.830543287338756, 55.33994413191273, 55.33444104656097, 54.712670849215606, 55.147112569501324, 51.65426154290476, 53.018622706013346, 53.36274008597098, 55.06999484954342, 54.05867053616432, 56.029281077846406, 56.00205198411019, 54.55805886176325, 56.250494910824685, 46.22877636263448, 43.9802658942438, 43.71355256726665, 41.53601738714403, 41.6835573411757, 46.22004124426073, 54.32739211666969, 53.74426118789181, 55.38709102138397, 53.03735202358615, 49.66964029496717, 43.49659058355516, 41.34075395522579, 39.59813117980957, 40.36591552918957, 39.70607872932188, 40.10348150807042, 39.99248235456405, 48.38411877232213, 53.027130326917096, 52.25113645676644, 52.46667854247555, 52.55364533393614, 51.09746932983399, 50.87925218766736, 49.3835465369686, 45.154329346072295, 54.824701586077296, 52.386599433037546, 51.543689927747174, 51.39416917677849, 50.57134612914055, 48.77922696451987, 45.52599745412027, 43.472730805796964, 39.40630374416229, 37.6738634417134, 38.30896185290429, 38.06269584163543, 38.591450952714496, 37.7306358275875, 37.88418877509333, 38.761626905010594, 41.07080467285649, 50.135617871438306, 51.512573765170195, 52.190633896858465, 52.19232051603256, 51.68362048364455, 47.70365422771823, 36.677353920475134, 37.56517456423852, 37.858269752994666, 47.504205626826135, 51.191453241532855, 51.64160797672888, 49.3551681887719, 48.730585652012984, 48.54315127095869, 49.97763264563776, 49.06813698430216, 47.592129476608775, 49.036550137304495, 49.04311226260278, 48.31945065529116, 49.65352327592912, 50.285287672473544, 49.13484473382273, 49.10974940946026, 49.103461850074034, 48.706678805812714, 42.654312579862534, 21.63550361510246, 5.6190909204944495, 1.7302644901698636, 2.8976014448750407, 3.6835198921542016, 5.072319382621396, 7.223904161683976, 7.251368597630532, 6.200310674405867, 7.410193210647953, 3.1172750121162784, 0.2716046451560913, 0.0754232177390687, 0.006995807672219892, 17.808288181981734, 40.68077987240207, 28.243669694469823, 39.043574717737016, 8.823310905887235, 0.2453511643914446, 0.07771123891636249, 0.12287473441251826, 0.07909646377928796, 0.09251149070839729, 0.08368965118162094, 0.03694550562349539, 0.026895328379806974, 0.028571097833675244, 0.08493492710253886, 0.08366434729748196, 0.09459606957651916, 0.024778003083361734, 0.04136666415199157, 0.020361215086473573, 0.08308046572511235, 0.03220938153625016, 0.10531040674616253, 0.05403623007418168, 0.027711943633133368, 0.14103782873961235, 0.12050264274641392, 0.17624082524449597, 0.10606655851006509, 0.1474203983502042, 0.13664111224634035, 0.1980610164783655, 0.09665693802338454, 0.15639473533918782, 0.10703949783478053, 0.22663600412347626, 0.2038690048239885, 0.2118313703085146, 0.10541303954537838, 0.1104722765364474, 0.11001416361860691, 0.1298751156296461, 0.11698205504686603, 0.10298609598389558, 0.07701135631049834, 0.19243822222755802, 0.10348471197029276, 0.08233117810901135, 0.12478623103590743, 0.17993644871298345, 0.15654341768353217, 0.15869609410724334, 0.29683118505823997, 3.6926342546939854, 30.882918834686283, 36.92738540710942, 39.74121532132549, 40.07058066706504, 2.493207531590616, 0.5053929227494425, 0.5444936213954803, 2.84045692413084, 5.348912669766334, 11.51493545501463, 9.980120831920255, 25.05183900556257, 52.92113219538043, 18.469678240437663, 9.179920054251149, 2.945348211834508, 2.4869408097959336, 13.781779081590715, 43.238090699718846, 56.89448141282605, 57.02849703450357, 55.79104808069045, 60.591021122470984, 56.13028603215372, 57.02705752465033, 53.406368609397646, 56.077808641618304, 53.786054042077836, 56.025394009005645, 54.71052139036117, 55.87178222594723, 55.366023971188454, 57.42957899647375, 57.28627520222818, 57.19508794046218, 58.74974289248067, 47.19580142728744, 46.16587331218105, 46.692577023659986, 43.30890124843967, 43.68475060309134, 48.22983626396426, 56.948037455158854, 55.52102819565804, 56.696354650682025, 55.69871548683413, 51.92546206135904, 45.965738296508796, 43.83161590945336, 41.12526678269909, 42.7039501743932, 41.62700853040142, 42.24225190378005, 43.249496952179946, 50.275587651037405, 53.674697952885786, 53.688532152483546, 53.846121218896684, 55.53912993400328, 53.34182208584201, 52.28218593905049, 49.61158921641689, 49.523743814037694, 57.02630835194742, 53.25852663286271, 53.19376045657743, 53.57155530683456, 52.68826107825003, 49.080174738360995, 49.25882693259947, 45.29467175083776, 42.31980892919725, 40.68804017959103, 39.699897073930316, 40.350751646103404, 39.21722589000579, 39.91403102874756, 38.80445134255194, 41.21268464672951, 43.31147432327271, 53.46740853401923, 53.924348969613355, 52.99670450149044, 53.44859292430263, 54.24885057633924, 48.616715323540475, 39.265427897053385, 39.98607320170249, 38.50460183235907, 48.894885893790956, 52.41928846605363, 53.00523173424506, 50.0092940176687, 49.446222089952045, 52.137415178360484, 52.310297566075484, 51.16390643581268, 48.16245386677404, 51.07131888789516, 51.135920324633204, 49.73539883090604, 51.43453821059197, 52.793313918575166, 50.636237821271344, 51.28202861355197, 51.96861205562469, 49.12369735779301, 44.2302660019167, 21.62636645378605, 5.760215838109294, 2.841735616807015, 3.637159683050648, 5.992227465875688, 8.937423440717883, 15.34996719129624, 11.818126824594314, 12.78167764986715, 13.710188961798146, 11.758723508927131, 2.700913702287982, 0.14934330968366516, 0.2243602326920917, 24.77633172465909, 44.58133774418985, 37.802842740089666, 45.77212226006293, 10.635316487281553, 0.33551841072978517, 0.2894240647794739, 0.13793195507699443, 0.27448357293202036, 0.12937358850913663, 0.31898338347673416, 0.13109904834099356, 0.14026421783191545, 0.07709354988389439, 0.21143617619189525, 0.2433060620340609, 0.250663647067643, 0.12149217553556928, 0.15246747752591489, 0.1086807262993628, 0.18472817546177298, 0.18006680623417903, 0.2135405277893428, 0.18129198000796382, 0.09600718055040607, 0.23480925829179827], [0.04998831724327418, 0.02029966758263688, 0.04992432591895904, 0.011171582492909605, 0.19132529565643883, 0.02811884931889513, 0.040193411987274885, 0.0674292434667868, 0.05621535951391824, 0.033713376840516444, 0.061213248184010874, 0.02342129584341761, 0.049578387425431324, 0.02419117973336289, 0.07804265621328547, 0.020890826990287152, 0.08848821143469504, 0.019731354832108465, 0.04488776513044873, 0.025155272657772707, 0.06480523144766208, 0.05560400602858394, 0.0329361078629811, 0.01673247492421539, 0.07080139397012611, 0.0340326554742792, 0.06301429408091692, 0.2201435468610256, 5.3240507264291095, 27.142211275715983, 22.844721309600338, 43.00859674330681, 9.360411840100443, 0.07613659881415867, 0.3115110844373703, 0.10541716875929026, 0.34630649152301973, 4.330074566025888, 6.091547271897716, 13.764631459789893, 11.90479257414418, 16.396941927171525, 15.561319205068774, 5.936136101522754, 1.0855945151659752, 3.963613649529796, 26.267371716037875, 50.69213551859702, 56.251400978334495, 50.958044759688846, 53.444788225235484, 53.132120409319484, 55.15567902595767, 54.24639125024119, 53.995124217002626, 52.537124310770345, 55.8070082049216, 53.91947738585934, 54.491033400258715, 52.87857055664063, 53.23968748892508, 51.17293965431952, 49.08617204235446, 44.93434321495795, 41.89520059093353, 39.99085064857237, 39.408213938436205, 39.73359023371051, 39.90474285617952, 47.75537067844022, 54.661523142168605, 53.172234489071755, 53.08338495992845, 52.2856846932442, 49.92993270197223, 45.63193675010435, 40.83864742709745, 40.37329742985387, 40.004747606092884, 39.847480174033876, 37.87195490252587, 42.082364328445934, 49.14328959680373, 53.47404126198062, 53.13108098122382, 51.21596021036948, 52.879370720155784, 50.8742315538468, 49.646572835983775, 48.32389077832622, 45.569422014297984, 52.26741037061138, 49.31266146321451, 47.57500440843644, 45.16425294260825, 44.739256289697465, 41.26724873819659, 42.05174238451066, 39.94720643566501, 36.06190658384754, 37.305741156301195, 36.35777488831551, 34.93511945970597, 36.48330250094014, 36.29517778273552, 37.01500723438878, 35.75791505075271, 40.08599165947207, 48.428857326507575, 51.083152678705034, 46.23634261469687, 50.592373955634336, 48.9822566893793, 48.430928337958555, 40.33729791641235, 35.401289232315555, 36.73644442712107, 39.12285366365987, 47.18561895432011, 46.768274845615515, 49.11319717284172, 48.90036544492168, 46.78392118023288, 48.63849232273717, 48.87365802641838, 47.72175596606347, 45.2636654146256, 45.200719218100275, 50.13471964866885, 48.51431400545182, 46.34043055195963, 47.95108910529844, 45.96724840902513, 47.78223891412058, 48.69297012206047, 34.407847004552046, 13.015518573022659, 2.570323045215299, 1.180604249238968, 2.629644726553271, 4.440375537641587, 4.115289497760035, 4.553586907925145, 4.668989902542484, 5.461578340299669, 6.095267640006158, 2.410712242126465, 0.07329755357556766, 0.024222328868364135, 3.0682355790368976, 42.21048855012463, 31.91736944260136, 33.46963174881474, 23.457774039237734, 0.7659560345834302, 0.039124826585213025, 0.0808289256547728, 0.05740817756422105, 0.049323544446979804, 0.06172328271091946, 0.026001638935638532, 0.01791277126739583, 0.07578419070811042, 0.036423749951345306, 0.08837697546808951, 0.045923561969351386, 0.06672081898056692, 0.044570907334526705, 0.019182046807761637, 0.02663151642698194, 0.11910903688159682, 0.021052885229789445, 0.05196575871518543, 0.05988424651384835, 0.04175919611307402, 0.056277971879969683, 0.02400271252789084, 0.02887102125603105, 0.038722737677275174, 0.07126802578568459, 0.05923037514871648, 0.010908750175017743, 0.004152496281500545, 0.011049886553307936, 0.029016344304827434, 0.07536327135899375, 0.021123658347454284, 0.0758404751879073, 0.037893799899686734, 0.041825359296654506, 0.025998452009873527, 0.07320649636488769, 0.04959055673210852, 0.10848228654433643, 0.013012790549246055, 0.02304581125387021, 0.0241374175980567, 0.025448860532994715, 0.0695541492032428, 0.04703967546623561, 0.013193958852019523, 0.14684051575679935, 0.06493082390196862, 0.41193611018600007, 10.330037436177655, 30.716843720405336, 27.42916795515245, 46.007138913677586, 9.6489002050892, 0.1532570383841953, 0.1525626256461105, 0.3309642938115905, 0.1156735615504365, 5.380050405379265, 8.083764189674008, 19.800087367334676, 15.931099672471325, 12.300794086148663, 13.721777604472253, 6.489375627809956, 1.502222913888193, 4.447413250323265, 28.093737094633042, 50.94182968139649, 57.298285499695815, 54.24107251628753, 55.11467456817628, 53.926019899306766, 55.420470391550374, 55.3534213958248, 55.18882305391374, 54.299900224131925, 57.880235795051824, 55.62472781827373, 55.53496437688028, 53.387419639095185, 55.62220181188276, 53.6366823411757, 52.08271380393736, 48.425338960463, 42.7346662552126, 41.481661181296076, 40.79297142644083, 41.148648031296275, 40.960440943318034, 49.5777391618298, 55.868452133670935, 54.33663714316584, 55.10836347456902, 53.17479187442411, 51.72297754595357, 47.442236100473714, 42.944391465956166, 42.03782189276911, 40.444260951011415, 40.01851120302754, 40.13960653735746, 42.3608486883102, 51.1604037592488, 54.35929667565131, 54.59464280836044, 52.24252685423821, 54.88434514691753, 51.378565988233014, 49.256481355236424, 48.54400242528608, 47.49011647316718, 53.83250667202858, 51.34455511646887, 49.48691668048982, 48.39098292012369, 46.061891278912945, 45.93201768013739, 44.42618446965372, 41.28584861755371, 39.334583205561486, 38.56104866150887, 38.28318011376166, 37.21304378201885, 38.12945850433842, 37.923506613700624, 38.49730230146839, 38.19962186198081, 41.82864973621984, 50.931251049041755, 52.87788414186048, 48.01319983697707, 50.2240006385311, 51.491255683283654, 50.914761404837336, 39.96597497693954, 38.0169649277964, 39.082245365265884, 41.40408846639818, 49.01292177938646, 48.20926735478063, 51.291952210087935, 48.62187716268724, 48.91749835783436, 49.901040523282944, 50.93598927220991, 47.99391354283979, 47.14381433302357, 47.52053837622366, 50.99243217898954, 49.457330242280044, 48.2573595354634, 48.97435311348208, 47.67913941414126, 48.90983012414748, 50.49442060532109, 35.38206961847121, 14.974538510845555, 2.4648845868725933, 2.171604801570216, 3.304907963160546, 4.0849771759202405, 5.651912823800118, 7.150697044787869, 5.952952773340288, 6.122489379298303, 4.8085037066090495, 0.9949081523283836, 0.3471179012089007, 0.03821245800223082, 2.5508979972331756, 43.210186958312995, 35.801190560863866, 36.505208938352524, 31.028085754763698, 1.2725008471358208, 0.051580665467847744, 0.07877141267301575, 0.04043150062282239, 0.04008755012745819, 0.08688913312770667, 0.049788521512621836, 0.04105213909379898, 0.028129974830775496, 0.056935528128017346, 0.07324097032148032, 0.0426316668369597, 0.006307777882959213, 0.11416994545969272, 0.012791124923575311, 0.06551689648580167, 0.09247903156304553, 0.011959408162041538, 0.01875699632951329, 0.006671209515432918, 0.05321966844700998, 0.05461509760108687, 0.10301553674282567, 0.06730635530285298, 0.19349652672967604, 0.08596677858863147, 0.2958177733084848, 0.10780999842550486, 0.12117441758633622, 0.2489421249277169, 0.19249621508342607, 0.16323547149377485, 0.17878311866473767, 0.10631842523693077, 0.12880011041077877, 0.16445684547145523, 0.13835239945159805, 0.19280922328752859, 0.13802736366708435, 0.2632822949559458, 0.15463507734239101, 0.10451628766473263, 0.13845350773584458, 0.17369117738018114, 0.2368828591199652, 0.07668982920867783, 0.152371532674278, 0.26848317394333504, 0.14328992805413662, 0.29446051065479556, 15.09894040323073, 42.53398210771623, 30.684470438188125, 51.380558552280554, 13.749438158927427, 0.3785290076367317, 2.1998041916278104, 1.6840172943569, 3.2601135152001537, 11.862993836402895, 18.267748740411577, 20.52206039428711, 14.547487516557018, 27.06624673258874, 24.78403525967752, 11.35370348730395, 2.932633358624674, 4.526955975640205, 28.381678288982762, 54.984589161411414, 61.98791834615893, 55.48102394227059, 57.63995924303609, 57.10885463222381, 58.0066067172635, 56.99533731706681, 57.09830345646028, 56.211588921085486, 60.121513412844756, 57.22689836255966, 57.91854950689501, 56.282689725199056, 58.5625595431174, 54.67224690221972, 53.82172015405471, 49.23687342674502, 44.97792466994255, 44.00721257732761, 42.923602904042895, 44.352812613210375, 43.241334499851355, 52.35189822412307, 58.625988191173924, 57.06499468895697, 56.877399490725615, 54.66397070115613, 55.205285241526944, 49.058193775915335, 44.37935136979626, 43.29224686468802, 44.266312583800286, 43.40146133976598, 41.09932814874957, 46.31073820975519, 52.642953780389604, 57.61898632972472, 56.03385456146733, 52.784327768510394, 56.67077687478835, 52.33363959097093, 50.282059561821725, 50.10277586598551, 50.20405930857505, 56.036521773184504, 54.0177406034162, 51.00597612319454, 49.94408853592412, 48.945555071676935, 47.414297057736306, 46.80996964054723, 43.656199670607045, 40.46508873662641, 40.70709505388814, 40.240984116831136, 38.95354847754202, 39.96013456775297, 40.05349090022426, 40.0553265694649, 38.97989896035964, 43.51462956397764, 53.147449031952895, 54.18037383787094, 48.01634950022544, 52.486404142072125, 52.37112176033759, 52.57450449851252, 45.09700390600389, 39.94429995936733, 41.24314969585788, 42.7606088115323, 51.27259923565773, 49.6544607224003, 52.143283044138265, 49.56494831269788, 47.206725228217344, 52.132673032822154, 53.10693487044304, 50.41201160800073, 49.15577450106221, 49.43781645067277, 54.66995231566891, 52.63104938691663, 49.18423129666237, 52.2783027925799, 49.360310416067804, 50.87749496583016, 53.4508639766324, 37.814327439954205, 15.149468375790505, 3.7939245614313313, 2.9324997528906795, 6.936268912207696, 9.5268468318447, 10.706401601914438, 11.053727480673022, 12.621257612782141, 14.213775204073999, 14.14022291860273, 5.060869493792135, 1.61967228256887, 0.16185703416985853, 4.080938115235298, 48.90495461802329, 40.95296098339943, 44.30108831774804, 38.22687841230823, 1.6251357764967027, 0.19188506078095208, 0.30198018457139697, 0.11451521362628668, 0.11963623560844891, 0.19250730803656965, 0.16119016995353086, 0.11898680755327787, 0.17768085603752445, 0.12877338926397985, 0.28604243010763203, 0.17987791959556843, 0.14828713490597664, 0.2714167084665068, 0.0748410905080457, 0.18574227669066, 0.4048201646054945, 0.12246326858838721, 0.1768708865969412, 0.20753110428490948, 0.11536310441912183, 0.14924016360554004], [0.0369266981649543, 0.018577528741931724, 0.026951787144606634, 0.12870704604973718, 0.04241020230936908, 0.02822840563772667, 0.03213250844348823, 0.02652557412793319, 0.03444439325962336, 0.06161335675466446, 0.027759452575757623, 0.047905136485614126, 0.009798899446914514, 0.07275504075110921, 0.04829134056044202, 0.010208942262726206, 0.10497150477021934, 0.06596160286496724, 0.048727010932540706, 0.02660125020831343, 0.030664459899848992, 0.053648700667244774, 0.04200362029575533, 0.08922157208285025, 0.01781619439322141, 0.02802060045782597, 0.07586495169708807, 0.06934116909941358, 2.6136056646223995, 28.361913465684463, 26.01301581628861, 46.04208723191292, 23.38532982334014, 0.6940907972954935, 0.25686990920334096, 0.030775852914478992, 0.4851527265723675, 4.078284631813727, 7.817839749397771, 5.250101300977892, 4.735523596886666, 6.566017760384468, 10.491227238408982, 5.082099322349795, 1.4145981448311962, 1.0170901975324078, 14.206322700746599, 44.36893747698876, 53.16624502981863, 55.588426282328946, 51.00931013784101, 53.293980936850275, 52.62370278758388, 53.70413141865885, 53.598768711090095, 55.46689556490991, 53.501070314838046, 52.82307294107253, 50.39309009428948, 48.36652301972913, 47.052097551284305, 45.13111283702236, 41.300475135926284, 40.57780981063843, 40.17267604028025, 40.19002468355241, 38.23595869925715, 39.27580256615916, 39.38215763338151, 49.961849028064364, 55.59574150270032, 54.157290689406864, 51.5211872900686, 54.56577808626237, 48.7865774862228, 47.00971634157243, 41.0148952084203, 41.042163525858236, 38.09637331193493, 40.059205793565326, 38.20085348621492, 43.306606661888864, 51.09691627563969, 52.01018133471089, 51.990279228456565, 51.107306634226155, 50.29636444584016, 51.33157599356867, 49.50891725478634, 48.08769741365987, 45.826094073633996, 52.75592196372248, 49.63490378472113, 47.94628420183736, 42.74859066932432, 41.569537962636645, 39.318807432728434, 40.48907403023013, 39.13684868043469, 35.780488291094386, 35.00545540163594, 38.054419640571844, 37.41062141233875, 37.21969219946092, 34.296820394454464, 36.26612478686918, 36.8376729565282, 40.26580095291138, 46.36920505954374, 51.468662831091116, 48.247137838794345, 48.52603012515653, 50.1464436131139, 47.62093144078409, 45.744853942624985, 34.581156930615826, 37.51283837902931, 35.755640076052764, 42.96981234704295, 46.821348436417125, 49.49118029686713, 49.82080451903805, 47.47863961804298, 48.680234186110965, 48.34589527499292, 47.32973467919135, 45.323540395306004, 44.24134277528332, 43.17960423807944, 42.89316531150572, 43.282374258964296, 44.88230512988183, 47.72963600773966, 50.39482378190564, 46.99891413411787, 25.718739994110603, 9.365327550518899, 1.0097546911528035, 1.4831632592024342, 2.581412075988708, 2.1064444270826157, 2.6921736809515187, 6.318111708087306, 5.171057697265379, 3.751881656146819, 3.485487512042446, 0.39954620083012893, 0.03978298804272087, 0.17362284233733533, 11.032906559205825, 53.04674217777868, 31.01373576348828, 31.173595882231194, 10.315142235448285, 0.26292790268217364, 0.10967359157098878, 0.07128530106837712, 0.033229745533918185, 0.0330508831557968, 0.045520373725242196, 0.028871603482853503, 0.026590664788419684, 0.030882046107322942, 0.1152496467975359, 0.026334073214280992, 0.0470974806305622, 0.027778853752440023, 0.07786703055664417, 0.0747540935633644, 0.054243200218244914, 0.007488434766269019, 0.14422630200222616, 0.028251118229461775, 0.02958771757661335, 0.048563091099382415, 0.08693058614528949, 0.08050064931833938, 0.028229125760375496, 0.05082364802459075, 0.04246253377547668, 0.054145282690203, 0.04295192989370516, 0.09021584695625691, 0.004474502188273736, 0.05121989934254558, 0.04832689470100788, 0.024129136187595226, 0.028678972589512988, 0.04106600911566808, 0.09640023728171665, 0.047490127504833286, 0.03139392690612905, 0.04342985384526753, 0.044953686996333064, 0.04426300510643952, 0.046573449677277, 0.05613097492905875, 0.07407455825276914, 0.04096790772652434, 0.06391793692244158, 0.014214219427817773, 0.06346994402608083, 0.09317067106284442, 0.017083450445845243, 4.306185860787669, 37.013504966612786, 25.097640522064705, 53.37594670634116, 25.160469047484863, 0.5890738098852096, 0.09862606744131736, 0.2627229894841871, 0.12879457925596546, 3.289668574448555, 7.919649770182948, 7.978844219638456, 6.070620446435868, 9.543537497520447, 9.50205941354075, 7.977443443190667, 2.41241920859583, 1.0621498957757027, 17.855950863130634, 43.41951600966915, 55.88037613899478, 55.855916238600216, 55.20375943952992, 54.94922114956764, 55.6518510080153, 55.45012743242326, 56.60128424244543, 57.68153636686264, 57.488528297793486, 53.76920353981757, 52.49450383647796, 50.413631546881895, 50.67392787625713, 47.50710033601331, 43.72008723597373, 42.02828661088021, 41.849422608652425, 41.43950746905419, 39.712060343834665, 42.04411729689568, 42.797486935892415, 51.18013328121555, 57.02986201932354, 56.02396626626292, 53.50260003920525, 54.76509724893878, 50.13405676810972, 47.562111577680035, 43.0347393405053, 40.28507155756797, 40.28897039351925, 40.431368120255016, 38.3219252863238, 45.66481797925888, 53.43896350552959, 54.113344453996234, 53.93435493592293, 51.71351286672777, 53.21321149026194, 51.972522658686486, 50.453855452998994, 49.811504579359486, 48.354763753952525, 53.66699049549719, 52.478288758185606, 50.29087704996909, 44.35191046807074, 43.682279509882775, 43.31727943112774, 40.766915121386134, 41.42783449542138, 37.947644879741055, 38.324517973007694, 38.527504551795225, 39.51224696251654, 38.13138438809303, 36.393299794966175, 38.58829344472578, 39.94439017388129, 41.86357059786397, 49.73943887218353, 52.97166801268055, 49.698971779115745, 48.21902621176935, 51.75021056205996, 49.53493041376914, 46.909225217757694, 35.87882995605469, 40.05056873444588, 37.1403818745767, 45.0737952416943, 48.76219995560185, 51.08173278070266, 50.817972998465265, 48.04278235281668, 48.978036219073886, 50.70990777784779, 49.087631164058564, 46.16109586531117, 46.687321047629084, 45.49973718581661, 44.3299412727356, 45.11115581758561, 44.77962924588112, 48.16377178315194, 51.35357656786519, 48.0845908964834, 27.758305803422008, 9.191094886872078, 1.7921287253979714, 2.237215022886953, 3.08364117818494, 5.208846792098015, 5.798480030029051, 7.234850516242366, 6.272561223276201, 5.91773332126679, 3.244935658670241, 0.28911165412395234, 0.05208629498919172, 0.03815018654530568, 12.033268828545848, 59.83094423047958, 30.854565981895696, 37.436991507007235, 16.145915139106013, 0.23033273075857472, 0.027205496312930223, 0.09527414932005829, 0.1361263624482578, 0.02619664661676413, 0.020990236474561597, 0.06309186048325031, 0.02313223937826772, 0.05525387320367079, 0.023750445520084713, 0.04067436581657779, 0.015727579199348488, 0.042993930664153836, 0.047931440114494295, 0.07120756612670037, 0.0957893587708954, 0.01962039274193587, 0.033323411273980336, 0.10060475763654518, 0.052281023048224955, 0.03895663581187687, 0.01497782714244339, 0.11618806620038326, 0.12180757393399555, 0.1242888254684306, 0.16407842868037764, 0.2659006609070686, 0.09392935091689711, 0.15321568495804264, 0.13156201059539474, 0.14072829857468605, 0.21004283079697242, 0.13613321127430086, 0.13507755743640085, 0.10059417030143161, 0.1276582716813972, 0.19236325286328795, 0.120583196891652, 0.2291409124530131, 0.10753093557732721, 0.10660069799351116, 0.16758033915633158, 0.12400422380456042, 0.19072436096687473, 0.21268266253173354, 0.25038898922502995, 0.10887208740196883, 0.22848702576612273, 0.14625893244820257, 0.15256132329663924, 5.947500188504496, 44.251944941859094, 33.905403152588875, 56.85072345118369, 30.78371228710298, 1.2235304232566588, 0.7498148684540104, 0.3375275835635201, 1.0534995986569313, 10.33239576124376, 17.93773816477868, 13.171210192864942, 11.227062902142926, 17.805322870131462, 19.620307491671657, 10.4433213703094, 2.032595634941132, 1.6173734059256892, 16.671667675818167, 46.73625261552873, 56.945362398701334, 59.64460419070337, 54.73623252684071, 57.21093431595833, 57.0726982239754, 59.08786296844483, 58.51609514605615, 58.9214877928457, 59.217983676541245, 57.060013278838134, 55.819712761909734, 52.67654495854532, 51.33116414470058, 49.266012714755156, 44.784881299541844, 44.270336935597086, 44.27739327953708, 43.094182860466745, 42.37142339829476, 43.7551296910932, 43.79160381132557, 54.67624379742531, 60.38479466592113, 57.15911588361187, 54.57678425696589, 57.28120357759538, 51.64504005062965, 50.096503996079974, 44.681954383850105, 43.922422701312655, 41.318623942713586, 42.92268899179275, 39.659681012553555, 46.71811557585194, 54.21211757967549, 55.06955162171395, 54.74664249727803, 55.63989562373008, 53.56609928992487, 54.385239231971006, 49.91614557081654, 49.31968250582295, 50.519480628352014, 56.71617830953291, 55.53260311003655, 52.65251651886971, 47.3803646333756, 44.46962864168229, 43.042085939838046, 43.98218785562823, 44.65406633192494, 39.562174812439956, 38.523209556456536, 41.30882193965297, 41.174696491610625, 39.83368127576767, 37.64277473572762, 41.19242168241932, 41.57688063959922, 43.32952507080571, 51.46170062403525, 56.66301842658751, 50.656536086913086, 49.24981332594349, 52.587134530467374, 52.72678267571234, 49.707279359140706, 39.19020468188871, 41.6664558072244, 40.061225814204064, 47.42107491339407, 51.658980154222064, 52.387564336099935, 52.95919879790276, 50.194884884742, 49.964633910886704, 52.124290927763916, 51.37439258636967, 48.29783055090135, 48.95374498059673, 47.41981583256876, 46.55659237215596, 47.212522491332024, 48.07662456266342, 51.77237587590372, 55.25763319384668, 51.00541130188973, 28.66118246509183, 10.967471618806163, 2.4861997269815017, 5.04511627458757, 7.267349804601363, 6.076010273348901, 8.75637467830412, 13.940414440247322, 14.076570695446385, 11.93987915592809, 8.920000272412455, 2.1500744213981013, 0.1514914202233476, 0.3225572755740535, 15.488904406947476, 62.57597577187323, 37.68653269736998, 43.45852398103283, 19.268619937281457, 0.4314605657371783, 0.15671379563789214, 0.22256288316942033, 0.2821057494128904, 0.16492889352863835, 0.17256153477055414, 0.3394720679329288, 0.07971189285237944, 0.24345512742236738, 0.154030327534964, 0.09214196819812061, 0.12559140476608469, 0.0983778932582467, 0.1799288184772576, 0.2140784440862556, 0.2338860304124894, 0.06354096037666164, 0.11594806617546467, 0.16016742725285793, 0.16964287767487188, 0.2694709677129023, 0.13817515734943653], [0.006518099661691175, 0.028229037660264203, 0.027179152464434028, 0.0478733093627999, 0.030691916491055203, 0.008507769333288796, 0.06426708532437202, 0.009950976518373336, 0.01358933778735058, 0.009950880757382801, 0.03235697603574203, 0.04756861704311544, 0.03670251785567211, 0.015582090484038478, 0.004847663137385803, 0.026307930463864922, 0.03999148653219304, 0.048041898501856674, 0.012065359079579433, 0.06405444612966911, 0.05103075989491997, 0.012311203397750374, 0.008080305678078966, 0.01141989169897692, 0.04070574477795632, 0.046237673340064865, 0.06499598734080791, 0.03976765479291639, 0.5320409541168521, 26.536593398740216, 33.60680487848098, 35.44687894082839, 40.999876453030495, 5.460842405596088, 0.1476013176744023, 0.07012325293955303, 0.12701346313640957, 1.637160292556209, 3.768797612959339, 4.746328255822582, 5.778817678651502, 5.054686367511749, 8.589783772345513, 5.986908731922027, 1.7004932102657135, 0.2430096472943983, 7.643941958104411, 34.758710861206055, 55.53767473466935, 55.829852088805175, 53.84796473287768, 50.56821215537287, 51.44856852869834, 49.270241029800914, 48.75890516465711, 48.4013811234505, 48.50820295272335, 45.64702218578708, 42.609738765224336, 42.13163714255057, 40.26804062627977, 39.140865187491144, 41.20055275578653, 39.931952338064875, 40.9790055213436, 37.03337569390574, 40.16568245426301, 39.75538684475807, 40.48934467377202, 49.05251418390582, 55.116267050466234, 54.79359719061083, 54.24324158699282, 52.1909123851407, 51.303574192908506, 46.42232179641724, 41.06023780761227, 39.297822752306544, 38.38497738684378, 38.1620063320283, 37.30013216695478, 42.44372837005123, 52.41559751572148, 53.9992505504239, 54.13237579407231, 51.30385660356092, 52.12052545239849, 49.45742437916417, 52.35359268803751, 47.388480017262125, 46.33938720149379, 53.34481485428349, 49.944033622741706, 47.27738672687162, 46.48504834021292, 43.91409550943683, 41.55506833907097, 40.085324856542776, 36.2387897891383, 36.26071976077172, 36.960250946783255, 37.72687427459225, 36.87730850711946, 35.7064417869814, 36.86401951697565, 35.68003639098137, 38.36816218591506, 38.050744379720385, 46.649077938449004, 49.91034830770185, 52.659333598229196, 47.46140472350582, 50.94226114211544, 50.03188686986124, 47.45350899234895, 42.37302764769524, 34.8499491137843, 35.75648338563981, 37.01829418059319, 41.083030700683594, 47.8319118099828, 47.5459514125701, 48.51174877535913, 48.59317325776624, 47.07551410121303, 50.4475639712426, 47.255091974812174, 44.85989662908739, 43.55408860791115, 40.65965398665398, 42.63112744977398, 45.97377131062169, 49.612703169545824, 48.45427428522418, 39.53115278674711, 18.918546438217163, 4.909255177743973, 0.6064617994331545, 1.1686981397290384, 1.9644910313429373, 4.3737952651516085, 3.875747409559066, 4.806742072105408, 3.984836123643383, 4.350934220898536, 1.924186839211372, 0.3680803344374703, 0.03670997189117536, 1.2312209654238917, 29.13165900015062, 32.615657237268266, 32.57373886723673, 30.29495554585611, 2.831331039628675, 0.19167084727556477, 0.06536499657217534, 0.058315344410197395, 0.037689089715000124, 0.0314453735406841, 0.02102160777506088, 0.03047282300559023, 0.059052018388625116, 0.0450783831277682, 0.021734647941024556, 0.00868564058515814, 0.030520284067719217, 0.08262176291957017, 0.1057727944346205, 0.04924431946429034, 0.03650150404522016, 0.03369608240562581, 0.049767396638109807, 0.0879198967689468, 0.05425464557183366, 0.054578716085562785, 0.03263424240773724, 0.056207947613250826, 0.03826161020345265, 0.0387722997355365, 0.06652679955286366, 0.06629236898715458, 0.03637788426731864, 0.044537877453671354, 0.061100146793309724, 0.026520364730048086, 0.04876565623788103, 0.02370052914615841, 0.02567116201164261, 0.06326984186025877, 0.05016485071410576, 0.024745565005427888, 0.03669329415706377, 0.05142896473708172, 0.009467547267465102, 0.06789310970493863, 0.017101399885911136, 0.044681622361343716, 0.023870307636717637, 0.01711285481559894, 0.006749955693169708, 0.06039788548444068, 0.01251600264015818, 0.08649731745883342, 0.06550226420644792, 1.1561494969552564, 33.2669158135691, 34.48756525593419, 41.77264221252934, 43.07949750654159, 5.045524691381763, 0.18215873188549475, 0.036132326274509394, 0.10001594245794321, 1.2040071934461594, 6.988823279257744, 8.477598101862016, 8.200616009773748, 7.926554612575039, 8.657629989808607, 7.724585398550957, 4.012511877282973, 0.5482184021703659, 8.458230418543662, 35.47759894401797, 56.33723028244511, 57.247761449506214, 54.92205481375418, 51.79276827842959, 52.95186396568052, 49.847178536076704, 50.69073915481568, 51.11513960746027, 50.75354022364463, 48.39562308403754, 44.995838134519516, 44.571029755377005, 43.14910388761952, 41.4233551486846, 42.76069118130592, 40.633028937924294, 41.531687090473795, 38.85442626091742, 41.940700084932395, 40.24604397435343, 42.779177311928045, 50.3083315972359, 56.21915909551806, 56.772409408323234, 55.642872702690866, 53.916629745114236, 54.3920131652586, 48.781788272242395, 43.840625593739176, 40.39966752452236, 39.73995624050018, 40.164215487818566, 39.7665891339702, 44.01906597998835, 52.59992145722913, 54.07566224375079, 55.893853402906856, 52.97281334477087, 54.26009208925309, 51.34900308424427, 51.32603368451519, 48.022895936043035, 48.94135421322238, 55.42672264960505, 53.020003380314, 50.05165953789988, 49.639175245838786, 44.24863838380383, 43.32963097480036, 41.33604711101901, 38.132376747746626, 38.90334606170654, 39.17254617137294, 39.13740173462899, 37.81983052530597, 36.474112387626406, 39.46644936838458, 36.313303055301795, 39.486014150804095, 39.556797242933705, 49.41710241379277, 51.424343970514116, 51.986878533517164, 48.04905814509238, 52.507384900123846, 51.73049280720373, 49.12008093249414, 42.23884728647048, 37.096298356210035, 37.692467243440696, 38.55498859959264, 43.86746245045816, 49.17194643328267, 49.501562810713246, 50.20653040178361, 50.21139414079728, 48.20670604705811, 50.62821657426896, 48.962189843577725, 47.31761063298872, 44.69002662166473, 41.44255907304826, 43.194536701325454, 46.568885080276004, 49.66122288857737, 50.36857135834233, 42.40743860121697, 21.697027952440326, 4.750282495252548, 1.3126802588662794, 2.22442711553266, 3.13487297104251, 6.9080214731154905, 9.568906407202444, 8.488983761879707, 5.664652682119801, 2.97803896088754, 0.758592703890416, 0.19198002504004588, 0.0705535492048629, 0.7630948494038274, 30.775153675386985, 46.726026996489495, 32.88070944047744, 36.96016465463946, 5.320095996702872, 0.2492836775678781, 0.029583145946925207, 0.06284359820006837, 0.032139376421729406, 0.018222033301548615, 0.037404319511786584, 0.033228454675765774, 0.033002535346895456, 0.032489777377416054, 0.0011324529552967438, 0.04882805409931368, 0.13853299701886793, 0.07632772242950817, 0.05302920366727537, 0.1143622488504456, 0.0634830402991464, 0.05589022796841399, 0.024215715614357786, 0.041712909080689, 0.04590058699250222, 0.027739911588029038, 0.08693845386827186, 0.12845370843405687, 0.15141511786608927, 0.14773852402164092, 0.16656184058275916, 0.10301159905089487, 0.10383444642948528, 0.13724488146122427, 0.18594539724290374, 0.09661533178821688, 0.18947212896760435, 0.18474873726166066, 0.1594640053207836, 0.16582783642074755, 0.10712693144957866, 0.11844088563755636, 0.14133614337732717, 0.17096782673991498, 0.10056813097288532, 0.23357110698857617, 0.12550418565590538, 0.12256580945705214, 0.12690490847753902, 0.12496266108486923, 0.11323613790614952, 0.13061235268269816, 0.11713557140601259, 0.1822126491536056, 0.1382170470371362, 1.6305458281309375, 39.82828017204039, 46.03019460555046, 46.40851897578086, 49.88160517907912, 7.9792683259133375, 0.4578169627535728, 0.3243490020113607, 0.39435718088380756, 6.20882761093878, 13.04030599132661, 17.04301218832693, 14.714663836263842, 11.43925920609505, 15.805578923994496, 16.194356410734116, 5.6274024228895865, 0.778080142073093, 8.927326279301798, 38.395152015070764, 59.202525615692146, 60.531561913028845, 56.80707531590616, 56.2124361530427, 55.93534815695978, 52.6136262186112, 51.987627706220074, 52.9090081491778, 51.96279518065914, 50.848371367300714, 44.02602818704421, 45.9784467758671, 45.424035441490915, 43.498908704327, 44.38800019602622, 42.45059251785278, 45.39604933031144, 40.58683126203476, 44.21492561217278, 42.88578341084142, 44.051370620727546, 51.89824473473334, 59.28306756481048, 58.165839256778845, 57.2030895756137, 56.46436606684039, 57.58701901282034, 51.94723906055574, 45.406847615395826, 43.219408450588105, 41.10174040640555, 42.228378480480565, 42.238270698055146, 45.659883637582105, 55.162331365769916, 57.681646193227465, 58.64922038970455, 55.044491598683024, 55.395025976242565, 52.884983631872366, 53.09891362344065, 48.37654075314922, 50.16305092842349, 57.462287641340694, 53.9730255834518, 52.73927934708134, 52.280256132925714, 47.28717304045155, 46.24650547581334, 45.049751112538004, 39.56313579313217, 39.73631628098027, 40.9556281951166, 41.44762285294072, 39.700936502025975, 40.07876273124449, 41.205934247662945, 39.18431720426006, 41.633519664887466, 41.57685318300801, 51.4252814169853, 53.78805445086572, 53.82202217655798, 49.903707735000125, 53.03715590507754, 53.453366448802335, 52.05984246346259, 46.184688921897646, 39.482005488487985, 39.14254788429507, 41.07952017937937, 45.914720027677475, 50.70375357904742, 50.61551986202117, 51.401217675978145, 51.26987711075814, 48.002554524329405, 54.3845881185224, 51.281718746308364, 49.826197778024984, 46.71327144868913, 43.72826537778301, 47.22490149159586, 48.92219343493062, 52.48052450918382, 51.09359402810374, 42.41933907231977, 21.180895028575776, 6.49856525082742, 2.2185335092006193, 3.7345886615014847, 6.364093163321096, 9.460930420506386, 13.18531797778222, 14.133501937312467, 9.198400301318015, 11.381004164295813, 4.611577189737751, 0.9539146036390336, 0.20233537340837143, 1.8305711400124336, 36.31876691695183, 44.703315611808534, 39.95895785670127, 45.15840076631115, 6.932726031349552, 0.303654914060908, 0.1986371145974244, 0.18523799165362315, 0.13169210764669603, 0.1926140394061804, 0.19038981037034144, 0.14995564376154255, 0.16141546109030325, 0.1483579980389726, 0.11653632210988192, 0.10882932437403549, 0.20428981692079576, 0.17197731611949785, 0.15951726375327957, 0.235025157190619, 0.13914269575428578, 0.058724734136053634, 0.15371131320153514, 0.1628700322321346, 0.15891043018669854, 0.09429492807436375, 0.12162632519199003], [0.018058492681912838, 0.03847885741702011, 0.03326899604871869, 0.050167034064689954, 0.03928498875710272, 0.07810527624021615, 0.1380961583626847, 0.11094336698372519, 0.02179742884641934, 0.0629924031184806, 0.031987355849255, 0.016475015755502448, 0.0652432881836449, 0.015698147058907538, 0.021562799097849958, 0.02899461230563541, 0.021666029445646752, 0.028475940137380557, 0.06970188159856104, 0.07013256856871229, 0.050355258037246046, 0.07924028146531313, 0.054984953359610615, 0.033413361487609726, 0.017532343495517008, 0.07985211758603973, 0.08396448522445657, 0.04713402685498999, 0.1120374094875109, 13.363188639763864, 33.14133328776206, 28.841307509330015, 42.62198048253214, 22.772130004821285, 0.6633194355714707, 0.13295828244618832, 0.27574489073407266, 0.5952857410715473, 5.553584396839143, 5.843399993834957, 4.852321484396535, 9.42671754667836, 5.131959021091461, 6.153227033153658, 3.4065662372496823, 0.46353081421506026, 1.574919509791559, 19.96492693501134, 52.16247127902124, 57.05745981585596, 55.39744607863888, 51.60739314171576, 49.631656062218454, 46.92391057168284, 46.17480847143358, 43.4021399098058, 44.43211509335426, 40.60483494112569, 41.8539176448699, 41.21008019293509, 43.037312415338334, 43.01743776567521, 46.55511756097117, 49.56921585144536, 50.55860627082087, 44.638435686788256, 41.19123320425711, 39.67096174916914, 40.102175358803045, 47.816536118907315, 53.85812759399415, 54.489389927156516, 54.36438791213497, 54.26779954664169, 52.96805550975185, 46.820713012449204, 42.104859121384166, 39.36715848984257, 38.203085314842966, 38.977647519880726, 38.23748842362435, 40.668255744441865, 51.39293755254438, 53.44308983895087, 51.910859077207505, 50.55934759878343, 52.3795783904291, 50.64400019184236, 50.03096119050057, 46.02908849716187, 45.2134394645691, 54.20652427980977, 50.955354013750636, 49.516962036009765, 46.26742347594231, 44.74664211273194, 40.296128719083725, 37.398948438705936, 37.63617338672761, 39.02783032386534, 37.632906052374075, 37.26485436962497, 35.33221629358108, 35.68624550296415, 35.83314218828755, 35.42801626266972, 36.098561133107836, 35.16327196551908, 40.8620169085841, 46.902808220155784, 48.466068852332334, 50.7947604117855, 47.00817877246488, 52.999944379252774, 49.63537446914181, 45.80078694128221, 41.745267991096746, 38.109615233636674, 35.463650995685214, 35.848521801733206, 40.849351575297696, 46.67709542858986, 49.53938230391472, 47.796088803199034, 46.6431277028976, 45.597612088726414, 50.38887746872441, 49.692621461806766, 46.83754390285861, 46.04615472978162, 43.672759917474565, 46.37080538657404, 48.099911674376465, 49.039680188702, 33.86605001265003, 11.795610458620134, 1.3778424719648978, 0.35575689086990975, 1.1095318823091447, 1.5796468238676749, 6.496971787944918, 7.481380797201588, 3.5875083602243856, 5.43359762237918, 2.5752811662612425, 0.5047371514862584, 0.026460025729911945, 0.024489505862396573, 7.7318295259629535, 38.458706178972804, 19.53401730906579, 28.12203307305613, 20.807599136906287, 0.09756030890369609, 0.15215669097679277, 0.023605993896302198, 0.07574600888596428, 0.05173271476861931, 0.04655566877655445, 0.053149360727759144, 0.09524002776391084, 0.058968242843665426, 0.023595814503008322, 0.07408635600680306, 0.04783690486463809, 0.019031140893217058, 0.018218078372639515, 0.04297563648452202, 0.06439869156888416, 0.026743763629647515, 0.03581613880552111, 0.03651641594666628, 0.034223108762694944, 0.03806289082633392, 0.06063927212850221, 0.06126630743364654, 0.009645542051012238, 0.05995218319097354, 0.05967366043478251, 0.05732776514524895, 0.05321575373771691, 0.052755989900399605, 0.06284860458465354, 0.07531347564391552, 0.02170379374987416, 0.03267817371975511, 0.08496223047616021, 0.02041028493324355, 0.013655463624144755, 0.02422849013049516, 0.012167211426722427, 0.011433944624337939, 0.0136765904138766, 0.04414813405263328, 0.05797605939029206, 0.023732637806284814, 0.05242137801683238, 0.05712403555310542, 0.04947889558670502, 0.017368670725714297, 0.024771765212438283, 0.06310025297646081, 0.08416159198649469, 0.04648470988256797, 0.03640046853932642, 18.81921437478835, 39.766989215727776, 32.862864617378484, 45.93243345137566, 21.959171718166722, 0.5573675144583948, 0.1814516940184178, 0.03750976385368455, 0.14999068462319914, 2.8619167016398523, 4.7068250852246445, 4.733565843874409, 7.1828178244252365, 6.9096620044400625, 7.395855967075595, 7.10648310761298, 1.5022286748693836, 1.817671812830433, 23.01393432001914, 53.213897905042096, 56.91781167061099, 57.00085609189926, 53.33778988930487, 50.246758230270885, 49.054483213732325, 47.45148112696987, 46.625508416083555, 46.25516214678365, 43.19520742662492, 42.65621100702594, 43.0063884488998, 45.285936632464015, 44.921387626278786, 47.074560965261156, 51.68339690854473, 50.87383931682956, 45.04325958990282, 42.42026867405061, 42.1958855659731, 42.18694648435039, 49.50929380232289, 56.12540268128919, 54.87695147914272, 55.13980911624048, 57.456247191275324, 52.901437974745235, 50.0008491546877, 42.90797225890621, 42.65862718705208, 38.63196903659452, 40.31319495170347, 38.494042811855195, 41.250755171622004, 52.73350169581752, 53.56453818659629, 55.20825447574739, 52.564274957103116, 54.05343417198428, 51.27650591634935, 49.667451612411014, 46.1881955208317, 47.075831813196984, 54.93790118925033, 52.93449571055751, 51.59543383506037, 48.57724843486663, 44.875574342666134, 43.27370582088348, 40.58370513300742, 40.65565709144839, 40.67300573472054, 39.62408550323979, 37.97652529131982, 37.59211340258199, 37.64128031269197, 38.35393574930007, 37.958737342588364, 38.36934281933693, 36.98825274744342, 43.6226124148215, 50.52963172235797, 50.47474991890692, 51.630613573135875, 49.23155077042119, 54.33420919602918, 51.071311043154815, 48.52601051330567, 42.91525217794603, 39.71968543144965, 37.80213671345865, 37.03588208844585, 44.76140199169036, 47.76658865713304, 49.70500830681094, 49.49158822336505, 46.87503783933578, 47.42613869328653, 51.23209291888822, 49.808986417708866, 48.42521344461749, 47.88141996629777, 44.732392141895915, 46.80043043628816, 49.153879996268984, 50.13593166105209, 36.1919919906124, 13.54492283636524, 2.468950859000606, 0.8539435615943325, 3.474302383199815, 4.010380804538727, 6.396784647818535, 6.4644764219560935, 6.757969240988455, 6.112994791999941, 0.8995115132101121, 0.4718086087415296, 0.012825889993579158, 0.01460843486711383, 7.207060523571507, 45.17174466963738, 23.89905833428906, 32.00302027886914, 27.618712571359453, 0.3518713848485101, 0.05425860241596257, 0.0035472226614553124, 0.052007728842117136, 0.014805614407504759, 0.022920601843525807, 0.10369354753845161, 0.026675461145538478, 0.0416299915542045, 0.04472831158988899, 0.02054811372692066, 0.0497083350895874, 0.017967374184198918, 0.0419932704478983, 0.006629231248817017, 0.024355427069108815, 0.03610870012292459, 0.028424805683654644, 0.03283262853660891, 0.08626338485027514, 0.037849746013600985, 0.08958927130386715, 0.015247281332830749, 0.1885324608414404, 0.18279208741601438, 0.21402665654257422, 0.24387747169502322, 0.1719287921103739, 0.1827739617757259, 0.29709297262372514, 0.3146078263319308, 0.08901263692326124, 0.14850262011731827, 0.1706452730802759, 0.07524335561620613, 0.08550213860167612, 0.11575533377547419, 0.1691667233864146, 0.1395460104029025, 0.06712525977843231, 0.21090806582041327, 0.1321090893038819, 0.14808773754104493, 0.24016372258624724, 0.19230478503290685, 0.20150464298504017, 0.09620921325779731, 0.15565932157539553, 0.25070853982000585, 0.19016620462700246, 0.15606208464070676, 0.25818045581540755, 23.125247263139297, 49.68220756899927, 39.55388292189568, 51.16067440279069, 29.112745331179713, 1.1269318841157423, 0.5802559540156396, 0.5525781779039292, 2.0063859897275127, 15.000463416499478, 13.38105993886148, 13.067569405801835, 19.01170272980967, 12.062617963360204, 15.138736770999047, 10.447002514716118, 1.1759613886956246, 2.1443710500194184, 21.75641263684919, 54.14025583574849, 59.54177141189576, 60.70716250327326, 55.724630586562625, 51.94530533206079, 51.20554631756198, 50.54121840384699, 49.69149574156731, 47.7727585454141, 44.85779423867503, 44.97721079857119, 44.60924148559571, 47.57460040430869, 48.31038213545277, 51.48010046251359, 53.864340628347094, 55.460615850264034, 48.926531576341205, 45.25577752820907, 44.63926722926479, 44.47454729387837, 52.10902506305326, 57.350758967861054, 57.05718524994389, 57.81345352049797, 60.13370413934032, 55.78802001091742, 51.545129437600416, 44.94949925330378, 43.92057526496149, 40.57739796177034, 43.143314469245176, 40.780357083966656, 44.1892066309529, 55.11713389427432, 55.791240276828894, 57.63489154077346, 54.25756608286212, 54.36774546100248, 52.41732728096747, 50.96171217579996, 46.16173521164925, 49.83900823900777, 56.85109607635006, 55.94775461381482, 53.89133437987297, 52.09714028143114, 48.61283217706988, 44.324324438648844, 41.785789997346946, 41.95574237454323, 43.27030904831425, 41.48074334667575, 40.129526046014604, 39.29246871702133, 40.50458700426164, 39.47779678529309, 38.8694057926055, 40.007363826997825, 38.55507096936626, 44.15384646384947, 50.40357851213025, 53.04433776486305, 54.177812530148415, 51.11920318295879, 53.70090330800703, 53.11281842570151, 50.01194161753501, 45.85734359679684, 43.15663876072053, 40.959205396713756, 39.06564981706681, 44.774518397546586, 50.24776627940517, 54.00099992752076, 51.92088073299777, 48.91971057461154, 47.01710608697707, 53.018889427185066, 53.10255358296057, 50.37974619096326, 49.95938577959615, 47.85390846190914, 50.04780777039067, 50.71756032205398, 50.58185023646201, 37.59882850031699, 13.837397310041613, 2.064738355336651, 1.6186203519182822, 4.622034718913417, 6.633736010520689, 15.318215604751343, 15.374898756704024, 13.61358686800926, 11.877415410933956, 6.504915568136401, 2.0478280369312536, 0.229028144310559, 0.0904644578094444, 11.723055435765176, 48.49170154140842, 27.13969703643553, 38.865475577692834, 31.167396576173847, 0.794530991585024, 0.266515615005647, 0.17138595752898725, 0.20021617502695133, 0.22670305213860928, 0.11033818816706059, 0.2809732569561851, 0.19395594965786705, 0.08874789991926763, 0.23270228667364967, 0.09584308451702518, 0.08856276711148602, 0.09200998657052556, 0.1329941966480786, 0.1403200656415955, 0.11141656417279475, 0.09799185389232251, 0.10965594090521337, 0.18528279247543505, 0.274625544346148, 0.12748174204100526, 0.17322654505410504, 0.1704718460959773], [0.04085116358774324, 0.025077987792751482, 0.059357924957669554, 0.0414038768729135, 0.017510831746603214, 0.011748160374531103, 0.0410277851586861, 0.02045691478997469, 0.061413346519393314, 0.03914027091776652, 0.07656882562103771, 0.039804798565925135, 0.03895359444281748, 0.016711815448117354, 0.08279207192601697, 0.03559359026351764, 0.04700132510474613, 0.05271230373651751, 0.010576197152747022, 0.023617263049668363, 0.056358989508401965, 0.0666152214210841, 0.03495042497712759, 0.049033174141039776, 0.05203686316587752, 0.03148488261015906, 0.04234940174125856, 0.05435949236515069, 0.08567291492175672, 2.5372103962206074, 24.962693337471258, 30.000509100575602, 31.59880630431637, 39.97572991155809, 5.9697405176778, 0.45183887224524255, 0.09569240268319847, 0.17944938533248442, 2.630206851228591, 2.9354574651487413, 4.027288671462767, 3.456619603018607, 6.871157077050979, 5.651532353893404, 4.123782900071913, 1.3555004063152498, 0.26093509348650135, 9.204721200850702, 44.256098731871575, 54.709674158403956, 55.737437125175234, 53.803257557653616, 52.48719253847676, 49.17130708694459, 46.35570033904045, 45.08137326086722, 47.24922803140456, 47.07318421333067, 45.925702664159964, 46.4826282378166, 48.111055128036014, 49.76521668895599, 53.514210254915305, 52.41569165260562, 53.191418801584554, 55.01874123850177, 43.4851098060608, 39.41117925028647, 39.74362757898147, 46.88747175278203, 53.5180934013859, 53.62674697752922, 54.65146226267661, 53.65922812492617, 54.31475816234466, 48.40562120560677, 45.941800071347146, 39.55895454652848, 39.29845817627446, 38.717570843235144, 39.92343687242077, 39.59287520377867, 49.690628897759225, 53.43460575226815, 52.07354330247449, 49.47420820113152, 50.685938173724765, 50.71356342684839, 50.58601187121484, 47.71353075581212, 45.4586935043335, 52.27304289417883, 52.13788978515133, 50.12989121098673, 47.54834405837521, 46.36525915515038, 42.80380587424002, 40.955514446381606, 38.08642618117794, 38.19733512017035, 37.2427478913338, 37.74716077312347, 36.83459781831311, 37.22907450891311, 35.7288698996267, 35.86274431597802, 37.098330143959295, 37.891217662442116, 36.00357701701503, 44.001081912748276, 48.22520002242058, 49.87556865138393, 50.43255306059315, 45.29384805310158, 51.7797028633856, 47.96968898465557, 47.92824914378505, 46.16359049274076, 41.26343227201893, 37.97885910157235, 35.60375021349999, 37.95206931329543, 44.00066614151002, 45.69150578591132, 47.43466592604115, 46.549414434740626, 48.58684647467829, 49.92732824817781, 49.84873571703511, 47.239241676945845, 47.43418347450995, 47.62221405583043, 48.50668891783684, 43.668406086583296, 23.748101995837306, 6.654731477460554, 0.5030321768454967, 0.6853092846370513, 2.9050161953895324, 3.0329445437077553, 4.97282208934907, 6.513700696729845, 4.171914794752675, 5.002543849329795, 0.6728712649595353, 0.3646132349967957, 0.06628827807763893, 0.39141365657410315, 21.027357770550637, 38.58924265830748, 23.89483198042839, 30.192834677234774, 9.867002617928291, 0.04198747882319074, 0.08324393356639533, 0.009674408243999127, 0.006212567996924684, 0.06254888800603729, 0.036907637897398204, 0.04686421068805841, 0.044002485416469075, 0.012508037240965473, 0.04024067578176337, 0.027084337592485453, 0.043440494806535786, 0.02899983319483938, 0.023603218742796493, 0.00750604952167299, 0.08568078264473908, 0.05590289523224196, 0.015311936280810306, 0.0229480546042924, 0.024171878148110646, 0.08657024902922493, 0.056607048778283986, 0.02138078618313997, 0.025659934993112282, 0.019880707503386566, 0.03201299681208067, 0.07283684361966387, 0.041050384752452374, 0.02272689459665168, 0.033875484875733816, 0.014820931377940843, 0.0653856426417347, 0.07663489304362767, 0.020721466017646656, 0.051433768108366966, 0.04907377297058702, 0.01985673852745564, 0.06403411032571908, 0.03264283025336843, 0.0802054373367179, 0.04151511283951902, 0.010322999348112894, 0.038641153143778924, 0.014237939425173306, 0.03669638915227787, 0.0750914020764251, 0.020247839819339496, 0.0643934362057236, 0.03834736991613623, 0.01838205566239213, 0.05298404278413904, 0.09819734165625227, 4.328109948865829, 35.537175824565274, 33.04646292040425, 38.56543779373169, 43.798997479100386, 5.319438019106466, 0.42946043274094986, 0.020199813767366355, 0.18546556573240988, 0.6508833157920069, 2.6158392092873974, 5.851594805717469, 5.9449246621900995, 6.754774470483103, 9.450171359123724, 8.581325181068914, 2.4287965749540636, 0.8989015846483169, 10.558363506870887, 44.122506726172666, 56.74976164294828, 56.251667699506214, 55.265485778931655, 53.661114784979056, 49.54508543014527, 47.72913002198743, 46.60502187667355, 48.196790295262495, 48.08670505400627, 46.840003228956654, 47.68396785182338, 49.7768896625888, 51.59023669458205, 53.69807527911279, 55.281088967477125, 55.765156515182994, 55.854900344725586, 45.357802298761186, 41.26731149611935, 39.97087793965494, 48.425488010529556, 55.838893152052364, 55.554395798713934, 55.839069658710116, 54.716452014061716, 55.021851678048414, 49.80878637683008, 46.04853168610604, 42.38413187765306, 39.7407171803136, 39.57994314932054, 40.50132751464844, 41.36131501966908, 51.08525899148757, 55.89195105337328, 53.84338732688658, 54.14357416091427, 52.03689267558437, 51.40299058729603, 50.33385445994716, 49.055412815463164, 47.17883717629218, 54.16109931084418, 53.06394961572463, 51.225256227677875, 48.29362577007663, 48.220806967827585, 45.10280116911858, 43.078230580975934, 40.32931981548187, 40.93516518992763, 40.06858418064733, 39.50633202829669, 38.33609680975638, 38.6272386581667, 37.228262578287435, 37.52566060712261, 37.50899837863061, 38.26782403453704, 39.69249163904498, 46.5879556440538, 49.37558020314863, 51.33991495255501, 48.10313586265811, 47.03217583317911, 53.076065817186915, 48.964594256493356, 49.81727438588297, 45.692725643034905, 41.85430203714679, 38.55675366617019, 38.229098473825765, 42.17939984413886, 46.870378063571074, 47.87478331596621, 50.585819675076394, 47.759697052740286, 49.10956113569198, 50.8275318145752, 50.557810029675885, 48.99022694556944, 49.11453862344065, 51.26645680396788, 50.58707875590171, 47.400604063464755, 26.869751676436398, 9.077886458366148, 1.830399291169259, 1.7034655088378539, 4.225646363150689, 2.7298230413467657, 5.422647835746889, 8.025850394079763, 5.1973130626063195, 4.112591642525889, 0.40629825464660124, 0.11988463961789686, 0.09574078113561678, 0.19937928525670884, 22.74730924637087, 44.17136376903903, 21.62212637162978, 35.76579117005871, 12.987088253421168, 0.01304502274105025, 0.02808316877382177, 0.037639768974434946, 0.08156836138016756, 0.054861249312037424, 0.05151387409216935, 0.00860862672374013, 0.030566463847794843, 0.1216096934231539, 0.011571195979242124, 0.020172560189460075, 0.019659227654037457, 0.07685884352653258, 0.03830140847111902, 0.04289064669020234, 0.06773615361101205, 0.05861592283772846, 0.03407238096359276, 0.1116050830892017, 0.09528224686941794, 0.040123881847267194, 0.060331343087337674, 0.045443366567093524, 0.21931888385405465, 0.12504776579237756, 0.07930626461823141, 0.20942752429794884, 0.08995535407936381, 0.1223695760352477, 0.18113125476144976, 0.18729597960989322, 0.1646626779749509, 0.14717826860085612, 0.1933123745144375, 0.14401605683228663, 0.18421578521449722, 0.10023282194930701, 0.192685806522927, 0.19567430019378665, 0.20151306995220725, 0.15604264132918852, 0.17512480367816266, 0.1726373927968164, 0.17902409928219934, 0.24780846801736664, 0.18080600447231726, 0.1267908839508891, 0.2176343331173543, 0.1113304865336226, 0.12226926448244242, 0.1608393016842104, 0.20149560314753365, 5.571002662181855, 42.77550989581693, 41.3667239681367, 42.474973970843905, 49.761984655934, 7.982392003459315, 0.7710662087605846, 0.24283551550920934, 0.40678864284869165, 5.1287706244376405, 11.60235724141521, 13.226712711395757, 10.878014122286151, 15.794221701160556, 15.287429901861376, 10.131346833321357, 3.2780752739598675, 1.2742168840862091, 10.97210786034984, 45.533638231215946, 59.31341494283369, 59.88484936375772, 58.23441797687162, 56.29812032945695, 52.50285064020465, 49.73121758430235, 49.9746516443068, 51.47998279140842, 51.46408542510002, 49.349484674392215, 50.18249803973783, 51.89869188493299, 54.063620567321784, 55.57934991775021, 57.07023497550719, 57.60972953611805, 58.36725688749745, 47.88680538054436, 42.58450615790583, 42.592696066825624, 50.75080633163453, 58.31626999762751, 55.98704499583091, 56.52227986243464, 56.03275237544891, 58.64386243204917, 51.36650469995315, 49.090690612792976, 44.06997834482501, 42.63678742993263, 41.83290943022698, 43.15006486831173, 43.09943491412748, 54.382426892557454, 59.10175992596535, 55.964863992506466, 56.42963740133471, 53.10143178509128, 53.35025910408267, 51.0615364966854, 48.527681442999075, 49.630757839449, 56.59242360822616, 56.77088752869637, 52.61040203032955, 52.11125689168131, 51.354619918331025, 47.42785669142201, 46.06475068676857, 43.189598437278505, 42.73739230248236, 42.707668581316554, 43.02829488631218, 40.21200172362789, 41.01829982572987, 39.294167103305945, 39.02783816860568, 40.07813515201692, 40.4992368913466, 40.2896293517082, 48.84141222123177, 52.642255598498934, 54.24360244504867, 50.88887768407022, 48.09146681139546, 54.26319076168922, 51.76167957244381, 52.2968634482353, 49.45797743335847, 45.34842783404935, 41.36104045375701, 38.807687297944106, 42.62171376136042, 47.12440252304078, 48.87723130564536, 52.132461224832845, 49.1744920515245, 50.193629726286865, 50.86087980578023, 53.07170806392547, 50.9264971363929, 50.774564127768244, 52.30356677885979, 51.76496259627804, 47.760501138625614, 25.736118055159046, 8.620285103397986, 1.2264127524629718, 3.0735378880654616, 8.154425688328283, 8.034971375619213, 11.937996418245378, 13.196720307873143, 12.648278820899225, 10.792562346304617, 2.8924937834662776, 1.0140221686132493, 0.22830685720809046, 0.8586049308219265, 29.403496903757897, 49.9670579356532, 31.423219442367557, 42.74263651140275, 16.173562945858126, 0.22184895051102485, 0.1560632031290762, 0.08841981510481528, 0.20716701333801593, 0.11033179133289284, 0.10696760814396605, 0.12442485970114509, 0.12965774584201076, 0.16046785629324375, 0.11311178651428032, 0.18213391063674805, 0.10459284283100598, 0.16501927658194498, 0.13862860479181813, 0.11839447603110345, 0.15480839707438024, 0.20188613944957334, 0.17284081978422983, 0.20877593587483131, 0.22823348130670287, 0.11856601843910834, 0.17611863422057322, 0.15375681882423742], [0.00338754911001982, 0.06280360074954168, 0.04297004021223515, 0.05192965299131409, 0.05510073222760713, 0.03485038538553542, 0.03453467289106019, 0.0386051393504585, 0.07574684392180174, 0.032673466109460404, 0.02343127222341155, 0.045493472547781084, 0.061931482426101164, 0.059312147373754176, 0.0553854909395018, 0.03178221857055061, 0.08879181207908739, 0.03138067741547862, 0.033406213887276194, 0.04105974634688708, 0.0863127745387535, 0.05593174993390999, 0.08192376488999975, 0.027036324947050987, 0.033718567086203445, 0.05198051356860707, 0.031824749856886846, 0.0297466540078242, 0.02381260206382121, 0.10481588933016024, 15.263859398903387, 36.47024100826633, 28.51985162304294, 41.34159726481284, 21.005772967492383, 2.7430610406783322, 0.08743708517642752, 0.1913741873877664, 0.17925461513861535, 1.8101624351355339, 2.369060838414777, 4.407354083753401, 3.698611701688459, 7.302228500766139, 9.652079286113862, 2.1501487012832396, 0.18926897777184365, 1.0704531857082922, 25.530405429101762, 55.11577283182452, 56.865777507905044, 54.089774931630785, 54.805611410448634, 53.10845282769973, 54.062122221915956, 51.493569881685325, 52.04500413710072, 51.82572403261739, 52.58831516388924, 50.87623980737502, 54.142762230288604, 54.78561516731016, 56.47287761011432, 56.62692477626186, 57.79306896271245, 54.20854037807834, 47.009775177125015, 43.15612885259813, 39.44675514774938, 46.70640730088758, 52.01508429742629, 54.4296443846918, 53.46877744120937, 53.105820917314105, 54.89807736489081, 52.37447146446475, 47.30847543285739, 40.34907287166965, 38.82916619700771, 38.57155276883034, 38.14242978249827, 39.29678332421088, 48.59405971342518, 52.647586099563114, 52.385246215328095, 49.342393029120664, 50.647695064544685, 49.637892630792436, 51.27836119744086, 48.043060841098914, 45.74065308417044, 57.55903682401104, 53.17387796217396, 52.80186076318064, 47.64213185156546, 45.88256835937501, 44.853491398596, 42.2324538230896, 38.727231640969556, 36.68987804843534, 36.41059744742609, 37.63313354984407, 37.13593390680129, 36.541412415043006, 36.71169819370393, 36.047703681453584, 36.74254371273902, 36.76182608450613, 37.44962153896209, 39.882267675092145, 46.64695985855595, 47.51075206264373, 50.961414075666866, 47.31703796694356, 47.81195871291622, 50.875431799119525, 49.328927532319106, 48.469724501332934, 48.663301314077074, 46.10119735040973, 43.73326247738254, 40.38495079163582, 40.75397522218766, 43.467682715385195, 46.17403184213946, 48.38500522798108, 48.171349802324855, 49.820220085882376, 49.170899160446666, 51.19450876789709, 50.74627991645567, 49.69380993996897, 46.08287595933484, 32.55652554573552, 14.327547473292197, 3.053760071915965, 1.5023109220689344, 0.7773215311669535, 3.2609364774919327, 2.36147252302016, 1.7726667826214146, 5.05472461062093, 3.966062189109864, 3.9011518657207493, 0.05511932135108979, 0.22340170348123198, 0.19581326854325112, 4.440063218916617, 35.64515083066879, 29.794653308007028, 24.247317737148656, 23.06277959577499, 1.480296251754607, 0.07871587895938466, 0.06738638084742331, 0.03321372663542148, 0.022372318461777705, 0.040741965415016304, 0.042564036595004226, 0.028464192179061716, 0.036017156446412686, 0.037936252662010735, 0.014717854247728904, 0.051832516872954947, 0.04332730148528372, 0.09534079896947069, 0.01823396512096928, 0.03613683470194379, 0.055318404619972554, 0.05667467518979984, 0.04192042314717847, 0.04130591721003575, 0.0790794872708859, 0.007216793394857838, 0.04459698113702959, 0.038808796164249225, 0.07694843750927718, 0.04133207145177069, 0.02585391803163915, 0.04292173836860926, 0.06593256813263701, 0.048023726896292744, 0.016149393913726655, 0.02169158613880075, 0.08901258329710654, 0.06384997726267864, 0.03013221839923532, 0.05838053083167442, 0.07243244878707394, 0.021439525974734176, 0.06115337841272835, 0.0493355528751929, 0.033217886492850325, 0.03601406528163822, 0.02171111180477085, 0.06808444782490693, 0.0398290797226852, 0.039329207352092194, 0.05846905229132503, 0.05829855942377641, 0.056394045691817045, 0.10532767436797581, 0.04250186855994886, 0.03249293365966409, 0.04085359974734245, 0.15444905587261723, 20.764286364278487, 38.94397789432157, 30.832922343284856, 49.14974974047754, 22.826986312866214, 2.372907702961276, 0.22513788854402883, 0.10155480625408311, 0.06805103106964981, 0.7309716795721363, 2.910746042766879, 6.045877645092626, 7.282064576302806, 8.986833537778548, 10.419446883663054, 4.830339541358333, 1.0636663821435746, 1.7320149704333276, 28.85103498735736, 56.198076355841856, 56.56861482128021, 56.44786073315529, 56.95079095901982, 54.02802898037819, 55.702347601613695, 54.30719583265243, 53.637407979657574, 52.11639127423687, 56.06696328809185, 52.835440174225845, 55.06473887351252, 55.61263122866231, 56.78174464933334, 58.51663251076975, 58.27108429324243, 55.42564792017783, 47.73738661120015, 43.71861634715911, 41.93047054352299, 48.05404739995157, 55.83396665511593, 57.317167789705344, 52.69776105880738, 54.423337213454715, 56.68979644775391, 52.76187219927388, 48.63071818505564, 42.28232283746043, 40.75255140181511, 39.657217764085345, 40.08548175134967, 40.3105277399863, 50.6341903440414, 53.59512482920001, 53.65157165834981, 52.232277700977946, 51.8030252764302, 51.44307328808693, 50.44624997723488, 48.622332157627234, 47.87941955750989, 55.40088599728, 55.082518977503625, 53.40469767970424, 48.515129858447665, 47.74171690787039, 46.278394345314275, 43.94506262194726, 42.11747346385833, 38.148552602337254, 38.403385070062455, 39.44187571925502, 38.85669339087702, 37.56538244985765, 39.301388186793176, 37.329114560158025, 38.73804169316446, 38.88687995172317, 39.053976843434, 41.48610522670131, 49.43729477543985, 49.06168076299852, 52.11891728062784, 47.08582601239605, 49.57730770111085, 52.02346640248453, 51.11578287616853, 50.56268553580008, 50.61481383539016, 46.224446065964244, 44.86739620085686, 40.70092124323691, 40.9587307899229, 46.71678589236352, 47.04100508843699, 50.631527054694395, 49.276442297043346, 52.0610309416248, 49.511921790338334, 51.135363348068736, 50.83342713694419, 51.377220615263916, 47.22608996975807, 34.73258003111809, 14.199925314995552, 4.415338558535423, 2.4532140647211382, 2.5259230406053605, 3.4890333346782194, 3.6448284070337977, 4.645334578329518, 5.355366439588609, 3.519136300010066, 1.161658833584478, 0.212700251910475, 0.05208580086248056, 0.03813522484814448, 4.4162809079693215, 40.54546594619751, 32.71789577699477, 26.178198591355358, 29.479194725713423, 2.451966505858206, 0.1442667208011112, 0.12250736460930879, 0.05196937848062766, 0.04815319192505652, 0.07221063568947778, 0.06577486893342388, 0.02306231470297902, 0.03631578134973684, 0.06925542853892812, 0.012469978950497125, 0.035318108876386, 0.02918947443005539, 0.12278096525058632, 0.07043772437159093, 0.03834419831212971, 0.055780957017334244, 0.025442846742789113, 0.0235492421028715, 0.07599219890131105, 0.041642252791432605, 0.048034762392842004, 0.027708174480545907, 0.015406412158852384, 0.3586702006718805, 0.13186919653127271, 0.1369068987907902, 0.11513490214823716, 0.1421559340650997, 0.24302683830741914, 0.16926279081211937, 0.10079894560359179, 0.20169126200339488, 0.1732114684437552, 0.10587224796895059, 0.1389099275993724, 0.18502645945597082, 0.223315441980958, 0.15459171676587674, 0.12189451725252214, 0.194414361349998, 0.14497290064971294, 0.13184697998146858, 0.2554164259063621, 0.15202374407841315, 0.15070470921214552, 0.27724712786655276, 0.25869097680814807, 0.20318042967588673, 0.13224778186169364, 0.10535048080548164, 0.13424186276332026, 0.15354821308245584, 0.28906909027887934, 28.060253781657067, 49.32565235322522, 38.860553003126576, 52.046314208738266, 28.000802416955274, 4.1188583643205705, 0.5172175205042285, 0.32895754181569625, 0.5620097008443649, 5.4470562550329396, 9.625206147470783, 13.467005933484725, 11.0740904654226, 16.138048825725434, 20.029597013227402, 6.774494186524422, 0.8384708531441227, 1.5320932336391941, 28.30765335790573, 58.56034732634022, 59.47411444879348, 58.39308177271197, 58.71681067251391, 57.15460515791371, 59.68389849508963, 55.28429746627808, 56.58073102274249, 56.28476073665004, 57.84041981543265, 55.62118199563796, 59.13750448534566, 59.48852915917674, 59.32180489263227, 60.5715230203444, 60.4753621931999, 57.59842918765161, 51.449568733092285, 47.628729112686656, 44.04662063044887, 50.30121249537314, 55.592509469678326, 57.771323342477125, 53.95174280289681, 56.07532578129923, 58.94173114530502, 57.33871729143205, 53.17402308987033, 43.1368935492731, 42.006650817009714, 42.06791039436094, 42.19900385026009, 43.38949811074042, 52.35193744782479, 55.94300462353615, 55.97683506627237, 53.42151288063296, 54.320276937177105, 52.57720701156124, 51.5794894003099, 48.81577560978551, 50.074256312462595, 57.51627906676262, 57.357211266794515, 56.836912785806966, 51.14074091757498, 49.50991745918028, 48.865699537338756, 46.84967187143142, 44.19675327116444, 41.18575365312638, 41.56904374399493, 42.357114591906154, 41.234300828749134, 40.20558864839616, 41.248456662701024, 39.99475340689383, 40.789005910196614, 39.71556694276872, 41.02699572040189, 44.67484704909786, 50.43100372437508, 51.56749871469314, 53.865803672421364, 47.913559867489724, 49.31822338411885, 51.788339922505045, 54.318900185246626, 52.1825106682316, 53.67247789136825, 50.06893365613876, 48.168247207518554, 43.54469845371862, 44.5701942905303, 48.06973295827066, 48.75650859648182, 51.775804027434326, 50.97145142093782, 53.00656534010365, 48.5934478236783, 51.94344220622894, 54.45891703328779, 53.392781519120746, 48.7440433040742, 34.73379204350133, 15.619327137547156, 5.2697548270225525, 4.014254635380161, 2.8190623560259422, 6.903747560516481, 7.450455359874233, 9.104854714485908, 12.328305590537287, 11.892825422748444, 8.277659204698379, 0.6642938994111554, 0.6305466231799896, 0.21681990504505175, 7.448075461772181, 45.96114127866684, 38.60223747068836, 33.37446720369401, 33.94630562874579, 2.850959805711623, 0.19871222185752085, 0.225854242040265, 0.13991465191206626, 0.1354188496066678, 0.18056945184305792, 0.15980595632666544, 0.11573809679717788, 0.10461538879861755, 0.10651083587999306, 0.139565683540798, 0.1734559271003931, 0.11059278216693672, 0.23892944768792201, 0.15414390773061784, 0.156627181737173, 0.16722110520687797, 0.10743810870354215, 0.07841690548605497, 0.10682155348120198, 0.19090239980047752, 0.11389166402119784, 0.11712839316216209, 0.09281641668489865], [0.049610934670894384, 0.014630714619171717, 0.07994575651302453, 0.035831732525219845, 0.07327638656621979, 0.03121507984976615, 0.039888708176271576, 0.01769142548343347, 0.026913000113000313, 0.035035828458926374, 0.025381228375819423, 0.03150271330659669, 0.012079186966612697, 0.039897027891129255, 0.15474479645490646, 0.05098266872547327, 0.052446678070531744, 0.05978505727985214, 0.037278619805170644, 0.043947878669226365, 0.08217300393528516, 0.02619031681528976, 0.03319702974911178, 0.010391306620271457, 0.06973506852744088, 0.030179507091581344, 0.03912696780096139, 0.030947031430719845, 0.0741264530487599, 0.027682905070363518, 5.8862665968556565, 36.701782441908314, 30.775604747956802, 33.53993631178333, 37.976811624342396, 9.790760567111354, 1.2719348000903286, 0.11311966189814192, 0.11407842859625818, 0.40866316806885505, 2.8911614033483692, 5.086201631253766, 5.6288919429625235, 8.29012155532837, 7.813692823533089, 3.034748343690749, 0.868486913461839, 0.08905287186104445, 6.482612971336612, 40.43354111333048, 55.161048750723566, 57.518322621622396, 54.51211221756474, 57.44334651577858, 54.58125183659216, 56.659080366934504, 53.77481252916398, 54.842607205913914, 53.48261948554747, 56.29583751001666, 53.56098844159035, 57.28385117746169, 55.48955509739538, 56.32403935155561, 57.257410480130105, 54.097584370643865, 47.4109120522776, 41.67461041481265, 41.151393690416896, 48.17862972136467, 51.22718995617282, 55.38317649595199, 57.216562917155606, 51.083525303871404, 53.8229674677695, 54.85422134399415, 49.4032839036757, 44.25719699551983, 40.05659741740073, 40.209730671298125, 39.330096014084354, 40.26033316889117, 47.52492750844648, 52.4340130436805, 52.98014033225275, 50.94304953852008, 51.848509080948375, 50.41720482610887, 51.60710288632301, 50.09628434335032, 50.73419509395477, 60.822841044395204, 51.093417521445986, 53.81689171637259, 47.56968567448278, 45.284528501572154, 39.81991375646284, 41.63436689684468, 35.840465253399266, 37.81330370133923, 35.25550257775092, 36.60481752887849, 36.060055225126206, 38.29748107540993, 36.248854591000466, 36.933547450650124, 37.57322326783211, 41.67523014929987, 44.96666746754801, 45.7163736128038, 47.32685958185504, 50.851062113238925, 48.103390816719305, 50.523053907579, 46.830852339344645, 48.01315669090518, 49.55387546170143, 50.46151191957536, 47.13861719254525, 49.09041996925108, 49.148223938480506, 46.838285230821185, 45.799245449804495, 46.20723470564812, 47.07841665514054, 48.84869998501193, 51.68702117858395, 50.66638908078594, 51.046780540097146, 52.379735285235995, 49.8507635824142, 47.9936428992979, 36.85626499114498, 20.37889584418266, 5.80567708899898, 0.9448159305799393, 1.5261581972722085, 2.901086225625008, 2.576100696479121, 0.8146088690527025, 3.5893898721664184, 6.281148272175943, 2.7442208365086587, 0.7901886213691004, 0.03762240559163113, 0.09044432501879432, 0.9213278586826018, 19.521128400679558, 37.25614670784243, 24.95565856656721, 31.268891826752697, 12.218787131770966, 0.015308264804433192, 0.012591395268006431, 0.023464070362669807, 0.03391836281685579, 0.030266672575605974, 0.04783216661082641, 0.04383940444958787, 0.022582829847270926, 0.025357749696160038, 0.025771245653290423, 0.04423005566481621, 0.05180579572615605, 0.051408479545986464, 0.12970381836977699, 0.059461848615037824, 0.023876068617908225, 0.06549494806677103, 0.02035390660767594, 0.022509865718142643, 0.05067877313723007, 0.0731867389573205, 0.042453988064681335, 0.004558524317784055, 0.04081306220482915, 0.023416940633568074, 0.054015089877911156, 0.07462359048546323, 0.039571084292425264, 0.014469946280211933, 0.04034112523039503, 0.03497505087345358, 0.03348857983045521, 0.05366993662450583, 0.06919950412045564, 0.03282573757573001, 0.07511096030113197, 0.05905389530403961, 0.020683230569345817, 0.037250703561209866, 0.06550097717873513, 0.024068356686902624, 0.05339092357204326, 0.09733785229224352, 0.041597402173905604, 0.027799773698432312, 0.03270228250673221, 0.005360554214642053, 0.03755595129463942, 0.05410373008119003, 0.03743315889169613, 0.07183151409750985, 0.10009316412071068, 0.06209144158469093, 0.10006343224836935, 8.65826541377652, 44.27680884638141, 32.95690344225976, 38.059801132448264, 40.3600319739311, 11.021124739800731, 1.1167041813173602, 0.11039518510862706, 0.08316923999377797, 0.2827286401823644, 1.4056542828198404, 3.8674942524202414, 6.0301803196630175, 8.137498209553382, 6.539175020110223, 8.10587655152044, 3.7018885968192934, 0.8215358360640465, 8.076526436113543, 42.31194457700176, 55.5791812558328, 58.16108534413, 56.82719315251997, 57.03250961918985, 57.250616934991655, 57.616252437714614, 55.729729667786636, 54.968397617340095, 54.69974271712765, 56.20033564106111, 56.88866453786051, 58.32704474849086, 55.520839921889774, 56.84389460471369, 58.52605012155349, 56.60987815549297, 48.70447835614605, 43.63685846328736, 43.49307613988077, 51.801907400931086, 55.2769273327243, 56.00027122805196, 56.33341773863762, 53.27549872859832, 56.15620113188221, 55.46823309313867, 51.850580092399355, 45.41027576692643, 40.52321041783979, 40.75181007385254, 40.801879129102154, 42.198050714308216, 51.061505117724025, 53.84667035072081, 56.29152290282711, 52.38583849322412, 51.88586573446951, 51.02006919922368, 52.35229438351047, 50.20566355797553, 50.72332620620728, 57.91361516521823, 54.143531014842374, 53.61080646514893, 50.63866576840801, 47.764117563924486, 41.47224357051235, 44.15587432922856, 39.207204234215524, 38.444911203076764, 38.142845553736535, 38.28241525157806, 38.25801810910625, 39.54844651683685, 39.18323070772233, 39.37865495681763, 39.541943227091146, 41.66776587886196, 46.198593724158506, 48.035745620727546, 50.30746083105765, 51.41727193709343, 49.507501279154134, 50.55867687348397, 48.196794217632664, 50.77361099181637, 50.09298170766523, 50.54524667801396, 48.7332607084705, 50.286299643978, 49.5554797111019, 48.67775132579189, 47.699688711474025, 47.9077116135628, 48.73830879888227, 47.9642996480388, 52.482642589076875, 51.6480367414413, 51.38829346626036, 51.5097104349444, 50.800447848535356, 48.84378133281585, 38.006386295441665, 23.13533167685232, 8.339839558447562, 1.8691507150088589, 2.1102069606704097, 3.2489372116904107, 4.978392345290031, 4.651472107056649, 6.11507119670991, 3.8229020516718593, 1.0983378055595583, 0.5109124636698155, 0.08151006208912981, 0.02100920289634697, 0.6770097945005663, 18.225438133362804, 43.32300216920915, 26.943517731082057, 33.569820850126206, 17.27016252856101, 0.015320478161166032, 0.04796348557236695, 0.05337535666542188, 0.03806740691464755, 0.02749120114341138, 0.03619081708752821, 0.015474096026962564, 0.013247461475041366, 0.04857955049843558, 0.054135549543125015, 0.0237339056817995, 0.03860271468217816, 0.0720963660146921, 0.057839960040104006, 0.0823552945568677, 0.014801869195164933, 0.09471206294913447, 0.015751579776406288, 0.019013185707491734, 0.06943470843496823, 0.0552173997575958, 0.057471230430828954, 0.01834420134283362, 0.041500645269068985, 0.16407073715761786, 0.09648247682038816, 0.11302334932430137, 0.12446071261600142, 0.13118866530637588, 0.12454172641399408, 0.10464836888375784, 0.10442102463134836, 0.14410319167279428, 0.14405194039065994, 0.11978835002669405, 0.13890105630120925, 0.10036416006304565, 0.156329081604077, 0.2795736143185247, 0.13901486632324037, 0.1553157924283897, 0.0988024362032452, 0.23008503921089635, 0.11605462134485284, 0.09650820971376474, 0.0918166489610749, 0.17131016078975894, 0.14734602653451506, 0.19862992869269466, 0.1325014335734229, 0.17168762763181042, 0.23536654129143686, 0.16265448573375904, 0.13007823618188982, 9.349734167898855, 50.22356133307181, 40.495283142212905, 43.627370249840524, 46.84790680485387, 14.242831141717973, 2.103226857800638, 0.4266773578861068, 0.19420016316636918, 2.0323897105070854, 7.629552252830998, 13.290871900896873, 14.136540793603467, 18.136914160943803, 15.208269607636238, 11.148706693803112, 4.8039969032810586, 0.794294546208074, 7.970941624333782, 42.63541460037232, 57.833288946459376, 62.76871711977067, 58.80523266330842, 61.31035635548254, 59.514055944258175, 60.55501376428912, 57.6707027804467, 59.28379712566253, 56.901522067285356, 59.1552375208947, 58.00824234562536, 59.29364227479505, 57.63853542266354, 58.8054209370767, 60.600662308354536, 58.582234151901744, 50.834964706051736, 46.269941637592936, 44.60259306815363, 53.36926298756754, 56.55132109119047, 58.94661449616956, 56.18288501616448, 56.11801293588454, 57.82153360305294, 59.22534204298451, 54.778276412717766, 47.49594511524324, 43.08352185833839, 43.14478535805979, 43.73289769695651, 44.23582792282105, 53.49570843481249, 55.7451210483428, 57.48264474253501, 55.400179970648985, 55.26045337800057, 52.182255714170395, 52.72835162378127, 50.21729338553644, 53.22847343260243, 57.85244580238097, 56.34225483863585, 58.4327212456734, 52.6250599276635, 49.67236634223692, 43.87859805937737, 45.82562731158349, 39.90540965910881, 41.8194321663149, 39.71558263224941, 40.390740210010165, 40.54690937842093, 40.93103885650635, 41.48525407237392, 41.31376412607009, 41.92916047188544, 45.78829811465356, 49.36586056986163, 50.72149838170698, 52.04635343243999, 55.42809940153553, 50.08745901046261, 51.719470947019516, 48.829511750128965, 51.34834804842549, 51.29177962580035, 51.7765296659162, 49.351202672527684, 52.63596803911271, 52.20219704412645, 50.90948973932574, 48.90247568007439, 49.97665597546486, 50.71354381499752, 52.08634199634675, 54.1980048917955, 53.66361333477882, 53.02351390161822, 51.39857007611183, 51.41463610433763, 50.11958322217388, 38.23889263214604, 23.119269570996686, 7.740533755671594, 2.567233443260193, 3.99851048665662, 6.7504677080339, 7.405312801561049, 7.046107044143062, 12.989895689872004, 11.640040432253192, 7.237690312247123, 2.02801295826512, 0.2892645652736387, 0.3008258432870911, 1.9983609429290219, 25.137986021657145, 47.03259944915772, 34.63066116456063, 44.00926397692773, 18.937926869238577, 0.15856141585015482, 0.12549522242719127, 0.13079411470361296, 0.13505753189806016, 0.09153551767550169, 0.18011310858832252, 0.18836292558379714, 0.07247387882201903, 0.2599937552886625, 0.32021347553499285, 0.2192750789465443, 0.1509275795110772, 0.21178028756572356, 0.16870481833334894, 0.16581908769665227, 0.18181650508796016, 0.1637469117920245, 0.13828225644125094, 0.0938495475378248, 0.20423807534238986, 0.13856975391747492, 0.15040717598411346, 0.1451908833076877, 0.3534254401681885], [0.050958839560588526, 0.07221964488346731, 0.02245050922576939, 0.03979363666486837, 0.032008831208992394, 0.01375617066984095, 0.04760136730187843, 0.057622023347404704, 0.009042842486392587, 0.03170244775021509, 0.05504846587897309, 0.05658217773382222, 0.056225081169677366, 0.04143907095215494, 0.014524771362513065, 0.04606687020690692, 0.056757791899144656, 0.04384345705470732, 0.09650550542339202, 0.032282447172028404, 0.032049809252062154, 0.04344767688082592, 0.055405619899712266, 0.019022777128303726, 0.0515862770618931, 0.08449529988631126, 0.01560777549691979, 0.031103326773811734, 0.05730982719650192, 0.03332884283736348, 0.13810925846618993, 20.643714666366577, 35.19425084514003, 27.672045038592433, 35.18175025140086, 26.57191041977175, 9.26084541505383, 1.5002785214493353, 0.08039816973670837, 0.02060033602549905, 1.1167572558887544, 3.0530133506944104, 3.469485957776347, 3.071762525266217, 3.9388210831149935, 6.079906167522554, 3.236944319740419, 0.4966688973288383, 0.7732024296156822, 17.32613475091996, 45.18160943062075, 58.58594079171458, 58.43179164394256, 57.57311813292965, 60.07513138555712, 56.85765820164835, 57.11132964780254, 55.47729769060689, 55.65434955781507, 56.679366865465724, 55.76821988628757, 56.1379817224318, 57.84530316629718, 55.84158389799057, 54.46234126244822, 50.64312158092376, 44.1307907719766, 40.97493017873457, 43.99941490542504, 50.99131430349043, 56.933540375001975, 58.72698530074089, 50.0465565343057, 54.93601452919745, 55.938199720075055, 52.40750174368582, 48.676351039640366, 44.355864217204434, 40.509238935286, 39.748252053414625, 40.219269875557195, 43.17395602503131, 51.26669214617822, 52.00127363204957, 53.23554938839328, 52.839880297260905, 51.87658540664181, 51.61546930190056, 49.663478251426454, 49.435078636292495, 47.57310205890287, 56.960373309350786, 52.6492884082179, 52.09936034294867, 49.3203140074207, 44.009420871734626, 43.27702414604926, 38.343768965813425, 38.128815235630164, 37.326996480264974, 37.16351601385301, 36.3097454655555, 38.21842962695707, 39.27573196349606, 37.37041711807251, 37.93049627734769, 43.92592145550636, 48.86377365358415, 51.68568365035519, 48.58492059092368, 50.728331150547156, 49.53637384599256, 51.01003969869306, 51.082168163791785, 45.7222257891009, 48.16440328474968, 48.63401689837056, 50.700203834041474, 51.37780504841959, 49.77234363555909, 48.971972234787486, 47.86605996470298, 49.50779153454689, 49.24780899478544, 48.98269599483859, 51.4430340643852, 47.831617632219874, 52.51582584073467, 50.82927334693171, 52.555932075746604, 52.66513086134388, 39.95197996016472, 23.244512811783824, 8.110610362022154, 1.2778134523860871, 0.8426479322295036, 1.4231899741195864, 2.796888707145568, 2.4371911825672274, 4.526968233046993, 2.450489978636465, 0.8953627487344127, 0.924664386097462, 0.3757693137853377, 0.035822443709137945, 0.4593890058177133, 6.739053610832461, 31.798321585501398, 28.533297507993638, 22.444470890106697, 27.7700807586793, 3.318515891028989, 0.07608164732735004, 0.043726027267233986, 0.0708225456577155, 0.020236072708822547, 0.02640456479463366, 0.0863012678981308, 0.013122278877774314, 0.03231783277325092, 0.044738592489832835, 0.01942654951445518, 0.026779576324887817, 0.01787278913862763, 0.08192273067130197, 0.021469014614159544, 0.01920499688675327, 0.08751920980191039, 0.0891762120168536, 0.026580895252165296, 0.04035426363829644, 0.06305573177674124, 0.06376710953190923, 0.07437174674123526, 0.04440414148472971, 0.029649345519682093, 0.08687178123622172, 0.03642787533481756, 0.03919276709277784, 0.06590669734343406, 0.058051082380716844, 0.04000825236641592, 0.014015370773361817, 0.04727933075158827, 0.03143585298300511, 0.08344909191251763, 0.02482955122456676, 0.00804973972751008, 0.08448819825125319, 0.0437668903971151, 0.021084495932765065, 0.03903383449200661, 0.03510338592252905, 0.03651034086942673, 0.04849823409571283, 0.030205929464089776, 0.05920934220475536, 0.048905448131864114, 0.09136589814818676, 0.02662331928619214, 0.09338578855198237, 0.049494811063331944, 0.041261020627233295, 0.07982486017769383, 0.039081178725727146, 0.03474364635504542, 0.5373888606986692, 28.735962452427035, 38.66028070449829, 30.53033894108188, 41.84182889999882, 30.215568734753518, 9.579990044716867, 1.3584078632054792, 0.13998323210304783, 0.04679712436852917, 0.08972863035817301, 1.477078682472629, 5.295254645809051, 5.247719441690753, 6.804162994507821, 5.223350246106425, 6.652864429258532, 0.849383928843083, 0.6118980206308827, 20.169549142160726, 49.48001330898654, 60.76733166171659, 59.38246042497697, 60.04351315959808, 61.10851118641516, 58.83556042948077, 57.028971641294426, 57.4723171418713, 56.88292218792824, 57.64367764995944, 56.66482271686677, 56.80514943215155, 58.512596391862445, 58.53693862115183, 55.73770776871712, 53.294392785718365, 46.36121126913255, 42.392843461805775, 45.21901707495413, 54.44453370186591, 55.84093278454196, 59.75665453941592, 53.58780960882864, 56.4153991976092, 58.27416727619787, 53.934547132061375, 51.94439926455098, 45.98009809370964, 41.4599940084642, 41.25790957481631, 41.416036005943056, 42.8478580136453, 52.15641121710501, 54.02800152378698, 53.93870876681421, 54.991861235710886, 53.07240624581614, 52.155689500993304, 50.764024719115234, 50.10431735746322, 49.85962029426329, 57.186988246056345, 54.66576322432488, 54.65573372379426, 49.5500825297448, 46.537172717432824, 46.17944471297726, 40.981562906695956, 40.522708354457734, 39.58827426356655, 39.71702606447282, 36.69962906068371, 39.1730050886831, 40.49260416338521, 38.72257578757502, 39.51629877090454, 44.428549658867624, 50.76672723216396, 51.811572121035674, 51.136669497336115, 51.72261668789772, 51.697415459540586, 53.34386564070179, 50.31568996367916, 47.52767708993728, 48.580115687462595, 50.00990982978575, 50.61155434577696, 51.49882585771623, 50.39770280161212, 51.257203932731386, 48.67509588118523, 48.722242770656464, 50.35163456393827, 50.13919507303546, 50.981316181921194, 49.27353582074566, 52.08214113789221, 52.72609233856202, 50.96791736541256, 51.86171177894839, 40.788056696614916, 26.464431593495032, 10.514710468630637, 2.853498804953791, 2.102172475668692, 3.180648256694117, 5.079924368089245, 5.314899346520824, 6.070092397351419, 6.101415464954992, 3.136619161213598, 0.3319613725668, 0.1932262509099899, 0.0413289956087547, 0.3351873688159451, 6.6987953839763525, 35.97213137534357, 34.849043046274495, 24.67078466569224, 34.42423858950215, 4.815239396787459, 0.07343390956521034, 0.1099883004902832, 0.11001106862339283, 0.014130957161767349, 0.028329180673726147, 0.07982931880941314, 0.0029140390219136833, 0.008667579104733324, 0.060953854643289125, 0.008189173475388558, 0.021944059990346435, 0.006585365054272717, 0.021195076894195333, 0.01248438714913303, 0.05455627353982099, 0.007173041634697228, 0.019351526524030396, 0.04343968275333605, 0.037527862680895675, 0.023704323196603407, 0.026578625716689615, 0.04506077842726823, 0.05013303508261039, 0.01867000513049143, 0.12050238227651966, 0.09172677918667756, 0.18675391111643086, 0.17135410359309566, 0.13163377771214133, 0.1372215311012922, 0.12224875630870943, 0.15718503164187556, 0.10227881296868287, 0.17669654030713344, 0.14424048995058383, 0.1204170554035133, 0.13411754201496803, 0.15875929636099648, 0.17743713282529386, 0.1268012261378669, 0.16402296391465973, 0.11184335941629064, 0.1265461495025985, 0.13973805332376113, 0.11574172039305973, 0.16116208517022673, 0.19552063827793445, 0.09910599854324134, 0.17371085051807666, 0.12973176525725474, 0.13873421767305943, 0.20463736036852484, 0.16967961925172037, 0.10629017191428332, 0.6099129336014871, 31.265222449456495, 46.13932671085481, 36.94996649219144, 43.90282261756159, 36.1869909686427, 12.577039753237079, 2.823722376938789, 0.3345594525096878, 0.41782217821286577, 2.505337461348503, 9.209259383140072, 9.869845355710677, 10.963902261949356, 14.444033042077097, 11.93974873711986, 7.827697646233344, 0.8865077529222736, 1.3017819533424995, 19.51234425267866, 48.93866346728418, 61.44797663534842, 63.0780509210402, 64.27713124982773, 65.22954548558882, 60.23129270922754, 60.109911041875044, 59.692445339695105, 59.72850368868921, 57.32071753471129, 59.73747414927329, 59.96492062845538, 60.73000246478666, 59.56842783958682, 58.048725128173835, 54.822014762509255, 49.352983428585915, 45.2961818633541, 46.86612621430428, 57.023499934904045, 61.25383892366963, 60.252089115881155, 52.95181689723846, 57.626430988311775, 60.262538310020204, 56.1337455626457, 55.280410397437315, 47.75631989202192, 44.12286366185835, 42.92926288420155, 44.149500477698545, 45.634105820809644, 54.11303458675262, 56.78329790792158, 55.95784687226819, 59.53596630404073, 55.24216336588706, 53.791011917975645, 52.11223748422439, 49.672837026657604, 53.779421314116455, 59.201176320352864, 55.044209188030614, 55.37071512591455, 52.68470741087391, 48.41068106312906, 47.88906858813378, 43.52978952469365, 42.50031640452724, 41.88490829160137, 40.787005501408736, 39.0517528595463, 41.07292275274954, 43.69381912292973, 40.702627474261874, 40.88861450072258, 46.860642740803385, 52.15395581337714, 55.79675905166134, 52.81621663801132, 55.05013588936099, 53.87311497042256, 54.110634096207164, 50.799988931225194, 48.08500274535149, 50.524058034343106, 51.4016059906252, 51.5544686009807, 52.72366439142535, 51.35713807998165, 50.98636819470314, 50.26920987713722, 52.62833902912756, 53.175854836740804, 51.34550433005057, 53.40646666865195, 51.360040633909165, 55.94305169197821, 54.157808442269605, 53.67967936300463, 53.428353494213475, 41.35570210795249, 25.90401314919995, 10.019752460141337, 2.2744969062266813, 2.475577458258598, 4.125167006446469, 7.19063412758612, 7.5002444559527985, 11.448933732125068, 9.770012209492346, 7.083400449445171, 2.4219030093762184, 0.8570847672320182, 0.23734893169133897, 0.8999188881247275, 9.558413086398955, 40.43316456579393, 38.26090889592325, 32.324250628871305, 39.415238903414824, 5.682241080268737, 0.24333728777785457, 0.17852557522635307, 0.27805467646929527, 0.175049880279168, 0.18984915147865974, 0.21999872559981964, 0.16500726432329224, 0.1916868891566992, 0.17729203577243513, 0.09799716288163778, 0.15528654319144067, 0.14786932587383256, 0.14539608761908548, 0.08348577986321143, 0.12000857732228695, 0.17431176988588226, 0.17280053888117114, 0.13155643347530596, 0.17419305690113576, 0.1150108648524169, 0.16978238228588335, 0.16633742278622043, 0.11365089024747572, 0.18803692452849882], [0.022386630899423075, 0.04921985061598882, 0.02215756486440378, 0.038433585451134754, 0.06546433519331679, 0.005232591675819769, 0.020673690859468716, 0.10116787056528753, 0.048766598526027896, 0.012823711431044485, 0.037029043681198553, 0.05666188535190398, 0.045275451585410104, 0.013170556781152564, 0.019954307485492002, 0.030459525634444533, 0.0937661971716631, 0.03757477024449937, 0.007035364143385162, 0.04002663847659865, 0.0458218178321277, 0.05333520599731034, 0.08294897439378886, 0.06855973643400977, 0.03672514809295535, 0.06133677603136148, 0.048186953419879566, 0.15755345864642054, 0.0520503884481807, 0.004997676080693641, 0.07281036762100074, 4.361078450756689, 32.715114816542595, 25.900345733088834, 29.859468513919463, 34.967832026943086, 22.10684307159916, 8.954026833657297, 1.1114051817886292, 0.07524302619839869, 0.16268840810704618, 0.6444608023570431, 4.085627063628166, 4.101668086744124, 3.3397329718835893, 4.920089744752453, 4.511035565407046, 0.7598211411987582, 0.8324084623206047, 1.8591930428820274, 22.592454071967833, 45.924023889726215, 61.17996108147406, 56.71167935094526, 54.80484262589486, 56.61442810489286, 56.2256976865953, 53.64313856247933, 53.661330515338534, 57.57053721335627, 56.172867282744384, 55.583774351304584, 56.337724501086825, 54.10174208302652, 53.47646528674711, 48.22190130910566, 43.126059962857155, 43.52982090365502, 52.440331982028106, 53.69516488044493, 56.573898253902314, 50.78293838808614, 50.4939656103811, 55.68127270667784, 55.34183079196561, 53.093720405332505, 48.93926358992054, 43.89562506829539, 40.12518005986368, 38.696405733785326, 39.24583173567249, 44.74282564655427, 50.766629172909646, 54.790204340411776, 51.27051645709623, 51.01653122132825, 51.50326598075129, 49.778415464585834, 48.50757537349578, 52.074500360796534, 41.844378440610825, 44.62704512380785, 55.34391749289728, 49.97667950968589, 50.21422609206169, 40.812912756396884, 41.40438656653128, 39.33528530982233, 39.613667688062115, 37.36643591234761, 35.35249886974212, 36.13817314947806, 38.21191457010085, 36.2363108511894, 39.06407302425754, 42.06049711473527, 49.59932788725823, 50.169009008715236, 52.35241205461564, 50.985058123065585, 51.66456953171761, 50.07276188942694, 50.14833811790713, 49.82195377349854, 48.69637473937004, 48.98534359470491, 48.224976447320756, 48.96761448152604, 47.859893998792096, 49.63761022014003, 50.56780422887495, 50.48945880705311, 49.295430491047526, 46.84869520125851, 52.55041330091415, 48.11440875453334, 48.85248114985805, 47.45718033083024, 50.80744927929294, 44.85349532096617, 45.65614561880789, 29.09752457372604, 11.79719509616975, 1.9929271119256176, 1.0227536097649605, 1.7999099723754393, 2.700190760435597, 3.7969438058714715, 4.577891874697901, 4.574675531156601, 5.306549601016506, 2.0846573768123506, 0.14927852928878801, 0.051782977797331355, 0.2347357904598598, 3.75578343387573, 18.511182800416027, 34.35441255569458, 22.658267521089126, 27.936891317367557, 15.093057828564799, 0.09377483864344897, 0.055465738649570176, 0.033543278508248835, 0.0515152607113123, 0.03191792913111708, 0.04741387877372965, 0.06303008315303633, 0.03478365146645135, 0.06964984890674392, 0.04804559487609133, 0.056442968066661596, 0.02848761531734659, 0.07716006929835967, 0.04182494943961502, 0.05918290068004882, 0.0632584463023851, 0.040875820127586206, 0.057429685482695225, 0.02778373373251769, 0.07053138628121346, 0.00957630493963558, 0.048891325300980004, 0.058887631241833015, 0.02126726535930028, 0.007399162540452616, 0.09151880929787314, 0.02238768810075858, 0.018475832485203302, 0.04912486337425728, 0.10368731158274798, 0.035883163838016416, 0.02283899624261164, 0.06376565779529272, 0.04926750128487906, 0.06606462636902448, 0.04404296167194844, 0.0632978730174082, 0.03898351400670025, 0.017541590176763076, 0.00955396198532394, 0.026881701590853836, 0.014676719156634665, 0.036222939154193286, 0.04691631998866797, 0.0019752672186211474, 0.06666562234562251, 0.04157300993439652, 0.04491795665554462, 0.05748624575414485, 0.04280275342264964, 0.019489594720183842, 0.04623067895731619, 0.07503474987442456, 0.040674909739004034, 0.02529144095587394, 0.03040740675773592, 6.863434910774232, 39.95684369917839, 28.36053671375398, 32.894018042472105, 39.787118819452104, 26.539417505264286, 9.228738854008338, 1.073603952123273, 0.03777556188945328, 0.05281230119327384, 0.2266709836980989, 2.933939507892055, 3.7460890508467153, 6.541866256344703, 6.6154523722587095, 7.33983765686712, 2.124222324740502, 1.1189151723538677, 3.1508674160126717, 26.42157969936248, 50.039025583574855, 60.255568258224, 58.34760973530432, 56.76316830419726, 58.892462253570564, 57.081072484293294, 56.1267755108495, 55.457760364778586, 58.66048935920962, 57.463001512712054, 58.51571075377926, 58.67874406999158, 56.47075168548092, 56.24333266289004, 51.17432817336052, 45.10528010706748, 45.071375139297984, 53.44512162670013, 54.481333378822576, 58.42994812996157, 54.61530977679838, 50.622431078264796, 58.51552248001099, 55.84448252954791, 55.71659757244972, 50.90910926941903, 47.28294472540579, 41.60052076462777, 41.221906139004616, 40.108345247084095, 45.58194614225819, 54.43659090226697, 56.804682670101045, 53.03006033743582, 53.12595836577877, 51.637732674998624, 52.46747086125036, 50.2993062234694, 51.923779364555116, 45.45358265599897, 46.09954995493735, 56.16466560671407, 51.59717536741688, 52.868086061170025, 42.7071233718626, 43.602733842788204, 40.72627544403076, 42.05324857465683, 37.8096676641895, 39.43614513643327, 38.343804267144975, 39.48858330326696, 37.18737579161121, 40.06439116693313, 43.81119997270646, 50.47118448442029, 52.652845997964185, 53.533873096589126, 50.91136855463828, 53.34634850102087, 52.17581125997728, 51.14029376737533, 50.0852781726468, 49.30799384270945, 51.3361769337808, 47.89530515670777, 49.960225166813025, 50.00043730581961, 50.20271001323577, 52.27699664331252, 51.52682373600622, 50.98271254570254, 48.90447608886227, 53.36253220035184, 50.45163539148147, 49.81517984021095, 50.10727874694332, 52.690787084641, 50.01898619436449, 46.90133733134116, 32.92150405145461, 14.357871317094373, 3.5965778606553234, 2.6903039361200025, 1.8388512634461927, 4.1146638797175505, 5.164168544353978, 6.520462862906918, 7.777842850454393, 3.1802192474565203, 0.8792632577880737, 0.08598266725218104, 0.08524836431587897, 0.403011798738472, 3.8106238072918313, 19.217550677637902, 39.94197791622531, 25.835114755938132, 28.796212019458896, 20.70787875883041, 0.2858884464348516, 0.021150833401348323, 0.010522051015868785, 0.0035434245411682156, 0.038239228944744796, 0.05365253110686618, 0.010142974431566414, 0.07235472150627645, 0.017711835980956114, 0.029524873468964815, 0.03414121013314974, 0.018933545122103348, 0.01483344638179387, 0.05005743752624239, 0.024597897727583206, 0.046425200172609864, 0.033503028248707135, 0.06207043545380716, 0.0677018711764005, 0.07479320235189892, 0.010126696020785359, 0.049694610624423916, 0.05520690818347278, 0.019327950168160662, 0.09576666724657822, 0.2590324068742414, 0.07558506913483143, 0.1518782639815923, 0.13645191917256003, 0.16669337787935812, 0.11804064300151602, 0.14541997424056455, 0.15990323417129057, 0.1404704946664072, 0.15376952056202198, 0.09479594191596394, 0.16099029761408606, 0.14774659858836284, 0.1051860323716556, 0.07962000826674123, 0.21479055345539125, 0.19274203737656917, 0.0827266633390419, 0.10929966405514749, 0.1283566757375675, 0.1598444292622228, 0.11977302826820843, 0.1679864883302681, 0.13853301234062643, 0.11081104061656422, 0.1448914961468789, 0.16467593129604094, 0.3009119209262633, 0.11884625340181014, 0.12316813076575919, 0.22847843025961231, 7.205704364084429, 45.22857981343424, 36.21042713042229, 39.15804124647571, 45.59990275290705, 29.40017269503686, 13.440633877631157, 1.7826922382077866, 0.3261083995382632, 0.4390481150438709, 2.4804066313851267, 9.26615140130443, 14.993787542466196, 12.410114465221284, 10.038623963632892, 10.858019840332771, 2.4292822134110237, 1.9494243494925962, 2.61008509224461, 25.022917409096998, 51.22812348027384, 63.76856850039575, 58.39106959681357, 57.86171828546832, 60.122905854255926, 57.81579909786102, 55.952406544839185, 54.540133630075765, 60.92512861374886, 60.17714831136889, 60.54522745070919, 60.969318036110174, 59.80948102089667, 59.147043689604736, 53.156635222896455, 47.6637323441044, 46.801454174903135, 55.336143355215754, 59.35290536572857, 60.22494239191855, 55.300912626328014, 50.635625931524466, 58.774261628427816, 58.59591537906278, 56.9545917357168, 52.869423589398785, 49.579665045584406, 43.232473865632095, 41.3333289084896, 42.906344475284705, 47.464499473571784, 56.99554128031577, 58.76990779753655, 55.95571702526462, 55.99069280009116, 55.20420266735939, 53.0772856743105, 51.78506474341116, 52.43317365646363, 48.65061244656963, 50.68582834735994, 59.078621864318855, 55.89840335230674, 55.48799791643697, 45.87550809306484, 44.598180401709776, 43.56833073400682, 45.238068026881066, 40.11620175453925, 40.68065435655656, 39.65993596661476, 41.2768389332679, 39.505339668643096, 43.6289470426498, 47.297453572673184, 54.426745753134455, 53.144687683351584, 55.326423721928755, 53.93792821514992, 55.3065961407077, 51.389811423517045, 51.12143893395701, 50.73126900580622, 50.94238665796096, 53.65033218937536, 51.11706549121488, 52.090903712857155, 52.35726794888897, 51.001959616138095, 52.13030784360824, 52.32410038671186, 52.40454427657589, 50.03586807558614, 55.26159478772072, 51.35229395281885, 51.7759060090588, 50.71445772724767, 53.84908260837678, 49.56951787394863, 48.47297222383561, 31.769068548756263, 13.666933063537845, 3.4786255705741147, 3.147837875350829, 4.782087524091044, 7.689188949523434, 7.5297990249049285, 9.144637353958624, 11.015058794329244, 11.949806674834221, 5.86913368394298, 0.8645459120312046, 0.312440931316345, 0.6800711431330251, 4.779960618865106, 24.434312812743652, 43.28590439211938, 31.71588120921966, 38.051426872130364, 22.58585076178274, 0.5520517222823635, 0.21598450148538237, 0.11743246112018825, 0.09749568172640379, 0.12938013090001, 0.11982718302357583, 0.14256067363725555, 0.17295099854949983, 0.16447670247045257, 0.10480185459938743, 0.1359460866379161, 0.08942096944778197, 0.1344729455248002, 0.16876595214970652, 0.17568130526811848, 0.12311932330410327, 0.12193135842080079, 0.18246268493033227, 0.25149450006504215, 0.15619996514531875, 0.13435354306092187, 0.22226499754094312, 0.1432878442949826, 0.10200634613753327, 0.10249312606550033], [0.048117587988775586, 0.05904810367933205, 0.022642667059816664, 0.028225243609819203, 0.04956260601419115, 0.06108306686303789, 0.056927384613382245, 0.032829958720192794, 0.1308545283973217, 0.032814640792146806, 0.11719423841925398, 0.06390824974063905, 0.040810760110616684, 0.05737304094157392, 0.04174479366009755, 0.035702110448431586, 0.049455208148086266, 0.018358850859165676, 0.03852554281512576, 0.030538995765269767, 0.03524710401712406, 0.0533679677473922, 0.02950230068827589, 0.04242839306713112, 0.037856365013266766, 0.045303766195091515, 0.028412781933683063, 0.035898581357492555, 0.04768960913943668, 0.04706523982026885, 0.022113961054973548, 0.21570962913815053, 13.828982845429453, 35.47018566439229, 28.754656468668294, 31.67301754797659, 35.77921744315855, 26.16597648589842, 9.638924637148458, 0.5715051461612025, 0.06441847961996833, 0.12530691801540314, 3.8833857351733796, 2.6162716505988954, 4.50911311372634, 4.7979270354393995, 7.8405600786209115, 1.369802471130125, 0.5301036096868977, 0.18233983507079465, 3.8295514497064778, 23.858626542552827, 42.643467226336085, 54.73921352817167, 54.5240479899991, 55.978094147097686, 53.62588013372114, 53.691281733974336, 57.18069676429995, 57.65926514902423, 53.982949179987756, 52.907643164357836, 50.15969730192616, 51.99216196613928, 45.63948339031589, 45.162566323434156, 42.01225980635613, 51.40524202777494, 53.64105186154766, 56.50711205697829, 52.799911345205004, 52.937704209358465, 53.66859082252749, 54.1522700555863, 53.604334554364605, 50.7528224299031, 48.395128865395826, 44.062161061071585, 39.283345284000525, 39.36674271860431, 38.209184600460915, 44.336232754491995, 49.726212639962476, 52.38511677711241, 51.75849068549372, 51.87814650997039, 51.32065219263877, 54.2155457312061, 50.75070042763987, 51.34723017292639, 43.209582913306456, 49.709311146889966, 54.67357266333796, 51.172504271230395, 46.66811320089525, 42.47149482850106, 40.778572405538256, 38.48876722397343, 37.6087599415933, 36.74949415268437, 36.44829534715222, 37.8653064850838, 35.866050874033284, 38.24367400138609, 42.933338226810584, 45.168485180024184, 47.66835681853756, 51.958280532590805, 51.95473863232521, 51.92110038572743, 50.117543589684274, 49.69743028763802, 49.95156849584272, 51.71501905687394, 47.59578512560937, 45.749235230107466, 44.83566030379265, 47.11178425819644, 47.46548398848503, 48.177860936810895, 47.30060323592156, 50.235014653974964, 49.3655114789163, 49.48475937689505, 47.766671026906664, 47.99204649463777, 47.2545075416565, 49.02057040122248, 50.713712476914935, 50.78243632470408, 25.47493919249504, 15.139547721032175, 4.055021544617992, 1.3796902760382623, 1.9323182803007866, 1.3708721750205564, 2.4697108182214924, 5.823800890676438, 5.707390827517356, 5.718863269975109, 1.8570173531770708, 1.1283867157274678, 0.03624637761423665, 0.15555698755047015, 1.7077515562695844, 14.225307952973152, 31.321561413426554, 30.496018202074115, 25.477657395024455, 27.228289650332545, 4.245934822866994, 0.08842498619830416, 0.058543014249974684, 0.03672763021783002, 0.025233766026494485, 0.04105210845028201, 0.01788718393072486, 0.0016685695440936536, 0.004912774386485258, 0.017411521853758924, 0.047168071802345016, 0.028619855499616074, 0.06312915747384391, 0.0651371237190981, 0.08851595147843323, 0.0711161871590922, 0.027224278873613766, 0.02920990407977614, 0.060708216211247834, 0.03328199656079373, 0.016244859960410866, 0.010760075491552633, 0.02531956404357428, 0.04387400098024838, 0.041475709107133656, 0.01431427721399814, 0.07532328156934631, 0.0638501113280654, 0.020158693998030597, 0.09068368919073574, 0.06188026178748377, 0.02433350546315553, 0.0687698743516399, 0.023858806741754376, 0.029673008060443307, 0.011583843133262089, 0.01339319438087724, 0.07957179835366626, 0.050761794085584344, 0.006277758248841331, 0.029609541506356293, 0.10270787583243463, 0.04939998853050413, 0.03000520676704905, 0.02341061849297295, 0.051934080979516434, 0.035810538702794624, 0.018696180439644286, 0.0908020344532786, 0.07686134863404498, 0.08454166352748872, 0.03727802225658971, 0.04351803822623145, 0.04865976373454736, 0.03846060920266375, 0.025684233386850646, 0.018931953574440653, 0.4652408756796391, 20.789048287176318, 38.52226818761518, 32.7229634792574, 34.21045372563024, 42.612696232334265, 30.103298733311316, 8.429759894647907, 0.4191698800892599, 0.05607875837613979, 0.07548125656021219, 0.746357973304487, 3.249413779666347, 5.597755678238408, 10.037373708140466, 10.07879295656758, 2.688067449677375, 1.4980257326556792, 1.0202929966392056, 7.082097241955419, 29.182943990153653, 47.88305559465962, 55.62464544850012, 53.93934419078212, 55.16418272449125, 55.84593380651167, 54.794040418440304, 56.91489734957295, 58.96530066767047, 56.139868382484686, 55.857524410370864, 52.924740775938965, 54.29332240935295, 48.507445935280096, 46.979949474334724, 43.61345368046915, 50.31864743078909, 56.32536511267386, 58.10706253974669, 57.175272126351636, 53.25271760263751, 54.20083292068974, 55.93538738066151, 56.08488459740916, 53.47424522522957, 50.17352365678357, 45.108296409729995, 42.05555885068832, 41.02035122532999, 40.6884834074205, 46.66690118851201, 51.49764522429436, 53.644197602425855, 54.996207221861816, 53.76372398868684, 53.89806516708867, 55.19813868307299, 53.097995788820334, 53.23437267734159, 44.286850114022535, 49.84674707535775, 57.51297643107753, 52.71102259235998, 49.28604425922517, 43.93610000610352, 41.24791537561725, 40.55366369985765, 38.47199516911661, 38.27907731456142, 38.94393867061984, 39.59084341602941, 38.38110992985387, 39.302137359496086, 45.32739216281522, 46.18256299726425, 49.29517553698633, 53.39603708636377, 51.84423761983072, 53.027393125718646, 51.667126917069965, 50.04022975121775, 52.44747461811189, 52.313792397899014, 50.33910259123772, 48.13571899167953, 47.44033375094014, 50.12377623588809, 49.42938727717246, 48.43152061585457, 50.25345371615503, 50.887646059836115, 50.87901292308685, 49.675421868601155, 48.6783161470967, 50.91120773746122, 47.8956267910619, 49.93306667573991, 52.153759694868526, 50.259133308164536, 29.45904354895315, 16.847181973918794, 6.386817414914408, 1.686950736949521, 3.06939562001536, 3.1593470900289478, 6.856805614886746, 5.941804907014293, 8.885051954177118, 5.603575985277853, 2.519133908133353, 0.30857754991419856, 0.1384095342889909, 0.06016188060804721, 1.8630842792411006, 13.529503999217866, 34.603726248587336, 33.75223067498977, 27.410958351627475, 33.56584356677148, 7.134836940996109, 0.07112626887617574, 0.024533293532928633, 0.04289508233928392, 0.008169054091277142, 0.051327657269974875, 0.015530540427613645, 0.026702414033934477, 0.018491885857656598, 0.047437872647518114, 0.10456661198047862, 0.03648662661773063, 0.0474778700980448, 0.043059561416626944, 0.06529216459321399, 0.07625611619122567, 0.015577414474870651, 0.026449654814636996, 0.027398941174690283, 0.017155309493142753, 0.03986728452746907, 0.06595823973897966, 0.04092411047989323, 0.03764141223303253, 0.1203318281219371, 0.021765971361028574, 0.14221709852497424, 0.18102535076679724, 0.10605346606743914, 0.14357681266002117, 0.21227993010993929, 0.10402440559118988, 0.27146371562154065, 0.15663386202387272, 0.208737937913787, 0.09532057424826969, 0.10425568753553015, 0.2066059611857899, 0.18432060136429726, 0.14786911136921377, 0.18488410499788102, 0.3597577084456721, 0.1489048162775655, 0.2323682876604219, 0.1583492401386461, 0.18284130090427014, 0.09743873841099202, 0.16818375597077032, 0.19273809968463837, 0.17546839411220244, 0.20272019469449598, 0.13882493780505273, 0.10067571270009203, 0.12177208874134288, 0.11785135799718481, 0.20918300435427697, 0.16018841806198322, 0.5928988562476251, 21.433013216141735, 47.43563475147371, 39.6431835236088, 40.42384501426451, 47.00514678032168, 33.1032431510187, 12.951098545905083, 0.8350970632126256, 0.35248048603534704, 0.5662855746284609, 8.706484090897346, 6.437019830749882, 13.347276564567322, 14.105914927298024, 17.68073074279293, 4.445649654634537, 1.3101220154954543, 1.0253689113643862, 5.2310297566075485, 26.391612791245986, 46.59292528706212, 56.24932212214316, 55.940243274934836, 54.75049818715742, 55.54559400004726, 55.28827867200298, 57.61117689071163, 60.95397372399608, 57.89027314032278, 57.398698176107104, 54.83502134200066, 56.463110908385254, 49.272951387589984, 50.14452557409964, 46.36107398617653, 54.64475500968195, 58.15593134972357, 60.284252551294145, 57.14468548374792, 55.02858246526411, 54.56267156908589, 58.10241060872232, 58.7178461782394, 55.92074125043808, 52.64843333152033, 48.176021345200084, 43.157148668842936, 43.92598029105894, 41.416749877314416, 49.16098733102122, 53.68835956819596, 54.0050321240579, 57.11407922929334, 56.54158576842278, 55.26963564657397, 56.745223460658906, 53.24490816362443, 52.82382603614561, 47.05987953370618, 54.70724228889712, 58.66671023830291, 55.67896635301652, 52.340762615203865, 46.75592330194289, 44.1462488328257, 41.747978348885816, 39.88676271130962, 40.84985756104992, 40.19026787050309, 41.27648591995239, 39.68083827726303, 41.00502652506675, 47.094106135829804, 48.88357770058417, 51.85145478094778, 55.924898962820734, 53.53976449658794, 55.330859922593646, 54.15820852402718, 51.91233781076247, 51.9538325648154, 53.67519609389767, 52.9801756335843, 49.152613070703325, 49.29585018465596, 51.80288014873382, 51.42737988502749, 51.33182310288953, 51.55253879485592, 53.09893323529152, 53.66901051613593, 52.042733084770944, 51.45851565945534, 51.836298742601954, 49.576687966623616, 52.056618275180945, 53.162695284812685, 52.785465255860366, 30.62828640783987, 17.471819423860122, 6.045879606277713, 2.2972795030763073, 4.675927594784768, 4.4227184980146355, 7.186092513222849, 14.519687717960728, 13.498219174723472, 12.858748301382988, 5.441892944997357, 2.8387315715512926, 0.25052614960699315, 0.38929275747749115, 2.858681726840235, 18.53355403869383, 39.68487439617034, 38.95063415650399, 35.39525662699054, 39.885527164705344, 7.040592681977057, 0.20022691557964972, 0.08818880895212775, 0.24772701754925713, 0.19951633838636262, 0.17606454841311903, 0.11947509667445576, 0.1766962645154807, 0.09071649307565344, 0.13363602511104078, 0.16418640111242572, 0.15807718699497564, 0.1444963633172935, 0.2841609181655992, 0.17425958397648028, 0.2238422653247272, 0.11817005823456472, 0.1782196763181879, 0.1801564691648368, 0.1280870204491, 0.08909863029276172, 0.1346944368654682, 0.1077469876937328, 0.1442517054777953, 0.20388798848275216, 0.14483505078861791], [0.03853258699358952, 0.041170174090732495, 0.010460389556453354, 0.013792438229786293, 0.014987453037211973, 0.08782517765798876, 0.020039402616901264, 0.031177390239111362, 0.007967938774175221, 0.027638006572341247, 0.02257243594935825, 0.037971952359282204, 0.07625531179890518, 0.02448307455427224, 0.03794607390920001, 0.03545513519296243, 0.08826817566108319, 0.0651138729505962, 0.04964625898508295, 0.027351037696785024, 0.027558130414916143, 0.02074198951313813, 0.021697280087297963, 0.06003289821467573, 0.06507173045388152, 0.010595940196165636, 0.008061193699587979, 0.04326749300103515, 0.031194420373668114, 0.06447143927817384, 0.026824892340828816, 0.06803717253909958, 2.153605780293865, 23.170621241292647, 32.97627602854083, 30.43282685741302, 27.01207095576871, 37.63431026089577, 30.446410025319746, 9.690595980613463, 0.6754611937269088, 0.012504462483188799, 0.35810001675159703, 2.0159684626325487, 3.4889271855354314, 6.9863212973840785, 4.838801564708834, 1.9135828340245833, 0.978810377418995, 0.5130335466275292, 0.47660422721697443, 4.414722746418369, 16.91239530040372, 36.64490415203956, 48.70231320781093, 56.36169802758002, 54.42625153449274, 54.71379264708489, 54.8434034470589, 55.10694357656664, 54.46268250865322, 51.7139913958888, 48.60321060303719, 47.68314023171702, 46.85899534533101, 43.38774481127339, 46.26774118792626, 56.82214898447837, 56.82352965877902, 56.36891518869708, 50.9866702172064, 52.00195220208938, 54.436226121840946, 56.73711592151273, 54.09809820113644, 51.393176817124896, 44.227838054780044, 42.77088934375394, 40.1839332426748, 40.0148477092866, 39.671412821738954, 43.712889686707534, 52.2902189531634, 54.29391468724897, 54.11664708968132, 52.33640878431259, 50.7306767279102, 51.48093984973047, 51.003383436510646, 52.31598892519551, 44.31676995369696, 55.758151162055235, 52.44722750879104, 49.35167727931854, 50.8156588000636, 44.35316170415571, 40.18792229314005, 39.45604332031743, 38.95621176688902, 38.06955998943698, 37.91381443700483, 37.68900379057854, 36.692400132456136, 43.248841916361165, 49.13794340625886, 48.77915636185677, 47.13596174793859, 48.30650291135235, 51.8503329830785, 51.68694665355068, 51.24716658746043, 52.413271550209295, 49.996381575061434, 47.61151775237053, 45.789851373241795, 41.70650320668375, 41.231519868296964, 39.4381377004808, 39.877521607183645, 42.56734971077212, 45.514677493802964, 47.02109121507215, 46.18250023934149, 46.70417547225953, 44.46159954993956, 47.50224836411015, 48.0091441062189, 50.55869648533483, 48.92338191309283, 41.178352140611224, 19.202657438093617, 3.2962032431556336, 0.9727221847541871, 1.555728946001299, 5.07912322398155, 2.9426425118600172, 6.244067655455682, 2.763605925344652, 8.660801226092923, 5.352816898976603, 1.6467143282774956, 0.06693566833893139, 0.34291685889324836, 1.2748616236832835, 13.94567237746331, 27.073038316542103, 30.31405748859529, 23.9347146403405, 27.763806927588682, 13.622630873034078, 0.41296128904627216, 0.01423887596766074, 0.0046074160491116345, 0.0782014662399888, 0.021170284373745806, 0.0751057738858846, 0.0606748684039039, 0.008326202664794701, 0.037973526669966604, 0.046192290291430495, 0.026560293232661583, 0.08216538136043856, 0.013117093420136842, 0.013537841357080447, 0.06493569622116704, 0.01677853596066275, 0.03319546692974625, 0.03588577619783821, 0.031802435630872365, 0.05519872636444146, 0.009199283386190093, 0.004785028746306536, 0.04325019090526527, 0.05645336004935446, 0.058672770392149694, 0.10236085332449406, 0.045542295331195484, 0.039001861812486764, 0.05164953677224056, 0.05536852209197898, 0.01945741519692444, 0.04864904233404706, 0.12079950181707261, 0.04863500377283462, 0.03184819980824907, 0.029450553364210555, 0.06024626902334633, 0.028702420625655402, 0.03293531879241909, 0.015434347555011272, 0.09629884554493813, 0.01044357967217483, 0.036130269328432704, 0.0328440623988788, 0.059984259292363167, 0.04621569427751726, 0.027146923145459547, 0.039275508419039755, 0.02368037911853002, 0.030013905695429253, 0.003832490582417156, 0.02617373101172909, 0.05039543168799532, 0.05220118136475644, 0.030205050378196666, 0.03756032948712668, 0.066696779141503, 0.008982061070480175, 4.060949716837176, 30.117095670392438, 36.829306540950654, 31.43318030142015, 33.30382923926077, 43.78193516885081, 32.002873189987675, 8.031654031045976, 0.5523122534636529, 0.02369935511641445, 0.34374757399482114, 0.6063115236259277, 2.0690546785631487, 4.784858678617786, 6.269691519198879, 6.445378401587087, 4.236377477645874, 1.622817655724864, 1.2473683828307738, 7.106106069780166, 21.486033854946015, 42.318691053698146, 52.16833914479902, 55.43065286451771, 54.11499577183878, 55.330789319930545, 55.04640963769729, 56.94713531001922, 55.34369391779746, 53.67688663544194, 52.15418723321731, 48.92269549831268, 48.79488506624776, 45.78646636778309, 48.75556330527029, 58.54190434178999, 55.980055332183845, 58.31018247912007, 54.371467790296, 53.22780662967313, 54.616223689048525, 57.4438956476027, 57.10730137363557, 53.87753940397694, 46.0685710753164, 45.83995965219314, 42.391325504549094, 41.96413232434181, 42.15006835999028, 45.31509160995484, 53.31511074496854, 55.84466688094601, 54.9606744704708, 54.46934661557598, 52.74696719261908, 54.37574317378383, 51.938919713420255, 52.86561889033164, 46.066558899418006, 58.23575550510038, 55.15155661490656, 52.78661058795068, 51.81954629959599, 45.167896824498335, 42.42544620267807, 40.749052647621404, 40.834611308190134, 39.11616602251607, 38.30981692960186, 39.96138188146776, 38.556867414905184, 44.51357879946309, 49.5649443903277, 51.36366882631856, 48.856862437340524, 50.39690656046714, 53.540956897120324, 53.31713076560728, 51.99830047545895, 54.936559738651404, 52.054457049216, 50.11230722550423, 48.111125730699115, 44.37411108324605, 42.7148582858424, 42.17416740232899, 41.93063528307023, 45.739040990029615, 46.53177945844589, 49.051525746622396, 49.934867043649, 48.46024021025627, 46.51365810824979, 48.21209538367487, 49.99149430182673, 51.142396157787694, 51.0471845442249, 41.957782007032826, 23.09393890442387, 5.517337283780498, 1.363959610462189, 3.1242641854670743, 5.083058832153197, 3.423525585282234, 9.343472103918753, 9.041194646589219, 7.192485976603724, 2.0958241195447984, 0.3086203895509243, 0.09872067929996599, 0.12546649413003078, 1.1548261873183714, 12.734812190455775, 31.234829964176303, 34.727241685313565, 29.499389048545595, 30.66842402181318, 19.988894577949278, 0.8302203926347917, 0.03560426952918211, 0.0436283472264486, 0.11405639590755587, 0.04926197013006576, 0.020536687525530017, 0.05592044630658723, 0.011336289481410097, 0.06546952926944341, 0.0070037912660008, 0.007649693401500343, 0.06810633495690362, 0.023474598325969234, 0.023150583353614616, 0.02000710243479379, 0.0015416683961502128, 0.03997430701049105, 0.035472391323456844, 0.02426751847979763, 0.052498971232243126, 0.02608456029256265, 0.07208364129426979, 0.04112971315701162, 0.04200619052074129, 0.09321320426440047, 0.047105562858163356, 0.20403625713961743, 0.14285593924503173, 0.14113047941317483, 0.16713591622969798, 0.10225300346651386, 0.1480630695098831, 0.18478820611151958, 0.12217271442134535, 0.08629130109423593, 0.14394090360691472, 0.1766208814637315, 0.13126133640687312, 0.12135244875905976, 0.06861129415131385, 0.152605204812942, 0.10231875679305485, 0.21097612507160635, 0.12132549012500433, 0.19795960175894922, 0.12362488004709445, 0.07254207596903847, 0.11042283322181433, 0.1400388654081091, 0.09987903488499504, 0.12458782958527728, 0.14021653651950822, 0.1552958741423584, 0.1669523155977649, 0.19348426932288756, 0.18972444768634536, 0.172620217105554, 0.153667293789406, 3.7468320948462335, 33.247915852454405, 45.751878907603604, 40.97629908592471, 35.981454849243164, 48.926319768351895, 39.07092932731875, 12.613831585453404, 0.8877309195456967, 0.09824228803476981, 0.9726291510366625, 6.181703440604672, 12.51976530398092, 14.659609448525215, 12.823724477521836, 7.513948236742328, 3.2504630136874417, 1.0911696740696508, 1.3443075553063424, 6.345325112342835, 18.81789057485519, 42.53560204659739, 53.90397617893835, 57.923056310223, 56.05817717890586, 56.876756222017356, 56.34007400082004, 58.32635441134053, 58.219932663825254, 55.70689362864341, 54.612426834721724, 51.06229351412866, 51.48589772562827, 46.3883658378355, 51.63891330842049, 60.593394156425234, 60.423508459521884, 60.637034446962424, 54.60496256428381, 53.181036287738436, 55.47251632136684, 59.946175621401885, 58.484218043665734, 55.9906731882403, 47.36491833963702, 46.638718958823915, 44.48626733595326, 43.248124122619636, 43.49628463868172, 47.07250172092069, 56.24547427700412, 58.62810234869681, 56.911932037722686, 56.33550051719912, 54.706112646287494, 55.58637096035866, 52.27944812467022, 53.55944695011262, 48.47672985446069, 58.97856612359325, 57.36751925560736, 54.38928319561867, 55.34552174229776, 48.21062057249008, 44.42972636991932, 44.155493859321844, 43.28366864112116, 42.19745451404203, 41.7715714054723, 40.36058110575522, 40.29750939338438, 46.856932178620376, 52.38953336592644, 53.93940694870488, 51.394569258536066, 52.609397903565444, 55.47637201124623, 55.14790488827614, 55.66075871067663, 56.16514413587509, 53.68977946619834, 51.97379742899249, 49.71074673437303, 44.822390925499704, 44.93312335783436, 42.9100432703572, 43.56592239872102, 46.11003445040795, 47.05944415061705, 49.91998164884506, 49.643576145172126, 51.25936123632616, 48.1241479996712, 51.051824708138746, 51.45487569993543, 52.71227775081512, 52.97493926940426, 41.814584116781916, 22.16398416026946, 4.745436406904652, 1.4454519989029055, 4.09642951623086, 10.505916514704305, 8.205738625218792, 12.100623769144859, 9.401351578773992, 18.969235227954005, 12.735575091454292, 4.580943478691963, 0.2727363102378384, 0.4949760575207972, 2.0761056292441586, 16.910383124505323, 34.8692040289602, 41.51905313614876, 34.43731577165666, 37.94835090637207, 21.308330874289236, 0.7627036542661729, 0.07352226248551762, 0.04705687797057533, 0.2285052739804791, 0.106515692877433, 0.15565460247378196, 0.14525793132282075, 0.12040637613784884, 0.1228619637268205, 0.12660848607699718, 0.10127276332388002, 0.14346047454783994, 0.21372210594915578, 0.11537459573798603, 0.12050435112248506, 0.07341280384289642, 0.12188388395213312, 0.16330443472871858, 0.14210305867656586, 0.11908230807391867, 0.1309124446443973, 0.13878405935341312, 0.1381798764510501, 0.15755862207903018, 0.2157676832810525, 0.18346190873172977], [0.06325747720116089, 0.02742802378751578, 0.048601878130988735, 0.06804933035445791, 0.018848013320577242, 0.03348223279200254, 0.011355803656061331, 0.050893863813290675, 0.04371617920696736, 0.05369578060063143, 0.05914920430269934, 0.016936137483665542, 0.01823261872144236, 0.01430800965716762, 0.06257601517943606, 0.09439635811553848, 0.0815186346130025, 0.0806960400434271, 0.033681105386706135, 0.028194213218446222, 0.023167519642400648, 0.04404964195864816, 0.01726847025565803, 0.023524564495610616, 0.006792681374316735, 0.10538909929774462, 0.037002360838795864, 0.05388871984436147, 0.037287031450579246, 0.06299928641848027, 0.04447687004182128, 0.03879607144382693, 0.05698106439423658, 5.192292919082027, 26.021898023543823, 34.09406131313693, 27.39229375316251, 33.964854517290675, 39.34409495322935, 28.50652340919741, 7.292693709173511, 0.46527691245559727, 0.05729393470251272, 0.3422653470789233, 1.6382192099286665, 5.891667700582936, 5.956554489751016, 3.772583435620031, 3.4474848931835544, 3.249815332312738, 0.570233317632829, 0.425641147359725, 3.0863613418994413, 12.693285076848923, 29.471914806673606, 42.05427623564198, 52.10179221245551, 55.68230429003316, 58.964665243702555, 55.99281480235439, 54.085444634960545, 52.7031268612031, 50.90266481522591, 50.79908286371539, 46.41668142810945, 43.205197703453806, 49.973082696237874, 57.02724187604843, 55.919799881596724, 53.4644942129812, 47.12229228788807, 55.58595911149056, 56.05911854774722, 54.933955284856985, 52.44790215646067, 51.26466820316931, 44.80012755240164, 44.204656847061656, 39.4916231401505, 40.1865690754306, 39.21033036324286, 40.626662931134625, 48.02542978717435, 49.81550539693525, 53.03410822345365, 55.35545710594424, 52.3661756515503, 51.5165118248232, 51.41103536851945, 52.467380646736395, 43.522984212444676, 49.38757873350575, 56.02155400860695, 54.27143166142126, 52.15091989886377, 51.208084091063476, 47.13294544527608, 40.915635708839666, 39.696849392306426, 37.026644906690045, 36.89099365665067, 37.04902202852311, 39.9128778519169, 49.34693513378021, 52.994504051823775, 51.12505535925589, 49.656665094437145, 45.78137513129942, 46.41801503396804, 47.51776133814166, 50.87530628327401, 48.015106108880815, 47.737625875780665, 45.99076694057834, 41.47871940366684, 41.933694731804636, 45.423341181970414, 44.506063538212935, 43.3262381246013, 37.83214676764704, 39.269562075215006, 40.728420980515025, 42.40339855993948, 47.02453113371327, 46.25253808113837, 48.10967053136518, 51.48425817489625, 51.661082544634425, 41.854164754190755, 23.665367441792643, 5.420704791622778, 0.4731162288977254, 1.3436061864899052, 2.3304066158110097, 2.4139300565565787, 2.9223189959602975, 11.629625558853151, 6.823844957736231, 4.925916425643429, 2.8965279411885048, 0.30278849926206375, 0.10928163800628916, 0.9554321931735162, 9.753344097445089, 23.03639969518108, 29.807803054009717, 26.732021570205692, 22.37736305882854, 24.562488025234593, 4.244568367158213, 0.03942658095770786, 0.06809983087042648, 0.03983806976447663, 0.08077523821303922, 0.035568883927959594, 0.06353201246970604, 0.0374010827903065, 0.06957324777519511, 0.07357247188807496, 0.022107975993065104, 0.03548751389908214, 0.054561482937706095, 0.03365713832599502, 0.06417335829727593, 0.024513195216235135, 0.048682489732821146, 0.07819354489085176, 0.023992860637184595, 0.02999143825182992, 0.04701008532016028, 0.09089787971348533, 0.010746826958512107, 0.022637432764074015, 0.029207603900783488, 0.018056588953421, 0.050320040975366874, 0.059564144335567, 0.06907236416854205, 0.06069662147051385, 0.03444816241221082, 0.05014816914955455, 0.0452609533714431, 0.061467363378934325, 0.013523652451112868, 0.015355856101509305, 0.057024922927901636, 0.0744973928216965, 0.028337921736942186, 0.03813277336678678, 0.027709840721781218, 0.022488068601477052, 0.03478013895331852, 0.03277279323928299, 0.08831342081389121, 0.0029030461390052113, 0.046612121795694676, 0.06336841822391556, 0.031714699411344145, 0.04876397084444762, 0.08046161713859729, 0.07655056974580211, 0.07368344738478623, 0.026396773680443728, 0.024047187762334946, 0.06578109722824828, 0.04106472974883453, 0.041359631464846676, 0.004525573918550846, 0.07775326649988852, 8.84336696517083, 34.53033478029313, 35.09720748470676, 27.12965772997949, 40.25831314825243, 46.608944246845866, 28.590475859180575, 6.823824855589098, 0.17225675435075838, 0.037663632613276286, 0.23469650547110268, 1.1691742174087034, 3.621189017449656, 5.558490301332166, 11.333868061342548, 6.521356182713663, 3.8345208475666666, 1.9177265729634994, 1.174243635708286, 5.8056741472213504, 17.20604354335416, 33.06872237113215, 46.40059186566261, 53.38042213070778, 55.10124829507644, 59.22271405496905, 59.85032073913082, 56.25048314371417, 53.55713667408113, 50.481257131022794, 52.6510024839832, 48.52948573327834, 45.55312064386184, 51.91461278546242, 59.684082846487726, 56.94632730176372, 54.879559855307306, 49.941954766550374, 55.58437447394095, 57.349115494758856, 56.87743086968699, 54.55616435697002, 52.454895742477916, 46.319681213748076, 46.03214010115593, 41.12490200227307, 42.188813532552416, 40.200873959449034, 44.07029997917914, 50.011251280384684, 53.940340472805886, 55.123378307588645, 55.04707251825641, 55.03611733836513, 53.42525874414752, 50.03633091526647, 53.52960948021182, 45.09536043290169, 52.10429860699562, 56.44293815858903, 54.09491715892669, 54.370887279510505, 51.390403701413064, 48.39845503530195, 41.97895103885282, 40.72014870182161, 39.63072607594152, 38.372563085248395, 38.94642153093892, 41.232194515966604, 50.91309047514393, 54.28022169297742, 52.3133413253292, 51.13570067190355, 47.96945364244523, 48.1946643706291, 50.17411593467959, 52.92068504518079, 50.21090384452574, 49.7900099908152, 47.645308971405036, 44.006643833652625, 43.53406490818147, 45.90178012847901, 46.526707833813084, 43.64292636994393, 39.45288188995854, 41.3916741648028, 43.922336409168864, 44.62860230476626, 48.20676488261069, 48.27167618659235, 49.36577427771784, 51.48985539713214, 53.04720109508884, 45.07671740747268, 26.754404575594013, 7.413729227358296, 1.6874869984965173, 1.806858451135697, 4.039634576728267, 3.923491970185311, 3.7322607348042154, 4.738963515527787, 11.627102494239809, 9.478520289544138, 4.329036118522767, 0.11636810452346841, 0.15450456660361062, 0.6753804787032066, 8.956540092345207, 28.029561235058694, 36.090116270126835, 31.785954352348085, 26.810957308738466, 29.989630406902684, 7.588653699044259, 0.04602724813946313, 0.035065793988084605, 0.02437250891460046, 0.04107246340643014, 0.05126208014365646, 0.064383162966659, 0.02577833962746926, 0.020294710993766785, 0.1173110361841898, 0.02522378773128073, 0.05537624042781611, 0.003174747121633001, 0.06989135812487333, 0.022349238147838943, 0.03329682419256818, 0.03632552598813369, 0.0753302070041818, 0.036975969109804406, 0.02194663979143145, 0.09438810734859399, 0.021310041793772293, 0.03887501297398441, 0.029359676184192784, 0.07465221153031434, 0.05266795490658092, 0.03725680162108714, 0.18281663287310831, 0.2232427249151853, 0.11656856675061489, 0.10960088982697457, 0.12303962717734038, 0.17096585023307032, 0.17411834800675993, 0.12193110561178577, 0.16244255517038608, 0.21423008352998765, 0.2845189876614079, 0.0870547766586946, 0.21641435341969614, 0.11610675362810013, 0.12440258186430701, 0.1910201628361979, 0.18982854371349658, 0.21706149853285284, 0.11548324998828674, 0.16317288211036116, 0.12211104434344078, 0.12383262777040083, 0.22231943574884247, 0.14482256355545214, 0.2122553080440529, 0.13379514157291383, 0.13490025404720538, 0.12468562070881167, 0.16221665116327424, 0.08553743993322696, 0.12310891983009155, 0.1134717329255035, 0.23461742987555845, 8.811199607387666, 37.57192496330508, 44.949789508696526, 37.65849167300809, 45.52105134533298, 51.04974977431759, 35.161569656864295, 9.740425771282567, 0.8415016195466443, 0.20171118028942617, 2.2947262852422656, 5.7455270521102415, 14.583373281263537, 13.358643593326693, 10.324828528588819, 9.967897745870776, 6.037602914917854, 2.1938507691506417, 1.0208822101835282, 4.6110761069482376, 14.43523810755822, 33.05325254317253, 44.51651665472215, 53.13635656910559, 54.71159611978839, 61.541901711494695, 61.40972175905782, 58.4318857808267, 57.11811927057082, 54.85828491949267, 53.49994067222842, 50.514079524624734, 46.19636189553046, 55.657601202687914, 60.53687280224216, 60.70327151206232, 55.50483665158672, 50.65782654669977, 55.13292143421789, 58.94917580389208, 58.664368583310036, 57.216668821150265, 55.9870881419028, 48.697837783444314, 49.180320693600564, 42.7321873172637, 44.62503687027962, 42.940625990590746, 45.66887763238723, 52.007965195563536, 55.28867090902021, 57.05850316632179, 57.44930459607033, 56.16080991683468, 53.831659440071356, 49.821647828625096, 53.37918658410349, 49.24314529665055, 52.62368709810319, 58.81509350192163, 58.53601294179117, 57.23429203033448, 54.8009830136453, 53.13805887776037, 44.80940003548899, 43.14092182344006, 40.9837672787328, 41.019782481655, 40.69576724883049, 43.63228497966644, 54.03759956359864, 57.43383869048088, 55.070355707599276, 53.365077818593676, 50.46660315605902, 50.70587558131064, 50.83851837342786, 54.495061674425685, 51.49270696024741, 51.23967486043131, 49.32536209783247, 46.055615486637244, 45.47333571218675, 49.1208654065286, 48.93381541775119, 46.62744214457851, 42.1471461942119, 42.579516903046645, 43.11542641732001, 46.555388204513065, 50.59152672367711, 50.30786875755557, 51.289900810487815, 54.78169279713785, 54.45868561344763, 44.261138977543006, 26.905551148999123, 7.457638200252288, 1.5962559777882792, 2.9022246935675224, 6.479821224366465, 8.691021127085532, 9.06180081828948, 20.52297430653726, 15.594384785621399, 11.269140128166447, 6.173694941305346, 1.098785323481406, 0.22985933438664485, 1.2363904041628684, 12.968895319969425, 30.29947411629462, 38.61716993393437, 35.23041902049896, 32.288557060303226, 36.384796096432595, 7.428114029668993, 0.20341920396012647, 0.22367081484727322, 0.11326007815378328, 0.16966486439829873, 0.21191904141056925, 0.11743348767800678, 0.08383902300509714, 0.14673963729893008, 0.22402215809110673, 0.11321595915022398, 0.165069792419672, 0.14824250262350808, 0.13900057112257327, 0.10736028183131449, 0.20599168124458483, 0.09971139952540399, 0.2566760736367395, 0.16830657518679099, 0.10913695464090956, 0.2792739513660631, 0.17937783272035662, 0.11769269352718709, 0.09216473633123022, 0.1667842205854193, 0.14676343198985825, 0.20771265180120546], [0.05353227062451263, 0.026531021013074828, 0.01645781516638254, 0.06940727482639975, 0.061510896325231566, 0.12298063074629154, 0.05448981924282928, 0.04084105888802198, 0.05643164528714073, 0.0597440485932654, 0.05842027547318609, 0.016131848585040822, 0.027520184164806723, 0.07510290105616854, 0.01848839058150207, 0.017589148915102406, 0.05361502344209341, 0.0469830998730275, 0.0064934732865602265, 0.05060217583612089, 0.0965639349493769, 0.04403518587951699, 0.019141363708542723, 0.09261829102592123, 0.03352917866000245, 0.01594382188012523, 0.02060948503053477, 0.041993044451960636, 0.04989420717221595, 0.06677236137611252, 0.024699057722764633, 0.05321408366604198, 0.03473435753896352, 0.16252457254355954, 7.673434749726327, 31.16172286771959, 30.736343783717004, 22.475547828981956, 33.34148791528518, 41.29801973219841, 29.107099079316665, 6.442104693382017, 1.1312457558608826, 0.054376587617181005, 0.40913431214228757, 1.3953590417100539, 2.65239643473779, 14.874921094986702, 7.0753424302224195, 4.534138816018259, 1.2819645457690763, 0.7785211022823089, 0.6362208219305162, 1.7570794061306985, 6.328985498797509, 20.335971386201923, 37.111595599882065, 52.01747302086123, 56.96798270748508, 57.340894206877685, 55.06239329614947, 53.769705603199625, 51.716568393092004, 49.82263626590852, 47.775515971645234, 45.671344803225615, 52.63563071527789, 58.066646437491144, 56.336512488703576, 54.15433714466711, 49.47756182762885, 53.44481568182669, 54.730447030836544, 55.16925434912405, 53.93207603885282, 53.056383363662235, 48.17114191670572, 44.212344692599395, 41.71617969389885, 41.521508539876635, 41.43064683483493, 41.064485734508885, 45.771930063924486, 53.230956292921505, 53.739060125043316, 55.22319086136357, 55.25007478652462, 56.66656032685311, 54.780759273036836, 51.13226075326243, 43.62187108685894, 47.74998134182346, 51.39103128064064, 56.020385142295595, 53.910565760827836, 53.63171269816738, 52.99212709549935, 47.09359230533723, 40.22898166410385, 38.87381845904935, 38.88047864360195, 36.19830700658983, 41.08084201812744, 51.76681395499937, 54.10972018395701, 52.26852040137015, 51.15268061237951, 46.833562697133715, 44.539686095330026, 45.718017085906, 44.83476992576353, 47.46249122004355, 44.37191063357938, 41.47401255946006, 43.93869269278742, 49.18358802795411, 48.848103784745746, 48.8084093986019, 48.0264143020876, 47.107348057531546, 42.130197632697325, 41.52275585359143, 46.36271745927873, 48.83160629580098, 49.215618102781235, 50.75616036691974, 51.318659628591234, 42.84910532736009, 24.935527001657796, 4.709238323473162, 0.16525415913952937, 1.034326562958379, 1.1128688387332426, 2.422113101328573, 1.6440255435243731, 2.0077770828239383, 3.9992648074703836, 15.357106885602398, 6.210100420059697, 0.43989565343626086, 0.011157871434284795, 0.9275943353291481, 7.004478929504272, 22.526144443019746, 37.009692422805294, 28.640635128944155, 21.763772964477543, 27.910999751860096, 16.336056936171747, 0.5947012466288383, 0.08116362946889094, 0.09499796696247594, 0.02409970500476418, 0.022977185097613165, 0.030414491155815702, 0.010242728655406786, 0.0145527690033158, 0.1184823769595354, 0.026666677947486603, 0.02106576891345603, 0.019753263031523076, 0.05119953289507859, 0.054779714574256254, 0.04814319064720504, 0.0657251191836211, 0.018548214387509133, 0.10102920099011353, 0.040306697239077864, 0.09437423349628526, 0.02781844900680646, 0.05079400808280034, 0.03417753036163988, 0.03123007985132356, 0.02858197819741984, 0.004341024295201585, 0.025442465614046783, 0.010170865777669656, 0.04759926439052628, 0.10324574616407195, 0.08673857386794784, 0.022424031311886448, 0.008755504931022805, 0.017334491712972522, 0.022830065572634343, 0.02096025562364488, 0.03272829119176154, 0.004113391323405649, 0.02175683576253153, 0.040796966697540016, 0.04019266888198834, 0.042534603496953365, 0.02853344078175724, 0.033973027020692825, 0.02685084739970344, 0.050689165119922934, 0.10831709500522384, 0.05734315202120812, 0.01817946945647559, 0.023939732439635743, 0.09512824787487907, 0.03681235571181582, 0.02794302830983314, 0.08485152311022244, 0.01392084318438485, 0.022496407468532844, 0.05233684021438803, 0.013497284662369038, 0.01037387716238417, 0.056475852390811335, 0.48495060193442535, 14.487449757514463, 37.79841438416512, 32.851736853199625, 25.327550249715006, 38.69703723538307, 49.10416787670505, 32.00943923765613, 6.679215402372423, 0.598622881356747, 0.08409709504414951, 0.1482688560481033, 0.567466146763294, 4.775884785959798, 10.20609446110264, 5.255077317837746, 6.715378674768633, 2.84510346189622, 2.2754569063263554, 1.5831089284150832, 3.8575476119595193, 9.23742788453256, 23.867300864188906, 39.347601552163404, 52.67075554017098, 59.335078193295395, 61.05408045553393, 57.15775874353225, 56.19548759152813, 54.63368608105568, 50.77687048142957, 49.02954870654691, 48.27757543133151, 54.412942932498076, 59.30297751580516, 58.96487705169186, 53.95834807426699, 50.869461951717255, 53.80863120478969, 57.63043180588753, 58.311586687641764, 55.83410786044214, 55.6323411387782, 49.74862898549726, 45.051943717464326, 42.60377284019224, 42.40185706846176, 43.08823654728551, 41.47329476571853, 45.82469378748248, 55.31935168850807, 54.95801902586415, 57.24894600529825, 56.528571344191036, 57.354391082640625, 54.090720222842315, 50.80696290539157, 46.88944078260853, 50.08893774401758, 54.376915962465354, 56.556349569751376, 54.99171610801451, 55.49458749832646, 54.64364890129336, 48.32860154490317, 42.63187662247689, 40.27592066795596, 40.0547029126075, 38.53677311251241, 43.12683659215128, 54.308615730654815, 54.77862942603327, 53.64232663185366, 52.81038015119491, 48.725274762799664, 46.05041834615892, 47.20732535085371, 46.991520466343054, 50.12086191485005, 46.17937411031416, 44.5381171472611, 45.311718371606645, 50.51317737948511, 51.07085212584465, 50.266801541851414, 49.18938136869862, 47.43108480207382, 42.30946956142303, 42.96652932320872, 48.210287171025435, 50.4181501173204, 49.936530128602065, 50.768982595013036, 51.37199601819439, 45.57006136063607, 29.248782934681063, 7.7849256703930525, 0.6856076299182831, 2.4634874876468413, 3.046946424630381, 4.060486632008707, 3.8307676296080317, 4.44326828564367, 5.308014606275867, 6.514127744782356, 4.028630857506107, 0.9411368086453408, 0.06607231023090501, 0.6980726771777677, 7.141392692442864, 24.07095620709081, 35.895092102789114, 32.0016239150878, 25.068579681458015, 31.2012799709074, 20.70043606142844, 1.24841577824085, 0.04624106327912981, 0.038780971850839355, 0.03957322550817363, 0.024980397767297206, 0.04464138742356051, 0.023135935752502373, 0.013639927361040347, 0.0043063162029871056, 0.013214717919547713, 0.009761815045719907, 0.04432554469413815, 0.024273543761322097, 0.06527360228280868, 0.0926740009397749, 0.0428302368269332, 0.053651098522447774, 0.034478330954668984, 0.04431884908567994, 0.016336587498024586, 0.025812080054874384, 0.03448650128238144, 0.03046612931235183, 0.024931879503832712, 0.05581577954393241, 0.029576530777699048, 0.024116064812387192, 0.113610670631451, 0.14926388168767576, 0.15047914228372036, 0.1871571797997721, 0.13218963578824075, 0.13032243436863347, 0.11365485092204426, 0.1141291359559663, 0.2127205992057439, 0.1428369249427511, 0.12930917583646315, 0.14138451416886624, 0.18868734849797142, 0.20645101224222492, 0.14124225164132734, 0.1566696689734536, 0.14640113368870752, 0.10917423247930505, 0.1846699068142522, 0.1669733064068902, 0.15755941881047142, 0.11389490457311754, 0.17320930807580873, 0.19513540330433077, 0.11517972595268682, 0.1512432383793977, 0.2161348232578847, 0.0859903357923031, 0.19877246701188628, 0.20251296791097811, 0.0779191705007707, 0.14497204263123775, 0.15978559370963805, 0.5202431387958989, 14.852289019092439, 45.13570985486431, 42.37243929216939, 31.214900401330766, 43.8865408589763, 52.55841493606568, 35.82187321878249, 9.021931886672974, 1.461148466314039, 0.20485912750084556, 1.8933193794181271, 3.767957490298056, 7.929450792651023, 26.90186215985206, 16.753237285921653, 10.632192319439305, 3.2392943097699076, 2.914288433328752, 2.09577361902883, 3.25921896965273, 8.051202143392256, 22.657634058306297, 38.86473424973027, 52.79427097689722, 60.08468627929688, 63.72314745380033, 58.764600830693404, 57.27216251434819, 56.92741363279281, 53.122812624900575, 52.024780396492254, 49.37171274615873, 56.50411144379647, 62.0850597658465, 60.06040680793024, 55.72085726645685, 51.25311682301184, 53.29680112100417, 55.99246178903888, 59.72647190093995, 58.44016590426045, 58.330359151286466, 50.40922280280821, 47.52445290165563, 44.52831122183031, 44.68492754044072, 46.559475314232614, 44.61016716495637, 48.958122345709036, 57.89234415177376, 57.82690725018902, 58.42080900746008, 59.275391486383256, 60.556629780800115, 56.45501513634959, 50.4839204203698, 49.755755932100364, 51.83472194979268, 56.70808253749725, 58.661622924189416, 58.77746228248843, 59.05497781692013, 57.71540211093042, 52.5679894416563, 45.4561008176496, 42.261502896585775, 42.66888026268252, 39.65869257527013, 45.39064822658416, 56.84269828181113, 57.952921236715014, 53.795393205458126, 55.87640670038039, 51.14484371677522, 48.08013508396764, 49.31066889916697, 47.952885550837365, 51.6124176979065, 47.77541006765058, 46.15631449607111, 47.28184646175754, 53.72341379042595, 52.93770813172864, 53.62346787606516, 51.8104346336857, 50.1561632464009, 46.02187133604481, 44.88707865438154, 50.991957572198686, 53.34761150421635, 50.628173428197066, 52.15165338208599, 52.86448140298167, 45.201790025157315, 27.911919547665505, 5.865611885824512, 0.46998850640750706, 2.5021941719516634, 4.621565015085282, 5.80079815080089, 6.617088981213109, 6.588067364308142, 11.966676788945353, 24.898950899800948, 10.783318300401012, 1.126409350864349, 0.17803242910773526, 1.5913889292747745, 8.615094827067468, 30.042768716812137, 45.407118258937714, 37.35542581927392, 30.054192619939005, 38.050105033382295, 22.873317349341608, 1.1742262301906463, 0.21373361258977847, 0.13149572866818598, 0.20804462834231316, 0.05968446227451486, 0.2570821308801251, 0.1694730513038174, 0.07351596524278003, 0.2043646177457225, 0.1163556632555781, 0.06495601287291897, 0.14333932540349423, 0.15062385629261696, 0.1631278974274474, 0.21757332187506462, 0.17496858302864338, 0.11144151565648856, 0.1630381578879972, 0.16625201930442166, 0.16810673349086316, 0.07185395281281202, 0.11337686825783984, 0.24128119971963669, 0.11292072418596476, 0.15520809578799433, 0.08742185534849282, 0.18262471252631757], [0.02256191756215788, 0.03579489901782044, 0.06971244595103687, 0.020064788855492108, 0.08994413089127311, 0.05739474804290841, 0.03578906525827704, 0.02763645715951439, 0.01537504468879272, 0.08255132879581183, 0.019065693373821916, 0.05754809969315126, 0.03516016835947672, 0.08843907455523169, 0.07634452273768765, 0.03654931942301412, 0.011643559686959752, 0.009942899078821704, 0.034831842227328214, 0.05248471816641189, 0.017609852441256086, 0.03993240966191215, 0.05309043707506311, 0.06200311547746101, 0.07950864206518858, 0.0408581541400523, 0.029701050708911596, 0.051261264260017106, 0.028662250805345756, 0.06394525944826103, 0.016078894672494744, 0.07150538280726441, 0.04453836391950327, 0.0268445405808668, 0.7858992644375371, 13.947030498135476, 35.04913099350468, 25.523835459063132, 21.65341119612417, 28.405049731654508, 39.05958975515058, 28.05288757047346, 8.968337601230992, 0.30604140051910955, 0.3030733920393452, 0.8005467429757119, 5.403569427228743, 10.094198065419352, 3.1255499874391868, 3.646528999651632, 3.161717917649977, 2.6265011920082957, 1.5237051224516285, 0.8702318166052142, 0.6889715526373156, 3.765451340906082, 9.492220147963494, 26.57214576198209, 48.91598824531802, 59.3478141292449, 56.80499253734466, 59.5066701212237, 52.47229929893248, 52.63472072539791, 49.464174778230735, 46.9201333292069, 50.888767857705396, 56.58153118625764, 58.66745941100582, 57.26958943951515, 53.605617169410955, 55.44256118036086, 53.2820333973054, 56.91131230323546, 54.352632568728545, 54.78961206251576, 52.77885606212001, 50.22806029165945, 42.03682168837517, 40.67940312047159, 39.8088252159857, 40.28105897288169, 41.114225310664025, 44.83808432855914, 49.91443541742141, 54.35813173171013, 56.17944117515318, 58.17959893134333, 54.609485057092485, 55.20682281063449, 42.29004206195955, 49.92257825789913, 52.08727552044777, 56.662622267200106, 54.61210912273776, 52.34816412771902, 54.81745696836903, 48.679257515938055, 42.330501310286984, 39.47538060526694, 38.470669407998365, 37.925679606776086, 44.53442227455878, 53.20679449266004, 52.10594600246799, 55.55766313306747, 52.00259547079764, 49.1127892463438, 45.2953032524355, 44.03464563431279, 42.48497601478331, 43.41179678517003, 42.27454085503855, 42.908803801382746, 47.69546039642827, 50.83831048780873, 49.76678563702492, 50.73462263230355, 48.58565407414591, 49.52519509100145, 46.69962552285964, 45.88203491703157, 49.955581080529, 49.755485288558475, 50.42479853476248, 51.82087206071424, 45.34702754789784, 25.201814751471243, 7.314683006655786, 0.3087178359348928, 0.1544682693577582, 2.179884434707703, 2.2678624622283445, 2.5500041871301593, 2.216491915525929, 3.8228880782281203, 2.762079142755078, 3.9953772483333467, 3.5328236558744988, 0.3705090476620582, 0.3091597154496178, 6.033420687721622, 19.461167127855365, 36.64742623606036, 38.085327917529696, 25.93987930205561, 33.344076679598906, 23.660001639396917, 5.026723790553309, 0.08139884144428276, 0.060363472814882, 0.04389268586472158, 0.09006917176227416, 0.08985993016751544, 0.044228010210058386, 0.0256049758454244, 0.007276327045063579, 0.01410932666922529, 0.033291710555673606, 0.011725930418188294, 0.037816287123508034, 0.03403875736459609, 0.024430371535521363, 0.14529931539249036, 0.056084044382817326, 0.07169435371554668, 0.0324055613318999, 0.02227771809444793, 0.020038669087713765, 0.006994090198854646, 0.12202221644862045, 0.019795024399495414, 0.027449127594609896, 0.07773707140116923, 0.012731913030297767, 0.07405625641225808, 0.04235499418310581, 0.10262396622208819, 0.028455832244588003, 0.009403486037626863, 0.04944237234491495, 0.014538576266908599, 0.04119982552384177, 0.07565391745658652, 0.0564228889021662, 0.03405199919436728, 0.01921704170414277, 0.02798031189388806, 0.05665649975379629, 0.04413602603299003, 0.045532772858296676, 0.05894729033893636, 0.06613793332249888, 0.011037997826333008, 0.02404643891138896, 0.05364613044225881, 0.056662762522577285, 0.007239060219182003, 0.012370153863523758, 0.013467821878411118, 0.06711280318878352, 0.03868630636603602, 0.07201692269694421, 0.012483448691425786, 0.041935744905664075, 0.009251200207208675, 0.015925864779180097, 0.026839013256493117, 0.034202033683897994, 0.06577182756436449, 1.6983948647975924, 20.045772867818034, 39.55602453600976, 27.53894332916506, 26.893323159986927, 37.10016973557011, 49.31317529370708, 29.267288677154053, 7.883811564214769, 0.38940626106435255, 0.09571178470768275, 0.21134876555973486, 1.8287422123455235, 7.279824412638142, 3.840720398772148, 4.890665594608554, 4.596412816355306, 5.130332708358765, 2.1569525426433933, 2.6193945927004663, 1.5620771795511248, 6.165383929206479, 12.9543266565569, 31.753355533845966, 52.10090967916673, 61.37931162311185, 58.10805489940029, 59.58940859763854, 55.035325019590324, 53.463866633753625, 50.77164196198987, 48.63872374257734, 53.314161531386844, 59.04267334168958, 60.227001636259025, 58.36721374142555, 53.522945373289055, 54.33119289336666, 55.03982397817797, 58.3397767620702, 55.29091842712895, 55.25925313272784, 55.35275067052534, 50.82652768781109, 43.880225842998875, 42.34950911614203, 42.75296803443663, 41.38846174363167, 43.81287874714021, 47.738571166992195, 52.876072006840865, 55.39113498503163, 56.497823884410245, 59.73967067656979, 57.051690009332475, 56.271832604562086, 45.77876283276466, 52.117505227365804, 52.20875916942474, 57.61528361228205, 53.689140119860255, 53.74885820573377, 55.12131906324818, 51.27862007387223, 43.59581870417441, 39.71912845488518, 39.244870754980276, 38.86313000032979, 45.51224562429613, 54.88975017301498, 54.090755524173865, 54.825062444133145, 54.81697843920801, 49.96175096881006, 47.844294732616795, 47.152561218507834, 43.41472679568876, 46.30181873998335, 43.93095385643744, 44.28824647780388, 50.17704202282814, 51.97326398664906, 50.62295667586788, 50.68854654988935, 50.89669889019382, 49.63223657300396, 48.597193687192856, 46.83977573148666, 51.68880193464218, 50.15237423681444, 50.93837407327468, 54.5445070728179, 48.462966257526034, 30.472521243556855, 10.715546607971193, 0.9993204510500355, 1.2028857632990808, 2.542116300713632, 2.8915607496615383, 3.5052354201193783, 4.173013548697195, 4.907513645387465, 4.3846450313445064, 2.3749012476013553, 0.8252066229620288, 0.1749182970172936, 0.2650051347671017, 5.151873875048853, 22.065567970275882, 41.92700709066084, 38.437133143025065, 26.156152909801854, 35.868973039811664, 29.30431192921054, 7.966161235686272, 0.12398717068736592, 0.047269402252089594, 0.007622978479165825, 0.06141372190247621, 0.0561579373935538, 0.06598322186619043, 0.030708368229229125, 0.06848794633462545, 0.015820634941900932, 0.0298036030688954, 0.07950652000163833, 0.03459884041559792, 0.03863639190732952, 0.04708872807602729, 0.024988997104247252, 0.06577686842290625, 0.025408790304115223, 0.02825476289276154, 0.017901498283590042, 0.018518200977855635, 0.0046880697857798834, 0.026932824553260883, 0.040852680441833315, 0.043958504308736136, 0.05803060485050083, 0.01693629836212964, 0.024879687848771294, 0.13115429860209266, 0.17313665229706995, 0.2428390548354195, 0.07111843945758958, 0.13508662791742435, 0.1938040650659992, 0.11256789473155815, 0.15288689534269995, 0.13461208241360803, 0.15530154319299808, 0.13728623488737693, 0.10915064463211645, 0.2229996605385696, 0.19644247187722116, 0.2644921316494865, 0.10852672730482395, 0.31700963454861797, 0.22091246931062591, 0.12894016660509572, 0.12268914195198206, 0.08958764719746767, 0.18109929357324878, 0.1295704884274352, 0.163910869929579, 0.143800066002915, 0.14920754358172417, 0.161901789026395, 0.13542591293732967, 0.16347305068085272, 0.1118029406174056, 0.12441297001656025, 0.20594709492739172, 0.15085299319076925, 0.21269916406562253, 1.7493155646708705, 20.94908883494716, 48.95351748312674, 36.51181420972271, 32.91580092522406, 39.331555135788456, 48.46029904580886, 34.97634357021701, 11.121305996371854, 0.6188478477058873, 0.48885660846867873, 1.3942166513973668, 11.425770175072456, 18.357300373815722, 7.531808259025698, 9.695342048521965, 9.633746127928458, 6.696762125338278, 3.483956561934564, 2.781961637158548, 1.197175527772596, 6.947401089053001, 11.694895759705576, 30.83266542803857, 51.38452406852476, 63.08315000226421, 61.38026475906373, 63.9913159801114, 57.720332530237016, 57.28230968598397, 52.114794869576734, 51.81490613568214, 54.71166672245149, 61.98254077665268, 62.64245602392382, 59.851842618757686, 53.756855918515114, 55.31542931833575, 54.72398296479256, 62.16816302268737, 58.084238267713985, 57.34669539236254, 57.1764253031823, 54.806054638278106, 45.95556759065198, 45.38361933923537, 42.720322147492446, 43.28996404524773, 45.546299642132176, 49.41337223975889, 54.35584498989967, 58.51117649386006, 58.268974058089725, 62.454703930885564, 58.67724572458575, 58.266177408156864, 47.9947764642777, 54.49819564819337, 53.16084000372118, 58.27411628538563, 55.86815403353784, 56.57510242154522, 58.92114262427054, 53.63423478218817, 47.543837255047215, 41.6335000530366, 41.6613841825916, 41.35295644883187, 47.68396785182338, 59.361248247085086, 54.329529808413604, 57.9704346195344, 57.75479839694116, 53.228030204772956, 49.98774451594199, 48.96651621787779, 45.98829192499961, 47.683861947828724, 46.404584838498025, 47.95093221049155, 52.998873572195734, 53.56465585770146, 52.11973313362368, 53.08923321385538, 52.41712724008868, 52.33685201214206, 50.559516260700846, 50.63667320436048, 53.67544320321853, 52.46774542716242, 53.06821715447211, 54.32336384250272, 46.82119154161023, 27.757276181251775, 8.939310100770767, 1.0784198872504698, 1.5296868595384783, 5.298395974020805, 6.011902074660025, 7.054822060369677, 6.41070366867127, 9.728398803741703, 8.476797938346863, 10.823963861311636, 8.042698935154947, 0.8418899954807374, 0.5785135636406561, 8.281404087620398, 25.204713383028587, 45.03581885368594, 47.816390991210945, 34.21119505359281, 42.92252817461568, 33.36759128878194, 8.00742211841768, 0.22191612110022577, 0.17819660174990856, 0.1660252879223516, 0.1633990772308842, 0.1645143786745687, 0.260440384548518, 0.11416420746113985, 0.1545449394372202, 0.13553207740187645, 0.16375723865724381, 0.13805368644816263, 0.17982781744532048, 0.16218358680846232, 0.19347319169150246, 0.16961860800943068, 0.15856786631047726, 0.1399842586608664, 0.08151894870905146, 0.05195085447461856, 0.11396520080104952, 0.08873494537246805, 0.15430235003511752, 0.14548556668864143, 0.23937791555879578, 0.13569117854199103, 0.11288124767522659, 0.13757793052542594], [0.055055195961387894, 0.03841097819648924, 0.07082249969244003, 0.057900262651063746, 0.01880176842302805, 0.06845891926317446, 0.027057706461017652, 0.03235247143874726, 0.021536633364796158, 0.021993855705424663, 0.08251968936453905, 0.06910587285435008, 0.0918960769570643, 0.018136131862599044, 0.043039191138720324, 0.022950395002901074, 0.12286416239916317, 0.06147316649496075, 0.033646750173741774, 0.03912088123240298, 0.05318620572647741, 0.059136249755899754, 0.01952828982123925, 0.06211468086187398, 0.026001976014325218, 0.05212127073337475, 0.0018916901383143401, 0.0655454485827396, 0.068109376325963, 0.03275162239949549, 0.052903262642963286, 0.009350442109749684, 0.06741386042126725, 0.06619217234753794, 0.1103369547655025, 1.979398489479096, 20.413371516812234, 30.388468773134296, 21.848074505406043, 21.024765083866736, 26.670095189925163, 36.45890143609817, 30.522909971975512, 7.819790638262226, 1.0626504882689447, 0.03852162044495344, 2.236002520207436, 4.463841117197468, 3.0323284864425664, 4.406745135784149, 2.2361488736444906, 3.9806024153386397, 1.6193215981606515, 2.735048373860698, 0.6036359768721365, 0.3377560616260575, 0.950188719697537, 3.8516147819257553, 20.014370372218472, 49.63969299870153, 57.72494131518949, 54.99477947911909, 56.21171051456083, 57.25798706854544, 54.10095760899206, 49.741207861131244, 51.00291275208997, 55.57823596462127, 57.38217715294131, 59.38983840327109, 55.5206516481215, 55.00005114463068, 53.29846028358706, 54.025593188501176, 57.90546448000016, 56.51157179186421, 55.11106598761774, 53.160357552189986, 44.28965460869574, 42.18224356251378, 42.98647849790512, 42.41657772371846, 41.85920499986218, 44.405588103878884, 44.602961770949825, 50.25329682134813, 51.621490140115064, 55.18589304339502, 55.158232488939845, 59.178050025816894, 47.17248293661302, 47.620284249705655, 55.895500798379224, 53.39962605507144, 56.62377903538366, 52.83431837635656, 53.36850989249445, 48.718124281975534, 42.69645060262373, 38.72902808650848, 38.91239104732391, 37.05879265262235, 45.512551569169574, 51.916668107432706, 53.20231906829342, 52.739271502341, 53.650897010680175, 49.71653615274737, 48.50861480159145, 43.736349382708156, 40.44259394368818, 41.924190828877116, 45.29594259877359, 46.39995251932452, 50.16036802722562, 49.80796267909389, 51.78471565246583, 48.11671118582449, 50.39892265873571, 51.60558100669615, 47.54464918567289, 48.72744775587513, 48.565567616493475, 50.662368651359316, 54.17183091563564, 45.835754871368415, 26.21392942244007, 7.591081155884651, 0.7170164380823413, 0.15310454092198802, 1.83066870897047, 3.7273790999766323, 1.5785463538862046, 2.2555626448123687, 3.7945036013280196, 3.438330326349505, 3.925776750810685, 0.9223743347871689, 0.16695472111384715, 0.2546224370598793, 4.409282418989367, 17.591449752930675, 33.850470358325595, 25.437545276457264, 48.01476094030565, 40.887237748792096, 25.941716932481338, 12.837756756813297, 0.15341773298719238, 0.025629211036909013, 0.07286030123190534, 0.011485438181778357, 0.02079551799162742, 0.024211075036756458, 0.03486403324190648, 0.022778157370104905, 0.1283170153657275, 0.026693717020774083, 0.05434683659264157, 0.03022871866461731, 0.047332026109459906, 0.01930614730583564, 0.029706830842300292, 0.06326061433121082, 0.027171254097934694, 0.030446222517639402, 0.05679517698984954, 0.036562660844215465, 0.0386039940490117, 0.025988617356145577, 0.015198464295075787, 0.014419412247896677, 0.024934759994428006, 0.005985034616558903, 0.03557354174253922, 0.040997720038097714, 0.014492517145681045, 0.059025350867980914, 0.04192388969503584, 0.062327519239437204, 0.02679209228635075, 0.03394883396404405, 0.06464492754950639, 0.04467300004175594, 0.03076160942474681, 0.018201122931655378, 0.03616321110917676, 0.046978219892949834, 0.04361291438521397, 0.025261080891434706, 0.05359544606518842, 0.019484844975053303, 0.08273971747727164, 0.015468132032472041, 0.026503018584222566, 0.034141593177111886, 0.0052992858540927695, 0.05754876618964538, 0.02748016564686212, 0.007814440130811907, 0.0542953516536903, 0.033957931258144884, 0.09672005600746601, 0.08279400246758616, 0.08990209564686784, 0.021115798285351168, 0.05212504371640183, 0.04080267022213629, 0.03592062936795335, 0.03901880767737185, 0.019195030082858378, 3.4951169308154815, 26.324916808835923, 36.77190657584898, 24.778771438906272, 24.143908369925715, 32.83432152963454, 46.69363214123634, 31.794279583038826, 7.04053629790583, 0.8695203354281764, 0.02361067277829974, 0.33040587700182394, 1.868679908014113, 3.71333995653737, 3.2421907349940273, 6.069904123583148, 6.453702161389013, 5.625228449221581, 3.065632105835023, 2.367183984287324, 1.4135784511604619, 2.3841837817622773, 6.003930347581064, 25.56318271544672, 52.13624631204913, 59.40244882337509, 55.936807278663885, 59.85488245564123, 56.96578618018859, 54.93305706208753, 50.66847185934744, 52.42798436072565, 57.69434682784542, 59.011051193360366, 59.662388217064645, 55.87938770171135, 55.45277895465974, 53.677251415867964, 55.00842932731875, 59.57725317247453, 57.44774349274174, 59.421350725235484, 54.65365094523276, 46.29114597074447, 44.024420015273556, 43.73108163956673, 44.07996077691355, 43.799574067515714, 45.18126033967541, 47.04242890880954, 53.92641998106434, 54.646225898496574, 57.60377930056665, 56.86172569951704, 60.42972149387483, 47.21903362581807, 49.611083230664654, 56.15515778141638, 53.39999475786763, 58.0970722629178, 54.779649242278076, 54.71164711060063, 50.55158915058259, 44.75723643456736, 40.60075959851665, 40.759337102213216, 40.030058660814845, 47.33324520049557, 54.212223483670144, 55.66728161227319, 54.033594823652706, 54.959666421336514, 52.02066975255167, 49.75138248935823, 44.98044283159318, 44.19293680498677, 43.57851320697416, 46.59886375550301, 48.03512980861049, 52.49524124207036, 52.24768084864463, 53.38705485866916, 51.27994583499048, 51.74718249228693, 53.38034368330433, 49.067587852478034, 51.19203767468853, 50.99167516154628, 52.09068013775734, 53.54344367980958, 45.982231863083385, 30.55678552196872, 11.48003322462882, 1.597878735873007, 1.1767815317838424, 3.303335337869583, 4.169920759816324, 2.7454083340783275, 4.129534075337072, 4.9056809179244505, 5.631749879929328, 3.526294870722679, 0.636558574774573, 0.2858696619589483, 0.4575376777398971, 3.480685550358988, 17.955867359715125, 37.31270336335705, 34.07613608144945, 50.37013246167091, 38.92203223320746, 33.31121113992507, 17.1153740344509, 0.6305662963178851, 0.03171245668894582, 0.06527950115982564, 0.053109305820638136, 0.06894948366548746, 0.04338794883580939, 0.09095031843190232, 0.02656377893271706, 0.05849447491909227, 0.008159274978923702, 0.01933558806476574, 0.027777379033185785, 0.010165937917096721, 0.04970738514056129, 0.10576200791664662, 0.04185920889158884, 0.0297894285270764, 0.029091080012280616, 0.019604563450200424, 0.05416623136449245, 0.15450026118947616, 0.05160132685916559, 0.0484000446064578, 0.011794750969256125, 0.02922746473022046, 0.04373223640986028, 0.04399943255609082, 0.04594187530118131, 0.18285354298930015, 0.15960511871643607, 0.23233821104851463, 0.1746499977044521, 0.10394674725830556, 0.117533860517846, 0.16803672837634243, 0.14242513736169185, 0.15514219690474773, 0.09770085539428458, 0.16773760168542787, 0.16622001215094523, 0.2875158929776761, 0.11652238697053925, 0.12015035721443354, 0.14517880976200104, 0.2238756974017428, 0.1916012711702816, 0.13423289953460618, 0.10383755674645787, 0.25795136488253073, 0.12937064673150742, 0.12647242886164498, 0.1722641854036239, 0.11846844182019273, 0.17645888451126315, 0.18602520828285526, 0.18341271056523248, 0.17044973679848258, 0.15379647153519815, 0.11409496843454339, 0.12444688472896816, 0.19458142980452509, 0.16135808110477465, 0.19582698151709574, 3.030402357539823, 27.189385621778428, 43.08936618989514, 32.17922295293501, 30.657329597780784, 34.55648129986179, 48.12148863269437, 37.77803374874977, 10.455655263316247, 1.4893447920199365, 0.16188743253869398, 4.4256691009767595, 9.230760835832166, 5.756601864291776, 10.358143179647385, 9.147672287879452, 7.338807054104344, 6.321086825863008, 5.905907375197257, 1.5826096842365882, 1.4257976148397693, 1.8480732460175793, 5.779036350788609, 25.346499220017467, 53.38059471499536, 61.99697117651663, 56.67573475068616, 62.6970358048716, 61.04885978083457, 58.45664378135436, 53.36652517318726, 55.283207047370176, 58.90327622813564, 61.9070351508356, 61.76467664780156, 56.466158590009144, 56.47221865192537, 53.18626088480796, 55.55771020150954, 59.14025014446628, 60.26288740096554, 61.16292230544552, 56.90418927900253, 48.64157922806279, 46.866761638272195, 46.29083218113069, 45.93242952900548, 46.0317910102106, 49.133624876699145, 49.37407009063229, 54.17582781084123, 58.077268215917776, 59.247577959491366, 60.02803156452795, 61.14493431583528, 51.30370363112419, 50.95167090815883, 57.388390187294256, 55.72476394714848, 59.134515639274355, 57.635617179255334, 56.712546194753344, 52.51965407402285, 45.48126674467518, 42.51571562982375, 41.4448340477482, 41.74265177019181, 49.6766064243932, 56.076274994880926, 57.07120380093975, 55.38099173576602, 57.89439947374406, 53.825862176956676, 51.85082327935004, 46.59797729984407, 46.08409581645843, 46.21716614692442, 48.44362897257651, 50.228150506173414, 55.18426918214368, 54.45208426444761, 54.516407212903424, 51.759867437424205, 55.4465227742349, 54.96311026234781, 51.26742955177061, 52.903132438659675, 50.907077481669766, 53.330670787442116, 56.318347992435584, 47.35852879862632, 30.018281359826368, 9.771891024804885, 1.3952498282155683, 1.9053213418491426, 5.078890333252569, 8.604443630864544, 6.97403496311557, 8.067183350363086, 10.208949946588087, 8.97381813295426, 11.773648127432793, 2.8502655461911233, 0.38004999860159816, 0.6055807983202319, 5.823543975430151, 22.363440605901904, 40.77710543909381, 34.01999519717309, 53.93388032913209, 47.91817257481237, 37.55802016104422, 18.531530095684914, 0.5431714149252062, 0.16186869402806606, 0.247927870481245, 0.11231429664598358, 0.1646681171992133, 0.11176166380004537, 0.1696091238409281, 0.13289875741447174, 0.16011338741067918, 0.0650670343349057, 0.17383979843749156, 0.18722792035870015, 0.12838191833467255, 0.11640407235151339, 0.14865997457696548, 0.13595630625082603, 0.10324459703218553, 0.1721624182837625, 0.07961920387442074, 0.1239108530083491, 0.20584088449756946, 0.11964019628301745, 0.12701692585382732, 0.06544362017584425, 0.14519279852749842, 0.10508996494595083, 0.15284364201849507, 0.13110822607432643], [0.029457919299602512, 0.10952222791890945, 0.056412768880686456, 0.046176225427658334, 0.01618481015846614, 0.06564134746910104, 0.021565813653832002, 0.03428583604193503, 0.028285335546599764, 0.022736242784547712, 0.029022787104270635, 0.051015821180396506, 0.023283765824030966, 0.10511089446804217, 0.029499224845259905, 0.025337777783974044, 0.046205045655369766, 0.13089433432586733, 0.02513727533721155, 0.010003696774102507, 0.08145756974455812, 0.01775503376378648, 0.007293818747594713, 0.0378707061792093, 0.025574127399933436, 0.034688319485153885, 0.034649026835517543, 0.042588275616928455, 0.07385412411343667, 0.06929807665367281, 0.07696105497739009, 0.07924434939219106, 0.028749044736727115, 0.0345821013944524, 0.02569464643696143, 0.10913627282265695, 2.432684869535508, 17.865643039826427, 31.568843318570046, 24.114665139106013, 19.724128707762688, 22.39535693199404, 36.209081757453184, 26.398214140245994, 10.265092792049533, 1.1130627509086364, 0.16527887313596665, 2.0649729621025825, 3.714061917797212, 2.5781761205965474, 4.864264611274966, 5.942016715003598, 3.847247713035153, 2.69352444717961, 2.743818058121589, 1.0274257655105283, 0.4168865703527005, 0.5977230038373702, 2.9852955908544603, 20.887976346477387, 51.44856068395799, 61.544219832266535, 56.97471741707095, 57.080358612921934, 55.7543582300986, 54.68233131593274, 52.54925227934315, 54.58464076442104, 54.23050565104331, 56.14526164147162, 57.32652264256632, 56.26503513705347, 55.193067058440185, 55.36795769968341, 55.32072844043855, 58.278564253161036, 56.4425459215718, 57.25930890729351, 45.38412924735777, 42.070526615265884, 41.77798055833386, 41.848442016109345, 44.02196853391586, 42.89398116450156, 42.24770792068974, 45.15799676218341, 48.31506544543851, 54.43445321052305, 54.06500124162244, 56.98859868511077, 47.822647171635786, 49.88217784512428, 60.197356362496656, 53.42072840659849, 56.42026293662287, 54.55891393846082, 53.74250396605461, 50.83762799539874, 46.08029503976145, 38.893948062773674, 40.044693023927756, 40.73064496440273, 49.30123559890255, 52.49190330505372, 52.70508804628926, 54.16890874985726, 54.785964258255504, 52.42895710852839, 50.191060573824, 46.22470494239561, 44.52963698294855, 43.274172582933986, 47.440023883696526, 49.10555639574605, 48.76403562484249, 50.009713711277136, 52.759420717916186, 50.63032288705149, 51.32293108970889, 51.5933039880568, 51.49445633734427, 49.693680501753285, 53.62965345382691, 50.67872885734805, 41.4953306413466, 26.6771319220143, 9.170747591603188, 0.8759872819627486, 0.7403904548095119, 0.9843027988268483, 2.564075935271479, 1.478325628465222, 1.3280064300183327, 2.417346440976666, 3.4560474272697204, 3.8065347363871918, 1.9050829352871066, 0.1843685891118742, 0.8550765749908263, 3.1240744408099883, 18.553769934561945, 30.72644764377225, 29.961312855443648, 18.240821669178626, 28.722544024067542, 41.42481819275887, 22.379665490119688, 2.783970380983045, 0.15454339193961314, 0.028061088204624194, 0.004651374174206848, 0.0450496586610473, 0.07347985951890869, 0.038108059370349494, 0.0706368612666284, 0.03793719111971798, 0.11024290215103857, 0.06701171788717471, 0.09551604158214985, 0.044850215330840125, 0.0559794120941191, 0.0301783005031006, 0.10483897922019805, 0.05010693063659053, 0.008011792519790752, 0.01988282382127739, 0.020982908843565854, 0.05710057027998471, 0.017875422565867344, 0.030840970388042833, 0.0429169311668844, 0.07980005425070563, 0.056455148864657655, 0.09015837504017739, 0.02260411751546687, 0.043349786165861354, 0.013271377782427497, 0.02499964572639475, 0.04180298952926551, 0.028773034780075955, 0.03365195957162688, 0.12691303667041565, 0.041866115174226226, 0.042795556026601025, 0.0919457960633501, 0.015105992694565607, 0.03847576242180602, 0.03265276641374634, 0.00968937281399004, 0.026868971124772104, 0.07295876651281312, 0.048208174055382136, 0.07350399894940277, 0.01903007603100231, 0.03954494537244882, 0.013137738532086295, 0.03731695484490164, 0.06376176223819775, 0.02573813341798321, 0.027068985190482873, 0.018512386370510347, 0.03281288645080021, 0.08070285056507395, 0.014032762884462794, 0.02285666606058517, 0.0612043577336496, 0.06611074486206617, 0.05132244404165014, 0.01710592746554363, 0.042128818214780865, 0.06374430692484302, 0.060837026234836354, 4.729357630975785, 25.547920773106238, 36.56900628920525, 26.096832944500832, 18.384050938390917, 30.519362188154656, 48.21073824359525, 28.64158042015568, 9.389311863530068, 0.9700842069522028, 0.0832476337710696, 0.11299733297839282, 0.18509660246631793, 1.9128307195440417, 4.773458309711949, 6.930361332431917, 8.998077992470034, 3.6735852639521327, 3.1678907477086593, 3.5394732990572533, 1.8815153741067456, 1.4184198816937785, 4.304038363118326, 27.00814074085605, 54.56418952634258, 62.56741716015724, 56.72917312191379, 60.337345753946614, 58.892230833730395, 55.01098279030093, 54.49823879426526, 56.35412000840711, 56.81704205851401, 58.74629120672903, 58.11998674946447, 56.35552813929897, 53.40890638289913, 56.628289761081824, 56.576553698508974, 59.40610055000552, 58.67016976879489, 59.20598122381396, 46.587943876943285, 44.3253364101533, 43.910251586667954, 44.93557091682188, 44.570637518359774, 44.75092926333028, 42.28924974318474, 46.101079679304554, 51.44823904960386, 56.77692797876174, 54.822599195664935, 57.859694342459406, 50.202490360506125, 50.27568571029171, 58.8137795079139, 54.68777948810209, 57.686706050749756, 56.16365755757978, 54.60042045962427, 52.6485941486974, 47.04938719349523, 41.94777604072325, 41.88517109040291, 41.609240193520826, 50.36858704782302, 55.173208098257746, 54.76526198848602, 55.0228597271827, 55.63674596048171, 54.325144598560954, 50.44203735166981, 46.458709624505815, 46.51186558508104, 44.41413102611419, 48.37887456340175, 50.299992638249556, 51.71480332651446, 51.704958177381954, 53.133987457521506, 51.79616112862864, 52.362214057676255, 53.57301442853866, 52.40401083423246, 50.942092480198035, 53.40639214361868, 53.48279206983505, 44.947259579935384, 32.323662273345455, 11.417746966884984, 1.5727395299942264, 1.6329735301194654, 4.188741762791911, 3.620342030640572, 4.071725448293071, 3.626652143655285, 3.6671307586854507, 5.227298111684862, 3.80816153941616, 1.9831627391038404, 0.14445488731707298, 0.3601650527167705, 2.642049712519492, 19.380927201240294, 35.33539341342065, 32.99987692986765, 20.363339724079257, 38.312480218948856, 45.87074241330547, 26.655296087265018, 4.833597069786442, 0.12076381744155962, 0.0456991863076485, 0.013735131022610493, 0.0297731414978062, 0.037833520271364725, 0.04107674966836649, 0.03387630842025242, 0.017186177090831825, 0.010454855528810333, 0.05330322182647163, 0.033896559954530774, 0.06472814001984174, 0.04403838046616124, 0.07042771926329983, 0.04175902757373068, 0.027319930696619615, 0.0001438553619898871, 0.0758454854029321, 0.01875153412261317, 0.04286708182565147, 0.032726264889201814, 0.0284994647823154, 0.0204626259754502, 0.04154671779683521, 0.030964398643963283, 0.01318182401929892, 0.03501284965163758, 0.021255004122072173, 0.08370845864016203, 0.18736448319208238, 0.16735023698739468, 0.07278389162233762, 0.09990203284448194, 0.22184639177735777, 0.09299856174977557, 0.14636039313289428, 0.2215971067667969, 0.0948643382458437, 0.23147403322640928, 0.11836061494485026, 0.27851601461729697, 0.1242812182153425, 0.15703336155462652, 0.189156255594665, 0.13036320556796369, 0.11251964651408697, 0.17243179011969798, 0.23699778763036575, 0.19283361552703768, 0.14954644555766738, 0.07119805897556006, 0.14444292102369571, 0.17646896622834668, 0.09941798785040457, 0.33566727693523135, 0.1363778537920406, 0.06323814114195205, 0.1899873997054754, 0.1912442741975669, 0.21394819381736943, 0.19149585747190062, 0.2028749904204761, 0.16728162615289613, 0.20795072128455486, 4.606101070680927, 28.84474938915622, 45.40726338663409, 35.01119775156821, 29.40468538192011, 31.56527003934307, 48.88778640377907, 32.57790442435972, 12.728512863959036, 1.7675422059912838, 0.4014868854034332, 3.889008943111666, 7.624386001017786, 8.643727148732832, 9.107450342947438, 13.354007351783014, 9.046118201748017, 7.258364635129129, 7.618742690932367, 3.4159742872561183, 1.5520702326490035, 1.633784112430388, 4.527947844997529, 24.357848167419437, 55.30824745855024, 65.39031559421171, 59.35197576399773, 61.41439722430322, 60.40335139920635, 59.882990160296046, 58.86674327235068, 61.629099922795454, 58.18538442734749, 59.732990880166334, 59.026548477911184, 57.87976511063115, 54.27683668751871, 57.98610448837281, 58.24478480123705, 60.865504664759484, 59.95631494829732, 63.66142111439859, 49.29545402526856, 45.95462229944045, 46.173835723630845, 44.74411610634097, 48.20597648620606, 46.68076676707114, 45.63086594304731, 47.22167338094404, 52.43010636298887, 58.73765022523942, 57.14452858894103, 60.12760093135219, 53.3691688506834, 52.757816468515706, 59.03529144102528, 53.42606675240302, 58.01978195867231, 58.595746717145374, 57.45537642509707, 54.998831287507095, 49.524504753851126, 43.099219183768, 44.37737449522942, 45.14974017297068, 53.72225276885494, 58.6389986930355, 57.36734274894961, 56.67975125774261, 57.41936514454504, 56.18145335105158, 52.99630834210304, 50.206451954380164, 48.43057924701322, 45.72758374675628, 50.866892799254394, 51.448035086354906, 52.9347663540994, 53.093896911990264, 53.33791540515039, 52.62172983538721, 51.57253503799439, 54.29302038684968, 53.35128676506781, 52.332329519333385, 55.47945107183149, 53.41322883482903, 45.285312975606615, 30.09023527945242, 10.976680363378218, 1.4850289590897099, 1.4596531852599115, 4.254333597998466, 5.840775928189678, 5.966279026000731, 5.347072587859246, 7.235447697101101, 10.250714363590365, 11.3514010560128, 4.7414453952543205, 0.9630594871217205, 1.2379998016741969, 4.58038208946105, 23.12850675275249, 39.07993508923439, 37.80934602983537, 25.15454822970975, 39.40761381579984, 49.338435357616795, 31.014014251770515, 4.672465122515156, 0.18244797604218607, 0.14740843205682694, 0.12506771472192582, 0.14000161821323057, 0.1070932925288235, 0.14284409552572236, 0.1346787933500544, 0.1180332655748052, 0.2936297036226719, 0.15299057768237206, 0.13785481002301941, 0.13471959519290155, 0.1073451592556892, 0.23477466176113776, 0.2406896419462658, 0.09683098553890183, 0.14385171565076998, 0.11898883002539797, 0.09923091684017452, 0.09510174123269897, 0.14777387131846723, 0.12635193855291413, 0.11208070877699122, 0.12890458948189212, 0.09949571513120206, 0.19193055108189586, 0.0888363600918843, 0.10617118313788407], [0.06488691174214886, 0.06450617370466072, 0.020144967617647305, 0.05563751471439197, 0.009361318643054655, 0.06753794368236296, 0.08660599469177185, 0.02145357219682586, 0.08542849456951504, 0.05792066357248734, 0.03766842832368228, 0.014838306252063524, 0.03155584341936535, 0.04691040962033215, 0.017900490877969612, 0.00862528530565361, 0.09181171535484253, 0.02773626117906984, 0.026123272630596356, 0.04254079348738155, 0.028665138956820293, 0.09833254851400854, 0.03332113982328484, 0.08020456399648421, 0.041102907740541046, 0.008671247708280722, 0.07903953578563468, 0.0231690862922058, 0.023419070357997573, 0.018363516334624543, 0.02822944560208388, 0.06342198692202088, 0.03156862559638197, 0.024910723985803705, 0.07308906274697474, 0.01116431710655771, 0.053736789287218166, 2.741323675840132, 20.28411961370899, 35.311180622346946, 28.149719122917425, 19.838605042426817, 27.707185552966212, 37.05070080295686, 28.88187658402228, 15.421328833026273, 2.0168393513848706, 0.15736297854492742, 0.7956190815856381, 1.0261131198175493, 3.8457277945933805, 6.565656902328615, 7.101208010027486, 2.215762109525742, 3.021615758057564, 2.5324297624249614, 2.5134614254197767, 1.4963206047973325, 0.13064219946822814, 3.871147204791346, 22.8517403910237, 49.59120858100153, 58.19822626729166, 59.27987475549022, 60.548502629803075, 59.268260617409986, 57.30759720648489, 54.145362761712846, 54.839539912439164, 58.91434123439174, 58.46134670319096, 57.87340302621165, 53.44957743921588, 54.844760587138516, 56.334872937971554, 59.867979249646595, 55.940247197305005, 53.704507966195386, 47.03410956167406, 44.50351007523076, 43.54932292815178, 43.396997682509884, 44.22282526569982, 44.274439734797326, 44.582938071220156, 44.51852883062055, 45.37715919556157, 54.481545186811886, 53.681511109875096, 61.96199147931991, 49.92148783899123, 48.94766530682964, 54.23559688752698, 55.49904331084221, 56.910523906830825, 56.39731314874465, 54.64069143418343, 52.74875971578783, 47.54735169872161, 39.26399230957031, 41.37532572592459, 40.17950880912043, 51.3994800659918, 52.12994306318222, 54.027624976250436, 54.85489991403396, 54.19019545278242, 52.08431805333784, 52.33925642505769, 47.334425833917436, 45.51496774919572, 47.202049762971946, 51.52193254040134, 49.694049204549486, 52.43842178775419, 53.61500732360348, 53.953727522204005, 51.02148909722605, 53.47000122070313, 51.394141720187285, 50.83033238687823, 53.52216874399493, 47.596106759963504, 37.75929266406644, 22.825240858139534, 10.0615188383287, 0.6555658903333449, 0.05261033360335616, 1.619174264131054, 3.332458691250894, 1.8420229900267817, 2.5012805048496496, 2.1860616774328294, 2.784380268666052, 4.619364565418613, 2.8279600076137053, 0.3562960329075014, 0.3905350150119874, 2.7026662663105996, 19.22562095426744, 27.71188847480282, 22.43129957106806, 24.863773122910533, 19.811307307212584, 27.174684578372588, 20.969757764570176, 3.890311170008875, 0.03474025641598048, 0.09931325597027618, 0.03335711148176943, 0.03859289343498888, 0.062498866295021396, 0.010702575804785857, 0.02221762807288718, 0.06812816080186637, 0.03911071141520816, 0.03655370910682025, 0.04638585389681882, 0.08814403111295355, 0.0590759624666985, 0.04709229804575444, 0.006991589879391776, 0.029641121565814943, 0.04364852598237415, 0.070398791783279, 0.07933635655189715, 0.11184456983521102, 0.06029194701583155, 0.02574730540565666, 0.022432747477244948, 0.008011470284057602, 0.03483361572087292, 0.022499582902978987, 0.0470959063198778, 0.020666286619680545, 0.056752666770931215, 0.03087936096914834, 0.019152638607568318, 0.03910897622605966, 0.044843328200400843, 0.01502626113623621, 0.04844720497907651, 0.04340188397515205, 0.03198194535328977, 0.018457218463863098, 0.055998326804969585, 0.029133867938071493, 0.017567386272393407, 0.006589073877436139, 0.05908255848372656, 0.046965437715933214, 0.018693694484329993, 0.015101157722153492, 0.02779575748248927, 0.015436484940320015, 0.057565765680685166, 0.0690156200359906, 0.06379284625572544, 0.01739194830729356, 0.041688099323261174, 0.022285467073802027, 0.009526489114749336, 0.00862984927446251, 0.03129899520577202, 0.04161248644513469, 0.03024401552524538, 0.03475284324057641, 0.04293745083193626, 0.015339294238196266, 0.022550947183082183, 0.09470746642158878, 0.04671734014165498, 0.18023577458675832, 5.895174299516986, 28.03612728272715, 37.1871796731026, 24.89408519960219, 20.036349373479045, 32.8925020464005, 43.808073843679125, 31.534959923836496, 13.502958378484173, 1.5451519071094453, 0.17857480403636733, 0.20723969976027168, 0.908923730734856, 2.116042712042409, 4.081790250155234, 13.224642680537317, 4.774299658113911, 4.455430084659207, 3.831697721635142, 3.555009807309797, 3.08797245544772, 0.8065597977369063, 4.770787175624601, 28.24251259526899, 53.94819698026104, 61.677662787898896, 59.63927761200936, 61.552276380600475, 61.75930300066548, 58.64118737559165, 55.50835109526112, 56.0212480637335, 59.8594912405937, 60.307978968466486, 56.24556841388826, 54.360136062868186, 55.92820159850582, 57.44782586251536, 60.61552809130762, 57.20952618506647, 56.333727605881236, 47.54871668354158, 44.789658746411725, 45.74225341120074, 45.45102134827645, 46.6643791044912, 46.21875470684421, 45.14457048908357, 46.01290087546072, 47.63225924584174, 56.03236013843168, 56.4272722121208, 61.040822844351496, 51.342566474791504, 49.66880483012046, 54.70872494482226, 55.659986003752685, 57.249722634592366, 58.317305503353, 56.6694668031508, 53.5378582246842, 48.15840205838604, 41.31063015230241, 43.453542570913996, 41.69892518751083, 52.39292229375532, 53.22740654791556, 55.65409068138369, 54.80337173708024, 53.85062409985451, 51.67496381267425, 52.957065028529016, 48.879627873820645, 45.619573439321215, 49.13253445779124, 51.272913025271514, 51.8984918440542, 52.652740093969534, 54.68500637239026, 53.081149208930235, 51.48560354786535, 52.433134432761904, 52.561815631005075, 52.27154062640283, 55.54857107900805, 49.776187558327955, 42.21630934746035, 28.035942931329053, 12.720409247183031, 1.3350252662935567, 0.8499000882429462, 1.8664820324028693, 4.450194701071709, 4.152222045006291, 3.9173809174568426, 6.756871957932749, 5.605742604501787, 3.8726845287507583, 0.90044436315375, 0.12687523789223165, 0.13463184748205448, 3.079326080699121, 17.75082742014239, 35.38925147825672, 30.124626621123287, 28.500618280902987, 20.997575213832242, 29.759648115404193, 30.535145805728053, 8.073511114043574, 0.15944620143742333, 0.018482225488931425, 0.0636114519570143, 0.004547300172083441, 0.026949906398752527, 0.014911647679494515, 0.0533444335263583, 0.03816428256311244, 0.025031074483488357, 0.017164111843392733, 0.0497795123186323, 0.06456314000271021, 0.04781810889741586, 0.03858620548740991, 0.07845144072968153, 0.023626444613440864, 0.005693438569940026, 0.09416974164665708, 0.061739033478642666, 0.052982836195658294, 0.02422464053867565, 0.046694135338428526, 0.047748919666534474, 0.05220777355134488, 0.037159527606901624, 0.08538062939600599, 0.01681942781884103, 0.00950171095844839, 0.02553428508221142, 0.15559086395848185, 0.10708206167985355, 0.14258131204593566, 0.20749281521045393, 0.17916832299482438, 0.10692357341007841, 0.2740824492948671, 0.09348454494630137, 0.1108952260185634, 0.15809218699653305, 0.13082725566721734, 0.14076471839460636, 0.1446238403478938, 0.17451292925303982, 0.11955614877684463, 0.20212710474527654, 0.12257599842644508, 0.15724909191410388, 0.10842564200321514, 0.09072820656001569, 0.24496969857042838, 0.21205817829937706, 0.08694573936443176, 0.17130354179009316, 0.19832946900879184, 0.1680657324651557, 0.16477348493231883, 0.13261502909083522, 0.18944433529771146, 0.1190206916221688, 0.15829752920375717, 0.19358667995660536, 0.21681028298072277, 0.10655117040920643, 0.20536322867678058, 0.11500025453466563, 0.24086408016662444, 5.775732244214704, 31.474576996218776, 47.61868000030518, 37.91093933966852, 27.310371129743515, 37.09237990840789, 48.40688813117243, 36.180754400068714, 19.350903418756303, 3.0702658958973426, 0.31760120764374733, 1.976480000922757, 4.584167666973607, 10.840139715902268, 13.934775052532075, 18.22899180073892, 7.314524640960078, 9.454579122604864, 6.709478449436927, 6.430498400042135, 3.2513104907927977, 0.45601245796968864, 4.969044356576858, 26.218600965315296, 53.21368609705279, 61.85614632021997, 63.80196356004285, 64.82738879419142, 63.40766337610061, 62.70586898249965, 57.07312576232418, 58.457883250328806, 63.07246154354465, 62.81495009699176, 58.19906565450854, 54.51687789732411, 54.53581902288622, 57.76874634527392, 62.536889353106105, 59.892976514754764, 57.78502025911885, 52.31021519630186, 47.868021149789136, 48.78447117344026, 46.00588767759262, 48.46788883209229, 49.00221763118621, 48.52316287256057, 48.26384713572841, 49.68782440308602, 57.619994378859005, 59.29160656467561, 65.12163715977823, 54.973551611746515, 51.76203650812949, 54.42824409854028, 58.21598283706173, 58.365178031306115, 60.8020564048521, 58.6176609992981, 55.98058092978693, 50.47367126710954, 43.451118546147505, 45.76211629375335, 44.221617175686745, 55.508394241333015, 55.62031515182988, 56.36795028563469, 55.21504802088584, 56.253142510691, 53.08632281518752, 55.677923002550685, 51.67985108590896, 48.25639463240101, 52.101639240018784, 54.732643558133034, 53.40277179594963, 55.34322323337678, 55.7706242992032, 53.267685367215066, 52.24339762041646, 53.94248208691997, 53.48963660578574, 54.17779684066773, 55.28263045895485, 49.709546489100305, 41.546858818300315, 25.201963801537794, 11.354333027716606, 1.231737002249687, 0.8026641487113891, 4.700072724973002, 6.298403759156504, 6.067508536000406, 7.0237863063812265, 7.881402248336424, 8.642623982121869, 11.513332186206696, 6.132120759256425, 0.9078673874178241, 0.5905843514107889, 4.328744392241202, 23.332081687065866, 34.24699060378536, 31.60839649938768, 34.776000668925626, 29.553160821237874, 38.106579319123306, 30.97458854798348, 7.746190303756346, 0.1584130399409802, 0.20508492425564798, 0.23867441701792905, 0.08770980481659213, 0.13563796607477052, 0.09936119009169841, 0.07953519467264414, 0.2366873994469643, 0.1552379425735243, 0.07753554431180801, 0.11157720514963712, 0.15694950557043477, 0.18568518781854262, 0.13739756278453336, 0.17836368552619414, 0.11035253699388235, 0.10333908631676629, 0.19171558681034273, 0.15194209442744333, 0.19094876344165496, 0.12368997453802055, 0.11806556384169287, 0.1711215346210426, 0.09854647856686385, 0.18471401815693225, 0.1897080227612488, 0.13505192413445444, 0.14754295709633058, 0.10428580245183361], [0.06891566854450973, 0.017304890075578325, 0.033564698326611714, 0.08592878062758716, 0.06969864870752059, 0.02231508977861414, 0.058914130223133875, 0.07391056947169766, 0.01835159600652274, 0.0209687247256478, 0.040139000592452866, 0.08013665030199675, 0.02373581898639039, 0.00450136123089901, 0.006797633653942256, 0.054746581271531126, 0.036281135023361256, 0.04757622429620355, 0.14056573471715375, 0.07705830983937749, 0.01966469177615739, 0.08094383118253562, 0.0383203040297714, 0.06261101390625681, 0.028588662314559185, 0.04614513757969103, 0.0870636173133408, 0.05847907272137462, 0.0490035763340852, 0.03229393849089261, 0.0790829040230282, 0.04329770750876877, 0.06507856395816611, 0.0781780545930228, 0.05612345577608194, 0.0891411328508008, 0.0486843781395545, 0.01905770307677167, 4.811113063366183, 28.1041431427002, 33.68593869670745, 32.715410955490604, 27.430605503820605, 30.276136013769335, 40.93055640497516, 35.038038530657374, 18.079178833192397, 3.5692713001082024, 0.012861716095358135, 0.3764679859722815, 2.73824657643995, 3.749693463886938, 13.89767433366468, 3.5147045120116207, 1.6814079375997668, 4.18731156856783, 3.306992948055268, 1.6214819661071225, 1.2681498354481113, 0.19377192001669638, 4.555684885671062, 25.1521751957555, 49.279262481197236, 62.880900829069084, 60.4082896632533, 58.19086005610805, 58.242356854100386, 58.07065902217742, 58.34886881612963, 58.605234930592204, 59.22627948945569, 55.46761728102162, 53.95565732832878, 55.71683291466006, 57.89099877880466, 58.87024202654439, 55.76066147896552, 55.7445405375573, 50.36525303317655, 50.1485263916754, 49.56351664758498, 49.82099671517649, 47.13741302490235, 45.538278395129794, 44.55731322688442, 46.69940194775982, 46.43221009162165, 54.90481207447668, 54.814848592204434, 58.149902666768725, 50.93718167274229, 47.705533043030776, 57.235711928336855, 54.05960406026533, 58.105313162649836, 56.918368647175456, 56.19900987994287, 52.81709917130009, 46.726721256009995, 41.917075649384536, 42.40212378963348, 45.12505277510613, 54.66623783111573, 53.56921757421186, 54.852785756511075, 54.95207663505308, 55.262096851102775, 51.74153035686862, 52.827987670898445, 49.631299126532774, 46.49555244753438, 47.07805579708469, 51.20292617428688, 51.5814309735452, 52.87005116862636, 54.93781881947672, 53.05013502797773, 51.849670102519376, 52.301417320005356, 52.35041164582776, 50.830402989541334, 43.70526852146272, 32.029592375601496, 19.03775707367928, 6.419794742138156, 1.3123582567899459, 0.12153912906444843, 0.974968844844449, 2.7305567697171242, 6.297636445491545, 3.7763077260986453, 2.7957419041664373, 4.654869369922146, 4.441626283430285, 1.8212357764282536, 0.31498786722940786, 0.7016444242288989, 2.575632953836072, 18.78328154163976, 27.214037718311435, 23.994138548451087, 23.16684203763162, 23.25004923728205, 27.093271863075998, 11.381924940693764, 2.8471582935702417, 0.28790402376363355, 0.044160954534046115, 0.031147087631266446, 0.09228577056238729, 0.03569889670958923, 0.06588373768834338, 0.09123652121953427, 0.046398674378231655, 0.03666346652373191, 0.02798594072491171, 0.016933777932858756, 0.0464523924634822, 0.053759978768686136, 0.026453661454480984, 0.021719465993585128, 0.022050237861431895, 0.11232768786290001, 0.11461203181815725, 0.03936398774385452, 0.007065466610759858, 0.011140825977969554, 0.024867380646267728, 0.06732838033067604, 0.03784520311221, 0.027747773565351967, 0.04684302835695205, 0.01788682769984007, 0.042682554227330034, 0.04524446715931258, 0.027571816575683417, 0.050004600442104766, 0.008367720799851082, 0.058352840583651304, 0.04551859640125786, 0.032561843268453114, 0.02920307632115099, 0.03620245779353765, 0.08128495481345924, 0.01967955196666862, 0.06768910815158198, 0.0536515505143231, 0.08202586908854785, 0.06328563476281782, 0.06049851113329492, 0.05720341758381936, 0.039381661392267675, 0.037077521725047025, 0.0517477645658918, 0.044219399381789475, 0.07564358293048798, 0.062480836415723454, 0.0453387342783953, 0.008827868638740433, 0.012087252914845463, 0.030802853683370258, 0.04471713053663412, 0.03836743375887314, 0.01578200495831909, 0.08910599239771405, 0.02882532794178734, 0.02443468461053506, 0.03833952900623122, 0.06383522623969663, 0.04308308797678159, 0.08352605310539085, 0.05760990000600296, 0.026413047303175254, 0.1132780505764869, 8.172423974160226, 35.304088977075395, 38.11349053536692, 29.510965924109186, 27.19779714461296, 36.965401018819506, 42.94700376449093, 36.89063672096499, 15.786755469537551, 2.2496102029277436, 0.034711666014646335, 0.0735333018125065, 0.7315320882105059, 2.072757641153951, 12.32764369057071, 6.039039482993465, 3.8267197435902016, 3.0059466246635687, 5.181992775009525, 3.7344932988766706, 2.8871931904746644, 0.6818710820328805, 6.740331813212364, 27.85795165646461, 51.494013109514796, 63.9545359150056, 62.32217488750335, 60.46086119067285, 59.77245384647001, 59.13216613954114, 58.64675714123634, 60.4369661115831, 58.964665243702555, 56.869876384735115, 55.39151937730851, 56.195385609903646, 56.741712939354684, 60.66577757558515, 57.3954543759746, 57.795069371500325, 52.60995488012991, 51.04906728190761, 49.13619402916201, 50.5723306440538, 48.15194583708241, 46.417414911331676, 45.48641681671143, 47.79802645406416, 48.27692431788291, 56.60957221061953, 56.11634985093148, 59.901766546310924, 54.18040521683232, 49.44481003669001, 56.640229455886356, 52.831839438407656, 57.22674539012294, 57.787169717973285, 58.163007305514434, 55.13393732809252, 48.34969605168989, 43.01496667246665, 42.740989115930375, 46.92734656795379, 55.0581963600651, 55.63684401973602, 56.608034641511985, 54.2543811182822, 56.06084831299321, 53.36316370194959, 55.40489858196628, 52.17641530498382, 48.724129430709354, 51.08693776592132, 53.12847260505923, 53.62796291228264, 54.393032981503396, 54.27104726914437, 53.54307105464321, 53.00217620788082, 53.17899665524883, 53.881399016226496, 51.21820772847822, 44.90476069911834, 34.681514693844704, 22.070869053563765, 10.415847128437413, 3.069715293184404, 0.6264558975254336, 2.3028595649426986, 3.495510638721528, 4.389753918493948, 4.618255024956119, 4.228611184704689, 4.628225199637875, 4.669060505205586, 2.006930708885193, 0.5150731484736166, 0.2743809784372007, 2.664921052994267, 16.250904240915855, 33.54144642429967, 26.89347613242365, 23.711839683594246, 25.761611500094016, 29.44051427225913, 20.440845758684222, 5.888419487783986, 0.37636361415347747, 0.026350712643996365, 0.0204238600112618, 0.03172246945811616, 0.035679771324559566, 0.01669009302502438, 0.08778511892042815, 0.0573687240361206, 0.03103434821710952, 0.06960202203763109, 0.023065497798304406, 0.06836160311415311, 0.061055380445454395, 0.027004840648582867, 0.021267770977330305, 0.04461831285528118, 0.04629372416304485, 0.021800387861026872, 0.050776985609122825, 0.056365765556092226, 0.016401944374064767, 0.045492622190185135, 0.06615472596979911, 0.13515868614758217, 0.06181902837969604, 0.03767315125573547, 0.01906343724488491, 0.04238481415555843, 0.06459092601172386, 0.05071523892242582, 0.2197282352755147, 0.12456290108422119, 0.1519628707319498, 0.20349487812528688, 0.17197026811059446, 0.0908030916546141, 0.1800194466787, 0.277044574219373, 0.1887544578001384, 0.19919006153941157, 0.24501920317209538, 0.11423439643676243, 0.1520820586912094, 0.1640376881245644, 0.13346572376547322, 0.1522833712759518, 0.12941976828921226, 0.12562068464655068, 0.2858786711529378, 0.1644393939885401, 0.2076660889771677, 0.19749351386581698, 0.08965255782729195, 0.11599095177746589, 0.08864725894865491, 0.1637381017808953, 0.1935767514571067, 0.1480588100610241, 0.13755836463983984, 0.11245041514836973, 0.13295526405976665, 0.13124907900008465, 0.17820435455970227, 0.1620947052874873, 0.1030074162108283, 0.15626065463068026, 0.12344141731098776, 0.16778874571525282, 8.084878142802946, 39.65982221787976, 47.7775046133226, 42.5533821505885, 40.75155904216152, 42.41022348403931, 51.86793265804168, 44.61931805456839, 22.80901009036649, 4.538947151553247, 0.2944539835856807, 0.8773423382832158, 7.0501108034964535, 11.169012804185192, 26.498458154739875, 12.782892604028026, 7.684465925539694, 10.557882035932234, 8.277171850204468, 4.454337214269946, 3.3453132788981166, 0.7510346030035328, 5.74359332361529, 27.48258867571431, 52.72679444282286, 65.98185216226886, 65.34056817331623, 63.43848536091467, 61.656905604947006, 63.24530078518776, 61.455472284747714, 61.92558403938048, 59.888732510228316, 57.64397182772237, 56.78010509860132, 57.23686118279734, 58.002143060007405, 63.49497533613636, 61.30429629356631, 60.826614364500976, 55.39146838649627, 56.491387274957475, 52.66644485535161, 53.668190740769916, 50.46119028522123, 49.45769894507624, 48.02830880688083, 49.15215415339316, 50.01748000421832, 59.26941379424065, 60.01956316732592, 62.03896407158145, 57.63749599456788, 50.71282602125599, 56.23713139564761, 52.637227119938025, 59.37733780953192, 60.066906175305775, 59.58229341814595, 57.108176062184, 50.34107554343439, 46.374735601486705, 45.478160227498705, 50.847637884078495, 58.07552668356127, 57.37768211672383, 58.5961821002345, 55.15176842289587, 55.591830899638516, 54.24342201602075, 57.041919385233236, 54.70036637398505, 51.58127407873831, 51.968670891177275, 56.65320857878655, 54.97466948724563, 54.31234982705886, 55.04037311000209, 52.984411793370406, 54.13540386384534, 53.47339799327236, 53.574473550242764, 52.3743930170613, 47.62184927540441, 33.6810435787324, 20.02236024025948, 8.6862652532516, 2.4377013358377644, 0.3675901300964817, 2.6779435671144918, 5.993747874613732, 11.539199236900577, 8.10936991245516, 8.811965450163811, 12.421977673807453, 9.718281049882213, 5.964110935887983, 1.1238248766429964, 1.167072930162953, 3.7094935822871427, 23.395282837652392, 34.51623778189383, 31.59160287149491, 31.495936262992124, 33.382021688645885, 38.20552110671997, 21.79748377492351, 5.839121668569504, 0.6876748415731615, 0.13748416136349403, 0.07679096047556208, 0.17324882289094312, 0.1801177357593852, 0.11109986342489721, 0.16498022141956514, 0.14438336534846213, 0.17258332231112067, 0.1458877475271302, 0.16257447551094717, 0.19726230853026916, 0.20805945980452722, 0.15946264168427837, 0.09158387314528228, 0.13377991174497914, 0.20386491391447284, 0.15279508736585418, 0.11418597967994791, 0.1581416456329246, 0.09444538774269243, 0.15981268257864062, 0.20317079228979928, 0.204079816898992, 0.0909476294632881, 0.19193157763971438, 0.12777382072301643, 0.18193360928806568, 0.18717597959743393, 0.1118460713675426], [0.020958987748130195, 0.004639495502135927, 0.03416469455846856, 0.049596666283304655, 0.05103388170321142, 0.06027588981293863, 0.02049935989141945, 0.03884343099930594, 0.046292023447852944, 0.0680417767275245, 0.10042785261307033, 0.10137131287445945, 0.048716052044783874, 0.014185204805295556, 0.04338938525066741, 0.08439209252115219, 0.06646820914841468, 0.03035807644107169, 0.019978990838412317, 0.0570172390660211, 0.03594897845159135, 0.016367468502252333, 0.027870330396258546, 0.05564622130365141, 0.030882873482281165, 0.0891683213112335, 0.02372403080845552, 0.03751357131066822, 0.008694948553438149, 0.03418621779870122, 0.032110801342153744, 0.07509241331248515, 0.07683302636348432, 0.03103008685303071, 0.0538465773476468, 0.07979705118604245, 0.027542262818784486, 0.07606796499702238, 0.13939325247080098, 4.33148612899165, 24.06601009830352, 34.851110135355306, 23.914526201063588, 22.747515170804917, 32.93528726024012, 31.92877765624754, 30.601284811573645, 19.35543179512024, 4.422420397881539, 0.37493394086918524, 0.26173617630716295, 0.7365906587050808, 10.515509651553247, 3.1338666379451756, 2.4493958825065247, 1.3228121087435754, 2.038381130945298, 3.7402756079550716, 2.2853297571982107, 0.3622113348495576, 0.390858058967898, 3.703027064761808, 26.828107872316917, 47.632227866880356, 59.199803490792554, 61.96953811953145, 61.25017150755852, 60.04223054455173, 60.44967066857123, 62.48366278986778, 60.676987709537634, 54.09711760859336, 54.917324435326364, 56.49385836816604, 59.056048623977176, 59.08994574700633, 56.06553162297895, 55.084138916384795, 57.50118578633955, 56.00701770474834, 56.325498473259714, 54.08615850633191, 52.11428888382451, 49.33435609263759, 48.59123168453094, 49.68326268657562, 51.68943343623992, 57.0889211470081, 57.604967778728856, 65.00584879229146, 54.263990925204375, 43.458786779834384, 50.235081334267896, 58.44172700758904, 59.7600003211729, 57.32242376573625, 55.753550221843106, 53.97566141620759, 45.850291175227014, 42.67721529929869, 43.229602690665956, 44.616042875474506, 51.506549004585516, 53.83720959386518, 55.115282535552986, 54.3213124429026, 55.08557842623804, 55.794307570303644, 55.1114974483367, 51.30499409091089, 48.213028907775886, 51.038472960072184, 50.480288305590236, 54.114736895407404, 54.42247821438698, 53.85536232302266, 54.50063928481072, 52.0945672065981, 51.08265453769315, 45.84756905032743, 36.574591744330625, 24.985345025216382, 12.739111108164634, 4.830092432037477, 1.16531717921457, 0.6926712670153188, 0.9442465127475801, 2.026029464698607, 1.5238774615910746, 2.0585593965745743, 2.8379475878131006, 3.2921678596927277, 4.855588328453803, 4.177963579854658, 1.145789291589491, 0.4184374693901308, 2.1047259386508697, 17.630024302390314, 26.759599754887244, 22.071375039315996, 21.504259147951682, 28.93768014446382, 27.05477183864963, 12.816285702490038, 1.7531196508676776, 0.25241693121290976, 0.06466192704054617, 0.06426020202437235, 0.027868964844533516, 0.022531676241346908, 0.016292935808099086, 0.04879105205257093, 0.05850925275515165, 0.05236809660169867, 0.033661202422433326, 0.04626438682598453, 0.027015893382110426, 0.006741311348554108, 0.06443166399314519, 0.10294242131133234, 0.025130731031118382, 0.03925609192059886, 0.027420087116620234, 0.021386252220479712, 0.06510529276584426, 0.02465198353503741, 0.04220285295178333, 0.017565675981102452, 0.030932690264777313, 0.004076625327504571, 0.016859913650419445, 0.025971951113352855, 0.019041182390684565, 0.025816697649837985, 0.029456917639641516, 0.061246350843219034, 0.03247798728426138, 0.042338071300858454, 0.02339196808245634, 0.046145225679802324, 0.04516963952130849, 0.06984569162370698, 0.040245632370633465, 0.017914598387095238, 0.04020974881226017, 0.026997518763246558, 0.08469825189921164, 0.05341880534204745, 0.03787115817108462, 0.020531734767099543, 0.04931139812294034, 0.018132125222755056, 0.018726969513321118, 0.03375462684479933, 0.02361654101179973, 0.07225378176137325, 0.07892964047289665, 0.020410187257033204, 0.024343663789031487, 0.031204151605526288, 0.023251695468300776, 0.06966314819310943, 0.013693776638847927, 0.03993196150047645, 0.004174244560060963, 0.08892573190913086, 0.014540374658310847, 0.05179350384541097, 0.04780799653681536, 0.011520130473429398, 0.045959644710585, 0.016647902647814444, 0.00847703867381619, 0.04495896917257098, 0.20774516457271194, 8.109279207644924, 32.511767379699215, 38.70786297705866, 28.402313878459317, 25.535935971044726, 41.745609237301736, 41.64548289391303, 36.38742408444805, 17.507703227381555, 3.1575479478605333, 0.28226500377058983, 0.2499617879549342, 0.6348201067697617, 5.9790311417272015, 5.8509740906377, 5.514955914789631, 4.540116508160868, 6.757724583148957, 5.789188915683377, 4.320209805042514, 0.8936426055527503, 0.742982957632311, 6.209464996091782, 31.10577614076676, 50.14277227463261, 59.93994689756825, 63.57977305689166, 62.591782923667665, 61.92834146561162, 61.95589219370196, 62.596831014079434, 61.374063491821296, 56.01676087225638, 56.37581463783019, 55.73922572597381, 59.49969614705732, 61.908964956960375, 59.929984077330566, 57.37686234135782, 58.60888273485246, 56.980283260345466, 58.5978961759998, 54.416724097344186, 54.376433510934156, 49.027477695095925, 51.68917455980855, 50.54878857827956, 52.21461919046218, 57.87539951262936, 58.902338781664454, 65.19680546176049, 53.740931095615515, 45.706983458611276, 50.39918153516708, 58.894066502971036, 59.35828685760499, 59.63033068564631, 57.78884064766669, 55.46356939500379, 47.87801927135837, 43.534288483281294, 44.21046587728685, 46.650968520872055, 54.38136393024076, 54.71313761126611, 57.772711861518125, 54.80369337143437, 55.0528540918904, 56.56544946855115, 56.94681367566509, 51.36293142072616, 50.34784947672198, 52.57955651129446, 51.38097432351882, 55.45932931284751, 53.1124379557948, 53.01891688377627, 55.044224877511304, 54.40659653755927, 51.59127612267771, 48.32766409843199, 40.84704522163638, 28.91375368641269, 15.559736528704244, 7.573415290924811, 1.9598270880599178, 1.6692679567683129, 2.4817762740196723, 3.1527756491015038, 3.6376916545052684, 3.665936642116116, 5.573412468356471, 3.620105217541418, 2.204669891826568, 1.280295454686688, 0.6319912811440807, 0.04967473447322846, 1.953881387749026, 15.391148155735387, 32.88747945139485, 25.684240787259995, 22.01439869019293, 31.33761175217167, 30.844285449674054, 19.53058131279484, 3.300564918787249, 0.8920371304115943, 0.07165699926835876, 0.07357661642374531, 0.06519564517563389, 0.0729245453652355, 0.04959038819276518, 0.032911872671496485, 0.04337328974337828, 0.08016203079492816, 0.04425268973253908, 0.013800646861894958, 0.04615496648775955, 0.029405704661903363, 0.04849706198118868, 0.06885726200116259, 0.04480839076061403, 0.05881348159164191, 0.041999441286128376, 0.058183665387332446, 0.019544823913865035, 0.09640174647492748, 0.0871647562411043, 0.028914927670191375, 0.05145116213468775, 0.040476274631556966, 0.021286561198893095, 0.02237408237922336, 0.018164245374200326, 0.009314039526807686, 0.09915236984529804, 0.04315591612530332, 0.19246393213829688, 0.07316124355120045, 0.12208494372786054, 0.18102309846829984, 0.11857144234161224, 0.2453598824720229, 0.16071585427609184, 0.11787069405639365, 0.11761805358072443, 0.18437692414849036, 0.24151036726130595, 0.1703103394397805, 0.25687265179810986, 0.14721516339528948, 0.1444882887505716, 0.18944697064017096, 0.13619783845159317, 0.12080725462686633, 0.15121936707967712, 0.21422963919899157, 0.14858587855292907, 0.10944013393694356, 0.11426148530576499, 0.16746560982879133, 0.13102099930326785, 0.22129928242535363, 0.07996673966127057, 0.22350057478873964, 0.10704130580228184, 0.19122892179556433, 0.08654422502243712, 0.18631609186770456, 0.1626841180146702, 0.16415370447981745, 0.1304173679842103, 0.20491017960011962, 0.09109085726161158, 0.21972688696076795, 0.2710199668522804, 7.798853516578675, 35.08298889283211, 49.27655604577834, 38.29002857208252, 35.83010235140401, 46.0304730938327, 42.778769385430124, 38.78326269888109, 25.145122774185676, 5.96930415399613, 0.6615397826798501, 0.8891449339928166, 2.948316465462408, 18.02847827634504, 9.993116624893682, 8.826192867371345, 5.611099581564627, 8.904641251410208, 8.976438276229366, 5.749218983034934, 0.8171882564502378, 1.0266409237538616, 4.995336494138164, 30.33723281275842, 50.00207685655164, 61.99768112551782, 66.9737175972231, 65.8273970696234, 62.49056223900088, 61.958029885445875, 65.57179581734442, 61.81446721476894, 56.89435981935071, 55.72690948363274, 55.35162887265606, 60.432792709719756, 62.798605580483716, 62.2173652341289, 57.2616623293969, 63.20088778772662, 60.69262619941466, 62.766661797800374, 57.43273650446246, 57.40250287517425, 52.059579664661044, 54.04587576466223, 53.143369766973684, 56.31013062692458, 60.6659266256517, 62.872432431867054, 67.04508120013823, 55.55705124332059, 46.84426684533396, 51.82817943634526, 60.652653324988584, 61.58051352347098, 62.28811302492696, 60.05883785986132, 58.26789148392216, 49.671409283914876, 46.028602123260505, 47.102962847678896, 48.20921244159822, 56.1492036234948, 57.01614549083095, 58.8529129951231, 55.00951582385648, 55.559561560230875, 57.6533894385061, 58.71954064215384, 54.814813290872884, 52.08765599035448, 55.26514453272666, 53.39960644322058, 57.596750413217855, 53.243613781467566, 52.06664385334138, 53.950377818076845, 55.08268763942104, 51.71608594156081, 47.38382024149741, 40.635272533662864, 26.76493613950668, 14.143721672796435, 6.587640806551903, 1.7379661865772742, 2.287063935110646, 3.164237305041283, 5.181317637043615, 6.477343267010105, 7.177553023061446, 8.403615336264334, 8.858995649122424, 12.232000616288955, 9.268311646676834, 2.959961492207743, 0.7519088012556877, 3.3397726858815844, 22.367515948510942, 36.54971999506797, 29.909494423097183, 30.285051561171013, 39.61875892454578, 37.54709636011432, 19.525023314260668, 2.5930894622879648, 0.6018619011006048, 0.19631654234422793, 0.17849130045262077, 0.20839782551892344, 0.1776334045514945, 0.15109745184740714, 0.14159609233179402, 0.11633063516309185, 0.2188658960644276, 0.13845431978904432, 0.08490338726269622, 0.10692091508498115, 0.10713408671079144, 0.1942859650138886, 0.18345656143801828, 0.16916796444885193, 0.1096171998388825, 0.13018694405834522, 0.1674028365842758, 0.14203869196916782, 0.2209699871919809, 0.22228664718568328, 0.09838460418846338, 0.19149484623584057, 0.11528565292997707, 0.08536931427736437, 0.1492969613642462, 0.0977465142345717, 0.14432296697651187, 0.1774993851300209, 0.17098515564876218], [0.018986882078611565, 0.057640302205278035, 0.061086223145285924, 0.02658910196905415, 0.05194163843688946, 0.07801204333983122, 0.03802580067947988, 0.08523370139300825, 0.11631994823654813, 0.06505740460969749, 0.005955247202843067, 0.0356037677415917, 0.0382775831366739, 0.023089775124624855, 0.06338984953359732, 0.023542217076605847, 0.03959947934133872, 0.049045021690788775, 0.06137347164293451, 0.12038731587029274, 0.04470267445750294, 0.08466019265113339, 0.007261346195704274, 0.041776819965772094, 0.048290969007798744, 0.0796620971373012, 0.024006225041023666, 0.017490124390009913, 0.0979985801442977, 0.08290768991554938, 0.05767423606988403, 0.10555083578031872, 0.05802034310275509, 0.018360635844029246, 0.0105440856197909, 0.0762843465312354, 0.05102608675858186, 0.028067268618953325, 0.12466530405705976, 0.008087113326896102, 3.4130062787763538, 19.374217987060547, 32.2310806089832, 26.98337881795822, 16.359144007006, 22.59062428628245, 33.25179115418465, 31.77299091892858, 15.674739441564007, 6.533958267781043, 0.35639510339786934, 0.7427686981616483, 4.083007655797466, 6.8415765223964575, 2.6042900354631486, 3.1741550180219837, 5.580455084000865, 3.7480171409345444, 4.00704899622548, 1.8494079550427778, 0.44482270195599527, 0.9720384053164913, 6.193032716551135, 22.359045590123824, 37.85712834327452, 52.719647884368904, 57.71047953636416, 61.59984688605032, 63.01458697165213, 57.88227542754143, 56.498016080548695, 57.08002521145729, 58.27151967633156, 57.024017687766786, 54.74206509128694, 60.068722232695556, 60.52627063566639, 60.51049878520351, 57.307416777456964, 57.71239365300825, 56.150760804453206, 56.191980992594075, 52.39070223223779, 53.63942800029632, 49.01252954236923, 53.02344722132529, 56.808695254787324, 60.238517715084946, 57.62062195808657, 54.598019969078806, 47.642508399102, 46.35653972625733, 58.82840994865664, 55.772024585354714, 62.47756742662, 57.29415916627454, 56.93385416461576, 50.989890483117875, 45.24752093899635, 45.321041845506244, 44.11145348702708, 48.35631701254076, 52.76833234294769, 55.799034026361284, 56.46708034699964, 56.63268673804499, 56.420733621043546, 56.804588533216915, 52.683601302485314, 54.74477152670584, 49.36420925201909, 50.14675348035751, 53.28291593059417, 54.80287751843853, 54.92100754091817, 55.89192359678207, 51.293556459488414, 43.96128554497996, 36.00130988705543, 27.97639350737295, 17.81914334143362, 9.21969190720589, 2.0598317153992194, 0.7597067183063877, 0.8293845600658848, 2.310221853756136, 2.313609310696202, 1.5960826580562901, 4.83724634493551, 3.0136734487548953, 5.061273988216154, 2.159812685943419, 0.37535047819537504, 0.4078717685995564, 0.06693434300682237, 2.171074546152546, 16.9584027413399, 32.291469420156176, 25.740536605158162, 20.2652177118486, 30.428106284910637, 25.449430058079383, 8.485858613444913, 1.0266822925017727, 0.03375170804980782, 0.04367140519823279, 0.08419224316434515, 0.033910778546405417, 0.052671551689385414, 0.009434074970833477, 0.0722775228261467, 0.03864230993654459, 0.07108873056788599, 0.034748338643581636, 0.051545525014761, 0.08254152287038104, 0.06555042815424743, 0.05135304542378553, 0.01649711547689813, 0.08151798343826687, 0.044777896630788044, 0.029373528969083584, 0.030551253172058253, 0.04833734797073468, 0.027696916818498608, 0.016031652903034082, 0.051535604176141565, 0.038792118430137634, 0.024819479083582282, 0.04428089325947147, 0.04438026635456951, 0.04413805233554975, 0.026270790521295804, 0.006661216856070584, 0.03541064846719946, 0.04650725585017954, 0.02662258384178483, 0.05201765351117619, 0.027200263932407386, 0.051927385371058225, 0.015289668020071282, 0.04730204525854319, 0.0442133013219122, 0.027056457737701076, 0.05240657336769566, 0.07326232119193, 0.061845021742966876, 0.08095347622950232, 0.021799878412557226, 0.014414126241219141, 0.07177821736061765, 0.01880260537408533, 0.05466188259062268, 0.07011412883237486, 0.03271825927039308, 0.04929961186022528, 0.037563857322017995, 0.02632109568484368, 0.0357927271585551, 0.028717637047051426, 0.028901134257114706, 0.06614099001331676, 0.045970898542192676, 0.0454800698395458, 0.012812317788390624, 0.036296970060756134, 0.05318870700355019, 0.046000285674968076, 0.029703984825661587, 0.08138963306743292, 0.045497076991464824, 0.06521053026400267, 0.043012063965321555, 0.03681194968521595, 0.03670342566986238, 0.19322510177810348, 6.534018574222443, 27.970051034804317, 37.00853140123429, 32.42047813630874, 23.70294570922852, 27.62602779173082, 37.73871983251264, 42.532648501857636, 18.516183822385727, 4.748533118155695, 0.21345058906703226, 0.016548899190139868, 0.6227184303345219, 4.402672734952742, 4.174051015607772, 4.508833644851562, 4.04498272845822, 4.102674664989594, 5.8927267405294605, 2.4781733318682644, 1.4531027044980758, 1.4312629473786203, 7.537197105346188, 26.033778882795765, 43.412149798485544, 55.6834182431621, 61.2843628083506, 62.49214687655049, 64.37661040213801, 59.649711116667724, 56.00983788890224, 57.22573734098866, 57.06353556725287, 55.97646636347617, 56.14501845452094, 60.69132397251745, 62.1214868176368, 59.22255323779199, 60.47143982302759, 60.16249433640511, 58.360400584436235, 57.819486125823, 53.78178650333036, 54.12506057370094, 51.07560211612333, 55.08255820120535, 56.464930888145204, 61.86084139731623, 58.86040079978205, 59.254320513817575, 52.41689582024851, 48.57987642288209, 57.484358818300315, 55.892162861362586, 62.41409955486175, 58.223070559963105, 57.76469453688591, 54.01575980647918, 48.85139465332032, 46.63008974444482, 46.256432994719475, 48.900185015893754, 53.7042647792447, 57.937427874534364, 58.27472425276234, 55.856383000650716, 57.08309250493204, 57.26486298345751, 54.012045321925996, 56.13887602283109, 52.32457107113254, 52.22773167394823, 57.14079449253698, 54.95104112932759, 55.00485997046194, 55.50961017608643, 52.714693930841264, 47.33728524177305, 39.411210629247854, 32.85800872310516, 21.418169006224602, 11.777619527232263, 3.2199151044891727, 0.9489653079259781, 2.598301556802565, 2.797886705206287, 3.5241488439421502, 5.689800958479605, 3.673519809399882, 2.5841660701459457, 2.459448426961899, 2.228162192529248, 1.0919716761958216, 0.08471206446448643, 0.1801942679430208, 1.7836706244176435, 16.34327507788135, 36.295475882868615, 32.45249252165518, 21.510454531638853, 29.610986363503244, 31.10919644755702, 15.671033782343711, 2.7738170806438696, 0.15548445434579927, 0.06361625149785992, 0.1379868529376484, 0.03314960890659883, 0.023702461602947405, 0.01220783706934702, 0.0745897064165723, 0.01928685912712207, 0.027258199331681096, 0.019797372458983335, 0.06446784632580896, 0.050124236562800024, 0.03293622277616974, 0.035605200326010104, 0.0389148150720904, 0.01026015428285445, 0.04432783529703175, 0.07936730650403807, 0.04545912882613559, 0.03510141707656365, 0.05129502958527977, 0.046891322539698695, 0.09287458574098927, 0.03026678748879462, 0.03519074675897437, 0.0852353408211662, 0.06937851588572226, 0.01645712568725069, 0.09459973147679722, 0.014515074604611485, 0.04537341124828785, 0.07368047496364002, 0.10434107569557044, 0.12944291946628403, 0.12979265392547654, 0.08126686747756698, 0.1335930016132132, 0.17177894531238466, 0.13813645458750187, 0.16283373498628217, 0.1986495865088317, 0.20980672249870919, 0.20848339754006556, 0.13597492218738602, 0.10182643804939524, 0.09729710407555105, 0.18339083109411503, 0.11748010412819924, 0.18686880898331443, 0.1440956227241024, 0.13524369126366032, 0.1622753641417911, 0.1821712497621775, 0.09362541319381806, 0.24891083789688928, 0.17095006882183014, 0.17610911940855367, 0.18807855374630422, 0.1200320655780454, 0.1841777719316944, 0.19880531686207942, 0.2907526757447951, 0.1524598932554645, 0.2032974572671998, 0.16086890332160458, 0.19547428995851548, 0.21311291283176792, 0.15474458195028767, 0.11908849806434686, 0.15873553231358528, 0.23034696467220786, 0.2099632036181227, 6.173086483632365, 30.48402947764243, 48.424832974710775, 41.47707593056464, 29.505013727372695, 35.330510062556115, 43.01785353691348, 42.51470365831929, 21.209510680167906, 9.004236113640571, 0.7761397332914415, 1.2687905301009457, 7.694041902019133, 14.419361333693228, 10.745640012525744, 9.39130638876269, 11.202667720856207, 8.937079252735261, 8.982824875462441, 4.6257418490225275, 1.112715008278047, 1.718146572670629, 7.89902888959454, 24.332843057570923, 40.070706182910556, 54.304548232786125, 60.195822715759284, 65.60042127486199, 65.65367529469152, 60.96973772971862, 56.645348148961226, 58.73719130792926, 59.25058249504336, 57.368295884901485, 55.258323530997004, 62.005678838299175, 65.32367844735423, 64.80290535957583, 62.86474458632931, 63.19514543779435, 58.80210261191092, 60.291297128123624, 56.40758975859612, 56.46866498454925, 54.58995165363435, 56.33630852545462, 60.317698601753484, 65.79274292915099, 59.68933882251863, 59.46255130152549, 54.78397953894831, 51.52121866902998, 57.46455869367046, 56.78361169753536, 64.24437945888889, 60.9838504175986, 60.45722515352311, 56.71084780846873, 47.96781016934303, 48.97325484983383, 48.22305840830649, 52.422595024108894, 55.67705223637243, 60.4661250114441, 58.88066768646241, 57.47007746850291, 56.83359838301136, 59.57792389777399, 56.00889259769071, 59.42567709953555, 53.758244437556115, 53.521450950253396, 59.185306410635675, 54.27287509364467, 54.56747255017681, 57.62425015049597, 52.38124539775234, 47.152933843674205, 38.54494733195151, 32.025805327200125, 19.899584170310728, 10.487286236978347, 2.761452789268186, 1.3318824671929883, 2.3880737923806716, 5.824609879524478, 4.282714887972801, 8.241709701476559, 12.066258903472656, 5.964475226017737, 12.483314717969588, 7.093168131766781, 4.098443163018073, 1.4077076436050477, 0.32592417071423224, 3.3957069102794897, 21.720795554499475, 42.06893413297592, 34.7097949827871, 28.661319748047863, 39.921130518759455, 35.988491581332305, 14.990217205016846, 2.0060115259501243, 0.1568843114880785, 0.11286695247455952, 0.27279410391084613, 0.0975311745799357, 0.2194899206440295, 0.13111257745373633, 0.18600881400127567, 0.10034244913127154, 0.23780597974696469, 0.23223491175280464, 0.26651739232963134, 0.14527228781052176, 0.1505151024508861, 0.3306781752936302, 0.11594294870813047, 0.09012793836694571, 0.23292218455143515, 0.136812332897417, 0.21628051785932434, 0.10893071611081401, 0.1049189511386137, 0.1587591584651701, 0.1852119446641976, 0.11850974162019069, 0.10300286564855807, 0.21205414867689534, 0.1649168199829517, 0.18544803764070236, 0.20253792705555118, 0.15160628744671423, 0.1634787963402848, 0.1800708665001777], [0.007759770660120393, 0.02628424302524617, 0.004851967593910354, 0.05210650438863424, 0.043350766758404435, 0.036091765749358365, 0.022127779365907756, 0.03929691291564415, 0.012065858951950026, 0.06007930782112864, 0.037617318767813906, 0.08674473321485905, 0.14046982050903384, 0.045800643161900585, 0.05785317505679785, 0.02150847580313923, 0.035917967212416475, 0.09163364587772278, 0.04779078254115678, 0.06236690381962446, 0.06053393120847403, 0.07850115983596734, 0.043123541249623226, 0.0430411906282027, 0.028644839542046673, 0.024605054904015797, 0.03722119002392696, 0.039601160904332515, 0.031639781758008946, 0.10099959935271934, 0.07708040381511373, 0.08718992989029616, 0.058933133034095656, 0.033393776449825496, 0.0793772809688122, 0.07730738034531956, 0.06514729736673255, 0.014346070820465686, 0.13600129093373978, 0.07736435430424829, 0.08979408491042354, 3.2002397602604282, 16.497983163402928, 33.364904465213904, 32.138498944620935, 25.231491404194987, 23.504664013462683, 25.15150643164112, 21.052080469746745, 22.096009485183224, 8.056734646520308, 0.8268114852328455, 0.428146438733224, 3.8965926006917035, 3.9624746912910096, 4.11538020257027, 3.4597280813801676, 3.648367120373634, 4.492933336765536, 0.8922272427908836, 1.1992882144066597, 0.4204396861455133, 0.8713357186605855, 4.691468025407484, 17.422309306360063, 28.93074735518425, 38.2538878533148, 47.28411359171714, 57.58323784797423, 63.63403512585548, 55.66392406340569, 49.30524818358883, 54.61783970555952, 58.930203299368586, 57.493219452519575, 57.1003117099885, 58.75509300539571, 59.586549189782914, 58.31314386860017, 58.89112080297163, 59.881283929271085, 56.52776725830571, 55.10566880626064, 52.306673296036266, 50.231304091791955, 50.83127767808976, 60.579116728998, 59.6920491803077, 61.873326301574714, 53.678251620261904, 45.45805808036558, 43.60887627447806, 66.34971557124969, 59.08362680865873, 59.46109610219156, 59.32172252285866, 55.817680974160474, 55.21941361888763, 46.87943873866912, 48.213676098854314, 48.83530116850331, 50.784103332027314, 52.04434910128194, 55.671435402285674, 56.959216210149954, 57.81810937389251, 55.40685976705244, 54.9606038678077, 55.275311316213305, 57.37274777504706, 55.376233900746996, 54.69013683257565, 52.07610068782684, 55.37359022325086, 52.11547736198672, 45.70093516380557, 37.38875419862809, 28.611042807179114, 18.004553779478996, 9.111712978732202, 3.299895909524733, 1.1773354439966142, 0.29254106203875235, 0.8470304454526595, 3.064829245690377, 1.7348460636792646, 3.0739585622664425, 4.097854317195954, 0.7024532292158373, 1.6327810888328862, 1.988846498631662, 1.8357886277860211, 0.3447758172067904, 0.16268791781077463, 3.5214250030056125, 18.05644085330348, 30.024708163353708, 29.57664012908936, 21.254494382489113, 27.216391140414824, 27.128653603215373, 10.133853227861467, 0.8159387976892534, 0.06269343347559053, 0.04104615977754997, 0.050387786130510995, 0.011352007690396522, 0.04485903300284859, 0.016660924227307403, 0.08980040513579884, 0.051605191772743586, 0.03219918107553836, 0.019988158995646144, 0.04758257899553545, 0.02082713060982285, 0.03347321593713376, 0.03542771690615243, 0.010700687398052505, 0.0425169796442553, 0.03433773466836541, 0.034511192296181, 0.02772494606042822, 0.03398099050466572, 0.025622141960587715, 0.020077530812892704, 0.004207379299200951, 0.06365083270676195, 0.024451080807334474, 0.05343744809168482, 0.03324541586240934, 0.060438844375312335, 0.020965677610928976, 0.026905484790463122, 0.021014822151271567, 0.09099606154186111, 0.016108921488686916, 0.08016635919170034, 0.07216510708413779, 0.04451570303870305, 0.008097549359644613, 0.018678014579739784, 0.10204548556958476, 0.0871286581781122, 0.04728391961825471, 0.06718309175583624, 0.017796651490273017, 0.039278300809523756, 0.04458927046207171, 0.0515052211290646, 0.06298959923667774, 0.02761362582415102, 0.02830007890870254, 0.07148516574694265, 0.017643183011621717, 0.03733200464217413, 0.04427798595579882, 0.058561365886200825, 0.03007070919979484, 0.1005252989970388, 0.06443269055096373, 0.027423739440799243, 0.10696650497735509, 0.036826164446650975, 0.08137584348479587, 0.03627243609498105, 0.04870974331072742, 0.08439399241920441, 0.09936112880466447, 0.03732688334440032, 0.08213577972304437, 0.05333604486358743, 0.053924649368010225, 0.07468057210527121, 0.08808501169926698, 0.058226650580763824, 0.00801918191662539, 0.23351737358156713, 5.892760570972197, 25.51713997317899, 39.35599542433216, 32.420737012740105, 26.255851714841782, 29.481752111065774, 31.826464591487763, 29.25567257788874, 25.017988950975482, 6.988851716441493, 1.032230178675344, 0.05032769802417006, 0.33994017829818113, 2.515163734074562, 5.423216579421874, 4.576475899065695, 6.225593782240345, 10.572485020083766, 6.573092245286511, 4.014880498570781, 1.5955595119345574, 2.1991307696988507, 6.534180371992051, 17.933105845605176, 33.32824207121326, 41.84614742955854, 52.25478033865652, 59.12368597522859, 62.64434660634687, 55.3448784735895, 53.979187626992505, 55.559494879937944, 59.173860934472856, 58.71610856825306, 59.002802448887984, 60.58161527879777, 63.31429135414862, 60.054731138290904, 60.80243295238864, 61.80455930771367, 59.01502063197475, 56.59898965589462, 53.60874722080847, 51.26377390277002, 53.27756581767913, 63.580333955826305, 62.073178906594556, 62.25490231667796, 54.70319832524946, 46.7843997093939, 47.22729413740097, 64.969896347292, 59.533404996318204, 61.016076610934356, 60.88608534105363, 58.09156917756604, 56.373625955274036, 49.412477939359604, 48.86273030311831, 48.78858573975102, 52.043513636435236, 54.17762817875032, 55.57760054065336, 57.53336098886306, 57.84655832475232, 56.35595960001792, 55.81326830771662, 56.971869776325846, 59.26726433538622, 55.27760198039394, 54.3571864404986, 52.372353384571696, 56.62222185442525, 52.951267765414336, 48.213315240798465, 39.19236198548348, 32.209289881490896, 21.02393550257529, 12.858644358573422, 6.038088308226678, 2.9216953391028992, 1.127779483795166, 1.9130947440862658, 2.80389896323604, 3.4927066343445934, 5.134536998887216, 4.957033568812955, 3.3694650280860166, 2.1016620772500194, 2.6623455266798697, 1.3740288249907957, 0.16945967540865944, 0.05652805745241143, 2.251958967216553, 17.020615454643004, 34.80266494135703, 34.980595419483805, 26.143646432507424, 29.43281269842579, 34.778636501681426, 16.150399388805514, 1.8922038328263069, 0.030300933942799608, 0.10681153305115239, 0.016227983043438966, 0.09585492057545532, 0.029426502033827767, 0.017373284490238276, 0.059264898901024175, 0.018176068026091785, 0.03903996702584048, 0.03433955029674596, 0.027897122406190442, 0.05387031841242025, 0.019579433851064216, 0.036019837754147674, 0.06485980755138783, 0.022101939220221776, 0.07420358278097645, 0.043949686636727665, 0.05133190905795463, 0.0353547278791666, 0.1267423599417652, 0.017741071811366468, 0.028150768372260278, 0.039664884097874165, 0.0638706922801512, 0.02881977380433631, 0.019759958639981288, 0.06552113295202294, 0.03324721999947102, 0.03957120686649315, 0.039358805159046766, 0.04636447238285215, 0.011466438243646297, 0.20151190549856235, 0.18318029481076425, 0.16272076766096777, 0.09907985196238565, 0.1377847589432232, 0.1376834974413918, 0.1985636467654859, 0.17906985005303738, 0.15062914229929447, 0.1857973277688988, 0.15993498085487276, 0.16816590612213458, 0.18609153617533947, 0.1639254868871743, 0.08586423005908729, 0.1816716838267542, 0.15025820252635788, 0.1314341658425908, 0.1554743113416818, 0.2167441695928574, 0.19376710898453192, 0.16748931258916858, 0.17749771505834597, 0.12346300566869399, 0.09554290062477512, 0.23690709814188943, 0.19232410577035722, 0.12866405319542656, 0.18500340020944997, 0.2075120286955949, 0.20722235552966597, 0.2182509266440907, 0.1817502384825099, 0.1362121642957772, 0.1562484585109257, 0.15542666067279157, 0.18979943237237393, 0.17782074369249806, 0.1376905454502952, 0.18121462044936998, 0.21041452133607483, 5.026733596478739, 26.496008634567264, 48.26276848393102, 44.93018550257529, 37.567355402054325, 35.91307617002918, 34.694007442843535, 29.71518412713082, 29.2827820393347, 10.503775881182763, 1.393451911787833, 0.8840393563432078, 7.6009802376070335, 10.449852116646307, 15.193012568258471, 11.102848302933479, 10.934357989218928, 12.06901534911125, 3.551993504647286, 2.627487913254769, 1.0063804109250347, 1.7608978334934482, 5.471969189182405, 20.575212432492165, 31.47744817118491, 40.33550147087344, 48.558456359371064, 59.28183986294655, 64.42855042795982, 56.18503839738908, 56.894912873545, 56.675817120459776, 58.49962903607277, 59.200748782004084, 58.12477596344487, 60.753450393676765, 63.56292255463139, 62.9130603421119, 62.66618636346633, 64.66226877704744, 60.61668911287862, 58.7036354311051, 55.94742513472035, 53.78407716751099, 55.40328648782546, 66.18718824078961, 62.77245906091506, 66.4396555193009, 56.20102990058161, 47.768824408131266, 50.044571814998505, 63.962659143632465, 59.10737283768193, 62.30960761347125, 63.359194647881296, 60.06315638942104, 59.76002385539394, 51.96421115629135, 51.05129518816548, 51.79599246671123, 54.61918507852862, 55.47854500432169, 58.68005021925896, 59.621524964609456, 59.05466794967652, 57.73348031505462, 55.513548235739435, 57.98832847226051, 60.992989540100105, 57.814712601323286, 56.213318686331476, 52.27958540762625, 58.08824300765992, 51.12434148788453, 47.784764920511556, 39.58135520258258, 31.411171882383286, 19.709500228205037, 11.033357631775642, 4.471957481676533, 1.5844106650160206, 0.9566530921766836, 2.9146377694222236, 7.810198972302099, 6.000864034698856, 7.29166163552192, 8.97907607017025, 6.196038722991944, 7.609379993331048, 6.961176453098175, 5.495780427609721, 1.0958314110194485, 0.37028789340007695, 4.381128626485025, 23.7594376456353, 37.454622560931796, 39.72363525821317, 31.20015621185303, 37.32382328279557, 39.01495318258963, 15.89324389734576, 1.6932164781516599, 0.15078763056906963, 0.17617727059029764, 0.1173456710192465, 0.17410671879206935, 0.19885454567209368, 0.148534290192108, 0.16163794834527279, 0.1548227075968058, 0.18164202090232603, 0.20405398441418526, 0.2518110935606303, 0.13892501953148073, 0.13248548362283938, 0.1264225718595328, 0.16349546641351717, 0.10880265685339129, 0.1858153308351194, 0.12411712218196162, 0.1423307553294205, 0.14374139898967359, 0.20281479123138613, 0.1612952159297082, 0.09132995330277952, 0.10467314416722906, 0.15105206879877275, 0.14354754810131368, 0.16807212163844418, 0.24912480625414082, 0.07718166531694513, 0.08706440638390281, 0.06926950923497639, 0.24206921308031007, 0.18310923249490801], [0.01787985821494893, 0.020175046144774365, 0.012203162975399005, 0.014356445566180253, 0.06151391088121361, 0.010732809464717585, 0.03206740437646306, 0.11238392637742144, 0.04176689529671304, 0.01013228175936327, 0.0326099306074602, 0.025555490395955505, 0.03633880995274071, 0.021451967242624492, 0.0442642193557995, 0.008449245003923293, 0.12273248720673785, 0.01406914727281659, 0.037439188003660216, 0.11737466744718053, 0.013927534004793534, 0.016813040560772343, 0.018189784830376025, 0.04800435636312731, 0.035996491224655223, 0.04815303104659242, 0.038705856929863655, 0.054848712283156575, 0.010838276789253278, 0.04114199737687746, 0.01490669109062442, 0.05680214838996049, 0.05862267973322061, 0.006585868757082931, 0.05486203072172019, 0.021365062228494117, 0.04330385536436112, 0.05758450802175268, 0.04322866383459299, 0.01862070545734417, 0.041135815047328515, 0.040057760798522545, 2.0564295495710065, 17.687926330874046, 36.240919636141875, 33.846708805330344, 26.88614914494176, 23.606447558249197, 17.35387179159349, 13.928300199970124, 24.089601193704915, 10.788268331558475, 1.2629198451195995, 0.30572188056765065, 1.807232179468678, 4.384586195791922, 1.289346569007443, 3.040513247251511, 10.840121084643949, 9.090279186925581, 6.3372151217153, 1.4436853388624808, 0.19706199185982828, 0.37205798551440245, 2.1358406303390383, 9.742347732667001, 15.147918058979897, 24.58092904859974, 35.387204001026774, 47.554302138666955, 57.68149322079074, 58.36313055407617, 51.70797840241463, 55.870503533271055, 56.100326968777566, 57.465052912312174, 57.093212219976614, 57.25953248239333, 60.93635443718203, 63.44847171537338, 57.09521655113467, 60.167420833341545, 57.82061969080279, 55.72388141385971, 52.90779221442438, 55.653321896829915, 57.761537028897195, 66.5854186396445, 62.0172929763794, 69.97600170873827, 55.056027289359804, 35.26514768600464, 59.54718036036338, 58.70606337824176, 62.907380750102384, 60.33849500840711, 58.26783657073975, 57.224207616621456, 55.513387418562374, 54.18354703534035, 51.8466067314148, 53.90370945776663, 55.910813731531945, 55.87227252221877, 57.0928592066611, 57.856093606641224, 58.03835438143823, 56.87605019538634, 56.543107648049634, 55.52420531549762, 55.65450645262196, 55.16010738188221, 54.227767836663034, 44.146064481427594, 34.36266522253714, 25.968465535871445, 17.919016691946215, 12.457012284186579, 6.641500342276789, 2.8835885322863057, 1.4337863797141661, 1.0274852139334525, 1.3727871496831219, 1.585132258553659, 1.440940170038131, 2.198961372337034, 6.012142810129351, 5.027822544497829, 2.646027486170492, 1.8822085304606346, 0.7917491731143768, 0.25048326400499193, 0.5170790730945526, 3.5358497644624407, 14.253995187820928, 29.315474994720955, 29.48284645234385, 23.674989015825336, 26.030815532130582, 24.233842434421664, 9.485927685614556, 1.0094004520966162, 0.043580451409422585, 0.018338968962310784, 0.07155306411967163, 0.04649597520549451, 0.08778538705120165, 0.062034728095656445, 0.05173267263378348, 0.023577135364194552, 0.07622288329707039, 0.06348419326147245, 0.019812364799661503, 0.010850119550952749, 0.04734427968580877, 0.06381581357169537, 0.01597501793801184, 0.03869638042224031, 0.043256154899755796, 0.09960352668478605, 0.009756347093160355, 0.04244931875878284, 0.08449631878325055, 0.07958233206262512, 0.03956577530311, 0.03936280796845113, 0.04498260298503503, 0.028736429183834025, 0.03450517467553577, 0.01593051684810029, 0.05861070577896411, 0.059528364199063474, 0.01267432907385932, 0.04812515693746748, 0.029530220762676293, 0.06690776741672909, 0.015673786420525325, 0.09673990534558412, 0.020586268735989448, 0.02344104942054518, 0.02940771755792441, 0.0028547555472957153, 0.018344756756578724, 0.014573260897680398, 0.006938724066956991, 0.013067382932340187, 0.04803274758160115, 0.08323083346289012, 0.030500993973785834, 0.04517855678474711, 0.07805873639881611, 0.05759661221095632, 0.03318928460019731, 0.014676348561601294, 0.032947258272719, 0.01162331389834083, 0.10787392080190683, 0.08034120343865887, 0.008532684427806208, 0.03545714234332404, 0.036990930806965604, 0.016182667027497967, 0.06488885760547654, 0.05629803572270659, 0.016749489737013658, 0.014430130775567266, 0.04488901385376531, 0.03105785754028588, 0.06837705510758585, 0.07324359034218135, 0.08805897237072069, 0.04699894257130162, 0.04792615410781676, 0.06367453163669956, 0.023034768096441706, 0.09415432029674131, 0.03889649024894161, 0.10993508802306269, 4.3738565521855515, 25.61475403847233, 42.95789226408928, 37.05454080335556, 29.691634216616233, 24.454538514537198, 22.607231601592034, 26.893623221305113, 28.14404933683334, 8.873316222621549, 1.7757929116487505, 0.3042717374140217, 0.46783564612269407, 0.7431324979951306, 5.163951833401957, 6.703507131145847, 11.617436793542678, 13.78782247343371, 8.084241247946217, 3.486000361942476, 0.8998775806638503, 1.8617804588810092, 4.336919592272851, 12.453322314446973, 18.725814896245158, 28.481304530174505, 39.403452181047015, 51.73151262344853, 59.289582621666696, 59.79147341943557, 55.09491366724814, 58.95212542626166, 57.75690863209387, 57.681630503746774, 56.73573524721208, 58.07570711258919, 62.15647828194403, 64.3885540193127, 60.43720145379344, 60.77945963028939, 58.10097502123926, 57.318148382248424, 53.518936710972945, 57.61910792320006, 60.05866135320356, 66.7127073964765, 62.62726468424644, 66.83834091309579, 54.63179549863262, 38.105657562132805, 60.61690092086793, 59.438291442009714, 63.41363322350287, 60.87189420577019, 60.98317969229914, 58.43778502556586, 56.99453715355166, 55.60706538538779, 53.595650426803104, 56.101252648138235, 56.74086570739747, 56.84238056982718, 58.52677576003536, 59.08291293728737, 57.01282716566517, 58.195327635734316, 56.760767813651796, 57.61822538991129, 57.00699852358911, 56.26909871255198, 55.161652795730106, 46.910727485533684, 38.75075409489293, 29.81528497511341, 22.61399180658402, 15.221386013492463, 8.343693287141862, 3.4464611545685804, 1.7128077365698355, 1.1616922963050105, 2.303391291249183, 3.097535929372234, 3.519180181526369, 4.450066733744837, 5.30613677155587, 5.4755454101870145, 3.6215133484332793, 0.8781038296799507, 0.5022215332475402, 0.4959318594586465, 0.2771074547161979, 3.434270428073022, 15.835871388835294, 34.00444299943986, 33.1471933087995, 27.972316203578828, 28.21796444154555, 30.228179154857514, 15.048203564459278, 2.3435656774428586, 0.1209414808920795, 0.07279631756846944, 0.06712853097386899, 0.06212867345781096, 0.06279944855299208, 0.09680280116416755, 0.02971182956600622, 0.04141244173590695, 0.04566920928717141, 0.07265001009669035, 0.03842662937278229, 0.05259845924052981, 0.07689478071106058, 0.03009257909481324, 0.03716697015108601, 0.05041244650079359, 0.06188675821308167, 0.0971467056942563, 0.01969526634521542, 0.04922084653029039, 0.03252412875994079, 0.07637189505922218, 0.05315528258741383, 0.025188800495778842, 0.08528093837441937, 0.03714571504162685, 0.028631208922653913, 0.05927997168093439, 0.10881731211538277, 0.034568166255109736, 0.016496659654583183, 0.02249532345411999, 0.05547488956982571, 0.05715326180741672, 0.14300046939282648, 0.23104860928029786, 0.06675031336565172, 0.08908325490812141, 0.16275760116836718, 0.10923221767429384, 0.11376626308887236, 0.28172264416371623, 0.18584815004179556, 0.09215781855727397, 0.16041233024049192, 0.1794938031103342, 0.13285702094435692, 0.11547171270414708, 0.15137632317360372, 0.15998696758141442, 0.1882160358851956, 0.1469573441652521, 0.16812090611746236, 0.25678173248325625, 0.2380530737460621, 0.17435673924703754, 0.05700989611326687, 0.10255694885047213, 0.16568244825447762, 0.08635745278649753, 0.1198955640316971, 0.23782697055608998, 0.12049649106038195, 0.08136691856047801, 0.18744139841968016, 0.12768135391055577, 0.2378985997770102, 0.1760361265511282, 0.26982980329663525, 0.14571330930677154, 0.15462263607450072, 0.14226200659909558, 0.11546117899518822, 0.1586153177965072, 0.21516143194129392, 0.2475255364251714, 4.238820623966956, 26.212411465183383, 50.12800062856367, 46.87430827848373, 38.87423030791744, 33.37379255602437, 26.440565932181578, 22.91800687389989, 31.652636912561235, 13.361809926648295, 2.242924277820895, 0.6415545099204587, 3.6928870024219638, 11.095974349206495, 10.137842278326712, 8.120282926867086, 20.972560298058298, 17.677351620889482, 11.780129844142545, 5.415740051577169, 0.9952585303014325, 0.8755397640409008, 2.881205447258488, 11.321103688209288, 17.78352233671373, 27.89925813674927, 37.86500446258053, 49.47116836424797, 58.163077908177534, 60.917919297372144, 59.31405428917178, 61.52766350776919, 58.93188991854268, 60.777333705656, 58.51618143819994, 59.897773573475504, 62.217408380200794, 67.21911676468389, 61.98699266679826, 62.95499047925396, 62.13719591017693, 61.78452776324365, 58.41604725007088, 59.83940478294127, 62.42072443808279, 68.37307806937926, 66.52378251475673, 66.14327338434035, 55.07254046778525, 43.42052405880344, 59.26893134270946, 59.968180118068574, 63.45180573001985, 64.63679690514842, 63.25394961141772, 61.59306510802239, 59.643615753419944, 58.824358140268636, 54.77198885333154, 58.72995453496134, 59.41692629168111, 60.47127508348035, 60.254532752498505, 58.658767438703975, 58.681536797554266, 58.059295915788226, 56.541358270952784, 58.65765348557503, 57.855936711834325, 57.51765189632293, 56.59051733632242, 45.3658902260565, 36.171281876102576, 29.240098807119555, 21.775532230254143, 14.845728854979239, 7.506032893734594, 3.994727360625421, 2.3006343553143163, 1.9879105230492933, 2.5281808549358002, 3.760040186105236, 6.1678128569356865, 7.004374986694706, 11.030518816363427, 14.257332144245026, 7.6622045136267145, 5.7007267205945915, 3.1795882361550487, 0.9808839016383695, 0.9170462239173152, 4.984046932189695, 19.00090640591037, 35.46098378396804, 37.756778424785985, 35.023831705893244, 38.00495855269894, 37.27590368640038, 15.91879225546314, 1.9406213250852402, 0.21731576311492154, 0.09017257831029354, 0.1779439153089639, 0.15163539878783688, 0.16145793300482536, 0.173226039436075, 0.10828822115135771, 0.1257573317496046, 0.15134995442725, 0.18272419670416465, 0.09436512471086557, 0.10472791945381511, 0.184364007906087, 0.24482820213081377, 0.15074715048315065, 0.11416072176108438, 0.14010321679374865, 0.23235852770026655, 0.15421676269221693, 0.2352014646655129, 0.13736995297574228, 0.20834706453306062, 0.1211833271888956, 0.20162931613383756, 0.22250194853592306, 0.1411618124092779, 0.17583835329259598, 0.10492621365213588, 0.28040429877658046, 0.15133100141200329, 0.09013247360745746, 0.1299684864258574, 0.13417988625024596, 0.17489706106003255], [0.011483253873584252, 0.02781826323048482, 0.022325008702013763, 0.01114347568457766, 0.048361161813860944, 0.08317190597975448, 0.039380382025434126, 0.057621728403553854, 0.019440287386157343, 0.034514015330181974, 0.07539733928898651, 0.023013884539625818, 0.049096820725789, 0.019067570289236405, 0.025042973744172244, 0.05620331661174855, 0.05972564716132418, 0.02205401275967879, 0.013158405669063572, 0.06300626547947046, 0.03165437381774668, 0.03704803117040185, 0.06481407210230827, 0.02196565026327247, 0.10137515863583935, 0.04211960217705177, 0.03539148477777358, 0.052028041663429433, 0.07439489791830702, 0.07997370340050229, 0.0676567332759019, 0.05420293463694473, 0.03153110260985071, 0.06403233300173475, 0.06303661022215121, 0.036182784655642126, 0.010833321157993089, 0.0693824076123776, 0.020327436354672237, 0.04765410096414628, 0.06587800735066976, 0.05232494286892395, 0.09154233585802779, 1.7359068196627403, 13.064014757833174, 29.612602380014238, 34.90723925252115, 21.010289576745805, 22.209583674707723, 24.453932508345574, 11.201202715596846, 27.92772081590468, 14.80125015781772, 3.135323798464191, 0.4245463770724112, 0.6063310741897553, 5.16233483629842, 9.445778304530728, 11.206870540495842, 16.515731888432658, 6.504681696814876, 2.864500072694594, 2.2623846271345696, 1.8630389268359833, 0.7455895564729168, 0.7490389133172651, 3.292899136581729, 6.750084296349557, 12.738742405368438, 23.18446916918601, 34.35929198418894, 50.45176875206732, 54.79859429021036, 55.92823689983737, 52.99131124250351, 60.71363441405758, 56.44950028388732, 59.28281653311945, 61.80211567109632, 60.701769244286325, 63.120942038874475, 59.08215591984411, 60.29468997832268, 59.125050960048554, 59.092577657391956, 57.760109286154474, 59.19139000677294, 61.71094017644083, 62.765661593406435, 59.39276449141964, 52.67867088317872, 34.02899703671856, 61.726029534493726, 59.60408218445317, 59.79372093754431, 58.72966427956858, 60.1149473651763, 58.95396109550231, 58.098856941346206, 56.52808497028967, 56.516733631010986, 53.62238922426778, 55.76434066218715, 55.27838253205823, 59.380848330836145, 58.06477546691895, 56.48506833660988, 58.017263797021684, 59.22028610783239, 57.131518087079456, 55.03849037231938, 48.43680012610651, 35.264422047522764, 24.24160872736285, 14.574450869714061, 8.695941740466703, 4.7176978953423045, 1.9394650839028822, 0.48246902864306207, 0.4780028586185748, 0.48775638363534407, 1.56311709794306, 3.2651128211329064, 2.934187597805454, 1.2804164352916902, 3.9733634360374945, 4.151755773252057, 2.949234545230866, 2.4766075707251027, 0.6420813332642279, 0.934837727296737, 0.7043993376916455, 4.666887512130122, 16.77745596055062, 32.70362815549297, 25.49517862258419, 24.851749097147298, 26.27104501570425, 24.66464811755765, 12.365723040796096, 1.6454717949513467, 0.10045028366749326, 0.029418061660122008, 0.005551128640710827, 0.03320182545951778, 0.0698315189971078, 0.011828267315943396, 0.030441836664272897, 0.10376624928246583, 0.03839080710144293, 0.02177395974285901, 0.027934381092387824, 0.06765198353077136, 0.046017311979085214, 0.027074677223760276, 0.06918098777532578, 0.04796412908622334, 0.07894254905442077, 0.01252712240637911, 0.026668740639222727, 0.06209701870477969, 0.07550033214952677, 0.023287466028705243, 0.05911040577977415, 0.04577766052417217, 0.008034725361804088, 0.09192158768494284, 0.04923588483624401, 0.05376698081231406, 0.04618764779860935, 0.04336073739273895, 0.026448819778799534, 0.04428305745785756, 0.0552999419009974, 0.032790122148130214, 0.04097079587799888, 0.042948072641006405, 0.07426477022348874, 0.03412921702669513, 0.031045012161015507, 0.002731701238043306, 0.04042687345175974, 0.01675312865465399, 0.010246626127721562, 0.04496538132849721, 0.053245458796980887, 0.016826950802257466, 0.0321074822662218, 0.04342777774699273, 0.020822026549027334, 0.06853635543056073, 0.0063420100430507335, 0.03444283427069745, 0.033628777751038154, 0.038267390336841345, 0.0008852811503945099, 0.038196653608352914, 0.050021550137429475, 0.04264572838080987, 0.03474281131920796, 0.005949149621770748, 0.03812724987285272, 0.03915540498471068, 0.0678785004082226, 0.04016353838866757, 0.09096308911760008, 0.06315444986666403, 0.10388045767021757, 0.023800509365936442, 0.016197205461081, 0.017924693510717443, 0.04458775360798163, 0.1156137147617917, 0.07107694813561055, 0.023043731325155786, 0.0181967600609266, 0.03106654880778684, 0.0416274328205374, 0.16442036436450097, 3.496189944205746, 19.75612936481353, 37.46428728103638, 39.89221480584914, 23.018235198913082, 19.21287717357759, 20.729526319811423, 25.85659169381665, 31.480943003008445, 12.01017979652651, 2.960269153118134, 0.16933371523214927, 0.29754468870739786, 0.7685546661096235, 3.3308245337778524, 8.85336410614752, 17.990074349987893, 10.568496950211065, 5.970800538216868, 2.7204181782660948, 4.040392329615932, 3.6062773917951896, 3.033554227121415, 5.370634265484349, 8.92336174365013, 16.331589356545482, 26.48098595680729, 39.1440305402202, 52.85309868474161, 59.039029459799494, 56.86617758966262, 55.06939080453689, 63.49320242481848, 57.41797662550404, 60.977374584444114, 61.35464775946833, 63.13760426736648, 65.63619721320369, 59.82745332102622, 61.83431048547069, 62.62943375495173, 59.13234656856906, 57.95281925509053, 59.72702495513424, 64.65426714189591, 63.35327971366144, 60.30841435155561, 54.21859341282999, 38.40991189402919, 61.47949680205315, 59.63666923584477, 61.42261066744405, 60.948709903224824, 62.15776481936055, 60.43094527336859, 59.828155425287065, 58.224996443717714, 57.160492635542354, 55.2956291937059, 58.22962484052105, 56.318826521596606, 60.86978789298766, 58.297462232651256, 55.79801028774631, 57.73637110187162, 60.49445629119874, 58.01466326559744, 55.45713278555102, 49.37440349209694, 39.77052327125303, 29.741061964342673, 17.218544137093332, 12.089907853834092, 6.621379073589079, 2.943591480293582, 1.063700948030718, 0.840030363009822, 1.7132264495857301, 3.246424688446907, 5.450677092998259, 2.856887732782672, 3.1407158317104464, 6.019788490187738, 5.208177537687364, 3.0262870557846564, 1.2030595733273415, 0.6007837395994895, 0.1580035353019353, 0.28730313503934496, 4.38258578700404, 17.74611665356544, 32.92573236650036, 32.621354479943555, 28.796806258540002, 30.09839577059592, 30.3543225795992, 17.06220434558007, 3.132061367073367, 0.03890825352901894, 0.045243601479958144, 0.011712282561817238, 0.035895137792272915, 0.088111074010451, 0.02248634298842761, 0.01941990944737148, 0.05233745691516707, 0.047102211223494624, 0.03226990248226831, 0.05645887205196966, 0.03803222049628535, 0.027900960506691087, 0.012067560624751833, 0.153852564493014, 0.0757712668048278, 0.04913572650102358, 0.06294453411453194, 0.0017716166292948109, 0.01610229099770227, 0.031241969535908395, 0.13068349160734685, 0.03288782517155332, 0.01932212598471632, 0.028868608079069567, 0.03659231610776436, 0.05669241778612618, 0.03870098078022561, 0.025805987740656542, 0.00412252979473241, 0.07506438215533573, 0.03534969468150408, 0.031814614513648615, 0.006773470762005497, 0.05849386970963209, 0.17729980390398734, 0.1725272599968218, 0.13427497308340766, 0.10303976810387067, 0.09643487211677337, 0.12187718068279567, 0.10297506431778593, 0.10000844245716449, 0.13161361427797427, 0.12450616461254897, 0.15187676244926068, 0.10533662993581065, 0.1917723692472904, 0.10714248303444156, 0.150006266851579, 0.12932308799316808, 0.15987363253389636, 0.1351962244558719, 0.12618895334702346, 0.13118241402891376, 0.19529056675251455, 0.10724205914283953, 0.14999964785191322, 0.15376978103191624, 0.18888369683296452, 0.09720871285084756, 0.1436005307421569, 0.12510519940406084, 0.15471522546102925, 0.185978093875512, 0.15040697680125314, 0.23349341035129564, 0.16605505809908913, 0.2445828701339422, 0.1057891350900454, 0.13614505499361024, 0.19345065338477013, 0.2543057363119818, 0.10999910233001556, 0.17870320037247675, 0.1808013926230131, 0.11525291799297256, 0.18179041213325917, 2.700194927953905, 19.60998773574829, 43.546141885942035, 49.32234971754013, 30.653244449246316, 31.362346218478297, 35.20290751611033, 21.075383270940474, 36.77693505440989, 17.709579775410315, 3.9514190006640653, 0.6704091196579318, 1.391417304835012, 12.360188576482958, 18.78590560728504, 26.987409053310273, 29.201559558991466, 16.11470091727472, 8.73305912940733, 6.988929183252397, 4.912597037130787, 2.4735616051381637, 1.344127126278416, 4.479224653013291, 7.244401487611956, 14.989959309178015, 26.341924205903087, 37.49017884654384, 52.14787613961005, 58.2331314394551, 64.10236612443002, 57.55978207434378, 62.02545150633782, 57.34345159223003, 59.81955758986935, 62.28199804982832, 62.33367527684858, 69.00946694035684, 62.19504302547824, 63.91645754537275, 64.4679427916004, 63.1157958892084, 60.99954774302822, 61.32914450860793, 65.6591901471538, 66.33299058483493, 60.664632243494836, 54.83249925797986, 43.333416062016646, 62.19131677381454, 60.45042376364432, 60.16747182415378, 61.92819241554507, 64.11325854639854, 63.006926582705596, 61.39955497557118, 60.00099074456, 60.55019709371752, 58.58826283485659, 60.210410010430124, 56.91203794171734, 62.9284752568891, 59.26268692939513, 55.44853887250347, 57.90071056735132, 60.21647399471652, 57.34513036666378, 56.56881878452917, 50.90514767554499, 37.704328490841775, 28.239561011714322, 16.173630606743597, 10.642212014044485, 5.636409165397768, 2.758805189401873, 1.098031615537982, 0.9737886404318195, 1.6093406369609218, 5.623087815700039, 8.96877984846792, 6.980756434702105, 4.491363898400338, 10.052681738330472, 11.651579064707603, 8.440443450404752, 6.9249469907053065, 2.3431430420567914, 1.7627131554388233, 0.9196348656569758, 6.4977243927217305, 20.94359359433574, 40.34259311614498, 34.22724146996775, 35.96156451009935, 38.29379012507778, 37.582154504714474, 17.875717647614017, 2.9092621611010645, 0.2237389966725342, 0.3388878799253895, 0.19784822789651735, 0.13048044766389555, 0.15991369893233623, 0.1734946758276032, 0.258933857323662, 0.166831917219585, 0.1897496519790542, 0.21048593605237625, 0.11931405733189276, 0.3193826072158352, 0.18829554048997743, 0.14507328881131065, 0.22212792908953083, 0.20329751855423375, 0.23434245027601722, 0.07926963029369231, 0.16148733545935925, 0.12399019673466684, 0.1604945314747672, 0.17835844548479204, 0.19141573999677935, 0.22593247493909252, 0.09166249674895117, 0.17256499748797188, 0.1484378397224411, 0.2871258010066325, 0.19631304898329321, 0.16878916461381221, 0.18852291538590388, 0.13949465186845872, 0.17393149916202794, 0.15401324377425257, 0.2043746381757721], [0.02843334756401037, 0.01854236147576763, 0.11539206254265963, 0.02019127763267006, 0.042246814907318166, 0.01979985075341838, 0.09108279801664815, 0.009809066391279622, 0.0031706645912040147, 0.03926498237096014, 0.07088854413239226, 0.06357819991066091, 0.008295120562486833, 0.05986600596037123, 0.014012827361453206, 0.06554091334222786, 0.03726190376666285, 0.05158156945159839, 0.02797839667407736, 0.014206773053193766, 0.03221853628694531, 0.05553901112908798, 0.01937232964161423, 0.03140605407797041, 0.12560575359290646, 0.07419221403618013, 0.033589780045252655, 0.07811601679291456, 0.055424944467602245, 0.06929638359936015, 0.09421292602294877, 0.04003391248143969, 0.08651981746116955, 0.006696293149293671, 0.054154088870892604, 0.05282242504519321, 0.030946435797358715, 0.04137114959678823, 0.04390582810306261, 0.045451192155240044, 0.01869086953510921, 0.08999707522772013, 0.07348146830354968, 0.037700144363747495, 1.0932071002260333, 11.442936428131597, 29.424862054086503, 37.67609134797127, 31.663935299842592, 25.38719577174033, 15.641171797629326, 18.56195003755631, 33.92616425791095, 12.62727648981156, 5.308523533805724, 0.44196880993343174, 0.7405472270423367, 3.7601985518009435, 6.509271360212757, 11.387399588861774, 8.663123269234935, 1.9827499096432042, 1.8200518335065536, 4.697370211924277, 2.834828568081702, 2.455442706423421, 0.3297729045152664, 1.0664772506683105, 2.129100037197913, 5.938717021096138, 13.805084824562075, 23.530483015121956, 38.13929188636042, 48.56860353100685, 52.191010444395005, 49.38433101100307, 57.80812694180397, 54.38145414475472, 59.413792317913426, 61.706362770449736, 60.620419286912494, 61.40076698795442, 59.88577112074822, 64.68991364202192, 61.590680306957616, 63.14810052994759, 60.524662463895744, 62.86456415730139, 61.56368263306157, 65.92981799956291, 49.49651079793131, 35.888726095999445, 62.37278915220692, 61.64462074156731, 64.18725405969928, 60.29224241933515, 65.1061712541888, 61.91114971714636, 60.58114459437709, 56.46757848801152, 59.73916469081756, 57.799631088010734, 58.564391289987874, 60.24732343612179, 60.5188024428583, 58.02757963057488, 59.03582096099854, 59.95195719503588, 59.52667420910251, 52.268128164352916, 38.82416909740817, 24.312093719359368, 12.321677765538617, 5.381203582209926, 2.1826180815696716, 1.1905377742744263, 0.5357534774849492, 0.06510469521726332, 0.7311586663126947, 1.067908548059002, 1.3765813073804303, 1.7101935994240547, 3.112802774675431, 1.8097749785069497, 3.730553278038579, 4.568317369107278, 2.5352671069483605, 1.2337399850929938, 0.5566321313381195, 0.37483612676301314, 0.5832244527916755, 7.904498634799835, 21.199983243019354, 28.893480916177076, 29.865589372573364, 17.455792619336037, 29.77786360248443, 28.547010114116055, 10.86248153640378, 1.911921219960336, 0.03172413952979109, 0.0440666337888087, 0.0693869888181648, 0.023515348457881523, 0.05039476519150119, 0.04612818022348708, 0.03338171056501808, 0.06281628333512815, 0.02924464999758188, 0.09412668750531251, 0.07229324295035294, 0.041155978481495575, 0.0647331808783835, 0.04851479308619615, 0.04560468170130926, 0.05963711804079433, 0.03184880501770925, 0.02684360595359918, 0.05113611230626703, 0.05205200872414055, 0.061845872100562825, 0.03393877906003787, 0.0926682016541881, 0.11970910589180647, 0.05500911960318204, 0.08402564202345188, 0.08441928098158491, 0.0451872518826877, 0.04550057801327879, 0.021256247099729318, 0.027993134290520704, 0.037273318476734624, 0.018354834643222632, 0.0746383683215226, 0.02042039346340443, 0.05846123819449737, 0.06600287202144824, 0.026202099247565194, 0.03876914345328847, 0.03938244280195044, 0.03511806033671864, 0.0532555022096682, 0.027318147626975854, 0.030055008227786714, 0.022807322337382266, 0.0105616070082291, 0.040250271033014984, 0.025583546450962464, 0.01647548306913626, 0.04671408809841641, 0.009962577004766753, 0.016411667945043697, 0.06783084207845312, 0.04692752785500019, 0.0158294344193212, 0.027008952625516443, 0.02113496197477704, 0.02290020858298146, 0.050181865526904026, 0.020895919559763807, 0.021439947323092533, 0.022758593399738593, 0.026184044470409715, 0.06774187628780642, 0.10470439289366046, 0.04531181011829646, 0.0715277525746534, 0.07936293214199044, 0.009860237234181935, 0.012712757959361038, 0.06614374792984416, 0.01542929137471102, 0.05651683809476034, 0.04139132452227416, 0.0556896010323638, 0.0732802706319959, 0.03123075783913655, 0.02051640151729507, 0.036035412321648294, 0.11129530777613963, 2.488697296188724, 18.144278410942324, 36.450809586432676, 39.37702717319612, 29.59192756683596, 25.476637578779652, 12.665591182247287, 31.96033508546891, 34.868690198467625, 16.81961947871793, 6.081941387345714, 0.3387113426241183, 0.2422025889879273, 0.866109466841144, 2.8273275254234194, 8.507134529852099, 8.089733546780002, 9.043030315829862, 4.098783918926793, 5.858339811525037, 5.954215776535773, 1.8384977598344128, 1.5689565265370955, 1.937027085692652, 4.096463101525461, 7.889708357472574, 16.36457452850957, 26.174952830037764, 40.525022552859404, 52.71795734282463, 55.40040354574881, 53.09517560466644, 59.53213022601221, 58.391779545814764, 60.10623185865341, 62.18351517954181, 62.163107087535245, 64.0315830323004, 63.65664366752871, 65.59363949683406, 63.61979692212997, 63.74099423808437, 62.897731719478486, 66.05425127090948, 62.55771321635093, 65.6021471177378, 51.345900489437966, 35.57099057782081, 62.68855956292922, 61.6642875056113, 64.04368746665217, 60.30880658857284, 64.17440829738494, 61.68368362611341, 62.76777575092932, 59.4063868830281, 59.31095953910582, 58.88204443839289, 60.266566584187174, 61.11218252489644, 61.29019537279683, 57.901663703303186, 58.31677990574991, 60.14865229206701, 60.62750308744369, 52.27648281281995, 44.01635562219928, 29.912004740007465, 18.16329013916754, 9.111404092081132, 4.723516731492935, 2.153416035636779, 1.6940684904975278, 1.1545474538880012, 1.7045820360222173, 2.2816057118677326, 3.8672831798753435, 4.29632943484091, 4.03150963206445, 5.225154046089419, 3.8444640559534875, 6.064567248667441, 2.9760986133929226, 1.1554966674697016, 0.13706737888916848, 0.20823820343902036, 0.5875402244348681, 7.029956684958551, 23.893547404196955, 32.51564072024438, 36.2289014939339, 20.84100204129373, 31.07591513664492, 34.83203172683716, 16.606477883554277, 3.7589870297139694, 0.037289368018748305, 0.09177833690398163, 0.02499115172653429, 0.0246232571530967, 0.059839116274228984, 0.022787109107500123, 0.02175017845846953, 0.1392668326415362, 0.029032951175806024, 0.049875618048733285, 0.025551305640669122, 0.015123400127425071, 0.05157774284241661, 0.09135741755486497, 0.019220722756618937, 0.09734560510203724, 0.06044870775733745, 0.03001203644089401, 0.04591153438894018, 0.0490282213826093, 0.029355728916162928, 0.02245722398642571, 0.061422608522397865, 0.134421541025081, 0.0255124113567534, 0.049374535259219914, 0.023136784194878513, 0.044794279421048785, 0.05995204912558679, 0.03255075031530953, 0.04694162004236733, 0.05305999657139183, 0.021039038190558072, 0.01640793326641283, 0.021398595812159683, 0.04131353595444272, 0.16836636068840183, 0.08322248310451547, 0.2884982934882564, 0.10271845550666894, 0.16023606873087345, 0.18086298609212523, 0.12234336816735807, 0.21641963942637368, 0.07802727316776592, 0.07599373107715961, 0.17309027333413401, 0.11476010129216219, 0.11915639643707585, 0.2127057983870468, 0.10827593310105224, 0.16551393955465288, 0.1750963205291379, 0.20169786568130219, 0.11199334411010628, 0.08281657141783545, 0.11502399559943907, 0.14856030653801658, 0.1603383414687649, 0.11775527524972156, 0.18453279239756448, 0.17646702036501902, 0.19356244093468114, 0.16044930164371768, 0.1433214755548585, 0.20375331022566368, 0.16225881664262665, 0.22588680077704693, 0.1434771139775553, 0.1460170172034733, 0.17436685160763804, 0.12831016653968444, 0.18122088704859057, 0.21794179484488505, 0.19047075522042092, 0.33300015714860737, 0.10065181075685448, 0.29293489251886645, 0.19628151680432981, 0.11061598697016317, 1.9079634258824012, 17.127464740507065, 42.400346955945416, 52.51365284765921, 41.523187314310384, 37.3796856787897, 24.78057376800045, 28.394210261683313, 40.45016411812075, 17.478210926055908, 6.785464565600119, 0.8069394709121797, 1.3427007318504396, 6.169494082850795, 14.212821087529584, 22.29675246823219, 19.99205404712308, 8.341601683247475, 3.1459666596304987, 9.942448427600246, 6.33216703130353, 4.8248712670418525, 1.2104440480470657, 1.4882897970176514, 3.0117652156660637, 7.005665446481397, 14.999545581879156, 25.634236451118227, 39.829158782958984, 52.85735837874874, 59.43838557889385, 54.52630335284818, 60.24078092267437, 63.85703755963234, 59.63964631480556, 63.42826366424561, 62.95286455462056, 65.9844409265826, 64.37881477417486, 68.40394712263539, 66.26528263092041, 67.46963854758971, 65.18438331542477, 67.74040760532503, 65.93660369996103, 66.74902854427215, 51.34834412605532, 44.12233806425526, 63.57565456821073, 60.87323173399895, 63.32010038437382, 60.16476146636471, 65.66472068909677, 65.30247019183251, 63.74184539241176, 61.054570751805464, 63.03166497138239, 60.73396013629053, 62.75356500379501, 63.29192599942608, 62.00337640700802, 59.219442798245346, 58.7601097168461, 61.62215340522028, 61.041697532899924, 55.14328825858332, 43.13903516338718, 28.25658213707709, 14.839125544794145, 6.717513915031188, 3.400930771904607, 2.10008749077397, 1.1660983437492003, 0.6876020938638718, 1.6328894443088964, 2.63781649451102, 5.09962986553869, 5.092232765689974, 8.077362391256518, 7.4334813029535365, 8.093460288739974, 9.970530636848943, 8.248648374311387, 4.535931829483279, 1.7424237151299755, 0.8883092852850115, 1.5634893553872264, 10.442066211854259, 25.97611611889255, 36.63018349678286, 38.02391536774174, 24.769467576857537, 41.66218434610675, 39.64480346248996, 17.529519450279977, 3.0726575611099123, 0.13051205645165137, 0.16371632956208723, 0.15763103270963316, 0.12088014023198236, 0.13171532011080173, 0.21441618160855389, 0.10828949285731201, 0.1739785829258542, 0.16231995045898423, 0.2825449935851559, 0.11274319097039201, 0.12376715789639181, 0.14609802334058672, 0.29000632224544404, 0.1423539831152847, 0.2274089255520413, 0.14735805411492625, 0.09214983592110296, 0.2513177942244276, 0.169310043115289, 0.1825714387720631, 0.10285406839102508, 0.11526702167165857, 0.2412799126919239, 0.11624333944412009, 0.175444905856444, 0.2031625645054925, 0.14014610239574987, 0.13125638747888227, 0.10784937534481288, 0.17331283719789597, 0.1483644638210535, 0.06559253234656588, 0.09578568154885884, 0.1761666679334256, 0.08045902010053396], [0.022182259708642963, 0.06275005886451372, 0.07167443542951538, 0.05384670375215431, 0.023940772403992956, 0.03284796944729263, 0.07809468124422335, 0.02012840288150455, 0.024126797704206362, 0.03722552991201801, 0.06337893278067631, 0.038254485585756844, 0.017494196147327463, 0.02847688242552742, 0.021324204844272426, 0.03639638146025039, 0.029221887610131697, 0.05499438773239813, 0.048667987688414516, 0.06881698875898315, 0.06577987914844867, 0.029362133411209912, 0.10269071546293075, 0.07173287261637949, 0.02310743919693895, 0.04123383982767982, 0.06953465226556986, 0.0605092287033556, 0.036580545166807796, 0.060196526934422796, 0.08879787183456844, 0.034284051057071455, 0.06545210076916604, 0.032771720716188994, 0.03538929376631014, 0.08035540670877503, 0.03389687405057973, 0.04981255369080652, 0.043632438135964256, 0.0341383028294771, 0.0593125993656295, 0.02724810037761927, 0.08156976332106898, 0.014066695791458892, 0.1284181696152495, 1.126161383525018, 8.654782349063504, 21.7510840969701, 36.16405294787499, 28.27467799186707, 24.02969091169296, 12.271840130129169, 23.465703110541067, 35.50501631152245, 15.703529638628806, 8.097114466851759, 1.9098633239346168, 0.3030945360660553, 2.1136750713471444, 11.83556568238043, 6.524554385292915, 11.876497576313636, 4.38374778916759, 5.0034494265433285, 6.238928369937405, 2.6514766389323823, 1.1208176444615088, 1.0105343847986192, 0.578951214350039, 0.7558623665282804, 1.878054740448152, 5.0048668730643495, 10.465136612615279, 20.869033259730188, 31.13090676646079, 34.33959776355375, 35.30980387041646, 45.019156625193936, 53.2169298971853, 58.987328698558194, 62.60787248611451, 63.66521012398505, 67.40867707037157, 67.4090849968695, 63.88338412007978, 65.33070733470302, 63.47293946050829, 64.05393661991243, 64.08561760379423, 59.096268607724106, 42.93056903346893, 52.28888926967498, 53.85530740984025, 57.73458250107304, 63.370957836028076, 60.80717509792697, 64.45134332103115, 64.58095412100515, 62.76868181843912, 62.01162907385058, 57.91313271368704, 58.11082409274194, 58.703784481171645, 58.86588819565312, 60.02178322884345, 59.9291996032961, 54.455147635552194, 51.30292700183008, 38.80841293642598, 25.534206205798736, 11.95032835006714, 3.6240690177486794, 1.362213297717033, 0.8520471569030517, 0.6962455881218756, 0.7698142372312085, 1.8342126929952254, 1.2820879778554364, 0.9968279073795966, 2.145660529213567, 4.841284425027909, 4.125214565184809, 2.5210105171126704, 3.538671909801422, 3.732348252688685, 5.330829562679415, 2.327869332605793, 0.9164646712522354, 0.13892117377010085, 3.2879133137964436, 10.145789980888367, 25.487918315395234, 17.781366994304044, 26.127388208143174, 24.556657421973444, 27.36867912354008, 28.110352254682972, 13.916946899506355, 1.8434191086599905, 0.08499164059157334, 0.06613584956334484, 0.07556062326916764, 0.016718242925802068, 0.05505421919928444, 0.017079913034854878, 0.054140885345517635, 0.07179157027313787, 0.0970106867833003, 0.12942621874953472, 0.056924446666192625, 0.013889490078473765, 0.06489859458299414, 0.047624943657748164, 0.0038321015533931075, 0.08649373216734779, 0.03656824179474385, 0.05106442179831286, 0.10583816471719935, 0.013105429731489671, 0.08781513424530145, 0.08009133620127555, 0.039980481679160754, 0.041851256898934805, 0.054307896343450394, 0.056609756899096315, 0.0379265999541648, 0.03479988103912723, 0.0683257348775383, 0.017602231781629306, 0.03960564634912918, 0.017319713876913154, 0.04756595871801819, 0.05160019687947728, 0.04177807634996791, 0.08753761889473086, 0.06795022155969374, 0.05556473636158532, 0.03508233382636982, 0.02604767507422836, 0.03720965657022692, 0.011459209246470804, 0.011144140265851973, 0.0322622224508274, 0.008632566971373896, 0.029405848303389166, 0.05958231211069131, 0.05719710118888367, 0.04168715703511431, 0.0424604423554434, 0.07059662632884518, 0.05434607050471729, 0.015022341638893611, 0.05012697915756895, 0.060040333097980875, 0.062064720437892025, 0.048707759143003536, 0.047936025150721116, 0.02487527901276706, 0.06676691449097087, 0.05037080579166932, 0.05578680609863612, 0.11695489722995028, 0.02836265488557758, 0.0794476308228989, 0.043683589826668465, 0.0456831329351952, 0.03985680827510454, 0.007047969162569292, 0.04666913405901963, 0.034344905251336676, 0.04532190332669885, 0.03463342162449995, 0.08802772364428929, 0.012732855318444631, 0.01138342782900098, 0.006862861252645212, 0.031686208601440155, 0.09271549226175393, 0.04046716201569765, 0.05494147403946808, 0.12231604181109898, 2.5973751419974915, 15.111319403494559, 30.835140443617302, 38.91682332561862, 29.70191671002296, 17.42629639564022, 15.030902970221737, 35.69372154051258, 34.56372983994023, 20.980352086405603, 10.252263699808429, 0.9171871840953828, 0.22173163180630054, 0.2513973447944849, 1.0813458528249495, 1.8073947126826935, 10.129689631923553, 6.696616017049359, 4.329570051162474, 2.5352318056168097, 5.848553007648838, 2.675746794669859, 1.255799640090235, 1.125889759390585, 1.138717380742873, 3.551959429056414, 7.990880993104751, 13.868877272452078, 23.267733243203935, 35.97635969038933, 38.98127571229012, 41.87877762702204, 49.28484793632261, 55.363219476515255, 61.15851748374201, 63.34499959022769, 64.84799300470661, 68.04728600286668, 67.08270457483107, 65.63029404609435, 65.61881326859998, 65.42587580219393, 67.14306200704267, 65.83415923580047, 62.04339242750599, 44.91137381522886, 48.44127162810295, 56.39637570227347, 58.662834936572665, 63.40960887170608, 60.47849616696758, 63.233204195576334, 64.06744526278588, 61.790493688275745, 62.278969980055294, 59.20570665790189, 60.00902768104308, 58.322424196427875, 61.34026835041662, 60.62349050275741, 62.35986102011896, 56.98209931773525, 54.79754701737435, 44.46407456551829, 33.840378099872225, 15.914413909758292, 5.938650340803209, 2.919896442082621, 2.33035734103572, 1.0435491584001049, 1.2519809675793494, 2.1451631236460904, 4.301117177932493, 3.6541418298598263, 5.448892414569856, 5.214273391231414, 5.6377059990359895, 5.3255623098342655, 4.921507681569746, 3.517117750260138, 2.8094373499193503, 0.2911319505543478, 0.36184192725246955, 0.058535112053035736, 2.525013541021655, 9.977620320935404, 29.7868928986211, 24.542823222375688, 25.498418500346524, 24.183445861262662, 24.55732422490274, 34.541152677228375, 20.204519033432007, 4.066602832848027, 0.11598463921296982, 0.0830353737898892, 0.02419795195061353, 0.08935798169864763, 0.010803805705490372, 0.08259289672658329, 0.043592015506639596, 0.017973242417698907, 0.03591196108309012, 0.06282785126278478, 0.011327270711321506, 0.09375079880438505, 0.014557233380694545, 0.036366756840218464, 0.03398790061774273, 0.04571525117142066, 0.009673984980420961, 0.04689478142667682, 0.054046533956763246, 0.07823043968528509, 0.016761423471654137, 0.04913640448883657, 0.0565162405461794, 0.060783365606180126, 0.04624137737517876, 0.05474404169006213, 0.062186788887746876, 0.05241024292885296, 0.0716560033540572, 0.0548474099336853, 0.005056083102845737, 0.03727267113243861, 0.04174514606054272, 0.061013751227648995, 0.03127143519269603, 0.059122605729968324, 0.06131455948155734, 0.11420075751600728, 0.14216433038874982, 0.13791090298083522, 0.1289177202289143, 0.13904920238400661, 0.10082059524833195, 0.24651802355243316, 0.22493723479490127, 0.11328805568477801, 0.1022979881494276, 0.08185693137948552, 0.140306199450166, 0.15470629287583215, 0.12085942521450982, 0.34906422418932764, 0.14294958583289577, 0.25261763092731276, 0.19445128678794832, 0.14377734383508084, 0.14384616917419818, 0.22248610583764894, 0.11147850238147283, 0.1702860544525808, 0.13849368138659385, 0.11293631407522386, 0.18119834874185825, 0.13914704713369572, 0.0870853282451149, 0.1041092268461662, 0.11727374302403581, 0.16286641629713197, 0.08656092573918643, 0.19013882464458867, 0.16626263728305218, 0.15105185429415396, 0.1120462348203986, 0.13778344127199343, 0.21143433758087699, 0.16257522627711296, 0.15191256939884157, 0.19114177163329818, 0.2691033374397986, 0.21557930226047195, 0.11014881123217846, 0.26546469559111907, 2.036950323850878, 14.277600011517926, 36.20082909061063, 48.80131383096018, 39.30320032181279, 32.47072173703101, 19.763430856889297, 33.842555015317856, 41.417091123519405, 20.45310708784288, 9.962489777995694, 2.4898566017227792, 0.9142574800118324, 3.680639891855179, 17.317707538604736, 13.030384355975738, 16.83793302505247, 10.955364242676767, 11.09885238832043, 11.285665073702413, 5.655711639312006, 3.7792747539858667, 1.9933637207554233, 1.2023970604904237, 0.9473301698603939, 2.3992147945588638, 5.739485621452332, 10.996951172428748, 21.30131571523605, 33.85907211611348, 39.36132200302617, 41.56882016889511, 48.39155950853902, 56.48522523141677, 60.14229413001769, 66.34846825753489, 64.96791162798482, 70.61946653550672, 68.82679431669175, 67.56907847619826, 67.14368958627024, 68.04348130379954, 68.01267500846618, 66.11415370818108, 60.69754877398091, 48.282725503367764, 50.81918108847834, 59.066411525972434, 59.48044123188142, 65.27697086334229, 60.695618967856134, 65.34749507904053, 64.53809438213226, 62.796040350391024, 64.70604635054066, 61.4513224171054, 61.4195708305605, 59.656665478983236, 62.915755010420284, 61.6411925900367, 62.6670688967551, 57.179802463900664, 51.901304183467744, 41.013585136782744, 28.863188451336278, 13.845493082077274, 4.92915875488712, 2.3687100314324905, 2.1632089682163733, 1.382880511303102, 1.920446123807661, 3.416131672359282, 2.63803614724067, 3.388429197572893, 6.982540622834237, 10.606899895975667, 9.911128301774303, 7.948851816115841, 8.017853171594682, 11.13582366897214, 9.976930964377619, 5.838728941256001, 2.6247324482087167, 0.4890431968435165, 4.495723122550595, 12.965397546368262, 31.384007507754912, 25.476943523653095, 33.50149316172446, 32.66540858053392, 38.010755815813624, 40.74962531366656, 21.07487924637333, 3.70980957823415, 0.22471876184065498, 0.16773174877368635, 0.23987063266817601, 0.15066835067925916, 0.12597297017853107, 0.12421511248835634, 0.22914195433259013, 0.11134009327619307, 0.2540979732669169, 0.19284599550789405, 0.17341563087557593, 0.18142632118636565, 0.22291719883440003, 0.1145994756370783, 0.17505029396664712, 0.10629093034132835, 0.10716547333304921, 0.12223508930014026, 0.2482040451779481, 0.1831765409799353, 0.15437590979760693, 0.12432010483837898, 0.12263665726828961, 0.347608381341542, 0.19002723627753798, 0.2576384945742546, 0.08224721487251022, 0.10752551933570255, 0.2618324275939696, 0.10962512118801956, 0.08863445761944018, 0.1335343192782133, 0.24101527527936045, 0.23670907973522143, 0.1447470119643596, 0.1576270796959439, 0.20527428586877164], [0.011739367600380173, 0.009512466832905287, 0.024673644671096437, 0.06353983805785257, 0.026729445446342714, 0.07590349358055862, 0.02746429422029084, 0.018623091821228305, 0.020709275643551545, 0.1517421914444816, 0.046644941002370856, 0.05017160377915829, 0.07648020456995695, 0.062088093780461824, 0.09490581424606424, 0.04362470830880827, 0.061857512806572264, 0.05967634174251749, 0.04687486697108515, 0.03112639176599201, 0.03751265966603833, 0.01998765337761612, 0.013451588475295614, 0.03706230338843119, 0.04029368523568396, 0.11723923842392622, 0.1086153636776632, 0.04498718802126185, 0.010308758731210425, 0.06864515523756705, 0.09906468342148489, 0.05442828323031145, 0.1377983799865169, 0.08521904613101676, 0.06505972585610806, 0.051581810769294544, 0.046395897309506134, 0.07682390225630614, 0.003073959636704756, 0.05525359741201805, 0.011227391040583533, 0.02421832414373996, 0.011694995787805848, 0.03767451872268031, 0.047963753703140447, 0.05432717877650454, 0.28662839543915564, 4.776174551056278, 18.899642575171686, 29.259287042002526, 30.935751199722294, 27.505711047880112, 15.273571187450042, 34.89676260179089, 32.809147757868615, 20.81535562392204, 12.720501422882082, 4.025500070664191, 0.8822737381823602, 0.8144939558640604, 1.9821180403232577, 11.059446296384259, 7.56210562682921, 7.086146108565792, 6.244612864909634, 1.7021625464962375, 2.1609604695150932, 0.5200788895449331, 1.3391402003265198, 0.25762280509356533, 0.6227391453519945, 0.7010511657403362, 1.7089780323928403, 2.433524747048655, 6.078343593305157, 8.259536873909736, 12.69844691599569, 16.37519826812129, 23.941902383681267, 35.892542562177105, 51.560975813096576, 63.32582312245523, 67.48892091935681, 66.76296864786457, 66.63259690807712, 66.48206418560397, 65.42374203282019, 62.14976318420903, 65.6656502908276, 47.38200418410763, 41.491400426433934, 45.35130685375583, 46.02597805761522, 56.733617167319025, 58.74103523069813, 63.44411396211194, 63.07799600785779, 66.86318520576724, 60.797828089806345, 63.37571567104709, 65.63944493570636, 63.637635861673665, 61.50933819432413, 57.52637524758616, 47.973513295573575, 41.44582248503163, 28.355857326138405, 14.706183671951296, 6.3082508694741035, 3.1959913430675386, 0.2088340819482842, 0.285456863141829, 0.6378615984032232, 0.7762826546545952, 0.4240332820242451, 0.7004247509664105, 1.3890348326775337, 8.314114693672426, 5.122843432810999, 3.8847517005858885, 3.0873791969591573, 4.040373453209478, 3.8993541944411496, 4.279616705832943, 1.3505623874164399, 2.8762612996562837, 0.24093413124642066, 1.1145254272607066, 5.000464502842196, 14.321516829152262, 19.865443860330892, 20.441408618803948, 24.69136534198638, 31.85522733196136, 30.57991966124504, 30.2271612997978, 16.518667782506636, 3.1264528680232266, 0.14596575059958045, 0.11043910492932606, 0.057464400756983995, 0.05132584164159433, 0.026041372085831342, 0.0032330899839214384, 0.06459478709486223, 0.04657960136330897, 0.05942835525098828, 0.04091030940593731, 0.12359359301626684, 0.011382798679293165, 0.030456972646436868, 0.03820307342515838, 0.012484746252847536, 0.09052497875546256, 0.027484239319399483, 0.056245811508908394, 0.07986781472760825, 0.1068970131417436, 0.0030071311536425307, 0.06425940912337073, 0.13187970725759385, 0.00928061894111095, 0.05694869717943573, 0.03729668415842518, 0.061222376121628674, 0.058503461130444086, 0.0547283215658559, 0.023635539992321885, 0.008848476403903578, 0.039172764537074876, 0.030872734308603312, 0.09768986203257116, 0.018165147442731167, 0.0468476900019713, 0.06573225146219616, 0.009409022938099601, 0.045528482765920704, 0.006505517146339821, 0.02381803554242417, 0.031930987099786444, 0.02287690227310504, 0.01785173321202878, 0.02423634636215866, 0.0545517651123866, 0.07347088096843613, 0.07890041421858535, 0.04501292474507805, 0.050933792315904176, 0.05738115381269206, 0.052829737354430466, 0.04983806824912468, 0.12692593759106052, 0.08108189554824945, 0.03129495983763087, 0.03693761874831492, 0.02696430693650919, 0.06101123079837811, 0.06291605479594681, 0.06585589039229578, 0.04995454425713228, 0.106347207160246, 0.0690789218811739, 0.09392054856664712, 0.06752523428369915, 0.05392364962326904, 0.02349974324686393, 0.059948279972999334, 0.036782187169357654, 0.12220562555857244, 0.04704358251464944, 0.042136816172710354, 0.1040581287816167, 0.03587125117079385, 0.060816521891542984, 0.015720868269131792, 0.07353515574528326, 0.06845063785271299, 0.07816315418289554, 0.05832431913023034, 0.029072741782593153, 0.06534229738697891, 0.15807121150916623, 1.1210447742092995, 9.236617915091976, 28.567918308319587, 36.74261039303195, 33.69551712466825, 19.893051462788737, 18.565264440351918, 40.245624280744984, 28.84834816378932, 26.03635980236915, 16.58479109887154, 4.718549049669697, 0.5195982766247565, 0.5741184252885081, 0.7399615681459828, 4.5811699955694145, 9.162698888009595, 4.631853882343539, 4.840307264558731, 5.782395860841198, 5.625249041664985, 2.147993849169824, 2.5040335184143436, 1.0799312255074902, 1.8173689323086895, 2.098157439501055, 1.4268763892112242, 4.305954440947502, 7.802181157373614, 11.491111959180525, 15.637425934114765, 20.193858031303655, 29.060144385983868, 41.638391248641476, 55.200005731275006, 63.591814733320675, 66.18262260190903, 67.92010707239952, 65.08469627749535, 65.75282104553716, 65.41963531124976, 64.71815078489243, 65.96921428557366, 54.91263720297045, 43.93139316189674, 46.24807834625245, 49.25069193686209, 58.15600587475685, 60.20597773213541, 64.20841524677893, 63.739719467778365, 66.275174848495, 61.91651551954208, 64.80636881243798, 64.35554727431267, 65.78323902622347, 62.752819753462276, 62.523984755239184, 54.09914939634262, 46.58467654258975, 34.59657184539303, 20.231400997407977, 10.474528727992888, 5.7914604583094205, 2.089818725662847, 0.7412824875885441, 2.078770389479976, 1.362263553084866, 2.873413904059318, 2.1930792879673744, 4.495942775280246, 13.948219956890231, 10.340223831515159, 9.33047729153787, 8.094039818932934, 7.350234879601387, 2.890235723987703, 2.0535922050476074, 0.9487634897232057, 0.7045898790801726, 0.07433836062949511, 0.651337820435724, 4.803536515082083, 18.247574029430268, 27.645743585401966, 27.177177244617095, 19.956195739007768, 32.19918389474192, 35.3195313484438, 35.48143502204649, 22.435975036313458, 5.367439985275269, 0.3293834254145622, 0.06372962868021381, 0.03695704290763505, 0.06954179986590339, 0.04357419630152084, 0.06400542033295478, 0.057873863261193044, 0.04706474569355769, 0.03185721857833766, 0.02318467809668472, 0.04458018465928974, 0.03381376117167454, 0.02784016185380038, 0.04754222148368436, 0.01486532330032318, 0.1390865874747115, 0.060696613809634606, 0.09368631718379837, 0.04365674227536206, 0.09709170058129296, 0.047193770221765005, 0.07350032938824547, 0.05500017552666607, 0.009002363358083512, 0.08929660273415428, 0.05663723647294026, 0.008107815895439878, 0.04477457947007591, 0.030262901507798704, 0.07268719600453492, 0.05535398557361576, 0.0325853928112455, 0.04314169370298905, 0.09946184638406962, 0.03816157444230011, 0.09235565310284015, 0.07336838606504664, 0.023721387805116755, 0.1170990979599376, 0.10287793969074566, 0.14548363614707224, 0.20897605336241185, 0.13605608154208432, 0.1295351411306089, 0.10814910724518761, 0.1291658867511057, 0.19027256827440955, 0.20446512848138812, 0.17575189260946167, 0.18360950323122163, 0.13993924333443566, 0.19823925449482857, 0.2997982435889783, 0.24480759436565064, 0.24736704815539623, 0.18809798173606398, 0.13001785313169803, 0.09404603376864426, 0.17272285756564912, 0.24355907023193377, 0.17007953246995328, 0.13782353831395028, 0.15447286588530387, 0.1959293461855381, 0.25405393853302927, 0.1814338135262651, 0.08101827194613796, 0.13254356840925832, 0.22676482946882326, 0.17639312352384293, 0.2374865517260567, 0.13258567260157678, 0.20805008288833404, 0.12547847574516652, 0.15954804516607718, 0.22591332274098552, 0.09184642679869168, 0.09016159260945936, 0.19656670069502247, 0.26022459290200667, 0.11285593613020836, 0.1793498705111204, 0.19107565824543277, 0.24386552072340445, 1.0425256649332664, 8.442746862288445, 30.655860670151252, 44.2058688594449, 44.716173141233384, 37.304835088791386, 24.78340768044995, 44.74017412431779, 42.43756240414035, 28.095794377788422, 16.30908573827436, 5.355129136193184, 1.2766782939434052, 1.918122119480564, 4.7022393441969355, 18.434977031523182, 14.470821849761473, 14.71721729924602, 20.982232862903228, 8.180844322327646, 7.166427710363942, 2.654857476872783, 4.75988837980455, 1.8268839894763886, 1.3048290220960495, 2.058624605978689, 2.2181724059966306, 3.575148726663282, 7.251118056235775, 9.717408322518873, 14.866769429176086, 19.910735468710623, 28.15262559921511, 39.78705606152935, 53.148790482551824, 63.45368062296222, 67.79255943913614, 68.61709656253939, 65.9182862312563, 67.58222626101586, 66.7378419445407, 65.50331907887613, 64.89233932187481, 57.29400227146765, 46.314299721871656, 49.22821675577472, 49.68997778431062, 61.98358804948869, 61.51828119831701, 63.19754200596964, 62.65245022312288, 66.65272651180145, 61.158133091465125, 65.62998025648056, 67.03986444780904, 67.65590406233265, 63.437653818438136, 61.782386149129565, 52.688217932178134, 45.03059817898659, 30.231701443272254, 17.380185011894472, 8.179538173060264, 4.574697594488821, 1.0845943107720346, 0.9343691266352131, 1.8646929413080218, 2.9423203872096155, 2.3588134011914654, 2.238605012816768, 3.5286870262315198, 15.051886670051084, 13.857039559272028, 11.399663859798062, 9.355700092930949, 7.947819742464251, 11.497000417401715, 11.286751570240146, 6.557730772802907, 5.321979714978126, 0.49940052171868665, 1.8451981486812716, 6.392897088681498, 18.87652804774623, 26.56080815099901, 27.677206877739202, 32.256207312307055, 39.04671261387487, 41.12882829481556, 42.0195318806556, 25.919457481753444, 5.152654426713144, 0.2636663501541461, 0.199192788812422, 0.31575177946398336, 0.21771777541406695, 0.21745543626527633, 0.2929975585110726, 0.1978337641565069, 0.13172318017290485, 0.140018732617459, 0.12959941590745605, 0.1670497466599749, 0.2069559407931182, 0.08498801699569149, 0.1612621822184132, 0.15058256415349824, 0.33474267009765873, 0.22188854193495167, 0.1726642058741662, 0.13912699095183803, 0.27507297033744477, 0.11758560975713116, 0.19752199701484174, 0.15326237035614831, 0.14224172059086063, 0.20593492945115413, 0.1909980382169447, 0.16871408799723273, 0.1530690097640599, 0.148207952058123, 0.10514616515607604, 0.1057574573543764, 0.16194847442450064, 0.2498511801804266, 0.19245017319917682, 0.131654906417093, 0.2705075459614877, 0.13799888051805959, 0.08443598169833423], [0.02041921943366047, 0.00813665431773951, 0.06462881672045877, 0.021402939530690352, 0.02596593540792744, 0.0730190959368502, 0.025613063818684993, 0.02122804357279693, 0.012950960550487283, 0.042683316484814694, 0.038584979746731064, 0.024352559985052195, 0.02574454365868963, 0.049063043909207474, 0.01605834819436554, 0.059397386146649245, 0.045016498545244824, 0.04755745131161906, 0.03180914464586925, 0.013116312010454075, 0.06710844414849436, 0.03850135741935622, 0.05071859821797379, 0.031025068977126674, 0.07016176417950662, 0.08394835907365046, 0.011832553577879745, 0.03967079446620999, 0.0203301138319676, 0.04369485514959501, 0.0883584131576842, 0.1133794729567824, 0.08894761904112755, 0.046565375110555085, 0.09323618690212888, 0.0781806133266899, 0.05437796274500509, 0.04835125246656038, 0.025001943990167592, 0.03207791318756438, 0.07026317889892286, 0.05691453348845244, 0.022110822009703806, 0.047578943908334746, 0.05063628590094948, 0.011844971863132332, 0.0773085677816022, 0.26327236645644714, 2.43284642215698, 16.760630953696467, 32.97183982787594, 34.37968830908499, 26.36678026568505, 12.300683279191295, 23.86077796259234, 25.091258825794345, 26.613295347459857, 22.355858664358816, 7.3491841746914774, 2.346269906528535, 0.6565608240423665, 3.329239405931965, 1.913528778860646, 1.5612821641468233, 1.1280688811694424, 9.704121293560151, 5.773200354268474, 1.1430523352276896, 1.459661152574324, 0.5451392802980639, 1.5792136471117697, 0.9766123179466495, 0.4074283262654659, 0.38935603634003674, 0.07115738736766, 0.23283714879184003, 0.6239118727464831, 0.7610747674780508, 4.667989698148543, 10.391774562097366, 24.296108099722094, 44.70986204762613, 56.89564635676723, 63.457144075824374, 64.8310915116341, 65.69757838403025, 63.97668161699849, 63.894005898506414, 60.36828540986585, 46.84286263681228, 34.38344986208024, 34.637246824079945, 33.35836587413665, 55.537227584469704, 61.252513162551395, 58.93137216567994, 64.06943390446325, 63.35881025560441, 52.48628647096696, 47.17420877948884, 44.00656538624918, 39.76084678403793, 33.89175722675939, 21.1062954702685, 10.824134484414133, 4.634330368811085, 2.185954302549362, 0.4522074831108894, 0.14470077089725003, 0.6843519198798365, 0.7342364398702499, 0.3188626480198676, 2.279461891420426, 1.473028590121577, 2.36716853995477, 2.873091534260781, 4.319515545522013, 14.893320933465036, 9.08386807287893, 8.660491358849312, 7.9028605549566215, 9.730010897882524, 3.096436930279578, 2.0659469356459956, 0.5515991175366987, 0.21121183500414897, 2.8881843243875815, 9.724350917723871, 20.078518775201616, 19.200207917921006, 20.11259436607361, 24.960822366899063, 26.200103067582656, 20.865644331901304, 20.69167740883366, 18.687324677744222, 5.500482368853785, 0.20072514852208478, 0.09509337555256583, 0.02425345119028803, 0.04976745409470412, 0.013255734267013689, 0.05984516453839118, 0.022943569159495737, 0.07151292111243933, 0.03209509653970599, 0.01556564353391408, 0.01744005096805913, 0.06497352564286801, 0.019183686235919595, 0.02413102650954839, 0.022279805684041594, 0.029678876293943297, 0.021148023773886023, 0.036394753523411295, 0.04521623298886322, 0.03987998243481402, 0.02000736865034748, 0.028490354081675894, 0.06606041288544094, 0.023959187242472847, 0.04519510428391157, 0.07436958637328879, 0.04001339281638784, 0.01486016369815315, 0.04591216641147772, 0.03405042105324326, 0.021324151218117728, 0.010887008599726664, 0.01698486067564978, 0.024133163894857132, 0.02067485339789381, 0.044773847856108225, 0.05777101978779801, 0.03935587104229678, 0.06165191012945387, 0.05352983446491342, 0.00991072625883164, 0.019281743575007688, 0.05964031262743858, 0.012634640931332064, 0.03593076088075196, 0.02827901340600464, 0.01680536052933143, 0.06503792299378304, 0.04063187474985758, 0.05573902519479875, 0.010612855417533748, 0.05478649828282576, 0.10771383906924918, 0.06897895506793453, 0.050116962557958986, 0.03514509941000612, 0.021620659803551052, 0.028163382009933555, 0.020675743975105788, 0.04277608590200544, 0.03575385202683749, 0.022449210706737735, 0.010650285515904186, 0.057355780980639884, 0.05918720226374365, 0.07672762798686182, 0.0043275057161677516, 0.029915218249023445, 0.10375242139543257, 0.0914265952944275, 0.040209794777535626, 0.05390095043807261, 0.03261328224212893, 0.048779170028865344, 0.10386969413488142, 0.07489552871594507, 0.08526709516562762, 0.02303673885762692, 0.042421291432073044, 0.033435332889278094, 0.05253695004108933, 0.033878905458315726, 0.0557745065570118, 0.037275260509622675, 0.045647364290010546, 0.03196595709831004, 0.48860355430553043, 5.581561682685729, 23.625141574490456, 40.68932279463738, 41.46523037264424, 23.85059156725484, 18.713228010362197, 32.5746488571167, 33.288029932206676, 35.936025957907404, 22.461692056348248, 7.872218999170489, 1.4358681776831228, 0.3582781475157507, 0.7110693894567028, 1.6920135362494377, 1.3238789934304453, 1.6296640302865737, 4.753923435365, 4.681898913075847, 3.8755824248636928, 2.979552995774054, 2.418860721011316, 2.2948008102755395, 2.870647652495292, 1.25412049793428, 0.7715117042103122, 0.3233856311248195, 0.8705694468752031, 1.5048236904605743, 1.9940292979440384, 7.206967367279915, 13.55120647338129, 30.139253139495853, 49.58314026555708, 61.40422651844641, 63.90116030170072, 64.46234556936449, 65.33468069568758, 63.132030579351614, 62.80099038154849, 63.102432374031316, 50.193739552651685, 37.63307079192131, 41.629134455034816, 39.74665172638432, 58.900181478069676, 62.21579628605997, 61.32094675494779, 65.07443535712459, 63.4520685288214, 57.67389558976697, 53.425337191550966, 50.75326173536239, 46.62202927374071, 41.411846914599025, 27.29417762448711, 15.923328476567423, 8.732705135499279, 4.387291160322005, 1.1670514797010731, 0.6338458880782127, 1.5239386260509493, 1.2102506261679435, 1.9808642301828632, 3.966770176925967, 3.4745137008928486, 3.090633293313365, 2.900591516687024, 7.409465610980988, 17.293681060114217, 12.760009496442734, 7.439546758128752, 8.03724193765271, 5.514341573561392, 3.086425815859149, 1.383584086452761, 0.812668337696983, 0.328313660237097, 1.7020446302429324, 8.722989424582451, 21.608374541805638, 27.87332146398483, 19.575294371574156, 21.375315150906964, 31.546175941344234, 29.006445177139778, 27.313275644856116, 24.38796216441739, 9.383293967093191, 0.5967916860695809, 0.13979302779320749, 0.03994216962206749, 0.029136472637014046, 0.03163536334590566, 0.07257756116169115, 0.029774539608268008, 0.04703428220724867, 0.006655146088075614, 0.02748887989700081, 0.048538756316467646, 0.00834332281468256, 0.10411494186208134, 0.03956722703972652, 0.04980352151417925, 0.040351635956716154, 0.026103844640836604, 0.07092261206238501, 0.0327982809845238, 0.043529759371472944, 0.027471708036178065, 0.052737879581869616, 0.05198832383499511, 0.03531322123542909, 0.02427543408327526, 0.06697425618767738, 0.054778546290171724, 0.03576445851414915, 0.0925144095033888, 0.046787766604534084, 0.025806822776494008, 0.017235260344140472, 0.09928242093132389, 0.09521585768989979, 0.03902167284620866, 0.05405457021908895, 0.0017832336344590952, 0.03635670959709152, 0.027750426144789786, 0.11882779068283497, 0.09378862822608602, 0.12303502298891546, 0.22312834798809023, 0.15939337201416492, 0.14978719634875176, 0.13063078475815634, 0.06388183119857023, 0.19167867669415092, 0.1645610947161913, 0.1847962806782415, 0.09954567938562363, 0.12269175431180386, 0.16086703406706934, 0.17178557963380892, 0.20245427025421975, 0.11186333132847665, 0.1314665407182709, 0.07792093250299655, 0.16675578340167002, 0.1328850444406271, 0.16661139114970164, 0.1520961087437407, 0.1424098462467232, 0.26843353144584164, 0.15493697727159148, 0.1845844880106949, 0.11605652124290505, 0.1414685540141598, 0.1863943247665321, 0.29953817206044353, 0.18186251632869246, 0.13345591784004243, 0.1597341126011264, 0.17171557451928818, 0.16260188613687793, 0.17484904266893866, 0.1326070617764227, 0.09265317100911372, 0.09000505020301189, 0.15978251403618246, 0.11247135233134033, 0.07608858808394402, 0.11749344937984021, 0.16837654965779475, 0.10405587648311931, 0.11061132915558354, 0.7209525978372944, 4.843428490623351, 26.998328931870002, 47.046465027716856, 50.1624115820854, 37.31679047307661, 23.1880404872279, 32.92868198886995, 32.799004508603005, 33.483567930036976, 28.435253943166426, 10.154116192171651, 3.049739642489341, 1.2703056681540705, 4.809057741395889, 3.433466587335833, 3.6801824454338323, 4.0477582956514055, 18.396120071411133, 14.025091548119823, 6.710540431161081, 4.176542701259736, 4.731220266511364, 4.76283407980396, 3.576574263072783, 1.4929924737061224, 0.9473065130652921, 0.45157429611971306, 0.49570969396060516, 0.9061892871414462, 1.1907379377272822, 5.896491235302341, 11.23227475150939, 28.39667154896644, 48.35865082279329, 58.75884279128044, 64.08089899247693, 64.96040813384518, 65.32822839675411, 65.66927456086682, 62.487969552316976, 64.94124735555341, 56.24270508366247, 40.73044492352394, 42.90812130897276, 42.08606312351842, 63.44250186797112, 67.36051820939588, 62.63585859729398, 64.3521426570031, 66.623489164537, 57.975059093967566, 52.655874067737216, 47.17631901464155, 42.78993245094053, 37.09878121652911, 23.082864092242335, 12.811768112644074, 6.05540459194491, 3.302558218279193, 0.6803276906571081, 0.345635459788384, 1.7066720464537222, 2.1943643544950793, 1.383764270332552, 5.556893896672034, 5.742477409301266, 5.740291178226472, 6.891123902413153, 9.497741864573571, 23.49093964022975, 16.458184834449522, 17.609071000929802, 15.529615667558486, 18.422486243709443, 8.660439387444528, 4.645366447587167, 2.5130346225154017, 0.7758770570639641, 3.705991396019536, 14.196330462732623, 24.297882972225068, 25.01209362860649, 27.043565627067323, 32.89739520319047, 36.74421464243243, 31.50532053362939, 32.86300974507486, 27.33880831349281, 9.054439510068587, 0.45857551237267835, 0.18359248075754414, 0.1806345233513463, 0.1300208868398782, 0.13500369123874173, 0.21328994042931065, 0.09110951150256781, 0.10369249799799535, 0.16320613032627493, 0.19162468281724762, 0.14949430561354085, 0.15196360617635712, 0.11379652356188144, 0.13559380876681498, 0.1183636639747889, 0.1272934376292171, 0.19668366699930162, 0.14088974394384893, 0.17680063633428467, 0.16329956240952015, 0.13300061646488406, 0.14153388599234243, 0.12024070962422317, 0.0877333160549883, 0.16439456252321122, 0.14837381009372974, 0.1626285459966429, 0.1293449981078025, 0.13530784346643956, 0.12732016643689525, 0.11766186614911403, 0.14455789549937173, 0.248309581450397, 0.2631583725733142, 0.1295460195791337, 0.12444782701711501, 0.18779223604548365, 0.14664890184517831, 0.11827872014574467], [0.012729338974872184, 0.04274771766616933, 0.07601856764766478, 0.03985091705896682, 0.05709393212812082, 0.03455771681582255, 0.02257645791096072, 0.06309494015670593, 0.049575269447579506, 0.05961476359516383, 0.06790638600866641, 0.04466359248204578, 0.04265138210969106, 0.06766453971185031, 0.024256492559347424, 0.09361370737033506, 0.05026490945789603, 0.0287862325597915, 0.021496607185972315, 0.09031350018396493, 0.028244748208371383, 0.021671937898762768, 0.014220743624102927, 0.026602008635358467, 0.03229460498738674, 0.04917395045800556, 0.02068612829691941, 0.04605377393384134, 0.035143651503829226, 0.08442074420952028, 0.01952941214004832, 0.08551681684630533, 0.037124946397999604, 0.042882890049969, 0.021391647394686457, 0.07205001003439389, 0.03697183606545291, 0.02553154631788212, 0.03772453660325658, 0.030006771501634392, 0.017331856370513, 0.06482999907025407, 0.028938306758420605, 0.03621422107361498, 0.0323539461580015, 0.030047803170858856, 0.1341957136267616, 0.15840315740675698, 0.0428504960220908, 2.50203384507087, 10.333585219998515, 26.927604675292972, 36.886086771565104, 23.55864171058901, 18.582820969243205, 18.561504848541755, 25.597783903921805, 34.7904702924913, 27.357927906897764, 13.472953227258499, 4.5923041335998045, 0.7978048223641612, 0.17405614166730837, 0.9485834897045167, 2.106869268801905, 1.3388926007093922, 3.153318161925962, 3.556486579679674, 1.6532288948374412, 0.4302074910411912, 2.442479273003917, 3.5025723759205114, 0.4493271763766966, 0.4351843965630378, 0.6476704043246085, 0.17113173891219402, 0.20317552671317132, 0.07848579977308551, 0.10838002146732424, 0.5537766458526735, 4.377200372757451, 15.5787923835939, 28.233271491143014, 43.810070330096835, 52.06152908263668, 52.44472895899127, 56.38728364821404, 51.683436132246456, 50.08626268756006, 41.203659272963, 31.095656425722186, 25.37845084744115, 30.6966729317942, 53.31818980555381, 70.59456732965285, 55.01702716273647, 51.33330183644449, 42.878515258912124, 30.882091214579923, 17.00785598447246, 8.222772007988345, 5.1932181081464215, 3.1462140140994905, 1.7867011456720292, 0.47454887460316386, 0.23425326231987248, 0.08350144636126296, 0.09210804582483346, 0.4595059414784755, 1.7387122949284894, 1.8098177568566416, 2.3455552997127658, 3.9598476838681007, 1.8436274845753948, 4.7878529179480775, 1.5587021025919146, 8.019552538471839, 21.519438720518544, 18.201148856070734, 8.174572452422112, 7.900272771235436, 5.0250165789358086, 0.9220448556926943, 0.19069524962575207, 0.7132898799834714, 6.2191405027143425, 12.709257948783137, 22.80360310308395, 25.245243234019128, 22.73697772333699, 30.24147402855658, 23.275232814973403, 19.143100169397172, 22.345978213894753, 18.120516692438436, 5.864011558794207, 0.24714554149296977, 0.14269185853340935, 0.01571458060249326, 0.12974166311323643, 0.015646381540254, 0.02148186765430916, 0.022827121879785292, 0.03879826245529037, 0.1067228353912792, 0.039164981083764185, 0.030706690496674953, 0.0381282304653958, 0.03677446500308091, 0.010633496699043581, 0.08798908983026782, 0.02043861486468344, 0.03785314744398479, 0.10389221711985527, 0.07951275595734197, 0.05602477216011575, 0.04702212822232996, 0.0826570795728795, 0.03314320058111222, 0.014400473596798557, 0.08150206413120031, 0.042148242374100996, 0.08310173232589038, 0.01709089107480982, 0.024054117027610063, 0.02883753746808056, 0.02646676155798618, 0.04012931341065034, 0.03403967283966561, 0.08944284125802018, 0.050934987413066055, 0.041691653971229835, 0.023654990964719368, 0.03732473446777271, 0.033479176101184664, 0.05579406478171868, 0.058201526727287047, 0.03469183199828671, 0.027763484113459146, 0.037797441360570734, 0.06349464270075963, 0.050372962329176166, 0.08223345593339013, 0.10206797791104164, 0.07522549810669116, 0.06263672764743529, 0.08969239439935454, 0.07659781438809249, 0.06020857366703211, 0.03315522816152342, 0.11896931010508731, 0.09299694530425534, 0.023655042675654256, 0.031034451638979298, 0.019766970259708264, 0.03494120127851925, 0.014996271666830346, 0.039687445387244225, 0.03598681553417156, 0.04053640104229412, 0.055506054026585434, 0.028158354557930466, 0.02103747345597273, 0.007278941798910139, 0.02266279602002713, 0.06821730279273565, 0.029459635336552898, 0.020157730642465815, 0.031222447700377916, 0.052984663315357707, 0.07452096534712661, 0.042652944929056594, 0.034978835347799525, 0.04812313446534738, 0.04420663635697096, 0.02733434081047533, 0.03458454904537048, 0.030523038153807004, 0.02190166276939694, 0.02248139597565657, 0.026850583099369562, 0.03856799940788939, 0.0857121769278761, 0.08240854532848443, 0.15152402492540498, 6.011258805951765, 19.32133267002721, 35.76406924955307, 39.98657134271438, 22.112261825992217, 21.329882337201028, 18.92315914553981, 32.20578720492701, 46.15695776477937, 28.242806773031916, 16.10581772942697, 5.375685787970021, 0.7099234444960472, 0.12126233383652665, 0.2730560446939161, 0.8258501368184245, 0.8884259757976379, 2.0346320805049714, 4.052489899819897, 3.368838674599125, 3.0452335746057573, 4.019898926058124, 2.9070124366591057, 1.737609496039729, 2.7560450665412413, 1.7295888619076822, 1.010190441964134, 1.5552996916155664, 0.9063304924676496, 0.7292710256672675, 1.800971708951458, 6.280741816566837, 19.91092766484907, 34.666998001836966, 49.590098550242764, 54.83962228221279, 55.613580442244015, 59.07873561305385, 57.985206265603345, 55.225034375344556, 46.36457274037023, 33.99560589944163, 29.257000300192065, 35.60737448353922, 58.00091535814347, 69.96978867438533, 59.39595730073991, 55.803536907319106, 49.4869912055231, 36.58411918147918, 22.257575834951094, 12.390811501010774, 8.525712836173273, 5.8874212445751315, 3.431536045766646, 1.1059334753982484, 0.2062904708568127, 0.25711795315146446, 0.6625379033146367, 2.304592026818183, 2.8420320009031608, 3.817698782490146, 4.4705655305616325, 7.121511178631937, 6.409281319187534, 5.921078122431233, 5.357389402004981, 7.066693113696191, 14.251629018014478, 5.083968822033175, 3.405616043075439, 1.2531764324634307, 0.6473512827388702, 0.3957989583573034, 0.067255747534575, 0.3702747166877793, 4.872480505897153, 15.777438859785757, 28.953259798788256, 31.11596449728935, 19.028802302575883, 28.567873201062604, 27.638655862500592, 24.86542836312325, 25.104183035512126, 24.164389025780466, 9.423170743450042, 0.56531117207581, 0.027537401990904927, 0.07944360886129641, 0.031074623374508756, 0.010392412659712138, 0.06817196570937673, 0.052541017967967264, 0.053710068140419266, 0.04537749832736389, 0.0471088110709623, 0.041498703236180934, 0.034800164491659215, 0.011087479445362284, 0.03239291705070965, 0.09493586787533376, 0.022167083506862965, 0.049108721901692694, 0.07759477823011338, 0.07606905284187487, 0.0682873615334111, 0.012936641409572576, 0.05698160448622319, 0.03873448946603364, 0.02021882040876775, 0.08743631142762401, 0.019442721630536744, 0.050469960551708944, 0.04477602354581318, 0.038717516788071206, 0.05759809076065018, 0.046191344172844005, 0.015826117258609062, 0.0896944628367501, 0.06151319458900441, 0.020913116318444093, 0.08224166839593842, 0.041137917958680666, 0.04539856957572122, 0.043464446545488415, 0.06893035445001817, 0.2024345051857733, 0.20711187032922623, 0.09958438214755828, 0.14732105206818352, 0.190308298615198, 0.1594489899974677, 0.20425759526270054, 0.21502456267274198, 0.22641815936132786, 0.07526013294174787, 0.18655192437431506, 0.1458039375082139, 0.25465580784986097, 0.19337430506223635, 0.24564734930472992, 0.26678172330702504, 0.10131086087635449, 0.10711447485992986, 0.1525551792714865, 0.14427871773800544, 0.11014430663518368, 0.15918118098089773, 0.12248561537313847, 0.12822097092266047, 0.09064671778750998, 0.0755200435918185, 0.11073512130326803, 0.16275459810370402, 0.14522365654908842, 0.15467200278034135, 0.1397066590406241, 0.1342369138353294, 0.08809434265018472, 0.16990348546495362, 0.1912714549971204, 0.11363236624146662, 0.16615261173536702, 0.15876088982387898, 0.11095482765907243, 0.11352787950947402, 0.0776831234895414, 0.17529502841493777, 0.09527097771605177, 0.18212850205600264, 0.15904723816821653, 0.12008485669690756, 0.3612513960369172, 0.29436471902074357, 0.3435740704017301, 4.843936927856938, 19.73833553252682, 41.56680014825637, 50.513416644065614, 34.1892493924787, 29.424328611743068, 27.80257171200168, 34.802923817788404, 43.358444706086196, 33.922249732478974, 17.022902196453465, 6.529044518547674, 1.3704501525048287, 0.5483050007493265, 2.71405658414287, 6.172756514241619, 5.097646617120312, 11.815854791672, 9.906032162327921, 7.0104090629085425, 3.449669408221399, 7.340428463874325, 7.957159886437078, 2.2376023569414696, 2.2924214024697585, 2.270406364433227, 0.7988026978508119, 1.2109750389091432, 0.824529278662897, 0.38669455496053545, 1.133112804062905, 5.1574882576542525, 19.55089722910235, 33.6104291485202, 47.9900303963692, 54.40158374847905, 55.788349490011896, 60.534860626343765, 57.10371632729807, 58.84579389326034, 53.080792273244555, 40.72786008158038, 34.05786175881663, 41.38171526693529, 62.064600683027706, 76.20966772879325, 62.994712321989006, 55.65003102825534, 46.68493624656431, 34.09208443857009, 18.974169569630778, 9.609946166315387, 6.589929999843721, 4.428015168636076, 2.7770258245929598, 1.1197258772388583, 0.6311042739018318, 0.2213494458626355, 0.38167934504247486, 1.358834053239515, 2.8804989303312, 4.631132656528104, 6.122185395609948, 11.950558789314764, 7.554301581075115, 10.538532003279656, 7.056512601913945, 15.172060247390503, 30.775261540566724, 27.3274608965843, 18.473341734178607, 13.789679715710303, 10.366488022188987, 2.490393476140115, 0.6415153475057694, 1.3328403835335088, 8.401218768089048, 17.245182914118615, 30.548366154393843, 33.11774023117558, 29.97241512421639, 37.803419328504994, 33.23530935472058, 31.11933381326737, 33.62165104958319, 28.575825806586977, 8.305007930724852, 0.5037137193064536, 0.1838745543312642, 0.12133030115716881, 0.1662219580142729, 0.14990128216243562, 0.18638407451010522, 0.11547295376658441, 0.2364498355816449, 0.1601926775108422, 0.17443632046061178, 0.148859050184969, 0.13688865057643385, 0.10345945405142923, 0.13849303787273748, 0.12779113431010516, 0.1313646203808246, 0.11692000958587855, 0.1893623945333304, 0.2082861758648388, 0.17623871084182494, 0.11725793096927867, 0.15827169671895044, 0.22314498741780558, 0.0914328235892519, 0.1839167044888581, 0.1660723716861779, 0.16845809205645518, 0.1455214042817393, 0.12358951742850965, 0.12031266826295084, 0.08638206719150467, 0.16275582384438286, 0.15375049093798285, 0.2152537608579282, 0.16413344911509947, 0.13059356820679482, 0.22665213793516162, 0.14334611294250335, 0.10490805736833042, 0.13232295040882405], [0.02577584984171535, 0.03155061295406232, 0.062225491649681525, 0.08209847890201115, 0.09073768306763903, 0.06352771088601121, 0.03867938859207976, 0.0350223031766232, 0.03493578120645496, 0.10528399969541258, 0.03022155574252529, 0.14626962703562554, 0.021133512153380343, 0.053357012690074986, 0.061337457849614085, 0.024497304637465748, 0.021136798670575507, 0.05202724493198818, 0.02984539891082433, 0.00319271044704252, 0.12597961982171382, 0.015637414481100297, 0.07062821213396327, 0.06817482321733428, 0.0168471448799415, 0.026714631221106937, 0.032953095862702016, 0.08683991197857165, 0.10685078739639252, 0.02712557227500985, 0.04137581124180748, 0.04440948111756195, 0.019001579475438884, 0.057392806010020364, 0.03784827512478636, 0.030410285333111405, 0.06531647256305141, 0.012676523915762383, 0.022999145007962664, 0.016155514956241655, 0.07263072766363621, 0.0723967184462855, 0.06888234371980352, 0.024546410873412125, 0.03136924546842854, 0.021251725265756253, 0.024811567310544274, 0.04660802322529978, 0.020943267623923963, 0.0325093470934418, 0.900471942319024, 9.110418596575338, 28.294735031743205, 39.11660532797537, 33.04105397193663, 27.74965697719205, 18.180846668058827, 12.320081360878484, 27.411317248498243, 27.779084559409853, 21.274804415241366, 11.278782294642541, 3.9413223295442523, 0.767045411611757, 0.30266105287498046, 1.3231496777265304, 1.4544896300761931, 3.0467101018274985, 3.5147662893418348, 2.706690863255532, 1.178028845498639, 1.8433297521645025, 2.218430546983596, 2.1534297639323823, 0.5541376877696284, 2.024857043739288, 1.4889645672613576, 0.7991877642850723, 1.1094376228509413, 0.8451701388243706, 0.11734855917072105, 1.7138840594599325, 8.102645499090995, 13.435792692245977, 19.185930490493774, 21.9422153119118, 19.01994166835662, 14.020758309671956, 14.407056858462674, 26.95571630231796, 25.883814903997607, 21.435401939576675, 27.730906086583293, 35.01743824251237, 32.91683643094955, 20.173740194689845, 10.172774907081358, 5.097132786627739, 2.583156059826574, 1.3895128715422846, 0.4868190597382284, 0.12283884319326571, 0.1107214772773366, 0.1647688117959807, 0.06142278855306007, 0.10301624920459525, 0.6685561061866823, 2.127737258711169, 3.416228751021047, 3.8867408325595245, 2.7472979359088407, 4.6303050364217455, 5.476875583971701, 6.470870375633241, 2.369529561650369, 3.1929382681846623, 6.8868284167781955, 12.252233182230304, 4.0446309408833905, 0.644604581738672, 1.2489830510270212, 0.1709135111060835, 0.3671760442516496, 3.8644551509811036, 11.726156069386391, 19.88135103256472, 22.488171977381555, 15.274692985319323, 11.145855130687838, 19.75964576967301, 26.913990128424864, 20.934203440143218, 26.218055755861347, 15.513471191929234, 2.7653653535150715, 0.08486613240693847, 0.013108823500994234, 0.06013427462969577, 0.05056970902988988, 0.0327970820569223, 0.05665325154099734, 0.018136024610289646, 0.02460880490440515, 0.03382407271513536, 0.07597548286280326, 0.08236303970578217, 0.0520894053061643, 0.08255777925613426, 0.04710525642299364, 0.07705411167755243, 0.07060304614565066, 0.0910435589931665, 0.009543933894395108, 0.08609021833587079, 0.047359210739453, 0.001363509262803071, 0.0868213956334418, 0.02722166076813254, 0.035858970781367634, 0.028761838405062596, 0.04041389975276205, 0.014268423978900237, 0.0675574942461906, 0.08484614517299399, 0.06321391361134668, 0.028326566398684538, 0.028773574872062575, 0.007810448812726405, 0.02573733477132215, 0.06158032304336948, 0.06416018541541792, 0.10479684438436263, 0.02750515160451253, 0.06346831991968137, 0.08830530028189383, 0.07098522442843645, 0.08552683727635492, 0.05900640168317384, 0.03179514821949265, 0.06151761874676712, 0.07238773989581293, 0.08356512358952915, 0.010067045542171166, 0.038763221593633775, 0.05139049180152436, 0.12574370304543164, 0.021585931122723608, 0.08434456442632983, 0.06540911557573466, 0.02919699166781239, 0.033356050449994304, 0.019535000751455946, 0.03479590504280022, 0.058705455533439116, 0.050614333651479215, 0.06617767796401056, 0.016766416449700634, 0.0175536215876139, 0.04847341667740576, 0.026794783170184782, 0.006971184648723612, 0.030005831128707337, 0.011231456094631746, 0.043556304318049265, 0.036055353590317314, 0.07141687666937228, 0.06140858911338353, 0.11067453907021593, 0.08829128087287949, 0.01840107187989258, 0.05780597637978293, 0.026746109773915623, 0.04669921450136651, 0.01627753935604086, 0.022424128988096793, 0.05013820617609928, 0.03760393904221635, 0.0975990423091477, 0.0436852790505415, 0.03205767697504452, 0.01656179436512532, 0.02542636819153784, 0.038160524901843844, 0.06499966456284446, 0.02058801924689643, 0.02835555708095912, 2.036734348343265, 15.968355324960525, 37.239190301587506, 41.413470775850364, 33.110636818793516, 25.72217599038155, 15.813952203719849, 20.316045745726555, 38.29016193266838, 29.56835019973017, 24.043119145977883, 12.079853838489903, 3.691091047179315, 0.5183634041778503, 0.17450313864936753, 0.520636969276013, 0.7561405483753451, 2.3563060260588125, 1.9379218763882116, 2.7327317239776736, 2.7458052289101387, 4.689617647278694, 2.7543849233658086, 3.7926635194209317, 2.1405217339915614, 3.888903284265149, 3.6212831543337916, 1.9461763818417828, 2.456247772901289, 1.4355811092161364, 1.3337061241749795, 3.3136364625346277, 11.234485987694034, 18.811777560941636, 25.609217612974106, 28.636324444124778, 26.256087057052124, 20.597005121169552, 21.636909784809237, 33.097414508942634, 31.79899819435612, 26.782631912539085, 35.00279995702928, 43.00322701854091, 43.865893502389234, 28.481861506738973, 16.611427914711737, 9.301635123068287, 5.351739718068031, 2.2514105708368364, 0.8341475431957553, 0.3425119354599907, 0.24135097500778016, 0.42150577410094203, 0.41494646800621865, 0.7662974646495235, 1.675161072804082, 4.395367810803076, 6.787606670010475, 7.04968914870293, 6.325710809999897, 4.621622870045324, 2.521741794001672, 6.736584478808988, 7.6409114368500255, 4.103865349485028, 4.824044627528037, 4.765457655152967, 1.6446921013055311, 0.7221402792680649, 0.6422948572904833, 0.25644430139612767, 0.32290388439451495, 2.4431585784881347, 12.08023823076679, 24.578463838946437, 29.71559009244365, 22.841283352144305, 15.840396823421603, 17.107874462681433, 32.64087415510608, 25.616568134677028, 29.730661799830777, 21.69087963719522, 6.041066367780009, 0.15299454601781984, 0.02493881068432764, 0.049825527389804204, 0.06877667721240752, 0.03450263126362716, 0.04192855517049471, 0.05013351771800269, 0.08166056006185471, 0.05776902029831564, 0.09912291376460945, 0.03495498703071668, 0.020591587301403768, 0.050529389822434996, 0.04561834870987842, 0.09160600542541474, 0.032774352228208896, 0.03431891571850546, 0.01612108121926506, 0.05241583920113983, 0.028871365995596976, 0.01168827719670991, 0.1069323757603284, 0.02707146540013773, 0.05557833059180168, 0.04786644138455872, 0.015264084513839937, 0.0718119788554407, 0.08424320333306828, 0.06567051243637839, 0.021701244592306115, 0.06661742775430603, 0.07718805449023362, 0.031693245119024674, 0.014205644988725263, 0.07107412127116997, 0.11283037177617512, 0.07194958356839996, 0.07555530661897314, 0.07975202819873249, 0.08162263104872358, 0.08451838977634908, 0.13930245573001523, 0.24399325822389897, 0.2250752991606151, 0.15822495003381085, 0.17646334314298245, 0.21418283122681805, 0.10383983202759298, 0.10259853210300209, 0.09420877382639917, 0.3170732811333672, 0.10081719381794815, 0.22315421111641393, 0.06663048955341501, 0.17095892479823482, 0.19951022500472687, 0.15460994965847463, 0.1044240583395285, 0.16926495118006585, 0.16580018064668103, 0.1791613975599889, 0.22331855229793057, 0.2099366816541841, 0.21530032368196597, 0.13720267001659642, 0.1120172766968608, 0.13177270009633035, 0.11078096400465696, 0.21051140081497932, 0.15460120093437935, 0.18441481485722527, 0.10353727326277765, 0.1802783843971068, 0.14665167508346422, 0.20545218680654803, 0.17965060598667593, 0.10848813945607794, 0.12759525328874588, 0.17634691310025033, 0.23416205189160763, 0.07868296016127833, 0.205953192987269, 0.17868403285261125, 0.2614684438993854, 0.12752015368952868, 0.0930986128326866, 0.08466688059871236, 0.17572681089082073, 0.18038246510249956, 0.08991110484085738, 0.19175064299375782, 2.048293940963284, 15.371002862530371, 41.8127445251711, 50.65397870156073, 44.32530110882175, 39.198343599996264, 27.573158164178174, 21.318917351384318, 37.77368776259884, 35.66509608299502, 27.638493084138442, 13.837667953583503, 5.666029924346555, 1.328519525066499, 0.5784808976515647, 3.12057813809764, 4.110905023351792, 10.809803124397032, 10.03073803840145, 8.733940682103558, 5.332162678241731, 5.298969130362234, 6.003766098330098, 7.901798573232467, 2.3129655516916707, 6.092680836877515, 3.008558187753924, 1.5965747929388479, 2.467982769012451, 1.4590919186030666, 0.6214836804616837, 2.2596041569786687, 10.729025833068356, 17.929057959587343, 22.4531412893726, 26.666547406104307, 23.959294173025317, 17.32729381130588, 19.313107459775864, 36.4411291768474, 35.497650100338845, 29.254240912775842, 39.67140497699861, 44.675000021534586, 39.88731968787409, 25.58981364773166, 12.406363698744006, 6.950385522457862, 4.275657563440261, 2.2410942469873736, 0.8855355567028447, 0.4951095713242408, 0.26356531847869197, 0.26066123237532957, 0.2662726425595822, 0.5048340462869214, 1.2250679923642067, 6.643988105558581, 9.886180066293287, 11.333171840636961, 9.15013945871784, 11.462218799898702, 12.074520395648095, 11.72879288273473, 8.959140623769454, 11.501780806049226, 16.169020841198584, 21.493925663732714, 11.2792912221724, 4.234951696088237, 3.8209712649545367, 0.847859352586731, 0.6712516938005725, 5.431187325908292, 15.845146813700277, 26.702601832728234, 29.844518400007683, 21.371598705168694, 17.645001872893303, 29.894991459385043, 40.169189053197066, 34.02726334910239, 39.53018396131454, 22.793830517799627, 4.851718419982541, 0.2229306360165919, 0.08981690666968785, 0.12227034466641566, 0.14507934090591248, 0.18394017742285806, 0.17124948662615594, 0.15498473519279113, 0.1589314209958238, 0.10241630276845348, 0.2923110211568494, 0.2387156325482553, 0.15332874421390796, 0.16080153354954335, 0.12511363403210718, 0.1623814213540285, 0.1559825800359249, 0.2041868240602555, 0.05857827344668969, 0.12098740786314012, 0.21054132420930172, 0.09896817932566328, 0.2174271676208704, 0.11652987164955948, 0.13616167910156712, 0.16106998607996972, 0.1387465210451234, 0.17009923625136578, 0.1496561953136998, 0.2380500860031574, 0.19116084722261276, 0.20160706894051647, 0.1965793258240146, 0.10726279714294981, 0.17377720905407784, 0.1602625447295366, 0.21765656498891695, 0.12263513275332029, 0.13582532053753255, 0.1650856044744292, 0.25506750350036933, 0.20300642046476566], [0.03919572419216556, 0.04571762604398593, 0.05880583220371797, 0.06411675972143008, 0.06661218771290395, 0.0183521437593886, 0.0719771167683986, 0.04990482515084648, 0.025184862803848043, 0.017979214073068673, 0.022505056601197972, 0.048096984054052064, 0.055552145706549774, 0.03202983733987616, 0.02864791346984285, 0.030096783002297726, 0.04528385940037909, 0.0855161656715697, 0.016949645528990417, 0.02877310181276933, 0.0076870933351587635, 0.05022295082228319, 0.05579230277949283, 0.06711847223942319, 0.06267469496496263, 0.03662234292395654, 0.03920368384569883, 0.016313970667280017, 0.051779706601894675, 0.010564020185190584, 0.06637844662632673, 0.004826981157454993, 0.04858048895614282, 0.02996805916360069, 0.047965488892288945, 0.07429104703929156, 0.03741599469175262, 0.04023209559701143, 0.05536007214217417, 0.011121741770165823, 0.0626556308669669, 0.02537589257342681, 0.03889381660208587, 0.07244437677605499, 0.020440813537026127, 0.07573439499303218, 0.05131412815723208, 0.021807386074215177, 0.034232370765699495, 0.07309149890657395, 0.05587297949879881, 0.6653809475321925, 7.353705686907615, 22.393456543645552, 36.42719299562516, 36.06615451074416, 31.463849313797493, 24.09838338052073, 11.137812310649503, 29.714607538715487, 35.84956907456921, 31.684194341782604, 18.920195794874623, 9.177134190836261, 3.969276816614213, 1.055225809254954, 0.5987468037393786, 1.1629532157413422, 0.31614266816646824, 3.623223992124681, 3.413888566916989, 1.1820012258906518, 1.8986967037762366, 3.950764700289696, 1.4756342696566738, 2.3602754646731965, 3.9706126288060224, 2.0290934486735255, 2.864966589596964, 1.3261705156295531, 0.021009158846291325, 0.07776363933038327, 0.3215888178636951, 1.4590951055288317, 0.6626498134386155, 1.4287118133037322, 0.6867695707947977, 0.5851548104997605, 0.4549517939167638, 3.4670168257528737, 6.141787930842369, 4.891270620207633, 7.013044405368067, 6.058289004910377, 1.6500830313851758, 0.3309844878892745, 0.040103879291564226, 0.09909614665253509, 0.1517062006337989, 0.5573511508203323, 0.16202128342082425, 0.09580056663722762, 0.33587703180889933, 0.9543684341253774, 1.1031424638725098, 0.47753165325810837, 2.6965508009156873, 2.731688128363702, 5.683085370448328, 4.416790816091723, 5.719457999352486, 3.0465782121304543, 1.4287099746927139, 8.28712780629435, 9.690893100154016, 2.45537381979727, 2.8281068513470315, 2.8448151676885547, 0.6098802676123958, 0.5983062725394004, 0.7452845921920193, 2.322626594574221, 8.93119961984696, 19.719923926937966, 24.89010399387729, 21.913642806391564, 15.957999287113068, 14.542044247350386, 15.434406995773317, 19.860948824113418, 25.447411998625725, 21.430316586648267, 10.151001830254833, 1.2828289380958005, 0.08031168607093635, 0.06211154373182405, 0.1158826039623349, 0.06791847487611156, 0.06174416626773535, 0.01671997619973075, 0.04030855883273386, 0.02839414109926551, 0.04061662960016439, 0.043672615617153146, 0.049971003656185446, 0.020107300989630244, 0.03356408928671191, 0.0609163737915937, 0.0499851341479488, 0.028478742103963613, 0.0298892593597092, 0.07842983705021682, 0.05312277364634699, 0.053872589863115744, 0.026115085065905607, 0.02480483148247004, 0.00839359637710356, 0.05422107559899169, 0.0544972502956948, 0.053307864319292776, 0.051355064065466006, 0.12271898873751202, 0.06048734157135891, 0.02231336225034489, 0.030244094049257618, 0.07916789381734787, 0.02457460865468508, 0.048255782589436545, 0.04663526148144757, 0.06010549653682017, 0.06717284916028862, 0.1596581932878302, 0.09730246669102101, 0.03584383288398385, 0.0375251468992041, 0.07863376199478105, 0.03841343733872618, 0.04318849018384372, 0.08505881118077425, 0.04053601416789236, 0.024212576569088047, 0.03966492240227038, 0.0498242020576952, 0.06540508595325294, 0.04904309497965921, 0.033621863807521524, 0.09637039815706593, 0.009690230832465235, 0.02670357082670014, 0.012076478845800364, 0.03762437443759653, 0.06753221334468934, 0.07457135094990654, 0.03966522883744009, 0.05732157515482076, 0.019044660429860798, 0.03609773357428851, 0.039628828169717904, 0.02713217786813696, 0.07614075101070827, 0.05073274020105601, 0.06655026482598436, 0.08394276663180321, 0.10285018432524898, 0.11103699824983075, 0.013789485918448098, 0.03882320627810494, 0.004607145045508421, 0.059662291689986185, 0.04282926772570899, 0.060291104319114844, 0.059901778435995506, 0.09994942304347793, 0.08203648706717838, 0.03425462945033947, 0.01479796693480063, 0.016235360470149788, 0.04062190794596269, 0.035472720741264285, 0.02343922230084577, 0.05796785458862301, 0.07665052889816223, 0.03702204929844987, 0.06188688078714956, 0.011256097312716228, 0.04319574503648666, 0.047350259002057776, 1.4498808451237217, 13.446756697470143, 31.28466367721558, 42.88762692482241, 40.54931379133656, 31.489195669850996, 18.230458767183368, 17.307591745930335, 33.3296109784034, 38.68030832659814, 33.900994408515196, 21.05687752846749, 10.967345122368107, 2.9578024725760184, 0.6822003159792193, 0.14805107257298886, 0.6377006586520904, 0.1963376557274211, 1.9864069069585495, 1.6411410079848383, 1.8353349811607793, 3.7073129896194708, 4.844433107683736, 3.357748663233173, 4.180430260396773, 5.9794557382983555, 4.4193599685545895, 5.541301494644535, 4.993815104807577, 1.1788458016610917, 0.7131649157212627, 1.1280539271331604, 2.6026056226222747, 2.2164166550482474, 2.5725556092877544, 2.0346486280041356, 1.523329923229833, 1.084780133058948, 7.2176053254835075, 10.273587665250226, 8.047466576099396, 12.148143283782467, 10.350642627285374, 4.400772836900527, 0.9013985409851998, 0.06166925052961996, 0.32117638676877946, 0.22891879292024722, 1.0083715653707905, 0.6090415545528935, 0.5886153828713202, 0.7786715619506375, 1.9565611020211253, 2.6654684687814405, 2.6101069104286934, 5.517304433930305, 5.1565640491824, 5.884097526150366, 5.733030871037514, 6.8156364175581166, 6.876264493311606, 3.060655598678897, 1.6095403101175063, 5.707819346458682, 2.493205080109258, 0.514704384390385, 0.8961384587230221, 0.34726152737294474, 0.30253958197370656, 0.6781122256671229, 2.1593594070403808, 8.954380827565348, 20.183797151811664, 30.463311518392256, 31.41487263864087, 19.782334719934774, 11.978829272331732, 14.188645558972514, 25.133591005879065, 30.379108036718062, 27.90364726897209, 15.94489464836736, 3.0636476316759667, 0.0405677531905953, 0.036999951492274, 0.12985484494316962, 0.010411159788829186, 0.03963334808847116, 0.009003249147245962, 0.03742664331390012, 0.014707548449927521, 0.030173278796756943, 0.02108405926264823, 0.08361819816092331, 0.02834397000110438, 0.039377440247804894, 0.040074319789005865, 0.03070677285112681, 0.08568373974412681, 0.03153186869777499, 0.014180530711347538, 0.03869607015663097, 0.061238540576830994, 0.03948659628569599, 0.037770398456843636, 0.07203407540556885, 0.02765776397990844, 0.06733572711386988, 0.12069738995764526, 0.026779361820269017, 0.09011345164429757, 0.04269863441286068, 0.06756693244941774, 0.005846062436654803, 0.0339529057213616, 0.05298740207968701, 0.02451340014475488, 0.01288373633513167, 0.06835205765861659, 0.03134469235045535, 0.04075341076860505, 0.025827865296554182, 0.048733974671772415, 0.027875922838105794, 0.054752430352833004, 0.1890541820396339, 0.17164693304127263, 0.14385523965522168, 0.10719686761618623, 0.15176024047597764, 0.14951600122355646, 0.18726334426431887, 0.18299248069524768, 0.17705703064078288, 0.14747071500507095, 0.18274327229347923, 0.13348600977370817, 0.10871497809045738, 0.16081222813696633, 0.09865127173402617, 0.12872226055591338, 0.21318584440215943, 0.21731496638348027, 0.15732317261638182, 0.14319801282498146, 0.08187817499762581, 0.15090257440122867, 0.12285877680105549, 0.1498400410937686, 0.18720332893633074, 0.15929987864388576, 0.13565290478929398, 0.19022093394831305, 0.2525875236718886, 0.16946459369313333, 0.1785266171059301, 0.09877962210486013, 0.13631391609388013, 0.13023834855806443, 0.14654515821847225, 0.2686371882596324, 0.20346066463858853, 0.1227761465575426, 0.1444161998768968, 0.08370223800621687, 0.16291449597525984, 0.2078836273041464, 0.15172647132027536, 0.09447037753078247, 0.1976758887570712, 0.24046623538578712, 0.13396965640206493, 0.17164578390938623, 0.09978194090147173, 0.19560835534526458, 0.1090344827201578, 1.0758403159918324, 11.671035001354834, 33.13355522771036, 51.730567332237, 51.415428423112445, 44.02569478557956, 33.066961226924775, 19.273689600729174, 40.65389202487084, 44.80935296704693, 39.43662366559429, 24.088442133318996, 11.639575631387773, 5.167174060498515, 1.8286983308292206, 1.7520990991784682, 2.943398793858867, 3.717520957992923, 9.040330744558766, 9.648556997699123, 8.481467520037006, 6.082689579456083, 9.457692503929138, 5.828470962662851, 6.395106363681055, 8.393942771419402, 8.391152985634344, 8.828856156718347, 5.235253658986861, 1.5965614323654485, 0.5602575045439505, 0.5274469393395609, 2.2298140006680645, 1.2146723630928224, 2.125886145137972, 1.3246431201696396, 1.39655131966837, 1.2216471952776755, 5.822636437031531, 8.743115105936605, 7.393719746220497, 10.917666342950637, 8.71104580740775, 3.0444434621641716, 0.5790751367326706, 0.19437450945617693, 0.3257566426069506, 0.2301338543334315, 1.0594981283910814, 0.22881537105046937, 0.6012965282124858, 0.945161283016205, 2.612344377463864, 3.3205873927762433, 2.2282148993784383, 7.601261177370626, 7.147967565444208, 12.627938389778139, 11.157588901058322, 14.678741789633229, 10.055140083835973, 12.29119408515192, 23.502516515793342, 15.472926632050546, 10.399911519019835, 6.783584769695037, 5.764818249210235, 2.6001793915225617, 1.159057811863961, 1.3320138665937609, 3.242679560376752, 12.184891969926896, 26.505730229039347, 34.31991531002906, 29.47626863756488, 23.017754708566976, 22.13115196074209, 23.77068308091933, 32.23276134460203, 39.47091302564068, 35.15530170932893, 15.01179220214967, 2.5193802820098017, 0.15100290127579244, 0.1986193260358226, 0.2615407932429545, 0.12068782918035023, 0.074292165527661, 0.14632717556049749, 0.13893456498701728, 0.09117608454318778, 0.07343775532659023, 0.19921149667953292, 0.1680399306238659, 0.18711573444306853, 0.1471312154805468, 0.1403022617582352, 0.24237578614584862, 0.16680783141524563, 0.10512631581795794, 0.13734937585409612, 0.18823960074974647, 0.17114663166144203, 0.12033380462878174, 0.11429919215339808, 0.16388338269485583, 0.13630144418247286, 0.16869470597274844, 0.2053183818896932, 0.1874000449935275, 0.28243366568799944, 0.18752507054277007, 0.10922076465982584, 0.09395200413681808, 0.1451180436678471, 0.17262233150822504, 0.20571049633285693, 0.13840323704625332, 0.2022981108917344, 0.30781587465636195, 0.24145945305785826, 0.1610357419497544, 0.18431893129262233, 0.10174674192263235, 0.13290502401369234], [0.07010528051684942, 0.02590791382376225, 0.09185047940381112, 0.0449058716185391, 0.01779264868086865, 0.021793979535540266, 0.017108716025588014, 0.011238875656178402, 0.01116051731045328, 0.015080234903331487, 0.024894331619443915, 0.010936747815820479, 0.020860890189426082, 0.06637099259082349, 0.030584985938584133, 0.028120779860464316, 0.02346650652226902, 0.05192457765881574, 0.09456807672376595, 0.025180946179335157, 0.06701867396552717, 0.028960096214206952, 0.08433789180050935, 0.03919884217001739, 0.03753211446887544, 0.06655131436644063, 0.03382957322643169, 0.10338174975326947, 0.06289783722510742, 0.09139584452514687, 0.018661302371671604, 0.052663040452546654, 0.018805876569522005, 0.04777454913804128, 0.07368409089864263, 0.06946185859100473, 0.05676685471928889, 0.08523497309896254, 0.0181209824738964, 0.031293379781287045, 0.044903190310804114, 0.014683513398913127, 0.07334345756399055, 0.023212088722615473, 0.02290746535084421, 0.0396185894046099, 0.04088066180326766, 0.06554096696838256, 0.09395119208361834, 0.05771166712586438, 0.051532378945980346, 0.037630445684396455, 0.19054186350155264, 1.9284461654963034, 15.523017260336108, 29.600352817966094, 39.63389535104075, 35.13781970547092, 25.315898849118142, 13.221309646483391, 13.541353479508432, 23.729843362685173, 28.233877497334635, 26.741800039045273, 17.89725342104512, 10.6706246829802, 4.150199572886191, 1.448853306712643, 0.6091586740747575, 0.662096759244319, 1.5521551764780477, 3.0283546351617385, 3.2584273863223294, 1.7461548697563911, 2.586295917149513, 4.1811201072508295, 6.520484926239138, 2.690345366154948, 4.425382767954181, 3.2025289535522465, 2.2810104921940835, 0.3923038200986001, 0.6421730799540397, 0.6432630085656721, 0.07480234944171484, 0.17389100375435046, 0.12035145529455717, 0.1814222149550915, 0.18191041214571846, 0.07924280189458402, 0.24191590356490306, 0.03717330952865943, 0.296545863271721, 0.02481477913416682, 0.034081907266931194, 0.0915528082799527, 0.10735449020660694, 0.12655846053554168, 0.3668438072406477, 0.14547286495085687, 2.6197167173508675, 0.3245085015171959, 0.5260077359214906, 2.304850903249556, 2.501713191309283, 3.7012987704046316, 4.444751922161349, 4.638125752249072, 4.120248844546657, 5.054946714831937, 5.078075951145542, 4.984392591061131, 1.0300467668041107, 1.503028960958604, 4.5945138988956336, 0.9140032001080052, 0.28236395168688994, 1.0343187182180344, 0.7474314157039889, 4.532741961940642, 8.740651857468391, 15.37573520214327, 16.57522051565109, 22.68178213027216, 28.421876699693744, 15.490906776920443, 16.74783422100929, 25.818693753211733, 27.569890829824633, 31.490474362527173, 21.359764914358816, 7.6633312144587125, 0.6144394100673738, 0.029982522903611104, 0.033017382130868016, 0.02550454171855123, 0.04291585098291117, 0.03799480093162387, 0.048001410755058455, 0.02384246034067004, 0.07796250809464725, 0.035066360893148574, 0.04399134649805004, 0.03276011448413615, 0.03909465804275486, 0.030614982111259337, 0.02293645028745936, 0.052001937217409575, 0.06821880432506723, 0.04624605817239612, 0.0677702751671595, 0.07973938774798187, 0.020019708411587823, 0.04078738676804689, 0.026001416770140492, 0.026262629769682407, 0.07456863133777535, 0.022137363125840505, 0.032131564240121556, 0.05780218424455774, 0.04316216357232582, 0.04206316064923041, 0.01643265492372936, 0.050595855610745574, 0.04561929482846491, 0.0018086228655808938, 0.10890329782400401, 0.05307693860583729, 0.036520897561023315, 0.03679945096073132, 0.03228160064487207, 0.055078668895387844, 0.01031593984789065, 0.02100797141000869, 0.06179591167658087, 0.03684594100641628, 0.011176925956181461, 0.04393086002598848, 0.06403085062160127, 0.034380371291791244, 0.05523994955564699, 0.005857296637259425, 0.03840920853338415, 0.0376364671354813, 0.013976761857197892, 0.014579502599043472, 0.018211978397542433, 0.012255125761693044, 0.0369778843296151, 0.07296962963957941, 0.03916006662972993, 0.05433021631512431, 0.025625416986464013, 0.0894911507625253, 0.012398741392028189, 0.016264634604956356, 0.022584702932245793, 0.029843589028103218, 0.03482764023506353, 0.04400659547818284, 0.031479579366503224, 0.05325198969653538, 0.008754389315483072, 0.04197529802519468, 0.058831756619075616, 0.029169326317646814, 0.095395298464404, 0.017146604819103115, 0.0482654582799202, 0.03024871355944103, 0.019817976393706856, 0.007232758667199843, 0.0530849059202498, 0.0556031403492295, 0.02687982084499973, 0.06026413419374055, 0.05241077919039996, 0.008778460755673869, 0.04278237548386378, 0.043148270567818996, 0.08493187041172097, 0.06315006401329752, 0.0384402695682741, 0.009182950391644433, 0.06398065654080241, 0.07363324564310812, 0.07436913438141346, 0.020669841267649206, 0.5820640440910094, 4.876512212138023, 23.769302406618674, 37.05809839310185, 44.395421320392245, 35.95271956536078, 19.66885074492424, 18.3848471795359, 22.508905626112416, 35.28064889292563, 35.63391716249528, 29.85762696112356, 25.485421726780555, 13.179408927117626, 4.252244445585435, 1.0247842943476093, 0.15221483705024566, 0.15969360187169046, 0.1547382847075501, 0.30918539471683965, 1.2972355585905815, 2.450089406582617, 2.8690034439486842, 2.0732172939085194, 5.869177810607418, 5.03338985866116, 4.755266356852747, 4.137481287602456, 4.1072604060173035, 1.3330363794680566, 1.3392935404854438, 1.6788773959682834, 0.5807405505930224, 0.7507657367856272, 0.4696988638850951, 0.3496135705180707, 0.7845880896333726, 0.13850949344135102, 0.48576271642119656, 0.19332012732423123, 0.4419319151389984, 0.1099944751589529, 0.24414552585972896, 0.5872139935531925, 0.4721408763960485, 1.1175685736440844, 1.3101785221407491, 1.5218578086745356, 3.6542560688910948, 1.2144115254763634, 2.28713846014392, 3.183004620575136, 4.850734885661833, 7.065446780573938, 4.244087386515833, 6.180236964456498, 7.382888611285918, 7.619490392746465, 3.508534133434296, 5.0561499018822955, 1.3560662082126065, 1.5603427564905537, 0.48457295123127203, 0.4453912311263623, 0.13844586217836027, 0.4677533989231433, 0.9919812061613607, 2.8907946617372575, 7.92646881072752, 22.23080369733995, 23.90586364653803, 28.529630091882524, 32.17443766132478, 16.745776937853908, 14.680348000218792, 23.181239097349106, 28.284348595526914, 34.10006253950058, 26.707563630996216, 12.364799322620517, 1.4436250324210813, 0.018075685610153505, 0.04143626323991245, 0.016149993377527403, 0.0276553048376715, 0.024253818912491686, 0.012955608788967855, 0.035186471988356886, 0.04835050170039458, 0.08694698808774834, 0.004071892340547376, 0.041270236664962386, 0.07797569246782411, 0.03071736018624037, 0.01173276488008278, 0.062252576688244465, 0.13753099997918453, 0.044982472750087904, 0.07062186892595022, 0.01415980611777594, 0.0487049782438384, 0.020843890698386297, 0.03702532049388655, 0.07886240093578255, 0.04095272003342548, 0.013482068240973017, 0.07305504844313668, 0.029373205296935576, 0.022670780571417946, 0.008893474493356002, 0.017961458070203662, 0.021191372859081434, 0.07168057945466812, 0.020586971621659976, 0.047814316762190674, 0.07387157559635178, 0.047162326142912915, 0.025288937763581355, 0.04298456906971913, 0.06660018311513048, 0.04819277951854372, 0.029936299073479833, 0.04915010980180195, 0.10201118015233548, 0.16173378594460028, 0.14643845749237847, 0.15405372386017155, 0.10837685752419696, 0.14616591405243645, 0.10453358593006289, 0.10935388775842805, 0.1134400015636798, 0.19334052058477558, 0.20593234007397007, 0.09752886865528361, 0.1388819347466192, 0.1384794627947192, 0.29773860088279175, 0.17070996154460216, 0.11255921495537605, 0.1302440329304626, 0.19023522914898014, 0.20601552190078845, 0.11549406714977757, 0.15327245207323184, 0.08069557272979329, 0.1545663286120661, 0.1421931046511858, 0.06948677177030234, 0.19506503046760637, 0.1601239287805173, 0.17824229123371263, 0.24397697119462877, 0.19905188992138834, 0.20788505222768555, 0.11991030356336026, 0.15921819834939896, 0.21793197359769576, 0.1456811949009857, 0.23717355884371266, 0.30917859185607205, 0.18954826278551934, 0.1319873885762307, 0.20156583808843168, 0.09490642711640367, 0.2152371367499713, 0.17552733691709657, 0.09652913157497683, 0.16061557336680352, 0.24087805361036332, 0.1590627284660455, 0.12900166814365696, 0.18545226644604437, 0.1682470348333159, 0.19999563363530945, 0.16263398522090527, 0.48897391185164457, 3.876733885657403, 23.720894475137037, 42.8020800313642, 54.316550685513405, 48.077091324713926, 35.33536203445927, 24.788581286707235, 22.052884986323697, 32.6160632025811, 36.19344718994633, 34.78812863749843, 23.13614360747799, 13.66044056031012, 5.442659768366045, 1.6970357635328848, 1.0874256491661072, 1.9116797490466026, 4.119415831181311, 10.024691704780826, 11.203336484970587, 8.036621222572943, 9.675538001521941, 11.530981871389574, 19.329340188733994, 10.238032360230724, 11.313855148130848, 6.612558643664084, 7.800206243991853, 2.3112058783731153, 1.8152019453625527, 1.6169652342796328, 0.40967547665199927, 0.5192190324587207, 0.6065802059827313, 0.255719413680415, 0.8001221464045587, 0.20806433212372566, 0.5824975272820843, 0.4709643492054555, 0.6744741047582319, 0.201991384608611, 0.3324335585198095, 0.40263509798434477, 0.39404385092277683, 1.0683981088861343, 1.5021129649493004, 0.9098837308345303, 6.54569007696644, 2.0490355140739873, 1.8274461141517087, 5.645539462566377, 7.620751925053136, 11.467509096668614, 11.633065477494272, 9.963433108022137, 10.509852613172225, 14.825721825322798, 12.240802414955633, 13.398752770116253, 3.281511025082681, 5.119252502918243, 9.013842978785116, 2.8509502449343285, 1.0499660334279461, 1.6417350019178085, 1.5792955265891169, 6.139394794740985, 10.925889592016897, 22.112181417403683, 24.0978636664729, 32.99876297673872, 36.08946123430806, 22.67392562281701, 25.94874385864504, 36.405494443831905, 39.182689420638546, 42.67610134616975, 29.729704741508733, 11.904509182899229, 1.1460796695563102, 0.10238991870034127, 0.07645269435259604, 0.1434498872127264, 0.13010938531689106, 0.1535805113493435, 0.10122974748693167, 0.14483952474209572, 0.15569820819843203, 0.2538052204275324, 0.16926024740021076, 0.15382437245740047, 0.2597359820239006, 0.13912536684543858, 0.09096546399016535, 0.12797920123463677, 0.21576432781594418, 0.1806315356084416, 0.14599683844754774, 0.14977257939115649, 0.12753866237377928, 0.18497969744907272, 0.14708195602701557, 0.1560430703384261, 0.21310157473048857, 0.1453757403238166, 0.20147792183824126, 0.20575978642990514, 0.12109174137754787, 0.10803148210529359, 0.06153347293636011, 0.17310299039367708, 0.1883360052541379, 0.09089043333886132, 0.1794256519285902, 0.1534965021475669, 0.12005843432439912, 0.18822472332225693, 0.25368281489899086, 0.1684738121806614, 0.10855757766553473, 0.06790447078885571, 0.24708477539881585, 0.22328366465385885], [0.034360391718726006, 0.0897979996197166, 0.04232464944042506, 0.057630634175673615, 0.04732221635358949, 0.047771615021291285, 0.015068300211081102, 0.04234467880920537, 0.027560062871705142, 0.01801907937342842, 0.05296937220038907, 0.06218570870377364, 0.0173836515750736, 0.006949963055611138, 0.026415335990849043, 0.03153216364162584, 0.034671599616206465, 0.05242884354365449, 0.04691608633185106, 0.0511712221158368, 0.06479994544098455, 0.053279082395977555, 0.029838687980607636, 0.022595031712684902, 0.05339858445128607, 0.05724074138749031, 0.006517480566887366, 0.042710550910522865, 0.004421767089591032, 0.03935291777334867, 0.030066857692755522, 0.12173979047445521, 0.05618835491458735, 0.02487017112153192, 0.07397667519868383, 0.01430176699819464, 0.07238348810783318, 0.07416377685243085, 0.019667949565055392, 0.05892530361550951, 0.02034965290447637, 0.0746068514643177, 0.059477752600345886, 0.030185430866455844, 0.060391867863795454, 0.05343719911310942, 0.05003698680910373, 0.040491278463554, 0.12419148633677153, 0.02052915496601453, 0.07282916741866259, 0.0184878773025928, 0.0705642514531651, 0.02606103564762781, 0.8348003113942762, 6.581705770184917, 24.356940138724543, 38.214817124028365, 40.26434967594762, 29.012101234928256, 17.119114014410204, 15.539336281438029, 16.92251109307812, 24.589705351860296, 22.623352543000255, 21.171736294223418, 23.12970699802522, 13.944213255759209, 6.1924580893208905, 1.4833832796542876, 0.6102961614247292, 0.1326918983531575, 1.2104829040265854, 2.1620236769799264, 2.5023473895365194, 1.2209734056265125, 4.06669942121352, 2.072227385736281, 3.225444910987731, 4.954373221243582, 2.1064503106378742, 1.7589896004046164, 1.1769960364026408, 1.0926339438846036, 0.6393187589222386, 0.9012556809090799, 0.6196399826195933, 1.516025979672709, 0.42673220978148524, 0.2812729199086466, 0.19445062795233345, 0.14309164917757436, 0.03410096753448729, 0.03708512897813513, 0.44909952568911743, 0.7049259158872789, 0.8175038233880074, 1.3479785260654267, 1.2872326566327004, 1.3826170996312173, 3.338196383368585, 1.827509730092941, 2.6619562314402674, 1.925174663624456, 2.907808677804086, 3.9579828419993004, 3.8438546176879638, 4.73336237092172, 5.459998605712768, 4.110154379760066, 1.8935376838330302, 4.596101968519149, 1.1019152523048463, 0.6626104058757906, 0.38697831392768894, 0.8976130860467112, 1.8118300553291076, 6.058359117277208, 11.18321962894932, 29.043652780594368, 23.658919065229355, 18.469023204618885, 17.416563034057617, 15.063834209595958, 16.99635559512723, 19.897452362122078, 29.228133616908906, 30.7249669490322, 31.30528553839653, 14.796128522965217, 3.5975660527906115, 0.27472001830897025, 0.2009454141220739, 0.032892092281291564, 0.0033203548199737505, 0.10503597872992677, 0.006808625579240822, 0.026220914366985523, 0.035084628259703037, 0.04910100739629519, 0.06093336562175424, 0.012413034677475452, 0.05337025451984617, 0.010008655278192414, 0.0841632237537734, 0.0306292753967066, 0.029170044525075826, 0.0408742266647037, 0.07884583045398036, 0.05037955068532498, 0.003765138286736704, 0.01266713455064042, 0.05389976683222959, 0.054341343742224484, 0.04624797722264644, 0.017719018055246245, 0.06392697675994809, 0.05615583065176203, 0.016351440027656577, 0.05067759336182668, 0.021274707903484666, 0.0576743011873576, 0.005226278153713793, 0.06424059783439003, 0.01057046968790312, 0.043789432534287055, 0.04220543849852778, 0.020012415254548676, 0.033364155660233194, 0.013957633599338513, 0.02671564628760661, 0.007780873509604605, 0.0639279267089742, 0.07827242130353566, 0.033024790201095805, 0.03852170471462511, 0.10182994673208845, 0.10362171147379184, 0.07488657314811023, 0.01771810832583616, 0.029258592797803785, 0.026052014962319407, 0.045151900755421776, 0.021585643839752002, 0.03060066009751491, 0.06831825785939732, 0.044881586631339405, 0.03354232089834348, 0.03720910498692143, 0.0628279623455338, 0.06751106165709995, 0.047661133651291175, 0.024067286079028444, 0.07122872547516901, 0.03080157048609709, 0.015474788378924133, 0.048124019296899925, 0.06746303560512681, 0.062496472270258015, 0.04233537850180461, 0.03706754726027289, 0.020543969191250303, 0.021005640587499066, 0.0533232971605274, 0.04177293589999599, 0.018577777720507116, 0.02856296964079863, 0.030911032959157904, 0.09809625635464346, 0.0841770746234444, 0.03599955557635234, 0.07830545501483065, 0.05386271882021139, 0.13029677042317006, 0.05400025841569709, 0.022459393930471232, 0.0055913975736456775, 0.0763747985324552, 0.024513216283653053, 0.03761785119892128, 0.04186295123109895, 0.05246070897086494, 0.05859448386716747, 0.0009695651862139424, 0.06188355213511856, 0.06517794088370378, 0.034732840684873444, 0.024737193579635313, 0.058901765564035986, 0.10426764616802817, 2.179072504082034, 12.437628911387536, 33.06088547552786, 43.517477204722745, 40.6336800513729, 27.17336077843943, 14.6514009083471, 14.84914621999187, 23.47346155874191, 30.868880671839563, 29.792611714332338, 30.68560008079775, 31.472137281971595, 17.26795227296891, 8.201029329530655, 1.3328701690320046, 0.5399414656623718, 0.0802344873908066, 0.3021140354535272, 0.6188728528157358, 0.4995272939483966, 1.1036973566778245, 2.0108931607777074, 2.402474284172058, 2.385225171043027, 2.5226333977714663, 2.8963597695673666, 2.477361401242595, 2.552248763461267, 1.8076321386521863, 2.09070346528484, 0.9846977324735735, 1.994686540096037, 1.7341068194758509, 1.3940201651665474, 1.5150284719082618, 0.8778054843987189, 0.3865383036674992, 0.47088915001480813, 0.42165693857016107, 0.7750898864000075, 2.63630687229095, 1.668241398949777, 2.3459132159909895, 2.6321545531672816, 2.7966967561552605, 4.73827023659983, 3.764496488917259, 5.80935578192434, 3.938873789964184, 5.2239498784465175, 3.7338434111687446, 3.672544364967654, 3.947210787765442, 3.138583778373657, 1.6878701650327252, 1.4212584519578566, 0.4671484039675805, 0.054257824836719426, 0.16789317882109075, 0.2882923077671759, 0.4063524936716403, 1.3518404672222755, 6.849290353636588, 13.5869873146857, 22.068235181993057, 31.24887989413354, 28.170421392686908, 20.349899722683816, 19.60777944134128, 20.910692753330355, 18.854917749281853, 30.574340089674923, 35.015488824536725, 35.70799112319946, 23.317702278014153, 8.00417390561873, 0.707193781291285, 0.07430191016605786, 0.03692320097357996, 0.05797516306742065, 0.04672934856986807, 0.04531955143677131, 0.022231865816959934, 0.017592286045152335, 0.021270465691603964, 0.02461145939906278, 0.025711153716509862, 0.03713325845197805, 0.013984606597542524, 0.0017573232241463099, 0.006241839737706488, 0.0588579185216898, 0.023556765086287935, 0.03895532963196597, 0.03578180657519448, 0.040550389807791486, 0.021158829444058, 0.11308531051561718, 0.0876304227858782, 0.09604589097321996, 0.05399139094797354, 0.017509657716859254, 0.0548971635139277, 0.009519523460297816, 0.03249574137190658, 0.036966144032175505, 0.042294917568083734, 0.06046270801415367, 0.054099834524095065, 0.07349656023565801, 0.030571656008701653, 0.13225279207671845, 0.04046279914496888, 0.0628923213920526, 0.02413239780693285, 0.012872907682321967, 0.014909458583250884, 0.006948765564424497, 0.06557945522569841, 0.04806858900513861, 0.029602340279868054, 0.18521821126341823, 0.12501473208108257, 0.14735135850646805, 0.20969219235402925, 0.11398430703388107, 0.1383683187586646, 0.16158807602140213, 0.117651516301257, 0.09510583980309387, 0.12523246959092157, 0.20485019491564846, 0.1980110522239439, 0.18109060613618744, 0.08354105310694826, 0.1817537624869616, 0.09921168037239583, 0.15381220698116288, 0.12835654550262038, 0.21355175863831274, 0.1339013213592191, 0.18308438060264434, 0.3329716893213411, 0.27631737291812897, 0.1873513677668187, 0.16587640639514695, 0.14904597563849342, 0.08958918703419548, 0.11796081663980601, 0.1274047731872528, 0.11899344187470214, 0.07922226307733406, 0.18595324198324836, 0.19364815085164963, 0.1523559810894151, 0.1863848099545125, 0.14322281875196965, 0.20267891787713577, 0.24028159287427706, 0.15253340705267845, 0.27233334798966685, 0.10066027602841777, 0.1358630580286826, 0.30452546573454337, 0.14164426394047278, 0.09779024253328962, 0.1795123424381018, 0.14234921804839565, 0.10357899441113395, 0.1577321409938797, 0.15637117047463694, 0.2229219179360136, 0.16434776987279617, 0.09360652912648455, 0.1210879339205642, 1.8226197602287417, 11.903354044883482, 33.936531082276375, 51.55058937688028, 53.01340595368416, 41.55912014745897, 27.511737769649876, 23.95997274306513, 26.44394309289994, 34.73261925481981, 31.347064664286954, 29.018104422476988, 31.90073467070057, 17.94158797110281, 9.552654066393453, 2.4094838048181226, 1.0480897921708323, 0.5878176095504916, 3.3445616547138464, 5.55870456080283, 8.871592340930816, 5.108657200490275, 11.5911373015373, 9.294181639148343, 12.668177985375928, 12.697027017993312, 5.915499041157385, 7.892709951246939, 5.015399907865833, 3.844805057010343, 2.6809294714081675, 2.337286698241388, 2.401008788616427, 4.1924385966793185, 2.8533735342564124, 1.7194333552352845, 0.9818701325885713, 0.37775777160160007, 0.4456294231837796, 0.29921644577576273, 1.347424246130451, 3.6990939080715184, 2.72508236669725, 4.650685181540828, 5.012223278322528, 5.153704641326781, 10.55350467081993, 7.854277587706044, 7.056966125965119, 7.501037265023879, 10.231998774313158, 8.749619376274849, 12.839679698790274, 11.882514492157968, 15.309259853055401, 10.533985976249943, 7.32366523435039, 10.41519699558135, 3.460391942531832, 2.08492802035424, 1.3587059633385752, 1.2538111209869385, 2.5565579773918277, 8.194207837504726, 14.757093095010328, 35.00546324637629, 30.43995772638629, 25.734725613747877, 26.76476747758927, 23.296421458644254, 26.490666366392567, 29.015448977870328, 43.755604297884055, 43.57444570910546, 41.665577196305804, 22.70673821049352, 6.478116464230323, 0.432388236926448, 0.22689742396675774, 0.19026575009188346, 0.0736390755722119, 0.22324620295436154, 0.2452926965610635, 0.1706692669540644, 0.13372155116690745, 0.1655644860358969, 0.11597842623990391, 0.10801988353411998, 0.21018621181288075, 0.14970946906795427, 0.15711242182841226, 0.0767663537314342, 0.1836084919951616, 0.12137857235727773, 0.08793828287912954, 0.08977886274336808, 0.11016046342950676, 0.14539901407495623, 0.2406717461323546, 0.23349105080048885, 0.18545435020519843, 0.1362356219080187, 0.12720116233873752, 0.25937880119008405, 0.10130591194836364, 0.1591389388927529, 0.1726935930069416, 0.2513716502055045, 0.100482237194815, 0.13687266998233336, 0.17348255631664108, 0.1254466524527919, 0.2530023602828864, 0.1439663683695178, 0.15976656408559892, 0.10993015441683032, 0.16262784119575255, 0.10934926824824465, 0.1494951176667406, 0.20406827961485233, 0.15238222726170095, 0.1348981090010174], [0.024154667982891686, 0.020298514620310838, 0.03316399603781681, 0.033800963672899434, 0.0489557188214554, 0.06648151609565943, 0.025597387744534402, 0.05189959936204457, 0.012655843372246432, 0.019919632430819255, 0.04832583749967237, 0.044674474761010184, 0.04154001835793738, 0.05611432400802451, 0.02653277726964124, 0.09277607449480603, 0.07096903699059641, 0.03849178132030272, 0.023449286780951005, 0.03077849400259795, 0.04020576515505391, 0.05452080749936643, 0.019664325969173543, 0.04885927601266773, 0.0765463792448563, 0.015603913456171513, 0.010271100721682512, 0.03392252267428464, 0.026518284801333666, 0.06013667631533839, 0.047176226808298985, 0.0484068283150273, 0.11215733289117776, 0.05012936935189271, 0.04029565408164936, 0.03800752182160655, 0.0586003597615467, 0.014392598212936954, 0.032957707712006186, 0.037658331284840266, 0.08747114544554103, 0.02533347045461978, 0.05100794196609528, 0.033589657471184774, 0.03802384715527296, 0.07149261212156666, 0.10635649980676752, 0.06468067321205331, 0.06612725405683441, 0.07881177018486685, 0.01741328577120458, 0.029001679466736895, 0.052163114455798944, 0.027163085685442054, 0.0789411394526401, 0.1971482073948268, 3.6138541852274253, 19.001808551050004, 30.121716222455426, 43.908663026748165, 38.60852110770441, 31.374121173735592, 29.10058794483062, 21.809090068263394, 25.83182388736356, 23.934318480953095, 18.61155821431068, 24.69025923359779, 23.37001689018742, 22.268658491872973, 13.342401058443132, 5.8386995234797086, 1.8869786228864425, 0.2734006003987405, 0.20314019473810352, 0.4879799893786831, 1.1734093966022616, 2.0076556119226643, 0.9344571961029884, 2.1502639209070513, 2.6797696755778406, 2.1942192267987037, 2.1768213087512605, 1.6058970410977642, 1.5744216139278107, 0.8935815636669436, 1.2236500555469145, 0.22038203003185414, 1.7913759980470905, 0.9250110868484744, 0.6978275290419979, 0.6010051083660896, 0.5722676181504803, 0.8189876437667878, 0.8098341800993489, 2.8122960223305613, 1.606852260808791, 1.7312895770995849, 1.303068490759019, 2.978789604479267, 2.1377174844664912, 1.7535286805322094, 6.155704500213747, 2.827629057630416, 3.5814218223094945, 4.742029338113723, 1.57236089869853, 3.7257709282059825, 3.8599326581724234, 2.396214916821449, 0.6631686694679723, 0.29610095004881587, 0.7363409753287993, 1.7020946404626294, 5.950607195977242, 10.162951330984793, 20.471485353285267, 17.477142080183953, 28.496029107801377, 67.11217726430586, 31.295348213564967, 24.445938717934396, 17.520052809869092, 15.947954097101766, 25.72121697087442, 23.47408521559931, 33.17756029867357, 32.032190945840654, 12.777626822071692, 2.0682449542707015, 0.1089294980310144, 0.0201654240804454, 0.049317296999957294, 0.05483807898276756, 0.02499308992898272, 0.03708580696594812, 0.02494774326952475, 0.014756183541800468, 0.05557918861027687, 0.034649371575083465, 0.04091659132691641, 0.03195533528923988, 0.10456845059149689, 0.047727342800147114, 0.042928571872893846, 0.012604687851102603, 0.02227607675107016, 0.05191774032409153, 0.036251380168382204, 0.027126644798103842, 0.04572975704626692, 0.012404681446271078, 0.032297577408532945, 0.023985239977557814, 0.09625474952401654, 0.05781441483826888, 0.040675327256922765, 0.01987855862675896, 0.0282300929463799, 0.025349131207011884, 0.12095682563320284, 0.0605406383082511, 0.0535953886085941, 0.03183692299400366, 0.012688283365400089, 0.12368557719333519, 0.025502647566158446, 0.014313629869702122, 0.028475039984069528, 0.026229818223885475, 0.07996419624936196, 0.05493991122010255, 0.024664208383089112, 0.018798552768965884, 0.12677106525628798, 0.05458029805712643, 0.033108232497808435, 0.011721078208797883, 0.03148873986285781, 0.058415100549257575, 0.04776093192518719, 0.02869432307629576, 0.04262690943094992, 0.09476549758185303, 0.03654491441744951, 0.012112583612061798, 0.06317984568135393, 0.033494440403075955, 0.005083368281878892, 0.08366788662369214, 0.02707075868402758, 0.022752646642226367, 0.03522224063354154, 0.04411428062725933, 0.0677029820038907, 0.022096180154250997, 0.028668172665000446, 0.04598945702215837, 0.08652839764592149, 0.01716658630738816, 0.08660782564191088, 0.05610060720374027, 0.05888602628763165, 0.032134887146493124, 0.041015431990907084, 0.0270654822534491, 0.031619214212461826, 0.07024553589402668, 0.057606188310009826, 0.008681701935617434, 0.03244620229628298, 0.03275929093961755, 0.09810224716221133, 0.09984178769011652, 0.0263641957914637, 0.017353641995859724, 0.12567169844142853, 0.04703690988882896, 0.05100659365134855, 0.013493525085880632, 0.06974571714958838, 0.1001731513608848, 0.018792456624308423, 0.05268481650179433, 0.058684552824425126, 0.027196776317132097, 0.05504407236472734, 0.02458146514160739, 0.07682606262425262, 0.022423640607045065, 0.05337342995429232, 0.7040002365266124, 7.73981596193006, 28.295925471090502, 38.49387414993779, 48.05087812485234, 37.725721097761586, 26.60167728700946, 20.975407938803396, 24.946093866902014, 21.071135344043856, 22.394574419144664, 30.077971989108672, 36.3606813646132, 32.153933471249, 24.28137371616979, 13.751223817948373, 5.93434504924282, 1.4911661200946378, 0.17233719358280783, 0.23797065800716802, 0.45272603270507633, 0.1769270868070664, 0.6303386149867889, 0.45893021108162024, 0.42217343504871097, 0.4548722739902235, 1.7372938678149255, 1.2289415780575046, 1.320355234126891, 0.9603006512888017, 1.6503758608333527, 1.8747280802457564, 1.931204082023713, 1.3724086409614933, 2.7176288827773067, 2.016095939663149, 1.2249870934794027, 1.4024195531683585, 1.2102957334249251, 1.255219497026936, 2.6967756017561886, 2.087936968572678, 3.2839058772210157, 2.9837376744516435, 3.743119326330001, 3.471673904888092, 3.139372419926428, 3.952784475780303, 1.6494869536930516, 2.661087916743371, 1.5180683087918068, 1.2374490763871901, 0.9744853514336771, 0.32954739887387524, 0.332201985462058, 0.13227962047582673, 0.26863262237560365, 0.2773880267575864, 1.2813619716513542, 5.226000297454096, 10.250415282864726, 21.626623369032338, 30.42341316899946, 35.35535827759774, 66.19905733293103, 33.475742801543205, 18.464388924260295, 17.869137871649958, 18.058913907697125, 24.67364211236277, 27.246569856520626, 37.459207811663234, 37.21970788894161, 20.115134100760184, 4.394231794341918, 0.3906893357634545, 0.05207256669358862, 0.011524754771662336, 0.02299728149908685, 0.07104844966482732, 0.06214957233638533, 0.02248413282476606, 0.030535709248074604, 0.08734174553425082, 0.033870049481911045, 0.04393849409215393, 0.05292819114401937, 0.047848622179439956, 0.031896913424134254, 0.040521312940625415, 0.026520636691261205, 0.014483563493066018, 0.0023331095214797967, 0.08661894923857144, 0.043549624031349536, 0.07395871809773868, 0.05742544135559471, 0.04264255294636373, 0.0774946122340137, 0.020443433557727167, 0.06401094765732847, 0.10270584569943529, 0.01750731923347039, 0.037734296563411915, 0.050432820609139825, 0.05688475565083566, 0.009980641358021286, 0.025475732982158664, 0.043066720508279345, 0.05778146922708519, 0.007800685979741356, 0.027022537279633746, 0.12832617011642264, 0.014664886928644153, 0.06449467472491727, 0.04436519357465929, 0.01164924884740744, 0.06421623240795828, 0.02882641770185963, 0.06390618513368311, 0.030123781855969183, 0.12702054944970917, 0.1042714459641326, 0.14469798233720566, 0.19737919822575586, 0.10870130342100898, 0.16307566555276995, 0.12242648104626326, 0.24581855463404811, 0.1100020977337995, 0.09982872589100754, 0.23408938079111039, 0.16143665108228886, 0.10398882080710704, 0.2902584264595663, 0.11083328780988533, 0.22302111100044944, 0.20794689084493345, 0.14572403453771146, 0.18384066260149404, 0.3234385831221458, 0.12341680290598063, 0.28763733323543306, 0.24085182275983597, 0.08626372192896183, 0.2064722328777275, 0.144225413340234, 0.15322415789048519, 0.14302146020195178, 0.18640316542117827, 0.0806701232889487, 0.20292645620722927, 0.18020978888436673, 0.13650701621607428, 0.16831299500359645, 0.12153599576483812, 0.14044228730903519, 0.2863013371825218, 0.191247369192781, 0.16762325540184977, 0.10369638206377145, 0.28367586193546174, 0.11274119914178887, 0.21913934348812028, 0.0952269736256811, 0.18253371660267154, 0.21093857144155811, 0.20601752905115006, 0.14454022951183781, 0.0992363024382822, 0.1866726291876647, 0.1296640890500238, 0.1814915305904804, 0.23047139267286948, 0.10474468911847762, 0.1977156180768244, 0.420314384804618, 6.6030351288857005, 26.769125230850715, 44.27888378020256, 58.3784984004113, 51.150468395602324, 43.133014325172674, 38.398321290169996, 33.63807793586485, 34.088691588371034, 33.70778629856725, 26.51344160879812, 32.894998635015185, 30.433972189503333, 29.223824893274617, 18.13340952319484, 7.219254682140966, 2.7617366708094075, 0.5145113915205002, 0.9019781324651934, 2.7765384700990494, 4.40400634081133, 4.579824132304038, 4.276977441003246, 9.659646518768804, 8.714589668858437, 7.272116955249541, 6.837863018435817, 6.2072699396841, 5.208853165949545, 4.9450144460124354, 5.431049062359718, 3.221801764542057, 9.675588992334182, 5.28298351072496, 3.5301684564159768, 2.1902044357792025, 2.7216260231310323, 2.5362476994914394, 2.901242384987493, 7.342113612159607, 7.366710305213929, 7.296770522671362, 5.172211854688583, 9.704109526449635, 6.206635496308727, 7.066147413945968, 12.59591615969135, 11.894081561796128, 12.078041703470292, 11.31367373851038, 5.2828702522862345, 7.719203906674539, 8.423053622245789, 5.281153725039575, 2.0768511247250343, 0.6318737326129791, 1.1658987931666838, 1.9736136063452692, 8.215226348369352, 13.454506320338096, 27.26996091104323, 24.653065358438802, 34.98123476582189, 73.27092601406959, 37.556710089406664, 33.129558332504764, 27.47562646865845, 25.263954900926162, 37.870805648065385, 36.74233190474972, 45.69212944276872, 40.48483002570368, 19.325168748055738, 3.671292393438278, 0.3172709931048655, 0.12061582457634712, 0.09930918038251901, 0.15000923927272522, 0.16287701895400403, 0.10259684670956866, 0.1371683033123132, 0.05762223019114426, 0.21491289769689884, 0.18919693486344433, 0.11078890067555251, 0.1383706783094714, 0.18713983556916639, 0.25038145091985503, 0.12303316905613869, 0.13631699576733575, 0.12922015641966175, 0.15383351954721636, 0.21513604378748327, 0.15927286638367563, 0.18067644368256294, 0.26406781086998604, 0.11612058917601263, 0.1688874536944974, 0.19914912180073802, 0.16533688131359317, 0.29305247169348503, 0.12411091686977495, 0.10815024105531555, 0.09171829093247653, 0.14396312015671886, 0.16291509352384076, 0.14078932513873424, 0.08345382633588969, 0.19048595440483865, 0.20178752861195998, 0.14503847777603135, 0.2286621075003378, 0.09512107729190782, 0.20905630873335948, 0.20435913255618465, 0.18407421216609018, 0.11239602290574582, 0.17609893043916072, 0.20952308610562356, 0.12307295200204658], [0.02754992178280748, 0.04544551161328151, 0.08176414281009667, 0.04413660059893324, 0.14869078663328003, 0.0331143650316423, 0.06916660064410779, 0.05692602863775627, 0.07349617719169586, 0.04904093461171274, 0.05150598338654926, 0.017523207897019964, 0.03483525514903088, 0.027678446438644203, 0.0389040591976335, 0.0674493226312822, 0.061657326371078534, 0.02499748727366809, 0.007756132221285014, 0.06836063784336852, 0.0293205559043394, 0.12221906274076431, 0.01218354825170771, 0.02924478980862806, 0.03863382551278319, 0.02592971094042784, 0.05898191751311383, 0.03797223198137457, 0.03569810763902722, 0.049626126194432865, 0.011766068637371065, 0.09312675124214542, 0.024032329487043525, 0.0419809211105589, 0.06548695010884155, 0.04533976849709307, 0.021242480499729998, 0.08508522589240344, 0.008015256673623359, 0.04853288042208841, 0.04411902271151062, 0.08137038893877499, 0.017356181577328714, 0.020617760695336808, 0.019747595896103212, 0.02446420580869721, 0.07581214525646741, 0.04365779564625794, 0.06577010386653485, 0.021008609178205653, 0.02114058122970164, 0.031979516854569796, 0.021998149628240257, 0.003303027108138908, 0.08707325469942824, 0.034707816422826825, 0.046529403452070496, 0.9693094162691025, 6.661156319802807, 24.93549562269642, 38.9549683755444, 40.334956261419485, 41.38738309183429, 33.64873893799321, 30.983074595851285, 24.955236911773685, 25.97997965351228, 21.803820363936886, 24.757296462212842, 23.455075448559178, 26.053029875601492, 26.32700743213777, 22.74842712186998, 15.065371778703506, 5.989570060083944, 2.1172963996087355, 0.5780136453047876, 0.27781875203213385, 0.1716488022958079, 0.12816233455293602, 0.3213218209003249, 0.6036871515454785, 1.3696724200440993, 1.1483618761262586, 0.9958334639668466, 0.9715067402970408, 1.43583704386988, 1.5960032300603006, 0.7113890626257466, 2.2806687556928207, 1.3068209732732465, 1.0027810847086291, 1.2950145164805076, 2.2525774759631005, 0.47635080533162244, 1.8070302999788717, 0.6813202954588399, 2.2572732885037703, 2.9448802240433234, 2.02555350959301, 4.053628367762412, 4.043331410615675, 4.5879267684875, 1.277966669970943, 1.9316487807419993, 1.0764439932761656, 0.329451852387959, 0.20506048605086344, 0.21134951632590065, 0.9981639034325077, 2.9512891317567522, 7.712962435137841, 14.900068390753963, 25.535186798341815, 26.399163353827696, 30.6407222824712, 23.650874284005937, 19.43106685915301, 36.375719731853856, 56.67960613004623, 31.826152763059063, 26.040531243047408, 33.11636740161527, 36.862266217508626, 37.9455699459199, 29.646497541858306, 15.833126710307216, 5.436199134395969, 0.4396359189864128, 0.1469221194424937, 0.04353744323335348, 0.012987623603323535, 0.11320072932228928, 0.04912918794058985, 0.018310669674387863, 0.061906396877020604, 0.10623780980465874, 0.004258613823161971, 0.07486606497437724, 0.005363965699929865, 0.13092123933376806, 0.0512432228894003, 0.08650717701041892, 0.02918769902129087, 0.027251314116461624, 0.03528344722825193, 0.0505214608124187, 0.013588887710695066, 0.0656974863921923, 0.016204766748893647, 0.10843514149347622, 0.05455653017927563, 0.02495023114005885, 0.0210068280237817, 0.033544029274414626, 0.030828684252957185, 0.018558108413051215, 0.10212865207464465, 0.056951363165412223, 0.05516739336833839, 0.0910638909666769, 0.028549103449369152, 0.006182736054348249, 0.035616231992119746, 0.051703151435621326, 0.028399204940445004, 0.07894345303817142, 0.020806356220536178, 0.075467083933613, 0.006559491392240049, 0.02729311378883018, 0.014870149654246148, 0.012850888400158335, 0.01208519405354896, 0.06416506156505597, 0.023543795217729868, 0.017660684290251905, 0.021402575638926318, 0.018726741602163643, 0.02449558477007574, 0.06327532704979663, 0.01979801405761992, 0.05851887098904099, 0.025458725830239635, 0.04591072616618007, 0.015727505463385777, 0.04839846263489416, 0.030241016291021824, 0.016759818517452767, 0.011628398806938242, 0.027165565895096912, 0.04101930839580394, 0.07343089117878869, 0.05205112006214838, 0.013934966972878864, 0.050997519339885444, 0.04429628013543064, 0.16618952185155886, 0.03747669566843299, 0.03462429751732177, 0.04722825183923687, 0.029800410397470962, 0.061883111634562095, 0.017944747777355295, 0.03176832365082397, 0.06410890348976658, 0.030548853401635444, 0.06154761874988195, 0.02510486215713524, 0.01592341904348183, 0.074975730460738, 0.022741814158977042, 0.046798185400304296, 0.0455589960479448, 0.02015143148450842, 0.01641288410962349, 0.06269451365956376, 0.07053034440163644, 0.025805386361635985, 0.05551835356820976, 0.026315669867119966, 0.03293398579943084, 0.04310766024695289, 0.03914990830385397, 0.03214028040548006, 0.03236104779305958, 0.045398136736044, 0.018175173618440187, 0.04880571497544166, 0.027791894484131087, 0.04047015741948159, 0.02859678859221599, 0.03949072166916825, 3.0286252787036285, 13.429127604730668, 34.95575504918253, 44.772792554670765, 44.472562574571185, 42.155532221640314, 35.484772959063136, 27.931460795863984, 23.091456044104792, 19.1720845237855, 22.140402870793498, 28.370540718878473, 38.11527521379533, 36.004789029398275, 33.26598228946809, 24.112652963207616, 13.193768724318474, 5.80776329963438, 2.0579810921222936, 0.6171872755212169, 0.42820999338742227, 0.1099473684124889, 0.09926421868224299, 0.45702602293702865, 0.34343773739472516, 0.5834935641577167, 0.7470573809358382, 0.7253167862373014, 1.0478893835698406, 0.6293110152886761, 1.1262503722983024, 0.9502680864064925, 1.7540431238951224, 0.6688108763867809, 0.9244948048745433, 0.5534943577743346, 0.38585746600743265, 0.914131228721911, 1.0150508714779731, 0.6095836996551484, 1.3028843845090559, 0.8536680763767612, 0.6784439110948194, 1.2358346533390785, 0.5923758326999603, 0.41239950144963883, 0.7136653243534027, 0.1946290038646229, 0.7414931311242042, 0.23142895661294463, 0.051804750016139406, 0.332181791384374, 0.7772962809089692, 2.139097668470875, 5.14953222005598, 13.953650478393802, 23.935634436145907, 34.10347892392066, 37.55919294972574, 36.65398836135864, 22.657920391328876, 33.2136147252975, 66.65069472405219, 26.550351112119614, 17.53916848090387, 28.078251577192738, 34.015241284524244, 41.03796266740368, 34.201542100598736, 25.257698720501317, 11.696583359472214, 2.384473301710621, 0.2616322947846305, 0.03964745942803641, 0.02817756612785161, 0.022259805043558442, 0.04065484972670674, 0.052280283773378025, 0.046279547706006036, 0.06305096670985222, 0.05149061183234857, 0.011663361144582591, 0.03267630063478024, 0.04185853090377585, 0.052861365294384385, 0.026199747357637655, 0.02672539284122327, 0.046562326080616445, 0.0048819178013100985, 0.008937633716531338, 0.05856502778647889, 0.07651509221402869, 0.05722009914837057, 0.06561110997872968, 0.13066859885809884, 0.06516677898264701, 0.034944721452531316, 0.024480914186325767, 0.01436230805402081, 0.08148096606976564, 0.05679254164739002, 0.06690644208462009, 0.07893989072932352, 0.10500280712280544, 0.023580638301228325, 0.022110915855474533, 0.03858298025724869, 0.07000767325441684, 0.049644742130992875, 0.11008930918309959, 0.007399798393429768, 0.010987899506524687, 0.05326972846242209, 0.04373081914720036, 0.03729482256476918, 0.035632599460622, 0.015775822628770145, 0.01682680141511223, 0.03951831232576121, 0.10028133829755169, 0.13065871632387563, 0.1498360421148039, 0.17428748489868257, 0.22908091244678344, 0.09905177483996076, 0.17521854219657762, 0.1315613057945044, 0.17357349095325317, 0.1053166120583492, 0.14024454469401992, 0.09432213951743419, 0.12342472425511769, 0.138019181848053, 0.1452237944449148, 0.18606769551913585, 0.1640564266351923, 0.1378205046057701, 0.12003926680453363, 0.11842273701463016, 0.12181820723438457, 0.21639541572620793, 0.11413888059436314, 0.17517199469429834, 0.17608206118306807, 0.1714513967594793, 0.14105359482909405, 0.17917702575364422, 0.13439656655874946, 0.1768081593177011, 0.07654960447501752, 0.20759032288145637, 0.12220412402624085, 0.19323398839802514, 0.18625478951200364, 0.09099340321676386, 0.12920052924704167, 0.20755054759642771, 0.13130380832139524, 0.1616155632561253, 0.14469433575868607, 0.18499417651084163, 0.12605149419076983, 0.10361229625320244, 0.15928276423965732, 0.14527699159037682, 0.0966231382241653, 0.2074282186766786, 0.13980721574156516, 0.11364122987875055, 0.1033768161470371, 0.054123556436670404, 0.14225955511773788, 0.13545747575981004, 0.14411249198019505, 0.13634969239994404, 0.10632407130493272, 1.8897033218414554, 12.741083079768767, 36.48448313436201, 52.55354727468183, 55.227532925144324, 55.1658183528531, 46.67705620488813, 43.29835399504631, 36.493708549007295, 35.266826460438395, 32.10348590727776, 34.209135809252345, 34.5404270387465, 35.28798372514787, 35.929016682409475, 30.169355369383293, 20.783137275326638, 8.246631295450273, 2.6583062208467916, 0.9948092350556005, 0.9399387084188001, 0.7439764204525179, 0.9218243449445694, 2.053157189680684, 2.9435983444413836, 3.630400948947476, 3.999701906596461, 5.892892950965512, 4.283715092366742, 4.444821053935636, 3.9458965486095803, 3.4356795395574267, 7.114351382178645, 6.738376021385194, 3.509057034407893, 4.5675951626993, 6.302327109921364, 4.606998803154115, 6.754625420416556, 6.983656537148261, 7.4191053259757265, 10.784579342411412, 8.091567745131831, 11.144348940541668, 11.229454567355495, 9.722964359867959, 4.2000146546671475, 5.605181705567145, 3.4290176389678835, 2.0651200509840444, 0.9610816319623302, 0.8384815170880288, 1.8908556406536412, 4.166578900429511, 10.242908846947456, 19.62444559220345, 31.68156243139698, 34.219302592738984, 39.58730936050415, 31.813244242821973, 25.958439957711008, 42.54649839093609, 63.65340378976638, 37.776778590294626, 34.17320689847393, 42.79621216558641, 46.22879597448534, 49.83936125232328, 41.460700035095215, 25.530489760060465, 9.144291204790916, 1.502546509427409, 0.22531788856271776, 0.11259886766633681, 0.12461347054810294, 0.1829978739542346, 0.14587159839368638, 0.15791764152386498, 0.15269836110453452, 0.17045243342797603, 0.1606035764299093, 0.11619470818268678, 0.26871027304760875, 0.22631519714430456, 0.13268331816840556, 0.30134911198289166, 0.21143628344420465, 0.12684470928844907, 0.1069183257077971, 0.09482885305319103, 0.1355417301097224, 0.2300202434942607, 0.11478194245888342, 0.22745093781380887, 0.1939218281017196, 0.19968210449141843, 0.1535120537324298, 0.09981626930135874, 0.12883482951550715, 0.13658901826748926, 0.1684650787783246, 0.08889200871870404, 0.2707236133996518, 0.1685012840936261, 0.13246103009629634, 0.12926763854920864, 0.1255540196753798, 0.20240925492778902, 0.1110951749668006, 0.18383873205992485, 0.1200249256385911, 0.12552125409485834, 0.13144009536312473, 0.08350968180644898, 0.13013006969084664, 0.0932530484973423, 0.07388027069429237, 0.1427137226827683, 0.12391033972943984], [0.042904980195265625, 0.0338167067797434, 0.02965370264475144, 0.04632232605569786, 0.019113355534031026, 0.060207190878328785, 0.05759563927929248, 0.03875148129619418, 0.03401754822041239, 0.052159188255187006, 0.14325658790767193, 0.047799075442937114, 0.011772521970523222, 0.012739617001986312, 0.09689642476939386, 0.03309342401823209, 0.05128518152501314, 0.017899284289488872, 0.011933430120529187, 0.10226470162911762, 0.031425658267952745, 0.12192515310861411, 0.05093696008947107, 0.036503488212944045, 0.05536530452269701, 0.013603926016648692, 0.02989655443196816, 0.029300329267918587, 0.009497679420746863, 0.07056241284214682, 0.038278460307347204, 0.04928165092884053, 0.12746589934273114, 0.04023407210385607, 0.03542087191054898, 0.05805596236079451, 0.06442859964144808, 0.07106265293494349, 0.10346141523651539, 0.03479229676867685, 0.018409136870515444, 0.02411703965927084, 0.03749913055329554, 0.06790204995101498, 0.005114314403580201, 0.037544716615229845, 0.023536304793050213, 0.002796785913467888, 0.07294372820685949, 0.02599996120308436, 0.04911233400625568, 0.07648615707312861, 0.049939919638657765, 0.04208715835345849, 0.04995681187738815, 0.07435669311352315, 0.05076345649638003, 0.015342375826871684, 0.19344840108627276, 2.5218552975885333, 15.16936165671195, 29.7163059250001, 36.23903689845916, 39.146301592549975, 35.261370443528705, 33.98913398865731, 35.10816658696821, 27.86488836811435, 31.903860799727905, 26.382430522672593, 22.858869298811882, 29.189757147142966, 28.91489313494775, 25.233391792543475, 23.995889886733025, 24.403306476531494, 13.019489972822129, 8.170592227289754, 5.1491429248163785, 2.4752555787563324, 0.5838916847302068, 0.44277740041575125, 0.12027742821843394, 0.23074857860563264, 0.3461627427849078, 0.8842044636126488, 0.7812055969430555, 1.8900500838795018, 0.5398421193803511, 0.8843180284865442, 0.6453141630176575, 0.4843391718402986, 0.15336781469804628, 0.10661014385761754, 0.22568095295179277, 0.9565444302655036, 0.3456277069785903, 1.2683421541606228, 0.32558549856466634, 0.6297245801937196, 0.5477002202983826, 0.041214913625510476, 0.29838701770190273, 0.6801525323141007, 0.28514209293550064, 0.8478321411436605, 2.9261717440620547, 6.32549851171432, 11.023976302916004, 18.18834427864321, 24.579362061715898, 35.39922998797509, 31.799425732704904, 27.106386307747137, 23.219805802068404, 20.015549044455252, 14.492606693698516, 19.277292297732448, 30.82659556019691, 39.62603492121543, 29.774951242631484, 35.633411176743046, 34.22041654586792, 32.53581935359586, 18.440193783852365, 7.917650341987611, 1.5917680508667424, 0.09091507072650618, 0.03445902553897712, 0.016017519538441015, 0.029725201630724535, 0.024155357462023536, 0.010788618012391513, 0.023635020967753186, 0.0693624510219501, 0.11252249636116529, 0.0013668142139889121, 0.05950319438031124, 0.04720201715826989, 0.10060181585891594, 0.053143687846679846, 0.028648913214584033, 0.05223868902952922, 0.04266570795387511, 0.053266928411058845, 0.028037933197112817, 0.05312368146053726, 0.11336766754186924, 0.042317122626569004, 0.07071605943624051, 0.037306773536387956, 0.03522918905101476, 0.03288433564105823, 0.008345256229081463, 0.06041081321816291, 0.04705188307730902, 0.05094390084606506, 0.04329833570086668, 0.05284744547680021, 0.04829889801781505, 0.013661661275452184, 0.04334213677793742, 0.05865107861257369, 0.051874245682190505, 0.0057527648976012586, 0.03689560265610776, 0.034171244610221155, 0.013047545085540943, 0.05272540384002271, 0.021764186376165, 0.08415503427386285, 0.05407949488970542, 0.058284271883988575, 0.0508209552255369, 0.031174745320552782, 0.03318463444649693, 0.018950140501763073, 0.039131679241695715, 0.04841916999148746, 0.06641450638492262, 0.03337199273969858, 0.06857238454563964, 0.04583510562717434, 0.016649452060641303, 0.028101888132251562, 0.026905111322600036, 0.13714714396384456, 0.037306773536387956, 0.018613804920366215, 0.05161630004764565, 0.0391195061045789, 0.02893731467455866, 0.039514589138449206, 0.053201240201991414, 0.03365766692666277, 0.04087476675669032, 0.08149233481456196, 0.042139248501869946, 0.04363858982199623, 0.04194925486620876, 0.04063265615954034, 0.05168453549906131, 0.012871664704664821, 0.04046933004452337, 0.010948332980455411, 0.011156009840628794, 0.03619621417695477, 0.021857015165169875, 0.1225252987276162, 0.03394650888719386, 0.04947917137835776, 0.03527473680855286, 0.04315613829080136, 0.06578223103837622, 0.02998933917091739, 0.027573421529884783, 0.017332197279639302, 0.04963405520444916, 0.028186326343265754, 0.04546686631417082, 0.05123040623842709, 0.016575930602548104, 0.03441314070275234, 0.0017533380108239551, 0.06959263746055865, 0.004801127126425385, 0.013502222099041027, 0.0704516978153298, 0.021739910965064363, 0.08083811104898492, 0.08888254753283917, 0.056424172099439375, 0.04380392691781444, 0.03498036369320846, 0.5411944790713249, 5.89350680189748, 22.13048908018297, 39.78566754248835, 44.14951224480906, 45.76121414861372, 39.71725356194281, 33.17232001212336, 31.288591930943152, 24.70442879584528, 27.34823573020197, 24.632937715899562, 26.704608125071374, 36.89604566943261, 39.024445318406634, 38.99776535649454, 34.72960687452747, 24.34056620444021, 17.19992660707043, 10.530976537735233, 3.7297479664125754, 2.122194459361415, 0.5848716031159125, 0.050596617868230234, 0.06748663111319465, 0.15527109885888715, 0.18374854818947856, 0.0918869681716446, 0.17197271959195215, 0.15393962272472922, 0.1905609697343842, 0.14856148631341998, 0.5259227920924464, 0.5519901901002854, 0.3857447897955295, 0.18664613786724307, 0.28536931461384224, 0.7117426275245605, 0.19950426484067596, 0.6523250932655027, 0.06157586824208979, 0.22866572343534042, 0.32690169890561416, 0.18287644901823613, 0.2630335002416565, 0.2967649644180652, 0.15894456706460447, 0.36916961953524624, 2.800531363294971, 6.012495333148587, 9.990811251824903, 17.185555042759066, 25.607209359445882, 39.90149513367684, 42.40999990893949, 41.47944896451889, 30.978724687330185, 27.840791286960727, 17.077419219478486, 14.504483630580289, 29.512564289954405, 48.4462098921499, 28.624416128281627, 33.93355792568576, 43.92306204765074, 40.27142170936831, 26.536342367049187, 14.692489697087197, 3.296709719204134, 0.4579274019887371, 0.04571450040525487, 0.03171220962559024, 0.031083904529711416, 0.05936736316089669, 0.07662190019243187, 0.017656334826061805, 0.04232767165728635, 0.03592364392393539, 0.07400806182094159, 0.07850918077653454, 0.05718834863434877, 0.025390519107121135, 0.07833185440470135, 0.04443471222334812, 0.01816335479698835, 0.01705916162820593, 0.07530498738971449, 0.01935438786242758, 0.015322493930016796, 0.046442322237717534, 0.021300959821429946, 0.10779591772945658, 0.02866523854825045, 0.028992455768128558, 0.05341360743548121, 0.06077434492087173, 0.023655722578687054, 0.037426827175001946, 0.08847043819485173, 0.07242019138028545, 0.042373338158452706, 0.07904314405975804, 0.002719050014181243, 0.04960765198413884, 0.06265000012072344, 0.05004971535996564, 0.02001300322703056, 0.036894438202462854, 0.038321257809237126, 0.018771787572111336, 0.08437103276411373, 0.03451259423708243, 0.04358343532188766, 0.049874706404103394, 0.013772761261451149, 0.004061874783327503, 0.014754097867426614, 0.016230187461441083, 0.268800518205089, 0.17439083015966803, 0.13883630654984905, 0.1535856134949192, 0.09440177435716314, 0.15663422974607638, 0.14653852389704797, 0.1797208868928494, 0.14962363657691788, 0.06473102051043703, 0.31104643678953575, 0.1544502662915376, 0.09032044860143816, 0.17170817410993963, 0.18281674012541774, 0.1645778260764576, 0.20104883599185175, 0.09758794169512489, 0.06428231515230672, 0.20304706909002798, 0.19864354973598836, 0.17791330243550962, 0.1672458958121077, 0.16071730984314797, 0.15464120604578527, 0.12990732196598284, 0.11425644444722323, 0.122629854407522, 0.12682104483246803, 0.17739165784610858, 0.12176803613622343, 0.12972081019993753, 0.3897365368902684, 0.1305470513480325, 0.15989961823628795, 0.1504810268600141, 0.12813762055649874, 0.16605337270565573, 0.15311796278242143, 0.17756649443218786, 0.09946743116503763, 0.17347216816438785, 0.20764897457293927, 0.16904753542715506, 0.1366756321682084, 0.16072719237737118, 0.1631622794534891, 0.10007147617157429, 0.22175910371926524, 0.06079783700706978, 0.10298327678033423, 0.1661519988650276, 0.126987983052048, 0.1591150982365493, 0.2017159300345567, 0.21027086452851373, 0.14074607181452936, 0.1093136987859203, 0.6054325449851252, 4.761937818219585, 20.96284850951164, 40.53142778335079, 50.55097333846554, 54.803332513378514, 50.80905352869342, 47.260206745516875, 46.38754998483966, 36.74972557252453, 43.780354453671364, 35.286599128477036, 34.08518498943698, 41.34443313844743, 40.45800493609521, 37.550363694467855, 34.11577947678105, 33.5377593963377, 18.507574219857496, 11.748351781598984, 7.905087970918226, 3.6986384228352582, 1.059049384728555, 0.6334437225614825, 0.9142076536532372, 1.1256219350522565, 1.3288246119214644, 2.1409360343410127, 2.1083845294290975, 4.492423428643135, 2.3278982600858136, 3.004066828758486, 2.0343159619838964, 3.6853906175782605, 2.004452383806629, 2.21310691006722, 2.4922122301593905, 3.058042809847863, 2.0512156164453876, 3.9235946872541985, 2.3360553191554163, 2.930323818037587, 1.7275681058245322, 0.39915086881768325, 1.075971715392605, 1.4467809469469133, 0.6887849949059949, 1.729945797593363, 4.761982925476567, 9.009921589205343, 15.452069428659255, 23.775252642170077, 33.27268562009258, 44.603797235796534, 40.83955349460725, 35.07965880055582, 32.13800668716431, 27.438246280916278, 20.542686177838235, 27.45509089962129, 40.24452209472656, 48.53241182142689, 38.860764811115885, 48.65663720715431, 50.25472456409086, 44.5742186423271, 27.813226830574777, 12.514396559807563, 2.7403918677760712, 0.45584027204782734, 0.19024181750512895, 0.13510905897184727, 0.09834916496108617, 0.11779280589713205, 0.14421766053044027, 0.08409329524804508, 0.20374690573061668, 0.2463417926863317, 0.1115850039247063, 0.15156265107854722, 0.11985636331261167, 0.3071657111567836, 0.23796866617856488, 0.12596124137241033, 0.16384919985167443, 0.12732713017612696, 0.28307650538702167, 0.12491418304102075, 0.13335805776859486, 0.19222986163391223, 0.057503187788590315, 0.1635165031879179, 0.11375149291369224, 0.19748599088240057, 0.10072602169407953, 0.132761106736237, 0.18445040730218734, 0.1466707353510203, 0.12054495378247193, 0.13604731749623053, 0.13906168961717238, 0.149515985901798, 0.15935845372657623, 0.13527327757929603, 0.17077789822172734, 0.14394543884742644, 0.13331685756002704, 0.11112217190525225, 0.20237577688549796, 0.1082148605717286, 0.3441796782276323, 0.17433767897948144, 0.16397335206068334, 0.15938166619068192, 0.12376505115460004, 0.08612810138372645, 0.16326144187440797, 0.09119217238959768], [0.029706620168121114, 0.048867484644776395, 0.027991741925718325, 0.06276827643535311, 0.08729149016641802, 0.09255248407322554, 0.03528760325524115, 0.09329181254631089, 0.05232293188812272, 0.05489536703774526, 0.06802748152685743, 0.09654878173023464, 0.06309841053500291, 0.05070580071919868, 0.07331051578324649, 0.058192548176814476, 0.041226971849438646, 0.05516791813856652, 0.02932719214098348, 0.02047644045594479, 0.04066732546855365, 0.034693260752265496, 0.024533015826056083, 0.012893982761118923, 0.02153210386994385, 0.022146052478121656, 0.028426259335490967, 0.06698962391143845, 0.007438333573630981, 0.06506243014648076, 0.05362335847870958, 0.04495136574992249, 0.027722429461596955, 0.02429056623499961, 0.06867316341207874, 0.060665035665395765, 0.05615982963072677, 0.09869666244353979, 0.024569535237406532, 0.033718578577522314, 0.023795434033438086, 0.037894217417605465, 0.0166657563268898, 0.09883390709517464, 0.026542188659791025, 0.0499791395099413, 0.012999791952390826, 0.03355613346361826, 0.02394643953941282, 0.010081112831680766, 0.019613390698307948, 0.02994088027926703, 0.049799744700712543, 0.017521620179796894, 0.05754548733332946, 0.01302479706223934, 0.07288264035577736, 0.04029950367346887, 0.048791741531702786, 0.11119622962489245, 0.4619040724731261, 2.708855030998107, 13.790198449165592, 26.527962223176036, 36.6269475413907, 43.74809688137424, 37.281677415294034, 36.013790868943744, 29.823541564326135, 34.09964676826231, 33.89405573568037, 34.793219873982096, 34.14360869315363, 18.6143744760944, 19.361193756903372, 24.83788351858816, 23.39126240822577, 19.826906573387888, 24.618393567300615, 24.023642616887248, 17.942550912980114, 12.500561379617261, 6.8095395834215235, 4.761698553639074, 2.6766717385861183, 2.403347746979806, 0.8500091791633637, 0.71619794974404, 0.29104440202636106, 0.4498603735719958, 0.45544199825775245, 0.08830595911750871, 0.6604317743932048, 0.11614365608341272, 0.23483300701745097, 0.24293259417097418, 0.29626075598982077, 0.36414215221039714, 0.6807741054123448, 0.7232633028780261, 1.593914935665746, 3.300869392771875, 5.809333718592121, 7.1417991480519705, 12.726668369385505, 20.317697063569103, 22.373370085993123, 23.021765332068167, 27.00340840124315, 28.657501320685114, 26.08133173757984, 19.234344305530673, 29.01362115337003, 20.99991490764003, 18.137826112008867, 15.93893558748307, 21.76842881787208, 20.679576896852065, 33.58947584705968, 36.86799680033038, 39.7295815713944, 32.67824649810791, 16.23909398432701, 9.906948035763158, 2.6854951102887434, 0.07542038321374886, 0.02442967439551027, 0.01982314940241556, 0.033306584152723515, 0.004226186757742037, 0.038218467961996794, 0.0056543403151144665, 0.05320102952781224, 0.09036085973944395, 0.023644039737841776, 0.05850177573701067, 0.05347704334605125, 0.018934615729977528, 0.024761557090847243, 0.05076895700767637, 0.08432887494564058, 0.041930183107333804, 0.04106850656230123, 0.026266232298146334, 0.03386888885870576, 0.01431497531161914, 0.07892413230072107, 0.035478025900139924, 0.01419671527635787, 0.07201634047012176, 0.032273648652218045, 0.026856142982480027, 0.013840656761350411, 0.06604339041176342, 0.05090607525480371, 0.04106043582601894, 0.05264104606824056, 0.05560326675373701, 0.01635625297504087, 0.033311862498521805, 0.0626665629416464, 0.03833792405202985, 0.12643999269893094, 0.03288543114678995, 0.04281848120773512, 0.02029270001296555, 0.0608516738359486, 0.06245851644404954, 0.010367171020217, 0.047548671944006804, 0.010726255582525365, 0.057396375979747505, 0.12137075826045006, 0.03452884679239604, 0.01759085154551412, 0.06863600814775114, 0.03017646572252195, 0.04007140099401436, 0.04385929592254181, 0.025078257838744792, 0.04580892840280168, 0.024961793322056055, 0.031231050867767587, 0.018880121980703646, 0.060430716182435715, 0.030657369756109776, 0.07575222185903019, 0.019793932724203316, 0.010255273345166878, 0.05237894057626686, 0.03972123752558424, 0.036107807630492796, 0.043308865579385916, 0.0278202454829889, 0.0402594909011837, 0.03482316245114611, 0.03924406817062728, 0.02360829599051466, 0.025611617827727914, 0.017811638085291754, 0.027109746813714027, 0.035281761834818515, 0.10408620590404158, 0.018380785871657635, 0.03703198545882779, 0.039941621869201624, 0.0074818813628817525, 0.07068283420296446, 0.034572843221887466, 0.1007270176083811, 0.05042000012772699, 0.02711688100750889, 0.10487149199170452, 0.055329053242120056, 0.022602412969835346, 0.01921291440545071, 0.04128101552205701, 0.02702640027799193, 0.04873886614316895, 0.0441559404885817, 0.04051234588147171, 0.0631481449630472, 0.010436622636212457, 0.02621107588281795, 0.018876615213230252, 0.016929506992680893, 0.02214603141070374, 0.02592949260536942, 0.04183503498713817, 0.04637594837995787, 0.06882199897400795, 0.05026641865110686, 0.04373819274347156, 0.0215328642122087, 0.04654437281011094, 0.0256225154284508, 1.5454692513711992, 6.832198625610721, 22.500366626247285, 34.41151442066316, 43.690085026525686, 48.548948534073375, 43.797342238887666, 37.21157289320423, 33.825602531433105, 32.62439823919727, 30.136097592692224, 31.269470376353112, 33.59311580657959, 22.107637351559056, 24.69493862121336, 38.014054529128536, 31.507589624774074, 27.764069726390225, 31.490421410529848, 21.26606341331236, 17.72809140143856, 12.605579899203393, 7.306675487949002, 5.782410079433072, 3.2880709440477434, 2.6422245031402958, 1.2938261608923636, 1.0435040511431233, 0.4309949374968006, 0.7418949289187309, 0.1831919699907303, 0.17453758196244318, 0.15978888788771245, 0.1954158068063759, 0.2406951577793206, 0.17765159147881693, 0.2552680959624629, 0.26311148799234824, 0.2908437482772335, 0.9409793622551427, 1.2585193135084645, 3.1292465761784585, 5.472366819458624, 10.061488439959865, 15.590057430728791, 23.238784190147157, 27.40984832086871, 34.241001144532234, 36.70040176760766, 38.62651301968483, 38.016643293442264, 31.32206936036387, 30.12693101359952, 19.926422988214803, 16.514635585969497, 14.193296509404338, 16.248140931129456, 16.93554512916073, 31.06148473678097, 40.81666646465179, 42.25157930004982, 41.278615766955966, 22.662766479676772, 16.559015243284165, 5.095705043885016, 0.5179007483586189, 0.029997858068635388, 0.051315499454616546, 0.027570985370285572, 0.01575807715961409, 0.06733199626567864, 0.03223753909790709, 0.06286399146061271, 0.053925407795055266, 0.03977564125952702, 0.015364607698434304, 0.0884015822122174, 0.02431349524657332, 0.029909231271895192, 0.02354197958934932, 0.04767005857560904, 0.01757484222311647, 0.033512267269073956, 0.04407897163482924, 0.0416973038696714, 0.03228912745872813, 0.07208914180556614, 0.042763794021260355, 0.04038148657268575, 0.0419025847898616, 0.017330935149784052, 0.025287798207793987, 0.030464334751389203, 0.02655326629117612, 0.03459931155967136, 0.03178660633913692, 0.07671900183683442, 0.042705065720985015, 0.06043527440558519, 0.033637511153374954, 0.028261301453195276, 0.032977809859139305, 0.11495444247679365, 0.06307732396488709, 0.019924981639750546, 0.07113649614996488, 0.04097286431539444, 0.08110795019855423, 0.12150997941892956, 0.058779118717798305, 0.033034259047839916, 0.0362434511583659, 0.045991379902848316, 0.05166437589533387, 0.08373150256492438, 0.014757244573575596, 0.11498379130517283, 0.10896934992483548, 0.16633031349028313, 0.1798264384870568, 0.13962024432276526, 0.23271282804348778, 0.32855133135472575, 0.24247338574740196, 0.13587088744726875, 0.20926457739645438, 0.197924193175089, 0.15563283025497393, 0.181926867714332, 0.17828346079876348, 0.18645479974727477, 0.11372732283968119, 0.1523306542226384, 0.19291071461573725, 0.18029139257006108, 0.08657736598604149, 0.15001005132592496, 0.07583495169397324, 0.10999152572044443, 0.11031368867524209, 0.09173853863631526, 0.07197759174291166, 0.1772540837766663, 0.12628174957729157, 0.09294509647354003, 0.16218395453066597, 0.19429410086764445, 0.2020643161790025, 0.12456316921499469, 0.21030756014008678, 0.17449981382777616, 0.102647592373673, 0.19831048535002818, 0.1688140931148683, 0.13612323680952673, 0.09419879170074578, 0.10389941068546427, 0.11334082382100244, 0.1596373250527728, 0.2001164150574515, 0.15655716130089375, 0.15671707449420808, 0.10102399159222843, 0.08904037696699943, 0.16897526269237842, 0.14232824256102886, 0.16789949138558682, 0.09276046928378845, 0.20900055285423033, 0.20085754383715893, 0.1293852483673442, 0.1347392530090386, 0.19498485170545118, 0.15459681891145247, 0.1220476735503443, 0.17257068186037003, 1.1519877396283613, 5.9823171073390595, 21.26498672270006, 37.23688787029636, 51.762240471378455, 58.867590504307906, 54.69354929462556, 48.72080326080323, 44.07912138969668, 44.84331677036901, 46.761206734565, 45.99118663418678, 48.04754411020587, 28.578322395201656, 28.688064429067797, 36.63966386548935, 33.11613205940493, 31.296548458837698, 35.31340068386447, 33.655646231866655, 24.33313331296367, 17.560188462657315, 9.669238675025202, 7.393470675714555, 3.8780035078525548, 3.2944053267278983, 1.8605946773482909, 1.385746538158386, 0.6214701973142163, 1.1254570729309514, 1.03500684903514, 0.28138084637541927, 0.8010203691740191, 0.2324239669307586, 0.4295948658499026, 0.4842198766287297, 0.5596179743447612, 0.7297778694379715, 1.150341815044803, 1.6235355720404656, 2.3998347741942254, 5.288654277401586, 8.160651470384291, 10.350613209509081, 18.36675524711609, 27.844111573311594, 28.880919525700232, 34.03259777253674, 36.6381968990449, 39.52648124387188, 36.385306004555, 27.882268390347882, 36.035363904891476, 28.857599073840728, 25.455482275255267, 25.421410606753444, 31.18377639401344, 30.260424960044126, 44.19803980858096, 49.38586465774044, 54.24679133199877, 50.75918059195242, 26.085059950428626, 14.978137285478654, 4.125428824655471, 0.37249342989056344, 0.12654066431306063, 0.11177634204467458, 0.08564372697184164, 0.11089555543637085, 0.12085592419269586, 0.10160571279665155, 0.21151594126657133, 0.19513787010744696, 0.12550217850554374, 0.18390876781796256, 0.19007461115477547, 0.05820187529729259, 0.17029889408619175, 0.1429982017725706, 0.15920894400727365, 0.0752322166977871, 0.1524860781407164, 0.14559418263454593, 0.10480443631569225, 0.14202320167133886, 0.18549741966830147, 0.12879948221868084, 0.14296093925593362, 0.12812160165800204, 0.09676933078275574, 0.1894342689023864, 0.1842840436485506, 0.18049241404139227, 0.15626235534587216, 0.19271398323678202, 0.2502555673521373, 0.1565132644628325, 0.13943086738788313, 0.15663096621151895, 0.10344835343740641, 0.1323215867723188, 0.2671455537840243, 0.22995056013666818, 0.11222344627904315, 0.0851375343758733, 0.18885257834148025, 0.19661977526641664, 0.19724464254273524, 0.11603821174151475, 0.10570446705265392, 0.12183745136304248, 0.2514191016915345, 0.13875923810466645, 0.25979711584025816, 0.12965362428897811], [0.020645937409191843, 0.12575689507948776, 0.011978478963306595, 0.08892841321686584, 0.05585237173363567, 0.09771810769433938, 0.024072719557631402, 0.07319384825325782, 0.07712228584193415, 0.045177886457813364, 0.041825202248630025, 0.014477855180420223, 0.03264962928369641, 0.04650880334778659, 0.05297784513283161, 0.03742572400839098, 0.035392231713499755, 0.043022325713067286, 0.13595817550536127, 0.02644842715873834, 0.08580146447545098, 0.12673795493620058, 0.0620436874939309, 0.03795049806696273, 0.02238861698236677, 0.06001812420905598, 0.028047164556600397, 0.0803602866888527, 0.07656794461992479, 0.1214023900308436, 0.030070153786049738, 0.015008736874968296, 0.060038919665760575, 0.02333259243788498, 0.03201661083186346, 0.033028260579392794, 0.017456531434530215, 0.020383799358481364, 0.05609214576261659, 0.03714717826956222, 0.040139368314656525, 0.07372453268016539, 0.011959895585483361, 0.04304465717606006, 0.036369572213340196, 0.0636765962436555, 0.024031827699453123, 0.016749503143552332, 0.03604499225114142, 0.03635657553170477, 0.007648138243014054, 0.03935974744719364, 0.02152131160631055, 0.08724151059023796, 0.004985903224517261, 0.040235405096844326, 0.03185034485443706, 0.07892179573255201, 0.005632664814906856, 0.0934954310557054, 0.06624671014686746, 0.2088668858332019, 0.1695887612239007, 2.3076688810702297, 9.616664205828021, 16.067586387357405, 26.209810933759137, 43.02032855249221, 48.65174208917926, 42.78883026492211, 38.36700116434405, 40.06287320967644, 43.92769436682425, 39.76895824555428, 32.25580134699422, 18.644802262706143, 29.157450545218687, 27.485781485034575, 16.87176150660361, 65.21670756801483, 43.388172349622174, 28.99677065110976, 26.849059212592344, 23.599604983483594, 22.462272567133752, 17.991198109042262, 17.601545933754213, 14.482457560877647, 14.216818963327716, 11.608661470874665, 10.735958622347924, 12.478570611246171, 9.125010794208897, 10.474218860749277, 9.77049171924591, 11.457225622669345, 11.174103060076314, 15.094847409955918, 18.63217419193637, 22.55360103422596, 21.609739526625603, 19.919264662650324, 23.88757363442452, 24.040836326537598, 25.597693689407844, 19.573937231494536, 27.754403045100553, 26.6093788608428, 18.73534821694897, 22.430073830389208, 20.283531258183142, 22.599371171766713, 29.89267137742812, 35.450938593956735, 33.99122068958898, 37.273813063098544, 38.897705693398755, 40.50859958894792, 37.80818108589419, 34.0212542779984, 29.64546595850299, 12.343519483843158, 3.548895322507428, 0.24808732402180475, 0.06751673836861888, 0.07235453764517462, 0.018795951900462952, 0.03420994737215581, 0.020356363834693067, 0.08641782817581008, 0.012787991623965003, 0.03541926312590799, 0.03940672778915014, 0.056148629425273794, 0.06727352077441831, 0.046397065593590664, 0.017203829671827056, 0.062123272537944786, 0.03472480059210812, 0.03943460189827508, 0.01823159024840401, 0.03764880881194146, 0.0018268545611663874, 0.032554117271736745, 0.12309452503799431, 0.04530096614372827, 0.06286936556740154, 0.052148424719850865, 0.017550777486195008, 0.03091019983854025, 0.07153141447493146, 0.036183918465770064, 0.029194980687011155, 0.03942984066182568, 0.059519703575079484, 0.058004531047997944, 0.02879822758146592, 0.06624004518192622, 0.015218770413118747, 0.10912759304647485, 0.08868913331459607, 0.04960276434318193, 0.04252814920619131, 0.03276042091930586, 0.09172094159669454, 0.022419768032587828, 0.06946548218688658, 0.018220648597625476, 0.05559159157377097, 0.09999236993251309, 0.12477888425271358, 0.13073353247056085, 0.05157723722438659, 0.023151115784721992, 0.015890744435901365, 0.011428537001202424, 0.07818775326614419, 0.0657963500388207, 0.024910503735525474, 0.11248136510051067, 0.11517375812775667, 0.03771796739930588, 0.03745777329670326, 0.024015004408635923, 0.057047216086498195, 0.08138503653988724, 0.058336948089662104, 0.04074146745786552, 0.00548132079383058, 0.03720309502715546, 0.06120926835724424, 0.03151926846664039, 0.03824996566700359, 0.05443791678595928, 0.07691914996793194, 0.025728580301567435, 0.04286925751535643, 0.056939243654450106, 0.08043064420381862, 0.06069479052037482, 0.029907467354449536, 0.04490557667468825, 0.129080927600303, 0.04973045970884062, 0.05050699707240828, 0.03654988632807809, 0.020813542125265927, 0.04048292427473972, 0.08904976920495111, 0.055564177117400596, 0.05415693871797093, 0.04045552897056745, 0.011974075872961794, 0.06434901842787381, 0.1077820668597856, 0.046816563849607785, 0.04414166060967311, 0.017463774795854287, 0.011116606108243427, 0.02438775406429364, 0.0739322497599548, 0.0707775150095263, 0.06406040629372001, 0.01937089897241564, 0.06393543054019252, 0.038476260378956795, 0.020160120836789572, 0.03168693830018803, 0.06003082211640093, 0.007823146720071355, 0.06359768152657537, 0.05695915811004178, 0.04807355325488795, 0.0438146215052374, 0.024983485101632057, 0.017113776036327886, 0.017899851194552837, 0.352434673977475, 1.0952463649934339, 6.089153645500061, 16.320861674124195, 26.622154020494033, 35.91231915258592, 48.083104318188084, 51.408689791156405, 44.7480933896957, 42.932196817090436, 45.39739470328055, 46.06638239276025, 27.63790276742751, 20.583859297537035, 19.173222011135472, 26.530480384826664, 25.68188540397152, 28.98924754511926, 66.1999124096286, 44.5966036089005, 37.78869867324829, 34.180074968645656, 33.32048362301242, 28.469527613732126, 23.622666558911725, 20.30131724572951, 18.766162357022687, 17.127097998895955, 15.029671345987628, 13.974427273196559, 15.662638929582412, 14.218475184132977, 13.018597633607927, 12.86620080471039, 15.339803349587227, 15.924192378597876, 17.605725219172818, 16.71373901828643, 22.512841724580337, 33.880617695470015, 32.83592970140519, 37.07747882412326, 32.85255270619547, 36.0250323818576, 30.411045935846147, 32.840887577303, 28.633447385603382, 22.301525992731897, 24.8939989074584, 21.268797305322465, 18.794487753222068, 29.431686978186335, 31.360918475735573, 28.432298437241588, 36.24164527462375, 37.79381344395299, 40.638104484927275, 43.19946712063205, 39.84533071517944, 37.15525942464029, 19.724636654700003, 6.253108228406599, 1.1509940316600185, 0.28479220525872323, 0.06555198331273372, 0.007571103314178125, 0.04396075660723352, 0.007150684316237007, 0.04916971782222391, 0.0741760649027363, 0.06536564008603174, 0.0336840892991712, 0.0385551329612011, 0.0793124546086596, 0.06547892916827433, 0.021595928570135467, 0.030730870146785053, 0.0739598825513836, 0.030280149977413878, 0.049704523802164106, 0.07460139691829681, 0.034731473217928605, 0.022152926202022263, 0.054034169297665365, 0.08410506235856204, 0.051494086041085185, 0.021081272617823655, 0.0631621413894238, 0.022497841968171062, 0.04243098244431519, 0.05241732158127332, 0.020178043463778113, 0.07207732872977372, 0.06743521129171695, 0.0172311847563833, 0.0477484408615818, 0.09675167245610107, 0.08083112432711548, 0.05624033398024979, 0.05920304113157815, 0.04086511021840476, 0.0308829692432717, 0.10808307812699389, 0.053102686820972356, 0.10870966144026288, 0.057637437036441225, 0.010204752719390297, 0.04940732765281874, 0.07375462461383113, 0.054546892793188174, 0.06223450084367107, 0.026449149196606972, 0.10964300168017227, 0.05253085198121206, 0.036818511228287415, 0.15702194684455473, 0.219794976855478, 0.12944184694319003, 0.2971140553634013, 0.19853638935714, 0.23768282345225736, 0.09299060975712153, 0.25621115019725216, 0.19594368735148063, 0.20559837170425924, 0.12734701015776204, 0.10311345044042795, 0.12988780204567218, 0.1756901152792477, 0.17788497250406973, 0.1382836660430316, 0.09422218802595332, 0.07407941525020907, 0.25097287079739955, 0.1473867670903283, 0.14919065900387304, 0.2553857211023569, 0.14254714452451275, 0.20770918908378772, 0.15799356083716118, 0.2021215889122217, 0.17661899688743776, 0.162740210972486, 0.23585682224121787, 0.20260505167947662, 0.08480528204311287, 0.09738491307343207, 0.17203169304036325, 0.1557755217917504, 0.13090645383682945, 0.1344308260107233, 0.16750751483824947, 0.1451675635912726, 0.16495475665696208, 0.1209591622013719, 0.13500306304664383, 0.13409508031702813, 0.16032554780042943, 0.1467857098266963, 0.14192759389838866, 0.1857411888458075, 0.10455646897636114, 0.10623519744483695, 0.13636130629287613, 0.13618337471158276, 0.07780608826226766, 0.17846919115512602, 0.2289102893442877, 0.2236401866520605, 0.14111236909464484, 0.20218598626313672, 0.266596483246934, 0.16511057894076073, 0.22780157625675204, 0.15642933186984834, 0.10736298612168721, 0.45813534889490376, 0.6063106656074524, 4.603202439123585, 13.843390691664911, 26.67528840803331, 39.081390288568315, 57.54406905943348, 62.43281710532404, 57.030454297219556, 55.22017848107123, 55.29892790702082, 56.6467680469636, 51.21744286629462, 45.77895110653293, 31.092012543832105, 39.98701064817367, 37.60238216769311, 26.611236103119392, 76.32795856844994, 58.0600215542701, 41.09118530827184, 38.67424434231174, 33.27589019652336, 32.085878387574226, 27.04432264451058, 24.961683327151885, 21.610851518569454, 19.495529051749937, 17.233619766850627, 16.405146544979466, 17.298413399727114, 14.643437516304756, 15.380622475377976, 14.374773790759427, 15.504515440233293, 16.200896962996453, 21.376872331865375, 25.15733115134701, 31.04334769710418, 31.0391507610198, 30.619874885005338, 35.51210403442383, 34.3987431833821, 35.45018157651348, 27.834925382368027, 36.48594617843628, 34.12798981512747, 27.385433527731127, 31.339459188522834, 30.831869186893588, 33.333811836857954, 42.571370140198745, 47.57239210990168, 45.60024007674187, 50.57852798892606, 52.203075655045055, 53.334251911409446, 51.87307096296742, 47.052544701483946, 38.473054209063136, 17.821534026053644, 4.757293731935563, 0.7245371538785197, 0.3417359803232455, 0.192399917831344, 0.0882972410369304, 0.09835700970143081, 0.0430617371063319, 0.10857445458250661, 0.16971401659952057, 0.13398867070434556, 0.1251550717279315, 0.14179427927780536, 0.1478647906333208, 0.19467867700563324, 0.15502423468616702, 0.11857407768407177, 0.16361952669197516, 0.11997021929991823, 0.13337201589057524, 0.1845116790143713, 0.10988688577086696, 0.10944299144490112, 0.21057938345737998, 0.21181413333021828, 0.16103436299149068, 0.11470792304363944, 0.13741172008937405, 0.12613600901057645, 0.23792199610221773, 0.10475988064201609, 0.1683916109463861, 0.15662692126727876, 0.24040847235629637, 0.16999648853896127, 0.09746181297927134, 0.250335194530987, 0.2429978188968474, 0.19691619000607924, 0.2029875287365529, 0.15322139997395778, 0.20436233480370816, 0.2039538873659988, 0.17494379242341365, 0.15939334137064798, 0.08024258494016626, 0.12076572500049107, 0.20365578723290276, 0.16896498179243458, 0.2836240743917804, 0.18687005004575177, 0.18934350280511766, 0.20960691144629834, 0.10161437725107517, 0.08230491661496701], [0.03786038697486924, 0.04105582780715439, 0.05571875450832229, 0.07120491546248237, 0.02498861022984549, 0.07619135877898625, 0.05575926523775824, 0.04071601801702092, 0.018164207069804112, 0.03997213898166534, 0.028707089931553895, 0.03509950951763219, 0.03961643669754267, 0.05707257359679188, 0.03232745100714026, 0.031660314829599474, 0.04813486327146811, 0.026864985552346034, 0.022101642361151117, 0.02446914899102863, 0.0022659219347030647, 0.009416443457256162, 0.012080146491737857, 0.050689176611241796, 0.01762605711607443, 0.06522959053155876, 0.08138036340354912, 0.0389407854527235, 0.07278409846607717, 0.09749859286051604, 0.059556004651371515, 0.07263466535556702, 0.03137060718971395, 0.02163417359453536, 0.04142534265655183, 0.01797594670807162, 0.03302201313237029, 0.1032212543331327, 0.0471946818663949, 0.046349947355807795, 0.1359170519055859, 0.04426992671083539, 0.0428001870281033, 0.02998650081515793, 0.019280215229598746, 0.011212275168227573, 0.016648574889968, 0.02806138314847504, 0.03803212473529481, 0.011060557200483257, 0.05057074707902728, 0.03173986348443695, 0.013606463682897871, 0.03439809473591947, 0.03750439740777497, 0.011066895620446774, 0.0324254987701293, 0.10353244690885467, 0.07739230119172605, 0.033080592045500394, 0.05143217847592408, 0.08123291446076286, 0.05605987047836666, 0.022837238070825418, 0.04142536563918956, 0.8598980259510779, 3.054679132276966, 8.424032253603782, 12.530680279577933, 29.973531038530414, 34.160145405800115, 37.3599483120826, 43.18745682316442, 49.73574399948121, 48.85409324399887, 42.299028212024325, 35.905305954717825, 30.144987644687777, 26.334836483001713, 36.771490804610714, 86.73268871922647, 49.87237584206366, 23.048490401237245, 21.186268675711847, 24.645014693660123, 26.650085218491096, 22.950801810910626, 18.854001875846617, 19.58776358635195, 23.89572039727242, 21.403983754496423, 15.672976336171551, 24.06120323365735, 20.284821717969834, 20.841266801280362, 19.477707762872022, 22.414725595904937, 26.02499669597995, 51.81241543062272, 41.51355397316718, 16.76667924850218, 19.2717166485325, 19.409111392113473, 28.000327810164425, 28.613708057711204, 28.28744334559287, 35.400449845098684, 33.23373256191131, 33.425556075188425, 35.249728848857266, 36.27145136556318, 42.737870831643384, 39.640265280200595, 42.37241575794835, 36.19238030525946, 33.1530454850966, 29.62331633413992, 23.654594652114376, 16.084335888585738, 11.381427780274423, 2.576920471845135, 0.20473889766200898, 0.1503776509555117, 0.04839228796622446, 0.03510839230711422, 0.031015670993515564, 0.044527914480216084, 0.050189016957677184, 0.03427932046413903, 0.05626905078609144, 0.030434191106788577, 0.09840927988050446, 0.02206341648894933, 0.06978861041246884, 0.014876856754023223, 0.039572915242564295, 0.06047865030385795, 0.08704245796487217, 0.018438771066646424, 0.022136411261594584, 0.01923509456607844, 0.038244580068895896, 0.04566262093102259, 0.034540242350269715, 0.07405631769929202, 0.045874490207361604, 0.011501393878021309, 0.05023339643113075, 0.011247687582527439, 0.02163685107183072, 0.05153248619828975, 0.05050564492722193, 0.01907886434046011, 0.011008875951501391, 0.042092344768705874, 0.010410749931789694, 0.06404807227813909, 0.020445036596708724, 0.022116309114461465, 0.0699811053252028, 0.046269741780575246, 0.03724359043483292, 0.01774998332914566, 0.022401387668064526, 0.031100030680517518, 0.009873172628783412, 0.10729753923031593, 0.04143915522182661, 0.05647908145141217, 0.06296036149104757, 0.06627360749388896, 0.046521409324580626, 0.022704480779207042, 0.031076504120362863, 0.06672546147338806, 0.03209410062540443, 0.03073312436050225, 0.016284870817476226, 0.052134570019740256, 0.09403226716864495, 0.062230632099653446, 0.01847686670390108, 0.01222672017907063, 0.020578086916958133, 0.00901156407405412, 0.020077752978390744, 0.06094138656232146, 0.04730540455409116, 0.030679954028117563, 0.06173915222227093, 0.06083042638736868, 0.020341982449134512, 0.0318291261341543, 0.08451698783544764, 0.036229519849462856, 0.023956318243196415, 0.033864487683580774, 0.03786758054047823, 0.07434212212120334, 0.08468789439047537, 0.05977540840244582, 0.04289675624139848, 0.030401391052310506, 0.01541037379103082, 0.058024445503589615, 0.10942193168786266, 0.045108996001222444, 0.03978139841027799, 0.12381201234435844, 0.02668188670800338, 0.021716928327335946, 0.03364214598531685, 0.02014214649886614, 0.07581778366359011, 0.009837066904912073, 0.036738202231185096, 0.012957840020047321, 0.024731369396190972, 0.05670337667388301, 0.07883463024852738, 0.01106971195117841, 0.02675682925919612, 0.03364302698642977, 0.05101556837138149, 0.10363695662348502, 0.027760910058033564, 0.05788633134216071, 0.04923685776790784, 0.027100078784109607, 0.04533778815980881, 0.06392547522761649, 0.1170527802840356, 0.036919247959890676, 0.06555697054512079, 0.03202450153748355, 0.01911540673444829, 0.04991684507037844, 0.012012602434673858, 0.05327088525518776, 0.03791321639812762, 0.37330824100682813, 2.3842386949446897, 6.958433245458911, 17.245441790549986, 25.080813554025468, 40.07243202578637, 41.422739336567545, 45.45304921365554, 49.71270791945919, 57.00853609269666, 50.609757900238044, 39.431959967459406, 31.427865489836666, 26.28383586483617, 17.136009623927457, 50.242424011230476, 75.9401616742534, 45.72382219376103, 28.807788895022487, 27.003404478872977, 33.0339309477037, 34.956974906306115, 36.230705784213164, 30.349468646510957, 34.209528046269575, 31.98762889831297, 30.769672163071174, 30.17614499215157, 33.516158903798754, 30.707149582524455, 31.247314868434785, 28.90027250013044, 30.394417047500614, 36.60824175803892, 51.0451723683265, 44.571492595057336, 24.46288924063406, 22.269699881153723, 20.72357020070476, 24.65663275411052, 22.842008990626184, 20.69462703120324, 29.43471112558919, 25.700948123008978, 28.626406731144076, 31.031098135056038, 36.61204645710607, 41.34628449716876, 43.161212244341456, 45.693937655418154, 44.594132515691946, 40.15703755040323, 38.48816317896689, 34.30276278526553, 25.092331594036473, 18.93232572463251, 6.2673219173185295, 1.1914602667093277, 0.1334661680964693, 0.10499202826571082, 0.05565857830187006, 0.04129816440024203, 0.04474901511604267, 0.03221189047420218, 0.020390931637056416, 0.013587185080283353, 0.013822302252294557, 0.05117118764188021, 0.031931027319402464, 0.052428950795963894, 0.06445165122708967, 0.12011242820130241, 0.04669028191616939, 0.04348380175689536, 0.09441840612599928, 0.06321262275319427, 0.027810910701631542, 0.02801630461979057, 0.008875072103804879, 0.014237049805571236, 0.06493537446423885, 0.026603039023616624, 0.014491209050550338, 0.04054445262637831, 0.022475617757487684, 0.009532083471816395, 0.026032834035915234, 0.07351293153459988, 0.04443665425623617, 0.05709166450786495, 0.0357166086623986, 0.037916717419941584, 0.05581567612206263, 0.015765277428492423, 0.02739644755849675, 0.058874921843169205, 0.05394287076928923, 0.030818763414337754, 0.021731097123495514, 0.002979246750211103, 0.039683442577839866, 0.02533989218664506, 0.049121205304418845, 0.06953480548315472, 0.03129477597652905, 0.05646587409559758, 0.038090665344028704, 0.09015766257840781, 0.052907200334894086, 0.0614922535755942, 0.05836689829706185, 0.0703435798265761, 0.15460429592959343, 0.17636010513430642, 0.13398484026472415, 0.18671287944720638, 0.06668820661763031, 0.16700341366231444, 0.14578912136775835, 0.13278396679989754, 0.1508682536622209, 0.10362688256728073, 0.09101784142154841, 0.12145750239611634, 0.14224401885463347, 0.1577863340536433, 0.19914205847007616, 0.13435461558401585, 0.13057247014536014, 0.172129399894226, 0.11071249872686402, 0.11419884995707583, 0.13763796117517257, 0.11727793352498163, 0.21451888335568292, 0.14490340115322223, 0.20084413729848402, 0.21194465939075718, 0.1434658524850684, 0.11395766249587459, 0.17140181554901987, 0.23718080603547637, 0.1302403097431506, 0.21259224883490996, 0.1908847184911851, 0.10294011538668026, 0.13818301741153965, 0.17537578940391543, 0.0786847068417457, 0.2310181955897039, 0.13865691940149955, 0.17887063654920748, 0.1626376011559079, 0.0889490592864252, 0.16674446062214915, 0.16931373565908403, 0.12749199995831137, 0.13578914586574803, 0.09523530866229728, 0.13011090217098115, 0.22055945599511748, 0.11417439643053279, 0.180376673477792, 0.14393403945911315, 0.09827361336999363, 0.13347983510503847, 0.10346827938431695, 0.22741364465365488, 0.10449633873518437, 0.16841555885489912, 0.18126637734953435, 0.14992521474919013, 0.10989099966302035, 0.1541269312222158, 0.18785730755377203, 0.10513519477700034, 0.2693618155054508, 1.5826581009934027, 5.64015846098623, 14.918434889085832, 22.220266249872026, 42.10717331978583, 47.82991532356509, 54.66850103870515, 59.198160017690356, 64.04050642444243, 64.51525442061886, 56.33069169136786, 51.04803569855229, 41.81860846857871, 34.39472275395548, 45.306348646840746, 96.94732512197187, 63.30408534696026, 33.234418976691465, 29.56497892256706, 35.31800554644677, 37.61247050377631, 34.28158198633502, 29.194565972974225, 29.795137720723307, 33.43339297079271, 33.668927377270116, 25.6214318736907, 35.11243020334552, 31.404117499628377, 30.46057958756724, 29.99128760830049, 31.788245016528716, 36.17881282683342, 65.61493012212938, 53.47612011817194, 23.533132576173355, 27.86863030925874, 27.51237515480288, 36.25536572548651, 38.05281931354154, 37.18240614860289, 46.06787289342573, 41.99854720023371, 45.098953323979536, 45.62713969138361, 50.43372584927467, 57.15631531130884, 55.07102251052857, 57.91420744311426, 50.91971535836497, 46.254879736131244, 41.39959735255088, 36.42654188217656, 25.669910407835438, 17.407084626536218, 4.599607096564386, 0.9316686360586075, 0.2977538307107264, 0.16257838255936102, 0.1595930298489909, 0.08355531000321911, 0.11127063208409857, 0.10907377536979415, 0.10931712319894184, 0.15596330526375002, 0.07599360850309173, 0.14365453994081867, 0.22257339389574146, 0.1456538149185719, 0.18168729669865102, 0.21327077290944516, 0.16059415354844064, 0.165836401283741, 0.18622172515719168, 0.21570271902507354, 0.1165240034160595, 0.13997397776092255, 0.13821124009067012, 0.14011634754077082, 0.18797611246906942, 0.1617446184278496, 0.11325610981833552, 0.07822893049207427, 0.10039691798268788, 0.15151791154376923, 0.12361832999534185, 0.16126913829676567, 0.14222744071195204, 0.14974002065437456, 0.06978887854324234, 0.12168675420745728, 0.11623675108797128, 0.12459239546930599, 0.1084355858244723, 0.2750168927013874, 0.1430979923855874, 0.12414604200110321, 0.15030611366514238, 0.0905187044953627, 0.20888098185100865, 0.17136377162270008, 0.30269387208165666, 0.3440899540099406, 0.30700890828044186, 0.20514743703026928, 0.14675402443014807, 0.17157643763048036, 0.19351132754837314, 0.23726400318405322, 0.20685588971020716, 0.19643318689157888], [0.03248886190234654, 0.010398199496370171, 0.027280385237968257, 0.10377132078452457, 0.0219052882804986, 0.002540317871006987, 0.09974974988689346, 0.04481018340635685, 0.03073667900847091, 0.025653538158944538, 0.0518706105949898, 0.027149464642148347, 0.04629189704334544, 0.016737582815450527, 0.0718112280892749, 0.03396775633577378, 0.049174433093397855, 0.0037020571706365916, 0.023936237163481214, 0.03582559999138598, 0.048110551471191074, 0.02604557216287621, 0.05472528785767575, 0.13199291973104402, 0.047618263371048436, 0.02018808496124562, 0.008523954855909031, 0.05771432928140125, 0.023266726113375158, 0.02680733935126374, 0.024330793511903575, 0.04769876005969221, 0.039229711682926265, 0.05309355122247531, 0.07921943621289346, 0.03626196367305614, 0.0314921029888454, 0.018949023928613435, 0.013390361770777213, 0.02994612989676816, 0.07363262511188946, 0.014778830058452104, 0.023228559612987504, 0.0352032263312609, 0.05508297047908268, 0.011188885546289386, 0.012748544799133897, 0.027101710551388325, 0.0004383951613084308, 0.07859102194948543, 0.02094533797653933, 0.05035787422750747, 0.060008544279562856, 0.013832776589439282, 0.01126853475016692, 0.04709381489984451, 0.0873213216301895, 0.024823753854199767, 0.023846964937664812, 0.01499562432253433, 0.052183139994139635, 0.033813803306510376, 0.04956562440061281, 0.021902788918645635, 0.01608680453031294, 0.03956448444495759, 0.037852676299911354, 0.1552607566719094, 0.4416251122470825, 1.7930772035352647, 5.8085252200403525, 11.30832656737297, 21.194856705204135, 18.008650695123983, 34.23854574080437, 43.561188097923036, 52.75552580433508, 49.31136315868747, 46.10633957770563, 38.02398989277501, 76.14690196129584, 47.6023982417199, 29.168362579038067, 31.42376857419168, 27.988852916225312, 28.63355525078312, 24.628142618363906, 24.249314223566365, 32.11728480554397, 26.45700066320358, 19.62668722675693, 32.86904235039988, 25.930446001791186, 21.81486575834213, 24.510724506070538, 26.3865529337237, 28.78709839236352, 28.694159792315578, 91.87111131606564, 65.2270116344575, 32.902274631684826, 33.49926917783676, 30.102796669929262, 33.877001270171135, 36.28131612654656, 44.15498002882927, 44.50710688867877, 48.21291908141106, 46.35488840841478, 46.18725415199034, 36.94054888140771, 35.19265836285007, 25.49146413803101, 13.432127237319948, 11.100458598905995, 7.439899281147988, 4.8561046104277334, 2.0030474398405325, 0.6591066874323354, 0.13373360939083562, 0.0631973622817426, 0.05948789560446336, 0.03564348940046565, 0.020676534960887605, 0.014548443479373332, 0.055695633974767504, 0.016058532055467367, 0.07436355726132471, 0.07226157287556319, 0.04416093538184801, 0.09259841104428615, 0.07767616741118893, 0.08243666841618477, 0.021813696723491437, 0.019773227282829826, 0.04900469865289427, 0.054080770426099344, 0.024530481990246523, 0.05641364988179938, 0.01594657022055359, 0.07680969898618999, 0.0908000656073132, 0.07151374848739755, 0.012303689990432994, 0.015367140576633957, 0.04803723685683743, 0.029833819491848833, 0.012224734096126932, 0.014867527718325297, 0.013233319491959147, 0.016884767457902912, 0.02113168311846112, 0.04241250057314192, 0.057999597441765575, 0.0362469062149044, 0.0315115750286608, 0.04084789239230656, 0.04221285039919519, 0.028815033635304823, 0.02778834175138224, 0.0478699270846142, 0.024322100329182805, 0.04186915654328562, 0.019542391584705443, 0.11410321154060865, 0.02366201790620483, 0.04597898843067308, 0.04637005333338053, 0.03177395056662781, 0.029506676965543342, 0.06567797413276089, 0.05047499757981108, 0.03796238392110794, 0.040810844380288355, 0.07400076866390244, 0.04633140419760058, 0.048188355360781, 0.052447011318778804, 0.02813258336015767, 0.02035000147448192, 0.10708727873861791, 0.005512335384640122, 0.029959141900162065, 0.023867415654803478, 0.016678226323077278, 0.02743012478364812, 0.09654447631610018, 0.12495862380150827, 0.045080148960433664, 0.04956257154023455, 0.06472650825256301, 0.04613557680239601, 0.026042235849965966, 0.1206217464360018, 0.018839226292085745, 0.0707721830375733, 0.15552021533010468, 0.04771935250309687, 0.05051216433545755, 0.06938613079968961, 0.028384170464930997, 0.04282021256644399, 0.08191978123279349, 0.032965138764871706, 0.05470783637476064, 0.03560336937587108, 0.12634662956359888, 0.07667462236338085, 0.06672987413983192, 0.03528839615624278, 0.03540293779224157, 0.004252141337811707, 0.04012299318527503, 0.08966556600024624, 0.011997031697612858, 0.05393033757084801, 0.015506671043112876, 0.018740787824255326, 0.010504284479294815, 0.029726812330585335, 0.02703060227025661, 0.08885662311748152, 0.06001482237010233, 0.032469334321156625, 0.04030316940418655, 0.05317676369281066, 0.07071720090724769, 0.036436336775941235, 0.01286868462263937, 0.11349502965928086, 0.04837674787268043, 0.04536722125785966, 0.11895144493469309, 0.02702552310731863, 0.046796944337866964, 0.07566809774406495, 0.02713631474292807, 0.05484846330458119, 0.03235764253223616, 0.021851813428164012, 0.042120467856406205, 0.021765973276248383, 0.1801499727392389, 0.43472860489160786, 1.1594154829940488, 5.0824572386280185, 11.031862228147446, 19.72365410097184, 33.07453532372752, 31.883538999865134, 47.96168342713387, 53.99451624962592, 58.14654511790122, 49.99582459849697, 39.257296823686175, 32.618251885137255, 87.70327921836608, 52.05732430181196, 24.404571440912065, 20.843949702478227, 23.669727156239173, 23.795697996693274, 19.67255738473708, 17.785899293038156, 20.191088837962, 23.641399798854707, 22.558462812054543, 19.430400056223718, 24.562752785221225, 19.1080714425733, 20.164759928180327, 20.509991261266894, 22.90034051864378, 23.691778721347934, 90.13616069670647, 57.247192705831225, 14.467912431686157, 23.70115318605977, 21.763363076794533, 27.081726366473784, 32.48072574215551, 43.308991462953635, 46.81500988621866, 46.655675365078835, 49.62121863518992, 52.54729501662716, 43.168237209320075, 44.81371464267854, 35.598517771690126, 24.4497493005568, 19.272026515776112, 14.555392073046777, 10.048942738963712, 5.211204626867849, 2.3100088200261517, 0.4831811226904393, 0.17527045231432686, 0.03136782246010919, 0.08525027187481042, 0.01482406276233134, 0.014204289013099287, 0.031609900498522386, 0.03873274278556628, 0.029336299011183363, 0.016884334618225694, 0.05126360848906541, 0.03976414611022319, 0.05293353460729123, 0.0589859739486729, 0.04997232898829445, 0.02051345207878659, 0.045863198071357705, 0.0755242111101266, 0.018508125006431536, 0.08031363193426402, 0.05057571515921624, 0.09913975237718514, 0.018009982079327587, 0.01753777888933978, 0.04092212631216934, 0.031073615968888326, 0.09595088074885069, 0.009008942138133271, 0.012454955966301985, 0.06521915641403006, 0.025687041099093137, 0.03075314415318351, 0.011920353957271625, 0.06600856405472563, 0.06744770618576197, 0.09228374042938794, 0.015747408427658583, 0.06242333385612696, 0.044130644265321955, 0.08699443191289903, 0.029572491579118277, 0.029133094189267968, 0.025047882452547073, 0.08162004167153951, 0.016854939824571053, 0.06875000203088408, 0.01226396067067981, 0.04851856606922323, 0.07808841464500274, 0.046319330651913924, 0.02703481383862034, 0.03288794008474196, 0.01838702948824052, 0.014054389546565233, 0.02916732491294463, 0.02113498495741477, 0.03609666871207376, 0.16342529275965306, 0.16855320953313382, 0.10886035093496885, 0.18724068338351865, 0.16964779595934576, 0.10878372682078231, 0.17243307714741077, 0.24245038778791506, 0.121155227083833, 0.08908886267172714, 0.20055994932209292, 0.23216170439076042, 0.13990024945908977, 0.11787972623302091, 0.12314317162118613, 0.14579270665924396, 0.16001011875848617, 0.1597017530472048, 0.13594230216357017, 0.1485497345246615, 0.22396134603167736, 0.18446784346334397, 0.22371863405550682, 0.3843817661606497, 0.12194834259008208, 0.16859577337820686, 0.2180176375493888, 0.2575593730134349, 0.17709818488407522, 0.12765385901495335, 0.21650165679954717, 0.15887014928363985, 0.12690660919273092, 0.19355338577541614, 0.32028993110983606, 0.15747464352077054, 0.1985104189765069, 0.18942942722670494, 0.05605487558510035, 0.1232823544752694, 0.14919402979073987, 0.11006104053869364, 0.16370417940760815, 0.18468964123918166, 0.21564126345178775, 0.1330270005329963, 0.11020737099311045, 0.14076609735287007, 0.21451457794154846, 0.13507726632298964, 0.13543150537917692, 0.11132257284536479, 0.11293232275713837, 0.12576817189373318, 0.1871588958367225, 0.05956277303818253, 0.17658433906974333, 0.15705193152591107, 0.25544841773808, 0.1344225062958656, 0.2118360128013357, 0.2666156048015241, 0.15932992461227602, 0.2557701287010024, 0.19582281399878765, 0.10959197256353595, 0.29008136821850655, 0.45104799371573234, 1.0999195013315448, 3.378760555098134, 8.222016461433904, 17.42660822406892, 32.9451520212235, 33.79137985167965, 52.31562806713966, 63.38330153496035, 70.34488493396391, 64.46365564100205, 61.646021027718824, 50.62960509330996, 85.64084991332024, 59.63749685595113, 43.9693695499051, 42.47777062077677, 39.463444832832586, 39.337419079196074, 35.338535231928674, 37.317492577337454, 41.83241128921509, 38.67757835695821, 31.43515325361683, 42.99529990842266, 34.7696425068763, 31.174935371645038, 34.297726461964274, 34.67682746148879, 36.85339381617885, 36.63348613246795, 99.22837949568226, 73.95898818969727, 43.71263081027616, 44.3852545369056, 41.16587900346325, 44.74577134655368, 50.322334458751065, 59.94409676521056, 59.720145117852, 63.668689266327895, 61.75081891398277, 62.42238360066568, 51.05759451466223, 47.63587567114061, 37.96981803832516, 22.41693781268212, 18.01566585417717, 12.441558145707655, 7.6771433507242515, 3.876792476061852, 1.7449899258152133, 0.25871494003841955, 0.2442682378234402, 0.10772225837553702, 0.12915395110124542, 0.08888773394808655, 0.09058960593275486, 0.08700179401785137, 0.14903822282869972, 0.1295445180468021, 0.1677663299825884, 0.12516724486504832, 0.16505830110080782, 0.16991252530246012, 0.14599437164443155, 0.10249234465581757, 0.14211694018975382, 0.11984029078796027, 0.18392744504155653, 0.10793976605899873, 0.1846053715675108, 0.08392948266719619, 0.17592683644785037, 0.26905823018281694, 0.1906595346067221, 0.1180122517830422, 0.11570739965405195, 0.18261657667256173, 0.20569532779195618, 0.13946377852511022, 0.1228591368623799, 0.22228977282441434, 0.10734538908206648, 0.1611248379753482, 0.1482457661580655, 0.15229970427049747, 0.11150839513227825, 0.10273683395597244, 0.17010787772315164, 0.16087471026807063, 0.16336167681842081, 0.14969738020050913, 0.10993050681727548, 0.18795138315087367, 0.10718575934128416, 0.1572498120367527, 0.20448734503119223, 0.07869308784363732, 0.11597370713829033, 0.14064189917858572, 0.19810505121225314, 0.1285766885285416, 0.20261517936183562, 0.14017597982479682, 0.1295213209044549, 0.11746177164417122, 0.10814372930795917, 0.054311240317239884], [0.07166495126101279, 0.04484599035593771, 0.04872317283204006, 0.029884988419531338, 0.0174859702782405, 0.05913279852980088, 0.029824205088399114, 0.010977997820103362, 0.07994194905604086, 0.015614374386777562, 0.03135732705554655, 0.02402256186600895, 0.01076290810165266, 0.04944700717685684, 0.05292483950935064, 0.023351779109948588, 0.04770897967260211, 0.03927384217780444, 0.04748656902642501, 0.051819795982972275, 0.02895997747057869, 0.10603264379765719, 0.02900871023866198, 0.02651434327896324, 0.031558026769949545, 0.039416572018977136, 0.02559942553841299, 0.033406229209034674, 0.12636739820722612, 0.05903967288172534, 0.031578199780215664, 0.05318780685023916, 0.050959651613788265, 0.024564894659805204, 0.05572881707320771, 0.023789824354612542, 0.05734289538175349, 0.04004163464771644, 0.01429718196196782, 0.10164322046142432, 0.03802095134291918, 0.023470285250955535, 0.029097350441940853, 0.037302590696321386, 0.026246873256299767, 0.05503820030078773, 0.02678387216292322, 0.09460039797329134, 0.03730694590617092, 0.0509049644273135, 0.02292434992869535, 0.03561496028616544, 0.015179224954467389, 0.0263019128432197, 0.029534740681429545, 0.02400923576656609, 0.03603290721413589, 0.05601278671454038, 0.026225432370518966, 0.07032376113197497, 0.08057352726257618, 0.03044017999913664, 0.055797056355063, 0.03527810376498007, 0.07198185885264989, 0.05615035695354304, 0.048896676425131104, 0.05943928349522814, 0.036814906784603675, 0.026079594127593503, 0.02917281201770229, 0.07513472434854315, 0.4028293778819423, 0.8489276468753816, 7.163109875494435, 15.799113877357977, 23.79396038670694, 34.76144083084599, 45.024824450092936, 56.23039276369157, 54.48916242968652, 48.01092093990695, 54.48150204073999, 45.984620586518325, 48.1326634653153, 50.99435414037397, 47.50370748581425, 47.097561743951616, 50.41748723676128, 42.49593511704476, 43.0698759325089, 49.2255416993172, 45.08739409908172, 44.51642644020819, 42.01801000102874, 42.493656219974646, 46.35766152412661, 43.75522382797734, 60.02725101286366, 61.709649716654134, 48.62039450676211, 45.539615923358554, 43.261334665359996, 52.33251779310165, 44.77188648716096, 38.53647893474948, 36.82946735812772, 31.64840271396022, 19.68914116582563, 10.764306572175796, 7.307817387965418, 3.6185323471023194, 1.494675170510046, 0.4162730564994197, 0.2410309647600497, 0.08004555478692055, 0.0733581587912575, 0.08753122972144235, 0.042533147929897236, 0.03598585409382659, 0.03961277862770423, 0.015401735192074653, 0.028096542753759893, 0.021392543717557867, 0.10953858389609283, 0.015427523626825743, 0.03297718932792064, 0.03315678332000971, 0.09401935858712082, 0.012288439095080381, 0.0069071358678141435, 0.03606140951535875, 0.08136166319731744, 0.021510046283384005, 0.016210654134591742, 0.037915744488277746, 0.030549075567133488, 0.02384234351226159, 0.047579441865485524, 0.038293713117919626, 0.07971319520185072, 0.06752172560100594, 0.040369976101623434, 0.05105751551567547, 0.05315681859370201, 0.032583738061329054, 0.06909566856319867, 0.02572575726756646, 0.0975482123753717, 0.025119910039187923, 0.04749190865925724, 0.07875543973979451, 0.04382163504018419, 0.027968002776164683, 0.015485411145604186, 0.03937365960389857, 0.09500941997694393, 0.027787332430542, 0.03524067653943935, 0.0778596990952088, 0.05987077485769988, 0.04656588838946435, 0.09988150168811122, 0.038605342363758434, 0.037687366017170494, 0.012357795907695208, 0.05298825626772258, 0.022975417349727887, 0.04513498936449328, 0.004040520561243138, 0.0407186456986012, 0.12052035469922329, 0.050981672811171705, 0.031376944652067564, 0.04174583553967457, 0.028875843779514396, 0.006050563383577091, 0.045745653370695735, 0.08024564929186337, 0.025092959066011736, 0.08602798135290224, 0.03332639901688503, 0.0526016078618986, 0.040162534813486764, 0.042714132371568875, 0.035333231452011296, 0.06556656196593277, 0.06677734860849958, 0.03303388749519664, 0.06503776211531893, 0.01891214254071876, 0.030551739637890173, 0.012509331929557508, 0.02963277886831953, 0.06538203436761134, 0.05161067696228143, 0.013634476645459092, 0.024579371806354295, 0.042230872617613886, 0.012413916636198279, 0.0365229889810566, 0.053256582393641436, 0.04837168403150094, 0.0585413173652224, 0.03842236992392329, 0.042664554991549065, 0.031796802969409094, 0.11369303274419039, 0.03499708739259551, 0.06532794856015714, 0.02758628031569383, 0.054508327927079894, 0.07088049254830807, 0.0659332652726481, 0.025160715712474722, 0.026868183969429908, 0.008272255710776775, 0.051573628950263226, 0.07721584049924728, 0.011401662636818665, 0.05703047706535267, 0.09238284156327287, 0.044919894857993053, 0.04244546916696333, 0.0405988410385626, 0.02638967779104508, 0.019143330639288313, 0.028631850521290497, 0.055287734289923986, 0.029963121726928704, 0.017941775356209087, 0.024265978643069827, 0.012062299515931837, 0.01841655451684229, 0.09714913419297627, 0.04247872887419597, 0.054981038650317546, 0.0493454852051312, 0.06362097826035273, 0.04638963837116476, 0.01937959598557603, 0.05201256668735897, 0.085416030318987, 0.08835902602802362, 0.07411722935015157, 0.023074344198610035, 0.039095971883545, 0.34005322223228795, 1.7622624505912106, 3.8052133879353924, 12.885919540159165, 25.298399194594353, 36.38483924250449, 47.47640386704476, 55.437991619110115, 60.01671160421064, 64.54498990889519, 52.76899914587698, 55.98033774283625, 47.2371785102352, 47.83813661144626, 45.57548992095455, 39.303117952039166, 39.71959129456551, 44.53827404206799, 38.00118915496334, 36.65466693139846, 44.353918721598966, 34.97244081189556, 35.45005606066796, 33.11102513344058, 36.057329177856445, 35.96218816695675, 36.21979375039378, 72.02733070619645, 69.15820321729107, 41.97644072194254, 46.78029298782349, 43.77950329934397, 54.63988734829811, 50.57131475017917, 47.35115474270236, 44.580172800248675, 42.35084272200062, 30.05541051587751, 20.20251666345904, 14.401022291952565, 8.712002865729794, 4.257231248963264, 1.5530073113979832, 1.213159799095123, 0.40624064483469535, 0.1675791134156527, 0.01974574196332645, 0.03215478628032631, 0.061274190478387384, 0.008361265551479114, 0.03857445752909107, 0.06833565571615774, 0.023078555766973766, 0.021640604902659694, 0.1195724664496318, 0.05713870996729501, 0.03980113666564707, 0.0112926923752492, 0.052201369056297894, 0.013515843142334734, 0.06041046847859698, 0.014103448859626248, 0.044556183124622034, 0.016506714558589364, 0.008893822105751644, 0.15108697176460298, 0.045996508861501376, 0.04656748568278648, 0.04042607672031849, 0.10578888228103038, 0.05470521252361998, 0.01383209285596686, 0.04756200187388928, 0.06817769604705035, 0.007732388283681846, 0.03502743596571588, 0.0540826588328327, 0.0036830210827306035, 0.04366290162227327, 0.0839161527373137, 0.025383651128879962, 0.0693329566368653, 0.05185020201268697, 0.04763760709113652, 0.026069788202162714, 0.030230723899759115, 0.05883942515919766, 0.024797932860711892, 0.03550543269563106, 0.03554746794003633, 0.027989518355518102, 0.10015871060351211, 0.008308712877483379, 0.031171114063791694, 0.07934858331516867, 0.08247213062619971, 0.04434438662663583, 0.012804320788071042, 0.02744506349817159, 0.11200819089407883, 0.06620224640374223, 0.05364947824648792, 0.0414893722852632, 0.0635402555757713, 0.027349126307413946, 0.16006235063316362, 0.18945784908869576, 0.24438767093083552, 0.1804780115884158, 0.1118328103855733, 0.09808540854963566, 0.14760634321118557, 0.08961125036641475, 0.16027440377060445, 0.08429827739394481, 0.1241005976654349, 0.13083865505553063, 0.1882380532521394, 0.13136180117726326, 0.11857387850121145, 0.10694656370868606, 0.17363318452431312, 0.14770630236354568, 0.19969420868062204, 0.08185778939796072, 0.17992570816028505, 0.23583425329096858, 0.16887642202838776, 0.12943921160073052, 0.11745694529024825, 0.1480436721636403, 0.17091432315928323, 0.15170319756913572, 0.2042372939327071, 0.13093671430983853, 0.18890986639645793, 0.3216818822247367, 0.11617169490144139, 0.17308463492701132, 0.09049147773053377, 0.12540898390955504, 0.2021661139423809, 0.10991981222985253, 0.09748814342122886, 0.14147575524064804, 0.19710198164947573, 0.11933085764007223, 0.28789556615294953, 0.14254291571917074, 0.10980898995072612, 0.20306004661946528, 0.10397200517716909, 0.12181156525208105, 0.1329867349516961, 0.1106528587819588, 0.22443374648930567, 0.16349022637211508, 0.10362165784763713, 0.07031604662657746, 0.15005551098335176, 0.17754136674827148, 0.13249286871042945, 0.11465732293624072, 0.20607452599271653, 0.16714236669002042, 0.23382079036485767, 0.1402866029210629, 0.11634018827950764, 0.08347863226287788, 0.21916854675979386, 0.11301749641255987, 0.21438774442480457, 0.18450216420235174, 0.13675191920370827, 0.1347140180728128, 0.20603525632571792, 0.24703828918357051, 1.0096940169892004, 2.743574135726498, 9.73960893769418, 23.625388683811313, 36.807910011660674, 52.14997853002241, 65.21517784364762, 73.740323897331, 70.98934604275611, 65.10926992662492, 71.80516765963647, 62.833067524817686, 64.3300401010821, 67.05075294740739, 61.96413701580417, 60.397459999207534, 65.8708804653537, 56.58475929690946, 57.966928020600356, 63.884019544047696, 55.69462053237423, 57.3714102468183, 53.065232230770974, 54.284387250100416, 57.72051688163512, 56.44065926151892, 73.13081110677412, 75.51420011828023, 65.5493441704781, 61.4914757205594, 57.75731655859179, 68.358777107731, 62.047738413656916, 54.874319568757095, 50.49735061583981, 43.075500611336004, 28.892810190877608, 16.540846824645996, 10.214894298584232, 5.71884120664289, 2.6229823356674564, 1.0240082779238302, 0.5229237723735072, 0.3763383945390102, 0.13825922783824707, 0.23744512169111162, 0.16881990006133435, 0.14139465717298372, 0.22939298602361835, 0.21014367861132469, 0.1600698429730631, 0.18641551475851767, 0.11463968759222377, 0.2260439866973508, 0.1671189703648129, 0.1957999539351271, 0.21377951657820135, 0.1000820558458086, 0.09532618967275466, 0.15922573665457387, 0.23013691868512864, 0.24447120515809906, 0.1303271075049716, 0.13739865062938583, 0.2068755322045857, 0.1391357703194503, 0.12667725778995984, 0.17486076381418014, 0.19487229806761588, 0.14534958608208165, 0.15847771308354794, 0.2307097532696301, 0.1547706442614717, 0.059481985236127535, 0.1197658806678749, 0.16452023158631018, 0.13099046303860604, 0.11557252987498239, 0.19263112316689185, 0.20018229861893963, 0.20333534797593472, 0.12268967055264982, 0.08132509782069153, 0.12473731632194213, 0.16397208035472902, 0.09156299724934563, 0.15797410220388444, 0.1928269965273719, 0.1949418128858651, 0.0868169063582055, 0.20414337155319032, 0.12547988534694718, 0.11884798476051901, 0.21866599308146586, 0.1761109886630889, 0.15342560837105398, 0.06915710881472596, 0.07679894311173309, 0.22767963038096506, 0.22774738319698842, 0.16946203495946624, 0.11361859198058806, 0.15845355067041614, 0.10947806295007469], [0.03595079407997189, 0.08517259822016762, 0.031329864718680905, 0.04712174646556378, 0.061535537543316046, 0.04440352095351104, 0.04744249215770153, 0.04890254082819147, 0.011157922187609779, 0.048666539782237624, 0.04369749815293378, 0.03255127125509805, 0.06720888593624677, 0.04582690848638454, 0.09450908795359636, 0.04543588954895254, 0.0743550383636067, 0.06434200872336665, 0.05248300979034074, 0.02589275485896055, 0.05232043061104994, 0.04039575496027547, 0.01831141852533385, 0.10298814909953265, 0.05308268809570901, 0.041566199412749666, 0.03404074919319922, 0.005287336797693805, 0.0348402347205387, 0.07965843523702315, 0.049192949438527714, 0.014614411310533123, 0.032759467139840126, 0.03350510434698194, 0.002710260831067459, 0.00803834608485622, 0.035239776386128324, 0.0544490518739387, 0.04946744640267665, 0.014209996368135176, 0.040321693410195654, 0.03276034814095305, 0.08641854829845891, 0.016771792471709273, 0.06299586200545873, 0.07470475750104075, 0.016377458288784952, 0.021477981673313246, 0.00831729306223532, 0.054969171948370435, 0.04689059092573101, 0.009215055221331217, 0.023061447108404774, 0.01522505999497709, 0.0030248036050432997, 0.07611871066112673, 0.06554147258641259, 0.046438556915569695, 0.017942543359353177, 0.08098972751007927, 0.040793829567490086, 0.03398763631740886, 0.03194462346483863, 0.060013121654910434, 0.05830020651281361, 0.04308568884528453, 0.07861599641581697, 0.027391540765341733, 0.042730442383476806, 0.016996539686055436, 0.04849660615887373, 0.04118208675795505, 0.028864005805864453, 0.014713878251401889, 0.024061278034482273, 0.01674838082474326, 1.0378750822236462, 4.0299990292518375, 9.465729440412215, 19.55923814927378, 25.114073291901622, 34.154724690221975, 38.94276588193832, 41.17943471477878, 40.597919802511896, 48.27645363346223, 50.98372843957717, 55.17932699572656, 50.70840943244196, 54.85216602202385, 54.13157955292733, 49.493467038677586, 47.20500723008187, 51.62809933385542, 50.774399388221006, 53.65288957472771, 53.91093838599421, 53.80667001970353, 47.07471393769788, 51.02086544036866, 45.18129564100697, 35.857939412516934, 31.347278433461344, 20.933685687280473, 16.587407319776474, 11.289286401964004, 4.791458556728979, 2.3010839569953183, 0.540143467726246, 0.19524066378512692, 0.132391668495632, 0.029428679638752536, 0.017573601160679134, 0.023465102666147777, 0.10629333585741059, 0.029431357116047895, 0.06420484451096385, 0.03768685273826122, 0.06789651879620168, 0.027276880385714675, 0.03715792265270026, 0.050696485090039434, 0.09297133498494664, 0.03645288810554532, 0.04782227641572395, 0.04014963006240226, 0.044273404750011625, 0.16406234083396776, 0.020270937370256554, 0.05968296840306252, 0.0604075190400885, 0.033916141161875385, 0.029659185919069478, 0.02775628288697091, 0.04255373654286227, 0.034352497182666294, 0.026170605372998024, 0.0314108133992, 0.02016580520918773, 0.03228718542584008, 0.04348287096006736, 0.009694290140854015, 0.03285417092903968, 0.04577175398627597, 0.04435599285868868, 0.022924980036013072, 0.0020906539453614146, 0.018460730976995923, 0.06805417203013936, 0.01434676796047678, 0.0641816397077374, 0.04469267317965146, 0.0916132832606954, 0.056891033741375135, 0.023916213540360335, 0.045604528483724406, 0.06014917503982302, 0.03534452741845481, 0.01747574683489098, 0.028279877170139266, 0.03367028822521529, 0.08269880072123582, 0.0036471128659022432, 0.029716621445972594, 0.01884656158396073, 0.02566608093348482, 0.05872716263477361, 0.03314161094866934, 0.08724537933425558, 0.06773283645029991, 0.03303186885351616, 0.05414382329270725, 0.043181139570210254, 0.04678181410136242, 0.02357431233019358, 0.02921225788492349, 0.0806263643467138, 0.1186788019033209, 0.032701612179798466, 0.021156665245671908, 0.07979730399505747, 0.05938093823891494, 0.016273180315751704, 0.026045815395792166, 0.015313474202318298, 0.028129026796969197, 0.04132262175722469, 0.02071235148656753, 0.04151508985688129, 0.01276008591371318, 0.08176032003135451, 0.029319408687672792, 0.03475749339427679, 0.062047376207286314, 0.08124105031451873, 0.06493257058243598, 0.03504484148335553, 0.018598979203811577, 0.02430390191054152, 0.09395807921405762, 0.09843695097632947, 0.015868947319235775, 0.00838113787223495, 0.030931958650809624, 0.040942002463364796, 0.06217234813037419, 0.07763288344346708, 0.0271558097653812, 0.038891012720283, 0.04361242791938205, 0.03433516827381907, 0.052711445718042316, 0.02017377826925968, 0.06160925818426956, 0.045758818591674494, 0.03944465680228126, 0.01206413812695011, 0.02481057714190214, 0.05567878387087295, 0.02826800663775254, 0.03224275615667144, 0.03651419046124624, 0.02436617336746666, 0.0353880871778294, 0.04061442709738209, 0.059639718909297264, 0.020640611182898283, 0.04535794776353625, 0.05377971702405522, 0.04315285560404582, 0.07069373563412698, 0.026406774958295208, 0.010012413897070914, 0.0744911645268721, 0.036485063798365094, 0.03537035224238231, 0.0455510861901266, 0.05859403187529214, 0.05777540947160414, 0.03435600969579912, 0.04760983257344173, 0.02982378757048038, 0.037988691380427736, 0.05514169111847878, 0.030005166547433026, 0.021665860906303413, 0.06882739223299489, 0.057396716888873815, 0.07954846331549269, 0.053812532400291775, 0.0478855514478299, 0.6367919557998258, 2.9981222316142055, 8.354755351620337, 17.81695269769238, 29.86017454055048, 37.90807993181291, 47.079522763529134, 50.29006119697325, 49.65991673930999, 50.632131099700935, 58.552588878139375, 60.158991659841234, 61.23438788998512, 59.26985309969995, 61.940143877460116, 59.54924352707402, 58.98401821813276, 58.1278040332179, 58.35575649815222, 58.75769353681996, 59.37050896306192, 63.50105500990345, 58.93130548538701, 55.96328719969719, 60.703138151476466, 57.60235155782392, 49.96126459490869, 43.17885114300636, 33.35881694670647, 25.90849053475165, 18.931872690877608, 9.912096146614322, 5.301176934472976, 2.0261109764537504, 0.5451632435283353, 0.22776069780511243, 0.07670837619732465, 0.038230189107238285, 0.014139611082482002, 0.07117155233337995, 0.051199008124850454, 0.02827538214924355, 0.013707895639292417, 0.03917590932800405, 0.06172143260858232, 0.03441451583057642, 0.029566619515178666, 0.06329147235280083, 0.06507907723707539, 0.15313037340679478, 0.02800314705969105, 0.09362002759571038, 0.04431012334422239, 0.02538373156811201, 0.07047403693920182, 0.009755099327453684, 0.09203999423451963, 0.029039210114147396, 0.031832341788216464, 0.032315411935410196, 0.061968668333945744, 0.022568404411656723, 0.07422568441759195, 0.030416195701447227, 0.06868581918458785, 0.02982398292290107, 0.06568073971016754, 0.029264246526684974, 0.05979328506415891, 0.024264523076013695, 0.14434602622303272, 0.04934767238615502, 0.02661991594058852, 0.05081606375414038, 0.06032098940904103, 0.002523949205492353, 0.06544555837829268, 0.06212599215007598, 0.03876328671110734, 0.009765512377564466, 0.03908556457909365, 0.023359510852324388, 0.05261471179584342, 0.021413404291736025, 0.03751417652012841, 0.0668227239962547, 0.05736615381113464, 0.049449883837012515, 0.01498927441125195, 0.046577709126136, 0.032795021280405984, 0.06411947167268203, 0.04109227444015203, 0.02866911686836712, 0.06545539494724044, 0.06823020371338052, 0.03457292366111952, 0.026841110422185836, 0.027300665500543775, 0.03624410999398078, 0.06018201722913693, 0.2319559178525402, 0.17253988512581395, 0.11876544644755703, 0.21584525734426516, 0.19365443277262873, 0.19534946359213323, 0.13418855836554883, 0.11210513932089652, 0.13531214888057402, 0.1035521200467502, 0.21338398538289532, 0.15450429081195785, 0.12314345507371811, 0.1667064779828633, 0.2436018485816256, 0.17131353157662577, 0.09960818449936568, 0.08713982007916897, 0.12461871058950502, 0.13103178582124173, 0.10161388695480363, 0.1256857791374768, 0.08773520063128203, 0.22748326672421348, 0.2230092519593816, 0.14125619444154924, 0.10045851145180003, 0.12159991048036084, 0.12591090939578511, 0.13424112731891294, 0.1449225993166047, 0.1028564356027111, 0.12833050617407407, 0.12011007631137488, 0.17012327609042968, 0.16440251451586524, 0.16079132925839196, 0.22912575923387082, 0.15975671219489268, 0.12959685717378894, 0.08723673020159045, 0.08058946955228045, 0.18134752138247415, 0.17881668863757966, 0.13665549937755833, 0.18441869126212213, 0.12684016638705808, 0.12086461929063644, 0.1619098635931169, 0.14748235954152, 0.06670805595574841, 0.12672100141043627, 0.08111556511252158, 0.16487655440165153, 0.19388484137673534, 0.18252818544785823, 0.19355223664352972, 0.1491645047621381, 0.17145098307200018, 0.19502052075920567, 0.20369220705282307, 0.15615729404793632, 0.16126290234106203, 0.1264763359100588, 0.10938633158202134, 0.227941096189522, 0.1452888506314447, 0.10397214307299546, 0.23006536607300082, 0.08581189859297969, 0.18042933436170702, 0.08123068514490321, 0.179829916526233, 0.10459677286205754, 0.18756244031171646, 0.31476772420348664, 1.8717312668600392, 6.225816376747624, 15.234561254901273, 28.975158391460297, 37.949621754307906, 48.38142802638393, 51.89961364192348, 55.448852662117254, 57.005284447823804, 65.1700548971853, 68.08026529127552, 71.95164465135144, 69.36761856079102, 71.53526936807941, 68.84722202054917, 67.99439676346319, 66.60008045934862, 70.15193570044734, 71.21872625043316, 73.442474795926, 72.85348384611069, 71.33646011352539, 68.04421870939194, 67.80480507881411, 65.70220678083359, 58.435525740346606, 45.788749187223374, 32.066452849295835, 23.082766032988026, 15.662888000088355, 7.060360937349259, 3.8102048491278007, 1.3104881442362264, 0.4824078948267045, 0.2691911311159211, 0.14573869746058218, 0.2102869830184406, 0.0827545642612442, 0.2811626338910672, 0.20741096637662382, 0.13571413053620246, 0.15805700823905008, 0.12289552603878322, 0.13923735357820988, 0.12335017623920595, 0.11249704692032068, 0.2373791308773141, 0.19694948418726846, 0.2483705773709282, 0.09900168035059206, 0.21270915385215514, 0.258892274071132, 0.12855367524729622, 0.07429815633522888, 0.09957376416892776, 0.15628852490936557, 0.10813831306633451, 0.11599010141986994, 0.10362738818531075, 0.2255223880732252, 0.10075108809096199, 0.13094105036748996, 0.18147732732036423, 0.1406825018385726, 0.0983077196043826, 0.1332469443760572, 0.13333145919586384, 0.10687172457936311, 0.0790749060650987, 0.23569640342987355, 0.0965891009376895, 0.11549303293107979, 0.1335225062024209, 0.11454313753112672, 0.1930761283203479, 0.11780703981076518, 0.20101684416013382, 0.13134142323847742, 0.100442040561428, 0.14336477484433882, 0.14770176712303393, 0.11903718549517855, 0.08824106380944291, 0.2002521811593925, 0.13267556535861186, 0.2831012653487344, 0.12428495672441299, 0.08760645189472745, 0.16050396967799435, 0.18370534083054912, 0.14907292661166963, 0.13677416639702936, 0.17493197934762125, 0.22971463569950676, 0.1922363887030271, 0.18559210813574253, 0.15147853462446123, 0.1381771951433151, 0.15436239600662263, 0.140348793938756], [0.06493496077675974, 0.059484520987156904, 0.011410312727093698, 0.10243892534485749, 0.09825756382797995, 0.09900981620434793, 0.046523994871325074, 0.06751663877718872, 0.08041792714427556, 0.07269301061188022, 0.05266133590691513, 0.06735461884208264, 0.05678359757087404, 0.08959746844465695, 0.053816048743864225, 0.0861326213024797, 0.039436019160935, 0.0440072504833581, 0.06395097446417616, 0.030972463634586146, 0.05636302679176292, 0.06286166638376252, 0.013823054933680162, 0.021953957846328136, 0.029587131519351276, 0.06888897038034855, 0.022582193994293773, 0.03387216005414244, 0.019992041146202434, 0.07536087350379075, 0.029587776948427482, 0.04777761732017802, 0.03549136349090165, 0.031178962634575945, 0.012145775328991155, 0.03309937652140375, 0.01961143334366141, 0.09810999997200505, 0.015265993987991205, 0.04490073116856717, 0.038470070388528614, 0.048784827588186155, 0.055332439350745374, 0.0709727218735122, 0.08080250328226436, 0.03347038524225354, 0.041680323530829726, 0.04484686369617139, 0.026527497008623138, 0.04081530301200767, 0.005986357075838192, 0.0272163383722786, 0.02644051155526071, 0.013420801316838593, 0.015709312790403926, 0.04905855846441081, 0.02235321414416596, 0.024227342913828553, 0.04102194373826346, 0.05837411867574819, 0.0919219017809918, 0.055759391642265746, 0.043337088258516406, 0.060994587538223115, 0.04310497893921791, 0.052467550136028766, 0.04058191815631525, 0.07296691002744822, 0.01440244435798377, 0.034845865466782165, 0.007302895931887531, 0.022202547632097717, 0.07172741807035862, 0.048129592586549065, 0.05766672074734684, 0.044695082526173324, 0.020949507410067226, 0.040415738363780325, 0.04404847367456363, 0.7864240653091862, 1.692823505690021, 2.1561516436838337, 3.829898334318592, 6.593380214706545, 7.920033181867293, 9.032036892829403, 10.313482092272851, 11.731517949411947, 13.99115716257403, 15.132117771333265, 13.2467334693478, 12.538880975015703, 11.904124790622342, 11.24362805197316, 11.611604229096445, 12.783226986085216, 13.823158125723563, 18.390801337457475, 15.680143487068916, 16.427001991579612, 10.569779565257411, 4.921670950228169, 1.705002832797266, 0.6414601278881873, 0.25087721705917393, 0.05620491390507068, 0.030803782564978448, 0.023151060243347482, 0.01828998338521248, 0.10817205923939906, 0.0587730321492399, 0.02519603045056424, 0.012729050734290674, 0.06015495517321172, 0.014126263915621226, 0.05110673283437087, 0.05789237577588328, 0.021366460338955926, 0.06721932771465472, 0.027737917844206098, 0.05648040678352118, 0.0476878586285297, 0.045333325697649876, 0.02548443574097849, 0.024100011439933896, 0.03182333833988636, 0.017678296651631113, 0.0458902754490414, 0.04650573516564985, 0.023657116858709245, 0.014263944279763007, 0.04193524311807367, 0.030845130245471676, 0.09674198144385893, 0.01482503473638527, 0.026785126631899227, 0.042833626765998147, 0.02361211876925682, 0.032443463531953674, 0.013468542958669847, 0.04803619497726041, 0.04821737094091312, 0.02644586459463162, 0.031114247357172352, 0.05084877570850715, 0.056455976239615874, 0.02405602650176133, 0.05647518589431721, 0.09090324998983453, 0.022938683433758638, 0.021825550018899867, 0.04192495838769021, 0.049887059571882414, 0.021385551250028997, 0.06968780090251277, 0.04284063264006569, 0.10201651978516772, 0.0333226528469353, 0.016116488522159, 0.057692204662148035, 0.014706462520294854, 0.06033187551844505, 0.013886120249216836, 0.023284089496178974, 0.019980680062285355, 0.0405072782098526, 0.029274081180412925, 0.07496861350392142, 0.10255574609243101, 0.027342482409890623, 0.030373156881861152, 0.010709537628797755, 0.034526831981155186, 0.04793989772517835, 0.0881252849414464, 0.028159040206622694, 0.04871151680427213, 0.09738066128545231, 0.03800052360841825, 0.06456176104444651, 0.027194332496653643, 0.031114896616688183, 0.038297650809850425, 0.08726940385156101, 0.030819313082423423, 0.05940572501370504, 0.12862210222069295, 0.03767957490298056, 0.05838362582688851, 0.029835039486868248, 0.023917902764233372, 0.0348094686294996, 0.026971510078217235, 0.039946501849279295, 0.01706462575032586, 0.019789671360124505, 0.04915962461382151, 0.07106646039192716, 0.009059876451388964, 0.060737580361385504, 0.061452122059680765, 0.025771850862750606, 0.035641145171417345, 0.042712703617590095, 0.025978443708511132, 0.05824214470903239, 0.035461034069979386, 0.03614353414084162, 0.01698289374490419, 0.04601427061002582, 0.053792062530955004, 0.03878689754093367, 0.05673113203937969, 0.025947555043404142, 0.03777619008155119, 0.06685351306993155, 0.02742253668275812, 0.032128122590121724, 0.003646307994776796, 0.027839324902743105, 0.03743233534717753, 0.028511233808052157, 0.05955480189333039, 0.01350275069970878, 0.03149271011352539, 0.031209634879844326, 0.09329548976834744, 0.021367469659796166, 0.027246200479567054, 0.07782779153316252, 0.031825709382012006, 0.03292391174322656, 0.01745223751171462, 0.02013646212646798, 0.04178484473677893, 0.05133290114181657, 0.038258040233725504, 0.04931796349645142, 0.035123737048237555, 0.06857713429077018, 0.05538225421802171, 0.036744541608758514, 0.06757762703684068, 0.03343824402339036, 0.030111549347038233, 0.06297739545604394, 0.07738149935199369, 0.04176538993394183, 0.03779703916441049, 0.16818852103765936, 0.035890077781533046, 0.032852726853302414, 0.004186205586583744, 0.022843548720101678, 0.18520944721756444, 1.3492362585759934, 3.304456155146322, 5.6787300686682425, 8.63100297989384, 14.052758966722797, 14.85269400381273, 16.99442186663228, 19.51057134136077, 22.931629265508345, 24.66361261183216, 26.20344884933964, 25.580082247334143, 22.254094731423166, 21.75529868372025, 21.446166884514597, 22.54423245306938, 22.928922830089448, 23.624325721494614, 29.18819800499947, 25.366842592916182, 25.957363267098707, 18.25021770692641, 10.17531071939776, 5.694182245962082, 1.9371809161478475, 1.1472086992955979, 0.17824656600433011, 0.0550494694541539, 0.033432391111648856, 0.01474714944995339, 0.058748743331600586, 0.024931892910371387, 0.023683855242486444, 0.029533505364651644, 0.04517834228012831, 0.031280647399985505, 0.07503212219284427, 0.012318939928175702, 0.05291721310406443, 0.1029972349023146, 0.06409487258943339, 0.06095117716599376, 0.032624099403619766, 0.028510111489243088, 0.025071251964677247, 0.011066672497338826, 0.009161836050841357, 0.026106640861760226, 0.16309726923223467, 0.020264607568782185, 0.02351247945860509, 0.057474539930661844, 0.02395146699141591, 0.02503498536234181, 0.0604274373261198, 0.03229162873580091, 0.034359545191569675, 0.030673656785379977, 0.0507719868854169, 0.03816016484051943, 0.013317368913351769, 0.033615662325774474, 0.06382542797514508, 0.04295907749403869, 0.05473946814515418, 0.015455122901907852, 0.04121316311460349, 0.07427712722170739, 0.060317488387227065, 0.03265766937646174, 0.021680950923191927, 0.023762643555059068, 0.02238203245665758, 0.04458353629395847, 0.013945034325813815, 0.01061620417937276, 0.05806583723413849, 0.05695678323747651, 0.05360915903903304, 0.022380998237959804, 0.014326844886395962, 0.05462080878656238, 0.10591744715648313, 0.03424817132913778, 0.03190140269937054, 0.060044515938047445, 0.08697940892870389, 0.12158281905877015, 0.04450748674571515, 0.0347121256674009, 0.030927563221344066, 0.03792964132322419, 0.008917694363082129, 0.022820048973024375, 0.08832790753653935, 0.06423481770100133, 0.05966538285476066, 0.16949931279786173, 0.2927012663454779, 0.14587522965044747, 0.12372806442961579, 0.20520751364529136, 0.2721896911821058, 0.11231149276418072, 0.1745603500955528, 0.17027621788363304, 0.2612080965791979, 0.2050325085198687, 0.1325214437900051, 0.20351214574710016, 0.2110571924957537, 0.09801873591758552, 0.2564788979267882, 0.14208401373076823, 0.12506904005403482, 0.15196634877112605, 0.104999543588248, 0.1445249077533522, 0.1357057954995863, 0.18060741916058526, 0.17178842948088724, 0.18091564697604026, 0.1267234605526732, 0.15571700799609386, 0.14561479039970907, 0.1133491895011356, 0.1454976555560866, 0.0973697598542898, 0.21570075783998738, 0.16387671772991458, 0.16622293860681597, 0.10893134430291192, 0.14571464229975978, 0.14110009636609785, 0.27477251065354197, 0.16212030794591675, 0.093173781379817, 0.12303512258034562, 0.15255467365345649, 0.13285861440723942, 0.19025620463634693, 0.16941191748745982, 0.16134187068429687, 0.17954655592480015, 0.11698714953156249, 0.16766359759194238, 0.15302938769661611, 0.16880234132610983, 0.07578109571289632, 0.09385752251311656, 0.27681962016128725, 0.15921663553003343, 0.09873718849473423, 0.09219858975660417, 0.0635970609953567, 0.0725927986505051, 0.2553402001578962, 0.12459138423324594, 0.10787631865710982, 0.1474499999875984, 0.1515784324897874, 0.13477605587292102, 0.16153532320693617, 0.11456074223162667, 0.10316716086479927, 0.141354406913442, 0.1370023073808801, 0.21909959884660862, 0.10428674473998048, 0.24433854937313065, 0.26119746327880894, 0.1128147972086745, 0.09022955993010152, 0.15756472013890743, 0.12149485684330426, 0.1298953556726056, 0.7240013213407609, 2.1193137236179846, 3.644385179204326, 5.61828536372031, 9.738413595384168, 11.144811780222001, 13.5035212386039, 15.18768697015701, 17.15444084136717, 19.864023962328513, 22.06401667287273, 22.34989077814164, 19.00328140104971, 18.088861203962757, 18.651431068297356, 18.028001708369104, 19.446760262212447, 21.80744855634628, 26.508311148612734, 22.766150351493593, 22.03817021462225, 16.575716695477887, 8.25097433982357, 4.190268055085213, 1.384002799468656, 0.7813392639640839, 0.11755732579096673, 0.24566746677362153, 0.16078746817525358, 0.12993758243899192, 0.1951533757270344, 0.17946391035952877, 0.16404370957564923, 0.1449655002403644, 0.14156388599545727, 0.09619202224477645, 0.1386014086705062, 0.12105918264076596, 0.11805100817113154, 0.2136316769305737, 0.09564718817390742, 0.14879485201691428, 0.15603246768155407, 0.11457499912789754, 0.12702782728498982, 0.10992776422250657, 0.1515943977621294, 0.12085097526470501, 0.2657007426023483, 0.16833407774327264, 0.10786239883952564, 0.1781841145167428, 0.1632357319636691, 0.07033682293108395, 0.18409823668339562, 0.2379113628018287, 0.1660272184639208, 0.14042157229156266, 0.15341669110761535, 0.13078570305820436, 0.13675078539358032, 0.1672403646572944, 0.2392319298439449, 0.08183461523825124, 0.2062003176298834, 0.09199690944965809, 0.15743152809239205, 0.10576854264664073, 0.12909882341421422, 0.20060208415792835, 0.1139390695419523, 0.2208776582753466, 0.13801043312395775, 0.14603151158700067, 0.10361497756093742, 0.08807213376125983, 0.22260681065099858, 0.17793259252944302, 0.36209924086447687, 0.09655788285477508, 0.13313903323104306, 0.16086787676378606, 0.1476626353518617, 0.10042540113171262, 0.1371311327262271, 0.14919588372351664, 0.14353047966236068, 0.21346211102941345, 0.18914859471542222, 0.1918847237022654, 0.10542407887236727, 0.12620092730127996, 0.18165150507082864, 0.08256298099314013, 0.304427896776507, 0.24609027069903192, 0.24061235899646438], [0.023164922604337338, 0.05806754177977001, 0.0365516789738209, 0.09577780616499725, 0.02264952354673897, 0.04790617836519115, 0.04111800733352861, 0.033703666676076195, 0.019152929720979546, 0.02082242874518758, 0.018570900166166887, 0.07736337371170521, 0.04996510860960811, 0.03675316775878591, 0.04509971101558016, 0.013935029217522713, 0.08756892890819619, 0.09444610020446201, 0.06377440268894838, 0.0731573518245451, 0.02780019887723029, 0.025391974674177267, 0.0024312738734748097, 0.045096887981579195, 0.021956131620813283, 0.017211775918821656, 0.0837203176812299, 0.05046024655682906, 0.05085378975397156, 0.0441365048379427, 0.046525913921575394, 0.08851627323536143, 0.012976635987269542, 0.022338375021072648, 0.017309358283396692, 0.04654601989914814, 0.0236903440072051, 0.06273107137531042, 0.009277750899444425, 0.008302661740491468, 0.05216258202469157, 0.04565930377031046, 0.041980262274944016, 0.08991157215449119, 0.034511383818162066, 0.04556380324966965, 0.03462481079623103, 0.08534067024987552, 0.04586263499673336, 0.0020194058531835197, 0.061359379455567374, 0.11136704424936926, 0.06980847507234543, 0.022610738430352464, 0.06760024961324469, 0.06804435078295008, 0.025611569947232644, 0.050966182513342756, 0.05474776870781376, 0.07511743374409215, 0.03585149376322666, 0.036685250233858824, 0.025118496606967626, 0.029934877980380293, 0.049198783198071104, 0.07916607052808808, 0.0695165649296776, 0.06512150318632204, 0.0615394675743676, 0.08610621425172976, 0.06422625283800787, 0.03390407144662834, 0.03026821432755359, 0.012816070661609693, 0.014770917327804192, 0.007802746277452717, 0.06836244581086982, 0.04717681669600068, 0.05747013875553685, 0.080095925067942, 0.03583315744875901, 0.04086068606064205, 0.028322889176647992, 0.04806638267191668, 0.03292283155925332, 0.02636935156319411, 0.2018740352603697, 0.13346750108945754, 0.1470133605142755, 0.08257954381406307, 0.2863366078705557, 0.21010014949546707, 0.05068655276010114, 0.0802084097578641, 0.03676010085450065, 0.024671440253094323, 0.2250374237736387, 0.13682935537109453, 0.08762361226423133, 0.12189814850928322, 0.09104610240507512, 0.021481635912712065, 0.01685593573887262, 0.020658641062196226, 0.02210283171265356, 0.0792506006696532, 0.04301012576287312, 0.057870515456963936, 0.01409629359841347, 0.02462880171444868, 0.038938655728294004, 0.025871381005873124, 0.04306482061022713, 0.014757711887209406, 0.05378668076328693, 0.01623148406525293, 0.0270947621339151, 0.03853260614578763, 0.010544393970180425, 0.09911195870729224, 0.02222972460121157, 0.051333096494237264, 0.0829428993165493, 0.044785817979925105, 0.022811777138661955, 0.05589608088015549, 0.049735523550020116, 0.028765347087755803, 0.01841736657004203, 0.026573544638531826, 0.003362371390985866, 0.020342308036502332, 0.07867677783172938, 0.041630956824989095, 0.01353401379028876, 0.06130360059380051, 0.0441217040192456, 0.018452133555265687, 0.02234941817850115, 0.019887941288611582, 0.04492254169177144, 0.03963601790488728, 0.011035756061544583, 0.030967491723957564, 0.03795206471676788, 0.06093387507022389, 0.05273258591431284, 0.03821559513228075, 0.06839962405783516, 0.05078939240305655, 0.03398864372302929, 0.013077614994178857, 0.07583854464633812, 0.015138798494703107, 0.008040736279179974, 0.03127172056044782, 0.017990291704453768, 0.02578541061901037, 0.038931515788839716, 0.08233246513672414, 0.03907034624247782, 0.012626865138900618, 0.026418553560131022, 0.011604516015898798, 0.049598792177294536, 0.029747642261246522, 0.008839471040353661, 0.04950350999171215, 0.019292365384077834, 0.023206789309399265, 0.10761637736352221, 0.039564277601218036, 0.06218105088919402, 0.01526064860949954, 0.05934487848031906, 0.012435968477098693, 0.018093713574231635, 0.05674483352190545, 0.05802693528934352, 0.07319031658792689, 0.0697701859978899, 0.019376960643116507, 0.05477973372645436, 0.03533190228946267, 0.05258126822750896, 0.03412644378840923, 0.04560750090487061, 0.044558615453781626, 0.009229735381180241, 0.05085858163393794, 0.0412141666897843, 0.024688244391713413, 0.025423822864409418, 0.02370509311496731, 0.05699231822584426, 0.05394475534558297, 0.008669095958823399, 0.019540081829613736, 0.011798456919589832, 0.026014026577374148, 0.0259941695783768, 0.0394681450580397, 0.0267512061738319, 0.047574519750572024, 0.030041528910758997, 0.014226240304959639, 0.015737927131985706, 0.06928998676519241, 0.010641577969034834, 0.02042129361671546, 0.018655623744932875, 0.01366065099700204, 0.008683079936271234, 0.02217466777731334, 0.045998033376470696, 0.03120622770380109, 0.01834114082157612, 0.011558257711810932, 0.03700688841842836, 0.07702323067332469, 0.031105272637139407, 0.004487391138794802, 0.024244721618390853, 0.048866768352567196, 0.030122406728145097, 0.023044020523347204, 0.019930771349238294, 0.041341881207641096, 0.0765815120370638, 0.05401593257462787, 0.01913581531675112, 0.062481771042991074, 0.011872129680048074, 0.044933745727664044, 0.0372556678109592, 0.07617966827726172, 0.03470803092744562, 0.035427732227910916, 0.0933710643420777, 0.08799742486688399, 0.04596629052332813, 0.06545180199487556, 0.017433294072566975, 0.019208702837086974, 0.02265107870522526, 0.06206323805775854, 0.037195472452308864, 0.026693429737802477, 0.0033613512970341913, 0.057812097422297926, 0.014382826761462757, 0.06644259116822673, 0.008890170739182543, 0.059762427042568886, 0.04450533403864792, 0.11253951117396356, 0.023614530030998494, 0.04710082460435168, 0.07237097023115044, 0.09031278772219535, 0.26201739186240786, 0.29095878403994346, 0.4675947267922663, 0.2762346660658237, 0.8232375931355261, 0.6834927982380313, 0.9343359090628164, 0.846088647602066, 0.4000414000643838, 0.2159869223232231, 0.07619459933090596, 0.2510148677374086, 0.6486712828759225, 0.5777195288288979, 0.2514255215083399, 0.3224643644305968, 0.12053222906204963, 0.08587777449358856, 0.032837991152078874, 0.041936618245897755, 0.022499194113357414, 0.025805537664001028, 0.03289651260861466, 0.039525000273340175, 0.050458580315593755, 0.05090978695079685, 0.030436025887367227, 0.02473403921260709, 0.032992610677836404, 0.02938113430695188, 0.04202696682524778, 0.04284459714507384, 0.03821494012710549, 0.021745593422242714, 0.019463009553991502, 0.08582809369169897, 0.043962836535947944, 0.07434283458297292, 0.03378728900345103, 0.03275754425915019, 0.03767351897793912, 0.03285816990800443, 0.011411089348726937, 0.030142014748567057, 0.019675895812049992, 0.03102055288881304, 0.047831867836535945, 0.021165120941136154, 0.03481114636205378, 0.02999570727678797, 0.04625327855108246, 0.027636520361768144, 0.025286641415028323, 0.03267093801931028, 0.014600749090013486, 0.019849127443927913, 0.031039051996964603, 0.02164096687920392, 0.028349550951632763, 0.060584868394559434, 0.02452811669378031, 0.03348113728627082, 0.04941994512093164, 0.06014538290459783, 0.030506739633217938, 0.06829983344481838, 0.01640234082456558, 0.02454941968373474, 0.014496060302330843, 0.05210569616587413, 0.037799950298522754, 0.03183220197717029, 0.04044722457746825, 0.06694920511255342, 0.013029969113338138, 0.06920405468272586, 0.011670380425188812, 0.04312585100471493, 0.028017752525967457, 0.05910062666742071, 0.03570245135755789, 0.053884632765285434, 0.03470569435927657, 0.017995472374041716, 0.014792128387207707, 0.028050299771430514, 0.02353566319441363, 0.0929964013818291, 0.05634252244846956, 0.07273522205650806, 0.058347094924219196, 0.04061219778152243, 0.11687293348293151, 0.17264324570855788, 0.2600853794044064, 0.1324572303001919, 0.13383696997357955, 0.09388051281172423, 0.15312505675660026, 0.13867590306026323, 0.10349460216539522, 0.1468631459940826, 0.09518722898416943, 0.20049006678164008, 0.09298379923547469, 0.16557018573005355, 0.1553836984619979, 0.09748988244081698, 0.15368243168678977, 0.19619280382269816, 0.15649516946606098, 0.14766272728241261, 0.14812967319402004, 0.11077253703748989, 0.08182658663680477, 0.19324361046235408, 0.15768282025331454, 0.0962147061082144, 0.12765749793259368, 0.12743534775631082, 0.1959180693712927, 0.14836524523073627, 0.15173255405839414, 0.1778526589154236, 0.13305867060778603, 0.09581811005069364, 0.1427484264657382, 0.26253974125269924, 0.10389877483248712, 0.2516454500296424, 0.14054486648209635, 0.22937276130241735, 0.17533104986913745, 0.166666901880695, 0.1030885985481643, 0.18124915569299654, 0.06869214707084241, 0.1008025998429906, 0.09851377427337632, 0.18868851295161634, 0.17440299563590558, 0.07806725529653412, 0.15598500087376566, 0.19136899331163978, 0.16239550205007677, 0.15939891849073673, 0.12408761247511833, 0.14426477493778353, 0.15100087880367233, 0.13715134212566962, 0.10701630835331256, 0.1766800847385199, 0.11936766050395467, 0.16887991538932248, 0.21702084990759052, 0.24049825786102205, 0.15821399497649363, 0.22090421088280218, 0.12419002310883616, 0.10971738115674066, 0.18962110242535993, 0.21334813246803902, 0.1736783224248117, 0.15595144622268217, 0.07348162152113454, 0.10412473246575364, 0.10237147130312459, 0.16652024200847074, 0.1912695091337927, 0.18736655162947793, 0.2974749747062883, 0.1690580155099592, 0.2629485870561292, 0.20785627796524958, 0.172182091421658, 0.1842619037075389, 0.22495582008794432, 0.16225264197395695, 0.2954368743925326, 0.19524873835184883, 0.4393071446928286, 0.3324870008134073, 0.49232946889054396, 0.4187847523679657, 0.2225027605891228, 0.19898596039462477, 0.16906042102604144, 0.2024253580959574, 0.4697779241588808, 0.40038987813938054, 0.22140668795233776, 0.2490152710027272, 0.2020035194413316, 0.2605728258288676, 0.15876963854797427, 0.1321437777650933, 0.12419754609225259, 0.12620818981480214, 0.09758486968254852, 0.17780939026946024, 0.13257271039389795, 0.228834921614297, 0.14759909601942187, 0.14368812523541913, 0.15823009814466202, 0.2059303942106424, 0.13585469234854947, 0.183604876060159, 0.16839430757587956, 0.1376338855874154, 0.12156171333645621, 0.172144828905021, 0.14172211379533814, 0.14965781942009926, 0.1912592895208828, 0.16028204932808876, 0.11538755028478562, 0.18461709271275228, 0.1870948049209772, 0.13308013639142438, 0.11610868416966931, 0.1345575063098823, 0.14940013808588828, 0.18977078068400585, 0.19538822764110184, 0.1570387854571304, 0.20265293217474417, 0.1880077672221007, 0.220039879843112, 0.09835410622819778, 0.11194826749664162, 0.09298792844938655, 0.0890596823826913, 0.18776574472506202, 0.0889826522419049, 0.1067109150631774, 0.1112148532223317, 0.17392900171539477, 0.14333270640382845, 0.17742781719613462, 0.14989579697289776, 0.18401199050488012, 0.08219549627674204, 0.08667292779371624, 0.27522830232497186, 0.14764417263288654, 0.11937067889037634, 0.1474917211359547, 0.07999791943978879, 0.15072884098176034, 0.3309270925819874, 0.20319581272140627, 0.08200880064959488, 0.07180375107113393, 0.16728508887031387, 0.096206079958187, 0.15969688072800636, 0.17285168291099612, 0.1242637667324274, 0.16241148264417726, 0.1002722678165282, 0.13176130070801706, 0.21198955214312, 0.19454194563290766, 0.2647847159495277, 0.13420535101284906, 0.19114097490185694, 0.18290484023670997], [0.03366351217752503, 0.04181746859103442, 0.058696599557034435, 0.05439291678128704, 0.004310154782292704, 0.061382086301643046, 0.01858587910030638, 0.030139147664510438, 0.02784603391773999, 0.023238742836721005, 0.0662082372113101, 0.05069800194412951, 0.029210520780555187, 0.028683659132389773, 0.06186782051959346, 0.022176967956305995, 0.06841598003501854, 0.08082853494993142, 0.03221510421304453, 0.038493382444064465, 0.04342045394643661, 0.057919380375214165, 0.0537415198801506, 0.0416253567222626, 0.025614272322385542, 0.046333070438835895, 0.02894495640160336, 0.08938871714616976, 0.06917419257543742, 0.020975585043009733, 0.05337223868757006, 0.06384065014220054, 0.034303931038706534, 0.015219145796201644, 0.07616520453725131, 0.03571090130736271, 0.016217671499978152, 0.05152362639144544, 0.055402965405054634, 0.028406072918686177, 0.004404884426959701, 0.04633736819209111, 0.07514295979372917, 0.09838347037833545, 0.07335461946504732, 0.008165850886143744, 0.07395534731087185, 0.03510685247038642, 0.13288421706566889, 0.03924285775170692, 0.043476428160624164, 0.029214414422430342, 0.020886829926542217, 0.06009409714850688, 0.02499317419865439, 0.018118144118136937, 0.03397427574400941, 0.048855146798755855, 0.024992764341614904, 0.07762673175743512, 0.04786141584777544, 0.016653420396089073, 0.0354844993431001, 0.0242633069114339, 0.015110267465183092, 0.035602603287946795, 0.06027142352034008, 0.008546991119792145, 0.029849800085949323, 0.05537501851757688, 0.058327475412478375, 0.03126044949186185, 0.042564262590941884, 0.030821415993775574, 0.03515549522313861, 0.041728878183470625, 0.12657503101734385, 0.03234997399211411, 0.04662813303331214, 0.06930798217053376, 0.032144677750165426, 0.024897030164157192, 0.036824896571136294, 0.04462685090519729, 0.08514633672612329, 0.01932649460110453, 0.05343811841861856, 0.10459458951147334, 0.020500652664791674, 0.06756533898653523, 0.06276396719077904, 0.03144506519029458, 0.013018806254671467, 0.06809101319841801, 0.018362849838130416, 0.06602992258605457, 0.043735024969904654, 0.09841971399803316, 0.14478219072184256, 0.01914619580812512, 0.126013511551484, 0.13065621887724246, 0.11562232559006061, 0.018623859824372396, 0.05009681061511079, 0.0864896182751944, 0.0394485293767385, 0.030164346211559834, 0.047784152050172134, 0.035838780534123225, 0.017665357426590016, 0.007239458106097676, 0.03962443082503254, 0.03754324572641523, 0.00840094316029741, 0.03318794394632982, 0.012535693015031999, 0.04158598746383383, 0.01880402646718487, 0.015979430604455693, 0.023485492096252503, 0.04212435958306155, 0.041287542591171886, 0.08759868376317524, 0.04145449996294995, 0.060508340041363434, 0.0232918078320161, 0.015240903650861115, 0.06355781048055618, 0.028754658245992278, 0.04085741486520537, 0.03136729194422162, 0.0830312215933396, 0.03631718329063827, 0.048606850041617314, 0.0351140613577539, 0.07227643498129423, 0.05124471676085265, 0.019892989808032592, 0.06344128084639389, 0.00501644284081375, 0.0657736202101073, 0.021070037938414082, 0.025276178569202463, 0.03019157106116895, 0.019722901051864028, 0.07696711473287114, 0.008049960935398216, 0.02540648629468295, 0.034637179285768545, 0.056766061818287264, 0.009133511865060897, 0.016078191786824216, 0.0058068052185849565, 0.022607279543374336, 0.0740880643828742, 0.11631504527383274, 0.07682721175613903, 0.09272431759464164, 0.006774406825687977, 0.05598582425004533, 0.02395014932018615, 0.034850994425435225, 0.08446835657401432, 0.02723365387458715, 0.036220598755584615, 0.060366770823396025, 0.06899431513081636, 0.04116413731788916, 0.012844340263625548, 0.025287512840042194, 0.0418900209479034, 0.04035807109528011, 0.022178448421219667, 0.023636028373373613, 0.030133867403492335, 0.057315553703735915, 0.04275533258013668, 0.0037857558674013786, 0.027711709976316463, 0.017175917258305896, 0.08111695173166453, 0.04938302734386056, 0.021640754289804928, 0.040489129586926395, 0.07737799833017973, 0.028604035783979683, 0.036726212955170104, 0.037238637676402446, 0.09862118746123968, 0.04948947143049971, 0.04994061294822924, 0.07008171565229855, 0.012524136578694228, 0.04074644319893372, 0.02458906090337663, 0.06228113644606164, 0.013189341257055922, 0.03356589725421321, 0.08673131135442565, 0.028858332924785155, 0.04064702413856022, 0.0350408271826323, 0.06642148544591281, 0.032955872931427536, 0.058724600070666884, 0.0350776951639883, 0.03263137340846081, 0.0296649526459195, 0.030108109612258214, 0.009836806435017817, 0.03619278210305399, 0.05838118583684968, 0.05047182597580457, 0.022854735519015984, 0.023720481906146295, 0.04774238110610074, 0.06641954724346438, 0.05582051396730447, 0.06768705503594491, 0.03915013429979163, 0.07054058699718407, 0.029504574054191192, 0.024306832196851893, 0.03180196065635931, 0.05267667681759885, 0.0344356483659677, 0.03878094886820163, 0.022186115046121904, 0.03239330009467179, 0.03540604044833491, 0.039738654534542756, 0.05210822808646387, 0.01366813950646188, 0.016411183394431587, 0.03191552169981503, 0.027719150605281035, 0.047532323627702655, 0.03383559850795615, 0.026712457446621794, 0.017001341142120863, 0.058984667768762, 0.009605095481439944, 0.022759223507056316, 0.02873253554195887, 0.06089079028536236, 0.07060380457269569, 0.022293844245254033, 0.09605534449820557, 0.016560928685770884, 0.06525347715303784, 0.051268645517167546, 0.05196048419982676, 0.01198186794476163, 0.018855160920910777, 0.010939864836062395, 0.06938069157542721, 0.029654598967622847, 0.06214218724879527, 0.11412113033715757, 0.09495241537449822, 0.028266106739700324, 0.04201709961278304, 0.05917816242623714, 0.027103656414715994, 0.043224415877052856, 0.05486529808671725, 0.045421467943777966, 0.05833406376862719, 0.033083212066201434, 0.03042413045712296, 0.0338426580081784, 0.1506566908210516, 0.07311219094140876, 0.09804108270233679, 0.029195185615530903, 0.03491023600461983, 0.0812311141541408, 0.18268157157205767, 0.033860749174510284, 0.03977040121812494, 0.023184607233551723, 0.05645871500394518, 0.013525902834390442, 0.0645595930156208, 0.04003358306363225, 0.003282072927592503, 0.05408011159048446, 0.06480938364421168, 0.024663390584229946, 0.009396445689602725, 0.06299777339482981, 0.016903264650834665, 0.031961714886429335, 0.04837230073227998, 0.0041238388474730235, 0.016363199477294282, 0.02320694252698412, 0.0407432371209706, 0.04253347734770468, 0.03565393883975283, 0.04135429949289368, 0.06154584525633724, 0.029478682197570324, 0.03791830705238446, 0.06774782113009883, 0.030549322630489067, 0.011475923369758794, 0.07497128715077717, 0.04526831930683506, 0.02127105557930566, 0.024160515148973754, 0.07020759155913707, 0.057314347115255175, 0.03645433984216183, 0.05609006583390217, 0.04561617302017347, 0.018208900639306635, 0.03574747051442823, 0.030332634661106334, 0.018602051216387944, 0.03614884313015688, 0.06536152619387835, 0.028380397481903918, 0.027784019100269484, 0.04344006196685857, 0.029739858807935834, 0.07296748459339142, 0.02481532305659306, 0.04985042907778294, 0.03846910511774402, 0.020768331446414514, 0.056203209359439156, 0.024163351589513403, 0.04493239358247769, 0.02987902059460119, 0.019191869970170722, 0.05938389916874229, 0.021722622275833162, 0.04767764667649904, 0.06329870805324567, 0.029383472790340745, 0.0418966437780088, 0.01649845421554581, 0.025683162778976466, 0.026762693662256486, 0.01729968642335265, 0.07606137664087358, 0.05184103577067295, 0.037932291987442204, 0.08665473320551458, 0.008883912758451075, 0.1938039578136898, 0.1821319647734204, 0.13676034617087535, 0.21760894496354366, 0.13493180154792725, 0.20074149683838893, 0.12388272992064878, 0.13190644372615123, 0.16657996622304763, 0.15342226822770413, 0.20936349466923745, 0.12225095498105212, 0.12708540645337876, 0.14861836068091855, 0.11720749940122328, 0.1251256616125184, 0.34331681807675674, 0.15216301886304734, 0.1080080934409653, 0.17638575375801133, 0.09147318876198224, 0.10107161927848093, 0.15193311587697075, 0.21480301004504004, 0.11237424302605853, 0.12407962217806809, 0.16487759628122853, 0.2660392921778464, 0.1927113478943225, 0.09356706793750487, 0.1435459239949142, 0.14546800795341694, 0.09818610314640308, 0.15122646105385598, 0.11367021098492608, 0.14091974394696374, 0.11737420779442596, 0.2605727032547997, 0.10203702795890071, 0.18860862530287237, 0.15264585343820436, 0.17357031934924666, 0.11742643200822415, 0.2518530445353639, 0.19231187900708568, 0.10098803908594194, 0.1235419893336873, 0.16783996635387022, 0.170287448732603, 0.15407774837747698, 0.17694728088475045, 0.1264680315169596, 0.10857310626775989, 0.1346160507490558, 0.11663281088394505, 0.14822486727949113, 0.13836988157803012, 0.11930236683016825, 0.10410554196325042, 0.12858491631284838, 0.11548921781321687, 0.14163743043618818, 0.09207291303262596, 0.15528082817552552, 0.1489744536698826, 0.15931541490699017, 0.0796568724176576, 0.09733027568267238, 0.12564184399501932, 0.20976019031818838, 0.13564748088679007, 0.1013472117483616, 0.1845773633929991, 0.08793022363416611, 0.17881935462355616, 0.28203971263381744, 0.11079957228033774, 0.16816045157611373, 0.08855918182000037, 0.15860652310713647, 0.21317009363443623, 0.06711492525233377, 0.1884214393794537, 0.20602134416901297, 0.2538560733439461, 0.09990366461176066, 0.2070634535724117, 0.15254820787137555, 0.08746982011343203, 0.15712008270765507, 0.21289013446338717, 0.12551377707671735, 0.221804088402179, 0.1530570128271657, 0.11005439089551089, 0.2230172192737941, 0.24274439701149542, 0.1897219655614707, 0.2179227958643629, 0.0835951618970402, 0.21533167199982753, 0.1758309682050059, 0.32642810335082395, 0.16152099736275213, 0.11873293367605056, 0.16529065556824207, 0.09194902895439057, 0.11549854876413462, 0.13673938600526703, 0.29892091969809226, 0.13668646465145773, 0.23973092887430425, 0.15325820283784022, 0.13883907978813495, 0.13338448780198253, 0.09442423605510304, 0.1311401872625274, 0.16648990492666924, 0.11926168756138895, 0.1049657897543042, 0.08053847874004035, 0.1532322477789656, 0.19810926469583667, 0.17298196382339925, 0.1247830211275047, 0.0974378957142753, 0.1307485784373937, 0.14796289585290417, 0.11633068112836731, 0.0971446679003777, 0.09492293631117191, 0.11739146009448076, 0.18356191384936535, 0.13208259798346028, 0.13003361922117973, 0.11942916970339515, 0.11976937402880962, 0.20683972525500482, 0.24842245684516048, 0.1639043735039811, 0.12826763333812838, 0.10251171901942262, 0.11786912357614887, 0.12074433582564517, 0.14271697089556726, 0.13709724099645693, 0.15136316178306458, 0.11252813476828799, 0.08507905888461298, 0.11362571659828387, 0.1580831778025435, 0.1947052296130888, 0.06091343967484371, 0.1913762098598865, 0.1246637718812112, 0.1925421803588829, 0.18905887049773049, 0.18221517724375572, 0.1436051119479441, 0.10338941063251227, 0.09737765822078913, 0.29989452551930185, 0.2115496184917227, 0.22873306256388465, 0.10096955338432904, 0.10479737298503038, 0.11338651330480654, 0.206691533206932, 0.12908440563947926, 0.07897876969148075, 0.132233563269819, 0.24009097487695757, 0.19638533703982833, 0.11238258572355395, 0.17739968644755502, 0.11673055604220399], [0.058930758161530386, 0.011196129865223363, 0.02525294886811847, 0.040703289466159004, 0.0057209971466011585, 0.03774740049735673, 0.029315133917055307, 0.0579614271109383, 0.04211009885635107, 0.016453549971864108, 0.01589172407083454, 0.0347196065159815, 0.02472144472713192, 0.07700911933375944, 0.02467441458946034, 0.031305261804992636, 0.010035905983268974, 0.06031882138021531, 0.008121030912133715, 0.03446347650981719, 0.007278055530942737, 0.023859260648849513, 0.043032449564986655, 0.037597906099812645, 0.06993301032531647, 0.02113899542769838, 0.038952039284331184, 0.048992483380941615, 0.036559290057348634, 0.06444083406559883, 0.031668036995876225, 0.054681310580382426, 0.03922264069138516, 0.0486868296209122, 0.00722943815485304, 0.032369333033960675, 0.0216860645600865, 0.050341652315710826, 0.08592933987177188, 0.03553806038032617, 0.0495808350763494, 0.05334104358729336, 0.076328442552157, 0.03176117605049043, 0.002791814002839308, 0.016710704620627147, 0.018821213649766102, 0.039468030144851056, 0.02103367557508811, 0.025229809182365576, 0.027016628826517734, 0.14236766544561233, 0.0620063521989411, 0.04678683580770608, 0.0245480349798116, 0.03942157074268307, 0.04252178684598015, 0.02738398713840833, 0.058316355646257444, 0.04251325262650367, 0.034276914948056784, 0.03415729414912001, 0.019190638483832442, 0.04044853841825839, 0.00671204966267631, 0.05946687032138148, 0.047502760294704675, 0.028826950132967006, 0.04033880015354484, 0.04410360136159486, 0.08256072869464275, 0.037829130587558595, 0.05408272778074588, 0.027051459013995145, 0.017317452002316713, 0.04025919595733285, 0.019082242788206187, 0.06341723334645072, 0.021511243295765693, 0.0732631792104052, 0.0592747469612908, 0.05511326159560873, 0.017390732142713763, 0.03985516118606733, 0.01068397423237442, 0.025019156070606365, 0.09240480530406199, 0.08928416912714321, 0.07049862836157123, 0.038868780848720384, 0.030512797473479184, 0.008106850624655285, 0.019987546125306718, 0.02060164986628919, 0.09907982897974792, 0.043227736868204615, 0.023786037965046785, 0.046648633546165885, 0.02669498872672839, 0.07035913907231824, 0.0050939857817044664, 0.009388599034038284, 0.023042467280080723, 0.06841601067853552, 0.05530576033878231, 0.02810226543055427, 0.08088826682538756, 0.05074037809766108, 0.038243928894160256, 0.06492917681293142, 0.06621553036834925, 0.027918207061086452, 0.016725963176859003, 0.01867269984476509, 0.027573833302144083, 0.010554101261790964, 0.05876842413037535, 0.11880151386703215, 0.02760878606368938, 0.05087108801930182, 0.05457189407259707, 0.08859624515377706, 0.03214847754626986, 0.03277379298402417, 0.0757277759933664, 0.037463967117571065, 0.019022313645109534, 0.041867287288750374, 0.044489495170813416, 0.077100352744662, 0.07562566413393906, 0.03921537051698373, 0.01764193428830514, 0.009079831126596659, 0.05897159447833415, 0.07318150657679766, 0.009431381214169726, 0.01764873331863313, 0.04296708694328705, 0.06856368178681982, 0.03719761366805723, 0.04003081365578598, 0.04130033625950737, 0.017429065267224948, 0.050884563505889914, 0.051521864389219595, 0.07047246645895705, 0.01529687116177933, 0.04893935901383239, 0.06090545703867271, 0.02632066092994665, 0.023467274525413112, 0.016037759581400503, 0.029279221630384846, 0.012312789199753635, 0.03631156403571367, 0.03209936364944423, 0.013586675631813707, 0.035264306521463784, 0.014440612773591233, 0.05740194926939665, 0.0855304838548745, 0.06019622432969271, 0.026240016769377456, 0.024835444355924285, 0.0381790220947756, 0.014233497072822385, 0.0725986515622466, 0.035700658711815075, 0.013043229137697529, 0.0791791016836801, 0.024348398212403543, 0.05817629562150087, 0.045530892112442566, 0.04439517059513638, 0.023637160268281738, 0.05603450530719373, 0.006335246444289243, 0.045583801974932996, 0.029537171095369325, 0.011476647322847238, 0.011097178118483675, 0.10756245243453211, 0.060466684010480685, 0.04235630802389595, 0.0034322785898937935, 0.031207692846956275, 0.04172698594629765, 0.03657630103970728, 0.12830478860245598, 0.04990120921584387, 0.05461710092100886, 0.026360600923879013, 0.008788655470726232, 0.01840988955190105, 0.049608575120087595, 0.038861227221786976, 0.07323686409020617, 0.028336136752078613, 0.017269125260833292, 0.05566108723982208, 0.0545254193486706, 0.030296555750312346, 0.03970869666626377, 0.06454194234984537, 0.009120602325926866, 0.043792029572350365, 0.04768756751511847, 0.013768132175168684, 0.03597760332688209, 0.04448946452729645, 0.08011395111680031, 0.023595383578550913, 0.0277198956257874, 0.11197220008339613, 0.05001748604099116, 0.02535573105447956, 0.038270967967447736, 0.04573464851766344, 0.03118637836568298, 0.067323898716319, 0.03142700466747967, 0.03666175431722114, 0.09737944320565271, 0.02618170215658123, 0.020089175349341768, 0.00782195928378872, 0.03379080534702347, 0.05691954370347723, 0.10558894099367243, 0.023338744123916955, 0.0267420782362141, 0.05618737432204428, 0.008199843164953974, 0.017812009637935028, 0.05233733051065957, 0.03697745148993788, 0.0046821062700943125, 0.013552718784569973, 0.00454878542504664, 0.017293935018261115, 0.027741790418663335, 0.02159817320775361, 0.03482993083795713, 0.06013602131016313, 0.03835313472776644, 0.04404828981346181, 0.03807666125677286, 0.06531210586188302, 0.04515491914184344, 0.06341573181411912, 0.11290275942414038, 0.05029859434392664, 0.028439851650487513, 0.04587074786785149, 0.04959703017506869, 0.025856128195300702, 0.04146057504018949, 0.04614648206399814, 0.050890443230708765, 0.04276270234596826, 0.06257538698733815, 0.01885098765694326, 0.04586199531331659, 0.023841020095372395, 0.03345603258499215, 0.041119455239705505, 0.03463108122589127, 0.009407868060553748, 0.04575878794815752, 0.014306111674335216, 0.037277409386250286, 0.04148556865871914, 0.049350572028948415, 0.05877876631735314, 0.05148314247508684, 0.10716477619303812, 0.04323094294616773, 0.03517265176220286, 0.00959556247483218, 0.007305768761603583, 0.06685925872936364, 0.008067679591476917, 0.017268843723521117, 0.0304966387639363, 0.033408282324671745, 0.024652874112249385, 0.04107838526608483, 0.015102335582337072, 0.05222524035601847, 0.027686505683607636, 0.04156139604146442, 0.024138174109881925, 0.04645533041067181, 0.05429022269503725, 0.03082012322040335, 0.0689352420909751, 0.02387725030853143, 0.07746966075031989, 0.013468759378508456, 0.07570813349898785, 0.1089635736218864, 0.021651102222442146, 0.033628038476191224, 0.01807229184064894, 0.07044641946953151, 0.02213300217033154, 0.01686949166469276, 0.023010695698641004, 0.051016388085460475, 0.056104146529950445, 0.04063645212520515, 0.024019869066955104, 0.015526024339300011, 0.011762818509352305, 0.07199971636216487, 0.05744617552526536, 0.03453310241081542, 0.05363299586479703, 0.07980518703979832, 0.02175067258518069, 0.010755715493653572, 0.04501110145581826, 0.040045989857565974, 0.0669977214607981, 0.03508731722831726, 0.018704310547740712, 0.019334343171888785, 0.03322723276552654, 0.028408704430706082, 0.06920501229263122, 0.014419017712615672, 0.0157833494426262, 0.008530634184998852, 0.06267415870341563, 0.0700364628386113, 0.012772847980921789, 0.07424221659499793, 0.029071134913171974, 0.05259955857670116, 0.007397289934282702, 0.015175957589470332, 0.009215195989987303, 0.061244826328249714, 0.007306948058202022, 0.05705675388115549, 0.060316120920282226, 0.07966718396111842, 0.028584837620597214, 0.08042519731867699, 0.023985241892777627, 0.0875421924396388, 0.13807761903491714, 0.136353446230773, 0.12285084779103919, 0.18143958982921418, 0.2092360176386372, 0.20529420415480293, 0.29985830488224186, 0.26713032395608965, 0.2034412060053118, 0.10994251907592821, 0.08333979414836054, 0.1658322644089499, 0.11915877130964111, 0.17101555401759763, 0.12697413218237702, 0.19019349267886532, 0.11644187879057662, 0.10064120809998243, 0.06691652380170361, 0.13567262389246496, 0.06800885026853892, 0.18907403903863124, 0.15676369860527978, 0.17104333236573205, 0.1513194794496221, 0.14871629736115857, 0.14997799820717306, 0.09622833481238735, 0.1534086778279274, 0.1256361519617419, 0.18787236884236339, 0.17374333264606615, 0.17632460461989527, 0.1768563002828629, 0.09764156784982451, 0.10039808243633279, 0.1099149016062579, 0.1923407298783141, 0.16862931270753184, 0.09557131482588668, 0.09298743049223578, 0.17363338370717343, 0.16492397524416447, 0.08920791273516032, 0.13959416668982277, 0.08785062709883337, 0.15170105252294772, 0.1358365513865025, 0.13343063693854118, 0.1869154790596616, 0.08788058879755198, 0.3135281326549669, 0.10809885187735481, 0.18060055501278371, 0.09971976520553713, 0.11412697558801983, 0.09502813550493411, 0.10795605308826893, 0.13104454884606023, 0.15052832512845918, 0.15864252923957764, 0.20404335111379626, 0.12664037831728497, 0.11420720797632972, 0.08259580019981631, 0.1604716714111067, 0.13383816507074142, 0.19408126632052083, 0.10545165037676212, 0.10863743467076172, 0.10701679098870485, 0.224193302133391, 0.17451610085704636, 0.1398109082853602, 0.11389737903711297, 0.23165286879145333, 0.08046046034583161, 0.12015545169913, 0.18141317511758498, 0.11080210037048786, 0.22748322075893804, 0.1527447094239535, 0.13467637251221365, 0.1538760680705309, 0.19157894736816808, 0.1572187395105439, 0.16641193249773595, 0.12794301890197302, 0.18378568813204768, 0.18853206247571977, 0.1312862802296877, 0.157800491358484, 0.09156485884300164, 0.10704180375943262, 0.1805063415198557, 0.1784201462062136, 0.21209525695491224, 0.21248948580074697, 0.1633118811033426, 0.15991840271219132, 0.15892884694039822, 0.32464756179721127, 0.15740931154258792, 0.14025370710559432, 0.11560477451571535, 0.1225591444921109, 0.16532595689979293, 0.17997623931977058, 0.1688758704450823, 0.16783486420829452, 0.17105229559444612, 0.17184898107042237, 0.08312653059199934, 0.1243485113786113, 0.10626482206486887, 0.11482436840813007, 0.10779463836262304, 0.16658410309783875, 0.12663711478272754, 0.13356591274421062, 0.19594315108993363, 0.15708721753570343, 0.15824413287543482, 0.09581919789554612, 0.21862761207645942, 0.20893856101939756, 0.15205247237557365, 0.13846579578615006, 0.1884609082293126, 0.22259003332545682, 0.19758930549986903, 0.08477190359225197, 0.09982486480786916, 0.1401840850350357, 0.15821949548778996, 0.14807077635440136, 0.09843853677833274, 0.09541632757792551, 0.09264690440989311, 0.14633698148592827, 0.14075325771925912, 0.13091860399130853, 0.12549020455128726, 0.13542094868758034, 0.15222136411936055, 0.12076583225280048, 0.1473477885367409, 0.126150066723987, 0.14723264552172155, 0.11497634493054883, 0.15035597066725456, 0.07558691540672895, 0.12293456587940456, 0.21666510931907162, 0.14775510216432233, 0.14457667997527507, 0.19501950952314562, 0.11262711332810503, 0.10566162741592816, 0.2671590982185256, 0.12074122550867258, 0.1426285337055883, 0.1223241163778209, 0.12418852157650456, 0.23873028014936756, 0.1403244170210054, 0.19740967320338373, 0.22761152516449654, 0.09708854429904493, 0.11404829069731698, 0.2597410382042008, 0.20276609868291887, 0.1812635734677315, 0.14033989199707586, 0.19420966265663026, 0.22239599857599507], [0.04138170628838482, 0.0221489061556396, 0.029222094453871254, 0.043092261879674854, 0.051010592630313295, 0.049898290420852365, 0.050581744271180326, 0.03540350469730554, 0.01928361282954293, 0.053810046444977486, 0.01554684948191167, 0.01332941373074127, 0.006516045588444198, 0.01695931738903446, 0.030039085090280544, 0.0551686842264908, 0.02270384301101008, 0.03435553855172569, 0.007226821485786669, 0.0905987760052085, 0.013720198053746455, 0.03659402448383551, 0.032863095853357546, 0.02622767317769749, 0.020287362295353127, 0.04287846206176666, 0.0355440626792129, 0.025310326938427267, 0.013606810337683607, 0.02030381977918648, 0.017697533119409796, 0.027198570878094724, 0.034611802623276754, 0.03281896535847937, 0.03035021637896857, 0.021753330910277945, 0.05935550411982883, 0.020791428997331572, 0.0252636032359254, 0.012775728471517082, 0.040065276121059736, 0.007250869943339739, 0.11621922299626375, 0.016693793229698654, 0.051014446052572424, 0.041218962400190295, 0.04099265619691822, 0.04916052093669292, 0.06198476001079525, 0.031058238669028206, 0.044241638914231336, 0.007710891856526536, 0.020093151345668782, 0.04275060964808349, 0.12494814371870411, 0.06383172138744304, 0.009506589023306245, 0.04757504452080016, 0.030433886586838675, 0.014494508974284176, 0.027142657950941115, 0.06667390375608398, 0.05046866203267729, 0.07390981870553187, 0.11220614801371291, 0.09120346452560156, 0.017079190996986245, 0.06191242215854507, 0.05448186341973563, 0.03694287794191511, 0.01785325964221791, 0.05117354336224737, 0.058100292038533, 0.01734362922668938, 0.03323926034593775, 0.027611425236588525, 0.04551609129374547, 0.013854216517610176, 0.040995640109383294, 0.05611966364085675, 0.13250774613791896, 0.04081028513610363, 0.06097029872058381, 0.01922679974907829, 0.05286895339527438, 0.016299422657597932, 0.06356293560876962, 0.036509122789627126, 0.036945229831842646, 0.008571802792439779, 0.01719856664778725, 0.021077876933099284, 0.014765072076941931, 0.03572861326017207, 0.027044167772175807, 0.03311980042546507, 0.07015529073654644, 0.025413894364910743, 0.07928798576035807, 0.07637148903262231, 0.07974543218170443, 0.006565865243770063, 0.04010083409206521, 0.006355571714530309, 0.024587953906326045, 0.01294248570282493, 0.054616591472539215, 0.11063114018930544, 0.028738589551780495, 0.02865941436480611, 0.044536548291122725, 0.035884581100676334, 0.010213293642136119, 0.055972678181264675, 0.09762020165761633, 0.05727920283172881, 0.07086491031992821, 0.0796921814100877, 0.055901945283215855, 0.03902018280519594, 0.03674544176206954, 0.08257302440582745, 0.038439438362876256, 0.03396573386365368, 0.01315759648869355, 0.05529612295269486, 0.1047533305902635, 0.029202333215864438, 0.07727782467320081, 0.030252139887682376, 0.013085002954598638, 0.051532723685546275, 0.013045495800343494, 0.04261585861264218, 0.0061197080855978836, 0.04571920035467033, 0.030515425155059468, 0.03778392756958643, 0.04444390910887911, 0.06436856133082221, 0.07633323826256298, 0.029665264826748642, 0.008206949588061582, 0.11515600020967184, 0.016772698370679733, 0.02162053914470298, 0.013977035733630822, 0.032983517214175195, 0.05681425640960375, 0.025730551062752644, 0.05041204047419372, 0.10491099914595967, 0.028791150844265378, 0.030965339016890338, 0.03921933502199189, 0.051459838080430226, 0.03522136729330786, 0.07804542179069213, 0.03791215536635249, 0.02734779906008513, 0.016347293576766408, 0.05863127140929142, 0.044423964009770465, 0.04750478659726439, 0.011561193743780738, 0.02920608130103398, 0.037581546292189634, 0.006149670263121446, 0.02868176306477718, 0.0750967187266196, 0.06452395460538327, 0.03972111878195598, 0.041228952186722914, 0.05976570206844519, 0.02544865751969478, 0.02675481061751564, 0.034539970389056596, 0.043928488983862826, 0.031158249532323212, 0.06404986875432153, 0.0448630434731322, 0.026739996392279867, 0.054333318971217646, 0.02188573388623134, 0.024701832876270337, 0.1141002697629794, 0.07318149891591842, 0.026605639892119556, 0.02912153966815001, 0.01104733165008046, 0.011312332954407941, 0.031670467409816, 0.047321668600723635, 0.01757154229938263, 0.06413069869121236, 0.026128485858921083, 0.01086042343353432, 0.024389138768216776, 0.024110072089599508, 0.09117449874118452, 0.010409856481748003, 0.0216696530415286, 0.052900462591600035, 0.023494725370959892, 0.0071924045069834165, 0.024655804398559758, 0.07394668285644825, 0.014021303166725464, 0.008240746514451119, 0.02379276804746159, 0.04589211022962005, 0.03254082181581086, 0.022579462890843713, 0.04667549258879116, 0.06859337535476492, 0.06353700353253273, 0.004305536229719198, 0.013787112003492733, 0.04212509502746886, 0.04661739248061373, 0.045686113017220656, 0.0276856227672749, 0.1167151117096505, 0.037942883152995384, 0.008532694961515166, 0.030034360243007544, 0.059334892524226066, 0.04620162124234823, 0.05579237555784564, 0.03815162679060333, 0.06684712389664305, 0.059536802657549424, 0.05058071388292217, 0.06872502756455252, 0.06740456777474574, 0.055837643693291375, 0.012382526183500888, 0.011735103363471647, 0.011374965430267397, 0.02473583951922915, 0.03346546695777967, 0.0568503468117166, 0.011218214264860558, 0.06336127445402165, 0.022904456540521596, 0.04598535845176347, 0.019820178896489165, 0.041918469622971556, 0.030351258258545594, 0.07559125912525962, 0.03153599025080762, 0.003761987989550577, 0.026155339155886925, 0.039644364432822314, 0.056221319677969145, 0.00892228514496838, 0.053980290333950715, 0.030844708897113323, 0.08557598947757676, 0.07555387403455473, 0.038965667988504135, 0.028886486656002464, 0.04286590205024808, 0.040569496040623036, 0.002748859692327378, 0.018466417264613896, 0.02523859238041745, 0.061373318425349654, 0.02703551480907106, 0.04339924097181328, 0.04950894538553492, 0.013214120370966774, 0.051669409092996395, 0.10415923706586323, 0.05385753240496401, 0.010444725931231535, 0.049383345270349134, 0.07630745940391095, 0.04518996766437927, 0.03179415996607033, 0.06701897273981763, 0.0041404303966931285, 0.07776300347740613, 0.09883458891342725, 0.041284899587833115, 0.005870764941773228, 0.08996484590874565, 0.03407116288379316, 0.004305082322624062, 0.03718962337100699, 0.07383424413180159, 0.036309679459419944, 0.03347074530357796, 0.04195313127110562, 0.01861870788308161, 0.059078639943993864, 0.012636699792628568, 0.09132720304713135, 0.010491920777806833, 0.023152408558094216, 0.05439712643443097, 0.039069951707196814, 0.09532666464726772, 0.027526964042936603, 0.01874923968927995, 0.0521408059754439, 0.0576914998612577, 0.004471575253598032, 0.026402745335813493, 0.023952026235600634, 0.020417737053526987, 0.04721147451369513, 0.025332397931525787, 0.015042295356491401, 0.004089896843182825, 0.0725531765830613, 0.031248004393531915, 0.04316003384789632, 0.03850326880872731, 0.04768280244822945, 0.034412389936586546, 0.0239379168112552, 0.0657112300095539, 0.004079305198824695, 0.04798478664710157, 0.1085427002380452, 0.055227998584028215, 0.08576107632008292, 0.036134023159261675, 0.07629886389740052, 0.04217941449173997, 0.006681739872757106, 0.025578607099070668, 0.044427901701701265, 0.05367017794220198, 0.025797547366950783, 0.00965051587686063, 0.11730434823661082, 0.025978891869946837, 0.07788432882197442, 0.030546413411596612, 0.02225527363348632, 0.011880421624218505, 0.0567482962393232, 0.009244705696830587, 0.03690353166612406, 0.02613139507781354, 0.026587993056783756, 0.10007293939950967, 0.008508582344098438, 0.05693849671872393, 0.04333374428472692, 0.10209600906819107, 0.1277880776192873, 0.1769877762924279, 0.15687263630811246, 0.08682945487840522, 0.11884169517866067, 0.17810483973833824, 0.11335352555878701, 0.09798611589376965, 0.1507890401708503, 0.17619907345262267, 0.08232410711747024, 0.13454753184510818, 0.08043304971990087, 0.11318942186452689, 0.19353853899144358, 0.19593921339800283, 0.1488011186161349, 0.18014790430184335, 0.12887354759920028, 0.16566927154217997, 0.23049403823191122, 0.16430773411787328, 0.227494451607908, 0.0821993573598804, 0.16375601291656494, 0.13799509604371366, 0.1412737225332568, 0.1356139109139481, 0.07082651399316327, 0.14848870796061334, 0.12953233724880603, 0.07808555713704518, 0.15440283012726616, 0.11377856646093631, 0.122472001990724, 0.1326129300099227, 0.13394607621575558, 0.2104529789498737, 0.22288532957674997, 0.13174032522065024, 0.10595366013266387, 0.1997609042953099, 0.1516861750954582, 0.14644429508236148, 0.2150369886188738, 0.14003255284361302, 0.10465359360340143, 0.13597221023613407, 0.1206533169193614, 0.21410625307790696, 0.19573615413279305, 0.2025121252142614, 0.12565547269919228, 0.16333605883823288, 0.26753916975951963, 0.1321751107611964, 0.14136929966269002, 0.22273338369784818, 0.11279501681846958, 0.20397330003400005, 0.1391823024999711, 0.08766939367858634, 0.1555972837752873, 0.13396682187674508, 0.28775681230810385, 0.16349781064256547, 0.11934099298331047, 0.12300839377266747, 0.08102247010796301, 0.1114859793996138, 0.13109883383637475, 0.10708910968875694, 0.09837243871222581, 0.14409703232588308, 0.08833731509624951, 0.22469288339057278, 0.11054474845408432, 0.18441182711432058, 0.056970875424843644, 0.1830546410694238, 0.2418754081572256, 0.20289261044273454, 0.2140465748286055, 0.0669239854980861, 0.09233635534802753, 0.19956830979114581, 0.11020865802082325, 0.10416018701488934, 0.109671768281729, 0.13840362009021545, 0.10804266698898808, 0.08776820369906004, 0.12905085098839578, 0.09996600118615936, 0.13528271578252316, 0.1664850479292293, 0.31752763255949945, 0.22067266846856765, 0.14166235893724427, 0.39743005147864746, 0.12181607750995506, 0.2426961028287488, 0.12958833827607094, 0.1695036028902377, 0.11660266532412461, 0.19428303855801785, 0.33115851242215405, 0.1116513854433452, 0.18220042239033407, 0.1570761858695938, 0.18066761834967524, 0.08841315780075328, 0.08281415057999474, 0.33219346656434, 0.10774172466969299, 0.13848346177368395, 0.1139855097919222, 0.11058754212553464, 0.11397588772759323, 0.10195073581510976, 0.1606109155522239, 0.09941213493866306, 0.09016601293678246, 0.1398433904133497, 0.11579571426996302, 0.15095627716472074, 0.08531240160546957, 0.15678202342842856, 0.16191069096807512, 0.18858043326725885, 0.09128629395197477, 0.08021695929909907, 0.07901899696838471, 0.14561471379091664, 0.17605782216114385, 0.16182582374782334, 0.11975851856292256, 0.04357154946774245, 0.17951542211155738, 0.19885509725539915, 0.13363711295589326, 0.10978252161294223, 0.18540764948533428, 0.09163058152602566, 0.1119540284778322, 0.11736260922325235, 0.10596570303483356, 0.10942589236243118, 0.18524975876414007, 0.14932106249034405, 0.2982580697824878, 0.12376227791631415, 0.16093518524881334, 0.09517807423347428, 0.1395314087670657, 0.1487194383216481, 0.1513627174520685, 0.14269147548944722, 0.1558919824779995, 0.16734720327921454, 0.22486497738188316, 0.12807342238844405, 0.11368407717635555, 0.2023514765765398, 0.10661955141732771, 0.1289889510841139, 0.12454601650637005, 0.12168876901869813, 0.13945181223173297, 0.1546116810171835, 0.25444324909439014, 0.1643045012268328, 0.12919608593708085, 0.269129445716258, 0.2182346396148205], [0.015791398153880674, 0.039593963508283904, 0.015792191054882304, 0.04037489438609731, 0.013164010559839588, 0.027472202162889224, 0.09571471116355351, 0.01732198149716902, 0.021066870164847182, 0.07495739797670996, 0.04492955522671823, 0.029607197277307994, 0.04155466978948924, 0.03935777477078861, 0.018425527321655425, 0.05575439291855982, 0.0954764424973438, 0.058694029332048474, 0.07236559995480123, 0.038647461877835375, 0.03918958782789208, 0.03805654378788125, 0.06383531433980792, 0.04187411696259533, 0.02471992404260222, 0.04048203561274756, 0.032161830458790064, 0.04143448591592812, 0.03922211592115703, 0.04337824250180875, 0.07156653960625972, 0.0540268914623847, 0.06266043040781252, 0.02545354516065169, 0.015196440865345781, 0.034339948662466584, 0.029324945588145527, 0.03719792010322694, 0.048172317310086185, 0.06276583261487466, 0.0411625515158859, 0.03645058601133285, 0.043768740499452244, 0.05889531127327393, 0.10387838923282201, 0.0370171501661741, 0.03571364390213163, 0.06338562072825528, 0.06965891172688815, 0.025822717185703017, 0.04762659840766461, 0.06486804299657384, 0.01749045189259754, 0.0767224875368899, 0.05073088243783963, 0.01661317779742662, 0.010657565266404663, 0.06466963388506444, 0.02985727135843087, 0.02777693661740951, 0.03238890658042604, 0.020212684044494264, 0.05267692196573462, 0.03827037424930642, 0.013350097147086936, 0.054890659427450555, 0.05037706089957107, 0.035073876215685765, 0.12100639918278303, 0.03709865042999868, 0.018482698548224666, 0.06449234581762744, 0.0355814669221159, 0.010633144298598412, 0.03449625741209715, 0.0472333041890975, 0.02324914439551292, 0.0163140932413479, 0.06407950869611194, 0.031248573213815693, 0.00807301156342991, 0.04104170114583066, 0.03785891991649424, 0.041005909518008275, 0.008009116000105298, 0.0339808066435639, 0.00892773681815954, 0.022862446193973866, 0.061690160899513194, 0.043754606177249265, 0.05496081392911654, 0.02860714035529283, 0.04204614583643214, 0.07902602199465036, 0.04923167135266047, 0.016726520505823916, 0.010802234267635692, 0.015591867681172107, 0.05454264483564804, 0.034076533160142364, 0.010736281758234387, 0.0692437916633583, 0.07957596587197435, 0.04829960664914501, 0.035625532299520514, 0.01760664061763354, 0.10215535789968506, 0.010318375049879955, 0.01829078011665373, 0.06480916913959288, 0.017690841341391206, 0.0440736664759536, 0.039165253044977304, 0.031862738241832105, 0.03262479654363087, 0.03442715628132705, 0.02996822387250441, 0.05344245830670961, 0.024121182279721386, 0.037959664308976744, 0.044435049302034804, 0.03031095820328882, 0.026880711422211705, 0.0429273116582584, 0.021426086877322486, 0.01426795379243671, 0.07118743333605028, 0.002521681585236483, 0.06117921472797471, 0.06764445288647568, 0.02750504052176351, 0.044091742320527, 0.050278335148769046, 0.024029711381562298, 0.09011109975437004, 0.04808684104993459, 0.015874053295251104, 0.029525306308642033, 0.06321397489838063, 0.07114673108463326, 0.04397937637423316, 0.11515144964740162, 0.0033307554211557634, 0.053047811942956144, 0.021253548555016037, 0.08305070320925406, 0.03009766783385027, 0.004775783501475329, 0.019366769758503766, 0.036874198159503366, 0.06389216189422915, 0.02387135143151447, 0.0314612832716516, 0.03655016978061007, 0.029918726931716648, 0.03489271940423116, 0.00922171539822293, 0.012324971912969506, 0.035291184716287165, 0.04002135246992111, 0.047061194876028646, 0.02030327585676024, 0.040186114999796116, 0.05490553302450046, 0.013791790885490277, 0.012852980777801526, 0.041228067355170366, 0.012016526720065986, 0.05188068465119408, 0.06338427624394817, 0.026457604892071218, 0.043079452889580885, 0.055378730213570024, 0.003925002641945837, 0.01212045516548378, 0.02933194763177345, 0.05566360383865334, 0.01779037914539297, 0.06458318852368863, 0.041026233830639434, 0.0156060948915359, 0.02110886902007605, 0.012945323100974484, 0.014926708010475964, 0.02659254361905398, 0.028354446253468914, 0.002427182963959152, 0.0413880035311224, 0.02754782461711476, 0.06408199082098662, 0.03923410519717201, 0.03581405887680669, 0.08246403307684007, 0.01745641460612176, 0.027538547292351726, 0.011606586368514166, 0.039762027877112555, 0.02818240588831325, 0.04172349258536293, 0.056694417275608554, 0.038231495287149184, 0.005456691545869915, 0.05714001231676629, 0.04899215396313418, 0.05096804793743838, 0.046757379727017497, 0.011392515547002756, 0.05811247283652906, 0.05251248502322743, 0.009532822746663325, 0.03855173153081729, 0.08501676827548973, 0.025502998051383806, 0.02141394055328302, 0.04033666659867571, 0.037349586360036366, 0.07109747929198128, 0.061378313318615964, 0.009442840931907056, 0.023123613228240324, 0.040535792002394315, 0.02362823151352425, 0.016732549617788004, 0.12103621532479603, 0.04026104989010961, 0.023780476166716507, 0.04119141004799355, 0.03900397238471816, 0.028728804693767623, 0.05393001581391981, 0.044105263772390546, 0.05113964397159796, 0.08681162035152798, 0.09720227005140436, 0.042148341965531154, 0.08128225052308652, 0.044517951506760814, 0.006894524145360676, 0.04179615219454131, 0.07746701774698111, 0.052622613992782376, 0.013952918328164567, 0.053315050224022525, 0.02966468259992619, 0.06716994568705559, 0.02455457928590477, 0.020134068101704605, 0.08100214579533185, 0.013524587078380489, 0.019107983342462012, 0.03609009950812306, 0.043782112564170556, 0.028791587514382218, 0.05946950949428063, 0.0642128539602122, 0.016562571944368464, 0.01605513158269347, 0.039076999716100194, 0.040112072601914406, 0.059583066707296725, 0.021348700505651293, 0.008157031298915466, 0.032807171434885075, 0.05143682862962446, 0.07316734161107771, 0.04371355152538708, 0.03691707610062534, 0.0995088228955865, 0.053560765264856244, 0.04322600550949574, 0.050661398263107386, 0.07466272991751471, 0.03948892519298581, 0.027214905787860195, 0.047992704165799004, 0.030109668601184126, 0.030401088447580417, 0.08761706987335798, 0.05343004002145702, 0.054627864456345, 0.04757541224300381, 0.06071293148242178, 0.02894225594167027, 0.04905850100781649, 0.090539411851956, 0.007678074565070171, 0.001616364123389846, 0.10302679057443336, 0.03226328731304215, 0.08955681981939463, 0.011635495653946795, 0.03359522309995467, 0.05072768785119538, 0.03941201379582767, 0.08315881353712852, 0.03527912649235899, 0.04527832441512616, 0.08082894863741052, 0.0530682243556986, 0.03469798368431869, 0.02015277213837591, 0.036977447659498265, 0.035534452106202805, 0.015153500679579955, 0.027046927603923028, 0.03675078139490178, 0.009121514928166666, 0.028440456859947696, 0.01967554724204444, 0.03852195752364013, 0.03531058206252995, 0.03651910874572012, 0.02324261349595843, 0.0674733777921046, 0.069196991352064, 0.04170477705737276, 0.09034551499832062, 0.02859028450573885, 0.018858018428868344, 0.028595880778025717, 0.0063442470197896325, 0.028665353461439093, 0.027185470774589528, 0.027927413522716493, 0.05211463641195048, 0.03668041621905662, 0.09646734658388362, 0.007138541343832209, 0.031415007730585434, 0.05581856810397679, 0.023313126143729015, 0.026707500857751698, 0.018388433344361764, 0.055165194695995706, 0.01786205050114903, 0.02150019247745795, 0.013340467421878732, 0.04818847793484888, 0.02652943904151119, 0.02150904845386263, 0.05669427937978218, 0.06127675687293373, 0.038906066347995115, 0.11842544896588211, 0.03886925199279382, 0.03132436229216476, 0.023709452155256466, 0.03714292648158247, 0.054156927226652066, 0.05933836673296267, 0.05159267006562122, 0.08858518284415046, 0.12392204555292284, 0.15740212563785816, 0.15691172211400925, 0.11511258600700287, 0.1404950860887766, 0.18305310889357523, 0.19689046477358188, 0.15940995015684636, 0.1903118072978912, 0.1888665517852191, 0.12384781163306006, 0.10840157152063425, 0.11109469999228755, 0.12135702996484696, 0.16207549180234634, 0.11201037424466304, 0.19541842682707697, 0.1394592432845985, 0.17757925745700637, 0.1050323321514072, 0.2232765553579215, 0.08396364252773986, 0.2149395575566638, 0.2634274226523215, 0.06084212838041206, 0.14014625561333474, 0.17751308278210703, 0.17768084071576598, 0.12004133524192918, 0.13131030474699315, 0.16934532912508135, 0.11711768325298064, 0.16606305605701863, 0.15986439351352955, 0.20621364755976587, 0.16627184565990202, 0.14558606210254854, 0.20988693190438135, 0.12294034218235363, 0.1377456884590849, 0.17072172865511911, 0.06862858475576486, 0.13661056065992003, 0.10626996251484079, 0.18844328820705417, 0.19920253345081884, 0.2052809355119544, 0.1642711917238851, 0.10913703124970199, 0.14156252235895203, 0.23928691963514975, 0.1893529410083448, 0.13614897736378256, 0.3093879483640194, 0.17706885903833375, 0.154805991558298, 0.17414620296368677, 0.16554121228475727, 0.1249076942763021, 0.1885123433725488, 0.15758986314458234, 0.08245664032837076, 0.16970410342178038, 0.30247143079196254, 0.1367111939696535, 0.22358072290737785, 0.2213081230799998, 0.1390198305729897, 0.17345608031797796, 0.3446001072804774, 0.13956652623751473, 0.2059077180080837, 0.08784452137807686, 0.17991769488059706, 0.16456150840367043, 0.22594905308177396, 0.09824626403109682, 0.12776963788294984, 0.14281124567552922, 0.16141495547227322, 0.11932125089750176, 0.13801682229724624, 0.17660188248320935, 0.11515616108813595, 0.1059442678947122, 0.09390610014839519, 0.11455359463129314, 0.17470682610667523, 0.11793225688198883, 0.1728341394975301, 0.13061557025198015, 0.18840334438268216, 0.14102023936087085, 0.1053823117587355, 0.09667613618676701, 0.15408648177981377, 0.13869865587161434, 0.04635786104406561, 0.13228326705434632, 0.19213669002056125, 0.11899477486769039, 0.20625926043477752, 0.20398871372303656, 0.15960893383429897, 0.16120017506182194, 0.14136925369741457, 0.1114280631525382, 0.14326165940973068, 0.21660553832207957, 0.15310012825554417, 0.10713381858001794, 0.19478021429911738, 0.1706713660349769, 0.22215252051190024, 0.10422603227198125, 0.15030213000793613, 0.18936162844540613, 0.1410787531565274, 0.11118302992995709, 0.13788807356069166, 0.1483903422711357, 0.21426095687333616, 0.15335445412464682, 0.12368859557975685, 0.06943978759790621, 0.11845029319726652, 0.16411736126868956, 0.1607400626544991, 0.13244006993068805, 0.19673833503357827, 0.14909653744149595, 0.16195933755126693, 0.16865640157653441, 0.12806160931265162, 0.1906872363460641, 0.1444160926245874, 0.10839461544228178, 0.19933138943968282, 0.11418779530832845, 0.14789161903242912, 0.1671625301241875, 0.3128653440263964, 0.06544506808202114, 0.14871822790272776, 0.18728831873065044, 0.20006035274315268, 0.1006750078992017, 0.12240621802066604, 0.1917305408466247, 0.1051976309428292, 0.21224865840087015, 0.11761615368267221, 0.1399306937932007, 0.09902238770718537, 0.10880650261477118, 0.14779098572269564, 0.07576269428095511, 0.1175044350806744, 0.1545431161479604, 0.15208696165392477, 0.2524249138490808, 0.12966369068430317, 0.10659375723691718, 0.10285938504121958, 0.1643429281971147, 0.07143801303520318, 0.2184700431121934, 0.24424710911848854, 0.09863383557286956, 0.11152295846371882, 0.07945309302979901, 0.17624699991316567, 0.11543081893074898, 0.1283053631683992, 0.12804230389695975, 0.2156297108458896], [0.06337234059408789, 0.031036815020225705, 0.007852861355434382, 0.023717360097854853, 0.06481056341961508, 0.04446774976508272, 0.02965329087249214, 0.02843719715582988, 0.011013521317152247, 0.030263585241271124, 0.07445450721969528, 0.06703215711299451, 0.008177540430258359, 0.10682060353217587, 0.07883651482482111, 0.06169409093056476, 0.03758583255412598, 0.034252718060968385, 0.0461241927358412, 0.045419353541106953, 0.012975729130689177, 0.06676614074216736, 0.018090193400219567, 0.0386482892527936, 0.03343352492177679, 0.021659797320382732, 0.030198324126221483, 0.028159291100417896, 0.011172606177898425, 0.02579278421528157, 0.02192613544813808, 0.013811246645937284, 0.05223374010153836, 0.033073046079446236, 0.030861378970345667, 0.03736745153043059, 0.007122441527298502, 0.03318920033052564, 0.04596060615092997, 0.012980992154728983, 0.10611731949592791, 0.01118412047940036, 0.04625805893972997, 0.032581830502397595, 0.03478438691085866, 0.026869160731533365, 0.026782058449762485, 0.009974335496794554, 0.06627540013963176, 0.029137208081421354, 0.04110401090715201, 0.024057834469262632, 0.034689844000123204, 0.041442744343751864, 0.0798409786676207, 0.06783153921846422, 0.015481949385796345, 0.07087214218993342, 0.04679976354142831, 0.11263668942715853, 0.04949656540467855, 0.05030068576395993, 0.036324844169881076, 0.06735745336740248, 0.079931162538067, 0.00913189446193076, 0.04902198925734528, 0.04471987696184267, 0.034836614955096476, 0.041551502015922344, 0.017746124161227096, 0.0325721318292762, 0.021061467329761194, 0.039923254911217, 0.06480365330653806, 0.03350410843268037, 0.03894474995773166, 0.03152788887100835, 0.031444934955347455, 0.0020588399896833806, 0.051664329930058414, 0.09029004257172348, 0.04409945299548488, 0.053582464705311486, 0.0779051204482394, 0.014432355303377395, 0.04609285973973813, 0.06271653102650758, 0.018337655121520646, 0.019437946987548665, 0.036173101304279226, 0.014149131640160998, 0.06063282549861939, 0.01782783126879123, 0.04796889798355199, 0.04230093901916858, 0.009208858527633692, 0.05224835322869401, 0.03928861235298457, 0.08479857877377542, 0.11057805795703204, 0.011029397531773054, 0.033236858660295125, 0.04242887570252342, 0.03912594124314286, 0.03136743750092724, 0.03769929017571192, 0.03155180422078458, 0.045681550963631565, 0.009509571978161413, 0.005470748301670557, 0.010150862264356787, 0.01564083506368221, 0.0604280463660196, 0.034611507679425904, 0.02434635275764571, 0.07869822829360924, 0.07144714480326061, 0.005652379130028309, 0.04090871211261519, 0.06052993222950928, 0.10605263869248091, 0.020542685993977135, 0.03102158710751082, 0.017045764665630077, 0.03595596517346079, 0.03579523992694674, 0.04944251024074132, 0.022226007159558997, 0.029999572190365968, 0.026809781256522384, 0.043992288786196904, 0.060086168138490575, 0.07216915968925723, 0.025507657781183243, 0.011147688210551298, 0.03740604320961622, 0.02780856264214362, 0.016903864114635417, 0.02944496858324255, 0.029732163454736435, 0.011175817043911065, 0.013820142841957992, 0.04694389149306282, 0.03442606843647457, 0.04774141966575577, 0.0551462225285509, 0.029674971160749276, 0.10734724301484325, 0.08080872391620952, 0.0335034879014617, 0.04643856840688856, 0.04352693250703235, 0.038196887265169815, 0.022412856004291007, 0.016904898333333192, 0.07298936406450887, 0.013707820945719798, 0.02974812489663882, 0.02037707310650618, 0.04002522504437835, 0.02440105909631858, 0.01963350050632031, 0.020709235423935518, 0.07939385911149364, 0.029926027749635042, 0.05250741735160832, 0.027624647914161606, 0.08436719466361307, 0.06856303827296342, 0.05782073123320457, 0.01400823753717686, 0.05360517155138716, 0.01354633056889138, 0.02726871963410128, 0.037694597887175704, 0.007284205301754898, 0.026622987953164888, 0.024387552966213515, 0.08209008257836103, 0.03331917097731944, 0.08863362258360272, 0.031866390566011114, 0.025984754357787392, 0.0452355575567532, 0.06245919826230215, 0.02575820875203898, 0.015259616306021571, 0.047743564711943756, 0.08058252879568646, 0.0052825123589906485, 0.07294361329367084, 0.0649640721178824, 0.016404123894209345, 0.025441157518916076, 0.035483154858792984, 0.022051323791064566, 0.03422562536152621, 0.045078597632386995, 0.024670948041602973, 0.052194604499926495, 0.02581832175623746, 0.14905915235079106, 0.055106087182197845, 0.02823110609765976, 0.035013841735499526, 0.048039351259508443, 0.01894295459703332, 0.013680254229374472, 0.03202919765645939, 0.015343953967995703, 0.041900290356528376, 0.04497645129900306, 0.0687979361523063, 0.03468619359116401, 0.04677836287526354, 0.03567277694181089, 0.03069341036250755, 0.02745552634399745, 0.01984177299985482, 0.027142826490284457, 0.017093097408031745, 0.03878510872563047, 0.02666183818702496, 0.019867624636859666, 0.06705736906658258, 0.036853521446427034, 0.07786241870734, 0.028017084114253524, 0.018046788773649645, 0.03743738003615891, 0.07624333784464868, 0.026753368456998182, 0.05402298441397087, 0.049114207091230544, 0.09180090585423094, 0.02055385555591314, 0.10702683440139217, 0.03395681660021505, 0.0410118926646969, 0.026586709859510584, 0.0819314334301218, 0.011752460043006127, 0.027851622529147614, 0.04683825562918379, 0.07944859609368347, 0.04190676762992817, 0.02829333541974906, 0.049676599897324085, 0.029178433187846697, 0.06949398831854905, 0.0992866114322697, 0.02373686086596741, 0.03362079128442753, 0.03333840361465851, 0.046094836246582775, 0.00529923941001236, 0.05852228774118328, 0.10813073645676337, 0.0277351618428985, 0.0223597354676214, 0.04287461630038677, 0.0611956971096656, 0.037336635643676404, 0.009445233999060528, 0.024691191915002082, 0.017298692424270897, 0.0530690479002172, 0.042536346346981106, 0.06790715209659069, 0.04578596108683175, 0.020580415824247945, 0.043722016796950376, 0.03862646723827047, 0.026971720752396414, 0.049682923953139016, 0.046533590122576685, 0.047271305980581435, 0.011898107721560426, 0.03408053596954673, 0.011339029203349305, 0.03439430260069428, 0.038793799993131435, 0.025310068383752823, 0.026285704337961735, 0.02356169486208068, 0.05441011162474752, 0.015922591668523608, 0.04578763115850668, 0.0015493418440230252, 0.016379942328879432, 0.1568791020901934, 0.01420222249092354, 0.023700138441317027, 0.03271680753377657, 0.050036362447445436, 0.03996820895061378, 0.07620685673769444, 0.015294074940855707, 0.020972945870110588, 0.03449640679924238, 0.01100518340770636, 0.09451446589082481, 0.031928244505017515, 0.038610172548121026, 0.13724587737552582, 0.045694666388895244, 0.021114038198345134, 0.04491194286533902, 0.04889528214510891, 0.012141721766261805, 0.009566888761436267, 0.038337533347188466, 0.0209062808989397, 0.024588133936988252, 0.042418694394009734, 0.04825415465259745, 0.015938535873447696, 0.04899565881538776, 0.017801502742053523, 0.05355073334348779, 0.09298871751994857, 0.07521482650190592, 0.061621733926116466, 0.019330664034632426, 0.050825306604946816, 0.05378032989439465, 0.005853417359532849, 0.04457668363747578, 0.04365421035477231, 0.029866315026377, 0.05297342480550851, 0.04923290092377894, 0.03437030106602657, 0.05696465096045887, 0.0641588026267146, 0.05806412885806734, 0.03468382637947798, 0.04253171917591845, 0.0022013981792805416, 0.03298449780671828, 0.030054134887553034, 0.012450160255895988, 0.036773633797683065, 0.05581970957498397, 0.021691712543308254, 0.027765738327176343, 0.034686955848648664, 0.0426310041709052, 0.024672688976410898, 0.04997718215529477, 0.05190867367350767, 0.20731465380278327, 0.13722893151064075, 0.12569852684053684, 0.12699211226595988, 0.21430990989169768, 0.25549940855032016, 0.17903280204101918, 0.11045077244841284, 0.11321218233675727, 0.09447492809305269, 0.17086437422662012, 0.14232409036447927, 0.1283957998478605, 0.15018887156921049, 0.15565268725397127, 0.17871991641098456, 0.18768179681031935, 0.14857323810217843, 0.06950046176150923, 0.08924231774383977, 0.08513868350775973, 0.16235911287367344, 0.17289001795072712, 0.15191874406751127, 0.18798303790390494, 0.15005882048318464, 0.31983432329950795, 0.08223262855843191, 0.1074016965445011, 0.1561675443043632, 0.16763572731325704, 0.1915669963965493, 0.10421045770448062, 0.10533068509351824, 0.11515310439731806, 0.17616599377605224, 0.10995109926068014, 0.20963246813945233, 0.13030391036262437, 0.17850996235445624, 0.17059498706892615, 0.08824392897827972, 0.12329402965523543, 0.2273180062371877, 0.13705622464899095, 0.10095531180981668, 0.11491282858074674, 0.05778412755218245, 0.18535750136981088, 0.1580937191723816, 0.10247352953639724, 0.20271713034279887, 0.10810443665832283, 0.1060548909909783, 0.18693429417908194, 0.15214124664423928, 0.1227881741379538, 0.14518768106016422, 0.11864149342140845, 0.2276008918641075, 0.17454571781619904, 0.25863379600547975, 0.1120887756828339, 0.12166265308135941, 0.125421540090634, 0.12075128424311839, 0.18418819072746462, 0.23209684738709083, 0.1553893368691206, 0.16319604860919137, 0.13200575936465495, 0.16575436858880907, 0.16571284662331306, 0.1136447998484777, 0.18976528017270952, 0.254291104032628, 0.15387648175801003, 0.10043329183733272, 0.18758566809758065, 0.14633480579622332, 0.12952093786049274, 0.24431932056623124, 0.15942413810520403, 0.18134454896132793, 0.21203095153454812, 0.15137906576837265, 0.1635870905292611, 0.1256993082502196, 0.19780580194727068, 0.15895078769854962, 0.1389331707069951, 0.13357746535010878, 0.24243134284211745, 0.07186734402972846, 0.12341730086313141, 0.11198399017655081, 0.10716419396621567, 0.20746332082536914, 0.1366477465677646, 0.1836862039542006, 0.15364149194811622, 0.1163201550802877, 0.15613064950992986, 0.15710063939613683, 0.05980542372731913, 0.18278937546476243, 0.1254844512309759, 0.22339537559497744, 0.14136589823230622, 0.09489509667600356, 0.15204851936188438, 0.10363329472320695, 0.15136682368334264, 0.1322352639850109, 0.13216337429419642, 0.20068623125553134, 0.19993699726558503, 0.15168482678071146, 0.17644501831983367, 0.13757252194468053, 0.15147372359229674, 0.32410201526457266, 0.10420465075801458, 0.05658140781545832, 0.2359117354236303, 0.18198380336886455, 0.17042067142263537, 0.16108803511146577, 0.11920685864864819, 0.23266655633286124, 0.14876410124763367, 0.11567021374620738, 0.1374254330632187, 0.18707481002615345, 0.13494078009839983, 0.094492165071349, 0.15203938759382696, 0.07991640002376611, 0.1495236467810408, 0.08809796624606656, 0.06879063533438791, 0.12378844747980758, 0.16268085448011277, 0.18087554993408342, 0.14779883046304026, 0.21396072701581065, 0.2843201418797816, 0.1281215250492096, 0.12534399667093832, 0.14520585266572816, 0.19553180783987048, 0.12430817684939793, 0.1878161226669627, 0.1457242030770548, 0.07507353690603087, 0.13858964155998924, 0.24610140961745094, 0.08293891565934305, 0.22450980369842824, 0.14041282356746737, 0.08903446276822398, 0.09666063822805883, 0.1530509147672884, 0.1550749497067544, 0.2620509465134913, 0.151321180164814, 0.12502565649488281, 0.1673653442412615, 0.26461292839338707, 0.17179435900142118, 0.14066270612660917, 0.16190532835260515, 0.1192803801067414, 0.14918174174043441, 0.23498509079217914, 0.12735793457156228], [0.03594215643862563, 0.014910891167669287, 0.06727872251142418, 0.038799327317505114, 0.02855360613114411, 0.08439871152081797, 0.05163678523874091, 0.040848535906162955, 0.03326390156402223, 0.03835316537128341, 0.043535355643759814, 0.03175933360903254, 0.025719900525385336, 0.048600820929653225, 0.01214999455823413, 0.02013807282632878, 0.08337305002515355, 0.011767688913330918, 0.03759828531333516, 0.04128281199823945, 0.014711813644445954, 0.055638579576606714, 0.010515437761862433, 0.031200516518325578, 0.07168103910742268, 0.04836205430629273, 0.055285386230436065, 0.04191524056237071, 0.038739894216339436, 0.021018012907476197, 0.056820863917950666, 0.047834277183057806, 0.07594287049986663, 0.03018518380310026, 0.04486884658915862, 0.04086810945262832, 0.06527461351886873, 0.010264408943663922, 0.05941060116334308, 0.030346512343854676, 0.08711422508161876, 0.07151041600492693, 0.05782839211244738, 0.05351595678216508, 0.03708109935565341, 0.12398553892008721, 0.06138401301277261, 0.042468639496233196, 0.06357543050281464, 0.056239154204846396, 0.05879105819809822, 0.04531498172230298, 0.06125457479708618, 0.13208500349954252, 0.037973944187885335, 0.03502898729376255, 0.048213586466567177, 0.057560529469722704, 0.03125736407274681, 0.026520337916970737, 0.023689166147021518, 0.02088183694849572, 0.02567151058164816, 0.022360300457465555, 0.030784235831590432, 0.07984335354018597, 0.06419301611341297, 0.06548135000611506, 0.04675134678461379, 0.0320503550897082, 0.01508494251362619, 0.022708594671360428, 0.032900787379232146, 0.04954069589955672, 0.051580642485210014, 0.018351239775637948, 0.08456237088408201, 0.021236736755517703, 0.018529180933030385, 0.038061431428838166, 0.013148887984214291, 0.06132471397699368, 0.04480760169005202, 0.01665901475315613, 0.0565513197122322, 0.017561200112404845, 0.07851562357597774, 0.025787641850089835, 0.07263202235222825, 0.013806336979952552, 0.018789836603607384, 0.04337976701677807, 0.026016397619499795, 0.03610339496404894, 0.034627951756720586, 0.015292887504573072, 0.058445338039628925, 0.02613549173298863, 0.062088610889810714, 0.033318343602361224, 0.11607817854852447, 0.004552871067707818, 0.009276068378840725, 0.040098623928403666, 0.06418388051491591, 0.036463103888015595, 0.055848951151053754, 0.03176696384475837, 0.04373481429572548, 0.060258036133863276, 0.021695813028922966, 0.08689814232169621, 0.018348098815148397, 0.011171553764612445, 0.016464196678791797, 0.03499173243800479, 0.06219388286192572, 0.015542338181647564, 0.027605465072537624, 0.013257203240608497, 0.023628957381832506, 0.024656859684675455, 0.004279605111092209, 0.025235539520039194, 0.029744654518341827, 0.042832289942570274, 0.04912762129078469, 0.04952545458030316, 0.03641791619180191, 0.042201435689123414, 0.025440176926372994, 0.00928889460591299, 0.0271478098922319, 0.010618483290947493, 0.07699386652318702, 0.0053151601534937665, 0.05534542454106193, 0.019460764916373358, 0.10705684972626549, 0.07468670080866545, 0.03177590792127435, 0.03131630879286076, 0.09866100105066454, 0.08334807555882201, 0.002642644953260559, 0.026271286563226776, 0.041790778087752486, 0.04451983991349417, 0.034614495422330596, 0.10647545027877055, 0.04587136839907016, 0.0671417766340798, 0.019687873596746116, 0.10371649187178382, 0.013812212874331783, 0.039132257638078545, 0.009749511673655963, 0.012586250029984983, 0.008820984381130867, 0.06897492544545282, 0.04828295572811077, 0.022415100641909148, 0.015666857155250208, 0.06705887059891416, 0.06450500159013657, 0.057055102961678664, 0.054828931892951654, 0.02628265913846272, 0.06785610765819589, 0.020092904282313202, 0.01988175895906264, 0.05980105702615073, 0.04095006553876785, 0.042459178310368335, 0.010273873959968408, 0.057362246762720816, 0.04568401776674775, 0.03054837268146296, 0.02787522952853432, 0.04519756342614851, 0.052049790899599754, 0.0614938815124333, 0.030891892252369758, 0.049357508955102776, 0.03308859000342988, 0.03177375712942693, 0.030811508561694817, 0.006019360143616195, 0.06551282855892374, 0.10016392000139722, 0.05497505167318929, 0.052141966598649184, 0.047880162019282586, 0.017388186815585342, 0.08062457936185022, 0.006768743999512687, 0.04088442329497587, 0.03977066934889844, 0.022542627468224496, 0.05688272168739669, 0.048333666918258515, 0.0648033545322476, 0.016671561358136036, 0.030691818814844857, 0.003589260778690298, 0.04504429221513771, 0.05946300923824311, 0.02728074912973229, 0.02724845852372387, 0.020841345371257876, 0.08769675833924163, 0.042379183409314965, 0.06167223061164541, 0.015325661703583696, 0.02423071944635482, 0.023568652855652957, 0.042253851424902684, 0.06367490318934284, 0.05045199195944494, 0.05677810089001733, 0.03118101575021302, 0.06714647275305564, 0.04570240004649086, 0.02981154548545038, 0.06384673288031932, 0.04713614125766101, 0.11769415675512246, 0.010040527408672197, 0.02552947979570637, 0.036460935859189886, 0.008925474943563102, 0.014093485886170981, 0.07167759171176342, 0.018189692899825114, 0.016993825819583672, 0.02208902489303822, 0.023360847675752257, 0.004860886293763836, 0.0245719809731048, 0.015012260879419986, 0.022019632648856893, 0.09452336783250494, 0.04193350792892518, 0.05462604499752483, 0.0307462876662612, 0.05389990472805597, 0.036659329648940794, 0.019645964756848353, 0.026552098007091594, 0.05406944381613886, 0.04421721220076565, 0.04448597499680135, 0.04482330649249977, 0.03381794784218073, 0.04940339762176718, 0.02826466840962249, 0.08432394900028745, 0.04176227195609001, 0.0353117197030975, 0.043370819109822475, 0.02382815173346429, 0.12931026368131562, 0.05231407208127841, 0.04793173888878477, 0.0443096062348735, 0.0458792859177676, 0.005165425395863432, 0.024223805502838185, 0.05018753074710408, 0.04710191627964378, 0.08562812942170328, 0.02423824051455144, 0.04693645660975768, 0.014023960534212811, 0.02535513159067881, 0.053361590065422564, 0.060176034082448294, 0.031136776087805632, 0.04963963998541717, 0.01146293817944224, 0.08837568844037672, 0.05387965319377761, 0.05589946698878081, 0.0144724284050866, 0.04620638247879763, 0.02344713407388378, 0.013386831063056185, 0.04281775342420705, 0.02843101865672056, 0.0746242646428366, 0.06113363632691964, 0.04970644285241443, 0.07438545205420063, 0.0008174768029881131, 0.04886242463403652, 0.045030950793936375, 0.03496170179137299, 0.008288724685928995, 0.027271498618046605, 0.027448083799813065, 0.016510020227982633, 0.05931016703646991, 0.05909935879190603, 0.016166989038127567, 0.058994730333647424, 0.02922802205918537, 0.002693105010210627, 0.030093938900878834, 0.023653592854257555, 0.01649941182545116, 0.02975665145523606, 0.016061904757554014, 0.02402775785735538, 0.1359547434314605, 0.12719286560651757, 0.10659309074042306, 0.06666155441874458, 0.060195749355179656, 0.06994901390205469, 0.10919704657769012, 0.021009043933102683, 0.018075796692902525, 0.06705936855606495, 0.042656806012194966, 0.0234266278153706, 0.0033714684456842203, 0.11843862567817974, 0.0770898650009786, 0.02593620928124555, 0.03159562445005342, 0.013742349486077025, 0.019443445583625187, 0.039942135148110895, 0.05875246651891259, 0.026590425385943344, 0.0678875019413329, 0.055570405412225, 0.025670187164758964, 0.028580221940853426, 0.06517041790028734, 0.05436246861673651, 0.02108625985021072, 0.07868100663707142, 0.06977700418041599, 0.03172157888090418, 0.03715917520645646, 0.027754252753971566, 0.03138649968370315, 0.04833583877752385, 0.04275827435776592, 0.014977576248648186, 0.04374164396957044, 0.12145295949472536, 0.15922820345769007, 0.24105819152487865, 0.15197983191859338, 0.11462655684520161, 0.12113476487537547, 0.11467663601281182, 0.11948071209894073, 0.10871716910192084, 0.12181832980845245, 0.14206388094011815, 0.10310820273814664, 0.13256622929005854, 0.1811739105370737, 0.1551276259124279, 0.16149295854472345, 0.18430241443697484, 0.2069169622395308, 0.13114141300320625, 0.10091292416496624, 0.1299844823417164, 0.22187067676455746, 0.1205147545964968, 0.1169742103065214, 0.14194190442081422, 0.1868689468791408, 0.14158709845956297, 0.1610613752517008, 0.08888024160818708, 0.12068678730077322, 0.15964497061025712, 0.12513843229821614, 0.1918930127736061, 0.09876381005010298, 0.15813424522357603, 0.1562864717937285, 0.14573489766447775, 0.11904495362673076, 0.20552573124727896, 0.16490330619196739, 0.15782597144284558, 0.16347488929187098, 0.26741834237210216, 0.11059270555814428, 0.14532393745837674, 0.18810342096032637, 0.13707842587703659, 0.14764424924167896, 0.21208106900655457, 0.12137820463507407, 0.21138359191677264, 0.14059935065527118, 0.1316734151013436, 0.2308260300947774, 0.11635176386804351, 0.12948418096188577, 0.16864881730608403, 0.14102037725669725, 0.14283439685260096, 0.0776371811967223, 0.17795415024363226, 0.14386815589762506, 0.08481465895930607, 0.27215438985055496, 0.13724033089895404, 0.14208462660110768, 0.20363856557636492, 0.17472449209420912, 0.12400068447835023, 0.149236471061745, 0.11786663379039496, 0.08010727849097983, 0.12970011050422348, 0.23526998356946055, 0.18133508011458382, 0.14264491266540943, 0.20061074095147274, 0.1245159398944628, 0.09295754540230959, 0.1573789897825449, 0.18303314464226847, 0.18228669921236654, 0.18575487117613518, 0.09456422330150682, 0.14758944331157595, 0.20104157347832957, 0.16267671760532165, 0.15169196672016574, 0.16632079867826355, 0.11679284665132723, 0.08772179409260712, 0.10954406908563069, 0.17484711212736948, 0.1107023633836258, 0.18293438058707023, 0.1693549818329273, 0.14935452521087664, 0.08779998868703844, 0.19003250696245702, 0.14861845261146947, 0.3000543927473407, 0.23912559684005477, 0.18899490215605308, 0.08203979656701127, 0.24180987699618264, 0.11578663612806028, 0.19138543355849483, 0.18931273671407856, 0.1521766858716165, 0.12398749244429412, 0.12031826836567734, 0.21148854596239908, 0.145281603439681, 0.1336769035626804, 0.13193380838680652, 0.08488331575908008, 0.1546206136023806, 0.11621114076866258, 0.17779555472154773, 0.18181347137978002, 0.15533073114291315, 0.21403206512331965, 0.11936222127969227, 0.12170794419944288, 0.13125482465951674, 0.12968106555842585, 0.18094921694888225, 0.18976521888567557, 0.23743750677714426, 0.10199513827120105, 0.11188313470131929, 0.10459115743757257, 0.07726655551983465, 0.16250208020210266, 0.13087073881779948, 0.12701052135878033, 0.12651810302369057, 0.23336421728374498, 0.21510009894207602, 0.27718504410116906, 0.202425281487165, 0.12009401910848196, 0.20904654877320414, 0.3614084440613947, 0.19984063872646904, 0.0793255010860101, 0.1754403399724153, 0.12890982952329422, 0.13159502898493122, 0.12924231168243194, 0.17076521180570128, 0.15011756410521848, 0.07648043439633424, 0.18579921234519253, 0.06820735131059924, 0.1544693112373352, 0.13475626016095762, 0.16150385231500672, 0.1425520168437112, 0.17851454356024343, 0.13526432967234042, 0.1385620011076812, 0.15482002628907082, 0.100408501232103, 0.13919577032567995, 0.23215329274535182, 0.2041066452981003, 0.1636163857314856, 0.13343863489647068, 0.14049720049144762, 0.17146055917105368, 0.1502938409365954, 0.1104658184152457, 0.14975950993116827, 0.08163449775067069, 0.21060653361341647], [0.0071028804297619055, 0.07710932363425532, 0.030137332036129894, 0.025009085844841697, 0.015205297799360369, 0.04939139685443333, 0.010763003862643195, 0.048813379685124086, 0.06262557340725776, 0.06728304324731713, 0.07647586851230553, 0.050840214675953316, 0.06466518291422436, 0.04071774937572979, 0.026181089286241802, 0.013954431351815021, 0.062350635942552364, 0.08045512837387862, 0.021803505838878696, 0.0758865247330358, 0.027970550018512917, 0.05659474540622004, 0.026318458427164345, 0.04412717771746459, 0.04195806104689837, 0.03116822974275678, 0.020449659937331756, 0.039955874935032866, 0.05240122224354456, 0.06338381276075399, 0.08254996515930661, 0.02811707007969099, 0.033012597911780885, 0.02554447022116473, 0.03622576218819426, 0.06582019835590355, 0.042565155083373676, 0.00720299854536631, 0.0372587819583714, 0.054898580776587616, 0.0507804713091783, 0.0809498219901035, 0.005672427172201776, 0.053086461078736095, 0.01188566645367011, 0.05162479979316554, 0.06049068937558801, 0.013877439515424833, 0.03915999385137712, 0.05313264468925134, 0.053087939628429955, 0.05685639890631842, 0.04160484854852961, 0.04735646431424445, 0.022634347344958977, 0.030683366949820233, 0.019367187276422497, 0.030288956158103484, 0.03199090475156423, 0.07073127394241673, 0.07873088662182132, 0.006948616177279263, 0.025346752504006993, 0.06491087497242036, 0.0414410857633958, 0.01729941063169991, 0.0891945215182439, 0.0730032225950591, 0.03709508046027153, 0.047399549099105986, 0.04632478136749518, 0.034664819738076585, 0.022549566309598666, 0.06024968960592824, 0.07559608547918259, 0.0407238167920901, 0.07222568165631064, 0.08535842816796034, 0.009735282548072358, 0.014010102961272483, 0.03531004963142257, 0.010508679908760374, 0.01273461253262095, 0.00640112042967831, 0.04841444705943427, 0.020481613464653492, 0.04926046476729455, 0.03124072847347106, 0.03757564358473305, 0.06566734849325111, 0.0890480148636045, 0.008912846941741244, 0.13701196008872601, 0.0217728661523471, 0.01957133630170457, 0.011704431118203268, 0.04516144621095831, 0.01786096648673617, 0.010874531900269852, 0.031176984212511492, 0.005608063337633447, 0.028988067999542243, 0.034293385838428815, 0.06858405972560568, 0.04743804501730108, 0.06294283339934004, 0.07030580403102983, 0.028511611106354865, 0.02098876367052717, 0.03559311145856496, 0.005335516067251804, 0.04977968468841526, 0.03487379703250143, 0.04356087786295722, 0.029907304560765628, 0.03564728919657008, 0.018962627734928843, 0.046762769155564814, 0.011021856353768419, 0.024257957702502612, 0.045491687562917514, 0.031140227313904516, 0.0586152678325532, 0.002106734370294538, 0.06339544197544456, 0.06949581926868809, 0.030698840010670886, 0.03472867699700498, 0.07482436680865866, 0.04749635963009731, 0.01646087185720042, 0.03606796722799059, 0.05983019901079036, 0.047210562869065234, 0.024265185742068197, 0.04291623785731293, 0.03718256387078474, 0.042246508472148454, 0.024468369496565674, 0.0557612800489991, 0.01837960418103443, 0.030945150684865735, 0.03689813074625788, 0.024678176081168558, 0.03487913283489404, 0.031325114973550366, 0.014541555391324144, 0.02391232755936442, 0.03033094735245311, 0.019469912006189267, 0.022500101927547686, 0.07011730043638138, 0.02907850084856393, 0.0603737996801013, 0.050358364523779, 0.023187049138810367, 0.015482554595256525, 0.04075519958390825, 0.022551877979910182, 0.05260107926123085, 0.03729931184000546, 0.02628272234071647, 0.028761313634834466, 0.020780291994132345, 0.03542498963314199, 0.05074312835330925, 0.0177057130232213, 0.053727331931792924, 0.06793984106831974, 0.053477851568811366, 0.1491918694227934, 0.07923051384427855, 0.05649051914412168, 0.01224642491809303, 0.058520610008629105, 0.061434689728963765, 0.015563458268110071, 0.052547587171917966, 0.06528157725810044, 0.046648771441992254, 0.03376937786778135, 0.09638582716786093, 0.08376519511183424, 0.024688035632754048, 0.06344475505513049, 0.04610923869955925, 0.10324753880981477, 0.044966710491045836, 0.040789807605887615, 0.013972165329652208, 0.046855461963963126, 0.011524546970312875, 0.05965918520345323, 0.033343796873645436, 0.030271100563808318, 0.04691473418666471, 0.011137075019970296, 0.05847701960573754, 0.010461894919224566, 0.0660155201330781, 0.02617051727288673, 0.060426778490504915, 0.020842977138536594, 0.015496702323998175, 0.04434635930304085, 0.028372974089917638, 0.06108782426904767, 0.05228176998395113, 0.08333402550629071, 0.030521502147518823, 0.052579081046485135, 0.05680782893191903, 0.024425244492088116, 0.05291043322593455, 0.018158036231574033, 0.07913889738941386, 0.049986478632255915, 0.013628307722448824, 0.03318956039185005, 0.05346772388645238, 0.0241087103683141, 0.04377692614892318, 0.03679120402422644, 0.0649465516870541, 0.022967898196751074, 0.001858983929606996, 0.03642853417043244, 0.0587761999228068, 0.035031840971280495, 0.04205468005590862, 0.03567873327542217, 0.01746545061318865, 0.028397197790083387, 0.06747829607657849, 0.022418624646360838, 0.044306679779002746, 0.03898539092211474, 0.035515116046993964, 0.03946945506839022, 0.05154123492238503, 0.008060718725074925, 0.02146925401663588, 0.0723606893312066, 0.06706165915895855, 0.030053843774141806, 0.04219817215456598, 0.014693484990857543, 0.07252669292351893, 0.03507464230361004, 0.01890452379631179, 0.015943800812707316, 0.013634504416146347, 0.01913401309490925, 0.0519526701029991, 0.030867442556266344, 0.04066212373154779, 0.020073897640911803, 0.04900950968505875, 0.03809605477257602, 0.0539519029459165, 0.015877330236347215, 0.03026125058832188, 0.0039498638709060735, 0.025527549254137184, 0.05758959484556991, 0.0268307241851524, 0.05465699494966576, 0.023265760842590563, 0.08046345574961555, 0.056401698910180605, 0.01804612036193571, 0.016683405077445413, 0.025161772913810228, 0.07895523547044686, 0.024182727868338267, 0.024750556068254576, 0.04381648692933302, 0.09994720904937676, 0.034781648146529356, 0.042265526604868715, 0.027597618416973183, 0.024296978390925837, 0.04263851949344239, 0.024325086156867688, 0.017689142541419116, 0.07008231320087949, 0.06025517862590571, 0.04189647906910508, 0.06753969802370957, 0.042071453551010746, 0.0654653923946523, 0.0667405917098926, 0.048776523195086956, 0.020851722032192255, 0.014624801378006176, 0.08353194432152856, 0.040091503141147476, 0.04847944578936985, 0.04609870882104001, 0.03509759046738187, 0.0034325443266425286, 0.01534941042923639, 0.04075702670360765, 0.013991785799002936, 0.020044219394725178, 0.03792763417286258, 0.05732442883233871, 0.035257074651458574, 0.07009866151718364, 0.03838362119671318, 0.018947463024467714, 0.026802876889104807, 0.030519100461876204, 0.04905143001627538, 0.07475648375768816, 0.04924456461242611, 0.027189942812847517, 0.06774231295792327, 0.08128854776582412, 0.032933411233487635, 0.023187669670029033, 0.03975467726347908, 0.041014409263528166, 0.03470724568732324, 0.019324173354693962, 0.01706760008669188, 0.025198470440603075, 0.01821715715191057, 0.02736418951122511, 0.02994058342019637, 0.062186727600712935, 0.024790587992737853, 0.03666676453224594, 0.03181493627057681, 0.05520829863305535, 0.030616947126785116, 0.04255416938253949, 0.0443982157946354, 0.06885687895720044, 0.015753061198929868, 0.02182539297087539, 0.07165162899200955, 0.03603919679599424, 0.033281670973425916, 0.058064121197188096, 0.04434535955829967, 0.011800170083710504, 0.025289075659407724, 0.03651887125846359, 0.03289268599943288, 0.05641821576582809, 0.033921948108341426, 0.16215237638642713, 0.16798391427484252, 0.14719188964414984, 0.0988196348771453, 0.18968796657939113, 0.1903364906508115, 0.22480255653781278, 0.29387580170746774, 0.12267918280896642, 0.18769897250158174, 0.19893993383213399, 0.16838221870843442, 0.17764676512489397, 0.08967401595005105, 0.16686818382192045, 0.13819374264247958, 0.13649238393672053, 0.12953639751480472, 0.15025386646870645, 0.100208874040794, 0.10977302212268115, 0.13725297134970466, 0.11603111776733592, 0.10500284542720165, 0.1861393094182976, 0.15749954137830965, 0.10359237796717113, 0.14219419249603826, 0.07275157037281221, 0.1598363393737424, 0.15072395334080343, 0.13659767506103362, 0.21074606886794492, 0.11280198055770128, 0.1255162745233505, 0.18378003440316648, 0.10292452549742115, 0.10573725561581312, 0.07789133086560235, 0.2151599610524793, 0.1313691096560609, 0.14567423882263322, 0.1225534141544373, 0.1584245312598444, 0.12105824035261908, 0.15655449531491727, 0.13041114735026516, 0.20255395361492712, 0.12559144307048092, 0.14436099558107315, 0.21075995038113288, 0.12603803402594022, 0.1288625925418831, 0.21420066575369529, 0.09517776779830457, 0.09634731592790735, 0.12456695368934063, 0.12027016570491177, 0.06416452530350897, 0.12458030660186084, 0.175209624933139, 0.09210105910296403, 0.12131415202372497, 0.09699657544373505, 0.12474576627174694, 0.09072374026741713, 0.13305978909615548, 0.15964038940446992, 0.11948086531652559, 0.11077841293186912, 0.10619483993298585, 0.2366886405094016, 0.10906887240707876, 0.1559791019967487, 0.18095499325183131, 0.1816040689065572, 0.13832837493429262, 0.11574363561287043, 0.16272933252396124, 0.201138008626238, 0.1561474115137131, 0.2067571409767674, 0.2221086849608729, 0.21424001202948634, 0.2651799253879055, 0.09424550008148917, 0.11890689692189617, 0.20558136455234022, 0.1675343125938408, 0.15263246222128793, 0.163795359192356, 0.11287928649014044, 0.20898235060514944, 0.07644960701826119, 0.1371824452953954, 0.1522431056946516, 0.19540883540626497, 0.15327842755904122, 0.15852039950268884, 0.12074069690800483, 0.1459698568308546, 0.20569825424782692, 0.12229629206441103, 0.11029395425031263, 0.16318077281598123, 0.13933432498766532, 0.17282024266258364, 0.0883169984444976, 0.2186187714218132, 0.14785432587227515, 0.15427147669176902, 0.15430699252793867, 0.15755898980123384, 0.10607173726443322, 0.09766241310224419, 0.16375913855529603, 0.09587673109865959, 0.1254690988289733, 0.08446287138447647, 0.15127196667655823, 0.260366901394821, 0.13387188826116825, 0.1314551260081991, 0.10543475047715249, 0.13220072874138433, 0.1878407294110906, 0.12925433926284313, 0.1552527587139799, 0.12596999775738488, 0.1379379612063208, 0.0748743080804425, 0.1331205551903094, 0.18793108182088022, 0.12678521490024944, 0.12892104505050567, 0.18789463135744297, 0.10907053481787445, 0.16184997083919664, 0.14929349864682845, 0.14717310516824647, 0.14907144040109652, 0.16759743823880152, 0.1436613274798278, 0.1330529402701124, 0.07706387163770777, 0.10484396645258512, 0.11614970817801454, 0.12240473947097218, 0.1655270090146411, 0.0862056218207844, 0.11904254044976928, 0.18647572926936612, 0.13202405354428676, 0.16123322409487542, 0.09717913419609109, 0.1463113788274988, 0.10631566732040337, 0.136778824211609, 0.16839351084443832, 0.11436555068939926, 0.10991599711198961, 0.12640260760822605, 0.15218407095920655, 0.10905390304903831, 0.07155917750130739, 0.18912335977919642, 0.08459001133639006, 0.09186027000748342, 0.11632059941128378, 0.13106958459942572, 0.15229680845814367, 0.27191331730254237, 0.13886550982152263, 0.08175026129690871, 0.1516144233004701, 0.14143335993491835], [0.07081646291959671, 0.05884361566014348, 0.017704772650294246, 0.019313317888806907, 0.02264770983357824, 0.05406743666577724, 0.036384495606105176, 0.03887888554844164, 0.040478415847305334, 0.035862119402736425, 0.023826428035634662, 0.018223703373223543, 0.030952011002227667, 0.013443341538790735, 0.03580612986679039, 0.004087713971403578, 0.0160474055859771, 0.04621787379766184, 0.02838013701200966, 0.04678804622662645, 0.041745770422201005, 0.03256318775276023, 0.05456510653358795, 0.03151658524368559, 0.040438115792048555, 0.0568871075407632, 0.00417561489983552, 0.03820051086105166, 0.0829639820562255, 0.023594895197499185, 0.029610368881314516, 0.07323616695019507, 0.029920159516135053, 0.05239481008761833, 0.08340210774012151, 0.047656866541552934, 0.015345604887472527, 0.05755179989782553, 0.08197366785738738, 0.0706264271490997, 0.04540187907555411, 0.02638820690223046, 0.05245124778500008, 0.041497090621100324, 0.051460156006918806, 0.08821488658507025, 0.051931472450134256, 0.03844493887417259, 0.030815354323074706, 0.05796268732557374, 0.0539341488582713, 0.01639829396510557, 0.014785939354389427, 0.026641418113403266, 0.035768254479813966, 0.10102406820102085, 0.016004442417573546, 0.022739471845148553, 0.04746653965764469, 0.020283972356288184, 0.03492689458653331, 0.08456410224279089, 0.057074845047487374, 0.056257375606125405, 0.04314535943370673, 0.029849616224847497, 0.039457967579965635, 0.03867776065524067, 0.02843088076089419, 0.03223670023163, 0.04245695665538792, 0.0014526037322807937, 0.01832595121325745, 0.01367496343464741, 0.014246644099212944, 0.015307391464199512, 0.02006801408565333, 0.09321082173095596, 0.022999455273571997, 0.05727359506812307, 0.05855259800990743, 0.03998810042356772, 0.06366950609991628, 0.006530758307030004, 0.09433587547391654, 0.02499045841696282, 0.04846017101719495, 0.03045364590962568, 0.044134654735605565, 0.06621108705838842, 0.04468934069718084, 0.012245715329153164, 0.056579274260589195, 0.014132969100178491, 0.019035854249171192, 0.030637836429260434, 0.046002085981590134, 0.10591092774824751, 0.02044350250564035, 0.034938347601001306, 0.04341450910414419, 0.023823618408172362, 0.05391221959143878, 0.024541274253879825, 0.0781710372276364, 0.06537069626633199, 0.042250507451113195, 0.06641172548575748, 0.01367498162923561, 0.028295850103360512, 0.032517038616201574, 0.03532646306520028, 0.019663391341905923, 0.015046643863071599, 0.037923298115211154, 0.06970094697129342, 0.06550122232687089, 0.015233797227753507, 0.026039303648435784, 0.03492446225737372, 0.02510213105368518, 0.08778782321080085, 0.08861782585060404, 0.01254137547221035, 0.08207897430345898, 0.01707735238596797, 0.06965552561826284, 0.03962508966064742, 0.013746291966057353, 0.03264448117284525, 0.030918519553397934, 0.033042812419514504, 0.03722893900328106, 0.018068017070031455, 0.0202955900796599, 0.023037805635061477, 0.06794777773921529, 0.027132486218526482, 0.02363784208653435, 0.061144147053240776, 0.020268972354730772, 0.07152176942796477, 0.04811631245238166, 0.09551590368632348, 0.06777416689381485, 0.0449708205527596, 0.04289256957089228, 0.08914878606916436, 0.015087148846848118, 0.036263878892866835, 0.0051442780175186215, 0.021782549503710003, 0.012150684037365982, 0.035298788138935645, 0.02631166322727598, 0.0507912271836352, 0.10061277857711239, 0.01649261662556279, 0.03846977927511738, 0.034440352145822785, 0.04844329410022305, 0.013617825724424855, 0.0412124123484377, 0.005913207649193224, 0.030555349827233343, 0.0465082670862396, 0.08660651563156037, 0.033923327066605134, 0.04471027021927219, 0.03120076741212078, 0.034225859018343116, 0.013986303482294805, 0.009686050865228378, 0.0680740443508952, 0.021976764283833966, 0.060503835444368666, 0.03519690227544597, 0.014751893449424496, 0.03386847517122665, 0.04202948725451866, 0.06143293538761716, 0.054510833034592296, 0.03804822024258395, 0.028826107436250296, 0.016757020381309332, 0.03907522239211587, 0.027398180832425435, 0.029276339224569743, 0.04075740974756979, 0.054120553372007225, 0.025317800126128623, 0.04209837771110958, 0.00847399634714689, 0.06397566930841535, 0.01361645729987011, 0.04322314417109855, 0.016529162849990592, 0.02068613021213922, 0.0654139572514161, 0.010815149552429156, 0.018324194956691037, 0.029106265790159666, 0.010461921732301914, 0.061013149848628434, 0.12205508928145133, 0.038814097492685246, 0.05694315836374318, 0.050606285897834655, 0.03295728636364783, 0.07569597568362951, 0.024212687651837067, 0.03272970079354221, 0.03666785620753804, 0.024720320493103038, 0.023649739431998423, 0.11272584673978629, 0.005868179395028781, 0.0916708241246881, 0.03354738090908335, 0.030889051981390487, 0.058768761209062034, 0.06303570240796094, 0.045216340241172624, 0.02376709452589914, 0.014190181503973663, 0.04533120363409962, 0.013476517933961606, 0.0587205206524701, 0.03988163335429084, 0.04378479770234516, 0.061176797720573606, 0.052154921145448764, 0.03514638643771891, 0.03450649617720516, 0.07878454342003792, 0.06442874519815368, 0.04214183021817477, 0.08049130304566315, 0.025893961447441292, 0.031334587650734096, 0.10216151724659628, 0.011013927343752115, 0.0804954475813335, 0.032435783500512766, 0.07549113143355617, 0.037933299393062635, 0.06643724387451526, 0.026366070791658376, 0.07754906576367156, 0.028498610594279827, 0.037259624655088114, 0.05845422465955058, 0.025602754190443985, 0.026737345728061856, 0.04473409555371731, 0.046057451155877886, 0.0637937157655195, 0.04967453912080777, 0.06504012932700497, 0.0781908865657545, 0.019147710746995384, 0.008800713694654405, 0.02295515815457029, 0.02262813245667325, 0.03073274897741935, 0.03636329412280071, 0.004930290986873931, 0.045391280249121695, 0.023551251168452927, 0.06085153594012223, 0.04180164121451878, 0.0498428869421684, 0.022503396105622093, 0.0555368852350981, 0.043426486888840314, 0.014048917763566059, 0.078910626170616, 0.021712473526056257, 0.026078988918133324, 0.0978341393713509, 0.0238239650629581, 0.07682119796593344, 0.0291930558911014, 0.0568760299093781, 0.03209487437420795, 0.02158289741454346, 0.02671048668543658, 0.10321281204420714, 0.016925988733888637, 0.009630400323188834, 0.011231881273429722, 0.06721345182027548, 0.05753262854752041, 0.04750582081596217, 0.027496042819092834, 0.04866012379587178, 0.01307773373780712, 0.0786314637310082, 0.02589245799988989, 0.0331702396543997, 0.014898818579592533, 0.07037267584594027, 0.022946296432506175, 0.017209504468126163, 0.05000613644839295, 0.07103983883655841, 0.04799980580085709, 0.03082809436525549, 0.04218928553464432, 0.052303128515280066, 0.03614842178179853, 0.05823541462661759, 0.06044097793018145, 0.02353514608506474, 0.02583782443956983, 0.005326818096481505, 0.016821339208212112, 0.06761123531407888, 0.039975816203701886, 0.05705200413602495, 0.039855053933757933, 0.04960022859215256, 0.049954065452179605, 0.0279125246039081, 0.0733766291711119, 0.06938204755105319, 0.05319695777049469, 0.059141424679828275, 0.038413027481686686, 0.017457889325376, 0.037633801149504806, 0.044319829678223024, 0.023222417503054586, 0.04373072338620982, 0.022297594245643388, 0.02676374128749294, 0.06267311682383861, 0.04656165192324308, 0.02810098031806129, 0.08448949293984521, 0.03673303496813582, 0.06561588270649796, 0.012265514871556193, 0.09146935832236083, 0.03049519851863865, 0.03477470738993537, 0.01467828963687944, 0.06457757309920366, 0.032843181397765875, 0.06238103814182743, 0.043738296165341334, 0.02990308724674246, 0.14394649604876197, 0.19379147058052404, 0.13533082610416797, 0.14035107688077036, 0.18060122917015708, 0.12485686434252609, 0.10854477633632, 0.16089968473440217, 0.08292802188905977, 0.14748649641631112, 0.17175181047810664, 0.09048195525763497, 0.14644530631842154, 0.13947862530908278, 0.15018513306014, 0.14000045375958567, 0.09038289242814626, 0.14491988736535275, 0.21233259099385432, 0.14983518409632868, 0.1443388249965445, 0.147012839574487, 0.16581824499993555, 0.1256224543096558, 0.1519955826863166, 0.09153761675641423, 0.1465150662848065, 0.10555475815049103, 0.20074037835001948, 0.13171027925225998, 0.1098180068055949, 0.12747280945580813, 0.11458518043641122, 0.12623576898007624, 0.27164846538536014, 0.153812084407095, 0.11122620664536954, 0.11531296396447767, 0.1423656889387677, 0.20603455152482758, 0.1340075777543168, 0.11311082890437496, 0.16880922079566987, 0.22428975260305792, 0.16704275993810547, 0.16472013456927193, 0.16867458850385683, 0.17998615249751077, 0.09947324577238291, 0.12488245167919707, 0.18759256288889917, 0.2027021763065169, 0.2599563701979576, 0.25165943879513974, 0.11905831420013022, 0.14647176699532619, 0.18081047842579503, 0.12663595798996188, 0.17198994124848999, 0.17667783244002253, 0.09583187665069297, 0.20440777913937647, 0.08870086212071682, 0.09081947827531446, 0.11696440438109061, 0.07303773485604795, 0.1477150051223655, 0.2065761144002599, 0.20875777959102587, 0.09253961379609763, 0.23293913041632022, 0.21038873481654355, 0.2457488099894216, 0.09765682832127619, 0.16690446574601436, 0.09386163640526995, 0.08966192708260591, 0.18407254209441526, 0.18523854323692862, 0.21903144766486463, 0.22666286316610154, 0.186977869260215, 0.12894087140598606, 0.20557705913820576, 0.10025722184969534, 0.12466937964481693, 0.12440248227287685, 0.11951307165286235, 0.060147616050897114, 0.13402081575364838, 0.13482664831944052, 0.15603557799852666, 0.1612468757816861, 0.13048058555972192, 0.07499417785795466, 0.1714872803178526, 0.1425565674059814, 0.15038396352000777, 0.16179441414292783, 0.13489293024664925, 0.15097942834179248, 0.11273205971285222, 0.20701814713256977, 0.15849626773307401, 0.1363312296809689, 0.1128625091645987, 0.14714692028299456, 0.13362358384315046, 0.08137521529269796, 0.14253467261310548, 0.1253130313970389, 0.2132084439959257, 0.1229526302326591, 0.10389210986754588, 0.09303384009868869, 0.14482178214576938, 0.1242767978880194, 0.19529533181940356, 0.11213153871076723, 0.13619754733818193, 0.11765529311472371, 0.24921695130967328, 0.1594020594512263, 0.12749092743521737, 0.222520625759517, 0.20306426010304884, 0.10556960493446359, 0.12222073281243925, 0.16914655995224753, 0.14236786462847265, 0.11332870431004033, 0.2164828570018853, 0.13636242478124558, 0.0906254971520074, 0.13529075970572813, 0.09723119753142519, 0.2972720226933879, 0.171169032072348, 0.08742763931232114, 0.1102214823326757, 0.18703103576216007, 0.18878877853914616, 0.11399162317355795, 0.2519877687577279, 0.1655043174903239, 0.16678536971730573, 0.11736448613866685, 0.15286588921181618, 0.16261317827288183, 0.20518889770873133, 0.0734605847467338, 0.16210835697429796, 0.10026569478213788, 0.15224060824801847, 0.11340477684092139, 0.13620508564335687, 0.18256226103873024, 0.15334544493065727, 0.16791190200996015, 0.0971595912931427, 0.2124553948881165, 0.16658506836862336, 0.1639470752448805, 0.20348399967676212, 0.13761084166265306, 0.14605876899534656, 0.23933047939452434, 0.16715511439308045, 0.12936675500485206, 0.08515123968883868, 0.14453399355613417, 0.19709016857368333, 0.09508651906564351, 0.1333831394872358, 0.1090334255188223, 0.158466451591061], [0.024275338322284724, 0.038947335504476106, 0.011660355207089697, 0.023794457271334626, 0.09327350304492059, 0.10591757739143026, 0.03973524927371933, 0.03247302686495166, 0.03301133386670582, 0.04237236905722849, 0.0059049147474128875, 0.03725382536950131, 0.038069961817875024, 0.015946845054596422, 0.0555050810949216, 0.019467198139717503, 0.03681128701916145, 0.0489885610107693, 0.04077547027038471, 0.030122921922274178, 0.03357871390518642, 0.023542431581224647, 0.03883057987437614, 0.026498372260961803, 0.03816506780323483, 0.028496553648203134, 0.03398704642970716, 0.03707513153072327, 0.05035315895633352, 0.02187898656683824, 0.03997424189301749, 0.026768533167459314, 0.01315741933086106, 0.007272551668011734, 0.019300999194984476, 0.0077602102030669496, 0.07526923406628833, 0.040939677386514606, 0.06227788057238345, 0.03917846806167115, 0.09590523723032206, 0.02940705680708972, 0.022921883125579166, 0.03477895917791513, 0.009280302929842185, 0.09939525036081191, 0.030928352291906075, 0.07861647905120928, 0.08830648771817647, 0.03985610347421419, 0.038133547115590305, 0.09741184106397052, 0.04222158380153199, 0.06950027023952815, 0.04920325332110928, 0.02063016557405072, 0.15182666029901276, 0.05192219895581084, 0.004961215083547418, 0.016983901150524616, 0.04507421177902049, 0.07265614646096384, 0.06147464887509423, 0.011684802030363392, 0.025555827474642186, 0.013278019764731008, 0.016515078323502696, 0.046439629438663685, 0.05666800256397936, 0.046475601097148274, 0.0483584153886524, 0.0707576503496497, 0.07842796779568158, 0.029297354931552565, 0.01693427780522935, 0.04425574642335696, 0.018115378540730285, 0.07654321530172903, 0.03585007267012712, 0.051504715511034575, 0.05413801251580158, 0.03985416144132614, 0.09101542824458692, 0.014876857711633128, 0.041007238680556904, 0.09161485374094018, 0.026689007495259567, 0.045459875761861765, 0.0010605979778413332, 0.0645416972017096, 0.015997763088483725, 0.08665883177590948, 0.06072904997234864, 0.01811115931148731, 0.0919779564344114, 0.03634147210827759, 0.023231681421278946, 0.03828312578280607, 0.06443391629164258, 0.03413577090888735, 0.06530947051942348, 0.02407227905707494, 0.08418601486952075, 0.0034061784531185108, 0.025988017892344825, 0.036500462165643136, 0.04500881468336429, 0.04412400611345807, 0.043973377905786044, 0.028985752498791106, 0.1025685397607665, 0.005809710128232838, 0.019523599447922844, 0.05049025422082313, 0.09912868240667928, 0.061611085303968964, 0.0071292625826543145, 0.0474462459885305, 0.024361603652998328, 0.049253508688942085, 0.054983635688380855, 0.05025472814938234, 0.06780736148357391, 0.04191804444417358, 0.004512962674902332, 0.04011831238805767, 0.025541809980847666, 0.020284142810851336, 0.026720627774334243, 0.09016311712442868, 0.04329726317777269, 0.015249289440802269, 0.043130397736545534, 0.026239624149316264, 0.038706125060637156, 0.05509445796750727, 0.02014853758737445, 0.020357193124871102, 0.04218286188739923, 0.016791655216366053, 0.02952406716142451, 0.007675855782919474, 0.033353982012598746, 0.02180024421954107, 0.0433362991879544, 0.04030088263173257, 0.055430406674502365, 0.12056762232415139, 0.025158181876665162, 0.03121150221915976, 0.011949753538975793, 0.06443010883465891, 0.0168850336734566, 0.05076000527028115, 0.0425352891456456, 0.02402993737749996, 0.05190434910717511, 0.014829751922779027, 0.08003531985225217, 0.044027505848076076, 0.008538060449814845, 0.04138110490936426, 0.068571480561889, 0.06829298461877531, 0.03851202519370183, 0.0528164457289442, 0.032945036617738586, 0.07129476991512122, 0.03370026907613201, 0.03651030256503052, 0.041061443231639363, 0.040873652098760496, 0.05379219276590213, 0.08814184776236934, 0.028453691028839642, 0.027026360058375908, 0.004937623884724153, 0.029555629983904864, 0.06096264550222024, 0.0772434426471591, 0.019518171714979316, 0.0692416466171703, 0.05125168050008436, 0.017797302665008653, 0.0464213773938677, 0.10857800923047528, 0.01883997514303173, 0.04652405998879864, 0.006035687392502423, 0.03133381581715038, 0.05166022752922389, 0.014587221892490504, 0.029845684278576128, 0.033735578068562096, 0.051832995677907626, 0.01116011128385341, 0.07132890679302716, 0.061775974238351475, 0.011006753887951134, 0.03449113994476295, 0.011410503291464862, 0.03217865374960727, 0.04078618784044539, 0.07142644510754655, 0.04133202165605561, 0.05372306865249431, 0.06079009568859493, 0.043148209280785055, 0.055027406121934616, 0.021704247656969294, 0.02815875100843128, 0.029810767906207233, 0.04198574363404224, 0.01248632726680127, 0.04287055220394846, 0.09634736189318281, 0.04755167117823036, 0.026522774076569947, 0.02965394779288721, 0.0720883833785211, 0.009926719301860901, 0.03814112755560106, 0.08002236530545258, 0.04544227489180142, 0.015903266143023728, 0.04932149133134273, 0.11061411771562793, 0.08111945683917693, 0.01060517059804331, 0.015025822550899562, 0.02547119008076768, 0.01868751598522067, 0.048971936902812416, 0.02722175078346364, 0.023650796633333932, 0.032778795538169724, 0.04074330989932341, 0.04809920570903248, 0.031957964886039976, 0.023229867708118215, 0.03852874506264925, 0.0306585016510179, 0.029814621328466365, 0.04514237445208334, 0.011857958968668696, 0.023320995781931187, 0.016324621204647328, 0.13948835462572115, 0.1552497556493167, 0.007432191942503015, 0.014863199321553113, 0.07048352110770441, 0.05389537714842347, 0.09338499948142037, 0.03534895157621753, 0.015819011793111362, 0.042552932150541775, 0.033316547126178785, 0.0568311065134983, 0.017164843457360423, 0.10551501350897936, 0.009948579620780244, 0.05946670944291738, 0.014393232150694296, 0.04345304715717512, 0.06874525994663278, 0.035533490665857835, 0.03081681563579027, 0.041348266550489975, 0.046687298003704324, 0.020768005859046694, 0.027125258178960894, 0.009531451449278862, 0.023803232808507258, 0.05615141032443893, 0.049355501804741166, 0.0261636033293701, 0.09056824740142592, 0.06905374057110279, 0.024846702017971588, 0.027214821518188523, 0.028401558745592356, 0.06896208581184188, 0.0769188205501245, 0.032643240110407916, 0.02643872657039714, 0.08010429074807514, 0.031046573065161228, 0.023873174720774257, 0.055254520547966805, 0.02195420490968372, 0.037673415556069345, 0.009003784451183052, 0.013910656130211729, 0.02126904459850442, 0.04300313904100368, 0.016093959791525718, 0.025861818313358292, 0.03787687701743938, 0.04939623086923554, 0.0262047671487615, 0.06629207021286411, 0.0389304394353061, 0.01593872931064858, 0.014278530593841307, 0.023295364395204573, 0.05527559945720339, 0.03272802689142766, 0.021605401247319196, 0.019829655404112512, 0.003995250271175117, 0.0660369782558372, 0.06082933471207658, 0.026051765983744014, 0.010181972137351912, 0.02522399265980048, 0.01973540743722791, 0.030539376894012097, 0.027541014095467907, 0.008205653941859643, 0.09539155995533352, 0.041905507415292725, 0.05355148027921396, 0.05169001685815954, 0.0469507786235021, 0.091126334793385, 0.04501665942370892, 0.026732954129035917, 0.015518898763994296, 0.04988251667049143, 0.03238054856117214, 0.008458167055411445, 0.04298151237890125, 0.005544876884443746, 0.15143348865451353, 0.03793246818766479, 0.06125741315284564, 0.020942790734191096, 0.07495775803803437, 0.05607105919250077, 0.02900461358348689, 0.014424960639688277, 0.024675360708046826, 0.05270640868994017, 0.038143353041021094, 0.03249539280190103, 0.0934518329919346, 0.015554385871866779, 0.04232456134031377, 0.053582652396852934, 0.011726521263499896, 0.008522537593249111, 0.12478133573407128, 0.18974975923136359, 0.15348145618073403, 0.15733805004387133, 0.20935114533189805, 0.18401539193526392, 0.12458448944192742, 0.09304516287820955, 0.1742096350438172, 0.1446515114437188, 0.1101715870261673, 0.17677593765960586, 0.13012699001739103, 0.09742727773564477, 0.20467131338532896, 0.1313415151690283, 0.1701430564806346, 0.060221133678550684, 0.11289707505174222, 0.06291623482660902, 0.16669639626577978, 0.15445639499493186, 0.09240648303661617, 0.11954455786655027, 0.12251034469133425, 0.11310314504249443, 0.11254634467824814, 0.16066846407709584, 0.134977858753935, 0.15870510330123289, 0.09287158267632609, 0.1779439919177563, 0.18250999852053582, 0.10103892264587265, 0.09833212716565018, 0.12962207678825627, 0.16662807654469244, 0.14769890195419713, 0.10988104818088394, 0.16756313282155222, 0.2642061663491111, 0.1419955612190308, 0.12119863362562273, 0.19844645063482946, 0.10482815439782797, 0.16325833155743538, 0.12382496689115802, 0.16309699344058193, 0.1785787723718151, 0.1673687303498868, 0.12743304183165874, 0.18786195004659315, 0.08848160775678773, 0.178587950105148, 0.2604597206077268, 0.1305341810709046, 0.1797289921030883, 0.18292999856414335, 0.07863555464052385, 0.13677269550821475, 0.08903293059237542, 0.18657288453992338, 0.19123178696440113, 0.13994002474411843, 0.11921487958921541, 0.18392603543977584, 0.11538032607565965, 0.15192386153484547, 0.14999780924089495, 0.10364788103728526, 0.1735289506013355, 0.26469238703289344, 0.30472866289557954, 0.06831404437581379, 0.1019333302974701, 0.15554410195158375, 0.1384476395023446, 0.24663043929444206, 0.15377223251327393, 0.07375147599246233, 0.09522210130648268, 0.12945784285904902, 0.17625311329480142, 0.17020178478090994, 0.22818337915645492, 0.23785042816833143, 0.1240951584411725, 0.1333331905545727, 0.1257041039606256, 0.14002558144350208, 0.16234527732576096, 0.2417338044653016, 0.09730845749858888, 0.10550893077086057, 0.29559533201879074, 0.1517265172855508, 0.13941936074726044, 0.09759149634309354, 0.16613738190743232, 0.08047408138912532, 0.14063284401932072, 0.13915244039268265, 0.13916839034326617, 0.11578233071392584, 0.1439113019695205, 0.17958213304800374, 0.14748841163612184, 0.1674316721337457, 0.14700274253564496, 0.2681805385697273, 0.22530157088993058, 0.11151831597089769, 0.10886700823903085, 0.26084598213914906, 0.16297780548132237, 0.11436925089407353, 0.17723110113893786, 0.11658323733436486, 0.1526574060441025, 0.14647656270573217, 0.10630367038350914, 0.20903130362351097, 0.17308184636696694, 0.17968535573492128, 0.10180523273565116, 0.18532495795478746, 0.11181587218156747, 0.1182145985864824, 0.11572001712216486, 0.1766258916787563, 0.17290210681817225, 0.16336418958681245, 0.15437077700851426, 0.09740162911193986, 0.138579253407736, 0.2041848015881354, 0.150936282269897, 0.08050107066669772, 0.144951005856837, 0.08106547062315288, 0.11639465713092398, 0.1313363210929017, 0.12906948224671427, 0.07315758931180162, 0.16284516501811244, 0.10791911998943937, 0.17104333236573205, 0.18468824695915947, 0.10103581998977931, 0.13635802743656023, 0.13424039187450565, 0.2012005060791008, 0.09271120216937796, 0.104395046589836, 0.18283206188390333, 0.12781584830654244, 0.237148737594966, 0.11353019309500534, 0.21920133532295305, 0.14120966226102846, 0.1765589049506572, 0.0967340677556011, 0.2418720986573927, 0.1581055475699325, 0.1281223294415301, 0.18360948790946316, 0.1317366479986137, 0.16899086024251678, 0.13731551476784293, 0.21193777992119714, 0.11684880171331669, 0.06396348084954005, 0.1449538863474323, 0.16770960883267466, 0.10130104729004445, 0.10097830976930358], [0.009807925877882349, 0.04140272774102707, 0.013759629556819076, 0.028580246838710965, 0.00783612137667895, 0.03565456320141112, 0.005969862724023481, 0.08975620186256786, 0.0679441464824542, 0.04496434710979943, 0.022110923516353773, 0.027090920202974832, 0.02008410193206322, 0.09738800806864616, 0.060121277948060346, 0.05889054237594528, 0.09159629143053487, 0.021828227496195226, 0.0021045105606918376, 0.008113535699404536, 0.03668587842595674, 0.032590111912859064, 0.01839361018351009, 0.011134906033534678, 0.056544225738053365, 0.043822584989210295, 0.037356523286190726, 0.016883296569088296, 0.06160870277052445, 0.04630824152920996, 0.01603812443077444, 0.06081482883723033, 0.07403493618532535, 0.08562623718453032, 0.02165290635950383, 0.03268589971647148, 0.05479562622044356, 0.005895957743163191, 0.01974062449599226, 0.05773659179648084, 0.030622949425671852, 0.03179703279578638, 0.0023449891511606235, 0.011149742283798274, 0.02918849575273212, 0.09109761415710373, 0.01766489968905526, 0.032315523018159216, 0.04602061381803886, 0.026238088143028082, 0.04457798598694705, 0.028102684863692814, 0.040390250618539514, 0.03125861088084358, 0.060779060192045674, 0.011047225355380967, 0.08578880104206263, 0.02407718968066958, 0.056083358734125094, 0.05161720020095668, 0.05249547021042916, 0.08181959225405609, 0.04383576936238716, 0.004025388409518787, 0.05894293512908682, 0.1521728554319951, 0.06238866837755327, 0.08369477630983438, 0.03186210238885495, 0.03965600513883176, 0.04195325384517351, 0.04223147782707407, 0.07539430558080636, 0.04209469665863341, 0.06084169554073484, 0.03122022029973807, 0.016631263218099074, 0.0669301218623596, 0.11197371693748621, 0.05379205487007576, 0.1267026995699252, 0.006516218915837067, 0.053086706226871866, 0.04958861086878085, 0.05189678781936246, 0.025620473804132595, 0.04272897532510181, 0.02296821803845946, 0.053968071231558445, 0.04639326579748623, 0.061472162919779944, 0.08756170469907024, 0.06801736916625692, 0.047999909222726865, 0.12545881792902946, 0.03431255335829431, 0.01555879758070073, 0.026124339408030915, 0.016545639486022053, 0.016972829264798955, 0.06361702907710307, 0.0983071297166809, 0.026287429951011177, 0.0073966191285440045, 0.032764952329377976, 0.034098872284014384, 0.02063420860307111, 0.0493450753480917, 0.022224582236019835, 0.038072581838576064, 0.04375895755665918, 0.03144873092101226, 0.03901962739145083, 0.05512546537624252, 0.06430850769843786, 0.01285241770317718, 0.07536394551636712, 0.09695993345831672, 0.047560040688803124, 0.0071807685890235015, 0.07123273211501299, 0.019461571223913662, 0.05347060054660805, 0.04756568675680507, 0.023733622229267514, 0.003369987741368072, 0.024806980359097643, 0.10137933381502667, 0.07367739529018441, 0.021800575552568324, 0.02720661288607986, 0.05595262966028625, 0.0429897363327684, 0.03004492076504375, 0.0807425722239479, 0.006236299006794129, 0.07669012798296829, 0.03399917360154852, 0.05843933191030257, 0.016245785011579434, 0.02781476412389067, 0.036154171271670255, 0.022541857549860593, 0.06661003500583672, 0.029984156586109634, 0.05282242887563283, 0.09575295427273359, 0.049842025093253584, 0.04977069081618421, 0.018152499331101295, 0.049302817938188394, 0.05926533557114102, 0.022289715031342163, 0.05121806073152731, 0.039444200979966315, 0.07335104949532018, 0.04144723744942777, 0.044976359368452144, 0.041013340570873795, 0.05362879004209273, 0.0601369291243534, 0.025635303351126855, 0.04551270901555977, 0.07139804622819347, 0.04725693034068231, 0.019598308342298674, 0.09235400601380295, 0.05033830451148172, 0.054282872081403775, 0.04739528965024699, 0.0554763374760026, 0.0293236700517516, 0.025888583510212844, 0.131463767479985, 0.03413932172641639, 0.04244800108755308, 0.03921530922994979, 0.03684205311020056, 0.019354278694898374, 0.036191249927205425, 0.03107504472286711, 0.0261467264123982, 0.03572137372928762, 0.009080132773716845, 0.020172188636816798, 0.04011843496212556, 0.04179309933416305, 0.006421100481548497, 0.032197013046712644, 0.02568279505677281, 0.06360688224254597, 0.04574252390152505, 0.1539644592952344, 0.02171742628448673, 0.0119044566752329, 0.06102161512019173, 0.02249177455181076, 0.05444539763453988, 0.0045809074917117195, 0.021436837006119952, 0.02855090758643083, 0.03043567540214187, 0.04788603791366181, 0.09242691460155672, 0.07705604988000087, 0.027098167394738526, 0.03768791377003636, 0.09759165722155765, 0.02057323758039744, 0.05518786323767516, 0.012024930704595342, 0.08106718666010326, 0.05290696284763756, 0.02385575579659593, 0.026740189829480746, 0.046368708849073424, 0.028307601892118974, 0.032400260003463875, 0.015379111658060744, 0.02477288178558792, 0.020363432911014365, 0.11521062993955229, 0.026772174000319456, 0.030119805859642166, 0.013540821439105899, 0.02780913529286702, 0.020119073845806624, 0.009579131804076175, 0.07989917070634904, 0.07936356033408835, 0.028142847023123217, 0.03534548119792054, 0.017818303050232992, 0.047104003869237444, 0.020767483004038374, 0.03167152844159113, 0.04306366381746146, 0.057526197239396074, 0.026559088559400652, 0.0505073762859308, 0.01653054755391373, 0.11950865898641849, 0.11397465432603514, 0.08132737310182664, 0.029354162266357776, 0.006878767631978038, 0.004664143423489746, 0.0342542962020924, 0.05605247772989735, 0.011643769403529024, 0.016229543947584687, 0.0454432018581898, 0.03558045568605585, 0.03954037182754086, 0.07744386656990937, 0.04024621459745592, 0.12802833811410014, 0.022237174806275198, 0.020090450885735696, 0.04677027681722276, 0.05444259375273701, 0.018357818555687706, 0.019028817731586677, 0.05086597821284687, 0.043647867146759264, 0.007622563355271855, 0.06793005812552667, 0.036961639435180736, 0.003192838766769837, 0.04629517206922174, 0.030559268366966038, 0.03380418890306065, 0.1254493720649231, 0.0334032797705262, 0.029411205173199697, 0.03030292768662255, 0.045503458503874085, 0.007210007771068523, 0.02397140059920569, 0.011972456554611845, 0.027387166403294094, 0.018540794825962475, 0.04381366006489243, 0.06655919741118146, 0.05193948189938261, 0.036158859729766846, 0.08345383399676892, 0.004961319941832054, 0.033761054322484045, 0.04978849852998411, 0.06150346144192642, 0.04203818235245924, 0.034853541667783455, 0.06392496960958646, 0.07745608567230164, 0.05358051501154419, 0.0334856265615071, 0.1066657082147656, 0.08218811885003122, 0.06349402216954098, 0.028763173313270655, 0.01750407676633087, 0.037014476519318364, 0.03402176936487517, 0.05718427687703122, 0.029190156248308, 0.019766481878656535, 0.08570680665152688, 0.03192357711433884, 0.04915408196768934, 0.0414651753981748, 0.09049430459497437, 0.052656976866625974, 0.02679660071378514, 0.025079203957331278, 0.022654602709676952, 0.05155484064392025, 0.004468816858265669, 0.024926754375619274, 0.024097604008631843, 0.06342571010933289, 0.048084420212093866, 0.06518919471531145, 0.017772483331481778, 0.07486357518862333, 0.026687502132488355, 0.010968036761867904, 0.05546753895619223, 0.016850429481916854, 0.0399011877485581, 0.003462723881614605, 0.0438807157409047, 0.028051964097446012, 0.026444539262522614, 0.03527630345835801, 0.0693885822810473, 0.08502413038044207, 0.06282597434737029, 0.05333019961272517, 0.04801600856045562, 0.04965509197884991, 0.025865336572150552, 0.026504799738646518, 0.0243969279671869, 0.027722036841535763, 0.05380872494330811, 0.10461716612260188, 0.04476752763073291, 0.024563925558580987, 0.054019640440181385, 0.006530225875922629, 0.024290367052139297, 0.11127981747831069, 0.0992560062196947, 0.07833118024732798, 0.10036222952147646, 0.119192969474581, 0.09697029862793223, 0.18454305797574982, 0.18039093803494208, 0.1828807544323706, 0.16575790791501924, 0.09392777277577309, 0.14297198624380175, 0.1055863592773676, 0.2149359722651782, 0.18297288416614457, 0.1012441576007874, 0.26172085454867733, 0.1146955124192661, 0.10111337107035423, 0.12392392246833733, 0.09388599034038284, 0.13134638748822675, 0.11823948112226303, 0.09299667717348184, 0.14832416759623637, 0.0838770286270207, 0.12311462718512743, 0.14987952526538603, 0.14263746629078544, 0.09610654215418524, 0.19489186395320202, 0.25726715643559733, 0.13017723006346535, 0.28124255218332816, 0.18539130116903013, 0.17799700520211653, 0.18664658219823915, 0.14851377435749577, 0.09033742510984022, 0.18932989708358244, 0.10201645083725454, 0.0930055637934035, 0.12199918784561659, 0.16332484331102143, 0.1837643449224772, 0.1996364303293728, 0.04937891728214679, 0.17012197374095842, 0.10894256749100263, 0.1666142869620554, 0.16166526704065262, 0.15029379497131995, 0.11431272892702012, 0.11619343647673247, 0.15061939766089763, 0.16033031286731844, 0.19020584201620472, 0.13461195983954016, 0.06301748483712155, 0.11873653428929469, 0.10488535818313399, 0.1838128076445672, 0.13404704660417574, 0.10933577743989807, 0.08286562402762714, 0.29341624088345036, 0.31988785752365667, 0.13095614229959826, 0.11512433779576134, 0.14155982572945858, 0.06656498903588903, 0.16363071157566964, 0.144136501175742, 0.12356093468805476, 0.1376471082649885, 0.1248123010079707, 0.13890094904889985, 0.1983948775957669, 0.20846084391157474, 0.1435459086731557, 0.31561829630405674, 0.13380978917402606, 0.14805998983642749, 0.11110968467208648, 0.16953561004371415, 0.08251441101874075, 0.18256408432799, 0.10037960439559915, 0.11822338561497389, 0.11460185050964357, 0.15162671135077554, 0.217214118569128, 0.14896572026754581, 0.11710092891007663, 0.17048039563721226, 0.10525369325712805, 0.11939954508336321, 0.08285826958355405, 0.08329166850495724, 0.13883128101306577, 0.17775112162193946, 0.14122912089430517, 0.08239201315107846, 0.15755888254892442, 0.09038810182603137, 0.07412515836016786, 0.22872074387006222, 0.20844078772971708, 0.10854479165807848, 0.14410843171419638, 0.1805767296783386, 0.1270169564973443, 0.11231953668738566, 0.10499978107550453, 0.12870767424183507, 0.16010918924885412, 0.16263493516993138, 0.20733598169059525, 0.13689978949485287, 0.10738103515318326, 0.1219102603593661, 0.16728078345617942, 0.28894630170637564, 0.17458872599226816, 0.05872173490183008, 0.08155909171628375, 0.17620066691550518, 0.1848783746602074, 0.1609502312156462, 0.07701025314388737, 0.14929306963759084, 0.2572512218067723, 0.08980756039701163, 0.12292621552102989, 0.22643116753428216, 0.25915865816416284, 0.11587172551381013, 0.11835105416755523, 0.23090740395409448, 0.06812686611327433, 0.10279357042764464, 0.09788190495342979, 0.09195798452222541, 0.12629186193789207, 0.10802909191096983, 0.14522526533372943, 0.14708690495500643, 0.23503721541454717, 0.2266377814474606, 0.1337050802765354, 0.1570000367299203, 0.14453924891929473, 0.1274997910725013, 0.15032276841661624, 0.0905674736526224, 0.16635465976451674, 0.1740904930498331, 0.11689324247380418, 0.17305359304431947, 0.1481550460260722, 0.27884972251711354, 0.1506565835687422, 0.1286467396083378, 0.1569030499987064, 0.11220346670597793, 0.09641723677275643, 0.19654509701555778, 0.1832007033930671, 0.12346133559701905, 0.11100293031983799, 0.27030422622638367, 0.12182579916571418, 0.27417177514683816, 0.25546522570713875, 0.0667576831314833, 0.09452475445164789], [0.020926746937836853, 0.0945090956144756, 0.06846110261375866, 0.08953788212590641, 0.0579150558088816, 0.008690693892628677, 0.04587882626501303, 0.015915460347558464, 0.007590448949486018, 0.05232752075478916, 0.03770347684621811, 0.10996715646357307, 0.024073816978582935, 0.024397180776201913, 0.01833265065215528, 0.01152425777212146, 0.08078646906200918, 0.031429237813778946, 0.00848541297243848, 0.01922083766980758, 0.0982747701627593, 0.006347660420297255, 0.02122001114091085, 0.053417675362359134, 0.05691519998494656, 0.026881611575522733, 0.08260791204989919, 0.07132689964266554, 0.07171388129673659, 0.028391484689388066, 0.03947965169866239, 0.12763829210833197, 0.0175088073592633, 0.018423242464421258, 0.028607485094858755, 0.01604094842238532, 0.006410365674509517, 0.025634190608416835, 0.013175251942518498, 0.044584290890563885, 0.06046211429601235, 0.029616917017847303, 0.06327942562019152, 0.06138857889680132, 0.06456012161628855, 0.017539822428877798, 0.03414974818306585, 0.03673969993307706, 0.0038492992696832987, 0.03882416388801029, 0.039939308283670295, 0.02417560325064246, 0.03325737449490736, 0.06980429223227887, 0.03324497536185288, 0.054510185690296274, 0.09156649061028035, 0.06981786731029711, 0.023368382150487556, 0.011084968592190455, 0.024939011782407764, 0.05109979973865613, 0.01878901114386897, 0.033309698300135714, 0.043733458320099505, 0.024834917670476343, 0.04196563382602988, 0.038369728192206354, 0.0441091938034421, 0.007265297772978703, 0.07366897598389657, 0.06355221803870893, 0.012035971946804034, 0.05100436050504927, 0.025805146959159645, 0.005622090407527022, 0.02162515482444677, 0.01492220245587129, 0.03286026898891695, 0.06354436180704544, 0.05207805188312646, 0.019696917264692245, 0.0218333775222662, 0.01538934467750932, 0.026061049054166483, 0.016180700096752376, 0.033939146782241525, 0.05520511936816958, 0.025359885166248968, 0.04501228506166128, 0.01807068114078814, 0.042777717669284156, 0.023051401780497645, 0.062183690062093164, 0.008381174261411353, 0.01569423522244418, 0.004405321575881493, 0.01695664565739853, 0.12085439201684729, 0.021112247467822125, 0.038057225606133865, 0.01183888625218383, 0.0372247944676107, 0.04313969421350668, 0.06330805815636151, 0.051427509170025594, 0.03821190258848571, 0.05113336205061886, 0.019232974417747992, 0.036156913866439176, 0.02248929242693609, 0.06292919703428784, 0.036525459614612406, 0.02816494482929909, 0.02523244069438548, 0.056420372303334944, 0.047795470999253374, 0.05150628599127935, 0.015619624004278694, 0.030100056112954215, 0.0524762911992448, 0.0599132850766182, 0.02289233702955948, 0.08772008571653597, 0.060933017051748695, 0.03620428108279744, 0.018463117340880058, 0.035355413527858835, 0.039394110321037235, 0.017212258554213954, 0.0488402808625852, 0.0164970924942604, 0.020362308676985484, 0.04520772175202447, 0.0903543709747253, 0.04358212914197676, 0.027072840527961814, 0.022887600690967614, 0.032112140080801425, 0.047691754185624664, 0.05859521931157478, 0.012178701787976729, 0.03163193893288413, 0.021758680119209235, 0.019441248826502312, 0.024479791867516698, 0.029426080685469414, 0.043231724355850494, 0.06638301251035544, 0.019339857089723793, 0.1037494183307694, 0.004151220266301666, 0.03677553369573528, 0.030518801687585733, 0.019122881837369456, 0.003488154649066048, 0.03631901807121692, 0.04451263868700593, 0.043619912598402276, 0.0849568065736563, 0.07212374599710589, 0.03963570763927795, 0.022218164334434177, 0.02856737464636324, 0.08510295316697129, 0.027921045416845914, 0.04697713204809735, 0.02324127475731075, 0.06278075983807926, 0.019022018701258688, 0.03341500857664693, 0.0731856128080718, 0.021550645112931248, 0.08854867109367925, 0.024131945815057527, 0.006997884249299645, 0.01243664263447206, 0.0020043841857019995, 0.05135839654793663, 0.044863664004350864, 0.10650425518472349, 0.051233558690235506, 0.01756550169609968, 0.017582912959398764, 0.03702757279238394, 0.051439034962846394, 0.03835525296087708, 0.09022752979710218, 0.037370450764654145, 0.07521438983178909, 0.03651528979741758, 0.08524056554080979, 0.040100692365799225, 0.03466781897230014, 0.030819184762696107, 0.024873237388448852, 0.1064785376131054, 0.06761563265876425, 0.14941112378672247, 0.1236405312233875, 0.0694064244688038, 0.00197004345658746, 0.07787286048574794, 0.07323274253717355, 0.06626092107786287, 0.06365198566908799, 0.02447791495210221, 0.026917338085871552, 0.0656528847532407, 0.00587856132281764, 0.022878095455047105, 0.017925871370901025, 0.047388061610681396, 0.017869703719512593, 0.00904965109281963, 0.029221929744967533, 0.08702351261050471, 0.02200444304053822, 0.009955204366105459, 0.031059018163491162, 0.06752070670406665, 0.0831492910642297, 0.02020406555534611, 0.043581979754831524, 0.02702937269913814, 0.06475608690731949, 0.054154713232550895, 0.06697776487037059, 0.07064263756957746, 0.028109171713191657, 0.011908789860054612, 0.06916019614906081, 0.028269037026010697, 0.039670775314011884, 0.027495661690350504, 0.014586263324975248, 0.06403754239961987, 0.04944933608414666, 0.014729015191175766, 0.05521503254590977, 0.052048473228369994, 0.018200793513847936, 0.05398074998670528, 0.019167590728630463, 0.04043864822315593, 0.03873465417493736, 0.030129504532763557, 0.04116100018783923, 0.013079577136874921, 0.014195442612793659, 0.018895595041554303, 0.019121594809656663, 0.017340371437791376, 0.06245541761839583, 0.016973380848104437, 0.05636712536215783, 0.027863856953298374, 0.027497513707907453, 0.032607640004566604, 0.06133229824744406, 0.06644536440651264, 0.034984136676235546, 0.03500499341997408, 0.03151210745976817, 0.037430309044617804, 0.03246299111314359, 0.051097026500370235, 0.14332556646437417, 0.09248504535325112, 0.040715589007783326, 0.053140294077175285, 0.009244760280595192, 0.02383530124901764, 0.022708259507893555, 0.026466642814357916, 0.006643646150722259, 0.012371970449514207, 0.03176672827272165, 0.022674189662680994, 0.033210298391960325, 0.014015968321942756, 0.12416970645708424, 0.03883441031399754, 0.018082791075651205, 0.02881768238430302, 0.010958697192461021, 0.031745982611732136, 0.015392252938791871, 0.043639302283765814, 0.04176533247734751, 0.03013462008487794, 0.04951775539666415, 0.11738651882736914, 0.07873496987045774, 0.06715816325478016, 0.03033942220011546, 0.04928579546451088, 0.05947227124124766, 0.030205362559025808, 0.02825970990553258, 0.011088841166647692, 0.04197629393949624, 0.0503422919991276, 0.07904091474389838, 0.039837905055572914, 0.017589798174618233, 0.028434770572329723, 0.020453352481126785, 0.05293323966344038, 0.04478276128910723, 0.051910079444848725, 0.019560287398616635, 0.04970813590672709, 0.049492014842408324, 0.010817249590951589, 0.010842220226843512, 0.04501793496010285, 0.011720179013096759, 0.03361022310151208, 0.0198812686627911, 0.017156638655691378, 0.02918996855676655, 0.011308301416706416, 0.05998135198869052, 0.02599351648842135, 0.05084879486070526, 0.025014436968992797, 0.02027571584368425, 0.02530389563030293, 0.02602517890233186, 0.04748723552291913, 0.04379102216672994, 0.014334702075669363, 0.04853510973794807, 0.023743491356952057, 0.08810659239609396, 0.007856839266981209, 0.07037124326152187, 0.007972204447498606, 0.042969687811789975, 0.015105994609785418, 0.017480385497272495, 0.06365677754905436, 0.008638094295747578, 0.03924573058142297, 0.01903518966789688, 0.020673355696001844, 0.009866771006566143, 0.016958196985445196, 0.019794802233997374, 0.006590211996808649, 0.04057972331441218, 0.13884076518156838, 0.21649917467467247, 0.21613390395237556, 0.19406133271273107, 0.18684251684575312, 0.14577427458378578, 0.15277993414671193, 0.11927322484552862, 0.147792732403163, 0.16943949665273392, 0.1892528439601583, 0.2508208176661884, 0.14521542876478166, 0.1550261958712532, 0.08160160959608133, 0.09899177483373112, 0.1756774441849801, 0.14579908051077398, 0.11052365039264965, 0.0671144655995792, 0.12743600659192572, 0.1811242067525464, 0.15729893359445757, 0.17521537059257108, 0.16798828097601093, 0.05478307770024385, 0.21323724890187865, 0.17401293430837894, 0.25082575127242074, 0.13870574984579317, 0.178889773425556, 0.1922330792031942, 0.12041799769166017, 0.08867928908476908, 0.08256846618267798, 0.1682217845753316, 0.11437482035328304, 0.21832837813323547, 0.07394357253947566, 0.13446362989564098, 0.2670868408055075, 0.178886586499791, 0.21765153945213367, 0.22637463024547025, 0.15531102736150065, 0.1746919486791857, 0.11576277248921896, 0.10625299366731798, 0.13164428843846246, 0.15479558808428628, 0.12389799805297969, 0.1983044945424603, 0.12494898641542082, 0.3044802052599769, 0.14681731861445213, 0.11350041525738855, 0.18169869608696432, 0.12711395855031668, 0.13314286367066447, 0.07370639171811842, 0.1031902201113201, 0.16593994572758675, 0.10485407881318562, 0.19034180730100603, 0.219428725540638, 0.06648454214296033, 0.11421565026525529, 0.1289168622104391, 0.12610707386967637, 0.11918047458053597, 0.10174558512986669, 0.18657181201682937, 0.11389591580917759, 0.13197251114874117, 0.1483012462455419, 0.09361427427539903, 0.15721762102217446, 0.10515446954917525, 0.0816703123611308, 0.1621898687294414, 0.08407249596090087, 0.13126856827687833, 0.06672822705079472, 0.16311885758994088, 0.19483817651146845, 0.14178632728515134, 0.10064668562864104, 0.14666932574923963, 0.10664343037792753, 0.11498764472743196, 0.15944710542117396, 0.22710317986146097, 0.1454297954877538, 0.15015813612168835, 0.07620606000625318, 0.11354244284091458, 0.07187030878999541, 0.08500415846825608, 0.2661799152772273, 0.08517918657631644, 0.10234152492616447, 0.15498344816507834, 0.13736008576327755, 0.10264175478368999, 0.18763783868522416, 0.23157829779290387, 0.15548883636872615, 0.17204428752583845, 0.1007580365084352, 0.08894536674263016, 0.12493599356422502, 0.20775641074344037, 0.1886460716806112, 0.1189076706706997, 0.11714437375626258, 0.1446537484204577, 0.203525644216326, 0.17767676512800878, 0.12039457838381491, 0.21552575271456473, 0.2254233635481327, 0.12358609301548813, 0.15845506752450622, 0.18062473274767402, 0.11116472042856679, 0.1698235365291757, 0.1875786966974697, 0.2858336558265071, 0.12960505431457875, 0.09493058186865623, 0.1478399080975402, 0.12194530122102269, 0.10858364763759798, 0.12794508733936857, 0.25667392859055155, 0.09632486955172594, 0.12540020454194278, 0.16176369401716417, 0.08712673529742226, 0.12674547791961702, 0.21623348006077353, 0.09762248459963069, 0.1534889485206335, 0.12429834028045017, 0.12400836067935153, 0.15216355512459434, 0.12413973709748638, 0.18372722030166658, 0.13293389020667923, 0.12650413724083093, 0.24932717604021876, 0.08017431884523361, 0.13105498296358895, 0.14614909076161925, 0.12010757886474172, 0.10787882376462223, 0.19258786984268697, 0.15161531196246225, 0.1237852682149218, 0.25729920955434926, 0.10251034772203815, 0.22028531909229296, 0.09871442802250387, 0.15743960265911397, 0.16162247336920232, 0.14070939152471482, 0.1768994003894829, 0.11638654425980584, 0.1511087593051695, 0.08744063982439619, 0.10718189059726654, 0.17204509957903819, 0.07925904295857876, 0.1879197130760839, 0.12918522281031455, 0.0749743898068705], [0.05776178842831043, 0.041194470569251046, 0.03543064336202318, 0.06075832602237502, 0.027654151875345458, 0.016080915229395032, 0.029158624069344614, 0.008831072801483736, 0.050654806076518955, 0.020586383649178093, 0.1269486597588947, 0.03585842302850178, 0.0180297605543127, 0.033719746861606836, 0.04375469044692094, 0.08768367355749493, 0.05833111049967909, 0.02886348103563632, 0.01923676846819299, 0.019866339524366686, 0.006885494362758173, 0.0024665467161309696, 0.03498364637996401, 0.03646837840337427, 0.04134019198376806, 0.05990347149030817, 0.020932383429739746, 0.03913019303112261, 0.01754856732253346, 0.04046882442649334, 0.07376351889463202, 0.036642387614495335, 0.07915490096615208, 0.01472954570706333, 0.04090079842435737, 0.044278265577891184, 0.019274456163627968, 0.06254297763770146, 0.033030447760416616, 0.010161409379854318, 0.01918225173628138, 0.02101477044033668, 0.018882812864537683, 0.06234213236659285, 0.03149977152896745, 0.07262819957348608, 0.05100476653164914, 0.045212808575841694, 0.08732714389841403, 0.04316703589152425, 0.03771346663275073, 0.06844383499194538, 0.06410637539961646, 0.025604140809586933, 0.03227243823329768, 0.02492381642842966, 0.01694878559529541, 0.027489525326077017, 0.053508211633250605, 0.0790758177097286, 0.012324902007446415, 0.03913999512611378, 0.05909966905751537, 0.026251349124997377, 0.01968567875484305, 0.056269996904677926, 0.045496314733980164, 0.04444189429763825, 0.012495564371948282, 0.011064492977194248, 0.01733899056430786, 0.0526426280398042, 0.047792847148112716, 0.023538246825938264, 0.0031326383806674954, 0.06723977460135376, 0.09288884263726012, 0.03774724727977188, 0.0564494836444576, 0.05787426545735329, 0.024426200186773658, 0.09439940714547712, 0.05443268823587606, 0.10090914735149953, 0.055725438625461636, 0.037441984224583835, 0.03595089367140205, 0.04515041071440905, 0.03690874106400917, 0.030763187565870827, 0.009290665226627984, 0.026345643057157437, 0.038109461311250925, 0.04331390643792768, 0.049260020436298464, 0.07103451452548466, 0.03963298036626751, 0.012018956176395859, 0.025952770186948682, 0.047410511817302436, 0.011462957331640346, 0.014161013663866589, 0.045202933702497713, 0.07354738250855478, 0.023471489924216465, 0.03924011132649837, 0.11080709526375418, 0.033582371975024866, 0.04773463212674664, 0.05535976570700446, 0.0487264899927522, 0.05881672980444086, 0.021144011388382605, 0.05616605409511155, 0.06543027492420328, 0.04734198142203593, 0.061409692279994495, 0.02211661746485099, 0.06280780657224598, 0.04138418075238024, 0.02354364200014501, 0.06355329439224255, 0.06212984940277473, 0.01699458807706833, 0.025922783590372533, 0.06091295320901179, 0.03866104461673287, 0.08068408141092909, 0.012819416550618988, 0.06507162320157213, 0.03721077122815675, 0.041258132475758755, 0.07407386111275804, 0.05765065205313506, 0.04893056432446165, 0.03253413386823189, 0.028859648680795106, 0.029590038823023922, 0.057713754715458046, 0.03429033297805056, 0.07034918759018183, 0.025012067842086958, 0.06965492040880265, 0.030795504984956597, 0.023989009130145275, 0.05523054199593683, 0.03469715247892084, 0.049541626696384726, 0.024708524654288928, 0.03423769890721287, 0.05017157696608094, 0.044560342982050874, 0.10224436199472797, 0.007160010479105216, 0.06791243044238898, 0.029455833625228658, 0.0487616955633125, 0.01201024384147698, 0.0463333577218075, 0.016700222622603178, 0.07238751006943565, 0.05113120168267239, 0.01872727977893045, 0.0535024659738185, 0.009684554120946315, 0.018279689078729962, 0.05947595612416345, 0.02781383332706267, 0.06506173300646967, 0.023193652816717664, 0.02678078674380818, 0.05748246894067815, 0.012996423080743802, 0.10297613684087993, 0.044216840648122376, 0.013665449580237752, 0.0423288973979652, 0.04195750180271365, 0.06228166504672939, 0.04752161754896084, 0.045479912791521325, 0.06911938664533439, 0.06246765587298621, 0.007227662267283567, 0.05840277802499552, 0.08087660696718, 0.06032284334181778, 0.014236254989349795, 0.018705856130127946, 0.031753350462343906, 0.028325765836803664, 0.019223325540341677, 0.03965464916320578, 0.03424586923492532, 0.05424898418207323, 0.026817290833400145, 0.03284040432904036, 0.039584847061984965, 0.03559341023285543, 0.04232076537464896, 0.0441444683219156, 0.019911465933546424, 0.006995001364679587, 0.042881174013018615, 0.001991911556087284, 0.022195677738636736, 0.013987787777648098, 0.014743951990479424, 0.04160248516728321, 0.030900022360466184, 0.03036484865832233, 0.025027217230789607, 0.04708686648237129, 0.02142145204538059, 0.019850849226537733, 0.05910716139741483, 0.042504733728785674, 0.03645085414210635, 0.03142528863052928, 0.07149111825011431, 0.02478576929969413, 0.04613408676138328, 0.04240208177737171, 0.002731289226381529, 0.06560990722068856, 0.0804289588103852, 0.08141516677794919, 0.022289697794363867, 0.03125720893994215, 0.11102314738015975, 0.01616938306289094, 0.017927794251590967, 0.03824901188753786, 0.03523813695797036, 0.01698005155870511, 0.1240482661993273, 0.016161873486013185, 0.05289658235626356, 0.0207250532243521, 0.004815779515587155, 0.034710313869459976, 0.014436000924287064, 0.0668571749702096, 0.059694976831275615, 0.05929705927208547, 0.023514149530280023, 0.021361900200586648, 0.05163539861959796, 0.06505316814347621, 0.019760498731967904, 0.021073542790667667, 0.04539571589820328, 0.05840908675905197, 0.04237176001732869, 0.07371100356742259, 0.018791589029734174, 0.018291465765345963, 0.09948647611083523, 0.028938931120078892, 0.031131128104583874, 0.05082349097656627, 0.03724164840194487, 0.05142781177475568, 0.004912125605774383, 0.02265143110567043, 0.06499149040469239, 0.01094921685439805, 0.057918035890907056, 0.028629176874434756, 0.03544947380320199, 0.014591507196816948, 0.03986908483409113, 0.04471356056690697, 0.043294562717839595, 0.051768755375017086, 0.05105439753782365, 0.02300519135690505, 0.02806973542206951, 0.09227414134769671, 0.013009817170489942, 0.0699144939801866, 0.023341532683961337, 0.09067895476736369, 0.01971924298202559, 0.051309635051556175, 0.04378711128787648, 0.10517684697744348, 0.07998658133850944, 0.007734292012173683, 0.019235439305644364, 0.1272109452815306, 0.014403457509263631, 0.053601766290563735, 0.0840278100522776, 0.06712098500781483, 0.016138685919765024, 0.05220668953693202, 0.027169993883299253, 0.07641433633022732, 0.01960630055456873, 0.01046018654315342, 0.026223764214063847, 0.03915185416718164, 0.02507926715958503, 0.04309232699714842, 0.055931087267855485, 0.02168297722575165, 0.06884162614662802, 0.04994115687065548, 0.020512258896844524, 0.07794666539637313, 0.045199869350800594, 0.04544759537243555, 0.018832733696927468, 0.01617341843103209, 0.09105905695187469, 0.10765314958388768, 0.06315070752715392, 0.027348279780257615, 0.02904189716754181, 0.017334175701703758, 0.024998609592477163, 0.0898435129032981, 0.046023758608968034, 0.019931843872332287, 0.08077992667113582, 0.014203803504877275, 0.012713027047744442, 0.01589921449551419, 0.06587174075144915, 0.035728410246872136, 0.05997904223359882, 0.02236384169889554, 0.07707893292629912, 0.03103000641379866, 0.04989544057377404, 0.07138145276375356, 0.037886273085830674, 0.05868474817684582, 0.056910262548274575, 0.004357314676106457, 0.037660449517950896, 0.04851750886788772, 0.015872216599452642, 0.01761073344236901, 0.029688268531894976, 0.07210486192977236, 0.03700545200357034, 0.05330340951801308, 0.13179877772927284, 0.0409956056354267, 0.018625376678462473, 0.11344122730435864, 0.15686980178279264, 0.16722560980387274, 0.218004139080163, 0.14151376852345082, 0.10361028144196158, 0.1310845079921907, 0.10057009981885072, 0.14764613381797267, 0.2012041373358619, 0.3587247154885723, 0.14358225188428356, 0.08136033020432919, 0.12234631760586655, 0.05374670246495836, 0.2035156084645179, 0.13907322690131205, 0.10733331553637983, 0.12974849661752103, 0.20983226387010467, 0.0585896038870898, 0.17857397666140912, 0.11208810152546053, 0.09283135539942211, 0.24531753313156868, 0.1682083933584152, 0.14229906993287225, 0.16210379109026926, 0.09986391997024899, 0.19562614390686636, 0.13964408497896888, 0.0964286668045867, 0.1947510263492023, 0.1041496916103267, 0.1496635344360144, 0.09201657492667438, 0.2310847533085654, 0.15477579237232286, 0.09940569213921986, 0.10352754394613928, 0.15143304432351745, 0.1520190862638335, 0.10237050603233999, 0.18210236313602618, 0.26703517583589403, 0.13057470712209904, 0.18385417639247834, 0.17657749024370026, 0.1421373947373321, 0.1469434013650302, 0.2029360782715582, 0.15757428091620246, 0.19418609779207938, 0.17836474272752964, 0.09983795725049512, 0.08735276187860197, 0.061355480068032785, 0.1727280669635342, 0.14096998399303806, 0.2273889306572176, 0.2155543277941404, 0.12314792136631666, 0.13072352736226975, 0.13021453854537782, 0.11714831910907261, 0.1561834329679128, 0.15386548073541734, 0.2639033471144015, 0.2551938773643586, 0.12892479888133465, 0.11549733068433501, 0.19227905980040952, 0.17917028417991054, 0.09842476251745418, 0.12074151662208381, 0.2033305829090457, 0.12327175181839736, 0.09361567621630046, 0.23063314447720207, 0.13432852262931486, 0.0712840446841813, 0.20134728852539294, 0.12097564841350242, 0.222424834125465, 0.11513758345597214, 0.07968815944848523, 0.1728604163133329, 0.10811123951909044, 0.1337315869187155, 0.2528019976471701, 0.10876262109846839, 0.188527557878725, 0.08770546109806146, 0.10453864977124239, 0.13242047340158494, 0.1877570113227252, 0.1831850445558948, 0.10805461796060686, 0.19386844709515574, 0.07983547815632436, 0.11816778295342961, 0.1126637093482479, 0.22630810317012573, 0.22271703538154403, 0.14117912599636664, 0.08340374716827947, 0.21369878623274066, 0.1143837605993594, 0.12701772258526858, 0.11399622736198288, 0.2465840909750231, 0.14166655709906933, 0.2161347160055753, 0.18006953350718946, 0.26884587061020637, 0.1859817251322731, 0.1259885830504279, 0.24553214500267662, 0.1534195256329352, 0.164091344922781, 0.1770846864148494, 0.11408043574661979, 0.11075880108100754, 0.08118331792854494, 0.11494928670506324, 0.1471589018981303, 0.15340435709203445, 0.10972598432413033, 0.16020741704250538, 0.15227488302175077, 0.10006008444414025, 0.16312843368899438, 0.14283091881342475, 0.14478574536981123, 0.15658984261174358, 0.0988251813537171, 0.10858787644294002, 0.0955795502710727, 0.19340914674103263, 0.19188999438718443, 0.22707639742762814, 0.14169876343540608, 0.15837305015133274, 0.09583730821407611, 0.0978662461162575, 0.2588106397419207, 0.2499854294282775, 0.09396302814204847, 0.07003395007021966, 0.21822938425165994, 0.1753587822519964, 0.11969995114111132, 0.16982974184136237, 0.07320215264635702, 0.11547419482902174, 0.09284794120298279, 0.12562185676107485, 0.28138152053279264, 0.15605145134031773, 0.09787622824191086, 0.2649694657133472, 0.12321023495807765, 0.10303648924755474, 0.20180925486549256, 0.0979361363175896, 0.07995854252048078, 0.1536168392387129, 0.13092090225508138, 0.10995642357175389, 0.07737437473429788, 0.09096695020073846, 0.18513676079530872, 0.15422788628887746, 0.22921136189852992, 0.07771763575053023, 0.16270299442112446], [0.0647940312422091, 0.0315741088707, 0.017893747389016133, 0.013951903261664896, 0.025202408132533875, 0.040311037127168915, 0.01639133022587386, 0.03750834276058501, 0.05542114084105819, 0.05231618648394943, 0.022877921170044332, 0.016180590929223165, 0.034249603913556186, 0.034735238540076444, 0.028003078111777865, 0.036700131491787975, 0.018972435575579445, 0.07903290912508965, 0.021841586154374867, 0.05482845308799898, 0.0152742974234805, 0.019834341946989298, 0.046512304369600556, 0.040621965402557005, 0.011634651042010275, 0.03388020397734738, 0.04854336816577181, 0.018470567545943686, 0.006125265574683586, 0.02202369099963577, 0.07896308021079149, 0.07805784007594471, 0.035599983267245755, 0.024601031027193514, 0.0404255596109696, 0.030191385284847314, 0.09263643964884744, 0.1011975564723534, 0.07290301829456322, 0.012757381623340471, 0.01843080566745372, 0.07745934154597983, 0.06993861042804296, 0.017254397220489, 0.03526596127138023, 0.03845833009108901, 0.004747195494165945, 0.00947076292152727, 0.028443950220882416, 0.030442164166860526, 0.0749459526231212, 0.04643910466843555, 0.023630437846746177, 0.026381371482726068, 0.038338617361601324, 0.03770237751004677, 0.022117758935858167, 0.036524072995469455, 0.08925519568184692, 0.028527674054907217, 0.044044922857034596, 0.02092553460369668, 0.06002928994055237, 0.05809712043452648, 0.029222636461077683, 0.05140312076095612, 0.03726897858864358, 0.02962437488379017, 0.05795499963325359, 0.02901963656768203, 0.08490566254383133, 0.057994652344214345, 0.03673242592823602, 0.03260941349811131, 0.012367844108432051, 0.06507012933011978, 0.04036435684669883, 0.03690854188114886, 0.013572591105325809, 0.06719464436173439, 0.10312320273970405, 0.016087137778560003, 0.02520343469035241, 0.021203749009498188, 0.005751106796050144, 0.04111886152156419, 0.03621933471050955, 0.149522896014875, 0.03765317551310986, 0.09801230077902157, 0.022361018664894566, 0.04311000447600119, 0.056710876674661716, 0.04698033046518122, 0.031877780378225355, 0.032888081811007955, 0.07889032484062257, 0.02432093970597752, 0.0495659806314976, 0.022062060513323354, 0.044233005103324695, 0.022354541391494776, 0.12984940571890724, 0.06099326603655374, 0.01442261832585979, 0.06510365333768629, 0.03281538772787298, 0.049343079689048955, 0.010875737531140689, 0.036312617406609564, 0.07331111333182744, 0.049401647110860196, 0.09495325041033569, 0.08431863235009295, 0.015039485729029103, 0.031071695003418193, 0.01664376768824314, 0.029309137363828, 0.060135573148727424, 0.05563138601099772, 0.07974186987285653, 0.023477884843164397, 0.01169170831300078, 0.02416274063439379, 0.06788214698674218, 0.10206835329412453, 0.03239485142271846, 0.0721888787924282, 0.026024207885887836, 0.04434186619736495, 0.08287904588806053, 0.028461982015400168, 0.025189262063753222, 0.015334487994081311, 0.06626172547018336, 0.015575936882786695, 0.04869741695602575, 0.017835921157271634, 0.03857166513860707, 0.021691429090776274, 0.03178362434189166, 0.020988723450911143, 0.036285984359921954, 0.02713283478853203, 0.06515914874692118, 0.01277704326991713, 0.028808108200469328, 0.022911960371739926, 0.07056081937926431, 0.02333353472603185, 0.15000597573816776, 0.03057375125917456, 0.027915433822800557, 0.03459597524676112, 0.046535915199426875, 0.010342072064597762, 0.07848427525811619, 0.05574443760598379, 0.04850512505659173, 0.10684707953083901, 0.038583244557582566, 0.07773815158514247, 0.04604549252337987, 0.047732215119345535, 0.01991049683232221, 0.08651446250657882, 0.02695565397340444, 0.04494686498336735, 0.020267083947997422, 0.0458007887186062, 0.11506856659487372, 0.033058471256686796, 0.052528117047322374, 0.01675048948175484, 0.07207459379588405, 0.01408792696067042, 0.07231906011340118, 0.016268622092602235, 0.035048105017912966, 0.02280066886375989, 0.05104666004978842, 0.03540865663859633, 0.02915929248105855, 0.01165091508864275, 0.03878657961444509, 0.05601729131153515, 0.018806723096678336, 0.02225067327550102, 0.046523803349344, 0.014256882864320952, 0.010813403829571702, 0.07661636137673933, 0.027548812870537082, 0.021465655318611575, 0.07456321509615069, 0.040258916335240494, 0.023112119994156306, 0.032479741625607975, 0.1036516118854765, 0.033021047861585696, 0.023338261488524657, 0.04901639298505841, 0.05976060758374872, 0.05652355668585628, 0.04748273475636398, 0.017790118675498713, 0.037800861943152644, 0.03461711161259202, 0.016930033678128835, 0.08147074645685573, 0.028381542783350717, 0.06868378139070927, 0.12091153451511938, 0.059571935449756926, 0.034314874604704886, 0.08036009516687163, 0.025123116117151036, 0.013731624255137099, 0.08207964846083234, 0.11851927941484798, 0.04053203434112572, 0.0897281094183845, 0.021372378368170995, 0.035171969943950256, 0.04091616614811844, 0.035112050376952655, 0.04527443268847081, 0.055038158165951895, 0.04176693743154888, 0.0310693871635463, 0.02479498342220341, 0.018935858707634673, 0.0621917684592547, 0.06574912071828881, 0.04290220312654011, 0.05172506921113499, 0.03593393248475848, 0.01851239977704902, 0.09358398315887298, 0.015546557410890538, 0.09548237967875697, 0.0334245961670193, 0.01907679590306455, 0.046576939207772096, 0.09033413093176582, 0.011304396283512395, 0.07669548293755901, 0.06598877600364147, 0.03763110068957171, 0.03697256001854136, 0.013901217926984594, 0.043964261459487106, 0.049910455897089936, 0.0234368474282805, 0.00350455874614718, 0.11382614052103412, 0.06299465158653837, 0.05701373804420714, 0.013910030810943535, 0.07463758691183983, 0.11447513956696757, 0.017149088859197595, 0.05452361138116929, 0.07841900456696749, 0.050218844591009046, 0.042090165248561295, 0.03967732153532486, 0.02476595060509299, 0.06345901195140136, 0.06859778036032954, 0.035444007765862255, 0.01135729082424434, 0.036082702929214124, 0.03446365654047939, 0.03646850097744215, 0.046358110022641, 0.0738202323836665, 0.03076623276536984, 0.05698748804148167, 0.023590137791489402, 0.07054791845861944, 0.07083067385059211, 0.023706671256091327, 0.05183423674034496, 0.09015378617351094, 0.07118705029208815, 0.04864322389626215, 0.010506271519848417, 0.02342359985284988, 0.14291281361253033, 0.007852794322741009, 0.07254255094355153, 0.08853737895767536, 0.02952248135942125, 0.040615675820698666, 0.044218047236603115, 0.02486796287309018, 0.02688395963501065, 0.04533474679074941, 0.031215813378953648, 0.03068338418679853, 0.029238574920342337, 0.012931972103674087, 0.06050973432138563, 0.03379181658308353, 0.01210593684170876, 0.055430061934936437, 0.04306245722898072, 0.009469090934632527, 0.04045951645821333, 0.06556138321156464, 0.03698577120479557, 0.026243734211030028, 0.023505902593775142, 0.054313098080456264, 0.05429674210327287, 0.027834086776560837, 0.04899834012312274, 0.030684219222635995, 0.02543631009757519, 0.019337698636997133, 0.012346235640917816, 0.042277948720560926, 0.034103610537826054, 0.026337714047141136, 0.07190335016216963, 0.05579644731516319, 0.03626610820872649, 0.025902652714942253, 0.04382702063829188, 0.03979639458139578, 0.032479714812530626, 0.09587334499003426, 0.030927432986396938, 0.06916996377009539, 0.02889477764256299, 0.04644145272792347, 0.02018147553767889, 0.03855089649497982, 0.011479393748055783, 0.004355462179744556, 0.04419433681534664, 0.025151857820850228, 0.0071663220859913826, 0.021998837192152298, 0.0667740774130629, 0.1024742036937706, 0.04001276079385031, 0.038149956718928395, 0.04778807825078407, 0.09371262464311816, 0.043228648512834505, 0.1700719175559859, 0.06792111787945032, 0.28964687379137166, 0.13731902345053612, 0.12436567940899443, 0.1560177281498909, 0.1095537524369936, 0.1390124761289166, 0.24782276321803373, 0.1727454571594154, 0.16968410852695667, 0.08105518972320903, 0.08224405092938293, 0.15899592559904824, 0.18766742500085987, 0.2490365529252637, 0.10120936954814581, 0.15404059311314938, 0.1524415837540742, 0.19306780860549022, 0.1282237518218256, 0.16189829566546027, 0.2719490782868478, 0.13839352305137342, 0.10870593059207163, 0.20261344800312675, 0.19542248709307564, 0.11719385537529185, 0.11776203980609296, 0.0824157695376104, 0.11651001465056213, 0.15924521060960908, 0.07253931039163182, 0.1131558825352019, 0.200176032019719, 0.12237408829312171, 0.2172580920159817, 0.2102310892434851, 0.0918788782831642, 0.1458003522167283, 0.06287608032805786, 0.14680887632552655, 0.19319551546246777, 0.3020363234944882, 0.13450069322941766, 0.2148361969739199, 0.13153507494397704, 0.05610705383362309, 0.1270021403568887, 0.11057170708813976, 0.1818640638262995, 0.18855539751389336, 0.0858132622294849, 0.19735364153260188, 0.1286314025280937, 0.20075194627767612, 0.14215205766020284, 0.20411632864946322, 0.13875644954462207, 0.14081552534574462, 0.2848569856536004, 0.173467219236397, 0.19323470852067395, 0.14144391662651493, 0.13038848646946494, 0.22040061532489716, 0.08833870171539246, 0.1534615685382197, 0.2516859454373198, 0.12233910105761983, 0.1459856842073702, 0.20255415279778743, 0.1870356629332227, 0.17701734728630514, 0.09054456762368641, 0.22050642738899878, 0.16681769862771037, 0.0873463420617965, 0.0966833833785307, 0.23847498900948033, 0.16857895008738966, 0.139092440386453, 0.1198423209209596, 0.13053578985554556, 0.26455807649800855, 0.12196916485986403, 0.1698254823925034, 0.24234416203633433, 0.15004604213660763, 0.19994890227192835, 0.11247351269928679, 0.09224444011887235, 0.10733355302363635, 0.2571323862479579, 0.10835248826732559, 0.10936836682019696, 0.20686108378633378, 0.14146210355383737, 0.15671594068408012, 0.14131015767493557, 0.18245364509282574, 0.12080613613849688, 0.28303403347249956, 0.1982434833001706, 0.19722365173360995, 0.19162275227567843, 0.10101698188772125, 0.20934149262405213, 0.18150050914095295, 0.07468546740710735, 0.17371917023293434, 0.15092270719187875, 0.1949982735658846, 0.34370084263144, 0.1841043347432729, 0.20915770813101725, 0.1555312776397313, 0.22611460468221098, 0.11497328057885171, 0.2071006241584978, 0.2212262742461697, 0.11980437658606999, 0.0637127670850004, 0.1916531200009969, 0.19211988205150252, 0.24501777824855622, 0.1192887228042368, 0.14368598018923115, 0.1021832664827666, 0.15127398914867832, 0.1535031211472327, 0.1438076349516069, 0.09611914430053965, 0.12991538121094628, 0.25970665617815913, 0.24082908527024333, 0.16021625769715156, 0.10822070582259087, 0.19246612314976033, 0.11128404628365271, 0.14115603610632882, 0.09196656470697734, 0.13968531583105365, 0.08774316794569455, 0.1513041576911365, 0.0830325469254486, 0.14610300291209452, 0.12900148428255512, 0.19578532165577336, 0.1259758353473679, 0.2763992830389931, 0.1801611729446919, 0.19634062814856731, 0.07328190239927462, 0.16473850535769619, 0.07047567636735978, 0.2351150039823786, 0.1327881496399641, 0.16452821422248118, 0.22091322007679173, 0.08284719961304819, 0.14626162907769605, 0.127723419798478, 0.11814920532126581, 0.10708792991335354, 0.2186048439433498, 0.08675098449232117, 0.17274024776153027, 0.08480188827360831, 0.1846460508362901, 0.2658763912416274, 0.1407668940843113, 0.0936079157456275, 0.14740524513106193, 0.1958084115458112, 0.09939721920677733], [0.05278830348904576, 0.033722037464500434, 0.04473772298003878, 0.04843453388480891, 0.019496876385904128, 0.06391595658515731, 0.04653159063309432, 0.047634182678114985, 0.098826882068909, 0.031322742016204906, 0.022622358068943988, 0.04405813021284919, 0.018365169169321176, 0.04896588863865022, 0.05452671786770225, 0.05158384856317313, 0.03551925292178508, 0.028397469751296506, 0.030711618357247887, 0.09102223110535453, 0.04631947620861954, 0.01957576428990691, 0.0952711998815498, 0.006187905232617331, 0.035241978888910626, 0.029918140874454574, 0.05139522239445679, 0.013793529905078393, 0.07715030933820433, 0.03964759349342316, 0.029980473618413654, 0.0378889620544449, 0.018656610083135388, 0.02153248308346637, 0.04359752367881518, 0.04432559065941361, 0.030357136068144636, 0.00992729003736449, 0.021832429488459905, 0.03444577221788707, 0.05618439807045845, 0.01964208069107225, 0.08884911545582357, 0.04764007006381308, 0.02787544403315312, 0.03697156410423979, 0.08973730247347586, 0.048836913906157985, 0.010042550838402203, 0.09384282894672887, 0.054770387453778144, 0.01861720060509059, 0.05266134356779437, 0.060852045388591874, 0.03721084400650956, 0.025826825332196972, 0.0469060888844392, 0.04459430749017385, 0.04280752231997829, 0.03834991332804484, 0.10488430864267773, 0.022596753495294723, 0.007613281242459292, 0.07627114683630005, 0.018289431801906997, 0.05660421425296415, 0.06932659044621453, 0.03651094224844729, 0.017495098215858304, 0.1101390129676269, 0.04178816955837031, 0.013927818414935423, 0.0545649188420465, 0.046047377099673596, 0.05582962658316378, 0.027038533195492723, 0.10975738626814659, 0.05190733301964018, 0.015219292310517163, 0.06765155452153376, 0.021628083195537332, 0.08612413304827868, 0.09603914939948628, 0.03297476082920067, 0.007153621305816717, 0.026300047419124076, 0.033307453662517576, 0.047433417846238425, 0.043895141176518895, 0.04997997837621839, 0.06127269660693504, 0.03354949914219399, 0.04019230882066392, 0.0169985736494944, 0.05310261787305917, 0.06195235066115857, 0.015457485325544354, 0.05698555366947286, 0.023657114943489436, 0.006759442255697063, 0.00810183849441068, 0.03712336825687559, 0.020248716990012797, 0.05078304536460389, 0.02947747177864996, 0.030186114599928263, 0.07521343222188373, 0.03088666178706673, 0.048020995792842684, 0.034392697646492915, 0.05253078686373849, 0.11256413323984993, 0.0738369637439328, 0.028228522466135123, 0.022735559051075292, 0.03349936634842907, 0.053677409812207186, 0.03610052213433289, 0.05213615199130389, 0.05487858205132427, 0.05365015240386129, 0.08156610908167017, 0.048736188665873585, 0.02273449035842092, 0.07566298793761, 0.015036931783411533, 0.011557489708666841, 0.04129845168321364, 0.07893404547846125, 0.029090018980505488, 0.016798410196638396, 0.019708906540707238, 0.03113415032144516, 0.014725017169820926, 0.059705384135726965, 0.04520811245686585, 0.028800364966774662, 0.05418400843477538, 0.01602313113248637, 0.02653217014496125, 0.07900019717072287, 0.042799371144463944, 0.0036201745810573024, 0.02452488954839928, 0.042344085091064056, 0.0253642748500551, 0.026141591708085714, 0.025960260611628334, 0.051792890975071545, 0.06757527514691315, 0.06061711686573202, 0.07071885565716414, 0.05575035946563848, 0.028573346301733006, 0.045456493483676065, 0.05207776843059448, 0.03964193210366272, 0.026653788518160585, 0.031640346747853106, 0.06038059104955005, 0.04044408744741832, 0.011048885850956845, 0.0051860681137881216, 0.025300220323486194, 0.07541123612393295, 0.03747040608657464, 0.027692575015187747, 0.0253891171662197, 0.05768331804222638, 0.03502064076582751, 0.06286280785476969, 0.012052825881138205, 0.03329660968794938, 0.062282569030480045, 0.054809530716269254, 0.042187868271984404, 0.07562043941429547, 0.0684767537900517, 0.02345467812471813, 0.03633336306759908, 0.025336429469227314, 0.042481088425002755, 0.07479835812362932, 0.0030633306455603174, 0.01543314479697015, 0.03581439212505375, 0.012508346548964901, 0.03614730329342908, 0.012415047573496499, 0.022838324000458085, 0.04498855548820669, 0.025321929340040492, 0.027021058729939887, 0.009859876215247618, 0.004361667970736181, 0.06527434538809523, 0.018189999334994825, 0.01901128963987914, 0.060848318370840246, 0.043768997138906876, 0.052285133109938715, 0.007563461108328475, 0.029305034962993477, 0.020832497055732438, 0.09840777834817287, 0.025599640043031786, 0.060591805320713794, 0.03414794787644379, 0.013009280908942945, 0.04092555072519087, 0.011905767643193324, 0.07476981368757064, 0.013690441283547591, 0.003311129206145603, 0.02581941151630975, 0.06173832484731271, 0.007750592926787514, 0.08439855064235388, 0.04968236470895429, 0.06749996870395637, 0.08504261608205496, 0.027633000187756076, 0.02810428598745456, 0.11588819640418214, 0.05453162083041765, 0.08999774172421425, 0.06754064797273568, 0.05418038100845391, 0.012440449133845828, 0.08015459208118339, 0.018727205085357832, 0.02827615015238764, 0.038493838266379414, 0.03949201252732066, 0.011879426667526847, 0.010390234097177464, 0.06598365087542804, 0.04927601252171782, 0.026497602342597903, 0.09258056885652965, 0.03302003279508602, 0.04778008795373383, 0.03700867340329193, 0.015225684356635377, 0.026216494039662426, 0.037393257202159975, 0.07367776301238807, 0.03358176293512506, 0.06426151969560212, 0.0277840401676874, 0.04149918587157323, 0.05745407006132507, 0.056260734901673375, 0.04187367263159925, 0.027433903512334632, 0.03288133640683467, 0.07120455540115796, 0.102468978974127, 0.05050040488581985, 0.022476178916892218, 0.009961459474007209, 0.05518723887601688, 0.025851397602368268, 0.06533747869393518, 0.06593207783636547, 0.03574762373201309, 0.012455886763129986, 0.029904809029352282, 0.007087587399573456, 0.008182985400180183, 0.029665299300705234, 0.05030314490619687, 0.06658601048853129, 0.030986182354090196, 0.01156277284251466, 0.027963220472297365, 0.021424916678018147, 0.05762309970093831, 0.04284708310038813, 0.04382567998442439, 0.04333844806458201, 0.028593998116951798, 0.03742299673538055, 0.04153359471069228, 0.029864409382665352, 0.01339827162859541, 0.03456214480402489, 0.0506621337075147, 0.01427951693204382, 0.014356440778130726, 0.024617831335372986, 0.02539561167659779, 0.018760206237916025, 0.032873219705276915, 0.05258616352934511, 0.05315373508980679, 0.004373519829729753, 0.007493704493578164, 0.04713551689600272, 0.028230692410180648, 0.01963361158906933, 0.04813534590686041, 0.030330945437233296, 0.04011579195878679, 0.010712535905411408, 0.10377861394156372, 0.022910138997699947, 0.06768664900934504, 0.06266293551532492, 0.03043078776118496, 0.07451240048413316, 0.03396732349609656, 0.04295520108914183, 0.05109013170905171, 0.024328771039783478, 0.09519724941421902, 0.033209264173262545, 0.06804349276447488, 0.05982544160478058, 0.03745089382714322, 0.03165936105013375, 0.03861186943287331, 0.03269117806226977, 0.0502619332063102, 0.032478975537683696, 0.07193736446600768, 0.0315746623692253, 0.016444577167050976, 0.03466832075989054, 0.06079701346255118, 0.01895646647279782, 0.053965294162832925, 0.07247368730003796, 0.044941977342410434, 0.03066912920574748, 0.020446024850131046, 0.00947685523574511, 0.024092291188876958, 0.015142145341322308, 0.040729527977565606, 0.027033944328826283, 0.046125590846303015, 0.05479270742545205, 0.012341415990264186, 0.04680750485990317, 0.05963619107440595, 0.07138016573604077, 0.032970466906385075, 0.03070981996584564, 0.010724961851543237, 0.05640824513149358, 0.025083608962895892, 0.18634771597721886, 0.19716254856076934, 0.10845609399820529, 0.13941410538409987, 0.13832717983713075, 0.10356102198843034, 0.13708239421248436, 0.081645613686452, 0.3130891336308372, 0.07148184092535127, 0.11104584656535618, 0.0694529949537208, 0.12225797234643852, 0.1391353413102127, 0.11695813012099075, 0.11083025410170518, 0.18812516253561745, 0.1589000267126868, 0.10509256964489337, 0.16964675407976876, 0.14783094486882611, 0.09464380451508107, 0.2709186287416566, 0.10260331249164958, 0.10225616740964114, 0.09477970851284843, 0.17218089632449612, 0.14430778311385264, 0.2268931951614157, 0.17786151489182828, 0.21061632421708879, 0.1285434709561448, 0.08219505194574594, 0.10557858348493615, 0.15795545562380747, 0.165124123375262, 0.12108012748461579, 0.10373788104662973, 0.11085843847643946, 0.11936297970673732, 0.09214788239689604, 0.21132814247281323, 0.17686639732170492, 0.18992920766674704, 0.2455522931150852, 0.24266907524678016, 0.13789893668745795, 0.2216001864402525, 0.1882358162754005, 0.19192445302201858, 0.1617936020897281, 0.17069600342262178, 0.19452630211749386, 0.14375649092178192, 0.1633200782441324, 0.09475299502692877, 0.09592880209487292, 0.11674856676930383, 0.1464396832330573, 0.15678770780082674, 0.1328313876424105, 0.1224713584768676, 0.12317550819247, 0.28710720039183096, 0.10353148163807008, 0.21863383271040457, 0.2593129789156299, 0.07693424190004026, 0.16660319400891183, 0.22729548325221385, 0.19363495881759352, 0.08780014956550253, 0.15989417901202557, 0.075299923548535, 0.14611967298532688, 0.2326166533654736, 0.2297210708380707, 0.11427003484699996, 0.09836817160248758, 0.1191173565964545, 0.08401602762000215, 0.16691053316237467, 0.2527775287988686, 0.10337750562616896, 0.07972886169990225, 0.14209452445708937, 0.12323022985290136, 0.19466890172371942, 0.10701068526794834, 0.11218143401727562, 0.12980604514239297, 0.07506080452472934, 0.1993721759607715, 0.09760127162500735, 0.12498241083155717, 0.24351322753054483, 0.20545853001456107, 0.08254153053126029, 0.1223635239406459, 0.12428104967599916, 0.07271223941877966, 0.09570165702532377, 0.1524790760970885, 0.11358913589989948, 0.12635233691863476, 0.11184925063242836, 0.14501287511760189, 0.13342067779552552, 0.14110149064612004, 0.10165866479397782, 0.07395794434893517, 0.22938114230430898, 0.13999781841712614, 0.09564266059427493, 0.21954587570601897, 0.12625135120845613, 0.12451322794321085, 0.12068111058925429, 0.16622531347938124, 0.17456263303756717, 0.1282112645886598, 0.1936448873170922, 0.1633245521976102, 0.10794112969550396, 0.15618711018994932, 0.16281174826285533, 0.10056425456798847, 0.14056861520774905, 0.27454988550274606, 0.2534859609459677, 0.07754655299527992, 0.22832250072350427, 0.15576756979909637, 0.2168357170998089, 0.12823850667524722, 0.12943734234619525, 0.1641601089748644, 0.10347784016161196, 0.12351160628661034, 0.14630705809160588, 0.40146650746464735, 0.15050921889562763, 0.12161327871463953, 0.1364848609533041, 0.13458788935695926, 0.14948405535711398, 0.13169428333640099, 0.10040652472525836, 0.11758254540543403, 0.1802371688667805, 0.10030972951602551, 0.1435176859940252, 0.08066067742484231, 0.1556951285249764, 0.12348892242317239, 0.15317276871252447, 0.12694941818593972, 0.1339437932737412, 0.11225110971398893, 0.19145035184919837, 0.08925567831723921, 0.12321238766514486, 0.14760822778747928, 0.128171956617265, 0.2558660275873638, 0.10535846344165264, 0.1213702449815408, 0.16654374558598767, 0.1416007961116491, 0.11321339275567763, 0.10947095365413737, 0.21336622746481052, 0.11084785114132589, 0.27107953784927247, 0.17026314842364482, 0.12965272030522748], [0.06665829088418715, 0.03955776585386165, 0.03633517103510038, 0.005392930526737004, 0.017053758793119943, 0.05475601181387902, 0.08242906882397591, 0.028271706842426813, 0.05457001332674296, 0.0373905222682703, 0.014704392167679487, 0.04455006208210703, 0.08696113007083055, 0.009224534601784282, 0.03164758436351774, 0.030245005693887512, 0.04290943499654532, 0.028101135450865955, 0.018991497758355354, 0.03099091486224244, 0.03339335127102752, 0.05919387105912451, 0.020912082099746314, 0.04459139252562196, 0.06645896246716862, 0.03306028305462772, 0.06830615367019369, 0.05086508188997546, 0.0047870100412007064, 0.016189607784091946, 0.049317837091943914, 0.00333474314820412, 0.05319726037522478, 0.007666267713742151, 0.002815633352222522, 0.0693262993328033, 0.04515661602659572, 0.03451488867041565, 0.07147866166046551, 0.019892350124615817, 0.02099896604645877, 0.00721366536210201, 0.05316277875775292, 0.05602264626612587, 0.045044928068114866, 0.045261167876061895, 0.044005216519919135, 0.030727108655076836, 0.023100622929632667, 0.05158530413022926, 0.07471574320187492, 0.03185204556962896, 0.04522234637049898, 0.016835739745968775, 0.027207453667576757, 0.06697407232657557, 0.02782967027967736, 0.0346148363314569, 0.07289635332962198, 0.09043055075791576, 0.017432897622066162, 0.04317186990632646, 0.03849331349615128, 0.04143721701937818, 0.07237810250972548, 0.026781158296451456, 0.019945365324195836, 0.04987426207310731, 0.03209333453748015, 0.044414257675769835, 0.06190636240306401, 0.06259700215812172, 0.06082373077891046, 0.021902007508962866, 0.034549764823168516, 0.0893730812916352, 0.023436098577334516, 0.07303734415120657, 0.017289131646975875, 0.07584216058134072, 0.025520049253358476, 0.04524587293065364, 0.04702692393273596, 0.11701737170017536, 0.08457759305113748, 0.08111258503049612, 0.05610869326178105, 0.05885229543632558, 0.051292497664690025, 0.003109402455119116, 0.05555159795368391, 0.05325434158646292, 0.03566190615416535, 0.05875856840922948, 0.06728783895772311, 0.04809724835438594, 0.07121888890622124, 0.03562256370881393, 0.024369526917355198, 0.05455184555161865, 0.025587321349209356, 0.07370053880637692, 0.026056487000577395, 0.026383112417533997, 0.07417251025476763, 0.01396009561440517, 0.11377305828876073, 0.048480606412575136, 0.02785035273841312, 0.035702539457669186, 0.02483811225712059, 0.1288952738527329, 0.02309462254596574, 0.04546728383208956, 0.011301690077919875, 0.08715625266514479, 0.05915247932857564, 0.06371905283641911, 0.03988328810420729, 0.01251858914451253, 0.0498870748936409, 0.056355863869670904, 0.03864265467611052, 0.11404220795919819, 0.09623329140125744, 0.044463145576657793, 0.006821130049384891, 0.03981244795384907, 0.004868347990146328, 0.13602016734019404, 0.034675154264175126, 0.03235039534047246, 0.010734373241693023, 0.0038231182148710137, 0.02665330971320791, 0.028382306956055186, 0.06536387808380589, 0.0318870059920535, 0.029801708916502617, 0.029309619999220295, 0.004654952283618191, 0.06745175113000217, 0.05336185053531682, 0.06142176965612078, 0.0418188973450132, 0.01461678235265877, 0.019128669631637393, 0.11905318907191677, 0.0221268026038043, 0.06862946575687778, 0.06937270127837697, 0.10135324852120492, 0.09601735419804051, 0.043518562996459585, 0.035992886780971484, 0.02097353384259247, 0.049513852178689935, 0.031757433710980325, 0.030590262369162617, 0.03264093418575583, 0.022563325248718746, 0.04310199502675284, 0.003109155870568488, 0.03771158971733624, 0.03972748114216713, 0.012485349547087908, 0.011415722265449024, 0.04269030703712375, 0.045042702582694834, 0.07074232093028485, 0.03331084360158251, 0.01166573410192805, 0.07995285048720338, 0.037578064422573776, 0.04830180149104807, 0.03241271276267306, 0.03900735849334348, 0.03814296233617971, 0.04000441043547565, 0.019737705701000748, 0.02585298915003096, 0.03652004337298774, 0.04785148734827677, 0.011840946071090238, 0.03179594303571409, 0.03726049416488217, 0.01755672998936667, 0.0168384651037594, 0.038584094915178516, 0.07161677965233404, 0.004037234044047974, 0.08174954883513913, 0.01335481912153022, 0.03081214441467197, 0.00859570665089714, 0.05489134124570316, 0.05666332559720163, 0.010682285008501383, 0.018579244778882113, 0.07230970617984572, 0.00944230275514025, 0.09110186594508349, 0.028643041150644425, 0.03426804748033324, 0.011094969870041937, 0.03473440350423898, 0.06098328774133998, 0.024967996719022913, 0.015317340073506198, 0.014273851711843765, 0.026927264670150417, 0.022377872599228736, 0.042858896176180536, 0.09158291553537692, 0.08620413561021129, 0.061853747484424425, 0.01680357745968767, 0.06879686362921231, 0.040549359419533325, 0.023600878344187816, 0.025082057634849223, 0.06708691707782208, 0.04274404044413278, 0.06874865371613734, 0.08526720241793702, 0.012374065699987115, 0.09243254534780018, 0.017171246037187598, 0.0409141551673172, 0.009318373669239302, 0.060730700891825466, 0.04189035802659008, 0.04065022638608371, 0.06533131168614473, 0.06016320594015622, 0.025156873781534455, 0.04127101807464515, 0.05204448191028449, 0.02788151527995304, 0.015381537283950997, 0.019095511431054726, 0.03739723702892661, 0.06100598692653641, 0.09517406759363028, 0.01833832161801477, 0.053778429996342435, 0.04288680092882245, 0.06640772650679273, 0.06810296417003678, 0.0596332109923805, 0.0020062575100793416, 0.050146905104479486, 0.04640157402102505, 0.027324188230258804, 0.016950137740481767, 0.06680111265591075, 0.022107485696793567, 0.02520222427143205, 0.05810603386752548, 0.015274602901040307, 0.021921234400642496, 0.04883655001439395, 0.07791929307483858, 0.059848205907450575, 0.038992707061791615, 0.030844436935900204, 0.03153742858088546, 0.034084354917849266, 0.0194315099337649, 0.038113050433176185, 0.06442723600494285, 0.04335355531844882, 0.05466040787136844, 0.08001288879782924, 0.023057852240820086, 0.028643835966865865, 0.01503903948281321, 0.07893909399788226, 0.07324762762554231, 0.047076045490440824, 0.05042125268148319, 0.029894905427711147, 0.043920640413078575, 0.029247237459546136, 0.0493326532323995, 0.06371468613525072, 0.06336661025641427, 0.03988916399858652, 0.052915493236674424, 0.014501857672697835, 0.021176374772743835, 0.08810264704328391, 0.012122373258124196, 0.05516302283673037, 0.08386938306953638, 0.11295615575246273, 0.008860342148240776, 0.031552832693822926, 0.014200785118455609, 0.05505988058904487, 0.017522545230965463, 0.0570990840694116, 0.062018329983637224, 0.04511638491925213, 0.0019732132650754084, 0.05341127852819139, 0.04805555401910697, 0.025575793641168746, 0.02680268919756336, 0.017070013263653365, 0.04732198269677259, 0.02877596315116652, 0.03412196600449181, 0.03118427353911102, 0.07669930571630117, 0.04221714049157116, 0.04295048964840751, 0.026744939574611284, 0.009753883162873888, 0.0077343609600868685, 0.014190607640381544, 0.04110643174499273, 0.06692162594727932, 0.0353790856447191, 0.04921306690741931, 0.024678815764585332, 0.011817904061547691, 0.09637517088483419, 0.03476358762371444, 0.05099763425307409, 0.006338007712451321, 0.05771065588980433, 0.017766737672049674, 0.03505680394629317, 0.026169303023526748, 0.07603902219524307, 0.04117548308004776, 0.022520366868364717, 0.010534430039115252, 0.03674922623641549, 0.02980305723124935, 0.030861677744636135, 0.016949206943653764, 0.04060629890450547, 0.034222158813668836, 0.02064859956472872, 0.06701763208595014, 0.0428123563347805, 0.06032307699863469, 0.03960540886187265, 0.023938194518127752, 0.06729788237041043, 0.1310652485417743, 0.13442258290465803, 0.19850675707622883, 0.09071303035823569, 0.08139815962603016, 0.1349561478221609, 0.20033514848159206, 0.08823072162246512, 0.2045607668978553, 0.07400460676440308, 0.11087816524048967, 0.12395413697607095, 0.15354297304105374, 0.1803907388520818, 0.14587722147905058, 0.270301744101509, 0.14165609233802365, 0.0916041361708795, 0.06664430211868978, 0.1623816511804058, 0.1367082215485073, 0.20885620656753742, 0.08496037654338345, 0.12619979349115204, 0.34266401923471884, 0.22420228068386355, 0.11946623303717184, 0.11815098264525015, 0.1263155110721146, 0.15163424965595046, 0.16159869400003266, 0.09041650836626369, 0.17526554935161145, 0.07956725545227528, 0.12119103403341387, 0.13301831309593495, 0.10565336898810442, 0.14192874303027508, 0.22298895062938814, 0.11167172507773485, 0.10346922167246381, 0.29323476997594683, 0.16367561964979097, 0.17980295023129833, 0.09523259671104532, 0.1430614653133577, 0.1568520591864663, 0.13358056034532287, 0.19729575592904322, 0.08060381071822298, 0.1606479482424836, 0.10080476787181632, 0.16458309676137664, 0.0752104904442545, 0.1442018944409586, 0.15348850418963741, 0.1568649294635942, 0.134196357140618, 0.23419375260991437, 0.16626092124610178, 0.15300888718376238, 0.13645613265614356, 0.1559528864679798, 0.20733147709360047, 0.16812515024456287, 0.10133954320823955, 0.19628487226943817, 0.14332815584155822, 0.1627884438681987, 0.1569123043408317, 0.13063496759822293, 0.21277301494152318, 0.08912528249164743, 0.0949381661391066, 0.1232919995222361, 0.21923145790013576, 0.08529215390163083, 0.13182030479994514, 0.09848453269730653, 0.1503609349170039, 0.18620134721840584, 0.1465633911110701, 0.12584429805076894, 0.14269961134320305, 0.1287748601527945, 0.19786148121760738, 0.28581655674403716, 0.14054524952605849, 0.07289217815043465, 0.10559460238343286, 0.11749256071784805, 0.12672756678394734, 0.14341576565657893, 0.16070647735989865, 0.15002629238991969, 0.14841519416339938, 0.2791003864859381, 0.11761030843180996, 0.10919760582187485, 0.1038023779889749, 0.12061851354496134, 0.16309748373685345, 0.08639809375088062, 0.20284161963049444, 0.09660263771131154, 0.13499632147291016, 0.18259791477072626, 0.13392264924703107, 0.10297095808651179, 0.12926550882477916, 0.16452916417150729, 0.20521782518875217, 0.16491315808267365, 0.120103012980713, 0.10890110681254057, 0.1648016156808984, 0.1155924711436514, 0.22285235715248894, 0.22009686146291996, 0.14646740029415778, 0.1730134193935702, 0.13735435542560395, 0.12332226765612442, 0.29975187994780084, 0.19215179727442805, 0.15795485807522652, 0.16211895963117, 0.15355397406364643, 0.1291402534491593, 0.24541946879077345, 0.16441955231130123, 0.15139195136725903, 0.09121963664168313, 0.09748450450358853, 0.12975028926326385, 0.09516870497816032, 0.14920161406119026, 0.10194300598795376, 0.13443937555195826, 0.14685799788323142, 0.15401557268154237, 0.11952499964184339, 0.1539296022946796, 0.14658188447356224, 0.11803223901698667, 0.19309578613648493, 0.10690391559394137, 0.16427178927246602, 0.12857903275758992, 0.156844919247012, 0.24688140969843636, 0.18947264990739285, 0.2011434478505004, 0.13788830338706895, 0.12891617273130726, 0.17318185148460252, 0.09488453998440698, 0.07130443028384639, 0.23106160213149365, 0.21296021618670036, 0.084920386753736, 0.10782053979534297, 0.06088268890556309, 0.20199590452736427, 0.189948421151888, 0.10263927265881531, 0.10486321824212229, 0.13524183733088357, 0.06799842381188947, 0.14271718540018605, 0.12116132514371027, 0.11642952945323722, 0.16990137106228262, 0.10307195911844892, 0.14341571969130348, 0.16468932251295737], [0.060457912303747675, 0.04696706565277231, 0.03922279007853039, 0.024419039179901444, 0.03607182065024972, 0.026023470526260715, 0.08416859403012261, 0.10495321825146676, 0.0031607406403523905, 0.0717640677166562, 0.08144065452318999, 0.05484301258899993, 0.024976383466573975, 0.020140541544664773, 0.04563085892568192, 0.05384345553935536, 0.034473175182938576, 0.10645179348366876, 0.02951355260466376, 0.03384158931552403, 0.04570139264087043, 0.014533739379276673, 0.061698549562284065, 0.03518767091595838, 0.024048637583731644, 0.050840953950800245, 0.008818719633704713, 0.07997292965169876, 0.015834892795781697, 0.030461479158651446, 0.013317437861264955, 0.04595541590524297, 0.07021843936414489, 0.06729108717052207, 0.03760612622324017, 0.016152406554488886, 0.028546276584928556, 0.03328763113747681, 0.032830544777454874, 0.03739340658930521, 0.0012024806933515076, 0.009142391781713213, 0.028145407672010125, 0.04897956713853825, 0.007727508782409132, 0.0414349838730789, 0.0205625640603924, 0.005911594076502708, 0.08115685725164029, 0.10468812118614874, 0.046374071464543386, 0.03453941114487187, 0.07699961984349836, 0.05120993253865069, 0.061332129708100716, 0.030266565323296576, 0.008935701259742341, 0.026868542115534508, 0.013395646819844844, 0.01698573593110327, 0.0424264740168808, 0.014371626556009777, 0.03237597884670381, 0.05692065070052782, 0.07450939741946998, 0.045356442400765036, 0.03182805552628012, 0.009820791366960733, 0.04756670182330474, 0.0116828705311843, 0.09030626065308049, 0.08631056054465233, 0.08980723864008343, 0.03431105565640234, 0.07301103669188677, 0.009167711945220588, 0.0900732779935483, 0.008139530020285278, 0.06654669485625721, 0.034455769665298924, 0.005772167031893568, 0.027507965062414447, 0.03068263150541292, 0.051439345228455724, 0.02702041330086368, 0.019565448916006475, 0.006617470841569406, 0.09352648826015574, 0.03405662253499031, 0.09465079889782975, 0.036956537289605025, 0.09319753776634894, 0.022836155971632372, 0.016567731546538494, 0.05012820872868742, 0.06169173521019759, 0.008650531733198272, 0.04631582196922072, 0.03412782657711256, 0.04146150583701749, 0.02704806332927077, 0.06671724134996053, 0.12973450785202364, 0.01925637457339514, 0.048320283362221335, 0.04158321039510831, 0.029808061700614712, 0.029276228141820723, 0.04802900907253066, 0.013327674711153153, 0.05587053950875998, 0.050820989699493495, 0.031626313932300094, 0.02472041625409357, 0.06168096784442183, 0.09712543909347827, 0.11684034410263262, 0.04836830941419448, 0.03366620114613925, 0.021078179537829374, 0.0609552642450698, 0.04824886481548029, 0.040205956677034985, 0.022331708140911597, 0.07213840125909737, 0.04280615485303345, 0.06497779275260626, 0.025671721255827337, 0.020891606484750108, 0.01643000617473116, 0.007856026256171567, 0.015640904011595395, 0.06976984891920321, 0.02167173105502321, 0.05277987269143905, 0.059481494939855994, 0.07575100377923058, 0.04121107552500983, 0.028558691039741523, 0.05284122484285505, 0.08170428836057264, 0.04676714351761245, 0.06950412366178728, 0.13857972838224905, 0.05894690729497422, 0.13030562639957474, 0.05274688494541953, 0.032172528876652645, 0.014429933507926764, 0.05526952437996384, 0.02381513973007039, 0.014708955178878482, 0.03152801336029605, 0.04315810330632714, 0.03384402930556286, 0.008356167236343026, 0.009932499435249596, 0.02942295887717797, 0.04907584140798257, 0.025762020039462277, 0.036908706590052576, 0.05765818269743074, 0.02248051880498327, 0.11890555626802868, 0.04089596057911554, 0.11436058643964991, 0.057802145940161524, 0.04967235577022357, 0.036314214699931686, 0.034520818190949584, 0.06613889093240423, 0.033924188915519946, 0.06034266586685854, 0.026306132072462674, 0.05110045091339177, 0.043487279796071594, 0.045574674037315195, 0.03929036669433117, 0.031337900981006604, 0.008149525552477327, 0.03985876946019069, 0.055067434215978275, 0.05955430393617961, 0.04616722389454803, 0.017581846181964202, 0.13902648021617245, 0.058014153112326904, 0.008217100253058298, 0.009705743155322008, 0.03962796249036347, 0.018408041364783724, 0.08730809895261642, 0.043112249113619334, 0.07176735423385136, 0.07357872316553708, 0.024588143513087305, 0.030101019468518998, 0.005497296599881543, 0.01460204377860552, 0.05677892060409631, 0.015330669045778773, 0.051668819205294696, 0.05288540896388793, 0.00783039439064, 0.0234823779488403, 0.05121568585896204, 0.0032414470455654327, 0.027292200228980473, 0.06430879115096985, 0.026205766893502687, 0.050132966134697206, 0.1223099054468255, 0.036353767819462285, 0.011773719940514816, 0.010296563569065786, 0.000910224853507844, 0.029258947113468766, 0.0653512452939345, 0.07880816957162273, 0.01623700755918699, 0.015796943672842557, 0.03884818074443648, 0.014971033857774832, 0.06119566263570901, 0.07888384373678316, 0.020379788888197754, 0.04919905898972385, 0.026513667206370065, 0.05658657890894721, 0.06419367111858822, 0.026656324269189954, 0.0624451405488916, 0.02032004552142274, 0.04712214100084478, 0.049811289645731456, 0.057901626287568966, 0.12675015105595513, 0.004583916780839284, 0.006779832643411693, 0.03964728322781382, 0.046222294124984936, 0.03363535078542848, 0.04847395293895276, 0.03418659701222374, 0.03494223166677741, 0.022867799233344775, 0.032996789687463356, 0.028734659520728935, 0.05525099654351512, 0.03942396093700682, 0.014679439726375766, 0.056456267353027105, 0.062460745759909196, 0.028932884771136508, 0.02064004810827394, 0.01929076426031609, 0.023810345934884205, 0.053644835753666784, 0.05261591072344492, 0.08269066486747996, 0.029452654360342893, 0.001411525618975922, 0.014803709721403017, 0.052938744005176334, 0.03709547499555253, 0.06749711885687805, 0.018497857513026367, 0.01824120082141411, 0.03449863611510204, 0.04506314180851464, 0.018825296898402514, 0.016707960110638412, 0.048355105888819506, 0.09030009364529003, 0.02649123423672732, 0.05806638115656473, 0.05737600570184089, 0.02812696219001326, 0.11194465922251826, 0.039536709927262804, 0.040091690832688924, 0.06939157768483124, 0.01785408318673651, 0.030393845086256345, 0.04836513781018796, 0.031048697043931296, 0.0632552057504654, 0.08676626794641057, 0.03736303886398673, 0.023259938574366035, 0.03704581717630068, 0.07092772952971921, 0.07675157589537483, 0.05135155538277281, 0.045231558577788454, 0.04511106826905762, 0.020115695398060546, 0.014053316065861333, 0.02136630712137107, 0.04404966111084627, 0.04650185876075299, 0.04540995364227603, 0.01711001837505929, 0.01074290075790017, 0.07429107002192929, 0.07993667071024257, 0.027456803795611186, 0.010944902821774445, 0.027010178366195292, 0.007195469816290444, 0.03952649414479252, 0.027653374296102314, 0.034348459899305336, 0.0635714162020914, 0.03278575927740143, 0.027480328440546032, 0.03895226911070847, 0.05579650094131789, 0.06261119776735864, 0.06446848217878612, 0.06359732146525095, 0.034970124928100456, 0.04931948801142074, 0.01684618918525596, 0.009093629327722856, 0.014005797547138026, 0.04324132343754173, 0.02309191825559303, 0.03022480970098367, 0.03807703663985576, 0.032429068739856445, 0.020464692497625947, 0.02975790017855264, 0.016962916087058764, 0.03705295328531535, 0.0627889646397483, 0.03281485912720523, 0.024123645252397945, 0.055058478648143436, 0.03500461037601194, 0.047201312357379545, 0.05513625955509563, 0.028962296801769448, 0.037249067963491526, 0.0243986286823788, 0.028936201931848645, 0.06894330133593853, 0.06562554307522313, 0.04138315802500133, 0.03657083500236754, 0.07284567661343083, 0.01341916859194997, 0.10999370907102862, 0.2012605826941229, 0.10306687995551095, 0.16015412796649242, 0.16370796388195408, 0.11291265728012209, 0.2017884479174691, 0.12967266923477574, 0.15707782529775174, 0.21279112526005317, 0.16776370996188733, 0.1191054362683527, 0.13530009065664586, 0.19525854427727962, 0.13280489632198889, 0.21794475194427276, 0.18097046822790178, 0.1867333033512677, 0.20651701837778094, 0.07157691243675447, 0.15676308573494036, 0.1513304345069393, 0.1734300639720694, 0.12096785729931248, 0.15509613969873998, 0.14465872799196552, 0.23061132629311856, 0.08178345588666779, 0.07821424458656581, 0.10620263870805503, 0.06084870524524201, 0.11864939944878702, 0.17494457383309642, 0.15657858111925665, 0.15888516460695576, 0.19631799791128407, 0.1099301161124341, 0.16691341365296997, 0.20576498050603176, 0.13340809863180886, 0.14748309498592732, 0.16839420032357016, 0.13002085619636122, 0.13345191886107768, 0.07924666297772238, 0.1719033579912878, 0.123544440815045, 0.11433297663085884, 0.25632469974938904, 0.17074604428583579, 0.1679975659616532, 0.10611928834189331, 0.14416593427379287, 0.1453270630971078, 0.11855006082764558, 0.138963615041106, 0.0834030730109061, 0.21708468035344156, 0.19865363145307188, 0.09625107230197999, 0.15163849378305097, 0.16583709076287287, 0.14087269082665443, 0.1536938770403785, 0.2564047865809933, 0.14463536231027496, 0.09415075798789341, 0.11175550445313416, 0.13268229161058703, 0.09249475168725176, 0.23225666864985423, 0.14956711460986447, 0.20013716071844104, 0.18495020306398793, 0.16005308096927984, 0.1736326789062831, 0.2569897559982154, 0.10673791200162903, 0.2251535473812011, 0.14555285985191024, 0.08860880899573527, 0.1194376809402339, 0.16283209555812422, 0.11484834696016005, 0.11857120485435571, 0.17204958885427446, 0.0847765997112278, 0.2008668135010427, 0.10441226824637383, 0.1306380779151955, 0.13372188824559414, 0.16836740256797883, 0.19891221677103352, 0.05073734055904131, 0.1413002291754369, 0.13760698057951468, 0.16232644688458214, 0.2088705783769969, 0.09964229073375465, 0.1325814897615102, 0.12300538304712504, 0.11875195563921045, 0.1613640719123425, 0.12408986477361572, 0.14749196628409048, 0.21546039009286513, 0.0985816726461053, 0.06058712452349644, 0.19288065332558849, 0.1135285919712436, 0.24047142946191374, 0.24039318124132775, 0.1742327402556135, 0.09700543142013973, 0.12953239853583998, 0.22098844991095606, 0.29672745675329243, 0.13645751161440728, 0.1421998155814025, 0.12304662156008905, 0.11803102093718706, 0.13315355825808742, 0.0898748842037974, 0.13613811423701627, 0.14642195595848947, 0.14210540290561416, 0.09799697135965671, 0.11551908758138457, 0.15187785029411316, 0.10614447731284365, 0.0754328474642769, 0.09426983869484357, 0.25176984738678704, 0.0756472218481283, 0.18606772616265282, 0.19300995364544854, 0.18476955953144258, 0.14814125644343515, 0.1296515098863071, 0.09688974448269415, 0.23041531503681215, 0.10654414538294078, 0.14430124072297928, 0.2225556666211736, 0.16549775977769207, 0.2357687680952011, 0.15434005688275063, 0.09223113317162761, 0.08207679861375401, 0.11786140907075136, 0.12006457068867261, 0.12840767421068686, 0.13054973265576747, 0.1483710828207193, 0.11487802520634667, 0.04464121505377754, 0.1975732636187346, 0.1409747490599271, 0.15139259488111542, 0.12194313319219698, 0.15282248267002646, 0.1512004447079474, 0.08502924784777627, 0.18415154108116705, 0.15218917310478228, 0.3330069906528919, 0.08009329738636171, 0.08573118356927749, 0.0709599435269352, 0.1460734319182173, 0.1530453682907166, 0.18614153107327802, 0.11894825034804883, 0.0849803944208449, 0.19142154694324542, 0.09201451415015806], [0.03097846784869269, 0.038043573919323184, 0.07118020912692433, 0.06467753225156377, 0.010996101435364015, 0.03852593735040676, 0.014836849727397485, 0.014201913182924112, 0.0140674666674327, 0.039049677190280734, 0.027498185950061007, 0.015769427709822214, 0.009011921262548817, 0.04169937613750658, 0.006323655533994879, 0.0531302391731691, 0.010109242622650439, 0.033854030583414345, 0.01629660919969601, 0.048394754769340645, 0.03805465155070828, 0.07534113141798204, 0.01735511096945453, 0.03450627018126749, 0.023868725665153998, 0.01379031137818651, 0.008010533262765216, 0.032779730165437344, 0.044418107267589345, 0.01089579371299835, 0.03835873483049293, 0.02434817987734512, 0.022261997970241695, 0.03199992160643301, 0.02912195527084893, 0.012911244637272772, 0.038187552483812455, 0.013328825758259385, 0.006588968061541598, 0.009574052641138194, 0.10756573129084804, 0.05573465083275111, 0.0837805628355953, 0.02445366635407892, 0.06275882291036748, 0.039981722741598086, 0.0804942831276886, 0.032613569525100534, 0.06080309237023035, 0.05463632589746868, 0.05135206483124245, 0.026082489939947284, 0.017841741510276354, 0.08361910980555319, 0.05722120614542116, 0.04130880919194991, 0.00952726286355286, 0.01932152077525614, 0.04069973098775072, 0.05741854656427618, 0.030883036275965073, 0.06966426668147888, 0.03409176298807706, 0.003839187148485273, 0.005219363252587256, 0.013966154412276322, 0.08917234327283599, 0.020030232544447628, 0.08525065491877257, 0.048056802742423556, 0.058806782152744076, 0.02874282793322158, 0.03904085951827226, 0.06172192673529349, 0.05441566576219855, 0.051606708626833656, 0.08433978403768233, 0.023271355199657624, 0.056355925156704845, 0.026091453168661367, 0.059672327441794265, 0.05722966758654483, 0.050669580082138704, 0.022558722975513628, 0.025791481865810293, 0.07322949432437459, 0.031055425211126288, 0.0603119993672496, 0.013847432809040673, 0.08619741701911535, 0.05975639410016518, 0.04428300383170286, 0.07948409660809463, 0.037550247770043156, 0.054898450541640484, 0.055059390292773326, 0.06555422028947262, 0.024960762933797898, 0.04364255432700438, 0.030346186756486856, 0.052049319755526326, 0.018492341679971547, 0.09213922560335168, 0.01995630122931494, 0.054587978088567336, 0.07264354431460943, 0.024684297123683557, 0.07965924729022288, 0.020385526886750615, 0.029286150895659963, 0.016839922586035345, 0.030451941363994154, 0.020160159141185786, 0.05474973755377916, 0.031177842230986685, 0.0706398873139293, 0.009116874350565336, 0.047420846343400984, 0.014167751407160634, 0.06257809127771086, 0.031695568280655055, 0.015915936279681422, 0.0424807743289538, 0.03023767614767196, 0.038432007310010737, 0.036744591404473594, 0.044041272448075396, 0.02969406590226197, 0.05049575090167984, 0.01245083154043964, 0.05899881358228384, 0.029537801202687047, 0.03980512798373257, 0.005745916071558191, 0.00942082452257314, 0.040572659983750314, 0.030880368374768766, 0.06532047154201616, 0.02345590578061679, 0.03055230845817395, 0.022150811799351248, 0.029111203226831653, 0.07855493154737257, 0.04304305988273794, 0.07890860369849591, 0.009087632774495551, 0.023123423621479063, 0.019471087951153036, 0.0508558352087294, 0.07459807209670544, 0.026123948703189532, 0.07668245944284624, 0.01572335230922627, 0.044389271718119426, 0.016097908974775386, 0.04500070564268578, 0.0384525997534154, 0.04461979906585428, 0.029458421087192915, 0.034904088149027485, 0.07073346495388017, 0.08997952415337486, 0.05285951902248687, 0.05007997583297472, 0.06694041808406193, 0.11858795153638048, 0.0501905223204484, 0.031137337247210167, 0.02367108072634907, 0.011035780959402122, 0.09070108704749616, 0.018645511384332375, 0.033757143443630594, 0.06404108938670929, 0.02410499675710115, 0.03682077884854328, 0.032265026332630266, 0.03341731450129901, 0.03921199206923766, 0.025110174976890127, 0.01310177836492057, 0.06927684069641175, 0.029072986930728923, 0.06445034121673915, 0.11848602353805497, 0.03637762379742438, 0.0309781116178079, 0.029291360293545073, 0.014392635559723263, 0.06809688909279724, 0.035741464385101875, 0.0071481787299196575, 0.02065581419775563, 0.05028465920458398, 0.039662559021023974, 0.03299951313003417, 0.05238491989251587, 0.03359515032160186, 0.024251639392347108, 0.04724322502771693, 0.02782784507519776, 0.010925432697178857, 0.059130883309990175, 0.008168102227031224, 0.04494206544252173, 0.026633852995150996, 0.11393500161507439, 0.07019321208879833, 0.01614779662040453, 0.0654942968920354, 0.03370635564469042, 0.04483995358309439, 0.037468640253909176, 0.07773021491424692, 0.01824723759425744, 0.08203662496300475, 0.023397001280118863, 0.04954392496015757, 0.031128094396403724, 0.03269740252665455, 0.02196872036062902, 0.031222202552242145, 0.020590512863089962, 0.03622369758123833, 0.05779194164901011, 0.08715519546380929, 0.06910891422340948, 0.08803149279687675, 0.05287465691987065, 0.07656041397562913, 0.05471370843870025, 0.02607398061832834, 0.055708611504204815, 0.044426155021233905, 0.054654455368196776, 0.021074661279037114, 0.052407090477044546, 0.04777136221227627, 0.06498410531710233, 0.022997116790183132, 0.05051452771670396, 0.052304676012887116, 0.10436380552428384, 0.025304891544604496, 0.09037389089503596, 0.034417005616330335, 0.053399231795582085, 0.03955623750845271, 0.04526594443426979, 0.029955050990646406, 0.15911750375263153, 0.05409836363528044, 0.03379182807440239, 0.06795078846475772, 0.06743263723629137, 0.03772883818695142, 0.05862785848758875, 0.024385877148879152, 0.019868959545067722, 0.06967554349572429, 0.08712728688072774, 0.05746838058375063, 0.007570365475746053, 0.026671691992951017, 0.04101744297170832, 0.05759742809459568, 0.04630936001757941, 0.03182805744149993, 0.0372972242504118, 0.021763606064562357, 0.04160607428920846, 0.04988900926564971, 0.03481094717919346, 0.028116539563803424, 0.03459217162021706, 0.06369526580637021, 0.06025189210871055, 0.08634767750458372, 0.01492339276498364, 0.029183619603094076, 0.007192594592549628, 0.017147744374890483, 0.02025410258812049, 0.04211389099157626, 0.057146033767851136, 0.08399475335834489, 0.046079767297112176, 0.04514702460578373, 0.06548356400021622, 0.05530093398485934, 0.06769045646632872, 0.011228101587133303, 0.029439680661345204, 0.030582272072112372, 0.042620439818429376, 0.11734673588146126, 0.2024605062099234, 0.03006382398457537, 0.0185494075694512, 0.009337058553712503, 0.016199997851565, 0.008912896737456322, 0.026745998691166603, 0.04650641698390246, 0.03853870037522528, 0.005178635624507743, 0.055575335188017744, 0.05595775861893931, 0.03562701467965399, 0.023476461834845044, 0.04703327863206787, 0.02172540509021811, 0.03320288649129291, 0.020782101876853455, 0.018657538964743578, 0.02583485393364343, 0.04000429935272663, 0.022438075618758317, 0.019761592322479815, 0.0032288403505639687, 0.07561451755464077, 0.02565876287858813, 0.027670498276429794, 0.054869059578425465, 0.07648100896227746, 0.05111745423487118, 0.03100110574685518, 0.11752027011806927, 0.022228209662341306, 0.04251216478165119, 0.02393182066659774, 0.030347169264249747, 0.0253916758998868, 0.01408854078861975, 0.04406110646443502, 0.05148366341487535, 0.03374913016394262, 0.03903382683112737, 0.04412133246660233, 0.06519543833189434, 0.04322659922763706, 0.10258299583989768, 0.06935964714014722, 0.02020892829844548, 0.024476290845702735, 0.03678566903897351, 0.04601349303078267, 0.10551130564342584, 0.05637048082726617, 0.05522535941112907, 0.05890215243843775, 0.02666935159434234, 0.2321319188922644, 0.1465905719106236, 0.0877041281050732, 0.1714420198432861, 0.07970705117669799, 0.2180365905646355, 0.13355940099685423, 0.21094750402675522, 0.16524344923034792, 0.17076415460436575, 0.1501422321363803, 0.14381407009017083, 0.07915417318262401, 0.1028790735008736, 0.10516874176720459, 0.17349996183428074, 0.252632278528425, 0.09980647103680719, 0.08916249904300898, 0.1527121353654131, 0.18940609218853136, 0.22684661701561945, 0.12783439529518928, 0.22088314346488447, 0.13395580553239392, 0.1380883136223401, 0.18545934509846473, 0.1091432978489226, 0.13412782291491188, 0.14254804850826341, 0.17305236730364063, 0.12344932333836633, 0.1143973816426531, 0.2905920424288319, 0.140878482451362, 0.11451324478032128, 0.14790577633726984, 0.1657214114863065, 0.13266453369250222, 0.11611762441574566, 0.24513339623808864, 0.14326550517111056, 0.27043942542326066, 0.0945374638503117, 0.12930192864469944, 0.15711560875417727, 0.13764543819331354, 0.13354830804371065, 0.13866479478536115, 0.17058862853915463, 0.1324298962830536, 0.15549027661402381, 0.14198860514067835, 0.1842418781691982, 0.19291451441184168, 0.16482199361968428, 0.11968517330505195, 0.15940474075896127, 0.14722222672595134, 0.1274810525618734, 0.23838552526168286, 0.1417617665062989, 0.14961098080440877, 0.07194163923662517, 0.11647930984655697, 0.14748574565014533, 0.2749650745141891, 0.10927781522754701, 0.21721289282844913, 0.16971000229879735, 0.17535227050464, 0.1503638000858407, 0.09465538010361696, 0.13359312418728106, 0.2071574678824794, 0.1124061122837086, 0.1664229488420871, 0.15460817233449028, 0.20437695176130344, 0.14478862586040653, 0.1639799863821076, 0.13293758275047426, 0.1895777878141211, 0.15032768670109012, 0.11735330891585159, 0.16881075297151843, 0.1133894780650735, 0.201786961706896, 0.189722731649395, 0.10467843783478584, 0.08932812725223842, 0.07866325637986583, 0.13954023409995342, 0.14413487706934253, 0.14215898309503833, 0.18486977915369696, 0.16187077778722012, 0.10151136906877642, 0.11835001228797822, 0.1936971651570451, 0.2245986392541278, 0.15644345853117206, 0.14763144025158498, 0.17460351148920675, 0.20398267695019323, 0.14964467335131862, 0.1840640691619727, 0.1949498261655531, 0.13698053516207204, 0.1328534203311128, 0.08474646181228661, 0.15172040390391506, 0.15289945918465817, 0.11112976383658187, 0.1248846043862643, 0.1716910750274697, 0.12868639231929857, 0.12790254647693328, 0.11774866391093501, 0.16418964932522467, 0.18344517737146349, 0.11046233271519024, 0.2048314870485375, 0.11050586949192709, 0.1222474616201174, 0.1688927703446919, 0.11892526004944118, 0.1485158734384083, 0.11373286165537373, 0.09015807626588691, 0.14784381514595402, 0.12500982145748793, 0.18094814442578824, 0.13122637215400898, 0.2278900747337649, 0.10628223524338777, 0.16918212175369265, 0.11912479531019927, 0.1865747844379756, 0.16901477750751281, 0.17596641255001869, 0.1992392137406334, 0.11224763167481269, 0.1556383001227533, 0.17284261242997262, 0.15668503669721467, 0.17324506906011414, 0.1489775180215797, 0.20988768267054714, 0.17066525265334115, 0.11662860506124074, 0.27727277649025767, 0.13950891642560884, 0.1367487782432187, 0.050172274106092034, 0.15556348397606806, 0.11244340544386257, 0.2340888445295634, 0.11043044047490244, 0.1303519134319598, 0.1383409387762508, 0.20220362160715366, 0.11957720087300386, 0.27103623855979214, 0.2192992413596761, 0.18587241970723678, 0.20560224810915612, 0.14408318145621207, 0.07103181023511194, 0.13186072359883017, 0.2156430407757721, 0.19237241527486235, 0.17005601357067787, 0.18894945782038475, 0.16485320404171944, 0.18532604579963993], [0.06218016605764147, 0.07802459186003094, 0.02116522244778612, 0.021314199735981323, 0.07734517912350355, 0.030627492327062838, 0.045990973876248446, 0.041061278522735646, 0.0642794116790737, 0.07324996419371137, 0.02899615405758302, 0.06535427900211466, 0.030011383350938562, 0.018166422979125095, 0.06315167662837813, 0.054275686176674026, 0.08057623921382813, 0.05037806447475188, 0.03475170560000885, 0.017713174719603795, 0.020822608775849787, 0.04027536041253517, 0.04658974053698682, 0.06338121189225106, 0.0442165763477885, 0.013167677248167175, 0.03488552200818255, 0.01832019406250648, 0.020795699937509435, 0.04576423483329915, 0.04256861013991218, 0.03759385732513282, 0.05001756264978359, 0.09423954757831751, 0.08427639026194812, 0.04474342267419543, 0.07007588572319477, 0.014298165427340616, 0.05647382608825161, 0.028308367980043256, 0.05883148082742288, 0.015147087566043823, 0.088341842675882, 0.0782211163952466, 0.0676759927263183, 0.018272056927784316, 0.025516437148795496, 0.024983054177174648, 0.044062749723032604, 0.05352237659897055, 0.040543613760101224, 0.04634117564907478, 0.011725857639835488, 0.02929611195389542, 0.03260609633739918, 0.0294185615324926, 0.023678948449331428, 0.017400771724961458, 0.028039654979722637, 0.018041328481969335, 0.10860440095946675, 0.06613127601843688, 0.04239755036729959, 0.03749320869364085, 0.09031351550572342, 0.048637934059144995, 0.011959223343329805, 0.05688470585512058, 0.0541211739032259, 0.06090300555731501, 0.02462219037566214, 0.0373722319190781, 0.022838831533707922, 0.05812982855845363, 0.06707589307259168, 0.017565164617412997, 0.0555630509681519, 0.028273374998881936, 0.019092839699418798, 0.02421843522648898, 0.04517330142158655, 0.08808150301657378, 0.055237222282636556, 0.017511756797771783, 0.05307426878942117, 0.039505683366329446, 0.06794275986331125, 0.019760362751361345, 0.02801141889405347, 0.05920656896646946, 0.0404942662064587, 0.04536835889842722, 0.05394659012616162, 0.014661769908402237, 0.04765416608161984, 0.04085630020727554, 0.03896726145138664, 0.02268851933730466, 0.02220407789272647, 0.11846664917444992, 0.019111633751421206, 0.035976032846637314, 0.07689294976092155, 0.01871817865439, 0.09034287965586109, 0.06516447305799493, 0.02750343939800176, 0.015389270941546608, 0.05583655201799928, 0.023330535491808288, 0.023902284146677104, 0.009265512644854045, 0.08085367029472705, 0.022941297708800244, 0.08880649798459585, 0.037509039900596106, 0.006463046668232569, 0.02242824862590961, 0.036911204036685734, 0.03775669314387826, 0.024146436368145292, 0.027043122062159163, 0.0907839777609033, 0.09138386291001113, 0.06877106944880179, 0.015680323065739247, 0.024842760495601163, 0.04603873945832734, 0.046381563804442846, 0.03138125964230107, 0.01281091584748919, 0.05499662470913703, 0.030612444445010156, 0.030161707038660685, 0.03618383802653801, 0.06137699181694658, 0.02180676745821632, 0.04430767952374393, 0.01868201930436396, 0.02254179051716722, 0.06365533347331709, 0.014593817909518558, 0.08240324400004842, 0.041874224214904734, 0.034169176172825604, 0.03423969839669524, 0.006352544709619496, 0.02000872079553383, 0.036232212648516705, 0.07704370054266146, 0.028849201156727733, 0.03525064334333424, 0.04727726614463234, 0.06436607920594754, 0.04245958816740782, 0.029282582841152628, 0.08693483027239, 0.02056692884634099, 0.03279326310861976, 0.04395059828135756, 0.025437579888309685, 0.04760340509575702, 0.028145987983612765, 0.06842559443846827, 0.032954375229535565, 0.04702481336050457, 0.02326989197172225, 0.03497235424396011, 0.07066886075922559, 0.08928042295719348, 0.042895584126874324, 0.07188950695337788, 0.06005197380399031, 0.046963051352049076, 0.05963915583467292, 0.01415372433726706, 0.05210519820872334, 0.03839247717311786, 0.040221925779816606, 0.04712926178810097, 0.04810864774269923, 0.06314753975358701, 0.05350151602479239, 0.03290077205747366, 0.059436789879034606, 0.04472918876056229, 0.02972540464402447, 0.02887448588866861, 0.03416421192307626, 0.03705266217190412, 0.018004067880552144, 0.05389223618793392, 0.07294132269077724, 0.029654671745975653, 0.07610787051699816, 0.019507314333872452, 0.03204094369955842, 0.0331779886337538, 0.02283181608354132, 0.05639696448680855, 0.03145610068684384, 0.016255702019759243, 0.06562008852920224, 0.02413116249015495, 0.05720330650107034, 0.015534750080757566, 0.04192567467989941, 0.04202612795897069, 0.04715685627513355, 0.0262865393737992, 0.07452132540845102, 0.01883609682291506, 0.03517533306993785, 0.02288815418949291, 0.040154230420387564, 0.046544487723299575, 0.009863574504702082, 0.04312844804277824, 0.0029577316496626387, 0.049887883116401015, 0.06737757849717332, 0.02555256010964513, 0.0270024121498629, 0.04542384664678285, 0.0675359288711221, 0.07577955587616853, 0.06964650110251482, 0.041987988271660386, 0.03503630343343943, 0.02953548570193591, 0.04223972093313933, 0.016647387453685367, 0.06354354592340608, 0.027129797249912258, 0.042920673506394516, 0.03466377402805994, 0.09834200203899415, 0.019655431688372648, 0.09510827596269308, 0.05581104895099998, 0.010071025368937803, 0.10298005921105224, 0.029097111039464513, 0.03887192180920993, 0.0007005468878853736, 0.041904568957585486, 0.019502275390550494, 0.018844303539803913, 0.04749316504345306, 0.03523357107394165, 0.020087505277666836, 0.006819341712886649, 0.007958399064298119, 0.02597674490853904, 0.020148709957157413, 0.048081715921721155, 0.04257698731136419, 0.013781001494686692, 0.028578073064225818, 0.02408757591770301, 0.01244676361356171, 0.03755377177449484, 0.023904990352269624, 0.05202207000805967, 0.046206819148914474, 0.06339877062747556, 0.033241160243989966, 0.026702180377117572, 0.045572322147387656, 0.019677847421037096, 0.02930011859373941, 0.031637069806757, 0.06173292392744653, 0.027356227942472024, 0.015433619771483205, 0.02680220464695125, 0.0236231217070693, 0.02363320725459245, 0.008174262531552344, 0.049499756160883174, 0.012425855158888286, 0.03431120504354758, 0.041352510677590486, 0.004287778790439329, 0.06170966549806538, 0.05953113360690975, 0.04211253501595028, 0.054266117738499764, 0.022413041780612642, 0.022714855524921612, 0.01679891389944861, 0.00794290206319983, 0.06978605167880174, 0.06827184059206517, 0.013545989659765076, 0.06531802006065845, 0.04918417007091546, 0.014945174559890745, 0.06092241822531628, 0.027123057591398398, 0.048236691678363475, 0.030647785996177027, 0.03266184455564907, 0.05526915282732057, 0.09711872816326157, 0.04819597793562759, 0.022953922837792386, 0.07545809006138195, 0.01440751298721279, 0.032694564170895085, 0.06823643200820492, 0.014311591118213632, 0.035225213054687746, 0.029524580440333778, 0.013209695255594149, 0.06555459567255552, 0.040374270024439024, 0.08064170908783713, 0.0017346773060008644, 0.05758978636755098, 0.0421475452340899, 0.036871754339024905, 0.020019892272689653, 0.02225395213181694, 0.04878684239942701, 0.08938719263120044, 0.0812125901481317, 0.06872630693138608, 0.007213779317680747, 0.043624505295508334, 0.08448846638202669, 0.05871824537133498, 0.04185410291557351, 0.04969669821401758, 0.00983221278030185, 0.07521268145571794, 0.045512574950173024, 0.09131376586493947, 0.01282716648758299, 0.06686341858679248, 0.01464818812711465, 0.038215916889208945, 0.04926648238793977, 0.030071785553328456, 0.04343655328416536, 0.010018297452329388, 0.07150079394059797, 0.021527258363822778, 0.01718051953151101, 0.043974595985585646, 0.08337579261992248, 0.04204683148512437, 0.09839436414861873, 0.14566728274428076, 0.09878136878532749, 0.09082174589557034, 0.12429467838017211, 0.13152557545371596, 0.13577682717192557, 0.17734069767738544, 0.1382106272203307, 0.21585089575138786, 0.13336447758540032, 0.18809405936589166, 0.08707086450510448, 0.14832341683007058, 0.16014220763839063, 0.12055564070901564, 0.216365002035614, 0.22759327695014017, 0.10234100398637595, 0.13712541771031198, 0.10611461520555521, 0.161574347725799, 0.08184347887553516, 0.14972448439127015, 0.1347635379962383, 0.11763011946553185, 0.14374835506802605, 0.11914845210530105, 0.13596304782455967, 0.09139242777300459, 0.10572623927146198, 0.15058242625767185, 0.2059665842041854, 0.1952789222160655, 0.15753565476306025, 0.21936161623847103, 0.1862254483445037, 0.06224969236720955, 0.1533632028487421, 0.06965635299322105, 0.12579916781114955, 0.15439899968764476, 0.2015541169431902, 0.10998599456563113, 0.1700815396203149, 0.12487618507997644, 0.10087689504988732, 0.12051117696589041, 0.13381953381242293, 0.18031987571908584, 0.165854511602271, 0.11562151353686087, 0.18784068344581514, 0.0727710213452097, 0.15150308008155516, 0.11777082683458445, 0.14003313507043547, 0.1182986614144137, 0.15478737562173797, 0.1298812749765573, 0.21831037506701487, 0.11192038955707705, 0.15127605758607388, 0.21224599241489367, 0.1872510868575304, 0.15307208943751552, 0.0776726893720127, 0.14980181330634704, 0.10081510239791486, 0.16677438401647154, 0.13865040765414316, 0.07610083782985326, 0.18895406966968892, 0.133235453057193, 0.18660443204064525, 0.11659173324944512, 0.0831474447923322, 0.112463706773856, 0.07832006431154667, 0.12296638151089992, 0.16181428646368368, 0.1416726704807051, 0.09675570207858279, 0.1158446979318415, 0.10476096082598933, 0.18858210333893377, 0.12038339350012042, 0.11858954499926298, 0.10750154078367258, 0.07709981648311501, 0.13626952895954733, 0.08632680926952632, 0.13385250623668396, 0.10454570544102501, 0.15077054680835816, 0.1342109434546963, 0.106978049922374, 0.14416924377362575, 0.09587890678836454, 0.15381327950425688, 0.09496160842958959, 0.18672274665967112, 0.1498850870637163, 0.1124155428260565, 0.1859693911166922, 0.13119284814644244, 0.11228134720436028, 0.13548782816337002, 0.23786083164234317, 0.17641463527275672, 0.2040046483518616, 0.0880284590886966, 0.1611740361418455, 0.13459970243275166, 0.13203888500650085, 0.14745916239917278, 0.08240882112013717, 0.16444829593022026, 0.11239442178198408, 0.11732441207934773, 0.1281486215790914, 0.09479892965886863, 0.26204736122200567, 0.14294762464780963, 0.1348043091955685, 0.09711066891829814, 0.08640181693819263, 0.1538687442699748, 0.18419330819479882, 0.16475611005819615, 0.09601167748652159, 0.13977442717840596, 0.14836898373980678, 0.12497889448798473, 0.11492504002225977, 0.1412599789158952, 0.11456716970931138, 0.07802422413782728, 0.14710063325060954, 0.14343844185913765, 0.17440209165215495, 0.1650884543215075, 0.22393513050290847, 0.12871073859353221, 0.14242446320431848, 0.1986744843663708, 0.0861784563429894, 0.17662848105594037, 0.15773617061636142, 0.17847153538417432, 0.21466206518873093, 0.10276409902519758, 0.1351943092360612, 0.13186875220027663, 0.10069456612390858, 0.19380432553589347, 0.2710834295759278, 0.16173499636352062, 0.18554980476056376, 0.20501491914112724, 0.1364309743287102, 0.09221986401826145, 0.10504675758702141, 0.16882927697752753, 0.09849970889908653, 0.13532880363204788, 0.14078843647674208, 0.14655251266254535, 0.19413735927833667, 0.20605780995420872, 0.15180432117514073, 0.14210342639876952, 0.16409626320725487, 0.09378022424155667, 0.2570504301618184, 0.12548062845223373], [0.013473922811118106, 0.09055668713464853, 0.05215164995001209, 0.012209366372365867, 0.03232516423468629, 0.03307473913375889, 0.04014510631320938, 0.01883258239456242, 0.037514479124858495, 0.011990272886900893, 0.05837477751136307, 0.04622450428864649, 0.019533106599063165, 0.007880132649123909, 0.01090806548393542, 0.055996162606583494, 0.05790744472535388, 0.07616776327091841, 0.006466339409892117, 0.037752920160851175, 0.061770672909915454, 0.028326252302635583, 0.0714357607367058, 0.025727295189074455, 0.04593394629116501, 0.036120340828934026, 0.03353379817018586, 0.02956135074547943, 0.07452122581702086, 0.006962617391705394, 0.04803712960452803, 0.04395548592231447, 0.01405480802209387, 0.05257201771582327, 0.019561465258800217, 0.027661058157982848, 0.02008685601815101, 0.022406518541937395, 0.02826610099404089, 0.011679045837222329, 0.017930381713555228, 0.11101030008566957, 0.03242364866779216, 0.07988279174652793, 0.019392412636549245, 0.1215578982185933, 0.045367305527531335, 0.013956396367340801, 0.05661900358034238, 0.017053963721639687, 0.01871655263277071, 0.024918204834384304, 0.060836497634168596, 0.05491823859272465, 0.02895902177589315, 0.04979066655880982, 0.03366634287240525, 0.0833835454297162, 0.008483978472800266, 0.052269937755960616, 0.010786537126067185, 0.03191876416695455, 0.02361200194084837, 0.029923030430631294, 0.040730121695706924, 0.019727365429242773, 0.020649141571935148, 0.0574067373189234, 0.04414308170277265, 0.012026534701186803, 0.03561311784470755, 0.020967148499743595, 0.02942260264629318, 0.10125585576339115, 0.013695375847389862, 0.017342744395136833, 0.043201165108550946, 0.028346201232183846, 0.04117859339702033, 0.024615161518956867, 0.024477087577143987, 0.07930165276892724, 0.0537118990905583, 0.0409282933199598, 0.03240477226133789, 0.032926447494255925, 0.005454558469805746, 0.0760378270980812, 0.009273549864789652, 0.007352630359931819, 0.032268542676202716, 0.05801062527743559, 0.02128139393584382, 0.024019292585792083, 0.05353382961343854, 0.027726217766382524, 0.04401259011619034, 0.08929029016965821, 0.011314239555729494, 0.02689682608169894, 0.013877075623660801, 0.08792140596215764, 0.027573126586033937, 0.10750958470687752, 0.012218735627679816, 0.018819782980567506, 0.06380264068983736, 0.04959437568041106, 0.07935885655423326, 0.08558885209382543, 0.02065679095985909, 0.045153762349077774, 0.02790112713081462, 0.05440589431072435, 0.007120788692601867, 0.05699604141315626, 0.008817925775093178, 0.056458546464601835, 0.03215128142807273, 0.031210266902381857, 0.03818502439366233, 0.059792714328655315, 0.036426798981283946, 0.046751768132972146, 0.01832108655493827, 0.08751577772800961, 0.013452773038748533, 0.017754076153881127, 0.05790510049630558, 0.0009863836291309957, 0.06469195768717798, 0.021953873576656468, 0.04711788921286503, 0.07388279112356325, 0.04076570264935013, 0.02298312993990558, 0.014174166435916579, 0.007484645982678499, 0.0294897923876922, 0.04498207438436728, 0.026085199975979426, 0.015848651734901773, 0.05456970689157325, 0.088605108791061, 0.053266633467207995, 0.13358546330803825, 0.03526924395813577, 0.040169594313709006, 0.04113866106396721, 0.03132711829347236, 0.08646517240953061, 0.028282558477874246, 0.008220011387170564, 0.01141544072813685, 0.07806116489753609, 0.09667301054803595, 0.023622127707987547, 0.05909236440915735, 0.07418835295304176, 0.03344168758861, 0.009062522327557448, 0.022825786971577236, 0.015630715042202464, 0.01956646972816558, 0.00855739555141378, 0.034066321208111705, 0.07659278119042998, 0.0763021350928372, 0.053437524700477246, 0.031207792438386433, 0.028965543099348585, 0.04118195652300793, 0.008659908649391465, 0.07323605969788567, 0.05102783343904922, 0.04294665154790686, 0.007449813401176324, 0.039209548248759205, 0.04034974754998281, 0.026961870776909976, 0.04798572893524843, 0.046478600331371835, 0.0180425752900661, 0.03696263151904268, 0.05390759242037612, 0.061117517836992784, 0.03416641442585857, 0.062071684177123734, 0.016403560819584998, 0.036137156458871986, 0.005000038025525189, 0.07253022458884986, 0.12235646060998402, 0.07189709122382826, 0.07245464235424035, 0.06597444249857819, 0.055355946758701924, 0.05112680433798702, 0.03859716054472712, 0.05122189500158833, 0.03395475582369874, 0.07748130528676896, 0.06358235593765013, 0.038726717504041816, 0.08864630133874955, 0.020255977588315165, 0.032007207102592916, 0.019774931828461347, 0.031112883720667135, 0.04996390202112737, 0.033119781273266966, 0.01171894082348914, 0.10355293976082917, 0.003474490034521648, 0.03236809197152334, 0.01762578707008112, 0.045738877323005474, 0.040376495509859056, 0.04660836413442608, 0.09436859508916255, 0.0445921854266236, 0.06961329885187649, 0.016486242774032777, 0.045757428142091924, 0.02525365941466824, 0.031460940447305484, 0.039699266123915875, 0.01817444391969231, 0.018203344586635792, 0.028366657694981947, 0.030297639764725205, 0.0408443377443379, 0.011443186517534478, 0.025610474441500924, 0.012229382334607504, 0.06268573429195151, 0.03478135320267851, 0.04581857344976837, 0.033637350274910854, 0.07873254137173777, 0.06283090029272341, 0.04061581754696466, 0.020921635216162093, 0.022015265947688493, 0.016379632063270096, 0.0342421077432171, 0.06402064633044986, 0.06965459865187446, 0.03322798736213196, 0.11751280076080754, 0.026714127518296726, 0.08101977347846955, 0.025865177608906262, 0.04609023205815785, 0.06057286762722558, 0.08782554538019242, 0.05106624125713303, 0.06003705807210458, 0.03333522434977274, 0.028000212942941055, 0.04317709462597005, 0.028051695966672514, 0.029418184234189893, 0.025345662743934703, 0.032284929296903075, 0.024053067487153797, 0.014453288655908359, 0.018917589425860394, 0.10038297518246597, 0.007578672741674969, 0.04355380687141611, 0.012837091156642043, 0.006534843949691183, 0.03104568057272944, 0.028685484336869373, 0.06674223113805056, 0.0412337287449308, 0.037541947207383575, 0.0327256711710605, 0.10595290936649808, 0.01923414461705233, 0.06812275222112095, 0.009723235815463048, 0.04290358591524344, 0.09782539830813486, 0.0829480704100382, 0.03781039973780994, 0.07615055693613906, 0.0715562280627989, 0.006849370923103585, 0.05505961245827137, 0.07111732096922013, 0.028247050302583846, 0.09195668983363336, 0.021533752874200864, 0.029293580033305674, 0.030086078838775718, 0.025198801773630326, 0.056337596503116434, 0.04335728999707968, 0.02840826584536943, 0.06094338222136421, 0.008987146936687491, 0.043267845401480313, 0.03548037779006747, 0.018885526731009447, 0.03466708352789283, 0.04593338704698029, 0.06194940888352933, 0.01652874724729167, 0.062067685198158994, 0.007209399688778626, 0.041387677943754586, 0.046051965966340036, 0.04048040384546884, 0.11844158277756746, 0.05063687195821155, 0.040193013621554266, 0.01064278168468586, 0.028854527383021293, 0.06866806126650303, 0.1054886217799879, 0.02463062883414809, 0.039627326637386315, 0.0432085310439429, 0.03840878718502579, 0.04696953628632811, 0.07929139485162112, 0.06286768783484736, 0.024376687924227407, 0.02699861618419809, 0.05978481979259561, 0.048943507379942366, 0.04089997871027839, 0.07586851400593597, 0.030788903222269112, 0.022906825667427435, 0.024268003030409737, 0.04687532662383972, 0.057680157929538727, 0.0801294107711123, 0.03803955578816034, 0.031691607606086525, 0.029879079966415322, 0.005680636283115394, 0.08521023611988753, 0.10205731396713566, 0.026731341513955308, 0.022786343019575845, 0.0793190429648084, 0.0404527633931608, 0.04209194257254562, 0.09609142723943918, 0.13078636189381923, 0.13849921254140718, 0.11060340014556724, 0.1649058649256345, 0.15393801394008821, 0.1475952349362835, 0.12071371529131167, 0.09821241060572286, 0.10453689542989578, 0.11879434328406088, 0.1641773765966777, 0.11976660845140297, 0.07840127729239964, 0.11033161513267026, 0.19009921789890338, 0.18575220519015867, 0.16904764267946445, 0.1427860413828204, 0.1395057601433608, 0.15442944402175565, 0.10381034530338742, 0.20483669644642263, 0.21249961348310595, 0.13350848679340657, 0.1859338293152471, 0.12840577431263464, 0.1479512666382136, 0.13374041225160324, 0.09632075565957254, 0.09815603419537507, 0.07108338327417452, 0.08760194729773269, 0.13301140298285793, 0.10149531952676275, 0.12011576834465228, 0.16546512443211772, 0.11162955193750321, 0.13084726588379952, 0.15717830538990038, 0.10395051641089302, 0.26086853576763985, 0.09144167956565658, 0.1892750911534794, 0.16844958848049565, 0.1948811387222621, 0.12545689504833954, 0.07271486710035995, 0.09995860843769006, 0.08338106330484153, 0.10766202854293008, 0.11983960896970765, 0.11278287432486973, 0.10421006699963924, 0.11353948574152686, 0.1465443461652725, 0.1885779204988672, 0.12129071739412124, 0.06460594133503976, 0.1839261886573607, 0.13504496805610197, 0.13086320051262457, 0.16420926117608625, 0.23593369150354018, 0.18928776224774702, 0.08296296315928621, 0.09408141936986678, 0.16427978723039552, 0.12088576331734659, 0.13639587218001967, 0.12255146829110962, 0.2197448134181961, 0.10271519197211151, 0.22074169299054533, 0.09176378889429955, 0.15974257021181046, 0.11198591305724076, 0.17434895579372683, 0.20291179328435854, 0.1517632435406408, 0.1349812448625603, 0.22607610110313664, 0.11854785449442365, 0.14770541370155352, 0.2764599265590791, 0.1283507538779128, 0.08866986620330042, 0.1673322185994156, 0.09446666966522894, 0.08489548123531765, 0.11828497908408604, 0.12610327407357194, 0.14519673621942922, 0.09678402434914343, 0.2227984092408611, 0.19691148622622415, 0.1464097904822519, 0.16413603849228353, 0.16865318400725243, 0.10583728371608643, 0.1253870354905244, 0.1652030151097044, 0.1590900778049423, 0.3238295024681476, 0.1476326047052299, 0.10701224808731388, 0.13055101968348026, 0.15120317198095784, 0.20072366231151167, 0.10092934142918357, 0.11082667647109878, 0.18601083647339575, 0.1431921139479645, 0.2103298073334079, 0.12862571815569557, 0.17182838862701771, 0.11366245051425312, 0.22026098813981781, 0.13070904830050084, 0.13209914548262475, 0.11085086952774756, 0.10719264647172344, 0.15829071102123107, 0.13551726126142088, 0.10119684401058382, 0.17120080939944715, 0.13941876319867952, 0.2126740823469816, 0.1382897334593919, 0.08373858887822398, 0.09881286265989465, 0.14428959618653023, 0.1589638265150209, 0.16861656500447184, 0.12056406001530348, 0.0978216827817021, 0.1391048969761018, 0.14614043396807488, 0.21263675854331066, 0.2742945024323079, 0.1406397694541562, 0.16612192225312034, 0.1202865293429744, 0.18098148457225294, 0.13742465165353593, 0.2690564528588326, 0.15850817273941734, 0.15660487325681796, 0.07493494393964929, 0.08050105534493923, 0.1558718803308664, 0.21810926166513275, 0.22489735225756324, 0.14713490802434184, 0.2005266704626622, 0.19729957104690615, 0.1621199402237131, 0.13226486562240508, 0.30555294285858836, 0.07801086356442782, 0.1082036373836379, 0.10906375493974456, 0.08194359890635937, 0.16556252485081074, 0.11549870964259872, 0.1914316746256044, 0.1980046783724139, 0.17553928788871537, 0.14524234909444086, 0.20363976067352682, 0.11133808612583146, 0.14775235956955343, 0.06160480338298987, 0.24936333539024477, 0.21772502260583065, 0.14800011240426572], [0.04523434330739322, 0.036154431741564505, 0.06773560968858582, 0.0213321644978057, 0.03232782255978354, 0.01258825047707726, 0.018395144274578463, 0.060517107917656826, 0.04673915832573849, 0.08793889574946896, 0.06718146764943678, 0.060972911080405603, 0.06436496071757809, 0.06263740563524828, 0.02785304936790659, 0.04945706974174227, 0.007417089955490684, 0.007440562889490638, 0.00533785455064067, 0.05147643537530976, 0.03828685663099732, 0.06378291009534752, 0.01832701990591182, 0.02261247361950096, 0.051875119022424185, 0.03228070815244029, 0.030805299419068524, 0.051218838310770454, 0.02129857345754581, 0.03554139286279678, 0.007072957993049416, 0.03570129456479223, 0.07434169311196574, 0.038226373989375374, 0.0518101356142471, 0.05083711201985998, 0.03195944726617346, 0.07834398923742195, 0.03959618133282469, 0.044199975222469344, 0.016438724255309473, 0.014324112825335996, 0.04172920760127806, 0.051446121276145985, 0.014795568121987727, 0.013655952005196485, 0.018953342749286565, 0.042318237284498836, 0.04645510058429453, 0.009489512923474034, 0.03709865042999868, 0.028027709753763293, 0.07466225494300166, 0.016696091493471496, 0.06293858927223953, 0.05524738826939175, 0.07494236733163558, 0.04365956913980265, 0.020971248985358307, 0.060752994050422025, 0.0649474097055293, 0.04362896392722765, 0.029249256101226615, 0.09734336812529834, 0.03953174950795309, 0.04564546056151871, 0.022023503308094317, 0.048176006023441596, 0.04878165215374001, 0.023893813129454374, 0.05205999136031155, 0.1286440889441198, 0.03888283473169131, 0.03604953132209278, 0.03387229794996881, 0.023451866582036022, 0.07166081438622168, 0.11320444484872204, 0.06014017733715235, 0.05023870925088564, 0.07492965793297177, 0.013149448186008921, 0.024990194116628943, 0.03682914835911605, 0.10092155797587288, 0.024396253809813532, 0.045363406139996745, 0.0572293573209355, 0.031332685837462064, 0.08151813665585173, 0.033746012186090794, 0.0793946558429349, 0.09135570917879382, 0.0959054593958201, 0.033445678906695496, 0.021336282220398708, 0.04617239498803693, 0.06011415333036454, 0.11944329636471888, 0.04052336988670211, 0.025125818492303935, 0.03820082878754024, 0.02818858055698295, 0.009029426371618625, 0.06279868629550742, 0.044001079645128026, 0.027060933606398684, 0.03475385447663646, 0.056330165450250914, 0.004787850822697604, 0.009379167534080485, 0.038576824740777095, 0.030825851642857158, 0.029663857140187776, 0.053348624027304115, 0.019384085260812315, 0.08312492946823759, 0.05272773274731252, 0.0749155082890103, 0.07537069475098003, 0.039428580447190234, 0.051908321273062503, 0.05513572712398826, 0.04090068351116873, 0.011782082747818242, 0.03578409334764846, 0.06350512661400341, 0.06703035680637245, 0.01634978144730051, 0.06424425207378884, 0.07548031427206532, 0.02169652740591236, 0.013285494867652176, 0.043253274409160505, 0.037698413005038615, 0.02228782279416919, 0.04958372705826356, 0.05516261297969088, 0.04243170639740364, 0.05657209984717831, 0.053163406949850826, 0.030399406884586623, 0.012712286815287606, 0.03174016800438685, 0.02918120259569297, 0.03569724579011241, 0.017928008756209767, 0.04340820803096698, 0.04831304383133689, 0.05112436817838781, 0.054312753340890335, 0.031400909797558864, 0.08514575449930084, 0.03165746498252115, 0.033984407256808014, 0.008952495822262381, 0.00914290123018286, 0.02047378979172678, 0.05501569263757237, 0.05641592133249487, 0.04463355800497436, 0.04612894631141136, 0.010529108600871218, 0.016044834403381232, 0.009435063224255798, 0.06327885488468794, 0.021465611268555927, 0.013341263195710077, 0.027705433800996795, 0.02546575660216472, 0.11647284406447604, 0.06358422519218537, 0.0487041738515179, 0.023231143244512142, 0.021099204820911252, 0.048947406767476956, 0.10159833536994073, 0.03122529563223643, 0.03858856886865632, 0.03612690620244511, 0.008599590716673242, 0.0634797269688739, 0.02213052962155592, 0.040683225623422095, 0.02984154931900482, 0.046213365370227445, 0.036329149584015535, 0.015044033418469613, 0.0683085898297929, 0.03436672343542019, 0.05616949382989157, 0.03814945876177761, 0.05520626466961638, 0.036078922285307805, 0.013184532140111251, 0.03913880385939152, 0.07286939469556655, 0.0814652995717141, 0.016264667163693135, 0.04034636527179711, 0.017066253687164957, 0.03351653054837258, 0.03675960289734987, 0.01100441731978208, 0.08703867349052623, 0.034883989832333984, 0.03718680033700601, 0.0885218503554502, 0.07161649619980205, 0.05967226998519994, 0.04577413268928086, 0.027047722420144468, 0.03439250612451184, 0.0187066528615692, 0.015062400376454238, 0.004478516010192013, 0.06227968470944513, 0.008243727554086476, 0.035344722770875504, 0.016622688779006564, 0.03133877815167991, 0.06292336710518406, 0.00535400320527955, 0.042579354523050214, 0.07012237959931936, 0.022999457188791806, 0.016279376051839323, 0.007516672767157997, 0.03202893527134532, 0.019177992287422382, 0.06045405505104892, 0.04459670151493723, 0.10397926002981202, 0.03016846393415284, 0.06250978304794239, 0.05131296370358718, 0.033470615068630825, 0.04154426248503789, 0.03284702332870614, 0.048356718503900116, 0.02591149528480826, 0.018743436573253527, 0.053352967745834784, 0.04185860751256828, 0.012026511718549076, 0.018286852000821984, 0.00909578682283961, 0.07321472414919446, 0.07877479878164108, 0.022960059202065872, 0.04597865518242602, 0.0392779867134748, 0.04255129272238382, 0.04224357818583808, 0.028554201764505238, 0.053334302013559695, 0.04262358843979817, 0.031626310101860476, 0.05314176113555028, 0.10613556771028428, 0.0340448439331545, 0.08488150779157878, 0.05596423206189948, 0.05101292919848235, 0.007112080188122608, 0.025916718089232044, 0.11108292522089136, 0.04069720289760059, 0.061725251556884866, 0.00928322651288322, 0.03153298718614444, 0.022465721816725792, 0.08467826466526716, 0.07200247427869229, 0.05807475066713749, 0.016812362572959354, 0.01959277527226556, 0.02976350794215837, 0.03268899471168557, 0.07111490013137942, 0.09895579168392767, 0.010592403742785176, 0.041068510392740856, 0.03218366013419244, 0.006482083953150939, 0.016313382694798133, 0.06699811216563949, 0.052319760284116196, 0.027137249370195696, 0.027420435686625784, 0.004843813545566293, 0.026857544923381462, 0.042504756711423404, 0.0379181346826015, 0.05272524296155861, 0.07254242836948364, 0.007173195809891989, 0.03009280126031128, 0.10361698471129903, 0.02681165434149725, 0.019482336037101287, 0.019735953274873957, 0.017137406018352317, 0.029996578701801842, 0.019227177047381, 0.01359449930474042, 0.044159996924140764, 0.03535583487621719, 0.011395812597906878, 0.03384689830483929, 0.04800800677208651, 0.030241874309497017, 0.04216479370370508, 0.03456818157686822, 0.012870546216295372, 0.04734660093221934, 0.02120812145632602, 0.018843085460004308, 0.056556935136717175, 0.026734963194617344, 0.05705353631187351, 0.05838804998465123, 0.014574413860006439, 0.019848775043482744, 0.035008471459150314, 0.013982213530389052, 0.020776551569842046, 0.04199482177594497, 0.016581885020939574, 0.0034452182937398435, 0.0938015980946441, 0.02626026447321619, 0.05264948452672651, 0.034497283969915686, 0.05450218007148755, 0.030086320156471866, 0.007144481398075098, 0.031678988222753814, 0.03424026147131959, 0.02005462861439634, 0.025531343304582184, 0.07478068447521619, 0.02865021173361569, 0.06305502697585091, 0.023525031809244427, 0.004047851065068596, 0.1013394972429641, 0.007928720339306541, 0.025708447510917342, 0.018763563618244185, 0.03866677112396687, 0.046948595272917906, 0.28073276663499497, 0.11605118161007283, 0.2161273768832607, 0.09605433326214553, 0.12311826610276777, 0.2950942185857604, 0.17041112596709884, 0.14787367725324246, 0.11576078066061582, 0.15277929063285553, 0.16306179936134046, 0.14642289058575708, 0.15812594083047685, 0.12401069724752058, 0.17315529887714695, 0.23478169444828267, 0.14751668028052778, 0.15155895853475218, 0.15563842269682115, 0.14188132218776212, 0.10700808056900579, 0.2034329935427635, 0.1587972790002823, 0.14994925458825406, 0.14936793174955154, 0.13259943154069687, 0.14035692979251185, 0.145606363432542, 0.13368490152060986, 0.19805147102282894, 0.14416670036171714, 0.2811088851622997, 0.2579965027830293, 0.16908986944585078, 0.09126218516499766, 0.1661604105104362, 0.11590985370980156, 0.14152984104810223, 0.13429011098079144, 0.10560748032144002, 0.13222387991845608, 0.08161200540921382, 0.12199498968379152, 0.06593138069635437, 0.0929408829899565, 0.10953182700060068, 0.058850518112341245, 0.12069930517745596, 0.21243072685695466, 0.10617712798017649, 0.1755697015793093, 0.12440582241622672, 0.19061274195630706, 0.08590925304639725, 0.22028850601805797, 0.13193854281017858, 0.19425748186486383, 0.10679197482644551, 0.1675222696916711, 0.1357111274715393, 0.1395376906880448, 0.1276815377716576, 0.1179140316502702, 0.17173731609457926, 0.14073127099583227, 0.12535767134038672, 0.14210722619487395, 0.1325796971157674, 0.08372971758006081, 0.07784078438435832, 0.13133241404448787, 0.1834144878892168, 0.23390492214070213, 0.11197234564010175, 0.12633342986866353, 0.10982862478422542, 0.15041859069418523, 0.20692980187314175, 0.17005984401029928, 0.25967585944360305, 0.14535248189443542, 0.1488355159639351, 0.15309357054291234, 0.18161998821362374, 0.1759330877253125, 0.19208576049535506, 0.21494321945694186, 0.1800927919365706, 0.11288960569448049, 0.10877470996591354, 0.1404282066129869, 0.12767673440037236, 0.155182370555497, 0.20489807541091598, 0.13793907969469024, 0.14212745091607495, 0.17809780705119335, 0.15778881617851798, 0.2243201203283764, 0.09658060502260925, 0.08119781997295157, 0.06235800570838394, 0.08790537940278169, 0.1345466585048745, 0.15178921392127392, 0.19670421347743083, 0.08566703136649825, 0.17835879788523723, 0.12560170098778703, 0.14948404003535548, 0.09706127922981979, 0.10199898403258094, 0.12321474721595166, 0.16973096246440567, 0.12611737775225795, 0.08848491725662062, 0.17368716307945792, 0.17977889507047592, 0.1365920519756694, 0.2173292156188719, 0.147113457562462, 0.18772917168755687, 0.1598516458104695, 0.14294246121519996, 0.07143216012346168, 0.10271457910177209, 0.09467696846132317, 0.12933143835154273, 0.10756911739947335, 0.0916880227985882, 0.2264730725437403, 0.08931878864044145, 0.09050398794633728, 0.139177598720116, 0.15549776895392328, 0.15136929048645884, 0.16560881188319576, 0.20663625230231594, 0.17470969127551203, 0.17372483928357402, 0.12243861587898386, 0.12135183588872034, 0.12595163462983985, 0.0796262289006864, 0.2524491375492465, 0.14769183862353527, 0.14925890211616794, 0.08738004993046485, 0.1895338296890259, 0.08608526174700068, 0.12830812874580586, 0.12393886884374004, 0.13817132690981512, 0.09157998141862693, 0.17807333820289184, 0.15834099703258084, 0.16356787704412015, 0.09108070659661487, 0.12936997257413405, 0.1281005648836013, 0.11724524455325258, 0.10516218405457274, 0.17178842948088724, 0.1219068589289823, 0.08090603240435162, 0.19748761498880005, 0.10460626469143938, 0.11737400861156565, 0.06692112799012853, 0.08573578775770242, 0.30848889821960085, 0.13408435508608818, 0.17067184100948996, 0.12009782656546562, 0.046957060544481205, 0.12378409610039766], [0.07952533512105865, 0.021195668697116837, 0.026694326060673883, 0.07691281442079814, 0.03649051068350673, 0.0173402507789433, 0.07050816615622851, 0.01717766585399307, 0.021815692382534186, 0.04764198911406341, 0.0736526046849547, 0.055659083919900085, 0.011518110874139014, 0.022768226955386422, 0.02823938559290142, 0.012287233464209544, 0.010498094488866629, 0.06006313187460746, 0.025111389226250114, 0.08184809072483933, 0.050307565233519966, 0.052712663797841924, 0.036386096729866924, 0.05552327568312326, 0.03169127052739984, 0.008995951202157284, 0.03578740284748135, 0.0557607974136068, 0.07904418593933506, 0.019300935992730722, 0.02286089295070739, 0.0760852019753187, 0.005751172871133614, 0.04183345301557453, 0.059146496181887005, 0.04432548340710421, 0.07574499764990422, 0.024515880354409738, 0.014253495798085727, 0.014206244452526013, 0.042984975096318996, 0.04978334658869332, 0.054242165999547134, 0.027714726447518316, 0.013649512078583002, 0.0418688845820725, 0.017304064615839915, 0.07030889136536468, 0.014683808342763975, 0.015097808002704575, 0.032649441592154965, 0.05248739947414687, 0.05202996454411938, 0.09551158295043054, 0.01817581521707677, 0.03965551867299984, 0.030515553474786784, 0.05186348980773361, 0.042996550684854876, 0.02279695716776675, 0.055581559652402523, 0.075552525719808, 0.039482018910348415, 0.020887203394405304, 0.039014467789280804, 0.02640437327265259, 0.052059815160088965, 0.036095232297215736, 0.014273235011064719, 0.03723242087289691, 0.009087368474161674, 0.04475109887519672, 0.03579355836395295, 0.047148525068957, 0.060044220994196595, 0.036882134830398906, 0.057065510266130014, 0.05923019894849389, 0.030090328711535663, 0.04954327378542193, 0.06696327814772245, 0.040878761905215444, 0.1009716218217246, 0.01977720327915684, 0.06558379894422908, 0.033885892180185166, 0.00964927385681339, 0.035320993197420915, 0.027128807081270124, 0.0362584320077252, 0.1120329738384293, 0.02560774142283105, 0.02451424092625178, 0.02667205588471505, 0.030859526952788718, 0.05886460646926876, 0.059263136898798335, 0.08170769745183569, 0.025832124745413184, 0.03781710300714739, 0.05017866327938053, 0.03993739689429922, 0.01956920083161564, 0.052092538605774605, 0.03924122981486782, 0.01714967874689929, 0.1333642630807815, 0.06505781063629736, 0.07535173407485408, 0.012300931116295679, 0.006636902182963827, 0.033260584403310096, 0.04334114086363585, 0.07691396355268455, 0.03155770692824116, 0.025125814661864313, 0.024218576952754974, 0.01244229444813344, 0.025702200063894835, 0.05089546493705242, 0.010477743363158118, 0.031898991437628865, 0.036486232082449624, 0.008420903581164537, 0.039851104750508265, 0.02982578322952313, 0.017851823227359884, 0.10033226016187861, 0.002004215766059896, 0.0637478998772079, 0.040995747361692696, 0.04853101499799279, 0.05006228686280308, 0.025846308863331235, 0.07301101370924905, 0.015364721654013041, 0.04115074227053312, 0.014235799167034848, 0.018855953821912408, 0.034419759702418125, 0.050792138828265096, 0.012223518889157042, 0.043148515715954766, 0.009245466039095436, 0.03148290610331441, 0.05851589090701553, 0.023773610103695143, 0.022721892042506128, 0.042436843016935934, 0.10937760584056379, 0.04153462892939006, 0.0332731673974664, 0.01923160695080315, 0.06485043829607387, 0.09730188446419855, 0.040130251868357586, 0.04377814805916241, 0.033394186306864984, 0.015502495863925547, 0.05676971222724646, 0.028018501376913443, 0.09483737961178827, 0.029701272874409636, 0.00872117174308627, 0.03023641593303652, 0.02807967924332667, 0.06002950444517117, 0.024164853121844992, 0.02021157896266349, 0.047148352699174036, 0.050072000857682965, 0.02099876877881827, 0.013332265493039404, 0.027122940762989947, 0.014956082694322593, 0.043069761877338734, 0.05359247364404221, 0.028040141445554556, 0.06041775397475689, 0.037120625662106665, 0.005281308643339623, 0.0384074273789602, 0.03429912383698168, 0.015197986447733017, 0.04723824545620911, 0.02968126457304724, 0.028187946619225607, 0.03143776054193657, 0.022353874895000653, 0.033469887285102765, 0.07158261979179037, 0.01022598293099192, 0.017096008542144013, 0.03495581823611452, 0.03951750410300109, 0.05457074111027103, 0.022233671869241425, 0.02137993774076383, 0.01823052155574964, 0.039190518624720075, 0.0302258534957805, 0.04342683162840624, 0.02492157562125114, 0.03209351073770273, 0.04892541621361048, 0.010929108003995592, 0.05230481007827386, 0.06665642162965191, 0.00875711658849351, 0.0500749962614669, 0.022266751545811855, 0.015071522568412607, 0.027718361534719026, 0.025928002564356695, 0.05052952005738213, 0.05763840230722582, 0.014597797736285195, 0.01485122919773623, 0.030690968457248904, 0.04586343555861423, 0.010343629138303861, 0.04242608331203942, 0.05730070308932374, 0.03452386722088822, 0.04377586894758767, 0.053984496156655015, 0.04109565288789811, 0.035582033827179865, 0.046247598009123925, 0.08116496246187918, 0.011284191672119403, 0.0360687562985526, 0.03499720230578415, 0.058299179954995076, 0.03712577760339745, 0.03435767976747405, 0.08391583864126476, 0.021261293703930515, 0.09666184864697919, 0.007758564550444605, 0.04876594352085264, 0.005641438915664631, 0.023451929784289772, 0.018057008386559544, 0.0777893798846391, 0.051498096511368795, 0.04232473754053635, 0.04534403560683132, 0.06068835538181086, 0.0376843246481111, 0.013873187727445077, 0.036802668530013294, 0.05425735369264599, 0.052107178546007604, 0.042330839430853244, 0.0704522340768768, 0.024996433902772206, 0.03707058096845304, 0.0473756050210326, 0.04118314395929056, 0.06610899052071957, 0.13842185298281331, 0.07133702732502453, 0.034672645326223106, 0.07048574276268482, 0.059364455857224045, 0.0681809289380908, 0.04109660283692422, 0.010114958596175477, 0.09050083166408925, 0.033809279557317495, 0.011885459609930555, 0.08569764423995249, 0.04059206499087234, 0.06223684124227974, 0.008082538824378243, 0.01399365313831837, 0.02312830551677654, 0.03568428358243358, 0.026782577474331184, 0.017326991712193818, 0.10383885909592915, 0.055220234282915635, 0.02623664023685119, 0.05271243780190426, 0.01903650159346721, 0.07597913710220207, 0.03204015654421622, 0.059483904286377856, 0.04482501486857091, 0.035823171492666006, 0.05809228641972427, 0.033398870934521964, 0.026958406144272418, 0.00457618982651301, 0.004767111386172473, 0.052762218195224, 0.08934468241228212, 0.08825937331083321, 0.04187766011924513, 0.05703982716846851, 0.008649489853621252, 0.03973017011078135, 0.030370536861160112, 0.020914713611766216, 0.01842808414010271, 0.043907678205399744, 0.03483224825392808, 0.04318566714984275, 0.033124297361580596, 0.08227913009543573, 0.1267452404323605, 0.04974899137572897, 0.08846863022735042, 0.03314024731216412, 0.082083739370348, 0.04479630189316888, 0.06619463148977488, 0.07509266612150016, 0.03791348452890112, 0.018647786665467486, 0.0028489909750679812, 0.06620056867118805, 0.008101442043909864, 0.08912034888541506, 0.06212481620511221, 0.02058586079416977, 0.050506617858885765, 0.03858977545713706, 0.02377731222358923, 0.06142330949284858, 0.032058762904677185, 0.009044544159194395, 0.05535036963861316, 0.008601897598935232, 0.09462931013155369, 0.024795883575514443, 0.0345663697789273, 0.026331466600118626, 0.01756528527626107, 0.03686384065076709, 0.046021985115423325, 0.01585179173778142, 0.03823786147779996, 0.02890994618346374, 0.04424468794416997, 0.07527401445493584, 0.04125957655149602, 0.0561010055694609, 0.028752248899470416, 0.03494849060511878, 0.06482754758889638, 0.15850546078816538, 0.1640225808706976, 0.12903960481766732, 0.23145661238701115, 0.08343851223828332, 0.10232767405649347, 0.19154942233956632, 0.12866817474845918, 0.19575858518721598, 0.129360978701903, 0.13416108645258412, 0.1240912207492417, 0.11918769878966194, 0.12327176714015585, 0.13255933449874002, 0.11474396748047684, 0.12628438491975108, 0.22903428833571174, 0.1271080903168167, 0.20017485224431564, 0.14831051590942568, 0.09788385081675746, 0.11225174556696609, 0.17875953847842832, 0.10035987763154892, 0.07754873634586412, 0.18809490206260837, 0.08435150518292382, 0.22547009491151382, 0.1175194504039903, 0.22053947642205224, 0.09555105946116871, 0.08248578997388964, 0.11102484809535165, 0.09789054642521566, 0.07761120315520995, 0.18325411504314792, 0.21088158982175015, 0.1774302533557338, 0.08718485072735818, 0.06875332685247545, 0.1913557553123082, 0.13330035602613804, 0.07139240016019152, 0.09122771120840505, 0.09509348280487523, 0.1712702782524209, 0.18174070834873185, 0.09807212458502862, 0.15758376508470506, 0.11284198566910722, 0.1384511635067963, 0.14900816153855095, 0.166123362498418, 0.0952079286798835, 0.15153217610091935, 0.06012470236108188, 0.2586432342087069, 0.19832341691419003, 0.11998034698227722, 0.22688463029842224, 0.13542753704372915, 0.2422848055439611, 0.13864277741841732, 0.2244229599713318, 0.10358755161324817, 0.10983196492757528, 0.1526924315840006, 0.1252300947183563, 0.19650541366108004, 0.15677790187539595, 0.10787861692088266, 0.1454379006979927, 0.15477689553893384, 0.16984648852338716, 0.11258649534635967, 0.15112466329047758, 0.14722602652205577, 0.16664182016205403, 0.22979565715837866, 0.1992115426448084, 0.10210221438037773, 0.21866888889381964, 0.12455425195155606, 0.14134703714761043, 0.23183625491876758, 0.14557967292926005, 0.17094095237553122, 0.19897670605249945, 0.14018768564827983, 0.1292555496817635, 0.14346507107538564, 0.11479066053946173, 0.1711084498392959, 0.11788418486474023, 0.11982743583259084, 0.10703497025514803, 0.17991859886434772, 0.24273606197487926, 0.10400877739753454, 0.19341199658811095, 0.08694582363410343, 0.07572284238713403, 0.19058707801084365, 0.10744486559903431, 0.22832219428833456, 0.2072330654388474, 0.07064370243179222, 0.10604264124506906, 0.1684468765292437, 0.14882915743416356, 0.20250391275171312, 0.15817872428845975, 0.10331716854125263, 0.13123456929479876, 0.180167424222154, 0.15014135879614662, 0.08752241204943388, 0.14681082218885422, 0.1486979725380098, 0.11232078541070224, 0.13394612218103102, 0.24584319202169297, 0.208442457801392, 0.19748208383398672, 0.1514327532101062, 0.15206115981263502, 0.13528168922470463, 0.10924373963667501, 0.11571829342433523, 0.08592169431428756, 0.16317692705460135, 0.12726748257034248, 0.14954820755989323, 0.24902480113650524, 0.1710426275648417, 0.12428789850204222, 0.14189331912465636, 0.13550607637772638, 0.15129764594378012, 0.19916577655221188, 0.15437643073739546, 0.11500942460711926, 0.10848800156025157, 0.09699927973410777, 0.18564302233919022, 0.11604937364257152, 0.13051300640067748, 0.12383676464519194, 0.1990606692890006, 0.17079421589451452, 0.11763466236692284, 0.0886171899976269, 0.14540408557701498, 0.2128567636734055, 0.16545202432861253, 0.0637873457444291, 0.17051847020704902, 0.09407984122874276, 0.19988360093726268, 0.1741274338095419, 0.21492429708521213, 0.0814705625957539, 0.10197220159874809, 0.10029007169988849, 0.2081303076157647, 0.13001328724766933, 0.11708009897941545, 0.095962532946179, 0.14777796222798287, 0.1397334874397324, 0.10363573854368541, 0.12132108511943972, 0.06741929198465041, 0.11531196038929686, 0.22800751601255712], [0.017211390959639705, 0.014090936728602937, 0.0008775660464908148, 0.04912374871632746, 0.051344867435193835, 0.0435380905776495, 0.10354287336550413, 0.04503575799566123, 0.07904831515324694, 0.02825730438945034, 0.04980962340449614, 0.04413057148696915, 0.0840532977975184, 0.02675315012193976, 0.09590264019225875, 0.06653480517167239, 0.043438548943208116, 0.037396198979789214, 0.02328592810719725, 0.012691226100639231, 0.06921447347849607, 0.05506097226433697, 0.01512333022190198, 0.059059177480277524, 0.06055186915722105, 0.021435617011100538, 0.015989166624363393, 0.027198620673809803, 0.03021891273918652, 0.0450323872087944, 0.035778125522718314, 0.017327169827636213, 0.040136920663738446, 0.06421462745375692, 0.07068180764514594, 0.006429236335304356, 0.012720975209958853, 0.05380383730235119, 0.015502862628519297, 0.01182401744318345, 0.069273661431526, 0.0654878923969884, 0.00794482781671949, 0.05357170500041497, 0.015036435741480562, 0.07100986181608132, 0.01926203596315557, 0.01904226640509742, 0.020708678094970605, 0.051519895543254195, 0.06847958831537156, 0.029445943430126197, 0.07869638202171172, 0.05658210495546941, 0.0952197800600721, 0.020660828243220047, 0.0557206352541764, 0.030278767188710552, 0.03502937799860393, 0.02180474690131603, 0.08095265651542334, 0.039887785040322817, 0.006805186323265756, 0.04912919943190871, 0.027412650318095283, 0.0386718234738275, 0.045273206947791966, 0.05035500522823103, 0.01030549519665299, 0.06923272169285244, 0.09287447848867986, 0.047673571088741866, 0.021780837297199235, 0.02341502158331775, 0.05840590366372659, 0.05336576524460989, 0.049545736758098494, 0.011657614527540583, 0.0200337718706578, 0.07096163658124786, 0.011231929153924989, 0.029849689003200303, 0.0881008007713864, 0.01429784941607185, 0.026488102852336826, 0.06884397037567631, 0.06106706328629967, 0.025401066222618666, 0.01783047618734981, 0.06102999229164374, 0.05580435334254177, 0.006100819230214843, 0.018252376129009554, 0.01837042644770155, 0.012313543796359051, 0.009403225567732609, 0.02920015178050005, 0.02599337476215536, 0.016639515900263385, 0.035112751347403375, 0.03826958517874441, 0.029273996910741253, 0.03465537004353058, 0.10147633586799908, 0.008855395135469735, 0.031649055252332366, 0.011887048284763531, 0.024312108627430374, 0.009247948163970104, 0.05941540453462832, 0.00239624091209994, 0.08924646227951012, 0.028883554454472278, 0.009601251635279869, 0.0290463519688215, 0.02715474490316645, 0.005818198861238817, 0.01789269784855987, 0.029355784457537438, 0.029509061414207664, 0.04340631579379401, 0.07002812014111588, 0.05724040430880362, 0.04332162094332519, 0.03833217456215813, 0.0279499652359875, 0.06995148070517086, 0.01917787354379412, 0.010125295037493832, 0.020603298870546204, 0.09751645803091027, 0.0820071382387992, 0.04231323089991366, 0.012015808512636972, 0.058948079409498366, 0.06528856397996988, 0.009665082081130916, 0.09752860818538936, 0.041658417246634924, 0.0748347932653081, 0.07933748270114584, 0.019383784571302035, 0.030969263302282463, 0.032949342031873045, 0.01744204662710188, 0.06861409803311672, 0.025480356322781696, 0.02414176131658737, 0.020330268964772264, 0.052165374415175575, 0.024661234046723095, 0.05985953251741106, 0.03045203712498469, 0.05198450871713219, 0.026239218122716394, 0.04650284318373569, 0.046152423075850935, 0.05084833903839031, 0.09480705019086601, 0.08107840218731473, 0.011449790195441775, 0.033921457812069886, 0.040000369321675076, 0.07999661709031752, 0.08152316985351425, 0.04415382225547106, 0.025438644750524434, 0.03450137487943134, 0.06829673078872504, 0.0396362898661004, 0.028280447905642853, 0.009489511008254223, 0.011959803654932448, 0.03204781933867883, 0.030383705912578492, 0.009559691365387653, 0.04239146379874118, 0.022679987033047987, 0.003957744042817203, 0.02556160377759126, 0.13459941131934045, 0.05863378034724344, 0.08288153567381444, 0.03853789215246516, 0.07799266131534692, 0.04473677686145229, 0.05372574612978966, 0.04420232328195726, 0.027409928790744276, 0.04071331755708783, 0.005524393608568297, 0.02843815668095504, 0.006233342865016312, 0.05086907320806096, 0.05389510518721035, 0.018989130546669328, 0.023706535275484768, 0.056053316596174435, 0.03576989773841154, 0.05570226063531253, 0.023885958813010685, 0.08354085392408794, 0.02381667382113876, 0.05964879322076037, 0.043223691923964414, 0.068519294652487, 0.020266790919366385, 0.050762238416580424, 0.03129185143587811, 0.04193203704011056, 0.04797652821927782, 0.08507134437921547, 0.02178052320115028, 0.023593889707098567, 0.012943175181956782, 0.02409817282891562, 0.1145177417164368, 0.01595381166665785, 0.08273656885590285, 0.01992334029637277, 0.05273595670117967, 0.10765471240325321, 0.09371987949576109, 0.05354751194376619, 0.027147189361013235, 0.05096127188974812, 0.04455169384938575, 0.04507926795932074, 0.08680059634629758, 0.02138072872654565, 0.09135106668597268, 0.014089721521633047, 0.024257913652446964, 0.07797645089486915, 0.032498008992162444, 0.013154644177355354, 0.06026167122106399, 0.03632586306682037, 0.005800104822077218, 0.04496028301336112, 0.012496311307674455, 0.0611004110936436, 0.03707985446277646, 0.04717547604213319, 0.019999575620937734, 0.04711261086706673, 0.026939501009520986, 0.09868577633413578, 0.017582064517022624, 0.03291485658396156, 0.03902593229506766, 0.03764651820904786, 0.029515301200350928, 0.028399488392976985, 0.021755814950372425, 0.11574801763579731, 0.010682280220451855, 0.04982004220026636, 0.0381457164222675, 0.03568951979339604, 0.058304714940248005, 0.0557104347934646, 0.06047475474676298, 0.01842996680117663, 0.029265861056985396, 0.06416909501797731, 0.007793605412101194, 0.08304225325944924, 0.04080165898607623, 0.025460091381964665, 0.030102317987550652, 0.03404015164461828, 0.02108666396159078, 0.027732806122531335, 0.01593140934053208, 0.052822578262778065, 0.04191458172675583, 0.01580953815831773, 0.09143910551023099, 0.04445571835423189, 0.133661336656059, 0.021234511270097668, 0.01747194703878655, 0.03173642566487674, 0.1106033388585333, 0.04646220604979223, 0.04733968315826309, 0.02049010171885452, 0.026941017863611062, 0.034057059205107154, 0.023778878873394384, 0.042245941567084486, 0.0159841209777721, 0.04443153678890198, 0.038684291554795164, 0.007063046251724084, 0.02614873739319944, 0.08712468218178519, 0.024194062139177998, 0.012754020412572691, 0.01975442556994817, 0.041092036952895504, 0.08356249590794887, 0.0480189579989641, 0.040340033555102926, 0.04809275907914966, 0.029895338267388365, 0.07610713507259086, 0.03626826091579372, 0.011507402880177384, 0.03785533462500861, 0.04848565493199614, 0.03624643890127059, 0.0470266979367983, 0.009547817002561305, 0.03946762794869081, 0.015876197383829182, 0.014704581774440745, 0.033116287912332246, 0.008403070969507098, 0.024221168245158853, 0.021463169363297282, 0.054218953535441435, 0.0634920763062133, 0.03703833249728045, 0.03263569031391413, 0.03214400742323168, 0.08122698494022892, 0.0713914119067692, 0.0785540045809842, 0.03483658814201913, 0.09404068647493279, 0.041078687870814916, 0.06557164112887075, 0.035069486531879634, 0.024552141211085746, 0.06358337866502904, 0.06141896960475753, 0.009059142922201465, 0.035209956413675705, 0.0237254404102362, 0.04762577486314601, 0.015498399208750457, 0.021518398556978475, 0.05856616925748606, 0.08362189070471833, 0.025181191327470927, 0.033664894966228355, 0.01496612802222972, 0.014639709449012675, 0.034391468075374444, 0.040928741481395504, 0.13617047379093786, 0.09221040283239658, 0.09908942806143915, 0.09941422635869634, 0.20225643570865356, 0.07998268195097485, 0.21651209091707585, 0.16763220330880535, 0.1414341566663596, 0.07166934860569817, 0.11246809645766213, 0.16087690127953408, 0.1857530325651169, 0.15666139522387137, 0.12213291615367898, 0.17810911450895572, 0.08855532073686201, 0.10893681417069129, 0.1417818839751905, 0.12055408555052935, 0.11520398795724877, 0.13664184769074764, 0.1442767412311608, 0.18750867626119047, 0.15982847931163927, 0.19879604719819563, 0.1812012905194875, 0.09344370479905799, 0.10748649481683971, 0.138701674258036, 0.15075695640858144, 0.13861398783422288, 0.10643007489101541, 0.18867711356330305, 0.15810243725295992, 0.21744140153450353, 0.10388777380989445, 0.15112501569092274, 0.1496546937813682, 0.05453887185262096, 0.13350759813141438, 0.20677722780214203, 0.11118211062444795, 0.13492544301815573, 0.17776731672065874, 0.19993567959435526, 0.19992336090053284, 0.1765113308905594, 0.16105019036800633, 0.13314390555024147, 0.19220222118160418, 0.07448354961290475, 0.23459696000622166, 0.14597658308282976, 0.13376978406262013, 0.07741975778293225, 0.10838140808646718, 0.24631691015055104, 0.1728473162098277, 0.11659616123764746, 0.1826692988435107, 0.15751322370863732, 0.07066296954308787, 0.11626611523810895, 0.1430203570353408, 0.15740652298254354, 0.1075472379283559, 0.24919289614885087, 0.12748609342041517, 0.2126799199369646, 0.22885798086081782, 0.14985782965537042, 0.09510892713742872, 0.10615148701735082, 0.08540609415860907, 0.1629331578770953, 0.13292131104296254, 0.10984378566424693, 0.12143474192388597, 0.23842689400959402, 0.18144361945169588, 0.14000656714122142, 0.1416201781361334, 0.11292650048891384, 0.09982161659507022, 0.0970299462337167, 0.25312839706818907, 0.11616352840416855, 0.18525331341210874, 0.17828010533365513, 0.12678319242812935, 0.18182058067571732, 0.15959162024721024, 0.14907882548868656, 0.10927095107974545, 0.1260343261603867, 0.11593076024925518, 0.09952834281589716, 0.15469271779781388, 0.1182695270906533, 0.1250280007239311, 0.16852169267592892, 0.1909431863215662, 0.20939948547992016, 0.1590958387861329, 0.2931783859047198, 0.13769007047578213, 0.21440249927822622, 0.16257015477505424, 0.15900317279081191, 0.17507595791211053, 0.13639524398792174, 0.16809827588017912, 0.16359491994784725, 0.145185244900565, 0.1772509734596937, 0.10836151278307361, 0.21250283105238793, 0.1020914891494378, 0.058352740992221146, 0.10337034270407693, 0.24029271647093758, 0.16147895445746763, 0.10898612725037722, 0.1341223530471325, 0.1948285238036225, 0.19487717038681432, 0.15609933183558528, 0.13297443157963215, 0.1527490914468804, 0.1919920372986986, 0.1603717735457805, 0.08769710307880756, 0.09604076584500652, 0.14740820223044965, 0.17315402717119263, 0.11842932537077897, 0.14270999949545632, 0.15657252902465482, 0.11819078857379577, 0.20717018494202247, 0.06709829348349763, 0.13016160186981002, 0.06775041050728291, 0.13766193972720256, 0.1493948214356938, 0.13875196026938577, 0.18492942675948146, 0.18483892113210695, 0.186953921351702, 0.1508155621347889, 0.2969292443125479, 0.1704499206595844, 0.1400196059576927, 0.14058435065371377, 0.2424865471379411, 0.15145431092429548, 0.12398207620266946, 0.21828006862873034, 0.12660593500420933, 0.124674903138751, 0.11139247836845537, 0.11731373281368326, 0.24361052069692846, 0.18122050400462844, 0.1341010864463545, 0.07868479111141737, 0.12333434886269032, 0.2113324478869477, 0.1649249098714321, 0.1002753628117423, 0.09747611584081765, 0.14170889111776508, 0.08930761907850543, 0.1553337801728518, 0.14066489713807262], [0.04601814318448306, 0.020425233223866072, 0.01194364973343909, 0.0757267187920309, 0.031405743812361074, 0.006769379373684887, 0.06961500722794764, 0.05953318672254682, 0.03574423762338777, 0.05352922925545324, 0.05552613702152045, 0.06080504589443726, 0.018486634324935657, 0.0747740118493957, 0.010924901223681387, 0.028508422265370047, 0.10297035287705161, 0.04180608069403999, 0.025151028530672196, 0.048651934315961216, 0.048021646967578324, 0.040233306015931794, 0.00846054097036681, 0.0773814840302352, 0.0067627536707497654, 0.014825831467826522, 0.06831762200642018, 0.013870792745071796, 0.15021649669976006, 0.010593048214251477, 0.03621039829487282, 0.04141771625126562, 0.04506871509816378, 0.02257306222623635, 0.036870509446147955, 0.03758335042925131, 0.04864240418218317, 0.01812145553318964, 0.020877724971562144, 0.03494228146249249, 0.0494633746453591, 0.018950826150455305, 0.049092040337141485, 0.037081520704011765, 0.03208539978180441, 0.06503917937797886, 0.0343196205193958, 0.1094173964473509, 0.025699850089187105, 0.08062244197654148, 0.05792926673987701, 0.051509082212202975, 0.03779015203397121, 0.02244996147290353, 0.12192178998262652, 0.023799032731462392, 0.02735973470994542, 0.03256068264524783, 0.07355305922007369, 0.025150951921879768, 0.01434339621600004, 0.027161806318608504, 0.020444575028734344, 0.03201336453428432, 0.008417481083362814, 0.06970824778921182, 0.046883140720667384, 0.04681423494231798, 0.038530890108837236, 0.07721126695433933, 0.08548829539288437, 0.09646211420336077, 0.019701257152783296, 0.033659961359995993, 0.026677041201882308, 0.06682900591723381, 0.044199718583014705, 0.007339382305696247, 0.019712754217306935, 0.016209049180390376, 0.08877590809377933, 0.030440224049192284, 0.037014587602067384, 0.012773932952944551, 0.050911231026534116, 0.04918561414665273, 0.014803961572808125, 0.05682797704432761, 0.021596947467074763, 0.10204623633575055, 0.033708232560104905, 0.023727120058010184, 0.030735085545588407, 0.008896705469176655, 0.031186824611898874, 0.004051405713037258, 0.04738227764685308, 0.03663078521288211, 0.029027582814676628, 0.010612345969064102, 0.026995161127659584, 0.04904558476541312, 0.045171681145626696, 0.034024197863595146, 0.07252386605907833, 0.003715755062125203, 0.06635302016811986, 0.032911378544785326, 0.04037342349728269, 0.03609022974307018, 0.06783944524584279, 0.014411530160765736, 0.038320212099220485, 0.034416143767415516, 0.030066892166712114, 0.040745359184520866, 0.009688259113670118, 0.025884189995967095, 0.013317471377611642, 0.06973116913990629, 0.002034459480895631, 0.06022909716252358, 0.06302459030261924, 0.0836900725299793, 0.04786290971922779, 0.03918646601960063, 0.05803581041794631, 0.01394422801827351, 0.026539260288700465, 0.03354097641403637, 0.03988009734800266, 0.02350824107716401, 0.06137596908956767, 0.02115722065941701, 0.034023952715459375, 0.056782708908881874, 0.043571683533129194, 0.058164601289336725, 0.0883168758704297, 0.04616134800016881, 0.14876155783572506, 0.01900314995568366, 0.04755260197505836, 0.031465148185229594, 0.04133357298410228, 0.039618577913291035, 0.011752172760034521, 0.027541060060743364, 0.05581250068761649, 0.03734548778964147, 0.07144106972602106, 0.039811938505379424, 0.019934467723472946, 0.023248728792813998, 0.04143324868393041, 0.0121428661100987, 0.031098216967356783, 0.06849589832727948, 0.0436627637264469, 0.005170013304919966, 0.04340378004276464, 0.007166529887340844, 0.0073637060760971046, 0.08446926821864421, 0.04125661562166868, 0.06563117382146659, 0.03164090790725764, 0.02266661113789005, 0.04136411690964334, 0.042637615509691744, 0.040177527154164935, 0.03804046360235061, 0.05618650481225022, 0.016340243652643218, 0.04308100804806717, 0.020100779666174805, 0.041342065068742925, 0.0149818740019034, 0.03916590805015257, 0.029576119005439744, 0.04485282769066192, 0.04237344158032248, 0.0592714719354145, 0.04807246157959585, 0.027600163744101604, 0.0857884716242552, 0.04471367164965599, 0.08131064174156036, 0.02014817369561042, 0.04840472923411478, 0.042920187040562593, 0.055855367137419606, 0.026626724547015566, 0.017806267808942546, 0.04518046051323895, 0.054766461253166206, 0.04156869685938282, 0.0657515185734918, 0.022576766261350245, 0.048327783363000046, 0.0246368590441923, 0.04618543380450818, 0.0359333272752983, 0.03023264486522925, 0.05590072337297663, 0.022935169005406, 0.02904020794366877, 0.0227141200805143, 0.02942249347876397, 0.11385877586660847, 0.08332598158308575, 0.02718954253190708, 0.023291689088387836, 0.06758030068369643, 0.05123374255133733, 0.04474024723974928, 0.019852320115352352, 0.040990484337652885, 0.04815251776768316, 0.08526576983351862, 0.018541091685033134, 0.09585380974796512, 0.051949333790088856, 0.08220371640016956, 0.07000762728914138, 0.029801682103425268, 0.05963871533411646, 0.042357786573589816, 0.073506687918017, 0.0774937005893838, 0.057001020984664086, 0.008201572608443038, 0.08052617536797639, 0.04500255191458329, 0.04086375807321841, 0.052897313970231244, 0.04145535415098552, 0.05649754800082696, 0.0202903998339729, 0.03527229681851403, 0.02214313368313015, 0.03443940219679668, 0.026541594941649708, 0.014195295140868234, 0.06036228537859936, 0.04191472345302182, 0.030576246790587906, 0.08666240940651587, 0.02602219115942717, 0.009426183307603484, 0.04970568442536939, 0.05642768844301182, 0.07869547037708183, 0.04356503388994644, 0.01504237579572345, 0.01540074693865233, 0.07728191558271646, 0.04913614401894231, 0.012410517121034284, 0.01886642432861751, 0.046179423844742204, 0.017872588040547508, 0.07008600574467452, 0.07441380496827826, 0.05648013865274768, 0.013736590420106247, 0.06727593395137979, 0.03864504103999465, 0.04412723517405891, 0.0542813552273137, 0.05485472607336218, 0.021578057654081814, 0.053637086774312684, 0.053917107232395685, 0.03988582768567628, 0.07176980571520906, 0.027287699462425326, 0.08761035128226204, 0.036830534978259, 0.01541994893247442, 0.03643350991150064, 0.021134755131037488, 0.12604690532410337, 0.06509041533835473, 0.048268871201622876, 0.041895529120078975, 0.009184848374476837, 0.01732683083372972, 0.019718226000306108, 0.08213368064213185, 0.036763360558618466, 0.011129763668342944, 0.02401429003164653, 0.07378503830442507, 0.04720649494218731, 0.031410997260301825, 0.06183702378503739, 0.04849453772147817, 0.04716678860507185, 0.021426040912047032, 0.05980826974395783, 0.031878875883957075, 0.026513255434110764, 0.06744582160946823, 0.007830909105964125, 0.08431852509778354, 0.12046053855409546, 0.03704438459188227, 0.029859002717139742, 0.03983801996876155, 0.02589805618739657, 0.03463221886645883, 0.0665610283613205, 0.03685824820891984, 0.06799809439408203, 0.03124471596111694, 0.05047121310546514, 0.04234496609217698, 0.008834422520932653, 0.048924194303371256, 0.038593613557637706, 0.053075463886583046, 0.06692606925724015, 0.0407408737397242, 0.08316724050429561, 0.04134014218805298, 0.0648320445250119, 0.06620867388142694, 0.021185336086238106, 0.029932727188532873, 0.06921539278400522, 0.08233464848730834, 0.02565440958395841, 0.053127983044232094, 0.013966156327496133, 0.02877345804365412, 0.058692117942677396, 0.03749690123743588, 0.029704691541771737, 0.0224286584829491, 0.0366497727020854, 0.037535971721574184, 0.06665092111835558, 0.013173635496998267, 0.057521788403391845, 0.05503816199639151, 0.016021292521468094, 0.038815909290626165, 0.014472801872949689, 0.022259925702406515, 0.06927982843931645, 0.06210055037011063, 0.1961764401846355, 0.13611248093506984, 0.08994680453812884, 0.12806894077408698, 0.10425629274499032, 0.15634231960340855, 0.18993742012929535, 0.2671442361127946, 0.1410750452909739, 0.1494689174597302, 0.1522056439951543, 0.12845085092609929, 0.09767405763869325, 0.13431137758156947, 0.10406945922201681, 0.17613622359931472, 0.1948028751799176, 0.12102990276029996, 0.2239554471546604, 0.21436652378930202, 0.07751145084658939, 0.19482973422254288, 0.08789402597974386, 0.13803039737526449, 0.09830274003287477, 0.07087754310979959, 0.21982224958558239, 0.057693078002381715, 0.29701703798867046, 0.11650198604911567, 0.18568121948309485, 0.1681080818056099, 0.11259984825887989, 0.18389589754083466, 0.09869362873535964, 0.10651284303035467, 0.09775174661509453, 0.15017258453994028, 0.10496094041774351, 0.12281755360984996, 0.16272317317705, 0.13061705646255325, 0.20775947509513748, 0.236517894832838, 0.10653725059162225, 0.14032708300698188, 0.18610825221384728, 0.19283796690644758, 0.13904719523364498, 0.16789604398992755, 0.13374775137391784, 0.08174771022412085, 0.13104079501523128, 0.15059097579890682, 0.18268213847712164, 0.12274319711591929, 0.2574102616598529, 0.1662302470856136, 0.1437757656939568, 0.06810412096280245, 0.09323813276545656, 0.13771072420622074, 0.1486000052142528, 0.17698659651702453, 0.1179817385010181, 0.18104603514075282, 0.1356803767022587, 0.12518625916732898, 0.17006611060951987, 0.1448837280153267, 0.10461749554040933, 0.22978485531864629, 0.19701090911703725, 0.10407486014188298, 0.14419190465442597, 0.13557082612908658, 0.15413836125404606, 0.05439248394160982, 0.1140288933510742, 0.11913218805866858, 0.17986236801070554, 0.13826311956490242, 0.11285828802013591, 0.1197401630962568, 0.17601605504751208, 0.14938100120953976, 0.1229374004047244, 0.14241281866786942, 0.12227164701588693, 0.2391686969466748, 0.15383161964916414, 0.14108551005201955, 0.16076581853051342, 0.15261687999290807, 0.18014107079755876, 0.23893919232631886, 0.16052503709591207, 0.12116928479724354, 0.11578986901910075, 0.14164349785254848, 0.15299036317775327, 0.10475097103945671, 0.14123408514405453, 0.12330301586658725, 0.12636613416215106, 0.07693392014311207, 0.20808486328009637, 0.19747368751033662, 0.17933620350255122, 0.15298112415738646, 0.24214933055543134, 0.17513577405723835, 0.1896294374619761, 0.17915199000027873, 0.09142990479426039, 0.17197463481176287, 0.1344921283664242, 0.2394890595948504, 0.1395067100923869, 0.18584611224791697, 0.1563980601607792, 0.26350311213924044, 0.10021357015976984, 0.14877079685609187, 0.16514971071193296, 0.08714784868061544, 0.08985583925799978, 0.19750197147650106, 0.0911999635037876, 0.2731940018073205, 0.2730473725786132, 0.1044248244274528, 0.1935412815862125, 0.1059717781120731, 0.09862802096552427, 0.11100986341555273, 0.19972903503765985, 0.24954702795272876, 0.1866985076377469, 0.08872309399227943, 0.27916185738098237, 0.1059683383772931, 0.12390721409070878, 0.1402094119018124, 0.14421776778274967, 0.22553754129236747, 0.1174717001436699, 0.1278190275714282, 0.1725713560177434, 0.13223432935774326, 0.1548573347709833, 0.12719804436088572, 0.1056119159705216, 0.166132417657683, 0.23816898284900576, 0.13686612759146, 0.11741633496938214, 0.10080816164132088, 0.12481003338771483, 0.2666793739603412, 0.2107407522177504, 0.09506697616269512, 0.11322856895745763, 0.1443023898548657, 0.14124735378690306, 0.11019347415816401, 0.12455036788577996, 0.06671330365802973, 0.20235075645389097, 0.15308453070540584, 0.1523309606578081, 0.11125065251103333, 0.20703798880980862, 0.06739754274848007, 0.18230508532254927, 0.17427018663335234], [0.029049031361336672, 0.08836828037014893, 0.03379486944346178, 0.04153534522159927, 0.02167150697430536, 0.012799574873380124, 0.031236241113454587, 0.012862997377411494, 0.027400220541523832, 0.07102582708842332, 0.03290726465263194, 0.029247068920202797, 0.03809827259711681, 0.027408260634289156, 0.04738033944440465, 0.035050441586082025, 0.04227736266329885, 0.03611570982743175, 0.01254454899143668, 0.013365755026649325, 0.0475572444678795, 0.045984737920544805, 0.05906036108612053, 0.09629306158110981, 0.030048465836913358, 0.03146049803152921, 0.056514639422417655, 0.020010480882539865, 0.10720066741229066, 0.040187578227731495, 0.008837349934413308, 0.014855809445913522, 0.01989088881190025, 0.041174529300582026, 0.06859117668242225, 0.07527047512872566, 0.015654268415434467, 0.08041604256798184, 0.06078790850757111, 0.015216818804131641, 0.04122658114459726, 0.021200841705825542, 0.07908877225652819, 0.10338677529005275, 0.028632143549921534, 0.018627291898273172, 0.04142901221770914, 0.0434487838778765, 0.028770546909541856, 0.027660226952585003, 0.02662400685010418, 0.04003229220547984, 0.01627781131725398, 0.043084447782847195, 0.034188527553792925, 0.0212590720489501, 0.04049366482743814, 0.03469325309138625, 0.06478787189529789, 0.029338080165607315, 0.06808126856002115, 0.03192040551033232, 0.03969892521478957, 0.06589778007999544, 0.006435553209045001, 0.07395648878187903, 0.07690211983337518, 0.04682261211376998, 0.06928262466024007, 0.019904228317881786, 0.019567708875383102, 0.08738180427181144, 0.045825000927453084, 0.008784332819613478, 0.014712821050066383, 0.048340048430667776, 0.0359799858603266, 0.011822992800584724, 0.09025032857372876, 0.020130745195333036, 0.016756528169817982, 0.06243554912807961, 0.033643072951705225, 0.033943256843955286, 0.05174591829399428, 0.027105483534415404, 0.0651948407833134, 0.06183258430551618, 0.07250148096993085, 0.03563082979751691, 0.06581939396358306, 0.08188674752149852, 0.04017593752172205, 0.015191831888871328, 0.045439038170321334, 0.07391400920647768, 0.012371435145577116, 0.03780993625461575, 0.00836544743393578, 0.06503604607836855, 0.04337132855829212, 0.08193700288933131, 0.10952844855285461, 0.07498621820442139, 0.08496466663575943, 0.06175147857697261, 0.0047193841084898006, 0.031245418846787467, 0.030759699950595538, 0.042989885719913634, 0.041250100043872674, 0.04233508355795376, 0.04267707669867143, 0.016558722352548953, 0.005202832032791189, 0.013790481832749663, 0.07781161175620172, 0.08330479159110016, 0.036054185306232785, 0.040955815028639576, 0.04381733345648935, 0.09673909329238439, 0.01925995028878172, 0.07932697197482472, 0.055084311132950176, 0.04034435812143549, 0.034274478788457574, 0.06858114093061417, 0.06661891396487914, 0.08364901021723786, 0.030424055763550346, 0.05030123734726541, 0.055827443232579585, 0.05691101714487999, 0.09522246136780708, 0.0642064992608803, 0.020098942970376343, 0.08460577742587175, 0.03729161265636644, 0.036366906227363695, 0.030084154042865963, 0.07711641760843416, 0.016411616234108806, 0.03359611176194684, 0.11113275924036581, 0.024183898067642606, 0.02988855264359905, 0.018227505084547787, 0.0278932306795351, 0.032618958953647845, 0.036631145274206516, 0.0038784232991372026, 0.016176442563113187, 0.03165167335781359, 0.0750182560014148, 0.0765274262296096, 0.06670446300338354, 0.0616576059931709, 0.04501851335648568, 0.05174926226778377, 0.04999237750927287, 0.03631991439408833, 0.042582993440690546, 0.01545191490872493, 0.036318374557360526, 0.045052458712410544, 0.0246942198775228, 0.046953207122222076, 0.08182939817948688, 0.04773191634505507, 0.05027828535305397, 0.07452995155847843, 0.06030823021466213, 0.050155910468029405, 0.033644681736346216, 0.033817411580633734, 0.08457297354095406, 0.015120972586315007, 0.06395316930607924, 0.011720873280278137, 0.03122281159214195, 0.039118257381262324, 0.04184535419147822, 0.02441550368413089, 0.060990366393760334, 0.043871446077020905, 0.029236983372679645, 0.02994768888569407, 0.02685885110329236, 0.01371641740984013, 0.05783669650554658, 0.005621260638544036, 0.020147221831364498, 0.05301127720984721, 0.014047779165388597, 0.03875592077571539, 0.05306151725592152, 0.029349718956396948, 0.05439401228701877, 0.03132125197519218, 0.050705256796772444, 0.050735785400555025, 0.015377809308589467, 0.05647247394306525, 0.06439574979125492, 0.007301592624806349, 0.01949419890860877, 0.02636845140988308, 0.05940349186740576, 0.004289520204052209, 0.017438566672705838, 0.052248115741437486, 0.07045683826530172, 0.01901091425679624, 0.07515519421787993, 0.06368653240403341, 0.03517074420327141, 0.005624325947851064, 0.01725461938598704, 0.006225207490065406, 0.0371358095247659, 0.043588250184491764, 0.0344067438685846, 0.058289328064288826, 0.00809576629000085, 0.033152125505430084, 0.02398760718924384, 0.01729299464533406, 0.027214298663180203, 0.01855574503180481, 0.02053636768382163, 0.024447574039861083, 0.06910450155696563, 0.00446521959665622, 0.04273897660295329, 0.04781016456564108, 0.06300531936088397, 0.040239764137133475, 0.03350031246701556, 0.05731178072070884, 0.022639554827624274, 0.051685722935343945, 0.05299386020088869, 0.02288607426077849, 0.028295781155447328, 0.057299596092273156, 0.015708791850615415, 0.10027436689744074, 0.01806234801939178, 0.06268503332150079, 0.04330305863291987, 0.007491241042096649, 0.028907609615294688, 0.04978693188017896, 0.059856104273949905, 0.04707507638921661, 0.031111926110761783, 0.018288403328868653, 0.015651425271625483, 0.03087305798075132, 0.03402314832313888, 0.034384125122620214, 0.015466709024152689, 0.07428124877474002, 0.09209886809150059, 0.08996630147580179, 0.04710819437018326, 0.0521712847835114, 0.0561808281007313, 0.02449574756375965, 0.0333328188336905, 0.08818402090260098, 0.06422660140801342, 0.01061985171550224, 0.025585702988469315, 0.02621582945838811, 0.0268940087933574, 0.06802526753275626, 0.0221600738023558, 0.08185804220697573, 0.054432473731257265, 0.07815906327337989, 0.03894968356396403, 0.014693145996951049, 0.08759725883963608, 0.02331803293688403, 0.012912150536243235, 0.014979163008261354, 0.02255374914966524, 0.03369662249761243, 0.019922334805972153, 0.07336219607461845, 0.017659282349350474, 0.06270984307892861, 0.03447293003480281, 0.02080554799777606, 0.029519955184490933, 0.014123426517471673, 0.019883304541449875, 0.00671828322435519, 0.03743132411111747, 0.049156843714656374, 0.03861480738006292, 0.035466634172705874, 0.021580273563402797, 0.050806081628487, 0.012661649361102572, 0.059453984722495086, 0.016403907474370736, 0.04593298102038042, 0.03061988698919454, 0.0026694225990438777, 0.014524299260829727, 0.010589503142381869, 0.04854831326332304, 0.0764646606459733, 0.017041982106503942, 0.023035091768589713, 0.0630348022546499, 0.04602732857869518, 0.06633012180006312, 0.03375366923489398, 0.027961640415953535, 0.007498484403420721, 0.04439557662173625, 0.08941530805802153, 0.02645337608672919, 0.08456815484791033, 0.04182971450650404, 0.04165304697028572, 0.06936618953102058, 0.03795816660708478, 0.08682603046538369, 0.04094189904149502, 0.044756913482542, 0.0360212741690057, 0.010698508835517833, 0.030837783462277828, 0.012926624809962609, 0.03107420011093059, 0.009433669901843513, 0.040083348135193514, 0.025544675149684472, 0.02128039993676207, 0.03434161107326227, 0.05310162578919723, 0.04226258482723948, 0.020922171477709087, 0.05867191620411412, 0.05251327409378944, 0.031228390627450524, 0.040851144435545134, 0.1211870656979661, 0.19619888656081694, 0.14178409030841244, 0.1024809146239873, 0.18355762375698936, 0.1319307440351094, 0.11341110472717594, 0.17082321998332778, 0.16543648806550812, 0.1833145287368567, 0.12934427798515366, 0.13596487111381947, 0.21098634468451624, 0.19432134295423187, 0.11493064012498626, 0.1189392794584555, 0.13719514703317998, 0.08748622971677011, 0.0490374374203384, 0.1202965344512655, 0.13156067760240647, 0.10240964546439149, 0.1104952744959343, 0.21815389394760135, 0.18906228724987278, 0.13877209306003588, 0.08311178339945693, 0.1786819644152157, 0.2235741805165045, 0.14075020868932048, 0.12567277862540177, 0.09648083739223019, 0.13107289409925862, 0.08426764153785284, 0.11948226725742703, 0.22559141259520288, 0.2248142163960203, 0.12539527859658967, 0.15113321283171255, 0.11538139859875364, 0.08548281786422576, 0.11374056083901275, 0.11206044575139401, 0.17568829198998792, 0.07608763047403867, 0.11421784127671873, 0.1239398111318869, 0.09219280579277585, 0.13462043277198268, 0.08847445249557497, 0.07052852111237665, 0.16995701968910235, 0.13865849754262355, 0.09071552780486884, 0.09363120481852563, 0.15780354038842265, 0.14359722124232402, 0.19244949904180345, 0.14569231849764624, 0.19090586251789526, 0.1284416885145249, 0.13329813437115762, 0.14545486188463627, 0.19876512788957168, 0.25021156326176663, 0.16882645777396618, 0.1476712308583721, 0.10407304451350244, 0.15059509735193946, 0.10329999284999025, 0.09296316082679457, 0.2658164525224317, 0.10785383397653218, 0.16849538521660914, 0.06918590605979966, 0.1420445755244263, 0.12635046766409952, 0.12817175743440468, 0.264628954952763, 0.1720560393145969, 0.1065789947226163, 0.1170423997926616, 0.061510406028960025, 0.10528370092112212, 0.11811615628821236, 0.19241058177525, 0.248295194319179, 0.22169012516256303, 0.17055251515440403, 0.21699907768878246, 0.19853199201245464, 0.2192495069316318, 0.15681568533182144, 0.10867033048623032, 0.07874557252732978, 0.1525771047078794, 0.18362761354975163, 0.17644411433608304, 0.2167106149417739, 0.19573998457241445, 0.09712558465018388, 0.23624706742984636, 0.21148162052756359, 0.12868709712018891, 0.18612847693504828, 0.1732578933719666, 0.1740667443241804, 0.142388257889017, 0.1621418809818645, 0.09707679251028646, 0.15223464808396756, 0.0953683628129863, 0.12596301103551544, 0.12359619771520938, 0.13946609211064157, 0.12861134634623606, 0.2075872125644838, 0.18804712881965024, 0.07263509436480461, 0.06082293021702959, 0.1828563621928615, 0.21167586978164413, 0.104250255972147, 0.12804929827970843, 0.10878250108010347, 0.1295053403103544, 0.0961995299064344, 0.17500109580014983, 0.10862690096180286, 0.13222404845779942, 0.08663438591024569, 0.13411876775564688, 0.09698830935503207, 0.13552089251818197, 0.19751168547138093, 0.10414524830036587, 0.1739345022266911, 0.14076862544302018, 0.11987967536814752, 0.12122542372033482, 0.11491822183973367, 0.12415027080644524, 0.19820925449171375, 0.14239685339552743, 0.17238743362888215, 0.14857545975715886, 0.16683110516638527, 0.07356396831211544, 0.16007137514891165, 0.14934419834565732, 0.1062532847807292, 0.2122593683100516, 0.13336934990459873, 0.1329308411767406, 0.20132334061687995, 0.21880243334078023, 0.2443858782850927, 0.2132504256141763, 0.22138140705083648, 0.22772466102915428, 0.09689368983550418, 0.10473934182476614, 0.09015552519309906, 0.18822063241274128, 0.09522243838516936, 0.10689154327396425, 0.1606407163724784, 0.10567092772332892, 0.1814464846205327, 0.16183464908071105, 0.1347646871281247, 0.14394405988916276, 0.14907531680599337, 0.1965594381815003, 0.08534815492889575, 0.138266735499905], [0.09621120508640044, 0.02369091474270869, 0.007592739073574664, 0.03541588467816192, 0.05051253205766121, 0.06867902398469948, 0.0755495532986618, 0.021046731628537662, 0.051317445317944216, 0.018755858688945734, 0.05039132162628155, 0.11541238685529079, 0.08311337686233944, 0.053124845914182164, 0.013837484199733985, 0.056023657502185915, 0.04509087802181321, 0.04253394083089886, 0.014587052395537257, 0.08195505192082736, 0.101191328177529, 0.0653827621511394, 0.02236266575393177, 0.018558910890151898, 0.034206228015283426, 0.055295015955644275, 0.022142365679986054, 0.024562115675859877, 0.024116871119927497, 0.014387241343126423, 0.07933422682746764, 0.009892050950457493, 0.08247296566203718, 0.0706068306199966, 0.04216215836124555, 0.03543622814299118, 0.015391955122111306, 0.02068104913398143, 0.043019878062149214, 0.03485379447679847, 0.012026883271192352, 0.041427548989773764, 0.0512641447506124, 0.10085981895005512, 0.04158664629944871, 0.009832998020424238, 0.08224650241074064, 0.06903843413437567, 0.04294685839164642, 0.013319633660777925, 0.047727243208716956, 0.04586824659077872, 0.05476796661593741, 0.020521980552603642, 0.024219410073372628, 0.021907257126464, 0.04495845206322209, 0.004629542583584665, 0.023971197585905754, 0.054041316897998896, 0.04732510067462441, 0.0172403835571341, 0.059567101434954715, 0.054679303430020816, 0.04599511075103956, 0.014660381374039478, 0.01957631587321239, 0.03900214526501875, 0.057754732758527806, 0.030148040030091524, 0.04315137322391233, 0.043273460825965296, 0.06262733157904399, 0.038461237394761656, 0.08433734021720388, 0.03532143369797738, 0.034379976756510236, 0.08463937804223069, 0.08228961783911913, 0.04846967050745603, 0.04464247526841299, 0.024560911002598947, 0.01869097295697899, 0.023962709331704725, 0.021430997500917124, 0.06916222628206015, 0.0535846863602919, 0.0461638339554831, 0.015395684055082742, 0.020877788173815897, 0.028092564842213067, 0.051291674120171424, 0.08130278934033648, 0.00296937762252656, 0.03227261060308064, 0.018899536563924724, 0.015600842401205052, 0.08164622655679142, 0.11249739932076586, 0.005031505087015009, 0.02132659695381599, 0.037459795768823356, 0.04239963412645363, 0.03435335903158111, 0.015166426498082378, 0.07769165770901788, 0.03987661547838681, 0.02525523947101207, 0.038192543546639146, 0.03621797490444395, 0.08615057840342484, 0.07939559813108175, 0.03767183741494533, 0.04457052046012494, 0.11233210052934386, 0.036222728480014114, 0.10270658880472185, 0.021390375688732154, 0.05056386760946724, 0.020527934970995112, 0.017117407293088974, 0.013091529066103601, 0.04268245080546026, 0.06437766245536267, 0.04413254033293455, 0.05548068885541251, 0.006873000426323063, 0.029005113455857483, 0.03938762155631858, 0.0982111465606478, 0.07857429058921915, 0.06248299678366992, 0.09096025459228024, 0.03569010968109773, 0.012279956586538784, 0.03491488232788059, 0.046948595272917906, 0.03145855982908078, 0.0646855378703725, 0.03976284376075191, 0.06355771855000528, 0.013251484394253743, 0.05244622607865641, 0.03217614098121563, 0.03023057068217426, 0.03236173727219144, 0.10060602934249949, 0.024750682472762082, 0.018944772140633677, 0.06062956579450158, 0.02626018594920395, 0.09226535431920521, 0.021912108378244505, 0.07027167481400313, 0.027063503831384644, 0.05611400608153594, 0.06688810960059205, 0.08989479482894944, 0.03825420596366448, 0.07906862414411961, 0.05875321728507838, 0.07038877901410864, 0.07898662975358386, 0.027729473640060717, 0.0708797111386253, 0.07275790591994602, 0.10233377977724999, 0.0687293176569285, 0.04061011402236839, 0.015115157978969718, 0.01139087133079527, 0.023566936818702568, 0.11807130950112497, 0.040934916150065205, 0.047504510805611654, 0.06511238674002309, 0.07390298520124729, 0.06751757340445634, 0.025225538242187713, 0.04269049089822558, 0.05604370219272472, 0.0398580723201796, 0.11038582351419235, 0.038485422790531194, 0.020673844077053572, 0.04363946316222991, 0.007313958720319094, 0.005421854655123166, 0.06160246681482081, 0.03492875234974969, 0.04759195591172865, 0.005036762365395384, 0.015864462832049016, 0.040344178090773286, 0.04438037743731853, 0.07435630240868177, 0.034726823064228224, 0.09627197118055436, 0.061526792649660385, 0.03044561922339903, 0.013967039243828867, 0.09549098284614664, 0.024346008018079787, 0.012807094983966842, 0.014071347860379085, 0.011177956344439618, 0.044903753385428465, 0.04507480549716181, 0.06430537439882755, 0.003986653088847355, 0.023465638927694772, 0.02344085981378392, 0.027647695669363585, 0.012778714299201967, 0.05346734084249024, 0.022371006536207372, 0.018800301364653053, 0.0226944507730584, 0.05671254674633665, 0.01745864775242104, 0.03549739643330536, 0.012814388141005993, 0.04094545368946368, 0.029978730768385916, 0.043883849040515004, 0.045572410247498946, 0.06455142651834796, 0.06639070403311523, 0.06617390881142309, 0.024251495750861305, 0.04063652107311834, 0.0773142981192758, 0.07320300300395297, 0.0654256247705029, 0.04307060457405545, 0.03337912884871325, 0.014236841046611869, 0.031097261272671244, 0.024804467590706005, 0.07645213510841131, 0.0077263634809623324, 0.038236222049642, 0.012779674781937034, 0.051257108233027884, 0.057974688092907595, 0.002829376251376685, 0.007108146326631429, 0.014997696590369508, 0.05715992294191834, 0.10930742452582044, 0.06208723959242625, 0.02730098151181254, 0.05143179160152232, 0.06430423292782038, 0.07053329384014492, 0.021344500428606427, 0.03911028240597056, 0.037031502823435494, 0.04079519703443493, 0.0221638678528008, 0.060878961887811466, 0.05157436056423092, 0.014680420318918844, 0.07595615446447365, 0.027318254879285252, 0.04139214806679276, 0.0325246496997293, 0.03401789679041794, 0.03672232122851476, 0.06750199117607648, 0.040527227139400865, 0.043117994773051435, 0.04309000192029823, 0.054792849151718045, 0.04861670193232356, 0.037906210524060076, 0.05527233975308557, 0.038595069124693834, 0.0736231639260246, 0.03436549003386209, 0.05330178924205323, 0.04164560059566171, 0.06425870432248039, 0.022118842950271025, 0.03924331357402187, 0.061393175424347, 0.024561366824913892, 0.03778567425005379, 0.028591155930752718, 0.0554081135159058, 0.03757621048979702, 0.020214819514583197, 0.12363958893524063, 0.020391176785192183, 0.023538710309132457, 0.023872490987301837, 0.02547818637873617, 0.02204658362203308, 0.05465447068995526, 0.02874838590111223, 0.0013947275851199765, 0.03255859888609379, 0.022791998663676843, 0.050576764699672504, 0.06034752286429848, 0.03013915341016987, 0.054956435736629276, 0.1137731042540362, 0.05269986246862719, 0.016039472745521175, 0.045671143659180215, 0.06224348322458326, 0.04328754152201357, 0.03268408025765131, 0.024768771723874157, 0.005900854002609248, 0.03240564943201119, 0.04528777794011178, 0.020590480304353183, 0.05512628892076112, 0.03321939568606115, 0.0676560361358908, 0.05196223471073374, 0.04964067803455457, 0.028439280914983926, 0.02882839037826465, 0.0147820332635855, 0.045681796111767335, 0.058418310457660313, 0.029170596108381307, 0.02655807157768117, 0.03796912932528123, 0.029694222950286446, 0.07337708116298722, 0.0038039545254451375, 0.028429683748512503, 0.0522507319316989, 0.06603068101309961, 0.07539150935988273, 0.028680644576407732, 0.04734842039103951, 0.02899093125315924, 0.03609823153143929, 0.04674062155367387, 0.08040300375151058, 0.030441758140260657, 0.03694559372360668, 0.00977247515918627, 0.0759961978802758, 0.048546237165048245, 0.03626611203916612, 0.046900029128958146, 0.1969956486455856, 0.12752570782697972, 0.108233078142568, 0.16449888837673973, 0.17380452774945768, 0.14279809960674855, 0.215840645494961, 0.14991691035609092, 0.12409715793065487, 0.11851355673805361, 0.14322156236777384, 0.27110233662589905, 0.2485131463336368, 0.1925064806616114, 0.17696039631001412, 0.11498523155047048, 0.12342452507225737, 0.08827389067699833, 0.20012985223964339, 0.21598045654114217, 0.27366490073261723, 0.1001740476837562, 0.1694013761176217, 0.1155068148528376, 0.11589698343267364, 0.30137555733803784, 0.25611480697989464, 0.13180207190734725, 0.107933085772299, 0.10284537329308449, 0.13552067801356316, 0.15973342312199457, 0.25788980205693557, 0.1057279093431369, 0.13361451336212699, 0.11363516246239025, 0.08947893932101228, 0.09012177135915526, 0.1064317373018111, 0.1573771664932851, 0.06215893010038042, 0.18739584683170243, 0.18895077549161451, 0.24315230818765782, 0.11805725944859367, 0.07761042940640643, 0.14567272196854317, 0.129198583383714, 0.25451987320857666, 0.08759811685811128, 0.15177142535967214, 0.17007018619727704, 0.09871943823752866, 0.0771434681730405, 0.09966923404605159, 0.1446028495387685, 0.15558285067879385, 0.1478766343526302, 0.11136325211414408, 0.17066005857721453, 0.09724697894266537, 0.07103673618046508, 0.15474447469797828, 0.13532989147690036, 0.11118500643680174, 0.1134086992110937, 0.09223592122115436, 0.10235349121954172, 0.14118105653793583, 0.12650724755780351, 0.13853938619215644, 0.06277434002127379, 0.3366636508895505, 0.13395575956711847, 0.10261057500517178, 0.23622596936841167, 0.12063353652915648, 0.31559424114323437, 0.20044941815637773, 0.11016166618754787, 0.10724355301429188, 0.15600484255100452, 0.2208193436625504, 0.1419142333249892, 0.1591860226565792, 0.14195126601524893, 0.09010266512632371, 0.15074109838854882, 0.10569654570351686, 0.1226168079301715, 0.07635294204397548, 0.08334853521157658, 0.207295241134782, 0.09231451418130629, 0.12169014797696184, 0.09645516578588756, 0.11024654106867891, 0.25110883608220086, 0.1573355372754797, 0.13157426800218322, 0.18467830313790232, 0.20561680377971744, 0.23006469191562748, 0.24799933116282188, 0.11878372530543035, 0.10084056716051795, 0.18564918168610145, 0.11712352084296367, 0.18691140347190444, 0.17386762275090142, 0.26777181534036515, 0.15155106782913208, 0.12365081978421058, 0.11593517291569903, 0.1190235721127641, 0.1408038501657786, 0.19263380447462683, 0.052857565498279954, 0.1290514485369767, 0.11686611530040542, 0.12272020681731163, 0.12882749039319255, 0.13920326266557942, 0.0939142819674265, 0.07349003316654314, 0.14711859035155467, 0.14204460616794326, 0.17602245954255905, 0.184340596259121, 0.1786879092575081, 0.18599035128230051, 0.1491713076229057, 0.22712544237654056, 0.19678806946162256, 0.11010601756072814, 0.23345369635330093, 0.16976057942355835, 0.09781653467085093, 0.1997562158372133, 0.15292579728749492, 0.16765809708064602, 0.13725329310663287, 0.12421947918952474, 0.1646688526436206, 0.14788084783621375, 0.14677925936637387, 0.16960766827387197, 0.1931004133075476, 0.11507824228535737, 0.1311190279140588, 0.15327412214490677, 0.15156766129357202, 0.15340837139275768, 0.1968449897943966, 0.10989526677275858, 0.14845021970329747, 0.09802779107685052, 0.15298982691620627, 0.2186367898097923, 0.11481314522003937, 0.1714770453831842, 0.22951310861014554, 0.16572138084278953, 0.11872142703542787, 0.21303420495842734, 0.22000837830766556, 0.17523585578366635, 0.1377472819219674, 0.174257209103915, 0.09917185146121249, 0.14665941257149945, 0.09946461196147627, 0.2239843899564397, 0.16604355145846644, 0.15470391800326688, 0.24206011195576962], [0.07265819957660091, 0.04150734853840644, 0.0033190902960937353, 0.040587468463326656, 0.08243938802831596, 0.02030372784863557, 0.17896288885704933, 0.08446254962754828, 0.04648954006693056, 0.03983755648556737, 0.06299306195409549, 0.046020265248033314, 0.05398867133584234, 0.00526736249148305, 0.021790331041800882, 0.013187598407028184, 0.003748470368126648, 0.09154923064934631, 0.03304876875312578, 0.07760447690323477, 0.01623861634382798, 0.04466744973474453, 0.015495625012854656, 0.004975966106529438, 0.017859604765450763, 0.015090384610718297, 0.027174536784690236, 0.06269799935961924, 0.036935695867624976, 0.040967294856184916, 0.020877479823426377, 0.08775500400412468, 0.05503564539756026, 0.054286036024531054, 0.03295955781434332, 0.022098221778569203, 0.08094494201002583, 0.011469255531987837, 0.020738205038792184, 0.041942815897205186, 0.02327913482252869, 0.023028241027326837, 0.008372341267644398, 0.07532905021141614, 0.07606480871477435, 0.018168738479876233, 0.03734650285614114, 0.08442718700896348, 0.04824421849221953, 0.06152008554988331, 0.06636595173228173, 0.054652118800027724, 0.01587159032257454, 0.035450404600029996, 0.08452834125848548, 0.023263904994593996, 0.023099471882526434, 0.005150181203780155, 0.020858201220811858, 0.0183502113025996, 0.058852042627310565, 0.019771080321422028, 0.029984049333800233, 0.03161515969212257, 0.03813142505204005, 0.016498984731433373, 0.05614746880206851, 0.03776623859941479, 0.030921164471956513, 0.06676143696231228, 0.0784163232592325, 0.04996455319586301, 0.014554387364055843, 0.017537189001638084, 0.045046958201114214, 0.04387379413650882, 0.036084250426821174, 0.10978776165434431, 0.03577800677909005, 0.03155874114693894, 0.019065149451395678, 0.036323553311728665, 0.03621642740683691, 0.06009181803693214, 0.01499017647978279, 0.016445126835136645, 0.006513441847111549, 0.06282320110908439, 0.09659684608660399, 0.0359226250269961, 0.025309647035394466, 0.012427462985919369, 0.04180214300210919, 0.025778684367035187, 0.01819421281857837, 0.04125496853263148, 0.110761781163033, 0.008551041809691778, 0.02843441051100531, 0.09148032870143653, 0.019880607911956408, 0.04817358901604049, 0.006476647122913311, 0.023748963139951233, 0.029279319306595192, 0.041715751266888076, 0.017504406184138312, 0.0341357977219647, 0.0544196647411633, 0.045838767527452404, 0.07825467104633009, 0.03856741718106693, 0.04756546076086741, 0.04819418145944515, 0.03278474038046214, 0.014843329873626993, 0.03635051577622372, 0.04193500946125677, 0.01657839740566429, 0.04940497959333082, 0.026634126871583924, 0.03194607711667496, 0.032911811384462544, 0.012492372658133749, 0.03238392700891822, 0.0203776668246475, 0.029402464109983657, 0.04512362061969696, 0.037095559265224204, 0.09396591629352301, 0.0472392643531484, 0.039333141213583375, 0.0337319812857576, 0.055519705713396116, 0.033259580828129284, 0.046404014011063886, 0.0061641756591627435, 0.11597107945671005, 0.03284724166376456, 0.04256704349010702, 0.010323695530514083, 0.01450486169497092, 0.12270961182131884, 0.028853305472782063, 0.06860723388531516, 0.0076335155397593505, 0.020286682392320326, 0.04897022469630165, 0.03360603643100589, 0.018607963499943578, 0.09521221877225945, 0.052473445182606104, 0.03243997400145858, 0.01675083422132077, 0.028900749297932755, 0.05722091886244955, 0.027083106106147174, 0.016173360974437768, 0.024108854009799903, 0.0363499948364352, 0.035531537141650915, 0.017223364913896207, 0.019823658850885207, 0.009234736977715888, 0.003403195977068296, 0.06374373618933944, 0.06011725215601826, 0.01837820415535281, 0.05080402851284993, 0.044249786259306055, 0.03195861031511619, 0.027517131304428465, 0.06005236833927132, 0.04919310648655219, 0.029170561634424715, 0.03590985817173797, 0.01183322198959368, 0.05197375667311492, 0.05651353625580669, 0.041560626123100526, 0.01895091999622603, 0.02967320724330362, 0.05995683334467392, 0.04253792831854474, 0.037023026060553334, 0.04119264727999126, 0.06712250952278415, 0.02857184668462123, 0.019327743324421106, 0.03552341277921393, 0.036525781371540604, 0.05515341992459952, 0.04120703824164887, 0.0491827106734197, 0.020966663949131485, 0.029787436698473273, 0.03968460703148477, 0.021892331818479206, 0.025585754699404203, 0.03467259170006841, 0.011352354345182258, 0.022564618022090966, 0.012697550156454166, 0.06682083941996098, 0.019234328478154157, 0.04728370128319629, 0.02108497282249793, 0.0884861659799372, 0.03511764281879991, 0.014035184679913425, 0.01670539180087226, 0.03893313606479957, 0.08501213344354784, 0.04408368307556357, 0.05765857340227212, 0.05421097856014968, 0.017004619998436783, 0.010598576496235065, 0.05056941408603903, 0.053119789733881914, 0.10438557008221265, 0.03649677728272734, 0.0148153398937035, 0.07931853734677838, 0.05923279981699683, 0.1533983509627081, 0.06909854905379396, 0.04934020302889328, 0.02134324787485023, 0.05187960829766047, 0.05734397556572672, 0.04710195841447962, 0.03945585317729462, 0.04145219403829786, 0.03721512643800628, 0.039750157344725826, 0.05067995674307308, 0.033868463679907784, 0.023226152181685455, 0.09497606450872076, 0.041450432036072016, 0.009796309112120542, 0.06036018629768684, 0.0629480696103025, 0.09905093214324406, 0.04597051932867016, 0.05277128867624749, 0.027846190965764468, 0.01417043846055505, 0.07817803927126431, 0.04888845247126395, 0.04781492580209048, 0.04408344558830704, 0.1050314894546905, 0.04762040075635718, 0.027506566951952638, 0.04156146881981723, 0.018349782293362003, 0.05596438144904472, 0.028863934942731456, 0.0140994489230516, 0.05343448716185747, 0.03639935005095698, 0.03636447389820411, 0.03638216286837574, 0.04094472590593561, 0.01589357321556177, 0.026740756734544714, 0.07832240087971573, 0.05681820176241379, 0.03166779759339988, 0.059737751350527814, 0.06567818097650044, 0.030552595741145556, 0.018011964331831665, 0.07481613136347263, 0.058489376603956186, 0.017637847209229104, 0.0660127622165507, 0.035792206218766595, 0.03482366806917614, 0.0718715038871573, 0.026480179587979952, 0.01903191464202058, 0.02453842057636188, 0.023161065351638584, 0.01684777881769884, 0.02667622723346276, 0.02846614378804882, 0.035923613280418425, 0.02326353535717053, 0.1035468953271066, 0.044404513037372986, 0.06812557908556155, 0.0450136486981665, 0.02466581525251029, 0.05363913222907051, 0.06410968489944935, 0.08542499354770107, 0.02039873424256521, 0.021938264535199252, 0.049293590409140435, 0.05739442628598022, 0.019029767680612784, 0.056176442247364795, 0.08924610221818571, 0.08767745292354977, 0.01470868130244555, 0.04578824019840649, 0.03674284855444585, 0.03909632428399017, 0.05477239843457938, 0.012172721514117815, 0.07336815623866935, 0.003934883260949245, 0.011447269766170894, 0.061049205776784694, 0.02351168081194403, 0.06094534723688999, 0.08833384471795253, 0.052383322599193746, 0.04261398552766731, 0.029853707134363153, 0.03669373848805985, 0.018004433687535987, 0.0725480744374856, 0.044951028671235814, 0.06567696289670083, 0.022012291611322475, 0.028762949232552803, 0.08039669884789376, 0.052188111904768214, 0.05242662954955332, 0.03392212813900363, 0.010997238118321666, 0.023715080986280116, 0.05660908274172295, 0.08165842267654597, 0.0656346825041598, 0.021079763424612825, 0.026640592653664853, 0.04475736930485695, 0.0201427478778867, 0.07156634808427866, 0.07232383284116946, 0.024478667633487813, 0.024217487192682685, 0.04667782149608097, 0.016008973827645663, 0.06206080189815933, 0.08238806779826842, 0.014156658454017054, 0.18887658753702719, 0.13694066794649248, 0.1409415161657718, 0.13436512631033698, 0.12481161918971809, 0.10023343481964643, 0.2516904500343146, 0.12241137379239644, 0.10178845541010942, 0.16560085989054174, 0.14511430515877663, 0.1402719246764337, 0.0960025687011019, 0.09660473679222407, 0.08742344115049609, 0.16299577790402597, 0.1213874819598371, 0.18141217920328342, 0.1264405059778402, 0.20094248766620315, 0.09355539275753884, 0.10550979645021501, 0.126501425289579, 0.09651009429005847, 0.10903686525360232, 0.08619855082924328, 0.1911687992152668, 0.21019732008778283, 0.16179076756440824, 0.12799251584276078, 0.11150068062688075, 0.22779952314111496, 0.18019932412332107, 0.13670198559280367, 0.1107033133326519, 0.15886910740406285, 0.22303326115492852, 0.05469128121471694, 0.13831133713885663, 0.23067635183613147, 0.15195176245704775, 0.10165973731707181, 0.15561991401257055, 0.22293167789616894, 0.16756513997191386, 0.1236913611571635, 0.08014985765781134, 0.27757216365106646, 0.14339731825936225, 0.310165650181232, 0.18647041261917163, 0.13394163290579475, 0.1529774469353499, 0.1964388099769431, 0.19315488215896393, 0.14216865112464275, 0.1345933592247386, 0.10062060799569854, 0.08641032051415214, 0.0943976144997343, 0.18978565811149536, 0.13776108682636293, 0.07754652235176294, 0.1235247906597872, 0.1662565392231749, 0.09902909863740207, 0.13844990712260047, 0.13913593885879363, 0.1348392274831572, 0.1067279911630096, 0.15734787129106062, 0.17648277113274222, 0.09210976952266309, 0.1981573443739645, 0.11035945476783861, 0.12535397113571245, 0.16028430162658616, 0.14410343682093008, 0.10751815723075021, 0.09978900423213359, 0.09577236694073486, 0.178497459799532, 0.15001788074451108, 0.13651794062987452, 0.08350777424751751, 0.14797198165568615, 0.11694651622805866, 0.2039183102427952, 0.14402240004029968, 0.11086901048979453, 0.0883641588171163, 0.09317156738571583, 0.22742882851631413, 0.26280854618357075, 0.12737093508363734, 0.15252626711322417, 0.16530689663223683, 0.12194448916782295, 0.18279103021467888, 0.1583179531078185, 0.1847047178495315, 0.13234472262763208, 0.14410207318442483, 0.2540970999266832, 0.1413228900562371, 0.13288326711664278, 0.1407170677257161, 0.1452971397027854, 0.13722263426790315, 0.2502353426309363, 0.1517602557977361, 0.10008168812360495, 0.13543050946487536, 0.1926197850656125, 0.16827412370231845, 0.18539631138405493, 0.11215118886602503, 0.2012894182435928, 0.12254580690134918, 0.12562860599568776, 0.17777093265566135, 0.16295356645939812, 0.1260884502722371, 0.13227516184410743, 0.1472117159996302, 0.1334982212152212, 0.14244110263403387, 0.1364345902637128, 0.19170860008847332, 0.1365920519756694, 0.17891804206996195, 0.17248582996187672, 0.20384628265615434, 0.21317925604601062, 0.18263669414145334, 0.10352882331297283, 0.11658056368750912, 0.24652378453362375, 0.09217995083740643, 0.12276010467640816, 0.20798940872473104, 0.11496800989393266, 0.1822613263803144, 0.11597752225615325, 0.22912076434060452, 0.10287577932279918, 0.14507109779984723, 0.10849128041656748, 0.10878430904760476, 0.10385947452197153, 0.22403171886840176, 0.13926580608371766, 0.08169439816547018, 0.08646609171503976, 0.23979408516278192, 0.1384460460394621, 0.23643820636695434, 0.10822033043950798, 0.044223448156469294, 0.11987798231383485, 0.15759551687346351, 0.12084031898167827, 0.1364983441007714, 0.09249469806109706, 0.10862644896992754, 0.13706567817397658, 0.1054147785649665, 0.14807321251400057, 0.2618600680462776, 0.13591761881064984, 0.12133613874715184, 0.1283630266064598, 0.06633394457880529, 0.09852125895239654, 0.1782721380192426, 0.1260609400548762], [0.08462758794907602, 0.04167756561430232, 0.01996935536754468, 0.046224374053699356, 0.012377146331052627, 0.027458194245193756, 0.02609274977247321, 0.04311200779592318, 0.03801968729784412, 0.058208417688165946, 0.11057248083694328, 0.05627321064352028, 0.015619524412848538, 0.04857265187667743, 0.027197714774839343, 0.03952447933355167, 0.03232501484754105, 0.0813455293856321, 0.01909110259505049, 0.026392364844439492, 0.04390609623383611, 0.01665499853721309, 0.03321030222239994, 0.10719878283599693, 0.02653269491518938, 0.023820929439558138, 0.08548464115348556, 0.008297107603040435, 0.028383306700796373, 0.028664123890320622, 0.013531707865636677, 0.024616749236179937, 0.11079129853075552, 0.08284922974604754, 0.061405635844435424, 0.027199116715740775, 0.03466954267012977, 0.005805147595838794, 0.025979481757648533, 0.04190409015263281, 0.008129981691919027, 0.028478073692249677, 0.06840573743947091, 0.13366348170224698, 0.01379000015496727, 0.04975480598307425, 0.07131682558646125, 0.023336066646621596, 0.056200738725883354, 0.057317679597725796, 0.030908905149948214, 0.05961528836539196, 0.012602605049558466, 0.004675383848558751, 0.07762660152248799, 0.014422278374343392, 0.06434523395352787, 0.03764016734015557, 0.10043159112214081, 0.053811819938522194, 0.030810897606575204, 0.02069913072421426, 0.04062936198146593, 0.07592465292902724, 0.03873840417532671, 0.044296705314228614, 0.0060815698347024385, 0.020782609410103292, 0.03588859540139956, 0.007632727426807246, 0.05180368898436428, 0.024529009186212095, 0.0520411187842969, 0.04530414540861403, 0.07007819164784686, 0.009540385949695784, 0.05959494107012307, 0.018834332905469403, 0.025057920119574955, 0.0315121840685606, 0.03686997701504058, 0.04605996775470915, 0.07782314904034138, 0.06926005570999078, 0.014160070418109818, 0.03919279773629481, 0.048977916219061425, 0.07249299271572983, 0.020979995794233777, 0.052168821810834834, 0.02593179086914226, 0.046076572710467924, 0.023357670326086304, 0.0705825609545554, 0.03448914811615983, 0.03054386616924838, 0.03357823126979413, 0.06384400943774851, 0.04595126753913299, 0.08277219194438189, 0.022269536275416616, 0.05965989766522281, 0.02303756240214552, 0.1499789941214746, 0.00873860215858346, 0.06405412820318053, 0.03604840517284409, 0.02601790872793044, 0.06122000507950302, 0.01943569277383147, 0.009450971040003484, 0.06964358230752331, 0.053357135264142874, 0.07455514819030801, 0.017962365884393934, 0.06032627541571856, 0.02008414981255849, 0.044726756431402705, 0.02236670303729273, 0.10630431389736553, 0.08268422972891601, 0.03550494239935952, 0.06751102335270374, 0.020784342684031978, 0.04013271867147377, 0.09144842880026949, 0.002493942499108192, 0.005907452413662067, 0.012487704309845164, 0.060540887286826495, 0.026742583854244124, 0.021309752595580874, 0.08487323404199655, 0.032818563162319125, 0.01975663381838991, 0.04624986562937979, 0.07261680018517279, 0.030952846038065134, 0.050731912826097784, 0.032781427050189625, 0.0345978866361322, 0.010777596879990832, 0.03257854781564205, 0.029981946422448082, 0.06510308643262233, 0.02269237084434398, 0.008363410597667098, 0.09137325259225984, 0.02971835471990128, 0.026737236560532646, 0.17473838892915558, 0.03402877523894272, 0.11172519035397038, 0.053120992491923036, 0.06438138564267466, 0.03458057687948308, 0.04872345245413242, 0.02573513035332003, 0.0435671214795401, 0.07568898130088084, 0.03800678637719924, 0.03268915559014967, 0.019332073636413104, 0.0516272972397987, 0.08133748546242714, 0.055064189833618944, 0.09177377868083217, 0.006249624627432036, 0.04740234148958999, 0.04493922708676227, 0.024830529901890025, 0.03657721651477679, 0.06726088798454694, 0.018246980954802806, 0.025029364192197402, 0.019622449688012564, 0.056821185674878864, 0.028732822824930473, 0.048556820669722174, 0.03670150278917244, 0.03328105044220725, 0.09100864836645704, 0.01884543351949223, 0.01325383724179119, 0.02891305075477689, 0.020209929958406477, 0.013041768782591869, 0.04966113641257248, 0.03854198306198082, 0.012187173762809367, 0.05251125162166934, 0.062268473012673284, 0.02025421750130913, 0.009542338516292794, 0.012794829916299112, 0.023269780888973225, 0.014703982310639995, 0.0065933596605675365, 0.01989773763794332, 0.021757203484735182, 0.00942108020441787, 0.031676406506448984, 0.01416203256080588, 0.05473937238416365, 0.06261769036251692, 0.0787175490310596, 0.024201981573095246, 0.04974627942447701, 0.15107728841324009, 0.01745720559190358, 0.020567993708555738, 0.02972113944950604, 0.013228517078283816, 0.059803857077513976, 0.00786870357490355, 0.02879943225472685, 0.020953424034580108, 0.011555278587395386, 0.07600819481717003, 0.06913764252056999, 0.018462094613501144, 0.038186552739071275, 0.045297407665319984, 0.03465107612071499, 0.03935964402532385, 0.05740010299749913, 0.025451765921447548, 0.0601777884237949, 0.053869747676916664, 0.07682440021345693, 0.01791253569535911, 0.03096633301597209, 0.03165363837333937, 0.039718736248511466, 0.036085675350360336, 0.053347306356074355, 0.046653739522181215, 0.02535786652456849, 0.021736992170072852, 0.0810108179106347, 0.03655704925017011, 0.06639622752704928, 0.03900187330380563, 0.04923147600023978, 0.022205594746816545, 0.041430785711253845, 0.07386695608616838, 0.016905852112798922, 0.11606838794485216, 0.06738284918209238, 0.009344429277153987, 0.04585155353490864, 0.02452061286256198, 0.03245410449322193, 0.010025562838681284, 0.0735589657579699, 0.06323842842492365, 0.015417128771303162, 0.025832988509547808, 0.013884748951832374, 0.029437277060482773, 0.007637909532810051, 0.028881782876147382, 0.022529274555704287, 0.0017820264474721628, 0.04459857076947247, 0.035483622172426794, 0.008435026412048649, 0.03978249391600971, 0.038654360499593525, 0.0908167663240625, 0.03761042397649538, 0.0967555795045149, 0.023068412762856292, 0.0436471929893859, 0.05200671377561746, 0.066406378192046, 0.05483689537692455, 0.01388418779242784, 0.07612801862940674, 0.026832246784901908, 0.05790776265184245, 0.049310651187214165, 0.046010570405351545, 0.014985028368931626, 0.004775793077574382, 0.060827614844686566, 0.06934693008060418, 0.06167821758877366, 0.06422679292999449, 0.03245258380869224, 0.09002254765120246, 0.053034669704615116, 0.04465708456512901, 0.02357163293767841, 0.07105162892971309, 0.042094838384899406, 0.08438789435932714, 0.1475172931508672, 0.009215205566086357, 0.04397433168525177, 0.034561662168632594, 0.03857826115563512, 0.057069283249157096, 0.10478623406661135, 0.010487675693096414, 0.025940384460432876, 0.033319044572811936, 0.051544755096397096, 0.04989319976659552, 0.051216831160408836, 0.08600495274989836, 0.03182995925477195, 0.024466347024445573, 0.05325109337366397, 0.0395415247898669, 0.026947326597667513, 0.05204195765057399, 0.02623335563487584, 0.05210721685040382, 0.037785421441038775, 0.08547255994691964, 0.017669226170607635, 0.06076538935303689, 0.015989069905762952, 0.03126073485961364, 0.08164609632184429, 0.006182858149611181, 0.0389210969930695, 0.054929469441694606, 0.08738410253558429, 0.01442480550688361, 0.01815362548034999, 0.07653900181814548, 0.0395042622732299, 0.08784598460601223, 0.003558813092944723, 0.053721904198849396, 0.013738160900351022, 0.04638916339665171, 0.02308309866836475, 0.02710527286023623, 0.08361953115391155, 0.008793946265453293, 0.02657494657943326, 0.030036750437331297, 0.02902441312588992, 0.048384523665111874, 0.058068844129241286, 0.049286542400237054, 0.03681720887881614, 0.05052271336617489, 0.23408196506000337, 0.14879367224151088, 0.07197451206945604, 0.08743544574826957, 0.10027145576332847, 0.1568320489698841, 0.10464135917925066, 0.12356275031643531, 0.08808543304762534, 0.10857952608456535, 0.16190180434815346, 0.19248021916756708, 0.10222286556757267, 0.15878905121597553, 0.13126518216825303, 0.10256293965804, 0.12281422878825858, 0.15539663002615975, 0.12468881529545593, 0.12898815435267266, 0.0788768723366722, 0.13762996321724308, 0.1238826992771318, 0.1654872030860955, 0.09790320219772478, 0.1412919094605792, 0.19179806383627077, 0.19913853446562446, 0.13222171955050963, 0.1790893240080726, 0.1180196981576662, 0.11313781818194736, 0.2462771195437639, 0.08918856901507224, 0.22094770935514282, 0.10096075869495831, 0.11482741743806871, 0.16391105379068083, 0.1490529317168459, 0.12332175437721515, 0.10535447212356715, 0.14010292568033741, 0.09821237230132665, 0.3404280537318799, 0.1292222095352988, 0.1118899911882416, 0.2789417756420951, 0.11044840523672682, 0.14985203803066285, 0.2066958079775495, 0.09237351061235513, 0.16344349500873398, 0.11009945218721706, 0.13286714862671592, 0.13354872173118976, 0.15767382638108346, 0.1516765989964047, 0.1250242928583776, 0.14598096510575664, 0.18768083153953477, 0.12751456124768143, 0.052107017667543505, 0.07359615932669371, 0.1490849848355978, 0.13124770004182093, 0.16970148340107935, 0.12220984670303522, 0.07577640725479973, 0.1480481767606351, 0.06235448170393225, 0.1487090195258779, 0.11080064480343174, 0.42828090248569367, 0.13094239868223667, 0.22853174997914225, 0.15229740600672462, 0.12134225978966683, 0.15161086865250142, 0.07529760996300368, 0.17148400146153667, 0.13309579522859666, 0.08945619417054039, 0.16014085932364389, 0.12787186465556585, 0.17389091182379954, 0.25151653275374447, 0.1732998290249417, 0.1830515307524512, 0.12899386936858778, 0.20077096057995675, 0.1652225043864981, 0.1272397425266043, 0.1011933506496491, 0.18438772598822273, 0.13045893591498176, 0.12046728012782913, 0.30842828534303174, 0.14991983681196167, 0.11530346447421659, 0.16329832134708283, 0.09566555130145243, 0.20729038413734208, 0.1293234710371302, 0.3721015605955355, 0.1393666998633454, 0.22474975775807138, 0.15717033807548786, 0.12803625180235795, 0.13377955934453395, 0.16738544638839462, 0.1383215873952835, 0.1733769281136413, 0.1908444988751604, 0.2243395942834116, 0.15244159907583268, 0.2066251287056554, 0.09120110497479478, 0.21974098297857472, 0.12438611097393498, 0.24864649159773705, 0.1418783650883744, 0.11664449372479033, 0.23330852269164978, 0.12105260194549639, 0.1277256184708207, 0.18082072868222193, 0.07211196356483045, 0.10927383923122, 0.19087213932746844, 0.16422776986033688, 0.27825091755197895, 0.09360938663444213, 0.13163906371881887, 0.1450667464204373, 0.11517951910894726, 0.15373106294822309, 0.2036569057212722, 0.13211167868106596, 0.1719224029370854, 0.12725876448976417, 0.13297637744295981, 0.11173835940538876, 0.1442398770802444, 0.12806136416451586, 0.23041624966407978, 0.17611241358662807, 0.12430142761478502, 0.19820309514480255, 0.14415347768414405, 0.12046131996377824, 0.30170898944620167, 0.13258496780068646, 0.16014603807801203, 0.16336918448007878, 0.24474828383855282, 0.15369131830671143, 0.10182060045941223, 0.15519882612411054, 0.12188537016270623, 0.22243701492346105, 0.21352399561193683, 0.1088845210089799, 0.07083250480073114, 0.1843915870713611, 0.09146861521707428, 0.10327386925177229, 0.2360167201127737, 0.13797729216035337, 0.16766296939984446, 0.1459305411985805, 0.09155599520571771, 0.22002575318178824, 0.24277792101906193, 0.16809397046604466, 0.10332604750029503, 0.13600676080151913], [0.04900960927648891, 0.016947065727905403, 0.04611523716800636, 0.0799294081967204, 0.04884931686965208, 0.002918948927300892, 0.017724792442975507, 0.03866028235924821, 0.05035384077458613, 0.05197172654011557, 0.021874930131279176, 0.0234117369813424, 0.020127495067314278, 0.08115478881424473, 0.05461007972518283, 0.012448187579490967, 0.06139543921416325, 0.05212298677032513, 0.05181858939449153, 0.05733323118258869, 0.05272822687402368, 0.018037358231301752, 0.07376384831243947, 0.0629776903998948, 0.08844697292173102, 0.019276461398769772, 0.04890586181934323, 0.06160031027731396, 0.014212915163126685, 0.038508217736718156, 0.01498005550069314, 0.03724437567495531, 0.016073731239885092, 0.04689907534949241, 0.024960456498628183, 0.03964144180739119, 0.004188791133328191, 0.041930960686576944, 0.042436532751326604, 0.04628121394724135, 0.044329896073548064, 0.025093663866902073, 0.05369200378716473, 0.014252270057406879, 0.0028274232059747224, 0.020867673897995584, 0.04449786851182581, 0.0027159399366111408, 0.05603325658387715, 0.02116215618086919, 0.06418454701141005, 0.03505884174017176, 0.05231949598378232, 0.02718768093825108, 0.06607701401076009, 0.028393315639527097, 0.014194473511569444, 0.05473899700108075, 0.05289357929160038, 0.05859927191669422, 0.040351854291774576, 0.0634336774237454, 0.0350376057829107, 0.03538153329563718, 0.06957352356684786, 0.02162262481907683, 0.0637796848651863, 0.06626340320273753, 0.020573566998204878, 0.051613657044306885, 0.021390274182082187, 0.024161696839596958, 0.04831704281030163, 0.05046857776300562, 0.035147661974112836, 0.08294310616028887, 0.02554452576253924, 0.07501663189501533, 0.053071541516410733, 0.038307234569783175, 0.037396505414958925, 0.011914389962781102, 0.06208707105308291, 0.03240703222071452, 0.032815498810622006, 0.016322594902087605, 0.07323733906471923, 0.03593868606032864, 0.08359771296982804, 0.009316906610864305, 0.019140331405064753, 0.04399849409838358, 0.05381195783434857, 0.044402682087233955, 0.04056504123934335, 0.01444464814173238, 0.009001787834530397, 0.03352641691303542, 0.05842419401291878, 0.07332689474306761, 0.04874244377377534, 0.05153161285805607, 0.025179492527498834, 0.0033765267806067584, 0.07243937422190944, 0.06410852427624407, 0.0246971903834492, 0.04607928466171988, 0.07119016826993997, 0.03191149590777294, 0.031736486951910683, 0.009139102391688334, 0.08249685228351625, 0.01572554619351943, 0.10426203074354319, 0.02438338736312524, 0.022428233304151127, 0.05036717453490823, 0.03152117411035203, 0.045548607895691554, 0.04059939262186808, 0.07088066874853066, 0.09890394285321237, 0.07894834834000758, 0.0542645319364965, 0.031541515659961494, 0.0074403459908470755, 0.08919508076242863, 0.12952942611469379, 0.035427536875490225, 0.042571961774580905, 0.04732765557785188, 0.032875878030374166, 0.021050598457335465, 0.07919528912152014, 0.0582401950152651, 0.02446508297937051, 0.027888147686157497, 0.03238806005326971, 0.017748200259501898, 0.007017116886638706, 0.03350968555276913, 0.015551469949704987, 0.022237712983042005, 0.0276832957752049, 0.09607831947505475, 0.044259921602544286, 0.00555282408904825, 0.042881078252028075, 0.0356063264752588, 0.013629036463586795, 0.021989038927600752, 0.05136789986863733, 0.04729016706527722, 0.050173170428963444, 0.0448409226843186, 0.046962461464347384, 0.08125393591340511, 0.05330917816008291, 0.06139223313620014, 0.05132207248900687, 0.027163778995013526, 0.06294740311380836, 0.07846175993402159, 0.014462792934218963, 0.011302146857844727, 0.05225819745852102, 0.01644688500692287, 0.024100831154012875, 0.03467975845260005, 0.0605279672139835, 0.028313443312541615, 0.024625333251371503, 0.05819213448933536, 0.05380713914130485, 0.04253265380318608, 0.07556291387206124, 0.044322265837822235, 0.021967193930439895, 0.07183437926634666, 0.0452335887107878, 0.03276065457612276, 0.0049603685563910874, 0.030029474517270446, 0.031678555383076595, 0.028243932324732025, 0.06131304262746727, 0.01114422549313355, 0.02273154091991244, 0.06232653098601488, 0.01691753878408382, 0.04057576647028327, 0.09201565562116523, 0.044984954874962575, 0.07837447953680832, 0.09514153950036534, 0.03978750796147412, 0.01789332221021816, 0.09311327575555733, 0.041388195053103476, 0.037394808530206644, 0.054442068982508876, 0.010610357013290689, 0.03810330196433971, 0.046942665752383976, 0.07815672670521083, 0.017958453090320674, 0.09592133273761119, 0.04369563655927778, 0.06533342608881575, 0.019055611656738386, 0.021481442475511182, 0.04005364690636916, 0.030784429268791314, 0.01794355842585285, 0.0537740747864929, 0.02418096012045299, 0.010116104855232183, 0.04815834386634731, 0.03818840667184803, 0.03145284864360527, 0.056985017407925866, 0.02856413984010297, 0.012482308178028513, 0.04632946216471253, 0.03210100690804182, 0.07549216565225395, 0.07739264593129197, 0.010191132633706496, 0.04328492533175215, 0.03907514578332344, 0.06826646265483673, 0.0350273325438461, 0.061246902426524516, 0.049104868479433565, 0.02768685042317356, 0.03885717461666754, 0.11719698867490215, 0.02918403903623262, 0.05180742749343476, 0.07920974520065131, 0.05504678431597929, 0.11217113779557329, 0.01672751067446605, 0.06849220578348444, 0.09976051342222961, 0.0272488932786209, 0.0175421321839695, 0.040043944402808146, 0.03090389685014323, 0.021085041770411116, 0.04689377785149602, 0.033747241757209265, 0.050564694984425465, 0.07316740289811166, 0.017809217247451027, 0.04058288342709984, 0.009619583161697995, 0.02755779525144927, 0.021904403448946053, 0.05736112061347212, 0.01652756747188828, 0.07327815622932489, 0.029296452863021728, 0.07776326394730038, 0.028393432467935548, 0.030822293164448875, 0.05274841712126809, 0.06992253790339155, 0.04259689027563699, 0.025807249870511795, 0.02830507763240847, 0.004821519908164778, 0.031951347801594004, 0.01274437728082581, 0.03379161356978359, 0.049748504909897046, 0.08677269542409528, 0.05591514880859083, 0.06515474374135656, 0.028169832470255996, 0.08352837435180142, 0.020025281701236963, 0.012499446522504573, 0.014347421050432229, 0.06284109309255596, 0.03154670399042868, 0.06638082915977125, 0.034059250216570594, 0.03279289538641611, 0.05647659932653751, 0.02190174895428842, 0.019539373198283777, 0.06813134772763138, 0.05056717327886051, 0.0764767418525392, 0.024393262236469218, 0.052175781719626925, 0.037981865537022395, 0.1583577743581226, 0.014483590306143367, 0.02150448640027354, 0.010709315463299713, 0.06412806717919246, 0.027892236680453344, 0.0982544228674904, 0.030234523695863547, 0.04283339310918124, 0.060132114261749296, 0.05918837054782818, 0.04902117337370592, 0.09322637331581886, 0.02433004083051797, 0.06984636578108035, 0.07562422388864141, 0.023140300538450963, 0.03455461799016884, 0.04032562344124721, 0.0568462482413217, 0.03362135052861225, 0.036686525770252755, 0.050727155420088, 0.01583111215187537, 0.017238755620295004, 0.040665337470390146, 0.0256418802159568, 0.023824625813792792, 0.056759504105655424, 0.004778596001767344, 0.02873532410200325, 0.02229789493515367, 0.05094025043710586, 0.022218101132180423, 0.012902870338650481, 0.04879728800827458, 0.029146878026245587, 0.05359162711688588, 0.021921475718338645, 0.048454639862381646, 0.0031962698830607077, 0.02497139048852748, 0.013125195757546013, 0.05178645200606796, 0.07002586018173926, 0.0377050856308591, 0.09219644471041619, 0.04633371778313191, 0.004231562300945723, 0.06892142186482107, 0.07904382587801065, 0.03794256905694643, 0.04679950690197368, 0.2616006093880823, 0.15461779439881926, 0.12009082452183771, 0.1489905108727755, 0.14446950427466823, 0.13609427868598892, 0.11276837994134235, 0.11362207001976429, 0.11409974116231165, 0.16981924643679974, 0.1112386555741391, 0.10676171435343643, 0.1240425052181367, 0.23980156218092288, 0.12123712188293859, 0.11257294325097916, 0.32559677537891174, 0.11767837534388227, 0.17665587636011262, 0.22637432381030054, 0.18143568278080036, 0.12845728606466325, 0.23136831309285857, 0.21117071140437357, 0.16334842349733078, 0.12391071511252273, 0.23256851240031182, 0.19248916707452268, 0.10372642803216174, 0.11924093423952019, 0.11839560218035214, 0.12907990104248449, 0.23940989206875526, 0.16582791302953998, 0.22546569756682844, 0.13673874249141063, 0.11942697103105246, 0.20423435215507785, 0.06842115878938668, 0.12386928507757765, 0.16900895523928827, 0.21854364883995828, 0.14408941741191572, 0.069800415827382, 0.11922326059110704, 0.0945534291226537, 0.098745416279041, 0.10227512042488783, 0.1846069497086348, 0.1872686302709964, 0.16508807127754535, 0.10938080808808727, 0.11374408484346445, 0.08241141049732124, 0.13101750594233313, 0.1525541067483925, 0.105025636542949, 0.12663885380231565, 0.20218502099235214, 0.20811405123001148, 0.2552036986115479, 0.2218630771723486, 0.08994340310774504, 0.1178222389951829, 0.12013430001154063, 0.3094083263028053, 0.12712934159583625, 0.18635148512980632, 0.10673055755755595, 0.17565823069983916, 0.11360016756600912, 0.12594354474135946, 0.21180403629137626, 0.1150600093927595, 0.09120131181853433, 0.10991691641749875, 0.12796234730030262, 0.15290016398554848, 0.1804502332402814, 0.08720685277254352, 0.08314906889873167, 0.19634239015079316, 0.1677967436731823, 0.08575764424618214, 0.19107123025723044, 0.1087285838119926, 0.217172060342085, 0.15652417355487425, 0.13133799116457665, 0.11079672243325941, 0.09941918294756644, 0.1509151995302208, 0.17295286780403507, 0.13977890113188376, 0.10336318744286414, 0.09512637095946459, 0.13928610741371109, 0.09917507669137371, 0.17199061540586336, 0.17486703041340076, 0.16902881223828564, 0.2924576503855567, 0.16035375515780143, 0.17624614189469046, 0.15642337170579743, 0.14885934129838022, 0.09618541090598992, 0.10496019731245695, 0.13657452388396188, 0.11809777783890886, 0.17049628430076186, 0.1295304833160293, 0.21813484900180372, 0.09599040322486432, 0.18920097980768452, 0.1269261674174378, 0.13822323702756437, 0.18786493778949787, 0.0726223313399861, 0.1296565047795734, 0.12377770692710915, 0.20366838171837792, 0.2209140014864745, 0.3176519533078517, 0.18302594341578024, 0.10447550114364394, 0.13050366012800124, 0.13173456423945967, 0.11333822678293913, 0.20394637970434082, 0.08187816733674658, 0.10412075646942663, 0.1813561015672261, 0.13821102558605133, 0.25283250326831497, 0.2410133907030667, 0.17867796543625095, 0.1445076554532974, 0.2085456651665511, 0.10838012871963364, 0.07236033693076142, 0.19139237431508882, 0.1834088494820941, 0.11206094370854479, 0.13592408459273078, 0.16418971061225862, 0.13310969206354312, 0.09383274722964534, 0.17164055918974264, 0.08899674825971166, 0.14275277784514812, 0.11262917410462134, 0.18141289932593224, 0.167049118467877, 0.10557348133936044, 0.1370437067723082, 0.14772144026092945, 0.11957791333477344, 0.1231677400609178, 0.11562475408878058, 0.11871350568629081, 0.04175146628591803, 0.2399764753757946, 0.14326470843966932, 0.07314862608308755, 0.07462006648101153, 0.1877254944655203, 0.21387428165443484, 0.14151513215995606, 0.19857434135290886, 0.14481666467843518, 0.16687635031919326, 0.1322166327266924, 0.17506731644032464, 0.16926217794177995, 0.11413898784667255], [0.018906835466623306, 0.031617785458483046, 0.05360111128538848, 0.03361549761687075, 0.03250469310930179, 0.05425781717584018, 0.01843793986124858, 0.018180195324783845, 0.00586506333239677, 0.001672335584448921, 0.026958205046192295, 0.07195067907413168, 0.1074662700956387, 0.05820943658510524, 0.05154240320646956, 0.08593370657294028, 0.05124568586207686, 0.01728613049753251, 0.08718815256631182, 0.028938931120078892, 0.026081727682462624, 0.07106320451824896, 0.0771513435569021, 0.05255557746896821, 0.06700854628316819, 0.045120789924816745, 0.0477218269670923, 0.04082290260421653, 0.10275728084267148, 0.052733650776527585, 0.02311257007081182, 0.023741332904225396, 0.05041035891119992, 0.04147640624714475, 0.04278974908013498, 0.0428954538919272, 0.04772965255523882, 0.05501045642660991, 0.04153745196339104, 0.03351188422511182, 0.027153798784579963, 0.018003225183835434, 0.05178506538692502, 0.0414305443935577, 0.09429302051543229, 0.04472743058877607, 0.03440860929268022, 0.07075303083946628, 0.022425774161914186, 0.013676198751425311, 0.011341068912447702, 0.01529896162420271, 0.016530269847041177, 0.022815933165651177, 0.017126064086633346, 0.04653770018429045, 0.02187453176555855, 0.008295994860330417, 0.0630197333051793, 0.0529111763312211, 0.011472911686606465, 0.05304159896989023, 0.05867575047417514, 0.06068065236773222, 0.04728201588976288, 0.015889693937835195, 0.03028525786864902, 0.0506266983105771, 0.06048680530981191, 0.01318590631032543, 0.04803833619300877, 0.047122776853821935, 0.06402720787352131, 0.039111048493894844, 0.05088953158607887, 0.01944140012886736, 0.04082786302352625, 0.06917131208484212, 0.05329387172335579, 0.03928077527351918, 0.008299294784064255, 0.08327882121046705, 0.06138409728244428, 0.07447550568969981, 0.06258122074688155, 0.027954975451012293, 0.05764597125591771, 0.01892112875207057, 0.028478983421659762, 0.02935872048950724, 0.04535041711924057, 0.06977984636661506, 0.07932500312885932, 0.041613627916141864, 0.04849000248096643, 0.024785401577490474, 0.08221624959861079, 0.02823104672584563, 0.05982189461769116, 0.05609640138103597, 0.07183797221871153, 0.09068888326686236, 0.04983705701306463, 0.08104317746455632, 0.022231720260254318, 0.029470429515406012, 0.05582286585723201, 0.02155583535861825, 0.06256997840659273, 0.024965761657503825, 0.031842500114092426, 0.03906348975555551, 0.03648247825162065, 0.04846167254952654, 0.030125057392363108, 0.013903354354683432, 0.033189901300976356, 0.05391534906060946, 0.02394682066815515, 0.06698534147994173, 0.06343494146882046, 0.0273452345807586, 0.05182622346065698, 0.08277305762373632, 0.07258620263347704, 0.022778071185213425, 0.040453456702732274, 0.05960270920167527, 0.03433171321728057, 0.06025030630670729, 0.06857878137980739, 0.02583206920403867, 0.028247471650942203, 0.04805085790013114, 0.01506642233805671, 0.05678223393436882, 0.008573543727247706, 0.036266525726645224, 0.014287093541614953, 0.015164604166432496, 0.03576794038376501, 0.019316983619524587, 0.05918133019980404, 0.03507883280455586, 0.026464827185977372, 0.026259249406716517, 0.03472550156255884, 0.04097875553153215, 0.05648021526154011, 0.04965746685141518, 0.04642466774150249, 0.015201917436394482, 0.029220140929664337, 0.028125822634225892, 0.04000851283631018, 0.0301298703397474, 0.031613876494849404, 0.03645535873910112, 0.05568216614905865, 0.03020786958175802, 0.030669661636854854, 0.018025328735670736, 0.022567282092847654, 0.015008681333593786, 0.05804151394254258, 0.02058097123799305, 0.019233746251331705, 0.06636758349956044, 0.0855339925375677, 0.04726340378364248, 0.021397211108236544, 0.06337670346481666, 0.0857135558861398, 0.08807630894044716, 0.06561333929458935, 0.07651946657607633, 0.015680813362010788, 0.01787297874538889, 0.05646632608747291, 0.023647286035420916, 0.018953375308023348, 0.06525974375225845, 0.020172315041324305, 0.016936840369336067, 0.028759779543766094, 0.02615964457002138, 0.04222729881744712, 0.08866136262734091, 0.036168244306839285, 0.023100534829521374, 0.04914319202784569, 0.057421630068171414, 0.027122550058148565, 0.01017144130122277, 0.0764027530808122, 0.054149339125762065, 0.009528734709977383, 0.06227301974450389, 0.014730133679545215, 0.06523617888770758, 0.014899364417238582, 0.0640965388306687, 0.024604901686430942, 0.054132596274176915, 0.0470477806764745, 0.04339811482256459, 0.016719432277304512, 0.03431764784299078, 0.09674985682772053, 0.03179067618123466, 0.06924019871099342, 0.031639461916300564, 0.10103230364620687, 0.0461011947763543, 0.017321801466506817, 0.0456750966728695, 0.006720824242239037, 0.027290122215485862, 0.053437011421567975, 0.04204352964617072, 0.0420697988010943, 0.041401938670465065, 0.023657743135587345, 0.05253634100118953, 0.03651648489457946, 0.03872576755501571, 0.034030016301380056, 0.03480992445181455, 0.058179302516603665, 0.0387239595875144, 0.06015674781895453, 0.04885153469419287, 0.09522348792562563, 0.043333177379662954, 0.03585480709349917, 0.04015243777464475, 0.08354046321924656, 0.024671811805737597, 0.06134928624716498, 0.060289085677434365, 0.09115218259995023, 0.021064062452604695, 0.007681514778655143, 0.0350375330045579, 0.03238861163657519, 0.025670786628559716, 0.0751097115778154, 0.01392928547331042, 0.02947165525608486, 0.13519248594680142, 0.049193098825672944, 0.06625281586762398, 0.02382294999645843, 0.12017173106752096, 0.020735853148864645, 0.025692939976110094, 0.017203034855605617, 0.06622502219773109, 0.04374068635966509, 0.05770003025029456, 0.06307098075687405, 0.025091763968849858, 0.05172545225509713, 0.030874574834841396, 0.0390007050197211, 0.0800562110699473, 0.05563121364121476, 0.05113240061027389, 0.08826688863337041, 0.06512041534146955, 0.03189896462455152, 0.07664525055236394, 0.0452217411610388, 0.016194382427080024, 0.023691864691734798, 0.02341662653751912, 0.060015779980007684, 0.0452579464763403, 0.07431595255770991, 0.01974499311238047, 0.03814620671853904, 0.07430878963561789, 0.014580229424961634, 0.023858174719216845, 0.018603050961129127, 0.03477425539806005, 0.0232500713619013, 0.039346390704233805, 0.022141925179429596, 0.03586839749327591, 0.011340276011446071, 0.06304282319521712, 0.029431466283577106, 0.03680168793747022, 0.015609896602860142, 0.11231019807558869, 0.08100071321091346, 0.015913536509258613, 0.02622264764091421, 0.03272365252938002, 0.03936954571174518, 0.0252489996848688, 0.02234759105880174, 0.020043363291469794, 0.031065384354141932, 0.06080753184975155, 0.06954756084709399, 0.0403867764098029, 0.08188552178081968, 0.022607170375845125, 0.00449997078131644, 0.06041953512918084, 0.040610596657760685, 0.038421358687863234, 0.04924577120090685, 0.0388014187375384, 0.009675988300342955, 0.013570551396227412, 0.0386827593789466, 0.030192402266566793, 0.021163680695838506, 0.015693404017046334, 0.046120917709964904, 0.02022157641007535, 0.04516872404623897, 0.038993530606310216, 0.0567247620182893, 0.0336685530360668, 0.04204233454900884, 0.031603505579574455, 0.026342818107936653, 0.05199864686977479, 0.030240784549424728, 0.036417169256075736, 0.03165644225514224, 0.033816021131051165, 0.03071510788774298, 0.03215527657659785, 0.01169461848950314, 0.04255036958643506, 0.08360071603449122, 0.04573123176552115, 0.04308998276810012, 0.026208854227837537, 0.04134640112639435, 0.021734504299538753, 0.06737584713846445, 0.03795664592255508, 0.05968967167239997, 0.02014722374658431, 0.02670132427386219, 0.08427855062989459, 0.08703572405201775, 0.13393090767485483, 0.1228071654575967, 0.10733293249241768, 0.10011533470523935, 0.25315715600886657, 0.12206700960955313, 0.06207716170578234, 0.16761167215243464, 0.08116556767133937, 0.17339729073066867, 0.2202861311454927, 0.23330176579615763, 0.16927391440877992, 0.11920663648315015, 0.22088082987935315, 0.13033384907870524, 0.16578066072637038, 0.16085275418816075, 0.09627348803464444, 0.11231638806601686, 0.12466408597726016, 0.1324982619694164, 0.1415174151019704, 0.22181194846428212, 0.13230569810876924, 0.11412597967371826, 0.22561528389492344, 0.185068870083459, 0.1329929096203658, 0.20999084407043075, 0.11992461408578581, 0.176549558677981, 0.2791220514524368, 0.1597398582605585, 0.1720410393130395, 0.13380813442410963, 0.11563183274120094, 0.08572800430439173, 0.1340744572301065, 0.1546182693733323, 0.1561978967079232, 0.13850826770067215, 0.11338780799339856, 0.12989858856364606, 0.17859832293564276, 0.17641733190225017, 0.17578458924206997, 0.16150520062975346, 0.1776835526670179, 0.10361145355648572, 0.11891484125367097, 0.21651463432898446, 0.13625983028642594, 0.19757243624377638, 0.16256589532619523, 0.1834961681837036, 0.08465991685948066, 0.14569009684266584, 0.19583140950529807, 0.12544813866336502, 0.1893628388643265, 0.14263955004993947, 0.11492248128859267, 0.20188710472035795, 0.07189755853746208, 0.11525599000554894, 0.15278033251243253, 0.14632924399789304, 0.11674100548149118, 0.11766425634343779, 0.12806688765844992, 0.11810374566383901, 0.2189169941289771, 0.15697899995551956, 0.15730271806880353, 0.2130281068985501, 0.17536344006657603, 0.17787622377997447, 0.1957977476019052, 0.06386223083902752, 0.1673247722247916, 0.1590681523685494, 0.1516305877556724, 0.18294354299864463, 0.1776184045499371, 0.19555322765823335, 0.1612063037652162, 0.13361462061443638, 0.15464370349241843, 0.1746209170068464, 0.1657164012712817, 0.1817433130476744, 0.1468848569258567, 0.15733196730575255, 0.12970605534651589, 0.14388508644075165, 0.1219814912145657, 0.21714475696846364, 0.13232589218645327, 0.09897308228837867, 0.19357829895471373, 0.22767794498753166, 0.16952280105362016, 0.08122873928157553, 0.15104088391507828, 0.23986940692749717, 0.09339537997279437, 0.1181432068528187, 0.12086748445947325, 0.10189288085506809, 0.1084000776491819, 0.09294186358249958, 0.15809140558685028, 0.08180976334598758, 0.1933930895381397, 0.22604987025260928, 0.16852863343252292, 0.1694171268853449, 0.223934042658056, 0.19386172084318054, 0.07455461958964026, 0.11938076060745986, 0.14334631212536367, 0.19230110781087031, 0.10869365020264542, 0.12353045971042688, 0.10609474288479936, 0.15385664008077116, 0.21793955786814614, 0.21944472145649696, 0.1551838567660701, 0.1665029130996235, 0.16339104862943774, 0.11004223308015255, 0.14153773175372233, 0.0712938352878536, 0.09671428736539618, 0.14316511700951284, 0.14416340618364273, 0.10083164223620009, 0.12919106040029757, 0.25661268752188454, 0.1489395200605354, 0.06814844681010132, 0.22104086564673533, 0.15343843268290644, 0.16774592140028555, 0.09199053559812809, 0.10494617790344263, 0.16622778028249743, 0.11275003213555583, 0.10496049608674743, 0.1280989944033565, 0.11263186307323557, 0.1398023893876422, 0.2135035717078755, 0.19876034750092417, 0.20556140030103348, 0.13543622448079048, 0.1291989204624007, 0.09165987672825014, 0.09245963421680274, 0.15809258536225365, 0.11597344666839608, 0.16259238664661685, 0.17084857749362148, 0.19263670028698063, 0.4004302662947486, 0.14190522413099968, 0.07885130032175973, 0.26251776985103087, 0.18531075468467129, 0.2649312532476841, 0.14202631198831145, 0.12512581483010324], [0.010771310170962205, 0.03882622466452661, 0.013872458986307104, 0.026380107437651006, 0.09762616182166724, 0.044698326908532655, 0.03633481863465521, 0.03727531413577738, 0.07022072996703849, 0.05648518717216869, 0.0457498706847189, 0.0379918361713569, 0.053165804805053826, 0.017893502240880363, 0.06573271877582997, 0.027579025463050896, 0.01142659592592428, 0.02056751107316344, 0.047580717401879455, 0.05832399354286252, 0.03484500744830697, 0.04218765376736561, 0.004992144925880336, 0.01821020490399772, 0.047402896903335094, 0.020333174353225097, 0.05722133638036828, 0.03434965882690684, 0.031442895246249054, 0.024538552726528818, 0.027552704597192428, 0.07744183643691002, 0.007227903584979716, 0.011892424306772169, 0.012179216982105808, 0.045534557843160246, 0.10018802878837432, 0.0331912342939646, 0.016696507096170418, 0.04837200578842913, 0.05453913232251521, 0.07196203249716951, 0.0553888923698856, 0.03465948776612359, 0.03091733594755492, 0.06342772492057373, 0.03907740957313969, 0.0707633960090818, 0.010922010199377134, 0.03674730335572555, 0.016384753361043912, 0.05891574666865411, 0.07853889732711739, 0.04956508047818657, 0.04131416031610101, 0.04592904332844962, 0.01511557549688845, 0.008488646821088849, 0.03974926485229404, 0.028169947383444638, 0.05431107177789654, 0.02866512746550143, 0.07061259160118719, 0.09303780077325721, 0.049722082537388614, 0.03364649353428714, 0.12552037309374542, 0.0300575114200793, 0.03999951896407912, 0.03297802819419773, 0.009517270204190527, 0.04767079785045597, 0.005799346873837133, 0.04570134284515535, 0.061537579167634256, 0.01576580315633046, 0.053304351806159944, 0.016710947853543105, 0.03208663126814269, 0.013441749033518137, 0.04407838174712755, 0.0299682219572846, 0.013161045799572623, 0.049195569459228754, 0.029980914118970116, 0.011133932144260936, 0.024906154271335374, 0.06036534973029649, 0.02620156873167763, 0.05792639391016095, 0.07085389397557705, 0.025277526883949197, 0.033494861751434304, 0.049145758422392036, 0.0077082076759618385, 0.013699500273252207, 0.029344725978350448, 0.09582464478068775, 0.045899744295785506, 0.07851351683418598, 0.0036997651313281353, 0.05841036612588552, 0.04918922625121571, 0.0132477363090842, 0.0370150740678993, 0.10829834117283745, 0.037774336148774436, 0.041432352361059, 0.01968816279493753, 0.06035715641994631, 0.012327958698264294, 0.049740166042841254, 0.026986395166586005, 0.028879739336609363, 0.053432606416003364, 0.020069883340188575, 0.030961100635449254, 0.07866518692143502, 0.02281236128070422, 0.015065096048337799, 0.029532471145953865, 0.055577476403766105, 0.14263538253163138, 0.012384448106580926, 0.05873324154245277, 0.00898950361466456, 0.02544759074226022, 0.05494172684848309, 0.0037266382986995126, 0.017890503006656806, 0.016032310781039057, 0.013038759014659352, 0.030351459356625716, 0.05917656896335464, 0.030418564828353065, 0.03397573514150516, 0.06933838053936921, 0.031979813713640455, 0.053737088061508634, 0.04021232669812538, 0.03870091566275205, 0.021694271276975353, 0.01556374267825196, 0.06455236114561558, 0.026841880340549736, 0.00752562354694331, 0.07417719105198499, 0.00470631895774615, 0.0448672492958365, 0.03627621290844776, 0.020265927155231758, 0.04147809164057817, 0.03386721495659121, 0.02860066691233266, 0.014701045321060285, 0.032071225239985415, 0.05125472569958337, 0.11001469988015392, 0.028989759138635093, 0.0219273018170028, 0.004036139974731111, 0.02357786506294243, 0.037508338930145387, 0.00940342666581273, 0.08521254204453961, 0.0817301974541718, 0.057466369602949395, 0.01691400520353308, 0.05543885662430718, 0.05207830086170186, 0.03489815479805393, 0.05337549839168788, 0.03920298287524812, 0.05293833414813685, 0.03382433701546923, 0.03505663157651021, 0.047210267925214384, 0.046093200648864435, 0.06921229012791189, 0.014024757265654064, 0.01638606528661424, 0.005814921441337755, 0.0731464350716241, 0.032814246256865805, 0.022063069834163593, 0.045117411477070664, 0.052333388988289146, 0.029296362847690622, 0.08126217135859114, 0.014058819449987384, 0.024245887987255573, 0.03739670459781924, 0.04928215271643093, 0.07749674961932244, 0.01894581976587013, 0.04733700568096773, 0.04720973166366739, 0.03374129308447723, 0.018485946761023615, 0.0255984794198265, 0.01350553925975316, 0.040076334600246726, 0.00537930278017396, 0.05382568612995167, 0.007633962264780196, 0.04547817760237283, 0.07065602112561464, 0.06235982133676449, 0.033736344156486374, 0.02537815827846287, 0.0420585602912451, 0.022224241326893532, 0.0505112603517069, 0.08202841250045646, 0.028211647464383035, 0.054464591967482726, 0.03786953789512477, 0.03670679645672922, 0.049792689030929926, 0.10320909651777438, 0.024166201436591726, 0.11126611982622456, 0.06357498617181856, 0.030367233106986653, 0.04687413918755708, 0.05266807365020918, 0.06962289027268849, 0.043873035709463784, 0.05419163484006159, 0.06477163083130313, 0.010103600385088113, 0.029419218452887672, 0.027703049352332473, 0.03163531929585001, 0.027269225252131303, 0.005920908748052053, 0.031215809548514026, 0.030084743930567658, 0.05682932152863472, 0.05687644742729683, 0.03038793471792052, 0.015459010798123576, 0.07183288539489431, 0.017633064905361786, 0.014827677739724038, 0.04778594469591495, 0.06732617399745411, 0.018691537946823145, 0.011088554841285993, 0.06103736205747532, 0.01593759837335036, 0.033000773344669616, 0.01987706092486699, 0.05984005473193623, 0.02035273449315179, 0.037823086153836026, 0.04952669947318012, 0.03504155879659999, 0.02988103923628167, 0.02781573705555451, 0.07016583976726379, 0.057630795054137714, 0.028849563133271954, 0.030355444929051786, 0.015732985864874097, 0.010293056801592392, 0.07384486977131137, 0.06657846452247712, 0.03640841670154083, 0.045672534108762784, 0.03179629160571964, 0.024286486816802816, 0.06913424109018619, 0.008461735109918782, 0.07566007680349773, 0.02121913780067717, 0.030849611859828718, 0.04796800166068058, 0.011585239328504091, 0.0361604800057267, 0.008542241374661606, 0.06983652155125333, 0.07383797497999284, 0.06276745672127412, 0.03675197649206366, 0.0257577107948882, 0.011665452564615878, 0.029590906417598168, 0.05449404804817131, 0.0304667862327469, 0.04675711542668362, 0.04713013512833465, 0.06852173081208622, 0.02394047937536192, 0.049452664736177654, 0.027154248861235478, 0.03214873418572449, 0.02231483505437932, 0.09434202715994851, 0.025258445548975182, 0.028735714806844632, 0.01812746932339524, 0.049516977817421, 0.03634932450950146, 0.06589279284760838, 0.03564737729668137, 0.018964950896559224, 0.04470845459089164, 0.00920402930088101, 0.05348852317359659, 0.04040994673907276, 0.030432609135224938, 0.05232459046847878, 0.04074878742798202, 0.042045965805769935, 0.03618223690277627, 0.02125849748300689, 0.01535076353203265, 0.02324906395628087, 0.049851421161644885, 0.013153368640961427, 0.03977903119859196, 0.04766803993392856, 0.031655159057869066, 0.022344375404739575, 0.026689264134714202, 0.06124273107777681, 0.0611515972583044, 0.04562309845500896, 0.027868311754578066, 0.12977198487327946, 0.03863943710682854, 0.05491394466990906, 0.03542677844844518, 0.041475847002960024, 0.032994330545226415, 0.03500403581006873, 0.04243535297592321, 0.026457549350696708, 0.00212213177996267, 0.019780644929156672, 0.06365144940754099, 0.015203547288453387, 0.012397221665108397, 0.01871274517578704, 0.009530619286271113, 0.04087334566359078, 0.0653172233292172, 0.10522218406080239, 0.027207520700270132, 0.059570816961387475, 0.03720087337217504, 0.13089557538830465, 0.11476689649205055, 0.12386690254413313, 0.10304343000414873, 0.16130034871880086, 0.1502134783133384, 0.17612058008390089, 0.1429233703041269, 0.16656203976561948, 0.11489831887546087, 0.14203156735147202, 0.059332188233853354, 0.19235704755110128, 0.11317602298673123, 0.1938915982722275, 0.08414940352761939, 0.14176142942761222, 0.2063505474718348, 0.15807439843493123, 0.13284663279210368, 0.11724745088647451, 0.13007031483275275, 0.19918984703479276, 0.20271610378498034, 0.19488915200195006, 0.10655560605828801, 0.19534836042552225, 0.11414284892981091, 0.07099804874028891, 0.13844681212738638, 0.1566431316877565, 0.1779181287894326, 0.15556870869571165, 0.08479775905969643, 0.12785409141572254, 0.12730822312615572, 0.24332581178074886, 0.14772903985313832, 0.13189355812726483, 0.09038143686109013, 0.10649795794198591, 0.1375561583066179, 0.11592595687796993, 0.15740040960090776, 0.09957174169680766, 0.23258918145250893, 0.13849585707629883, 0.2196592260752955, 0.14184062759722435, 0.14638639415704435, 0.15429393838970892, 0.1203622877778065, 0.15036121070865663, 0.16494921018039027, 0.123970860675458, 0.1545038158374448, 0.09107443999739424, 0.1020122220319125, 0.15285764610575092, 0.08150263869714353, 0.08879102300852539, 0.15806969465507617, 0.14256143972517984, 0.11739908266932735, 0.08424252917569491, 0.14160332420179922, 0.17334876672154473, 0.1827444827123996, 0.14118019851946062, 0.20376045016511796, 0.12643246205463526, 0.18183806280214942, 0.14626222662627697, 0.2910655154095542, 0.1787580829113722, 0.13927574990497482, 0.08374017468022724, 0.10650302944404465, 0.0901205073140802, 0.11159672506994779, 0.10814994228102508, 0.10467714314619381, 0.20779456192206955, 0.14227631712152114, 0.08489600217510616, 0.15781732997105968, 0.08228089975854082, 0.1530262007708511, 0.19643664960899662, 0.2013197553253943, 0.15348707926609825, 0.16664672312476944, 0.09528458343758699, 0.18991478989201208, 0.22347252064895248, 0.14126653662852703, 0.12137802077397225, 0.23044660206763978, 0.24544137890540788, 0.1653513144100866, 0.12329579931834053, 0.15841012880686792, 0.1971840143444077, 0.17156770422814355, 0.22538967100122284, 0.1760743696603083, 0.24289099559668573, 0.13973993790005484, 0.06020272458573023, 0.2028757411866419, 0.10194505910359083, 0.16765736163623873, 0.15766466396950907, 0.2025620741469245, 0.17269820485624576, 0.12626347071941824, 0.18442728676863257, 0.12751957146270623, 0.13416264927194965, 0.11109892113675034, 0.12264957351069297, 0.1309498297351022, 0.2400513374877553, 0.07539267381352764, 0.154985394028406, 0.12239336306529662, 0.10208447178405139, 0.10637527662179164, 0.12104706312980383, 0.1490382381504582, 0.1330394111573696, 0.12223407806408022, 0.11926305119789417, 0.18990009632562438, 0.18884764473524787, 0.1547092040099444, 0.08134793490171432, 0.17291255625745944, 0.1419071240290519, 0.09433762981526314, 0.17971671937454134, 0.15459340215931017, 0.06686701920003661, 0.11285235849960197, 0.08473261860349486, 0.13269911490140424, 0.11697552797775115, 0.08914844899047768, 0.20264950010084337, 0.13476137762829182, 0.14887847817472874, 0.2240879803655609, 0.19143196573901564, 0.08534433981103283, 0.22147344485405954, 0.18427302730419945, 0.15917623205290687, 0.23717712881343983, 0.08700941659269795, 0.13501919685832917, 0.09266661585218484, 0.112924455034156, 0.10014969374864333, 0.1433357554337671, 0.16671833702393118, 0.16038626792930788, 0.11325743515044452, 0.07060601856679687, 0.2588148685472627, 0.12098297987493778, 0.11153618880217114, 0.14549702736398867, 0.13573403350047528, 0.10980068555762691, 0.16469920504718058, 0.1593264312513413], [0.06433436316588233, 0.029861718498831315, 0.01465691865662173, 0.024086026504876155, 0.07202800798920855, 0.055423937061981815, 0.044462000275210994, 0.06006048504082907, 0.04669244611455549, 0.04943642750262253, 0.03600946109321329, 0.0507113510262101, 0.02412576157028877, 0.02349201150448813, 0.028459055559529413, 0.11041239910428563, 0.09849451482295991, 0.04950195866366548, 0.04279652129738562, 0.06546533110761835, 0.031307096585571285, 0.06636454979138029, 0.023358488124945474, 0.018520677357070872, 0.012139266454464486, 0.04264603481597958, 0.044270083758859866, 0.09084929441732746, 0.09337798211603396, 0.07563984442141748, 0.050596740442298116, 0.03940944357084171, 0.018778329962984692, 0.037681926792908105, 0.05020302104493303, 0.04021087496150886, 0.04310920391412031, 0.04774114770454265, 0.04047381931975965, 0.03345726215611062, 0.05704697859924167, 0.024112994715030638, 0.021839780102093375, 0.08388288919964144, 0.03979837491868004, 0.039618198699768514, 0.03146241325133991, 0.042632302689936855, 0.038741751979555816, 0.03766642500376029, 0.03155360261218683, 0.002521740478245662, 0.041643309992768114, 0.054812572085328644, 0.034998420385583755, 0.0250957093216599, 0.00273700041185704, 0.04483656747446907, 0.022167083506862965, 0.022574573334666993, 0.031116181729181163, 0.04804074170909101, 0.02814476990381316, 0.014980534305645814, 0.02257555392721007, 0.004998174037844424, 0.06584240724482844, 0.021346241363414356, 0.041084199873430115, 0.006466306372350383, 0.041556814835677226, 0.025721522716565, 0.009607561326946222, 0.05161420479717274, 0.021155571655159997, 0.022629955745933038, 0.005183500282826924, 0.023127058708679774, 0.09129406208352697, 0.05213620178701897, 0.01698784267289504, 0.020500943778202902, 0.010524075403208695, 0.06833221598137772, 0.018524323935590444, 0.06587036179318544, 0.04784254327176079, 0.029773629878857927, 0.03216217519835599, 0.010403446241041586, 0.06063271058543075, 0.07703672914255051, 0.014510994228804785, 0.04435184066213908, 0.028156226748720776, 0.04113250937793524, 0.02764385182320351, 0.031909431300817, 0.031893416232759916, 0.09385227481083525, 0.05401561464813929, 0.04454454241861259, 0.06164153729895912, 0.029865075879159476, 0.08119696195447638, 0.01461744789154299, 0.027618413873677774, 0.04893887637844009, 0.030652261864874634, 0.03307953484416489, 0.04530531369269856, 0.02958419357216166, 0.03844180557456228, 0.007363412089856162, 0.0865142250193223, 0.05949990020223683, 0.03470864762822467, 0.03697839377808475, 0.007420438717329695, 0.025397132361127485, 0.04210344921316832, 0.05925461034020109, 0.08146495483214818, 0.02418431558556134, 0.05714933560680478, 0.01890296289216607, 0.03380013246750159, 0.04787028331549899, 0.07986671922187652, 0.020119294096084855, 0.016126675576332117, 0.02187794660248103, 0.07884706385553845, 0.034798823837791724, 0.021240544212501378, 0.05373024306590519, 0.07601469124276793, 0.008653272412747385, 0.040269790953325654, 0.07414755111019458, 0.04876371037455336, 0.04651863225585511, 0.027045866572147897, 0.011580071107844913, 0.02881844081134806, 0.0251235930068839, 0.016286820511243517, 0.0877123941937762, 0.0944199306409686, 0.0403934873400196, 0.06698443749619108, 0.05119726910526234, 0.07394338101749459, 0.10075131025646003, 0.03145412801043882, 0.08450861449443525, 0.037893750103971655, 0.03802676211982485, 0.05410547676165739, 0.045908125297677134, 0.045355197507888086, 0.04399506968536204, 0.07533072794397032, 0.013390938251940234, 0.03085816906194293, 0.04138978851598598, 0.08148146402691642, 0.053513206526516914, 0.13160555503301083, 0.0667523664812888, 0.06829391924604293, 0.07126814069887323, 0.0984126506673713, 0.03586890311130593, 0.020040251059277404, 0.04868709392124607, 0.04031211348070253, 0.012030679236857161, 0.019364437020774332, 0.046091009637400995, 0.0446472211831039, 0.05444333302758394, 0.06417587489610718, 0.09916565380990507, 0.009715108580196337, 0.023298560897068634, 0.0815010222516233, 0.005653134205438678, 0.02994792828817041, 0.05299907725965304, 0.03697472421692745, 0.0519243210193611, 0.028745888454479077, 0.08687681443388424, 0.05515094546060409, 0.026111220152327613, 0.06198465658892548, 0.030931931837732275, 0.05075578029537874, 0.05185518541463441, 0.07576945117644726, 0.01669588273451213, 0.039935619570314884, 0.02771036166156973, 0.03412828622986713, 0.04209610626041409, 0.04481655725788686, 0.04175415525453226, 0.03901610721743876, 0.013216833279828632, 0.0294559485384173, 0.014896219626309411, 0.09532271929445768, 0.06241467323214297, 0.020598041592165828, 0.01132362413280193, 0.027946843427696058, 0.06570251958985483, 0.05581430099423855, 0.10000579945382573, 0.023988139620351217, 0.034282955551339735, 0.03805055298031338, 0.05719906620440945, 0.020999845132351886, 0.007070672657010296, 0.009446136067591367, 0.03360048612399447, 0.05107218226898582, 0.05983322888853089, 0.045643503206872174, 0.012769908118512363, 0.037102967335452, 0.04109029793330739, 0.0652678259798596, 0.12153705296617363, 0.03907526835739132, 0.0235087581865129, 0.049587400449860486, 0.027558097856179364, 0.01506404555027163, 0.043495729745876406, 0.06675250437711516, 0.014500162703165365, 0.03148666567980282, 0.052019649170218944, 0.07895020993366357, 0.049055095746993065, 0.0972060162213541, 0.037676081542045846, 0.057514139015467904, 0.01309446031002388, 0.012115111702211924, 0.014894933556206526, 0.06987694801101763, 0.03749810016503738, 0.0522432855570749, 0.06630016776222376, 0.023412673523829832, 0.027534102067171086, 0.021978344340177796, 0.08748994524320287, 0.0731938099488616, 0.0119580588896849, 0.03779366837754365, 0.01079334956293385, 0.04154182249499906, 0.06609089552394806, 0.031245708044978882, 0.031355896386347955, 0.053481011681499026, 0.053728802820607546, 0.08230352233494483, 0.05481814920541741, 0.027379630013338985, 0.05684503399196172, 0.08260801930220858, 0.07826035541872825, 0.07910256183916524, 0.04613145524936338, 0.025225182011302923, 0.048124785384824204, 0.014718080243666568, 0.04003423423836789, 0.06097607502353288, 0.012097283878604011, 0.03693044816534366, 0.006891149528054221, 0.05328542177355098, 0.013852150953044335, 0.04293072074952145, 0.024063313913141048, 0.05940086035538585, 0.07096631737846522, 0.021231929553792845, 0.06155321885260844, 0.03906178520992398, 0.05546103103927547, 0.017043198271083738, 0.08072297569484481, 0.028115721764944257, 0.08478225344010899, 0.002464361689729436, 0.022407209936289058, 0.05743231699471513, 0.03479449927145916, 0.027575819385087783, 0.05247466709284533, 0.014467035146099667, 0.07166407025989986, 0.05336935819697477, 0.049705964047461755, 0.026405127869258006, 0.07483604198862469, 0.1623207471904255, 0.05187884604017581, 0.026923430400089394, 0.026111739176896312, 0.02174818279942678, 0.037562137454627983, 0.03459080798371184, 0.03991727942540761, 0.037231195132218065, 0.06582225913241987, 0.027374811320295258, 0.05784993833531776, 0.023920917320215417, 0.029067289151792085, 0.11595712899560891, 0.025050337764344392, 0.048433384752922484, 0.032765557538838155, 0.028134127027325095, 0.08959715434860799, 0.08654277711626022, 0.012740450122603967, 0.05183937335987726, 0.03947624260739934, 0.06459777483776694, 0.05723908280713424, 0.02636508828389549, 0.05725231697602619, 0.02651827905567423, 0.11065280515580408, 0.03148543036302492, 0.02460522727379876, 0.10608369589693124, 0.037877558835691987, 0.08228768729754994, 0.06878178701886246, 0.038590859471549915, 0.02525461127891416, 0.11341240707664721, 0.15635903564191636, 0.04026258589639779, 0.1291418469120418, 0.2626419986688322, 0.1465679110298234, 0.2345057036126814, 0.1122540208481012, 0.11491775452609986, 0.1402686304983593, 0.20717062927301855, 0.23609778753692107, 0.15326085350205823, 0.11592681489644513, 0.2391684977638145, 0.19442093438438832, 0.2300332363454565, 0.1590123352023863, 0.1655476627450797, 0.1516148523097077, 0.12115354169039957, 0.16058283076891977, 0.17838887449714447, 0.11276844122837629, 0.114666860730898, 0.06346645449558574, 0.26954178488062275, 0.17722108070888828, 0.1472648671798168, 0.14995613405781408, 0.2037597606859861, 0.12210349071650736, 0.12238397848822417, 0.06392085188699347, 0.12362170844308792, 0.15292106286412285, 0.21376117643329406, 0.15187104743334556, 0.07844996217998766, 0.09591776276788405, 0.16865828615282813, 0.16292041017403527, 0.09197338288950344, 0.21736257108709506, 0.06729752996996527, 0.15623364237047013, 0.10659877511282122, 0.2132376319458408, 0.1671708191955282, 0.05641853752275629, 0.1404147234655196, 0.11026600736283487, 0.15885102772904983, 0.155508708689482, 0.19494817141563664, 0.13575548396235512, 0.10922215893984803, 0.15304199750384978, 0.09614353654004874, 0.15424025094797536, 0.08082573106812854, 0.17959788381572694, 0.08479142351256264, 0.0841057901420901, 0.12133891964631698, 0.1361664748119731, 0.19191412615679926, 0.12014448898093355, 0.0798141885729086, 0.15943017487804736, 0.24674599599694055, 0.12295639938524655, 0.16845873557031157, 0.1328454376949418, 0.14485211922757088, 0.08971895466768935, 0.11664691456263104, 0.17234281666817206, 0.17672134623412164, 0.1360685534534916, 0.1727165909664285, 0.10641217141622498, 0.09219673582382741, 0.09201369443607908, 0.16914793891051125, 0.2364340848139217, 0.2404216337468355, 0.13293776661157608, 0.10733438039859457, 0.08837473849135061, 0.11298804799275053, 0.12041163150100939, 0.09289271904215698, 0.1988416447514488, 0.12323474977165462, 0.19135414652766722, 0.10966403079369377, 0.18253648984095744, 0.15620309078404981, 0.15480421423431368, 0.1934127933195522, 0.17709049336131544, 0.14380394240781186, 0.1173200760216963, 0.1615675601867899, 0.0882478436875728, 0.13591265456090051, 0.1315449115129248, 0.12464885614932546, 0.06676149058846698, 0.15764528194502478, 0.11897746128060165, 0.1347256013222279, 0.13697360972723654, 0.19852675197105255, 0.17396989548879285, 0.2112754815888982, 0.16247687590939386, 0.09295486409457461, 0.09909548015604097, 0.12285699181619192, 0.1020729651434287, 0.1362159181266062, 0.09989596542812164, 0.1483378652483225, 0.1187884750505609, 0.08934291274917704, 0.11682288495883827, 0.1902341106606107, 0.22257969113847903, 0.20275600164407687, 0.1699535569716846, 0.17409993125306022, 0.1459090447714252, 0.18099752645338738, 0.13343227636669913, 0.134368849497649, 0.19342754817297383, 0.24250415183844107, 0.18691837487201537, 0.09403949903865015, 0.15876265182610483, 0.11285263429125471, 0.13121806776090977, 0.21279828052126595, 0.19116001984765454, 0.12818424466757045, 0.26975760717065106, 0.1303440380480982, 0.14662735945274755, 0.10457804967318812, 0.16398715696507887, 0.14442416719130932, 0.2904925429292264, 0.12732585847017266, 0.29501604697396683, 0.07975367528776969, 0.1718333069114916, 0.15178538348165252, 0.10288730128518037, 0.18596582114696505, 0.14153117404109047, 0.13982230767367348, 0.09707650905775447, 0.13748851274290394, 0.3050094187980698, 0.14014529034255013, 0.23307745525192833, 0.30533007255965666, 0.14377976467292156, 0.19514084252859318, 0.18171982479191598, 0.23616046885088568, 0.10903030754097047, 0.12546360597855624, 0.163825711595916], [0.009565900508013946, 0.007806198461161507, 0.02998133546732847, 0.04737066375392099, 0.011419686770457174, 0.05760076440750592, 0.0074075612581274925, 0.07119903956810314, 0.026623231186080846, 0.03437439580598185, 0.047574550394089, 0.02594599413925842, 0.03915249768103804, 0.036114644965217, 0.08322813683339665, 0.046485081435211247, 0.03494165327039457, 0.08065245730141479, 0.02367114584382263, 0.03453093821242933, 0.03510710144896181, 0.05073061047662651, 0.05697831796902803, 0.07629391496940967, 0.06278829431281456, 0.0042191703499655335, 0.03673967311999971, 0.05212782844600659, 0.017587480758647286, 0.016629409285322312, 0.004982815890182411, 0.060317070869308334, 0.1310860248462808, 0.021387851429021647, 0.0098980120721183, 0.06001478406570612, 0.0286517170963869, 0.029485364399489858, 0.04443984884288042, 0.01040094496396881, 0.05058806449655564, 0.05984211167801292, 0.12907726570002495, 0.02964337960997176, 0.0836252308480682, 0.02358630543664819, 0.044573060041593934, 0.02658787239793568, 0.03209034679457545, 0.017580235482103402, 0.009995460371306587, 0.0453049804444515, 0.027656697202473882, 0.005592219202944468, 0.0967646729681761, 0.05791152031311105, 0.02855543133562371, 0.01941952257296972, 0.05213996710916681, 0.1121289033683077, 0.04780602769084996, 0.04079582139609322, 0.018235775003690394, 0.012098012619741983, 0.02992351306602359, 0.06636016010757416, 0.03271437137417736, 0.05452268441478091, 0.028556501943497892, 0.03658531789457606, 0.02414842628152861, 0.015324819964476892, 0.045481058092968124, 0.05155043180791601, 0.04022469518766288, 0.03279001872626043, 0.013544357892486357, 0.06716842883296552, 0.022930342651483034, 0.007082495308901754, 0.06339794708295696, 0.025838314735841368, 0.023545204819510543, 0.02541197531466042, 0.05035659486067392, 0.03647983524828188, 0.03417797469263596, 0.030383989365110477, 0.02332397777917645, 0.06354277600504218, 0.026378787851201433, 0.02479926585370014, 0.0680008982758849, 0.08404293262790288, 0.02292170501013677, 0.016029820995285146, 0.04183645224979809, 0.007042394436505293, 0.05936996019896, 0.006737842885476928, 0.09266974915179516, 0.06858995094174339, 0.01735821554076768, 0.08093202576762246, 0.01780417255846964, 0.03793126542962367, 0.01837405770446264, 0.03343359003925035, 0.07492361349924918, 0.027638291940093044, 0.033551728458053647, 0.09874365427681515, 0.021943489254842845, 0.06592284647687789, 0.030057168595733184, 0.06442018033516023, 0.038895574773872094, 0.09826444329754, 0.02117079190699564, 0.0399292150752679, 0.07353428240504957, 0.061537939228958664, 0.04313441586770839, 0.030292786597724886, 0.05454057639825249, 0.016445257070083773, 0.022864541444446773, 0.06815467510492572, 0.05371667181832656, 0.036574642459351214, 0.00877926802082408, 0.0944079413649536, 0.029327180649664615, 0.047610598661366015, 0.0061628397933447794, 0.01362473871033158, 0.01449937459021326, 0.07106592413038015, 0.11239790748203955, 0.02929370643781318, 0.0010063231621320631, 0.05193988409554286, 0.05026592069395608, 0.06545435306766341, 0.04319893579269129, 0.01767686598243252, 0.013577593659471362, 0.050990000186908635, 0.040078709472811995, 0.020402756204167684, 0.041024831889738, 0.01876846658095958, 0.054876279957111807, 0.07478852921556081, 0.03257719950089532, 0.016799191606321165, 0.04447049235985164, 0.0427371533136935, 0.02806041787769045, 0.04121300606657902, 0.05904443028773512, 0.0121428843046869, 0.03864670728122996, 0.060251888278270924, 0.016346140614440365, 0.050956625566487355, 0.02135784184980777, 0.008502665272493277, 0.005773177789148665, 0.06440458278502188, 0.030096974524278796, 0.017297981877721125, 0.014213024330655894, 0.026688838955916228, 0.024277062020114353, 0.0664773409164721, 0.042971530253247875, 0.012422306256579056, 0.02746606771383555, 0.032085348070869525, 0.02215011274412034, 0.010845461736373123, 0.009061287010779545, 0.04735069567217462, 0.04641287381790819, 0.043847298985647584, 0.03417323260838467, 0.04174679314957992, 0.09189369442361979, 0.015373342058381007, 0.04804292122923559, 0.03337624069723872, 0.155006691272701, 0.04214869436597632, 0.05962592166578097, 0.02120321274795119, 0.027790469560591925, 0.021436457792597435, 0.06685854626759406, 0.04157760263150258, 0.08432200313695977, 0.07485940767031524, 0.02738409630593754, 0.04895802091566786, 0.056442726748965444, 0.015105585710355833, 0.023415387390301596, 0.033206425817503084, 0.11968881222269229, 0.05275646487491266, 0.028443689750988158, 0.032404366234738025, 0.02147088961435422, 0.03601491946967379, 0.028085409581000288, 0.0362937256783968, 0.029811273524237257, 0.04283621997362183, 0.06086557067089504, 0.052487495235137405, 0.08582591800199402, 0.031171972082266887, 0.0839216455877308, 0.04875024637928413, 0.06266156804838008, 0.019899396218299385, 0.03462859144013736, 0.039394466551922025, 0.033116203642660574, 0.02873261789641073, 0.010538604260692674, 0.05966284710373129, 0.015445994006680145, 0.01820375252845547, 0.07790015619849006, 0.06267858669161797, 0.027453881170180057, 0.042683779968008886, 0.016739352478555614, 0.07133207839703368, 0.03351233238654752, 0.095736276538622, 0.018454991063223253, 0.04894382147599132, 0.0629861020453034, 0.05051266612304796, 0.026032368637501233, 0.02137594642267833, 0.040478415847305334, 0.026529000456174536, 0.06357037815295401, 0.07058051549979756, 0.052452645895461884, 0.01326181030186314, 0.036045497869171446, 0.004559821400400853, 0.03535858896230498, 0.04627249203622342, 0.04234870843168709, 0.015712754440403754, 0.044980366008296135, 0.03667738251087647, 0.024012552927278226, 0.04833282422154181, 0.060544012925557555, 0.0494338802602743, 0.02609124057926238, 0.05774838188963552, 0.030084653915236556, 0.02873900706969923, 0.05038380630374436, 0.06074306938136297, 0.028917601317047115, 0.06734634509250041, 0.0565803659358813, 0.019755005881550814, 0.06527021617418335, 0.10092598596407522, 0.026718781502436728, 0.053527995853895144, 0.05203156566788113, 0.05476101053758495, 0.06759766023606062, 0.12622935682415, 0.030023006819969708, 0.009589274808193647, 0.05475664000597693, 0.055392063973892125, 0.023930887954549927, 0.020533077336186846, 0.05270080858721368, 0.046785391731968815, 0.017655028646150907, 0.05852024994730469, 0.018925821040606788, 0.04675343820464708, 0.033312954173813906, 0.03710745278024866, 0.022743738954886798, 0.023277717559868773, 0.028017160723045952, 0.019695547882527597, 0.03770656418055296, 0.05651881460160498, 0.019494874981201945, 0.0226635238035552, 0.05082315006743997, 0.07032900883425629, 0.022416933507267988, 0.008554315877958171, 0.04135841721548669, 0.06262990563446957, 0.02414099139822347, 0.057238787863283395, 0.12174948148669736, 0.021101807604633996, 0.0085389471965872, 0.05110110591856703, 0.04797195084393025, 0.027001701603313128, 0.05300113420572974, 0.01213453490392215, 0.0286772565525626, 0.05142697673891822, 0.029795448062941435, 0.04834028974836392, 0.01610900958879821, 0.013625702065896365, 0.0407047220505774, 0.07117476990266193, 0.06339653365073666, 0.053057357398492676, 0.06270403613246257, 0.03933274284786275, 0.042054626429753925, 0.07133023212513617, 0.009159203581211549, 0.04694407152372503, 0.028313282434077516, 0.04783711170837764, 0.06025230579618966, 0.054928772301683505, 0.028151747049583543, 0.02370460090347596, 0.05574729511394136, 0.08034706401127963, 0.14428795675837225, 0.014648773226766817, 0.015639771159077366, 0.040805922265374855, 0.03799170593640978, 0.072862530547765, 0.10236790899427668, 0.1414015672860607, 0.0918136765399287, 0.15767650768881844, 0.12001532655689987, 0.10107946401882557, 0.0752316804362401, 0.1779848856911544, 0.12368112622249512, 0.12978019733582774, 0.1368627108393177, 0.11237918429317013, 0.13484052983262848, 0.07965597609478621, 0.1614027133872432, 0.1561124012955735, 0.2701093641019637, 0.168750002199123, 0.0768672781545789, 0.14781324823777522, 0.061232599564978195, 0.1438651987982373, 0.1221961873553453, 0.14207898819398496, 0.1604469267711524, 0.16302521100207684, 0.0862400574729808, 0.1553417628090228, 0.1340471078912097, 0.09199755296351449, 0.18496368621145526, 0.15644825424157804, 0.27017874102438655, 0.15334388211129174, 0.18965061213220322, 0.1546982336308687, 0.12774719916764768, 0.15305106798487325, 0.15872715131169365, 0.1077723681866642, 0.10879277431916808, 0.17418326629746347, 0.2876940237418298, 0.10308012561572176, 0.14113185837143852, 0.13131908411460538, 0.13986698592141752, 0.10258941565670314, 0.1338049628201031, 0.19778675700147308, 0.12389450469204497, 0.1848720927392283, 0.12070395533115634, 0.15745757508181757, 0.1128989136627605, 0.14759157303600542, 0.1460441367159928, 0.16015935268613601, 0.10735737069720223, 0.28828624035081557, 0.1533957769072825, 0.160195573323196, 0.0931247594135423, 0.10927802973216581, 0.14778744639648547, 0.20175271757668067, 0.09649246660692078, 0.1386124556583743, 0.20468505700269055, 0.23065448768677252, 0.1235216956645731, 0.08488454149975892, 0.13139840485828538, 0.12273908322376591, 0.16822575291077937, 0.1184227446755094, 0.1307377612759029, 0.1375009080455188, 0.14940160897470292, 0.2299776643274292, 0.13436765440048712, 0.14594445335528544, 0.1858064748587147, 0.18055219954300314, 0.14928113398773057, 0.14846650673256767, 0.23813257835084395, 0.12876479375746944, 0.09335805616912343, 0.2229492825966689, 0.13680632676809065, 0.13244132631488387, 0.12823117521381186, 0.15610927565684243, 0.11453646490530622, 0.1877331859882801, 0.14931099609501902, 0.15695684469274937, 0.13145060608944586, 0.06675482562352573, 0.2047288772319594, 0.22990061120400507, 0.1332380117908601, 0.14504581689834595, 0.10929024883455808, 0.13560851765496118, 0.21965030881185688, 0.25813850484067397, 0.09968023506864425, 0.07217623068079834, 0.09851994894204602, 0.2797809789978689, 0.10776078493724908, 0.17052173374160645, 0.16332671256555667, 0.13578442676413444, 0.10408488057193258, 0.1974058734072793, 0.176233317582838, 0.11139313720407025, 0.12442685152974822, 0.22014225983331281, 0.10321458936819147, 0.15390082803224364, 0.16653822975293284, 0.15549566987301075, 0.11112343595032731, 0.18090492174510034, 0.10838274874033467, 0.13229895653503557, 0.10585846604719278, 0.276904012407026, 0.07506861862155699, 0.17535502842116743, 0.0941225506305214, 0.11362956235966376, 0.09708678229681908, 0.1049567882211939, 0.26038344889398546, 0.1210892745744317, 0.15245135903598803, 0.12769790907059947, 0.14118131700783007, 0.2939382225515381, 0.22535201011886521, 0.08277596109696934, 0.1251604956304354, 0.11700212655048217, 0.14881403485853828, 0.1228043692366731, 0.10854558838951973, 0.1355179660623112, 0.17148933343348965, 0.16165161535384195, 0.22124921091862265, 0.0775418798589418, 0.16686101323894917, 0.18098966639128425, 0.10846239124094287, 0.24575294686421273, 0.09166862545234543, 0.09953079429725487, 0.12141801822449892, 0.14371044903753266, 0.17237988000194873, 0.19378445321513763, 0.18767326259084288, 0.09073600533508486, 0.15901541487584192, 0.10834895660199466, 0.26727955788373947, 0.05861885695447845, 0.20763268754366906, 0.10541867029162184, 0.10784341518076197, 0.1965074820984756], [0.014234045783298151, 0.014540072053580757, 0.03854542662720046, 0.07036375858250164, 0.02669911411020064, 0.014111812624539581, 0.08505495775851511, 0.011730132410452973, 0.018653972825456052, 0.09104784908554248, 0.02902812673710287, 0.027268033985409047, 0.0556019950477827, 0.03433210009168233, 0.03291289922931502, 0.05442957408846386, 0.04967332487144778, 0.0472071920821984, 0.007986429263837636, 0.04049682110968617, 0.04255573986278426, 0.06578845167232138, 0.03204974221936878, 0.05551063523237264, 0.030773491448452397, 0.003269191398548203, 0.03496289688853487, 0.014039276547038989, 0.018944603601290334, 0.03318781754182231, 0.07840706125622796, 0.03438419024009378, 0.0689229310580319, 0.0590150929506748, 0.10799192132488375, 0.047778099955570315, 0.09037718507311038, 0.03285212164384223, 0.050728220282302755, 0.015390342507030697, 0.04145775200618852, 0.03365133137952897, 0.03206808427949587, 0.03774639692217593, 0.03283623298029265, 0.07220479043861551, 0.04120531454381924, 0.07599786029107149, 0.08756611736551409, 0.06591365342178652, 0.05638921550745445, 0.02785195386217487, 0.02152789038636031, 0.025650025645811713, 0.018307157161255038, 0.05821397182561698, 0.024336801556449746, 0.05408393436922662, 0.0762657688990716, 0.0159379641803342, 0.04997358537249027, 0.04551857341862014, 0.09688201465553815, 0.027676780197408893, 0.07377023748572796, 0.007223876356522763, 0.030284775233256723, 0.028775700766052452, 0.06565273919653508, 0.0719774385253268, 0.04539050650031817, 0.020231525976991942, 0.02069236616784286, 0.009662404603835557, 0.02404758804327538, 0.06276727669061193, 0.05279006932171122, 0.0393527607253242, 0.08561399509950031, 0.01815824307531359, 0.031454332938958565, 0.05701665683919865, 0.13842969772315797, 0.08271405353180825, 0.032135331477489204, 0.04802068935767297, 0.010757195000957337, 0.0361812409884747, 0.034549937192951484, 0.03051270171248865, 0.051181031871707215, 0.04155853087262761, 0.01573061865318807, 0.0469237165675769, 0.03001479244220161, 0.02590037551858733, 0.06275087091771346, 0.010672502065708321, 0.026321279545945507, 0.03866392510732816, 0.05919813050798351, 0.07756939007630272, 0.04441997269168497, 0.0345065574642391, 0.010510823997338454, 0.03494064586477415, 0.05028290486323738, 0.054488570519512704, 0.11406256291534632, 0.034422061796630585, 0.044209681556469975, 0.04978629985764142, 0.021173524925665512, 0.09279364089090979, 0.01809730652659651, 0.0193582393694669, 0.053322320398423946, 0.0315863145665536, 0.08857701634687763, 0.019939627325642976, 0.13758860979109042, 0.04089179689124708, 0.03493965761135182, 0.01873741129172906, 0.068888763536609, 0.009616532216539547, 0.028344218979679772, 0.017476913203755697, 0.052203092754127524, 0.10908342807764008, 0.027048996041318583, 0.07516554406573696, 0.0004919727771559866, 0.023276386482100335, 0.015646194806322455, 0.021732156240050832, 0.06247183488261315, 0.08948669979168523, 0.042678049630335266, 0.04786531906574965, 0.07675435679453997, 0.04311160176932331, 0.035226297069100604, 0.0023593494693012608, 0.03498849954696433, 0.062430067768981384, 0.0541579537844706, 0.038795795652174184, 0.017169847926725785, 0.049407672392384666, 0.07430641476305262, 0.046705664961688945, 0.0036075702800806016, 0.006818152361384203, 0.022156377428121144, 0.04829595624018581, 0.06769728230973406, 0.129680912340841, 0.0811542448918185, 0.010882913859771385, 0.015584758385234784, 0.08779073434491312, 0.004661733119357979, 0.0729174590519359, 0.05943279473050948, 0.036093290264327685, 0.07884209960578911, 0.0861376315175045, 0.03302425010910919, 0.08488472536086075, 0.02798984202766611, 0.021876740014000286, 0.08059394350575824, 0.006843983888581035, 0.05759637089326017, 0.09329614094308308, 0.09359299235286252, 0.0391245890979565, 0.03242218927029641, 0.030656730072693, 0.040330882634847395, 0.02286673628634984, 0.08041054971756474, 0.015211836359794102, 0.034162606968874895, 0.018774549319078366, 0.034504703531462344, 0.06580459314488596, 0.06191067930851733, 0.06815949379796944, 0.0752223035200469, 0.048348636276298956, 0.07344736973003996, 0.03993559658767716, 0.044433543939263596, 0.03817360202271131, 0.09245752747501097, 0.02334812487054977, 0.03493716399515829, 0.012532730169984843, 0.06114824945407529, 0.02059384151512096, 0.030393900627630855, 0.021441106031078006, 0.05318881808629921, 0.04934725103779666, 0.0492029698685773, 0.020428159679736824, 0.037106453035507476, 0.005663598966484349, 0.021005820618161274, 0.047617796057414626, 0.13885185813471196, 0.06077436024263021, 0.06319271595848185, 0.02672392003718884, 0.023336951478174137, 0.03491802328837014, 0.04865795576704606, 0.061265150640880874, 0.06306924173728594, 0.04115852955428343, 0.042323588408649936, 0.03917805054375241, 0.0395415247898669, 0.031094459306088187, 0.08503368349685785, 0.044962788120873516, 0.006934946295880383, 0.03389878927039043, 0.015486581344908525, 0.0526490172130927, 0.034941032739175905, 0.03891840802445527, 0.03876601398411778, 0.02923134879599656, 0.03744703657444447, 0.05512366123918084, 0.095220691704702, 0.007652532714869708, 0.05127021599741233, 0.016418359723062288, 0.02765404462303606, 0.01649996532397645, 0.03395583217723235, 0.011100870662278706, 0.02909546586564712, 0.019659298517170454, 0.02037808051212661, 0.029259431664080873, 0.023132988229213704, 0.04756230830905899, 0.09590829392113993, 0.06015501646024566, 0.021076587990166682, 0.02496697207642419, 0.028168380733639486, 0.04030963135582786, 0.0709145221739046, 0.07569503339548266, 0.03481763512677243, 0.09354002503377777, 0.06239453278061363, 0.034220806668482484, 0.028636165511524005, 0.04109103720815432, 0.015727653892921106, 0.06407919460006299, 0.052043673687524376, 0.045877661811368126, 0.029340728914605516, 0.07256564849446859, 0.015374798583047045, 0.013351042308063518, 0.046286829371726325, 0.02577954621595, 0.013990804248849952, 0.047547526642560005, 0.04038535148626374, 0.031507675641126213, 0.06057539954781533, 0.031050074086975188, 0.03144487749875313, 0.025486356706448623, 0.04306105528807929, 0.04952723956516674, 0.07550760998480743, 0.04027201260830607, 0.05539895876521065, 0.047525681645399144, 0.00929277292602966, 0.04037769443746056, 0.03351575679956906, 0.03774812062000556, 0.07079602369377691, 0.026785528828059475, 0.08040616769463786, 0.04437851967410215, 0.0003050860469820985, 0.007564884116647826, 0.04036890740896906, 0.030663377800655943, 0.025169309303765337, 0.013817238411115063, 0.044990773312747485, 0.020625448387656963, 0.010754121073161163, 0.04970221021663278, 0.0009950073252830115, 0.02140110283489189, 0.027346586725944956, 0.03353130455399233, 0.0839223274059834, 0.042647999831505363, 0.03095832739716336, 0.06759271896894901, 0.015624328741743682, 0.05751388237601327, 0.015868215705268085, 0.057248923206521626, 0.06974193267524242, 0.036767213980877594, 0.01482310898286561, 0.07496675191026542, 0.03106329676454827, 0.020501799881458282, 0.058482539269231984, 0.04293979889142417, 0.014505920811526239, 0.010034986677759839, 0.020631701580338904, 0.01567388409673567, 0.0537121327473752, 0.11636598245991815, 0.04430176532496849, 0.02124806145025838, 0.06781751214857064, 0.0454070846429996, 0.04466216372806699, 0.04853725478413606, 0.05067762017490403, 0.035413391061968384, 0.04030010888292905, 0.06611718766150937, 0.07705476285228807, 0.07105426427217261, 0.040123452838029594, 0.015601224487557288, 0.06642248902109361, 0.03609118352253591, 0.007639144370783001, 0.020423465475980795, 0.15432635923066448, 0.12177473940556088, 0.14460491797616407, 0.21881962435380106, 0.11569567084793123, 0.10273216081963432, 0.22616092235811297, 0.12698030685104672, 0.14418117942348604, 0.10934173760394897, 0.17252906796432313, 0.17778441580312868, 0.16556332158225198, 0.10550798848271371, 0.22635134117257213, 0.09608972652424728, 0.13605039716968614, 0.1022021122457039, 0.09755084005695197, 0.12574855238199234, 0.27990343049168587, 0.07770121848631291, 0.08469181676064769, 0.10306051376486018, 0.18669265472600538, 0.12633237266732802, 0.08762363524686906, 0.10700856320439808, 0.12548168565356924, 0.167710819251595, 0.14145070416552408, 0.12310645302697537, 0.15134368782802937, 0.07055289036924801, 0.19986264077165436, 0.08929533868907921, 0.2278879603310939, 0.11815323494374753, 0.11969512478718836, 0.09620050283809824, 0.09448320184263492, 0.18316293525840008, 0.11603346199638422, 0.17811763340667372, 0.15926267741428268, 0.21156209040312998, 0.11582555339461374, 0.24423601616534496, 0.15107943345942806, 0.1863923942249629, 0.15795234530683488, 0.14659414188035075, 0.10683405603612624, 0.16653815314414042, 0.10873614509980525, 0.11383105114462877, 0.16509562490447877, 0.10212239313630328, 0.13677228182073564, 0.08734659487081152, 0.08839189119997526, 0.1388703514972041, 0.37009186682201206, 0.11737282883616225, 0.1565396638527032, 0.054209802615185904, 0.12022135824325586, 0.09691514795826328, 0.2048174676395232, 0.1981449950366251, 0.11484977188369921, 0.07690601922090977, 0.12749661946849478, 0.09717947127477777, 0.12486424176923691, 0.15521944921103217, 0.19404679236392822, 0.12390827129204428, 0.16335769316121457, 0.12115448397854645, 0.13378283820084988, 0.1249114710897688, 0.3006494592034048, 0.2261812390098649, 0.12113543903274883, 0.21544330633215367, 0.17518431338812077, 0.082332082092762, 0.05013330704382351, 0.1959514861265498, 0.11450251188850212, 0.10071511260203778, 0.11475554306901271, 0.16298954194832235, 0.057332675768843586, 0.1269270024532753, 0.24678537291624855, 0.12826076919032683, 0.17188636616112726, 0.1609162628770836, 0.13713710821203648, 0.26352606413345186, 0.1645676983940986, 0.12175818424551718, 0.1256293337792158, 0.10694768985793476, 0.11929026264096461, 0.19408230820009786, 0.2852925526038293, 0.10445330757647754, 0.22173376153073004, 0.1630451599316251, 0.12162653969660883, 0.17851589187499017, 0.06327064625257928, 0.0833121536960525, 0.09762100604993683, 0.11018474841670645, 0.27006244887748077, 0.10912519519127185, 0.15328965840801118, 0.10179792425685352, 0.09619454267404734, 0.058743802064488974, 0.15478492414038028, 0.09677524498153119, 0.14711289065739802, 0.11421099245067566, 0.21202627839821003, 0.20055250294746893, 0.11988301551149738, 0.14271890143713645, 0.08097992924552772, 0.09524941234098327, 0.12486432603890858, 0.10218383338783057, 0.19363898844007524, 0.13908465693314231, 0.15033033736530813, 0.23452923783371527, 0.1428150914369091, 0.2217433069862666, 0.09146868416498746, 0.11676257851743892, 0.11444328563107599, 0.10503752622753383, 0.3167514322746185, 0.14887614926743895, 0.11432058898912323, 0.1512428093701601, 0.17654105510202148, 0.12833421403962758, 0.15178066438003895, 0.1174173998315969, 0.17659475786551354, 0.11840851076187627, 0.21606002243295794, 0.26674139643869094, 0.13686755251499916, 0.07061588577926159, 0.09849274515985482, 0.19926663968832264, 0.11707626853979404, 0.2618572488427162, 0.1659463961879092, 0.15455595578157133, 0.17806276618953676, 0.1541338566570513, 0.13721517257152066, 0.19680982635867214, 0.10766120882885111, 0.11595188129332759, 0.22842166314442314, 0.10379075643516357, 0.17264454805802915, 0.1922317002449305], [0.01505745240607329, 0.008795797325400336, 0.09173136805334399, 0.014385119279576166, 0.07329140955041494, 0.06945079628137812, 0.005796350991248244, 0.037219592730604836, 0.0301191317022688, 0.03844356757678813, 0.03706310011987244, 0.02763364178639266, 0.04875177089425345, 0.04368072848827128, 0.04450888868661658, 0.058827596761646776, 0.01557125608556934, 0.017699444508780877, 0.04148773285710523, 0.012584106899016808, 0.026385720946916172, 0.030437353134696043, 0.017053245514210676, 0.06460054807605282, 0.08649320356668004, 0.02400284276283797, 0.02297319377952766, 0.024207198631859595, 0.029322239382553007, 0.05219985986308706, 0.06660957535308215, 0.054351490576781576, 0.021830443405516205, 0.08429777943679402, 0.046521642981397535, 0.054513491359689546, 0.04894534599096064, 0.04317351316492404, 0.09758541360497476, 0.055285642869890704, 0.044110373578845494, 0.06215074062046986, 0.014590719083864844, 0.03176499308357316, 0.020027528254074917, 0.07084950429177092, 0.02878315671677551, 0.03726381515603393, 0.04133540393424131, 0.021002875010092414, 0.062006654803671186, 0.07708430320264832, 0.09278039523069898, 0.053142914097876325, 0.07410078144241726, 0.02011464394238447, 0.019525302078334555, 0.021848716517730106, 0.030098439667433984, 0.030235839451873497, 0.03015767550095916, 0.03085939480262178, 0.026493932781440598, 0.06203673524601806, 0.07296810512461009, 0.04804898864559589, 0.022351565139908946, 0.07005666457717458, 0.021610880691197612, 0.018184698006558805, 0.013044187705212784, 0.0363240244558021, 0.05645391163265994, 0.03928823313946205, 0.07814990852268473, 0.03864919323654425, 0.030777432970822822, 0.04491133765587884, 0.058070050717722026, 0.036844925939916603, 0.08925959302653229, 0.012284585672821249, 0.008600992657574675, 0.06219119772375111, 0.07009296948390623, 0.02976157548536937, 0.0734708579857984, 0.08679016222876888, 0.030950402217586676, 0.02632286726316858, 0.07747267147586231, 0.07526247717079616, 0.07481721154744587, 0.011915981510443794, 0.03582077363746301, 0.00859581581842635, 0.02419267743525486, 0.04617385821597231, 0.052343428570536844, 0.04878174408429092, 0.07525112374775833, 0.02975973304391148, 0.0855566840618849, 0.07470609049402899, 0.03918930820579972, 0.066632098338056, 0.0686635643303875, 0.01763223561518375, 0.0287229479515865, 0.04168494304101314, 0.02374114712790376, 0.016862148711938533, 0.05067271338174901, 0.04628638887116986, 0.025529075684326313, 0.08805379361635254, 0.04755421459013897, 0.01702425100149647, 0.008042504984675156, 0.09528344962745906, 0.03288263492586632, 0.05471852713174397, 0.04047277744018263, 0.018479147730695627, 0.013676511889864362, 0.06780612042113658, 0.032972075691026066, 0.05500610887763962, 0.05026807340102331, 0.056375150133164666, 0.05207594897177431, 0.02936944955088679, 0.026989942153675422, 0.055993937121163455, 0.06385366214559444, 0.02928256177373471, 0.012740938503655696, 0.012759304504030415, 0.055088176046528166, 0.05719363847146592, 0.041302764758227334, 0.03229584221938445, 0.04499351590751641, 0.04537785455824868, 0.051461462186829704, 0.036379623286906755, 0.04174888840005283, 0.027080455441929163, 0.008710293294561487, 0.02747114687677353, 0.04560819421444209, 0.08583562433599465, 0.028971024458446813, 0.06322817816849678, 0.027266197289610584, 0.05533589057684426, 0.004598429837759825, 0.014441996519904465, 0.022759719548987287, 0.046879976777540106, 0.066087769885217, 0.03515320462024501, 0.04178928804673976, 0.0935998794833018, 0.09614491549831244, 0.03284324268479982, 0.013253434088021038, 0.030635735433128093, 0.03000413615917487, 0.030717157172940435, 0.008768356055952609, 0.02851828564739516, 0.04209588026447643, 0.04441632611316539, 0.07316718073261362, 0.015766551049666542, 0.025359839200973514, 0.020983029502413927, 0.04231750567053114, 0.053891902939686855, 0.03101948228093886, 0.044202905508779713, 0.04725288922688173, 0.05829741795276923, 0.026108962108170795, 0.04788305017075712, 0.05046669318671188, 0.03684273875889279, 0.02559481177388901, 0.03617888143766792, 0.05305558390494797, 0.030036737030792623, 0.10119212490897025, 0.02481436544668771, 0.05729836269071507, 0.043464496341203494, 0.02734457766036353, 0.07038380710348006, 0.06368548669401677, 0.02976462068486839, 0.006592539946488556, 0.01430778940688939, 0.03878852930821238, 0.02142119923636558, 0.027473772643134, 0.04060697306187884, 0.08228533540762241, 0.03458892723785774, 0.028936418351687254, 0.07425818186733993, 0.043669306117320256, 0.031644089087363214, 0.0278497226310954, 0.05210586853565709, 0.026182516125000777, 0.058583999953923695, 0.03837687579253989, 0.06078638782304141, 0.03943198187757404, 0.16765688666172568, 0.07473779121233572, 0.023374091420743256, 0.04144996089199859, 0.0313831269816165, 0.06929337287381773, 0.04301582545702977, 0.010844141192313646, 0.02571316086687148, 0.09188530576084891, 0.06097316388942062, 0.03423356586286137, 0.024559438198564515, 0.006095392933686174, 0.025649565993057146, 0.032505980137014584, 0.04184036312865154, 0.018562978817029827, 0.030862305936734044, 0.017611160536386797, 0.0666136662625978, 0.05634910314373913, 0.0363304327812887, 0.01151044999489621, 0.049838420649569844, 0.02113276138721455, 0.02929395350116876, 0.028142318422455462, 0.12111390430119731, 0.12195309233521262, 0.0693110312004724, 0.01576184918503127, 0.020964503581185016, 0.056829662437761025, 0.013212344004592348, 0.017285094363614917, 0.018525417526102355, 0.039620117750018835, 0.030793281414756374, 0.020119788222796014, 0.045552557078941215, 0.002121048962562195, 0.03881865188539509, 0.02008994909814529, 0.04045458285198097, 0.05770324781957654, 0.03720547756059997, 0.04510320437651488, 0.06953883510563644, 0.06000429632202272, 0.0719497521077433, 0.01095103727082812, 0.025428595592177687, 0.031788301308669394, 0.03311872790237108, 0.03326970851048827, 0.006217056793356014, 0.07037926420208908, 0.03649985695618295, 0.02106361237594918, 0.041623012493214304, 0.023657036419477195, 0.04353409542912438, 0.02163420040761271, 0.01456201281173215, 0.0473716673291018, 0.06172752300758035, 0.012994796101514612, 0.04923336823741275, 0.0094751889945098, 0.14785345253204146, 0.01518714630360445, 0.014092123207275667, 0.040876164867152134, 0.03889472824671576, 0.01550519345102892, 0.054133603679797346, 0.019571487604069616, 0.054226024526982546, 0.017240320354880347, 0.06550078565675406, 0.03145383115136816, 0.07146317136263655, 0.044778030696174795, 0.06094447772709593, 0.033174905129858566, 0.07426078656628247, 0.016543708944452867, 0.02941808464275974, 0.056601452505997116, 0.021159471042694587, 0.026047173286637953, 0.09312836002678641, 0.06210913438530219, 0.041938598583182024, 0.07856475279456185, 0.041838903731155785, 0.013788246771230573, 0.043148366328809536, 0.03625963859620594, 0.04564868579167993, 0.03873172005818736, 0.03228441984843343, 0.039289083497058, 0.010453575204366879, 0.011094849211193863, 0.06308609950205972, 0.04981060782747884, 0.015923150912708333, 0.04538474551912758, 0.03754018137471811, 0.03286454758997406, 0.050943180723416234, 0.017885312760969805, 0.026856780750676993, 0.006084084518313889, 0.03489250873005198, 0.0667045625948137, 0.030073654807863698, 0.0372800255765117, 0.10002008699361356, 0.008969732800558692, 0.05542346208746876, 0.04336648305217105, 0.007683022056646165, 0.07713088134844458, 0.02639621060581938, 0.039689755142335935, 0.022839637841248227, 0.07918799596448099, 0.04510019365097246, 0.04606665953272774, 0.024554525659750068, 0.09333789273495637, 0.13181760817045166, 0.1580483820890227, 0.12027784190591305, 0.11849611291601775, 0.1528860832895002, 0.12285581204078852, 0.10718608109821236, 0.15716451580726332, 0.1734007687698449, 0.17453316929599932, 0.20220912211845, 0.12231857756212836, 0.16727584984994706, 0.12318247959258095, 0.17784303685109462, 0.16023675821000533, 0.10940182187985029, 0.15526895381269917, 0.10385022784072546, 0.1399966692852397, 0.09672872046188963, 0.08596798900755183, 0.13253854287247505, 0.14420299760756955, 0.1503532433942441, 0.19211925385940462, 0.17950547829030022, 0.10100742877130547, 0.15949297876607987, 0.12464104971337704, 0.1417199227838747, 0.10679052692026862, 0.18325834384848996, 0.15619463317336577, 0.12563347065400693, 0.11732281861646522, 0.1448631815371975, 0.1496043158394675, 0.1380334770487201, 0.16781961905860132, 0.23285297616835565, 0.13343684225072786, 0.4184018309798933, 0.22023573788183354, 0.20123239065850937, 0.1110992352327993, 0.08242356065180033, 0.14816575593525363, 0.19244143979684, 0.15352585863682533, 0.10056852933860595, 0.22186672375086816, 0.19035262446249687, 0.1303019491775382, 0.11067289198117872, 0.12616195640857183, 0.11578313510624633, 0.1680752013118998, 0.16730908274410233, 0.10956342812747726, 0.0818588772428132, 0.16340551236944814, 0.1669931174406121, 0.15188358063178678, 0.14663909591974753, 0.1677132860547112, 0.23805140367438718, 0.11377398525514912, 0.06954703224642624, 0.06070551192087512, 0.17829645364995927, 0.15465856559814947, 0.19655792132741023, 0.1348498761053047, 0.10463557521542234, 0.11064279238663374, 0.15396608340163387, 0.13912242506780934, 0.17506132563275678, 0.18623249635340708, 0.10600586902470359, 0.12706398663501586, 0.209959710257188, 0.10142539102103441, 0.28960899840439525, 0.1862095750027126, 0.1926426604510315, 0.10130149928191978, 0.13870280806816396, 0.14516445327430003, 0.15441245219159513, 0.15109725266454682, 0.1575232441386869, 0.11187506013459737, 0.1137639954686165, 0.10395738821957382, 0.2176557376139587, 0.15006317186259455, 0.17793194901558662, 0.2541834840010251, 0.16233753983772573, 0.16688200404807446, 0.1440544225155346, 0.1483093361340223, 0.11348104855466275, 0.11715830889560523, 0.10905310631759706, 0.12893215332540775, 0.15570989870015653, 0.1054711013491596, 0.1279911598671348, 0.13965546904552367, 0.3172615855451553, 0.06635727195609963, 0.25597136467695236, 0.1504446223618523, 0.15839568038861598, 0.0484514108017808, 0.19071882981206142, 0.11518983831328732, 0.13121060606452728, 0.103664658362827, 0.1259142342173765, 0.07232870516036788, 0.1694783679540119, 0.15922418915696684, 0.12701818223802314, 0.18123349685582424, 0.18167451835207402, 0.09374941984612135, 0.11383632182954781, 0.11627042831312265, 0.1493773546310202, 0.2161731276540987, 0.16825517068707174, 0.14232045910771818, 0.22993010558908988, 0.2281907795658035, 0.21284579329432982, 0.08824674818184107, 0.20619541466716798, 0.19627964754979457, 0.11383991478191269, 0.1295438898547042, 0.15559447989348443, 0.10881598678327377, 0.19531973938067115, 0.10040897620661605, 0.09497755071929387, 0.12178128945731348, 0.19979357028440123, 0.11501350019487644, 0.1340532672381209, 0.17044972147672408, 0.1235283146642389, 0.1418167103322283, 0.12516825610110838, 0.13467965136852958, 0.10313893052478952, 0.20393741647562674, 0.11557069892484335, 0.20822842815710654, 0.2630620293559567, 0.15669694170355797, 0.19247373806372767, 0.18955434552363812, 0.1266182766806695, 0.12782688763353134, 0.07638281947302242, 0.12434498737415961, 0.12430964773821256, 0.19681806946473737, 0.10234768427307568, 0.1856364646265584, 0.08084218663674209]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03545416226129859, 0.09128952684301524, 0.04147963147730597, 0.04546474808106019, 0.007269681711125398, 0.04408010161451755, 0.002527305867613083, 0.05065026317512797, 0.029783200232252, 0.01380861513391738, 0.019310521667883284, 0.04448068132924457, 0.08878710829923231, 0.040259667101406285, 0.05170929929121368, 0.03058768065285779, 0.037692311114721724, 0.03478509937262824, 0.014967954184319225, 0.00886885817312906, 0.04718966399049086, 0.025087663483235146, 0.025754485564726978, 0.06124633169102092, 0.02202760570892884, 0.026445812883696733, 0.023653952915581967, 0.012620023973736794, 0.007641564251013822, 0.014907402594784095, 0.02501300438457439, 0.03714432459204428, 0.0551406032736263, 0.041093090323791395, 0.009940693703209682, 0.027045719100222475, 0.06149883427086377, 0.026271598744055918, 0.03345266179812532, 0.06266231881454587, 0.007007112735957509, 0.09413897555561797, 0.005892090435560432, 0.05668208326002764, 0.08619317289201484, 0.01972103945820803, 0.09376293363710565, 0.07898828450350032, 0.06467809149574849, 0.03553881114649196, 0.03450724311293133, 0.040591551711963075, 0.07246160609347206, 0.023157752021366072, 0.0028430482873978515, 0.08013006960672718, 0.07261722153353115, 0.020430544128401146, 0.012053894573792577, 0.07710973732173443, 0.06214193060934063, 0.04815588089367075, 0.04479037237263495, 0.12163323530506705, 0.05617160057168334, 0.1150098076510814, 0.06029130350197516, 0.06142348569307116, 0.06622903649845431, 0.07090895271469509, 0.04044011145109131, 0.03159637521621922, 0.016614369064148878, 0.018054306011406646, 0.05773551544294723, 0.04906904237765459, 0.011080737871628617, 0.05853919530167215, 0.04274541940239649, 0.04939054266639775, 0.06703081645912702, 0.08755438089851411, 0.044870129786431796, 0.04708970866857037, 0.06092445218875524, 0.054328193843004205, 0.059473569760279316, 0.04045369035954918, 0.051990913212179184, 0.04775009178105862, 0.04643071600566468, 0.04599247923901966, 0.023624443208738685, 0.017174580434878028, 0.04870749101223004, 0.0126770994393155, 0.035856128595168554, 0.051780775294549046, 0.028369053634965134, 0.03088195992243146, 0.02059364807792008, 0.03240679856389761, 0.015408064035939114, 0.037833742436862765, 0.01959223134983932, 0.04326049095740722, 0.01432958460833517, 0.021413992264217908, 0.03636427854578342, 0.02892704526593368, 0.007283299881589389, 0.02775193533800062, 0.05790403563409083, 0.07602069737209428, 0.10266409390756201, 0.02414075391096694, 0.012977083191095341, 0.032160217843709454, 0.025292904183809316, 0.013574963105061363, 0.06145607890380968, 0.03159972302044832, 0.056416043906562754, 0.07987261809889348, 0.05899067389808836, 0.06318343480327918, 0.07973261553073123, 0.05739699268052655, 0.11929241534803184, 0.03247474673234167, 0.01893301269099597, 0.03201095327254265, 0.04170269329821871, 0.036329528797538056, 0.12421837602291377, 0.013539050818390906, 0.03162623923872748, 0.05448750182685833, 0.05571703081049266, 0.0316899202974333, 0.04446540553603442, 0.04212437107438042, 0.017501002838534695, 0.04342560205728777, 0.07041956808778548, 0.01869988064431856, 0.0388938395847236, 0.014752917134413316, 0.008397980315250256, 0.07168956566601992, 0.012232503185289042, 0.00413992429985815, 0.022853151632232532, 0.0839963851256236, 0.09827213482029977, 0.011166241902467466, 0.03352359004859482, 0.09711796973621654, 0.083218177690381, 0.03357509030930458, 0.010710944357748714, 0.03843599862809624, 0.02509313335101451, 0.12610367243929257, 0.043041673263594996, 0.0371655720406242, 0.043814207817758286, 0.03521253812998053, 0.06275522995800262, 0.05332677903014326, 0.044093826079681035, 0.024125855416059497, 0.012201355965507608, 0.033866395242512226, 0.02537567232314858, 0.051038099017234585, 0.03692401685721932, 0.05600380433362819, 0.013905302133230914, 0.01162181045078943, 0.026667028432711962, 0.06123438454984177, 0.03246727354464031, 0.02015219374199308, 0.02872158431508128, 0.029444208240977703, 0.027301017900988944, 0.056072530081315394, 0.022527045239844633, 0.08508509565745631, 0.025335360776572943, 0.034038964208335645, 0.06312646850522968, 0.02398908190849808, 0.037990847917934584, 0.03893873233708643, 0.02528427611856211, 0.022440278121540626, 0.06888643462931918, 0.036973866198452256, 0.08829370171072022, 0.06725950136540398, 0.03721750897145079, 0.016655331785460154, 0.04184075383349292, 0.08434373705137162, 0.006880190161492436, 0.09724894012775152, 0.024070248924075596, 0.0725264018101077, 0.037784525118167364, 0.0630889761622154, 0.06930722374348872, 0.03806513929439168, 0.035275085378558405, 0.02561715664342046, 0.025828637130137895, 0.043574904932850794, 0.04066140743933859, 0.006871677488238821, 0.0776893517843658, 0.04861718839815548, 0.01670402624914723, 0.025752905508383148, 0.01923447211963996, 0.03627478415446897, 0.05885171703994275, 0.02783106647491936, 0.055808191443042415, 0.020997634968690334, 0.03255601333934934, 0.014245985263598063, 0.04879268765028927, 0.004628374778305091, 0.03929079570356877, 0.029624520440495787, 0.023425388668153076, 0.04327291307309943, 0.03902466058911335, 0.0574887776747346, 0.08407556797347723, 0.06863348771848025, 0.01124323661168737, 0.09208497891743338, 0.07730929556513026, 0.0035140074830832743, 0.0515846835990106, 0.006711948156026343, 0.011919068844778644, 0.024475088087661613, 0.12637785530739254, 0.06296716052137556, 0.03250110015693692, 0.07261960406697567, 0.020087968760861025, 0.04048571666522373, 0.053523112043377855, 0.056061728241583036, 0.035011849906896396, 0.07078010438671035, 0.01371304375014358, 0.018758109072223306, 0.035878073183759567, 0.050066048354511304, 0.030859814235760324, 0.02061658283515323, 0.011025558473662505, 0.0468514476632399, 0.050014563415560036, 0.09246274453377532, 0.039621603960591945, 0.05713114484904274, 0.03322927055940513, 0.02811865588169425, 0.051695502047697385, 0.027421205604989684, 0.09209970312733805, 0.006524112494286871, 0.050263538160511566, 0.029396689722254395, 0.010476897793611693, 0.07880127478030421, 0.02599944600895528, 0.025596114123360287, 0.029987270733521833, 0.04073502465842232, 0.03053064923733473, 0.07101009930333785, 0.01576779115449397, 0.028373288185966593, 0.058201748892785087, 0.047615252645506013, 0.03754198934221941, 0.032134078923733, 0.022716121485216484, 0.08350870887478513, 0.09543190214542613, 0.03104270815158323, 0.045152283799383915, 0.004427676021511997, 0.028148609919533617, 0.04441375971861905, 0.02156673870500057, 0.02802157913514924, 0.056054090344977964, 0.024101193130557096, 0.025430809586278857, 0.021601823616712805, 0.05912487335022419, 0.02704338636249304, 0.044880000829336145, 0.05512149704079475, 0.013455592242309885, 0.012377665355621327, 0.030432339089231628, 0.0009358324795386815, 0.07815407604099282, 0.023337579670272047, 0.09088522394097621, 0.02598898699356904, 0.05154195121459423, 0.01663846635980712, 0.03265779961140887, 0.03932848722944337, 0.04961904754201251, 0.03639644657772395, 0.007456345258340721, 0.052001393294983336, 0.0030394500091431606, 0.002370591809590077, 0.02138842791018467, 0.036473890405989466, 0.0942186946650186, 0.04046313239321594, 0.06114889296793169, 0.019386245628758784, 0.021766465487739733, 0.06198486343266503, 0.012475149086376112, 0.021329632577215953, 0.028618539743606123, 0.04221181235005779, 0.05755143217562188, 0.03891668432662564, 0.026541730922256267, 0.028646796896693208, 0.023651989815275998, 0.06262757672717975, 0.022393874260747147, 0.038384337488922386, 0.027789668998711055, 0.0695750710644549, 0.22718188773480155, 0.2336274910598032, 0.14808479576341568, 0.09139337006115145, 0.10722564953950145, 0.15197230893517696, 0.15419774838993627, 0.2188190727704956, 0.09841084269987, 0.13131974295022028, 0.11352889840641331, 0.10600312642993466, 0.1466903318801234, 0.13949279793568198, 0.10352562106544934, 0.10433198989278848, 0.08597347419708969, 0.12497784494752846, 0.17629707141989664, 0.14655828896549442, 0.13853071407685358, 0.09543800786618264, 0.13247635185478196, 0.21129933756686028, 0.22510402745777564, 0.1603569727270834, 0.11308286669513873, 0.08953364565968515, 0.11453683262750988, 0.12695359336512704, 0.11999195321433007, 0.20929791754291904, 0.17205990039773528, 0.1507718951231049, 0.10674374959161205, 0.10816793002548719, 0.30728347419250396, 0.16955548236446996, 0.11243115569795332, 0.13104741401489706, 0.15685071087171956, 0.12070472907995987, 0.16893032397474014, 0.17368219882970856, 0.14441929487211091, 0.1065867092280138, 0.1922522467230597, 0.14823884072323001, 0.11115018774064318, 0.21212960833743696, 0.18344693937368933, 0.1825253356007799, 0.11934734385220275, 0.07318933599538381, 0.09200636297464372, 0.21855875609382508, 0.1789894261427464, 0.18563087218471114, 0.08704163825079318, 0.14250998926018515, 0.10110936443051023, 0.20879783066770724, 0.13576409479062404, 0.14352905473882152, 0.17694893563466688, 0.2548566301383319, 0.1413535795384838, 0.13176821082109405, 0.16028561929781593, 0.27845298090288717, 0.10585986032721498, 0.07278065107041791, 0.08767222054302694, 0.15649317763745785, 0.3929185290490428, 0.21938812288065113, 0.06166126789344896, 0.17912906864958425, 0.16799025748285557, 0.1923654285529929, 0.26827939455547645, 0.1694200073759402, 0.08763911022293953, 0.15659376498191588, 0.18025619849081964, 0.1306510860881498, 0.17648327675077224, 0.11696932266556448, 0.151906241512587, 0.19062041815730835, 0.15999867340489743, 0.12324043414405278, 0.12005140929813347, 0.11667725164443256, 0.19877203800264867, 0.14700903977838256, 0.21117141620526392, 0.11722105915748304, 0.16008545584495992, 0.12351709147614819, 0.15827614002891127, 0.11228499378287986, 0.09750067661967009, 0.0900216436674518, 0.08896274927763209, 0.16237710061813557, 0.10550024333379923, 0.1522069310228671, 0.2092721157016293, 0.12179637372854257, 0.17598605504439724, 0.2152740009008877, 0.12586824595928192, 0.15259504648706607, 0.17528831748472107, 0.13320030494322702, 0.11920906498187012, 0.10257729614574103, 0.07047351599941332, 0.21558230532513512, 0.14529994358458828, 0.09081026223758537, 0.21878387869125415, 0.17820099909459391, 0.14954808498582534, 0.09815291621752324, 0.23505834411949883, 0.15169801881476758, 0.24783010234034833, 0.13704143915205233, 0.18129441616756303, 0.19114958573012583, 0.1332494877879658, 0.09806126145826233, 0.13543643898540927, 0.09956762780465427, 0.10173999268801943, 0.10681833591192, 0.17020212185959663, 0.10907780499227586, 0.19157323235225296, 0.30068089945181725, 0.1732023979627317, 0.15708392335762902, 0.16093035889489038, 0.16429947569004952, 0.14104450902631208, 0.11185914082753082, 0.11276190649838218, 0.09048879642279879, 0.12796201022161593, 0.15520703858665882, 0.1016828578506266, 0.16624097231655352, 0.24210574015253977, 0.07401131769461979, 0.16717877118818222, 0.21862309215770614, 0.1193191824601062, 0.1164197541713234, 0.11744972108112228, 0.14753574054808388, 0.15367642555746341, 0.22304824583472746, 0.15633677312683675, 0.0998954751318501, 0.2002107664462059, 0.11415857671489639, 0.07499295211727582, 0.09761421085004846, 0.12875805218373576, 0.08537386483963459, 0.06032698404704852, 0.11385958791980821, 0.11422994546592237, 0.19546967810921131], [0.026734275630705302, 0.03602187554802626, 0.03235443645427304, 0.04687461033163052, 0.041766856992316824, 0.007248680847096107, 0.03154873220820821, 0.014871101518492065, 0.009069137496783609, 0.030625004456528736, 0.09405056134827676, 0.06160618234125357, 0.028835526487279325, 0.055341540475285826, 0.08801975632987677, 0.012117737468572394, 0.02956588790121098, 0.06997744342492473, 0.038609448595032576, 0.05275698198426155, 0.012615804744493819, 0.014289129420273728, 0.053064439881352655, 0.030136546796007507, 0.04713756618120017, 0.07844062356819069, 0.036389601582120505, 0.029847992118448022, 0.0037746013878213786, 0.011419759548809982, 0.08150817751283608, 0.051245249191960024, 0.07032390668868058, 0.031576060479687106, 0.021326845932391383, 0.10121850131620323, 0.02649863656129568, 0.0055785713465734115, 0.011459257126966072, 0.0073809823163995345, 0.043650130936575514, 0.010617918301103337, 0.02493610256351531, 0.010522379476066318, 0.03850575093360197, 0.036443875081116156, 0.03713697397841081, 0.052219356800759995, 0.046051866374909885, 0.0497365232947613, 0.04679715118160652, 0.008104417337885788, 0.026002713373952338, 0.051044744829977715, 0.02984801318586594, 0.029513374489221363, 0.03436986056547012, 0.04318855913175691, 0.03795149781170391, 0.07607829186224169, 0.04013118649562521, 0.043608647275475726, 0.028480607528059233, 0.011486248319758283, 0.041228189929238254, 0.054914477101016435, 0.051758018652758295, 0.04809088599417479, 0.007566790717969379, 0.08341001376750008, 0.019648063837760882, 0.016570809304774288, 0.007217486704429312, 0.036456925388906276, 0.030976430054814107, 0.0387784207780515, 0.016941088326876203, 0.03756326360387668, 0.018031583843572487, 0.06695171022006581, 0.07510686939161632, 0.01597691017518481, 0.029600426975277164, 0.04911615678499784, 0.049415942311527274, 0.052287151751619194, 0.024657489791993174, 0.043382973094741185, 0.036271765768047304, 0.028540866088963328, 0.03806307851787537, 0.0742027324233805, 0.03247753529238605, 0.039928027638985265, 0.035689297627898, 0.035682307075588934, 0.051617790088658376, 0.010116570253646182, 0.012038754761188984, 0.01313388989787669, 0.03391476220361168, 0.02311275584713346, 0.04139588274542363, 0.004753744109503685, 0.054777496749715465, 0.06851433806361691, 0.03375615135976865, 0.05559520750877358, 0.03223586519579253, 0.04452314558288744, 0.049788326160201145, 0.08541246801013909, 0.05812446977342329, 0.04167039120089143, 0.033186407940041636, 0.042888976618527405, 0.018382561280422153, 0.04726752150623549, 0.027752471599547614, 0.01869125640951097, 0.08080206661214752, 0.07543191283700929, 0.028707794732444232, 0.02360424913105465, 0.008414623575405249, 0.025668001898954955, 0.011316691037087191, 0.04214084196475245, 0.006689310736668807, 0.0394705965393974, 0.011378303658397449, 0.025860584911800204, 0.04714205928687607, 0.034041335250461296, 0.013413476558672565, 0.05443241627466294, 0.027176007673504855, 0.04903822266046078, 0.02324215001276424, 0.007342955148253109, 0.05725219057151868, 0.07759163726962383, 0.09246865873255077, 0.02766619286229534, 0.08871822167308101, 0.0333943318635706, 0.07756100907441109, 0.009218454736495211, 0.029783106386481278, 0.017912079873044166, 0.026118553528982787, 0.04392024970823719, 0.026325014224576376, 0.004359749878095764, 0.05872485671012152, 0.032080144418643854, 0.04351770497798439, 0.04395475047790716, 0.02350649631191646, 0.031623950551053694, 0.05049882291425621, 0.07266495647209306, 0.03444320199290111, 0.02657961588533175, 0.05232519567793897, 0.024315006355003967, 0.032616790924822135, 0.024521767740107836, 0.019165907250416857, 0.05461762952167661, 0.050854915903220256, 0.06490895209173042, 0.06190671097306956, 0.03979359836047215, 0.07319439217568406, 0.017022898856310115, 0.02495227276437706, 0.026901776924909606, 0.004228798159953928, 0.027756284802190723, 0.04768661373565274, 0.06347332630426654, 0.08661673524447026, 0.030225840089241826, 0.027060671221284617, 0.08978926621737982, 0.04829554638314632, 0.04657453752212948, 0.03682732506985626, 0.005980381111223852, 0.029327540710989027, 0.03907202014459237, 0.005786869695575367, 0.021445093518723885, 0.017656202675894867, 0.05695228630136098, 0.06028409461460768, 0.05888611438774294, 0.031384119065478444, 0.02239066626756422, 0.06018385200971558, 0.0585816212509188, 0.028946754793005607, 0.018894924714620558, 0.01131832855002534, 0.06265261248054524, 0.04920937819406391, 0.10559205897152425, 0.03741440122887012, 0.017168371292251735, 0.10973471006558788, 0.03044414067370517, 0.028824933406506336, 0.07664590172709958, 0.028008927193079746, 0.03284227741401523, 0.037306310053193764, 0.03672798644871481, 0.046459976733932574, 0.04630378289749065, 0.044553720151945475, 0.037754394880105416, 0.021338055713943416, 0.06303669066138326, 0.03213947984359918, 0.034720104473132285, 0.14398630197730758, 0.058971050555907914, 0.018977874799841837, 0.024490928870715925, 0.047259485243909785, 0.028555856514421683, 0.012943522794352425, 0.06558934542080087, 0.020685159195695194, 0.020956768008369594, 0.014597814015653587, 0.04983640966876861, 0.01848183861452966, 0.044233610312784874, 0.06464341835629556, 0.01605802260699772, 0.0632990719450097, 0.05055815642399173, 0.03249580265894052, 0.11705622001881562, 0.014669180851459745, 0.050398277704634016, 0.04071587629075493, 0.03505332590711694, 0.05271181344024597, 0.052984728432831266, 0.017688845682348457, 0.07618842466223626, 0.015793428286880015, 0.02576967708826546, 0.07306174405159489, 0.04092921645590856, 0.018192494866408167, 0.030001939402051994, 0.09982056705461395, 0.03481476229705638, 0.0375969140159507, 0.039142887108027935, 0.00879071528963264, 0.02636572222165283, 0.05201773778084786, 0.025736624224772377, 0.07219440228636227, 0.011836512337228464, 0.025842271579970277, 0.07034417737515704, 0.019536203509497068, 0.03818818450634999, 0.0489227157536774, 0.011304840614508477, 0.024328839987696662, 0.016234002579304, 0.01820667898432622, 0.027084473573092013, 0.012527946908507618, 0.026042486743761167, 0.05403375944062587, 0.09588869739203684, 0.05981044926410241, 0.036614180257123326, 0.02643300389360276, 0.06254536017114598, 0.021689192114037373, 0.011198541126965035, 0.040486559361940434, 0.06846416696545578, 0.03409189322302419, 0.07437398371797416, 0.0029018290168155107, 0.031152023152718623, 0.032555975034953125, 0.07434822018108062, 0.06510930706656749, 0.047903772849108905, 0.030231248669987245, 0.023015399478496085, 0.04453117035389428, 0.01657061586757341, 0.05867396931975119, 0.03834904381825078, 0.032081448683334936, 0.021112329822273988, 0.07289459132739613, 0.051230942499974085, 0.08077775098143086, 0.041348795151157726, 0.06366745298427921, 0.05926426687848665, 0.016952315345406532, 0.019897486744148117, 0.0268692392555456, 0.01172153594633264, 0.035587913551998716, 0.018001959223540562, 0.056126056644584865, 0.03587266843345377, 0.05931690861020358, 0.05949456439984422, 0.08405391832873707, 0.009779828645649457, 0.017968910190487103, 0.11714673330706936, 0.03672357378227096, 0.01800809558781405, 0.0325238453074088, 0.01245783837211709, 0.019521998324161096, 0.030714069838605584, 0.013262241226320547, 0.009350867288547659, 0.05227007948222661, 0.028128641837787245, 0.11908518856451397, 0.08265219959280184, 0.0419036764651537, 0.015985071884408113, 0.05584593659507171, 0.04998044952029183, 0.01578108373759014, 0.05453971454933767, 0.08333698260567843, 0.03771029119830459, 0.07923441323181314, 0.027571981284587134, 0.017734351305050716, 0.07722171639362652, 0.10076208145267541, 0.07787778643110106, 0.06159679776418114, 0.09403736931422065, 0.1551772684099213, 0.08681882923889546, 0.1290164229970786, 0.194260515573044, 0.07061095217302923, 0.18660420221426796, 0.18385789957979035, 0.13263597393468504, 0.19825309004274108, 0.11415695260849693, 0.26859655495612855, 0.11322784117392956, 0.11211332880080709, 0.09210104378120554, 0.07582061818890995, 0.10807865779967078, 0.21801933826458073, 0.14547747680016104, 0.11494442204674406, 0.0908574992189965, 0.12414309256259473, 0.23436857387423518, 0.15438013860294897, 0.09803939730890336, 0.20766026670894316, 0.13358794543291294, 0.3248381031857383, 0.2114438064276211, 0.14294016295142714, 0.12166723428714661, 0.3404634776374986, 0.2075288519864121, 0.12587961470407824, 0.25808815754229025, 0.06548453693188007, 0.13737148515159084, 0.11030000634491445, 0.14261413125261185, 0.09323555104915174, 0.1052378812023709, 0.16521617650024353, 0.11038878061358007, 0.18674764451721024, 0.13518795070628967, 0.16801943011101217, 0.11798736158638232, 0.3068773863056014, 0.15641633901865254, 0.11476125808492785, 0.21857413913934462, 0.2603417737109046, 0.16421425606935255, 0.11386883460105428, 0.1618041281378077, 0.14822790098767127, 0.1158648843486463, 0.12952328208954106, 0.2031549189480082, 0.09000328820078604, 0.12980966107739558, 0.12928610126818382, 0.10916455678882138, 0.18624484569074648, 0.13750240957785037, 0.1023987670158667, 0.22847786335454834, 0.14388007622572685, 0.12873922174255695, 0.17112680530596167, 0.1438914143270062, 0.13685316538378117, 0.10605857587389408, 0.07098505588909311, 0.14292770636177834, 0.07450633306777285, 0.19097271135016797, 0.1946604134695184, 0.0878058186161422, 0.1213432557039684, 0.13572209785061498, 0.20533721233087204, 0.17382775553532187, 0.12466371059417726, 0.17258931311868853, 0.10364492393789754, 0.1191718331087501, 0.1385018172403497, 0.1574051746677968, 0.31036550719891826, 0.1559702306985855, 0.07245559230326645, 0.14576290583898946, 0.1686976171068607, 0.13854894696945144, 0.07931322069658388, 0.13734392130807524, 0.14717546471905324, 0.1165097235371509, 0.14081361012593394, 0.08446579784034722, 0.1852949885951896, 0.17702375178135213, 0.1253204777716629, 0.21234161550960234, 0.1033376230888309, 0.17324485455549535, 0.13706560156518413, 0.13616993752939088, 0.09228105146077373, 0.1024263998072955, 0.0876253589446987, 0.11350091321453934, 0.22362287306497175, 0.1344288954691541, 0.08476038162987079, 0.14142093398878652, 0.19672878957804174, 0.2090645058741493, 0.13109625978094916, 0.0913508904857501, 0.11229730481582303, 0.1333266941289748, 0.08950493268428311, 0.13796295099441083, 0.09958559256647864, 0.11285919966476579, 0.13435332855630305, 0.11059151812186165, 0.2016955214522539, 0.11736446315602911, 0.1296032769905944, 0.12026386846217418, 0.14830809507158496, 0.18125762862543907, 0.1772153197276977, 0.07977441328787997, 0.13165383389399898, 0.1430319709282729, 0.16082952640229659, 0.12359699444665063, 0.172663884117238, 0.1528595919690786, 0.13443085665424026, 0.1254650998500086, 0.12007695066952899, 0.0719373491442492, 0.11831812770856966, 0.25782741185638214, 0.08793753977384298, 0.1280164637512738, 0.12052633018503267, 0.0894854587292479, 0.11294537689536811, 0.11549805080698383, 0.13382566251581715, 0.07291339878593722, 0.1013046172597716, 0.13802806846797466, 0.17813902258151965, 0.19125643967380448, 0.1534832028612014, 0.11728298204440264, 0.11434191687693519, 0.12106512748305837, 0.15465769225791579, 0.1723627962412373, 0.10637875466096787, 0.20701207971620947, 0.16149700348896368, 0.061481401940146764, 0.3199298697854242, 0.10752225580114512], [0.05930877275644772, 0.015670243263875526, 0.051733833256988764, 0.077262181157787, 0.02855226930771624, 0.08986310177152196, 0.012320086187232408, 0.06462805063253449, 0.00979056919834787, 0.056509150402440186, 0.014590113874404662, 0.01651272260313553, 0.11711324760389906, 0.026828556156326688, 0.00886440528706918, 0.007917991756731945, 0.024390027430208943, 0.06710496610931813, 0.0698405052084596, 0.06135100611455499, 0.012680514276237979, 0.052803575451816284, 0.03156131711758433, 0.056938960201918125, 0.04454748802668145, 0.03863093736130865, 0.06073909721547558, 0.04627685107651257, 0.06258862881710933, 0.1333213621570218, 0.0913168685210328, 0.02684410199553015, 0.04089309157983911, 0.010498736087503213, 0.01088056484267356, 0.019605295064168114, 0.05432054828551989, 0.06551632191985846, 0.01714459575352169, 0.06040468834520829, 0.0471709676146988, 0.03173972750383039, 0.05195604472030556, 0.07102058704702124, 0.020934101381909945, 0.041088934296802174, 0.027903982723552375, 0.04216734094605331, 0.0706683781238333, 0.006636953415093764, 0.03040423898416902, 0.03188921807093486, 0.03093997767615703, 0.023187510706784747, 0.08994848227068301, 0.04314316842224329, 0.016121908594223282, 0.014787593146695968, 0.05055496183734748, 0.08056687761939342, 0.02616960945869646, 0.018947248519848914, 0.0709941646745128, 0.05609147926612247, 0.07746019956445502, 0.011298056905938974, 0.03445534448650095, 0.01536004660245512, 0.04495166069377334, 0.005895743238544393, 0.06380218486752241, 0.05169898391731324, 0.040170356571193666, 0.04055792045208716, 0.0338120183216468, 0.012505403813725759, 0.06017098556302729, 0.04091023662758451, 0.10293427779669724, 0.042851626001779115, 0.01887965658228965, 0.01204815561762981, 0.025898061933056004, 0.04179685699543165, 0.034105085257080295, 0.005818931911621364, 0.03381505202982695, 0.05442549083982745, 0.021518701161708564, 0.04630664806632746, 0.03498292242687556, 0.016171840289908073, 0.05685189430932364, 0.07250406268623567, 0.04282820669393386, 0.02477870022337283, 0.021236267526664084, 0.029464819836580468, 0.03183387013362541, 0.02354749542240414, 0.04900166877515374, 0.021987196486142856, 0.08684080830144306, 0.027650398044516484, 0.041455181781202555, 0.0411983814481045, 0.047138952800343116, 0.05122791262223356, 0.04330715720331477, 0.020363858089812344, 0.03644265700131655, 0.05160491981153047, 0.016390795879546675, 0.06672772143276469, 0.005706198721928823, 0.16009395942091942, 0.06256414847748895, 0.03459497167158031, 0.02450176709962468, 0.020664967033230973, 0.06886116904957641, 0.06286637782449685, 0.037761419906371066, 0.0324308690464785, 0.09638969591187854, 0.051186137847722545, 0.0478783387300228, 0.07280283697670506, 0.05465184300837498, 0.02621779447391389, 0.05234716707960733, 0.021763655860277436, 0.03731316654011607, 0.014098110184403918, 0.01718829532394246, 0.009415794197740334, 0.012168212129073519, 0.007454729291625442, 0.05898853651277962, 0.019582322002538753, 0.04686647447787466, 0.019706010728353457, 0.04054931728469749, 0.064707892316003, 0.013127052563152487, 0.07450064869537469, 0.04098774557332358, 0.03019577113821382, 0.02557578214984988, 0.054756168861903494, 0.04271636551786815, 0.024442420183350484, 0.03431571347098197, 0.033977098778010376, 0.01942550571965835, 0.03756772606603561, 0.02252717930523138, 0.054085792132443, 0.06338542154539498, 0.03512141963226661, 0.020884140957927993, 0.08913631415775708, 0.011942070634705166, 0.049156353418384834, 0.05287698582716046, 0.05651580004562294, 0.024734954687676603, 0.048588801010121266, 0.012772490792427094, 0.03522496024567274, 0.023882754650267384, 0.029330944056592645, 0.07593370808829224, 0.04772580679385893, 0.006069891781906688, 0.037792718428517544, 0.03614055788925579, 0.043670351827336897, 0.01503973758043421, 0.039207127410918474, 0.03933970658709446, 0.029707217716702053, 0.05752065459326391, 0.05196325360767303, 0.027741399713821953, 0.010406998016180532, 0.013051501929669852, 0.027504163351090207, 0.06279750652010403, 0.006500827251828366, 0.03616469731974987, 0.01491943209041511, 0.02861694436550381, 0.07612938992679119, 0.01623788472986029, 0.06561593633265266, 0.0328803404925331, 0.021256716328582937, 0.017147554768129222, 0.042892224831326355, 0.02197817197039483, 0.02614895381303805, 0.029702636510914857, 0.05063236736121678, 0.02510698996634493, 0.06931001230353309, 0.02686360467886252, 0.02649742805759513, 0.05949430776038959, 0.02623134273885479, 0.022901771402346994, 0.042084929037598834, 0.07065613603880329, 0.018700282840478807, 0.03867004231940355, 0.01715470045324295, 0.01618144511725874, 0.047884888781775395, 0.05269356522588961, 0.05135317948917228, 0.05906670046369395, 0.03850416513159871, 0.03906522877514362, 0.08595324947588867, 0.025575240142643455, 0.06687175362340866, 0.021540969422447587, 0.02495337401576821, 0.00806176156226185, 0.05246636653018575, 0.07467467322825425, 0.01737916613027694, 0.024015345317762227, 0.07238145031395458, 0.0764130799460315, 0.017341059001703418, 0.018999800236234744, 0.07323967563288827, 0.02836718438042989, 0.05524742657378797, 0.010145671061059881, 0.03226041831376572, 0.07719131036391182, 0.038484338776118336, 0.06839697339361714, 0.01144022654531704, 0.06721237929718149, 0.05282536299238282, 0.049379208395558025, 0.026927528970484293, 0.06612078061387425, 0.09743703769580012, 0.06857522673183872, 0.029054989610167763, 0.01996211583666023, 0.04106753363063739, 0.03622244502748213, 0.012762942464060843, 0.014350282388829417, 0.02415946369329768, 0.027201843988751213, 0.018958452555741516, 0.01586124526276704, 0.00827379554750458, 0.07187697375493665, 0.011264888171647346, 0.031421473512666366, 0.044831246993834936, 0.041368253784434456, 0.049662760518971956, 0.07115080667239043, 0.06302402339755528, 0.02561327832330379, 0.04415473390010096, 0.003984247093960162, 0.0637798648958485, 0.043652341100237066, 0.014907072219366749, 0.05622220450952169, 0.014572485233657064, 0.020766508157154726, 0.04205615094472324, 0.07168997935349904, 0.042968347157922485, 0.04086942712385808, 0.03554197125917962, 0.05860050148781269, 0.03186889567352351, 0.06669681744589921, 0.014835113580639084, 0.025116397526055097, 0.009520199532890994, 0.038062526934569886, 0.049754940048461004, 0.03821911147585319, 0.030943999637759505, 0.013543534347967756, 0.0467143370769918, 0.040310696218042605, 0.02989242330283648, 0.04651956688312273, 0.008774080647966795, 0.027719418736054536, 0.07234025776626603, 0.07026538523214479, 0.055701785660799474, 0.037773784565468954, 0.03916481637486047, 0.009177053429847284, 0.016004813012606915, 0.06871443256855973, 0.0005046682605508626, 0.006800852659639092, 0.05267049831848952, 0.05408259754579875, 0.06001494877460984, 0.04601952214274676, 0.04201268311589957, 0.032424372620880604, 0.036467865124465, 0.0431461944695442, 0.02854972398058782, 0.009633954971157497, 0.013645022803346717, 0.0374659244722176, 0.025186159407659888, 0.024605813331060836, 0.01535244030697692, 0.02438879402865085, 0.008566017871001556, 0.02893840060419133, 0.035007728353863767, 0.025729978412029245, 0.05340934032574297, 0.02161593112583843, 0.05210222578757713, 0.01670921266439461, 0.018430342184259527, 0.01657996022502982, 0.030382185228048798, 0.03690026430112701, 0.020288827438508312, 0.03553658566107193, 0.07887201533923227, 0.025968653104838826, 0.043907750983752554, 0.037632104264752525, 0.04303486657238776, 0.06578524176391863, 0.06748811732376776, 0.04926985317480661, 0.03512963209481489, 0.24228213955798458, 0.16024045075380033, 0.11910031880101851, 0.3043096128009981, 0.10665599421988572, 0.15503068514648946, 0.10417394595400942, 0.2470232738602546, 0.09108775460551824, 0.08069991644832396, 0.07218497174401438, 0.21698033917815457, 0.1418278032853719, 0.12711902239149617, 0.08752281807603375, 0.12275180028330897, 0.19802573046857314, 0.17528811830186075, 0.15659987836355166, 0.13419160739548747, 0.08709809126993341, 0.09470069420433815, 0.10766815724632434, 0.11977734900410138, 0.09090334192038545, 0.10643083331806046, 0.1638147258950818, 0.1730835011168834, 0.1991419818612837, 0.3463258582257456, 0.13529696501791477, 0.12202575577483063, 0.12961847617501213, 0.14252307404193187, 0.11964011967422501, 0.13308004446087346, 0.22980330271586297, 0.12173879456015364, 0.09863159093525141, 0.1058869262135798, 0.11430594138801099, 0.14430773714857717, 0.1547290303654248, 0.1447299741689236, 0.1878447437118138, 0.15209690547518193, 0.12089867955974995, 0.20647943410421574, 0.244048033510485, 0.1537275542655299, 0.07482438213041714, 0.16154941922474295, 0.12556818464109976, 0.0789802099367784, 0.2635986586251567, 0.1272111061599947, 0.09901380752243343, 0.19621246163883518, 0.24341078625331003, 0.11660968268951101, 0.09526312531482789, 0.15836304504304163, 0.17708942083822143, 0.13882054046036738, 0.2129704970866442, 0.07897792699476404, 0.24938544468773952, 0.07061760947709123, 0.11050816775569994, 0.20804966920085494, 0.0862691764749827, 0.11278607657239323, 0.08820770834121974, 0.12628722710595017, 0.12286835290010899, 0.1528428759305708, 0.08528320599467525, 0.12624654017629164, 0.20450263614616088, 0.1663810285108705, 0.12413134843471552, 0.07500750778783714, 0.1364036249898134, 0.16446651350105965, 0.09341717517424016, 0.12263792897424391, 0.09229761428169667, 0.07888771248080077, 0.14572788029909134, 0.14519701201108196, 0.19505304885247063, 0.12806262054871168, 0.10501089701128584, 0.17597883849615054, 0.21901713714243906, 0.16115301468920323, 0.1227426072282176, 0.14180103617329753, 0.10699377004658023, 0.15462645119236362, 0.12315346018200922, 0.16033978171406255, 0.34013436626522775, 0.07398562310563941, 0.11753204488946546, 0.18006432410930434, 0.17782429834046673, 0.17744644845445312, 0.18106313422322276, 0.2662896803550182, 0.13348173500309068, 0.15414053694375102, 0.16382437860292776, 0.10065966315807835, 0.11364786420017482, 0.31333415919253904, 0.18629441157944743, 0.1322183181201258, 0.12178580171518749, 0.0986445991082057, 0.12383093471608816, 0.16663900095849268, 0.16991920558915985, 0.17308768395694996, 0.192544202831003, 0.13663835432981292, 0.19420452986753758, 0.17063695336541823, 0.1712149054172539, 0.17743308788105366, 0.11393528506760636, 0.17818618295413835, 0.14091119440572877, 0.10924108131157775, 0.11259543559243602, 0.12332293415261854, 0.11550987920453472, 0.17875555482122207, 0.16065649778371857, 0.13777642390660702, 0.2273139612929475, 0.12503146344134886, 0.19435502017938322, 0.1315401004807603, 0.1767708814793056, 0.21558368428339883, 0.10524925760804646, 0.10668126746050774, 0.09870301331243209, 0.09369423853293543, 0.12199770163504348, 0.13443637248729506, 0.1797704068162749, 0.08557986588247361, 0.1552688159168728, 0.10799528445087134, 0.14939793175266636, 0.16301103837547765, 0.18721748624117146, 0.10054666518924699, 0.0903571825174074, 0.19766058232034409, 0.08511513396496735, 0.22773014621869211, 0.12942637196711956, 0.1109581524806638, 0.15995926584207243, 0.1823476491676223, 0.17669483959194154, 0.21661247907867356, 0.1365912399224697, 0.10650640023091149, 0.16848015538867445, 0.11752454488868676, 0.1331419596869138, 0.16630630429473617], [0.0625785279478277, 0.01429991306541788, 0.020378923208843318, 0.027305420991333745, 0.010257317842314801, 0.08458449550333523, 0.029806640607515172, 0.030187951295726725, 0.041381419005413214, 0.06908468286236448, 0.06582356148189114, 0.06538833927122817, 0.04322038242413152, 0.06532076265542738, 0.043615105396677414, 0.041183396768305576, 0.03269361039142936, 0.01744289315425821, 0.041462957573634, 0.09403409811878398, 0.02121001943915842, 0.04399150737651414, 0.04881441007338224, 0.008137958582430597, 0.06097550045758967, 0.014102028724136613, 0.03419084496976387, 0.05757329249454122, 0.0372511210791286, 0.03442198901827778, 0.06465472581405794, 0.06475322173848268, 0.04554029584171311, 0.020322763218334126, 0.06807274200142392, 0.008615172945053108, 0.026861350465145324, 0.0018023008446870074, 0.032856392584020094, 0.018372985181368647, 0.06146786899696435, 0.0466368779269678, 0.01808247123394282, 0.04078321158885956, 0.028860949115046573, 0.048088656678315134, 0.04391005690840464, 0.106821522837685, 0.028252342054920814, 0.024793135235086087, 0.018624553133943872, 0.03594737349738998, 0.007086611595079904, 0.049456437719204736, 0.0189783153003983, 0.0540886726230383, 0.06327186433237887, 0.0234270932137846, 0.029509067159867095, 0.07382811542840735, 0.04248255931381737, 0.030609985302773215, 0.043850658281195554, 0.04960140836755595, 0.05039116457825707, 0.042772060109963345, 0.006907661116847228, 0.056138183816426226, 0.03091574439989223, 0.0372941101029996, 0.0691876297576293, 0.010583437641241379, 0.05723708714809149, 0.019466880213228926, 0.029258782404565045, 0.06262465410174863, 0.012873058984687012, 0.09892675695159743, 0.047234798060549844, 0.055459230732653415, 0.02088721297050436, 0.13386232748387322, 0.049631837379908374, 0.07919121353376297, 0.04676014147398453, 0.0504033760197701, 0.017698567338107575, 0.04163395605921265, 0.07558740570300049, 0.00879695794860562, 0.0037234903955381485, 0.004350796225480735, 0.05702868441960985, 0.022093360950689644, 0.026138571406444235, 0.029633451110473084, 0.06221896458056666, 0.008241367045669787, 0.04298263469771032, 0.02019882934438365, 0.06818409288121809, 0.06707511932378815, 0.020514829121830485, 0.032674856559042974, 0.0076399583392025485, 0.052860702628329884, 0.043314086468589884, 0.030014610496319594, 0.05140712740080011, 0.054456203304711855, 0.05346902240548403, 0.01585489152104504, 0.01791241312129123, 0.0856894317774042, 0.058872340126864375, 0.022709590585661993, 0.06483223604699297, 0.0187585016922845, 0.07462614155825108, 0.10540325660258533, 0.0673203747118673, 0.04414700790338459, 0.042314881819390485, 0.0782138845252414, 0.06801343913520537, 0.011556738942501046, 0.020353416311404398, 0.06490677640202545, 0.04966288309303984, 0.040501444450309204, 0.02907368981639945, 0.01833879467730801, 0.01698870643702967, 0.08861166650369283, 0.08639912030869916, 0.03254709990635034, 0.022184460296205456, 0.07359434369831316, 0.047288860885366324, 0.012789354302860316, 0.044101820207170905, 0.04123312353547062, 0.058253996089221015, 0.08099378777607795, 0.02604003334718366, 0.041415165178477764, 0.04332563907448803, 0.03182451811528975, 0.032569293473516746, 0.061327690228579514, 0.036836039319994955, 0.04350850809245341, 0.10466500065259396, 0.05881913915096272, 0.02490772283636034, 0.02798524933056005, 0.021261326262667295, 0.05681342903464552, 0.018112429102221807, 0.0418645715070588, 0.020163192849365935, 0.05125508193046816, 0.04748158945491718, 0.06766692990617407, 0.003950170066673309, 0.025172944390966047, 0.02214863610964629, 0.010015854589460839, 0.022479170490236535, 0.0948000328254796, 0.05337466718629003, 0.027143690254419085, 0.021186266883066105, 0.01576911935943269, 0.030536611316605445, 0.03590433084736428, 0.07435667013088543, 0.11048402066432661, 0.009423245360413867, 0.06541038728168895, 0.025579562793756207, 0.043898523454704595, 0.007421797565785387, 0.05376869684926445, 0.014338002957013107, 0.0442412558702692, 0.022048590772394693, 0.03528620897521896, 0.051276260431134896, 0.01572087305718132, 0.04331147410876809, 0.026693341637691183, 0.04339901880631524, 0.04542735915991568, 0.04437568514878231, 0.03279335503917068, 0.010467737297257109, 0.022812759646424846, 0.046295650874174414, 0.03938864045325787, 0.06368568970731671, 0.05181118132426374, 0.07234414949292138, 0.010677965230218345, 0.022285731374135902, 0.049268531673137224, 0.003236759305676265, 0.034795096820040096, 0.020234856544242754, 0.05520120082843689, 0.09106640373506854, 0.026200023149290395, 0.01840942606870686, 0.025608155110310164, 0.02262209568382992, 0.029431642483799692, 0.15843366302790182, 0.05655534167383468, 0.03736665479898934, 0.04448871376113065, 0.003806089516729117, 0.0832230806530964, 0.0404571300943292, 0.04191810573120752, 0.043487413861458345, 0.04659134932162781, 0.029499169303885395, 0.038799572465640884, 0.0353954071479459, 0.047065461985766895, 0.06751284664196354, 0.027607652253561446, 0.05041836453000865, 0.05500898170735567, 0.04804991178154465, 0.006517890902731809, 0.007595289188752612, 0.08475093576576441, 0.04056363546800229, 0.007309836688481512, 0.01758282677450728, 0.011589450896867822, 0.011115123728109945, 0.019558427720180443, 0.05627158653712081, 0.022003749730966745, 0.06465284889864345, 0.0699205767183054, 0.07595182606770147, 0.024763935793852134, 0.037171838639844815, 0.020585052571409655, 0.01841338482805558, 0.053817351093335505, 0.02352618285635066, 0.03266426922392941, 0.06174941013957705, 0.03223909042595375, 0.04997920079697525, 0.040949483311945395, 0.014256834983825685, 0.0340240293242518, 0.022119903982046153, 0.0411127787834454, 0.06776370979364842, 0.04316485637137967, 0.003764240527450438, 0.022369070248978756, 0.004444983384136352, 0.09187413619891291, 0.06843853366350935, 0.07731452794565309, 0.02241732038166975, 0.023206021306255174, 0.03221040809406869, 0.046652827877551324, 0.08924900569141873, 0.04418236286109013, 0.057839726383287104, 0.03355239112410815, 0.03919593869678436, 0.05050288701069452, 0.014080446112089822, 0.015388617851591159, 0.03516863363104002, 0.07511058491804908, 0.03956861365886946, 0.07610971678889568, 0.02210678281112304, 0.0643177850232009, 0.07660205851519301, 0.056551718077952826, 0.03758016350348631, 0.039864070788626714, 0.06851856686895894, 0.04730917753711824, 0.009878312121145427, 0.0276029369823875, 0.0673037659256689, 0.05468355904844019, 0.0475029977819612, 0.006839459181778254, 0.06818585488344393, 0.04099346441967834, 0.039603202528650724, 0.03523879196314562, 0.027418717734455585, 0.03339590234381538, 0.04186225026064823, 0.08053230407137064, 0.06356231890799058, 0.03666783705533993, 0.027658685200637387, 0.03767870922362612, 0.021878812281835466, 0.04169633476844719, 0.05440540018401319, 0.04090740593270429, 0.071090592161542, 0.06325034492258584, 0.04116987531644203, 0.01770989011762844, 0.038312286919643807, 0.026311023543859204, 0.025513079768467336, 0.08159655341578108, 0.025302759904955185, 0.012231041872573477, 0.007034084776551613, 0.021308450246109598, 0.03244217267380126, 0.03299228126002896, 0.030120018449041153, 0.06163223316111873, 0.06781772665318943, 0.048734269615623264, 0.029381249220140522, 0.009657249789715055, 0.04158281969026693, 0.07085726476244389, 0.051381367694346175, 0.041294751478539365, 0.03873445116163742, 0.12266624358392532, 0.024754181579356233, 0.030856403229277463, 0.06809688909279724, 0.04233026869534966, 0.01301952254688067, 0.03125560590096059, 0.0677438757772888, 0.020071823457856814, 0.18329442658972356, 0.17937011055407986, 0.12859625441412773, 0.1214513200665674, 0.1370629968662416, 0.19859190008813338, 0.1173311536530814, 0.10994196749262272, 0.212981881153199, 0.26765304106858473, 0.1260558608919382, 0.10873390812306635, 0.14279362565327075, 0.08665519285826914, 0.10546026120503103, 0.19306325804321997, 0.06005243345674488, 0.15025172142251847, 0.17290330191533412, 0.23192008025944236, 0.08750606373312973, 0.13655929405602718, 0.13673645954939628, 0.12770636668128352, 0.11627765252224861, 0.11068284346331513, 0.10801013889572314, 0.16658656990095494, 0.16943318408823785, 0.12234346775878822, 0.12069914429899185, 0.10767043252745945, 0.15085328430418046, 0.15527263103473574, 0.28555170482685494, 0.15438102726494113, 0.11146018521920328, 0.10825868080099744, 0.14281939685104356, 0.16149147233415037, 0.23445066785620106, 0.18470574440735002, 0.11306731511027583, 0.2815457391402414, 0.08101208961658901, 0.2819928586963685, 0.18689464146812118, 0.15515535829528687, 0.24111687385987854, 0.2699797726686924, 0.10634415813030736, 0.2214478268738716, 0.17495799569352982, 0.1566251592650529, 0.1357143143973043, 0.11539251453453496, 0.17410409877136832, 0.20443503654772238, 0.13907584692201308, 0.19860224227511114, 0.2106518553750169, 0.13908048941483422, 0.11190059384511364, 0.1517869003357426, 0.1856848813833729, 0.22074192281692262, 0.14468731839329968, 0.15306907105109385, 0.09306777779373432, 0.24166721610292313, 0.12172625370083318, 0.1162282168684948, 0.13849553531937062, 0.15134200243459595, 0.11369470281586533, 0.07945344543024417, 0.10409100161444756, 0.26265931225592093, 0.11588981284970239, 0.1340475062569303, 0.2588978511912208, 0.19060794624590105, 0.17886057015388243, 0.20075692584918392, 0.11304795606842927, 0.11242301218331822, 0.16287222324359804, 0.15263816191544458, 0.13615009585215201, 0.11774774460542588, 0.18233278706189127, 0.12625236244451615, 0.08665179142788534, 0.11131265966762459, 0.1899320268703084, 0.23049120370659137, 0.16880254050897014, 0.10936574679949593, 0.13914485612223226, 0.12669674706675355, 0.30322259532347806, 0.20389736539894537, 0.2009220944056588, 0.058103636012322483, 0.04765090254706241, 0.1502033659527379, 0.15371047050481842, 0.12332865682941292, 0.12758964552514016, 0.2927906841279999, 0.1431943509247034, 0.12692167814220154, 0.10659495233407906, 0.2258667139516723, 0.17707034524890686, 0.14397986683874361, 0.19935875410033813, 0.11023704923929707, 0.15661945957089626, 0.12504773514886058, 0.11103609426608009, 0.08633348955622605, 0.11195358414683612, 0.20293267684117441, 0.1697368766631811, 0.07800685692458384, 0.15727507761649548, 0.13606346662967436, 0.18229595355449185, 0.11195571387126563, 0.10080944100815444, 0.14679301830549396, 0.18242536112666133, 0.16533479755443914, 0.2941324718056187, 0.11489597464641256, 0.0965983322971771, 0.23094060620473278, 0.14481064322735035, 0.113087892231922, 0.1161381402503579, 0.18952331896270477, 0.17684041161931333, 0.12519874640049475, 0.1656967281333862, 0.10849678092786383, 0.06336646853014827, 0.1031958585184428, 0.13228234774883718, 0.2180213607367008, 0.07797450503154148, 0.1082914770250359, 0.2116184131873231, 0.12585234963485312, 0.152083529580024, 0.09437474677519453, 0.12068654981351669, 0.12425380758941175, 0.1019013844310276, 0.12024480819461808, 0.19588189469950815, 0.18034829758107665, 0.15873495008676283, 0.23437926846165813, 0.05978772709626825, 0.20563353513998373, 0.1491202248801147, 0.20330680353987604, 0.11564328575566893, 0.14111500443710437, 0.15422747260139835, 0.11512089040010207, 0.11625354373527151, 0.14404617940946934, 0.22221163185613774, 0.1241230593633748], [0.020432664276731592, 0.0296041022820939, 0.025801450584924994, 0.021386577807847532, 0.11232472310263304, 0.050923250946066076, 0.04564618068416754, 0.06896577835563691, 0.03192219624085532, 0.031150933392646334, 0.035093399966436054, 0.05626687509638648, 0.014334950096634849, 0.05858508013789693, 0.09722250243348461, 0.023481973837460243, 0.022043151548132304, 0.008574486973004477, 0.011447213267186477, 0.03978235602018334, 0.08964174832668036, 0.044817196941303636, 0.054238400677399295, 0.0453781992978146, 0.042194583032640724, 0.015825308078239043, 0.0662994782830919, 0.03741538948229244, 0.040389645409079335, 0.09789048513818173, 0.05987708359175633, 0.015823651413102786, 0.03725714253021344, 0.017320926211053328, 0.01421732591435073, 0.028896999297543403, 0.016003466613079994, 0.026280487279197382, 0.01501007274078626, 0.016932808831634543, 0.024808845783193267, 0.03832609565447896, 0.04741684353399662, 0.04463972501276482, 0.04283124806299325, 0.03340994856590706, 0.0503526188643469, 0.026398213925741376, 0.03131820869091297, 0.02696021411177372, 0.09819005616009237, 0.022126494253414775, 0.011897633704657276, 0.020804986838371526, 0.06493526721192945, 0.016786420920623407, 0.0483636247865375, 0.006148054296406167, 0.006331344183924939, 0.059923493198209235, 0.07669210448981294, 0.014781099593927784, 0.024907360859816114, 0.06118783704756249, 0.020505540305748582, 0.015568919517400285, 0.06152814479484674, 0.04991725492741793, 0.08874003219628528, 0.06760442479243202, 0.08233914542342387, 0.06262344368282827, 0.02735612835104187, 0.05198191933994813, 0.024800211972286625, 0.12038943027296375, 0.07357527576987782, 0.04329869959263071, 0.04161126836533508, 0.0675778798458557, 0.02665596420786554, 0.012228494630225245, 0.055747555583835616, 0.05302050856933479, 0.06921485652245822, 0.07155246657109068, 0.04555445314655381, 0.08056997261460751, 0.025217787347613804, 0.09402829883319717, 0.09312663632895678, 0.042305321042095466, 0.04271569902137403, 0.026476397028853817, 0.003118597904235245, 0.034105575553351836, 0.0331073859706521, 0.032983540196812926, 0.032356933900906194, 0.022571114447688865, 0.029112455780587854, 0.07301617714185869, 0.027305744663481752, 0.08879760370379494, 0.03388278569365221, 0.0874049018227285, 0.028104412391962066, 0.0782018569448302, 0.09199984356640808, 0.015362881127774957, 0.09356204240072159, 0.08149230417104499, 0.035862008319987405, 0.03948416012609678, 0.05485720819823685, 0.03293056904728855, 0.04288814541312956, 0.06649450894685523, 0.005730946713517751, 0.0056576455057027845, 0.009226942033086334, 0.03690147855048699, 0.020555644371216337, 0.03371644119221357, 0.05474189664387415, 0.018578561045409694, 0.05707677558905656, 0.013781411351726182, 0.023300227138303944, 0.03633955305802726, 0.02853032854956485, 0.03616541361195907, 0.012874537534380873, 0.024097360775715882, 0.02866681668937447, 0.040776803263372956, 0.02733627901292376, 0.03109459911713437, 0.021424625564606923, 0.03290721102647724, 0.04276024320373132, 0.029425372054139455, 0.0755145124370052, 0.09235753001825464, 0.07393116957598156, 0.018904200124163783, 0.07078183574541923, 0.04292393321051233, 0.03172892374887822, 0.05178551737880034, 0.03041808027774096, 0.03772127306869915, 0.03982285525830042, 0.05505912216199983, 0.0526285779872729, 0.032131797896938465, 0.03596964367334882, 0.03326836402618116, 0.06068889547379748, 0.008871491600368774, 0.05606940827302395, 0.016328327154981035, 0.017383720522986788, 0.02858092291130414, 0.028998180360142744, 0.018534426720091896, 0.05017683999012074, 0.010438040856482282, 0.04886545834221667, 0.04516253788625041, 0.052867651045803106, 0.05456995587014864, 0.035103301652857376, 0.012419792530577511, 0.03730407690689449, 0.022257265462089452, 0.029575653607025746, 0.049566428792933305, 0.06280873353863436, 0.0029009867989037547, 0.04508113721385599, 0.021043136760952975, 0.054295432092922355, 0.04791018883547476, 0.03294912752725425, 0.04168066060951641, 0.0472262523497545, 0.13992746090216024, 0.02417803174936243, 0.047818794546108094, 0.02642996252454337, 0.035686968720608184, 0.054772034542815345, 0.03870008062691458, 0.02994377609162081, 0.024526940748816537, 0.08299336918900091, 0.044958827446304986, 0.10747714088328424, 0.05347764089463219, 0.02424232567840767, 0.062383037631309805, 0.06217461192019044, 0.04324588932157044, 0.011935125090061657, 0.06149738253424726, 0.031262763077393174, 0.0337104159106891, 0.032329071283100114, 0.021193510244390177, 0.04350102341343318, 0.03845505506521271, 0.03312024092602153, 0.07999611913316673, 0.06676986392947935, 0.04842201217768654, 0.01400308655349598, 0.06874175892481882, 0.023484126544527473, 0.05986136346755009, 0.06031612858116146, 0.014817375772362276, 0.03329229278249606, 0.0026967448854608644, 0.006701007941662665, 0.03024055280782763, 0.023608353447108984, 0.04531774729970963, 0.02271377725616819, 0.06083660105603838, 0.00441983032355746, 0.006733203265485504, 0.048772872786127755, 0.023170331185082757, 0.005863191683836763, 0.02260174647334122, 0.03378655355904372, 0.028665150448139158, 0.06378497087186383, 0.09285119707666098, 0.016098481625498786, 0.06109062815085054, 0.005360944919483436, 0.07171047220547354, 0.02602509271744038, 0.008224811885626087, 0.02420053749735798, 0.058744916722418807, 0.00855394145248518, 0.10094754367826447, 0.03427455539725, 0.05019198554838377, 0.13101782769926135, 0.050507234559664806, 0.0393943363169749, 0.03693875638888248, 0.054791979641923984, 0.01860297818277632, 0.04422999820822189, 0.06563093633421006, 0.016139695240605264, 0.04264564028069858, 0.028541837105407353, 0.04531955526721093, 0.0158316005329271, 0.08299582833123785, 0.007715485990047456, 0.022906398573409648, 0.03505466656098443, 0.03444009933680777, 0.014428512414827224, 0.030592476363263787, 0.046757567418558944, 0.027686473124870853, 0.019073501724990147, 0.06131638277081713, 0.028228715903336005, 0.04440773060665496, 0.01981451367628911, 0.23358647471233723, 0.003516175990713941, 0.035238401258304235, 0.012327896453620446, 0.043464224379990375, 0.04197401865836113, 0.017860958825856928, 0.04948995406589201, 0.04406741519849147, 0.05276124909399979, 0.016708509778724085, 0.04887503061083056, 0.03493284325926535, 0.07144155236141336, 0.021766605298785914, 0.03221457178193716, 0.0385730670795085, 0.03918997470229384, 0.04387026247117789, 0.06520977183695763, 0.02713327145864887, 0.02456860061013891, 0.011589336941289085, 0.05083470650377774, 0.0528673101366768, 0.04146203826812487, 0.019786658719362273, 0.05426995200856079, 0.025290575276519504, 0.03717851509610492, 0.0351879237249734, 0.016370776086865414, 0.014889815131262427, 0.05172107406260987, 0.036467719567759384, 0.08853632941721909, 0.0172150949947536, 0.04295469547111181, 0.03958988409008711, 0.053644307152999025, 0.035477087442432685, 0.026515289397549727, 0.04286899321502255, 0.018249288794674703, 0.029960513197546525, 0.013772412691445602, 0.008965708923736408, 0.03443980439295692, 0.041420968294504194, 0.02988901612679324, 0.021602675889528567, 0.08214285837546473, 0.028141690230357553, 0.08109331025832123, 0.04277757594301816, 0.018414321370543014, 0.023595412306848074, 0.05788060483492671, 0.02073611744919852, 0.012798007265965064, 0.05467436599334883, 0.023598256408266967, 0.040555105078965425, 0.05712463310168636, 0.05851144759705471, 0.01075172609078788, 0.03148498411680902, 0.056008600044034185, 0.08126771017428368, 0.01312909322986079, 0.06337368890883462, 0.02699728319120984, 0.027163928382158763, 0.11137891095131637, 0.1412176908624749, 0.12226679767932623, 0.13641615818825462, 0.2056680703836103, 0.18789369673017534, 0.16411933777553422, 0.2192976478967936, 0.09899736727557837, 0.14726342693451913, 0.1378053207431109, 0.20640814196198218, 0.1305897684106904, 0.23476661783793282, 0.1363492021036725, 0.11912560736339901, 0.14243590855790725, 0.09054862022880586, 0.1313371791113769, 0.16376859208028163, 0.25121736009755447, 0.11511847722314059, 0.20049299323751082, 0.1700348695439677, 0.16789858740183616, 0.16342959817378752, 0.14927210947198255, 0.14218558166776935, 0.10708989875931894, 0.16976347523591212, 0.17568220925186911, 0.1253278858418907, 0.12848738565920823, 0.10436299347108412, 0.06373017643307967, 0.18088627516502337, 0.16693342386955218, 0.19319424375651345, 0.15553077202170126, 0.18029911473633783, 0.06827659033719571, 0.18875461101772326, 0.17016844463444528, 0.2030429168934784, 0.14706474969223624, 0.13293732228058, 0.1353709384678833, 0.051916265604837294, 0.150376777615278, 0.12733002598848076, 0.13415826724902277, 0.18133921698937494, 0.1890905865377957, 0.07768978079360339, 0.20068514341067886, 0.09161470052335532, 0.21451180470326256, 0.08378031002658029, 0.16451836233177494, 0.1718377655432109, 0.16837475701205193, 0.0659797438270142, 0.14449833982413815, 0.13731790496216667, 0.19450926432205787, 0.12026143230257497, 0.10584395634190691, 0.1886131911869011, 0.1764613972796548, 0.12966128516822092, 0.12292869764590457, 0.11611078325058184, 0.09970029891138116, 0.13427743988652385, 0.15688012864801193, 0.23142633659224357, 0.2357018886194114, 0.1293555241558821, 0.09350039530545474, 0.1792379757089, 0.27804398188187235, 0.12113816630575927, 0.20096263577861173, 0.15266066957865992, 0.16690596727834595, 0.17321307722839618, 0.1417710514919412, 0.2032661702363722, 0.09806863122409391, 0.24750016359311922, 0.2798311730786678, 0.25192583820992903, 0.18603224097000015, 0.17705243411323718, 0.1049197938353304, 0.06983367170417501, 0.16481614070794276, 0.17243791882309223, 0.10200055451282572, 0.13582257794276362, 0.10434959459328845, 0.10512223256932152, 0.10258599890456085, 0.3714875258024662, 0.1136296236466977, 0.23838190932668027, 0.20345928568032481, 0.1264658098619792, 0.1683497978674789, 0.08196501872472226, 0.2030931262960357, 0.10902535861297961, 0.1120023149996996, 0.15546617548792593, 0.10542699766735877, 0.16638168734648537, 0.17606566690148848, 0.12872082031061574, 0.10959070851846088, 0.06091720116655193, 0.14679363117583338, 0.21325516003754832, 0.07755406065693787, 0.14428666973065946, 0.2331232673098003, 0.08400859656713663, 0.11957155480500191, 0.1378275526146735, 0.1327236603584982, 0.14168531093145573, 0.11776921804994346, 0.11213097946658251, 0.15838616557659643, 0.09499652671717829, 0.16966730055789794, 0.17390093225384914, 0.16751114609501055, 0.13635415103166335, 0.21987989004100525, 0.1286443953792895, 0.16441111002237568, 0.1728185572691502, 0.15776123701324388, 0.1473784473754706, 0.11958018861590855, 0.17800150979911128, 0.15321580753211053, 0.19211088817927147, 0.11896515024765847, 0.14747845249310618, 0.1593131472867343, 0.10574225050907944, 0.09723868987132465, 0.17318992605132444, 0.2684456049915283, 0.10591060599131931, 0.12405084025475288, 0.2513572937178035, 0.08547229181614616, 0.055823743027905305, 0.09897972427068219, 0.102701356424199, 0.09237894983661753, 0.15067328428549154, 0.08537283828181606, 0.12278811285091985, 0.16162092587159527, 0.20203980136542551, 0.16849930758678144, 0.11914024730363201, 0.13784187845885754, 0.16734853627220278, 0.11071529494778765, 0.17874481426852365, 0.12589901205032103, 0.09844281154895022], [0.016962561771393787, 0.04908527195033047, 0.020384054082716187, 0.0715681100865045, 0.03989435807471314, 0.0325514244726829, 0.008825996511375472, 0.02127048867424169, 0.00706942584891353, 0.039449318447300506, 0.06303022870974195, 0.02285040520702399, 0.04041255909889456, 0.011623740992358616, 0.03601423382098156, 0.015870213279530646, 0.04947282817034472, 0.0389592175281817, 0.03693727783918862, 0.007605802309098504, 0.04496943393361665, 0.014978435224733286, 0.03902656814804481, 0.011294437140496749, 0.05267550853351432, 0.057569373954808524, 0.06821698103580745, 0.04915511618638712, 0.02985194896257693, 0.011085660944152023, 0.017485278883888837, 0.03134590468459553, 0.02151650248936588, 0.07060355942455993, 0.0068913874941157, 0.11823005057991513, 0.04281447839833075, 0.016321589411686988, 0.012776333680977265, 0.04565926929635387, 0.05733425774040723, 0.010656131724376353, 0.05636533654685463, 0.008830661029224435, 0.023257234283993324, 0.04429583963487418, 0.08185781238059844, 0.02007827966383869, 0.06245223069263082, 0.07567308497645202, 0.03613548255675743, 0.03056574180992621, 0.016938010568640405, 0.07616597062517559, 0.042856609403726556, 0.05705663513752723, 0.0513600742804908, 0.02835022319378632, 0.030628279482405034, 0.017508673293876554, 0.006450761490756827, 0.03011246482210775, 0.005236539422654577, 0.03977064253582109, 0.017360856628886635, 0.020338460359902635, 0.03528770284667131, 0.06259938469156623, 0.021205007308913816, 0.02840356781117378, 0.016247834296776884, 0.0534669577985281, 0.02408579859371868, 0.05158156562115877, 0.07341869505903414, 0.037334368023420536, 0.02893841018029038, 0.11079846145284754, 0.048748315837714946, 0.04269304197101344, 0.025430150750663974, 0.07622820760814414, 0.04100228592212643, 0.04931066267853303, 0.01807758933864534, 0.037936892345427506, 0.05721239230385231, 0.034247140940879627, 0.06344958140905346, 0.08656698549466749, 0.10236852952549536, 0.06437478196476737, 0.019057028919398304, 0.05397071040445759, 0.041014853594524246, 0.02561901440663684, 0.04924991190613759, 0.05233087621989751, 0.03248791578376005, 0.04375511945615854, 0.11425642146458549, 0.030071369950629534, 0.02464860125685171, 0.04035725904208037, 0.06795269602368917, 0.053470274959240234, 0.022909803834233074, 0.05349977700520427, 0.044616953049215584, 0.05440840324867637, 0.0417974928484088, 0.027326884859752272, 0.025506493327538335, 0.03468492571564932, 0.007588559585142761, 0.04192486262669967, 0.02073698504377277, 0.013858645463422423, 0.02792964858423558, 0.037722510300696864, 0.011213555492671027, 0.011629656148743967, 0.02931211744585345, 0.05886068792953607, 0.0629540680787496, 0.09941047252786737, 0.02672257938332135, 0.09047139090515914, 0.030156112681593628, 0.053903566628334024, 0.03270292602058861, 0.04211558787632854, 0.05541117020672368, 0.04876281788212158, 0.022726557517964995, 0.04179738176565978, 0.04500080906455556, 0.03190317810813506, 0.03860705073982958, 0.014936447860823284, 0.035649468716714657, 0.08265717916430966, 0.019058549603928002, 0.062483605823569724, 0.108273274775955, 0.011999803978288847, 0.05050351520279243, 0.022146967953191172, 0.026609386062069286, 0.04320664646764917, 0.022459210069369406, 0.03937521093194524, 0.03198862563998949, 0.016459743792731917, 0.07993739849377064, 0.009722937041172578, 0.05621945808431315, 0.01356222497810039, 0.07165812541760745, 0.013910459820181133, 0.033464674056778033, 0.017854192354265722, 0.04718062798342398, 0.017367157702063842, 0.046724951225182706, 0.005491591638870417, 0.015592617489727996, 0.05654478498223809, 0.006046096133368631, 0.01721539376904407, 0.08101170657262688, 0.015859890244750968, 0.01981295851780282, 0.031807160478145365, 0.02307449741619489, 0.04184573723544036, 0.042701955404012434, 0.0357970938597235, 0.005761889483584392, 0.015271396823077193, 0.0677934876312652, 0.0234722655882398, 0.05613925633952022, 0.0367096386429283, 0.07666745178040958, 0.025468851597378814, 0.013783687590471199, 0.027773330258505962, 0.01773592178529549, 0.041941528869492394, 0.0505292289439709, 0.03621958368908494, 0.022796729256609277, 0.01540623787384961, 0.04538938035106948, 0.06182394283373029, 0.056807407583560676, 0.022453849369119254, 0.024464437550294305, 0.01315898885349593, 0.06181663052449304, 0.05703196710636539, 0.018013496507680225, 0.04287049091691452, 0.022157823419078224, 0.08807217206565604, 0.026606068901357152, 0.04457774466925091, 0.014332102164776336, 0.02377343964913199, 0.024956660532963373, 0.02772543635669976, 0.07318479309399283, 0.015560851653947707, 0.0487909218176238, 0.061585547763013074, 0.05214621838662894, 0.035958255776354385, 0.029644563215814775, 0.04368015009188845, 0.06710441452601264, 0.040723341817577044, 0.02048457822492046, 0.05488975927413953, 0.03460048750463513, 0.05712050388777449, 0.026710971236048688, 0.01667541861083479, 0.03253625593178215, 0.05683759910865657, 0.044885091483592994, 0.026339221325132157, 0.06490152869974414, 0.029900720035056436, 0.0644162196605917, 0.06321198690021712, 0.08100026887991736, 0.02777490648441017, 0.01878510409545514, 0.05580281350581397, 0.07566482654862827, 0.04190328192987269, 0.013541711058707969, 0.03354686763017409, 0.014976975827237532, 0.025500180763042262, 0.07041612835300547, 0.027308257431873394, 0.008163538258222323, 0.0202132988300535, 0.04035393805092862, 0.042354626460902156, 0.05298253359092821, 0.0458800558361315, 0.06506833668437696, 0.02389848052013305, 0.00023102741461996395, 0.006261837026554972, 0.028492995169794852, 0.037381371348014766, 0.028992993944895365, 0.014682123906940464, 0.04302823608140311, 0.03577434104837237, 0.0127036769446286, 0.09768377163357313, 0.03386048487417641, 0.028668413982696594, 0.027328212107081088, 0.026330344281309558, 0.032613029433113915, 0.0007918385334403044, 0.04067276469281605, 0.06219919185124098, 0.06378070376212559, 0.02735725066985094, 0.06210850619320428, 0.03171715472314147, 0.042491928569131324, 0.012612946278926347, 0.026041412305447365, 0.013659134142911963, 0.007102247449614469, 0.060228966927576455, 0.05161597829071745, 0.03565256754236837, 0.050370304004078915, 0.042458170904747905, 0.04585880072667234, 0.04910625509857651, 0.01917863580127878, 0.010582413956252559, 0.08421861957157813, 0.059244045987725265, 0.02157353390488894, 0.013552727403059123, 0.025680301440579277, 0.03566885457163857, 0.03800780527413853, 0.03156932082117325, 0.09039771622948109, 0.04610764140623712, 0.0491834614395855, 0.09752482371104342, 0.04191035675185342, 0.08907735603110445, 0.024008339443694682, 0.012930300116779344, 0.02627596736044413, 0.010121422463036593, 0.031620690846935876, 0.01760603923861298, 0.04688233249790726, 0.009657134876526412, 0.07326668789309841, 0.032867205915071314, 0.03093306564786021, 0.03774183103814721, 0.020118307757882342, 0.036133145988588376, 0.03211622907509727, 0.027061176839314645, 0.038515070393200845, 0.07006972637628356, 0.026660313672055642, 0.019320827465684667, 0.04061353843538992, 0.04934538178326142, 0.04475988973412783, 0.013080616143622227, 0.012505329120153142, 0.07325100607328838, 0.05375501068849718, 0.013697753592784847, 0.03276150110327909, 0.02219730567547583, 0.026484638219699267, 0.02023151448567308, 0.026987180406708392, 0.030289126612666636, 0.034466272730740814, 0.03475743210724285, 0.016521088283268676, 0.03175041251515429, 0.021778205785179333, 0.025847011749001763, 0.031170681224114476, 0.032645097873624296, 0.059336309786885984, 0.014094114078268891, 0.03384267332993689, 0.012955818505537127, 0.11043908194668832, 0.22748855273089102, 0.07010942505251977, 0.16571200392659635, 0.14980296243823346, 0.16327022124202023, 0.11402664105257682, 0.13953202163740513, 0.19980472452457876, 0.07419241321904045, 0.16789348525626047, 0.13544938587132963, 0.13244950813391518, 0.17986215350608672, 0.1266948778122183, 0.11814690705749298, 0.08209607338592892, 0.13530707737851527, 0.10408079732329616, 0.09826314094806872, 0.14041106156524152, 0.06834664141699191, 0.09372631463432506, 0.09837092185813574, 0.1524542701701003, 0.10889667116345898, 0.20795842812907314, 0.13474928876084669, 0.1591237090648182, 0.17486672397823105, 0.10052373617767327, 0.13483381890241178, 0.14141066841060115, 0.09409275747114614, 0.1304699675810914, 0.15718300916975544, 0.2012252353972966, 0.11992529590403843, 0.11546314018027437, 0.15298185960179375, 0.11610823983867323, 0.2522849802288317, 0.14324336523009887, 0.1536135144171215, 0.13210000350109993, 0.10876123447932544, 0.30755561926672537, 0.155372406325994, 0.1687338224221622, 0.22392176992950902, 0.13236218943230568, 0.12877876720120832, 0.13511229186288773, 0.23219648478252275, 0.12898197968400296, 0.08653117854508661, 0.14756829928486578, 0.15241541419058077, 0.10112827914136072, 0.08805720270761559, 0.12242294172005308, 0.08562429898208188, 0.16425888835182115, 0.19615180279699065, 0.17003833226138548, 0.15580216632975688, 0.08896785908408704, 0.18704781308770183, 0.06759830374991702, 0.1164317817517346, 0.13795489174944742, 0.17285460936686686, 0.11118379601788138, 0.09503288525006465, 0.16212761642471438, 0.106477105028687, 0.2600331628514875, 0.185866306325601, 0.20551454636358446, 0.09645656006590975, 0.1605062526200087, 0.1587061451808099, 0.12237579666919286, 0.18579622460228784, 0.07300048000029019, 0.08969992504365022, 0.17370672896504405, 0.10591063663483628, 0.08678158204401694, 0.1408636663109064, 0.27402922150588804, 0.22533334821702974, 0.11258857910551372, 0.16405199864698997, 0.1441932529691727, 0.08221727615642933, 0.17362296491140322, 0.165673530991039, 0.17915228111368997, 0.3204795531928539, 0.16590718780794453, 0.15758856079511105, 0.18593203666950428, 0.08221159944491041, 0.16925034954422907, 0.10145308509949716, 0.1211779032863917, 0.12720518430034, 0.09307002243135246, 0.09703706319053328, 0.11470237656706765, 0.16440058397429605, 0.11440597714916353, 0.11661461629574338, 0.07951188261710829, 0.10943268756231955, 0.15899007268730672, 0.12185395289693149, 0.07308769911046951, 0.1555399957203096, 0.10545884394237112, 0.09963466049802881, 0.13364849702244805, 0.14951901960997813, 0.14470031124449548, 0.1526134172754903, 0.15076941299823024, 0.24211445823311809, 0.1560576719742629, 0.21343039498934824, 0.10583095582983187, 0.18088681142657034, 0.24186468292628568, 0.10397361396181007, 0.14879423914657486, 0.10931946742799013, 0.13789424822936136, 0.10601403552197641, 0.21739807160150623, 0.14723995400051917, 0.18723092342336334, 0.16152023127482784, 0.10905635453039601, 0.1901987173985089, 0.1635232141181346, 0.10508036586425959, 0.09307549229913181, 0.0957440599919327, 0.169174813274895, 0.2154971623132306, 0.15056722707325412, 0.11994147568099922, 0.13754782327000173, 0.1695494915569021, 0.14714946369490317, 0.14554476996342983, 0.1688414730972821, 0.14139130170787537, 0.11751851577672268, 0.1155491948368088, 0.13185030480305995, 0.2020954040269698, 0.293836148996507, 0.10529325403753789, 0.17359356245686933, 0.1626622998305867, 0.1898746162412628, 0.17853178053853974, 0.14248990243481052, 0.1357241203227351, 0.18791344647686328, 0.08345215626421475, 0.14146766535216762, 0.20404600177801427, 0.09755739776958382, 0.11435801238422433], [0.025359377632999135, 0.020447725565322948, 0.035065816970722335, 0.11442465437275749, 0.02466687819950523, 0.035125866772667054, 0.02584750013005349, 0.03718868874373936, 0.051598304642304305, 0.05916720736891993, 0.021751833208385977, 0.036750015306977496, 0.017464106128881537, 0.0547309339256777, 0.02895615469183653, 0.021200041143944668, 0.10273153262753641, 0.025800560007713018, 0.020511192119409962, 0.07255903715568204, 0.017393323435117642, 0.06524064518030613, 0.027016847161576155, 0.07149088076285778, 0.01976438662818363, 0.05131737637003103, 0.02586645697573981, 0.04404641672848694, 0.041594717035731005, 0.06724123782928913, 0.12735666286560798, 0.1041184811882915, 0.04823209515081779, 0.12339582741861382, 0.024915291785052227, 0.03644307068879566, 0.05787981193392508, 0.02447396002319311, 0.04075078308702477, 0.03392550658674971, 0.03739201230928302, 0.010151372670436339, 0.021785826444806113, 0.07139436134527768, 0.025018886024613055, 0.07832466083909236, 0.008811123871935472, 0.037203405292764787, 0.010479347359749579, 0.025443838826651057, 0.013139589592033337, 0.03462134041793404, 0.02690279965228852, 0.14244375329825187, 0.03160187764273536, 0.09189525724298532, 0.04099022769819825, 0.02147987199526641, 0.06243489029246473, 0.0372940028506902, 0.020931536902583415, 0.05188848725670288, 0.029261745249612198, 0.06693344668395097, 0.02482652517726585, 0.037431553937494755, 0.043734025225163474, 0.02273908497074679, 0.02005520701077917, 0.02006900042385584, 0.0671317715257887, 0.0234784402569095, 0.01180001207807612, 0.02530094236135483, 0.0431338987583595, 0.08731382929029004, 0.0381190489016233, 0.0069921093827654286, 0.06707554067214651, 0.020036188878058907, 0.01586380303882423, 0.0435409557464863, 0.08439033051892635, 0.009141187108452282, 0.027110503325539253, 0.04377699126639674, 0.04378996879583405, 0.0542469923534701, 0.0525284617868883, 0.015198545691917743, 0.0230486017291344, 0.059748733220922376, 0.024100451940490354, 0.02208378868207576, 0.043430447563408844, 0.0878644856293836, 0.030956873745327036, 0.08324446216706308, 0.02726012029715123, 0.03095508876046346, 0.03548780884293299, 0.0637563306748146, 0.031525328222121445, 0.012734116490689978, 0.06249713876675214, 0.03008736203604889, 0.01486655287144165, 0.01678116364224303, 0.038558718252686724, 0.032466243156382156, 0.044039732611347596, 0.02256039304718856, 0.040663062189255035, 0.034877248258600314, 0.06772525984072877, 0.030671705176392873, 0.033242481745659344, 0.056469283186860626, 0.0340259790180191, 0.0036689530750135743, 0.048353056603622054, 0.011016318495685776, 0.027516508857989987, 0.023175107743290645, 0.08529750885622156, 0.07295072258960816, 0.03221710753296653, 0.05540999809219953, 0.024407478913124052, 0.043141456215732524, 0.03950810803460979, 0.010900883409645288, 0.051447461930013476, 0.019242249827291218, 0.015234100790093503, 0.07931934939997812, 0.05441563511868158, 0.011643542449981456, 0.045630586964468804, 0.04412212153716434, 0.0043441226420503475, 0.04496856442382259, 0.06604970297625949, 0.056932823837644635, 0.02690820823303394, 0.065864700403425, 0.04686615272094646, 0.03496321481502345, 0.0324588427470336, 0.025519982220665104, 0.015709164360868597, 0.060654850526442455, 0.06806796927365565, 0.004617317256728007, 0.040782181200601404, 0.035258070565760136, 0.06192641092404243, 0.018952500052569855, 0.017621504638584393, 0.016638588933875004, 0.015792458228045897, 0.03539230066141294, 0.06520825498286756, 0.05414483835920692, 0.058722554615909056, 0.041530181788989616, 0.01578776785472949, 0.01541065820117271, 0.01976372779256875, 0.03369246647062321, 0.018998354245277665, 0.06014828637783086, 0.14950633319395204, 0.051782338113914576, 0.054514307243328904, 0.08639980212695177, 0.03032030639118485, 0.040334582839521675, 0.08392313945918314, 0.022814644222718575, 0.01449965708513534, 0.04314139109825896, 0.09539917486930087, 0.0377076443645262, 0.05327857294750791, 0.025807952756182324, 0.014433465173257696, 0.03975431720215467, 0.04638361692007992, 0.05919367570670382, 0.019020666556072333, 0.024851175971449386, 0.033271167907984026, 0.028941426651492238, 0.032584588418925, 0.06966907771364336, 0.05408261669799686, 0.019499484915286303, 0.024783787047190052, 0.020108373512724237, 0.0193217103820174, 0.07713304171639104, 0.0724478318325935, 0.049895103495087356, 0.050504465151818535, 0.07181225464709344, 0.0669514037848961, 0.09037631173287669, 0.07464625902714268, 0.08212721486005091, 0.0218736105448296, 0.04492182156912262, 0.048612201165768414, 0.025765530637375293, 0.021859033806850354, 0.05433080237238638, 0.06196643518764646, 0.04157040140501434, 0.011510004706290222, 0.033588512169737975, 0.023879969920662623, 0.034997838158761306, 0.021176070252793933, 0.10873463590659442, 0.020565138115817984, 0.04517237828563779, 0.01733734922093009, 0.046496170557915203, 0.01889045076114276, 0.02488382855400203, 0.04216891908717733, 0.01248094932957282, 0.0603198211249565, 0.058649826058817495, 0.028434613524305246, 0.06572757066497881, 0.04441843285495716, 0.017037125109064005, 0.02936002283897852, 0.05128399408873051, 0.027642367527850216, 0.05930055263302019, 0.033726534400615966, 0.016369935305368517, 0.07076315086094603, 0.010956175805580233, 0.03418367055635299, 0.021840356583256396, 0.03267094568018952, 0.019880297646347075, 0.04705888512093694, 0.1165335641933545, 0.026487662351780364, 0.0698365138903741, 0.052818200070290804, 0.017200345886991392, 0.024871664992984266, 0.016986377529739853, 0.061682396598400614, 0.026975677596525322, 0.02490070547097393, 0.05810093172194977, 0.030398838064302842, 0.059111608537815274, 0.046621755351342505, 0.04719203886305613, 0.05016212727153494, 0.041704692787701086, 0.01680085210189704, 0.0631938535990494, 0.04169016393021711, 0.01614954904653132, 0.04110048690270032, 0.04666890040220273, 0.018253508023917675, 0.012923356487355646, 0.04407684574083936, 0.024599247957549752, 0.11210753717609953, 0.01648923243215728, 0.06035897204832685, 0.014690511612101428, 0.02144379691491204, 0.051653244637794075, 0.040301897698232246, 0.04761354043899525, 0.03847030787578514, 0.026497508496827176, 0.004276764361307987, 0.056335160343517224, 0.044882283771350506, 0.06522888573066843, 0.06286688727296649, 0.04490117549956326, 0.1250472908178645, 0.06595615597982561, 0.023145025385723963, 0.07085167232059664, 0.03366345089049109, 0.030715960160558744, 0.08275054229964172, 0.01667569823292715, 0.022440387289069837, 0.015485355604229676, 0.0482280348848191, 0.012135394837617153, 0.07407421351320322, 0.04862756122865024, 0.023744900958732735, 0.04322617404883908, 0.022453075620315732, 0.0527444449553807, 0.09858300563909354, 0.031908241949314554, 0.009580583540692685, 0.015257893565801844, 0.018552238264331417, 0.0007847791529192981, 0.01036924903371161, 0.023608250025239204, 0.007237481599253032, 0.05660073238334829, 0.05590243940992702, 0.05339466208111375, 0.031542758637618636, 0.030565584761901732, 0.028955986152493188, 0.023857556103217988, 0.07104173107373138, 0.057992932476824334, 0.06354884725184211, 0.06306546492381923, 0.06961878404141435, 0.027409373376999172, 0.028287120531463338, 0.04370184953234369, 0.036614256865915754, 0.015365290474296819, 0.0660240926569508, 0.06166359297029915, 0.08263891562819481, 0.03521375620978014, 0.019385695960673115, 0.04283409407963196, 0.04012940917164087, 0.03239077966540091, 0.056561386107557246, 0.034963027123481996, 0.13391606089088226, 0.05540814032898315, 0.018174154721500895, 0.04484131721959961, 0.07501829430581101, 0.11539584701700557, 0.19586537784386068, 0.18560114797324906, 0.1755070815523786, 0.11507131685052188, 0.3479244998626171, 0.09797895297167764, 0.19921241598504208, 0.1263158481508013, 0.11881878148884543, 0.23457612241468123, 0.14634200702271155, 0.18727774671729536, 0.1881016896016175, 0.13863698579370975, 0.1985046579953163, 0.09248623278953376, 0.16309641121375948, 0.15956316774170246, 0.24613939225673678, 0.15448418866482475, 0.19207649083147127, 0.15933029233447968, 0.13839062723901965, 0.13587313974576612, 0.15971178879901288, 0.15726318793191066, 0.10622271787255042, 0.20475850951287056, 0.23353856357355274, 0.10385466348980704, 0.12537469381406424, 0.1668476986308252, 0.18037768471385204, 0.14628971386100018, 0.22279251036384415, 0.14696304385940875, 0.1649158547121671, 0.2660411920758986, 0.09946435149158202, 0.09727575320510135, 0.21358580358566778, 0.1742072908147689, 0.10990734797932449, 0.11292799436036619, 0.10900374727263566, 0.24987685944764848, 0.14351308946647953, 0.12587000030062853, 0.07368125637332279, 0.1204947826843108, 0.11912991277753346, 0.2697288022646981, 0.1157163552218868, 0.1653275043974, 0.1322740280339795, 0.12565904266891942, 0.14186479001035615, 0.09701296206443541, 0.141468339509541, 0.10236479867730411, 0.0680419376059886, 0.16449547162459743, 0.20218594029786127, 0.10597576176927936, 0.15363009255980292, 0.15558838183360715, 0.1713359779528072, 0.11765478749669368, 0.10345498009795144, 0.0813793751501268, 0.18032156111251924, 0.14258060724504534, 0.1616997716407622, 0.21685324519151644, 0.13538322651818877, 0.09356932023600226, 0.11884500467849356, 0.1270018875478737, 0.09841990552001423, 0.1245390987324138, 0.23347980462976042, 0.12692945393463298, 0.08913648269710042, 0.15589199779975801, 0.2900442589194544, 0.15593768728356208, 0.18823943221040312, 0.07938491886541729, 0.12984811869119445, 0.1826465153886426, 0.12232435386507742, 0.18090204125450504, 0.13755091826521582, 0.14230746625652238, 0.11216559897988074, 0.17951623416475712, 0.12796303677943446, 0.15783706439598916, 0.1885068888265279, 0.1691819378925908, 0.12297264811012054, 0.11036566008002528, 0.17972467136719536, 0.11663410557253708, 0.17072096256719482, 0.10071112128395228, 0.1588858694078461, 0.13596894670157664, 0.17406449202568303, 0.2107697409848052, 0.15370503128055604, 0.0959478393797913, 0.19942652223811996, 0.21395006307190467, 0.16065760095032955, 0.18437169942884676, 0.20288966866510533, 0.10085989555884754, 0.19362080151275282, 0.2071119009727432, 0.09729840642502231, 0.15769250360467743, 0.1489195251657117, 0.1313191760451563, 0.134686132472369, 0.1316035785261662, 0.10829937539153522, 0.13179076444958487, 0.13144043244181142, 0.10654923986763724, 0.07747950498014688, 0.08939411806603594, 0.12010433831282201, 0.2579839082975542, 0.24901775312760185, 0.20324821313542707, 0.11581239966495384, 0.11692919498009068, 0.07489786528411412, 0.07928157360443185, 0.10324832021949754, 0.13087843034055927, 0.08724394674983718, 0.155030102919667, 0.21742399601686388, 0.15175277877959514, 0.17210606485605243, 0.15009988279592607, 0.1885112708494548, 0.15918418404556092, 0.20583596621309558, 0.15400538371214945, 0.1112188598621757, 0.13804414099262607, 0.13204271544612226, 0.05343062224827948, 0.1723568054336694, 0.10664434968343667, 0.1117694549142353, 0.11018552216550997, 0.16793440967317552, 0.15993783070195108, 0.2298206163029517, 0.10822861184996944, 0.08570448540511631, 0.10793381355582707, 0.13328449800610542, 0.10975065235529216, 0.10681243703490305, 0.1530742344837035, 0.21316358188707984, 0.1887798919192245, 0.09347420275932358, 0.22963730678442987], [0.03562287397442326, 0.0036077620414641477, 0.05796045800971408, 0.07920467369859258, 0.04936560650446242, 0.03155908588650486, 0.08956996588817528, 0.06192538819666352, 0.010093304163385785, 0.03882312200843327, 0.03545514668428129, 0.03134583573668234, 0.021221171764116135, 0.04748978659570698, 0.04927851762923022, 0.043851715482531056, 0.06945451946869012, 0.04852946366994612, 0.1105633031036104, 0.06809698102334816, 0.014569148920746821, 0.02570627756687182, 0.021299232293160695, 0.0298237550117436, 0.029439795574533845, 0.03345480301387368, 0.019176435213716283, 0.0023460099633197274, 0.030218575660499836, 0.029082022937795812, 0.038181508050089887, 0.01961946577554749, 0.0421289676019261, 0.02788185044341991, 0.038513545878231525, 0.020354823997965264, 0.010705832636073954, 0.07956607567687189, 0.023370285878979394, 0.05507373145871586, 0.0417876486185818, 0.04657366801233542, 0.028492401451653535, 0.08490764671155522, 0.01525560009007853, 0.06481140611633178, 0.06629938635254098, 0.013593576168791663, 0.045796287952051054, 0.034403066646548054, 0.02654987826733099, 0.010912266518590192, 0.05839591004675435, 0.03385491158452726, 0.0370263853561013, 0.027412575624522664, 0.04521892961835669, 0.0692086588711508, 0.06635094406984507, 0.07687261778741114, 0.04924933734019438, 0.06686619948595762, 0.007215458965454732, 0.0376369497708736, 0.06996499449615518, 0.036310403412508394, 0.020304323481996695, 0.06314414598408245, 0.027510117769481677, 0.05674322090682484, 0.05668304470037261, 0.04249483970324359, 0.030276066728777466, 0.07174323012511577, 0.04695539430324589, 0.030087363951268698, 0.019677722931749398, 0.03683469100524822, 0.10857274620643548, 0.03865567050994404, 0.05638324385208469, 0.010093759985700732, 0.04052595543344656, 0.05146641494526018, 0.035670038177481586, 0.02287070462179761, 0.038554776730316306, 0.044322116450677, 0.06850638607096288, 0.03204121374555173, 0.0570180434583416, 0.09502354663826766, 0.025446209868776704, 0.024927838390032132, 0.024301567257592277, 0.04026121076857371, 0.01936456917094127, 0.059632165282363855, 0.02816351032966087, 0.061225325560137156, 0.06366484062445742, 0.0442048896765036, 0.017461066675041954, 0.03761119006441967, 0.03980468748317611, 0.11182970772947996, 0.07714876184059728, 0.0577503469051613, 0.0317698673179914, 0.040101715093178135, 0.053885295431339936, 0.028149776288398334, 0.06509184792277313, 0.017359814749309616, 0.010036596420010733, 0.04723272962315429, 0.02651550773260815, 0.06229309507855966, 0.04779155245952068, 0.02853811966375478, 0.058519663890042616, 0.05015958385962633, 0.08493172485501536, 0.03570128307347337, 0.04641657019214285, 0.028806217878516165, 0.0320400818506436, 0.04214833813509153, 0.042677314185927955, 0.030110846461367705, 0.033521157719435236, 0.02818813814120668, 0.027430329712167866, 0.032217590168358824, 0.08311499330785968, 0.04126597338566377, 0.03349341767569704, 0.039082201453106064, 0.01706857493357553, 0.05857407911530426, 0.02346022651650973, 0.10676728381264596, 0.014621705425182178, 0.04332040286352558, 0.033552061706300707, 0.04688078500030022, 0.08336419404874887, 0.01389307920039902, 0.054571101171595436, 0.08189923475466429, 0.03026916236135989, 0.011110372067759595, 0.010776104923758295, 0.015183002725543996, 0.03895008192968465, 0.06882049744167636, 0.051292892199971026, 0.019637417130833192, 0.04179325638218753, 0.04516002894829839, 0.06176760089733909, 0.03032295705540286, 0.0299418589565903, 0.020998019927872286, 0.01181070187744955, 0.04080788728090064, 0.10805514656127461, 0.03544236833770429, 0.03730703400628221, 0.044847595310139085, 0.009671992194207927, 0.026587983480684703, 0.024255601982135448, 0.03093035752704788, 0.05992410223810904, 0.05046000523913292, 0.024525891208360275, 0.01734543144853125, 0.025909744773901282, 0.059814007742510694, 0.034975610117638306, 0.00862744758881989, 0.016428443355365627, 0.041709036506231756, 0.05446492904616941, 0.0016710264120070686, 0.04269867654769652, 0.020963513412542885, 0.020438134144510955, 0.0335008027632871, 0.09739292635312004, 0.03664044175116766, 0.024581541750399817, 0.02353509054369023, 0.01588269189420727, 0.10328729111220568, 0.031289380802322304, 0.04604878670145427, 0.013249745374665627, 0.03718701484162481, 0.0168901339038125, 0.02710131601610732, 0.06741585991074962, 0.05113610081494816, 0.051065532625803066, 0.010154617052795667, 0.0123351187475266, 0.07267522205027842, 0.02928838021151962, 0.04207768567627476, 0.0064076498928179425, 0.03769888414911205, 0.024015123152264187, 0.010561571576662604, 0.02225702031395368, 0.0918025299606304, 0.07448033204362278, 0.03947715425202924, 0.057706710536994284, 0.025856982383336273, 0.03453629699745967, 0.02044175007951356, 0.020964446124590693, 0.024552685133511984, 0.012526116915978493, 0.06286469243106342, 0.018399187303598852, 0.048376380150476773, 0.05466833688138474, 0.03620115544406637, 0.104440291742644, 0.03518324292775604, 0.05595832552400328, 0.08422254960262969, 0.00991860260030315, 0.020900259447854855, 0.03237561112450015, 0.01238977146004477, 0.013568221531327695, 0.014495802705266304, 0.03305538009191233, 0.05285922407863602, 0.04685514020703493, 0.051761684383475975, 0.0808341503744164, 0.05647157762019385, 0.036244527511899514, 0.03762582234377342, 0.05520899577306644, 0.05175860087958075, 0.047618585127976634, 0.051037497638214024, 0.06638025459382804, 0.020029460710863915, 0.05950763002939283, 0.042905386221865495, 0.03177908910137992, 0.02313311463372121, 0.034188833988962636, 0.039156749469017794, 0.018048345847355745, 0.11490247107201046, 0.03464066881626364, 0.09122502990067007, 0.07427536521948154, 0.01209569807660075, 0.030680771826976733, 0.05152977807747741, 0.06403491088759995, 0.034679854213590586, 0.025797932326132735, 0.033185316264749534, 0.07702825621010796, 0.03175182977781421, 0.051522343194172274, 0.011105388665812151, 0.03949853576599591, 0.020001257183931528, 0.056338787769838694, 0.030569355829709002, 0.029641089007078163, 0.04785914822751957, 0.034457539328404015, 0.04100526600415188, 0.030353389898194905, 0.04231170255450472, 0.055103038152259205, 0.03936525944980883, 0.01771608393849625, 0.005381134687922896, 0.03269227356800149, 0.06295794831408609, 0.02276420116334433, 0.022571168073843566, 0.045130051927821296, 0.07175620765455308, 0.05387124154836901, 0.04013617755845189, 0.06428626050511677, 0.07382396323185775, 0.0695205562477631, 0.07789934414529032, 0.02884670945575401, 0.0208105486367018, 0.05488087265421787, 0.11404210070688879, 0.048797586782565044, 0.038327398003950235, 0.05623024460228701, 0.02857043133718112, 0.0322580702542778, 0.023054602112801328, 0.02067872597235105, 0.07497319470970862, 0.05829427699227968, 0.042979823155028206, 0.04187418974094814, 0.09277341616970879, 0.00818411059181897, 0.028877176772502643, 0.02387862543635551, 0.0530241091825789, 0.03162178826788741, 0.03681966419061346, 0.009805173707014371, 0.02536909354309882, 0.050376700838246656, 0.02732573572786585, 0.08083013607369316, 0.020539995110143098, 0.028317063077983838, 0.05192799441095802, 0.04070166152931991, 0.06485034636552296, 0.013844546572785946, 0.022061484032160333, 0.014578860042796982, 0.048732695304938865, 0.026374066834368055, 0.09484176929559439, 0.044256194584792664, 0.061090697098763726, 0.01901582679561069, 0.06036593578755856, 0.04985392243871766, 0.029007833067988677, 0.0126046514619262, 0.03804176978226151, 0.04436205644460936, 0.02272217741025792, 0.006000832307167472, 0.013471152445661926, 0.1276330520669299, 0.08501111454660855, 0.16144124760983453, 0.14889933108802766, 0.17660997237168974, 0.08581897724540004, 0.2378242739265965, 0.1673254004168895, 0.14190905457062108, 0.1070510734233164, 0.13188588192626355, 0.24019756835074196, 0.12026957581721007, 0.18513588745507503, 0.22302627443305909, 0.13973635260856923, 0.1330972661174113, 0.13482552983107107, 0.19686601124703887, 0.20791849962645964, 0.12069172856788482, 0.11848501230199492, 0.11411659509664583, 0.17482943081807706, 0.08711030271144644, 0.17752465070976367, 0.10005918812126884, 0.11693441969973427, 0.2257562900382665, 0.09923572021145975, 0.15207197697412583, 0.06963680242939342, 0.12025877397747771, 0.18379973818457898, 0.1852510304700944, 0.1559381009710412, 0.1142368785616371, 0.17632402239307282, 0.2533153225217135, 0.15898981221741246, 0.22904778680493756, 0.13060861417362768, 0.17820138213855607, 0.23987818629510943, 0.1293597836047411, 0.15867809104102273, 0.11186903868351253, 0.06759739976616637, 0.20344990876413163, 0.13907920238712143, 0.09031650324862811, 0.11611666680584032, 0.11597617394140652, 0.15926773359458293, 0.25457297842348775, 0.13876303790077088, 0.17206964503613212, 0.23355250637377464, 0.1003346197126854, 0.16810420540071305, 0.1328200035758557, 0.22880461517601247, 0.11682128383507652, 0.12542033733259286, 0.17718993157388704, 0.11630155446548616, 0.13779458019041246, 0.17218576864369456, 0.16783270384034804, 0.15469084854327864, 0.17127649888636606, 0.09442116404252668, 0.15256334576875935, 0.17140469603961514, 0.13067786852198263, 0.18919468256494693, 0.2317260301882221, 0.12732256429209826, 0.14386438674503757, 0.09222945543907343, 0.13330463079675553, 0.19221814048867072, 0.13674200602596806, 0.13943756299634136, 0.1052479552585752, 0.17181064603069138, 0.11893904963207823, 0.18652543305389344, 0.19403772188290475, 0.12185039824896282, 0.10951656652914901, 0.20330720190559665, 0.18230081055193179, 0.130471469113423, 0.16113609946783514, 0.12994276119336007, 0.17670429311692717, 0.1215415575631684, 0.15716992438800875, 0.09805661896544118, 0.18578556065838184, 0.11076401813977188, 0.07511841433663523, 0.09329492286328347, 0.17952075408351037, 0.197540873421296, 0.17673147391648064, 0.17406118252585012, 0.11389134226426964, 0.1370046516099284, 0.3072109716313501, 0.20501059840523428, 0.2180829082405375, 0.09926442552598254, 0.1963607609392174, 0.08382515681366767, 0.14745569968175504, 0.18626955968718376, 0.1540888106871036, 0.15927897976531138, 0.1593031115349262, 0.12540369024199824, 0.08614887002735369, 0.1263943491804023, 0.16412378108549505, 0.14068725158370313, 0.11047055283861776, 0.1273082537696727, 0.1371565821670717, 0.2288259890290999, 0.20267467375003523, 0.1614338318787275, 0.14596354426635852, 0.1438592692777034, 0.1652708292127617, 0.10377472987578762, 0.11933326315615447, 0.17424058499595813, 0.20577785078315966, 0.10418799600654072, 0.1442364603281021, 0.24064603622161576, 0.0884204816013094, 0.1483601277634021, 0.18000076945510604, 0.09809480078758732, 0.12621466325776232, 0.10129142522571549, 0.1873323228210211, 0.1364387731037794, 0.1320486143231392, 0.12224828899507562, 0.1398402800963771, 0.14799284989074354, 0.17491645840627534, 0.18191362971500044, 0.09131394206516205, 0.17424778622244635, 0.08528627800725161, 0.10542263096619038, 0.11197059129875515, 0.10906427587953307, 0.12548734704332967, 0.09550258141732025, 0.14649763012364989, 0.18109455914987674, 0.14869205833923432, 0.19145215981669966, 0.201342431527953, 0.13613394671870818, 0.10297648924132509, 0.0836420005127307, 0.13180622410389686, 0.14985911668308322, 0.12805694383719277, 0.13685543300403705], [0.03036160236074319, 0.04118338910742633, 0.09665586550029055, 0.030945041517336524, 0.010801781318150462, 0.006644532418689661, 0.09547844964770541, 0.019594700068175312, 0.0029126919041793315, 0.006866747233641124, 0.1078630346925028, 0.04773503815334651, 0.011879116401917512, 0.018425960161332643, 0.07427413181792344, 0.097305400807771, 0.048106824453439445, 0.03225828858933622, 0.03211898507640487, 0.06716613823007192, 0.04162633731480568, 0.022082854054808136, 0.1367943451529549, 0.0690036307599756, 0.03587063830045443, 0.014784390899172474, 0.024998663218631863, 0.037089036026548956, 0.0501840258948505, 0.037372059549295136, 0.045316720741891095, 0.06241036781800851, 0.00703423272728199, 0.03659000252223304, 0.11826476968464353, 0.01060346317958207, 0.003625751222341111, 0.06372675202005813, 0.04006487775533911, 0.028483989806244933, 0.012848599712484548, 0.0307858944119465, 0.01077831604502975, 0.01978986862776501, 0.054031438194215305, 0.016537363821220015, 0.05790475958717927, 0.04083895597666983, 0.020207085856987585, 0.03202963624179604, 0.01802804068692269, 0.014374634408722482, 0.03262346738108224, 0.05109187838951907, 0.03788663314715509, 0.06435725387305984, 0.02823364759434856, 0.03430704518611874, 0.07440777585631417, 0.08764445751665101, 0.10055043434183444, 0.0693619683865578, 0.025560075432182323, 0.034891294480691996, 0.01890661521634508, 0.06729610504642611, 0.04318114340064987, 0.0014664097139874715, 0.053446395998640414, 0.03356401650835911, 0.1060763491137374, 0.018505504985730496, 0.11097404114421337, 0.035614266976593964, 0.034624052369186, 0.03191519611244721, 0.05681058684844644, 0.04434257482869491, 0.05113590163208785, 0.05290012551291336, 0.009398315901747875, 0.05976255727751602, 0.045195632884579326, 0.009963259780629268, 0.050768547150636875, 0.04290728228947809, 0.01524018161299248, 0.006730442476128379, 0.026790958476222815, 0.06623338787786423, 0.0350585276441228, 0.03929175714391374, 0.04716130724597362, 0.04880058984722822, 0.01552811288650358, 0.025294267820314537, 0.03782796996435331, 0.040339160214869246, 0.07145624592780106, 0.02826751442626119, 0.06929583201605467, 0.013981168777982314, 0.03542960531288578, 0.015564818074175668, 0.05960445205170301, 0.05539201034773743, 0.017227476890829783, 0.04904894406096109, 0.01686452549972361, 0.044420164213666034, 0.06135978931260686, 0.003912098848471238, 0.09554637100307212, 0.0668802265558512, 0.02995328132754132, 0.09200833182060912, 0.0386436544208517, 0.006473854253624356, 0.043126793292861794, 0.02938621538510967, 0.0039942694392295615, 0.0005194749446086316, 0.04181723493421751, 0.02558782122157995, 0.007557886382264476, 0.062059802153418143, 0.07865107558186978, 0.064015555676193, 0.03678549666919055, 0.035474973039761666, 0.042996680919802, 0.006144658611681794, 0.01654758726456954, 0.06973772685253812, 0.02643294452178863, 0.011885329374983426, 0.04021275187692335, 0.019625106097890005, 0.002683428362117059, 0.04795135073964635, 0.0961713761752171, 0.008967270785492034, 0.06078588986589063, 0.07223252282147447, 0.04056856907423466, 0.02779187533193298, 0.08142492673810452, 0.039377459400003, 0.12258657043980015, 0.016263711469007597, 0.015223188825222033, 0.033136190876605055, 0.08006899707740353, 0.0034560316247910627, 0.08664789204035075, 0.017847665285150853, 0.0697757171527032, 0.03233281745304985, 0.029919853080965342, 0.054702898938088655, 0.0605647815691848, 0.02686384982699829, 0.03923418180596444, 0.056419154223535335, 0.07412514303840938, 0.024211889005176002, 0.056523966542895765, 0.03365993454691864, 0.011261544197857862, 0.0306198257021606, 0.03317341125840622, 0.07892780952275762, 0.07681357539108685, 0.012520975508396665, 0.025901436550362457, 0.010363421019827648, 0.08010051393460843, 0.02864147833127889, 0.07360352143164604, 0.05771625599253082, 0.07295737989367017, 0.04372113579583745, 0.0066457643838328945, 0.054793404565463145, 0.024079451555266015, 0.015563484123577515, 0.08193351718927584, 0.024368695711957353, 0.05130752830976441, 0.06496355883897313, 0.029465603161483046, 0.05919014787181251, 0.05611651884992758, 0.03148541695648625, 0.035863827778807575, 0.05814845215589289, 0.04079482165135203, 0.033805108208569794, 0.08707169954094195, 0.04736252023928589, 0.08610711823548041, 0.03910372469333872, 0.0726719431939625, 0.05727987315866256, 0.033592894192664854, 0.030232899589464072, 0.08269825679880959, 0.019523773732925617, 0.04586288397530875, 0.06396104468994084, 0.046686646828968684, 0.026043817821529605, 0.027030050686951128, 0.028792338280548013, 0.017026154729988308, 0.04302893705185383, 0.021310694883727742, 0.033558286170685486, 0.04309442990850057, 0.0686736383865918, 0.02903668202399727, 0.061824061577358556, 0.047892971009376555, 0.02223999592505636, 0.06308589265832017, 0.05397739069115731, 0.006505871462004801, 0.03597496798442256, 0.07275713217114249, 0.012234302534301196, 0.07407019921247998, 0.03842001037311651, 0.03171553827762123, 0.03260657514235185, 0.04590691104831715, 0.09376949901061674, 0.014097558601098436, 0.02912586231926276, 0.02133284248561869, 0.05202745943660698, 0.01866795201485436, 0.022859885545086958, 0.004364728491993681, 0.022649720814379475, 0.014391963317569707, 0.043636804837132656, 0.06323524916003789, 0.0213042444234053, 0.03413020144967783, 0.0587002614573125, 0.06892243310088111, 0.047167543201677264, 0.06123257658234047, 0.015790777622662004, 0.060704090827775586, 0.028887915409981247, 0.07507146080775608, 0.014776669690505633, 0.016005730402896243, 0.04488792600891283, 0.006821252144647823, 0.04058842990367163, 0.026031857273811777, 0.03382330662721107, 0.030985743768753547, 0.04079760255051717, 0.04071272000850689, 0.036923974722383485, 0.0650093172706904, 0.03551964362662646, 0.05071146593939874, 0.06924343160203389, 0.03539829912986006, 0.06368419583586436, 0.05889952858729709, 0.06074575451953758, 0.0698961998005548, 0.02464409857507675, 0.03524830677516518, 0.02979125947721543, 0.02678587165240559, 0.0591959088530031, 0.01873268835967587, 0.05266625036094939, 0.06584727956402688, 0.021279543833506685, 0.07382210163820176, 0.056434123581575776, 0.022900880825135018, 0.05252314130625418, 0.09729761735446031, 0.037074840417312044, 0.04502665687112078, 0.021666686366041823, 0.046708779109101144, 0.004618599496391272, 0.08797287940979005, 0.05555121107928215, 0.03494991935909756, 0.11351339278682587, 0.008070825340015995, 0.020330759261043805, 0.1006599925758858, 0.06533698839766365, 0.06157894408510578, 0.03047659215817769, 0.02961324362625038, 0.022922852226803382, 0.027815057152521708, 0.059205324073592504, 0.06056142610407645, 0.01579597265639853, 0.022061522336556547, 0.06229126412842063, 0.039924250825518565, 0.01644672029801915, 0.019363058062510628, 0.0923602955956613, 0.06490552001782963, 0.04311998277121494, 0.05329097974144163, 0.016027402072664232, 0.028884316711956938, 0.019879703928205757, 0.056846983685729005, 0.03523240278985712, 0.010397749419714655, 0.012991938593557045, 0.06372009088555652, 0.055884359734914, 0.023322685005804224, 0.023089164169505242, 0.013787957573039158, 0.030175722617235397, 0.05997705040499569, 0.060755330618591084, 0.05983414053316078, 0.050925035930929646, 0.0563992282766248, 0.050294158694845055, 0.04229201026441109, 0.021288913088820634, 0.009610852632190912, 0.047420968917468866, 0.021081155789415204, 0.011438483695289301, 0.036765283439308405, 0.07175754830842057, 0.12172075318953685, 0.021482218139534517, 0.025263813910104578, 0.025084811720937013, 0.14686253312374317, 0.11648904682407457, 0.3131533930859258, 0.09921590917773786, 0.2414943560236885, 0.11580028781487096, 0.2337116075138892, 0.3095560280546066, 0.07773394576243817, 0.1872138090191349, 0.24339174130751243, 0.16079923528577053, 0.10412706137304345, 0.13773497854990346, 0.10210845799696061, 0.13483426323340786, 0.1389120726455604, 0.06340881020972325, 0.1396408827314454, 0.1021441423724736, 0.1417926551714059, 0.13213058573103723, 0.24274870242562988, 0.18937034652598445, 0.18893133218009628, 0.15056232411053874, 0.17326739286222767, 0.11639712393404016, 0.16808482337622874, 0.16357268807628464, 0.18026563669404677, 0.11163745030400254, 0.07889373393188562, 0.11687515513791193, 0.17959443642006767, 0.1279179601659698, 0.10158908102781543, 0.17935062127728618, 0.1689878571778536, 0.12716773792260117, 0.1747742265222534, 0.13175048354652621, 0.09593659320906286, 0.10787881610374297, 0.20770595619274726, 0.13030487563340895, 0.13599767499873716, 0.11556013457236752, 0.17797362419866747, 0.20626868331624618, 0.07036803335311913, 0.13646328791735635, 0.25433504683596475, 0.20880282556097354, 0.17033244873727524, 0.19588299786611912, 0.14848124626423084, 0.1315004018045241, 0.1231170710056059, 0.14267800766373837, 0.11006305534993449, 0.19192632227655382, 0.10295844787070829, 0.07837275583897868, 0.15703611947115392, 0.14074021890278787, 0.11292519813944256, 0.12395959918297107, 0.15180760003145666, 0.0830244570369682, 0.23997194013528286, 0.11268908218030008, 0.31457041059770896, 0.20943710039700233, 0.09230972613177954, 0.12083466525279707, 0.2303497072669768, 0.11622517549943541, 0.17615395087388255, 0.1150534057148522, 0.1113405452680684, 0.1717564223274108, 0.1493601176527239, 0.20076306987433665, 0.16052774904716402, 0.18216789429706914, 0.08899458789176519, 0.1283866527580446, 0.12129968062283532, 0.12068117953716748, 0.07877627733133494, 0.1699933782219887, 0.1314663415354106, 0.15535785065543267, 0.18611853311379112, 0.12958694399604875, 0.1425217563707021, 0.16869554866946515, 0.21775417991222876, 0.14732273746161692, 0.10947232495152182, 0.12097547221327982, 0.1004482152300977, 0.13945075503039744, 0.1566374932806338, 0.13761143921123398, 0.14046056616690852, 0.13582501410236283, 0.19326248686880837, 0.16025833124595304, 0.16123394421752424, 0.10923843064735975, 0.31423569146183233, 0.18733972323036965, 0.09706418270305281, 0.11628433280894834, 0.12781090703943085, 0.12108289306202244, 0.14784848828229213, 0.09395093161372409, 0.1490480287541305, 0.11205185024488358, 0.12446889443503273, 0.2230810956849206, 0.10301320783553586, 0.1974022727940352, 0.2815871691751865, 0.17787846075671335, 0.22957513108849528, 0.1611946898722841, 0.16972121782600882, 0.057452664289984016, 0.11244558879444677, 0.2291193853823408, 0.17181044684783106, 0.21416249925330763, 0.08854540755912181, 0.12700913473963737, 0.07239662651573459, 0.14325217524122807, 0.2152081020176411, 0.15835800418449988, 0.16646083955082203, 0.11151384967829912, 0.14188041820401145, 0.1576995669353393, 0.16232001174601818, 0.12540870811790228, 0.17912799612649027, 0.13907197051711623, 0.08704300954817765, 0.10018763808353294, 0.19517188441128502, 0.08521802723407747, 0.16329608437034393, 0.12161723172832882, 0.14225871242102117, 0.13078824647011297, 0.09584566623333002, 0.18073495747821947, 0.09083997112728896, 0.09489543375469024, 0.1597846744041289, 0.2024008739258974, 0.22396635624670216, 0.18440094866579582, 0.1099671104982976, 0.1267911137772664, 0.08356292491718646, 0.0683950505129272, 0.14198999942070054, 0.12253690495966904, 0.17947288891000135, 0.07657191295537256, 0.14953984187976008, 0.06516374527446686], [0.05759178585703335, 0.030205021649899504, 0.024445199167295813, 0.010960993541014052, 0.030826993113864335, 0.017975331922512383, 0.022597195911070993, 0.039936083053509076, 0.047138891513309175, 0.016441401732604832, 0.038461248886080525, 0.10543706406268383, 0.022200594107890805, 0.033557757570017735, 0.0662752086176507, 0.06899537233215186, 0.0397129982499586, 0.05310939775118905, 0.025534603008699995, 0.026659068779178688, 0.057988860719506784, 0.012688220163146335, 0.03166982772639923, 0.025997063475510767, 0.0127541113855137, 0.07584697927438444, 0.11896099039022962, 0.050728848474400665, 0.04852543021702478, 0.06710074496485534, 0.04432984244739337, 0.016372660663159146, 0.07852676249439679, 0.04540028178223199, 0.015897613371752443, 0.059318471429569114, 0.04903625381449538, 0.017917873412971536, 0.09640260449340267, 0.03244672706651111, 0.01473210156790071, 0.026390378761495796, 0.03215232713808937, 0.01467886803326227, 0.047676865266816276, 0.047860998329856706, 0.03791027845093801, 0.060549708789274584, 0.007966794430338328, 0.026234493275443395, 0.034961759247967315, 0.06089609161379838, 0.05645028420633847, 0.010981758354201673, 0.04647514144439371, 0.09026682244673853, 0.01912573743010721, 0.02277376577107897, 0.008933886588971702, 0.03378222133183191, 0.01755078131663463, 0.05842383778203399, 0.011895888939409727, 0.04026299192299766, 0.05169696910607238, 0.02728784501913094, 0.0649750424969581, 0.15394690056000987, 0.022184979320774158, 0.04281874933850862, 0.04648554874884506, 0.007139217895230339, 0.018064157902112892, 0.047778969465364377, 0.10350196427034755, 0.03662603546775157, 0.018320908439495874, 0.032018648625742045, 0.06750647279043352, 0.04016916530447141, 0.11767867411817275, 0.038948408027570096, 0.03946723724384943, 0.018297697890609987, 0.06938427686691284, 0.023022671568117315, 0.03951832381708007, 0.04279432262504294, 0.04543179863943689, 0.030428022183778308, 0.03944188739443499, 0.02730153309511802, 0.06261581344710243, 0.031072620054586764, 0.006797482351577211, 0.06374012025433683, 0.02086757813700505, 0.03441418258232936, 0.005820714981265126, 0.041505456301233465, 0.08771911278487214, 0.06588320908767563, 0.05827555763384989, 0.05407410929159773, 0.09264141155947601, 0.03853829434862541, 0.03691786517118735, 0.015742442262689435, 0.054308398131040804, 0.052627536107695876, 0.044235391467208826, 0.03198842071146975, 0.03334459360508669, 0.023826791927398696, 0.0874677746586742, 0.04321360637644126, 0.036732042884273876, 0.06591787456624931, 0.00766186127176268, 0.058651584230603716, 0.05077652978680788, 0.023756371210179022, 0.007489732806495722, 0.07205342678653617, 0.048369956503231684, 0.07245783694088459, 0.06537995060845729, 0.022906605417149204, 0.012643461476170249, 0.018043080908096126, 0.0843613800562678, 0.03706208505337277, 0.09533342154275987, 0.008980341203090166, 0.07545763806950662, 0.046380223150575356, 0.043100133433096835, 0.025782938070234754, 0.054817517182879874, 0.043978016568167556, 0.031794046968101494, 0.023908625439470334, 0.03835440643372075, 0.058461368429444494, 0.017330454429611564, 0.0036368772130264274, 0.047202564911135746, 0.01761075834022655, 0.05166481256545071, 0.0471316481519851, 0.04267038109021322, 0.024803647876627026, 0.03346554739701171, 0.0458574332597275, 0.049593111635335994, 0.07763649937846968, 0.018281087189191775, 0.030860289210273378, 0.052586040955277226, 0.07549505380372848, 0.030844934893050985, 0.023831951529568723, 0.02757964216382994, 0.05050852541781722, 0.03375670294307413, 0.04924442671659974, 0.022605341340925907, 0.044003385569780104, 0.012322554905568401, 0.0472913276884825, 0.07330735950099845, 0.032797369339893905, 0.07045621007320381, 0.020541879686436827, 0.044186626140388756, 0.03279951055564227, 0.02925696294574488, 0.0606943576806976, 0.011750427994786972, 0.014691521890551574, 0.05831229921069838, 0.04183138074773935, 0.06993855680188826, 0.050567023891715274, 0.06953243061058945, 0.06736442476751343, 0.017232349210028208, 0.0588961654613095, 0.07094753290256185, 0.04026908232199569, 0.04698699926056209, 0.034744994669792154, 0.006074484957817702, 0.03521852510710878, 0.04737825568525061, 0.060547307103631966, 0.07165860805299974, 0.021612219429845293, 0.05573324123097043, 0.011117892178346314, 0.011822741906789523, 0.023609370428828463, 0.04100645727087413, 0.03045342374412764, 0.04988360451534391, 0.027561813382612124, 0.06786224402246938, 0.07068301040318704, 0.04380984877746913, 0.05361060311477031, 0.016085592196172765, 0.025790993484758565, 0.03494535347506885, 0.01798784022309607, 0.06723664130174345, 0.027123128454531395, 0.03822381142526865, 0.04356700273591184, 0.019739452381468108, 0.05141431330552986, 0.02235662898108844, 0.04776062549001748, 0.08089383628459708, 0.07859571040758202, 0.02422264104919328, 0.025286076425184167, 0.09008468504274085, 0.045848680705192595, 0.012155960467944463, 0.04005048296324188, 0.03571252158332256, 0.008555135592037152, 0.02548020502041665, 0.014718055345809028, 0.02328907098290661, 0.025343320430106214, 0.038894586520449775, 0.039039687403748115, 0.014326683050321956, 0.038380058887865276, 0.01624667750401122, 0.024738130122122746, 0.0645971619674275, 0.020299679073955745, 0.008582945541298438, 0.09500625603381666, 0.03764361473581484, 0.02195453624271097, 0.03952846299075792, 0.08257575933971713, 0.07823119811233013, 0.017689033373889905, 0.016500953577398773, 0.016954523593848272, 0.0314597261979455, 0.03211491906474675, 0.09673224446634132, 0.06652977197400986, 0.02022695626252361, 0.03099312119546437, 0.06911191728807266, 0.04431583069925828, 0.027096141092178803, 0.0280476127180361, 0.004526098688778978, 0.0908906631652386, 0.021837876373601538, 0.033700901098669536, 0.0656763653481199, 0.02280594529433837, 0.028461629614954995, 0.04410689170922964, 0.07597735977821773, 0.036418410318513075, 0.0487122445878002, 0.014021282099307546, 0.01192869856998685, 0.026770454132929448, 0.05016936297197977, 0.05961307437129079, 0.0600781012326479, 0.0153817345515915, 0.0346755794429731, 0.0274611724119994, 0.015553994209415492, 0.016304155165750175, 0.07522669320385303, 0.03771567679641228, 0.01275633974376345, 0.03217019996936283, 0.011667935647100452, 0.118252290112357, 0.013069265593414106, 0.04642446472820255, 0.021074059900016557, 0.03904737892650789, 0.04695005850085328, 0.017698707149153756, 0.04848288169371025, 0.034006428454191454, 0.03980568339747768, 0.016617058032763102, 0.007711397953361514, 0.02752725707156764, 0.006341560924005125, 0.02772126117751243, 0.06418362004502166, 0.03789140587492335, 0.0407918453997662, 0.01715636477925845, 0.04211513205401359, 0.04455038000859561, 0.017506405673620683, 0.03172416634286844, 0.06580064013119667, 0.027966995370544256, 0.060205076475657766, 0.035931239685704636, 0.025858748216001738, 0.05681456667521308, 0.031061059787809372, 0.038893862567361326, 0.04389347110484396, 0.03453288790619662, 0.023755336991481246, 0.035268968166483027, 0.025258679205792087, 0.035604166107312325, 0.037367570274058855, 0.03641398999118998, 0.007824163701790836, 0.003429041389608756, 0.014838626093771911, 0.022747722612093055, 0.030059938003579457, 0.021562588423670783, 0.05278827667596841, 0.04678677069023252, 0.04420804212831202, 0.019821785765910344, 0.029491749742338737, 0.05365361129083941, 0.056511257144231955, 0.10543169378633462, 0.08211915561508748, 0.048718166447454886, 0.08783458521769894, 0.014046124415472152, 0.035051364722030784, 0.03137104960549022, 0.010972332599903307, 0.03611867458769872, 0.1431588963755677, 0.13585194975378054, 0.27201768912134633, 0.08940354094750459, 0.1260070840737993, 0.12464403745628173, 0.11696156219489152, 0.12378311550785458, 0.12638116480722544, 0.20546966893298013, 0.12984879284856782, 0.22465309278378565, 0.09650998703774907, 0.12771198976664774, 0.1598064313011785, 0.23360412537811265, 0.12882916046486748, 0.16326360224235445, 0.12368310272933976, 0.1592804659758845, 0.17915723004168083, 0.09433210632132907, 0.17858169882768588, 0.13204248561974496, 0.23605716955517572, 0.1715144304738891, 0.21167769307090392, 0.11960963703571789, 0.10109218107836862, 0.07520349606150582, 0.1687499868773645, 0.17022544157601174, 0.08780986356038241, 0.18606875272047135, 0.20707641578009053, 0.13537247064373187, 0.18255084632865845, 0.19449605696624328, 0.14700425938973505, 0.185245591245832, 0.17313988518811044, 0.11728640645742418, 0.10222786046083897, 0.1364903921081174, 0.12063596502787645, 0.2007436418845769, 0.233463732105109, 0.20056624656483052, 0.10684398453562491, 0.08783868378809384, 0.17981220457342365, 0.14724646574787556, 0.1337467094943408, 0.13241590751755622, 0.1771646506723858, 0.15232935187316712, 0.09970904763547644, 0.1322467399821166, 0.13840668444191256, 0.18661454440124575, 0.1627866665442144, 0.21167928653378643, 0.13379020796668145, 0.14612279862405794, 0.12638422915892256, 0.11279046625619936, 0.18840172027628269, 0.2532923245622266, 0.12042213456645129, 0.20196143057077162, 0.16464407736014935, 0.1013329471912115, 0.10638482973820741, 0.23637026968982913, 0.18032937520934691, 0.1693638990963659, 0.16311965432138215, 0.13940186329906987, 0.16983522703090023, 0.1516325029754831, 0.2112609872053708, 0.19910232915032297, 0.1557594339453405, 0.08800235081223712, 0.2042858332635895, 0.10576091241091491, 0.09322711642110541, 0.10954500371289831, 0.08707568319814821, 0.28242297110057646, 0.19033973886361047, 0.10116177250541027, 0.14512343692683405, 0.06708935323742128, 0.08924116861195334, 0.14649277312620995, 0.18360686788876213, 0.18116896160908286, 0.1384655353162558, 0.11669492529284571, 0.15712075686502844, 0.1310822710154518, 0.16537299469834374, 0.10202002846786093, 0.17678578955031213, 0.1172650785696122, 0.13556477403448475, 0.10241204331959448, 0.08707188340204378, 0.24324351861592264, 0.12487525811358807, 0.0948451707259782, 0.14318920281385222, 0.09347231052215062, 0.1452606432740727, 0.16761142700429887, 0.11317899540787744, 0.15222378495720126, 0.19650628700131373, 0.08713313979246924, 0.1824954122064575, 0.11035239909805598, 0.16448324486132593, 0.20069979101179108, 0.09173665406002153, 0.12106505853514518, 0.1816675009866876, 0.23799512685546953, 0.08769766998387153, 0.12170301825408975, 0.13027086132957091, 0.12850839945097126, 0.1385980685271563, 0.19230306899595648, 0.18566479455799828, 0.12094289815473942, 0.19090354893236391, 0.17563593754124257, 0.18567478434453089, 0.1374420112059001, 0.12613941044096025, 0.10198185430659402, 0.10667202077926168, 0.1734362233189806, 0.09504785460810508, 0.1286067038534149, 0.1355854890519573, 0.1123925831709658, 0.15278705876440773, 0.09660549521926912, 0.10642596865974127, 0.13194318530299973, 0.11616440174440223, 0.16613171285679265, 0.16453887816638718, 0.133563369332302, 0.09140248650745039, 0.15461056252881406, 0.11448302261170842, 0.09297588554721686, 0.11145155906917588, 0.14352831929441423, 0.12568214021983648, 0.11463674581459454, 0.12166780119221057, 0.1190301221645167, 0.06922445560414946, 0.17753638717676365, 0.17251377684935448, 0.1425613784381459, 0.21524115105069455, 0.11270631149771715, 0.08687631647673347, 0.1450328853341841, 0.1419519248508638, 0.06168967060324165], [0.009716813125827862, 0.019937221809560736, 0.03009282998860844, 0.002291336662188593, 0.032956799897815914, 0.09518283930036331, 0.0577820246408303, 0.010621307282558373, 0.016622447461310415, 0.044646987526287, 0.04758882644255796, 0.006619133731170047, 0.04340396007342685, 0.07009762729848586, 0.03585428998415028, 0.01475960412438238, 0.03949598852364768, 0.040628703145851056, 0.006363684106843487, 0.03179678956287042, 0.049021648348218975, 0.04642429235841959, 0.0696954847643933, 0.01221329353058771, 0.09809630998079816, 0.024101963048921, 0.062452284318785516, 0.024696927998335134, 0.00977148020249461, 0.019903429671220725, 0.03372764905854579, 0.024808024153894475, 0.03629243098980477, 0.026811912896171696, 0.0443181251325915, 0.018984775336819793, 0.08842550713809268, 0.06299544831797962, 0.0671167562024728, 0.06603006814276019, 0.031243444255162633, 0.018964847474689447, 0.08948631674772309, 0.036513688673655835, 0.051806167278799324, 0.07274606986151588, 0.019442275384320848, 0.022129361337471395, 0.0057874571892523, 0.0044999243372360305, 0.027475345038598584, 0.02412611014029432, 0.01848068948264324, 0.015819701272243216, 0.037907800156502955, 0.05320376829214154, 0.04729568289833204, 0.025908997838175105, 0.042415361911539114, 0.02936780820750902, 0.05416595174240009, 0.01190514232392513, 0.038772112043995055, 0.04281026491474721, 0.06480490202985464, 0.06784458569581471, 0.05160341827919887, 0.02705131154206972, 0.00869117940085069, 0.03389376373360715, 0.09310613581610304, 0.042429090207142216, 0.03071553498176077, 0.013324497361487199, 0.052227952307270425, 0.02127526331722977, 0.04243619567263992, 0.005540525505033833, 0.015912599009161275, 0.017066826337888356, 0.02703923799638306, 0.05263013697619881, 0.017353569217506918, 0.012537769113306799, 0.019455111187492168, 0.03566324297759322, 0.025943896973565705, 0.02900625109642504, 0.04111291667927177, 0.014462114946405976, 0.07772685178825933, 0.0450684507978299, 0.014064217497023844, 0.024409064715127313, 0.023104445708374825, 0.008943055703815435, 0.02845069179461608, 0.020107743405406515, 0.03910321524486907, 0.03440082200892991, 0.05018477666101629, 0.012043542810715737, 0.026988283573319356, 0.015306140825663124, 0.03902294838260259, 0.01484359417396087, 0.013896529468887997, 0.04871796343415495, 0.06078588603545101, 0.07900689277918109, 0.008474954914662146, 0.031412186611804276, 0.031939414066953525, 0.027093277838561806, 0.049306433873191, 0.012132783435405263, 0.04479488846094859, 0.03320649859585589, 0.10794777167780746, 0.039323151427050757, 0.03009105266462411, 0.03852030660416331, 0.08275696977732644, 0.03603379587612806, 0.09641091654738111, 0.04240682003118339, 0.023561635490266547, 0.04040616609516644, 0.03247994080846829, 0.07392458888071199, 0.056815160393354394, 0.049779527640390786, 0.03141454807783087, 0.045749951123950944, 0.03686023237664373, 0.08142022295824944, 0.06192233150584563, 0.03702390706166625, 0.048160764704188036, 0.05003216428562038, 0.057504739116636984, 0.012248911831017223, 0.0412209503983538, 0.0915916795812307, 0.02096511262108482, 0.016943401912407532, 0.02239238805017404, 0.026517059060654817, 0.05794754942818996, 0.026678238214263995, 0.04540929480666115, 0.03820589645915935, 0.036335213169936216, 0.03786579938605428, 0.08325420680545992, 0.0026400390573056236, 0.04558121259774893, 0.03191510801233592, 0.037190944872676365, 0.03228118695739297, 0.03199716177468579, 0.010506373984108289, 0.024740740566724734, 0.022956738210914117, 0.10640748295812838, 0.011689497191729325, 0.035436492443325064, 0.014086499164301543, 0.03721162924663194, 0.026782259547842607, 0.05061191664407811, 0.03842035128224281, 0.04476191986712717, 0.021844187022877798, 0.01639430647745969, 0.03790721409924088, 0.058592721864941626, 0.023514130378081918, 0.015421574954093705, 0.04409860263788893, 0.04284572712476215, 0.15141318732452008, 0.012799004137876534, 0.06749501977596553, 0.04992507285468521, 0.08677330063355547, 0.03721204293411105, 0.031593058055507085, 0.06143320351839066, 0.06430515989420876, 0.03076942735201409, 0.033691294356099064, 0.051153429723795385, 0.0345082045532763, 0.042053040627750664, 0.008409040709657055, 0.03285987445363595, 0.015333968011902706, 0.06667155952703568, 0.017339982648169803, 0.04811137884614929, 0.03851077263994563, 0.026412915153008316, 0.02186218242821915, 0.026740454129814625, 0.012938985638620873, 0.06244661526814584, 0.018834118400850607, 0.010833979035998064, 0.047883525145270174, 0.025628042752824487, 0.04553808567805156, 0.007182132704333673, 0.03415978393487392, 0.02012605673723644, 0.04060971182620814, 0.07228159841390387, 0.045460932963197274, 0.03965769053226517, 0.06165418158014936, 0.015490105349360215, 0.027673775217525905, 0.03862354078239972, 0.0248644580208366, 0.0894775833453863, 0.05522278535570349, 0.0804434914983088, 0.05020005628466607, 0.03994506926486089, 0.030639830173083374, 0.022643526993511666, 0.024956143423614484, 0.050729955471451246, 0.024912861371112448, 0.04477630316790554, 0.0174011011427689, 0.135100279604235, 0.056639664971660224, 0.023327618612036593, 0.05472105905233372, 0.0715789732132708, 0.03236587031654293, 0.0645136354010432, 0.01946842004995673, 0.03131191144817539, 0.019492415838965008, 0.045216757759091356, 0.016168728057715683, 0.03289483104562087, 0.018479009834869255, 0.03309375726647916, 0.033237866065915556, 0.0776132332882093, 0.029524854316766706, 0.024052508242969072, 0.016457079721975233, 0.008103750841391665, 0.07506005375856355, 0.020656612844416694, 0.00916650056869032, 0.10391209710149035, 0.04209805978462101, 0.056430273989756266, 0.05838511586790124, 0.03784959279601613, 0.019082641153926813, 0.1007786519344776, 0.04914573160931469, 0.05353850274977665, 0.019560645544721235, 0.020600000862032175, 0.03407434980955816, 0.026359534146444454, 0.021856252907685215, 0.008028623950292147, 0.01633078055155854, 0.07647315656105358, 0.019671506128243862, 0.04102461355467958, 0.0162513448946899, 0.02111851023660312, 0.03361261712627546, 0.012562937016839222, 0.10589248035103084, 0.07955676004771264, 0.06895240246047897, 0.046779569463744286, 0.02234000104269193, 0.04242873780669705, 0.03463358633340367, 0.021389431485365477, 0.013716016171289789, 0.05670832560187387, 0.041826922116020036, 0.03228390273908454, 0.04323163242529958, 0.03455778959417536, 0.019971938999069315, 0.014335680752992632, 0.05383107555849899, 0.04544932673114442, 0.02327718704398121, 0.05146527730469262, 0.06291708518420497, 0.04900818818338937, 0.05106510361656547, 0.0653238959550377, 0.039683224242781444, 0.022048314980741952, 0.023815181864906224, 0.06632629136044173, 0.05257513569367509, 0.054404622604770046, 0.03992202917053815, 0.03666234037448322, 0.03275245743533296, 0.036981193829448, 0.0033612536208238457, 0.02939533949228785, 0.020594425657163226, 0.04180931741552007, 0.01701824104173049, 0.0738891726359725, 0.02008707818364905, 0.08285112964409976, 0.015343113186498804, 0.02080197419760929, 0.0240543028039317, 0.06022272714143319, 0.06091507527256205, 0.07264411121967339, 0.0092899345702702, 0.03652356354699981, 0.030379398583224228, 0.05194180314579318, 0.03901656687019333, 0.04632858882447885, 0.09443601848737848, 0.013063477799146166, 0.0359583477069053, 0.0545053401841752, 0.06504590562995403, 0.04043368014296697, 0.07071773716879469, 0.048557579096767216, 0.01960763546277679, 0.030605637753802924, 0.03974878604734137, 0.12993062636063946, 0.04630933703494169, 0.04393497774858148, 0.008026514814475612, 0.17782183153735054, 0.146016251115549, 0.13125418114566034, 0.1057017780840397, 0.17444436438381675, 0.25069352449668997, 0.1420176245512501, 0.16365079840104427, 0.137373446336677, 0.20309013855313102, 0.13982550992119697, 0.15969878062605858, 0.1199362279787179, 0.2563461348895104, 0.15094190535526122, 0.12140278839656424, 0.2630477188335311, 0.20842468456154872, 0.15557235527423122, 0.15355083310315687, 0.12200200704917794, 0.2016972221674458, 0.19083751215329095, 0.08483597152535954, 0.2060190918705156, 0.08061090469240181, 0.22785491129804045, 0.16669559953433855, 0.16305741733841358, 0.07667818467222876, 0.1306148807728483, 0.12225260973096856, 0.09333084472605298, 0.14875303893800707, 0.1286195128435089, 0.1052167984626947, 0.24189672072327909, 0.09657908816851916, 0.18234121402905834, 0.20372946956946006, 0.13673776189886755, 0.22908124952547013, 0.19994303403842836, 0.19100425885088984, 0.1368575933719835, 0.10348968388092133, 0.12493009468720806, 0.11631063260738889, 0.20569056272506717, 0.16951969073664758, 0.15369982188267095, 0.13153858362667023, 0.09786833753629078, 0.15228991366682515, 0.13075683686521747, 0.0997063739886207, 0.20132547034130943, 0.1172222848981619, 0.1503724262358681, 0.11211484565489716, 0.29096172581757274, 0.1761184350377129, 0.14529436646449953, 0.17864785818082674, 0.17876228107319725, 0.1148923816940477, 0.14604974447959854, 0.08657782563879605, 0.09442288774035631, 0.15388953589623974, 0.1943676146648584, 0.0997669715434313, 0.11623216222130484, 0.10792675788604444, 0.11890082950553588, 0.09583596756020862, 0.10215384870647423, 0.08009019473026838, 0.09264349531863006, 0.15452656864879594, 0.10757057296652948, 0.13175566230089436, 0.1334766175357565, 0.06261644163920034, 0.1949939987952671, 0.12315264812880948, 0.09339348007474216, 0.1361817199616663, 0.16107829047306893, 0.12280314349599424, 0.2180192310122713, 0.16012555288691677, 0.1446449996963624, 0.10964706194617095, 0.0982238176549154, 0.1473225382787566, 0.19573005607291577, 0.10153297274824112, 0.14089103097156172, 0.17787689793734782, 0.17720654036008543, 0.11315187589535791, 0.12856948730205336, 0.10144478070639795, 0.16432570654057688, 0.15963174793268406, 0.09073599001332637, 0.16724614096024346, 0.1947917975485325, 0.19031333947373977, 0.13374048886039566, 0.060267616063356406, 0.09516079128990251, 0.12306387386014386, 0.12152285735693671, 0.1286740276602007, 0.10802276402471528, 0.1307768011165242, 0.14020075510826804, 0.11148430166705964, 0.2592934896388362, 0.14426998433566865, 0.115330706560804, 0.20641715115597173, 0.21726552306884722, 0.10127855494858758, 0.14127150087827636, 0.19468137363512672, 0.13280033043796016, 0.15072907080813763, 0.1337729250231097, 0.14178701676428318, 0.140766694901451, 0.09023184287211589, 0.18556488137091362, 0.2313472150314239, 0.2073909561600416, 0.23943754784282179, 0.2090375549009731, 0.14507607737135503, 0.15658052698258432, 0.08965392146379718, 0.14426806911585793, 0.13729138299822807, 0.13507990166544914, 0.0961172367416082, 0.16942435875535014, 0.09940758437639284, 0.12340718084165167, 0.09505307166686944, 0.1707034191537288, 0.12293726250889803, 0.12238350351371112, 0.13114197990827023, 0.3049209509645739, 0.13414584130289095, 0.15832855576469054, 0.13648876800171791, 0.15581379554444746, 0.12168057187790833, 0.15147603717782807, 0.1300044619147816, 0.09885365684186259, 0.1262024211727323, 0.2550285555902989, 0.12390310785943463, 0.09103374540685646, 0.15080387163306438, 0.12764095809430848, 0.11819486416155293, 0.10337876201036478, 0.09167623270543353, 0.24776562838064087, 0.10286556737076852, 0.1484798979494841, 0.17362059003883795], [0.025410159686279875, 0.0300771271013805, 0.04544712422836212, 0.059000755615171895, 0.004104471187137308, 0.01836944010949904, 0.022665065555502812, 0.05470793596619079, 0.0379135879507709, 0.03270720079120609, 0.08158428834811335, 0.026032372467940854, 0.045393042251347535, 0.06209255241218114, 0.07252593449647389, 0.08346341009582244, 0.036690658814604246, 0.006587238139247583, 0.022646070405420278, 0.012230988246418778, 0.0057932746694273046, 0.06988869979977608, 0.013018616647910208, 0.02138190467150942, 0.04392288505069671, 0.04809535994765259, 0.01748683787281475, 0.030932916260714975, 0.030338571842519507, 0.008081364794634283, 0.04262741504897995, 0.016069444977948745, 0.008126211581721662, 0.07263109538583987, 0.013403637116895089, 0.03832185535781807, 0.022225670080872315, 0.042365439791953376, 0.02604216498683297, 0.008981113994283783, 0.05423000435374918, 0.012876516914055234, 0.02612948751888208, 0.058720256352136214, 0.05547134641317591, 0.03805596539149842, 0.027931979406745206, 0.04981607003437896, 0.07281022972517437, 0.022256625778672677, 0.01619953628359062, 0.05300926239860635, 0.022469050468756788, 0.018161784316743576, 0.05373126196284449, 0.0017827233480807816, 0.04488134914408288, 0.038166527200730584, 0.05379672800641387, 0.030641557701352625, 0.04205633863626469, 0.012933611531832047, 0.045956074740857854, 0.021874903318201824, 0.018939683401596644, 0.05503913492805535, 0.020629774869209336, 0.06561469527021532, 0.017439139323429238, 0.03856135742558587, 0.033826256065719554, 0.055253130098384236, 0.06548760128357718, 0.05603943125254685, 0.0318622728434181, 0.05115184775223175, 0.062178691338387236, 0.022930344566702846, 0.04908223824215032, 0.06639196041731105, 0.05326946416208821, 0.021672702071467237, 0.026228623126723596, 0.06342454565568797, 0.01344351965423313, 0.03525228660193182, 0.06964430243017213, 0.02074802628598146, 0.03742529499915339, 0.01342550796952339, 0.0634225270140075, 0.057590261342064034, 0.0387190910987556, 0.13830183764859555, 0.06017468193726194, 0.02166309149845714, 0.029773323443688215, 0.03513355063454759, 0.05590558420085619, 0.09166202943531737, 0.054899986547928666, 0.0818432720317956, 0.04180580490238724, 0.018675909753167824, 0.018159350072364175, 0.053435421789125095, 0.0649500220653511, 0.003498214341121756, 0.028491863274886727, 0.05597007731276174, 0.039703720925195564, 0.022690225798155994, 0.06715486907670576, 0.06967227230028761, 0.01875011494473344, 0.013689788193592142, 0.038277303514581536, 0.06590486639329503, 0.05085089777205741, 0.019583501777942144, 0.05851848794507885, 0.028243443943680297, 0.014253513035064024, 0.014012366751088731, 0.04119683778093707, 0.027665714057342663, 0.06610178929423133, 0.06396868641698553, 0.0907455507906214, 0.020272042452087326, 0.049369739548813914, 0.02757592663739718, 0.01702916162509111, 0.06259091558956331, 0.024245644754339612, 0.04363026627669892, 0.031490007738372496, 0.064953584374199, 0.07347219863966589, 0.03486581822677005, 0.05313739060394226, 0.03116406030922888, 0.010314122304290293, 0.09618089098723666, 0.07311609032894335, 0.013470311664165029, 0.04003900313569654, 0.03407531124990314, 0.027445672538071394, 0.029405317787501602, 0.036867939221161994, 0.03320448378461503, 0.044105179502718875, 0.017791708307941596, 0.010657020386368518, 0.04551865768829181, 0.05642701045519883, 0.05543473507127455, 0.055901883996181914, 0.07066601091214726, 0.011462956374030442, 0.06818351065439564, 0.032095583005537914, 0.05100907960666284, 0.04793969471187842, 0.03643827114795004, 0.05505325009806022, 0.046658355201925, 0.04237543340892561, 0.03942027222365141, 0.05598398946946668, 0.023032257243269877, 0.03684471909617705, 0.039675053915068995, 0.05148051096306694, 0.04049310175281379, 0.03165009330146976, 0.04800358644476341, 0.021073571518964825, 0.02453265767995148, 0.01685107491099306, 0.022575565418528936, 0.013196213065736718, 0.015615210380224932, 0.09153767038256892, 0.06967273961392141, 0.06016160481639447, 0.041934722178285165, 0.031084645719778155, 0.02507582934002482, 0.00888886743210136, 0.01995791384439555, 0.006947116081362531, 0.07079486690101124, 0.010878001320956936, 0.02164641184912574, 0.010352283059018514, 0.05222772631133276, 0.04051386656600141, 0.0764475692243826, 0.06692570153503649, 0.015687669848933095, 0.021175719767568574, 0.05435810191556812, 0.03925686949984201, 0.04167949232543188, 0.03597908570701557, 0.033930068640338804, 0.04048810685954748, 0.039704590434989626, 0.017837099017455213, 0.01768961751593217, 0.10854389533520707, 0.03779738007353679, 0.05333531708005936, 0.014383615832024766, 0.01850524643105605, 0.026169046384072112, 0.015643768222822298, 0.05728857208704276, 0.014518127464989742, 0.02954608452836833, 0.02043352995608603, 0.04055116355659501, 0.04724584887885759, 0.006984155953696539, 0.02648787302595954, 0.0670163527191166, 0.0335522762109195, 0.03481020024346729, 0.044084020154250246, 0.011936209104474516, 0.026559869969083418, 0.012513161411569005, 0.010851191116436835, 0.011821670341305436, 0.01772532295886307, 0.022310418557495843, 0.045972940166510885, 0.001492976805292851, 0.09217373020346127, 0.05178831359972397, 0.007133003964554519, 0.04950099339288089, 0.03265985655748556, 0.051009880168543714, 0.07165892980992794, 0.03197167594466479, 0.014790139431434294, 0.03812881269221825, 0.017497967215134733, 0.010690398837229418, 0.09003670495604316, 0.015046336470291981, 0.002597099110942274, 0.029652808237099842, 0.029929651345516887, 0.06290867736923599, 0.0650910358695734, 0.023736843628989115, 0.04153886156517171, 0.03572866305588715, 0.04096773535674138, 0.053611522420279445, 0.03570087321643387, 0.035065276878735716, 0.03600996288080369, 0.04901174283135803, 0.04875296216097571, 0.029735727678804152, 0.005450679192079171, 0.04428140653838073, 0.07230994366710225, 0.010708182610781684, 0.03431943282785435, 0.020786267479941733, 0.025256792714278546, 0.06258430425077677, 0.04633247289025495, 0.05852159826205142, 0.01902887901862062, 0.04562508262273285, 0.0440501131027216, 0.005781158510099856, 0.0186444599286563, 0.020801633288482987, 0.011306058694308084, 0.06333382169325506, 0.0022434406057601016, 0.06975988977618756, 0.03146324445673775, 0.03786783717993287, 0.03157410504026038, 0.04085613549837182, 0.03267116784568756, 0.03897671497637226, 0.04739222912898949, 0.03158739283530703, 0.024474678230622125, 0.05067310025615077, 0.020307301648802335, 0.012870575902202438, 0.02978879458931906, 0.026312942594109524, 0.0380255708531026, 0.056962605505701036, 0.04807061530769833, 0.0364366163980336, 0.006308295949918008, 0.13487964628204224, 0.015901001395597573, 0.05441149441345085, 0.04149100405254191, 0.09860113894026126, 0.016423004131103237, 0.023005174119926752, 0.09839826353615332, 0.0043434824798286205, 0.01242526335596678, 0.043026091035215125, 0.017763684811671416, 0.026288552269820246, 0.05755690587384086, 0.017313627308354746, 0.030625236198125832, 0.048363670751812964, 0.07506458133819603, 0.03796010863997283, 0.032614848891934084, 0.012327161009213137, 0.009912372390258937, 0.055773035668197184, 0.02116100704898277, 0.03731939100450085, 0.04320418349497261, 0.10906192398960553, 0.0675669247885385, 0.029742620554902864, 0.0318265501635089, 0.10314845299768834, 0.06523674579277154, 0.014115727333832654, 0.06955582693579697, 0.02067036795309715, 0.06002922099263919, 0.07980647406751111, 0.03683502425349528, 0.07459542909336668, 0.028475932476501313, 0.02030012723539145, 0.05116392895879765, 0.009937880245307762, 0.13249338965021795, 0.12275525533984746, 0.18580725626839747, 0.1855562705426447, 0.10311283757008853, 0.08806114806042564, 0.17852919116135568, 0.08988906449127583, 0.26064695249642095, 0.22625653013106317, 0.20774326467465973, 0.21151390347269275, 0.287297741780358, 0.14550576076632546, 0.12501819479850032, 0.13799192443970712, 0.1318437624121866, 0.10854455417082196, 0.1404948869059163, 0.12399978049459959, 0.06719988440313647, 0.21746734127161965, 0.17091248454826494, 0.24570874359098174, 0.1652494400379158, 0.1312262342581826, 0.10646782770392396, 0.16700868434723348, 0.11134275926216958, 0.10210166279707225, 0.14673465772742225, 0.15321216095359097, 0.09085645733941948, 0.1408958420037262, 0.16966720862734705, 0.1119133109046567, 0.28220871162991373, 0.1424377778124425, 0.14498736438972337, 0.09862036008628146, 0.13490990675505132, 0.1470922369269594, 0.1117962986351021, 0.1443065573731738, 0.11330474874064808, 0.14177748663050516, 0.0999571681923924, 0.11076479188857541, 0.1644254665100767, 0.09700085787523179, 0.06557948586921539, 0.15174789113863824, 0.11541574998127839, 0.10240687988698484, 0.13502812944352627, 0.10105759986946661, 0.15502432661671794, 0.11944646796872539, 0.1124267123879925, 0.07666227302604145, 0.09599914428808036, 0.134239487890755, 0.13985816058852982, 0.08151059835067681, 0.17145266846543358, 0.20582234516980188, 0.08071348386546297, 0.21569449124076676, 0.1574847099160956, 0.14069469795832712, 0.1658774023094485, 0.14749922879761265, 0.2112797103942402, 0.15466432657934007, 0.15998747319944445, 0.13798604088444866, 0.1261981387412356, 0.08611400536591969, 0.13456027954816818, 0.22249414976085388, 0.14224573489158385, 0.14674435640054365, 0.13259120375639008, 0.0839154709190611, 0.12212121799107521, 0.13707032066679772, 0.15991178371252554, 0.10320086873346761, 0.2113053896614621, 0.14072226180184272, 0.11810405209900872, 0.16086266736590094, 0.14413524479154619, 0.2023910833222251, 0.13429902824423007, 0.1092983770274347, 0.15955949051966592, 0.14964755384191392, 0.2029343162693324, 0.2596213446269112, 0.20605748819728054, 0.13711852291899343, 0.15904889291813298, 0.10744882627360283, 0.12541748748551454, 0.10443475292695147, 0.10223745188165097, 0.10708794523511203, 0.14479283934399007, 0.14441569425886677, 0.18366538168441865, 0.17088872050085377, 0.1682006865138969, 0.17531123883541555, 0.12969280202542582, 0.11926374833790526, 0.10032025556410513, 0.13874668958446673, 0.16580822456988598, 0.10147415251741487, 0.15108519444061866, 0.14853442808793438, 0.13475508038555423, 0.10061376683053472, 0.1595692964450967, 0.08557496291975822, 0.13275022828771224, 0.10448687754931951, 0.18539925316168418, 0.22109728036147935, 0.16829937396030273, 0.12131974446557223, 0.0763669767747483, 0.3174359471567216, 0.10601913766755212, 0.10444202310135288, 0.14888079176026006, 0.2398567051897126, 0.12181116688636043, 0.09267524200221224, 0.16040215659285748, 0.08434741427340815, 0.07386374617776564, 0.21578683547915953, 0.10560947981092239, 0.1311094364932468, 0.2082141023129225, 0.06429291780917876, 0.09985847308510735, 0.11036253444129422, 0.1636437350703824, 0.1369862195344702, 0.1256647500239553, 0.07185943800234987, 0.10113232408560092, 0.21195556848279892, 0.2115014009177685, 0.1611826622918729, 0.13048320558042298, 0.19362708343373192, 0.14117768575106898, 0.15117504123237827, 0.07048947361087607, 0.20040892274870029, 0.19767777333336492, 0.09747981604549194, 0.1434349791417199, 0.13586190889679617, 0.19795391738655108, 0.17014984401964373, 0.09802944582676697, 0.17449013047641324, 0.08885681463946259, 0.08370681155112483, 0.1680187559536388, 0.09873159605288699], [0.029049035191776294, 0.02927602895896041, 0.046916660897794275, 0.020890650790064566, 0.04125966465160732, 0.04842093965459255, 0.07490338111716895, 0.03421143741316853, 0.023529796876133453, 0.008090334726617703, 0.03547105066958935, 0.03511253684278458, 0.03105625833174394, 0.017141994885018757, 0.08281546825122449, 0.032443218383817904, 0.043544483581377615, 0.02505855980299173, 0.031495065833892555, 0.03417192642847377, 0.009504943849488853, 0.04425247522792028, 0.02617019168551891, 0.10601880824974469, 0.008281816488071796, 0.02648303518071771, 0.0365441789730422, 0.0222781241210478, 0.01661656007561232, 0.026185875420548746, 0.047587470466931986, 0.057950196261968345, 0.026483494833472277, 0.053756175142142086, 0.024208556522705385, 0.08980793578009452, 0.03344172589300621, 0.015433125644772044, 0.02704037755217043, 0.017503295356648105, 0.03226702199167302, 0.10168407593042621, 0.06078870906945198, 0.02538263606238029, 0.04535915052157737, 0.020194114073209708, 0.04677279724649364, 0.04103567586430619, 0.004904261234426691, 0.05398381433840241, 0.0918914421251224, 0.051969596815686074, 0.06395766241175514, 0.020203077301923788, 0.028898556371249502, 0.027544252732167804, 0.04701869997886881, 0.0335088926517675, 0.10330711746768606, 0.015237412205146206, 0.07987436477936084, 0.04494876105097994, 0.054075909598219785, 0.04216011673692734, 0.02716749452144629, 0.01820880870875572, 0.024698979198752392, 0.05936691882990061, 0.007307979882875037, 0.052176114967873985, 0.05529664772292299, 0.014709881187656955, 0.04863299662247301, 0.02092318845942857, 0.05687842010370186, 0.013829314829631439, 0.05275492503818485, 0.0360096947500302, 0.04164375815420382, 0.057127249291947776, 0.05558023815073314, 0.03897271982784714, 0.03553124219780007, 0.0535318531065939, 0.03929429672538273, 0.02118223726058439, 0.022986525624629953, 0.07546714522064694, 0.04171628752843507, 0.006259140875866457, 0.04195476303838434, 0.02175672659500232, 0.014534412579040134, 0.04654449921461844, 0.026460517941403295, 0.044079442778902675, 0.05255178533374302, 0.0596152424001165, 0.029823421763496536, 0.035289258005157594, 0.05976895028124413, 0.04713077481175142, 0.034401909853782386, 0.05704826945739408, 0.009409831160859717, 0.035737971024167155, 0.03246430495393372, 0.05974250492609798, 0.02203467861568976, 0.11592931234307828, 0.010543582874590592, 0.043123112240385626, 0.027434518297893867, 0.050796509359873114, 0.03931292798370123, 0.02946764095536163, 0.01974742927197968, 0.045389667634041085, 0.04691184603519017, 0.03010061727235875, 0.04561799247899363, 0.028132024115972945, 0.0785596966142616, 0.06638480515609826, 0.06502479990764011, 0.05397418844363382, 0.03919115447769723, 0.010608191857294691, 0.032037360323292595, 0.02461948800050924, 0.03152631647554377, 0.019018460222850406, 0.04073196413716482, 0.05848040571436287, 0.06433696020394564, 0.09005531323172393, 0.026850594590688427, 0.04962524519331994, 0.04836696876032699, 0.018413616569652673, 0.06053969985054386, 0.08697894161507007, 0.040748044322695465, 0.05319477441991049, 0.06534700882771323, 0.045525100487735004, 0.03685164453101255, 0.03059330948388144, 0.05810597258049154, 0.051479806162176595, 0.025301045783224608, 0.05470160424949662, 0.019247269618415067, 0.031219902373249495, 0.057128444389109655, 0.040425234023601785, 0.03840612502948892, 0.047851291995856075, 0.025900226131442095, 0.021788896542162667, 0.03679837077675808, 0.03446142339418012, 0.06685064024021549, 0.034520201490170536, 0.012633553086479586, 0.03552445465879094, 0.0715575150905117, 0.11135107897702726, 0.08746534615995423, 0.08108824641714174, 0.06246018651572447, 0.07763108313684502, 0.05022089770664612, 0.10447667325816809, 0.0308663604570733, 0.019776770439479622, 0.03420586795395902, 0.01893604065351669, 0.052852988122932376, 0.009874459656496203, 0.028684427135533867, 0.04391184189326821, 0.04668068283447816, 0.052886079290821675, 0.018934359090522896, 0.03888022237186951, 0.04255716861676305, 0.012167746730659519, 0.023979863955549175, 0.07619846807492357, 0.04103809670214692, 0.04737306543956361, 0.03369552699188071, 0.07517223201331592, 0.026622897937833786, 0.028117357362662593, 0.0378410509156604, 0.02302797864221277, 0.05353311715166896, 0.06637069381653302, 0.025338970965916113, 0.06161581206646177, 0.10537273565968198, 0.04064588266755304, 0.006625046493530635, 0.007804694534805153, 0.03259426410940867, 0.042280001836198, 0.07722671894777207, 0.029296902939677242, 0.012407206663591488, 0.08054278415417479, 0.05451390504716866, 0.02871674646983945, 0.027831763614930456, 0.02329909524339582, 0.07975503126339567, 0.034659089400402965, 0.10323726557075016, 0.038859419254285675, 0.03670319967392472, 0.02688842975804883, 0.05807682293497267, 0.02409385209302268, 0.024792591312659845, 0.06525756040167424, 0.034744883587043134, 0.02649423538617069, 0.019262363465743202, 0.043409571667472203, 0.06649193489142964, 0.03706788433895957, 0.024561230844307332, 0.029427007651857795, 0.02237466077560619, 0.013305159387058549, 0.06431580085547701, 0.06493509867258611, 0.012852357373753143, 0.07188948397074016, 0.017826544241078438, 0.009872955251334897, 0.10499835615196537, 0.07121852884489684, 0.03629592435073949, 0.060372539465465856, 0.013684323113862307, 0.0758447346367663, 0.06666965196810423, 0.026008558624814597, 0.023823549460259177, 0.12498942819694359, 0.05712123167130256, 0.053098615063654805, 0.014033623775767704, 0.11719106681524746, 0.023774104230406306, 0.015745914556206237, 0.06121981355752196, 0.036546278053954724, 0.025879352150725263, 0.07008536989169736, 0.02020808751694858, 0.032069897992656596, 0.03536629580682324, 0.0039370548808121035, 0.02431135594604477, 0.0190266918375968, 0.03676600356195723, 0.024726709666391535, 0.049721488819247296, 0.042963647208507025, 0.022909824901650992, 0.05681598010743338, 0.03766554783308699, 0.009155786829069257, 0.02273205802926133, 0.043580010908866124, 0.06483052001004258, 0.02005832115819137, 0.04481408279389144, 0.03459238612483587, 0.021974188313188574, 0.009562747098595626, 0.0324604706838727, 0.05224884352496555, 0.027501593126104246, 0.1099707953812134, 0.038438369670221885, 0.036776709640699054, 0.01996798407016022, 0.049337755377975204, 0.024046502113642714, 0.03510173500305222, 0.01435007171465024, 0.05019080960342, 0.033873699890870246, 0.07826090700203374, 0.034062249450794155, 0.07986665027396334, 0.016096443831620198, 0.05485414384653973, 0.06315714266571788, 0.014205316528527728, 0.027648122763381373, 0.021067140210840492, 0.01582440888253792, 0.012929612552867302, 0.013660847307032636, 0.042741550658378875, 0.026701833722331834, 0.0490903243001911, 0.009921971471950172, 0.02849602313231557, 0.05656545020399555, 0.017762189024999257, 0.015702250417351963, 0.03981029141634222, 0.07884188510117032, 0.04861710029804418, 0.015178402367558692, 0.016299005139679197, 0.06499493780035166, 0.039061459622556166, 0.059833826437111826, 0.0398621708905745, 0.0806618188958495, 0.016797531110745285, 0.03867329819308173, 0.11324027478094063, 0.03850723714417508, 0.015196279029271778, 0.040908037955241824, 0.027694695163518194, 0.017074186527620883, 0.06035212705272341, 0.05654094305129782, 0.02208509869242628, 0.02077238788197358, 0.09790470373005637, 0.03646399638044738, 0.028628351414696347, 0.04425839325713535, 0.04026733947196796, 0.08861800205082664, 0.0963681381976893, 0.11661102334337851, 0.12849245716126698, 0.07776924709398901, 0.0435030841899495, 0.03203550830573565, 0.037039106246083975, 0.12898574883659042, 0.11253916643439763, 0.14647761990706767, 0.12858644848869694, 0.19494231850389512, 0.18231643874558712, 0.21930297986874658, 0.10821091521891857, 0.16371606909219297, 0.16189469505221615, 0.12421124374433873, 0.1259726867259991, 0.14008958042869646, 0.24629113895277827, 0.2056176771199511, 0.15396320291103857, 0.10988559108227493, 0.18561381906751664, 0.1120329738384293, 0.09260918990138078, 0.19367228262126449, 0.12941927799294073, 0.1281516093219961, 0.22629967620295866, 0.09709913929503772, 0.12723607296544698, 0.1442933346956007, 0.15900698790867485, 0.1036259479400131, 0.08629015962322874, 0.1926649229661111, 0.241401169088579, 0.16605107444188288, 0.1356834410539558, 0.060626409512253544, 0.1785862340681976, 0.12638968370494344, 0.11383353326950343, 0.1584956548627346, 0.06983784688336235, 0.18933087767612553, 0.14084305854574328, 0.14804615428851498, 0.1765051409001312, 0.14025811977203817, 0.11807955260719023, 0.21755508898246675, 0.09098431741398189, 0.15460578214016654, 0.19458627148020655, 0.3133347414193615, 0.11163391097779236, 0.21348448079680243, 0.18962588281400744, 0.14400562271475792, 0.10853153067610918, 0.12251261231159011, 0.10325094024019857, 0.1782659786723314, 0.10743151268651409, 0.1314858001686873, 0.09550888632093707, 0.09369489736855031, 0.20100293200342886, 0.10676490894008069, 0.09345289785414936, 0.17472916523054724, 0.17709770990956217, 0.18000962543151072, 0.1785646150669744, 0.1807683589117181, 0.17083242836017765, 0.2556593677089099, 0.11807864096256034, 0.12903563648221955, 0.16031525157872709, 0.2262228682276703, 0.12361787034258728, 0.14388894752389, 0.22224622838679822, 0.11240327009750951, 0.08105742669994793, 0.14538428986505156, 0.13909895213380938, 0.10060649665613329, 0.15423441335799234, 0.10359898164507844, 0.1229048110244255, 0.2228891293728544, 0.059054048521624464, 0.14930169578761826, 0.11788436872584206, 0.10982420445690233, 0.11489120957952355, 0.1095496921709949, 0.1784827509113858, 0.12817584834392035, 0.08461949039971636, 0.18185620376419637, 0.19683132278582743, 0.11603135525459245, 0.1584360225787086, 0.09887652456640236, 0.2395853262034155, 0.1827298963983213, 0.13004123413514707, 0.09923943573789251, 0.1771591195175725, 0.04481150107758661, 0.1923202753307358, 0.12605468877741408, 0.22040161123919874, 0.11056717184762802, 0.08700671230232523, 0.10359967878508954, 0.11532312995123288, 0.0821312751260496, 0.28515854850411415, 0.14428913653377565, 0.11702503257941817, 0.1558434584688756, 0.2020972273162296, 0.12293013789120222, 0.231394482656352, 0.15442224279526742, 0.1742072908147689, 0.17573555961491602, 0.06131671218862457, 0.15209347340128115, 0.0963734012217291, 0.07965455117124705, 0.14924993888745386, 0.09097159269355959, 0.171953184349883, 0.16906740774791088, 0.24307291083518537, 0.06546138575480831, 0.15197370321519915, 0.19579266077808796, 0.17069056419835937, 0.18739354856792959, 0.17693208170033273, 0.12520138940383352, 0.14947536792005264, 0.16359985355407963, 0.08510227134871869, 0.12382819212131924, 0.10614864483115174, 0.1566748936930972, 0.1547513694892968, 0.1702832812142949, 0.1044366375032452, 0.160258392532987, 0.3082209206636875, 0.09824477015964447, 0.0935774177853619, 0.12849797299432178, 0.14257090857192395, 0.08843362767009005, 0.09048592359308275, 0.16095415358581852, 0.1300312137050975, 0.11041034598864856, 0.20905492977509577, 0.1183111563084587, 0.09727718578951974, 0.10611080774857153, 0.16773890403489913, 0.2026565021444713, 0.21596423079890592, 0.2841892940623145, 0.2377111993489727, 0.17609312349269468, 0.21211745818295788, 0.0933298794552684, 0.08626707739407018], [0.026974739138818076, 0.03636360438841005, 0.03159922123285792, 0.045206350454640006, 0.08376584628656988, 0.0349793677789069, 0.03600873330968522, 0.01793340393041651, 0.027101997834359928, 0.050431050946034735, 0.09392843161138797, 0.024022866385958852, 0.04196931870894567, 0.062132772028205864, 0.010299916161344418, 0.004173100216224069, 0.0698511002044524, 0.09260810971740754, 0.04464991781259737, 0.01860390323394489, 0.09235084973155491, 0.025763377930308064, 0.0861287372367036, 0.024091308681114067, 0.01668028326915397, 0.030682415085574313, 0.00675948630575271, 0.05513595695036554, 0.07017572230148701, 0.03182646589383724, 0.03452941752789963, 0.010696767900709905, 0.008725129544825084, 0.05562010536631269, 0.06233650545078901, 0.02555579108546578, 0.0755973954895331, 0.019658555411883903, 0.017911978366394198, 0.08079065956295499, 0.02497446441632365, 0.04024924064475683, 0.02518611344238443, 0.019493513259916537, 0.03339218298694299, 0.01886346531400998, 0.10091899924220578, 0.007648556239737739, 0.026871838208828724, 0.01866956654515478, 0.01143335569424615, 0.052472656112044096, 0.03230307791982928, 0.07777847845347659, 0.060692986383313136, 0.03562604174799016, 0.0388204062267417, 0.021083710692642678, 0.08503202874694141, 0.06323706095797882, 0.08892752455487367, 0.036301616384016896, 0.027483555585927064, 0.11339976662589658, 0.041331902912427346, 0.024868100768916553, 0.04322937246592295, 0.040196916839528474, 0.05345481530492825, 0.03316999450626393, 0.01094548696381671, 0.022544402876989018, 0.14122956522530125, 0.005061739225751691, 0.03742437569364425, 0.04833950067780191, 0.03691929392516613, 0.055942478995289535, 0.025495915568523833, 0.02023788642198328, 0.017272461573743535, 0.014631098620743762, 0.02972338025668456, 0.023398200207720363, 0.038156380366173484, 0.03757687315585152, 0.09082451913385622, 0.019755934763159004, 0.022912640274772723, 0.06037634309200991, 0.036425879675774805, 0.04969341935770166, 0.048132005763510545, 0.003718732989528367, 0.048276378863280824, 0.00540454154683938, 0.011879830778906903, 0.033448375536188964, 0.03616491948524791, 0.025064468256107746, 0.02064398963064436, 0.008727718922009152, 0.041238191207089735, 0.09148999673104094, 0.03543139029774935, 0.027145553763294895, 0.029905490847604892, 0.09326032633262296, 0.052561024354109843, 0.0439154731500293, 0.05854786358653538, 0.03116796352720309, 0.06386068334142048, 0.044964622901452166, 0.017065474192702004, 0.04732914561886461, 0.055921465203526526, 0.023397736724526174, 0.07559950223132487, 0.01816007211023281, 0.014955481315302032, 0.02271635514203339, 0.04638652805419219, 0.027072534092792103, 0.03556364005611789, 0.05690187771594333, 0.028770363048440026, 0.060272231743100195, 0.03706091293884862, 0.06849365368966134, 0.02306287969282318, 0.033444794075142954, 0.011939160458202805, 0.03922307353106238, 0.04268566071386299, 0.05987968446025926, 0.05818837682806677, 0.061429587583388054, 0.01520722546809984, 0.04768622686125098, 0.07931949495668374, 0.010782658805950515, 0.08665381390000544, 0.04321350295457148, 0.1044310910266734, 0.04788441763770196, 0.03734631133416007, 0.04722120383033349, 0.0822021305981663, 0.027334894309000626, 0.017611800219803568, 0.04292874041223719, 0.03663526299679953, 0.013587183165063542, 0.036254727972611304, 0.056449207852804856, 0.02816418257181443, 0.012577856579164584, 0.03657470757682477, 0.01904478108870887, 0.007020448890304374, 0.02935059995750987, 0.013975630919899673, 0.049759567219523654, 0.03785526567709543, 0.09035626321189827, 0.021325357806598468, 0.03897967207575998, 0.05259755142633954, 0.07500903230280646, 0.06301050194569173, 0.021304838141546618, 0.05580207423096704, 0.034199413663196954, 0.022282667022438783, 0.02679379300154265, 0.058033956485169555, 0.026406338288178368, 0.00810398641342838, 0.062361165821071596, 0.0398857051116084, 0.021487042578237674, 0.031792568418407635, 0.0038073231576896847, 0.00512272748540366, 0.03629974712948165, 0.0870324068913056, 0.038958780858064854, 0.04048540256917477, 0.03398321599008576, 0.02567758374366789, 0.03686292517569758, 0.05023918422539869, 0.05424626073950241, 0.005519411164230758, 0.06988183565197453, 0.06336901960293613, 0.013823659185530439, 0.10380344285118966, 0.06949337544820963, 0.02329406970661254, 0.03353739112255073, 0.001939083688944999, 0.07886444639054038, 0.04901141724399021, 0.05842009927296351, 0.005008683327750694, 0.049669992388977166, 0.04836983009872418, 0.055050829260219494, 0.02682852934324934, 0.01875189609915739, 0.01543899866632156, 0.007074131543988423, 0.053865109014535145, 0.08533306299678742, 0.056704985458524, 0.05822589598415841, 0.0559531391087559, 0.00563424582886059, 0.09757871799651655, 0.006640442466783908, 0.0422163246079318, 0.03577011990390959, 0.03619150273622044, 0.05062493630835126, 0.07463530396982547, 0.0477831254923536, 0.07022670545284787, 0.013217823448470764, 0.0680423666152262, 0.06335591949943094, 0.05319619934344965, 0.027550768309963808, 0.04005819746863939, 0.07793209440405331, 0.05680465732791251, 0.030295161470290155, 0.04264491632761013, 0.05400460596466738, 0.05703115505316565, 0.01624782663589764, 0.04398409930628635, 0.041984962224359476, 0.04719807946633908, 0.03664895298800642, 0.01866156475678567, 0.06916438665000663, 0.03451124209189608, 0.0077697719379718755, 0.0192849496529708, 0.03282645769837884, 0.05529693117545498, 0.08754373993724586, 0.012956920714538186, 0.027060259449025317, 0.05917708990314315, 0.010656690010951172, 0.05766546436315102, 0.0646761609541793, 0.02327601684467687, 0.04875804132391368, 0.05508512701658953, 0.06914279063142116, 0.051100274713169185, 0.029300440350667607, 0.022544035154785362, 0.03331983747381357, 0.02497928885502681, 0.01673863618634641, 0.06800806885885616, 0.04409394099286968, 0.0613117058040394, 0.025591666982959838, 0.08058641286146256, 0.03394969581295887, 0.008299149227358641, 0.006992784976553653, 0.04558645646959063, 0.039208242068848306, 0.035970237391490134, 0.03931292798370123, 0.04924588994453511, 0.041813389172837626, 0.024560129592916178, 0.05852356710801682, 0.05456168212056641, 0.07013288266476124, 0.02013952264772548, 0.008852682226607877, 0.04136880153730031, 0.03506132769548605, 0.011571328129409062, 0.028019920554793173, 0.02534393521566545, 0.06083652827768557, 0.022852236157163017, 0.06986704249415668, 0.04722146813066737, 0.01684337381213423, 0.024031241642191045, 0.046358385814293745, 0.042256237788786816, 0.0319295660066869, 0.006436106228765341, 0.046414815850796244, 0.022926789918734182, 0.12779389222663257, 0.061614279890613216, 0.03283818267405995, 0.03391959621841389, 0.04307946438089975, 0.05786645136052563, 0.05774084741490022, 0.038270205709963076, 0.026069271092813824, 0.03738427482124779, 0.06364023771076914, 0.06284192046751419, 0.04346255430831544, 0.02121990580382126, 0.030194844171825438, 0.040941278510276354, 0.013852029336586356, 0.05107775555863496, 0.04728024622665779, 0.04555392837632568, 0.03547261731939451, 0.029577729705300544, 0.02584561363853995, 0.05038937576295388, 0.04010756800491964, 0.06109103800789003, 0.006952026704957168, 0.046062273679361235, 0.034009439179733876, 0.04275698733005313, 0.018343529100680066, 0.004376925569358132, 0.014710093777055943, 0.049416804160442085, 0.04268441965142566, 0.10666481955277343, 0.013586451551095854, 0.02039373168841966, 0.03882574969001355, 0.03834338242849035, 0.010847213204890009, 0.036477655728137305, 0.04652313685284988, 0.027011256634948716, 0.009026493212478537, 0.11909982850474697, 0.1308954068489613, 0.19731277840272074, 0.1276887313372666, 0.1616159769436044, 0.22296071262849917, 0.12282811030144654, 0.07729667809701736, 0.10626648447566456, 0.345736614037906, 0.1839586707853502, 0.13437419679136048, 0.12468130763379798, 0.17435660135121117, 0.1952397138361008, 0.14648563318675564, 0.14767633300394784, 0.11691080886990794, 0.14873943321647184, 0.13769834422536437, 0.1643616820295011, 0.05272995440229293, 0.2946827067963539, 0.10918288927284941, 0.09105068361086231, 0.18248493212365335, 0.09700265052097459, 0.1735701661316618, 0.15513038382895533, 0.10928671716922715, 0.13567149008233703, 0.12960289394663227, 0.17085050803519067, 0.16282379116502502, 0.149979101373784, 0.1461723645127589, 0.12727667562543385, 0.09339276761297258, 0.10502569782998293, 0.26118220280735727, 0.10595884654791125, 0.18711573444306853, 0.09705635328446666, 0.1321048298550229, 0.19137017308704315, 0.11703087016940118, 0.2577651442298966, 0.1254008863601954, 0.07844361897197463, 0.13200168377689778, 0.16848801545077757, 0.0953172111222821, 0.137387833467895, 0.18328998327976276, 0.16293760118705614, 0.18854658750276412, 0.21961254067718985, 0.13046949260657834, 0.1647491233363267, 0.20947457741825812, 0.140934391548076, 0.14582270666235878, 0.1569640459192376, 0.31023769308963134, 0.1810630576144303, 0.16050640583759354, 0.1284286037327782, 0.10106924440591566, 0.11429454966057694, 0.20226953581215876, 0.1720030107084782, 0.16032027711551036, 0.30043185958939217, 0.14465814576514308, 0.0979387486774114, 0.11929920288704096, 0.11019859928637744, 0.18533989666931092, 0.12591409632155012, 0.14226753775390888, 0.17462614172649, 0.06737023937485873, 0.13907632189652613, 0.11252734569772599, 0.10104075359601168, 0.12936022793573718, 0.19639298259731264, 0.1525032385102203, 0.13542050435658426, 0.13560375258807214, 0.11723494833155025, 0.19779101645033206, 0.1522894540140706, 0.091895594321672, 0.13486866058120806, 0.11763403417482493, 0.1356578843608018, 0.12645550597939761, 0.10721172206103803, 0.16800856698424588, 0.1375423227587054, 0.09645228529529226, 0.13111721994655748, 0.16137096670366105, 0.13024463047904353, 0.17155576857828325, 0.1238650179678394, 0.2165354565987664, 0.17262695867928768, 0.1347206217507201, 0.2690380667486499, 0.09476764262804101, 0.08103262843383897, 0.14859228304797603, 0.1357566943812755, 0.14800100106625788, 0.21046332113685148, 0.06061924659016152, 0.1435082171472811, 0.12032353138971714, 0.12563712489340575, 0.12157541098854235, 0.15243890244633923, 0.19428214989602569, 0.1680999919171295, 0.2715452273766841, 0.11423562983832053, 0.18690873748592793, 0.1877047488045308, 0.29620287038626214, 0.11274136002025298, 0.25035822313399086, 0.10821619356471686, 0.12430718859597562, 0.09814452755475238, 0.13962111766299895, 0.17978016677643024, 0.1856284513468704, 0.1150825783430088, 0.08575425813755683, 0.13510352781703397, 0.18355115797490845, 0.1777861165183206, 0.16966135571560553, 0.23009407904840287, 0.10198615972072848, 0.1766470969925004, 0.22228689233381904, 0.17581656575202945, 0.10269318992692618, 0.10532811869897189, 0.1119762909929118, 0.1395961431966674, 0.07993641024034831, 0.18795018805371178, 0.1519246582662867, 0.18323621922923675, 0.13271368589372406, 0.08628713357592784, 0.09675866683884975, 0.13977188376649735, 0.06043222920608617, 0.09796028340896291, 0.06966838057363225, 0.2593968502215801, 0.20766349959998362, 0.17796499804864008, 0.1227631000801921, 0.15507341753090584, 0.1851829865406598, 0.21512775471614254, 0.11677406217542388, 0.10531015393714752, 0.12577957128204648, 0.1827840741363264, 0.1373518273354538], [0.02964182062104585, 0.029580301845506318, 0.018077822995462248, 0.031059544848939104, 0.06768764492364661, 0.03185521334319586, 0.04276508487941277, 0.03084904495476475, 0.03096122320951714, 0.027441641000369867, 0.07343214756298451, 0.029805476153870265, 0.039245554381200386, 0.021864325559187322, 0.021864199154679815, 0.06882592134418027, 0.0841784535817081, 0.10342255159611664, 0.03165222302589926, 0.07920295000076294, 0.009372473840842084, 0.02761067255520292, 0.07847590957798305, 0.03948652350734319, 0.056232171313416575, 0.03735469616649132, 0.047724266957131126, 0.038298845907012304, 0.04390205895047515, 0.007192144037089161, 0.09818053368719355, 0.06118611718017248, 0.0077813930129782575, 0.024342937920723232, 0.05631163378336257, 0.033629869426330256, 0.0499709768431081, 0.03799805297486244, 0.054500425730140946, 0.021379355513941378, 0.05209132435641462, 0.03128137135307395, 0.03748634837627892, 0.013814424953213143, 0.03928574718414776, 0.14412219065331644, 0.04373201424436223, 0.05598498155332862, 0.053283521875498764, 0.04211595942897182, 0.01991740503017941, 0.021048428513289943, 0.034024841377451535, 0.01667197696083496, 0.030309600312443032, 0.02716550652328278, 0.019516009431813034, 0.04131487660831021, 0.05498720948854762, 0.033185339247387265, 0.08140372908523968, 0.0034690275882190516, 0.07398693311598993, 0.0501430057169449, 0.06435406694729483, 0.040955190666981285, 0.013763179416738212, 0.05688610013514277, 0.02652398832592993, 0.11955452467044515, 0.030576497684383107, 0.05284385252443533, 0.023488182980086536, 0.055774165647885496, 0.00978849501529288, 0.09645675158789081, 0.013542705057789723, 0.04927245787374916, 0.06431117368441436, 0.0697457018278299, 0.01706705424904583, 0.012406837026168023, 0.01928024970355534, 0.040142873166910106, 0.04112595932618265, 0.04180346067333895, 0.043621303047984845, 0.041200120467692614, 0.054285407832433144, 0.05537844293059842, 0.04377725939717024, 0.07696011268924322, 0.05091930942369565, 0.025682251134346572, 0.005142452334234071, 0.007993107635317551, 0.030051468901576537, 0.006761750574373911, 0.03999541273280498, 0.044558485218834494, 0.007050615996347681, 0.020366947339367003, 0.04852030891925097, 0.011060228740285722, 0.03195543105023042, 0.09335764248164431, 0.09545568917547503, 0.046812246944154465, 0.02395627419314077, 0.023292252163012183, 0.04275227205887918, 0.04715300668331404, 0.04024682746779534, 0.03716745278647831, 0.021786849172185027, 0.06901817110877845, 0.03390181914813096, 0.03902850635049324, 0.04005342474087112, 0.008393412516001732, 0.07010331167088402, 0.030352629555930054, 0.02886968634782299, 0.045618969241097096, 0.05825799123774614, 0.08054087659524334, 0.01151879748044115, 0.046130413369786356, 0.016518135014320576, 0.0314227509642801, 0.00598932231491011, 0.04036254121831829, 0.10253916028887035, 0.017752568875890107, 0.027268987764874776, 0.04185178933004218, 0.041738718582858006, 0.032777918367496425, 0.04422365500020885, 0.024098871884146528, 0.04489742932961353, 0.04005535145200068, 0.06534649554880397, 0.044070820459314895, 0.12207570470749371, 0.057983394682167046, 0.04594229281910005, 0.058455967509578315, 0.05119734188361515, 0.027194095009397116, 0.04677306154682752, 0.03941905414385181, 0.029405894268664624, 0.03080171221236308, 0.02105375090914388, 0.06956220078732699, 0.03051822137598309, 0.011513179183126459, 0.04088575628796413, 0.027028135467140425, 0.04317822077521875, 0.028136413799779072, 0.040592647217694795, 0.07553954819037069, 0.04757690228401654, 0.01809878507629037, 0.05524333183383269, 0.05846812915537627, 0.06482043829295905, 0.03444701711076402, 0.009152883355836234, 0.0437768763532081, 0.03670263276886075, 0.07721747992740524, 0.021448732436364217, 0.03769532950114339, 0.03100520240203027, 0.05690476586741786, 0.03624540851301244, 0.056775297008214466, 0.03248734887869608, 0.07040911864849829, 0.08692542271267983, 0.03458239250786362, 0.08883264456545154, 0.020569045164231813, 0.043602572198236184, 0.03829604968608868, 0.047589240130037076, 0.007479631937214084, 0.0468142579249557, 0.04897264553414238, 0.04886756125356882, 0.06084652572509743, 0.015703387100309614, 0.035440001126018264, 0.06619968767007513, 0.017934802040878325, 0.031624923482717525, 0.07415601638175788, 0.11668207033747628, 0.060341072403976036, 0.05892585519881499, 0.03538405372490806, 0.04624280612915755, 0.04440296170932632, 0.06220149394545344, 0.07555463246159977, 0.03653699689875207, 0.010855594206781638, 0.08639365810179904, 0.01966683107668594, 0.0672357909441475, 0.02574170721814998, 0.062080674218915166, 0.033773407490263065, 0.03835303896677591, 0.00858617460189928, 0.02877356912640314, 0.05699483482467552, 0.064624312123464, 0.0062157649775936965, 0.07838456125389184, 0.024218006217251384, 0.07384831716697063, 0.0167775783507574, 0.027484187608464595, 0.03342201445071447, 0.032849539927537405, 0.07508952516101061, 0.04661066239819892, 0.07809891004956539, 0.04271903533428427, 0.019532078126024817, 0.0462711475519163, 0.02135469322843898, 0.01649960526265204, 0.04784057442579539, 0.047801484789458976, 0.054912592524722706, 0.06119942412741723, 0.017964964837677056, 0.07263139416013034, 0.019929467084547205, 0.05322598484194568, 0.04565497154309865, 0.030721941392027566, 0.08898980750311768, 0.01843737295618461, 0.03308860149474875, 0.03963866856910529, 0.08692173782976405, 0.0316015443944883, 0.02368275399109529, 0.03117704166910581, 0.11933805886656047, 0.025730445725663055, 0.08843478446285571, 0.041775084776623596, 0.03166751797130752, 0.03649876145045123, 0.038010716408250794, 0.055638759607268926, 0.013052850244416585, 0.012325821312955551, 0.11023737865710452, 0.04271908512999935, 0.0999287310086431, 0.044465175709657134, 0.04413463941384708, 0.04771896945913473, 0.0265612087077311, 0.048670228495593035, 0.02460416241158401, 0.043218674048060374, 0.0437704871799196, 0.020792855836090543, 0.02970764672593965, 0.03386636842943488, 0.04879697391222562, 0.07537128463868173, 0.03674900790135707, 0.04932416497819847, 0.04636339985975816, 0.024985676113095497, 0.06853262458236949, 0.014765154431393791, 0.040351229930116285, 0.03348471491687721, 0.06611332657837099, 0.02276912327825783, 0.04449778041171451, 0.025351234118364034, 0.035857825479920835, 0.041052594916113926, 0.007459364602372291, 0.043707982066177556, 0.08946839795117417, 0.024335133399994626, 0.0066136092796260796, 0.04386066721992628, 0.009205503062525345, 0.09568607479694391, 0.027461873382450114, 0.10757579002529384, 0.035244219696089145, 0.013971340827523701, 0.05561113447671937, 0.037326879513960694, 0.08453569570255857, 0.034519136627955783, 0.0755925078485762, 0.006491146773295177, 0.019345495496846495, 0.04717348038309044, 0.06076702495075523, 0.016190640087569916, 0.024156407002479802, 0.023180903198437828, 0.015271330747993724, 0.03691298136067006, 0.058882188187131, 0.020542008006164146, 0.03480085780123069, 0.05994614258769059, 0.02811999845078155, 0.05068234693739684, 0.039906611651062004, 0.07760405555487641, 0.06874525228575354, 0.034323355198026664, 0.053323086486348224, 0.04948184885565312, 0.0595858016411864, 0.02579713750991129, 0.0866998557842547, 0.02891747874297923, 0.02070920286519874, 0.10811593563806628, 0.047031056977087454, 0.03660560773325063, 0.02803400508128107, 0.044204280636603796, 0.01677697697173684, 0.038158460294887904, 0.04646908551935227, 0.015419424162246289, 0.011235556580246457, 0.036990536271684596, 0.1029171787142273, 0.03177152589834746, 0.01976718284910725, 0.15259028142017705, 0.16153000655674166, 0.10310732173703371, 0.1046391988113042, 0.17317681062606075, 0.20277837141146585, 0.2128701089250465, 0.06870903164869355, 0.1178710617785973, 0.11418590307115548, 0.14045581642177798, 0.09295681761878152, 0.12261930537680465, 0.14565081185390874, 0.13815946786874725, 0.17453957379104632, 0.20172837130244703, 0.3243227711608333, 0.11673165154793572, 0.1704105284185179, 0.15539531235493, 0.10300973745723886, 0.21695977737826688, 0.12308131002130047, 0.1982721196667802, 0.1385567763880376, 0.20680221759023207, 0.11024658703395437, 0.11165726133772444, 0.15670622668920026, 0.1313849676760935, 0.17158391464862133, 0.11623525721651894, 0.09019690160188945, 0.11305887282135026, 0.11792386055833871, 0.1443293561498004, 0.12517695885992822, 0.13082212287812464, 0.11000396698833474, 0.2656643993912205, 0.21487211117581015, 0.12132641709139272, 0.09477566356860823, 0.11341632178594029, 0.16851795416685844, 0.21961422607062325, 0.10467451546461352, 0.15713126759134954, 0.12285270172381595, 0.19751733920026213, 0.1330459382264845, 0.13207498306949295, 0.10256121596021038, 0.14396459104553347, 0.172885344814389, 0.07917610627989616, 0.16145466947026793, 0.21624549231942625, 0.12275514042665883, 0.10584217901792257, 0.1732546911244431, 0.18315072381688705, 0.20975245283015315, 0.15453701808808312, 0.15419799353807204, 0.19001168469267507, 0.17091109026824275, 0.1858630274692851, 0.2075558795683807, 0.07303752035142914, 0.23574722570277032, 0.10036285005269513, 0.09588615398012823, 0.0971342874090037, 0.20992431699508624, 0.16002125767690523, 0.08251641816910237, 0.11057444202202944, 0.21094001168685578, 0.08575336947556465, 0.13900548940704716, 0.11047908705809426, 0.15075081238342872, 0.09750004076669294, 0.13844840559026889, 0.15147133339797297, 0.1529799290602246, 0.16031614024071925, 0.15106706880033016, 0.13479710796908026, 0.2901410617895665, 0.22201186676900234, 0.16708011438529338, 0.09900750261881659, 0.10242256170679485, 0.21972455805347813, 0.10211349119462314, 0.1254079956561327, 0.1873634106689884, 0.23259262884816817, 0.10365364201847585, 0.09436802818409859, 0.09051864320832877, 0.20280808030116945, 0.1521189841291597, 0.12234490800408587, 0.21143649794882347, 0.08507921210219783, 0.13604599982500076, 0.12012599561844142, 0.1800520513807574, 0.07080379948620835, 0.13691609184588158, 0.11344607664091934, 0.16655865365699415, 0.17104641203918766, 0.08212204376656203, 0.1451012356987884, 0.08547456709728127, 0.12936053437090692, 0.16917061511306994, 0.13120628532863435, 0.1650083828116617, 0.10196097841065738, 0.12481482909812082, 0.14044711366295815, 0.1899702393359715, 0.15961400533635772, 0.1340449322015047, 0.05443869436520243, 0.11226250910230222, 0.17308560019779592, 0.16051316273308572, 0.11568020353274, 0.19412638889926095, 0.10365158890283878, 0.12879093267744587, 0.12163268372176156, 0.16530254525282692, 0.09140103094039426, 0.1691093280791275, 0.12696586609367402, 0.13183481450523102, 0.2183052422779222, 0.13680140848361677, 0.1298390022448955, 0.17246902199281802, 0.17571623887746565, 0.09663561779645183, 0.25780249867708455, 0.12830533252488222, 0.20625238096521747, 0.14007330872118473, 0.14203715979331924, 0.34000489740602435, 0.09319430487530847, 0.13572382920932385, 0.08941980499413707, 0.11711042840033771, 0.17393243378929554, 0.05901386720999595, 0.12317883301406138, 0.1703169277959293, 0.13874935557044324, 0.1116180759403975, 0.17759707666212515, 0.10878358892495595, 0.13185174504835762, 0.24868603705638842, 0.10357772270517965, 0.11313042543347805, 0.21290858186060385, 0.1644937249441301, 0.07102801809988676, 0.1348337882588948], [0.06477972071978354, 0.01880375450597175, 0.044854704606076407, 0.040869668441554236, 0.01438051126071162, 0.027391056214729627, 0.0314446208592985, 0.022817218278144157, 0.03024114461074914, 0.03168917910736655, 0.009844612870966236, 0.020395660314769037, 0.03172957683883367, 0.017076425419579593, 0.022359854211249662, 0.03863075350020682, 0.03950248111880595, 0.04831321237068023, 0.011849198753254549, 0.04169232429816358, 0.03689714632327518, 0.020944047118386915, 0.02405793406069279, 0.06674826025001465, 0.03625815238563284, 0.023526305430418542, 0.019662994891405106, 0.04432848647176739, 0.025900394670785438, 0.01635323267339939, 0.027585136929466843, 0.03874585438039034, 0.07313805406973248, 0.03230139635683548, 0.07404019920936517, 0.015314789000718344, 0.04936359169322157, 0.04843834134179258, 0.04980076742809146, 0.06900379929931895, 0.04109840314354628, 0.06793927416325578, 0.05476161191660551, 0.03453798622133271, 0.03177807786531987, 0.046674826092297034, 0.024059537099674348, 0.0036087876416727783, 0.034972082282746994, 0.04300264874473215, 0.04010003353018434, 0.051244398834364074, 0.04182895224901938, 0.05273237524013366, 0.013330156836027821, 0.03382541336900285, 0.015260760649858464, 0.03551713851911407, 0.0672698665350195, 0.05386948337658279, 0.010081022816349663, 0.02399578900827516, 0.036234464947014086, 0.05882438302280442, 0.029737112382727287, 0.012120188949930092, 0.029859998631441308, 0.00648778604133235, 0.023437203659165292, 0.06631652373940715, 0.01695162203583506, 0.006701766847512655, 0.02750244922935963, 0.010561266099102797, 0.03624395677639592, 0.013256259994851726, 0.010320772905082954, 0.038498155171832735, 0.03231260039272808, 0.020244723756707484, 0.02288742640596484, 0.0073504388696634245, 0.03720973700945897, 0.023732712499857433, 0.050663183247970964, 0.09352336262142466, 0.019293156369859656, 0.007475080417333952, 0.024456271053021474, 0.02905314333827025, 0.013860494608149655, 0.024057704234315504, 0.09020186585163878, 0.09535397568176832, 0.030001098620555097, 0.04079949095725052, 0.025584157406082077, 0.08235407647706809, 0.0553416247449575, 0.04481427814631213, 0.0054013876586161075, 0.06346401067510729, 0.020876198541373018, 0.009438038518231724, 0.05714351716901987, 0.03132787863573721, 0.03231109119951725, 0.04269543599577681, 0.015188342358376232, 0.021882502910410686, 0.03368275247574334, 0.02310462956947665, 0.03095912029816499, 0.0731004391526503, 0.02237440796659118, 0.05983415968535889, 0.0411391781733161, 0.029880887933916626, 0.024791526450445096, 0.05814348024526431, 0.06889762717389292, 0.017918821446777835, 0.07129110035396392, 0.07401075078955582, 0.03274766555536659, 0.05492558920635812, 0.012996126221673144, 0.010341314595162628, 0.04481158151681866, 0.045324619108390425, 0.07265537271216031, 0.0714791059914616, 0.16457931228703068, 0.02215267722344687, 0.07317711689299153, 0.05917539684883049, 0.10525206915072857, 0.030935827394827243, 0.022425107665420062, 0.021039526571609804, 0.023598095529802868, 0.026955251777244192, 0.02493951740043779, 0.06731329605944696, 0.039222564082592726, 0.05975568929927484, 0.09504779332107115, 0.04350256325016099, 0.07995851953784305, 0.05456988692223545, 0.06192522731819942, 0.03212088114401746, 0.04615151526166066, 0.032829192632268515, 0.03259866911497328, 0.023489517888294596, 0.01718927783170535, 0.02247576522941311, 0.030824510988989667, 0.03685362486829681, 0.037656144103816444, 0.025635717038605964, 0.06450073448039832, 0.014749518576859227, 0.032907934979565685, 0.048277731008467176, 0.039379558480915525, 0.012359910310366222, 0.044847633614535296, 0.04709989380752368, 0.0327358026838591, 0.04481602482677949, 0.04881256380148473, 0.031462344303426724, 0.021257739055961854, 0.03685450203897011, 0.013369295310469405, 0.035192470456804, 0.04060856269432172, 0.06629696551470027, 0.030118712269130255, 0.032034161906208725, 0.05524948351986467, 0.05873941621112247, 0.04096457907449334, 0.06163352784971076, 0.007316084135504019, 0.07108801810611641, 0.023414299545449116, 0.027969452597561385, 0.05122914219335203, 0.07585431839669905, 0.04425970326748587, 0.04026968753145587, 0.0427375823229311, 0.05562500066814884, 0.03816661530084187, 0.027337738410419515, 0.04854409211886026, 0.01661539179152779, 0.07074281888743562, 0.07391115935939936, 0.028965003007361968, 0.03623924150522198, 0.016031735257485944, 0.01989737949183872, 0.021154719382344235, 0.05026009842573155, 0.10020395575632011, 0.02743813614811628, 0.056417480321420785, 0.04424174616654073, 0.04239076665873009, 0.010291185631837335, 0.04756373706303778, 0.016811056393048456, 0.027079155007677696, 0.0809121304642289, 0.023650616602671724, 0.00951282880944951, 0.037225755907955675, 0.05409816062198051, 0.01673744491962416, 0.02378821556997155, 0.049006924138314305, 0.042568319026500955, 0.09409781365144639, 0.04407541315642096, 0.05154161030546792, 0.06407109705070335, 0.048975123828577424, 0.08329759036461193, 0.0473231663026156, 0.048834799503486966, 0.032245468107923385, 0.05093479206064536, 0.03423379951967828, 0.018432946883202083, 0.05466302406162985, 0.009149216667508647, 0.016076332108388026, 0.0073887566724161234, 0.021730639385960756, 0.007862650043886877, 0.016877489622622248, 0.09248860766209903, 0.007409779561473238, 0.04312256448751977, 0.07631354214202973, 0.027429584691661502, 0.04113049839713401, 0.024291481710069125, 0.03837360459710321, 0.051206052303314216, 0.0010526277905991, 0.03787793804921451, 0.04757843829030472, 0.04324492022034623, 0.00802110575492524, 0.04188227579898892, 0.05759408029036657, 0.07835178035161189, 0.039043514012929895, 0.03705555415381828, 0.04602649354285771, 0.0847443474096156, 0.024241797077739914, 0.07596448184021058, 0.10328683145945111, 0.04872629080989188, 0.06904498418612827, 0.045317322120911656, 0.07990041942966562, 0.037412704344117836, 0.02985369181260467, 0.03453664556746522, 0.030658629970745217, 0.032686616008680676, 0.063036035656208, 0.03728320101095784, 0.05416047804418111, 0.03190900037635959, 0.04919230209423169, 0.03092848061163339, 0.027967658036598758, 0.057744980459251714, 0.0640921185033456, 0.033420777218716766, 0.02685538264021518, 0.009988891167355882, 0.02423610121402289, 0.04400209854206732, 0.031308289767513355, 0.009250845891543695, 0.06325659620004796, 0.05355079463052173, 0.01914671866313344, 0.0560877445874916, 0.013344339996335969, 0.03862570115034619, 0.02688368001291829, 0.049904047571603334, 0.0550887008167563, 0.04654747546620427, 0.045764855364517826, 0.018353471006717414, 0.026836299390021353, 0.020662168897087538, 0.035846004743249185, 0.03175195235188209, 0.062151077699156544, 0.03634498462141041, 0.07617169330196996, 0.010366947897109053, 0.047784297606877746, 0.046698923387955275, 0.03631762762163435, 0.08558825454524449, 0.06259078152417656, 0.10704676800918196, 0.03494620000222518, 0.016750108353012515, 0.01533998754776774, 0.06609803546340236, 0.02764517332487289, 0.010617586968076086, 0.09052231276948607, 0.03615552341685661, 0.0333624740972394, 0.01994248291838073, 0.023532453286010894, 0.024247726598273844, 0.04891084139085105, 0.05916821094410074, 0.033616179435123364, 0.0654274327380042, 0.08168246251560989, 0.017223437692249016, 0.07259665973364346, 0.041945707879119346, 0.05142437587041528, 0.03857495165580223, 0.062445784062748, 0.07080451960885717, 0.06823770371415923, 0.09042668201389814, 0.039645666782293594, 0.05853097517824462, 0.02224393744742678, 0.03890405536719388, 0.019120608471454154, 0.05399529799638737, 0.11404547149375563, 0.09933010990461034, 0.17489356769909783, 0.19614852394067472, 0.12421242351974211, 0.10312834318967597, 0.15728299896563255, 0.12738279412470518, 0.06313159746388275, 0.13874534126972, 0.11499513706733143, 0.13340097401411305, 0.11037296855882292, 0.09389939687905774, 0.10084418309552055, 0.12831406592721903, 0.09723072255691213, 0.072376761855858, 0.1178140035499969, 0.19299288520649557, 0.09849108274905913, 0.07930315430125884, 0.18765286933029854, 0.18352676573539936, 0.24593357507499958, 0.26878412392350937, 0.1564056291094711, 0.17279528351801057, 0.14035631692217243, 0.160821084113371, 0.11278051477406295, 0.1295551819907081, 0.16123757547428533, 0.09500560485908101, 0.23176528453346223, 0.14999347318324352, 0.17484030926660185, 0.18429233271989132, 0.10704470723266564, 0.12760802397444365, 0.19897325865684018, 0.18841488166682183, 0.22145285241065488, 0.14246273695701553, 0.10137403248659066, 0.1162164574188571, 0.11553936592874028, 0.11334662310658924, 0.13866435045436507, 0.13418460535185953, 0.28116005983564163, 0.22794112683303897, 0.1686763198625657, 0.08863967467820452, 0.09030883470850606, 0.21041876546317534, 0.12539716317288338, 0.1269383711980716, 0.1408503670245409, 0.14905921363782498, 0.079736836675194, 0.1103229966435221, 0.1261666601884269, 0.1413261842343115, 0.18690072420623996, 0.15035443849140598, 0.10051337100805775, 0.11853119208207054, 0.13926755276418504, 0.1872956731747235, 0.17261241833048482, 0.15347666047032804, 0.1568606700147352, 0.12209691768211704, 0.10412360631650495, 0.09234974656494395, 0.14695847797538006, 0.11483838781714441, 0.10114717853045273, 0.09188808666001405, 0.226565478069167, 0.10647568776602707, 0.0855814746671146, 0.11005337199857158, 0.1644280099219853, 0.2432752806212633, 0.0968444380428522, 0.06753532366166193, 0.25476071593021193, 0.17072965000425616, 0.09086510647208461, 0.12116837315261365, 0.18008655598086698, 0.17391789344049272, 0.2111266000616935, 0.14282174108009185, 0.23571961589397925, 0.13019642822684782, 0.1894872975085051, 0.15138861122390918, 0.1519481771655621, 0.13916540260036148, 0.13270722011164313, 0.10397224266442562, 0.17245426713939638, 0.11498298691285234, 0.16201179925232165, 0.09864189481783299, 0.12791299591622046, 0.11334365068544304, 0.12708150706584417, 0.13871835965302684, 0.1527891118800448, 0.1662826321778759, 0.13419937552703967, 0.11164986092837588, 0.12109936395239447, 0.11530751707933604, 0.13423792507138946, 0.14408898840267814, 0.12129663925377593, 0.15606070568244304, 0.17631899685628954, 0.09207629914125127, 0.1251619052322161, 0.20325149199174297, 0.09876310524921264, 0.19221077072283915, 0.13482759826846663, 0.10021330202899634, 0.10075737767282034, 0.15040109324599468, 0.28394659740790246, 0.08262403820070528, 0.1114505248504781, 0.18847967738345747, 0.15122947944027765, 0.1438599127915598, 0.16730214198750837, 0.12938351700863532, 0.1566327282137448, 0.2062810020100686, 0.14637533184741774, 0.22205380242197748, 0.16016732000054854, 0.09712405247433532, 0.13169158670690753, 0.1475663687432966, 0.1483175332748121, 0.09580588328742212, 0.16250664608613138, 0.17851005428500716, 0.09216163367513688, 0.12296717058146193, 0.18272194440566725, 0.22255755119746734, 0.09386033405579867, 0.15806097657449786, 0.22116843460788652, 0.13874190919581922, 0.1060481264346069, 0.05112526067081959, 0.14282641421642997, 0.1300258817331445, 0.17579225012131278, 0.1592305170432214, 0.1526474928663623, 0.15671165059170417, 0.11638607694617203, 0.1610792557438535, 0.11796083962244373, 0.14760412155620514, 0.15866364262277083, 0.16154267765100927, 0.1606133823553401, 0.13302151534345844], [0.006086847222890826, 0.0078406585324105, 0.03673948925889788, 0.04881696880704934, 0.06582512430125667, 0.1388479817298151, 0.01576276561771069, 0.028842214434858293, 0.02654498105027503, 0.04487063923490144, 0.020505810351741892, 0.04395854261313235, 0.016346328305981813, 0.04699349185572036, 0.006954184200073923, 0.04043965945921598, 0.03152508881964511, 0.09942217069047113, 0.04813443809267014, 0.02478896388633838, 0.014726075328766339, 0.03510306416560085, 0.05186448572203518, 0.012759164692984234, 0.07280253054153535, 0.04430790168924197, 0.04356569655600094, 0.0313586600485348, 0.030771809885458603, 0.05746299115520331, 0.01046559895433846, 0.036858650405080094, 0.01098730387316356, 0.05049519548793474, 0.03739745536398503, 0.027774600049240455, 0.030180114216261336, 0.006552228399912917, 0.03012547107984222, 0.08720812447849782, 0.04922659218972249, 0.021520920901469166, 0.0038967110149021596, 0.017227425179894895, 0.053662620484828956, 0.056402928481299075, 0.02202399935002529, 0.10418858589424242, 0.03355873433212119, 0.022818143329312725, 0.04995414589141166, 0.03465033301542844, 0.08422869362778242, 0.08845624258561481, 0.08547560897685828, 0.012320920265459967, 0.015515564366303866, 0.05815207192133512, 0.02696723147716013, 0.058324188895283215, 0.025929260863772324, 0.009448592336998593, 0.0518168656966619, 0.05172097064074009, 0.024931732031907287, 0.05988100979236826, 0.043016790727814364, 0.08727905655940695, 0.07331043151357482, 0.024186244211910714, 0.060991140142563856, 0.04691199159189578, 0.04676085776619373, 0.04180120837484156, 0.0283240536302929, 0.05186037182988179, 0.013587575785124735, 0.042328721197742614, 0.031404133112500274, 0.020443245866185716, 0.06300558749165747, 0.06696656466491761, 0.02753099558063813, 0.01760638972383834, 0.056662383309054765, 0.012414617606648996, 0.07640868260134613, 0.0170904582351326, 0.018276310630983884, 0.029769092723126375, 0.037274080734219284, 0.0427602048993351, 0.04247109863847014, 0.04688969843329922, 0.043527162333409634, 0.03441199157086592, 0.04166477960684607, 0.04522357977205708, 0.0656376012991513, 0.03208386377551623, 0.03370254435726712, 0.042914203893873966, 0.06977974677518492, 0.041920216303438916, 0.08940223093715408, 0.021360170757097584, 0.1004448137997139, 0.05941626638354314, 0.06437746327250235, 0.04226030571566474, 0.09110273928531716, 0.02320188634668387, 0.013955735616506109, 0.06460123755518468, 0.010632557283726432, 0.042445055479484226, 0.030080924982265122, 0.013956645345916192, 0.05254435045043788, 0.03937568973689791, 0.05910362973208389, 0.05347764855551143, 0.06823697593063116, 0.10820441879332067, 0.053099553521362045, 0.07659259732932815, 0.04030690791325704, 0.050806116102443594, 0.015354867848086984, 0.021740613850734888, 0.06873903165180838, 0.03685955438883074, 0.04390939424235014, 0.04862894401735356, 0.03653236972768942, 0.05347753364232279, 0.03159983218797753, 0.017782645487797358, 0.04116121086201841, 0.07810811842641524, 0.09332584217190744, 0.071638643801693, 0.049148305664740266, 0.06794085996525903, 0.04883520169964722, 0.04634126757962569, 0.0579323617350911, 0.03464132765187852, 0.020607906889410752, 0.09244197589014808, 0.07028208594889411, 0.010407744951906705, 0.012675337437089654, 0.0322145258166617, 0.03651043663041727, 0.05739189053495085, 0.062052968649133566, 0.10368171148002149, 0.016153044322685852, 0.02117306144247132, 0.0186911893768176, 0.02588631205951735, 0.042171136911718116, 0.06845801527942381, 0.0684070244671837, 0.05842706684263484, 0.07057304614253583, 0.03486524366082684, 0.03910347571476333, 0.07094750225904488, 0.04395070170322734, 0.06114100609275122, 0.07211970105286568, 0.026973013525768638, 0.028138689080914183, 0.01796914767774363, 0.08855479213619426, 0.04076947563237721, 0.010817714031755684, 0.023335844481123552, 0.0027633610185265785, 0.09378791576431644, 0.026800438814285784, 0.01575751983064918, 0.024205545797162963, 0.06077645932354274, 0.04173756562053196, 0.03133515647101787, 0.04048316942287549, 0.045676801218501026, 0.031595178203837525, 0.06278794957324862, 0.025560692132961367, 0.04897332352195536, 0.04731251001958886, 0.03248125847969805, 0.042041664222075094, 0.010859077034007398, 0.054160581466050885, 0.050624974612747474, 0.06646258606305046, 0.04304676391785184, 0.037950781519494714, 0.053046973076679056, 0.099473690103379, 0.057257966874467756, 0.016321964794769883, 0.030696329157499057, 0.010044824204317505, 0.0014919922626089126, 0.02111457829033175, 0.06628998645371006, 0.013105198947502481, 0.06068484669911766, 0.08022036072948287, 0.04091029408417883, 0.09788650148097547, 0.020980855727928783, 0.0751864199616736, 0.08210922711558881, 0.01738184169235249, 0.045185018736388416, 0.05702427941404524, 0.05238367116919929, 0.003117165798621793, 0.035950173548753225, 0.06587925607398634, 0.06942182283608184, 0.023781117765353094, 0.061932708166780016, 0.050675394689483996, 0.04900701606886522, 0.07578592972769853, 0.004370593852663954, 0.007441836989469707, 0.01550134002876979, 0.013364906584273183, 0.021693041705856883, 0.07041803591193692, 0.018835323074111537, 0.022671117650104627, 0.04643838837622635, 0.020002526974666025, 0.08745865821237526, 0.0277962631005193, 0.06378343486557565, 0.009970328856950567, 0.03157927421852946, 0.013302622678419276, 0.0059186080902544486, 0.02035022363997996, 0.02470243234007109, 0.015888249862097924, 0.006739297494923155, 0.03114340466357047, 0.01451085537536851, 0.027793028294259024, 0.11275633703917266, 0.08132204112987365, 0.03751300823604388, 0.08047151499457898, 0.034285131241044695, 0.03768075084794433, 0.06661322193160173, 0.09358621247473264, 0.012297677157837297, 0.005383286437380218, 0.01953493371876257, 0.017066539054916754, 0.04086920878879967, 0.04483996124397363, 0.037347357044176716, 0.0544904129609706, 0.04797432571649552, 0.01954095708506723, 0.053814462941860965, 0.037260180068833214, 0.07118737204901635, 0.06002735939898318, 0.03555908183296842, 0.045694750658566916, 0.05249949600247126, 0.052799243224604483, 0.07716892527476435, 0.05918627146691565, 0.011332788459596135, 0.027994065087348707, 0.04229140505495091, 0.0263294211453608, 0.04513996127512186, 0.02192145656614054, 0.038907675132636106, 0.047161759237848946, 0.037555392050454696, 0.015893914124688074, 0.05985507388569175, 0.05026548785427886, 0.05870231457294957, 0.02370105774682616, 0.07469600111606621, 0.06478637802384554, 0.03389559085330656, 0.060421120931184104, 0.05368083422522872, 0.03235320305271495, 0.06855656483000325, 0.03258288387329348, 0.0711879006496841, 0.017570703433105544, 0.0976143793893918, 0.05225655036948381, 0.018249972528147123, 0.06987412114657703, 0.026274477319431402, 0.07464231367433265, 0.08818032069792671, 0.062408441106878945, 0.03979595025039969, 0.0320226667569049, 0.04054882315798633, 0.028490614551570148, 0.05195750794824093, 0.032002179650589824, 0.03874503466631136, 0.029928525196268197, 0.09142931490655869, 0.03581538037847608, 0.016614878512618524, 0.029306634171535412, 0.0691608549846757, 0.05880917234706783, 0.06543511659988473, 0.0446968138848822, 0.07705559788812553, 0.09262680226275999, 0.04016330473185067, 0.1290600746870041, 0.01200958883630172, 0.053876217289437214, 0.02359717813951354, 0.05733779323617778, 0.04933754853423565, 0.040341523596115654, 0.039945594035089016, 0.1369143451654142, 0.036188813767606215, 0.07109389400049564, 0.02648562647312159, 0.029760244407600937, 0.109266898474626, 0.014220897799297689, 0.05012471919819232, 0.10928332339972259, 0.19096869704944475, 0.09753973178204992, 0.11638220820215442, 0.11220708264098053, 0.30984548671591666, 0.07630600383685482, 0.10745588960426469, 0.09917760478152383, 0.14837978557953913, 0.13420513650823024, 0.21433995586008797, 0.16121223328575013, 0.12763151223020208, 0.09966655273831661, 0.14032348239373776, 0.11850672323376903, 0.19513361065858797, 0.0895772360625767, 0.20491117551442117, 0.11034284598164021, 0.08121093539821525, 0.17863978361410482, 0.13104631084828608, 0.1808420259265169, 0.10645508000086393, 0.10073470913114087, 0.16100886758537064, 0.227382097152933, 0.1225091725768101, 0.08446587444913965, 0.2847571184317912, 0.07561995677890317, 0.09884946634091678, 0.19404889144484075, 0.16869320444041686, 0.09287983344327058, 0.1447824818352538, 0.16644219297074503, 0.1285588233581474, 0.19973399928740918, 0.150844213823157, 0.14106730780293866, 0.2692268308131926, 0.1936640548369577, 0.1355507699472289, 0.15823091019786176, 0.17748060065411753, 0.1102274424967266, 0.21195910780900912, 0.15815522071094285, 0.127380327321589, 0.16570604376254544, 0.15469926018868724, 0.1583343320676396, 0.11920606957808619, 0.14559110296109032, 0.11104320356201743, 0.11831823496087907, 0.12216322259196352, 0.14188521391441747, 0.11802421807641945, 0.12877392552552686, 0.13231878289051596, 0.10788259291720968, 0.1533416757780698, 0.1363655044547012, 0.20545900498907413, 0.14979957632960814, 0.14002743537627882, 0.11148555805125546, 0.18970186341433756, 0.22346181073977103, 0.151366425317622, 0.12791908631521848, 0.204523780172871, 0.11538083935456893, 0.17802674473533708, 0.15982916879077114, 0.09287367409635937, 0.10280177522931369, 0.1605142352561797, 0.13752635748636338, 0.21914268363147013, 0.16100966431681188, 0.1228174003922651, 0.25673883155949656, 0.15091837113422735, 0.1330039872517509, 0.05420032227712293, 0.11152737879104192, 0.10688474807407587, 0.08155667853932227, 0.10426540919128927, 0.07930402764149251, 0.09402542600348111, 0.1068284482725205, 0.22372053395355904, 0.1416005969287888, 0.17521475772223166, 0.18989441195322623, 0.1724676430345543, 0.15838046588243979, 0.1497783097288301, 0.1727460547079963, 0.2076354454601965, 0.18177810876119524, 0.15983030260089906, 0.1468015984902459, 0.22610515115722535, 0.14445317128012258, 0.14418626624730327, 0.07806511791122538, 0.12215481860743416, 0.1589925241686644, 0.14866693065531794, 0.197482849921911, 0.10099930057842886, 0.09494807165596755, 0.13712200095816968, 0.11839743313049117, 0.21272691177023997, 0.12780526097142889, 0.21213343877705837, 0.17173062048612103, 0.15598873938283614, 0.18969446300498902, 0.11889749702306525, 0.11754240239820174, 0.1755229548941697, 0.16149928643097802, 0.09177929451388699, 0.11458654407291644, 0.1801053711002873, 0.1369729202481047, 0.14217896266810356, 0.1875636660523953, 0.10598760548858874, 0.1289939459773802, 0.21732083461698026, 0.2618421722323664, 0.18283534074021926, 0.15078625161080592, 0.14377230297653906, 0.1225562793232741, 0.1272847348703973, 0.1729606052920703, 0.1755278425351266, 0.12524036029654165, 0.1359566433295127, 0.1474744994794169, 0.10014129742499321, 0.19399535722069203, 0.2139800630750195, 0.11912871001949234, 0.17892096852583272, 0.19903623108421603, 0.2891367205208348, 0.1453606024264328, 0.20639147188874984, 0.19768903482585184, 0.2520241272906142, 0.15437581786705604, 0.18118553975176427, 0.1492926099848363, 0.15012717084778895, 0.15525214584364047, 0.10888082846518486, 0.2705234805903127, 0.16531903146495744, 0.17148954793810847, 0.13430170955196505, 0.1403031197767104, 0.25011698204663496, 0.10487213550556092, 0.26057561438891197], [0.015450965917308726, 0.03432311771077014, 0.050638557351644964, 0.027984592410164977, 0.05040258694920809, 0.009812915025489225, 0.07064672081821388, 0.025241959336844665, 0.0469297839839372, 0.055632339790463455, 0.05492951923740968, 0.09185427919991555, 0.03645316772763768, 0.02165831877068887, 0.013010286399343563, 0.012265434432324144, 0.047361995469057755, 0.027386113032398206, 0.0185155637201763, 0.04934474976072389, 0.013364142411568714, 0.028851667959843914, 0.06714901616496426, 0.022878853882092143, 0.07888994179666042, 0.07764353206561458, 0.018415344097921928, 0.06761101314858084, 0.02167837495254653, 0.04862311791868941, 0.04285893065013713, 0.01687604363166517, 0.02240926305192613, 0.04885514296831624, 0.014410498814897673, 0.020072947691885695, 0.03609129460528493, 0.05390324870184545, 0.08077370603719065, 0.015294312428112234, 0.02511045459898249, 0.06325831606743798, 0.01145892387871901, 0.015677186893299222, 0.01698838084966185, 0.04279136552565521, 0.07831703060336652, 0.05683139762690952, 0.03974950616999019, 0.020560005326725302, 0.014038129330372379, 0.04987297887583414, 0.011187085239667327, 0.02066887599686461, 0.050923327554858504, 0.04971147221963733, 0.05356864830959709, 0.02275691566718442, 0.04752070207389132, 0.03563845620280312, 0.04165258348709153, 0.04642912254278218, 0.0681478875659166, 0.047020017650098576, 0.05130819480625853, 0.012263574753887953, 0.03648062814928351, 0.05917829649162389, 0.03671692796952782, 0.07997210993761979, 0.0741352247554929, 0.07482022993386754, 0.05568412350370519, 0.022174947399405703, 0.05120730102663079, 0.00671296609535573, 0.007405118395258943, 0.024233638241346327, 0.03423690600621124, 0.059965402038107, 0.048644947594091784, 0.013313137235180026, 0.00761384288066878, 0.040905356647506844, 0.05716940327998131, 0.023243528971027945, 0.11644508869897936, 0.025223136556545095, 0.027342484325110435, 0.037801869348773075, 0.025460955146099293, 0.012510666837765565, 0.05203932613855408, 0.0060977309382700875, 0.02032129999039875, 0.021591192231543606, 0.08031807524422485, 0.06202058611257423, 0.020306581526153514, 0.033658030818426804, 0.019548154481115843, 0.021590069912734534, 0.016255818848167698, 0.019303979277009928, 0.018478739788875948, 0.010149254437325703, 0.02463331397232269, 0.05293472970445311, 0.013958745384438625, 0.05645779952887566, 0.05703339202990455, 0.05818401012689837, 0.10542887458277327, 0.05180467340734698, 0.03692130107552775, 0.053940074548365614, 0.016130927364311872, 0.06568984849558723, 0.02759849367242667, 0.02901015814483887, 0.04066803793032323, 0.025390304602502335, 0.01423553486670097, 0.024242285458791642, 0.026403783384950894, 0.046479803089412956, 0.09392824775028615, 0.03532530627243462, 0.02591051086182556, 0.0701619940058839, 0.01638725463811669, 0.035125418611231356, 0.08478295824099934, 0.012513960058230066, 0.07479155526286171, 0.021447929959263534, 0.02566113583593359, 0.011926650242399306, 0.022402921759132898, 0.038429869924701994, 0.008335694494176536, 0.1062100084738866, 0.06351806583904451, 0.009115819064449639, 0.11061971015747517, 0.05006984048973649, 0.037777090234862226, 0.045482594099256306, 0.02462101443069837, 0.07483056445996608, 0.017153601117071607, 0.0699405333087329, 0.026802083988103177, 0.012345065441613477, 0.09273911841333875, 0.059055917776159705, 0.03344728769133649, 0.0419636151843494, 0.029158520647474838, 0.03936669969510648, 0.02713283670375184, 0.06829775734654359, 0.0705036538983545, 0.004293739912100136, 0.026174843754439105, 0.06759340078720162, 0.04362792970852987, 0.015570029387280587, 0.10386883611640624, 0.027011143636979887, 0.042813199031497204, 0.05107701628378803, 0.05408303038547597, 0.02371858775375351, 0.0410471135570157, 0.069091324844668, 0.03483622425025509, 0.06734506572566687, 0.053205763951184294, 0.04580603642088752, 0.07124361056353777, 0.09712295696860361, 0.034787420619038806, 0.06646660802465293, 0.05691560218110681, 0.03404656380054451, 0.08034369322441279, 0.06406683377140472, 0.042597326945753834, 0.03818346923517604, 0.0032536158734376756, 0.049124652700078104, 0.07502825344882666, 0.05936393491743554, 0.020807170188955722, 0.03384159697640327, 0.029830400824486732, 0.06202441655219563, 0.03496244106621992, 0.05399675739388313, 0.015257730772117934, 0.024631245534927137, 0.007233050259416022, 0.03080163177313103, 0.05348929692240012, 0.040490631119257985, 0.018827675601407405, 0.03118634389172639, 0.04972536905458377, 0.02083078676444148, 0.054264700475839846, 0.054560605767032797, 0.013931675667634175, 0.027795849413040186, 0.032062488007209, 0.024122304598530455, 0.005004649396024404, 0.06415437080807264, 0.035022123145960996, 0.04981026691835254, 0.060015622931983204, 0.10676228891937964, 0.0725702143784973, 0.03211953282927073, 0.07506428256390557, 0.08393407153386263, 0.015019131730490876, 0.06270185661231799, 0.035661427349212675, 0.045548458508546316, 0.07411316142327364, 0.04757139028140134, 0.023614960955455903, 0.02611294001971762, 0.024596562819375146, 0.06640422548497878, 0.03433675024538271, 0.03942703294958319, 0.031180316694982113, 0.07384574311154504, 0.06622031075699676, 0.015543961330437133, 0.05397789630918734, 0.027649354249719652, 0.0890298126145236, 0.09290819401822745, 0.056708057471100366, 0.027012786895577467, 0.02329557698460356, 0.06767993807912835, 0.020562523840776375, 0.06128020043815337, 0.08071181379378804, 0.029698752445138754, 0.041457740514869654, 0.03547591149746891, 0.012835733265796257, 0.022921923345195192, 0.02621860652711363, 0.0635768554263538, 0.03444586031799836, 0.07783179051212727, 0.044744387944980014, 0.056746112888739, 0.013247606074137074, 0.03021943367897503, 0.014318468672553859, 0.08728520058455967, 0.023623163841905135, 0.01815532044988246, 0.04004728837659763, 0.02799656253398186, 0.02849995890902656, 0.04826345495999821, 0.027697707804280425, 0.03703536773701349, 0.02207977246613272, 0.07582075608473632, 0.04792830681488399, 0.05663597625830481, 0.02738915823189722, 0.03865550963147994, 0.017992111163273934, 0.08978778766768594, 0.03349133774698262, 0.02370163039754956, 0.05824623561854805, 0.006164551042245642, 0.03297297201389748, 0.043688063780146266, 0.06467428403876482, 0.05004650545156291, 0.07211746407612678, 0.04283179198541949, 0.017768957411810275, 0.013311755404086604, 0.017015188181352232, 0.04436810853921118, 0.06098424152080571, 0.11413288978679527, 0.022865102603851307, 0.027629773042375044, 0.07946947198962012, 0.03204772166246849, 0.021348566440264546, 0.03058529620419347, 0.04674723672290002, 0.019283047839698773, 0.0656200961900815, 0.035980901335396116, 0.058673521158315485, 0.04740066758747544, 0.009041093890705417, 0.040738866589362585, 0.05515747636015858, 0.09257204229793242, 0.006325155151106658, 0.06259747713263478, 0.07572218355151915, 0.01736709258459028, 0.043468878364130374, 0.07358732633292675, 0.012309934564625785, 0.07487120542434916, 0.013107197479374949, 0.08646206975343727, 0.044610567706366705, 0.034226146301314715, 0.044777406334516504, 0.03366889011475348, 0.09313032887275181, 0.03691043794876145, 0.06034264288422081, 0.011686755554570306, 0.05244085197186759, 0.01885614151345386, 0.029431077493955533, 0.028880082160955476, 0.03018878250112457, 0.041229392687279376, 0.034127485667986256, 0.04973482641000902, 0.053466275980275486, 0.04599611432622037, 0.09100329341186632, 0.009889783330201622, 0.048995961420117855, 0.0671658471166607, 0.028873961118440476, 0.03136461446692627, 0.018666080845099305, 0.015219439782442586, 0.1495743158363527, 0.11765792845718323, 0.14261238457214448, 0.20232375951543932, 0.1430335950346724, 0.13084231695580867, 0.08393643874554865, 0.17331659102872496, 0.11446095927948914, 0.11408368395941873, 0.1302943036200539, 0.19874586843915526, 0.07688469899397704, 0.11441472587325882, 0.07332426706148733, 0.12394413186777985, 0.2232776585245325, 0.20623961794039897, 0.13126602486496972, 0.09161371993081224, 0.09096819126317579, 0.12682365719228983, 0.11567688637202787, 0.1679774331710031, 0.14392227234859623, 0.15076691555159707, 0.13582519796346465, 0.12248237482121876, 0.160256783748346, 0.127375278802168, 0.14000909523137156, 0.13692307856775102, 0.08698234304545388, 0.14923389700631942, 0.1337948657812611, 0.11125288182689298, 0.1677111563302817, 0.12858784276871912, 0.10486072079548914, 0.10453222995443691, 0.07310574048108633, 0.1845399936240527, 0.13772022369648182, 0.13805250667275923, 0.101255219910414, 0.25901904630084194, 0.1895232883191878, 0.13104818010282132, 0.11776130436168564, 0.16321088007140547, 0.08832584676002303, 0.18183205667282307, 0.1267558201065948, 0.12828157613835028, 0.1802982873613796, 0.13732935031575544, 0.07525359821175376, 0.1111699298264519, 0.14254395759874774, 0.0995472651876269, 0.20069666537306002, 0.1275768748394424, 0.18377241948919912, 0.1531528197829762, 0.20484880063562624, 0.12372032694158056, 0.13901443731400276, 0.14909186430515783, 0.16265699850215068, 0.218221340328455, 0.16699884777828572, 0.14131432519324366, 0.09601052835463517, 0.16097158974697515, 0.13749566800411672, 0.18459265450796775, 0.1631630455414134, 0.10390529424072274, 0.12075311519325742, 0.12731216081808652, 0.228997286288969, 0.08024462273404484, 0.12135231852411263, 0.17468499260083323, 0.1561482848539468, 0.2748986087258785, 0.2707130107427797, 0.15616578230213735, 0.09129979242120059, 0.09564489757101383, 0.07012979533042639, 0.13260960518833131, 0.15954102780069077, 0.0841822457169333, 0.1404477112115391, 0.16405880150775756, 0.19777034739813498, 0.1594865742710329, 0.09429892705332849, 0.09384785448351214, 0.13259972265410808, 0.1905169962875305, 0.11415137548840816, 0.16803996126738288, 0.2210717696336008, 0.0855960763029514, 0.08008363701763653, 0.14653290081168377, 0.0910563909658982, 0.13038719944175214, 0.13515507021257955, 0.09022809670216615, 0.16808650876966216, 0.1008068056656949, 0.12728443609610682, 0.17009869998981877, 0.1656481734807453, 0.12415576365686233, 0.11561780567130736, 0.12213872310014502, 0.10450209205549572, 0.09968144548756462, 0.21250658488321691, 0.12643727308679975, 0.21981160096343488, 0.13496460543284494, 0.18658799179379018, 0.1365494728088379, 0.11912703994781741, 0.10643580522868903, 0.3018935247054023, 0.15004729852080345, 0.21136099232300637, 0.11356279779706271, 0.18787408487931376, 0.2108094243392829, 0.135537899670101, 0.08826922520153946, 0.12525377449609582, 0.15521137464431026, 0.07109010186527046, 0.18029238848436266, 0.15442708447094888, 0.04341673842000385, 0.22647353219649485, 0.17655738809656712, 0.12022154976523693, 0.21331594145346075, 0.09308634776501887, 0.13488978928615972, 0.12110451206324563, 0.10563476071242364, 0.10072497215362326, 0.15273424466290783, 0.22976394111831344, 0.31365159538484394, 0.12146648860746816, 0.1139701190855234, 0.16143099735340766, 0.09573546448542226, 0.08803970525942503, 0.18902667948315222, 0.1517521812310142, 0.11289604083304444, 0.17091429251576626, 0.18463249108003033, 0.18972852327410253, 0.07184556415004116, 0.23618859959946525, 0.12026785211938044, 0.15110969393243714, 0.1429497696939976, 0.15221495962431356, 0.16568715203433268, 0.1643236687466983, 0.12118746406368672], [0.021545933672196923, 0.018018307539844708, 0.03812709282482824, 0.014595207401491223, 0.06868164400540053, 0.05467807002846272, 0.060745723876020605, 0.035875024153820934, 0.02200826390406057, 0.019837339265993046, 0.04689246018026625, 0.061178938936321973, 0.02963761671356136, 0.035970325491601424, 0.039962164516891205, 0.0801907973964849, 0.06505702156573534, 0.017659334060285362, 0.07409415478187223, 0.050842884492369435, 0.012944263984419167, 0.03704297115966197, 0.005632207556177052, 0.09496773713298383, 0.053740887857613065, 0.0454419837783902, 0.021950012493518092, 0.06680377864188726, 0.03353390925293488, 0.056038749434294245, 0.061898130788317615, 0.011634271828487757, 0.06974754043884816, 0.012342253898931368, 0.02255479485968188, 0.03335554483196428, 0.09226613572888798, 0.03258381083968186, 0.02178322366108337, 0.04729432692270606, 0.020166142287874417, 0.07676256925708826, 0.1333834459224055, 0.06197173651608248, 0.012160048504630405, 0.02499442292197097, 0.11040089246366294, 0.005276182557516281, 0.008332300724671974, 0.06297469499611086, 0.0632631347604817, 0.03909045222005056, 0.05591977597965349, 0.10583549107034361, 0.020249749293490764, 0.05376335721643222, 0.03436668513102397, 0.039890454856738936, 0.0327533767408421, 0.044248874614676165, 0.08246993961473627, 0.04340870215767815, 0.031634555123145544, 0.06668955493237703, 0.03164513096694024, 0.015662492369301617, 0.04025853712171797, 0.07633113152077121, 0.04469219437469879, 0.048082811427452875, 0.0550182935060753, 0.017318273631615505, 0.055668139079165076, 0.04418075024600952, 0.05700818773719573, 0.04535120618980258, 0.05762110787233519, 0.035947614815086126, 0.04040723478782081, 0.021371715702116493, 0.07357728292023943, 0.014869814490779273, 0.0229718761082979, 0.03595119244569252, 0.011701844613848916, 0.08425873193529346, 0.06982444800556668, 0.05930185881293109, 0.01237625000818122, 0.08404858635678407, 0.06130108782540887, 0.09767917510602744, 0.011059014490925738, 0.08879087745181977, 0.06613237918504784, 0.003205545292603934, 0.05549679968446013, 0.032373749530844154, 0.025849530263052835, 0.025466511198770136, 0.019971592344283577, 0.04923919050563728, 0.030364369853369655, 0.021606347365905682, 0.04305595314250358, 0.05990963083721938, 0.060259771323011774, 0.02626466373312137, 0.062038811344292864, 0.01906840149463425, 0.045006573876185764, 0.014168945546712608, 0.06159445736557246, 0.09789832221764712, 0.028724581634085027, 0.029778977172569405, 0.01878286520349643, 0.054215004352191766, 0.02988786124924739, 0.05627737433138875, 0.04398470451574653, 0.03776183359385018, 0.04402715727807053, 0.018967990350398808, 0.014360383258111054, 0.02376277570522601, 0.014090683919587925, 0.06727932006000512, 0.0012402507432383457, 0.034228950183117585, 0.03321986683013459, 0.06089202368692045, 0.060244100994520614, 0.0738546297314667, 0.0316264575737859, 0.02791371778585017, 0.05158520070835949, 0.03664928240581386, 0.07256716534855866, 0.004748221094374575, 0.041650220105845126, 0.03824730351146671, 0.02337028013331996, 0.04879913428017209, 0.023617512028243755, 0.007574415208035781, 0.01820478100149382, 0.02156351155961954, 0.023701059662045974, 0.06766769599409835, 0.028869985122113462, 0.06308491589621672, 0.032758448242900834, 0.025168411065674117, 0.029933161943429903, 0.035778738393057744, 0.08464796588786187, 0.02384691322672992, 0.022023283057816086, 0.06684195280315415, 0.027092965657732664, 0.044732122877312284, 0.049925846603488734, 0.008023658742932904, 0.013571822144571814, 0.045485570350842136, 0.07712991607765998, 0.05337726805479296, 0.025659226361782323, 0.01821246486337435, 0.04211260779430309, 0.05409931358430655, 0.02948758030881084, 0.0437451986175391, 0.010946665781610196, 0.060599703687213125, 0.006186502812910946, 0.004966511623933911, 0.033008146940940813, 0.029380462064798323, 0.05195602939854707, 0.05485343138477015, 0.06780746107500407, 0.02616977225238037, 0.02275616873145825, 0.032389002341416576, 0.045688219759012424, 0.029966486768136104, 0.07027239493665195, 0.12209307192073715, 0.04602328363445498, 0.07199923372677258, 0.014748440308105803, 0.034405230844934145, 0.10519525607026393, 0.02515702316867969, 0.03572283312678337, 0.03354614750752526, 0.038629094919850754, 0.10906708742221517, 0.05116934136998269, 0.03048068306769335, 0.022845149843863422, 0.02534961575762399, 0.06239863901188778, 0.02885387237784603, 0.02820291980770567, 0.06350904898417574, 0.04705480570274015, 0.054206370541285125, 0.04470173983023532, 0.0432406377888495, 0.061322155243326584, 0.05085079051974801, 0.03881363400949105, 0.010746899736864914, 0.036393117925692955, 0.01899550631341915, 0.07827707145723604, 0.025239697462248228, 0.0848517146322035, 0.07819689269508086, 0.04131237916167706, 0.02199250930589774, 0.003899756693206127, 0.04272532108570299, 0.04447683173742506, 0.024312131610068104, 0.020930968082299637, 0.012902669240570357, 0.058368292577084036, 0.05092145063944402, 0.062113497256030964, 0.06424458915247552, 0.05666778805936056, 0.07525876930524265, 0.08523526421237378, 0.046902748741089344, 0.014524382572891492, 0.03806240819094162, 0.011588185894182854, 0.047798654094578764, 0.03602096390339636, 0.05348022261093702, 0.057826181948785825, 0.05744710249165374, 0.06425388945987628, 0.009088175739311885, 0.08169548601032266, 0.018994759377692978, 0.02494474020486157, 0.03632976628479458, 0.037252894572673306, 0.04643145528051161, 0.06426738409866249, 0.04971559377266996, 0.06148289198115949, 0.06355999383114039, 0.003808354503557747, 0.007951997920885802, 0.039892377737428875, 0.09740635587443268, 0.030595866302328727, 0.06161606104503717, 0.03465919282227274, 0.03937091700912964, 0.020757790076576417, 0.0032365134393330668, 0.03898552881794111, 0.039248530632786216, 0.03480844973256031, 0.05937040069951646, 0.004388457107838363, 0.06209562059431788, 0.036629053854173234, 0.05522980655152952, 0.022385451124019684, 0.09303742539017432, 0.008037214189948095, 0.012581942700630715, 0.013548956335251851, 0.02309637114165291, 0.018787496204998706, 0.007781183296408986, 0.005009865975983802, 0.04980108918501966, 0.0642986711294901, 0.06121998975774454, 0.01755264291029063, 0.06692416169830868, 0.021648909295758894, 0.007335513082873678, 0.045660219245379975, 0.04145194889016209, 0.014794171926745725, 0.11757928953175584, 0.03660722417877086, 0.03122824890118453, 0.09723279865518694, 0.014000692528732603, 0.05197639201557444, 0.0424593698323494, 0.06058469602477647, 0.028275776684524554, 0.058869080422746564, 0.02977754650337081, 0.08386226611271982, 0.006121027672047457, 0.03433879953058016, 0.021533067225508636, 0.03968050080021063, 0.022267875779840737, 0.028069281514974374, 0.02409507591848172, 0.011651035747490825, 0.04807354176356908, 0.0953168893653539, 0.008036314036637064, 0.051465039817436095, 0.02741919845462807, 0.059267430821613926, 0.01750047806830656, 0.019482663539688916, 0.05237786422273325, 0.05439989201183762, 0.054988473533622684, 0.06200213488491793, 0.01903956402994452, 0.011158942042158978, 0.03565524501966373, 0.0234683106593307, 0.04226176894360012, 0.0514109923143781, 0.011158281291324285, 0.08476711554272522, 0.07645545226912345, 0.04534395899803889, 0.011563614581621463, 0.07644916268726511, 0.07743567708999881, 0.011208896720481497, 0.017779253633512605, 0.049117244629850315, 0.056230803846471736, 0.04711468696534153, 0.0252072804517323, 0.0404330404595502, 0.09901746176183225, 0.01710573211312294, 0.02471360764766653, 0.022754690181764386, 0.0545208036689268, 0.14830040354882518, 0.1318146970363394, 0.08678655395464552, 0.1215272776842598, 0.18322212321142997, 0.1133681808207785, 0.1443953469635979, 0.14862229837284935, 0.07740135635099105, 0.09156780828151012, 0.07924887697182356, 0.19931740067418546, 0.19459031642444674, 0.3271489308005379, 0.17708877732436504, 0.20802919933151817, 0.12389004606032565, 0.1463747649423538, 0.16382998636653348, 0.1537507360861186, 0.13040314939233566, 0.13428692405502643, 0.09992125399050214, 0.14885076111362827, 0.13229471240793506, 0.11081716931995847, 0.05944628170841645, 0.10129729345921548, 0.10529165291377615, 0.1845006320265032, 0.2561008488579143, 0.11369723090601545, 0.09341261695109068, 0.2181661819979068, 0.20505539922704621, 0.15679388246949644, 0.12146648860746816, 0.2266478938080611, 0.10573827451275242, 0.1058734124225955, 0.1154738117850596, 0.16939215241901337, 0.19807753333401298, 0.11329400052707042, 0.23835949359401581, 0.1510245662422911, 0.28700935564214186, 0.10949885457633965, 0.1533767013179679, 0.13039204111743358, 0.1537829117789384, 0.10616908405697155, 0.08616488126497115, 0.2181721421619577, 0.15716404083275026, 0.20603130331202862, 0.12224842689090198, 0.13781065271506387, 0.1145195650056966, 0.14507443794319708, 0.33443218998370633, 0.1527841169867785, 0.1460919406024679, 0.1321126133083336, 0.11668392427025304, 0.09588128166092981, 0.10711732470700819, 0.11342294844648532, 0.1164865800209584, 0.13785169970604683, 0.20183013842230846, 0.044979753137956706, 0.18455888535226547, 0.08502154866413725, 0.19885514322067463, 0.16515933277626194, 0.2581841636809611, 0.13861870693583644, 0.1151789368821248, 0.16534851052828375, 0.19788447917709429, 0.18584914595609714, 0.11186211324867704, 0.1447924716217864, 0.16218046116973125, 0.2939570070274415, 0.1627857932039807, 0.17444696908275928, 0.08879712872928189, 0.22471657082919153, 0.10611449263148731, 0.19767127690776704, 0.05414322191368669, 0.11703974912844359, 0.1507040810200476, 0.20095577163081016, 0.17014900132292704, 0.18530056571527836, 0.09222920263005842, 0.11757031864216251, 0.10283035030888935, 0.13069236290551003, 0.12888223503626164, 0.11445047919668498, 0.07811110616931993, 0.12864136167110937, 0.3012289893963645, 0.15025383582518947, 0.10680430884202642, 0.09987026317826203, 0.07101422851724971, 0.15558714077116984, 0.1416074763983488, 0.20121650199495977, 0.08524956707392009, 0.06967761193311985, 0.13621826235565448, 0.08617752937660103, 0.13748112765531387, 0.22822819530002533, 0.07564709927406042, 0.16110372459215505, 0.18473222040601317, 0.11380835195943234, 0.12548779137432575, 0.16497395482034455, 0.11521850532341389, 0.14316592906271258, 0.1283263769601622, 0.17941439043610327, 0.1383259540964519, 0.10687475062666402, 0.10249025323578428, 0.18477087720267235, 0.12377441274903475, 0.09522449150080643, 0.12604334301525547, 0.1163673154529064, 0.12761784522163291, 0.12256987738393008, 0.20462275873268806, 0.10894257515188187, 0.26662544137047184, 0.13805215427231404, 0.0979887895406254, 0.08914903887817938, 0.10200147381833485, 0.08943740969463702, 0.1363245187507522, 0.13562791500120394, 0.14158846209606818, 0.20327524071739567, 0.12994024842496843, 0.13497140829361257, 0.10518815443520585, 0.2368509132535227, 0.20868880103432363, 0.11963235154267281, 0.11601594922643517, 0.16110168679827647, 0.19568407547570046, 0.14320044898458067, 0.13470404360803867, 0.13045988586400786, 0.07727024040275043, 0.12054869995242166, 0.11719514240300465, 0.15892852518347003, 0.18401644913659942, 0.0829063875660781, 0.23084810874875517, 0.18907958551520304, 0.06534179176894889, 0.1862929406906328, 0.08587572137795149, 0.1889638755951197], [0.03415890676420062, 0.036001091582640525, 0.08005157623800539, 0.03878680561038275, 0.01015473579642393, 0.02893692971537671, 0.06823185846329698, 0.03444326327993505, 0.04832885205565442, 0.020496850953467434, 0.01575098222782535, 0.042662724041410034, 0.054548857808713956, 0.030729226888187473, 0.02973264800534854, 0.07258456320531907, 0.016434468636890093, 0.03985890735601706, 0.044129671333658124, 0.05361934800842597, 0.02187603521310995, 0.01660751449244638, 0.020643782786904805, 0.025252782243994937, 0.02827464478961643, 0.09473768859020165, 0.0347365370591081, 0.05429548954951668, 0.06209966553855808, 0.03389786613444167, 0.027880362317626996, 0.002583185757224959, 0.038825588811549454, 0.07868993156138929, 0.04579539545961926, 0.051514973428340695, 0.05676729905028498, 0.06945584480079912, 0.025923339004117637, 0.02479096146060094, 0.024073050890658653, 0.036734463722114606, 0.036472909813446384, 0.019267312393734054, 0.04166337383550502, 0.02736642840318382, 0.097281989160805, 0.060529350002686826, 0.07520402466217357, 0.024609450333481355, 0.03586743605293093, 0.08481173250343531, 0.05734079247040134, 0.04095446671389284, 0.10981859669329659, 0.05763414668880644, 0.011929354532772015, 0.02591276890598238, 0.03949513050517248, 0.04391510159738603, 0.11316307610081089, 0.013733409240000672, 0.07736591712361382, 0.11667187370720411, 0.0626752465482681, 0.0382308709254909, 0.030114705629286267, 0.022303089011280287, 0.05867072110695224, 0.03713302096472152, 0.0685039192678467, 0.08233467913082532, 0.028378804019021413, 0.028610421126828562, 0.06737429964085741, 0.0035885306011374683, 0.037618647930362535, 0.04048575113918032, 0.034160255078947356, 0.04456856693591803, 0.011237896978855135, 0.06675284911668108, 0.0470170337376335, 0.05866000736733118, 0.1497442494597166, 0.07930493162524316, 0.04317460484021614, 0.03615279997428579, 0.015972695733991363, 0.05676719945885482, 0.037104461206904346, 0.05348551244805417, 0.024777926474569306, 0.05632761437746306, 0.03357624327163062, 0.02817587881919838, 0.03089048265058908, 0.05848094580634948, 0.033560442708192334, 0.037618893078498306, 0.095243850542653, 0.008349659319426264, 0.07159974951777728, 0.05614558422577478, 0.06771927669404015, 0.03600320981575116, 0.06693020613203127, 0.021872225840906465, 0.021520047561235486, 0.0445239806187249, 0.08347270274234396, 0.06992623044718659, 0.020847746035865238, 0.014169936672964645, 0.014945754871493386, 0.044003163404282064, 0.017646308650352785, 0.037195962748580405, 0.06791840592819838, 0.02601512208310587, 0.040496878566280495, 0.04280105653789736, 0.05010247966575046, 0.023844651352133484, 0.04243248014620716, 0.02423897212851913, 0.04008500671554958, 0.03540257007003792, 0.052753752923660704, 0.04581809081437607, 0.027509135261718786, 0.12176154737150478, 0.009747079344496373, 0.06334452011111764, 0.006445976314059789, 0.03730162542553679, 0.04777670184510851, 0.03410744480788708, 0.03930147879967286, 0.11069413559931902, 0.024151086521845673, 0.018113518862294096, 0.04165940550005725, 0.04308668475958609, 0.030587659585439873, 0.05128268024794037, 0.0470544571327346, 0.07767177006650357, 0.03749937953187093, 0.04503267066132638, 0.10647768725550945, 0.013007639565565174, 0.029439690237444256, 0.04479118825627431, 0.03917582122789275, 0.01268142017520844, 0.04569705275277938, 0.0372667454423443, 0.022210264052715034, 0.031055879118221424, 0.016357854098802613, 0.03847680813182266, 0.013146343614695775, 0.03891583013859007, 0.03460795686189686, 0.038231319086926605, 0.020913803882356134, 0.026668167988499327, 0.08088751605922177, 0.04542170160059487, 0.05053968221369771, 0.05064138804652518, 0.009940340345154607, 0.01901988897682919, 0.05241891887459544, 0.06710617652823848, 0.03403755460655497, 0.03953778628079642, 0.0464724907801757, 0.08633244767664902, 0.028936353234213688, 0.054544322568202214, 0.010943425229690489, 0.014440000860861715, 0.08345236310795431, 0.08152463308144962, 0.045903482804856, 0.049502410655540806, 0.013038323302152417, 0.03440804238761625, 0.0696333090684587, 0.06887589325948108, 0.058877112854632645, 0.05975489256783359, 0.02346999605276412, 0.027660857059902726, 0.01606518169865012, 0.08261057037499644, 0.054498644575716994, 0.03389338452008463, 0.02771430126872034, 0.09419022683775234, 0.011521849383209503, 0.029573657947982994, 0.05851599049844569, 0.01119539920886558, 0.03165500584028421, 0.007091538019237981, 0.07986837397179297, 0.005919784035218219, 0.06787582676136686, 0.054030269910130775, 0.04774164183125381, 0.07439885859287555, 0.02550886053922436, 0.03386012864329162, 0.019218265529601805, 0.023686230115051714, 0.03545802717487659, 0.03117798395725268, 0.07560668813605463, 0.02619807920118253, 0.08646641347196796, 0.05233745308472745, 0.043636548197678024, 0.05410701276794557, 0.013815436189273193, 0.020734728914835764, 0.05154231510635826, 0.030182707423885024, 0.07483352922023305, 0.011421256293092045, 0.07181371787502881, 0.024056641287320567, 0.08581968970716962, 0.0670634211611844, 0.04318323865112278, 0.0327773591233117, 0.05102241719742456, 0.08092898439856307, 0.035317438549452254, 0.06698126589218456, 0.021351107936953346, 0.031958778854459524, 0.04716709120980194, 0.08496170187549246, 0.019623062558351986, 0.04280678304513136, 0.023876579981597684, 0.07131376889564338, 0.024207987702421607, 0.0041551957838237286, 0.03259032641747787, 0.02924256432320803, 0.06506344138254082, 0.0654841309052802, 0.04792295186029327, 0.02212716649556833, 0.10186471946297154, 0.03245161470746802, 0.014285141932627848, 0.06730108461793392, 0.060228717949001066, 0.061710542668738676, 0.019620572772598075, 0.007819110873125253, 0.011358353771239279, 0.037744014388731414, 0.01618865975028565, 0.07802368787628028, 0.02792884993757452, 0.034713094768625115, 0.01760175106145682, 0.012552865833464651, 0.024023856554600983, 0.015490864734015158, 0.04009885375478095, 0.03494451077835214, 0.035191872908223065, 0.04315500448067342, 0.03052723823085187, 0.023982813394057657, 0.07872702553868294, 0.022381973084843448, 0.03360992432722161, 0.032731949261599974, 0.02068008960885627, 0.051767307468840194, 0.012233569005113697, 0.03747953019375282, 0.05354523666263108, 0.011458531258657817, 0.09926528354445774, 0.045927300478421876, 0.023032370241238706, 0.043753625584706184, 0.06339803518306825, 0.03814706090657461, 0.01776195153774273, 0.015170493467350402, 0.05954282793907389, 0.03531202230782759, 0.0158782045341908, 0.03413174894728488, 0.10626302175824681, 0.05693191985389399, 0.028095885833364823, 0.07768180581831163, 0.03324594063263747, 0.06402411287830723, 0.05190340298858862, 0.036797118223001885, 0.011706948674644434, 0.021968419671118743, 0.014192104384663605, 0.061034810984687465, 0.04482950797424682, 0.013414374796763785, 0.04784807442657409, 0.010626564560938748, 0.040412049650424914, 0.03348428973807924, 0.042662919393830726, 0.127348933038452, 0.01768777124403465, 0.05233408995873986, 0.023582411794773033, 0.0068846837459732935, 0.03245571327786292, 0.05022443320241667, 0.00807519874445373, 0.009949830259316632, 0.008939117054274727, 0.006023723014344972, 0.06292205326439393, 0.01915957361850287, 0.003586016875135923, 0.03156899523380543, 0.043518057378429564, 0.04808219472667383, 0.0671787863417018, 0.04311771515095907, 0.04164823976856086, 0.02957585278988606, 0.02170382822383075, 0.06276264568910965, 0.0783203554249579, 0.006801787286906714, 0.011783192617698543, 0.02879865850592333, 0.06335577777316494, 0.017097663292060458, 0.1072842016395542, 0.11018388273735201, 0.14078845179850055, 0.26894089615633415, 0.0974124079690345, 0.12699456374731757, 0.10202094011249081, 0.07516322281932639, 0.1473214810774211, 0.14207763987923824, 0.1543031467665588, 0.24534417766957517, 0.17196026300230335, 0.1433473386831822, 0.14956812584592452, 0.1706506050522289, 0.13262442132878688, 0.11680319649918426, 0.0983444994856273, 0.11936801290439984, 0.06837880944893246, 0.19573465260046144, 0.17969928321338471, 0.14723126656345784, 0.08750230224142153, 0.1469207251624715, 0.14982496448341878, 0.1305786601357883, 0.19854306964383972, 0.158992983821419, 0.24720774783242136, 0.08755089519845863, 0.18448051455761158, 0.19314665437465717, 0.1941690293531264, 0.13555026432919887, 0.2585051238777176, 0.1317230116335615, 0.2511046379203758, 0.14449142971106116, 0.1089490409339628, 0.15325467883338853, 0.08859223085305384, 0.15151850909235018, 0.12657930578796134, 0.09957127438317384, 0.14787551586426076, 0.11583821682800209, 0.11444635764365235, 0.155100399147599, 0.12248364652717307, 0.24486456066370013, 0.10125590172866661, 0.1061771662845727, 0.20692097654025401, 0.20925031283930426, 0.12344176971143293, 0.09302899076212799, 0.09972606244827471, 0.16364977184322574, 0.1530976461306695, 0.0901280073148589, 0.23014284820566255, 0.2287381340659434, 0.1842771335354736, 0.13421031526259838, 0.11067946501556905, 0.1153673408853431, 0.24171449904960973, 0.16151670727037615, 0.08704188339892896, 0.18049169391874345, 0.07164664175962249, 0.21086764702152824, 0.11930212934291172, 0.13936826268271094, 0.11073396451050237, 0.09069143433965023, 0.10937353791368586, 0.11367921251803638, 0.09032409517995774, 0.16459837255458679, 0.1551266759634018, 0.13079518722670694, 0.20658697752702623, 0.1801416836678982, 0.16072294825027067, 0.1447321192151116, 0.08347630335558807, 0.13844218495632374, 0.2330824807887116, 0.14030080619117907, 0.11798382992105139, 0.21667914404984445, 0.12667816943458973, 0.17064536501082683, 0.10409123910170409, 0.180336193391873, 0.09962738266274815, 0.13642850752559402, 0.14497086285583435, 0.11809014760318304, 0.1395906120418541, 0.13755960570227715, 0.1529299494840445, 0.20537200804439285, 0.1716297267064933, 0.1029531158987553, 0.08647507792639156, 0.08762477671787625, 0.15766890809660958, 0.138404616004517, 0.12038033680930255, 0.2194247725269487, 0.1534365481066127, 0.10928141584079112, 0.13758828803416223, 0.11983413144104904, 0.13663908977422023, 0.08716950598623484, 0.09640133278744836, 0.1238182176565451, 0.11081827248656943, 0.12894163749391033, 0.09804358780984918, 0.11312183758784687, 0.1692210390202461, 0.12428627439564276, 0.20767549653687786, 0.15972770810607942, 0.15796572120199281, 0.30938592589189934, 0.12563175461705656, 0.11482738679455173, 0.09719693807945137, 0.12941155582666397, 0.1986437182753317, 0.1427069198220007, 0.12173896309949699, 0.18494790480021508, 0.07800825886548528, 0.08658295842788874, 0.12211420828656805, 0.17004280621486326, 0.09055880153731954, 0.11131532565360108, 0.13419908441362843, 0.2091903281548331, 0.0786985270678997, 0.33775560197330295, 0.1343734153816777, 0.08121769995458665, 0.11103616321399329, 0.19723400924234621, 0.13931095930597476, 0.04552128920031171, 0.12492410387964019, 0.17090831702995687, 0.19691410624692518, 0.10284069249586714, 0.16859511454259196, 0.1679658345998295, 0.12713959951314235, 0.15557960246599492, 0.10303229108572969, 0.11156840279938714, 0.10282448207538936, 0.11059904110527809, 0.14995878472203208, 0.12656602182335433, 0.15341025596905142, 0.15928777445468212, 0.1815206878968785, 0.18536683232072862, 0.12079243848641073, 0.13140294009879713], [0.01697933909693553, 0.018523908332891522, 0.01750667380439418, 0.03127457232274596, 0.06684159274182974, 0.060142636479389285, 0.03601262503634057, 0.022765101316655358, 0.03322131473631148, 0.05607998028637902, 0.03732203783827924, 0.030826083384454254, 0.04146201528548714, 0.04983547887194061, 0.05410102579081732, 0.02886820971334894, 0.06911344180304198, 0.051939466577624126, 0.015359824436957078, 0.011948738472476121, 0.04157886667657764, 0.03463177070502312, 0.013071733354140195, 0.06800865108567862, 0.03183959472563959, 0.001280921632930967, 0.03664975354988729, 0.025073341469490723, 0.04945833761725695, 0.09543077599617744, 0.03541488876386035, 0.033310521844654314, 0.010404510145646431, 0.022512656193406835, 0.0432176589815607, 0.021282857163779197, 0.01828178624442268, 0.09643540837832036, 0.03878696265840723, 0.033550832135182236, 0.021544790285969936, 0.047489897678456, 0.015169419986646504, 0.0338577997360018, 0.024588036260777907, 0.03577549784113804, 0.06195910755665072, 0.020089140875385176, 0.02258347144590751, 0.047785615278107506, 0.01817593970636447, 0.04923376277269376, 0.078638052087157, 0.025431795924481367, 0.10105585318899925, 0.00592152018197662, 0.016269966576909347, 0.03312988980342785, 0.07142246145034029, 0.028554709297755075, 0.04570243069000783, 0.03188348773326124, 0.06271867607269557, 0.027469411687625032, 0.0423684505174958, 0.14482777295333726, 0.02730278756409403, 0.05059483671380628, 0.0457894774304042, 0.016675713554685636, 0.05420268948880896, 0.010639592843701043, 0.03948346298608569, 0.03638248079486432, 0.024060900736179565, 0.03722862873767172, 0.051986987011567246, 0.06249525036001879, 0.01806978098747711, 0.027454388703429894, 0.047381159158483635, 0.01954817171809414, 0.018685037690785625, 0.059130994392739195, 0.02270060054387056, 0.019626584647583867, 0.030230892439102455, 0.048988495893295736, 0.01347013833677216, 0.009003224249388422, 0.03204978818464423, 0.04592334363429297, 0.025364110141151378, 0.061477031408538746, 0.0198130083135179, 0.04755722531568139, 0.05915917876747347, 0.037162147627602664, 0.07891798061468909, 0.03540125239880816, 0.0035256797902195928, 0.03933198059037809, 0.017955047829497247, 0.08367071348813274, 0.01739755224045967, 0.036368591620797114, 0.09056402625696314, 0.014876195045578626, 0.028667678538289283, 0.044215339115790786, 0.016229323697306456, 0.021038463624614864, 0.02478233148013392, 0.016033613130510334, 0.024196645770702633, 0.03015414192040842, 0.06462623500415395, 0.03093980913681369, 0.07808810054895379, 0.05987062547055464, 0.02226578052936783, 0.008859919842272516, 0.05255674958349236, 0.016149097054655996, 0.02156760821479463, 0.018566910763301196, 0.0646417253019829, 0.022854651249344313, 0.0582780129456472, 0.059495296013811906, 0.03603982498809215, 0.040362093056882584, 0.03257028938781831, 0.025039689142196894, 0.07116090371123246, 0.0796132896756453, 0.07893902504996908, 0.014079179194185042, 0.022139029367075815, 0.012578865900004824, 0.03500346507456514, 0.02531312698979051, 0.020090021876498096, 0.019463373445755532, 0.07479902462012346, 0.11361820127574668, 0.10417030703636909, 0.049783810071887515, 0.02503834274266997, 0.11638953200271053, 0.08726280783453295, 0.01726370901920863, 0.060474865829512, 0.015004780030839387, 0.028670637552896817, 0.060215690623848676, 0.054426348858302644, 0.04012258332823554, 0.010764100325984821, 0.05853193661858959, 0.10873046838828634, 0.07111331432937615, 0.003952910506819946, 0.03206998992320751, 0.10762692639423956, 0.04759716914005337, 0.034750073832730134, 0.03055597418889163, 0.08054180356163172, 0.043014032811286955, 0.055700084945607575, 0.0320585503152782, 0.007684235348396244, 0.057340133634786454, 0.045607148504425446, 0.06891022932024733, 0.06114845246737523, 0.03694979188543174, 0.06977015535437292, 0.012248483779389533, 0.029165606960774432, 0.05145063353402, 0.05240588771900343, 0.06867352347340315, 0.01354508854884414, 0.04577612068744437, 0.043673316587603865, 0.029478678367130702, 0.03534510964527726, 0.05673576687132159, 0.06594007579429496, 0.022347786411222433, 0.03754811421517403, 0.022422366985870947, 0.00778473315632812, 0.012955945867654538, 0.029422008928151864, 0.017616697436859532, 0.018526534099251996, 0.07324729054685562, 0.06073011100412377, 0.0323133013631788, 0.04768408564550262, 0.056179357211916685, 0.09437595719411489, 0.11800956281442797, 0.018273301820661274, 0.03596822258024927, 0.056518217053024046, 0.03700106998064345, 0.03036105460787733, 0.019010236268983256, 0.01237757821311994, 0.01813328393074053, 0.03660093459691252, 0.04642847902892579, 0.05488178429884776, 0.09326272418782597, 0.007891281143642001, 0.07205238490695916, 0.026973879205123074, 0.03748657437221658, 0.047867617329522494, 0.03791107518237926, 0.032520949495055025, 0.026766223412367608, 0.06629855897758277, 0.07095261972637908, 0.03341047716657481, 0.052664603271912185, 0.07301452239194224, 0.003960242447060263, 0.036418276253126325, 0.027331979344448736, 0.05737461908269794, 0.01712918589492479, 0.05058210050206512, 0.005317669091445785, 0.058185745316046866, 0.025927382033138026, 0.09266274710816723, 0.11170380884000372, 0.014257907506919677, 0.06769837015458653, 0.06365394685417414, 0.04017943088265677, 0.012102217484836378, 0.015459067297107993, 0.002449021976058101, 0.0274510964405753, 0.025445166073979873, 0.025513596877816225, 0.06813933802468163, 0.05048658849010545, 0.019293282774367163, 0.02595787807818382, 0.02438665664334211, 0.04132954719206018, 0.018214288152634137, 0.045181954384691296, 0.08904325745759473, 0.010002998676481507, 0.05473930726669008, 0.045053435474514, 0.0192447702565621, 0.02410275786514244, 0.08178097376179311, 0.03205895251143844, 0.07479233667254448, 0.06307772616104734, 0.03772748221132544, 0.023784768174312288, 0.06345320500493531, 0.015542615888520114, 0.07616476020625523, 0.02189923235545716, 0.005258837848105618, 0.06325000018301992, 0.02581133311914821, 0.0733769509280401, 0.03371190595170183, 0.028166063317668535, 0.0593012880774275, 0.02705581422384468, 0.05419238943666701, 0.013060623164018317, 0.02707651200433893, 0.05876831304762633, 0.03167212790539188, 0.031101763954446204, 0.04288171793544485, 0.01814057134212025, 0.10252172412771372, 0.05391898414781017, 0.03339135178154515, 0.03472559349310975, 0.03263464460389749, 0.04583250092823179, 0.07592309777054095, 0.05064208135609666, 0.18300103023648265, 0.055602362769986355, 0.05889931025223867, 0.0459896945094149, 0.07983182391692555, 0.028352251411565853, 0.005368152370436057, 0.021870130590433558, 0.03676765065099444, 0.05619171421013533, 0.04133998130958888, 0.09462042351163204, 0.03757429143954669, 0.025809640064835552, 0.015338666046098357, 0.04724574928742744, 0.03709552479126761, 0.027909711146006183, 0.05923967162567762, 0.030168168990301992, 0.03991213514499607, 0.04097140108745906, 0.0382632649533691, 0.02463002553990772, 0.015421593148681908, 0.05664202452246701, 0.041836333506169825, 0.009351969497548717, 0.08598747062346629, 0.046707855973152385, 0.04000485859691136, 0.015474814234391577, 0.017615054178261952, 0.007884016714900011, 0.09945070746565059, 0.06756199884318537, 0.08021705122964998, 0.029082091885708997, 0.08451696485280992, 0.07085724177980615, 0.11427000420348299, 0.05768699909470255, 0.03952518796488162, 0.05629923081986847, 0.03139409161503277, 0.0684172440800936, 0.06646583427584941, 0.05078553898079742, 0.05823934848810877, 0.02583635355075521, 0.01837241061542544, 0.020943692802721937, 0.10255786049510203, 0.1269228196132087, 0.13302701585475477, 0.12281387638781341, 0.14032515246541272, 0.19027059176756492, 0.21197697297940332, 0.1457246167645339, 0.1678918151845855, 0.1313583691033625, 0.09998327646885188, 0.16417604360368945, 0.2538184124615885, 0.1261463971628297, 0.1391477978998615, 0.06945468034715423, 0.17109944064530636, 0.13769774667678342, 0.11322241727142565, 0.0803424061967, 0.09431129937330562, 0.1901154742846566, 0.13975677651263055, 0.15838173758839408, 0.1226322905671212, 0.12182366944128468, 0.11718808673322202, 0.13448279741550648, 0.27801916063312565, 0.2825829915462002, 0.07320997440406392, 0.08414899750101952, 0.15238573594439417, 0.13639806319148312, 0.11967392713432351, 0.08047194400381658, 0.10014679793628956, 0.113576595040579, 0.16583473121206607, 0.13268547853635204, 0.07799549584066676, 0.15079994926289206, 0.1439241109596145, 0.11656585479936293, 0.10678571588810414, 0.1641351191867744, 0.13376063697280424, 0.20248183409773535, 0.09352515526716748, 0.16683464449259544, 0.21042065003946905, 0.1241495123794002, 0.17599402235880976, 0.13700822157965553, 0.2842972205290871, 0.16410620702851206, 0.09156226946581757, 0.09759531146095646, 0.1979098979744219, 0.13266122419266932, 0.10707486811424456, 0.06822611280386487, 0.3388719759400814, 0.14873950982526427, 0.15972490422427654, 0.3217804624188331, 0.12453944347197972, 0.15756053729884087, 0.1673949458786557, 0.12098216782173804, 0.07146807432535195, 0.0657039828177902, 0.12991296037310554, 0.1541113489938359, 0.0962334446188423, 0.16408360743474576, 0.22888710752369898, 0.1946433603523239, 0.1782768264773392, 0.08533533061704329, 0.12608689511375082, 0.1489459398773409, 0.13700265978132525, 0.1854945238559477, 0.13263056535393963, 0.09843782431656316, 0.10526025863063913, 0.14598075060113785, 0.16129394422375387, 0.07105044149343046, 0.1830497074631914, 0.1526029831579616, 0.10853195202446754, 0.1795071177184582, 0.09415112571009705, 0.1493478296024184, 0.22314929283194004, 0.09554203494542068, 0.2167284801121681, 0.08025071313304287, 0.08665372963033377, 0.1765009887035816, 0.14177889623228582, 0.20193002096587614, 0.2034029935396487, 0.13168962552182137, 0.14203034161079314, 0.11067312180755601, 0.13098087161779404, 0.14505081179161228, 0.07348802601618153, 0.21167381666600707, 0.13467493226691601, 0.11524933270148693, 0.1525574468917424, 0.1455701581172405, 0.2086508490385548, 0.20114741618594817, 0.22377702527709548, 0.25576996016165904, 0.0969914656372801, 0.1284774111944341, 0.20555701827810657, 0.10895448781910444, 0.21073860717156243, 0.1503524160192859, 0.10047593229119817, 0.17346361862315288, 0.11917030859378078, 0.17240752045425678, 0.070494866869863, 0.09501126624884144, 0.07524174683156513, 0.1572858181691939, 0.1251536008391169, 0.2729236340570835, 0.13460322643720335, 0.11498907731185037, 0.16546748398292452, 0.16186495551899557, 0.2312526644598092, 0.1249913817211505, 0.10473617788163886, 0.11391108435007835, 0.13190771543210553, 0.18439667389517833, 0.19800913700413322, 0.14326107718290823, 0.0836016046964834, 0.1778814178561011, 0.17749877225968147, 0.17296599855105724, 0.17085098300970372, 0.15815819313208904, 0.09498742559263784, 0.11491139599632834, 0.11995920295556707, 0.11405333155585874, 0.2819331651253085, 0.10291946165624166, 0.19810384079333276, 0.2355443962639378, 0.1831674704989118, 0.1663505688550011, 0.19327624580792843, 0.1254147065863494, 0.11904532900981366, 0.12451227033330549, 0.09720961683459821, 0.13446782805746602, 0.18137764395965686, 0.14014216470381907, 0.1267383533019212, 0.2293473578268482, 0.15144301878829158, 0.14858065383328548], [0.02741365772371571, 0.014841898246818494, 0.041866570996541175, 0.006719359099083851, 0.035100371366547006, 0.03553607238216266, 0.08225945695754021, 0.023193733255949714, 0.020809550807180426, 0.018444348186735186, 0.050076543759073944, 0.02633691540048007, 0.024260451318696145, 0.08075887457497659, 0.04367715085766489, 0.01915998156032255, 0.0626032610964631, 0.05856971241413586, 0.010962522844032896, 0.023047523460380977, 0.00783082914553703, 0.019299413392981215, 0.0392457535640607, 0.04649757249881664, 0.035190187514789646, 0.08700373222029979, 0.04000495052746227, 0.019804546872394222, 0.013077189815380882, 0.01807305984379303, 0.08637491193029188, 0.05763831803755415, 0.020014838007609212, 0.05497400979361227, 0.05034475880224378, 0.08431709251336514, 0.008693834853118226, 0.024270864368806926, 0.015905104754042002, 0.11260262149716578, 0.014372877194546165, 0.03515054629514775, 0.012387499051739373, 0.05634587025269867, 0.021917903833391688, 0.055143671455763044, 0.011151503328414214, 0.0979634473520902, 0.021958851232944478, 0.020110800096224395, 0.04725885322137226, 0.015840648031312854, 0.05651347879921237, 0.04178405949665655, 0.02304791416522236, 0.03207937833071957, 0.043611010656722134, 0.026082170098238898, 0.0592257441472142, 0.020189774185118657, 0.06208067804935479, 0.0523990274016415, 0.05007747838634157, 0.023321620143589475, 0.021395772778158708, 0.04106680201666971, 0.03477185371241743, 0.0045432470881590446, 0.06649529035653799, 0.02910930715921906, 0.1232732073854535, 0.04710147960952694, 0.017335964517006953, 0.028224261102056312, 0.11641756315985996, 0.08449925290000054, 0.04707070968804821, 0.06155811798488421, 0.03288464973710718, 0.03230804216957862, 0.03357921569277683, 0.06499145976117542, 0.03770092960386988, 0.04151992770212312, 0.00675779325144005, 0.03624274635747556, 0.05731429348910048, 0.030260630057103215, 0.04731113489176478, 0.05604041950596918, 0.03568667760719696, 0.03322005835211566, 0.025876004346496156, 0.04303336504005617, 0.029707888043635798, 0.04707262490785891, 0.018971686724633462, 0.02799495374934087, 0.01928118624604277, 0.09040271878362664, 0.0069637899850344956, 0.012240904296988682, 0.046251302044237816, 0.024362363995263175, 0.03335960892840259, 0.027094233533247348, 0.009537168380413807, 0.04591522693273522, 0.021138600892417377, 0.003071138996728546, 0.030057323728537852, 0.013642420019623975, 0.012587271799753993, 0.033015440097979964, 0.06852051273228661, 0.025029205228953112, 0.04071159002881858, 0.03715886494084712, 0.010101665055469401, 0.024372349951356172, 0.009202341034617877, 0.04571070827002968, 0.014452472772269, 0.06068039572827759, 0.045990667441078735, 0.015075557936553755, 0.04201731028696222, 0.02012474481166611, 0.0729608579328464, 0.023917263080816598, 0.04801726494465144, 0.04645584368958108, 0.009701648415366729, 0.04994949573771127, 0.027841977482180924, 0.07012193526832328, 0.03321679864799784, 0.06308313091135313, 0.15813318802224052, 0.0466098886493954, 0.061128070698149746, 0.02477326482955006, 0.035726897223221685, 0.01707406778399262, 0.03013281786303607, 0.02473733913634093, 0.053427010143716494, 0.026901342170012575, 0.02141965173875853, 0.05076369398363656, 0.032138503081495726, 0.06089936280923505, 0.04094469143197902, 0.012112328887826974, 0.0217513180142569, 0.06589332910915537, 0.017108694958170096, 0.012140441441818351, 0.02869662325528841, 0.04202114838746287, 0.09929179784751709, 0.007586696076266949, 0.00856831134672487, 0.0642472321558143, 0.009495746963957866, 0.02101460764665277, 0.013984329848279877, 0.05212433891551149, 0.10512422439792465, 0.022365088506992307, 0.025386568008651657, 0.04024950111465108, 0.05307292430511406, 0.015718426363873148, 0.043412854354227745, 0.048618165160258936, 0.042791039938287395, 0.0012610915667122051, 0.10875384173085613, 0.03844989163260307, 0.019552772076079444, 0.0909075400822105, 0.06283908594219435, 0.024784468865442662, 0.07127531894272374, 0.005190207382603999, 0.044769393054828535, 0.06812234619452108, 0.04119260897559505, 0.04447418490364667, 0.04875311920900018, 0.07280573278905884, 0.04041979096889977, 0.010091857214818799, 0.0725266163147265, 0.016743673214448557, 0.008747826814801704, 0.1096407723643126, 0.037778668375986243, 0.06391902859773367, 0.059046138663806265, 0.05201470024222809, 0.0325574191106904, 0.02570163507405068, 0.02869009427095373, 0.03657598694365832, 0.028007718689379194, 0.07563566158135092, 0.045473282300536676, 0.031175386919189366, 0.04023843114414523, 0.0808730446583321, 0.024928725136804487, 0.05453725157666111, 0.0325564346877077, 0.05205402736582103, 0.0336931444584362, 0.043330407971816684, 0.040695318321306864, 0.005591409543769495, 0.014101581520310814, 0.13123999319730267, 0.009442243383326119, 0.04121532348254996, 0.03061331970046365, 0.02566921614831494, 0.03273280344963555, 0.04031242374631186, 0.016101469368403478, 0.011883980102626788, 0.030302558049199083, 0.053809138630787214, 0.05019760863374799, 0.050080810868812185, 0.062014162465329134, 0.05501427154447283, 0.03955980747817986, 0.03555914695044199, 0.0699799791759541, 0.037848393868414626, 0.05558814417811171, 0.021698352610391956, 0.04840883929582854, 0.03211177427381758, 0.04015340687586896, 0.014529014532003674, 0.05340122745462483, 0.04488305752015403, 0.03984731261528308, 0.016854093297414722, 0.027158257416299274, 0.03531040586230736, 0.09213605399934516, 0.03613668531479855, 0.020789906397582065, 0.080452868414502, 0.03749208254439216, 0.03695551839266573, 0.034932555976293744, 0.024464159843421752, 0.024461068678647283, 0.009683015241828418, 0.04264547174135524, 0.053585774205144376, 0.0711806151535242, 0.0023839906873857424, 0.06455799189185904, 0.023964908004047412, 0.013328070204044062, 0.0498287832634824, 0.017129800680484024, 0.022242008821077408, 0.01427893183239165, 0.026211148661170757, 0.075200378083654, 0.07557373869443133, 0.02274557565068526, 0.03154082809604945, 0.038582421013063965, 0.028170650269115166, 0.10694507749811297, 0.011806305490374085, 0.010126336917070853, 0.012661032660323526, 0.036705455802861726, 0.023641664865276506, 0.053253334180842486, 0.044398005120456226, 0.036603539295855074, 0.01970327004880434, 0.04465900744581896, 0.02530509264268462, 0.03881230867738205, 0.04174785801179467, 0.010532171994958435, 0.059494411182259364, 0.0993633198161279, 0.01757574620686712, 0.025810507659409797, 0.03709268260506853, 0.04227954601388305, 0.05640293997261794, 0.04535551543437666, 0.03849636635652954, 0.04309466356531747, 0.017514089535501216, 0.0384778538418393, 0.037691598652952144, 0.04554715232863542, 0.07509975243479976, 0.033385299686943336, 0.011709939290378845, 0.10375448217194888, 0.012427037807121392, 0.02567932276325601, 0.023711313748912468, 0.011987481454026797, 0.040396241426107385, 0.010472163370239639, 0.026596375973895196, 0.030559854424228112, 0.05732684967017943, 0.028796030824343045, 0.09399504295640415, 0.0492395160930051, 0.0162590402478893, 0.04721532793595426, 0.04224112287404076, 0.029005146014594266, 0.05192664609621129, 0.06548187094590356, 0.13210901269508948, 0.021173082509889238, 0.018468020303595453, 0.031436936997417966, 0.08172665812796162, 0.02203233247142165, 0.017238675181062955, 0.08240319037389371, 0.04274229376366542, 0.053784888117544116, 0.0541593135905362, 0.015461989922539122, 0.014056306681595744, 0.03837563856054218, 0.01813999869139685, 0.03153470896875426, 0.012160611579254752, 0.08912149801730149, 0.0710319098265421, 0.02007341692073932, 0.08297827725689258, 0.12392435147757493, 0.14679548510861012, 0.2066262012287494, 0.22138136108556103, 0.09709304889603969, 0.1736893081256459, 0.1800058256354063, 0.09831030898156667, 0.2010930852303582, 0.12209936916347473, 0.10463944395943996, 0.1534904194094481, 0.11002819834937973, 0.23828692974582796, 0.14408779330551624, 0.13135089208522152, 0.2633249813750867, 0.19754831979592002, 0.19018641402644498, 0.0699772595638229, 0.19184697088935684, 0.15882004713339193, 0.12526398644812647, 0.15938108396385947, 0.14757571501597283, 0.15556539919587875, 0.18131310871291548, 0.13544678117238707, 0.06538738932220206, 0.1533572273629327, 0.1056670743010698, 0.26222359208810714, 0.23940658256892236, 0.14388828868827513, 0.10468707164569248, 0.142151368181071, 0.06781948865541527, 0.17437175457035342, 0.10704116790645546, 0.20581866794776535, 0.1691615139885295, 0.16391039495506596, 0.09986500781510146, 0.2816011426189254, 0.0795965736371375, 0.27341009988900156, 0.08192034813785747, 0.22940774087704, 0.11091647729758294, 0.14290541320318176, 0.0815012367562421, 0.08321869096929028, 0.10989513653781145, 0.1334081292753258, 0.1054259098225063, 0.0756688944755062, 0.17634110615378426, 0.1765518875852708, 0.11087383684371749, 0.11938585509215632, 0.1331445337423394, 0.17498255647238226, 0.14089585732548468, 0.12722042178915394, 0.13702578031488005, 0.0725349743339804, 0.15678429104868444, 0.11834628143978697, 0.15592037369647335, 0.0869169497802373, 0.24933901975952813, 0.23717499908901032, 0.13439088218635128, 0.11073090781968449, 0.1879482421903841, 0.1496007152262234, 0.18375599456410255, 0.15204298820707107, 0.13943209312856197, 0.151683708292342, 0.16390187605734796, 0.19663950969134608, 0.08463075189220329, 0.1503848675037584, 0.15487740627459942, 0.15709570578990445, 0.11663369188505797, 0.11021074944085653, 0.16950086029546876, 0.15985192160212225, 0.23862820659433645, 0.12773484983030828, 0.09819066136955254, 0.07350337075730486, 0.11582029803145318, 0.10144542422025435, 0.226063996913933, 0.13159697484825889, 0.1709027552316266, 0.13813901332116899, 0.10713911990845397, 0.1788694414520456, 0.16699803572508598, 0.1432502293779004, 0.13925921772756886, 0.09332969559416657, 0.10212585585372103, 0.15639948508431836, 0.13110022811639693, 0.12311769919770381, 0.11847948114718161, 0.17973950282940943, 0.1022472501462025, 0.22910997782263065, 0.10391058790827952, 0.06418427888063655, 0.09344926659738825, 0.075285283608302, 0.15072989818309585, 0.09266089317539046, 0.12707894067129782, 0.09719544420799903, 0.11318499387632455, 0.25994052749968344, 0.17955605541506123, 0.12223638398873231, 0.23481215410415204, 0.09823025279347936, 0.18980473370080997, 0.06218028480126973, 0.2094905733341171, 0.12872275085218493, 0.3099897257503002, 0.2162978314464131, 0.1359534564037477, 0.18259774623138292, 0.13200510052904008, 0.1599401289657239, 0.1892101728627759, 0.13980212891774793, 0.16541591094386193, 0.18712206232932307, 0.08957683003597683, 0.10478737553761852, 0.1796337060870663, 0.1687435057735251, 0.11893281367637458, 0.12990672441740192, 0.2073347559499164, 0.09813812305970539, 0.18490880367255982, 0.15935687558545222, 0.17843661709658562, 0.09013485614090197, 0.22208873603132465, 0.19990344261450155, 0.08681373475419898, 0.0832542221272184, 0.12355922631198361, 0.24027359491634756, 0.12576605749106215, 0.1756458200754658, 0.1279290607799926, 0.13509051964407967, 0.15310190557952852, 0.12185170825931335, 0.12899166303536586, 0.0731842874759628, 0.12353138667681526, 0.11889804860637074, 0.1208247903794531, 0.12141208104308575, 0.18703975384273838, 0.16969117185761853, 0.12093403451745549, 0.22506621335783314], [0.0513681986429278, 0.02695789861102258, 0.03658889552518245, 0.0656631043661506, 0.013366185951106732, 0.011276581546201581, 0.07494472688244236, 0.01295605886562337, 0.05146169201320699, 0.039624063102828885, 0.04600684721803954, 0.07168961929217463, 0.052197469668763305, 0.01768959453329444, 0.05665066216381327, 0.025448939057006955, 0.009441984828651674, 0.024913880268051743, 0.01335773791652173, 0.025151486268206954, 0.06027943296958843, 0.040653149011514844, 0.05564474275395755, 0.059417204841250376, 0.043496403903249777, 0.05109930561194497, 0.02300284904307656, 0.01953812064452758, 0.038385398520697514, 0.03589135331792697, 0.06262573045528223, 0.05098289855185056, 0.034521925188000166, 0.042375046534523855, 0.07520430045382631, 0.052624716904134526, 0.004541661286155784, 0.09911634073021913, 0.08180689817715077, 0.027517363046025558, 0.024167561242657325, 0.041890155013290145, 0.054491190540213744, 0.031201906967908147, 0.03256635169588751, 0.028655919088651578, 0.03158798846866816, 0.07436502815013932, 0.08681866069955212, 0.04849854053088254, 0.024930845285134933, 0.04955622067134227, 0.055025004436292, 0.03708639302321019, 0.025635962186741735, 0.01998140210015399, 0.07154875104465792, 0.025097737539439433, 0.050634949077521606, 0.07546172131814304, 0.016693571064200614, 0.02686423861661986, 0.05457864330720998, 0.021729214462421594, 0.022345823310916463, 0.031408239343774416, 0.02266407347164087, 0.02089431269034263, 0.035371145143383936, 0.02881789497370201, 0.023862824872917226, 0.07267044166163092, 0.017475432738842025, 0.04058128996421734, 0.01179644498117869, 0.03606923510350528, 0.035503230192848755, 0.03967743261807388, 0.05894979544644875, 0.010656930371037415, 0.05658127758051119, 0.031376293477331924, 0.03571956959222594, 0.033177881381444396, 0.011658823031241135, 0.01778870907371804, 0.06835923590246709, 0.06448486879948648, 0.07533083519627971, 0.0434721572204463, 0.010252263577234362, 0.07947357056001503, 0.0658827570958003, 0.06497784637876096, 0.07779314903722656, 0.046826921358344056, 0.016803159941768935, 0.04416289273649455, 0.0493549540518753, 0.04810623456573775, 0.055345328780071396, 0.010964765566431228, 0.012707327353587795, 0.07641093489984352, 0.07259533440153446, 0.027701201165215145, 0.04998742092040278, 0.048275367627220775, 0.08619056053219304, 0.07033913651661527, 0.05596646903863838, 0.05759198887033328, 0.03770057337298509, 0.06065078259956452, 0.06375174946902741, 0.06978561500868491, 0.04325632726953876, 0.03393156634223077, 0.03248200924586385, 0.04882255358801735, 0.030624818680207097, 0.07598574844098861, 0.021797968938405958, 0.047392577698995034, 0.07028082190381904, 0.024212925139093594, 0.053998714748529665, 0.022972521537374106, 0.050313471771416166, 0.08670128070779386, 0.04087522640944489, 0.01916640520756764, 0.03342338191765932, 0.09218566585332157, 0.041813048263711315, 0.029686238398895632, 0.0593188621344105, 0.021573440059118217, 0.02787034380279722, 0.055609177122072834, 0.057701734795926087, 0.0224544660698983, 0.04234309683764174, 0.023116433069170005, 0.062262332817960175, 0.02515978874608634, 0.023381024516457995, 0.051093889370320306, 0.05813961916212594, 0.02675809330427118, 0.009657101360179726, 0.02596284424315297, 0.04633426936643739, 0.023991429967986002, 0.024433631239639177, 0.04944030390751939, 0.028977808167016315, 0.03572495135989401, 0.04859627802826224, 0.018447351251398365, 0.07882836364930676, 0.16774622783545526, 0.03422410850743613, 0.043019801453356786, 0.036817871544870644, 0.03363848791547841, 0.0168686221548987, 0.05793811122496283, 0.040498885716642105, 0.03506074929910322, 0.08319613734079946, 0.016653378261253238, 0.02263975784092421, 0.037951666351047256, 0.06973002766889912, 0.019661292260993394, 0.010265166413099056, 0.024236832827990575, 0.03064383489770755, 0.015318479629293566, 0.03560852897804111, 0.01609576584380721, 0.026501689421673937, 0.023073214218921723, 0.046334744340950446, 0.04903332735862463, 0.049479493135285955, 0.04612199789393814, 0.051659308223714756, 0.03154421420467477, 0.018175104670527003, 0.04045496206550349, 0.027411390103459842, 0.01812271191738546, 0.06244756138673233, 0.06766985636204481, 0.03517747045524659, 0.042061984704266635, 0.05893620887711164, 0.06378501683713929, 0.051315576063408974, 0.047609958977949236, 0.06749966992966591, 0.026647734508338957, 0.10446258490124058, 0.00865790341424966, 0.05975174777690442, 0.04517631597756859, 0.039739060561142625, 0.0357305514626205, 0.06348803519241272, 0.03627969477806361, 0.023498663062890692, 0.06040469983652715, 0.011353255456103193, 0.041004277750729554, 0.10697573633684267, 0.04115382194398873, 0.050922967493534095, 0.08329945195826792, 0.01964253842860701, 0.04041525189794841, 0.049843656860532305, 0.062020471199385585, 0.046946385109256354, 0.10246703311079934, 0.012798454469790863, 0.018641941414605227, 0.0407151025419514, 0.030206528927890525, 0.08853308120442015, 0.03135309825020452, 0.06684236649063326, 0.027810740247068387, 0.0349679492383955, 0.08070288120859093, 0.05197566423204638, 0.029909508978767745, 0.04862093073766559, 0.014091370525890061, 0.060439070371249994, 0.03434936388305599, 0.10401481417037788, 0.03392950556571445, 0.08904544080817893, 0.05499583563857502, 0.02260955673972926, 0.06704256058700624, 0.044261875126751206, 0.022835891671298493, 0.07026672588601228, 0.02997677149851957, 0.037480759764871294, 0.024676170846026753, 0.025579620250350526, 0.022757959461981253, 0.028698716590541507, 0.01660357871573539, 0.06531638829337974, 0.13335854806486638, 0.014068677086353064, 0.027137626668498404, 0.06057801956851637, 0.04799581831321121, 0.03391093176399027, 0.04057758592910344, 0.06181136367001361, 0.07027741281255599, 0.07232354938863747, 0.023425409735570994, 0.03288552690778048, 0.02531098960448177, 0.03289454376264926, 0.012579365772375417, 0.0525433162317401, 0.04099300093648415, 0.04237116246874775, 0.07138840118122679, 0.029170563549644528, 0.036008055321872234, 0.011033110185376099, 0.003175048050545757, 0.06477061959524309, 0.0474640537023304, 0.05308759871930365, 0.029769167416698994, 0.05396262051597719, 0.04505165815052967, 0.07257753051817417, 0.062196077703828775, 0.06625424079116314, 0.07933192856369481, 0.046720366188955885, 0.04639554490906097, 0.03211273379894274, 0.012102456887312716, 0.021570624685996485, 0.10989877545545179, 0.046588074295751514, 0.014432561189507045, 0.04300045007238946, 0.030889205198975343, 0.026439979124153336, 0.028953201422888427, 0.05845963707073562, 0.13002149971021762, 0.045294626766154845, 0.026440051902506142, 0.0036202102520262766, 0.05119181072880184, 0.02605032573844637, 0.027706481426233248, 0.012695457778810974, 0.017745214431817015, 0.04387622263522879, 0.05936688818638364, 0.03573861070758393, 0.07469501286264389, 0.01669360936859683, 0.0268685402003147, 0.01627532153150007, 0.032894440340779485, 0.07690413464461604, 0.053327108447950695, 0.05600226832734001, 0.016657490238186815, 0.016317278251893098, 0.03958212361941415, 0.04811072767141366, 0.021856850456266154, 0.02298286180913208, 0.06787027262391583, 0.030430450682498278, 0.031231625433710795, 0.04073415131818864, 0.08858179673552515, 0.0810108179106347, 0.14887038828624835, 0.017785119951792785, 0.05211207384784376, 0.04134174331181473, 0.013766483170911671, 0.02171640738754744, 0.029472250889445988, 0.026503154564829125, 0.008013458282221109, 0.035740725110254945, 0.06095648232486941, 0.02970617583712503, 0.021774245110610803, 0.04671520658678586, 0.03264223653522711, 0.19495437672782331, 0.059150908848330866, 0.08314284826478652, 0.14038096963157579, 0.1235419893336873, 0.08638885473051379, 0.1324800290768185, 0.1433483039539668, 0.14960491338804846, 0.1789210910999006, 0.10264377725581009, 0.13590752177180784, 0.11896692757164279, 0.07442514306955761, 0.11638201668017334, 0.07436041630083516, 0.07818464294917161, 0.10798773082393794, 0.10911529733529014, 0.179257664168554, 0.1881980481407335, 0.13822242497436463, 0.10418906852963472, 0.17952075408351037, 0.18240682179889373, 0.16143796875351862, 0.15249870326970855, 0.07780294730177811, 0.17120061021658683, 0.13845646483523233, 0.22349311309235714, 0.15561121125375071, 0.14128910557877633, 0.14186551013300497, 0.1528848269053044, 0.08873074721064299, 0.11106250131683004, 0.1821965919507127, 0.23601410009207266, 0.1256504088580128, 0.1427941159495423, 0.09362519868919927, 0.19288063800383, 0.11816707815253928, 0.13529325715236126, 0.2215291700896717, 0.15303033764564222, 0.11820623290634925, 0.18238696479989638, 0.23305441132716595, 0.07388950971465919, 0.15584586398495784, 0.13958952419700163, 0.1058341810599931, 0.09804869761630412, 0.12193664442747833, 0.12965641284902252, 0.1408365621201454, 0.18090898201109903, 0.17362304152019564, 0.13444063193615408, 0.15439538375264214, 0.19416446346909771, 0.12093682307749988, 0.13593271074275817, 0.11292941162302611, 0.25736304000020027, 0.08372208734433498, 0.17784536575838444, 0.16383746338467445, 0.07845412969829575, 0.15104931088224535, 0.13745946268881523, 0.15065544975861428, 0.14367283412045048, 0.11279333142503617, 0.14277291063579822, 0.15572883639364474, 0.14069943238169919, 0.0665577724876423, 0.14843713492155075, 0.10243927008442341, 0.2032287851456673, 0.2534541376535931, 0.12310541114739834, 0.08546205688147776, 0.14355071970532018, 0.1260451739653945, 0.18004572349450282, 0.16400378107303576, 0.1020986290888921, 0.18162050915341224, 0.18729915121389976, 0.14006180208056204, 0.19730307972959935, 0.15582283538195396, 0.18261161242281237, 0.2268624443921351, 0.15663327979705027, 0.20349104768566548, 0.1282527482497596, 0.1927823642449033, 0.09633921837854771, 0.13669628589864702, 0.1675941440607271, 0.09216049220412971, 0.18620087224389278, 0.09670770667012661, 0.13341205164549813, 0.13288764913956966, 0.12192188957405668, 0.1842215308739293, 0.20123494939217645, 0.27944246006588785, 0.15099494928313842, 0.2399658420754056, 0.18237210269416534, 0.1235931027199953, 0.0784034529821046, 0.21578478236352244, 0.14846013288103765, 0.18904057631809867, 0.10891216912216718, 0.2026774929535966, 0.16967004315266687, 0.12918404303491116, 0.09012708034847053, 0.10592349159020571, 0.1719801353230592, 0.16972789811270853, 0.18037413006588338, 0.07878475792465672, 0.1075698605047599, 0.12632570770238677, 0.08520660486312644, 0.13499863505844148, 0.10889854041799422, 0.11061742721546082, 0.06749314286055104, 0.13031693385733714, 0.17149628951184212, 0.15644436251492272, 0.12431724733042142, 0.15482773313358908, 0.12107173882184491, 0.10978780761961976, 0.12140786755950221, 0.3109713295294393, 0.17431897111237052, 0.08181967652372776, 0.16645909287035468, 0.09348563279115385, 0.14632703766467112, 0.11525648796269972, 0.1531557922041224, 0.1666355842063504, 0.1116607087333837, 0.1780581543402326, 0.09452181267401866, 0.1904025274298845, 0.08093814681013746, 0.25681965383550814, 0.13523992211107286, 0.14244280334922577, 0.15492669637164763, 0.18613010104144775, 0.09142271888953063, 0.16825204504834068, 0.14750731868609307, 0.06595299203669833, 0.10242151982721784, 0.19909240065082429, 0.0741323595866561, 0.09915617730228171, 0.1890828184062435, 0.0980411746328877], [0.00605067398752116, 0.036943253324998, 0.010168849051208987, 0.029186942509465644, 0.03443965883625131, 0.027980511076748375, 0.03754827892407775, 0.04531829122213587, 0.031161256427426013, 0.05046569727241032, 0.024697263161802006, 0.06705726947515242, 0.04792461810152858, 0.04274771000529009, 0.045498747063139756, 0.09133350795074817, 0.02961276290607789, 0.019288835633966713, 0.04930767876606795, 0.07609925202785, 0.01372391262256931, 0.015724392273583482, 0.06067733903745971, 0.017716129903771707, 0.023534745804124305, 0.02951719152230409, 0.050109531505093466, 0.012243214052080387, 0.018305774372551712, 0.02614415427219243, 0.009803416492838052, 0.026569834857758497, 0.059398604226448846, 0.07648676994346804, 0.04180527630171949, 0.006568797445300246, 0.029141908030836817, 0.07034095980587506, 0.03290569034194754, 0.033073455936485724, 0.013045581985234976, 0.04647318408974717, 0.10771241414571002, 0.029974473234746727, 0.014474404911931246, 0.06016710915813043, 0.07087820960629372, 0.07120401147873172, 0.005211646353164989, 0.0074184890235624015, 0.01945052040560592, 0.040775562200935624, 0.02675558053587954, 0.04322235127009692, 0.04589337810513474, 0.01052408689452756, 0.05181273265231041, 0.06211193060622581, 0.012555617046722723, 0.08495152056697877, 0.0199092423633462, 0.045455263912557595, 0.07524353181642872, 0.03369379946361146, 0.02617766678844008, 0.024521681555216352, 0.03302092145707819, 0.0471358348224913, 0.04343192994354233, 0.05619268331135954, 0.04055732290350622, 0.06711014486368626, 0.015269970941928127, 0.03627666490032308, 0.029276549898748918, 0.11497342613555732, 0.051189937643826976, 0.05210374647210683, 0.050833323715074416, 0.05196348726448994, 0.04980606109564824, 0.047352212526264696, 0.03249007998214614, 0.06095646700311092, 0.06839347237180318, 0.07312116949188133, 0.0460598873154771, 0.027966742561529243, 0.09047950377627727, 0.09154314791122753, 0.04228548319529622, 0.015246073786740102, 0.019936371451964783, 0.049966625463698185, 0.017953548212385467, 0.03555617069885616, 0.05218688999452899, 0.044666626190225926, 0.07640167289683897, 0.06067084644230143, 0.04164985238364147, 0.011792540805594576, 0.12383813594257641, 0.06465769057432491, 0.037101044454762054, 0.012653140997093533, 0.05472305854181609, 0.07067174891070013, 0.07391153474248226, 0.022818555101572026, 0.06669883225714007, 0.010959633734948453, 0.03817183235960622, 0.027350625924525723, 0.029541265835324605, 0.048929250483671506, 0.045126853510737426, 0.07251949169703069, 0.013187239303313678, 0.020721261089126912, 0.053788864113871133, 0.05684311111127177, 0.04229420510631415, 0.023865146119327798, 0.013383882582157612, 0.0758380773327043, 0.0497773825942028, 0.014144586823550204, 0.044209704539107705, 0.05175737130846228, 0.013873191557884699, 0.018749829576981646, 0.07536637401508708, 0.034000112059255766, 0.017475810037144733, 0.03766044185707166, 0.04435539914054736, 0.0796560450426994, 0.03980697425563009, 0.028311886238835515, 0.07766361889098922, 0.0968766367183097, 0.010591017123642228, 0.004388621337937131, 0.10823592032876708, 0.020300943119030808, 0.018661120425789587, 0.04559186888077567, 0.058624154452474854, 0.034445408326123035, 0.04524271281796598, 0.03595108902382274, 0.007835448176915488, 0.049343684898509134, 0.08439599190868678, 0.06653675103500005, 0.04100350783236566, 0.08142184706464892, 0.0198133128334678, 0.0927616413983126, 0.08900031822943881, 0.020852754335670222, 0.01504984419537528, 0.09549876629945733, 0.007534421587948718, 0.02258398664003659, 0.04153632964458197, 0.06052855327124558, 0.03231681004587201, 0.010539118497211848, 0.09091778267775813, 0.046937942820330786, 0.038136105849257404, 0.033078485303708625, 0.16188360209907257, 0.022152709782183654, 0.03571283184893189, 0.04650954645307315, 0.07848496473724804, 0.044050143746238564, 0.049814675754356774, 0.003919762361141283, 0.03077770110159632, 0.026105020585800373, 0.09626270917754981, 0.021185581234373876, 0.011453104483324194, 0.006474876502198318, 0.061452072263965686, 0.06419612259994592, 0.0514883250598946, 0.030895083008574385, 0.04355794757664685, 0.03811914466261383, 0.06645707022999564, 0.024578695733761115, 0.0331183027235731, 0.003218941297569883, 0.0345247405611219, 0.018142900249410062, 0.05391153777318616, 0.04720958227652216, 0.05287089542816243, 0.03163118050583909, 0.03991354474677675, 0.03441113355239073, 0.027500112661190575, 0.031629533416801886, 0.02421178749852604, 0.05055809896739741, 0.04212480008361801, 0.04715692139260712, 0.04372602343679436, 0.05806666077865709, 0.027149813212153893, 0.048064038442868384, 0.04144977703089676, 0.06322370038457936, 0.030913246953259074, 0.02398091541122525, 0.049716225795207486, 0.09415670283018582, 0.03164579937865417, 0.024289158548438744, 0.06783191460154711, 0.015710637164903025, 0.0322821598890568, 0.025953819727404945, 0.07025613089001949, 0.03482178732332203, 0.03434563686530437, 0.06116123847483147, 0.021504530450329188, 0.04711097143890877, 0.03281785453098916, 0.03854991590243675, 0.05916454904382268, 0.023978770365037268, 0.12133875876785287, 0.020015399167013746, 0.03644699305896798, 0.028185071874289747, 0.036127270094209143, 0.03995783995055864, 0.04772222533281292, 0.05948332205955541, 0.012420639057733841, 0.08183775619874079, 0.003293927420013314, 0.037659097372764544, 0.02604664277075039, 0.07134901660103952, 0.05869797468485852, 0.05103591566665038, 0.07734730884793305, 0.024656287033952052, 0.022462868139207847, 0.03720695611029383, 0.07078404207864115, 0.040759819094091654, 0.015094040765336927, 0.0997364582614072, 0.03674204799256498, 0.1101060098998489, 0.023824078060926932, 0.07916486010916772, 0.06945566093969731, 0.017397586714416262, 0.029587393904465343, 0.0312674745181275, 0.0458462292238349, 0.052072670115458394, 0.07351765829709268, 0.047580644623526645, 0.04706745764480964, 0.048737150106218555, 0.010139296251919963, 0.02447942223009323, 0.0990817595213171, 0.03169258628340979, 0.05373051885755793, 0.04127962507247444, 0.010463002873885055, 0.039347068692046794, 0.05942296965288059, 0.025708882265814373, 0.0025576063208357105, 0.0868064875624353, 0.057297087154321136, 0.024585358783482544, 0.04043517784485894, 0.0392184425295601, 0.013202661610839349, 0.04364895116117212, 0.02829580988374449, 0.053920573780253056, 0.07268374094799643, 0.018806087243701183, 0.03956603577300426, 0.030856964388682, 0.02858816244218859, 0.038585435569046006, 0.01804877485659334, 0.03841486226226534, 0.009723198468676739, 0.038488820390475374, 0.10023387148976327, 0.04420783528457246, 0.03439429493981504, 0.023099969839677218, 0.04182796782603668, 0.060727234343968095, 0.02968806551859504, 0.01954440448072649, 0.023307271316767703, 0.032559652256989674, 0.07086518611158095, 0.008155862057221033, 0.03377124712231659, 0.041691569701558163, 0.03971873241807184, 0.07609270963697665, 0.02118048674967741, 0.061993186977962335, 0.036761590895513375, 0.00963357096958545, 0.03717120278686766, 0.03209995928280537, 0.018664138812211253, 0.02479421924949894, 0.025531105817325657, 0.052372141545938874, 0.08232752386961253, 0.06922228757532374, 0.11719407754078989, 0.08614004469446598, 0.009036660156843644, 0.007980687913650107, 0.013588315059971667, 0.07813487021673111, 0.01825534855015576, 0.07653536290050515, 0.011420071729639126, 0.0800828249644368, 0.0723051019914208, 0.019811489544208014, 0.08778959287390595, 0.04902603037114586, 0.050557696771237164, 0.08195354272761653, 0.1262907051451264, 0.02648289920011115, 0.14143493807604238, 0.14303992292092693, 0.14313879422843456, 0.1596837653027427, 0.08306212558020508, 0.12090296199124669, 0.1024691551743496, 0.19499975977645767, 0.22294289342338042, 0.1429008166756361, 0.07872485750985724, 0.1479629724616966, 0.1680170399166884, 0.15266531207148107, 0.13861657721140694, 0.1635585767367194, 0.24945408616575504, 0.15781639534379208, 0.24659487749299697, 0.22030425678578117, 0.0735040755581952, 0.08533736841092188, 0.20183246732959825, 0.17224933861965136, 0.12891575904382815, 0.10323178038121232, 0.09793212201686637, 0.13677514698957244, 0.09715373838140119, 0.144137037437289, 0.07596989808183524, 0.1625838217836234, 0.19357929486901532, 0.11413598478200937, 0.1267317649457724, 0.18656811947303434, 0.08624077759562962, 0.1555876004239244, 0.12352156542962599, 0.11114460295967518, 0.11286421754066983, 0.13496140318532146, 0.13543659220299414, 0.09097976685171166, 0.2695358706818473, 0.15657642075131017, 0.141140959495979, 0.10595486289070499, 0.12242363119918494, 0.1623400219626004, 0.11230342585833804, 0.14152155197676153, 0.2171456456304558, 0.18579351265103589, 0.1422031863682693, 0.14600595489384668, 0.10388981160377303, 0.11422882697755292, 0.17730424721394816, 0.17705298569654265, 0.20322259515523913, 0.1182486588555959, 0.1906688042706059, 0.10233636149355482, 0.11567466471704746, 0.07994927285659699, 0.17472973213561122, 0.20248639998176407, 0.31202022647184713, 0.08746965923496793, 0.1256904446129357, 0.1859939672173031, 0.13023718410441953, 0.20477844312066035, 0.06922341372457243, 0.21256489949601315, 0.19172841112219519, 0.10405418342880665, 0.19317904457209573, 0.15690776910031998, 0.15670371392080862, 0.15103386654969186, 0.16166471545734715, 0.16537373014275106, 0.1622324785397899, 0.1677646292673965, 0.13259042234670732, 0.22977284305999357, 0.1623485102168014, 0.1832665103457628, 0.14500411107174813, 0.11018837967346753, 0.13821726154175498, 0.10257714292815617, 0.14718758423001538, 0.14555681286559952, 0.13602808868933108, 0.11091322908478399, 0.09310464960552993, 0.13184052952114614, 0.19572702236473563, 0.12097384810688035, 0.22072263272298923, 0.1633316921370645, 0.1481570684981923, 0.15847277947731558, 0.1092356650699531, 0.11873920793615042, 0.14389902924097356, 0.12627475519454287, 0.2080113648046409, 0.12286034728130027, 0.19269116913839696, 0.12369572785833191, 0.14132399322284808, 0.09772431300652605, 0.0947606788888093, 0.14507980055866704, 0.11625378888340727, 0.14555558712492067, 0.20595069554063583, 0.16889345982382375, 0.10212695135945275, 0.2704596195009447, 0.11602305086149324, 0.17748976306569192, 0.14198509645798515, 0.11742117664506359, 0.11789678701109464, 0.12514695119593414, 0.11898298477453571, 0.11005023869896129, 0.1547299803144509, 0.23268880352618235, 0.10486754663889447, 0.12690591971359907, 0.20698644641426303, 0.158406849950552, 0.08489057827260225, 0.1534886267637053, 0.15751253422950545, 0.11646937368617905, 0.08131061109804338, 0.179027117668621, 0.25218324375248724, 0.19820940770929862, 0.17720742902207762, 0.13055039149138237, 0.13473726118043547, 0.12036273210880258, 0.18149018227573366, 0.14058019845716416, 0.16684360772130952, 0.09081766264693392, 0.28850570921936347, 0.1466352808018846, 0.11835469308519557, 0.20906870403597433, 0.13808737899507248, 0.2131465900569193, 0.14330934072213788, 0.10664116275767166, 0.10441588418137643, 0.17404697925573395, 0.0887019882699655, 0.11086635216469727, 0.11463968759222377, 0.17852943630949145, 0.1138696236716163, 0.1299255855020977, 0.15761641575203789, 0.18180011080638056, 0.09869460166702348, 0.1683734240190637, 0.24605890705941186, 0.06602074485272169], [0.04916354315355421, 0.03747317166398129, 0.02335004200558028, 0.005070170980968303, 0.011688183350939185, 0.051113792334593115, 0.05292141892676873, 0.0631708211656059, 0.009701327616048437, 0.0540818008143575, 0.011463056923070503, 0.07672213513644473, 0.0173642867875676, 0.04493879041664543, 0.030595540714960907, 0.023196131111152714, 0.009385775042427404, 0.009616671069975822, 0.08068192870386186, 0.011646105014088174, 0.09780511996077915, 0.09458535966733772, 0.012114948908528014, 0.009203134893229412, 0.03548667886324468, 0.06528686326477798, 0.1627973151663619, 0.024171382106179674, 0.010194550343458692, 0.019348278311231447, 0.024072213939601378, 0.0777662746728428, 0.017714697319353302, 0.03694127298771374, 0.02851187349146893, 0.018086640667470715, 0.019068497255624785, 0.049108289062015476, 0.03234476842466862, 0.0975599181988547, 0.045005635418478525, 0.0236035960410992, 0.02173570131192044, 0.031606322867915995, 0.03098370980531458, 0.028969090086438005, 0.03553583489490613, 0.052857921729164745, 0.07565477547506172, 0.022741827565515717, 0.047489870865378654, 0.01608622613393011, 0.02704197293027274, 0.04575514903051719, 0.02669046689275532, 0.0044555185295100655, 0.014109263466971536, 0.012056652490319985, 0.056325442518197724, 0.06507199092377579, 0.05427074874000204, 0.05472385527325734, 0.09341454749265987, 0.007106543766454824, 0.05902603268623353, 0.0438485553698434, 0.0515480492744715, 0.059828486804279594, 0.10636304985852012, 0.006546819340362544, 0.0482164899398002, 0.07475001797560724, 0.03818239288164243, 0.04018118139356375, 0.0586887356644917, 0.014233546868537464, 0.012300233018674679, 0.06398922523423549, 0.01097130221164515, 0.04249527637336043, 0.02680577653189821, 0.02864657856163479, 0.08972964159423306, 0.01714295441014392, 0.014346293943573632, 0.058694113601720145, 0.023341429262091557, 0.0592277129931796, 0.010951546719297768, 0.031164316948683515, 0.04332732829836108, 0.021746591251764088, 0.04300385150277326, 0.030247282890242436, 0.06812870472429261, 0.03657296855723666, 0.05068254228981753, 0.010980289380606866, 0.06052399504809611, 0.06281953537836671, 0.02106098852480852, 0.08623802733998145, 0.09618102888306303, 0.03393955663928101, 0.029746556331613855, 0.016502899440726446, 0.05927614890219224, 0.06292937706495005, 0.01688647391875425, 0.07304638398871308, 0.031111326646961035, 0.046216169252030315, 0.01712318168081824, 0.019266147940089146, 0.05529451033761425, 0.02308493536416321, 0.061687119530453804, 0.05443652633637671, 0.02571101007502406, 0.04773046460843856, 0.03170985582044288, 0.05329878234695043, 0.03299716124010663, 0.03640179387143543, 0.062136744194093256, 0.0406420445670524, 0.03977572552919869, 0.0450486014597118, 0.09182945795116887, 0.018645155153447585, 0.03632226628401587, 0.0770421147406582, 0.01620297218793102, 0.06982860786299552, 0.04644052193109547, 0.03091264174379889, 0.11951920035625659, 0.014249956471875552, 0.018900473106412158, 0.0777706950001659, 0.006684352711383855, 0.03962380263293463, 0.04284321818681013, 0.02210905234659872, 0.07433973958775883, 0.051820190518253276, 0.020074740337628513, 0.04338193504560379, 0.03797819214542547, 0.017534128480380582, 0.031267939916541504, 0.08250773073204103, 0.02358750819468931, 0.06259586451755417, 0.09031727699743164, 0.10766133906379824, 0.033630696801288475, 0.071541496192015, 0.02166085643693805, 0.06108759061223077, 0.06971530345899445, 0.009274367663648822, 0.054852561874976086, 0.001983792221102293, 0.06366566033853639, 0.04174130796004207, 0.06130439732524176, 0.017943160060132225, 0.035997759100169904, 0.05780451315184755, 0.008064853684646229, 0.059289609067021846, 0.052118926504326445, 0.025771682323407263, 0.048917330155569705, 0.026691175524085283, 0.033389237378874136, 0.04417016291089597, 0.010658027791988947, 0.0537834708548842, 0.037913197245929516, 0.01126731762797722, 0.03824209411358161, 0.03698986594475085, 0.03597334387802309, 0.033886987685916886, 0.027720673205030542, 0.04809851622990063, 0.0023131955446930785, 0.01425684839036436, 0.027780311234715967, 0.06353423029424683, 0.028817571301554, 0.018807738163178007, 0.08609930413865274, 0.052947132667947205, 0.03897187330069081, 0.07332298769465379, 0.04661413277649591, 0.05127609572223118, 0.03472154088799031, 0.060939624560095614, 0.06066294041492286, 0.02808754696630903, 0.05292174451413655, 0.016978624719946135, 0.05520994955253217, 0.04872773488562915, 0.06801673331327977, 0.014430245688755908, 0.04705038537541705, 0.027909412371715712, 0.054292678006834565, 0.037538369576777184, 0.018470450717535232, 0.043683451930842096, 0.019395825558251912, 0.09475403690650579, 0.02129291015256557, 0.04009114307982307, 0.05818809337553479, 0.05146084165561104, 0.034121471877780654, 0.07120241035496996, 0.051652827119875344, 0.03132802227722301, 0.10100549056885705, 0.012703442330201788, 0.024651518136623408, 0.0455339947685359, 0.020328524199524717, 0.01839806306956997, 0.0021094185508592355, 0.025581328626421672, 0.02219377784058452, 0.021828859518732757, 0.018171917744761994, 0.02835261913376951, 0.05782886708696043, 0.04115808905372697, 0.05253953558783378, 0.05844580918370236, 0.10312536310765053, 0.05837427955421229, 0.07439213234090036, 0.014004282608267762, 0.07265977771772493, 0.04191433274818044, 0.031219517414067543, 0.03867331351484022, 0.037461101948734254, 0.04012861244019963, 0.024074418357603496, 0.03556538673658525, 0.009036380534751282, 0.0370485597710696, 0.0268022314600286, 0.03837538958196679, 0.06065588857557985, 0.03679344483140496, 0.00355746214477075, 0.043885618703620094, 0.05669910956414477, 0.0286746614297191, 0.042421180349324024, 0.02969399120868935, 0.04409288379153417, 0.02630055495237391, 0.00986909895624605, 0.006749391660935456, 0.0341985096794463, 0.011725259133644644, 0.03755124368434472, 0.01685331380295177, 0.02502195995240923, 0.03396573386365368, 0.014963937010766279, 0.006830800951819026, 0.035196166831038656, 0.008186932668210039, 0.010295848234466488, 0.031490549745578925, 0.028413749119687467, 0.07154900385367294, 0.061091106955803214, 0.03521967040855558, 0.035408802195301944, 0.043188432727249405, 0.01648133023521833, 0.040715048915796706, 0.0560377381982342, 0.03982071404255206, 0.08534567280402107, 0.07248153970126184, 0.028747139093015465, 0.01649446289746031, 0.00897232792340219, 0.044217775275389996, 0.05523802667495705, 0.029803356005539818, 0.08567244760812291, 0.041704769396493514, 0.08956460327270532, 0.06274082367458651, 0.11661945797142484, 0.02836333478861038, 0.057413203101004326, 0.015792087633012524, 0.03419140804438822, 0.05051383440713248, 0.09790199943968365, 0.014098465457678804, 0.07691495180610688, 0.007902801190803369, 0.01858273622459702, 0.05543464314072363, 0.04507064563973297, 0.05711265148655061, 0.0553230471127937, 0.045619884716166605, 0.11447868655405699, 0.08742346413313382, 0.0878135867476944, 0.03782184126095907, 0.03064705629742915, 0.07942569006474749, 0.021554385537221547, 0.08465139030088341, 0.04239049086707734, 0.06366165369869241, 0.0688028237932632, 0.05303138318741995, 0.05432429445546962, 0.056972974505756176, 0.06008904479864625, 0.03730968850093984, 0.03804383438921744, 0.011026250825624072, 0.01135939182037668, 0.06207122069392955, 0.03408308321189496, 0.10224191817424952, 0.030336959227438898, 0.01760578834481778, 0.04355746877169417, 0.0731081153536516, 0.0440382655529726, 0.1233544433489442, 0.05879119992436421, 0.029554586189108032, 0.06267417402517411, 0.05078508315848247, 0.21432175361100705, 0.0972898492229081, 0.10260079206237871, 0.09512953490259186, 0.11122711828999943, 0.09137203451246025, 0.09278791055323617, 0.16134136506626684, 0.1260253399490349, 0.11516964423560327, 0.11632444517266367, 0.15817970488100283, 0.11545258348867779, 0.08819537432563883, 0.0826400034730473, 0.13469575453669796, 0.08172366272417769, 0.11633227459124981, 0.2530349343414268, 0.12512232146916852, 0.1302987622517732, 0.2019907564165131, 0.06128966928489747, 0.11063763661490333, 0.14930082244738457, 0.12106975465412102, 0.20935826994959386, 0.15896151292948954, 0.20109985744760883, 0.11460818605677736, 0.16154024149141005, 0.20138749281965918, 0.10957773098902357, 0.10386968647400219, 0.1472592134509356, 0.11032500379388371, 0.1862643043240232, 0.1048470767695577, 0.15419264624436058, 0.20117229872172881, 0.13560013665306953, 0.11740916438641087, 0.15050160398166026, 0.07836375430586838, 0.1436072416723736, 0.12565491345500754, 0.13408884436132448, 0.19875673156592155, 0.15709457197977653, 0.09323060978204013, 0.17749518696819583, 0.12274954798481158, 0.09904161651408482, 0.11501241235002396, 0.18817076008887063, 0.22659131055397375, 0.07192932054280274, 0.1435229107136688, 0.10989145165489567, 0.1426223743586771, 0.1690489756724527, 0.1822993243413587, 0.15430308547952484, 0.09908183613010954, 0.12012805639495773, 0.1780419439197548, 0.203731645259165, 0.14574830420315266, 0.2296513415152027, 0.153554939334431, 0.21203553274033532, 0.15900455174907563, 0.13219389523709976, 0.1361363675565489, 0.13033853753680183, 0.09456694291363801, 0.11824632228742685, 0.1236070455202172, 0.1614719677355982, 0.24437334508665148, 0.16762967521865524, 0.1559264870781091, 0.1894773996525234, 0.14115885530989017, 0.15235806484856915, 0.17252463997612077, 0.12014104924615353, 0.09630224697532193, 0.10783856584420128, 0.07775427773594856, 0.17079450700792576, 0.15456582299403607, 0.11140147990156567, 0.12384152971208097, 0.1266042113063797, 0.14095550493126915, 0.1195086972908147, 0.10614073114289392, 0.18955753244940313, 0.1899084160404821, 0.07721909637292547, 0.29285518873122435, 0.15447281992002843, 0.11339990452172295, 0.11534771371272304, 0.09313229005783798, 0.18659667923085152, 0.15136299324372124, 0.14563020408874558, 0.09760424404615357, 0.12955792458547702, 0.11336743771549194, 0.10108850385633208, 0.12120843955105352, 0.20669510317665918, 0.15120626697617193, 0.24644915224804034, 0.16940571217527314, 0.13866572941262878, 0.10920068549533045, 0.11233868888549267, 0.1490844638958093, 0.19324731832790762, 0.11322699847721285, 0.18040941607567573, 0.15442207425592408, 0.16925747416192488, 0.18875588272367755, 0.2653856659608503, 0.23821458040225893, 0.17603637169926398, 0.17584422152609597, 0.08293100963196448, 0.16165020575206127, 0.16559044109477153, 0.0736538917126675, 0.1907725938625874, 0.09062495322958117, 0.12386936168637007, 0.19736802866381986, 0.17217948672271546, 0.13592794567586916, 0.2210395326537471, 0.15380655325228168, 0.22088605459899674, 0.22536632064129078, 0.17226657559794767, 0.171870140418891, 0.18858657729241157, 0.2127298688696277, 0.11875492039947741, 0.22435483943310477, 0.06793993299887066, 0.20618297339927769, 0.1538612825735923, 0.1634218760075108, 0.14164096976239837, 0.13083807282870816, 0.13972437099343346, 0.1902065927823705, 0.09352052043522559, 0.08249859130310436, 0.10487506196143166, 0.07892152760177851, 0.14060725668264976, 0.12710944629244267, 0.12943023305025794, 0.1080579887474737, 0.09326188915198849, 0.1438903418039122, 0.13915634744109648, 0.20502477103183347, 0.13765489171829917, 0.15928812685512728, 0.1860445443420641, 0.15402504152828647], [0.021590832170219194, 0.020200258098362435, 0.018666004236306877, 0.07457596279921071, 0.019848121953527295, 0.03538939718817992, 0.03968296760332681, 0.02321655118477441, 0.028150651543851823, 0.061891645854038585, 0.014749146066606047, 0.043979885822702805, 0.047999418926455324, 0.016558021382098238, 0.04696425794052982, 0.02964914059116235, 0.034695195124274304, 0.04206401100682636, 0.09637397578767232, 0.033456764198959835, 0.0883898227625797, 0.021773090233064948, 0.04669375995534562, 0.0788615505781866, 0.07312585794997793, 0.024617725998283397, 0.023435117984791438, 0.029746416520567674, 0.024393691245706815, 0.00826404707866811, 0.012466149468485628, 0.027100145816802982, 0.039775606785570426, 0.02209266381067855, 0.029708295985455477, 0.07183407283117695, 0.005839091994153757, 0.029195260309103518, 0.051084183036319675, 0.025844972039903366, 0.03133828977062818, 0.06594349254643725, 0.05585864599373552, 0.07431333253700888, 0.01853919944786016, 0.01854116829382556, 0.018194289427370797, 0.012536519432380315, 0.05116526578222552, 0.010863782729082292, 0.049246338105970816, 0.02651174241046031, 0.04027957389611871, 0.012643552449111257, 0.0723853880058854, 0.06276520825321637, 0.03413997673159165, 0.026932045058797927, 0.012814966537388823, 0.03976425719297221, 0.05895926046275324, 0.11558081894632309, 0.07208292117162098, 0.028832734096795324, 0.03240252762371975, 0.015797297988507538, 0.026705499453049515, 0.06786595954890214, 0.056778832503985015, 0.07241908055279525, 0.07762698456645012, 0.03776872455472908, 0.062190799358030485, 0.01019286207719556, 0.05809671440792661, 0.032722181640565395, 0.04455464711833385, 0.016607344037883224, 0.07923725541801223, 0.04216698471516852, 0.05167106767335246, 0.05357799075183369, 0.004469310984976831, 0.08747016485299795, 0.0071376129410289715, 0.05461002609902813, 0.07702381290014713, 0.04127689779946401, 0.011265587226878251, 0.013879775125983984, 0.07239339362469412, 0.007940348596387214, 0.0805091375725404, 0.02904571803106416, 0.0340028393322662, 0.07969363697714384, 0.03996645460926718, 0.05811971619785313, 0.03344161097981757, 0.053849756612532565, 0.024157324392769127, 0.023907447579286756, 0.04428218411762388, 0.018779603584158807, 0.025493006349631378, 0.006982199556659908, 0.08480353536264551, 0.08106263609783304, 0.027804875844008023, 0.02381975157937456, 0.0457864896874995, 0.05816615261738339, 0.026666442375449885, 0.08581143894022511, 0.055798385517611626, 0.07757618527619109, 0.048985420050279754, 0.05949942139728416, 0.04037364566278073, 0.012561820443689585, 0.07892751074846714, 0.04323822078144839, 0.04702538792644778, 0.028940582039555716, 0.04656245248512395, 0.055090527936455705, 0.015299967114603328, 0.02636053197596583, 0.016633327825055007, 0.027198272103804256, 0.021473929068193804, 0.01878554268079179, 0.07515998992828593, 0.05993014284139199, 0.0605060954037453, 0.1251813255610966, 0.09083605641799589, 0.01924631966938896, 0.006324799877831773, 0.048730347245450945, 0.02760700682448524, 0.013788440208431455, 0.009015441436560885, 0.06274660763841483, 0.031602457954338005, 0.08896715428319671, 0.055810053036698413, 0.10272520474128186, 0.03415957709113437, 0.010916515433740233, 0.0839780756242333, 0.04256922684069123, 0.1004885574201903, 0.007192138291429729, 0.04300951672297332, 0.04600206682939203, 0.03426447368016647, 0.01640570012011355, 0.0859187142322621, 0.05278509741108264, 0.022094429643344016, 0.04517952588597133, 0.026203102822746002, 0.04301415538535484, 0.053249090053741975, 0.030530089993150007, 0.044894525856380506, 0.01863908199142785, 0.08068761307626002, 0.047036369796842344, 0.07875579980111892, 0.07118675151779767, 0.044349059762973944, 0.020989818956642863, 0.09083205743903115, 0.030024146375757073, 0.022888987310110562, 0.04419473135062764, 0.0266651917369135, 0.041094250946996674, 0.06052473432294304, 0.017010495892816016, 0.012491935988016909, 0.06420809655420243, 0.020274277513606415, 0.023006516689014052, 0.01661849444762113, 0.021190087746588454, 0.01181250218407161, 0.05918451329512943, 0.014520529150632362, 0.050063244472708435, 0.02960158759848245, 0.061925598870842695, 0.09317339833585486, 0.019364530866545056, 0.06020279736408304, 0.05019163697837822, 0.042616751105073965, 0.029608750520574472, 0.036215174853080706, 0.03522312546509408, 0.014554600911064735, 0.039490284999051405, 0.0559582565760901, 0.05076006655731509, 0.04202880543626605, 0.012559641881154911, 0.03495058585559169, 0.0129072226756703, 0.03040480971967261, 0.03505069822553666, 0.030585667756836743, 0.024693047762998653, 0.011097009579140333, 0.10286729106859815, 0.06921858737064947, 0.012413170658082012, 0.09078757071326818, 0.021767967020071322, 0.02128021033000081, 0.03325145263525267, 0.04433303703403762, 0.02013067816263966, 0.03212917213057799, 0.027521821677744873, 0.04374940827068302, 0.06810679460965818, 0.012027763314695369, 0.0324512699679021, 0.04005134098171707, 0.013347281773965205, 0.017655057374448065, 0.04346653030464246, 0.04549361427404708, 0.06644794612281746, 0.040724042788027756, 0.0302730483423558, 0.022084786511597135, 0.03084221528091979, 0.03076699310763469, 0.008702813403590793, 0.08165715097059166, 0.01032123926110686, 0.016744920022545323, 0.05363828570191419, 0.056140068392719955, 0.016736529444554643, 0.07529787043289793, 0.022603636795294382, 0.11638922556754082, 0.0376768437995305, 0.05369895603507758, 0.05440363052090811, 0.08566893126455047, 0.06483087241048775, 0.011909172904016751, 0.0203730319927056, 0.011710859553497887, 0.030968458909961968, 0.09672344211609134, 0.06697267038567413, 0.03111604000291517, 0.01836503893437405, 0.016920084111212243, 0.07150461671934014, 0.09906567933578646, 0.0332611589692533, 0.0938722773665382, 0.0743363534791335, 0.044764202809141534, 0.054800253391506216, 0.00972173811357108, 0.005103402917513685, 0.034257157540489594, 0.0197462341748178, 0.03160647417028104, 0.04394070425581548, 0.047679355052570184, 0.03351394883206776, 0.05111292282479906, 0.02714587360500328, 0.02744930187961267, 0.0299311567082881, 0.037865014145931894, 0.03446605056524277, 0.02817669278761793, 0.02772686319545873, 0.03301473146665, 0.012702907983874603, 0.04653666596559267, 0.008520028655297093, 0.012293476123182524, 0.020045717096617146, 0.013198213512828995, 0.017004129702165242, 0.03563432698889125, 0.06494792298443856, 0.06916941984766914, 0.02072278943453585, 0.023252216408089287, 0.007918213922229987, 0.008802671049300943, 0.044731211232682394, 0.028285034857089483, 0.03154097939841449, 0.023719422789590976, 0.01508300239595795, 0.03128307206826585, 0.05380787075527253, 0.01591438207880504, 0.0695402064030209, 0.037452353224638975, 0.012415493819712391, 0.047813945209547404, 0.02064453163785079, 0.020061998380227916, 0.0173829180458861, 0.013958743469218814, 0.033353185281157494, 0.022279648636017117, 0.030904680175045808, 0.06779862808123713, 0.02571953854884111, 0.031129904279124834, 0.03289103891039568, 0.04956810269504786, 0.08465170439693236, 0.05108342843971426, 0.045338431673665205, 0.11658386552646277, 0.0220102557326637, 0.026140226156360684, 0.01788447772513234, 0.05902880592451942, 0.04073897001123236, 0.02022591438294659, 0.029736064757490833, 0.028391469367629582, 0.02535737814351676, 0.020943367215354117, 0.018389149636570967, 0.022424791654151295, 0.018043490765135617, 0.030880330070372553, 0.019107922055428068, 0.011648685772783093, 0.06291465285504538, 0.07826556481661336, 0.05576658137743512, 0.10437685200163435, 0.029287924389204675, 0.09524848537459489, 0.10274569759325636, 0.18536692425127954, 0.16977519638115363, 0.14510535725182103, 0.08403637491527104, 0.13327873702491486, 0.13369150519851716, 0.12087824033393015, 0.11864029832424657, 0.09159654423954988, 0.1285623167190821, 0.12474401959127958, 0.25709772843026346, 0.0828512292355299, 0.10926274627807642, 0.1897967050993635, 0.27186578920772003, 0.16223218742637865, 0.11428313495050516, 0.18907554057096282, 0.16140876548184505, 0.06483285657821164, 0.2237384604109872, 0.20491981698620707, 0.11321109449190479, 0.10595313919287537, 0.1167881352105929, 0.11403863032859181, 0.13274947752154645, 0.18508814485563388, 0.13202186253282333, 0.10257278388786702, 0.20537557801411999, 0.16471120198407482, 0.21213014459898397, 0.11195224349296863, 0.1567956138282053, 0.11846503272892968, 0.2699338380367525, 0.10527591746781143, 0.13597306825460928, 0.1386592023435139, 0.14799062823576314, 0.11924645773345426, 0.1631406604522659, 0.14118389106325566, 0.1702781943904777, 0.0958330640869756, 0.1596205017619556, 0.11929014772777596, 0.15812345870560215, 0.10289817973370514, 0.13052440578899077, 0.19636226247154898, 0.25097637948009277, 0.11618936088897529, 0.14039014736490865, 0.07721313620887457, 0.13169475831091404, 0.24721499502418504, 0.19114177163329818, 0.14000932505774882, 0.11848320433449362, 0.05478820282845728, 0.10380042446476799, 0.15772710013533794, 0.11792111030269055, 0.1657654921854696, 0.23658805316494358, 0.15238832532157823, 0.09832622062775398, 0.11699188395493454, 0.12046180259917053, 0.2500134529245477, 0.1935724000776968, 0.078404096495961, 0.14365116915395185, 0.16096621180974668, 0.1398374302492988, 0.22919729652424015, 0.1603187449396618, 0.08422661752950761, 0.15589345336681412, 0.17197792898983727, 0.11687653409617564, 0.16875262221982404, 0.11095739405361876, 0.06689165658768147, 0.17095956831209122, 0.21148473084453615, 0.11861203734071986, 0.15113324347522952, 0.20244121611599, 0.09391285704388734, 0.1424111485961945, 0.10582052171230318, 0.0640070521002335, 0.26966353157354944, 0.1500849594031611, 0.059312798548489816, 0.10438406854988107, 0.1272342496761872, 0.06722400851187206, 0.17729490094127195, 0.13181930888564358, 0.22125339375868922, 0.1511221964873614, 0.0988784627688508, 0.15520426534837292, 0.18447697523140139, 0.12059108759727209, 0.1157178950586146, 0.14237665931784338, 0.15264246732957903, 0.06871885289588282, 0.13529420710138737, 0.08990168962026797, 0.17780433408916, 0.13054475308425967, 0.15460236538802424, 0.15441021521485623, 0.15801104296359325, 0.15439604258825704, 0.09681662905120081, 0.2016587645536469, 0.09401994081394327, 0.08714251670866244, 0.1648903286625301, 0.18677415115939033, 0.13373673502956668, 0.11906356956329077, 0.11218963881894467, 0.15011791650566364, 0.1555853634471855, 0.19719918288530844, 0.12281561540740153, 0.19187559193420797, 0.09539756608465988, 0.08856209295411265, 0.1075005984955257, 0.12790084576174138, 0.13776013687733682, 0.1233880746088201, 0.12438537552952768, 0.1912973028036856, 0.2049524676535399, 0.18833873252714836, 0.1261642776549824, 0.09936588621067424, 0.15062151206356866, 0.1479063585640923, 0.25760638016846876, 0.15016640987127058, 0.211434873842424, 0.09759686661944275, 0.14688540850916218, 0.08143248036503792, 0.18130547847718964, 0.1544137392193079, 0.15242661439603375, 0.12906677029546232, 0.12279716034930561, 0.11439416407337112, 0.21377026223607604, 0.15798763131662724, 0.06641787717178946, 0.1225766112967845, 0.22136515066508325, 0.10639017703191889, 0.1617144805289084, 0.17043179501929592, 0.1604215845826172, 0.11212611480826333, 0.21595053314681978, 0.2741951561502872], [0.07528611864413946, 0.0485895058110116, 0.05261488416562638, 0.016531535807336052, 0.03895858933608379, 0.1318721842741774, 0.03163438466858239, 0.01819692285461051, 0.10223771235154522, 0.06645052783912228, 0.10603509527901489, 0.032255162950605154, 0.022548878745686625, 0.03334679227742938, 0.0609797828890864, 0.08268917099602761, 0.020288095824540626, 0.024396998830319896, 0.005779466892202055, 0.022756111274863926, 0.02562291570939124, 0.03521034328807746, 0.026184511784043525, 0.053531083188229994, 0.05017586322801729, 0.09961776059841919, 0.061368396310436155, 0.028132790203897223, 0.0028726346030335634, 0.02997751460380612, 0.06989606190472841, 0.032193366468193076, 0.07359767618078379, 0.03888496445612081, 0.02163392461595997, 0.024389087057281888, 0.030447716389091748, 0.10846181667499966, 0.061947819251086444, 0.04859890954028215, 0.05450271250259492, 0.03258271916438976, 0.007212980192214732, 0.031126487526982546, 0.02535578851107388, 0.02412788746427865, 0.04450038511065706, 0.01599791630606858, 0.02836985802728563, 0.07292460665226945, 0.02424853099059434, 0.05493899957547265, 0.046987826635520306, 0.02069659305796508, 0.06953984634169648, 0.01568557651368, 0.011621265570753285, 0.022326165494779428, 0.01685498578984651, 0.06737017808782478, 0.06613442463980568, 0.02522206594867091, 0.07020884028245365, 0.029130409051093365, 0.03450640424665424, 0.008141309259489419, 0.07492337601199266, 0.011469199990613327, 0.05025732135700603, 0.031324871740634405, 0.0573666824118024, 0.0190238285839798, 0.024551020807496483, 0.016156823051372365, 0.021963430523511865, 0.041380189434294744, 0.03338072231159576, 0.08074158397052558, 0.07059856453129361, 0.047398453593374267, 0.008048889369914129, 0.07586142003175712, 0.08401723037804328, 0.028888832800270572, 0.04596236432271619, 0.040874602047786604, 0.055493727671883764, 0.03534332849085331, 0.011900832121741148, 0.030226897290577332, 0.0182362231651261, 0.018196528319329507, 0.02048971675967257, 0.016776254933868206, 0.05183045992687826, 0.03454297728415939, 0.022532603207735286, 0.03523852383237212, 0.01206765830096218, 0.031021883966581478, 0.003674774625030677, 0.04752209252347389, 0.05152151964965367, 0.024188178583919525, 0.06343575735245982, 0.028353756774337064, 0.05929920048783383, 0.056431802335165204, 0.03391075556376769, 0.03475674645855062, 0.03928171373122642, 0.009352409998105179, 0.062473221501756104, 0.03611310129804957, 0.02653831991577341, 0.015905876587625715, 0.05253577026568594, 0.028975753136159434, 0.021565411457671754, 0.04550105298779184, 0.10263289880728531, 0.04395884138742282, 0.0399470764152225, 0.05090285385508211, 0.022172991959978978, 0.03419345732958567, 0.04513804605531116, 0.041704765566053896, 0.04696231207720215, 0.03377182934913905, 0.03629584008106782, 0.025216067480223796, 0.016419641005115646, 0.04842159465976781, 0.08770784363150598, 0.08728595135072548, 0.030370140410659295, 0.004585733366829734, 0.050409941393281185, 0.05846406505893796, 0.121120615231414, 0.044460636638705774, 0.04999244262674644, 0.04604081555660214, 0.11129296354709134, 0.1046619669444138, 0.06133273874800052, 0.03178755245772341, 0.026788861310530095, 0.05632088812548788, 0.015851776416022933, 0.01135102135219401, 0.055002864495280294, 0.0019252597520525959, 0.05374693229133564, 0.06836819147030193, 0.018340993349650697, 0.03852610205931049, 0.003929761244968001, 0.059358231392839265, 0.010602744972153057, 0.04086037579503271, 0.030643670188803828, 0.022331323181729645, 0.08073827447069269, 0.08067456659890952, 0.0546844017451569, 0.07902792189270258, 0.023343275533989075, 0.03515622683710629, 0.10742084108172886, 0.04190173826270527, 0.0987050740889484, 0.020321016537866766, 0.03513585655919967, 0.00795128881075089, 0.05806726215767765, 0.04687550665450193, 0.03466195073880015, 0.031500058811939055, 0.048620923076786345, 0.026609568007951303, 0.03742202380371671, 0.04258069900735732, 0.03532786117566209, 0.028145024628047983, 0.004620316969756518, 0.007841918268240988, 0.04296650088602497, 0.004395789526883633, 0.06274000396050754, 0.016431331506840164, 0.01904019030682262, 0.07374051327426588, 0.0483933336762411, 0.028042190730752006, 0.07382677477453986, 0.01691919736443989, 0.04497706033890286, 0.04747331953577457, 0.079394533268867, 0.04913978676702227, 0.08079986793980484, 0.036863009445369244, 0.05299412067078295, 0.02614352416487471, 0.0453722927599184, 0.016575220055998336, 0.02849600589533727, 0.04019929554253336, 0.01689242833714572, 0.06885428191913713, 0.04339559822373333, 0.037234860862935745, 0.10484252620728747, 0.06183211699188237, 0.10014978567919425, 0.018557943704147494, 0.011315546693250297, 0.06351081864728082, 0.10334248008627085, 0.022844877882650303, 0.02051033410093477, 0.0786011802753614, 0.053119789733881914, 0.022074700964073983, 0.027108055674621177, 0.05270149040546629, 0.0559298002401427, 0.022937551538850513, 0.08216990127919183, 0.03956057356610414, 0.025720026929892843, 0.10745700809263414, 0.05526328459382058, 0.01446884694404059, 0.016207679798225724, 0.004254193974643826, 0.050728737391651645, 0.01664682437906102, 0.040121595074813214, 0.033551150061670816, 0.06367262790820773, 0.055243496542736414, 0.005839869094591949, 0.03822796362181825, 0.04031400954831512, 0.04637815088274018, 0.023167249596407338, 0.05714072860897549, 0.057242702572576465, 0.07314081198625988, 0.027113839638449495, 0.07135254060549122, 0.016014909093839028, 0.06901718285535613, 0.019067876724406116, 0.045483272087069294, 0.023038129307209484, 0.08934093624233239, 0.0600259842711591, 0.017685019073166677, 0.02057480039976297, 0.049161627933743506, 0.03047787727067067, 0.06499279275416367, 0.02220254954731753, 0.05549283517945198, 0.06140277067559862, 0.06791379407889421, 0.02962494370407395, 0.06820065570214102, 0.07508371821454457, 0.03819585687691166, 0.022104783321640665, 0.05119383320092194, 0.07523967839416958, 0.027780870478900693, 0.011634698922505543, 0.01038540295520497, 0.03659353418756397, 0.022726722226868716, 0.11145760350289846, 0.023527322412138025, 0.050765842860264164, 0.04422699514355871, 0.04138851297959205, 0.013787171375306865, 0.025284327829496998, 0.028682374019896793, 0.0347033194867113, 0.012982390265190795, 0.02825421322467587, 0.035735128837968075, 0.017643489446791432, 0.03215360267448329, 0.0399838907704238, 0.05732356315298427, 0.02905667500360118, 0.03025423322293547, 0.0774296632997932, 0.016528657231960567, 0.05668181895969376, 0.08732580324454654, 0.057418408668449814, 0.017757280316624432, 0.060205172236648306, 0.03216151636274111, 0.02819663980194638, 0.05324336354650798, 0.0266962795848808, 0.03911466059845783, 0.018802685813317378, 0.03180760289392164, 0.020090234465897083, 0.05713151640168602, 0.046305763234774915, 0.048909408806432644, 0.091101061552763, 0.01401617516568231, 0.02511850618306668, 0.0559141414029704, 0.031931565496169274, 0.020576868837158528, 0.09199834969495574, 0.05722848781114144, 0.08805963120633557, 0.058449325527274804, 0.07894560574523865, 0.020379246880991325, 0.06460527483854564, 0.08841698824037468, 0.0813713925139558, 0.10537548591533016, 0.05311052006999812, 0.07905739329514966, 0.03877684263692748, 0.019845467458869663, 0.074096008714649, 0.0367071335354159, 0.05503901235398747, 0.0478659893926834, 0.0432448436115538, 0.04213374416013399, 0.02788814577093769, 0.026945459258352077, 0.039457071257094224, 0.03506001768513553, 0.017710524055385785, 0.030795028095223734, 0.06755519598241776, 0.03689134320724876, 0.26734458342675244, 0.18959139353565632, 0.16962046194220745, 0.1521450617621022, 0.09488943528624312, 0.25790408193584413, 0.09539324534876693, 0.17616778642179506, 0.15410070037168844, 0.2424141671508551, 0.32947636720153595, 0.11727318377985109, 0.08986333159789925, 0.11027916109249478, 0.16375483314116157, 0.15604130833620028, 0.10506500580137777, 0.13804193465940415, 0.1486734730461913, 0.10474442864858335, 0.11932182546344497, 0.12224094987276102, 0.1010424389894451, 0.11747219043994143, 0.15935024126402794, 0.16232770326877796, 0.20987712597895056, 0.12085405493816062, 0.1051257718955317, 0.1671351501417737, 0.10334546782917554, 0.1116116178191958, 0.19733309505447266, 0.15456517948017967, 0.11627343137778583, 0.16924141695903194, 0.15739999591342865, 0.17965792978723205, 0.15418357576333708, 0.19346033673613303, 0.21288913854908562, 0.14373769112412008, 0.07587399919547382, 0.09169258868261691, 0.25069507199429697, 0.15634199784648034, 0.14688562301378097, 0.16301198832450375, 0.1536090404636437, 0.10565925254336289, 0.09259091104350745, 0.11272226144830066, 0.14119899831712246, 0.20998802486686938, 0.1653627137983999, 0.08601728676547928, 0.07896805978229932, 0.34954612413721703, 0.1385516589207034, 0.22113722418585133, 0.19561880478455176, 0.10161521994779188, 0.13227978901517007, 0.1442193459238737, 0.14685522464494552, 0.10279981404422753, 0.12018848541042498, 0.13871501950967696, 0.10240111890579424, 0.09685588339644094, 0.1966799438119896, 0.0980353600255424, 0.1579801236549693, 0.11903840357497816, 0.20545129814455587, 0.14564814586793223, 0.0790127839953188, 0.18462915093668048, 0.2281015609661418, 0.198874969576155, 0.20663473544822586, 0.14662457089270317, 0.19185144484283465, 0.15628041969912668, 0.1290385782598488, 0.09337309447507705, 0.15549331032220395, 0.18317678612807106, 0.10544744455405783, 0.22680149443687933, 0.14266437129868617, 0.2054266760786695, 0.1244482713481111, 0.19171512715758818, 0.16639653413045793, 0.08246237832692363, 0.19568280376974614, 0.19509072505658676, 0.06404076379934145, 0.11240929154859436, 0.105654870520436, 0.12006146803257928, 0.15147977568689855, 0.0639171899867154, 0.14306079115598433, 0.10887828505327625, 0.13020347623575118, 0.15551692115203028, 0.1715101557032716, 0.0846027820220878, 0.14137138342184408, 0.09722791867510927, 0.14044345176268008, 0.10356399440957655, 0.09881311546890967, 0.11663612804465717, 0.17113340898386895, 0.14266607201387807, 0.08850586210047046, 0.17522254117554234, 0.12391981623706319, 0.10673838697614209, 0.12368474215749772, 0.12371590661425745, 0.251298779922147, 0.17510577405412353, 0.3115266207004747, 0.23686131672753444, 0.15195856531781538, 0.06785062246865804, 0.2220580005838025, 0.15895170700405875, 0.0931397747368582, 0.1722353345323955, 0.1469690499887351, 0.16812361806871431, 0.12042871526172085, 0.2413480638736679, 0.2222045225602004, 0.162138648090824, 0.16689976196615927, 0.14254939682301015, 0.146110495251994, 0.16698622264929358, 0.15488171168873388, 0.15627563931047916, 0.15633669651804433, 0.15913072643020462, 0.13657164339336658, 0.1313999983211679, 0.12745993917868023, 0.13607691913362474, 0.18243061648982187, 0.08614477911783804, 0.1253531744042712, 0.20637863225513892, 0.11708695546633775, 0.14675171084461675, 0.10363251331352419, 0.18210080031666065, 0.1963802348942526, 0.13168780223256157, 0.15360393831806798, 0.14137579608828793, 0.20978351003460347, 0.16879313294926, 0.1317397429938278, 0.21611758627958838, 0.1922928034177711, 0.10038218611190397, 0.2254333686564238, 0.09393416194906158, 0.11616322196899884, 0.16505784144805324, 0.16748994078126647, 0.10100556717764947], [0.0485238942107366, 0.025023882833099174, 0.02768939000464255, 0.05789866535774162, 0.05742262215203336, 0.04551647816814723, 0.030335714334561944, 0.02124227365599044, 0.046888208392286496, 0.01574215497971783, 0.0641926828651659, 0.01613534194597554, 0.027305666139469515, 0.01537507150187007, 0.024392930903441967, 0.09375934068474079, 0.02595156742890756, 0.007087523239709798, 0.05776078102269, 0.044791709196062825, 0.07307888143846104, 0.030941762661020604, 0.007385283900094369, 0.035759681955941265, 0.027436035151983944, 0.05298085585837403, 0.02663512087066568, 0.03601709132893913, 0.05532100165803587, 0.05850567129410564, 0.1004178781482962, 0.01569493523528499, 0.02037430752909953, 0.037345771242173455, 0.0055925749550243065, 0.026057879365379774, 0.05810373560375264, 0.02285420691834823, 0.06954708587258093, 0.047353737041234016, 0.026213494805438865, 0.05837845473339962, 0.02828083861048424, 0.0691963095338114, 0.03032308729034999, 0.07123293129787331, 0.024244392200583414, 0.12231725989089859, 0.04305541305051696, 0.04199685573938393, 0.004618959078910731, 0.02397930279614464, 0.021759440461474083, 0.0292046353100769, 0.05702120357102925, 0.03533000622185008, 0.03300696716553742, 0.031060552254559535, 0.056810839657461455, 0.013530876660238833, 0.02092155094649042, 0.040827571910115025, 0.019001830369234085, 0.046167258368504625, 0.02242540260927091, 0.0212563869107755, 0.001611221638496875, 0.006568183617350916, 0.0593546575926725, 0.043101880113564195, 0.012559497282059203, 0.0528767598312228, 0.061636324070634387, 0.008659124366878983, 0.062198341493645025, 0.058628203227154674, 0.014752376084816794, 0.01876508238755407, 0.022897850947394487, 0.03140627815868826, 0.018272593189331315, 0.057010371087779926, 0.030516842417719386, 0.06930730801316039, 0.03812012142471729, 0.01440964079642248, 0.030604279862957138, 0.034702894307913325, 0.02856128424736521, 0.05667362564934358, 0.05026335812984936, 0.05487585477831383, 0.046709342183725494, 0.06565706759330726, 0.007315764772600585, 0.06902071452068706, 0.03702984807351905, 0.05086247719103291, 0.022156051840753328, 0.01584771519241434, 0.0998629930038606, 0.009973619204585352, 0.08491667122730324, 0.05297643936149055, 0.04922053243424143, 0.06580719018294927, 0.012644873950780641, 0.06048475985505408, 0.06008046844433393, 0.022221657695368897, 0.0622853346078867, 0.05324357422068716, 0.015503515718474746, 0.05526467121296352, 0.01713381498120725, 0.015848787715508333, 0.024655635859216415, 0.07764861122855256, 0.05304197818341275, 0.0017994966037804263, 0.022846660952294068, 0.08459503687317334, 0.06327371826515564, 0.045717691161459496, 0.019282649473978147, 0.08325082069683461, 0.02535485196858645, 0.026369456900283698, 0.02450649003167787, 0.08956127845111395, 0.05885107735652597, 0.011462061966378844, 0.04166468767629516, 0.016118721668458274, 0.06326852035858939, 0.05537629405397081, 0.0413548395848803, 0.060099551694527756, 0.06375235084804796, 0.013060351202805198, 0.03626593200850391, 0.07058847515333085, 0.031854753690441294, 0.021053348712983633, 0.024420793521248048, 0.030089738823833968, 0.027521329466253523, 0.011443356014487725, 0.06693716987126297, 0.017546680831019918, 0.07711608052974747, 0.03023757081058237, 0.043620628890611475, 0.042958529741172834, 0.03766529119363235, 0.019355002647986817, 0.13145328739718085, 0.07167614380558653, 0.0021263613035121275, 0.0525544474892799, 0.020188919997083086, 0.06231110197521987, 0.025436108999495066, 0.014484344902748783, 0.03661703010420165, 0.036999982135790976, 0.05842280739377584, 0.05266689770524541, 0.017388223204761744, 0.07978329990780161, 0.049097820470530185, 0.011685377553916507, 0.002688308581597202, 0.005513088066025728, 0.014815254666421925, 0.04039132697207313, 0.03689096016328662, 0.052473238338866544, 0.07197535476617276, 0.05760446078174057, 0.0608612499350021, 0.048293646485094106, 0.022734971078593406, 0.06045552977030316, 0.054172279628654646, 0.06626191699216444, 0.035867386257215854, 0.015601043499285176, 0.09289557655011454, 0.0446900838024674, 0.048228659246477394, 0.02752279652462852, 0.050905722854358536, 0.04808795953830404, 0.07654975003172314, 0.014700674726026914, 0.04404160952676208, 0.05912229929479861, 0.0452833614432283, 0.031483490245356675, 0.015901833558605326, 0.06303352288781636, 0.06403112258281439, 0.03260369848219618, 0.040970726930085695, 0.04509163261841863, 0.018675568844041517, 0.01851220633984814, 0.014363097124582818, 0.003305642580192897, 0.04694437412845512, 0.04649978649291781, 0.030583785095762824, 0.02202913213911797, 0.0335344493449215, 0.015971063966712645, 0.013461606032515486, 0.03790185914465016, 0.049985605292022235, 0.048591616383243, 0.030955720783000996, 0.04655461540565856, 0.0180899674042819, 0.06445440914361708, 0.060871274195491314, 0.015025596554961898, 0.040787026706722476, 0.013265319942166249, 0.024342537639782797, 0.021897246272513465, 0.05440102199152593, 0.02331002157241587, 0.028995447341472875, 0.07808758727004451, 0.02538113836048832, 0.07737874909634553, 0.050141553980328386, 0.08962775190030375, 0.03145029565559761, 0.07431163948269622, 0.031134475908812978, 0.025295081788734085, 0.011342878795168813, 0.006989315077061615, 0.060525734067684224, 0.04247121355165878, 0.053342445528194796, 0.09385061240003956, 0.042034861361307484, 0.01775263399336367, 0.07737281957581159, 0.04104745829658162, 0.005255925277578495, 0.023836823848767147, 0.04755599957500254, 0.027104472298355355, 0.06196604065236546, 0.027723544119526784, 0.020419386057784, 0.07018486939130292, 0.034721395331284696, 0.04234513846195994, 0.0319079814794203, 0.03404022442297109, 0.05677818132924938, 0.010710965425166632, 0.07517522741709987, 0.06158098570942398, 0.0263434348087157, 0.09169831902029053, 0.051722813082197984, 0.04290199628280055, 0.03786341685260977, 0.05241578174454551, 0.006181629057297664, 0.040123180876816475, 0.08706842068462603, 0.022955949140352108, 0.055522252955744346, 0.01888960614920624, 0.07896674977194879, 0.10542503648227262, 0.014950280535906075, 0.14976919328253116, 0.025338804341792583, 0.02028363719282131, 0.005118842462017652, 0.035855622977138527, 0.02391189088924758, 0.07042421824148587, 0.03278505064607148, 0.027890187395255894, 0.012342650349432183, 0.029734356381419687, 0.030548476103332736, 0.02194997993478131, 0.05689659170926579, 0.02518862621077607, 0.04857306173371692, 0.09055465700164919, 0.02559423529272599, 0.03281705396910829, 0.03510034455346965, 0.030605465384019963, 0.0458575060380803, 0.07858100151943584, 0.030497550408566193, 0.05902556154216009, 0.012900132531931084, 0.024790465418669968, 0.039203074805799036, 0.029112547711138765, 0.02831157597322618, 0.010659896088914286, 0.05117840419012693, 0.030816821381449703, 0.03851560665474784, 0.09828181817166268, 0.0845971972411198, 0.0056019097363816635, 0.02921720298247472, 0.05106543686481253, 0.07751591713918794, 0.028697921774320068, 0.02848195201236635, 0.0538808865953357, 0.0379535892317372, 0.00519507012570337, 0.03352267840396493, 0.017576194368302822, 0.05337806478623421, 0.07493276824994434, 0.017685130155915697, 0.027284520197539564, 0.07221366939765793, 0.049005510706094005, 0.0680299636517321, 0.11267738401769631, 0.0252727311735432, 0.029910953054505012, 0.06869281356733653, 0.016502326790003047, 0.04289011042865534, 0.021880478523070776, 0.03095898814799805, 0.029367298759039373, 0.04102107039802978, 0.026198410534209786, 0.10051172391902055, 0.005014765587064528, 0.015340045004362061, 0.06357106380164623, 0.1896878899705987, 0.15007040373259975, 0.13740681712665867, 0.12724301372204097, 0.10980638525178356, 0.08509945980603657, 0.1011989507523756, 0.2613631527750723, 0.07123175918334915, 0.10127482410039633, 0.24797682349960654, 0.08720730476441883, 0.18298480449424637, 0.2153995014246433, 0.12931536582689132, 0.1243860420260218, 0.11866027023643257, 0.17589223991718986, 0.18456951865265447, 0.2372737171789331, 0.24714134333114474, 0.15288830494448064, 0.12503851911113148, 0.11511024943883381, 0.1372768886147007, 0.1602420901819583, 0.10879621405394808, 0.1036508764410692, 0.18551893141721526, 0.08173646405339241, 0.10410299089046256, 0.15026952530587875, 0.09290538247554533, 0.11571529802055129, 0.17046720360315618, 0.21943102380441082, 0.11547772649435267, 0.11253498359433106, 0.19425867696202573, 0.14625300292766866, 0.14023290015757084, 0.18590841051791945, 0.11856980291345429, 0.13888176620727585, 0.13502155640913596, 0.1735393081100718, 0.10255127979983246, 0.21757134536821998, 0.15405082804781778, 0.11603065811458135, 0.11540240472963742, 0.08156171939786404, 0.07554753848742093, 0.15747249847458256, 0.20306899452642088, 0.11588356157224025, 0.19497028071313136, 0.10946293271357015, 0.08654848447129612, 0.14082346201664017, 0.10580348391686717, 0.1574011144017981, 0.06516284129071621, 0.14457864116036123, 0.17141598817561904, 0.14886001545575359, 0.08829679670593432, 0.06454221048061887, 0.14435091386398963, 0.1938768893840813, 0.1610809564590454, 0.18187820580938172, 0.18492237875057807, 0.08248483236398428, 0.1458969099387046, 0.2095788419847527, 0.16834474168717864, 0.14765931053027032, 0.12609541401146881, 0.17000364380017405, 0.15371617019897507, 0.17454718870501365, 0.10036256660016314, 0.1619599963868818, 0.13354516708322112, 0.1269216015334091, 0.10965509054761742, 0.1326623120375218, 0.13193164801886006, 0.12753510772581064, 0.2979070482955825, 0.24176476973920102, 0.21477693241209755, 0.20313319269447558, 0.13557887005229152, 0.18739455980398964, 0.09469742300890147, 0.15630985279717755, 0.19939330466572316, 0.11935344957295926, 0.2043020436840673, 0.14898652721556926, 0.16509683532339914, 0.11640971075863608, 0.20850576730745457, 0.12711358316723378, 0.11941586275615039, 0.26083075231121433, 0.13457978414672037, 0.11533410799118782, 0.08021652262898223, 0.27571329726807536, 0.15254397906603354, 0.08710121690866449, 0.10908560376734504, 0.13207101473404517, 0.3327410968561327, 0.21207794336782348, 0.12604400185087036, 0.14803486215251108, 0.12994816977410548, 0.1992285651184859, 0.10422568753241532, 0.2266175414045011, 0.10174508717271591, 0.1911387838903935, 0.14021972344527323, 0.14447111305930924, 0.10837318030216041, 0.12660663214422044, 0.1871268120744536, 0.15265382075261685, 0.12572294206268367, 0.12394580193945479, 0.13155628025772112, 0.1302294466163843, 0.14838798272032894, 0.18927628625064127, 0.15449065444690568, 0.07302828133106232, 0.0717682735393605, 0.15377082291149324, 0.21369189144142214, 0.11401596944779159, 0.11531982045139998, 0.11152694212092508, 0.0836243881513515, 0.11175502181774187, 0.18277808332875853, 0.15840893370970605, 0.16919416465586232, 0.07229622303237838, 0.14394856448615753, 0.17240831718569802, 0.13710859441949477, 0.18075551927810718, 0.1608744497981764, 0.10485993172492712, 0.16551504272126383, 0.14364698631388528, 0.08204504426929259, 0.13396642351102445, 0.0949315088350446, 0.1314331852500477, 0.12620490329760697, 0.12994288376742794, 0.18152416593605475, 0.09921381775770458, 0.14669696620154768, 0.17375773509904263, 0.17636146877081166, 0.1320452895015478, 0.12620445130573166, 0.08642483788031725, 0.07644946146155558, 0.1382360919829338], [0.03943282074385113, 0.043032311669160286, 0.058939533698703014, 0.03381562276533054, 0.08118693386354754, 0.10178392016959768, 0.06180981234196694, 0.020213065173236594, 0.02560808616239698, 0.04337242789446347, 0.01387010996920928, 0.02867048050487234, 0.03489748064068056, 0.032409445397676, 0.016324783998331236, 0.050054472765975425, 0.044939269221598105, 0.008123712219868698, 0.018479848701146342, 0.059620884637678825, 0.07099059470478566, 0.026978799404816765, 0.0474859063603705, 0.036767076085051226, 0.03767681315601353, 0.11770436104627387, 0.050543834410247304, 0.005212622636463494, 0.017132916743116035, 0.0743968284598762, 0.018243093058587085, 0.030759799542025696, 0.002890737260684311, 0.020960977661513516, 0.013753227934601807, 0.07938003888533962, 0.03195798403823809, 0.09643692523241044, 0.04286248529810579, 0.014320854078828087, 0.05394187485498767, 0.034312120518617095, 0.059648436989875576, 0.09128446300183574, 0.05257333155661341, 0.03664587331455081, 0.01967242926419262, 0.05478117397175201, 0.004518355455084314, 0.025383833074761976, 0.005190355333334376, 0.060225986845551006, 0.03988079065757413, 0.03695862104875907, 0.017708049591390357, 0.006248163793521423, 0.04579837554164472, 0.027206235587777152, 0.06933209095751086, 0.022530280046104904, 0.025502256861317064, 0.028806687107369788, 0.06002436016475963, 0.029762751430333145, 0.07036692252562893, 0.05254593242200152, 0.020425263867383043, 0.022343333525162552, 0.0858177361829627, 0.0876031653775323, 0.09829257404611957, 0.0709795783604345, 0.05095600886570831, 0.017486338000444156, 0.04052087244006895, 0.05272093754742415, 0.052084774304662025, 0.03576580682889589, 0.04379782502749755, 0.08450759559749596, 0.0636605083972456, 0.029063880060529037, 0.011067960482661524, 0.060748627349253626, 0.019025469927357572, 0.0753504317253828, 0.055992791819716656, 0.01447870649562608, 0.033742809938567306, 0.024697784101590518, 0.030399414545465863, 0.03162048591841613, 0.07091999970256321, 0.07019498175190342, 0.009737068490545836, 0.03917065779528311, 0.0672078363957905, 0.0403201267603905, 0.018873987531649972, 0.002811115348689078, 0.09589704775041151, 0.02816345095784674, 0.029153385943162347, 0.037163377198721134, 0.05994262241367852, 0.06691880674371797, 0.05855913657034117, 0.01391833616165264, 0.039421739282026406, 0.033761069644242525, 0.03084579482674599, 0.05048361223851962, 0.04124063119712857, 0.030888119269342675, 0.03402108371618294, 0.058560515528604876, 0.013254504695895218, 0.03129505942906103, 0.039021308954444625, 0.025959632419530424, 0.046511963460474245, 0.029342362597104044, 0.0024017505206903743, 0.0613608158704254, 0.04763173502719691, 0.01787770359266189, 0.06945880190018686, 0.03178450151256496, 0.04825216282399432, 0.02233803219672653, 0.017844365361417015, 0.018906936973273274, 0.018126356580685225, 0.036458181773102095, 0.041134880420060894, 0.05940100974253109, 0.033664917948866085, 0.08463956190333252, 0.021499529811403444, 0.015528690325276507, 0.015250895352613543, 0.11596328834252012, 0.050757316301666924, 0.006605230671759214, 0.03417080794010432, 0.04998540610916192, 0.14804935653603848, 0.03464213204419902, 0.0714591340792756, 0.03300665306948847, 0.06349616338528934, 0.00939107924369314, 0.05549482700805511, 0.07781605506616254, 0.06946348269740421, 0.06748153662849819, 0.00540682353124383, 0.021967848935615153, 0.04714407409811693, 0.02201069240278054, 0.03122325209269841, 0.04930940629433721, 0.01707010519420428, 0.05335719272073719, 0.007313088731720083, 0.01706822636356998, 0.050280748325730526, 0.027026926963439873, 0.024123415426020662, 0.08504621669529908, 0.02493930098059918, 0.044948358854819695, 0.06786245086620893, 0.01717081511273019, 0.07924038105674329, 0.021372137050474846, 0.021184715555019436, 0.035249325672104474, 0.03693139428393014, 0.06116184368429165, 0.06563319629358669, 0.1415420218460983, 0.05633145247796371, 0.0858374782687714, 0.038505452159311504, 0.02537007222042209, 0.015444377561159914, 0.013103900428470826, 0.024132466754846038, 0.044245021192417036, 0.03076820161133524, 0.025053610875000878, 0.05968234021096461, 0.013187184719549072, 0.036235238695817615, 0.053033417150858915, 0.03527765943398399, 0.019564407036429452, 0.023162195331326896, 0.012576269819551419, 0.024586871807133, 0.06361774536931226, 0.0660279920444854, 0.032988152046117096, 0.07365923900637897, 0.03725207868903395, 0.032764894872783654, 0.013885363737391609, 0.0015895579887118432, 0.014208834787319987, 0.04147489322349429, 0.026292723618567954, 0.04981817677617074, 0.05705940837581312, 0.06945189178710984, 0.01633257319730136, 0.04289096461669092, 0.017521654653753486, 0.0448308103237181, 0.00957828814974956, 0.030994013687896154, 0.05844975070607278, 0.03373925146015902, 0.049101658571030826, 0.03457250231276116, 0.03291117170104577, 0.0399164175764928, 0.05709018212773147, 0.08303661485232654, 0.01565062854018423, 0.046071662086873286, 0.023471907442135197, 0.05805675526179614, 0.018143857859315413, 0.10567866521136415, 0.022828960490803567, 0.024157274597054048, 0.059491323847924514, 0.027218856886329672, 0.02661647237536888, 0.03221906871805268, 0.02372052978664156, 0.06781328334322861, 0.04093786175813406, 0.0379481308552767, 0.0355821295881704, 0.03249989356845617, 0.026240890109611135, 0.006283876418526615, 0.036728423118831656, 0.06347724867443885, 0.04002849240937541, 0.036590412379272526, 0.045951853596395066, 0.03150750518656306, 0.07063198894742997, 0.04888104823147578, 0.06668203960983984, 0.017968111543826038, 0.03126324379756566, 0.032774264128097606, 0.030838442297892708, 0.08810158984194841, 0.04334816205946188, 0.04360583956323324, 0.028145223810908296, 0.017980767316335154, 0.01423764831176208, 0.04296599143755533, 0.04021128864898797, 0.07710209176425012, 0.045971526734290585, 0.0216077282393892, 0.0020167779322007614, 0.05400517286973135, 0.02374098241900004, 0.033127840518230395, 0.01674646177449294, 0.04725638641825607, 0.04570149606274021, 0.08253418374806643, 0.05393812485459832, 0.030321633638513666, 0.00787384163085071, 0.01208915472811749, 0.03949728704267933, 0.044962309315920844, 0.011455547346192743, 0.025639275517014247, 0.032812265919581536, 0.018901120450708176, 0.02228596886139243, 0.03638892742474714, 0.03947187207579132, 0.030271935599645784, 0.025778485184174874, 0.02794843880579837, 0.06335451372808988, 0.009079376261891618, 0.027331312847954613, 0.02597949899462683, 0.0818474242283452, 0.020319453718501235, 0.06544325245364059, 0.04188359347021869, 0.03567721642133209, 0.04515851592464794, 0.019577026419762163, 0.03885151705734673, 0.06580868405440161, 0.05426763459258983, 0.007440085042147868, 0.054191236474340966, 0.030624221131626158, 0.030886640719648813, 0.05157210826573353, 0.01333370382311724, 0.0407000680664374, 0.03797004096991113, 0.04132902242183205, 0.041904683870774125, 0.021569933291644822, 0.045242371908839674, 0.07198181288737444, 0.026132505905303745, 0.08434973551981872, 0.02017460181377828, 0.0018710425126388852, 0.042447947461398385, 0.016089744392722365, 0.02305539884424258, 0.05827119476312111, 0.02047236869862724, 0.028282686797601563, 0.025660973042249683, 0.06962511958854814, 0.05712918749439621, 0.04179162461490881, 0.08162155852562959, 0.03372674890523476, 0.014932998549944211, 0.0017596919919484325, 0.04394527013984419, 0.022463814257794333, 0.02363738434899959, 0.04402949384623959, 0.034126256096867785, 0.07984375956678584, 0.0845472100040605, 0.06704505037276015, 0.1084065204486251, 0.0012667760588116043, 0.1402216693086009, 0.15816377025217782, 0.1771251358572514, 0.14031672549824561, 0.19325649606124048, 0.20004011270019317, 0.15211337636555397, 0.1561159253000252, 0.1919330638502875, 0.11180439618446174, 0.1894548307022741, 0.14087491248163486, 0.15447551654952188, 0.18916655181636735, 0.11969713193754997, 0.1650305227526734, 0.13541644409058556, 0.09173476182284857, 0.0647406962009207, 0.10763317767170169, 0.19010338541721145, 0.08093722750462833, 0.08511000883675392, 0.11605557129387895, 0.13194260307617728, 0.1702776428071722, 0.11692310458109265, 0.16142943453404213, 0.14559029090789058, 0.15226374410333174, 0.15228260518802753, 0.12464707882534112, 0.0980666623781285, 0.12199649887700235, 0.13258792490007418, 0.11692750958665726, 0.1476293105271555, 0.17332760737307612, 0.12301965526515439, 0.11135553760874657, 0.1645876320018884, 0.14690620013542716, 0.1612066102003859, 0.12569695636029207, 0.1318134253303851, 0.19634303366464956, 0.15236643052870227, 0.1261553297480268, 0.1133516792868895, 0.11017438324709093, 0.12475275299361638, 0.2420072059237188, 0.11476272131286322, 0.1307720360496352, 0.12802983198555248, 0.07237247942436127, 0.2584494752508979, 0.1330664693828552, 0.15623021029656933, 0.12068766064100689, 0.11738553823482607, 0.11205473839635811, 0.12071544665002054, 0.12270783449733451, 0.14322050516643833, 0.1317911628153055, 0.08481481217689092, 0.12060470097968656, 0.16277851536870003, 0.19571988242528132, 0.24508145547682242, 0.1690969634200296, 0.14663168018864048, 0.12504778877501527, 0.09852160369196246, 0.11491979998085769, 0.1674526476211125, 0.13813666909212066, 0.14994288073672404, 0.2068231777558404, 0.1385154536054019, 0.38851159294286086, 0.09996738014442307, 0.0719791392405187, 0.18129554997769096, 0.14733580692160517, 0.23811981532602544, 0.12276755105103217, 0.2183247009111989, 0.13228017205913223, 0.11821235394886426, 0.09387228502741746, 0.15004702272915071, 0.17448213251848377, 0.15091778890740487, 0.149069877581731, 0.1615372231049884, 0.1298449777307049, 0.13028356306735547, 0.1098143755488338, 0.2523227023982233, 0.0776731183812503, 0.15750475077619477, 0.12763338148473732, 0.22547092228647203, 0.1647059006556388, 0.14920254868845786, 0.1063772224851193, 0.09425572735527832, 0.0831209764545483, 0.10145063361813945, 0.2621297616391413, 0.14380000471588106, 0.10115740580424186, 0.1179024713834928, 0.09582488226794428, 0.14859758437641207, 0.12247672875321682, 0.14461527548490033, 0.09744591665484252, 0.17632337887921642, 0.18405870654650275, 0.17486451764500913, 0.17998075923852383, 0.17018496149009274, 0.170640385439319, 0.1625541282156783, 0.1754422398704675, 0.10843725589614724, 0.12419020696993797, 0.15653031758002697, 0.1791365916330007, 0.09926677741591008, 0.1365743859881355, 0.14131432519324366, 0.10669796051637781, 0.12539445122163143, 0.16050577764549565, 0.09183361014771847, 0.08449707721029559, 0.11613421021930634, 0.17621306221812003, 0.08398486316324243, 0.12562008709796976, 0.07425324826110756, 0.1478243565126773, 0.19735290608819456, 0.14751995913684368, 0.1835056370304477, 0.19599794169827817, 0.16723146271561423, 0.08310036868938515, 0.16456348491051506, 0.14416273202626936, 0.15622811121565683, 0.09451464975192662, 0.11922455527969908, 0.08943203175740858, 0.14616949934392207, 0.13855962623511592, 0.08084657632054822, 0.10987591539179126, 0.2646881888710684, 0.1606793578473791, 0.13217198512246534, 0.15049771225500494, 0.09350509142443057, 0.16773662109288479, 0.20194681361317637, 0.16970945071549187, 0.14669802340288318, 0.15392489851482455, 0.16339665639304346, 0.1916008574828025, 0.3235366423764537, 0.08561515189226597], [0.0037725451599521145, 0.08227505450767857, 0.023701310555841175, 0.06442802507550487, 0.03365236176778713, 0.023319461690862815, 0.07644663459711498, 0.014429883712211685, 0.006055273866701511, 0.06745794112043035, 0.0258782853732907, 0.008774939624051894, 0.06771895493711196, 0.05671366906514572, 0.03568833618755302, 0.04895514425551219, 0.037225744416636806, 0.0028892840876529415, 0.04670920428789912, 0.035628734547044, 0.03618989778201907, 0.03650054260487518, 0.010275525837055138, 0.017774846712728182, 0.049893077192527634, 0.04280518192136961, 0.04183444509943647, 0.01942135735354837, 0.031179583165794614, 0.038843155207653204, 0.10301055717131785, 0.06541922793633516, 0.017076480960954103, 0.043855664665780725, 0.05754570566838788, 0.040115677045598146, 0.017547816556367665, 0.026343149440963904, 0.05498887956022255, 0.024220084230745995, 0.04353376218087731, 0.03467989634842642, 0.028427592328479214, 0.029035743566290028, 0.0585118574540942, 0.03774702511427384, 0.042209996721677245, 0.04864213222097005, 0.0808943419026271, 0.0674120984190414, 0.021011210046708587, 0.048046483538083495, 0.01886928375179489, 0.02448256319058278, 0.040521067792489644, 0.05286683133172412, 0.025961455708790212, 0.0043568286890794915, 0.033558152105298736, 0.030692309111116395, 0.018701991216549953, 0.03252689433734744, 0.05036010354336712, 0.04055759103427972, 0.02951869113941587, 0.02915358129558304, 0.005210643256789134, 0.02790037061898939, 0.013850817960056086, 0.04375348002800057, 0.03765288056925901, 0.028730470935002934, 0.059357836857558265, 0.038369540500664906, 0.04032106138765812, 0.016126238906215278, 0.02477337399707927, 0.039033424634967125, 0.020465659683630354, 0.04194807126036575, 0.01431344505099039, 0.05862266058102251, 0.08056264115317215, 0.02781964410396834, 0.11786236668065672, 0.0473147891311636, 0.005950578375749531, 0.04315886939425142, 0.03023931557582992, 0.06441107921061978, 0.050314873712317604, 0.041089658249890616, 0.041115490734697356, 0.04749909456398699, 0.07099002779972169, 0.018586873099388137, 0.03921609447007218, 0.04674264785623358, 0.05606327190875046, 0.020279195798080296, 0.00477586968636681, 0.05043581984336338, 0.01861129981285382, 0.04453368695272554, 0.033295931700136394, 0.04915564478705487, 0.07128111822831054, 0.06050906016401226, 0.037507036580674114, 0.05264076261570858, 0.11314122727321041, 0.033437336209200086, 0.02077517452679815, 0.05815809720285958, 0.05481079476134432, 0.08395503936035019, 0.04030895719845449, 0.02178986372816707, 0.024510795445812326, 0.006763367019894143, 0.07676474494679321, 0.011619212455116214, 0.023928955497760928, 0.0517038255929947, 0.0028333544023259874, 0.022798577443726604, 0.025712115156854835, 0.009126105710052916, 0.055908365100021326, 0.06999171564295407, 0.02579030017518709, 0.02988026931791777, 0.07320497951079762, 0.0828628967546167, 0.047167098870681184, 0.03867000784544695, 0.01626227888458919, 0.02810286489435502, 0.015552821137281436, 0.007449447115387528, 0.03447856844192551, 0.04273487420211877, 0.04054324220745795, 0.016764700412750244, 0.011112602341229157, 0.08828059394633578, 0.020337862811321696, 0.03041652320403486, 0.04063721055225019, 0.04407111923360536, 0.09991645828009614, 0.02154955535285896, 0.04351481299607023, 0.03145214001227531, 0.03484251766255306, 0.08842818078494842, 0.0291542363007583, 0.05647140525041088, 0.06473894185957409, 0.03736977660728078, 0.022195007411702987, 0.031420025606489474, 0.02341239581695728, 0.07664014840678823, 0.03230979651092522, 0.0653476293589319, 0.10513586127349447, 0.03994904143074828, 0.06754271641013122, 0.01472443781582819, 0.03391769632036167, 0.033577763956160314, 0.005100734058707472, 0.04992643649119043, 0.11481149813100217, 0.026800277935821685, 0.023097319175459208, 0.046399536227146466, 0.06869883501842138, 0.029598521331565517, 0.052038866485799515, 0.031241379648206696, 0.021027713495817398, 0.09182504528472502, 0.01772460858187368, 0.024322579134135477, 0.03619737480016005, 0.01857707866527621, 0.060822535681748585, 0.0263754170643346, 0.055663044594468615, 0.03587265694213491, 0.049759023297097416, 0.04415958323666165, 0.02077217146213497, 0.055181535351420605, 0.04699097908732872, 0.01784891209324762, 0.05022264438711348, 0.027963793123020764, 0.04366570550407614, 0.03792154760430417, 0.03652275915467932, 0.020218525464916905, 0.044789372627893766, 0.031677549892675974, 0.09027174073121241, 0.06553175093065347, 0.04618960132281627, 0.018042916199192405, 0.05279872228481597, 0.044673969142980156, 0.08122868565542084, 0.009515031312231817, 0.016833719189068484, 0.0168345274118286, 0.046878268401468956, 0.03937963892014758, 0.016152485078501127, 0.04254460477480485, 0.03176694852299988, 0.04492338055804853, 0.04399519608986955, 0.023369799413147475, 0.10623185730148708, 0.0479759153489384, 0.03469343695248808, 0.00037151457828229237, 0.05684927428862261, 0.057563356334163304, 0.04783322381216192, 0.045917705227170265, 0.020773270798306313, 0.05165277349372065, 0.04006908357804341, 0.05092319348947175, 0.011729310781154181, 0.043793688152706435, 0.08493513394627841, 0.024481318297705824, 0.03651446242245936, 0.03243931133540408, 0.057133956391724854, 0.04966985449315079, 0.021428758608958414, 0.043510304568635846, 0.0560418022946725, 0.07895191064885548, 0.03500865915069177, 0.11085149771984547, 0.014345873552825184, 0.015818776221074644, 0.00719947645613443, 0.019586403335955356, 0.007356619283992558, 0.05086296748730445, 0.01613353206325443, 0.04760643880393717, 0.06218638669158663, 0.044789617776029536, 0.04312406985029098, 0.06931563538889732, 0.05684780339980799, 0.05198633200639198, 0.021943745894297477, 0.033010357104602366, 0.027309375920242844, 0.04005585707003071, 0.02656517512795906, 0.04597525758248183, 0.037703993955567, 0.03027307707065296, 0.013186910843116142, 0.03208193323394704, 0.024318285211319887, 0.009900376410974611, 0.022250516227476543, 0.048083083388665994, 0.034397504848217776, 0.05045530145927783, 0.012812269907895357, 0.024979112654804222, 0.10165933129047194, 0.016119344114896753, 0.006836565763449237, 0.025714298507439035, 0.09752991819573988, 0.04571728130442001, 0.06042220877603658, 0.04690567902739971, 0.08470378305402496, 0.06242461322296051, 0.058371992781758315, 0.004845599966844725, 0.05380471064258487, 0.04993415482702756, 0.05077154255442081, 0.041258795141813256, 0.02372659145734243, 0.017419418305038445, 0.040870235346618204, 0.01927033844103496, 0.04044527105326134, 0.045961391391052354, 0.11083087463292385, 0.1119582879266912, 0.02816547726040646, 0.08886731004402523, 0.042309040398967844, 0.07682074597405811, 0.00771887640791735, 0.043863524727883844, 0.046977139708976594, 0.02632087543456545, 0.06752074500846286, 0.01778489395585512, 0.03521261856921258, 0.04338352467804667, 0.04514528558619561, 0.025026644580066208, 0.06335256020388295, 0.021976503813939712, 0.02679379300154265, 0.11619588029721092, 0.03922969253072816, 0.05985179502937583, 0.05916127401794638, 0.02832858887080464, 0.06066618862772181, 0.03334911735427957, 0.03553803739768844, 0.029455042639446836, 0.02700577144541087, 0.024607619383342327, 0.07913469156670956, 0.024239994855898044, 0.03938505899221186, 0.049642240853920105, 0.07722116481032103, 0.04200018439141493, 0.008068708064515264, 0.04533886834378204, 0.006370262408088292, 0.05613279055743929, 0.029924721569724144, 0.034450391728070476, 0.048418832912800774, 0.00852094604558642, 0.01765034018805431, 0.04459337669334585, 0.032361986250766826, 0.06381006791226326, 0.07918731414622839, 0.17085314337765017, 0.11424213392479766, 0.17230244383456247, 0.09968217327109269, 0.12510680818870185, 0.16683908780255627, 0.1618189442782633, 0.1108917020141117, 0.20361555229511955, 0.11547890626975607, 0.15981308094436125, 0.209688178053306, 0.22376800076134745, 0.16184227931643688, 0.14235304848801705, 0.10793664042026767, 0.1264250233408905, 0.19607261994913702, 0.11848883508073708, 0.13615912036790004, 0.12405828662937689, 0.14474292105484396, 0.0903439904833513, 0.12534930566025357, 0.14982841187907806, 0.10058298541773712, 0.09238730785587142, 0.19746130752948024, 0.13222602496464408, 0.24868304931348373, 0.17127257651619374, 0.16235753473254944, 0.17256865938824995, 0.24694128713059812, 0.16221718742482125, 0.162887146636363, 0.08951411807849523, 0.13837642396890348, 0.12433368757727647, 0.14903678258340206, 0.16667257093133467, 0.16170616081405073, 0.1676387456996787, 0.1301558715321364, 0.11626740226582175, 0.10156216069815621, 0.15035054676475065, 0.20632701325080088, 0.1343579863708827, 0.0884697180722029, 0.10925847916833817, 0.13989085722113812, 0.15645422972738743, 0.10543175507336856, 0.17993199008126415, 0.07808122107939375, 0.14889240565319217, 0.1287265200047724, 0.1533404347156325, 0.0931265520592851, 0.16909685616772022, 0.17046231596219927, 0.112582151627829, 0.13479001399490143, 0.1524826767103326, 0.1066353175068094, 0.10363653527512666, 0.11815993055220574, 0.09753936405984626, 0.1108388496082156, 0.18948886032787063, 0.1401516182288047, 0.186596725196127, 0.13502218460123386, 0.05619984240301194, 0.07759535279605659, 0.1709559830206056, 0.22140330184371243, 0.18855953438868447, 0.07903171402792777, 0.20840631377312446, 0.19843820752876423, 0.07437844234969347, 0.2769882514351799, 0.18012135169438778, 0.12374755370640948, 0.1181417206422456, 0.07239523989659163, 0.1239042646522003, 0.1445059547381055, 0.15198931608709598, 0.08974745313847259, 0.21157126813646288, 0.12837415786399958, 0.13123504426931182, 0.14305878400562272, 0.13584327763847767, 0.17485970661284464, 0.09960276825774102, 0.17656961485983866, 0.17198410365850697, 0.12322553373392552, 0.12833864968870917, 0.09514789036925762, 0.14208131710127478, 0.22267730606179084, 0.11242846672933911, 0.11641308920638216, 0.12361619261003311, 0.21904503806464135, 0.1270690198326784, 0.16418753492255367, 0.12363378198877459, 0.11605503503233196, 0.21825385309996145, 0.1610327388850912, 0.10168167807522321, 0.11674285941426793, 0.0997323979954085, 0.16874065592644677, 0.15715406636797613, 0.09208201415716641, 0.0784376894514407, 0.06798004536258598, 0.106067186702163, 0.28001046829646636, 0.14701791107654572, 0.15762540962426894, 0.21985007389899225, 0.1494317315518856, 0.19253890150256697, 0.2209638125233112, 0.14819233918622618, 0.07832275328016089, 0.1168565008969557, 0.09871881004543075, 0.0787370229860948, 0.14720339628477253, 0.13855211857345798, 0.13011366008750855, 0.24560942795247803, 0.07624643283986277, 0.05480073985733813, 0.14751278855387243, 0.1359853869484317, 0.1782637416955925, 0.19956195126137427, 0.1374114749412383, 0.13258219456240056, 0.1372404534730219, 0.08386536110793391, 0.1090621155115866, 0.09527934339618492, 0.13817515734943653, 0.15856945977335976, 0.0909721672595028, 0.13751555564663104, 0.163297601224434, 0.10590034041313395, 0.0859518935002627, 0.12825230391876352, 0.09130469538391599, 0.130840371092481, 0.13372282287286175, 0.0844797712840861, 0.18408607120715803, 0.1843598710312959, 0.2047710427113118, 0.20575682933051742, 0.15195194631814957, 0.11527032351061223, 0.1183532298572602, 0.15565176794846214, 0.268342673418022, 0.13156348148420935], [0.022624997241843133, 0.07570523002575483, 0.05513212651074414, 0.031074920233579415, 0.029352541990397923, 0.021810641947893367, 0.02478257662826969, 0.05532460610171961, 0.10881642345339061, 0.07114624844924097, 0.043738296165341334, 0.04792500114549072, 0.09737336812841316, 0.01094655374125127, 0.035184997269102646, 0.013991282096192723, 0.05588910948004454, 0.013937336099784703, 0.009463017772612794, 0.019978017906748483, 0.03764485579825217, 0.012924637769409006, 0.07779212247940802, 0.013543004789690097, 0.047303401234169165, 0.013562728680910604, 0.023117260444128228, 0.051737242348251805, 0.019961541270717018, 0.052818766975354765, 0.011441795110342004, 0.0463636756514109, 0.010754445702919077, 0.05224292166531087, 0.035939793057379224, 0.057207680863117984, 0.009280271328715308, 0.09862664200726057, 0.02823535980085933, 0.07703858307532727, 0.009979874312487102, 0.04590151012845097, 0.04486801155332116, 0.05386664885126295, 0.04143680333189907, 0.03007056555830904, 0.04420398186231333, 0.04090109336820822, 0.07490486732774204, 0.045566074700365146, 0.02546007797542599, 0.07739421641153675, 0.005565505238219855, 0.009290170142306917, 0.07234227257750689, 0.01624500360189667, 0.05338172285607266, 0.02618056260079386, 0.048810208081117565, 0.050597399277913, 0.004775351619408016, 0.04673766445428614, 0.06410561697257143, 0.0294648255822399, 0.04594488219628411, 0.03259320690807316, 0.09691169290172477, 0.065053918909642, 0.002285748768988396, 0.056160905984260386, 0.029109648068345366, 0.05526639491079315, 0.040621448293208115, 0.08358312665574974, 0.025329099923011758, 0.03809264568131297, 0.03787012778282647, 0.08607601506575462, 0.0393750615448, 0.05070236864529791, 0.04803774630530708, 0.0455803124444379, 0.058822578885742736, 0.03037804835325768, 0.04093906068573556, 0.026712101215737003, 0.020071877084011515, 0.042349397910818945, 0.01690720617320509, 0.054322471166209835, 0.0419674264717727, 0.04644152550627628, 0.041970019679396384, 0.04338683417787956, 0.027557010011326884, 0.02825306217756964, 0.07081949662777685, 0.08216032518013831, 0.037701868061577125, 0.05725059327819655, 0.052994737371562, 0.012322423713011368, 0.035683276176813154, 0.028033426684898236, 0.04235554193597167, 0.04989913311756907, 0.04788295440976659, 0.045771708021000515, 0.06147836823196662, 0.05517384765910045, 0.024977040386969046, 0.08014805735118928, 0.01050115884056375, 0.10773090750820215, 0.0498629316327072, 0.03790037293407706, 0.07315135335609799, 0.0222825272113926, 0.02517434824708729, 0.03852948050705656, 0.0370576149303346, 0.02173446791036235, 0.04915179519523536, 0.04452290043475167, 0.007259261957745278, 0.04020783359244947, 0.02996352775352857, 0.03834813600406051, 0.04867582859831953, 0.0753405491911596, 0.04822705429227603, 0.026428966610241803, 0.004709230570663368, 0.03566996539912878, 0.0455630946183397, 0.03859210819486649, 0.012415685341693463, 0.048926396806153565, 0.05808600066830555, 0.010293684036080396, 0.043892325803397164, 0.01581584689237418, 0.05383768306684591, 0.021272490078943874, 0.009824391022594947, 0.06475962623352967, 0.002713720915057967, 0.05971300671057356, 0.01956843282847155, 0.034040021409671155, 0.050331700833574425, 0.05154061439116636, 0.04641357861879853, 0.03654897468344819, 0.03279910835948202, 0.03435015678405762, 0.01711795887639446, 0.03740074954205944, 0.024784357782693642, 0.016841424118366935, 0.04406312893655512, 0.02059028303671268, 0.07345917514495312, 0.06368203163747826, 0.039135712694617054, 0.013581791821296417, 0.05168106512076432, 0.0390665119724168, 0.03878007935840757, 0.028851669875063726, 0.03829835561074076, 0.02209127527631579, 0.04394534674863662, 0.019333033161538265, 0.020835733777212522, 0.03682572777653414, 0.06055683723741001, 0.08102836898497998, 0.03321829251945019, 0.019393287892002734, 0.008217541711224664, 0.05042776059839995, 0.033190357123291304, 0.010491597105658824, 0.03287788518073578, 0.03373254819082157, 0.06720214436251311, 0.06111094097216284, 0.046019832408356096, 0.06608779286785472, 0.01700437101986139, 0.02876976933029871, 0.04422529059792719, 0.007256278045280206, 0.02697854276536213, 0.035939865835732034, 0.0790359428332698, 0.051554342686769464, 0.07932375440554273, 0.012371725301378438, 0.04863920959553892, 0.028932160818048065, 0.018950153908301747, 0.03664358654209683, 0.032068116838232644, 0.036146782353640564, 0.027756432274116144, 0.03595744755359427, 0.02409570985623906, 0.039249787016982035, 0.07033359770092272, 0.01728607878659762, 0.032032438208379095, 0.060338858409874865, 0.0737971807980249, 0.05238625288550412, 0.048946744101422454, 0.038506543834603606, 0.03326431525150134, 0.02769575428007351, 0.042362796788614605, 0.019518273221629284, 0.04239074750653198, 0.062234864735435096, 0.049242894540751175, 0.024599483529586467, 0.02768714919746403, 0.09538657272294646, 0.009506421441572809, 0.00718093664956189, 0.018677685161932342, 0.03994392396341409, 0.029643119140077504, 0.04583633519829281, 0.06439353579715376, 0.060166473305153276, 0.04595295676300603, 0.03505299265886988, 0.03559128050842593, 0.09512933571973155, 0.06667741243877719, 0.036747640434412226, 0.11992146546441702, 0.0917887480388726, 0.010432345950375161, 0.027476674201147213, 0.07254365411016249, 0.016474651863738414, 0.016059436996827926, 0.05507471205125894, 0.026242117765509797, 0.08733516483898125, 0.02150793571115261, 0.03344518861042396, 0.027663172560653863, 0.06741579096283644, 0.031729546195316705, 0.06959904961648487, 0.032094546871620326, 0.04591759797486086, 0.03685224974047273, 0.02068303713214494, 0.03964747858023451, 0.010381578261243, 0.12824756949539148, 0.04484125593256566, 0.015067034250786229, 0.035663311925506404, 0.029679121442079067, 0.010098150627116763, 0.03225548470753335, 0.03875077266486422, 0.08286547847092152, 0.04541340103793529, 0.038983812780990716, 0.03327515922606953, 0.029790690656931653, 0.0965782531326817, 0.03344844831454177, 0.03728729575091312, 0.06660858709965983, 0.042361456134747115, 0.01445458813254992, 0.07872720939978477, 0.10844355313888482, 0.06426913077912985, 0.04072318859999219, 0.06710402382117125, 0.05705872272712089, 0.032467300357717666, 0.053009354329157266, 0.05405501455008503, 0.005112707534159024, 0.022716226822306073, 0.05153907838487818, 0.06763152898319306, 0.04509694543817351, 0.04853817408964519, 0.018987709453569788, 0.04008527484632308, 0.017394721545579455, 0.07388719612912786, 0.050069909437649676, 0.05342075120537512, 0.046460823261088906, 0.050787883209845716, 0.08954373503764791, 0.022140896706391248, 0.05642843920917762, 0.12356090404453779, 0.02767052125906752, 0.0414004064946165, 0.03391706812826376, 0.03405350838757811, 0.023049565084699183, 0.07865787078175815, 0.06599019326630139, 0.04913676455016098, 0.02073988468656617, 0.024406442779206464, 0.06618226683067699, 0.017039047989753947, 0.017646007960842505, 0.02583695684499558, 0.06327934135051985, 0.050124638758960276, 0.054716420389952204, 0.10912441378158909, 0.0009406705043323699, 0.10912586934864522, 0.027562682892406182, 0.038217483539014094, 0.052649496018045375, 0.059148093475209135, 0.04889142872284978, 0.011843204115247054, 0.07500155528466548, 0.08010203844957775, 0.01775703516848866, 0.053183731262481986, 0.023023623432363235, 0.009049969019308206, 0.013238143930662305, 0.025620600208640102, 0.019617508420900955, 0.04498822990083887, 0.030048622884937835, 0.018899963657942512, 0.07521597563379234, 0.09880173140235486, 0.060217602013219754, 0.06107050685151931, 0.16250692187778412, 0.10503723511412259, 0.11729167714234322, 0.1282675490684567, 0.09728509947777757, 0.11041370911463616, 0.10677685991169945, 0.12076758659414707, 0.16001938842236996, 0.11868486165880196, 0.24685649651913877, 0.12246418789389635, 0.1302817091345787, 0.1676333217971748, 0.12101460398445207, 0.10223492379150084, 0.1801081443385732, 0.11830067622565454, 0.09718952234834434, 0.1115648864558147, 0.1310809073789466, 0.1420535234313819, 0.2757077201479866, 0.1331321690832415, 0.1197661487986484, 0.09291720321221698, 0.11809689683779595, 0.11599144973461667, 0.14981607786349713, 0.12123696100447448, 0.12362727790229744, 0.11718455506789109, 0.08759594882928556, 0.17101132521225562, 0.1480767978054862, 0.06484764207515024, 0.1469964299711489, 0.1708957072227232, 0.1250915706998879, 0.17248029880706342, 0.1255053577704295, 0.23150555008361418, 0.09878388921459837, 0.13430648994061256, 0.09476150626376753, 0.21678861801422414, 0.08277399225100394, 0.1463080999711829, 0.12443373099930825, 0.11305590040020405, 0.11940332955770916, 0.15290448472144144, 0.06637014223322754, 0.09234699630929578, 0.13969476935603928, 0.15538323880924335, 0.2751819999708284, 0.16272038461700564, 0.16239556333711072, 0.12471723715744673, 0.12149397584219133, 0.1322190842080501, 0.1419173436419618, 0.16665680484185297, 0.13152568270602535, 0.3006707564476998, 0.21536625320872954, 0.15432436740206135, 0.07288565108131978, 0.1601009001775134, 0.2157288426232915, 0.13431606603966606, 0.09873984681983149, 0.15575609380199065, 0.11664902130442283, 0.22085793917217564, 0.11153984304156997, 0.1644543327030636, 0.11770855920809893, 0.10589297830818162, 0.12506576885859813, 0.10839184986487513, 0.1278229269589628, 0.11166639310578186, 0.10231106527029507, 0.07726572048399719, 0.1382982676788684, 0.14692051065785272, 0.1693282453643699, 0.15239534268696464, 0.10258442076343684, 0.1335925572822171, 0.09796746931369267, 0.09659134557530766, 0.10072269687248815, 0.15203132834886351, 0.1397211534241515, 0.24137814048557515, 0.11084914582991794, 0.2111349350983097, 0.13414648481674735, 0.2330102846627274, 0.11022661512176837, 0.15505000588393983, 0.10219968374698393, 0.09930700469281405, 0.14514675664324916, 0.1523098625963734, 0.3827369753872195, 0.1834640078126423, 0.10472681628720415, 0.23762504510100813, 0.11712653156850608, 0.14844505627068783, 0.10718072614362163, 0.11449908747548058, 0.1432620424536928, 0.1085360812383794, 0.20692946479445506, 0.170071856268952, 0.1760177097974285, 0.18320344598783603, 0.174809803645457, 0.13437582089775993, 0.0909587607208279, 0.19442294153474993, 0.13282931920501495, 0.15874605836166492, 0.1372249172099175, 0.14604519391732831, 0.14641748200501167, 0.17241928756477373, 0.14605706828015466, 0.20017670617709238, 0.22154495150091189, 0.06174917648276014, 0.11228527723541183, 0.1382131859539978, 0.13027243947069492, 0.12295658324634838, 0.1203736182182066, 0.12879975801033358, 0.10234503360885767, 0.07982423198559592, 0.12642333028657785, 0.18126987071046907, 0.06041180147158523, 0.1137615439872588, 0.2459876455606953, 0.20293914262325535, 0.16340477692504085, 0.2164612533224206, 0.14814309505445344, 0.12904893576858506, 0.12694129765394235, 0.10487369832492645, 0.09839804903153451, 0.12250617717302616, 0.19523870260004075, 0.0831494136382976, 0.1619628768774771, 0.22209523245692256, 0.13026335366791295, 0.07715017910325721, 0.11617624546371161, 0.14005907480755161, 0.24237065335675595, 0.0879679841079539, 0.118539756945064, 0.10650258511304857, 0.15351185454956948, 0.09774957092538958, 0.2954641777661539, 0.10460567480373768, 0.21334972593092152, 0.13011824129329574], [0.06295768401375221, 0.03900413709362188, 0.03661432198338932, 0.06617073720741658, 0.06500639081481965, 0.06427306847106065, 0.04371752752171409, 0.021825218685872613, 0.04423587410260112, 0.03354720853930039, 0.032002152837512475, 0.0216514335554694, 0.04049559536900732, 0.023246533950910937, 0.04010086856602181, 0.059357296765571645, 0.06353263300092471, 0.032738503143792196, 0.03727971914134199, 0.06389376684843052, 0.022169941014820532, 0.022635326022282246, 0.037716013875098965, 0.01664278135004063, 0.012593155355012466, 0.02757971877262237, 0.05001804145473627, 0.05008900034872275, 0.03317563674382625, 0.060203869887177026, 0.0349099257390105, 0.14414817635570804, 0.04662895274739112, 0.09082847980842476, 0.057732738374221715, 0.0389096248264034, 0.04071215310344293, 0.021643311108252215, 0.039537759467719064, 0.039181708613590854, 0.04056432494713415, 0.015391761684910426, 0.04703476101220135, 0.0529026038073484, 0.04301170390399714, 0.006735133328249739, 0.07498159103335873, 0.08265417609964648, 0.04215592240554191, 0.03855627060176865, 0.039419781927379875, 0.0574974229769601, 0.028288564607200604, 0.04573439187820881, 0.0560918967840412, 0.11552130157548575, 0.04687351865633842, 0.009343037869961513, 0.02892408625132615, 0.010529791376733733, 0.049048798504255475, 0.051974503608841094, 0.0038825865082007145, 0.03191320236862427, 0.042598901256438226, 0.030794300311695666, 0.04423369075201693, 0.07225813314078317, 0.057062258222891446, 0.07082008651547855, 0.05689592904321129, 0.040542778724263755, 0.012572100386023523, 0.11787191213619326, 0.046523048752738584, 0.034482965786610885, 0.06753949884084925, 0.07497802872451083, 0.07152625870320105, 0.0425939025327323, 0.059479748259388635, 0.03958891115842327, 0.08419267217358274, 0.04311135662118754, 0.045224529721083186, 0.05915038790854235, 0.06361910517537786, 0.020316942865329406, 0.08274219960214631, 0.024312288658092582, 0.0571669134942274, 0.022778921542809378, 0.03836982778363651, 0.079610156376035, 0.04054459052220468, 0.018821951009393222, 0.047689318026025454, 0.05543602592942696, 0.03562423761092848, 0.09640791348271793, 0.043446669475205486, 0.06551770087812217, 0.0785764279745279, 0.03523382005251704, 0.019203930109318708, 0.022425785653233048, 0.03218604649807657, 0.04830910613940609, 0.034296273989903356, 0.021658550512285966, 0.08601478931884612, 0.03676654365394385, 0.08661916374319023, 0.04969621940906491, 0.049342807727835836, 0.05602414013757821, 0.03418976861623026, 0.0999993336717448, 0.03382018098848001, 0.05552204228156517, 0.014635879009391272, 0.03140898627950059, 0.038442491223254514, 0.02626922387149065, 0.023277776931682904, 0.08103370861781221, 0.02843137871804497, 0.030279016167285944, 0.0548573422636236, 0.014320931645230421, 0.030209237048702858, 0.08440087188876445, 0.03190818640794004, 0.060772196044244116, 0.033723175105068, 0.038623782100095864, 0.024035602597700014, 0.060912585486808134, 0.0166977385825087, 0.011133887136595385, 0.02870260257153742, 0.0358799041338986, 0.04990270308729622, 0.07998108082721311, 0.012774434740534954, 0.013877175215090957, 0.011243121698498728, 0.06906379164466936, 0.14585206315161722, 0.030862091432115248, 0.014704685196310524, 0.09510816871038369, 0.050937806616627404, 0.046544755854073076, 0.020927865426206303, 0.04405164910900978, 0.044681633852662585, 0.04486958586400555, 0.028960877623889717, 0.022076813451525186, 0.059969489117183035, 0.028332599341088248, 0.09188561985689787, 0.043398448070811654, 0.1225316879009047, 0.0339694417292072, 0.03650998846898156, 0.01930308678457814, 0.1366312297121171, 0.04211107561845453, 0.04643590242091206, 0.026371036956627524, 0.0412278222070346, 0.04521450929103359, 0.01815325009726709, 0.06394168947853389, 0.03615766846304459, 0.05579042969451797, 0.014000084446442705, 0.0769964942047673, 0.07488039847944053, 0.06003795439497598, 0.02759098026510929, 0.024244916970811548, 0.03258817371041064, 0.04571133646212759, 0.011468881106514846, 0.08160305750225821, 0.026419290919758143, 0.03705910880178694, 0.014146555669515604, 0.02597939365753724, 0.035888580079641075, 0.022528307369699883, 0.04151786309516719, 0.04492993444024075, 0.0060391122843289095, 0.03721309247456732, 0.03545111323135995, 0.038395258072283, 0.04793715513040943, 0.08409058329679313, 0.04786741814666218, 0.045555912544049566, 0.07631490577853496, 0.09573027807017488, 0.016303310553813656, 0.062496495252895745, 0.022901173853766055, 0.029474700455583876, 0.04999171484321837, 0.0323476106108677, 0.06542960076682991, 0.04262288363890783, 0.009792349395161916, 0.021068850502131448, 0.07345372825981149, 0.02794012483660012, 0.06516594394680954, 0.09692313059443429, 0.059664245214193105, 0.02538135669554674, 0.04454675258227414, 0.04255865865777578, 0.02059564373696283, 0.004512004107387076, 0.006013176377652394, 0.045026810088705634, 0.019003128888265743, 0.021143507685572393, 0.040910585197590055, 0.073724425427856, 0.016137701496782324, 0.005769264995075402, 0.025733310894499865, 0.0531797782487927, 0.03206806704251757, 0.040187394366629665, 0.011559402055647826, 0.037902460523670724, 0.04732172605731795, 0.051594677215982834, 0.06430001944423684, 0.10420965331216013, 0.051442627915211266, 0.014892093285227255, 0.07287602901699082, 0.0237878842369443, 0.02651218482623658, 0.027476854231809417, 0.03413033551506458, 0.05972285094040056, 0.014611970362884384, 0.004822478954484987, 0.007365066360967655, 0.01676050608136481, 0.03437614248644921, 0.04666412767443446, 0.029976556993900772, 0.04628650378435851, 0.02282845295755373, 0.06085911638013298, 0.06124591417310219, 0.06774850294835146, 0.029143601085149476, 0.03634455944261244, 0.03402996650566498, 0.08059235004287574, 0.03019031467697313, 0.044469687967531146, 0.0832087624697916, 0.03377224686705778, 0.03532735938807169, 0.03327006857181269, 0.02749895012276548, 0.036853988760060845, 0.05418613049832564, 0.05618793739666862, 0.0548300848552777, 0.03407105180104414, 0.049527147634615826, 0.0036483749957574954, 0.07237155245797289, 0.06502268550496909, 0.04955455826054658, 0.0170736349443154, 0.015463303763329264, 0.03034493611795047, 0.0407436469780101, 0.03981120306097212, 0.0691728825650869, 0.024296218048660986, 0.008623222613917484, 0.05166440653885084, 0.015512166766359683, 0.008392078565403579, 0.033746613565111355, 0.014724893638143137, 0.048354726675296986, 0.043902376876963724, 0.05483419108655184, 0.033853758622201226, 0.02601395379902134, 0.036655388126570376, 0.04705848675521632, 0.049854102469379866, 0.04529647686849198, 0.045062256976962096, 0.03244228758698991, 0.03030716415284382, 0.044087536497822696, 0.05546585356275882, 0.040100458708982316, 0.07818526348039027, 0.025551096881709756, 0.05765026134829368, 0.09551022697480456, 0.03013267613677008, 0.0242844260402865, 0.035754652588718364, 0.03483109912204166, 0.06474854094126532, 0.006625757518885357, 0.03171212152547894, 0.030532524237529408, 0.08653693186539797, 0.005407241527967516, 0.02407058600276228, 0.07277593962968358, 0.09924819978374629, 0.017792043471408468, 0.05358925224432061, 0.0398357906529019, 0.01282885954189565, 0.037345108576118946, 0.03127143136225641, 0.05545361913860806, 0.022078422236166174, 0.13507662280913324, 0.04752895667127544, 0.04661751505468161, 0.05165462359605778, 0.0414771493524313, 0.050956725157917514, 0.08367182431562294, 0.046062583944970564, 0.03441517849663093, 0.0835997814072236, 0.030355910327465787, 0.029612303253323324, 0.026340255543829936, 0.054850164019773086, 0.30684398487210274, 0.136624947791138, 0.10652326948700414, 0.2025839076527665, 0.23188051947903252, 0.263163888406369, 0.1149436253153028, 0.12039204263278555, 0.2003356694213806, 0.19861788579052497, 0.15550749827056162, 0.14136902387103728, 0.10412396637782936, 0.08016344039670883, 0.17194987485005012, 0.15822695718417246, 0.1827851466594204, 0.1568197915630956, 0.10385725286699111, 0.12565351917498535, 0.09493026777260727, 0.10347885905855125, 0.21588838809440214, 0.1305521381718497, 0.17140823536582533, 0.28320226638067153, 0.15485895887738274, 0.14626185890407334, 0.24516810002105854, 0.1836499986388991, 0.1087629811597928, 0.24345989248925642, 0.08483225599892678, 0.1851740539554627, 0.33293850239246126, 0.19656895299351987, 0.149932278079852, 0.09865269665756533, 0.12032763762099129, 0.21124857658099747, 0.16107545594774908, 0.10774824407792861, 0.2514842038433398, 0.15045717088205202, 0.22402552887797358, 0.11032904873812392, 0.10021002317268042, 0.1522056439951543, 0.11842100565592129, 0.13295837437673924, 0.14679596008312318, 0.09635560499924807, 0.12126257898466242, 0.19081794626770482, 0.13142302692417177, 0.3493793314743427, 0.12730397133817598, 0.09643404474181515, 0.1054051488397583, 0.15012930057221843, 0.11729570676482494, 0.12491700990546135, 0.1226674923072419, 0.15874569063946126, 0.12591610347191173, 0.18397668917332927, 0.11262259340935177, 0.2269421635015357, 0.13976187865820625, 0.23669349750684154, 0.1827581037556933, 0.08703417655441069, 0.14251882991483136, 0.21163845404742226, 0.10515278415574182, 0.16885536993222852, 0.19669609294543344, 0.13384545822778057, 0.2025040200040225, 0.08324429362771973, 0.1281777175984556, 0.1521652864833032, 0.11294887791718207, 0.18884461102706773, 0.184312358258232, 0.20982484813899765, 0.16048789715334294, 0.18847526471701362, 0.16565607950812386, 0.1076382108693642, 0.134765453216049, 0.3053855986124085, 0.09363680492125212, 0.27793345071615716, 0.1723227604863144, 0.1210407735479455, 0.13942918199444973, 0.1373405658429669, 0.11961824786398681, 0.18726093874823663, 0.14632590385454317, 0.19189362564394552, 0.23487454430470545, 0.1250186391294964, 0.14895910126788003, 0.08538609160290611, 0.18846775705535568, 0.18431856357041868, 0.10823090245286304, 0.15653002646661576, 0.17566952283584303, 0.09163070410009354, 0.14353150622017924, 0.21332505789975967, 0.11857226205569123, 0.10453825140552175, 0.12829644590496056, 0.1499608225159107, 0.10681673478815826, 0.12782916291466645, 0.11169469239370478, 0.1700817388031752, 0.09109330874296928, 0.21779931781272735, 0.13869117885347337, 0.1909078390247399, 0.11680734103485463, 0.07747186708354181, 0.13834987136144794, 0.10383148933009756, 0.14136139363531144, 0.16720848007788583, 0.06738265766011131, 0.16593441457277344, 0.10194705093219396, 0.1156082908592878, 0.19170377373455033, 0.16053973066229976, 0.1046752815525378, 0.19285426925747626, 0.19459128169523132, 0.11016167384842712, 0.13280909448381395, 0.10426316455367113, 0.1064129987911832, 0.152270914686303, 0.13792178142936, 0.11850198114951772, 0.16740027785060868, 0.2591135202636642, 0.11411114055062495, 0.18048608615513773, 0.2206036286248315, 0.14149984104498742, 0.11635828327627913, 0.11829535957546004, 0.15731954135962073, 0.12062370762108796, 0.22407998240763144, 0.1124703104517633, 0.13714150555672186, 0.09653030368950098, 0.31947778597954785, 0.1758904013061716, 0.17518103453180484, 0.12829888206455978, 0.09765246162010778, 0.14026964173441933, 0.25676406649572237, 0.15487483221917384, 0.1680421676006048, 0.12805426252945779, 0.11935785457852388, 0.09277199890704886, 0.10271071035775448, 0.09491236429781684], [0.048620601319858146, 0.11047944711941866, 0.02507156223028658, 0.08226616788775691, 0.02991132460714829, 0.010994673638995136, 0.016925398846186938, 0.054344159115346215, 0.03981152481790032, 0.023765495317357204, 0.05173652222560299, 0.0318985317848743, 0.02347656334149501, 0.07618008962562008, 0.03388581174095312, 0.05120664219101591, 0.0217669423774726, 0.05275248887858564, 0.030737535111726295, 0.026402820029386112, 0.07725773784782618, 0.06072808853200367, 0.039978256193740715, 0.034609144298179496, 0.015255670953211526, 0.04300159920427588, 0.04740665456460369, 0.04853766081073592, 0.02227856653682407, 0.039448740050917676, 0.08225277667084048, 0.036026410788538, 0.04008690661360179, 0.020544319676475662, 0.028332945995873986, 0.05220808381695421, 0.03348433570335469, 0.027159594239727147, 0.030900459030583024, 0.07263680274087576, 0.02920504133667677, 0.01518720184497896, 0.013892396424536504, 0.03210302363450249, 0.02973408250498676, 0.0877989468074614, 0.04805538164932401, 0.0598917005493516, 0.03417788659252467, 0.035016749039172165, 0.028069507510912035, 0.05437220559425412, 0.021415869179632396, 0.026026973463294488, 0.04645711539553539, 0.026419955501032454, 0.029324010960877906, 0.04330534157493422, 0.0031152053317430642, 0.020545024477366, 0.06810435845005898, 0.043400033872814915, 0.03230427684743078, 0.007637752484785574, 0.04348963551643876, 0.03113614215004829, 0.0728477833552226, 0.01787562749438709, 0.021703807156412833, 0.04156122750212108, 0.030103763978507732, 0.0032239835925265067, 0.01429682190064341, 0.05947599059812004, 0.04276330755542844, 0.013987624983964188, 0.02983662911931113, 0.01168511133836282, 0.09362824005825866, 0.008306853199047188, 0.020513743192197818, 0.025021948461090366, 0.08785952137963426, 0.035805727670630144, 0.03542433462796673, 0.0833914208135778, 0.027946734260166847, 0.06109297237989884, 0.031095208157034173, 0.04589265032160667, 0.009174318495957602, 0.05367640240658676, 0.07225059483560824, 0.01910558165681939, 0.023960903279423237, 0.02999689662829042, 0.012773779735359694, 0.07126291597922964, 0.09082065805071786, 0.07127551046470482, 0.054530824098976395, 0.041275093662402326, 0.024467080553633072, 0.02064824716428355, 0.054091530130995866, 0.06067731222438236, 0.026360466858492266, 0.05538849400416498, 0.07198954271453042, 0.030259433044721524, 0.1017921402930252, 0.033713350027439096, 0.05562606169992397, 0.08633068567442317, 0.03957943848123954, 0.008616171732184388, 0.06997543627456312, 0.03855145956960417, 0.02155237072598069, 0.013285259295615458, 0.02140850132902063, 0.039292151679194746, 0.03676984166245788, 0.013828184849943125, 0.02899608702488965, 0.04190034398268308, 0.07326036766772309, 0.07716385377270561, 0.042528965089830666, 0.02971805211517119, 0.04903782429474016, 0.026607919003694292, 0.047901738885669946, 0.05499847864191379, 0.06809462913342061, 0.03983106389040909, 0.03218116268755929, 0.024284826321226936, 0.04630482094662805, 0.0169034140379799, 0.0733018896332191, 0.032975105568766594, 0.013645466176732896, 0.05141002321315389, 0.017416631660213875, 0.01676296522360175, 0.039103559984435, 0.07493950216279877, 0.06070159721158205, 0.009262744194617676, 0.027680882598243417, 0.09255708060077122, 0.01147136418899942, 0.03937263304608003, 0.014592129643255425, 0.045157857089033054, 0.04492674751447574, 0.07971175495655307, 0.03253092012938953, 0.0505839774174796, 0.051409214990393776, 0.022836814807247252, 0.05836831172928215, 0.019121520116084048, 0.04041145976272322, 0.03334101980491992, 0.0896827033871124, 0.019682809755566622, 0.04886815497171014, 0.00926727273186008, 0.027037234676461068, 0.035343125477553375, 0.0567167793821183, 0.0555122210343759, 0.05777784946164297, 0.039519515083802324, 0.028561140605879408, 0.03123081912617049, 0.018561257034420006, 0.04305981039520233, 0.013085560283563552, 0.024680711832197926, 0.11050898746977891, 0.057790321373050256, 0.07837679312233964, 0.0385609858729426, 0.03557714235578333, 0.03512503556726921, 0.04982099597973209, 0.03990969132451762, 0.01094352386351074, 0.08270233238656675, 0.0178036650252198, 0.017610229739558794, 0.013513414643614764, 0.03258535067640966, 0.021963053225209157, 0.03065156664008335, 0.0359008796212654, 0.029383819445126483, 0.021771988981673797, 0.007625416553984847, 0.03086497383793035, 0.04431941982118353, 0.02958889160635731, 0.03175706981921629, 0.04379765648815421, 0.025862538436007117, 0.057647488110007784, 0.07817050862696864, 0.05977712443939621, 0.07281573789734995, 0.04150016263367669, 0.015371429711400021, 0.09243006322292552, 0.022603636795294382, 0.0057726333879174726, 0.028587331236790747, 0.019103568760798346, 0.0507303768198096, 0.04294000956560335, 0.05495298451053039, 0.04179688763894862, 0.030919592076491927, 0.02957992646242342, 0.036532400371206385, 0.016061495858124428, 0.028131733002561717, 0.050934887821635896, 0.030727127807274945, 0.018309334766179807, 0.051660315629335186, 0.023904249162202882, 0.030967786667808413, 0.01877634004960137, 0.06015344214956126, 0.06584845933943026, 0.0399252237571824, 0.031738427069578926, 0.029502402194925857, 0.021019466559312517, 0.03486939202693682, 0.02498022156707462, 0.006841621464944535, 0.04861951347500567, 0.029875236120255246, 0.0035001951572109736, 0.0666936305201342, 0.022157520814348134, 0.03446128166791412, 0.04352661458054378, 0.015566161600872876, 0.046026639099563324, 0.016318297148832393, 0.0406045139196419, 0.0280003278561297, 0.02958241624817733, 0.02965861901400551, 0.029952940418415015, 0.019114811101087162, 0.051875069226709106, 0.012955917139357377, 0.046878992354557406, 0.098801861637302, 0.020409107073059967, 0.08723723581962048, 0.03601427212537777, 0.031713556025117155, 0.11726083444251169, 0.03808596922505287, 0.028340926716825175, 0.04390551783745328, 0.06710007080748197, 0.06765888598296912, 0.033147337455903335, 0.08706439106214432, 0.026419888468339082, 0.034780862906406966, 0.06036838726891626, 0.05121352932145519, 0.03150844172905049, 0.07612563609596222, 0.017057529860927213, 0.04858737225614248, 0.02475723060929487, 0.03265091248096959, 0.03523183205435353, 0.056517665469718564, 0.0437078288485927, 0.04328065439157429, 0.047035645843753894, 0.026489529691095796, 0.05345584952362603, 0.02407443176414217, 0.027680534028237867, 0.008498356985529105, 0.022863309958108494, 0.06204905010940087, 0.0055900492588989445, 0.035577249608092734, 0.010483929523146682, 0.02757341195378573, 0.031290694643112446, 0.05249862266223758, 0.050716487645742395, 0.015295769910388177, 0.0009732224779943335, 0.02709722319137185, 0.011398758205975737, 0.04663516955089666, 0.07419477276984723, 0.032325635378759716, 0.03215270252117226, 0.06334195754701091, 0.014623902182305052, 0.059356419594898346, 0.06763186606187975, 0.05643489349993968, 0.02092445058928382, 0.07382783963675461, 0.030523476739143653, 0.028716844146049796, 0.0058130938428333934, 0.026543333961237824, 0.03810454685721667, 0.08356484013699716, 0.03972741219425394, 0.0073693143185077905, 0.013466450581026655, 0.04480637594937317, 0.007379463547089648, 0.07374417517454394, 0.04630883141691166, 0.014495818984634696, 0.027108168672590006, 0.06746066073256154, 0.055598831104655425, 0.05138576886947117, 0.05655911848730138, 0.024544541618876883, 0.04087943606258881, 0.05325316947193877, 0.05317346568429663, 0.015211234023163637, 0.06278274017536352, 0.005291917045871097, 0.030294807154625177, 0.021294135893244418, 0.048116898509643735, 0.023334323796593857, 0.05339790646347308, 0.03066257340833545, 0.12343417011922407, 0.25369697220383153, 0.08207181138136695, 0.21428269844862724, 0.27661228612546, 0.11463365081938044, 0.2198452475450693, 0.1457269609935822, 0.10107993899333863, 0.06391648518582506, 0.14117315051055726, 0.12458644296613433, 0.1712972292255971, 0.1360678026873258, 0.08216396409777865, 0.16281098217493103, 0.08696168931501527, 0.19106298715116518, 0.10971279229007422, 0.11737440697728627, 0.11681687882951192, 0.09637732359190142, 0.07089506354062788, 0.12497910899260353, 0.12764701018891028, 0.1040825056993673, 0.1577733718459645, 0.15131112909124744, 0.12718894323634525, 0.09828486720160132, 0.1864777823850032, 0.09875407307258538, 0.09492394754723196, 0.1657452674642686, 0.18510112238507118, 0.16389418453458818, 0.15180386152238617, 0.2103605581026885, 0.14017256307265452, 0.15255337130398522, 0.0880042966755648, 0.1404757040642923, 0.09536660081076045, 0.15480743180359566, 0.1426784979600099, 0.20820647207719667, 0.14420394755659566, 0.22821033012963113, 0.11488274430796025, 0.09496197615179325, 0.17408084034198718, 0.14168921797986955, 0.12094362593826749, 0.09819910365847812, 0.1648160947426673, 0.14557241041573787, 0.11691747383484918, 0.12285516852693212, 0.10963986071968272, 0.1985751534061086, 0.19182803319586864, 0.19721090403054992, 0.16549224394463724, 0.15827289181611232, 0.15142461735635035, 0.1665917180118061, 0.2132128106970941, 0.08971510890630946, 0.10899917372772772, 0.10609682664395341, 0.08439878812961041, 0.12194223686932557, 0.10458558797836305, 0.11626826794517618, 0.10972290465067472, 0.1573610786468752, 0.14165206271554195, 0.15057019949440034, 0.12632714028680517, 0.06502552003028893, 0.08891996326706103, 0.07733425470970332, 0.17619315925384724, 0.16129336199693142, 0.0887146057380784, 0.18109581553407256, 0.13274144892009998, 0.17454368002232046, 0.10592305492008887, 0.16293864306663314, 0.10342989071843126, 0.1837407187708924, 0.20775432698428634, 0.11354052762110388, 0.18272375237316857, 0.12731153262598863, 0.18951363561134185, 0.13803683251382845, 0.1373113012842594, 0.14398810994480887, 0.19345403949339546, 0.11834209093884115, 0.11799673084169628, 0.10216546259940633, 0.10676405858248474, 0.16895018097373748, 0.27343801613296237, 0.196775903985385, 0.11952820955024612, 0.08166836649780312, 0.13511469737896997, 0.2575532136665237, 0.16292276972484204, 0.2149556300813152, 0.11385978710266853, 0.09482070953855593, 0.15626990897280557, 0.12070846758903035, 0.08704923784300204, 0.17666165266306172, 0.0760775410960759, 0.19482961164847498, 0.0929198002502803, 0.19059378894106035, 0.14680835538573805, 0.12078257893482525, 0.11739063271952253, 0.20804183978226878, 0.12677829712629318, 0.2197249104539233, 0.19660472929958375, 0.13566742981633834, 0.1186273284556885, 0.13822121455544426, 0.19269807925147397, 0.0871152516394373, 0.17032278070767082, 0.16057625773452944, 0.14692849329402372, 0.16078457236289978, 0.16456161565597982, 0.08683399777979621, 0.059624649959826664, 0.1000021605361854, 0.23116989632046994, 0.0882222333682641, 0.10942263648875299, 0.15820945973598188, 0.08408381107954249, 0.3133055381476879, 0.1381039724595124, 0.241335162953023, 0.1563993318667335, 0.10345697192655456, 0.10142645588324917, 0.11470615338053435, 0.11358640096600979, 0.18929557634457467, 0.08408600209100593, 0.1435832937638606, 0.256084117497648, 0.09015993785954292, 0.13444366564433421, 0.12668809793408842, 0.15842220235255458, 0.19243382488287267, 0.1550170181379203, 0.04178437742314512, 0.15205259494964155, 0.13306412515380692, 0.11220656936207127, 0.1411219911589738, 0.12676256934120772, 0.174226856700355, 0.15359022534422337, 0.1633364572039535], [0.04238508994721117, 0.018384792511501623, 0.061212485926526214, 0.04608640161853644, 0.11557896501354634, 0.04104796008417203, 0.015775649301377277, 0.008964913149905062, 0.03975453936765271, 0.016456876708675298, 0.0358595376864316, 0.08815379107310888, 0.019563236837125113, 0.035867926349202474, 0.020751510070817127, 0.05860750736188024, 0.11800071449890254, 0.02578374629299487, 0.02508428886592869, 0.02022217395865629, 0.022478239693408533, 0.010731512860905741, 0.048256851282090917, 0.07079174126228018, 0.027058890066860665, 0.046104508106626814, 0.02309246600845889, 0.04580861813719234, 0.07362851888061532, 0.05168831231252802, 0.047100376442915974, 0.03424302704872624, 0.01125891460105777, 0.026126574469550003, 0.023883091728954066, 0.040849026202434496, 0.06421295738208198, 0.13473744504153728, 0.09405707309563315, 0.06336863272853437, 0.05767484127934422, 0.07643982407546814, 0.03501184607645677, 0.07470530142346699, 0.018993707922016902, 0.036655920557677746, 0.02897297798265373, 0.08170985015890292, 0.024744661021677238, 0.046096276491880424, 0.028869289897322178, 0.028430760102046114, 0.004274659055931073, 0.0861298633859523, 0.06755472866878395, 0.052908495023486116, 0.06595834699128905, 0.009585345734751994, 0.029114945566341765, 0.05437320916943493, 0.03528076975095657, 0.09807846013216243, 0.0856289184922653, 0.0524602723007481, 0.03225427811905261, 0.015688521164138953, 0.0159696955421579, 0.02197931727184163, 0.03671751785722952, 0.07869765372766603, 0.030019932892173532, 0.04180008988647212, 0.02148902866118137, 0.048004341041368824, 0.011302423607107374, 0.04886289960854957, 0.047589933439608545, 0.0714018996504526, 0.050774204709957686, 0.07593062841483662, 0.032210825611987424, 0.016523662338694258, 0.06262976773864319, 0.014433553273368989, 0.03523816377104771, 0.07362847291533986, 0.01889114024027461, 0.05370421905911738, 0.013583349852612423, 0.034772930065951044, 0.04423442236598461, 0.02325167823132248, 0.03791826108710901, 0.05436059936220127, 0.08754781552500303, 0.03986607027810909, 0.07657538333366956, 0.007290279421384537, 0.015950887126006907, 0.0971379722919195, 0.03493248702838056, 0.06577501449012949, 0.014869712026519401, 0.02218053409559352, 0.0415902430822532, 0.0512431156370909, 0.08314830281080739, 0.0751396349721378, 0.05308672154863035, 0.053546079359347784, 0.011815783913217246, 0.02315381241421546, 0.021588794376340606, 0.006078057800374565, 0.03700888407747111, 0.04453716116146215, 0.07766309029032147, 0.07147232611333171, 0.06589574228611685, 0.03614430405920552, 0.050720789229437235, 0.017491587617945288, 0.05719982846189411, 0.03471782536155755, 0.06610639348265625, 0.028687677263552626, 0.027528385136036143, 0.025254471467867978, 0.054446102435430216, 0.13126708206630525, 0.013754222891293468, 0.027479882194330136, 0.049927949514840884, 0.04587600706145168, 0.002422372889404576, 0.032480442596058694, 0.01885379919962537, 0.053209295616515224, 0.05822529077469822, 0.047436604772003434, 0.054683195156676155, 0.06344154897716738, 0.0427021277737954, 0.018587985842098153, 0.07580209418290085, 0.03736128835307975, 0.07166709630720078, 0.004017998533879197, 0.05128052754087314, 0.04071241357333718, 0.05408694892520866, 0.016244168566059203, 0.03545373325206099, 0.008763771977335697, 0.060136396693246025, 0.004851626684784048, 0.052686942395784205, 0.044184121032876354, 0.013774220658946904, 0.04749607617756532, 0.03968368389553601, 0.016229645454234654, 0.06172189226133689, 0.09408617677587656, 0.030066700644731045, 0.03262413387757636, 0.008476579978671527, 0.09393266807760924, 0.02961409781428595, 0.04349693250391753, 0.015132770340348926, 0.025741316513308597, 0.038125920710304094, 0.04660865907827693, 0.053728427437524644, 0.02730617558793916, 0.031211381560311686, 0.01832494763807664, 0.023105836157957395, 0.036213650338111386, 0.03554675930870637, 0.03812460686951395, 0.013800287758180452, 0.021727345207886353, 0.030231440191968318, 0.020503169263622934, 0.038867880695409356, 0.033635124789490815, 0.040151005190226345, 0.031498842647359256, 0.024127866396860733, 0.0078072379467137645, 0.07193050031820614, 0.01079540267857092, 0.015264141012824353, 0.03194782188192251, 0.01503444870092696, 0.053348486131477746, 0.061012694026313485, 0.017744067215150403, 0.02379572131640969, 0.059723383371507933, 0.07613738788472069, 0.015433055739248953, 0.09006184796171804, 0.08335763633611702, 0.049745995971945026, 0.04408443001128974, 0.07104579133973007, 0.033030053225135615, 0.047372781987031626, 0.03024019657694284, 0.03300953356008376, 0.03326721489429474, 0.028143147712633498, 0.011116798587834403, 0.028273049411514116, 0.030785203017594836, 0.022257608286435568, 0.031393381068482995, 0.05290844905821066, 0.02111668694734333, 0.07445259199988458, 0.037049808494386174, 0.0213890235435458, 0.02716168182932081, 0.060212848437649596, 0.04762481342280104, 0.016295797146496274, 0.011953579190547669, 0.04504072607585019, 0.045846144954163226, 0.015178553669923737, 0.0406815440604283, 0.009403693838976324, 0.06451499903754843, 0.04750850212369715, 0.024925568854556452, 0.04456655978555641, 0.08412922477169384, 0.009095252476512425, 0.015023792417900217, 0.04475794387080016, 0.01226391087496473, 0.04486635297296509, 0.10853194436358829, 0.06355685670109046, 0.03769402715167211, 0.011282607785335953, 0.01727114581773358, 0.007864704117133853, 0.020610791210445668, 0.02598633632935103, 0.0165127704836308, 0.017265254601595864, 0.018112637861181172, 0.05882516826292681, 0.024543622313367746, 0.05934202097236149, 0.03561826595555871, 0.013729724357084883, 0.07646936442582838, 0.08462609407762367, 0.02662427306565787, 0.028798214174927245, 0.02750048229861404, 0.04485230675087341, 0.013795126240790613, 0.052530327210983926, 0.021029314619579145, 0.060611968754880854, 0.04250461498515741, 0.04878452881389568, 0.032087044955621806, 0.04225192854421274, 0.01329397546097396, 0.04459721096340687, 0.013180168311772569, 0.016450887816327236, 0.016335467094435327, 0.02681184011781889, 0.02325310507008145, 0.030815746943135897, 0.03245408534102383, 0.026982955431805986, 0.051266347253394705, 0.05056356500473715, 0.018171971370916695, 0.041458881985876835, 0.0767895508737814, 0.025234989851953524, 0.09413373551421589, 0.03962868261301229, 0.08446802715620688, 0.11722252238541843, 0.04793877923680891, 0.01381904733622627, 0.027304679801267003, 0.0327293943583725, 0.048349092098613905, 0.08173978887498379, 0.025066597980537245, 0.030924056453870672, 0.04419217261696055, 0.032692511055258014, 0.01734852452852553, 0.03808853178915959, 0.050624591568785335, 0.036489537751842896, 0.02848679177282799, 0.02305453316488814, 0.03603715517167603, 0.0794918570787676, 0.037230984458038886, 0.059663436991432985, 0.03225342776145666, 0.02386343582803684, 0.0526823228856008, 0.07778222462342632, 0.08368663279519928, 0.0555313004541301, 0.04518746255686687, 0.06337750019625792, 0.0515038957969556, 0.04325317098729072, 0.04166405948419725, 0.07230678738485422, 0.028167036249332374, 0.04272003890946508, 0.005121446682155253, 0.028968618942364573, 0.05663137590031951, 0.05096915110404934, 0.002702794107232964, 0.02005095139235979, 0.04180650587283796, 0.08638077250291264, 0.08961017018244152, 0.028762219533804926, 0.04385787099900265, 0.04711973165432292, 0.019057164900004864, 0.0754388612544825, 0.05325448714316853, 0.007623501334174146, 0.07739960967052369, 0.030286219308993993, 0.025298119327353857, 0.045124248811794866, 0.016243852554790435, 0.05645787230722847, 0.016070846918850176, 0.15437491388330538, 0.0904162785398864, 0.12856855267478576, 0.1141598484208507, 0.18084870621321664, 0.18856311968017012, 0.18397918661996243, 0.23279161252562078, 0.07263599068767602, 0.0663680967784697, 0.10982914572401394, 0.27944800654245966, 0.09923453277517712, 0.10463575907652417, 0.13385632135454686, 0.1677451093470858, 0.16704873542391485, 0.09981983161020665, 0.07117600330422003, 0.15287096071387493, 0.15226492387873514, 0.1875472870925742, 0.15284410167124965, 0.1538503275162751, 0.08672801717635124, 0.19747074573270737, 0.13443663295718933, 0.1262806464106806, 0.14049001458671787, 0.14380883004876877, 0.1352397842152465, 0.13317821096749077, 0.12871622378307004, 0.15550198243750682, 0.07651437209137986, 0.15250870837799965, 0.2313213212595832, 0.2588172280980695, 0.19757435146358707, 0.23926709327966939, 0.1416556173635106, 0.15046786546947497, 0.12189334513799799, 0.13154837423034255, 0.09867580953024088, 0.16416755534948843, 0.1478867467132307, 0.2402189268820709, 0.19881807988689792, 0.14201141923906344, 0.11652126082129056, 0.14950991848543768, 0.10176718880933139, 0.11674939414426205, 0.1270174238109781, 0.1868809591377935, 0.10166096305775066, 0.09471695059009137, 0.09389542854360997, 0.13279291470685314, 0.11103059375478376, 0.2807415613243657, 0.11019895934770185, 0.2578799348444708, 0.08527672489083583, 0.11823697601475062, 0.18428197521115505, 0.11013434749216804, 0.15555706415926257, 0.1923039883014656, 0.11411520847750288, 0.10625395893810258, 0.08319942385799463, 0.14378650624665523, 0.09741372564026425, 0.17082654480491916, 0.17767664255394092, 0.12671492633319673, 0.09952991329614194, 0.15828848936625067, 0.15801240660009847, 0.1603073761948655, 0.14320037237578823, 0.15892231987128336, 0.1377056680259205, 0.16703794890594098, 0.20992624753665542, 0.07728574602233787, 0.16119841305959612, 0.1695213914518395, 0.1299394210500102, 0.07825091721550112, 0.12720472464758542, 0.19007666427041256, 0.16421286178933037, 0.1649638884250195, 0.10475005939482682, 0.06392665117258026, 0.09642246149240002, 0.19298671053782587, 0.17556315918843593, 0.07374376148706482, 0.1380046108557332, 0.14107984100137988, 0.11092937055734858, 0.14726500507564316, 0.21450230521300148, 0.15149022512618573, 0.20178072575119235, 0.17820168857372579, 0.1701066519824728, 0.07222979554846402, 0.09801713479382378, 0.1383974913868212, 0.1132309974561776, 0.28307855850265873, 0.1143763525291316, 0.20629053214384666, 0.1893613373319949, 0.13807781821777745, 0.1012079905898821, 0.10391520741846293, 0.14213946317472767, 0.16333083411858929, 0.13790733301110808, 0.09728177465618619, 0.18686260367112775, 0.1639749761670828, 0.11823256334830677, 0.18288093829347243, 0.08425047350746971, 0.13287603524663757, 0.16224196270829247, 0.19518386602642077, 0.16022010345853147, 0.10629489101589688, 0.11508545117272485, 0.13515844099944638, 0.17608946159241662, 0.10963144907427412, 0.15425952572015025, 0.20577190594086725, 0.33436382429734357, 0.14054457536868512, 0.17721933402842094, 0.1188133346037038, 0.18930429442515298, 0.07166466014760156, 0.18100443656646437, 0.15703385185089805, 0.13996777244873587, 0.09972875141688894, 0.18040437521713396, 0.10357952301180172, 0.2043354451175659, 0.1570310173255782, 0.19489353402487694, 0.09202850291565542, 0.10520156863476, 0.15330042960422655, 0.2157542920641361, 0.2257986700222377, 0.12254484929144384, 0.19310545416608935, 0.1323112905506165, 0.13961685821413994, 0.14767702248307968, 0.13556698036770667, 0.11057186796660386, 0.24876595534864934, 0.07885808786076885, 0.1645069169781862, 0.1525478554709304, 0.2430005002045824, 0.1757605187594891, 0.1494026968195554], [0.07511902720697465, 0.02486752620297334, 0.08089261820479747, 0.03730433737678874, 0.015230829594656827, 0.04568788268032574, 0.024900372222726865, 0.006643462768425384, 0.04178179187640067, 0.02677396281562265, 0.07124118972569704, 0.04180557507600996, 0.0871061045496214, 0.050296173506085916, 0.022206251667211616, 0.048129680686660355, 0.053404648037206744, 0.06826679207264416, 0.0833228406225962, 0.03131865493712887, 0.05016522992762828, 0.0469095784149343, 0.024556425557802283, 0.03117058546312394, 0.03149714767782679, 0.02998974328229745, 0.08727521079802707, 0.034784245184592666, 0.048161013682763425, 0.013999698529650849, 0.060288530263689265, 0.025503216386442224, 0.11412133718089712, 0.005612219364622669, 0.03559305017153102, 0.039676344773221406, 0.04229633483074365, 0.07053943786529765, 0.03225986290002062, 0.03855626294088941, 0.03366856069694604, 0.03837144422915675, 0.009418207374701818, 0.03565079787926328, 0.031909743481646144, 0.03400514908735791, 0.055766025963690014, 0.05965224827729887, 0.013417281142826523, 0.014530561072000814, 0.09950551339575361, 0.07374216802418232, 0.05786000473064281, 0.02848575372369059, 0.05857143611196549, 0.06721846203530027, 0.034934612922370434, 0.0183867039008727, 0.05791846490014465, 0.028491648770267927, 0.018121656631269766, 0.025412318139006535, 0.019301433949881507, 0.10023295984513338, 0.06661537463866896, 0.04317021898684963, 0.012622060810005473, 0.056816619790850155, 0.016781303453289213, 0.03790712599912959, 0.013708075669954621, 0.04046243908364446, 0.04685404087086359, 0.032211266112543886, 0.04824452492738924, 0.05565164520615532, 0.06406188484341388, 0.08469903330889442, 0.04918797752789913, 0.05308128232436796, 0.0748042416788878, 0.08754729458521451, 0.018478285881780812, 0.04247568367469696, 0.015221874026821987, 0.060087424522686395, 0.07954722225305536, 0.04770159841545167, 0.04263459712327008, 0.03132076550936026, 0.056890861371592175, 0.058250257580150525, 0.04014709048093327, 0.07172713461782664, 0.0497963011354929, 0.041336736927229556, 0.03317062652880146, 0.06482904912122796, 0.04487367294308159, 0.019026965714029728, 0.027253087610006336, 0.04865978671718509, 0.01892768646470241, 0.07250121283915735, 0.01653614957186003, 0.017133901166098735, 0.008901362326146375, 0.058000532069033196, 0.08831985595245516, 0.04904852271260274, 0.01919570998589118, 0.03178855603290422, 0.04024965433223594, 0.015639939698420705, 0.05241719900720543, 0.051156367670985005, 0.09502181527955879, 0.04958841551636016, 0.039470244138952226, 0.0141808639595946, 0.0248383823031139, 0.040930982288574023, 0.03131036203534853, 0.012846727585119587, 0.04808695213268361, 0.00946569812273787, 0.007405868203814833, 0.03204746693823367, 0.03244059070223763, 0.08042574124110323, 0.05719618571381416, 0.040989710588849364, 0.020137429312472383, 0.02167483945677598, 0.02904017155449237, 0.02666935159434234, 0.04462467521549233, 0.019953208149320657, 0.027041890575820883, 0.05514264489794451, 0.011476854166586795, 0.03865227290999986, 0.044035994102277105, 0.007564888904697352, 0.06884456792425725, 0.04762607363743648, 0.01732320532262806, 0.0098555775043825, 0.04847998588135646, 0.11372117115364921, 0.021737863595086723, 0.029698601142773708, 0.03344374070424707, 0.015443115431304662, 0.037253411682022196, 0.06958074777597381, 0.04545042223687615, 0.029081411982676195, 0.06110993356654241, 0.027537210468923854, 0.06028489900692817, 0.03860283342580642, 0.006807814962455944, 0.03385735540500572, 0.008056885412623806, 0.047284383101448904, 0.03492327482109109, 0.031764508532961054, 0.03161434763892284, 0.034713945126221064, 0.035582355584108064, 0.03439071730920865, 0.04529795541818585, 0.05106329947950379, 0.02852569180240314, 0.02658000275973351, 0.056481847028818824, 0.02490563141632705, 0.018188729544260332, 0.041342670278203104, 0.014948974355995176, 0.03537472277399033, 0.03434089861149269, 0.07303557448810147, 0.07308153210267906, 0.03457940476495893, 0.06585477956480558, 0.018307314209279515, 0.041693105707846345, 0.07937759506486117, 0.028262743613712733, 0.05994266454851436, 0.08253669651645808, 0.011732162543452315, 0.08537750375727493, 0.0342791366030372, 0.0019381743186386304, 0.04123208548633322, 0.05863848795753814, 0.04848198537083884, 0.022005117197911588, 0.05094797260338261, 0.11204245034605266, 0.008999813242905564, 0.04597453362939339, 0.007045234228679611, 0.021278002081559073, 0.0236799098896764, 0.02181359904728109, 0.007994716898763493, 0.03429410213063802, 0.021412898673706, 0.061868605759715846, 0.028066749594384627, 0.02230199159032876, 0.03781895693992415, 0.02193913404499331, 0.028479538835404862, 0.013252380717125152, 0.08314371394414095, 0.015504316280355618, 0.07453686167155543, 0.055899865354501435, 0.016716406230003606, 0.01644757448605472, 0.04188045250972913, 0.035609099713544694, 0.05647087281930351, 0.024626547500731486, 0.10087268156630379, 0.020678143745528597, 0.04669600459296377, 0.05128051221911466, 0.06801590593832155, 0.07995202311224515, 0.018195796705361818, 0.062342258771100355, 0.02905022645849855, 0.047361957164661544, 0.012299177732558982, 0.04590326063935796, 0.09043786689759263, 0.045079087928658536, 0.03391725581980521, 0.03306869853047594, 0.030155042073719447, 0.03672183476268284, 0.0386544639214633, 0.0853094904713573, 0.037529004151902856, 0.06864170018102854, 0.06559914368535243, 0.025557032147903117, 0.032836424502273726, 0.07363106229252393, 0.020068412451373956, 0.011520092169033184, 0.052862951096387646, 0.035259778941831285, 0.027702706527986357, 0.03004819770613986, 0.023199994109510895, 0.03262850057874476, 0.06739827053200814, 0.06523187347357312, 0.012699092866011686, 0.09631322501527687, 0.019612377547028086, 0.058261725916377, 0.06376158220753556, 0.01738761033442232, 0.04052655681246712, 0.08648540479161086, 0.040649877816078164, 0.05024109178433015, 0.009253109681359943, 0.05642083195608951, 0.035403474053788575, 0.07811376449441718, 0.036710772453056234, 0.019899934395066193, 0.021241218369874745, 0.008198705524386419, 0.028976090214846116, 0.027101988258260875, 0.032102581218726216, 0.05597537481075814, 0.03419966647221196, 0.048709911850070765, 0.017757942982678934, 0.07086569939049021, 0.030878472307156173, 0.053558279309541955, 0.0736558605586329, 0.052828998079583536, 0.04061369165297478, 0.023382319205050028, 0.010781778762447498, 0.019614560897612286, 0.00599119252705526, 0.057053157098350994, 0.08505635969941655, 0.04429028932786277, 0.002713077880006524, 0.019196025997159943, 0.03715364788208277, 0.021800332319652362, 0.030189345575748917, 0.02445491124695588, 0.07621607277542353, 0.05312683008190605, 0.08851448825049786, 0.04108962760637364, 0.09900336574402549, 0.011109327315352859, 0.053921462442245216, 0.021280275447474375, 0.04351566718410581, 0.04281861527312187, 0.021001212599296725, 0.024633564866117896, 0.07934591732919216, 0.05085285512670394, 0.0479736055938467, 0.06592599509824669, 0.024924166913655017, 0.051658055669958555, 0.04404278930216547, 0.044816212518320936, 0.021651142442058173, 0.05566269602446307, 0.06628593384859062, 0.010997386547856996, 0.08525031784008588, 0.055975543350101485, 0.08664016987407401, 0.11703643196773146, 0.012673923047259452, 0.13052229138631977, 0.01910972236205013, 0.06236232644427688, 0.0517094103739627, 0.07704026080788144, 0.09647886088538556, 0.014919288448929308, 0.025508822234828147, 0.03304040690343226, 0.06493548171654825, 0.02685732467310323, 0.028732644709488078, 0.008497069000206407, 0.03084240871812067, 0.14009086745640925, 0.1171550453610478, 0.17035682565502583, 0.0976424258682997, 0.1238523468735718, 0.1358512449528902, 0.06744982824931223, 0.184624876166063, 0.17052343445679835, 0.07287284975210506, 0.11652439412090088, 0.0931413681997407, 0.16711081918929854, 0.16846034435495255, 0.10107417801214803, 0.12141585785655246, 0.20417570046359496, 0.11651054325122988, 0.1820317604729245, 0.10861188563848696, 0.11262411792432109, 0.2323513571172953, 0.13938421263329445, 0.12093902941072181, 0.0975231919437647, 0.16328117629933744, 0.1919997901084923, 0.2781743087595509, 0.19504001003599938, 0.21695775490614677, 0.163969965952058, 0.11051163813399692, 0.18634180177844342, 0.08093741902660939, 0.11136014179717149, 0.09688793651519284, 0.1304270513355732, 0.11824044639304762, 0.13328264407332868, 0.14241856432730152, 0.12483355994786947, 0.13532884959732333, 0.1050211089633165, 0.1909143048068208, 0.2174576119549813, 0.11265110720189349, 0.19836025042158945, 0.1861202491507415, 0.1032369667964597, 0.10141776844618783, 0.2618049097157294, 0.2017595970462407, 0.14456370244583777, 0.23457877307889924, 0.12473029129567648, 0.1962528191506863, 0.09652344720257867, 0.18237349697418753, 0.1522243671840237, 0.08793901066265761, 0.14350391173314664, 0.06634484600996779, 0.13032738329662433, 0.21468356161588625, 0.15076633332477463, 0.22519707649705872, 0.10793203623184275, 0.10072753088729036, 0.06482000162284221, 0.17587799068179824, 0.1701870299274883, 0.15124667045329848, 0.19406143996504047, 0.14015636797393524, 0.13152411988665982, 0.15055454065722806, 0.1448757300573972, 0.1302075211799914, 0.16747802045316468, 0.18168066237722674, 0.14556107231445853, 0.17311929274470578, 0.10013897617858264, 0.12839192344296363, 0.1685478162741469, 0.1403561637045876, 0.16387513958879057, 0.15949022084955247, 0.17726105517677723, 0.11077970762046115, 0.34628608294071694, 0.09696646052743159, 0.09948866712229867, 0.15282473496852383, 0.12972962021106674, 0.10808115524630393, 0.22038363881649511, 0.08401917624137095, 0.10092988535160981, 0.08870021860686042, 0.13416989646371336, 0.1031188283776564, 0.22022783185445496, 0.10090949209106546, 0.11434157979824852, 0.1396935742588774, 0.10730827212213509, 0.1703825049222477, 0.15407351957213494, 0.19297836017945122, 0.09574514783678517, 0.0893778233758865, 0.2055891480056509, 0.11241434006801537, 0.1774727559137729, 0.12183170570361039, 0.1737543489904173, 0.21018512396802827, 0.08188118572316824, 0.12158107237830279, 0.06491655934481852, 0.13618751158637388, 0.09350679980050172, 0.11080881130070457, 0.12025483628554691, 0.18663741978666476, 0.18496220000088218, 0.13969130663862153, 0.10368830749704953, 0.2303125213591322, 0.13597322147219412, 0.1355340385869626, 0.21912347014632919, 0.10906196229400174, 0.14780301330310686, 0.14824432591276784, 0.12366345257408197, 0.1926557605545367, 0.13687525935951741, 0.14157572971476665, 0.17041964486481684, 0.13904875805301053, 0.1320541454779525, 0.1285992881223079, 0.11458285152912141, 0.22028910356663892, 0.11799160571348284, 0.08487446744355463, 0.16873322487358125, 0.21970961933895466, 0.11874922836620001, 0.12814954088460054, 0.09894272988481868, 0.10981964623375286, 0.16430319887736153, 0.17396692306764666, 0.1850419037885243, 0.16855575294504244, 0.20473788642594892, 0.2568009919336727, 0.1997527224762786, 0.1327155551482593, 0.22425213768597574, 0.16471179953265577, 0.15464941850833355, 0.14393295161426067, 0.11635589308195537, 0.15763320839933812, 0.06056761992494426, 0.0807162800863866, 0.1694809113659205, 0.1370597026881672, 0.12400858284484957, 0.0968372981033979, 0.15140514340131514, 0.13620240433562186], [0.02841517978888606, 0.015010654967608712, 0.04037704326272492, 0.01294173589426904, 0.03933018794463527, 0.04536326824417038, 0.04244518571443135, 0.030226428061723713, 0.017828223888852426, 0.021171318592443582, 0.012852068175561728, 0.07602440523764781, 0.027022236590123466, 0.021732441607802626, 0.041985946647342176, 0.07230124856916166, 0.04184033631557419, 0.00690350748388277, 0.023162513257815473, 0.03736633304206114, 0.014068349583765433, 0.02326697700717036, 0.037480552921131734, 0.014523947817994463, 0.06040825831493544, 0.07801369042886842, 0.02459889555710458, 0.025042862661423224, 0.003812425063862916, 0.04477486675304752, 0.02983427722938359, 0.06532039493322372, 0.015305797043707103, 0.037335758473003106, 0.04115394068761699, 0.03523471637538845, 0.024705644163693634, 0.07449906289337144, 0.03852159746231572, 0.12228572005105597, 0.044556918569029345, 0.04606249967529889, 0.06147999233836609, 0.058687483110735496, 0.07847669864854506, 0.012496244274981081, 0.021750934970294757, 0.03685025408142998, 0.03226661979551277, 0.0123683717514899, 0.031968090653179154, 0.03491333099983392, 0.022141706844371174, 0.046389646032044006, 0.06506181727614134, 0.035751427358557145, 0.04079707011940979, 0.05857799382459733, 0.006537814934422533, 0.02034492039632413, 0.03328524860403231, 0.08386127785929749, 0.03219819282211604, 0.03515611575435727, 0.08332543766065952, 0.04285828330584111, 0.08359208988446383, 0.021298178922264807, 0.05173327401280404, 0.01647848804901925, 0.07699083281500686, 0.06267187576140128, 0.09427709354748649, 0.01812623017617772, 0.05602937251810105, 0.017097534972333142, 0.04438488969519254, 0.04008489563280056, 0.028550225768178224, 0.03799779250496819, 0.09863650155884605, 0.09498068401890417, 0.033459690654830586, 0.0157116704259909, 0.04156446422360117, 0.057128088158224864, 0.027969075299258676, 0.06478793318233182, 0.07292139674386672, 0.02166372735143429, 0.031554862826822266, 0.013241735925417275, 0.043752932275134715, 0.044372099857296676, 0.01243766823468069, 0.04977480087789798, 0.04944763919939438, 0.017163730714650407, 0.04394266927134126, 0.021102608166514866, 0.06606988173218505, 0.041664526797831065, 0.020702193160691572, 0.03629166873232011, 0.04166620836082486, 0.0563647581504718, 0.014826854195205436, 0.03248469438403845, 0.05029605093201803, 0.04000125415322762, 0.02303600532843942, 0.013275277169962085, 0.08413179116624017, 0.05634089451163046, 0.0614040193989152, 0.021826584237597643, 0.058715012480294516, 0.001210098240746095, 0.056538679261481574, 0.07362248976865123, 0.044443487760520754, 0.04621937149955381, 0.07811784008217436, 0.006750945383006888, 0.025570624462899663, 0.07195287774647437, 0.019206938919641318, 0.07121507378835833, 0.02790831303554437, 0.05526509256132188, 0.061811723731338024, 0.026525418995128527, 0.03444012998032474, 0.03802955451030885, 0.10553108603363076, 0.013141229020191297, 0.05030118372111071, 0.052532345852664405, 0.04569069422300785, 0.08915994797022113, 0.047637541973662954, 0.008960543575906947, 0.00887033480760311, 0.022227568063704718, 0.02492955251176271, 0.006734180506393915, 0.04692460522956906, 0.05996457466314878, 0.0814538082528499, 0.027804833709172187, 0.010701047459376917, 0.022491487268839153, 0.03892491594137203, 0.023821335466158007, 0.052683878044087085, 0.05247095539685219, 0.019341827850909005, 0.06410842851525353, 0.042748491414972854, 0.03601824812170479, 0.062116201546403675, 0.018124334108565125, 0.008610893386386095, 0.049758161448182604, 0.02100411607252975, 0.035893437077081015, 0.11170959280383204, 0.08505910229418548, 0.03585286506061112, 0.049196458121220914, 0.055635377329083226, 0.028808510396629575, 0.02123394053459408, 0.048172723336686055, 0.0907195650882298, 0.012271827436052265, 0.06233854707510722, 0.05110695499986891, 0.004073919600717003, 0.029607710556217262, 0.05393594916489336, 0.043257740701759057, 0.01575018741160391, 0.026295650074438705, 0.028799455237364577, 0.01945831151979585, 0.0085675289794322, 0.009280187059043637, 0.07326306429721656, 0.0427618328361742, 0.03589997946795437, 0.07912846327188515, 0.04661417874177137, 0.06369396345689893, 0.07232934867422428, 0.027314072039218682, 0.044210466796592365, 0.05314932625380255, 0.018902570272104877, 0.033568203178865295, 0.050655189120481094, 0.053343345681505824, 0.053713749192895434, 0.036362907248398954, 0.010108770520967102, 0.060545667675474, 0.007816535860089766, 0.023988223890022888, 0.020599374585154078, 0.02209970798914231, 0.023419269540857886, 0.05697443007281231, 0.02475818821920022, 0.020329317100526347, 0.08282751881427343, 0.0275062566863433, 0.062262692879284584, 0.04116727444793909, 0.027515413352258267, 0.03838809515019098, 0.06895453984578771, 0.017818963801067685, 0.027883746511032505, 0.06365343357526487, 0.06135242337721491, 0.05874369481217958, 0.09097901608554587, 0.04465806132723247, 0.02532897351850425, 0.04549544522418611, 0.07272410612072676, 0.06936003784498862, 0.04437145634344028, 0.06469679936285942, 0.02994814470800902, 0.03010463348830179, 0.041721619500388066, 0.03511252535146571, 0.015902442598505127, 0.01643651409164792, 0.05390619047947469, 0.07976510531959996, 0.039770232678781596, 0.029352089998522596, 0.0403924684430803, 0.03267730804040067, 0.0433636638486097, 0.02331483451980016, 0.03526535606192004, 0.03656891595211722, 0.07114819431256864, 0.055863748139311234, 0.020281877105815277, 0.04034171511809673, 0.028597217601453586, 0.04629131481652299, 0.06632404672282358, 0.06578269069113078, 0.08570291492487155, 0.02230388382750173, 0.041265969555224144, 0.036552058187343424, 0.08852527476847173, 0.07295269909645281, 0.08114831537128457, 0.03271634405058238, 0.024956549450214353, 0.021237694365423054, 0.0517153169118589, 0.048779254298537016, 0.030389549248220942, 0.04983324572564133, 0.032779553965214765, 0.009534901717767842, 0.05626547315548505, 0.08179888489746279, 0.06760322969527015, 0.023276980200241652, 0.05003633563436809, 0.06111305537483385, 0.05224638055228899, 0.0805511804778249, 0.050422095378199895, 0.007990266406728376, 0.024210284050974636, 0.009423809392648119, 0.01974874885842925, 0.03292897558440605, 0.04693940604826616, 0.021620280590028535, 0.011384224560442231, 0.015064493711707334, 0.053947294927051956, 0.01675558396645131, 0.08620031283146913, 0.03539765944644328, 0.03469244869906576, 0.040479128309074915, 0.08272862452412806, 0.07519671618337594, 0.019707397347496405, 0.0652917355839764, 0.014204305292467677, 0.05387419481731711, 0.016154293046002428, 0.01036904123236215, 0.030868153102816116, 0.029821401206596248, 0.04289477590411421, 0.05491268828571324, 0.026780959113591143, 0.03839626164746381, 0.07339421088897413, 0.015374530452273548, 0.04949566525136752, 0.011060903855268995, 0.01672814269700358, 0.035028730654307914, 0.019832332881407875, 0.022148398622389764, 0.06507891635861128, 0.02472109232668675, 0.013154653753454407, 0.09576303598981711, 0.004088000296765278, 0.0349327628200333, 0.018169816748629657, 0.020672271681588986, 0.02862814265573698, 0.017649039753802845, 0.0565841963755027, 0.11408687854606299, 0.051530682061228066, 0.023228594086944096, 0.046353015537944534, 0.09982065132428562, 0.05072821645186313, 0.03533813824516631, 0.012433158849636394, 0.0531342113390565, 0.027533196168200626, 0.016902659441374483, 0.03582442404642221, 0.05564577697265533, 0.11058925816248502, 0.007007920479912672, 0.01853585547407068, 0.02535559698909281, 0.04582256093741425, 0.009907194593500708, 0.09761739011493423, 0.04909687818238332, 0.13116162240264878, 0.13919010127504028, 0.12465520701821774, 0.1393835231541626, 0.19080043349775577, 0.09752701472250686, 0.13203149991891078, 0.15650566487062365, 0.0954822954090853, 0.13225433957432547, 0.07656615963506122, 0.19381938682448482, 0.13210357347082707, 0.14821876921961386, 0.12224812811661152, 0.16196710568281913, 0.1281573703031867, 0.10134816169738771, 0.14830899905533562, 0.15443751858847757, 0.1258827173601716, 0.10083527349296117, 0.13575579039752483, 0.13122054988578444, 0.15851093065594474, 0.12351290863608161, 0.12265488250000824, 0.13873913595753332, 0.10205994164871593, 0.15953050175261113, 0.0927345295466723, 0.11413207773359553, 0.13273527425143028, 0.06726912342973294, 0.11854365633259858, 0.16581605398847213, 0.10808701581892469, 0.0947906022831317, 0.22053206069094522, 0.3184435366382522, 0.13742120425787666, 0.0935850939863632, 0.14168647538510062, 0.1419533957396784, 0.1210321857023143, 0.08916501181140062, 0.16447322443127632, 0.1764669437562266, 0.15453104260227374, 0.1318073732357833, 0.18575496310668607, 0.2009361444581901, 0.13964573972888533, 0.1079087088545484, 0.16050669695100478, 0.1986753577066045, 0.1001892775116909, 0.2126425501680182, 0.14782432586916033, 0.1529921405017376, 0.13639789465213978, 0.1741489455584557, 0.09608844715741374, 0.11746783139965228, 0.15595628789836363, 0.11317200102512875, 0.15010397370544173, 0.1637746135313665, 0.11200548660370613, 0.19325609769551985, 0.15651383136789646, 0.13429343580238282, 0.11967590364116816, 0.10969298125635232, 0.13380926823423756, 0.14302363589165673, 0.11695095187714023, 0.14259824258906229, 0.1172779105423439, 0.11780837280375343, 0.14267131205528014, 0.2913918075782638, 0.13261487587325035, 0.1124487450766948, 0.09976365438271916, 0.13834954960451973, 0.17023464995286158, 0.14024474387688024, 0.1582455424772155, 0.1754191499804297, 0.09265860257249686, 0.15540101204908666, 0.17664541159906696, 0.14160795137286186, 0.19935253346639298, 0.13813069360631128, 0.13824706236200948, 0.08227326952281498, 0.12247492844659476, 0.16545934812916865, 0.10371243160578514, 0.19644132274533474, 0.1393195394907267, 0.12168994879410153, 0.16612651878066603, 0.15620537372606416, 0.0998214174122099, 0.08684105344957883, 0.12554686441416704, 0.12176346259131549, 0.12735356020951463, 0.11872554092758125, 0.13749235850428382, 0.11517620194823512, 0.2215397267812683, 0.08670288949243485, 0.14780046989119824, 0.045928717741081794, 0.1934679363283419, 0.164551840374066, 0.20634569047439486, 0.09779610310591037, 0.24644179780396724, 0.12632600647667724, 0.08927071662319284, 0.14305925898013577, 0.12388548017629694, 0.18795214923879794, 0.1780707028604323, 0.10827378805486426, 0.15266842238845366, 0.11123933739239171, 0.1509652403934348, 0.10082709167392985, 0.24338555131708425, 0.10983657677687945, 0.1842437933890089, 0.1849698149148495, 0.12237301577002772, 0.09347075536366432, 0.19072339569609012, 0.10536932656841894, 0.05084746569815663, 0.09336511949978529, 0.15351844290571828, 0.1572436526898415, 0.08931768547383048, 0.18883288988182623, 0.12285205820995955, 0.10703100191970026, 0.08149920662324275, 0.1158943251075764, 0.17299644288516816, 0.11092624491861752, 0.22982322100189426, 0.1756080519407988, 0.17089278076685246, 0.10904568292561079, 0.19052001467395216, 0.25059387177949954, 0.11216810408739314, 0.08279863729952805, 0.13116462546731197, 0.15308416298320218, 0.13151193908866377, 0.08921067065168774, 0.18881085719312393, 0.22359458909880733, 0.2797636347672632, 0.07428949188080526, 0.11584504267140744, 0.12008615904637884, 0.10743935742685873, 0.17421640726106782, 0.3543408233071528, 0.15080272250117796], [0.06270466049412085, 0.01783984544266376, 0.030892878590572267, 0.040950023403932015, 0.014280887271818376, 0.00729062894899999, 0.05063829305131109, 0.020886393256425377, 0.051445420305695266, 0.12130314334025308, 0.058412208567343415, 0.02930903394195822, 0.030137069651015827, 0.048590325525090586, 0.06531333160256186, 0.04328236276764543, 0.06269961197469985, 0.04447382867276188, 0.05140456100625377, 0.056932823837644635, 0.02579833069185336, 0.07213542883795115, 0.018894206507191546, 0.08920054296932875, 0.050373035107528975, 0.1000240323464236, 0.05698153936874963, 0.0969137919826373, 0.04940737744853382, 0.03371175273411697, 0.0775929396190951, 0.04793634307720969, 0.012831569577927792, 0.012881359547346592, 0.027191384973364974, 0.037717174498304244, 0.047558378278007435, 0.02594049745840171, 0.034307359282167695, 0.04987057719019152, 0.023622256027714863, 0.03112753898265862, 0.02566553318061896, 0.028692970931109403, 0.04606619221909393, 0.014096599075973276, 0.05383995834798102, 0.0442737571504568, 0.018743576384299708, 0.0037937406581946683, 0.0437873640968915, 0.02877496340642533, 0.03694337972950551, 0.02111895265237939, 0.03663625891110109, 0.06556745062792493, 0.042637749575078494, 0.05901493590265032, 0.012269495655932735, 0.03431233502323589, 0.04609791208959876, 0.03513201845869903, 0.06186847552476872, 0.07076734136189185, 0.030372042223931323, 0.03545728790002965, 0.0227375298122605, 0.047385292202835126, 0.05988638772959671, 0.00549329043884251, 0.010814764593247204, 0.01498931367325807, 0.04917329928326992, 0.03896559904059095, 0.09330437638826909, 0.015301034849647795, 0.02253001766099084, 0.0751104470222227, 0.050068557292463324, 0.04021354094748536, 0.09488063293599314, 0.008467654096743753, 0.06844342130446626, 0.03877991464950385, 0.027763803955167535, 0.09192510402851528, 0.05814292866195883, 0.0136449299151859, 0.013155882366962973, 0.058484787737289747, 0.062418097645164504, 0.020630726733455257, 0.032177945118277304, 0.06162691651092422, 0.05218815020916443, 0.02472172243400447, 0.0734749412344348, 0.05552723252725217, 0.1016627250599765, 0.040517290979022944, 0.029457957603998726, 0.04341663882857369, 0.04910021066485394, 0.07228557441023088, 0.10030874892348245, 0.016600751851294792, 0.042510896906136506, 0.014282820686217279, 0.10865016705206326, 0.0833573452227058, 0.03118700655778089, 0.04357320038721927, 0.03756069337889072, 0.028526858171267856, 0.019475667241720424, 0.032831812652969555, 0.024706138290404796, 0.052141315423913544, 0.026045652602108258, 0.034050512983794176, 0.0484307570713422, 0.026564912742844997, 0.02201774041168392, 0.003492266386597147, 0.036641893487784176, 0.04376882476912391, 0.04827505353117182, 0.022907725820738464, 0.06120056176798479, 0.058321001969518206, 0.033711453959826505, 0.008814035006047738, 0.05021473069885566, 0.008279344896906087, 0.021720622786350792, 0.011218864481986291, 0.03577186658437695, 0.02760349048091279, 0.05771360532831281, 0.01861398303580861, 0.029109920029558485, 0.011414348095234846, 0.03926771730484982, 0.014671931107107912, 0.02076905539950296, 0.03254742932415778, 0.04554565079630383, 0.08810559648179239, 0.0229749538665337, 0.05814760179829694, 0.008220101402501666, 0.053534032626738476, 0.02111821912319189, 0.07538345777579854, 0.042832818543238026, 0.024795783984084285, 0.02986805979162455, 0.08602709269091006, 0.017922330129471038, 0.05737754936900832, 0.010865304371221893, 0.044370897099255555, 0.016487684934550238, 0.0416725515688379, 0.02718861173507908, 0.025201371998616287, 0.022443225644829295, 0.04441813025022707, 0.01706348044887906, 0.051758964771344784, 0.05376485108788456, 0.04311856550855502, 0.04090466333793537, 0.044614739055114414, 0.058162203434133725, 0.03819689109560944, 0.023720399551694433, 0.008461697763132473, 0.036375861795198534, 0.05229124266113486, 0.03657655767916191, 0.0479837179544472, 0.05792596873136298, 0.02648691541605419, 0.05570719041110528, 0.07125459626437196, 0.02083502323066275, 0.057929186300644954, 0.028336659607086933, 0.03615738884095223, 0.055329424794763334, 0.07780006681118282, 0.04094120956236317, 0.057611872682407986, 0.013713768660841931, 0.025477178973115744, 0.03966251305574852, 0.056099324006467104, 0.017226488637407462, 0.08165417854944546, 0.04627389397712485, 0.07246834766720572, 0.0298925343855855, 0.04318457930499027, 0.029986784267689914, 0.03343000474776472, 0.00926424093889974, 0.01681346957000994, 0.04484402150997231, 0.033988613079512314, 0.025048870705969395, 0.042878262878906344, 0.022126766214627894, 0.030584332848628683, 0.05664614607549964, 0.03699495659900769, 0.003981305316330925, 0.04462525361187516, 0.015313808408175266, 0.01579536936215816, 0.02364426190333982, 0.04622334749588082, 0.0043711277201861866, 0.037141072548805706, 0.02972089430137027, 0.042181777872986374, 0.06345567563849111, 0.033776356928771546, 0.04541048990382303, 0.039518886891704415, 0.05064069856739333, 0.035256385172326724, 0.07035100321856237, 0.01624774428144578, 0.05159453165927722, 0.026896864386095155, 0.059845474804000515, 0.035360002394525275, 0.0705523158033048, 0.027224780661204172, 0.027835871761424408, 0.048558747380851745, 0.025050866365012144, 0.03380592792264877, 0.04639164552152638, 0.016504397142618414, 0.014563750873710361, 0.046639505608548085, 0.029609367221353516, 0.1208408629041045, 0.03069998531211769, 0.0024571279045044175, 0.04582246134598409, 0.020735276667701624, 0.028679102824460116, 0.041085096196301525, 0.04186789632865018, 0.029713185541632197, 0.036269413878119765, 0.004879839309010535, 0.05799433058728615, 0.01458605265079607, 0.07006689185096372, 0.0168824921767678, 0.07454038567600713, 0.06955981059300323, 0.10049307733894357, 0.017048784967271552, 0.08165369591405315, 0.05773902029520082, 0.056224135051090876, 0.01654421073204327, 0.03232352863696795, 0.034346640440485174, 0.02510490046153146, 0.06081744502749174, 0.016805498425157803, 0.07438942038964841, 0.16779570179360528, 0.05998413288785566, 0.07465952000911198, 0.07270692276858515, 0.07978732953028334, 0.06463407974449858, 0.020951947400106058, 0.007583121318490275, 0.004553465264654088, 0.05560820035996938, 0.045276815221915324, 0.0022852867222090643, 0.029006025100487377, 0.03077991509569749, 0.04875849331578901, 0.03787274397308788, 0.03499487339849434, 0.04872729055463307, 0.05241508077409479, 0.06962835247958861, 0.06424500283995463, 0.06793213422380148, 0.017639804563875643, 0.05315309540639001, 0.011777139565486823, 0.01045618469135896, 0.005933644959793216, 0.050212918900914734, 0.034836025067394784, 0.013901416152235002, 0.02678343166236676, 0.04525012088819377, 0.07083586792671873, 0.021802824020626086, 0.0403360192543797, 0.012154910927488199, 0.029907277747688275, 0.0033993207691838186, 0.05358895730046977, 0.035908923544470346, 0.009345472114340914, 0.05191359195798155, 0.02945244943182315, 0.0748954980724281, 0.013775636963996918, 0.03219946069763072, 0.02937826722289526, 0.025566510570746277, 0.04119207271404805, 0.0403818006687347, 0.06267724986819011, 0.06461251436943008, 0.05107587098234123, 0.01628289048019196, 0.007705712623353447, 0.09723978537705638, 0.006798713837915491, 0.08859717212016545, 0.013400928038472851, 0.056958323074204315, 0.036534330912775574, 0.05833393736411968, 0.03581392481141994, 0.015304925618693234, 0.05898436133359229, 0.03372741540172889, 0.07689903249904033, 0.019703365809794877, 0.05485937622706256, 0.012501649025286879, 0.038518759106556257, 0.05082089393850296, 0.041408569161449714, 0.06803890389780845, 0.1077847328457621, 0.145789994707992, 0.14430588321580043, 0.12034300534475235, 0.1265817649301983, 0.09378400871590262, 0.10792683449483688, 0.13560761367121052, 0.19739174674595558, 0.24741842201159847, 0.1317345182741842, 0.10608034809270214, 0.12027830921954687, 0.22681551384589366, 0.17433513556757282, 0.20861458243621936, 0.2820134817832901, 0.15545463820378627, 0.1475724514814154, 0.11336575998293777, 0.22539509490372675, 0.1467556025712721, 0.11395469007472839, 0.18863473357933183, 0.12274213991458378, 0.30694235056158037, 0.09425162878488341, 0.15667152290623035, 0.14803745152969516, 0.17318209663273829, 0.09507794654177082, 0.14140080119813644, 0.04557266305651396, 0.10859639534065801, 0.10991777443597395, 0.12550224745345692, 0.1364066893415105, 0.0973746091908505, 0.14305032639493867, 0.1450606636823185, 0.07470055167833645, 0.10660000851437931, 0.059835239869332126, 0.12811442341415152, 0.09467168245464565, 0.194114652432261, 0.0796856313583351, 0.1772385015482864, 0.06904011186692985, 0.07960716863313029, 0.1605712015542292, 0.12549696910765865, 0.12950037606060505, 0.26030687074507436, 0.19204374823358752, 0.14390048480802967, 0.10972475858345147, 0.08473340767405688, 0.09330420018804651, 0.16268958788244955, 0.19977653248896524, 0.1351742836977205, 0.14680731350616102, 0.1361858721582159, 0.11943613344262685, 0.12321994129207828, 0.14139664900158683, 0.12319947908362075, 0.11371773141886919, 0.09412504807715455, 0.11221606885233235, 0.06737396256217072, 0.16482326532563857, 0.16050171737949695, 0.15274496989384775, 0.059629778918479724, 0.10314573338555713, 0.17429177499105855, 0.17064148860592998, 0.21670840860855198, 0.18734208278117642, 0.14446921316125702, 0.20116286051850166, 0.15285514865911778, 0.14034343132328603, 0.14820890200714912, 0.13337054500176063, 0.15961685518343605, 0.2290352995717718, 0.20460775873113066, 0.21142856127792792, 0.08240801672781668, 0.14042261417113966, 0.21592548207169582, 0.2658265342395152, 0.06503991482238616, 0.19001588285450013, 0.15437388732548685, 0.207300573106735, 0.13920690924409898, 0.1409830228095093, 0.26512620730265496, 0.17731575385457088, 0.2057564309647968, 0.2650368814506839, 0.2246255749055455, 0.18522639308244954, 0.1282189561114196, 0.20760254964472788, 0.12945416563701245, 0.1326177103985702, 0.15379967378272166, 0.20573441359785297, 0.11224989163418932, 0.09490971363359883, 0.18243870637830228, 0.12170209128770137, 0.1442860108950446, 0.12414451748613389, 0.17935630564968433, 0.14785890707806235, 0.24263631732713795, 0.20288160942014188, 0.15315406084541353, 0.15327560835547988, 0.19533771180337478, 0.13516397215425968, 0.1672841082777708, 0.176506427927844, 0.07589265343643005, 0.0714015242673697, 0.2784427459682188, 0.2224693131903487, 0.09209928943985894, 0.09493988983693624, 0.09200481547703666, 0.134880427691725, 0.09742428999274008, 0.1423714039546828, 0.150061103425199, 0.09880903222027326, 0.1254622193594133, 0.10830498315514096, 0.1570672532843967, 0.06828226704871462, 0.15033488792757835, 0.0880119958592038, 0.15130147638340152, 0.1197978112125589, 0.1164455100473377, 0.22028743349496396, 0.15247962768039397, 0.19078079100337722, 0.21600304081314997, 0.09449431777841623, 0.09820728547750943, 0.14235885543448312, 0.31280791807559233, 0.14514519382388363, 0.2084066048865357, 0.08086768970374139, 0.1885106273355984, 0.12370831468292784, 0.14211044376415594, 0.11499168967167217, 0.1191497314721346, 0.1776135169089802, 0.14203791055948506, 0.19277628150678452, 0.12787427783252733, 0.1572289591234538, 0.08492772587605062, 0.1980022268910562, 0.10495404562642498, 0.10269227062141704, 0.177269313604601], [0.031278471710280545, 0.0489917632582928, 0.11411877844723002, 0.029023177809112018, 0.03215017443102214, 0.011462924772903565, 0.08072386435683697, 0.06273277592094195, 0.06007596384733916, 0.038640930978280884, 0.08828263174021438, 0.02820956179000918, 0.024814915114773378, 0.03287998809208793, 0.02633778491027413, 0.05395265754252192, 0.03446354928817, 0.013033528549356327, 0.07877284525743417, 0.04583937656735221, 0.05417324872987886, 0.04512140279515617, 0.03567982495071427, 0.041965403999652595, 0.05965667243506159, 0.01902855151603299, 0.09140410295297062, 0.028178265183082515, 0.05768784179141926, 0.039463219112686576, 0.06384474871259543, 0.03133358790599291, 0.03930812844285562, 0.06746166430774235, 0.0441209685748383, 0.06158277452472718, 0.009426113402080393, 0.03005671851907767, 0.03595083238436811, 0.006472647186338661, 0.05477994440063354, 0.06742552794035404, 0.03968313997310977, 0.004013735733385529, 0.018014783535393018, 0.04981198678574255, 0.04499407132126151, 0.07046055379173449, 0.0307203192008479, 0.04228416552406646, 0.033762728224598595, 0.02546414590230392, 0.04872128442530671, 0.04443559705490067, 0.054302614167212486, 0.029534788561924815, 0.07414735958821352, 0.028838316962543516, 0.049876908906885696, 0.04196938382641923, 0.013105997594163544, 0.004509282101231117, 0.06539098993544618, 0.012933490872983972, 0.08462373452681689, 0.03270277663344338, 0.07162227250275112, 0.042285739834750855, 0.07017492557004576, 0.02556437893109697, 0.05630543996249476, 0.12937219422911445, 0.028960322210144614, 0.07897480135603298, 0.01755420572965616, 0.08207528175966394, 0.015843512242539756, 0.18093176546596712, 0.059396673684879664, 0.08276793249552289, 0.12448663703135907, 0.21360775966557766, 0.29795978578828997, 0.19429336542323714, 0.18847374786292354, 0.04721188437073462, 0.060028841779116666, 0.10147885629726995, 0.12513667795686953, 0.06639834959059954, 0.12809916294269985, 0.031608586657732245, 0.09155368162018639, 0.1440270578548793, 0.041336763740306905, 0.03652382018645445, 0.08771810920969134, 0.048322026212249077, 0.03824423532932997, 0.05079611099415249, 0.012718514152502101, 0.06724234865677935, 0.00781877714607324, 0.10921252921463982, 0.019603716923044096, 0.03970904906670894, 0.027409710455685857, 0.07672703809916012, 0.03483166602710563, 0.02736260562444166, 0.015843005666899827, 0.08963195772300805, 0.04173683400656428, 0.058734769887861714, 0.02132591322034357, 0.12957137708942737, 0.006793369417033729, 0.06136271576847761, 0.03557854812712439, 0.04284590715542436, 0.013727224037622013, 0.02162856774614944, 0.013673055875715951, 0.029522577120411782, 0.0502556512853311, 0.05518365358453124, 0.04196917315224006, 0.011710846146959211, 0.02181875673423131, 0.03558592555383521, 0.09104447829867564, 0.04079888191735072, 0.01769183725569277, 0.03647053877132074, 0.02512061484007826, 0.07908663487121945, 0.03323356831266034, 0.012789704788085676, 0.028327426332379543, 0.04133171139044627, 0.00350064906430611, 0.02719940399871238, 0.04243361012589547, 0.04896004721822758, 0.020133035798226635, 0.05761554607400491, 0.08154126485028575, 0.047585746769102356, 0.06709714435161122, 0.03352451318454358, 0.034967983712352095, 0.03912273133474012, 0.024443508028202963, 0.023102610927796172, 0.004790561816339652, 0.013225080216333512, 0.013107342078470656, 0.06809782372006486, 0.05279185430657479, 0.01939671996590351, 0.008497045059958774, 0.03185698492152076, 0.11070230209659185, 0.06647328065047342, 0.014488708731087466, 0.08911565276643924, 0.08396227123035539, 0.04051623760812706, 0.01643254384098034, 0.06705986651321573, 0.06559396493098428, 0.05255995566145547, 0.04358082679250548, 0.017125056681012916, 0.05697182920430938, 0.023178103147074584, 0.023887094538358432, 0.042542865755216736, 0.07556089139994114, 0.043058209271440585, 0.08920773653493774, 0.06068969603567835, 0.07577518917500012, 0.056722475245835326, 0.022463176489597367, 0.013490052792363831, 0.04431897932062707, 0.032263279652162906, 0.03973948190950098, 0.05008610836680859, 0.03988251435540376, 0.040775167665654616, 0.05659331665224126, 0.01720416292007412, 0.08185811115488892, 0.055674631674323356, 0.05815595598711122, 0.058888833999874136, 0.025273748155262683, 0.049784411450908075, 0.006977000692483759, 0.06668624543254414, 0.024237529968001673, 0.030588052205501065, 0.051383493588336056, 0.02530675696870012, 0.022138843590754177, 0.03461664429895821, 0.009261754025975543, 0.03442276659752092, 0.038309153620033495, 0.045944694504742666, 0.038635664123801455, 0.024410746278121107, 0.07678568979064304, 0.07782729357601174, 0.019405664042419484, 0.030849742094775846, 0.02818101543873068, 0.07757466076122177, 0.03104155901969681, 0.12622340432097837, 0.04391547698046892, 0.03080602720259659, 0.005201429613084803, 0.0573345756668958, 0.025661066888020407, 0.03500140046760921, 0.014611361322984582, 0.02621109503501606, 0.036741354682993506, 0.016286353197609706, 0.047454416316242955, 0.09178188389107104, 0.016403560819584998, 0.03386758267879486, 0.0039351284090850145, 0.08121735521502073, 0.04954993491992355, 0.02427110377128326, 0.020608958345086827, 0.0038885323081030362, 0.03455777427241687, 0.030050151230346774, 0.027118734940285646, 0.0467486999508354, 0.03628959263404531, 0.061599348836968985, 0.04349972106396191, 0.07152845737554374, 0.0029012836579744134, 0.05339969527877627, 0.016919074790372003, 0.07212676438352755, 0.1620506245883242, 0.07113329390244139, 0.12019497417514363, 0.3215757330819484, 0.2205057685533839, 0.13654038700605595, 0.10151098602481427, 0.0898322360890527, 0.05273056727263236, 0.09929543676515741, 0.062674043790227, 0.10345756181425626, 0.11899800775873086, 0.03064097355931036, 0.05880507377667293, 0.19510425416932953, 0.018112239495460546, 0.035362055510162346, 0.017123541742142652, 0.07074912379105246, 0.04113306862211997, 0.038386471043791504, 0.054768897412765416, 0.040892474879060066, 0.015451875646718809, 0.09610904726169764, 0.024897503223450437, 0.0334173834492122, 0.05059398252577071, 0.03828697537462558, 0.032327163724168655, 0.027556029418783805, 0.046445903698763544, 0.007498979487741787, 0.026297295248256098, 0.07571441541996694, 0.050224701333190166, 0.0855761580169201, 0.01794033511091144, 0.053011349988200014, 0.05100901448918928, 0.0251430650466993, 0.009100553804948446, 0.12586848344653845, 0.034494296227010994, 0.009226925753717943, 0.027169120543065573, 0.03527655626737303, 0.06680583941840357, 0.05337267918812652, 0.05122106762663011, 0.12973115238691532, 0.05104178006971075, 0.01816453457239174, 0.034721912440633586, 0.03938366088175005, 0.06440191679904539, 0.020574285205633893, 0.03335098660881481, 0.042020060542610385, 0.01916577893068954, 0.06607137560363739, 0.025163487035540805, 0.057337180365838354, 0.053286402366094054, 0.027314537437632683, 0.033010016195476055, 0.041953521975947004, 0.025134377609637958, 0.03763191657321107, 0.04460539661287781, 0.027813500078815608, 0.04162896116594634, 0.016046815698275405, 0.013837498563882566, 0.01198150788343722, 0.06897843412814603, 0.03156947020831848, 0.015901203451287604, 0.06569453695368382, 0.072250050913182, 0.035711521838581374, 0.04500730549015346, 0.04299298071512773, 0.06288311684564238, 0.01690130921140794, 0.09534816873530227, 0.03929726531608932, 0.07228107747411536, 0.017584922024980187, 0.03902159623741623, 0.006890943163119618, 0.020426723264878797, 0.03405529337244169, 0.0682034595839439, 0.058413081907577095, 0.023714525572535013, 0.03597228667668758, 0.10357986775136764, 0.1922129464125441, 0.19606869757896472, 0.14488222648299512, 0.13662289467550096, 0.08699599473226456, 0.2082629634007331, 0.11743831403192975, 0.15904464879103247, 0.10187064132262623, 0.21365813760747834, 0.11132225874931582, 0.07731321793530258, 0.08928924062920195, 0.14537031642131268, 0.20191407101529263, 0.15251826915529468, 0.14608933590352535, 0.3024668036208999, 0.13396505987451923, 0.22071875631809237, 0.19374723666377608, 0.14091845691925095, 0.1092877284052872, 0.17628470676079874, 0.15411948484759178, 0.1480862819739888, 0.15939303493547827, 0.1740569383987496, 0.13233839474137754, 0.09103143948220438, 0.2165416465891946, 0.12379361857329646, 0.128181548038077, 0.15342196179253442, 0.17241605467373328, 0.12509729337668227, 0.16120169191591202, 0.23918725159620088, 0.13080306261056854, 0.12474469374865295, 0.11417490970944205, 0.12001706557648799, 0.17708067211412615, 0.11797662869456316, 0.2871250349187082, 0.14056769590223991, 0.14576483638055865, 0.15265619562518212, 0.17107301061191868, 0.08215882364780673, 0.1673083932649705, 0.0918277802186147, 0.07154363357732374, 0.1615249503764414, 0.16252253474968095, 0.17214017109044139, 0.19387238478708654, 0.09826605974306023, 0.16054555293052428, 0.10581956410239782, 0.15763040451753527, 0.13121840483959646, 0.1771586598648179, 0.1705148542720464, 0.11901658539089466, 0.20413181894729215, 0.18477331336227157, 0.22468459431923207, 0.16294693213797387, 0.1876668580957959, 0.24026942739803947, 0.14701898359963972, 0.2384003873674139, 0.10670495489912649, 0.11486771366288585, 0.21261916916456916, 0.21765930758368587, 0.41042210594300305, 0.307012003275656, 0.4818129203011913, 0.4842384466000142, 0.42097999263674984, 0.32906396675013727, 0.28428753717772426, 0.17507431848395258, 0.11451914365733824, 0.2055898068412658, 0.33447530541208487, 0.18991203197548467, 0.2767101002316321, 0.20248082286167532, 0.20631026656877613, 0.36353302038004326, 0.2698809779699772, 0.24906437723867356, 0.17953534039758867, 0.23955324244114662, 0.26065731000515724, 0.1673905638557288, 0.24138305877004904, 0.163280057810968, 0.13983226681668914, 0.2475367979176583, 0.15361268704216327, 0.12609076385776843, 0.09847705567916555, 0.12539720913815883, 0.13463324176207667, 0.1364675933314908, 0.12569284246813867, 0.14931232908800726, 0.14247910059507818, 0.1493334731147174, 0.12059937666861281, 0.2518494439221198, 0.1671558191939708, 0.1703237613002139, 0.1381491869688034, 0.1808800698528367, 0.0871883977144476, 0.20402242159170492, 0.2019957513097794, 0.12760188761017016, 0.08403964611070772, 0.19343956043162655, 0.08957473861594355, 0.2142338526825751, 0.14867806957373697, 0.3136597465603583, 0.14445491796058996, 0.14209801781802409, 0.13569145433364377, 0.14861653739165875, 0.15716237076107534, 0.07910213282992763, 0.13583863514565653, 0.1316836347142535, 0.19812129227624786, 0.11109781797013937, 0.1279022477026428, 0.08001924732760077, 0.12853934940311218, 0.1045540098341242, 0.17692253624479617, 0.10468714059360566, 0.1782469184047753, 0.14776256386070483, 0.13279623952844452, 0.17271973192691806, 0.08428095614597683, 0.15016591957499906, 0.14043980518416052, 0.2071314055712954, 0.13066389507824375, 0.11009870908193051, 0.13085396149225775, 0.12253871292717035, 0.35218615505483847, 0.15302517421303258, 0.12485800581353328, 0.1364582470588146, 0.203418116115274, 0.16058765712284273, 0.22527488038664867, 0.22640297549866864, 0.18738457001745704, 0.1027435755297061, 0.10855214610215157, 0.12772078445601848, 0.12815761545132245, 0.1335101568650815, 0.2063917170368856, 0.1607831934046361, 0.24063495859023065, 0.13518499360690195], [0.05995452358958222, 0.05072793299933115, 0.06489144698266061, 0.04371384646923792, 0.044054667495431445, 0.027973062786904555, 0.08627164327809889, 0.013334069630101085, 0.022185760730456923, 0.04883045961539592, 0.02858586417841575, 0.06411760241814679, 0.04468443390402583, 0.012156268818333987, 0.09623002020582076, 0.045316498576393055, 0.009380181642970251, 0.020698540836512562, 0.029167169780139963, 0.07410176969583958, 0.05481005548649738, 0.07129090883198284, 0.005620691818260258, 0.02437275597795604, 0.054231107520360144, 0.012687652300472462, 0.0210861487674617, 0.0032827394240866267, 0.08249902031234196, 0.02658851782701189, 0.05691169130225336, 0.04707395407040754, 0.009933648567136017, 0.05049624502839101, 0.08315083856183676, 0.014339347441320219, 0.10357233710707196, 0.07249902182769391, 0.022192929398208376, 0.05919747933324787, 0.03508957718769389, 0.04990896202563759, 0.005416483899969007, 0.033206123212773, 0.016396995446073915, 0.02662403749362115, 0.011092898559816664, 0.02919387752040019, 0.02845625742338598, 0.08632296350814643, 0.05127392003252622, 0.04235848754404053, 0.011729000515544848, 0.07056569935934198, 0.03307275879647463, 0.012246933408952769, 0.04587583852210834, 0.030544327737222758, 0.023659924570951733, 0.06916888358612215, 0.024204457952310483, 0.06601561206362902, 0.05480952688582963, 0.05052650167096046, 0.027699372130295927, 0.0659801192100971, 0.041651859534003084, 0.029211321342436057, 0.010006318710023358, 0.06592463912262071, 0.08107121628258498, 0.4097881835074194, 0.4793059741777759, 0.8222905858870476, 1.8848855481032405, 2.023894592158256, 3.6792871644420013, 2.6604706337375026, 4.114991397626938, 3.0391754738746153, 6.500757365457474, 7.279002676087042, 9.35602270787762, 9.455071380061488, 8.453516710189081, 11.428221656430154, 7.443009720694635, 13.755182470044783, 18.305205414372107, 12.748493417616814, 8.709212099352191, 8.501670668202063, 10.071156101842082, 12.608011768710229, 11.295678884752336, 5.362525255449357, 4.5568866018326055, 4.282115255632709, 2.9302019794141096, 1.887115415546202, 0.7709735427652636, 0.2465298979152595, 0.020312204611517733, 0.011777641353077226, 0.06363154644326818, 0.11862998678078575, 0.013677403424686242, 0.08265370878601268, 0.06817630176702816, 0.00490658583247193, 0.05352826781510826, 0.010292625877134984, 0.002819244977980552, 0.022033629075233496, 0.0457028903427624, 0.036965220896226746, 0.060393281296015754, 0.03383818022426098, 0.042037626938714136, 0.05247723731783129, 0.018034801412854466, 0.0371264134563746, 0.013234030038508917, 0.04062093884473847, 0.022682201027149157, 0.04225827175222578, 0.01378438377287239, 0.019680203141404257, 0.08284071850920878, 0.04838204537067683, 0.09309631456891376, 0.017327999117814245, 0.023605618513219302, 0.02139878350370113, 0.037153931334614754, 0.021574098894733097, 0.030324709481529655, 0.10048908602085807, 0.05073239546149008, 0.04311525600872213, 0.013732412368089203, 0.05292765488247237, 0.021898004699558504, 0.05006375009073846, 0.05120763427487785, 0.0401861839477093, 0.047283004143185196, 0.039062003544982404, 0.04610164676822963, 0.0778245126768466, 0.06985381215570435, 0.04613426679204549, 0.060533260881540284, 0.02915437802702429, 0.07112105181741138, 0.11057034345163454, 0.08977566049584458, 0.02469618106260896, 0.0375059066009858, 0.041623993085757385, 0.035916147753596306, 0.02493269347225226, 0.04647961922831113, 0.04143264730490985, 0.045204247543287855, 0.025068863685573303, 0.039459959408568765, 0.04348413883558205, 0.02717473405233074, 0.0955052397424175, 0.09254832421579669, 0.037973526669966604, 0.019599593454791654, 0.039964294241320704, 0.01894403669622637, 0.04606380202477017, 0.07832262304521377, 0.0835184381914235, 0.05223279398295188, 0.07681999520789232, 0.06316178515853901, 0.02267759300828461, 0.07286420061943993, 0.029844228711519993, 0.055496726906107324, 0.033011180649120966, 0.02627949519533544, 0.06510781319511515, 0.07281313319840739, 0.0853012933305675, 0.07037987707242851, 0.021695590863424926, 0.023500608926218365, 0.055631995050897526, 0.027907261579868295, 0.031940829414393634, 0.015624048162041413, 0.051438544666574854, 0.05070413830840299, 0.03487468186405397, 0.04825044678704393, 0.05795951572156722, 0.00827454918650009, 0.07576512277967508, 0.07179916220446748, 0.0008741009350483036, 0.02501400987497501, 0.07898448470739589, 0.019606183726160277, 0.04358030585271697, 0.06358666901266383, 0.023622736747887348, 0.022537925603589224, 0.021577643966602705, 0.02353176189165923, 0.09707604174412067, 0.02079677629104305, 0.03170430742865128, 0.056556835545287024, 0.011173457493104283, 0.02269475146256868, 0.06092544427261718, 0.042277791672536445, 0.07717831751271602, 0.09196153917019406, 0.03883917538088657, 0.026816181921129747, 0.07646255390418154, 0.059622014617367144, 0.05172331486978839, 0.07794376958401934, 0.027240033471776594, 0.08271570828172468, 0.0624786262520619, 0.040954072178611835, 0.008102041507710614, 0.04594540313607262, 0.03125110896484506, 0.05207654652035525, 0.03034026681205198, 0.039891665275659294, 0.04689069817804041, 0.02230770660624389, 0.0628359449817048, 0.057223902774914626, 0.023618092339846398, 0.06768231295169362, 0.2825908669300618, 0.5432019358681095, 1.1071980720566166, 2.028065419966175, 2.0460297527813145, 4.371141781730037, 3.582851035941032, 4.25937972722515, 4.1923998632738675, 7.985212677909483, 9.484083191041025, 11.202934442027923, 10.890640231870837, 9.526315350686351, 12.66093630944529, 8.739095657102524, 15.823012878817899, 20.956394249393096, 14.656464688239561, 10.389984980706247, 8.869481125185567, 11.31206556673973, 13.671906628916341, 14.16253237955032, 7.813333926662323, 6.8381846527899475, 5.784829201236849, 3.6764005451433124, 2.320170210253808, 0.9083225662189146, 0.2151536638097417, 0.015904391334662517, 0.04901222163631071, 0.05672499184466659, 0.12022538786573757, 0.018140827981574882, 0.04613237838531214, 0.02824285214075879, 0.0213530327328631, 0.027475785539155046, 0.004889522181568487, 0.03539286756647691, 0.02754370306408213, 0.048532558665160215, 0.01146938480932506, 0.1149655660734542, 0.03845960945792256, 0.06023221897081502, 0.026979975349780534, 0.07487519674243466, 0.016843036733447544, 0.02562906164976378, 0.04780351875289794, 0.045383933465927846, 0.008778499060070083, 0.037436456900210156, 0.039453551083082156, 0.10570222241503578, 0.016817857338596257, 0.03532026158345323, 0.027598551129020994, 0.014338884915735935, 0.019867616975980423, 0.07658023267023026, 0.05669485394572539, 0.0701703520251378, 0.07486226517827281, 0.05256079069729294, 0.04693446478115455, 0.020879521447744583, 0.01672466848826697, 0.06156548008983655, 0.06668609221495929, 0.06050886481159157, 0.014325277278980902, 0.049513246969229756, 0.04823641588671073, 0.031751320329344565, 0.03555111068811628, 0.010944973684907442, 0.03279577204657178, 0.041944727286576264, 0.011927077336417092, 0.10172548298273357, 0.05349603849613378, 0.02508106363576747, 0.0042566641293946775, 0.02211951327720477, 0.05804919397398349, 0.02065895707346499, 0.027134966428181338, 0.09583144764145536, 0.019921057354358417, 0.036106183524093324, 0.05676469818178204, 0.026730615645647052, 0.02274268941443053, 0.041644723424988414, 0.04588729919745557, 0.024712450854900866, 0.04984692039508974, 0.08648039457658607, 0.025972992992929878, 0.06826059442133674, 0.1382819806495982, 0.17221602911670364, 0.12915882342044385, 0.2317758871903343, 0.12841146634591202, 0.13095787365830716, 0.17009807179772085, 0.21243132440553558, 0.07870745965309682, 0.15466680870421473, 0.24949404531188552, 0.08101052679722348, 0.1286368570741146, 0.2215443999176064, 0.29983219660578236, 0.1824580730810281, 0.18408222544577815, 0.07246611835134607, 0.14281516804570152, 0.14204612302203334, 0.16812251490210334, 0.10605900488313168, 0.246055030654515, 0.1456424614955341, 0.1134321261798182, 0.2279903709648117, 0.1574043013275631, 0.08057368814104027, 0.15533105289984137, 0.2152594145868094, 0.13077330775558949, 0.11127754985805481, 0.16104481243077787, 0.06826572721042941, 0.09411333459279231, 0.196609785479884, 0.13170741408342315, 0.1825198197677251, 0.18461799669650295, 0.11125351001899089, 0.19552638393736657, 0.10128301358030689, 0.14022713917638027, 0.10099181589940864, 0.08881076509433408, 0.11812369459338727, 0.15828095106107576, 0.07164419793914403, 0.1326867195987894, 0.2219010598116344, 0.16667255560957617, 0.08855486874498668, 0.22465537572580002, 0.07778827671802814, 0.1481864709527262, 0.13002784291823066, 0.10863172731572583, 0.16599930221996, 0.13653854839503765, 0.11091116064738844, 0.14532251253483758, 0.2278306722761162, 0.2519412212554486, 0.15777125744329346, 0.08433465890946888, 0.14625766074224827, 0.12735278646071113, 0.12979841490666713, 0.22732143831108848, 0.1171711178856992, 0.24247255837244375, 0.25476655352019495, 0.6851457708304929, 0.8982963139011014, 2.0034961835030587, 3.9198350954440335, 4.553802638284622, 6.382027220341468, 5.91831922531128, 7.715249667244573, 6.985881501628507, 11.696555902881007, 13.889361850677, 17.410363728000274, 16.626230939742058, 14.034713122152514, 17.247006816248742, 13.810470238808664, 23.43638731587318, 33.13626558549943, 24.869784155199607, 17.408386853433427, 14.21205230297581, 17.540662903939527, 19.97400329959008, 20.531572141954978, 12.667955390868649, 10.033692563733748, 7.47225099032925, 4.983175185418898, 3.6879122113027885, 1.3295865323274367, 0.47915033575507904, 0.08961787702695978, 0.11110583891070659, 0.1614247767194625, 0.18611723076431982, 0.13635579045982132, 0.18216257764687463, 0.1086972814594065, 0.1332151057619241, 0.1359863522192163, 0.10315101939223467, 0.13872134739593153, 0.20966225363794835, 0.15369095058450777, 0.12870888466075545, 0.1694398184096621, 0.19697197652872533, 0.26428393959518404, 0.1494704036703033, 0.2218907635899321, 0.17801586628681232, 0.09408188668350059, 0.2007429217619281, 0.15754967417207458, 0.15976927603685087, 0.10208380528755727, 0.09041197312575194, 0.2257618211930798, 0.15854744240641594, 0.14371472380815015, 0.17580410916238062, 0.11569300486195473, 0.15849079786529466, 0.09606826074060895, 0.1354210712616482, 0.19031975929054523, 0.22559320524094567, 0.07763007956166422, 0.11633146253805007, 0.07878856538164039, 0.15468828980961155, 0.2031412672611975, 0.13883606140171328, 0.11124420971159013, 0.1113429278015129, 0.14271985138616256, 0.11857639893048233, 0.13010417591900597, 0.1290252636517248, 0.19027825264680773, 0.09287223385106172, 0.16424132961659663, 0.1263386852318241, 0.12769538098044936, 0.2186617949196408, 0.16803528813104476, 0.11648832670142574, 0.12484780152238185, 0.13384089234375185, 0.13135680628399696, 0.1773545638688149, 0.2054546842531812, 0.1802351463946604, 0.12539504110933314, 0.19278598017990592, 0.2347912245820607, 0.1377168375878565, 0.09040939140944712, 0.2150799967949429, 0.246465485242586, 0.17642577419117575, 0.1710874743519291, 0.22201825594229085, 0.1493132637152749, 0.21005121179886405], [0.03679505744648557, 0.039399744897720315, 0.0690936537519578, 0.007500919605410028, 0.03466538664314055, 0.0716013276589013, 0.05770874450043325, 0.040067271780102484, 0.05154249896746009, 0.12527359319069695, 0.010677308309823276, 0.06052759566134023, 0.010036190393410865, 0.02141899673358327, 0.07261709129858403, 0.04298490231796619, 0.027267049562426347, 0.013229021738703935, 0.07178985423618747, 0.05360527880369656, 0.027896365894365217, 0.04371106557007279, 0.0342877091269099, 0.11442800217698659, 0.016743202070375125, 0.008169217842570957, 0.016278514202924508, 0.02435369762561975, 0.003986602814327325, 0.06291722308003134, 0.0545061445764957, 0.019285706164796027, 0.05569564929652599, 0.025636100082568107, 0.02184372545490342, 0.04791893372913042, 0.044121784458477656, 0.0529938793530868, 0.05660005822597493, 0.022789238831929626, 0.0358154914612251, 0.041204862551943916, 0.018804520593896028, 0.05310752849665381, 0.029028452324470686, 0.012737593572256307, 0.03875642639374541, 0.009696124921432667, 0.021529242531546665, 0.026524852090064558, 0.11692326545955674, 0.051871748235557354, 0.04521948120166217, 0.01637792177197914, 0.031638454510680133, 0.05574431886235553, 0.06909498674494606, 0.03608879332821216, 0.034718717853989334, 0.02836871464105864, 0.06846331660785983, 0.03963306463593918, 0.027619220181218082, 0.027948643734318115, 0.026938238879665736, 0.05007501158322539, 0.1240966599735041, 1.048063316172169, 1.2655721028004925, 2.2552513066799413, 4.505234870218462, 13.488632902022331, 24.553939219444032, 28.880137012850856, 32.62859321409656, 30.367656676999985, 35.90652973421159, 40.5543932607097, 49.69088385182042, 56.832864899789136, 61.919516132723906, 66.61180834616384, 74.26757674063407, 69.33651416532456, 71.25054451727098, 70.3787192990703, 67.06910963981383, 73.97549352338238, 78.57587675894462, 75.36179250286472, 61.993005660272416, 48.32564015542307, 54.38724356312906, 58.87682376369354, 66.35750539841192, 56.48066351490637, 53.8190294081165, 55.6260222004306, 40.09512685960339, 31.59487608940371, 20.248012235087735, 8.198934293562367, 1.4808408483382196, 0.14702662915712403, 0.027014443560713725, 0.08075559571866067, 0.06327273384217294, 0.034336577875599746, 0.019791236094709848, 0.03692001787825458, 0.032891084875671134, 0.030719625891276428, 0.04878323412530365, 0.04356991770046373, 0.05979236192821015, 0.022867521526472225, 0.028893628510676568, 0.015770854548581185, 0.008406864062342192, 0.05032507800346902, 0.03336659948071165, 0.06500769316429092, 0.049896949766984874, 0.055805793587839415, 0.06924865632167748, 0.012782279480879587, 0.06596459060787194, 0.025855674288205566, 0.025950161657566508, 0.08374476354689368, 0.013157976659825973, 0.12316675946837473, 0.02219684793794107, 0.026776670936434984, 0.049925256715787035, 0.0033814781026223735, 0.09047284647221528, 0.030100651746315342, 0.05316940541829794, 0.03496210015709362, 0.1566836117736755, 0.017036914434884826, 0.034188719075774, 0.030006478473003355, 0.022296222948258924, 0.022397386773879972, 0.04767152946442366, 0.0009036382928776044, 0.03172814616963508, 0.03544670822579534, 0.04507421943989973, 0.026510853748468143, 0.05581355405851238, 0.028867924345597148, 0.03767968215528996, 0.006810419661398497, 0.059805251357536164, 0.04290662728430283, 0.014451155101039238, 0.055475996566876296, 0.0981196373580925, 0.0658651294126626, 0.027944079765509215, 0.021154579571298054, 0.03288764897133074, 0.07985833055910566, 0.042610013361779914, 0.05468502227637557, 0.08518614265466891, 0.08998261148770971, 0.024787293814663446, 0.1003996222730606, 0.07659789865776416, 0.10086268411889192, 0.025939687320421782, 0.014737048580671751, 0.011248873103590263, 0.06662023163610889, 0.03749019030721919, 0.017389234440821796, 0.0965269405635134, 0.031750395278176, 0.05442087516008366, 0.014109964437422254, 0.009518594578689626, 0.14384492811176086, 0.028146449551587144, 0.0392470597439716, 0.044403727797250596, 0.04059275447000419, 0.04523129044701496, 0.022446073576687806, 0.014518115016060972, 0.05048551979745108, 0.04442854904599729, 0.038666058662197286, 0.08683057336677467, 0.040678992987640446, 0.030962676861353462, 0.04633060746615933, 0.057502831557705525, 0.08924785655953231, 0.016593025854578423, 0.019581603795109738, 0.03525477638768573, 0.070940722380915, 0.025491987452692082, 0.036472392704097495, 0.070822530335957, 0.03447256614303878, 0.04197150205952987, 0.06045422742083188, 0.031242909908835447, 0.07023801291061026, 0.042172527361300685, 0.07638865706300543, 0.010582008887262595, 0.038755641153623024, 0.034954929574122356, 0.1104139312801342, 0.01313743880018592, 0.029755582762581688, 0.01848298200075665, 0.018038566735002304, 0.030821797122517904, 0.07087110797123564, 0.06534661812287185, 0.025513466642869097, 0.09039063757706074, 0.05384819762360665, 0.058888788034598676, 0.040212931907585556, 0.05174571528069435, 0.0468138633896747, 0.03065951097185814, 0.027880076949875203, 0.07001705017061004, 0.03415134547638797, 0.06602312738616621, 0.04014169722194633, 0.018910133475137335, 0.0388349580668634, 0.11903872533190636, 1.2586714279267097, 1.5027119844190537, 2.5732930148801496, 4.518007088092066, 14.145877995798665, 24.836394979107766, 30.121182780111994, 35.89479792502619, 33.43052179582658, 40.478703283494525, 46.00863333671324, 57.21444483726256, 64.37368431398946, 72.44707922781669, 74.74540771976595, 84.03835773468018, 78.68430675998812, 78.56580411234211, 79.0319150493991, 74.65246323616275, 84.62902745892926, 89.89314633031046, 86.11254630550262, 67.71906206684729, 55.42701682736797, 62.14810402162614, 69.6177637961603, 77.79370123340239, 68.8809936277328, 64.02863340993082, 66.78622045824605, 51.67706228071644, 42.88513621976299, 29.100034890636323, 12.55441258030553, 1.9900408603491324, 0.10992239394615735, 0.048762921303991354, 0.09816593971223601, 0.051109069402539925, 0.10394930599197265, 0.013889262167316292, 0.03582533952149172, 0.05006249370654264, 0.023216294545319774, 0.03807969879539263, 0.03200650996258182, 0.01698284969484854, 0.036225474905222654, 0.03658108142835479, 0.028874660173671383, 0.0200131181402192, 0.0198748431003262, 0.019176168998162595, 0.01305721790319489, 0.04701829395226894, 0.03690720122728137, 0.053536457295018824, 0.016197282069873427, 0.01675818291973443, 0.005344572184126704, 0.08407431925016065, 0.05378962254091617, 0.0124076921718135, 0.02458406409489051, 0.020169905694802443, 0.007897873330230435, 0.06280192684742712, 0.02669527026404056, 0.011579597090941765, 0.028286136108480638, 0.04596510691748512, 0.045629748098191716, 0.05821350834242279, 0.009189750379582327, 0.03089261429023839, 0.06994088570917807, 0.07021493834233092, 0.03293166838345989, 0.05686594436185495, 0.019304109511957056, 0.05417194254996796, 0.020199934426214428, 0.10963813702185309, 0.014589468445328456, 0.05139302372211411, 0.059868503407004385, 0.07595292923431243, 0.029357081061349283, 0.014513908235746768, 0.02833680516379255, 0.045647770316610416, 0.046402209874002204, 0.021757919776944384, 0.008592407684773207, 0.04708384809594962, 0.06941891170196957, 0.03278928328185313, 0.038220900291156386, 0.04720159964035115, 0.07150063306213388, 0.11725986151084786, 0.09037142409191978, 0.046085551260940494, 0.10167316683838445, 0.07100079133505784, 0.03400632120188206, 0.03048907173046422, 0.06390552246762861, 0.17608731654622864, 0.1646140313917591, 0.17628527366586272, 0.26202113037147834, 0.21696141680642483, 0.18632773640415362, 0.20298406601913516, 0.20940195228303635, 0.18176381356052815, 0.31089266762137413, 0.21111072671990241, 0.13840669976367106, 0.13610573936133616, 0.2195442515996195, 0.2064923503466191, 0.1611016561547595, 0.11369720026249848, 0.1675004361858291, 0.17397695881945474, 0.11252438093745902, 0.1691909011213049, 0.15628847894409012, 0.20626332070077621, 0.2135772540444328, 0.14089686856154474, 0.17590915513855798, 0.13127598400798537, 0.08350491673955995, 0.09343616649388306, 0.1132621389302996, 0.15101543447423368, 0.11353844386194983, 0.16973871527419937, 0.12044580668331155, 0.16385054816642117, 0.13526253702659763, 0.1433163734092828, 0.24197403431659747, 0.19496350849588073, 0.17239477275119675, 0.12089204523832568, 0.1313390943311876, 0.15789219208302038, 0.15454714577044212, 0.06441756797533843, 0.10225268170958567, 0.051045947588018836, 0.1678355383656679, 0.14168207804041524, 0.11897459611176484, 0.18216660726935635, 0.16080173273240367, 0.19631707860577494, 0.17914140266516518, 0.11239550962683656, 0.13612279247853065, 0.12620663465631585, 0.17541487520981222, 0.11376600261897811, 0.1795535426466696, 0.1592332902815073, 0.09632535984799748, 0.278537311861592, 0.08065594300147026, 0.17076916481939056, 0.23911502482669972, 0.3977017369001143, 1.9386939704418185, 2.843408017389236, 6.076718261165004, 8.810721078226644, 21.46677697858503, 35.4453609835717, 42.83571827796198, 49.65845369523572, 46.6319920939784, 54.6059274673462, 62.180557712431884, 70.49377026096468, 80.44712974179177, 86.98033932716616, 91.05306179292741, 100.23306323635964, 95.80504463564966, 95.66238803248253, 94.90794366405856, 92.74913387913858, 102.79322562679168, 103.4971498673962, 99.51705809562438, 83.39178639073526, 70.98256034235801, 75.96607285161173, 82.83437052080708, 91.06144782035582, 83.72740007215931, 79.86377131554389, 79.70978690731911, 65.08892851491129, 53.86675680837324, 37.112415375248084, 16.094760567911212, 3.508399056811487, 0.36293568630372325, 0.11468564520680136, 0.16377110484867327, 0.13444384950543606, 0.15548998550061258, 0.09969207878795364, 0.13152811886562457, 0.13345505982156725, 0.09480351086465583, 0.1676820909544345, 0.26218305071515424, 0.17170166236258325, 0.09882715786056173, 0.07630254111943707, 0.06707150338878555, 0.1259384349349045, 0.1063244773315326, 0.14618229301225755, 0.23024499836948611, 0.16066498603791962, 0.14111428431445552, 0.18030000339833, 0.14948676730836594, 0.21346565035562362, 0.1736339352904789, 0.2105979840721815, 0.14649732368848017, 0.13771774157160713, 0.25084384626919226, 0.1045660527362939, 0.09903387902604957, 0.19348908035505205, 0.110598343965267, 0.19695385088843687, 0.07867843258164584, 0.14144733337865723, 0.1496484271821476, 0.24734130760114043, 0.12468562836969092, 0.14987800841129598, 0.20096255916981928, 0.11029097416828718, 0.10262435692692957, 0.13045352733423635, 0.0982264836408919, 0.11837654191279605, 0.1880514342337847, 0.1491254495997583, 0.0760024644794964, 0.1561245208065356, 0.09897520435192893, 0.21844391951397543, 0.1585583514984577, 0.15209017922320675, 0.22819295525550845, 0.10515127496253099, 0.25726908697716655, 0.1316466786327862, 0.19519676694706564, 0.2513653069974915, 0.10221561837580898, 0.19219394743202195, 0.2359932778222907, 0.19385690981101608, 0.1681894403431685, 0.3599793836474419, 0.37859648466110235, 0.18390250121874196, 0.20959408713444588, 0.20756894902836895, 0.17609200500432523, 0.18995635782278356, 0.13864331367996433], [0.024086635544775956, 0.05591560463090578, 0.046668279870984056, 0.011895415880116484, 0.07553539599382109, 0.020027518677975864, 0.030787464892191273, 0.10265885386615993, 0.041835594231322895, 0.007648323061725786, 0.06543691690650678, 0.04111070651561022, 0.0405380443008917, 0.03107835039226038, 0.007535787618478701, 0.016339479479938745, 0.02890991362472696, 0.010136607283305739, 0.07973287600062548, 0.034928901736894925, 0.02550647609056004, 0.0361039771908714, 0.06630800484168915, 0.03841197794123042, 0.04668245632802287, 0.029074417599927516, 0.04467665045071514, 0.005744919199646721, 0.030802982003097574, 0.038611773671882774, 0.04711730698604257, 0.02802718115309554, 0.04105696927816157, 0.03343527543268377, 0.023656678273372596, 0.02214972586971858, 0.01698603662061355, 0.05804625219635426, 0.029330980445769046, 0.031210481407000657, 0.030530224058536753, 0.06463414869241177, 0.012494784877485326, 0.019217390274148316, 0.0674517587908814, 0.07607332761249236, 0.034180307430365396, 0.15687210004656546, 0.033284095641706264, 0.01438486934339087, 0.07938371610737617, 0.005528093334437619, 0.07898415528958844, 0.07399541370931172, 0.05570268964455013, 0.07733130527119483, 0.03796318448298881, 0.028479379872160576, 0.02031026066340987, 0.018284071101656845, 0.029801369922596122, 0.02577516610824293, 0.24617210421110355, 0.19140072467346347, 0.8953206445420943, 4.164999165842611, 10.273992649970516, 22.013239629807014, 23.996717506839385, 31.921584029351514, 44.18285239127375, 54.468087534750666, 64.25311065489247, 74.5359060841222, 79.32516713296214, 81.94822080673711, 79.88401859037339, 81.7181267276887, 93.13141592087285, 85.34839014853202, 76.11514645238077, 90.2158946375693, 82.32193639201503, 84.93617257764264, 86.52412060768374, 93.96677878595169, 85.10309296269571, 88.53389601553641, 86.39680047189036, 79.39185527063186, 84.71965774413079, 78.8305405647524, 85.3842249224263, 88.06494528247465, 87.13055826002552, 85.71251161636846, 72.60435842698621, 79.5387480335851, 79.73832607269287, 91.0573293316749, 87.82069929184453, 62.041960762393096, 33.90020208974039, 10.478133386181248, 1.8267288107064463, 0.35429372422156796, 0.06277492607853587, 0.07803003874517257, 0.10822960010339176, 0.04734304628425068, 0.0665153005731202, 0.059961418380900744, 0.018711772244123202, 0.04825132778815685, 0.06390378727848012, 0.019282532645569696, 0.029097959481840654, 0.09024062223972813, 0.03134093085874713, 0.01296181122832481, 0.02028627636572046, 0.011575512884695445, 0.015593577972463062, 0.011907593805282828, 0.008111368628188727, 0.036768577617382815, 0.029385248199105266, 0.05600271648877571, 0.01266389878677024, 0.029857943600584424, 0.0985208759084344, 0.021629515779955734, 0.016014779816501807, 0.06229216045129204, 0.05474446686886011, 0.013655732712528158, 0.03581154993885467, 0.02191613608550641, 0.05100436050504927, 0.08373394638540284, 0.02499981043529847, 0.0304385444014183, 0.041673141456539595, 0.06167552862015944, 0.06505036426167335, 0.048678617158363906, 0.06307807090061326, 0.04058189900411714, 0.03576767608343113, 0.030787083763448946, 0.015841387306159783, 0.0376847536573487, 0.014268432597389386, 0.03286765407650702, 0.06267319343263103, 0.11095058353197192, 0.03965703935752954, 0.0727053369665819, 0.00667051189661687, 0.016923564065608288, 0.024183409686590877, 0.019930558759839307, 0.020762486195552255, 0.05303048303410892, 0.02985825961185319, 0.02419447774187692, 0.08346204645931722, 0.03401415828134745, 0.015693085132947853, 0.04913012639829709, 0.07022394753632046, 0.07448204041969392, 0.03263974291903358, 0.022068286892927943, 0.06289661148442857, 0.038091312688324726, 0.03518123577739443, 0.03654070859474521, 0.01602897829856844, 0.05963486574229695, 0.06933927686224062, 0.030068889740974675, 0.02601872269634999, 0.12113906262863068, 0.03836353437133855, 0.017421105613691673, 0.06666301764667996, 0.070981455275849, 0.058166531830905914, 0.028399132162092194, 0.052336526118339076, 0.024555699689494028, 0.028875728866325754, 0.016086049933707523, 0.15151875424048594, 0.020275721589343685, 0.033385410769692356, 0.061364029609267755, 0.026938913037039103, 0.030412934082109603, 0.007912429479596717, 0.03898843995205337, 0.03763156800320552, 0.07503708644259362, 0.04261984993072768, 0.0329768062839585, 0.040172264130125125, 0.018666975252750902, 0.024152902150226217, 0.08183666069300906, 0.06548917176382196, 0.010769230242247784, 0.027294134600989284, 0.036610575813439586, 0.016580167068769375, 0.017403137021427675, 0.01983211071590983, 0.041022591082559484, 0.026464041945854985, 0.02042910579832331, 0.0499132406266947, 0.0897455762230581, 0.04235730393819752, 0.06975179222682792, 0.07887387693288826, 0.049036889667472536, 0.11465072691921266, 0.03815603562660756, 0.06914256846592312, 0.05153526709745488, 0.060675531069958405, 0.05511263723395044, 0.039750379510223866, 0.04292954097411806, 0.035235792728922063, 0.08088543230006773, 0.04263256699027073, 0.06299768146427889, 0.22691127483642873, 0.5831281708613519, 1.3439442457691317, 5.863359464753059, 13.702027490062099, 25.678994617154522, 26.893336888282533, 35.774467452879875, 48.08795629009124, 61.322307817397586, 75.03301943502119, 84.6923815819525, 88.87686021866338, 90.50970369769682, 92.14178623691683, 94.70973060977076, 105.69545007521107, 100.91749329720774, 90.32114751877324, 103.31890952202582, 95.0321965063772, 100.1007224667457, 99.46460031693982, 106.68007481482722, 99.14407991593885, 99.41726515370031, 97.35038003613873, 93.66691358627813, 98.44043024124639, 88.59145287544497, 96.72522483333465, 96.97514257123395, 97.06582776961788, 96.3768477593699, 87.39272163760278, 93.42697435809721, 95.67471996430429, 107.01205638147171, 104.32652719559209, 75.8906456731981, 44.842751949064194, 15.375540064227197, 3.1014043669546805, 0.5429953985637235, 0.0961214425643125, 0.1371364493764216, 0.04284645490829022, 0.064414304440781, 0.045771439890227014, 0.039993298330133965, 0.07388825333046337, 0.05906548238389435, 0.04601242050768868, 0.03593920700011715, 0.007106039584839657, 0.08429865277702771, 0.040503857627270684, 0.005366519645547434, 0.028926397921637665, 0.012967505176822025, 0.019833315389170762, 0.01181759762637798, 0.07732948964281429, 0.04148733066094499, 0.01612717544870271, 0.04684072626273959, 0.025073462128338796, 0.016807947991295688, 0.02916092807877689, 0.03132025606089062, 0.06596125046452207, 0.06208661140032834, 0.04049441559360393, 0.023900807512203054, 0.044724714807084495, 0.02933638902651447, 0.05080401319109144, 0.05574225042495997, 0.0039134660760136025, 0.02426617974114995, 0.026365331516811447, 0.027748235133326346, 0.05129858040280881, 0.02088072229056589, 0.05288356269199041, 0.04263444390568522, 0.05828170931988186, 0.0711951325196893, 0.023130672728462566, 0.07292390951225836, 0.020907958631493875, 0.04065923174963363, 0.029909453437393232, 0.02769553594501509, 0.03623529232197231, 0.009572434280398152, 0.07475328151016467, 0.01697295949974608, 0.03612898230071991, 0.021014102028622743, 0.02380315619971483, 0.04929433351442699, 0.03642273488484564, 0.023999198099538207, 0.05391073721130529, 0.06382820121343098, 0.01417143724768633, 0.037451345819018544, 0.05905179239268746, 0.04828975092799914, 0.05830354282572385, 0.04135888835956012, 0.09655910093457469, 0.012160410481174628, 0.13344759812518475, 0.14563280878768814, 0.09891815378420776, 0.11622505292536751, 0.145926833333027, 0.1589062013813565, 0.15240654289241762, 0.21354869428661563, 0.14636131243840342, 0.19520890177978625, 0.2054235810834554, 0.20277284025665254, 0.1716338789030429, 0.08423634684614598, 0.12737657349076004, 0.07936837902713208, 0.12144751260958372, 0.1350738802143643, 0.2533179731859315, 0.10539601707170088, 0.1676072441642323, 0.1770485730300988, 0.2528445155269677, 0.11585549211069462, 0.16875053846066998, 0.13315866040366311, 0.09771572516089487, 0.20513490383182803, 0.12240581965494542, 0.11972037504517263, 0.12523629236966372, 0.08698595131957725, 0.13786168949257943, 0.19536680782273894, 0.16107305043166684, 0.12648342988423764, 0.09279347235156644, 0.0835227512664372, 0.10062074589152491, 0.180548093311729, 0.16158548664421807, 0.10560344303807906, 0.08056691592378963, 0.12619811575859785, 0.15014882049252912, 0.2826316534511505, 0.14233556636158498, 0.1433938555419445, 0.1361259181172617, 0.1329548044070121, 0.2596403742509504, 0.219471825647258, 0.153778008816223, 0.11668559434192798, 0.18450564224152796, 0.18835920239648513, 0.20459376996563328, 0.1293709838101941, 0.18541088237637476, 0.20580287121476668, 0.14861578662549296, 0.10751580534082268, 0.5603724790196265, 1.1662622252779624, 2.676840400503528, 9.886431097984314, 21.338466444323142, 35.59368148926766, 41.870383754853286, 49.86546070344987, 63.33503284761983, 76.86824152546545, 89.92536467890586, 101.48749997538906, 104.05215740203859, 106.02322686103084, 107.99214686116865, 110.1966130348944, 120.15677390560028, 112.36880594684233, 104.08558384064706, 116.95608846602903, 110.47132799702307, 113.79140253989928, 113.41788307312997, 116.9887774990451, 109.47170411386799, 111.02471951515444, 107.49817140640752, 104.46662641340687, 110.30412520131758, 103.41706291321786, 109.88845594467656, 109.8308127926242, 112.17015358709521, 109.80101846879529, 98.20189522158716, 110.63265508221043, 111.40471089270808, 121.70972654896399, 117.82647809674664, 86.75062964039465, 52.82832107236309, 19.634935971229307, 3.8666421175003056, 0.7953513798213775, 0.19243056134831524, 0.3171545783838918, 0.18019273576717224, 0.172391310033779, 0.13457393123497888, 0.1690171217365611, 0.13260320069328432, 0.23437549930907067, 0.10711436760762047, 0.1421762660386101, 0.12152349320991386, 0.1925049025204874, 0.15837156394075963, 0.065926730542654, 0.13257238863696977, 0.14134985635117178, 0.1811281444444772, 0.09218058669038358, 0.112548612298504, 0.13786070890003635, 0.050984070666374705, 0.14476273208856583, 0.1164225274096093, 0.12338373855116869, 0.17355936429192945, 0.10709133900461659, 0.12239245142066672, 0.24518775783719557, 0.14085418214240383, 0.08648595637491635, 0.19297719572580632, 0.11343365069478752, 0.11186929149252754, 0.20899330566246666, 0.11205379610821126, 0.09734478538795825, 0.11374672018592397, 0.19536679250098046, 0.18344510076267107, 0.11835522934674256, 0.16336904658425241, 0.12240353671293105, 0.19113650094837914, 0.19151988198920605, 0.11339896989445533, 0.19872086332930675, 0.11078123979630972, 0.1478874974793965, 0.21118992488951455, 0.14629522969405498, 0.11334200359640584, 0.20362503646362215, 0.17159232629402993, 0.11599920254441039, 0.14950204310157608, 0.10953512883955434, 0.2307694928059655, 0.15984484294970192, 0.15267055211288316, 0.09849708887838549, 0.16352624782631475, 0.11332020839496006, 0.08702069340694336, 0.23922719542057286, 0.2096198583322187, 0.2313259177871289, 0.17559571792521786, 0.11666900087748805, 0.1614837501678736, 0.1026714866560313], [0.02466329673845922, 0.0509734220442272, 0.017238862872604403, 0.014127574883581651, 0.03033352906875793, 0.06566318863582227, 0.06957062775449407, 0.03793229581788182, 0.030320775620038473, 0.04422326046492785, 0.01747381054766236, 0.05016314616847423, 0.0158920391244934, 0.01199739558937689, 0.028215834134889227, 0.01652042370199436, 0.03338266051404419, 0.02495998343933494, 0.04410701811373715, 0.03474189967457806, 0.026188315410587578, 0.0781063947285856, 0.009348007865370283, 0.06917326560904903, 0.06503022381014402, 0.05310874657645341, 0.06850188913484735, 0.023261725474449418, 0.08095506969238482, 0.014743821755532297, 0.07653157076527996, 0.11861612825023553, 0.046236217773008736, 0.04352955635817301, 0.03365909185020193, 0.09383135294962315, 0.009217758554094022, 0.009380953476553964, 0.06865342132627003, 0.00807567467657669, 0.010367120266892016, 0.02503018390627638, 0.030043442215349887, 0.08946680448829167, 0.01972620480603749, 0.03924392261392167, 0.0012547728974529873, 0.013481940878855606, 0.04517716250472492, 0.019244655343373458, 0.03275153812982383, 0.047105505401569034, 0.051630645044027805, 0.0607176429231561, 0.034518087087499524, 0.05976403199677026, 0.06587081378506077, 0.005629806349339385, 0.043139265204269084, 0.027392925469264872, 0.30335322863632636, 1.2195565719758312, 9.672614855151023, 23.542916928568197, 41.80988511731548, 47.792358629165165, 52.80657937449794, 55.09299170586371, 64.32980868124193, 67.05662865792551, 71.61376383996779, 78.40146464686241, 70.63550902951148, 75.74525910039102, 77.95877810447448, 70.10398864746094, 69.85898956175774, 64.10987746331, 53.842465569896085, 94.31747005831812, 59.45979779766452, 39.9375730945218, 44.52629512356174, 41.58108149805377, 57.850908233273415, 66.15048270071706, 60.99005560721121, 53.99934076493787, 48.75739112977059, 51.14084289919946, 56.88868807208154, 61.065463173773985, 76.70074847436722, 68.13070697169151, 60.4707298740264, 58.22491799631427, 51.71252835181452, 71.99363754641625, 62.60616233271938, 68.7218552251016, 67.07784868055775, 87.88225696932885, 80.06493399220129, 71.94569833817022, 34.25476866383707, 14.121829944272196, 3.5003270641449964, 1.3638874143362048, 0.18692902349416288, 0.07497340921432742, 0.05648612179943631, 0.0496124591858637, 0.013395527118606674, 0.013018524717359294, 0.04592364240858344, 0.030041961750436216, 0.03345502517937172, 0.06564874021757035, 0.051518711937411185, 0.037912978910871094, 0.024374699926063902, 0.05270727819973423, 0.03348266563167976, 0.038508600780680295, 0.04160360365565266, 0.006362293657260917, 0.043506098745931546, 0.03177845133318296, 0.032127766359236934, 0.04469118313863874, 0.025522864626480207, 0.07519860075966966, 0.04714257256578534, 0.05948350209021761, 0.037760646157567544, 0.03374125861052064, 0.018020349164162914, 0.02720658224256289, 0.025339357840317874, 0.0241039855210411, 0.04327814545362227, 0.05425112922826121, 0.07527594499650501, 0.07909959707889827, 0.05160182098587675, 0.0250743220620338, 0.012236398742384007, 0.025888529884058143, 0.05357442461254616, 0.02517833381951336, 0.05319557498179136, 0.054857890016489455, 0.08270705914905957, 0.09873671352022118, 0.03315564950988178, 0.04034888570106799, 0.037233803661600236, 0.056147101079864856, 0.04147826784080075, 0.033071081063920454, 0.07655504369927991, 0.030263041318844885, 0.04902744763380578, 0.06519144701380884, 0.014362399026961818, 0.037185042165219784, 0.04946057076355623, 0.06090167639476638, 0.08619259832607162, 0.0719542260612211, 0.02260688117765371, 0.018910750175916383, 0.05074358800606382, 0.016403668071894396, 0.016837794776825656, 0.01894292778395597, 0.059973806022636356, 0.0627575014086981, 0.0459491569669016, 0.06859621754096401, 0.02160098666565553, 0.05496048834174872, 0.09707524501267942, 0.05278599373395405, 0.047959658963185166, 0.07464759202013094, 0.03354794781414732, 0.031922987226637146, 0.012269615357170903, 0.043477385770529516, 0.030867553639015367, 0.0232134887482971, 0.03919262919695147, 0.03946313101257529, 0.0250689345487063, 0.03019146955451898, 0.012308337271303661, 0.016961849309624206, 0.012808305402887205, 0.0279392265985089, 0.04246955497130271, 0.02653665942019753, 0.1115515718476907, 0.038317948309404236, 0.031786772963260455, 0.02872054626594388, 0.04160559931469541, 0.10431744954398564, 0.06266517249206383, 0.10090346297910137, 0.024077233730725223, 0.03398403187372512, 0.02177191620332099, 0.09281731300777005, 0.0623525741450008, 0.09328885544692317, 0.07206101105698655, 0.05188893924857821, 0.015458887266445787, 0.07111488480962093, 0.006208166821799692, 0.016869085638092893, 0.04727805138475472, 0.0661780456862142, 0.006505335679262757, 0.09155412595118247, 0.041440415436462055, 0.031011223853115114, 0.034255445333978826, 0.025828510725630388, 0.011211085816725128, 0.023728454966218244, 0.030705526043030045, 0.01562839283818199, 0.038680664128473694, 0.021079060538942297, 0.6675151459151699, 2.4583504084617864, 13.070617087425726, 29.309430622285415, 47.3056552487035, 54.45999960745535, 61.54966408206571, 66.93259546833654, 73.8216503204838, 77.90730876307335, 82.59611006705993, 89.04790693713774, 83.37743836064493, 89.1067817134242, 90.16650415235951, 81.7469169247535, 81.06764085831182, 75.59882133237778, 68.05470712723272, 98.06552225543608, 68.7799612168343, 54.87775164265787, 58.65180915401828, 51.32235842366373, 72.04271424201228, 81.67349799986809, 71.95671235361408, 67.1939508376583, 61.65089261147284, 64.00337726839128, 70.35889564021942, 72.23196860282653, 88.92409340027841, 78.46463834085773, 72.8229050482473, 73.01257518029982, 58.031949150946836, 81.58100851120489, 68.88716743838403, 79.26944594229423, 78.69203382922758, 100.85051490414529, 93.90132227251607, 86.14860857686689, 46.515795799993704, 21.02634579904618, 5.7539449487963035, 2.5001305149447535, 0.32981963587864754, 0.15942858141516486, 0.10004337606651169, 0.07135848544778363, 0.028890688648267143, 0.0812356417337733, 0.09700319444340083, 0.05124573182735232, 0.04966696634167626, 0.08355020785764342, 0.12229200197203506, 0.04986183612697548, 0.06493236373869643, 0.06925896020425905, 0.02225261530838907, 0.027570142673568863, 0.04665148339324421, 0.03427534063737239, 0.010397409468198256, 0.10709444166070993, 0.019625378059103124, 0.020784509308155508, 0.006476925308590816, 0.058816369743116444, 0.08801110719721164, 0.03262755062971865, 0.06561549966253581, 0.06965825289127327, 0.0141001470206726, 0.028097963846859433, 0.009729377925395966, 0.05358608447075371, 0.012224040786555458, 0.0011028833978343755, 0.05694209733196805, 0.015251211363882309, 0.09365686876398903, 0.020704617828971917, 0.021481254783969735, 0.03731768262842971, 0.0448690036371831, 0.05163394305254183, 0.03950043949448774, 0.027603285552393046, 0.08965967478410852, 0.0262103691667078, 0.05597886051081362, 0.013372629708159837, 0.13263355309684433, 0.023156101101889245, 0.044691474252049966, 0.029071491144056764, 0.0843083514501491, 0.03578110560474377, 0.04796109154760357, 0.04034433130835814, 0.014791138218565574, 0.04357217765984036, 0.06140249105350626, 0.049476857792826436, 0.03103068248639184, 0.06703022657142532, 0.027729257220222105, 0.04674621782596073, 0.09101929698860453, 0.055519866591860215, 0.06620469788509993, 0.02480712591580326, 0.1896277214250257, 0.1185235771681032, 0.12254537789211159, 0.1874031093452246, 0.1178507298050869, 0.14099540279036568, 0.20846585412659954, 0.14897471413977686, 0.11112613257982078, 0.23141723546770313, 0.07526889698760164, 0.16466286183605272, 0.16751655467575596, 0.12868600927533644, 0.16805074778535675, 0.07074186127753028, 0.08370920174544857, 0.1899616438294611, 0.09994357013173642, 0.25568271806884196, 0.14808208381216373, 0.1890924098270555, 0.11717921543505885, 0.13729469249806098, 0.19185791062491556, 0.16036110960187452, 0.29890915258757533, 0.19265243573294533, 0.17459341445036475, 0.10690117299917246, 0.1752953042065905, 0.17989993696251225, 0.24818035773932937, 0.1707443129271269, 0.13927506042584298, 0.10851093057182529, 0.09340336260896537, 0.1264592444884681, 0.22821232195823427, 0.1728529699387089, 0.12437851138172612, 0.13491137764386593, 0.12728442077434834, 0.23477239414088188, 0.09474364109337331, 0.1555136116521974, 0.10893532796011818, 0.1302359430419822, 0.19335381987114109, 0.1592707673027631, 0.08899985091580499, 0.1212040881716436, 0.20765142605429698, 0.17901567231503226, 0.10518525096197283, 0.09501631476826246, 0.13511794559176893, 0.07491368499975051, 0.13410975856165733, 0.14726998464715096, 0.8769185384435039, 4.369729238171732, 18.883968783963113, 39.18374061584473, 64.44971553740963, 70.59103719649777, 78.5777908755887, 82.97956881984588, 90.38729436935918, 94.02568494119953, 98.57299066358998, 101.85619492684643, 98.88127326965333, 98.49160932725476, 100.81508805674892, 93.11758564364527, 96.23511683556342, 87.1921786954326, 79.81376894058721, 110.94155742276101, 82.23104723038213, 61.87279678160145, 67.22388636681342, 63.15379973380797, 81.61987135487219, 87.85370995921474, 83.34689878648328, 78.21358311560847, 69.92151214230445, 73.18488490196967, 80.65962806824716, 83.72030058214742, 98.49795572219357, 92.05540780098208, 83.46387955450243, 79.67639184767201, 70.64833517997496, 92.81102888045773, 86.10379157527801, 93.10579499890729, 91.22625012551585, 114.41618903990715, 111.87565418981738, 97.3213388073829, 55.82162295618365, 26.43473336773534, 8.633685881091703, 3.8867761338910753, 0.7206115354934047, 0.41308208579017275, 0.32456997241224017, 0.11003045830875637, 0.10526238835506863, 0.22498657085722495, 0.18565109690591214, 0.18016895639800257, 0.30742881639349845, 0.21677976203781946, 0.2024957462544403, 0.16475931230571964, 0.08879624772816898, 0.2018918544654885, 0.13311122423939167, 0.06346069734483477, 0.2230848188722326, 0.10810086668859567, 0.11147381392337623, 0.13690141360125235, 0.08974654149384269, 0.22369103956847425, 0.09072222341332706, 0.13996311463415623, 0.16377387808695917, 0.12173790589816148, 0.1590444955734476, 0.20502544518920685, 0.10789100456261828, 0.12431954559419425, 0.12341894029128937, 0.19315537245523548, 0.11265792538441959, 0.10596357331040407, 0.16912501755981676, 0.18085792991182498, 0.1776152329459306, 0.09278173588456647, 0.06782619192475273, 0.14171724147613973, 0.19579261481281252, 0.2053716556439477, 0.14318149596933397, 0.10589573622470903, 0.15522015401192252, 0.1221006868347045, 0.17795534534079416, 0.14659253309570974, 0.2735003450464818, 0.1375363319511375, 0.2077093116578556, 0.16898819425654027, 0.2629800885915756, 0.11621391400694848, 0.17987206668382694, 0.2878983547129939, 0.09256841104117133, 0.11611140378180052, 0.21050643656523, 0.1335784919079273, 0.16700604900477395, 0.1693065191108373, 0.16480720812274566, 0.12131602127826023, 0.22293924684486083, 0.16374121209786785, 0.09124679445859887, 0.1430048360939949], [0.055512029512394825, 0.08064766159100879, 0.010499960870572157, 0.045955978979867314, 0.04155949997385183, 0.05185484833594772, 0.0767438384073396, 0.03167200916176362, 0.09280148563125441, 0.04016423935911829, 0.047729445711499265, 0.02499100616982868, 0.01091147170236875, 0.04075798814395263, 0.026005902214937156, 0.04356844298120949, 0.04282496231157453, 0.022464670361049717, 0.02203710519918992, 0.037515509513116656, 0.04805204150597415, 0.0409593275417724, 0.06565180456926746, 0.1056752178157049, 0.053210031060922536, 0.06779116638485463, 0.051241545156846126, 0.03146637967156787, 0.08126967135936984, 0.024833822164744623, 0.007940406531786487, 0.015821430715732276, 0.04947439482014987, 0.0353798900370396, 0.042947015439670895, 0.05546836633115046, 0.04775644648039053, 0.06838001986785282, 0.055108216906627344, 0.04266526362287902, 0.04733997044123469, 0.0226461278620146, 0.06925575029585632, 0.008294269247280975, 0.0035200689143816675, 0.04821332599667292, 0.05267936578621307, 0.08264109897877901, 0.016961368589451718, 0.007822639665626472, 0.08373652810170766, 0.018131864752860802, 0.0538143978243874, 0.06471700876230194, 0.01720678868643459, 0.03012388719305877, 0.051939910908620206, 0.04785110430431463, 0.254546104059104, 10.181820873291263, 26.7713943219954, 46.87488094452889, 64.38003855366861, 73.53567815596058, 82.40220377522131, 81.34125755679223, 85.33448926864132, 62.311541341966205, 64.02771949768066, 71.99118214268839, 64.43470070439001, 60.23266946115802, 57.834700999721406, 52.61471271514893, 46.15945239220896, 40.53976281996697, 36.836453099404615, 26.3777256396509, 44.121690873176824, 72.18260165183776, 43.51163679553617, 21.89779446971032, 23.895471326766476, 26.516042140222368, 21.07418694803792, 27.226820722703014, 25.95954998846977, 22.54187903096599, 23.050198593447288, 26.12804520514704, 30.08967830288795, 30.919365498327444, 27.594056552456273, 48.13775470179897, 43.54978969020229, 38.739571417531664, 52.67949065854473, 37.53292091431157, 48.71981090114963, 57.08300229041808, 47.361082261608495, 55.18683441223637, 73.49098667021721, 74.09919723387688, 78.86922297939178, 63.04589533036756, 48.11186705866168, 33.05338590375839, 17.130767376192157, 4.2762047340792995, 1.3779686006807512, 0.26409214182246116, 0.028122346510269472, 0.15193015877758304, 0.03865708394216434, 0.026732241667266336, 0.06706036447036652, 0.061649945113928094, 0.05406482047551582, 0.024449512242309512, 0.050283736068635225, 0.04807997690213304, 0.07760737271558854, 0.06416077913355923, 0.03458156130246578, 0.05690805621505265, 0.10283762048329077, 0.08328363990351077, 0.03278450672364524, 0.05957735552182121, 0.05853313554619109, 0.030829546101872, 0.00920560073873569, 0.045816968495567004, 0.04298687499437121, 0.05009650034950145, 0.0521465861088326, 0.048345142915364236, 0.0885728411676903, 0.05968632003773124, 0.09491350576882401, 0.06287506143111857, 0.009703866239907521, 0.02444210417208172, 0.018750566936608766, 0.02877938181852862, 0.02999373843082257, 0.0237049839474381, 0.07550116718536423, 0.0289598185073344, 0.030806565379363396, 0.06365327269680078, 0.05781708082424537, 0.09692771946110072, 0.02786542360310353, 0.03022317027282571, 0.024809805308318427, 0.0953132198041966, 0.030229745222435846, 0.06477717730787493, 0.04213432638695644, 0.039177671330229896, 0.009629503042707521, 0.01122141651238405, 0.021818341131532387, 0.028399220262203487, 0.07370423135017196, 0.0709854848983307, 0.024272936636642106, 0.04654657148245362, 0.10767423998444312, 0.020265865868197817, 0.06443496583209884, 0.0632555121856351, 0.06953210119278201, 0.025770590648115165, 0.01971615564769074, 0.02740559847875228, 0.03491811904936068, 0.068379552554219, 0.014365399218795281, 0.06030066509640986, 0.05639089707044825, 0.04757556929102829, 0.027355438871910016, 0.056462062808174285, 0.05758499831802422, 0.010829833542717802, 0.07232013263649519, 0.055592744536097013, 0.0266362700025521, 0.003613193126042344, 0.018252301435436935, 0.030462614883999192, 0.031824173375723824, 0.050444717954603896, 0.09687639923105318, 0.023524884337319002, 0.01694773988527877, 0.03366105686572771, 0.020095168072129452, 0.034913610621926286, 0.10937251135586731, 0.029982189655364044, 0.06120824946030494, 0.03276839972503724, 0.02986893504707804, 0.03416662126959812, 0.06336286025602492, 0.05887154722586275, 0.03371905355203537, 0.02826011401691264, 0.06785916434901376, 0.06516872484597468, 0.05346191693998633, 0.04476078605699924, 0.044083736701718265, 0.03207542148659066, 0.0472552104732923, 0.036733011985498096, 0.014044326024069903, 0.004074266734307692, 0.03153304272751895, 0.027798659040502487, 0.012010615394120256, 0.027230825094926744, 0.10853455672341009, 0.07067712684792858, 0.11472852314792334, 0.015258100409541401, 0.028910277516490994, 0.030954602294631546, 0.054207094494373574, 0.07764372358759565, 0.9614961774599169, 13.873127160533784, 33.169527284560665, 55.27659000888948, 74.67966879567793, 85.09135723114015, 92.07691023426672, 90.66843417383011, 92.63369068022698, 72.42129356630387, 75.73034624899589, 83.6864113038586, 73.956022877847, 70.0612348125827, 69.89486355935374, 66.79516346223893, 56.691710564398, 52.13995687423214, 50.94253178565733, 42.431208164461204, 53.57843906648698, 81.42031684998544, 61.09534378974669, 29.267965286008774, 37.4952426264363, 37.876567609848514, 35.44002263776718, 45.4973876860834, 38.04581788278396, 36.51480697816418, 40.120771315789995, 44.36603100069108, 48.31636767233572, 45.34223441154727, 45.38609043244393, 61.597332646769864, 56.795480789676795, 52.710591131641024, 62.08645220725768, 54.67203117186024, 62.118745080886356, 69.72492294926798, 59.82760629346294, 69.03778645300096, 83.60775993716332, 87.42497920989992, 92.57489435134396, 77.26797026972618, 61.48259939685945, 40.489866349004934, 22.649655957375806, 6.592124075658861, 1.649021417383225, 0.23053427316969444, 0.0757380645541895, 0.15520406616551263, 0.026977223178912556, 0.03625319196632312, 0.17000156004102002, 0.05058077900039573, 0.03845622717973687, 0.046327317118524544, 0.05555942737227006, 0.041653556418755365, 0.1127748150799063, 0.11450647256307064, 0.005830851282113262, 0.022947160196640802, 0.06082246290339578, 0.11696650346200313, 0.058621285453198425, 0.08414676818515986, 0.027833437517045007, 0.05201023011918991, 0.07017741535579966, 0.03066282238691084, 0.0609194151606531, 0.006319340064956417, 0.03177939553654963, 0.012524966826482166, 0.046948595272917906, 0.041288063530960394, 0.02086195313642102, 0.060660714929502826, 0.04756672480594247, 0.04522919519654205, 0.026907158692577676, 0.07080228263211828, 0.04360390136078481, 0.01693709317835108, 0.013712485463568761, 0.034673790627669905, 0.04076374912514322, 0.059690341999333714, 0.04675293258661705, 0.022630398161709312, 0.027609914128157883, 0.03167722430530816, 0.06347245679447247, 0.06021032417793909, 0.10518648436353092, 0.06107924025385611, 0.04890366314700054, 0.023983993169461048, 0.004815411314578547, 0.06088051704629775, 0.08181391554253717, 0.09217698607713946, 0.09688843447234362, 0.02087066164090028, 0.0202943911520584, 0.04442145890225807, 0.0793440633964154, 0.052502035583940246, 0.06453802764055229, 0.039105421578091, 0.038374523902612354, 0.024819599742430355, 0.13277458988370436, 0.17607107548223389, 0.12007689704337429, 0.190999279279382, 0.10054936947961969, 0.1987043924389347, 0.15989447012543678, 0.1335868269445435, 0.15795076716571085, 0.21390282609049352, 0.15295066450151706, 0.10810016188770534, 0.14950323819873795, 0.17987981949362064, 0.09053020347510615, 0.10433051900397386, 0.09148001460538757, 0.2518860322813834, 0.10680515919962238, 0.16058168163703335, 0.17006004319315957, 0.11379837749465821, 0.20521091507567515, 0.20662059346514366, 0.10633802942691312, 0.146221746540358, 0.18436984549607002, 0.1625122691714956, 0.21031280018148885, 0.12320376151511747, 0.16251098214378282, 0.11985009671339106, 0.11232129102873226, 0.21405345429816555, 0.10549535569284232, 0.14498255335755889, 0.15617158924860342, 0.25106276355443463, 0.2248131745164433, 0.08134060344027896, 0.11818232330223245, 0.084964842835982, 0.12034485161664987, 0.12748918841562926, 0.1307718215450164, 0.13130020770815112, 0.10126682614246685, 0.2601346848232131, 0.10226720673663002, 0.20358478620408044, 0.17543421126902106, 0.15968771831643197, 0.3448855209975474, 0.10285096573493174, 0.14788538307672547, 0.14823237494114908, 0.17768939025700095, 0.166222371701752, 1.884623852468306, 19.67124927428461, 42.62485165749827, 70.64671131872362, 89.59951769921088, 99.63760037575999, 105.91380842270391, 103.29142939659857, 106.40161006681382, 85.07383992595058, 88.09184489711639, 95.48098625675325, 85.79715636468704, 82.99746267257198, 81.38471741830149, 75.43807475797593, 66.28542007938509, 62.81649158846948, 57.226870905968454, 45.639632440382435, 62.93701033438406, 87.09442538599815, 59.293257882518155, 39.5605666406693, 41.437997356537856, 46.054293647889175, 34.07140178065146, 41.674763387249364, 42.102152685965265, 38.03248182419808, 38.575482983742994, 42.418229041561005, 49.56979636223086, 50.8665084069775, 44.74177052897792, 65.41395964161043, 65.66268890134751, 58.67110329289591, 74.91568565368652, 58.81062199992519, 71.07086858441754, 77.94724633616786, 72.27553829070061, 81.07868625271706, 98.48577284043836, 98.86308916153448, 104.23682258975123, 89.81118448318975, 75.4000513015255, 51.92296743392945, 29.909208090074603, 9.33346123464646, 2.759357508151762, 0.6458985348862987, 0.23264550423670202, 0.348043887004737, 0.23668508586143297, 0.14998150688986625, 0.2737548394549278, 0.1556508333211945, 0.2324139311789505, 0.12498593483600887, 0.1957531459629536, 0.11903173094915769, 0.19867613911628726, 0.18172062152335722, 0.13606830830535582, 0.13447896697588507, 0.24340150126766777, 0.1935520374606694, 0.13412007010511814, 0.19309244599313508, 0.11774513224560408, 0.1933916952581175, 0.16424629386634598, 0.2029952968681051, 0.12158095746511415, 0.08075613964108691, 0.17356763804151168, 0.08352735545486213, 0.1610347460354528, 0.20633384675508548, 0.20886307071533897, 0.18711570379955156, 0.16301080854910036, 0.18886797670875827, 0.12499756405069945, 0.16623156475684336, 0.11695961633156385, 0.11792969814832173, 0.11113745535934165, 0.1172066950089028, 0.1253343822674886, 0.14770720634729634, 0.13315409451963442, 0.24813295221857487, 0.2274363208562136, 0.20016441812678692, 0.11478286176439255, 0.23770658749966855, 0.17789036576305667, 0.11401132695497045, 0.1021922143897222, 0.10872377277982813, 0.08509822640447848, 0.1547123909357094, 0.17068515561761397, 0.16332488927629688, 0.18574318067441065, 0.165468571827777, 0.08645458507441706, 0.15102229862203523, 0.1438576758148209, 0.20835906146995484, 0.2079142708211176, 0.13711956479857046, 0.22987211273322183, 0.13246101477453787], [0.03602985818419726, 0.05587293353352336, 0.04086145980944557, 0.03033824625515169, 0.014948239869197771, 0.020693660856434898, 0.023063509800140897, 0.07740190793429652, 0.0774731541112546, 0.06810487938984748, 0.022247687447816137, 0.03917603190207193, 0.10646229654911066, 0.06743240740991409, 0.025377346225263133, 0.03598339878202927, 0.0548829717351304, 0.07286299786139881, 0.0600724819777233, 0.030773847679337187, 0.032189210441203854, 0.026171432747956247, 0.11860352610388111, 0.01882498088713375, 0.01610532853632204, 0.05248628098577742, 0.013384995324867628, 0.046408212172888944, 0.029951400581687212, 0.06543565286143173, 0.032691967132831776, 0.045704702140703324, 0.05260676746406863, 0.027956107345920418, 0.08164982717003554, 0.06379133706251461, 0.04039101670646379, 0.05305359590678446, 0.08903595663967634, 0.10224038599840096, 0.027246146853412354, 0.06415795992999788, 0.06425387796855743, 0.07920507206431321, 0.028914144345288797, 0.02141317829579836, 0.03230322730697451, 0.02664028430327533, 0.030358819546358242, 0.10525159417621552, 0.04437100818200458, 0.04776800674716792, 0.05760117809498503, 0.05313105888724808, 0.06424998241146246, 0.07369471653815239, 0.42004888937357937, 8.564837498049583, 25.40618004337434, 57.83692106123894, 84.99328228735155, 79.6498687805668, 75.17550345390075, 70.16102775450676, 66.74298024946644, 56.31311555062571, 55.01732918523974, 44.318319289915024, 32.144886524446555, 54.38865561639109, 52.11819164214596, 51.553809642791755, 34.055014118071526, 28.757096182915475, 22.83023991892415, 17.744475141648326, 19.648574052318452, 13.486309878287779, 21.103181108351677, 27.338978936595304, 19.198489919785533, 27.249713636213734, 25.62854705318328, 17.85058113836473, 25.476519907674483, 27.723953685452862, 28.0467608282643, 22.994712744989705, 16.96442750192458, 14.397807909596352, 14.82367728987048, 13.424285438752944, 16.447226712780616, 20.021695398515273, 15.725387046414038, 23.581254174632413, 18.183486423184796, 12.364423755676517, 17.054832250841205, 29.073500056420606, 31.108123679314893, 35.52102742656585, 50.665098620999245, 55.04947693117204, 67.29112363630726, 64.7754526907398, 75.55480449430405, 65.61969580188875, 56.489888929551654, 45.67795399696597, 29.65662314045814, 15.83372389116595, 9.275283659658125, 2.2966416276270345, 0.6944864663866259, 0.10701217913940068, 0.058161414363571716, 0.025110339685793848, 0.05654595709676224, 0.07875936977084606, 0.024892832002332135, 0.03860591309926203, 0.06385302246217767, 0.02706662947011571, 0.14068582666016397, 0.006383037403030622, 0.02012428132847192, 0.05127433372000533, 0.006785820099344898, 0.011614446430617284, 0.036493057925854964, 0.01979661594715811, 0.019279874320472443, 0.0038687590999724047, 0.07269125627053362, 0.03842691282531427, 0.04391096472259491, 0.023632692060463374, 0.013114489678804193, 0.04787368091544317, 0.03618319834312124, 0.06623529543679568, 0.0807784404605627, 0.05124626042802007, 0.05099362378279048, 0.03263436881224475, 0.027314977938189145, 0.036576473409490246, 0.032811331292313915, 0.030202669759971962, 0.06099427344217416, 0.03896762151271105, 0.033736229243297736, 0.03404325813115124, 0.05642319916777554, 0.036311782370772094, 0.06806325783292133, 0.08592601505018051, 0.009890293736281175, 0.033956824261094296, 0.06026840896435803, 0.07769943350144932, 0.022481330858183005, 0.06944791579078283, 0.009241961186841853, 0.06478817066958835, 0.004442867066245526, 0.009460609383700837, 0.10318849641349047, 0.029038390400068417, 0.007609007429451712, 0.0379992442415847, 0.03011465966401081, 0.02824651212581704, 0.07284725475455485, 0.030162712529061303, 0.02704515985603775, 0.06116531023214902, 0.04407518333004367, 0.031921525913921577, 0.011281203929214709, 0.1580271767752786, 0.022034638396073735, 0.0851422917818831, 0.06897107202319369, 0.01891776754130279, 0.14451059723092666, 0.043799460625215884, 0.025170010274216056, 0.07301874353640503, 0.04018429554097595, 0.05256064514058733, 0.011391048488627759, 0.03568889543173775, 0.06599469786329616, 0.01500672780938687, 0.044493011514385866, 0.00727657602363897, 0.037471015126474445, 0.040510955431889144, 0.029803702660325556, 0.044287906794418255, 0.06662148802030472, 0.034823553155987494, 0.10961369881706853, 0.0502465233477133, 0.08254228895830532, 0.09557107733863016, 0.041910774269772154, 0.03789792145271936, 0.03402910848718978, 0.02636043046931586, 0.04691638127570191, 0.0678768533191854, 0.06382823568738757, 0.043983172339897965, 0.018643676603753722, 0.005862741128376295, 0.05947908942377376, 0.048455268054479556, 0.07161462694526681, 0.034200658556073904, 0.08381445456536547, 0.04191829342274897, 0.005086575796256864, 0.061484424157008055, 0.09108770864024278, 0.05843628671080355, 0.021442766526653882, 0.004326842571308296, 0.09451558437919426, 0.1782737468038836, 0.5313325985785454, 13.913055908295417, 35.343061647107525, 70.24491940775226, 94.34347537256058, 91.11562359717585, 84.18643505342546, 83.56612790015437, 75.46078528127363, 68.37896162463774, 64.51533679039248, 55.81331537615869, 45.297084008493734, 66.08148036464569, 57.29979953458233, 63.66659864302605, 43.51467271004954, 37.76306206180204, 38.50535884980233, 27.009680271148685, 29.275113805647823, 27.94942132888302, 31.875776629294123, 36.468001334897934, 31.74442625814869, 36.241492302187034, 39.73838337006108, 29.25113831796954, 29.109126944695753, 26.172254239359212, 35.797075994553104, 31.716432302228867, 25.365161857297345, 23.32365643593573, 25.817875939030802, 25.799723209873324, 23.68286317394626, 35.41400947878438, 36.74783499010148, 42.07575513470558, 41.4227314918272, 25.843137964125603, 36.93281004505773, 45.83263266471125, 44.44330169308571, 44.50156850199546, 61.93042816654329, 68.81533315104824, 75.16016698652699, 73.81116190264302, 85.87424662805374, 77.83408595669654, 66.80769935730966, 53.705045330908995, 38.248780927350445, 20.73248378692135, 11.22157354508677, 2.797209606055291, 0.7219928839514334, 0.1398206988890325, 0.06680109733415228, 0.09396816093114116, 0.025232051904763908, 0.01138280155212288, 0.05532913751179173, 0.03489231337763129, 0.05071797002587588, 0.015562507361474057, 0.01760316257845731, 0.026829747423048944, 0.021762977872464447, 0.05364611895093995, 0.054584450253676024, 0.009320959215983748, 0.05418163356221011, 0.07037927186296833, 0.01915987813845277, 0.03048550367595688, 0.027231361356473742, 0.04319741127772197, 0.014948547261977389, 0.04283230909476838, 0.019544438954683083, 0.021237487521683498, 0.03119430163003985, 0.0411380137196712, 0.07110131739248192, 0.044875703076080936, 0.04614825938798247, 0.04932591548910545, 0.01596561899679082, 0.05903255209446915, 0.06758069138853781, 0.03310892963781953, 0.029256708221510056, 0.06738839565866417, 0.026985050682278893, 0.031548588566722414, 0.04660125100804914, 0.04059559665620327, 0.07650789098754045, 0.008950542298055465, 0.08480307570989094, 0.07684816426086812, 0.02093028243360741, 0.06606719276357083, 0.021866865140656312, 0.08733752438978803, 0.009002093312090204, 0.00939629438723768, 0.0885974862162144, 0.02528472427999781, 0.05607015903918974, 0.025629735807137146, 0.08500708492412683, 0.016338960455370047, 0.034923872369672024, 0.05868846370327858, 0.04244345052528285, 0.06598854617726418, 0.17960244969975564, 0.15428414778603664, 0.19776694596775118, 0.11046787153088278, 0.07354446371356327, 0.20571861686485432, 0.10380321302481237, 0.14200149073956475, 0.1593818960170592, 0.1326443242930597, 0.22796999302602586, 0.1525776716129434, 0.16595217249085828, 0.18348243988810048, 0.09858415477097997, 0.1659937710651467, 0.08148056004316577, 0.09960838368222599, 0.2443302143365145, 0.10296979363286689, 0.12419761504016577, 0.11457486123207117, 0.17975085625244727, 0.1845505503156493, 0.10649686243625418, 0.1385730787390663, 0.2189726121122799, 0.17836340973454137, 0.2467996068298817, 0.13721622977285616, 0.4033239336023408, 0.17259695867617286, 0.13216395652101887, 0.11915157774403212, 0.15532028170362597, 0.146245158187324, 0.13119146918817876, 0.1189681456514424, 0.1753486392478789, 0.15632220213451695, 0.0820792654168702, 0.09759833750825736, 0.11754754284817366, 0.17304680550531035, 0.13774401838740996, 0.12764923184389068, 0.1763632307730375, 0.12400816149649121, 0.11711718529582986, 0.24453895797412245, 0.17162946623659905, 0.14688162403481622, 0.17213084013952365, 0.1235328958700261, 0.1664612992035766, 0.2758342165860438, 1.2685561684831497, 17.9303817595205, 49.29553639504218, 84.69729238940825, 109.78348547412504, 101.24968667184153, 96.88556348123859, 92.64677570712183, 86.8102575117542, 76.47123490610431, 74.05387816890594, 63.3176802819775, 50.10494885906097, 78.11569644558814, 73.56528420602122, 74.46676254272461, 54.93714024943691, 48.03258026799848, 39.126336728372884, 33.97887306828653, 32.69316327187323, 25.013036958632934, 33.56588671284337, 44.64828868066111, 31.87050300259744, 41.98247724963773, 39.674440891511985, 33.88189246577601, 41.898820938602576, 43.010193147966945, 46.043828764269435, 35.706347650097264, 28.146222329908802, 25.15288906712686, 28.066351106089932, 25.96429409519319, 29.31748913180444, 33.50744731964604, 29.057532087449108, 40.73192757944907, 34.05118980715352, 25.118395743831513, 32.416730311609086, 48.129423587552964, 46.301371589783706, 54.65136812579248, 72.77942165251702, 78.7362781647713, 88.20598586913079, 86.00867409859934, 96.97424042609431, 87.60337645007719, 78.15900725703086, 65.22409731341948, 48.152365530690844, 28.35952081987935, 16.438401379892905, 6.390871184487497, 1.85113882345538, 0.5184311263503567, 0.2690483936138692, 0.16332590051235693, 0.12768707658735015, 0.22775300628235265, 0.1062332898859055, 0.1266410984399338, 0.1641212529953449, 0.08702599473537938, 0.196992032710583, 0.10849877275646695, 0.09238454993934402, 0.1332525981049384, 0.09028232040544672, 0.11592083941063575, 0.12595774035059637, 0.13377975852739427, 0.15823783563269725, 0.1354721846479562, 0.17808767936883435, 0.11867980547850171, 0.12242540086229002, 0.14280844179372634, 0.14557432563554856, 0.12114796457031082, 0.24935411169163643, 0.14994081229932849, 0.3382707194935891, 0.12168772713912111, 0.09317054848877654, 0.20456836649006416, 0.16113597689376724, 0.09406245869374084, 0.10718924504133964, 0.1202916851147048, 0.11926143475237394, 0.10877795051783325, 0.06959950926923944, 0.10500686738880412, 0.12606102432454788, 0.1640680252063659, 0.17952617798601428, 0.22664161188708198, 0.15241395862352464, 0.1726656767629808, 0.14220122518318315, 0.1325150852602336, 0.15667362198714288, 0.23662027482303882, 0.09899920588659664, 0.14427530098586314, 0.19850350886342988, 0.20338905073942679, 0.2167054821526812, 0.14601451975684013, 0.12973315953727693, 0.14704313069101305, 0.13571011623547924, 0.20412064938535615, 0.18464344613734754, 0.23963988698538274], [0.01713397202923173, 0.07540159873784551, 0.0028473022299998953, 0.05909168642134436, 0.009068837764883235, 0.027143933487335042, 0.04742961038925475, 0.08051934952457106, 0.041021805842437094, 0.020930818695154403, 0.05522290792977137, 0.05916135828761805, 0.037076954819983056, 0.03197678192068012, 0.027196910382518848, 0.07917358585062527, 0.04830555149143742, 0.01262276178045619, 0.03926556459778259, 0.03998471048450278, 0.06701066068583919, 0.022760012577618324, 0.07885991881090788, 0.13022707174381903, 0.03402469965118555, 0.06146791879267943, 0.03902569480781113, 0.027434478078277844, 0.004702506233907996, 0.034988909404003815, 0.09688206828169285, 0.08929346943454397, 0.060396858926622145, 0.012367853684531105, 0.016518883865266558, 0.019818437961681236, 0.05170260368275547, 0.018518346534561247, 0.022024368987448757, 0.08049416821449995, 0.06116637126392415, 0.023848060443396532, 0.012887805219619505, 0.07238579403248525, 0.00989807814720177, 0.04716432946283491, 0.05000495284254994, 0.038054628568070556, 0.03019072644923243, 0.10401223245407305, 0.05667987309636609, 0.07342945859437028, 0.10587731947100933, 0.3303571231663227, 3.0902655711097107, 10.797704573600523, 36.55053192569364, 65.6259519823136, 81.95491237025108, 76.69224477583363, 63.39943816584926, 66.66115176293158, 55.15036813674435, 42.94588588899182, 38.672624403430575, 29.031248284924416, 29.45081637751672, 17.01683036742672, 23.561222630162394, 20.106400943571522, 36.351350045973255, 22.727848406760927, 25.506629982302268, 43.28114263473019, 16.12049425801923, 18.724273404767438, 21.877152996678507, 32.66234520942935, 44.648884880927305, 35.54812315971621, 42.3849202740577, 43.743217452879875, 46.65822098332067, 53.75898968788886, 47.16382234327255, 57.307738411811094, 35.93284883806783, 43.969079294512355, 74.94999854795395, 58.695653407804436, 46.26710184158818, 37.33716718612179, 43.391933902617424, 25.295002422025128, 21.749375904760054, 23.08893592126908, 14.172479510307314, 21.75234906135067, 16.322821878617813, 15.715683102607729, 15.240374207496645, 31.50453409840984, 22.220858527768044, 23.969223653116536, 36.395311970864576, 46.812703532557336, 51.33241538078555, 64.16466512987691, 70.98959707444715, 74.03639224267776, 72.9086245259931, 61.75025409267795, 47.99030103991109, 32.72720160022859, 19.188478069920695, 7.042387656627163, 2.0252431520531258, 0.5748919902309295, 0.31250696809541795, 0.05729368572393733, 0.08935993522285454, 0.09168133485100924, 0.013173556972986028, 0.03163197532206053, 0.019760525545045253, 0.017034510834022396, 0.05332723868289783, 0.02683598337875259, 0.014064042254411166, 0.017147556683349035, 0.010475198993639601, 0.04962255622470572, 0.01849532942287624, 0.09356515271769417, 0.03749627687577759, 0.04708682434753545, 0.06993471870138761, 0.04051371717885618, 0.003092037875302917, 0.01769035487555929, 0.038486912831543915, 0.027037667516138286, 0.013095865123755029, 0.02825120824479288, 0.03265392703695163, 0.04194878755257495, 0.06666785166148217, 0.035085689291478164, 0.04901558859273792, 0.0761473393668571, 0.1217079671820806, 0.0360526492999446, 0.09735603155868669, 0.009551943343643461, 0.025196474781560323, 0.07294686916734903, 0.0207483020776342, 0.058098231262016686, 0.07012581167322013, 0.01172478415913159, 0.01594612014389807, 0.06140536005278269, 0.03840827773655615, 0.016849035201894663, 0.019734434505564072, 0.057052187997126774, 0.04903686285439519, 0.053706084483213005, 0.038372026455979195, 0.03359684720635414, 0.02008307154380506, 0.059878638750242616, 0.01679010771875901, 0.020781421973820657, 0.06273803128410252, 0.09321702704314264, 0.0424088808076997, 0.032312906827897794, 0.02977325258055522, 0.03346437145204794, 0.060541036673971725, 0.026657550009868802, 0.06693164637732892, 0.07125683324111086, 0.06733149830852786, 0.009882762134375592, 0.019434120378366882, 0.03932316291836962, 0.027136688210791158, 0.0513494601322999, 0.00426847672638213, 0.05096782960237996, 0.0699817871434554, 0.036528780605764165, 0.07596404517009374, 0.0734890602348793, 0.019945248495787382, 0.043342500669701446, 0.022586568356341413, 0.018223132637719956, 0.01707403714047565, 0.08136144869269864, 0.04017800978955723, 0.0759738281128868, 0.004500758415463591, 0.018140561766021194, 0.08574426069014496, 0.02734225641395296, 0.05599820040046208, 0.007164113837549644, 0.043036080821747744, 0.04916548518644226, 0.015108166469050752, 0.042741860923988205, 0.07367142746525426, 0.02303966531349767, 0.023067334494102868, 0.018286836679063497, 0.03833177236599788, 0.06483880142050405, 0.03306707442407647, 0.043380341582721284, 0.10231009999951048, 0.027090140708511876, 0.06546982804373389, 0.06492227436073365, 0.06455747861294978, 0.04555207827398854, 0.15438327956343853, 0.4801077005122939, 4.5547332206080045, 15.897647738456728, 45.999313785183816, 79.97001263403124, 91.17865608584498, 85.90056573190998, 73.45486948567053, 79.11856020650556, 63.97430466067407, 55.068661243684836, 51.3286106817184, 37.315637296245946, 44.51846999506797, 28.596734000790505, 29.0592755809907, 39.211334490006976, 51.595939820812596, 29.87548355133303, 34.198349291278475, 46.75333061525899, 19.437650557487242, 23.54137935946065, 32.79027919615469, 31.532720250468103, 31.279697956577426, 41.02262620002993, 34.06248623324979, 37.25353048693749, 37.61517301682503, 40.955196734397646, 42.67921963045674, 43.21392497708721, 35.20559826204854, 38.05444709716305, 43.549605338804184, 42.68910008092081, 33.13407690294328, 28.372539166481268, 37.89937619240054, 28.135133789431666, 13.925894806461951, 19.636067575024022, 18.839477339098533, 25.794377019328458, 26.265520357316543, 27.262471145199193, 31.206251575100808, 42.921198491127264, 35.89420564713017, 33.95570755004883, 47.31214677133868, 59.12056376857143, 61.2824643811872, 72.59958098011633, 81.21150555149202, 84.2730959000126, 81.91085630847563, 71.89893584097587, 59.39436874082012, 39.52997607569541, 24.37072530869515, 8.7047690345395, 2.8442241155332137, 0.7936734634061015, 0.3476518032050902, 0.12324097806647902, 0.050216879575483264, 0.0976324360817671, 0.045843207006973606, 0.014186349149132449, 0.04700714354253104, 0.014863104518172483, 0.034514379221946, 0.02072647240223183, 0.0539263807267191, 0.04049764848464439, 0.03472556284959278, 0.07838809291922277, 0.02705480490300444, 0.10242794730490255, 0.031349242912725575, 0.027192534105251395, 0.0405038959316669, 0.062209311872720725, 0.09301612814587933, 0.08137254930672147, 0.09032124533287941, 0.0339410581716126, 0.010458802796840187, 0.03451578882372668, 0.027835716628619743, 0.09582413916265774, 0.035719098448152506, 0.03376630202476536, 0.050365113758391915, 0.05946003298665728, 0.04701954267558552, 0.030005764096013965, 0.05475638336652229, 0.03477035218008584, 0.0770895432440504, 0.07520501291559589, 0.02543139564354093, 0.05799657905534391, 0.03913127704553547, 0.05142617234659772, 0.025054744685128815, 0.05366222977998757, 0.05521852590684449, 0.002766028201515456, 0.052623380080706654, 0.028689508213691657, 0.05078314112559442, 0.03323431524838651, 0.08669605598815026, 0.05204901715079623, 0.01530002840163727, 0.0869386760337699, 0.04626186639671365, 0.051875697418807015, 0.05940107102956503, 0.06990843422470555, 0.16669641158753828, 0.15198747747607771, 0.10985880098756283, 0.16509830621221375, 0.19728181312882132, 0.1564680193100245, 0.1937956534205906, 0.294712400364299, 0.29939779410919837, 0.1260019512847066, 0.1250976917424029, 0.17150667766409536, 0.11549861005116856, 0.19013753761687588, 0.1241268361768415, 0.2251656975356802, 0.18999737417024953, 0.12855044235625576, 0.1321949217949183, 0.11100653093308212, 0.08584292515391305, 0.0790800771585876, 0.16682241772932394, 0.1896562811828429, 0.17950757737121276, 0.17834978869124768, 0.1834832979065757, 0.18192254697843907, 0.1542785247006724, 0.10662409431871869, 0.26195775957838185, 0.10660239104782382, 0.22985489107668403, 0.09444469826356058, 0.12977210744734735, 0.12771079466948587, 0.1295272657467473, 0.11265623233010692, 0.15767606335782236, 0.15365253893598435, 0.14220024459064007, 0.1295577254026167, 0.13018721984999795, 0.15131975524127483, 0.2065124831372692, 0.1231399617127834, 0.13263506995093438, 0.10957975346114367, 0.1409175835790173, 0.18282584124995818, 0.1830711272815543, 0.23011051929525791, 0.3493181670144681, 0.7357217924248788, 5.968808954761875, 20.645432664502053, 57.34256513657109, 94.18066563144808, 104.59688048208915, 97.41760161615188, 82.55050859143658, 86.96127660812871, 75.26351359582718, 62.883575885526604, 57.83262214353008, 45.36760430182181, 47.39995687238632, 30.69275252280697, 38.406487664868756, 36.912809879549094, 56.26286998871834, 39.04125659696518, 43.86019429852886, 61.83302394805416, 29.02480971428656, 36.27604053866479, 39.10318689961588, 49.52029212828606, 56.984762607082246, 51.0485730632659, 59.860887604375044, 61.63888231400521, 62.83380493041008, 74.12959560271233, 67.6799560362293, 79.24816316173923, 55.324003619532434, 62.89861033039709, 94.91446264328496, 77.70359654580393, 65.7814504254249, 52.31563198950983, 63.330400528446326, 38.771393606739665, 31.996581708231282, 34.108123010204686, 22.626986618964906, 32.37388822340196, 28.925532564040157, 29.4584414651317, 25.44632157971782, 48.8065266609192, 37.57093260365148, 42.196587670233946, 57.937533778529016, 69.31902823909637, 72.07403044546805, 86.17582982586276, 92.31835565259381, 96.5101142083445, 98.06409451269336, 85.74321593007734, 69.33598072298112, 49.255481150842485, 32.21682083222174, 14.098011351400807, 4.985162356207448, 1.3523496399002692, 0.6629962690414921, 0.20240750824732168, 0.2301457899832918, 0.21628280080133871, 0.09552062278793705, 0.10767286102617941, 0.12042695325949501, 0.14623639414147024, 0.21556813269853595, 0.13661756270354794, 0.13488163811064538, 0.17368576879943573, 0.08511494244298629, 0.14403378410685447, 0.11481463143061246, 0.20331970446052092, 0.23989052031069036, 0.18038157644050737, 0.13889992249108132, 0.16656940953145105, 0.17881299609378462, 0.1405204282773118, 0.21136981765589408, 0.10555172444231088, 0.11593361775721274, 0.11648630422930564, 0.09088831127531107, 0.19775174678333346, 0.15377175753876088, 0.08887382179138162, 0.24089286975081892, 0.16469212639476025, 0.16409918966312564, 0.09216200905821978, 0.16989355696545494, 0.16820384279614495, 0.12538937205869344, 0.1895810819921955, 0.0729531281056904, 0.204616982429739, 0.14350766556397562, 0.11257313477296023, 0.1543647708791879, 0.12429604201667732, 0.17685790906750387, 0.14073016782922132, 0.0917769885892349, 0.16341666660962567, 0.1518978451889369, 0.1436073642464415, 0.17839422179085596, 0.10145800338397104, 0.12273704542988732, 0.2499981771313375, 0.14875231881535825, 0.14402937144041061, 0.1428366185075814, 0.20874460287872823], [0.07902786060566865, 0.03622292000199518, 0.0973511285959713, 0.04262365738771135, 0.016170214268288786, 0.015062402291674049, 0.04556452337231848, 0.022375541776719115, 0.02787722518757707, 0.011723607256557914, 0.034345288295298815, 0.046544537519014655, 0.03002776997163892, 0.034784172406239856, 0.03757654373804408, 0.016649643582622373, 0.016161814114199053, 0.05719649980986311, 0.06950705011765804, 0.0415365135056838, 0.047750026663585056, 0.07732172151126208, 0.02518805164483286, 0.03921276581804118, 0.026331163995388537, 0.015509820622091573, 0.007827107873444837, 0.009633886980854217, 0.01684217296931292, 0.021760737065285928, 0.045455555025968826, 0.019098401497749072, 0.010813638443998512, 0.016897164675737583, 0.012815935638613038, 0.056547156024363734, 0.03387337430350242, 0.04660699666748124, 0.07677810552019267, 0.03606607882125724, 0.005148173574613588, 0.01108487091598011, 0.014740859868095047, 0.016212630641436385, 0.026650544135801257, 0.06949066349695768, 0.07045840108466726, 0.04935992596250388, 0.028951971851769957, 0.05065266103033097, 0.9528556249795422, 4.119602143764496, 8.28802308728618, 17.112891174131825, 45.986330739913456, 66.06804232443532, 78.67246904680806, 77.59690807711694, 61.54149770736695, 58.37932209814749, 36.266360129079516, 34.57074303780833, 29.83685212750589, 25.87907668082945, 20.384110635326756, 18.782400969536074, 19.278349376493885, 27.132934870258456, 32.79119310840484, 23.47260452085926, 21.784255581517375, 28.6871858181492, 38.21310304826306, 44.64195405283282, 55.93874100715884, 43.61206516142815, 60.07796333682153, 79.74635908680578, 75.3615414711737, 50.80958304866668, 70.50611003752678, 63.40996580739176, 66.08093123282156, 53.84143398654077, 45.865494282014915, 32.79283265913687, 44.04831509436331, 53.60915122493621, 67.34469536812075, 63.69296089295418, 70.00443889248756, 71.2989700994184, 59.959692109015684, 78.4073168231595, 100.84514910174956, 70.85722492587182, 77.54607415968373, 58.96861507046608, 68.69819548822218, 47.40186314429007, 18.773438353692335, 18.482580877119496, 16.498683306478686, 31.939034654248147, 24.817426396954446, 26.039597718946396, 30.958218536069317, 36.7997593264426, 54.24852109724476, 60.87844064158779, 65.46071821643461, 66.41172039893367, 72.86939297952961, 78.20121980482533, 68.16894223613124, 52.891651661165305, 29.21452299241097, 19.564450979232788, 11.247299390454447, 1.5777363844456211, 0.590386271717087, 0.21817439446045508, 0.14598332465656344, 0.0439489588531996, 0.04163456892955207, 0.04666475969697199, 0.04947185140824126, 0.037570254156185735, 0.05534511810589222, 0.03305533795707649, 0.030241952833509257, 0.009416407068079759, 0.025898829936200095, 0.05007194340108864, 0.017047017219386274, 0.08825078546520203, 0.07854401479445158, 0.07581778366359011, 0.023729282341176466, 0.05525372764696518, 0.03889962354855191, 0.027949216385041515, 0.018989867906296448, 0.06115419429636771, 0.013218804998623749, 0.08130634398830515, 0.09611512233893718, 0.03169682274963106, 0.02250919922164852, 0.056377341144628106, 0.029398717940033927, 0.01578094775698358, 0.027571366499027902, 0.03906281559818214, 0.0856429149186419, 0.0204252562065038, 0.05953747298448317, 0.06721419492556203, 0.05279517912816617, 0.04193045889898654, 0.054749362170696265, 0.030587839616102078, 0.05811811890453101, 0.10667565203602276, 0.032676687509182005, 0.007074024291679024, 0.05681882229363246, 0.01966886887056453, 0.017687129645398068, 0.009455680565517998, 0.09126652122264908, 0.00782117883171586, 0.03849160895051976, 0.027906664031287356, 0.06442142905847681, 0.08621899005506309, 0.016588908131985415, 0.02676807926036418, 0.014826861856084679, 0.07477526823359151, 0.07583777855841384, 0.021585919631404743, 0.0659982142068686, 0.05104095652519215, 0.09724534717538665, 0.025241811864919243, 0.010248522195334156, 0.04132013963235002, 0.0146721436965069, 0.029799100387120442, 0.08525731988371381, 0.02957091343799426, 0.028361712597430717, 0.019205420150331432, 0.023121655873593785, 0.021387326658793518, 0.028822332538003405, 0.028220476627710368, 0.02185216391338937, 0.06447940659258636, 0.030184819911336227, 0.02810184982785535, 0.039989142303144744, 0.10754064191132785, 0.08286878030987517, 0.03120598638610494, 0.04082093375825113, 0.06789546925574541, 0.030923972184199, 0.017839200013587554, 0.060559882436909025, 0.043226901832367146, 0.03929194483545519, 0.020976146202414267, 0.09525031632473392, 0.0387647997347578, 0.04277504785286804, 0.02721865195780993, 0.027149585300996423, 0.03216486416697022, 0.04646390293454451, 0.020147830871264302, 0.10475359106015776, 0.044833399700902166, 0.09558602371403287, 0.06803796160966158, 1.0968135970254098, 5.443326080999067, 12.651356900891951, 22.632319081214167, 57.897882538457075, 77.55736274103965, 91.82034800129553, 87.0250778813516, 73.44933894372755, 65.12140181756789, 48.40646451519382, 46.1973895565156, 44.85540943761026, 38.118452333634906, 34.28717528620074, 31.243467023295743, 30.07736598291705, 31.709634834720244, 34.60120416456653, 24.619311401920935, 29.393610569738573, 32.18667349507732, 38.20844719486852, 42.374141600824174, 43.28555922354422, 38.964260470482614, 40.29632875996251, 46.181339217770486, 66.3149319925616, 49.90994430357411, 46.80349772976291, 50.39757336339643, 44.600165121016964, 43.64456984304613, 31.98795641622236, 27.408957942839596, 27.957946600452548, 36.22791697902065, 56.131325460249386, 50.50628969746251, 55.82996583754017, 52.17672124985726, 47.579330782736506, 52.743535118718306, 64.38018368136498, 49.75323384807956, 48.58352814951251, 39.68468612240207, 44.06132951859505, 44.27022710923226, 23.309584932942546, 30.355105092448575, 28.266456703985895, 40.024037822600334, 35.66762993412633, 34.04083474989861, 41.98722723991641, 49.189832441268436, 64.48890786017141, 67.78345169559603, 73.99370116572227, 76.26935835807555, 83.2914129380257, 89.52039564809492, 77.0705024657711, 59.385159015655525, 34.34387314704157, 21.74124679257793, 13.027902476249203, 2.1586519095205494, 0.7665709273949747, 0.132316070939264, 0.025047457273749095, 0.16137456731690517, 0.0050517915740549086, 0.04782817529274091, 0.03935990449521811, 0.04086132574405882, 0.12252208115833423, 0.024588055412976012, 0.04029266633874467, 0.020156868793551, 0.02762361944112326, 0.029435302468857942, 0.02949107750018518, 0.05657632482208072, 0.11576476431782208, 0.10965541996542486, 0.014604131368199184, 0.040879669719405716, 0.030847235072043636, 0.01983357968950464, 0.01654598231036817, 0.056642124113897165, 0.011888059520823582, 0.03133918609349959, 0.06636311720696188, 0.059220768406146, 0.09534950938916976, 0.008948832964374414, 0.05024329428711245, 0.052881333376130754, 0.03940105490807084, 0.008869515093524129, 0.09111370966439286, 0.061865457138347055, 0.05863405230845656, 0.054204773247963, 0.025553257249656226, 0.01712149054172539, 0.090242637050969, 0.022825074509807655, 0.10180355500309698, 0.07599160135273011, 0.02414439091338746, 0.03508088208975331, 0.04556456933759394, 0.039323940497612765, 0.009140562746793994, 0.02247508724160012, 0.006620878017612643, 0.03735350106932944, 0.06846588300240618, 0.005159831038796373, 0.08971204455461233, 0.028600320257546923, 0.09198722609829518, 0.08499815999980896, 0.23293635717803435, 0.22510451775404716, 0.17195529875255403, 0.1281734658104758, 0.142808273254383, 0.16219440396995316, 0.12879874677427355, 0.11899655985255396, 0.10463551392838841, 0.12995161716976475, 0.06235990943687578, 0.1542806697468604, 0.19935743642910836, 0.09516806912518318, 0.11430956498389283, 0.09712292632508664, 0.15385152261343696, 0.2056085147083767, 0.08263239621995919, 0.17362590668903244, 0.18694834423161324, 0.1382219193563346, 0.14885882035859171, 0.07519247971715466, 0.14217661843905527, 0.1828917094896878, 0.16453268817595898, 0.100280464957318, 0.16673744325676274, 0.12211800808267248, 0.2750285372378365, 0.16042227406174908, 0.1825717758507498, 0.20503682925576167, 0.1676858141417465, 0.11731750196627072, 0.22836045271927313, 0.11624565302965142, 0.1094834715308201, 0.15938368866280203, 0.17022263769420887, 0.05306362016727367, 0.14588627663831558, 0.1687212432584455, 0.27037960927813287, 0.1480347395784432, 0.23227554505630849, 0.2842546566840141, 1.6417381888435734, 6.656085185466274, 15.892365286427161, 29.730142085782944, 66.7086987341604, 92.10462570190431, 103.58269676085442, 96.47252221261301, 82.97192019800987, 78.64553805320494, 54.953567135718565, 49.07842536126414, 46.811209109521684, 42.41569519042969, 34.93885747848019, 34.27041892082461, 32.74743122439231, 40.55978259732647, 48.49828720092774, 38.51791043435374, 38.31400209857572, 47.745043077776515, 59.70666393156975, 66.02780665120771, 79.53135828818046, 62.79274555944628, 78.5229326063587, 102.7352608403852, 93.00163253661125, 66.03524346505442, 92.51296797106343, 82.77740201642438, 86.69364544653124, 68.89197626421529, 56.52019316150297, 40.36271095275879, 55.7816618488681, 67.76482043727752, 83.55873031000938, 80.0232627314906, 89.92511364721483, 90.74974490750222, 80.86099470815351, 100.7557269065611, 129.01376816534227, 90.898175239563, 102.35719926895635, 77.1681381041004, 89.19290911766791, 62.04225494015602, 28.293587738467803, 30.08082159103886, 27.252335740673928, 47.11903279827487, 39.52430432842624, 41.3309911758669, 49.24616159931306, 55.45650128395327, 73.98865699768066, 80.78291600750339, 84.86143573637932, 87.59561800187635, 96.47857050741874, 101.30899290884696, 89.16526425269343, 72.72828179021036, 46.990379056622906, 31.912756735278716, 18.8349195449583, 4.531471604301084, 1.5043756822424552, 0.5199614023008655, 0.389577190602018, 0.24374172091484073, 0.10583803448225222, 0.17650405305527872, 0.19811589901726093, 0.20720939332198715, 0.2148164778707489, 0.23455724600822697, 0.1903584620524799, 0.08689146203499648, 0.09915604706733458, 0.09801411640740211, 0.18518439614244048, 0.18432968716707923, 0.15299718136027937, 0.20435845839881128, 0.11317549438606347, 0.21440321940087506, 0.17829380298574127, 0.1646764215923125, 0.1201334726365824, 0.12644053662135718, 0.11043204159866418, 0.2510253018549373, 0.29349750749045805, 0.1788870001872701, 0.13849624012026096, 0.17820015639787723, 0.16369903129675697, 0.08183977867086088, 0.17506987517399175, 0.2076434280963675, 0.2902834009258978, 0.15604550649802532, 0.17161696368167478, 0.18059916073276153, 0.15636948508120355, 0.09534707322957055, 0.3726222858794274, 0.12337941781527574, 0.16160047132401698, 0.21791754050120232, 0.17741534528472733, 0.1094597917530806, 0.12841447707145445, 0.20915430670063342, 0.08265737834716998, 0.22555623383771992, 0.1720102425784834, 0.23028912503392468, 0.14321793111101275, 0.06873300253984428, 0.29792800846119083, 0.17461936950923937], [0.05218630393726691, 0.0767116244101236, 0.044209336816904046, 0.045392731985738205, 0.13439380864222206, 0.02914208806149902, 0.03476382128053135, 0.011472209758545843, 0.05871684343043355, 0.02581329621945418, 0.0537616181968441, 0.04450208582584897, 0.05437988562569503, 0.04673637742657335, 0.08380814966174864, 0.021270722331058596, 0.02611820112853762, 0.0816833052123266, 0.11482745574246492, 0.0034047676543254527, 0.03484986827618653, 0.024817684522619652, 0.034704407331563776, 0.07995793731102059, 0.06729870974536865, 0.052045163728537104, 0.015872201277694155, 0.04870613120616444, 0.03488907282571158, 0.06375996959245493, 0.05336846187410336, 0.013509746997677272, 0.012197167379781606, 0.031822032159975464, 0.043906850830441525, 0.09850386875651537, 0.050511061168846585, 0.020245585605622302, 0.023683142780716863, 0.06740109739644874, 0.04192819893960992, 0.005169596744611139, 0.039951584842656894, 0.025053930716709267, 0.0178936343910473, 0.08352066750728315, 0.04335278923052453, 0.04846725350005492, 0.9644571992178118, 7.470285392576649, 9.813821161946944, 35.96791090503816, 54.72472037038496, 76.55416950102776, 78.20715827326622, 75.44786499392602, 73.59817720228627, 56.94841792506557, 40.154307580763295, 41.35192486547655, 24.268727994734242, 20.145183378650298, 14.151734094465933, 21.208908596346458, 22.39105409191501, 24.333978583735806, 29.02286029631092, 37.426169687701815, 61.19814911196309, 52.022819211406095, 51.78502944207961, 33.81241552291378, 55.36481588117538, 51.098461689487586, 55.201590368824625, 48.048920862136356, 63.226928403300626, 47.647026969540505, 20.219057298475697, 24.833290423116377, 16.371531832602717, 13.853708486403189, 14.706266041724914, 10.162645386111352, 14.2220494439525, 10.915444320248021, 11.558310985565187, 10.65864968684412, 10.273458227034538, 20.528157718719978, 19.38008781402342, 21.168086528778076, 33.226201611180464, 42.68018061114896, 38.343341427464644, 49.05021567498484, 66.142332015499, 85.43167775677097, 95.75505795017366, 65.33172715094783, 65.25930450808617, 37.70633282199983, 40.58643118027718, 24.06798501168528, 24.066374878729544, 29.98288000783613, 20.95457426963314, 26.232950956590717, 37.051904970599765, 33.33681245003977, 45.51102576717254, 43.80510460945868, 53.751074344881125, 60.667448505278564, 74.9802557114632, 67.69603775393578, 72.80041417767926, 52.34658733490975, 42.44101016752182, 41.16436104620657, 17.089486391313617, 6.282045024056589, 0.4884860364179458, 0.24737640974983094, 0.05303278512832138, 0.01975448111132268, 0.07922984734778443, 0.04886389552285114, 0.0574465585692275, 0.03806545339044064, 0.016701421550204678, 0.019338278948599776, 0.049441985470513185, 0.015357951351982212, 0.04812642864342179, 0.06362888045729169, 0.10638412493731707, 0.029575565506914453, 0.0023823811845373245, 0.022813012455439857, 0.02691789924527609, 0.049668222725872076, 0.012807432062653525, 0.04212363179953348, 0.08619723315801352, 0.10238207395999663, 0.03890653749206855, 0.05297222204746739, 0.033590013702069564, 0.05505966608442607, 0.0804132999732129, 0.03222502505166396, 0.07018487705218215, 0.11081867085229005, 0.05243499522968646, 0.044737830232348175, 0.03262989102832733, 0.06658735114239878, 0.020080158494472988, 0.05794530862101144, 0.010382573217934659, 0.01254594135623906, 0.03117795905939514, 0.03449112079256485, 0.08037033776241927, 0.09215511426690126, 0.10113018670029218, 0.05828801422349869, 0.11736234109247885, 0.041371701180093715, 0.07140494868039124, 0.008256141051289537, 0.059771639249858365, 0.058310104368795315, 0.031513714329189355, 0.056031000454940146, 0.026294613940521117, 0.07150669281761493, 0.02866903451391526, 0.0518848215259852, 0.04465814176646452, 0.044861017170572476, 0.06284839008003473, 0.06816301780242114, 0.03499657028324662, 0.021554594296180916, 0.018059892707594463, 0.0615876276917275, 0.029274921961909825, 0.04423752502207795, 0.05635566468681059, 0.023840905182183753, 0.012111107935197653, 0.06410311569549865, 0.045788178911372546, 0.05275757187196324, 0.02304862854221175, 0.022494413724709904, 0.05909539045645826, 0.0375635547172879, 0.03896924178867091, 0.048421096702617024, 0.026478934695103, 0.03844115823026627, 0.03987015735718512, 0.10381457410872945, 0.04602224175487796, 0.05163148007986527, 0.048928905744105584, 0.034329047231304075, 0.038304748614468885, 0.007086993681432139, 0.015501090092584493, 0.03574501520263092, 0.02504077698704937, 0.04509170156633181, 0.04067828818675011, 0.03115360129384264, 0.0253819216853909, 0.017844593272574486, 0.04228403145867971, 0.05129920859490672, 0.07303583495799573, 0.0840029888035309, 1.195044822750553, 7.42974671625322, 15.417922254531616, 46.687407339772875, 66.28177227512484, 88.25948699828118, 89.07138624498921, 83.41614430950534, 82.90398474662535, 67.5186211063016, 51.80016586857458, 53.803277169504476, 30.467182897752334, 31.632024857305716, 23.89425931438323, 27.7213982612856, 29.858968411722493, 26.159357486232636, 32.50102793016742, 35.100741540232015, 55.58506481109127, 47.36244724642846, 49.11546038043115, 39.6306868522398, 52.39789585913382, 54.14209542735931, 50.79692948249079, 41.45607163829189, 46.804482244676166, 40.20712229513353, 25.173161837362475, 22.558655008192986, 17.04110199405301, 13.292646773399847, 12.152577523262272, 8.449914993778352, 10.55108456842361, 6.519898531898376, 8.85958988820353, 8.249665248778559, 9.449301573538012, 15.734137854268475, 17.53217097251646, 19.12580055575217, 24.680347404172345, 37.82701630746165, 43.62313016768425, 48.023237182248025, 57.96706138118621, 70.1880136612923, 76.5089524176813, 49.06601105966876, 35.945992700515255, 36.62072666229741, 37.965166107300796, 40.59265598174065, 38.223018800058675, 37.048300312411406, 33.85249822370468, 35.28282580837127, 45.994140178926536, 41.56134413134667, 56.29269961387881, 53.49610459419989, 63.23484766867853, 68.79877290418072, 84.95099913689398, 79.47470357341152, 82.74376376982659, 61.34947807558122, 51.11723415313229, 48.53132532488916, 21.38535837973318, 7.102876978535806, 0.9242603206826795, 0.27331758711126547, 0.06316207244151062, 0.06051640694720611, 0.040946124016397425, 0.016183239678221367, 0.025056876324778123, 0.05204130264539873, 0.05395044354842075, 0.09702880476270953, 0.029399198660206412, 0.04059089670678781, 0.029355502920225266, 0.04903792771660993, 0.03776038951811291, 0.05284002208481393, 0.03799930169817902, 0.0585466684893735, 0.03144439869380045, 0.041438289542472174, 0.018062981957149123, 0.028806493670168905, 0.06444045868251594, 0.04927599336951972, 0.03637205050777524, 0.025171257082312822, 0.01561253960619891, 0.06666899313248935, 0.034648819991777983, 0.046276582945739074, 0.044960466874462944, 0.05384643945182043, 0.045811038975033073, 0.0243033254293785, 0.028204134057065653, 0.027622749931329203, 0.01505360089903397, 0.029205740391907674, 0.029496650789834322, 0.024631657307186437, 0.03437893487693321, 0.031977890832950516, 0.060587277741081295, 0.047321155321814364, 0.030723605718043064, 0.07189581185699472, 0.09786269146828883, 0.0859338904340421, 0.07619237001504629, 0.010510372963073033, 0.046700386615890654, 0.058430889621377, 0.06749049219633303, 0.01000916472666206, 0.12681614186975265, 0.2846134922677471, 0.13209683189709343, 0.2229727248871519, 0.19237183304803987, 0.136206004948866, 0.08742229201860967, 0.16514042572629067, 0.15864562423479173, 0.1046977432504777, 0.10082414223542137, 0.17138183597595463, 0.13023790422706835, 0.20192399951479129, 0.2979202250078801, 0.1260884809157541, 0.2543301745167663, 0.13568296607944275, 0.1309020411703856, 0.19950308506527256, 0.1791237060341143, 0.0839240970690885, 0.1811099115518793, 0.21910157535345326, 0.15654661993105567, 0.15944181941449642, 0.17625746467421133, 0.1070684482974391, 0.11717216742615547, 0.23880207790963112, 0.16617430734538263, 0.13184345597701688, 0.18179237331834533, 0.09401746634994784, 0.18795066302822483, 0.15356598632229915, 0.17802643830016737, 0.14248009650937973, 0.07040456042534883, 0.14158637833691415, 0.13216803210877603, 0.12257012253206585, 0.16194358678354373, 0.11345357664169804, 0.18272263388479912, 0.2283010655833829, 0.1354620722873557, 0.2879428797431531, 2.1096026705157374, 9.637036015910487, 22.056817162421442, 59.62802040961481, 75.95694157385057, 102.93977322116976, 99.6425033384754, 94.77464583612259, 90.58019653443368, 77.35741599913567, 58.96159402785763, 61.79824036936607, 37.133380443819114, 34.18684497956307, 25.075838027461884, 33.76513135048651, 34.242224924026, 36.358763325598936, 46.18915650152391, 53.43990879674112, 77.15004813286566, 73.77570367628529, 75.55500845755301, 52.087710903536895, 74.05502350099626, 69.50716080204134, 71.01553963076684, 65.33788919448853, 83.50351118272351, 59.42532016384987, 27.816296085234615, 34.97600232401202, 23.136584874122377, 18.807190349025113, 19.823180321724184, 13.97026759962882, 18.675326147387107, 13.705622342325027, 15.719850620915814, 13.702226550348344, 13.143904612910363, 26.39236588631907, 24.809546355278265, 26.878831963385306, 42.037904262542725, 54.655765102755645, 51.39864067877493, 64.0913324971353, 86.74755450217955, 105.18281982791041, 119.79193072165214, 83.28936546079575, 87.00927857429751, 51.632131530392556, 55.59754187060941, 37.395065292235344, 40.49925650319746, 44.097034854273645, 33.45623293230611, 39.16860026697959, 53.79696215352705, 50.47771523075719, 65.27538622579267, 62.426957084286606, 76.25789719243204, 82.33981455526045, 95.74249067614156, 91.88924051100209, 93.41295580710135, 73.65825222384545, 63.716091109860336, 60.186981693390884, 29.83408489534932, 11.475752938178278, 2.2209938158912044, 0.6455790455783568, 0.15738216138655142, 0.11379588004802504, 0.2612380659387958, 0.13819297655455529, 0.1493720073373087, 0.1132123661978591, 0.13854350774518906, 0.13926260383619418, 0.15685870882964906, 0.09430763747302756, 0.09626626382551848, 0.15763650257741252, 0.160462815434702, 0.12066438688986725, 0.20902833120236475, 0.12934801649422417, 0.13147659179183746, 0.13296180645064, 0.18424917132623736, 0.10590089965731868, 0.23761402875665696, 0.2249264635986859, 0.12835340454213082, 0.1402841820832222, 0.10249959950846049, 0.2984505110690671, 0.24434303864836696, 0.18944743029292554, 0.1508462209735186, 0.18297703636269416, 0.10596990119665863, 0.16779884275409485, 0.1250036238061805, 0.18097230683892004, 0.11718461635492503, 0.10833044025686481, 0.09437952716384204, 0.11084995022223842, 0.17708437997967968, 0.12118917243975787, 0.23030489112340638, 0.22801384389881166, 0.1631652825181523, 0.34927364198430894, 0.3490173396083617, 0.15443571062097627, 0.17993847118510356, 0.13726268534458455, 0.20471370869105865, 0.11370525184658267, 0.16253459297360914, 0.12962131070033198], [0.04693745635449887, 0.03913143792399957, 0.007456602376600307, 0.027719525988363934, 0.06797055353320415, 0.0403385971402449, 0.07430407819488356, 0.05503869442749889, 0.02309448273491956, 0.08707266481172654, 0.02551710364528962, 0.02362782165648476, 0.046685723693019925, 0.05220835960860695, 0.06025550804371315, 0.008939356456751065, 0.03998805445829227, 0.05497370718888218, 0.07008710125040624, 0.07306251780039842, 0.017264130367566983, 0.012320085229622501, 0.04102282090893677, 0.018931160673439022, 0.10338541931442677, 0.04125679948277051, 0.11085195737260004, 0.11715060205108697, 0.03963191933449238, 0.019069518067783887, 0.036337833190637256, 0.11535131432596715, 0.04539651646008415, 0.015287844730811495, 0.04315461377583204, 0.0352440856307024, 0.04335613320431402, 0.06596763197693133, 0.03268070180990523, 0.013150288009895914, 0.15945884188817394, 0.01761101114924156, 0.03154397097175881, 0.029717655664670373, 0.050146326708096656, 0.04422031485685899, 1.0186720158784621, 6.8324717206339685, 19.177895515195786, 30.473478301878902, 53.136627212647475, 73.73123968801191, 71.65607836938673, 70.42090831264373, 53.72100545514015, 64.7755350605134, 42.90767808114329, 22.093410914944066, 18.462345369400516, 12.750405573075819, 28.60198409326615, 33.488235550542036, 33.31907941449073, 36.981467047045314, 57.742513533561464, 68.22963699217766, 58.98152359070317, 59.489525441200506, 57.60141018898257, 50.130734520573775, 48.302051021206765, 52.37482840015043, 41.66571055689166, 23.245311014113888, 24.139289779047814, 15.819986770229956, 5.164249933535054, 2.5630573447673553, 1.4236254797827814, 0.5163587052975932, 0.21518982315976776, 0.3841308570436893, 0.3923487434944799, 1.02526061717541, 0.22998713317417332, 0.5038447509850226, 0.19112281861805147, 0.3546110991268389, 1.2003413707979265, 0.9428082286350189, 0.9029261203062151, 1.3857239845298952, 1.7654713171143688, 2.2957193803402687, 4.865385918847976, 13.144567493469486, 15.921738936055092, 20.188925650811967, 23.04041816342262, 48.6093726465779, 70.26925379230131, 71.88178723858249, 84.56940743231004, 55.49113189020465, 40.62401140889814, 40.04284166520642, 27.645153268691036, 29.58830721916691, 30.773994615001065, 18.044191291255338, 21.798440833245557, 34.034205944307395, 34.5278597647144, 43.54216068021713, 42.18087073295347, 55.29943781514322, 72.74827018860849, 73.21186296401486, 79.05192698201826, 75.69889668495425, 67.35479154894429, 43.177831326761556, 22.88693581857989, 8.527552427784089, 1.576103575287327, 0.14853894800668763, 0.020653515933982788, 0.10064286284989889, 0.042598912747757095, 0.12652623887744643, 0.03245835628120169, 0.03965801228919337, 0.03115528668727606, 0.0355908821427053, 0.026444818884614977, 0.0349678956122408, 0.048468950384807204, 0.0216753086856296, 0.051854855996826967, 0.11346280034030638, 0.033381339012374805, 0.030384368578632994, 0.05323834567060394, 0.019539802207521374, 0.013369071229751553, 0.059512284013532826, 0.021214169720488212, 0.014168259898020376, 0.06682456260727299, 0.030329118317533887, 0.0411299429833889, 0.0565917500024361, 0.07226104427489542, 0.0701076936938109, 0.052192424979781916, 0.02163842729773493, 0.005347410061081211, 0.0306710118668214, 0.014238341621333554, 0.06157497191921838, 0.0776620407498652, 0.07942513848144202, 0.050635600252257246, 0.11884329630242241, 0.020245269594353535, 0.05222737008044797, 0.08216074652849667, 0.11188501161673378, 0.03514776539598261, 0.053721042349934585, 0.04243913361982953, 0.009766650975741928, 0.04194137948234716, 0.008788829755729005, 0.014390849617249785, 0.020428466114906535, 0.036962673653878515, 0.025536529719829563, 0.07558682347617804, 0.011868002381356013, 0.04316125575813555, 0.032514085347253474, 0.004883237866564624, 0.007691255107807417, 0.014711040853252335, 0.010296218829499859, 0.019270334610595338, 0.015541351843445052, 0.03746025542157792, 0.011061609613769239, 0.1081081904891518, 0.04425298084595031, 0.05228643162897038, 0.041761957860041055, 0.025060927014677756, 0.04544479915151193, 0.076585304172289, 0.014590695143617211, 0.03700521834675343, 0.06149979188076912, 0.018780409891699112, 0.09523457321788996, 0.015016158351734763, 0.03505947759314891, 0.06543583672253356, 0.043486869939032106, 0.04766030627633295, 0.05138749639774042, 0.0527665848963924, 0.03997446788895515, 0.02597346413700331, 0.0755325691293805, 0.06593270602846338, 0.049934285061974684, 0.037270422664380846, 0.041655682312745246, 0.05174829316655955, 0.03491573651591617, 0.00918462333614908, 0.028081906643966516, 0.030372900242406516, 0.04850206836577385, 1.2910757213830948, 8.023519525604865, 24.06257606321766, 44.154917270906516, 70.07651636677404, 87.92987454322078, 83.7331267326109, 80.14704488938855, 65.7206654548645, 76.47032491622433, 57.39559165893063, 34.54335704926522, 31.090635791901622, 29.02951263612317, 36.4395563064083, 38.002467847639515, 34.75951494709138, 35.08489908710603, 51.35719691553424, 57.157209611708126, 44.19723180032546, 51.300138196637555, 52.00788674816009, 46.78540383615802, 46.95554448712257, 43.42020242444931, 38.518055562050115, 28.522130520113055, 21.28764625518553, 14.46815856041447, 7.448295604798102, 2.535302163131776, 1.508783936019867, 0.6461324062078231, 0.22446457386737872, 0.4282900036102341, 0.14658220623049045, 0.6219114026715679, 0.411082259229114, 0.39852028652544946, 0.1850992990958114, 0.20655254953570906, 0.6677201510437074, 0.5143923108135501, 0.5193823011171433, 0.7510586888078721, 1.6794713899012537, 1.8065822917607524, 2.7727705432522685, 7.395349491027094, 11.793629661683115, 19.27024575971788, 23.751251659085675, 40.479166123174856, 57.48827334373229, 53.61385022440265, 61.93985754443754, 39.580829604979485, 38.34445538059358, 41.42494370860439, 24.72012023771963, 32.43107834169942, 39.75933667152159, 28.999335881202455, 28.854818113388557, 43.31909548851752, 48.43686288402927, 58.6310362815857, 53.48580052775722, 64.53913773259809, 83.37060559180476, 84.06015042335757, 88.56598100354596, 86.09301290204449, 76.94122114489156, 50.81726697183425, 27.45351410681202, 10.13327173648342, 2.10027527424597, 0.06827238451449141, 0.09578368972025572, 0.02969002861890101, 0.034651907326112834, 0.03645569198734818, 0.10075185417888627, 0.042150456368202166, 0.02962767863796363, 0.04740169031485435, 0.06044928615372028, 0.06868780335231174, 0.0560688988245543, 0.028829901486695297, 0.02179642335601872, 0.035416945709937045, 0.04003444491254707, 0.05218453427416183, 0.030660215772748477, 0.01414868635155501, 0.04560431780954523, 0.05057178512816468, 0.053273976419962225, 0.0324245143471466, 0.028889077948406342, 0.03381895524780116, 0.07865170377396768, 0.04875666236564998, 0.016551139997318387, 0.04989661268829819, 0.0736703242986433, 0.010502444910666636, 0.10351658122794283, 0.025977359694098274, 0.03147915418770525, 0.05339917433898776, 0.03814902975254002, 0.07615138431109729, 0.03994972324900089, 0.027596894463884736, 0.02411641338239274, 0.031558369594295664, 0.09008610996628001, 0.07839952295105304, 0.04080758850661017, 0.026987762633530844, 0.022758106933906678, 0.053398752990629406, 0.06445477686582074, 0.06430510626805407, 0.018656184904337413, 0.06583624789791723, 0.10728723534773435, 0.10603203092731776, 0.16179867359178682, 0.1709441546230547, 0.15507862692879093, 0.18190276658823415, 0.17517657590008553, 0.14111109738869054, 0.10663384661799478, 0.14432276779365155, 0.1683941850018117, 0.11014393125210079, 0.13547106615958676, 0.20845773359460218, 0.20325213550559937, 0.06904652402285608, 0.15536374953244964, 0.17318327640814168, 0.11369615838292146, 0.13137182160731287, 0.12534776582352578, 0.13874944750099413, 0.24185594952394887, 0.1696328725665808, 0.18161438045001801, 0.18033551923449964, 0.17755066705567224, 0.15286254906846633, 0.28896428945083774, 0.15052985730430773, 0.0770645764385981, 0.2757936445695739, 0.24746959668494042, 0.14142493296775127, 0.1309677255490134, 0.22197745409944367, 0.09073877091249151, 0.11452385509807257, 0.17074616685990365, 0.09291249177148266, 0.28172917123283114, 0.08948409509274269, 0.14066451409411046, 0.1690405793488026, 0.21120015982418291, 0.22505069241648723, 2.534466207988801, 11.64502674533475, 32.67863873512515, 55.77331504514141, 84.80417697660386, 101.09999333658527, 95.91066621964978, 90.0365952522524, 73.8138448038409, 84.1046771695537, 59.77957687070293, 38.28180728420135, 31.96976446336316, 25.147297728446222, 42.54324282369306, 45.8761513617731, 47.34934260768276, 53.475331721767304, 74.33440608362999, 87.53725313371228, 76.34722525073637, 76.63032624029344, 75.83745048892114, 68.42035047469601, 64.70399887331071, 69.07060884660291, 56.30509038125315, 34.44038306513141, 32.662639387192264, 22.549308000072358, 8.11790498995012, 3.613825257747404, 2.2443409888975085, 0.9331088200692208, 0.5198199518265263, 0.9632774238144198, 0.98105366672239, 1.673385097134498, 0.5599190775425203, 1.0811956995917906, 0.6002257211554436, 0.9177513312428229, 1.8339680351557273, 2.0559760255198327, 1.5516706411876988, 2.452073145297266, 2.4144585959372984, 2.8498583551376098, 6.980107282438587, 16.906399957595333, 21.39600173119576, 27.529833624439856, 30.604134413503832, 66.42423275978335, 94.47543174989762, 90.24277071799003, 101.91064526957851, 69.11979536856376, 53.98254909823018, 56.415242302802305, 40.45479251492409, 41.57551957714943, 45.685359431851296, 33.32524930277179, 36.53220661224858, 52.58320431555472, 52.85598947155861, 63.07068863222676, 61.430882946137466, 76.7461302972609, 93.45297967233967, 95.26618942137688, 100.60127181391563, 97.81449056440785, 89.99258625891902, 62.97690083903652, 38.10882291486187, 15.449263953393507, 4.330628110516456, 0.46707053879095667, 0.2438177781239633, 0.2857550858489929, 0.14238124052363058, 0.1905750197869155, 0.17568337370551404, 0.21633677935648352, 0.14679989777505398, 0.17536389971933058, 0.1366423226652607, 0.23098877781341154, 0.1145039214902828, 0.16632294372445153, 0.10200607034588054, 0.22715587138889298, 0.22695045257287644, 0.10108130262984384, 0.13315311392709134, 0.10139103963850968, 0.12092394513949273, 0.1691718255319903, 0.1627575858466087, 0.1178175122326901, 0.10391771252597533, 0.1741920456650757, 0.17787591734480473, 0.1177700837292979, 0.17801433411096373, 0.17897330765281955, 0.18057155092397045, 0.0871328103746618, 0.1497407254552649, 0.16751704497202752, 0.12440198431572608, 0.14836026565922847, 0.13506816519844916, 0.17876701549656931, 0.10342730900212642, 0.13987325252063815, 0.1296764383873632, 0.26322254009785195, 0.20975118112419883, 0.28576740454281535, 0.14681593965618842, 0.1327634662870438, 0.15870098174820024, 0.08172918621811175, 0.11098179395400709, 0.12121257642584464, 0.16510777505895785, 0.17916361921496932], [0.0457183002013593, 0.07110143230567056, 0.026243829972020565, 0.008575512573213108, 0.019432919535545573, 0.04711401280796817, 0.09526543890035923, 0.026489569910711823, 0.03339237067848444, 0.024744674428215912, 0.10739805762686076, 0.016012629982264295, 0.017701055208641677, 0.06539382446076601, 0.05062230096589174, 0.010896974446011648, 0.004193921528396107, 0.04858852904890815, 0.10562978114091581, 0.04790450063263697, 0.04647054874728765, 0.03956589404673826, 0.031170428415099462, 0.055627272118844336, 0.05287994675698781, 0.08944896996141442, 0.005469686791090476, 0.03888127191232578, 0.01709911311345716, 0.014225505818162235, 0.07750473225549345, 0.010736433060599432, 0.06740025469973203, 0.04670668385862824, 0.039171963975194006, 0.03800829940084969, 0.03873889064115863, 0.04754126004333939, 0.09567922597090084, 0.04719273217262761, 0.026743539548929662, 0.02758758841082454, 0.016512621096485568, 0.01949715217755687, 0.043644174602964235, 3.489585653428109, 17.16669628697057, 36.25486758447463, 60.11881874453638, 66.15185553027739, 70.55861488465341, 56.019314335238555, 69.20201609211584, 44.1666647695726, 30.88488001977244, 24.78520412598887, 16.62619956078068, 17.76754063944663, 19.135139719132457, 23.86202527630714, 33.3765225256643, 49.94449254005186, 59.47309463254867, 54.78560340019965, 65.2387709002341, 68.03063161911504, 93.52155054769209, 60.44315953408519, 45.19404334406699, 42.01267557759439, 29.668941343984297, 19.03840034238754, 9.650741757885102, 4.90139082554848, 1.7650305407662548, 0.5256684509015853, 0.39627767137942776, 0.14299697603189176, 0.040859042802044464, 0.06724945795271667, 0.12392385352042415, 0.024660571380668593, 0.031226331766154018, 0.08649714125861084, 0.037701917857292204, 0.019115967893852823, 0.09558031635899698, 0.0639829433132564, 0.07471456342647154, 0.03245218161253199, 0.07626376174871, 0.053131166139557484, 0.03657961820041941, 0.12213488499964438, 0.5293699426035727, 0.6568377801487524, 1.3053112284791086, 2.7083127633217843, 6.88293791586353, 7.402432801262026, 13.816089034080507, 30.982896128008445, 36.81282081911641, 69.26341687479328, 78.34050316964426, 53.32193959143854, 51.382664865063084, 52.52848725165091, 24.96600381789669, 16.869543406271166, 20.428553050564183, 25.49560812211806, 13.498055415768778, 14.717543836562866, 21.366248592253655, 40.29928622707244, 49.485802727360884, 48.573698689860684, 47.25588821595716, 64.04008280846381, 69.39545954427412, 72.22416308618361, 64.60635539024108, 45.72756805727559, 20.996272986935033, 7.757893185461722, 0.6054155071896892, 0.010983208175598374, 0.04118584824966327, 0.08137385165619274, 0.027435732547253854, 0.00863559780672433, 0.023520387401203477, 0.061858481907796484, 0.05457298957832879, 0.03618472285809056, 0.050987629144782984, 0.0802941733009873, 0.02650387851791757, 0.010925080296733688, 0.0231537128227853, 0.04095540134116046, 0.08446861704390857, 0.02037947670736861, 0.034431595760848255, 0.015063856901120276, 0.031499185471705375, 0.055263659976903474, 0.011283126809904653, 0.04011431340909293, 0.02094518284373466, 0.025449527029488838, 0.010190758208233503, 0.05163152987558035, 0.052257561605543866, 0.042718215620205294, 0.012943558225918923, 0.0805531493237903, 0.01884085039848522, 0.012948368300473499, 0.019055636554595926, 0.022416673037373734, 0.04816390949511721, 0.014031916357306464, 0.07031379432808008, 0.023149240784527316, 0.042454677543813185, 0.08435119108687486, 0.06095663937289388, 0.05706533406590743, 0.027851762340193795, 0.05469064536173979, 0.004644956272621189, 0.04190527758891544, 0.059813429346127864, 0.01834400407519312, 0.026566056129071983, 0.05982435759036772, 0.04839215007039809, 0.055862514737753145, 0.05714338310363312, 0.03967968491657127, 0.04234090199573867, 0.011524475149569974, 0.0485055847093463, 0.07779288090645306, 0.05744323374763612, 0.04165903777785359, 0.016296126564303716, 0.052132712256523876, 0.04642636079581515, 0.07625036287091433, 0.014444023780074092, 0.00744651587146725, 0.05842523206205619, 0.09317935849990576, 0.015945403851688873, 0.03650717692629945, 0.036056115847801974, 0.026996356224821463, 0.061878507446137175, 0.03707691268514722, 0.04719046455237174, 0.03418725584783862, 0.020917517493569085, 0.014670288806120235, 0.04329196951021591, 0.0631158198830822, 0.039254349070571126, 0.04049831115069889, 0.018139653951830922, 0.035720377814986055, 0.02708637155592442, 0.09503576574065993, 0.13579446251594252, 0.029569394668684374, 0.04824180148481842, 0.03159728303040949, 0.01175603671600261, 0.09002114571030102, 0.10625191348334474, 4.943243986175907, 21.58438728701684, 45.72491261266893, 74.95493288963073, 80.99230781678231, 77.43076432135798, 62.50799717441682, 78.0464901462678, 56.95693731307984, 40.11878267411263, 36.07452484869188, 27.355572523609286, 25.480869816195582, 25.74500418478443, 22.176270984834243, 40.324440386987504, 45.82601562623055, 50.324244653024984, 52.63784685442525, 54.32859236194242, 65.86254935110769, 72.2034372821931, 52.60260435842699, 43.636211272208925, 37.61255287354992, 27.03824297074349, 18.509749174118042, 9.64875017443011, 3.9818744890151487, 1.7446847163861798, 0.5842544426841121, 0.052155928551069194, 0.04751636218580027, 0.08284461023586412, 0.08127191599698798, 0.11349337490936441, 0.08809800455046278, 0.03828853436355149, 0.07605063608817517, 0.039340338609631986, 0.03649508422841469, 0.03531252026497837, 0.03650835670170285, 0.03171536016217884, 0.013309942648535775, 0.08274783800926902, 0.06456350772491386, 0.13161439568765704, 0.08762729714714712, 0.18935735367478865, 0.29586649650046903, 0.8085615548395342, 1.827341558471803, 4.77185994386673, 6.712326580478299, 12.012853872391487, 24.415487397101618, 30.049736807423255, 48.16234404040922, 53.395385972915165, 46.39124485754198, 39.25071116416685, 42.38248055981052, 35.94628295590801, 25.28942677282518, 28.849970063855572, 38.07800485241798, 23.839555978775028, 23.563121057325795, 28.709460958357784, 49.1229481850901, 60.042732607933786, 64.15257246263566, 58.706796861463985, 75.81612848466443, 78.6312057125953, 82.00540111910912, 74.69234589607485, 52.85996283254316, 25.4676200497535, 7.962804177115041, 1.0037759571306168, 0.042118717345499226, 0.04390608091207762, 0.026900156648949753, 0.021223772632619067, 0.00881343937268661, 0.07765539110668244, 0.10069928522552214, 0.03123671417274783, 0.05893533553687796, 0.055103444178859075, 0.020226661318672762, 0.014578122683169862, 0.006384024220038086, 0.006961485496797269, 0.0344138493340823, 0.06605198591827385, 0.036972085044028304, 0.038348074717026566, 0.013468517103202403, 0.05379260645338124, 0.041186671794181874, 0.050414442159836335, 0.04918390577058158, 0.06373054415528333, 0.07423507665554363, 0.010489856170850896, 0.10594815962136754, 0.026075099106697787, 0.023641618900001053, 0.07463557210059897, 0.016998452990646326, 0.09306461385060703, 0.05800662629847085, 0.08792827777083843, 0.04915743360235807, 0.03202944280459516, 0.014237096728456598, 0.03021481225357181, 0.028027518231782223, 0.0434698666175527, 0.040353811646421114, 0.07167509426513026, 0.020869951094350508, 0.08641638793051244, 0.03127510666907315, 0.015358000190087385, 0.09878198931654615, 0.03718762771196423, 0.07235370260933716, 0.13261959497486392, 0.2249868466488777, 0.15592077206219399, 0.14474897314944576, 0.20967107897083606, 0.20999639054700253, 0.1798938235808765, 0.10178799575735485, 0.1494843617922837, 0.2030013489627069, 0.2634914063157574, 0.17820561094389809, 0.29030963177642516, 0.2664859520812189, 0.16577281598602572, 0.2647105279949404, 0.09423720334926922, 0.1735009730703408, 0.2118779790978278, 0.20868313198368396, 0.091006564607303, 0.1449359905335211, 0.06710724905133247, 0.1840916330054883, 0.1439793458989551, 0.1260911315799721, 0.15914880610521764, 0.210368556060618, 0.13183427824368402, 0.07776366997390025, 0.30365283030175394, 0.1663744095112047, 0.23273578003769924, 0.12633732925619812, 0.08763992993701851, 0.11694109232555475, 0.1788801973265025, 0.17599183134734633, 0.20571610409646265, 0.13670451368295378, 0.10167941811584658, 0.1086707211910717, 0.10874507002412312, 0.1378417099195142, 0.918342138250028, 8.279866518512849, 29.203171653132287, 56.779846222169944, 87.82282521647792, 93.88371083044237, 91.57523124448716, 73.10901057335639, 86.26606002930673, 64.99104968963131, 44.94284299112136, 38.03777310156053, 28.90032937449794, 30.24689082176455, 31.833373846546298, 36.45118221159905, 47.872606400520574, 67.39408585333055, 79.41314589592719, 71.52773841734856, 82.66352776558169, 84.87522678990518, 109.98995903999575, 76.61207152951148, 60.62645581460769, 54.427012474306174, 39.52270007902576, 25.13228093424151, 13.278952798535748, 6.904744823132792, 2.7302937257674436, 1.067880110875253, 0.8182667856735568, 0.3948783351769371, 0.22567954335001209, 0.27024983398375974, 0.47931807836697954, 0.1890719399577187, 0.29184263499994434, 0.2691311923967254, 0.2386955304011222, 0.16531112543757887, 0.2589552158549909, 0.2899942180562404, 0.18834633211935722, 0.11068357890772243, 0.23147682178645368, 0.3108259566849278, 0.18437844100258044, 0.2753890275714859, 1.1137969695752667, 1.455400110252442, 2.078284751023016, 3.909941161832502, 9.491834775094064, 9.77223030982479, 17.765022477796002, 40.22920523920367, 49.18188179692915, 85.5693764840403, 96.06785912667551, 71.35007858276367, 73.44789551150414, 73.07527818987447, 39.57240043147918, 30.10723875414941, 33.679698205763295, 39.84718599627095, 23.30386023367605, 25.691444220081454, 35.625511523216005, 58.91865584158129, 69.72992004886751, 67.30323591539937, 67.23518279290968, 85.71664579453008, 88.21652135541363, 91.97228493229036, 86.49394973631829, 64.70066878103441, 33.90051980172434, 12.173614175088945, 2.0075825577782047, 0.1014546325971042, 0.17542687214670644, 0.13659948302853492, 0.1234721527585099, 0.14085240481841949, 0.09955718602624633, 0.18682261388148033, 0.13221600453459448, 0.14822172631900157, 0.1341863520323269, 0.10799005207034851, 0.16643284669806882, 0.17245354701674756, 0.1099607366467676, 0.2305914846158797, 0.3086829942560965, 0.08533262632667057, 0.18712849746788704, 0.12132930524286725, 0.15891835153583558, 0.1398543301489084, 0.15660360155086364, 0.18833749146471102, 0.19920383580029014, 0.20976648756092597, 0.09121618158514462, 0.25620903579458115, 0.10256663986271429, 0.13336505981222277, 0.1405760156170976, 0.18050301669826432, 0.18822374272971384, 0.206572835543944, 0.1436055256354232, 0.14636278332721803, 0.13215068787817033, 0.09400345460181275, 0.2840761275541398, 0.10815663788948329, 0.11695630683173096, 0.20900825969874862, 0.20147013838493055, 0.10759212301983949, 0.1591800318490113, 0.17134103413310744, 0.08503216664276778, 0.1583911145045873, 0.15168320267431198, 0.1496507560894374], [0.041248671289893894, 0.05082349097656627, 0.030236404441717653, 0.012461841181521455, 0.06647200894451911, 0.022271139314398173, 0.03316620620147836, 0.06858580640607304, 0.023196079400217822, 0.021302317712275733, 0.025694606217345404, 0.06371241468455523, 0.058300152886658914, 0.06053104305699949, 0.0411047961472744, 0.07398022218577324, 0.11714432779098712, 0.009337848581884418, 0.041087670251727104, 0.04563761199073446, 0.03385029590478347, 0.06708012953881295, 0.04408497393371598, 0.012193534207800704, 0.059449449481983344, 0.006998651294833831, 0.027199909616742405, 0.03883254872034154, 0.03217637463803253, 0.08331143357340368, 0.04221843134972357, 0.01874415286546273, 0.027443171260998617, 0.04546559843865614, 0.03384758778397114, 0.06055611328432157, 0.03905646472928986, 0.01176044650961675, 0.08831886003815359, 0.04145068101464741, 0.056752295218287944, 0.13655292020449716, 0.6517159001481149, 2.9504867619083774, 15.612667933587106, 41.214261439538774, 57.731370079901914, 70.20983772893106, 71.98201164122551, 63.026856145551136, 50.901209615891986, 58.26204322999524, 90.90267812052082, 36.09486626040551, 19.212735968251383, 15.061626895781487, 21.27185675405687, 32.752393022660286, 43.8749384880066, 63.25139614843554, 55.403674802472516, 61.16850383820073, 62.623911057749105, 62.05583810806275, 54.31552302452826, 40.180336429226784, 35.92563952169111, 31.86119914054871, 14.54855832361406, 7.016909410876613, 2.906565041311326, 1.0826051787983988, 0.18218765936551556, 0.029738292158130678, 0.057665138775783206, 0.05684365503369801, 0.0026622742805029118, 0.06403691037708233, 0.060643347716259385, 0.03256615251302719, 0.02074971167941488, 0.08694425315385865, 0.008413221634503816, 0.021129706611616478, 0.12010858243992252, 0.02216359589158768, 0.03879259723509031, 0.08059448742818448, 0.10061436437911565, 0.024176549369228945, 0.06207564868213189, 0.05718041579389284, 0.11381687085715034, 0.057322563408243085, 0.06053029995171293, 0.044330987748840166, 0.02689145772056955, 0.03759021457705287, 0.056373403452697306, 0.4113455483269307, 1.0613764534073493, 1.0182967553696325, 3.6794678386180633, 5.995475188378365, 18.210648836628085, 25.084224054890296, 34.96147778726394, 48.44159326245708, 58.397557197078584, 44.47065238029727, 36.0485666028915, 32.74711155122326, 39.143238221445394, 30.187262950405, 37.38005438158589, 43.444038667986476, 48.877894186204486, 56.447437117176676, 64.00373028170678, 59.090926339549405, 53.78827410359537, 61.111472575895256, 66.38094548256167, 76.70621625838741, 64.6194286500254, 40.13500559714533, 15.777046622768527, 5.827820339510518, 0.733392027116591, 0.05896832328289748, 0.05212207512569524, 0.03615206452987848, 0.04574119856941604, 0.024407195460592068, 0.04923698417241535, 0.0216676841955632, 0.02094165883928297, 0.07299422106194882, 0.019760203788117058, 0.019974478580538305, 0.03615738118007299, 0.01568293446795114, 0.0485119202564801, 0.0187427700767594, 0.1026148038105138, 0.019610987097445517, 0.08574141084306663, 0.010690564503743043, 0.07451436933009856, 0.020168375434173692, 0.07417845509706006, 0.15193901475398772, 0.008311828940115389, 0.08771008826912412, 0.03604077110667864, 0.028944287989889423, 0.010563388162653052, 0.07028123559129816, 0.07432168289538353, 0.03411371140710769, 0.11708973636550289, 0.04660025509374757, 0.01267124365474428, 0.044100050544065815, 0.10478213549621644, 0.03822596030189626, 0.011712150411650298, 0.006719210190743569, 0.0334611960176018, 0.06196530520795815, 0.01884626089445045, 0.05218539612307664, 0.03197586453039079, 0.012822871607157492, 0.03225533915082774, 0.020529017070188157, 0.060732918716366255, 0.09623926688706684, 0.05711186624642822, 0.04743858893972732, 0.017721337386437, 0.02313024754966459, 0.015329808154473863, 0.04261467883723878, 0.019772143268416968, 0.04471897680853163, 0.020223154551199368, 0.03595663550039453, 0.0463161398957093, 0.008322612585259542, 0.03040434815169823, 0.10712104789432018, 0.06878059958257983, 0.029879258081857717, 0.023796357169386842, 0.0646730812807237, 0.033631210080197746, 0.05609363963406894, 0.017658460720051682, 0.01929311998068325, 0.06486726158689107, 0.02297062738498132, 0.017525429552000378, 0.015494630056162997, 0.048981926689345034, 0.04446553960142117, 0.06660350027584261, 0.014701158319029116, 0.04831534975598897, 0.005242258747814284, 0.05833219068365232, 0.03776462598433418, 0.032453943614757834, 0.04859098436070546, 0.04937754215432271, 0.10421134636647279, 0.01912909481043537, 0.14201011688959214, 0.9818930539392656, 4.592425727075146, 21.96670855245283, 53.50189401257423, 71.006392663525, 83.04038124699747, 80.8434695582236, 70.90536025262648, 62.454825524360906, 68.44627734153502, 92.21852348696802, 39.69968134357084, 24.672869405438824, 22.913937414846114, 26.918867595734138, 37.41825042232391, 42.953765930668006, 56.03821623709894, 46.34210148165303, 50.19198233081449, 53.47483750312559, 51.678380197094334, 44.24142906742711, 33.81938557470999, 35.38839247918899, 25.964547088069303, 14.907161997210595, 8.9376901618896, 3.5153570963490397, 1.1508683932404364, 0.170207055465829, 0.05485744951593299, 0.04309777005185043, 0.025618179370799375, 0.037451096840443156, 0.041615937671233574, 0.1891950196436336, 0.2154312481082255, 0.3712615298648035, 0.13675680684466518, 0.0285860346329789, 0.1733128218761375, 0.1335106931266285, 0.06507109460090438, 0.05488938772149625, 0.10371490606978055, 0.019878141108840224, 0.030512515936167012, 0.05040427234264151, 0.22292328157251884, 0.07048633265038652, 0.09061109469903093, 0.08877661289466966, 0.026452058415499427, 0.07769013319404856, 0.0334392361072523, 0.08605556051817634, 0.1807869901700366, 0.5851054131504029, 0.7251576850971868, 3.5799298507551995, 5.06783317173681, 14.415684111656683, 20.957161072761785, 29.70835331947573, 43.88664676297096, 42.287974972878736, 34.87809211977067, 30.944313733808457, 31.699530809156357, 29.390827648101318, 25.71174248572319, 35.97024471529069, 52.29063472440166, 57.374842320719075, 54.30427758924423, 62.54568722940261, 64.91784257273521, 63.85894383153608, 72.22560651840703, 79.33216464134955, 86.80648419164842, 76.78529908580165, 47.95261490729548, 20.509689238763627, 6.239706470120338, 1.0953108389531414, 0.04613479922315286, 0.03438094202729483, 0.01524065562989563, 0.04970113386309916, 0.017570628739532926, 0.023448965024022807, 0.011745646648529557, 0.04763719723409703, 0.041236490491897836, 0.04071399937534044, 0.018019458586950938, 0.03327881729590797, 0.033419065012206, 0.04292080757178126, 0.022306254869627378, 0.08749765208772114, 0.01373947761397088, 0.023524514699895537, 0.04378760541458765, 0.05421722217673256, 0.03638375250081863, 0.022239229837132078, 0.04918198672033126, 0.042381443368691596, 0.0779326306656003, 0.02182154337905588, 0.06917797704978336, 0.04985000389898497, 0.06590501961087988, 0.01720353089753659, 0.04233497247520474, 0.07258976494232494, 0.014646311211700161, 0.005489909597071669, 0.05294567327045145, 0.07303876141386648, 0.03377732602999576, 0.029779471299280564, 0.03006004717110867, 0.01401566667482257, 0.05206423548741206, 0.0429534046129594, 0.04518745872642725, 0.02566315064717445, 0.025516820192757635, 0.05978167500166644, 0.0215431374512733, 0.1498709450806341, 0.18352336430501553, 0.19525091404155379, 0.18983974391894956, 0.17886671417903516, 0.1507710677481467, 0.10985038168127499, 0.2158286025927913, 0.12204999479675487, 0.10715430377111321, 0.08411075439183943, 0.09480702720822827, 0.19498255344167834, 0.1252854675535233, 0.1310633333219636, 0.15533134401325258, 0.24040773691188908, 0.19234598524147467, 0.16172071648461206, 0.13677936047315598, 0.09396878146235982, 0.20156543972271107, 0.08283851983686609, 0.2216146961455384, 0.15360525598929775, 0.1868232727170952, 0.1092699551654439, 0.21485340330869923, 0.09972795468544769, 0.20063640489693613, 0.22832086129534632, 0.10334513075048886, 0.2700903038344076, 0.110557611070333, 0.19518420310510745, 0.1309780524142327, 0.17495762797132616, 0.11162927614585047, 0.1769429601488575, 0.17032354679559508, 0.092017509553942, 0.22145512003091075, 1.6847631575599795, 7.994231187528181, 29.056633864679647, 64.90217270389681, 84.66304225306358, 92.84508289829378, 91.89000145081552, 81.41215047528668, 72.33978671412315, 75.97885977837348, 100.1501678651379, 48.305671368875814, 29.99139351229514, 24.539281322110085, 33.91166717775407, 47.03106580242034, 61.65481890401533, 82.39243707349225, 71.59274778058453, 76.83317553612494, 79.44035930018272, 77.78546425604051, 70.55217435283046, 52.08982506105977, 44.85491914133872, 39.84480511757636, 20.919574960585564, 10.83761469010384, 4.398034532223979, 1.703038460785343, 0.6092696036061933, 0.19010012188265402, 0.17627510001822827, 0.23515874760285502, 0.21905450691138545, 0.11594310192571533, 0.25141953070077205, 0.2147318251551159, 0.46041442982612124, 0.2945753625564037, 0.2677927448624565, 0.33579683772498564, 0.28028114248187314, 0.16376136021027643, 0.2107796235190284, 0.30914261636714785, 0.4998887648745891, 0.13061613715704412, 0.10772474816129093, 0.2450450356569021, 0.34301081191628213, 0.18913569379477732, 0.1914786051718458, 0.1852489773544573, 0.10627169387354966, 0.1125049223041823, 0.2533323296736325, 0.7179528426739478, 1.7648936255324272, 1.6358068296986243, 5.243418072500537, 8.103157858694754, 23.92875852123384, 33.49742958622594, 44.86203039846113, 62.61484646028089, 74.55474130568966, 58.599543571472175, 50.236081538661836, 45.65023460695821, 51.09464522330992, 44.79594630579795, 52.1573055175043, 59.76189090359596, 62.61090055588753, 68.14799677941107, 77.24390260634884, 74.5481203448388, 73.08266793527912, 82.12130715770107, 88.0007988406766, 97.55242916845508, 88.41664068160519, 59.18230187508368, 27.531639875904208, 9.810853888911586, 1.7977569588730413, 0.0947259214796847, 0.11178509842964912, 0.08369003422558309, 0.11225695496485119, 0.20125404030324953, 0.14963673668042307, 0.1666937302798033, 0.1117452925011035, 0.2776989358807764, 0.13196411482509107, 0.14410130709650057, 0.1025236010431282, 0.13019086642851754, 0.15548892829927707, 0.10688683949410917, 0.11447116357064056, 0.09078895733241113, 0.266370793744441, 0.10309685697598804, 0.23342790983376965, 0.06921615121105025, 0.14948161919751476, 0.23314016720940992, 0.13131890025350357, 0.3995238310627399, 0.16002540987345482, 0.1255944844395403, 0.2091721259057522, 0.23993512194964195, 0.09930831470316458, 0.24501624607270767, 0.20481230420691354, 0.11226298407681527, 0.06172653092371841, 0.1413352393935765, 0.23275070343046422, 0.15882599197568434, 0.14889157827823393, 0.14107447838590992, 0.10100663203986422, 0.1876838652477149, 0.13618265458893392, 0.15394777390024356, 0.1142131298359844, 0.10766485540737068, 0.14898288063704967, 0.14675834516604103], [0.0388865732407618, 0.052394235521675124, 0.051936628221864664, 0.053485749935310696, 0.02210995441512956, 0.05410403651635974, 0.04176836618552766, 0.05159537818643355, 0.10837010062870481, 0.11426900828918142, 0.06381087613502337, 0.06690903146180414, 0.10818373441936509, 0.07276746669724103, 0.013059806322769053, 0.03298699908379105, 0.022711626464320768, 0.052339663248389005, 0.028684616742295124, 0.024129287489960273, 0.016049109173998717, 0.0719562485333412, 0.07311259696800863, 0.028153717810768756, 0.03812004098548524, 0.024775436688815395, 0.03036277639048715, 0.012782813827206772, 0.02962470047115799, 0.029848876950000564, 0.034738138182869846, 0.051706388157101414, 0.09981183365227715, 0.09307503264637725, 0.012311641983087025, 0.026724538653187697, 0.017580861758981502, 0.06109614398390536, 0.11667484612835032, 0.040461818552425796, 1.068838149789841, 2.7859702994746547, 13.355036973953249, 45.61441944491479, 67.1309026595085, 71.52399647620418, 70.0279260450794, 57.96417451673939, 52.814816351859804, 47.67584070082634, 27.68676961621931, 19.3510171674913, 57.385165999012614, 79.56672237765405, 28.925585516037483, 31.744863602422903, 46.41590087644516, 55.21970779665055, 59.85617291542792, 46.24661922454835, 58.075381555864894, 49.804620819707075, 36.51764285179877, 30.329235099977065, 17.045042014891102, 9.355990348323699, 3.568945007939493, 2.6532502856946762, 1.5078114333652681, 0.5392495350491616, 0.11783668741343484, 0.05944771046239523, 0.09922433614490495, 0.03436013124883175, 0.0655308086425066, 0.042937343579626856, 0.10989859159434996, 0.08111784805453594, 0.02300659138258667, 0.15383129789223596, 0.01991525232311218, 0.017727544613843484, 0.08448522583010697, 0.0012841040100489234, 0.052040191817908525, 0.07958482950925827, 0.05513673452960868, 0.025419523195934393, 0.0707071804771981, 0.07531159872850103, 0.08876784118793665, 0.055369085166603334, 0.1319755601786798, 0.07511010994353602, 0.052501357596127264, 0.09832904749219457, 0.135506505386964, 0.10349599644541742, 0.14458660847477375, 0.05312709055180031, 0.027152111475926735, 0.10871660985773611, 0.0647149786293026, 0.3810896105583637, 0.6765290590063219, 2.1768296437878765, 4.863686061674549, 9.517401764469763, 35.27848374459052, 55.42737376305365, 59.226079448576904, 56.49896921650056, 48.00984228810957, 33.191100320508404, 26.600035775092344, 22.73342405596087, 31.00218438333081, 71.00760859827842, 76.63137743549963, 54.40813802903699, 34.454487908271055, 45.96786814351236, 59.41110549434539, 68.13531967901415, 67.11580153434508, 71.81556978533345, 54.06627208955827, 34.901190957715436, 12.372409701347353, 7.58770497575883, 1.5732191623218599, 0.1974566650366591, 0.010991665786282431, 0.10627480419052225, 0.05842121776133295, 0.007930115098133683, 0.04682550026524452, 0.06807104894711126, 0.02162600518204272, 0.021195954064868634, 0.045582151055456176, 0.00834535965095124, 0.06964748935593713, 0.03617709262236472, 0.057803387002598856, 0.08095080258264657, 0.0596741775441314, 0.07430760986021451, 0.004900924442711497, 0.019819738395932703, 0.03674223185366681, 0.004368932878283123, 0.08533305533590817, 0.030815214512028524, 0.002873045417682959, 0.014571903964444516, 0.02723111429311816, 0.07603268664810928, 0.04918733401404274, 0.032621517687314944, 0.022587637048995784, 0.07125020658056583, 0.04410448236270778, 0.018962759885095784, 0.03711158965503977, 0.010245707779822331, 0.018637254871728442, 0.013020310659832772, 0.09624668261817387, 0.01716232494330935, 0.06453322426926705, 0.04518983359899252, 0.03386538017601256, 0.006296701687988976, 0.04546602744789374, 0.046525592164647196, 0.016687436615146937, 0.03143979833581515, 0.08949531828083339, 0.09148580623009513, 0.010696975702059366, 0.07376164964009678, 0.013645249756894285, 0.01941632990154528, 0.03274569670940119, 0.01700747367595473, 0.0648456272639094, 0.05956287646005231, 0.12895325138684244, 0.05492943113729839, 0.02161668380722404, 0.01229836663696915, 0.010545043229696252, 0.014970689118208905, 0.02317331509754783, 0.01933966365252291, 0.03314708847732794, 0.05347513961755941, 0.06246482517810599, 0.05004484304076722, 0.02995259184840947, 0.012951028540790563, 0.09703840384440077, 0.025285137967476924, 0.07822361384187976, 0.04935306564514195, 0.05130352550036004, 0.03547026925990659, 0.01976966688920173, 0.03781571638800445, 0.039414545716417414, 0.027825198241419373, 0.06968560223017009, 0.052639027426560084, 0.1769126996758484, 0.04181252732392281, 0.8270417406193672, 3.9720337525490796, 18.04408734844577, 56.18366164545859, 78.74345610218664, 82.4949364508352, 79.13402218972483, 67.83701558266917, 62.72127605253651, 60.12480035904915, 38.84187467636601, 34.593300588669315, 71.09317118121733, 77.86664947386711, 25.47467835487858, 24.650913938399285, 39.70649842293032, 46.988900323067945, 50.781800900736165, 42.888497691000666, 48.84047085239042, 42.04119120874713, 33.087553670329434, 25.9139092891447, 17.39809455410127, 9.454249643510389, 4.497336687580232, 3.603663867519748, 1.261032572196376, 0.41757764294743543, 0.02582823684919746, 0.07799958675018243, 0.06515855119834024, 0.05453613691873128, 0.02768128479440366, 0.1489770277253082, 0.2680001401853177, 0.2587476060275109, 0.35434701329758095, 0.7405603424676004, 0.25543464347720146, 0.13096437008390505, 0.06641524182932992, 0.04787735813747972, 0.10861220739541516, 0.04112642663981646, 0.21966619747540644, 0.020893263149886362, 0.10409979630381831, 0.08517291997709582, 0.6431454600345704, 0.2446753829116783, 0.29918868274938676, 0.08514234540803779, 0.209068535496631, 0.0945705741703991, 0.3515598628549807, 0.12086660345836032, 0.07199056161146972, 0.03418324154711539, 0.029169155863083662, 0.10348075129572423, 0.01624601866839634, 0.10229151470646744, 0.28472380892884347, 1.9174880438273953, 4.263955662327429, 8.709559229112442, 26.30635811436561, 39.28066630517283, 47.332931410881784, 45.49008031045237, 42.720259389569684, 36.78856095960064, 33.90428919945994, 34.62109450371035, 37.9333007720209, 76.36253818388909, 89.99413951750725, 70.27078351666852, 41.92075875497634, 55.39020930567096, 66.88922974371141, 77.59671980334868, 77.67041329414614, 81.24452406360258, 65.45114763321416, 42.75025767664756, 15.445900520970746, 9.34779945881136, 1.9016830983661839, 0.34309125114833156, 0.03900277728755628, 0.06862394226294372, 0.09143637057634131, 0.04102682754878075, 0.07052332703625003, 0.039268188448923255, 0.025366017700082837, 0.04021821791426309, 0.020038416278698755, 0.01637551817111671, 0.046691982631361297, 0.05941971760964202, 0.014056052914970826, 0.04431985649130037, 0.028960350938441775, 0.0031242820372309296, 0.02677478252970163, 0.04359013093034587, 0.04000429935272663, 0.035504976873316114, 0.021948292626128085, 0.03523322633437572, 0.009070467616942142, 0.036886624105635195, 0.027467475400396416, 0.047877951855621034, 0.06314262146911313, 0.026807852630173008, 0.019108333827687368, 0.026688779584102096, 0.07498575089078757, 0.0256691912504574, 0.01652869170591716, 0.018566041253507137, 0.023459853048646645, 0.042385469160733685, 0.04531917222324879, 0.03040942731463621, 0.026517041823676517, 0.015883306679766507, 0.06428072935030346, 0.015885964047253853, 0.05807633646914075, 0.07154036238188706, 0.09302128391760973, 0.22194022222632365, 0.1432569556298756, 0.1701640472897599, 0.15477951555963487, 0.15223601172047277, 0.11845240759993754, 0.08805134213499485, 0.12507373617301065, 0.1817385326590269, 0.19333767073769725, 0.1640291539050879, 0.30437365775146796, 0.2166322288253615, 0.10576264376962378, 0.10537989092089477, 0.14171275220090343, 0.09816145043699973, 0.1882263627504149, 0.16179297389763017, 0.09898550057363126, 0.24076315574347976, 0.23434240431074174, 0.20163405055720962, 0.13107952842068288, 0.20822577749288854, 0.20248963287280453, 0.12608508714624952, 0.14838884073880412, 0.08141954113999683, 0.15413453081442466, 0.15590181904694728, 0.24494078641216604, 0.19873180306486546, 0.11287685033054122, 0.09802809751202023, 0.13643851263388512, 0.14191132219087693, 0.3170328316909652, 0.12776370836241593, 1.2496499765303828, 6.133302373270835, 26.427167115672944, 70.62295744496008, 91.94631884174963, 93.06468071476107, 90.0142220527895, 77.44352771389869, 74.28100693610408, 69.51575863745906, 46.13979739527549, 32.85693399367794, 66.64260679675688, 90.94517307896768, 38.58800318933303, 45.5433500197626, 61.24580590955673, 72.22856398551696, 75.78666363993, 59.7897122752282, 75.70440369267618, 61.97539029582855, 47.921651717155214, 37.5027657324268, 22.287927135344475, 12.888168038860446, 5.519198448427263, 4.288911252252517, 2.5417586295835437, 0.9573317235035281, 0.3999791630814153, 0.21356226936463388, 0.3267010145129696, 0.23909262441579374, 0.14741137383445618, 0.24849229342033788, 0.40569135979298626, 0.29714013299634384, 0.3860951677685784, 0.614298572463374, 0.3778203456632553, 0.3923264963011588, 0.21421508352843024, 0.22928328223286137, 0.3718679957091809, 0.13907033108895825, 0.3600859924429848, 0.3767642474943592, 0.30994900051624547, 0.2150420907644495, 0.7797232474530897, 0.39132233889352896, 0.6456699955367273, 0.34901988302027026, 0.38558547415079614, 0.370437985346202, 0.4635509776492273, 0.31701714221027594, 0.6156404520715437, 0.08483145926748553, 0.07060487709578968, 0.32058153481733415, 0.22056115671030938, 0.8919194593064247, 1.0351362872508265, 3.499141527760414, 7.261293665055306, 14.026017227480489, 47.68910223437894, 70.91264017166631, 78.23315574276832, 75.63800581039922, 64.76861992189961, 49.04653256939304, 40.0266501211351, 32.93151394013436, 40.21875212269445, 76.21438241774037, 82.44033705803656, 70.7063627243042, 50.355333359010764, 63.02915465447211, 77.77255965817359, 87.77629806149392, 87.29934569328063, 93.07334130810153, 75.62791747431602, 52.424340478835575, 22.08764699197585, 13.137391517239234, 2.4615878347427618, 0.5504931930092074, 0.10682454888498592, 0.16946361310059027, 0.2836581499826524, 0.0972099539132849, 0.1302806672550017, 0.23668476410450476, 0.12824407613445676, 0.12087648599258355, 0.13927156706490826, 0.139530566070349, 0.10454034282555504, 0.1193381737797491, 0.1274721965854687, 0.17311252052745513, 0.14123416175284695, 0.1354320722842409, 0.13998024436014314, 0.1197349536983717, 0.12171285482303751, 0.10519644350654657, 0.18622452903899456, 0.16294256543680546, 0.1398541309660481, 0.14277726201520813, 0.10794644634569846, 0.27529636157616494, 0.19505856468552546, 0.11399353073248941, 0.13253868076830141, 0.19631874867744986, 0.14227339066565037, 0.12099725209296712, 0.12195437936292541, 0.07290625884648293, 0.2371515108332519, 0.1959296679424663, 0.1709625560549959, 0.233906147881381, 0.10263001065581076, 0.09688735428837039, 0.14710293151438236, 0.14538994359393276, 0.1829991456601889, 0.23833058143575347], [0.08975921258811029, 0.03649237227716273, 0.026388346713276643, 0.056465288038335504, 0.08038607320838398, 0.0379117799832696, 0.0755557662717277, 0.02030375849215254, 0.022549618020533554, 0.01619508722797036, 0.054486440795083205, 0.04973478044473356, 0.049354333520656636, 0.06329125784818204, 0.02111708339784415, 0.053590435850163626, 0.06407636390518277, 0.032747079498104514, 0.09472070442092034, 0.04092210332953161, 0.05203103706721337, 0.050286394393732475, 0.04134990597864793, 0.041132865608820034, 0.038495263189918576, 0.01130374032072723, 0.046670210412553245, 0.021241350520041682, 0.034459753322505185, 0.011698061097112876, 0.051624114144473314, 0.04380010030863266, 0.06567336228345672, 0.06992636834301295, 0.03714938460278415, 0.04961000387406638, 0.03729887516988862, 0.04818368988532213, 0.18769426872172665, 1.0467011505557646, 6.402156333769522, 32.25398136723426, 63.214266992384395, 69.31399191579511, 70.75889110565186, 66.73757522336899, 63.742410213716575, 48.58847033592963, 41.47684451072447, 27.502412334565197, 18.381789691986576, 15.42812139757218, 18.661319363501764, 35.89041271517354, 43.688892625993304, 46.8787052554469, 69.41729145665323, 58.670318818861446, 45.281818143783084, 31.62771809485651, 17.575320966782108, 8.79986297699713, 4.469874212818762, 2.290891432954419, 0.8169741808406769, 0.2418364449253967, 0.15205279413250186, 0.06435113283054483, 0.028744072826098532, 0.07350818178946934, 0.03281911091518498, 0.016430613299411152, 0.044327348831199834, 0.10901271816222899, 0.017885498537291444, 0.060264222293851845, 0.06825994324660109, 0.16149793811623128, 0.2702039606388538, 0.5419487385980545, 0.7377879009131463, 0.22465635631834308, 0.12691037068443914, 0.12211725731650669, 0.02217594331370727, 0.12804889991398782, 0.38643135779326965, 0.0411997948803248, 0.10175092476269892, 0.08023785817767344, 0.12660024297093192, 0.5187733531478913, 0.1649136330571867, 0.12572206872244998, 0.2962505823421863, 0.0550413450917169, 0.09657289051721174, 0.06214771457316895, 0.07322414703066311, 0.27006722926612825, 0.10728735792180223, 0.0534478439048173, 0.024687679401869257, 0.060725644711525216, 0.0475833029486239, 0.06296390081725775, 0.0474884842462357, 0.44758542951556946, 0.5790150141523731, 5.660299831821073, 8.171812084413345, 23.176769556537753, 34.81296116305936, 45.60751607341152, 38.51144636830976, 40.930434811499815, 54.45631257949337, 22.583620894339777, 16.818956598158806, 15.869817541491603, 19.876330398744155, 31.20730669267716, 39.11944120160995, 43.881539837006606, 55.55969492081673, 62.22257414171773, 69.36724985799482, 65.7155663736405, 55.96297341008341, 49.09320485207343, 25.660077025813443, 8.639320365844235, 0.6695778223295367, 0.16516995075489246, 0.06191671991180028, 0.05435160932040984, 0.016739216497949055, 0.054603296016613324, 0.07848322571765992, 0.016866524989205985, 0.005064179215790524, 0.088300320710386, 0.05883395146097868, 0.055850904675260674, 0.028479510107107704, 0.030832620029668176, 0.010679212038315112, 0.061586712216657985, 0.04958067802832492, 0.0825073859924751, 0.044143231089917884, 0.050823460333049304, 0.040736652595261415, 0.044626766635525617, 0.04666043513063942, 0.027475458036567417, 0.02517070932944696, 0.03381777547239777, 0.06837134009167072, 0.05264393038927548, 0.0689565776396663, 0.028934204357586084, 0.01957915039853223, 0.020482320180763642, 0.029461150275423165, 0.0613397867569039, 0.025077959064454324, 0.00784721959667701, 0.05103112761712363, 0.019647872315779812, 0.020137191825215856, 0.028508410774051186, 0.009060030626583724, 0.032204708399912046, 0.057457969448859655, 0.046096805092548175, 0.05205797271863107, 0.03837537809064792, 0.04575581935745093, 0.011165350367645583, 0.0031951059082207544, 0.024248115387895418, 0.023899888206693917, 0.024033620345195936, 0.05625889246021548, 0.05199115836031495, 0.035906713380808794, 0.024067513990185918, 0.009835887129508681, 0.040336072880534396, 0.029006814171049385, 0.009142921339990872, 0.0688020347227012, 0.08476812677878527, 0.12356867983696923, 0.01830800560363118, 0.08067082808983904, 0.04926269408315421, 0.038169875004959684, 0.0282280704742598, 0.03836561813049259, 0.02277895793198578, 0.03546929632824275, 0.03611684363755969, 0.014342690457499797, 0.08261597129486262, 0.04626423360839967, 0.029439253567327416, 0.03018564154063502, 0.05951306159277597, 0.0686053263263837, 0.0711703802188558, 0.04381068764374622, 0.05176642646772727, 0.27946596364340476, 1.4588684660773126, 10.344929695129395, 40.580559392129224, 74.48508001142933, 80.10083936875867, 80.81182387567337, 76.48525345710017, 70.1632478160243, 60.38581448216593, 53.034688734239154, 37.02656253691643, 33.24851989746094, 25.618166500522246, 30.516765579100582, 50.80870836011825, 44.80335566305345, 42.21531698780675, 56.75027155107068, 45.9620395014363, 35.90752993860553, 25.13754083264259, 15.316436809878196, 8.66000988791066, 4.780057207230599, 2.2878148238505087, 0.649328647601989, 0.14192986151864453, 0.029646943834039475, 0.05489246356451223, 0.050119030995354544, 0.0344205257903424, 0.023931631059836478, 0.11950147308168874, 0.0773204191617908, 0.1580992350054364, 0.17500950744555843, 0.14555105188440892, 0.5771398147748363, 1.413330238672995, 0.6343580025338358, 0.7150257739328569, 1.231233590552884, 0.4601094042581897, 0.1323917910696999, 0.08793570116282472, 0.07187874341804175, 0.17107558466734427, 0.5433208327139578, 0.2562408131216803, 0.3418778291633052, 0.37261045748187654, 0.1978249541453777, 1.078984831129351, 0.8816779669254058, 0.6828449330022258, 0.586880101792274, 0.19877484188445155, 0.33275975875796815, 0.3998564664394625, 0.07759798047763687, 0.550988698678632, 0.12463968607687181, 0.060915707295099576, 0.07149944562585124, 0.096250536040433, 0.12119320972311882, 0.011744580828704903, 0.03187632481116922, 0.2473699592895085, 0.9716204890320379, 4.589188300794171, 9.166812473727811, 19.534601742221465, 29.366253998971757, 38.57628706962832, 36.796107599812174, 30.038756132125858, 52.562384374680065, 35.26013489692442, 29.890541530424553, 27.50599934208778, 34.4609990427571, 46.29207165010514, 47.973242652031686, 51.471930165444654, 62.72720275386688, 71.07890159853044, 78.84321766514933, 74.75925368647422, 68.93000756540607, 58.18877727754655, 33.51979101857832, 11.582197239322047, 1.060965707705867, 0.08028690312658587, 0.010078464082682566, 0.010287828251509177, 0.04328880939752825, 0.008527207856757507, 0.006802997227022124, 0.04959506132910329, 0.023166743978377313, 0.0387266791996456, 0.05420651226755112, 0.037270939773729736, 0.018946388586153908, 0.0382708722064572, 0.03167636245639334, 0.08569264168580694, 0.05469315046925218, 0.03761254220960602, 0.10734761073704689, 0.011104747067175565, 0.05955025516149979, 0.0561685860157013, 0.04310063522068724, 0.014870387141502675, 0.05300565412448299, 0.07846041161927485, 0.08797494018630636, 0.04699989252032773, 0.043890935353814595, 0.010132490518322636, 0.011277716313939423, 0.02257158176132268, 0.0307701627964214, 0.02460443245757732, 0.04569692251783225, 0.017638720549462784, 0.06908619205557531, 0.03661022724343404, 0.02654768725586755, 0.08788120932877065, 0.012739071164340263, 0.04693306667069274, 0.03658850865078069, 0.08462734280094024, 0.18133151014485668, 0.171683260930642, 0.11447589799401262, 0.1752674186061467, 0.11731119706265389, 0.07553173409354302, 0.1241457891920882, 0.11549044355389573, 0.12317455058256466, 0.09497144499853735, 0.1424490239831709, 0.20211504652134835, 0.1158564573814792, 0.16138608927928633, 0.14883216049882675, 0.15026155799146623, 0.14561918774439445, 0.16990360803902152, 0.1978630593587314, 0.20742489385508722, 0.1620612732104717, 0.15777740146844618, 0.11849235142430953, 0.14656475474757535, 0.10864327226074473, 0.06940657768638865, 0.14860398887145906, 0.2101436939330832, 0.11662693498956582, 0.16442894454925291, 0.1902618736869866, 0.12149856470885778, 0.12266738505493249, 0.15732556281070556, 0.12445135102156671, 0.15886886225592706, 0.11241320625788744, 0.15179748767085616, 0.822399860668567, 2.8229418252744987, 15.606452938049072, 51.52272878154632, 86.63044821831488, 90.52046668144965, 90.26512822797223, 86.34948884287189, 81.89354296653502, 69.89825248718262, 58.35365410773986, 42.014475945503484, 31.851414788153868, 26.170418570118567, 28.63840133913102, 47.7823644299661, 56.29141307646229, 65.67596612438079, 84.40435409545898, 71.70637099973618, 55.6430374422381, 38.35504970242901, 22.207255748010454, 12.131135886715306, 6.416307755054967, 3.187669299302563, 1.4372922432038093, 0.39937603738038774, 0.43241639831854456, 0.23245562168378986, 0.12801637182072287, 0.20986113006309157, 0.13525709780233522, 0.22166869002244166, 0.14914035767076478, 0.28294240935675563, 0.3263037826024717, 0.32320756164769976, 0.3689339096027036, 0.8065425760803685, 0.8281049480842007, 0.6930933508180803, 1.831598310701309, 1.2509618867789547, 0.5138290829716191, 0.3133436893263171, 0.21797444551221787, 0.42173507953843764, 0.7774802032978304, 0.9533320703814108, 0.531244590397804, 0.3464281462853955, 0.751076891056953, 2.6408874652078076, 1.3235665521314068, 0.8684138593173797, 0.6891253218054773, 0.2086710737597558, 0.2184770757993383, 0.2093717684188197, 0.14388124067937175, 0.6681992317880354, 0.43405466202285986, 0.16985637105761037, 0.1752557127826637, 0.15869704405626944, 0.30227840727856087, 0.1329616225895382, 0.15710995502529607, 0.6136177960903414, 1.5899097054235398, 7.390729919556649, 11.355236153448782, 31.09723714090163, 45.85089129786338, 60.21713687527565, 52.51935205151958, 53.999976188905784, 68.74084734147596, 35.53170804054507, 28.524493748141875, 26.084808918737597, 31.964212348384244, 47.15312603981265, 56.38234538416709, 62.69299576359411, 73.54723345848822, 80.03368839140862, 91.74771355044459, 86.48908599730461, 78.64616563243251, 66.17657430710332, 42.57432760730867, 15.913964798373563, 1.9509342168608022, 0.20513966889871707, 0.11148211831647543, 0.14672498969781786, 0.12838211751753284, 0.2234108505710479, 0.15144370826742343, 0.13122981954966823, 0.12287323288018666, 0.14217971343426936, 0.16438380664875432, 0.15385529176602442, 0.11817661594719657, 0.14930970906730623, 0.09206442477842493, 0.14632187423206147, 0.20188880543554985, 0.1615788370010353, 0.229459896142925, 0.11850207308006865, 0.13793143413720593, 0.17552100903084203, 0.14359746639045978, 0.1311256009484491, 0.11176772355552643, 0.23135792494060534, 0.16649782627580628, 0.0965879518058031, 0.1392442636912869, 0.23177423244041784, 0.11019296087925473, 0.23279219475244325, 0.14973815139983931, 0.116201373147628, 0.1686136232268426, 0.11054456459298251, 0.20446682919658002, 0.10172676234956711, 0.10679525368276144, 0.20514242681524447, 0.13077439560044196, 0.05890734651456437, 0.18070590742413076, 0.15408075144214017], [0.037669129294133, 0.002855085922713061, 0.027359267396311608, 0.10395450006809928, 0.05111121061828829, 0.03718452888631052, 0.05134698566830447, 0.045613840282444036, 0.029877283490232887, 0.007476823746166643, 0.03583282420051194, 0.03237172322828443, 0.04454629675995919, 0.030923757679580204, 0.023898656720355637, 0.08440743726227554, 0.03639601373804673, 0.0922178875114168, 0.03228152020564003, 0.05060272358898675, 0.010957454214803876, 0.032395494936574856, 0.02132483878202977, 0.02341658057224366, 0.02211389019184055, 0.017322736093774438, 0.006406141178412063, 0.0008662856412082611, 0.031799850084127924, 0.016481560061595613, 0.032492730646364154, 0.07810436459558626, 0.0605371832517126, 0.04630626502236532, 0.0766295840543124, 0.1335349627920697, 0.06602667437325563, 1.0755400095255145, 8.335184685645565, 30.748626685911614, 50.07178521925404, 64.24212801840999, 66.06778344800396, 72.17841256049373, 69.75262272742488, 56.16765445278537, 43.814565366314305, 24.201967293216338, 13.9207447344257, 19.753020886451967, 17.904419591349942, 22.75035300562459, 40.46440232184626, 38.00943397706555, 35.669496982328354, 29.391547403027936, 25.400724026464648, 12.729947470849561, 4.484111435951726, 1.2762616646866645, 0.6406721604927894, 0.20888723312847077, 0.09095193487742255, 0.022451288720232346, 0.07266745391872621, 0.05840183573684866, 0.03646161767744249, 0.06105671343844264, 0.10760915315439624, 0.027450320776551965, 0.06012468320888378, 0.05002689360070133, 0.07369926710042261, 0.09877671863162711, 0.08227709230155715, 0.24452480066928173, 0.5481164818329196, 0.5708404882780967, 1.0179292170270797, 1.1078048136926468, 0.32059933870069446, 0.08991572435104078, 0.011627381825218759, 0.061189124075275284, 0.10575782507658006, 0.06774188394868566, 0.1992846887198187, 0.07218387623828265, 0.019762191786280563, 0.16878721875048455, 1.373439488872405, 0.4808532572802036, 0.8817412151444344, 0.5037578459708921, 0.6076092765696588, 0.19446375869935562, 1.1991585310428374, 0.07571767895452439, 0.15670339216388043, 0.03576040973946933, 0.09918832235158452, 0.07871847599744797, 0.030473391825874007, 0.1605535202449368, 0.051434863614098686, 0.11761268330437523, 0.01926946127036166, 0.06798048203270282, 0.08110039657162083, 0.1533931262430645, 0.5561448381312433, 2.704463202145792, 7.562426770887068, 18.49563256386788, 37.767011888565555, 66.51091714059153, 59.374423488493896, 53.470589576228974, 45.95865449597759, 32.824062570448845, 17.99522638320923, 24.190914054070753, 29.693883695910056, 59.085395797606445, 67.65701017072125, 56.90930404970723, 58.32254186753304, 57.9832293910365, 69.78072258733934, 73.04846486737652, 67.04247674634381, 44.988385631192116, 14.991640044796853, 3.082049676487523, 0.30170123663640797, 0.08548571367657955, 0.10816096628625547, 0.03331123813686352, 0.048907796191352035, 0.050273550929681915, 0.05142484318404909, 0.03882009213069274, 0.03807996692616613, 0.015922291936623235, 0.06723289513179372, 0.05463959326246574, 0.03728290223666737, 0.04655507505841313, 0.021233810299646952, 0.0157652554034646, 0.06619289247018677, 0.02396230905076429, 0.02407984992098664, 0.07182661113479445, 0.005274324315494948, 0.014156798265063235, 0.007708488255664106, 0.014282327517116023, 0.04676903958522505, 0.01697554504649053, 0.032760440071503964, 0.010875591016825168, 0.03331570442946207, 0.026663272686663176, 0.03165306955305559, 0.010909450187858556, 0.03020176194578169, 0.04217482562507353, 0.03302574015012191, 0.040960947817732254, 0.04398005053160652, 0.0350800930191913, 0.017333401952900233, 0.05043649400073675, 0.06262350880030183, 0.04370643839901013, 0.05631537612287268, 0.06227057975446505, 0.03715035370400837, 0.012677837756552525, 0.02185050150259368, 0.007895549689795101, 0.03348688294570293, 0.033736095177910985, 0.061672728568796194, 0.020839861075904582, 0.047810045822012814, 0.055831921016497005, 0.06900898571456633, 0.038552995575892354, 0.024114549873516928, 0.05896967542808383, 0.07688470665485629, 0.08154873420754749, 0.04321123150387599, 0.05949916858826915, 0.04444085241806123, 0.030882049937762564, 0.03860346544834395, 0.03356160333139762, 0.0485916891615958, 0.032177477804643494, 0.007904998905536148, 0.060884205759653164, 0.08937414615384995, 0.045718024409706556, 0.05349510769930579, 0.0764241958818128, 0.0857600344405059, 0.05397553292794093, 0.04172865601797258, 0.13217327215017813, 0.04996227025384865, 1.349792254547919, 9.79019574580654, 37.31497441568683, 59.62256831507529, 76.83766272760208, 74.70178311870944, 79.16948041608258, 77.99038456332299, 67.13898274206346, 57.23912831275695, 34.42048095887707, 29.048687142710534, 32.86954833615211, 24.204962022842903, 24.208452932296264, 33.79253695088048, 39.91614910864061, 43.53324513281546, 32.34142668785588, 22.02660510616918, 11.906391920581942, 3.991140353102838, 1.4483728163665341, 0.6081704819394697, 0.12099834759869885, 0.0776187644430226, 0.025278888605234605, 0.050845259364934704, 0.10267385386771734, 0.030444395397939993, 0.06744225930062032, 0.3531015381938027, 0.39847088917609186, 0.3433724054165425, 0.3183846704421505, 0.5439436315528808, 0.3263320052816022, 0.4469787185230563, 0.6943683662722189, 2.47976434326941, 2.525222897529602, 2.5332907226777848, 1.8649451987397287, 1.0594937157246376, 0.5225626078824843, 0.16768898574575303, 0.06968265279166161, 0.1108627438905739, 0.09411488975127859, 0.48952083734254687, 0.4811863523096808, 0.2519416809082031, 0.8388048674791091, 2.279797254070159, 1.420732118910359, 0.3874056377718526, 1.7838584078896431, 1.5107459791245, 1.0063633731295987, 2.784449645588475, 1.8851685716259865, 0.4451257969823576, 0.7044967227885801, 0.6314192892562959, 0.2777092627459957, 0.09786462200985802, 0.45660571645825143, 0.12783832532624084, 0.10688945185393096, 0.13828764970023788, 0.027768530717660344, 0.15014506666170013, 0.19735420843766582, 0.4518571357813574, 1.8749821762884817, 6.28394982507152, 18.214998745149185, 32.08886723364554, 58.119468996601725, 59.32482904003513, 46.373758931313795, 36.581989334475615, 24.471034042296875, 20.381565017084924, 32.7097725483679, 39.53997027489447, 65.9503790640062, 75.79111945244574, 65.23843357639929, 68.5095843961162, 67.65799076326432, 82.10363295770462, 86.55080841433617, 80.56286319609612, 56.46546825285881, 21.658937815696966, 4.692678566901915, 0.41837014558334507, 0.07974497252894987, 0.04943685268142051, 0.03919868895243253, 0.04305206907672748, 0.09539673870970165, 0.044212339881567225, 0.0385099605867459, 0.007941299981828178, 0.01885855085997572, 0.01704662268410527, 0.04844640058675601, 0.04421797062781069, 0.08645551970168468, 0.03158348195645357, 0.05523133489693846, 0.015822331826653213, 0.023422914204157652, 0.04977088233816528, 0.046570358512502526, 0.043955305891652266, 0.032581045262275204, 0.022823444657748746, 0.02375060065288938, 0.059507610877194715, 0.044313187695919506, 0.04321457164722585, 0.04109373000720817, 0.007004107756074519, 0.04008550467270036, 0.02513561484163567, 0.1077308462211682, 0.01865361467935145, 0.015752094012925464, 0.09214433540980663, 0.050312533313708926, 0.016185367487431053, 0.06638395479850231, 0.07126421832870092, 0.04690890808800056, 0.032806029963877895, 0.056415932823813734, 0.11724464700467165, 0.08652273625616105, 0.1968542594582804, 0.20008540381827664, 0.20132416799183817, 0.16417622746479127, 0.16423691695015277, 0.18375950324679577, 0.1260661800962783, 0.08664791502298848, 0.19104190441148897, 0.11289903623682838, 0.17910567232437674, 0.11606050490011131, 0.08835802245284281, 0.12374154757708312, 0.12392489540000116, 0.2438922878354788, 0.20131351936969066, 0.12100535730320601, 0.12767617515618765, 0.2097428001223072, 0.10579873417173663, 0.09072154925595369, 0.1889350553674083, 0.11078555287132341, 0.10161594773131995, 0.14655058212097616, 0.20503863722326296, 0.16796759660205535, 0.19533726747237867, 0.17335353178843377, 0.17947308809286167, 0.1407398818241012, 0.1490371809491227, 0.33174548898973777, 0.15947980205378226, 2.2947574190555082, 14.077255149041454, 48.70816146173785, 73.20655991954189, 88.73885554652061, 84.3098641980079, 89.1172230628229, 87.93499715866582, 74.98919087071573, 63.906271150035245, 38.62362223286783, 24.762619118536673, 33.153269060196415, 28.635663524750743, 37.27059671955724, 56.605077174402055, 54.6574007311175, 50.0591669544097, 39.23718683181271, 32.915381231615626, 17.061612067684052, 6.464327371889546, 2.0208769411809984, 1.230816225851736, 0.39136815095140093, 0.3307632416967423, 0.2198389656240902, 0.2356782318243096, 0.29587755881009564, 0.1764507639792658, 0.29286294154101805, 0.3615450222165354, 0.34398549026058567, 0.3045252205864076, 0.22911547833392698, 0.4198808403265092, 0.313139358355153, 0.5034601442035168, 0.5722114179403551, 2.3096479619702985, 3.077607347119239, 1.3878510123299015, 4.211966116582194, 1.971215812429305, 0.788992359753578, 0.5224788897941189, 0.16757186622388903, 0.3878283038014366, 0.13226172466191555, 0.7529566256750015, 0.4725673728652539, 0.2909602549287581, 0.7048551906501094, 4.362075713373, 2.5297566671525282, 2.458460234826611, 4.183835368002615, 2.9260057787741385, 1.198405068247549, 3.959644210915412, 1.5805765481725818, 0.5374024051331705, 0.201516532669625, 0.18540754223302489, 0.4426815474946653, 0.13400515691647608, 0.5144154160253464, 0.2645641132708519, 0.3922306740235898, 0.2406612966930674, 0.25562218180106533, 0.40499728413358815, 0.5166895939938484, 1.536785614105963, 4.000328505231488, 10.499677984945237, 27.18691452856987, 49.54687795331402, 81.4080790550478, 71.63911804076164, 69.72623302090552, 62.97452780508227, 47.76446273249965, 28.248215721499538, 35.627813954507154, 43.249496952179946, 75.40810000511908, 85.44107575570384, 78.92119438417497, 77.23984687559067, 80.05768545212285, 92.9727089789606, 96.73793331269296, 90.93881883928853, 66.38173780133648, 29.427429245364284, 7.174742154536709, 0.7659077404006835, 0.2380119807898037, 0.1138534821990517, 0.14372092912033682, 0.2110856143577445, 0.14706295704649341, 0.16362498123799601, 0.2767802738854962, 0.13864755780706484, 0.07687521482547445, 0.19749103174094232, 0.16453294864585324, 0.134982654464341, 0.25617430136809427, 0.20845272337957738, 0.146922349268871, 0.20585737070969998, 0.16486340833287086, 0.14758587334184878, 0.09374394997834198, 0.11667894469874522, 0.1441891007726231, 0.20900796858533738, 0.1274202941285987, 0.18439970760335847, 0.13017718409818987, 0.10251233955064129, 0.13596373730369155, 0.09180901106446983, 0.09950894546965439, 0.07357764298156386, 0.17209844994208506, 0.19000702687809545, 0.13762136771073266, 0.17326343984853837, 0.10776121394648668, 0.19620981097461718, 0.12784315934104304, 0.12470269680864389, 0.16188298922873315, 0.17647383854754511, 0.10655362955144337], [0.032823351211845875, 0.0466312931459998, 0.05038618883718887, 0.024670438593133323, 0.035151327704830516, 0.016082615944586934, 0.05586690442155927, 0.02825500804089731, 0.03658583500392495, 0.07379704290219853, 0.029819154653758295, 0.06108153468718933, 0.01571497992582379, 0.049550716329606316, 0.03662216289329433, 0.015259166229366055, 0.029009160315317493, 0.02035126168911736, 0.06153659091421193, 0.020954157563767607, 0.02905538606066858, 0.04866431046637797, 0.054655072068975824, 0.06718516785411105, 0.04267203200969004, 0.010782053596490334, 0.025095332023357193, 0.016473588916743477, 0.0201753391734054, 0.029128522559579824, 0.03031614844897582, 0.0689586537379411, 0.05763272176526728, 0.053448981545384855, 0.062004919614522695, 0.10329962512778659, 2.2862860800758487, 12.260905542681295, 36.55180669599964, 65.43508160498835, 66.17381295850201, 63.33028677971133, 58.778325203926336, 57.69367610254596, 55.798406447133715, 34.27205062681629, 22.794873868265462, 23.344058644387033, 22.971633518895796, 18.417181238051384, 31.34395226355522, 74.08157010232249, 63.96047046107631, 44.06396927372102, 25.683093493984593, 12.464667770170397, 3.956157223832223, 0.5354611996200778, 0.15316112417607539, 0.14045223113029234, 0.03845750654657041, 0.048302173043691346, 0.031985432968565056, 0.007004336146036945, 0.04134350148360095, 0.09756089113051854, 0.33046529478123116, 0.03994507309530051, 0.0374668016428909, 0.13225585642841556, 0.15912121161818504, 0.38322751680689476, 0.18150513631201562, 0.4048449552107242, 0.25662013389650856, 0.23261024887042664, 2.422079025737701, 2.6784784803467416, 1.7658592640392243, 1.5433908854761433, 1.6489975154399874, 0.2743998854871719, 0.08606113763826509, 0.009560263058501146, 0.1658027853456236, 0.08855247855066292, 0.21530325013783672, 0.11707276751798008, 0.34531235454543946, 0.7795806938121397, 0.47881007014263066, 0.5954028605934113, 0.4407794431092278, 1.0905054451957827, 1.2433396183675336, 0.49378577139108415, 1.924430393884259, 2.1892182048290008, 0.4354038041445517, 2.7606548320862556, 1.4787526765177328, 0.07750094012026826, 0.11640497633526403, 0.029189428464779933, 0.18011911471764888, 0.11494204717417879, 0.14285100563879938, 0.11622686089286882, 0.07979808540474023, 0.05204678400449696, 0.07029975959730726, 0.061357092683113394, 0.03406199281133952, 0.41617821481439377, 2.5143500874119424, 4.572206889429401, 20.761315168872958, 40.388461312940045, 65.89025697400494, 52.4830073695029, 70.341017476974, 26.193452688955492, 14.410816450272838, 23.80902424935372, 32.395759359482796, 33.81845989534932, 46.84585148288358, 50.14035609460647, 49.035087093230224, 66.90790022573164, 68.46633634259625, 78.86415527712914, 69.07479793794694, 38.4268565331736, 13.081325157996147, 0.1905017511378373, 0.07953714819685107, 0.0302979615216534, 0.03849578796014671, 0.015417163245259755, 0.024372801943231496, 0.0031618038267498057, 0.05805945189128961, 0.05556087910888657, 0.1191606482250556, 0.014813900606015758, 0.03578327363356948, 0.09200885276039762, 0.02087334294863526, 0.02903689844383588, 0.04496670283016659, 0.040376928349536274, 0.05157074462922831, 0.10069127194583417, 0.056164361040798895, 0.05087797131930148, 0.04645952857249687, 0.011968084107784015, 0.015665898587734952, 0.051211219566363486, 0.016473238431518118, 0.08938329324366585, 0.06314414598408245, 0.029215251373487617, 0.02383985947216711, 0.019656787663998625, 0.02130378860109035, 0.048144205713704716, 0.030955364552116206, 0.04685138637620596, 0.10195117248522659, 0.06736747379745207, 0.031216838021552375, 0.04674317645690134, 0.006815227820733262, 0.08358341776916096, 0.050011943394858996, 0.008591239400688679, 0.15475374436186207, 0.05057314110379066, 0.09994321773129125, 0.039412638157485955, 0.16751082433808237, 0.047317068242738326, 0.0394955288708931, 0.017610932625229322, 0.06430646224368004, 0.04315808032368941, 0.020139145349422773, 0.017840785815590815, 0.019706851509850354, 0.02478246554552067, 0.022652969027178425, 0.02068468039074252, 0.023551955969343265, 0.023433813720100352, 0.016688241007467432, 0.007938840839591238, 0.041702616689426285, 0.03419622290699232, 0.08234722765102502, 0.05427903781134275, 0.029104628277221517, 0.022147791497709773, 0.03280165177139063, 0.022150124235439207, 0.08119898442659648, 0.11570284909178173, 0.08780099226221924, 0.06417724619349165, 0.0376225434874575, 0.03172256713432651, 2.585044681064544, 15.521356136568132, 43.97513935642858, 76.25464162518902, 74.87311224783622, 72.18776349098452, 67.46054649353027, 68.49017650850358, 66.81277490431263, 48.868982561172984, 37.14347270227248, 34.16226348569317, 26.248299191074988, 19.546988587225638, 30.816650390625004, 57.40265976998114, 51.95504065482847, 43.774561112926854, 21.314687075153476, 8.702389136437448, 2.828512816659866, 0.6297402083873749, 0.06963390661703964, 0.056348137872954535, 0.06605858959618115, 0.0313762360207376, 0.15503972498399599, 0.07993172944313096, 0.14944170601665974, 0.37759477873483016, 0.5568862886678788, 0.6094305433573262, 0.6136105642203362, 0.7526041639427986, 1.2398784944126684, 1.3825517676530348, 1.2607212340639484, 1.2696391103729125, 1.8053245592501856, 1.7506016117911187, 6.290285923788625, 6.092637690805621, 7.122250545409418, 3.8250951468944554, 1.5577973833968564, 0.20478736038409895, 0.10520316209764251, 0.1148257320446353, 0.11185249118434806, 0.13365799651270913, 1.5483950943716112, 1.3094337621042806, 0.7063676320737409, 2.1548722155632514, 2.3472919291065586, 2.592039002526191, 3.7153430619547447, 4.893081284338429, 3.9403422272974447, 3.4575359667501147, 6.450651047691223, 6.5865538197179, 1.2862101437584048, 4.6359944343566895, 5.0604336204067355, 0.20702171710229691, 1.22897835027787, 0.05194823445391752, 0.4021027588075207, 0.07273887629590689, 0.2872896518918776, 0.2334547229111195, 0.05419035547322804, 0.12718468378748626, 0.1445609138857934, 0.056553269405999494, 0.045352359152128624, 0.19757085810265235, 2.2453279552921175, 5.050668879862755, 17.562324193216142, 34.776592946821644, 45.84119127642724, 44.84994557596023, 48.5962954644234, 33.968102239793346, 27.110077258079286, 41.92762290277789, 49.441244602203376, 44.32909011840821, 52.65082597732545, 58.88368791149509, 57.08214721372051, 74.42663669586182, 76.2982113130631, 89.37092981030865, 83.00951219374134, 52.361711994294204, 18.732294651769823, 0.5066899708922833, 0.13627567298470006, 0.012607435233921055, 0.020503226720217257, 0.06057114775983557, 0.062116917838612874, 0.07138847779001921, 0.01090101268698251, 0.020939730212933595, 0.06066702366355927, 0.07821312609819636, 0.03917599742811534, 0.04511810478664214, 0.01862610637721035, 0.046331706802330674, 0.060548180443865646, 0.0730615831731308, 0.1384675424666174, 0.0986124923632991, 0.03198289721753569, 0.05666011185835927, 0.043444371211432645, 0.04120311204103693, 0.014752839568010984, 0.06489447302996151, 0.05429040655613907, 0.08199760810502114, 0.03243815454263841, 0.0119581843365825, 0.024179358996691245, 0.049203590399795966, 0.015900038997642696, 0.07162031131766497, 0.042546324642194856, 0.02575381715301304, 0.07040485153876005, 0.054416631032983144, 0.05840591132460583, 0.07358737229820221, 0.007038939858771741, 0.0077969355005470505, 0.1893537837050615, 0.18033956417873984, 0.2075694086811235, 0.12028374844380926, 0.18256840506388297, 0.1371794728742492, 0.23103624462119995, 0.19668429519139952, 0.1048141656323306, 0.2654382502359729, 0.1283444566351752, 0.246239765096576, 0.15661582831413517, 0.07436941017306621, 0.12125855702305995, 0.09542782655766896, 0.11506114320288743, 0.10410410937883201, 0.09215047177408012, 0.1391917713467152, 0.12056854162966052, 0.12324310013002927, 0.11784098516669005, 0.15598788136436095, 0.18929409013400156, 0.1736650231384462, 0.20804724836301422, 0.10423590714532523, 0.09630125872189961, 0.1663627190094802, 0.16133322921251098, 0.31449076809710075, 0.17451484447285054, 0.18658368637965572, 0.1681746242027129, 0.2499083456613364, 4.150955119440633, 21.70687702394301, 56.09506314800632, 86.73643066037087, 83.89851739329677, 81.43026398074242, 78.35223890119984, 76.87272871694258, 71.86732938212734, 49.12173617270685, 35.82706643689063, 36.62172686669135, 31.305471850979714, 28.629122972488407, 47.08413939322195, 92.57141913137129, 82.21459680987944, 57.52623404225996, 32.26795481097314, 16.8972804469447, 5.004511408267483, 1.0698819905519485, 0.3842906936282112, 0.4176931996499339, 0.21614256074591992, 0.25938125267144174, 0.28030207200396445, 0.2637628159455715, 0.20123597594999498, 0.598645189837102, 1.1446822026083547, 0.6392285444082753, 0.34470355979377226, 0.38550325759476234, 0.7717255346717373, 1.545599302457225, 0.5942066602649227, 1.2426995365850388, 1.2601773729247432, 1.3539337871536132, 6.881849458140712, 10.30166889390638, 6.991407140608757, 5.180960701357934, 3.9165954628298363, 1.2707735333711871, 0.3012495205527352, 0.3743479142506277, 0.32921540701100904, 0.6421975947676167, 1.8822206652933553, 0.7513171975170413, 1.1314480030728926, 4.447384322843244, 4.544205579065508, 3.5224183432517515, 3.6233715713024144, 6.413632208301175, 6.936972977653627, 2.6455180683443626, 3.656432494040459, 3.837834760066002, 0.5277390333433305, 6.276833664986396, 2.915817177103412, 0.15364855527877808, 0.6501653381893713, 0.15643247283033787, 0.5448522118310775, 0.1542598168335615, 0.37447814919775535, 0.32213798033133634, 0.14425519883873003, 0.31458119711568283, 0.3029872224696221, 0.20842762633917794, 0.23648354345031325, 0.7291944781618734, 3.5932558582675074, 6.408647856404705, 29.504886250342096, 52.55702641702468, 84.85731724769839, 70.88158284464191, 93.29248412962883, 37.92864884099653, 25.35855462474208, 34.28380204785255, 47.968645634189734, 49.81426200559063, 64.65309043084422, 67.66776530973374, 65.95947111806562, 87.96886290273359, 88.1371404278663, 100.1037819154801, 93.36598934665804, 64.16068784652218, 22.36771402820464, 1.1023316364134512, 0.18693608682482474, 0.13724725633378954, 0.14685076601322622, 0.13789096937304543, 0.11426903127181916, 0.2332698658949906, 0.15851921972728547, 0.18914482556283477, 0.192874800413847, 0.18177881356208556, 0.13658779252681041, 0.12701528642566937, 0.060789973114527045, 0.16382281578356223, 0.1119128818954191, 0.11252814242916723, 0.25018360105253035, 0.28996850814550157, 0.10554518971231677, 0.19104979511710907, 0.15125653766576322, 0.11456083416217759, 0.0775589176543778, 0.19377034187557238, 0.15175035794175443, 0.16419118150107323, 0.18261423244351344, 0.08411968697703655, 0.1370627670398643, 0.13105231697761244, 0.1251750436401175, 0.1815195081214751, 0.16440718765220336, 0.16790427177423434, 0.24673003072459854, 0.10846302709392003, 0.16261441933531917, 0.16620539519334995, 0.12566724747058847, 0.23320186793083147], [0.06209141094117396, 0.02857345738448203, 0.012775441188545478, 0.02363554573798132, 0.036584888885338465, 0.020625507759471095, 0.07080668763768289, 0.011636459967121484, 0.028706990340123736, 0.12158576083639938, 0.037110463505791086, 0.04788908694360045, 0.006381040307573013, 0.07810496980504644, 0.029585289077893383, 0.04502329374513319, 0.01914786779501986, 0.07209576846611115, 0.09646553095550307, 0.044295621299815756, 0.04872950837917386, 0.07990882341419497, 0.05650195300639157, 0.05742360274457643, 0.03487240658291886, 0.04996001029447202, 0.024528076474164284, 0.0507242021511399, 0.036547063294077115, 0.015750145276768074, 0.017344098455543, 0.08858728192506299, 0.01654623128894356, 0.14600739513914432, 0.05203924186888242, 1.2854754347955029, 16.360207949915242, 49.26035665696668, 64.79219728900541, 61.38416359501501, 73.46910768939604, 56.14595197862195, 61.697204036097375, 33.238149150725334, 18.320383025753884, 20.274794178624308, 14.746471316583696, 23.753442302826915, 39.25975614978422, 42.82839521285027, 49.46466507450227, 63.239299558824115, 35.97848561502273, 12.424168317548691, 3.6489245872343745, 0.8140473572477218, 0.017588030426732956, 0.08047454104187989, 0.024409784837776137, 0.10858552455301247, 0.10663963824270234, 0.04536091252380321, 0.11373522120618051, 0.09960611606197012, 0.04578459745032653, 0.07044288014332134, 0.23909930470249346, 0.08728237372011909, 1.048848280502904, 1.2783274054527283, 1.1824382024426614, 2.74722439146811, 1.403314343863918, 0.9175994006856796, 1.266086913885609, 2.013712854635331, 4.054910737660624, 3.733360714489414, 6.61298422082778, 1.9916919330435416, 0.8276386150429327, 0.49608342229358615, 0.0175382653551717, 0.05466282104832992, 0.15695837686859793, 0.509536293966155, 0.541147594490359, 0.7660542164118059, 0.8091654772720029, 1.9026692067423177, 1.0624109785402975, 1.654904727493563, 0.23280509567308813, 1.0557360850995587, 1.0105169792809794, 0.9536978926870131, 4.182031568019621, 4.544805211405601, 1.475100337016967, 8.279436038386438, 11.296981111649545, 0.895828775340511, 0.9531920907958862, 0.6738134305323324, 0.4285256522557428, 0.20755751899653868, 0.29239967285144713, 0.05623907376561434, 0.0993470864130124, 0.07428365429082225, 0.046737488254063556, 0.07377080439079194, 0.03584701597930924, 0.13746868638742354, 0.0321054597941017, 0.4038559357004781, 1.0492913857583077, 6.9596280974726525, 22.456947949624833, 38.87044914307133, 48.92307989058956, 55.85986998773391, 32.25286937529041, 19.736158617081184, 19.648589741799142, 24.651557207107547, 25.285596578351914, 27.54101041824587, 39.387586193699995, 47.59296494145548, 54.272533847439675, 65.51554902907341, 69.92128464483446, 75.5975426397016, 56.06408426838537, 19.57274679214724, 1.9620352598928639, 0.039517075093763496, 0.03859511125952967, 0.01367982809296659, 0.08831265472596692, 0.02573244904558505, 0.012787769458466961, 0.011329066229894037, 0.06870800509087502, 0.09443679989706125, 0.036399786721073815, 0.05118064499730545, 0.011221951816321142, 0.017010313946934, 0.014354843484808602, 0.05692556132412246, 0.0620678116026665, 0.0649056196092598, 0.0480192989080904, 0.06526070136216379, 0.030218464577750816, 0.05971512494368419, 0.013632447470069654, 0.016328438237730055, 0.021471293725734277, 0.016858327848416184, 0.024039952061890114, 0.024011376982314453, 0.07417823293156202, 0.029999022522280296, 0.060143287654124925, 0.03645806685991345, 0.0077757373688772564, 0.03313647049869741, 0.04404975687183681, 0.030454502012881062, 0.029195585896471338, 0.021394954979299538, 0.05914450435328388, 0.04827643248943552, 0.06571555840632608, 0.056771447416394956, 0.07841219404532064, 0.03446716905361222, 0.04850725095058161, 0.05317783621590465, 0.04928273111281376, 0.018371451090300278, 0.035637946754333474, 0.05456386547115061, 0.0677792767002698, 0.012526758514615077, 0.018165645399881948, 0.09775819707541697, 0.016589118806164593, 0.01289904181424889, 0.02194516890261683, 0.04436262718011295, 0.07705771229079655, 0.07674134096070644, 0.0681947261816071, 0.077503613767124, 0.08111515142504247, 0.03608874353249708, 0.018595535638591936, 0.014762641663002151, 0.02319276223950569, 0.08429934225615957, 0.0361115844439595, 0.04407110008140726, 0.03969191167984278, 0.01601446763567266, 0.04154569889989592, 0.16008775410873277, 0.08280225323453065, 2.0179785547717928, 21.49989551113498, 57.55648336102886, 74.6090582878359, 71.08358490851619, 83.4178073944584, 64.67065872684603, 66.99188601586127, 44.95814023479339, 29.08475333644498, 30.765082989969564, 26.874360461388868, 33.15264540333902, 38.82297669687579, 40.998895860487416, 42.72591936972834, 63.7276856360897, 35.59058281683153, 10.472956838146334, 2.5752387556337544, 0.6165949363381632, 0.08715580067326946, 0.10334151481548626, 0.11112884453107273, 0.053040760103613145, 0.2052039130320472, 0.037795127775039405, 0.5693298854654836, 0.3914902653665312, 0.6885833605643242, 1.0801757607729205, 1.2512570451344214, 1.2014946702026552, 2.722294787245412, 3.181813936079702, 3.607922826082476, 7.285301021991238, 3.5852088707108654, 3.6300513677058683, 4.857984406332816, 7.270414646594756, 8.186533229966319, 7.89134398583443, 10.278753426767166, 7.104889644730476, 3.1663490110828034, 1.1327167672495688, 0.06608247621766021, 0.14034163867754323, 0.22386190781910575, 0.30632325958821083, 0.40063907121939046, 1.3210916591267432, 0.9951879889253648, 2.1053118426953596, 2.1335882092675855, 3.2233170251692496, 3.2018604345860022, 4.649592801447838, 4.058636744176188, 6.235370289894843, 10.662896633148195, 11.04040515038275, 4.720825985554726, 11.406246577539752, 10.856100820725965, 2.9471946675931258, 2.139146698098029, 1.5656230021868984, 0.7959881521040394, 1.0116467444646744, 0.7781296007094846, 0.4441771656274796, 0.4177005847375239, 0.2273228172693522, 0.30120784536965434, 0.11387782847328533, 0.15291914764431216, 0.04557928205617974, 0.06275482393140275, 0.22201175951669294, 1.1308488610290712, 5.3262041076537106, 20.893903047807758, 36.652152692118, 49.55806455304546, 34.765449493162095, 22.263435855988536, 21.730244544244584, 28.988268913761264, 36.214196528157885, 43.087871766859486, 41.72764478191253, 45.67134088085544, 60.166444163168634, 62.535583203838726, 75.42761771909653, 78.04566644853162, 87.58767127990724, 68.82099705357706, 28.184940045879735, 4.751545498448034, 0.09659017346078351, 0.022514433517391165, 0.04463013742239245, 0.05466815302028291, 0.03308512345557252, 0.030908100757627722, 0.07199899623951606, 0.1110503588232302, 0.0417867178217538, 0.0312369056947289, 0.07300449430101341, 0.02356218707357203, 0.03812225114914679, 0.012249980523671595, 0.020221176129134915, 0.07774255659070708, 0.1235986338748086, 0.022606915651610302, 0.006186830315498576, 0.03182921040382597, 0.040370232741078066, 0.062262826944671334, 0.005386284713993871, 0.03194578408804392, 0.10407246994755923, 0.05214236879480943, 0.008943996076742488, 0.0728339324855516, 0.07499773250592333, 0.01505788716097032, 0.04643796319742838, 0.020582490007302934, 0.013795399159613638, 0.03134012455120683, 0.015269736327501315, 0.07494350114176351, 0.04439138995123006, 0.015351372571932453, 0.02253569245728995, 0.18146614243666973, 0.14895926980722338, 0.11087064991795248, 0.12974045269431608, 0.14924025553609097, 0.23357676071745737, 0.13197287887094483, 0.1401412607200684, 0.16259750411395105, 0.23695747608379011, 0.23922518827021125, 0.10941804762208655, 0.1603546284980351, 0.2106559003192571, 0.1138729714758454, 0.14046212898627405, 0.1610645928209828, 0.16875438422204989, 0.225179226648423, 0.18222872167825702, 0.11192724604399935, 0.16889059465498696, 0.19173935085775393, 0.13478072900925914, 0.12167887882359567, 0.12590212236729362, 0.10585815195114383, 0.17463130515909966, 0.13889881932447035, 0.08476688571634793, 0.20433360650654764, 0.1737374337690492, 0.10053228571890824, 0.3405075736584202, 0.18441182711432058, 3.3600680097456905, 29.1821300983429, 70.55010334137948, 86.52855288597846, 81.01631272223689, 93.82493019104005, 73.91031157585883, 76.82129075450283, 46.9792434477037, 28.73869046088188, 30.282064676284794, 24.6681978625636, 35.79244759774978, 53.1090098042642, 62.75184700565954, 64.10417825944963, 79.33935042350524, 45.0527125020181, 16.367469237696742, 4.650179195788599, 1.5976324845706265, 0.2178928724700405, 0.23767346185782265, 0.19931735470891002, 0.37449123397950207, 0.3626990877091885, 0.29423623075408323, 0.3651201706980506, 0.43729821700722943, 0.42870718445028033, 0.6149359576163754, 0.7060505942471567, 0.6183324237504314, 2.379039102985013, 4.094463183033851, 4.371772302735237, 6.57057261274707, 4.502590212129778, 4.670949126443555, 5.465443836104486, 8.305250137082993, 13.395880614557575, 9.974191188812256, 16.763613916212513, 9.444027946841333, 5.333752709050333, 2.325544837982424, 0.11051942924818686, 0.22819304718605934, 0.6005811246652758, 0.8343489936763241, 1.7247735396508248, 3.3325469445797706, 2.956935628767937, 6.325935365692263, 2.7796432712385735, 3.852571349951529, 1.9428060852712201, 3.535452869630629, 2.5719138114683093, 6.485444432304752, 9.027977239701057, 13.653185156083877, 7.875825128247661, 21.97188804226537, 22.289449014971336, 4.2191371898497305, 2.4735415029910306, 1.941044205619443, 0.7475354810876231, 1.5363287805549561, 1.4951663248000608, 0.4112333317677821, 0.347546634654845, 0.5073271721841828, 0.48290634227375834, 0.23612198059356984, 0.31292457794470174, 0.25962339774254833, 0.20162163993283627, 0.8330722621852352, 1.849007260414862, 9.829108599693546, 29.333568888325846, 52.6661624446992, 66.05964060752623, 70.83784841722058, 45.139392960456114, 30.083435850758708, 30.524890768912535, 38.30372548872425, 43.99796755083146, 44.007036070669855, 55.91539113752304, 67.7008544245074, 73.9359874110068, 85.17772782233455, 88.55541413830173, 99.11335206800892, 85.37993384945779, 36.511943647938395, 5.717859633507268, 0.29656578155775226, 0.1585357825482084, 0.18912990217006978, 0.18774446280252552, 0.26843469589948654, 0.11606566833272097, 0.12948758239226957, 0.2453555464143715, 0.1126786710454091, 0.1077112650138236, 0.1956130131598442, 0.09645359530564278, 0.13546286901879695, 0.151904127109916, 0.2433189169894303, 0.1829155807894084, 0.31071527230162777, 0.09593619484334223, 0.14855829938765497, 0.09135731796343481, 0.10917754197913794, 0.1287383330805648, 0.16708037485518765, 0.1474642645447485, 0.14762181818725603, 0.14186811483194753, 0.07475294443147798, 0.1889967867323468, 0.1373316332577698, 0.21226359711539364, 0.17231888408141752, 0.07944864205895893, 0.12406319725297152, 0.14762837589988786, 0.09434817884598048, 0.21899680516892867, 0.07738225777903873, 0.16482626839030176, 0.11158978431335381], [0.031485629545885234, 0.05848342027034491, 0.026455385152310617, 0.01113689307408828, 0.043648491508417556, 0.044103348552579844, 0.041440231575360226, 0.051894049055033156, 0.03441750357348112, 0.09004498636650463, 0.025197160430252556, 0.053839805130396164, 0.011377076960108694, 0.057915082621958956, 0.07521707113952407, 0.05152008323479564, 0.05980874854891051, 0.03586779611425535, 0.07315754334652617, 0.04538826952357927, 0.023217254070444934, 0.08938507822852942, 0.062428527932253584, 0.046195071190595634, 0.08207544263812803, 0.033119735307991505, 0.06314746697523421, 0.044183833749904755, 0.11519199868123378, 0.10786715624553543, 0.007553828989095505, 0.055813163353670994, 0.028875273044010805, 0.1146498918833752, 3.3329752183729604, 28.578995081686205, 60.61626157452984, 66.77631255119078, 64.91365740376135, 59.47052940245598, 44.983588572471376, 51.88257486589494, 38.29994824624831, 21.888037573906686, 16.330707803849254, 18.060373029401227, 20.898988400736165, 50.62933444976807, 55.57561974371634, 36.3697067383797, 52.65545437412878, 27.648200950314923, 5.788979068879159, 0.8664783534984436, 0.0437881340152554, 0.04553388368578688, 0.08256511071756964, 0.08631142622400677, 0.14939209416268334, 0.13643092836343473, 0.2007104089904216, 0.11699497128926939, 0.30610431165945146, 0.18623675580226606, 0.5106082961203591, 0.910135375395898, 0.41305652909701873, 0.9037511050701142, 3.403439863074211, 2.6883376029229935, 3.738750541402448, 2.796847277110623, 3.966723843928307, 2.5947196973908335, 7.101675752670535, 4.530124270146893, 7.8692718282822645, 7.222180279993243, 9.916618639423001, 4.53386228892111, 0.9631940121612242, 0.2233738025590297, 0.0954743510773105, 0.10560922700190738, 0.07705823323058505, 0.36905875129084437, 1.8096642941236498, 4.531440225339705, 4.675528983916006, 3.410306952653393, 2.2240338979228853, 1.634469914340204, 7.920916205452335, 4.899770396371042, 3.072256743907929, 6.495166026776837, 15.984745929318091, 14.726540773145615, 4.4264668130105544, 4.769349136660177, 8.837302980884429, 2.138508087204349, 2.5764686638309113, 2.513037564293031, 0.5397223645160275, 1.5494567083735622, 1.496575681432601, 0.1561836168290146, 0.11723272667656984, 0.29172318657079055, 0.11926513495704821, 0.014613960276267704, 0.08599986592608114, 0.011912646155143458, 0.040303387739244974, 0.051591858012421485, 0.054223113392870274, 0.03060707608388076, 0.20689879063396685, 6.09444639375133, 28.644543770820867, 75.26370186959544, 79.54725957685902, 55.69085505700881, 31.095550521727535, 17.627447305187104, 11.709021195288628, 23.384976810024632, 28.696428883460264, 30.08671299103768, 47.6349852931115, 67.57081216381442, 63.97841530461466, 63.15079519825598, 75.18332466002434, 70.51372728040143, 38.27223277861072, 5.769782008663301, 0.5180444664532139, 0.0646631297985873, 0.016748512974910198, 0.033426706739250696, 0.03866579436186341, 0.028739845935976314, 0.0282833552093155, 0.04374638222338211, 0.032129633698552366, 0.044520494918669426, 0.03733220765547406, 0.05183107279721768, 0.02126521607410283, 0.06696277252969242, 0.08325249842938878, 0.07531809515409893, 0.06674907230321439, 0.049233406541808966, 0.02733228577961845, 0.025283176782390764, 0.025340123928242156, 0.02492592317022143, 0.04856207986332236, 0.04380845832788656, 0.13106224547711112, 0.01964527910815612, 0.0289052136753115, 0.02800484202922352, 0.038854765270145676, 0.009298105855592558, 0.058850269133765856, 0.013315493913157093, 0.019753148118334434, 0.026022543559872338, 0.10047383321028563, 0.022540105123733802, 0.021062786916210767, 0.02123238154566817, 0.06013194955284557, 0.016698615753182, 0.07750415002867099, 0.018672521729322693, 0.04285745976132251, 0.039135908047037746, 0.06005849704266556, 0.023348322138190273, 0.037054887657324155, 0.019356548230374054, 0.0058402703331422905, 0.02623838117165912, 0.05948508789222087, 0.020148983833590345, 0.026860741425245523, 0.05405005796121494, 0.0037321462314726128, 0.021285224375465227, 0.012276043792465522, 0.0441438248080592, 0.05375753111776806, 0.005098088182538989, 0.029595485708165555, 0.02804695196720141, 0.019403813940082348, 0.04685075818410805, 0.10366681873077348, 0.026925177080556754, 0.05108948053431608, 0.02410898232952722, 0.01947794635329516, 0.011861824839856597, 0.026404932516837315, 0.11862462416531579, 4.534654607695918, 33.858315098670225, 72.88280748551892, 75.99449434588033, 75.06161351357737, 65.73504094154605, 54.86705533919796, 58.14834548581032, 48.50725373914165, 33.08256441547025, 25.367995769746845, 25.976261246588926, 22.48784249828708, 45.59323472361411, 44.91025201735958, 37.92296532661685, 50.56949477041922, 23.752759810416933, 5.126654015433404, 0.704147509269176, 0.0769197858209091, 0.10663563926373759, 0.13659238905435608, 0.15604472508834255, 0.2563575802430991, 0.527699135484234, 0.4257581136640041, 0.33627429436291423, 0.9660468010171768, 0.9427680243407527, 1.7646731147843024, 2.599189728498459, 2.680390145509474, 4.0491693683208965, 6.684966577637581, 7.645660446536157, 10.324232328322626, 8.353516863238427, 8.822317565641097, 8.082506089441239, 6.533213507744574, 10.232995056336927, 9.270483659159753, 7.652167168355758, 8.920292488990292, 7.01613131069368, 3.6859019965894766, 1.3284318846079612, 0.42672231192550353, 0.13480343585533483, 0.14358442757398854, 0.37125868001772516, 2.136613827559256, 3.1169183215787335, 3.0066749597749407, 1.2867868547478032, 1.396231033628987, 3.343179019228105, 3.4869731097452106, 8.992620014375257, 6.66064739227295, 7.224955356890156, 11.863879311469294, 9.313743479790228, 6.0100031572003525, 5.676840957134001, 9.780994845974831, 5.946529401886848, 3.228400907208843, 4.931605823578374, 3.0200330816930343, 2.9073943774546347, 3.1512557306597313, 0.9046948028187599, 0.6174452326470806, 0.19078630683643205, 0.23860592875749836, 0.15991429648091718, 0.4349508929637171, 0.08973171769250786, 0.03762679910587688, 0.021066730353801, 0.06718178940636498, 0.053740305630790616, 0.1991732076050774, 6.117395201037008, 23.608930418568274, 60.61647338251914, 66.29279413530904, 42.491000775367986, 28.739798530455563, 27.389926602763516, 19.307116039337654, 35.33709179970526, 39.830190366314305, 36.57222655511672, 55.004342217599195, 75.62145340827205, 71.43530384186776, 71.73463559919789, 85.66470576870827, 85.68539234899706, 53.26975637866605, 11.349159421459323, 0.8067297466820287, 0.04543365257221364, 0.05254961730491731, 0.03718923649660522, 0.03617333113065651, 0.01968288253391943, 0.014244623542312655, 0.04546240002157227, 0.031416886561219735, 0.014405829508999183, 0.03643052599903557, 0.028309949951606895, 0.0372574030001077, 0.024691205321540757, 0.03824104457312534, 0.013751761833836716, 0.04314943119102428, 0.08248531499937659, 0.06020419930498447, 0.002097537484763551, 0.03161695233786539, 0.01904029181347259, 0.06313078541068301, 0.08127329495525168, 0.10523081787170903, 0.034175707072380095, 0.025728503692775004, 0.008484449616873698, 0.0033157877389326574, 0.024846759474565907, 0.05793235407421186, 0.04302322969681794, 0.0438110783485876, 0.02538126859543545, 0.02279007195254728, 0.03015008165440973, 0.05300149809749377, 0.022900867418596343, 0.14608714489206193, 0.2244667189135667, 0.19204489736547395, 0.1708036081324662, 0.16697243306665652, 0.1295413311210371, 0.19423181791940045, 0.11763296165173093, 0.11701760918743188, 0.18901132708114965, 0.10890787902979121, 0.14685137888356564, 0.1476927579290444, 0.19693572524814837, 0.21593885796685375, 0.09572402679271276, 0.26206890361443647, 0.10987675808850797, 0.1333890996512867, 0.27999174510759695, 0.13978487661769315, 0.19874543942991765, 0.12363093214169626, 0.17232819971057678, 0.15176675222333402, 0.14121263468217465, 0.1531391680961655, 0.2222519127591964, 0.14510425408521008, 0.22664337388930783, 0.06853309955688254, 0.135697077419008, 0.15291710985043358, 0.2513916604220867, 7.069235790160395, 44.939536433066095, 84.35309656204717, 87.36908543494441, 82.32700409427767, 78.20416158245456, 62.40878866564844, 66.59032160235991, 52.78999167103922, 32.0927543024863, 25.065708506491877, 27.07634291341228, 31.445220016664077, 60.4154009203757, 70.18415404904273, 51.12131734048167, 68.9311372080157, 36.481835534495694, 7.6868727899366815, 1.468750510004259, 0.2622949914826501, 0.2689654109699111, 0.302955445142523, 0.18650873233714413, 0.6330891770701255, 0.4332587579565664, 0.6948550466087557, 0.2902702855006341, 0.629900841703338, 1.0074634141018315, 1.6801559660703906, 1.8336450524868506, 1.6439045629193707, 5.06508800291246, 9.496952487576394, 11.076661579070553, 17.935422005191928, 12.520158521590695, 14.787435570070821, 12.357757687568666, 17.088954910155266, 15.49205505078839, 21.689951996649466, 19.42954105715598, 18.361081538661836, 11.88952180647081, 3.287870412872684, 0.6469456238612052, 0.17271331211011257, 0.10188417809624827, 0.267385492521909, 0.847978433293681, 4.066676377288757, 6.040180402417337, 3.2045801080042318, 2.5739267228111147, 5.657319320786384, 6.874653870059598, 16.42602826318433, 12.224149011796522, 8.716452794690287, 12.921163016749968, 29.083923755153535, 28.24750577249835, 13.66495030541574, 12.478374492737556, 18.836217849485337, 9.866611361503601, 11.083667912790853, 7.970976435369062, 5.227832534620839, 4.922195076942444, 4.415560662746429, 2.0304817225663894, 1.212051606947376, 0.7296636304067028, 0.5753557492167719, 0.34381912660694897, 0.45035548087569977, 0.15752108377074042, 0.17167707094021384, 0.10006246697758475, 0.12047120249800145, 0.1302369083127668, 0.6113517080103198, 8.93033669840905, 39.43849071379631, 98.10399286208614, 100.00677385637837, 72.73585980938327, 42.708504046163256, 28.35024049205165, 20.575190859456217, 35.34654471182054, 45.17423929706697, 45.857739756184245, 64.64563792751682, 85.617307847546, 83.82072110329905, 82.04142416677168, 94.51751093710624, 97.24084392670663, 63.52311834212273, 14.123532252926982, 1.1226086967414426, 0.157164316624403, 0.10566584856039095, 0.10777231456050951, 0.12217178745495698, 0.08028468147160546, 0.15489147164888922, 0.17810186731719202, 0.1593543168517851, 0.11560735623202018, 0.11375418188230646, 0.10413754145584761, 0.1707484651236765, 0.17767178555650098, 0.2444407455022297, 0.11204228946758855, 0.13511033067780157, 0.12992131073148022, 0.11156778226816848, 0.11904905219712567, 0.13550118873676947, 0.06879619713271819, 0.1284266195650543, 0.1511295202879175, 0.19226453477336516, 0.1032258355389199, 0.08252902797633603, 0.17128992074679944, 0.14503742057469585, 0.0837301619110569, 0.20112722210826414, 0.113477049575698, 0.1885261635987028, 0.20606548615521003, 0.25193860123474754, 0.13494586692221705, 0.10444068244748539, 0.08508759310408946], [0.17927113199426284, 0.10609719436615707, 0.054841710239528656, 0.09473310738441446, 0.10214673941053691, 0.13534610189737814, 0.09439915433646211, 0.08434533051425412, 0.046052950389322736, 0.010942603600391699, 0.017072809484576987, 0.07190043136717812, 0.055232526163660714, 0.033176605845050465, 0.0563757476817456, 0.030652325067128387, 0.0339444212976002, 0.07627021986991167, 0.11246659492533054, 0.034612798537578315, 0.0744341982288226, 0.13301278194112162, 0.15124371335391076, 0.19933797779583162, 0.17233740808742662, 0.32400591719535093, 0.24614058735389865, 0.04191173571011713, 0.11143760860807474, 0.034212697627803976, 0.15680256990655778, 0.1384647692283315, 0.07156505339568661, 4.861542486375378, 33.922516453650694, 65.15412222954535, 65.8090482219573, 67.92677510169246, 52.56500451795517, 60.43968431411251, 39.98402180210237, 33.02400342879757, 30.14712141406152, 19.70184768399885, 23.61079158321504, 29.92006717189666, 54.701762737766394, 53.447839829229544, 54.98034907925514, 44.97349239164784, 18.096535321204893, 4.475663140896828, 0.22714545259312277, 0.026547258246629953, 0.11624526998568928, 0.07788054434762848, 0.06828056633352272, 0.10728826190555289, 0.022814180739524386, 0.3017002254003479, 0.4358872056247727, 0.645060312123068, 1.6041328325386972, 1.139276441066496, 2.448822726165095, 2.6148828864097595, 4.388363928564133, 3.699877156365303, 6.109971625189628, 3.746047865959906, 5.3522780633741815, 10.777748534756324, 4.585281129806273, 5.233050267542563, 6.5730559633624175, 10.397143306270724, 6.5837272617124745, 9.02597192795046, 9.621247495374373, 6.9142747117627055, 2.9248324997963446, 1.1839142393681312, 0.15957039961170766, 0.12675136913575474, 0.5487118240806365, 10.118345156792673, 33.98141476415819, 39.966967336593136, 46.63598506681381, 34.73663183950609, 14.663714208910543, 4.657592475414276, 4.328943942823718, 5.364152548774596, 6.8409734579824635, 7.614473681296072, 11.05325875743743, 6.514690604902084, 2.453933329351487, 3.354755159347288, 5.981265912132879, 2.455257619580915, 0.6271002694003044, 2.805410546641196, 1.2920438113712496, 1.2237850095956557, 0.703577907575715, 2.203367664929359, 1.2101887262636617, 0.33486487644333995, 0.3665886386748283, 0.09384728757844818, 0.19926990322288007, 0.320688174256394, 0.10238030429689154, 0.16770443007830652, 0.03017220435844314, 0.11871758127404798, 0.23482130119396796, 0.09477649094356645, 1.77417726285996, 7.710844355244791, 31.12151857345335, 54.05550126106509, 49.43462756372268, 42.24706857435165, 35.94769108679987, 37.355092417809274, 36.21345127782514, 38.55534161290815, 30.682285678002145, 35.43497062498523, 45.18171925698557, 58.80309889393469, 73.22574030968451, 70.16278497634396, 74.33639864767753, 60.4511768587174, 20.16606019389245, 0.7146597677661527, 0.03288482976776939, 0.06400258963807456, 0.029540614660588965, 0.00508361678164933, 0.02527322338503455, 0.023701172660014803, 0.10338768693468264, 0.08301689574915556, 0.030554746532992973, 0.06451555828173315, 0.05253766633329853, 0.02365404676135269, 0.20305486786509716, 0.34397231354828806, 0.17218193820407315, 0.08316555511086218, 0.14447054615424526, 0.11454936582595111, 0.05056754866194341, 0.0867209921500856, 0.029512470505470713, 0.03312082315284399, 0.14811648115996393, 0.049295497968071894, 0.009425437329487215, 0.047251073598501184, 0.022216817934907252, 0.03570894778315579, 0.029750572547556895, 0.049735282232323964, 0.03663535875779006, 0.016951388379018155, 0.05957767727874941, 0.03892554796390957, 0.059308152225229054, 0.23810263963476305, 0.2707314581399964, 0.05215443851005647, 0.034466307204697406, 0.07757510509221785, 0.11309784371405841, 0.06595698335478384, 0.07544600885481605, 0.01080529957694272, 0.05060116843050046, 0.10921372431180171, 0.029779434910104163, 0.03864073945629982, 0.07444429526766462, 0.033131173000701016, 0.07396644026401543, 0.032393748256107496, 0.006206095990379371, 0.0913213961006653, 0.029991106918802666, 0.042254567717111884, 0.063417999434375, 0.13038117799066729, 0.1241574413894165, 0.1053837443431539, 0.10961842557956135, 0.21517439414897274, 0.07024509922390984, 0.06535808645909832, 0.172364680817531, 0.027414575114005038, 0.09952163954655971, 0.058528041061494625, 0.03326136581299286, 6.304019122354447, 38.09887578410488, 74.376312686551, 75.95704355547505, 78.2695161142657, 61.802472606782, 66.88860216448384, 47.971136339249156, 39.91288569665725, 37.370099406088556, 29.54699093295682, 25.573690745138354, 24.28760047881834, 40.06321053351126, 48.44301316045946, 55.600107100702104, 41.61612787554341, 20.153004584773896, 3.838176741715401, 0.423289226788667, 0.11183060405235137, 0.18712590809070295, 0.10208709946563167, 0.08655921736311528, 0.33088848175060365, 0.38877607713783946, 0.741207104536795, 1.0773351067496886, 2.070506936119449, 3.8811941108395978, 2.799555918862743, 6.424276050060026, 5.436117254918622, 8.265455730499761, 7.121123354281149, 14.887409921615356, 9.908395390356741, 6.503781512860329, 9.471203107987682, 10.667142598859726, 10.583181323543673, 11.286394634554464, 10.775221547772809, 6.578891959882553, 10.376196868958013, 9.266532851803689, 7.723405745721633, 4.702703164469812, 2.425682213037245, 0.5265553968568002, 0.35144301912476944, 0.4844691922828075, 8.116764070526246, 30.790329325583677, 39.923880100250244, 44.68084043072116, 31.716420535118353, 12.967900018538199, 5.774474634278206, 3.611542193158981, 7.208504936387462, 8.884165498518175, 8.716618514830067, 6.692969193381648, 4.189379638241184, 3.377029073815192, 7.83430144671471, 10.18067652179349, 3.5005126412837737, 2.2655487541229498, 3.279167654052858, 2.097590902159291, 2.213999004133286, 1.700715191902653, 1.5718359139657792, 1.689271676924921, 0.8306338349657675, 1.2655276084138503, 1.202932341444877, 0.33194948288221515, 0.7670838998690729, 0.31659135054196086, 0.10180997481990246, 0.06877052552637554, 0.010372724200058128, 0.024667766861497395, 0.047584605298095176, 1.5319986064587872, 7.529657329282454, 30.519162147275864, 44.5139318127786, 38.30072487554243, 34.24955975624823, 32.82351147743964, 32.1700857916186, 41.119238099744244, 50.217822905509706, 45.69372584742885, 48.84592294692994, 53.83242430225496, 69.94728211433657, 80.16562907926499, 79.95918689235565, 86.44748533925703, 79.96052834295458, 33.33679676055908, 1.5593268626159238, 0.0991037539056232, 0.031486096859519044, 0.06126336182557768, 0.043533409780432145, 0.0585216289055684, 0.08922102049954476, 0.07358359548473552, 0.014828851769467997, 0.01964035890846243, 0.01567650603265652, 0.08507677594259863, 0.005121376776632163, 0.159846865421822, 0.1979941370025758, 0.11325067059407312, 0.09240659794980481, 0.18567674552961705, 0.023278679000213746, 0.006563744137829711, 0.06811983342612944, 0.03026523807596776, 0.051118354388182206, 0.08102640013901458, 0.013874897061126127, 0.012866723437553212, 0.014799098829708755, 0.12451551854610445, 0.0849643755223482, 0.03769647480259019, 0.0794003325544538, 0.038373872727876714, 0.022507986887508345, 0.0738558095068701, 0.05503680602076554, 0.02861183455904886, 0.16439987917340573, 0.41612529346058447, 0.12192793400777925, 0.133274324358471, 0.19603426958764755, 0.2074983157217503, 0.22398667289845406, 0.24267092917955693, 0.2548924677314297, 0.20169041930667816, 0.24849911160286398, 0.05220409249886871, 0.22871646909944474, 0.1594420952061492, 0.2022583049631888, 0.19007870206429114, 0.12951398178214027, 0.08888805570501475, 0.16353478204579125, 0.11312176863993369, 0.1495823137942822, 0.19555547995673073, 0.24537354948059206, 0.21131478189941377, 0.2574567172315813, 0.4837956171362631, 0.2970955466791507, 0.22802827699530512, 0.1632928208357865, 0.21443272910771832, 0.15356305986642838, 0.2348519293891807, 0.306252779499177, 0.13481714882917945, 11.849301822723882, 52.947878837585456, 87.35499628128545, 85.15699417360368, 87.22266335641184, 73.99271272843885, 78.44930971822431, 55.16956813873784, 47.021012767668694, 40.41508636166973, 29.963942804644187, 34.368862567409394, 42.01272264603646, 70.91828053997409, 68.47763276869252, 70.81394549339049, 60.053393610062145, 25.480667814131706, 6.977148344439845, 0.6243291761605971, 0.18355477390991104, 0.5487482285787982, 0.41479208596771766, 0.2307418983189329, 0.469904451240455, 0.24126558684773985, 0.7057470395680397, 1.5200825684493589, 1.9796109103387403, 4.2002264626564525, 6.117380982445133, 10.046121574217274, 12.688647854712702, 17.028654352311168, 16.48322916799976, 13.696222382207072, 13.194023678379676, 15.333084329482048, 24.155047901215095, 12.191892420091937, 15.861543301613102, 17.315958161507886, 21.879551526038878, 17.884892071447066, 20.82278459302841, 22.796585982845677, 15.44893349370649, 9.58488320150683, 1.9286833463176607, 0.5568365235963176, 0.6694985781946491, 1.986035752680994, 11.031965190364469, 28.250086692071733, 30.636199789662516, 32.128367462465846, 20.694109278340495, 6.928987031982792, 12.39335515806752, 13.155507964472617, 18.126810135379916, 19.89467924641025, 17.101355483455045, 26.301184508108324, 18.03801355823394, 7.666894687760261, 17.15865150574715, 18.9028000831604, 9.988123447664323, 8.202857154030955, 9.97904610249304, 7.52696511245543, 5.347572199759945, 4.710184104980962, 6.2937582019836675, 5.369513938503881, 1.9479940326944476, 1.9132567870040096, 1.9673546067168637, 0.33326856371375824, 0.6458124266036096, 0.34107116922255487, 0.2489961800916541, 0.09878962721315124, 0.2317134510245054, 0.2910825838485072, 0.23964189413574435, 2.534848393932466, 9.585741219982024, 42.39948795687768, 73.22729356827276, 66.19445247034874, 59.65801477432252, 52.426552695612756, 52.190296573023645, 49.71513586659586, 52.287975357424834, 45.420897545353064, 54.189971877682595, 62.39488386338758, 79.07384518654116, 92.20653672372141, 91.31312278009231, 100.03030807741227, 93.05558866070163, 38.41368521413496, 2.109656357957471, 0.14559030622964905, 0.21619247903506603, 0.1082166302348337, 0.10036369274941184, 0.15229245707873376, 0.13390977896990316, 0.1758353195844158, 0.12933203590012368, 0.17074772967926918, 0.08698325469008378, 0.20166633350233878, 0.1808126694372585, 0.29590078659595986, 0.32791762342376096, 0.2452590499794291, 0.2339025319463784, 0.3689368207368159, 0.16571416429454283, 0.12009481583992321, 0.19854385105352249, 0.09450063800379153, 0.1217624819987724, 0.23404896199222536, 0.1295228990455789, 0.1477839990008262, 0.13600634711404003, 0.1399810257698259, 0.12381188210941131, 0.18561617861832344, 0.1930628137122239, 0.17337242351664653, 0.11198995034060172, 0.23561844632269877, 0.130108910342378, 0.17795595821113358, 0.2902392436179423], [0.14721752294609625, 0.11824095201107765, 0.07248858771016521, 0.03691647089116516, 0.016331450878492287, 0.0826753354481151, 0.2450710366810522, 0.07233135582458589, 0.28655365590126286, 0.08568711053099363, 0.044274094229143475, 0.03174895503287835, 0.03842522743188086, 0.035930209297446475, 0.03586178232404975, 0.0438334672681747, 0.05488052791465194, 0.11098406923514222, 0.19104372770074876, 0.15368462269825323, 0.1403188705444336, 0.1349745492541021, 0.12888572839719634, 0.38029756757520866, 0.5111075709423711, 0.4313651111818129, 0.36633573772926487, 0.15651452084702833, 0.09700900138986689, 0.06215970384918394, 0.24011354382720687, 0.1722015653766932, 1.5590614897589532, 23.281898883081254, 52.5912961652202, 65.32059546439879, 67.30098447492047, 53.03032705860754, 54.404796169650176, 36.41571614050096, 22.772757584048858, 22.64847336276885, 28.26156354719593, 29.141370788697277, 38.017961209820164, 37.79812412877237, 54.56530740184169, 55.540451772751354, 28.59949338820673, 14.351434707641603, 1.9166916801083473, 0.09396956287204258, 0.05309639723911401, 0.2444876760484711, 0.11382316809988792, 0.2334868373169053, 0.14883799808880976, 0.2922048107270272, 0.10543374690197169, 2.187523005470153, 1.180108191986238, 2.647017884639002, 4.490941263014271, 2.229557085421778, 2.747138099324319, 4.537273770378483, 6.477722266028005, 7.56083821096728, 12.124233495804573, 8.930909364454209, 7.594898112358586, 6.937446113555663, 14.089347816282704, 7.478110030774148, 5.567572549466164, 7.772793289153808, 5.509327313592357, 6.138472057157948, 5.042746182410948, 7.353974369264419, 7.043806083740727, 8.112852486871905, 3.7245128279732125, 0.3502823652759675, 9.888816879641626, 53.05346512025403, 74.14683049724948, 65.74407808242306, 77.92570467918151, 74.28671790707496, 64.49507774845247, 31.668034176672663, 6.227433864147433, 9.817553297165903, 7.359480886690079, 7.33985677842171, 6.675958854536857, 2.011504805376453, 0.7838630027347996, 3.039157578060704, 3.897364081874971, 4.017550406917449, 0.6491186782237023, 2.873018970412593, 2.1515798760998637, 1.6495574337820855, 2.2616001531001064, 0.389919999626375, 1.1805005515775373, 0.26045129364055974, 0.5657849208481851, 0.6808491820289243, 0.7384175638998709, 0.4553774017239771, 0.37205605497283323, 0.20761886731751505, 0.05746973272893698, 0.11964859260666756, 0.091336342476068, 0.08878563741041769, 0.031747641192088207, 0.7386385036572334, 7.89091399600429, 37.1458928046688, 51.29247780769102, 55.36678098863172, 32.858791235954534, 100.29234593914401, 77.58732180441581, 20.928676820570423, 18.161323070526123, 29.824027938227502, 24.891498396473548, 36.294004994054, 63.6211540622096, 61.797946191603145, 69.57763794929751, 76.38390725658786, 74.05419195851972, 26.59909832862116, 1.4142898710504657, 0.25999473588120553, 0.026397352076826558, 0.04753267602814783, 0.10963648227193665, 0.06662081386293135, 0.04161789502588011, 0.08542266464041126, 0.14078345690523425, 0.14170607191420373, 0.20718022069383055, 0.37157476789528326, 0.4144915649967809, 0.6179828425088237, 0.25046478596425825, 0.14920556707487953, 0.012310312820538398, 0.10415616505328687, 0.15869971004224595, 0.007838696389714437, 0.018565001289149927, 0.07258435636157952, 0.11020037661036176, 0.04848832474841226, 0.07429631006333136, 0.05591593787915284, 0.10543933168293969, 0.06483889335105497, 0.022039029995099674, 0.02583640909212972, 0.17801623400901595, 0.08823508066275428, 0.22026587578077472, 0.057400570311132944, 0.10552399205945193, 0.09851293157665961, 0.18265529475625486, 0.19520070463899644, 0.03263604654479892, 0.01634634554296011, 0.054318916518241174, 0.09797147595353665, 0.21331111509953776, 0.12971215340639317, 0.37707485018237946, 0.09969482138272255, 0.06681474902096295, 0.02814809855584416, 0.06749314286055104, 0.018339978283151023, 0.012740914563408062, 0.03359298229277615, 0.042854778453587525, 0.10365301382637794, 0.1624472283067242, 0.07815948462173825, 0.07587922391511741, 0.1322425111767746, 0.09055558396803756, 0.18198067773013346, 0.26899954784781704, 0.38147023368266325, 0.33896954489811776, 0.09972198686051754, 0.09839542134995423, 0.06404515348314758, 0.020027336732093847, 0.12644661935947596, 1.9523867195652378, 30.676143246312296, 63.70030749228693, 76.94533963357249, 74.60611651020666, 64.0818089823569, 62.82009624665784, 48.28788342014436, 30.781031347090202, 27.069543484718572, 42.82089171871063, 27.119545859675256, 28.4277484878417, 39.93115609691989, 48.35638369283369, 47.52376648687547, 28.567424089677875, 14.583770421243484, 0.6426289941995376, 0.11520308397349813, 0.08854277987754153, 0.2772957284844691, 0.23163301179245596, 0.4030839948644562, 0.6370408424446661, 1.0871259555701287, 1.4049292572083012, 3.4335717558860783, 3.1696335058058462, 6.107824617816556, 7.413631168103988, 5.414308876760545, 5.588493491372755, 7.279562104132868, 8.792470289814858, 8.344353225923355, 18.14598660315237, 9.911554859530542, 6.388990407989872, 6.59764971463911, 7.265986780966482, 9.512994000988623, 10.176833579617163, 6.298418958340922, 4.643545977530941, 6.498004842189051, 7.459275299502958, 7.333785929987508, 3.6771477566611384, 1.5541563207103362, 1.724871353756997, 0.671232081949711, 11.207120591594327, 59.76512685898812, 84.09758552428215, 82.41060549213041, 89.45724548832064, 88.62586775133687, 72.60663340168615, 37.95811368573097, 8.85777481140629, 1.8949917800003484, 2.547097955980609, 4.054894312735527, 3.126723756713252, 4.0084156970823965, 2.366304147628046, 3.7939103428394567, 3.2253684247693712, 4.025204667160589, 0.979094687969454, 2.1167926201897282, 0.888891205672295, 2.2997145595089084, 1.7037082054922659, 1.515178379993285, 1.3322385448601939, 0.5622243280372312, 1.2582749008171021, 1.2532427450341563, 0.9004434438482408, 2.173440961107131, 1.1141811167040179, 0.5479321917218547, 0.21203626818474264, 0.37874838457472865, 0.08317031251687197, 0.08395302454910933, 0.04681584372695896, 0.08540660743751834, 5.9126808181885755, 30.1806459119243, 45.76251245314076, 44.90079126050396, 31.06080616674116, 75.65007102104926, 70.25110106314384, 26.220164029828965, 27.48755047398229, 38.16677593415783, 35.33909220849314, 48.392347904943655, 75.06365314606698, 69.74011821131553, 81.51068041401525, 84.27865782091695, 89.07467319119363, 39.599774652911776, 2.6753844657251915, 0.21950703504825794, 0.06607157478649771, 0.03579825448292879, 0.06480196791310465, 0.051960024547072194, 0.06320338373282744, 0.1292015711266187, 0.1615401802043761, 0.05777842402758618, 0.04434587666764856, 0.13471896700080366, 0.38247638291889624, 0.34093088320186066, 0.27110739280619933, 0.0914029001949295, 0.06610367387052506, 0.06559427902703324, 0.07326294172314868, 0.0333678979997433, 0.029486806560007316, 0.04412221346771525, 0.17769122886801922, 0.03277236423004539, 0.08474145925814107, 0.04433823877104348, 0.07632468106044878, 0.14742366188476164, 0.1610048686064059, 0.03916889579305726, 0.12381537547034603, 0.10508426525179418, 0.08383982739741765, 0.032746424492929256, 0.11732484874946457, 0.06927133252423617, 0.31255406718100276, 0.3207245174675219, 0.22422316424067945, 0.10060729338757454, 0.15941797875829283, 0.32724398699018264, 0.4686813152605488, 0.32214325101625535, 0.49086838600135624, 0.3035641173201223, 0.12980894095474674, 0.2220711160090662, 0.19184303319742604, 0.16493788740086943, 0.1472916649354081, 0.1673454412769887, 0.2151821163152495, 0.2975952198668834, 0.24305958090530289, 0.2737189252530375, 0.2162339243917696, 0.23602989682507133, 0.26063089529352806, 0.4612612940611378, 0.6555312018721335, 0.6986106547617144, 0.725036091621845, 0.3072861401784805, 0.3928166087115965, 0.1289867294291335, 0.2561247661229103, 0.4399359190175611, 5.631469430462007, 40.274520381804436, 73.45756807634908, 85.68189359480336, 85.83299113858132, 73.97505421792307, 71.61166144955543, 50.91376904518374, 39.39535640901135, 37.67112170496295, 40.1604147111216, 40.56455612182617, 54.27095313226023, 53.81872346324306, 69.98037907385057, 67.41226211670907, 38.557938221962225, 18.943482906587665, 3.133093195576822, 0.1734697473265471, 0.30241786592429687, 0.4790827055131236, 0.41953711199664306, 0.5432349695794044, 0.9479234283489566, 1.0531800480619555, 1.5669939931361907, 4.8229243005475695, 4.539671809442582, 8.98711790961604, 12.218596896817608, 8.73546060054533, 9.92994293089836, 16.20013504259048, 19.680929683869888, 15.653222299391224, 21.45116202292904, 22.926481154657182, 13.81739910571806, 19.49168905135124, 26.09582881773672, 21.03228230630198, 17.39253459438201, 20.857509336163922, 13.901034824309813, 17.538278102874756, 18.357172896785123, 18.531186888294837, 15.539427476544535, 16.326962920927233, 11.97934800578702, 3.1605973455213734, 12.80586592612728, 54.30648980602142, 71.52874254411267, 72.53753692873063, 80.75374141816171, 76.93881280960576, 59.37663178290091, 30.241356357451412, 11.736627817153932, 16.9787343471281, 16.40265093695733, 17.89954604641084, 15.298073253323956, 6.403160460533635, 8.198823486604999, 7.191934393298242, 15.699236604475207, 13.850111672955176, 4.067126959562302, 11.082212713456924, 8.330410180553313, 10.122831367677259, 6.040875152234109, 3.156297447219972, 3.3408143203104697, 2.909663958895591, 3.3724671121566527, 4.450774231264669, 1.9854769375055068, 1.8527959022791156, 0.9876931975445441, 0.39263752799841667, 0.39063092922010734, 0.24616199185050305, 0.19752227280649448, 0.34813002593094305, 0.23175880342962282, 1.1521695169710344, 10.863740617229093, 47.89771349199357, 68.46667366643106, 71.00475311279297, 45.934669202373875, 110.57217213415332, 88.62382027410692, 32.28627816323311, 30.28191366503316, 42.98439571934362, 41.20117641264393, 50.93275331681775, 83.26390143363707, 80.50972292500158, 92.07605515756916, 98.4767984574841, 105.24585231657952, 47.32409431088356, 3.072087346546112, 0.37011975242245587, 0.14087485119460091, 0.1561824370536112, 0.24000564800395122, 0.2030512059648191, 0.19057040793761132, 0.24450889668397366, 0.3279783588743979, 0.3831102440674459, 0.3114486942368169, 0.4668978319293069, 0.6920634834997116, 0.7699133996521274, 0.5842089064178929, 0.27385688236644196, 0.25957939365217764, 0.2289511677959273, 0.3603314470139242, 0.15589645643147731, 0.07930460986831496, 0.1930568382264145, 0.31785233126532647, 0.12577158098499622, 0.1709440320489868, 0.1413822005833349, 0.3465403628445441, 0.2233462233937556, 0.24193326311726726, 0.14077590327830086, 0.3535337343571648, 0.22920017701483544, 0.30136847868561745, 0.18737099493943876, 0.2841915310390534, 0.44399535764128933], [0.12518233679715665, 0.1708477041533878, 0.12670353460576267, 0.038971754557062546, 0.0787508585340073, 0.006619950093614359, 0.04977342958051351, 0.1025075285184768, 0.1919127165550186, 0.050033301926187934, 0.06907713689631031, 0.03569530375722436, 0.02963707087591531, 0.0431722529502886, 0.028123451592100245, 0.07748394829010771, 0.03346463575238182, 0.09756672105962232, 0.12182612858352163, 0.1577370286348366, 0.016096275292276856, 0.07830083550464723, 0.20521197227701066, 0.07398407560803237, 0.5903821041987789, 0.313434302206001, 0.28277246041163323, 0.1800239206321778, 0.14322272682141873, 0.06738707032655517, 0.3154504617616054, 1.0985265696241011, 21.22528253063079, 60.28621765875048, 70.10175289646273, 65.46956316117318, 49.19955991929578, 42.03674716334189, 30.790856884371852, 34.00299564484627, 39.61075728939426, 21.848235322583108, 17.988150427418372, 49.71835613250733, 35.307187649511526, 33.72424064144012, 40.83019864174628, 20.68400133040644, 7.034527226801842, 0.5147385825553249, 0.10469649452716114, 0.031669674508814374, 0.03347996900218629, 0.03159206980208476, 0.05614888223428881, 0.4703046555720991, 0.49731032742607983, 0.24486442276787376, 1.6373268707144646, 2.011477103637111, 1.8086202082134064, 5.640609533556047, 5.525499245812816, 2.4267248280586737, 7.938733081663809, 4.116053869647365, 5.74991814551815, 5.104283757748143, 24.134996744894213, 10.032532522755286, 5.092882898546034, 7.585033841671483, 11.978286024062864, 12.008593197791809, 12.356832008207999, 8.593589452005203, 4.2328880390813275, 8.218170087183676, 6.267078240071574, 7.5989391342286146, 4.005097371916618, 2.4967222204131465, 1.251088138068876, 4.680375562560174, 27.26778595678268, 59.75370883941651, 47.63843697886313, 56.62519893338604, 56.871621839461795, 67.11933166750016, 61.44712155865085, 63.220370200372514, 31.7495390676683, 7.772515781464116, 5.831008245868068, 6.463089373803909, 4.247832269437851, 2.6982744374582848, 1.9349277596319876, 4.349380962310299, 3.7101059623302954, 0.9706316227393766, 1.8340561659105363, 0.4554176673052773, 0.2044754553466074, 0.4443708326547377, 0.32427037074681253, 0.45663069092458297, 1.4128685021592726, 1.0436777385973162, 1.1192365615598618, 0.8506262170210962, 0.7246516380579241, 1.47505902955609, 0.9756764036513145, 0.33808992274345895, 0.3100343427110103, 0.1521449698315513, 0.08091252882994952, 0.053142396988527435, 0.05950720868103447, 0.03893536538065922, 0.18496903350516675, 2.203211505566874, 14.207175816259078, 38.79255087144914, 51.4423829509366, 87.87097623271328, 104.69787366928594, 67.19588064378308, 23.02776655843181, 48.27283328579318, 75.90081245668473, 29.285188413435414, 45.70234329469743, 48.82897830778553, 60.13297065611809, 59.811202941402314, 69.32672392937445, 78.68928817010696, 27.960604006244292, 0.6916917776388507, 0.16984238229211301, 0.1537400108551787, 0.1348810558838229, 0.05247664743012959, 0.10380440812197425, 0.11808809448754597, 0.1351149884923812, 0.13858685299994486, 0.2826130834798659, 0.36674249977354084, 0.23913469796459522, 0.2672469225381651, 0.08566097161101718, 0.14008757327833485, 0.02661969377509048, 0.1572354708708102, 0.022400529649589333, 0.0273930020780573, 0.035266424754574414, 0.05331904154210802, 0.02636247209363407, 0.08150678323281389, 0.08588834650694363, 0.009532580471357271, 0.06624147776634463, 0.012560034501216105, 0.04410943129069863, 0.024969249272779114, 0.10960475091011294, 0.0623557074446111, 0.14954011767141281, 0.07132248697622169, 0.019251603760846683, 0.03725784733110378, 0.04465663257325369, 0.18464477913033578, 0.1780956313614884, 0.03410222774912273, 0.022138393514098662, 0.046986914990890416, 0.08227196717334372, 0.08285134414871854, 0.08205962292249165, 0.02987812235650997, 0.060309360194350445, 0.01712462767177532, 0.09162321176019408, 0.04790541227726687, 0.061320159584283836, 0.02634398064636175, 0.02442159791356854, 0.08068155332077896, 0.07382233146457903, 0.03610592688463869, 0.052235111398922826, 0.064584115490077, 0.18170991161417577, 0.10439014362712061, 0.30237692618562334, 0.3394717308542421, 0.22561231147377725, 0.17923373158179945, 0.14075079091614293, 0.011461257574058348, 0.2028922580422894, 1.3426178717805495, 26.40338186294802, 67.9785817669284, 78.3310188785676, 75.11186692022508, 58.56716048332953, 50.59704157613939, 43.791509674441436, 42.10701642497894, 43.60571876648934, 32.32918889291825, 23.403459018276585, 41.78221279574979, 32.67656772367416, 29.204989671707157, 36.66723812780073, 20.15160429862238, 4.78049062913464, 0.22844070809022074, 0.029686855099674676, 0.05247160657158783, 0.18762472325996046, 0.6041402465874149, 1.2838456899889055, 1.2916182342075533, 1.7042686141306356, 2.5783648846610903, 3.4558410125394023, 4.990710058519918, 5.059096092177976, 8.190179563337757, 5.952570832544758, 6.679336995847764, 5.457303937404387, 5.959290833242479, 6.458196217013944, 8.41361443842611, 12.253428524540318, 5.824637336115684, 3.3212412028543414, 5.458457604531319, 4.436723811011161, 5.59710358419726, 4.414238333702087, 4.801120825352208, 4.239672758886892, 3.52598475833093, 4.201008975505829, 4.069944201938568, 4.341534260780581, 3.2211933068690763, 2.6303228062968103, 6.0444170524997105, 33.07010696780297, 71.74700675472137, 62.08527549620598, 64.47928236376855, 63.86366636522355, 76.38332674580236, 74.0628525518602, 71.66068323196905, 35.15312479388329, 8.152751816857247, 3.8727154174158653, 2.2455748194648377, 2.6775849153918605, 2.2308051345809816, 1.3292032432171608, 1.5049292267330232, 0.6120102984770652, 1.2282280744083467, 2.0572304485305666, 1.6593312448070896, 0.8624326125268014, 1.7235376253243417, 0.7766765464217432, 0.522369186003362, 1.4969617897464385, 2.290475171419882, 2.4971553971690517, 1.665602011546012, 2.059017578440328, 2.776441146289149, 2.8459237275585054, 1.9785845976683403, 2.1144526812338063, 0.7253623225035206, 0.44062766576966933, 0.38036335920614583, 0.10633312646419772, 0.053788703235407034, 0.07799400963009366, 1.434579679081517, 12.52580673463883, 31.992906447379823, 42.96325806648501, 85.1670354412448, 95.40581011003064, 51.50060661377446, 23.126957416534427, 58.55230646748697, 74.54560218318817, 32.69411248545493, 59.186945961367705, 58.99125106873051, 72.74062156677246, 68.68177644668087, 79.69119487270233, 90.95592821798017, 39.104547962065666, 0.9648082513482341, 0.1387818683419497, 0.04683011977542793, 0.0634474938194598, 0.035045385405781775, 0.08041007474305169, 0.025035950633126403, 0.09141826791869057, 0.09557149868698851, 0.2740882102760577, 0.25702085916794115, 0.2507494795586794, 0.16015610447333706, 0.1018574109841739, 0.013186474172999302, 0.049193049029957865, 0.09888839892922871, 0.05521415537523647, 0.05507993294046291, 0.020647115269375425, 0.015077232796278213, 0.024406473422723434, 0.028775894203253334, 0.08580989910349732, 0.058236464167073856, 0.10155851411963664, 0.0715730666753746, 0.03210067940545419, 0.013194001944465263, 0.07728314132339532, 0.037882592033354506, 0.12132000493546649, 0.052358413250335765, 0.009591237908499617, 0.04080017277550313, 0.25583671706338085, 0.30294000080996947, 0.2084178817007811, 0.13476784341037273, 0.21606608984931824, 0.15935353544210235, 0.13324806286442664, 0.3543869111566775, 0.3343144575915029, 0.21379396499645328, 0.1506020840738089, 0.10798309599199604, 0.19898231381610518, 0.10358554446288656, 0.19283565332091626, 0.13389874730379353, 0.18387266975497046, 0.20537936248846594, 0.2450275075651946, 0.2967435445997023, 0.17249471658179838, 0.16866118196518193, 0.30943942947253106, 0.27819897679071276, 1.0411028251532586, 0.5640327245477708, 0.45097932159419984, 0.42495096342698224, 0.25376660959614866, 0.20756806036637676, 0.5469189331896844, 3.674898277367315, 37.58519434159802, 81.63126976259294, 88.05408816183768, 86.91556530614054, 68.79930634652415, 57.730495391353486, 44.943352899243756, 45.80484267204039, 54.364199638366706, 37.12396283303538, 25.892224465647054, 68.7638088964647, 50.38212314728768, 45.92014466562579, 54.141601208717596, 27.728099630725, 9.682119738671089, 0.8174129960037048, 0.27455527876173297, 0.2837159130121431, 0.29870727309776895, 0.7673205903941586, 0.8759290592805032, 0.749186002198727, 1.1552164631505166, 2.943811868467639, 6.750814837794151, 6.9579424588911, 7.973364178211459, 13.092817702601034, 13.558308905170811, 10.11667913006198, 19.689690297649754, 13.572754994515451, 15.742592523174903, 15.842602176050987, 40.36983789936189, 21.161236109272128, 17.3957097530365, 19.33052670571112, 23.074170158755397, 27.29726649099781, 24.88672291078875, 21.374063914821996, 12.395352625077772, 18.389442236192767, 16.26734289430803, 16.496086697424612, 9.98666726773785, 8.16380750748419, 4.094365614075815, 5.453860586689365, 38.80015634721325, 69.59562593890776, 62.165044738400375, 66.32021150281354, 68.67459850926554, 79.6702729502032, 75.52254692200692, 71.14989649864935, 38.157715259059785, 13.362158037001088, 11.92772275017154, 13.714487879507004, 12.47940117313016, 10.104647259558401, 3.9937982491908537, 15.158935996793932, 11.43843060539615, 3.750884883826779, 5.833725958101212, 2.524316830019797, 3.3111114367361996, 5.066243140928207, 3.3185293741764563, 1.480496660355599, 2.8188927135159894, 3.6245843191300673, 3.7903809451287795, 2.7491730739993434, 2.9311274136266405, 4.671535030488045, 4.7674967973463005, 2.0590518991793356, 1.4783589686116865, 0.6626313047543649, 0.23385489659924663, 0.3988038003444672, 0.2730045942289214, 0.1599655784065685, 0.3122415952384472, 3.4158514680400973, 20.577089286619618, 51.42637183589321, 63.94626755868236, 92.90375371133128, 105.93666015132781, 84.50814785495882, 34.053923699163626, 59.53435028752973, 83.21692712845342, 44.93526497194844, 64.50594271382978, 68.95618546393611, 80.95953249162244, 81.2666383866341, 88.76697894065612, 104.78549157419513, 46.211361039069395, 1.766688967904737, 0.3989039740014461, 0.2762027661646566, 0.26736683062007355, 0.15632201827341513, 0.23857399821281436, 0.22669255673404665, 0.29977942846955796, 0.3487493620524484, 0.4671066674974657, 0.7025960892919572, 0.5048596336235923, 0.47704043768105975, 0.29316091910004616, 0.2251895381918838, 0.22494336349829552, 0.2968582126402086, 0.13195711278146313, 0.11390465687239364, 0.10601657893388503, 0.1501103935222472, 0.11967583469325498, 0.20420878014016539, 0.2743725821135506, 0.17037922606593178, 0.20570623688399794, 0.1652869170591716, 0.13367293522723261, 0.14258785443680902, 0.21452718774878213, 0.20941016474558463, 0.2184910185995602, 0.2098904712305915, 0.11147792015465037, 0.18201470735573], [0.09511648842524137, 0.09334052807741589, 0.19562767608271492, 0.028550905671211022, 0.10144714791808399, 0.04049796641113297, 0.016037752878131167, 0.04876345373509873, 0.06433411801774656, 0.1512403885323194, 0.12499246190512374, 0.10944064721585282, 0.008190386767138638, 0.0034221987880300735, 0.07576062584355955, 0.03751090532469173, 0.06757744317573887, 0.04230468901955793, 0.0910841846357911, 0.040230551929844004, 0.07135617952313154, 0.02348701661122182, 0.09865294180570111, 0.11622473116843932, 0.19992345283108376, 0.29557572016792916, 0.19422064835746444, 0.09939561042213634, 0.058792157534269564, 0.16301168188933404, 2.6622298167597864, 22.65417060544414, 49.20084253434212, 66.20835335023942, 63.865745221414876, 56.51425469306208, 45.23114504352693, 23.402421551366007, 22.089015899165986, 16.924797834888583, 20.499181209071992, 28.917915321165516, 57.74071708802254, 42.64124324244838, 41.23202193167902, 55.110206988550004, 12.50194009273283, 0.7024281015319209, 0.03146763414054388, 0.012988972875680174, 0.031489628524849975, 0.05789351724689046, 0.03808108541453558, 0.28772292057833365, 0.6809094884703237, 1.1974793888868824, 1.0214814135143835, 2.504370842249163, 1.6482914888089704, 3.6966573807501026, 3.6368343714744817, 7.702443128631962, 5.927256836045173, 5.516858754619475, 3.7290703769653075, 3.922492501235778, 4.309449763067307, 3.458348877968327, 13.73352804491597, 4.81561545402773, 5.08656592138352, 3.994997023574768, 2.218395490800181, 4.42869471926843, 6.614550227119077, 4.967188585189081, 5.732305232555636, 9.980761158850886, 14.83382151972863, 22.03699350357056, 21.259515016309678, 24.112919684379335, 25.02328807307828, 37.91299466163882, 38.1571465153848, 45.47742282190631, 37.71047092253162, 55.42445551964545, 52.53158984645721, 57.10431252756427, 46.353146876058275, 57.65179695621614, 51.04040668856714, 20.72806327573715, 11.897106689791526, 10.14296293258667, 12.891183360930413, 11.68706572824909, 6.716973118243679, 7.364116147641213, 9.177291085643153, 9.082868849077533, 15.505433274853615, 15.23006425749871, 8.973097397435097, 8.531759169793899, 5.73342114686966, 3.950619817741456, 1.5863062729758601, 2.1685004907269634, 1.6646021748742752, 0.7158088383655394, 1.0279194325689347, 3.281681157888905, 2.11284720609265, 2.3357976684647226, 0.21809715747592912, 1.242494960465739, 0.24863354471181673, 0.04412158527561734, 0.1777307590049121, 0.13034907890663994, 0.2938508272411362, 0.16934255588679545, 0.6131931382321543, 6.804007570589743, 26.73132338831502, 50.548251213565955, 61.580015382459095, 35.27166666523103, 47.95317972860029, 24.461098678650398, 28.308271131207867, 25.841771018120554, 21.14422086746462, 31.867255280094763, 42.20936282988518, 61.62081195462135, 62.78579511950093, 71.58593070122504, 58.84250302468577, 16.064184711825465, 0.25148012825558264, 0.1349106421994586, 0.06386334932739697, 0.11839870483644548, 0.07515809003023372, 0.016026600553173453, 0.07110405998725085, 0.010580590666992771, 0.16169739676819694, 0.1609181934186528, 0.09590940474863015, 0.07771833289054134, 0.058453715211080934, 0.10712765157222749, 0.05900265934366373, 0.06794748662580406, 0.022273357138938965, 0.043612814793783816, 0.03567682571649071, 0.05493833690941815, 0.03677446117264129, 0.07345103929119726, 0.05059732266912057, 0.02992843518093709, 0.034772719391771865, 0.024909957897879427, 0.0835860531116205, 0.011959837171279136, 0.03566203638911247, 0.038289936304452925, 0.04598352750162444, 0.04576391307637096, 0.07454411652419837, 0.05959261216283326, 0.11900264259067275, 0.1312430422272413, 0.11852744591212082, 0.021082366208335566, 0.03835845520840057, 0.0723925126235812, 0.019003900721849456, 0.03367276268921072, 0.07847562612545106, 0.037041615184035995, 0.2174203494383443, 0.034077034947732766, 0.04246751717742413, 0.048821182290632884, 0.026855859529948043, 0.03143614218119652, 0.05497596714825881, 0.04663079135840939, 0.07368561541361195, 0.024145070816420262, 0.07136387870677056, 0.07215448910550726, 0.09205043601292758, 0.05709528044286755, 0.1055621432380811, 0.1616827644888432, 0.21617705002427104, 0.20463662492411755, 0.08227025113639333, 0.15298903018476503, 3.6205227048166337, 28.444306773524133, 59.30579769995905, 78.63563799089002, 71.7858382194273, 68.16928740470641, 55.50502100298482, 33.69905118019351, 27.450666466066917, 24.65365763633482, 33.60801689086422, 35.53297496611072, 40.55205945045718, 42.47731954820695, 37.820705213854396, 37.37311963112124, 11.274502008192002, 0.7182659581303598, 0.10592432662604317, 0.10478508493472492, 0.15325040406277105, 0.4338112299240405, 0.4738357999632436, 1.4395062985920137, 1.7205109038660604, 3.158921758013387, 3.2220684857137742, 5.779354062772566, 5.973806544657677, 6.95605726972703, 5.998650347032855, 7.218879605493239, 6.484298609918164, 8.476998959818195, 7.122680044943287, 3.723036545899607, 5.323585435267418, 5.911437426843952, 7.034535561838458, 5.3876539199583, 3.94699358651715, 3.2615380710171116, 3.8097535314098483, 5.093934093752216, 4.181657471964437, 3.795249832253303, 6.803052963749056, 10.682960537172134, 15.825836985341965, 22.279627400059855, 23.138300911072765, 26.799421618061682, 27.401407380257886, 40.68400013831354, 46.2125652067123, 52.783633508989894, 45.40921280460973, 62.20217781682169, 59.429356282757176, 65.86535776815107, 56.086865394346184, 63.4740573360074, 59.143070328620176, 25.427600106885357, 15.79320090432321, 12.786240346970098, 13.632123008851083, 13.089842584825332, 8.317668361048545, 8.61832195712674, 10.777589678764345, 9.944810675036523, 17.448147919870195, 19.280585127492106, 11.708147487332745, 10.679648095561612, 8.924487463889584, 5.822062300097558, 3.194210587009307, 3.855849715971178, 1.5119402182679025, 0.3309345696001284, 1.0287884214232046, 2.018551956261358, 2.680169757335417, 3.18482925814967, 2.890184978323598, 2.7525693562722977, 2.4190173706700726, 0.8431097913172938, 0.7438442856073381, 0.17590023787511935, 0.04474044259216997, 0.07453344491941315, 0.2092416560457599, 5.84613633732642, 22.105370221599458, 53.297028618474165, 65.78832634033697, 45.995175684652025, 35.09172793357603, 19.06259548279547, 40.61051845550537, 36.731894477721184, 38.54460608574652, 42.417091554211034, 49.48087623042446, 71.76321398827338, 71.93565707052909, 79.20348736547655, 75.82905661675238, 24.947205858845866, 0.45914388832546055, 0.09665742831965608, 0.031143125041478106, 0.10694096360595957, 0.023166251766885963, 0.056970002084609964, 0.04612820703656443, 0.03715777326555502, 0.14162120469395192, 0.05462979499791419, 0.06688813258322977, 0.06671183276921511, 0.05498881444274899, 0.11991571214410568, 0.050642870426658666, 0.020151088660162304, 0.04149216850618682, 0.02660822160842438, 0.030844082620235223, 0.021431575897299958, 0.0054253212029805355, 0.04659923236636866, 0.0156545604864556, 0.039622431335550164, 0.014892624758724726, 0.019954680953355088, 0.03273946075369755, 0.04379714703968456, 0.026137908740389734, 0.0773908609464284, 0.09658393750507986, 0.07724849116658011, 0.03379420294696766, 0.0245327323735241, 0.2820967402189009, 0.4142280613943454, 0.35975222325613426, 0.12756821038501878, 0.20615942385648528, 0.2384046468162729, 0.14246264502646463, 0.15466596600749802, 0.21987400648574676, 0.3164362637025695, 0.2582490666499061, 0.23498513675745458, 0.12883374167065467, 0.16267579829981252, 0.12125430523508018, 0.16134773891779686, 0.21131556330909654, 0.13781534117316047, 0.1608915795241633, 0.0910377597075797, 0.18068473275390365, 0.19340332447280809, 0.37256023275756067, 0.2650144503962609, 0.26241716718481434, 0.6992363340912328, 0.3633254718395972, 0.41680334256060664, 0.23623174567136074, 0.3440161337775569, 4.9847583520797, 37.84339220293107, 73.28638015254852, 86.14824771881105, 82.38904030092301, 76.29253956579393, 63.58604492679719, 37.50749218848444, 33.43580130607852, 25.653248179343443, 31.731692283384263, 42.06647088450771, 77.20111739250922, 57.00488044369606, 55.41222556944817, 72.86998133505546, 17.495451704148326, 1.6460724078839826, 0.1640999557510499, 0.265002683285744, 0.29321972400911395, 0.24563758934457458, 0.28483210311781976, 1.102390471966036, 1.5980698288448396, 3.792556879981872, 5.866210537572061, 7.533298269394906, 8.78867833845077, 12.932418257959428, 10.558595907303596, 16.476386593234157, 14.85821375923772, 15.545904290291572, 11.036118980376951, 14.86928072667891, 9.10871530732801, 14.935143205427355, 29.802611797086655, 14.113666511351063, 13.365958813698063, 9.900438862462199, 8.837235319998957, 10.131368406357305, 13.729682160962014, 9.800834194306406, 11.012220959509573, 14.712800710431992, 20.550813328835275, 27.875549370242705, 26.06256123512022, 30.909669399261478, 28.515419344748224, 44.62463286615188, 54.60350344257971, 57.52728523746614, 50.866735904447495, 66.46799856616606, 65.2743624871777, 72.7432809337493, 63.477003036006806, 70.90667816900438, 62.658118048021876, 27.735414851096373, 18.340734243392944, 16.252467305429523, 18.289821878556285, 19.72614872840143, 13.372735688763282, 13.112149103995293, 13.88169950054538, 12.633859207553249, 20.568597355196555, 20.473732871394006, 14.533588597851416, 14.78848284290683, 11.666169301156076, 7.948629221608562, 5.479090252230245, 4.957042884442115, 4.212642725436918, 2.9852009636740533, 4.135203861421155, 9.386200443390878, 8.861359857743787, 7.327727829256366, 3.244496108062806, 2.8679858340371043, 1.56598741489072, 0.7186544566385208, 0.5788967914638982, 0.4145072238339532, 0.561640140029692, 0.2810458514478899, 0.9538446138462714, 9.317338332053154, 35.42391738583965, 60.73707057583717, 68.21009574397918, 47.98617078411964, 66.4818053091726, 32.35633561688085, 38.4846918813644, 38.694001320869695, 35.481282049609774, 45.45054281911543, 59.817616016634055, 81.22116242685627, 84.59254941632672, 90.16451943305232, 88.53198189889231, 29.28660046669745, 0.8157041909233217, 0.22428255137656966, 0.27737414524439846, 0.44901887195244916, 0.2604725295978208, 0.16951055896859016, 0.2626363602617095, 0.15405468913095613, 0.37794763883275373, 0.3670434191101982, 0.2813106420780382, 0.4334430787111483, 0.2366705761561471, 0.20792259053597528, 0.13380779734542295, 0.35948167164479533, 0.24747575603185162, 0.19011967244648165, 0.12324224211155407, 0.19429970863125018, 0.12623515610973682, 0.2053507720871318, 0.2102206704477149, 0.14016712384839214, 0.10273173947127597, 0.12953880303088697, 0.25932682978530086, 0.11104837465550631, 0.21940054882678295, 0.19706318695699016, 0.2751459325513532, 0.16844203485356224, 0.29850168574240904, 0.1284176027101855], [0.051358450174091325, 0.035019369059873205, 0.03177094558674482, 0.038521540005721396, 0.044787476560281175, 0.054331108807556094, 0.0148142300238232, 0.042708877008408315, 0.040794557351018154, 0.041068675101644574, 0.027393392782898682, 0.044427273509603356, 0.041890829170663516, 0.09598985164155883, 0.0493068820346267, 0.07955263083380076, 0.05357036434654748, 0.029418653463043516, 0.10948622944734751, 0.015008892007772962, 0.017219641726584207, 0.02316932760990195, 0.040368535856325785, 0.029389478919667103, 0.04620747415408973, 0.010758453300372969, 0.13605893138916264, 0.059722843279521313, 0.14269067875800595, 0.4913287129132979, 15.481121443933057, 53.17200306923159, 69.28576654003513, 69.1331784955917, 63.610963744501916, 35.20340957949239, 41.28914733086863, 37.11196430267827, 23.332448428676976, 24.550475766581876, 23.73407756128619, 40.48666177257415, 44.33638964929889, 48.93205427354383, 30.650014377409416, 6.488543595037153, 0.20338224787865916, 0.04224883737943826, 0.09147996864011211, 0.1601318041643789, 0.06718146764943678, 0.34859442843064187, 0.5693904983420526, 1.0392687493754973, 2.620080272036214, 3.8008144497871403, 3.542759509817247, 4.555067112368922, 2.1251676159520305, 5.117124617099762, 4.176287256902264, 4.914578324364078, 3.32119143778278, 6.6874592438820875, 4.719726251017663, 3.444049632357013, 4.478308289281784, 9.299831813381566, 9.590397073376565, 6.609784547359713, 3.665041361124285, 5.7223316257999794, 4.510131459082327, 5.811655761734133, 6.85550093650818, 11.59222379807503, 20.884793343082553, 28.06246795961934, 35.652595489255845, 51.16257282995409, 45.50915087423017, 36.9411176250827, 59.145282545397365, 62.09181408728323, 37.07987146992838, 38.65299294071813, 43.63687807513822, 50.84009516623713, 43.589625281672326, 49.60485058446085, 47.045127499488096, 51.457146752265196, 39.602504622551706, 49.41970294521701, 27.495397175512007, 34.84937644773914, 42.32904611095306, 35.02249810003465, 35.20745746551022, 36.075921212473226, 40.09854324402348, 39.95041885683614, 53.17445062821912, 44.15159502337056, 40.78469914774741, 42.15845046504852, 35.12540540387554, 32.554707527160645, 28.287955214900357, 17.061674825606808, 6.180403665188821, 2.3384688025520695, 1.55972057052197, 0.3199264683550404, 1.3113706775249974, 1.5196455918973493, 2.9182316410926084, 1.2100824545468054, 1.6861359871202901, 0.7036368657023676, 0.4577755633621447, 0.06906632739569872, 0.06352989040615578, 0.07863963788916027, 0.043277203165475404, 0.06330899278362913, 4.175105642887854, 12.798431073465656, 37.443467340161725, 35.19625909866826, 52.59170016934795, 62.678106446419996, 25.413703149364842, 16.943801718373454, 18.84243284502337, 19.975399663371427, 36.60040486243464, 40.9920983929788, 54.846933580213985, 63.225379067082564, 72.43407264832528, 44.82244976105229, 2.2758177643822086, 0.24339050024507508, 0.08863379112294606, 0.0864247765932833, 0.042261738300083146, 0.05820352621676941, 0.025383122528212208, 0.15292596582683826, 0.07434138667679603, 0.031682138759342414, 0.06393936057124408, 0.02363069065576119, 0.08155049620977334, 0.029308633661017786, 0.08871544077391587, 0.010525215916605967, 0.0017818145762806038, 0.03021421278977106, 0.027075590783609983, 0.04223550744955579, 0.04509603762398324, 0.05145054160346908, 0.03787986476034407, 0.050200109910820766, 0.06403681078565217, 0.07027847001389151, 0.06125367847421478, 0.06872000202776925, 0.038641888588186235, 0.034562581474141735, 0.042688755709077084, 0.029967335210512244, 0.04390413121831033, 0.12362440507258139, 0.07759042685070346, 0.0383783083769583, 0.00564014470587755, 0.039801960210165674, 0.03371836407290351, 0.049044642477266254, 0.06938009402684628, 0.0971074207054992, 0.040265362965123314, 0.08830353827966798, 0.07147395021973119, 0.055405397734214226, 0.035996464411577875, 0.08605270301021876, 0.06367654644794042, 0.08769223842048839, 0.031063988158899932, 0.05813441742512007, 0.06067378055905143, 0.04518392706109632, 0.053938281902622794, 0.03570397204208759, 0.009612491102738967, 0.09050890623081116, 0.0678616771174054, 0.04776318422368458, 0.14070672553873834, 0.048534983333440564, 0.22581629004449616, 0.3983198472809407, 20.02237985211034, 65.291691518599, 79.77583177628057, 76.9842181667205, 69.27616457785331, 46.40589491013558, 47.822172564844934, 42.96309332693777, 28.963791362700928, 27.682170637192268, 27.97791146462964, 36.559082692669286, 42.87080780152352, 42.332223230792636, 29.93347579433072, 6.642689801031544, 0.12934090719828684, 0.08777531299499736, 0.15759154853801574, 0.44588851411977126, 0.6681552276976648, 1.465832266596056, 2.344495769469969, 2.6679035252140415, 4.518240469117319, 7.250850844767786, 4.619868589985756, 6.308561227013988, 5.709106864467745, 5.451255152302404, 6.323029379690848, 6.499325700344579, 4.111070253195302, 4.543854036638814, 2.9892870928010637, 4.02094227652396, 3.4551712678324793, 6.993335475844722, 8.723986687198762, 8.233387412563447, 6.053757686768809, 6.206339357360718, 5.87506675912488, 6.680947619099771, 8.62980273462111, 14.380132729007354, 20.45750406480605, 31.231023303924072, 38.54019341930267, 53.84264992129419, 50.2283936931241, 41.58858891456358, 63.529205860630164, 65.08304495965281, 44.68533546693864, 45.38572957438808, 50.01892735881191, 56.828781712439756, 50.32179317166729, 55.91171587667158, 54.16774380591608, 56.72173238569691, 45.71826419522686, 54.48865252156412, 31.68321963279478, 38.75195041779549, 47.93647043166622, 38.63930386881675, 40.39030874929121, 38.27209157328452, 42.8541063493298, 44.0270636927697, 57.40388747184508, 47.33524168691328, 43.633540138121575, 45.09548594874721, 39.70586692133258, 35.80382247124949, 31.626468819956628, 19.947213511313162, 8.17395664030506, 3.587463252967404, 1.7119723942972, 0.22257445109707696, 1.4256434166623702, 1.4929240773762427, 4.866171373474983, 3.811615921797291, 3.284280953868743, 1.2704726140345297, 1.4380024373531344, 0.32673539653901135, 0.047279116246969476, 0.11084351508367447, 0.1005043771358267, 0.020735192398029952, 2.3966375522075163, 15.200131670121225, 40.213233347862, 31.692227355895508, 49.15617458281979, 49.07389502371512, 28.82940507704212, 19.95854719992607, 19.894228173840432, 26.244416044604396, 49.50140591590635, 53.95890897320163, 61.4869846067121, 74.14405345916748, 81.60153035194644, 59.45430647942328, 4.552428337835497, 0.25233189545331464, 0.11504641899298276, 0.03179647163638184, 0.07358991571011082, 0.08433560885849499, 0.07786001319125777, 0.038163512644748536, 0.05363450505800786, 0.0707969889645615, 0.0549358049888284, 0.03615164318152013, 0.058267157479760155, 0.04692117315566829, 0.014296987567157035, 0.08732205707459681, 0.04763464616130918, 0.07189617957919836, 0.02561769482018727, 0.01397367260764323, 0.026394801004038706, 0.022199284097540285, 0.06847073233896686, 0.04466707818210126, 0.05264914744803983, 0.048301839795444286, 0.043754472111862515, 0.0442263477992627, 0.057773222290580316, 0.030229584343971747, 0.1328470464795828, 0.04191519459709526, 0.06032165590553515, 0.03840331731724643, 0.22012404226247342, 0.25701845365185894, 0.18576397230067562, 0.09977595009390386, 0.14165937119433958, 0.15529602735994325, 0.20049164492276408, 0.14996659881885976, 0.13612173527719515, 0.20402983732281194, 0.19464343696111636, 0.24381163409881054, 0.17866589189056428, 0.20254819263373652, 0.23884802786332948, 0.211689306963836, 0.1263209886007732, 0.3418316800267466, 0.24005792584390412, 0.1518519258787555, 0.1622857063287689, 0.1416434672090315, 0.17273816400237624, 0.142891884090439, 0.2429610007112065, 0.10241902238058467, 0.2980695508660809, 0.1555261754941556, 0.43852058689921136, 1.0923943115818886, 29.211328221905617, 77.34339744813981, 88.12377299031904, 86.9399389143913, 82.80536851575299, 49.34167131300896, 54.65654173204976, 48.26073277381159, 32.96377543480166, 36.40616516913138, 35.58857848567348, 54.820284997263265, 56.37757970440773, 63.87069133020217, 40.467936377371515, 8.858218039235762, 0.2715366778354491, 0.35560591026179256, 0.44213627675367945, 0.4209043337933479, 0.5792714391023882, 1.609574753430582, 2.1637017159692706, 3.9094569942643567, 6.6155028727746785, 13.032027829077936, 10.489238596731617, 13.40475791885007, 10.69601712688323, 13.023217205078373, 13.720067451077124, 15.498503427351675, 9.919640825640771, 14.901017604335664, 9.991985021098968, 9.812609149563698, 10.230820102076377, 17.887098404668993, 20.612255296399518, 13.89082979771399, 8.461130030693548, 10.640919593072708, 8.60008881938073, 11.269818698206256, 12.139167920235666, 17.135570318468158, 26.444766790636127, 33.352172451634566, 39.09341235314646, 53.453021280227176, 54.80926313707906, 45.294707052169315, 66.62248503777289, 72.23274523212065, 51.1749400631074, 48.822008255989324, 56.210914273415845, 61.903277520210516, 56.54198977255053, 63.482635559574256, 61.41317736717963, 63.25303177679739, 51.26377782514019, 60.86370821922057, 36.545919218371, 42.05466847265921, 48.795995097006525, 42.563682294661, 42.27220312241585, 42.46055533809047, 44.982808020807084, 46.33673960162748, 59.97941378624209, 49.30128266734462, 48.68420362472535, 46.66863879849834, 40.17645720512637, 38.110274191825624, 34.26960699019894, 23.492212449350667, 9.524823869428328, 6.7130208399988, 6.94428280476601, 5.008699519018974, 6.741136879690233, 9.332025647163391, 11.645999493137484, 5.349653997728902, 6.133202843127712, 2.76125495472262, 1.6867747205880381, 0.3510334378769321, 0.2376836355054571, 0.23767226676066078, 0.27896524857609506, 0.10096722447703924, 5.764720680252199, 18.980241398657522, 49.10338732504076, 46.74325404628631, 73.05708623701527, 84.86051005701866, 39.1431244727104, 27.20436711465159, 27.964620513300744, 34.222507169169766, 52.99092685022662, 61.970989396495206, 72.92350599842688, 83.86159220049458, 89.84706632552609, 72.5932502746582, 6.248334213610619, 0.44878812626965586, 0.3032138312776243, 0.22161088102767545, 0.27351064126818414, 0.24689947405169088, 0.2114691486161563, 0.25018350912197945, 0.333736245069773, 0.24076378393557765, 0.16401484338266237, 0.107880647053882, 0.23162833865611787, 0.14609405500513895, 0.2253746863214239, 0.22314763808202362, 0.15290689023752368, 0.20395874436343872, 0.1611893885438481, 0.18327807827341944, 0.11802517568632481, 0.13073435984551907, 0.1819425265515043, 0.20686324415428026, 0.15241060315841629, 0.2076722636458374, 0.20256886168593363, 0.1519046480497045, 0.17765954347147098, 0.21397224897819184, 0.2865914393576884, 0.1109924808805508, 0.19529346256486832, 0.1949878088048389], [0.08962560685411577, 0.030647682574307247, 0.07030617175323349, 0.03683318181203739, 0.04600441488887995, 0.06625235621486941, 0.09322649588988674, 0.03569296335861568, 0.05259479350981213, 0.02030878785937544, 0.03266254552609978, 0.04562034053848155, 0.08974615844988054, 0.03527380218128524, 0.03196760993300667, 0.04725976486600215, 0.027004417385004705, 0.06663687106582426, 0.03940198953533846, 0.05840511459316458, 0.06535261659131897, 0.08139129547822861, 0.055120799900783654, 0.13098675517305253, 0.03276107592448112, 0.037332621342953176, 0.059316406822613174, 0.024888949851775845, 0.0573120603428012, 8.530978618129607, 62.81924116996027, 70.88836854504001, 72.19956198046285, 55.05699611479237, 48.87894538141067, 30.486631970251764, 83.24283830581173, 67.05768769787204, 23.33568242288405, 29.34754429324981, 37.642033407765055, 41.82131882636778, 39.67756702053932, 35.49239020193777, 3.2295097122269296, 0.18090432419651942, 0.054031032167615435, 0.04568732343614102, 0.04557553971666963, 0.090163032854757, 0.08007510279816005, 0.8648918773378096, 1.2576380059603722, 3.6831443252102023, 4.3367818190205485, 4.367545948874566, 1.9151604848523296, 6.710078081777019, 6.031548246260613, 3.8202998042106633, 5.794423808974605, 4.509047414025953, 4.995520845536263, 6.715944966962261, 8.270549908761057, 4.766899126191293, 13.921410556762451, 22.747372004293627, 21.530974411195327, 19.097100573201335, 15.239225933628699, 12.696657334604572, 14.70139543856344, 24.47861990621013, 23.004767740926436, 32.114517573387396, 37.537243366241455, 55.59497664051672, 57.2374338488425, 71.21202684217884, 55.80977347589309, 53.81298503568096, 69.90228468371977, 57.905213448309134, 42.94967882094845, 40.68334118012459, 46.472967440082186, 45.01233562346428, 40.80777052910098, 49.116672392814394, 43.022050472997854, 39.727965554883404, 50.05171052871212, 52.188245173423525, 37.43763085334532, 57.212750373348115, 60.636089155750895, 62.96648694622902, 67.44662207941856, 62.79285930818128, 67.060896196673, 68.42399827895626, 64.15927579326015, 60.75531744187879, 63.65880881586383, 61.7140898396892, 59.188962059636275, 59.18432189572243, 53.26631646002493, 48.17884937409432, 41.411956740963845, 30.113632217530284, 15.995193162272054, 6.601477947927291, 1.2568581897404887, 1.3359836729303485, 2.2820178058839615, 3.726984411478043, 4.421147588760623, 1.448614655002471, 1.1924825344354877, 0.2771629807689498, 0.2095762985728441, 0.13915005019835888, 0.0949433372325955, 0.07907169615669597, 0.05849578109900317, 0.6265187167352246, 11.023614464267608, 60.3272456507529, 30.90344459779801, 32.528678678697155, 55.16985447176042, 50.84321345052412, 46.81916367623114, 26.988489666292747, 17.801074943234845, 29.94174022828379, 49.3741681498866, 50.67507713071762, 59.09745708588631, 64.54468004165157, 30.36459722826558, 0.3866976805992665, 0.1081417144967183, 0.10108153245622113, 0.08554636485754483, 0.05893940346375589, 0.062316077716288075, 0.05589028925544793, 0.08836517005317635, 0.06772873787990502, 0.08957108437654474, 0.03968507434511858, 0.09292672568511579, 0.08478142606515078, 0.034466357000412486, 0.013589588681145782, 0.06676880672814385, 0.13326395152797624, 0.03417226733760007, 0.06700237161449848, 0.013127529452885351, 0.04437188152223826, 0.03516933460149073, 0.05511597354686069, 0.041432961400958805, 0.1414690749539483, 0.08948712880092283, 0.0139326466840782, 0.06642260393428226, 0.08096165804853363, 0.08531590262728353, 0.0224307882073786, 0.01885521646228529, 0.07085850582488122, 0.09193235888115822, 0.03277812521123598, 0.06989099806354893, 0.04102185563815217, 0.08235686503711247, 0.08581967438541113, 0.017748623523080063, 0.04346286457392477, 0.06452344898735324, 0.07215270412064369, 0.05142322290808924, 0.049010551564635775, 0.05785262347349237, 0.049168469098907326, 0.05810506476630127, 0.03824592838364263, 0.045521542009326725, 0.006717080466314069, 0.012849865672779421, 0.031158919859256957, 0.0845835761978261, 0.065262601260216, 0.03568809486985688, 0.047348696182692246, 0.04389560082927347, 0.04431239096447826, 0.04466131720091066, 0.06539689647334238, 0.05778704251673433, 13.611887501132104, 73.01716435340144, 81.49224527420537, 78.44039024845247, 65.17647189478721, 58.79753305066017, 37.745274113070586, 84.7720370754119, 54.40204658815938, 17.8427363980201, 29.110038895760816, 33.53187191870905, 39.37138680488833, 35.59803532015893, 29.260612803120768, 3.4171693844179956, 0.11643162087327051, 0.22636549847741283, 0.04348915671148608, 0.08245166841774218, 0.8227955910467333, 1.7217599336178073, 3.085643793306043, 3.430381888343442, 4.727349867743831, 5.799014943261301, 4.724991542677726, 6.6635200381279, 7.980876007387716, 7.748982050726491, 4.654685508820319, 5.631204670475376, 5.49555391073227, 5.012413513275885, 6.412634455388592, 7.749885176458667, 8.918780415288865, 16.019054901215338, 22.742502381724698, 19.671339488798573, 16.170350524687, 13.915653497942033, 12.862378454977467, 14.215640291090935, 23.35162489644943, 26.16461738463371, 34.72384099037417, 38.89982377329181, 56.62840743218699, 56.44443258162468, 72.43935215857722, 59.24768386348602, 57.54308454452023, 71.9773675549415, 60.82898347608505, 46.29716680895898, 45.601942385396654, 52.98215250815115, 53.760703763654156, 47.40385963070778, 53.669230168865575, 50.16185068315076, 46.03240682232765, 53.74525354754541, 56.67695068543958, 42.250343753445534, 63.03899588123445, 60.30908115448491, 65.37299048516059, 68.05804114187917, 64.99780008869787, 66.89785111335017, 67.87358776215585, 63.06319690519764, 61.159470619693884, 63.60330335555538, 61.76608477869342, 60.55561780929566, 61.79889148281467, 56.267588600035644, 54.580585033662864, 47.41933730340774, 34.986373070747625, 17.457324304888328, 9.344120275589729, 2.180308540982585, 1.2556352682652012, 2.5457800396027106, 3.157845557697358, 3.358649092335855, 3.7181210806292877, 2.805543171782648, 2.2342855026645045, 0.49057240027093124, 0.227002025611939, 0.045536944207044384, 0.10830637743516315, 0.04667948773731628, 0.5271791762882664, 10.596211437256107, 50.960096159288966, 34.1907085141828, 46.52059678108462, 56.81526130245578, 45.64008351295225, 41.51797448435138, 31.597837478883807, 31.77958050081807, 36.11394074655349, 56.12739916770689, 58.34967290201495, 67.66280743383592, 75.90603705375426, 47.05705150481194, 1.1990805739356627, 0.06086492332659903, 0.028633560812581452, 0.06869809191313482, 0.06441628094762564, 0.016203552499533664, 0.0650085818262831, 0.09195025469506941, 0.05737240125815715, 0.06538891383717138, 0.10369317981624797, 0.05686109885573388, 0.052104336359808524, 0.04037964030078823, 0.006888686076572706, 0.07954853992428511, 0.07647146350674092, 0.05265512293384922, 0.045310005981234774, 0.03157012138305412, 0.06355504490314953, 0.03318140538589608, 0.042119372350674485, 0.03103674798753233, 0.06516241994235786, 0.10039877957634388, 0.10285706379480901, 0.08544948537864032, 0.061583747456391016, 0.031490046042768706, 0.07154094460870951, 0.05683957944594084, 0.1354749732080006, 0.22956388491776683, 0.11288419711373507, 0.180259017694381, 0.09225915666789779, 0.22765137705831762, 0.15037090938177802, 0.22482742375183493, 0.23945199626107372, 0.12491825096789869, 0.2467921298117407, 0.12535241597722616, 0.23860625051442655, 0.20100670115601635, 0.17832882852563936, 0.08641217444692889, 0.15341701286454357, 0.0935210950011688, 0.10952181423143034, 0.11974598536448133, 0.1852906218940212, 0.20285756958107795, 0.16809067628797025, 0.13806490197537408, 0.30926607909702486, 0.12513907581207254, 0.14875192044963761, 0.17335676467947422, 0.19886801349780253, 0.2491934936974318, 19.597138051063784, 86.81665097513508, 91.66211174380396, 90.10995141921505, 75.84284767027825, 69.66551473063808, 43.51325281204716, 92.87433593503891, 73.51443459910732, 33.1156260736527, 43.237631782408684, 51.509867329751295, 55.33753579662692, 52.433609039552756, 45.16737514926542, 4.876295501186002, 0.4928380286981983, 0.3082344650981888, 0.25170701285523756, 0.1038103069989912, 0.8108235979753157, 1.5323717219214288, 3.2314074039459233, 5.189107954502106, 9.76244007387469, 13.208726682970601, 10.912978130002177, 11.60058040772715, 16.454386018937637, 13.85918019279357, 10.877812120222277, 13.832350200222386, 10.85437595844269, 14.05184897684282, 13.707523711266058, 13.494955762740105, 10.15665396567314, 18.545250546547678, 28.729831787847704, 28.61542605584668, 24.34246463160361, 20.35126666868887, 16.58173949487748, 18.631203405318722, 29.26654342682131, 28.93851560931052, 39.61443647261589, 43.49544525146485, 60.36582216139763, 57.61540520575739, 70.45835125830867, 64.8849456541, 62.74657141777777, 77.59987338896721, 62.46501976443876, 52.145620776760964, 49.625933324137044, 56.3979721069336, 58.184721546788374, 53.05370438483454, 61.11407702968967, 56.284384189113496, 50.651793941374756, 58.06168071685299, 62.75187446225075, 43.8853092347422, 61.53447274238833, 61.080077925036036, 65.00792764848279, 71.68876740240282, 64.96459722518921, 68.69763066691738, 70.04600032683342, 65.0629702691109, 64.55586271901285, 68.30561330241542, 66.73890882922758, 64.54247174724456, 67.7128254982733, 62.783488765839614, 59.82697871423537, 54.63357625469085, 39.0145177995005, 21.206045266120665, 10.755102730566456, 5.050787041264196, 5.657274213529402, 7.641789557472353, 11.109911511021277, 11.490027423827879, 7.43312289637904, 4.510743348829208, 1.702231433122389, 0.5766945644732445, 0.38804715979964505, 0.3247941297388846, 0.42564366012811666, 0.17597531449169884, 1.400824006526701, 17.069258728334983, 78.06747482668969, 43.865591479885964, 50.52084169080181, 73.48879014292072, 71.39578204001151, 65.25514679570352, 39.832524176566835, 29.449812250752604, 43.60380464984525, 65.97647067039244, 70.11023306077527, 79.6628910495389, 87.31484690020162, 58.03524394189158, 2.2953739666169692, 0.1613900729364926, 0.2377808520630483, 0.22478072303197077, 0.20290983209927238, 0.1597828817583861, 0.2071459918853737, 0.25042703315134973, 0.14752878446973142, 0.16642080379589913, 0.29564852916425277, 0.1535566400496229, 0.15415454103100687, 0.13271391572010133, 0.13734212866233242, 0.22675460985591336, 0.14932593480954248, 0.1811536858158727, 0.2065096026466739, 0.22339241849558972, 0.16323046127875007, 0.1520056797251586, 0.11731086764484645, 0.22005883285835867, 0.2672304669695516, 0.23919960093354029, 0.23577581610410447, 0.1974585649347113, 0.19917699207942333, 0.10375367777962839, 0.1788960553465351, 0.16504487924037442, 0.3239072450707036], [0.1302491350760383, 0.027989441746725675, 0.11273859444284633, 0.09286411331906434, 0.07147116932056605, 0.007248061752292298, 0.05772447611595835, 0.059940308828147194, 0.0742121093395737, 0.015224110045950982, 0.09894435399121816, 0.05843244094942367, 0.02865092228016546, 0.005230235476647654, 0.14428165951563468, 0.038292816795048215, 0.08260048099703367, 0.07351539833771606, 0.09286674100064463, 0.04593216513674106, 0.016709134140382373, 0.04900566392367886, 0.01431184871527817, 0.11285069608880628, 0.03416566365969277, 0.031199330997262752, 0.07998340207362369, 0.06041214238071154, 9.68717175145303, 45.34107731234643, 64.78798074107017, 69.92938041687012, 51.65325349377048, 39.9876735287328, 32.28082606869359, 29.262118993266938, 61.21167736668741, 61.184962103443766, 35.502019620710804, 34.939983198719645, 46.17849549939556, 44.436767024378625, 33.653398713757916, 3.8665570510971934, 0.3901072315150692, 0.019155019225793022, 0.01456817503147308, 0.024247353130410758, 0.31076074728081304, 0.77986984603828, 0.7675084351531921, 2.3494205503694476, 2.591777429465325, 2.053895085569351, 4.303550518328144, 4.970741762268928, 3.175512403249741, 2.0028534050910705, 4.498767372100584, 4.383242293711632, 6.002106445450937, 7.39908064565351, 12.166059690137065, 15.19316848247282, 25.097420869335053, 37.13884038309897, 38.04131892419631, 47.92818638586229, 46.888632774353034, 41.17221363129155, 35.11363437098842, 35.57701141603532, 38.88327137116463, 47.67896682985368, 53.78975675952051, 59.24064320902671, 63.06219277843353, 63.26278278904577, 67.24871497000417, 70.25581575209095, 68.47534994925222, 68.42402965791764, 68.51892748186665, 69.14063884365943, 60.202992808434274, 31.833012988490445, 41.40342950820923, 44.610308370282574, 39.790578349944084, 41.671782385918405, 40.231484136273785, 60.666985665598226, 67.15083614472421, 63.52195732055172, 66.61558166626962, 66.19935543306413, 64.4458794593811, 66.95137577672159, 65.78467853607671, 66.69130694481635, 65.00446419562063, 64.19876229378485, 61.79296085911413, 64.1804212908591, 58.57439333392728, 56.194942382074174, 57.05237250174246, 55.71774290454004, 60.75957321351575, 60.10773020405924, 56.99904395687965, 54.59032035643055, 45.08903364981375, 34.30675183573077, 20.010565673151326, 8.923604930600813, 6.291271909590691, 2.3815682963017495, 0.7394616498101143, 0.41550791852416535, 1.7601742787707237, 1.3467844094960921, 0.4519100877786837, 0.29362378942389644, 0.1853239620404859, 0.03698493616895811, 0.1010294461382493, 0.10050519684990568, 0.3412397392094136, 6.2483381359807915, 35.29687181595833, 40.77928235453945, 37.88650689586517, 40.95887591761928, 40.15170312696888, 40.60689418546615, 32.48313996099657, 36.95865061975295, 37.78909091026553, 52.94120296355217, 55.47189658687961, 63.34130079515519, 64.35325661013204, 17.00766182714893, 0.6764560048618625, 0.1264483430573056, 0.12761375431211727, 0.06812434568400345, 0.08603598697171097, 0.157483744645311, 0.008322688236442066, 0.05757477870511432, 0.02313641455745505, 0.019926728320217902, 0.020947672629488573, 0.05021466941182172, 0.08144721989670108, 0.05544386683933197, 0.041093132458627224, 0.028682672794187264, 0.037056707116144325, 0.03233945560491374, 0.0525365861493253, 0.0128502736145991, 0.043234267767759106, 0.06314974991724857, 0.03315597892768922, 0.03353952467741986, 0.07302160870524184, 0.023226228790477883, 0.012204225922393943, 0.019055642300255356, 0.055535353059249545, 0.029439598306893345, 0.12231263271983593, 0.04332289264927949, 0.03857364547589133, 0.029233654720648646, 0.029220539295384963, 0.057222849404018734, 0.04757890560393853, 0.0360237448025615, 0.01832822649439256, 0.1430972416194216, 0.036335324252685236, 0.08497024375584819, 0.055423753200879985, 0.050370192921329895, 0.020310436863632455, 0.05500246229912004, 0.06223133690054379, 0.025873300056123448, 0.05196052250422297, 0.05400299334958677, 0.026754105816625302, 0.05891400764906599, 0.020288639746966864, 0.016336872865776383, 0.08947868651199727, 0.05806740005350402, 0.026712321466015234, 0.0312713930578602, 0.017862822334732742, 0.02612741142060728, 14.458599744304536, 56.45748622955815, 76.7570266415996, 77.43210577195691, 62.27713823318482, 50.47573051145, 47.988645799698375, 32.05567417606231, 65.43453247316423, 67.47360798620409, 34.45951246446179, 31.769543155547115, 40.10773335733722, 42.751473611400975, 27.977854590262137, 3.414468097109949, 0.1352738291626015, 0.03466268235276784, 0.07878779163283688, 0.5570407319934138, 1.490757213004174, 2.920084715850892, 3.023443582557863, 5.6127871813312655, 5.194858639470993, 5.362403171677744, 5.9665021108042815, 7.691985109160024, 5.143193669857518, 4.226747078280296, 4.924163126176404, 5.72928745900431, 5.498151010082615, 9.524896433276515, 12.482770489108178, 17.873317157068563, 27.99908834118997, 38.20800396703905, 39.23413915018882, 48.51089762103174, 46.517505953388834, 42.18827224546864, 36.94076853413736, 35.72002103251796, 39.79671685926376, 47.307577210087935, 55.320697061477176, 60.348610801081506, 65.95574486640193, 68.25878020255797, 67.46047589086717, 69.99107145494031, 70.18778616382231, 70.57641460049537, 70.01519403150006, 69.03910436937886, 62.66216201166954, 38.268000541194795, 46.90952724026096, 50.72039619568856, 45.04883327791768, 47.58594389884703, 48.32974295462332, 61.63786642013058, 68.57450746720838, 64.53494864125406, 67.44043257928664, 66.65299323297316, 64.07697269993444, 67.0393310054656, 65.92913550715294, 67.70399232064524, 64.92015677113687, 66.13695836836293, 62.98645573277628, 65.52364872347924, 62.7948401051183, 61.013009317459606, 61.56459262294155, 61.6416750415679, 67.31417932818013, 69.00985917737408, 64.98555837139007, 62.5269579118298, 51.43959022337391, 40.65505304644185, 24.357579485062633, 11.247017960394583, 6.059753029577195, 2.3324876783355593, 1.4474607427274029, 3.5536985099315648, 3.6460078147149857, 2.6363826230649026, 2.6881682055611766, 1.2613961268817226, 0.856567565952578, 0.14311518339860824, 0.04111333802763013, 0.08336811641892118, 0.15601676287910632, 6.608159705515831, 32.69664437540116, 36.691297946437714, 35.244598388671875, 34.05357853058846, 32.330718617285456, 39.46921463935606, 30.353518493713874, 44.089954976112615, 50.25303794491676, 60.88337106089438, 66.45452914699432, 68.64021501233502, 82.45949391395816, 32.017340852368264, 0.22817939549924868, 0.057334805493273085, 0.13767332379375735, 0.1377864596584151, 0.11313555822257074, 0.16668174866466753, 0.02808107543856867, 0.11904802563930712, 0.04385435848586983, 0.065392782581189, 0.05341159645467997, 0.08105310596405499, 0.04960760218842376, 0.14137089312557252, 0.05379105512533457, 0.08016499555519513, 0.06170464379172172, 0.03916293179856674, 0.06324896596432214, 0.05161597446027783, 0.06654335471290736, 0.026022099228876255, 0.03026091925529463, 0.027177369394790263, 0.12231565876713685, 0.009427581418065295, 0.005952234083275882, 0.06181835039188305, 0.03455642595767014, 0.0405971939495254, 0.03192366329923032, 0.01883959018384978, 0.17213534473651843, 0.16444477192576856, 0.24078932530697317, 0.11983062275835585, 0.24326473925142522, 0.2136157116582317, 0.11908695822761906, 0.3109140261527031, 0.2043132132460033, 0.14081422299627336, 0.21104737124856443, 0.11037392616872826, 0.13136563161688466, 0.13072043236705566, 0.251188509226326, 0.12520767898569185, 0.13839370691247527, 0.17025934862754039, 0.1816596409245845, 0.10944496029086652, 0.11594897015921532, 0.17009341398314123, 0.16560243803166574, 0.16822005321662273, 0.13737382938063916, 0.16132058876176036, 0.09204696563463058, 0.19155470834624386, 19.579122604862338, 71.89128721913984, 84.20645483078496, 86.92257850400864, 73.92060387519099, 58.39618436751827, 48.03776956373646, 43.629045101904104, 68.71265334467735, 70.25312500615274, 48.15591919806696, 46.54076953088084, 61.8816456487102, 56.710957634833555, 41.64418851175616, 5.460660995975618, 0.7010760482761168, 0.18050206674923822, 0.16779334224279852, 0.6886557405514102, 2.0728696738519976, 3.52287971204327, 3.8768613626880035, 8.061019835933562, 11.981463143902442, 8.856282349555723, 11.615703105926515, 13.07643102061364, 10.12765980535938, 8.541854370024897, 12.549900874014824, 12.950274848168897, 14.796147154223535, 15.821022275955448, 18.356931671019524, 20.197154783433486, 32.74071024310204, 43.78198223729288, 46.764097521382, 51.240851571483, 47.87737600265011, 45.1198987806997, 39.698492865408625, 40.30635826049313, 44.64701783272528, 50.89918959525324, 58.25599101281936, 64.15151342268913, 67.25404939343854, 69.90979994496992, 68.06067697463497, 71.59893728071644, 72.96826808683335, 71.60598185754591, 74.12531237448417, 69.02841198828914, 64.8590305543715, 42.11177033762778, 52.13320255279542, 55.97686252286358, 49.57946500470562, 53.46818908568352, 52.98121898405014, 64.60550031354352, 68.80701772628292, 67.87077150037213, 66.68059102950558, 65.43548953148627, 64.6939968293713, 67.65498622771233, 67.09697415751796, 68.43596150798183, 67.19581788586032, 66.8883825117542, 63.95783855069069, 64.82483140883907, 64.67701688889535, 63.26988620142784, 61.942752253624704, 62.34630530880344, 70.8823908528974, 70.66498956372662, 68.9429670764554, 65.75844180199408, 54.39794378895914, 43.4656273934149, 25.706411984659013, 13.807292138376544, 13.02905761426495, 9.438742553034137, 8.625994113183792, 6.522309808961808, 5.483432316010998, 5.775940129833837, 2.7752440879421854, 0.8621293029958202, 0.6338070320986933, 0.1941421090234672, 0.18905914628938322, 0.16089308105649489, 0.6946089178804429, 8.615938136654517, 48.71876755068379, 53.6565177671371, 52.26029911348897, 56.59692256681381, 56.19327145238077, 59.51001590298068, 43.28041307387814, 47.836414690940614, 54.57007308160105, 70.84937234078684, 77.17864221142185, 81.71429064966019, 93.2655688255064, 43.530346501258116, 0.964067229820836, 0.22710765381493878, 0.3117838117384142, 0.320486968923961, 0.1674054719267353, 0.30441539422158276, 0.15877749861007737, 0.20330972999574679, 0.10403627229313697, 0.19386947365297427, 0.22739769470307136, 0.25302935722133807, 0.17477836339704453, 0.25057332530137033, 0.20475181390441236, 0.1892747847183097, 0.170812341534803, 0.18701957508681283, 0.1553411346169249, 0.15763481718397912, 0.3330670519461555, 0.13511123466155223, 0.11200135738979425, 0.06599633729145413, 0.22205933357679078, 0.12016292871727098, 0.10188570261121759, 0.22377501812673387, 0.16786402151469262, 0.10910473298281433, 0.28777103089997846, 0.12011034444214837], [0.025934361094128222, 0.02579362691199828, 0.03599385205175608, 0.019195729138089285, 0.03498605189604625, 0.03754253709508527, 0.02782328302160867, 0.0659323689497767, 0.014094128442417472, 0.027730546163154707, 0.013405658631405283, 0.035608272338586475, 0.04493163132499303, 0.04990235068685105, 0.02709806397286875, 0.02760378925520326, 0.07103534956132213, 0.06748570414680628, 0.03329849043380349, 0.05969267856750277, 0.021483692858788758, 0.037475469927754135, 0.062403741157463485, 0.041003201397195946, 0.027324879624610467, 0.05110955586837185, 0.12863201539843314, 3.6180104267212654, 44.02080358997468, 69.14357277654833, 73.85547684084985, 62.28417104290378, 48.72353323044316, 33.598724795926, 21.49572407045672, 33.90082182422761, 29.43240281074278, 21.543641705666822, 27.585986275826734, 35.841747868445616, 44.33876268325314, 26.64787888526917, 2.4618425436558264, 0.04919811287113736, 0.01235300881577836, 0.11003098690942412, 0.22062924660501942, 0.29135733362167116, 0.6552073611847816, 1.2307094638386082, 2.4562791518626677, 3.9160284351918007, 2.179236263036728, 2.8082817216073317, 2.8552790707157505, 2.4948706165436776, 3.476081423221096, 8.871219715764447, 12.243463743117548, 13.06756450283912, 15.92660463625385, 25.316067511035552, 27.768250972993915, 38.97879677434122, 43.970561950437485, 51.74147936605638, 56.203673578077755, 59.944873394504675, 62.83053367368637, 61.19663115470641, 59.717254331035, 60.250696674469985, 65.26936538757818, 69.7197924890826, 68.68834249434933, 69.74956327869047, 69.82157015031385, 67.3736346152521, 67.1819091612293, 64.24421079697149, 69.52141469524753, 70.37528330279936, 64.95605822532409, 63.91311960835611, 63.01655207910846, 53.09552861798195, 29.398607669338105, 41.72024719176754, 44.203986121762185, 34.12356930394327, 56.36576552544871, 68.67722649728098, 61.866387628739886, 64.50046316269906, 64.30613325488183, 63.205461271347545, 62.90936939177975, 64.8648670411879, 62.488593209174375, 61.33169797159011, 62.29817390441895, 64.19097638899281, 65.16083340491018, 62.68904201446041, 60.241514405896595, 60.13723035012523, 69.83219977348082, 72.2936596408967, 68.49383215750417, 67.12257939000284, 68.45480457428964, 65.36999771671911, 59.9994178741209, 55.28692545429353, 48.0881602533402, 38.82409065000473, 22.082549871936923, 13.960170438212733, 5.129882616381492, 2.9333683127357117, 1.6454184752318168, 3.059256293119923, 1.1805993462762525, 0.5186819128932492, 0.36741316378597294, 0.13844287443545558, 0.08812333907811873, 0.02630678324719831, 0.029218978391239242, 0.08447607107941182, 4.86539670536595, 35.847152894543065, 51.24218125497141, 51.4933894526574, 51.323150742438536, 56.92140456168883, 55.7839995814908, 11.972211253258491, 18.94129030166134, 41.04865112612325, 50.21614020870578, 57.579386080465014, 60.09522568794989, 51.68088266926428, 10.62802185935359, 0.31716263762885527, 0.13147389516234398, 0.031176553288054083, 0.20311754917906177, 0.05636560850806775, 0.026740954002185215, 0.04007635375244483, 0.028492956865398635, 0.02705658222698877, 0.024646243621264736, 0.021157885240691326, 0.06381998109000345, 0.05855259800990743, 0.021824284058604992, 0.04668367057738285, 0.09534603901087277, 0.04100893173486956, 0.036768309486609314, 0.04198963919113721, 0.04022306725082379, 0.03158807656877945, 0.032764105802221645, 0.0753975537936053, 0.04891053495568134, 0.04376991261397639, 0.025240727850506385, 0.06108417386008848, 0.09250404433377328, 0.04907632404337487, 0.0677285386970447, 0.03334795673107428, 0.07148264531767176, 0.08124707942648281, 0.060613615843918056, 0.024608352912529826, 0.04064597842854358, 0.02635747336992814, 0.047895790212937904, 0.0703170578626375, 0.024153884657989108, 0.010127223663843207, 0.10254871340528612, 0.012584974493591056, 0.025130271378363815, 0.0463375099183571, 0.021696987058666926, 0.08534931172166141, 0.04522483232581327, 0.0077069038900757034, 0.046553466273772146, 0.0311688426130962, 0.02120372985730008, 0.06839274458827511, 0.05506157747379715, 0.0640718937821446, 0.0500930184798856, 0.07312150657056801, 0.1152635895977578, 5.737769584501944, 56.16307704679428, 79.20211453591624, 83.74482324046474, 71.39676263255458, 59.3832213647904, 42.41602074715399, 32.75615849802571, 41.708664432648696, 42.05614720621417, 36.89484150178971, 36.81704913416217, 43.714780269130586, 45.773161688158595, 23.34817517188288, 1.8442957583935031, 0.03452253422789997, 0.017626290772891334, 0.27827776127284576, 1.1632255753201823, 1.811772200369066, 1.468408773502996, 3.5490458434627907, 9.06644098220333, 7.28031127683578, 4.0364172525944255, 5.222927610720358, 4.085740322066892, 3.8377881819202058, 3.7906790452618755, 7.498521064558338, 10.390157564993828, 13.974918550060643, 18.192256842890096, 26.204586336689612, 29.40997469809748, 38.70440736893685, 46.00442463351835, 57.82445576883132, 63.359779081036976, 63.50721313107399, 62.80165718447778, 61.92670191487959, 61.68583700733801, 61.28147594390377, 66.26916577739101, 71.48718110976681, 69.70004727763515, 71.5726338663409, 71.17061445789953, 68.96026472891532, 68.5613126139487, 66.53988776668426, 71.31064307305121, 71.37806861631333, 65.23304423978253, 64.2292312652834, 66.29957983570715, 53.338390011941236, 35.44359591699416, 47.16362230239376, 49.102140011325965, 42.69623487226425, 59.461284375959835, 68.74160828128939, 63.38763967637093, 67.01397680467176, 65.67103570507419, 64.23094926341888, 62.89957523345948, 66.16552106795773, 63.27552264736545, 63.66390789708784, 62.85668019325503, 65.3513115452182, 65.3091029197939, 62.0409409461483, 62.016861515660445, 61.98699658916843, 70.54667518984887, 73.64021716579315, 71.12248697588521, 70.79755783081055, 71.58757025195708, 70.0993759401383, 64.25435012386691, 59.96128459130565, 52.45543702956169, 43.07076238816784, 26.295834395193285, 15.584388625237251, 5.928674772862466, 2.823159516819062, 0.16137551726593127, 3.080488573158941, 2.94248414616431, 2.251663318564815, 1.5258057968270395, 0.9949802258802999, 0.07665434401602515, 0.04845575068987185, 0.04235623524554315, 0.062179162482460665, 5.455025040334271, 29.104971193498184, 40.513306433154696, 47.47940840259675, 48.338556520400516, 47.981212908221835, 44.46155640386766, 18.869844328972604, 32.33092258053441, 53.04343561972342, 57.61542481760825, 67.98250413710072, 66.02280955160818, 70.50797708572881, 24.324611963764315, 0.5048201034866995, 0.1349502642669024, 0.03694955056773559, 0.1018322449958613, 0.016503516141505494, 0.022610774819528865, 0.056724716053013845, 0.029183295930946068, 0.0985874719316921, 0.03107783136769168, 0.0873244013036451, 0.036528956805986744, 0.012436987374037986, 0.02564777526253414, 0.01439183499784239, 0.029773260241434462, 0.006949375561934206, 0.07137924643053163, 0.0737549770142763, 0.022207117346566052, 0.06496512165833866, 0.05876085135124384, 0.009396009019485885, 0.040108862693511674, 0.03618344732169663, 0.0905629460729899, 0.050231086676039045, 0.06070587198219954, 0.0256508645120888, 0.02918936334730637, 0.027063402324734677, 0.25683784076283056, 0.21566328081873157, 0.16070060912639866, 0.056228946083255356, 0.12241982374220126, 0.10588940067757523, 0.15057482666546299, 0.1462979722888239, 0.12894347610492862, 0.174392975205856, 0.23721912575344886, 0.1442319250875904, 0.13698050451855506, 0.14243786974299338, 0.09155961880159956, 0.17011734656989577, 0.15609698760653698, 0.11249422771675933, 0.09372811494094711, 0.24694926976676912, 0.05283945134931034, 0.23215153074312597, 0.12086581438779832, 0.19927843744235657, 0.12602663463762692, 0.2013625489968446, 0.3026325237606802, 8.056610601563609, 69.166942258035, 87.78968903326219, 92.50935154576456, 82.6583973053963, 67.32494231193297, 48.02293908211493, 33.6625535257401, 47.89541890544277, 41.166479126099624, 32.04398551294881, 39.66152844890472, 49.03864860534669, 56.61022332406814, 34.54506328029018, 3.7962696484981047, 0.19731929015007713, 0.17397462991216492, 0.3258642626385535, 1.0220477669950456, 1.5498918463145535, 3.377241372100769, 4.023221663890347, 9.142592818506303, 11.107693410688832, 9.579520340888731, 11.26133559211608, 9.338298497661468, 8.043223061869222, 9.985194417738146, 15.692082201280902, 18.946830649529737, 18.76429138645049, 21.332424033072687, 33.161305996679495, 32.77516238151058, 47.410731623249674, 53.132422431822754, 58.99227088497531, 64.21859771974626, 68.21250407926499, 68.02692890167236, 65.2896087400375, 61.96413701580417, 63.447353839874275, 69.8620568552325, 74.01794925812753, 72.41222504646548, 75.15933544405046, 74.480224117156, 71.09656010904621, 70.92479167446014, 67.57125931401407, 71.53153527167537, 73.27870799649146, 66.82550691789197, 68.18587118579497, 66.5854892423076, 58.611526412348596, 40.246706854912546, 51.68561304769209, 54.852534724820046, 47.73298178949664, 62.69046975720314, 67.14635679798742, 66.32244725381175, 65.68474046645626, 66.5298386543028, 64.68099809462025, 61.703781850876354, 68.51824498945668, 64.60209569623395, 63.76356355605587, 64.29384839150214, 65.31165246040591, 63.83608425817182, 63.77067481317828, 61.9040306152836, 60.59281364563973, 69.05561754780432, 77.35521947183918, 74.35728134647493, 73.30260307558122, 76.08651315012287, 73.2042771001016, 65.9364781841155, 62.52094099598547, 52.864218604180124, 45.01949002665859, 30.680397056764175, 20.768116558751753, 9.153090061679963, 9.48066484543585, 7.341202151390815, 9.703979107641405, 5.0315983160849544, 2.886880381453422, 1.3917711761689957, 0.6730911628373208, 0.33273539716197603, 0.18983079601199399, 0.1508594436510917, 0.33803626594524233, 7.747100783932594, 47.73444483357091, 65.87821529757592, 68.98062967484998, 63.27721318890972, 75.02697114021548, 73.59982459775864, 21.826128844291937, 32.02139658312644, 57.65753146140807, 67.42719850232525, 77.82562148186469, 77.45911521296348, 83.1945147052888, 31.064330416340983, 0.9710138699700757, 0.32080281165338337, 0.3287272251421406, 0.4260222301367791, 0.15310751334313424, 0.22955398706178512, 0.1302687162833829, 0.1296490737267079, 0.21134305054381972, 0.1435149280774978, 0.23927861524205055, 0.08510027952011555, 0.12716982168175522, 0.11159689360929113, 0.12397195618118971, 0.16352307622230824, 0.18179896167449414, 0.17670708167697155, 0.21712612571014514, 0.17290656544989155, 0.14422172079643897, 0.1337480118438121, 0.16786647299605031, 0.23468337472408052, 0.07896135651296185, 0.11644984610498914, 0.10800797852777666, 0.23718223095901553, 0.11095265196936746, 0.19467132256156017, 0.12646281445819524], [0.055560024920851, 0.022682888591061198, 0.0368224450897786, 0.05064921363467171, 0.030261746630252852, 0.007802149686481684, 0.04416154059130819, 0.07309196622020776, 0.04879927983687771, 0.06747199117296165, 0.07957749038694367, 0.031281334963897546, 0.012005678915058174, 0.036117908499774434, 0.016895389266973062, 0.04255908766701337, 0.01898756006642455, 0.06151257788822536, 0.023195749982410384, 0.03275267193995176, 0.029074226077946446, 0.01951900866603659, 0.01620368656492041, 0.04404772673883746, 0.03641287916369977, 0.06612443485327306, 0.23187226105120876, 26.113585387506795, 70.48740817654517, 70.67569763429704, 70.02131292896887, 53.657031597629675, 37.843756983357096, 29.724413464146277, 26.6890049365259, 17.86773366312827, 25.00953624325414, 32.25174365505096, 28.793746809805597, 45.95501453645768, 35.856586194807484, 3.994194163430122, 0.01890363896475925, 0.13819679167241822, 0.10029656812548639, 0.10355230390785203, 0.7294537223154499, 0.9328087587510386, 0.6309413116785788, 3.6009696895076386, 2.4075321805092598, 6.456885164783848, 3.077309246986143, 3.379405539843344, 4.9297020031559855, 13.588447416982344, 18.53335595900013, 19.244079628298362, 25.08923488278543, 31.98154922454588, 38.47030854994251, 41.32938300409625, 44.54161982382498, 54.51021379040134, 57.281670339645885, 63.071433882559504, 66.27616328577842, 67.11557403687509, 62.75892688382057, 64.23771535196613, 61.37602075453728, 63.83152254166142, 66.66696471552696, 65.82938178893059, 61.55929350083875, 67.67055019255608, 63.71121952610632, 64.89047619604295, 67.65444494062855, 68.6340098227224, 66.05419635772705, 63.706379321313676, 60.55917539904195, 67.25339827998992, 62.36823135806669, 63.76934905206004, 42.52121087043516, 35.3222809299346, 33.394196725660755, 37.8052746095965, 65.62816419909078, 58.815120958512836, 62.37947679335072, 60.11766949007588, 62.46370184806086, 62.697055416722456, 64.57608645962131, 60.54931456042875, 61.58841709936819, 61.50542759126233, 62.314698849954915, 63.30527382512247, 62.31222775674636, 59.12160319666709, 63.65592979615735, 65.78091306071128, 69.64823276765885, 67.50984284185594, 66.7678637658396, 65.75415465139574, 66.24837721547773, 66.62052385268673, 69.9131888727988, 73.88503582246842, 68.88599857207268, 62.51646164924868, 54.21779717168501, 35.28335140597436, 19.923002681424542, 9.325092857883824, 4.981836676597595, 1.6211522418645121, 4.454936846610039, 3.252343299888796, 1.3692389981400583, 0.38059153083351355, 0.05326610869697986, 0.07144797983909808, 0.019678307073791663, 0.055418930677396644, 0.2155885259590803, 2.296228307870127, 18.972263297727032, 39.069603566200506, 43.78827764141945, 62.39503683582429, 54.74083738942301, 42.05031464176793, 22.22615961105593, 25.134167594294397, 46.01262238717849, 49.543763591397195, 60.281757923864554, 56.49253260704779, 53.18797103820309, 5.747004805072661, 0.5494839181342434, 0.07437275797729531, 0.0654817177283187, 0.02965176061186339, 0.03234967138738402, 0.06491356394103458, 0.04750237342030291, 0.056800053139487584, 0.05672398826948578, 0.03951941932281179, 0.042881530243903405, 0.05872848796688261, 0.02757092216803182, 0.025222299605487816, 0.04823138268904821, 0.055218253945631374, 0.035691936800797144, 0.05234859200314649, 0.03419737969975799, 0.08730314236374632, 0.011758410630957975, 0.08080234240380027, 0.04493903173434158, 0.02132782077927503, 0.033203039708877766, 0.017066083232601805, 0.02376943875494744, 0.042057223467817234, 0.03553708744866233, 0.03795721282761905, 0.019639926068785212, 0.051205807155178445, 0.022478825750670606, 0.04408890013432792, 0.04037796639867368, 0.03542984280014231, 0.03290533411106275, 0.04564217021388393, 0.014157943566510034, 0.03847529510817221, 0.03371295166171847, 0.10789084368415418, 0.07547175706995111, 0.028309643516437184, 0.04380059443534382, 0.029360880857453715, 0.010127786738467554, 0.020789917888900927, 0.08743006015016187, 0.05138523260792417, 0.04428237563960495, 0.04202685574249875, 0.09430296433668944, 0.05773894751684801, 0.049638747492985386, 0.057437089722483396, 0.7239211579003643, 35.233168601989746, 82.09665898353823, 79.75921661623063, 74.2795007459579, 62.830231651183105, 50.3901679285111, 39.20592554153935, 27.28675061656583, 26.884672372571885, 33.53803003987959, 34.152033944283765, 36.66167228452621, 38.31178203705819, 28.947613546925208, 3.4102745930994716, 0.02679422584121987, 0.060331526948439504, 0.215379613782129, 0.8164408610713098, 1.887944996837647, 2.902420812076138, 4.1927729787365084, 5.729499757289887, 6.675492092486351, 6.860073929832828, 4.612094942600497, 3.6467783153057103, 4.837516498181128, 11.595300897475212, 18.445520362546368, 20.48854374116467, 26.787760411539388, 33.50061847317603, 38.56533188973704, 43.59776027740971, 50.87096421949325, 59.16012871649958, 64.1996918955157, 66.66041435733919, 69.64816216499575, 72.26566960734706, 67.31980400700724, 67.4998172636955, 64.6706626492162, 65.65457351746099, 69.82019732075354, 67.26369842406243, 65.4978826738173, 68.71576770659416, 65.4399492663722, 66.34214539681712, 69.3184712625319, 68.76550336037913, 66.71211904095065, 64.9857113438268, 61.75388228508734, 67.47942093879946, 64.30255605328468, 68.07954357516381, 45.231862837268466, 39.73590835448235, 39.152114545145345, 42.27668246915264, 64.59210934177523, 58.04958804961174, 63.320135685705374, 61.824245683608524, 61.85812711715699, 61.44879641071443, 65.74008118721747, 60.2676962267968, 62.00338817411854, 61.48357998940253, 62.1313908023219, 63.65590233956615, 62.5537790790681, 59.23243368825605, 63.51039025091357, 67.09568762010144, 71.74810501836961, 69.89888791115054, 69.37294513948503, 69.80306440784086, 68.14250546116983, 68.769802278088, 72.52681316867952, 75.36037260486235, 69.55961073598554, 64.42741686298002, 57.15271065312048, 39.23540999812465, 23.49472276626095, 9.641224126661978, 4.975055879162205, 0.41213468017597354, 2.0994165203263684, 2.3050222617964593, 4.6032823574158455, 2.1391962180214543, 0.8096603700710882, 0.14915051599664075, 0.01128549210637087, 0.06704011676652778, 0.04581121900569528, 1.958160448458887, 18.280841612046768, 42.7977301228431, 54.48812300159086, 65.00318550294446, 46.83642602735951, 30.991896006368826, 25.595253975160663, 35.9604387898599, 59.27051990262924, 55.51873753147741, 70.20105161974507, 64.22392822081044, 72.60857889729162, 13.873392901112958, 0.49437167543557387, 0.09315020119350764, 0.044216913426475185, 0.1301477663218975, 0.04609373691041143, 0.0668306147018748, 0.08189423986139797, 0.0236481421386763, 0.028930854638137167, 0.03442650893703103, 0.05026315511654943, 0.040653934251637235, 0.034828299070678415, 0.011436401851355069, 0.037703702842155774, 0.09991583008799823, 0.008479808081662463, 0.03786979070413978, 0.07163911111532681, 0.03444741164604503, 0.03847220394339773, 0.060406454177873756, 0.07570483166003421, 0.01792964818436773, 0.025972870418861992, 0.053144515221638065, 0.040474527951089606, 0.03768564998022011, 0.029889929686642946, 0.02385420255332945, 0.14495135825728217, 0.18774017271014953, 0.21523116126416192, 0.15163279408889432, 0.22268233159857415, 0.07427265326822959, 0.11178708259737301, 0.16797688158769764, 0.09930095259821224, 0.15249586874438872, 0.12449048279273896, 0.2502421301699454, 0.21177719257050948, 0.15452279949620848, 0.09744285230314541, 0.14443545932731322, 0.05801996005879295, 0.09318182530302195, 0.1777853504303963, 0.19886801349780253, 0.11363722323890656, 0.12839910934769339, 0.13005332300259223, 0.1605519267820543, 0.23652613793890323, 0.166725997903174, 1.6039059479390423, 51.049432062333636, 91.74167310037922, 89.64027897004159, 84.4868415401828, 69.93939030554988, 56.68169283097791, 41.07059286486718, 37.77870055167906, 26.095632699228105, 34.41604868058236, 45.44161942697341, 38.466962768185525, 58.36249513010825, 46.725901480643984, 5.898373482688781, 0.19486796200996448, 0.3492965633350034, 0.2900173232680367, 0.6678636239901666, 1.4759712257692892, 4.508397771466163, 5.940515427820145, 9.646043739011212, 7.9566921437940294, 14.334082141999277, 9.887000822251844, 8.561405424148806, 12.436828747872385, 21.172401135967625, 27.785811424255375, 26.990574406039332, 32.9552403573067, 39.906994296658425, 47.31484536201724, 49.964967312351355, 56.24283059950798, 62.84563479884979, 67.13371107655188, 70.27054817445817, 72.30006094901793, 71.30462615720688, 67.69697912277715, 66.94249553065147, 65.64014311759703, 67.9759459341726, 72.30775663929602, 70.72181686278313, 66.28739695395193, 72.67860889434814, 69.69481483582528, 70.17129651961788, 70.40889017043575, 69.29343869609218, 67.41252099314045, 66.9648059721916, 63.49066465131698, 69.2644053120767, 67.07994322622976, 69.89507536734305, 49.6323581664793, 45.174961013178674, 44.56107085750949, 47.04650817378875, 68.33613718709638, 61.21239908279912, 63.335287801681034, 61.76658291970531, 62.86568203280049, 63.285403097829516, 65.74951448748189, 61.71219925726614, 61.94643535921651, 62.936504348631836, 64.93692098125335, 63.77444421091388, 64.47935296643165, 58.748519112986905, 66.27843826047837, 67.94860701407156, 75.57674623304798, 73.65494958816036, 73.45472828034433, 73.02445996192195, 71.99737948756065, 72.65301150660362, 77.714524269104, 77.85677294577323, 70.88639167047316, 64.74375601737731, 59.62076402479603, 43.35247093631376, 28.08014412080088, 14.004973711506015, 10.58783325456804, 6.527331423374915, 10.668058472294963, 8.521620823491006, 7.217827919990786, 1.2091613104266505, 0.37291876190612394, 0.1286471686175754, 0.2078382595772705, 0.1701433629158043, 0.6312384312191318, 3.714568884141984, 26.773890910610078, 50.397071300014375, 57.653832666335575, 70.93557034769367, 71.436857100456, 59.80054193927396, 32.85017967224121, 41.020751307087565, 63.53766249072168, 66.60488144043954, 80.27218418736612, 74.65746033576228, 85.92083654096051, 16.935476487682713, 0.8156778987857604, 0.2051539181341087, 0.17058026285902148, 0.323298848684757, 0.20648004697455516, 0.12631723476994422, 0.13798049440787685, 0.20306426010304884, 0.16253039481178408, 0.1979322524200524, 0.1770010909005519, 0.1170519375873189, 0.14417390158820537, 0.11861398320404754, 0.12337227787582145, 0.23277601497548245, 0.1406208164389095, 0.13062906872120597, 0.22180894539961893, 0.10769074151833212, 0.14378071462194766, 0.18443218973134795, 0.1928001681282636, 0.07946515891460643, 0.10925733003645174, 0.12250485184091715, 0.23948276235211283, 0.12428227541667801, 0.11495607424407236, 0.12791122625311538], [0.0713814604246328, 0.050831580865046674, 0.031020372858150836, 0.014750701225092335, 0.013502962331497862, 0.03274357464585093, 0.0280238812293617, 0.02634193710682373, 0.05684387719919605, 0.02301426949880777, 0.016142152467622392, 0.019097238959323977, 0.036768443551996065, 0.06115412917889415, 0.03129121749812076, 0.056672162421408205, 0.035410093053454356, 0.05411109601658198, 0.11003597414181118, 0.028437036277365782, 0.0319823992603849, 0.01513065210723829, 0.02270621788357535, 0.08482100982819835, 0.08284051166546923, 0.06545769321101327, 12.558522243653576, 63.01992923982682, 71.2256060877154, 69.99702561286189, 57.201300974815126, 56.949445586050714, 33.82746957963513, 25.722315234522668, 39.214370404520345, 32.895767419568955, 41.51489150139594, 41.83466665206417, 49.74264344861431, 50.86076213467506, 6.994966201243862, 0.11915970593690874, 0.03872149278439822, 0.04487875976689881, 0.2019531721429479, 0.8609428473057286, 2.5261358291872087, 3.3093448992698424, 1.4572129807164593, 4.837814108017953, 16.21940564724707, 5.266592906367395, 2.363959550857544, 12.107807590115456, 24.98364663893177, 35.51289635319864, 44.84964355345696, 49.784530439684474, 52.90216361322711, 57.05585948882565, 55.57205038685953, 58.062684843617106, 64.46760546776557, 66.95365859616187, 64.00067083297238, 64.08142851245019, 66.44546847189626, 67.77120605591806, 64.57595309903546, 64.81881449299475, 65.45636830791351, 66.17560155930059, 60.64797393737301, 63.33638606532928, 61.286688773862785, 61.46048899619811, 58.54080607814174, 62.97511223823794, 64.70522657517465, 64.36221138123544, 59.66216071959465, 58.62806312499508, 68.52161822780486, 65.82018775324669, 64.32822404369232, 62.55082161195817, 54.84010081137381, 34.661918532463815, 24.84933291712115, 45.80999274407664, 53.80581886537614, 56.970465567804155, 60.69864311525899, 61.22692754191738, 61.24876337666666, 56.61163145496, 61.0857928183771, 59.48177483774001, 58.5319140649611, 59.18993088506884, 58.5602218104947, 60.22757822467435, 58.29519118032148, 59.87732233539705, 64.80012047675349, 66.51046214565154, 66.97266640201693, 65.32823231912428, 58.26602443572014, 54.677906882378366, 55.61383931867538, 61.61956856327673, 62.075497027366396, 68.16742820124473, 65.22954156321865, 64.25597398511826, 63.62423312279486, 58.19507268167312, 45.631395463020574, 29.0263198268029, 12.80776043092051, 5.207914738885818, 0.9795007145693226, 1.7324005884508935, 1.9350955635309222, 2.407602538024226, 0.3969122986159017, 0.19749141478490448, 0.07841743408672272, 0.05792446336859177, 0.007151483920507975, 0.040874184529867866, 0.9862137898322075, 8.633770212050408, 26.878869225901944, 41.535750665972316, 49.67256638311571, 42.249037604178156, 30.99010152201499, 19.810820933311216, 24.703261890719016, 42.86774050804877, 55.118961718774614, 53.700711111868586, 55.66561460494996, 48.33939982998756, 3.5102496800884126, 0.11443604610019154, 0.01567911360442879, 0.06291481373350948, 0.05063458518575757, 0.022616614324731693, 0.05698917343491509, 0.020433378653720986, 0.06401660521664927, 0.06098246419682138, 0.04304443501056202, 0.017321621435844613, 0.027834063793923107, 0.11467336481737514, 0.006435438774661312, 0.03178643205413415, 0.05053086071124962, 0.04759662138718752, 0.033549698325054306, 0.026811370888965267, 0.06415249772309776, 0.039407149137508486, 0.042951799658758026, 0.04484759147969946, 0.021324279537845044, 0.0300695562374688, 0.02110902989854015, 0.055945700395011136, 0.0660729690665199, 0.02781170168741336, 0.04920595378104237, 0.017573174066661347, 0.024601050179391622, 0.02305446996263439, 0.010351849261731392, 0.06839688912394547, 0.025358502377545642, 0.015511882356217793, 0.028023484778860887, 0.04362631709344926, 0.04369144605833196, 0.017329205706294988, 0.042338511801414916, 0.012362159736033891, 0.035142226580290065, 0.012598825363262046, 0.03715396963901097, 0.042563584603128896, 0.04527848146315064, 0.0366574144291301, 0.02881472720013511, 0.07365772215228888, 0.010078558886063196, 0.04776815613431316, 0.05778592402836489, 0.08214436756867556, 16.92266602669993, 74.6045240279167, 81.7155928765574, 78.42445758081253, 69.5359274648851, 65.64857229109734, 41.25222213806645, 32.37752622173679, 36.27966873107418, 27.175420022779896, 34.490306992684644, 39.15674686431885, 38.23413087475685, 41.82622571145335, 6.557101722686522, 0.046714532429412495, 0.020059031704741142, 0.1992164149640068, 0.9571691902895129, 2.3723286630645877, 2.4325117949516546, 2.106935949094834, 3.3578616765237626, 6.294730459490131, 6.555051793975215, 5.567921640411501, 4.953530401952805, 10.724705342323551, 23.776115563607988, 37.396332217801, 45.08698225021363, 49.43282719581358, 50.85232119406424, 56.322250750757036, 59.25939213845038, 60.61119779463738, 66.518644209831, 67.96044472725161, 65.44540528328189, 66.490873829011, 67.5915301230646, 68.50916862487793, 64.71268692324239, 66.80504783507317, 67.66947546312886, 69.02024561359038, 64.89085666594967, 67.48393950923797, 63.68146050360895, 63.33287554402506, 59.32927308544036, 65.74590590692335, 67.27988996813374, 66.26635736034763, 61.96670224589687, 61.33296097478559, 68.68089783576228, 68.32623712478146, 65.190102131136, 66.83412044279038, 57.92393884351177, 37.92708381529778, 29.371533509223696, 46.503401110249186, 57.9745727200662, 59.10727085605745, 62.12835096543836, 60.89738568952007, 63.013308278975956, 57.770640850067146, 60.97705687246015, 59.8076061279543, 58.572483139653365, 59.44025654946605, 60.539924406236224, 61.71183447684012, 58.24881699777419, 59.51198101043702, 65.33445319821759, 68.38483733515586, 68.52431681848341, 65.893308577999, 59.6362260080153, 56.11844439660349, 59.457342393936656, 65.00600960946852, 64.58727305935275, 69.97494266879174, 65.76785156803747, 63.62182478750906, 64.1800682775436, 61.567542245311124, 51.105882813853604, 34.58549899439658, 16.935178387549616, 6.547904254928713, 1.6623329611555224, 1.793265477303536, 5.863029005066042, 3.697790945729902, 2.3853095020017316, 1.1621425108563517, 0.2887868941310914, 0.10864167113698299, 0.04134534775549847, 0.15589409688067052, 0.8044908087580436, 8.819985716573655, 25.83860174302132, 46.91080201056696, 51.56239963346913, 39.06893284090104, 24.77157585082516, 33.51366819873933, 37.181300040214296, 55.12295469161003, 61.7685244929406, 62.56384388093026, 64.34776921426096, 63.64315071413594, 9.319976125994037, 0.13912761914393595, 0.0085455336375162, 0.0424830649318474, 0.06151186542645578, 0.08030452314884433, 0.09677551311230469, 0.05094917536142373, 0.01349315066040764, 0.03160715407331384, 0.07465051081512245, 0.010902926949183307, 0.02704480554037277, 0.021198962875191244, 0.03278393981858127, 0.05401224386127246, 0.04019115585833788, 0.04154457275064723, 0.037182479601113066, 0.01363010228341145, 0.04866207348963907, 0.03942059781101923, 0.03888690648900886, 0.07272284973653094, 0.027776172444705042, 0.006709785872860061, 0.027144550188114087, 0.08199467398827115, 0.04793484920575734, 0.030486694942679138, 0.1636506605052179, 0.12033464732549845, 0.132049870707335, 0.1551542551286759, 0.05805976215689894, 0.18915101555326294, 0.1496944077793629, 0.1645811049327735, 0.10397594286909989, 0.20362515903769002, 0.12405218090862037, 0.10685284817290884, 0.1179104693414223, 0.21230645207387788, 0.1217377833240936, 0.20643375994217014, 0.11870846482774905, 0.11721686865653723, 0.1996773394245294, 0.09727838854756087, 0.09821830948273982, 0.15950227907348066, 0.14224958065296375, 0.2087636937898013, 0.15631512348209659, 0.19524860045602246, 25.21378386405207, 90.253627838627, 91.11913804085025, 87.92672095760223, 77.54416004303964, 74.08604944905927, 48.84533851377426, 38.66544646601523, 52.908145227739894, 43.842877034218084, 53.980399639375754, 54.13864374160767, 62.8915382969764, 65.2864041636067, 9.624517771505541, 0.17598751061145337, 0.2921492846742753, 0.20531982213499086, 0.8576032555391713, 3.035662255940899, 6.608352391950547, 7.1807257302345775, 6.457147473289121, 12.665042050423162, 28.020535861292196, 11.766403509724526, 6.599042156050283, 16.773547318673906, 30.19328574980459, 41.1745866652458, 48.21027540391492, 53.86370912674935, 55.245964142584036, 61.10078411717569, 61.89566812207622, 61.19044165457449, 70.0049566453503, 71.15873752101776, 69.47156137035739, 68.37787905047017, 71.66889667510986, 71.5734261851157, 64.59300756454468, 66.31993693690147, 69.44361056050947, 72.7935500298777, 65.99696897691297, 69.94751745654692, 65.79171919053601, 64.71437354241648, 61.881492676273474, 67.6252232828448, 68.00016264761648, 67.82800197601318, 64.16706562042236, 63.40362725719329, 70.59036254882812, 71.14536223873016, 67.79976091077252, 68.878585292447, 60.690304156272646, 42.55030309000323, 35.14312274994389, 52.308991416808105, 61.57621068339194, 60.77811425732028, 61.32332371127222, 62.509754396254024, 63.10527217003607, 59.67236672678302, 61.5989996540931, 60.25270492799821, 58.74357300419962, 59.98987866986183, 59.93056851048624, 61.181557486134196, 58.87398396768878, 60.23854909404632, 67.44295074093726, 70.96523131093672, 72.80294802881056, 70.35900546658424, 62.25523571814261, 60.472306666835664, 59.976946615403705, 66.40112999946841, 65.85672070903163, 74.84050166222357, 66.97297234689036, 64.92424388085642, 65.18305363193636, 62.00736545747327, 54.60131083765338, 39.375783781851496, 19.20933723449707, 8.890197123250655, 7.635001405592888, 9.002260219666267, 10.01616741380384, 6.485390990011155, 2.246961622468887, 0.765865758782433, 0.2497023139749804, 0.29904511787237664, 0.13574270561577814, 0.3289637011626075, 1.8217585548277826, 13.538011620121619, 41.248468429811545, 55.079149661525605, 61.0753083229065, 57.17417386270339, 43.87617403461088, 32.630536748516946, 37.19456941850724, 60.746464652399865, 71.64284429242535, 73.89349245255994, 72.3349465093305, 76.49392973992133, 11.245099921380321, 0.4034091838665547, 0.12231700708188357, 0.1827243499217495, 0.10421400469157005, 0.21405576788369687, 0.21844414934035272, 0.11238708265966947, 0.1615338216746046, 0.11556653906741451, 0.18278283307388907, 0.14632132264875597, 0.09389476970799508, 0.22574653007811118, 0.13705355866301444, 0.11630346968529687, 0.19273439181908486, 0.09230873787835722, 0.08347347649114747, 0.09654919541771374, 0.17477666268185263, 0.1619638268265032, 0.13820155673930723, 0.20251142041337108, 0.09677925162137517, 0.16987726993618474, 0.1626303233206272, 0.1798893343056402, 0.09017994041524588, 0.14107761934639948], [0.01991578858465918, 0.07723948197259058, 0.023659309785392497, 0.04485627508632118, 0.05642030335542175, 0.05205332256493069, 0.02347021247260273, 0.014910600054258061, 0.04549847510192664, 0.08236755196365618, 0.024495956322719014, 0.07486146844683156, 0.03441232481911298, 0.08999047154981284, 0.003903424578546096, 0.04903433476424506, 0.04050161298965255, 0.08805537941835581, 0.06285365310407455, 0.08499638267582463, 0.06546367635770191, 0.03979862006681581, 0.08357309090394167, 0.004223224870304788, 0.14898055172975988, 1.5638434718693457, 37.766560815995746, 69.59058177086615, 68.52571318226477, 62.68770448623165, 49.11781772490471, 39.32902912939749, 35.88612948694537, 26.25423962070096, 45.463918101403024, 46.92172581149686, 44.15919265439434, 49.249703499578665, 48.13917459980134, 6.2508930698517835, 0.039677283230928645, 0.011917286732744788, 0.047766930393634305, 0.14738361080808027, 0.46225304084439434, 1.6953504926735357, 2.1127415472461335, 1.7087889006060941, 5.017456210428669, 5.565550567642336, 4.162740370919628, 6.865530927335063, 23.348390902242354, 37.139283610928445, 47.92082017467868, 61.300024832448656, 65.33172715094783, 64.67665210846933, 64.1136468610456, 60.796023799527084, 62.48487480225102, 64.31658637139105, 65.1258772419345, 59.26280852287047, 57.75464150213427, 58.50048411277033, 65.1655912399292, 67.79419114512783, 63.63704750614782, 67.00096238044001, 67.20546691648423, 60.703816721516276, 61.2963064255253, 56.67220461753107, 58.03541652617916, 57.334885135773696, 63.532253542254054, 63.76872931757281, 66.04657127011207, 61.8843363946484, 60.654037921659416, 60.75338371338383, 64.16937981882404, 59.24817808212773, 63.482208021225475, 60.8716235622283, 71.39699797476493, 43.72184445781093, 22.470385989835187, 54.708003228710545, 53.87109887215399, 66.47549029319518, 63.934308252026966, 65.75969696044922, 64.56459391501643, 61.932962017674605, 60.402311971110684, 63.04598162251135, 59.984399118731105, 61.51992859378938, 57.16408552662019, 61.105467427161436, 58.10148885173183, 61.9040737613555, 64.33135409508982, 63.48141178008049, 61.564451417615345, 55.118687152862556, 49.5257834465273, 52.752148643616714, 56.01960851300148, 63.05106501425467, 68.06588588222381, 70.37516563169419, 61.75946774021272, 62.28012315688595, 64.18742664398687, 63.024918494686005, 63.571281125468595, 54.258181894979174, 41.69863493211808, 27.35200316675248, 10.584014827205289, 2.1721034328783713, 4.967571506577154, 5.638149226865461, 3.14037139857969, 0.7162494921395857, 0.06369289859468419, 0.08461441889765763, 0.02512118940602147, 0.0382867110742917, 0.0492697803964538, 0.8004864365343125, 9.940681399837619, 32.37050321794326, 35.51311600592829, 54.15027749153876, 62.68970097264936, 20.67625072694594, 26.47996614056249, 39.30072530623406, 49.46005236717963, 51.78262895153415, 60.054178084096606, 54.665586717667125, 47.14663059480729, 4.377199392164908, 0.38622981538214995, 0.02543674485247222, 0.0243070122275141, 0.01612201010087325, 0.0511048405971979, 0.039371744384087866, 0.10485290669866147, 0.02155007437742766, 0.054431044977278485, 0.045982274947868246, 0.03548591660576002, 0.043269638047223134, 0.05928770916896963, 0.017304258053040793, 0.04069935560466782, 0.03304071333860198, 0.07352767106626304, 0.01247685075917792, 0.05364747492656593, 0.05263598222706107, 0.08079726324086228, 0.0795673473828262, 0.04741421968285595, 0.03712486212832793, 0.03102369001886297, 0.029941416540814024, 0.028960029181513577, 0.032895673742337574, 0.061512420840200886, 0.06010039822168409, 0.055863966474369656, 0.06805635538072356, 0.037168628731442076, 0.06983052308280623, 0.033361374761068055, 0.03531009942713765, 0.04435270634149352, 0.1050630063118954, 0.08059153032879676, 0.041354724671691656, 0.06549553029359349, 0.03585334003512417, 0.020313108595268383, 0.03984771481144332, 0.055499358418127226, 0.0823689692263161, 0.09568758399015474, 0.06279258823563015, 0.05944421327102089, 0.05005273374638731, 0.02580379289875348, 0.0237651544082309, 0.07872842747958438, 3.2570972125376425, 49.765934482697524, 79.38270045864967, 76.85854542639949, 70.58400046440863, 57.00077372212564, 51.57216633519819, 48.27743422600531, 38.730855911008774, 57.011732824387096, 37.71395790961481, 42.2461978081734, 42.696576118469245, 36.397665392967966, 5.865310353617515, 0.07779893300105488, 0.11938068399866743, 0.042680669651036306, 1.0897972122315438, 1.76051466695724, 3.3801782467672905, 3.6373727167806322, 3.6941036726197893, 5.372708709009233, 5.593088548029623, 6.330642700195313, 8.648694830556071, 18.827516071258053, 37.37903848771126, 50.82837512416225, 63.93756774164016, 66.23987351694416, 63.695804611329116, 63.42338815812142, 61.923261996238466, 61.427392036684104, 64.72163384960544, 67.72281185273202, 63.100612394271366, 60.409348703199825, 61.629060699093735, 68.69388088103264, 69.81690252980879, 66.07400432709726, 68.40072293435374, 68.08598410698676, 64.49835292754635, 63.79446398827338, 60.49160472808346, 60.76377014960013, 60.04473693909184, 65.40691114241078, 65.41197099993306, 67.07911168375324, 65.41795653681602, 62.78568921550628, 62.08763284067955, 64.72501493269398, 62.30565778670773, 64.55260715176983, 62.63056731993153, 72.24160978871008, 46.61516120356899, 26.880359726567423, 56.160849140536406, 54.18328031416863, 66.37808999707623, 64.8580381947179, 67.55385967992967, 67.20000697720435, 63.41912454174411, 62.60337744989703, 63.67530630480859, 60.84006809419202, 60.55298197653986, 56.86982539392287, 60.755588085420676, 58.34706060348019, 62.620133815273164, 67.36816683123189, 64.85086810204291, 64.89692065023607, 56.75302505493165, 51.54565503520351, 53.633960216276115, 59.297784297697014, 65.50680606595932, 70.39122381517964, 70.70680987450385, 62.43607659493724, 61.90693709158129, 65.0169647893598, 64.99960437897714, 64.81001661669823, 57.846574014233006, 47.501479579556374, 30.319613525944373, 13.585854730298443, 2.1653643106260607, 0.7262121285161665, 2.8430486302221976, 5.077327759035173, 3.1117224068410936, 0.8163225158087669, 0.2779391504103138, 0.0579945374310257, 0.05218310552018304, 0.09656506109862559, 0.772384002564415, 8.110947195560701, 31.692076344643873, 44.728485461204286, 53.69411760760892, 52.18358539765882, 19.28854753894191, 33.728382664342085, 48.34318491720384, 57.17569574233025, 60.61871697825771, 70.13373590284779, 65.0359098372921, 64.76836889020859, 10.215215932938362, 0.5676937668073563, 0.029563972681400277, 0.05566428565690595, 0.013380390178832798, 0.09096927910802827, 0.03478366295777021, 0.06680065300315619, 0.020889281407899914, 0.049651112152083274, 0.10353293720512621, 0.02354260395100761, 0.0019441352008969614, 0.04571050142629012, 0.03720968338330427, 0.03362224685148366, 0.054726322076373526, 0.033661007070012634, 0.060273917136533614, 0.06400209934180302, 0.015565863784192311, 0.08262033799603101, 0.0595185429518742, 0.07123285468908087, 0.012791052145222503, 0.04343831145595159, 0.01569440376178752, 0.019439232100041646, 0.014782920010357857, 0.19593086303962817, 0.20687600717909876, 0.06043550423196247, 0.22574381812685923, 0.12776630540047923, 0.2134761151166693, 0.12469296749200552, 0.06715883741215353, 0.16559915917534984, 0.26745465493971304, 0.13975185822815667, 0.13512122444808483, 0.18195700561327321, 0.20235671661794188, 0.1545479118583664, 0.12041442772193302, 0.09578460136488562, 0.147705429023312, 0.18340682700997402, 0.1787562902656294, 0.15755405619500146, 0.1484228090773667, 0.2008770484357111, 0.1660861919123319, 0.3769950851077034, 6.372134512470615, 67.26872690262334, 86.32592324287661, 87.88640683697116, 82.239056710274, 65.38457324427944, 54.921121289653165, 51.115131762719926, 39.641924442783484, 59.4150435539984, 61.70210699881277, 57.19013398693454, 62.483419602917095, 61.734015480164565, 8.188537561124372, 0.319431820704091, 0.26213567583791675, 0.2904805613140906, 0.9299882068749398, 2.429015982535578, 4.201499271777369, 6.570379436016084, 5.6408635070247035, 12.4403049484376, 13.976356098728797, 11.762485061922382, 11.17267825911122, 29.024378253567605, 41.157834222239835, 52.81463984520205, 66.8902809389176, 69.47451883746733, 64.59888719743299, 63.439630693004986, 63.74903509693762, 64.44334168587962, 67.45348622722011, 71.99734026385893, 66.09673838461599, 63.35011043856221, 64.96065132079586, 70.39108260985344, 70.24866134889665, 66.80911925531203, 71.31098039688604, 72.1654373599637, 66.47518434832173, 66.57557349051199, 63.05887445326775, 64.23973929497504, 62.4327661145118, 68.45709523847027, 67.66247011000111, 68.33001044488722, 66.76818540019374, 62.779134934948345, 63.865886426741085, 65.62245715049006, 65.43952957276376, 67.14857685950496, 64.76482698994299, 72.90684376993488, 49.75102163130238, 30.95235263147662, 58.09491103695285, 54.541074998917125, 67.97378078583749, 67.85880827134656, 70.23363867113667, 68.78036129859187, 65.96231091407039, 65.21778621981221, 66.15507187381868, 61.486800255314, 62.46401956004482, 59.077731486289736, 61.72706504021922, 59.39228203988845, 64.58122084217688, 70.56733039117628, 70.25313285089308, 69.59985425395351, 59.465653896331794, 54.552041945918916, 56.738692714322, 63.82983592248733, 68.40739096364668, 73.98926888742756, 71.24601025735178, 61.29343525055916, 63.40144249700732, 64.93123746687367, 65.34420813283613, 67.13599389599216, 61.42426983002694, 51.753611256999356, 34.65405418026832, 14.822131876022587, 6.516580206732597, 10.52661878447379, 17.64093045265444, 9.287532241113725, 2.360057527980497, 0.3223439660524169, 0.20896201863163905, 0.2892410616961218, 0.12166056932220537, 0.24873171121843402, 1.42369510185334, 13.108677806392794, 43.933283744319795, 50.86304887648552, 64.01814891446021, 79.79598491422593, 32.056727332453576, 38.925734950650124, 52.057363525513686, 65.16114719452398, 69.32199355094664, 82.51839222446566, 74.4841072636266, 79.5962421355709, 12.387516710066027, 0.810547377313337, 0.11009606607859174, 0.14542051050211155, 0.12377228302460526, 0.14472203749802806, 0.1266000820924678, 0.2269204525697616, 0.12148026286834672, 0.13844267525259527, 0.1576668856244895, 0.12813385906479052, 0.14062766526495257, 0.17450634089689102, 0.10818932686121234, 0.11882447352212284, 0.15903062938201815, 0.15772342291330138, 0.08310635183607379, 0.17682982428419977, 0.17037043137656105, 0.24056697594783, 0.15407776369923545, 0.13511000892087338, 0.08781089011820094, 0.1222195223935189, 0.14852943319466808, 0.11779799231237943, 0.18429933476351923], [0.024403282666518807, 0.01603608376406614, 0.012879563071164153, 0.016813214845775117, 0.02549189552214117, 0.07468514565017915, 0.07368546985690633, 0.12956776115442478, 0.04115823077999296, 0.046399095726590005, 0.09476352873588763, 0.010755286484415974, 0.014739266405212543, 0.041364982588997776, 0.003999286118121217, 0.032019669437901147, 0.026797495121436737, 0.011932624770598787, 0.011995196917034205, 0.06943472375672671, 0.045184673996822494, 0.057123472478481076, 0.026971188321289037, 0.030356862191711704, 0.18870764982796487, 16.323357282146333, 68.31815704222649, 68.67237060300766, 62.52331795230989, 47.26228167933803, 49.40276615081295, 30.285055483541182, 17.15468010594768, 24.333955049514774, 31.59979081922962, 66.52721851102768, 47.89525024352535, 31.144221252010716, 5.067976828544371, 0.3115589189673624, 0.0647412860886224, 0.0436705663319557, 0.05119865572440529, 0.3210489097381792, 0.9048762737262634, 2.619214653968811, 1.3404966049617337, 1.2791894688721628, 1.3718836562287424, 3.776084886443231, 9.046605556241929, 30.530544865515928, 42.388544544096916, 58.6798894020819, 62.78536365878198, 67.04945072051018, 65.59987214303786, 67.23561425362864, 62.21763195530061, 61.52974628633069, 61.00317593543761, 61.45890435864849, 61.17386964059646, 57.90690006748323, 55.78625886671005, 59.812532624890736, 64.46128652941796, 64.14946202308901, 64.11561981324228, 63.39338202630321, 62.43233465379285, 59.71021759894587, 54.77977475812359, 54.7070187137973, 57.625273889110936, 58.22497290949668, 62.973319715069195, 63.74505781358289, 63.573348214549405, 62.90283864544284, 61.37121977344636, 57.1786218304788, 65.4433499613116, 59.940523485983576, 58.3154502222615, 56.06863421778525, 67.47582804772162, 47.73377018590128, 25.930604857783166, 68.16437659725067, 60.292626811612045, 65.59429845502301, 59.3525601971534, 63.300986674524125, 57.55682460723385, 63.571602759822724, 59.2834754913084, 64.01772137611144, 62.10048644773422, 59.519178559703214, 57.21581766682287, 59.36908906505954, 55.92599330409881, 62.96098778324743, 60.4314826380822, 60.192578915626775, 52.54722441396406, 50.27981988845333, 48.30738936701129, 50.31429752226799, 60.99137744595928, 62.95168392119869, 66.15761356969034, 61.42969054560508, 62.30907417112782, 62.32982350933937, 60.71882370979556, 65.51717289032476, 64.45226115565147, 68.06732146970688, 63.72525376658287, 47.24386222900883, 33.06987162559263, 14.874636723149209, 5.519681390254728, 2.065417415672733, 3.321896483821254, 4.289739362655148, 0.8572903239438612, 0.06442416399236649, 0.11721183545887472, 0.14732145043390413, 0.054096295197884885, 0.028256438710095904, 0.08395975846196375, 5.652856644122831, 29.112417813270326, 48.84666035252233, 59.62040708911035, 66.82309073786583, 25.171516403075188, 18.1793345943574, 32.9841011570346, 44.053069007012155, 45.27131403646162, 51.79382731837612, 52.8895414260126, 40.864437010980424, 3.59056388658862, 0.13415613752459327, 0.04266822838314599, 0.022270543681037043, 0.06159343463819354, 0.025639340634487813, 0.04486291706862469, 0.024088047061776443, 0.0315911830553124, 0.05900571986492123, 0.021864381100561832, 0.05831412249995817, 0.07621018155928581, 0.061946562866890625, 0.005383371664661794, 0.02986066704315524, 0.025732901037460374, 0.038296126294881105, 0.029291475206733714, 0.03352029204008079, 0.05004883435885272, 0.04473475438933219, 0.08800880127255956, 0.0330335580773892, 0.01232395971929955, 0.025348819026182738, 0.07401438970719615, 0.016403516769529353, 0.02102641306156593, 0.009317862305549846, 0.05756359382141983, 0.04539945440727376, 0.03957791779670985, 0.036274987167768905, 0.009021633342208882, 0.018609355864745956, 0.02180049319811646, 0.035372746267145684, 0.04030196281570581, 0.03745269413376528, 0.01919989665639737, 0.024392542113820394, 0.0155904705283202, 0.0708124179753565, 0.030351258258545594, 0.04110055585061351, 0.010235147257786124, 0.021950010578298283, 0.02555597111612799, 0.07117692260972916, 0.03019651424350037, 0.012559561441922861, 0.20941831592109897, 24.03065973712552, 79.36938008954449, 77.97009022005143, 69.08050106417748, 56.954901602960405, 61.189935668822265, 41.18003483741514, 25.531501731564923, 25.166148639494374, 37.95386575883435, 64.3716956723121, 46.55969888933244, 27.21280609407733, 4.953587276320304, 0.334794610858925, 0.06627772138604233, 0.08618925052184252, 0.708826958171783, 1.723648064559506, 2.794485519970617, 4.3208663117501045, 3.4049759612929438, 3.907013357647004, 3.983415245048462, 4.246699685050595, 10.20827235714082, 25.801054854546827, 45.586445100845836, 60.03738641738892, 66.19484470736596, 69.94830977532172, 68.97386750867291, 67.98499091978996, 63.04519322610671, 62.31160017751879, 63.36549397437804, 64.23917055130005, 64.35874008363294, 60.96817270401986, 59.468776102988954, 62.095289307255904, 67.59889633424821, 64.19487522494408, 66.30674992838215, 66.0262926163212, 64.79938307116109, 60.719596416719504, 56.44076516551357, 56.94143610615885, 61.548051987924886, 61.45671567609234, 66.2750336431688, 65.93812557958788, 67.47855017262121, 63.00918586792485, 63.92098788292178, 60.73987899288055, 66.15859416223341, 61.584404514681914, 59.57553125196888, 59.071263497875584, 70.42465025378813, 48.599115648577296, 28.676330658697314, 67.25177441873859, 62.09621890898674, 68.26256921214443, 61.321135028716064, 63.59596067859281, 60.39547135753017, 65.24263835722401, 61.00541953117617, 66.00639051006686, 63.96233358690816, 62.97600261626705, 57.12197496045021, 59.16010518227855, 56.564421807566, 65.24610573245634, 63.779225580153934, 63.27190229969641, 54.40721234967632, 51.40173935121106, 50.01356155641618, 53.6909757891009, 63.49288079046435, 66.09401625971641, 68.2042827913838, 61.10260801930582, 61.800676161243075, 60.373215829172445, 63.06933933688749, 67.2163083476405, 67.42345656118086, 70.10008981150966, 66.92114999217372, 55.001616170329434, 37.647097187657515, 16.259872740314854, 3.660851044039573, 1.051652652602042, 2.9279267595660303, 4.460371290483783, 3.624805197600396, 1.3952161203469, 0.1270463129866027, 0.02442285812820398, 0.020839458879744335, 0.021000287548128157, 0.05714255955911452, 5.428344097829634, 30.81617578383415, 57.23698277627268, 69.59068375249063, 50.09433884774485, 27.086150800028157, 36.15319582723802, 47.197021284411036, 50.9818260900436, 53.379931834436235, 62.12736252815493, 62.50251370091593, 58.308907708814075, 6.357885031930863, 0.16539865864380715, 0.07602490319479858, 0.07540449455019928, 0.06177478680206884, 0.012570753028886694, 0.04220949493408684, 0.005020537580769029, 0.0429019503175251, 0.047508888998098915, 0.05382149179856624, 0.09251181246532549, 0.07794274302620081, 0.047046164230954264, 0.038325536410294236, 0.0189177158303679, 0.014349207950515613, 0.06977590101380503, 0.02032258318767192, 0.010010864484244058, 0.031926312048228524, 0.019833338371808493, 0.050935994818686485, 0.018738443595207026, 0.05114137916074646, 0.08723719751522427, 0.049206172116100795, 0.03497450695102734, 0.08273718938712152, 0.07428152456639275, 0.16962283681477272, 0.1249212080672864, 0.11087218209380105, 0.18036224038129856, 0.19462756361932526, 0.17580875165520177, 0.12578952276418287, 0.1996250615845765, 0.14367496384488, 0.17450241852671872, 0.08099173466044088, 0.09780786255554808, 0.1234559576597906, 0.20679187540325428, 0.10149853709604471, 0.1709669380779228, 0.08504451598010718, 0.23404592828404522, 0.14524807943211449, 0.16106434767284702, 0.1018720509244069, 0.13394537141486523, 0.3735810602384229, 32.03814510376223, 91.51502286234211, 86.62294080180507, 81.70561436683901, 64.70285746359056, 66.50674373872819, 43.388152737771314, 26.713757053498302, 33.857852258989894, 41.1961361669725, 80.15212828113188, 63.20426102607482, 40.337686231059415, 7.3835201128836605, 0.6980569264100445, 0.22331527344161467, 0.16207397494825626, 0.4053082545438121, 1.1358451026101266, 4.494688597417647, 8.149911530556219, 7.321640801045203, 6.0532639584233685, 5.5508215773490175, 9.268344986823298, 16.623191102858513, 37.36686345069639, 48.11744859141689, 63.24649318572014, 66.85660346861809, 73.4619846651631, 68.51741344698014, 68.22546359031432, 65.00846893556657, 63.650132533042665, 63.34913376838931, 64.72847446318596, 66.69049893656086, 63.65808709975212, 60.58804796588037, 65.15801322075629, 69.80405284512427, 67.37209704614455, 67.13990842142414, 68.10676482415968, 67.64903206979075, 64.31658244902088, 57.81852514513078, 58.38870440759967, 63.58555463052566, 64.91042144836919, 69.13584570730887, 68.36650417697045, 67.9138312801238, 64.02991994734734, 64.40451806591403, 64.078396520307, 69.11266449959048, 65.41464997876075, 61.773086209451, 63.297888002088, 72.28355561533283, 51.53892032561764, 31.661105309763265, 66.69180116345807, 65.14573227974677, 71.8974296508297, 65.2449054871836, 67.35051616545647, 63.20744991302491, 68.52732135403541, 64.83942262588009, 68.88886190229847, 66.15864123067549, 64.38152120959374, 58.224992521347545, 60.762189434420684, 55.33872035241897, 67.54949015955772, 66.06625372363676, 65.79124458374517, 57.20953402980682, 54.779064809122396, 54.77491886385026, 55.2226064282079, 66.66995356159826, 66.93013221986833, 69.83709489145588, 60.2130340760754, 61.857456391857525, 61.12450268960769, 62.63485839290004, 68.16985222601122, 70.29518065914031, 72.31300477058657, 71.52707945915961, 58.01862093710131, 43.21321502808602, 19.899790094744777, 9.618595973137888, 9.654974975893575, 13.090977130397675, 12.217270155106823, 2.7429379763141757, 0.6522901596561556, 0.18412033065913186, 0.39398590403218425, 0.1270651740712985, 0.1811426081844876, 0.24874743134264024, 8.438507760724715, 42.70998670208839, 62.67511367797852, 67.65922238749843, 87.29783165839412, 37.26171255111694, 31.966842297584783, 47.78181922051215, 61.12469488574613, 62.750489865579915, 74.1609980983119, 70.6851819253737, 73.85967377693423, 8.130951773735786, 0.3611101907107138, 0.2447412971166834, 0.10221859079695518, 0.21731672838570612, 0.1475204800766322, 0.16409525197119484, 0.16325755014775262, 0.17045820973092513, 0.2152468507448512, 0.14243537229636025, 0.1542712775089087, 0.17656512558460238, 0.19860222695335267, 0.10353882842126394, 0.17249686162798636, 0.1782942932820128, 0.1756230519423562, 0.10268339932325388, 0.1768978222483589, 0.16468559932564536, 0.10290394837577498, 0.1627615235385395, 0.11490447056149283, 0.10720933952759351, 0.23507607139406667, 0.16267068083247832, 0.15294363181437218], [0.11306795096325298, 0.0058316824875111065, 0.07514243119306142, 0.035923479215031674, 0.025366155595909205, 0.08118371629426557, 0.14604562292656592, 0.036715483893790556, 0.036576465748611, 0.014311996187203595, 0.03470913792449621, 0.05235416146235601, 0.007299531848290034, 0.011347763563296007, 0.13354437035177985, 0.05191898138652887, 0.041686609282248446, 0.06604896753185219, 0.09898858790796611, 0.027494683013027234, 0.044332071763253024, 0.10999819834626491, 0.08175855036824942, 0.051112095449840834, 1.2541287103968284, 45.971445345109515, 68.92251583837694, 60.66462439875449, 55.24474036309027, 42.63331220995995, 21.440536322132235, 16.716059100243353, 30.80859188110598, 50.62001882060882, 38.25064013081212, 38.969179122678696, 30.407998254222257, 7.5802789484300925, 0.18277837444216977, 0.06526294599978194, 0.049953375973047755, 0.10229521491114171, 0.2657033473012909, 1.8935332711665862, 1.630387707583366, 3.9729905657229887, 2.7842140582300003, 3.093301485623083, 3.9403628197408493, 10.099506012855038, 33.44744290074995, 49.8993186027773, 60.97997119349819, 64.34037162411597, 61.91130661195325, 63.068794127433534, 68.36474695513326, 64.63059171553581, 61.683942502544774, 61.940822447499926, 59.0706947542006, 64.40082711558189, 63.00296498883156, 53.82204571077901, 50.62379998545493, 61.51644945144654, 61.271250324864546, 61.401484781695956, 64.12057768914008, 62.103773393938624, 58.46371581477504, 55.8059609320856, 54.728878082767615, 53.600231755164366, 58.96319043251776, 59.739352964585834, 62.99470839961883, 60.96168902612502, 64.30481141613376, 60.399295668448175, 59.612613339577955, 55.703489011333836, 65.53432149271812, 57.24331740410098, 53.08955484820951, 54.75192200752997, 69.7659509412704, 46.60846964005501, 38.187466436816806, 67.71859922716695, 57.41567419421289, 65.61430254290181, 55.558886912561235, 60.84248035184799, 56.55512579025761, 59.35653355813796, 57.110525561917214, 61.93643331527711, 58.602650088648645, 63.90541999570785, 58.83119875384916, 57.95035600662232, 56.625238157087765, 62.40101060559673, 61.41920212776431, 59.311190958945986, 48.233609584070024, 45.945153697844475, 46.19564017941875, 53.43966560979044, 60.652774918463926, 64.30935352079331, 63.911758545906316, 60.3531176044095, 60.822907724688136, 61.858350692256806, 67.76261606524068, 64.86567504944341, 67.27576363471248, 64.13525127595472, 69.855922268283, 71.50648701575496, 58.78865280459004, 38.79591234268681, 16.45608244403716, 2.9802742215894886, 3.3320568934563672, 3.3733030672996276, 4.48268614469036, 1.1764130741357803, 0.15601696206196664, 0.027483862021096775, 0.05348434033353002, 0.048507266272340095, 0.07227933845452725, 0.04632232605569786, 7.359835861190674, 32.26013556603463, 29.35461436548541, 61.479057496593846, 46.60124855656778, 19.059710579533732, 14.329114460176038, 31.92967195664683, 41.01146705688969, 49.8066996758984, 52.18728811510148, 53.144205231820386, 36.28386566715856, 0.9175454680958103, 0.043244590802538785, 0.06190519028853986, 0.08580682709092095, 0.044272814862309925, 0.04757155882074468, 0.03252938029266173, 0.07531673151759372, 0.0663210972843151, 0.07827039117053633, 0.054808944659007174, 0.06908705773492975, 0.07068255841131173, 0.009358008185611858, 0.038519237911508936, 0.040764561178342956, 0.014191068250746017, 0.03806740308420793, 0.04027630653112166, 0.038963404198687886, 0.029282902682861014, 0.01861594422089477, 0.06975768344296564, 0.04761560121551157, 0.021450113309847734, 0.04463780979295412, 0.049923739861696965, 0.02047042666573919, 0.034755191300064325, 0.0338854861535853, 0.0155534052793237, 0.04658436259975837, 0.010757598154727491, 0.1102976008288322, 0.01673155370348644, 0.04074315285129894, 0.042306910674538345, 0.024471677081178755, 0.09161935833793494, 0.0488414989423848, 0.022640320915548552, 0.02487257472239435, 0.05502120464018757, 0.09740073278906847, 0.10585351711920193, 0.13834784888932783, 0.04616381863372461, 0.044387490563695474, 0.028304374746737943, 0.041958834795701894, 0.13981735874568263, 3.0218425200831507, 57.602026001099624, 80.31169029974168, 70.19030432547294, 63.92913856813985, 51.07608456765452, 33.8094659005442, 26.122763733710013, 31.721258778725904, 44.086424842957534, 31.359635860689227, 48.6611871565542, 30.092253338906076, 6.189243216668406, 0.2425997289678743, 0.04629642845341756, 0.15216937739281886, 0.8129124439531757, 1.9941469690492077, 3.097053722989175, 4.9800926927597295, 5.48651873104034, 3.8305082628803873, 3.0175896902238173, 5.101500345814613, 10.422898569414693, 29.83383582484338, 49.33854518398162, 64.41586940519272, 66.48790067242038, 64.99887481812509, 65.287184715271, 69.22886863831552, 66.03828722430815, 61.64613085408365, 61.52873039245606, 59.31841596480339, 65.12057419746154, 65.99936162271808, 57.306506787576986, 54.27240048685382, 64.48824890198247, 62.807536817366085, 65.06605325206634, 65.10434735205867, 65.46667237435618, 61.669123788033765, 58.36003580401021, 57.67486049282936, 55.797072841275124, 62.35005901705835, 62.62021226267662, 65.11460827242944, 62.05256685133904, 65.2613127616144, 60.059524274641475, 62.051947116851814, 57.8187487202306, 66.47643950677687, 59.02406561759211, 55.25240859677715, 57.348456536569905, 71.63804331133443, 49.77783103143015, 38.908405919228834, 71.88040656428184, 59.01520106100268, 66.84255353866085, 57.610502243042, 63.35101650607202, 59.15909713314426, 60.26446419377481, 58.7364774365579, 63.56052206408594, 61.266347362149155, 66.40982197177026, 59.745930779364805, 58.18725932028986, 56.33947780055385, 62.723762835225756, 63.79897079160137, 60.92279872586651, 50.18769125784598, 49.100269040753766, 49.51495770485171, 55.527398124817886, 61.46510170352075, 69.06643544473957, 66.17713912840813, 60.01605656839187, 60.17720714692147, 60.93450700083087, 68.98091993024273, 68.29362653916883, 70.21463871002197, 65.65195337418588, 72.82617630497103, 74.03500372363676, 65.65416166859289, 43.33253352872787, 20.75287618944722, 3.097299606569352, 2.5603312974975956, 4.799551877283282, 7.761637578087469, 4.071611209261802, 0.7964727486814223, 0.1894082065912024, 0.0992196017215329, 0.06169641217697532, 0.08273264648573053, 0.11121264688910977, 7.800477868126285, 33.43189070301671, 34.75281553883707, 58.9366908996336, 36.0415808616146, 20.031009066489435, 27.68808557141212, 50.87280381110407, 50.41729111825266, 59.04595244315363, 62.07572060246622, 63.33604874149446, 47.972748433389974, 1.5043949263711132, 0.11973739751885015, 0.06825889370614482, 0.026357115223823536, 0.020152875560245687, 0.07424384836227664, 0.05441516780504777, 0.018980517803180604, 0.08886588512048607, 0.04541812396998848, 0.023394515324804573, 0.031102587498964804, 0.045470355844665925, 0.0741844229219902, 0.023556657833978537, 0.03254193264330107, 0.003200474508752626, 0.033177563454955816, 0.033101107880112626, 0.030446061639175303, 0.06928499953280534, 0.030285190835955645, 0.06107302345035057, 0.04232124417960163, 0.0071651743905198195, 0.07535485205270591, 0.06669168465680654, 0.21812181018533247, 0.16478056358473916, 0.13995511667622676, 0.06557660537862009, 0.16997428731091563, 0.18453705184642347, 0.30429177827412085, 0.14109085734573104, 0.16193938862171867, 0.11426628867705023, 0.09143537466203974, 0.2518461037787699, 0.14986760493728424, 0.1536421507837311, 0.18265488106877575, 0.07848000814837795, 0.2048866607008442, 0.17694570274362642, 0.24134763486443028, 0.1102367657867651, 0.15546380061536066, 0.27891349167593066, 0.1907901679195704, 0.2582671769684361, 5.6469441613843365, 72.71346307569935, 87.72764498187651, 80.37912368774414, 72.2149847399804, 58.16661980844314, 32.29844731669272, 25.652102847253126, 43.40768221885928, 69.51024378499677, 51.624930058756185, 48.995953606021025, 40.95524772520989, 10.672557430882609, 0.6627437664616493, 0.18151170934640593, 0.18183374206625647, 0.6360532018926837, 1.4768804802048592, 6.477237363015452, 8.44170057004498, 10.354184527550975, 9.595299055499416, 9.767133189785866, 11.364306634472264, 15.920627924703783, 39.14893742530577, 54.94871124144524, 67.86238547294371, 70.38775643994732, 66.32464378110825, 68.13725732987928, 74.55069341967183, 67.16653347015381, 62.22788503093105, 60.33721631573093, 58.627784636712846, 67.70724004314792, 69.48052006383097, 59.56538800270327, 56.64585805708363, 68.96688568976619, 67.9028800226027, 67.23471995322936, 69.11861865751206, 68.69707369035291, 63.907820486253314, 60.25261079111407, 60.09227214321014, 57.93363494257773, 65.1705373487165, 63.9880721799789, 67.05055682889878, 63.19523957467849, 66.62804695867723, 60.72535053376229, 62.61183407998855, 60.821448602984034, 70.65710559968026, 62.287257948229396, 57.52136245850594, 60.732465713254875, 74.78544727448495, 52.69538802485312, 42.51165989906558, 71.65032032997378, 62.94086602426345, 68.77047692575763, 59.86148380464124, 65.8515824041059, 60.1917826744818, 64.00053355001634, 64.24084148099347, 66.2067137995074, 64.76011622336604, 69.10918143487746, 61.16413824019894, 57.705949198815134, 57.212056113827614, 65.00474268390288, 66.71840267796671, 64.50682524711856, 51.98636470302459, 51.37882486466439, 52.34730120628111, 57.020256134771536, 66.26063069989605, 71.02868741558444, 67.18251320623583, 60.003759937901656, 60.53875553992487, 61.85667584019323, 73.33155801219326, 70.55162522100633, 74.2099335885817, 68.71867810526203, 76.19833992373559, 77.55618602998796, 69.11794400984242, 46.59325084378643, 23.392852929330644, 5.414287303724597, 8.569660052176445, 14.963074403424418, 17.681628965562393, 5.1602324458860584, 0.3460646528870829, 0.17942252628985914, 0.2309191863863699, 0.17518173933269518, 0.2252997782441878, 0.28652693475446395, 10.949796438217165, 48.12941182044245, 42.21012769206878, 72.1240798888668, 62.713921608463416, 27.888863855792632, 24.881735617114654, 47.90791557681176, 57.076040083362216, 67.78097275764712, 73.10337804978894, 72.17841256049373, 59.4454772241654, 1.9322279432127554, 0.1895022975100625, 0.23399251663396436, 0.17107981347268628, 0.16638340338343577, 0.1347301825280151, 0.14082640379426942, 0.2702353396002324, 0.1860578589501881, 0.22935318009507275, 0.14910131783014344, 0.20310331526542866, 0.13093230164339467, 0.16557637572048173, 0.1514465121492263, 0.11232334414436934, 0.10110775564586925, 0.09682209125810093, 0.23918947325118128, 0.08148442878718339, 0.09726202490949824, 0.11877237954327177, 0.13913644447682366, 0.2240801049816993, 0.11263132681168857, 0.12472407066173131, 0.205451175570488], [0.06482480499412745, 0.029321733764522982, 0.04840482882554493, 0.023069157783362656, 0.030333988721512502, 0.0494516879740742, 0.015434231684212724, 0.06159374107336325, 0.027152297252248374, 0.026040619404445735, 0.04102134618968253, 0.03335194421872016, 0.02335039249080564, 0.04594940211503737, 0.022743101186689832, 0.042880496025205626, 0.04605803338270034, 0.041585110293160525, 0.02978508672376554, 0.00023825425717316856, 0.0516456603673437, 0.025550273337191152, 0.02688550904783751, 0.28708403389300075, 13.987347560544169, 62.77296112429712, 65.2854706395057, 62.54021552301223, 41.63073085969494, 44.70223696001115, 28.815145300280665, 26.362542144713867, 39.44460176652478, 26.186221799542828, 46.017035053622344, 37.30683941994944, 6.915498000960197, 0.26648236678973325, 0.007641163970073386, 0.13707631147436558, 0.06487116097442566, 0.4539132544830923, 2.4479916739848355, 2.5563635749201623, 1.9843551396362245, 2.1838278876196955, 2.6015228033065796, 4.59293318371619, 14.47433433225078, 27.779474835241995, 54.93102527433827, 61.47853189899076, 66.59786824257144, 61.11984683621315, 60.43972353781424, 61.01776323010845, 63.39029904334777, 66.38987279707386, 62.17168138873193, 60.64244731780022, 60.816424046793294, 62.803081004850334, 64.04012987690588, 54.643393947232155, 48.70947937811575, 57.97346661167761, 62.034139556269494, 59.53154187048636, 63.02514206978583, 57.44691195026521, 55.94517369424143, 51.806025889612016, 52.514158833411436, 52.59885065017208, 60.98971436100622, 61.34849356066797, 62.895519502701305, 59.622685986180464, 61.67315990694108, 58.37507417125087, 58.739532962922134, 54.7388409030053, 62.80687001443679, 51.98210893138763, 51.819738495734434, 53.71211736432968, 69.66721703929286, 43.894393444061286, 40.5559661311488, 70.89431485822125, 56.85423397248792, 58.63291509689824, 54.43261361891224, 58.17397425251623, 54.69878958117578, 56.90281252707205, 50.89227053426927, 54.726206948680264, 56.822313724025605, 59.068317797876176, 60.720184772245354, 57.14568961051203, 57.046943941423976, 62.414785969641905, 62.02883258942635, 56.32054844210225, 46.15092515945435, 46.48526014820222, 45.18852064686437, 54.384470447417236, 59.886328097312685, 65.73253454700594, 59.2212902345965, 57.80975080305531, 59.345295967594275, 64.1618880917949, 65.20920015150502, 61.46576850645004, 59.626765251159675, 63.89653190489739, 62.33626404116231, 65.65113752119004, 69.31851048623362, 64.73226739514259, 45.32097908758348, 22.370938216486287, 3.922512603382911, 2.663445506365069, 5.550524948104735, 5.067187451547192, 1.7177732120598517, 0.18019495742215266, 0.0678075913099512, 0.047156775835901506, 0.020223817217253873, 0.006329520894665152, 0.04058632699231948, 15.78620045415817, 49.729707471786014, 38.382314097496774, 63.13219924126903, 40.71980745561662, 18.21187065493676, 10.83530539466489, 31.075073788242957, 35.23194482249599, 53.659690964606504, 52.839911676222286, 54.50393407575546, 19.422092476198753, 0.2158958957560601, 0.013947768302093592, 0.0554109059063898, 0.032703458451695984, 0.09408210118811938, 0.027754086129848036, 0.05712634913863675, 0.08082455129272516, 0.013898637168289674, 0.013941540964879097, 0.03922873109038319, 0.02201654148408242, 0.025348039531719782, 0.036519591381112416, 0.02564892822486018, 0.05479993163457802, 0.0733562435714468, 0.04732973550656631, 0.027461406068816304, 0.043098520818016225, 0.03291817757511332, 0.024029979512335795, 0.06994839337083601, 0.03856136891690474, 0.0407342509096188, 0.013514633681024275, 0.008423404858237313, 0.05833705151153188, 0.021196758457189126, 0.030190236152960893, 0.01477462519335771, 0.024441244238386714, 0.049876602471715985, 0.016856010432445237, 0.04067095672531475, 0.033813952693655606, 0.03098503896786321, 0.09040467996871279, 0.0634992545500638, 0.05824378030675073, 0.05754821077590028, 0.05607611537280102, 0.016387959439007026, 0.09781649636645472, 0.02802726925320683, 0.009364756462614863, 0.052673558839747024, 0.06373468103007444, 0.08897811700139316, 0.2649476475292637, 20.62166310125782, 73.2548599858438, 75.01734564381262, 68.39572583475422, 52.327999222663145, 52.85953921656455, 38.02651197679582, 25.059179721340058, 40.33154379936957, 31.605935212104555, 45.209650454982636, 32.06246576001568, 4.696572499890482, 0.19341250220614095, 0.04110524047827048, 0.2439186106165571, 0.20985325467922997, 1.705224078989798, 4.037592737905441, 4.943477857497431, 4.550999124203959, 3.7552191028671884, 2.036106891689762, 4.322315137232504, 13.313539278122688, 28.202931957860148, 53.24302934831189, 63.829306402514064, 67.8822797344577, 62.57022557720062, 61.339138707806995, 64.04114969315069, 65.71193033649077, 68.02277118928971, 62.051680395680094, 60.705726915790194, 61.25332901554724, 62.90873789018201, 66.47578054858793, 57.02019337684878, 51.06186989815005, 59.65910911560059, 62.58906079876808, 62.63825516546927, 64.1369810412007, 59.390646411526596, 58.70170562498031, 55.00744873477567, 54.29422455449259, 56.8240434892716, 62.89016546741609, 64.2002567168205, 63.860626528340006, 61.02739264888149, 62.80218278208087, 58.39317198722594, 59.84448817468459, 59.37626308010471, 65.31521397252237, 55.243504816485995, 53.55697193453389, 56.64878806760235, 70.3762560506021, 46.803132949336884, 42.654202753497714, 72.79300089805358, 58.61044776055121, 61.990134485306285, 55.43964293695266, 59.60119532000635, 56.49695311823199, 59.422833381160615, 51.9173780564339, 56.96963402532763, 57.28426302632978, 62.76971732416461, 62.29730706061087, 58.05332214601579, 55.44659729926817, 64.31211094702444, 63.32101429662397, 58.7614707792959, 49.694284546759825, 48.785812624039195, 47.55097204639066, 56.133988749596384, 62.48744395471389, 68.10937712269445, 60.930502260884936, 57.96793606973464, 59.94180217865975, 65.85696389598232, 66.20374848765712, 66.00835953989338, 62.61014353844428, 66.35188856432515, 64.32501946726154, 66.91879657007033, 71.47596313107398, 68.51989238492905, 51.63624609670332, 27.019894123077396, 4.846405079287868, 2.4480039313916238, 6.26876485924567, 7.602630574857035, 5.825039869354618, 1.859829937738757, 0.2365522615371212, 0.24924249268106877, 0.03878387149363276, 0.05339903644316139, 0.12540347573737945, 15.865003812697628, 44.26814040830059, 46.314676269408196, 58.45973460905014, 25.16850402278285, 19.83781272365201, 23.222669132294197, 45.948095475473714, 41.69995284849598, 60.014228743891564, 61.28087189889724, 67.22730667360368, 25.83909203929286, 0.1549556851387024, 0.03198716049683431, 0.04898885595462015, 0.07878586109126769, 0.041015604360690044, 0.006419749293972048, 0.052571627010981885, 0.06790685332230023, 0.03743055036231395, 0.0240999769659773, 0.05185174951029401, 0.04770016200059364, 0.061567460427120815, 0.0532571301465073, 0.027966361432786913, 0.05041252694002563, 0.09548638631860096, 0.02666626809044711, 0.05018456981727674, 0.004351457933925333, 0.04669994611533419, 0.04224116117843697, 0.04791054889679917, 0.0324602370270558, 0.05542049732720179, 0.05252738160291507, 0.15530252378554116, 0.17460602425759839, 0.14255693512818507, 0.11450688625054975, 0.11331254751571726, 0.13847837494986673, 0.1866298355162144, 0.1349279098212719, 0.1977517927486089, 0.159819730587544, 0.14351315075351348, 0.22713094288783692, 0.19580853411987906, 0.18645863018689618, 0.10038847569376232, 0.20258737037018423, 0.10413666045473469, 0.18285027945474272, 0.10720817507394861, 0.1693567744786701, 0.14657813064273328, 0.12079695074428475, 0.1512511290850178, 0.3608904766940302, 30.027414598772605, 86.88864215727776, 83.3674676956669, 80.60931190367668, 58.86738654105895, 60.33629848111061, 41.35234455908499, 37.98907295350106, 56.52602180357903, 37.48276948928833, 59.08661957710021, 47.33866591607371, 9.365521707842428, 0.3793326645128189, 0.15573756979598155, 0.3314441406438428, 0.17103876648170335, 1.0762238502502441, 6.848400465903744, 7.587001400609171, 6.966036760037945, 7.807588144656151, 6.975793655841582, 10.327602624893188, 22.51989414615016, 33.39320044363699, 59.006583613734094, 68.04708203961773, 71.5414196445096, 66.77078985398816, 64.40361984314458, 66.72520406784551, 68.99739388496646, 69.46512083853446, 63.77431085032802, 61.62553448830882, 61.92628614364132, 64.76370911444387, 70.29517281439998, 60.19381838460123, 53.28994089557279, 62.32666992372083, 66.07798945519232, 63.98065497798305, 67.31749765334591, 62.367054647014996, 61.94949480795092, 58.18809478513656, 56.84041938474102, 57.39510528502926, 65.73787681518063, 65.7120793865573, 65.56888934104674, 61.757298669507435, 63.75853899986514, 61.56267458392728, 62.452601540473204, 61.93761787106914, 67.86336606548679, 56.415493334493334, 56.21989257874028, 61.52875784904727, 74.98588039029029, 50.89981325211064, 44.64461734217983, 75.33924671911424, 62.370926026375066, 63.72280620759534, 60.33315666260258, 63.59712562253399, 60.32766926673151, 63.411130751332934, 54.10678625106812, 60.395534115452925, 59.30390319516582, 64.75422090099704, 65.2834153175354, 58.35541132957705, 56.67926880621142, 66.84828019911244, 66.45321123061642, 60.69466583190426, 51.22824507374918, 50.40597115793536, 49.52471656184043, 59.445132055590236, 65.2615834051563, 71.29871906772738, 62.80235536636845, 58.1470589483938, 59.94474395628899, 67.55274572680074, 70.20610363252702, 68.36938319667694, 64.41602629999961, 68.44932894552907, 69.60898553171467, 70.49712780983218, 76.06854869473365, 71.06275712290119, 54.40052863090269, 27.70670702380519, 7.341687544699639, 8.432656565020162, 18.82608440614516, 19.017794170687278, 6.035883936189837, 1.218280330781014, 0.1983882892396181, 0.37729392068520673, 0.14686512250092723, 0.20848131378091153, 0.34717888180767337, 23.14443353683718, 67.90079332167103, 50.63134662566647, 77.90516714895926, 62.34464222385038, 28.935001165636127, 18.401056374272994, 45.46469473069715, 48.17124782070037, 72.53100226002356, 71.024443411058, 77.13273479092506, 30.767532510142175, 0.43353709302121596, 0.22844784802967505, 0.2025719720029062, 0.16181934264398393, 0.2416266900517287, 0.17616174964895173, 0.16340073198080063, 0.3688971986693721, 0.074421810587087, 0.20370703851503713, 0.10850307817060141, 0.11224577008115669, 0.1723293488424632, 0.16245366344528814, 0.1410898614314295, 0.11917894240468742, 0.276745370919666, 0.1361287066773061, 0.11116449826306875, 0.08721030016820278, 0.17436265344581298, 0.10901791989923486, 0.22699277126981368, 0.0706105538073086, 0.16393979740959985, 0.19034715459471752], [0.02652824394434931, 0.0637510676507748, 0.03280532899342718, 0.07871864453679131, 0.022776018069576354, 0.06114485951501036, 0.027586584835643732, 0.017283548781227683, 0.021993725470477538, 0.07605496448494735, 0.0917889625434914, 0.02310391136204764, 0.07095160849031902, 0.08808104336381921, 0.016572582798319, 0.0787722630306117, 0.04417891929587049, 0.05328356784077422, 0.08809661793131983, 0.09796129464502297, 0.04670880592217849, 0.10054825865212949, 0.04104388832685448, 1.5709360977334361, 39.23589637202602, 72.4489619654994, 62.49769310797415, 47.219739652449086, 37.21757411956787, 33.832482368715354, 19.855555565126483, 42.382927710010165, 40.60654117215065, 38.18455996051912, 48.95960500163417, 12.765378240616092, 0.4743787724404566, 0.027462853974993193, 0.11722026242604179, 0.06529876061024205, 0.3683231230224333, 1.7291613235588998, 3.8648020355932178, 2.2396341446907293, 3.707874133702248, 3.700935215719285, 5.631719481560492, 16.885944797146706, 38.05634944669662, 54.92547512054444, 63.501839483937914, 63.272835823797415, 61.926988247902166, 56.707804049215014, 55.49423056264078, 59.49115714719219, 61.27354491141535, 60.671904317794315, 58.730456598343395, 59.66656554129816, 59.39253699394965, 60.00491311473232, 62.91351533705189, 56.90584059684508, 46.885800823088616, 46.04791979635916, 54.537811586933756, 55.90716984964187, 56.61436142459993, 51.9835719754619, 52.29501208951397, 48.9786716430418, 53.97799522646012, 55.67775434063327, 59.81988706896382, 63.53009623865928, 60.56008538892193, 59.08736090506277, 62.10180436411212, 56.70878071938792, 56.785000216576364, 56.36632250201318, 61.43443661351358, 46.59847544085595, 50.379883473919286, 54.75376552151096, 68.7883472442627, 41.26108669465588, 40.83752955159834, 66.90833953119093, 55.56520192853866, 54.30856473984257, 51.64697770149478, 56.428472457393525, 55.63524761507588, 57.64193611760294, 49.4965970900751, 47.7215676922952, 51.695564100819254, 61.61438318990893, 60.41757391345117, 59.23677967440698, 53.62445631334859, 61.29894618065127, 60.73392483495898, 58.03056455427601, 45.05025709829023, 44.48425123768468, 46.31976358352169, 55.445173478895626, 59.609934360750266, 63.39866153655514, 58.89070503173336, 58.44877550678869, 60.47678601357245, 61.1502452050486, 65.06530407936343, 62.42420750279581, 59.36162087225146, 55.93428911701326, 60.031840185965265, 64.00671912777808, 62.12519737981982, 66.11737789646273, 67.37881214387956, 52.320460427191954, 25.983517631407707, 3.524656055435058, 2.9739714630188483, 4.578847952427403, 5.2538672666395865, 2.060715719576805, 0.07767514851424964, 0.045272655364486485, 0.06978487190339835, 0.0371449910885384, 0.03926556076734297, 0.36891147854828066, 25.938224061842888, 39.4089944901005, 55.63559670602122, 69.46865881642988, 40.431693676979314, 22.677163539394257, 21.251562410785308, 42.986533411087535, 47.248710278541814, 55.069253521580855, 51.97990063698062, 41.014459825331166, 3.0660378259997216, 0.1508419768464181, 0.01968176213033017, 0.05862859776243568, 0.04906720759707594, 0.0032647583828938585, 0.03414026401456326, 0.0319074452178733, 0.029250401402673418, 0.013795198061533514, 0.03037664258191663, 0.03395311639554078, 0.03286134534245057, 0.044796753885044206, 0.04649528955680229, 0.04933328142449741, 0.08491514671233394, 0.07016154967488782, 0.042341537848715825, 0.06451849239848315, 0.048421698081637585, 0.0685330918960033, 0.030029836493814667, 0.06365488531188139, 0.02433408194431855, 0.03543739259663609, 0.012795758797907302, 0.08072820807536764, 0.08520324173713885, 0.066249598298342, 0.03245939816077871, 0.03516477637834126, 0.03401435746420776, 0.028075214865947926, 0.022181501281597925, 0.022534851675793048, 0.052978358411740874, 0.014463307170738137, 0.0334690714014634, 0.06540806603527839, 0.03874505381850946, 0.07739934920062942, 0.02914734917031902, 0.025197026364865805, 0.10242007192104094, 0.01716898607781097, 0.05299602439927478, 0.05552527134216601, 0.038806570678829186, 2.1610960364341736, 49.286946404364805, 79.68688026551278, 71.69132478775518, 56.20083770444317, 49.73120973956201, 41.4027823171308, 25.701909103701194, 42.68127887479721, 41.942147439525975, 34.20132637023926, 43.60902140217443, 11.851689565566279, 0.3955418286063979, 0.040055876222228816, 0.12137976745443961, 0.224437132597931, 1.1545974641076981, 2.5635054755595426, 4.587632100428305, 5.274221916352549, 3.4686536798554086, 3.107663489157154, 3.664630492848735, 17.763428034320956, 37.203837979224424, 56.713985704606586, 65.47647045504662, 65.98395455268123, 63.85023224738337, 58.944821973000806, 58.2416037590273, 61.15240250864337, 62.764214238812855, 64.8498365186876, 61.570711520410356, 58.57975913632301, 59.065270116252286, 61.40538361764724, 64.75535838834702, 60.29687866087883, 50.234602805106874, 47.78154857697026, 56.411123814121375, 57.6832425978876, 58.88393502081595, 55.11632588601882, 55.45985883282077, 50.755646536427165, 57.720493347414084, 58.347472452348285, 62.08478912230461, 64.1839788806054, 61.18002776176699, 60.29795339030605, 61.68726082771056, 57.73737130626556, 61.1642009981217, 59.8360433117036, 64.33017346166795, 49.802137959388, 51.96911019663657, 57.07795812237648, 71.58498933238369, 43.2082022390058, 42.556520046726355, 68.40453547816124, 56.936995983123786, 57.86180457761211, 53.51357483094739, 60.94110442746071, 57.284631729125984, 60.82523369020032, 51.70757047591671, 50.42094284488309, 54.033171207674094, 62.741539016846694, 62.641502887971946, 59.74131414967199, 55.12513160705567, 62.20885369085497, 62.193497611630356, 60.54952244604788, 47.34068201434228, 46.0385767106087, 49.064861805208274, 57.362129918990604, 61.24371528625489, 64.88917004677558, 61.25405857639929, 59.66731471400107, 58.05702486345845, 63.5111786473182, 67.56373620802357, 64.31145983357584, 61.06193696298907, 58.77258285399407, 63.31593482725082, 65.91801166534424, 65.16909391649308, 69.25375999942904, 70.86520302680232, 57.28638895096318, 29.59985075458404, 5.334424905238613, 2.353472113609314, 6.798818274851769, 6.259409516088425, 5.714947763950595, 2.101746408208724, 0.6107761001875324, 0.3060922687572818, 0.01996449453966512, 0.1875723228459397, 0.6996178458775244, 25.166474196218676, 42.52082647815828, 59.3166587429662, 71.35560912470665, 36.03362629490514, 21.92911655672135, 32.78595086066954, 51.8269831134427, 54.7134514008799, 63.017481680839296, 62.905627450635365, 55.24877648199759, 5.1281896233558655, 0.24255210894250104, 0.02743048484497253, 0.0536513360097043, 0.03151132030442598, 0.014953706864147417, 0.04983968852508453, 0.029579118239663305, 0.049130088093900876, 0.008920194682544999, 0.05660419893120566, 0.07957218905850764, 0.04712560754870215, 0.0395074836729515, 0.02544126285600566, 0.06937845459868831, 0.03937361363862311, 0.0675862378651096, 0.035415470990682804, 0.059137008182944796, 0.026671737958226475, 0.03587646439911858, 0.03625632909637305, 0.005648782826028765, 0.011154582044259917, 0.008502025589076503, 0.16029176332296866, 0.25565349947540994, 0.22386219893251696, 0.17974840477108958, 0.10989666871366002, 0.17243021197857397, 0.15035765606068796, 0.1486245813148637, 0.10880545307431491, 0.17747421148082904, 0.1592408285866822, 0.12063212692737581, 0.21015138545584297, 0.15030012285757452, 0.163247024099673, 0.24330356458742775, 0.08851199846474395, 0.07727957135366817, 0.26071179417833207, 0.11482649047168032, 0.1911743303700801, 0.17716774566759988, 0.14398697613468095, 3.951033627794635, 60.87619704584922, 89.0816314758793, 80.59974132045623, 65.16071573380502, 54.06207907584406, 47.76114832970404, 28.70142794424488, 57.77744223994594, 53.36988272205476, 47.64053152453515, 64.57079518225886, 15.790893570069345, 1.0482154305904143, 0.15792576205586234, 0.3541575137886309, 0.16650320421303474, 0.794280879199505, 5.690150539721213, 12.472908669902433, 9.614331376168037, 9.354187038636978, 10.60365511525062, 11.127840665078933, 23.110004932649677, 44.346983971134314, 62.26289610708914, 66.86717817860266, 68.59990089170395, 67.79767420984084, 62.42807495978571, 59.44772474227413, 64.0942781971347, 65.09112896457796, 66.48646508493732, 59.40543374707622, 59.277905725663715, 58.41478816924557, 63.5391608361275, 68.94856822106146, 62.519611312497055, 51.08542765340498, 49.487956108585486, 57.676919737169825, 59.73921175925963, 61.83946055750694, 56.783874496336914, 58.71077806718888, 54.03157480301396, 60.66834280567785, 61.51807723506805, 64.00775855587375, 68.16719285903439, 62.49790491596345, 60.03720206599082, 61.62488337486022, 58.46814417069959, 64.66796405853765, 61.141604223558986, 66.65373063856556, 52.278812700702304, 54.67240771939678, 60.51006340211438, 73.5026204201483, 45.90032492914508, 45.508844929356734, 69.84643013246598, 61.415299369442856, 59.274858044039824, 57.00613167978103, 63.545479774475105, 61.956743348029356, 63.446286955187404, 54.7008409807759, 52.640133596235714, 56.196934946121715, 67.13881800251623, 65.92370694683444, 58.78223972935831, 54.888871562096384, 65.07076009627312, 66.02047966372582, 63.86653754018969, 48.83834492775702, 49.14835337669619, 51.25636454551451, 60.07256615546442, 65.77203673701133, 67.25336690102854, 62.25058378711824, 60.224597223343395, 59.72295353489538, 64.39764999574231, 71.71049733315745, 67.80018452675112, 63.393817409392334, 61.347614949749364, 66.01803994947865, 68.99152601918867, 66.72581595759239, 71.91878303404778, 72.76873711616763, 60.037880636030636, 33.66505207553987, 7.740661722998466, 9.69028317159222, 13.75136894564475, 15.452280256056017, 6.022602790786374, 0.9848187743656098, 0.45185431657779607, 0.35534976110343014, 0.0873724350164975, 0.26905694315510414, 0.9121782560983013, 35.89804172515869, 54.63205045269382, 62.112026060781176, 84.09605579991495, 54.721139246417636, 31.494659531501036, 30.78819359502485, 56.220861404172844, 64.17612629552042, 72.06003542869323, 72.78606614758893, 68.26758200122465, 6.282023941316913, 0.5175863458744941, 0.1454011591211442, 0.16243812718218373, 0.13296562156850292, 0.11149570105537293, 0.2480369001146286, 0.13572078017938521, 0.12274219354073848, 0.10082809524911066, 0.1056297964626743, 0.1954880029323601, 0.21026720262823567, 0.08260418120170794, 0.17341976775036705, 0.24090189426656694, 0.17810580500912282, 0.14158308415883972, 0.07999971974641085, 0.14731109292516786, 0.16673378135648467, 0.10665650749879499, 0.1506745713132043, 0.1575846843902142, 0.1382086966787615, 0.19381509673210884], [0.022362296116508307, 0.054817712535300565, 0.09094297164870847, 0.08569798131863918, 0.016961437537364902, 0.0251413470945291, 0.028302986212375186, 0.037605375457074375, 0.05097502699842857, 0.05753185862915651, 0.052120401223580685, 0.05458428171433268, 0.032849896158422195, 0.05640203598886729, 0.035884803266174374, 0.03248588565076071, 0.014768329865839935, 0.027549554060603824, 0.06790195035958482, 0.03425630718289364, 0.01770813194584222, 0.07925879014956375, 0.09142689406871797, 6.685822634927689, 53.704719774184696, 68.62120720647997, 63.123526880818034, 38.75143658730292, 22.17030505980215, 39.91498808706961, 38.76628668077531, 26.72419251934175, 29.951114692995628, 49.3756704176626, 19.841027106008223, 0.5214959683437501, 0.033759418724765705, 0.06214246304044801, 0.10910227384057739, 0.265777780404014, 1.0656040330086987, 3.4093395981096455, 3.2132556553809875, 4.689493602321995, 4.045263913369948, 9.074690707268255, 23.56272685912348, 46.70481481859761, 61.75496093688473, 65.54620235197007, 63.52169059938001, 59.44523403721472, 55.53360723680066, 55.66073125408542, 54.71512625294348, 56.73866918010097, 57.47576490525277, 62.17057920271351, 61.601627642108554, 59.68976243849724, 57.392398849610366, 58.611651928194114, 62.05252762763732, 57.706035490958925, 53.76142940213604, 47.44866094281597, 47.16732501983643, 48.31995271867322, 47.674785583249985, 47.54218593720467, 49.01958196393905, 47.3264124316554, 52.67403464163504, 55.0018201335784, 61.20661750916512, 61.40293605865971, 61.54576524611443, 58.03881722111856, 59.662670627717056, 54.273690946640514, 56.51166592874835, 60.39730310440064, 57.935753022470784, 43.04698105781309, 53.02868750787551, 54.6978089886327, 68.33245015913441, 38.282332881804436, 39.73007579003611, 68.06111628009428, 52.543486395189845, 53.08381249827724, 48.40669593503399, 58.30336147739042, 55.47408919180594, 58.552443750443004, 47.01885546407392, 45.78245770546698, 47.55949143440493, 57.71329972051806, 61.30037784576417, 60.24035338432559, 51.94042198119625, 59.356243302745206, 58.82253031576834, 57.77610863408735, 47.407734932438025, 44.85712351337556, 46.87512413147957, 55.92309859491164, 59.6822589443576, 65.06921468242523, 54.46151756471204, 54.35975951533164, 58.027885575448316, 58.96305314956173, 60.46403438814225, 63.669297233704604, 55.580707057829834, 53.15108506910263, 52.207409874085464, 57.39621139341786, 60.904406732128514, 67.12501910425001, 62.864140541322776, 69.8387344421879, 54.663947166935095, 25.64909438933096, 5.9193576728144, 4.360500881748815, 7.158524624762997, 5.073033253992758, 1.0126591449783695, 0.37313201014072667, 0.19264783920539966, 0.08650438845037453, 0.08026819525947494, 0.12192564340488565, 3.791867033127816, 37.352221242843136, 38.601904069223714, 59.94290436467817, 56.50642956456831, 52.26000885809622, 23.501451592291556, 20.088303127596458, 35.43533148304109, 46.69198474576397, 47.62410071588332, 62.565977650304, 22.22269419700869, 0.29532910114334476, 0.04180120454440194, 0.04292623913516441, 0.04145631559133049, 0.10495678056031467, 0.05135619404515432, 0.06649265501407847, 0.008374106142699959, 0.09425474676273524, 0.0387016051418839, 0.02125486048058637, 0.1548893725679767, 0.04348140773213199, 0.03348486430402245, 0.06503679684453434, 0.05058071388292217, 0.0955868357672326, 0.06530393170373094, 0.006626347406587053, 0.019602948919900005, 0.05722210629873219, 0.04000222325445183, 0.05182143541113023, 0.026504554590510748, 0.04116781453992571, 0.07071274227552837, 0.062160006453914035, 0.030535805009065137, 0.07185839612277285, 0.026119865454553116, 0.043219202648728125, 0.03287643344411927, 0.032447424206522205, 0.06425352556811226, 0.031992287540267554, 0.039953837141154275, 0.06913469308206151, 0.03594912400829696, 0.06051648738643816, 0.023992234360306494, 0.020210743926826025, 0.0036455976876295024, 0.07791393045936862, 0.0667197771009899, 0.030364013622484864, 0.049419791903346784, 0.04807539952678546, 0.10260445396265677, 11.140893332419857, 64.87710091375536, 77.526823166878, 71.17044187361195, 50.75061413549608, 32.75839032665376, 47.01948696567167, 29.44769613204464, 32.891709727625695, 30.636054661966142, 42.88886639379686, 18.77304807786019, 0.1991893720602797, 0.09387147297421772, 0.07458254349448028, 0.0593274538104813, 1.3129437931122319, 2.00388033063181, 1.889990022586238, 2.4916692270386607, 5.574575451112563, 3.1188417538519833, 8.756026567951325, 23.68278276535773, 48.567309148849986, 63.57383851082095, 68.43867578814107, 66.04861090260168, 61.07592021265338, 58.50856027295513, 58.40056957737092, 56.84775029459308, 59.7387763761705, 60.71245378063571, 62.58899019610498, 62.74980345079976, 59.762742057923354, 57.99230967798541, 59.32893968397572, 63.90395695163358, 60.60454153245496, 57.52109573733423, 48.52152332182854, 48.629141392246375, 50.66077224669918, 50.65658315535515, 50.468058355392955, 52.063498112463186, 50.22473019938315, 54.476077402791674, 56.41483829867456, 63.25141183791622, 63.597019718539336, 63.440619130288404, 57.670447826385505, 59.86872449997933, 57.41040645107147, 59.28522879077543, 62.045153571713364, 60.92991782772926, 45.59920457101638, 55.45239064001269, 57.0156983406313, 69.59947770641696, 40.44331173742972, 41.97418928146362, 69.02132818775793, 55.26944345043552, 55.35044823923419, 51.96058688625213, 61.08066235819171, 56.21471505011282, 60.8828729198825, 50.29647034983481, 47.690757474591656, 49.17140906856906, 59.549090554637296, 63.199075652707016, 60.093452776632006, 52.61170033485659, 58.84520946010467, 61.39400874414752, 60.13771280165642, 49.85417996683429, 46.87389642961564, 49.27155894617881, 58.125995820568455, 64.22043731135707, 66.94248768591112, 56.26843190962269, 54.42839314860683, 56.57852665070565, 60.90929400536322, 63.81102815751107, 63.82532127441899, 59.10804748535157, 54.542879289196385, 54.429385508260424, 58.6941001492162, 63.94471037772394, 68.15623375677293, 65.55884415103544, 70.86353994184925, 58.9898076365071, 28.77020278284627, 6.331494835115248, 3.352005823004631, 5.161866603359099, 6.430545468484202, 6.233718481756026, 2.1191274110347997, 0.5212688998829934, 0.07126314580560693, 0.02241805199563744, 0.024144130443493207, 4.20491712708627, 36.21551052216561, 44.17403490312638, 71.2244293766637, 44.74341792445029, 32.26726055145264, 21.518575799080637, 29.59003894559799, 45.42502780114451, 55.48798222695628, 54.20251561749367, 73.80436051276423, 27.23327498282156, 0.28702415646083895, 0.023221038544790882, 0.03181594750663686, 0.04649105309058101, 0.08733101264243165, 0.049667092746183764, 0.021659841370438377, 0.07414956592143544, 0.06518496590996943, 0.03253648958859905, 0.04927166497274753, 0.04103295242173537, 0.0421672681677005, 0.001439509494136268, 0.08497335407282076, 0.04450592009590999, 0.06734537982171582, 0.006959524790516064, 0.05060752312983236, 0.05690096607131343, 0.055286761358260154, 0.03701293285215094, 0.053551675631634654, 0.02026155662362374, 0.0326629055874242, 0.17107386863039387, 0.22207211192336776, 0.3397055715322495, 0.22985836911586024, 0.07038996645039128, 0.18117524353006195, 0.08679528735698232, 0.08815756022569635, 0.10668793242544898, 0.1277454295045426, 0.12688679815900902, 0.1487241574232617, 0.10670904580864216, 0.17241000257913144, 0.06703524444732936, 0.16892074787568662, 0.10094241088917179, 0.14491147571994414, 0.13819847706585162, 0.14128806369919933, 0.18260698525174973, 0.13348303735256195, 0.2689492311929503, 16.977385051788822, 78.34482562157416, 88.56350991033739, 81.53836450269146, 54.85052254892165, 34.3390094080279, 51.67232797991846, 51.473624629359094, 39.76326688643425, 39.563496651188025, 64.10461756490892, 26.755875464408632, 0.7747545850373084, 0.1750096453413848, 0.319918409110077, 0.1921063989040352, 1.9883657631374176, 3.327281898067844, 6.577236719669835, 9.026009190467096, 13.65885788394559, 10.875560679743367, 13.891783914258404, 29.15676020806836, 52.70785723963092, 67.44673190578338, 70.5974228151383, 69.9492197652017, 63.57952594757081, 61.006223617061494, 62.30557541693411, 60.53770826708887, 63.548139141451934, 63.18937955364105, 65.53021084877753, 64.75813542642902, 60.964336625991336, 55.700582535036155, 59.61227993811331, 66.02475504721365, 62.49200174885412, 60.3078495302508, 51.56797724385416, 49.67990513770811, 52.88160254878383, 51.68904512159286, 51.78381742969636, 54.18235071243779, 51.77167769401304, 56.76249365652762, 58.899040068349535, 66.4586554804156, 67.00867376019879, 63.699797584164536, 58.85814935930314, 60.3222877748551, 61.20922196295954, 61.932314826596176, 65.10258228548112, 64.38493367164367, 48.813198612582305, 58.13616652642527, 60.13159782655778, 72.19916189870527, 43.43016524468699, 45.40727515374461, 72.40487452476256, 57.888394325010246, 58.52852513713222, 54.586841214087706, 63.05861949920655, 59.871478003840295, 63.947201082783366, 52.369752853147446, 50.77517601751512, 52.14870768208658, 61.6699121844384, 67.03007421185895, 62.321386491098714, 52.58155692008234, 61.13596777762137, 64.03735676119405, 62.99231575381372, 53.163385621963016, 48.98649677153557, 51.885740218623994, 61.202153851909024, 66.74782045425908, 71.25559653005293, 55.80153257616105, 54.68212343031361, 57.21100884099161, 61.115665589609456, 65.678543121584, 67.92039732779226, 61.077638210788855, 58.37217161732336, 57.34256905894126, 63.092591147268976, 65.33133491393059, 73.22057062579741, 68.31341881905833, 74.35863848655455, 61.84816429691931, 32.01930595982459, 10.996708966070607, 12.938175316779846, 19.275323267905943, 15.994920557545079, 6.745990812778474, 1.4034822703369203, 0.5115010643437986, 0.266474062396634, 0.1816421587981524, 0.3068149041744971, 6.296434729330002, 52.32829732279624, 50.721180669723026, 67.77765443248134, 70.5793171544229, 74.11567118860061, 33.24823356443836, 31.870797180360366, 50.87927964425857, 66.10383002988755, 64.70195924082111, 83.20273599316998, 31.911727113108483, 0.526768614447886, 0.11858697860471665, 0.25117874926617073, 0.20383117540228754, 0.18345519780151306, 0.10843706437416616, 0.14170104637742043, 0.15217751324657472, 0.20744162521535353, 0.10132690275748892, 0.13633366584056808, 0.29085704756359904, 0.3081847306701445, 0.08259783033281565, 0.16888273459288383, 0.08237476851190291, 0.19611549022937977, 0.19896645579607258, 0.13354253174076158, 0.14445735412018915, 0.15056420868683248, 0.13040388483674298, 0.11532210339341434, 0.09548526016935226, 0.16681616645186179], [0.04552054226458554, 0.03640987992947621, 0.033541972328337936, 0.03105046479181657, 0.10689731957691331, 0.06748633999978343, 0.023267835025645556, 0.01998891359225156, 0.005530018609152326, 0.06364646217515392, 0.13432384949297677, 0.024725780784783345, 0.0112428842112422, 0.051991039616686684, 0.0254925984078117, 0.041548675151481744, 0.01858906985651101, 0.06440281312191679, 0.025140297554072835, 0.03460717162177448, 0.10268948206137266, 0.03449130465366668, 0.5554284539914901, 48.563139669356815, 76.71013862855973, 68.66199201153171, 52.02273684163248, 39.18165783728323, 25.708161361755867, 39.880553599326845, 57.380223812595496, 31.04559913758309, 51.27987915469755, 32.44706003896652, 1.66582350288668, 0.015826543395016945, 0.15803368852263497, 0.06413322678136249, 0.048992774494352846, 0.9722670059530967, 2.8266918563073684, 0.824342966079712, 1.5720114400309901, 3.798045256445485, 10.955723139547533, 36.01368888731926, 43.826132435952466, 62.276828365941206, 62.57087669064922, 60.79597280871484, 60.59597115362845, 56.50496652049404, 58.09114556158743, 58.029740856539824, 59.216430417953006, 58.16095198354414, 59.36451950380879, 60.066710056797156, 64.5790909951733, 58.08166911525112, 59.43306684494019, 58.326577986440356, 59.95323981008222, 58.42414302210654, 57.121665093206595, 51.866571595591886, 54.89473942787417, 51.497402037343676, 52.38096298709993, 48.404848498682824, 48.25146029072423, 49.035910790966405, 53.04316105381135, 53.990295779320505, 58.286911056887725, 60.05468799221901, 59.965395235246234, 57.26367058292512, 57.83683476909515, 54.060714091024096, 58.98021744143579, 58.07907250619704, 51.467113494873054, 41.92572055324432, 54.62406058465281, 54.54631528546734, 69.40841121058311, 39.69628849337178, 43.393871553482555, 63.45934452549104, 55.24663879025368, 51.343833400357155, 46.01816469623197, 56.55881281821959, 55.92205524444581, 60.112229162646884, 49.3903479268474, 44.41420555114747, 44.64450359344483, 60.04148921658916, 60.849619065561605, 58.68543563350555, 54.09035544241629, 58.64570986840033, 60.52758462967412, 59.875804378140366, 48.501350572032315, 43.691712810147195, 46.05975750953921, 57.19430346642771, 59.75584653116042, 61.74908914873677, 59.47463220165622, 58.87339168979276, 56.23914749391618, 60.79683180778258, 60.48482295005553, 61.18636238959528, 63.16772414791969, 52.989742294434585, 50.630974000500096, 52.56082719372165, 56.107367623236875, 59.10858485006518, 62.82689371416646, 62.55754063206335, 68.00435173896052, 54.29136906900714, 25.443091507880922, 3.8386611544316818, 3.3495494386842175, 6.816427755740381, 6.82068843034006, 1.2041356510693029, 0.5918244945426142, 0.1159543174529268, 0.24242121515975845, 0.028448592713703553, 0.010822425472490009, 12.026980288567083, 37.004071666348366, 21.90972043621925, 60.01505636399793, 85.22885199516051, 64.66069198423817, 27.068643300764023, 30.100553074190696, 40.6423367223432, 54.988699805352, 61.24397808505643, 45.74795653743129, 1.8597392329285223, 0.10143198703806247, 0.04093349888740529, 0.09937583003193141, 0.07275943809579458, 0.09186996101972558, 0.0344886961242845, 0.06379476147553613, 0.09411107463341567, 0.06921686367281983, 0.055369862745846474, 0.0549528427842644, 0.056144707055101474, 0.04466633890725432, 0.048366574225045984, 0.042322469920280485, 0.018107231195655563, 0.04029008079200022, 0.05838741413167408, 0.03470960906856964, 0.07940770232028539, 0.023869595174948056, 0.02720358109311952, 0.04688381487804075, 0.05554019856537062, 0.023037545165167223, 0.030331724931696252, 0.01071103820351944, 0.05910108248973566, 0.05566662988595425, 0.0590082556159506, 0.02449559051573517, 0.04254025722583456, 0.05660412615285285, 0.0047040360157317935, 0.05924434859245535, 0.10036108038959005, 0.03785107517614961, 0.046203387075013695, 0.056510521699824644, 0.07652449977373885, 0.05030462345589073, 0.03554525394593516, 0.01676509686325106, 0.06501366865010032, 0.030431640034000722, 0.06432318594306707, 0.9553697416859289, 56.814198340139086, 86.97488723262664, 76.93754980641027, 59.86794002594487, 46.03266569875902, 27.437946219598096, 47.36396520368515, 50.59117763273178, 24.619838960709114, 45.018352539308616, 31.30475013486801, 2.2534453003637256, 0.04542352872029428, 0.1535979781540171, 0.14577507131522702, 0.5628145221740969, 1.9003922708572882, 6.664313827791522, 3.244498314396028, 2.8253771268552352, 3.9566315854749377, 12.854782785138777, 34.264245110173384, 48.082049200611735, 64.6732121898282, 65.08211143555181, 64.13367840551561, 63.62673167259463, 58.92930115422895, 59.705247955937544, 61.7808368129115, 63.57533685622677, 59.22712672141291, 61.581745147705085, 63.36191285041071, 65.74192077882829, 57.802482651126006, 58.863009175946644, 58.61786104017689, 61.41538958395682, 60.889235004302, 59.780161303858605, 54.92168218858781, 56.30494525355678, 54.160714918567294, 54.59509388093026, 52.33647938697569, 50.603819431797156, 51.444171551735174, 55.414602525772594, 57.24154449278309, 61.392612380366174, 61.678466873784224, 61.41515424174648, 58.145286037075905, 59.35258373137444, 56.403404589622255, 62.170500755310066, 58.59315795283164, 52.95033424131332, 44.59061414964738, 56.41440291558543, 57.8069188517909, 69.86164108399423, 41.86895208974039, 45.92585171422651, 66.42788840878394, 57.89913769691222, 53.72746559881396, 49.35997701460316, 58.20079541975453, 57.39321862497638, 63.0039220471536, 52.27854990190076, 46.482345827164195, 46.055093811404326, 62.54720126428912, 63.20711258919009, 59.85130525404408, 54.78547396198396, 58.539354801177986, 61.926917645239065, 63.15319568880143, 50.92088030230615, 44.9792504310608, 47.32119175695604, 61.52046203613282, 63.1072372774924, 63.313679464401744, 58.73514383069931, 58.32528360428349, 56.04368009874898, 60.45359696111372, 63.317637135905606, 63.759719633287006, 64.01303022138535, 55.9459581682759, 52.97319381467758, 55.048037421318796, 59.61977166514243, 63.54550723106631, 64.6452300010189, 64.93035885595506, 70.93636266646847, 58.73572041911464, 25.950799180615334, 5.065162527945734, 2.7863392474189883, 6.706148847456902, 7.397724976462703, 5.136496222788288, 2.4289078722077035, 0.43706468276439175, 0.10723177058201645, 0.00673655106971461, 0.09365326048986566, 12.55066671679097, 37.12167609122492, 20.333417923219745, 58.58752150689402, 74.62059790088286, 52.67937298743956, 29.477072723450203, 37.94217709572085, 48.42806500773276, 60.70230660899993, 67.55145918938422, 52.06227433296942, 2.687243751941189, 0.1028878069032104, 0.06480337751488532, 0.010655041964304064, 0.03416007887872477, 0.018710217085636912, 0.04437638611923303, 0.05966141451931289, 0.037927921455834186, 0.023953546920130332, 0.07942150722468093, 0.050604267256154176, 0.027062601762853807, 0.02617417342750536, 0.04286815434874546, 0.04517297966465835, 0.016016908583321398, 0.009913771458330655, 0.0493694331136442, 0.020551097639385733, 0.05950422859900902, 0.05564429842296147, 0.018126046315075892, 0.02402977458381605, 0.010861886661469696, 0.09630899620993484, 0.16601712142507877, 0.1110130426804385, 0.15199714550568214, 0.19797830962606017, 0.19080565821739937, 0.09864347295895701, 0.11863564817054618, 0.15505185981671657, 0.2239068925020195, 0.2317206216074767, 0.20961219745297588, 0.12054224183121998, 0.16372227440437964, 0.08345834625464293, 0.13747202653077342, 0.10367664763884199, 0.09057124280520985, 0.09987084540508448, 0.11338612259996515, 0.1503009655542912, 0.2607002722159509, 1.4380202105929776, 69.32178958769768, 95.52115917205812, 83.7836782393917, 68.36156199055334, 55.05702749375374, 35.871165644737985, 48.8347206577178, 71.36423049434539, 42.18524809806578, 65.22811382047593, 44.625181997976, 2.80881957661721, 0.32623219934682696, 0.33671960595153994, 0.20012090433268778, 0.6910084272103926, 2.820033632939862, 11.881630978276654, 6.507643576591246, 5.625070573822145, 8.511576614072247, 15.324468843398558, 41.27547787081811, 49.58484649658204, 67.40613537449991, 66.80700902015933, 68.09122439353698, 68.0005705741144, 60.62680490555302, 62.11277915585426, 63.91688116135136, 66.72584733655377, 61.99308410767586, 66.01721625174245, 65.03918893875615, 67.8199532724196, 58.72112135733328, 59.21622253233387, 59.11624916138188, 63.296601464671475, 63.798303988672075, 62.83510715730729, 56.169854902452045, 58.291370791773645, 55.48795869273525, 56.78917754080988, 53.52327485238352, 53.99469275628367, 55.060730211196415, 56.658523390370036, 60.87705996728713, 63.397704478233095, 63.689360157136, 61.801068398260306, 58.89744758605958, 61.86105712767571, 61.632167216270204, 63.21888362207721, 61.910620197173095, 56.22284612348003, 46.88227853467388, 58.95801682626048, 60.900766772608605, 72.1766710281372, 46.01603092685823, 49.055428504943855, 67.52300631615424, 60.388297342485004, 55.55984397088328, 51.901743488927046, 61.25534119144563, 60.333027224386896, 65.30634157119259, 54.97550495209233, 48.665670425661155, 49.72921717551447, 67.02218240307224, 65.44252234120523, 60.782691663311375, 53.98266284696518, 59.538770798713934, 65.01460352251607, 65.38223551165673, 54.34025356846472, 47.01674915129139, 51.51755909765921, 63.82995359359249, 66.21839461788055, 64.72895691471716, 59.225400878537094, 58.46441399666571, 55.7145461728496, 61.85657385856875, 67.11542498680853, 67.79172789665961, 67.7366578194403, 58.18982847275273, 55.111811237950484, 56.64994124443301, 62.696702403406945, 65.43065324906381, 67.95696166253859, 67.49270992894327, 75.83462638239708, 60.183055400848396, 31.12731191419786, 11.008512358511648, 11.924588776403859, 18.159816880379957, 18.20146656805469, 6.853002877004686, 1.505246570994777, 0.40041007221706454, 0.2894987430303328, 0.26070140602607883, 0.4225542420341123, 18.103436731523086, 52.40830975194132, 30.4932293968816, 68.63149950581213, 94.79133944357596, 79.19506995908677, 38.688619828993275, 45.00304745089623, 54.90421195184031, 71.3953427345522, 77.8923959116782, 61.74413911757931, 3.4988596074042784, 0.17896210744736657, 0.16185423028805565, 0.17392618251183342, 0.19582293657285554, 0.16867913906612705, 0.16392649812323434, 0.15574345335124, 0.11901712165244165, 0.14288724159761784, 0.21121198822173382, 0.15752650767324433, 0.27645180602708175, 0.1807997685166136, 0.1364550601330496, 0.14005343640042892, 0.08803854080578012, 0.14788264048195657, 0.17542321024642837, 0.1731304316631248, 0.12172021692798984, 0.13808664355066516, 0.10036061307595623, 0.13747870681747315, 0.11690905452856135], [0.013398398990712821, 0.024321947111597946, 0.03734998855619662, 0.10496610385035315, 0.01485663777848165, 0.030460272570170706, 0.05272616609750737, 0.06022871411856144, 0.039658460450629075, 0.11956793886999931, 0.03439303855561922, 0.02285368406333991, 0.060642907215702924, 0.04029191174213925, 0.027801547191977024, 0.0711370017679949, 0.03810025293440108, 0.064416702295984, 0.03988637543854214, 0.03797720772244277, 0.044811922425944964, 0.0937236026830731, 5.7151193676456336, 61.2762866481658, 68.0613673117853, 61.07724205140145, 46.63967209477579, 31.273500611705167, 31.285171624152895, 30.54390641950792, 63.564773913352724, 60.826528072357185, 47.38967241779451, 6.404360215510092, 0.18279325186965928, 0.0366955004902857, 0.06635659013784702, 0.23181733254703785, 0.6778181704782671, 1.2824199084312686, 1.4265341624136896, 0.42902409970279665, 2.4133512618080264, 19.5766064043968, 34.13337522937406, 50.251147362493704, 59.6011600186748, 64.22009214278191, 61.796020307848536, 60.471890895597404, 59.3724819152586, 59.389426554403, 61.084537659921956, 60.836996878347094, 65.04874775486608, 61.460889077955684, 62.0521471577306, 61.39344392284271, 62.84484640244515, 57.60258690003426, 57.7198814576672, 56.962530612945564, 59.2973606817184, 59.59733963012696, 59.52911784571987, 57.781376377228774, 59.396353460127315, 59.30213812858828, 59.19270007841049, 55.22246130051152, 51.53695129579114, 50.970902289113695, 52.380876694956136, 54.111473483424035, 57.38746843030376, 60.72051032896965, 57.62941983438308, 57.46587661004836, 54.56026715617026, 56.0340859813075, 61.84041761582898, 51.402253181703635, 45.61429000669911, 45.25200028573313, 56.6745109711924, 54.284708884454545, 67.08279871171521, 36.625998327809, 40.14928302457256, 64.47215149479528, 57.03690267378285, 49.9726394684084, 46.574074376013975, 55.663163123592255, 54.553022538461995, 58.214566861429525, 51.33887160208918, 45.000509677394746, 42.398495597224084, 55.014465855013945, 57.99510632791827, 58.38620193542973, 53.953978553895034, 55.66563813917099, 59.31765894736014, 58.66546292458811, 49.0877959036058, 42.250198625749164, 47.04816341400147, 57.99826775827716, 60.3195813394362, 58.54592477121661, 54.44420814514161, 53.736224251408736, 57.316971671196725, 60.6346143445661, 62.89641772547076, 58.18392922801357, 63.37364073722594, 57.307059841771284, 48.175809537210775, 49.230727072685, 54.31914729456748, 56.99449008510959, 58.23541033652521, 65.07951482649773, 63.82740797535066, 67.33127301739108, 53.61676454544068, 19.02079282268401, 2.5890428020108134, 3.4716555187779092, 7.593948898776886, 4.744314118739098, 0.8851368232600151, 0.33040428353894147, 0.1547588311856793, 0.02176842475760608, 0.0906005839727098, 0.6811999890112108, 28.970630015096358, 73.49696436235982, 89.22151104096444, 85.52028409896359, 75.43831794492661, 28.63058013300742, 24.61764635578279, 41.10526661719046, 47.18052379546627, 58.12220288861183, 51.06094421878938, 7.39713465975177, 0.29382799782099267, 0.08002045008564189, 0.04108715697281784, 0.0359601556744066, 0.05778924118907702, 0.02558385288613218, 0.04370823870563219, 0.05180274286577779, 0.020832922234530413, 0.07788179307094506, 0.04387727600612468, 0.015757794664692015, 0.03880886511216241, 0.010089187398402682, 0.04383986027190282, 0.05509947201297168, 0.007982234453647248, 0.03697370148954853, 0.016316994799361113, 0.07300732116545401, 0.05413540781685903, 0.022217997710310647, 0.042279871601250865, 0.03924187332872422, 0.03914200993735464, 0.011137586383659755, 0.05010681189296227, 0.06011789183943503, 0.04033385505599361, 0.01440154611989255, 0.039790679565480644, 0.071209037015515, 0.03628370524834722, 0.09315267565750307, 0.027113379985694925, 0.026726587938385147, 0.031086220030462554, 0.05659440832753336, 0.08236385941986116, 0.04965514560500461, 0.017880850298810872, 0.1210210161403783, 0.047525681645399144, 0.07514387909923831, 0.0979746169140262, 0.034972905827265595, 8.381418643459197, 73.14898737015264, 74.95481521852555, 70.27959316007554, 54.28146508432204, 41.234814659241714, 35.07388899403234, 39.55922519007037, 62.359570764726215, 47.60938006062662, 47.565143569823235, 6.875882062219805, 0.1679860593210305, 0.11226881400591905, 0.05574425374488196, 0.4661000279649612, 2.328711661600298, 5.214222400419174, 6.065453704326384, 3.3022581569610105, 2.1787329739139927, 17.65087366104126, 37.32079913539272, 54.308097977792066, 63.48234138181133, 67.25757168185326, 65.87275535829606, 63.4886367859379, 62.02439246639129, 61.385406986359634, 64.52521331848638, 63.05801153182984, 65.93237538491526, 64.95254770401986, 65.30952261340234, 63.09725484540386, 64.46640522249284, 57.91511743299423, 58.29894881094656, 56.63810745362313, 59.361177644421986, 61.641651507346864, 61.99636713151009, 60.26432691081878, 62.89069106501918, 62.406262659257465, 61.77272535139515, 58.458114670168975, 53.52238447435441, 51.794972650466434, 53.950805356425626, 56.672447804481756, 61.290132614874075, 62.736082999937004, 60.203636077142534, 56.323572589505105, 57.22641591102847, 58.13376211350965, 63.75771137975878, 53.505408456248624, 47.66405397845853, 47.02349955035795, 57.9257902022331, 57.05703227750717, 68.58265030768611, 38.70873374323691, 42.66961374590474, 67.28331811966436, 57.68559994236116, 51.3243745219323, 49.10996121744956, 57.6761156512845, 56.47090858028781, 59.79894161224366, 54.04900189368956, 46.412445268323346, 44.790388307263775, 57.49944817635321, 61.30210368863998, 58.61665295016382, 53.58866860789638, 55.44916252936087, 62.00115242312032, 61.76335088668331, 52.0034780040864, 43.48860071551415, 50.54640377721479, 61.34558708437028, 63.62636296979843, 57.81107264180338, 55.288396343108154, 53.06086663276919, 57.57296123812276, 62.52793850437288, 63.972253261073945, 61.44107326384514, 64.78421918807491, 59.64424725501769, 50.48085312689505, 52.308403061282256, 57.63592312412878, 59.628730358616004, 61.52851858446675, 66.28031315342074, 66.40361678215766, 68.43898957775485, 58.86869269032633, 21.553681012122862, 4.518663594799658, 4.05282526246963, 6.668244533000454, 6.823236990359522, 3.238967037008655, 1.1572320711228157, 0.7853385493639977, 0.08655567037602586, 0.14724053622734162, 0.9272722719657807, 29.72964002240089, 63.49881533653506, 89.38732531762894, 86.4494857480449, 73.78068508640413, 38.85348881444624, 31.65676912953777, 45.0064246116146, 53.98144298984159, 64.28085357912126, 60.60067799783523, 10.327027997662945, 0.27445449223441465, 0.06964423348225894, 0.07024155989769967, 0.06211861089292554, 0.015680821980499936, 0.017231408837101152, 0.03424257505685091, 0.14474164934888964, 0.020467609377397646, 0.04912113635650566, 0.048817539542552926, 0.054770533010483756, 0.03032590266347172, 0.017344073557685462, 0.014076630036616999, 0.04803215386345983, 0.0042012496381968025, 0.0752836365192648, 0.04186982303977974, 0.030145230402629224, 0.048622374813402855, 0.02482223316967007, 0.04565153946919788, 0.0325720782031215, 0.18008009019878604, 0.062733392621721, 0.12149765306422788, 0.16252746835591333, 0.13874281317956988, 0.12191985944105733, 0.13861818599604792, 0.14692578134277176, 0.25061044992218096, 0.204486012038204, 0.14722207350836647, 0.13190299633049196, 0.12446018401533367, 0.12983426782152346, 0.20502342271708673, 0.1483370225516058, 0.1117018016896421, 0.2504169667560247, 0.15246163993593187, 0.18662899281949769, 0.1318489871318302, 0.23186677586167093, 10.561067981104697, 83.89387330701275, 84.43520745923443, 80.29935836791992, 63.19787932980446, 45.6310228378542, 42.48997703675301, 40.2320489575786, 71.73463559919789, 75.07320803980674, 62.90182275156822, 10.120870182591101, 0.48871117433713335, 0.32586527387461356, 0.1787128224368057, 0.4109413296945634, 2.044814308324168, 7.281436016482692, 6.4940035343170175, 4.1962766358929295, 5.877121590798901, 24.99512153287088, 38.34488684131254, 54.215608489128854, 63.57515250482867, 69.4340713562504, 65.67131027098625, 66.26370583811115, 63.335432929377404, 64.42440448268768, 65.89165333778628, 64.5228991200847, 70.57906612273186, 67.82693509132632, 66.25696720615511, 65.23516624204575, 66.61153378025179, 59.018895933705, 57.98613978970436, 57.526936146520804, 59.96897243684339, 63.74270046910932, 64.1589149352043, 62.77534984773206, 64.79591569592877, 64.2508670591539, 63.4560771911375, 60.58696931408298, 57.07828367910078, 55.81510005458709, 56.2783908074902, 59.46642660325574, 62.480744546459576, 64.18527326276227, 61.12214534513412, 57.219418402641054, 57.2188731931871, 61.05562586938182, 67.66523145860242, 56.171266955714074, 48.94795163985222, 50.73879211179672, 61.03530799188922, 60.65039011739916, 72.04348302656605, 42.8200444867534, 46.02546422712265, 67.74587538934523, 62.877304015621064, 52.87933541882423, 52.06611433336812, 59.07628020932598, 59.76264792103922, 63.35442896812194, 58.08938049500989, 48.94135029085221, 46.75124783669749, 59.13817521064513, 63.423674491144, 60.25353647047474, 54.07002972018335, 57.23688863938855, 62.897194354764885, 64.74848639580512, 54.33926905355146, 46.19279646104383, 51.715230864863244, 64.23976282919607, 64.44695811117849, 58.835678100585945, 54.11860827476748, 53.11742328828382, 60.410278304930664, 63.26992150275939, 65.57496117007348, 64.66133133057626, 69.08344284180673, 63.35198140913441, 53.53655992015716, 56.128030669304636, 59.980104123392415, 61.57892104118102, 64.60850877146568, 71.64254619229224, 68.94207277605611, 70.96156781719577, 61.352694419122514, 23.93624044233753, 8.521959127918366, 12.4868409287545, 18.508472442626953, 14.456230632720457, 5.460482037836506, 0.5196495125851324, 0.5140131585780652, 0.18294446230415376, 0.301691583928562, 1.3103593188908793, 42.568730385072776, 86.34767670785227, 91.02222411863266, 91.07414845497378, 80.41805713407456, 39.85812940905171, 37.90700912475586, 57.207702282936346, 62.94376073345062, 73.63848347817698, 68.22398877912953, 12.782332685685928, 0.44339456084755163, 0.20156455106071888, 0.1979269664133749, 0.1782448040021043, 0.13152382877324859, 0.1625865797001508, 0.11758672824550061, 0.19556280375728685, 0.1837087882262084, 0.1450701631725796, 0.11539064527999972, 0.13076411470049812, 0.10264931607150263, 0.13847987648219834, 0.16346894444957857, 0.22543778132286765, 0.08286777673469437, 0.1173852930866903, 0.11648834202318423, 0.15021943847738928, 0.25375174749041757, 0.1162707041047754, 0.11716792329905495, 0.11122488131326054], [0.03700845889867314, 0.06133060136269178, 0.046910375146375555, 0.042798716139288685, 0.026564690577346953, 0.010310948785063962, 0.044927138219317125, 0.0401402952810449, 0.09209557391342618, 0.06771714696961065, 0.0928720346682014, 0.03642858779658714, 0.0817706085921776, 0.05867650507078056, 0.060323728173370325, 0.018927533247117555, 0.06350781558261764, 0.08601233017660918, 0.040556024384474566, 0.06940814816663343, 0.04539400369169251, 0.1517301332205534, 22.962641485275764, 73.38889521937217, 64.76308937995665, 58.24163906035885, 48.015835669732866, 27.064034515811553, 21.376727204168997, 32.72123175282633, 55.38876587344755, 62.69596107544438, 22.890797392014537, 0.47914485056554124, 0.06176224211230875, 0.01010530876115926, 0.02415167449432756, 0.5964864153535135, 1.9619547287302634, 1.8280969824521773, 6.794679193727433, 3.3154365852955854, 14.700008880707527, 34.720201030854255, 53.649916418137096, 63.07933353608655, 64.9728185130704, 66.70006167504096, 63.94849154257006, 62.5349909259427, 62.48403149266397, 64.23912740522816, 63.95177848877446, 61.09939167576452, 60.71260283070227, 62.96982488324566, 62.29308659030546, 58.441978039280066, 61.10242759027789, 56.84201578940115, 57.0447866378292, 54.11613325918875, 57.82720535032211, 58.899467606698316, 60.280773408951305, 60.16295325371527, 60.08884791404971, 55.93188470409763, 59.39943252071258, 58.01344733084402, 59.2905318352484, 51.86763455790859, 53.6382120655429, 53.16273450851441, 61.011958122253425, 57.73203688283121, 59.7443735984064, 53.35062388450869, 55.69308688563686, 57.74705956059118, 55.66837595355127, 44.7238649091413, 46.53794542435677, 45.79524070985856, 57.003162445560584, 55.96950807879048, 68.46050770052018, 37.94033358173986, 40.154978306062766, 66.74749097516461, 53.35125146373626, 52.5744221287389, 43.187264627025975, 55.40498487411007, 54.80342272789248, 57.38878634668166, 52.752058429102746, 45.849377262976866, 41.4147965369686, 53.32475977559244, 56.9639701227988, 60.059402681166134, 56.326204499890736, 55.3992425241778, 58.33066509615991, 58.59726859677223, 49.38246396280105, 40.83219512816399, 49.245781129406346, 58.45268610985049, 61.06488266298848, 56.24877299031904, 54.492672950990745, 54.76902354148127, 61.264496003427816, 60.35130546938989, 62.869937804437455, 62.57947060369677, 61.337252047754106, 57.06674406605383, 50.81452131271363, 47.17440882036763, 50.163062695534, 50.66998981660413, 54.30709777339813, 57.3557403779799, 61.67978871253229, 61.67158703650198, 65.02327588296706, 43.93023998506608, 15.526684676447223, 4.399745666211651, 4.927723657700324, 7.149295287747537, 4.704113256546759, 1.5778364048850153, 0.06696458815807296, 0.14489177193853164, 0.1300053046114983, 0.06665446044456574, 5.778898577536307, 33.58760487648749, 70.90806668804538, 71.69900478855257, 71.95429617358793, 38.577903086139315, 29.288481243195076, 41.30058888466128, 44.32468921907487, 61.33436910567745, 61.15876851543304, 18.199515188893965, 0.3609394450341502, 0.11262032578909591, 0.10611650744272817, 0.03105346785647975, 0.05091431453042934, 0.013122388045303525, 0.03791178764414884, 0.013749758513914722, 0.053493280579606374, 0.052984851006899154, 0.019610140570289186, 0.03077918156650999, 0.04138479362271967, 0.02084651454952696, 0.04546049629308043, 0.008469594214411994, 0.015358338226383973, 0.026296801121544935, 0.020909274387503826, 0.035723537927673715, 0.03936471169694297, 0.049374274789325656, 0.06783535433632713, 0.020550268349207697, 0.013117328992173558, 0.027571969793268272, 0.09916610580178038, 0.06215739792453186, 0.03348358876762852, 0.0286430545571831, 0.07151978526024089, 0.018195089989251668, 0.028568786163363728, 0.014567485552341228, 0.034612086075808735, 0.07031510433843059, 0.06559777238796796, 0.07313192536633822, 0.0786999213479219, 0.018142992179960977, 0.06695069898400577, 0.05583683930097088, 0.053850652935403975, 0.020340873536864118, 0.03270151641880793, 0.1205528598098505, 30.171242029436176, 83.34239590552546, 72.64701812498032, 65.9808245012837, 57.29931316068096, 32.75934934616089, 24.362492253703458, 29.224046507189353, 57.234264573743275, 69.44919601563485, 20.855950194020426, 0.7028861608236068, 0.111594901780688, 0.1777363820902763, 0.5456691067064963, 1.7997714636787292, 4.14962298447086, 6.450406389851724, 8.51728170148788, 3.1044741119107897, 15.135617506119514, 40.54304192143102, 56.59668722460347, 64.52615468732773, 65.98424480807397, 68.38474319827172, 65.87904684005245, 63.71886422557216, 65.11480439093806, 65.64010389389531, 64.22146889471239, 61.8304979416632, 62.090292207656375, 63.29475795069049, 63.911491824734604, 61.8721378234125, 63.01622652238416, 57.92333479850524, 57.22839278559531, 54.765175696342226, 57.953313473732244, 61.19086134818293, 62.43325248841317, 61.07598689294631, 60.899680276070875, 57.5938674711412, 61.66615455381332, 61.382731929902114, 59.96024124083981, 54.288933277130134, 56.72550962817285, 56.43947470572687, 61.799981901722575, 60.57224865882628, 59.706208936629764, 54.00972327878399, 58.0573582649231, 59.71372812025009, 59.09726488974787, 47.96588036321825, 47.729161400948804, 48.09170607597598, 58.04449681312808, 58.97496931014523, 68.27658776314028, 39.2095458892084, 42.96738439990629, 67.51864464052262, 57.814555706516394, 55.984922993567686, 45.88647111769646, 57.42024767783381, 55.57662779285062, 60.17517535917221, 54.395064769252656, 48.625485743245775, 43.62511096462127, 55.348655716065444, 58.533565382803644, 64.39921502144107, 56.59809143312516, 55.40371794854441, 59.588490763018214, 62.04023884188745, 52.01500192765267, 43.21016342409196, 51.41133346865254, 61.76463742409984, 61.184358058437226, 57.10433998415547, 54.65241932099866, 55.60678689710556, 62.31341623490857, 63.11288941291071, 63.95918392365979, 65.5440999615577, 64.61884029449956, 60.61697936827137, 50.90406117900726, 50.06734901858915, 51.353580490235366, 53.998105218333585, 58.1621757630379, 60.0781516105898, 63.83830431968936, 64.33468418736612, 65.41448523921352, 50.8373651965972, 16.909820264385594, 3.4527597456209125, 3.632318497665467, 9.200773335272267, 8.71060650194845, 4.354416795315282, 0.734605816823821, 0.4423121398975773, 0.08380597397204369, 0.06890871246615726, 6.326568828475091, 39.99562417307208, 78.92557174928727, 86.55249503351028, 69.66978226938556, 29.999608916621057, 33.235846719434186, 46.97056324251237, 52.46272087097169, 68.1258903011199, 69.6206977290492, 22.182791925245716, 0.24418842678348868, 0.06084730330434057, 0.05440720049063525, 0.007020057227853085, 0.10393311089325337, 0.029574550440414783, 0.07707272761411245, 0.04615847900089237, 0.040643837212795214, 0.02057509917405344, 0.04987608153192748, 0.03233538384759619, 0.04942197142349136, 0.02927001516875481, 0.02004004804597747, 0.041205850805366234, 0.04962326485603567, 0.04263428685766074, 0.10826252656237734, 0.03296119341206166, 0.014049966346412418, 0.024450266838914925, 0.0849191839956949, 0.013399836363180751, 0.18748304295924403, 0.12952292968909587, 0.14042825257826236, 0.14898842711362148, 0.1394122667730816, 0.14607520924220163, 0.17926100431190384, 0.15832372941076756, 0.1318461985717858, 0.2040188209784608, 0.15239603216609648, 0.13022704110030206, 0.1777495894460909, 0.20595739114909403, 0.19534742579825465, 0.10927465894529897, 0.1162351806077265, 0.19185686874533855, 0.1433491772942005, 0.20107034774076557, 0.1600085865826376, 0.23868039250373843, 35.646229482466175, 95.40406073293379, 81.10649585723877, 74.30995402797576, 64.02547197957193, 39.802820067251886, 30.474709926113007, 45.998564612480905, 66.6539659807759, 76.8643662237352, 31.793989327646074, 0.8836216239198562, 0.3034447301780024, 0.3708465553579792, 0.6950790507178153, 1.7604435739978668, 7.197803729964841, 8.718002130908351, 14.223659576908236, 7.815548594920867, 19.908911566580496, 39.91751409346058, 55.8819019409918, 64.40389048668646, 66.80847598660377, 71.65238349668442, 69.27235203404581, 67.25826986374395, 68.5225909756076, 66.19661761868385, 67.04400647071101, 62.406690197606245, 62.49247635564497, 66.62899617225894, 66.17478570630475, 63.16995989891791, 65.12810514819238, 59.58675707540205, 57.195440953777684, 56.261599140782515, 59.483661497792895, 61.003489725051395, 62.99132339416012, 62.71478452990132, 63.38204637650521, 60.61345707985663, 62.72794015945927, 63.83088319532333, 63.72778761771418, 57.838317425020286, 60.13375513015255, 58.60991824057795, 63.940960591839215, 62.60012972739435, 59.6198893362476, 54.867565247320364, 61.69587043023879, 62.41693542849634, 61.4016063751713, 50.434627994414306, 49.98658349437099, 51.07240930680306, 61.84559906682661, 62.31946452971428, 69.8846104837233, 43.800923362854995, 45.79541721651631, 71.57007648098853, 58.786436665442686, 57.97139167785645, 48.271221191652366, 61.51728883866341, 57.767522565780155, 61.00086565940612, 56.78939327116936, 51.32736729037378, 46.682021925526286, 59.305111285178896, 60.64438104629517, 66.52030729478406, 58.06458719315068, 55.486111256384085, 61.3368990344386, 64.47053547828429, 53.462066265844534, 45.140761867646255, 55.343678228316776, 64.55900453752088, 65.28269752379387, 58.31250059989191, 54.50160026550294, 57.08599898122973, 64.6597388482863, 66.73286837916221, 68.24647180495724, 69.23508951740881, 69.23017870995307, 63.709995746612556, 54.73786423283239, 51.06617273822908, 54.54601718533424, 57.08758361877934, 59.42961123681838, 61.81180784779211, 67.72491424314438, 67.17304460463986, 70.7854377069781, 52.75709083003383, 21.677302352843746, 9.901154695018645, 11.361696297122586, 21.695568830736224, 16.637325363774455, 3.6538721669104794, 0.30352657901183255, 0.27804128525237887, 0.1838746615835736, 0.19152944276650108, 9.012180874424597, 47.17575811570691, 75.75734000052176, 77.61935972398328, 81.37992428195092, 48.931524753570564, 43.070880059273016, 52.76715170952582, 60.20563648593042, 75.67760605965891, 76.84684891854563, 27.124089925519883, 0.4453944180521273, 0.1749155237790077, 0.2986457715592077, 0.16658880687769384, 0.15552580777195193, 0.12078614890455239, 0.16763744335020744, 0.18607486610210713, 0.19063604635096368, 0.2233450589401107, 0.12078309221373451, 0.19439478014265338, 0.10668989361053514, 0.10083611618967787, 0.17131417509048216, 0.11528453444160762, 0.08253042991723746, 0.11770463683792662, 0.16127575729643145, 0.10491083826749556, 0.07653039865075581, 0.15833408691950385, 0.16163958777343074, 0.12235066898527647], [0.04452085497999384, 0.03311522688055712, 0.0047926891467443885, 0.031934403851928736, 0.03367936636711802, 0.04852118225948465, 0.04061292939549012, 0.03644689729797744, 0.045318639792141416, 0.015664140415948727, 0.03891689883124444, 0.02635488016230445, 0.021495699371782043, 0.023028589597332384, 0.01564775762568799, 0.0208686429992198, 0.026402749166253115, 0.08147321325997192, 0.016609657623414553, 0.02204461669128749, 0.09271437377338448, 0.38910613845913644, 39.206847298529844, 72.72536354680216, 58.69157022045505, 57.07338071638539, 32.184216130164366, 30.97975430950042, 27.610483438737933, 57.998652150554044, 49.1122087355583, 39.433654431373846, 5.980044093824202, 0.05672544383654191, 0.20628261079470958, 0.11003139293602399, 0.35557428615227826, 1.381068131135356, 3.4765155805695445, 6.679405147029508, 8.545504135470237, 5.8552705568652, 29.972581824948712, 56.831637197925204, 64.38059945260325, 62.412789483224195, 63.22632435829409, 62.81587577635243, 63.76005303475165, 63.04267114208591, 63.66950119695356, 61.56890330776092, 59.295073939907944, 59.04920016565631, 58.558970574409734, 57.20402702208489, 58.44892455685524, 58.04423009195636, 59.18397672714726, 57.28287842965896, 58.19720645104685, 56.61066262952743, 60.1815531330724, 57.69459393716628, 60.19507746542654, 56.8840753647589, 57.027638035435835, 53.433593780763694, 57.21436246748894, 58.7587918004682, 59.48896061989569, 53.55303779725106, 51.54623554598901, 52.72777503536594, 61.07256266378588, 59.694802684168664, 56.81950530698223, 54.417653699075025, 58.032466903809585, 58.246087028134255, 51.60666358086371, 41.75318333410448, 45.216032151252996, 45.80861599214616, 55.50259697821833, 55.228403691322576, 63.9073694136835, 38.87587378101964, 42.33875397712954, 63.474794741599794, 55.22315163766184, 55.15667923035161, 42.359613141705914, 52.34924670188658, 56.38917030826692, 59.957766225261075, 52.47933210865144, 45.84843981650568, 39.80737393902194, 45.58893972827543, 53.606221214417495, 59.46342991244409, 57.20199523433563, 55.44221208941553, 56.402118052205736, 59.870815123281176, 49.49010164506974, 40.70582812832248, 48.94007552054621, 59.34819067678144, 59.66626351879489, 55.85610451236848, 51.85338066470239, 57.149459008247625, 58.87498024971255, 59.06472490679834, 57.189682914364724, 58.92142111255277, 59.02640727258498, 57.000628594429266, 46.933222278471916, 45.89672027095672, 50.01731526467108, 51.77638453821982, 52.4228342886894, 57.5366989258797, 56.41336740985994, 62.59464233152328, 65.21892762953236, 64.51587415510609, 34.327661991119385, 11.360877502349116, 2.2724575188852127, 4.26544027943765, 4.368353957130063, 5.347229972962411, 2.0061434156471685, 0.025747427979724544, 0.05860264653400068, 0.045840870438804554, 0.22907559579658895, 18.959627382216915, 31.59943388354394, 31.43377846287143, 62.81269473414268, 68.5097256014424, 27.055854412817187, 21.911748301598337, 41.016954452760764, 51.35027785455027, 60.20220441202964, 33.44921973443801, 2.029935042223623, 0.03537454274332812, 0.09570881228653655, 0.04950038818342071, 0.04667046705200788, 0.021623524972387863, 0.014426715938644785, 0.01953082940270824, 0.026947661761134386, 0.034888096063608126, 0.02537395054053876, 0.028870904427622596, 0.02807437983011046, 0.01911603301132639, 0.026123192191364306, 0.00356349173553979, 0.05804142967287091, 0.03592303488403559, 0.0222918160274745, 0.01229951193841595, 0.022716207670107968, 0.04150026988598608, 0.025161838031283794, 0.08289337939312381, 0.029839293190067815, 0.07515792149089037, 0.016181711332812425, 0.013512177411617051, 0.04518363211724547, 0.021769909052959373, 0.10578738840957803, 0.03297691736670752, 0.018987927788628206, 0.017991161214247826, 0.07928931875334633, 0.025662240917764367, 0.061898977315473946, 0.05875363480299712, 0.021575604257504308, 0.05541616126955037, 0.05001003583592754, 0.06001106087839412, 0.040249060614094626, 0.025930218473677675, 0.035305774860805085, 0.6028981422705035, 49.114401340484626, 80.93684550254576, 67.79016679333103, 65.22855312593522, 41.99590352273757, 37.99078310689619, 29.40472068325166, 43.322523640048125, 51.741342083100356, 43.18525637349775, 5.800477006743032, 0.09643153197342351, 0.0582337330636238, 0.20481418878320726, 1.167865003789625, 3.456139848116906, 7.143919679426379, 6.822455458102688, 5.171821088560167, 10.780108821007515, 33.43137295015397, 58.364056233436834, 64.24309684384254, 65.30946377784976, 63.56986514983639, 63.552700857962336, 65.10898359360235, 64.98691158909952, 63.519109679806625, 61.72170708256384, 62.41155393661992, 60.2519557552953, 60.596598732856016, 59.83732984912012, 60.2337481129554, 60.212186844118186, 58.99710716739778, 60.679086177579826, 59.99049055960871, 57.40039264002154, 60.67264564575688, 57.616785880058046, 59.85973442754438, 58.16467039046749, 55.591921114152484, 54.3623443572752, 57.33734446187174, 60.91514225929015, 60.743805285423036, 54.589837904899355, 55.37910115334296, 56.69447583536948, 62.61186545894992, 59.91558113405782, 57.37654462937386, 56.13079594027612, 59.379824592221176, 58.37720009588427, 53.116250499602295, 43.074304288433446, 47.50358589233891, 49.35485047678794, 57.54952507634317, 56.56630454524871, 66.5159926875945, 41.12482355486962, 44.914397962631725, 63.76706231024958, 57.455286210583104, 56.17535406543363, 44.596807572149466, 55.96645255242625, 57.64215969270276, 61.46585872096401, 55.12870488628265, 49.45215663602276, 42.15922709434263, 48.79620690499583, 55.262508699970866, 60.7424363782329, 58.70862468596428, 54.24458695996193, 59.131766057783565, 62.21893025982765, 50.71330847278718, 44.05039787292481, 50.09134607930338, 62.33098453091037, 62.10312620286019, 56.47176757935555, 51.8289952893411, 58.784973621368415, 61.490322543728745, 61.07213512543709, 60.074362601003344, 63.323881549219934, 60.212834035196614, 57.937357271871264, 50.27103377926735, 48.28428268432618, 52.0535078356343, 54.42165843902096, 54.02611878610427, 58.786350373298895, 58.35226166632868, 63.90236054697345, 67.891050154163, 65.81777157322054, 37.68785061374788, 11.725494169419813, 2.445070488799003, 2.441623951158216, 7.556559885701827, 8.290701085521329, 2.991245581257728, 1.4691369860403, 0.10936065231479945, 0.03286982976621197, 0.19426102119107402, 20.58565966544613, 40.97123922840242, 40.74127066519953, 67.10365003155124, 54.14266809340447, 26.743702388578846, 28.237656700995664, 45.36321124722881, 57.81815644233458, 66.54916809451196, 40.59975547175254, 2.5959047434791445, 0.04470633252734139, 0.029990331254779335, 0.056891378480941064, 0.01860059181889219, 0.04527648963454751, 0.06057882013039724, 0.08815559904061018, 0.08934655166681736, 0.033033818547283454, 0.02384914828824901, 0.039375287540737665, 0.04738425415369773, 0.06066173765688174, 0.07050455022122591, 0.012816414443565714, 0.052725507261892485, 0.09093370964570392, 0.03472580799772855, 0.033429625534242204, 0.07527337860195868, 0.04494706416622766, 0.03239635295505005, 0.046449841390694344, 0.15526981183117436, 0.13517095887612912, 0.09428958844153151, 0.14961661921153147, 0.17515144821616913, 0.10287017922007269, 0.2019039739764506, 0.1591427693323743, 0.17610409387177037, 0.18529512649101598, 0.21264238162867485, 0.2418520884408105, 0.10429111910202812, 0.12211369500765878, 0.11872561753637369, 0.14325916196309751, 0.22611727066818746, 0.18936991751674684, 0.13869099499237153, 0.11322522881410776, 0.15317813132799443, 1.2461517126329484, 58.92655157273816, 90.86415260068833, 75.06664199213829, 77.19324911794355, 46.480635673769065, 44.42499206912133, 40.86634720525434, 75.90227942312919, 62.397033322242, 51.65728176793745, 9.097426725972085, 0.21207365327544753, 0.506021635787141, 0.21850470092988786, 1.2481419477731952, 6.156602232686936, 11.432787295310728, 12.539458544023576, 16.62448940738555, 11.334587816269169, 32.94868999911893, 59.617390786447835, 64.44264350398895, 64.44634622143161, 65.5315169980449, 63.00312188363845, 66.29545350228587, 66.0402484093943, 67.68022275740101, 62.1541876177634, 62.14207533867129, 61.88344993898946, 61.166048434472856, 61.07846975326539, 62.355291458868216, 61.685986057404556, 61.059399189487586, 61.185464166825824, 60.71407371951688, 58.11416202975858, 60.97557813890519, 58.89242302986884, 60.09022074361002, 58.88895565463651, 57.55276103173533, 54.98911949896044, 58.347260644358975, 61.954601733915275, 63.91433162073936, 57.7922962557885, 55.70704267870996, 59.47604033254809, 64.86723615277198, 62.3355148684594, 56.621672722601126, 57.51434533826767, 62.35558563663114, 60.69738795680385, 55.380336699947236, 47.83483789813134, 50.58759258639429, 53.34629358783845, 60.69477565826909, 60.3433548250506, 67.67969715979793, 45.107064785495886, 48.11973533322735, 67.49110175717261, 60.99717078670379, 58.68070917744791, 47.10274319494925, 59.638983434246434, 60.15404947342412, 63.97318678517496, 58.49817775910901, 51.623231672471576, 44.824563918575166, 49.960582102498705, 59.25472059557515, 64.85461788792765, 59.70083136712352, 55.34032460181944, 61.16222412355485, 66.1137536264235, 53.62274615995346, 44.91233479592108, 53.06395746046498, 64.86993082108037, 62.64083216267248, 56.24588220350204, 52.158811707650464, 61.039704968852384, 63.32104959795552, 63.799998452586514, 62.07959590419647, 65.57738519483998, 63.69529862557689, 61.721236398143155, 52.482532762712054, 50.508851005185036, 55.37577890580701, 58.61713540169501, 57.620712172600534, 62.606327072266616, 61.27729077492992, 67.71613597869873, 70.67309318050262, 70.6586588582685, 42.564953142596835, 17.760268565147154, 5.657327165526729, 11.10322779224765, 12.487226301623929, 18.413184342845796, 4.12528173577401, 0.500531911008781, 0.1826341660513032, 0.14839510733802475, 0.4309691662990278, 28.15685195307578, 43.819593844875214, 39.94105223686465, 70.29840484742196, 80.05144888354887, 37.88832295325495, 34.431632257276966, 55.82231721570415, 66.33182171852359, 75.95363893816548, 49.32353819570234, 3.2493600922246135, 0.14992760494351387, 0.15194025581642506, 0.2513172273193636, 0.09546828366095021, 0.11236449072678244, 0.07794410666270603, 0.22107020681423528, 0.1923558371321809, 0.13609231750090278, 0.09575591903300056, 0.1862804994227425, 0.11839123547918375, 0.1466403982692188, 0.1766633840217706, 0.10547898439390045, 0.14890680810616863, 0.1468235239266388, 0.11794786975388566, 0.10689684460240026, 0.1309265253404456, 0.16989695839583877, 0.16478807124639713, 0.13329787390126338], [0.03221036595923286, 0.008544047426943098, 0.007227205966163668, 0.059984707453798865, 0.01612299452385595, 0.045646762910989985, 0.038523064520690715, 0.04714502021670342, 0.013221528441194567, 0.012936797499987147, 0.04508397556961544, 0.07932476564160279, 0.08615358146808802, 0.023086193663578843, 0.030983441674541083, 0.05958634556361264, 0.027579278272065907, 0.013944667561220066, 0.07409824569138788, 0.048794338569766095, 0.03360390670657639, 8.233556074480857, 53.633230655424065, 59.0413240463503, 67.30536184003277, 50.35390561626804, 40.12749818063552, 16.691852192724905, 48.977769497902166, 57.31184513338151, 43.99080138052664, 23.560447962053363, 0.018051618958012234, 0.09375309706815789, 0.04407471218597024, 0.07427511241046653, 0.8117755081865096, 2.943251459829269, 3.0368107749569804, 6.296405311553709, 8.926202520247429, 29.366342252300633, 56.68308919475925, 64.79116570565009, 66.25488050522344, 65.13703246270457, 62.61058284390358, 61.554112049841116, 59.28627214124126, 61.672010652480594, 59.850167766694106, 61.07508474780668, 62.46240746590399, 61.103827876429406, 59.72689551691855, 59.076590076569595, 60.71376385227327, 57.34598936573152, 55.23522469305224, 56.05967160194151, 57.30150184323711, 57.76301184008199, 55.951496554959206, 56.864157569023874, 56.748447648940555, 55.12097781704318, 56.012199155745975, 55.20878007335048, 53.28158232473558, 56.49198347522367, 59.18947589012885, 53.88941241848854, 54.49641096976496, 53.30496357333276, 58.602595175466234, 57.32922907798522, 56.942667730392955, 54.95788958764846, 58.73231972417524, 54.38649831279632, 46.29211479617704, 41.43198044069352, 46.23648382002308, 47.41334392178444, 56.279893075266195, 54.12326412816202, 65.70063783276466, 39.289907409298806, 42.07891656506447, 61.88810187001383, 54.5920422769362, 57.110772671238074, 43.97023247134301, 52.29503170136483, 53.51944269672517, 57.78530659214143, 53.62422097113825, 46.53389753833894, 40.48596359068348, 43.77678117444439, 49.147388473633804, 59.61512365648824, 61.09943874420659, 54.8508128043144, 54.715722453209665, 58.636555056418146, 46.90009393999654, 41.8624605671052, 47.876811181345296, 59.80294635218959, 58.6436741582809, 55.9933796236592, 52.712446412732525, 59.55157341495637, 58.50262572688442, 56.59549482407109, 53.249301218217425, 57.090784272839954, 54.65133282446093, 51.32679854669879, 47.868005460308446, 48.80113732430243, 48.8466368183013, 54.481317689341886, 55.4689508868802, 58.91522376768051, 60.345790616927616, 60.01856688530215, 62.5822711759998, 66.99558873330393, 55.729717900676114, 31.50099612051441, 7.651629313345879, 1.866206485898264, 8.157536127874929, 7.906817736164217, 3.8896664304118005, 1.7503364840822837, 0.09204655960803071, 0.10020171877958121, 0.05220341834149534, 1.9533249014808287, 31.065016831121138, 37.281532287597656, 28.70642112147424, 47.24422700943486, 32.077194260012725, 25.83569918909381, 40.38931246726744, 47.96932028185937, 58.38690403969058, 52.048918662532685, 4.8338750677724045, 0.1052623117462762, 0.037566255177220995, 0.06603913096290442, 0.006304155723492225, 0.025113398291831537, 0.040339321093333345, 0.033688268308798154, 0.03637557451222693, 0.13025483477019495, 0.008166305750848786, 0.02583605094602512, 0.04015510759106086, 0.003747688479638929, 0.03277906749938284, 0.024042407373687433, 0.009433007235789012, 0.04988798270783117, 0.05313464417873372, 0.07659847322370737, 0.0546403746721485, 0.07850666034726367, 0.07034557165517923, 0.07866288865766219, 0.018654578034916235, 0.02051579630783489, 0.034915924207457615, 0.07355081458245555, 0.02521207041647886, 0.028545543055741057, 0.018812133592643568, 0.07843637944109018, 0.05485479502127536, 0.025761851500118935, 0.06549628105975928, 0.09674375876784326, 0.045512735828637116, 0.059661111914582794, 0.06592453187031132, 0.034379915469476295, 0.021593643712901303, 0.025669039948092356, 0.07750782725070754, 0.05108627828679258, 0.03841696134317787, 10.58456886199213, 64.71194167290965, 67.41528234174176, 73.33271118902391, 57.602076991911865, 43.14835079254643, 20.419047186451575, 43.575273329211825, 59.572267839985514, 51.027757044761415, 23.97380105910763, 0.06456753734739558, 0.09189485121638545, 0.056610457869547035, 0.5873546472960903, 3.6939663896637582, 6.578886566623566, 5.8778320300963625, 3.755451503299898, 8.039269803031798, 30.574398925227506, 57.961766181453584, 67.40200904107863, 68.42890124167165, 65.88904103925152, 62.42145007656467, 61.426893895672215, 59.677932570057536, 62.96901295261999, 60.509600562434045, 61.88515224764424, 63.05633667976626, 62.006463312333636, 62.302806223592455, 59.36291917677849, 62.23965606381817, 58.499134817431056, 58.185003957440784, 57.536416515227295, 58.66339975787748, 57.8835266636264, 55.354021518461174, 57.84148670011952, 58.54997265723444, 57.53863657674482, 57.84752715018488, 55.82460395751461, 53.25946015696372, 57.70723181386148, 62.83921387887771, 57.08131567124398, 57.43092044707268, 56.55010515643705, 60.4619163082492, 58.89133261096094, 57.293915979323856, 57.68150891027143, 60.94411680775305, 58.166533516299346, 47.79125252077657, 42.79998156332201, 48.23117379219302, 49.99191791780534, 56.71364445840159, 56.391084424911014, 67.3278134868991, 41.20592248055243, 42.827579359854425, 64.95739967592301, 57.72526294954362, 58.286930668738584, 45.9925869203383, 53.842124323691095, 55.44904878062587, 58.376533292954974, 56.32942084343203, 48.27377465463454, 43.06285096753029, 45.785305346212084, 53.265312333260816, 61.29833821327456, 62.87115373919087, 55.79711206497685, 58.682105541229255, 60.22314986874981, 49.14409760505923, 44.97260201361872, 49.7970231886833, 62.581890706093084, 59.500617904047814, 55.52373855344711, 52.337095199092744, 61.77524743541595, 62.178937773550714, 58.709330712595296, 56.66742717066119, 58.372289288428526, 58.10553281537948, 53.45238977862943, 49.668663624794256, 50.4807040768285, 51.151323472299886, 56.2519383430481, 57.75708906112179, 60.698917681171054, 62.88967909351472, 60.975158445296756, 64.24667012306952, 66.9969537181239, 58.833767906312026, 32.42127437745371, 8.564427610366575, 0.46687062048623645, 2.5820666215112134, 7.302461881791392, 9.103429913520813, 4.03621819230818, 0.20823587453173054, 0.0645124709473983, 0.07428305674224131, 2.946308457082318, 28.55957542696307, 31.60998505930747, 34.432291215465916, 49.415164762927645, 34.08128223111553, 32.68817597819913, 46.678531016072924, 54.861195318160526, 63.55237137886786, 60.042308991955174, 6.581070836513273, 0.10236551113907369, 0.04981176462024451, 0.02299473425673862, 0.04421011822658681, 0.055316297878180785, 0.027527820146191987, 0.028615295361246795, 0.030399774606790275, 0.038171104576078155, 0.08588836182870212, 0.018839745316654444, 0.07227650392920741, 0.019287996767689625, 0.047578051415902954, 0.03168579682918086, 0.005998381304614727, 0.0456532976409841, 0.051860283729770494, 0.01908102279318677, 0.06284551341987907, 0.0706619200026316, 0.01367027976460034, 0.03689583631292467, 0.1083972507847413, 0.17668203060184756, 0.1059553455260973, 0.15866171208120164, 0.15067031186434532, 0.15712477116575166, 0.14411129688303317, 0.09911191274201679, 0.19675511235912002, 0.15230175738613452, 0.1971077579524248, 0.29844959176355795, 0.1938640191069534, 0.10866163538828974, 0.23247685764105092, 0.14651572512042138, 0.10067135365980287, 0.14364827334159805, 0.27741459468680046, 0.14208580637651105, 0.1715421015697141, 13.809928951724885, 78.283613112665, 74.61326306866061, 83.94255776559153, 64.2138320399869, 56.06393129594865, 25.579576261581916, 64.00418919901695, 66.66905926119897, 58.73982714068506, 31.504071258729507, 0.22348295476648117, 0.3096595418549353, 0.09573633782565595, 0.5967229220174974, 3.6188419691977964, 10.458682352496732, 9.653753157584898, 13.257560191615937, 14.124932539078499, 34.59790937362179, 60.11897563934327, 68.18725970483595, 69.28532723457583, 67.81887854299238, 63.451119315239694, 63.13665897615495, 60.68570713843069, 64.09549020951795, 61.64360092532251, 63.0133592697882, 66.04300191325527, 63.71617740200412, 62.542239466021144, 62.616811567737216, 64.96987673544115, 59.3215460162009, 59.54459159604965, 58.73135482111285, 59.69735614715084, 61.3960091529354, 57.29879540781821, 59.300278925126605, 59.58735327566824, 59.39442365400253, 57.81393989439934, 56.02528418264082, 52.664915130984404, 58.44373526111726, 65.11198028441399, 60.086639619642696, 60.31783196233935, 59.152895865901826, 62.270395678858605, 61.41908837902931, 57.6647525448953, 58.806048516304266, 62.66989692564934, 61.33392195547781, 49.942660793181396, 46.15690677396713, 51.40326515320809, 53.80321048921155, 60.45818613421533, 60.21517176781932, 70.08263526424285, 45.740092185235795, 46.27808055570049, 66.56736004737117, 60.665432407009995, 59.79306590172553, 48.67892803684358, 57.64090061187745, 57.51697724865329, 61.16598175417993, 58.499993816498794, 51.520312601520175, 44.862677589539565, 49.13443680732481, 54.714024066925056, 64.6194992526885, 66.09490271537535, 57.96855972659204, 60.63248057519237, 63.22702254018476, 51.809614858319684, 45.42678894535188, 53.28084491914319, 66.40447970359557, 62.07716795705981, 56.331252590302505, 52.51723789399671, 64.31116957818308, 64.69757010859828, 62.220848298841915, 60.25086925875757, 62.797181760111165, 60.4269209215718, 56.45058285805487, 52.06365500727008, 52.852749593796275, 54.78852556597803, 58.76973913561914, 61.59583430136404, 65.23710781528105, 66.64157913577172, 64.41777175472629, 66.89312073492235, 71.82598760051113, 59.03566798856182, 37.839269791879964, 12.980910520399771, 5.489929231905169, 18.66225680997295, 14.918450578566521, 12.957625369871817, 3.109243223744054, 0.23108173492214373, 0.2049086167807541, 0.2556362012100797, 3.376804272974691, 46.77557437650619, 53.42869474041847, 40.29180234478366, 56.835132029748735, 42.161341251865515, 39.085206754745975, 54.46535364274056, 63.35512322764244, 70.5543081222042, 68.91809140482258, 9.649516997798797, 0.21647257610194146, 0.1415139983498281, 0.1308682720146833, 0.14212864601323683, 0.17617431349090992, 0.11110067547809695, 0.14445844196504162, 0.1158856836357905, 0.15663649736633226, 0.10472012067874593, 0.18255234786099006, 0.16091198810646612, 0.09891138156695713, 0.18366846135787426, 0.07947989844626958, 0.15351006190382666, 0.12741193610934481, 0.1527683662190553, 0.15480521014861523, 0.19525276797433055, 0.14629959639522339, 0.0849614567273567, 0.200229826713762], [0.01818569583608018, 0.05150796755427315, 0.05652824897439249, 0.040662238644736434, 0.01777319962369098, 0.07666478579443309, 0.054864003398125215, 0.041457652414758364, 0.02553713109885012, 0.02066304606776084, 0.010379436087884731, 0.036678382255617654, 0.03260722631708749, 0.05399141776105089, 0.04770651286948593, 0.009910596981494418, 0.045111799883025314, 0.02784680383610389, 0.10324733196607522, 0.07059395268198944, 0.1794766427408303, 21.183615192290276, 75.54869344157558, 60.326453331978094, 58.432462369242025, 42.966141008561664, 35.52634616051951, 34.966153252509336, 51.643792736914854, 32.42368663510969, 48.32651876634168, 4.838270083550484, 0.06715513720747925, 0.03569710789428603, 0.06859760416010696, 0.26492273434996605, 2.198822128195917, 3.626584482769813, 7.091774709763066, 7.759954390987274, 25.73372737053902, 60.12744011417512, 65.24494078851515, 64.45609331130981, 66.77381007902085, 64.92221993784752, 63.091861586416925, 59.98795278610722, 59.5208377222861, 59.94884283311906, 60.0120282942249, 59.4957463202938, 60.50356011236868, 61.64083565435102, 58.890304949975786, 58.23636739484726, 59.64820492652155, 58.57029837946738, 58.3142735112098, 57.85055521995791, 58.255163392713, 52.425752532097604, 59.3406871826418, 58.925445464349565, 57.95117970435851, 57.04907771079772, 57.8840797178207, 57.943789958953865, 58.48078204739479, 55.429311413918775, 59.377243672647786, 55.911825703036406, 55.7972179689715, 54.268411436388575, 57.962185875062026, 56.29510402679444, 53.677035685508486, 57.02440600241385, 60.384033726107695, 50.06287751659271, 44.0047767854506, 40.774775551211455, 46.09008919808173, 47.08948950613699, 54.37508421559488, 52.76411971738262, 63.32217924056515, 36.36097162000595, 40.109608250279585, 61.792278366704146, 53.760935183494325, 58.59951611488097, 43.92791009718373, 46.950284588721495, 50.67703831580378, 56.796245651860396, 53.07381437670801, 47.90799794658538, 42.52478022729197, 41.05723719443045, 45.99636024044406, 54.80374436224661, 59.80989286976477, 54.53753702102169, 54.84352504053424, 56.83295119193293, 43.00093635436028, 42.351478145968535, 46.75806491605697, 57.51308625744235, 56.25745319551038, 54.42392556898056, 52.38965495940178, 57.17736274965348, 58.61974770022977, 55.990328019665135, 50.13042465333016, 51.51165593054987, 48.99357272732643, 47.8490408005253, 46.896191181675086, 49.379012277049405, 53.19347804592502, 57.814355665637606, 60.34431972811299, 62.2901761916376, 61.376440448145715, 63.058341010924316, 64.29864937259306, 61.768516648200254, 60.72381688702492, 53.59794893572408, 29.470016379510206, 5.2112036462753055, 2.7979117103161353, 5.960775940648972, 3.604148280236029, 8.152640029307335, 1.1323192595474183, 0.11179075215853031, 0.06367424435372795, 0.10844061902213482, 12.5717661265404, 43.62524040283696, 38.952477670484974, 29.829621238093225, 15.534038139927773, 19.97778054206602, 36.39174261400777, 49.09592305460284, 48.88968875331264, 60.75173239554129, 16.76457489690473, 0.10457398174631019, 0.01148750757678382, 0.09615117443665382, 0.07554717076521728, 0.06365254874371233, 0.034929223493823124, 0.055859247372756084, 0.03913484318482299, 0.049127897082437436, 0.015256947447215358, 0.053667764765240496, 0.012159586936656025, 0.032934445452185414, 0.028682755148639123, 0.03959638817656425, 0.011207820366947882, 0.10761433190876439, 0.007853053835025358, 0.07329926195163881, 0.021908931028578552, 0.09039229232697718, 0.03064300943796914, 0.12932388472460932, 0.05212914994767597, 0.03517490789113987, 0.028659431601784406, 0.0379019740578388, 0.03570769139895997, 0.04395434062086767, 0.024334390294708075, 0.06817303057159148, 0.037139299055261, 0.029353974574816324, 0.015862142543248352, 0.10316610366346375, 0.04552595084533096, 0.028933964955109744, 0.037247263826429844, 0.024448508667128704, 0.03174405590060257, 0.02180996779052, 0.12445849862190024, 0.058759116162095344, 0.08740936045444782, 28.510159446347146, 83.83034659970193, 69.02917292810255, 64.8337548009811, 52.02892241939422, 45.82557239840108, 36.595290091729936, 55.40987999208512, 36.92210589685748, 52.74255060380506, 5.106564125707073, 0.06261350752245035, 0.08968271870887087, 0.29860878483422343, 0.9275942740421143, 5.357677205916374, 4.125465596875837, 5.387377883157423, 4.763439105403039, 28.26042409866087, 60.55893613446144, 68.93156866873466, 64.76566637715986, 70.39524032223609, 66.75807352988951, 65.35850517211422, 60.087498618710434, 61.568287495643865, 59.29193996614026, 61.40149654880647, 60.9423517411755, 63.74286520865656, 61.74978340825727, 61.61838792985486, 61.181471193990404, 61.3080382347107, 60.38659111146004, 61.07104470652919, 57.896901945913996, 59.12023821184712, 52.326630315473004, 61.429529728428015, 60.501073329679436, 60.29587061174455, 59.73418720306889, 61.71072052371118, 57.782141239412375, 56.96826904050766, 55.63809917819116, 60.843876715629335, 57.08940752090947, 57.60244177233789, 56.33994848497453, 59.86219375364242, 57.316544132847945, 55.647191232250584, 58.113659966376524, 62.88359941974763, 52.604408648706254, 45.638239998971265, 42.20686428008541, 49.17312314433437, 50.05183212218746, 58.044967497548754, 55.26150457320675, 65.65994716459706, 38.35539879337434, 41.2784824063701, 63.48936242441978, 54.958662294572406, 59.45377303707985, 46.25140843852874, 49.268707383063536, 53.894252623281176, 58.647357263872706, 55.08031460546679, 49.13108318082748, 42.85496927076771, 43.22456244499453, 48.291923461421845, 57.92124417520339, 60.44850572463005, 55.623472659818596, 56.67568768224409, 59.16714975910803, 45.79325991292154, 42.206252390338534, 48.70409396386916, 60.78792018275107, 59.249362637919766, 55.220256928474676, 51.86137837748374, 60.352533171253825, 61.28030315522225, 57.62993366487565, 51.557681022151826, 52.91927691428892, 51.07198569082445, 48.82763293481643, 49.46771275612616, 52.388007563929406, 55.02810785847326, 61.06867167257494, 62.40752174008278, 64.24175147087344, 64.16533193280621, 64.09065392709547, 66.77565359300183, 62.36858044901202, 62.734137504331535, 56.62705029210737, 31.22000732729512, 6.37227620809309, 2.071961645157107, 6.303605312301267, 4.798282990532537, 5.483665697036251, 3.2334002131415955, 0.07073412378949505, 0.1593827693572929, 0.02232525193492972, 12.56219554331995, 41.867677319434385, 39.25033853900048, 41.553738655582556, 20.666338897520497, 23.27984944466622, 41.8692188109121, 53.82909420997866, 55.52853953453803, 68.87551799897226, 23.26597013781148, 0.21896583989502924, 0.016361764977656065, 0.03778253712000386, 0.02095269433583223, 0.03674905003619291, 0.057469460767723864, 0.01757241755483612, 0.02742529459928553, 0.06899785445702654, 0.054344971168545954, 0.016104673531146783, 0.04412923466354128, 0.006764572171960027, 0.11726271901880542, 0.021631536336856026, 0.03635055791105955, 0.06072010206539304, 0.017329678765588233, 0.04517050903110255, 0.027076125129937168, 0.019608489650812362, 0.033567057877418496, 0.07332569198502649, 0.20527129812586695, 0.09100833427040808, 0.10257264599204065, 0.09390831414249637, 0.09869709911365664, 0.17195762765984382, 0.17126425680133606, 0.09346346220662517, 0.13484000889283998, 0.1667246955537027, 0.07782458162475979, 0.23726928919073076, 0.11931078613645608, 0.20766559868089615, 0.10939743219604416, 0.09200152895984151, 0.1997068184878557, 0.13185787375175184, 0.1708121423519427, 0.16441532350595922, 0.2716159219703367, 37.09427049083095, 93.48869677512877, 78.57103655415197, 76.19972844277659, 60.767465022302446, 49.54765458260813, 49.68033659842707, 67.39662754920222, 41.96028840157294, 64.96429520268595, 7.2372519873803665, 0.2959158632063097, 0.14467553596102423, 0.3101766205603077, 1.1388167883119276, 6.678024472728853, 8.855334116566567, 15.864717479675049, 12.145077951492803, 30.14576819635207, 65.32508657824609, 70.02176792390885, 68.8118657758159, 73.08786115338727, 70.66018073789536, 65.77352331530663, 61.48576474958851, 62.40468194407802, 60.86451622747607, 63.090806468840576, 63.182111401711744, 64.96558958484282, 65.55875393652147, 62.392734404533144, 64.00757028210548, 63.688979687229285, 62.31951552052652, 64.03929441205918, 60.41174919374528, 61.0105303795107, 53.621945996438306, 62.55938414604434, 63.0779803183771, 62.65265418637184, 63.61634131400817, 62.86130466768819, 60.281491202692834, 59.62926772332961, 56.610172333255896, 62.264225790577555, 60.049808563724646, 59.99003164229855, 57.33750135667863, 61.808073751388065, 61.04850284514889, 56.45463858881305, 61.68067909056141, 65.83950150397517, 55.294048478526456, 46.91301030497397, 43.544576860243275, 51.208303743793124, 53.23889909252044, 59.71623059242003, 57.319219189305464, 67.60772166713592, 42.702016445898245, 44.51042129147438, 65.56135446794572, 57.696229565528135, 61.57104099950483, 49.57371873240317, 50.84811249086934, 56.58814430236817, 61.87442064285279, 56.710192772649954, 54.99567770188855, 46.16203331178235, 45.33545263351933, 51.12154483795167, 60.232077183262, 63.99943136399793, 58.02306498250654, 59.25682298598751, 61.714638971513324, 47.29126799491144, 45.648418549568426, 50.64061126401348, 62.83542879166142, 59.90607330876013, 57.374073536165305, 51.362068499288256, 62.99100175980599, 66.08518308208835, 60.717262606466974, 55.326694365470644, 55.97795686414165, 53.28359057826381, 51.35551421873031, 52.30431202919253, 54.3862315916246, 58.80579356224307, 63.59441134237475, 64.62757933524348, 67.18383112261373, 66.61676622206166, 66.39650160266508, 68.18323535303917, 63.83730411529542, 65.20742331781696, 58.98376326407156, 34.55859153501449, 7.843488618250817, 6.739233059267844, 16.81318090808007, 11.141345385582218, 17.00694795577757, 3.0395755556321915, 0.12323212975095357, 0.4162763353557356, 0.2330711733309492, 18.89778337171001, 57.58637574411208, 54.10739421844483, 43.32490451874272, 22.159418521388886, 31.56439535079464, 50.32553903518185, 64.31042432785034, 64.3227013464897, 78.37148989400556, 28.09256430595152, 0.5197970304758318, 0.12915949757781722, 0.19003981544125467, 0.18038554477595514, 0.2966132483655407, 0.12518559267083484, 0.1853478026966895, 0.14134201161082716, 0.20598098665716189, 0.13505661259255103, 0.12767243664711714, 0.18223557050430006, 0.06671930212647685, 0.14179308418064349, 0.12050486440139434, 0.10628474801177941, 0.1796551105836707, 0.16688561998307708, 0.19198422320187095, 0.1022182920226647, 0.1415877879386948, 0.11961830915102076, 0.2019806287341541], [0.019240817242872812, 0.028786858836669597, 0.010637697733698354, 0.02390713156801799, 0.015588055436138906, 0.03678401428905707, 0.024857614940452962, 0.018038919135447473, 0.021632325407418034, 0.10999010845778451, 0.02394506824202836, 0.032072922124737696, 0.018737505137499784, 0.051105330893469435, 0.02142218940500771, 0.0584119557583284, 0.0014493947814879639, 0.048196000918265314, 0.006705456997282924, 0.06015729174138077, 1.5204721088370972, 45.20643803381151, 66.64060638796899, 54.56837077294627, 53.188790813569106, 32.28787064552307, 16.226919927904685, 17.54007847078385, 20.862229908666304, 52.2584673666185, 24.08768315469065, 0.5133229746453224, 0.03745576614634164, 0.04864197517294557, 0.2035582948836588, 0.619448644499625, 6.190023768332697, 5.859722447010779, 3.873609962963289, 16.368555734234473, 52.130249008055664, 61.41068273975004, 62.934782428126184, 60.61634786667363, 62.426584459120235, 61.24715520489601, 65.0482339243735, 65.0622760095904, 58.60345417453397, 57.88238133153608, 61.268398761749275, 60.964944593368045, 60.09376264387562, 56.906068094315074, 56.65700151074318, 55.10326047097483, 55.90270619238577, 57.23161697387696, 59.148828368033136, 57.21426048586446, 56.12305318155597, 57.06710100173951, 60.00841971366637, 54.92522801122358, 55.498360818432225, 54.43449635659495, 55.554764501510135, 58.90319778073219, 57.59144344637471, 54.14322899233911, 57.544586812296224, 56.4525911115831, 58.01575368450534, 58.57322054524576, 59.76173793115924, 53.23046599664996, 53.217886955507346, 56.24215202946817, 59.54963184172108, 46.209097831479966, 43.01011862293367, 40.06169257625457, 46.76035165786744, 46.86759318074873, 54.15352521404144, 53.315267639775435, 64.51906304205617, 36.447353978310865, 37.603221554909986, 61.97712790581488, 52.158862698462706, 59.214508456568566, 46.582225061232045, 46.57117966682681, 50.50095919639834, 54.6641589749244, 52.152390787678385, 47.81442196138444, 40.255143873153195, 41.29976910929526, 43.44531736066265, 52.24093437194825, 54.45302955565914, 56.81493574573148, 53.70462955967073, 50.884916090196185, 42.16231399966825, 41.235222585739635, 47.77698293808968, 57.530717311366914, 58.614377975463874, 56.17074528048116, 53.82161817243023, 59.42806582297049, 56.75346828276112, 55.95426574830086, 48.76166259088824, 46.21890767928093, 45.16238197203606, 45.56871598766696, 46.62444545376686, 53.02781674169725, 54.68025245974141, 59.791893113044004, 61.66144770960654, 60.98761197059386, 61.4564097312189, 60.963305042636016, 60.13130757116503, 63.499250719624186, 63.47086060431696, 63.19490225084367, 58.76801721511349, 29.11038798670615, 9.062910849048246, 2.830630651404781, 7.119191586971284, 4.038306364128667, 1.5792190403707567, 0.14463897824527758, 0.04979874878641098, 0.05784951315651979, 0.5740120922846179, 22.41264085615835, 36.59703554645662, 18.602442626030214, 17.9647260327493, 27.412260578524684, 34.94263079858596, 43.76058963037307, 56.889966764757716, 61.94142257013629, 31.849520283360636, 0.5853010413627471, 0.039909231671763044, 0.044483060032249465, 0.05034761631020135, 0.09349756844101414, 0.048314376824325135, 0.07724820771404813, 0.032411306991332, 0.028764487154060797, 0.02154020908018274, 0.0601966533389303, 0.009505437976200013, 0.03473107485220798, 0.031755838332878004, 0.05745411602660053, 0.017064853661483335, 0.028889690818745765, 0.028339748856641596, 0.01852365552387651, 0.0825506776210762, 0.03038771255242248, 0.03034701221622527, 0.0370921042086857, 0.05259404274364633, 0.014420185039090294, 0.028206531912268653, 0.023637413077296752, 0.03593981987045657, 0.04383028034240969, 0.11474173816461718, 0.019237411982049386, 0.049503789613804514, 0.03511532540282896, 0.008049801014544023, 0.0023653426708938976, 0.02904848552369062, 0.02302303354466154, 0.01781018251823562, 0.08115430617885244, 0.022831546037548014, 0.07235321997394485, 0.05048119906155814, 0.0340156176788432, 2.004803313362983, 54.7203783066042, 76.18886347739928, 64.50106328533542, 62.07584611831173, 43.422363650414255, 23.982742101915424, 25.83232987311579, 29.35243941122486, 47.42638972497756, 28.548681043809463, 0.5471251027718668, 0.08214545541352804, 0.07989541687552007, 0.5139149461061724, 3.891454786062241, 6.2015903476745855, 5.6471618529289005, 2.25930507625303, 19.412959237252515, 54.41011882597401, 64.41373563581898, 65.73168731504872, 63.93075850702102, 65.29945781154018, 64.44189040891587, 66.85752914797875, 64.3233250033471, 60.154390719629106, 57.90408380569951, 63.27767210621988, 63.80437581769882, 61.30961502751997, 59.07023191452027, 58.760639236819365, 58.83046527062693, 58.62520371713946, 59.242459266416496, 60.86768550257529, 59.13659449546569, 57.15709586297312, 58.1037873606528, 64.34314081745764, 55.64234710508778, 57.705305930106874, 56.57578883632537, 55.99592131953086, 60.168526941730136, 58.25624988925073, 55.87373556629304, 60.479080600123254, 57.369704015793346, 58.994808658476806, 58.864134896186094, 61.70069494555074, 55.704630421053984, 55.423906387821326, 59.37936959728118, 61.44765892336446, 49.62959289550782, 46.59865194751371, 41.59073837341801, 48.60195544458205, 48.389370825982866, 56.10790891032065, 55.9758387842486, 67.7104014735068, 37.52169901324857, 39.583516428547526, 63.90060724750642, 55.089834197875, 61.50983633533601, 48.311460787250155, 48.939424407097604, 52.649884608484086, 57.1779550275495, 54.14193068781207, 50.589667520215436, 43.33627546987226, 43.53262539832823, 46.05826308650356, 53.86991039399178, 56.98277004303471, 58.96146458964194, 56.24834545197026, 53.29382404204338, 43.63230851388747, 43.181734085083015, 48.88387972308744, 59.4709373289539, 59.069282700938565, 55.47354790472216, 52.056065220986646, 61.59355540429393, 59.154747224623165, 57.58885860443116, 50.22712284518827, 48.681308915538175, 47.60735219524753, 46.600189516621256, 49.72109002451743, 55.21716610077889, 57.63669583105273, 60.429031156724506, 63.228516963220414, 64.1624568354699, 63.10404839054231, 62.9025327005694, 62.282162789375555, 65.03480765127367, 65.18365375457272, 64.57596486614597, 60.13953670378655, 32.847712501402825, 8.465491706325162, 2.987655631957516, 5.960199842529913, 9.961010063848189, 7.403203056704614, 1.6002984705471224, 0.1280269055296817, 0.06098708370700479, 0.8147004318814125, 25.068361989913452, 38.58472408786897, 25.401714424933157, 18.482414176387174, 31.893721472832468, 45.27794284205283, 49.94309617627052, 61.49115800857545, 69.03737852650305, 41.80332299201719, 1.057879170102458, 0.05398224002771801, 0.052605036105359756, 0.04846014037367798, 0.05844847900011848, 0.05880567515569349, 0.060483254492282874, 0.02074018920651607, 0.04841034848903937, 0.0215147883676353, 0.048344591332058755, 0.05903989504722338, 0.022246199322023222, 0.03306439694678111, 0.02996909529751828, 0.06826288502423034, 0.06494738672289156, 0.026539974665689855, 0.06636686337691161, 0.013541691906509862, 0.0334023489736982, 0.013591954935221903, 0.034521036526008, 0.0835987778320428, 0.13106106570170772, 0.14015961618673417, 0.1312470105626891, 0.07588831737877862, 0.14231238454099626, 0.1974136415388315, 0.12203685638885345, 0.10134488284107178, 0.21853833218976376, 0.2238829445935065, 0.1160902827377281, 0.10086262283185798, 0.14410875347112456, 0.07193478274970286, 0.14592997429351653, 0.07561783471535291, 0.20911699821872098, 0.18899576017452827, 0.20424893846915615, 3.35667614013918, 65.74905557017173, 84.62684662111344, 72.96345926100209, 70.12833872149068, 46.137981337885705, 26.674464710297126, 28.29189915810862, 32.81129329435287, 69.20901360050325, 35.174423263918975, 1.2557827248688669, 0.21466318367710038, 0.20287866764251264, 0.39907085859487135, 5.137887193310646, 13.931932314749687, 13.101199807659274, 9.86334991070532, 20.9658863852101, 57.22459593126851, 65.99714940594089, 68.04628187610258, 64.82532170511061, 68.34796705553609, 67.784361685476, 70.39119243621826, 68.5447915907829, 60.30903800841301, 60.21665050137428, 65.45215960471862, 66.3904925315611, 62.88023402613979, 61.368560406469534, 61.48141876343758, 61.56667932387322, 60.01726858077511, 60.98494475887668, 62.88447803066623, 61.80559089106899, 58.54899206469136, 60.62747955322266, 65.82738138014271, 59.72844485313662, 61.562478465418664, 60.26004760496078, 59.3692655717173, 63.3757862737102, 59.607584861017045, 55.718539145685014, 60.5989246983682, 59.18675376522926, 62.017092935500614, 61.72678262956681, 62.31094514170001, 56.00911225042036, 56.947500090445246, 61.499877437468506, 65.42493835572274, 51.06536865234376, 49.76305546299104, 43.88981603807019, 52.09017807437528, 52.83975870378556, 58.48586151676794, 58.22259595317226, 67.70055632437429, 41.7162149952304, 42.16254934187859, 67.30950386293473, 58.30460094636487, 62.712191843217425, 50.52601137468892, 51.185997224623165, 55.9808829522902, 59.96329676720404, 57.315634142967966, 51.96001814257715, 46.07830247571392, 45.554199295659224, 47.851998267635224, 56.19540522175451, 58.855289951447524, 61.85675428759668, 58.94146834650348, 56.427397727966316, 46.18441435598558, 45.16113073595109, 51.99122844203826, 62.89630789910594, 64.35665730507144, 56.161531632946385, 53.23057190064461, 62.32698763570478, 61.818252301985225, 60.97766483983686, 53.47888146677325, 50.80520568355438, 49.70679298523934, 49.922946960695334, 52.493374193868334, 57.46127566983623, 61.32140959462812, 63.94732659862888, 66.08672849593624, 64.54046741608651, 64.35626899042438, 64.0797968064585, 64.28843552066435, 67.39968699793663, 69.3550826657203, 67.21136616122338, 64.49477180357903, 34.0777011071482, 12.398339509963991, 11.290063031258123, 16.4524640575532, 14.802350382651053, 6.4213989915386325, 0.8700972302786766, 0.2439594737464382, 0.16187336716440417, 1.4545743287571016, 33.71301089563678, 51.32761439969463, 27.427906913142053, 26.96116447448731, 39.14137117324337, 48.640049503695586, 58.54932154378584, 68.05612702523509, 77.11120097867905, 50.06179886479532, 2.0970795231480754, 0.17427902728799852, 0.12971734748251978, 0.16440827549705583, 0.21050660510457334, 0.10518609365868954, 0.16267213639953446, 0.11049561923550022, 0.10523116261127496, 0.11339075743190705, 0.1266114431763849, 0.15987352528158696, 0.11129812697970098, 0.13655270569987837, 0.10976531527816288, 0.14164455505388399, 0.1068455933202659, 0.1279035500521141, 0.12405303892709556, 0.14289065834976014, 0.12427929533465255, 0.08948176618545287, 0.1784644107664785], [0.0251862513382108, 0.05148404262839787, 0.04067039748113002, 0.04054793449599416, 0.030676711560978048, 0.042005014575777516, 0.06157557712867857, 0.06054228539728831, 0.04326583442067908, 0.06103449688863851, 0.02786673552867386, 0.024347183963043556, 0.022069861203612342, 0.03158709597623637, 0.03536380985150895, 0.03972702148941256, 0.027719118046544255, 0.05694880826218475, 0.1405139165299554, 0.3852908367351178, 4.496718914278092, 60.31283486273981, 57.42737854680708, 59.751920238617934, 45.744422481906035, 31.020462628333803, 20.504325397552986, 37.660307730397875, 44.703119493299916, 43.55726572775072, 11.180140568364052, 0.0020358714767010704, 0.05043380886256214, 0.09826137894584287, 0.2932176402499599, 2.050938353903832, 5.232493781274365, 2.350496260389205, 9.364884322689427, 41.52034359593546, 65.55503552959811, 63.68419439561906, 63.371746232432706, 58.63362504589943, 58.04219438183693, 57.70451753370224, 62.470891552586714, 61.19448954059232, 61.802335323825965, 58.67658284402663, 60.696721153874556, 57.964060768004394, 57.16138301357147, 54.30390496407786, 51.75774151279081, 51.71258326499693, 52.80391608515094, 56.02644128184165, 58.31220249975882, 55.53827093493555, 58.12725490139377, 57.70728672704389, 56.23261674757927, 54.56865318359868, 51.4407669344256, 51.06418409655171, 53.753769013189505, 55.432006082227154, 59.19857578892862, 52.75323121778427, 55.27387572873024, 59.4797077486592, 56.75226019274805, 55.47541103055401, 56.60276689837056, 54.53061796003773, 52.71209339941702, 56.47229709932881, 57.03222720853744, 42.46082990400253, 42.59349230797061, 42.02859647812382, 47.10410425739904, 45.51859594160511, 53.48797352083268, 52.260930615086714, 64.79980276476952, 36.3042345354634, 36.51983153435492, 61.62180431427495, 51.00526225182318, 60.16900939326133, 48.12971776531589, 46.24330482175274, 46.404906472852154, 52.46318763302219, 51.82335492103331, 48.47616895552605, 40.603234614095385, 42.40342601653069, 41.40743817052534, 46.70516783191312, 49.825609422499134, 52.32779918178436, 47.77794784115207, 43.556320436539195, 40.84674319913311, 42.148240535489975, 46.130419008193485, 56.68776466000465, 56.99611002399076, 56.95741584224086, 51.14715791517689, 56.4619420420739, 57.74172513715683, 55.36032476732808, 50.32119697140109, 43.947808281067886, 45.41717913842971, 45.05575626127182, 46.27206363985616, 50.75709781339092, 56.45490138761459, 60.1916257796749, 59.61555903957736, 59.64129371027793, 60.03112239222373, 60.418460369110115, 61.938072866009136, 59.83683955284857, 58.716998946282175, 60.575916074937396, 61.76358622889366, 56.72538803469751, 31.905406213575798, 5.117035383178342, 2.257806975995341, 5.207801970743365, 6.546006808357855, 1.0575694254329129, 0.08643669692138511, 0.01790236970860391, 0.08822822417583197, 7.8354835510253915, 39.100268656207675, 30.620545610304806, 20.16689761992424, 14.178588601850695, 20.92514080386008, 39.505629924035844, 49.985736262413766, 55.05678038443289, 59.38659852550876, 7.019444732896744, 0.21920441499640866, 0.032404515621883255, 0.07570473972948329, 0.04115518175005432, 0.0022128368295999544, 0.045470872954014814, 0.07176708610307786, 0.06700616374972367, 0.042985825453914946, 0.031563241913494085, 0.017482076636365345, 0.03533004835668591, 0.07816938247771994, 0.02413037916525237, 0.12212719347688461, 0.04011828940541994, 0.030556937544456417, 0.049109001523785056, 0.03531207976442191, 0.03682804902294471, 0.03388026526438133, 0.04211927275924433, 0.0382498775668923, 0.07483711451171868, 0.021207569873020537, 0.03636246291740287, 0.03932152349021166, 0.04103823076753367, 0.06116046472602795, 0.0338583359975488, 0.025379845587116097, 0.09218084716027783, 0.005795266498030434, 0.05919111697303672, 0.04273198605064423, 0.0655021186497423, 0.05887725458089864, 0.016160136381644877, 0.04446563153197208, 0.03023600990643665, 0.10755695192323578, 0.24901300338247132, 7.008695967735783, 70.12554599392799, 64.73800190033452, 67.1589554509809, 53.514229866766165, 37.87437500492219, 28.919876506251676, 29.764641292633552, 38.14858005892846, 51.00076721560571, 11.936401974770332, 0.05790416586903795, 0.011408814067591824, 0.26192610482535056, 1.511600933247997, 4.571467032355647, 4.163472383253036, 3.6187394972770446, 9.720813920420985, 44.81262814614081, 68.48054316736037, 66.79718740524785, 66.9768633381013, 61.42568972802932, 59.61070706767421, 60.59873250222976, 63.442615616706114, 64.6602056103368, 62.75644794587166, 60.27005357127036, 63.55342257407404, 59.624054893370605, 58.53044709851665, 56.49551753074893, 54.720354772383175, 55.05094781998665, 54.10557816105505, 56.361776474983465, 59.928599480659734, 58.224086453837735, 56.64340265335576, 58.70765978290189, 58.635845107416955, 56.413865550871826, 53.5759562061679, 53.67879682971586, 54.697695239897705, 57.982566510477376, 57.720207014391505, 54.66897172312583, 55.27523286880986, 61.61230041134743, 60.006823309006236, 58.05872324974307, 57.67027916446809, 55.1594288118424, 54.373617249150435, 58.246761675803896, 59.511502481276, 44.86154794692994, 44.15716478901525, 45.249925351911976, 51.08126209628198, 49.675386567269605, 53.626935251297496, 53.73994658070227, 65.3009443898355, 37.9543403656252, 38.333017749171105, 63.35165977478028, 54.6333997480331, 62.62467199756254, 49.494733964243245, 48.99185080682078, 48.439557552337654, 54.4090990097292, 54.35715506153723, 51.23658403273552, 44.00753421168174, 44.843869824563306, 44.027000934846946, 49.05121587937879, 52.232532655039144, 52.88991797354914, 49.211177979746175, 45.786321240086714, 44.75798952964045, 42.84435533708142, 47.297453572673184, 58.22539652547529, 59.53871980790169, 59.07617038296115, 51.387744334436235, 57.90150680849629, 59.73549335233627, 58.1909385035115, 51.94948657866448, 45.13865555486372, 48.48983841557657, 47.64917250602476, 46.92356932547785, 54.15016374280376, 57.952026936315725, 63.35617050047844, 59.812838569764175, 62.98198815315001, 62.04812672830398, 63.090724099066954, 64.36350968576247, 62.09331635505923, 61.930577216609834, 64.02276162178286, 64.3377201018795, 58.947712759817804, 35.266469524752715, 7.3768319814435905, 2.5415541760383116, 11.018063329881238, 10.311970999163966, 6.5616202931250305, 0.44541528628718474, 0.05132387279562893, 0.15177425988499196, 8.928377474507979, 40.581751792661606, 35.53113537449991, 22.888255696142874, 17.235080849739816, 28.966631158705685, 42.49671566870905, 58.36154983889673, 60.32968928737026, 70.56946416055003, 11.805578181820533, 0.17780479374191455, 0.0307022069670981, 0.07737304940218888, 0.03966537056370609, 0.02990387057164504, 0.053575895501360785, 0.05984989896176323, 0.04062996719092612, 0.059260543691174644, 0.03517970743198549, 0.034648057734293324, 0.021852613990044883, 0.07468048017472029, 0.07093428724235104, 0.04700438179556401, 0.056359931796548836, 0.06307175067523796, 0.05430565170583226, 0.05027083131755072, 0.056138777534567544, 0.03970869283582415, 0.056568238764039935, 0.1370632879796528, 0.12530960698401736, 0.10368485244051104, 0.1307855498406195, 0.10977913550431691, 0.175142546274489, 0.13391177079850627, 0.1514924927464416, 0.08270849173347797, 0.18662016748660998, 0.11407191684890179, 0.15456254413772016, 0.14725570476824237, 0.18735069360944534, 0.1284376971964394, 0.1397903464854725, 0.100759323536148, 0.14068659274808823, 0.26520860771979055, 0.5449148471797667, 9.757453760793133, 85.67382920172908, 70.9396888363746, 80.13561510270642, 60.28505663717947, 46.07884768516787, 30.898975056986657, 52.12232582030758, 58.236477221212084, 59.870352283600845, 16.036709489360934, 0.11569898800864337, 0.2938406229499848, 0.3617768097789057, 2.0313937962055206, 5.939461781132606, 13.017127725385851, 8.03364610479724, 12.995275220563336, 47.20288522781865, 70.89004731947377, 68.19616348512712, 69.69322235353532, 63.63716517725299, 61.82424176123835, 62.822057431744, 66.30904843730312, 65.03287784514889, 62.96407076620287, 58.06376741778467, 65.73380539494177, 61.71450168855729, 60.3376595435604, 59.246777795976215, 57.10137074993503, 57.19005946190127, 57.637256729987364, 59.99533860914169, 62.40103413981777, 59.46751309979347, 60.77695323574928, 62.7993586755568, 61.51161316902407, 58.58495627680133, 54.60027533192789, 56.30299191321097, 58.51465563620291, 60.75567829993464, 60.666558127249445, 54.73571869634814, 56.80305096410937, 62.805591321760616, 61.582745352099025, 60.664895042296386, 58.37088900227701, 57.15087498387983, 54.15845955571821, 60.482053756713874, 62.00069742818033, 46.70133567625477, 47.497965135881984, 47.38120009822231, 53.0410861199902, 52.49703768760928, 57.3595372323067, 55.6302583602167, 68.03132195626536, 42.91321254545643, 40.67432757346861, 64.83300955064836, 57.65607626207414, 64.80485869992164, 54.040086346287886, 52.70888490061606, 50.840259905784364, 57.1939661425929, 57.49110921736687, 53.17890644073487, 45.771847694150864, 47.169235214110344, 47.09089763702885, 51.44930985666091, 55.19098035750851, 56.54453539079236, 51.98428192446309, 47.87803496083906, 46.40576154954972, 45.58643725610549, 49.69380209522863, 61.666362439432454, 62.60333822619531, 59.94654432419808, 51.724268005740264, 58.859835978477236, 63.50710330470916, 60.365155358468336, 55.36887161193356, 47.71535073557208, 50.587886764157204, 49.280227384259625, 50.75770578076763, 55.32750237372614, 61.49195032735025, 65.85708941182783, 63.225092734059984, 64.37395887990152, 64.95820376180833, 65.44626428234962, 68.09912404706402, 64.68024107717699, 63.56606437313942, 67.60932199416622, 68.85117576968285, 61.47165598407869, 37.726682078453806, 8.269902717682625, 9.588804591086603, 19.235332742814098, 15.161786579316663, 5.243434742573769, 0.3131226576384037, 0.16112902081541478, 0.2802633998855468, 11.852566215299792, 56.801399646266816, 41.91047037801435, 29.004111366887248, 21.82353811879312, 32.046436994306504, 52.09322575599917, 64.83408820244574, 67.11128296390658, 77.18649479650682, 16.75381583552207, 0.45775880135836144, 0.29288978526188486, 0.20197980135919588, 0.13827384479584234, 0.13166673481464386, 0.15720340243029982, 0.1565908691695621, 0.14342106698501494, 0.19802355477886815, 0.1652852929527721, 0.16077050698861, 0.13198368071067718, 0.1828818269554646, 0.10958379840538388, 0.2269811420551231, 0.13396976365437432, 0.10548150482317133, 0.13598713362889905, 0.16477118666854598, 0.22572803671561906, 0.06539949351140568, 0.0957303700007258], [0.0466172086195119, 0.008963623249362554, 0.05054373098837753, 0.06526749656205216, 0.011160922379443243, 0.0065704517164117395, 0.03598752799594114, 0.03106922053942277, 0.03531070463659783, 0.031199834700072968, 0.022389191548309983, 0.03449339607369996, 0.031124219906726674, 0.03779787803068757, 0.01161732021794324, 0.026900754197530692, 0.07130780107071323, 0.030018820149463513, 0.05681232969847418, 0.0033069518723359875, 20.532109506668586, 62.42379173155754, 56.75467637277419, 61.636195490437174, 42.114684658665816, 21.26121928614955, 25.554731968910467, 45.0960821490134, 42.66840957826184, 32.887346090809, 1.6456164323514508, 0.041196450906535315, 0.03897610593647246, 0.06134823670670871, 1.2426192505705742, 4.6223337996390566, 2.966660410165787, 4.627991328316351, 26.10232230155699, 59.087074572040194, 64.45509702928605, 63.15954600611041, 61.39478929581181, 55.89706974644815, 50.784475957193685, 55.80980877722464, 60.6561363897016, 61.748332131293516, 61.01320543596822, 59.56363470323625, 59.91839347347137, 57.14805479972594, 53.46788706318025, 48.75231166039744, 46.576121853243926, 47.442557734827844, 50.44786599374587, 51.20251040304861, 56.4948977962617, 57.11926460266114, 57.622598832653416, 55.92698958612258, 54.11724328994752, 50.04445414389334, 43.03471972865444, 44.98310219857001, 51.133908148734804, 54.74024511152699, 55.90577348586052, 57.120025542474565, 59.70909187870642, 53.939230442047126, 58.95128996141496, 56.45382665818738, 55.12302921664331, 52.64323226867184, 54.67488665734568, 56.9367527961731, 50.104293823242195, 41.87786371477189, 43.129641086824485, 40.05369486347322, 48.09640899781258, 44.03859938344648, 53.50045842509116, 51.113794234491166, 66.15998268127441, 35.5798472896699, 37.37051909969699, 60.22924523199759, 52.764500187289336, 59.93408295416064, 49.46917972257061, 45.07736067618094, 43.8126394825597, 52.1283309690414, 49.56520718912925, 48.53733439599314, 42.99251502560031, 43.54208615518386, 40.9321371201546, 43.10204721266224, 42.71236758078299, 42.482320570176654, 41.02439911134782, 41.334207519408196, 41.72859399549423, 43.58982924492129, 42.40825445421281, 53.734851421848425, 55.771236188950084, 58.928049918143984, 55.22583061648954, 56.55862454445132, 59.42624976558071, 55.94062374484155, 50.05395412445069, 43.975566894777366, 44.29310629444738, 45.252066966026064, 44.45245258269772, 50.34688849602976, 57.126783786281464, 57.882993221282966, 58.27241005436067, 58.231735075673754, 60.15448877888342, 58.534596966158965, 58.29368106780514, 59.77856882156865, 59.554919196713364, 58.38245999428534, 59.309727914871715, 62.837935186201534, 49.37917309422647, 22.887143704199023, 4.381111466115521, 7.961655903247095, 12.783132849201081, 5.710110991231858, 0.6686469948580188, 0.04286827692281335, 0.05825830150335547, 0.12215920063036105, 24.683265647580548, 36.37138943518362, 25.3808670274673, 18.397965546577208, 30.098305556081957, 40.623987874677105, 49.106384015852406, 57.87807456908688, 58.883813427340606, 34.82610894787696, 0.6318208419026867, 0.10852665835691076, 0.028490285133762706, 0.06375063481109758, 0.028354335170719894, 0.043983796701556256, 0.02831406958941971, 0.02937936464384679, 0.03355903310641166, 0.04560389263074725, 0.06758758617985634, 0.05021013417130998, 0.0199553455346294, 0.04115916157682096, 0.03618831198001581, 0.0485829902332156, 0.04931687182115932, 0.011607334261850245, 0.018295587318378593, 0.11698787731509055, 0.04890245272808018, 0.020811383672539267, 0.03613375502848818, 0.06622462383201046, 0.0594682875840414, 0.06338605739837212, 0.019012772020012624, 0.01937279120958861, 0.06377485851126333, 0.060156088983339656, 0.02906842104670021, 0.04536655093092592, 0.020536384920799927, 0.0723551964807895, 0.018839936838635517, 0.03562997943992096, 0.042022791646060445, 0.06283637016050278, 0.06601859214565446, 0.09857663944844278, 0.08420193417658729, 0.028633357799281518, 26.80671918776728, 74.03387408102714, 63.95952516986478, 68.76692325838151, 48.724290247886415, 26.555207006392944, 26.271237211842692, 46.640754668943345, 44.86092429007254, 35.757726776984434, 2.703551986525136, 0.02808781318186272, 0.11432064261527793, 0.4749308460422101, 3.3107589137169624, 8.32726542026766, 4.571732772934822, 4.896945799550703, 29.742683864408928, 61.05425696219168, 69.21842728891681, 65.9730346741215, 63.78892952396024, 59.773654091742735, 53.64119306687386, 56.3508330622027, 62.96809511799967, 63.140173419829345, 60.62746778611214, 59.30214597332863, 61.695740992023104, 60.19171991655904, 55.43657172110773, 49.3849350560096, 51.003352057549264, 49.363424777984626, 52.68275799289827, 53.886698138329294, 58.25901908259238, 58.071690605532744, 59.40675558582429, 58.915529712553955, 58.386500035562825, 52.06206644735029, 45.799582773639315, 48.20750228820309, 53.940536591314505, 54.95241003651773, 60.30054999936012, 60.050808768118586, 59.197163735666585, 56.21167521322928, 60.741275356661895, 58.16257584479548, 57.10668556151852, 53.853644324887185, 56.719355429372484, 58.220254298179384, 52.197654939466915, 41.79312482956917, 46.07414868570144, 43.03775172079764, 49.85104991543678, 46.736397743225105, 56.99368992159444, 54.85286420391452, 67.41496070738762, 38.115357583568944, 39.29139790996429, 60.296819825326246, 55.53867493906329, 61.66166343996602, 51.23090444072601, 46.51865520784932, 45.543165668364495, 53.19393304086501, 53.040854700150035, 51.326755400626894, 44.805865979963734, 45.31440127280451, 43.45666085520099, 46.66583038145497, 44.89070292442076, 45.94707173685874, 43.823582895340465, 44.39768845035184, 42.722628501153764, 44.69714964589765, 43.87940214526269, 55.3127307276572, 58.94977200415827, 61.73062262996551, 54.40495698682724, 56.875563821484974, 62.46534924353323, 58.99504007831697, 51.970259451097064, 46.26092410856678, 46.731282972520404, 47.18136318268315, 46.559722423553474, 52.98342727845716, 59.00449691280242, 59.71365359521682, 61.107765936082416, 60.341072005610314, 63.88796544844105, 61.28108370688654, 59.645074875124045, 62.78200218754431, 61.648029281247055, 61.242456205429576, 62.62340114962671, 63.61225812665878, 51.79137975938859, 24.393294626666655, 4.973858575667105, 6.413118377808602, 10.530173432442451, 8.639084043041352, 3.428173593936428, 0.06313209542103353, 0.01314531897209705, 0.3274461116281248, 26.70001699078468, 34.161788878902314, 23.432080553423976, 21.743102073669437, 39.611027932936146, 47.71667257432015, 53.066922772315245, 63.21915818798927, 66.39711349241196, 45.10378176166166, 0.5682126228367129, 0.07563648895630914, 0.05080847182281075, 0.08064131838299575, 0.05093340927194204, 0.007620512154854595, 0.03911839144664907, 0.06817457806919852, 0.029628419828030373, 0.037281596056756475, 0.019293384281017126, 0.02163581685313294, 0.09528762480664639, 0.009275316655065024, 0.055244814213966174, 0.028119960146385337, 0.047763666859076875, 0.05040977668437747, 0.009703880604056102, 0.0655050910708885, 0.01688263390303379, 0.06386146092066361, 0.22086037533177486, 0.19567036250185585, 0.1625200679465648, 0.1500614098603687, 0.10760222005868152, 0.13857661806527646, 0.14953797262522484, 0.18096760305906498, 0.10318992899790888, 0.16602153409152262, 0.1565100775370675, 0.1511345611464593, 0.1993241575696776, 0.2137288781664064, 0.17344118756872995, 0.21190574212420374, 0.2819442580784521, 0.17616974760688123, 0.12694489060630723, 0.12401664975069224, 34.694740926065755, 84.41041023500505, 71.9995681701168, 78.91982939935501, 56.859266373419, 30.428341627120975, 35.955155357237786, 60.66356928117814, 56.588638521009884, 47.15729551930582, 2.9906935076559744, 0.21952738234352684, 0.26695176418269834, 0.34808645084981, 4.032823626072177, 17.375993959365353, 10.715021990960645, 12.001523125556208, 29.799928895888794, 64.33089517777967, 69.82526502301617, 68.57649218651557, 68.02933723695817, 60.77233660605646, 54.44818935086651, 58.664137163469874, 66.11742496490479, 64.76810216903687, 60.63315130049183, 60.426983679494555, 64.33365260401081, 61.85223963952834, 58.924017721606845, 51.900229454040534, 53.24512781635408, 52.44469758002989, 55.65657354170277, 58.10516803495346, 61.61049219869799, 61.8799158834642, 62.17967125677294, 62.24343722866428, 59.252465232726074, 55.418705324972834, 48.212213054780044, 50.53465235617853, 56.22278336555728, 58.57610740969258, 61.847744603310865, 64.00190637957665, 60.60502398398615, 57.85310868294009, 60.89612268632459, 58.89000684984269, 57.12259861730761, 55.95625046760806, 60.31787510841124, 61.23814944298037, 54.90441983745944, 44.388451268596036, 48.08932911965155, 44.35376574916225, 53.0627925165238, 49.89578062488187, 58.01192152884699, 56.23768444984191, 71.31167857877671, 40.852595375430205, 42.88955673094719, 61.56896998805385, 59.66414936127202, 64.63383159329815, 54.448495295739946, 50.577382656835745, 47.81688128748248, 56.902894896845666, 55.78975762090376, 53.23461978666244, 48.836160167571045, 49.32340875748665, 45.82889072356686, 48.66353273391724, 46.28077522400887, 47.542711534807765, 44.879649685275176, 46.73970822365054, 45.57377584518925, 49.64098345848822, 45.1304970249053, 59.056354568850615, 61.69521147204984, 64.09649041391188, 56.578318765086514, 59.04371276978524, 64.67696589808311, 61.25366633938205, 54.720142964393865, 48.24349395690426, 49.15835934300577, 50.05406002844534, 48.51024258521296, 54.675537770794286, 61.36698361366027, 62.460834595464895, 63.660150266462765, 62.68699845960064, 66.55519285509664, 63.93789329836446, 63.94917403498004, 66.33357109562044, 65.76721614406955, 63.8242857686935, 63.084730717443655, 67.5560248282648, 55.7083684398282, 29.292458526549805, 8.950408447173334, 16.318011091601466, 25.51356081039675, 13.074146239988266, 2.1755595312964533, 0.17703104493839128, 0.16570063518180003, 0.468789732023593, 34.68640981181976, 52.305657402161636, 36.304246302573915, 27.143680203345518, 40.60778848586544, 54.50765640504899, 59.82566864259782, 71.67672572597381, 74.23650372412898, 53.22238983646516, 1.13673388717636, 0.24590159856504012, 0.1440553724645607, 0.16269590044694562, 0.10148245691051407, 0.15799178351317683, 0.0893286941573024, 0.1870294269775191, 0.10240642789510951, 0.12093302328139545, 0.16619113063619984, 0.11334263178850375, 0.14305127634396478, 0.10505757474851225, 0.2182146140764798, 0.07194936906378116, 0.11466060945343588, 0.13136429862389642, 0.10567910954236023, 0.2684422342046615, 0.17481197933516196, 0.15428315187173505], [0.06286733926484181, 0.018280100850989262, 0.059659767430275686, 0.03869906172997529, 0.06498260378477073, 0.02398036382791977, 0.05491589436367635, 0.017581135635414434, 0.037620628267646804, 0.04962010857378764, 0.010579164785843705, 0.01611062028865901, 0.029547881004550768, 0.01388793013193795, 0.02523331594983897, 0.06487864565344588, 0.05399376199009919, 0.05235165252440399, 0.06929033150475833, 0.3655997110951332, 32.90265314040646, 65.19772721875098, 63.51648169179117, 48.495855331420906, 37.56786531017673, 25.627034979481852, 42.107804821383574, 45.56570360737462, 40.83764330033333, 20.928047280157767, 0.005063499791562678, 0.0907883597838302, 0.10332728856273236, 0.192753421443124, 1.6785252406712503, 3.7710162035880552, 1.3471885361979086, 16.104317422836058, 51.66254951107887, 68.6358533367034, 65.41957647569718, 63.46636556809949, 59.71039018323345, 54.807819704855646, 49.81768231238089, 51.55945393346971, 58.991404041167236, 61.6112413714009, 59.38022859634892, 58.76442824640582, 61.94163830049577, 58.73390828409503, 51.107236031563055, 45.778994252604825, 44.569868733806, 44.62694314218337, 47.037498489502944, 48.9304147228118, 51.7400751575347, 56.207203711232836, 58.96283741920226, 55.5396947553081, 55.075082163656916, 44.357091919068374, 41.59039712721302, 42.10109756838891, 47.70868270627914, 51.14309433967837, 54.64696330408896, 55.766639171108125, 57.26722425030124, 52.042070204211825, 53.293353357622706, 53.50243922202818, 54.806270368637584, 51.93120441129131, 57.847111378946614, 52.67585069902482, 44.64711589197959, 41.26083174059468, 42.436075825845045, 44.26879544411936, 46.28649403972011, 43.58927619072699, 52.418033307598485, 51.059579233969416, 63.04040008975614, 37.57479221590104, 36.025342249101215, 59.97382048637637, 51.15539097016858, 58.459381595734634, 50.09485267823743, 46.13336078582272, 41.13978347470684, 49.70638505874142, 47.45994167943155, 47.736202055408114, 42.75731009821738, 43.67082618897961, 41.13388422996768, 41.59716713813044, 41.213602481349824, 43.68480159390358, 40.311924103767645, 41.550177143466094, 40.128529763990834, 43.00321525143039, 41.23357911263743, 47.917603831137384, 53.991774512875466, 57.24447450330181, 54.291608333587654, 52.731379693554295, 58.185964938133, 57.0858891548649, 51.67530113650907, 45.55347365717734, 43.81279245499642, 44.60579764458441, 45.88398825737738, 45.401693620989406, 55.35613567598405, 59.89995441129131, 60.05876725719821, 59.333426875452844, 57.61021983238959, 57.35128456546415, 58.831665515899665, 52.41506799574822, 53.55934889085832, 53.663040668733665, 58.914674635856386, 60.15064093374438, 60.629581943635024, 29.52558852011158, 7.525934019396383, 4.763771035978872, 9.358049592664166, 10.833095139072789, 1.3179321899529428, 0.03760006263731949, 0.06122859675557383, 0.01881231553852558, 5.968522131443025, 39.245015882676654, 50.29857666261735, 24.130121238770027, 23.73454628452178, 46.22379103014546, 34.852326070108724, 51.95052600676014, 50.34571962971842, 54.596380418346776, 1.488129470136858, 0.11953075296215473, 0.003743877910423063, 0.019639933729664456, 0.03228846862311325, 0.03829030019621696, 0.039916241376270215, 0.0320421387967203, 0.01820369315664134, 0.043211756274104125, 0.016952311514966914, 0.044358187700591745, 0.05291797153110947, 0.04504911473862106, 0.019504675160973303, 0.027526546525017872, 0.07630318463329347, 0.0790892778745582, 0.04072194370711523, 0.045610235838760296, 0.03011815110972572, 0.08264485280960798, 0.09672401668203455, 0.03878418558968171, 0.03440072241749975, 0.015049978260762029, 0.04661565729146523, 0.0579317718473894, 0.04950314609994812, 0.003286500197587415, 0.025996642127152414, 0.051288425907372474, 0.05410523161352162, 0.03132829423843613, 0.03068338993245796, 0.006431006477214397, 0.032378483954216206, 0.02155657463346518, 0.04138806864859597, 0.05935903578515976, 0.04425506077466473, 0.4307979609697096, 40.97484780896095, 72.94267069908881, 70.41062385805192, 56.21739795131069, 42.2198159463944, 29.433057846561557, 35.24184488481091, 41.55247957475724, 44.91966962814332, 23.622874444530858, 0.006562614158141397, 0.15993416880167302, 0.18281972786832243, 1.4582847683660447, 4.786699741117416, 5.4781969324235, 1.81154654151009, 15.290301076827513, 54.99983933664138, 72.68032689248362, 67.39936536358249, 65.35368850154262, 61.43604870765441, 57.411924408328154, 52.21073996636176, 53.70080917112289, 61.249806727132494, 64.76090461977067, 60.728794374773585, 59.11722975392496, 64.23493831388413, 60.091621029761534, 55.629234621601725, 48.93931458073278, 47.39617962991038, 46.434230112260394, 49.515432311642556, 51.15372396284535, 54.69960543417162, 56.627395460682536, 60.679003807806204, 58.09822936211863, 57.35653661912488, 44.6668650257972, 43.80082138123051, 45.23932710770638, 49.03700513224448, 53.85520542821577, 57.6249679442375, 57.84305172581827, 60.105949448001006, 52.355757836372625, 54.57314429744598, 52.9571238640816, 54.6011382533658, 55.248599975339836, 59.85615330357706, 55.90177266828476, 47.09119965953212, 41.791959885627996, 44.674486191042014, 45.733710488965436, 48.69894781420308, 46.14184095013527, 55.388271654805834, 52.96528239404002, 64.40928766804358, 39.15722539347988, 36.142064140688994, 60.38401019188666, 54.16389988314722, 59.9870349514869, 52.39917847418016, 46.337512308551425, 43.44585080300608, 50.634806156158454, 49.142540424100815, 49.64064221228323, 45.754852064194225, 44.900936388200336, 43.31019955296671, 42.83048191378194, 42.77494115214194, 45.22199415391491, 42.39774642452117, 43.064678792030584, 43.01168364863242, 45.24066463593514, 42.39149808883667, 50.1636588958002, 56.10215087090769, 60.20216518832792, 55.97592899876257, 52.86312426290205, 60.861084153575284, 58.56253993126654, 54.50448712994976, 46.19748369339974, 46.524421092002626, 45.91895226509341, 47.13360048109486, 46.68682682898737, 57.60236724730461, 60.62312179996122, 62.86101833466561, 61.33771096506427, 59.662333303882235, 59.22519299291796, 59.93555776534542, 53.82063365751698, 55.77597048974807, 56.10673219926896, 61.54105447953748, 63.08007094167895, 62.683738969987445, 30.74493769676455, 9.085842005668148, 5.420740092954328, 8.837327495698007, 9.216893296087942, 8.37305615025182, 0.3942004699380167, 0.08541503440468542, 0.060472207504414746, 7.3936006042265126, 39.84332246165122, 41.68760130482335, 21.708477350973315, 25.07984865096308, 56.02865349861884, 41.232480848989184, 58.372434416124904, 54.932029401102376, 64.87201359964186, 5.8099804193742814, 0.14723690497058053, 0.018464846784369122, 0.12485683369900911, 0.04457457689568401, 0.03200375587649403, 0.05751300903577959, 0.05047025932599941, 0.053547676652669914, 0.08005680861852824, 0.04050379634023674, 0.010725818912408525, 0.019261120488086057, 0.012587606963220865, 0.04458900233129821, 0.040669175570890795, 0.010367340517170247, 0.044255589375332485, 0.03676954671860703, 0.028581598983897318, 0.025396523321227684, 0.04682623954009145, 0.1674970500772038, 0.12045311516210919, 0.10816771552086839, 0.11360125541086159, 0.15740211031609969, 0.12954352213250053, 0.2177057937989312, 0.15030455084577685, 0.16749826049612415, 0.22760174988258272, 0.12482804411481466, 0.17828772024762246, 0.14200276244551907, 0.21639681000623012, 0.16457512944696412, 0.15356682901901586, 0.1454736616822981, 0.1304090789128696, 0.14777385599670873, 0.838968932868973, 48.04304907398839, 81.57838836792978, 79.32682237317486, 66.08152743308776, 50.194021963304095, 36.98646414664484, 57.771213516112304, 58.740313514586425, 56.648913583447865, 28.326894544786025, 0.2665176681212841, 0.26384218265452697, 0.19785507672256042, 1.075459846085118, 7.598463546845221, 11.61587372902901, 9.052126292259462, 21.790539218533425, 57.44639419740247, 75.16937671169158, 69.91234164084159, 67.68223885566958, 64.03030826199439, 59.627800756885165, 56.25194226541827, 57.09154129028321, 62.3924010030685, 66.6297649568127, 60.340338522388095, 59.33539198290918, 67.2654164221979, 64.11363901630526, 57.33695222485451, 51.55735546542753, 51.053856495888006, 49.184792195597005, 53.54353389432354, 54.482157076558764, 57.31987422512424, 59.14509427162909, 62.94889119363601, 60.85729122161866, 59.51144364572341, 48.04904637798187, 46.20981954759168, 46.86580850232033, 50.207577674619614, 56.46815899879702, 59.12546673128682, 58.55333020610195, 63.00703640907042, 54.71084694708548, 55.04464457111975, 55.20808581382998, 53.967498963879, 57.32407116120862, 62.8376566979193, 58.67687309941938, 49.33735670581941, 44.4273768701861, 46.13240372750067, 49.62569405955654, 50.718278115795506, 49.67957958098381, 58.38748455047608, 57.20819650157806, 66.47960093713576, 42.32770466035412, 39.050905627589074, 60.96292065035913, 56.912928319746456, 62.68414297411519, 54.63015594790059, 49.91682414085635, 47.27611980130596, 54.09537999860702, 51.66130219736407, 51.79685931051932, 49.489689796201645, 46.38004649070002, 45.736938599617254, 46.23550322748, 44.779762606466974, 47.81455139960013, 44.86141850871425, 45.65967967433315, 45.02432238671088, 47.34113700928227, 45.16860285112935, 53.78877224460725, 59.348578991428504, 62.5846795112856, 56.689886662267874, 55.192447323952955, 63.572579429995635, 62.39135373023249, 57.842384922888975, 49.38823769169469, 48.14252822629867, 49.215598490930375, 51.14730696524344, 49.819455223698775, 59.491180681413226, 64.5614089504365, 65.99322703576857, 65.06368021811208, 61.59817987872709, 62.40181076911188, 63.27279267772552, 56.75166007011168, 58.14714916290776, 57.89487408053491, 63.85291122621106, 66.93664335435437, 64.01187312218451, 35.61924749805082, 11.980914012078317, 13.06131616715462, 16.14885397495762, 19.498725783440378, 5.938578267251292, 0.4781444929540158, 0.24132592393265617, 0.2548460121597013, 9.682352139103799, 57.61879805595645, 63.261943401828894, 33.046725719205796, 30.284237669360255, 58.38873578656105, 47.49490568714757, 68.09546055332308, 62.96462774276734, 74.82639681908393, 10.363293251683636, 0.3347875322065046, 0.13847655166060696, 0.2612999351995607, 0.12116455803475074, 0.09518317637904998, 0.2607856450542327, 0.17627929818005333, 0.1359957291354095, 0.12311056691912875, 0.1879368734455878, 0.10802698516917807, 0.15643789673284178, 0.11692459845254499, 0.11888651132223108, 0.18810564261530677, 0.1200389220649677, 0.15936930153158405, 0.11706106169449708, 0.09152525975819557, 0.11794454493229428, 0.16159814241672718], [0.050089234005539655, 0.010990857563522315, 0.01800766466335664, 0.014756975485192192, 0.017765312748510512, 0.03947338509944178, 0.05654548595268881, 0.05279510251937374, 0.019601931938180522, 0.005395044929408018, 0.09650886854937962, 0.07106300533538865, 0.06259676850130481, 0.06005950827872562, 0.07142225460660073, 0.026806211286795237, 0.12182334768435649, 0.023450234814757304, 0.014272748545232802, 2.030871630676331, 44.05708943643878, 61.51303306702645, 63.9209133578885, 48.66741195801766, 31.029287961221513, 20.584353516178748, 33.3857753969008, 55.16217447096302, 37.452233837496856, 4.718138671690419, 0.04787034077209331, 0.08341865523928597, 0.03401684724996167, 1.3001958449040691, 3.465071330147405, 6.261320200658614, 4.314967067010941, 26.142397157607544, 64.45769363834013, 62.51941127161827, 61.931961813280665, 59.340216498221125, 56.42484426498414, 53.271568513685665, 47.474179883157056, 49.45616137596869, 58.87466253772859, 62.7234451232418, 60.71314019541587, 58.26511444584016, 60.03269134029266, 57.79192363062213, 50.37012853930074, 42.991208876332934, 43.58657367767827, 41.7482921384996, 43.83798583861321, 44.92535706489317, 49.38723356493058, 52.36504600894067, 55.19525574099634, 53.16529189386676, 47.91297543433405, 41.29698814884309, 41.353278083186, 38.478494536492136, 46.91991367647725, 50.193382616966005, 54.11358371857674, 55.95442656547793, 56.02579801313339, 56.93023381694671, 54.39370370680287, 52.67877286480319, 54.08591139701105, 53.57887837194628, 56.043633030306914, 45.88947173087828, 43.05885799469487, 42.04750622472456, 43.81997039241176, 42.01838262619511, 44.51987420358966, 44.461105331297844, 50.20634997275568, 52.41283224475, 63.32465033377371, 41.65843848259219, 35.64880647966939, 58.176359053580995, 53.49550054919336, 58.87975769658243, 51.86561453726984, 45.73312997817994, 40.93341581283077, 44.94012086622177, 45.28710157640519, 46.80028923096196, 42.8294111067249, 44.759240765725416, 44.10076502830752, 43.40637999196207, 41.42093896865845, 44.54753083567466, 42.6241534756076, 42.727009788636245, 43.65474447127312, 42.66364389850248, 41.815866731828265, 46.79106773868684, 52.7876696278972, 57.04269993689753, 56.388181870983495, 53.34043356680101, 56.38612262664303, 56.12436717556369, 54.26455574650919, 50.02474815614762, 45.257966210765225, 44.63627053845314, 43.9413442150239, 44.648578936053866, 43.015704078059045, 49.615021290317664, 55.041942058071015, 54.75689557290847, 54.03475976759388, 51.76916737710276, 49.235441761632124, 48.89486235956992, 51.4821675515944, 55.424816377701305, 56.20169278114073, 62.50245094299317, 64.60153871966948, 47.33578689636723, 18.528682454939812, 5.137632729545717, 4.723561838749917, 8.423983223976629, 9.518536310042105, 0.5956515633771496, 0.03117583125018545, 0.06266183234871396, 0.5572489240477162, 17.88117366452371, 40.0170716931743, 46.43790145074168, 24.90595821411379, 16.628486302591142, 28.30056759618944, 43.05516312199254, 52.052550777312256, 54.31697430149202, 36.21380036877048, 0.5052097358049885, 0.07965913237703424, 0.04432750204878469, 0.02400822070006642, 0.03689264555672004, 0.04691393745522346, 0.01280681727709429, 0.04612339983483957, 0.045627534104090546, 0.03275367934557219, 0.08683108664568394, 0.03404213581234217, 0.08728192172824376, 0.05320041665747281, 0.031693553469414194, 0.018523833639318907, 0.0274674370960002, 0.05903493845835329, 0.022020352771505717, 0.07468012011339588, 0.018931677782787912, 0.008235964210583799, 0.04492958203979558, 0.017958186874766986, 0.0431313400246924, 0.03465970227074239, 0.035561261353113, 0.023690826642597397, 0.03685002042461307, 0.02872201906997831, 0.0578179081992036, 0.08517780761805274, 0.01495242941253368, 0.06917981566080163, 0.05326510895223868, 0.07622762538132168, 0.042833243722036, 0.02808330858486795, 0.025368256592041543, 0.03500657922197734, 2.8836995843918096, 56.55832252194805, 69.96664293350713, 70.17744679604807, 55.93187293698711, 40.684584571469216, 28.133280469525246, 38.08113098144531, 49.471717496072095, 41.590554022019916, 5.582257903391316, 0.07745263827664238, 0.02002963499586669, 0.26007747337702786, 3.5347012454463593, 6.468828291662279, 7.757767669616207, 4.592837085646968, 30.708622432524162, 66.04366087144422, 66.5982997032904, 63.85806914298766, 61.780048416506865, 60.23745867513842, 55.84008163021457, 49.629000617611794, 50.7874922598562, 59.437342228428015, 63.17255650797198, 60.63823076986498, 58.92697911108694, 62.45330364473405, 60.64076462099629, 53.215102072685, 44.919783376878314, 47.97214438838344, 44.29176484384845, 46.05057916333599, 47.28112474564583, 52.799691692475356, 53.52760122668359, 56.81593595012542, 55.13371767536287, 49.7227099633986, 43.969455842048895, 43.2642529087682, 41.31077527999878, 48.77208040606592, 52.96845166913925, 56.35290407365369, 57.06956425020772, 57.26496496508199, 57.72310956831902, 54.96003120176254, 53.773522069377286, 54.760739495677335, 55.98134579197053, 58.810720059179495, 47.821258652594786, 43.96693768039827, 42.9946566397144, 45.57472505877095, 44.6149524565666, 46.26656447687457, 46.679566521798414, 52.73382333017165, 55.4796628798208, 64.36089346485754, 42.722628501153764, 37.01185757114042, 58.23575550510038, 54.279499976865715, 61.27179161194832, 53.73685967537665, 47.05788304728847, 42.01697449530325, 45.866906335276944, 47.75240144421978, 47.13076460746027, 44.545032285874896, 46.813166372237674, 45.505954142539736, 45.03068839350055, 44.78149629408314, 47.15924493728146, 44.99338273079165, 45.553308917630105, 45.65293319763676, 44.71899332538728, 44.612657870015795, 48.35730152745401, 55.12961095379245, 57.89022607188071, 58.529533186266505, 52.81366317502914, 58.345158253946614, 59.20136067175097, 56.156714962374785, 52.6626636905055, 47.58775211149647, 46.25858637594408, 46.69340856613652, 47.62868988898493, 44.48896200426164, 51.70079262025895, 57.348919376250244, 56.79042485452468, 57.38402458929247, 54.2769229796625, 52.548589398784024, 51.457503687950876, 53.54139620257963, 56.57408652767059, 60.76320140592514, 62.46380775205551, 66.53298439518099, 48.55980173234017, 21.081115814947314, 5.126112728349624, 7.285678059824052, 9.01814091590143, 11.08261573699213, 2.34429867036881, 0.26275626834361787, 0.02650188285887482, 0.4375039575801742, 21.34673087827621, 40.57673900358139, 35.76149617472003, 17.334363883541478, 25.533164816517985, 35.59408549339541, 49.373893583974535, 57.77375913435414, 62.944921755021625, 46.05434071633124, 0.8804559647556275, 0.031801250109809547, 0.11336026713252069, 0.015508794064273038, 0.00750852829491299, 0.04858754079548582, 0.01971186938575439, 0.05212846046854412, 0.06887690449554114, 0.018879986000097087, 0.04641052958885989, 0.021443318109959367, 0.04525743319743103, 0.020857676450583725, 0.03240405596912869, 0.041615803605846824, 0.05900780745451489, 0.014047950577561655, 0.022958862189684185, 0.03725431949621247, 0.01196553111977635, 0.10122109835426654, 0.17886608598693726, 0.07130664427794757, 0.09302716747286821, 0.13552761877015715, 0.0930671496016364, 0.12755986768752337, 0.1627986634811086, 0.2338084103840013, 0.14041648546774543, 0.2512474520312202, 0.1411685233394946, 0.17733130543943376, 0.2334274501810151, 0.22598171907086528, 0.11549107174599364, 0.15962476121081462, 0.1416822159362416, 0.1507677582483138, 4.2354096328058555, 69.5655256702054, 79.05355868800994, 79.5702995792512, 64.66762281233265, 45.448656159062544, 29.41320869230455, 45.7281760246523, 67.77759167455858, 53.11788220559397, 7.859867945794137, 0.2769169133276709, 0.19107601064587795, 0.3576241842200679, 6.029221790452158, 12.598375485789392, 18.9268442123167, 11.11473112337051, 31.351138045710904, 68.79729809299593, 68.09775906224405, 67.97699712937879, 65.42615036810598, 62.82122588926747, 58.458118592539144, 51.518602448125044, 52.3590487049472, 62.99594002385294, 66.21939874464466, 61.73498430559712, 60.102905688747285, 65.60662254210442, 63.777762536079656, 55.16239804606284, 48.07408286679176, 49.07335373663133, 47.167576051527455, 48.49196041783979, 49.366193971326275, 56.983687877655036, 57.519248300983065, 59.334168203415416, 58.17481756210328, 52.375722700549716, 46.140009203264796, 45.72058623836887, 43.409541422320956, 51.66917047192974, 57.30202351847003, 58.794869761313166, 60.67840368516984, 60.33585133091096, 58.90705739298175, 56.66886275814426, 54.183445053715865, 59.12634141983525, 58.02823858876383, 60.74424459088234, 50.06884736399497, 47.01319548391527, 46.39366103756813, 48.05069377345424, 46.07418006466281, 50.30030250549317, 49.37777673044513, 54.39577864062402, 57.249867762288744, 67.68913438243251, 47.76270158829228, 38.73961848597373, 59.67361011812764, 57.5904118630194, 64.26967874650033, 56.426260240616344, 48.41984764222176, 45.06410698736868, 48.61196141089163, 49.81099467123709, 49.862185524355986, 48.245749319753344, 49.392615056806996, 48.94982261042441, 49.53968824878816, 46.88853471509872, 50.33277580814977, 47.68918460415256, 47.55743219006447, 48.60226531182566, 46.65477714230938, 47.149635130359286, 50.905669350777906, 57.02781454209359, 61.78657916284377, 59.79787080518661, 54.39298591306133, 61.537426287128085, 64.33969305407616, 59.00225723943403, 55.467605513911096, 49.676386771663545, 48.716771064266084, 49.32913934030841, 48.97412953838226, 46.83485707929058, 53.63901222905805, 60.46813718734249, 60.69272425866897, 59.705032225578066, 56.53876558426888, 55.05409356086485, 53.60846481015606, 56.4633737071868, 60.28376617739278, 62.41210306844404, 66.6769040015436, 68.31859634768578, 52.529742410106046, 23.68654431835298, 12.441562068077827, 15.540499264194121, 17.775969812946936, 16.071061607330076, 1.120570412566585, 0.11731970829949265, 0.08061532501972492, 0.613473403838373, 27.699564387721402, 55.96847649543516, 60.52766699944774, 35.152783547678304, 27.855039296611665, 39.380882863075506, 58.454443331687685, 67.12358351676696, 68.17663008166899, 55.42575774654266, 1.4875700420910314, 0.2595664620880158, 0.20185502095808908, 0.12800043719189783, 0.09535435872573046, 0.2114781731319043, 0.11373114561842335, 0.13400763904135074, 0.21377789247180187, 0.11395328813382696, 0.12315629470732906, 0.10762526398344387, 0.17167458881533917, 0.09779226500540973, 0.16133637017300054, 0.13062948240868508, 0.09924096025286183, 0.14443385054267224, 0.12027571218148356, 0.19909566418538172, 0.13001408397911057], [0.03135353683554117, 0.036621044404924884, 0.0535878005077041, 0.01963648441878538, 0.05450190044939519, 0.0264449663565404, 0.04888847545390168, 0.016465748006838466, 0.019063469803621693, 0.06015995772735727, 0.08080470195460705, 0.028829516527513345, 0.028157479302476973, 0.0112494170260165, 0.016588561477199677, 0.0658280277744897, 0.056380367191929015, 0.0755532611642153, 0.08497307062028878, 11.568953356435223, 56.788400911515765, 57.70123058749784, 60.31599237072853, 36.637259452573716, 23.2647483195028, 26.02991927054621, 45.20428857495708, 46.81164057024064, 21.59853135385821, 0.9544894760174136, 0.028405019547790292, 0.12118480573858946, 0.2629204563075497, 2.5734040669856535, 4.508378649911573, 2.3984085023403168, 8.588028511693402, 45.83437419706776, 65.76459207842427, 63.46924458780597, 60.33104250507971, 55.16339825045679, 55.20317500637424, 51.75019879494944, 48.06772470474244, 46.48480123089206, 57.50305283454157, 60.813392054650095, 59.12407821224582, 56.64670921141102, 61.64750760601413, 55.56142468606272, 47.89022960970479, 41.775364337428925, 43.07369239868657, 39.634185606433505, 43.662597056358095, 43.67401507592971, 46.30690997646701, 46.52600180718207, 49.78931180892452, 49.05528337724748, 45.128661355664654, 38.59201969638948, 41.55552725638113, 40.426771102413056, 44.80929805386452, 48.84189859513314, 53.06632264967888, 51.63274734250961, 55.797480767773045, 55.76173228602256, 53.52760122668359, 53.126734995072894, 54.58174997760404, 55.04198128177274, 51.29381925828996, 41.95669943286527, 42.90947060431204, 40.369112260880016, 41.48112773895264, 42.0529975429658, 49.17873605605095, 43.55649694319695, 52.09388863655829, 50.37250549562516, 61.10494575192852, 41.47004704321585, 34.03480998931393, 59.42148408582134, 52.58985273299679, 58.43717705818915, 48.254660944784845, 44.657298364946925, 41.721239551421135, 41.34719840941891, 42.749453590762236, 43.59830156449349, 42.38526936500303, 42.95335015942974, 42.32183679457634, 44.155631142277876, 45.46298065493184, 44.261495913228686, 44.16183633189048, 45.18371966577346, 43.791140971645234, 44.436641508533114, 43.349231058551425, 47.925232841122536, 53.85101241450156, 56.505884355114354, 56.68024547638432, 50.899452394054784, 56.07638089887558, 58.209608985531716, 54.53543855297951, 51.79284280346286, 52.09330028103244, 47.30487861940938, 42.46963562503938, 45.04327527938351, 43.65196351082095, 43.73552960734214, 45.36055188025198, 47.17059627656014, 46.96869227194017, 45.522820334280695, 47.235840982006444, 46.44597761092648, 52.76854022856682, 56.3936221984125, 61.01263276992306, 58.804287372096894, 59.05069458869196, 52.67305404909196, 33.65719556808472, 12.352104571557815, 4.638699889183044, 4.4981559726499745, 15.29091198598185, 1.2966506351386349, 0.2705543692554197, 0.19361087301325416, 0.09905401181669966, 5.912014505555553, 28.71248902813081, 27.119243837171986, 23.131409306680005, 17.60633122536444, 24.032832730200983, 38.52707309107627, 46.465875794810636, 50.662101930187596, 43.9599480167512, 8.450133665915459, 0.2540103328083792, 0.0545998371296352, 0.05854088069510557, 0.023689752204283595, 0.11984262735612931, 0.04481125592945084, 0.08372677580243157, 0.011737728172222213, 0.026611975439253355, 0.1237604776096921, 0.06235397608590223, 0.07747452540863907, 0.0221272143760636, 0.04075534514061386, 0.01578754760445126, 0.026636890533770767, 0.03521068419720377, 0.02539670143667008, 0.0396033059505205, 0.011491703823389066, 0.043427750933915384, 0.04832256247379607, 0.011985766374686313, 0.019015685069344698, 0.025022032730762037, 0.05709319668371351, 0.05249242884136977, 0.027375736371463826, 0.05292956244140383, 0.04113562352534744, 0.05147517516067432, 0.05153847700585762, 0.05005858665812881, 0.04509367424273684, 0.017016394769832972, 0.05657122267650501, 0.06448890608284744, 0.0285941417584376, 0.05748923349704954, 16.921907048071585, 68.75587001923593, 62.0664010509368, 67.47892672015776, 44.917233836266306, 28.78405659429489, 24.866269711525213, 37.14105259987616, 48.58857231755411, 26.252115657252652, 0.9299791363939163, 0.08082573872900779, 0.08151112695134456, 0.9927979784627116, 5.67731507362858, 6.979566485651079, 4.3366813082848825, 9.123851733822978, 49.96517912034066, 67.25411999610164, 66.38748015126875, 63.06862154314595, 58.858267030408314, 56.9209260325278, 52.92407005063949, 49.616229380330736, 48.80552645652525, 60.84018184292702, 62.62051428517988, 62.2252138968437, 59.03555423982682, 62.03875618596231, 59.80364845645044, 49.718975866994555, 43.98580820329728, 45.372189552553245, 43.51737522309826, 46.1394836056617, 46.10392732004966, 48.609282432063935, 50.292520523071296, 52.44576054234659, 51.12638896511447, 47.694091489238126, 41.12375667018276, 43.12517742956839, 43.3185738132846, 46.86490243481052, 51.17763080904561, 54.89026400350756, 53.86949854512369, 57.581272740517896, 58.85354057435067, 55.53552135344475, 54.234879093785445, 58.63531166507352, 58.28348290535712, 54.35381320215041, 43.078936607606956, 44.65073623964864, 41.926171625814135, 45.108998513990834, 44.41773960667272, 51.55861454625284, 45.20482593967069, 52.465140973368, 54.055920954673525, 62.09264170738959, 42.912126048918694, 37.31817506974743, 60.38659111146004, 56.00379743883687, 60.08214458342522, 50.55945350277809, 46.190035112442516, 43.54057604266752, 44.23041112961308, 44.73860909861904, 46.226246433873335, 44.48232535393008, 46.14352364693919, 45.211223325421734, 46.72874519901891, 45.943404320747625, 46.61081129504789, 47.53719668234549, 48.31060178818242, 46.01914921114522, 46.32937731281404, 45.47707765333114, 51.1966896057129, 56.33714006793115, 60.25801189484135, 58.863723047318004, 51.32407249942903, 59.38589642124792, 61.080352490948094, 56.66780371819773, 54.76142198808732, 54.39059718962639, 48.57174534951487, 44.662413135651626, 45.87807332315753, 44.79486765400056, 45.073120594024665, 47.01973015262235, 49.42750061711958, 48.797885679429584, 48.5227902473942, 50.35375264383132, 48.282741192848455, 54.33188323051699, 59.242812279732, 63.45837962242865, 62.025314223381784, 60.517284485601614, 53.674274336907175, 34.431902900818855, 11.913400215487327, 3.403036104094598, 7.50812400733271, 11.906172267852291, 8.956344954429134, 1.2749182529026464, 0.11819391421252683, 0.05717380828554592, 6.3844698763662775, 34.07394347652313, 36.53408934993129, 27.29429921796245, 18.75994343911448, 31.640214766225508, 44.63914563578945, 54.57104975177396, 56.4536109278279, 53.11846663874965, 10.502167709412115, 0.1403840493050314, 0.040404875237014026, 0.009409936497949306, 0.03300926925974988, 0.018880824866374175, 0.07712731903959667, 0.024851587743708686, 0.00493155790477871, 0.04728961548197174, 0.04684278703925591, 0.026011387404475002, 0.04484588310362832, 0.014994401454685197, 0.01450260460842401, 0.03217321452534488, 0.09192398554014583, 0.058766803854415496, 0.019431400766235687, 0.05634315447100709, 0.026009301730101148, 0.13210565722998113, 0.16639926140346836, 0.1838413214371089, 0.1086077564245751, 0.10454153026183767, 0.2357012297837965, 0.1627522538746557, 0.10678168626562243, 0.10405099650304164, 0.1905497695289312, 0.14871830451152018, 0.16923173360766905, 0.11694458568648947, 0.15332119058697455, 0.16124394932581534, 0.13562995279508253, 0.1931912100483333, 0.2385536202740285, 0.11050264426176587, 23.35124246535763, 77.44266479246079, 71.07785040332426, 78.48501897627308, 51.60632625702889, 34.9259764148343, 34.66688425310197, 59.412325351468986, 61.343582753212225, 32.430491947358654, 1.4390470135596491, 0.24877694104948353, 0.3380816489938767, 0.9609165246928892, 8.097932281032685, 14.267170429229738, 11.915027999108839, 13.014095733242652, 51.731489089227495, 71.23311350422522, 68.37284272716892, 66.65880618556854, 60.34771650068222, 59.3947962791689, 56.68949442525064, 51.761114751139, 51.71809419508904, 62.43619818841258, 65.71748441265476, 62.43342507270075, 57.751350633559696, 65.04837905206989, 62.49648894033125, 53.001419190437566, 46.28149301775041, 47.77439417377595, 44.61144193526238, 48.99171352386475, 48.80304751857635, 52.90913366502332, 51.58409034052203, 55.30966343418245, 53.949146193842736, 49.970423329261045, 44.06903305361348, 47.33093884683425, 44.2215387282833, 50.04381087518508, 53.38906703456756, 58.182791740663596, 56.4604829203698, 61.912600994110115, 60.2158542602293, 55.72186139322097, 55.25988071195541, 61.440065214710856, 62.13428551150907, 56.115439861051506, 45.255291154307706, 48.36296150761266, 45.268180062693936, 45.64246046927668, 47.069391281374045, 52.845422606314386, 47.32987588451755, 56.650733563207815, 54.899830664357836, 62.84304603453606, 45.61612175356957, 38.071105403284875, 61.55634780083934, 58.12660771031534, 62.21659644957512, 52.7602404932822, 48.91170501708985, 47.18337928095172, 44.730748668793716, 48.88125565744216, 48.81770149354012, 47.799971949669626, 48.72793805214667, 48.4468610055985, 50.481512085084, 49.45035234574349, 49.01126261680357, 50.84367236783428, 50.514789473625925, 47.9848450230014, 48.92221304678148, 47.047802555945616, 53.50185871124268, 59.4729495048523, 63.046915146612356, 60.069687135757945, 52.15962756064631, 60.76212667649793, 63.31745278450751, 58.31904311333933, 57.85501103247366, 56.64389687199747, 50.6511781292577, 46.975387757824315, 49.09515819241924, 48.528289410375784, 49.431160188490345, 50.636018168541696, 52.16258110538606, 52.25084620137369, 49.756842428638095, 53.634321074331964, 51.17799951184181, 56.72977324455016, 60.83295291469943, 66.56524196747812, 63.15637280864101, 62.7385344812947, 54.771200456926906, 39.395756490768925, 16.794178985780288, 11.297722439612112, 12.999518244497239, 31.11935930867349, 7.930832447544222, 0.628626500406573, 0.3203571629860709, 0.21775077848184496, 9.332561050691913, 45.57891807248516, 39.78685994302073, 32.895777225494385, 28.261540012974894, 33.190476663651005, 51.80797530758766, 62.46612587282735, 64.40631058908278, 60.55567272247807, 12.132507735683072, 0.3655665854532873, 0.14645774758631183, 0.14956159877680963, 0.22384565143335253, 0.19400248183838784, 0.18126922719661268, 0.19876898897271003, 0.1571824422646915, 0.14025151609413086, 0.2058124319920617, 0.16138210562208008, 0.1972271144510277, 0.12953679588052536, 0.12196757905786076, 0.08324705920512639, 0.1937504082677826, 0.11360378350101172, 0.13272677067547076, 0.13490327243362704, 0.11537975150971644], [0.059278355235414165, 0.03528244365307112, 0.035525163290120905, 0.036779613113932075, 0.04398388097122793, 0.046213656483638677, 0.016550423705109184, 0.05498214947780775, 0.03321404839234968, 0.008230200356563494, 0.04317157113203599, 0.031079455474091154, 0.012845077623252668, 0.027237549431682117, 0.017013039304724625, 0.02212827923827835, 0.02633130189121491, 0.06498101798276748, 0.4866522670753541, 30.073918219535585, 61.821233303316184, 57.27898743844802, 59.058707990954005, 46.33260542346586, 26.123538401819047, 34.825708866119385, 51.08164648855887, 40.4284224202556, 10.751873639322097, 0.012046906894313232, 0.11720815057595892, 0.23530104077391087, 0.21949847018526447, 2.928848026260253, 4.064306775408407, 5.216816067695618, 18.274758015909505, 62.5558187115577, 64.3634194712485, 60.311191389637614, 57.13623669839675, 53.15283052382931, 49.28952732393819, 47.95193633725567, 45.384901954281716, 44.267520673813365, 55.551740354107274, 61.27481183698101, 58.677222190364716, 59.84657879798644, 62.18111468899635, 56.252150151037405, 47.875634470293605, 42.18638166304558, 42.86466536983367, 42.87185507435953, 43.66804522852744, 43.6816950767271, 44.932636983932994, 45.31645267240463, 45.30543865696077, 42.40340248230965, 42.692496853490034, 40.08409323230867, 38.84087839434224, 39.75145662984541, 44.202970227887555, 49.07433040680424, 47.78621227510514, 50.38593961346535, 52.507345676422126, 54.278966534522276, 56.67282042964813, 50.74707223523048, 56.2536524188134, 52.11257480805921, 46.33479802839218, 39.59889604199318, 42.348399085383264, 39.33841536121984, 44.26792467794111, 45.39466081127044, 47.75193468216927, 47.2437680921247, 52.929890847975216, 50.0722009904923, 61.57844251201999, 42.24032602002544, 32.721884827460016, 62.13353633880616, 51.82397073315036, 57.32927614642728, 44.470585700004335, 45.51441469500142, 41.46970971938103, 42.960684991651966, 41.10886343063847, 41.63408840856245, 41.90289235884144, 44.069488048553474, 43.64553866847869, 44.875958734943026, 45.26894100250737, 46.11244278569376, 45.816880426099225, 47.805353441546046, 47.45966711351949, 44.16097341045257, 47.2225010010504, 54.024451778781035, 55.037180300681825, 59.053969767785844, 57.68923205714072, 51.266225384127715, 52.64199279969739, 53.464862915777395, 56.793860850795625, 57.323333755616225, 55.712796795752745, 52.76823820606355, 45.13263079427904, 43.3810140240577, 41.57118535810902, 42.93902566356044, 43.73487457152336, 42.31216422973141, 42.69448157279722, 42.99089900908932, 43.135807052735366, 44.50448282303349, 51.093703854468565, 56.643532091571444, 59.995558261871345, 60.85975447008687, 60.963003020132746, 60.26719808578492, 53.243990329004106, 28.507892316387547, 7.074562859150672, 6.2735413255230075, 10.214032357738866, 7.154527729557407, 3.0553876103893405, 0.10868028196836672, 0.062431764653733665, 0.7706204068756873, 14.845122848787616, 33.765590267796675, 27.84291328922395, 22.39339770809297, 17.729909420013428, 40.1241288646575, 44.05582251087312, 50.3342035508925, 52.15840378115254, 18.407930327999978, 0.5893836158417887, 0.031195489066322486, 0.05071145061764026, 0.019111114726852507, 0.03953129751607776, 0.10155836090205178, 0.026785360288716135, 0.014143882980269772, 0.04651194047783652, 0.04798894650453041, 0.008501030632384844, 0.05682436493976463, 0.026405786704872886, 0.042753413529886354, 0.06576196035189975, 0.041082342110213735, 0.0044277109742735426, 0.032731259782468124, 0.013599244261821433, 0.035588342561236316, 0.01147964368424108, 0.021494502359400355, 0.012084230697984177, 0.012999569786892784, 0.03564899757264122, 0.05119433498851234, 0.05304786939955047, 0.035945500412415114, 0.014044253245717096, 0.028734242002810204, 0.03956610089047782, 0.038793861280165376, 0.03325236427988256, 0.01829551837046541, 0.076562145334338, 0.029065730162866177, 0.020457056516240683, 0.11443190156452118, 0.6514148582373896, 39.65055757953275, 71.41344055052727, 65.31619848743563, 66.44763362023139, 52.67723921806582, 30.075183183916156, 34.268167480345696, 47.04864586553266, 46.86225875731438, 13.294203954358256, 0.07466172634233391, 0.06518528766689763, 0.5659739913478975, 2.937066617511934, 6.870650601002478, 4.6810580549701575, 3.168101820253557, 22.443037263808712, 61.686095883769376, 67.76949590252292, 62.03801093562957, 58.94220575209587, 56.060287414058564, 52.30579076274749, 49.21867755151565, 48.64636059730284, 47.3184068741337, 56.79207224999705, 61.77463554566907, 59.62369011294458, 59.56175196555353, 63.56951998126123, 58.095385643743704, 50.039468811404326, 43.2476612829393, 45.85014212516047, 44.32705833065895, 45.05524635314942, 45.56252648753505, 46.75959071805401, 47.36858967811831, 47.68802358258156, 45.716079435040875, 44.59045333247031, 42.16632266198435, 42.168150486484656, 41.59678274585355, 46.67668357972176, 50.81546660392515, 48.94168369231686, 53.27313353938442, 55.27144778159357, 57.276218245106364, 58.29346141507549, 54.16866948527675, 58.77821145519134, 54.75894697250859, 48.694911695295765, 41.0602338852421, 42.41292599708804, 42.40170801839521, 46.739535639362956, 47.329895496368415, 50.6208582078257, 49.17641401290894, 56.13128231417749, 54.737707338025494, 62.599823782520915, 42.92441091229839, 34.236251154253566, 63.67303133010865, 53.858578666563965, 58.596888126865515, 47.67315779962848, 47.88514621796147, 43.31962500849078, 43.78718330014137, 41.644953373939764, 45.10411908549648, 44.338641089777795, 45.22064485857564, 47.133380828365205, 46.917105259433875, 47.897670345921675, 48.30712264583957, 48.12933729540918, 49.06717208123977, 49.34823343830724, 45.98894696081839, 48.085438128440614, 53.51448874319754, 56.32275281413909, 59.63655940947994, 58.595962447504846, 50.781604782227554, 52.12118048821726, 57.171137948190015, 58.857360962898504, 59.360754028443374, 58.03132549408944, 54.57268145776565, 48.36677012904998, 44.56691911143642, 42.84324922869283, 44.24787352162023, 45.15478434101228, 45.24481842594762, 45.13738078455771, 44.297989645311915, 45.42023074242377, 46.843298019901404, 54.24415549924297, 59.208660202641646, 60.361283979108265, 62.938167433584894, 64.24874897926085, 59.60271327726303, 52.41920217390984, 28.598563786475893, 6.786461828216431, 2.721169557302229, 5.135500921357063, 10.274259371142234, 5.911685026461079, 0.6188740172693806, 0.07714680831639037, 0.539225755679992, 19.90230433402523, 31.681313360891036, 28.8638513318954, 23.656591138532086, 23.699162583197317, 46.657620860684304, 49.13074193462249, 56.46032210319274, 62.25054064104634, 25.854199048011537, 0.589566373777005, 0.04824788422293721, 0.02050963696092367, 0.036349401118293885, 0.03193786273890686, 0.07496776314632547, 0.04358083828382435, 0.10331863943006724, 0.039210655245809786, 0.061429461178880554, 0.02261904090823185, 0.0836792630293677, 0.07585470144066118, 0.023341385212035912, 0.013558176203420567, 0.013497594927978373, 0.0345744596674077, 0.007330548354319387, 0.06918029063531468, 0.033405796369357456, 0.15983129851520061, 0.09219580885743903, 0.11600596710078179, 0.09449411093467668, 0.19838845777896144, 0.16282353069513075, 0.223311182532099, 0.14938593481577214, 0.07956297302077855, 0.11206020060325823, 0.14975485211658865, 0.11041912535626082, 0.16350803025547536, 0.13203952852035725, 0.2092491943509348, 0.11027480971308486, 0.10717946209854658, 0.13838883459327683, 1.3514174641140047, 48.25675549045686, 81.20712818637972, 76.00768135439965, 74.9064523943009, 61.81799734792402, 40.04240628211729, 49.23994464258994, 66.30638907032629, 54.46884062982375, 16.392088974675826, 0.16129241204790531, 0.33644025965083035, 0.3134923410271445, 2.229366115024013, 13.144438055253799, 14.720795481435715, 10.186095276186544, 23.228789990948094, 65.67141225261074, 69.66700523130356, 65.17169052554716, 63.26477143072314, 57.657629520662375, 54.472119731287805, 51.6746735572815, 52.37505197525025, 48.28587516661614, 59.59997546288275, 65.49636863893079, 60.37727155993062, 63.07067294274608, 65.9385335060858, 61.66519357312111, 53.22613569997972, 47.15078438481977, 48.980872092708466, 48.28565159151631, 48.298289468211514, 47.286682744180005, 49.00395131880238, 49.31732123897922, 49.60001430203838, 47.70679996859643, 45.710921518264286, 44.236714378479995, 44.64285227560228, 44.11871771658621, 48.752868636961914, 53.32794866254253, 53.59026109018634, 55.742602886692175, 58.48357869732765, 58.69928944495417, 61.517406509768584, 56.301466111213934, 60.50673723220826, 58.27057046274985, 49.43495704281715, 43.65592510469499, 45.17632599799864, 44.95644969324912, 49.834646563376154, 50.13889305053219, 52.49071090452133, 52.01193071180775, 57.5857638543652, 57.34992350301435, 64.31121272425499, 46.77827688955492, 36.46160787151706, 65.19192211089596, 56.90877452973397, 61.11570089094101, 48.818905661183024, 49.96015848652009, 44.81821752363636, 47.08437865780246, 45.47763070752544, 46.45607771412019, 46.35215843877485, 48.042099860406694, 50.83642775012601, 48.557436543126265, 50.254838312825854, 51.00924737991826, 50.50513259826168, 52.292160526398696, 53.235435639658284, 48.708639990898874, 51.87134119772142, 58.02313558516964, 59.66166650095294, 62.127237012309415, 60.54823590863136, 53.027714760072776, 53.56877434638239, 59.331450000886, 63.10189108694754, 62.457124033281886, 61.199404270418235, 57.07992715220298, 50.52868643114644, 46.84152510858352, 44.88787489552652, 46.68793293737596, 47.4186901123293, 46.792291518180605, 47.553215642129224, 45.83489979467085, 48.33913703118601, 50.54254024259506, 56.59758152500276, 62.97708911280479, 62.251321192710634, 66.22441153372488, 65.84032520171135, 60.96155566553916, 55.06189907750776, 33.53203665825629, 10.823425516005486, 13.593586702500621, 19.385771328403106, 14.033270670521645, 4.215814452017508, 0.33333444727524636, 0.16399809670063759, 0.9047222594099661, 25.145477748686268, 49.80502482383482, 39.89324246683429, 30.353861701103952, 28.01730775064038, 53.03250789642335, 58.08020214880667, 64.39856390799245, 71.1221339625697, 31.045050005758966, 0.9307700455669434, 0.1609501239633368, 0.1357206116400419, 0.12473827393184747, 0.1775368468295182, 0.20600635948921406, 0.12807934424809872, 0.2122874837368727, 0.1585848581406378, 0.1615372384267469, 0.22524688753389546, 0.1748219537999361, 0.11649277001138657, 0.159786727519766, 0.09566628674585974, 0.12719316438080805, 0.10988384440180757, 0.11900781368416165, 0.15198626705715734, 0.10388385143972213], [0.11274560414735349, 0.01591155425675454, 0.04408849027728842, 0.047492578986190984, 0.04248897913062284, 0.05667512335123555, 0.10795694941114034, 0.05578800885667724, 0.042822644895603584, 0.020326892432246, 0.030723283961114865, 0.07650551611497518, 0.024251532140037706, 0.027423710712502082, 0.028241955817887382, 0.02221216395076725, 0.041743196366775426, 0.10247520726895142, 1.8981250183236216, 39.73695562731835, 65.64674446659704, 56.17537367728449, 52.181522230948175, 26.544094931694772, 15.822214676487832, 30.215870757256788, 37.69190634450605, 30.88146951890761, 3.078377357413692, 0.05483469670458187, 0.11125485067285838, 0.30257258504148454, 2.3319799765463802, 5.11673826363779, 2.286860707306093, 11.646385846599458, 45.29701732820081, 62.35366759761688, 64.04736272750363, 61.383787047478464, 61.05559841279061, 53.05661086113223, 51.125490742345015, 46.293797492980964, 45.43396688276722, 41.955271690122544, 48.600096241120376, 59.09701778042702, 59.64452966567009, 57.8336262702942, 57.70331728842951, 53.198565360038515, 44.339990385117076, 42.43772714368759, 43.383049734177135, 41.34096968558527, 45.51477555305728, 44.066208947089414, 46.08499403922789, 43.0206266526253, 42.53468813434724, 41.42797177837741, 40.88417437768752, 39.68177180136404, 39.21100893328267, 39.485606224306174, 43.4582454927506, 45.22659509412704, 48.13516985985541, 46.33564918271957, 50.39600833769768, 53.52447117528608, 54.797445035749874, 55.15409438840805, 57.07844057390767, 48.31306111428046, 42.8919925228242, 39.97242335350283, 40.83748640552644, 40.53187493355044, 48.01898925535141, 47.60627746582032, 53.64366023771225, 51.65039800828504, 57.04644972278226, 51.21284192608249, 60.85619295797041, 40.44309208470006, 34.76149966639858, 61.660545564466915, 50.14625533934563, 52.049255986367505, 43.40348920514507, 44.17156380991782, 41.381930997294766, 39.482770350671586, 39.93408610743862, 39.619229608966464, 39.37940020715037, 41.51267536224858, 42.45798226325743, 45.23554986523044, 45.72402615700999, 47.84233746990081, 47.96699431634719, 49.76616982490786, 49.263255288524014, 47.56015039259388, 52.38023734861805, 53.96119179264192, 56.44577403222361, 55.986350736310406, 55.26590155016992, 48.448814345944314, 49.435329667983524, 57.96216626321116, 55.685928560072384, 57.24647491208969, 55.98081627199727, 54.914916100040564, 46.17596164826424, 42.30735540390015, 42.6648872898471, 42.34847753278671, 42.9065013700916, 48.10588936651907, 48.82472253614857, 44.78683071751749, 47.37042926972913, 44.105569931768606, 48.44056560147194, 57.788883793738584, 58.67514725654357, 58.808409783148, 59.59441354197841, 60.0022380582748, 61.66551912984541, 50.51002379386656, 22.115089854886456, 6.524880922609761, 5.426066671648334, 13.71739729758232, 7.166285034148925, 0.5074878667871798, 0.07113232097077755, 0.07801876193092716, 5.176999597780166, 37.78864376006588, 41.97346364298175, 15.661550471859595, 19.62973883075099, 23.433102330853863, 38.35051936487998, 47.06462167924451, 50.76048281884963, 35.03646566021827, 0.13167715361041407, 0.14691695600988405, 0.008486541036906983, 0.06909595201573066, 0.020979200978012338, 0.12915286325639294, 0.033383997337472056, 0.07971125699940228, 0.023685239946409583, 0.0341675827099431, 0.03816207622989051, 0.015243605068404109, 0.04637532018785996, 0.01231345569624776, 0.01432571873714727, 0.04395798336894762, 0.037469586372495665, 0.018840019193087375, 0.04365451678994202, 0.02294117513473236, 0.04785418780820985, 0.01874642431615822, 0.09228404686455766, 0.06965622275827393, 0.05009445872518325, 0.023542941029694293, 0.044830990354380304, 0.04230571940781609, 0.02018566029296527, 0.05636162485086149, 0.018834011148541205, 0.060342845897520744, 0.07761517915153697, 0.01852903346110496, 0.04086858442714138, 0.03446300536574375, 0.07008748429436838, 0.148271843791008, 2.9451378747340176, 49.31007269890078, 73.69424389254662, 62.29942514050392, 61.18469145990188, 36.51232411784511, 23.99243231742613, 30.452730924852435, 41.94677191395914, 36.1207107574709, 3.69341921902472, 0.12675761275233763, 0.13583848192807169, 1.0099441293747196, 6.575759457003686, 6.075732275362938, 2.479455211470204, 11.88996405370774, 46.37065241413732, 65.58198221268194, 66.93985185315533, 63.9912885235202, 61.338232640297186, 55.8800466599003, 52.945780369543264, 49.099872881366366, 47.33239012379801, 44.961521317881925, 50.45069794501028, 61.36878790393953, 61.58229427952921, 61.12635012595885, 60.29863196034586, 55.515258389134566, 46.71997477931362, 43.780746690688595, 45.52938245957898, 43.40094358690324, 47.7953278633856, 45.84619229839694, 46.63686367773241, 44.824775726564475, 43.88659577215872, 43.16078470599267, 44.95637124584567, 42.082831090496434, 42.26064389751804, 42.66456565549297, 47.08068378510014, 46.78194038329586, 50.03787240674419, 49.94333544085103, 52.84721120711296, 55.92682876894551, 57.50016989246492, 57.9582085917073, 58.78193770685504, 52.68660583803731, 45.10887692051549, 42.71706265787925, 41.97319692181003, 41.96975308079874, 50.07011428956063, 48.12883915439729, 55.60297827566824, 53.38810605387534, 59.23179434191797, 52.44188131824617, 64.07028505879065, 41.93233366935484, 35.90640421836607, 64.10202880059519, 52.54878551729264, 55.864800407040505, 45.44079180686705, 47.14445760173183, 43.21590185165406, 41.65850908525529, 41.50681141884097, 42.596779254175004, 42.30891258485856, 44.466200490151685, 45.64785765063378, 48.158570720303445, 48.51255286124445, 51.00693318151659, 50.227828871819284, 50.61076594937233, 49.63934390775619, 50.28624473079559, 53.927718285591375, 57.27469244310933, 58.778933171303045, 56.468759121433386, 54.22961135064402, 50.23476362228394, 52.1435183863486, 60.36502592025265, 56.99799668404364, 59.33432117585213, 57.80336518441477, 56.67921781539918, 48.655542865876235, 43.98317237054148, 46.026056505018666, 44.43015783063827, 46.2277251674283, 50.553652317293235, 49.57646439152379, 46.40446716739286, 49.41438028889318, 45.40614158876481, 50.37224661919379, 59.85907546935543, 61.34677948490266, 62.07985085825767, 62.11714083148588, 63.17386657960954, 63.96093722312682, 52.64124362699447, 22.905978925766487, 4.098484347904883, 2.1975326490017677, 7.212695008324039, 10.669906889238666, 3.152617038257661, 0.16528791297347317, 0.03736118110077035, 6.135464579828325, 39.30776596069336, 42.46678406192411, 20.18529549721749, 22.233820000002464, 32.008154661424705, 44.14920629993562, 53.50351002908523, 54.907765619216434, 47.57596931149883, 1.2002210030632636, 0.2135173306469956, 0.026127189255109238, 0.02532997134802563, 0.01489325007799292, 0.08920300211156569, 0.05266404402772746, 0.013895657086264224, 0.07602994405334035, 0.038163845892995596, 0.05016648248138447, 0.09039374789403332, 0.05033199960786489, 0.052686536369184335, 0.11475420241514522, 0.06421066677918838, 0.048762637851459366, 0.04511744212058764, 0.11014204667580706, 0.036727775774535634, 0.19385479540834505, 0.1343348658373279, 0.2023443366370855, 0.11088036391283236, 0.1264435473468996, 0.13847373245704558, 0.1625300577330974, 0.2169275097548962, 0.14549793134773933, 0.1510634222218106, 0.14811451997487776, 0.13847742500084062, 0.16740424618605645, 0.14722601120029727, 0.1699154364365724, 0.15510174746234573, 0.1754582357863265, 0.2145065646618605, 5.054680974252763, 62.68411943989416, 82.00788790179838, 74.2342758178711, 69.08138751983643, 40.37932611280873, 25.670940030005674, 41.64767157646918, 51.30053827839514, 44.435927637161754, 5.009260417953615, 0.2625854307365033, 0.31089193217696687, 0.9842630235418197, 8.683237183478571, 16.07048501891475, 10.133936578227628, 15.702137197217635, 49.4655397630507, 65.84517325124433, 67.83569766629127, 67.00827367844121, 64.56780633618756, 58.433799897470784, 55.99113210555046, 51.318640016740375, 49.057142580709154, 46.90969982454854, 52.849725446393414, 65.33445319821759, 63.727218874039195, 61.76846957975819, 61.924101383455344, 57.213621139526374, 49.026100943165446, 45.43930915094192, 48.17911609526604, 46.37694389589372, 50.61053060716199, 47.72939674315914, 50.26712709857572, 46.391048739033366, 46.89475559419202, 46.460082454066125, 46.11513745400214, 44.713117614869155, 44.28907017554007, 43.586063769555864, 48.42993597830496, 49.17119726057976, 52.69890246852752, 52.661208491171564, 56.7503539208443, 57.61832737153577, 60.104098089279674, 59.96581492885467, 62.524090659233835, 54.814503423629276, 46.523675841669885, 44.50725986111549, 44.16587245079779, 44.71718119036767, 54.37459391932334, 51.93062390050581, 58.66702795028687, 56.38369075713619, 62.28131947978851, 56.596875498371745, 64.5770513626837, 45.564342544924834, 39.725843552620184, 64.38048962623843, 54.505863881880245, 56.88763687687536, 47.77271932171237, 48.23830466116629, 46.234769744257775, 42.63253558066584, 45.83293468721452, 45.153348753529215, 43.995523914214104, 45.79727249760782, 47.44793530433409, 50.854733451720215, 51.095108062990256, 53.84019059519614, 52.03146019289571, 54.67522790355068, 52.762719431231105, 53.102184880164366, 54.79361680246169, 60.34430011626213, 61.21543499731249, 57.37364992018669, 56.82076438780754, 49.820118104257894, 53.75067034075337, 62.5123510053081, 58.08985510180074, 62.19958905250796, 59.74145143262802, 59.79280310292398, 50.6100050095589, 46.65981346561063, 48.45377222184212, 46.682684806085405, 47.340403526060044, 54.53084545750772, 54.52262809199672, 48.43241491625386, 52.01364478757305, 48.67088717799033, 52.70234238716864, 63.43462967103528, 64.0019299137977, 64.34150518909578, 65.1016213047889, 65.3093147277832, 67.49256087887672, 55.46396947676136, 25.807660125917007, 11.26775651208816, 11.518332227583855, 27.649057988197576, 10.032533503347828, 2.152712215338984, 0.2429986769153226, 0.25283104770125886, 8.357215658310922, 57.25984234963694, 57.16902771303731, 23.250943537681337, 27.26518346417335, 35.105573900284305, 51.472353781423266, 62.30379466087588, 62.41768460119925, 56.26049695476409, 2.3798993277934293, 0.4891786411885293, 0.12712531963423376, 0.13719997338710294, 0.11653937113982056, 0.23156029472668327, 0.15584198758006096, 0.1863501214933011, 0.19732736471679904, 0.2505865939442189, 0.19061727719681879, 0.12175125114980245, 0.2307140280402476, 0.17299526310976476, 0.17697665269576734, 0.10128799315181472, 0.17196816902968193, 0.12537686184288996, 0.1868998355442478, 0.0911164369374033], [0.05458137441066004, 0.03438898595049977, 0.01590077731487972, 0.025850032050643238, 0.08005677797501126, 0.004071591651037095, 0.04528832569297764, 0.050568644167675134, 0.05017718856012629, 0.03591045955075853, 0.022115541111317374, 0.0357946232261677, 0.06197055291023947, 0.027703254280852217, 0.06694098498912589, 0.05182639583043995, 0.0294122968484918, 0.019812010483996525, 15.58401894184851, 57.960514945368615, 59.91855429064844, 57.49056793028309, 38.59022717322073, 20.728333919279038, 22.646380778281923, 39.5471207557186, 42.32497076834402, 24.05602962740006, 0.39432886627412617, 0.06733025724609053, 0.05953925796934675, 1.5712766084940204, 6.131140657009618, 2.6761998284247617, 3.851570655261317, 29.75900092432576, 59.93342399597169, 65.31532379888719, 65.15234931822746, 60.403594586157034, 58.07872341525171, 58.8908697712806, 55.79880260652112, 49.78078457616991, 45.2279051657646, 44.71997784030053, 43.40995719355922, 53.20868115271292, 59.27785473485147, 58.47727152609057, 57.032717504808986, 49.423350749477265, 42.858652376359515, 42.565827831145256, 40.61284834338773, 43.606883710430516, 44.69626319023871, 47.305278701166955, 46.63091736455118, 44.85691170538626, 41.184914265909505, 40.71604590262137, 40.2688721687563, 40.5546207581797, 40.49072927044284, 39.55143536290815, 41.25789388533562, 44.34998850668631, 44.63556058945195, 44.733533551616055, 49.060135349150634, 52.4302867920168, 56.77403326957457, 55.389087507801676, 52.584439862158995, 42.461692825440444, 41.331673668276885, 39.86610358761203, 40.86127558062154, 43.84605415405766, 51.301667921004764, 52.89693117141724, 56.77830473069222, 54.79537794666906, 58.943735476463075, 51.936938916483236, 65.08877946484473, 36.19284314493979, 33.775792352614864, 61.73045789041827, 50.27423835569813, 54.600675413685465, 46.213769374355195, 48.3311197065538, 45.3626032798521, 42.86043313241775, 39.169710297738355, 39.87555257735714, 39.6465685290675, 42.10259591379474, 42.96737655516594, 43.525290566106, 42.84013486677601, 50.21719924865231, 49.437239862257435, 49.93028179291756, 48.01755759023851, 50.081634290756725, 54.17496881177349, 57.30628321247717, 56.72059097597676, 54.25739742094471, 54.79546031644268, 51.85733049146591, 56.97444677352906, 56.92875116102157, 53.59716053931944, 57.55221189991121, 56.89368517168107, 55.12151910412697, 46.154474904460294, 44.51885830971503, 42.33858139284196, 42.43187496739049, 49.10233220746441, 55.73385992357808, 56.1118979607859, 53.04039970521004, 47.65658578565044, 45.5697161920609, 43.50922453788019, 49.87713759945285, 53.31512643444923, 58.094663927632, 58.54689359664918, 58.9063278321297, 61.85296920038039, 62.9396971579521, 48.36194561373804, 12.575695360860518, 1.1774841263409586, 8.404976398714128, 11.26260938182954, 5.320814771036948, 0.08699073170822474, 0.02372310192684733, 0.8746471796785632, 16.423308099469832, 30.34386161834963, 23.655553671621508, 15.840802788734438, 23.455132322926676, 36.19395317569856, 47.925126937127885, 49.62030864530995, 53.50616155132171, 11.977184818636987, 0.19913920862299783, 0.04761253686381444, 0.013287319114521868, 0.049258381008140506, 0.10893310630513776, 0.014008772841113952, 0.01107369082033514, 0.029950103977875366, 0.034097160077503616, 0.03266773960222641, 0.09312436870870092, 0.014167904624745492, 0.050123006991681554, 0.010380159083363271, 0.04786998454120852, 0.09946945363715773, 0.04749668904790475, 0.057019031711763916, 0.010051589718298807, 0.12748089934428855, 0.015651363026981634, 0.025844640706876115, 0.0151673793199382, 0.08790013936137961, 0.040790531558976065, 0.04587657396651564, 0.05132768408305222, 0.035559005224175995, 0.018468073929750153, 0.04034407466890351, 0.008505947959248819, 0.03530811142897414, 0.05302908875408673, 0.05597297695555514, 0.05800516307053547, 0.07277114391927758, 0.0870960304934171, 20.356699151377526, 67.06903119241038, 66.31567724289434, 65.38052143589144, 46.161335129891675, 27.282739993064638, 22.60588034506767, 37.70735263824463, 44.68886560009372, 29.132947498752227, 0.37132223467192343, 0.05137916136112425, 0.16223880642604444, 1.4727356380993322, 5.1577951831202355, 4.5349017170167745, 4.4363242195498565, 31.212368511384536, 61.38798398356284, 66.52604179997599, 67.93983659436627, 62.63336789223456, 62.04238830074188, 60.38493587124733, 58.30501671760314, 50.70512640860773, 47.31286848745039, 46.413998526911584, 46.903981008837306, 56.330075879250806, 61.957261100892104, 61.85229455271075, 59.692104093490116, 51.88298671476303, 45.00973116966986, 44.96358056222239, 43.0179202172064, 44.84207730139456, 47.418556751743445, 48.03647125920942, 49.39376431126749, 46.96234979937154, 43.46198351152482, 43.0482126820472, 43.380072655216345, 43.04294886127595, 40.58933373420469, 41.61004820177632, 42.77842421685496, 45.15924407589821, 47.497784706854056, 48.206913932677246, 50.81481156810638, 55.00116117538945, 59.15120532435756, 57.28407083019134, 55.27538976361675, 43.86880782342727, 42.46944342890094, 42.84525748222105, 43.5320488099129, 46.043597344429266, 52.30388841321392, 53.95753614364132, 57.4182786480073, 56.00234616187311, 61.251587483190725, 54.092324472242794, 66.05801674627489, 37.34882447027391, 34.805669476909024, 63.79287542835359, 52.99084055808283, 56.839478015899665, 47.7277022792447, 50.41870709388487, 46.36936195435063, 45.50939798355103, 42.558944071492846, 41.26365584711875, 41.481665103666245, 43.47428798675538, 43.6083036084329, 45.16883819333969, 46.393080526782626, 53.48188600232525, 51.65332409643358, 53.1415537095839, 50.92001738086824, 53.023419764734086, 56.3657106122663, 59.12409782409669, 55.68484990827499, 54.1347292161757, 54.1244565286944, 54.63410969703428, 58.49456917855048, 56.70488580580681, 55.78098720119846, 59.36105997331681, 58.64874578291371, 56.66515219596125, 49.17224453341577, 45.54999843720467, 44.493727684021, 44.98648720402872, 51.4339380879556, 58.10039058808358, 58.38891621558898, 57.11515395872055, 49.0678898749813, 47.71402889682401, 45.028444797761985, 51.05290728230631, 56.09969938955, 59.66755397858159, 60.169119219626154, 60.161129351585146, 63.42179567583146, 65.31147595374816, 50.00060204536685, 14.044228792190554, 1.0124271735548973, 4.3051905593564435, 16.364675529541508, 4.844146774661157, 0.25870378579824205, 0.06366565267765714, 0.8344113225898435, 19.882908213523127, 33.667554547709805, 27.04850781348444, 20.22985754474517, 31.450113173454042, 43.76430411492625, 55.13583183288575, 56.768934188350556, 61.608813424264234, 18.215032085295647, 0.28598000926356165, 0.04894079925913004, 0.06202066272136666, 0.041940590411785154, 0.029589466172300523, 0.019881634469774943, 0.10461936479494457, 0.034398749741094733, 0.037735870874096314, 0.005663156071903125, 0.0200394083625607, 0.019191100051806822, 0.04932306181158751, 0.0804411089648643, 0.09356613331023725, 0.015063173167647855, 0.008332979670094868, 0.0327102076863089, 0.03126425503362571, 0.19612272209938497, 0.09234292072153862, 0.06297698942944407, 0.12204066384583713, 0.11384170742765551, 0.0769732664189031, 0.21932729549946325, 0.1399497387389983, 0.18799218499372083, 0.1323314080195081, 0.1007911085241264, 0.1130042737349868, 0.18614700094105738, 0.1370844932933969, 0.20653543513148062, 0.12777722981427947, 0.16756691729589818, 0.17397744911572627, 26.37204016408613, 76.80515412361392, 75.15982966269218, 72.85443305969238, 51.90884690130911, 32.48746633529663, 31.915529850990545, 54.758739086889456, 58.250805639451556, 33.98503511182724, 0.8489312628103841, 0.16326628355008943, 0.26258947568074353, 2.274394924602201, 17.870359689958637, 11.496790570597495, 8.04922870089931, 33.30870082301478, 60.3626097402265, 67.17810446216215, 70.64151810061547, 64.99297165101575, 64.51445033473354, 63.446106526159475, 60.81865979779152, 52.905203450110655, 50.63034249890236, 50.24974707634219, 48.78806798688827, 58.20558071136475, 62.726473193014826, 63.9846283389676, 62.65317193923458, 53.71378829402309, 47.78858923142957, 47.119079866716945, 45.41903441952121, 48.67434670848232, 49.74451049681633, 51.24223616815383, 51.02208137512208, 49.00259025635258, 44.150018230561294, 45.17088959293981, 44.557799600785785, 44.44511382810531, 44.30383005449849, 44.687751646964784, 45.99501486747496, 49.47458082629789, 49.27445757773615, 51.53819076476559, 53.252011576006495, 57.218449577208496, 62.469514800656235, 59.066784151138805, 58.4534352825534, 47.57732252920828, 45.234271172554266, 44.922352529341175, 46.39483774861982, 49.27985868146343, 55.05783550200924, 56.33823440920923, 60.0852785571929, 58.39347793209938, 61.89744103339411, 56.358065912800456, 67.5485723249374, 40.53731133860927, 38.940600733603205, 65.42729962256648, 55.19700511809319, 59.22098428972306, 52.4869611186366, 51.80336652263519, 50.14275658515192, 47.396238465462964, 44.822355624168154, 43.84155127309984, 43.43337374348795, 47.0770908940223, 46.921168834932395, 47.91841183939288, 47.90613089838336, 55.351879904347086, 54.1700933056493, 54.589441745511955, 52.69807092605099, 55.4667543595837, 58.99933507365566, 61.8043278878735, 57.9651080408404, 56.79229974746705, 56.60665004484115, 56.899274549176624, 60.85067418313796, 60.048690688225534, 58.39251302903699, 63.408165439482666, 60.63353569276872, 58.87965179258778, 51.31750645176057, 47.46097718515704, 46.54544891849641, 46.9252049538397, 54.75464805479973, 61.17519932408487, 61.23164615323467, 59.96508536800262, 51.91436959851173, 51.09422552970148, 46.99714906754033, 54.98889984623079, 56.87532847927463, 62.49759112634967, 64.44528718148509, 63.33150271446475, 67.16374858733147, 68.42712048561343, 52.44894942929668, 16.485239382713072, 6.266329557664934, 17.005918333607337, 22.37445854371594, 10.504880028386271, 0.25812496040617267, 0.2523595205838642, 1.406713813062637, 25.56609311411458, 44.13147326438658, 35.176529576701505, 24.327071289862356, 34.17949445786015, 48.27092701388944, 63.44260777196577, 63.49059797102406, 71.6190198159987, 23.184686860730572, 0.535951741039753, 0.10228194626829318, 0.21385319891475865, 0.139769064562936, 0.21232566555901883, 0.08548249610729756, 0.21407496604707935, 0.19272682287039297, 0.16757634017736683, 0.1287699418683206, 0.14646307955826485, 0.06623520350624477, 0.16275717215912958, 0.1977668387154418, 0.21038608415232551, 0.17115320469583237, 0.1100898837490428, 0.12769079977466216, 0.1744084195384095], [0.07921524571194764, 0.040806351274612455, 0.04266414513450958, 0.042000854718348676, 0.03644474459091022, 0.05545314799453463, 0.021526815948046504, 0.03408271165925168, 0.03174089578791492, 0.012857829156752317, 0.05243435937670931, 0.024171652152172984, 0.05650116010538994, 0.06518369420401512, 0.029532683735352852, 0.05712839076295496, 0.018678757685026335, 0.12864226565486, 27.41966012985476, 61.307053719797445, 57.122363275097264, 51.54677683307279, 31.96197267501585, 20.319605296657933, 32.182968816449566, 38.35073509523946, 41.86015813581405, 13.562408762593424, 0.027400446537461494, 0.16183857145088335, 0.12574591703953283, 1.4282645405300203, 5.153547746519889, 2.945876996363363, 12.611481105127643, 50.70146291486679, 59.97398130355343, 64.25173782533216, 61.4401162055231, 66.23042060482886, 62.11621122975504, 59.48566190658077, 58.04488512777514, 55.29894751887168, 45.95747778492589, 45.22836408307476, 43.672810908286806, 43.885450440068404, 48.91841619245468, 50.365582512271025, 47.542142791132775, 43.170202316776404, 43.1724419901448, 44.67467838718046, 43.22036158653998, 44.44237209135487, 47.853688809179495, 48.0959108568007, 48.745894662795536, 46.82096404414023, 42.35245481614144, 41.884931825822406, 41.78293058949132, 40.50526165193127, 40.473306102137414, 38.97947534438103, 41.256564201847205, 42.13889352736935, 43.6900967936362, 42.571103419027025, 44.844885718437936, 47.08518666605796, 51.1873661318133, 49.25513205989715, 44.88786705078618, 39.118668494686005, 41.938491790525376, 41.52064561843872, 41.444720299013206, 47.92868452687418, 55.425279217381636, 53.77603238628757, 57.62851376687327, 54.42727527310772, 59.16733018813595, 48.62521117733371, 60.082685870508996, 36.42778919589135, 31.786609388166863, 62.97174292225992, 50.25997661775159, 56.48622935818088, 49.1763355655055, 52.29188988285681, 46.973367737185576, 46.085425499946844, 40.82515447370468, 40.776615142822266, 40.633707507964104, 42.330889624934045, 38.89364996264058, 41.46024504015523, 42.05058136293965, 47.93921609078684, 49.77421460613128, 52.49404099679763, 49.911803507035785, 54.275240282858576, 56.43880398042741, 53.732231278573316, 53.231136721949426, 56.47794531237695, 53.86835321303337, 56.57105061315722, 51.11332355007049, 53.7939223166435, 54.986922971663944, 57.009740260339555, 53.63933386341218, 50.284322769411155, 42.26199711522749, 44.534179087608095, 43.28684968333091, 45.374044833644746, 55.86311378786641, 59.061508563257036, 58.82928855957524, 57.67536647858159, 51.580305253305745, 47.35951723590974, 43.39052969409574, 44.13727837224161, 45.47415548755277, 50.49693484460154, 53.36239099502564, 57.11518533768193, 59.00042157019339, 62.329156706410075, 64.41439459400793, 42.84465343721452, 6.147824458537563, 2.563156874910478, 15.221037903139669, 11.143588000728238, 3.082489227094958, 0.050955127864595384, 0.09668762750563123, 9.596393396777492, 31.364574124736173, 39.66660007353752, 22.372740545580466, 16.193158126646473, 28.94558764273121, 47.74311327165174, 47.73925758177235, 52.59454388772288, 29.718859387982278, 0.4222345995085855, 0.04556832316842291, 0.04230194642478901, 0.024292828109596046, 0.02287821419867537, 0.04338902135890338, 0.03323899604560387, 0.0816050952961368, 0.036159962896377816, 0.024365943541089376, 0.006964504362023886, 0.022306902213923396, 0.042839537134333965, 0.013077117037028076, 0.04199113689302918, 0.023475314618178436, 0.0042485364153230145, 0.05179903883066389, 0.0723733604254742, 0.06860315829755799, 0.07000201952553566, 0.039876998522348946, 0.04380373539583337, 0.062313974804935925, 0.056084427426779465, 0.03358401906406207, 0.0749583555866153, 0.023184072887224537, 0.07142612335061835, 0.021657933811506918, 0.07798677776008844, 0.05115698820220367, 0.09901108024942298, 0.07073169529077507, 0.029280410981887293, 0.0636721950685305, 0.20141931611203379, 34.75682420115317, 70.1520533715525, 64.2381428903149, 57.457317998332364, 35.81879023582705, 24.388789784523752, 33.919147137672674, 39.25994442355248, 43.79018783569337, 15.282893680757093, 0.05420812871307135, 0.09012102825386871, 0.17462503855987904, 4.834791921800183, 7.895122208902913, 3.729279733473255, 15.238822910093493, 52.56069775550596, 60.83571818567092, 63.694094457933986, 62.78436737675821, 68.03121997464088, 63.24417898731848, 63.59372100522442, 60.911871002566436, 57.07489082890173, 48.782780631895996, 46.26022592667611, 44.72448464362852, 47.136534413983746, 51.72762555460776, 53.22442946895477, 50.886987101647165, 44.15653328741751, 46.64674805056664, 47.22530941809378, 44.413770168058335, 45.96818193312615, 49.501115660513605, 50.66047414656609, 51.62409851627966, 49.36794334842313, 44.69043847053282, 44.85137331870295, 42.77834184708134, 41.805350857396284, 42.50025364660448, 39.94328014312252, 41.395447484908566, 42.44936089361868, 46.67969988238427, 45.330526136582904, 47.81299421864171, 50.267350673675544, 53.02019949882261, 52.35116081853067, 46.51951028454689, 40.770731587563795, 43.18262054074196, 43.71967538710564, 44.56085512715001, 48.36203190588182, 57.05011713889338, 56.22827468379852, 57.60595229364211, 55.71836263902726, 59.62527475049419, 50.2222865627658, 58.0347026548078, 37.77723750760479, 33.455809316327496, 64.57672188358923, 51.46086908155873, 58.58655268146146, 50.588235855102546, 54.73179240380564, 49.1407439785619, 49.926779116353686, 42.85327872922344, 42.37542029350035, 41.80326807883478, 44.06202377811555, 41.72750357658633, 43.85008242822463, 43.529310995532626, 51.25197541329169, 51.21444617548297, 53.5486957334703, 52.778942354263805, 57.111466930758574, 58.07430290406751, 54.75151408103205, 54.69135668969924, 59.50294386956, 56.04126784109301, 58.635472482250584, 53.63120279004497, 55.89837197334536, 57.127799680156095, 57.67533902199038, 57.61282036381384, 52.52422755764377, 43.60820947154876, 45.622389701104936, 46.10899502231229, 46.32538041760845, 56.423624407860544, 60.811681901254964, 61.373122122979936, 59.77988673794655, 53.72230768203736, 48.97409423705071, 44.4067765820411, 46.80072853642125, 47.78595732104394, 51.972412832321666, 55.722849830504394, 60.76583331631076, 61.21962801102669, 63.57522310749177, 67.03024679614653, 46.14930522057318, 6.847935174742053, 1.1142328429606654, 8.091404476473409, 12.972172460248395, 4.683702713058842, 0.12391292144574466, 0.09315731815032421, 10.267779615617568, 35.82212817284369, 30.198614289683682, 20.82485168210922, 23.79573133683974, 36.84350552097444, 50.939813583127915, 53.60849226674726, 58.63495080701767, 37.18009587257139, 0.6857940037885021, 0.035529936017889174, 0.027246824841225342, 0.07070165698326404, 0.038975902923172524, 0.030929332884449153, 0.028971053186743975, 0.05387161310101229, 0.014701583497827093, 0.06885603626048373, 0.013417635458491504, 0.04410658527405993, 0.038060182705521584, 0.024764209670285066, 0.08300201066078679, 0.015870967876136063, 0.028312432076481563, 0.028795370073508353, 0.05938402557324979, 0.14382229787447762, 0.13186714341563563, 0.06818682015422853, 0.19798361095449618, 0.1519516092394629, 0.12293905515464083, 0.15660208469677359, 0.13013812893581006, 0.1751292469881235, 0.12903339950548065, 0.2298221178352833, 0.11137548653829484, 0.14358851848350418, 0.2390302648587573, 0.3113835154762191, 0.15765148725721145, 0.22020101877710513, 0.4516479324909949, 41.26710753287039, 78.95857457191714, 72.96207074196109, 67.72330607137373, 45.10963001558858, 30.491607496815345, 45.121220619447776, 53.591657453967684, 55.58776340176983, 18.78710977492794, 0.24510650655194638, 0.487664943380702, 0.29405549529098696, 7.811593374898357, 13.634027319569743, 6.995613882618566, 15.867328797617267, 54.21851104305637, 62.17978108313776, 66.21600197207543, 63.75461662969282, 69.77356818414503, 67.27549691354075, 65.7168254544658, 63.52494616662303, 59.81741205338509, 50.46219441198534, 49.30577770356209, 48.32078818351992, 49.315081565610825, 54.86469014998406, 55.0549800165238, 53.34215548730666, 47.96538614457654, 48.90760614025978, 49.167016013976074, 48.39418749655447, 49.00871307619157, 53.60607216435095, 52.71418794508904, 53.207284788931574, 51.78489215912358, 45.8624348332805, 47.30208981421686, 45.63967166408416, 46.47423044327767, 44.25711854811638, 44.06570688370736, 45.12108725886191, 46.65795033977878, 47.6399157124181, 48.164595480888124, 50.71662287558279, 54.00699330914406, 56.92417767740066, 54.97833298098657, 48.616680022208925, 43.284672767885276, 44.87439370924427, 46.58970109878048, 46.0161917440353, 51.77158355712891, 59.52246158353744, 58.68364703270697, 60.42514801025391, 57.93574125536027, 61.56762069271457, 49.371116545892534, 59.96379490821593, 40.685106246702134, 35.2720824364693, 65.11962106150966, 55.373739273317405, 61.55828937407463, 53.68085215168615, 57.119699985750266, 51.355525985840835, 51.875663649651315, 46.05632151326826, 45.8141073103874, 44.7027821694651, 47.84890351756927, 44.31823692014141, 44.98563604970133, 45.426102530571725, 53.76712860599641, 53.44502356744582, 58.03568716972106, 54.92517309804117, 58.90538254091817, 60.2554976555609, 55.578726260892815, 55.91962729730914, 61.96115601447321, 56.92527201867873, 59.792873705587084, 55.90214529345113, 58.91847149018319, 58.60069674830283, 62.720875970778934, 60.39975066338817, 54.25421637873496, 45.91016615590742, 48.63173407893027, 49.08320280813402, 48.15189092389999, 61.91552315988849, 63.6942905764426, 63.27474994044151, 62.825599332009595, 55.15818542049777, 53.35371471220448, 47.62528134930519, 48.67320529876217, 49.990250910482104, 55.01294789775726, 57.908292508894405, 63.158769376816295, 65.25346802126977, 67.63117744076636, 70.07004445598972, 47.60688151082685, 9.346919867300219, 7.963727895290622, 26.20301150506543, 20.91281279440849, 5.465973356077749, 0.18555024909155984, 0.29366390178761176, 14.053931755404319, 47.978965390113096, 51.853753289868756, 31.88876359693466, 24.194842307798325, 40.358459103492, 59.12114035698676, 62.94002663704657, 66.75284893281999, 45.49118641884097, 1.251507586529178, 0.13925144959601665, 0.1293019746099749, 0.08838056075957515, 0.13539231232097074, 0.13659338496865767, 0.13603498348064963, 0.13454457474572046, 0.11569315807953959, 0.20029702794647988, 0.09326645503601722, 0.1487677018608778, 0.1749807791483979, 0.1689263096740169, 0.15954144148816987, 0.1292794056597256, 0.1461795810610056, 0.10182312854956235, 0.19544784460336934], [0.061703444864120216, 0.031605610406146414, 0.05683992418550676, 0.01390001804177319, 0.02867313308431016, 0.04701269001910283, 0.03331344447008545, 0.03869619273069886, 0.007238379837344251, 0.02590641229143066, 0.03919328803256635, 0.04696841013707942, 0.0490439338459363, 0.012882534534700457, 0.011173502500769834, 0.0447242321716922, 0.05125346165450831, 2.054567036609496, 42.42191214715281, 61.023152566725216, 55.883035505971606, 43.05546514449581, 22.386155051569787, 14.350038343860259, 31.083746148693947, 39.25412362621677, 42.42233184076125, 5.358263109960864, 0.13544308862859203, 0.10100562080380418, 0.46714861847219935, 1.2586704473341666, 2.3116329264256263, 2.992352915387, 34.56228248534664, 60.46970613541142, 67.80092977708387, 64.32628247045702, 63.952908131384085, 57.71368803516511, 65.07038747110676, 63.70709319268504, 58.78400087356568, 57.413010904865885, 55.39276669102331, 44.77260035853232, 45.16819100226126, 43.453436666919345, 45.23183930304743, 41.959990301439845, 43.25020297881096, 42.716078142966, 42.808022422175256, 43.42906305866857, 46.39692837192167, 47.14454781624579, 49.18262704726189, 50.047850916462565, 51.852898213171194, 47.60253160230575, 45.992379034719164, 41.35838893152053, 40.70007008890952, 40.197983172632036, 40.47490642916772, 40.90874802681708, 40.94914059485159, 38.36656578125493, 41.558398431347264, 41.75267342598208, 42.366720476458156, 41.53872382256293, 42.55262513314524, 39.20044206803845, 40.993063296041186, 39.68585891108359, 40.59093798360517, 41.68703256114837, 43.08818555647328, 46.881552896192, 55.067880692020545, 55.174922174023045, 58.77372426371421, 53.035830143959295, 55.71064341452814, 50.169118835080056, 58.70847171352756, 31.44903648284174, 26.219536450601396, 63.79094562222881, 51.63865835435929, 56.71191077078543, 51.48345801138109, 54.44285492743216, 52.22784542268323, 53.2959891903785, 44.845477996333955, 41.832003362717174, 40.37288165861561, 43.332439391843735, 40.80428746438796, 42.25062224172777, 41.891019344329834, 45.69676176194222, 49.30464021621212, 52.51204467588856, 53.19479203993275, 55.41046050287063, 54.467106942207586, 55.22329676535822, 55.88103509718373, 54.143244681819795, 54.963996718006754, 53.24777541622039, 53.78500676924183, 54.94096848272509, 52.34560674236667, 52.09976826944659, 44.73661261220133, 41.38613577811949, 40.51522839453913, 43.28181728239983, 41.01684462639594, 43.81234530479678, 55.347749648555634, 55.78743165539157, 57.575777499906486, 58.43298796684512, 56.70381499874977, 52.87067874785393, 46.04958288131222, 42.96674113119803, 42.57562198946553, 44.84527795545517, 46.39779521572975, 49.9449553797322, 55.015340543562374, 59.09442901611329, 59.102744440878595, 61.859864727143325, 31.054187167075376, 3.769757122762742, 14.134736503324202, 3.1430346879266926, 2.2414712848201876, 0.461412305312772, 0.0863778307252834, 2.56824835654228, 27.05955516907477, 45.44396108196628, 35.9383362339389, 18.785276066872385, 31.61417022828133, 45.924133716091035, 49.013161043966974, 49.38151474921934, 39.83678779294414, 5.931105171480487, 0.19405675150694388, 0.056205894497613755, 0.005544932425818256, 0.05276277743940873, 0.08136642826420647, 0.04001622734170768, 0.11491354870339555, 0.0376528422648628, 0.020723333356962092, 0.08755303258376737, 0.027900650241081754, 0.029613167017457948, 0.03402363095853118, 0.060840285938954165, 0.040482759565836, 0.05090608674612257, 0.11174101773048602, 0.019957900437856876, 0.013777697740513233, 0.048893133268481305, 0.039826551632535075, 0.03937565526294132, 0.007371191233922277, 0.013894152681102917, 0.007865275331442396, 0.05553790796247702, 0.025784899255320914, 0.02429788620511611, 0.06654975920795433, 0.12052123570033621, 0.09808923132837781, 0.04450876228210907, 0.06410874261130249, 0.021544321057116313, 0.037087990316532315, 2.913886880682361, 55.02126724489274, 68.5635248307259, 62.56889197134203, 49.966308762950284, 30.534906541147542, 18.15259187452255, 32.17776579241599, 39.570737346526116, 48.68598830315375, 6.681798283130893, 0.18996031083647283, 0.0930101833035869, 1.3781448621903698, 5.282943796726966, 4.961258942081082, 5.4067568432900215, 37.16840720945789, 63.02431444967947, 69.6375560760498, 66.12399101257324, 65.00236572757845, 61.044423580169685, 65.15656978853288, 64.13323125531598, 62.22551591934697, 60.41393003156109, 58.303902764474195, 46.02769997812087, 47.77946187603859, 43.96001077467396, 47.52624542482438, 43.4438935402901, 44.360014084846746, 43.38648573044808, 44.15560760805684, 45.84037934580157, 48.200018405914314, 48.799027089149725, 51.08643962490944, 52.2574475503737, 53.88357200930196, 50.26128668938914, 47.300234533125355, 43.92373277295021, 43.885874056047015, 43.04109750255462, 42.86324547183129, 42.37304333717593, 43.63486197686965, 41.2015058917384, 45.36301905109037, 44.55657582129202, 45.00264344676849, 42.779016494750984, 44.655407782523866, 40.917993053313225, 43.306461534192486, 43.181486975762155, 41.59572370590703, 43.008302565543886, 44.33878621747417, 47.60566949844361, 57.638786454354566, 56.870911890460604, 59.04770574262066, 55.3019206754623, 58.24318447420674, 51.66269856114542, 57.75483762064288, 32.463300612664995, 27.88950320213072, 64.77972022948727, 53.488197095932506, 58.43156022410239, 53.422983769447576, 57.76764023688532, 54.81566444520028, 55.38274895760321, 46.09987551166166, 42.83591047410042, 42.48461515672746, 44.676317937912486, 41.87878939413255, 43.42450918689851, 43.84864291837139, 48.131149430428785, 52.12881734294277, 54.97617959976197, 55.4357401786312, 56.82178028168217, 55.88309826389436, 55.26822359331193, 58.4364474973371, 56.520110791729344, 57.03590246938891, 54.47415936377741, 57.00655921812981, 56.96958303451539, 55.75195381718298, 54.066330925110854, 47.29735551341888, 42.789657885028475, 43.481446312319854, 45.46616169714159, 44.29876235223586, 47.20921201090659, 58.0759895232416, 58.28411440695486, 60.758871109254905, 59.96529717599193, 56.77527273854902, 54.123346497935636, 48.28633800629647, 44.704241291169204, 44.013276561614006, 45.11195205873059, 48.99212537273284, 49.89191709026214, 57.551839274744836, 61.64152206913118, 62.287116742903194, 63.311428023922836, 35.70624566847278, 2.8925580122778496, 5.640554620373634, 10.521227486671942, 7.890463413730745, 1.1266533958335077, 0.1606437041153831, 2.600700576459208, 31.20200560938928, 41.98556415496334, 31.589931941801506, 19.408252393045736, 36.557729474959835, 51.08709073835804, 56.3134999429026, 56.25023603439332, 49.49254528168709, 9.357685792830683, 0.1335831956877824, 0.07105466263789324, 0.021760545543304855, 0.09361124056721888, 0.04735759812437239, 0.014597746025350307, 0.06417952530506639, 0.013298299069696618, 0.03988565148545369, 0.045110987829825575, 0.03878968993141767, 0.0182535482435337, 0.03411682938495952, 0.04044012294241017, 0.10858040708567827, 0.023834730513514053, 0.09146812492080274, 0.010533861218831472, 0.07816846317221081, 0.21320070650789047, 0.10512305228340049, 0.11503399304685094, 0.10872583355634444, 0.16936218305941553, 0.08756664596618184, 0.1345624245943562, 0.15600563928244576, 0.10189020720821235, 0.12721224763100186, 0.22264877694749066, 0.2094228818051277, 0.14188640901157934, 0.15501566982317358, 0.06993985149048029, 0.33389598972374396, 3.969619533708019, 62.70403723562918, 74.84243146834835, 71.35963347650343, 58.009128801284305, 34.66071436482091, 23.351917113027266, 43.69216780508719, 52.17514837941816, 54.7944091212365, 7.947206381828555, 0.36619627908352886, 0.3922651479801824, 1.1901446792387194, 5.344563741837779, 10.729717150811227, 7.441365757296163, 41.14708692796769, 62.31229835940946, 72.12793950111636, 67.8645976897209, 65.04624920506632, 60.4885531240894, 67.04615592956543, 66.35650911638814, 63.126394133413996, 61.22365628519366, 61.62763295635101, 48.119241114585634, 49.908861729406546, 46.773664182232274, 49.501186263176706, 45.35660597585863, 46.430201838093424, 45.88120729692521, 46.79348784108316, 47.48982621777443, 51.342319365470644, 51.457095761452955, 53.051178378443566, 55.304156426460516, 56.80579662322999, 51.4743463454708, 50.295219113749845, 46.550379337803015, 46.49638791238108, 45.21015644073487, 44.052304144828554, 43.69270124743062, 46.27643708259829, 43.08015646473054, 47.08481796326176, 47.37558326413555, 47.23995947068738, 44.701303435910134, 46.70825473723873, 43.30673217773438, 45.09753734834733, 45.375331371061264, 44.23531409232847, 46.75143611046576, 46.770930290222175, 50.644329670936834, 59.52041018393732, 60.67906656572896, 62.36922371772028, 57.022613479245095, 59.71392423875871, 54.90116034784625, 58.41038334754206, 34.31386701522335, 31.512929931763683, 65.64929008483887, 56.497859185741795, 60.17662663613597, 55.24190841182586, 59.402507658927675, 57.3068166548206, 57.46526472030148, 49.120233904930856, 46.90172564598822, 45.9927281256645, 46.93472846861809, 44.605970228871996, 47.037263147292606, 45.86400378134943, 50.26784096994708, 55.38657326852122, 59.17731654259467, 57.064971154735936, 58.8892969008415, 58.155374373159106, 56.74199142763692, 60.07401351005801, 58.62036351234683, 58.95354532426404, 57.008065408275975, 58.91035218392649, 57.83319873194541, 57.6163112732672, 57.82862917069466, 49.802628255659535, 45.88921677681708, 44.792992761058194, 47.13209821331886, 46.11743988529329, 48.989516996568256, 59.74075325073735, 60.30641002039756, 60.44129248588317, 61.886270123143355, 60.8693995783406, 56.92187132373933, 50.428375736359634, 47.573949290860085, 47.56790099605438, 49.05940186592841, 52.484403733284246, 53.821869204121256, 60.24608396714734, 64.15247832575153, 65.39694832217309, 66.46226406097412, 37.6900432186742, 5.9485224562306565, 23.594576504922685, 11.098096351469717, 6.041786613002901, 1.1027670195025783, 0.22533535536739135, 3.879751414060593, 39.48730853296096, 61.50343110484462, 48.294896618012466, 27.737383880922874, 42.406054004546135, 57.911112693048295, 65.43923539500084, 62.934723592573604, 59.1031131436748, 11.86662300940483, 0.30870233031530536, 0.2060701899350651, 0.13349671968288962, 0.21918933838605884, 0.1851133491483427, 0.16538087008220537, 0.12725401474463363, 0.1818200903794458, 0.10734735026715264, 0.3157100123503516, 0.13980995833633408, 0.11349869155955893, 0.11296367107499992, 0.1537937595839462, 0.17002443542643902, 0.16904395013566942, 0.18666279261871693, 0.09761653975733826], [0.022297885359054612, 0.02583878204947518, 0.04869965010232503, 0.011818568642822005, 0.08581671728602341, 0.06609277243936254, 0.030573126897516272, 0.008013452536561678, 0.011942132879349013, 0.10834158683616309, 0.01814797749712823, 0.06485025443497204, 0.049865628262200666, 0.012018307874489938, 0.029366733769195217, 0.09752535231171117, 0.07681736752631203, 6.551654040813447, 54.79221651631018, 56.25798271548364, 46.36777731680101, 33.86402999201129, 20.01702581682513, 23.17327472471422, 44.77319655879852, 40.07468738863545, 29.603831960308938, 0.3608876574904688, 0.10891860426073113, 0.04406400993766804, 0.4341677059569667, 4.409183869438787, 5.987415207970527, 6.978353492675289, 42.80562977637015, 63.231901968679125, 63.23690299064883, 61.78320200212541, 64.30925153916883, 60.96912976234191, 55.48020808927475, 60.23552102427329, 62.16386802734868, 57.09721303755238, 56.352307873387495, 48.79000171538323, 44.27325910137546, 42.52658451757124, 43.83128250798872, 42.3447669706037, 41.686416749031316, 39.4640802568005, 42.99561762040661, 46.692365215670684, 50.373768498820645, 50.86369606756395, 54.156466991670676, 53.14355411837178, 53.63835719323928, 51.29328581594652, 48.539554457510675, 41.04275972612443, 42.08608665773946, 40.54516000132407, 41.907614892528905, 40.53009025512203, 42.306108090185354, 38.36358477992397, 41.4932047167132, 39.757038162600615, 41.04490526260869, 39.92883013140771, 41.29406990543489, 39.722811560476984, 41.704816587509654, 39.41377585934055, 43.267041713960715, 41.08574890321301, 43.21923194393035, 41.400048425120694, 50.72454998570104, 51.97819832832583, 58.15557833640807, 54.757385869180005, 59.48931755558137, 53.86555264073034, 62.35619752637802, 35.37793544030959, 25.528518769048876, 56.306627950360706, 49.19351554686024, 56.59925637706634, 51.764358551271506, 55.58449606741629, 54.33262063610939, 57.68819262904506, 50.88431596755982, 44.541270732879646, 40.236846016299346, 41.72365180907711, 42.86539100831555, 42.26799441922096, 40.84073805039929, 42.52023027789208, 46.22435585145028, 50.60723581621724, 53.69646318497197, 57.33017436919674, 57.2024384621651, 57.901267543915786, 54.23172158579673, 52.44320707936441, 47.37001742086103, 48.729816867459206, 49.04818388723558, 49.229095366693315, 46.99649403172155, 42.10950320766818, 40.85936146397745, 41.3374944656126, 41.721843596427675, 41.320875383192494, 42.89099231843026, 44.53887416470436, 52.83334562855383, 56.94792762879403, 55.82571398827338, 56.82487503174813, 57.20632160863569, 54.98638168458016, 53.880900875214614, 46.736119254942864, 48.83394402842368, 50.09782191245787, 50.68078025694817, 47.61018806888212, 50.791748031493164, 57.41058295772922, 62.1457152981912, 59.4313802257661, 59.91445149144819, 13.947431560485596, 2.5196269010343864, 8.950125055928385, 2.3366471067551644, 5.237679644938439, 0.25116859094029476, 0.31736868463696977, 15.776196449033677, 35.68086008871756, 26.510099749411307, 25.39786461860903, 22.76396166893744, 36.351989392311346, 45.763089041556086, 48.98905023451775, 50.5096080226283, 22.548160706796956, 0.12148205551408953, 0.03286886449542738, 0.05408146756611044, 0.031806880856053, 0.015919927597766923, 0.03137373857410445, 0.011966734835427376, 0.02245955097849571, 0.03324911989752324, 0.014892305874626243, 0.05182137795453591, 0.01959903421060693, 0.03645313708412071, 0.006475734999478465, 0.03166498222027815, 0.05636347878363825, 0.013665570239085826, 0.0084278050757524, 0.015748553729105382, 0.029138552565728466, 0.08256375474194366, 0.06599963913040777, 0.03614880482576067, 0.0730261822501498, 0.058697059209789, 0.02079645070367523, 0.02313018817785046, 0.07488343984849992, 0.021012774781293927, 0.03655597672707612, 0.05102325989414127, 0.06873379927128553, 0.012538223020401935, 0.08740589773703007, 0.036031601034224994, 9.155992615607477, 65.63936648830291, 62.71731838103264, 53.874946717293035, 41.66895043465399, 27.705459710090395, 26.150777301480694, 38.75783005068379, 41.087753234371064, 35.95689296722412, 0.3662370349611006, 0.054558284520622224, 0.09441256853601626, 3.0339123885477743, 10.276147992380205, 7.116662148506411, 8.713502191728162, 42.15552437689997, 65.37537528622535, 64.301038096028, 63.176545558437226, 66.04741850206929, 63.223680680797955, 57.919173163752404, 61.41438153482253, 63.74650516817647, 59.832415119294204, 58.53781330970026, 51.37830711180165, 46.27236566235943, 45.34973398331673, 45.56115365797474, 44.32657980149792, 44.56482064339423, 41.98123778066328, 45.79868062849968, 49.58210475983159, 52.680231986507295, 52.67641159795946, 56.02854367225401, 55.62459445768788, 56.566426138724054, 54.829518256648896, 50.08939666132773, 43.46290134614514, 44.37082805941182, 42.485211356993645, 42.155175285954634, 43.29423942873555, 44.05696784296344, 40.71531241939914, 43.50970698941139, 42.89506766103929, 42.85676179393646, 42.51030668135613, 43.40583086013795, 42.89201213467506, 44.325305031191924, 41.84240548841415, 45.947130572411325, 44.48947583475421, 45.45622633349511, 44.321578779528224, 52.3234296614124, 55.03157523370559, 60.358330434368504, 56.93752550309705, 61.494837191797075, 56.20360689778482, 63.180146294255415, 36.624284252043694, 27.85637290247025, 56.55306262354697, 51.74381709867909, 58.173527102316584, 53.8847997111659, 57.18983588680145, 55.354786380644775, 59.975966022860625, 52.68034965761247, 45.842979877225815, 41.612519294984885, 44.31513432533511, 43.53725379513156, 43.64089458219467, 43.03985803358017, 43.06729893530569, 48.41155575167749, 52.82441046930129, 55.50931992069368, 59.3055074445663, 58.13959467795588, 57.761442892013065, 56.89348905317245, 55.195157681742025, 51.60921704384589, 52.053888305541015, 51.12705576804377, 52.28635934091384, 50.35319174489668, 44.690391402090754, 43.44313652284684, 42.56100331583331, 43.09697166565926, 45.23035664712229, 44.572830123286096, 44.933774471282966, 56.20728215863628, 58.41964798588907, 58.87907912654262, 58.73586554681101, 59.781961671767704, 56.38156875487297, 56.31710852346113, 50.273230306563846, 52.43166746631746, 54.16626507236112, 54.21287067474858, 50.4896588479319, 52.53190363607099, 58.62704330875028, 65.42460887662827, 62.03364141525761, 62.84743516675888, 15.336086903848956, 1.8783991735789085, 4.766839800342437, 4.520432583747372, 3.555302759332042, 0.1570456036396565, 0.16892594195181326, 18.554032733363492, 43.2030874683011, 29.67348344864384, 29.88991395119698, 29.69900042779984, 44.3036300136197, 50.804456510851466, 54.77806852709863, 58.26485556940879, 30.194413431229133, 0.4752901719222146, 0.013062160127916405, 0.052737416098675424, 0.03995278377025839, 0.06627773670780082, 0.03764458766747867, 0.08054337404187649, 0.011087061927443551, 0.04196836109904032, 0.041915363136438594, 0.027676678690758925, 0.06688482308339688, 0.022330455587155396, 0.020958756006533102, 0.021622220707696774, 0.06094065111791415, 0.040534792257653135, 0.049068839364354654, 0.11304662307544101, 0.22488199985556065, 0.16721034933242107, 0.11897033666290584, 0.08317546062772313, 0.18530215917816087, 0.17618442585151042, 0.0754954521694491, 0.1179036511588962, 0.22730412472399975, 0.1706121627601885, 0.13997981535090556, 0.16570517042231175, 0.11317180184226845, 0.2404156889045431, 0.165744869098548, 0.14141492785946017, 13.119873231457127, 73.07825134646508, 69.64784053064162, 64.37829702131211, 49.62107742986372, 30.817201483634214, 33.279541923153786, 61.08848356431531, 53.4457492059277, 40.782549688892985, 0.7757243910624135, 0.28700319629523063, 0.14174852850696734, 3.803307116031647, 16.460673578323856, 13.56285297101544, 12.177917015167976, 44.96283138951948, 69.705028687754, 67.40897517050466, 65.17908419332197, 67.14687455085017, 65.20581906841647, 60.560712968149495, 65.41221026451358, 68.10137548754292, 61.87114154138873, 61.986800470659816, 53.13681548641574, 49.57607215450656, 47.18676428641043, 47.356928471596014, 46.07257973763251, 47.021114749293176, 43.97181710889263, 48.34493037193052, 52.61261816947691, 55.36818911952358, 55.237370229536495, 59.358918359202725, 56.2878123406441, 59.71169633250083, 56.53127385723976, 52.718847720853745, 46.039800490102465, 45.750196210799686, 44.62087131315663, 45.72985087671588, 46.914218394987046, 45.466075404997795, 42.60817766189576, 44.92572969005954, 43.749116697619044, 46.18396720578594, 43.132476960459066, 46.20304953667426, 44.58433835737167, 46.08642570434078, 43.723425172990375, 49.540641384740034, 45.67627130016204, 46.93871751908333, 45.3846783791819, 53.65244242452807, 58.13551933534684, 62.56966467826598, 61.212344169616706, 65.68012775913363, 60.953875664741766, 65.10712831251084, 39.14994155206988, 30.383854104626565, 55.93161013818557, 54.79046713921332, 58.90795561575121, 56.544049016890995, 59.43321981737691, 57.56779155423565, 62.11553265971523, 57.86648004285751, 48.73850491739089, 45.04341256233954, 46.80386643255911, 46.38176841120566, 46.09106586825463, 45.92650675004529, 44.76532828423285, 50.352018956215154, 54.79520536238148, 59.59698269444128, 61.38741131751769, 59.95107466174711, 60.38576741372386, 61.71912616299045, 56.814947512842, 54.35298165967388, 53.11920012197187, 55.251706492516306, 54.381889527843846, 51.791799452997026, 46.56156985990463, 46.644994751099624, 46.90095686143445, 46.843721635880016, 46.484150117443455, 47.2969554316613, 49.2217723015816, 58.34043572025915, 60.98638034635975, 61.184252154442575, 61.08044270546206, 60.87951929338517, 59.808829907448064, 59.000531396558216, 51.87058810264834, 55.87266868160617, 55.95250068172332, 56.071764269182765, 52.20062025131718, 53.53001348433956, 63.48924867568478, 67.30701708024549, 64.94711129896103, 65.89260255136799, 16.976910444997973, 8.108144171776312, 18.431448859553186, 6.498168110847474, 8.394035927710995, 0.2898089779961494, 1.0014821060242192, 22.37053421235854, 51.264640746578095, 37.99453681515109, 35.62033791695872, 32.04567017093782, 48.429586887359626, 57.74073669987341, 62.01646143390287, 64.07805135173183, 37.18266894740444, 0.9765724813745869, 0.11742689932185797, 0.17993675514815316, 0.16657835743840665, 0.10959175805891715, 0.1411903415235781, 0.1214089400825962, 0.09216698862972761, 0.2270332973210081, 0.29176660843433877, 0.18412921727905351, 0.11919791840257184, 0.1712934753947681, 0.13381101491470493, 0.10623815454422467, 0.19284095464935228, 0.13843081621152742, 0.155113177494176], [0.03966903246398415, 0.0322041989514424, 0.01683914117635258, 0.06394218360524505, 0.01644956631465785, 0.03158540483714352, 0.07872258222872212, 0.09277315569981452, 0.058057119153560176, 0.017829158516120047, 0.044032106206061385, 0.0614064364063163, 0.02836805772066357, 0.0100727251265198, 0.03585577619472339, 0.07315145294752813, 0.20794224835211234, 16.583059372440463, 52.61673665815785, 56.90987279338222, 52.92175585223783, 39.05244319669662, 17.78832135661956, 25.846824992087583, 38.28879302547824, 40.85345829686811, 20.208237440355365, 0.4084064060401532, 0.0947698413003837, 0.09502062784327615, 3.129424063428756, 5.830249267239725, 2.4253245419071567, 9.204212273320845, 50.657340172798406, 64.14807742641818, 60.79207789513373, 58.45974637616066, 61.17755274618826, 62.25405116235057, 60.33245063597157, 52.29515329484017, 60.406999203466604, 59.830755956711315, 59.291814450294744, 53.44140714214694, 45.094481821983095, 41.95816639930972, 43.10137648736277, 41.886590988405295, 42.65226510263259, 41.686632479390795, 48.51537696776852, 51.61459069098196, 57.59928818671935, 55.63376888152092, 56.79839511071482, 53.44798495692592, 56.68974545694167, 55.167089200788936, 50.67375529196955, 39.98660664404593, 43.22727672515377, 40.010827279859974, 43.086498937299176, 39.490528798872425, 42.124882821113836, 40.56092008467644, 40.6265962508417, 39.90628827002741, 39.77353957391555, 40.42592779282601, 40.71932108171525, 40.00521044577322, 40.83043398395662, 39.93714555617302, 41.465116623909246, 40.23821492348948, 41.305362409160985, 41.16920517336938, 41.261035703843646, 41.347418062148556, 46.83678296304519, 45.70407698231359, 54.27101196781282, 49.87277984619141, 63.27001563964352, 36.70278656867243, 24.970832255578813, 57.60795270242999, 45.03109631999847, 52.90606637154856, 50.85337238927042, 55.608677479528616, 50.19559875611336, 55.95610533991168, 54.044867715527936, 47.167944754323656, 39.78530668443249, 43.053178402685354, 40.86193453881049, 42.45984931145945, 40.079158890631895, 43.0963989996141, 40.90082876143917, 47.9749410383163, 52.45548017563359, 55.39439839701499, 56.5323878103687, 53.80499124526978, 51.4081524264428, 45.40713787078858, 44.04423975175427, 43.67326590322679, 44.69647892059819, 44.943313675542036, 41.307715831264375, 41.8312345781634, 39.61924922081732, 42.59018967228551, 42.0581123136705, 41.346559063080825, 41.12645133849114, 43.28718308479556, 49.465441703796394, 54.82352095265543, 56.6100585845209, 56.073599938423406, 57.22564320410452, 57.10938415219707, 54.82261096277545, 54.66248020049065, 53.9794151244625, 58.07963340513168, 57.09485569307881, 58.52974499425581, 55.948927402496345, 50.38468837738038, 56.53933432794387, 59.985791560142275, 62.68619437371532, 38.27559032747823, 4.432407242636527, 9.904272979305638, 4.977049914098555, 8.687973445461644, 1.593718081712723, 0.08055573870097438, 3.392652609655934, 33.01431517447195, 40.44579852011896, 21.329919599717666, 18.400575883926884, 29.888894134952178, 46.65056451674431, 49.87767496416646, 54.84457231337025, 40.273661382736705, 2.6616434224190253, 0.12885487037560633, 0.033997457564598134, 0.04980673142258198, 0.09224028792232276, 0.010413090330398372, 0.04828419679054811, 0.07969149193095584, 0.06330404385563827, 0.024992388958532005, 0.004583361845899133, 0.024775566923762524, 0.05075477288975831, 0.007850718224466207, 0.04834493607162468, 0.019389629822164293, 0.06770544114612764, 0.06783867149703926, 0.0419632934274212, 0.03698292901859649, 0.06543149300400289, 0.05368525455255182, 0.03332937909891048, 0.05658257226910322, 0.026675597126145038, 0.0487110992863534, 0.029794528757432298, 0.030435834365386157, 0.024702129735340996, 0.08090470707224262, 0.0461565139853666, 0.049915868308274984, 0.047939905386057594, 0.020821047871704065, 0.21443248395958256, 22.46663228158028, 62.57666218665339, 64.8791483909853, 60.875969548379224, 47.356387184512236, 22.935369245467648, 29.158756694486065, 39.52095070192891, 45.100934120916556, 21.734555229063957, 0.21013928126663933, 0.08112280464340603, 0.3079102566886333, 4.256027081320363, 9.156559398097377, 5.479667330941846, 10.064828338161593, 53.08840559374902, 65.4143165772961, 63.134776238472234, 61.15261431663268, 63.131171580283876, 62.48282732502107, 61.9984773666628, 58.55045118639546, 61.25488227413547, 62.312608226653076, 62.54766802633963, 54.42660847017842, 46.75142042098507, 43.58402413706626, 45.343736679323264, 43.81086657124181, 44.81750757463517, 44.27077231868621, 50.116880709125155, 54.142817143471014, 58.04073526013283, 58.65656306666713, 58.20698491988644, 56.83166465451641, 58.61193041647635, 58.453870665642526, 52.71090884362498, 41.781338107201364, 44.88645891989432, 41.923088642858694, 44.642428659623675, 41.93588733673096, 43.339801680657175, 42.030643955353774, 42.27087736129761, 40.79929820952877, 43.55164497129379, 40.32868439151395, 42.72793154562674, 42.02498789756529, 42.562211405846384, 40.06140624323199, 44.76028019382108, 42.95120462294548, 42.5456746931999, 43.2793697234123, 43.15880390905565, 42.950384847579464, 49.76050200000886, 47.34280009423533, 58.39473309055452, 51.474365957321666, 65.52711609871157, 39.096169779377604, 25.76867372758927, 58.60308939410795, 47.38966849542434, 55.12575918628324, 51.993009198096495, 55.45181797396753, 51.105502343946895, 59.59035388885006, 55.766352838085545, 48.934144896845666, 41.45289844082248, 44.28948202440816, 42.74698641992385, 43.624393170879735, 42.25562718606765, 44.67299176800636, 42.92077879751883, 50.88678313839821, 55.10774766245196, 57.92147559504355, 58.539911777742454, 55.69398118603615, 53.68684945567962, 49.98262582286712, 46.32577265462568, 46.34565122665898, 47.09172525713521, 45.69856212985131, 42.67674853724819, 42.856000854123025, 41.43357292298348, 44.59048863380186, 42.4553934989437, 43.54402772841915, 42.42645425181235, 45.046452399223085, 51.80032668575164, 57.04139771000032, 58.28773475462391, 56.99667876766574, 58.57259296601819, 60.069420414586226, 56.867668090328095, 57.71784574754777, 56.1472189041876, 61.04936184421663, 58.5783588501715, 60.61627726401053, 57.29926216986872, 53.36579561233521, 58.54220636429326, 63.25423202207012, 64.32149325647663, 43.610966897779896, 3.806775226708382, 1.6127776138244139, 8.651256138278592, 9.647316548132128, 2.22202098658008, 0.2002886929098637, 4.255227898397754, 39.28661261835406, 32.229082161380404, 17.733035549040764, 21.83734682298476, 37.597730236668745, 52.2422444435858, 55.80153649853122, 61.09021725193147, 50.61611998465754, 5.518533606683055, 0.0648406553532808, 0.0488574450625287, 0.04072873507656398, 0.029934029538004153, 0.03253714842421394, 0.03852799429648346, 0.12248184622055101, 0.03527107107783518, 0.04239448984604209, 0.040589399004895846, 0.053137463382295066, 0.07870185955037033, 0.02733818465663541, 0.0027850772171551666, 0.02000499377778221, 0.0205367200842668, 0.06777049733265754, 0.12399497712331435, 0.07364112102696974, 0.1142179791725451, 0.09399933304878012, 0.11430154404332561, 0.160327049332761, 0.13034730158265562, 0.16428603850785764, 0.13387807825159642, 0.06255621563703304, 0.17308449703118495, 0.2009695765352057, 0.14048754778360167, 0.1522577073304884, 0.12409216303738857, 0.17683198465214622, 0.38425177636165775, 28.57923434626672, 70.93570370827952, 72.35751582730201, 69.7307437466037, 54.16538646144252, 27.410003254490515, 36.387396627856845, 52.594190874407374, 56.13579696224582, 27.58770819633238, 0.7647733174024091, 0.3791769035160542, 0.2594965642258044, 6.0196090417523545, 13.841317719028844, 7.428680812158893, 14.349803001649919, 55.92783289570963, 68.4391543173021, 64.25863335209509, 64.00471479662004, 66.30965248230966, 66.88664882413804, 64.59947163058867, 57.947657415943766, 64.91357111161756, 63.41619453122539, 63.95274731420702, 57.16721165564753, 49.370508578515825, 46.16842285279305, 47.76402342704035, 46.433661368585405, 46.039145454283684, 46.82162300232918, 52.33546349310106, 56.09227042044363, 59.8631037435224, 59.218842675608975, 60.210480613093225, 57.420765430696555, 61.00703554768717, 60.23435215796194, 57.63453852745795, 44.07276322764736, 46.941102320148104, 42.680412030989125, 48.24522372215025, 43.09883086912094, 45.632356443712794, 44.77017241139566, 45.502463233086374, 43.42534465174521, 43.59984697834138, 43.96937739464545, 44.54623253114762, 43.965388344180205, 44.64993215376332, 42.722338245761016, 48.36158083331201, 45.076580124516646, 44.42469789135841, 45.43548876239408, 45.05337146020705, 44.48999358761696, 52.293803999500895, 49.08369702677573, 60.41638543528896, 55.38734989781534, 65.55323123931885, 41.312367762288744, 29.417187936844368, 57.7815568062567, 48.58445382887318, 55.33591585774576, 54.20308436116865, 58.44884218708162, 51.850933105714866, 60.26840617579799, 58.280297940777196, 51.91467946575534, 43.793937621578095, 46.746599828043294, 44.7660303884937, 44.88762386383549, 44.788391820846066, 47.960844039917, 44.89299751097157, 52.22326801669214, 57.74680460652998, 59.71458711931783, 61.39244371844877, 58.440534607056655, 56.262634646508005, 52.45377394460863, 48.47913818974649, 47.893445953246086, 50.06269708756478, 48.10236315573416, 45.02367127326227, 46.21620516623221, 43.994096171471384, 46.59050910703598, 46.423624023314446, 45.47055867410476, 45.29714284404632, 47.14439484380907, 53.89428400224256, 60.16656183427381, 59.7816635716346, 59.66480047472062, 61.87800176682011, 62.213842945714156, 58.837890317363126, 61.3156750894362, 59.00341041626469, 63.06190644541095, 62.116321056119865, 63.41721042510002, 60.29893006047895, 56.491226457780414, 60.79788300298876, 68.4363772792201, 68.04717617650186, 45.77481692837131, 6.288091847973486, 20.65308520870824, 14.165576138804036, 14.315465592568922, 2.751602492024822, 0.167692203315035, 4.772754244266018, 46.431413850476666, 53.06795043330039, 28.74619003265135, 28.25583100318909, 42.05597069955642, 60.256850873270345, 63.81383657455445, 68.68642837770524, 57.71399005766838, 8.048799691661712, 0.37520706653594976, 0.14465391695980104, 0.16859148328583087, 0.21679755059942124, 0.10613253400210412, 0.12432391229536265, 0.20451095586101856, 0.13739558627768872, 0.1713588686599847, 0.14182205762593977, 0.1400135998283663, 0.18328446744670793, 0.11089018516002164, 0.1721550638396894, 0.058143836476149104, 0.10715877006371176, 0.17427230103602334], [0.07187546456172582, 0.05576184312362344, 0.035709307844480204, 0.05671066983092216, 0.05028223070586401, 0.04629046062848741, 0.021992651032163732, 0.043665835739023266, 0.04148653392950374, 0.06477339283352898, 0.022108883807255376, 0.02992927404721418, 0.013229007374555355, 0.016998447244986892, 0.03450733121304262, 0.0045672189369196856, 0.6404290348291397, 26.055371530594368, 58.38747278336556, 50.50172798095211, 44.38336787685272, 25.57431047962558, 22.8531995127278, 41.62152897927069, 37.21350269932901, 42.05083239463068, 12.726894886262956, 0.2599456756105346, 0.06966403685510159, 0.27020576860635515, 2.9121880041014765, 7.677837610244752, 6.712954650002142, 13.56151544278668, 59.22354167507541, 64.5259036556367, 61.00549405620944, 58.77773292603032, 59.60698473838068, 59.73860771425309, 61.30074654856036, 62.44461951717254, 60.64163146480438, 58.515683297188055, 61.70527235154183, 52.10356904614357, 41.95305947334536, 41.735391463002856, 42.34941890162807, 42.39732673091274, 41.96415978093302, 44.35797052998697, 51.100528778568396, 54.26247296794769, 55.38829911139704, 55.27399732220558, 53.265241730597715, 52.692795338169226, 55.45561090592415, 55.13412560186079, 47.069642313065074, 39.85599956204815, 42.813121503399266, 39.46592769315166, 42.51509197296635, 39.326581570409964, 43.08892688443584, 39.84382060266311, 41.23714846949424, 39.71122880135813, 42.00150074497346, 39.46621794854441, 41.26805282408192, 39.322690579199026, 41.55770809419694, 37.22545023887388, 43.587577804442375, 45.10021632717502, 48.760768290488954, 46.42743264475177, 49.65918717845794, 43.93991647228118, 44.982164752098825, 42.007737313547445, 51.97295411940544, 48.68314850714899, 62.4287143061238, 36.60890071622787, 21.217453479766846, 56.862514095921675, 48.512509715172556, 57.14053169373543, 49.50898785744944, 56.52624930104902, 50.21550478473787, 54.46960941437752, 55.04538589908231, 49.4310111384238, 40.951403802441014, 42.209778601123446, 40.15679436345255, 41.976217146842714, 40.194080414310584, 42.33443152519965, 39.725698424923806, 41.5697850719575, 45.463361124838556, 49.21956400717459, 48.78439272603681, 48.01652208451302, 42.719149358810924, 42.44277131172919, 39.153181429832216, 40.98347702334004, 38.33407286674746, 40.005261436585464, 39.99908762593424, 40.711233154419936, 39.98114278239589, 41.17186846271638, 40.961296020015595, 43.00506268778155, 43.50721628435197, 49.64841634996476, 51.70530726832729, 55.84291750384916, 54.303944187779585, 53.7627669303648, 48.1006569247092, 56.37995273836198, 57.99356091407038, 58.29253181334465, 56.079663922709805, 59.36602177158479, 56.64449699463383, 58.638555465206025, 54.83192266956453, 57.366409224848596, 54.56915132461056, 59.84402533500426, 58.529089958437034, 61.27486282779325, 11.89478268546443, 1.1409538671855004, 5.802881419658662, 0.5309248559417263, 2.0507928584852526, 0.07828568994638421, 1.0189225572732188, 23.735181708489698, 48.73883047411519, 41.47140026092529, 22.88707898509118, 23.994448415694702, 41.3410363658782, 42.211151430683756, 52.94671781601445, 47.92453465923187, 18.37436660643547, 0.07558300069743588, 0.01354829749963697, 0.10104979343351819, 0.026680199399350152, 0.05792086275534765, 0.018912019966650876, 0.06990985914824471, 0.030393915949389342, 0.02498268070931156, 0.011853369144392351, 0.0029764696814855865, 0.009548428915290823, 0.02743533801197285, 0.056587023239943295, 0.016634143708694368, 0.032827246768940846, 0.05438887949792608, 0.05376732938231961, 0.04786426186441414, 0.06291567941286391, 0.044450623869535424, 0.07874226302749689, 0.010302454785203502, 0.048385492766336094, 0.035583068045877644, 0.0186753505089831, 0.04613125606650307, 0.03917777092166005, 0.09154418212992531, 0.026934331831251903, 0.023575430818563028, 0.04384462150835222, 0.03138606492880612, 0.9018203183527916, 33.619560426281346, 65.32432956080284, 58.51021943553802, 50.465453901598536, 31.846437300405196, 22.39098348925191, 35.183142692812034, 36.76570530860655, 48.094993022180375, 12.308049490374904, 0.22757918093233342, 0.04235400592968349, 1.054982990026474, 8.31205839110959, 6.292632972040485, 4.556233036902643, 14.97013565032713, 61.07441402250721, 64.33842220614034, 64.31690016100484, 59.50086893573884, 61.20239311648954, 61.27331349157519, 63.633658578318936, 62.08713077729749, 64.5467588978429, 59.56423482587261, 64.33923805913618, 53.73907189215384, 45.43664193922474, 42.96051632973456, 44.4600070676496, 44.33608762679562, 45.36643935788063, 45.54129862016248, 52.85944900205059, 55.36232517611597, 58.18390177142236, 56.00775118797056, 53.925027539653165, 55.019761054746574, 57.6856077871015, 57.06560657870386, 49.12480738855178, 41.76901009774978, 45.44987209381596, 41.48044916891283, 44.8670078862098, 40.67531993312221, 43.23607460145028, 42.2959569961794, 43.8024805438134, 41.43701676399478, 43.48554126677975, 41.672959096970104, 42.79558458635884, 40.763047664396225, 42.638140647642075, 39.91252091623122, 45.03194747432586, 46.80208567650088, 51.307265143240656, 48.44480960599838, 51.27293263712237, 45.31416985296434, 45.750910082171046, 43.41399723483671, 53.6477904935037, 51.092436928902906, 64.82611010151525, 38.298132188858524, 22.58703139520461, 55.08681005047214, 48.791700101667836, 58.209769802708784, 52.475829432087565, 57.41760007796749, 52.61468133618755, 55.094603800004535, 58.40014988376249, 52.24602168606174, 42.51036943927888, 45.00242379403884, 41.844307837947724, 43.10747577298073, 42.53200523314938, 43.91362482501615, 42.72413469129994, 44.46500024487896, 48.8749171072437, 52.09003686904908, 51.96007697812973, 50.864002012437396, 44.82019047583304, 44.38146160494897, 40.607925768821474, 42.20385189979307, 40.12352481965096, 42.481485105329945, 40.531172829289595, 42.64332994338005, 41.296960692251886, 42.0359666116776, 42.710022003419944, 44.171567732288, 46.5255585793526, 52.373569319325114, 55.44939002683086, 57.55952712028258, 57.382832188760084, 53.35384022804999, 51.29508618385562, 58.352359725582986, 59.33780031819498, 60.71611335200649, 58.84519377062398, 61.58154902919647, 60.731626326038, 61.06161532863494, 56.275896180060606, 59.87431779984505, 56.36009377817954, 61.201047743520434, 60.65322599103374, 63.69580068895894, 14.645863502256333, 0.8543378210836842, 7.649417096568693, 2.675178296143009, 3.674345958617426, 0.05165983682438251, 0.2974130441584895, 27.932890499791792, 48.1656192195031, 32.82916361285795, 28.785635348289247, 30.462199526448405, 48.99603205342447, 50.28408350483064, 56.76165034694057, 56.410053007064334, 25.527147900673654, 0.15261458172913522, 0.03607175936321578, 0.022361767515840552, 0.02162427956899328, 0.01154979722829716, 0.04563518349201449, 0.024341447879710508, 0.06870887843110869, 0.011742737429637102, 0.041102739201197704, 0.061044835245176676, 0.03630322133821826, 0.0210373604580039, 0.05377400583857971, 0.04648859394834407, 0.06910764251745517, 0.030221245476915955, 0.19463759937113334, 0.17506068211890038, 0.12654778893075644, 0.11080602274066019, 0.1887161227604074, 0.11081939097493888, 0.060916856426986, 0.11667424857976938, 0.10282147901072618, 0.19935178270022716, 0.11287414604016852, 0.21592578850686553, 0.17688473746661218, 0.20102173180109073, 0.24457756880550618, 0.09708174909915655, 1.4679193352499318, 42.48712155126756, 76.2589797665996, 66.89274418738582, 58.704392448548354, 36.96147472627702, 32.73951588138458, 54.3304084193322, 50.4077793705848, 56.83357484879033, 15.609100537915385, 0.4019316454087535, 0.3255351206227657, 1.1197510049227746, 8.806817339312646, 16.587995675302324, 13.404574548044513, 19.041449985196515, 62.461140540338334, 68.79414450737738, 66.75470029154133, 63.99605812564973, 64.20988613559355, 64.27030240335773, 65.74299158588533, 66.50583374884822, 65.47917689046552, 61.79196457709036, 68.94146088630923, 57.33700321566675, 47.40381648463588, 44.448604737558675, 46.50999461450885, 45.64107979497602, 48.90817488393476, 48.580484390258796, 55.36072092671549, 58.46543773528069, 59.25133951248662, 57.889347460962114, 53.96167816654329, 56.24759235689717, 60.484497393331225, 61.365273460265136, 51.12633797430223, 43.13998829933905, 47.813166802929295, 43.929643784799886, 47.014521245033514, 42.86884269406719, 46.24538760031424, 45.956524648974025, 45.68368457978772, 43.23441151649722, 43.87331462675526, 43.13153951398788, 44.46758508682252, 43.134563661390736, 44.93193880204232, 41.289527800775346, 47.79859519773915, 49.04197477525281, 53.22011486176522, 50.66138413644607, 55.26310490023706, 49.32973946294477, 48.62474833765338, 47.18360285605154, 57.37550912364837, 53.724712094952984, 67.1012887647075, 41.99961800729075, 24.88889982623439, 55.30472124776533, 52.42292058083319, 59.77259112942604, 54.860873683806396, 58.283129892041615, 53.44949899181243, 57.48868519260038, 59.66893465288224, 55.06134994568364, 44.909816634270456, 47.90491104125977, 44.0941362227163, 46.30821220336422, 45.272122044717115, 46.48043563289028, 44.82945903655022, 46.36699284276655, 50.49660928787724, 55.10899889853693, 56.68511706013834, 52.40652115114274, 47.81813252356745, 46.97028083185996, 44.1318105882214, 44.63234816828082, 41.643682526003936, 44.772647426974395, 44.12849226305562, 45.34367784377068, 45.0712731576735, 44.71820885135282, 45.2113135399357, 46.94645635543331, 49.306864200099824, 54.959576206822554, 56.726753019517474, 59.19096246842415, 57.93569026454803, 55.69774666140157, 52.33631464742845, 59.16686342608545, 61.733964489352324, 64.00356554215955, 60.9614223049533, 64.1836376344004, 61.5789092740705, 64.31379364382836, 58.67624944256198, 62.493209838867195, 60.184679262099735, 64.82813404452416, 63.89253893206197, 68.77049261523833, 16.014672633140318, 3.990803274416155, 14.305041893835991, 0.851898842280911, 3.227129568976741, 0.14799603681650855, 1.7263657767926495, 32.90074490731762, 62.996340105610514, 57.88246762367987, 32.226869944603216, 32.97936293386644, 53.952731240180235, 55.6234295137467, 66.12072760058989, 63.68691652051864, 32.204249635819465, 0.38165296097436263, 0.1922005051446538, 0.1402540288625225, 0.121508700052096, 0.1416549891714127, 0.2136898076822681, 0.087310673008042, 0.18035680115703615, 0.11477246595126007, 0.14823029118199504, 0.1299472964338718, 0.06544507574290037, 0.10926623963901114, 0.13912317583397513, 0.10437604760931385, 0.1376622001970968, 0.16647035436284158], [0.02041902408123978, 0.10133071787535183, 0.009453442631169193, 0.035066127236331665, 0.026892700698226694, 0.05310946286866262, 0.06885769101040018, 0.013182558506096323, 0.021052205326756643, 0.04610752649304848, 0.03721937822598604, 0.003319132430929571, 0.06419595406060258, 0.054799862686664834, 0.0461641748646094, 0.01994060025730681, 3.076880728044818, 39.373720615140854, 58.96887002452728, 52.644483504756806, 47.615094953967684, 28.585221844334757, 26.481433107006936, 51.17639134007116, 36.945491067824825, 42.73729424322806, 3.2054954911431963, 0.16169050197687843, 0.037943078505416075, 1.4040719741775145, 6.075340038345707, 6.545530240381918, 4.169854079523395, 21.183405345486058, 66.93837704197054, 60.50710985737463, 62.06400056039134, 54.880775790060724, 57.38587202564363, 55.814201831817634, 58.016279282108435, 56.1204408830212, 56.49389759186776, 55.98850019516484, 52.274321586855, 41.86638293727752, 43.11196688682803, 44.154509344408595, 40.963578839455884, 39.60537971988801, 42.4164169065414, 47.88982168320687, 56.03458412231938, 55.35094638024607, 54.925949727335286, 51.47995533481721, 53.72246849921442, 54.89675552614274, 55.73679777883715, 49.405790298215805, 42.80619852004513, 39.206290321965376, 43.15074736072172, 41.91184320757466, 42.81520820433094, 39.11039229362242, 43.560282030413234, 42.65998824950188, 40.78139651206232, 39.07009386247204, 41.7866607635252, 40.00502609437512, 41.7690493214515, 38.793213752008256, 40.09877858623382, 41.94844284365254, 51.77417624381281, 52.2395811542388, 56.65933924336588, 53.332592748826556, 54.3417989823126, 50.81159914693525, 54.95204525609171, 47.697962868598204, 55.41140579408216, 48.12661124813942, 62.658741704879276, 35.62373468952794, 23.799032011339744, 59.66593796207059, 49.872815147522964, 52.91389150004233, 50.8483596001902, 55.01926683610486, 54.043761607139345, 55.732887175775346, 53.15114782702539, 45.456234178235455, 40.04292011260986, 42.54174447828724, 41.18307467429869, 41.71529323823991, 40.025689140442886, 40.738976078648726, 40.534271501725726, 41.74714680640928, 39.245090407709924, 42.602560827809, 39.812233755665446, 41.28023178346696, 39.794351670049856, 40.853348470503285, 39.18010850106516, 41.171703723169145, 41.76711559295654, 42.063129025120894, 43.28930508705878, 42.22629962428924, 39.82788401265299, 41.9436889310037, 41.14375683569139, 41.01833120469124, 46.382297931178925, 56.130399780888716, 57.355854126714895, 53.69705154049782, 53.688998914534054, 53.014614043697236, 53.65411727659164, 57.24537664844144, 56.141276513376546, 56.08129170633132, 54.72575195374028, 56.55908738413165, 58.110804480891076, 55.18364552528628, 52.706080405942856, 48.2313895225525, 48.319893883120635, 57.681430462867986, 57.807546431018466, 60.91305555835847, 34.1416867317692, 0.9426751744843299, 6.67552347144773, 2.4615177223759317, 3.648779214389863, 0.18820927898970344, 0.0999334347884982, 10.078631158797972, 33.7999737647272, 34.788465961333245, 11.232371830171155, 29.11495166440164, 44.53306121210898, 33.4469251478872, 55.2464505164854, 47.88738589132986, 38.51785552117133, 2.2473254223023695, 0.01830667069542312, 0.057831077250621976, 0.08633673010814576, 0.015801660859236316, 0.04430354647939244, 0.04549557162869362, 0.020490823756723155, 0.04582711149968448, 0.02469279878442326, 0.01728801698904605, 0.008215218549594283, 0.007006261420751652, 0.05491631571203471, 0.02682867106951533, 0.02445114784002785, 0.04522754810750485, 0.005490814538432225, 0.07252683848022454, 0.031796395027589415, 0.05579322591544159, 0.013795296695353764, 0.011796581919395156, 0.019018623016534314, 0.03015633101665205, 0.04022122863980551, 0.048822189696253314, 0.03330209104704761, 0.020421086772975904, 0.04834037401803559, 0.04097366870771493, 0.05479407106195727, 0.03620483649654254, 4.888243531027149, 49.21214680517874, 66.43309731637278, 58.12473281737297, 53.80308889573621, 37.25617024206346, 27.55925924547257, 48.83936474400182, 37.49055539408038, 49.8322460728307, 3.3003825285742363, 0.019388315981374155, 0.20908352017642992, 3.0993556639840527, 14.609469790612499, 10.042562023285898, 4.792413163569666, 21.88533898322813, 71.15588203553231, 63.07175551691363, 65.10779511544013, 56.84158825105237, 58.9826100872409, 58.374929043554495, 59.83237197322231, 58.9445121057572, 60.20096886542536, 57.76670671278431, 54.81451126836962, 44.57529337175431, 45.89051900371429, 45.4029409347042, 42.27349358220255, 41.075338932775686, 43.72231906460178, 49.71199012571766, 57.779144548600726, 56.92625261122181, 55.57994219564623, 51.492248042937256, 53.024918110139915, 55.776868712517526, 56.61801707360053, 51.89413801316292, 45.04721333903652, 40.59522121183334, 45.9393132886579, 43.582427732406124, 43.95090303113384, 40.45214883742794, 43.45295029301798, 43.7774597444842, 44.2321369724889, 41.78731579934397, 43.399739419260335, 42.02620383231871, 42.671531784919004, 40.61980662807342, 42.62967617281022, 44.024702425925966, 54.794197313247196, 53.35165154549384, 58.756579583691014, 56.39792503849153, 57.27297836734403, 52.81945651577365, 55.71002760241109, 50.53855903687016, 55.899583985728604, 49.24718533792804, 65.2900323560161, 37.879379949262066, 25.231632609521192, 60.96171256034606, 51.820091509049945, 54.563895348579656, 51.10151721585182, 56.85576369685512, 54.7825361067249, 57.07410243249709, 55.071677546347345, 47.34327077865601, 40.92860306462934, 43.70065581414008, 42.378436596162864, 43.7407777386327, 41.99598197014102, 44.372549979917466, 41.44403780660322, 41.84787719480453, 41.25778798134097, 45.86103454712899, 43.53710866743519, 43.665895769673014, 41.9631988002408, 41.921731502779075, 41.38718697332567, 43.37291432965187, 42.76014989422214, 43.522144825227805, 43.219926203450854, 43.71475281253938, 41.590503031207675, 42.65892528718518, 44.4600070676496, 43.484705801933046, 48.73055819542178, 57.969657990240286, 58.52681498373709, 57.04973274661649, 53.52558905078519, 53.21663571942238, 54.16968537915138, 57.63790784343597, 56.62474786081622, 57.10833687936106, 56.47833754939418, 58.78442841191446, 59.67338262065765, 58.09581710446266, 55.520604579679436, 51.33667115242251, 51.24856295124177, 60.577167311022365, 60.88337890563473, 63.967118878518384, 38.445268138762444, 1.41789244547967, 6.015348367152676, 8.448404881262011, 4.572657471702946, 0.1393469960819329, 0.03315117172596436, 11.41489246199208, 39.796709014523415, 32.255936668765166, 14.913916318647324, 32.512030178500765, 51.55366843746555, 39.61802544132356, 62.43571965925155, 54.53969040224629, 46.41131562571372, 3.295814438212303, 0.033342099988893155, 0.0332136040613536, 0.05068325092114749, 0.04188558146838219, 0.007502932022626122, 0.07362976760393189, 0.032925344327644955, 0.022236665357805552, 0.011709212464460684, 0.1164210411990362, 0.09734601112863711, 0.08253150244033144, 0.05479255037742758, 0.03772726387626702, 0.023694609201723532, 0.03991855113136192, 0.07719488033363897, 0.15409981170969625, 0.159657902174419, 0.1781899521067258, 0.11413122737599958, 0.13041464071119988, 0.17628355762891232, 0.12237385846674444, 0.15246870326659373, 0.16220030284697012, 0.1103006958240463, 0.16226315270027808, 0.14070637313829315, 0.10173884355613302, 0.1429333907341765, 0.17042535988073196, 6.531627399306144, 60.338769574319166, 74.48239711023147, 68.00314364894744, 62.06827202150899, 43.02040307752548, 38.68559568159042, 65.17259659305697, 48.818584026828894, 56.463734565242646, 4.300159629314177, 0.23872781334625137, 0.33955357968807226, 2.4304824586837523, 10.349763035774231, 14.06863279881016, 10.933845139318898, 22.464690708344985, 74.08381369806106, 65.49317582961052, 67.33710165946715, 57.86462083939583, 62.52398867760936, 60.85164300857052, 63.82721577921222, 62.80388901310583, 61.91522505975539, 60.11138193068966, 56.94733142852784, 45.57688236236573, 47.35593218957224, 48.81654831670946, 43.709292873259514, 43.12763283329625, 46.52391118388022, 52.015951141234375, 61.987494730180316, 59.584266370342625, 58.09061996398434, 52.483419218371, 53.88331313287058, 57.7597092043969, 60.622203965340894, 53.57597581801876, 46.49337945445892, 43.24084812594999, 46.978968881791644, 46.51133214273761, 46.54334652808405, 41.77348944448656, 47.48593522656349, 43.89948468054495, 46.03386594403175, 42.757121824449115, 45.58973989179058, 43.47380553522418, 45.658102881523874, 43.018426202958636, 44.73133310194939, 47.29906174444383, 57.438988762517134, 55.36105040580996, 60.328485119727354, 58.42093452330559, 59.31352084682834, 55.435281261321045, 59.591577668343824, 54.40356454541607, 58.947085180590236, 52.496512090006185, 66.32123916379868, 40.13652747677219, 26.720191701765984, 60.75838081298336, 54.771843725635165, 56.16008035598263, 54.25329854411464, 59.63101317805629, 57.93691012167162, 60.19077070297734, 58.18591786969093, 49.186447435809725, 42.93878639897993, 46.605096401706824, 45.39001672498642, 45.32343449131135, 45.588068962097175, 47.331362462812855, 45.60453507208055, 45.547476353183875, 43.93293073100429, 48.22062653879966, 44.66455867213588, 46.143402053463845, 44.950730877537886, 44.327070097769464, 44.0848990409605, 44.63080275443293, 46.05801205481253, 46.81791636251634, 47.00784537100023, 46.72702720088344, 43.55948186689808, 46.465412955130304, 46.05974182005852, 44.589068735799486, 50.91285905530376, 60.35608291625977, 62.197922045184725, 58.41611785273398, 54.89819503599598, 52.77615354907129, 55.472328047598566, 58.293041721467056, 58.06818792896887, 58.809798302189, 58.45077983794674, 60.249896510954834, 62.482905772424516, 59.736356273774184, 57.74233702690371, 53.082216093617106, 54.38002247964182, 62.72110346824893, 64.48489135311496, 65.28155219170355, 41.28045535856678, 1.8088054176299804, 18.893706067915886, 13.021275631843075, 6.050993886686141, 0.35896980233730813, 0.2607138166504522, 14.53963787324967, 50.043446094759055, 46.32190519763578, 18.479033093298636, 37.79274655926613, 55.5413656850015, 46.381246735972745, 70.45609981782975, 61.17386964059646, 54.961051018007346, 4.558014283257147, 0.11136494516845673, 0.13584372196947375, 0.2312587318761695, 0.0812695028200265, 0.1315887623857106, 0.18076500344660976, 0.12241213988032072, 0.1246041932233399, 0.13062480927234696, 0.19904743128966904, 0.2325177667362075, 0.16638203974693053, 0.28189483008557753, 0.10900865789623031, 0.08223120363489275, 0.08904694234051051], [0.02513602086823554, 0.03165516288830869, 0.024096491265921824, 0.03412447494244383, 0.026267421649648782, 0.061373536760408076, 0.08651580316044631, 0.06321085309008918, 0.01881448931301073, 0.016152180558551225, 0.04317942353325986, 0.050893702934826576, 0.0582293855146535, 0.05839778696216884, 0.04283776747122888, 0.009273215658932684, 8.587988307399135, 45.5776511469195, 58.339023666997115, 45.23605977335284, 25.804039778247958, 12.787873033554325, 34.44114008257466, 36.097494248420965, 39.714445144899436, 35.12374624129265, 0.222887413335904, 0.10611669130383, 0.11063623467400191, 3.223323153872644, 21.57348898149306, 5.159667134284973, 1.393715078311582, 27.60766129339895, 67.38639800779282, 57.11932343821372, 57.954219541242054, 51.24141247041764, 50.365296179248446, 48.17773934333555, 49.51897421190816, 48.05307072977866, 46.514297454587876, 41.951545438458844, 41.198532735147786, 40.65750845016972, 41.128412523577296, 41.776113510131836, 42.22546808181271, 39.2241527957301, 43.602945650777514, 46.59067776895339, 54.58295022287677, 54.09908271604969, 56.92487193692116, 53.29043903658467, 52.77858149620795, 54.56256958746142, 55.04018483623382, 51.59137025956185, 42.99682571041969, 41.638230431464414, 42.53917924819454, 40.96703052520752, 42.360519209215724, 40.7934146542703, 39.82071784234817, 40.499687963916415, 42.625479236725845, 39.31541066015921, 43.182149856321274, 40.0550010127406, 42.5429251117091, 38.74052063111336, 40.00864644204417, 50.0057795739943, 56.785761156389796, 53.1081311933456, 54.74596000486805, 52.53428451476559, 56.06070318529683, 52.143942002327215, 55.98999854057066, 51.048918231841064, 59.08824736072172, 51.10168195539906, 62.83669571722708, 31.09638010301898, 27.18636931911592, 62.95290377832229, 48.875705503648334, 53.74894449787756, 48.199696771560184, 52.31312167259955, 51.23365009984663, 53.09150818855532, 46.06360927704842, 43.48274461684689, 40.37443099483367, 40.97811514331449, 41.19980750545379, 43.57586952947801, 41.70415370695053, 40.75650907331898, 40.98580298885223, 40.08315970820766, 40.3647074391765, 40.107043020186886, 38.86918613987584, 42.117112605802475, 40.34484455662389, 39.540519406718595, 39.30909956655195, 39.79998027124713, 40.03443994829732, 41.161933099069905, 41.7894378016072, 40.35557223904518, 40.62687081675376, 39.7353199989565, 40.6942218349826, 42.58366284831878, 52.02227792432232, 56.060958139358036, 54.500074463505904, 52.42121042743806, 54.708913218590524, 55.04711958669848, 58.00528487851543, 56.180798315232806, 56.9472098350525, 51.76483708043253, 55.14531612396241, 57.855579776148645, 55.36708301113498, 47.221355668960086, 46.59643973073652, 50.483445813578946, 56.702559840294626, 53.956367277329974, 62.20988919658046, 60.492895187870154, 49.7970937913464, 8.326741783849656, 5.2505871845829875, 9.5322802951259, 5.173383662777563, 1.339244388284222, 0.04823872564180244, 3.472939604713071, 32.132711487431685, 39.991125214484434, 35.79950786405994, 25.628856920426895, 33.09320188337757, 46.5221147383413, 51.05042049961706, 51.56017172721125, 46.32922434037732, 9.636201531656328, 0.017516734454059796, 0.09520662633041221, 0.03974112899853818, 0.009314170719364719, 0.006760974910350577, 0.04558905350765394, 0.013318292049300528, 0.053918175925050056, 0.04354533776941319, 0.040925577538268226, 0.03743971277388834, 0.02951810891259342, 0.04941663945153837, 0.07480343728656731, 0.023631060293184656, 0.03225985140870175, 0.07309302342154327, 0.023854411312288815, 0.0248412455567309, 0.13369669927464378, 0.07695232923593252, 0.03540697890604216, 0.05193974619971649, 0.01633796454106848, 0.03231810090402442, 0.050745602817304676, 0.07094538785637387, 0.05616963555615756, 0.023730984971588178, 0.035678147218160094, 0.06399004111787485, 0.06718215712856862, 11.318551205819654, 55.31364463990735, 64.76763932935654, 52.937543392181404, 36.92435341496622, 23.199642858197613, 34.688606339116255, 38.60032727641445, 45.081914547950994, 39.679932209753225, 0.3088647715987698, 0.05929372295917523, 0.16729065066864415, 4.930197692686512, 12.06082740137654, 9.202843366130706, 4.133389765216458, 30.748263866670673, 69.77244638627576, 60.77637272496378, 59.44476727516421, 53.99130382845479, 52.818589671965576, 51.55252310537523, 52.27650634704098, 49.4071513606656, 49.38517039821994, 44.32281824850267, 43.998587285318685, 43.934546747515284, 43.37134538158294, 44.2881013501075, 45.3085373293969, 41.28500923033684, 43.74306448044316, 47.35197844043855, 55.85244101862754, 55.3345077268539, 57.887009728339414, 55.349510792763006, 53.31850751753777, 55.65388671813473, 55.794162442607266, 53.01089955914406, 45.2695881935858, 43.38043743564237, 43.683950439576186, 43.3166322400493, 43.60833890976445, 41.494624614715576, 41.9359383275432, 42.6263500029041, 43.753254798150834, 41.371968177057084, 43.82099413102673, 41.707013114806145, 43.72284466220487, 40.075436561338364, 43.19901997043241, 52.21685886383057, 57.31683831061087, 55.8237135794855, 56.20259100391019, 53.75099589747768, 58.17781033054475, 56.83776394013436, 59.93558129956646, 53.25856977893461, 60.782691663311375, 53.299064328593595, 66.91652944011074, 31.56337945692001, 29.09889740328635, 63.67675365940217, 51.368685537768954, 55.85406487987888, 50.80216584667083, 56.455458364179066, 52.86837631656278, 53.50247060098956, 48.58172385923324, 46.07750231219877, 40.940542759433875, 43.03419805342152, 40.72388279822565, 44.38413273903632, 42.239890636936316, 42.11184878503123, 43.24160906576341, 41.92526555830433, 43.22361323141283, 42.14902500952444, 40.76059618303853, 44.608147144317634, 42.00346977479997, 42.730347725652884, 41.31661961155553, 41.84107188255557, 41.34533920595723, 42.935103293388124, 42.73319144402781, 41.27906683952578, 42.81782442523588, 41.88073096736785, 42.3566399851153, 43.44046538875949, 53.17461536776636, 58.454780655522505, 57.94401353405368, 54.344681924389256, 55.00535026673348, 57.03189772944297, 59.58536855636105, 56.75304858915268, 57.90843371422061, 51.505356604053134, 56.50777885990759, 59.82944980744393, 55.9433223355201, 50.795850830693404, 48.0188911960971, 52.23472525996547, 55.61792642839494, 57.19179314951743, 64.03690176625406, 64.0095079329706, 53.531594199519006, 12.315683403322774, 3.1553744644887987, 10.800836586183118, 11.283433245074365, 2.2568607041912694, 0.15408789138159446, 3.4334599683361673, 35.78356735167965, 42.820181769709436, 34.657035181599284, 30.53231385446364, 37.92314575564477, 47.09560448123563, 57.42150675865912, 55.66700312399096, 56.35896413556991, 12.81951283254931, 0.04544310992763889, 0.03915830845794371, 0.0868278767372812, 0.00448332991518621, 0.04672854034710796, 0.045452333626247225, 0.020011779401571523, 0.03187210558192625, 0.11506269836137373, 0.034779966583535556, 0.023107502399192705, 0.011201684002674395, 0.06369642259913587, 0.15233109855363447, 0.05366565802344873, 0.04070061581930326, 0.22386426736991252, 0.16303088005271651, 0.1864062297728754, 0.31972134065243507, 0.167892397411408, 0.11515508856504195, 0.22082078390784804, 0.14708456072595813, 0.11116441399339708, 0.11925845467034848, 0.14821067933113347, 0.17314026823207257, 0.1487245711107408, 0.176577229773806, 0.16182401578032202, 0.20245670641381897, 15.999392059541519, 65.46349133214643, 71.34072765227288, 62.70923829847767, 40.9123016941932, 23.680982397448634, 45.37431939955681, 49.65896752572829, 54.7712867490707, 47.77116998549431, 0.32126424173193596, 0.219057111610328, 0.17549572812934078, 8.42259568552817, 37.151156625440045, 15.26751014494127, 4.9795195364183, 32.67111759031973, 72.77691918034708, 63.231599946175855, 62.88468591628536, 55.8172102897398, 54.37407224409042, 53.98303154976138, 54.040035355475645, 52.33625973424604, 50.950611868212306, 46.72496011180263, 45.78277933982111, 44.51174313022245, 45.145221602532175, 44.68654747932188, 45.96664044164842, 43.45020463389736, 48.9640215904482, 49.567042858369895, 57.973258726058475, 57.168835516898866, 60.43340852183681, 56.06158964095577, 54.53318711250059, 57.965829756952104, 58.84525652854674, 58.40620602330854, 48.15205174107706, 46.70557968078121, 46.39562614502446, 44.81740951538087, 46.370154273125436, 44.29813085063812, 42.37856603437855, 46.08247195520709, 46.298916186055834, 42.53553144393429, 47.66667804410381, 42.990565607624674, 46.28737657300888, 42.06403117026053, 45.51690540006084, 55.275291704362445, 60.293772143702355, 57.23240929265177, 57.21746113992507, 56.3812392757785, 60.62215689689883, 58.60412882220361, 61.62289081081268, 55.96646824190694, 62.67473320807181, 55.66785427831835, 67.8943371003674, 33.89385569480158, 31.631946409902266, 64.67609905427503, 55.02647615248158, 57.32271794349917, 54.13550976783999, 58.04560292151667, 55.88576939798171, 57.05562022424514, 50.93170604398174, 48.46959114074708, 43.55724219352969, 45.00729537779286, 44.431342386430316, 45.707450220661784, 45.048774442365094, 44.26869346249489, 45.38737304749028, 44.04976244895689, 43.419598379442775, 43.99124853072628, 42.717466662007, 47.04222102319041, 44.98831895089919, 44.42859280493952, 44.26097423799577, 44.16953594453874, 43.98416473019508, 44.504098430756606, 44.439422468985285, 43.74667698337186, 44.20080507955244, 43.77374133756084, 45.15499614900158, 46.62285689384707, 57.47159934812977, 63.49840741003714, 58.784887329224624, 53.781900252065356, 57.10316719547395, 58.91722025409822, 61.51053843959686, 61.33499668490503, 61.299671819133145, 52.96460774637038, 57.22758869970999, 62.83063565531085, 60.38193918043568, 52.763343088088504, 51.724071887231645, 54.45002502010715, 60.38209999761274, 60.90964309630856, 68.35039108030259, 65.06277415060228, 57.50291555158554, 13.091452717781069, 9.63459728225585, 22.646659266564157, 10.329655985678396, 1.9308363598200584, 0.2941006331914856, 4.803621336337059, 44.98019179990215, 54.8143857525241, 50.21662266023698, 34.89209498128584, 43.72696707325597, 59.00380265328192, 64.01630932284941, 64.67475368130592, 63.54599360496768, 16.900335973308934, 0.23130763892925557, 0.4641289450228215, 0.17696323083533397, 0.15901081834829625, 0.11379510629922153, 0.13739074460200726, 0.15443229386883398, 0.14544435115831514, 0.23309777190368022, 0.1080292298067962, 0.07577304412881214, 0.17747503885578725, 0.1670357119292021, 0.3102745572405477, 0.09639649111176692, 0.189610913455967], [0.026583513357646527, 0.12334540351143769, 0.02032823308611349, 0.05137345017564874, 0.08133689557472545, 0.024009197462169875, 0.06409762284508155, 0.051881611617582465, 0.09289189166719876, 0.05216836981895951, 0.12816706897630809, 0.05063167405164531, 0.011848340734779354, 0.05954493085042604, 0.05498794110251531, 0.24691530142820653, 17.018150244989705, 56.66352441233974, 58.06898809248402, 43.42921210873512, 24.16303384688593, 20.622722141204342, 38.64478341994747, 44.86024179766255, 43.30182137027864, 21.055292890917872, 0.1368770826487772, 0.09958824323069665, 0.684751695202243, 4.398553265679268, 11.895756413859706, 7.601502893432495, 3.98780805449332, 40.49011738069596, 66.32517722345167, 58.73023694561374, 55.21641300570581, 47.483597493940785, 44.98000352613388, 45.3068232536316, 43.52102694972869, 41.358738022465865, 40.8278295301622, 43.60558540590348, 45.89918351942494, 46.31606086607903, 46.381635050619806, 42.59629288027364, 41.13409996032715, 41.06676070920883, 41.29369728026852, 43.6622283535619, 47.98461360316123, 50.446379415450565, 53.93776739797285, 55.7535659113238, 52.39288699242377, 52.697451191563765, 55.20379081849129, 52.6024043175482, 47.67384029203846, 40.07155733723795, 41.66555366208477, 40.490364490016816, 41.564882109242106, 40.93782847927463, 41.736678000419374, 38.85582262469877, 41.172700005192915, 41.70998234902659, 41.70673462652391, 39.61606817860758, 42.06832224322904, 37.148407043949256, 46.84938946077901, 53.86379149652297, 55.19908789665469, 48.806122656791445, 54.11606265652565, 49.5462150727549, 51.87510667308685, 51.647730796567856, 54.24829359977476, 49.88473130810646, 57.20389366149903, 48.031003475189216, 62.612818594901796, 26.680073699643536, 29.566887155655895, 60.78294661737258, 48.78728743522398, 54.993520398293775, 44.32692497007309, 48.45764752357237, 43.86838028507848, 44.61318346761888, 38.2605048917955, 41.036064240240286, 38.4826365593941, 42.03232272978752, 39.37641528344924, 40.559343291867165, 40.57580940185055, 41.41827175694127, 41.496224941745886, 41.16566719547395, 38.96562153293241, 39.84231833488711, 42.33135638698455, 41.077966920791134, 39.88184405911354, 40.80747242896788, 40.27023715357627, 41.26284391649308, 41.085415501748365, 41.42246477065548, 42.739898697022475, 46.175561566506666, 43.42165762378324, 42.748727952280355, 41.74066705088462, 43.301487968813994, 49.974702635119044, 53.60004740376627, 55.53436817661409, 53.43997939940422, 55.31035769370295, 55.29717068518362, 51.66673075768256, 54.90298424997638, 57.11265148655061, 55.56285242880545, 57.51189385690997, 56.13261984240625, 49.07476971226354, 43.04903245741322, 49.71219408896662, 50.7170896376333, 53.478375481021025, 57.9619622999622, 60.225256181532345, 57.85733699798585, 55.466911254390595, 24.221355568978097, 4.9871828671424625, 8.487370687146342, 4.322411235301725, 1.4748353318822, 0.06313228694301459, 0.5045030043730813, 19.208564527573127, 37.537631680888516, 29.292850763567035, 14.150623083114626, 21.02043282601141, 35.63979679538358, 44.25821288939446, 50.51358530598302, 55.49140253374654, 20.97039907209335, 0.2125356655808226, 0.06180170330128843, 0.02841310560583107, 0.05696487695639653, 0.031286393059417605, 0.0318021196196036, 0.037285246465715675, 0.04637902422297386, 0.07163042367826547, 0.02999709772637054, 0.024693980475046465, 0.08252479151011476, 0.0632378806720578, 0.03802488903484998, 0.11881026259112744, 0.026384753760911768, 0.03792679147614587, 0.056551250764319015, 0.10355542188570385, 0.05552017685746955, 0.16464806101735563, 0.036897341675695874, 0.04223336623380742, 0.024585082991829803, 0.05190232663505501, 0.03359183316088973, 0.10007015850034454, 0.03619067919170184, 0.07415920330752289, 0.10715003666137496, 0.08696074702686842, 0.3830493553992241, 23.554944876701605, 65.07299192490117, 65.52443319751372, 52.98101894317135, 29.306673196054277, 17.571459393347464, 41.55894364080122, 42.53005189280356, 50.67289237053164, 23.776419547296342, 0.044636599374033754, 0.1652869170591716, 0.9401548065004811, 7.111220840484866, 12.651062723129028, 8.057704942841685, 4.81373026486366, 43.13432047444005, 66.16701941336355, 60.665808954546534, 56.88343209605063, 50.64973861940446, 48.10424981578704, 47.387875972255586, 43.84407335712064, 43.454452560793975, 43.26690443100468, 45.456426374373905, 48.111929816584436, 48.16041031191426, 47.50575104067403, 44.02940534776257, 44.096038572249874, 42.255070209503174, 42.68635834417036, 45.335040784651234, 50.35491366540232, 54.364113346222915, 55.45011958768291, 56.22209695077712, 53.507577526953916, 54.31117311600716, 57.37390879661807, 55.13880891184653, 49.465979068509995, 42.18420866997012, 43.8227552752341, 42.19171216410976, 42.350019024264434, 42.327716427464644, 43.42290101512786, 39.990748666947894, 42.34688505049675, 42.4353031189211, 43.71250921680082, 41.99132611674648, 45.725861826250636, 39.08155502811555, 50.3177256737986, 55.93273193605485, 56.234585777405776, 51.5289378935291, 52.48994211996756, 50.783471830429576, 53.216035596786014, 51.56427060404132, 55.667493420262495, 51.952377365481475, 59.515518988332445, 50.03082390754454, 61.38951370793005, 28.186128524041948, 31.993543832532822, 64.12268400192261, 50.87523175824074, 57.454642941874845, 46.64695985855595, 49.8022791647142, 46.7975906402834, 45.66336277992495, 40.90664171403454, 43.25647877108666, 40.1197789561364, 42.82960330286334, 40.20738509393508, 42.967568751304384, 42.333490156358295, 42.89161205291749, 43.434699504606186, 44.287760103902514, 40.78983745267315, 42.14509479461178, 43.624785407896965, 42.92851763386881, 41.28280093592983, 42.50050075592534, 42.618866120615316, 42.473032397608605, 43.279648211694536, 43.12818196512038, 44.503980759651434, 47.84738948268276, 44.975175088451756, 45.281210176406375, 43.88113975524903, 44.169751674898215, 52.47724933008994, 57.19657059638732, 57.04114667830929, 52.86177496756277, 56.7103849687884, 58.46976410958075, 53.95805781887424, 55.981145751091745, 60.362711721850985, 56.94657441108458, 56.97830246340845, 58.13555071430822, 51.867501197322724, 46.00599358158727, 50.564972277610536, 54.75561295786212, 55.256413336723085, 60.35958559282365, 62.75634988661736, 59.594339016945135, 56.08112696678408, 26.314181281674294, 4.949870830582035, 3.314137545324141, 6.3597461965776265, 2.9620815332858794, 0.04077649299776362, 0.3312105144704542, 23.021349560829904, 41.601430754507746, 27.743181144037557, 19.68372633380275, 30.7149217590209, 42.488219814915816, 51.462332125633, 57.48451179073703, 62.52233343739664, 27.71720720875648, 0.43203127059725027, 0.10654182413653021, 0.04164951530495479, 0.01774078069795524, 0.05065396337980225, 0.007598200322864878, 0.049585841460934574, 0.024648714254820542, 0.059960579514623656, 0.03608954409437795, 0.03310994853475883, 0.047985740426567294, 0.038521808136494896, 0.16020113512152628, 0.02526781480428913, 0.08658074443378756, 0.17051820973715476, 0.20272359612487978, 0.2317012089394754, 0.14891169574712554, 0.20242869823930726, 0.0899260895206563, 0.23292557066006048, 0.15470535824856452, 0.14780042392592277, 0.09801096012515408, 0.2331767096033981, 0.15515488332077382, 0.18191148466881246, 0.15195278901486628, 0.19053034153917145, 0.44549253859346916, 33.463830563329886, 72.24273158657935, 73.22210035016461, 58.15079696716801, 36.713902565740774, 31.157457290157197, 53.46179169993247, 57.905193836458274, 58.27891334410637, 28.644406487864835, 0.30701828519663504, 0.43583250694697906, 0.8789646060716723, 13.814886827622692, 25.889896538949785, 18.356309975347212, 9.920364502937565, 46.09652188516433, 70.33945637364542, 63.97290437452255, 60.14081539646272, 51.882743527812345, 50.129400914715184, 49.31363028864707, 47.993085922733435, 45.70947024130052, 46.68226119010679, 47.90702912115282, 51.89303190477433, 51.79176807403565, 50.08123028662897, 45.451778365719704, 45.66486504770095, 44.289544782330914, 43.99962671341435, 47.6809750833819, 52.550028908637266, 55.38777351379395, 59.034926660599254, 58.89452149791103, 55.62235870668965, 56.481722554852894, 59.512098681542184, 57.79146863568214, 49.92168787987002, 43.730807073654674, 46.17491437542824, 44.47320192090927, 44.240856401381954, 45.24494001942296, 45.182158562444876, 42.515947049663914, 45.41299396945585, 44.49974067749516, 45.141514962719334, 43.84690923075522, 47.58789723919284, 41.32172261514972, 52.11532438955, 59.82077744699294, 60.256223294042776, 54.66365691154234, 53.992021622196326, 51.49664501990042, 53.06584019814768, 52.36633254635719, 56.97026552692537, 52.692061854947, 61.954032990240286, 51.674544119065814, 62.25889136714321, 30.463421344757084, 34.29201549099338, 64.20179820829823, 53.399222050943685, 58.28180413092337, 47.35947801220802, 52.933585720677534, 49.45377265253375, 47.96936735030144, 42.33114457899525, 44.716275122857866, 41.547376571163056, 45.8293810198384, 42.18178464520363, 45.320433878129535, 44.27043499485139, 44.525428279753655, 45.97076285269953, 44.91476274305775, 44.48979354673817, 43.91481722554853, 45.26306921435941, 47.17038839094101, 43.27888727188111, 44.720342620726555, 45.7309962088062, 44.92683187607796, 45.26691313712828, 46.422835626909816, 47.614777241983724, 51.91389499172088, 47.11771488189698, 48.352445633180686, 46.13601230805921, 46.84681638594597, 55.668776035308845, 59.0453483981471, 60.118414740408625, 53.16016927842171, 57.677402188701016, 60.94796465289209, 55.34527855534708, 57.85831759052893, 62.73969550286571, 59.92810526201802, 62.25490231667796, 60.968725758214156, 54.457834459120235, 47.95121854351413, 54.11335622110675, 58.01311392937937, 57.80915852515929, 62.68309177890901, 64.28151645968038, 61.71705515153947, 60.8239471527838, 30.46401558383819, 8.66277123651197, 17.070839443514426, 10.214716811333934, 2.516624326667478, 0.1164529181175655, 1.0160700748524358, 26.130098565932244, 50.78141650845928, 41.022928222533196, 23.3643098415867, 31.445133724520286, 47.00197358285227, 59.398138138555716, 65.3905705482729, 71.05822286298199, 34.91091843574278, 0.7541883111961427, 0.1751635064400973, 0.14567118979269458, 0.10025672389254456, 0.09610327095874856, 0.13099709736003032, 0.15515663000124116, 0.11711121747089971, 0.14148819650853836, 0.10508686228985749, 0.10203081498583479, 0.12371336320234884, 0.19727024520116468, 0.2827645543842547, 0.20768957723292614, 0.1620944907828685], [0.02638697350067237, 0.07911242139075073, 0.03070220888231791, 0.018067856191567356, 0.029598458129311764, 0.01427584258283699, 0.01873066588755577, 0.05483469287414224, 0.017498231515468612, 0.05583361407080966, 0.03781819468243949, 0.03488198651241199, 0.0275145246902661, 0.11121411777792439, 0.06970722123139328, 2.5026263681150254, 37.48426391232399, 59.82557450571368, 49.58871787594211, 40.61129116242932, 43.37340070355324, 29.234993842340288, 40.23835612881569, 37.66259839457851, 45.012025756220666, 8.318839188544981, 0.19967586853571478, 0.05380391391114362, 0.6531997818139292, 3.813928649310143, 7.469629376165329, 4.320207353561155, 4.17789101600647, 43.85424798534763, 62.01392366040138, 56.94003582000733, 51.79880088375461, 51.45127104174707, 52.44023000040362, 50.111103057861335, 48.36142001613494, 48.18401513561126, 49.96754430955457, 49.31653284257459, 52.5585247624305, 53.31924100075999, 54.32773336287468, 52.35029397472259, 46.08329565294328, 41.58539610524332, 41.009968711483864, 38.62016662474602, 41.84151118801486, 45.4871149986021, 50.88952879751883, 54.255895153168716, 55.5041031683645, 51.695654315333215, 54.1464610253611, 52.680820342033144, 51.925552275873, 49.14598818748228, 47.223838529279156, 47.252809155371885, 44.42451353996031, 41.62804011375674, 40.46332759241904, 40.13781793655888, 41.77407387764224, 41.39909136679865, 40.70165472645914, 39.99630274311189, 38.4093431503542, 40.68893055762015, 50.206561780744984, 54.30679967326503, 50.05445226546257, 49.83521138468097, 55.29532324883246, 53.09634447097779, 53.83878246430428, 50.793638613916215, 52.98946380615235, 49.049729301083474, 53.66541762505808, 47.62517544531053, 58.4356394890816, 28.993805339259488, 34.68413875948998, 60.462336001857636, 46.74621543576641, 54.15820460165701, 41.0700241211922, 41.579006564232614, 37.8347590661818, 41.514040347068544, 42.405999091363725, 45.32672535988593, 41.66833462253694, 40.628871225541644, 37.830122824638124, 40.111267412862475, 38.13181192644181, 41.549926111775065, 39.165250562852435, 40.57623301782916, 40.542084863108975, 41.363852793170565, 39.109062610134, 40.20794207049955, 39.5994451738173, 39.21158159932783, 37.144010066986084, 39.789558533699285, 39.81220629907424, 47.047123985905806, 50.489776519037065, 49.81842756271363, 49.099535557531546, 47.220469213301136, 43.53939148687547, 43.5494052979254, 48.92517443626158, 54.148998798862586, 53.939304967080396, 51.49491525465443, 57.08437119760821, 55.24217905536775, 49.82959455059421, 47.95305813512495, 52.95886147406794, 56.61868387652982, 57.00190336473527, 50.30386009523946, 41.96178282460859, 47.39595997718073, 54.02218464882144, 58.4214718880192, 64.60435890382337, 58.94782258618263, 63.75712302423293, 59.757070310654186, 63.61030870868314, 43.96054421701739, 7.930151426023054, 4.657783690960177, 8.635237178494855, 6.098558998877003, 0.504567202541136, 0.04703482996011454, 12.700177661834225, 41.31285805856028, 43.01955976793843, 29.120009560738843, 13.819536797461973, 29.305633767958614, 38.06141322658908, 53.52940943933303, 47.50304068288496, 40.40707688177786, 5.2024675473090145, 0.21616126861303084, 0.05247893803302319, 0.03496095485564682, 0.01824619954512004, 0.07803567715229527, 0.0780929881899107, 0.017556806598159096, 0.030392977491682096, 0.0331172646744357, 0.06266021590319372, 0.020691791601899653, 0.07298899634230523, 0.04545272050064899, 0.06713090584643426, 0.06393266113234625, 0.05464581389641089, 0.0423749660952918, 0.03670317286084737, 0.020268141149332928, 0.014092812686407519, 0.03471494487096225, 0.01475154679463876, 0.028095977763915737, 0.11180605859525743, 0.035113712787748344, 0.08087536590474267, 0.03801445874776091, 0.0870223481568598, 0.08507859157097918, 0.08450999345269897, 3.21220544076735, 46.19598142562374, 65.30073258184618, 56.1567267294853, 45.948930940320416, 47.756010024778305, 25.24109140519173, 40.21223706583823, 38.681061421671224, 52.4868473699016, 9.784542629795691, 0.4128588477690374, 0.24488904483376012, 2.3210480857279996, 6.386893901132769, 8.843711153153452, 7.677105107615072, 6.086556055853444, 45.90028962781353, 64.36557677484328, 59.76835104726977, 53.361261352416015, 53.24477872540874, 53.793098618907315, 51.06332901985415, 50.16855793614542, 49.99786815335674, 51.218184194257184, 52.16584451736943, 57.19701774658696, 55.904326131266934, 56.179021481544744, 53.93572776548324, 47.53073653867168, 42.07562177411972, 42.4952918483365, 42.47234990519863, 42.35472979084138, 47.03414094063544, 52.85081978767149, 54.912829399108894, 56.209051147584, 52.8147888952686, 55.24226534751154, 53.464796235484464, 54.38018329681889, 51.053970244623, 49.09824117537468, 48.61108279997303, 45.35896724270236, 42.783668425775346, 43.38430881500245, 41.691747250095496, 42.903277181809955, 41.70642083691013, 44.11038267997004, 41.63048375037409, 39.50567307010774, 41.82504115566131, 51.631401969540505, 56.0570671481471, 54.15615320205689, 51.068620297216604, 57.08159415952621, 53.67727887245917, 55.12365679587088, 52.053731410734116, 54.171517126021854, 50.014585295031154, 54.9142453747411, 48.4663434182444, 58.54988244272048, 29.759995245164443, 35.914825547126036, 62.61240282366353, 49.39741603789791, 54.728309339092625, 42.27775327620968, 44.061164779047814, 39.86813929773147, 42.927078124015566, 44.76226491312827, 48.12099833642283, 43.77099960081039, 43.35460862805767, 39.64738438206334, 41.418981705942464, 40.82013776225429, 43.128715407463815, 39.9606248640245, 42.771297270251864, 42.9102982244184, 42.94009647061748, 41.77794525700231, 42.806932003267356, 41.041786978321696, 42.041681505018666, 38.461883298812374, 40.44238213569888, 41.77527020054479, 49.51321225012503, 52.55555160583989, 53.42238756918138, 51.13798349134384, 49.04800738057783, 44.4518603048017, 45.157396639547045, 52.48208169014224, 56.827624613238925, 56.28382721254903, 54.3014064142781, 58.076699472242794, 57.55220405517086, 52.43537018376013, 51.347740081048784, 54.88338024385514, 60.352176235568145, 57.92047931301979, 53.46918929007746, 43.24218957654892, 50.062238170254616, 56.44368340892177, 61.09679114434027, 64.7644700542573, 61.82481834965368, 63.72737576884609, 60.61603799943001, 63.4180498123169, 46.11405095746441, 10.585097401372849, 1.00627665197657, 3.4963779728258815, 5.6061490601108925, 0.8876875283256654, 0.17549934406434337, 14.902251189754857, 48.398482491893155, 31.21137615173094, 28.60530241843193, 21.15352080714318, 35.89725332875406, 44.48217630386353, 60.85144689006191, 54.003522011541556, 50.32574299843081, 6.6666294970820035, 0.13913989187248293, 0.012978383625346809, 0.06666939915908922, 0.033336722051664706, 0.10513512582908716, 0.03520084762825601, 0.03840624377311718, 0.01036692204164161, 0.04144571293445845, 0.05529118168558325, 0.019264075672253966, 0.054252979330598354, 0.03258336267824615, 0.05376694633835747, 0.04362175887029979, 0.14399768604386237, 0.13792208786452972, 0.07384121553191254, 0.11501724636482616, 0.19692545966996303, 0.0966529926705745, 0.07577578672358105, 0.15710572621995406, 0.20803931169211867, 0.15275253884253964, 0.07206145538798264, 0.12956989087885426, 0.16013375002770655, 0.2539143879567423, 0.1966722829327468, 3.9887594744082424, 54.82172450711651, 75.0077123026694, 65.28516077226209, 54.5061109912011, 53.908133891321, 41.22095300305275, 52.96693763425274, 49.01920149403234, 58.38151862544399, 9.670009420764062, 0.4621104872034442, 0.39112471885258154, 2.5427541761629047, 11.44316686737922, 13.184961042096539, 13.139586083350643, 9.198753314633525, 47.98828101927235, 66.41295986790811, 63.527668291522616, 55.95617202020461, 58.110302417509025, 56.57947194191718, 54.39470391119681, 53.41058515733289, 51.79089338548722, 53.73051328043784, 54.63988734829811, 58.47389044300203, 59.6960735321045, 60.01098494375906, 56.77641022589899, 48.6657488730646, 44.24385701456378, 43.66881401308122, 42.75036358064221, 45.361779582115915, 48.56026064965033, 55.12734382383285, 56.845902858241914, 59.590397034921956, 53.992398169732866, 57.489493200855875, 57.829244982811716, 58.81330882349322, 53.76529685912594, 51.49293445771741, 51.50019868727654, 49.996024639375754, 45.57099488473708, 45.15467843701763, 44.6998639260569, 45.120832304800714, 44.59298326123146, 47.46040844148206, 43.25338402102071, 42.350642681121826, 45.067990133839274, 54.557337145651545, 58.242003840784875, 56.1490192720967, 54.80115559793288, 60.07686899554346, 55.543252345054384, 55.46023538035732, 54.26364183425904, 53.621965608289166, 50.39425896060083, 56.25740220469814, 48.91597255583733, 58.375321280571725, 31.799798357871275, 38.946394074347715, 62.69836548836001, 50.46160213408932, 57.39861972870366, 45.38081092219199, 45.51041779979583, 40.98277099670903, 45.8341270877469, 47.221414504512666, 49.22754210810508, 47.29935592220676, 45.14332317536877, 41.82469990945632, 44.183428979689076, 41.85067776710757, 45.64215452440324, 41.76732740094585, 44.948773614821896, 44.84386590219314, 44.83547203002438, 43.70943015621555, 43.025596295633626, 44.311235489383826, 42.70112214549896, 39.91761607508506, 42.59870906029978, 44.0117193806556, 53.32348892765661, 55.63710289616739, 54.75407538875457, 54.42325876605127, 51.17412028774139, 48.28317265356741, 46.08767301805558, 55.86609478919737, 59.45068613175423, 58.40481358189737, 55.27309125469577, 59.133531124361106, 58.892768198444, 55.304089746167584, 53.18373487841699, 57.54010354318927, 62.346768148483775, 61.61700333318403, 55.51384633587253, 46.325031326663115, 52.552315650447724, 57.74140742517287, 62.46607488201511, 67.55112971028974, 63.72172363342778, 67.93037583751064, 63.639969671926195, 67.25638712606123, 48.72429417025659, 14.058563093985281, 16.892332376972323, 17.796272000958844, 10.304030160750113, 0.9880694386459167, 0.2741801714704883, 17.985549895994126, 59.28970421514204, 57.34266711819557, 39.23920685245145, 21.729764053898474, 41.231912105314194, 50.073954289959325, 69.39026632616597, 59.48441459286598, 60.307990735577, 7.993443281419816, 0.44837514359143477, 0.15799909199197448, 0.1990464966624014, 0.19267436116933825, 0.21993469597110826, 0.23200269518119676, 0.12294981868997698, 0.1797760452233976, 0.10868803477816044, 0.1384257140659517, 0.10586955133945712, 0.24237250728953272, 0.11862681517677924, 0.17399269426541944, 0.1361754533624457], [0.01932400481535062, 0.06569402367477456, 0.06308621058480875, 0.041964875398984844, 0.026197487398261027, 0.04242319516056488, 0.008266852875690787, 0.04202337770332252, 0.07389026814170423, 0.0263919185982236, 0.024581311924022534, 0.07074121010279463, 0.07990172177913689, 0.008796843993026883, 0.07489295466051948, 3.7219404885845804, 41.60755357434673, 57.37925890953311, 51.88898794112667, 36.122099276511904, 33.89348699200538, 29.382931916944443, 37.012751871539706, 47.011293134381695, 39.13598183662661, 3.30285509267161, 0.24127513230327638, 4.444954904817767, 8.095518062191626, 3.4063767377407324, 8.926109363955836, 5.311628089797113, 3.190603477339591, 41.783762131967855, 64.04074961139311, 55.22786632660897, 57.65540945914484, 59.07336588828795, 58.35949451692643, 56.78598473148962, 56.379748775113015, 55.51545058527301, 56.65725646480438, 62.35935111199657, 59.259635325401064, 56.50772394672517, 57.39572894188666, 54.15218376344251, 47.930814373877745, 41.634664996977776, 40.578668809706166, 40.0185739609503, 44.0753637590716, 41.85590628654727, 47.9682965432444, 50.41540838056996, 55.30314837732623, 49.587011644917155, 51.5904994933836, 52.3060731733999, 52.66474646906699, 52.24454295250678, 53.54544016622729, 52.18770388633975, 50.18057215598322, 42.72927299622567, 41.56362302841679, 41.30283248039984, 39.09019208723499, 40.773438022982695, 40.29724659458284, 39.919883205044655, 41.795905790021344, 38.95163043852776, 49.23832470370878, 52.135916832954656, 56.486931462441724, 52.83603245212186, 54.099227843746064, 53.779527218111106, 55.786619724765906, 55.975081766805346, 57.89135179212017, 53.05683443623205, 56.394261544750584, 51.995025296365064, 61.40267718222834, 29.785990753481467, 37.09789868324034, 59.128184933816236, 49.85088125351937, 51.632045238248764, 39.60901575703775, 44.31486760416339, 44.81488743136006, 49.504590880486276, 50.02304584749284, 52.59811716694986, 51.954770011286584, 52.258863526005904, 42.40171194076538, 41.51285186890633, 40.353336488046956, 39.10682293676561, 39.72638483970396, 40.788311650676114, 40.56081025831161, 40.72561648584182, 40.896686738537205, 40.539978550326445, 40.85961249566848, 41.09548030361053, 41.44555576385991, 40.99704842413626, 48.298877823737364, 53.80475982542961, 53.68931662651801, 55.5994128411816, 50.75292441152757, 50.93490277567218, 46.79919488968388, 50.2732930644866, 49.61568809324696, 53.38962401113203, 52.8509178469258, 52.57617150583575, 56.23571934238557, 53.008856004284276, 51.09806160773001, 45.91042110996862, 49.31025705029888, 51.287920013550796, 47.70301095900997, 42.17037054800218, 46.970308288451164, 55.19476936709497, 64.27570742945518, 47.82377289187524, 38.240206626153764, 65.72709421957693, 55.42272575439946, 62.61087309929633, 55.9710927163401, 64.65787572245445, 23.188724940822972, 2.5552403061620654, 3.0435033190634946, 13.495359766867853, 3.9782874814925657, 0.442705265576801, 5.302189886569977, 32.73761157066592, 43.89763332182362, 36.577568823291415, 23.128438111274477, 28.999441785197106, 40.2545202162958, 46.46808016684748, 49.99700130954866, 53.397009834166504, 8.715388851781046, 0.15583362189992783, 0.031395890006435015, 0.018889429948983655, 0.0722174768546416, 0.06497207773669113, 0.07731563877314329, 0.13378881368665926, 0.0381252963486458, 0.027951558698870005, 0.05007481240036507, 0.057044017669414325, 0.024734523763219197, 0.02412580562034442, 0.01565198164298049, 0.08206751362811174, 0.01759099518699992, 0.03308749449769816, 0.04806061019940723, 0.03968622730744462, 0.015538298025456889, 0.06329306581568334, 0.034322638905817465, 0.01277373568530405, 0.01995342648437908, 0.014264078345149757, 0.04989948551801424, 0.023004185866504427, 0.036769834001578634, 0.024215390026989966, 0.051798935408794114, 5.2889616931638415, 51.01637824889153, 64.9150106214708, 58.45060333128899, 42.84408469353953, 39.564587070095925, 37.550669639341294, 41.219748835409845, 49.85994977335776, 45.28764286348897, 3.7082291082028425, 0.41507265800910614, 5.914202697815434, 11.820644005652397, 6.345405520931368, 8.954408284156553, 7.886895527762752, 4.53144169622852, 40.50760722929432, 67.05793872956308, 58.13552325771701, 61.98019519928963, 61.423038205792835, 62.04489469528199, 60.10738895785425, 58.35013966406546, 56.89725845090805, 58.29927829004104, 61.43176155705606, 63.28275942033338, 58.549698091322384, 59.4359419422765, 56.228098177140765, 50.163184289009344, 42.45276943329842, 43.789960338223366, 41.43062722298407, 46.025020999293176, 42.556182722891535, 50.65264117333197, 52.21373273480324, 59.027956608803045, 51.10278806378765, 53.60185953878588, 54.76869798475697, 55.795660788013095, 55.36312926200129, 55.85906982421876, 54.546907563363355, 52.38585810507498, 43.50702408821353, 43.46206980366861, 43.73387828949959, 41.203580825559555, 41.240058868162095, 42.444932537694136, 41.89765207229122, 42.90927448580342, 41.587098413898104, 51.01589187499016, 53.05219819468837, 58.549533351775146, 55.015199338236165, 57.337815146292414, 55.19448695644256, 57.00521776753088, 56.13252570552211, 59.59851634117865, 55.200951022486535, 59.438840573833836, 52.91298543253253, 63.55231646568545, 32.26908837595294, 38.5515800599129, 59.748856867513354, 53.21984421822333, 52.69598814748949, 42.515958816774436, 47.16639934047576, 48.03128196347145, 52.551617468557055, 52.821288262644124, 56.356038047421364, 52.70742577891196, 52.95988521268291, 44.03839149782735, 41.7168386520878, 41.00495984477382, 41.68785233651438, 41.356031587046964, 42.7738703450849, 41.56899275318269, 43.10802882717502, 42.21338718168197, 42.173127974233324, 42.75221101699337, 42.692885168137096, 42.94550934145528, 42.50800425006498, 49.93502001608572, 56.22295987221503, 57.12146112995764, 57.648557078453806, 54.23419267900529, 52.72067946772422, 49.470019109787486, 52.036775004479196, 52.03360965175014, 55.908283802770804, 55.2464936625573, 52.41511114182011, 57.53937005996705, 54.745473630966686, 53.05965854275612, 47.339399399295935, 50.382150603878884, 53.032778539965236, 50.51162412089687, 45.0727048227864, 48.10018231791835, 57.17578203447404, 66.27943454250213, 50.72593458237187, 40.94348453706311, 66.8043496531825, 58.5989159922446, 65.0378788671186, 57.57480475210375, 66.35855659361809, 25.52617515287092, 1.7993473574038477, 3.29864320255095, 19.695636610830984, 6.081572684549517, 0.46840475751988353, 5.030493678585176, 38.58492020637759, 44.59815294511857, 35.132846140092425, 23.64751869632352, 31.867622021705877, 44.694219635378936, 53.08564816751788, 56.05597672923919, 62.32050003543977, 11.944573252431809, 0.12556413203598032, 0.08398012873987037, 0.030545729678124193, 0.0372057150478565, 0.047787507515280485, 0.08426017218059109, 0.051124199639044465, 0.005454466539254833, 0.06770080631418575, 0.04684133147219977, 0.05628695426088187, 0.016205002320930362, 0.024114000205431255, 0.03352269372572342, 0.044915589443858595, 0.10619726843170582, 0.08990227950796967, 0.2255080009420072, 0.1042322529059264, 0.14494195069757201, 0.17233461952738224, 0.128273899937349, 0.10355614200835267, 0.15364212014021414, 0.10986660742351126, 0.20711850465065051, 0.12184024758396611, 0.2061726312122999, 0.0849767248596876, 0.09478376877884712, 7.327516511563332, 61.25933024191088, 72.58007895561957, 66.18041038513184, 48.877576474220525, 42.87107844506541, 39.54538706810244, 46.75106348529939, 57.82540498241302, 49.44015418329547, 4.395777208189811, 0.45595530781053734, 7.258639691337463, 12.513749368729131, 12.8923894897584, 22.80649781227112, 12.131596765210553, 7.152012509684409, 46.27582127048124, 69.93098074390043, 59.39025417450936, 63.3864825771701, 64.92304755795386, 64.49957670704012, 62.03412386678881, 62.22784580722932, 59.68090180427798, 62.133191170230994, 62.30700708204701, 65.35137430314096, 60.29303081573979, 63.01313961705854, 60.17128436796127, 53.52107832508703, 45.63027366515129, 46.362646856615626, 44.23325092561784, 48.62799998252623, 44.35182025355678, 52.78774415293048, 54.779672776499105, 61.74212301931074, 50.96763103238998, 54.274224388983946, 56.86999405584028, 57.51368245770855, 57.522562703778675, 59.344064343360166, 57.55052135836694, 55.11942455845495, 46.75050258636475, 45.33226374656924, 46.004055930722146, 43.62697016808295, 43.97104047959851, 43.63673686981202, 44.33898625835296, 45.9823848355201, 43.12713861465455, 53.98771485974712, 56.335375001353604, 61.82826219066497, 57.85132400451168, 59.138936150458555, 57.78673041251398, 59.64617706114247, 58.61633131580969, 62.09683079873363, 58.23965826342183, 61.49232295251662, 57.50891677794918, 66.45626283461048, 34.67356797187559, 40.605050671485166, 61.377385739357244, 56.209843466358805, 54.786784033621515, 43.52659671537338, 49.76744067284369, 51.1642006135756, 54.18743410418111, 54.881842674747595, 58.834144453848566, 54.24186875743251, 55.992979541901626, 48.02685752991707, 44.00386679557062, 43.33643628704933, 42.79262319687874, 44.911758207505756, 44.14179302030995, 44.90355653147544, 44.697930197561945, 44.58904520157845, 43.950965789056596, 45.1471592533973, 44.61792953552739, 46.033701204484515, 45.33971624989664, 51.899692089326926, 58.48913669586182, 59.04647019601638, 59.03811162517917, 56.80503960578673, 56.04039707491475, 51.9394806123549, 55.27708814990137, 54.48011744406916, 59.17337456057149, 56.48790421024446, 54.81154987888952, 58.85192848020985, 56.50180509013515, 55.7525029490071, 50.850634574890144, 54.123224904460294, 54.5470291568387, 52.47248757270075, 46.34033641507549, 50.821326624962595, 61.5943947915108, 68.08345810059579, 56.1461716313516, 46.84080731484198, 67.92204472326463, 60.07504509341333, 68.469403636071, 60.625996897297526, 70.54312152247276, 27.851771962258127, 4.858038338922686, 12.549213478642127, 20.985584528215472, 5.635970840531011, 0.6247380219640271, 6.6290139671294925, 44.99245705143098, 57.98974444789272, 50.7509514593309, 32.73707224476722, 39.22095606403966, 52.62582086747693, 62.52831897427959, 63.40764768661992, 69.80186416256812, 17.488493419462635, 0.36383902654051786, 0.15613575165550556, 0.17404108037871702, 0.18286209253053512, 0.2458822318623143, 0.18648838504187523, 0.22094510465620026, 0.09146236393961216, 0.12745278391746745, 0.1192710031905482, 0.13497899256406293, 0.20739207464841106, 0.11673745083352251, 0.1339529710070741, 0.12757503622842412], [0.08241155605402686, 0.0023551795569684117, 0.013142356127049896, 0.07046865900197337, 0.06065906784046562, 0.01699827104476431, 0.02069711399775359, 0.03890047390614787, 0.12080135574984936, 0.021607310721470464, 0.019865552369024486, 0.04647720222091002, 0.02569786400624341, 0.07703741096080312, 0.029895292302112908, 9.015169720495901, 44.272298120683246, 53.5572974912582, 45.597486572880904, 32.849332440283995, 10.846268419296512, 18.099220183587846, 21.779921362476966, 44.17970665039555, 27.823089630373065, 1.1850810219203274, 0.18183737332301755, 8.586046734163839, 20.330154511236376, 4.3629729555499175, 8.495350749261918, 5.160864437780073, 4.175163988144168, 27.586945295333866, 66.5011033704204, 55.559259537727606, 63.438348077958636, 49.80545628455378, 56.77719469993346, 54.513732156445904, 59.20387491103142, 56.68041021593156, 62.10302814360588, 58.491274387605735, 54.679742551619015, 56.91005714478032, 57.741583931830625, 49.284753799438484, 43.42907874814926, 41.23077461796422, 41.29085356189359, 46.81454704653832, 52.224362357970215, 49.9202169910554, 49.334650270400516, 51.91940592181299, 55.665194911341516, 52.62901367679719, 49.06260251998902, 51.32939907812303, 55.067241345682454, 53.27535752327212, 56.9873905950977, 53.13444637483167, 55.08570394208355, 48.076879516724624, 41.12727895859749, 39.30291398879021, 41.20621273594518, 39.9139682708248, 41.10171294981434, 40.071102342297955, 40.6892482696041, 40.17890084174372, 47.887546708506925, 47.63050202400454, 50.77435231977894, 48.248851914559644, 51.10732624607702, 48.14279886984056, 53.469287349331765, 51.62911522773005, 56.296398408951305, 50.65466119397072, 55.059216176309896, 48.498997149928925, 60.16176085318289, 34.53727737549813, 41.36914407053302, 57.4609265788909, 49.66290166301113, 49.47090164307625, 44.78579128942182, 52.389592201479026, 49.114620993214274, 52.84344965411771, 53.27889550116755, 53.56136891149706, 52.35729932785035, 52.60931553379182, 53.02691067418745, 46.89318664612309, 38.754456812335604, 39.76682447618054, 39.75919154382522, 39.137868496679495, 39.98839132247433, 40.00489273378926, 39.74813045993928, 40.06941964549404, 42.59885026562599, 40.00837579850228, 40.99800940482847, 50.835945298594815, 52.78394729860368, 55.25699776987876, 54.687179365465724, 53.76621861611643, 55.03316379362538, 54.22240987900765, 52.486721854056086, 51.01558985248689, 53.324445985978656, 55.664963491501354, 51.654026200694425, 53.27642833032916, 51.949455199703095, 55.70282220840455, 52.54105844805318, 43.56740505464616, 40.91275668913319, 40.20303518541398, 41.15766163795225, 40.114103286497055, 49.14241883062547, 53.768976042347575, 59.22123532141409, 37.73644093544253, 36.782332235767, 65.46565255811139, 56.45976120425809, 60.73843556065714, 57.001664100154755, 64.227219089385, 47.90636231822353, 7.638337381424443, 1.8700230746499955, 6.426026898045694, 6.042993232127159, 0.37345165266625346, 1.0535855230785187, 30.008663708163848, 34.342884709758145, 31.765097148956794, 31.48311011252865, 22.841628520719468, 33.39028612259896, 48.5111290408719, 50.5885535670865, 49.61330721455236, 11.555995806570976, 0.20836414829377206, 0.029997566955224163, 0.054968704634736625, 0.04547305247415939, 0.09571969073506133, 0.06965250723184117, 0.05102691413354009, 0.0779248089078934, 0.04253705880875069, 0.03828935024719085, 0.03014972350830513, 0.07080686383790548, 0.02952508222792418, 0.01756701088931051, 0.03091238701956407, 0.029135379046502135, 0.05178683121959048, 0.062245455900988275, 0.02260288985956821, 0.05844896929639001, 0.03909149793006721, 0.03244704882343931, 0.07133193284032807, 0.07254242836948364, 0.03188831983284364, 0.003080181467662295, 0.013536924924401027, 0.08079647417030028, 0.036872528087828434, 0.04327104381856419, 12.308011247265725, 54.146664988610056, 58.35650174848495, 53.116748640614176, 35.98102731089438, 19.430447124665786, 29.908166700793853, 26.662003340259677, 51.091370044216035, 32.989996479403594, 0.8636628271591279, 0.407249337482837, 9.906689159331783, 21.755404587714903, 7.9174537331827235, 8.862082554448037, 6.559602233671374, 3.7096781788333772, 31.135468482971195, 68.50577969704905, 58.922766485521876, 65.21799410543134, 52.555398633403165, 59.05279697910432, 56.41929411119031, 62.33367919921876, 59.68285906699396, 62.06067046811504, 59.841381657508116, 57.73973649547946, 58.79020998554846, 59.80919076550392, 52.402665461263354, 47.13007427030995, 42.350532854757006, 43.834188984286406, 46.570920790395434, 54.92616938006494, 51.663330062743164, 50.84892442149501, 53.921297365619296, 58.80304790312245, 52.707323797287486, 50.78733928741948, 52.86855282322053, 57.00997952492007, 56.12016239473897, 58.70401590101181, 54.70455154295891, 57.301925459215724, 50.58023814232119, 43.267775197182935, 42.103419611530924, 42.218164628551854, 42.35516517393051, 43.41180462991038, 42.20415784466652, 43.0471222631393, 42.71311283111573, 49.69112703877111, 49.65355073252032, 53.72590841785554, 50.36986181812902, 51.84299815085627, 51.93017675030617, 55.884282819686405, 52.38905091439524, 57.55623625170801, 52.69565866839502, 56.299626519603116, 50.8887953142966, 60.753164060654186, 36.77036900674143, 43.03068360974712, 59.856769115694114, 52.77680858489006, 52.38229659295852, 47.38564022125737, 55.78559206378076, 51.59150362014771, 55.69613064489057, 55.34281138450869, 56.30771052452826, 54.801312492739775, 53.77379271291918, 53.87826896482899, 48.37279488963466, 41.740113996690326, 41.579002641862445, 40.72003495308661, 41.10161489056003, 41.40615555547899, 40.92072302295316, 41.96194756415583, 41.333454424335116, 44.15448188781739, 42.30571193079795, 42.560571855114354, 53.41370736399005, 55.65750314343361, 56.92035728885282, 54.79884139953121, 53.56576196609005, 58.31858811839935, 55.90187072753907, 54.3331148547511, 54.09357963069793, 55.81975590798163, 59.62642008258451, 53.570688463026485, 51.76936349561138, 54.780994615247174, 57.770644772437315, 54.73276907397855, 45.10305220080961, 43.5329980234946, 41.53009068581366, 42.62131367960284, 42.685491500362275, 51.72639785274383, 55.71806453889417, 60.99211092918151, 44.12800196678408, 42.39602058164535, 65.44475809220346, 59.14710644752749, 62.904611556760734, 58.71673614748063, 67.2933280083441, 49.921040688791585, 9.93525872307439, 2.076087243133976, 7.598341463073608, 5.275012273942271, 0.301247559367649, 0.7281092073648208, 33.12316879149407, 40.35437983851279, 32.83226228529407, 29.78539651440036, 30.78513610747553, 38.71644904536586, 55.05940837244834, 53.31693072472849, 60.19623848699755, 18.328104211438088, 0.2758231236329002, 0.05989258155046452, 0.08264671440326399, 0.008204502894753411, 0.04947575845665509, 0.012475638425037747, 0.019714110192932913, 0.05503464565281907, 0.046818532695573185, 0.021129693205077803, 0.020484522683545947, 0.08198143598893959, 0.018199853140920885, 0.020418849796237006, 0.017218216803045045, 0.1660315698433307, 0.1433121139604238, 0.10923040204591329, 0.14799652711278008, 0.17502580979658713, 0.19180117415324335, 0.15454391287940164, 0.10517038119536255, 0.12132984150441424, 0.12210168274900607, 0.11228431962550649, 0.14395599553902305, 0.2987139227409517, 0.20322046543080963, 0.14242078598228194, 17.55848027044727, 64.2657720658087, 66.64750975947227, 60.90858013399186, 44.536603112374586, 19.210419808664632, 28.054456518542384, 32.67292972533934, 57.09478901278589, 36.954834153575284, 1.7785199395110531, 0.3709005798783995, 12.072352305535349, 27.588584846065892, 12.901857110761828, 14.580744312655542, 15.726703982199393, 9.565002668288447, 32.04766077380027, 71.20185221395185, 59.96276332486061, 67.29139820221933, 54.235000687260786, 60.269382845970895, 58.911289630397675, 63.11485059799687, 61.35077245773808, 63.47559098274478, 61.156513152583955, 61.17293611649544, 59.88033079331922, 62.77417313668036, 53.41366814028833, 48.80970770312894, 45.96272199384628, 46.03120265468475, 50.312167675264426, 57.02047970987136, 53.24243707041587, 53.98267853644587, 57.68005371093751, 62.13697625744728, 53.96605553165559, 49.33596818677841, 53.463901935085175, 58.40155409228418, 58.00018971966159, 61.39434999035251, 56.18248885677707, 58.5797748258037, 52.23956938712828, 46.953367571676935, 42.454491353804066, 45.31789610462804, 43.61057858313284, 45.863321288939446, 43.47353489168229, 47.41819197131742, 44.56399694565804, 53.031766568460775, 52.13873309473838, 56.26081858911822, 53.150783046599365, 53.3566015766513, 53.47002475492416, 57.75442969414496, 55.52668033107635, 61.44522313148745, 56.204140340128255, 59.55802963626001, 52.10045860659692, 64.10516277436288, 40.54255946989983, 45.62605711721605, 62.98287068643878, 56.420341384026315, 53.710156179243526, 50.216042149451475, 57.943609529925936, 54.137416039743734, 56.9191138975082, 57.22171298919186, 57.52696360311201, 56.5240566961227, 55.95934914004419, 56.409394048875384, 50.90914457075058, 43.411435927114184, 43.43155376372799, 42.87074896597093, 43.35460862805767, 44.37523288111533, 42.8002522068639, 44.58387551769134, 43.2383103524485, 46.372848941433816, 43.38008049995669, 45.54984154239778, 57.27846968558527, 58.73537132816931, 59.323369918331025, 56.20544648939564, 54.24388877807125, 59.19406898560063, 58.793406717238895, 56.56263320676742, 57.1635324724259, 59.931713842576556, 61.61408508977583, 54.32940821493826, 54.5854252384555, 56.414830453934215, 60.97977507498957, 57.39560734841132, 48.103657537891024, 45.4641338317625, 44.93990121349212, 45.782038011858546, 44.64535082540205, 53.95523763472035, 61.07280192836639, 64.74457579274332, 46.030657445230794, 43.18266760918402, 70.23459572945872, 60.64835048490956, 65.89079826108872, 60.93609163838049, 72.43453548800561, 53.29141570675758, 13.937121610487662, 5.477192805659387, 11.904771001108232, 7.945672735091179, 0.4249385528026089, 1.2208217815045388, 40.10118299914945, 50.69840738850255, 43.18748035738545, 42.22549553840391, 33.24470343128328, 44.353200927857436, 62.168704309771144, 61.71908693928873, 67.84836692194786, 23.682747464026175, 0.5222786037671951, 0.1652150273683571, 0.2618299454690949, 0.16068734048355013, 0.10030952267228596, 0.0972097240869076, 0.1698288838228872, 0.0751470277206071, 0.1787427458311281, 0.17051182056386627, 0.1598073659284461, 0.15609634409268058, 0.16103171232727267, 0.12978666311790868, 0.12373878966055571], [0.10474718656511077, 0.026021396343205726, 0.014439054742275227, 0.024909140099020257, 0.06130765702935958, 0.0305553421663541, 0.03445804111599442, 0.060006464350848436, 0.033243891347440026, 0.04833919807307182, 0.04181635393310459, 0.10141560041736211, 0.015418230022694317, 0.07643322039756083, 0.3942104903680663, 18.23945668435866, 51.15277082689347, 56.064029355202955, 46.168199277693226, 31.298699878877212, 17.113377548033192, 33.92861573926864, 39.171063515447806, 50.12421554134738, 21.405682140781035, 0.049938218923465866, 0.24760732397196755, 1.1555417747266832, 5.937620718632975, 5.526384230582945, 3.278934027879469, 6.14370547956036, 3.077968695471364, 22.803224594362323, 60.851917574482584, 56.414191107596125, 58.761513925367794, 57.0902822094579, 58.56943938039965, 52.219122071419996, 55.06412306139546, 51.65910959243775, 56.71964568476523, 48.40308735447545, 58.500688076019294, 53.46454912616361, 49.61049879750898, 40.60538799531999, 42.42142577325144, 39.20434482635991, 46.95589357806791, 53.63072818325412, 55.87197442208567, 52.596775716350926, 55.508166743863015, 52.377542680309666, 53.420222420846265, 51.7918033753672, 52.11195507357198, 50.51020422289449, 51.91325956775297, 50.578367171748994, 52.45679809201149, 51.49417392669186, 55.13159175072947, 52.283641138384425, 41.42090758969707, 38.33960340869042, 40.9485443945854, 38.90953163946829, 41.99313040702574, 38.687156784919004, 38.74179147904919, 39.88270698055145, 43.08438870214647, 42.60191755910074, 47.12852493409188, 45.70028405035696, 48.3153792350523, 45.19829127096361, 49.94579476694907, 46.7464429332364, 50.617939964417495, 48.009214708882, 52.946506008025146, 49.51255329193608, 60.475958393466094, 36.55911407163067, 43.13396746112455, 58.98157458151541, 48.31858381148308, 53.77243949520973, 50.25814094851094, 52.65122605908302, 52.44157145100256, 53.68103650308425, 49.771869028768236, 48.59511875337171, 48.71976775507773, 55.69585215660834, 52.9925310996271, 52.645267978791274, 43.76060139748358, 40.40781820974043, 39.444566465193226, 40.35330903145575, 40.33439144011467, 39.09729942198723, 39.714806002955285, 40.634668488656324, 42.64493419278053, 41.86699090465423, 50.506375989606305, 53.49957196943222, 55.03144971786007, 51.567985088594504, 50.85154064239995, 52.61432832287204, 53.68126400055424, 57.69381338550199, 56.973156313742365, 54.871307188464755, 52.33024281840171, 50.82286027169997, 50.24253775996547, 53.30472430875225, 55.289145515811065, 55.4696451464007, 49.34020042419434, 41.0550053658024, 39.39282648025021, 42.54868315112206, 42.91598566116826, 42.009788713147564, 45.61163063972227, 58.17415075917398, 56.44692720905427, 61.50969905237998, 62.32530886127103, 58.83622723241007, 51.03964182638353, 52.06037198343585, 55.47847047928841, 59.976750496895086, 56.532976165894546, 19.3118699519865, 2.0277143678357525, 8.455691664449631, 6.758262438158836, 0.09505196083937922, 0.13286276660378904, 14.20148837950922, 47.4083193655937, 28.943230298257646, 59.40558671951295, 29.732322923598755, 28.06680021747466, 45.842571950727894, 52.612233777200025, 56.72607052710749, 25.006971013161447, 0.18649282835183606, 0.015809821610849713, 0.021289566178776084, 0.031079972583440044, 0.0171782978765306, 0.02313930845458902, 0.013160308439945503, 0.0438047428014538, 0.04741591656760824, 0.03272676667679222, 0.08716739158356383, 0.061169305380674145, 0.03311547585913251, 0.040098317493233955, 0.01753813320500476, 0.03106100233121505, 0.02539190189582446, 0.01731776992880529, 0.03468437796278346, 0.058933393503989906, 0.03071411197344142, 0.0647927059101001, 0.0542799954212481, 0.05687483864265585, 0.029024836389468085, 0.033838965464383364, 0.08198012597858906, 0.13826468238426795, 0.046811446382273594, 0.23474020312630364, 26.07201610842059, 58.34870015421222, 63.01885058802944, 52.68553110861009, 36.3284198699459, 14.701651373217183, 32.45499107145494, 37.18108038748465, 58.21876379751391, 23.394388537253104, 0.10094747473035129, 0.07499395569245662, 3.593623825619298, 12.338019340269028, 6.590843421797599, 8.838601285411466, 4.948018491268158, 4.744461697916831, 24.794604086106826, 63.16958727375154, 57.58539122919883, 60.361072171118956, 56.80471012669226, 59.75591713382352, 55.30544688624721, 55.63765987273186, 52.516763287205855, 58.3757919649924, 51.699643365798465, 59.8427584094386, 56.4582863930733, 51.774807745410556, 44.5097231095837, 44.918567442124896, 40.05943721340549, 48.84284780871484, 56.70204993217223, 57.9289359431113, 54.75541291698333, 57.54870530097716, 55.381317292490316, 55.597039807227354, 52.06228217770977, 52.00471747306086, 49.84717069133636, 51.08836943103422, 49.637982845306404, 53.80535602569581, 54.246842322811005, 56.787490921635786, 54.01989006227063, 42.55153471423734, 41.49626808781778, 42.90202202335481, 41.75599175114786, 42.775878598613126, 39.9940905263347, 41.48690931258663, 42.40759549602386, 44.10260854228851, 45.20322953501056, 48.957679117879565, 47.56170757355229, 50.35122271507017, 47.778383224241196, 51.07970491532357, 49.99070590542209, 51.295035193043375, 49.51991558074952, 53.687163245293405, 51.1433453713694, 62.329529331576445, 38.300265958232266, 44.83492682057042, 62.23740070096908, 50.68143137039677, 55.63538882040209, 52.410827913591945, 55.91499497813564, 55.13710268082158, 53.49099374586537, 51.58195264877812, 50.1500992621145, 48.71552375055129, 56.27912036834225, 55.11676911384829, 54.14469595878355, 45.44626351325743, 42.214257947860226, 42.46438749374882, 42.38485359376477, 42.44920399881179, 40.83793355572609, 40.81699202137609, 41.71459897871941, 41.21753661863266, 43.33649512260191, 53.73006220786802, 56.617911169605875, 56.84608720964002, 54.456555766444055, 51.351089785175944, 53.76014678708969, 55.614098195106756, 58.94058581321471, 59.76542495912122, 57.74438058176349, 54.015093003549886, 51.18119624353225, 51.64490669004379, 54.17908337808425, 57.44421728195683, 58.3182547169347, 51.548106516561205, 44.138914000603464, 40.94067612001973, 44.550864850321126, 43.51455896131454, 44.88019097235895, 47.737986733836514, 60.80320173694242, 57.69827312038791, 63.26498716108261, 64.60634362313056, 61.26500591155022, 54.57702744391657, 55.13643195552211, 56.96469968365085, 63.95362592512562, 58.298533039708296, 24.63438310930806, 2.386795590000768, 8.916024950242813, 10.470234713246747, 0.1241922677464543, 0.05883899614996007, 15.437776311751335, 55.49807840777982, 27.916434195733842, 48.12507367903187, 31.72756987233316, 35.2779620693576, 53.016214370727546, 59.04896874581615, 63.008942680974165, 33.5440351886134, 0.27754875200410045, 0.015439553122456758, 0.07647239813400854, 0.021812572489462553, 0.02517991004541757, 0.013871632568958788, 0.027967012607522553, 0.039934278916447394, 0.035460099442711765, 0.04749622556471056, 0.025769966286456874, 0.04961953783828405, 0.004337516091313333, 0.013272746206982242, 0.02767890034573934, 0.22877599413116134, 0.08860891624804466, 0.08474976365124026, 0.12645057237316526, 0.23465907441512232, 0.16109272356956236, 0.11934798736605914, 0.21043666127708652, 0.1215156944348447, 0.15000301863878004, 0.12854100415302863, 0.2620075552934601, 0.18695629622426727, 0.1483696885406971, 0.4727658815681935, 33.42844293963525, 66.23537063598633, 71.69560801598334, 59.76609960679085, 43.55407291843046, 26.69191533519376, 47.56603787022252, 51.89565597041961, 64.31754735208327, 27.04061992706791, 0.21374780053813613, 0.3999085604183136, 3.120294011408283, 12.009229602352267, 13.342155910307362, 10.789812764813824, 15.375952893687835, 7.719009259054738, 26.672550593653035, 64.35806151359313, 58.446327947801166, 62.142777442932136, 56.1845402563772, 59.62332925488872, 55.143064683483495, 56.908225397909845, 53.3350795315158, 60.790069641605506, 54.88244671975413, 63.48075674426172, 59.56174412081319, 53.97958378637991, 46.01428939450172, 49.47589482030561, 42.48330900746007, 51.57083272933961, 59.27066110795545, 59.51948450457666, 57.51596135477866, 60.31228573091569, 57.771680278162805, 58.118096167041415, 53.03459067498484, 53.3232065170042, 51.16840931677049, 52.82716005079208, 51.44175144933885, 53.95715959610478, 55.011186753549886, 58.009419056677054, 58.03252573936217, 45.11891426578645, 42.10261944801577, 45.27346741768622, 42.536515958847545, 44.12800196678408, 41.80859073515862, 42.31745550709386, 43.72120903384301, 47.03808292265862, 48.22529023693454, 51.10808326352028, 50.46299065313032, 52.79711077290197, 49.70270587551979, 53.977046012878425, 52.50278395991172, 56.051246350811375, 51.82979937522642, 56.12309632762786, 53.41058123496271, 63.83827686309815, 41.47497354015228, 47.82237260572372, 63.943388538975874, 53.132940184685495, 56.85654817088958, 56.304458879655414, 57.13600135618641, 57.494251035874896, 58.00788933230985, 52.89762935330791, 51.669499951024214, 49.237563763895345, 58.970184018535, 57.21551956668977, 56.53283888293851, 48.28498478858702, 45.07414825500981, 44.99795621441257, 43.63112003572526, 43.33432212952645, 42.488219814915816, 42.55031093474358, 44.769635046682055, 45.42094461379513, 45.89087593939997, 56.79470808275285, 59.866629954307314, 60.0600028038025, 56.07095626092727, 53.1440757936047, 55.79686887802617, 57.225855012093824, 60.107573309252345, 62.12698205824822, 60.601682124599336, 54.77497377703267, 51.75963209521387, 52.12008614693919, 55.87220584192584, 61.01458611026887, 60.74069484587639, 55.276488027264996, 46.898905461834325, 43.80187257643669, 48.256708422014796, 46.91005283786405, 47.70205390068793, 51.15623427975563, 63.93506526947022, 60.74373860513011, 66.36894302983438, 67.28771901899769, 65.13145092994937, 55.006585813337765, 57.54818754811441, 59.75174765433035, 67.76046660638625, 60.39383180679814, 25.878243177167832, 5.047523138984557, 12.575423736726085, 10.304805809451688, 0.13733486614881024, 0.1473911184697382, 17.91382739620824, 65.03320732424336, 40.335905475001184, 73.69855065499583, 39.05113704742924, 39.06220989842569, 59.05928457936933, 68.59172667226484, 72.6730626629245, 42.7114026777206, 0.768140059325003, 0.10987239138733958, 0.17264093212302656, 0.13622668932282156, 0.09227719037763535, 0.1092787268721769, 0.1306331596307216, 0.11361624009066051, 0.14993666010277887, 0.09778007654653442, 0.26332341855572117, 0.10320915014392908, 0.14412865643539738, 0.09912246943361337, 0.1054274496592341], [0.07194956824664148, 0.037526548840105534, 0.036224670512902166, 0.04398252116516233, 0.056409643241955396, 0.020089253873354005, 0.018729989814962593, 0.026419166430470445, 0.015635067379222285, 0.05478314281771741, 0.024425566249016314, 0.006904122748246958, 0.011517773795452331, 0.022134666496347037, 0.5343669196290355, 27.506271946814756, 58.28836233385148, 45.820869476564475, 40.406088444494436, 26.503349350344752, 31.109641636571578, 44.973002095376295, 33.00403464225031, 51.192402455114554, 12.616132055559467, 0.19030287471269408, 0.20790493987019987, 1.3021265090473237, 2.2685376001942545, 7.3325214559032075, 8.583102014756973, 4.977674061252225, 6.417408960480844, 28.047627672072384, 56.70987898303617, 53.8329852011896, 60.681106198218565, 60.14594193427794, 57.496125928817264, 59.72140027630714, 55.98138893804243, 54.72868588662917, 55.97663110302341, 58.238387415486, 55.22519127015145, 47.31509639370827, 43.252638770687966, 40.41583161200247, 42.36339430655203, 43.06700867991294, 49.78352239055019, 52.033852838700824, 57.035733807471495, 51.80004819746941, 55.79971651877127, 52.11829362377044, 50.89145075890326, 49.65230341880552, 53.02454940734371, 54.41726538442797, 55.02380109602406, 52.40541504275415, 50.26450695530061, 43.901206601050596, 52.9790852146764, 53.03874054262715, 39.70526287632604, 38.19380106464509, 40.15899873548939, 39.920346044724994, 39.57035295424923, 39.24707904938729, 39.74871097072479, 41.4309488573382, 40.23186068381033, 41.60499226662421, 43.61777221002887, 42.70822948025119, 44.26940341149607, 44.42967537910708, 46.29406029178251, 43.76260572864164, 48.19498600498323, 46.011971273729884, 51.12296473595404, 47.90609559705181, 59.05511902224634, 39.468049695414884, 41.0510947627406, 59.55285603000272, 50.1814115432001, 54.8373394627725, 52.156458285547075, 56.48722171783448, 51.76089509840935, 48.05352180234848, 48.73353135201239, 52.961003088182025, 48.17320900578653, 49.448665726569395, 51.51175791217435, 53.30199826148249, 50.75897662870346, 40.86285237343081, 39.43851424801735, 38.925001467427904, 41.09446833210607, 42.0773240827745, 40.631401154302786, 39.44168744548675, 40.95328654012373, 50.108663343614154, 51.388434671586566, 53.487396932417354, 50.71712493896485, 48.92686497780585, 49.62324650056901, 49.666294513210175, 47.189910027288626, 47.10630470706571, 58.91002662720219, 52.340511583512836, 49.187176996661776, 54.86105803520449, 53.78551667736423, 53.029821072855306, 53.59293614664386, 51.14669899786673, 42.403877089100504, 42.70604079769504, 48.57028622781077, 49.7315941318389, 48.293849345176454, 44.048358240435206, 40.666184732990885, 46.30365048685382, 51.5829332413212, 53.3300353634742, 50.58203066548994, 48.32917421094833, 45.821583347935835, 52.438586527301425, 57.00570414143225, 59.20864843553113, 59.80484477935299, 46.168042382886334, 3.359819184387884, 1.5479114170997375, 4.436795884563077, 0.21828196852678255, 0.04363352598081674, 6.930382905467865, 36.70161377999091, 41.239364608641594, 93.28416870486353, 42.87444383867326, 22.031906189457064, 38.31972483665713, 55.045307451678866, 53.767187441549, 38.054988384246826, 2.8073977174297458, 0.09175337775940857, 0.07238043141701529, 0.045472792004265135, 0.03413839092958839, 0.05348698716730841, 0.038377461849801967, 0.03804246309183298, 0.04090615337894809, 0.03217307279907888, 0.09164148295718817, 0.07137387615418242, 0.07018263241456402, 0.05923664557837671, 0.006996278337488372, 0.07522733671770943, 0.023342107249904546, 0.09824763532848128, 0.06685892931155621, 0.06273308235611166, 0.04943936161937253, 0.01298742729329294, 0.0678027419733905, 0.0649282421856638, 0.04111897260431321, 0.019583455812666687, 0.03709879598670429, 0.03566806167063694, 0.01212247572238407, 0.612830380278249, 36.57800420638054, 64.11591006863502, 53.715259182837706, 46.96562105609525, 34.14765657917146, 34.853714589149725, 42.248323732806796, 37.581083697657434, 56.30978153597925, 14.153760979252478, 0.1583430807917349, 0.03132530841075125, 1.1420578918149396, 4.9175411847329915, 8.465657426464944, 11.497112204951625, 6.476790212815808, 7.2255819555251835, 29.49995779222058, 59.050949542753166, 52.75244674374981, 61.40044535360029, 61.01093046126827, 59.81623141996322, 61.35246299928235, 57.72538062064879, 55.597749756228545, 58.59566042500158, 59.2967801709329, 57.82695039626091, 49.691876211474025, 45.25440469864876, 41.69259840442289, 44.413734866726784, 44.076748355742424, 53.946898675734005, 55.10236617057554, 58.50206875031995, 53.59337937447333, 56.26416829324538, 53.88529785217778, 52.00922427638885, 50.61564930023686, 55.99480344403175, 55.6194051619499, 55.42159611178983, 53.6825034695287, 50.05058873084284, 45.18155059506817, 55.28661166467975, 54.07206150793261, 42.05940669582736, 39.26753813220609, 41.73329691733084, 41.56136766556771, 41.66765213012695, 40.452890165390514, 42.56744384765626, 42.711234015803186, 42.81410994068269, 43.674309253692634, 45.317868648036836, 44.93591608539705, 46.91951751708985, 46.746454700346916, 48.49080331863896, 46.2177505800801, 50.246507198579856, 47.72456830547702, 53.7851518969382, 50.25417150989656, 61.31955431353662, 41.25778798134097, 43.71947926859702, 59.749190268978, 53.81598172649261, 54.406937783764256, 53.03175872372043, 58.51679332794682, 52.72024016226492, 51.408583887161754, 49.9028330464517, 52.92835327886766, 49.60536049258325, 49.713323731576246, 53.6083314495702, 57.121017902128166, 52.692850251351636, 43.457645370114236, 40.576954733940866, 41.53966911377446, 41.462410188490345, 43.08451814036216, 44.25312557528096, 41.86539057762393, 43.03209174063898, 52.674097399557795, 53.77611475606119, 56.95057522866034, 53.01806965181905, 50.100689165053836, 49.29434007213962, 49.701058480047415, 49.861710917565134, 48.86123980245283, 58.17585699019894, 52.19301085318289, 49.215457285604174, 55.49128486264137, 56.31976004569762, 56.14677959872831, 56.78834207596318, 55.925895244844504, 44.94276062134774, 45.56263631389987, 51.01202834037043, 51.935369968414314, 49.06547369495515, 46.59884414365215, 42.98939674131332, 49.5015981120448, 55.86856588240593, 55.08247583143173, 52.18987687941521, 50.548949395456624, 48.64219504017984, 54.765709138685665, 59.984952172925404, 63.43816764893071, 60.141035049192375, 47.58202937341506, 3.7084769529681054, 0.4317368476861908, 10.457531136851157, 0.6964852204245906, 0.11737332679331304, 7.139689893491807, 42.87210218368038, 42.10537295187674, 86.13445666528519, 46.51772168374831, 26.79225152538669, 41.1147665977478, 61.91495049384333, 60.06221109820951, 47.30239968146048, 4.2946589954437755, 0.07295669041453831, 0.04954673650283968, 0.04832558852109698, 0.035190375206331094, 0.015833559802793447, 0.0459923796475895, 0.033120704409215725, 0.04373393329461256, 0.027228034619662552, 0.06302382421469496, 0.003782704682840455, 0.05193947423850337, 0.04888323158205998, 0.051512181037856694, 0.18154979923800116, 0.11282628086665947, 0.3532163594518939, 0.13457193940637574, 0.15178481657658854, 0.12017328622600726, 0.13937313500190937, 0.2546045718894851, 0.15372159410147898, 0.12324291626892744, 0.13966671521625212, 0.05779995109825846, 0.1410237174000471, 0.07309131504547212, 1.382292646073526, 44.3126985334581, 72.20847360549435, 58.711825340024895, 56.42307527603642, 39.067771819330034, 45.79689987244145, 58.874866500977554, 43.80399850107009, 64.78262670578496, 16.47505102619048, 0.5519032850861549, 0.28265874232015303, 3.3012255930131484, 5.547725846690517, 16.579276246409265, 17.108137261482977, 12.628515958786013, 10.181196235841321, 30.763802336108302, 58.054236058265936, 53.48927967010006, 62.592994936050914, 64.23067469750681, 60.61096637479721, 63.35695889688308, 57.64407773171702, 57.5721061614252, 60.43469113688315, 60.63019775575208, 61.61022939989644, 51.871494170158144, 47.15252983954645, 45.96810740809287, 46.592030986662834, 46.64259426055416, 56.72014382577712, 57.79861127176593, 62.958724575658, 54.688948354413434, 58.900059884594334, 54.21777755983415, 52.484466491207, 52.82972920325495, 57.38234973722889, 58.706494838960715, 58.72789921299104, 55.71099250547348, 50.826531610181256, 47.77295858629289, 57.35670528104229, 55.97081815042804, 44.35763320615215, 40.56838827748453, 44.21006971789945, 42.96854149910712, 43.611500340123335, 42.949792569683446, 46.04675093004781, 45.51935295904837, 44.46090136804889, 46.40626361293178, 48.23386453813123, 47.87069228387649, 50.63043663578649, 50.142658525897616, 52.402061416256814, 48.60032373859037, 54.06939429621543, 51.154014218238096, 55.31835932885447, 51.762950420379646, 63.566538979930264, 45.29375783858761, 44.86397197169643, 63.06920597630163, 56.18727807075747, 58.54919210557015, 55.40862483362998, 60.57879901701405, 54.873644921087454, 51.081152269917155, 51.60374925982568, 53.924046947110085, 50.06669398277037, 52.02692985534669, 54.80089672150151, 59.86106018866263, 53.384101313929406, 45.96596187160861, 43.18846879466888, 43.607401463293264, 44.932762499778505, 45.608398606700284, 45.507185766773844, 43.41083972684799, 45.83800631184732, 54.65233302885487, 57.0926905447437, 59.95078440635436, 54.6561965634746, 49.44001690033944, 47.448755079700106, 49.95215685136857, 49.15853584966352, 50.85899314572735, 59.25775258771835, 53.7161103371651, 51.21498354019658, 56.2989204929721, 58.72998591392272, 58.664572546559, 59.752030064982755, 57.19689615311162, 47.806659590813425, 47.99648269530266, 53.92845961355395, 54.64747713458154, 53.247645978004705, 51.109656133959376, 44.43546087511125, 52.674760280116914, 56.77481382123886, 58.05262396412512, 56.638433010347434, 53.910730500375074, 51.438766525637725, 57.37562287238337, 63.338837546686975, 65.63489890867665, 62.67893406652636, 54.02032936772993, 6.300427211869148, 4.0509204614547, 6.786231879265078, 0.6977810734702695, 0.19110326805422384, 9.377584957307386, 51.43871945719565, 53.54048229032948, 100.92591070359754, 54.1647235808834, 33.21041014886672, 49.80977873648367, 69.62522414422804, 67.84278931156283, 57.13707608561362, 6.287006822324568, 0.22810107066987023, 0.10583236543161255, 0.16548875058370252, 0.12754577933059585, 0.18083050396413575, 0.126270373171616, 0.10431808539696279, 0.18544572405517104, 0.180502817515404, 0.14481352371794565, 0.10726565465090737, 0.1855521030243366, 0.19289157773938873, 0.09357964710122155], [0.031474214835813454, 0.022447406569676056, 0.11320269816825468, 0.016727587283258478, 0.04823243222950448, 0.044744387944980014, 0.023446115176944483, 0.041273400608089664, 0.04672195965183839, 0.019321099426897786, 0.03301070567460791, 0.050423324949318366, 0.06743135020857857, 0.020648664682202285, 0.9945645159290684, 34.20772767836048, 52.43219698629072, 45.044330396959865, 40.637520051771595, 22.764903037778794, 10.009655298725253, 31.634982324415642, 36.98931570976011, 56.531285624350275, 8.18423766282297, 0.17326613647803185, 0.07146780619457846, 2.034305788336262, 7.498136181985179, 4.8374115747790185, 9.529545422523253, 3.635145300819028, 13.637432917471855, 38.25293471736293, 55.72659961638912, 58.29590112932267, 59.85065414059547, 54.483831928622344, 56.15182768914008, 53.78286907749792, 57.74412955007246, 55.97309704749815, 57.48267219912622, 50.876628122022076, 47.25606864498508, 41.18531827003726, 40.14841225839431, 43.827438585219845, 43.13708182304136, 48.487818394937825, 51.877295355643, 54.91280978725803, 52.32285307299707, 49.84773551264117, 51.15495166470928, 50.80416625545871, 51.05224832411736, 53.68695928204445, 52.39049042424848, 50.24569526795418, 51.819448240341686, 54.55028080171155, 56.363149304543775, 48.94424892240956, 54.97641494197231, 50.86015808966852, 40.24217651736352, 38.39872137192757, 40.65462158572289, 38.79235083057035, 41.09258559442336, 40.16421941018874, 39.0220134488998, 39.38644870635002, 39.37093180994834, 38.957980755836736, 42.74815136386503, 40.759392015395626, 44.376170327586514, 43.924882027410696, 46.505758454722745, 46.076847276379986, 48.51756565032467, 46.96193402813327, 52.79405524653774, 51.76151483289657, 60.65576376453523, 37.46971976372504, 35.67720443971696, 58.2201523165549, 51.12182724860407, 55.37806564761747, 51.103172456064534, 50.986042637978834, 47.19537781130883, 48.97816565728957, 46.73610356546218, 49.45010131405246, 46.280088809228715, 48.2770812126898, 54.69845225734096, 54.435163159524244, 51.76308770333567, 51.59342165916197, 39.52801489060925, 38.49219537550403, 40.25006832615022, 40.75628157584898, 41.60857731296171, 40.16285442536877, 45.26507354551747, 53.183354408510276, 55.95036298997941, 53.98849148904124, 49.33277929982832, 55.95036691234958, 52.379464641694106, 54.3602615787137, 50.841342479951926, 48.249636388594105, 46.76282667344617, 48.94772414238223, 55.78838086897328, 54.683590396758056, 52.04698493403774, 52.15248492456252, 47.469708381160615, 44.74776783297139, 42.73407789968675, 50.727727105540616, 56.2554096406506, 56.49691389453027, 57.7069886269108, 49.10035925526773, 42.51011840758785, 43.53380995412027, 43.50341943002517, 45.35834750821514, 43.93938695230792, 45.56137723307456, 53.650453782850704, 58.045697058400805, 58.62435648518225, 62.034708299944484, 65.03048519934377, 46.5322736770876, 3.869558154575287, 0.6116458857732435, 12.129113904891476, 3.822605177279442, 0.025400880446297028, 1.651223215364641, 40.06262217798541, 52.05215069555467, 58.02716385933661, 24.750606859883955, 26.19505693835597, 37.994638796775575, 48.75786573656144, 58.916494615616344, 42.57670064126292, 6.988272186248534, 0.08507712068216455, 0.021660197601323167, 0.07397354955995276, 0.08520858903085032, 0.039902892294189626, 0.0494713036553754, 0.06140593844916552, 0.03501135194974561, 0.03583950448721167, 0.059418139468518004, 0.012051625995926801, 0.03000307129696012, 0.0762621146596728, 0.014182801204433125, 0.037200206875680916, 0.02280651986028158, 0.05404304059582853, 0.04330106297387712, 0.04149016135582521, 0.016329604606594772, 0.030430582832665216, 0.050468631389160315, 0.04575594193151882, 0.06601774944893776, 0.008341532084159553, 0.07157364890219704, 0.087909838034501, 0.010057672456417595, 2.0985935580345894, 46.766925550276234, 61.24418204830539, 53.6352506760628, 50.64060734164331, 31.69705383239254, 17.311333687074725, 38.20926304786436, 38.03232100702102, 63.30213200661444, 8.031208842031418, 0.05147780667269423, 0.10796266442705547, 4.381914571408303, 8.161659029222305, 7.693982576170276, 10.864486848154376, 5.305360632558023, 14.5155898217232, 38.27507257461548, 56.76753390219904, 57.634240427324855, 62.97923072691887, 56.502460125953924, 58.94736759124264, 55.17751486070695, 60.56656906681677, 58.31886268431141, 58.88127957620929, 53.547122863031205, 49.41634539634951, 42.72759029942174, 42.80031888715683, 45.56700975664201, 45.77306362890428, 50.680697887174546, 53.617082257424634, 57.550074208167295, 54.029754823254, 48.73016988077472, 52.176831076222086, 50.44524585047076, 54.1532898718311, 53.74204112637428, 54.524977591729936, 53.394907443754136, 55.24686236535349, 56.745399967316665, 56.5241272987858, 51.39445550980107, 56.85701493294009, 53.22310370783652, 43.77079171519126, 39.29437498892508, 42.66040009836997, 40.1785909745001, 41.92375936815816, 40.86129127010223, 41.19098217256608, 43.018002586980025, 42.663843939381266, 40.96753258858958, 44.89602950311477, 44.090009889295025, 47.96725711514873, 45.57173621269965, 49.64403114011211, 47.82608316790673, 51.34990522938391, 50.06208912018807, 55.042832436100134, 53.20426456389889, 62.972715670062655, 38.42530327458536, 37.45550509422056, 58.2297307445157, 53.463458707255704, 58.44821068548388, 53.94806361967518, 51.979120085316325, 48.238971464095584, 49.50705805132466, 46.2904909349257, 48.95662400030321, 49.852701233279326, 51.70558967897969, 54.07055139541627, 55.972391020867136, 55.29780610915154, 52.64550724337178, 41.90596357468636, 40.87008130165839, 42.32892059510754, 42.29279164345034, 42.4705260030685, 42.178313347601126, 46.767957133631555, 54.995054045031154, 57.387217398612734, 56.65158079516504, 48.79555579154722, 55.698213423452074, 54.1207734231026, 56.71300118969333, 52.51464912968298, 48.22881644771945, 47.54993654066517, 49.66775363491428, 57.87423456868818, 56.19161621216805, 53.31533039769819, 54.97708566727177, 50.89189006436256, 46.71378135681153, 45.41706146732454, 53.13142614979898, 58.339717926517615, 57.68170502878005, 58.87243070910054, 51.544062552913545, 43.61955688845727, 44.93898730124197, 45.715063541166245, 47.677758739840606, 45.906604643790956, 46.510410385747115, 57.05243133729505, 60.07912828076271, 61.02369385380899, 63.32160657451999, 68.19301774424892, 51.30219351860785, 5.433236274027056, 2.1792051292234853, 13.983722309912405, 8.218720199600343, 0.07023095724082763, 2.030205440617377, 41.61961094025643, 52.31656159124067, 59.717481828505, 29.167364335829213, 32.46861738543357, 42.916079798052394, 54.87324876170005, 64.8527116160239, 52.466039196137466, 9.345960847793087, 0.12926455887575306, 0.04312619957472048, 0.054491692327804146, 0.030581189972919323, 0.06698106670932424, 0.03499216527768201, 0.020630824409665603, 0.029417812681546616, 0.01774200452341428, 0.029279947498693105, 0.008044373281600495, 0.03163733027665125, 0.059141734945437605, 0.03589192788387018, 0.1047433101602139, 0.1606839390531663, 0.15831203890904305, 0.09641150643508281, 0.10874535347665511, 0.16462803547901494, 0.1424724815954124, 0.23443528481068152, 0.18240234784541592, 0.09987479075789453, 0.1046439408955555, 0.15286008226535014, 0.23184226104809394, 0.2413614857341013, 3.5269158309505837, 57.606823059820364, 68.5046108307377, 59.07575068935272, 55.82920489772674, 33.174818561923125, 18.55686272344282, 44.33431471547773, 47.915854454040534, 68.86941479098412, 9.986063222731314, 0.47512935474514967, 0.2192782505505508, 7.450462714318307, 17.30666410538458, 11.3508274093751, 22.275226500726518, 13.455942888413707, 17.05612663299807, 42.742432548153786, 58.7313901224444, 59.10236397097188, 63.15974212461903, 60.06748668609127, 59.71590503569573, 58.89000684984269, 62.20381736755372, 60.14802863520961, 60.79063446291032, 54.284559834388, 51.310850189578154, 44.13501516465218, 43.313411974137836, 49.635751016678356, 47.44666053402809, 54.07706645227248, 56.2785751588883, 61.227233486790816, 53.55708176089872, 49.473306055991884, 53.11580334940265, 51.40352402963946, 54.25749155782885, 57.53703624971452, 56.83699123321041, 55.07523513609364, 56.26692571947652, 58.860459635334635, 58.86741792002032, 54.53355189292662, 59.06972592876804, 57.1370800079838, 45.51015107862411, 42.01644105295981, 44.603279482933786, 42.06648265161822, 43.76579461559173, 42.78908129661314, 43.27623574964462, 44.92466280537267, 45.005714662613414, 44.19510195332189, 47.17564044460174, 47.12744628229449, 50.455687199869466, 48.098734963324766, 50.40039354755033, 51.751740286427165, 54.528543026216575, 52.001101047761985, 58.27210410948723, 56.6151733552256, 64.01195549195813, 41.45894281325802, 38.889252985677416, 60.679039109137754, 55.969257047099454, 59.41114864041729, 55.23836651156026, 55.72120243503202, 51.98718840076078, 50.621042559223795, 48.92925370124079, 51.20174554086501, 51.900017646051225, 53.30101374656924, 54.211615516293435, 56.883534077675115, 54.617149368409194, 56.49323471130864, 45.00066657220164, 42.89084326836371, 44.283104250507975, 44.399932046090406, 46.262030216955374, 46.06908490580898, 49.413795855737504, 57.921612877999586, 59.44735996184811, 58.220944635329715, 49.776454279499674, 56.89581501868464, 55.74619185539984, 58.47225873701034, 53.29429472646406, 48.739803221917924, 48.91386624305479, 49.88512746749386, 59.97385578770792, 58.37011237298289, 56.668564658011164, 57.58996471281975, 52.46778072849397, 50.64105056947278, 47.65812335475799, 56.040138198483376, 61.98512169622607, 59.917828652166556, 62.670634331241736, 54.65930308065107, 47.19145936350669, 48.7232861211223, 48.3953877418272, 50.52665072102701, 48.435866602005504, 50.64224689237533, 58.87285432507915, 63.47505361803117, 62.463203707048976, 67.28094116333993, 70.36459876644996, 55.06564494102232, 6.2479640399256064, 3.6428618286886527, 19.544386094616307, 5.617411165468154, 0.16303382183034576, 2.232727341113552, 52.68776685960832, 65.41503044866747, 65.59844047792497, 34.159435456798924, 35.50208237863357, 49.19793605804444, 63.258676067475356, 73.42362388487786, 63.03712491066226, 13.084213003035515, 0.22671517164957142, 0.16995446095543523, 0.17706254647383768, 0.14739468843946535, 0.1372590234443065, 0.13282757252454758, 0.1458972316956328, 0.1235780337705247, 0.13983775200622697, 0.1374199631954393, 0.12725381556177331, 0.16313318343412492, 0.17136363372687372, 0.13351455420976685], [0.1143546952235122, 0.04440137207688344, 0.1034463999131995, 0.07104088071613543, 0.03581205938732432, 0.05019475112579042, 0.038627014991136334, 0.07931856799029535, 0.0731698084141939, 0.07527896338292668, 0.10150160910862108, 0.10346329215192988, 0.020332913883330844, 0.025833852273682435, 4.178861802624119, 44.528456349526685, 50.875184689798665, 43.42597615334296, 28.923891052123043, 19.183916353410293, 27.33958298160184, 34.00267401049214, 43.578948590063284, 51.136810702662316, 3.915434196110695, 0.05642366648140935, 0.05463379397687893, 1.225816061900508, 4.439278254585882, 6.205766691315559, 10.664522455584619, 7.472367190545605, 27.322269639661236, 44.63315617653632, 53.62259710988691, 55.18448491250315, 59.11192278708182, 53.93557479304653, 51.500751741470836, 45.835774483219275, 50.16848733348232, 48.74134863576582, 51.00906302852016, 42.35697730895012, 42.384994799090975, 41.276572212096184, 46.968841322006725, 49.44116615479993, 53.97666554297171, 52.05464924535444, 54.3158995720648, 52.680298666800226, 50.305668307888894, 51.95623697773103, 55.97346575029435, 53.14072216710737, 55.26198310236777, 50.966215056757775, 54.33900625474992, 49.788680307326786, 51.24589181715443, 53.50560849712741, 54.77620147889661, 54.32178704969345, 56.64133164190478, 45.190897603188795, 38.20358345585485, 38.809436675040956, 40.414203828380955, 38.047763378389426, 39.729636484576815, 39.15745681332004, 39.241395535007605, 39.538162062245036, 38.64498738319644, 37.96371483033703, 39.90904961862872, 41.07230694063249, 41.15261746991066, 39.308197421412316, 44.17467817183464, 45.34117537160074, 49.71983486606229, 50.77913368901899, 50.15938743468254, 47.20206545245263, 59.07954362130935, 38.691718501429406, 31.70225097287086, 55.107171074036636, 47.26849471369098, 52.117163981160815, 45.24654034645327, 50.320051639310776, 48.86429140644689, 50.4610804588564, 47.33147228917768, 50.81999301910401, 50.52248124153384, 53.754494651671386, 47.52813600724744, 57.17058489399572, 53.12655064367479, 54.675145533777055, 47.28816932247531, 38.86156497463104, 39.14659184794272, 41.925618571619836, 39.284165059366536, 40.51651100958548, 46.40221572691395, 57.77936812370055, 49.48909751830563, 47.601209763557684, 56.08963851005801, 51.84748926470357, 54.15789865678357, 53.52440057262298, 53.77647561411704, 52.33784829416583, 47.666011241174516, 51.652186609083614, 54.31042394330425, 50.70969596985848, 51.369419020991174, 45.868847908512244, 42.394906628516416, 44.03595570595034, 50.9940521178707, 54.09465828249532, 55.93597573618735, 54.981164932250984, 55.228066367487756, 52.661298705685525, 46.41706974275651, 44.17694530179424, 46.14592021511447, 44.270623268619666, 50.10030869514712, 55.84760473620508, 58.23593201175813, 61.18149472821144, 58.248334546242994, 54.09509366558444, 56.42415000546364, 53.64016148351855, 6.99935729465177, 1.0975592150803537, 13.097175455862477, 8.703757063035043, 0.1570244289694294, 0.3321005247773663, 29.58865631011225, 49.03615397791709, 42.80847349474507, 38.273507548916726, 20.16283796679589, 31.06053552319927, 45.22759529852098, 50.60732603073121, 48.21133444386144, 7.980425425114171, 0.31531281108337067, 0.12887331777282302, 0.0922455203028456, 0.049258346534183914, 0.043475409263684865, 0.06948225951242833, 0.03189966176456261, 0.04481858356044658, 0.08711466941261485, 0.034119146800930464, 0.042615533025274356, 0.009772416744982044, 0.06439857665569552, 0.013542948290705683, 0.03498338974050937, 0.05077021339187219, 0.03097471210264391, 0.0210833927661541, 0.029550225233599067, 0.011026997761350247, 0.024917080600355423, 0.02000150424728711, 0.05022467452011282, 0.03793158335611224, 0.04754515943087397, 0.0022162870980889328, 0.037414749798875664, 0.0519306029403402, 6.041947920476237, 57.0125682892338, 57.31308067998579, 50.65346094869798, 35.94562792008923, 24.234215059588035, 27.101877543234057, 33.75642368870397, 48.157429310583304, 54.354076000951956, 4.060651126407808, 0.11005757782127588, 0.2253667036852529, 3.6753079199021865, 5.189669343733019, 10.43185922407335, 6.003333166722329, 5.2406297576042915, 26.98843279192525, 48.441801148076216, 53.991648997029955, 55.38726752804172, 59.91853467879757, 55.15591044579783, 53.09517168229627, 48.444476204533736, 52.607668138319454, 52.40975318416473, 51.96640376121768, 45.62817127473893, 44.35772342066611, 44.562847691197554, 48.00875186920167, 51.37435336266795, 55.01199868417556, 54.88320373719739, 56.42391858562347, 54.20772060271233, 50.51565239506383, 51.22588772927561, 56.076098488223174, 53.810623768837225, 56.65662888557681, 53.365791689965036, 55.89416719252064, 52.52173293021418, 52.14434600645497, 55.007138867532056, 56.72319935214136, 55.41482610087241, 59.23630506761613, 47.88501677974578, 39.93882433060677, 39.59463634798604, 41.36568061767086, 40.12300314441804, 41.74977087205456, 40.69002489889822, 40.65353116681499, 42.98943204264487, 39.37516404736427, 40.56576421183925, 43.855801243935865, 42.94028474438576, 44.604632700643236, 41.432458969854544, 46.70188088570872, 47.10111541132773, 51.24944156216037, 51.86662258640413, 53.41976742590628, 49.04572063876737, 62.178400408837106, 40.61026742381435, 33.38641474323888, 55.81457053461383, 48.77876804720972, 53.677090598690896, 45.51059822882376, 51.6509981309214, 49.30431858185799, 51.56728690670383, 49.988325026727495, 53.92761630396689, 52.27316841002434, 53.28525366321687, 52.22007912974204, 56.926786053565245, 55.522871709639034, 57.196472537133005, 48.63988084177817, 39.68903603092317, 41.09241693250595, 43.66851983531829, 40.60423874085949, 41.596602316825624, 49.33114759383663, 59.095578270573775, 50.98088079883207, 48.95447454144878, 55.427173722174864, 54.436551678565245, 54.969260538778, 55.40120763163413, 55.543307258236794, 54.37051073197396, 48.94097374331567, 52.008377044431626, 55.37561808862994, 55.12925401810677, 54.91162523146599, 48.41078304475354, 44.6529798353872, 46.631266455496515, 53.49650467595747, 55.78206193062567, 56.233267861027876, 56.87894882694368, 57.46831632429554, 55.248643121411725, 49.11191455779537, 45.846258978689875, 47.41495993829543, 47.215817282276774, 51.60382770722913, 58.53523631249705, 59.3021067496269, 64.21237684065296, 60.85372186476185, 56.443016605992476, 56.69260486479729, 56.058624329105506, 7.687194914587083, 1.790103188926174, 8.708132466962262, 7.758005953604176, 0.2815194470026801, 0.2485932025217241, 33.25350915232013, 52.24350352441111, 48.879788690997714, 38.40921763450869, 24.014272074545584, 35.71566327925652, 52.38234758377076, 56.32293324316702, 57.85769001130135, 13.260650038719179, 0.5396809344810825, 0.08811667411317749, 0.07594608040826936, 0.07093688428041435, 0.03840791767523174, 0.042872245258261124, 0.042517772545256925, 0.04923357891159193, 0.020806635842628537, 0.013610269224661733, 0.06804491768801404, 0.08807051731573959, 0.045421310895753485, 0.026512684698607174, 0.24605271706898368, 0.17453413456678393, 0.2846910203656843, 0.15676109390633722, 0.17597592736203826, 0.14973176222655082, 0.08337541723683958, 0.20494066989950596, 0.18830052006148523, 0.14199033649938722, 0.24845031180208732, 0.11880319159958633, 0.11439853077453953, 0.1313039615389801, 8.106297716017693, 68.31564672531621, 62.61610946347637, 59.35612955401021, 40.872638687010735, 28.744972136712846, 38.04271528797765, 48.09457332857194, 55.46428718874532, 63.05256335966049, 4.736130093374561, 0.1212057888868355, 0.1596991943135377, 5.463811639816531, 15.557544904370463, 18.842374009470788, 20.614367492737312, 14.697193599516346, 31.17916564787588, 49.63665708418816, 56.71085957557925, 56.038353520054976, 64.19861324371831, 57.396340831633545, 56.38469880627048, 50.62438834098078, 56.111662618575565, 54.94798952533353, 55.34318008730489, 47.73875944076046, 46.83717520006242, 47.27258182341053, 50.72380865773847, 55.60124851042225, 58.98912122172695, 57.95483143098893, 59.718203544616706, 56.63407525708599, 49.36154596267208, 53.828909858580566, 60.03511536505915, 56.71151461139802, 58.791343550528254, 55.82786736949798, 60.10856566890594, 55.59285071588332, 55.77378180719192, 57.708369301211455, 58.03984488210371, 58.264624149568625, 61.54802453133368, 48.44632756325507, 42.375334001356556, 42.18404393042288, 43.26953241902013, 42.51613140106202, 43.64023562400572, 42.104902267456055, 43.009589102960405, 45.146645422904726, 41.989196269742905, 42.05429584749284, 44.8115102706417, 47.27969308053294, 47.44116921578684, 43.99495124816895, 48.27180170243787, 49.75049995606946, 53.17163436643539, 54.79167915159657, 55.12586509027789, 50.98230461920462, 62.513927798117365, 44.23320777954594, 35.189438096938595, 55.32414482485864, 50.94689346128895, 54.73512249608194, 46.50758235685287, 53.20252695391255, 50.8424093646388, 52.78118595000237, 51.35383936666673, 55.052120608668176, 54.39015003942675, 56.227494132134225, 53.68692005834272, 56.61408293631769, 57.425240855063166, 59.40720273602394, 51.33804398198282, 42.9673255643537, 44.26649693519839, 46.61013664737825, 43.98458442380352, 43.743213530509706, 50.72231031233265, 59.665047584041474, 54.42929921611663, 50.82302893361738, 59.0013550942944, 57.31944668677546, 58.23985045956027, 57.56442223825763, 56.81640271217593, 56.0133287983556, 50.68920943044847, 53.90644334977674, 59.287731262945364, 58.031756954808394, 56.6070971950408, 51.383186540296, 46.60000124285298, 50.58595303566226, 55.56795151002946, 58.33612503543977, 59.55284034052203, 61.10828761131533, 60.903029980198035, 57.55101165463848, 52.533343145924235, 49.267942520879934, 51.9884317921054, 49.07531099934732, 54.97787798604658, 61.72979108748898, 64.35570809148973, 67.59985339257025, 61.94866326547439, 58.33242231799711, 58.913803869678134, 59.73274377084548, 8.486175344836328, 3.0694591133825244, 23.221510071908277, 11.320376088542323, 0.5800256986291178, 0.38453709814817677, 39.57158065611316, 62.052884563323, 54.92246666262227, 48.65988100728681, 29.052280033788374, 42.93655849272206, 59.32609204323062, 64.73080435106831, 67.95691459409653, 18.947242498397827, 0.6326927112475519, 0.22490250036841442, 0.1958929110438593, 0.24754456604921052, 0.20009680320658993, 0.15449810082152968, 0.09198613059256347, 0.15063332513936106, 0.1725624081107878, 0.09040517792586358, 0.11672326288516484, 0.207270756964722, 0.16505132970069686, 0.10773306787614861], [0.03531106086748262, 0.0449589193768559, 0.08017508493315789, 0.02961361134845403, 0.024717911146581176, 0.020048398404352127, 0.04140595680162792, 0.018470986979082227, 0.06939739995305577, 0.04345296671794307, 0.034288034714277715, 0.057843905392914056, 0.031078379120557543, 0.08160864228322622, 6.4261244670037305, 49.75840353196668, 51.05335443250595, 49.71418665301416, 35.97069186549033, 14.947815402861565, 33.40606581780219, 38.24981643307594, 45.684947582983206, 47.6980060146701, 0.6263950395007288, 0.11083907177371365, 0.3414102703813584, 2.570588050350066, 4.532549765802199, 6.576667485698578, 4.01062055941551, 7.382756721588874, 36.518823485220636, 52.6679902691995, 61.19621146109797, 57.84532277814804, 60.6220196139428, 54.05650146545903, 56.443659874700735, 46.428970213859316, 44.96452193106375, 42.66510694257675, 39.05893471933181, 38.931136054377404, 43.358397637644124, 46.80567464520855, 51.70416978097732, 54.87081296982304, 55.7654389258354, 53.81159651663996, 54.90880896968227, 54.406690674443404, 52.692763959207845, 50.69439480381627, 53.45996387543217, 49.86751210304999, 51.48836881883683, 51.09123668363018, 49.076342582702644, 44.726971426317775, 43.56485159166398, 49.330108165740974, 54.43850894128123, 54.114148539881555, 50.5260152970591, 38.29719474238735, 39.18300713262251, 37.11375682584701, 40.55335383261404, 38.75124439116448, 38.91588195677727, 37.79002835673671, 39.30214912660661, 37.592097713101296, 38.87620326011412, 38.011434385853434, 40.30876659577893, 37.94423241769114, 38.88639750019197, 39.32509499211466, 41.841664160451586, 43.414628736434445, 48.575408843255815, 46.06739828663488, 51.36824230993948, 50.320086940642334, 59.14322722342707, 38.59131759212863, 28.464969819591893, 50.75873736412295, 43.613265406700876, 51.19262995258455, 51.34241350235478, 55.088331930099, 51.030463480180316, 54.61232485309724, 53.465129636949115, 56.10963867556665, 51.66834677419355, 55.4954464973942, 47.47545857583323, 50.499347102257516, 56.82270596104284, 55.135663170968336, 51.11141335579657, 40.71350812911987, 36.7536126413653, 41.70678953970633, 39.18905934979839, 39.426896187566946, 44.62586449038598, 57.67540177991314, 45.9690526993044, 53.03952893903179, 53.14679791850429, 49.958962163617535, 49.17084424726425, 50.829759720833074, 51.18040784712761, 53.53299448567053, 50.2965997880505, 52.3904315886959, 51.63636769017866, 52.193999290466316, 48.396325188298384, 43.46791805759553, 44.44409793423068, 50.32955946460847, 51.388689625647764, 56.950194758753625, 54.12339748874788, 53.867796236468905, 57.55420446395875, 55.59190542467179, 51.04905551479709, 47.07056799242574, 49.08057482011857, 54.724296754406346, 55.09852224780668, 59.48355559379824, 56.29537074796615, 61.550942774741884, 56.638915461878625, 52.91340904851114, 36.90996223880399, 35.57407356077625, 10.320232491339407, 0.9983183467580427, 8.802167369473366, 33.59739511243759, 8.510270464804865, 0.3859406631560095, 20.348934819621427, 44.34455602399765, 42.1840831541246, 30.565389240941695, 22.22160573928587, 31.257817014571163, 47.534619685142275, 50.94375556515109, 53.2607388496399, 20.75543357479957, 0.16194930179945885, 0.0461937956542017, 0.03858890977778262, 0.012504912559844315, 0.058509662612191135, 0.029303334247801575, 0.02719609832931911, 0.039191303864842465, 0.02813633144532721, 0.058923415208776156, 0.043642267044032776, 0.016259193465474154, 0.006556837855192323, 0.052587136461008946, 0.07242320210582788, 0.048614131707337596, 0.026723552314985185, 0.029990474896265135, 0.010530145692398712, 0.024610356232451818, 0.06726847225499731, 0.04164443231157718, 0.07773003871402434, 0.05526068755575726, 0.031591864873565016, 0.02598087412245091, 0.03669445861070868, 0.11221612247848704, 10.335075720663994, 60.89978225769536, 57.96366853098716, 55.57547461601996, 42.67311250009845, 22.01338475750339, 29.704338773604366, 40.052702503819624, 52.57332386509065, 49.13513498921549, 0.6828658318808002, 0.07431756900323015, 0.7723847380088222, 5.520705128869703, 9.985626859049644, 11.579835972478314, 7.346845951772506, 11.185653459641243, 32.73661528864215, 55.07578819028793, 59.06425030000749, 60.30301324782833, 62.453240886811294, 57.13860580998083, 56.74404282723704, 49.60998496701641, 46.68887822858749, 45.44860909062047, 41.13492758043351, 42.114668969185125, 42.75965175321026, 48.436349053536695, 52.27234471228815, 57.76372963382352, 57.6327460042892, 55.290894892907914, 54.40617684395083, 56.274507661019605, 52.55923078906152, 53.50257258261404, 55.358214532175374, 52.98341943371681, 54.92667928818734, 52.82011155159243, 51.81622797443021, 47.30015216335174, 46.01739983404837, 52.42720380906136, 55.71603667351508, 55.87621450424195, 51.9841250296562, 39.5044885143157, 40.463425651673354, 39.057910980716834, 41.88790890478319, 39.36483644670056, 42.146047930563654, 40.49935848482194, 40.72243936600224, 38.83430057956327, 40.940225047449914, 39.791523641155614, 42.22399719299809, 41.11143650547151, 41.66301981095345, 42.037723833514804, 44.06002336932767, 43.60878605996409, 48.529983874290224, 49.0230611062819, 52.166919246796645, 52.06655363882742, 61.38635619994133, 41.399350243230025, 30.563992877160352, 52.388599841825425, 43.317091157359464, 51.239839599978545, 52.15697996077999, 55.86353740384502, 52.83113733414681, 58.43003049973519, 57.28903655082949, 56.24622344970704, 53.06877805340675, 57.325400844697036, 48.03960131060693, 53.59965908911921, 57.24944806868031, 55.89826999172088, 52.806987300995864, 41.104686106404955, 39.87519171930129, 43.722373977784194, 40.10722737158499, 41.04973762266098, 47.87521869905534, 58.87048521349507, 51.521383408577215, 55.395935966122536, 55.31199724443498, 53.09613266298848, 51.08720056472286, 51.29882420262983, 53.05181380241148, 56.11558106637771, 49.20979338307535, 53.88764735191099, 54.58312672953452, 52.92211671029368, 50.20184316942769, 45.49956852389921, 45.88139164832331, 53.35498556014031, 52.13847421830701, 58.850316386069025, 55.537188360767985, 56.196883955309474, 59.38522177357828, 57.82564032462336, 51.90040203832811, 48.46291134434362, 50.28826082906416, 58.747695415250725, 55.91588143379458, 61.589252564214895, 58.04023319675077, 64.09404285492437, 54.06182412178286, 53.1497436185037, 36.74199065854473, 37.145755521712765, 10.73642832617606, 1.401153117898972, 7.893821452894519, 26.173672176176503, 10.764325203434115, 0.44588811575405063, 22.899924747405514, 50.23853302001954, 48.49498848761282, 32.49039830700044, 24.170525573915054, 35.03382590509231, 53.54928801136633, 55.01361470068655, 62.05187259181854, 27.826162807403076, 0.32040622325674184, 0.01927989730311017, 0.01589591744461007, 0.011237043748429466, 0.027406207518652085, 0.025395626998356274, 0.04509644748102273, 0.034007386064096805, 0.02917321995952197, 0.06370918562395439, 0.01598884965548472, 0.04325124427616116, 0.05339467740287224, 0.0394330122658322, 0.16554876591169065, 0.11509793840589062, 0.1373286301931066, 0.06992788519710302, 0.0704984445004694, 0.11496746597150642, 0.10651050646218563, 0.19671608784025718, 0.19192639888534624, 0.15620882112172343, 0.12449717074031792, 0.18396470755819352, 0.2358628590140612, 0.24242369728463314, 14.526941161001883, 70.12462815930768, 63.810353509841434, 63.772879185215125, 47.30066599384431, 26.358249110560266, 43.71978129110029, 54.79429929487167, 55.27770788438859, 56.556651592254646, 0.7165005851176478, 0.3288607083020672, 1.3197415057689914, 10.503434634977772, 10.466834998899891, 13.278532124334767, 12.351950618528551, 12.94962275412775, 38.772229071586366, 55.39894050167453, 63.021847278841086, 59.07965344767417, 66.4976595294091, 59.173484386936316, 60.45350674659976, 51.2650094493743, 50.36109924316407, 47.93235194298529, 42.5333192271571, 44.12426787038004, 46.996564634384654, 50.55305219465687, 55.17881316523398, 59.56200691961474, 59.55928479471515, 58.350610348486136, 56.49323078893847, 54.45089970865558, 52.15470498608005, 54.83664128088183, 58.20511002694407, 55.06348763742755, 56.910931833328746, 56.25091068206295, 52.51584153021536, 48.690879498758626, 48.20064598514188, 53.13782353555003, 60.07030687024517, 58.2783563675419, 54.08894731152443, 41.63774405756305, 43.38270456560197, 41.02867449483564, 43.571601990730535, 41.483214439884314, 44.07367321752733, 41.2496647527141, 43.69832984862789, 40.967481597777336, 44.40127349668934, 42.426642525580625, 45.96543235163535, 43.55248435851067, 42.7405184315097, 45.179522729689076, 46.98789227393366, 46.43288473929129, 51.123796278430575, 51.14136849680255, 53.60764111241987, 53.894644860298406, 62.664876291828776, 43.01252695821947, 33.16203163516137, 51.14776196018342, 43.77130554568383, 50.48775257602815, 54.808678703923384, 56.091984087421054, 55.271616443510986, 59.643827561409246, 56.97663545608521, 59.116025586282056, 56.04451556359568, 60.6947874253796, 50.55524087721302, 57.565242013623646, 56.11798940166351, 58.837870705512266, 56.22470532694171, 44.24910906822451, 40.728711235907774, 46.966903671141594, 42.94312061802034, 43.02917741960095, 50.24710339884604, 62.64732760767784, 51.79744374367499, 58.04151581179712, 58.131326321632635, 54.314036446232954, 54.15481567382813, 54.65051304909491, 53.65061852239794, 57.35408121539701, 51.968384558154696, 55.384325750412486, 57.44989295159617, 56.16868995851087, 53.54565197421659, 47.82032512849378, 48.406809683768984, 55.01159075767764, 55.145539699062226, 62.67536863203972, 57.28093293405349, 56.47925930638468, 63.098282506389005, 59.98153578850531, 55.527413814298576, 51.08961282237884, 52.563294364560036, 60.160003631345695, 58.72875428968861, 63.67000326033562, 60.13726957382695, 65.28193266161027, 55.660613582980254, 54.67904436972834, 41.42977606865668, 40.351591033320275, 14.721766268053363, 4.351742229154033, 16.551323475376254, 43.498237979027536, 8.961402850766337, 0.369400916801345, 25.494435333436538, 56.75336237876647, 53.845870187205655, 42.300989397110484, 35.90700826337261, 44.50264715379284, 61.99604157478579, 64.63971514855662, 68.99394219921481, 33.8852813936049, 0.4807646055856059, 0.10528278927649222, 0.10150435170339, 0.07015200421935128, 0.1835805910729593, 0.09044522900254497, 0.13635255756878084, 0.10998955687447903, 0.13984994812598153, 0.1271740045218218, 0.15211824868475238, 0.12582372092912275, 0.15473076172413366, 0.2754515403461072], [0.03175760416554348, 0.07793309031835488, 0.08078151247313908, 0.047264970433447635, 0.006774159283527444, 0.03831898635854164, 0.0343608552019202, 0.06923585499246275, 0.03410402422530517, 0.0646345317363739, 0.02684963889600289, 0.04980927866493022, 0.04392845834034585, 0.046368490514015, 14.176770583275827, 53.62569970469321, 49.40691994082544, 45.72734840454594, 25.47392329862041, 14.065185035428694, 34.52575345193186, 32.62000322341919, 52.7022913963564, 31.184172553400842, 0.46968544202466167, 0.02072756599274374, 0.31700424128963106, 3.4479921046764623, 3.9386053527555163, 11.328946467368834, 2.8570507562929586, 17.46703609343498, 58.02828565720589, 61.777820510248986, 56.903538165553925, 57.80265131304341, 57.12422640092912, 58.19961870870283, 54.54238507055468, 55.08025184754403, 46.1426293465399, 46.41861907897457, 41.9890550644167, 41.22936256470219, 44.33083949550506, 50.50863135245539, 53.16666472342707, 52.860668859174176, 52.724390029907234, 54.4569048573894, 52.7001380151318, 51.31723580821868, 49.07385972238357, 52.38486182305121, 52.49091486777029, 51.19654447801652, 47.73328381199991, 42.862613970233554, 41.66978982187087, 43.052146819330034, 40.44542981732277, 41.69315145861718, 47.914199213827814, 45.74832131785732, 40.35688231068273, 38.11847979022611, 39.08788965594384, 38.15638557557137, 41.701466883382494, 41.17395516364805, 40.67101317067301, 38.47989090027348, 38.67353439331055, 38.753158507808564, 40.31863527913248, 39.030701498831476, 39.74534165474677, 39.59635042375134, 39.94192692541307, 39.01470607326877, 40.605356616358605, 38.759002839365316, 42.27239924092447, 41.97042772846837, 48.20582351376934, 50.65397870156073, 59.13938722302837, 42.03419762272989, 29.836455968118486, 52.01391150874477, 47.836144047398726, 55.33058535668158, 51.111978177101385, 53.464831536816014, 50.59784173965455, 53.141800818904755, 51.12854626870925, 51.625263460220836, 51.12140363262546, 50.222086521887014, 53.94589847134006, 50.4360165134553, 51.570001186863074, 56.2097454071045, 49.70042697844967, 43.19201069493448, 37.16484569734143, 40.808331428035615, 39.968053833130874, 40.138029744548184, 41.97554642154325, 55.80308191237911, 55.81206021770355, 56.24565470603205, 50.65311185775265, 47.94384448759018, 41.54410531443935, 49.90444906296269, 51.596849810692575, 55.04815901479414, 49.01140382212978, 52.82688940725019, 53.88146569651943, 48.84899416277486, 45.32647040582473, 47.30400393086095, 49.36577427771784, 51.93402067307503, 55.08842214461296, 55.14260968854351, 48.73157801166658, 53.263135417815185, 57.968963730719786, 55.455728577029326, 51.98948690968176, 53.59546215303483, 50.288084322406405, 55.51437193347562, 54.40576891745291, 58.96338655102638, 55.51942394625757, 56.63324763697963, 52.94090878578925, 55.26945129517586, 33.32045224405105, 22.81818843656971, 10.131878314479705, 1.316833190860287, 5.861399750555716, 9.473632035716888, 4.819668243008276, 0.030266481053624904, 10.23613295247478, 43.77495727231426, 41.26083958533503, 40.75944300620787, 24.596655791805638, 28.987647218088952, 42.90412441376717, 46.63787564923687, 53.15024568188576, 29.49700228629574, 0.10656490636568879, 0.06093670193466449, 0.040442999602565845, 0.06735029044531046, 0.07843464042150206, 0.04786817657370721, 0.018866054691194047, 0.05189899032214477, 0.06747314796572731, 0.004996166408677856, 0.02833217799272989, 0.011120117663766348, 0.05128247723464043, 0.05554233212023974, 0.05474809046474196, 0.010971639290331833, 0.04620316107907603, 0.03784982645283303, 0.037478151235489116, 0.048358576267116496, 0.03390790571668937, 0.03655639424499485, 0.017543137674370123, 0.16071268267208533, 0.02438229185739352, 0.04913006128082353, 0.07775004893060654, 0.059078122834644975, 20.327899148387296, 61.2298850090273, 56.0444292714519, 52.19489751323577, 31.492816017520045, 17.894531296145534, 30.6685063915868, 37.352146717809866, 56.24514087553948, 36.200025004725305, 0.10586075665008639, 0.10688051160785461, 0.7582628570737378, 3.059106262460832, 7.175942399809438, 15.632142501492655, 5.394857352779758, 17.49513791453454, 59.75586222064111, 64.72786257343908, 59.98225358224685, 60.08036774973716, 59.25577179078133, 59.98112786200739, 56.36396515753962, 56.60347684737175, 49.290335332193685, 48.12862734640799, 43.49869297396752, 42.11355893842636, 46.322391571537146, 52.67533294616207, 55.47736437089982, 54.19215663786858, 55.48424813055224, 54.94827978072628, 52.93009481122417, 54.278558608024355, 49.75947433902372, 54.79216160312776, 54.240997991254254, 52.682977645627915, 49.19241728321199, 45.33314235748784, 43.64802152879777, 44.50396899254092, 41.75262635754001, 45.67822071813768, 49.85734531956334, 48.46012646152128, 43.7778990499435, 40.62718460636754, 39.94232700717065, 39.89081451969762, 41.36644155748429, 42.37735794436547, 42.194500969302275, 40.103795297684215, 41.045356335178504, 41.094813500681234, 41.583085829211825, 39.50661443894909, 43.48723573069419, 41.71491276833319, 43.22842205724409, 42.32964623358942, 43.189602359648674, 42.6050829118298, 45.461329337089296, 44.635780242181596, 50.19614004319715, 50.85943245118665, 61.936617666675204, 45.8290123170422, 31.415511984978956, 52.3663874595396, 48.56788965963548, 57.885370177607385, 54.54664084219164, 54.917944169813595, 52.627370203694994, 55.3799170063388, 53.365062129112985, 52.6364936367158, 51.78870862530124, 52.74881855134041, 54.64858324297013, 52.51994825178578, 53.19907134579074, 58.227420468484205, 51.392447256272845, 44.41595100587414, 39.08635993157664, 41.907595280678045, 41.51020426904002, 40.05467937838647, 43.78267649681338, 56.987402362208215, 55.763536576301824, 56.8426747475901, 53.10991194940383, 50.44653631025746, 44.427835787496264, 50.34312302066434, 53.46212902376729, 56.76998146118657, 50.71922732937721, 54.3598222732544, 54.85841043533818, 52.53304504579114, 47.10943868083339, 49.69411588484242, 52.75982864441411, 54.66074259050431, 56.426405368312714, 54.776032816979196, 48.78412992723527, 54.10053007064327, 58.74994685572963, 57.20127744059409, 52.9523777961731, 52.65607803098617, 54.066405450144124, 57.74858536258821, 57.59411458046206, 61.08504756804436, 56.25932416608257, 56.953936699898016, 51.69282628643898, 56.898078226274066, 36.286242623482984, 23.458238840103153, 11.710889224083195, 0.7041050986416879, 6.0742334396608415, 10.776970924869662, 7.049205716579192, 0.22957199012800572, 11.317574535646747, 47.761626858865064, 47.30438440076767, 44.70492378357918, 33.81047394967849, 38.91281074093234, 48.2554885648912, 51.926081795846265, 61.3231550493548, 35.51499089887066, 0.200246297604134, 0.07656007689694244, 0.07333841670544879, 0.08211838186628397, 0.01958834919928303, 0.03295342528050946, 0.011256104973595471, 0.026615143212820255, 0.0341331125837901, 0.07797165518446315, 0.029907643554672122, 0.07827692590053044, 0.040362705927222006, 0.06363890088734127, 0.15706674766636666, 0.1330797993127377, 0.1618070239501615, 0.16745692239173, 0.09794704540963135, 0.15590313671817704, 0.12376141223695972, 0.17053676438668083, 0.22112933348023125, 0.3039908895809805, 0.09353443259193052, 0.20661952094204966, 0.18448322650886353, 0.21014939362723983, 26.41469397852498, 69.39766391631096, 65.23925727413547, 62.46710254300026, 35.928377336071385, 21.811831805013842, 48.19767282855127, 46.00069445948447, 63.58013391494752, 38.99466276168823, 0.6418833761445938, 0.2861601931433524, 1.8069961018139318, 8.325101252525084, 10.834402268932713, 24.67943545310728, 5.389397903796166, 19.0374001379936, 61.54577701322494, 67.6675848807058, 61.43936311045001, 63.9459067006265, 61.142992742599986, 63.35013397278325, 58.462201779888524, 59.69609314395536, 50.43402394940777, 49.18337229759463, 45.921046810765425, 44.48733422064012, 48.73214675534157, 55.14967779959402, 57.33358290887649, 58.54092374924691, 56.50161681636688, 55.880038815159956, 52.192257758109804, 56.406346367251494, 49.59453867327783, 56.01347784842215, 58.138763135479344, 55.8795367517779, 52.454205405327585, 47.3121585384492, 45.502780945070334, 47.28920482820081, 42.96578015050581, 46.63014073525706, 51.67241819443242, 49.62415649044899, 45.94596562847015, 43.99744979796871, 41.75178304795296, 42.71817661100819, 43.85118853661322, 44.208740034411036, 44.682491748563706, 42.36424938324959, 43.94732582953669, 44.566695536336596, 43.86887058135002, 43.49140521018736, 45.84143054100775, 44.74978785361014, 45.51261040472215, 45.86832231090915, 45.838873155655406, 44.190097008982015, 47.67547592040032, 47.175381568170366, 50.76464837597263, 54.89584161389259, 62.93924608538228, 49.77098257310929, 33.53258971245059, 52.78579865732501, 50.52068479599492, 58.604109210352746, 54.49768181770079, 58.07998641844719, 54.748419330966094, 57.317269771329826, 56.433693132092884, 56.07845975506691, 53.46013253734958, 55.10878316817745, 57.14870199080437, 54.40693386139409, 55.970343543637185, 60.00715278810071, 53.86896902515043, 46.373507899622766, 41.27238312075215, 45.175243423831084, 43.797714864054036, 43.9468002319336, 47.055541392295595, 59.47125504093786, 59.103721111051506, 59.84249561063705, 55.385274963994185, 53.481066226959236, 45.69305512212938, 53.05846221985356, 57.74536117430657, 57.06638713036814, 52.0980385042006, 54.57345024231942, 59.25411262819844, 53.87819836216589, 49.01088999163721, 51.943603023406006, 54.40516879481655, 57.01315664475965, 59.81295624086934, 57.17146350491432, 48.67522139703074, 54.43752442636798, 61.52618085184405, 59.9562051219325, 56.62106083285425, 57.040189619987245, 55.11984817443356, 59.7550699018663, 58.605050579194106, 64.15711064492503, 59.12642771197904, 57.549685893520234, 53.547087561699655, 57.93312503445534, 38.773139061466345, 26.14996340966994, 14.740844676571509, 3.5036674526429947, 9.667751116137351, 12.013604025686941, 6.715865538966272, 0.34733366221189504, 13.089896517415202, 54.71082733523462, 55.32570200581705, 54.593921092248735, 34.81363188835883, 40.82916705839096, 54.98643659776258, 60.11823823375087, 68.98167302531581, 44.61278730823148, 0.5422079827516311, 0.14469439704572, 0.23134091778868632, 0.31905453772314135, 0.140456352683325, 0.15142121592596655, 0.10988918403463979, 0.1141795522022632, 0.1414309544188361, 0.193889437904281, 0.18671431969250404, 0.1117031270217511, 0.1506090095086444, 0.12408326109570843], [0.03932485597268228, 0.051660736977693536, 0.10747242178167067, 0.026699862961146622, 0.015451188082806768, 0.020108563119485494, 0.014712250314562794, 0.03392057681095696, 0.05008870157443228, 0.04183255669270312, 0.02903504451105912, 0.09808772213516698, 0.06700817090008529, 0.13387977896678832, 21.47494923683905, 50.630103234321844, 45.62587276581795, 39.640002481399044, 20.774009919935658, 18.970560989072247, 29.87570320406268, 34.943815354377996, 56.60087631594751, 23.00915687314926, 0.07117753548006858, 0.019040883616394094, 0.9959800625520369, 3.3398832476908162, 11.116783503563175, 11.415521021812193, 10.731676374712299, 42.73030457958099, 56.831692111107614, 57.07374549681141, 55.24341067960186, 57.53836593320293, 56.689706233239946, 57.23656700503442, 58.253570910423036, 56.80889137329594, 46.68342613404798, 43.24694741156794, 41.94321824658302, 41.08179123170915, 42.849595623631636, 47.99960490195982, 53.04311790773946, 54.145633405254735, 51.77139528336064, 53.62303641534621, 53.45221719434185, 52.81149018195368, 49.63525287566647, 50.912368759032226, 53.88081066070065, 49.378580816330455, 48.79887019434283, 45.9148730001142, 41.04312058418028, 38.44571921133226, 40.994773449436316, 39.3630321564213, 40.715390866802586, 38.290871881669574, 39.31446536894768, 38.954117221217004, 39.06102142026348, 37.749255318795484, 39.32945666774627, 39.51500046637751, 39.06841901040847, 37.60477089112805, 39.09641688869846, 38.687443117941584, 41.09368778044178, 39.42543314349267, 41.32589209464289, 39.950548295051824, 40.934800409501605, 40.78133375413957, 40.65155821461832, 39.50082502057476, 45.342807077592425, 43.683185577392585, 47.6691020688703, 48.7880366079269, 58.453796140609256, 42.76238564522036, 29.723862371137066, 55.74042204887637, 52.962446520405436, 54.29808416674214, 49.90300955310945, 53.281394050967315, 50.89696561136554, 51.49384444759738, 50.39391771439583, 50.07363657797537, 51.85939365817655, 50.186910706181685, 51.8772247529799, 52.7449667838312, 46.614349272943315, 56.15757003907235, 52.65692134057322, 45.2245044708252, 37.26833743433799, 39.45174440260857, 38.83027622776647, 40.02108820023076, 40.36682944143973, 49.13070663329094, 52.0361082015499, 52.666272271064024, 47.66346954530286, 40.82872775293166, 43.737812426782426, 49.511258909779215, 56.88648762241487, 52.30158990429294, 47.41259474908152, 53.68762216260357, 53.57309287594211, 49.04876832039126, 46.71124750568021, 51.54385074492424, 51.312509352161044, 54.92824039151592, 53.65042240388932, 53.49241364386774, 54.70093511766004, 54.03820753097535, 55.0220517189272, 57.220520588659475, 56.22352861589002, 54.35340527565249, 52.0838983597294, 56.80115645931613, 57.4466452290935, 52.30007586940643, 51.20738198680263, 58.74116466891382, 57.38626034029069, 58.95867186207926, 49.92185654178743, 42.400594065266276, 18.886822308263472, 0.6775030325497351, 4.404782970105448, 6.764483317252129, 1.0799395605441064, 0.06946345971476647, 3.894503938574945, 44.62776291754938, 37.07674926327121, 36.43718327245405, 16.162644047890943, 15.218389322680814, 36.727736765338534, 51.769959695877574, 56.59434164724043, 30.909477203123032, 0.07282038805105033, 0.0480131242394207, 0.022619282225928, 0.040692487626426646, 0.030610824169050303, 0.07923894081144564, 0.05366169351844057, 0.05569332805011542, 0.057083655058616595, 0.029908798432217974, 0.018452104826968525, 0.041706711429381566, 0.04729806160133693, 0.08221483999683012, 0.014045643695299665, 0.04221518313692462, 0.036567717024515715, 0.03918089272995149, 0.051882438992540685, 0.01726682125140102, 0.026700855045008565, 0.03891172007687631, 0.02866930455990857, 0.062289421686962734, 0.05331517279809041, 0.035033074372838584, 0.01916525799090103, 0.24932397379269525, 27.599626318100963, 59.61302911081622, 51.0727152516765, 48.56960373540079, 28.132046884106053, 23.725418929130804, 34.95070695877075, 38.891880973692864, 58.17285245464694, 26.139337708873136, 0.12090123063253781, 0.08206695438392701, 2.1556554638570358, 6.8527165439821065, 11.098726872474918, 13.330848697693119, 9.016937728851072, 40.99592662626698, 61.56530649431291, 57.68346617298742, 59.501347464899865, 57.9193300585593, 59.64025035981209, 57.81839570691509, 58.795261998330396, 58.90860672919982, 48.62015131981143, 44.108460718585604, 42.98203837487006, 41.606439621217795, 43.50065023668351, 50.3504539305164, 55.46058447130265, 55.562522949710974, 55.257233112089104, 53.70154265434512, 55.91390848159791, 54.915378939720895, 50.40899922770839, 52.31042700429117, 55.033152026514855, 52.52347838494086, 50.19388860271823, 46.95292826621763, 41.883209905316754, 40.78530319275395, 42.488545371640114, 41.26817833992743, 43.35300437865719, 41.52170858075542, 40.540053075359715, 40.8432444449394, 43.121690442485196, 39.334583205561486, 40.5516593686996, 41.61070715996527, 41.79762378815682, 40.475428104400635, 40.71885824203491, 39.39629777785271, 45.55132419832292, 42.9546170849954, 43.77838150147469, 41.05411891014346, 42.97872004970428, 41.730978796559, 43.258330129808, 41.7606476045424, 45.659259980724705, 45.208187410908366, 51.16743264659759, 49.46459447183917, 59.50422648460635, 45.01213558258549, 31.715932200031897, 55.36708301113498, 54.31085932639338, 56.677437059340946, 52.4205671587298, 54.14899487649241, 52.18916693041402, 53.04916620254517, 53.39475839368759, 52.14083156278057, 53.16091845112463, 51.78069130066903, 54.67140751500284, 54.20222143973074, 48.426558817586596, 57.433371928430375, 56.2228931919221, 47.89295173460438, 40.661728920475134, 42.40472432105772, 39.49779302843156, 42.62538509984171, 41.46896054667812, 52.10383968968546, 54.83649615318545, 53.90341135763354, 49.94271178399363, 43.554061151319935, 45.513587074895064, 51.27839257640224, 58.00036622631935, 52.868027225617446, 49.77288492264287, 55.917858308361424, 55.88052911143149, 50.23829767780919, 48.26276848393102, 52.929004392316266, 54.43706943142799, 57.31432799370059, 54.28676812879501, 54.85233468394126, 54.79871980605587, 54.832762056781405, 57.61930404170867, 58.259438776200824, 57.42362876092234, 56.61032138332244, 53.74759128016811, 59.48623849499611, 59.14434509892618, 51.64425949896536, 52.485007778290786, 59.69600685181157, 59.49901365464734, 61.13939592915197, 56.80256851257817, 47.45658805293422, 21.60035917835851, 0.9583663712105445, 4.2042312026023865, 3.238767486426138, 0.5311674300220706, 0.09013788984908212, 4.651932985551896, 48.908884832935954, 44.32827034304219, 45.591210780605195, 17.840469268060502, 21.16722360734017, 43.19821980691726, 56.733240619782485, 61.698196395750976, 38.408786173789736, 0.2585699962031457, 0.0456562509099322, 0.04636388249515046, 0.043629446562619946, 0.07426756644441236, 0.04134898284269918, 0.06409681079188181, 0.06343214907833646, 0.022288393529672778, 0.017366292022709406, 0.03432317133692484, 0.06398581614297244, 0.02186582709151891, 0.11167742477189149, 0.15100149167401178, 0.2031783305949742, 0.23269157676446825, 0.15030623623921027, 0.15192271240295904, 0.06962207821948875, 0.13583990685161085, 0.12822903016762388, 0.08302438808905502, 0.15933544044533085, 0.21589563528616584, 0.10325635648182324, 0.0728798901001292, 0.5915299490574868, 37.14403360120712, 68.6709193260439, 58.115154389412176, 54.78747044840167, 30.838394049675237, 30.930620739536902, 41.57413890284877, 47.48384068089147, 65.77404891290973, 27.929126985611457, 0.30742553753718255, 0.20620488351391209, 3.6319897540154, 13.804428808150755, 25.105961830385272, 22.363013067553123, 16.689943959636075, 47.89370090730729, 63.29962168970416, 62.416480433556345, 59.77881985325968, 60.541418829271876, 60.12849523175148, 61.44956127289803, 62.492746999186856, 61.92524671554566, 50.45975862010833, 47.1040964126587, 45.65250958165815, 44.771058867054606, 45.72750137698266, 52.35214533344392, 56.429056890549205, 57.98215073923911, 57.53982897727721, 58.294273345701164, 57.96485700914937, 57.39845498915642, 50.368951828249045, 54.05648185360817, 56.762297538019, 55.40230589528238, 51.606192896443034, 51.20494619492562, 44.61113599038894, 43.29332159411523, 44.865015322162265, 44.131245766916585, 46.654333914479906, 43.711948317866174, 41.71229654742826, 42.26015752361667, 44.626495991983724, 41.66721282466766, 41.56048905464911, 42.636442261357466, 44.00000718332107, 41.3470297475015, 42.6563012215399, 42.511859939944365, 47.66026496887208, 45.37417427186043, 45.82665889493881, 43.824638012916814, 45.62855174464565, 44.488499164581306, 46.78688256971298, 44.11037875759987, 48.91926734678207, 47.55615741975846, 51.292862199967914, 53.92243093059909, 63.651344545425914, 48.819242985017844, 34.432471644493845, 56.504915529681796, 56.74230913962088, 58.41599625925864, 54.26066475529825, 56.954811388446444, 54.57570952753867, 56.93118303052841, 56.36452997884443, 54.04624838982859, 56.17795851922805, 53.839664997593054, 56.03521170154695, 55.79755921517649, 50.989172689376346, 59.28547590009628, 58.67020507012644, 50.37420780427995, 42.12156057357788, 44.625672294247536, 41.59002450204665, 44.27227458646221, 44.78340648835705, 53.592512530665246, 57.06601450520178, 57.08730513049711, 53.107319262719926, 46.09233671619047, 47.98268379703645, 53.99178235761581, 59.58799262200633, 53.79518531983899, 50.38803415913736, 58.185380504977324, 59.34701788809992, 54.81729615119196, 51.59958370270268, 57.956074822333555, 55.33935577638688, 61.1698256769488, 56.45807066271382, 55.94576989450763, 57.061068396414484, 57.51906787195514, 59.11671592343239, 62.313145591366684, 59.46581863587903, 58.93661245223015, 55.40393367890389, 62.31522052518783, 60.32342526220507, 53.25758918639153, 52.72704155214372, 61.496817988734094, 61.08223522863081, 64.58935191554409, 56.47732165551955, 48.9761927050929, 22.70610474771069, 2.979846683240706, 9.20577141546434, 10.797638873900137, 2.5524338503037733, 0.22091208626666378, 5.476816258122844, 55.440450945208156, 49.227134181607155, 47.11910340093797, 24.70125363719079, 25.75687327692586, 50.9657012262652, 65.65975104608845, 69.3679323504048, 47.5606014651637, 1.0150853760780827, 0.10090602171276847, 0.0885116690469365, 0.12620880268514156, 0.1671644147004812, 0.24680879988497306, 0.1699026427682369, 0.11322516752707382, 0.16174192179835614, 0.10819392338875802, 0.1333378636909108, 0.2237304777748162, 0.08113975050829111, 0.17518147886280092], [0.05497576030451925, 0.0344099844205043, 0.0722410647018302, 0.08699168165725085, 0.11826882995064221, 0.05516532876138246, 0.0649752416798184, 0.04236974137564821, 0.04222925234165403, 0.024786269172064723, 0.03107515963605575, 0.01794377676091127, 0.13185960511046071, 0.8228539975900805, 33.90284184486636, 55.4473582390816, 49.815870177361276, 31.067360447299098, 18.537825499811483, 20.15379886473379, 21.284416183348625, 36.49759954021823, 53.898528006769, 12.357601773354316, 0.18087746515389413, 0.07772833799883243, 0.5324752953264021, 2.9871283183174753, 4.911277649864074, 14.894515295182506, 22.32880803846544, 56.2993323418402, 59.4192091111214, 55.64923086474019, 50.36525303317655, 49.50549302562591, 51.8015936113173, 53.582690915753766, 51.56188580297655, 46.86023089193529, 40.72242367652155, 40.91440016223539, 38.83025269354544, 39.58063348647087, 38.97715722360919, 41.93306323020689, 44.302147357694565, 46.10624151845133, 48.832202496067175, 50.85459616876418, 51.1722767737604, 54.29413041760845, 54.31091423957579, 49.61017324078468, 50.45345144887125, 52.28085625556208, 51.437213267049486, 52.05750080846971, 47.325298478526456, 40.42617882451704, 40.27014693906231, 38.5299168094512, 40.199673714176306, 39.47478048263058, 38.44819422691099, 37.6818258531632, 39.77171959415559, 38.542872398130356, 39.57668758207752, 37.67058826261951, 38.87418323947538, 36.7511337034164, 36.78132026426254, 40.15580984853929, 43.13973726764802, 43.76128388989357, 41.843237030890684, 40.051486569066206, 41.22460472968317, 40.022053103293146, 42.014758356155895, 43.88397562888361, 48.86006701377131, 47.45682731751473, 51.121925307858376, 49.45182323455811, 56.8450830828759, 45.41894812737742, 27.6910920681492, 57.216688433001124, 50.34349956820088, 52.73200727278187, 50.023104683045425, 49.95000739251414, 47.591470518419825, 49.66746337952153, 47.67823334663145, 49.456796799936605, 50.98531307712678, 52.89525631935366, 53.84084563101492, 50.93886044717605, 45.94691091968168, 50.8404246453316, 50.633876554427616, 44.879316283810525, 38.7922449265757, 39.911328515698834, 39.920773583073775, 40.71322571846747, 38.49017143249512, 41.06718040281727, 43.03681427432645, 44.55910967242333, 39.32765629983718, 43.495547233089326, 46.5672416071738, 55.14118586817096, 54.07234784095518, 47.3097070570915, 53.02848746699672, 53.190222478682, 51.000371056218306, 46.20636001709969, 48.9603227953757, 52.92494473918792, 53.34132002245996, 55.26538379730717, 54.37179726939048, 54.93718731787897, 53.59999641295403, 54.12624512949298, 53.19058725910803, 53.778083785887695, 54.82172450711651, 56.223481547447946, 57.96793999210481, 55.93252012806555, 51.400492037496264, 56.14743071217691, 59.970549229652654, 60.18436939485612, 58.53920575111144, 63.28792125948014, 60.314341052885986, 63.544055954102554, 33.93332650584559, 1.4178060307618112, 1.0742488142944153, 5.180741048628285, 0.7536722130833134, 0.04702490146061586, 0.9708138290912876, 37.54860255026048, 45.26549716149607, 36.498482073507006, 65.40099228582075, 21.810386411605343, 33.835690867516306, 46.1928709860771, 54.406172921580655, 40.22482002935102, 2.023940925155917, 0.05791183440916001, 0.05166677375053687, 0.03675682199818473, 0.009554815215749607, 0.035612409213377584, 0.18034242934757666, 0.0547535756542798, 0.008396655940751155, 0.06497567834993524, 0.08012761046449024, 0.04830427212460388, 0.030846455577580683, 0.031761097526478196, 0.0591246243716488, 0.04183220812269757, 0.021748573504268162, 0.04442304853470095, 0.06284330325621752, 0.08963328305511706, 0.023409542139439334, 0.1495074516823215, 0.040603855084027016, 0.04944711825960586, 0.026247240978503422, 0.06634561975877132, 0.05077148892826611, 1.3789044536890522, 43.78246468882407, 62.92413711547852, 57.36168669116113, 38.95534884545111, 23.08527242752814, 21.764337785782356, 27.140624676981282, 42.32888137140582, 60.367669597748794, 14.557956322546929, 0.27497521751830656, 0.6159921783593394, 3.605435553096956, 9.942552370409812, 9.65426600748493, 6.346047809047084, 17.74870541787917, 57.70272501053349, 61.78745777376237, 58.60377973125827, 53.619219949168546, 51.83693808894004, 54.09571732244184, 54.69499664921915, 53.0942734595268, 49.631103008024155, 42.96157144731091, 42.43156902251705, 40.89617290804463, 41.25899999372421, 42.69808230861541, 44.37036521973149, 46.44607174781061, 48.372418342098115, 51.06593347364857, 52.72370361512708, 53.331827886642955, 58.12477988581504, 53.55058239352319, 50.812889606721946, 51.717274419723026, 54.967405257686494, 54.33407975781349, 52.40173193716234, 47.82736578295308, 42.79647888675813, 40.92463362601496, 41.090510660602206, 42.01726867306618, 40.73602645627914, 40.69013864763322, 40.949117060630556, 41.65157041242046, 40.24263151230351, 40.94102913333524, 38.8452479147142, 40.644937253767445, 39.24160342062674, 41.38533169223417, 42.65570502127371, 45.5042165325534, 46.42010565726988, 42.42896849109281, 42.34647712399883, 41.64912677580311, 41.44886232191517, 43.095147763529134, 44.29986846062445, 49.65903028365105, 49.52218271070912, 54.629646039778194, 52.757620350007095, 57.653973871661776, 47.51250536211076, 30.188220008727047, 57.204619299980905, 53.27712258984966, 54.50849579226587, 50.17111924386794, 52.1838991872726, 48.32618144250686, 50.999696408548665, 50.608228175870835, 50.59409587613998, 52.46353280159735, 54.380140150746996, 56.75746125559653, 52.31456510482296, 47.483291549067346, 53.710889662465746, 52.80915637170115, 45.80178714567616, 41.129412727971236, 42.044297725923606, 40.330520060754594, 44.002741075331166, 41.76597810560658, 43.106020573646795, 45.997940955623505, 46.77424469301778, 42.36158217153242, 44.18436250379009, 49.56249290897001, 55.767972776966715, 55.533799432939105, 46.46135330200196, 54.36859661532987, 56.23229511322514, 53.592461539853005, 49.70677337338848, 52.644393290242846, 55.60805774504139, 55.217224936331476, 54.810690879821784, 55.79873984859836, 56.38595004235545, 54.57891410396945, 55.230812026608376, 55.54361320311024, 56.23808845396965, 57.96690056400915, 57.842632032209835, 61.402441840018, 57.26057191048899, 51.07006765181019, 55.205693168024865, 60.09149551391602, 61.314682729782604, 60.60412968358686, 63.1271864521888, 62.08395365745791, 65.01381120374127, 38.82128223296135, 2.0153731203848317, 4.253310349679762, 8.349716086541454, 2.027780312684275, 0.010376879269437445, 0.7559614676621653, 43.310725150569795, 49.35070845388597, 29.1376131580722, 52.26287611069218, 29.38109232533363, 37.900239113838445, 50.46769357496693, 61.60477338298675, 49.1234580932125, 3.3575062117268963, 0.15536780979844833, 0.1057739742100239, 0.022833769607748237, 0.05067450602749183, 0.03871280534733688, 0.0071266468711978495, 0.007850417534955929, 0.048579512194039366, 0.03089251086836861, 0.008279432997017378, 0.06478254758422414, 0.038455602818078576, 0.03071638725457653, 0.11835958072615248, 0.2018351026720578, 0.15855760073229191, 0.14042655186307046, 0.2631710283458233, 0.18011490123406534, 0.12383593727023372, 0.3011174776381062, 0.18473160753567375, 0.14352203737343514, 0.10848884425696828, 0.149823141194159, 0.191319779823384, 2.1748289898518594, 53.54452233160696, 70.23644708818006, 67.27602251114385, 42.37334928204937, 29.144612627644694, 30.494037405137096, 30.284545575418782, 50.90399057634416, 66.88872768032935, 16.344963658240534, 0.3469548470550968, 0.24272207320938188, 2.008350974609775, 9.902682458200763, 11.503653737806506, 23.29391702528923, 26.25729318588011, 60.41691495526222, 63.35961826385991, 61.682938375780665, 54.998584178186235, 53.27565954577539, 56.096506580229736, 58.09435406038838, 55.174922174023045, 52.11625006891067, 44.17945561870452, 45.87956774619318, 41.83164642703149, 44.108496019917155, 42.25300704279254, 46.783234765452725, 48.98772839576968, 51.5394498455909, 52.50204263194915, 56.04856344961352, 55.18612446323518, 60.668605604479396, 55.63469456088159, 51.836283053121264, 53.52756592535204, 56.760701133358864, 55.48438933587844, 55.7794653215716, 51.54089327781431, 44.80087280273438, 45.116105848743075, 44.22897161975984, 46.05029283031341, 43.70581765328684, 42.73778846186977, 42.5394263575154, 43.771615412927446, 41.802695412789625, 43.23116771636471, 39.27611635577294, 44.31745636847712, 41.18201563435216, 42.0443840180674, 45.78102996272426, 46.63864051142047, 47.52322912216187, 45.497042517508234, 44.643876014217255, 44.317621108024355, 43.935637166423184, 47.657762496702134, 48.27377465463454, 53.14604874580137, 51.748712216654134, 55.29242853964529, 55.751412530099195, 58.57010618332894, 50.20156860351563, 33.51288372470487, 58.393132763524214, 55.956842745504076, 57.42536244853851, 52.57275119904549, 54.42036797923427, 51.34972480035598, 52.94678449630738, 52.391984847284135, 53.227265342589355, 55.40551439408333, 56.537380987598056, 59.27598768664945, 53.09582671811504, 49.01714617206205, 57.54845426928613, 55.09438022490471, 48.85974145704701, 43.57064493240849, 44.64636671927668, 43.31975052433629, 46.659738940577355, 42.30295842693698, 44.77940174841112, 47.675103295233946, 48.0433314846408, 43.63569744171635, 47.38602461353425, 50.66411018371583, 59.23257489358226, 55.987241114339525, 47.601621612425774, 56.75066771045808, 58.94058973558488, 56.602582546972464, 51.34747335987707, 54.82811404812721, 58.51303177495157, 57.40699398902155, 57.60644258991365, 57.965206100094704, 60.63231583564513, 57.98830493803948, 58.285040086315526, 57.524402295389486, 57.4200790159164, 59.281349566675004, 60.06211696132537, 64.52760204192131, 60.51968497614707, 52.11564602390413, 58.044324228840495, 62.17234426929105, 65.20475218372961, 61.09632830465994, 68.59308381234446, 64.90632257153912, 68.69282184108611, 40.118347291023504, 2.890022199961447, 4.798588935405978, 9.76505825596471, 4.15296386326513, 0.16293237646741254, 1.186837998609389, 48.3481074917701, 59.1753985035804, 52.7995857884807, 76.47183895111084, 30.836781955534416, 46.003608780522505, 60.695528753342174, 69.5509187636837, 57.69258176126788, 4.5957852371277355, 0.29391015308999247, 0.18912014220991444, 0.13009122903308562, 0.1730581436065897, 0.16165386765233933, 0.32783767448798307, 0.10944505222141744, 0.1645998587651599, 0.11727320676248883, 0.15934547619713893, 0.17619700501522711, 0.17861425756446778, 0.2084224629065683], [0.036058368146299355, 0.010325058209409398, 0.01960545019697278, 0.018972113818651246, 0.030569802075924895, 0.05373796523218194, 0.046077798451146776, 0.06884829111156926, 0.054274766871164885, 0.02418890636744759, 0.09070588275790216, 0.022467409125379017, 0.07788225272369963, 4.350844006384573, 44.772612125642844, 44.310615754896595, 44.6507558514995, 34.15131222817206, 19.886085333362704, 33.17235923582508, 33.84231182836717, 37.50937100379698, 53.65497235328921, 6.200640153500342, 0.12110604423909418, 0.3316954174830068, 4.30201736188704, 7.604526060242807, 8.560579765227533, 9.662786376091743, 42.3274536286631, 59.84145618254139, 56.37098620014807, 54.35214619482718, 48.60525415789697, 43.50452161604359, 42.29726314544678, 41.729476528783, 41.17393947416737, 39.03948368564729, 42.93883346742199, 45.26453618080386, 48.350468758613836, 46.090646174646196, 44.14376597250662, 39.54637942775604, 38.889151004052934, 37.91945088294245, 43.272799753373675, 45.84236406510877, 50.15231147889168, 53.08773486844955, 54.214623974215606, 53.209010631807395, 46.35905396553778, 49.16414091663976, 52.63608178784771, 51.29154820596018, 51.4132671971475, 45.38707102498701, 39.53600475865026, 37.47718795653313, 40.55156523181547, 40.03122360475602, 39.33170418585501, 41.6322958853937, 41.01719371734127, 39.69306822746031, 40.05422046107631, 39.0179184944399, 42.294803819348736, 38.46151851838635, 39.19833575525592, 42.563293980013945, 43.62880191495342, 44.3923108808456, 45.21884841303672, 39.94428426988664, 40.37677657219672, 39.145979958195845, 46.71289097878241, 52.04022669023084, 55.76243831265358, 53.361963456676854, 56.344447443562174, 50.51096124033774, 57.475639389407256, 41.22034503567604, 27.660593678874356, 56.19269094159527, 49.518695723625925, 51.665114741171564, 48.123963648273104, 48.29854049990254, 46.19946449033676, 50.19000153387747, 49.165074440740774, 51.284825263484834, 51.070259847948634, 52.87182015757407, 51.16765622169741, 48.34928812519197, 46.565998215829175, 49.18549037748768, 51.85046634366436, 42.75411728889712, 38.15376935466644, 41.205863644999845, 40.52994904979583, 41.47976667650285, 38.29418236209501, 41.531259552125015, 37.92470685897335, 40.28183560217581, 40.93918169698408, 43.461606963988274, 48.64969461194931, 57.01426667551841, 48.43781994235132, 49.367472664002456, 53.49381000764909, 51.245366219551336, 49.49353371897052, 48.64915332486553, 51.41661297890448, 51.98515661301152, 53.41733555639944, 52.105110537621286, 55.00997866353681, 52.089691700473914, 52.45510755046722, 53.5530456419914, 55.57824380936162, 52.698270966929776, 52.59941939384707, 53.09659550266882, 50.85640438141362, 51.0461647279801, 53.5054123786188, 56.89845869618078, 54.7794609685098, 55.8875423092996, 55.2329065722804, 56.95029674037811, 57.851139653113584, 58.330841602817664, 42.18582468648111, 3.6325668327270018, 1.506930003243108, 0.6919543312922601, 0.24825425458050546, 0.08678280012381655, 0.16520574238271485, 28.09435094556501, 49.78578952050979, 68.40913249600318, 74.85321798632222, 21.556024628300822, 25.22419971804465, 45.69416907525832, 56.92452676834599, 48.251260249845444, 3.8904874315184936, 0.10647430880776337, 0.04050798684118256, 0.04461966117002791, 0.03885096164360162, 0.004984296833901036, 0.06359563990225715, 0.03205684960008629, 0.02426831329601907, 0.03665398235522932, 0.07762306985715706, 0.02584465411341479, 0.01225387225032694, 0.011287610339481505, 0.021337343252173836, 0.05418243412409098, 0.06111315496626401, 0.010580698876912075, 0.04781877922434961, 0.04103404026658785, 0.016949611055033825, 0.08501133671210659, 0.060417979970694556, 0.05626479516767206, 0.025597062157166582, 0.016226422139293244, 0.04813640693863554, 5.988166341858526, 53.88014385777136, 50.13763004733671, 51.23983567760837, 40.4086301403661, 27.13720044782085, 27.990439514960013, 28.446505262005715, 42.42499905247843, 57.29040153564946, 7.33721653299947, 0.17757024826301684, 0.9481376878196194, 6.934329300157486, 10.847901105880739, 10.230161143887429, 8.02231094529552, 41.286766452174035, 62.6714188052762, 57.68577252664874, 55.80229351597448, 49.950419241382235, 47.80180761891027, 44.15740797596593, 44.30126090203562, 41.931647254574685, 41.412670612335205, 44.11739587783814, 48.58364974298785, 48.920883363293065, 48.35086884037141, 44.360265116537775, 42.59935232900804, 41.26238499918292, 40.58614876962478, 44.844744513111735, 48.675174328588675, 52.76952474348007, 54.86580018074282, 54.84820442814981, 54.64510802299746, 48.830759063843765, 51.3666812066109, 54.21274515890307, 54.024812636836884, 54.38120311306369, 48.49949136857064, 42.49185585206555, 38.739677321526315, 42.68610731247933, 42.96892981375418, 40.97933500043808, 42.028376825394176, 42.29648651615266, 41.34916743924541, 41.132177998942716, 41.179352345005164, 43.66879832360053, 40.08570532644949, 39.81969802610336, 43.35662472632624, 46.130207200204175, 47.585406534133426, 46.44310251359017, 43.028502771931315, 42.46734103848858, 40.4356199695218, 49.055785440629535, 53.461171965445246, 57.48364102455878, 58.14459177755541, 59.28156921940466, 52.943658367280044, 60.44310854327295, 46.56736320064914, 29.440714313137917, 58.08705060712753, 53.96013667506557, 53.16496241477228, 48.918059256769, 50.75345000913067, 49.00985448591171, 52.912977587792184, 51.384571136966834, 53.99535171447262, 53.150500635946955, 56.022648349885024, 53.79442438002556, 52.52292140837639, 47.61671097047868, 52.80627735199467, 52.26773200496551, 45.03008042612384, 38.58795219852079, 42.94679195650163, 40.780231568121145, 43.06059952705137, 40.0746952333758, 44.45246434980824, 40.627961235661665, 43.30104081861435, 42.97765316501741, 47.29525704537669, 50.09918297490766, 58.19993642068679, 49.58473667021721, 48.05787955560992, 55.40444750939646, 52.658639338708696, 51.90162581782187, 51.50399161923317, 53.07523819708055, 54.18937175504623, 54.86993043653427, 53.38314425560736, 56.99643165834489, 54.451154662716775, 54.90123487287953, 54.79383253282117, 57.98627315029022, 53.57552866781912, 53.67213664516326, 55.45809768861341, 51.22921389918174, 52.18290290524883, 52.92911421868109, 59.67737951586324, 57.69335054582166, 58.26916625422817, 56.718123805138376, 59.43160772323609, 60.22546798952165, 64.27375801147954, 44.44874986525505, 4.479847329278146, 3.4049379633318995, 3.761325497781077, 2.523067064823643, 0.25901543036583935, 0.15659229409310127, 33.00955733945293, 52.899429721217004, 66.92539399670017, 76.03537328781621, 23.982306718826297, 32.51413453009821, 53.85400518294304, 61.919433762950284, 56.88538151402628, 6.5317475218926715, 0.15800957207477864, 0.10388231926387358, 0.0650330123701884, 0.04453942112083878, 0.033335477158787756, 0.06474170743698074, 0.07322626909421337, 0.05242728455472858, 0.02430928176298978, 0.027227034874921365, 0.011083762961319618, 0.038013964621049744, 0.07334600863677841, 0.18555463111448675, 0.17704330234517976, 0.1928473131791238, 0.11449170238789051, 0.18125963577580068, 0.12240092435310926, 0.09027751703416148, 0.24553096522727322, 0.2069805168937291, 0.1477454494564764, 0.24022971340004476, 0.15691641057210584, 0.2487094793468714, 9.206862814964788, 64.36562384328535, 60.17987828100882, 57.49947563294442, 45.21977017002721, 31.49333377038279, 45.49090400818856, 45.65317638458745, 49.56731742428195, 64.06493102350544, 8.215010618009876, 0.3942133095716277, 0.646150608456904, 8.664173483848572, 15.57757939061811, 16.504882612536033, 15.046613043354405, 45.3243484035615, 63.33626054948377, 60.98807481027419, 58.61662941594278, 51.742738446881695, 48.70924011353524, 47.43293616079515, 45.86313301517118, 44.851447843736224, 43.662208741711034, 47.68900417512464, 50.43895829108454, 52.43347567896689, 51.25926709944203, 46.47736441704535, 44.07315546466459, 44.12058084241806, 40.28325157780802, 48.43949087204472, 50.684867366667724, 56.56914434125347, 58.33645843690442, 58.60406214191068, 54.8336838137719, 48.54453586762952, 51.821927178290586, 57.60148079164567, 57.072851196412124, 56.21301274145804, 49.73620291679136, 44.838449108985166, 39.98685767573696, 43.61062172920474, 45.744673513597064, 43.15026098682035, 45.17179958281979, 43.8979196548462, 44.49027599826936, 43.9485143076989, 43.53045632762294, 46.20998036476874, 42.750132160802046, 43.02467453864313, 46.696997534844186, 47.358815131648896, 49.87386242035897, 49.12638418136105, 44.155493859321844, 46.68037845242409, 42.657144531126946, 53.7839202727041, 56.6793982444271, 59.23487732487341, 61.238125908759336, 61.25636885243078, 55.87389638347011, 60.794403860645915, 47.03410563930389, 31.690358346508397, 60.163074847190614, 56.35049573836788, 56.00437794962237, 52.37573054529006, 51.53518622921359, 50.981457387247396, 54.19026605544552, 54.42062293329547, 54.626508143640336, 55.02055729589155, 57.470434404188595, 56.32093283437914, 52.218066953843646, 49.35573301007671, 56.77522174773678, 54.28283006914201, 48.1567781971347, 41.36969320235714, 46.28790609298214, 43.488714464249156, 45.25929589425364, 42.63236691874843, 47.47019083269181, 43.2481005883986, 45.28136314884309, 46.05427403603831, 48.288789487654164, 52.81948004999469, 57.902483478669204, 49.99149037945656, 50.1388067583884, 58.801926105253166, 54.40589051092825, 54.47163335738644, 52.934315281529585, 54.827808103253766, 55.65878183610978, 55.68162571999335, 55.26323826082292, 60.1719747051116, 56.07938935679775, 58.01940541113577, 57.87339518147131, 61.54800491948282, 54.848400546658425, 54.553218656970614, 55.27626445216518, 49.981762901429214, 51.68189464076873, 53.86481131276777, 61.086016393476925, 59.19588504299041, 61.47629614799254, 60.36195470440773, 62.16326790471231, 64.26515625369164, 65.45030432362711, 47.01142649496756, 5.895586638681351, 4.6175416438810295, 2.18044386275353, 3.446643544781593, 0.39423506646867723, 0.4061907265455492, 36.993140020678126, 65.28545887239518, 80.95076991665749, 74.70576824680452, 30.478530314660844, 36.67880519743889, 61.1442518234253, 68.03038843216436, 67.01448671279415, 9.269445211656633, 0.3965509196202601, 0.22736608591531554, 0.16285359198527952, 0.2517268392107179, 0.14069641399527752, 0.1960640244426266, 0.1586040256605033, 0.27749604515490994, 0.16181839269495782, 0.1304206621622847, 0.09697762242848836, 0.14181467253834973, 0.18444954928371216], [0.057043144329180645, 0.017671248642727733, 0.006343678678310807, 0.048841996899535584, 0.05117529387315435, 0.02733482727630725, 0.009058471637657814, 0.027136266862432805, 0.03664976121076653, 0.061690846548205426, 0.050342636738693526, 0.02055671689431033, 0.05120263938161154, 9.864138307109956, 51.40827009754797, 54.49303773141677, 38.992732955563454, 23.33875559991406, 15.41668180496462, 23.36281934092122, 31.55337937416569, 44.268250234665416, 45.23479284778718, 3.1128983824483814, 0.39619603705021644, 5.179817820748975, 8.22820301978819, 8.954443585488105, 11.660387727522082, 18.895796691217733, 53.535516569691325, 57.52546133533601, 58.1578258545168, 52.20727259112943, 48.15442869740148, 43.84617966990317, 43.897856896923436, 40.398298617332216, 40.74313379103138, 41.44958796039705, 46.180609656918435, 51.871576539931766, 53.86016330411358, 50.63417857693088, 52.02767118330925, 46.83403730392457, 46.150744730426425, 43.941324603173044, 45.71362795368318, 46.197401323626124, 49.085399335430516, 50.21759148566954, 51.86936824552475, 53.45118561098653, 51.17235129879367, 49.06681906792426, 48.13804103482155, 51.419288035362, 52.05641823430216, 50.700894171191806, 42.441814253407145, 36.86785951737435, 39.40166750261861, 38.65626811981201, 40.11280890434019, 39.6286746763414, 39.52023683055755, 38.68757255615727, 39.36101605815273, 38.78846376172958, 43.32169209757159, 37.97508578146658, 39.15010629161712, 42.316894608159224, 44.87261687555621, 45.91923859811599, 44.72112709476102, 41.420048590629335, 41.14010118669079, 40.91063860924014, 52.43825312583677, 54.77523657583422, 53.8571273896002, 51.85550658933578, 53.689657872723, 52.48246608241912, 52.99031103810957, 41.8077278137207, 29.159437225710963, 55.71402841998685, 51.38952901286464, 51.795741435020204, 49.068995983369895, 52.18627222122685, 50.918668085528964, 51.4421279968754, 52.843535946261504, 52.53581031676262, 49.29323396375103, 51.19313986070695, 49.15495864806637, 46.08011461073353, 45.51642687089982, 51.42072362284507, 50.242000395251864, 42.3411113216031, 39.18499577429987, 41.110102899612926, 38.82585571658227, 41.05353447698778, 39.92955184751942, 40.535954198529645, 40.580182844592684, 41.29536428759175, 41.11123254222255, 45.690886051424094, 54.0760584031382, 55.25396185536539, 44.58920209638534, 51.36580651806247, 54.44743233342325, 51.598061823075824, 50.79507420139929, 50.54845909918509, 54.99516779376615, 55.92609528572329, 52.744802044283965, 55.415457602470156, 53.54527934905022, 47.39460675947128, 46.57414890104725, 50.04198305068478, 52.996535839573035, 54.510519735274784, 47.42202804934594, 47.90867259425502, 54.65308612392795, 53.4172845655872, 58.22940911016157, 56.00129888903711, 57.141955514107984, 52.62580517799624, 50.54714510517736, 55.161229179751494, 59.606819998833444, 61.607079736648075, 53.49711656570435, 8.525658903583404, 3.659401483112766, 6.799410552747789, 1.8117459695185385, 0.11698266791720545, 0.036552988984171426, 16.904568210724864, 53.560156899113814, 33.97995172008392, 49.105203382430545, 29.781401580379857, 22.955963650057395, 49.916988880403586, 52.53312349319459, 50.376016016929384, 7.4292181768725, 0.08143757484973439, 0.030096309943004485, 0.042758783806235566, 0.0340014603740025, 0.06588975913942823, 0.004973896711523975, 0.035048181626705394, 0.045663996058846676, 0.07763832266772948, 0.013320883341704406, 0.0485309996762343, 0.015360534983506847, 0.021152549438298713, 0.07156198138311025, 0.034232343952622146, 0.08572704669448637, 0.009242480211410551, 0.07378435648617244, 0.057704124990249836, 0.04741306672052992, 0.05267016890068209, 0.03423847265601639, 0.08880128092583149, 0.0592056458305207, 0.04140638581086551, 0.06910467009630895, 14.071370613190437, 59.594444920939786, 60.60197630236226, 44.876817734010764, 28.183786869049076, 21.783706449693252, 23.48327729009813, 33.464936671718476, 48.025516079318145, 50.895506489661436, 3.1557720947650174, 0.15490965857621164, 3.5929501585422026, 8.086393648578275, 15.1259567083851, 11.09604004890688, 14.960429745335734, 55.35451181473271, 59.887430283331106, 60.86466135517244, 54.764465747341035, 50.831442417637, 45.41618677877611, 43.782562748078384, 43.19881208481328, 42.63267678599204, 42.2348347017842, 48.24805175104449, 53.87506046602803, 56.789048102594194, 53.87279725843861, 52.67553298704086, 48.80420461777718, 47.6076110716789, 44.48179583395682, 48.04468470235025, 47.967343407292525, 52.078512945482814, 52.88827842281711, 53.523039510173184, 55.530555632806596, 53.860010331676854, 48.56329264179353, 48.53025059546194, 52.17735667382517, 54.43362166804653, 50.56669812048636, 44.698946091436575, 37.9343911909288, 41.335792156957815, 40.23562615917575, 40.263949594190045, 40.8173018886197, 41.23915280065229, 40.3124967698128, 41.21444971330705, 40.679701220604684, 43.7115482361086, 40.935659408569336, 41.09276994582146, 44.31646400882352, 48.35137482612364, 47.32766366774037, 47.384008515265684, 45.03002551294143, 43.127981924241595, 43.29804805017287, 53.96289802366688, 55.37560632151943, 55.67929190974082, 53.799762725830085, 52.780350485155665, 53.511574422159505, 52.547624495721635, 42.32644557952881, 31.29223777401832, 56.88062367900726, 53.58499334704492, 53.21216029505576, 50.72245544002902, 53.27753051634758, 53.241177989590554, 53.53277875531105, 54.34210100481587, 54.64264869689942, 50.86004041856336, 50.613892078399665, 50.60252897201046, 47.538330247325284, 47.65281638791485, 52.693422917396795, 51.405959821516475, 43.442316747480824, 41.33385450609269, 42.65053533738659, 40.74713460860714, 42.4662898432824, 41.88917583034885, 41.56122646024151, 41.86304892263105, 42.063521262138124, 41.776666564326135, 47.534207836274184, 55.56942632121425, 57.68944386513003, 45.81202060945573, 53.06166679628434, 56.389052637161754, 52.892381222017356, 53.771078432759936, 54.12385640605804, 55.66605391040925, 56.54406470637168, 53.14291869440387, 57.738410734361224, 56.572823524475105, 48.857909710176536, 48.6426971035619, 52.42944740479993, 55.41163329155215, 54.439901382692405, 50.030290465201105, 48.88610762934531, 52.814922255854455, 54.56062016948577, 58.447736078693026, 58.815054278219904, 59.3759532128611, 54.22959566116334, 53.44173662124142, 57.672852239301136, 60.54091676588982, 62.792690646263864, 57.27424529290969, 8.589517051173795, 6.638463937467145, 15.076486795179306, 4.379753345443357, 0.48981930519784656, 0.04058925727862985, 21.813912622390255, 60.492302909974136, 43.441351844418435, 51.8982643465842, 29.89143975319401, 28.973677696720248, 57.37083758077314, 58.71164098862679, 60.56942062993204, 11.005134217200741, 0.08969023403140808, 0.025989410257147207, 0.04773003176876134, 0.09641358253335762, 0.08465889030166211, 0.04836044935209136, 0.027178321259036183, 0.034723096046476595, 0.09776354436912844, 0.08708087727427484, 0.05136647877553779, 0.011357870178237077, 0.06190856873628594, 0.1728134857670915, 0.08057368814104027, 0.235690581161649, 0.1023186955060209, 0.10183385378050228, 0.11458344907770235, 0.10853890810282, 0.10329380285956206, 0.11366032078982362, 0.2795508155418981, 0.2123930046875631, 0.14126595440170459, 0.14426440721557987, 18.137055366270005, 68.31463475381175, 68.14836548220727, 54.589747690385394, 34.35998624370944, 24.484436781175678, 36.134611637361594, 44.325395245705884, 54.6997348723873, 55.95606611620996, 3.72433215379715, 0.5494105575546142, 9.290496572371453, 24.11985835721416, 21.920232388281054, 25.029308911292787, 23.202359099541944, 57.753688366182395, 62.62248723737655, 63.20923066908314, 56.25974778206118, 53.043263035435835, 49.873313288534845, 46.89730513480402, 44.490158327164195, 45.83346812955795, 44.37466413744035, 50.96547765116538, 56.26394079577539, 58.070070666651574, 55.36067778064359, 56.52500198733423, 51.012977553952126, 50.946548292713786, 47.013536730120265, 52.60564027294036, 50.9928910962997, 54.36565876007081, 55.07181875167355, 55.06478594195459, 57.59255347713348, 54.8010536163084, 51.29346232260428, 48.39674488190682, 53.171214672826956, 56.83781100857643, 54.82683927782121, 46.427256138094016, 40.81069269487935, 43.681475423997455, 43.08395331905734, 42.55832825937579, 41.926669766826016, 43.19643905085903, 43.70905360867901, 42.478453113186745, 41.89016819000244, 46.373900136639996, 42.51615101291288, 44.008404977859996, 47.220237793460974, 49.80233015552644, 49.908842117555686, 48.80174529167914, 48.26518858632734, 45.37656299529537, 44.337299639178866, 56.91214384571199, 58.73650881551928, 57.32816219329835, 54.25511067913425, 55.6738829612732, 56.76457251271894, 53.31225918185327, 43.511789767972886, 34.320597802439046, 57.82929989599413, 55.703967540494865, 55.00912358683925, 54.046397439895145, 55.72919230307303, 56.929904337852236, 56.088057794878566, 56.52895965883809, 55.63207441760648, 51.82202915991507, 53.644927163277906, 50.488654721167784, 48.66414070129395, 47.555263119359175, 56.84748749579153, 53.44823598861695, 46.48521307976016, 43.98719672233828, 45.96529114630915, 42.80538658941946, 45.41504536905597, 42.12188613030219, 43.66786479949952, 44.37640566979685, 44.767516966789, 44.51569687935614, 49.30733880689068, 60.031130236964074, 59.554754457166126, 45.95300628292946, 54.00121565788023, 57.68567054502426, 55.488174423094726, 56.430770966314505, 56.42766052676786, 60.46142208960749, 58.96989768551242, 55.0747722964133, 61.618081984981416, 59.34487235161566, 52.130751071437714, 51.425571672378055, 54.04889991206508, 58.12745101990239, 57.42569192763298, 53.73942098309917, 51.33348226547242, 55.68788190041819, 56.21209490683771, 60.89929196142382, 59.73916076844739, 61.40844306638164, 57.83241425791095, 56.7218618239126, 61.52572193453389, 64.05414450553157, 65.92757440382435, 60.16480853480678, 9.978550903258785, 12.611729195041042, 15.673349941930464, 4.979578862267156, 0.34495440762369867, 0.0675282679918793, 25.681855986195227, 68.6339392200593, 45.752200541957734, 58.960974293370406, 43.460642060925885, 34.34235126741471, 65.64485780654415, 67.6633487209197, 69.98942405946794, 15.870254885765815, 0.25816479697823524, 0.15361389746108364, 0.14696275274599754, 0.23661419208492004, 0.1718563968015294, 0.09591843692525741, 0.20456035321037616, 0.1673774790739821, 0.12514741850956795, 0.21167413842293525, 0.24345664427645747, 0.1676571930968954, 0.12968982960427963], [0.06120783960326545, 0.03729528987840299, 0.01882757792519706, 0.07234457084127972, 0.019653160237677155, 0.07374967568584027, 0.031053308893235463, 0.05865161487412068, 0.06547555838140749, 0.02300918267499055, 0.025277626475379355, 0.05100900299787041, 0.005259062886433376, 15.320375850123746, 54.58779827240975, 48.44290333409464, 43.09689714062599, 28.446097335507794, 23.004557894122218, 26.695782792183664, 27.281276948990364, 44.84528187782534, 41.70217291001351, 1.4057774697580647, 0.03030968266689489, 0.8694791505413672, 5.164114611764108, 10.771074621908127, 15.226014410295795, 31.804824875247096, 58.88705330510294, 58.458365701860004, 55.980808427256925, 50.233194674215014, 45.894409994925226, 41.999229692643695, 42.133280615652765, 41.19179018082158, 40.854878194870494, 41.517484188079834, 48.22837714226016, 52.24977931668682, 53.52255705864199, 52.65873347559283, 53.02849531173707, 50.88105255557645, 49.36559777106009, 50.5150483500573, 48.68418793524466, 50.46171980519449, 49.622866030662294, 49.21211542621736, 51.66468720282278, 51.58381577460997, 50.08228540420533, 49.260062479203754, 47.638095732658144, 47.965362610355506, 50.59413902221188, 50.75071219475039, 44.22333517382222, 37.21743291424167, 37.56381350178873, 38.766761287566155, 40.340322063815215, 39.610651385399606, 39.50158988275836, 39.07086264702582, 37.777829785500806, 39.40859440834292, 40.82466809980331, 38.28148172747704, 41.990604400634766, 41.22604031716624, 47.67010619563442, 47.12227659840738, 46.11468638143232, 43.126632628902314, 41.63859521189044, 42.783280111128285, 52.16450306677049, 54.86151303014448, 49.115774170044936, 47.50694344120641, 51.9678315039604, 53.49572804666335, 55.932143580529, 50.2122413727545, 31.73881138524702, 54.487695463242076, 50.64764015136227, 49.65164446061658, 49.2093187762845, 51.18989998294462, 51.8534787239567, 53.46968350871917, 52.11879176478232, 50.37854202332036, 50.08760021578882, 51.738831766190074, 51.93798226694907, 51.253693411427165, 48.55831515404486, 54.22415141136416, 48.22443908260715, 39.70612972013412, 37.929319566295995, 39.8155403137207, 40.86676689886278, 42.35698123132029, 39.11467159948042, 40.614393757235625, 37.825180638221006, 38.89552485558295, 40.528034933151744, 47.58789723919284, 54.415516007331114, 51.792387808522875, 48.3310491038907, 50.362876076852125, 54.23811112680743, 50.60288590769614, 51.28573133099464, 50.96165334024737, 53.42938115519863, 54.210556476346916, 54.19008170404742, 53.49444150924683, 46.04879056253741, 40.58033189465923, 43.41812356825798, 49.46131144800494, 53.72427278949369, 54.43137414993779, 51.58274496755293, 56.73005957757273, 57.67190694808961, 56.23695488898986, 56.2832506241337, 56.92752345915764, 49.68495322811989, 45.25414189984722, 48.48118958934661, 53.96876588944466, 55.817782955784956, 59.93591077866093, 55.74212043516098, 17.525916753276704, 4.687399546946249, 17.48871699456246, 6.3340684002445595, 0.32534721457669813, 0.03957898648936422, 9.954763689348775, 51.88078234272619, 37.056400006817235, 51.861864751385106, 30.763010017333496, 28.351024966086115, 46.630532972274295, 54.199134534405125, 53.346485783976895, 12.150591823362536, 0.04658518614427698, 0.060575690661226554, 0.03411335900666253, 0.03207352924941769, 0.022136355720220074, 0.04582939444169883, 0.032210530668136575, 0.07771524555620649, 0.020722092294524756, 0.04700605186723894, 0.11600291807084315, 0.04458733992050252, 0.009301139563772707, 0.050787404404893044, 0.06809934823503418, 0.021698239612423127, 0.05921881105149946, 0.040872755775889086, 0.05450357435150974, 0.04315887705513066, 0.050930781590361754, 0.03359098280329378, 0.056794640728302544, 0.10772366031643846, 0.004455040203362343, 0.02468705695543078, 20.420023856624482, 62.35034535008093, 53.11106904860466, 50.546058608639626, 32.7552387022203, 26.421220802491714, 25.713566387853316, 29.54149373116032, 51.17020968467959, 43.829309555792044, 1.2361071354919866, 0.16811152920126918, 1.8983326587946185, 6.563710916426874, 13.165430580416034, 6.069172111249739, 32.501912424641276, 59.85486676616054, 60.209766741721864, 56.90488353852303, 51.118520690548806, 46.80122667743314, 43.402681196889574, 44.14620960912397, 43.47517836478449, 42.15263751245315, 44.65234833378946, 49.337360628189586, 54.71621667185138, 57.21886927081693, 54.91216651854977, 54.972037576860004, 53.97924254017492, 52.0801015054026, 51.175853975357555, 51.856071410640595, 52.01486072232647, 51.69813717565229, 51.7226323773784, 52.99456288737636, 53.478430394203436, 51.758247498543035, 51.97860625482375, 48.09446742457729, 48.35394005621634, 51.16523219693092, 53.44310945080173, 47.293068362820534, 38.58501434326172, 40.74909971606347, 41.1496639251709, 41.73051595687866, 42.48883562703287, 41.22072158321258, 40.99703665702574, 39.459899010196814, 40.292955521614324, 42.28974788419662, 38.722724837641564, 44.98258052333709, 44.22062089366298, 51.36629289196384, 50.757607721513324, 48.58121002874067, 46.4509472539348, 43.90381889958536, 44.51786202769126, 56.53491381675967, 56.01428193430747, 50.967874219340665, 49.64057945436048, 53.44014413895146, 54.58333461515365, 56.693950237766394, 51.01501326407156, 32.72511489929692, 57.790950882819395, 52.82405745598578, 51.91576988466325, 49.85586658600838, 52.81294538128761, 52.31718524809807, 56.841121489001864, 52.649814005820986, 51.06936162517917, 51.00343050495271, 53.09716816871397, 52.07619874708114, 51.84973286044214, 51.01342862652194, 56.084978734293294, 50.929242795513524, 42.04352109662948, 38.90162021883073, 40.1190846966159, 42.5036935652456, 44.78646985946163, 40.62947919291835, 41.93979793979276, 39.644434759693766, 41.96905882127824, 41.36027951394358, 49.493965179689475, 54.95362989364132, 52.51520610624745, 48.89138321722708, 50.29256759151336, 56.63708371500815, 53.45426859394197, 53.426694331630586, 51.041595166729344, 56.17201612841699, 56.10573983961537, 56.115247664913056, 54.88704373759609, 47.97211300942206, 44.123028401405584, 46.45650525246897, 50.911713723213445, 56.156769875557195, 55.64896806593865, 53.866725429411865, 57.18993786842593, 58.432689866712025, 58.61708441088277, 58.046677650943884, 56.83587335771131, 52.09481823828913, 49.49745216677266, 51.3465202239252, 56.14066854599984, 59.1959713351342, 63.16967356589533, 58.41109721891342, 18.995813208241618, 1.1738520115613937, 18.569312326369747, 6.74662672704266, 0.4581802416472666, 0.04527120745830959, 12.33494616323902, 59.2277229216791, 41.25607390557566, 56.467280387878425, 34.45180892944336, 35.540988368372766, 53.164711383081254, 58.79258301950271, 63.59726290549002, 17.99068820091986, 0.05797264263814977, 0.11835771147161724, 0.03715617980267252, 0.006844714544938818, 0.03835771210311401, 0.03800417401737744, 0.05389071550340422, 0.08817577013565649, 0.03003391208157184, 0.028583604219039122, 0.04191485368796895, 0.04129767793441012, 0.062292486038659854, 0.2004077123297799, 0.09270655201567758, 0.07500247459017462, 0.21470654425361466, 0.09939929530505212, 0.23054447746084583, 0.11035675813834514, 0.22577979361578343, 0.33159708243704616, 0.15395440822166784, 0.22444012034083569, 0.18272897709281216, 0.1322703048466675, 25.321752986600323, 70.93952409682736, 61.855805074014974, 57.243733175339244, 38.66435604710733, 33.96019081915579, 38.88812726543796, 40.90047574812367, 57.207506164427734, 51.02793747378934, 1.7973969588356635, 0.23903812492086043, 2.82924335810446, 12.342680096626284, 18.153405766333304, 22.517491694419615, 34.27746742002426, 61.78227632276474, 63.834813410235995, 60.02720002205142, 54.992535883380526, 50.070526138428725, 45.94366711954917, 47.56668506130096, 46.39950536912488, 44.53544993554392, 46.70106111034271, 52.54845603819817, 56.93812170336324, 58.64529801953224, 55.54224037354993, 57.85137499532392, 55.850162121557425, 53.969401313412575, 54.78663890592514, 53.8420811776192, 57.26401575150029, 55.771804932625066, 54.96796615662114, 56.24592142720377, 54.94614208898237, 53.28501832100653, 52.04267032684819, 48.02452371966455, 49.928206859096406, 54.10759818169379, 54.78418350219727, 49.2153827605709, 41.10515679082563, 42.107130173713934, 43.62007071894985, 44.32097865689186, 43.38731727292461, 42.71004553764097, 43.247327881474654, 40.78608374441824, 42.759224214861476, 44.608327573345555, 41.02657602679345, 46.512814798662745, 45.15349388122559, 52.87662506103516, 52.43146742543867, 48.92445272014987, 48.105014677970644, 45.41170743203933, 47.075133631306315, 58.36272262757825, 58.28468707300002, 51.74296202198152, 51.15113127616144, 55.929480291182, 56.95543112293367, 58.119449384750865, 54.13798478341872, 37.515846836951475, 59.9977037983556, 54.72699926745508, 52.84071183973744, 52.19943177315497, 54.1913878533148, 52.926776486058394, 57.7799133331545, 54.28106892493464, 53.220314902644006, 53.11216338988274, 53.215819866426536, 55.153184398528076, 54.42059155433409, 52.83802109379923, 58.42757901837749, 53.469126532154704, 43.97337821222121, 39.653264014951645, 42.88816428953602, 45.186873251392, 47.13961739693919, 43.699675221597, 42.640137134059785, 43.38921177771784, 42.44428142424553, 43.494731380093484, 51.364245414733894, 59.575476338786466, 55.016176008409076, 50.40509646938693, 50.962292686585464, 58.35514853077551, 55.54941046622492, 56.14910164187032, 55.50617417981548, 59.14749083980438, 57.09239636698077, 57.40808440792946, 58.14092828381447, 50.4782094493989, 45.52194956810244, 49.13389552024103, 54.64108367120066, 58.47727937083091, 58.1537465895376, 54.397453492687596, 60.95718222279703, 62.10937453854469, 60.191100182071814, 60.914993209223596, 61.42488956451417, 54.9817297535558, 51.103650985225556, 53.010746586707334, 59.137955557915475, 61.55279805583339, 65.59804039616739, 59.32006728264594, 21.50051916799238, 11.687433450452744, 26.940936811508674, 10.328213534047528, 0.6064209209815149, 0.2138689956477573, 15.224087545948645, 67.93039152699133, 50.925477320148104, 65.81213904965308, 39.773547418655895, 40.64415670210316, 60.01156153217439, 68.04747427663496, 72.17341546089419, 27.07764906267966, 0.2426851171279146, 0.2105172843702378, 0.15637664034241633, 0.09981747205939986, 0.17957733733759773, 0.20049821795715442, 0.13927181221304402, 0.1897309134684263, 0.15198775326773045, 0.1430230230213173, 0.167698607810082, 0.2773929603638188, 0.14773075589008872], [0.023985100166511633, 0.03752522350799653, 0.01957527590885518, 0.040525656659156084, 0.04511867935258535, 0.0733981792244219, 0.03270350058653182, 0.04739784838391408, 0.01845605401021819, 0.01043568513611512, 0.05430560191011718, 0.03754023883131243, 0.1460656637866651, 18.561714695345973, 49.849798679351814, 53.161338144733065, 48.23854784811697, 25.21459383349265, 13.7066960911597, 23.43935851127871, 38.97747885796332, 46.10069528702767, 36.04285170955043, 0.3110559669233138, 0.1643733878529841, 6.33938713419822, 3.241580806432232, 16.530719264861077, 13.112144201032578, 47.08412370374126, 57.4769651505255, 54.480799936479144, 53.3195234114124, 46.745293678775916, 44.91178566409696, 46.53771008214643, 47.42416181871968, 44.46834602663594, 43.488110419242616, 40.70573791380852, 47.050803169127434, 50.79923975852228, 54.53071209692187, 52.802425584485455, 55.42339647969892, 51.19522656163862, 51.806276921303045, 51.59730872800274, 50.27769788619011, 51.241585054705226, 51.24131441116334, 52.03352335960635, 50.27443055183657, 50.45658542263893, 52.79286284600535, 46.914410591125495, 47.08057788110549, 47.19263215218821, 50.92988606422178, 50.018421373059674, 44.14251865879182, 38.296759359298214, 37.36720077453121, 37.429166378513465, 38.9441857799407, 39.40129879982241, 39.025822070337114, 38.10959169941564, 39.78015269002607, 39.579507766231416, 38.06780276759979, 37.658793695511356, 38.45891014222176, 42.521277550728094, 48.26362748299876, 47.988736014212336, 47.86854674739223, 44.28637550723168, 41.25442258773312, 43.663220713215495, 52.045086506874334, 53.14424837789228, 53.81696231903569, 52.422026280433904, 55.1377930179719, 51.76004002171179, 52.87704083227342, 51.64182370708835, 36.166492662122174, 53.76678735979142, 52.192504867430664, 49.81971802250032, 49.928850127804665, 52.421057455001346, 51.14794238921135, 49.90539435417422, 52.2274100395941, 55.33200133231379, 52.54720872448337, 51.74821799801242, 54.372636656607355, 53.07927823835804, 54.4645260226342, 50.67529678344727, 45.51690540006084, 40.26358089139385, 38.881694578355365, 37.504742606993645, 41.232727958310036, 40.717657996762185, 38.87669355638566, 39.30853474524714, 41.208483788274954, 39.68079120882096, 39.78967620480446, 44.964353269146336, 51.99849267159739, 49.87090103087887, 51.71060639043009, 50.06518387025403, 52.64689968478296, 52.23173249152399, 52.370945253679835, 48.55416528640255, 54.16044035265523, 53.779727258989894, 49.50609314826227, 46.628363901569, 40.950132954505186, 41.79039485992924, 45.231172500118134, 44.92554926103161, 51.238360866423584, 54.093791438687234, 55.011669205081084, 54.9699979443704, 55.761167464717744, 53.79351439014558, 52.97520206820581, 46.07539207704606, 45.34791792592695, 44.75866025493991, 49.86096174486222, 58.247687355164565, 64.27442089203866, 56.86895855011479, 64.31460165208387, 25.735374766011393, 5.944816797010361, 14.08693555862673, 5.165611486281119, 1.4079605139070943, 0.17290932336641898, 6.73366476451197, 47.1957935825471, 39.759713219058135, 41.89345121383667, 27.37832227060872, 16.121226760648913, 41.11538633223503, 51.00039851280951, 52.435570224638916, 18.695330235265917, 0.19644472417571854, 0.07371271960437298, 0.04118832654409832, 0.04881909470103922, 0.054889161725558584, 0.028244047237920667, 0.034486654499966296, 0.10112955084731502, 0.05944258533418179, 0.011622256697005322, 0.03407011717377651, 0.06079006121463834, 0.020508357594090126, 0.10772333089863101, 0.03115998855191133, 0.016032499430190413, 0.0738327042950738, 0.02932371793224687, 0.11590535677368603, 0.036324231299541654, 0.015350854504973659, 0.043502337254223325, 0.06461970793503909, 0.060993763993704514, 0.012064108441043045, 0.18008315455048315, 24.615473362707323, 57.67051058430826, 60.81212120671427, 54.74994121059295, 32.01573071941253, 13.516550371723792, 22.064810952832623, 42.53843007549163, 52.10986052789996, 40.519695974165394, 0.4528243983945539, 0.2134123612796107, 5.824578010266827, 5.169895695101831, 5.429486978438593, 11.43252351591664, 48.947555480464814, 58.822808804050574, 56.249792806563846, 55.751996963254875, 48.78483987623646, 46.251969337463386, 49.16238761717274, 49.30843314816875, 45.71349851546749, 44.375134821861025, 42.71393652885191, 47.9527678797322, 54.0723596080657, 56.43829799467518, 55.16455534965762, 57.30175287492814, 52.96456852266866, 56.510618655912346, 53.41848088848976, 52.00334464350055, 52.94077542520339, 54.00538513737341, 52.53422960158318, 53.26409247613723, 51.17982341397194, 52.79058002656507, 48.25966588912472, 47.00055760722007, 47.855057716369636, 52.75683195360246, 52.25650225916217, 46.24821955157865, 40.922770500183105, 40.728746537239324, 40.21291171350787, 41.39601230621338, 40.110749659999726, 40.82919451498216, 40.415345238101104, 41.84990113781345, 40.67669276268252, 39.428147423651914, 39.665082116280836, 40.86314262882356, 44.52329058800974, 50.57354657880722, 50.587686723278416, 51.461143647470784, 44.755459600879306, 44.121118207131666, 45.31768037426857, 53.941556407559304, 53.100082489752005, 54.67048183564217, 56.11971132216915, 58.42922249147969, 53.55290835903537, 56.60695206734442, 53.6582749889743, 39.30356902460898, 56.203406856906035, 54.913307928269916, 52.128017179427616, 51.19332813447522, 53.08344379548104, 53.34182993058236, 50.06567808889574, 52.530934810638435, 56.40624830799719, 54.14573930924939, 52.81969185798399, 55.597714454896995, 54.59023798665693, 55.011779031445904, 54.02325545587848, 46.67285142406341, 40.27185317008726, 39.79094313037011, 40.69814420515492, 41.77887093636298, 42.18090603428502, 40.749531176782426, 41.41651453510408, 42.83553392656388, 41.732990972457394, 40.775136409267304, 47.20494839452928, 55.6364635498293, 53.233454842721265, 52.504890272694254, 49.9602565457744, 55.03791378390405, 53.98108605415591, 54.303606863944765, 52.28777139417587, 55.34941665587887, 55.74302650267079, 53.17192069945797, 49.40337411818966, 43.86952953953897, 44.1559253200408, 46.14855604787027, 48.00379399330386, 53.07889384608115, 57.535133900180945, 56.55176431901994, 56.942703031724506, 58.09761747237175, 55.72381473356678, 56.057486841755534, 49.17998729213592, 47.6653052145435, 47.496360886481504, 51.10522777803483, 62.13018271230883, 64.68309264029226, 59.46073916650588, 63.83671968213974, 29.668702079403786, 2.918719731030926, 3.0715102678345096, 6.136465764814808, 1.0167021893205181, 0.12435771209458191, 7.725421353693932, 53.62785308591781, 44.21057962602185, 49.19467264606107, 30.508289337158207, 22.90103477816428, 47.30403530982233, 57.96297427146666, 60.30372319682952, 25.680953841055594, 0.057359937007629105, 0.07520325091337005, 0.025180061347782615, 0.03585673380462873, 0.04071285407389364, 0.035052337653694615, 0.03498549648230115, 0.07645509220779904, 0.025797139425131104, 0.08123520506365646, 0.05953000745766106, 0.04612873180679256, 0.02853885510816209, 0.14266067875489113, 0.16187053263908432, 0.0965392899008528, 0.11231187580814285, 0.1639276778986377, 0.20502089462693662, 0.1555277536352796, 0.14798218594683757, 0.13104294006141926, 0.13707660258777682, 0.13429752671189849, 0.1094233719331603, 0.3671219278006785, 30.376170181459, 66.4753883115707, 68.46755227734967, 60.848493345322154, 37.59272529232887, 25.144132375717167, 35.94677325217955, 53.05128036006805, 58.455172892539736, 46.3869773187945, 0.5132923311283512, 0.2043160937365986, 11.449436776099667, 6.503008805936383, 23.20105883382982, 16.127323104489236, 51.54392134758734, 59.74100428242838, 57.66978102345621, 59.01449895674183, 51.55489221695931, 48.614185394779334, 51.135885023301654, 51.10717719601047, 48.310158560352946, 46.936591594449936, 46.19914285598263, 49.95366304151474, 57.013764612136356, 57.08708547776746, 55.77502519853654, 58.69652417398269, 56.1367775547889, 56.86387515837147, 56.29687301574215, 56.352860927581794, 54.78996899820144, 55.648540527589866, 56.36383179695376, 53.22249966282999, 53.94309397666685, 54.12172655905447, 49.57701744571809, 49.12349339454405, 48.718995048153786, 54.89534739525088, 56.16385759845857, 47.84685211796915, 42.89732694625855, 41.79061059028872, 41.9970606219384, 42.070099076917096, 42.216627059444306, 42.62266689731229, 40.61762971262778, 43.674568130124, 42.63639911528557, 41.92645011409637, 41.35756915615451, 43.204719174292784, 48.09240033549648, 53.229748202908425, 51.905720772281775, 54.00272969276675, 48.99991127752489, 45.27951571249193, 49.177269089606504, 55.525993916296194, 56.6559071694651, 56.30437650988179, 58.498173836738836, 61.26797122340049, 55.43026454987065, 58.495039862971154, 56.214903323881096, 42.445469902407744, 57.655456527586914, 56.01937709316131, 54.24358283319781, 53.0984547061305, 54.776852592345215, 55.467731029756614, 52.23501551535822, 53.374777840029815, 58.22876584145331, 56.664920776121086, 55.337551486107614, 58.78212205825314, 56.05793791432535, 59.98042968011672, 55.49265769220168, 50.644039415544086, 43.57604603613577, 41.89207446190619, 41.80182856898154, 44.77315733509679, 42.797502625373106, 42.36202932173207, 44.27644798832555, 44.52835829027238, 44.236788903513265, 43.63094745143768, 51.036119537968794, 57.049709212395456, 54.149712670233946, 53.967028279458326, 50.68100383204799, 56.86844079725204, 55.17391412488876, 57.86825687654557, 53.78781126391504, 58.56986691874843, 59.64215663171584, 54.98812713930684, 51.414090894883685, 45.93228832367928, 47.32800099157518, 49.974063288780954, 49.729103426779474, 57.17802170784243, 60.460531711578376, 58.124481785681944, 59.50296348141086, 60.92858814424085, 58.85760022747902, 59.229915526605424, 51.35025432032924, 50.625361088783514, 50.150632704457934, 54.41796356631864, 63.933386495036466, 69.5172256039035, 61.33588314056397, 66.58597561620897, 30.383299089247185, 11.965420649897668, 26.901579749199655, 12.929574539584499, 3.237053655808972, 0.28102415583787427, 10.060175426544683, 59.8933962083632, 52.04461190008348, 56.39919980879753, 35.841124211588216, 27.67570657114829, 55.731996797746234, 66.3684174322313, 69.15025649532195, 34.197941364780554, 0.41873458893068377, 0.18954814021145144, 0.1357158006078774, 0.113303231886558, 0.2129655941239288, 0.16552314793150272, 0.15461171166070048, 0.23740482546629446, 0.23840437102462017, 0.23941481035322915, 0.14261777783113141, 0.14659000500555963, 0.11178201875619351], [0.017249771964646155, 0.0031162318895616, 0.032348384359671224, 0.06605378622489591, 0.018207969842478633, 0.05727342269834011, 0.06997514516115189, 0.03265323372738015, 0.023365785112424244, 0.0535670931511108, 0.03616487735041207, 0.0698801119541449, 0.5812635128536533, 25.00765350557143, 51.225115022351666, 43.407368429245494, 34.26449221949424, 18.142230933712376, 32.624839505841656, 42.075394276649725, 36.813064006067094, 45.55642327954693, 31.828312027838926, 0.2815545644731291, 0.9718792428893428, 2.8621836679597057, 8.424470578470538, 15.343571766730278, 19.003763852580903, 58.29482247752529, 57.74282732317525, 56.47292860092656, 44.49669691824144, 48.59515013233308, 50.776560614185954, 53.28073117040819, 48.329754721733835, 50.21948599046277, 45.233114073353434, 41.11389583156955, 44.91385667554794, 52.53028369718983, 53.82475606856808, 51.71465035407774, 49.87080297162456, 50.83324278554609, 51.130911457923155, 54.62515884830106, 51.50566647129675, 54.70455546532908, 52.19578789126489, 51.66425181973366, 54.49607364593014, 51.938809887055434, 49.136688247803725, 48.1950330734253, 45.94220799784507, 48.272648934395086, 50.702467041630904, 49.58889046022969, 43.38338705801195, 38.56689691543579, 36.93947022961032, 39.260775966029016, 42.44387742011778, 39.8898692284861, 37.46303604495141, 37.18475957070628, 39.498514744543264, 38.90742924905593, 38.76463144056259, 37.501945957060784, 38.95241491256222, 45.36666685535062, 50.88604965517598, 50.6139430692119, 47.342337254555, 44.79953527450562, 40.437738049414854, 44.617058769349136, 49.870261684540786, 50.85403134745937, 52.30741462399883, 52.38430484648674, 50.12535695106753, 49.12378757230697, 50.82666104839694, 54.18117007901592, 41.406590938568115, 52.30655954730127, 52.9608226591541, 49.8003101348877, 51.28302489557574, 55.091677711855986, 49.163556483484086, 49.851897147394, 55.12733205672234, 51.44172791511782, 50.41130165899954, 48.76931513509443, 49.54578753440611, 44.28834845942836, 46.22817623999811, 44.68851258677822, 40.02473992686118, 39.09749946286602, 38.11469078063965, 39.030599517206994, 39.43046162205358, 39.890716460443315, 38.83355140686035, 40.71970155162197, 40.10670569635207, 38.42078078177668, 39.610973019753736, 42.70732733511156, 49.15235419427195, 50.8461630728937, 51.774058572707645, 49.79309297377064, 53.0186854639361, 53.672505347959465, 50.63534744324223, 49.31958052419847, 49.49521249340427, 47.49943210232643, 42.725695794628514, 43.040305183779815, 43.06158011959445, 42.62190595749886, 43.53169579659739, 43.42948667464718, 44.705708257613644, 49.21457082994523, 53.91901062380884, 56.48187552728961, 51.26708438319545, 46.429899815590154, 43.835244101862756, 41.847673231555575, 43.72201704209851, 43.240726532474646, 49.282506281329745, 56.86807209445585, 59.23564610942718, 60.82075042109336, 60.1522804844764, 44.236114255843624, 4.416691776244871, 2.580416529409347, 1.7849896439621527, 0.46596593193469515, 0.07104509419971897, 2.3543311126770514, 45.612905410028276, 39.44721406505954, 38.23701773920367, 42.55158962741975, 25.57674627150259, 43.44918089528238, 51.58409818526238, 51.1541122774924, 32.106149196624756, 0.6967868139186214, 0.019638750123821443, 0.055309763148186676, 0.0064668598708756755, 0.021462108331522154, 0.12291145300672901, 0.039012721108813445, 0.050977256314288226, 0.04389807529326889, 0.040634226639785116, 0.025276869963554126, 0.05685204369646888, 0.03249687901247413, 0.010913209764346963, 0.0160073698310542, 0.009985340349826842, 0.025956326750137156, 0.02774007629693276, 0.031827567145228386, 0.0345342975079773, 0.023902303298875213, 0.03336009156379489, 0.007864681134496124, 0.04517227869420763, 0.0739250178899496, 0.5930891524880164, 33.02747864877024, 58.48028782875308, 51.25522313579437, 42.44339889095676, 30.033555069277366, 29.522835016250614, 40.81794123495779, 43.16046307163854, 51.20412249718943, 37.127300770052024, 0.2056240969367566, 1.2519391698222007, 10.470746582554234, 12.143664917638226, 6.285333441149804, 22.87810067976675, 60.29117553464828, 59.568090515752, 57.85822345364479, 46.53934178813812, 47.75173464129048, 52.38965888177195, 54.90591818286527, 51.22577005817045, 50.44910154035015, 47.02907716074298, 43.31838161714616, 47.45512893123012, 53.63079486354705, 54.629163588246996, 51.798451792809274, 50.74839407397855, 51.62979772014003, 53.905396076940725, 55.75871598336005, 54.459175909719164, 56.57267055203838, 54.188238190066436, 53.52380044998662, 55.852927392528905, 53.27483977040937, 50.92090775889736, 49.965292869075654, 47.09768333742696, 48.93134040217246, 52.30322945502497, 50.18072120604977, 45.78729791025962, 40.24675392335461, 39.21377812662433, 41.93207479292347, 44.202597602721184, 40.81391296079082, 41.19615577882336, 40.160669665182795, 41.4746166044666, 40.722662941102065, 39.314508515019575, 39.74391391200405, 40.382358104951926, 47.24885932860836, 52.683275745761016, 53.77272975060248, 49.90107974698467, 45.346964789975075, 43.30262153379379, 46.732494984903646, 50.51435801290697, 53.03910532305318, 54.81371894959481, 53.01399038683984, 52.843018193398755, 50.05117316399851, 54.65338030169087, 55.195938233406316, 43.50582776531097, 53.09098259095223, 55.03410516246673, 52.020787423656834, 52.76565728649017, 56.19047088007773, 51.95953176867578, 51.13954067230225, 56.38931151359313, 53.59606619804136, 52.26828898152998, 52.69124600195116, 52.184126684742594, 48.07853475693734, 49.21883444632254, 45.99127292633057, 41.50346563708398, 41.29607423659294, 39.7420782427634, 39.93869881476126, 41.37138374390141, 40.27728173040575, 40.37100676567324, 39.68883991241455, 42.08853813909715, 41.68097642160232, 41.00739171428066, 43.79449459814256, 51.62666766874252, 53.32110412659184, 54.4128684074648, 51.207483968427105, 53.3514162032835, 55.748149118115826, 52.80895240845219, 51.37819728543682, 51.96900037027175, 50.71101780860655, 47.002055952625895, 45.210721262039684, 45.48809559114518, 45.50140027076968, 45.9458165784036, 44.84209299087525, 46.60536312287854, 52.354279102817664, 57.42231868928479, 57.03280379695278, 53.59519543186311, 48.19575086716683, 45.78543870679794, 44.19878505891369, 45.03136304117019, 45.91846589119204, 50.85684368687292, 59.31485445268693, 62.79454984972554, 63.02021949521957, 62.59398729570451, 45.936222460962114, 5.4694833870857, 1.1656480066237913, 4.6888346441330455, 1.281667671376659, 0.14058105647563934, 3.6158062998325597, 49.99422819383683, 45.594505571549945, 47.185167881750296, 42.000782951231926, 27.535536750670406, 49.323157725795625, 56.54618278626473, 59.74292624381281, 40.57638991263605, 0.9312355205897362, 0.014163083058872051, 0.016362527235140725, 0.07399688459812634, 0.03280805626643762, 0.03254101716823155, 0.0542504282578105, 0.05743333972209404, 0.012826091091659282, 0.1015825079934251, 0.03182968537833902, 0.08100788379388471, 0.026313798697364908, 0.19251026513595737, 0.14547013767784642, 0.19087433033893186, 0.20259058793946622, 0.12724809288497896, 0.14867776313856726, 0.1364652491024425, 0.0884298968218988, 0.3689943386181709, 0.08328946983261455, 0.1581238264278058, 0.13722983549439138, 1.2124459277237616, 39.996255674669825, 68.30941800148257, 58.567438971611764, 47.098914961661066, 28.707148721141202, 45.614564572611165, 55.55602750470562, 49.32229872672789, 57.73657898749075, 42.741361741096746, 0.4187628728968482, 0.9920169977891831, 11.979734359248994, 19.73996331614833, 24.191523982632546, 22.70260991588716, 63.96531066586895, 60.511306793459006, 62.003313649085264, 48.52823841956354, 53.56363604145666, 55.28291679197743, 59.21984680237309, 52.69355235561248, 54.027232739233206, 49.04808975035145, 46.91898799711659, 48.85733704413138, 56.733138638158, 56.41468532623784, 54.39782611785397, 51.95486414817072, 51.00895320215533, 55.074693849009854, 58.01138808650356, 54.65365878997311, 59.47395755398659, 56.60720702140563, 55.62209198551794, 59.027634974448915, 54.08527989541331, 50.753799100076, 51.70090636899395, 46.205638300987985, 50.23393207980741, 53.76780325366605, 52.60580893485777, 48.206258896858465, 41.91488304445821, 41.110679488028254, 42.856942222964385, 46.136949754530384, 44.30866633692096, 41.731006253150206, 40.34458175782235, 42.368026625725534, 42.19531289992794, 42.23425811336887, 40.55367938933834, 43.5136293595837, 49.39991458769768, 54.67532596280498, 56.2280079626268, 51.67619543690836, 48.809880287416526, 43.61911758299797, 50.61718686934441, 52.83689537355977, 55.38008174588604, 57.35761134855209, 55.990379010477376, 55.967327240974676, 52.45827682556645, 56.403031964455884, 58.43814196125154, 46.960749472341234, 57.386272107401204, 59.310473165204456, 53.4643373181743, 54.60542540396414, 58.7107466882275, 54.32102610988002, 53.43454299434539, 58.30646014982655, 55.9487352063579, 53.54420069725283, 53.0136138393033, 54.938395407892045, 48.200551848257746, 51.51543317302581, 50.10558036065871, 44.66354670063142, 42.03870442605788, 41.464779300074426, 42.54132086230863, 42.756890404608946, 44.03125278411373, 41.34043232087166, 42.975389957427986, 43.059611089767955, 44.57485798866519, 41.662047063150716, 48.035980962937884, 53.57839592041508, 56.16950581150671, 56.25222467607068, 51.21881177348476, 55.80771423155262, 58.40801031358781, 56.666940796759825, 54.000525320729906, 55.04446414209182, 53.13037103222263, 47.73176977711339, 48.930740279536096, 48.569223265494074, 46.82236040792158, 49.35322269316643, 47.194263858179895, 49.970780264946725, 54.22056636502666, 59.08573312144126, 61.15224561383648, 55.16681855724704, 51.637764053960005, 48.322070798566266, 47.1005819689843, 47.24225013486801, 48.440714651538485, 55.5602518973812, 62.46145040758195, 68.70258854281518, 65.68818038509738, 63.6945180739126, 50.38698296393118, 6.552296819225435, 6.664717341622999, 5.5456053153161085, 0.8336250099443621, 0.1773036956306427, 3.7177141347239098, 59.89213320516772, 52.03960695574361, 54.22963880723523, 51.917236851107695, 38.814465153601866, 55.993375701289025, 67.58078282879245, 68.2953445373043, 51.72966518709737, 1.2164325267076492, 0.19176964197427998, 0.16697505308735758, 0.11728737938908801, 0.11365809147396397, 0.24166585246641792, 0.21821637607870564, 0.10322208936897018, 0.14685093455256956, 0.17694193359103896, 0.16661293864730867, 0.11848350310878408, 0.11224137273647132], [0.06792642686876559, 0.06911468286547931, 0.08938992756509012, 0.023819249791784153, 0.06743214694001982, 0.004836278592026042, 0.05172905669878087, 0.05958278325476474, 0.04450372142356731, 0.02279471827580804, 0.030319915686343468, 0.08896660269989122, 2.2713099804616745, 33.70395022053873, 49.07566009029266, 43.37323988637617, 23.442437571863977, 9.88829618500125, 25.719738237319458, 47.38702874029837, 42.15373969847157, 47.612153176338445, 30.422150165803973, 0.03414779082841931, 0.8614658095663594, 1.766915852504392, 3.2989810166820406, 2.030600129115966, 16.90122635133805, 57.12534427642823, 57.41248922963297, 52.188547195926795, 51.924744267617505, 54.63403124963084, 50.87300385198286, 57.2633058024991, 54.64076595921671, 52.2558040772715, 51.23862366522513, 39.53793456477504, 43.42640369169174, 50.04135547145721, 54.806466487146196, 51.61529279524281, 46.98504463318856, 45.35074987719136, 49.4703564336223, 48.829919676626886, 49.50242965452133, 49.521096214171386, 50.97941383238762, 51.004740576590265, 48.106383585160785, 46.646222452963556, 44.29871528379379, 45.57163815344534, 50.97506000149635, 49.96783064257715, 50.42385324355095, 47.09565939441804, 39.86271465978315, 39.86270289267264, 36.436587072187855, 39.15039654700987, 38.75591201166953, 38.65115334910732, 40.23027996863089, 37.730765265803186, 38.96922619112077, 37.490818192881925, 37.06642558497768, 37.24306952568793, 39.18305812343475, 49.40901056412728, 50.56802780397477, 49.677398743168006, 51.1956972460593, 45.57977314918272, 40.021966811149355, 39.990179923272905, 46.30792587034164, 45.860022575624534, 48.14295968701763, 46.61556520769673, 45.1988168685667, 48.09611482004966, 51.229696350712935, 50.81367408075641, 38.117424672649754, 51.94444633299305, 51.3611702765188, 51.525090048390055, 50.396341739162324, 55.57037553479595, 50.724177360534675, 54.32684298484556, 50.88716360830492, 49.383024861735684, 50.935981427469564, 46.95117888912078, 46.86862476410405, 40.94481029818135, 38.96661781495617, 38.58695591649702, 38.81131941272367, 39.37377945069344, 38.56284510704779, 40.15395456744779, 39.45010485187654, 39.03827951800439, 40.62627853885774, 39.09919000441028, 38.82476137530419, 39.226670957380726, 39.84100041850921, 40.09605646133423, 43.790136844881125, 51.26632344338202, 49.20079546590006, 51.53508032521894, 50.79587436491444, 53.60746852813229, 53.26337860476587, 50.737995870651744, 47.6859486487604, 46.755636968920314, 47.93456415976248, 49.44722621671615, 48.93593742001442, 46.9619301057631, 46.76481139275336, 42.42212395514212, 40.261415743058734, 42.92375587647961, 47.40236128530195, 45.6860105452999, 44.59458358826176, 41.4568208109948, 42.28575883373138, 44.56599735444592, 42.15730905532837, 44.50807179174116, 46.46088261758128, 54.725096917921505, 58.578292169878566, 61.26295058957992, 62.04604002737231, 58.92289200136739, 15.936481164347743, 0.6651552273861824, 3.779203170730222, 0.37320855764612076, 0.12904115231527438, 1.7198444686589704, 40.34407577207012, 49.66050509483584, 34.96889106688961, 52.32599489150509, 24.89416756937581, 28.34062284038913, 47.341768510880016, 51.9671647010311, 31.34171259018683, 1.0729540644153472, 0.06887747906148434, 0.042531048848984704, 0.03382892971257529, 0.05951803350340455, 0.007516242800310495, 0.0778339968453492, 0.0767007076572026, 0.02954909142347113, 0.01966996820673587, 0.015064697682617173, 0.06774253512342131, 0.02560805743409982, 0.011545185378992991, 0.05922840247231145, 0.06653522652003073, 0.037181813104618947, 0.02986940427593166, 0.06989810735948625, 0.0534263857820582, 0.03251812646105405, 0.03427379697020497, 0.048994463718225884, 0.03543894392468276, 0.05397552143662207, 2.9788160804779302, 41.91785620104882, 58.29010778857816, 48.875579987802816, 27.738884187513783, 16.372680106470664, 29.11274336999463, 51.9491296429788, 48.479208792409594, 52.050236578910585, 33.3687444656126, 0.01682158244112807, 0.8955352717349607, 5.194537495413135, 13.38982153323389, 7.326653590125423, 16.177126419159674, 57.702897594821074, 58.59653903592018, 55.73389522490963, 53.61004160296533, 54.75971575706236, 54.471692192939024, 58.94479843877978, 56.786459338280466, 54.31117703837734, 51.58656535610076, 41.47080013828893, 45.962031656695956, 51.686130800554835, 56.79206440525671, 53.69305464529223, 49.8004238836227, 46.14002097037531, 48.60641910183815, 48.74202328343546, 49.92839513286468, 51.069922524113814, 50.16308622975504, 52.341123473259714, 49.776520959792606, 49.1804148304847, 45.70675596114128, 46.77688444814375, 52.39657009801557, 51.71272447032314, 51.4800141703698, 50.15364900712044, 41.729315711605935, 41.391580027918664, 38.39062952226208, 41.31349740489837, 40.09605646133423, 40.4650063668528, 41.81423894820675, 39.52852479873165, 39.226243419031945, 40.19587293747933, 40.05253776427239, 38.995509993645456, 41.13930494554582, 50.11029897197601, 51.28198938985025, 51.573460717355054, 52.76771653083063, 47.18745854593093, 42.450619974443995, 43.47028716917961, 47.546010248122684, 47.806977302797385, 50.59857522287677, 49.5872312976468, 46.89333569618964, 50.089428040289114, 52.52369411530034, 55.25862947587044, 41.09546461412984, 54.642268226992705, 53.188453489734286, 52.29969539949971, 52.21752958913004, 54.95961543052427, 50.04697230554397, 53.99031931354154, 51.97826893098893, 52.53349611836096, 52.44487800905782, 49.725396786966634, 47.63403215715962, 41.898699345127234, 39.591325867560606, 40.760588338298184, 41.354478328458725, 41.739725682043264, 39.584622536936116, 41.434879072250865, 41.58186204971806, 40.39109322332567, 40.76052558037543, 41.950580535396455, 40.54937262688914, 38.97422721309047, 41.92082935763944, 41.41441998943206, 46.46993544793899, 53.95031506015409, 52.409902234231275, 52.184538533610684, 52.494852927423295, 55.28587818145753, 56.47727850944766, 52.11468896558208, 50.82897524679861, 47.363129738838445, 50.48224164593605, 51.23039845497378, 50.300082852763516, 48.59209852833902, 47.424138284498646, 43.4543780357607, 42.5850905910615, 45.404780526315015, 48.8807261374689, 47.6386683987033, 46.38876199722291, 43.05402563464257, 44.84835701604044, 46.98587617566509, 45.23573813899871, 46.46411857297344, 47.803945310654186, 56.86506755890385, 61.31342757132746, 62.40851409973637, 63.73755431944325, 61.388364453469556, 19.200284404139367, 0.45584091556168377, 3.7019035508555755, 1.1197106780544406, 0.10924940868731468, 1.5384141331718815, 45.79326383529171, 52.35947232092581, 44.257126392856726, 54.731588440556685, 25.862828262390632, 34.52074850759199, 53.76422212969873, 60.77103830152943, 40.937836324014974, 1.0171085223555565, 0.022035343196964072, 0.014216555038376922, 0.04975490557450441, 0.030732394661754373, 0.024795613529521133, 0.029249627653869893, 0.06799581911294691, 0.0406126038081223, 0.0459714577863774, 0.13458079538278042, 0.01758287657022236, 0.07154645278088509, 0.15698080792302088, 0.13000839960671243, 0.13213567255485442, 0.13600256263969407, 0.1394845854731337, 0.13656583644690054, 0.2544555065011786, 0.15947664577153423, 0.137251025486377, 0.1294010757438598, 0.1073587956207414, 0.29153417735811205, 3.715052071117586, 51.97764135176136, 66.8608945415866, 57.56526947021485, 33.07267612026584, 18.56393671804859, 35.51000948875181, 60.030537959068056, 55.12786549906577, 59.35974990167926, 37.79102071639031, 0.1931303979889039, 1.2552277094894841, 4.399094552763047, 11.366884612268018, 5.486458424598941, 19.896114833893318, 61.50787122787968, 62.68493137051983, 58.32762133690619, 58.632346353223255, 57.76086238122756, 55.878297282803445, 60.44884697083504, 57.94334673112439, 55.63922097606044, 55.00481682439005, 43.2441899853368, 49.333653988376746, 53.046969675248675, 59.26341649024718, 51.839989692934104, 51.165820552456765, 50.347257198825965, 47.8869975766828, 49.64982448085662, 50.74611517690843, 51.894953866158765, 51.54292506556357, 51.89027055617302, 49.27257091768327, 48.227612280076556, 44.90283873773391, 47.87157481716525, 54.57909061062721, 54.74431260939568, 52.49158559306976, 52.83565590458532, 43.58223553626768, 44.31090601028935, 39.77630484488703, 42.92146521229898, 40.95360817447786, 41.75970623570104, 45.13137955819407, 41.46810154761038, 41.78218533915859, 41.01623665901923, 40.966610831599084, 41.496817219641905, 43.135101026104344, 54.13724737782633, 53.4216070175171, 52.83229443334764, 55.62197823678294, 49.58645074598251, 44.27764038885794, 44.42312109854914, 49.66289774064095, 51.35005035708028, 53.14022794846566, 51.49458185318978, 49.7680486402204, 52.72873601605816, 53.88687464498705, 57.85071603713497, 42.92083763307141, 56.25229135636361, 54.50504410651423, 56.245340916418264, 56.01539588743641, 57.713844929972005, 53.519932992996715, 56.04217783097298, 53.66701795208839, 54.54452276229859, 55.678672175253595, 52.204930936136556, 48.743988390891786, 45.36854174829299, 42.41842123769945, 43.63082193559216, 42.907144638799856, 43.82246501984135, 42.22483658021496, 43.6133477764745, 43.18448758894398, 41.92384566030195, 43.72326043344314, 43.58973903040732, 42.1056043717169, 42.5735588227549, 44.96042697660385, 44.063514278781035, 49.01201571187666, 55.55737287767472, 55.016285834773896, 53.863716971489694, 53.99399065202283, 56.777273147336906, 59.669801496690326, 54.39531972331386, 53.86767856536373, 50.88286076822589, 54.43737537630143, 55.5287278083063, 53.37505632831205, 52.27676522347235, 50.36885376899473, 45.253184841525176, 44.24851286795832, 47.21938663913358, 52.492409290805945, 49.80640157576531, 49.44388043495917, 45.001490269937825, 47.1317098986718, 49.64295248831473, 48.5116820950662, 49.52203366064256, 51.77321918549077, 60.26867289696971, 64.30552136513495, 64.8582656921879, 67.5499451544977, 62.74969754680511, 22.68914638027068, 2.4758628106886342, 13.749064553168513, 4.304558077166158, 0.20103490851338834, 2.2475539003649065, 50.318235581920995, 63.05984720107048, 50.90781096489199, 63.18340578386861, 34.910122194597804, 41.06905137338946, 62.69182689728276, 70.65387356665828, 53.61294807926301, 2.6978927418108913, 0.12748219403288058, 0.12170644266711128, 0.17650192333084924, 0.11676767300213538, 0.07559337352793064, 0.22889616268296398, 0.20860595628619197, 0.1696371013719228, 0.16604048710676933, 0.14402454508648765, 0.1834437677696828, 0.19745770691623613], [0.01802279681508099, 0.10608624696971909, 0.12830985244363546, 0.11199437832880406, 0.10342256691787513, 0.029454793660871448, 0.016506785421722358, 0.04393331533778579, 0.10983636227226067, 0.03487421838085979, 0.06010652692507833, 0.04782553611984176, 3.1320787725910066, 37.41208445641303, 47.04588059456118, 47.77382935247114, 24.749883182587165, 26.512704203205725, 51.52427811776438, 63.73441642330539, 43.2221580320789, 46.9822754398469, 25.828752671518636, 0.038922809199580265, 1.2431732853574138, 10.485964398230276, 16.260913149003063, 3.8516422385169617, 17.507607129312333, 54.798174596601925, 56.0439036738488, 57.468810542937256, 53.408298415522424, 53.91601785536736, 56.52775156882502, 52.07073488543111, 48.90881030790268, 56.86921350417599, 49.69832066566714, 41.58521567621539, 43.441332232567575, 50.56851810024631, 53.4051997430863, 52.881226001247285, 43.19870225844845, 45.472096243212306, 51.02727067086005, 46.047484413270034, 51.628903419740745, 50.43007804501442, 53.47219774799963, 51.676364098825765, 52.77436887064288, 51.33065031420801, 49.902056417157574, 50.40175068762995, 51.145530131555375, 47.6194840861905, 47.103555125574914, 41.01651122493129, 37.435869709137954, 37.29924571129584, 37.6472266258732, 38.81114682843609, 38.50936751211844, 38.93748637168638, 38.1500901714448, 37.853974757655976, 37.403906314603745, 36.84887524574034, 37.90729545777844, 37.14220969907699, 42.868191580618586, 51.68496977898383, 50.918432743318625, 49.68906779443064, 50.38135044036373, 46.838999102192545, 43.58064697634789, 41.15495128016318, 42.21135931630289, 41.93687969638456, 45.07146143144177, 42.16721304001347, 44.349015758883574, 51.09360187284408, 53.777424827698745, 54.508378121160696, 35.51739531178629, 50.516731046861224, 54.94564394797049, 50.310814457554976, 49.61867693931826, 53.80226912037019, 53.756620576304776, 48.598154667885076, 46.6117722757401, 53.31269064257222, 50.6905940271193, 51.86863083993235, 50.38675154409101, 47.863745766301314, 47.146913005459695, 43.85081983381703, 39.692452415343254, 37.7873807568704, 38.142504307531546, 39.37893736747004, 39.034659170335345, 38.588724905444735, 39.32471844457811, 39.98194686828121, 38.72758073191489, 39.1000097797763, 37.92959805457823, 39.2551669766826, 39.73081319562851, 47.03690621160692, 50.72587966918946, 50.47305937736265, 51.11997588988274, 49.46532403269122, 54.16268787076397, 51.20145920784243, 51.755843085627404, 50.36131497352354, 51.85679704912248, 51.006705684046594, 50.97671916407924, 50.7971412904801, 46.58194657294981, 43.480979550269346, 39.68839276221491, 40.32709975396433, 40.250111472222116, 42.59116634245842, 43.220851882811516, 43.67959268631474, 47.12473200213525, 48.15517002536405, 48.374089271791526, 44.349411918270974, 46.873641475554436, 49.21107992049187, 57.07987616139074, 57.59615421295167, 60.19034316462856, 61.76659468681582, 38.255766668627345, 1.8037666428473689, 1.7564958309934986, 2.09401075878451, 0.018298601874360637, 1.0160872965089738, 32.851836873639016, 61.24664137440344, 37.02370705143098, 51.69071997365644, 37.00582496581539, 35.219138283883375, 51.635002705358694, 45.68332372173187, 38.404777511473625, 0.7542680456273018, 0.06630053548442741, 0.03605343070962737, 0.06549761405274754, 0.08372057815112414, 0.03776823808889716, 0.04633835644551343, 0.018458635726523016, 0.012993434380229204, 0.10484391282643042, 0.04738024751385374, 0.009570011527337616, 0.02603066792230933, 0.04129436843457722, 0.1025832333271542, 0.014034833237078163, 0.04466052813034865, 0.024337259293984503, 0.04003888439206828, 0.04967681440194288, 0.10489699505870381, 0.08540408700824746, 0.10698125983077673, 0.0508114327526381, 0.04129211996651946, 3.9069542769462835, 46.29611169138263, 54.52004717242334, 54.011562870394805, 33.17405762210969, 24.935742732017275, 48.894819213498025, 70.51033835257255, 47.89556011076897, 53.01463757791827, 29.50431162311185, 0.0973367031603571, 0.8261342022207476, 7.581430654371939, 8.517758269463817, 6.542536491347898, 20.17654076699288, 57.67452316899454, 59.379063652407744, 58.85281885823896, 55.030728001748365, 56.171588590068204, 59.197571662164506, 55.022310595358576, 50.54279127428609, 60.52519198386901, 51.693265591898275, 41.99069069277856, 44.22102489779073, 53.626637151164395, 55.83281740065544, 53.248571657365375, 46.600369945649184, 48.80129421910932, 51.48516424240605, 47.13485171717983, 52.26526875649729, 51.90515595097696, 53.99060564656412, 53.22019723153884, 53.24710469092093, 52.47064013634959, 49.18976183860533, 51.08191320973059, 52.288830434122396, 50.507423262442316, 48.383451969392844, 44.45064044767811, 39.159492523439475, 40.80680562603859, 39.29153911529049, 39.57047454772457, 40.071012127783995, 41.62144660949707, 40.18053647010557, 40.542351584280695, 40.80785682124477, 39.482331045212284, 38.94518598433464, 39.887700157780806, 45.65340388205744, 54.46351405112974, 52.31045053851221, 52.32617532053302, 51.766374649540076, 47.362768880782596, 43.70810831746748, 43.56018004878875, 44.799048900604255, 45.240346923951186, 46.326015841576364, 44.50596547895863, 45.18616330239081, 52.390164867524184, 56.867169949316214, 56.58272358679003, 37.26735684179491, 53.1631895034544, 56.039247820454264, 52.61814478904971, 51.8766716987856, 54.92437293452602, 55.11127779560705, 50.92611666648619, 50.7405375665234, 54.34091644902384, 52.67615664389826, 52.97613166993665, 53.15969467163087, 51.71912970081453, 48.535239850321126, 45.74700340147942, 42.26241680883592, 39.26693016482938, 40.06444215774536, 41.61369600603658, 41.15586519241333, 39.84079253289008, 41.4176873237856, 41.032447814941406, 39.37897266880159, 41.74665651013775, 40.085626879046046, 40.65234661102295, 42.19591694493448, 49.122159788685465, 53.598537291249926, 53.6387651197372, 49.42353117850519, 51.57706929791359, 55.68894486273489, 52.58238061781853, 53.750682107863895, 52.68777862671883, 54.16740648208126, 54.42083474128477, 54.282316238649436, 53.36075144429361, 49.47800113308815, 45.242006086534076, 42.460143489222375, 43.696686375525694, 42.23787453866775, 44.27720892813898, 44.15991829287621, 44.576572064430486, 48.08557148902647, 49.99576576294438, 51.0285532859064, 48.30431815116636, 48.19280124479725, 51.18904098387688, 60.16252179299632, 59.94251605003112, 63.313000894361934, 64.0613224429469, 41.984485503165956, 2.077380644698297, 1.383177508269587, 0.5858719913709549, 0.02517598384480563, 0.7331937635617872, 36.18555145878946, 63.877884957098196, 42.33912267992574, 57.30695001540646, 39.86733521184614, 41.215967670563735, 59.27330086308142, 53.223166465759284, 49.14896526644307, 2.937990825983786, 0.03284778175575118, 0.007124729736167337, 0.013535689607623124, 0.045062888999499624, 0.05271802258287227, 0.05937409707375112, 0.009169498845303973, 0.04289082672086455, 0.01357503971385379, 0.039560784240283316, 0.01887851894172209, 0.04580934592072041, 0.12349931057542564, 0.3237338640516804, 0.21836205535838682, 0.11377167933049703, 0.1723324438376773, 0.130926632592755, 0.18829622996910927, 0.1570589182477805, 0.24945002589975637, 0.23507132164893613, 0.1884737018976481, 0.1785452483642486, 5.6290091237714215, 57.10337900346326, 62.53854067094865, 62.8889887563644, 36.932915949052386, 40.31094743359474, 62.634623050689704, 72.43203301583567, 52.05429230966876, 60.059257553469756, 33.19073554008238, 0.2107676112603757, 1.4528879547311415, 22.144952820193385, 24.835488911597963, 6.951972611488835, 20.87472265766513, 60.77535290871898, 62.97684200348393, 64.00136901486304, 57.02767725913756, 58.37381116805538, 61.042089769917155, 56.960283094836825, 51.18950382355721, 61.254333142311346, 55.11949123874788, 44.466235791483236, 46.86210970724783, 56.885550175943685, 58.69886190660539, 54.068041078505985, 48.27606924118535, 49.98585785588911, 52.04795768184047, 46.462329972174864, 53.870832150982274, 54.10477799753989, 55.37086025361092, 55.27902580076649, 54.468122836082216, 53.98634987492716, 50.90270011655746, 52.59124125203779, 55.7780336564587, 51.3404130935669, 50.757678324176425, 45.696930423859634, 41.941343353640654, 42.41056865261447, 41.36715935122582, 42.43354981945407, 43.04896577712029, 43.89464447575231, 42.22752732615317, 42.382657066468276, 41.09713162145307, 41.907042226483746, 42.175551998999815, 42.10029740487376, 48.00198970302459, 56.609638890912464, 54.4449886968059, 54.21197637434929, 54.281837709488414, 50.702659237769346, 47.495698005922385, 45.927110795051824, 46.136643809656945, 45.45460639461395, 49.13146757310437, 46.6019545831988, 47.80112120413011, 55.56071473706154, 59.09131465419647, 57.9698972548208, 40.323153849570986, 54.04888422258439, 58.43701231864191, 55.08228755766346, 54.44094473315824, 56.43920798455515, 56.75144826212237, 50.309390637182425, 51.669539174725934, 56.95512517806023, 55.81927345645044, 58.504147606511275, 55.64274326447518, 51.88704636789138, 51.6789803197307, 48.13364013548821, 44.92853810710292, 40.61195796535861, 40.85350536531018, 44.318531097904334, 43.634497196443625, 40.87762401949975, 44.345987689110544, 42.980524339983546, 42.573123439665764, 42.62028994098787, 42.46943950653076, 43.61597184211978, 43.94400750437091, 51.41911152870425, 56.06783013189993, 55.976795842570645, 50.27235561801542, 53.559533242256414, 58.38590383529664, 54.146700289941606, 57.35810948956398, 55.2812066385823, 57.22306620690131, 55.46131010978453, 55.14576327416205, 56.959588835316325, 52.1727635783534, 46.53010068401214, 44.951425137058386, 45.016654153024, 44.95396683293004, 47.00389946660688, 47.89370090730729, 47.553929513500584, 51.458037130294315, 53.66125991267543, 54.43606530466388, 49.56561511562717, 53.480622999129764, 53.71469043916272, 63.119337789474, 62.19076764199042, 66.64625460101713, 65.37327681818317, 45.8479416754938, 3.2981173597997238, 8.341308486077095, 7.54317577808134, 0.09124048955498204, 1.6981871017525274, 40.48739525579637, 72.93422975847798, 50.51291065831339, 64.8069336337428, 46.608606923011045, 51.08514916512274, 65.17376545936831, 63.06593079720775, 60.32523347485451, 6.932091587974179, 0.1618751444883885, 0.11729307908324466, 0.18672312970363325, 0.13263730692767328, 0.11923183311497974, 0.17274688208295455, 0.13583383943525054, 0.16603852592168317, 0.11721129153644848, 0.12937253130780113, 0.11603740734919427, 0.1842629762306329], [0.031983489020457195, 0.02775237775377689, 0.039915184174934705, 0.045416116819626866, 0.07840614961159807, 0.03737561036682418, 0.046021383736402764, 0.04829324045849424, 0.020007996842445388, 0.018812191049237887, 0.015994650856291336, 0.06952443265265996, 4.302791049403529, 34.451797162332845, 52.16167896024643, 42.38652844582835, 16.13396465778351, 29.09245687146341, 51.9296197737417, 65.9253857212682, 37.676122726932654, 49.867570938602576, 24.504366344021214, 0.23759493784558391, 2.936734441787966, 19.299488990537583, 7.3953127188067285, 11.330632105950388, 15.731402001073285, 57.750891716249534, 55.81477449786279, 57.833508599189024, 56.27653160402852, 57.84619746669647, 55.603256763950476, 47.66913344783168, 50.42705389761156, 54.42085827550581, 49.129274968178045, 40.665153149635564, 44.1510655033973, 50.1138565617223, 53.961540883587254, 53.57017071016374, 47.48374654400734, 46.26414437447825, 47.40377333856399, 51.28346027866487, 50.33940461374099, 52.1516651491965, 51.24101238866007, 51.236219252309496, 54.28932159177719, 53.06247088216966, 51.52425458354335, 52.236945321483, 49.40429587518015, 47.33683809157341, 42.838973845205004, 39.080515600019886, 37.0639152680674, 38.80214106652045, 37.599369787400775, 39.29362189385199, 37.83297831012357, 38.98487252573813, 39.0935770926937, 37.249137432344504, 36.539776786681145, 38.3792350369115, 36.810192831100956, 38.65211825216971, 44.84832955944923, 52.637242809418716, 50.76537793682468, 50.45166677044284, 51.57742623359927, 45.8156095781634, 41.99651149011428, 42.61481431222732, 44.097713424313454, 42.41496562957764, 43.45687266319029, 42.98333275702692, 48.65810809596893, 51.087679093883885, 52.74609642644083, 53.77058421411822, 32.30253442641228, 52.6292254847865, 53.24019739704748, 50.7234360325721, 49.20322733540689, 50.669323013674834, 54.05914514295517, 42.688162634449625, 45.852322962976274, 52.34011150175526, 51.350426904616825, 52.95409579430857, 54.8352841408022, 52.98966776940131, 54.55695275337466, 52.341103861408854, 45.30885504138085, 36.84865951538086, 39.49205067849929, 39.63578201109363, 39.33035096814556, 39.43362697478264, 40.40021665634648, 38.83279046704693, 44.144526912320046, 38.596891280143495, 39.93317219518846, 40.59969271382978, 39.1923306065221, 41.422472615395826, 48.75812069062264, 48.72067774495771, 52.82827792629119, 50.49687993141913, 50.22903303946219, 53.43718667184153, 54.23368669325306, 54.001066607813684, 55.2906987743993, 55.07697666845014, 55.567975044250495, 53.18687277455484, 50.505979830218905, 47.71251093956732, 45.519451018302675, 43.60122765264204, 41.8084652193131, 38.49152465020457, 41.945869768819506, 44.86682745718187, 51.2251817026446, 50.230605909901286, 52.41769990613384, 48.08407314362065, 49.71943086193454, 46.680221557617195, 56.08518269754226, 54.5795024594953, 63.929785759218284, 60.034848643887436, 61.21219511955016, 8.607721751736058, 2.246448527420721, 0.7607755641783438, 0.013205601473248774, 0.14532148597701905, 29.219439683421967, 57.791217603991115, 40.25126857142295, 43.34684625748665, 27.846388509196622, 25.984229541593983, 37.168364063386, 52.169331504452614, 36.62821054458618, 5.9313130570996195, 0.267151284121698, 0.0675620754519778, 0.017778587137018482, 0.05019385480291901, 0.04579230812528441, 0.0556462902515646, 0.045211479413293065, 0.03695099847391248, 0.046463175151016445, 0.07973653790090354, 0.051313484643375686, 0.027881344825389887, 0.05271468626996202, 0.02145532079251303, 0.03538972660598736, 0.06330094502998457, 0.021850051425938165, 0.0286194839469728, 0.0891319168130717, 0.018918481918292183, 0.023805645985468745, 0.04062543961129362, 0.042748338197388, 0.02224415386726539, 6.084645861579526, 41.8464651415425, 58.91047769977201, 48.730209104476444, 20.75478638372114, 32.67253748832211, 60.18054116156794, 73.50728804065336, 41.824107631560295, 52.73766725294052, 28.553331013648744, 0.26340946555137634, 3.4261574956678578, 20.888078328101866, 7.5314454397847586, 5.279522509344163, 17.031482381205407, 56.388126957801084, 58.14023402429397, 59.827939694927586, 57.79281793102142, 58.93037588365617, 56.45524263381959, 48.99411401441021, 51.683334150621974, 56.11765600019886, 50.33562737126505, 42.813584343079604, 44.39867296526509, 51.42000190673336, 56.55469825190883, 55.10844584434263, 49.011964721064416, 47.636793505760934, 48.26662025144024, 53.50612232761999, 53.76713252836659, 52.617223032059215, 51.88674042301794, 52.78181745160011, 56.701383129242934, 54.51674845910842, 54.49321031570435, 54.80286182895784, 51.642419907354544, 47.90454626083375, 44.00885997279998, 39.91424283673687, 38.65188683232954, 40.753367254810954, 39.174064128629624, 40.34507205409389, 38.80563197597381, 39.585818859838675, 39.502331210720925, 38.65662113312752, 38.85209637303507, 39.25863042954476, 39.93400766003517, 39.775657653808594, 47.52528836650234, 54.9571757162771, 52.22453101988762, 52.21202258140811, 52.7547295631901, 48.707388754813906, 46.734189448818086, 44.60256168919225, 47.03781227911673, 46.50837075325751, 46.172102036014685, 46.13693798741987, 49.35376790262038, 53.598125442381836, 54.03916458929739, 54.61756513964746, 33.23286571810323, 53.43962638608871, 56.28238378032562, 52.94161089005009, 50.11669635772706, 53.69714175501178, 55.26571327640165, 44.96177234957295, 48.4402165105266, 54.462254970304436, 54.108692522971864, 54.14737101524107, 56.7079766335026, 54.96413007859261, 56.45430910971857, 53.01989747631935, 46.89273949592344, 39.80289066991499, 40.83621555759061, 41.49143965013566, 41.10496459468719, 40.76462053483532, 42.3319447425104, 41.19184509400399, 44.850612378889515, 39.99528292686709, 42.10720862111738, 41.86258608295072, 41.226165833011756, 43.571562767028816, 51.116379076434725, 51.456417191413145, 53.579121558896965, 51.66763682519236, 51.86915251516527, 55.74781963902136, 56.911543723075624, 55.15766766763503, 57.0859323009368, 56.78172503748248, 56.42830379547612, 54.860218647987615, 53.2159806836036, 50.93931936448621, 47.0122423479634, 44.8332872698384, 44.12513471418812, 41.29769025310394, 44.21367045371763, 47.141723709721724, 52.570209503173835, 51.34765378890499, 55.42804841072329, 50.484061625696, 51.5694167537074, 50.314987859418316, 57.954309755756015, 57.01224273250949, 66.6814382614628, 63.306905531114154, 62.99457503903297, 9.631669232922217, 0.4877684265375138, 0.5460458381041404, 0.03771570360948963, 0.07396159858833398, 33.03326414477441, 64.11931860831477, 44.285120348776545, 48.951332722940755, 36.64557487733903, 32.279253198254494, 44.38376403624012, 60.23835689790788, 48.834948155187796, 9.145769938345879, 0.17097272970263036, 0.06390278753373893, 0.013421604751549182, 0.0261274324880252, 0.018215872039417588, 0.01257793797600654, 0.03192674871834536, 0.05763486298101564, 0.05198820892180647, 0.0313320116800887, 0.02979407293511735, 0.046677296725852836, 0.18683396730451815, 0.2352082981697975, 0.1423355510398265, 0.16763447092906122, 0.1878052748619549, 0.12527527858413037, 0.17060243344355017, 0.12120018878410901, 0.09334771398214564, 0.08891132945615439, 0.16491295889981333, 0.2409329055057418, 8.5988817099602, 51.52329752522131, 67.67968147031723, 56.39069611026395, 27.26476573175, 41.260651311566754, 60.314293984443914, 71.848109768283, 48.77090761738439, 60.97923378790579, 30.318301493121734, 0.3914803062235156, 3.6055242967221046, 34.44091258510467, 14.223878249045342, 19.492487253681308, 17.789774594768403, 58.32259285834528, 60.06995385692966, 61.54372169125465, 59.25907442646643, 61.37377715879872, 58.426347394143384, 50.023124294896284, 53.22009917228453, 60.20410676156322, 52.57052721515779, 43.90807859359249, 47.15207484460647, 53.654913517736624, 57.69319365101477, 57.032756728510705, 49.284934228466405, 48.72450205587572, 50.00018627412858, 55.497697937873106, 54.10620181791244, 56.06245256239369, 55.7858274059911, 55.37573183736494, 58.80343229539933, 58.75833288315804, 56.81395123081823, 57.18649794978481, 54.53971001409716, 49.239936797849595, 45.093858165125695, 42.368716962875865, 41.10427033516669, 43.35212969010876, 40.582606869359175, 42.64675809491066, 41.87878154939221, 43.403963811935924, 41.64581629537767, 40.6292869967799, 39.48601022843392, 41.47434988329488, 40.29596005716632, 42.08680052911082, 50.50484234286893, 57.36478144122709, 55.77359353342364, 54.41058166565434, 54.77916679074688, 50.952235729463645, 48.583402633667, 47.19450704513058, 48.94019711402155, 47.775241405733176, 48.27223316315682, 47.278445766818145, 52.28470410070112, 55.11370966511389, 56.000028041101274, 58.23503771135884, 35.5117392539978, 57.87843542714273, 57.80658152795608, 56.2979438227992, 52.184393405914314, 56.159907771695046, 58.86264047315044, 46.29322090456563, 49.51931545811315, 57.8546227178266, 55.455053929359686, 56.290710972201445, 60.163769106711115, 58.339078580179525, 61.210586947779504, 54.86542363320628, 48.36313016953007, 42.78503733296549, 42.47792359321348, 42.837973640811065, 43.268755789726015, 42.89453421869586, 44.62351106828259, 42.13899550899383, 46.300649873672, 42.694175627923784, 46.4256715005444, 44.10298901219522, 43.84500688122165, 45.358018029120664, 51.51339746290638, 53.82712125778199, 56.55184668879355, 52.895071967955566, 52.86034330244988, 58.82030633188064, 60.0792577189784, 58.680324785171024, 59.447077551195704, 59.863680331937736, 59.31463872232745, 57.622453704957046, 56.25175006927983, 53.8132478344825, 49.50754442522603, 48.330554885248986, 46.70410094722625, 41.60090907927483, 47.52327619060394, 49.932984305966286, 54.022847529380556, 55.19202763034452, 58.40244839268347, 52.271842648906095, 54.4022701632592, 53.37182429529006, 61.14373799293273, 59.65993281333678, 71.11729375777706, 65.60315516687209, 69.57086793838009, 12.92338013648987, 4.504915197049418, 3.118301202212611, 0.20539705911951683, 0.3355417917332342, 34.939434066895515, 68.74510703548309, 53.27705198718656, 54.433841320776175, 37.78274843769689, 37.738056951953524, 54.220993903375444, 67.45001885198778, 59.17856385630947, 14.008850974421348, 0.4840836968393096, 0.12628404018018516, 0.11485871212977557, 0.22616869048966518, 0.1783543392535179, 0.1671168406403834, 0.1616246184153903, 0.12869998271907532, 0.14526611314185206, 0.14081894209788692, 0.12922224017881578, 0.11125320358382118], [0.05352023538322218, 0.10073096296119113, 0.04119075121237867, 0.03889899918689363, 0.012393590408347309, 0.08725736094939132, 0.04523389131551789, 0.030773721274829684, 0.030701377676920067, 0.06169421350463264, 0.08689182975720014, 0.07865341215003883, 7.258560263341473, 41.4283561706543, 50.647483256555375, 43.482352379829656, 43.2882107457807, 38.07808329982143, 50.24027455237604, 52.141910214577955, 28.52871814081746, 58.05745632417741, 18.331634344593173, 0.1791963005258191, 2.8749534343519523, 51.62374550296415, 11.5428372352354, 5.722070297887249, 23.29453479859137, 42.47382471638341, 48.50576323847617, 57.92770039650702, 54.03503825587612, 54.37487240760557, 56.6915693590718, 58.604356319673606, 57.24951474897323, 52.09635972976685, 47.07145052571451, 39.17831205552624, 43.11771708150064, 47.90167116349744, 54.22661858220255, 52.508581223026404, 47.87028043500839, 45.73511469748713, 49.97207072473342, 51.846481215569284, 49.5305726605077, 48.89284233893118, 48.78518504481162, 47.03809468976913, 48.63803340542702, 51.215932753778276, 52.094880996211884, 48.1945231653029, 44.05018998730568, 40.14404666039252, 37.51106546771142, 35.95262935084682, 37.96615846695439, 37.10830080893732, 38.628803683865456, 38.42542879043087, 38.34868761800951, 36.3358292272014, 37.5580083939337, 37.22124938041934, 37.599499225616455, 36.92673037129064, 37.10072671213458, 41.5002179145813, 50.18975050218644, 52.07065643802766, 53.45351549886888, 53.331651379985196, 49.48406903974472, 46.9967842871143, 45.57270896050238, 44.13555252936579, 46.79552747357277, 47.19598185631537, 45.14519806831114, 45.240641101714104, 47.04076974622665, 51.82617902755738, 52.90510539085635, 54.42008556858186, 34.30971714758104, 47.82704022622878, 55.336335551354196, 48.1760331123106, 48.021201472128595, 51.439888323507006, 55.28436414657101, 43.87240855924545, 47.709031797224476, 49.949383735656745, 52.502160303054325, 52.2818878389174, 50.40053867524671, 49.79397550705941, 51.80674368335355, 52.28606124078074, 50.481057090144006, 43.86072381850212, 37.364360978526456, 37.75243636100523, 37.69165531281502, 40.85950266930365, 38.81711667583835, 40.103956114861276, 41.24046287228985, 40.87277596996677, 40.83668231964111, 38.11687554082563, 37.62876402947211, 39.199853712512606, 43.244025245789565, 49.52977249699254, 52.03022464629143, 52.23451345197616, 48.52323739759384, 51.45137694574172, 54.063942201675914, 50.590130359895774, 53.98359637106619, 51.06301523024037, 55.30318760102796, 53.57847044544836, 55.29440933658231, 51.47147909287484, 50.93062346981418, 47.12428092956544, 44.299507602568596, 41.224832227153165, 42.80716342310752, 47.368209208211596, 53.26382183259534, 53.156576387343875, 54.82091649886101, 51.26797868359474, 50.70596579582461, 50.78514668249315, 52.40821953742735, 55.03562704209359, 60.426662045140425, 60.932875294839185, 63.44800495332288, 31.667516423809914, 0.34271258920911823, 0.6309734873713986, 0.060766699363387404, 0.05517948606622316, 17.490968435041367, 60.921982872870664, 42.98325038725331, 38.12262181312808, 32.26269687375715, 31.65251139671572, 41.01792327819332, 47.38644038477252, 44.294283005499075, 9.652579388310834, 0.08694693446159364, 0.10714426801930513, 0.04526645005229981, 0.03385990264735395, 0.02682353444998303, 0.07622341189773814, 0.06994522942770874, 0.03892178647220135, 0.05278666789132742, 0.04934929649255449, 0.13647831856243073, 0.03574773864520173, 0.008827391749007568, 0.04256747632978424, 0.11001780253624725, 0.06499854607447501, 0.023620459551532424, 0.09132131949187287, 0.04320773431250165, 0.03022000249925881, 0.047763988616005074, 0.012407039081858052, 0.048650915419021924, 0.16468788226765974, 8.421684715055651, 50.630899475466826, 56.83505358234529, 49.06841939495456, 42.335168930792044, 36.17783615666051, 52.756012178236446, 59.023767517459014, 32.47263977604528, 62.09411651857438, 20.436976340509233, 0.34157105691490636, 4.2751790342792395, 59.5569117607609, 6.927600964423149, 5.539453077700831, 22.61357407416067, 46.47710946298415, 49.44136227330854, 57.854861982407115, 54.39357819095735, 55.364329507274014, 55.79174626258112, 59.833521227682795, 58.960511453690074, 54.008209243897475, 50.26975508659117, 40.89681617675289, 45.26177483220255, 50.40064065687118, 55.84339995538035, 54.8728447575723, 48.78456138795423, 48.73726544841644, 51.676360176455596, 52.568824906503, 51.366779265865205, 51.16298860119235, 50.51840982129497, 48.61164762127785, 52.53256651663011, 52.94912222893008, 51.70002775807535, 51.0881027098625, 46.69158466400639, 42.6651422439083, 39.42666084535661, 37.64264529751193, 38.16882733375796, 38.49289747976488, 40.58086925937284, 39.48931286411901, 40.60349741289693, 37.95565435963292, 38.36816218591506, 40.48124890173636, 40.01001927160448, 39.839388324368386, 39.70074430588753, 42.666860242043775, 51.52699239792363, 53.21638468773135, 53.67246220188757, 55.57784372760404, 51.54933029605497, 47.72399956180204, 48.043468767596835, 47.586038035731164, 48.1745308445346, 47.09161935314056, 46.530324259111964, 47.141202034488806, 50.15611225558866, 52.814263297665505, 55.4842951989943, 54.94871124144524, 36.450119249282345, 50.49760949227118, 55.39890127797281, 50.39571808230493, 49.90318998213738, 54.34109295568159, 56.48369158467939, 44.90333687874579, 49.485410490343654, 51.6724064273219, 53.80676023421749, 52.500183428487475, 50.099018235360425, 50.28861776474984, 52.24197380004391, 54.28654847606536, 53.29848774017827, 45.27767612088112, 39.101625796287294, 38.82706380659534, 40.5067168512652, 41.20586756737002, 40.56427371117377, 42.0220539646764, 42.951467421747026, 43.55858364412862, 43.487078835887296, 41.35771036148071, 40.01746785256171, 41.73605826593215, 46.15776577303487, 51.04243847631639, 54.728560370783654, 53.8013473633797, 49.51352996210898, 52.951236386452955, 54.79989651710757, 53.5234199800799, 54.70478688516925, 53.6835507423647, 57.372845834301366, 56.361078293092795, 56.78361954227571, 53.432397457861136, 52.22835533080563, 49.858443583211596, 45.12583724914059, 42.418248653411865, 45.03178665714879, 48.532851126886186, 55.8707231860007, 54.46336892343337, 56.55979733313284, 54.133987888213134, 54.27785650376351, 52.358377979647734, 56.28503138019193, 57.94226415695683, 61.59682666101764, 61.36738369541784, 65.5418053750069, 34.400010108947754, 0.45673993506258537, 1.0437753075553526, 0.01018398886381258, 0.05031958898349155, 19.704773772147394, 66.23179343438917, 46.15596540512578, 40.760800146287494, 31.755673654617805, 38.17841752882927, 47.29268397054365, 55.53674905530868, 53.52922508793493, 13.618330974732677, 0.10008668301687126, 0.05905524744922596, 0.04718606337724675, 0.03364818275816018, 0.055202962830662734, 0.04756398604161317, 0.029424987094957503, 0.025505100962735956, 0.044781930083709384, 0.04587551676518014, 0.052364882862856316, 0.0079984946698401, 0.10879232998817198, 0.22177391985972084, 0.18752972835734968, 0.13198233239593046, 0.1447640650815541, 0.18011471737296353, 0.14357895770620915, 0.21485508870213263, 0.15692356583331862, 0.14781096529576088, 0.11542021627387694, 0.2566199960006822, 11.74670046375644, 61.22765710276943, 64.93044907046904, 59.37593360101024, 54.44182334407684, 49.50597939952728, 54.51450486336985, 58.198022304042695, 40.17909303788216, 70.15853312707716, 23.468705684907977, 0.44797132332478806, 3.1069697199329256, 58.35853745860439, 17.97940746430428, 10.465030708620626, 27.09112240422157, 50.34995971187469, 55.99209700861285, 59.40469634148383, 56.12157052563083, 56.88962159618255, 59.55330710257254, 60.69372446306291, 60.580214992646255, 55.57270934504848, 52.252834843051055, 42.95814329578031, 47.2999599672133, 52.0486480189908, 59.34889278104229, 55.84257625764417, 49.20729875564576, 50.58460766269315, 53.15401507962135, 54.75738979155018, 54.94531839124618, 53.814299029688684, 52.602855390118016, 50.78202839820616, 53.950624927397705, 56.13306307023572, 56.68684682538433, 54.91631246382191, 49.24421610370759, 46.23113370710804, 41.73693687685075, 39.46018926558956, 41.42035845787295, 41.21048811943301, 43.449906533764256, 42.41749163596861, 43.55652047741798, 40.366456816273356, 40.384374203220496, 41.61176227754162, 41.5611284009872, 40.215508322561945, 42.473942387488584, 46.347157416805146, 53.53366913334016, 54.609092820075254, 56.8289307625063, 56.87226118579988, 54.458014888148156, 49.64676503212222, 51.28832009530837, 48.86575052815099, 51.60655375449888, 50.894404303643014, 49.04077845235025, 48.69149531087568, 52.528440183208836, 54.53629362967707, 59.09569201930877, 57.649251337974306, 38.545849477091146, 52.42630950866207, 58.69607702378304, 53.31707585242487, 52.0900329466789, 57.3608551486846, 59.13672393368137, 46.00584453152072, 49.06122969042871, 54.21181555717222, 56.37686975540654, 55.13718897296537, 52.67288146480438, 51.91407934311898, 56.255213522141986, 56.22007300776821, 53.55230823639901, 47.85301808388003, 41.957440760827836, 40.92421785477669, 42.19707012176514, 44.99324544783562, 42.66863707573184, 44.904450831874726, 44.57306938786661, 45.09414842051845, 45.974085100235484, 42.67624255149595, 42.25647834039504, 43.788752248210294, 46.718943195958296, 52.126597281425234, 57.89887489811067, 55.81559819559897, 50.92193149751233, 56.389444874178984, 56.5110069705594, 53.037253964331846, 55.232722220882295, 54.57102229518276, 60.10840877409905, 57.74877363635648, 59.612327006555375, 56.49864758214643, 55.42564007543749, 51.65998820335635, 48.461860149137436, 46.18925848314839, 45.14855169480847, 52.431561562322806, 58.71545745480446, 57.62216344956429, 58.90506090656404, 56.8338337252217, 57.317254081849136, 56.337155757411836, 58.00207637971448, 61.66450323597078, 65.81372368720271, 64.82374491230135, 66.25875580695369, 39.16440333089521, 1.6316752255924287, 2.4478499783623606, 0.2719370047411611, 0.15176505150814212, 22.553961892281812, 73.39478661937099, 55.46676220432405, 51.12344718748524, 44.1514342061935, 42.29169337980209, 54.02253373976677, 67.44066007675664, 63.97787793990105, 18.376480763958348, 0.27079102913698844, 0.18581634207117945, 0.15197373385871613, 0.10685845593651457, 0.1976971860013662, 0.18511082105819257, 0.16686985389359538, 0.15393815183591458, 0.09280471086141565, 0.17761242906412772, 0.26242482806405715, 0.05119422773620294], [0.09763992842166655, 0.014817896712150787, 0.023771022641730886, 0.06851220067830817, 0.03213184769265354, 0.0482655463800315, 0.026920515435537504, 0.06385311439272857, 0.04768041991478494, 0.10723223023477102, 0.039928322582836115, 0.017364572155319394, 8.536422867928783, 47.58401409272225, 51.04739242984403, 49.4915529220335, 31.230152537745816, 29.470826348950787, 37.415975447623964, 33.299189075346916, 35.482011610461825, 61.8982215850584, 13.657786096296004, 0.0253847677020296, 0.3662918255694451, 8.117410281012136, 8.951560643411453, 4.786155021959736, 19.787627958482314, 16.71084038672909, 24.367379526938162, 48.99271765062886, 55.72505420254123, 56.581084036058, 56.60514385469499, 57.83127284819081, 52.77469050499701, 49.883436925949596, 43.6322614454454, 39.43491743456933, 38.86505196171422, 43.7763967821675, 50.10826326185658, 53.711799652345725, 52.58831516388924, 48.308860255825905, 51.20013344672419, 51.89338884046001, 50.93351425663118, 47.54541404785649, 45.52776644306798, 42.88762300245224, 39.940028498249674, 40.4754202596603, 40.73936439329579, 40.51454590212914, 37.49303825439946, 38.16242602563674, 38.237264848524525, 37.6600488539665, 37.531022487148164, 38.1641597132529, 38.41124549988778, 39.55375348367999, 36.79977109355312, 38.69272655056369, 36.52630736750942, 37.83408834088234, 36.91403365904285, 38.47707463848976, 35.35529944204515, 43.82792495912121, 50.507403650591456, 50.07297761978642, 54.73215718423167, 50.57213844791536, 51.833353042602546, 49.20970709093156, 46.24579944918233, 46.56657872661468, 45.19984845192202, 46.21014510431598, 44.880583209376184, 45.45413963256344, 45.55757645637759, 52.33200396260908, 52.162749767303474, 54.695165311136556, 40.02576758784633, 49.15990475685366, 54.081396748942716, 47.49549404267342, 47.71111065341581, 48.74713413176998, 53.254380687590576, 47.44194192271079, 46.81761434001308, 46.147712738283225, 47.351201811144435, 44.805293313918575, 47.581009557170255, 46.786121629899554, 48.732742955607755, 51.74736684368503, 52.296710475798584, 46.03452882459087, 38.019757655359086, 37.6652342273343, 39.57964504918745, 39.3149870441806, 39.104995112265314, 39.81806239774151, 39.79135497923821, 39.269263975081905, 40.32662906954366, 38.60295918680007, 39.60354405064737, 39.67879864477342, 39.70182295768492, 43.8125257338247, 49.55922165224629, 50.788162985155665, 53.46073658235612, 53.19514897561843, 49.28172180729528, 49.52321821643461, 49.89109339252595, 50.863507793795684, 49.370630171991166, 51.79533743089246, 50.95798592413626, 53.35772729689076, 54.15767900405392, 49.56878046835623, 44.951664401638894, 44.60519752194805, 42.56416866856237, 44.889479144926995, 53.78972145818896, 55.62732442732781, 57.727004481900124, 53.5324022077745, 55.29760606827275, 55.61775776647753, 59.370948268521225, 58.09749980126658, 62.120529759314756, 62.61942386627198, 64.2108431939156, 45.84369767096735, 8.584635661494348, 0.3880194580603031, 0.17625657601221917, 0.05261678023323898, 14.243743092783037, 61.387438774108894, 45.97195917560209, 42.66457350023332, 33.01458581801384, 23.687872040656305, 41.90271192981351, 53.41011839528238, 46.714879620459776, 16.83639153357475, 0.04289307901936193, 0.03691389300529996, 0.02250055008898339, 0.08626261876235086, 0.013292773660542745, 0.08117621629348687, 0.08335713837896624, 0.10577755184063029, 0.028090400643826976, 0.09107513713740534, 0.01820285429036425, 0.051014480526529016, 0.06390965168154047, 0.08228569546894682, 0.03683027833880436, 0.0724755029284185, 0.06117475226581578, 0.07859948722104873, 0.02612164660897707, 0.056608217062368515, 0.03815397485009125, 0.045593703661354325, 0.0385654789786185, 0.023111332838814107, 10.683937207345041, 54.70572040927026, 57.72500799548242, 55.6272695141454, 37.64632055836339, 38.741105064269036, 42.14977810459752, 41.44117447637743, 38.62264164032475, 68.69413191272368, 14.988270728818833, 0.11228857141348625, 0.3470502709669452, 12.867142173551745, 13.349892785472255, 4.570806603277884, 19.496601819992065, 17.664392109840147, 27.053355863017423, 50.934012397643066, 54.86327417435185, 57.42560171311902, 59.09182456231887, 59.42762259514102, 55.738951160061745, 53.75924856432023, 44.66017346228323, 42.30925775343373, 40.379224131184245, 46.22787813986502, 52.91298543253253, 53.560211812296224, 52.842320011508086, 51.47051026744228, 52.757710564521055, 54.53189273034373, 52.7954202313577, 51.223012631939305, 49.06550115154636, 45.354346690639375, 43.37435776187528, 43.556198843063854, 44.50334925805369, 43.31929160702614, 40.39087357059602, 39.868719808516964, 40.21990137715494, 40.041202114474395, 40.052667202488074, 38.959659530270486, 40.21365304147044, 40.37347001414145, 39.59914315131403, 40.834375965979795, 38.61722092474661, 38.78439626386089, 38.8205526721093, 40.417553532508116, 38.2243327940664, 44.778738867852, 51.67560708138251, 53.384332733769575, 55.13989540838427, 54.46037223262172, 54.549241373615885, 51.76916737710276, 47.100578046614125, 47.694338598558986, 47.51993040884695, 48.37566606460079, 46.25615450643724, 46.61478857840262, 47.42627205387239, 53.466553457321666, 53.985620314075106, 55.82267415138983, 43.88875307575349, 48.64463867679719, 54.18323324572656, 50.60828701142342, 49.99827607985466, 49.82542899347121, 54.78456004973381, 49.019276019065614, 46.71493845601236, 47.74519605021323, 47.69732744463029, 46.87769720631261, 46.875155510440955, 48.0055590598814, 49.95575758718675, 52.608848771741314, 53.70357836446455, 46.780136093016594, 40.24589884665705, 40.07535419156475, 40.002445174801736, 40.518727148732836, 41.41870321766023, 41.63517098273001, 40.824872063052275, 41.92659524179275, 43.296836037789625, 41.05342857299313, 41.11125215407341, 41.88637133567564, 39.82652687257336, 46.81444898728402, 51.73720398256856, 53.137737243406235, 54.72765822564402, 53.26926608239451, 51.6607177642084, 51.294627266545454, 51.16061948960828, 51.11619472503663, 50.309119993640536, 52.679678932313, 52.49151106803648, 55.26939245962328, 56.24499182547293, 53.4797247763603, 46.48176923874886, 47.12479868242818, 44.190108776092536, 46.464663782427394, 56.23896314251808, 57.75603002117526, 59.55017312880486, 56.57837367826893, 56.52200529652258, 57.69230719535582, 62.29481635555145, 60.72299318928873, 62.00180353656892, 66.4549841419343, 63.827466810903246, 51.36487299396146, 11.824283965172308, 0.11510719274801594, 0.16662652904708541, 0.007991975740409427, 16.244631390417776, 66.25096597979146, 51.1480914392779, 44.90968719605477, 41.20332194912819, 35.46265079129127, 50.021786766667525, 61.56646359351374, 53.17623530664752, 21.662277713898693, 0.09875971147970808, 0.06799856170771584, 0.06327400937856686, 0.0910783853502043, 0.05641116392648509, 0.04367471086762605, 0.06659308914095163, 0.09345597752760496, 0.057411368320425676, 0.018345835025332147, 0.06604534393597035, 0.027533533246887308, 0.19902159880486228, 0.13736947800122923, 0.18356539188854157, 0.14282227734163885, 0.200859596952796, 0.19533893754405363, 0.13798478450025284, 0.14597287521727625, 0.12811601687703403, 0.20969772350884255, 0.22259539594092678, 0.22575898666775998, 14.664201563404454, 64.72181820100354, 64.71936279727568, 63.15336042834867, 41.86259000532089, 41.46892916771674, 43.36567755668394, 44.12058084241806, 47.44680958409464, 72.40809086830386, 18.795637007682554, 0.2828896412205312, 1.0467493221644433, 10.972583447733234, 13.003604373624249, 8.440073767016012, 22.55762734720784, 18.65551425564674, 28.578287093870102, 55.12834795059697, 56.803839360514, 60.437487786816014, 61.22988108665713, 62.980560410407286, 57.06470835593439, 55.71139258723105, 46.86418856343916, 42.34291561188237, 42.83445135239632, 47.885526687868186, 55.23524822727327, 55.619177664479906, 54.20654389166064, 52.68089486706642, 54.73837021858462, 56.25964972280688, 55.85138590105119, 54.30113184836603, 51.86938001263527, 47.242254057238185, 45.44534567863711, 44.853181531352384, 45.7218570863047, 45.26988237134872, 40.82094577050979, 41.78401708602905, 43.07699111200149, 42.7235581028846, 42.12781283163255, 41.56259144506147, 42.32428435356387, 43.04021496926585, 40.27955278273552, 43.8704748307505, 39.77093512012113, 41.850779748732045, 40.78853130340576, 42.45082393769295, 38.70410534643358, 46.30103034357871, 54.18261351123933, 53.524353504180915, 54.69226667957922, 55.91974104604414, 55.792346385217485, 54.00410252232706, 50.946854237587225, 50.74511497251449, 48.991246761814246, 50.98109652919155, 48.99156055142803, 49.544434316696666, 48.02145642618979, 55.605629797904726, 55.16171947602303, 56.217292047316036, 45.17434127869145, 53.08318884141984, 57.359976537766, 51.8839398507149, 51.51001637981784, 52.345343943565126, 56.86121579139464, 50.66320411620602, 47.74394089175809, 48.32625596754013, 47.72252082824708, 48.19699818088163, 48.91170501708985, 48.021825128985995, 52.11746992603425, 56.36671866140058, 57.43010067170667, 47.82651462862569, 42.63001741901521, 42.48650573915051, 43.120105804935584, 43.40929823537027, 41.34982247506419, 43.31263534484371, 42.70507589463265, 43.7278417618044, 43.64509544064922, 42.95097320310531, 44.521094060713246, 44.13820405160227, 42.30944994957217, 48.76183125280565, 54.134737060916045, 55.51507796010664, 56.303262556752856, 56.32808331520327, 53.769991936222205, 53.789191938215694, 51.80279385659003, 53.440132371840946, 52.41625647391043, 54.79237341111707, 55.887099081470126, 57.62000614596952, 59.092652182425226, 54.85614722774875, 48.661324439510224, 49.839400476025, 47.157142546869096, 50.675814536310014, 58.62094402313233, 59.84239362901258, 62.34743887378324, 58.84463679405951, 60.81739679459603, 60.36591237591159, 64.96693495781192, 63.553854034793, 66.88711950855871, 67.40750820406022, 64.46754663221299, 53.95657124057893, 14.593982311987109, 1.7060990126863604, 0.6869291009441499, 0.17076904224532266, 18.374348955769694, 74.631117697685, 56.901412240920536, 57.565885282331905, 44.806858339617335, 35.09323020135203, 54.53827442661409, 69.09629252649123, 64.09427035239436, 28.600597535410238, 0.23992511684135084, 0.23254264927198812, 0.12577382562261435, 0.33512785910598697, 0.14244945299240852, 0.18459021834836853, 0.20081410665185223, 0.21725400110646603, 0.18656937585723016, 0.16502595686864469, 0.1860382470993265, 0.2732107331675868], [0.05723863847613816, 0.10926182697256727, 0.012726107999051531, 0.05266870950318633, 0.0671937863432592, 0.08564969479677179, 0.08152536086497769, 0.04327176394121301, 0.048393402624154286, 0.09203440179267237, 0.07867060316305968, 0.03911084548059491, 10.736281237294598, 51.77770245459772, 49.21553181063745, 45.495030341609834, 22.799547372325776, 15.455649572034037, 25.76228418657857, 36.9480876768789, 40.056126732980054, 58.96360228138586, 10.934504097507848, 0.2534784226407928, 0.3547593524619457, 2.476028040532143, 2.838300110832338, 3.8113835213645815, 24.21773914367922, 28.484946450879498, 33.5665495934025, 54.2279286538401, 55.94052176321707, 54.076438873044914, 52.80576744387227, 53.265669268946496, 45.99845086374591, 42.65486955642701, 42.91125136037027, 42.868744634812884, 42.22826473174557, 43.315855610755186, 45.673023577659364, 51.32150726933634, 52.10536941405266, 48.92630800124138, 51.08639647883754, 50.2846561708758, 49.70787948177707, 48.49851077602756, 44.14670775013585, 42.33834997300179, 40.81565057077716, 37.550293091804754, 35.29918209198983, 36.67247841435094, 36.73546775694817, 38.20075542696061, 38.093282484239154, 36.72567752099807, 38.27298587368381, 37.821372016783684, 37.811777899342204, 37.622656899113814, 37.96517787441131, 37.90453018680696, 37.040785051161244, 37.60621040098129, 37.49512495533113, 39.12149652358025, 35.90381937642252, 40.8056838281693, 52.997124195098884, 49.14645494953279, 47.64858022812874, 50.8773616052443, 51.308818401828894, 50.948760509490974, 49.34189881047895, 51.20240449905396, 50.5710558737478, 49.278889856030865, 48.58778784351964, 46.91503032561272, 44.4474672502087, 51.45885298329016, 51.03049878151187, 55.27240876228579, 42.82983472270351, 48.39053969229422, 55.44846826984037, 48.84642108794182, 46.90363976263231, 49.826554713710664, 52.31165862852528, 49.057499516394834, 48.560237115429295, 47.2519854576357, 48.51167817269602, 51.736180243953584, 52.60331038505801, 53.45246038129253, 53.379716104076756, 50.10484295506632, 48.95643572653494, 46.451649358195645, 38.44136538044099, 37.85865022290138, 39.170832095607636, 40.03612656747141, 39.66523508871756, 38.6366327347294, 37.850460313981586, 38.488480890950854, 39.98487295642976, 38.49617265885876, 37.66381040696175, 40.43376861080047, 38.47325817231209, 39.2943436099637, 44.891150074620406, 48.821737612447436, 48.98449636274769, 52.59935271355414, 54.42880499747492, 51.41391046585576, 53.24436295417048, 50.742420304206114, 48.28893461535054, 49.400334281306115, 56.11655381418044, 56.475482063908736, 55.56150313346617, 53.00519251054334, 50.86653978593888, 46.311769793110514, 43.909180779610914, 44.95678701708394, 55.27621346135294, 55.08400163342876, 57.94692001035137, 57.01404310041859, 58.87448210870066, 57.361608243757686, 61.7367729063957, 57.68998515221381, 64.64627335148474, 59.44332776531097, 63.21183120050738, 49.12885919693978, 14.097038603598072, 0.8420453581117815, 0.024777890085392905, 0.1607555069870526, 8.650231419071075, 61.467055043866566, 50.091459828038374, 34.21141470632246, 16.084290781328757, 19.731679270344397, 36.92287860378143, 51.501430311510646, 52.1998946128353, 21.67692384412212, 0.14047714430958996, 0.04103987785657087, 0.042185060559741916, 0.05989917373705295, 0.018842777109614784, 0.04812473941954875, 0.056660563850234595, 0.009068494940537119, 0.03862236100699633, 0.021796444423436638, 0.00848975477574934, 0.03899228188299364, 0.07180444821114502, 0.03275713823255032, 0.01484547683503479, 0.027845610654161825, 0.12796053167192206, 0.08719051211711862, 0.016572709202826504, 0.015070478773615776, 0.04660924896597863, 0.10605153552586995, 0.018254540327395645, 0.05585419885333508, 12.122913618241588, 60.88831324731151, 56.49267773474417, 54.95217077193722, 28.021847894114835, 20.084894587916715, 28.342427130668398, 38.80882478529407, 42.81766360805881, 65.99385461499615, 12.036305723651765, 0.19550340129963814, 0.4184027809289194, 4.5080526028909995, 6.656455849447559, 3.788829157429357, 25.77599875388607, 29.54057981891017, 34.92813764079925, 57.04098586113223, 59.13848115551857, 56.620033171869096, 55.065888127973004, 54.86372524692167, 50.28286757007722, 44.843838445601925, 43.68473491361065, 42.91988841948971, 44.800457031496116, 45.324571978661325, 48.33906250615274, 53.090900221178615, 53.502800080084036, 49.87893796736195, 51.701628085105654, 52.21789436955606, 50.95991965263121, 49.937012580133256, 45.10941036285893, 43.38712115441599, 42.07019713617141, 39.95362343326692, 38.1313177078001, 38.51627088362171, 38.283493903375444, 39.502315521240234, 38.81019761485439, 39.12985901678763, 40.547505578687115, 38.933183531607355, 40.569666970160704, 39.62271267367948, 39.74567113384124, 39.71349985368791, 39.51562412323491, 38.28758493546517, 38.7085376247283, 40.29007257953767, 38.25003608580559, 42.964874082996005, 55.400501605003114, 53.095763960192286, 49.11187925646382, 51.83780101037795, 54.32588200415335, 51.28335829704039, 51.31629443937733, 52.88400696169946, 51.62414166235155, 49.86192664792461, 49.3414242036881, 48.3285270198699, 46.03310108184815, 52.220996964362364, 52.93154216581776, 55.2470741733428, 44.94550628046836, 50.35620412518902, 55.77645294127926, 50.07626064362065, 50.206522557043264, 52.892667555039935, 53.802457394138465, 50.6566890593498, 47.4231812261766, 47.4075113573382, 49.62371326261952, 51.962630441111905, 55.272495054429584, 52.66588003404679, 53.79529514620381, 52.81911134719849, 51.033534696025235, 47.327667590110536, 40.76367916599397, 38.84094899700534, 41.634131554634344, 40.598904317425145, 41.57868885224865, 41.340463699833045, 40.248013004179924, 39.62187720883278, 42.373941559945386, 40.274077153974964, 39.264270797852554, 41.74082002332134, 41.27973364245507, 41.10050878217144, 46.96334608139531, 51.57758705077633, 52.581815796513716, 55.26537203019666, 55.34889498064595, 53.02673024515952, 54.36028511293473, 51.917276074809415, 48.91530967527821, 50.25347332800589, 56.95033204170966, 56.38993517045052, 58.10972190672352, 55.76781588215982, 52.30585744304042, 47.92842957281297, 45.090328031970614, 46.970272987119614, 57.453211276761955, 58.05707977664087, 60.941986960749475, 59.70374961053172, 61.06900507403959, 60.79833407555858, 64.34683176778978, 60.77467826104934, 65.3392110332366, 59.79627047815631, 64.18910541842061, 49.29391253379084, 17.296112929621053, 0.8975117785796043, 0.08678021074663247, 0.07130220862886599, 9.661593975559358, 66.89313642440304, 53.84596824645997, 42.868940753321496, 16.946113955590032, 20.641339671227243, 40.9801822323953, 58.29549320282475, 60.27700008884553, 26.344675748578965, 0.07218638900667429, 0.05076028106193389, 0.02282345040340818, 0.05732564308169869, 0.04838317151992552, 0.026129445384046244, 0.03784803380709022, 0.001255005237556273, 0.06417394052409837, 0.04817511736144943, 0.05260404785193744, 0.08569975098174426, 0.16919511460488842, 0.14538597525848498, 0.10540278162807228, 0.23414479959155285, 0.20021035275872678, 0.3119009619037951, 0.13484117334648488, 0.21138386770842538, 0.12845240608458558, 0.0947191569233133, 0.13842620436222325, 0.13384274627652862, 15.574335590485605, 68.28362449522942, 65.49006539006388, 58.941044730524865, 33.13208041652557, 25.305112331144272, 36.200256424565474, 49.079284360331876, 50.311783282987534, 69.98118708210608, 13.724405592487706, 0.33061305782006634, 1.2251274407871309, 7.768843462390285, 8.460797609821443, 5.754001332867531, 29.06789302825928, 32.019047083393225, 38.5215425491333, 59.878106809431515, 61.00817695740731, 58.85454862348495, 57.95743980715352, 57.44074598435433, 50.467650428895034, 47.24858084032613, 45.50335753348566, 46.046005679715066, 46.634926026867284, 47.428044965190274, 50.60515303765574, 54.673505983045025, 55.23074926868562, 52.07684593815958, 52.93293460722893, 53.93353908292709, 52.33487513757522, 53.539262433205884, 47.653047807755016, 45.83888884513609, 43.550154470628314, 42.49133809920281, 39.14698408495995, 40.075464017929576, 39.987504866815385, 41.91267082768102, 40.98112752360683, 41.54332476277506, 42.6487075128863, 42.31094437260782, 42.602964831936745, 40.60592143766342, 41.94548929891279, 40.758219226714104, 40.274163446118756, 39.917780814632295, 40.1130207123295, 42.378903358213364, 39.96465313819147, 44.23635352042414, 57.862640042458814, 53.27491821781282, 49.10134377018098, 53.395848812595496, 56.882447581137384, 55.35586895481233, 51.77793387443789, 55.238998013158, 54.441078093744096, 53.27933088425667, 51.68890783863684, 50.53939450171686, 47.9640878400495, 53.714207987631525, 55.54639416356241, 57.271366273203206, 48.4860219493989, 54.227744302442, 60.27656470575641, 51.864877131677446, 51.554543126013975, 55.4135670200471, 56.59316101381856, 53.63918089097547, 46.697852611541755, 48.97863241934007, 52.94495274943691, 56.64694455362136, 56.712538350013, 55.302038346567464, 57.09312592783282, 55.69727205461072, 53.520862594727554, 50.631174041378884, 41.80744148069813, 40.97271796195738, 43.782276415055804, 43.897143025552076, 43.8789196937315, 42.59222146003477, 40.59762954711914, 41.020096271268784, 44.476983085755386, 41.81525091971121, 40.08223010647682, 44.823528412849676, 42.85893478701192, 43.032017215605705, 51.1405251872155, 53.80918425898398, 53.50960931470318, 58.0821947128542, 58.049419387694336, 54.31822161520682, 56.96480951001568, 52.511397484810125, 49.50086070645241, 51.29845157746346, 58.614432888646284, 59.455290994336536, 61.088048181226185, 58.75795241325133, 56.27707681348247, 50.56931826376146, 49.01332578351421, 49.97137646521292, 60.78718669952885, 60.94596816647438, 64.05652930659633, 62.278703258883574, 65.39074705493066, 62.76404949926562, 67.8037303493869, 61.489722421092374, 68.1562965146957, 60.39919368682369, 66.56493602260467, 50.10924777676983, 22.53988842810354, 1.3148101058698471, 0.16670430229315836, 0.15986993999010132, 10.677750648990756, 74.71877482629593, 61.04346652184764, 49.19466087895055, 26.452327159143266, 32.468062370054184, 50.724553908071215, 68.85978929458126, 69.94960415747859, 34.28972874918292, 0.30431353517117044, 0.14595900902584677, 0.10161587112252751, 0.13307118848446878, 0.1035323090130283, 0.1714086950185799, 0.07533147104925687, 0.11579999670145974, 0.12850924214768794, 0.2215212027752592, 0.18254082589860887, 0.11604589560339529], [0.0504691829724658, 0.031906849584512176, 0.059033456078219804, 0.046095809178246606, 0.11220966435728535, 0.05950979422777892, 0.02492403476348808, 0.05543067097483624, 0.06125502678896151, 0.07156230314003845, 0.023706154146742438, 0.030539193032910267, 11.873587177645776, 47.83907798028762, 48.678261233914284, 41.4904276786312, 33.80412755473968, 22.443582473262666, 22.564787633957405, 40.62426244058917, 39.47203874588013, 59.7042908976155, 7.959310325884051, 0.09735342685974414, 0.05213155546375821, 6.109644107280239, 13.080721112989611, 1.6702088353133973, 24.624130033677627, 50.31467799217471, 55.00262421946372, 57.4700931579836, 56.12923875931771, 53.07104518336635, 47.30455306268508, 43.25235243766539, 45.779672822644635, 48.7125466715905, 51.52621576862951, 49.37515266479985, 48.920738235596694, 48.42433875606906, 48.52333937921832, 48.148886388348, 49.96649311434839, 49.896098336865826, 48.08170403203657, 50.4655441161125, 50.677454087042044, 50.34374667752174, 44.85245197050033, 41.77885524688229, 40.23126448354414, 38.380980491638184, 38.56410026550293, 39.099982323185095, 38.46478977511006, 36.92127435438095, 37.73180469389885, 38.33248430682767, 35.98385141741845, 36.84596484707248, 39.07142746833063, 36.93344546902564, 37.92376156776182, 36.58121270518149, 36.609445925681825, 37.92744467335363, 39.30550275310394, 37.54484491963541, 35.39466042672434, 37.927978115697066, 49.85684717855146, 49.283557476535925, 39.807672039155044, 49.59568792773832, 51.42453616665256, 53.84056714273269, 53.374793529510505, 53.40452901778683, 51.60363551109068, 52.62189065256427, 52.47549995299309, 51.79487066884195, 46.25555438380088, 47.13167851971042, 49.533671332943825, 55.18513210358159, 45.16715549653576, 49.93825597147788, 55.312181595833074, 46.848412790606105, 50.31495648045694, 50.11373104587678, 54.69150966213596, 46.168324793538744, 44.44276040600192, 51.75907511864939, 49.63611579710438, 52.28413927939631, 50.06967498410133, 50.08823563975673, 51.23666248013897, 49.7092640784479, 47.038608520261704, 43.23266606177054, 38.01786315056586, 37.55670616703649, 39.3572937288592, 38.40594245541481, 38.35408087699644, 39.28955831835347, 38.04433914922899, 38.840548915247766, 39.18968300665579, 41.23142180904266, 39.23605326683291, 39.130878833032426, 39.02873246900497, 38.176166088350364, 37.9304531312758, 43.294392401172274, 47.305529732857984, 49.59745299431586, 50.24259267314788, 52.98782817779049, 52.63320276814123, 52.08522412084764, 50.8143408836857, 51.50484669593073, 51.4150518755759, 51.99509982139834, 55.35144844362813, 54.45629296764251, 53.25913852260959, 49.38235413643622, 46.15593794853457, 41.96616803446124, 50.82293479673324, 55.23287911568919, 55.212059174814534, 59.16297635724468, 57.71999128403203, 59.41474153149513, 62.35063560547368, 62.588307703694994, 60.000033686237956, 56.22916113945746, 60.967321549692464, 45.686179207217315, 14.477858581850606, 0.7307856734241209, 0.19504954016977744, 0.015387092379011936, 5.250892639160156, 55.132580188012895, 53.48984841377505, 41.35833009596794, 39.98912088332638, 51.69761942278955, 42.58054848640196, 47.7144132891009, 54.399646097613925, 27.745534566140947, 0.4050034128369824, 0.0380304393418614, 0.0769134885781715, 0.015678527547166716, 0.06585662583670308, 0.07664883584384957, 0.032188463505477674, 0.059819492932048544, 0.01794721458047148, 0.011845095394810122, 0.014247165039001454, 0.04356074762801009, 0.028416964773749633, 0.03667126529880109, 0.061413246927963155, 0.01977217199671413, 0.03705037539945014, 0.06452574725112607, 0.017522414996018334, 0.04551926289775199, 0.04128026475589122, 0.0623724771092736, 0.019956370177228126, 0.0857325625275412, 12.7132656305067, 55.12379800119708, 54.84584708367625, 47.47491336637928, 36.009550786787464, 23.601238650660363, 25.25217406211361, 43.12140803183279, 45.41784201898883, 63.80084960691391, 9.98753999510119, 0.1973030184425654, 0.0166035633939769, 3.361685742293635, 8.893439942790616, 3.584176551911139, 25.86273608669158, 53.39157342910767, 58.78983343801191, 60.127542095799605, 56.945735023867705, 55.644033724261874, 49.414258695417836, 45.688210994966575, 45.94939770237092, 50.05657426772579, 51.41262785080941, 53.804555862180656, 51.93259685270248, 50.02372049516248, 51.187370054183475, 51.53447628021241, 53.03004072558496, 51.13724608575144, 49.03510278271091, 52.61522262327133, 52.22754732255013, 52.41167514554916, 46.75154593683059, 44.06982145001812, 41.09754347032116, 41.35324278185445, 40.621775657899924, 41.98782736255277, 40.02946638291882, 38.98446852161039, 38.57965638560634, 39.450889325911, 37.83649667616814, 38.308985387125325, 40.533863575227805, 39.04584577006679, 38.81444161938083, 37.8519743488681, 37.98471912260979, 39.945288396650746, 39.90405644139936, 39.79243755340576, 37.66610891588273, 40.48612833023071, 50.813391670104004, 52.574029891721665, 40.56193597855107, 50.29112415928995, 53.62577815209666, 54.3697968606026, 55.070712643284956, 54.05484230287614, 53.2822883513666, 54.50619336097471, 54.768745053199034, 53.15772956417453, 48.82128261750745, 51.30205623565182, 52.560368276411495, 56.9864845275879, 46.45802320972566, 51.3503876809151, 55.695605047287486, 50.423829709329915, 50.51728017868535, 52.88006890204645, 56.97225809097291, 48.31437903065836, 43.94021457241428, 52.51055417522308, 51.33785178584438, 55.37932472844278, 51.59735187407463, 53.66595106740152, 52.43752356498472, 50.1808584890058, 49.54276730937343, 44.90396445797336, 38.45386989655034, 39.758179572320756, 40.502221815047726, 40.43107394249209, 39.64496427966703, 40.42020113237443, 40.34905325981879, 39.579900003248646, 41.611789734132834, 43.79954661092451, 41.0233675279925, 41.88323736190796, 40.81103001871417, 40.69275486853815, 41.08617251919162, 44.68417444536763, 48.573251539661044, 49.7449262680546, 53.93193483352662, 54.57143414405085, 54.47863478814402, 53.09477160053869, 50.746907495683246, 51.450051184623476, 52.86484618340769, 53.72122903023997, 55.26229689198156, 57.41635668662287, 54.879469640793346, 51.95876690649217, 47.88129052808208, 45.79565648109683, 51.9722088690727, 57.73160934448243, 58.89282703399659, 59.81197564832626, 60.58542390023509, 60.84022498899891, 64.25050227872788, 64.40647140625985, 62.78173154400241, 58.56430499784408, 60.25268923851752, 47.956270556296076, 16.728744045380626, 0.6696240327531292, 0.2418236512570612, 0.15310336114658465, 5.366289259925966, 62.165385984605365, 55.0844919297003, 46.88690300910704, 36.608018182939105, 53.85289907455445, 51.98351706227949, 54.398696884032226, 61.18744888613301, 33.56101905145953, 0.5177431181073189, 0.047433356559204484, 0.029788957383002967, 0.07334586308007279, 0.030080723884184996, 0.04978418162453079, 0.08541128057385645, 0.031504645763385686, 0.044099311269218885, 0.02907648412210326, 0.05497215203039589, 0.02559907122274801, 0.1303654119011856, 0.10368035550439551, 0.09994974480040612, 0.11714606681057524, 0.15010136900649917, 0.1091198172540434, 0.1649673051771618, 0.13665937578245518, 0.15818034839485923, 0.1945349895545552, 0.1791811779501938, 0.21623557914168606, 15.846267630977017, 64.99087710534373, 63.92301967067104, 56.25980661761377, 45.198405019698605, 33.69557596022083, 31.387580786981893, 55.97530926427534, 49.22629087202011, 70.3407350663216, 11.369876400116953, 0.3091024120728816, 0.14547179242776287, 13.182969458641546, 21.322875022888187, 4.2196338599728005, 27.98665442774373, 54.33513095301967, 61.25350552220499, 61.685040766193026, 59.935993148434555, 57.30282760435536, 50.8743021565099, 47.857364070030954, 49.64454889297486, 53.37204787038988, 55.84664375551286, 53.6779692096095, 54.10563699660763, 52.90519168300014, 52.881186777545565, 52.756678981165734, 55.569955841187515, 54.03122178969845, 51.16356518960769, 52.78750488834997, 53.52649119592483, 55.8036506560541, 50.16213701617334, 46.15807956264865, 43.85805268441477, 43.51124455851894, 42.35398061813847, 43.69619607925416, 43.259604900114, 40.76909595920194, 40.76149832817816, 42.006270347103, 39.57798196423439, 39.355073667341664, 43.14694658402474, 39.27424538520075, 41.493644022172504, 39.6897263680735, 40.33591331974153, 41.016452389378706, 42.49336204221172, 42.16473802443474, 38.3575443298586, 43.75390198922927, 53.044349531973566, 55.27353840489542, 43.572264871289654, 49.08723108230099, 56.03958906665925, 57.30633812565958, 58.609777035251746, 57.29462592832504, 55.42632649021765, 58.35339915367865, 58.01401215214884, 55.80915374140586, 50.68549494589529, 51.89961756429365, 55.02727239362655, 57.16614869333083, 50.41481610267393, 55.481435791138686, 58.48665383554275, 52.16785277089765, 53.28654020063339, 55.07227374661354, 57.735845504268525, 51.06311721186484, 47.732350287898896, 53.09859198908652, 54.33358553917178, 56.97261894902876, 53.6487671636766, 55.589210756363414, 55.20115106336532, 53.115787659921956, 51.80115038348783, 46.150905547603486, 41.73959624382758, 40.48388473449215, 42.67829787346625, 42.30178563825546, 42.969345584992446, 42.731379309008204, 42.96349733106552, 43.29217626202492, 44.784092903137214, 46.765925345882295, 44.031374377589074, 43.44394060873216, 45.04968443224507, 41.598994962630734, 43.736384684039706, 46.350044281251975, 51.82251161144626, 53.75142343582646, 54.83373088221396, 57.217825920351096, 56.667082002086026, 54.75050995426794, 52.82413198101906, 54.297487966475956, 55.61400405822262, 56.22732154784664, 57.57766808232954, 60.16082340671171, 56.22521523506411, 55.446852253329375, 50.881229062234205, 47.49146969087663, 54.39414693463234, 60.0465137727799, 59.9355891443068, 64.40961714713805, 60.91878614118023, 62.52626757467947, 67.25730496068155, 66.40229886577976, 64.23114145955732, 58.50620685085174, 60.954805266472604, 48.83385381390972, 19.42221995322935, 1.15695480858126, 0.3539166251017202, 0.2433941161800777, 6.420236499078813, 67.35379526692053, 66.54011526415425, 53.62097717100575, 48.87574864972023, 63.254847834187174, 56.348671836237756, 62.92514516461281, 69.78258179080102, 43.83303972982591, 1.1313620786513052, 0.26201843374198486, 0.09663291350607911, 0.19809152209951034, 0.10494319016053792, 0.2115220546482071, 0.19087520367916555, 0.11359803018070037, 0.16421480765265806, 0.1266175488971414, 0.1532039178475257, 0.09351872012860353], [0.09339486669388511, 0.018321697510057883, 0.06476290508984558, 0.03792475751270691, 0.011812515590610284, 0.048279527484649615, 0.023579293816921212, 0.059924638499656034, 0.05856486690801479, 0.02127057102869355, 0.041143625313716556, 0.03841206221090209, 9.125316739082336, 49.35691756586875, 49.877663197055945, 49.225349503178755, 36.95668943466679, 21.613436360513013, 23.019347190856937, 36.666304603699714, 42.06236416293729, 57.1277565340842, 5.735093547451881, 0.15324323347979976, 0.01795874037329228, 1.8133513220856268, 4.058119481609714, 3.289532517233203, 21.283029625492713, 53.379147360401774, 57.164591512372425, 53.29886821008498, 52.347540470861624, 48.54767376376737, 47.49349755625571, 49.820933957253736, 52.94348578299246, 54.84910657328945, 55.24412062860305, 53.06491451878702, 51.78195430386452, 53.00216051840013, 51.3130114155431, 50.27149661894768, 52.814561397798606, 50.224243825481786, 49.54685049672281, 49.51071762269544, 49.85965167322467, 48.42844155526931, 46.13289402377221, 42.73157150514665, 39.0785308807127, 35.560278584880216, 37.664159497907086, 37.216158143935665, 41.03432663025395, 38.92521719778738, 37.83686930133451, 38.59873087175431, 36.6440059292701, 36.47114315340596, 38.58736776536511, 38.19904919593565, 37.296256865224535, 38.07619663976854, 38.51417633794969, 37.29875933739447, 37.990218285591375, 38.797955897546586, 36.39543356433992, 37.40957021713257, 44.938077311361994, 52.78415910659298, 42.2825111112287, 44.769654658532914, 48.35226912652293, 48.74977780926613, 52.688876890367084, 52.30768526754072, 50.21627749166181, 55.24943151781636, 52.60330646268783, 53.067585652874364, 51.468607917908706, 48.33843884929534, 51.07378213636337, 54.01625794749106, 46.20120602269327, 49.646215900298095, 53.30162171394595, 49.10404628322971, 51.698972640498994, 54.026824812735285, 54.091842020711596, 47.25541753153647, 36.65438059837588, 52.650492575860795, 49.70430620255009, 51.411808075443396, 49.56988657674482, 49.35000634962513, 46.38238422332272, 45.31347951581402, 42.3830218468943, 39.74053675128568, 38.04590417492775, 37.21894302675801, 39.9163060034475, 38.96108335064304, 39.52881505412441, 39.720152193500155, 38.79326082045032, 39.238136045394405, 39.82114145832677, 39.89881615484915, 40.23049177662019, 39.39728229276596, 37.88136859093943, 40.09750773829799, 38.466017476973995, 39.2680754969197, 41.01771147020402, 46.104213653072236, 47.02398200188914, 49.951082121941354, 52.5698172661566, 53.137007682554184, 52.54256856056952, 51.7984204138479, 52.50094436830091, 52.57411226149529, 51.67683086087627, 54.75991972031132, 55.91636780769595, 54.88320373719739, 51.135316279626664, 44.06165115294918, 47.597016749843476, 54.38693761825562, 58.766024651065955, 56.11564774667063, 56.69804126985612, 56.80026608128702, 59.177551884805005, 59.37453723722889, 62.20087951229465, 62.642181458011756, 64.66788168876403, 51.814776697466456, 29.522695772109497, 0.36799054893274463, 0.0487548582285883, 0.11270068075147369, 2.2519354329955195, 50.439821212522446, 55.51439939006683, 47.604092705634336, 34.518826546207556, 28.355382719347556, 33.14111363503241, 51.59041712360998, 55.6127175208061, 25.692973944448656, 1.0412649906450704, 0.03644433856431035, 0.097149157175614, 0.03774979069168049, 0.02006823433593156, 0.11459588268471342, 0.04292734996265462, 0.042922607878403324, 0.022027264799802534, 0.06380095529640395, 0.029859006547579364, 0.03241529447897788, 0.028283242211346666, 0.026462777900779923, 0.136786270586233, 0.012982651692694955, 0.011368403887195934, 0.045903115082652345, 0.07048244858461042, 0.03934610725170182, 0.0395081999651607, 0.02421300366310583, 0.03800307851164572, 0.050453719487714196, 11.43440233122918, 56.11235295572589, 57.46443710019512, 53.68461762705157, 41.66004273199266, 21.667743536733813, 24.528383016586307, 43.89927287255564, 47.81125660865538, 62.711885898343986, 6.861355564286632, 0.16080081342689453, 0.07727577921844299, 4.471269105711292, 6.717775242943918, 3.144952726940955, 22.655398307308076, 52.69453294815556, 56.75289561671596, 55.80666303634644, 54.183801989401545, 51.87214136123658, 49.20585532342234, 50.63109559397544, 54.629504834451986, 57.29733236374394, 57.962491819935465, 54.982290652490434, 54.73669928889121, 54.65265858557917, 52.72505291046635, 53.35729191380163, 55.14267636883644, 52.54689885723976, 49.93881687041252, 49.695320052485314, 52.65221057399627, 52.10806015999087, 48.768342387291696, 43.342174714611424, 39.114298974314046, 38.110360483969416, 39.309158402104536, 38.97230525170603, 43.34506157905825, 40.55691142236033, 39.74532988763625, 39.89562334552888, 38.24670207115912, 38.5437157077174, 40.67279392673124, 40.409959823854514, 38.75564529049782, 38.82697359208138, 40.162309215914824, 39.54487715998004, 39.641763625606416, 40.38194625608383, 38.39039810242192, 39.58601890071746, 47.689937699225645, 55.43976845279817, 43.427819667323945, 46.35545322971959, 50.74811166332614, 48.96444128405664, 53.62944949057795, 53.15480347602598, 52.1054635509368, 55.50523281097413, 54.23269825596964, 54.79754701737435, 54.23543607034991, 51.105859279632575, 52.54915422008884, 57.6833838032138, 47.144273250333725, 51.68602881893035, 56.982624915338334, 50.33323472545993, 52.17592108634211, 54.540988706773334, 54.369479148618645, 48.27286074238439, 39.04515543291646, 53.23431776415918, 53.71279201199932, 54.44849137336978, 53.11315182716616, 51.79214462157219, 48.864632652651885, 47.1341182339576, 45.03658371586954, 41.74322443623697, 40.188734223765714, 39.74983669096424, 39.8405061998675, 41.71579530162197, 40.51602855805428, 41.392148771593654, 39.79878394834457, 40.155299940416896, 40.98123734997165, 41.7334577345079, 41.484387228565836, 41.74778615274737, 41.195441907452, 40.593875838864236, 42.06474504163189, 40.55110239213513, 43.40565435348019, 48.172793234548266, 48.78944473881876, 51.861864751385106, 53.53945070697416, 54.712961104608354, 56.05314870034495, 53.56388707314768, 54.253631945579286, 53.59192809750957, 53.515528171293205, 56.74010868995421, 58.836407661437995, 56.637146472930915, 53.25826775643134, 46.368408818398755, 50.283357866348766, 57.59488336501583, 59.513738232274214, 60.60884437253399, 59.654880800554835, 59.0388019623295, 59.77924346923829, 62.23307432666902, 63.176796590128255, 63.48177656050652, 62.391071319580085, 56.09286269833965, 34.51186826152187, 0.11301637026331118, 0.15878362731347162, 0.07536599097112495, 2.70047684831004, 56.137730690740774, 58.72931911099342, 49.27222182673793, 41.73789001280262, 34.2847865627658, 39.43036356279927, 58.09819406078708, 64.28423073983961, 34.78967012897615, 1.4136115461587908, 0.0357735941126462, 0.13284021297529822, 0.007798086068848329, 0.08537521315438133, 0.023174724699328506, 0.03000684619520701, 0.09259420522158185, 0.045296350463984475, 0.08660162032972421, 0.03665115549078873, 0.05029010225928599, 0.23436665865442446, 0.12359448933913825, 0.22297542151664534, 0.176656550517486, 0.16146444475218175, 0.12153981854358029, 0.16210287178476013, 0.13827318596022745, 0.2730630927028195, 0.0762135446852734, 0.1009623138534446, 0.14660475985898128, 13.554343388926599, 65.27897127213018, 65.24678822486632, 61.00404277924569, 48.01013646587249, 30.78218060155069, 33.74646871320663, 48.18909460498441, 53.093787085625436, 67.58564656780612, 7.138870118125793, 0.3509798730092664, 0.4255094415237827, 7.5166620266052995, 10.860724314566582, 5.605599928286768, 25.129256786838656, 54.47983111104658, 57.33214732139342, 57.02480608417142, 57.587834865816184, 54.93855230269894, 51.22157312208607, 54.75072960699759, 56.95539582160212, 59.191048760567945, 59.547199972214244, 58.62068122433078, 57.16138301357147, 57.43382300100019, 55.17359249053463, 56.10276276065458, 58.48158613328011, 53.567409361562426, 50.12081484640799, 52.53421783447266, 54.19192129565824, 54.31926104330248, 50.90077423280286, 46.10712797411027, 42.635022363355084, 40.29013533746043, 40.39789853557464, 42.30534715037192, 44.81091799274568, 42.324472627332135, 42.523470155654415, 42.3373850699394, 40.60032421542753, 40.28038040284188, 43.67078304290772, 42.64299261954523, 42.124776917119185, 42.590468160567745, 42.54141499919277, 39.84868434167678, 41.298588475873395, 41.44248454801498, 40.225027914970156, 41.71857233970396, 48.974011867277085, 57.39419921751946, 45.266364005304155, 48.15558187423214, 50.21069988127678, 50.347186596162864, 54.61498422007407, 56.17149837555424, 53.30930955948369, 58.2058709667575, 54.788274534287, 55.445961875300256, 55.5259507702243, 52.914472010827836, 55.27716267493464, 59.08386215086907, 49.31588565149615, 54.49186494273525, 59.88552008905719, 52.90315989525088, 55.89488498626217, 56.76077958076232, 54.030500073586744, 48.83082182176652, 42.007074432988325, 55.68680717099098, 54.70033891739384, 57.137013327690866, 54.63972260875087, 53.42883594574467, 50.68058413843955, 49.535612906179125, 45.90383152807913, 44.279377998844275, 42.26171078220491, 41.19921914992794, 44.09551689701696, 43.71826725621378, 42.95701757554085, 45.05050812998126, 41.73536792878182, 43.16486004860171, 42.26819838246992, 43.55235492029498, 44.54689933407692, 44.21457652122744, 43.69286598697786, 45.01381043464907, 43.94604321449034, 43.58385939751902, 45.661201553960005, 51.0889381747092, 51.10587496911326, 53.90437233832575, 55.878917017290675, 55.97061418717908, 56.9985693500888, 55.702347601613695, 55.9945837913021, 55.76638421704693, 54.314142350227606, 57.44354655665737, 61.04263890174128, 59.5383079590336, 55.64533595115908, 48.89053598526986, 52.79137626771004, 59.63401771360829, 63.47999188207812, 61.463744563441125, 63.48305917555287, 62.026647829240375, 63.73181196951098, 64.77806498927455, 67.80676626390027, 66.06972894360943, 67.67866165407243, 56.57270977574011, 34.52366282863002, 0.7035465286143365, 0.5616249408452743, 0.1813424498804154, 2.9260901097328436, 62.13485817755423, 66.13390676436886, 59.615304085516165, 40.94790112587714, 37.64666572693856, 46.17864062709194, 68.65779507544734, 72.0274954457437, 45.555356394860056, 2.4098419662444823, 0.08306475326178536, 0.2447230948676025, 0.11402363032703439, 0.12221419808244514, 0.2981082536280155, 0.23685079067945483, 0.17982755697542624, 0.1345130885320325, 0.12603606517997482, 0.07947135656591385, 0.10015551601686787], [0.07770482676043626, 0.018031964972314816, 0.02764273141961425, 0.038751362552565914, 0.011410434343551677, 0.017005568032243082, 0.028067757000005054, 0.0562318342347299, 0.04099704971116397, 0.033063738111166224, 0.03746232768941311, 0.030620411759422674, 3.625307751278724, 41.55419365052254, 55.00278111427061, 44.8693456188325, 30.383593267010106, 20.23496250952444, 22.33802168600021, 35.375813438046364, 40.38202862585745, 55.805039175095104, 7.01320130017496, 0.1506058072611209, 0.31526031873879895, 2.126370312706117, 3.9408707666781644, 3.263132759640294, 18.629897256051343, 52.6689669393724, 56.28567857127036, 53.414570285427956, 52.49753190625099, 55.025056254479196, 53.70081701586324, 53.45456277170489, 52.15699957263086, 52.31768338910995, 48.77160187690489, 50.40699097418016, 50.68338078837241, 50.52269304952314, 51.662937825725926, 53.347854691167036, 50.15454330751973, 47.473411098603286, 46.53461533208048, 46.907303256373254, 54.45696761531215, 49.30048642619964, 46.214730355047415, 41.70992351347401, 38.82421224348007, 38.556404575224846, 37.84670660572667, 37.749251396425315, 38.693216846835234, 39.309429045646425, 35.50896613828598, 37.27582916136711, 36.85209551165181, 38.24239138633975, 36.44577718550159, 37.81653181199105, 37.381544882251376, 35.103785299485736, 38.312672415087306, 37.18654032676451, 37.67420468791839, 37.890754822761785, 37.41886623444096, 37.422157103015536, 40.36990457965482, 49.21325291356733, 51.848579683611476, 51.237042950045684, 49.67960703757502, 50.04217524682322, 48.96248009897048, 50.052487158006244, 50.30762949297505, 50.51675850345243, 49.04785440814111, 52.99221731001332, 52.37667583650159, 49.51740134146906, 46.52420536164315, 54.05071989182503, 43.493782166511785, 48.213138734140706, 52.792490220838985, 46.8320918083191, 51.2969296978366, 54.19087010045206, 48.99045052066926, 48.094632164124526, 49.24781683952578, 50.15499438008955, 52.00585103804066, 46.306384378863925, 45.485828461185584, 41.82616687590077, 42.55583755431637, 40.691181998099054, 38.54469630026048, 37.24434429599393, 38.18912167702952, 37.657632673940356, 39.467049491020944, 38.69739417106875, 40.26375347568143, 38.6413788026379, 37.44367130341069, 37.18780725233017, 39.047497087909335, 40.11477401179653, 39.748255975784794, 39.54447315585229, 38.64932944697719, 40.961919676872995, 39.45286227810768, 41.389210916334584, 39.6946567873801, 39.516306615644886, 43.50649064587009, 44.130516206064534, 48.79145299234698, 51.2134067473873, 50.756717343484205, 53.36927083230788, 53.135254383087165, 52.30246459284137, 54.34735305847661, 53.73289415913244, 52.46899274087722, 55.93342619557535, 53.50121544253442, 43.87749195098878, 45.53761551457067, 54.419293249807055, 58.01135278517201, 59.8364669276822, 58.22035235743369, 58.32291057032924, 58.123159946933875, 61.702208980437256, 62.667445444291644, 64.09326230326008, 67.05689537909724, 75.70486653235652, 35.26480251742948, 0.5779150344671742, 0.20490307030418228, 0.11844881464757266, 1.25584107012518, 44.05368481912921, 57.715892407201956, 44.03842287678873, 32.81926747291319, 29.008855473610666, 42.20501684373425, 48.93084226116058, 58.558358684662856, 21.577448614182014, 1.0180638033536173, 0.05715007871209134, 0.023033965619341023, 0.08713898504333151, 0.030207310337573293, 0.03336409437319925, 0.06501088009005593, 0.07148783173291914, 0.14499121015110325, 0.031354210992914536, 0.046057784404124946, 0.02402649764271994, 0.10463722230445956, 0.016765981694803606, 0.05285140998180836, 0.09789593202332336, 0.018516446636509032, 0.023740986249439662, 0.0465489310332604, 0.04917431051932997, 0.008667504411160706, 0.055866540529795235, 0.03207729648678534, 0.07277743350113593, 5.487571397135335, 50.36711223663823, 59.173182364433046, 53.22003641436177, 33.94905521023658, 25.624497205980365, 29.46335227258744, 35.53063723348802, 46.628128559358665, 60.75138722696612, 7.243764102458955, 0.09925756903906023, 0.07953979120018982, 3.392918105086973, 4.0783196879971415, 3.8378651584348376, 22.65580819499108, 53.67893803504206, 59.1665300246208, 54.44818935086651, 56.4991339560478, 55.68677186965943, 55.77241682237195, 55.0075154150686, 53.949252097837395, 54.166563172494214, 50.188922882080085, 49.286640459491366, 53.47326855505667, 52.332741368201475, 54.20633992841167, 55.42305131112376, 50.04368143696939, 49.333708901559156, 48.19389166370515, 49.75777203036893, 54.866314011235396, 51.982599227659165, 48.44702574514574, 43.236219729146654, 40.298744939988666, 38.86880174759896, 40.02626965122838, 39.233927342199514, 39.8412279159792, 41.10305440041327, 36.90428264679448, 38.41569346766318, 39.46968532377674, 39.93830265537385, 39.04093496261105, 38.28155625251032, 39.44617463696388, 37.27043198001, 39.20389767616026, 39.454709714458836, 40.191205316974276, 39.84714677256923, 37.90017635591569, 39.1117415889617, 41.248790064165675, 50.16510625039378, 53.66568826859998, 52.53957579212805, 48.96475115130025, 50.714214540296986, 49.305930675998816, 49.78069828402612, 50.17939544493153, 51.09107586645311, 50.49966481424148, 53.22118174645209, 54.64231529543477, 51.00456799230268, 48.04260192378875, 56.0240682478874, 47.095706462860115, 50.76269503562681, 54.90838143133349, 51.619168096973056, 54.55340693073889, 54.476516708250976, 50.44282967044462, 49.24211371329523, 51.52164228500859, 51.5110283513223, 53.532178632674686, 49.07965306312808, 49.39233656852476, 44.71478462219239, 44.54477340944352, 43.06361190734371, 39.81909398109683, 38.51865568468648, 40.531976915174916, 38.96213454584922, 42.456417237558675, 40.85272873601606, 41.95978241582071, 39.94674751835485, 37.8577402330214, 38.19070631457914, 41.23214744752453, 42.52775338388259, 42.7962984577302, 40.958193425209295, 41.41624781393236, 43.322292220207956, 41.746887929977916, 42.87426340964533, 42.00334033658428, 42.20873917302778, 45.17041890851913, 46.31930074384136, 49.78480108322636, 52.69472906666418, 53.3342440666691, 55.84476494020032, 54.72271996159708, 55.92907236468408, 54.42456491531865, 56.3035959582175, 55.346286604481364, 58.93535337140484, 55.197118866828184, 47.00272667792536, 47.92673903126871, 55.416387204200994, 61.62320067805629, 60.69115531060004, 61.04160731838596, 60.57141711634975, 59.90434354351413, 64.36453734674762, 66.50556702767649, 67.32556989116054, 68.6415486181936, 74.61824447877946, 36.70809745788574, 0.47467993692524973, 0.3636086485799282, 0.004851905349266506, 1.697889491915703, 48.64087320143177, 63.077866569642104, 46.820779692742136, 37.46427159155569, 32.29507211715945, 44.77443602777297, 56.647579977589274, 66.53492989078646, 30.809437151878114, 0.8110165908452004, 0.015311460348687347, 0.019531913417121096, 0.021496116889700777, 0.008861104405725436, 0.10478440311647232, 0.04626278570222278, 0.0697481916135838, 0.10359179574034869, 0.026077508453219652, 0.03597465771881323, 0.04046639209733375, 0.22929802176452455, 0.12918353741688113, 0.16932720348479288, 0.22873618820261574, 0.16206662050418316, 0.15638886710568783, 0.18494269540233, 0.12811553424164174, 0.1500609961728896, 0.1572242553435987, 0.13516453905932366, 0.13432728156687754, 8.447244840283549, 57.98041705162295, 67.60780011453937, 59.54922783759333, 41.59610417581374, 29.754088155684936, 31.352691304299142, 47.84207467109927, 50.77567415852701, 67.35336380620157, 9.245399121315248, 0.22858102475443196, 0.39780843762620804, 5.635392290930595, 12.397525618153235, 5.2898206922315785, 21.76473786753993, 57.179978970558416, 60.043015018586196, 57.03832257178522, 57.73617106099283, 60.48015925192065, 58.01263540021835, 56.216244774480025, 55.97418354403589, 54.611246201299856, 50.41549075034357, 51.14824833408479, 53.16493888055125, 53.48926398061938, 56.302784027591834, 58.06441853123327, 52.13770935612341, 50.426469464455884, 48.68900068344609, 50.46554803848267, 57.72885584062146, 54.73090202577653, 51.06608252371512, 45.878830340600786, 42.28668451309204, 41.4315725141956, 41.44002914428711, 41.86902661477366, 41.74476592771469, 42.221922259176935, 38.519695112782145, 40.64535694737589, 40.97283563306255, 43.62731141428794, 40.40797118217715, 41.96684268213088, 41.39380401180637, 37.60446102388444, 43.084235729709754, 41.167565622637355, 40.58110852395335, 41.7493982468882, 40.1018419573384, 42.361641007085005, 43.37553447292697, 53.04544387325164, 55.60111514983639, 54.29989237939158, 51.55645724265806, 52.9963279539539, 52.27654164837253, 51.830595616371404, 52.05976401605914, 51.36380218690442, 52.03584540274836, 54.16631998554353, 58.01631066106982, 53.12774696657735, 50.19917203534035, 58.29753283531436, 48.867860763303696, 54.329188562208614, 56.620656828726496, 53.87807284632037, 57.532372551579634, 57.76228620160011, 52.39051003609934, 51.688523446359945, 54.72978022790725, 53.70476684262676, 55.45720731058429, 51.33979728144985, 52.12114126451554, 45.37091870461741, 46.19526755425238, 45.286564211691584, 42.406054004546135, 40.02353968158845, 41.96721922966742, 40.92724984691989, 43.738742028513265, 41.904441695059504, 45.9681034857227, 41.77188127271591, 40.84289143162389, 40.5043085159794, 42.608707181869015, 44.52148629773048, 44.43349969002509, 43.447823755202755, 44.12952384641094, 45.59037531575849, 43.859119569101644, 46.133521602999785, 42.79731042923466, 44.151838210321245, 46.563950738599225, 48.37759979309575, 53.81716235991448, 57.4982165521191, 55.65514579896004, 57.45491358541674, 57.38921780740061, 56.59559680569557, 57.21621774858045, 57.347048405678045, 58.09254192536878, 60.245370095775975, 58.923499968744096, 49.19836751876339, 50.32172256900419, 58.574138379866085, 63.3080743974255, 63.60745714556787, 63.962004107813684, 62.59059836787563, 64.37899128083261, 67.07571491118401, 67.03822489707701, 70.43096526976555, 73.05080259999922, 71.15768632581158, 35.49777561618436, 0.7127467542886735, 0.5791899886342787, 0.24434645540050923, 2.0869539245482414, 54.311235873929924, 68.60556479423278, 57.308071813275745, 42.81764399620795, 41.1581087881519, 54.59920060250067, 64.33074220534294, 76.51711879238006, 42.25648226276521, 2.248344993399036, 0.14220913121056172, 0.13464739906691736, 0.15660508776143675, 0.08688571637556439, 0.1411980024028209, 0.16991877657992227, 0.16902625350461853, 0.18805978459215936, 0.16325348988175392, 0.12857543214434577, 0.16851698889607386], [0.07357368230699532, 0.055577361490577466, 0.06647465960873712, 0.03191289976389418, 0.07002297203026472, 0.06243359177343308, 0.09775261229444897, 0.017875891794720968, 0.07752909385148557, 0.011633251016328653, 0.02913695144196672, 0.03661381636535929, 5.4465262447634055, 39.83891371757754, 55.24802730929468, 36.477269895615116, 37.92125125085154, 23.61704776363988, 16.891755788556992, 34.9739940704838, 37.503656110455914, 58.98451243677447, 5.683704124343011, 0.19387621522670795, 0.05428888587160938, 4.538420573357613, 5.094456259281405, 1.9913629442453387, 19.31909691902899, 46.94196524158601, 58.39265815673336, 55.96223992686118, 56.24828661641767, 55.984977906750096, 54.481957035679976, 52.881276992059526, 52.6736149480266, 51.988498472398334, 52.50092083407987, 50.54081047734907, 46.98527605302873, 50.17735189007175, 49.03800141426825, 47.46518196598176, 47.14693653968073, 50.4653597647144, 50.23607369392149, 52.578858329403786, 51.28285231128816, 49.83657636950093, 44.39254622305594, 41.95308300756639, 36.901988060243674, 37.01647420083323, 35.88333675938268, 38.0611268935665, 37.084229223189816, 37.374770948963786, 36.09296391087194, 36.53910213901151, 35.827042902669604, 35.606546863432854, 36.67313737253989, 38.51286234394197, 38.51198765539354, 38.13485568569553, 37.23083957549065, 38.57764420970794, 37.18004488175915, 38.75644545401297, 37.30236007321266, 36.08281281686599, 35.06397324223673, 43.07272749562418, 49.113373679499475, 53.273870944976814, 52.8495724739567, 53.220491409301765, 50.66139590355658, 51.644769407087765, 54.270458913618526, 49.12157927789996, 47.52371549606324, 51.85920930677845, 51.469219807655584, 52.37216511080342, 48.6793359633415, 53.801567016109345, 46.65928394563737, 48.164932804722945, 56.42668385659495, 48.55963307042276, 52.38298693010884, 50.861170061172984, 50.86468842721755, 50.02008445801274, 51.4005155717173, 52.82328867143201, 49.376674544426706, 47.28474117094471, 45.12469583942045, 43.736353305078325, 40.62107355363908, 37.235338534078295, 38.0069471943763, 39.72209376673545, 37.71424816500756, 37.520961607656176, 37.92513047495196, 37.88267474020682, 38.38799368950629, 39.11943335686961, 38.56404142995035, 37.82396078109741, 38.73344859769268, 40.65011870476508, 39.82475788362565, 39.2206540415364, 39.27752448666481, 40.2430433611716, 39.65585670163555, 40.31640345050443, 39.45163457624374, 38.402655509210405, 38.0957692669284, 40.53119636351063, 42.83718132203625, 46.05608224868775, 48.475231509054865, 48.762086206866854, 50.92149219205303, 52.73081094987931, 52.53930907095633, 53.44030495612852, 53.568248748779304, 55.06841805673415, 53.30240226561024, 47.31622603631789, 44.26692447354717, 51.28304842979678, 54.5676725910556, 56.60264138252505, 56.612388472403254, 58.94829327060331, 57.74731451465238, 57.44494292043871, 56.74220323562623, 61.739416583891845, 60.60236069463915, 63.757546640211544, 27.661850798514585, 0.3127918608726994, 0.15575777919542405, 0.11140310400796515, 0.7832868433287068, 41.74054937977945, 56.83637542109336, 46.226536689266084, 40.96785030057354, 22.843060185832364, 34.75179964496244, 48.08842305214175, 56.491634384278335, 29.006664829869425, 1.9280243881287116, 0.021590623411259825, 0.04033303917235425, 0.07036483110559565, 0.07913798574478396, 0.04320568885774382, 0.04307200651495688, 0.07152582203308422, 0.029304106081385287, 0.021525764492370432, 0.040924903380894856, 0.05002185274215956, 0.03108608404985599, 0.070824139120598, 0.07569986741028487, 0.0064016222172687135, 0.0457269991297395, 0.0632382407333822, 0.03343301164286752, 0.025603248317155148, 0.09061745322880246, 0.0515493554543824, 0.06778642430060333, 0.09917503072609825, 5.941465131698116, 47.72257574142949, 60.35865599109281, 42.50692559826759, 41.55817485624745, 24.351627288326142, 20.273878305189072, 45.4654948942123, 42.250677154910186, 63.26272003112301, 6.0027840348982044, 0.11453775193301902, 0.08751198559278443, 3.7066787913922346, 5.53548461967899, 4.9787708540116595, 23.070545888716175, 47.24503109532018, 60.81250952136133, 56.16871741510207, 59.64971896140807, 56.183045833341545, 56.113804232689645, 55.870075994922274, 54.35253843184441, 52.356687438103464, 53.81222409586753, 50.09065574215305, 47.638844905361054, 50.643023521669456, 48.80964102283601, 48.81821532403269, 47.6157303779356, 50.833991958249, 51.22141622727918, 52.439355311855195, 52.63813318744783, 50.97200055276194, 46.39806978164181, 42.459429617851015, 38.48207566045946, 39.016800618940785, 37.10853222877749, 39.769915303876324, 39.15267152170981, 39.31193936255671, 37.83350390772666, 38.60845050504131, 37.754440692163286, 37.79798292344616, 37.5718935843437, 38.39370466047718, 38.519428391610425, 38.27329181855725, 38.545708271764944, 40.30949223426081, 38.91636048593829, 38.46385232863888, 38.56929740598125, 37.644175021879136, 37.90110595764653, 45.76566996112947, 53.055426305340184, 55.03764314036216, 54.264473376735566, 54.95584603278868, 54.05952561286188, 53.38366593084028, 55.60876769404258, 50.89423956409578, 49.17338986550608, 52.13951364640267, 54.4174732700471, 54.68415914043304, 50.4445751251713, 56.064205861860714, 47.98485679011191, 50.47105112383443, 57.62552884317214, 50.43959371505245, 53.67408998550908, 55.26152026268744, 52.415711264456476, 51.604855368214274, 54.35589990308208, 51.457272268110714, 50.81425851391208, 49.09293028616136, 46.48345978029313, 44.5431181692308, 42.75020276346515, 39.68742785915252, 41.593731141859486, 40.60176764765094, 39.78136470240932, 38.50362908455634, 40.22243130591608, 39.62704689271989, 40.083155785837484, 41.42011527092227, 39.23302519705988, 40.10661940420828, 40.01649902712914, 41.317588436988096, 41.902441286271625, 39.81858015060425, 41.79298362424297, 40.65643764311268, 41.202780662044404, 42.24792757341939, 40.83233633349019, 39.38276952312839, 40.79492084441647, 41.536911687543316, 46.61107801621961, 48.10746223695817, 51.653971287512014, 51.30151102619787, 52.78520637942899, 54.66028367319415, 55.83060910624843, 55.50338145225279, 55.12873234287385, 56.3483972703257, 55.64963879123811, 49.38827691539642, 46.1392717976724, 53.028483544626546, 57.17171453660535, 59.403111703934215, 59.01458917125579, 59.58798085489581, 59.59965382852862, 60.33344299562516, 59.401507454533736, 63.07683890865695, 63.85968515949865, 67.13669992262318, 29.446158562937093, 0.5028792963393274, 0.21751647815108302, 0.042495923717656446, 0.8510310791673199, 47.09844035487021, 63.90087396867814, 48.208663309774096, 42.86757576850153, 26.647702378611413, 40.413046729180124, 54.714741860666585, 64.54572339211741, 36.2609354911312, 2.2863204008148563, 0.030351340612997452, 0.03627522848546505, 0.040852596172161644, 0.03225901637286429, 0.027610977075152823, 0.012257875059731306, 0.0591087318776596, 0.04790235558644899, 0.04148428929188559, 0.0520861839064427, 0.037948896943200985, 0.19710886111903578, 0.1559791786055411, 0.15975334140802586, 0.1324552384715888, 0.1483514862916162, 0.1855418987331852, 0.14161103104631748, 0.12413482647389175, 0.17328796998387383, 0.13640848198725333, 0.13942985615182307, 0.3085764161040706, 8.190451677768461, 57.61906085475799, 68.10816903268137, 49.53722107794977, 51.99668838131813, 31.49230807058273, 25.162849926179458, 48.98134277712915, 46.347388836645315, 69.52435647287678, 7.392899480558212, 0.5524907825935272, 0.21382574232355242, 14.953825454558096, 11.449122005893338, 5.172545746449502, 22.01476739298913, 47.53080714133478, 62.09057461830878, 58.95914254649993, 61.0457532636581, 59.5551976849956, 57.59584826807822, 55.21221214725126, 53.59742333812099, 52.653932494501916, 53.90461944764661, 52.43117717004592, 47.10947790453511, 50.299015968076645, 49.7734889676494, 49.295128468544256, 48.12404209567655, 52.085396705135224, 53.30494788385207, 55.11046194261121, 54.812491247730875, 53.814636353523504, 47.93768636641964, 45.59502724678286, 41.19782670851677, 40.3486414109507, 39.12528945553688, 41.0949037151952, 40.41223872092463, 40.26222375131423, 39.74870312598444, 41.64604771521784, 39.376407438708895, 39.091192291628936, 40.044108590772076, 42.529389012244444, 40.78615434708134, 41.45931936079457, 40.485838074837964, 43.530672057982414, 41.82074616032262, 39.75528486313359, 40.7655736707872, 40.31718400216872, 38.709208350027765, 47.26347800224058, 55.946664194906916, 57.085457694145944, 58.19737511296427, 58.53261224685177, 55.94221622713151, 55.25808034404632, 59.29941992605887, 53.21392536163331, 49.96927015243038, 54.601102952034246, 55.94013344857001, 57.63065145861719, 53.389004276644805, 58.02778751619401, 49.308272330991684, 52.193042232144265, 59.66171749176518, 52.54199589452436, 55.54821806569254, 55.49572498567643, 54.155988462509654, 54.436175131028705, 55.7999244043904, 55.786105894273334, 52.0262473629367, 51.24199298120315, 48.49207024420462, 48.05569087305377, 44.32015888152584, 41.53597816344231, 42.01515843791347, 44.251372275813935, 41.70407525954708, 40.63272691542103, 42.490094707858184, 40.446582994153424, 41.37138374390141, 44.67298000089584, 42.63457521315544, 42.85891909753123, 41.1775480547259, 44.16507228728264, 42.91016486383254, 41.94869779771374, 43.54289416343936, 42.87005470645043, 43.438535582634714, 43.956245299308534, 42.48705879334481, 40.773206603142526, 41.21899574033676, 44.133046134825676, 49.549180384605165, 51.10248604128438, 54.081930191286155, 53.657478747829316, 55.62087997313469, 57.570219501372314, 57.58656009551018, 58.057213137226725, 57.42099292816655, 58.07590323109781, 58.67614746093751, 50.12286624600811, 48.514059051390625, 56.65827235867901, 60.46642703394736, 59.77127321304814, 61.71243067710631, 63.721943286157426, 63.30912559263168, 63.1963574501776, 62.33251425527758, 66.58667379809965, 66.00745739475374, 68.27776447419198, 32.97216146223007, 0.7653530314564706, 0.24802694097161296, 0.343122722040261, 1.3272146015397965, 52.00428208997173, 69.85875421954741, 59.89388258226457, 53.37525244682066, 34.56599696989983, 49.243215899313654, 63.576693996306396, 72.87339379710536, 47.68820401160948, 5.078782958369102, 0.16639628898232214, 0.18038047327389642, 0.11203290489051612, 0.16392297411878265, 0.17830912474422686, 0.12231571239329155, 0.20469057283574538, 0.20911243233469226, 0.1404748307240586, 0.10723897946938392, 0.12192242583560368], [0.05142302755566855, 0.06661886033872444, 0.05100572797199411, 0.04839572387056486, 0.036538153691517736, 0.10198092734020564, 0.041907254095760085, 0.03076977975245926, 0.034649605231900374, 0.08394150258672815, 0.051303697870143, 0.021320609976687742, 2.277942463274925, 42.18301626943773, 49.033498533310436, 49.362965860674464, 22.983129985870857, 33.29743577587989, 34.48885179335071, 27.442913901421335, 40.776171914992794, 50.251876923345755, 7.601083690120329, 0.0492711938286741, 0.14450325810861203, 2.206721781722961, 2.8126215790548637, 5.085249475894436, 22.284073406650176, 43.297491073608406, 56.20537588673254, 54.33860617299234, 57.32278070142193, 54.65466291673722, 55.55504298979237, 52.08600859488211, 54.06443249794745, 52.217353082472286, 55.083479958195845, 56.18499525131718, 52.968792915344245, 53.74178224994291, 52.42052009028774, 52.144651951328406, 52.8113450542573, 50.015832608745946, 50.96591303425451, 48.99666355502222, 49.731954989894746, 44.898320167295395, 40.01077628904774, 36.55546234500024, 37.66831721028974, 35.91124050078854, 35.3619517818574, 35.76210806446691, 36.91573989006781, 36.091218456145256, 34.55508101371027, 35.7292817484948, 36.93270414106308, 35.32904309611167, 35.694168690712225, 37.481757517783876, 37.71152604010798, 37.12282142331524, 36.51575226937571, 36.8181356306999, 36.29079649525304, 36.99440302387361, 36.50400477070963, 36.06020427519275, 36.129049716457246, 37.05958104902698, 43.66704110176333, 46.41594402251705, 49.36112626906365, 47.49315631005072, 48.25062482587753, 49.983567191708474, 50.50987866617019, 50.551871561235004, 51.016295879117905, 53.831518234745154, 52.07602616279356, 50.89412581536078, 50.07242064322195, 54.54937865657192, 49.6716328590147, 48.097664156267726, 53.49642230618385, 55.554156534133426, 53.84240281197333, 51.74087139867967, 51.63607743478591, 50.44791698455811, 51.928701939121375, 51.76184038962088, 52.40514832158243, 50.88524949166083, 49.64697291774135, 48.81140216704338, 47.73215809176045, 42.60851890810075, 37.28760019425423, 38.14606974201818, 37.80294864408432, 37.161798015717544, 37.05996544130387, 37.88370240119196, 41.4885723975397, 38.839176085687455, 38.560221041402514, 37.22765068854056, 39.59130233333957, 38.227098065037886, 38.41182993304345, 38.16930586291898, 39.18505068748228, 39.39417969795966, 39.312868964287546, 38.04215831141318, 40.350233893240656, 38.90126328314505, 39.22395667722149, 40.18130525465935, 39.6290433791376, 39.89935351956276, 42.38423778164772, 43.752701743956536, 45.62830071295462, 48.50759106297647, 50.584744945649184, 54.078188250141764, 55.92635023978449, 56.00153030887727, 51.46149273841612, 46.931688631734545, 43.23737290597732, 46.813582143475934, 54.19986801762735, 59.368081015925256, 58.90292321482013, 57.959126426327614, 56.7621563326928, 56.02033807385353, 55.996709715935495, 61.0273769594008, 63.94407495375603, 64.24727809044623, 22.5539913100581, 0.3028158332792021, 0.3500930802716363, 0.02213901596053714, 0.4394016799426848, 36.94089404998287, 61.10103514886672, 50.012961433779815, 33.956244914762436, 22.98210232488571, 37.79001266725602, 50.60329775656424, 54.73935473349787, 36.87607688288535, 3.7307849430268814, 0.0824544263342696, 0.0994605363737191, 0.060723296652037295, 0.02283118214578398, 0.04944291243690157, 0.08280394628884331, 0.049941800384511875, 0.022838812381509813, 0.020810906782806404, 0.013712058369550976, 0.03596251905565301, 0.03772165994310091, 0.06792903156770815, 0.04212216857159811, 0.04807876648321267, 0.013262688430146346, 0.05439258736347961, 0.08339581049738393, 0.05165252068470563, 0.05760480935174612, 0.03967514967605953, 0.0041244852341591354, 0.06041775014431727, 4.144114505860114, 49.76872328789004, 56.52191115963844, 55.786874678827104, 32.905904785279304, 46.16533594746744, 33.60435731949345, 34.13281040806925, 43.34362991394536, 59.692178618523386, 8.03895160075157, 0.09102200893985649, 0.03071728740788756, 3.8949920285132626, 5.158840004474887, 7.015110023560063, 25.26898926304233, 45.7176915291817, 56.70939653150497, 54.68342565721082, 57.90466823885518, 56.548473450445364, 57.31670887239518, 53.43882622257356, 55.285685985319084, 51.697274254214385, 57.137158455387244, 57.612918423068145, 55.08929683316139, 53.150998776958836, 54.98097273611254, 52.63912554710142, 54.399932430636504, 52.08966032151253, 53.658620157549464, 51.14213728135633, 51.05216987671391, 46.60450020144063, 41.498315565047726, 38.18505417916083, 38.81088402963454, 37.765886168326105, 38.576620471092966, 37.56983434000323, 38.95537237967215, 38.15116097850185, 36.89240963228288, 37.88268650731733, 39.38750382392637, 39.09899388590167, 38.34061538019488, 39.54213150085942, 38.29492369005757, 39.989571955896196, 37.54844173308342, 39.308393539920935, 38.06723010155463, 38.89074740871307, 38.00255806215348, 37.76127738337363, 38.49712187244047, 38.46138123543032, 45.670438735715805, 48.56166878054219, 51.462085016312145, 50.47275343248921, 51.579520779271284, 51.440888527900945, 52.50315266270792, 51.48772947249874, 52.70876330714072, 55.42767970792709, 52.53624569985175, 54.756209158128314, 51.00430127113096, 55.42220800153671, 51.22926488999398, 49.69627711080736, 54.69866406533026, 55.35950499196207, 55.11149352596652, 52.318248210414765, 55.29378567972491, 52.391933856471894, 53.68330755541402, 54.84036361017535, 53.69295266366775, 52.132123900998025, 52.79443963881462, 48.93702783892232, 49.9275988917197, 43.78772850959532, 39.77858374195714, 40.34173803944742, 39.59848811549526, 39.06642252399076, 38.85547353375343, 40.94547317874047, 42.55963440864317, 39.64788252307523, 39.652389326403224, 38.17093364654049, 40.23719902961485, 40.422597700549716, 40.43128967285156, 39.48884610206851, 41.163929585487615, 41.53463671284337, 40.90433928274339, 42.2464096161627, 42.111617365191066, 40.7011918867788, 40.86622168940883, 41.76118496925601, 42.43804093330137, 42.638995724339644, 44.24170363333918, 45.24262974339147, 48.23659843014133, 51.86301008347542, 54.01879179862238, 55.630281894437736, 57.856827089863444, 58.4096694761707, 54.44728720572687, 50.90611257860738, 43.8498039399424, 48.76269417424356, 56.582331349772794, 60.725358378502634, 60.06491753362841, 61.04135236432476, 58.979872272860625, 58.000840833110196, 58.9862657362415, 64.50135354072818, 65.35035056452598, 67.13794723633798, 23.91248852975907, 0.6548182498062811, 0.5224519234991843, 0.08061531735884567, 0.3217606973503867, 41.66590667540028, 66.21207960190313, 51.13532412436701, 40.2538965594384, 29.59783857868564, 50.191119409376576, 57.08182165699621, 61.44035939247378, 44.97817570163358, 5.270513805650896, 0.0667446902802875, 0.017070507390364524, 0.017179899000292344, 0.042577753399288466, 0.04744269517100146, 0.04136456124063942, 0.029026115756301634, 0.024771447285949707, 0.11540262689513546, 0.05437202939403154, 0.018327389543335286, 0.139218584424065, 0.21755997662342366, 0.1848194931423472, 0.1344942580908537, 0.1458500406794971, 0.12858963541446194, 0.12069108505402842, 0.08855215679373472, 0.18856630660593512, 0.2613541742245997, 0.2017514918360018, 0.11289637791173113, 5.42511647747409, 59.847547623419, 61.260397126597745, 64.11822818940686, 34.46521559069234, 44.631359730997396, 45.08088688696585, 38.028492773732836, 51.149895729557166, 64.09318777822679, 9.402604776044047, 0.1632423662850934, 0.3468680952585513, 5.84305384466725, 9.412060629936958, 10.257392198808732, 25.583084821701053, 47.04764566113872, 57.76988775499406, 56.14515965984714, 60.076818004731216, 59.28954339796498, 57.691004968458614, 55.05086937258321, 58.90242115143807, 56.094674833359264, 59.454635958517756, 60.083486034024155, 57.45679240072928, 56.33742640095373, 56.40632283303046, 53.53001348433956, 57.318485706083244, 54.18125244878954, 55.663398465802594, 53.907663206900324, 54.78995330872075, 48.80496555759061, 45.33933577998992, 39.3743521167386, 41.41388654708862, 39.94469219638456, 40.50498316364904, 39.04392773105253, 40.50288861797702, 39.79388098562918, 37.954736525012606, 41.24802912435224, 41.25682700064875, 42.46773327550581, 39.47736532457414, 42.00748235948625, 40.214225707515595, 40.246722544393236, 41.17518678788216, 40.84677457809448, 38.86963329007549, 41.04879233144945, 40.284789146915564, 39.05174893717612, 40.42875974409042, 41.030643524662146, 47.64336347579957, 49.992776916873076, 53.80203770053003, 51.994291813142844, 54.502514177753085, 54.38024997711182, 54.65411770728327, 53.26069962593817, 54.75658962803503, 57.17409149292977, 54.51173959239837, 55.83259382555562, 53.61788634330996, 57.8357796515188, 55.81045989067324, 53.19257197841522, 57.959997192505874, 59.97727609449818, 56.60251586667953, 54.417920420246745, 56.54890883353449, 54.75331052657097, 56.50185608094739, 58.631726618736025, 57.221112866555494, 55.59085815183578, 54.82068115665067, 53.05842691852201, 51.87547145351287, 45.52713886384041, 40.45787157550935, 41.84385676537791, 41.367653569867535, 41.52107315678751, 40.91088571856099, 41.837549594140825, 45.6864929968311, 41.93925665270898, 42.02407006294497, 40.3744270724635, 41.79091653516216, 42.38785420694659, 42.155571445342034, 41.23736812222389, 45.06350294236214, 44.1455820298964, 43.309419001302416, 43.81780524407664, 45.82284635113132, 41.565827400453635, 44.78071182004867, 43.875071848592455, 44.433684041423184, 44.112241883431714, 47.40287119342435, 47.51910278874059, 51.56714177900746, 54.354632977516424, 55.36157600341305, 57.11554227336761, 59.352360156274614, 61.737957462187744, 56.48218147216305, 53.51630872295749, 46.792326819512155, 51.56456478180424, 58.7970192201676, 64.25051012346822, 64.18218243506648, 61.416570217378684, 62.63985941486975, 61.235717573473536, 61.629919698161466, 67.09709182862314, 68.33725898496567, 68.78632330125379, 25.535269168115434, 1.3615130320672066, 1.4226267462776554, 0.21017873479473978, 0.5721387928051334, 46.72512092897969, 74.03599216092017, 61.80759129985687, 47.02751997978457, 33.89434206870295, 50.60745546894689, 64.75210282110399, 70.93007118471208, 55.580707057829834, 7.6861084180493515, 0.1753823011512718, 0.17432603444303238, 0.21823843941092494, 0.10921013902031607, 0.1734321783747404, 0.20201378501951697, 0.17701714810344482, 0.12464334031627064, 0.20634847903443923, 0.11864506339113559, 0.15892927594963582], [0.04481311752310684, 0.0038900970426883792, 0.02078643218884545, 0.08457508794362507, 0.055255305788089196, 0.021193717088129733, 0.03525843445752417, 0.032469334321156625, 0.02943240857172397, 0.017885969681364876, 0.018560513929133455, 0.06347625276013728, 1.6455100380605268, 38.96159718113561, 54.26025682880033, 45.90694981236612, 22.478236613735078, 8.943396229897777, 38.99719269044938, 43.38073945814564, 36.7189702680034, 49.01078016527238, 7.416683262394321, 0.15962002678744255, 0.086873083585693, 2.198485294657369, 4.12035474854131, 6.06250015958663, 23.807300367662986, 40.5885531825404, 61.90849819490987, 52.56617730663669, 56.01181868583926, 52.494174357383486, 55.22934113779376, 53.192732795592285, 52.83058820232269, 51.58812645942935, 51.97879060622185, 48.62185755083638, 51.216525031674294, 50.64896199011034, 52.337075587241884, 52.41595445140716, 50.259274513490745, 49.57407566808885, 49.124085672440074, 43.040058074458955, 44.27957411735289, 38.1633242484062, 37.26957690331244, 35.52842893908101, 36.59634520930629, 36.63076400756836, 37.45719171339466, 35.49202149914157, 37.807784926506784, 35.53805443548387, 35.85675093435472, 34.10593825001871, 35.55816442735734, 37.30798475203976, 37.31467631555373, 37.69799386301349, 37.116608388962284, 36.975120652106504, 35.97552030317245, 35.073928217734064, 36.283245932671335, 36.57025360292004, 37.00053761082311, 35.75496542838312, 36.01749358638641, 36.51757617150584, 40.474376909194454, 38.87022164560134, 41.493392990481475, 44.418120076579434, 47.68466995608422, 49.6250468684781, 52.54901693713281, 51.320444307019635, 51.19264564206524, 51.99416237492716, 50.93928014078448, 51.78341342556862, 49.98531656880533, 53.22273108267015, 50.14359989473897, 49.360773255748136, 54.867263224817094, 48.51946799985824, 53.43790446558307, 52.288077339049316, 52.644683545635594, 51.9701966931743, 52.45669218801683, 50.7432871480142, 50.182615710842995, 52.88576026116648, 53.02553784462714, 52.53759499519102, 53.07007243556362, 50.289531676999985, 43.53882666557066, 37.88439666071246, 39.002232936120805, 37.14011907577515, 39.791857042620265, 38.37167270721928, 37.93823903606784, 38.123108187029445, 38.39415573304699, 36.93881911616172, 38.66038660849295, 36.57605871077507, 37.1423077583313, 37.48020425919564, 38.35563021321451, 38.563072604517785, 38.2721229522459, 40.7629809841033, 39.92172671902565, 39.76792666219896, 39.43739245014806, 39.27659880730414, 40.28593447900588, 40.33488173638621, 39.51458077276907, 40.279454723481216, 40.5158128276948, 41.283914889058764, 43.0460161547507, 44.49237838868172, 47.66973357046805, 49.27707772101126, 46.32207778192336, 44.828607882222826, 41.63493956288984, 46.315241090713016, 54.29644853838029, 59.09762182543355, 58.98440653277982, 58.18116395704208, 54.50327511756651, 53.34621514043501, 56.857144371155776, 60.68487167358399, 63.723206289352916, 63.79412274206839, 20.621082590472316, 0.14795613895741203, 0.17820659153644117, 0.1232197497700972, 0.23262675040431563, 34.627582103975364, 60.17334753467191, 47.54217024772398, 46.965118992713194, 18.149575571860037, 20.922018597202918, 47.542378133343114, 58.35777259642079, 39.4842412394862, 2.301091556587527, 0.06712322198455373, 0.035961120945191195, 0.0625444332047576, 0.0926372746846849, 0.01732751648242195, 0.07083568406561691, 0.025636697631149043, 0.06919611035095108, 0.0569027319039789, 0.036553237962746815, 0.020619888504546498, 0.06958137596807173, 0.056673506905715314, 0.02544256712069675, 0.021534063139810197, 0.07585497723231394, 0.033492241730733265, 0.022205947147261713, 0.04490282641904009, 0.04168879263283264, 0.03538434483831929, 0.059615679070233345, 0.017477319230355563, 2.9242939093420586, 46.92817811043032, 59.74580918588946, 54.253792762756355, 27.276028817699803, 14.803503559481713, 30.93831054625973, 36.886498620433194, 44.142726544410955, 55.17139596323813, 8.732362908701743, 0.1324976950643524, 0.0851679021011918, 6.053957237351326, 6.387294473186617, 8.004354334646656, 20.19625852184911, 42.564419700253396, 60.509918274418006, 54.898355853173044, 56.344890671391646, 54.95393191614459, 56.29932841947002, 55.88991142088368, 54.204037497120524, 54.044420565328295, 53.8923934198195, 51.55693577181909, 52.82270423827633, 53.279126921007716, 54.75921369368031, 55.398269776375066, 51.805904296136674, 50.91919368313205, 50.31525850296021, 46.423090580971014, 43.93684133406609, 40.051129633380526, 39.86388744846467, 38.055239415937855, 37.89162166656987, 38.70803556134624, 39.66640787739908, 37.316543363755756, 38.350684104427216, 38.22487800352035, 37.72110839043894, 36.369443939578154, 38.32044263039866, 38.87855668221751, 39.687153293240456, 37.85631641264885, 39.308358238589385, 39.91627070211595, 38.407327052085634, 38.8587212562561, 38.226419494998076, 38.355606678993475, 37.50117717250701, 38.494415437021566, 38.61604421369491, 37.837877350468794, 41.25948636762558, 41.68789156021611, 44.44571395074168, 45.47126470073577, 49.16894582010085, 51.5383319700918, 53.149198409049745, 52.502658444066206, 52.346579490169404, 53.59036307181082, 55.03121045327956, 53.88794152967392, 53.49918365478516, 55.1141607376837, 50.249488199910815, 50.776756732694565, 55.592685976336085, 50.26052967194588, 55.727038921848425, 53.5840755124246, 53.482403755187995, 51.739298528240575, 53.03526140028431, 51.49703725691765, 52.03963441233481, 54.488609375492224, 54.86161893413913, 53.32443814123831, 56.26967137859714, 53.421595250406575, 45.051159243429865, 38.9129872475901, 40.417910468193796, 40.24784434226252, 40.69505337745913, 39.62663504385179, 40.94656752001855, 39.462040624310895, 38.8126177172507, 40.03580885548746, 40.28374579644973, 39.51623993535196, 39.78598525447231, 39.10226122025521, 40.58277553127658, 40.60758060024631, 40.21375110072475, 40.62392511675435, 40.82526037769933, 41.35896159756569, 41.52508181910361, 41.844162710251354, 42.35877375448904, 39.64844342200987, 41.678897565410985, 42.38293555475051, 42.884449804982836, 43.976241542447, 44.77850744801183, 47.17252216031475, 51.49109878847676, 51.93882165416595, 48.67713159130466, 47.033223106015114, 44.51472020918324, 48.54940352901336, 57.30129395761798, 62.58888036974015, 60.830340616164676, 62.51335905444238, 56.674444290899466, 55.72287336472542, 58.50135487894858, 62.05949375706335, 65.10457092715849, 64.01280664628553, 21.75739715176244, 0.5678266983839774, 0.7160547219457165, 0.01394810633839018, 0.5141971116104435, 37.60121722375193, 67.3991378661125, 51.79763593981343, 45.03325362359324, 21.84206151193188, 26.76352800861482, 53.021744912670506, 65.0203105711168, 48.8111589800927, 4.195464214970989, 0.034300667504149104, 0.016399397131716533, 0.050556662552539385, 0.1078507926074728, 0.05676882356525429, 0.05653061618607852, 0.01582259612698709, 0.03197051915189913, 0.06833364090491688, 0.03870804028044786, 0.014550543517895765, 0.1487931206582054, 0.24407236446296018, 0.07093425659883408, 0.2718410292460073, 0.23483623990849142, 0.08294748818321575, 0.30013136926197237, 0.08150650744116114, 0.1258353807873303, 0.11575031589957015, 0.11873967524978424, 0.11585006054731146, 4.683860098162006, 57.04388841505974, 66.4130618495326, 59.7190546989441, 33.66869203505978, 16.593031998603575, 48.58584234791417, 54.898191113625806, 48.332123833317915, 60.69095526972125, 9.49025111813699, 0.3980998268290874, 0.23887690937807485, 9.750353290188698, 11.274148994876493, 10.040786170190382, 26.594224783682055, 43.4231363573382, 62.978187376453036, 55.596627958359264, 60.44904701171383, 56.105296611785896, 59.44257074786771, 57.473623291138686, 55.80083831664055, 54.98919010162354, 56.04986567651072, 53.84719202595373, 55.13930705285842, 56.31504143438032, 56.628450578258885, 57.94952446414579, 54.521110134740034, 52.942803290582475, 53.39913968117007, 47.758041812527566, 46.059094628980084, 41.56530572522072, 40.508854543009114, 41.20401228627851, 39.99167434630856, 40.534365638609856, 41.85541599027572, 39.33115505403088, 42.35898948484852, 40.34129481161795, 40.1517854967425, 37.51598411990751, 40.95652249551589, 41.31864747693462, 41.856784897465865, 41.13160925526773, 41.456330514723255, 40.68890310102894, 38.787016407136, 39.74669095008604, 40.091549658006244, 39.61868832188268, 40.0993904759807, 39.285522199446156, 39.41754525707614, 39.19884958574849, 43.936939393320394, 43.70514300561721, 45.76313218762798, 48.3136926158782, 51.433385033761304, 53.03266871360041, 56.18565420950613, 54.65675354003907, 55.27313440076767, 56.19413045144851, 56.244305410692775, 56.993356520129794, 54.268305532393924, 55.86945626043505, 53.69096794436055, 53.65065774609966, 57.494839391400745, 54.42563572237569, 59.25040991075578, 54.837127654783195, 55.914167358029275, 54.41671625260384, 55.53106946329917, 52.85823306729717, 51.37276088037799, 56.94766875236266, 56.21935521402667, 55.496485925489864, 59.04779203476445, 55.48014140898182, 47.41599544402092, 41.85127788974393, 42.735890034706365, 41.31637250223468, 43.69592543571226, 43.21130875618228, 42.94546227301321, 42.50287771224976, 41.304715218082556, 42.56509042555287, 43.30641446575042, 41.28905319398449, 41.26136910530829, 41.62208595583516, 42.94589765610234, 42.60095657840852, 42.050114600889145, 43.045051251688314, 42.326202392578125, 43.52261943201865, 44.22812831017279, 43.08049771093553, 44.911456185002486, 43.992491922070904, 43.805579216249534, 45.067652810004454, 45.354236864274554, 45.8464394077178, 46.99132042546427, 49.22407473287275, 52.36072747938095, 54.235538051974395, 50.29471705036779, 49.20608282089234, 45.52286348035259, 49.959193583457704, 60.381648925042924, 65.32958945920392, 62.98569087059268, 64.50769993566698, 59.01128261320053, 59.95310644949637, 61.82199424312961, 64.96841761373705, 67.8276881863994, 67.5812299789921, 23.637742188669023, 1.2918350677336417, 0.90500975688619, 0.16964292364014735, 0.5728964231187298, 42.76182082391555, 72.7708238170993, 61.16249476709674, 58.99297298923616, 28.351534874208514, 33.947635312234205, 62.268556087247795, 75.69089504980272, 58.85098711136849, 6.943714061091024, 0.14034861007765417, 0.178228041998321, 0.1969983146315621, 0.22485500291710903, 0.1378029765140626, 0.15597306522390536, 0.11808915168888147, 0.08434725339494406, 0.14550121020405524, 0.08077650225811428, 0.17662771496801608], [0.048649743304497776, 0.049719964304277976, 0.016416442588031772, 0.09199635020547337, 0.07321085540517684, 0.02241114379778024, 0.06092740162726372, 0.04328582548506318, 0.04767757389814623, 0.0281158730673093, 0.050267475852442366, 0.034224499212277514, 3.870266877835797, 39.036067301227206, 52.2823977470398, 45.852354341937655, 32.15054846579029, 48.15225178195585, 56.85808181762696, 48.48961484047675, 34.84204946025726, 48.88190284852059, 10.312918251560582, 0.18886593891487968, 0.036137788481409513, 1.764703513153138, 3.282909595197247, 7.263410764355814, 21.253466721503965, 50.254297025742076, 60.22062778472901, 53.74715981944915, 50.8411895075152, 52.42599571904829, 49.57315391109836, 49.25442211089596, 42.773470263327326, 43.2072255688329, 41.94039414005895, 42.54616891184161, 44.64767679091423, 46.05365822392125, 44.85849634293587, 46.19611086383943, 43.66991227672946, 41.15388047310614, 38.66049643485777, 36.73999809449719, 37.09322714036511, 36.76852157039028, 36.03309285256171, 37.0669747168018, 37.93421468427105, 37.74878071200463, 38.290569859166304, 36.894037415904386, 37.36845201061618, 36.88228599486813, 35.78142573756557, 33.856671625568026, 35.66386838113108, 36.7491921301811, 37.60025232068954, 36.85787316291563, 37.80073642730713, 37.14781476605324, 35.6613149181489, 36.75738988384124, 37.888397478288226, 37.704932535848315, 38.56703419839182, 35.51343371791225, 36.943153335202126, 37.580150173556426, 36.96107464451944, 37.49469349461217, 38.468190470049464, 43.981324934190326, 44.4172885341029, 48.17888467542587, 51.512969924557595, 52.39247906592585, 51.17967436390539, 53.16505262928625, 52.68349539849066, 54.46590669693486, 52.07074273017145, 51.94509744644166, 49.3165446096851, 45.61040293785834, 52.8152282007279, 50.896541995386926, 52.26304477260959, 51.91692698386408, 52.9707109543585, 51.08385086059571, 51.40152754322175, 47.86644435697987, 48.98695568884573, 46.78642365240282, 47.2463607788086, 47.37375543963525, 53.070700014791186, 50.425857574709006, 46.89936830151466, 38.40012950281943, 38.126191169984885, 37.51417590725807, 39.964900247512325, 38.632800579071045, 37.95410110104469, 37.179644800001576, 37.19225914247575, 38.63740151928317, 38.498765345542665, 40.12983983562839, 37.86562419706775, 38.16319088782034, 38.58368858214348, 37.2301374712298, 38.36917807978969, 38.69890036121492, 38.35631270562449, 39.26208603766657, 39.54196676131218, 42.37268247912007, 40.920679876881266, 39.68894581640921, 39.85363437283424, 40.34012202293643, 39.4499832584012, 41.67997621720837, 39.77348466073313, 40.06992170887609, 40.83318356544741, 40.13018892657372, 39.81807416485202, 42.7257546301811, 42.406214821723204, 44.287520839322, 55.18664221609793, 61.566130192049094, 58.471650769633634, 57.564673269948656, 53.875264429276996, 54.785407281691036, 56.30082676487585, 61.186264330340975, 61.79034463820919, 65.68210463370046, 20.595171413113995, 0.3027542398100899, 0.3836933595518912, 0.07305112607296436, 0.18399158192257728, 29.52212310606434, 63.39679841072329, 43.301864516350534, 42.38101751573625, 40.255049736269065, 34.594296870693086, 43.562506014300936, 56.365859662332845, 37.25255773913476, 3.4925563585373665, 0.06355230613882024, 0.03483980571130111, 0.029539567035352512, 0.03418866544961929, 0.013538783645227313, 0.20859253442575856, 0.06718855396273636, 0.02990912210436598, 0.09138616883466322, 0.03343986429935021, 0.00826654548291117, 0.10246205353929151, 0.04106671008611879, 0.038231981752981106, 0.04591881222422085, 0.01801514551193724, 0.06899801533549063, 0.015555764830130485, 0.04010087239646143, 0.03128651180304587, 0.0429232667140182, 0.023534717075827143, 0.04951171862382082, 5.276642999341411, 48.634260085321245, 56.96430352426345, 52.86946673547068, 35.945121934337, 31.254473193999264, 46.37594369149978, 48.346012946098085, 39.813967443281605, 55.41398671365554, 10.992356115771878, 0.14959195118036964, 0.10855820585763264, 3.77502731738552, 7.31834061684147, 7.3386079938180995, 18.718285906699396, 53.03580268736809, 62.07484199154762, 55.67158445235222, 53.83281261690202, 54.514065557910556, 52.72327607677829, 51.830576004520545, 44.50981332409767, 44.87975558926983, 44.66554318704913, 45.58748845131167, 46.758492454405754, 46.918281970485566, 46.832935117906146, 49.10194781518752, 45.98434994297643, 43.4308006686549, 40.55485610039004, 38.49676101438461, 39.19461342596239, 38.30354113732615, 37.876312655787316, 38.155287311923125, 40.008081620739354, 39.56777987941619, 40.29001766635526, 40.24074485225063, 39.77923485540575, 38.96704927567513, 37.98389150250343, 37.094321481643185, 38.668651042446015, 38.543013603456565, 39.28000734698388, 38.58899947135679, 39.66219132946384, 39.46791633482903, 36.43468472265428, 38.54744588175128, 39.01441581787602, 38.632455410495886, 38.39470486487112, 38.06633972352551, 39.942507436198575, 39.17564876617924, 39.08171976766279, 38.56293532156175, 39.766185129842455, 44.841500712979226, 46.776064672777736, 49.74276896445982, 51.13977601451259, 52.93178535276844, 53.17092049506403, 55.5200279912641, 53.335181513140284, 54.86520005810646, 52.354345783110595, 54.83471931949739, 52.15354396450905, 45.29443248625725, 52.53196639399375, 51.6715278164033, 53.63700005315966, 53.35478551926152, 54.54569162860994, 52.902187147448146, 51.660105874461514, 51.34120148997153, 49.18599636323991, 47.866758146593654, 48.58464602501162, 49.99884874589982, 54.15731422362789, 52.735121634698686, 47.96321707387125, 40.50471252010715, 39.75007203317458, 40.03317302273166, 39.98990535736084, 39.42817488024312, 40.73088030661307, 38.987688787521854, 38.694573986914854, 41.59304472707933, 38.74658461539976, 41.30242847627209, 40.67994832992554, 40.39496068031558, 39.928241775881865, 39.756861655942856, 41.243408572289255, 39.395721189437374, 40.07733498850177, 41.45713852297875, 41.02892552652667, 44.2536590176244, 43.62748399857552, 41.26519733859647, 41.413717885171216, 41.691947290974284, 42.26440545051329, 42.87337695398639, 41.49569542177262, 42.91016878620271, 42.62823666295698, 43.35981361327633, 42.164749791545255, 44.786932699141964, 45.33238534004458, 48.05433765534432, 57.62739981374433, 62.355130641691154, 60.829756183008996, 60.10027377836166, 55.35458633976599, 58.125638884882775, 58.556436723278416, 64.39623794248028, 62.90599615343156, 67.076169906124, 22.10280695269185, 0.4715839917621305, 0.5993316046172573, 0.08660810143356362, 0.06496990204698617, 33.67439123892015, 68.11016944146925, 52.303649148633404, 47.55425899259506, 42.878334829884196, 38.59218051356655, 51.68762522359049, 67.2553986887778, 44.40545474329303, 5.223528223652994, 0.06888209091078851, 0.05661287487694814, 0.011667039324229043, 0.05837625223061731, 0.02630249123960253, 0.04574866026579853, 0.03295535199163902, 0.050297246029179905, 0.00839673925281292, 0.06341580842291156, 0.04526439693666274, 0.18579979457201498, 0.1362270876885422, 0.08226882621285417, 0.22425917037312063, 0.12165218065943449, 0.2347421336678728, 0.1061939512709937, 0.08917471814540126, 0.12977080509787606, 0.16399035921260235, 0.13753254747679158, 0.16663468022259975, 6.921921372413636, 60.071350220711004, 63.135752908645145, 61.056229914388354, 41.4123175990197, 62.596113220337905, 66.14834108660298, 58.091675081560695, 45.866314057380926, 62.43226797349992, 13.964138896234575, 0.2951371195095201, 0.3881793865753759, 7.275150908577827, 10.606961673305882, 12.393595403240575, 24.64287700191621, 55.590603197774584, 64.84669862254974, 57.60408524544009, 55.07477621878348, 58.27515179111112, 55.93811342793127, 54.21715782534692, 46.27543295583418, 46.217566228681996, 46.64606163578649, 48.94657881029191, 47.962299239250925, 51.02164991440312, 48.69635904988935, 51.33531401234289, 48.137891984754994, 44.556854309574256, 42.30358600616455, 40.02285718917847, 40.39538821866436, 39.435725442824825, 40.50761899640484, 42.32223687633392, 42.69639568944132, 40.87239157768988, 43.63524244677636, 40.93184686476185, 42.34916786993704, 43.03208389589864, 40.79780378649312, 39.63045151002946, 41.01693091853973, 40.8581925976661, 43.32881119943435, 39.84318910106536, 41.2211295097105, 41.34744551873977, 38.820258494346376, 40.2725709638288, 40.72169803803967, 39.956753484664425, 42.78512754747945, 39.11511482730989, 41.277266471616684, 41.071557767929576, 40.99662088578747, 41.0264269767269, 41.50005709740424, 47.20052396097491, 49.50989784732942, 51.038186627049605, 54.25469490789599, 55.50871195331697, 54.97343786301152, 58.50488893447384, 57.15929239026962, 58.1108162480016, 55.070912684163744, 55.76769821105465, 54.08389529874248, 47.527308387141076, 53.72833636499221, 54.03905868530274, 54.704292666527536, 56.23218920923049, 58.87678453999182, 54.46457309107627, 53.1489787563201, 51.785292240881155, 50.6047058874561, 48.56923111023442, 49.3713205091415, 50.86490023520685, 57.44532339034542, 55.15298043527911, 51.27629018598988, 42.7882222975454, 41.916883453246086, 41.55781792056176, 42.73642739941997, 42.40446152225618, 41.67436330549179, 42.44537968789378, 41.09746502291772, 42.93288323187059, 41.44878387451172, 44.08816245294387, 43.027557480719786, 42.00924350369362, 41.68530279590238, 41.51684484174175, 44.09861556945309, 41.52362269739951, 41.90570862062516, 43.963336944580085, 42.935260188195016, 47.0435820856402, 45.72746607565111, 43.26740649438674, 43.907003864165276, 44.91827718673214, 43.70502141214187, 45.48305534547376, 44.51402202729256, 44.36347361533873, 45.39378220035184, 45.54989253321002, 43.20429948068435, 47.61021552547332, 46.33051872253419, 50.202780615898874, 59.27231634816816, 65.66323803317162, 63.04171800613404, 62.22328016834875, 58.2589602470398, 61.0118482958886, 61.33569878916587, 66.8287467956543, 67.74852691158172, 70.11352785172002, 23.912127671703217, 1.7790927281302793, 2.091971861739313, 0.3112433213860758, 0.4390892386436463, 37.59388631389987, 75.62626223410331, 55.2193469385947, 56.708588523249475, 53.51639109273111, 46.084848911531516, 58.59791186548049, 73.65072127311461, 56.27044800789126, 8.831753807683146, 0.23197300161325166, 0.11089285114599813, 0.1340867912456874, 0.08350323900700578, 0.13528075459743702, 0.3724994666634068, 0.18680617363462526, 0.16744848010280441, 0.13868143421507653, 0.2147835054464879, 0.11904784943908454], [0.022668842368969516, 0.06576694758428682, 0.023652252200390064, 0.012998875519711406, 0.02308531649290554, 0.01847685712780203, 0.12731119554730194, 0.04868574943693896, 0.07158383021071073, 0.04256968266300617, 0.03706549797507544, 0.1039746558413871, 3.3388362200029436, 43.97997956122122, 53.821802523828325, 41.834235191345215, 21.696357227140858, 40.44306855047903, 74.30927938030612, 60.421864986419685, 36.52252228029313, 54.10440537237353, 13.83874366360326, 0.1722854826479189, 0.31479600816965103, 4.9434979596445645, 5.49640114268949, 7.031984060041367, 24.581839038479714, 59.312799130716634, 54.80096340179444, 53.74689309827743, 51.09246830786429, 47.23435048134097, 47.61333773213048, 47.1622141715019, 45.081000635700846, 41.00050403225807, 38.144253684628396, 37.32331337467317, 37.415653813269834, 36.69460842686315, 37.79739456792032, 37.00611522120815, 37.473344033764256, 37.629642640390706, 38.38496169736309, 36.853013346272135, 36.61540400597357, 35.04309838817966, 36.77941791472897, 40.78817436772008, 42.92825875743743, 40.98583829018378, 36.90057600698164, 37.923824325684585, 37.68347717100574, 36.95557155916768, 35.843320738884714, 34.063372688908736, 34.353655538251324, 35.34922369064824, 38.583649358441754, 37.50564475213328, 35.96975049664898, 35.974406350043516, 38.11639701166461, 38.77511201366302, 37.73309515368554, 36.792130316457445, 37.72454046433972, 36.410879858078495, 36.962267045051824, 37.25727242808188, 36.25294954546037, 38.18057875479422, 40.580524090797674, 44.997567899765514, 46.95252033971971, 49.898220339129054, 50.540924226084066, 50.80863383508498, 50.28882957273915, 52.27897744024954, 52.79046627783006, 53.46143084187662, 51.22048662554834, 52.899500323880105, 46.114219619381814, 40.81869825240105, 46.37657127072735, 44.15705104028025, 49.422656489956765, 51.265868448442035, 52.12860553495346, 46.377826429182484, 48.36772326500186, 48.223227070223906, 47.27303681835052, 50.310029983520515, 49.00928574223673, 47.70516826260475, 49.91683983033704, 51.545988436668154, 47.79570441092215, 38.99580809377855, 37.64628917940202, 36.91208031869704, 38.722971946962424, 37.04072229323849, 37.3447883513666, 38.033827197167184, 37.58338220657841, 38.77133869355725, 38.16007652590352, 39.45028135853429, 38.20839228168611, 36.06438159942627, 37.55234841377505, 39.35352825349377, 39.30180003566127, 41.00345365462765, 40.16329373082807, 38.9799185722105, 38.58894455817438, 38.21711563294934, 39.96758314871019, 40.749084026582786, 41.78284037497736, 39.154342451403224, 41.526301676227206, 41.66292959643949, 43.39995907198998, 42.249986817759854, 40.072761504880845, 42.48909842583441, 41.95447152660739, 42.29421938619306, 40.84629604893346, 42.84983881058232, 46.475595428097634, 54.14003618301884, 54.095121122175655, 53.581690711359826, 50.0522949618678, 50.77146937770229, 57.231413010627996, 61.4689064025879, 61.794314076823575, 67.00132323849586, 25.795373301352225, 0.3303373580978763, 0.8749067915543434, 0.027664465334026084, 0.1926355511550942, 25.732591844374134, 65.71165184820852, 39.3673820649424, 50.20627937009258, 26.536616932961252, 20.38575214724387, 46.37032293504285, 55.42130977876725, 47.39611687198762, 5.888524901482367, 0.07428078912198544, 0.025453999067746827, 0.09864031667670897, 0.044937273562555356, 0.02992036827509442, 0.025085510776167916, 0.05333597208523462, 0.03159064296332579, 0.012706211738048062, 0.020075487273354686, 0.04725202354752729, 0.03234816985505243, 0.05008397864237909, 0.05098157321974155, 0.024203381598776868, 0.010400324432750144, 0.06342484442997845, 0.08190189307976155, 0.017785204221464453, 0.06759252744696795, 0.014234938275729938, 0.059672204867726376, 0.1122008313635184, 4.728813892410648, 51.4451168429467, 59.63711246367424, 48.911038214160556, 28.255895722296934, 55.13781262982277, 78.38762652489447, 66.72815369021508, 40.70285104936169, 59.01976277751308, 15.360153586633745, 0.12136567909751209, 0.08664702636099632, 1.9120496775834792, 5.788491714385248, 4.82986101219731, 26.424205726192845, 59.1492872853433, 57.487335897261104, 55.74954548189717, 53.2172985999815, 49.856023480815274, 49.418357572247906, 48.70913028717042, 47.121829448207734, 43.01081288245417, 40.82573890686035, 39.14117505473476, 39.53225497276553, 40.0377857300543, 39.71342532865463, 39.876556704121256, 40.441303483901486, 40.61515469704905, 39.9237310501837, 38.86084325851933, 39.74203901906168, 36.233875059312396, 39.399659249090384, 43.00448217699605, 43.63646622627012, 42.7789576591984, 39.48904222057712, 39.33741123445573, 39.85042979640346, 39.612134041324744, 37.90467139213316, 36.44583994342435, 37.28253641436177, 37.4704336350964, 41.19755998734505, 38.74014016120665, 39.593200760502974, 36.32752556954661, 38.855363707388605, 40.366174405620946, 39.020793591776204, 38.95310524971255, 38.98950092254147, 37.772644412133005, 39.11707993476622, 37.89650109506423, 38.49403104474468, 42.30701808006533, 42.39527140894244, 46.54789255511376, 48.81789761204874, 50.75657221578783, 52.28742622560071, 51.60388262041154, 52.316122285781375, 53.86842773806665, 54.673380467199514, 53.54785634625343, 53.22510803899458, 52.888176441192634, 47.04737109522666, 42.281467760762865, 44.505102557520715, 45.76040614035822, 49.11315402676983, 51.221302478544175, 53.64878677552747, 49.948156033792806, 50.564834994654504, 50.74003550314134, 48.764871089689194, 51.64409083704795, 51.68940205727854, 49.057264174184496, 50.54962012075609, 53.71089750720609, 49.9049864276763, 42.66036479703842, 40.084206981043664, 37.08362910055345, 39.750479959672504, 39.440730387164706, 39.37313225961501, 39.87740393607847, 38.563107905849336, 38.72681194736112, 39.657253065416896, 41.19948587109966, 40.177194610718765, 38.49171292397284, 40.25976834758636, 40.513345656856416, 41.69086079443655, 42.24766085224767, 40.7911475243107, 39.92500974285988, 40.995149996972856, 42.0055329415106, 43.11938408882388, 42.14621267011089, 41.684353582320675, 41.293148148444395, 41.88552802608859, 42.834333681291156, 44.375527058878255, 43.010565773133315, 42.531973854188, 44.76200211432673, 45.07354421000327, 43.174995453126975, 42.3140783463755, 43.453844593417266, 49.70525541613179, 57.32425551260672, 56.67973556826192, 55.06921429787913, 52.45668434327649, 53.54706010510845, 58.19269180297852, 64.50131823939662, 65.45287347608998, 68.84103252041724, 26.322694786133308, 0.6290621899308697, 0.6287379202342803, 0.053686231314655275, 0.25689578765342314, 28.972073447319772, 72.56592704403785, 45.59955758433188, 50.19836794945502, 37.27731573966242, 27.34566853892419, 53.025063237836285, 61.63510507152927, 53.73154878616334, 8.286840492679227, 0.07158650385756647, 0.09320981815577516, 0.05653913891423614, 0.05711886829005615, 0.037668075923237114, 0.05851792104001488, 0.06011433336102675, 0.04615469452654643, 0.03658697647493213, 0.05358372491994693, 0.026816783300150308, 0.10402720181211349, 0.14344322224778516, 0.09024197821535411, 0.21930032920452858, 0.0919700810505498, 0.19604951473734072, 0.2925472520291805, 0.10183950750938348, 0.16553598756511367, 0.14733563838226182, 0.22714715330831467, 0.194699683136517, 6.31166382182029, 60.95910418418146, 67.24783635908558, 57.164579745261904, 33.82528874181932, 51.60315698192966, 77.53732727419946, 67.95889146866338, 46.81923035652407, 64.61683204097133, 17.010697741662305, 0.3872909697313463, 0.45992060955013003, 9.374634354345261, 12.20221511779293, 10.480578983983687, 29.407815433317616, 63.11061443821077, 59.142662402122255, 57.320537105683364, 55.175173205714074, 50.773277590351725, 51.99645303910779, 51.92206528878982, 49.54967068087671, 45.339492674796816, 41.69344955875028, 40.75619528370519, 42.489204329829064, 41.492129987285985, 41.47469112949987, 41.21450462648946, 41.513126434818396, 42.186283603791274, 41.87028961796915, 40.94922296462521, 42.177972101396136, 39.315081181064734, 41.096986493756695, 44.75980166466006, 47.591152806435865, 45.63149352227488, 41.349877388246604, 42.70026314643122, 42.05188358983686, 41.19756390971523, 39.83210840532857, 38.86170225758707, 38.82631071152226, 39.802482743417066, 42.94117512241487, 41.55586850258612, 40.98981557353851, 39.859557151794434, 41.065415336239724, 41.59356247994208, 41.16980921837592, 39.99548689011605, 43.11107258642874, 40.86752783867621, 40.2357046065792, 40.36064386367798, 40.60237169265747, 44.85058099992814, 45.314464030727265, 49.654507790842366, 50.53296965937461, 51.48467002376434, 52.978779269802956, 54.10016529021725, 54.40737708922356, 55.33133845175467, 58.601508678928504, 56.5315091994501, 54.18033853653939, 55.59500017473775, 48.17219703428207, 43.181432062579745, 44.89522149485927, 47.17157686910322, 50.30086340442781, 54.069810067453695, 55.16157827069683, 50.54226959905317, 52.49593550159086, 52.64728799943001, 52.05796364815005, 54.70671276892386, 53.348125334708925, 51.63866227672946, 52.99712027272871, 57.34957441206902, 52.29705564437374, 45.09414842051845, 42.43394597884148, 39.41669018037858, 40.655668858558904, 41.82761030812418, 41.48323797410534, 41.88664197921753, 39.883279646596606, 41.1604465207746, 41.28062794285436, 42.76914781139743, 43.665644737981985, 41.61483349338655, 41.782530507733746, 43.313164864816976, 43.28202516801896, 44.62569975083874, 43.804418194678526, 42.07934802578342, 43.37252993737498, 43.94600791315879, 44.26340218513243, 44.80039819594353, 44.30097849138322, 44.010017072000814, 45.04810371706563, 46.24585043999457, 47.898403829143895, 46.08815939195695, 44.40883974875174, 48.08587743389992, 46.78195999514672, 46.68304566414126, 45.5244912639741, 45.39559433537145, 51.32778306161204, 60.80542964320029, 60.87631863932456, 58.09359312057496, 55.8431096999876, 55.5908424623551, 60.68680540207894, 67.56004133532124, 67.29847415801018, 73.89101351461103, 28.152352994488133, 2.3363769535095464, 2.6137566758740336, 0.2265902993179137, 0.3587207931184, 32.83169550280417, 78.51723732486849, 54.054422609267704, 61.616513036912494, 37.033775775663315, 34.83778192150977, 61.56875818006454, 71.60736253184658, 64.46059226989746, 12.304006507319789, 0.17329687192555399, 0.21367281585210757, 0.14929495421388458, 0.18212012105411102, 0.10560406356929772, 0.19598635844886306, 0.1475810623096843, 0.13337793008935067, 0.11903305628126669, 0.16095188596556265, 0.21786225959658626], [0.019933399030818574, 0.04158869941508578, 0.03563569062539647, 0.02139295932025679, 0.09850483402729997, 0.07713278890737603, 0.035585366309650486, 0.01033084121562781, 0.03091116510932484, 0.04739555778102048, 0.018636121061600504, 0.10866967165061545, 3.6986384228352582, 45.57612534492247, 52.11121374560941, 43.47528426877914, 21.31774260151771, 23.284156207115423, 34.40552496141003, 27.419919006286133, 39.782125642222745, 59.565297788189305, 15.362051033204603, 0.00994167238053295, 0.11359979218292622, 1.5651371185818028, 8.608733723240515, 5.777968485509196, 38.61984499039189, 57.596926919875614, 55.242026082931034, 52.60726021182153, 53.01047202079527, 53.43479402603642, 52.15726629380257, 52.54119573100921, 50.67641465894638, 48.58951760876564, 46.4789019861529, 44.78554810247114, 40.260968592859086, 38.083707978648526, 37.40034088011711, 36.320237805766446, 37.212125947398526, 36.190827046671224, 36.355413621471776, 36.58654320624567, 35.599463062901656, 36.2469365519862, 38.312637113755756, 44.30873693958406, 45.00197664383919, 44.13097120100453, 45.360300848560954, 41.23541478187808, 38.27779862188524, 37.10322918430452, 38.829907524970274, 37.292867937395656, 36.20195481085008, 35.96101537827523, 37.86650673035653, 38.29493937953826, 38.621260966024096, 37.48727237024615, 37.13716945340557, 36.14617478462958, 38.5880071117032, 37.54348777955578, 36.28801553480087, 37.1236765000128, 35.92582387308921, 36.05592496933476, 40.33173991787819, 39.77395534515381, 43.31372968612179, 48.25757526582288, 48.611278918481645, 48.48253103994554, 48.806263862117646, 48.73262528450259, 50.796274446672015, 51.715175951680834, 49.861636392531864, 52.25822417966781, 53.32804672179684, 51.31284275362569, 41.2498491041122, 41.800538109194854, 46.898654430143296, 46.94551890896213, 51.81676926151399, 50.53337758587253, 55.36902850674045, 51.45546797783145, 50.977911564611624, 51.21839600224649, 51.28761014630718, 52.13712492296773, 51.984168175728094, 49.95870720955634, 50.80129508049258, 48.6367743246017, 45.855758959247225, 39.856360420104, 35.974229843385764, 38.17310663961595, 38.63220437880486, 36.756550496624364, 38.363019958619155, 37.25196546123874, 38.16263783362604, 38.06970903950353, 36.804575997014204, 38.24884368527321, 37.29657065483832, 36.011151113817775, 37.46504822084981, 38.07824019462832, 37.196526681223226, 37.746701855813306, 40.16529021724578, 39.56066077755344, 40.629349754702666, 40.775862047749186, 38.04628464483446, 37.61214102468183, 39.32998226534936, 42.62625194364979, 39.750676078181115, 40.093652048418605, 42.55984621663248, 44.42505482704409, 42.7626209874307, 42.17983914959816, 40.32988463678668, 40.45449833716116, 41.921449092126664, 41.316113625803304, 42.45013360054263, 41.82060103262625, 44.96943666088966, 47.52978340271981, 47.29562967054306, 50.31139496834048, 56.123943559585086, 59.763079381758175, 60.58044249011625, 64.86464346608808, 33.764358643562566, 1.4282476253086522, 0.40210058311781577, 0.07811116745635387, 0.04897526172440379, 26.507875765523604, 62.958579447961625, 50.64683214310677, 48.38535431892642, 26.69497282274308, 30.137948951413556, 49.78994723289244, 54.668332376787745, 42.346057430390395, 5.4301586843306024, 0.11110693441643832, 0.010127344322691282, 0.021413865859710404, 0.046391687656362215, 0.03886706098133037, 0.02646405535239366, 0.03836865949955198, 0.02965744306904174, 0.068661970867505, 0.026997733267865358, 0.03409063683882837, 0.0435347619256185, 0.03229066729545593, 0.0692199356853962, 0.057944695750672015, 0.08430864256356033, 0.03954764200194229, 0.0612520007416606, 0.07131463457499781, 0.008434954591305747, 0.029659697282758933, 0.026149444109309587, 0.08844298160364551, 4.390160864399326, 51.637744442109145, 60.909215557959776, 50.04511310208229, 26.814520782040013, 29.265515765836163, 54.059219667988444, 45.17978160612045, 42.227613618296964, 65.11498481996598, 17.88942240899609, 0.19745733919403247, 0.09270891922736361, 3.315511600625131, 5.523144843116884, 6.37196388936812, 39.25316656789472, 59.97690346933181, 56.977823934247425, 53.303445616076075, 54.580459517817346, 53.2646769092929, 54.74751718582646, 54.686571398089015, 53.2659948256708, 50.837122009646514, 48.60801158412811, 46.42260420706965, 42.11615554748043, 40.56976110704484, 40.240023136138916, 38.50405270053495, 37.75243636100523, 38.39730931866554, 38.440431856339984, 38.759697098885816, 37.3063922697498, 36.981874973543235, 38.78862065653647, 47.502420948397734, 48.72542773523639, 47.69645275608186, 46.19451838154947, 44.328140904826505, 39.85362260572372, 37.64628133466167, 42.214720787540564, 38.697762873864946, 38.38653456780219, 38.580636978149414, 40.21428846543835, 39.838195923836004, 40.56916098440848, 38.66488164471042, 39.186682393473966, 39.080731330379365, 39.60290078193911, 38.359066209485455, 38.07905212525399, 38.579205313036525, 37.58784194146433, 38.5937455392653, 40.88735934226744, 39.74043084729103, 43.64240469471101, 48.212283657443145, 50.516374111175544, 49.676669182315955, 52.391969157803445, 49.15726107935752, 53.107209436355106, 53.30810539184078, 52.382037716527144, 53.37532304948377, 53.734353280836544, 52.52236835418209, 44.54213757668772, 43.356969894901404, 47.802894115448005, 46.38616146579866, 53.000921049425685, 52.697435502083074, 55.880274157370295, 52.34266104236726, 52.94542735622775, 52.26894009497858, 52.94755328086115, 55.27241660702614, 54.552006644587365, 52.25824379151868, 52.67776481566891, 49.68341958138251, 47.42886474055629, 42.041932536709695, 38.538718608117875, 40.278030903108665, 39.47535707104591, 38.319822895911436, 39.74706357525241, 40.55379313807334, 39.85949439387168, 39.066932432113155, 39.67721400722381, 41.47464798342797, 39.07269439389629, 37.85006415459418, 39.421977535370864, 40.20104654373662, 39.87147331237793, 41.112464166456654, 40.00535557346959, 41.135174689754365, 42.67844300116263, 43.793937621578095, 39.94471965297576, 39.031027055555775, 40.96121757261215, 43.25396845417638, 43.547393122027, 43.003509429193315, 44.732694164399184, 45.89622212994484, 44.54826824126705, 44.96645958192887, 41.362303456952496, 44.13923563495759, 43.852059302791474, 42.86385736157818, 44.19343494599865, 44.50557324194139, 48.18216377688993, 50.43205099721109, 48.83073552962273, 52.47576667416481, 57.421871539085146, 63.41122488821707, 63.71298851505403, 67.29359472951582, 37.093627222122684, 1.729248351147098, 0.6423150820116843, 0.15447605281106888, 0.05632866008747971, 28.51592533050045, 69.08487058454945, 51.985984233117875, 52.15712901084654, 27.568225783686486, 33.881672813046364, 56.75005974308137, 62.04726772923624, 52.3402762413025, 7.858747128517398, 0.06754893704407638, 0.03040224332512627, 0.05121364040420421, 0.03790433743908521, 0.0501571093956309, 0.04859210284907491, 0.0386717162215181, 0.015259158568486813, 0.013031724412294646, 0.06522618144029571, 0.051347154207647815, 0.12637394059809948, 0.1020121147796031, 0.1439988351757488, 0.08679859685681521, 0.16886224940178857, 0.2321840741581494, 0.09300077574387675, 0.1304152535815393, 0.08320039678965846, 0.20411504162175043, 0.160784894119828, 0.2172993994768589, 5.150382884087102, 63.478783792065045, 67.38396613828598, 58.144819275025405, 31.30315176902279, 34.33447907047887, 41.951329708099365, 37.86017602489841, 50.59854384391539, 70.98267801346319, 21.30671093540807, 0.34480931057083997, 0.3173083475520534, 6.497050235348364, 19.869919284697502, 9.109407605663423, 43.42146150527462, 60.26308744184433, 60.92546985995386, 56.408076132497484, 59.685812611733716, 56.815535868367846, 58.43115229760447, 56.83997223454138, 54.74001761405699, 52.73260347304806, 52.07566922710788, 48.857591998192575, 44.61869439771099, 43.443560138825454, 41.37511391793528, 39.67705711241692, 41.22361237002958, 39.829496106793805, 39.78163926832138, 40.921609478612105, 40.00151165070073, 39.95610237121582, 41.01352630123016, 48.827550565042806, 50.475279438880186, 50.36311926380281, 48.890092757440385, 47.702202950754476, 42.62073316881734, 40.53330659866333, 43.27366267481158, 41.40757545348137, 40.81181449274863, 40.214849364372995, 41.97862940449869, 41.79061843502907, 41.8800720091789, 41.7484058872346, 41.50400692416776, 39.74447873330886, 43.03068360974712, 40.25675596729402, 40.374960514806936, 40.75934494695356, 39.90684132422171, 38.82977024201424, 43.47441742497106, 43.885250399189616, 47.56795590923679, 51.36521816253663, 53.26945043379261, 52.67052804270099, 53.05851713303597, 52.15498347436228, 55.539682988197576, 55.86650271569529, 53.26857182287401, 56.137534572232155, 56.77874403615152, 52.82803473934051, 45.75169063383534, 45.457818815785075, 47.477498208322835, 47.98947341980473, 53.33697011393886, 53.7510351211794, 58.27421042226977, 54.94013694024856, 54.89379021429247, 55.135184641807314, 53.51616359526112, 57.21038910650439, 56.687850952148445, 53.66717092452511, 54.82241092189666, 52.021301254149414, 49.62634909537531, 45.9716179293971, 39.95282326975177, 42.524662556186804, 41.16162323182629, 38.8052358165864, 42.718243291301114, 42.16595788155833, 41.78176956792032, 41.128185026107296, 41.87832263208205, 43.61856845117385, 42.82669682656565, 40.41341150960615, 41.26130242501536, 42.34255083145634, 41.81835351451751, 42.298675198708814, 42.37402785208918, 44.36547794649678, 46.281959779800914, 46.427970009465376, 42.808147938020774, 41.266813355107466, 41.113099590424575, 46.61316863952145, 46.02201254137101, 44.468534300404215, 47.13067439294631, 49.59020053186725, 46.28769036262266, 47.46641359021587, 44.669940164012296, 46.167948246002204, 45.87331548813851, 45.791153600139005, 47.15923317017094, 44.66295050036523, 50.145353194205995, 53.29377697360132, 52.12546371644544, 55.619679727861964, 61.7514229589893, 66.42879839866393, 66.5078890708185, 70.49071865697061, 39.29671664391795, 2.7689513804451114, 1.3596758919377483, 0.3306532314708156, 0.17164360821968125, 32.118459555410574, 75.04506895619055, 63.03874484954342, 57.43919272576609, 37.30670998173375, 43.65077111028856, 64.19451044451806, 70.35355337204473, 62.05475553389519, 10.94351770416383, 0.12605422146378026, 0.12597242625610483, 0.1637837299776654, 0.08287421953413757, 0.1303867091454806, 0.0823781316378905, 0.11804712410535544, 0.1190909035804291, 0.09645659070942672, 0.18206214352000147, 0.1340565614161953], [0.044126243090196964, 0.05582229512172842, 0.0725530157045972, 0.008667888412732751, 0.012442603756132866, 0.039069051553885785, 0.10186570005551462, 0.026815540322493163, 0.03360227493929767, 0.05128752192362182, 0.044235690241499294, 0.02637168047048392, 3.163751666584323, 42.31690245289957, 50.31235594903269, 41.775560455937544, 28.458752862868774, 31.568151020234634, 22.313771632409868, 35.95999556203043, 42.41325155381234, 59.148938194397964, 17.287418996134114, 0.13466966158199695, 0.018722842214629054, 0.982962757829697, 1.3033766419656816, 12.924057725937137, 50.237344541857325, 55.130493487081225, 57.28675765375937, 53.26841885043729, 51.88661490717242, 52.126059916711625, 52.75402353655908, 52.8113450542573, 51.999120250824966, 51.993687768136304, 50.38957172824491, 47.42788022564304, 43.05167221253918, 39.85530138015747, 37.91028430384975, 38.83320623828519, 38.8569797238996, 37.176487292012865, 36.96297307168284, 34.654003189456084, 35.398167025658395, 36.50476963289323, 42.32483348538799, 44.24848933373728, 48.03078774482974, 48.43337589694608, 47.38094906653128, 48.11236519967356, 45.233918159238755, 41.205436106651064, 37.110218847951586, 37.65905649431291, 36.42521612105831, 36.873358680355935, 36.5898262300799, 35.93107984912011, 35.89067551397508, 36.42625947152415, 36.17012085453157, 35.98550665763117, 36.97586198006907, 36.8515581469382, 35.95297059705181, 36.33762567274032, 35.91153860092163, 35.68465302067418, 38.22206958647698, 42.37296881214265, 48.806369766112304, 51.109397257528, 53.23568667134931, 52.992593857549856, 52.21046932281987, 50.68580089076873, 51.32664949663224, 53.96266268145654, 51.99911632845479, 53.413664217918154, 53.08488330533428, 52.60088243792134, 48.95306641055692, 43.11094314821305, 49.39401142058834, 51.624855533722915, 54.0814281279041, 52.65149670262491, 51.37840517105595, 51.89561674671789, 47.28788691182291, 50.23140215104627, 49.340784857350016, 49.81457971757459, 48.49265075499012, 48.12758791831232, 48.81558341364707, 44.50026627509825, 41.81997737576885, 37.26099867974558, 37.76550569841939, 37.408542556147424, 38.386428663807536, 38.91740383640413, 37.936838749916326, 40.57670762462001, 38.962295363026286, 37.56484508514404, 37.19115695645733, 38.31424920789657, 35.96341194645051, 37.008456876201016, 36.61571779558736, 37.53281108794674, 37.70381858271938, 37.984848560825476, 40.48320224208217, 47.30651817014141, 50.51623682821951, 49.29529713046167, 48.19259728154829, 40.21037001763621, 37.06134219323435, 40.37091262878911, 42.527855365507065, 39.2801603194206, 43.823033763516335, 45.97189641767933, 45.91100162075412, 43.99339406721054, 41.778345338759884, 40.66494526401643, 45.41115045547486, 52.271199380197835, 50.48395964407152, 48.104512614588586, 48.249812895251864, 45.59774544931228, 43.547801048524924, 47.632121962885705, 53.77135692104217, 61.08221953915012, 62.748065840813425, 64.97442668484103, 32.60222900298334, 1.1950515643242867, 0.4842558827611708, 0.10187003611316604, 0.0667920268531288, 22.891921151068903, 62.76923879500359, 50.06203028463548, 39.837658559122396, 30.745604499693844, 33.85412992969636, 44.67744758052211, 52.951522719475534, 35.35455419171241, 4.7581301773748095, 0.022532246976850495, 0.06258518525188969, 0.026912927334647507, 0.04377742793651358, 0.013295832266580435, 0.02717389518605365, 0.06874310723956555, 0.03754224981211367, 0.013791081296550411, 0.02403731097377116, 0.04993341555218062, 0.022632209959650235, 0.0373335023440661, 0.04233778401788685, 0.028302323546320684, 0.01605344235882043, 0.08012281475408424, 0.033443671756333886, 0.0310693871635463, 0.05418977707684521, 0.024061559571794445, 0.04864656787005164, 0.06835171291905065, 3.5687758557258116, 48.107474004068685, 58.345515189632295, 51.183396693198915, 31.652276054505382, 29.762017226988274, 27.653686385000906, 38.33457885249969, 46.749878929507354, 65.33248809076125, 18.470658832980742, 0.1321193242385503, 0.022627000561765125, 1.5125310252751074, 1.9932602682421285, 12.86405428763359, 52.65639182059996, 56.292711380989324, 58.52091181662775, 55.241578932731386, 56.412531945013235, 52.721836566925056, 55.50736658034786, 54.800975168904955, 55.016195620259936, 52.74246038929109, 53.62088695649178, 48.56702281582741, 45.276597469083725, 41.18713432742704, 39.736700673257154, 40.56384617282499, 40.59171461289929, 39.09555396726055, 38.487143362722094, 35.7582131508858, 36.2528593309464, 37.44243575680641, 43.007894639045965, 44.98981729630501, 49.904833455239576, 51.51231881110899, 48.31264142067202, 50.476495373633604, 47.63369875569498, 42.31476868352583, 39.653189489918375, 39.15933170626241, 39.20409379466888, 38.672608713949884, 37.929139137268066, 36.75338514389531, 38.830284072506814, 38.41653285488006, 37.99746682566982, 39.098680096287886, 38.836124481693396, 37.84127020066784, 38.231506809111565, 38.083656987836285, 37.24063373381092, 38.2522875262845, 39.357921308086766, 44.27496533240042, 51.51657458274595, 52.33519677192935, 55.32281121900005, 56.303584191106985, 52.58582445882982, 52.14737799859817, 52.81743649513491, 54.58460546308949, 55.63100361054944, 55.77961437163815, 54.70608126732611, 54.62143259663736, 50.31842385568927, 44.8208337445413, 48.62407368998374, 52.74689658995598, 54.78339118342246, 53.73494948110273, 53.861806777215776, 53.09391652384112, 50.59490388439548, 52.14245542403191, 53.06801711359332, 51.72079278576759, 52.87965313080819, 48.930418645181966, 50.64714985509073, 47.245035017690356, 43.64551513425766, 39.81129630919426, 40.376478472063624, 39.77308065660539, 41.13732807097897, 40.86910070911531, 40.217238087807935, 40.7512217183267, 40.12212061112927, 38.54731644353559, 39.671377520407404, 38.98332711189024, 38.45236762877434, 40.231374309908965, 38.19335783681562, 39.68768281321372, 39.04751277739002, 39.60538756462836, 42.171559026164395, 47.82428279999764, 52.07517500846617, 50.19999181070636, 50.06033582072104, 42.068604653881444, 39.68676890096357, 43.470102817781516, 44.54565594273229, 41.4990843496015, 46.043667947092366, 47.9163839740138, 48.62958069770567, 46.5859866142273, 43.57257866090344, 42.59293533140614, 46.18635985159105, 53.28251192646643, 53.02070548457485, 50.94693660736085, 49.134052415047925, 46.92804474984446, 45.803026614650605, 50.218713283538825, 57.096722741280836, 62.52113711449408, 66.19945741468861, 67.33219085201141, 34.33722472959949, 1.4355413952181417, 0.6525375141251473, 0.11367724367207098, 0.035661415857893806, 25.665274166291763, 69.14053686203496, 54.62270736694337, 44.045742019530266, 34.90636848634289, 40.36585669363699, 51.166444209314164, 61.61743479390299, 44.10187898143646, 6.813441851446706, 0.033208992212049426, 0.05491610503785553, 0.030746230209666877, 0.045141052950413964, 0.05744834355409107, 0.02262479805898282, 0.028108346253453244, 0.041490632499898636, 0.09755087070046894, 0.03748208126654068, 0.07859891265510552, 0.17090087065533285, 0.14688566897905644, 0.18614922259603778, 0.12002759928544683, 0.150747319022494, 0.20852378569543364, 0.23774349761586036, 0.181632996386578, 0.15057966834114445, 0.07798211994550883, 0.13949854359511407, 0.16879091129427956, 4.084227512921057, 55.34347034269764, 64.83716334066084, 56.34092123277726, 40.65497852140858, 43.101247049147084, 31.061047392506755, 49.05720533863191, 54.42931490559732, 70.80218622761389, 20.760791532454952, 0.25289728366319214, 0.09399157257810717, 3.2958053677312793, 6.51432631477233, 15.231169385294761, 54.98686413611136, 59.16563572422151, 62.028628626177394, 57.63277738325058, 58.675386521124075, 56.70638022884246, 59.15656328201295, 56.97570977672454, 56.87862719258955, 56.06000500340616, 54.94104300775836, 52.4427834633858, 47.7261725548775, 45.122260047543435, 42.27142649312174, 43.31556143299226, 43.61616403825822, 39.92265632075649, 39.824432326901345, 37.132811700144124, 38.7532526446927, 39.544120142536784, 46.38724796233639, 46.78160305946104, 51.02338360201929, 52.81760515705232, 51.757196303336855, 52.46077929773639, 50.32245605222641, 47.347067632982814, 41.850791515842566, 40.83222650712536, 40.48031930000552, 40.394807707878854, 40.94350807128414, 39.58117477355465, 38.95865540350638, 40.26210608020906, 40.02817592313213, 40.166517919109715, 40.53535799826346, 40.197998862112726, 39.91052442981351, 40.96139800164008, 40.209699292336744, 40.63898701821604, 42.946387952373875, 46.937070123610965, 55.32446645921277, 55.70748590653943, 58.03409468743109, 58.29155906554192, 54.80414052163401, 54.688928742562574, 55.34212496972854, 57.57297692760345, 56.429107881361446, 56.69995146413004, 58.035181183968824, 56.48046347402758, 51.7180000582049, 48.551160750850556, 50.602289707429954, 54.85617468433996, 58.56272036029447, 56.04208761645902, 54.74104527504214, 55.48435011217671, 51.47078875572451, 54.50374580198719, 55.657048148493615, 54.03689353696762, 54.41309982730497, 50.814568381155695, 53.44585118755218, 49.72281586739325, 45.58131071829027, 41.88482199945758, 41.82099719201365, 42.65201407094156, 43.74748499162736, 42.351391853824744, 41.95385179212017, 44.35597796593943, 42.44621515274048, 41.64933073905207, 41.50244189846901, 42.792423155999955, 41.37191718624484, 42.3949380074778, 40.626502113957564, 40.99882918019449, 42.08549830221361, 42.59152720051427, 45.13968321584886, 51.54490978487077, 54.64288796147993, 54.31200858085386, 53.07234741026356, 45.329565155890684, 41.45666391618791, 44.56412246150356, 46.63664010263259, 43.428082466125495, 48.066610751613496, 49.695139623457386, 51.125098505327784, 49.142450209586855, 45.27123951142835, 45.96857417014338, 51.13013482862904, 57.11040789081205, 55.73596623636062, 53.67838498084776, 53.16516245565107, 49.86882609705771, 50.81277585798695, 52.1886452551811, 60.66216115028628, 67.06881153968074, 69.44126498314643, 69.4942169804727, 36.23044690778179, 2.341794237013786, 1.5198348462581637, 0.6716545947617101, 0.15849049143012495, 28.256623321963897, 73.87865020382789, 61.943834827792266, 50.10122652976744, 43.09118224728493, 49.12871014687323, 60.52909081982028, 68.9581701832433, 54.576697964822095, 9.164616927023857, 0.19220258890380784, 0.14140659282284399, 0.18215629572589553, 0.13990031074612372, 0.14563587313938528, 0.12249031149211431, 0.21274972586862503, 0.23695802766709562, 0.14504207838927546, 0.1213642311913352, 0.15229883093026378], [0.07526754101197566, 0.05158062716345153, 0.042776698772344864, 0.020792468961688782, 0.03786524397230918, 0.033088965386512785, 0.05297161683800721, 0.07145724184210263, 0.040181169902244886, 0.059447737275472576, 0.010771217282801386, 0.02909788478826804, 1.0103782867231677, 32.09222086014287, 46.35970115661622, 46.710317903949374, 38.96858292241251, 23.217248416716053, 32.0080409126897, 44.05867015161822, 39.57479699965447, 61.0016893571423, 19.60284706084959, 0.07430946379299126, 0.09367414404668155, 1.0888904092773315, 1.4784690401246472, 16.38600733972365, 47.77994432756978, 57.12620719786614, 56.91059058712375, 53.013578537971746, 52.193450158642186, 51.46771753987959, 52.20089089485907, 50.041433918860655, 50.04540335747504, 49.749746860996375, 48.11823306545135, 47.29793602420438, 43.57806213440434, 41.38848135548253, 37.52653137330086, 38.571968540068596, 38.74176010008782, 39.167698121839955, 36.46386715673631, 36.48097261305779, 36.105609632307484, 37.61911107647804, 39.8692257942692, 45.549810163436405, 47.22260298267488, 46.80187386851157, 50.85148180684736, 47.939408286925286, 48.3042004800612, 48.46848110998831, 39.617370405504786, 36.20928179833197, 36.8850238092484, 35.886709997730875, 37.04546051640665, 37.65374168272942, 36.40496100148847, 37.89535968534408, 36.808106130169286, 36.00453407533708, 37.653482806298044, 38.01952231314875, 37.239813958444905, 38.154644043214866, 36.44506723650041, 37.30147753992389, 38.384789113075506, 50.44373573795442, 50.61162494844007, 54.40390971399123, 44.590606304907034, 44.42925568549864, 50.38875979761924, 49.7197917199904, 52.60860950716081, 51.65441059297132, 49.621814835456114, 50.14377247902655, 51.14367877283404, 52.65948657066592, 51.49407194506738, 46.70276734136766, 51.289685080128336, 51.860048693995324, 52.19920427568498, 50.90399057634416, 50.48404593621531, 50.32879852479505, 50.29615263785086, 50.79336012563398, 49.93951897467337, 48.49807147056826, 47.699425912672474, 43.552970732412035, 44.3652347595461, 42.52829859333654, 38.181159265579716, 37.438030935102894, 37.96054947760798, 39.447155229506954, 37.827534060324396, 36.26884691176876, 38.27918714092624, 37.39287268730902, 38.10591643856418, 38.04238973125335, 39.24167794566001, 38.0030797373864, 37.32081090250323, 35.96881697254796, 36.38964022359541, 37.63659308033605, 36.608484944989605, 37.133862895350305, 40.9999039096217, 48.99551430056172, 50.33480367352886, 57.018494990564164, 53.964710158686486, 46.72564260421261, 38.69890036121492, 38.665528835788855, 40.767738819122314, 39.78974680746756, 44.84793340006183, 46.63074870263377, 49.44101318236321, 47.0508227809783, 43.5104287055231, 41.9859956156823, 53.24067200383833, 59.22011744591498, 57.561429469816154, 57.69606090361073, 57.231307106633345, 56.855277322953754, 54.02369868370795, 53.17333667509018, 54.31557009297033, 59.84680629545643, 61.382123962525405, 64.87288436582013, 28.539077120442546, 0.7243634664243268, 0.4829472513689149, 0.10146843750149974, 0.020231615992323048, 17.67343709545751, 65.15125889931956, 43.82308867669875, 48.75740681925128, 28.17994098509512, 34.437319694026826, 51.18891154566119, 50.73222606412826, 37.71458548884238, 3.388306623505008, 0.13868069877066921, 0.015809995895852486, 0.04615567511908951, 0.029819742626240178, 0.028436350628673553, 0.023383941396229693, 0.014007890882391124, 0.06840232834820786, 0.03712364787896795, 0.012384795718976568, 0.07418897348426043, 0.03251462160880047, 0.05576387325662279, 0.08777610206555936, 0.030278629292884184, 0.0426933215931058, 0.02016423855938258, 0.04206124159898009, 0.04621304744373887, 0.02316634944309631, 0.04313540029069109, 0.08136221478062292, 0.0270487662149413, 1.4428879945508897, 37.722316480452015, 54.73549119887814, 53.03672836672876, 43.85878224526682, 29.712805209621308, 32.06567425881663, 45.40595331499654, 45.013645695101836, 64.6070182708002, 21.329482255443452, 0.1330513621289884, 0.05577973510709502, 1.176048293709755, 2.012670852484242, 16.924729193410567, 49.985901001961004, 57.73098568762503, 59.13120515884892, 54.716114690226895, 56.16115900778002, 52.903528598047075, 54.826345059179495, 52.43360511718258, 52.27939713385798, 52.797040170238866, 51.0799559470146, 49.322173210882376, 45.90866388813142, 43.513041004057854, 38.8238396183137, 39.80658946498748, 41.528729623363866, 40.833340460254306, 37.309753740987475, 38.23387984306582, 37.15636553302888, 39.04881108191706, 43.87198494326684, 46.374845427851525, 48.353375234911525, 49.632726869275494, 51.12942880199802, 49.780282512787856, 49.80471887896138, 49.50136276983446, 41.50809403388731, 37.54961844413511, 39.30532232407601, 38.59207460957189, 37.885000705718994, 39.44418207291634, 38.42323618550455, 40.174915713648645, 38.86470287076889, 39.21988525698262, 40.02616374723373, 38.87413224866314, 37.91212389546056, 38.72665505255423, 37.93014718640236, 37.272212736068234, 40.263643649316606, 52.00767101780061, 51.843076598259714, 55.40079970513621, 47.531160154650294, 44.44294083502985, 50.811661904858006, 50.734089189960116, 55.14623395858273, 52.70837499249367, 52.27343513119606, 54.02012540448097, 52.114951764383626, 56.15096869007234, 52.350909786839644, 47.299175493178836, 52.4635681029289, 53.568284050110854, 54.52001579346196, 51.95961021607923, 52.82618338061918, 51.31152483724779, 52.829344810978064, 52.645660215808505, 52.46927122915945, 50.93938996714931, 49.89157976642732, 46.1478147199077, 46.20788974146689, 44.07525393270677, 40.90974823121102, 39.6240698137591, 39.41144597145819, 39.25026401396721, 38.54407264340309, 37.59086216649702, 39.67708456900812, 38.18701144187681, 39.059778028918856, 39.82329876192155, 41.06046530508226, 40.67453938145792, 39.119574562195815, 38.925770251981675, 39.27162916429582, 39.67271112626599, 39.226137515037294, 39.97247826668524, 42.876518772494414, 50.82671596157936, 52.39407939295615, 59.46350051510719, 55.40605568116712, 48.51560838760869, 40.92576719099476, 39.832026035554954, 42.507176629958614, 42.883277016301314, 45.25314561782345, 47.654495162348596, 50.588651626340805, 47.928013801574714, 46.002557585316325, 42.561587748988984, 54.805736926294145, 59.72318887710572, 59.5068113265499, 60.12790687622563, 58.77438322190316, 58.5609592160871, 54.47458297975602, 55.609516866745494, 55.35525706506545, 62.38321873449511, 63.976834589435214, 67.8757058420489, 30.096991562074233, 0.9569600789297013, 0.9606961365188322, 0.0076567701387008835, 0.06182661265014641, 20.994884467894032, 69.35316070433586, 50.350073460609686, 51.70822943410566, 33.95323645684027, 44.91501377474877, 57.11009802356843, 60.3215229126715, 44.94252135676723, 5.18991792394269, 0.09633787006380097, 0.060788253247137033, 0.03307471615112117, 0.01248347454689323, 0.021942202227130052, 0.05812740389017328, 0.047450727602887544, 0.04624157655803908, 0.005952874245497609, 0.01577146933414042, 0.0877200014468643, 0.13723965674158067, 0.121684126525877, 0.15279228348405133, 0.1484643616863797, 0.0985236491467203, 0.16476896501356558, 0.17781118291520304, 0.22743175497218487, 0.11774016799585474, 0.11643388083264714, 0.17138779614000552, 0.13634337983544798, 1.6724263227755025, 41.640246529732984, 64.2028219469132, 59.873505869219386, 52.74563750913067, 35.07364972945183, 43.29511411728398, 56.6110077981026, 51.20612290597732, 70.28295070894303, 25.140967022988107, 0.18001517190808253, 0.2009305979816183, 5.248739748231826, 4.494099261299256, 19.337355552181123, 52.99266838258313, 59.42452000033472, 60.71339907184724, 58.07199655040618, 57.58554027926538, 57.05185474887971, 56.917603784991854, 54.6008401532327, 55.22439895137664, 54.352969892563365, 53.553735979141734, 53.32215532179802, 47.44087503802392, 47.46220880939115, 41.44655596825385, 40.957126540522424, 42.43134152504706, 42.45615443875713, 39.751338958740234, 39.492470372107725, 39.87705484513314, 42.24026326210269, 44.965176966882524, 49.12320706152147, 51.09772820626536, 51.12271370426301, 54.49872516816663, 51.19210435498146, 51.91768792367751, 55.581919070213075, 44.350831816273356, 39.77416715314312, 41.045803485378144, 38.535776830488636, 40.954196530003706, 40.96786599005423, 40.80409134587934, 41.858867676027366, 40.557236979084635, 39.6545034839261, 42.430686489228286, 41.33931836774273, 39.592522190463164, 42.22728413920249, 40.47527905433409, 40.05085898983864, 42.31887932746641, 55.69096096100346, 54.38472147910826, 58.275465580724905, 48.08196290846794, 46.06407603909893, 52.498437973760794, 52.09280606239073, 55.16346493074971, 55.06821017111502, 54.354417247156945, 54.205414249051, 53.18497434739144, 57.786404855789684, 54.563754143253455, 49.02046057485765, 53.66133836007888, 55.75147528802195, 55.79825347469699, 54.824630983414195, 54.34499963637322, 52.51741047828428, 55.21423609026017, 55.39947786638814, 54.268717381262014, 53.083502631033625, 51.14633029507053, 46.66507728638188, 47.29269966002434, 46.486825173900975, 42.23150853187808, 41.28830794365176, 40.72114498384538, 43.53807357049758, 41.51741358541673, 39.52064475705547, 41.00745054983324, 39.84888830492574, 40.99798194823727, 42.63057047320951, 43.62180440656601, 41.87305096657046, 41.327362983457505, 40.5743149788149, 41.653884610822125, 42.26694714638495, 41.606533758101925, 40.9710431098938, 45.60790438805857, 54.21561241149903, 55.276715524734996, 59.38234667624197, 56.58202932726953, 52.569621147647986, 43.655305370207756, 42.75764349968203, 45.52133375598539, 44.69605530461958, 50.00079816387546, 50.30338548844861, 53.88553319438812, 52.12757787396831, 48.750625041223344, 45.207477461907175, 59.776093805989916, 62.935190354624105, 61.54866780004194, 62.14065151829874, 62.56620907014417, 63.36934966425743, 58.89642776981477, 58.143591573161466, 59.57711981188867, 64.19105875876643, 67.52787005516791, 70.17260659125544, 32.23798986404173, 1.5720855973420607, 2.338873051827954, 0.24874234451882302, 0.23032621901121833, 22.092400904624693, 76.09436573520784, 57.43626271524737, 61.354153540826616, 42.07053446000622, 47.50294654600082, 65.96573122086065, 69.05473893688571, 56.53104243739959, 8.12763491945882, 0.22873819535297735, 0.11879243572512943, 0.2470457355581945, 0.15262516906424878, 0.1252376636670482, 0.19641294684861937, 0.23938894722490545, 0.22320307220422456, 0.1395233342003438, 0.10330941573145891, 0.15531763103940796], [0.06775454738207402, 0.03123446761990988, 0.08190551667564339, 0.035763596665234335, 0.028070867316977634, 0.045427642612447666, 0.009305765777225456, 0.01425916772155512, 0.06251835940225471, 0.09038369682046676, 0.024087478241492665, 0.037899986059675296, 0.15426078210434607, 20.816412702683483, 44.7630964556048, 51.36342956173805, 40.189856021634995, 23.043626662223573, 26.522245368649884, 36.090720315133375, 40.64014803978705, 57.225282346048665, 25.72205243572112, 0.10506820804890125, 0.01685826081572281, 0.2954206639720548, 0.6942522273428979, 9.44312874347933, 47.398144737366714, 60.296086342104026, 57.47611007382793, 52.94168933745354, 48.9436056537013, 44.564220520757864, 43.28372747667375, 39.5647753438642, 42.200584565439534, 40.318733338386785, 41.68123922040386, 39.17317375060051, 39.08748172944592, 40.94527313786168, 40.44460611958658, 36.954245798049435, 38.71431919836229, 39.52187638128958, 41.43066252431562, 41.65137429391184, 38.510516766578924, 38.261956168759255, 40.66157987040859, 40.9333844338694, 45.09290502917382, 47.126924607061575, 45.68665381400816, 47.45883949341313, 49.89219950091455, 48.93725533639231, 43.08016430947089, 35.12327947924214, 36.38963237885506, 35.81506398416335, 37.484950327104144, 36.605794199051395, 36.67003870010376, 37.535835235349595, 36.49327316591817, 36.48782499374882, 39.05868368764078, 37.92078448880104, 37.18678743608537, 36.161762283694365, 37.11100724435622, 36.28934914065946, 39.36605630382415, 48.169925981952304, 51.39862891166441, 49.37328169422765, 48.454980311855195, 46.043915056413226, 47.76582379494944, 51.29675319117885, 50.702537644294004, 50.6789053640058, 49.978228845903956, 48.75625756479079, 50.7893906870196, 50.55435442155408, 54.091539998208326, 48.16469354014243, 51.959045394774414, 50.806405928827104, 50.191656774090184, 52.80417888395248, 51.86372395484678, 50.685953863205455, 51.28870448758526, 48.93016761349094, 51.419229199809415, 47.960302752833215, 47.003911233717396, 44.6056721287389, 43.175654411315925, 38.79079757198211, 38.17045511737947, 36.712725854689076, 39.66217956235332, 37.91008818534113, 38.753974360804406, 36.71376920515491, 37.513901341346006, 37.974026741520056, 38.33897975183303, 38.38933514010522, 37.31857515150501, 37.969806271214644, 36.96589131509104, 39.378407847496774, 37.48303228808988, 38.22372482668969, 37.53960071071502, 37.34523550156624, 41.24328697881391, 48.05010541792839, 50.3146936816554, 49.25597929185437, 52.64712718225295, 50.34865356260731, 40.645294189453125, 38.91691354013259, 40.27284160737069, 40.941593954640055, 41.83694947150446, 46.63740888718636, 51.46135153308992, 48.14714485599149, 45.19135259812878, 43.43390718583138, 50.20185885890838, 58.09534249767181, 55.64259029203846, 58.11183214187623, 57.87086133033999, 59.67734029216152, 55.45058634973342, 59.182592130476436, 58.04831327930574, 58.95742454836446, 60.103348916576756, 61.9539741546877, 21.777818972064605, 0.6702732463036815, 0.5281373990639564, 0.08314802701915465, 0.039400890199167114, 20.988522383474535, 64.14022484133321, 48.865009200188425, 40.42548064262637, 31.360310508358864, 23.25424813455151, 46.79954005825905, 52.083109963324766, 39.65200101175616, 3.6769435482640422, 0.0497411045005485, 0.043985374842680273, 0.029113926669402473, 0.08759970266011455, 0.025618995254438733, 0.03373585386021483, 0.015937569645053197, 0.03954946146076245, 0.05344999278144491, 0.046024754523269595, 0.025730951343693083, 0.06841297697035537, 0.028000998183063446, 0.0036272668794188052, 0.01016343568241404, 0.062316499064646425, 0.015139136530999697, 0.03144685017515815, 0.010895613682336144, 0.08863556078605114, 0.06130352015456846, 0.017879662862528237, 0.04621198258152412, 0.18301359407844084, 25.012317203706314, 52.36068433330905, 59.973718504751886, 45.994426511949115, 25.503352842023297, 26.694088328269224, 40.917530213632894, 45.869079328352406, 61.219604476805664, 26.253133512312367, 0.04119475019134341, 0.022574690163075443, 1.2703214802088276, 1.667489652191439, 11.248536898243813, 48.17881407276277, 58.762012066379675, 57.87066521183137, 55.574646995913604, 52.69119893350909, 48.592329948179184, 45.813130640214496, 43.96416456468644, 44.31467540802495, 43.03484524449995, 44.06465176613101, 43.18743721131356, 40.7025529492286, 43.2632174030427, 41.906257752449285, 38.85247292057161, 40.885688412574034, 41.76503281439505, 42.13558696931408, 42.21482276916504, 38.745345146425315, 39.43802787411598, 42.08891860900387, 42.20177304360175, 46.762877664258404, 47.8687350211605, 47.80859331930838, 49.46803046811012, 50.82422133414976, 50.11657084188154, 45.59701588846023, 37.726611475790705, 38.15118059035271, 37.86712254247358, 39.670820543842936, 37.792342555138376, 37.13873447910432, 38.360380203493186, 38.284921646118164, 38.14886639195104, 41.14151323995283, 40.13439370739845, 37.74703133490778, 37.46262027371315, 37.99145775456583, 36.97261033519622, 41.3290927487035, 50.57754739638298, 52.257294577936975, 50.792885518843136, 49.429748135228316, 46.011935972398334, 47.16768195552211, 52.31696167299825, 53.49763824093727, 51.82790879280337, 49.42146801179456, 49.30805267826204, 52.810054594470614, 52.743515506867446, 56.072172195680686, 49.209428602649325, 52.75996984974031, 53.20724948760002, 53.21323110211281, 54.97008031414401, 53.57057471429148, 52.71459979395713, 53.50238430884577, 51.77173260719546, 54.02922530328074, 50.78502508901781, 48.715786549352835, 47.28301925043906, 44.86925148194836, 41.69593241906936, 37.75284036513298, 38.87883517049974, 40.17066386438186, 38.94946921256281, 39.48815968728835, 39.10289272185295, 37.52733938155636, 40.497283551000784, 39.61999054877989, 40.229738681547104, 39.995490812486224, 40.27002142321679, 39.87871008534586, 39.853151921303045, 40.67592397812874, 41.141929011191095, 37.877595270833666, 39.72746349150135, 43.839629311715406, 51.37941322019024, 53.73135266765472, 53.62628413784889, 53.955975040312744, 52.20970446063627, 43.96600023392708, 41.43473002218431, 40.651887693712794, 41.803656393481845, 43.39429124709099, 48.27077404145272, 54.29221630096436, 50.32716681880336, 47.5681245711542, 46.206297259176935, 51.79081493808378, 58.93593780456051, 59.46130006544052, 59.65419830814485, 60.39911131705008, 62.632979577587506, 59.86606121063233, 60.9093685303965, 60.9488981769931, 61.8269128953257, 62.71915797264346, 62.830035532674486, 22.778613682716127, 0.9218752744697756, 0.5849202037338288, 0.08067249816151396, 0.025430514642428008, 22.472284416998587, 68.62647887199157, 52.914334727871804, 48.07196870926888, 31.818139360797023, 29.268163365702478, 55.5589771270752, 58.983829944364494, 46.98985345901982, 5.09814917079864, 0.05599825019617716, 0.06414015604663761, 0.08909057870867754, 0.05149770580652741, 0.07570375147606097, 0.02199550662490149, 0.020690083225828507, 0.04370448104436359, 0.07266840386775232, 0.04829710154163261, 0.01891096276531537, 0.1463481204043473, 0.13059062642916558, 0.14427698637929656, 0.10002015594152674, 0.25632402559201567, 0.13425053487862312, 0.13958174074369092, 0.09759246161387813, 0.21348915393314055, 0.16366166152781056, 0.10157030421279131, 0.24372388638796347, 0.34113242561298035, 28.301610946655277, 64.2891219354445, 67.89048533285818, 51.724836749415246, 32.940523624420166, 37.51429357836324, 47.14162565046742, 50.13878714653754, 67.48170375823975, 30.111584740300334, 0.19105010155227878, 0.06013133668250615, 2.6682143730501977, 2.684207837427816, 11.778009803064409, 50.89312561096684, 62.68000879595357, 61.272823195303644, 58.06665428223149, 54.590441949905895, 49.9531021425801, 47.072211465527936, 46.2402218387973, 45.95184918372862, 44.74819144895, 46.09059910620413, 44.38008093064831, 42.08813021259923, 45.31378938305763, 43.976888733525435, 40.64318003193025, 43.939430098379816, 42.86488110019315, 45.87750457948255, 45.28807040183775, 41.52166543468353, 43.113755487626605, 43.88212427016228, 45.559404280877885, 49.47074082589919, 50.78419746891145, 48.28017988512593, 51.3465908265883, 54.10877489274549, 53.619380766345614, 47.83668925685268, 40.31738796541768, 40.754438061867994, 39.32943705589541, 41.941680677475475, 38.82291001658286, 38.464715250076786, 40.337972564081994, 39.89900835098759, 39.288871903573316, 43.823371087351155, 40.697634297032515, 39.18314441557854, 38.324317932128906, 39.61105538952736, 39.17182837763141, 43.11948607044835, 52.19855708460654, 54.16205636916622, 52.27836162813249, 51.6480367414413, 46.84295285132624, 48.59059233819285, 52.2007026210908, 53.86918083313973, 53.357287991431456, 53.875982223018525, 52.233705443720666, 53.695702245158536, 54.210207385401574, 58.53134924365629, 51.70067102678361, 52.593653509693766, 54.85066767661802, 53.26066432460662, 57.10082554048108, 54.991021848494015, 54.82313656037854, 55.04726471439485, 54.84035184306484, 56.66923146094046, 51.90371644112372, 51.823821683083814, 50.3006947425104, 48.60886666082567, 43.32408866574688, 40.59406411263251, 41.48969811777915, 43.40862358770063, 41.207165871897054, 42.1481385538655, 40.59803355124689, 42.05764162924982, 41.39797349129954, 40.589400414497625, 41.9155223907963, 40.588270771888, 41.633096048908854, 42.42148068643386, 43.570617475817286, 43.06672234689036, 43.190273084948146, 40.493039546474336, 41.5425677453318, 46.465197224770826, 53.42996166598413, 56.461239937813055, 55.37517486080047, 55.80165809200656, 53.1004511925482, 46.64006433179302, 44.17602354480375, 43.22660599985431, 43.57384166409893, 46.613011744714555, 51.13564575872114, 56.41644254807503, 51.838452123826556, 49.62711395755891, 49.6227522819273, 56.30781250615274, 63.88740062713624, 61.1661974845394, 62.767320755989324, 61.48720425944175, 65.06057370093562, 61.69380726352815, 63.633980212673066, 63.58458972746327, 63.37596278036795, 65.69273817923762, 65.4498807076485, 25.312170636269357, 1.4590480370867638, 1.0599118158701928, 0.4349906682487457, 0.19103248153002034, 25.85330866998242, 75.61870774915143, 60.50805514858615, 52.394267666724424, 44.013935519802956, 36.467644399212254, 62.16058108114428, 70.06781654973184, 57.7608427693767, 7.836834807549754, 0.21396304060134197, 0.3088785305378899, 0.2010978962625227, 0.21305095164045212, 0.14532209884735847, 0.09488727491829665, 0.10632749571795426, 0.12869403787678288, 0.2079163086149962, 0.1447908934806624, 0.1390288704104962], [0.029975277627067223, 0.03797205578115198, 0.06959373296629037, 0.05307160663388429, 0.06470927893514596, 0.0339944621608142, 0.08817771599898416, 0.053870471630005114, 0.0435134646813235, 0.02148743711351868, 0.06044192021832832, 0.009854443694254564, 0.03294139003921901, 12.049833978376082, 44.7179421301811, 50.087537457866055, 43.70040086007888, 33.14370632171631, 25.95422733214594, 31.886694546668764, 40.61356221475909, 58.70113688130533, 32.51893551118913, 0.2677140216673574, 0.013868231138574981, 0.6483308334023722, 0.6490318344966058, 7.863319141249503, 41.86411972968809, 59.057033138890425, 56.67123971446868, 51.53221699499315, 45.0613691729884, 43.087001000681234, 41.54851405851303, 38.226976471562544, 39.06396712026289, 37.581797569028794, 37.797888786562034, 38.62017054711619, 39.750609397888184, 38.6812771520307, 36.17359215213407, 38.78349411872126, 46.37959149576003, 49.779588253267356, 47.36620095468337, 45.51158274373701, 45.366576640836655, 44.62464071089222, 41.354478328458725, 41.541869563441125, 43.686825536912494, 45.26601099198865, 48.59501284937705, 47.95439566335371, 47.78238796418714, 50.21956836023639, 46.41874459482009, 36.8204302172507, 35.394880079454, 37.47402652617424, 36.63386268000449, 36.42594568191036, 37.54762588008758, 37.43315150660854, 36.12670806146438, 37.71804109696419, 36.65301561355591, 38.138064184496486, 37.24852162022745, 35.914739254982244, 37.36405503365302, 35.39516641247657, 37.94094939385691, 49.04355941280242, 52.811568629357126, 51.12157229454287, 53.93355869477796, 53.65201880854946, 52.59413596122496, 51.383037490229455, 51.75933791745094, 51.50914561363959, 50.00912143338112, 44.229371701517415, 48.644509238581506, 52.08012503962363, 52.4398220739057, 51.114633621708045, 51.10909523502473, 51.020716390302105, 49.9824022477673, 48.125995436022365, 51.841166403985795, 50.58119127827306, 48.66554490981564, 49.27822305310158, 48.62363438452444, 48.947963406962735, 48.88410329818726, 43.76139371625839, 42.2479118839387, 36.36070097646406, 36.54334614353795, 39.07424765248453, 37.079008548490464, 38.394222413339925, 37.199841084018836, 38.421176941164084, 35.97826988466325, 38.00716684710595, 37.342415317412346, 39.15398943808771, 36.86923234693466, 38.658166546975416, 37.860054431423066, 38.12347296745547, 36.979611765953806, 37.996066539518296, 37.51457206664547, 37.8259180438134, 42.42106883756576, 49.51582062628962, 47.73458603889712, 48.74234884015976, 48.856631017500355, 53.35549939063288, 46.44225135926278, 40.80803725027269, 37.02909246567757, 40.00676762673163, 39.20975377482753, 43.52401187342983, 49.39223066453011, 50.97244770296159, 49.27882317573794, 44.89258958447365, 44.36974156287409, 53.50250197995094, 56.81734015864711, 60.241181004431944, 58.351520338366115, 60.01191846786007, 60.34154661240117, 61.72671594927388, 60.173182795124674, 63.09563098415252, 63.88304287387479, 53.56620519391952, 13.183486230911749, 0.3495920587691569, 0.9170864894986154, 0.08290448766802588, 0.03769740559941819, 24.04438214917337, 63.77655836843676, 49.27428499344857, 46.54980274938768, 36.401360265670284, 28.241116231487645, 45.41618285640594, 55.07334847604075, 40.567525356046616, 4.595797004238252, 0.02011580839602938, 0.0428531083819126, 0.035147328725865776, 0.022858280590885592, 0.038135477657159494, 0.06942325542050024, 0.05201963001802083, 0.01702177079184161, 0.01803661704123501, 0.07426480086700571, 0.043250359444608616, 0.00907771385109593, 0.02829988738672147, 0.045904815797844244, 0.04096621084177206, 0.026757853901794842, 0.026702624708113652, 0.0426396303209326, 0.04667661490760023, 0.018568213112772475, 0.06580472337983309, 0.08283806784499077, 0.01488548098883081, 0.019937851916878455, 15.071225916185687, 52.556700860300374, 56.30815375235773, 49.47165866051951, 33.86761896071896, 28.039392655895604, 38.10967799155943, 46.60922665749827, 62.70352340513661, 34.71966758851082, 0.2788332056614661, 0.0282835697139343, 0.39974495468120425, 1.5354415894516054, 7.879889684338724, 43.869921776556204, 61.14171012755364, 58.66056388424289, 52.97541387619511, 46.578071271219564, 43.938061191189675, 43.669818139845326, 40.63290734444895, 40.55028261676912, 40.06757613151304, 41.015189386183216, 39.42585675947128, 41.52859234040783, 39.73806173570695, 38.30674963612711, 41.518496159584295, 46.703987198491255, 51.817345849929325, 50.20810719459288, 46.24581121629285, 47.26956159837785, 45.30826668585501, 42.44303803290091, 42.38513600441718, 46.14298628222558, 47.97491750409527, 50.019751056548095, 49.66984425821612, 49.292437722606046, 50.628906911419286, 48.48597488095684, 39.001091526400664, 37.18011156205208, 37.9091860402015, 37.97325403459611, 38.364663431721354, 39.27814029878186, 39.24265461583292, 38.20215571311213, 39.15626441278766, 40.56915313966813, 39.94463336083197, 39.02712429723432, 37.85938762849377, 39.832951714915616, 37.23959038334508, 38.86666405585505, 53.217086791992195, 55.26485819970408, 53.045510553544574, 55.161962662973714, 55.29165191035117, 53.013453022126235, 51.92364600396926, 52.52044247042749, 53.96607514350645, 51.72927295008014, 45.94194519904352, 51.51501347941738, 54.46819736111549, 53.771702089617335, 52.68888081273725, 51.89405564338931, 52.47808087256647, 53.22833222727622, 51.298071107556744, 52.83855453614266, 52.365810871124275, 49.306542565745694, 50.64066617719589, 50.21464578567013, 51.48280689793249, 50.75235566785259, 44.626566594646825, 43.53210764546549, 38.47829449561335, 38.29057378153647, 40.68205856507824, 38.73854375654651, 38.71800622632427, 37.696464138646284, 39.13232226525584, 38.317096848641675, 39.86045145219372, 38.97021462840419, 40.433956884568744, 38.74513726080618, 41.851026858052904, 40.1223284967484, 40.175966908854825, 40.08558373297415, 39.30718544990786, 39.05918575102283, 39.51098788169123, 45.654035383655184, 50.40535534581831, 51.0542683447561, 50.411227133966264, 50.41309025979812, 55.68925080760833, 49.68275670082339, 41.84164062623055, 38.85936844733454, 41.26152600011518, 41.612950755703835, 45.416939873849195, 50.00473622352847, 51.74513893742716, 51.46034740632581, 46.642762922471576, 45.97293192340482, 57.568917274475105, 58.69657124242475, 63.25662074550506, 58.97695402945242, 61.48785537289035, 62.63951816866475, 63.55544259471279, 61.19921599664996, 65.62303766127556, 65.5247469871275, 55.27555842553416, 15.247748263420599, 0.797305578185666, 1.0768733702359663, 0.050201193925233624, 0.07068793634854018, 25.260854267304946, 70.0290007745066, 55.3835726553394, 50.945889334524836, 38.816018412190104, 32.257252623957974, 50.99523275129257, 63.47727760191887, 49.72290608190721, 6.340662885096766, 0.10218393297926073, 0.06271733541882808, 0.030579265177009568, 0.03177324576573747, 0.06930883252812971, 0.029035628653101386, 0.06584716465083823, 0.01677599254875414, 0.020350181505144126, 0.06074612224174123, 0.038359477935779485, 0.09953669317427183, 0.14284195047953438, 0.23591999385145404, 0.1738132611517945, 0.18164171446715632, 0.13574085168300137, 0.2747124187167614, 0.14531561774351906, 0.1608143731831543, 0.16557750953060968, 0.1541604552297823, 0.10985310895428543, 0.12760570272803307, 16.347801493060206, 64.49450508240731, 63.747046455260254, 56.18843909232847, 43.36602664762928, 37.50347175905782, 42.53466852249638, 51.891117788130245, 69.44496770058909, 39.03294509457004, 0.5838433905474602, 0.19720998472504078, 1.4317002916528334, 3.538111746311188, 9.819545861213438, 45.29080821621803, 63.18417064605221, 61.78407276830366, 55.45201409247614, 48.74004248649844, 45.816911805060606, 47.159033129292155, 43.60082364851429, 44.5951444871964, 41.60025012108588, 43.45014579834477, 41.40005626986104, 45.4683425349574, 41.59764566729146, 40.25896426170103, 42.97182452294135, 50.387528173385135, 53.39157342910767, 50.93147854651175, 49.389830173984656, 50.37429801879391, 47.940706591452326, 44.68435879676573, 45.27571885816513, 48.28717347114317, 48.464696022772024, 51.28012234164823, 49.823914958584695, 50.910752742521225, 53.720020940226895, 51.47169874560449, 40.39132856553601, 39.22321927162909, 40.57766468294206, 39.49468258888491, 40.320376811488984, 42.71343054309968, 40.94712449658302, 40.75114327092325, 40.71135474789528, 41.5193590810222, 42.36999957792221, 39.9656415754749, 39.508587391145774, 41.724640246360536, 38.178354770906516, 39.71557870987923, 55.93677982207268, 56.7632898976726, 54.1233661097865, 56.78259972603091, 55.8141076949335, 56.26754153159357, 53.18423694179904, 54.29934324756746, 54.582667812224365, 54.24754834944203, 48.696994473857266, 54.55625849385416, 55.38263128649805, 56.35374738324074, 55.436603100069114, 55.39763043003698, 54.49508913101689, 55.5637231949837, 52.276584794444425, 54.85436254932035, 52.56537322075137, 48.92806130070841, 52.61477939544186, 53.423968284360825, 52.431169325305575, 54.17565914892382, 46.792597463054044, 46.407259894955544, 39.373681391439135, 39.831135657525834, 43.328571934853834, 40.949830932001916, 40.39912623743857, 39.91671392994542, 41.64508673452562, 40.63449198199857, 42.239125774752715, 40.86838291537377, 42.20492662922029, 40.06212011460335, 44.15423085612636, 42.55340568480953, 41.923461268025065, 43.39881373989967, 41.52588590498894, 40.82098891658168, 41.07697063876737, 46.734809183305316, 52.9357155676811, 53.007734206414995, 54.83421333374516, 51.17101769293509, 56.9279823764678, 52.45665296431511, 45.5696887354697, 40.667953721938595, 45.12302883209721, 43.56236480897473, 47.25140886922037, 53.76668145579677, 55.276021265214496, 55.9184152849259, 50.39934627471432, 48.180535993268414, 59.149432413039676, 61.16236140651088, 64.5187923985143, 61.69692947018532, 62.14317752468971, 64.16580261722689, 66.92709630535495, 65.22449739517705, 69.62483975195116, 68.52257528612691, 57.076667662589784, 17.18896162125372, 0.9002099402489201, 2.726134542495974, 0.4997594798764875, 0.2403245397633122, 27.854297968649096, 76.63902605733564, 61.13501856403967, 62.063588711523245, 50.37182300321518, 41.24125519106465, 59.49641704559327, 72.06136903455182, 60.60713814150903, 9.826493359381153, 0.2628761457820093, 0.14813318187671323, 0.10159116478696947, 0.16631945036351684, 0.19166833450717313, 0.29941516898332105, 0.24653719107229866, 0.1001602121358437, 0.10005098331959979, 0.1395517560623346, 0.19737300823532766], [0.016934143739842603, 0.060370942172143734, 0.04355560717803817, 0.014660618861296005, 0.05540097740689113, 0.07957671663814014, 0.06385388048065287, 0.0292596691513374, 0.007560533216042865, 0.04141454081681948, 0.05467383356224145, 0.11031639296561481, 0.03062783515140895, 6.056908820905994, 42.103851072249874, 50.07412687424691, 42.32566110549435, 31.63013819725283, 20.002813108505745, 34.10762879156297, 42.001426219940186, 54.519913811837476, 38.94227166329661, 1.164816586721328, 0.1267369207175028, 0.5142874486984745, 0.4973055470374323, 3.23876160287088, 36.399183350224654, 55.79263664061024, 54.89291160337387, 50.94997644424439, 48.481593593474365, 49.67648875328803, 49.61757867567001, 48.075043847483975, 48.40475436179869, 43.55237453214584, 40.699756299295736, 38.70434853338426, 37.5052172137845, 34.962073987530125, 40.71385329769504, 47.696001683512044, 51.04103034542453, 46.587033887063306, 46.91205324665193, 45.97598352739888, 42.055354887439364, 45.65711052187028, 46.807871172505045, 44.36721555648312, 48.82111787796021, 49.69627711080736, 49.14634904553814, 49.59197344318513, 47.875830588802216, 49.16044996630762, 46.43852510759908, 35.86694909680274, 36.59686688453921, 37.06534301081012, 36.94394565397693, 35.337625242048695, 38.40178474303215, 37.8932612173019, 36.90625952136132, 37.404635875455796, 40.15140894920596, 38.46980256419028, 37.28152836522749, 38.02615504111014, 37.02610754197644, 37.10448434275966, 37.27849245071411, 42.360021068203835, 48.16081039367184, 50.295164200567434, 49.579665045584406, 50.76162422856977, 51.41847218236616, 52.66552309836111, 52.23330143959292, 53.29984880262806, 50.768892380499075, 46.5794127218185, 47.36525566347184, 51.84206854912543, 53.80234364540347, 50.866390735872336, 50.26679369711107, 51.3957538143281, 52.33194904942667, 58.81832161257344, 51.96371301527947, 46.93909406661988, 45.2011546011894, 46.81602970246346, 49.682180112408055, 51.60841295796057, 49.15153834127611, 43.404195231776086, 39.56985481323735, 38.28630232041882, 38.364714422533595, 38.25696691390007, 38.49823974793957, 38.76682012311874, 38.21058096424226, 37.28173625084662, 38.37911736580634, 39.46133459767988, 37.52578612296812, 37.97748234964187, 37.988025680665054, 39.27228420011459, 36.515010941413145, 38.156966086356874, 37.57450588287846, 38.37904284077306, 37.448440905540224, 39.29444559158818, 43.81359654088175, 47.72333275887274, 48.70575312645205, 43.12684443689162, 47.82318061397922, 52.26418618232974, 50.371305250352435, 46.61087797534081, 38.879003832417155, 38.178217487950484, 37.52912405998477, 40.31283017127745, 45.55878454639066, 49.27057050889539, 48.74630258929346, 47.51564325824861, 41.07034183317616, 43.836793438080825, 52.690445838436005, 55.26084169264763, 55.220845284000525, 55.23056883965769, 57.270456283323234, 61.52934228220294, 62.12529936144429, 65.84239621316233, 62.02216848250359, 42.15912511271816, 6.882648641063321, 0.5640626939073686, 0.3801060149506215, 0.09433163134681602, 0.0544399239363209, 23.473237983642086, 63.89586902433827, 50.75408543309858, 45.00061950375957, 26.443101744497977, 22.78760571633616, 44.11544253749233, 49.179748027555405, 37.4154459276507, 4.648615150682388, 0.23740107163546548, 0.06107634061106271, 0.03364664292143237, 0.06626411566450711, 0.0621133785124027, 0.027012317666723847, 0.011853662173023388, 0.05072701369382201, 0.08876106130980677, 0.01916605280712247, 0.053427722605486075, 0.025416374574565602, 0.09644352891031774, 0.027453659004682017, 0.013632276057896596, 0.05312507957099907, 0.06551141129626382, 0.030510504955365777, 0.01351236318793869, 0.02692036413317246, 0.0325935899520353, 0.03634435259887288, 0.04126510770630933, 0.04422513738034233, 7.754110059430523, 50.72133364215974, 55.24996888252997, 48.69247198104859, 36.29962575051093, 26.158557322717485, 37.44568740167926, 48.850516042401715, 59.41887178728658, 41.094225145155384, 1.1604686393853159, 0.0619581729293831, 0.899238050464661, 1.5597400597987638, 4.683647309580158, 37.31885363978725, 59.206683328074796, 55.73631532730595, 51.24131441116334, 49.90126409838277, 51.5991561643539, 51.748190541421216, 50.55999478986187, 50.3076647943066, 45.48004296518142, 42.79564342191143, 41.07317770681074, 41.090483204011, 37.89230023660968, 41.92992533406904, 49.27086076428814, 51.895561833535474, 48.717633985704, 47.27866934191796, 45.94533804924258, 45.20737940265287, 47.83075078841179, 49.325722955888324, 44.78940379235053, 50.18003086889944, 50.890729042791556, 49.81914535645516, 49.31746244430543, 49.51602458953858, 50.2119158160302, 47.958678891581876, 37.57332132708642, 39.01087783998059, 40.04293972446073, 40.366154793770086, 37.168089497473936, 40.059460747626524, 41.37889900515157, 38.66054742567001, 39.43587841526155, 40.7692293197878, 39.5511451075154, 38.347369701631614, 39.607215389128655, 38.88011778554609, 39.48681039194907, 40.15479787703484, 46.48618974993306, 51.05428011186662, 51.36578690621161, 51.40444186425979, 52.20263634958575, 54.44968377390216, 54.61399578279065, 54.96501653425155, 55.23694661355788, 52.32961523917414, 48.14852160792197, 49.883013309970984, 53.42293670100551, 56.70676462111935, 51.92824302181121, 51.55533152241861, 54.2935420620826, 51.21213982182165, 58.59007104750603, 53.53474778513755, 49.428983273044715, 47.018278875658595, 48.619049133793006, 51.04960072425104, 53.89340931369413, 48.79637948928341, 46.76431325174148, 41.20692660731655, 41.197818863776426, 40.36489963531494, 40.141736384361025, 40.70794228584536, 39.963527417952015, 38.373527988310784, 38.876007141605506, 40.32429133692096, 41.19338658548171, 39.920863797587735, 41.02470505622126, 40.1592654566611, 41.7270681934972, 39.2644198479191, 39.46915972617365, 38.15797413549116, 40.793410731900124, 37.937105471088046, 41.016150366875436, 44.95056221562047, 49.13306005539433, 51.60717348898611, 46.62333150063792, 49.42349979954381, 54.01887809076617, 53.672917196827555, 47.81261767110517, 40.84105184001308, 39.74376486193749, 39.67044399630639, 42.15655203788511, 48.171993071033114, 51.64863294170749, 50.60908717493857, 49.33184185335713, 42.78770454468266, 46.71187508490778, 55.585915965418664, 57.6651918503546, 58.07367924721011, 56.657130948958866, 58.17353494705693, 62.92359190602457, 63.60230707353162, 65.69225180533626, 64.64730493484005, 43.70123632492558, 9.300847707256194, 0.4927554444199609, 1.58264608873475, 0.017778567984820377, 0.046132389876631, 24.53241913549362, 69.14183908893217, 54.09937689381262, 49.86299745498165, 31.843538668847856, 26.95591045964149, 50.47901353528423, 57.70014409096011, 46.796766942547215, 6.531723987671637, 0.13222231709909055, 0.05690390784894267, 0.007642558250095576, 0.026317606154348583, 0.02106203040438554, 0.021300988549727107, 0.038972114618386955, 0.042862305267443584, 0.04444385165228479, 0.09659514537141209, 0.026914635710718653, 0.15693609903175987, 0.16654014497274355, 0.12636002844139455, 0.1413340749399316, 0.20208919871478312, 0.24720324323542658, 0.1410582986089491, 0.07113249717100013, 0.142695949442925, 0.1598986223219864, 0.2247582306905139, 0.24924537317166406, 0.16880157523818556, 8.841862736209746, 56.85523809925203, 65.33785781552716, 54.42259588549214, 43.0712644515499, 30.794965567127353, 45.422270374913374, 54.38770640280939, 63.666979112932765, 47.48722176398001, 1.617501495826629, 0.30414101217062245, 2.487466407399024, 3.0360804786605224, 4.340589950161596, 40.5573977962617, 61.19163797747705, 57.73847349228398, 55.280339794774214, 53.18641385724468, 54.21172926502844, 55.51135170844294, 53.48556518554688, 54.349247563269834, 47.738249532638065, 44.20862628567604, 44.47726549640779, 42.88395558634112, 39.32211006841352, 44.02622430555282, 51.7786124444777, 55.61722432413409, 51.456805506060206, 49.44184472483974, 48.12317525186847, 47.77370383662563, 50.44213541092412, 50.818243642007154, 47.97794165149812, 52.11536753562189, 54.76181422510455, 50.09811609022079, 51.95161642566804, 51.43492260286885, 52.92290902906849, 50.55749231769193, 40.55498161623555, 41.815921645010675, 41.597598598849395, 42.74296206812705, 38.39777215834587, 42.13002897077992, 43.18808048002182, 40.830939969708844, 40.964700637325166, 43.52610641910184, 41.79685892597322, 40.70958575894756, 42.55998742195868, 41.29283828120078, 41.035385670200476, 42.0180296128796, 47.94524085137152, 51.95184784550821, 53.88051256056755, 53.22116213460123, 54.52935495684224, 55.235781669616706, 55.9801886927697, 56.95678434064312, 57.61096508272233, 54.71642063510034, 49.77138657723704, 52.87696238486998, 55.45503039513865, 58.75027241245393, 54.49385358441261, 53.075351945815555, 55.12732421198199, 54.271353214017815, 58.36110268869708, 52.66821776666949, 49.57018859924809, 46.63662833552207, 49.63014594970211, 53.521556854248054, 56.111666540945734, 52.79613802509924, 48.06936817784464, 43.21923194393035, 43.187888283883375, 42.115688785429924, 41.896381224355395, 42.53226803195092, 42.38073902745401, 42.4745072087934, 40.28481268113659, 42.859974215107584, 42.60949557827365, 42.42075112558181, 42.65042551102177, 41.834843158721924, 44.64696684191304, 40.80947283775576, 41.90688925404703, 42.329889420540106, 42.75576076199932, 39.38537005455264, 43.456205860261, 46.98078101681125, 51.389560391826016, 54.82690988048431, 49.73654808536653, 50.07499371805499, 56.68466990993869, 56.18221821323518, 52.51056594233359, 42.678784247367616, 41.171397778295706, 40.81967100020378, 43.898068704912745, 51.84985837628765, 54.1607423751585, 53.906894422346554, 51.32592778052054, 45.20899541916386, 48.427151095482614, 57.24105027414138, 60.802225066769516, 61.1112529231656, 60.84015438633581, 60.44546588774651, 64.79460170192104, 66.049073742282, 68.8158195249496, 65.45783135198778, 47.390103878513465, 9.773793374338458, 2.5757876423097428, 2.533287290603884, 0.29600439232683956, 0.16253669205452168, 27.687836500906176, 76.09948835065289, 62.12933940272178, 58.24240000017228, 37.41402210727815, 36.967350436795144, 60.53449584591774, 66.91144604836741, 55.54080478606686, 10.026380285140007, 0.39462307468056684, 0.10344066957552588, 0.19389633269559955, 0.11690147025811097, 0.14280982075199006, 0.14859559254780894, 0.16903593685598145, 0.15221304440450284, 0.256677192125109, 0.20342036841377137, 0.13072168875125148], [0.017314201874297955, 0.055949132468911915, 0.020537943909725836, 0.012507780601510839, 0.0184944809805001, 0.045258298876785466, 0.016286749648110523, 0.028356133562122143, 0.024801793943850264, 0.024163769107432138, 0.04892494889997667, 0.01731655759466512, 0.03910301989244838, 1.8269642754908533, 33.48534476372504, 50.31707848272016, 44.4376064115955, 35.22039344233852, 25.859176535760206, 30.901359858051425, 44.11250075986309, 50.017456469997285, 52.05575143137286, 3.7587548744293953, 0.10766226603018661, 0.21960837315888176, 1.9034155602416687, 2.8647810124581863, 20.24532933388987, 56.43564255006852, 56.081644719646825, 53.26357080090431, 52.06705570220948, 55.43866626677975, 54.40223486192765, 53.47260959686772, 51.185357878285075, 51.65508131827078, 43.17325392077046, 36.920991943728545, 38.28783988952637, 43.96504317560504, 47.8391368158402, 50.336078443834865, 47.80243127576767, 45.60560980150777, 48.89062227741365, 47.729839970988614, 47.6084896825975, 43.61263390510313, 45.613191743050855, 49.02436725554928, 49.4068689500132, 49.7614747478116, 46.767635499277425, 48.2521741620956, 49.50723848035259, 50.749939487826445, 43.90898858347247, 35.721091839575, 37.21456566164571, 37.74145764689292, 35.86632151757517, 37.17712271598078, 39.10324181279829, 36.95436346915461, 36.99268502573813, 39.534863348930116, 37.66316321588332, 38.37337893824424, 36.594913544193396, 37.08973230854158, 37.93768205950337, 36.15241527557373, 37.774036853544175, 38.028888933120236, 41.506854564912864, 43.95861048852244, 44.2011933941995, 43.46891826198947, 48.829099901260875, 50.81152854427215, 52.181486929616625, 51.8953029571041, 51.57599849085654, 42.70748030754828, 46.0027733156758, 52.31735783238565, 51.39723647025324, 49.970337037117254, 50.86213888660554, 56.53020697255289, 56.63264751434327, 45.67846782745854, 43.54203908674179, 44.32177097566667, 48.13462072803129, 50.305291760352354, 51.55460588393673, 51.60737745223507, 48.2874951054973, 41.58762793387137, 38.58299824499315, 37.18547344207764, 38.2158604744942, 35.47163301898588, 38.17159652709961, 37.59995422055645, 38.639805932198804, 39.12593272424514, 38.89318712296025, 38.74715335907475, 38.416309279780236, 38.30842448819069, 38.43825101852417, 39.94289182847546, 37.75084387871527, 36.92462405850811, 36.72128838877524, 36.9543085559722, 37.07109320548273, 42.38384946700066, 46.19502828967187, 45.84728663967502, 47.656777981788885, 46.80068539034936, 45.75731923503261, 54.777707669042776, 51.73412099961312, 51.19859195524647, 48.34593057632447, 42.09781454455468, 39.49898935133411, 38.586995140198745, 40.12377977371216, 47.103374696546986, 48.61850784670923, 45.51136701337753, 45.12507238695699, 43.03016585688437, 42.76513914908133, 50.64572603471818, 54.15621203760947, 59.27743896361321, 57.40295394774407, 59.67273150720904, 59.341620706742816, 60.10901281910559, 56.10979949274371, 31.226891086947536, 3.140677098304995, 0.2571477692934775, 0.4124934238291556, 0.04987593980566148, 0.028631352564139713, 20.817524694627334, 64.72958057157456, 49.60238733599263, 42.749065276115175, 29.458619932974543, 30.737298880853963, 49.036887461139315, 49.33368536733812, 37.11420397604666, 5.361772650672544, 0.1625349453740543, 0.07872150204474888, 0.17255099340071603, 0.024068255180252657, 0.03773459533770238, 0.06332395065035071, 0.024944198197655143, 0.025379148447105003, 0.10732726344177801, 0.050001168368203994, 0.06396743003278971, 0.041103129906039086, 0.080772265791893, 0.010482303501527396, 0.0235551122515913, 0.03396205664161713, 0.029329969209708998, 0.1332166072942557, 0.0348079479449699, 0.005280616770183007, 0.04477673600758276, 0.04533063289859603, 0.03576133287541809, 0.025786622953150543, 2.6884037929196514, 39.752974587102095, 58.188553702446725, 49.93573780982725, 39.197202190276116, 27.514954113191177, 38.99106202587005, 50.50459915591825, 54.47130387829196, 55.64969370442053, 4.020546852580963, 0.12291877680728513, 0.34504014818418416, 2.1595187533286313, 4.826937865826392, 22.515942358201553, 58.667847725652884, 58.12204599380494, 56.00504083018149, 52.49609631876792, 56.65063942632368, 56.18905098207536, 55.34729857598582, 53.439618541348366, 52.962411219073886, 45.54276558660692, 38.93299918020926, 39.78143922744259, 45.78452087217762, 50.08884360713344, 52.125954012716974, 49.70620070734332, 45.95065286082607, 48.58290057028494, 49.11050642690351, 47.30915792526738, 45.629877505763886, 47.99265053964431, 51.258847405833585, 52.80291980312717, 51.26282861155849, 47.4644680946104, 47.24005752994169, 50.47301230892059, 52.32230394117294, 46.14404924454228, 36.13579619315363, 38.6551227877217, 38.36358870229414, 36.65996605350126, 39.161190909724084, 39.905919567231216, 39.48494334374705, 38.26836139925065, 40.17834778754942, 38.25503318540512, 39.47789876691757, 38.40171806273922, 38.55633789493192, 38.934536749316806, 37.03708233371858, 38.545472929554606, 39.758732626515055, 42.977429589917584, 46.91437528979394, 46.63816982699979, 46.20625803547521, 50.68258062485726, 53.35182805215159, 55.73021996405817, 53.40340329754738, 52.84035882642193, 45.2454734617664, 46.55907131010487, 54.09597227650305, 53.62607625222976, 53.673556543165645, 52.26015790816277, 54.652144755086596, 58.57270671475319, 51.964301370805316, 46.1534119421436, 46.91488912028652, 48.75886594095538, 49.72529872771233, 52.260640359693966, 52.462548286684104, 50.2581605603618, 43.67589389124225, 40.8204476294979, 39.3017529672192, 41.44876034029069, 38.6835874280622, 40.30860185623169, 38.359458446502686, 39.69465286500993, 41.45190215879872, 38.83560280646048, 40.60221087548041, 39.587175999918294, 39.828429222106934, 39.746930214666556, 42.63124904324932, 41.203933838875066, 39.84031008135888, 38.522299566576564, 39.075722463669315, 38.77084447491554, 44.48256461851059, 47.70735302279073, 47.52940685518327, 51.966031136051306, 48.23635916556082, 47.905154228210456, 55.063475870317035, 54.27109825995661, 54.04248291446317, 49.72262367125481, 44.547585748857074, 39.941028702643614, 40.46536330253848, 41.126937712392504, 48.03295681553502, 50.046552611935525, 47.983707535651426, 46.67919389663204, 46.18068810432188, 45.38377231167209, 52.55548884791713, 57.14926681210918, 61.83368290624311, 58.96892101533952, 62.3185976859062, 60.27366999656924, 59.634041247829316, 57.77489269933393, 32.6754008185479, 4.715092951251615, 2.0663793769574936, 0.8717156982710286, 0.22118666750048438, 0.04790569189935923, 23.074093672537035, 70.13655216463151, 55.33496664416406, 49.11897482410554, 32.985054292986476, 32.19533016604762, 56.7044621898282, 57.53642435996764, 45.7642343736464, 6.871825350869087, 0.26340606412099254, 0.09293383498105312, 0.030866350880974246, 0.0447219951949533, 0.023936752357610294, 0.07649185676728526, 0.013745550775990613, 0.026135543443923517, 0.05546772281729406, 0.06730924345432751, 0.02047256596626774, 0.1646764215923125, 0.15045231388461205, 0.17111917507023583, 0.11042320094401799, 0.1023509631293916, 0.10776749586746578, 0.2866290083094951, 0.13083916067356063, 0.18275401284617765, 0.1704156458858521, 0.16485844408312153, 0.19924977043223, 0.12662504123704088, 2.80995314159701, 45.48126674467518, 68.49614635590585, 57.15329900864632, 48.37759587072557, 36.50822524101504, 42.09710067318332, 56.542103521285526, 58.54215929585119, 61.37152179594963, 5.053771964965328, 0.2355323840052851, 0.7085473054359037, 5.362123212506694, 5.621108489651834, 22.46115076926447, 59.61114245076334, 59.67180975021855, 57.28594180076354, 54.682150886904815, 61.03246035114412, 58.516718802913545, 56.87331238100606, 54.669975849889944, 57.00127970787787, 47.64277904264389, 40.55432658041678, 43.0527469419664, 48.226619920422955, 52.7485949762406, 53.85261274153187, 51.384943762133204, 48.00648081687189, 49.337470454554406, 51.298137787849676, 47.51691410618444, 47.12612444354642, 49.90810471196329, 54.975818741706114, 53.976030119003795, 52.29126230362923, 47.674750281918435, 50.24275741269512, 53.17058709359939, 55.62976414157499, 49.07013347071987, 37.82303902410692, 41.783028648745635, 39.958761738192656, 38.76621215574203, 41.376349464539565, 44.013096132586085, 41.693320120534594, 40.487261895210516, 42.64726015829271, 40.0641401352421, 42.80633188063099, 40.99324764743928, 41.15170748003068, 40.405303970459975, 38.95754929511778, 40.76186310860419, 41.3600637835841, 44.92962068127048, 48.563998668424546, 48.17993194826188, 48.07433782085296, 53.646547102159076, 55.59286640536401, 57.433658261452955, 55.291247906223425, 55.601389715748454, 45.997882120070926, 50.386943740229455, 57.35457543403872, 55.286490071204405, 54.82112830685031, 54.29735852826027, 57.6556565684657, 55.63125856461064, 50.809182966909106, 46.63746380036878, 47.83526543648013, 50.92779936329011, 55.271243818344615, 53.62463282000635, 55.63615760495586, 50.0197079104762, 44.660079325399096, 42.89464012269051, 40.60280315337643, 43.455664573177216, 39.37927076893468, 41.404178680912146, 40.54028841757005, 41.69719542226484, 43.181518354723536, 41.212531674292784, 43.44121848383258, 42.408603545158144, 41.78999870054184, 41.33590982806298, 43.92167352860974, 43.1957761702999, 41.16161930945612, 39.84004336018717, 42.67634845549061, 41.353725233385646, 46.21972745464694, 51.215418923285704, 49.625290055428785, 52.00169724802817, 50.91425149671493, 49.10027688549411, 55.09277989787441, 54.858559485404726, 59.04980028829267, 53.472276195403076, 46.74892579355548, 42.692893012877434, 42.970298720944314, 44.53060580838112, 50.73066103842951, 54.58170290916197, 49.40059315773749, 49.75312794408491, 48.1899889053837, 47.51234062256352, 54.86908712694722, 59.23519895922754, 66.00684550500685, 63.11030849333733, 66.25608075049617, 63.15596880451326, 61.75108955752466, 58.79607392895607, 34.625283595054384, 5.017346384063845, 2.6668155577874955, 2.734717178729273, 0.4523736322599073, 0.1999192393475002, 24.530220647012037, 76.70969932310044, 62.72799899501186, 54.97728570815056, 41.14383136072467, 44.91586885144634, 66.49162692408409, 68.55312270502891, 55.01604264782321, 8.593588471412659, 0.5075141589247412, 0.23267205684415757, 0.29621828407529865, 0.16968102885350106, 0.2604529177469592, 0.19028045898002965, 0.10386271507389123, 0.15945979183720005, 0.15803192652040915, 0.28227735310792923, 0.10939862729320604], [0.03563918398633119, 0.09768901933585444, 0.050065531245162415, 0.0022325264862663443, 0.06660900844801819, 0.03304458591305921, 0.07765940540740568, 0.07162789558811535, 0.017197875253435586, 0.011309567377001289, 0.0633627146993193, 0.0378796196122083, 0.023101164936839093, 0.28305330824467445, 22.057785987854007, 48.51613790758195, 43.40814505853961, 30.915682392735636, 23.292242173225652, 24.750585286848008, 40.0791863472231, 46.6335924210087, 55.15567510358749, 7.5479125303606835, 0.02583736478681526, 0.34631841185112155, 0.9072405436346609, 2.9563068237996872, 9.397070311730909, 43.679176915076475, 55.49213209459859, 54.77097295945691, 56.29960298538209, 53.35001199476181, 48.73278610167965, 54.754957922043346, 53.96694590968471, 50.632574327530406, 40.22751077528923, 34.921320561439764, 43.65771762786373, 50.311763671136674, 48.04262545800979, 44.84853352269819, 45.58651178113876, 48.22191699858635, 48.93939302813623, 46.51366987536031, 47.101946953804266, 48.09547547371157, 44.0220901273912, 49.50331611018027, 45.98603656215053, 47.63674643731887, 43.70428792891964, 49.24163126176404, 48.61980222886609, 46.10670043576149, 41.81770240106891, 36.47496746432397, 36.97848604571435, 36.62083648866223, 36.26988633986443, 37.20979605951617, 37.28838074591852, 39.81177091598511, 37.5024676322937, 37.92075703220983, 38.63419694285239, 39.05918575102283, 36.124895926444765, 36.67017598305979, 36.11098327944356, 36.84790642030778, 37.793362371383175, 39.80660515446817, 43.41762934961627, 42.41159239122945, 39.56661101310484, 39.95877742767334, 41.45159621392527, 44.038489557081654, 48.328468184317316, 49.66809488111927, 45.64990512786373, 45.032551519332394, 50.68350630421793, 53.25474939038677, 55.43443010699365, 47.50268766956945, 55.357265318593676, 58.149173105916674, 39.32335738212832, 43.99734389397406, 49.10437968469436, 50.05030632019044, 49.42298596905124, 50.44164511465257, 51.98567044350409, 49.95433376681421, 46.42296114275533, 38.60684233327066, 37.991861758693574, 37.281065525547156, 38.898756888604936, 38.84915459540583, 36.80720006265948, 38.031524765876036, 37.84305487909625, 36.75664855587867, 37.780485230107466, 38.00963794031451, 37.464306892887244, 38.4414202936234, 37.92298101609753, 41.64992693931826, 39.18455646884057, 38.46801788576188, 38.40660533597393, 37.72736457086379, 38.125579280238, 42.7507479729191, 47.4400709521386, 48.73925801246397, 48.665693959882184, 48.81616784680275, 46.240476792858495, 46.17664414067423, 51.26236577187815, 55.23538158785913, 55.523299247987815, 50.957605454229544, 44.085569766259965, 39.597370239996145, 38.32533774837371, 40.004653469208755, 44.76535181845389, 45.392244631244296, 44.17335633308657, 44.228053785139515, 42.08190541113577, 42.028365058283654, 46.91868989698349, 53.30887809876473, 57.780823323034475, 57.85496396403159, 59.89585945683142, 63.24966638318954, 55.43179819660803, 23.764770107884562, 1.911949779718153, 0.5431272269737336, 0.9314372775054748, 0.04494034557513172, 0.04534880450415996, 20.777826386113322, 65.93522302566036, 49.368331663070194, 47.94378565203759, 27.96365757142344, 23.997019529342655, 46.80287407290551, 49.926139770015595, 33.35478082779915, 2.140348659407708, 0.04044871461848098, 0.10766172210776037, 0.0989659270271659, 0.05785213700766045, 0.0768856029777277, 0.010092111939053622, 0.059604854247863256, 0.03634418788996916, 0.040350957968903166, 0.06996300266755205, 0.00958889942511075, 0.014465848667426937, 0.052162708429199074, 0.05273364311564834, 0.04340685971622025, 0.014981507237309651, 0.030765062566065503, 0.09363909552414572, 0.01384495355699572, 0.023295065620914105, 0.03452218565789442, 0.09439112573501565, 0.07498823301566225, 0.05328433775913812, 0.41386940967171426, 27.41352358172017, 55.58708090935984, 50.17631638434626, 36.97627382893717, 26.4032857648788, 29.093623776589673, 49.71337080001832, 51.87676583566974, 60.01402085827243, 8.222838688281275, 0.08842087230615078, 0.42554933938287925, 2.178191931978349, 5.476645144724078, 11.256334570146377, 47.399250845755304, 57.08698349614298, 58.50239430704425, 57.130168791740175, 55.640091742238695, 50.145372806056855, 56.371688304408906, 55.10618263675321, 53.265849697974424, 41.906916710638235, 37.93224565444454, 44.21468634759226, 52.72887722138436, 49.97493013258904, 47.75469995314076, 45.82036741318242, 48.155479892607666, 48.362577115335775, 46.43481062304589, 47.423695056669175, 48.287232306695756, 45.98748783911429, 50.72839783084009, 47.00890833331693, 48.02165646706858, 45.20699893274615, 50.82048723774572, 51.4335693851594, 48.78577340033747, 44.41138928936374, 38.38839769363403, 39.266196681607155, 38.126979566389515, 37.710761177924375, 38.998153671141594, 38.7826664986149, 40.39587067019555, 37.93411662501674, 40.27804267021918, 39.606234796585575, 39.98890123059673, 39.93230142901021, 37.98596251395441, 38.29786546768681, 38.473983810793975, 39.15960627217447, 43.01478624343873, 45.17904812289823, 43.60800158592963, 41.85715360026206, 43.181734085083015, 42.919664844389885, 47.67047489843061, 50.03982182471983, 53.13264600692257, 47.80347854860368, 45.56997114612211, 53.31102755761916, 54.24759149551392, 55.07630202078051, 49.43286641951531, 54.89360586289437, 61.57533991721369, 45.3055053372537, 44.97379833652128, 48.533510085075136, 50.703298584107436, 52.177046806581565, 52.72910471885435, 54.586182255898755, 50.65646548424998, 48.739210944021906, 40.92382954012963, 38.61608343739664, 39.28286283246933, 40.53717797802341, 40.00730106907506, 38.397556427986395, 39.908312213036325, 39.276947898249475, 40.34236169630482, 38.98145221894787, 39.03484744410361, 40.354211176595385, 39.22085016004501, 39.24168579040035, 42.702644025125814, 40.67382158771638, 40.421597496155776, 41.10384279681791, 39.40018484669347, 38.7293654103433, 44.84501907902379, 49.758517280701675, 50.19870527328984, 49.324424651361284, 50.33170107872256, 46.38875807485273, 48.390367108006636, 51.170845108647505, 58.14450940778179, 55.94316151834304, 52.83899776397213, 45.3315184962365, 42.57378632022489, 40.490866553398874, 42.59341778293733, 46.599726676940925, 47.771876012125325, 46.613043123675936, 46.25377755011282, 44.70166429396599, 44.98104687659971, 49.44567688049809, 56.09223511911208, 60.338110616130216, 60.18422818952992, 61.375671663591945, 64.20370448020198, 56.241026309228715, 26.725177034254997, 3.1645184899530108, 2.3240528664281292, 1.6198881355024155, 0.11472451650807935, 0.03635005995390877, 22.291102293998968, 72.04931951338246, 54.041082628311656, 50.99737044303648, 32.3292104659542, 32.097584701353504, 55.1858812762845, 55.11595718322262, 40.86702577529415, 3.0946895143678113, 0.06682031848017247, 0.06286794830474161, 0.06604892922745598, 0.05186476917456716, 0.004289611176993217, 0.019721910883221897, 0.044166884054580045, 0.007847461871983064, 0.028678099249279308, 0.0427486599543162, 0.028290089122169924, 0.10740119858735031, 0.10816087435570457, 0.09045300479497641, 0.09760943812228019, 0.3321379711551051, 0.0894030429903538, 0.1565635198306653, 0.1259459119530455, 0.12278540856054715, 0.15203509750145097, 0.23058664294019823, 0.18028696458185875, 0.152390684872385, 0.49010444312326373, 30.931599370894897, 64.15248617049187, 56.25732767966486, 42.73103414043304, 33.61416324492424, 33.27094408773607, 52.03280556586481, 57.50292731869606, 66.23712785782354, 10.050258694156524, 0.16140786149809438, 2.032347790175869, 2.9908972257567994, 5.967460149718869, 11.668032426987926, 49.288299622074256, 57.9603619729319, 60.69746248183712, 58.81720373707434, 54.730270524178785, 52.24841040949668, 58.475463313441125, 57.460059735082815, 56.31038950335596, 44.61052802301223, 40.591757758971184, 47.58141356129801, 54.885980775279386, 50.986074016940215, 47.616287354500066, 46.78901633908672, 48.786102879431944, 50.31166953425254, 49.05120803463844, 48.88346787421934, 50.0771314097989, 47.88218482848137, 52.66897478411275, 48.092871019917155, 46.081679636432284, 46.80916947703208, 51.59777156768307, 52.87538559206071, 51.82575148920859, 46.41112342957528, 40.76612280261132, 42.191421908717004, 40.832807017910866, 40.674641363082394, 40.876717951989946, 40.79743116132675, 43.23167762448711, 40.7531476020813, 42.57384515577748, 43.41369521233344, 44.08505985813756, 41.63892076861474, 39.34915873312181, 38.09027794868716, 39.523543388612815, 41.11378600520473, 45.1136935910871, 48.18340324586438, 45.095764437029445, 43.748547953944055, 44.079423412199944, 43.92899659372146, 48.15813141484415, 51.894863651644805, 54.467734521435155, 49.306150328728464, 47.532552596061464, 53.892346351377434, 56.74521169354839, 59.03213393303656, 52.5356573443259, 55.500357304849935, 57.82726810824487, 47.38423993510585, 47.986402203959805, 52.72033037677888, 53.99204515641736, 53.052786550214215, 53.0406193579397, 55.30987131980158, 52.845532432679214, 51.4860781546562, 44.08755448556716, 43.5729669755505, 41.147671361123365, 41.70059611720424, 43.589499765826815, 41.48131601272091, 41.762330301346324, 40.973023906830825, 40.926018222685784, 41.814552737820534, 40.1171431233806, 41.821432575102776, 41.828794863916215, 42.06727104802286, 44.162962052129934, 42.60152532208351, 42.68091409437118, 44.843728619237105, 41.58299169232769, 42.61308454698132, 47.085347483235026, 53.12091419773718, 51.858385609042266, 51.26099686468802, 50.83775743361443, 49.78323997989778, 49.70486710148473, 51.58608682693974, 58.82332655691332, 59.1368180705655, 56.54315079412153, 47.543496008842226, 44.63989873086253, 41.61074638366699, 44.13724699328023, 49.224584640995154, 50.2975921477041, 48.749232599812174, 48.32994299550211, 46.6665756317877, 46.93058644571612, 51.99022039290398, 58.75519106465002, 63.93174302193427, 63.03965091705323, 64.58816343738188, 68.85513736355689, 58.863173915493874, 29.266961159244662, 4.370204825555125, 3.058410777199653, 2.5400082718941475, 0.4173579902177857, 0.14637496412521409, 23.809285086970178, 80.61796465227681, 60.75574105785739, 62.92253678844821, 39.792645439024895, 39.256049509971376, 63.15529023447345, 65.27728465295607, 53.89943015190863, 4.578710669471372, 0.21071208520762383, 0.23988635279238227, 0.19472317139227546, 0.1970060980848728, 0.18136691872871694, 0.13325239892207807, 0.18548998861543595, 0.18279484533254178, 0.10939218449376284, 0.1255853909758791, 0.15407905072694825], [0.0647861558583475, 0.035690584655610785, 0.08569312432119924, 0.024339124718080127, 0.06107133039603792, 0.05921170175556214, 0.1361307138276677, 0.02864131170715536, 0.06545800730706224, 0.045662927366192305, 0.02066775176283573, 0.06934211138756045, 0.035513637497300105, 0.025448337677986394, 7.294764230328222, 43.20021237096479, 45.48084705106674, 37.34235648185977, 25.532856910459458, 34.147397702740086, 43.2848531969132, 45.51151214107391, 58.53564423899497, 11.055157184600832, 0.09655785987213736, 0.2680636335524821, 2.392372464941394, 2.4747540056705475, 2.1660078244824565, 28.28196575564723, 51.95925328039354, 55.6559028164033, 49.28509504564347, 44.5458246046497, 44.668939959618356, 52.74823804055491, 50.42643808549451, 45.57990258739841, 34.82915662950085, 45.748007528243534, 51.99158930009412, 51.315576645635794, 45.12791610533192, 47.84412999306956, 48.88185970244869, 50.53051425564674, 49.965751786385816, 50.121536562519694, 47.920333800777314, 49.64795351028443, 44.93293508406609, 47.138797621573175, 49.30348703938146, 45.73358105074975, 49.24895040450558, 51.42273972111364, 47.515023523761386, 43.76355494222334, 36.061035817669286, 34.987192846113636, 37.15394543063256, 37.36403542180216, 38.039746053757206, 37.47965120500134, 37.41685798091274, 38.59306304685531, 36.68390820103307, 37.120099298415646, 38.442342050613895, 36.81136169741231, 37.73986516460296, 36.07542699383151, 38.13243950566938, 37.56748876264019, 37.40817385335123, 43.71257589709374, 46.08265238423502, 47.61624813079835, 48.88818648553664, 46.83184077662807, 40.6067176788084, 38.270918784603, 37.14830506232477, 38.476074434095814, 39.17726478269024, 48.912501258234826, 53.10825670919111, 51.58472184211978, 50.78840224973617, 48.03047003284578, 57.06211174688032, 40.371830463409424, 47.377697421658425, 52.54712243233958, 48.636001617677756, 51.888925183203916, 49.37520757798226, 50.55070269492365, 49.87690225724251, 46.495344561915246, 43.03213488671088, 36.93933294665429, 36.9331826702241, 39.06168037845243, 38.98139338339529, 37.727058625990345, 39.02278223345357, 39.99660476561516, 38.27042848833146, 38.00901428345711, 37.135980975243356, 37.80370566152757, 37.40981732645343, 37.89974881756691, 38.659519764684866, 37.234769790403305, 38.10837576466222, 36.54766467309768, 36.66237831115723, 35.363367757489605, 39.60933739139188, 43.245825613698656, 47.823949398532996, 52.11499491045552, 49.41501179049092, 48.54042522368893, 50.56539197121897, 49.83818846364176, 46.1896546425358, 48.86690370498165, 48.362326083644746, 51.72032210134691, 51.79225444793702, 45.96275729517783, 39.78223546858757, 39.99609877986293, 41.14478057430637, 39.548987803920625, 42.39935459629182, 43.457872867584236, 41.15333134128202, 42.38632448257939, 41.37547477599114, 45.9347790287387, 50.3878301958884, 56.236782304702274, 57.31400243697628, 62.02804811539189, 55.66805824156731, 17.005612388733898, 0.9653967294481494, 2.139246963685559, 0.7498930707093209, 0.03881017129207331, 0.0610826570059984, 20.272024985282652, 65.749130095205, 50.56505072501398, 49.34018865708382, 38.22512903521138, 35.816785904669, 53.51134300231934, 56.7520679966096, 35.44359591699416, 1.6157592280257134, 0.18428684753035346, 0.030385180631832733, 0.04237519209122947, 0.07132634805936007, 0.008934299318840908, 0.07036581169813871, 0.02542144799184415, 0.054121610573342735, 0.04191044868240434, 0.05011162675556637, 0.08356189835936793, 0.0289848925650961, 0.05143805820074293, 0.04300337652826021, 0.03367542867518721, 0.11295312970516183, 0.08048964063486747, 0.03487773089399261, 0.043995460390203425, 0.033676581637513255, 0.0685230331615575, 0.06582007578183567, 0.01243093719465598, 0.04757925034350446, 0.03600079663878968, 10.555022628076616, 51.67918820534983, 51.17923113607591, 42.238431515232215, 26.11414432525635, 32.52107320293304, 45.350651817937056, 50.41542799242082, 62.013150953477435, 12.38252353283667, 0.08770835691041524, 0.13981182759086933, 2.656354106241657, 4.064941218783779, 4.310414666129697, 32.165202440754065, 53.98138807665918, 57.231969987192464, 49.973808334719756, 43.714031096427675, 47.05712602984521, 56.52344872874599, 51.66197292266354, 49.14811411211568, 36.66444147786787, 46.201912049324285, 53.545338184602805, 52.300970169805716, 46.20272397994996, 48.96954036528065, 49.93041123113325, 53.6477198908406, 50.704655724187056, 51.38232754122827, 49.44213105786232, 50.688005262805575, 46.35364893944033, 47.65689173052388, 48.44872805380052, 48.65568407120244, 51.1978780838751, 53.541702147453066, 49.853022867633456, 46.697982049757435, 37.911774804515225, 36.775197444423554, 38.8175206799661, 38.557687190271196, 38.623257452441806, 39.00796351894256, 38.951151909366736, 39.61607602334792, 38.18428931697723, 38.624308647647986, 40.28930771735407, 37.94937856735722, 37.85972887469877, 38.70716479516799, 38.635879639656316, 38.852692573301255, 38.836148015914425, 45.37200520115514, 48.272845052903705, 48.91717672348023, 49.512294415504705, 46.158679685285016, 43.881202513171786, 40.391422702420144, 40.78848815733387, 41.303989579600675, 41.43175294322353, 49.99255726414342, 55.43393981072211, 53.85162038187827, 52.697576707409276, 47.326224157887125, 60.3170592554154, 45.371616886508086, 45.00725223172096, 54.722049236297615, 50.338416176457564, 54.691705780644575, 51.214697207174, 51.71842367418351, 51.14919362529632, 49.134676071905325, 44.878978959975704, 39.12844696352559, 38.89733699060256, 42.511114689611624, 39.39490925881171, 40.410724686038115, 40.03144325748567, 40.86226794027513, 40.41392141772855, 40.0366953111464, 39.82662493182767, 41.10378003889515, 38.66982383112754, 38.859874433086766, 40.93301180870303, 40.01569886361399, 39.195723456721154, 37.50675870526222, 37.87908577149914, 38.3032508819334, 39.9249783638985, 44.73838944588938, 49.32278902299943, 53.773753489217455, 50.34891243903868, 49.952435339650805, 50.18505934746035, 50.10403494681082, 48.14860790006576, 51.410046931236025, 49.814713078160445, 53.81155729293824, 53.8581628953257, 47.90122009092762, 42.11373544508412, 42.14671081112277, 41.80523318629111, 41.57308770764259, 42.89993924479331, 45.993124285051906, 43.68294631281207, 44.139392529764486, 43.39073757971487, 48.7759360959453, 53.93319391435193, 58.21798324584962, 59.344546794891365, 64.62413941660236, 56.3227802707303, 20.591307878494263, 2.032664766715419, 4.267847634130909, 0.6722479145373068, 0.05635521652537489, 0.058344547681870966, 21.93755945851726, 71.58261237605926, 56.0350626514804, 55.47745458541378, 37.92710734951881, 36.32483090123823, 60.20854688459828, 63.55595250283519, 43.44437206945112, 2.8931534770996343, 0.13387433974252594, 0.04933547243596085, 0.03801700599010914, 0.05377170374436725, 0.01095203031229997, 0.06838108473006757, 0.05530876340344549, 0.07683780675213184, 0.03677976250107731, 0.0097730353609809, 0.07802920370933511, 0.11205335177721516, 0.13975881430650913, 0.23865232304219278, 0.1122407598661319, 0.19383553595792866, 0.17581109588425006, 0.2612657063911038, 0.07474972686219601, 0.15970307071843456, 0.1703381024661564, 0.17954612691556254, 0.1602293118353813, 0.09002743529215937, 0.1325166634013576, 14.120234520204606, 60.26657835129769, 59.15064050305275, 50.4334238267714, 37.78735722264936, 46.00766843365085, 57.56967821428853, 55.33475483617475, 69.35101124548143, 14.828848934942677, 0.1697117643010232, 0.4799848200092393, 7.394402728926751, 6.036017296775696, 2.907359076123084, 32.23374782070037, 53.23216438293458, 58.64239154323455, 50.96750943891464, 45.565413351981874, 48.05523195574361, 58.58954937227311, 54.31147121614026, 50.93996263319447, 37.501671391148726, 51.20938631796068, 56.71409160860124, 56.176295434274984, 46.41441822052003, 50.20491046290244, 51.24835506562264, 54.01408103204543, 52.625640438449004, 52.880759239196784, 51.152484493870894, 51.23363833273611, 45.950393984394694, 47.59906422707343, 49.370755687836684, 51.13310014047931, 53.006071121461936, 56.12119790046446, 53.05386520201161, 49.716928389764604, 39.36280073658113, 37.8196697081289, 39.972870503702474, 39.979660126470755, 41.35671407945695, 40.751421759205485, 40.45143496605658, 42.797090776505016, 40.34163213545277, 40.99868797486828, 42.09212318543465, 39.91699241822766, 40.61964581089635, 39.08116671346849, 40.79708991512176, 41.48757219314575, 40.6268512049029, 48.219359613234, 50.72611893376997, 51.251783217153246, 51.58405503919048, 50.18274907142886, 44.98938191321589, 42.30490000017228, 40.544634403720984, 42.461355501605624, 43.35549116134644, 53.60682133705386, 56.048802714194025, 55.99423862272694, 53.19641982355426, 50.80218938089187, 56.00964961513397, 48.74118389621858, 51.35569464775824, 54.29418140842069, 53.35553469196443, 56.047571089959916, 52.46823572343396, 54.27348306102138, 53.837076233279326, 50.48143363768055, 46.90062738233998, 41.4164831561427, 40.53843705884872, 44.109296183432306, 41.15248803169497, 41.669625082323634, 42.93434235357469, 43.92141465217837, 41.93826429305538, 42.492016669242616, 41.84536687789425, 42.95049075157412, 41.26402454991495, 43.232583691996915, 42.34628885023056, 41.85173288468392, 41.409265995025635, 40.24829149246216, 39.60362642042099, 41.264212823683216, 42.48042214301325, 46.7482001550736, 51.66913124822801, 57.14100237815612, 52.49642579786239, 53.39555855720274, 53.18345246776458, 51.275391963220414, 49.55609160084879, 51.061556108536266, 50.96141015329669, 55.480706230286636, 57.12249663568313, 50.48097472037039, 45.5080133868802, 43.75650644302369, 45.39104438597157, 44.710748503285075, 46.70426568677349, 48.72313707105575, 45.87526098374398, 46.44116878509522, 46.51230881291051, 50.149506984218476, 56.279908764746885, 61.274784380389804, 61.67540350267964, 65.69772351172664, 58.66138365960891, 22.345931145452685, 2.306308063768572, 7.45464199973691, 1.761763819283055, 0.23888046402604352, 0.1684895629483846, 25.227582762318274, 76.71286859819966, 62.570731562952844, 59.60838894690237, 50.14983646331295, 49.304561768808675, 68.76158099020682, 70.9839645508797, 52.82144123508085, 4.783763847043438, 0.29107241020087277, 0.10132254371719976, 0.24217785966973154, 0.22583602446942563, 0.11428610737165136, 0.1870508314741235, 0.09852711186413804, 0.16093247329756138, 0.17119083493467302, 0.13553837464461405, 0.1956194176548912], [0.0216344666231664, 0.0877616306646697, 0.02937446934201064, 0.05570804076870123, 0.06790692227021342, 0.03416540318979852, 0.06321434262058427, 0.014125146384861682, 0.07078106965749495, 0.03218934067615098, 0.09692971128970386, 0.04239752738466186, 0.06807641922346047, 0.08475114260950396, 6.625639748188758, 46.027213604219504, 51.19783101543304, 46.48290280372866, 28.908354543870498, 20.521495572982296, 38.751495422855506, 45.775872045947665, 55.09067358509187, 17.247583404664073, 0.07870836363684747, 0.11129170716289552, 2.532524144457233, 3.9365439020818283, 1.1017947619961155, 9.59577758466044, 39.80215718669277, 54.96930760722007, 54.61796129903486, 55.83842639000186, 52.73900085879911, 51.90255541955271, 44.03453973031814, 35.291482479341575, 42.359220904688684, 51.75718453622634, 48.96949329683858, 46.83311946930424, 48.37457172332272, 51.656913065141254, 50.76139280872961, 49.81612905379265, 48.89677255384384, 50.1102009127217, 48.72355284229402, 50.185577100323094, 47.91708215590447, 47.15749556018461, 46.52714321690221, 49.48040946837395, 52.018398700221894, 46.89667755557645, 46.06382108503773, 37.75540951759585, 34.5744026091791, 36.50105514834004, 36.76474040554416, 37.79512743796072, 38.186415241610625, 36.35986158924718, 37.56492353254749, 39.27096628373669, 36.60115011276738, 37.30629813286566, 38.15325160180369, 39.726408373925, 35.12062795700566, 38.54675554460095, 35.56950007715533, 37.31384869544737, 38.339026820275095, 45.16306446444604, 46.07886729701873, 51.373462984638834, 52.83331817196262, 60.53176979864798, 54.573846401706824, 48.09342799648162, 40.243180644127634, 39.32349858745452, 42.15893291657971, 53.15941618334863, 52.09544189514653, 54.152779963708696, 48.216045210438395, 50.97000014397406, 47.19332641170871, 43.85955495219077, 52.36492441546533, 47.75237790999874, 53.28812091581283, 50.80656674600417, 51.14587922250071, 46.62053877307523, 48.694805791301114, 45.93515949864542, 40.91641626050396, 36.913260952118904, 39.38781761354016, 36.92102332268992, 38.76183086825956, 38.64799976348877, 39.58295160724271, 37.593360716296786, 38.09973478317261, 39.851402544206195, 39.846609407855624, 37.027190116144, 38.20467779713292, 36.66135849491243, 38.459867200543805, 39.990411343113074, 38.63996674937587, 38.27315845797139, 36.528954967375725, 37.994674098107126, 38.19719391484415, 41.29789813872307, 49.33655261993409, 50.11740630672824, 50.48656409786594, 52.44053202290689, 52.11562641205327, 51.6683820755251, 52.667182260944, 52.38904699202507, 51.81074450092932, 51.115276890416304, 51.94632907067576, 50.89593010564005, 47.378627023389264, 44.87493499632805, 46.73446793710032, 40.91707129632273, 38.03861641114758, 39.359207845503285, 41.791979497478856, 41.285746635929236, 42.84909748261975, 41.18063888242168, 45.82828275619015, 55.1918315118359, 57.609600097902366, 60.0566295654543, 54.3657450522146, 12.813253710346839, 1.2468703643929575, 2.3036523740137778, 0.6098908089822339, 0.12558185164966892, 0.08178803709245498, 18.59828687483265, 63.43249590166154, 49.155998076162035, 48.22420374039681, 31.991751309364076, 28.721818385585664, 50.41199591852004, 58.962617766472604, 30.673038690320908, 0.9929106240310978, 0.06741558411909689, 0.0273438920116713, 0.01469552853039556, 0.0237493691665511, 0.03891343994426631, 0.04821372819283316, 0.05897802195601887, 0.12150326848871286, 0.020083569500955845, 0.056896051617279175, 0.04256433153885507, 0.020644196474383918, 0.017474952018669537, 0.040592241191094926, 0.058290113304411216, 0.0665629972072859, 0.02000287171423195, 0.04263681111737125, 0.09341977221230346, 0.031147597079736092, 0.03136606237310315, 0.041994729845394055, 0.02957241688554566, 0.0597634497699478, 0.020252106929077737, 7.916087767770214, 52.02394885401572, 56.75717492257395, 51.81405498135475, 31.606282341864805, 30.207669081226474, 50.87058767195671, 50.63675165176392, 59.59924197966053, 17.21646135853183, 0.11768117922568515, 0.09447183309783859, 5.526751462490329, 6.8983091942725645, 3.152665577588543, 12.886000929340241, 42.233046100985625, 55.24243008705878, 53.17072437655542, 57.6834975519488, 54.69055652618409, 54.98695042825515, 47.12883087896532, 38.270424565961285, 42.19298301204559, 52.823014105519945, 51.61252360190115, 47.997435831254535, 48.751727227241766, 52.58019978000272, 53.11608183768488, 52.99047970002698, 51.5975832939148, 51.70286363170993, 51.4168797000762, 51.24910031595538, 49.01760901174238, 49.08949428989042, 48.85915310152116, 50.52004152728666, 54.31027097086753, 48.92070685663531, 47.38349468477311, 40.898985247458185, 36.438869891628144, 38.88682503854075, 38.12882700274068, 39.14848243036578, 40.42601016259963, 38.09499263763428, 39.15391099068427, 41.4010682413655, 39.30011341648717, 40.47355713382844, 41.12010102118216, 39.93357227694604, 38.292687939059356, 39.99908762593424, 37.945271845786806, 39.73665752718526, 40.64119923499323, 45.663558898433564, 48.86048670737974, 54.64701821727138, 55.517651034939675, 60.515656701980106, 53.76277869747531, 49.69864230002127, 41.476420894745864, 41.43205496572679, 43.21070471117574, 54.63658863498319, 54.75425974015267, 54.444753354595555, 48.45796131318616, 52.605471611022956, 51.07426458789457, 44.57157496483096, 52.8881529069716, 49.30750746880808, 53.67826338737242, 51.764076140619096, 53.749736816652366, 50.01885283377863, 50.66359243085308, 47.06347634715419, 41.75786272172005, 37.910723609309045, 40.41842429868637, 38.62809373486427, 40.414062623054754, 40.44517878563174, 40.7120450850456, 39.57670327155821, 39.722937076322495, 40.63639040916197, 40.984312488186745, 38.84277289913547, 39.75874439362557, 39.599739351580226, 39.71180146740329, 41.91631078720093, 39.861424199996456, 40.70863262299569, 37.8855380704326, 38.45586638296805, 40.213778557315955, 43.86927458547777, 51.5822389818007, 53.0228235644679, 52.81178828208677, 53.118603921705684, 53.36289698077787, 54.50545987775249, 53.67034804436469, 53.23631032820671, 51.11858344847157, 51.4573154141826, 53.89725715883317, 55.07283072317801, 50.00889393591112, 46.875920372624556, 48.67097347013412, 42.60978191129623, 40.13646079647926, 42.79822826385499, 44.11501499914354, 44.56194162368775, 45.284010748709406, 43.77572213449786, 48.9184279595652, 57.02713597205378, 60.10669469833375, 60.67860372604863, 55.95373230595743, 14.92309956781326, 2.1070237121274396, 5.236293577378796, 2.0748695923436076, 0.10438943882623028, 0.06591327803870363, 20.925811529159546, 70.43677822236093, 54.42855004341372, 54.492080673094726, 41.65784620469616, 37.53227372323313, 58.381612762328125, 68.21339053492393, 40.720082021528675, 1.4123500138521197, 0.09484003793688552, 0.045761365834022724, 0.04839276677117713, 0.028200087197605642, 0.031210554185353463, 0.059939814701436035, 0.049110935895793864, 0.034564944855388136, 0.02819350075667664, 0.05380379133707574, 0.04231940556858336, 0.16878859770874824, 0.13429357369820918, 0.24124986672353363, 0.1775530419282375, 0.13101408919019084, 0.11194399272602414, 0.15786999085497472, 0.15231373900127027, 0.1231683299486195, 0.2358383748440012, 0.1769464535097922, 0.097034152056421, 0.13882418703888694, 0.12249388146184145, 9.765805467482537, 60.62374153444844, 65.36529871725267, 57.7061531620641, 39.35454806973858, 29.210912450667355, 52.19205379486085, 57.0059512507531, 66.00179349222492, 20.54047396106105, 0.18238036112198908, 0.2836537679597255, 7.217804876066024, 8.00962600015825, 3.1597621258228057, 13.416648584027445, 43.08791099056121, 56.59040750995759, 57.477604496863584, 61.54926007793796, 56.69485238290603, 57.56706983812394, 48.6215437612226, 39.27172722355012, 46.25444435304212, 55.17487902795115, 53.46920497955815, 47.875493264967396, 49.44118968902096, 54.73178848143547, 55.370032633504565, 54.72528911405995, 53.90201499385219, 55.02511116766161, 53.89059305191041, 50.80124016731016, 49.71985055554298, 48.44484098495976, 50.4668894890816, 53.283480751898985, 54.238052291254846, 50.914443692853375, 49.63734349896831, 42.88615995837797, 37.32526279264881, 40.49099599161456, 39.8741130675039, 41.207824830086004, 43.374102807814076, 39.032329282452984, 40.17975591844128, 43.62771541841569, 40.190832691807906, 41.35828302752587, 41.31501536215506, 42.828540340546645, 39.38199289383427, 42.04488608144945, 39.92705329771965, 41.084113274851155, 42.774701887561434, 48.24252905384187, 50.5738329118298, 57.37696040061213, 58.01642440980481, 62.794793036676225, 54.575988015820904, 53.440826631361446, 43.7613780267777, 44.261174278874556, 45.125182213321814, 55.872072481339984, 56.62614030222739, 55.24846661475397, 50.47280834567163, 53.357233078249045, 49.506979603921216, 48.680379313807336, 55.1526274219636, 53.08410275366999, 55.72040619388704, 54.65209768664453, 55.002220215335974, 50.67255896906699, 53.2117445238175, 50.17205276796895, 43.989475619408395, 40.33564659856981, 43.12283969694569, 40.71208430874733, 42.52796126950172, 42.387563951553844, 43.569852613633685, 40.54699959293489, 42.62709525323684, 44.04071746333953, 43.152335920641505, 38.96947330044162, 41.33024200316399, 42.51977920532227, 40.970705786058986, 44.214753027885195, 41.112852481103715, 43.016363036247995, 40.464280728370916, 40.785777799544796, 43.039022568733465, 46.08094223083989, 55.701708255275605, 55.39137817198231, 54.46425145672214, 54.5976669557633, 56.74629034534578, 56.64010394004084, 57.13832339932842, 55.31843385388775, 53.98069381713868, 53.92738488412673, 55.409236723376864, 56.04480189661826, 53.398774900744044, 48.22107761136947, 52.25179541495539, 45.07130845900505, 41.234657764434814, 43.18141245072888, 47.52639055252076, 47.0770908940223, 47.904142256705995, 46.84627509886219, 50.16456104093983, 59.630228704021825, 63.433845197000814, 65.12343360531715, 61.147648595994525, 15.70276575703775, 4.51304970249053, 7.18205443313045, 5.197114002320075, 0.44042131232638515, 0.09776130739238956, 22.81498582132401, 75.51234091481855, 61.65585440974082, 61.89220466921407, 43.86008839453421, 42.70514649729575, 66.41621543515113, 75.23908507439398, 47.86747594033518, 2.446283236626656, 0.23935410554610917, 0.16066644160497576, 0.11621294107528464, 0.1176543431656976, 0.16424303033178853, 0.18280316504739946, 0.228231213686447, 0.2864418377078349, 0.1422352241652627, 0.17708153013260136, 0.1349118679401375], [0.0296068582834015, 0.02125093427997443, 0.06356015087916486, 0.015611238214337539, 0.05036358158254335, 0.027623230651501688, 0.02444675049534248, 0.06017918653425671, 0.08383145405640526, 0.02949634626988442, 0.07180049519745574, 0.0727338660808821, 0.004565345373139867, 0.028603624011720383, 2.794006745661459, 39.485394416316865, 53.23980908240042, 44.0139865106152, 27.653958989727883, 20.943948568836337, 34.844285211255475, 41.6970306827176, 55.73155749228693, 25.891794966113185, 0.47124400194133487, 0.03026705945000774, 1.2149995132800073, 5.7815250946629435, 1.557812582581274, 2.7750859673946136, 28.168662209664625, 55.029017848353234, 51.98822390648627, 51.34129562685567, 46.631368437121, 42.841452783153905, 34.577289473625925, 42.82671251604634, 48.48389994713568, 53.65217178098617, 49.53447934119932, 51.464258009387606, 53.45284085119925, 49.028152342765566, 47.05125424169725, 46.67451450901647, 46.68410078171761, 49.66538844570037, 49.10066912251134, 49.90960305736911, 52.17908643907117, 45.93344934525029, 49.88148750797395, 51.01067120029081, 46.45335166685043, 47.330487774264434, 39.47864793962048, 36.84608251817765, 35.30287304232198, 35.440407030044064, 36.890934821098085, 36.55240681863601, 37.07486260321833, 37.0044207572937, 37.37745385016165, 38.13971550233903, 38.580664434740626, 37.18992925459339, 37.767992481108635, 37.88844846910046, 36.20940731417748, 37.02212633625154, 36.28721929365589, 36.817770850273874, 40.140504760126916, 42.09275076466222, 47.64988637739613, 49.85281105964415, 51.170562697995095, 46.48908445912023, 61.9042855693448, 51.45749192084036, 48.65151066933909, 44.9160296686234, 40.88059717609037, 47.05775753144295, 50.9631948317251, 52.88505815690564, 53.774985113451564, 48.63857861488096, 46.61378052926833, 47.258618185597086, 51.623855329328975, 51.539642041729344, 52.622024013150124, 49.43702020952779, 48.68446642352689, 46.556015783740634, 43.71315640787925, 42.31312128805345, 38.40368317019555, 37.773338671653505, 38.26373300244732, 38.87655627342963, 39.22182683021792, 37.95155548280285, 38.149266473708614, 38.14581871032715, 38.272401440528135, 38.88523255625079, 38.28949905210926, 37.57403127608761, 38.370460694836034, 39.14089656645252, 38.25342893600464, 37.61375311882266, 38.604936061366914, 38.49685515126875, 36.595294014100105, 38.204301249596384, 37.43041761459843, 37.18894081730997, 43.771815453806234, 51.09626123982092, 49.545010905111994, 50.08589006239369, 48.34735439669702, 48.36636220255206, 46.80583546238561, 51.99696294723019, 51.848971920628706, 53.03288444395989, 52.052860644555864, 51.77780051385203, 51.29543527480095, 52.11466935373122, 54.04376945187969, 49.8654136350078, 40.730119366799634, 38.2284277485263, 39.17153419986848, 41.55801403907038, 43.55428472641976, 45.27121597720731, 46.00429519530266, 51.94962386162051, 57.038836402277795, 60.457044724495184, 53.228638172149665, 10.820861266505334, 1.3325871455092586, 3.8183881390479306, 0.4724364331172359, 0.13830298678048197, 0.02459659537811193, 16.888912070182062, 62.15301875145205, 46.43696400427049, 42.50232073568529, 27.590487195599465, 35.47757148742676, 48.7928807350897, 58.925406240647845, 27.13897139795365, 0.49679254391981714, 0.06940450158811386, 0.09297929463847991, 0.029080326053043528, 0.04212855774488661, 0.0602291546191179, 0.011961483302706433, 0.05218042421244806, 0.061212619991912964, 0.055423703405164906, 0.057044546270082076, 0.03939144433506074, 0.0503029189102592, 0.011966400629570408, 0.03401938683143066, 0.006789768803789611, 0.1012151305293364, 0.04785325318094223, 0.03174042655906129, 0.04791472790642612, 0.01634801561463504, 0.08544189344731071, 0.02913711806609025, 0.03875451500437433, 0.015764910663898676, 0.030425825426655433, 4.795760416215466, 47.31444528025966, 59.963437972530244, 50.31048105609033, 30.771043031446396, 19.36871882407896, 40.633240745913604, 49.2696762084961, 61.271772000097464, 28.428852635045207, 0.243432650402669, 0.011229413512703634, 2.0004111167884644, 7.5926407883244185, 3.5986773092900557, 3.2749251204152263, 31.258458322094334, 57.28754212779384, 55.80097167722641, 54.82710207662275, 51.0414461166628, 45.962106181729226, 37.21586788854292, 43.52921293627831, 50.517209576022246, 55.77182062210576, 49.9868933616146, 53.398202234698886, 55.91371236308929, 50.91885243692706, 49.266212755633944, 49.18007750664988, 48.47520797483383, 51.026690160074544, 52.16139262722385, 51.95396200303109, 52.46185794953377, 48.66152055801884, 51.53981070364676, 52.62587578065934, 49.03448697059385, 48.78263158182944, 42.760193040294034, 38.62838791262719, 36.32142236155849, 37.016462433722715, 39.515486840278875, 38.53193683008994, 38.29424904238793, 37.88334546550628, 38.311017174874586, 38.91151635877548, 38.812629484361224, 38.80259998383061, 39.730993624656435, 39.55631086903234, 38.745651091298754, 38.65759780330043, 38.399195978718424, 38.653942154299834, 41.99023962020874, 44.28688933772426, 50.36846545434768, 53.84429339439639, 53.69125427738313, 51.07135811159688, 61.095947834753225, 52.81939768022107, 50.4433984141196, 44.70053072898619, 43.040964141968765, 49.494145608717396, 53.435802075170706, 53.65483114796301, 52.911781264889626, 50.57155793712985, 49.25159800437189, 49.349829842967374, 51.50803558288082, 53.456304304061405, 52.736298345750384, 51.73481133676345, 49.58370508686189, 49.19908531250493, 46.59927560437111, 43.56689906889393, 40.88994026184082, 40.12468976359214, 39.34780943778254, 40.705055421398534, 40.74720521127024, 39.713841099892896, 40.6900837344508, 40.35741575302617, 40.56650553980182, 39.93896553593297, 39.356105250696984, 40.042276843901604, 40.60764728053924, 40.717924717933904, 38.806942047611365, 39.14621137803601, 39.43881627052061, 41.773046216657086, 38.695087817407426, 39.439330101013184, 39.34963726228283, 39.094655744491085, 47.090783888293856, 53.315020530454575, 53.24025623260006, 52.036261173986624, 51.331156299960234, 51.74643331958402, 49.998519266805346, 53.83462475192163, 53.775377350468794, 53.64896720455539, 51.33214473724366, 52.927313850772, 54.001792246295565, 53.232423259365945, 55.461988679824344, 52.810552735482496, 43.15738793342344, 39.951972115424375, 40.44626920453964, 42.07746921047088, 45.485879451997825, 47.31953651674333, 49.737964060998735, 54.07477578809185, 59.03058851918867, 61.96548631114345, 56.81271176184378, 10.589203142350721, 1.4887284896066113, 6.828046796783325, 2.2901371121406555, 0.08071627242550736, 0.052812366310747406, 18.943498596068352, 67.50116655903479, 52.423712899608, 47.36492226200719, 29.86033731891263, 37.3120169485769, 55.77696284940166, 66.15896286502962, 34.01107964977142, 0.9510263295904283, 0.07198452483862638, 0.05244563619095472, 0.034562447408754984, 0.060599975648426244, 0.04496000722170838, 0.022061265697101914, 0.032990975080118064, 0.0657738347147261, 0.054136606744460525, 0.0029306078278985358, 0.015612585571474366, 0.10708786096544036, 0.09338951940017362, 0.14229493305808114, 0.14572829398657047, 0.2689054416071984, 0.1268560090853322, 0.22086527829449024, 0.11929328868826551, 0.2263375362681766, 0.15496573621226897, 0.13821025949812707, 0.23238474322903543, 0.15278247755862054, 0.20704583355015327, 4.615805995079779, 53.78444194793702, 67.67928138855966, 57.5251514680924, 38.6976844264615, 31.792375272320164, 47.98469597293485, 52.92388177687123, 64.33993231865668, 33.02855337819746, 0.5813998765041751, 0.09662843955260131, 2.757264678516696, 13.5104638338089, 6.149856246286824, 4.097361569443057, 32.88512406810638, 57.739658048076016, 57.28585550861975, 56.52686903553625, 53.04509085993613, 47.1846422841472, 38.532654623831476, 46.498019618372766, 53.14908858268492, 58.10792938355477, 50.938079895511756, 54.509448928217736, 57.273633403162805, 52.4665726384809, 51.96998096281483, 53.09490496112455, 50.261914268616714, 54.42798522210891, 52.79978582935949, 53.788889915712424, 53.863677747787975, 50.76327946878249, 55.34387042445522, 54.071108371980735, 52.17358335371941, 52.12842118355536, 44.56865279905258, 41.58347414385888, 38.5996957748167, 39.8162345732412, 39.75914839775332, 40.22008965092321, 40.50995280665737, 40.13053409514889, 41.180917370703916, 41.78837091692033, 41.82217390306535, 41.696881632651056, 41.946744457367934, 41.50793321671025, 40.21852854759463, 39.083704486969985, 41.01209855848744, 40.29679159964285, 45.32696854683661, 47.99488236827236, 50.77406990912653, 54.313071543170565, 55.27588398225846, 54.501121736341915, 61.3950599393537, 54.316546763143236, 52.82590096996677, 47.5893485161566, 45.927514799179576, 50.407445969120154, 54.3647095464891, 55.75049469547888, 55.50596629419635, 50.54728238813339, 49.460468138417895, 51.07602180973176, 54.222343198714725, 55.074438894948656, 54.64571991274434, 53.57293205876505, 52.62320464657199, 51.713214766594675, 48.57844868013936, 45.59230512188327, 44.29960958419308, 43.73284670614427, 43.00529802999189, 43.019449941573605, 41.819628284823516, 41.38373136520386, 41.67729331601051, 41.73046496606643, 41.333101411019605, 42.697238999028365, 41.27492089425364, 42.25758444878363, 42.69893738531297, 43.117662168318226, 42.29243078539449, 41.38887751486994, 41.690072398031916, 43.2008909410046, 40.989729281394716, 42.222600829216745, 40.9898587196104, 39.641422379401426, 48.99307066394437, 55.691133545291045, 55.4081541492093, 53.33000398451283, 54.71478108436831, 54.36918497085572, 53.46844011737455, 56.733974103004705, 56.87120606822353, 57.58260242400631, 54.89092688406668, 54.292534012948316, 55.49339509779408, 56.355300641828975, 59.155892556713475, 55.67039597419001, 45.131352101602864, 42.18845267449656, 43.047738075256355, 45.127249302402625, 48.27783430776289, 50.33674916913433, 51.06569028669789, 58.118845339744325, 61.725194069647024, 66.49227019279235, 58.96594001400856, 14.591100350503, 4.883924020874885, 13.209170891392617, 3.0916268787076397, 0.4189816982515397, 0.09248814034846523, 21.44144238964204, 73.69916254474272, 58.30174938324959, 55.25048663539272, 40.6541116776005, 47.67728805541993, 63.946828457616995, 76.83472094997283, 43.18435422835812, 1.97315689536833, 0.2497103119329099, 0.19153731815036268, 0.1110932061208352, 0.16210379109026926, 0.11003349201693652, 0.17877453847998576, 0.11905970081927315, 0.1545519414808481, 0.2522650619428004, 0.09929056444595899, 0.1440741262969471], [0.02875779920648183, 0.03724103936204507, 0.06628085468565265, 0.042913307571002555, 0.030884242864445816, 0.012605394567212751, 0.07257078128356127, 0.07411956591832061, 0.021919912898973114, 0.019231593544264475, 0.015718091200406275, 0.0754890783179191, 0.0032324751983622032, 0.020574698893113003, 0.5382011590465423, 28.58969726870137, 54.79664879460489, 48.28564374677597, 34.46206984981414, 28.05207563984779, 38.01304647999425, 40.43578470906904, 48.53184700012208, 35.942870493858095, 2.079893167941801, 0.2724406309425831, 6.267848005217891, 10.186516930980067, 1.5193950505025926, 2.983192219849556, 24.787569315202777, 53.19928315378005, 50.73877249994586, 51.09699864541331, 42.06035983177924, 39.078695620259936, 43.481924841480875, 47.93290891954976, 53.30921150022938, 50.35764755741243, 52.05327641579413, 52.311258546767704, 48.36744869908979, 47.04904594729024, 47.11379251172466, 46.81491182696435, 44.845831009649466, 46.7883966045995, 48.3887001006834, 49.29669349424301, 49.31290072779502, 48.53222354765862, 51.72426408337009, 46.569065509303925, 43.94694535962997, 40.11131448130454, 35.32055508705878, 35.87575481783959, 35.866392120238274, 35.93024438427341, 36.945722487664995, 36.43564962571667, 36.95204534838277, 35.83877863422517, 38.439274757139145, 37.65102740257017, 37.09346640494562, 38.31808920829527, 38.63296531861828, 37.35681041594475, 38.04826936414165, 37.24270082289173, 35.99297485043926, 38.22076343720959, 44.364046281383885, 39.79308082211403, 47.46065947317308, 49.66444707685902, 53.36212427385392, 48.6990301839767, 45.10370331425821, 54.85402130311536, 51.24692732287992, 52.78970141564646, 44.702723333912516, 43.354632162278705, 50.364868640899665, 51.63453594330819, 54.24242965636715, 47.633710522805494, 43.13554817630399, 50.84188768940588, 49.99402423058787, 50.496424936479144, 49.38395446346652, 49.8294690347487, 45.94593424950877, 47.75566485620315, 44.21159944226665, 39.54116659779703, 38.62426942394626, 38.79730478409798, 38.10626945187969, 38.05631806773525, 38.36587152173443, 38.01672566321589, 38.756151276250044, 38.10783839994861, 40.02150789383919, 38.62068437760876, 38.21846100591844, 37.88925255498579, 37.60843046249882, 36.62878713300152, 37.98533493472684, 37.32409784870763, 37.573399774489864, 38.391923904418945, 36.9153162740892, 37.41328862405593, 36.330706611756355, 35.356589901831846, 35.83719791904573, 41.395945625920454, 44.70371569356611, 47.56355500990345, 44.69187798038606, 46.50924936417611, 45.44953084761097, 48.08464188729563, 50.37548257458595, 48.677245340039654, 53.290270374667266, 53.35273019729122, 52.24241310550321, 52.12621288914835, 58.223976627472915, 55.81160522276356, 49.12669797097483, 42.99342893785046, 42.256188085002286, 43.169755166576756, 41.359161638444476, 41.435969491158765, 47.124520194145944, 52.73329381019839, 57.92394276588195, 58.58201449917209, 55.06999092717325, 5.989082215293761, 0.7517579738651553, 4.433459908731522, 2.3069371138849566, 0.12205622309157926, 0.08683936805614541, 20.66422866236779, 62.67876148223878, 45.56879051270024, 50.37347039868755, 38.51461172103882, 31.922033140736243, 44.17107743601645, 50.95305942719983, 22.699020947179488, 0.13079906363160382, 0.07260307955044894, 0.022352407836625655, 0.041869313591310096, 0.03881736102724268, 0.0797509020494838, 0.021724388108498627, 0.05899724310203906, 0.06138322777265023, 0.07676015608012676, 0.042578764635348515, 0.004503757170882196, 0.021350249918478153, 0.07555165237957433, 0.03147230153122256, 0.06352308754538817, 0.010587653040044732, 0.015188879577533133, 0.08033937248851984, 0.008640472041142565, 0.037260999782912196, 0.021908168771093892, 0.04822347666166964, 0.03355829383156473, 0.034590038065347946, 0.04615207833628501, 0.9701361170699521, 36.802563821115804, 61.01968911386306, 54.06000806439308, 37.32254851248957, 26.171765904272757, 40.94659497660976, 46.656867765611224, 55.633333498431796, 39.50325296771142, 1.6918011153897934, 0.1653951806046309, 4.515337424893533, 8.521735552818544, 3.2496591729502526, 4.224031327232238, 25.861241663655928, 56.93421110030144, 53.533826028147054, 54.0623144180544, 45.134952837421054, 41.477205368780325, 44.55268875245125, 51.47366777543099, 54.4417723532646, 51.78451561158704, 53.02891108297533, 55.62329615316084, 50.444171121043546, 49.70333345474736, 49.87197183793592, 49.76621689334993, 47.77374306032735, 49.91707909491755, 52.09378665493381, 51.44041392111009, 51.56354104318927, 50.75444236878426, 52.8853327228177, 49.513059277688306, 45.45019765054026, 42.19006084626721, 37.33091100569695, 35.60700185837285, 38.43036705447782, 37.72463852359403, 38.30714579551451, 37.18015470812398, 39.28494561103083, 38.02941060835315, 40.52690529054211, 40.12468191885179, 38.34092916980867, 39.99427095536263, 40.23484560751146, 39.900169372558594, 39.937353441792155, 37.595502330410866, 38.335622202965524, 39.515024000598544, 45.4917904638475, 42.78479022364463, 49.63142856474846, 52.259357744647616, 56.468013871100645, 47.44713121844877, 47.31635939690375, 59.01994712891118, 52.49395862702401, 52.729218467589355, 44.791757214453916, 44.67965195255895, 51.0412617652647, 53.99561843564434, 57.02928935327838, 50.82042840219314, 45.73281618856615, 52.77092895200176, 52.968581107354936, 51.70367163996543, 51.179580227021255, 51.914777525009654, 49.01570666220881, 48.794818385954834, 45.26678762128277, 41.948815468818914, 39.411853897956114, 40.15474296385243, 38.83592836318478, 40.75473223963092, 40.02784644403766, 39.07194522119338, 41.237611309174575, 39.46481374002273, 41.19035459333851, 39.64341102107879, 38.95180694518551, 40.05932346467049, 39.485406183427386, 38.59436527375252, 39.20538817682574, 40.043590837909335, 40.779219596616684, 41.456938482099964, 39.10044516286543, 38.8357126328253, 38.80404733842419, 36.95061760564005, 38.32664389764109, 45.973445753897394, 47.46435434587541, 49.60210492534023, 47.412567292490316, 49.582677425876746, 48.86264401097452, 48.44126770573278, 53.74619883875693, 51.18625610105453, 55.22543837947231, 53.96181937186949, 53.65185406900222, 54.42844413941907, 59.08265798322616, 57.365946385168264, 49.902746754307906, 44.40214818523776, 45.57245008407101, 44.5189759808202, 40.61880642367948, 44.40192068776777, 49.882781890130815, 55.56265631029683, 59.693194512398016, 61.00533716140255, 58.032843451346125, 6.495324392472544, 1.8574817863202866, 6.300872891179978, 2.5846921580453075, 0.20654591521428478, 0.028519095785375086, 23.52874932750579, 67.10038661956787, 50.06188907930928, 52.182930361840036, 38.74463127505395, 37.34334884151336, 51.20455395790839, 59.119555719437145, 31.25410841357324, 0.8549619682373539, 0.09005421772599222, 0.04548195824627915, 0.033693175101953174, 0.031517343670730634, 0.05200986622742588, 0.06495667936941309, 0.03568771182589474, 0.05154175203173392, 0.04747920692147267, 0.01946036655065273, 0.015017624452499854, 0.13575214381900527, 0.1826993294901425, 0.171669976966035, 0.12641977563860918, 0.07805181096398062, 0.14755830949833318, 0.1753707025800982, 0.1825573887195318, 0.10093049822194923, 0.14213376348057102, 0.12487849866550778, 0.1849713164471811, 0.14187136304474648, 0.17870992662445193, 1.3374549294671705, 41.621007304037775, 69.48573681616014, 61.97575507625457, 46.11593369514712, 39.113565491091826, 52.06949541645666, 51.539747945724, 59.77953764700121, 46.26331283200172, 2.7666398786729385, 0.4356379206142118, 11.83918014649422, 21.762362872400594, 6.602223198260031, 5.057942915347315, 27.8197693440222, 58.88224840164185, 56.62750136467719, 56.726862845882295, 47.90923349318966, 43.77434930493755, 48.28972301175518, 52.52426285897532, 56.793872617906146, 52.0878089627912, 53.75190588735766, 57.09380449787263, 53.14082807110202, 52.264456825871626, 52.42897672037925, 52.819538885547274, 49.89348996070124, 52.690320322590495, 53.3271877227291, 54.154117491937455, 54.534140248452466, 51.29988324257636, 55.44398500073341, 51.598257941584436, 48.70650622152513, 44.40901625540949, 37.64584202920237, 39.11415384661767, 39.471540604868245, 40.38077346740231, 40.4995624480709, 38.46880235979634, 41.06994959615892, 38.82394552230835, 42.96871800576487, 42.28090686182822, 40.42416272624847, 41.40936013190977, 41.33407023645217, 41.09905750520768, 41.52679981723909, 40.134338794216035, 40.04071574057303, 40.57429144459386, 47.68956899642945, 43.88939634446175, 51.483818869436945, 53.795467730491396, 57.55264728300033, 49.592040123478064, 48.04779121952672, 57.88259706189556, 56.23586447008195, 56.09010527210852, 47.014733053022816, 45.791738033294685, 54.03917635640791, 55.55970668792725, 61.51985406875611, 52.981666134249785, 48.28247054930657, 52.57938784937705, 53.90009303246775, 54.68206851713119, 52.87803711429719, 53.86047709372736, 51.68558559110088, 52.125059712317686, 48.5261046501898, 43.25552171276462, 41.414310163067235, 42.95689598206551, 41.26013355870401, 41.9782450122218, 42.019943729523696, 40.3750507293209, 42.40509694622409, 40.94776776529128, 43.75153287764519, 41.52894927609352, 41.94042159665016, 41.57324068007931, 40.81728619913901, 40.560892628085234, 41.99660170462824, 42.04843974882557, 43.24284068999752, 43.914330851647165, 40.99143551241967, 41.30419354284964, 41.08454865794028, 39.24051300171883, 39.4012007405681, 45.467663964917584, 49.80991994180987, 51.45719774307744, 49.231892016626176, 52.466254926496944, 51.272967938453924, 51.799106828628055, 56.90030613253194, 52.32927007059897, 57.64625856953283, 55.836880976153964, 55.56185222441151, 56.503809421293205, 60.524521258569536, 58.38716291612195, 54.039015539230846, 46.33125220575641, 48.588615463626006, 47.701971530914314, 44.45894802770307, 46.744191492757494, 52.02575314429499, 59.56474865636518, 64.47872538720408, 64.04311480060701, 60.66125508277648, 8.163318191805194, 3.0861689006128623, 10.343336232246893, 4.850553476041363, 0.3439560418407763, 0.18575922255554508, 24.752375848831672, 72.372083510122, 56.956537231322265, 64.25919032865956, 52.15823119686496, 46.16814044214065, 59.665808523854906, 67.9460653181999, 39.08701888976559, 1.2084099313905163, 0.25339243693217156, 0.15386094549490562, 0.1267677787390928, 0.141066940080735, 0.16042918417482607, 0.11183611988540619, 0.16620845954504707, 0.13255406381382098, 0.14542466269866114, 0.10072884855852013, 0.1660966107081021], [0.03485991551931347, 0.02675724294667523, 0.025262670523877588, 0.04720023217340631, 0.04631044403199227, 0.0640092354508177, 0.02320478598947727, 0.011571734156008932, 0.07110439706593752, 0.040309807556050445, 0.07001701952709306, 0.04937150155103976, 0.027266578418352914, 0.047700832327527386, 0.19278697609420747, 20.61189247715858, 52.981419024928925, 47.11061931425526, 28.004895410230084, 19.186401174914455, 28.505858567453203, 43.82616773728402, 49.191903452719416, 47.278139821944706, 5.069399178028107, 0.09179377357565588, 1.2326308123527037, 4.760463497331066, 3.959585620510963, 2.6679697152106994, 31.978011246650453, 52.156101349861395, 50.520100362839244, 43.874483493066606, 42.86452808687764, 45.897085051382746, 50.664706383982015, 56.0525328882279, 52.102400179832216, 51.04326217405258, 53.261425264420055, 47.81542216577838, 49.02858380348452, 45.09955736898607, 44.59117112621185, 44.53287293834072, 44.7687642805038, 46.02329515641736, 44.40299149482481, 47.36424761433756, 47.89315569785334, 47.90540525990148, 45.20117421304026, 44.65981652659755, 40.2194110808834, 36.04164361953735, 37.096368958873136, 35.711478110282656, 34.58076077122843, 35.576128882746545, 36.955273459034586, 35.09118272412208, 37.72607018870693, 37.759151458740234, 37.8444786994688, 36.686959805027136, 37.00193789697463, 39.26608293287216, 37.58879899978638, 37.21598948201826, 38.07036799769248, 36.062267441903394, 35.142585385230284, 39.97301955376902, 38.55973074513097, 39.69306038271996, 38.46162442238101, 49.49906033854331, 48.78432212337371, 56.986562974991344, 43.38969030687886, 39.79883101678664, 54.43669680626162, 49.24502411196309, 50.334419281251975, 42.84693625665481, 44.580106119955744, 50.14775368475145, 54.605935312086544, 46.37793625554731, 44.20759077995054, 49.029062332645545, 52.22791602534633, 52.47096569307389, 50.88590452747961, 49.3020357624177, 47.30333712793166, 45.076780165395434, 42.89772702801613, 38.80375708303144, 36.403427354751095, 38.374163412278705, 36.54980628721176, 40.63616683406215, 39.165395690548806, 39.65915933732064, 41.00194746448148, 38.026107972668065, 37.55616880232288, 37.38242349316997, 38.67311862207229, 37.137106695482814, 39.024896390976444, 37.664069283393125, 37.54557840285763, 37.03931023997646, 36.49055888575893, 36.91023288234588, 37.845455369641705, 36.424698368195564, 40.06880383337698, 39.440463665992986, 38.36139217499764, 37.29465653819423, 37.45374787238337, 37.66383001881261, 38.51780845272926, 39.12066890347389, 42.45522091465612, 45.98391848225748, 45.079647417991396, 48.85104164000481, 49.34268720688359, 51.334223593434984, 54.353683763934725, 50.38170345367924, 44.398261116397, 58.18264661296722, 53.01715966193907, 51.268257171876975, 51.18322803128151, 51.51690013947026, 46.48683301864132, 40.26239241323164, 46.35774389390023, 52.07360213802707, 58.39447813649332, 58.326472082445704, 54.05213586745724, 3.219805278124348, 1.2211473382288411, 4.572167665727677, 1.7865717074563428, 0.0917735718370926, 0.030666574302520004, 20.29226245418672, 61.66076521719656, 44.65613734337592, 36.4697350225141, 28.168354303606097, 37.48998665040539, 43.74714374542237, 51.07814773436516, 18.00282597541809, 0.009522684530595378, 0.025618225336074833, 0.06121152831662086, 0.08384406386363892, 0.031553842014663165, 0.06645111006594474, 0.029960264218971137, 0.01540477368830433, 0.03991418443019352, 0.04070684028368804, 0.01871100041053949, 0.09156017804578429, 0.04712196097018258, 0.036516040563583374, 0.09487960637817461, 0.07320327879560572, 0.028810360498966712, 0.0043974950301250626, 0.04141969275811026, 0.0035564422902215516, 0.02773439767019403, 0.031101197049382235, 0.03095795009886065, 0.026735905482764208, 0.01582666979952445, 0.056144396789492144, 0.24807624639041964, 24.71018683525824, 59.88621434857769, 52.28905008685205, 34.8568211063262, 20.359338906503496, 37.626151730937345, 49.5676939718185, 53.7694114254367, 51.387371709269864, 4.655533721370082, 0.1363356883126882, 1.661593226655837, 4.809900070390394, 4.365425907796429, 3.5891074615140117, 31.631732640727876, 55.40152926598826, 53.4226542903531, 46.238139060235795, 43.478202512187345, 48.13804887956189, 52.101011660791215, 57.92971649477559, 53.26634391661614, 52.393628320386334, 54.92020737740302, 49.794422657259055, 50.03051011793075, 48.83872147529356, 46.31785731161795, 46.088845806737105, 46.93125324864542, 48.35131599057106, 48.13001586544899, 50.674261277721776, 51.766053015185946, 48.31561849963281, 47.978396646438114, 47.808440346871656, 42.748437696887606, 39.46295845893122, 38.30025811349192, 38.049457842303866, 35.37257356028403, 38.471720603204545, 38.26907527062201, 37.77215019349129, 39.2741394812061, 38.91092800324963, 39.61872362321423, 38.33990935356387, 38.47413678323069, 41.1379046593943, 40.39768672758534, 38.023381925398304, 40.156731605529785, 37.14953668655888, 38.34488291894236, 40.57365994299612, 40.88674353015038, 41.84143274061142, 42.559889362704375, 52.12232189793741, 51.05389571958973, 56.24736485942718, 43.40732920554377, 44.29320043133151, 56.053219303008056, 51.16968800944667, 52.193218738802024, 45.33212646361321, 46.41677164262342, 54.29833519843317, 54.880434543855735, 50.529282631412634, 46.90361622841128, 50.737176095285726, 52.057849899415054, 54.02317700847503, 51.971373404226, 51.13363358282274, 49.77014710826259, 48.10468519887617, 45.12404864834201, 41.28557797401182, 39.90871621716408, 40.520456913978826, 39.03609868018858, 42.52258762236565, 41.121281654604026, 40.57833540824152, 42.784629406467566, 39.54535176677089, 40.28668365170879, 39.943005577210464, 40.549341247927764, 39.489795315650206, 39.366887846300685, 40.34128304450743, 39.944535301577666, 39.60444227341683, 37.882266813708895, 39.77507322065292, 39.89354056696738, 37.905298971360736, 41.02974137952251, 41.55844157741916, 39.909312417430264, 37.31832411981399, 39.05711473957185, 40.28822122081634, 40.06885482418922, 42.04211296573762, 45.92906021302747, 49.34478567492578, 47.53931476223854, 50.67899165614959, 51.90115905577137, 54.09472496278825, 55.7736837479376, 50.82141683947656, 47.08835594115719, 60.77245035479146, 54.100526148273104, 53.66539016846688, 53.79923320585682, 53.10786054980371, 48.92992442654025, 42.81168199354603, 47.78657705553117, 54.37966946632632, 61.39266729354859, 60.912765302965724, 55.58211126635152, 3.494446940960423, 2.221966318545803, 8.968339562416077, 2.2072951832125267, 0.10147481135302976, 0.009112386032938957, 22.690115205703243, 68.66305105147823, 49.77068055060602, 47.03595699802522, 35.41010279809275, 41.08664712598247, 51.713210844224506, 59.53733913360104, 24.401692421205585, 0.20717373958999113, 0.04697240528560454, 0.06466500671400179, 0.022957004426467805, 0.08731011376385728, 0.05244103966340904, 0.047869547871091676, 0.0424748677910576, 0.04326363957877602, 0.03655147596052097, 0.030399226853924415, 0.02129741857999996, 0.20515790179131493, 0.17545483435594267, 0.1305613005834241, 0.2000680902311879, 0.10952468706114639, 0.09792380996288792, 0.1514929370774377, 0.08907145715408749, 0.24526953006223326, 0.18126925784012965, 0.18780135249178256, 0.18535656674254328, 0.2727121325029481, 0.20269491379299473, 0.2616394653676018, 28.7152817556935, 69.13242540051861, 61.589895832923155, 40.09852363217262, 31.06844106028157, 41.811465832494925, 54.94243544916953, 61.437339167441095, 58.942311656090524, 6.6601698437044705, 0.31456848005613974, 3.321913399042622, 11.320747733116152, 13.023569237801338, 4.032474780274976, 36.099173022854714, 57.322639496095725, 55.76464268469042, 47.850570524892504, 48.27978372573853, 49.1819445548519, 56.017961117529104, 59.28709583897745, 54.979878394834465, 54.32852175927932, 59.430281962117846, 53.383512958403564, 55.00695451613396, 50.47600507736207, 48.58212394099082, 47.60059395144063, 50.15386473747992, 51.326414154421904, 49.793422452865116, 51.50472118008522, 54.149269442404474, 51.7390827978811, 50.85485112282538, 49.82711561264531, 44.50088993195565, 40.89271729992282, 41.30022018186508, 39.11303204874839, 38.54959926297588, 39.1522910518031, 40.5324475995956, 38.53997768894319, 42.49988886617845, 42.336608440645286, 43.05942673836985, 39.21931259093746, 40.82576244108139, 43.99536309703704, 42.456378013856956, 40.24780511856079, 42.196446464907744, 38.12898781991775, 39.06558313677388, 42.39249437086044, 42.22795878687213, 44.13731759594333, 42.40982732465191, 52.65476011460828, 53.09213184541272, 56.94697841521233, 45.340316372533, 47.00229129483623, 55.86325499319262, 52.90549762787358, 55.436850209389966, 47.32066615935295, 48.13011000233312, 53.42253269687776, 57.45691007183444, 52.686684285440755, 48.063778800349084, 51.37443965481174, 54.46044675765499, 55.5312773489183, 54.16748100711454, 53.409326076507575, 50.85118370671427, 50.623466583990286, 47.27120507148005, 42.891117834275775, 41.35495685761975, 41.81144229827389, 41.53056137023434, 44.89063624412783, 43.70773176993094, 43.477806352799945, 45.07113979708764, 42.1143747914222, 41.83115613075995, 42.725425151086625, 43.07584577991117, 40.92099366649505, 43.00672185036444, 40.514914604925345, 43.24116583793394, 42.20723690525178, 40.91713013187532, 40.87656105718305, 42.09031105041504, 41.164196306659335, 43.961411060825476, 43.23451349812169, 42.689751194369414, 40.69212336694041, 40.29351642054897, 41.80083228695778, 42.59300593406924, 42.61563408759333, 49.08588570933188, 50.9972410048208, 50.23320251895536, 53.534590890330655, 52.87391862561626, 55.22081782740932, 58.79564246823711, 51.00422674609769, 47.76984814674624, 60.80641415811355, 57.903303254035215, 57.011320975519, 55.616647735718765, 55.96231052952429, 52.924262246777936, 44.94740470763176, 49.85017130451818, 56.09270188116259, 64.18273941163095, 62.25050926208497, 58.01432594176262, 4.432068447912894, 4.504257709749283, 14.18273356653029, 5.0383678367061, 0.4209942112286245, 0.18119090236723426, 24.923032291473884, 74.51309357920002, 57.879286581470126, 51.984199554689475, 42.08256829169489, 52.65660362858927, 59.977342774791104, 69.97972796040197, 33.124149384037146, 0.48240504497962616, 0.18958934042001926, 0.1585561145217188, 0.1423232017024871, 0.1452023899483104, 0.15121628740622153, 0.1837356166253167, 0.16610604891132924, 0.1672309570975842, 0.11767391671216297, 0.12799608581248792, 0.17657798053997179], [0.030262081793719725, 0.04470807537736912, 0.05985170692926454, 0.05132571906752644, 0.08737031295294724, 0.0719451172758014, 0.042406218652162826, 0.021407241114385186, 0.07011229788223583, 0.05611304847163059, 0.05710106823713549, 0.01601097714756766, 0.029689304665812564, 0.06740013978654338, 0.18030720462481822, 10.773001486255277, 48.40922194142496, 50.175571134013516, 34.86097489633868, 23.373770598442327, 26.064755801231634, 39.75752845887215, 48.56147266203358, 50.9865721579521, 9.873960902613979, 0.11875080650732403, 0.562755870482614, 2.5812414528862124, 2.7583320534998372, 5.201116290784651, 28.495744735963886, 51.6135787194775, 52.865230575684585, 48.713131104746175, 49.699328714801425, 52.07898362990349, 52.39956286645705, 44.470903411988296, 51.10529838069793, 52.95500186181838, 48.83370476384317, 49.001927375793464, 45.065601410404334, 42.72302466054117, 40.946030155304946, 41.31481532127627, 42.3471753058895, 43.09659511812272, 45.694027869932114, 43.445054561861106, 43.58158442281908, 41.49223981365081, 40.81338736318773, 38.40888031067387, 36.3616580347861, 36.84274850353118, 36.03678772526403, 34.78638710514192, 35.84954554034818, 36.22663828634447, 37.963420652574115, 35.918269388137325, 35.722872595633234, 35.56672696144351, 36.514246079229544, 36.097549161603375, 37.21964905338903, 37.614933752244525, 37.742124449822214, 39.396023211940644, 38.80926801312355, 38.03975782086773, 35.981058689855764, 36.84267005612774, 37.82130141412058, 36.275130548784816, 35.1487748853622, 46.51333255152549, 53.27026236441828, 56.3327548580785, 46.32837318604993, 44.45900686325566, 47.830017305189564, 52.63905102206815, 49.042574897889175, 44.10493450780069, 46.23097681230115, 53.761503927169315, 54.73427134175455, 46.590242385864265, 43.192344096399125, 54.236287224677305, 52.79475342842841, 51.14460837456488, 48.21281709978658, 47.625846170610004, 45.32303440955378, 42.162768994608236, 40.283149596183534, 36.741606266267844, 38.851974779559725, 37.89898787775348, 36.0324417391131, 37.88472221743676, 38.11876612324869, 38.917176338934134, 39.009434407757176, 38.7349469430985, 36.72739159676337, 37.83867359161377, 38.84479684214438, 38.0159019654797, 38.19674284227433, 38.50630414101386, 39.69738283464986, 37.007797918012066, 37.32824771634994, 38.344196504162205, 38.60281405910369, 37.92351053607079, 36.945738177145685, 36.570116319964015, 38.23506832122803, 38.21621741017988, 35.974425961894376, 36.84359181311823, 36.31156152294528, 35.78407333743188, 38.039640149762555, 38.83672852669993, 43.11908206632061, 45.78146926818356, 49.530764856646144, 50.15621815958331, 50.64781665802003, 53.52489479126469, 49.356639077586514, 52.47884965712025, 59.81883195138747, 51.32861852645875, 54.14483324173958, 53.417210040553925, 55.12980707230107, 45.72392417538551, 44.48282349494196, 54.40309386099539, 56.310291444101644, 61.934228943240264, 45.789157113721295, 1.794635610234353, 1.7287362366914751, 3.461988102043829, 1.9637157503635654, 0.062145925757865754, 0.07779160153961952, 25.10166879623167, 60.371093826909224, 46.68386936187745, 38.32559662480509, 30.056010638513875, 32.18587137037708, 46.74843941965411, 53.33161215628348, 13.79899142249938, 0.060893306884193615, 0.04252541427230162, 0.06607188888254666, 0.047109466076137564, 0.030308495230612256, 0.034027940203105254, 0.10076295479290909, 0.032589644599225254, 0.028540643923465284, 0.0669598154303047, 0.009648732807216866, 0.043959205279186855, 0.005392325796081775, 0.03998258076007328, 0.039797765878780235, 0.057354241143912084, 0.0886556169679088, 0.05938875999662185, 0.038099682198897485, 0.018450658836011446, 0.026948588727522763, 0.04177917185569963, 0.05533623531641019, 0.022524511404035073, 0.06902510420449319, 0.01789468776194319, 0.121909563219355, 14.452103318706637, 54.46929562476374, 57.69675124076105, 38.81015446878249, 28.07872618398359, 33.57166044173702, 49.136335234488214, 51.12708714700515, 56.99787116819813, 10.352560666299636, 0.10695558056355485, 0.10336855771921336, 3.2727977248930165, 3.3670204108761204, 4.7479271119640725, 30.780213532909272, 54.279645104562086, 55.36418830194781, 50.02541495907692, 52.5755556937187, 53.271980362553755, 55.026986060603974, 45.597592476875555, 52.4871454700347, 54.99537175701511, 52.39730750360797, 51.89236510184504, 47.0889913651251, 43.35147465428999, 43.47551568861931, 43.91860231276482, 44.69289779663087, 45.146186505594564, 46.72845886599633, 46.33355855941773, 46.20377909752631, 44.16827686371342, 43.135740372442434, 40.3462173861842, 37.98074183925506, 38.52988935285999, 36.864549036948915, 37.040463416807114, 36.90481608913791, 39.189659472434755, 38.55065438055223, 37.495203402734575, 39.214692038874475, 38.82876219287996, 39.737108599755075, 39.47410583496094, 39.24457657721735, 40.159457652799546, 40.098680526979514, 40.481025326636534, 40.20899326570573, 39.124622652607584, 38.21170276211154, 39.30486340676585, 39.192103109052105, 37.41031154509514, 35.995908783328154, 46.58966579744893, 54.74575211924892, 55.383933513395256, 49.22602022847822, 46.50897087589387, 49.068286034368704, 54.64719472392913, 49.59714312707224, 45.13306617736817, 48.48764188828007, 53.668426082980254, 58.332336025853316, 47.35864646973149, 46.88420441842849, 54.406384729569965, 55.3943121048712, 52.891655583535474, 49.91245069811421, 49.58548192054995, 45.93831700663413, 44.07379481100267, 41.27326173167075, 39.92781423753308, 41.31219125563099, 39.471058153337054, 38.48515472104473, 39.65384060336698, 39.397392119130785, 42.56471387801632, 39.849013820771255, 40.89616114093412, 38.251455983807965, 39.29737952447707, 39.795191057266734, 38.74414490115258, 39.794175163392104, 41.73424220854237, 40.586741047520796, 38.91840796316824, 39.4631310432188, 40.441840848615094, 40.101959628443566, 41.14085428176388, 39.74457287019299, 39.539966352524296, 40.55405201450471, 38.88764089153659, 38.22609393827377, 38.293582239458644, 38.2745312875317, 38.48729633515881, 39.874689655919234, 41.00270840429491, 44.82018263109269, 46.823509662382065, 50.4999589920044, 53.43820256571616, 54.46030555232879, 56.14574017063264, 48.76735787237845, 55.5894539433141, 60.86362977181712, 52.4055915494119, 55.57494117367653, 55.91304556015999, 56.50062837908345, 46.97044949377737, 46.55782791876024, 57.47304278035318, 58.05303973536338, 64.88360420350106, 47.83700696883663, 1.8564606217607376, 3.1028982996940617, 7.576391389293056, 3.280652516311215, 0.05425694766604612, 0.10149512034390243, 25.454509527452533, 66.41023774300852, 52.39478541958717, 44.689191156818026, 36.755530680379565, 41.50465411524619, 53.91358598586052, 62.595720983320675, 18.37252897600974, 0.05517875062181585, 0.027390129248341246, 0.041483791334734815, 0.03386686638658566, 0.03354954893790907, 0.04164059804151616, 0.03285042858952957, 0.04729489765820965, 0.028853389742453734, 0.07595708909174127, 0.025107258097118428, 0.03394282017383845, 0.1814070923794662, 0.0773609911782607, 0.1687334087346831, 0.16688840854312145, 0.2803226950908861, 0.2016841220639406, 0.10232773534352742, 0.16201553776139216, 0.25098794740774943, 0.14008726684316514, 0.14331810476799167, 0.08215175265626562, 0.13622157185548736, 0.10140272247935496, 0.23289362479361797, 17.2175851175862, 62.35869215380762, 63.80802754432925, 48.8038908281634, 34.812886638026086, 37.17913489187918, 52.18557403933618, 58.29963130335654, 65.41503829340782, 12.733174600908834, 0.2266979193495166, 1.7443645529208647, 6.18039385926339, 8.560987691725455, 8.118396266814202, 31.907188930819114, 56.025158666795306, 59.19300210091376, 52.25172873466246, 54.83979878887054, 57.25329983618952, 57.136460273496574, 45.755816967256614, 55.468476280089355, 56.17140423867011, 54.02949202445246, 54.80041034760014, 49.96682651581303, 45.85408018481347, 44.72522989396126, 44.86323456610403, 48.04783044322845, 47.26677279318533, 48.553141547787575, 47.37012332485568, 47.55815390617617, 45.88470212874874, 45.46105477117723, 43.21823566190658, 39.52786976291288, 41.33765920515984, 39.174115119441865, 38.61588731888802, 38.72526653351323, 41.26120828813122, 41.42855621153309, 39.32858197919784, 40.502523837550996, 40.05153755987845, 42.80790867344026, 40.20276846424226, 42.62433390463553, 42.41373008297336, 42.2551094332049, 43.004776354758974, 43.28178590343845, 41.37601998544509, 38.51745936178392, 40.00985060968707, 42.06071676746492, 39.525645779025176, 38.05165829197053, 49.6952376827117, 57.98809705242034, 56.43621521611368, 50.66059574004143, 49.38999883590206, 51.08663574341805, 56.696084007140136, 52.18839422349007, 47.53227018540906, 50.74803713829287, 58.86999099485336, 59.692817964861476, 50.17104864120484, 46.952692924007295, 56.68612510927262, 58.99251014955583, 54.58936722047868, 51.21544245750674, 50.834211610978656, 48.54983498973232, 45.80179891278667, 42.36195479669879, 41.648071658226755, 43.76787739415323, 41.65473576514952, 41.13608860200451, 42.789340173044515, 41.01012952866093, 44.03307276387369, 41.27747435723582, 42.66030596148583, 40.00978392939414, 40.97551461189024, 44.79877825706236, 41.156226050469186, 42.660549148436516, 43.35146288717947, 42.03797486520583, 39.19353869653518, 41.37454125189012, 42.50583125698952, 43.73177982145741, 42.360609423729684, 42.258451292591715, 41.252924242327296, 42.08936183683334, 41.74950022851267, 40.95870725570187, 40.69863842379662, 40.27672475384128, 40.33392860043434, 41.69015084543536, 43.85320463488179, 48.07958595214352, 48.59640136841805, 55.3938021967488, 55.82392930984498, 56.88314968539823, 56.95362683265441, 49.70401594715734, 53.630947835983775, 61.813992607978086, 55.123754855125185, 59.05839812371039, 58.5292076295422, 59.11312695472472, 48.83094733761203, 49.954824063085745, 61.02656502877513, 62.05539880260345, 66.53999759304908, 50.478366344205796, 2.107192619192985, 5.315535751081282, 11.471562866241703, 5.285557075854271, 0.4058408695122888, 0.2794946766188068, 29.18801953715663, 71.4696559598369, 59.38788114055511, 52.281256337319654, 42.338428420405236, 46.20707781084123, 61.38763881498768, 69.79711024991929, 24.53052070833022, 0.34130684851158055, 0.11036814220489995, 0.17362193835358466, 0.16172440902840707, 0.11749708829748055, 0.13753691417796, 0.16570415918625173, 0.23532111227752703, 0.07244090639775799, 0.21185726408035527, 0.22002343959625692, 0.20281230910651146], [0.03523942398568315, 0.0289603911580578, 0.0842841737152588, 0.11041113505921057, 0.020177853857016852, 0.07313453772616002, 0.08125929086799584, 0.04601605176444977, 0.029105882746197527, 0.01643303413725188, 0.08242880069320241, 0.018480896326382796, 0.06651451916343744, 0.0906271595628031, 0.014606712126894104, 8.181789613539173, 44.471228968712595, 49.60243048206453, 41.950898247380415, 15.67782340511199, 28.257772576424387, 44.160216393009314, 45.520396309514204, 54.53910989146079, 16.462024834848222, 0.038628194766539725, 0.09490187655413344, 1.3172287373773515, 1.1045053649333216, 1.9537881088833657, 23.55408391644878, 46.452324005865286, 54.33233822545698, 51.4626576823573, 50.760675014988074, 52.83625602722169, 52.25384289218534, 49.608776877003336, 55.6968641281128, 49.65673177473007, 49.32334992193407, 46.54237770265149, 42.99525283998059, 40.228824769296956, 38.81934458209623, 40.09466009755289, 41.14471781638361, 43.655109251699145, 44.634391723140595, 40.314650151037405, 40.5359032077174, 37.112501667391875, 38.054223522063225, 35.76752878004505, 35.76230418297553, 35.91832822368991, 34.919378988204464, 36.54924538827712, 35.25603602009435, 36.56407979226882, 36.78114375760479, 36.24096670458394, 36.05337542872275, 36.83093040220199, 37.34012073086154, 35.916163075354795, 35.83885708162862, 39.002503579662694, 38.09571435374599, 38.35104496248307, 38.468994555934785, 36.71029398518224, 35.40602353311355, 37.86756969267322, 39.65414654824042, 35.776816952613096, 37.595357202714496, 46.45854488495858, 56.31720266034527, 50.512114417168405, 39.62663896622197, 55.31056165695191, 57.51804413334016, 50.75177907943726, 48.363589086840236, 45.67347072785901, 47.725415537434245, 50.90259813493299, 54.843834907777854, 47.26369765497024, 42.54182292569069, 51.994130995965776, 50.54116741303475, 52.5643769387276, 46.07122259755289, 45.990147206091116, 42.781177720715924, 39.66359161561535, 38.89928248620803, 37.66723071375201, 37.23010609226842, 38.61088237454815, 38.011222577864125, 36.33562918632261, 39.91332892448672, 38.592219737268266, 39.259332533805605, 38.43637612558181, 37.21866061610561, 39.538487618969334, 37.39517119623, 38.182763514980195, 38.2323383515881, 39.24186621942828, 36.56638614593014, 36.64471587827129, 37.05376809643161, 37.96732341089557, 36.116070593557055, 38.07200754842451, 37.556388455052534, 36.45816403050577, 36.82039099354898, 36.83765726704752, 36.86580811777423, 37.365235667074884, 35.510021255862334, 36.22664613108481, 37.06668838377922, 37.13949934128792, 40.16830651990829, 42.40069212452058, 45.48332206664547, 48.31985073704874, 50.257901683930434, 51.790324641812234, 57.35159443270776, 43.50674952230146, 51.23204585044615, 58.07355765373477, 51.73050065194407, 56.67279297305692, 54.99532076620287, 53.06361621425998, 43.339868360950106, 52.25265049165296, 57.566814884062744, 64.41970548322125, 36.436602761668546, 0.3786802027494677, 1.9076348048064018, 8.776313066482544, 2.475918214167318, 0.02277406837580906, 0.1686300021866637, 25.127274028716553, 61.66390311333441, 43.07969754742038, 41.1005989966854, 22.46446321087499, 33.724268098031324, 49.071474921318796, 50.361091398423724, 10.821436874328121, 0.07277555658572143, 0.05972278199248737, 0.010521824062321215, 0.044291289072603955, 0.08226318014485222, 0.0598613481457916, 0.07346790088641067, 0.0764849926194837, 0.03604706834941622, 0.0366528868494976, 0.01367474509958899, 0.041931964261757756, 0.05498326030529796, 0.01747209834115159, 0.017243271708608638, 0.07932961497816347, 0.055566896729531794, 0.031172219145622466, 0.11030539194302214, 0.030500934601971702, 0.024510730328338764, 0.09116846962922043, 0.017594626443761013, 0.02470869127841246, 0.054129148878517656, 0.09343343155999338, 0.0015350993119007457, 9.585267593783717, 53.14579771411035, 54.42935805166922, 47.447637204200994, 20.64360091763158, 28.503181549810595, 47.66102983105568, 53.41472718023485, 59.62066204317155, 16.94288976730839, 0.042375494695959554, 0.10815845351786384, 2.1147132737021295, 3.4296317350479866, 2.774841799851387, 26.1582435331037, 47.39182579901911, 57.572341503635535, 52.80449659593644, 53.06970765513759, 54.83113427315989, 53.90096772101618, 49.62112449830579, 57.0094225483556, 52.1457149136451, 51.128824756991484, 48.18865137715494, 46.08406051512688, 42.84252751258112, 41.753524580309474, 40.45481212677495, 42.11542598662838, 44.0033882664096, 47.18973744300104, 42.57157802581788, 43.44485452098232, 40.49796996578094, 39.79268466272662, 37.854276780159246, 37.31083239278486, 36.78692533123878, 37.44285152804467, 37.92980201782719, 37.49389333109702, 37.42204727665071, 38.99937352826519, 37.84985234660488, 37.45286533909459, 40.22963277755245, 39.12179854608352, 37.944867841659054, 37.866581255389804, 39.117350578308105, 40.524167476161836, 40.8822367268224, 41.25030017668202, 38.26526664918469, 37.51516434454149, 38.43259888310587, 41.37314096573861, 37.260100456976126, 38.10733633656656, 45.45621848875477, 56.485233076157115, 54.54671536722491, 41.25496779718707, 54.14551573414957, 58.26071354650683, 51.91169846442438, 51.93939824258128, 46.6465558544282, 48.2481498102988, 50.86068368727162, 57.803341650193744, 49.73637157870878, 46.254322759566776, 53.238247979071836, 51.93628780303463, 53.65174032026722, 48.63763724603961, 46.92059224651706, 43.76812842584426, 42.746037206342145, 40.62420752740676, 39.42246390927223, 38.92411501176896, 38.8295780458758, 40.00661073192474, 37.78567060347527, 40.920632808439194, 40.04099815122543, 39.08663057511853, 39.89895736017535, 39.67215022733135, 40.0811985231215, 40.185968952794234, 38.71204814603252, 40.894976585142075, 40.14668249314831, 38.214142476358724, 40.080884733507716, 38.78688304655014, 40.32184770030361, 38.66627016375142, 39.20567843221849, 41.071989228648526, 36.9114488170993, 38.23766885265228, 37.94742130464123, 39.330770661753995, 39.6199042566361, 38.15257303176388, 38.964617406168294, 39.27930916509321, 38.581009603315785, 41.35032846081642, 44.369376782448064, 47.53851459872338, 52.21965159139326, 53.87094982208745, 53.82919226923297, 57.00662589842274, 48.09985283882388, 53.674615583112164, 58.98482622638826, 55.06394655473771, 57.967253577324655, 56.523209464165475, 56.09728320952385, 44.68902249490061, 54.79874334027691, 60.05297783882388, 67.54618752387263, 38.80926801312355, 0.6113178775675836, 3.61342738232305, 5.472552641745537, 3.12886635141988, 0.020950181567440593, 0.2897192231349407, 27.316654766759566, 69.1853460188835, 48.573302530473285, 49.25667355137487, 27.124189945959277, 36.4141668042829, 53.85853159812189, 58.18902830923758, 14.484663894099576, 0.04609253415237031, 0.05047765973534796, 0.0393355620514241, 0.03349211532622576, 0.04554215360492949, 0.011888355422284336, 0.03390465750389042, 0.041644738746746894, 0.04600932168203496, 0.014244575661817386, 0.01579263251304867, 0.04210100922312948, 0.2622816615527676, 0.15309357054291234, 0.19058284920550164, 0.29847291147997307, 0.24585154238006762, 0.11534469532630137, 0.18389810387405658, 0.14014709831005143, 0.13644309383967232, 0.22476768421549953, 0.1634225961301596, 0.23516594882934327, 0.16713780080599172, 0.2075427028560831, 0.09872004344698884, 10.879406563697323, 59.31475247106245, 61.92257558145831, 54.03870567198723, 25.05599867913031, 38.984546969013834, 56.144022172497166, 55.06945356245964, 68.50086104485297, 20.740622705028905, 0.18530327766653032, 0.22745896641525531, 7.099557672777484, 6.616505038353705, 3.113910108804703, 27.26734272895321, 49.301208142311346, 60.80916373960434, 55.56417034518335, 54.83794743014921, 55.41551643802274, 54.398041848213445, 52.81664025398993, 59.81639615951046, 54.289627536650634, 53.876605879875925, 51.878323016628144, 47.17991190571939, 44.5046514849509, 42.317020124004735, 44.82299104813607, 44.51712069972869, 46.43356723170127, 49.55641715757309, 44.01806577559441, 43.99308419996693, 40.85172853162212, 43.22793568334272, 39.448206424713135, 41.25621903327204, 39.603810771819084, 39.41967510407971, 39.93769861036732, 38.95112445277553, 39.9033857160999, 40.299819669415875, 38.88896665265484, 40.1483848018031, 42.74775520447762, 42.188852756254136, 39.98527696055751, 39.390955509678015, 43.45609603389617, 41.8904152993233, 42.11044065413937, 41.459236991020944, 40.845609634153305, 37.572289743731105, 40.02635986574235, 44.21541983081449, 39.00690055662586, 40.68325881035098, 49.92634765563473, 59.871191670817716, 53.9825608653407, 44.887494425619806, 53.23740074711462, 57.22369378612888, 55.11023444514121, 53.905325474277625, 49.48769330978394, 50.858746036406494, 54.092575503933816, 59.86054243579988, 51.641486383253536, 46.60846179531467, 54.975226463810095, 54.275903163417695, 55.678013217064645, 51.02477212106028, 49.54292812655049, 45.719695860339755, 44.56392634299494, 42.658999812218454, 41.83495690745693, 40.344134607622706, 41.230962891732496, 42.2682297614313, 39.29392783872543, 43.657427372470984, 42.49042026458248, 42.518084741407826, 43.70207178977228, 42.12672633509482, 42.18587175492318, 43.04099159855997, 42.073272274386504, 42.657324960154874, 42.36582225368869, 40.4879875336924, 43.75433344994822, 40.31447756674982, 42.79414115413543, 42.23305394572597, 42.82298626438264, 42.24341292535105, 39.61697816848755, 41.43929173869472, 40.83995357636483, 40.61309937507876, 42.099924779707386, 39.53494179633356, 40.31367740323467, 42.35156051574215, 42.22447179978894, 44.2958950996399, 46.235056077280355, 50.76744502590549, 54.238193496581054, 57.4475944426752, 57.65808059323219, 60.320087325188425, 48.269122723610174, 53.61800009204496, 61.556983224807254, 56.928370691114864, 59.910344769877774, 59.29073187612719, 59.383091926574714, 47.78931486991144, 57.61325182453279, 63.95138625175723, 69.91700926134664, 40.76219651006883, 1.0963255070870923, 5.369413427768215, 18.29934539333467, 6.809406713131936, 0.14079183790712588, 0.6377270733637195, 31.13801214002794, 74.30501184155865, 55.83545715578141, 56.92118883132935, 35.22050326870334, 46.90608339924967, 63.23575765855851, 67.57782536168253, 20.598030820969615, 0.3292514437869672, 0.16080951618571437, 0.13096634659074968, 0.11309078038339654, 0.15136860100732696, 0.12583104472967888, 0.2894068737664531, 0.1766593237557719, 0.16559689155509397, 0.12553799311600386, 0.16746254547709422, 0.1433306532881914], [0.034348854434586344, 0.019608303874490723, 0.034621397874528365, 0.044786924976975694, 0.050558164084870974, 0.02397438834211038, 0.0639303283946168, 0.08569458754913462, 0.013329411815521459, 0.020584782525416345, 0.031109147126816457, 0.01800933665025138, 0.04475271915115657, 0.06523576520022846, 0.06414295992844048, 3.560752892686475, 40.064304874789336, 51.172892585877456, 45.04520900787846, 38.133788801008656, 28.463708777581495, 39.72376469642886, 43.232917093461566, 53.98253340874949, 22.171026775913855, 0.06335477036754451, 0.08148736290393338, 1.8667590497962891, 2.9580054552324357, 1.2892253432543048, 12.054494734733337, 35.11213994795276, 54.47194322463005, 54.05870583749587, 56.13723254972889, 55.09512939760762, 54.79029847729591, 53.15748637722385, 50.611828911689024, 48.82462447689426, 47.545049267430464, 42.76023618636593, 37.46185148915937, 38.19018463934622, 37.96125550423899, 38.77768508849606, 39.13493848616077, 36.99827048086351, 38.451041867656095, 36.37961856780514, 35.66092660350185, 34.348446630662494, 35.0925830102736, 34.84096296371953, 37.29809645683535, 35.885035145667295, 36.088151162670506, 36.199436649199455, 34.704935166143606, 35.505086914185554, 35.994359447110085, 34.704582152828095, 36.59961646603, 36.448369872185495, 38.66085337054345, 35.92933439439343, 36.64254288519583, 37.64125677847093, 37.59679671256773, 37.021581126797585, 38.075953452817856, 37.175400795475134, 35.56485206850114, 39.158194218912435, 40.10566626825641, 37.02862962599724, 38.987951586323405, 46.93594440337151, 53.7478187776381, 44.52217271251064, 44.83442475718837, 48.30511046994118, 52.13839969327373, 54.44252544833768, 49.55406765783987, 46.35438634503273, 48.00107971314461, 52.03327232791532, 53.935421820609804, 47.58117037434732, 43.325183007024954, 54.03161402671568, 53.73970731612175, 51.35471013284499, 47.39785448197396, 46.16550460938485, 42.9476313437185, 42.66715049743653, 38.26153255278064, 38.2365745113742, 37.05936924103768, 38.00124014577558, 39.26314115524292, 39.23064039599511, 38.9909561218754, 40.00486135482788, 38.20348147423037, 39.84847253368747, 38.83937612656624, 38.2672631356024, 38.24682758700463, 38.377889663942405, 40.850190962514574, 38.51585119001327, 36.38459997792398, 37.86331392103626, 37.41484188264416, 38.40430290468278, 38.14095104894331, 38.21566043361541, 38.94122831283077, 39.15125162370744, 36.73066285348708, 36.719268368136504, 35.11755674116073, 37.47873337038102, 35.02585172653198, 35.69631030482631, 37.44732695241129, 36.48747982517366, 37.93713685004942, 38.743744819395005, 41.60900485131049, 43.02718877792359, 47.210788803715865, 48.77923088689005, 52.58430650157314, 50.414914161928245, 48.247918390458636, 57.13705255139259, 54.17143475624823, 55.52973193507041, 54.13391728555003, 54.55858838173651, 47.11067814980784, 52.701942305411066, 54.97405367512857, 65.42722117516303, 30.46736921033552, 0.2911058116343714, 2.880814681130071, 4.059012801416459, 2.4560227269126527, 0.033176100227020444, 0.3227222602694266, 31.63517648173917, 57.89707453020158, 49.41191311805479, 37.13494154714769, 28.08384487705846, 37.95451687228295, 49.61601364997126, 50.10673353748937, 9.511019087606861, 0.06455332641640017, 0.07282221900118936, 0.0220915453223091, 0.03379417996432993, 0.10681391558459691, 0.03224462158076706, 0.13002784291823066, 0.07294422616401026, 0.0643883187383894, 0.021062287043840177, 0.03626584390839262, 0.13401923761252435, 0.05656669509687251, 0.05114021470710155, 0.06248233794805504, 0.07364462204878369, 0.04106142790988088, 0.01430612508087389, 0.043444505276819395, 0.03690138278949646, 0.006048685510552699, 0.05629088046149381, 0.03752647606175273, 0.031213777500294873, 0.05078502187144853, 0.13269237332767056, 0.03372054359304809, 4.520639979070233, 46.59123474551786, 59.71335157271355, 50.69822695947463, 34.665519268282004, 32.47201219681771, 45.79130657257573, 47.50817114307035, 60.20211811988585, 24.181170886562718, 0.04040626951703622, 0.08303160463730175, 1.0266474201794595, 2.862339582174055, 2.0030388596557804, 14.478085098728059, 40.593397309703214, 58.75986652989542, 54.53384607068954, 57.938330019674, 56.53583165137999, 57.16496021516862, 54.87901464585335, 52.55549669265748, 53.56385569418631, 50.38804592624788, 45.04749182731875, 41.824013494676166, 38.49248955326696, 40.20683203974078, 40.97216098539291, 40.73358674203196, 39.174209256326, 40.65315461927845, 38.730797075456195, 38.05288991620464, 35.37772363232028, 36.15179946345668, 37.01692527340305, 39.132557607466175, 37.860376065777196, 37.79123252437961, 37.78991068563154, 36.87456677036901, 37.11744385380899, 38.0708896729254, 36.61089720264558, 38.31684189458048, 37.999651585855794, 41.84348806258171, 38.207737245867335, 38.60742284405617, 39.5826691965903, 39.6161074023093, 40.22905226676695, 39.85888642649497, 38.685144609020604, 38.45712938616353, 40.122461857334265, 40.83095958155971, 37.50926509980233, 41.08924373503655, 48.50786562888853, 54.493084799858835, 48.38278124409337, 44.23096810617755, 49.194221573491255, 53.03082519961942, 54.47501836284515, 49.5596884142968, 49.32287923751339, 49.084348140224336, 55.08400555579893, 55.60384119710615, 49.45991116185343, 45.49149236371441, 54.997599663272986, 54.94661277340305, 52.98848713597944, 48.06624597118747, 46.04808845827657, 45.31404433711883, 42.32813219870291, 40.56518762342392, 39.43990276705834, 39.457529898612734, 39.784612424912, 40.93379628273749, 40.51854279733474, 39.68113637739612, 41.61887745703421, 39.62232043666225, 40.407355370060095, 40.095040567459606, 38.57984465937461, 39.938263431672134, 41.21323377855363, 42.21064544493153, 41.03140838684575, 38.95633336036436, 40.312528148774184, 40.08938058730095, 41.49016095745949, 41.00097863904892, 39.82839784314556, 41.102815135832756, 41.08656475620885, 39.28552612181633, 38.59798954379174, 37.20254751943773, 38.3423843691426, 37.76807092851208, 38.43845105940296, 38.77054637478244, 37.619499391125096, 39.30396910636656, 40.613401397582024, 44.92561986369472, 47.38533035401375, 50.02697998477567, 51.948741328331735, 55.74117122157928, 50.936389353967485, 50.09401329102055, 57.52571236702704, 55.79866532356509, 57.63928067299628, 57.11353009746921, 57.416431211656146, 49.92561417241251, 54.31324804982832, 57.987893089171386, 65.67663684968026, 32.12419013823233, 0.46423999712832514, 4.377122905946547, 5.765440435178819, 2.446966954777318, 0.0292026128379568, 0.41686968577484934, 32.21711108761449, 64.18285316036594, 52.22161277647942, 43.06700083517259, 30.791484463599424, 45.82943201065064, 56.70945144468739, 58.14419169579783, 12.80001473042273, 0.13417345111168202, 0.0942610210228351, 0.024954502080236713, 0.027248642384825696, 0.03989443851394519, 0.0059669008365862315, 0.06898746630477329, 0.05067640975598366, 0.03925281689472256, 0.013175587105985372, 0.04996952127605196, 0.05180604853517106, 0.1838630630124, 0.10800633909961871, 0.20648999079581232, 0.1503223700508956, 0.1374290336764628, 0.09725907547098976, 0.14106454988641126, 0.22854322597624796, 0.12204256374388935, 0.2743215300142765, 0.18252619361925512, 0.08071940572511765, 0.13486597927347307, 0.3481784426877576, 0.2063443268378896, 4.534331012156702, 53.467926286881976, 68.06811378848168, 57.89336789038874, 49.67180152093211, 40.62021847694151, 51.61054280496413, 51.29663552007368, 67.16787492075275, 27.01520492953639, 0.34546643014877076, 0.19609737991084977, 4.548961943195713, 7.596394496579324, 1.7934758144040264, 14.030095511867156, 39.732401755548295, 61.164228454712905, 56.112823640146566, 59.34789257664835, 57.22409386788645, 58.0329179763794, 57.036698710533884, 54.170552222959465, 56.05949117291359, 52.8630889615705, 47.42379703829366, 42.607706977475075, 40.76253775627383, 43.05963854635916, 43.187527425827525, 44.438210456602036, 40.40490781107257, 43.15790960865636, 40.13945748729091, 40.66172499810496, 37.213067316239886, 38.57591836683212, 38.645952286258826, 41.45280430393834, 39.88284818587765, 37.655545973008685, 41.25779190371114, 38.556706597728116, 39.12454420520414, 40.2620433222863, 38.893661729751095, 39.9694658863929, 40.13514288010136, 43.65741952773064, 39.85374419919906, 41.01139645422659, 41.06654497884935, 40.570663252184474, 41.45785631672029, 42.75891826998803, 39.67108726501465, 38.64470105017386, 42.885163676354196, 42.58757345138058, 40.25390832654892, 43.403787305278165, 51.34300185788063, 55.444428228562884, 47.904106955374445, 47.160386347001605, 51.014118963672274, 53.99370431900025, 58.64221895894697, 53.488236319634225, 51.02793355141917, 52.171308379019464, 57.135962132484686, 55.475932705786924, 51.586063292718705, 48.85571318288004, 57.22766322474326, 57.66451720268496, 55.76407001864526, 49.86854760877548, 49.586635097380615, 46.90475371576125, 46.065939164930775, 42.309901022141986, 42.18743678062193, 39.70115615475563, 41.9518356938516, 43.175568119172134, 43.53280974972633, 42.11616731459095, 43.89860214725618, 43.038383222395375, 43.15659561464864, 41.83022652902911, 41.142003536224365, 42.6861543809214, 43.21520759213356, 45.00399666447794, 44.19723572269563, 41.14400394501225, 41.377722294099875, 43.366187464806345, 44.010566203824936, 43.13359483595818, 42.23436401736352, 45.49226899300852, 44.12602901458741, 41.06967895261703, 41.36516678717829, 38.41564247685094, 41.536448847862985, 38.624367483200565, 40.48841507204118, 41.38102885215513, 40.294308739323775, 43.066408557276574, 42.85092530712005, 47.57555746263074, 47.28240343832201, 52.63315569969916, 53.87101650238038, 57.31331209982596, 53.600588690850046, 52.15869795891547, 60.00357166413338, 59.28052586893882, 58.82241264466317, 57.726341601341005, 60.879923297512924, 51.26782178878785, 55.794664505989324, 59.79240694353658, 67.85400729025564, 33.07333507845479, 0.7178380520593736, 8.43106996628546, 12.330923772627308, 5.352485458697043, 0.1775271634781553, 0.6943324520703286, 36.76352447079074, 68.96160617951425, 62.20401348606233, 53.49056620751658, 41.4549498404226, 52.35159227924963, 63.98751520341443, 67.8659156060988, 17.6990972411248, 0.318455487609871, 0.202548238599012, 0.1439796676558833, 0.1431463325336095, 0.24671454042676957, 0.10990575451644198, 0.22854815958248031, 0.20047410150929806, 0.2180310747315807, 0.12293469611435168, 0.21824728006557112, 0.20468697222250126], [0.03738462722169296, 0.060057604550233776, 0.021061792917129014, 0.08103789145787878, 0.049587783493822625, 0.03785197532946064, 0.05032931830012991, 0.1015806463997691, 0.05366157860525193, 0.02368790784760589, 0.03358924378370566, 0.022394173035037615, 0.04239797171565794, 0.021381594405900088, 0.06588983574822065, 1.6666302854014983, 33.45014933616885, 48.52605365937757, 45.188489267902995, 29.256066776091053, 21.89395643049671, 33.26201285085371, 39.49798914694017, 50.22514204825125, 32.314405479738795, 0.2971402862139287, 0.07524888677101943, 0.3749080470973446, 1.219339493301607, 0.6591902829466328, 3.1821000239541455, 16.783804316674512, 41.98787050862467, 54.378343705208074, 53.61781966301703, 53.61007690429688, 51.81898932303152, 48.14741549953338, 48.56595200877036, 44.76714041925246, 40.81699986611643, 38.62514019012451, 37.784160490958925, 38.26085790511101, 36.550171067637784, 36.67634587134085, 36.62421364938059, 35.72202928604619, 36.733620320597005, 37.23001587775446, 35.6753570033658, 36.19754998914657, 36.718985957484094, 35.96742060876662, 35.911134596793886, 35.95279801276423, 36.450029034768384, 35.81209867231308, 36.09048105055286, 36.498446772175456, 37.11964038110549, 34.1077386179278, 38.15939795586371, 36.03779969676849, 37.33567276308614, 36.34406228219309, 36.43450821599653, 37.878579785746915, 39.106434622118556, 37.90653059559484, 38.14877617743708, 37.08660617951424, 35.28495565537484, 37.39271579250213, 38.39854486526982, 37.77431534182641, 38.95896919312016, 49.70056033903553, 50.31982806421096, 46.07867117851011, 46.87425728767149, 49.151577564977835, 51.692124182178134, 51.56779289245606, 49.110267162323005, 46.49976899546962, 46.80051672843195, 51.84144489226803, 53.77314159947058, 46.20268083387806, 43.705205763539965, 52.07347662218156, 53.213897905042096, 50.820989301127774, 48.15839421364569, 43.326646051099225, 40.454337519984094, 41.00869001880769, 37.221041494800204, 39.94037366682484, 39.161543923039595, 37.738433499490064, 38.11430638836276, 39.498279402332926, 39.31175501115861, 38.15068244934082, 36.61312903127363, 39.097009166594475, 38.267698518691525, 38.925103449052386, 39.618551038926654, 37.981322350040564, 38.143810456798924, 36.80210490380564, 37.13061125047746, 37.60205268859863, 38.278426201112815, 39.65631954131588, 37.79944988989061, 39.53837387023434, 39.73382165355068, 39.93640422821045, 39.22212100798084, 39.22018727948589, 37.47239482018256, 38.486696212522446, 35.495794819247344, 35.45535518277076, 35.07637577672159, 34.7679715771829, 37.09525892811437, 37.953351928341775, 38.5537334411375, 40.118366902874364, 44.334808934119444, 46.785231251870435, 49.77127675087222, 55.74756468496015, 55.026786019725186, 53.30728561647477, 54.78488952882829, 54.60327202273954, 53.845783895061864, 57.713472304805634, 52.42194391066029, 52.68580567452216, 58.27742284344089, 64.41899945659023, 22.608941754987164, 0.37803619859680054, 2.7236394247701092, 3.310529209913746, 1.1445322945233316, 0.008680018457403828, 0.2849898865867046, 29.551262394074474, 58.38196577564363, 40.1790734260313, 34.93355443400722, 21.84767638483355, 36.223731810046786, 49.41353697930613, 44.17745128754647, 5.196258435326238, 0.029647943578780662, 0.04642012484011151, 0.0232934185318769, 0.12291903727717939, 0.05218104091322711, 0.009461364937916158, 0.060625731524440556, 0.05388644456322636, 0.027282208527228045, 0.01931068254634738, 0.03389217027072464, 0.04666437665300985, 0.021964089359126745, 0.06075769783027711, 0.0503942480821523, 0.034379068942319964, 0.03926844125793826, 0.06299817176055043, 0.03000417063313146, 0.09670962188993731, 0.040785574970105966, 0.07931504398584366, 0.030769909987406387, 0.04269474651664496, 0.07712954835545632, 0.08940446791389296, 0.09570560237813382, 1.9931423519888234, 40.762047460002286, 56.58364142141035, 53.455700259054865, 36.896049591802786, 27.278517561574137, 42.09313907930928, 47.15196894061181, 56.71639011752222, 34.87462082216817, 0.2975351892171368, 0.09597766318268354, 1.2504585976562193, 2.815458188133855, 1.81129097457855, 5.586594573913082, 21.569766652199533, 44.74428869062855, 55.92977446894492, 55.43313964720696, 55.31243654989428, 53.60621336967715, 49.41802024841309, 51.262161808629195, 47.39540692298643, 44.55294370651246, 42.207429101390225, 39.90422510331677, 38.01839267053912, 38.35894461601011, 37.68166111361596, 37.88422799879505, 38.83981150965537, 37.89960368987053, 38.5686384477923, 38.09213322977866, 38.85375553561796, 39.96736349598054, 38.24927514599216, 37.337120117679724, 37.38404735442131, 37.205940369636785, 36.851554224568034, 37.6469285257401, 38.43456006819202, 38.13523615560224, 37.367341979857414, 37.85757157110399, 38.439737596819484, 39.413885685705374, 38.013238676132694, 38.65624458559098, 39.123108617721066, 41.07433872838175, 39.14324998855591, 40.67977966800813, 38.70337578558153, 37.19348684433968, 38.14488126385597, 40.29352818765948, 38.33338252959713, 40.533028110381096, 50.01198868597708, 51.47827263801329, 51.39825236412787, 47.09551818909184, 51.10940510226835, 54.84545092428885, 52.355369521725564, 50.67154699756254, 48.305471327997026, 49.77268880413425, 54.04740548902943, 55.51605463027955, 47.7327464472863, 46.31575884357576, 53.681973949555434, 54.23469082001717, 53.0892724375571, 49.77333991758285, 43.732336798021876, 44.26630473905995, 43.636854540917184, 39.73544551480202, 42.17782305132958, 40.0805748662641, 39.93179544325798, 39.42287575814032, 41.37794586919969, 42.294023267684445, 39.09282791999079, 38.245572428549494, 41.57783769792126, 39.52146453242148, 41.82622963382352, 41.54009665212324, 41.295466269216234, 40.403613428915705, 39.334869538584066, 40.06865086094026, 39.63963377860285, 40.23920728314308, 40.82817077636719, 41.1767400464704, 42.14521638808712, 41.18180382636286, 42.76131876053349, 42.7580161248484, 39.99030936148859, 39.70479611427554, 39.570615753050774, 36.69889949983166, 38.74041864948888, 38.00631569277856, 36.32815314877418, 39.94725350410708, 40.476742098408366, 40.806295717916186, 41.98054352114278, 48.24840868673017, 49.864119252850934, 52.86406955411358, 55.18965851876044, 56.9606125739313, 54.21786777434811, 58.02001730088265, 54.90269007221345, 55.60909717313705, 60.00190857918032, 54.85183654292938, 56.22896502094885, 60.4721183930674, 65.7586104639115, 24.846669627774148, 0.5800104994447001, 6.247916971483539, 4.880909189101189, 2.619589485468403, 0.08145512592407965, 0.41997534493284844, 32.18682254514387, 63.451793962909335, 49.50452812256352, 47.34445141207787, 28.6194464852733, 39.94287613899478, 57.09076073861892, 54.42343527270902, 6.4566223659823025, 0.11217600245389248, 0.030995892518530452, 0.04092178540304303, 0.10589614991218814, 0.053381493029695366, 0.017101505223000725, 0.026264514345976136, 0.016307579578771707, 0.033092313190741886, 0.035285967657522815, 0.10347524312354865, 0.07471834790081748, 0.14377476977965525, 0.21811649353513796, 0.15782952609081424, 0.14557299264256032, 0.15459787611278797, 0.15265504649329573, 0.1391103362003642, 0.16600996616386599, 0.15965912791509784, 0.17550449217519454, 0.1508751790970564, 0.16836335762373864, 0.1902308777695702, 0.18560464133418378, 0.2213254979541225, 2.34855983526476, 45.650611154494754, 64.70881162151214, 58.92864611841018, 42.11355109368601, 32.68073131961207, 46.83241344267323, 51.45942172696514, 60.50164991809476, 39.528681693538545, 0.7219947838494856, 0.5352127419844751, 3.42371704597627, 7.008962198611229, 2.7845964893218014, 5.098332051307925, 20.187854843754923, 44.90537258886522, 55.95815281714163, 56.8239297405366, 57.54547326795517, 55.793075946069536, 50.00347322033298, 53.2277399493802, 49.69456303504206, 45.3269136336542, 43.30714402660247, 41.579685134272424, 40.905778792596635, 39.9742982464452, 41.667377564214895, 40.95257266875237, 38.981354159693566, 39.19534298681444, 42.005368201963364, 40.060959093032345, 40.96988993306314, 42.54376449892598, 38.1357813650562, 39.53158816983623, 39.58989028007754, 40.031506015408425, 38.69659792992377, 40.11127525760282, 40.07965703164378, 40.4880855929467, 38.5029112908148, 41.870650476025, 41.49138473695324, 41.68479681015015, 40.69778726946923, 40.75901154548892, 42.126204659861905, 42.83523974880096, 41.42805022578086, 41.28486802501064, 40.82240096984371, 38.0788520843752, 40.80582503349551, 42.503124821570616, 41.59444109086068, 43.06197235661168, 52.40167310160976, 54.91347659018732, 50.06133602511499, 48.85850591044272, 52.53619078666934, 55.01139071679885, 55.85072694286224, 52.35259640601374, 49.53704849366219, 51.572480124811975, 54.91581432281002, 58.14517228834091, 50.068866975845836, 47.425244392887244, 56.57185469904254, 57.66949469043363, 54.057599729107274, 51.72805309295655, 46.154933821770456, 45.513779271033506, 44.56879008200861, 42.12729507876981, 45.202429371495406, 43.4165193188575, 42.07834782138948, 42.149934999404415, 44.07261809995098, 43.20258148254887, 39.95209370889972, 38.998134059290734, 45.10311888110253, 42.02860432286417, 43.88934143127934, 45.23263554419241, 42.78879496359056, 42.74331900381273, 41.30743342061197, 42.59020143939603, 42.621505875741285, 43.642879301501864, 44.41385253783196, 43.351372672665505, 45.485236183289565, 45.103303232500636, 45.47310429234659, 44.6535328895815, 43.416993925648356, 42.10534157291536, 42.38213931360553, 38.9506890696864, 40.891513132279925, 40.31784688272784, 39.45603939794725, 41.54567818487845, 43.26516682101835, 43.75075624835107, 43.96960881448562, 49.88321335084977, 51.25397582207957, 54.11336798821726, 59.491419945993734, 58.77970980059717, 55.48155738461403, 59.67229612411992, 59.161595682944025, 56.50594711303712, 63.47457508887015, 57.682018818393836, 58.69534746293099, 62.832177146788574, 69.49014556023383, 26.41071277280008, 1.1854641884565353, 7.863134299555133, 11.163559729053128, 4.445525119381567, 0.18573870672093284, 0.7931831671345619, 36.276813245588734, 71.25583187226327, 53.36827847265428, 49.39977338237148, 33.81894234688052, 51.07830070680188, 63.20325297694053, 64.59728687040268, 9.995505348328622, 0.25424647175015946, 0.14983227296221643, 0.2216322395590044, 0.20076496977238886, 0.18473873215336956, 0.08135620865129656, 0.19644974971250181, 0.1160277316587106, 0.14626642478810203, 0.16532929704314278, 0.2345895595968731, 0.14414004050195217], [0.0730978804189832, 0.024719362883197687, 0.011581489328114737, 0.02837773149592742, 0.03298816353743596, 0.0319246802809498, 0.03425788915445728, 0.07161483378900636, 0.055737776471482176, 0.046046224137347554, 0.046014998393553885, 0.08983337756005988, 0.03436851991160262, 0.048258529014645085, 0.05547817991746049, 0.1667847568469663, 22.035636363490937, 44.01665372233237, 43.55839929273052, 33.39059598984257, 27.244516495735418, 30.737300842039048, 36.6440059292701, 51.11002875912575, 39.83504233821746, 2.078751758221657, 0.05815262733508022, 0.15442539907751546, 1.8053724857107287, 1.1806538917364613, 0.9614052275015462, 5.8990976502818455, 25.958638037404707, 49.38338964216171, 56.14639520645142, 49.90527276069888, 49.97908000023135, 46.95662313891996, 43.48217979554207, 38.294386325343964, 39.25149956057149, 37.26829036589592, 35.89909292036487, 35.03569295329433, 35.19020688149237, 37.24561514392976, 35.210010928492395, 35.58543666716545, 35.72823447565879, 35.416374667998284, 36.66209590050482, 36.373613419071326, 36.98279280816355, 35.92307429159842, 35.99344161248977, 36.25974701296899, 37.09066975501276, 35.14948875673356, 35.15708638775733, 35.916233678017896, 35.70858340109549, 37.26520738294048, 37.559330232681766, 36.03844296547675, 37.89077835698282, 38.25724147981213, 40.810610325105735, 42.70229101181031, 38.12526156825405, 36.7625242663968, 36.87568856823829, 37.99176369943927, 35.393283674793864, 37.47521108196628, 36.958293684067264, 38.62238276389338, 38.47091651731922, 48.56115102767945, 49.927081138856956, 45.189897398794855, 46.94926085010652, 50.69608926773072, 50.224184989929206, 54.56260488879297, 51.32024426614085, 47.17458924939556, 47.52832035864554, 50.27134364651096, 53.03027214542512, 48.005727721798806, 41.74502480414606, 50.14310567609726, 52.14369489300636, 50.692429696359945, 47.471151813384026, 42.94297156795379, 41.63471206541985, 40.72247466733379, 39.729408987106815, 37.93618763646772, 38.69477795016381, 38.9661471305355, 37.72342651121078, 38.17071399381084, 39.10345754315777, 39.46372724348499, 39.055647773127404, 39.35910586387881, 37.13196446818691, 39.768507172984464, 40.63109128705917, 40.48361801332043, 39.11738980200983, 39.93028533074164, 36.63451771582327, 39.52035842403289, 38.419623682575846, 39.31959582913307, 40.73761501619893, 42.46081421452184, 40.52834480039535, 39.93319180703933, 39.80589128309681, 40.733555363070586, 40.749750829512074, 38.9820719534351, 37.74364632944907, 36.92732657155683, 36.13892232218097, 35.97881901648737, 36.83688848249374, 37.265470181742025, 39.0802724130692, 38.73321717785251, 41.843268409852065, 46.46522075899186, 50.134390169574374, 51.93100829278269, 51.592766623343195, 52.301970374199655, 53.012260621593846, 54.11664316731115, 54.05275560194447, 49.962527598104174, 52.76661826718239, 56.47368954073999, 57.71430384728217, 53.61156740496236, 16.903832766317553, 0.8066547313524831, 4.107897791170305, 3.3709074797168856, 2.1025443653906546, 0.05505082159934025, 0.3541447967290879, 33.607420690598026, 55.48055718022009, 41.91052136882659, 36.447640311333444, 21.228908761855095, 37.27271872182047, 51.535539242529104, 39.915854930877686, 3.501799914144701, 0.05260779019144755, 0.02615810664851339, 0.01820265319228413, 0.10301504644655413, 0.14863976517752295, 0.08331678852799439, 0.05117885235156264, 0.06237045080671388, 0.03177611284979409, 0.05706599290152231, 0.025130842113867406, 0.01267782243479404, 0.057834754472658526, 0.020911270046546575, 0.03456782151554381, 0.013168573571038584, 0.010462736658331369, 0.034332441000808636, 0.07122742312569773, 0.01084065740747798, 0.0638662183266734, 0.01384576273736574, 0.04648305896309115, 0.07411663946244987, 0.02840474567135736, 0.015667150183881245, 0.009489670929108417, 0.29052355416840125, 26.849951551806544, 52.13466559686969, 49.72166269056259, 36.70970170728622, 29.03954213665378, 36.81561746904927, 40.26373778620074, 57.77210781651159, 44.07490484176144, 1.9415325407058963, 0.06566478209870477, 0.23510104586039823, 2.8386055654095066, 2.108217583548638, 2.4035512199324947, 8.923924603769857, 28.508845452339422, 52.52085431929558, 55.835865082279334, 52.48626293674592, 52.26324481348838, 49.887810368691724, 44.99629705182968, 41.179689668839984, 40.732206067731305, 40.32510326754662, 38.57017993927002, 37.327078850038596, 37.84185071145335, 38.32817362200829, 37.35018161035354, 37.46056495174285, 38.05908333870673, 37.93956479718609, 37.21375765339021, 38.700990984516764, 37.48546415759672, 37.20888606963619, 37.57667103121358, 38.043990058283654, 38.16897638382451, 36.83256210819368, 38.063299886641964, 37.315672597577496, 37.98883761129072, 39.085571535172, 39.15417378948581, 39.50725770765735, 39.50399821804416, 40.252041278346894, 42.29231311428932, 44.990703751963956, 40.28925672654183, 38.800921209396854, 39.02785778045654, 39.35978443391862, 38.140488209262976, 39.37298320954846, 38.591650993593284, 38.69058493644961, 41.29124579891082, 49.884794066029215, 49.96819934537334, 50.13869693202358, 48.78467905905939, 51.066639500279585, 52.23841621029762, 55.42394953389322, 53.482694010580744, 49.228220678144886, 49.8945725348688, 53.345218858411236, 57.287514671202636, 49.79326948042839, 44.619451415154245, 53.25520830769693, 54.1778439091098, 52.248218213358236, 48.337952475393976, 44.69073657066592, 44.663181920205396, 43.6977767944336, 41.29800404271772, 40.80171438955492, 39.771676448083696, 40.95092135090982, 40.54619550704956, 40.36190686687347, 39.59939418300506, 40.80409919061969, 41.481629802334695, 39.91557252022528, 40.29601104797856, 41.28538185550321, 43.539387564505304, 41.85497668481643, 41.97853918998472, 40.69549268291843, 39.40891604269705, 39.784475141955966, 41.70097266474078, 41.541194915771484, 43.25145421489593, 43.28824996948243, 42.12427485373713, 41.69125695382395, 41.17966613461895, 45.12919872037826, 42.044250657481534, 41.855447369237105, 39.67937131081858, 38.571878325554636, 37.44505982245169, 37.18979589400753, 39.266377110635084, 39.20546662422919, 40.91736155171549, 42.18233377702775, 44.51520266071443, 48.75633601219424, 52.94217178898474, 55.00912750920942, 53.309595892506266, 53.06509494781495, 54.63507460009668, 54.856104081676854, 55.832531067632864, 53.44881649940245, 56.306847603090354, 58.44209963275541, 62.510150555641424, 54.33660184183429, 19.342384030742032, 1.318312046989318, 5.439744466735471, 7.417177481036033, 3.04430274713424, 0.08558362737418183, 0.4651894865016784, 37.2092116263605, 61.84527351010231, 48.78172943668981, 37.94211433779809, 23.380099342715358, 45.468248398073264, 57.999005163869555, 47.27360948439568, 4.89744492115513, 0.1730292927353613, 0.054428919083288604, 0.03436008911399591, 0.029477322391504725, 0.00981466266356649, 0.039792058523744345, 0.03888733932868608, 0.02030343290478472, 0.08473641073872006, 0.03309593295618411, 0.0133070832253584, 0.06840173846050616, 0.25582787640873467, 0.1947576147053511, 0.16266767776781516, 0.10046355997122104, 0.115869450232675, 0.14001758348557258, 0.14402708849839627, 0.1294123065928298, 0.1842971284302973, 0.09851697652089982, 0.21320265237121813, 0.2047471714115912, 0.11436122229262707, 0.09023713653967266, 0.1861478283160156, 0.308748479451864, 28.800052019857592, 61.56566342999859, 55.820371720098684, 47.53524726436984, 38.18963942989227, 42.57795972208823, 48.14292438568608, 61.230583190917976, 50.90848169019146, 3.2414834826223315, 0.14257263993063282, 1.2563889762086253, 6.4889662304232205, 4.397650139947092, 2.612464745198527, 8.256889274043422, 29.726419756489417, 54.006503012872514, 59.56778457087856, 55.68261807964694, 53.85675868680401, 51.82573972209808, 46.86561238381171, 42.97967710802632, 43.049326635176136, 41.38601418464415, 39.048309018535, 39.6805166429089, 39.3218433472418, 41.29338349065473, 39.50077402976252, 39.2704132295424, 40.9378755477167, 38.37371626207906, 40.72443585241995, 40.40640615647839, 39.796316777506185, 39.108470332237985, 40.905884696591286, 40.89682402149324, 40.81010826172368, 39.64813355476626, 39.07682072731757, 39.23158176483647, 39.297540341654134, 42.50627056244881, 42.22366379153344, 41.49624063122658, 42.01605666068293, 42.69300283924226, 45.82080671864171, 45.811832335687455, 43.265723797582815, 40.54053944926108, 40.31852153039748, 40.10226949568718, 38.50476264953613, 42.01856697759321, 40.53672690545359, 41.34619036028462, 43.692387457816835, 51.961987172403646, 52.939449664085146, 47.03544316753265, 47.07658490827007, 52.22322879299041, 54.1097358734377, 58.27592057566489, 55.61601623412102, 51.45869608848326, 50.830238249994096, 55.03714892172045, 56.54277424658499, 52.843696763438565, 46.1992330704966, 53.10408722969794, 55.73966895380328, 55.270620161487216, 51.33223102938745, 47.1620729661757, 46.36128579416583, 46.623743349506015, 43.96998928439233, 42.855302672232355, 41.615696414824455, 43.03410783890755, 41.14562780626359, 42.08936183683334, 41.37006190515334, 43.026168961678785, 43.042623304551654, 42.61941525243944, 43.12015287337765, 43.94703949651411, 45.66559853092317, 45.361442258281095, 45.07797648829799, 44.349423685381495, 40.79732917970227, 43.39174955121933, 43.08458874302526, 44.19872230099094, 46.63371401448404, 46.86214500857938, 45.855460859114125, 44.56291044912031, 44.1946469583819, 48.08233161126414, 44.917606461432676, 43.98958152340305, 42.66567960862191, 41.16875802316974, 41.15916390572825, 41.11973624075613, 42.49742954008041, 42.827347940014256, 43.27545519798033, 43.202738377355764, 46.04553107292422, 50.253924400575706, 56.26136379857218, 56.88543250483852, 54.84663940245106, 56.334994531446895, 56.172082808709916, 56.42642498016358, 56.85075483014507, 55.21714256655786, 59.20863274605044, 61.8879214409859, 63.78123775605233, 56.89810960523544, 19.974848570362216, 2.703545122377334, 11.107089365682295, 9.763868797209955, 6.440329330582773, 0.35182122141122824, 0.4803033593681551, 40.00760701394851, 66.58145704577046, 54.07118681938418, 47.48790033401982, 32.508029360925, 54.133725089411584, 64.71999822124359, 58.60025352047336, 7.363824421359647, 0.35340858623385435, 0.14200512199632584, 0.09589975204078421, 0.2417346778055353, 0.2190272341812811, 0.12546202017655297, 0.09386060218657218, 0.1654053082869899, 0.25449791712866676, 0.11781504542957391, 0.0778478860194164, 0.12938783774452825], [0.04895781024148868, 0.08131926023070851, 0.016227080974908128, 0.06553093887745373, 0.019149110772677006, 0.03481514534101852, 0.022780675884155978, 0.09667158562449679, 0.053376486645110195, 0.08317647952466242, 0.0259018195943246, 0.08760911788070395, 0.049542139975294, 0.0655407754464015, 0.02918985747401753, 0.05353675989974892, 13.522325081209983, 40.90599844532628, 50.51674673634191, 31.52148069873933, 18.64036213967108, 36.03358707120342, 40.21883841483824, 50.20704030990601, 46.10688086478941, 6.423063057084238, 0.049501560297944856, 0.16726445046163377, 1.6077867655023452, 1.0825403371164877, 1.1866716655992693, 1.5370639798141297, 12.528222914664978, 43.426074212597264, 53.05607741878879, 50.64850307280018, 46.61993472806869, 46.5092650536568, 41.731096467664166, 40.36351111627395, 35.5428397270941, 36.56764522675545, 38.87107279992873, 37.79172282065115, 37.71904522372831, 38.34654208152525, 38.2892244861972, 38.542680201991914, 39.819952980164565, 37.81369593835647, 37.85531620825491, 37.20461068614837, 35.57708201869842, 36.36980872000418, 37.16404945619645, 35.523408305260446, 37.818069381098596, 37.789632197349306, 36.30049259431901, 37.79122860200944, 35.57698003707394, 35.58553472641976, 36.462792427309104, 38.28389398513302, 37.843423581892445, 37.89607747908562, 38.82458486864644, 38.48044395446777, 37.685410899500695, 36.491692450738725, 36.9008937189656, 35.97217059904529, 35.599608190598026, 36.63856952421127, 38.19169475186256, 37.267447056308875, 39.62971018206689, 46.06234235148276, 50.430854674308534, 42.76394674854894, 51.06194442318332, 48.50704977589269, 51.257847201439645, 51.70709194675569, 52.177705764770515, 48.884691653713105, 48.46154635952365, 50.7286645520118, 53.50734610711375, 44.01699889090754, 42.373749363806944, 52.19951806529876, 53.204660723286295, 51.74930057217998, 43.95181302101382, 43.18948076617333, 40.86570785891625, 40.42943439176006, 41.12174057191418, 38.498377030895604, 39.3049693107605, 37.378893360014885, 36.74898424456197, 39.80476164048718, 37.73869237592144, 39.98375508093065, 38.07995819276379, 39.12727417484407, 38.47777282038043, 39.404883846159905, 38.70452896241219, 38.407040719063055, 37.480639642284764, 38.57996625284995, 38.767184903544766, 38.540467985214725, 38.78352549768264, 38.679794496105565, 38.29317823533089, 40.8788634884742, 41.25029233194167, 40.8950158088438, 41.08237174249465, 40.521472807853456, 41.07033006606564, 41.31863178745393, 39.4760670200471, 37.504581789816584, 37.01997295502694, 35.691438721072295, 37.47727817104709, 36.93670495863884, 39.2556494282138, 39.271531105041504, 41.617975311894575, 44.80900387610159, 50.947242552234286, 50.421389995082734, 54.96826817912441, 52.41650358323128, 54.31504841773741, 55.14191542902301, 56.32484735981111, 43.42786281339584, 47.43033955174108, 59.79298745432208, 57.1313690370129, 44.3702083249246, 11.914379827437863, 0.6129243945883167, 7.108028521460872, 5.083386840358858, 1.1785309088806952, 0.051755827641294855, 0.3947070992041019, 36.45166074076007, 56.528983193059126, 50.51151821690221, 46.95386963505899, 30.874556341478904, 36.9242985017838, 51.15508110292497, 35.918877355514034, 1.846748097769676, 0.11371515736344362, 0.025429445949773637, 0.021714949905271494, 0.03774441658489166, 0.01829695095488381, 0.03017419810226608, 0.005488961563265372, 0.02425156469877449, 0.04804302082066575, 0.018693637027735674, 0.028115802204176307, 0.021123543434265642, 0.07695696406787442, 0.05043195492978539, 0.023018182292881034, 0.017522229219696695, 0.031157977571110093, 0.050103582832361424, 0.011784855028494232, 0.0739129749877799, 0.03363821978470491, 0.07110910850667185, 0.08958258335628817, 0.0068923273882378015, 0.04057909512231427, 0.016069958256858013, 0.022664468006921873, 0.03238941602889569, 16.140574832116407, 49.04050388643819, 54.59300717999859, 40.72661669023576, 23.375982815219512, 38.20698415079425, 48.25317436648954, 55.393457028173636, 50.17081722136467, 7.136922661335238, 0.0370984397558195, 0.14814406032523803, 1.7422364219542474, 2.8826069591506838, 3.603400823570067, 3.596657043503177, 14.800883416206608, 45.45549285027289, 54.76040609421269, 53.38065355054794, 49.050509852747766, 48.666152877192346, 43.40094358690324, 41.43898971619145, 38.82646368395898, 39.7213210598115, 39.67166777580015, 40.01269825043217, 37.88204323860907, 39.58535602015834, 40.68579266148229, 39.466049286627005, 39.54441039792953, 39.5200603238998, 38.94007905837029, 40.01024676907448, 37.509076826034054, 38.75100512658396, 38.865903116041615, 37.839591426234094, 39.26662814232611, 37.915163732344105, 38.19393050286078, 40.34385611934047, 37.91323392621933, 37.38223129703153, 39.19148729693505, 39.50215470406317, 39.43582350207914, 39.1542600816296, 40.80002777038082, 41.00725050895445, 39.225153000124045, 39.42951240847188, 37.85060151930779, 37.03262259883266, 38.506916030760735, 40.209856187143636, 40.43844407604587, 39.14878445286905, 39.81857622823408, 49.33350101594002, 51.31223478624898, 49.844075941270404, 54.911613464355476, 49.08938054115542, 53.99183727079823, 52.07780299648162, 52.81095281724007, 50.11055784840738, 49.83000247709213, 53.89987730210828, 54.04906857398249, 47.11616946804909, 45.959631166150494, 53.56772315117621, 52.41464830213978, 52.82652462682417, 47.603755381799516, 45.78226158695836, 41.93780537574522, 42.30099724185082, 43.60914299564977, 41.26224379385672, 39.368601922065984, 40.90245654506069, 39.50615552163894, 40.3704458667386, 40.71572034589706, 41.4022292629365, 40.26730714305755, 41.063987593497004, 41.70302014197073, 41.179191527828095, 42.08626316439721, 41.43852687651112, 40.344923004027336, 39.93385468759845, 39.905225307710715, 39.940773748582416, 40.45473760174167, 41.20160395099271, 42.17730529846684, 43.01241713185465, 43.09595969415481, 42.38121363424486, 42.67885877240089, 43.87898637402443, 43.24821041476342, 43.71032837898501, 41.92668153393654, 39.7153982808513, 39.516698852662124, 37.69327525169619, 39.66277184024934, 39.31937225403325, 41.99134572859734, 41.090836217326505, 43.081666577246885, 48.69242099023635, 53.57084535783338, 53.95899134297525, 56.06288010074247, 53.57230840190765, 57.130184481220866, 55.249870823275664, 57.20855343726374, 45.041706331314586, 49.440624867716146, 62.2806409097487, 59.44122145252844, 47.97000277426935, 13.628256532453722, 1.13037952492314, 5.4572426503704445, 5.092871621731789, 2.41428870827921, 0.17567811834235347, 0.515812760399234, 41.28320494005757, 62.516653845387125, 50.900072128542014, 49.246047850578066, 33.301777839660645, 43.40619956293414, 57.08355534461237, 44.56111400358139, 2.9439113986107612, 0.23112593819537472, 0.05171301481764644, 0.020123316057687326, 0.03082146195905103, 0.048107548406527895, 0.022989314184674335, 0.008871242621793382, 0.01984286467514692, 0.04467275106318055, 0.013468620525072179, 0.0557566452170572, 0.076020467545717, 0.2216460904286754, 0.14217496368913882, 0.12351752814626503, 0.09352864096722296, 0.17091983899233804, 0.16204385237107355, 0.11191769292758358, 0.2771274342892632, 0.1528419106597862, 0.2523690813611592, 0.18570734308131281, 0.15902948025013172, 0.2630608342587948, 0.12566697167893573, 0.14509864632160435, 0.13182920674162527, 18.888055893682665, 56.98928117752076, 66.3385368162586, 45.58637057581256, 31.855505820243593, 47.66083763491723, 52.3343534623423, 59.74072971651631, 57.6376332775239, 9.573279849944576, 0.2988353936422256, 0.5757758718344473, 5.768484194432536, 4.639315701300099, 6.293843023238644, 3.7448454143539553, 15.244071041384052, 50.58095593606272, 56.484825149659194, 56.52362915777392, 50.93858980363416, 51.500379116304465, 45.818339547803326, 45.14031471744661, 38.49169331212198, 41.2411924331419, 42.50773752889326, 42.329905110020796, 40.10723129395516, 41.5779592913966, 42.34899920801963, 41.31838860050325, 43.096500981238584, 41.985328812753, 41.67207656368133, 42.54334088294737, 39.01924817792831, 40.21474738274851, 41.79878480972783, 39.77446133090604, 42.27233256063154, 40.44268808057232, 40.22471412535637, 42.957527483663256, 38.791432995950025, 37.81562182211107, 40.73472030701176, 41.33740425109863, 41.711751337974306, 40.59899453193911, 42.84669699207429, 42.509828152195105, 41.93525583513322, 40.60670198932771, 38.71096557186496, 38.80633015786448, 40.40237788231143, 40.94748927700905, 43.39490313683787, 40.7755914042073, 42.06302704349641, 50.60901657227547, 54.554556185199374, 48.40722545500725, 50.393768664329286, 51.918182142319225, 53.465792517508234, 55.767474635954834, 55.28524667985978, 52.86812528487175, 51.606083070078206, 55.016572167796475, 55.727933222247714, 49.22457287388463, 48.5562559097044, 54.47393186630742, 55.09449397363971, 55.68007246140511, 49.92177809438398, 47.537737969429266, 45.12078131398847, 45.53564648474417, 46.20447335704681, 41.2555012395305, 43.57605388087612, 41.45434187304589, 40.219646423093735, 42.79898135892807, 42.31276435236777, 42.830203425499704, 41.593283991659845, 42.74283262991136, 42.450619974443995, 44.254761203642815, 43.76385304235643, 44.65149325709189, 41.576260905111994, 42.93021209778325, 43.23602753300821, 41.74971595887215, 43.35918603404876, 44.35973167419434, 43.60385564065749, 46.658385722867905, 45.62205629964029, 45.34001827239991, 45.02430669723019, 46.93779576209284, 46.461380758593165, 46.69428325468495, 44.359947404553814, 43.50425881724204, 41.84763008548368, 41.032840051958644, 42.96987118259553, 42.59167232821065, 44.62604884178408, 42.74017718530471, 45.04930003996819, 51.41203557291339, 56.23342475583477, 56.57219202287736, 58.9499524331862, 55.858222592261534, 60.54962442767236, 57.19397790970341, 57.63592312412878, 46.214444022024836, 48.35159055648312, 63.71387889308315, 59.5546446308013, 47.998541939643125, 14.675733331711063, 2.233875124685226, 16.428894535187755, 14.345203042030336, 3.466003138211466, 0.3168813914300934, 0.7036243631474434, 45.86802028840589, 67.73555955579205, 60.701023993953584, 57.3025373489626, 42.772026831103915, 52.34745417871783, 64.36088169774702, 52.54972296376383, 4.013627056152591, 0.30148296286502196, 0.17647085080464042, 0.08297524354871243, 0.1301461881807735, 0.1547361396613621, 0.17436354210780514, 0.08040777647927885, 0.10638245486564214, 0.11029082095070232, 0.15172170625338632, 0.11435875548951088, 0.15426882602755101], [0.028989054337744753, 0.050009039921625975, 0.0660373000127654, 0.008618637577690666, 0.03891294964799478, 0.027521530564333645, 0.048644242793201446, 0.035424127784227176, 0.055330259830600796, 0.03921720912800201, 0.014204905713878333, 0.05599137072661712, 0.03077223314903677, 0.013560969551514476, 0.024650836318370797, 0.04178366879181516, 5.168201721483662, 38.63346345963017, 52.320817362877634, 29.70432112293859, 26.76981164563087, 22.685820210364557, 32.65905630203986, 48.30740505649198, 49.361447903417776, 13.725931394484736, 0.08927578046437233, 0.284477343121844, 1.1497098231507887, 1.3774586925583503, 2.6717533315381696, 1.2504798029699635, 5.318982533870205, 35.05992927858907, 56.803878584215724, 50.055499538298584, 51.6884449989565, 45.86330559945876, 43.89565644725677, 40.46710483489498, 40.54178676297588, 40.1693263361531, 42.74764930048297, 43.86519139812839, 44.39382491573211, 43.53116627662413, 43.21746687735281, 42.695940694501324, 40.66066595815843, 40.80063966012771, 39.87042211717175, 38.150047025372906, 39.72553368537657, 37.86996233847834, 38.30814992227862, 37.18141771131946, 36.43226069788779, 36.767835155610115, 37.11789492637881, 36.4332373680607, 36.442305887899096, 36.42158008390857, 36.452719780706595, 37.11167012491534, 38.796014324311294, 37.491481073441044, 38.14333977237825, 37.58178972428845, 37.38310598557995, 38.262222889930975, 37.833225419444425, 35.08272609403057, 36.52322438455398, 36.39612782386042, 40.0833519043461, 37.027637266343646, 41.19361016058153, 45.20492007655483, 54.551202558702045, 38.53884412396339, 43.960983522476695, 57.88281671462521, 47.25656678599697, 54.837417910175944, 52.38796049548734, 51.232391019021314, 47.9374235676181, 51.77998135166784, 50.68544395508305, 44.81519729860368, 43.475825555862926, 48.09615404375138, 50.77963575240105, 50.62268995469617, 45.29158876788232, 42.636304978401434, 41.308872930465206, 41.50616422776253, 40.71268443138369, 39.806565930766446, 37.238782375089585, 37.68255541401525, 37.86776973355202, 38.73947728064753, 39.1182017326355, 39.028971733585486, 37.935254112366714, 37.327796643780125, 37.94000410264538, 40.4260140849698, 39.32815444084906, 39.374022637644124, 38.13468702377812, 39.40770795268398, 37.26009261223578, 38.29016193266838, 37.83975224341116, 37.78506655846873, 37.63152537807342, 38.571541001719815, 39.34774667985978, 39.19290327256726, 38.430053264864036, 39.7050275341157, 38.83417506371775, 40.51335350159676, 38.34006624837076, 37.55831041643697, 38.55967975431873, 36.174102060256466, 35.706382951428814, 36.937665939331055, 38.0923254259171, 39.91641190744216, 41.95438131209343, 45.47232766305247, 47.95758062793363, 51.77688660160188, 55.476375933616396, 52.140878631222634, 53.39400137624433, 53.128515751131125, 54.03670918556952, 54.962996513612815, 57.25388426934519, 52.88410109858359, 51.52780825091947, 34.9127580273536, 7.333611874811112, 0.5433020788815714, 1.750464941705427, 4.431272697064185, 2.632172448981193, 0.09563179746750863, 0.4406683603602071, 33.651512053705034, 50.53720581916071, 45.160138376297496, 29.73610212725978, 28.13245284941889, 38.87439504746468, 49.941648821676935, 28.336720082067675, 0.8598322649636577, 0.10542025609362511, 0.0503066765715278, 0.01801793407198162, 0.052102589679341164, 0.02237861187407567, 0.053675000465685324, 0.018287137368573778, 0.028795707152195038, 0.022921065326719996, 0.007162201490568659, 0.030646606220773635, 0.11002317281259645, 0.025082036567431305, 0.0742826966809169, 0.1113269625291709, 0.024843777477320646, 0.052637782533683126, 0.04238306364465145, 0.047287570027213906, 0.0071463760292728344, 0.008483634690844245, 0.017861295904543613, 0.0575678302876411, 0.07363670836052588, 0.025277772032084967, 0.05292420748681311, 0.0248070799505278, 0.05298793451079438, 7.7522802737451375, 45.968542791181996, 59.08487412237353, 33.77606691852693, 27.809159332706084, 35.69425106048584, 42.859385859581735, 53.38871009888188, 54.420399358195645, 13.385927600245322, 0.03429020274310343, 0.14223442743382148, 1.1968562223257557, 3.21730108991746, 3.8530268351877894, 3.376580943023005, 7.19368229950628, 37.50618603921706, 56.8450124802128, 53.90592559691399, 52.30064069071124, 49.26819355257096, 45.17056011384533, 42.376918638906176, 42.799946261990456, 42.121713546014604, 44.93930109085576, 45.45090367717128, 45.515689465307425, 45.2942559795995, 44.59050432328255, 44.69121509982694, 44.12765287583874, 43.119552750741285, 40.857678767173525, 40.85991844054192, 41.23006466896304, 38.898596071427875, 40.12876510620117, 37.991449909825484, 38.629980394917155, 36.82487034028576, 37.64462217207878, 38.36675797739337, 38.87138658954252, 37.456909302742254, 39.48092291432042, 38.61473021968719, 39.96702224977555, 38.66621525056901, 38.404346050754675, 40.07820575468002, 39.76496527271886, 38.86074519926502, 39.29510062740695, 37.75172641200405, 38.45481126539169, 39.292955090922696, 41.46259846225862, 38.544766902923584, 43.358609445633434, 46.32747888565064, 56.58313151328795, 40.96892110763058, 51.632610059553585, 58.23578688406176, 46.6982566156695, 57.84047865098523, 54.21775402561311, 52.18335397781865, 49.40117366852299, 55.21787997215025, 54.713725966791955, 46.347302544501524, 46.19362408115018, 51.51276988367881, 52.96723573438583, 52.788712978363044, 47.74328977830949, 44.06694635268181, 43.73733781999157, 45.219813316099106, 43.13542658282865, 42.927917511232444, 39.922217015297186, 38.91841580790859, 40.95349442574286, 39.810755022110484, 40.19013058754706, 39.99862086388373, 40.973118043714955, 39.77828564182405, 40.939064025878906, 41.73062578324349, 42.87572253134943, 39.75656747817993, 40.0823595446925, 41.24956669345979, 38.29202113613006, 39.84139265552644, 41.56261497928251, 39.16262257483698, 40.15439779527726, 40.97152163905483, 40.607066769753736, 39.16102617017685, 40.85479974746704, 41.80971645539807, 40.97068225183795, 42.42814871572679, 41.735344394560784, 40.849924241342855, 40.23668127675211, 38.54473944633238, 38.43557596206665, 38.69202836867302, 40.62783179744598, 41.92038612980997, 44.587307591592115, 47.68201058910739, 50.47743674247496, 52.28651623572073, 55.93348503112794, 54.1147094388162, 55.757441213054044, 55.6600683735263, 54.43388446684807, 54.05618375347507, 56.59667153512278, 54.88514923280286, 52.15653673295052, 37.66097845569734, 8.957347120008162, 1.825639004668882, 3.766976897754977, 5.446421321361296, 1.58603624230431, 0.18847840567750318, 0.5094535871138496, 36.441148788698264, 59.31363459556334, 50.58790637600807, 35.97996827094786, 31.28086486170369, 46.00659762659381, 57.919938025936005, 34.48165424408452, 1.6091931803572563, 0.054614427274153124, 0.03683649897274952, 0.019196776763325738, 0.09010925348247252, 0.05466835220314322, 0.03673304645945469, 0.06074760845231433, 0.004652854639120521, 0.04405957811902608, 0.024070564935344364, 0.03881446904532852, 0.07173676434303485, 0.22852531484057828, 0.12880224013520827, 0.2780019389765878, 0.11458564008916579, 0.13269503931364707, 0.1154104563137216, 0.1438716032932843, 0.17085574807659273, 0.14352793625045207, 0.08485022842163041, 0.16400421008227334, 0.19923231894931487, 0.0821321178227663, 0.15517906105566412, 0.08896241985982464, 0.2292302229832257, 8.232488209201444, 52.71623542231899, 65.93155168717908, 42.223612800721206, 39.65425245223507, 34.58877809586064, 43.83582461264826, 59.38422156918434, 60.06148545972763, 18.157804704481556, 0.16905890417195138, 0.6103068253686351, 4.526187191086431, 7.307104987482871, 6.331636530737724, 3.745757365419019, 8.108053957262348, 40.267263996985655, 61.10629504726779, 54.847663141066036, 55.825839504118896, 49.885919786268666, 48.56134322381789, 44.596203527142926, 45.040019712140484, 44.35453453371602, 47.97484297906199, 48.83732903388239, 47.95916526548324, 47.81225289067915, 47.12813269707465, 47.98717491088375, 45.99980408145536, 44.30137465077062, 43.39109059303038, 41.982418414085146, 43.95577069251768, 41.48683086518319, 41.63517490510018, 40.78357734987813, 39.66366221827846, 39.88460933008502, 39.326812990250126, 40.472325509594334, 41.08085770760813, 39.649020010425204, 40.653319358825684, 41.38702615614861, 43.16167900639196, 40.50801907816241, 41.24409498706941, 43.9983872444399, 42.26016929072719, 42.47451505353374, 40.49946438881659, 38.43286560427758, 40.51389086631037, 40.66653382393622, 42.813403914051676, 41.16446695020122, 44.548119191200506, 49.483688569838, 57.83374394139936, 43.11111181013046, 46.40096056845881, 57.09395354793918, 51.55537859086068, 57.78367488614975, 58.20211333613242, 53.67080696167485, 51.62919367513349, 56.705642823250066, 55.57543539231824, 50.65406499370452, 48.92597067740656, 51.181470809444306, 55.77960260452763, 54.00525962152789, 50.2348969828698, 45.59554892201578, 46.45949802091045, 45.947738539788034, 45.27432249438378, 44.52689916856828, 40.71386506480556, 41.54032022722306, 41.821310981627434, 42.43427938030612, 42.816098582360056, 42.93650357953964, 40.92587309498941, 42.590985913430494, 43.00195617060508, 45.463439572242, 45.31464838212537, 42.80659075706236, 41.59502552401635, 43.293717753502634, 41.40722244016586, 42.59963473966045, 43.62530708312989, 40.852097234418316, 41.96970601235667, 42.85866022109986, 43.47153840526458, 42.79563949954125, 42.89034120498165, 43.762880294553696, 43.601945446383574, 44.837295932154504, 42.85964473601311, 42.7551684841033, 43.559783889401345, 40.20139563468195, 41.042038010012725, 42.848548350795625, 43.32517908465478, 44.172783667041415, 46.85457091177664, 49.06210045660696, 54.37714345993535, 55.2069640159607, 59.496938720826186, 55.95109647320163, 58.311084624259706, 56.69330304668796, 57.65511528138192, 54.34189311919674, 58.09393828915012, 54.937355979796386, 51.86245702928113, 40.03340052020165, 9.907431467886894, 2.7467287019375832, 7.118589503149833, 15.58447099501087, 7.6553874342672295, 0.6626457684943754, 0.4438976048221512, 42.81587500726023, 66.82185126889136, 58.917941970209924, 41.55706482548868, 39.67432714277698, 53.09416755553215, 67.08439119400518, 43.928165051244925, 2.4928478992754415, 0.2838737577680619, 0.09344763483010954, 0.24591356485841737, 0.21162939888815727, 0.1173930075920878, 0.127252827308351, 0.130811627473562, 0.130243067659678, 0.11431288980548421, 0.1875330225354241, 0.27224635104498557, 0.2764899265621939], [0.07544722693461565, 0.03050005168563897, 0.06605294352817921, 0.03359235410067824, 0.04181895863204714, 0.029578407693113533, 0.043313393159018415, 0.0423033943309659, 0.014141190181215926, 0.041342053577424064, 0.04772712446508869, 0.04601789420590766, 0.07522142251893398, 0.06385049820246716, 0.017653580739974015, 0.07759739058993517, 2.055738231828136, 29.159013609732355, 49.01139205501926, 49.76757795579972, 30.17097530826446, 24.752607268671838, 44.50156850199546, 51.50191668541201, 52.698165062935125, 26.336521140990723, 1.0894217678616125, 0.1560033869839484, 0.3686359014001585, 1.8814015027976807, 3.206589096976865, 1.6096565103338611, 2.350050090782104, 29.27949901550047, 51.64833091920423, 52.40732131465789, 50.034248136704974, 48.76332567584131, 47.42569938782723, 45.70146468377883, 45.22182549199751, 44.039944756415586, 46.08184829834969, 47.189506023160874, 49.3920345460215, 46.39222152771489, 46.74914152391496, 47.115714473109094, 46.368444119730306, 43.93067144578503, 43.00543923531809, 41.26869217042, 41.6960540125447, 39.759034649018325, 37.734440526654645, 38.31510428459414, 35.58911977275726, 36.21926815279069, 37.03334039257419, 37.093941011736476, 37.56373505438528, 36.948503448117165, 36.691921603295114, 36.917587326418975, 37.65630691282211, 38.10052710194742, 37.34839693192513, 38.24805528886857, 37.08633553597235, 36.904129674357755, 36.853017268642304, 35.69945604570451, 35.47236257983793, 36.540290617173724, 35.26670878933322, 36.46133722797517, 40.46127619281892, 47.50749257303054, 48.09999796652025, 49.678685280584524, 30.886629396869292, 46.09581193616314, 60.56709858679003, 51.963214874267585, 53.12907665006576, 50.55859058134018, 48.696849346160896, 51.231426115958925, 51.50860432655581, 46.53276005098897, 47.26026950343963, 49.76011760773198, 51.641203972601126, 49.39774943936256, 44.5109704232985, 42.20654656810146, 40.89601993560791, 39.9477320332681, 41.458236786627005, 39.97314506961454, 38.36420451441119, 35.631022453308105, 37.52330718501922, 39.046210550492816, 39.063829837306855, 37.21999422196419, 38.07719292179231, 39.66762773452267, 36.814170114455685, 38.70888279330346, 37.72577993331417, 39.10663858536751, 39.448865382902085, 38.57554181929558, 39.125654235962905, 38.09238426146969, 37.839571814383234, 38.51552955565914, 36.503137926901545, 36.56114193700975, 39.1126201998803, 37.19404382090415, 38.303545059696326, 36.94165106742613, 37.08655911107218, 37.1817393456736, 36.479658619050056, 38.55481601530506, 36.9917828805985, 37.20709354646745, 35.933068490797474, 37.38964849902738, 37.733656052620184, 39.33601879304455, 43.24967738120787, 43.681569560881584, 48.96819106994137, 52.64818622219948, 52.11881529900336, 52.66312260781565, 51.476691922833844, 52.43814722184212, 54.09130073362782, 54.17387839286558, 52.6323280795928, 53.12980621091781, 49.70664001280262, 26.349192357832386, 4.140610848703693, 0.8560524484322918, 2.2665264048883995, 1.34780679979632, 1.2643230730487456, 0.06492386016273691, 0.8315906481396768, 38.677617580659934, 47.16872922835812, 41.503630376631214, 29.86591885166784, 30.03678317992918, 44.18727682482812, 42.54452151636924, 23.043585477336762, 0.33301079044899634, 0.03685476250886437, 0.056461706577289494, 0.03670008552651252, 0.029253925407125108, 0.07168126127292072, 0.06181647730690818, 0.008694492731123202, 0.03733146071974789, 0.00261464300321325, 0.05715623805900255, 0.006424152863121802, 0.01285097362743991, 0.057450427313245116, 0.02513326103648832, 0.021287484334841855, 0.07186549775783094, 0.03771969875801475, 0.05161057737085128, 0.019715590657846584, 0.027416206881283756, 0.040785486869994676, 0.021372650329384114, 0.09840916496731582, 0.038159245535010294, 0.05966246405976915, 0.04597158802132453, 0.0740659780680172, 0.04739254705547806, 2.607823600692134, 36.168595052534535, 56.631513949363466, 51.92423043712493, 32.95280064305952, 25.78200782499006, 48.03451791886361, 55.95864703578334, 56.91912566461871, 26.8025222516829, 0.7824029617251889, 0.16677723386354987, 1.121603099088515, 3.372648031480851, 6.862849006729742, 3.893778790389338, 2.7838007384730927, 32.2297626926053, 53.865713457907404, 53.79175324593821, 53.034139602415024, 49.96944665908814, 49.077876229440015, 48.1728873714324, 46.18739143494637, 47.3349122078188, 48.64667438691663, 48.92251114691458, 49.442907687156435, 47.57625956689158, 48.97057979337631, 46.522322623960434, 48.57287891449467, 45.08666846059984, 44.464560939419655, 42.297678916685044, 44.764484974645804, 42.478594318512954, 40.07709964629143, 39.78944086259411, 37.070857863272394, 37.68445384117865, 37.894751717967374, 38.107226510201734, 38.00809644883679, 38.88326352642429, 37.518682710586056, 38.79527299634872, 38.27317414745208, 38.764403943092596, 39.40071828903691, 40.99624433825093, 40.17952842097129, 39.75175080760833, 39.07908001253682, 36.8887500609121, 37.8459103645817, 37.7145972559529, 38.21571534679782, 38.19757438475086, 42.86761891457343, 47.29730060023647, 50.228934980207875, 51.22086709545505, 34.77550645028391, 55.424890902734575, 60.347202670189645, 49.14689425499209, 55.93287314138105, 52.19414049579252, 50.402880330239576, 54.55913359119047, 53.58697806635211, 50.58738077840498, 48.467422070041785, 53.20074227548415, 53.13152420905329, 52.35093724343085, 45.26755248346637, 44.69728300648351, 41.45365153589557, 42.39046258311118, 42.38948591293828, 42.38956043797155, 41.25161417068974, 37.12331171958677, 40.78580133376583, 40.47520452930082, 41.15984247576806, 38.975862841452326, 39.982456776403616, 40.856070595402876, 39.68411345635691, 39.73082104036885, 40.6640431188768, 39.26122311622866, 40.47411411039291, 41.1676440700408, 41.47744071099066, 39.42672360327936, 39.399725929383315, 40.74356917412051, 38.01657661314934, 40.36372292426325, 41.87588684020504, 40.69140557319888, 38.75154641366775, 39.29981139398391, 38.65765271648284, 38.80070155666721, 38.232463867433616, 40.98687379590927, 40.005473244574766, 39.72006197898619, 38.55617707775485, 41.27102598067253, 39.05960936700144, 39.97917767493956, 44.899194855843824, 46.84599268820978, 51.893832068289484, 55.29518204350626, 53.517046128549886, 54.894033401243156, 53.56058835983277, 54.11756492430165, 56.69634680594168, 57.016192559273016, 52.69738451127083, 55.12886570345972, 50.089698683831, 30.36476000662773, 5.179027463159254, 2.1166604853445485, 2.7015434878487743, 2.807692385488941, 1.6932118203370803, 0.09401027278433885, 0.7523338881231124, 42.541689565104825, 55.002632064204064, 52.039661868926025, 36.05281060741794, 34.0313857601535, 50.30444845076531, 49.74935854634931, 30.87857677090553, 0.4644890063472333, 0.04972005240438927, 0.03281430371346013, 0.035055114722420136, 0.04417535315658297, 0.03016239651779254, 0.02794311449472462, 0.04439089199407928, 0.018819528256332683, 0.0023088434470757363, 0.06562820140032039, 0.0909300707280636, 0.009183781597042277, 0.26760011971477543, 0.09601570710900331, 0.12064809219971781, 0.10503070804500773, 0.17885595830457826, 0.14736989783423562, 0.06906898572079598, 0.1503480493181175, 0.08183109123379954, 0.11280829312219737, 0.26976652443408966, 0.10529915291455486, 0.2012282997489937, 0.12546033478311955, 0.10796036616328264, 0.18748442191750775, 2.670285874797452, 40.34214988831551, 62.525800812628965, 60.14809139313237, 41.33085781528104, 37.20148063475086, 56.445279813581905, 62.3534793238486, 62.596505457355136, 32.536635206591704, 1.5406929076679292, 0.42867148475300887, 2.9459726041363132, 10.226958528641733, 13.81707747136393, 6.559198229543625, 2.7726109518158824, 35.15312479388329, 54.1071431867538, 57.12930194793209, 54.21805604811638, 53.628653249432965, 52.08069770566879, 51.44410094907207, 49.65751624876454, 49.594479837725245, 50.31465838032384, 50.91824839192053, 53.794647955125384, 49.39195217624788, 51.324025430986964, 49.44694380606375, 50.491325855255134, 48.50435118521414, 46.31026360296434, 45.047699712937884, 46.48930411184988, 43.204789776955884, 42.006772410485056, 41.85565917722641, 38.47490556778447, 39.98642229264782, 40.37589796127812, 41.71619930574971, 39.66072436301939, 40.910128701117735, 39.8395569862858, 40.81503868103027, 41.08084594049762, 41.064199401486306, 41.78298942504391, 43.455272336159986, 41.252892863365915, 41.456150085695334, 40.01274531887424, 40.03042344124087, 38.570474117032944, 39.21789269293509, 39.99685971967636, 40.35983585542248, 45.00774645036267, 49.0893687740449, 52.568464048447154, 54.000399804884395, 37.854904359386815, 50.25481085623465, 59.780067166974476, 54.568868913958156, 57.95724368864491, 55.02668403810071, 52.06459637611143, 56.1586683027206, 55.90820143299719, 54.34235988124725, 50.078676823646795, 53.47176628728067, 55.64489664569978, 54.7923969453381, 48.78421621937906, 46.83435109353835, 43.75309398097377, 44.048966207811915, 45.79842175206831, 45.01209635888377, 44.28100970483596, 39.768805273117565, 42.131299818715746, 42.65353987293859, 41.577665113633685, 39.77918778696368, 41.670087922003965, 43.754968873916134, 40.35845125875166, 42.63083719438122, 42.829666060786096, 42.299459672743275, 42.783205586095015, 43.212583526488274, 44.006020176795225, 41.64344326142342, 41.815533330363614, 40.810276923641084, 39.49533370233352, 42.08356849608883, 43.9669612146193, 41.86285280412243, 41.055993803085826, 40.71652050941221, 40.097523427778675, 41.360593303557366, 41.489117606993645, 43.994594312483265, 41.759423825048636, 42.565937657510084, 42.0208497970335, 44.36032395209036, 42.13339044201759, 43.969577435524236, 48.66352881154707, 47.56383349818569, 55.408432637491536, 56.9374470556936, 57.243839079333895, 57.84706038813437, 56.24306594171832, 57.03120739229264, 58.34052201240294, 58.9998528265184, 55.19323572035759, 55.00109449509652, 52.91225194931031, 32.014697174872126, 6.437402752137954, 3.3941293820258114, 6.049444060171805, 5.621063872691124, 3.5939042750866186, 0.32242363919654204, 1.203972750133084, 46.92830754864601, 59.77929446005053, 55.00158871373823, 41.859546246067175, 42.32000112533569, 60.568349822875, 60.270991017741544, 37.749290620127034, 0.7606995069692213, 0.22733361910908456, 0.12311607509130433, 0.0690072620167367, 0.13194333852058457, 0.22181823038526122, 0.14117911067460814, 0.1618625959681888, 0.14821974981215694, 0.09772261229133415, 0.1316640381851504, 0.1163924967629775, 0.08950405168317019], [0.09128055595342191, 0.018180235544399872, 0.04161415268637, 0.06677082153938471, 0.07567793431301272, 0.029628404506271886, 0.02520815379196598, 0.06386830591626706, 0.011595822833178025, 0.021442986776932113, 0.03345556910179796, 0.07580818458189888, 0.11313097701678354, 0.014956416900179561, 0.03256247529099065, 0.04091654536164096, 0.6115841697300635, 16.320586127619592, 51.98336801221294, 46.14450816185244, 33.829901449141964, 34.55629302609351, 43.79125079801006, 47.121041051803104, 50.7893906870196, 41.06343846167288, 3.015226217046861, 0.04702322372806169, 1.0268549380763885, 2.5968416996540564, 3.693722467268667, 2.1701601436061244, 2.694396439098543, 21.934484320302165, 51.49427198594617, 52.06621239262243, 51.3846456620001, 50.8995779099003, 50.16298032576039, 46.464518654731016, 47.121237170311716, 48.363196849823005, 50.365351092430856, 51.47819419060984, 49.81586625499111, 49.168569272564305, 51.45879414773757, 48.07657357185118, 45.98664845189741, 45.47862698954921, 46.383329514534246, 44.12017683829031, 44.391608776584754, 42.32958347566667, 40.63334272753808, 39.00899902466805, 38.06387255268712, 37.48492287051293, 36.98958243093183, 37.21709559040685, 37.602652811235004, 37.087896639300936, 37.65327884304909, 35.76375938230945, 37.90691498787173, 37.6580366780681, 37.42065483523954, 38.97945965490034, 36.93127247595018, 37.96611924325266, 38.46288350320632, 36.10955553670084, 37.14010338629446, 37.44871154908211, 35.97482604365195, 34.69749050755655, 44.82433642110517, 49.90087186136554, 49.805974037416526, 50.72383219195951, 48.969214808556345, 30.45178955601108, 42.28417419618176, 57.98120152565741, 54.91294314784389, 49.82149877855855, 50.12714162949593, 52.64752334164035, 54.30803521986931, 46.483455857922955, 47.96689625709288, 49.801573138083185, 51.72582518669867, 47.7648235905555, 44.260429028541814, 42.40144129722349, 39.85677619134226, 40.575209279214185, 42.332121249168154, 42.5197321368802, 38.833057188218646, 38.28004613999398, 39.54134702682495, 37.58547675225043, 39.27773629465411, 39.39966709383073, 37.700531636514974, 39.153495219446, 39.256410368027225, 36.98024718992172, 37.81620233289657, 37.70305764290595, 38.83685404254545, 37.977992257764264, 38.6837286333884, 39.57113350591352, 38.354586862748675, 37.73685670668079, 37.33763002580212, 39.87401500824959, 35.85098112783125, 36.65422762593916, 37.0738035632718, 38.148191744281405, 37.71703304782991, 37.00991599790512, 35.644750748911214, 34.61721527960993, 34.692383581592196, 37.51066930832402, 36.64015416176089, 39.494145224171305, 37.66935663838541, 40.100943734568936, 42.80414319807484, 45.46983695799305, 47.54258601896225, 49.005422207616995, 53.81065122542843, 54.787713635352354, 53.85403656190442, 53.850451515566924, 49.689310981381325, 54.11399556744484, 55.57167776169316, 54.562455838726414, 44.59810195430633, 22.247718918708063, 2.911446676138909, 0.7520495162856194, 2.32147513378051, 2.9039059194826313, 2.4231113445374275, 0.04248458944681672, 1.3053199312379284, 38.85435958062449, 47.8586192284861, 44.198565406184045, 29.354161331730506, 29.534482494477306, 48.22364676383234, 39.77977614248953, 15.753631053432343, 0.01797217947070397, 0.046707817668756174, 0.10382432640800554, 0.022991422841685916, 0.06534092608959445, 0.02516669311350392, 0.022678320791812676, 0.08024593274439536, 0.032337099884546576, 0.03266168367718497, 0.04539352871717946, 0.020002203302518017, 0.03663130998311024, 0.03228997015544484, 0.08457671971090379, 0.04770451338000355, 0.021703539025639335, 0.07850370324787595, 0.08404258022745771, 0.019159209726738836, 0.037676836138651255, 0.07034327339140639, 0.05539050881540584, 0.08806892385285708, 0.008602253829820022, 0.025363418746799715, 0.03216726968305246, 0.044707910668465405, 0.12606891503016796, 0.8520156553676053, 22.03487346249242, 57.766557662717766, 52.215293838131814, 36.895445546796246, 34.1816125377532, 45.95401433206374, 53.542576836001494, 56.12985457143476, 43.233293640998106, 2.9155538880055953, 0.07475912676102693, 0.75578183536568, 5.12702860178486, 5.3859045428614465, 4.843161769451634, 3.5947784733387733, 25.099542871598278, 52.89800982321463, 53.920179490120184, 53.07060587790705, 53.74632827697262, 50.7991809229697, 49.01783650921237, 47.669278575528054, 50.64597314403903, 52.0023601285873, 52.48973031197825, 51.18755440558157, 50.85464323720625, 51.80976390838624, 50.096021544548776, 47.60555182733844, 48.32624420042961, 47.715182073654674, 46.79829274454425, 46.86186652029715, 44.4909937920109, 41.31837683339273, 40.37647062732328, 39.77479865474086, 39.405876205813506, 38.96876335144043, 39.52326490033058, 39.49024638822002, 37.82535714487876, 38.99156016688193, 37.33341740023705, 40.64707886788153, 39.76154496592861, 39.102037645155384, 40.3551015546245, 39.62244987487793, 39.769593669522195, 40.07806454935382, 37.8693582934718, 38.76007756879253, 39.807777943149695, 38.87252015452231, 36.7872626550736, 46.83031105226087, 52.4129028474131, 50.28198111441828, 53.3738443159288, 47.869303764835486, 33.61856806662775, 51.51056943401214, 60.65692086373607, 55.33144043337915, 50.25960791495539, 51.18727983966951, 53.644123077392585, 54.99972951027655, 50.1832668242916, 50.211602026416415, 53.4961595073823, 51.77761616245393, 50.02265361047561, 46.023954114606305, 43.849148904123616, 41.60258393133841, 43.152249628497714, 43.94699242807204, 44.10673487570978, 39.4602127998106, 39.7647338528787, 39.449061501410704, 39.72235264316682, 40.943970910964474, 40.65426465003721, 38.90283615358415, 40.05462838757423, 42.73054776653167, 40.26877018713182, 39.801647278570364, 39.52140961923907, 42.27762776036417, 40.78444811605638, 41.026760378191554, 41.22173747708721, 39.04739902865502, 39.77284923676522, 40.136692216319425, 39.64469755849531, 38.49915366018973, 38.928492376881266, 38.23776691190658, 39.661179357959384, 38.67657030782392, 38.26287792574975, 38.40219659190024, 37.30519202447707, 38.02185612340128, 39.33787407413606, 38.56521421863187, 41.514773830290764, 41.14016002224338, 43.40252430208268, 45.02493035408759, 48.64207736907467, 48.93955776768346, 50.52545439812445, 55.20256703899753, 54.42775380226874, 55.692223964198945, 56.24374058938796, 52.144153810316524, 54.060235561863074, 56.867346455973966, 55.70794874621976, 47.80244304287819, 23.580255931423558, 3.3241739100025547, 2.1901958555944505, 3.658051697477218, 4.318566822236584, 2.7532871500138314, 0.016877642840207104, 1.2537836643957323, 42.93738219045824, 53.65843188378119, 47.94865723579161, 29.339303393517774, 36.456751977243734, 55.81724559107135, 49.27645798652403, 21.39260691981162, 0.014820312761941986, 0.016502321044343616, 0.05141762663580237, 0.030708912151655367, 0.029852828048470042, 0.03295144111278557, 0.06261787422361874, 0.07681107794445369, 0.047970250128738345, 0.026893796203958414, 0.041454821719878146, 0.062085879786360654, 0.015964540728037397, 0.1741053091902887, 0.17984597372912592, 0.12562914225723476, 0.1291269541627938, 0.33317071896406913, 0.1322838339594103, 0.0864555580060809, 0.1531678351062921, 0.16331702921419375, 0.17225992595476491, 0.09714859793142927, 0.11057236592375463, 0.2695613660879674, 0.13856580090378562, 0.13658702643888612, 0.2590841331308888, 0.9702200190194192, 26.147815912000596, 69.63750900760775, 59.30260881300896, 45.88418829825617, 45.93134695483793, 55.568637924809615, 57.244266617682676, 60.6270206359125, 50.00168069716423, 4.572476552378747, 0.2063298784196377, 2.900709923236601, 6.026174108828268, 10.604628843645896, 8.516602150855526, 5.182657126457461, 26.4490068727924, 54.75343604241648, 56.22509364158877, 54.82993402788716, 57.35991377984324, 53.84753327215872, 51.4589314306936, 50.81162268115629, 52.51095817935083, 55.37503365547427, 55.530539943325905, 53.81713490332327, 51.75360341225901, 54.95003308019331, 52.747104475575114, 48.348793906550256, 50.188691462239916, 50.9595666393157, 48.486433798267, 49.462911775035245, 46.182355111645116, 45.424729701011415, 43.288755955234656, 42.60477696695636, 41.10074412438178, 40.567454753383515, 42.6643773817247, 41.65419447806574, 39.945092278142134, 42.30147577101185, 38.013626990779755, 43.863359651257916, 41.42947404615341, 40.766256163197184, 42.77161105986565, 41.577131671290246, 41.70746810974614, 43.120317612924886, 39.48097782750284, 39.12417942477811, 41.79790619880923, 39.556044147860625, 38.384432177389826, 49.82179687869165, 54.04112577438355, 51.23252437960718, 54.09814134720833, 52.162769379154334, 37.938125287332845, 45.89276259945285, 56.95926327859202, 58.294861701227006, 52.68245989276517, 53.477842038677586, 55.9548697933074, 57.06052318696053, 53.281378361486624, 52.12635409447455, 53.7006091302441, 54.74363011698569, 51.156155832352184, 48.50431588388259, 47.01634122479347, 44.24644970124768, 44.52589896417434, 47.73235421026907, 47.10693228629328, 43.30581826548423, 41.33535677386869, 42.81976599847117, 41.98055528825329, 43.51956782802459, 43.770458313726614, 41.222478805049775, 43.272074114891794, 44.89545683706961, 41.81770240106891, 42.55061295724685, 42.105949540292066, 42.96850227540539, 43.79234513928814, 44.40816117871193, 43.92867495936733, 42.37162343917355, 42.18696609620125, 41.79209324621385, 42.559532427018695, 39.84244385073262, 41.54628222988498, 40.389453672593646, 42.2159484894045, 40.98066076155632, 40.82358552563576, 39.61458552268244, 38.545135605719786, 39.63169490137408, 42.43289086126512, 40.38495863637617, 45.13754160173478, 43.190222094135905, 46.046911747224875, 48.27166441948184, 51.462512554660925, 52.71503909941643, 52.73379195121027, 57.68901632678125, 57.62364610548943, 57.08530079933905, 57.56069206422376, 54.02136487345542, 56.40564034062048, 57.78025850172966, 56.01919274176321, 48.88650771110289, 26.104075601024014, 4.758819533932594, 4.167794835182929, 7.732099679208572, 10.623727844607446, 7.997367122480947, 0.1673407374971336, 1.7354988931648194, 47.83486927709272, 60.79896949952649, 58.280490136915645, 40.07183582552018, 41.23897629399454, 63.72598332743492, 59.38325666612195, 26.946537956114742, 0.182482112920092, 0.1767664228475863, 0.16256172780788716, 0.11244921239032862, 0.22768402772565044, 0.0781585116900744, 0.12860806748992012, 0.2113043324601266, 0.2661342257934232, 0.09212856165944569, 0.23317507017524014, 0.15789868850861827, 0.11629871227928709], [0.06402116343979875, 0.044660045494956356, 0.027645837906147205, 0.02543019288549981, 0.04950552480295301, 0.03547806803497576, 0.03561282673129632, 0.004559244919237831, 0.014309456605734605, 0.020249969543768995, 0.061918562353258176, 0.07092006098959716, 0.04539021921734657, 0.016044163118837582, 0.027269941544340506, 0.059037343974435524, 0.2433074409923246, 8.296724865513465, 46.5642802176937, 44.35144762839041, 32.51664484700849, 25.571490295471687, 44.98812283239057, 48.05998979076263, 50.6026231088946, 46.83174271737376, 8.524597902451793, 0.03250323754224566, 0.5558198329902465, 2.769088173104871, 5.139360533606622, 3.2080992094932066, 1.9595514189812446, 18.553944480034616, 46.85204098301549, 52.93315033758841, 54.38969504448676, 50.12596491844424, 49.418749809265144, 48.24459222055251, 50.70716604109734, 50.778145251735566, 51.69221831906227, 49.49274140019571, 51.049651715063284, 49.99806427186536, 49.8289159805544, 48.85510521550333, 47.03916549682618, 47.4302375701166, 48.41152829508628, 46.356178868201475, 45.38704749076597, 44.82157899487404, 44.289866416685044, 41.07383666499969, 41.373768544966175, 38.03090503138881, 39.01823620642386, 35.99213154085221, 39.37822349609868, 36.33219711242184, 38.409158798956106, 37.54920659526702, 39.58005297568537, 38.57909156430153, 37.92724071010467, 38.09383946080362, 39.2588657717551, 36.03626605003111, 36.48606777191162, 36.298256843320786, 38.19867657076928, 37.0887085699266, 35.5102095296306, 35.89422133661086, 48.379690416397594, 50.622458534856, 52.08867972896945, 49.149118238879794, 47.85523030065721, 45.29790378385975, 34.20732367423273, 39.976322189454116, 54.99288889669604, 55.56681402267949, 50.06721958037346, 49.22964057614727, 54.137478797666496, 50.033569566665165, 47.62653650776033, 50.12374877929688, 49.78136116458524, 47.254786029938735, 43.993182259221236, 41.01811939670194, 40.96930549990746, 41.41650669036373, 44.20616303720782, 44.92908331655687, 41.174288565112704, 38.504095846606845, 37.57727899859029, 37.64120971002887, 37.906942444462935, 39.11461668629801, 37.57940884559385, 37.68885474051199, 37.25585645244968, 39.397980474656634, 35.97109979198825, 36.95109221243089, 40.14985569061772, 39.10733284488801, 37.320999176271506, 39.034427750495176, 39.368723515541326, 37.37275092832504, 36.3926879052193, 38.437650895887806, 38.56165270651541, 37.75933973250851, 36.03620721447852, 37.19184337123748, 38.411139595893125, 37.39234708970593, 34.23088142948766, 33.775482485371256, 35.12734697711083, 35.04587150389148, 36.150999299941525, 40.35598408791327, 40.54221430132466, 42.6780076180735, 45.546621276486306, 47.423997079172445, 47.2504125871966, 50.86303318700483, 54.79340499447238, 53.13688216670867, 51.914863817153446, 53.27415727799939, 53.92974222860029, 55.16236274473129, 55.66696390028923, 54.28242214264409, 41.93217285217778, 14.21989312095027, 1.6206288505946438, 1.5605251467035663, 1.6075841505681316, 1.3840552611697106, 0.6791724300672931, 0.029891929176125317, 2.6906086552527646, 45.18302540625296, 42.86057041537377, 34.782935419390284, 35.656015796046105, 35.56076888115176, 44.82480710552585, 39.95884803033645, 8.509177104119333, 0.05275048172822403, 0.04298135533087677, 0.03418747801333666, 0.04623717155247446, 0.029425678489309166, 0.02453825969789778, 0.059814042216467286, 0.014205193954459844, 0.021845784316199924, 0.04355823102917883, 0.09681822251408331, 0.0319211371243, 0.07099259419426804, 0.03786637395199749, 0.0578631533520116, 0.07121979288997189, 0.05353807374053905, 0.02753015288392142, 0.05020698171950156, 0.07762119294174256, 0.0254446700320489, 0.02352751967977853, 0.1118020979206889, 0.03312974424672223, 0.01972140143475225, 0.016533020102689346, 0.05545322077288743, 0.057616710527649814, 0.05531611018663934, 0.2710258504075389, 11.699471204511582, 55.748611957796165, 50.22293767621441, 40.66654951341691, 31.16294468602827, 51.00695671573762, 54.45087617443454, 56.28385859151041, 50.36662978510703, 8.130470793093405, 0.043572802021498644, 0.4819148099951206, 3.660700768232346, 6.907461064477121, 4.802973654962355, 2.8204457269560907, 22.578200178761637, 49.663584155421105, 53.791953286817, 54.59824354417863, 52.5407289689587, 52.18013763427735, 50.41287845180881, 52.796236084353545, 52.30968175395843, 54.02286321886125, 51.05962238004131, 52.33767178750808, 51.93698206255513, 51.209778554977916, 51.443222338153475, 49.44658687037807, 49.49616562935614, 50.06462297131939, 46.77022426359115, 47.61772686435331, 46.980769249700735, 47.0620015359694, 44.05731693390877, 42.79558458635884, 41.0246148417073, 40.59678623753209, 38.11658136306271, 40.8279001328253, 36.57410929279943, 38.527771272966945, 39.530968435349, 40.70446706587269, 40.272559196718284, 39.75175865234868, 39.58705440644295, 41.13364104301699, 39.03716556487545, 39.46373901059551, 36.927377562369074, 38.84843680166429, 36.931562731342936, 38.93695292934295, 37.69109049151021, 51.103243058727635, 54.52887250531105, 53.96380801354685, 49.93789511342203, 47.69103204050372, 44.537921028752486, 35.80224960081039, 46.553391718095355, 60.840099473153394, 56.13635001644012, 51.58413348659393, 52.42482685273694, 54.60414278891779, 51.31887535895071, 50.26318903892271, 52.08914649101996, 52.819350611779, 49.507462055452415, 46.2147891906, 43.40748217798049, 44.69145436440745, 43.47391143921883, 44.952158620280606, 46.128924585157826, 42.62208246415661, 41.47835462324081, 38.983570298840924, 39.31250026149135, 39.81880764807425, 40.06015892951719, 40.26607944119362, 40.253159153846006, 39.60292431616014, 41.35821634723295, 38.961287313892, 39.81199841345511, 41.83354877656506, 39.94709660930019, 38.75714363590364, 41.56639222175845, 39.24361951889531, 38.126246083167295, 38.50463713369062, 39.05096838551183, 39.94609640490624, 38.458812082967455, 38.203979615242254, 40.107792192889804, 39.43687861965549, 38.58959174925281, 37.101789674451275, 37.14539074128674, 37.0273313214702, 39.01211730895504, 38.73428014016921, 40.55475019639538, 43.51452365998299, 45.06322445407991, 46.62022106109127, 48.498193064043605, 48.01466680342152, 51.712948045422955, 55.847451763768355, 55.614757153295706, 54.291729927062995, 54.1104301329582, 54.601353983725275, 56.04247593110608, 55.68841142039145, 56.23076931122811, 42.48709017230619, 18.97941573973625, 1.9928096859685838, 2.5004033648198654, 3.7736353662706192, 3.0029484629631047, 2.1521951979206455, 0.08302683190953347, 2.7420735839874517, 49.36047123324487, 48.7123348636012, 42.536284539007376, 35.992559079200994, 37.227207460711085, 49.70390612079252, 48.83807428421513, 12.861470426282576, 0.0549818009078022, 0.03576723175243505, 0.013854599561572317, 0.061424665468474554, 0.02583793743753866, 0.028187879586532235, 0.04963222425431014, 0.03643740929903523, 0.059270261516494144, 0.07617923926802413, 0.018568381652115815, 0.053922764791716496, 0.08269624198756872, 0.13411473813316516, 0.1466404135909773, 0.13965933012866205, 0.1152183980711045, 0.10476332803767537, 0.21206446022035616, 0.22030663165834644, 0.1381039571377539, 0.09306819914209266, 0.17183105461299422, 0.23756142915977588, 0.10014080712872167, 0.11579669486250609, 0.1535273908126739, 0.1346501416616863, 0.1892517561153058, 0.2844734820387056, 15.03049308253873, 61.68862189016035, 56.979518398161865, 45.400199197953754, 36.150516848410334, 57.44834753774828, 59.16171727641937, 59.832324904780236, 54.72526557983891, 10.087173100440733, 0.12336857001026794, 1.8098192277454563, 10.91071198063512, 12.938617564016774, 9.89497402021962, 4.068277194615334, 23.955242364637314, 52.59987046641689, 55.77391909014795, 57.32516158011652, 54.291341612415934, 54.8778183229508, 52.496708208514804, 55.2170366625632, 55.736860536759906, 56.49153240265385, 52.15403818315076, 54.593548467082364, 54.09113991645075, 53.39738638170304, 52.87038849246118, 50.74216142777474, 51.10963652210852, 52.52210555538055, 50.52381484739242, 49.08141028496527, 49.198963719029585, 48.41782762158302, 45.72195122318883, 46.60814800570088, 42.819718930029104, 42.600591797982496, 40.63796720197124, 42.22672324026785, 39.781360780039144, 40.65574338359218, 40.248938683540594, 43.16190650386196, 42.57739490078342, 41.46097460100728, 40.59730791276501, 41.86985423488002, 40.17642190379482, 40.824750469576934, 39.20712970918225, 41.25851361982284, 39.978095100772, 40.19900691124701, 39.71397053810858, 53.79021959920084, 55.759720110124164, 56.185222748787176, 51.18980192369031, 48.223105476748565, 46.99946326594199, 38.39858408897154, 46.46251824594314, 56.570830960427564, 58.347205731176565, 54.69658913150911, 54.55745481675672, 57.20672953513361, 54.223127672749186, 51.37140374029837, 56.44515429773639, 55.12618672463202, 51.77413702011109, 48.153059790211344, 47.09156051758797, 46.48185945326283, 44.530115512109575, 47.34794624390141, 49.86368386976181, 45.31855506281699, 43.76742239921324, 41.870085654720185, 41.21003704686319, 41.51283225705547, 42.98791800775836, 42.35593003611411, 42.76282102830949, 40.39096770748016, 44.04882108011554, 40.836694086751635, 40.50365348016062, 44.72586924029935, 42.793101726039765, 39.88584095431913, 42.761510956671934, 43.658584471671816, 40.15315048156246, 40.70452590142527, 42.45825682916949, 43.36956854789488, 40.54425001144409, 41.140093341950454, 43.52511405944825, 42.01956718198715, 39.93599237934236, 37.49219494481241, 38.536651519037065, 39.18211675459339, 42.22506407768496, 40.97390644011959, 44.242190007240545, 46.5521522491209, 46.89190403107674, 51.157332543403875, 52.53018956030569, 51.1514215315542, 52.91906510629962, 59.39524342936855, 57.20113231289772, 55.79963807136782, 55.412766856531945, 55.784536946204405, 57.678829931443744, 57.96227608957599, 55.38364718037268, 47.28155620636479, 19.698386192321777, 2.708200485475602, 3.703842672609514, 8.391497173616964, 6.120124190084397, 4.642623239947904, 0.33407317053887153, 3.476543527457022, 54.551151567889804, 53.409063277706025, 47.66354407033613, 49.63663354996712, 47.9811893740008, 59.7513436502026, 58.398996706931825, 16.63540928594528, 0.295263922382747, 0.15486260545590233, 0.07984095568498296, 0.2051699906587601, 0.1563821868189881, 0.11706860766055123, 0.17115600857763522, 0.1009701892373062, 0.13563448803559428, 0.19329994856830568, 0.13410503946004376, 0.15200128238047325, 0.15849887243201657], [0.1660325197923568, 0.07319569452515534, 0.05063737757624157, 0.0633234143888037, 0.07457191019409126, 0.05456103094583077, 0.06048155377709097, 0.06689550234906136, 0.07572427497155244, 0.013668226648963267, 0.05702868058917023, 0.062255392061366197, 0.05871982734289862, 0.007403705920648551, 0.05961230828336651, 0.03194376927680306, 0.038065618099344355, 5.30717178698509, 37.412696346159905, 47.10810899734498, 34.89130266251103, 27.765350380251487, 43.11120202464443, 42.939825827075595, 47.68494059962612, 49.01632247432586, 14.24756936488613, 0.08192846100897559, 0.35130328468738065, 3.0094309151172642, 2.835529201453732, 3.1493283760163093, 2.2566339421656827, 12.048121863795865, 47.83604598814442, 50.74913540194112, 54.688940509673095, 51.684746203884, 52.95182081960863, 51.28680606042185, 52.073535457734145, 51.588703047844675, 51.064603790160156, 51.103474478567804, 50.11232291498492, 47.51462344200381, 49.94851689184866, 50.40201348643149, 46.642441288117446, 47.80311769054782, 49.01081154423375, 49.536664101385306, 50.67804636493806, 46.24607793746456, 45.07041023623559, 46.46464024820636, 44.877280573691095, 42.50743158401982, 42.42230830654022, 39.659759459957, 37.5962632702243, 37.362956770004764, 38.3716413282579, 38.35450841534523, 37.033846378326416, 37.98320901009345, 35.8806420910743, 36.49314765007266, 39.37803914470058, 37.31528820530061, 36.39411172559185, 36.07426989463068, 39.25094650637719, 38.193671626429406, 35.819068724109286, 37.7579669029482, 50.57182465830157, 54.435676990016816, 53.49780690285468, 51.501449923361506, 52.247523953837735, 48.92982636728595, 48.954772641581876, 41.58676893480363, 38.5350315801559, 52.91647241961572, 56.10771671418221, 52.67512113817277, 54.8880047182883, 45.84676104207193, 45.06970813197475, 50.78857875639393, 49.6352489532963, 48.28551038619011, 43.150464950069306, 41.55056153574298, 42.7892578032709, 44.6745018805227, 45.84661983674573, 45.666677182720555, 45.72770926260179, 42.48300698495681, 37.28961237015263, 38.74143846573369, 38.89248894106957, 38.401588624523534, 38.281517028808594, 38.89454818541004, 38.938584635334635, 38.566783166700795, 37.74461123251146, 38.23757079339797, 37.714667858616004, 36.684892715946326, 38.735825554017104, 39.87461120851579, 38.6803710845209, 37.865977210383264, 37.52585280326105, 36.85894396997268, 37.43106872804704, 37.37012686267976, 38.201802699796616, 39.45242689501855, 37.445393223916334, 39.19263262902537, 37.703312596967145, 35.31023533113542, 34.72769275788338, 34.13628955041209, 34.99235468526041, 39.31421825962682, 42.09813225653864, 45.67812658125355, 46.712098660007605, 49.36442106000839, 49.400295057604396, 51.695630781112186, 50.94125701535133, 53.52172159379529, 52.06413745880128, 54.15645914693033, 51.87002328134353, 53.14259706004974, 55.68548533224291, 51.35416492339104, 35.358766817277484, 6.735332752427747, 0.4018031877856101, 1.3016865907176849, 2.60771720640121, 2.3895868466746424, 0.7129985827111429, 0.12286750254251304, 4.208335472691444, 49.00339826460808, 47.30094840449672, 36.19972690459221, 22.242298203129923, 39.19111074939851, 55.31590000275643, 39.482578154533144, 4.210472674139084, 0.03854167279637149, 0.02730959617052107, 0.07498682341388158, 0.08049632092156718, 0.03370812913823513, 0.07914058278284727, 0.05232337238867918, 0.1094853331244761, 0.026013386893957376, 0.015672314574100798, 0.013743697800823759, 0.03760741325095296, 0.06484674575227885, 0.08374404342424485, 0.022038920827570464, 0.024864205211821585, 0.01784473116840086, 0.03395366797884626, 0.03828029125748623, 0.05618391926550577, 0.0067464771751885215, 0.05062007931091132, 0.028153472662632986, 0.014867730731625232, 0.03675467312155712, 0.03569975855850405, 0.03912292668716081, 0.09658280369495192, 0.03893985465589551, 0.09218021896817992, 7.007047101374596, 45.37685325068813, 52.89235768779632, 38.92214598194246, 28.975940904309674, 48.82427538594892, 49.58311673133604, 53.75434952397501, 54.6180122898471, 15.927361653697108, 0.11225505506679898, 0.43174221030166077, 3.706823183644203, 7.792029082775117, 5.315272952279737, 3.592505704972052, 16.49946778051315, 49.69058182931716, 53.129978795205396, 56.07491001006096, 54.58387197986726, 53.94938938079342, 53.73691458855906, 54.17891079379667, 52.880496440395234, 51.99667269183744, 52.13849383015787, 51.92663092767039, 51.6802982361086, 51.88901932008805, 52.03981876373292, 49.34963764682893, 50.270774902835974, 50.93691495157058, 50.82712781044745, 51.11851676817864, 48.16422677809193, 46.87032315038866, 48.47341937403525, 46.57866354911558, 43.78624193130001, 43.29565932673793, 41.63066025703184, 39.37507775522048, 38.868876272632235, 39.535475238676995, 39.89494869785924, 40.3963178203952, 39.835626771373136, 38.45114384928058, 39.356783820736794, 40.96683832906908, 38.30139952321207, 38.505292169509396, 38.57208621117377, 40.15049895932598, 39.90370342808385, 36.438920882440385, 39.8854761738931, 52.85104728514149, 56.051975911663426, 55.344290118063654, 52.41235763795915, 52.36304167778262, 49.265247852571555, 48.24627491735643, 42.14480453921903, 42.26629211056618, 58.76901349713726, 57.307059841771284, 52.51598273554156, 56.58852084990471, 48.66645097732545, 48.25885788086922, 52.77882468315863, 51.791371914648245, 50.45571857883085, 44.661667885318884, 45.02488328564552, 42.56360384725755, 46.6375304806617, 48.448167154865885, 47.55546708260813, 47.49749052909113, 43.38292814070179, 39.90642555298344, 39.73820294103315, 40.72263548451085, 39.45017153216947, 39.59513056662775, 40.66699274124638, 39.556044147860625, 39.67542148405506, 38.62112760543823, 39.81465385806176, 39.36367150275938, 38.86087855985088, 40.46967006498768, 39.73317054010207, 40.11279713722968, 41.53144390352311, 40.83589000086631, 39.7195363813831, 38.93743538087414, 39.531799977825536, 39.61706053826117, 40.86604910512125, 39.76548694795178, 39.18972615272769, 39.77375138190485, 36.69480062300159, 36.778049007538826, 37.04242460189327, 36.83663352843254, 40.84475063508557, 43.773580520383774, 45.799657298672585, 49.78494621092274, 52.21727855743901, 51.7652097055989, 53.7856343484694, 51.994091772264056, 53.87807284632037, 53.19272102848176, 53.439814659856985, 52.627048569340865, 53.97615171247914, 56.86678555703933, 54.26930965915803, 37.970657425542036, 8.923172489289316, 1.9233769923448565, 3.543234361756233, 4.890633725350903, 4.287335930332061, 0.9928426567104556, 0.17305429784520981, 4.872640342481675, 53.459175479027536, 51.57405299525107, 44.43083247830791, 29.9819347166246, 43.89319319878855, 61.16453832195651, 46.01423055894914, 6.031726714103453, 0.1048481492926517, 0.04379651501714703, 0.048303069366562756, 0.02220989441529157, 0.03398976221139874, 0.005844050977048615, 0.03416274869514089, 0.010315464873377596, 0.02574175701386506, 0.038864352860518044, 0.020538233107917254, 0.020569702084626884, 0.09873191780981519, 0.2695983221694347, 0.1770013207269292, 0.09631893237031276, 0.13214578491545495, 0.17294919058199854, 0.1142073994983108, 0.1102964363751873, 0.12926953844726086, 0.2571026007494619, 0.11524738683815926, 0.1948953113488613, 0.17228349081931577, 0.13929778259367714, 0.07685325874556458, 0.24202053585360128, 0.15630622154041646, 0.3398378289514973, 9.21549399052897, 54.48722477882139, 61.7016637709833, 46.33843798791209, 39.74462386100523, 55.66064103957146, 54.9122331988427, 58.296646379655414, 59.53234203400151, 18.866904512528453, 0.17772574878988728, 1.073240887734198, 10.959516071504163, 11.846333569095982, 9.649779796600342, 4.94444570233745, 17.868092559999038, 55.65775417512464, 52.60187871994511, 58.277105131456935, 57.145438578821, 59.04193593609718, 56.948162971004365, 57.67398188191076, 55.657989517334975, 52.80546149899883, 53.17072829892559, 54.93303745023666, 51.77574126951156, 53.149571034216116, 55.28750988744921, 50.11902624560941, 51.941630071209325, 53.58829598273001, 53.94676531514814, 54.68772457491968, 50.585066580003314, 49.20412948054653, 51.33381958930723, 49.607800206830426, 45.88432950358237, 46.06939869542276, 44.899567481010195, 42.30643756927983, 41.589914675681825, 41.06568597978161, 42.64425954511089, 40.32741354357812, 43.06696945621122, 39.46142481219384, 41.19742270438902, 43.5266516285558, 39.987540168146936, 40.288531088059955, 40.037872022198094, 43.18506025498913, 42.64971556202058, 39.43643931419619, 42.119822963591545, 53.56590317141626, 59.1441999712298, 57.23326436934933, 54.715918571718284, 53.42938115519863, 49.87018323713734, 48.9117834644933, 45.07237142132175, 44.394742750352435, 56.68303428157684, 57.2653885810606, 56.4488217138475, 58.624591827392585, 50.12145811511625, 48.602614402771, 54.29090230695663, 52.573190504504794, 53.3964999260441, 49.157782754590436, 45.16585719200873, 46.41006831199893, 48.78556943708851, 50.97684860229493, 49.54387734013219, 49.99022737626107, 47.49214041617609, 40.97264343692411, 43.020697255288404, 42.31484713092927, 42.529369400393584, 41.260663078677275, 42.533519268035896, 40.3659547528913, 43.92018695031443, 41.394706156946, 41.711398324658795, 41.21668938667544, 42.383590590569284, 43.059010967131584, 43.93641379571731, 43.08760504568777, 43.07971323690107, 42.64117656215545, 41.463406470514116, 41.366672977324455, 41.073577788568315, 41.62623974584764, 43.50848320991763, 42.424881381373254, 42.66665235642464, 41.653190351301625, 38.414226501218735, 38.5634530744245, 37.90340054419733, 39.00706921854327, 43.48134825306554, 46.10632781059512, 49.67257815022623, 51.38334735747307, 54.72004882750973, 54.60313081741334, 56.0171687987543, 53.673842876188225, 55.07931440107284, 54.46858959813272, 52.30814026248071, 54.26127272267496, 54.63897735841813, 55.58278591402116, 51.42858405267039, 40.221960621495406, 9.909158291355256, 1.8063642324939853, 4.5615277463389985, 8.773475231662873, 9.211735379311348, 3.6851018330743237, 0.3747841860017469, 5.678346656983899, 59.17071519359466, 57.59624050509546, 49.57360106129801, 34.415911397626324, 52.92898085809524, 68.29179086992818, 55.25291066015921, 8.039679200418535, 0.1690280001850859, 0.11027172237875, 0.22527730122448938, 0.1623985510800154, 0.1557717832826799, 0.1454826402327707, 0.12359573040157558, 0.19999155804755228, 0.1010434961907806, 0.13006159675217446, 0.14830498475461237, 0.17930021269186852, 0.18562414593273596], [0.023862156461203293, 0.11175283080627842, 0.05798438676602899, 0.09196341608560855, 0.014549802327829023, 0.06406881410868899, 0.09307615879562595, 0.019896228444732485, 0.024432123961648154, 0.09518932806508196, 0.037434173958195795, 0.0860196692989238, 0.04350427162623213, 0.0372051787863095, 0.07361122061528506, 0.02934289694343123, 0.04237867396084532, 2.4008896466224425, 31.717201086782644, 52.655826999295144, 35.71760093012164, 34.92842397382183, 42.617834537259995, 40.141218631498276, 47.28303101754958, 51.302468084519916, 24.19369305333784, 0.5053257521602416, 0.13559397730615833, 1.715015295532442, 4.967908340115701, 4.305540140598051, 1.5394629994707725, 11.423835465984961, 43.72639048484064, 48.11161602697065, 52.548958101580226, 50.701984590099705, 53.73528288256738, 51.54137572934551, 51.054311490828, 51.94253221634896, 52.191041823356386, 50.26613081655195, 50.831273755719586, 50.21657166942474, 50.46861140958725, 49.2622943078318, 46.38736563344156, 50.82775146730485, 49.037903355013945, 48.96118179444344, 50.337129639041045, 49.63921839191068, 49.851242111575225, 47.25718652048419, 50.3574671283845, 47.08799900547151, 46.57315654139365, 43.44303454122236, 39.19868876857143, 38.03976566560807, 37.377006699962, 38.879705936678, 37.69806054330642, 37.32407823685677, 37.67973522986136, 39.52187638128958, 36.90328244240054, 37.86119191877304, 38.74997746559882, 37.689086160352154, 40.33783528112596, 37.618146173415646, 37.30922422101421, 36.424639532642985, 51.4985316799533, 52.146903391807314, 54.09517211298789, 50.22845645104685, 53.609680744909475, 51.71376782078897, 52.95636292426817, 47.61413789564564, 50.46534407523371, 41.292434277073035, 52.92059483066682, 55.84187415338332, 54.45495151704358, 48.344965673262074, 48.59902543406333, 50.95451070416359, 51.58492972773891, 46.52214611730268, 43.17555242969144, 39.83667012183897, 42.45434230373752, 44.9593012563644, 44.3838228717927, 46.418721060599054, 46.084923436564786, 40.10391689115956, 37.60947773533483, 38.038851753357925, 38.23931624812465, 37.07287788391113, 36.77985722018827, 37.7972690520748, 38.67145161474905, 38.84212570805704, 38.88495406796856, 38.29227609019126, 37.75089879189768, 39.029760129990116, 38.588748439665764, 39.83395584167973, 38.19154570179601, 39.116315072582616, 38.388123127721975, 37.85375510492633, 39.75852866326609, 39.99131348825271, 42.72956717398859, 41.98394421608218, 40.571910565899266, 39.730318976986794, 36.58413879333004, 38.311997767417665, 36.81162449621385, 35.839751382027906, 35.20363707696238, 38.65336164351433, 43.19397580239081, 47.55630646982501, 50.477668162315126, 51.96440727479997, 53.14430329107469, 51.784044927166356, 51.610330996974824, 51.78013040173439, 51.953397181726274, 54.44864434580649, 53.35362057532034, 55.36645935427759, 53.06368681692308, 49.29820360675935, 27.740553156022106, 4.502190130372202, 0.5672344204879577, 3.0258533887324797, 2.130517238570798, 2.3546248001437036, 0.784042512457217, 0.05089053516125968, 5.54578721523285, 49.784259796142585, 44.220103140800234, 35.621859796585575, 23.592295646667484, 35.855872323436124, 49.619939942513746, 34.70641389969857, 1.6123216382918821, 0.03718895687451286, 0.058307618413481026, 0.013148127641949444, 0.061999951534333735, 0.06728702690452337, 0.03067969738866293, 0.041565797216589415, 0.07979796283067235, 0.0647699760813867, 0.07966732951782404, 0.05867942769621169, 0.02663454438950266, 0.03176198810369017, 0.030772738767066793, 0.07558475503878248, 0.013191838703689077, 0.05504732823840553, 0.025165377357493968, 0.050221725081604336, 0.03521514282892308, 0.04024678150251989, 0.01052879929287179, 0.028607159507490938, 0.027539252093242064, 0.0774464329644557, 0.0662343148442526, 0.045935114575249535, 0.016570437752131014, 0.05452322067632791, 0.02327557634412041, 3.3927879314268794, 38.99432936022359, 60.04359945174187, 39.982154753900346, 36.083354103949766, 47.88792325604347, 47.37544598117952, 52.6448678970337, 54.73528723562918, 25.435060454953103, 0.38680870206125323, 0.20899195734771991, 1.864518886131625, 5.253496602658303, 5.8596238974601995, 2.23621089612284, 12.722829349579351, 47.76967556245866, 50.925422406965694, 54.40648671119444, 51.95176547573459, 55.05913380653628, 53.20268777108962, 52.769548277701105, 53.28824643165835, 52.8880823043085, 50.645949609818004, 51.48521523321829, 51.39026249608686, 51.29268961568033, 52.244009510163345, 47.89911770051526, 51.075358929172644, 50.803852465844926, 51.40188840127761, 52.51224079439717, 51.66816634516562, 50.89476516169887, 49.72517321186681, 50.98166527286653, 47.28703183512534, 48.252303600311286, 44.17066558714836, 41.96017465283794, 39.551266700990745, 39.420679230843824, 40.452537152075, 40.121520488492905, 38.94426030497397, 39.06562628284578, 40.36527618285149, 38.938588557704804, 39.025853449298495, 39.29845425390428, 39.48201333322833, 40.83639990898871, 39.568901677285474, 39.03820107060094, 38.63974317427605, 52.71117948716687, 54.356374509872936, 56.22612914731426, 53.10167889441214, 54.89760668047013, 54.30984735488892, 52.62287124510735, 50.107447408860736, 49.5106940884744, 43.708288746495406, 58.863950544788, 57.603916583522675, 54.56826879132179, 51.09251145393618, 48.89490158327165, 53.19119522648474, 52.53392365670974, 47.350115314606704, 45.84816917296379, 42.56785569652435, 44.58551899079354, 46.517545177090554, 47.50335839486892, 48.542315806111986, 47.57368649205854, 43.71858889056791, 40.149063371842914, 38.95397993826097, 39.921879691462365, 40.242219663435414, 37.87322575046171, 38.97547844917544, 40.951988235596694, 40.24440050125122, 38.80189003482942, 40.024626178126184, 41.4354399711855, 40.800235655999955, 40.423597904943655, 41.434314250946045, 39.14883544368129, 40.06864693857009, 39.67870843025946, 39.92953223566855, 42.558018392132176, 40.994279230794604, 43.17791761890535, 42.24461317062378, 41.87591037442608, 42.17705426677581, 37.908064242332216, 40.07332632618566, 37.95088083513322, 38.04120125309114, 37.152101916651574, 40.928810950248476, 44.83653891471125, 49.76938616844916, 51.61010349950483, 55.009170655281316, 54.15186605145855, 54.555411261896936, 52.93493109364664, 53.91032257387715, 52.867654600451075, 55.600852351034845, 54.88088953879572, 55.261151559891246, 53.74813648962206, 50.71759562338553, 30.078838832916755, 5.8484220985443365, 2.35428772145702, 3.9831350407292767, 5.124554566798672, 4.535355241067948, 1.0917512880217646, 0.0175657200311581, 5.711832911737504, 54.39712009122295, 49.6693657290551, 40.300819873809814, 27.794799535505234, 41.61429220630277, 56.20374025837068, 42.10403934601815, 2.53248663679246, 0.022979776390017043, 0.04313141280304521, 0.021814759670486374, 0.06952512979267106, 0.12198533697594559, 0.03519062418490648, 0.04138283243763351, 0.008093297571664857, 0.016371668579297203, 0.05181541012960577, 0.0516457331456965, 0.053687288515990784, 0.033670648286539706, 0.08195299880519029, 0.29284483122248806, 0.22250282187615672, 0.1969516598769734, 0.06408536543829307, 0.18565961580363013, 0.17296446637520868, 0.09187107950809503, 0.0914643251246983, 0.17259372578513238, 0.08286635947203444, 0.1511802199867464, 0.1585826211638989, 0.15449741134239783, 0.1379024147266342, 0.12515353955208294, 0.30065129781442307, 3.9871174721948566, 45.75440099162441, 65.28827905654907, 46.405228107206284, 49.04868595061764, 54.261068759425996, 52.56976235297419, 57.32056063990439, 61.45417398022067, 30.3728263608871, 0.815336530006701, 0.8664350848524802, 3.793004275329652, 14.699304815261597, 8.868900614400065, 2.977921780078642, 15.497506164735364, 48.36612686034172, 53.12798623115786, 54.80769026663996, 55.230651209431315, 57.37091210580642, 56.185528693660615, 56.18406172721617, 55.62992103638188, 55.51851395637759, 53.47355488807925, 53.02572611839541, 53.40815721019622, 53.405262501009055, 53.7164790399613, 49.93630655350224, 53.074641996814364, 52.07621835893201, 53.79185130519252, 54.25085882986746, 54.78668989673738, 54.40305855966384, 50.14406665678948, 54.48077640225811, 50.11682579594274, 50.67432795801471, 46.06874365960398, 42.891066843463534, 41.4448340477482, 41.0184645652771, 43.825281281625074, 42.65983919943533, 40.56456396656652, 41.268064591192434, 43.952519047644834, 40.212174307915475, 41.37139158864176, 42.216179909244666, 41.67188044517271, 43.675803676728286, 41.791497045947665, 41.998535433123195, 41.1440117897526, 54.43228413981777, 55.198546609570904, 57.948587017674605, 55.61628295529274, 57.83720739426152, 56.851351030411266, 55.35622196812784, 49.360341795029186, 53.4924764017905, 46.5237307548523, 56.87883900057886, 57.42604886331866, 58.24782071575042, 53.298719160018436, 53.09794479800809, 55.861089844857496, 54.13483904254053, 49.172523021698005, 48.31029976567915, 43.85067078375047, 46.614737587590376, 48.04419440607871, 50.18638118620842, 50.61937947427073, 50.19704611070695, 46.91618742481355, 41.64358446674962, 41.869332559647106, 43.081023308538626, 40.952521677940126, 39.467759440022135, 41.457644508730986, 42.400009632110596, 43.25678471596011, 42.375526197495006, 41.892388251519975, 42.26671572654478, 42.06344281473468, 43.35670709609986, 42.738102251483554, 40.6645961730711, 42.957813816685835, 42.24965341629521, 41.57177371363486, 44.98266681548088, 43.436982324046475, 46.76842781805223, 43.76033859868204, 45.56527214665567, 44.530150813441125, 40.77123757331602, 41.90074289998701, 40.192758575562515, 40.88287607316048, 39.35490500542426, 43.021426816140455, 47.549811024819654, 51.879762526481386, 55.12754386471164, 57.51227040444651, 56.844345677283506, 56.529842192126864, 54.72182958356796, 56.34520446100543, 53.242542974410526, 56.4883670499248, 55.24718399970762, 56.34805210175053, 56.98549609030447, 52.88757631855627, 32.897150055054695, 7.198681360290897, 3.120612458836648, 8.055933992708884, 8.036255951850645, 8.19746977859928, 3.4291179045554134, 0.281405575693615, 7.120184927217423, 60.12294507795765, 56.41131993262999, 46.53003008134904, 35.082114204283684, 49.14134017882809, 63.719342754733184, 47.80627127616636, 3.339146577542828, 0.14215735898863885, 0.29762402477283634, 0.09015348739922048, 0.23269531527353873, 0.1808994365555625, 0.12356693315650187, 0.1498340043209253, 0.125122620243459, 0.17904942614897607, 0.24756897361047808, 0.2238245993371933, 0.14040306360731203, 0.11384133970545185], [0.06570466463604281, 0.008962883016905718, 0.07859417057085423, 0.04769722405340403, 0.018350469857274045, 0.04888804261422446, 0.07138232610398723, 0.03051180538961724, 0.049674646373117165, 0.0724848798446117, 0.047757676051509, 0.05859523846377289, 0.026858402941856655, 0.0452922020978745, 0.023792545881963546, 0.032824186247683344, 0.07958728099061597, 0.378630866687144, 20.724352713554136, 47.61549503572526, 47.07212909575432, 36.7362992994247, 25.667453042922485, 38.14945474747689, 41.27743905590427, 49.443974571843306, 33.004917175539084, 2.280531963033061, 0.10165714793988775, 1.5006923315025147, 4.415696474813647, 3.670077684425539, 2.34069180584723, 12.465928812180797, 42.854180874363074, 48.80825642616519, 50.92641084424911, 51.671316008413996, 53.577607524010446, 50.871595721091, 49.04594029149702, 49.7540497010754, 51.07369584421958, 51.12189785126717, 51.13690876191663, 49.37281100980697, 52.31085062026978, 48.21933215664279, 45.627775115351525, 48.537169656445904, 46.782093355732584, 49.309994251497336, 49.88832812155447, 50.82456650272493, 49.544030312568914, 50.90934853399954, 48.21735920444612, 49.57078087714411, 49.488191450795824, 45.62578255130399, 43.895236753648334, 37.99839642740066, 37.5840215529165, 37.69588755023095, 36.021372810486824, 37.709137316673036, 36.987687926138605, 37.702559501894065, 38.683807080791844, 36.32485051308909, 35.57286154839301, 38.56592024526289, 39.38791959516464, 38.713024816205426, 35.23455712103075, 35.98497321528774, 44.27203924425187, 48.07035661512806, 48.862259618697635, 50.13965791271579, 49.59057315703362, 50.360146107212195, 56.518381026483354, 50.90618318127048, 47.35181762326149, 52.58908002607284, 41.805637190418864, 52.48651396843695, 58.28280041294714, 47.889115656575854, 49.75530485953055, 52.67382283364573, 49.846837289871715, 47.99987162313154, 41.13325272836993, 41.60967557660995, 41.9114980389995, 47.395257872919885, 50.24736227527742, 49.056911160868985, 47.1990099260884, 39.92809272581532, 39.55769546570317, 38.34090955795781, 36.50034912170903, 37.128512782435266, 37.380674116073116, 38.19944143295288, 38.681112412483465, 41.47123552137806, 38.40127091253958, 37.33299770662862, 36.271427831342145, 38.32646739098334, 38.150831499407374, 38.18257524121193, 37.40312968530963, 36.64550035230575, 38.562005719830914, 40.68603584843297, 47.33843057386337, 49.277144401304184, 47.92822560956402, 49.143395500798384, 46.56227980890582, 45.277507458963704, 40.77530507118472, 37.458654757468935, 35.87709234606835, 35.844830851401056, 34.78355123150733, 37.91388503966793, 44.97859539524202, 49.38448006106962, 52.69796894442651, 52.50516876097649, 51.80752815738801, 53.00813821054275, 52.779601312452755, 51.43655823123071, 52.24009498473137, 54.99430487232824, 55.351848525385705, 54.53788218959686, 54.722712116856734, 48.207361082876886, 23.402803982457808, 1.975357712757203, 1.7724923597228144, 4.8003373319102876, 4.750187868072141, 3.0102938365551735, 0.6046646797368603, 0.032638417586924574, 5.668533377109036, 46.78912616545155, 41.58226213147564, 36.81366412870346, 26.774392973992136, 37.64106065996232, 48.8244911163084, 22.742902463482274, 0.42980462072357056, 0.022972163391269507, 0.059363387164569674, 0.05488131315477433, 0.016126778998201894, 0.030710501784098246, 0.033870306121365684, 0.04337262324688416, 0.02912503494430454, 0.034227793390351924, 0.021592094300074444, 0.02746839279068574, 0.021799162120348024, 0.01653133662447574, 0.13298742443082795, 0.051325661610932126, 0.06514525957285397, 0.0844459101978329, 0.01129647206154562, 0.03307404965462704, 0.014287321452772426, 0.0014614160177335446, 0.03795035634069674, 0.054980391306021524, 0.06223935018023176, 0.021710797708721894, 0.04292408259765756, 0.02820734396546839, 0.027740530204027895, 0.04402510416243346, 0.06059205812972881, 0.7671068212197674, 26.507642384498354, 55.22536385443903, 49.88426846842612, 41.8477399118485, 34.1796003618548, 45.85623748840825, 49.64778092599685, 54.7053320946232, 36.3823446150749, 2.022020312086229, 0.17883109109055612, 1.4447937761583638, 4.816806873967571, 5.255676459881568, 1.9447503551360101, 13.936647003696812, 45.24930953979493, 50.10253660140499, 51.3111129883797, 52.289489392311346, 53.1459467641769, 54.11776104281026, 51.159470235147786, 51.12269017004198, 53.36303818610407, 52.37531085168162, 51.84319034699471, 51.35105056147422, 53.50637728168119, 49.605321268881525, 49.05776231519638, 50.50636422249579, 48.7052353735893, 52.27913433505643, 51.54546283906507, 53.891240242988836, 51.07145617085119, 53.44196804108159, 50.16634964173841, 49.43148966758482, 50.77328935746224, 48.26530625743251, 46.04780212525399, 40.07160440568001, 38.75901068410566, 38.51931464287543, 39.64310899857552, 38.80386298702609, 39.255355250450876, 38.6860663660111, 40.080923957209436, 40.25652454745385, 39.17404843914894, 40.3368389991022, 40.859192802060036, 40.614856596915956, 37.00348723319269, 37.911402179348855, 47.592184389791186, 51.29265431434878, 52.121227556659335, 50.326664755421305, 52.19920427568498, 52.22154217381632, 57.65361301360592, 50.655151490242254, 50.96426563878214, 52.10193341778171, 43.55672836303712, 57.974706080652055, 57.00582181253741, 49.00386110428841, 51.89238079132573, 54.422356620911636, 52.468678951263435, 50.501504405852295, 42.69030032619354, 44.1254916498738, 44.24781076369747, 49.64847126314717, 50.81698063881167, 49.982923923000214, 47.5469712288149, 42.62180005350421, 40.154248745210715, 38.80106241472306, 37.871876455122425, 39.701591537844756, 39.42191085507793, 38.19051019607052, 40.04302993897469, 42.61831306642102, 39.806550241285755, 38.57305111423616, 38.75045207238967, 39.54581852882139, 39.82349488043016, 39.54581460645122, 38.67204781501524, 39.20903205871582, 39.453215291423184, 43.4170723730518, 48.28434151987876, 49.9740711335213, 49.8798793362033, 52.413502970049464, 46.4300488656567, 48.21593538407357, 42.35012100588891, 38.80138797144736, 38.81018977011404, 38.087363627649125, 38.47962810147194, 40.087215438965835, 46.42842500440536, 51.67792127978418, 54.283924410420084, 52.62453040769024, 52.66591925774851, 54.45827768694971, 54.45261770679105, 53.79212587110458, 53.12487186924104, 56.17809972455425, 57.32693449143441, 56.121558758520315, 56.42400487776726, 49.525755989936094, 25.9891717280111, 2.380866192040905, 2.2732358642162818, 4.522932604435952, 7.685096936841165, 4.874425020910079, 0.9190899626381936, 0.08673900287718543, 6.0293379906685125, 52.28958745156565, 46.688458534979056, 41.75754108736592, 28.333229172614317, 44.19885958394697, 56.16027647449125, 28.815217864128854, 0.7072413400296242, 0.055501832882122654, 0.026574465859260772, 0.08053146903553317, 0.0470508948238867, 0.023351018767683737, 0.07412158839044071, 0.08797798155536575, 0.009383572539645097, 0.030886006781891472, 0.007303161189831313, 0.058429185075745474, 0.029671736354489, 0.02480814672796236, 0.22615053420585973, 0.15716373439758055, 0.17044504834038599, 0.17796577945832284, 0.10323272266935918, 0.19745979067539016, 0.15952060389662945, 0.14117721077655593, 0.14500087818070767, 0.17574315920712488, 0.16758220841086682, 0.1584636936745336, 0.10958795060193348, 0.1278330393195633, 0.25101310573518276, 0.13474179642094722, 0.19357704257051792, 0.9072795834752821, 33.91669565631498, 62.83086315278084, 57.35835659888483, 50.394372709335826, 37.36333331754131, 49.10598001172466, 52.23855349325365, 59.30875908943915, 40.46638704115345, 2.9088088821980262, 0.3647681073315682, 5.4452485326797735, 12.445516797804064, 9.582915152272871, 5.63936859369278, 17.08911768851742, 48.003464514209384, 50.98001787739416, 52.84432826503631, 54.79098489207607, 56.2188413835341, 56.21483272121799, 51.9474861698766, 53.56662096515779, 54.203535433738466, 53.95093479464131, 53.71083082691316, 53.42414086864841, 56.18339492428688, 52.13399094920005, 49.182791786809126, 52.115630334423436, 50.84686517715455, 52.53793624139602, 53.81698193088655, 55.02134569229619, 52.203467892062285, 56.9286060333252, 52.77569463176113, 51.345845576255556, 53.244610063491336, 48.82918227103449, 47.760787471648186, 42.741008727781235, 42.44428142424553, 40.77783892231603, 41.40740286919379, 41.22334957122803, 41.92981158533404, 40.52936461664016, 42.43017265873571, 40.29876062946935, 40.81381097916634, 42.450282650609175, 42.60619686495873, 42.69743119516681, 38.59735019745366, 39.605395409368704, 48.25912852441111, 51.85814242209158, 53.27964467387046, 52.71442720966955, 54.93264521321943, 54.3061093361147, 60.35037194528888, 52.58512627693915, 49.98774451594199, 54.06776651259392, 46.69496182472476, 54.84842015850929, 57.661336160475216, 53.07901936192667, 54.22190781562559, 56.45258326684275, 54.74910182337607, 52.344528090569284, 45.08588398656538, 45.813762141812234, 45.98234561181838, 51.65440274823097, 53.01296664822487, 52.31623603451637, 51.593500106565415, 44.96059956089143, 43.25881258133919, 42.180619701262444, 39.721901570597005, 39.795175367786044, 40.610079150046076, 39.59726825837166, 41.83675727536602, 45.24124906909081, 41.68489094703428, 40.23996037821616, 40.39841236606721, 42.09191529981552, 42.410831451416016, 41.66284722666587, 41.002480906824914, 41.1261453936177, 41.5279176927382, 46.464393138885505, 52.42355600480111, 54.19809510630947, 53.1017691089261, 54.28676420642484, 48.59788794671336, 48.96344500203287, 45.5182429282896, 42.28304847594231, 39.44055780287712, 38.521836726896225, 40.298835154502626, 42.11692040966403, 48.84202018860848, 53.58709573745728, 56.06673186825168, 56.05942449262066, 54.91073485343687, 56.30724376247775, 57.384860054139175, 55.18421819133144, 55.40078009328535, 56.99616493717317, 59.17089170025241, 59.475601027088786, 57.92342893538937, 52.29593384650446, 28.874286797738847, 2.9399449017740067, 4.781517309527244, 11.646855550427592, 11.161034703254701, 12.791010929692177, 3.679802710971525, 0.27688066204709394, 6.610806324789602, 57.57402420043946, 53.873891599716686, 49.52777993294501, 38.611051036465554, 51.67863907352571, 63.02319265181019, 34.90494074360017, 1.248086789442647, 0.19027589309600093, 0.1744143797024604, 0.17291784226413698, 0.1326346256199383, 0.10146315915570145, 0.13099394107778228, 0.1265388716673178, 0.06904997141851534, 0.22148925690881668, 0.09835987487026761, 0.19041663876944975, 0.06151798263853116, 0.14179607192354818], [0.008263694678222942, 0.08198849931960145, 0.04076987399809784, 0.05303422537361903, 0.05468268187776689, 0.008357098033171027, 0.05920327095795543, 0.03804317172316294, 0.14050409528276614, 0.07254583746074669, 0.03672136744904903, 0.04085374530404806, 0.033811282877239494, 0.032126096287562, 0.11280742744284292, 0.004253578231474686, 0.07436018647445787, 0.11635931749497691, 17.263365061052387, 46.57008532554873, 50.944053665284194, 36.238013159844186, 33.44194766013853, 35.30785837481099, 39.4501244637274, 48.15148299740207, 42.83242740938741, 4.99316938461796, 0.179489758166094, 0.8194905651673194, 2.100374314092821, 4.7387948536103774, 0.9799530128798178, 6.258932948112489, 36.81392300513483, 49.72395335474322, 50.00027256627237, 51.02325808617377, 50.067905995153616, 50.72488338716569, 50.3796128303774, 50.99258907379643, 49.58858843772642, 49.89480787707914, 50.04411289768834, 51.34893640395134, 48.79457519900415, 49.875223482808764, 44.617796174941525, 50.66092129676573, 47.34078399596676, 50.32662160934941, 50.37518839682303, 51.82567696417532, 51.295678461751635, 48.98576328831334, 50.640599496902965, 51.097873333961736, 47.866765991334, 47.02431540335379, 46.5478023405998, 41.18170968947872, 36.81653138129942, 36.12402908263668, 36.61423121729205, 36.446318472585375, 36.2549852555798, 39.09702877844534, 37.31580203579318, 35.788176136632124, 37.37176641341179, 37.58605726303593, 39.935839406905636, 38.39273975741479, 35.95759507148497, 36.002757241649014, 37.05428977166453, 41.17333542916083, 42.4054931056115, 45.53658000884518, 46.29544096608316, 50.579343841921904, 51.82064848561441, 53.73938960413779, 47.791130927301225, 46.51171653501449, 50.01263587705551, 41.02192017339891, 60.53421343526533, 45.55252836596581, 51.40827794228831, 53.117431133024155, 50.01302811407274, 47.491438311915246, 43.07479066233481, 40.397941681646536, 45.52473837329496, 46.79046369368031, 50.103956499407374, 51.06146197165213, 48.75075840180921, 41.37518452059838, 37.98707254471318, 37.109312780441776, 38.193314690743726, 37.685089265146566, 34.79177251938851, 37.50196949128182, 38.259175208307084, 38.712291332983206, 37.46768405360561, 37.03962010722007, 37.41280225015456, 38.46014176645587, 38.068963789170795, 37.57741628154632, 38.22423473481209, 36.77717824136057, 42.11747346385833, 48.54026440651187, 49.59889642653927, 49.857745401320926, 47.98645711714222, 49.34955135468514, 54.25244738978725, 50.86690456636491, 48.90261296303042, 48.4937450962682, 38.39062167752174, 36.69050562766291, 37.47076311419087, 35.372440199698175, 41.52206943881127, 51.15707758934268, 53.05151570227839, 50.901570473947835, 50.83663563574515, 51.947921552965724, 56.28959309670233, 52.02570999822309, 53.26744610263456, 52.68731970940867, 52.97994421374414, 54.34590570388302, 56.091772279431744, 46.93982362747193, 20.0316660634933, 1.391267396749989, 2.047748731509332, 1.8335174528821823, 4.737365149682568, 4.050551513510366, 0.38728407494002776, 0.06636910801452976, 7.356954390002835, 50.62346266162012, 38.90491500977547, 29.830099767254247, 32.72922946560767, 40.62050480996409, 47.667937124929125, 15.255445914883769, 0.09738682063236352, 0.04380838554953376, 0.03188270632357847, 0.030471206560069998, 0.07681116987500461, 0.05138366978855864, 0.03250647809416537, 0.0595225342699597, 0.03334797205283277, 0.03134304526141815, 0.022680665020860975, 0.055456438342169415, 0.018591550066165866, 0.07199849062148603, 0.014208106046182015, 0.07294680021943585, 0.007838799332779261, 0.018400152574383447, 0.05310334948702686, 0.05370847467753676, 0.047130556476693, 0.08424153326139336, 0.09142418211746602, 0.03918820886962837, 0.028658230758963094, 0.0797008611862698, 0.0705370859753701, 0.05192026075336242, 0.03487594590912904, 0.027513392795357975, 0.03339539672578535, 0.16343168193294158, 21.540992144615423, 52.36257491573211, 57.74198793595838, 41.01030995768886, 36.971802326940725, 46.34828705941477, 44.328513529992875, 52.326712685246626, 45.522871325092936, 5.715805782425789, 0.1566691327119066, 0.8035108290853039, 4.783602539570102, 4.625446200370789, 2.3362254519616408, 8.734643766956946, 38.260614718160326, 53.002278189505304, 52.95630408871559, 53.482427289409024, 53.0344690815095, 52.93779442387243, 52.27028546794769, 52.23170503493279, 51.14835816044962, 51.52938504372874, 51.520508720028786, 52.163840186211374, 50.57271503633069, 52.2546979688829, 47.27733573605938, 52.89025529738396, 50.01731918704126, 50.778784598073656, 51.63214721987325, 52.468380851130334, 52.82111567835654, 50.24830364411878, 50.71620710434453, 52.94408198325865, 51.22349900584067, 47.81267650665776, 48.41835321918611, 42.34033076993881, 38.2075293602482, 39.00570423372331, 38.5355689448695, 38.878325262377345, 38.88118859260313, 40.295359934529955, 39.49471004547612, 39.71904608511156, 39.592914427480395, 39.19565285405805, 42.69881971420781, 40.29354387714017, 39.132840018118586, 37.19453411717569, 39.07837006353563, 45.497399453193914, 45.78344222038023, 48.01532576161046, 48.57249844458796, 51.79082670519429, 52.69260706440095, 56.543696003575484, 48.40553491346298, 50.96076688458843, 49.72461231293217, 47.54748505930747, 62.2670106733999, 47.265647072945875, 52.71337993683354, 54.308917753158084, 52.26146797980032, 47.606626556765654, 44.85915922349499, 43.23557253806822, 47.043990012138124, 47.48393874014578, 52.103541589552364, 52.22313857847645, 48.750958442687995, 43.73104633823518, 38.44668019202448, 39.63338152054818, 39.81974509454543, 39.802733775108095, 37.07856532066099, 39.688671250497144, 40.26981745996783, 41.02543461707331, 40.18763988248764, 39.70999717712402, 40.94566537487892, 39.22405473647579, 40.58007301822786, 38.832704174903135, 39.745898631311235, 38.07963655840966, 43.020285406420314, 51.71410906699396, 51.900621691057765, 51.61087228405861, 51.44481874281361, 52.930498815351925, 56.49257575311969, 52.84919200404998, 51.87846814432452, 47.730161605342744, 39.844024565912065, 38.174828560121604, 39.76560461905695, 38.54744588175128, 43.89489550744334, 51.804868790411184, 55.0869865571299, 52.97652390695388, 51.948007845109515, 52.646640808351584, 56.83937995664535, 54.26783877034342, 54.597502216216064, 53.95206051488077, 55.1210327302256, 56.68994549782046, 57.278002923534764, 48.066434244955744, 21.381975335459558, 2.370723678219703, 2.903155766187176, 5.177661497746745, 9.152828243470962, 7.45612318477323, 1.3174026699796801, 0.16323991480373568, 7.148550037414798, 55.538592569289676, 50.32251881014917, 37.40844449689312, 37.50131053309287, 47.513831123229, 56.362168712000695, 19.92929808555111, 0.040309535594837326, 0.02744869667015249, 0.042199662195578705, 0.016688003520210905, 0.06279609308788373, 0.052185622119014306, 0.023495547000258684, 0.05812287631054079, 0.08182994210191312, 0.05167327400657439, 0.04728918647273414, 0.016126978181062207, 0.08834427883548122, 0.07882090195292428, 0.1123871056423072, 0.20673303985066954, 0.11818776252649485, 0.0951274664651963, 0.13533519280533637, 0.11743811484906944, 0.12762398924678564, 0.1923627625670164, 0.22273756653791477, 0.1295467703452995, 0.13427656654629017, 0.2335696973867955, 0.17330839388793515, 0.13617574447585692, 0.14227306890872218, 0.12567647883007604, 0.22344104975702303, 0.30057144080919607, 25.431502865206813, 60.92513253611904, 63.78968261903333, 47.26219538719424, 45.77680949241885, 49.327507634316724, 51.060544137031805, 57.81464984340053, 52.32321000868275, 6.768368424907808, 0.5042811453102097, 2.875858276121078, 8.04037836290175, 12.291998171037244, 2.623622662598087, 8.329718862810443, 40.671907471072295, 52.236007875011815, 53.5898139399867, 52.57763454991003, 52.97655920828543, 54.94301988232521, 54.547123293722834, 54.190254288335005, 52.74564927624118, 54.00117251180834, 52.732375975578066, 55.572650509495894, 53.31213366600775, 54.73610701099519, 49.491580378624704, 53.76128035206949, 50.52221059799195, 52.95163646821053, 53.9484715461731, 55.397379398345954, 55.33625710395075, 51.8396641362098, 53.06984886046379, 54.9419726094892, 51.44337138822002, 49.67567682266236, 52.47474685792, 44.957846057030466, 39.87596050385506, 40.789374612992816, 40.132197180101954, 39.78070966659054, 41.43212164601972, 41.395678904748735, 40.62704340104134, 39.980303395179014, 41.040704404154134, 40.71713632152927, 44.369396394298924, 43.65340302067418, 40.11284812804192, 39.432571857206284, 40.218359885677216, 45.71381622745145, 47.05307422145721, 48.431304885495095, 48.42937900174049, 54.34668625554731, 56.83295119193293, 58.01395331659625, 51.262479520613155, 53.04274528257309, 52.177815591135335, 46.191035316836455, 58.87769452987179, 49.30954317892752, 55.507758817365094, 56.40196900213919, 54.45763049587127, 50.285644608159224, 46.44971955207087, 44.60543286415839, 51.043305320124475, 50.28903745835828, 53.36999254841959, 54.366184357673895, 51.74899070493637, 44.977810921207556, 42.00150466734364, 40.373230749560946, 41.155873037153675, 41.86763025099232, 39.05924458657542, 40.42747712904408, 41.706918977922015, 41.171397778295706, 41.6699271048269, 41.339267376930486, 43.099230950878514, 42.33191336354902, 42.645844182660504, 40.89826745371665, 43.09968594581851, 40.61062435950003, 47.71278158310921, 55.47566990698538, 53.36079066799533, 52.99433538990637, 52.188813917098514, 55.18193929426132, 59.739906018780125, 55.306439245900805, 54.77747624920261, 51.93917466748146, 41.68916240815194, 41.326311788251324, 41.20453396151143, 39.94338996948735, 45.57230103400446, 55.15656548161661, 57.73699475872902, 54.85813979179629, 54.44361978961576, 54.53391275098247, 60.63484576440627, 57.255731705696356, 57.17115756004088, 57.15870795711395, 57.196754947785415, 58.585101404497706, 57.969250063742365, 51.00725873824089, 24.603912176624423, 3.041194513920815, 4.908605044887913, 8.680273832813386, 14.197137490395578, 9.295945725133343, 2.9932168174174527, 0.36516543117261707, 8.491048889775431, 61.571193971941554, 51.38033889955091, 41.63158593639251, 43.696380430652255, 53.71168590361073, 64.6793193201865, 24.023734792586296, 0.18664829823518955, 0.1404170370510509, 0.14216111281946783, 0.20997500137215663, 0.2200871321462816, 0.21022603306318485, 0.10837742442926092, 0.22386150945338512, 0.15629050141621023, 0.0858087882760071, 0.12635347838964195, 0.1649967842404881, 0.17011780622265033, 0.17090514542595034], [0.027648952053559404, 0.12866290406354014, 0.07708621842245902, 0.042717932167673306, 0.016912145525096886, 0.031149301625367616, 0.061499129214714614, 0.07299255099027388, 0.04967080061173728, 0.006813091871839378, 0.05074655659677041, 0.11990386076391706, 0.011514125301712945, 0.037702534558071245, 0.045949528519544876, 0.016786166196388584, 0.05836274610051225, 0.06825588298060241, 8.206236275934405, 41.455793150009654, 51.02155969988916, 32.08223058331397, 22.890583622840143, 27.83168354342061, 43.043733335310414, 50.07519375893378, 48.54983106736214, 8.126637166546237, 0.18097978385706104, 0.4842818684635624, 2.8363808460773963, 1.162771438398669, 1.0454002719733024, 4.713395545559545, 30.657196237194924, 52.29296068991385, 50.657269570135306, 54.01153933617377, 51.77836141278667, 50.792532505527625, 50.277909694179414, 49.42157783815938, 47.08307250853508, 48.471309138882546, 48.29919945809149, 49.49786793801093, 49.785589479631, 47.24454079904864, 47.59835820044241, 52.738424270383774, 50.37518839682303, 49.06082568630096, 51.550499162366314, 50.45658542263893, 51.64360446314658, 49.30121206468152, 51.55592380031463, 51.43123949727705, 48.41340711039882, 48.034572832046024, 49.20594946030648, 38.459541643819506, 36.92542814439343, 36.947522855574086, 38.09781674415835, 35.91131894819198, 36.69296495376095, 36.41875205501434, 38.16901560752623, 38.19787640725413, 37.7129106367788, 37.736099689237534, 39.628894329071045, 38.37644623171899, 37.38165078624603, 36.90706360724665, 38.71148332472771, 35.371071292508034, 38.95155199112431, 37.56156598367999, 40.88453523574337, 44.942925360894975, 52.175446479551255, 49.055216696954545, 53.871930414630526, 44.98223143239176, 47.51636889673049, 40.36432696926979, 52.44379543489026, 51.82316664726504, 45.807588331161014, 57.22672185590191, 49.506053924560554, 47.48679422563123, 41.659889759555945, 44.8356250024611, 44.962427385391734, 49.58447387141567, 50.679109327254764, 55.162676534345074, 48.780074196477095, 45.329671059885335, 36.76874906786027, 37.82245066858108, 35.61280696622787, 39.257583156708755, 37.483040132830226, 39.40159297758533, 39.40729218144571, 39.886617583613244, 38.11260015733781, 40.31306943585796, 36.46636962890625, 38.90392657249205, 35.94346277175411, 38.42712325434531, 37.76245017205515, 36.38392925262451, 44.468573524105935, 49.57919436116373, 47.25195407867432, 45.27321638599519, 50.112511188753196, 47.30142301128757, 47.479526073701926, 53.67816140574794, 51.27254040010514, 51.15845826364333, 48.698579111406886, 40.68445121088336, 36.203268804857814, 35.85466423342305, 36.14606888063493, 44.0746263534792, 50.468791838615175, 54.745261822977376, 51.99248360049341, 52.00890264203472, 53.87100865764003, 52.22082045770461, 50.537876544460175, 48.97035621827649, 50.510031638606904, 52.633826424998624, 55.95909810835316, 46.51247355245775, 17.1603302801809, 1.1536820809687338, 2.32158643103415, 2.0824493275534723, 6.814711718789994, 5.175568913259815, 0.7049015236477698, 0.07172948650775418, 12.291320581589977, 48.69404877385786, 39.44561766039941, 34.81969587264523, 24.64186699159684, 44.64723356308476, 40.54239473035259, 6.9636274441596, 0.09817728547439461, 0.035313807292691166, 0.035514154606648994, 0.04303765130199252, 0.056773504362471645, 0.05847523079043435, 0.011058027195113321, 0.05723511830212609, 0.10535628009106844, 0.04508574140228091, 0.07769156577846698, 0.018724617623393575, 0.07014000728245705, 0.030221844940716704, 0.06694205751221988, 0.058257083423555865, 0.03737788564795929, 0.036897770684933474, 0.013581869387698751, 0.0551537225293296, 0.02615013550366125, 0.04219635269574581, 0.02370293849268027, 0.02314958169365362, 0.04145912330357298, 0.04973468468374303, 0.026816178090690125, 0.06591322441254893, 0.02054893344099964, 0.023347895044172486, 0.03880768150631939, 0.12867214308390695, 11.394428476210564, 47.20612902795115, 57.34648750674341, 38.97080690630021, 30.281250784474036, 35.784434195487734, 49.6190534868548, 55.14016997429633, 52.975213835316325, 8.383653413864876, 0.09892576103729588, 0.42876317015578674, 5.817236804193066, 6.140375877580335, 2.2585836052894592, 5.057570780477216, 33.376189124199655, 54.214714188729566, 52.69528996559882, 54.69474169515795, 53.10159260226835, 52.70819848583591, 51.38377881819203, 50.95739364624024, 49.08873727244716, 51.72659789362262, 49.87505089852118, 51.41780930180704, 49.881797375217566, 49.49956240192537, 49.03531459070022, 54.24270029990904, 52.434707303201, 50.891101667957926, 53.757224621311316, 52.96605902333414, 52.12656590246385, 51.849117048325084, 54.087119487024125, 52.731932747748594, 49.56696833333662, 51.09442949295045, 51.09186034048758, 42.03953204616424, 38.71885738065166, 39.417451120192005, 38.999506888851045, 38.18318320858864, 38.18631325998614, 38.398572321861025, 38.62486170184228, 38.93390132534889, 41.22732293221259, 38.73544116174021, 42.976892225203976, 40.30903723932082, 39.3018667159542, 37.98683720250284, 39.48879118888609, 38.50382128069478, 41.60740844665035, 40.49956637044107, 42.26744920976701, 46.9230515726151, 52.81761692416284, 50.896361566359005, 54.92770694917249, 48.453693774438676, 49.66529823118641, 44.15132830219884, 56.507625887470866, 52.44405038895146, 48.03185462951661, 56.74708658649076, 52.29674185475996, 48.92722191349153, 43.65749013039374, 44.85408367649202, 47.39590898636849, 50.16646731284357, 53.02352174635857, 56.459686679224816, 49.40945379195675, 47.87842327548612, 38.33621448086154, 39.67216591681204, 37.270228016761045, 41.105345064593905, 39.466410144682854, 39.997306869876006, 40.7750658066042, 39.71061298924108, 39.35602680329354, 42.456738871912805, 39.27492003287039, 40.4082614375699, 38.73916741340391, 40.17212690845613, 38.49373294461159, 38.61884870836812, 46.314284032390965, 52.39511882105182, 50.97533456740841, 47.77642988389539, 50.93479294930735, 48.52157431264078, 50.18082318767425, 55.98081627199727, 54.18555528886857, 51.402182579040534, 49.50151574227118, 42.05498618464316, 40.026140213012695, 39.04939551507273, 39.49019147503761, 47.708874902417584, 54.53748210783928, 56.44639376671084, 55.30396423032207, 55.08521756818218, 55.067327637826246, 52.19681162987986, 52.05579065507459, 52.2954749291943, 53.30782690355855, 54.56190670690229, 58.01718142724807, 47.65835869696833, 19.410952944909376, 1.586638693847964, 2.930972234856698, 6.186804483013769, 7.392753862565564, 4.824193677594585, 0.7370604238202496, 0.023267963345372872, 11.975872785814348, 53.77715026178668, 45.389557807676255, 35.57733697275962, 29.26626689972416, 51.506745123094134, 48.8334027413399, 9.717768199982183, 0.07438796482259229, 0.01757451855096846, 0.011738424354623403, 0.04455591499384853, 0.04940093847953024, 0.022165961188053893, 0.01792134570648834, 0.0704313122156647, 0.05916442263931517, 0.08904569361719394, 0.023539562581948215, 0.02595278550870717, 0.019832629740478534, 0.06046155888226725, 0.1977492646584588, 0.2673075967017682, 0.07167069692044489, 0.15837548631093196, 0.15130709946876572, 0.10969012374839476, 0.10188554173275348, 0.24272507627404508, 0.17733300615462566, 0.09371663894384138, 0.1095451262869662, 0.16364712117900773, 0.10911501388275817, 0.20185327427762173, 0.09579050024190257, 0.2019074826591438, 0.19413438685719045, 0.1577617426312739, 12.088259477769176, 55.96575044816541, 63.71389066019366, 43.85217697389665, 31.767550591499578, 39.27299807148595, 54.006322583844586, 59.19950146828929, 58.07795855306811, 10.699705135437751, 0.23701326260643624, 2.056611204339612, 12.31388891896894, 9.446786353665015, 4.812705545656143, 5.870689884308846, 35.596772316963445, 54.56766866868543, 54.52103560970676, 55.440043018710234, 55.03148109682145, 52.91957109205185, 52.417907791752974, 52.94879667220577, 50.49761341464136, 51.69553272185787, 51.76399377084548, 52.04851858077511, 53.25562800130537, 50.56873383060579, 50.7354227958187, 54.98377330841557, 54.177404603650494, 53.75625187350858, 55.81710046337497, 54.52106306629797, 54.99549335049045, 53.36010033084501, 58.19009127155427, 55.11499228016023, 52.34653242172734, 54.48298469666512, 54.41092683422951, 42.55753201823081, 40.68022681820778, 42.533719308914684, 41.17154682836225, 40.80261261232438, 39.488049860923525, 40.58181455058437, 41.28825303046934, 41.2244439125061, 42.03758655055877, 40.88449993441182, 43.80320618229528, 43.72738284449424, 41.02036691481068, 39.392402864271595, 40.52597568881127, 40.03136873245239, 43.575061521222516, 40.65619837853217, 43.40323817345404, 48.66631761673958, 56.420968963253884, 52.34814843823833, 55.2190488384616, 50.53581730011971, 52.80478292895902, 46.22542665850732, 53.66595106740152, 52.364241923055346, 50.47278088908042, 59.78361691198042, 54.302383084451, 51.15614014287149, 45.380583424722, 46.873868973024436, 49.12186168855237, 52.399649158600845, 54.844603692331624, 57.38956297597578, 53.83887660118842, 50.51370689945836, 41.26609556136593, 41.512738120171335, 39.09200029988443, 42.32485701960903, 42.148311138153076, 41.801412797743275, 42.81891092177361, 42.32098171787877, 42.45285180307204, 43.391608345893125, 41.241463076683786, 42.39402017285747, 40.31581509497858, 41.69840743464809, 41.280992723280384, 40.28878211975098, 49.17984216443954, 51.63084499297604, 53.224327487330285, 52.44687057310536, 52.688410128316576, 49.97625589370728, 51.53139329725697, 58.87567450923305, 56.186987815364716, 55.180323277750325, 53.736294854071836, 44.04081552259384, 42.104188396084695, 40.332653830128336, 41.35869879876414, 49.33498759423533, 56.63935084496775, 59.11104809853339, 56.646258138841205, 57.17180475111931, 58.008167820592085, 54.5106021050484, 54.78547003961379, 54.67269013004919, 56.59816988052861, 57.43095574840423, 59.92406129837037, 49.324048103824744, 20.806961751753285, 2.2830920450149046, 6.740580393422035, 9.261691666418507, 16.505115993561283, 14.100075498703989, 2.5323944610934106, 0.16885209107591262, 14.498890330714566, 59.62128962239912, 50.76879824361494, 46.49608981224799, 35.606437037068034, 59.521331940927816, 57.14344601477347, 12.750188862123798, 0.2368292942522995, 0.15338476056293135, 0.11702195290596255, 0.10489341742809742, 0.1832264745908399, 0.12059314071290916, 0.1011977173508175, 0.13222807808028114, 0.21963002280362193, 0.14396920289483764, 0.13614986602577472, 0.12215124097682777, 0.149598493571243, 0.1711338992801405], [0.1055676743928944, 0.02519127495977427, 0.053099427116854545, 0.045889114825836116, 0.14805789075551495, 0.03518908434817868, 0.06449901844344794, 0.031714710902663014, 0.019702760600334695, 0.026433009639262196, 0.057652260837776054, 0.05841048103907417, 0.050408539452379754, 0.06674698854406035, 0.03366697489494278, 0.0337016097299995, 0.025843298137788812, 0.025658397071604288, 2.3111338048211993, 32.90185101570622, 49.904531432736306, 33.13229222451487, 29.111658834641982, 34.79851507371472, 43.152908586686664, 43.610378542254054, 49.889112595588934, 13.32566430491786, 0.13403037653094338, 0.43827347757835544, 2.9193075962605017, 4.049944771874336, 1.0693230528023936, 2.5275621010411173, 25.5406859613234, 54.40097578110234, 51.500681138807735, 53.56392629684941, 51.64665214477047, 52.446023341148134, 51.29875359996673, 50.2217335085715, 49.214206049519206, 48.17799037502658, 48.32535774477067, 49.743718178041526, 47.15062749001288, 50.92555968992172, 52.62652297173777, 51.58835003452917, 51.12172134460942, 51.151213645935066, 50.17105648594518, 51.02130866819813, 51.05101669988325, 49.43211332444222, 51.66363992998677, 48.336493353689875, 47.20080637162732, 48.77779529940698, 45.997905654291955, 40.01336505336147, 37.30593335243964, 36.34452512187343, 37.668458415615945, 36.621354241524976, 35.84154782756683, 36.52833131051833, 36.698746527394945, 36.91153510924309, 36.57984772036153, 38.89727031030963, 39.00077773678688, 37.65805628991897, 38.30265075929704, 39.357136834052305, 36.78318731246456, 37.685108876997425, 37.197542575097856, 37.33989323339155, 37.94756643233761, 41.766790036232244, 48.48579052955874, 49.83360713528049, 50.62269779943651, 50.98726249510243, 49.5510591999177, 42.82747737822994, 49.00774817312918, 49.73802289655132, 46.00377744243991, 54.382638700546764, 49.01996243384577, 48.27107606395599, 44.0089423425736, 46.20290048660771, 44.31343201668032, 48.47510207083918, 47.49119120259439, 51.59423751215781, 50.51520916723436, 49.43756149661157, 38.14486557437528, 38.46387194048974, 35.9413682260821, 38.776331870786606, 37.07967535141976, 38.31539061761672, 37.64678339804373, 37.3791326245954, 36.964565553972804, 40.05797416933122, 38.43531708563528, 39.04697149030624, 38.74361145880915, 38.37709342279742, 38.30143482454362, 37.48951988835489, 45.68783444743003, 51.309351844172326, 46.7167035225899, 49.234567073083696, 48.61688790782806, 50.15342543202062, 47.84458498800955, 48.35528150681527, 52.33023497366136, 53.44506671351772, 50.05939837424986, 50.08762375000985, 41.45474195480347, 36.8982147401379, 35.762166900019494, 36.6489088919855, 42.920841555441584, 46.943153719748224, 48.80438896917528, 49.25561843379852, 50.44900740346601, 47.617824923607614, 46.06645691779352, 45.01817603265086, 50.97511099230859, 53.67232491893154, 54.80623114493586, 46.30395643172726, 18.07832964005009, 1.0345183913746188, 1.8497710194318526, 3.5929300563950695, 5.383696738750705, 4.181028421848051, 0.8046147924277091, 0.0757437948918631, 15.556674138192209, 52.95199732626639, 37.302693474677305, 31.69973085003515, 37.05962027272871, 44.734784787701024, 37.02093001334898, 3.876795908135753, 0.08435063950356939, 0.03708972933612043, 0.012331043159769428, 0.07417400412621998, 0.041254650606142904, 0.03670873465917764, 0.008658560334644731, 0.07199759429861462, 0.027299185035630103, 0.029989925228179466, 0.04744435758179715, 0.0431571303746633, 0.03913661284792808, 0.01376657414385268, 0.05087785640611284, 0.019659419176018527, 0.03012959454809466, 0.07499141994142726, 0.03980834555301455, 0.07455870283827667, 0.035802697792889616, 0.016593278663593437, 0.05466839816841868, 0.05623964067067831, 0.08342199538263582, 0.01561270239988282, 0.04056534767451306, 0.03311547968957213, 0.019178103370171402, 0.027816244588804342, 0.05318560434745685, 0.03547901798400187, 4.213823849155057, 39.741709539967204, 57.94729655788791, 36.65133683912216, 29.840778420048377, 36.5638130710971, 48.55486346829323, 50.43735011931389, 55.51241467075964, 13.935507555161754, 0.100919037546602, 0.4915937793350989, 4.055981789865802, 4.693675829518226, 1.586631094255755, 3.983644948851678, 27.527133072576216, 54.67762054935579, 53.4058508565349, 55.25510326508553, 53.65544303770989, 54.78712920219668, 53.59901189804078, 51.224561968157374, 50.49604054420225, 49.323102812613214, 49.202584066698634, 50.38699080867153, 47.527935966368645, 51.97788061634187, 52.86407739885392, 52.70765327638196, 52.79162729940107, 52.715439181174006, 51.183914446061664, 52.1662877451989, 51.83015631091211, 51.217219291194795, 53.156042945000436, 50.79368568235829, 50.6496052588186, 51.139379855125185, 47.88644844485868, 42.73030850195116, 39.374399185180664, 38.89368526397213, 40.121551867454286, 37.950672949514086, 37.71724485581921, 38.048712591971125, 38.982032729733376, 38.31404132227744, 39.326652173073064, 39.96644566136022, 39.31153928079913, 39.325922612221014, 39.24492174579252, 40.99803293904951, 38.24683543174498, 39.33146884364467, 39.21682188587804, 38.866844484882975, 39.162151890416304, 43.66629585143059, 48.89085369725382, 53.367701884238954, 53.814655965374364, 54.888636219886045, 49.42386065759967, 44.55532850757722, 51.45700946930916, 52.11770919061477, 48.08407314362065, 56.38922522144934, 51.278459256695164, 49.419585274111846, 46.640397733257664, 47.96446046521587, 47.3179950252656, 50.46242190945534, 48.924841034796934, 55.79290336178195, 52.453220890414336, 50.178763943333784, 38.143826146279615, 39.35116698665004, 38.602292383870775, 39.359458877194314, 40.0091955738683, 39.17920635592553, 39.26474148227323, 39.91980083527104, 38.22515256943242, 41.68824065116144, 40.87043823734407, 41.218340704517985, 38.47896129854264, 40.60682750517323, 39.72855783277942, 39.823738067380845, 48.56837603353685, 52.02198766892957, 49.764647945281006, 51.77857714314615, 49.68356470907889, 50.46842313581898, 48.18296786277525, 50.08534093056956, 54.15689060764929, 53.345007050421934, 50.33292485821632, 51.525607801252804, 42.21727425052274, 39.265357294390284, 37.36784404323947, 39.297214784929835, 43.71510974822506, 51.174963597328436, 50.724875542425345, 51.90969413326633, 51.450357129496915, 50.08442309594924, 48.477996780026345, 47.55024640790878, 53.59138288805562, 55.659758506282685, 57.668757284841234, 47.871872917298354, 20.785808409413985, 1.8955357637136214, 2.6226104459454938, 7.837141242719467, 8.71422096606224, 5.122051604332463, 0.9484981781532689, 0.008715486413078203, 16.94918517143496, 56.967292370334754, 40.23772070484777, 38.85282201151694, 35.14748050320533, 50.72493437797793, 45.9077460535111, 5.692253910726117, 0.07385848315372583, 0.05946962440746927, 0.038060129079366886, 0.06984151644451965, 0.026477896645965598, 0.03347127390424571, 0.061381289570201794, 0.03557022075138746, 0.046301825542844115, 0.05620977473295024, 0.09873815376551882, 0.03417648848206286, 0.07128684856598416, 0.11589165146072065, 0.20146817719984442, 0.08388260574710947, 0.103526777858215, 0.14224971854879012, 0.24635469360697657, 0.15320377995169934, 0.08780938858586936, 0.15250230388295266, 0.15731992440358286, 0.12241367205616929, 0.20901850995517549, 0.15008131282464152, 0.1801524242205966, 0.20952947527891208, 0.09108868923278586, 0.12790264606836343, 0.1264080774760054, 0.10422667578583765, 4.631976456411423, 45.56715096196821, 64.87830508139827, 44.15508593282392, 39.79846623636062, 46.291479372209125, 56.39079416951826, 54.50690723234608, 61.3219940277838, 17.10145942626461, 0.3081281014507817, 1.1257179105474104, 8.224084531107257, 12.237023211294606, 5.373454939934516, 3.9934621510967134, 29.647529125213627, 57.51266656383392, 54.01845055241739, 57.54908969325405, 55.815147123029156, 55.541040128277196, 55.151846870299316, 52.519897260973536, 53.35710756240353, 50.682227611541755, 51.13137037523332, 52.316392929323264, 48.18249717835457, 53.220938559501406, 55.64186073118641, 54.33982603011593, 55.8174220977291, 54.55752934178999, 52.236737435863866, 54.91815205543272, 54.43454342503702, 54.51426952115951, 56.39761909361809, 51.86575574259604, 52.01676699423021, 52.94377211601504, 48.78475750646284, 45.958309327402425, 40.91100338966616, 39.89933390771189, 41.28683313246697, 39.40606840195195, 39.83607784394295, 40.09602116000268, 39.20751802382931, 39.5653283980585, 39.473752821645434, 42.61821108479654, 43.06509456326885, 41.34442529370708, 41.626459398577296, 43.70922227059641, 39.12543458323325, 41.41884442298643, 41.170707441145375, 40.66433729663972, 40.20682027263027, 45.54274205238589, 53.09878810759514, 56.04681799488684, 55.12610043248823, 54.722778797149665, 52.52544349239719, 47.64798010549238, 50.097504200473914, 50.54180675937284, 50.901174314560436, 57.2608268645502, 54.16566494972476, 51.177281718100275, 50.76573095014019, 49.57938655730217, 49.11977890999087, 51.86451235125142, 51.35985628251107, 56.849319242662006, 55.20280630357804, 53.446247346939586, 41.35955387546171, 41.53864929752965, 39.60652505197833, 41.4859640213751, 42.05682577625398, 41.98464239797285, 41.92193938839821, 41.35195624443793, 40.781427891023704, 43.303504067082564, 42.147440371974824, 42.608240419818515, 41.79999682211107, 42.861366656518754, 42.0831762590716, 40.590149587200536, 50.40912866592408, 55.410484037091656, 50.86725757968042, 52.79263927090553, 50.1535274136451, 51.896216869354255, 49.335666164275146, 50.39320776539464, 54.8261175617095, 57.23207589118712, 54.28125719870291, 54.85949693187591, 45.943439622079175, 42.32941481374925, 40.26789942095357, 40.527395586813654, 47.4586590643852, 52.051664321653305, 53.47311558261995, 52.99922266314107, 55.8737277215527, 52.85755841962753, 51.970224149765514, 50.62321555229926, 56.30461185209213, 59.3589222815729, 60.066910097675944, 51.206413161370065, 22.704331836392804, 2.945879202696585, 6.543323416863719, 11.65282343664477, 13.596485334057963, 14.335827596725958, 2.772581288891454, 0.20100049584382967, 18.70314948020443, 65.68699582930535, 46.53780029666039, 42.41078046060378, 46.72247332911338, 60.263142355026744, 53.308423103824744, 7.870202900901918, 0.2529685145183917, 0.12136738747358324, 0.14872709920089092, 0.12912153026028989, 0.09612370252368913, 0.18883835974960558, 0.14126832927426985, 0.12395898631263165, 0.08084775609595161, 0.18205737845311243, 0.228047015505933, 0.1461261540891663, 0.15347730398418444, 0.19430196092974758], [0.0246241879499247, 0.08268811379469211, 0.03848153872475509, 0.041102011417669636, 0.022631612411069296, 0.09156977712747552, 0.09501422334822918, 0.011235037555677757, 0.07466519672063089, 0.028248973183273792, 0.04302633235291128, 0.0651961278110262, 0.036859462458279826, 0.027379055447395773, 0.039744216332873034, 0.07400643771454211, 0.003502575536033199, 0.014330462736618376, 0.5669989557035509, 19.204746100210375, 47.61011354384884, 36.71423596720542, 19.334621660171017, 22.66996991249823, 40.49782876045474, 47.110595780034224, 51.15882696643953, 27.06583880609082, 0.488246250897646, 0.3350499939293631, 2.4505615618921097, 4.074570147260543, 0.5055945877346301, 2.3363254724010347, 24.003930745586274, 48.41225001119798, 53.71347058203913, 52.95172276035432, 53.83963361863167, 52.96267401787543, 50.68183145215435, 48.818635017641135, 48.80292200273084, 48.517593106915875, 48.73875987145209, 50.18929158487628, 51.603639433460856, 52.44228924474409, 50.59709648932181, 51.24591142900529, 48.49848331943635, 48.052972670524355, 46.524013165504705, 49.97562046973936, 49.74518906685614, 49.892838847252634, 50.09073811192667, 51.62144699404317, 51.47854720392535, 50.29258328099405, 44.86841209473149, 36.1133288568066, 37.258268710105654, 37.54706105878277, 37.45868221406014, 36.81654314840994, 36.26982358194167, 36.0992318584073, 38.38597759123772, 36.21476919420304, 37.74332469509494, 37.611725253443566, 39.01291747247019, 36.88635741510699, 36.56481719786121, 38.5640767312819, 37.82913046498453, 37.264399374684984, 39.35548551620976, 39.246867241397986, 39.866201646866344, 40.1419246581293, 42.264248555706395, 44.28355532307779, 49.2692369030368, 48.96839503319033, 53.341720104217536, 44.358143114274554, 44.684970686512614, 47.90434229758478, 44.94787146968227, 56.89774874717959, 48.46604139574113, 47.38221599209694, 44.82253605319608, 47.362812026854485, 45.393264447489095, 52.39877054768225, 49.80627605991979, 49.91468252674226, 52.84784663108088, 48.30756979603922, 39.80624037404215, 36.750521813669515, 36.337049084324995, 37.80652584568147, 35.57243008767405, 37.4104723622722, 37.35560624830185, 38.21186357928861, 37.27579386003556, 38.49258369015109, 38.54815975312264, 38.49863982969715, 37.49368544547789, 36.60710427068895, 37.58890098141086, 35.92692213673746, 43.69059493464809, 49.9779385905112, 49.83693330518661, 50.62964039464151, 49.701038868196555, 51.824582622897246, 52.327838405486084, 49.869159498522365, 48.27351185583299, 51.28673545775875, 52.49580606337517, 52.05391576213222, 47.30582783299108, 42.00776084776848, 38.84861330832205, 36.49286523942025, 35.31234556628812, 40.93503967408211, 41.67931725901943, 46.66059793964509, 43.76879130640338, 44.032817809812485, 42.32567287260487, 46.965530841581284, 52.423685443016794, 52.41642121345767, 57.70370952544674, 43.27964428932437, 17.79938244050549, 1.107905692150516, 1.0525669325743954, 8.122496124236815, 6.537183926951501, 2.026836492361561, 0.24073735390218998, 0.06478017271165887, 17.16778866706356, 50.14982077383226, 35.490126994348344, 25.936209924759407, 33.06484314703172, 46.52955155218802, 23.710311920412128, 2.367985128395019, 0.16388577288917958, 0.06821749431471671, 0.052929849724375436, 0.06026489645122521, 0.08959238162083973, 0.03672495274053466, 0.08778182474235374, 0.00710370636830527, 0.01888906031156019, 0.017237233020545497, 0.04184369561112216, 0.03811610329355444, 0.027722318378847935, 0.09219674348470666, 0.08774959542337926, 0.031370222230532, 0.04743719849014475, 0.01707997623710863, 0.0025044314398039737, 0.04447223520987938, 0.032581412984478864, 0.014001744942018583, 0.02434016659765715, 0.0551078874888199, 0.0068173206771814055, 0.028436578539831024, 0.007864167376781904, 0.0072333016320161765, 0.019446722524721297, 0.00883716032765205, 0.08152342266252927, 0.030793400158384637, 0.9205926594234283, 24.86650113136538, 53.090653111857755, 45.348157190507465, 25.548142387020974, 31.848027821510072, 50.487850635282456, 51.971259655491004, 55.973744238576586, 27.92170782243052, 0.6120152014397806, 0.3404366952036658, 4.296181365366905, 6.5303246821126635, 2.2160101994391415, 2.553624779947343, 25.731407288582098, 50.72889989422214, 54.967064011481504, 56.608395499567834, 54.019019296092374, 52.64321265682098, 52.925156547177224, 50.57589215617026, 50.73318704482048, 48.42132245340655, 49.939922978801114, 48.925907919483805, 52.31836980389011, 55.671188292964814, 51.744664330636304, 53.859633784140314, 50.47777406630978, 50.69055088104741, 49.04617171133719, 50.8634058121712, 52.7291831662578, 52.84607764213316, 51.6726613813831, 49.884456742194395, 53.28917995575936, 53.451013026698945, 48.20113235904325, 38.82836603349255, 38.861125669171734, 39.88735498920564, 41.14655740799443, 37.51870624480709, 38.57805998094621, 38.70575666427612, 40.5476350169028, 38.268353554510306, 38.64552082553987, 39.32456939451156, 40.50697572769658, 39.75836392371885, 38.07201931553502, 40.470701648342995, 40.743792749220326, 39.16686265699325, 39.91454485924014, 40.778470423913774, 41.824268448737364, 42.06891452112506, 45.16369204367361, 46.54569995018744, 51.5755513406569, 53.02562021440076, 52.95295438458843, 46.642194178796586, 47.19312637082992, 47.953811230198035, 48.561770762166674, 58.1050778204395, 51.06363888709776, 49.380024248553866, 46.513834614907545, 49.18394496363979, 47.16348109706756, 53.64396618258569, 50.73016289741763, 52.87233398806665, 53.62301288112518, 49.950474154564645, 39.94098947894189, 39.3111470437819, 38.884479461177705, 38.827730609524636, 37.932794786268666, 38.43124958776659, 39.26910708027501, 39.22164247881982, 38.90800975984143, 40.396749281114154, 39.99268239544284, 39.03283134583504, 39.40932789156514, 38.368601491374356, 39.323957504764685, 39.59734670577511, 45.724367403214984, 51.155940101992705, 52.88442273293772, 53.791243337815814, 53.099352928899954, 53.21543939651982, 53.66159331414008, 50.376404331576445, 49.482535393007346, 52.971613099498136, 53.70685746592861, 52.45581749946841, 50.204596673288655, 42.31023050123646, 39.63176942640735, 37.667528813885106, 38.49995774607505, 42.30188761987994, 45.28497957414197, 47.11519672024635, 46.307561089915616, 45.4508722982099, 45.85964210571782, 48.25137007621027, 54.032155313799464, 55.90761699984151, 59.247173955363614, 45.83838285938386, 20.37966266755135, 0.9716017351996515, 3.784782987448477, 11.008107373791358, 7.007111330186167, 4.266310555319633, 0.39010140924684467, 0.06367754619268161, 18.792401052290394, 55.98554272805491, 36.5340736604506, 28.562621147401874, 39.61000419432117, 54.64122487652687, 32.482934036562526, 2.7546724821290662, 0.21590240750341647, 0.09686048758486587, 0.1031780316524448, 0.03900566543903082, 0.06795101829113499, 0.010457055158762923, 0.05328540262135287, 0.0341339897544634, 0.05452250821455833, 0.0316771611030544, 0.030005729622057373, 0.06729963671175704, 0.02503381516303747, 0.05377621983268088, 0.1478455618264214, 0.1819653253281309, 0.11601486904246193, 0.16888705532877676, 0.18268232233822349, 0.13366083103802898, 0.12097780112056963, 0.17330436426545345, 0.1510839840216983, 0.1324940944511083, 0.07397344230764336, 0.15541444923127853, 0.07534320751625685, 0.15677886714618053, 0.12664928791984437, 0.2077281727425514, 0.12567601917732146, 0.11935253792832937, 0.9385157460647245, 27.47498712232036, 62.26208417646347, 51.48988677609352, 29.276984776220015, 35.18040880080193, 52.694407432310044, 57.76205478175994, 61.29757727346113, 34.43513101147067, 0.9470084129321961, 0.8667326946893047, 9.076744068053461, 12.857378413600307, 4.756176837028996, 3.89813139553993, 27.00168844192259, 53.00090928231516, 56.352982521057136, 57.25385289038382, 55.733777553804465, 55.64319825941517, 53.48154867849043, 51.94610549557594, 51.93263607640421, 49.99280829583445, 49.99487538491526, 49.99618937892299, 52.43915919334658, 56.67006692578716, 53.530437100318174, 54.99091986686953, 51.425571672378055, 51.589075673011045, 50.33218353025375, 54.31208702825732, 55.29600181887227, 53.908820306101155, 54.32119084942726, 54.9504880751333, 55.29840230941773, 54.350298758476015, 48.8412670935354, 40.25973696862498, 41.03341664037397, 43.17824709799982, 42.384335840902025, 38.94046345064717, 40.58619583806684, 40.65366452740085, 43.11260623316611, 39.498922671041186, 40.51298087643039, 40.52155517762707, 43.648747167279645, 41.53188320898241, 40.3030046339958, 41.87995826044391, 42.448537195882494, 41.00135126421529, 42.1323117902202, 42.78073449288645, 44.25651450310984, 43.466470703001946, 47.09394139628257, 48.99718130788496, 53.12336960146504, 53.853856132876494, 53.84870213847007, 48.94877533758841, 50.13972851537889, 49.96270018239176, 50.14340769860053, 61.47477034599551, 51.16652265671761, 50.73449319408786, 48.42380531372563, 51.543595790863044, 49.903711657370295, 56.20881972774383, 52.287045755693995, 53.91622966335666, 54.953084684187374, 51.82659087642547, 45.32512111048545, 41.17931704367361, 40.091671251481586, 41.1373241486088, 40.24864450577767, 41.55791990218624, 41.80746109254899, 41.63470814304967, 40.75840357811221, 42.63053909424813, 41.753383374983265, 41.88699891490322, 42.057206246160696, 39.39081038198164, 40.98188061867991, 41.35245830781999, 48.46814770852366, 54.83959482562158, 53.7427746095965, 55.11920098335513, 54.06787633895875, 55.22456761329405, 55.99507800994381, 50.77169687517228, 50.20503597874796, 53.54520090164677, 57.52113496103595, 56.76224654720676, 51.71101039455783, 46.423392603474284, 43.300346559093846, 40.45468268855926, 39.69652383558212, 44.61181456042875, 45.95233948000016, 50.24893122334635, 47.32576524057696, 46.8753045605075, 47.20752931410267, 50.78875918542185, 57.86701348520095, 58.0901296677128, 59.8818487505759, 47.46985350885699, 22.040470684728316, 1.777402186586011, 6.8409567879092315, 16.041651675778052, 14.08153739667708, 6.341813610446069, 1.86926017365148, 0.1634446288188619, 20.994225509705085, 61.82706979013259, 46.54311118587371, 40.07036101433539, 47.18685450092439, 60.9485294741969, 37.282281460300574, 3.58825973926052, 0.4166983272279463, 0.16486055848579254, 0.18650689372612586, 0.13215916081061288, 0.2336881039363723, 0.20110079207487647, 0.1472012818821015, 0.1695110339431032, 0.11320128090559475, 0.0793220307077131, 0.12452393019151305, 0.16468815805931247, 0.0999034577680211, 0.19505174650299936], [0.066188640682207, 0.043128229707719824, 0.03990946532857995, 0.004226258578484938, 0.07315624865793413, 0.014862776057974947, 0.06572839803993702, 0.0695730485923348, 0.08576422494145171, 0.00902717215790143, 0.009916457554115164, 0.023940232312006336, 0.031025095790204023, 0.07439872069704918, 0.04423708452152149, 0.03649886104188139, 0.0311681799470417, 0.010805125291939947, 0.12062871017523351, 10.819561000793211, 40.36738249563402, 37.255895676151404, 26.77749949116861, 24.546918176835586, 34.950965835202126, 44.554771531012754, 52.88069648127402, 40.07656228157782, 3.7004061860422937, 0.39251660868044824, 2.9531262718862106, 2.869132882164371, 1.3197449378428923, 2.026163805877009, 20.33015255005129, 47.09650270400509, 52.961128604027536, 51.585953466353885, 52.25644734597976, 50.89927588739703, 48.191671602187625, 48.694731266267844, 47.184097074693256, 48.83543845145933, 49.68316462732131, 53.16304045338785, 52.145667845203036, 49.79001391318537, 48.66357195761896, 48.19692757821853, 47.687925523327245, 45.59720808459867, 46.74850217757687, 45.07741951173352, 46.948021381132065, 51.33767135681645, 50.49191028841081, 51.92722320556641, 50.287052739051084, 50.38503354595554, 39.22336832169564, 36.91937592721755, 38.9516108266769, 37.87441815099409, 37.06585684130269, 36.02493824497346, 37.17462416618101, 37.07587849709296, 36.52236146311606, 36.697373697834635, 35.89469594340171, 40.47101151558661, 38.749232215266076, 37.88781696750272, 37.379497405021425, 37.092823136237364, 37.102464322120916, 39.19273068827968, 43.07757554515716, 42.5055213897459, 43.20738638600996, 40.75581481379848, 40.09986116040138, 40.36131851134762, 46.648756304094874, 48.15570346770748, 52.99268014969365, 48.63475822633313, 45.33531142819313, 43.9507382915866, 46.062118776382945, 54.46217652290098, 48.732044773717085, 48.704090041498986, 45.27720935883061, 47.146858092277284, 48.38160453304168, 48.81561087023828, 50.15917562669324, 47.95061842087777, 52.61437539131411, 50.28209878552345, 40.06096693777269, 36.59316024472637, 35.768172048753314, 36.074207136707926, 37.44012548077492, 36.03191221913984, 38.094082647754306, 37.049265215473795, 37.44095702325144, 38.16562667969735, 37.64532035396945, 38.89050814413255, 36.54873155778454, 38.99147387473814, 37.50289909301266, 36.391926965405865, 39.415827258940666, 45.59642753293438, 47.58607725943289, 48.24907156728929, 47.63434594677341, 48.762564736027876, 47.842525743669086, 52.88477574625323, 51.597897083528586, 50.44073904714277, 51.328375339508064, 51.59990533705681, 49.02648925781251, 46.440666721713164, 39.86433852103449, 35.495171162389944, 35.98905248026694, 36.10247173616963, 38.27362129765172, 41.277478279605994, 41.056299747959265, 42.39344358444214, 44.736600845090805, 52.23270131695656, 52.89237729964718, 57.557507099643836, 52.796275308055264, 44.197580891270796, 15.750029337021614, 0.7873793463072469, 1.2841184172899494, 8.581305569218053, 7.035315132910206, 2.6337838076776077, 0.4623775760973654, 0.2755911215659111, 23.73744099370895, 44.88788666263704, 31.43880694143234, 34.244044903785955, 38.49926348655455, 45.32900425695604, 16.75938363998167, 0.5094322592260376, 0.16653479767903206, 0.01827017809715002, 0.007133911299939838, 0.021698923345895547, 0.0408594066938085, 0.038446072684300524, 0.05344674839908558, 0.044807839177308545, 0.17536923169128357, 0.019968392011979898, 0.032812342528373964, 0.1488741574388358, 0.09072203189134599, 0.026270915010583498, 0.06847673846829323, 0.021447186853976983, 0.022186446379149155, 0.07899598368713934, 0.10894294287408553, 0.0244969024413055, 0.0711086182104003, 0.03060873657945664, 0.07996850166349642, 0.019562330938154654, 0.011445971247139237, 0.05791392199875367, 0.049449194357880664, 0.09522073000909821, 0.05636370094913629, 0.01912065060628999, 0.03404665956153505, 0.037426432639720945, 0.21518321948186045, 14.55466349278727, 48.66183042526246, 41.406818436038115, 27.759339347962413, 26.52642857643866, 44.31942932067379, 52.40404221319383, 57.26076410662744, 41.70444003997311, 3.7828848054332123, 0.15017099107705778, 2.5892146508539877, 4.370780923674184, 2.2829809929094007, 2.6302522036337086, 21.816297423455026, 48.14077492683165, 54.21205089938257, 53.98839735215711, 54.353864192962654, 51.916522979736335, 49.49739725359025, 49.8937370700221, 48.005602205953295, 50.375031502016135, 51.09681821638539, 54.28887444157755, 52.19416010764338, 52.16068660059283, 50.538696319826194, 50.432584439554525, 49.3836602857036, 47.66439130229335, 48.88895527009041, 48.93828299737746, 49.411920962795136, 51.54755738473708, 52.72333883470105, 54.30469728285267, 51.930306188521854, 52.075053414990826, 43.634446205631384, 37.721084856217914, 40.47002700067336, 39.92474302168816, 40.120806617121545, 37.895179256316155, 37.99513693778746, 38.28218383173789, 38.27528438260479, 37.896830574158706, 38.83021346984371, 41.45540483536259, 40.55306357722129, 38.58788551822786, 40.2718061016452, 38.48840636591758, 38.912846042263894, 40.814038476636334, 43.726955306145456, 44.897802414432654, 44.43648853609639, 41.01373810921946, 41.45824463136735, 43.44665881126158, 47.1703334777586, 50.67876808104977, 53.42051267623902, 49.40284067584623, 45.816197933689246, 47.60162945716612, 50.33262675808322, 55.95534440009825, 50.92463008819088, 49.044128156477406, 47.06348811426471, 49.05849187604843, 50.41542014768047, 50.08786301459036, 52.05750865321006, 52.08495739967593, 55.21480875630533, 53.008750100289625, 41.65556338525588, 37.49448168662287, 36.9373482273471, 38.09933862378521, 38.2797166608995, 38.35046837406774, 40.07136121872933, 39.62595647381198, 39.66921237207229, 39.03978963052073, 37.70401077885782, 39.86320103368452, 37.97829820263771, 40.57546815564556, 40.791069076907256, 38.386181554486676, 41.70404780295588, 48.83305757276474, 49.57194974345546, 50.99046707153321, 49.75868202024891, 50.12374093455654, 50.19730890950849, 53.38079867824432, 53.538532872353834, 51.55438623120708, 51.54998533187374, 52.48753378468176, 52.14476177769323, 49.00798351533952, 41.18458086444486, 38.69007502832721, 37.443541865195, 38.1844775907455, 40.93831877554617, 43.52909134280297, 43.75159955793812, 44.19738477276218, 46.152082258655184, 52.6114728373866, 54.78432862989364, 59.33878091073806, 55.09480384088332, 45.868024210776056, 17.50458102072439, 2.275385077922575, 4.218002644277388, 10.207491805476527, 9.031714277882731, 3.461270308302295, 0.2631697413181105, 0.2569288366864766, 23.679382070418328, 51.791603334488414, 37.98249121635191, 39.04187633145241, 44.028766001424486, 50.93762490057176, 21.90740231544741, 0.9163583382483452, 0.18039420156949953, 0.018575015973540086, 0.030657291232097535, 0.020037460584013213, 0.08258227874795276, 0.03092830441141081, 0.08398673241777767, 0.015210289819796961, 0.07277436148855956, 0.04315708823982747, 0.05047209027613844, 0.06996000726376811, 0.05158029391520447, 0.04671000101934037, 0.1629576573689138, 0.13005042719023843, 0.07859632327792146, 0.20363024586150724, 0.17974679598644858, 0.1303203965747549, 0.21388004263562543, 0.11627566069364549, 0.19408839093821664, 0.0897492304624569, 0.09264029307110656, 0.12542948442240878, 0.1428254336238869, 0.1942945758421575, 0.17235908837568376, 0.12469839139450943, 0.11702208314090969, 0.16490535930760447, 0.43312506029202097, 15.983689831149196, 55.94242803512081, 49.3712067604065, 39.637680438257036, 35.9460711479187, 46.97655662413567, 57.42056146744759, 62.34278694275887, 47.22969462794643, 5.607075229767831, 1.0244150399681062, 8.017114295113473, 8.901683784300282, 4.847036090589339, 3.7424414917345974, 23.461153161141183, 51.04559206193494, 53.94013258718676, 54.515297182144664, 55.23910783952283, 53.93488053352603, 50.7996908310921, 50.77754120672903, 50.13033836118637, 50.37660437245523, 51.04819651572935, 55.59625141082272, 54.6073159863872, 53.06655406951905, 53.579215695781095, 52.98694956687189, 51.818824583484286, 48.69126781340569, 51.59237046395579, 49.8863120232859, 51.49962994360155, 53.92219558838875, 54.86540794372559, 56.70104188303794, 52.965906050897416, 54.85656692135719, 44.229963979413434, 40.16966365998791, 43.24790839226016, 41.353176101561516, 42.880209722826564, 39.229989282546505, 40.045049959613436, 41.145278715318256, 40.5936404966539, 39.769825089362364, 40.30072181455551, 44.703939268665934, 42.9805870979063, 40.94920335277435, 41.34452335296139, 39.57188267861643, 39.95825575244042, 42.36308051693825, 45.17187018548289, 48.07403187597952, 47.0740863584703, 42.75194037345148, 44.74723831299813, 44.5992394416563, 50.03659763643819, 52.12542449274371, 57.14641524899391, 51.38488100421045, 50.4229393313008, 52.415624972312685, 51.787072996939386, 58.40679437883439, 52.60316917973181, 51.320711028191354, 51.30357811527868, 52.000940230584916, 51.473228469971694, 50.49095715245893, 54.54478163872996, 52.188531506446104, 56.82405525638212, 54.65611811607115, 44.937222234664425, 41.06760009642571, 37.89019392382714, 39.52246473681542, 40.111334093155406, 39.779450585765225, 41.45346326212729, 42.66798596228323, 42.08492563616845, 41.57150307009297, 39.954949194385165, 42.00314421807566, 39.990532936588416, 43.21508599865822, 42.41216113490444, 39.47335666225803, 44.714847380115145, 49.76459303209859, 50.651884155888716, 54.28728980402793, 51.78669252703267, 53.3838620493489, 51.87436926749445, 56.823612028552645, 53.505741857713275, 52.63233592433315, 53.79959406391267, 55.700300124383745, 53.43855950140184, 51.78916362024123, 44.165080132022986, 40.393858494297156, 40.95471428286645, 40.2897431004432, 42.362390179787916, 44.99006832799604, 44.61947494937528, 45.144272388950476, 50.48485002210064, 56.96138528085525, 58.60110467480075, 62.82160635917418, 55.22242207680979, 47.693750243033136, 19.07809276734629, 3.153717508239131, 5.541891321059197, 16.58446554214724, 15.496773662105685, 10.314243032086281, 1.8410778213893215, 0.365969363840357, 28.71809997866231, 56.02533125108289, 42.455079709329915, 47.943024712224165, 51.922461448177216, 59.58254052746681, 28.846812555866858, 1.2794039734909612, 0.40997605890996996, 0.09920067168892392, 0.1287742166389381, 0.08265316486358643, 0.19819379483740177, 0.11832866141752851, 0.1696816110803235, 0.14199902393644856, 0.35126038376362095, 0.14946712481398738, 0.10562179084386557, 0.21982396562253276, 0.1699838940534861, 0.14692719094455242], [0.030703222033597773, 0.026834686774940743, 0.030327904068173903, 0.031810257388579274, 0.0920021188475432, 0.041887967832266323, 0.05082283597139101, 0.02819390869849632, 0.004748630472609113, 0.05343773920509604, 0.03481337950835305, 0.07899954599598724, 0.027635162470922358, 0.08098562893968436, 0.04246567856640585, 0.13321381873421131, 0.047609024350681615, 0.06965380958131245, 0.07345712202931605, 5.1821227035214825, 29.745735468402987, 44.282837529336255, 32.31674713473166, 31.20163102303782, 43.27574153100291, 47.24033601822392, 46.20060590005691, 53.39977902750815, 10.190502059075142, 0.14274093412583874, 1.6690915726846265, 3.674585713494209, 1.17710561761933, 0.7845032070913623, 19.9511045025241, 44.71021898331181, 53.856707695991766, 53.93610823538996, 46.32868305329354, 51.09078953343054, 52.91568010084091, 49.12301094301286, 47.786741795078406, 49.04476358044533, 53.60114958978469, 51.14267072369976, 51.24966905963037, 47.81808937749555, 46.617773502103745, 44.9403287518409, 44.36717241041122, 43.3440339180731, 43.61623464092132, 45.890883784140314, 45.23356906829342, 46.30760815835769, 49.24336102701003, 49.27918011142362, 49.080959212395456, 42.63604610197006, 38.08180955148513, 37.55343491031278, 37.69820174863262, 36.75447556280321, 37.669827322806086, 36.2414962245572, 37.384063043902, 37.500659419644265, 39.19076165845318, 38.00500169877083, 37.36693405335949, 40.20353724879604, 38.012238471738755, 37.085445157943234, 37.015426927997225, 38.257872981409875, 37.14373157870385, 39.049336679520145, 45.68547710295647, 48.179712295532234, 47.777155522377264, 44.23738118140928, 42.89528339139877, 42.08413331739364, 42.30950094038441, 46.69504419449837, 49.510137111909934, 50.969855016277684, 44.303324068746264, 37.775727395088445, 48.733735315261356, 55.73658597084784, 50.46885851890811, 49.19687309572774, 44.81513454068092, 45.891644723953746, 48.63553093325708, 53.55312016702468, 50.463602542877204, 43.920787072950795, 50.33765915901431, 52.94760819404356, 42.24147135211576, 35.713545199363466, 36.499984341283, 36.82024194348243, 37.7039990117473, 36.77479736266598, 38.28061488366897, 38.0382594754619, 36.324803444647024, 38.05235255149103, 38.19624862363262, 38.76329391233383, 36.93362589805357, 36.48383594328357, 36.88344309406896, 36.86319974160964, 37.362897934452185, 38.340093704961966, 40.935871216558645, 43.021458195101836, 46.01961597319573, 44.3755349036186, 49.371183226185465, 47.28751036428636, 48.35860375435122, 49.487799213778594, 49.85110482861919, 52.88903544026037, 49.89683182008805, 49.420977715523016, 46.48092592916181, 42.0164998885124, 39.41268151806247, 41.5903579035113, 41.93491066655805, 41.23261028720487, 41.74328719415973, 42.931730055039935, 49.17748481996598, 51.104913988421046, 51.8505173344766, 56.304564783650065, 53.21633761928928, 42.824123751732614, 11.609114504629567, 0.7645021835642477, 3.8483726978302006, 12.102806568145754, 6.11507757056144, 1.8620821136620738, 0.30612628306111983, 0.7007265283215431, 23.094727300828506, 40.73754049116566, 32.53385228495444, 23.89169800666071, 32.20100779687205, 49.35744708584201, 13.4023731177853, 0.13818150055744957, 0.07505914211393365, 0.05543157878902651, 0.02736908672828107, 0.013951481913306541, 0.045750157967690504, 0.06408601278258909, 0.022051635971893708, 0.007085562533428593, 0.005908100236763037, 0.0035504318516506187, 0.03189691916979369, 0.05229451385657153, 0.07891960472108857, 0.07290406783501949, 0.00404875026076972, 0.004385269703268404, 0.0511401878940242, 0.02557391672575426, 0.08579139808012594, 0.03721864661201835, 0.032813054990143545, 0.02864066053241972, 0.016864035203452074, 0.04053029915197723, 0.01126574235968292, 0.08331012356305316, 0.01572191302153853, 0.11297199078985762, 0.022938099291716373, 0.02082744662109162, 0.04279912982676779, 0.04274418983127802, 0.05672067493921327, 8.331599639308068, 36.99231240057176, 49.903480237530125, 38.53432555352488, 35.59187327661822, 43.142604520243985, 52.69558022099157, 53.144260145002804, 55.05667840280841, 10.246782187492618, 0.29700585310497596, 2.7717450886003436, 9.496558289374075, 3.709036135865796, 1.3003799511540322, 21.812312295359952, 46.96319703132876, 54.83077733747421, 53.23526697774088, 49.14008894274312, 52.06850305680306, 53.48657323468117, 50.08490946985061, 48.718085058273815, 48.77159795453472, 53.507416709776855, 53.04572628390405, 52.940696977799945, 50.49001970598775, 48.30647545476114, 47.84697763381466, 48.17408761670513, 47.148599624633796, 47.402726065727975, 47.48910842403289, 46.827537936549035, 48.95450199803999, 50.22935075144614, 52.224111326279186, 51.00263034143756, 45.41634759595318, 40.48698732929845, 39.72499632066296, 38.88694663201609, 38.75460978477232, 37.541577585281864, 38.95840829418552, 40.59753933260518, 38.83284538022934, 40.197822355454974, 40.61484482980544, 40.223423665569676, 41.66755014850248, 39.61337743266937, 39.269616988397416, 38.704752537512014, 39.775065375912575, 38.82207847410633, 41.134048969514915, 47.57015635890346, 50.649213021801366, 50.55296590251308, 46.739661155208466, 44.325501149700536, 43.529275694201075, 44.08999812218451, 47.89917653606784, 52.31356490042902, 52.44686665073518, 45.27018439385199, 41.89018780185331, 51.05579022438296, 55.08268763942104, 53.3380409209959, 49.8878142910619, 47.10202932357789, 49.72542424355784, 50.059990652145885, 54.50438514832528, 52.34891722279211, 48.24902057647706, 52.089495581965295, 53.80120223568332, 44.362191000292384, 36.60870459771926, 37.800685436494895, 38.08747345401395, 39.06936430161999, 39.36499334150745, 40.32872753758585, 40.77370474415441, 37.39806982778734, 39.62863937500985, 39.37397949157223, 40.194896267306426, 39.4118421308456, 39.29128416122929, 38.88067476211056, 39.36273797865837, 39.12461480786724, 40.01563218332107, 42.84414745146229, 45.81724520652525, 47.668262681653424, 46.83328420885148, 51.8353142276887, 48.83365377303093, 51.73505060134396, 52.219337801779474, 49.363377709542554, 53.862948186935924, 53.69373321533204, 50.87934240218132, 49.20652604872181, 41.924245742059526, 40.87107366131198, 43.42989852351528, 42.818455926833614, 42.133927806731194, 44.159361316311745, 43.787842258330315, 50.9026530481154, 52.46843968668292, 54.61854965456071, 57.52684200963667, 53.641236212945756, 44.129178677835775, 13.77108277813081, 1.0894440763419675, 5.970191099951345, 7.801810983688601, 9.41953274511522, 4.644610410736454, 0.19414753292597112, 0.3765299471635973, 27.3515893566993, 47.353610146430235, 36.83865354907128, 31.494692871647498, 40.20189377569383, 55.300143841774236, 19.506546989563976, 0.06362160645245064, 0.0934466235940495, 0.02275579717881497, 0.08656646455487899, 0.057825821887461416, 0.04377950020434876, 0.005181512284663416, 0.02712324528293985, 0.06279759462021532, 0.03672613251593806, 0.03157832618472317, 0.07329756123644691, 0.02349277950763222, 0.028042974055654583, 0.06273427362283392, 0.08256953104489273, 0.07643005645443356, 0.12337466040926597, 0.15120585328869282, 0.31000259602742813, 0.16951475713041522, 0.20805602773062645, 0.12690159897770614, 0.09275347490103976, 0.15585059840832988, 0.11074616063025691, 0.15923503696197466, 0.1764666066775399, 0.24102494330896487, 0.08121986032253312, 0.15167508214231462, 0.12392887905720743, 0.19389694556593898, 0.25054285032374246, 9.472320002894248, 43.24675129305932, 61.90747837866507, 43.76969737391318, 44.004721872268185, 55.92108641901324, 58.6778772261835, 57.845393380811146, 65.54959912453928, 12.775264574635415, 0.41791371039805875, 7.434779607480572, 13.927908943545434, 5.689700447743939, 1.9000535987077223, 25.39332643631966, 48.94361742081181, 58.19333507168678, 55.46452645332583, 49.303867509288175, 53.71366277817757, 53.69192892505277, 49.32064740888534, 49.033161209475615, 49.24242750290902, 54.45980741131691, 55.31239732619255, 55.44644040446128, 51.75176774301837, 50.893674742790964, 49.799219715979795, 49.616715754232104, 48.618625517814394, 48.658257146035474, 50.229805746386134, 48.8275937111147, 50.821683560648275, 53.12728020452684, 54.836456929483724, 54.59381911062426, 45.4637651289663, 42.25699609325778, 42.28534698486328, 41.7138498060165, 40.843197376497336, 41.60378025424096, 40.29531678845806, 43.772168467121745, 43.06398845488026, 43.253529148717085, 41.08180299881966, 43.4750214699776, 44.86729029686221, 41.81288180812713, 39.8915401581795, 40.765612894488925, 41.581822826016335, 40.35012014450566, 43.09090375900269, 49.466281091013265, 53.6151602960402, 53.78752493089246, 50.97167499603764, 47.1674426909416, 47.18999631943242, 46.09299175200924, 49.00799528245003, 54.68094671926191, 53.31843691487467, 51.85871901050691, 47.7201791732542, 51.77226212716872, 57.925609773205174, 53.369415960004254, 53.658102404686716, 47.75695923836001, 49.74750718762798, 52.44962799933649, 57.76384338255852, 54.06368332524454, 48.36998647259128, 53.76982719667497, 58.39128140480288, 46.04280894802463, 40.313975503367764, 40.84670005306121, 40.368135590707105, 40.8297005007344, 40.65273884804019, 41.74023166779549, 43.239604734605365, 38.92975145770658, 42.098320530306914, 42.751148054676676, 41.92164913300545, 40.95868764385101, 40.696618403157885, 41.351767970669655, 40.044555740971724, 41.28622124272008, 42.21968650817871, 44.43649245846657, 45.65003456607942, 50.16501211350965, 49.421350340689386, 53.25733030996015, 50.26598961122575, 52.57853277267949, 54.73611877810571, 51.55102083759924, 55.845651395859264, 54.01022141979587, 54.132277734818004, 51.08431762264621, 45.38126983950215, 43.22293466137302, 44.96967592547017, 46.260371054372484, 44.264743635731364, 45.86856942023001, 46.56861051436394, 54.26035881042481, 55.51141838873587, 56.58775206535094, 59.14516487429219, 54.85033035278321, 43.998230349633005, 15.387583701841294, 1.3615213671038229, 9.065449603142278, 22.819529887168642, 18.113491727459817, 11.60683168518928, 0.6104096037245567, 0.6503127947930367, 27.959307662902344, 51.34328819090321, 43.305641758826475, 35.74193531467069, 44.79153756172427, 62.73773824014972, 23.548384712588405, 0.23363456971222357, 0.31610914415890173, 0.14790478042296826, 0.15672787633394042, 0.11588467239973047, 0.13515419687234587, 0.18025322606967342, 0.0646308621752166, 0.1393960869961208, 0.1377905199244138, 0.07374425944421562, 0.21219127841534155, 0.18245373702337667, 0.13024663762940517, 0.20080727314756763], [0.015725868908057532, 0.023808934417883718, 0.02915300864485964, 0.0032988289463138512, 0.026271895603126576, 0.06755344164107116, 0.07322684366015658, 0.0749110879616872, 0.032920472008446534, 0.04692299261448845, 0.040298944429284146, 0.028174854176599654, 0.1024598855104658, 0.03695004086400713, 0.019673915474765727, 0.024231717275876193, 0.01444241978348263, 0.02467578014118537, 0.029435704665018186, 2.4597073033932717, 25.32722077062053, 42.72002796972952, 35.49776777144402, 26.160155688562703, 22.862870116387647, 33.29514511169926, 47.26553332421088, 55.0901597545993, 12.971327189476261, 0.13276386465276444, 1.3168567250813208, 3.9883209043933503, 2.102903997705829, 1.288873678253543, 16.013556718826294, 40.836125343076645, 50.76532302364227, 52.602729874272505, 50.546164512634284, 47.986437505291356, 51.0316127346408, 49.23941120024651, 50.168636383548865, 52.16769979846094, 53.32852525095786, 51.93407558625745, 47.509304708050145, 45.66083677353398, 44.46989536285401, 43.32182153578728, 44.13953765746086, 42.458700056998964, 44.012547000761955, 43.14081199707524, 43.36095894536665, 44.1704184778275, 46.29097338645689, 43.58322397355111, 42.10337646545903, 36.29094554531959, 36.59608241050474, 37.23081604126961, 38.86192191031672, 37.37417867106777, 36.900509326688706, 34.83189052151096, 37.79042059375394, 35.45123669408983, 44.02857772765621, 38.20995338501469, 37.421427542163485, 40.16297209647394, 38.686317397702126, 36.32716471149076, 37.65122352107879, 37.69212207486553, 36.97318692361155, 40.7355087034164, 50.17251953001946, 51.82669678042012, 52.23074405424057, 51.372447090764204, 43.329654509021395, 42.928007725746404, 42.95513483785814, 46.05900441446612, 48.897345219889, 53.411679498610965, 42.59827759958083, 36.08580950767764, 48.36433433717298, 52.401378923846835, 51.2909794622852, 50.26327925343668, 48.18296394040508, 48.55006640957248, 50.0666194577371, 51.00348541813513, 51.61126059870566, 45.65538075662429, 49.50354753002044, 54.963353449298495, 43.97194262473814, 36.342187389250725, 35.99192757760325, 35.73247455781506, 38.45325800680345, 36.00117652646957, 37.95758024338753, 40.23357475957563, 37.157251988687825, 36.87826164307133, 36.373887984983384, 36.97603848672683, 35.741268511741396, 37.240241496793686, 38.69686465109549, 36.894661072761785, 35.32121404524773, 35.99504978426042, 35.71427476021552, 36.85359777942781, 38.463240438892, 40.438130286432084, 44.543914410375784, 46.844796365307225, 48.54224128107871, 52.42522301212434, 48.955788535456506, 50.404233547949026, 51.00867079150293, 48.78230210273497, 46.3305736357166, 50.920966594449936, 48.79832106251871, 45.38219551886282, 45.513300741872484, 47.45589379341372, 45.95924677387361, 50.06893365613876, 50.32346017899052, 53.39538205054499, 55.45451656464608, 55.87730884552003, 47.07099553077452, 36.64887359065395, 5.827894864543792, 3.3542663339645635, 9.411532090556237, 4.743914036981521, 8.284076202300287, 1.8935788687198394, 0.4183111568131755, 0.7909800821254331, 23.99191064219321, 30.96202127395138, 33.83213327777001, 24.575300447402466, 40.11899840447211, 44.989350534254505, 6.173799864707455, 0.05938123318276579, 0.014028464173597675, 0.11945330913388923, 0.03900671497948709, 0.019521879580532833, 0.024554598438102874, 0.006341261670909703, 0.06692093646814747, 0.031793836293922316, 0.027718623919833093, 0.04332873406970213, 0.08643967700341056, 0.040138177047934265, 0.06851228494797984, 0.04111894579123586, 0.007211143975221222, 0.011167305807072309, 0.031516838052700606, 0.02683366404756183, 0.04639358755441443, 0.029033060343335235, 0.06033115539579623, 0.054515337631587064, 0.01900848001241684, 0.04089366614578232, 0.011223815325196954, 0.048811058438713514, 0.06683010142296553, 0.03394945449526272, 0.003987352622883214, 0.008175145447885078, 0.07495313086697171, 0.048992552328854806, 0.035076645623532035, 4.323469784951979, 30.894903636747795, 51.70183204835462, 37.47347739435012, 27.255593269102036, 31.1298006580722, 45.866263066568685, 50.09597447610671, 63.50882914758498, 14.713265511297411, 0.10140204066110235, 1.9269788313296534, 6.230232965561652, 1.975891277674706, 1.3663115616767638, 18.526195672250566, 43.38405778331142, 52.27612587713426, 52.756031790087306, 51.83425911011235, 49.631687441179835, 52.27646712333926, 49.22450227122153, 49.92429625603461, 51.844449427820024, 54.45465341691048, 52.500434460178504, 50.16932672069919, 48.95106600176904, 46.79296224348007, 45.765065916122936, 45.83258559626918, 45.24699141902309, 45.83589215432444, 45.22354349013298, 45.156486649667066, 46.98590755462647, 47.95470945296749, 47.59864453346499, 46.63689897906396, 38.95221094931326, 39.29574389611521, 39.300266388923895, 40.139222145080566, 38.77026004175986, 37.66739545329925, 36.94587546010172, 40.398549649023245, 37.49255580286826, 44.73911900674143, 41.39551024283133, 40.880322610178304, 42.1410116072624, 39.65958687566942, 39.49845590899068, 39.35704269716817, 38.95345041828771, 36.76521501233501, 41.88455527828586, 52.60378891421903, 52.34230018431141, 53.53461834692187, 50.97679368911251, 45.57123022694742, 44.808144877033854, 43.688355261279696, 48.046924375718646, 51.762275772710005, 54.45537513302219, 44.479697365914625, 38.243003276086625, 50.678968121928555, 54.664586513273186, 52.93771597646898, 51.43577767956642, 48.6241795939784, 49.18584731317336, 53.06445167910669, 53.813667528090946, 53.312859304489635, 48.320325343839585, 51.39176084149269, 55.221488552708784, 44.53492041557066, 38.376465843569854, 37.428326991296586, 38.49993813422419, 38.566081062439956, 37.19468316724224, 39.43001054948376, 41.947760351242565, 39.62277150923206, 37.413335692497995, 39.05957798804007, 39.840549345939394, 37.53958109886416, 39.38386778677664, 39.08659919615715, 38.23027518487746, 37.08220920255108, 38.216582190605905, 37.51622730685819, 39.61101224345546, 40.897651641599595, 42.588059825281945, 46.496540884817804, 50.41966807457709, 50.29938074850267, 53.41780624082012, 49.54940788207516, 51.84936808001611, 53.48060730964907, 50.40839910507203, 49.51458900205551, 51.435895350671586, 49.80462866444742, 48.15296957569738, 47.35256287359422, 48.37670157032628, 47.65971583704795, 51.770783393613755, 51.776094282827074, 54.9003170382592, 56.60523799157912, 56.96205208378454, 49.514416417767926, 38.42256153783491, 7.29070310631106, 5.831211718820757, 15.676833987236025, 8.453039161620602, 8.097948951105918, 3.079241014296009, 0.23265325704649573, 0.7843327065629344, 26.316385653711137, 36.598573115564164, 38.367193360482496, 28.127726393361247, 42.589393431140536, 51.75899274887578, 9.658511973196461, 0.10752319042841274, 0.02037723398497028, 0.03155817615709478, 0.06774036709459559, 0.016058701552420614, 0.0146630339534773, 0.03687799412516817, 0.04767837446002711, 0.0436216899223866, 0.03171730219506689, 0.06093998462142003, 0.006584355254627525, 0.06574745830749312, 0.030761057841441328, 0.005164162308398274, 0.19715562312593385, 0.1157036841276192, 0.1157582525704657, 0.15071911166512197, 0.1607967991261713, 0.15470411718612717, 0.13606233281954644, 0.21025105349479184, 0.1455855564845185, 0.16466516009982557, 0.10265970422375588, 0.1397628745725078, 0.21982675418257716, 0.13118550902412784, 0.16958932812896468, 0.08269747538912682, 0.18271596891985786, 0.16195892386378782, 0.20844293277590506, 4.984189608404714, 37.9284684119686, 57.065469295747825, 48.322710144904356, 37.18895650679065, 36.0945563931619, 45.27132580357213, 56.280159796437914, 65.41825463694911, 16.516779161268666, 0.2738722041249275, 4.0041594351491625, 11.445832117911309, 6.549501149885117, 2.4942317605018616, 20.566696966848067, 45.34900442246468, 53.44588256651356, 53.31208659756569, 54.03690138170796, 52.251465935860914, 53.350317939635254, 50.48302219760034, 51.54510198100921, 54.38868699535247, 57.087611075370546, 56.38438893902687, 50.88597905251288, 49.69888156460178, 48.9077865692877, 47.33756765242546, 48.327365998298895, 47.089913122115604, 48.7978543004682, 47.43569750939646, 47.02997146114227, 48.9927411848499, 50.87901292308685, 48.09910366612096, 48.666725543237504, 39.475302157863496, 40.764647991426536, 40.674888472403254, 43.529973876091745, 40.4592953958819, 40.55343228001749, 38.54592400212442, 42.16313377503426, 39.375803393702355, 46.23991981629403, 41.8383615247665, 42.17149626824164, 44.88692568194482, 43.119784170581454, 41.28004743206886, 40.552926294265255, 41.62418834624752, 39.484374600072066, 44.543631999723374, 55.291785270937034, 54.79218121497862, 56.24368959857572, 54.67213707585489, 47.985029374399495, 47.59148228553034, 46.46396560053672, 49.883280031142704, 53.20752013114191, 56.583610042448974, 47.546190677150605, 42.775184339092625, 50.75778030580091, 56.02788471406507, 54.731462924711174, 54.35118521413496, 51.91921372567454, 51.1499898664413, 52.81405541204637, 54.944471159288966, 55.0958275794983, 48.19822588274556, 53.14089867376512, 58.71853651538972, 47.127618866582075, 39.88591155698223, 39.24394899798978, 40.05168268757482, 40.86741016757104, 39.594181353046054, 41.983775554164765, 44.19330550778297, 41.43292965427522, 40.95199215796686, 41.20937808867424, 41.69919190868255, 38.40868419216525, 41.38297827013078, 42.112084127241566, 41.62550626262542, 37.64023696222613, 40.152267948273696, 38.89203002375942, 39.87885521304223, 42.4835600391511, 44.642734604497115, 49.997417080786924, 50.91029774758124, 52.009569444964015, 55.68003323770339, 50.95106686315229, 53.04858569175967, 53.55135117807696, 53.18757095644551, 52.81243939553538, 53.6992206112031, 53.01139770015594, 50.54417587095692, 50.31043006527809, 51.932553706630586, 49.71763049402545, 57.43493695412913, 54.33843751107493, 58.81456005957819, 58.88471949485041, 57.74008166405463, 50.39725957378265, 41.820130348205566, 9.489566664541922, 12.136252618605091, 24.870239150139597, 11.11339653691938, 21.86624880759947, 5.79038719977102, 0.8875471197309033, 1.1093146810608527, 31.369739886253114, 41.796325483629786, 47.23559779505576, 37.12344508017264, 53.487930374760786, 59.492412305647335, 13.252795492449115, 0.24252238473103893, 0.2053542654480665, 0.35080161967104484, 0.1493038714773232, 0.15296091475794393, 0.12647552385685906, 0.13214546315852674, 0.1782209327023837, 0.219463843011087, 0.12166413929193251, 0.17772973244709356, 0.15869546591514544, 0.15036810549997515, 0.1228558809887017, 0.17106944064219154], [0.07130520403264992, 0.10488207932681808, 0.05470884761082069, 0.02681834420429603, 0.05051808236467262, 0.06175734298003297, 0.035069620597266385, 0.022150631768689043, 0.056749035514170126, 0.051731048527384, 0.056218649861553026, 0.02683273899639326, 0.03596472921931455, 0.03586347920880203, 0.017283929909970012, 0.046024214431282975, 0.03624381121969031, 0.05581517433447223, 0.01362576048010059, 1.1489559926332966, 16.052117539990334, 41.9044142384683, 48.52218620238766, 44.51197062769244, 44.42100694102626, 36.42748717338809, 27.828369140625004, 42.04817695002402, 18.97052764892578, 0.050554915872072025, 1.7140681657098955, 11.058431383102171, 5.2506322918399695, 3.1480695403391317, 15.983696695296997, 37.39832870421871, 49.74314551199637, 48.62064946082331, 51.42078245839765, 48.003409601026966, 47.26829859518236, 47.840195855786725, 51.96589777546545, 51.67655237259404, 51.162408090406856, 47.070375796287294, 47.0385810636705, 42.345312180057654, 42.71193612006403, 42.16007040392968, 42.26500165077948, 41.2046516326166, 41.353034896235314, 40.7173442071484, 42.93260082121819, 41.011035596170736, 39.99831884138046, 37.838681436354115, 37.13283523436516, 37.02055738818261, 38.106045876779866, 39.44972438196982, 37.696585732121626, 38.11170585693852, 37.133647164990826, 36.52445208641791, 36.48960182743688, 37.74040645168674, 41.01190636234899, 38.206882169169766, 38.83902703562091, 37.805411892552534, 37.872162788145005, 39.54469673095211, 39.012340884054865, 38.87639545625256, 37.00493458778628, 43.428137379307906, 51.38454368037563, 50.64790295016382, 54.20838348327145, 49.32930015748548, 49.706067346757465, 45.095054488028254, 44.23447862748177, 43.12601289441509, 46.78099116971416, 50.74483648423226, 49.61569986035747, 41.94191209731564, 46.128140111123365, 53.366807583839666, 50.68562830648115, 51.59300981029388, 50.05281663710072, 49.94037405137093, 50.84003240831437, 53.871502876281745, 50.40845794062461, 46.14068385093443, 48.1194725344258, 52.359805722390455, 45.47809354720577, 36.36018322360131, 35.94584365044871, 37.300963709431315, 36.91277065584737, 36.56087913820821, 37.48935122643748, 39.602665439728774, 36.845243130960775, 37.75424457365467, 38.04961865948093, 39.506555603396514, 37.67554221614715, 36.435265233439786, 36.1339448344323, 36.76762726999099, 35.73967995182161, 36.10446822258734, 34.51162115220101, 36.529488409719164, 37.03345021893902, 37.18827793675084, 41.24049032888105, 43.59134720217797, 49.3991183465527, 49.11013380173714, 49.87583929492582, 48.38021993637086, 49.64601193704913, 49.433101761725645, 52.05293516958914, 50.71948620580858, 47.703375739436, 49.97611861075125, 51.24833937614195, 50.244777433333866, 48.10644634308354, 51.672492719465694, 53.34724280142015, 53.97782264217254, 53.732121452208496, 51.91104342860561, 47.066378901081706, 25.902479502462572, 3.787682599598362, 6.268918321978662, 4.218068343977775, 7.138392569557314, 10.128888487815857, 2.5141647554213002, 0.21336078824054813, 0.8510647257489543, 32.036736972870365, 37.023663905359086, 32.78660197411814, 31.174676495213664, 44.319684274734996, 36.06951598198184, 4.089491333692305, 0.02722084296927337, 0.04805549273207303, 0.03366322489455342, 0.061267605952678196, 0.04350168224904807, 0.052145092237380244, 0.030468984905089584, 0.018435988252261476, 0.03359321978003268, 0.04042122738375779, 0.049074669293458426, 0.038119830311306065, 0.02870126191766993, 0.0399446057816667, 0.048462538228880976, 0.08664635986450218, 0.05093733164211435, 0.03664718332490133, 0.03656795451177224, 0.07067747924837374, 0.01777633292330129, 0.07467310274800948, 0.022816479003297228, 0.02922823081814474, 0.04172734983806168, 0.016132457624940623, 0.08886943210757549, 0.01651047413507777, 0.02238847525610078, 0.00819840866531576, 0.0211151241279778, 0.019175950663104173, 0.03916165626217281, 0.045284514405554345, 1.88292044064691, 22.913894268774218, 49.9403505171499, 52.16911577409314, 42.135100595412716, 36.95069997541366, 39.192260003859, 38.959855648779104, 51.27798464990432, 19.408883894643477, 0.05630162101419223, 1.3148532519417426, 7.726240148467403, 7.617275234191649, 2.605797451349997, 19.132862783247425, 37.87777962223176, 52.53278616935977, 49.23333544884959, 52.22626862987396, 49.041864948887984, 50.36120906952889, 49.0939030339641, 52.16509142229634, 53.065228308400805, 53.361531995957904, 51.16536947988695, 48.975294482323434, 45.554642523488695, 45.15780064367479, 43.61459901255947, 43.52403540765086, 44.211065999923214, 43.81406330293225, 43.26357041635821, 43.77295686352638, 42.57160156003891, 42.53110701037992, 40.83792178861557, 38.5840259059783, 38.920224020558024, 39.815893327036214, 39.95225060370661, 39.73394324702602, 40.461876315455285, 38.37583434197211, 38.889205917235344, 38.72254833098381, 39.27674393500052, 42.03655888957363, 40.49172947483678, 40.13477417730516, 39.956376937127885, 40.238540480213786, 39.63752354345014, 40.07187112685173, 39.05055653664374, 38.43448946552892, 44.94057586116176, 53.05154708123977, 52.83365549579744, 56.12339835013113, 51.934475668015025, 51.915565921414284, 46.43184531119562, 45.64561405489522, 44.858990561577585, 49.769499917184156, 53.47612796291229, 49.71452789921915, 44.725025930712306, 47.784462898008286, 56.24754921082528, 53.24905803126674, 51.56492171748992, 51.95719795842325, 51.206468074552475, 52.535500449519006, 53.46334103615054, 53.234631553772964, 47.70808258364278, 52.77876192523588, 53.98659698424801, 48.09954297158026, 37.25433457282282, 38.80975046465474, 38.61859375430692, 38.92665278527045, 37.95631331782187, 39.60975708500032, 41.519480674497544, 38.01648639863537, 39.53334146930326, 40.2312409493231, 39.82474219414496, 38.32619674744145, 38.468190470049464, 38.98701413985222, 37.73267938244728, 37.00140837700137, 37.905679441267445, 37.64270413306452, 38.113302261598655, 40.32972774197979, 39.138441162724654, 42.24913958580264, 47.16465780811925, 50.12027748169438, 50.61928925975677, 51.40570878982545, 49.410548133234826, 48.91705905237506, 51.52872216316962, 54.380422561399406, 53.326128682782574, 49.3287157243298, 52.23739247168265, 51.86198634486045, 54.080682877571356, 50.82278182429653, 54.128304373833444, 54.410895455268125, 56.766827875568026, 55.132576265642726, 53.343010564004224, 47.771679893616714, 30.624707245057632, 5.535004129332881, 11.42401687560543, 6.656768168172529, 10.994612459213505, 10.778417298870703, 3.8521190516410337, 0.18026819542771388, 0.9295739678125229, 33.47317757145051, 39.6507772322624, 35.22429620065997, 34.06722053404778, 50.059959273184504, 45.221754889334406, 6.225508470689097, 0.009908782310723778, 0.06148966802884975, 0.03523190866314596, 0.06516605885999818, 0.0832549728933842, 0.036775491560899445, 0.02892406709912804, 0.024460289184184327, 0.06302691154902981, 0.03500117064123193, 0.012854463157935009, 0.006622517445770603, 0.06865301529967016, 0.05127111232028373, 0.07959483461754938, 0.21255437344793351, 0.2023987442014679, 0.12073495124857272, 0.10516125708818437, 0.18526766989980975, 0.16588829607973177, 0.14462180255401522, 0.09327498159461445, 0.11413479734572674, 0.28665300218328355, 0.28618899804930537, 0.3093379075008054, 0.15580066479742527, 0.07589698183320223, 0.12759406585246325, 0.21301848483422112, 0.2079641891102637, 0.11741012965719547, 0.17224212207140463, 2.3008412603409063, 26.829017862196896, 59.21291989664878, 60.32491184050038, 54.22387292308193, 53.190449976151996, 48.08375150926652, 38.84581665838919, 52.80075465479205, 25.212738552401145, 0.15650716640295523, 4.0610624849796295, 21.80821930208514, 11.47938701414293, 4.226400438816317, 22.665465070355324, 41.72372633411039, 51.65499502612699, 49.98089605762113, 53.00269396074357, 49.00929358697707, 50.92467715663295, 49.278156372808645, 52.491016849394775, 53.539297734537435, 56.11407879860171, 52.61662290942285, 51.695705306145456, 47.14645016577936, 47.091305563526774, 45.222366779081284, 46.95192021708335, 46.427722900144516, 45.48946842070549, 45.6263905186807, 47.231416548452074, 45.504797043338904, 42.75199136426372, 42.28930465636715, 39.99906016934303, 40.405625604814105, 42.2776512945852, 42.016256701561716, 41.614555005104314, 44.351765340374364, 41.61069539285476, 42.819805222172896, 39.94303695617184, 42.01600959224086, 44.92786738180345, 41.25735259825184, 43.61037069751371, 41.008968507089925, 42.80247226838143, 42.34157023891326, 41.561512793264086, 41.739655079380164, 41.39556123364357, 48.05587914682204, 55.40111349475, 53.411075453604425, 57.484111708979455, 53.3188566084831, 53.341225885575824, 47.69185966061008, 47.06662601040256, 46.400944878978116, 50.82622174293765, 54.649756031651656, 52.64436975602181, 47.21198904898859, 49.15982238708004, 56.45174387962588, 54.861073724685184, 53.792631856856815, 56.33892866872973, 53.670312743033136, 52.904862203905665, 55.46835468661401, 53.50330606583626, 47.435921084496286, 56.32198402958532, 56.246733357829434, 49.29535596601425, 40.301757320281, 40.111306636564194, 40.88459014892578, 41.241074762036725, 40.55275370997768, 41.26662508133919, 42.955997759296054, 38.89324203614266, 42.12012890846499, 43.265798322616085, 43.83467535818777, 39.59289089325936, 39.41280703390799, 40.788276349344564, 39.425527280376805, 39.092765162068034, 39.66118328032955, 39.79487726765294, 39.92124034512428, 41.355454998631636, 40.8946471060476, 44.437782918253255, 48.33526565182594, 53.17113622542351, 52.54850702901041, 53.24745770423643, 49.6470513651448, 49.765561857531154, 52.01620609529557, 57.494145131880245, 55.585680623208326, 51.1574149131775, 53.378186379709554, 55.43522242576846, 56.44629178508636, 52.77656932030955, 57.50279003574003, 56.422443774438676, 58.15380934746035, 55.55053618646438, 54.471331334883175, 50.24971177501064, 33.82123693343132, 8.938074554166487, 13.731614908864422, 12.14123304813139, 15.139142736311882, 18.641601608645534, 9.703603540697406, 0.8167333840843171, 0.9928324830628211, 40.69390412299864, 47.144434067510794, 44.87074982735419, 44.19094424093924, 56.78687118714856, 52.19805502122449, 7.6112950905676815, 0.1811906265755815, 0.21332036944166308, 0.08959235097732275, 0.19450365655845214, 0.19483624596989926, 0.11225389061315406, 0.19153140395158724, 0.14510086797658475, 0.1544905318728378, 0.16322177384168873, 0.15160208928488916, 0.11620167958279772, 0.1416869197160967, 0.2500710320929366, 0.25434453100446736], [0.04291861656031782, 0.05199824084317492, 0.08595455948623919, 0.03630302981623719, 0.07062202980441433, 0.10146658356872298, 0.028178516076877717, 0.01816008168633186, 0.08081712790073887, 0.08643727148732833, 0.020210200004399787, 0.04790928868216373, 0.016045688591416807, 0.019471168390385086, 0.01888379345708076, 0.09602280874406138, 0.010977016269950377, 0.03480832715849242, 0.08119223519198357, 0.1545350109377215, 10.737038254737856, 40.1118871473497, 45.516026789142245, 51.9762332208695, 67.7977212782829, 63.03029606419226, 31.788650981841553, 47.76582771731962, 31.890316855522897, 2.0521129811963728, 1.336418688297272, 5.801848855710799, 28.471902608871464, 10.974080812546516, 19.438790006022302, 37.98374245243688, 51.04814160254694, 52.87564054612191, 52.927808069413715, 52.70318177438552, 47.731479521720644, 48.685698047761, 52.328387537310206, 54.76518354108257, 51.71594865860478, 46.10194652311264, 44.06919387079055, 43.14030993369318, 41.595621724282545, 41.36616306920206, 39.872763772164625, 39.45670227850638, 39.21788484819474, 37.878579785746915, 37.49027298342797, 37.723281383514404, 36.91580264799057, 36.557262712909335, 37.56610024359919, 38.174134300601104, 37.02984556075066, 37.8565360653785, 37.18079405446207, 39.01962080309468, 39.77799930880147, 36.728627143367646, 38.40492263917, 36.43324521280105, 37.67448709857079, 36.51927848016062, 38.49417617244106, 38.81058985187162, 37.81522566272367, 37.82869900426557, 38.143841835760306, 36.68173128558744, 35.331486732729026, 43.561454819094756, 49.697030205880445, 50.91803266156105, 47.97915758625154, 49.29777606841057, 51.11115840173537, 47.712954167396795, 45.01404577685941, 43.84317513435118, 49.07075320520709, 48.8959135547761, 54.04411069808468, 45.988170331524266, 43.59867418965986, 54.252525837190696, 50.96604247247019, 51.54379583174183, 51.029969261538604, 50.88990534505537, 55.62091135209607, 48.037102760807166, 53.288258198768865, 46.35835970601728, 45.63550610696116, 54.333342352221095, 46.592309474945075, 37.84154084420974, 35.3059874042388, 38.97532547673872, 37.03025348724858, 37.6714119603557, 37.01618394544048, 36.892719499526486, 38.778575466525176, 38.79971704175396, 37.312530779069476, 38.19965716331236, 38.08883059409357, 36.45041342704527, 36.404117691901426, 37.1298542330342, 35.660687338921335, 37.417058021791526, 35.55727404932822, 36.22426133002005, 37.79211898003855, 38.05671422712265, 39.278320727809785, 43.01786530402399, 46.319983236251346, 48.293292368611986, 48.706725874254786, 48.92889676555511, 46.834527600196104, 49.01455740774832, 51.22535428693218, 47.877525052716656, 51.15679910106044, 50.8591265063132, 50.407822516656694, 52.449125935954434, 54.13981260791902, 54.35588029123122, 55.02340493663665, 52.558391401844645, 53.33440096147599, 52.0394814398981, 35.37130663471837, 20.021671864294238, 11.402856669118329, 4.846892924078049, 4.3703582882881165, 12.405338979536488, 6.135619513450131, 1.7267811803087112, 0.08044042714661168, 1.8002718110238354, 32.153368649944184, 37.33645331475043, 34.7374241582809, 33.36361400542721, 46.307541478064756, 27.683239483064224, 1.6393190670397975, 0.07386615935472712, 0.019723678631107175, 0.05014490561499711, 0.030995406052698533, 0.02876419029499014, 0.015089738224032185, 0.0304105707008632, 0.052156001329422004, 0.038250291254371405, 0.04035279274948182, 0.01207721524781758, 0.09209221078743858, 0.06421427122287213, 0.0688535081703336, 0.0003330887152368368, 0.04649703623726965, 0.0669933547596297, 0.024684479069565574, 0.016028093467015895, 0.027997414806797623, 0.11401830601596064, 0.04253996228198371, 0.026634854655111992, 0.0920170805447044, 0.05525296921992014, 0.05439635268562744, 0.03394988350450032, 0.05579466616073924, 0.01188479502865624, 0.04043603969377376, 0.036477310988571376, 0.059952979922414794, 0.03527348808523628, 0.07871906588514967, 0.3267125058318338, 13.988904741502578, 48.391673257274014, 51.16334945924821, 56.955168324132124, 63.75254169587166, 57.078377815984915, 32.305423252044186, 50.33384269283664, 33.46822361792288, 1.5525382204401879, 0.30288128783145263, 6.896766722202302, 28.25677433321553, 13.943085574334669, 22.03088637321226, 41.79452511572069, 51.314329331920995, 53.08988824967415, 53.211030652446134, 51.58785973825763, 48.45369769680885, 49.76483621904927, 51.69341071959465, 56.30311742905648, 51.96028878611904, 49.197559510507894, 45.890879861770145, 45.80349337670111, 43.410172923918694, 43.25880081422868, 42.648264285056825, 42.34558674596971, 41.48722702457059, 40.49934671771142, 39.468186978370916, 39.99321583778628, 39.0807548646004, 37.709000033717004, 39.66791406754525, 38.99550607127529, 39.452160173846835, 38.634440129803075, 39.03846386940249, 40.76098842005576, 41.73468543637184, 38.72273268238191, 40.12751779248638, 38.3631415520945, 39.01216829976728, 37.432429790496826, 41.17622229360765, 39.944735342456454, 38.547438037010934, 39.36336555788594, 39.92832806802566, 38.036125706088164, 37.715216990440126, 45.496128605258086, 53.67105799336588, 52.4766609745641, 49.901801463096376, 51.323331171466464, 52.48186203741258, 49.45108190659554, 47.4302375701166, 46.0186981385754, 52.05807739688505, 52.08611842124693, 54.576180211959354, 47.10642630054105, 45.30038664417882, 54.466271477360884, 53.096422918381236, 52.7809113840903, 54.56574670730099, 52.04140340128253, 55.35997175401258, 51.189727398657034, 48.15411883015787, 49.25838762714017, 49.27395943672427, 56.55669473832654, 47.76836941319127, 38.68718031914004, 35.91565708960257, 40.43191725207914, 37.87764626164591, 39.630051428271884, 39.723666637174546, 40.09481699235978, 39.062864934244466, 40.779843253474084, 37.91155515178558, 39.61935904718215, 40.117060753606985, 38.71197754336942, 38.281819051311864, 38.16980792630104, 37.417501249621, 38.350970437449796, 39.704356808816236, 38.08478663044591, 38.38120014436784, 39.440145954009026, 41.29541527840399, 43.40055134988601, 48.76296481778545, 50.18586343334567, 51.0187630499563, 50.9071441619627, 47.20954933474141, 50.13459805519351, 52.8439046490577, 49.015424251556404, 53.59598382826775, 53.0217606021512, 52.2366197647587, 54.88017566742436, 55.604315803897, 57.3825183991463, 57.256320061222205, 53.451275825500495, 54.51418322901572, 51.97484862419867, 40.33230866155317, 25.44054981200926, 12.812888929920813, 6.194561950622067, 2.9347163823343094, 8.080538530503551, 9.04385401356605, 3.1661560794999524, 0.1399831554942554, 1.8352359413139283, 36.817908133229906, 40.82774323801841, 41.67128032253635, 38.373327947431996, 50.78730006371775, 33.57029153454688, 2.6244265033352763, 0.06375228573057441, 0.030238626096698067, 0.08009920392425791, 0.040386803222880255, 0.022061612351887652, 0.03942747728057927, 0.026525993561071735, 0.04385859878253072, 0.005502018574324827, 0.04806068680819966, 0.06926809197231647, 0.028093122171177983, 0.04705058072783774, 0.04289415920333516, 0.020769831063526294, 0.19938686952715923, 0.13200873178580116, 0.1496196529197116, 0.12569198444966348, 0.33980108737464876, 0.26870356211739205, 0.2420917667088009, 0.10408823603704091, 0.19728041884879913, 0.1980072217843225, 0.12627960453110357, 0.20012805959390056, 0.14269214964682056, 0.0896219066494415, 0.11056707225619786, 0.16103709026450114, 0.1467291878596429, 0.13557862490415573, 0.21231350008278124, 0.5991077230822656, 16.856303445754513, 56.478674873229004, 58.380683160597286, 63.63587863983647, 69.88396721501505, 67.39392895852366, 41.47742894388015, 59.22826028639271, 39.621135880870206, 3.2413116337791568, 2.0967990736807547, 14.253523522807708, 42.96610178485994, 16.68720026170054, 26.826625216391783, 46.27851201641945, 53.18929287695116, 54.042122056407315, 53.03984665101575, 55.07343476818454, 50.18700876543599, 50.27028068419426, 53.62400524077877, 59.932000175599136, 55.992595149624734, 51.37673031899237, 48.10678366691836, 48.04310790954098, 45.61530982294391, 46.474148073504054, 44.78979602936776, 44.39266781653128, 45.24818774192564, 43.645370006561286, 40.77596402937367, 41.9715142250061, 41.30346398199759, 40.7143828176683, 41.135421799075225, 42.71645076813237, 40.48383374367991, 40.28456949418591, 41.241678807043264, 42.632994497976, 44.46656919294789, 40.045712840172556, 42.02410928664669, 39.834559886686264, 40.93025046010172, 40.007046115013864, 42.714160103951734, 42.66740545149773, 40.284553804705226, 42.74655888157506, 42.154104478897594, 40.02960758824503, 38.707482507151944, 46.50624090625394, 55.88238047015283, 56.044382203009825, 52.15756439393567, 53.03209212518508, 52.94695315822479, 51.95231852992889, 50.474906813713815, 47.437082106067294, 52.3231747073512, 53.509832889803, 55.68523037818171, 49.69752442452216, 47.9060406838694, 55.58240152174427, 55.14724593008719, 55.24961586921446, 56.7694244846221, 54.30241446341238, 57.630172929456165, 50.68418487425774, 49.778537058061175, 49.119343526901744, 52.18410315052156, 56.61400056654408, 51.71998085514192, 40.751562964531686, 38.71643727825534, 41.28278524644914, 41.85976589879682, 40.87809470392043, 42.09952469794981, 41.733987254481164, 42.58784801729264, 43.82756410106536, 40.49072534807267, 41.44465754109044, 43.57183733294087, 40.40146789243145, 39.176931381225586, 41.179775960983775, 39.65701772320656, 40.70875029410086, 41.753897205475845, 39.91525480824132, 41.68110193744783, 41.361381699962, 43.889514015566924, 45.556427201917096, 50.43244715659849, 51.791658247670824, 52.33298455515216, 53.87570765710647, 47.19922957881805, 49.365138853749926, 55.414728041618105, 49.44596321352067, 55.27043973245929, 55.20672082901002, 54.3898166379621, 57.904836900772594, 58.59174197719943, 61.553986533995605, 58.30681708551223, 54.8452312715592, 53.0099150442308, 55.40996236185874, 43.11705027857135, 34.91887300245224, 15.9301681095554, 8.276042207594841, 11.65329117928782, 23.806965005013254, 14.062020663292179, 6.66646917020121, 0.3903589986505047, 2.406694999625606, 41.78132241772067, 47.94367582567277, 46.49703510345952, 45.20288044406522, 59.64232529363325, 40.74751115614369, 3.5212340326078477, 0.17282632540070242, 0.0945318790693437, 0.18614010614973886, 0.1628161456075407, 0.05890483757661236, 0.07023654968267487, 0.19039459075898896, 0.10710141306082088, 0.09555410849110735, 0.11208123737765897, 0.14492799257559164, 0.15146166536836855, 0.18997624546529787, 0.21909250487242976, 0.11903087293068249], [0.03153272863147, 0.05131619659462764, 0.03820976903361659, 0.04449727862412411, 0.04187303294818248, 0.0052032931219606155, 0.04909972419902202, 0.0830470949351307, 0.09260387325118627, 0.04997877178773765, 0.041957386889525, 0.03806626161320075, 0.04721943799766803, 0.03574677720485676, 0.03806339261392432, 0.01907602598470065, 0.009510368709602665, 0.020410581792314208, 0.03026034851979104, 0.03996668443564446, 5.78494098878676, 36.45650486792288, 45.29123575456681, 46.65640884830106, 59.92917214670489, 70.16889602907243, 54.35440155767626, 47.594486821082334, 38.74809865028628, 2.5770413298760695, 0.683094003508168, 6.020012555583832, 22.09456409177473, 11.98453926271008, 21.265845721767796, 26.562016241012085, 47.24890247468026, 52.649225650295136, 49.87584321729599, 49.88091091955862, 50.73741928223641, 48.3785411619371, 50.86905794758951, 51.91953536002867, 52.59892909757553, 48.4044837182568, 46.71358916067308, 42.63406922740322, 42.93386774678385, 40.791747646947066, 39.22680824033676, 37.41588131073983, 35.976371457499845, 35.42738083870181, 37.334892211421845, 36.74560316147343, 37.21281236217868, 35.78707002824353, 37.08697095994027, 35.3015237469827, 36.92229809299592, 38.9022752546495, 42.621858889056796, 41.1116640029415, 38.025017553760165, 37.23148676656908, 37.74704702438847, 39.00186815569478, 38.51647484687067, 37.092446588700824, 38.07702818224507, 39.72365094769386, 38.097722607274214, 38.0099791865195, 38.22273638940627, 37.56443323627595, 36.826611872642275, 40.25358669219479, 51.44272419714159, 49.81308137216876, 45.883497961105846, 49.21091518094463, 53.477626308318115, 49.59395816249233, 47.415312951610936, 45.256146231005275, 47.6554443759303, 49.014141636510054, 52.93139703812138, 47.74448217884187, 42.07361352059149, 50.19377093161307, 52.87536598020985, 51.13347276564568, 50.88723028859785, 51.057794555541015, 49.11509167763495, 52.09061345746441, 56.94205584064607, 39.346279713415335, 52.27682798139511, 49.010109439972915, 49.76665227643905, 38.12390050580425, 35.93095041090442, 37.38695775308917, 36.943082732539025, 36.395865025058875, 37.7102904935037, 35.85727260958764, 39.53692651564075, 36.78595650580622, 38.93529376676006, 35.90636891703452, 37.40762079915693, 37.01789802120578, 35.96476908653013, 35.7329373974954, 37.25476603354178, 35.08611894422962, 35.83148694807483, 38.13646777983635, 39.698881180055686, 41.11169930427305, 44.627543264819735, 44.99035466101862, 46.86373356849917, 46.71666822125835, 51.141356729692035, 45.54023958021595, 45.95117061368881, 43.8005389705781, 44.09417152404786, 48.660273244304044, 52.635265934851866, 49.369155360806374, 52.69564297891433, 51.075413842355054, 53.21299968227264, 48.83618762416225, 50.75872167464226, 49.39820835667272, 48.044508195692494, 41.39051314323179, 21.6210751764236, 7.406957745552064, 2.8681471415104407, 2.168839530598733, 2.271479868119763, 3.30262097620195, 4.094781140165945, 2.4284124278253127, 0.11901345975216358, 3.2387576805007074, 37.77831615940217, 38.37584610908262, 29.301140692926225, 20.980987510373517, 46.13096029527726, 23.61672612928575, 0.5544218757460194, 0.06373802500386393, 0.07197113362170997, 0.03785091812812513, 0.09176660043698165, 0.01754346709217756, 0.09774206326373162, 0.028194270675040545, 0.06349594505023091, 0.043135967195755055, 0.012443844818570202, 0.04396158781263136, 0.11363087237001428, 0.02974646057062332, 0.0656735384836793, 0.07194896303718129, 0.03906674179879408, 0.03642063963437273, 0.061921071291210196, 0.019326257113848003, 0.036277607188469944, 0.07479147099319004, 0.06143478932039392, 0.02996469986805272, 0.07358609293136867, 0.017445783220952558, 0.032457153523160566, 0.015484684319686026, 0.03675635851499054, 0.03821749503033296, 0.022618550611960313, 0.012400136629660285, 0.05154552884520062, 0.008853721233355183, 0.06223997837232967, 0.07802014855007011, 7.770173636174972, 44.6636918283278, 49.24508294751568, 53.554575366358605, 66.32685599788543, 71.06306306777462, 54.54076513167351, 52.60896252047632, 42.93319702148438, 3.290152006572293, 0.8131201457112067, 6.954732489201331, 27.27512667256017, 17.011595964431763, 25.674844749512214, 31.0247419341918, 47.892610488399384, 52.09840328462663, 51.448948998605054, 53.08420473529447, 53.004306054884395, 48.95755360203405, 53.21240740437662, 52.55384145244476, 53.717165454741455, 49.18659648587627, 47.74956949295537, 44.896806132408884, 45.97667386454921, 42.33796165835473, 41.03914722319573, 40.45544362837269, 39.04882677139775, 37.52247564254269, 39.10236712424986, 38.16181805826003, 40.01002711634482, 37.42840151632986, 38.336406676999985, 37.73207925981091, 38.810687911125925, 40.19579449007588, 43.62821748179775, 42.311991645443825, 40.34935528232206, 37.71968457006639, 40.387104172860425, 40.15380159501107, 39.40067906533518, 38.736645329383116, 40.26809946183236, 39.87440724526682, 39.786204907201956, 39.9126935005188, 39.477569287823094, 39.75341781493157, 37.35285666681106, 42.670068740844734, 54.05879212963966, 50.872117396323915, 47.763815541421216, 50.24301236675632, 55.994654393965206, 50.909540730137984, 49.242266685731956, 47.36269043337914, 49.77918817150978, 51.25592916242538, 53.213360540328495, 49.72937799269154, 44.23546314239503, 52.338197385111165, 55.676499182178134, 53.880720446186686, 53.312023839642926, 51.551495444390085, 49.898993046053, 48.045857491031775, 58.28787988232028, 42.953483520015595, 50.677544301556004, 53.29593035482591, 50.23646200856855, 39.780380187496064, 38.06521008091588, 39.113071272450114, 39.00222509138046, 39.27200963420253, 39.375073832850305, 37.90685615231914, 39.565457836274184, 38.56521421863187, 39.239634390800234, 38.52157000572451, 39.49003458023071, 38.632263214357444, 37.44971567584623, 38.29255457847349, 38.62195130317442, 36.17130933269378, 37.59164664053148, 39.66320722333847, 41.73521103397493, 43.2394713740195, 45.30854909650741, 47.64665826674431, 49.536201261704974, 48.624505150702696, 52.81405541204637, 47.4357485002087, 46.34015990841774, 44.00921690848566, 45.511535675294944, 49.05801726925758, 53.24198599784605, 51.20952752328689, 54.61846728478709, 53.08101584834438, 55.309934077724336, 51.324433357484885, 51.8802135990512, 50.91321991335962, 49.68933843797254, 44.492617653262236, 29.506586597811793, 13.558630539524941, 6.106919530899295, 2.4719796642180416, 3.81577633080944, 1.9703677224536098, 3.4439780491013683, 2.1167305977113786, 0.06679922041873779, 3.3887478901493937, 41.70158455448766, 43.45468790300431, 34.166511412589784, 28.53266012284064, 53.303053379058845, 27.8255783742474, 0.9151854269927548, 0.05703889254120089, 0.07628977809461855, 0.07745754890023701, 0.0812305778925938, 0.008914980496610365, 0.06238817425084211, 0.012165417823369705, 0.052422481183443344, 0.03891780664543471, 0.044023077859873735, 0.031243986262369062, 0.008896195063097103, 0.0544018225534068, 0.01897802418698707, 0.04581498049740349, 0.1052541299272449, 0.07814543456920693, 0.1126956552146904, 0.0950331993461136, 0.11164122711746924, 0.1948137229849254, 0.16336570644090254, 0.11727571953088047, 0.23778609210445037, 0.1276316577869077, 0.06998588571385031, 0.18282691377305216, 0.15395151240931404, 0.1729677452315246, 0.12573904523085203, 0.1526702763212304, 0.12001351092851932, 0.13878094903644056, 0.14181258877919567, 0.13575692420765278, 9.66517411893414, 50.78330316851216, 57.34728374788838, 57.52779514558854, 65.9927406618672, 74.50700606069258, 61.931926511949115, 58.09935115998792, 50.87075241150395, 3.9507531783273144, 2.3606897650226473, 15.185558103745985, 33.80027186486029, 24.802572381111887, 28.834384525975874, 34.944458623086255, 48.574106616358605, 51.14092526897308, 53.00463553397886, 54.295048252228774, 53.08717004714474, 48.76714214201897, 52.950828459955034, 55.80328587562808, 57.387837133099964, 51.08541980866463, 48.82497749020977, 46.547457172024636, 48.29900726195305, 45.70903878058157, 43.05309995528191, 43.63616812613703, 41.58801232614825, 39.002072118943744, 41.76451898390248, 40.2048316309529, 42.198835188342684, 39.610243458901685, 41.021771123332364, 39.19803373275265, 41.17360607270272, 42.849795664510424, 46.2098587712934, 45.97477151501564, 42.092919426579634, 40.54854500678278, 42.052409187439956, 43.98206233978272, 42.91588760191395, 40.97260029085221, 40.89586304080102, 43.76110346086564, 41.144992382295676, 41.45401631632159, 41.77484266219601, 42.20381659846152, 38.67860601794335, 44.08456171712568, 56.739751754268525, 52.46390542676372, 48.7215014426939, 51.937154646842714, 57.49912654199908, 52.94480762174053, 52.111833480096635, 49.79395981757872, 49.5286036306812, 53.59668985489876, 54.75067469381518, 53.005412163272986, 45.79553096525131, 51.29413304790374, 57.35731717078917, 52.69109695188461, 54.08619380766346, 51.15110774194041, 52.165958266104425, 48.47469022197109, 56.973905486445275, 46.36713797046293, 53.51894847808346, 54.47500267336446, 54.136792382886334, 42.31414502666843, 40.36802184197211, 41.484034215250325, 40.12776097943706, 42.231422239734286, 41.10081472704488, 38.68971809264153, 41.98480321514992, 41.04522297459264, 42.05593147585469, 40.79158682977, 41.251237623153195, 40.52756032636089, 38.339332765148534, 40.86192277169997, 40.31383037567139, 38.20446598914362, 38.8045415570659, 40.915655320690526, 43.64717821921072, 46.147928468642704, 48.686000070264264, 49.66343510535456, 51.778839941947695, 51.04574111200149, 54.61116383152624, 47.381635481311434, 48.4351448858938, 45.80262653289303, 46.151760624301055, 48.777312847875784, 53.888922122217, 53.00325485967821, 55.49267730405254, 54.56196554245488, 56.049426371051425, 50.57385644605083, 51.273160134592366, 51.29599225136542, 50.41636936126217, 48.63493081062071, 33.56635739726405, 13.72122847264813, 4.897372847603214, 5.7800081179988005, 11.715950062198024, 8.692178226286366, 11.986834829853429, 6.033039237222364, 0.34901375431687603, 4.445732514704428, 49.226581127412864, 51.423681089955, 41.64181155543174, 33.61978400138117, 60.28611175475582, 34.27671824732135, 1.3220968890574671, 0.14065182767808437, 0.1834705961687911, 0.18542552997748699, 0.15186182373473722, 0.13412834385470038, 0.19185683810182158, 0.10512807015930453, 0.18957930466821118, 0.10668208717458671, 0.12465234184938094, 0.09844507916920608, 0.14159246107503293, 0.12461859567631638, 0.1874251573556854, 0.13691155660536983], [0.04409232837778907, 0.022858391673634612, 0.05781403562474636, 0.04059306090517391, 0.0536504396868329, 0.06591484851894841, 0.05269350393885567, 0.04534717273688124, 0.0526613129242774, 0.040642136497603315, 0.08975417172956852, 0.08631538689857529, 0.013823372860168739, 0.03536399371261078, 0.013447654613804434, 0.07936159914900219, 0.03742558228212499, 0.025858459017810323, 0.030743328651653665, 0.0926342869417802, 1.9534987115090894, 23.28555060971168, 46.332589733985166, 33.27297195311516, 32.02924720702633, 49.6264353875191, 43.07408071333363, 52.15503446517452, 39.567881861040675, 1.5161997897009698, 0.1599411861670594, 0.8384681565146294, 15.731211766119927, 5.475212008722368, 9.351948345861128, 32.32126766635526, 44.611673355102546, 57.5967582579582, 51.57101315836753, 38.77506102285078, 46.35305273917414, 54.512963371892134, 50.38745757072203, 50.922747350508175, 50.8017030069905, 51.371250767861646, 48.94292708366148, 47.529430389404304, 44.938771570882494, 41.24349094206288, 40.228008916301114, 40.741886477316584, 36.69482415722263, 36.66101724870744, 36.65508270263672, 35.51812879500851, 37.26161056949247, 36.270070691262525, 35.131496844753144, 36.98424016275714, 37.346663244308964, 38.79744598942418, 37.5981185513158, 36.55688616537279, 36.100969468393636, 37.8058276637908, 38.70008883937713, 37.937772274017334, 37.92695437708209, 37.19580104274135, 39.150616199739524, 38.60143338480304, 37.88448295285625, 37.9907948740067, 38.13312199807937, 36.70999196267898, 37.353150844573975, 43.024745141306234, 49.594091523078184, 52.19558392801593, 50.36136988670596, 50.57416239092427, 51.81674964966313, 50.05518182631462, 49.73164120028096, 46.687336737109774, 48.55803274339246, 49.19340964286558, 54.12668443495228, 46.946523035726244, 42.42800358803042, 45.76510906219483, 47.326871348965554, 52.134457711250555, 48.51562799945955, 49.01061934809531, 51.609989750769834, 54.43330787843274, 37.477627261992424, 44.37299320774694, 53.52142349366219, 51.08107382251371, 48.86176147768575, 37.448221252810576, 36.34066550962387, 37.88997427109749, 36.47190017084922, 37.97372079664661, 37.12351568283574, 36.5233342109188, 37.56679842548986, 36.633105662561235, 37.05803171280892, 35.577391885942035, 36.315440747045706, 34.699643888781154, 35.72837568098499, 37.00624465942383, 36.30494840683476, 38.29861071801955, 39.14441493249709, 42.08765168343821, 45.09218723543229, 44.68216619183941, 47.25571955403974, 48.13962175000099, 49.76828398243074, 50.0118161016895, 49.632793549568426, 42.548694918232584, 46.281477328269716, 46.083103456804835, 49.17367227615849, 46.29482907633628, 49.16120698375087, 47.79117015100295, 48.494592328225416, 50.537213663901056, 51.2309475867979, 48.96952467579996, 49.705832004547126, 46.52306002955283, 46.92481271682247, 35.676537636787664, 12.989108274059912, 1.651027096856025, 0.5736881903102321, 1.243726829847982, 2.141232663585294, 1.3832794898940672, 2.3755508901611453, 1.9693291523764211, 0.04541788265229233, 3.3313633693802744, 36.05813718611194, 36.495151981230705, 44.13413655373358, 39.68035190336166, 44.05204526839718, 15.232774615287783, 0.2044278812865096, 0.02622425834077501, 0.025969220009902795, 0.08878746069967748, 0.051196901383058685, 0.037031280657937454, 0.022989185864947016, 0.05314311711117626, 0.012195124797853492, 0.010669353444339528, 0.006748238219804461, 0.040053773310876666, 0.04489492805254075, 0.024295287251832987, 0.012844771188082955, 0.08379116549246735, 0.05128932223024388, 0.016871958467808944, 0.017966893464026433, 0.007744733311776673, 0.042898315230324384, 0.029528343847261804, 0.02711051864729774, 0.033629873256769874, 0.027925119089383273, 0.020520846742475708, 0.07936624930270257, 0.13099781748267914, 0.049850375451628244, 0.03792786016880024, 0.029502783323668187, 0.004957973574017806, 0.08659379091113807, 0.06525181474224215, 0.021835055254820376, 0.18312810890136227, 3.151383452838467, 32.02022379444492, 52.40290472584387, 39.62381878206807, 47.41814098050518, 61.67756080627442, 52.16332243334863, 54.56193024112333, 44.034406369732274, 2.03599228493629, 0.28256396192216104, 1.736802345802707, 21.618823735944687, 9.658488438975427, 11.532778316928495, 34.41742543251284, 45.193235335811494, 58.0303958923586, 51.62497320482808, 44.09589736692367, 48.955360997107725, 53.18346815724527, 49.787091747407, 53.44833012550108, 52.86518742961269, 53.14172237150131, 51.28120883818596, 48.490744483086374, 45.12622948615782, 44.34482274516937, 42.846245919504476, 41.68886430801884, 38.179731522836995, 38.768130194756296, 38.31283323226437, 37.1393463688512, 39.40634689023418, 38.374218325461115, 37.72319509137062, 39.757002861269065, 39.64563500496649, 40.93981712095199, 39.1803438432755, 38.962707211894376, 36.88652215465423, 41.655398645708644, 39.91021064019973, 39.130380692020545, 39.25581416776104, 38.60966251742455, 40.07147104509416, 40.546630890138694, 39.8505513898788, 38.84814654627154, 39.01592200802219, 39.196413793871486, 38.18767432243594, 44.22955605291551, 50.73237511419481, 52.8631164181617, 51.67813701014365, 51.09559443689162, 52.77789900379797, 53.075481384031235, 50.7788630454771, 49.281545300637525, 51.310834500097464, 51.78925775712537, 55.524621086735884, 48.964221631326986, 43.05159768750591, 47.9076841569716, 47.91986311635664, 51.587204702438854, 50.43895829108454, 49.3982397356341, 48.52892091197353, 54.98691904929377, 42.84450438714797, 44.542843603318744, 55.15835016004501, 51.91937062048143, 49.78820570053593, 39.650765465151885, 39.12714473662838, 38.37627756980158, 37.340509045508604, 38.59139603953208, 39.97576913525982, 38.29866563120196, 38.49087353675596, 39.1222260844323, 38.10850520287791, 37.95861182674285, 37.334535275736165, 36.83990086278608, 37.440788361334036, 38.356944207222234, 37.53347004613569, 39.00883428512081, 41.15791266964328, 43.58132554638771, 46.26443070750083, 47.6241320948447, 47.450394630432136, 50.040182682775686, 50.65417482006935, 52.813871060648275, 51.43964121418615, 44.420477421053, 47.60733650576684, 46.599118709564216, 50.31843954516996, 47.55434528473885, 48.84790766623713, 48.248404764360004, 50.083113024311686, 50.62936582872945, 51.340946535910334, 48.20143045917634, 51.23386190783594, 47.70499960068734, 48.872155758642386, 38.960710725476666, 16.83719365827499, 2.3429724189542958, 1.6442671370121742, 2.428593102001375, 0.8430373500431738, 0.9783015111761709, 0.6200838233194044, 1.4559920204262582, 0.05316663601045167, 3.6966966044518257, 42.804280481030865, 45.07301469003001, 44.115356245348536, 38.14791325599917, 49.71475931905931, 18.862664430372178, 0.40787774408536576, 0.04631966773060061, 0.0650489240163757, 0.08076143330864369, 0.04411366009604066, 0.061444691006815245, 0.020976266861262343, 0.036380580896812106, 0.05002055039268829, 0.039429097556539124, 0.008640630046776947, 0.045175262606672706, 0.031202044863734516, 0.026604793364963224, 0.06942130955717257, 0.04804969727692585, 0.1929534776436706, 0.21267517019183407, 0.20227191068472403, 0.20633611437534133, 0.1504110983542858, 0.24947811068306047, 0.09729314340098251, 0.15041382562729622, 0.1251869639682193, 0.14034667953608498, 0.15120450497394608, 0.15288957665043493, 0.13574209274543872, 0.18317755221599535, 0.1889915773344617, 0.19529686399525215, 0.21038295851359445, 0.13114081545462533, 0.17023287262887726, 0.3000034938656515, 3.2444828700634742, 35.84632135206653, 60.06410168063257, 45.03998833317911, 45.49068827782908, 59.24757403712119, 52.89061223306964, 62.89977135196809, 49.135284039282034, 2.4055131404630603, 0.6194170203901107, 2.4838595428774437, 21.03985248073455, 8.39440364991465, 13.741990558562742, 42.219929695129395, 49.70587515061902, 57.59808009670627, 52.472173783086966, 43.727649565665956, 50.89110951269827, 54.38216409375591, 51.803178248866914, 55.36051696346652, 54.56706462367889, 55.84487084419497, 53.48746361271028, 51.30016173085859, 48.65038494909964, 46.08598247651131, 43.79733439414732, 44.82997678941296, 40.399122315068404, 42.17298676890712, 40.98848981242026, 38.99904012680054, 42.38488497272615, 40.2523668350712, 39.45254456612372, 41.259309860967825, 41.72906075754474, 43.57453200124925, 41.72503640574794, 40.94966227008451, 39.4822447530685, 42.18013332736108, 41.9348753652265, 41.167997083356305, 40.983814347174864, 41.98126523725448, 43.33321994350803, 42.310242268346975, 40.316148496443226, 41.131660246079974, 41.31459959091679, 41.74886480454476, 40.92178598526986, 45.96849180036976, 52.88919625743743, 56.77186812123945, 53.15084580452212, 52.65506998185189, 55.319190871331, 54.97906254183862, 53.3100155861147, 50.05427968117499, 53.737240145283366, 54.96828779097527, 56.29512756101547, 50.77635665093699, 45.99987860648863, 46.69915091606879, 48.47545508415469, 52.92732954025269, 51.14454561664213, 50.580430338459635, 48.86992393001434, 52.59846233552503, 46.11952658622496, 47.81185673129174, 57.51453361203594, 54.3798851966858, 52.29277633851575, 41.62085040923088, 40.93673806036673, 40.81383451338738, 40.802553776771795, 41.56309350844353, 41.2531635069078, 39.018259740644886, 40.626502113957564, 42.12562807144658, 40.60392495124571, 39.271225160168065, 39.307628677737334, 37.897815089071955, 39.98945428479103, 39.829456883092085, 39.96170351582189, 41.18820513448408, 43.13834482623685, 46.500212223299094, 49.22480821609498, 50.166730111645116, 51.329210804354766, 51.71823540041524, 53.02280003024686, 51.97727264896516, 52.923850397909845, 45.32381496121807, 49.39468606825798, 45.56038879579114, 49.036601128116736, 48.56092745257963, 50.82042447982296, 49.02452807272635, 50.87535727408625, 51.89665617481355, 51.60341585836103, 49.37805914109754, 50.072114698348514, 49.46297061058783, 50.18100753907235, 42.70316570035873, 19.601686039278587, 2.7934291766535853, 1.966941164385888, 4.005574675336961, 5.071041180241493, 6.9374034577800385, 7.528587012521683, 4.125551398723356, 0.1782783280096708, 4.252238071733906, 47.62148057260821, 48.11992360699562, 53.99734820089033, 49.75264157018354, 57.90871612487301, 22.404339159688643, 0.6034440258818289, 0.19885808499830387, 0.2134468199144448, 0.18560879353073337, 0.17016631491001577, 0.1750740733358168, 0.07384518386736032, 0.13194370624278823, 0.14354223145111916, 0.07823983192323677, 0.12608538592054, 0.07279298508599882, 0.09502013754700461, 0.18538866582657063, 0.12685242379384656, 0.2704526327790753], [0.043153537422298424, 0.06575226167877836, 0.022317121826833295, 0.06688959581116516, 0.0363629149092782, 0.02951630669075155, 0.05191013690144305, 0.06873532378625485, 0.026884702740297205, 0.05264841966451176, 0.007985702437919476, 0.04105501192351503, 0.033481807613204566, 0.04675213202473618, 0.037576283268149824, 0.04622772951880771, 0.04165637945275634, 0.015934583817368314, 0.02144859454053785, 0.021660511697372122, 0.11211632420459103, 11.171437809544226, 46.18838771697014, 43.83168651211647, 24.27474883294875, 28.255022994933594, 41.504038303129136, 45.32811387892693, 40.46608501865018, 3.445830143267109, 0.6726297327587683, 0.7731665767008259, 10.773673192147287, 1.2910341687740818, 0.48003366577529144, 19.437944735250166, 41.467705388222974, 54.11316010259814, 53.079399831833385, 53.173175857913115, 50.71321041353288, 52.10780912829984, 49.188357630083644, 51.0330443997537, 50.08394848915839, 49.708224650352236, 49.795583678830056, 48.998522758483894, 44.70865395761306, 44.54835845578102, 41.99183994723905, 39.07123527219219, 35.60540545371271, 37.48591523016653, 37.064864481649096, 37.534015255589644, 35.988974032863496, 37.670560806028305, 36.33761782799998, 36.43802265967093, 39.051172348760794, 38.908582425886586, 38.47770221771733, 37.54653938354985, 38.42536211013794, 39.87797267975346, 37.70226924650131, 36.63942852327901, 36.2701883623677, 38.31488070949432, 39.391045724191976, 39.00136216994255, 38.24702762788342, 39.20713363155242, 36.275773817493075, 38.84951153109151, 38.63423616655412, 41.61319002028435, 46.08784167997299, 50.204988910305886, 49.892372085202126, 51.70666833077708, 51.38848174002863, 52.51914416590045, 52.24666495477, 50.3172432222674, 50.64935814949774, 50.91650685956402, 52.30035043531849, 47.093568771116196, 40.837082401398696, 46.92583253306728, 48.16892969992853, 52.67100657186201, 49.10881588535924, 52.602659271609404, 48.4375100751077, 41.744809073786584, 47.84025076896914, 51.8414919607101, 49.45239982297344, 51.81590241770591, 45.83651581118184, 35.8531698103874, 35.86081450985324, 36.87935598434941, 37.62871303865987, 35.0623611480959, 37.997329542713786, 39.397003804483724, 36.766332887834125, 37.82063068882112, 36.67618505416378, 36.502443667381044, 35.88287784207252, 36.33245598885321, 35.13075943916075, 37.82401961665, 36.673984604497115, 36.83426833921863, 41.27400305963332, 44.573147835270056, 48.00726921327653, 49.234763191592315, 47.57190181363014, 49.62245025942403, 48.24172496795655, 46.008566656420314, 45.3213595574902, 46.00263995508994, 50.48365369919808, 49.72303159775273, 47.8289504205027, 48.601759326073434, 49.461840967978205, 48.598103677072835, 49.530243181413226, 49.40121289222471, 49.127137276434134, 49.522131719896876, 49.160328372832275, 50.05588393057547, 44.068436853347286, 23.371028861691876, 4.808259048769552, 0.34052170031974394, 0.7469226107481988, 1.8389997006424013, 0.4236595230477472, 0.5923467826458716, 0.2188953904495124, 1.1383197504666545, 0.005012924103216539, 3.6732543139688434, 30.361951589584354, 33.029447678596746, 34.76096622405514, 33.901531773228804, 42.46008073129962, 10.447264332925121, 0.068005035150676, 0.02000084924211185, 0.013488466032750666, 0.0030071627547694074, 0.061017700410898656, 0.05824540824358983, 0.0738349948979674, 0.032533030701620926, 0.009965184576539023, 0.007014243099312749, 0.012531570504389465, 0.07747516126161622, 0.05850622670785074, 0.10079521475540054, 0.025012598357974522, 0.018400700327249307, 0.015234490537324981, 0.062099569777567545, 0.05589471341321065, 0.015276584195934478, 0.02626381912118485, 0.049247088872136614, 0.04236634377570402, 0.018127476984274485, 0.01879240491337353, 0.07434106491986783, 0.08035860895629852, 0.07217667501179442, 0.05421777759047766, 0.04952617853339161, 0.03731695484490164, 0.01798490802156589, 0.023971408260084932, 0.07705186703993429, 0.06620937102143803, 0.03464607356656944, 0.08760120419244613, 14.706633763928568, 57.35507749742078, 42.38646568790559, 26.341363306968447, 40.39506658431023, 50.51570338587607, 51.40987042457827, 44.73129387824766, 2.9257773007116015, 0.4643439705814085, 1.5272909042335328, 18.48988825275052, 5.429661523911261, 0.8310962456368631, 26.130098565932244, 44.20077762296123, 54.25027831908196, 52.516190621160696, 53.9222034331291, 50.40505332331504, 52.9845961447685, 50.86061308460852, 54.20677138913063, 53.414413390621064, 52.434558253134455, 50.991479043037664, 49.85595680052235, 48.19189517728744, 47.692330345030754, 43.733642947289255, 42.23257541656494, 38.87971378141834, 39.29362189385199, 38.83098617676766, 39.48690060646304, 38.23306791244015, 39.43170893576838, 38.59687951303298, 38.737017954549486, 38.76517665001654, 39.92163258214151, 40.033294616207, 40.27834077035227, 39.110470741025864, 42.252818769024266, 39.91882416509813, 39.1399081291691, 37.702685017739576, 40.118755217521425, 40.56291657109415, 41.25656027947703, 38.18170447503367, 40.717583471728915, 38.81816787104453, 39.721576013872706, 39.76627926672659, 43.629880566750806, 48.21999111483174, 51.63011150975382, 51.68140042212702, 54.03821929808586, 52.80582235705469, 53.612089080195275, 53.03708530241444, 51.75561951052759, 53.55980780816848, 52.52176038680538, 54.151603252657004, 50.55008296043643, 42.26560569578602, 47.9551056123549, 49.34422477599114, 53.59934922187559, 52.126899303928504, 52.66386785814839, 50.74552682138259, 46.677621026192945, 47.63919399630639, 53.147162698930316, 51.800911118907315, 54.3014338708693, 47.59886418619464, 37.30742777547529, 38.05290560568533, 36.90577706983013, 39.221430670830514, 37.85313144806893, 39.28623214844735, 39.069838908410844, 38.67018076681322, 39.0079439070917, 39.575287295926, 39.03262346021591, 37.29261690570463, 38.98555501814812, 35.83473859294769, 38.777277161998136, 37.462788935630556, 38.71881423457977, 44.197922137475786, 45.99076694057834, 50.767911787955995, 51.20150235391433, 49.92957576628655, 51.24981810969692, 50.757391991153845, 48.12353218755415, 44.932762499778505, 47.17379693062075, 49.8393298733619, 49.114369961523245, 48.67333865934803, 49.298391880527625, 49.85170102888539, 49.47909155199605, 49.02921530508226, 49.59373850976267, 50.26837048992034, 49.77582277790193, 50.827033673563314, 50.25761142853768, 47.012807169268214, 27.21432012896384, 7.3878597251830564, 0.49904763097724614, 1.5570838797476985, 1.7069083692566043, 0.9655945639937156, 0.2083136477778035, 0.46465209114455414, 0.278659732711892, 0.041870309505611665, 4.129275198905699, 35.17577648162842, 39.024464930257494, 42.367650078188994, 40.930454423350675, 48.9369886152206, 13.863173165628988, 0.01906457488545247, 0.01860772601268705, 0.05039926595805634, 0.041137159531635624, 0.053668714714266604, 0.03868275171806736, 0.025632633534710736, 0.010610802301896677, 0.032449638200623375, 0.019105393965277943, 0.02625955775710604, 0.044167485433600606, 0.043747607964060964, 0.06987355424151306, 0.05013716046608264, 0.016105276825387153, 0.13430385459815303, 0.1543005727111332, 0.20344788629201152, 0.13592020818783393, 0.1155742152684158, 0.2613675960850331, 0.1672400275786077, 0.11886481571221545, 0.14618079147992596, 0.20545750345674255, 0.21243233564159564, 0.15728067005834273, 0.11824785446327542, 0.18708556590061035, 0.36036239696606515, 0.09364933811969335, 0.13682152595250838, 0.1625114264747789, 0.17605262808501723, 0.0699004592494138, 0.23918674597817086, 19.159515288568315, 62.813318391000074, 52.02922836426766, 35.709069774996856, 40.06478340395036, 53.639773168871486, 56.15130209153699, 49.341679157749304, 4.160995406489219, 0.9043699815388649, 5.043329144677808, 20.759097068540513, 4.652273741460616, 0.8765661379983349, 27.174335487427253, 49.15442520572294, 52.66761372166296, 53.24476695829823, 54.56373060903242, 52.40562685074345, 53.25274898159889, 51.609687728266564, 54.257483713088504, 54.62341731594455, 54.056344570652136, 53.48318430685229, 54.045165815661036, 49.37767867119082, 49.58417577128257, 45.873409625022646, 44.791066877303585, 40.08949041366577, 41.4292779276448, 40.67265272140503, 41.57655508287492, 39.76439652904388, 41.39172907798521, 40.68700075149536, 41.02721929550171, 41.82536671238561, 42.5359982059848, 43.69319546607233, 41.44952912484446, 42.21657999100224, 45.24641875297793, 42.26568806555964, 40.87449789047241, 39.11879008816135, 42.1246749354947, 42.647585715017016, 44.02009756334367, 41.22024697642173, 43.02901660242389, 39.93338400317777, 43.05081713584162, 42.77637281725484, 46.26519556968443, 49.47168611711072, 54.79490333987821, 52.17074748008482, 54.19127802694998, 52.6724107803837, 56.02060479502524, 54.78206542230422, 53.19675714738908, 55.13756159813174, 56.073105719781694, 53.83466397562335, 52.8965114778088, 45.15094826298375, 45.892574325684585, 50.13470003681798, 54.55069265057964, 53.144562167506066, 55.49653299393193, 51.1966896057129, 49.947175441249726, 51.33974236826743, 53.38858066066619, 53.42007337077972, 56.27048330922281, 49.86013412475587, 39.146925249407374, 39.99263532700078, 39.03079171334544, 41.945501066023304, 38.54648097868889, 41.697901448895855, 41.427771737498624, 39.7729512183897, 40.830061358790246, 41.35097565189485, 41.63315880683161, 38.86744460751934, 40.448371594952, 37.57359589299848, 41.22876244206583, 40.57870803340789, 40.66494526401643, 47.22616449479134, 47.65501683758151, 52.8145339412074, 52.71678455414311, 51.12544759627312, 52.049130470521995, 51.27627841887936, 49.73027229309083, 47.13625592570151, 46.98238134384156, 48.5394367864055, 47.88293400118428, 48.635346581858975, 50.10336029914118, 51.00292844157065, 49.885543238732126, 48.77924265400056, 51.078885139957556, 49.95570659637452, 50.54597623886601, 50.97246731481245, 51.241639967887636, 48.73009927811162, 31.85968118329202, 7.626568309722408, 0.8386954701235219, 2.1377844099075567, 4.66403938108875, 3.921188558301618, 2.0146544686248227, 3.6952254704890715, 4.727871542976749, 0.15392512834120184, 5.539642332061645, 40.772759452942886, 44.320759004162205, 46.262085130137784, 45.53946687329201, 55.87812469851587, 17.181452243558823, 0.27174833260716935, 0.06566296647032423, 0.18490581592965513, 0.17887091234086022, 0.16395574736018337, 0.18206511594114766, 0.21311334184100553, 0.11148447020640297, 0.11171755245736531, 0.11062852782948364, 0.07628261517252653, 0.2392661126871263, 0.1640042713693073, 0.12556715808328123, 0.17693313890166823, 0.10336372370441115], [0.019943963383294402, 0.039841643564643404, 0.04201706130838683, 0.042462587401631384, 0.018936519458469366, 0.03138978045523888, 0.053439336498418165, 0.011149604387971903, 0.020314353488145337, 0.03391658166243184, 0.07625995429172631, 0.0387186965634746, 0.012148316825679954, 0.08313483498509854, 0.048860804358076666, 0.05995085402842491, 0.06321268020978858, 0.018882872236351815, 0.005191319646509064, 0.012594578363331816, 0.07825510771644693, 3.1042772579577664, 34.70473904763499, 50.462978886019805, 41.95982948426278, 20.610970720168083, 31.595374230415594, 40.00928186601208, 48.86440907755206, 7.866350643096432, 0.18228516703651798, 0.433007848839606, 5.307020775733456, 3.6592936179330273, 0.25517743711750357, 2.080067223118198, 18.059614050772883, 47.491297106589045, 52.10196087437292, 52.28956783971479, 50.27183786515267, 50.83821635092459, 48.921930636129076, 51.67044131986557, 50.51894718600858, 52.479183058584894, 52.16000410818285, 49.25701479757986, 46.554788081876694, 44.34148480815273, 41.673865164479906, 41.29675672900292, 38.50378597936323, 38.18814108448644, 36.90126242176179, 37.31045584524832, 36.03551295495803, 36.61122668174006, 37.75806888457268, 37.323215315418864, 37.776762900813935, 37.55748671870078, 38.49203455832697, 38.57345511836391, 39.0635552713948, 39.83303800705941, 37.53256397862589, 37.09952254449168, 36.63734574471751, 38.35688144929948, 38.76513350394465, 36.870291386881185, 38.11908775760282, 39.16279908149473, 37.07635310388381, 38.2217832534544, 37.71163194410263, 41.236756232477006, 44.52922513408046, 48.28232542161019, 48.649749525131725, 52.099191681031265, 50.416683150875954, 52.22808468726374, 52.39234962771016, 51.201953426484145, 51.70349121093751, 51.25580364657987, 51.70530334595711, 45.30165749211466, 41.97197706468644, 53.518756281945016, 53.068864345550544, 51.28218943072904, 50.28386777447116, 49.6142368162832, 47.88222012981292, 53.973857125928326, 52.085804631633145, 50.15538269473661, 51.38067622338572, 48.8411101987285, 40.9086460451926, 36.56982214220109, 36.53716056577621, 35.118588324516054, 35.2135096826861, 36.22142153401529, 37.09580413756832, 36.74346546972952, 37.108332187898704, 38.2739076306743, 37.6117487876646, 38.77713203430176, 36.68955641408121, 37.878309142205026, 36.699887937115086, 35.70938748698081, 35.125593677643806, 37.47950215493479, 43.567232470358576, 48.30551447406892, 47.27298582753828, 46.50355800505608, 47.22483088893276, 42.778851755203746, 45.11576068016791, 48.70810654855544, 51.64582844703428, 49.47648709820163, 49.26269438958938, 48.394756240229455, 49.55696628939722, 49.18700441237419, 50.2243418847361, 50.13625329540622, 49.35263826001076, 45.84598049040764, 46.06858284242692, 47.83290024726622, 49.21638688733501, 41.98078670809346, 34.33759343239569, 11.772100752399815, 2.1003130270588786, 0.5558872487275832, 2.6281579031098277, 1.3972729132060082, 0.3981442905722126, 0.05253773911165134, 0.2721353602265158, 0.24444846766850642, 0.04285246103761658, 4.573490485068291, 25.772539223394087, 37.72412861547163, 43.32080564191265, 31.08905507672218, 36.95528130377493, 4.3248053519956535, 0.017841067352902987, 0.03613092050316834, 0.055305250890312664, 0.06960769874915, 0.07184092931809925, 0.06806128898695593, 0.029854827537952416, 0.009722142224951137, 0.01812872379237125, 0.009652030815730893, 0.046787716808819005, 0.059210587097632314, 0.05576936610703988, 0.08154924748645676, 0.09759696621087291, 0.038910260679380554, 0.03894289219451528, 0.04007590942144875, 0.019030725290518136, 0.025295089449613326, 0.09089156714898926, 0.015100901082698858, 0.0304144011404846, 0.008719960366556001, 0.0647318019201198, 0.028331365939530156, 0.023738371974398053, 0.01031345772301598, 0.04013611244097833, 0.0467060326838926, 0.05012537037292796, 0.03767790866174525, 0.03205164786308043, 0.01411123614337656, 0.03805300446167108, 0.04247655318449101, 0.0641249415404614, 5.084818505471753, 41.83279568149198, 55.99742750967703, 40.49272183449038, 26.581488847732547, 44.65786710862191, 45.70559886194045, 52.76326464068506, 6.912784211097225, 0.13462542766524901, 0.8031048024854353, 8.897261311930995, 4.646101891994476, 0.7655466371966947, 3.6870115370519705, 25.363596831598592, 51.55080902960993, 54.377017944089836, 52.45091061438284, 50.99922180175782, 51.89842516376127, 50.13839883189048, 52.041058232707364, 52.120835319642104, 54.04251821579472, 53.6358743329202, 51.72826490094585, 48.48164066191643, 46.49920809653498, 43.45309149834418, 42.99799457673104, 41.50378727143811, 40.50499885312973, 39.79762684914374, 38.62979996588923, 38.8926693700975, 39.10692491839009, 39.942915362696496, 39.60978454159152, 41.152146785489975, 40.28061966742239, 39.7579756090718, 41.255658134337395, 40.8197808265686, 39.21076574633199, 39.934309682538434, 40.27492046356201, 39.12485015007758, 39.43615298117361, 40.81550544308078, 38.779936528974964, 40.34562510828818, 40.39081865741361, 37.94471486922234, 39.6620971925797, 38.93507019166024, 42.875879426156324, 47.950496827402425, 50.70235329289591, 50.859581501253196, 53.993731775591456, 52.8869055932568, 53.284763366945334, 53.578572427072835, 54.09931805826003, 52.62609151101882, 51.395749891957934, 52.16217317888814, 48.105438293949256, 43.98773800942206, 53.46845972922541, 54.40153275766681, 51.973448338047156, 52.434789672974624, 51.792423109854425, 49.73537137431484, 51.58562790962958, 54.88752226675711, 53.07969793196648, 53.4468827709075, 51.157010909049745, 42.76374670767015, 38.22949855558334, 37.50651159594136, 36.94708747248496, 37.99723540582965, 36.9861582017714, 38.14664633043351, 38.528167432354344, 39.109180281239176, 40.689577748698575, 38.639013613424, 39.914693909306685, 37.978851256832, 39.12311254009124, 37.006640818811235, 37.49086133895382, 37.225622823161466, 39.97420018719089, 44.37599774329893, 49.91493748080347, 48.685337189705145, 48.82053736717471, 49.014267152355565, 44.35039643318423, 46.65682069716915, 49.79159462836481, 51.80815965898576, 49.65021671787385, 49.79912557909566, 48.320325343839585, 51.12129772863081, 49.044626297489295, 49.56701540177869, 50.53130265205137, 50.18577714120188, 47.53683582428963, 47.89585036616172, 48.96838718844999, 50.65319814989644, 44.41609613357052, 39.69650814610143, 15.455782932619895, 3.478202690039912, 1.1777519506792868, 0.6609099358320236, 1.2706867509311246, 0.04555603894855707, 0.07785193862453585, 0.17938852730777957, 0.17837237296325548, 0.07947184686218539, 4.66920220082806, 32.214049677695, 40.018652408353745, 43.991597621671616, 35.29961747507895, 43.277577200243556, 6.076688843388712, 0.03475735932889004, 0.04139374919055451, 0.04220271888639658, 0.02075378726717205, 0.031010942315802942, 0.05759427181234764, 0.06355199587321089, 0.02772159825619911, 0.020182306743076733, 0.03815595135693589, 0.053133713381905714, 0.13386267988431838, 0.030893305684590054, 0.019510056928641373, 0.0748287411707063, 0.03674972419356627, 0.1426434724201118, 0.1742787361745873, 0.1570837241747687, 0.1350242836821464, 0.1956596525926744, 0.1105116151513592, 0.17027096252047247, 0.18347393631214098, 0.13569638793987615, 0.12987537609954036, 0.16110501161986784, 0.14064353860674367, 0.08427680394942723, 0.2056214309507801, 0.2515417370464533, 0.16749038511226255, 0.11120232768476972, 0.11164403866015135, 0.16573670260127515, 0.08735257801750014, 0.2798314488703205, 5.264169862193446, 50.50370877788913, 62.6743370486844, 52.18003565265287, 30.33101781722038, 43.303484455231704, 51.07064424022552, 61.130751025292184, 9.872112485670275, 0.36780901673820715, 1.7147952750805886, 10.495536942635814, 7.72272619508928, 0.716315069265904, 3.6097641337302426, 25.417760841308105, 55.85312351103752, 52.74053842790666, 53.16287963621078, 51.63634415595762, 53.495975155984205, 51.48988677609352, 57.18807866496425, 52.87634657275293, 56.65462847678893, 55.381446730706, 54.39231126539169, 49.739693826244725, 48.2966773740707, 45.5765607280116, 46.08375849262361, 42.8339022205722, 42.56789492022607, 41.74000024795532, 41.99713906934185, 40.08017086213635, 42.39326707778439, 41.845017786948915, 42.15115093415783, 42.41683267777966, 42.93053373213738, 42.34006012639692, 43.76980720027801, 42.91289483347247, 41.84919511118243, 40.189463784617764, 42.548996940735854, 40.816689998872825, 41.232657355646936, 42.17643060991841, 40.67107985096593, 42.45063566392468, 43.538799208979455, 40.05559721300679, 41.23068832582043, 40.961601964889034, 43.73765945434571, 48.52645374113514, 51.42204546159314, 51.51612743254631, 57.67437019655782, 54.81866898075227, 56.55110143846082, 55.486895730418546, 56.74905169394709, 54.04118460993613, 55.092320980564246, 53.476253478757805, 49.2440592089007, 46.40127828044277, 55.225622730870406, 57.07291395433488, 53.76930552144205, 53.51288449379706, 54.87752414518788, 53.105891519977206, 55.14823828974078, 55.90727967600669, 55.561809078339614, 57.617233030257694, 52.24555884638141, 44.54849181636688, 39.809488096544825, 38.22721181377288, 39.27983868506647, 40.312312418414706, 39.03782060069423, 39.926606147520005, 39.14650947816911, 40.737316916065836, 43.08907593450239, 40.35222253491802, 41.3993816221914, 40.0918242239183, 40.90426475771012, 39.92028720917241, 39.906617749121885, 39.09121974822014, 40.67856373325471, 45.78382269028695, 52.28727717553416, 50.48044127802695, 48.595499223278416, 50.23451651296308, 46.54499000118625, 46.609501223410334, 49.69919927658574, 51.200957144460375, 51.22911191755726, 51.982097164277114, 49.887861359503965, 51.61286484810614, 49.626270647971864, 50.29771766354961, 53.52641667089155, 51.95518970489503, 49.670161970200084, 51.22797443020729, 51.43132578942084, 52.82305725159184, 46.694145971728915, 42.25383858526907, 17.164187931245376, 5.7047147904672935, 2.517368841555811, 5.611439356880804, 7.089288417370089, 1.3558760958333171, 0.3169533730514588, 0.9328981152465268, 0.822170892309758, 0.14038175104125855, 6.442461138771427, 37.590901390198745, 46.100095164391306, 50.57376623153687, 44.41671979042792, 51.42629338848976, 7.393330941277166, 0.2040399956486879, 0.13786666906408726, 0.09197288493235266, 0.12836747757729985, 0.16461642158608283, 0.156871517819743, 0.18598751675698066, 0.16476830617795069, 0.12480509212060321, 0.14982252832381956, 0.12963388986404867, 0.2536233511543082, 0.183347761631012, 0.19173666955001895, 0.17351220391931074, 0.08182171431760635], [0.01348615627765896, 0.05340078695406837, 0.04934778346890404, 0.030134332801906333, 0.06159307457686913, 0.054991204637072744, 0.045601770567197, 0.05759529837016618, 0.02985716602134128, 0.04721183457501954, 0.026812305516232888, 0.023310065622471517, 0.018966069384928674, 0.08199548604147089, 0.09972037807587655, 0.021634602603772958, 0.04172673696772226, 0.10465280453283941, 0.10312145605923669, 0.020999781930098133, 0.055087475076077454, 0.1744718669402984, 11.789347414047489, 43.026831842237904, 42.47911599374587, 25.963433134940367, 36.6579617223432, 29.612945587404315, 46.15663613042524, 15.216377146782415, 0.15925336178512345, 0.17464134091090772, 3.950897815727419, 4.927897222580449, 0.8260047027180273, 0.46991039608274743, 3.7553308904170994, 30.491695750144224, 53.3283644337808, 54.07309309128792, 53.13918459799982, 53.49655174439954, 50.18876990964336, 49.73956046565887, 51.28305235216695, 52.426038865120184, 51.51583325478339, 50.90851306915284, 45.712102151686146, 45.93370822168166, 42.72247160634687, 40.78564051658877, 39.306632395713564, 39.52169595226165, 38.166164044410955, 36.16602982244184, 36.268823377547726, 37.56629243973763, 36.90199198261384, 36.67222738265991, 39.12739184594924, 37.47415596438993, 38.10309233204011, 38.0462218869117, 36.94558128233879, 37.101683770456624, 38.5123053673775, 39.220410854585715, 37.228223354585715, 38.2841803181556, 38.16234365586312, 37.044880005621145, 37.97981223752422, 39.18775712290118, 38.47676084887597, 36.534391372434555, 39.137974400674146, 39.35302619011172, 42.934189381137976, 45.385831556012555, 49.29349676255257, 48.15984156823928, 51.81680456284554, 50.44157843435965, 51.263244382796756, 50.65469257293209, 51.36519855068576, 51.28324454830539, 50.28212624211466, 44.22219768647225, 42.81248607943135, 53.31298874270532, 49.80774694873441, 48.65604100688812, 46.578745918889204, 49.25855628905758, 50.4566599476722, 47.3632356428331, 49.15688453182098, 50.040720047489295, 45.68114680628623, 40.16019505839194, 38.00938690862348, 37.7051325767271, 36.538490249264626, 36.075889833511845, 35.64769252654045, 36.07746662632112, 36.83059700073735, 35.32220640490132, 36.467393367521225, 37.76980461612825, 36.518450860054266, 36.79620958143665, 35.69446679084532, 37.46759776146182, 36.837398390616144, 35.57181819792717, 35.42741221766318, 37.29596268746161, 41.1391088270372, 46.57092863513578, 46.580106981339, 48.357870271128995, 47.38273374495968, 49.554503040929, 49.28156883485856, 46.989218035051906, 45.13325445113644, 47.28440384710989, 47.5653475330722, 47.81626547536543, 45.788121607995805, 49.559715870888006, 47.286631753367764, 50.31458777766074, 50.23233175277711, 47.93378753046836, 44.30819957487045, 45.328278618474165, 48.08712082524454, 41.75749009655368, 23.277645072629376, 3.862865120172501, 0.9355690654727721, 1.7723027376397964, 1.276439029362894, 0.5543379737965523, 0.13902975907248838, 0.14433159312653926, 0.061081006086521575, 0.11535581892296193, 0.09502552314511231, 7.101464434977501, 34.29030141522808, 31.171734717584428, 55.204975374283336, 42.925348358769575, 26.670150103107577, 1.577983738914613, 0.016579918090193983, 0.02230139595696763, 0.05794705147103918, 0.0353260378864023, 0.05596845703680189, 0.03320986172184348, 0.051005402384626294, 0.04887894148968401, 0.048275072683369925, 0.05210707895457745, 0.04990047377143657, 0.0275888160667232, 0.0327798106046694, 0.043204168173214125, 0.014829919504512463, 0.03472657791609245, 0.07354865421450908, 0.020492673859060295, 0.04735084122888023, 0.0324744479580512, 0.054848022804024725, 0.04807116689100381, 0.03756554654589103, 0.050851928160315564, 0.027411076007410887, 0.054427283485570264, 0.01131335280895714, 0.03511946227762007, 0.0454864053866796, 0.1039613412332631, 0.02553958449542763, 0.037405939787746444, 0.03414347392296599, 0.0008368687626751772, 0.0891224862707238, 0.025610976229091326, 0.06238098834611236, 0.29172318657079055, 19.148191405880837, 51.757533627171675, 48.445209687755955, 22.134856639369843, 37.72296759390062, 41.36781830941477, 52.00366627785468, 16.468500668002715, 0.17259400157678514, 0.2516228657576346, 5.26236851369181, 6.38239102017495, 1.2767025636088465, 1.1147087980662624, 5.35167254747883, 36.49111193995322, 50.884719971687566, 54.25159623545986, 51.945960367879565, 53.70210747564993, 51.80988942423175, 51.67823899176813, 52.26835958419308, 55.36689081499654, 53.007659681381725, 52.31825213278494, 49.061221845688365, 47.26215616349251, 44.108798042420425, 44.20101296517157, 41.03912368897469, 40.811343808327955, 39.419035757741625, 38.102194109270656, 38.44874728110529, 38.36351809963104, 38.92422483813378, 39.443428977843254, 40.0672427300484, 40.384091792568086, 39.35052764031195, 40.06606994136688, 38.30798126036121, 38.67670366840978, 40.504469333156464, 40.63535490343648, 38.678437356025945, 39.4907170726407, 39.45589819262105, 38.25459387994582, 38.34540459417528, 40.98424580789382, 40.28660128193517, 38.367565985648866, 41.47480880060504, 40.738619142963046, 45.57360718327184, 46.47148478415705, 51.63555575955299, 50.60219557054582, 52.84521864306543, 52.297283141843735, 54.322183209080855, 51.96082222846247, 54.12033019527313, 52.08425137304491, 51.92578761808334, 44.82428935266311, 44.892864150385705, 53.88829454298943, 52.38472061772501, 52.01633553351126, 50.11419780792729, 51.240851571483, 53.045110471787, 51.390741025247884, 51.05428403423679, 53.51144106157365, 48.29077812933153, 43.05582208018149, 39.190585151795425, 39.936066904375636, 38.54202516617314, 38.362757159817605, 37.469123563458844, 37.97241856974941, 38.35946236887286, 37.10595523157428, 38.53498058934366, 39.80802505247055, 37.453606667057166, 38.30740467194588, 38.47359549614691, 39.56238662042926, 37.81542178123228, 38.60289642887731, 38.9232167889995, 39.79696789095479, 43.58268268646733, 48.40870811093239, 48.29435925329886, 49.52632865598125, 47.832704128757605, 49.686777130250015, 49.210248378015336, 47.63367914384412, 46.141582073703894, 46.729306097953554, 48.04987399808822, 50.82120895385743, 47.6810888321169, 48.952650639318655, 49.52295149526289, 51.28599412979619, 50.85905982602028, 50.08124205373949, 47.63268286182035, 49.0283170823128, 49.903586141524784, 44.729450364266675, 28.045466446107437, 5.986119354924848, 1.2435901597622903, 1.8162430894951669, 1.5342023656252892, 1.0185565511065147, 0.14755818692426528, 0.021121580333959673, 0.06132066520231386, 0.07095854924691301, 0.07509080452784415, 6.795429347022888, 37.57128561696699, 35.92259184006722, 58.9195187630192, 44.83125548208914, 34.85729963548722, 2.341350518888043, 0.04062571157250674, 0.06316828158413691, 0.011514537073972245, 0.09485807930750233, 0.0976859320015196, 0.060712372238237056, 0.059492304440467596, 0.02822602693472178, 0.0477149206844549, 0.06541399555581232, 0.08434660222020843, 0.005407224290989219, 0.06693982053548098, 0.060724809675687746, 0.016435657988392537, 0.03979815658362162, 0.18280370130894646, 0.14240436105718537, 0.18590022869888814, 0.11532423311784384, 0.21486115611849294, 0.24441860556121797, 0.25244199760979225, 0.24425473935421438, 0.133332347857856, 0.20962393391997586, 0.08642007281342823, 0.0996561722469426, 0.18128525375598864, 0.20616308575676334, 0.1689075864851475, 0.14187885538464592, 0.15683477624289452, 0.1284650618570947, 0.18219973291120223, 0.19247395256834646, 0.17838867531428415, 0.373421223653901, 22.90602795539364, 61.42280286358249, 55.69333399495771, 36.27152981296663, 47.61783276834796, 41.235971758442545, 58.39841227377615, 18.879291357532626, 0.25351461263433583, 1.1998016771770295, 10.212348680342398, 12.626449850297744, 2.9663255378123257, 1.0002998178524356, 6.674529150609048, 39.4227933883667, 53.507240203119096, 55.960851407820186, 52.96092856314875, 55.602421299103774, 51.10780085286787, 51.76542935832855, 54.56727643166819, 56.53122286642752, 54.583789610093646, 54.65875394882695, 51.60399244677637, 50.52740773847027, 47.24237565071353, 46.39364142571726, 44.68740647838962, 44.239820895656464, 41.38841467518961, 39.38306762326149, 40.407069037037516, 41.5473138132403, 41.932969093322754, 40.79709383749193, 43.442701139757716, 43.46618829234954, 40.69384920981623, 41.893957199588904, 40.11933180593675, 40.5009509671119, 40.74314163577172, 43.34535575682118, 39.588760637467914, 41.83347425153179, 40.23840319725775, 40.65624544697423, 40.0677957842427, 44.09656809222314, 42.63389272074546, 39.61968460390645, 43.272572255903675, 42.12292948076802, 47.455729053866484, 49.753171090156805, 53.74211565140755, 52.04402746692781, 53.37885318263885, 53.88376028307023, 56.33279408178022, 55.00306352492302, 54.865996299251435, 55.18293165391492, 53.59650942587084, 46.43246504568285, 49.11622132024458, 56.144841947863185, 53.86019468307496, 53.65089308831, 49.84566842356036, 54.356041108408284, 55.65779339882636, 52.41280478815879, 53.492193991138095, 53.98967604483328, 49.92520232354441, 43.76943457511164, 41.60529428912748, 41.88385709639519, 41.187942335682536, 39.987042027135054, 39.193656367640344, 40.417894778713105, 39.185948910251746, 38.42687614502446, 39.73646140867664, 41.9801434393852, 40.09922181406329, 40.98948217207386, 40.90553952801613, 41.814623340483635, 38.84593825186453, 40.216124134679, 39.98997596002395, 41.509137384353146, 44.96038383053195, 50.13539429633848, 50.3118734975015, 51.1045374408845, 51.057567058071015, 53.45740649007982, 50.02548556174002, 49.18230933527793, 46.38425127152474, 49.33545827865601, 48.834928543336936, 51.59127220030754, 48.076644174514286, 50.91997815716652, 50.49636610092656, 52.76543763376052, 53.047452126779866, 50.6011914437817, 48.96063658498949, 49.51082352669009, 52.516335748857074, 45.577286366493475, 28.544099715448198, 5.749121414076898, 1.9456369333690213, 5.28531143742223, 4.372966664452707, 3.4901617515471677, 0.5591046954354932, 0.5312107599550678, 0.4172587665098329, 0.4156180513241599, 0.215500456491305, 10.844639655082457, 46.89176674812071, 40.114099364126886, 61.83032927974578, 55.091395301203576, 39.262097804777085, 2.7175521514108105, 0.20272607824975447, 0.17834084078429208, 0.1789644363546564, 0.1964790295929678, 0.2178958295694282, 0.167470206356337, 0.11900784432767861, 0.1268700208334673, 0.11402693982686728, 0.11903268089818379, 0.21685358227020313, 0.09428540560146494, 0.1839756166502353, 0.1506983353606155, 0.07990001340306575, 0.22522513063684588], [0.045716660773201336, 0.07167800539924253, 0.053277580863645965, 0.059991039170493046, 0.025577348799655036, 0.07755039875665981, 0.043889073760158596, 0.0060570650760294695, 0.006918740184647182, 0.041414782134515625, 0.04945454931247139, 0.07022106704572517, 0.0436590405391349, 0.016618532752017343, 0.05237074726591668, 0.0537375821882198, 0.024634355851899714, 0.034181364631700906, 0.05214776588423599, 0.14602224192311689, 0.013582159543500073, 0.05548842634344774, 3.0201914473887417, 25.70971069797393, 47.05934609136274, 31.71413575449298, 31.07867648524623, 28.633135557174686, 42.48165376724736, 15.712238281003891, 0.08805488912208427, 0.21293787706282832, 4.668662874929367, 4.650467980292536, 1.402975916862488, 0.5688398956291137, 1.3970047211454761, 13.563730601341495, 42.124204251074026, 55.271459548704094, 56.02637852391889, 54.04376945187969, 53.81861755924841, 50.9848149361149, 49.7726103567308, 53.561153181137584, 53.88282283659905, 50.74403239834694, 49.25494770849905, 45.217640323023645, 45.01350056740546, 42.75333673723283, 45.038658649690696, 42.05548824802522, 40.75423017624886, 42.19850570924821, 42.0400341095463, 40.16930280193206, 40.10831779049289, 38.389441044099875, 37.77670014289118, 38.61373393766342, 37.837963642612586, 37.727392027455, 37.38415718078613, 37.684967671671224, 41.254834436601215, 39.40602917825022, 38.22809042469148, 40.00794433778332, 38.45024170414094, 39.26943263699932, 38.643065421812, 37.72031214929397, 36.81155389355075, 38.32187821788173, 37.47510517797163, 38.74722788410802, 41.30697450330181, 43.921140086266306, 45.63531783319289, 48.95331744224795, 50.38543755008329, 50.26600137833626, 49.52681502988262, 50.83823596277545, 50.20831115784184, 48.71324485348117, 47.0304617574138, 41.29080257108135, 45.57187349565568, 52.99556701414047, 50.08521541472405, 48.55017623593731, 44.556999437270626, 44.895539206843225, 41.12756529162007, 43.09892892837525, 41.984308996508204, 40.36149501800537, 37.18409276777698, 38.67827261647871, 36.2360990432001, 37.059785012275945, 36.108618090229655, 37.44033336639404, 35.878900558717795, 37.56343695425218, 36.56189110971267, 36.30916495477, 35.94971110743862, 38.377054199095696, 35.539897949464866, 37.63886805503599, 36.88503557635892, 37.62630862574424, 39.162348008924916, 37.096725894558816, 35.105801397754306, 36.05910208917434, 38.1522866987413, 40.05695043071624, 42.42837621319679, 45.14479014181322, 48.74838929022513, 48.79994100139987, 47.3895037558771, 49.169942102124615, 48.19241293015019, 49.40311916412846, 45.3329776179406, 47.2198377117034, 48.41441123716293, 50.27674082786807, 48.64212443751674, 50.97931185076314, 48.501044627158876, 51.92361462500788, 46.2215905804788, 48.81364968515212, 48.61109848945372, 33.463548152677475, 9.973352782187924, 0.49078638394994123, 0.12455528617025384, 0.17065654989452134, 0.35385294787345395, 0.0729103880603948, 0.11856839331167361, 0.0389086940295754, 0.07059048230369246, 0.10034921368764294, 0.10961973558991187, 9.77463766451805, 34.09061747212564, 27.32071049751774, 44.5907239760122, 44.70648096453759, 11.151481770700025, 0.03829636761257726, 0.02452170645307389, 0.031200786564318888, 0.0303301410449128, 0.004059024936249179, 0.09102919484458624, 0.016432882834886833, 0.018624779129881534, 0.042183930580053604, 0.04431198876831801, 0.0427554245106876, 0.03225233608616456, 0.02126248305543296, 0.01602846118921955, 0.05491893956317537, 0.0321413988938495, 0.049440529903457056, 0.042514018714427955, 0.02164589282455704, 0.029604339769350427, 0.054159991578349186, 0.040779151322860877, 0.04147749792243685, 0.04271638083962664, 0.028550334935707432, 0.036626813046994715, 0.025098149311698736, 0.050755420234054334, 0.11942052057073002, 0.045551641603871706, 0.024899991093984535, 0.09894161139644923, 0.060724081892159686, 0.0357904710296181, 0.05708647809261757, 0.04466291832467241, 0.060118447253180135, 0.06429844130311282, 0.01046390398480599, 3.8917950516746895, 34.41906890561504, 53.170536102787146, 33.89163955565422, 34.84240247357276, 34.275263047987416, 52.21525853680026, 18.868251846682643, 0.363130854863313, 0.23112921705169065, 3.5309178742670246, 5.047019604713687, 0.9950512575526392, 0.5625856763893559, 1.1757280076703718, 16.78194707439792, 47.10008775034259, 55.80428215765185, 54.51999225924092, 54.59612154191541, 52.377134753811745, 52.19691361150434, 51.59298627607284, 54.09734118369318, 54.167700659844186, 51.772050319179414, 50.1559788950028, 47.623331931329545, 45.75505994981336, 43.8690157090464, 45.396543548953154, 43.48655716065438, 42.44883137364542, 42.854714316706506, 42.298424167017785, 41.364570586912095, 40.95381213772682, 39.773943578043294, 40.13862594481438, 40.82270299234698, 40.488277789085146, 39.339505780127745, 38.50406839001564, 39.72080330694876, 42.038202362675825, 40.0516434638731, 39.05219216500559, 41.62072881575554, 38.99774574464367, 40.05140812166276, 40.74214143137778, 40.32333035622874, 38.94347975330968, 38.943024758369695, 39.74250578111218, 41.56508607249106, 42.867156074893096, 45.252671011032604, 47.59301985463789, 50.69219827651978, 51.20277712422033, 51.192096510241115, 51.628923031591604, 54.5945212148851, 52.902434256769, 50.55287961036929, 48.366711293497396, 44.747473655208466, 48.63336970729213, 53.942638981726866, 52.02972258290937, 50.37673773304109, 47.416171950678674, 46.89415154918548, 44.0251221195344, 44.8929072964576, 45.56935141163488, 42.24566436582997, 41.01009814969955, 39.257763585736676, 37.66767786395165, 38.3353986278657, 36.63849892154817, 39.673887837317686, 37.740429985907774, 38.49763570293304, 37.879234821565696, 38.298324384996974, 38.096918521388886, 39.68734156700873, 36.96327509418611, 39.27030732554775, 37.61462780737108, 38.68437190209666, 41.2665819352673, 38.14335938422911, 36.99262226781538, 38.39765056487053, 40.973059208162375, 43.08070951892484, 44.972554945176654, 47.556404529079316, 51.16516159426782, 51.62529091681204, 49.6545313250634, 51.58314897168068, 47.62643844850602, 50.63390401101882, 45.418610803542606, 48.79477523988294, 49.236100719821074, 51.3497914806489, 50.38732421013617, 51.2228714266131, 49.97130586254982, 55.1236960195726, 49.064398965527936, 49.643933080857806, 49.76884880373555, 37.172317812519694, 12.102572206527958, 0.9556239603027221, 0.4068495008733965, 0.687038743447873, 0.7495034690345488, 0.09732943298595567, 0.05795140285044909, 0.10920950316733892, 0.0430173154980425, 0.29888696668128817, 0.4745693751160176, 10.948262791479788, 42.087851724317, 31.809421893089052, 49.007438305885564, 51.05315046925699, 15.936047742443701, 0.22507067198955247, 0.06368431457949263, 0.08456960275408723, 0.03969890223215184, 0.006624045312374591, 0.019564359155934186, 0.028838112034023772, 0.031156202162345572, 0.03179556382219157, 0.04832463474163125, 0.027265825736967307, 0.0692255357881227, 0.0511292711411032, 0.04459929089212129, 0.04398770758040971, 0.06891436619503845, 0.030471013122869116, 0.14589793649652313, 0.14214082681123288, 0.16724905209435573, 0.13877989183510506, 0.1647188935068346, 0.11060878574367493, 0.13371087190124298, 0.1543732897769059, 0.10448067223713284, 0.1697930921950648, 0.20665768744243732, 0.2198493844198604, 0.12480912174308494, 0.1100640052989606, 0.24668579680785058, 0.127783871796583, 0.12163145798108271, 0.1835273479622218, 0.18741542803904704, 0.25946322407933975, 0.28847334966544186, 0.08481003178824341, 4.684223897995488, 42.177940722434755, 59.57358183399324, 44.307724968079604, 45.06712721240136, 38.17658970432897, 55.818661566703554, 20.63779777096164, 0.5722928071214307, 0.6062411661109617, 10.5993365856909, 13.844460518129411, 4.1204037781684635, 3.433353574045243, 2.399927930485818, 18.59902624161013, 47.29434313312654, 56.92522102786649, 53.67353300894461, 56.43623875033472, 54.03015490501158, 53.32828990874752, 52.9638546512973, 57.37385388343566, 57.24168962047946, 53.639008306687884, 53.285916543776, 51.84896799825853, 49.43728300832933, 45.74902342211816, 49.206416222356985, 46.37821866619972, 45.50135320232761, 45.75344001093219, 46.07161875694029, 44.632336401170306, 44.36292840588478, 42.86285323481406, 41.09213059948337, 43.398719603015536, 43.08476524968302, 41.93610698946061, 39.786240208533506, 41.878554051922215, 44.44608265353788, 42.78753588276525, 41.26755076069986, 44.50681663328602, 40.88759860684795, 42.587008630075765, 41.105690233169064, 41.20336117282991, 39.89857296789847, 42.79881661938083, 41.58388599272698, 43.296106476937574, 44.72754016999276, 47.3278715533595, 51.05190707791237, 52.35057246300482, 53.97017402033652, 53.4974774237602, 53.420096905000754, 56.731424562392704, 54.01424184922249, 51.445112920576534, 47.80085840532857, 43.50869501790693, 51.84330409572971, 55.905608746313284, 53.84880412009455, 51.360711359208636, 49.15123239640267, 49.40362514988069, 45.39229562205654, 47.38915074256159, 46.43373981598885, 43.94040676855272, 41.74301655061784, 40.664780524469194, 39.602704663430494, 41.192260865242254, 38.91066520444809, 41.98548178518973, 39.63804521868306, 41.217163993466286, 38.876116967970326, 39.112212273382376, 40.85236003321987, 42.53848891104422, 38.6570212148851, 41.222086568032545, 40.08363823736868, 39.775598818256015, 42.440908185897335, 39.73996016287035, 39.6699890013664, 39.774049482037945, 43.4721306831606, 43.96373702633766, 47.24779244392149, 49.911450493720274, 51.68568365035519, 51.4231986384238, 51.83346679133754, 53.433358438553356, 51.25649790610037, 52.880974969556256, 45.505330485682336, 48.67195014030703, 50.188212933078894, 52.331368538641165, 52.20066731975925, 53.97892875056113, 50.96276337100614, 56.528896900915335, 52.007502355883204, 50.75963558689241, 51.56153671203121, 39.7368928693956, 13.038068279143303, 1.268089529006712, 0.33454066803378446, 1.09786540510193, 1.8164955920750097, 0.6062769577387841, 0.23246711300265407, 0.32495062618005666, 0.1617103436541173, 1.184743820659576, 1.1388147045527737, 14.980848623860268, 45.096517532102524, 39.092015989365116, 53.76166866671655, 57.01270557218983, 19.239896420509584, 0.3427507710312644, 0.1492009399038169, 0.18633015724199434, 0.06889256333271343, 0.15075926999411277, 0.17192254083291178, 0.08824726912162958, 0.20732717167946602, 0.0877556705006188, 0.1880619449601058, 0.12327901433191954, 0.14798817675440543, 0.1401423485649209, 0.12349217063597134, 0.12532354978423926, 0.15033216065456792, 0.10532268713558875], [0.016927543892374924, 0.09124596708364065, 0.022514529278381698, 0.034433947650775794, 0.03570702873290547, 0.02289553927708297, 0.06810628133074892, 0.03125312186086611, 0.048065846410369685, 0.04530067119987742, 0.04161301504580244, 0.027277399410283374, 0.050073425781222126, 0.06964684584208074, 0.08504152057632323, 0.036163065552471146, 0.02319721895600519, 0.016052906097273435, 0.02854767469539037, 0.0390402581392517, 0.07775550347662742, 0.02868561265659669, 0.25972556322813034, 15.55111712025058, 47.6715810068192, 27.089382833050145, 21.31285140591283, 32.74589953884002, 29.691128230864006, 18.746262211953443, 1.1778402040081641, 0.0920187965816548, 1.9051061017859368, 2.2523144320134194, 0.45080119083004616, 0.0696560388971721, 0.3629883318658798, 2.0260929580657714, 21.973043180281117, 48.212354260106245, 54.04849198556716, 52.143604678492395, 50.43927992543867, 52.02653761832945, 51.224416840461, 51.35741264589372, 51.10064252730339, 50.44344940493184, 50.0983278982101, 48.19862596450314, 47.846040187343476, 47.990359875463675, 48.17198130392259, 48.5308938641702, 50.114601812055035, 47.165132414910104, 42.96477210137152, 43.682867865408625, 41.1365867430164, 42.48264612690095, 40.718564064271995, 39.15966118535688, 37.80864392557452, 39.49945219101445, 37.17063903808594, 38.67633104324341, 38.13096469448459, 38.49969886964367, 38.04682985428841, 44.381602810275176, 42.585243563498224, 38.06147990688201, 38.830044807926306, 38.73653158064812, 38.423624500151604, 37.25310294858871, 36.554626880153535, 37.189988090145974, 40.28123155716927, 41.66234124091364, 43.747508525848396, 46.80067362323884, 48.21577064452633, 49.34926502166256, 50.74065523762857, 48.54735212941324, 50.8602326147018, 46.18300622509372, 47.52498242162889, 42.412023851948405, 45.29207906415386, 53.14412678441694, 48.6727895275239, 47.72634906153525, 41.385319925123646, 39.495553355063166, 38.93591742361746, 37.5212557854191, 38.34420827127273, 36.74401852392381, 35.35326765429589, 37.25014940384896, 35.66464893279537, 37.34338806521508, 36.72738375202302, 35.889530181884766, 35.65213264957551, 36.57810618800502, 36.49151986645114, 37.798492831568566, 35.86929859653596, 35.96395715590447, 36.996281839186146, 36.56411901597054, 37.463628322847434, 37.28282274738435, 39.135318956067486, 40.976554039985906, 37.82507081185618, 35.03133127766271, 36.16496686012515, 37.51598019753733, 36.47333575833228, 39.35163767107072, 43.96003038652482, 44.876817734010764, 46.395449638366706, 49.2840987636197, 46.964475724004934, 46.779398687424205, 46.09198762524513, 47.033721247027, 46.32373694450625, 48.0056296625445, 48.5234845069147, 50.796921637750444, 49.46437089673935, 46.81543742456744, 44.329545113348196, 51.60987992440501, 41.58416448100921, 20.29608480391964, 2.1874619635843464, 0.2656972798849306, 0.9814629415350576, 0.11746414651673649, 0.2005564712829167, 0.07341999740850541, 0.11383354859126192, 0.16778295409054528, 0.05960639408459106, 0.3672836336397356, 0.5146921882706305, 19.972297068565123, 35.6100966084388, 26.447492837905887, 38.70441913604736, 33.01213433665614, 4.359334466918822, 0.15452692104924112, 0.02988410167275898, 0.11345504753051266, 0.013101378083980132, 0.013506086055009116, 0.028795176636307474, 0.03937420352632481, 0.051624370783927946, 0.038665813514061516, 0.03150619326099273, 0.041652338338955756, 0.057044756944261255, 0.04661050151973482, 0.06542999147167129, 0.04407492286014942, 0.10842722780521839, 0.02691344827443602, 0.0308588796084927, 0.053873244868291, 0.03591568427040212, 0.03899587100491889, 0.02390716412675477, 0.06280866076028155, 0.05619348387324041, 0.06743304326289123, 0.02791805767394122, 0.044569578171978076, 0.0199451259217195, 0.05317891256943826, 0.06783769090449618, 0.1006430620327592, 0.039527141489088535, 0.05404670249610659, 0.023247187040866386, 0.05204704830483083, 0.014143878192220245, 0.08653573676823609, 0.03388058702130953, 0.06538636276438352, 0.6711376999174395, 21.07799360829015, 54.63853413058866, 32.03306563438908, 27.71994894550693, 37.04196176221294, 36.285007076878706, 19.41672471261794, 0.4434638151959066, 0.10863632384327152, 0.9008559668737074, 2.4813693281142943, 0.32542428302188076, 1.0279445602528512, 0.14229145501890492, 3.729260366770529, 26.7357890067562, 50.9351694968439, 53.277828616480676, 52.63812534270748, 53.754161250206735, 53.42585102204354, 52.34414762066257, 54.282426065014256, 52.75887943083241, 53.08946463369554, 51.31993439889724, 50.063218762797696, 50.37327820254911, 49.6842707357099, 50.46559510692474, 49.99361238171978, 51.48942785878336, 49.73080181306409, 44.45025605540122, 45.71255322425596, 41.8618094536566, 43.491338529894435, 41.12339973449707, 41.36076196547478, 39.446186404074396, 41.28071031262798, 39.151239856596916, 39.60532872907577, 40.05096489383329, 38.818764071310724, 39.99869538891701, 45.86450192236131, 43.09442212504726, 39.532388333351385, 39.41676862778203, 40.72265509636172, 38.98821830749512, 39.198072956454375, 38.27850464851626, 38.54894030478693, 41.2306373350082, 43.94259937347905, 46.37630062718546, 47.8746146540488, 49.47352963109171, 52.08392973869078, 51.76573138083182, 51.83598495298817, 52.290148350500296, 48.28670278672249, 48.325655844903764, 43.436676379173036, 48.858572590735655, 53.12485225739018, 50.795686091146166, 48.37044931227162, 43.36518333804223, 40.88607280485092, 40.29679159964285, 39.714123510545306, 38.51656113901446, 39.01739289683681, 37.312213067085516, 38.44530736246417, 37.464255902075, 38.159480325637325, 38.18357152323569, 38.60037826722668, 36.705257661880985, 38.353343471404045, 38.45420329801498, 39.218539884013516, 38.62219841249528, 37.86855812995665, 37.34940890342959, 37.29159316708965, 38.459541643819506, 38.55261164326822, 41.96494033259731, 42.5416228848119, 39.70890283584595, 37.12452373197002, 37.80471371066186, 38.65487960077102, 38.413853876052364, 42.036598113275346, 47.03772598697294, 48.479655942609234, 49.222533241395034, 50.96369297273698, 50.10097157570624, 48.715076600351644, 48.743600076244725, 48.08776801632297, 47.14692085020004, 48.21159724266299, 51.59391587780368, 52.222471775547156, 51.96510545669064, 48.902962053975756, 47.61270230816257, 53.911601266553326, 43.348980026860396, 21.164591696954545, 3.343865679156396, 0.894031471783115, 1.7432416518849714, 0.2223365501530709, 0.19819278360134174, 0.2750829907674944, 0.13128145387576473, 0.2354310152511443, 0.004539394623509819, 0.6960175390685759, 0.812939839257348, 22.33404048027531, 41.63656342414118, 31.79476203457002, 44.97575167686709, 39.650408529466205, 6.501984086728866, 0.0784981108060287, 0.029817961471816225, 0.08474016456954903, 0.02750097451010539, 0.003824060503017879, 0.03375065850935156, 0.017895298717062802, 0.015720058131151866, 0.045338213338606784, 0.005765516431100908, 0.05937181413173676, 0.011486274175225727, 0.06589375045751372, 0.09597230822809281, 0.04223173829696832, 0.011993189766672591, 0.002653278732454525, 0.113854753905006, 0.22825320040987385, 0.17672428801175089, 0.10937363750511601, 0.09002188115470833, 0.09369535702130488, 0.16796087035008017, 0.08918679169108791, 0.20472636446356776, 0.1789119286883262, 0.17130990031986468, 0.08699450852169145, 0.16776253018648396, 0.21544937374851397, 0.17322823044753846, 0.1494681513718059, 0.2070676210907198, 0.13924005020770336, 0.09594639913449365, 0.22546791922180887, 0.16350280553583177, 0.12970302163833572, 0.730817542681771, 25.092929755487752, 62.6012711371145, 39.11645235553865, 30.107842799155947, 44.903364335336995, 39.444052634700654, 24.575535789612804, 1.9318076367339783, 0.27392086602987786, 4.726989990280521, 6.518333996495893, 0.741026062638529, 2.698202118758233, 0.9436469416945212, 3.934413809930125, 27.30600553174173, 52.614320478131695, 53.44677294454267, 52.93340136927944, 52.74075023589596, 54.7483761848942, 52.66678217918643, 56.70166553989534, 55.85704980358001, 55.44750728914815, 54.0025100400371, 51.45007471884451, 51.30322510196317, 52.003168136842795, 51.901441466423776, 52.981705357951505, 55.660025227454405, 50.89594187275056, 47.15409878761538, 49.39119908117479, 44.12345986212454, 46.72670948889948, 43.59400264678463, 43.367791714206824, 40.090286654810754, 43.40120638570478, 40.89748297968219, 40.87818491843439, 41.378671507681574, 42.10856183882683, 42.16341618568667, 48.137891984754994, 45.72600695394701, 41.56581955571329, 41.768625705472886, 42.75583136466242, 41.57669236583095, 41.47662878036499, 39.69136591880552, 41.724036201354, 43.44615282550935, 46.44025487284507, 47.47792966904179, 50.327347247831284, 49.796419143676765, 55.11713781664449, 54.188328404580396, 51.909478402906856, 52.310187739710656, 49.97410643485285, 48.66266981247933, 43.98118372886412, 50.26560129657869, 55.997349062273585, 53.33205930648312, 51.960253484787486, 44.57284189039662, 41.520724065842174, 41.77549377564461, 41.07089488737045, 41.40772058117775, 41.13359397457492, 37.81227996272426, 40.04108444336922, 39.95210939838041, 40.389728238505704, 39.90306408174577, 39.40762166054019, 38.848519171437914, 40.82347177690075, 39.10066873796525, 41.64147815396709, 39.789911547014796, 39.71913237725535, 40.82627234920379, 40.10088097664618, 38.976631626006096, 40.83082622097385, 44.3972687567434, 43.55736378700503, 42.130264312990256, 38.0360354915742, 40.24811106343424, 40.56141822568832, 38.970159715221776, 44.1827739438703, 48.59399303313225, 48.670895022730676, 51.22855886336296, 53.47381376451062, 50.65022499330583, 50.71899198716687, 49.6169707082933, 48.8962116549092, 48.49507085738644, 51.473408898999615, 50.303738501764116, 55.82738491796679, 52.60332215216852, 52.82926636357462, 49.70129382225775, 55.24346559278427, 43.39361659942135, 23.63008179972249, 3.2615491026832215, 0.9581811617939704, 3.2087861145696337, 0.557426962881319, 1.020396020143263, 0.8638539814179944, 0.5128212789854696, 0.5219589305981513, 0.2756042063476578, 1.7645265161991122, 1.942342142424276, 28.045537048770537, 47.19278512462493, 36.62115420064619, 50.30751966661023, 42.947639188458844, 7.770525668897937, 0.4912654340507523, 0.1538843877853886, 0.26068038457343656, 0.11778838556980896, 0.08014661710589163, 0.156733667958648, 0.12060272447284191, 0.11399670233649593, 0.10975051445946579, 0.11739732832798075, 0.2454812767645044, 0.119761529288465, 0.19007536192094127, 0.16347396998636185, 0.09809679261619046, 0.20957856619309997, 0.10539478367014278], [0.03823857393956954, 0.06327836075797677, 0.07342646319058634, 0.009052816951166718, 0.05300155172364847, 0.022054843965076634, 0.018642288069390965, 0.0171706025233312, 0.025185720822323236, 0.11239468991275757, 0.0743811849444624, 0.0410708814348665, 0.08160944667554672, 0.026584982331241333, 0.02563988072647443, 0.015989296859310522, 0.03355346747764176, 0.06554617636626767, 0.01575377940635888, 0.01926331724520893, 0.006384401997145747, 0.08969601033435715, 0.0240771935111092, 6.115587478683842, 38.599213323285504, 45.09342278203657, 23.82077370920489, 29.794859232441073, 32.166569386759114, 19.931131793606667, 2.072707385786118, 0.04622829259343205, 1.0404499956677038, 1.8823814824704204, 0.2218980107816958, 0.29030295148972546, 0.6489508130377339, 0.18127947745303954, 5.227099541694888, 31.542337902130622, 51.38514772538216, 53.077015030768614, 53.127644984952866, 52.2543018094955, 48.85758415345223, 52.7748905458758, 52.78927779966786, 50.505124753521336, 49.7267617717866, 50.92388483785814, 50.93791123359434, 50.2449421728811, 51.423594797811205, 51.93127893632459, 52.48658457110005, 51.67484221919891, 48.72109743856615, 49.37276394136491, 50.387320287766, 43.85042759679979, 41.03792344370196, 38.92802169246059, 40.281521812562026, 37.848769772437315, 37.36546316454488, 37.008299981394124, 38.87168076730544, 38.38696210615097, 39.22712595232072, 39.59440492814587, 39.02111914850051, 39.539836914308616, 37.80733777630714, 37.20149240186138, 37.42825246626331, 38.29983057514314, 36.97641895663354, 37.86617725126205, 38.8878526995259, 40.03079606640724, 43.70533520175565, 45.888942210905014, 46.72241057119062, 46.05009671180479, 50.52319903527537, 48.585928640057965, 48.17529962908838, 45.28305761275753, 47.53157984825873, 42.72518196413594, 45.514763785946755, 53.6543643859125, 49.44814405133648, 51.04497232744771, 45.70881912785192, 42.887964248657234, 38.70053598957677, 38.80713816611998, 37.38913466853481, 36.825305723374896, 36.377947638111735, 35.46266648077196, 34.45937125913559, 36.40755368817237, 37.57820075558078, 36.80075953083654, 37.00905699883738, 36.595164575884425, 35.34497968612179, 36.7277838337806, 36.816127377171675, 36.64976396868306, 36.3219871828633, 36.380050028524096, 37.41279832778439, 36.7119296135441, 36.71189431221255, 35.468875592754735, 39.69626888152092, 38.72094800395351, 35.97185680943151, 33.98639225190686, 34.55335909320463, 36.43871691919143, 38.40439704156692, 41.555397818165446, 42.84021331417946, 46.96030624451176, 48.51744405684933, 47.89987864032869, 45.746740602677875, 46.11827535013999, 46.52710791557066, 49.3372311899739, 48.74136040287633, 46.000631701561716, 45.28173185163929, 45.006714867007354, 49.44637506238876, 47.591827454105506, 31.88398026650952, 9.332091346863779, 0.4848967612751069, 0.5100476729773706, 0.6169358761079851, 0.23782566820661868, 0.0771374543828349, 0.06348494402763825, 0.043692001472077066, 0.027509677268925215, 0.08962053535205704, 0.9371785242711345, 4.68016081279324, 24.94059470392043, 29.75133465182397, 29.498755585762765, 38.99094435476488, 15.336631132710366, 0.26066025178278646, 0.01576110991018434, 0.05415523800277903, 0.0638892162861603, 0.013912192136499912, 0.016445559674813863, 0.07422233661336285, 0.014751114912571446, 0.03539747941578108, 0.015973805603871665, 0.03951444358174359, 0.04533949270544033, 0.03315115257376625, 0.041235567355949077, 0.059061763027021964, 0.096399586106981, 0.01908291503035974, 0.036277990232432084, 0.04251442474102782, 0.04021804937491975, 0.0366711963508879, 0.038725882468204346, 0.039611372856363174, 0.05454349902368361, 0.022307528490801493, 0.047209122623767585, 0.029229261206402898, 0.005119489806313669, 0.047682231712725856, 0.06515260635604782, 0.0719401760086898, 0.039026855431016416, 0.06783215974968287, 0.05710083458031859, 0.017648986127648144, 0.08227084102409501, 0.03843322155937072, 0.04501656366271838, 0.09587783426527055, 0.04088249275340669, 0.06727902128571464, 8.331611406418586, 46.396508678313225, 47.31646922326858, 24.9262741304213, 32.645329967621834, 35.76275133317517, 21.436245249163722, 2.088263996185795, 0.02409513720551566, 0.3505505879800166, 0.24864509731771486, 0.4252044772428851, 0.5837703364030008, 0.18881986638711346, 0.32978366038972334, 7.377405628081291, 37.12497872691001, 51.51136567515712, 54.22989376129643, 53.515194769828554, 52.21046147807952, 50.868959888335205, 53.85213813474102, 54.4937555251583, 52.54064267681491, 52.508071314904, 50.508478380018666, 51.7921995347546, 51.81818915951637, 52.85750350644512, 53.61678415729154, 54.155431485945186, 52.93137742627052, 48.86682917994838, 49.923731434729795, 52.07300593776088, 45.84696108295072, 43.80564197417229, 39.916227556044056, 41.80192270586568, 39.775296795752745, 38.413818574720814, 40.17512359926778, 39.64286581162484, 40.545524781750096, 40.54212800918087, 41.56596468340966, 41.238662504380756, 40.13471926412275, 40.558256795329434, 39.680269533588046, 40.44045625194427, 39.96075430224019, 38.84369073375579, 38.35920349244149, 40.589706359371064, 41.9566523644232, 44.570174678679436, 47.84729534579862, 50.35317213304582, 48.58131593273532, 51.79863614420737, 50.06162235813756, 51.108573559791814, 45.86944803114861, 46.62806187906573, 44.47312347350582, 48.3782156052128, 55.17267073354414, 50.550534033006244, 52.14437738541634, 47.68680372545796, 42.88761515771189, 40.939475874747004, 39.97567107600551, 38.93674112135364, 38.38731904183665, 37.685124566478116, 36.84872227330362, 36.64679473446262, 39.147603819447184, 39.107434826512495, 38.41403822745047, 38.384722432782574, 38.02252684870074, 37.39966623244747, 38.59926823646792, 39.51385121191702, 39.294527961361794, 37.894198663773075, 38.65359306335449, 39.18059487496653, 38.80883655240459, 38.147211151738325, 37.425189095158736, 40.51267885392712, 40.00225690103347, 37.50380908289264, 35.6290691129623, 35.74848567285846, 38.33144487873201, 40.45598099308629, 44.45315860932873, 46.0051816509616, 48.08231199941328, 49.56564649458855, 50.92614804544757, 48.1970727059149, 48.6516793312565, 47.84763659200361, 50.26877057167792, 50.38855975674045, 49.980817610217684, 47.81593599627095, 46.815253073169345, 50.013675305151175, 49.696955680847175, 35.78109233610092, 10.663096674026983, 0.9573914783616221, 2.105704324860727, 5.363331302519768, 0.8753470776061859, 0.15057548550107788, 0.03384921572081024, 0.08074182145778211, 0.14921760997704922, 0.09321139629689917, 1.7089700650784279, 4.438233433231231, 30.910375425892493, 34.079293589438166, 29.917256793668194, 43.38450493351106, 20.780795620333766, 0.8007788369732519, 0.015422644604357983, 0.0329641351896909, 0.03136107131027647, 0.06374950100096964, 0.027218424046652454, 0.03007777827611614, 0.03286101209420351, 0.004082718599332316, 0.011474483124461147, 0.08692751413271313, 0.04025715050257502, 0.024110393846527706, 0.05390133348203475, 0.01569613799332611, 0.026440978868894523, 0.030859521207129283, 0.017978949772734797, 0.16047852023714976, 0.15336760019342746, 0.12129222658733207, 0.13642889056955615, 0.13642110711624547, 0.13629686297668567, 0.16360772893794123, 0.10838849439976678, 0.11728685078842026, 0.21650174873009806, 0.14451076577027, 0.12039093946617459, 0.1260709834675635, 0.12433200218384305, 0.18456254725254354, 0.09842600357989151, 0.11531901605907949, 0.31919252548006277, 0.10511463297711265, 0.10749764905701722, 0.13317163793310044, 0.14377074015717353, 0.17017504831235256, 8.999625367503013, 52.52258408454157, 57.15586816110919, 33.7263116528911, 40.297642753970244, 43.15495606391661, 27.02537367420812, 3.2257940019330675, 0.2134504664929644, 3.8105066264829333, 4.855630003636883, 0.7283692482498385, 1.0286833754470273, 2.106540280003702, 1.4569507947852536, 7.6149762349744, 37.91100209759128, 53.114505044875614, 54.041439563997336, 54.4003717360958, 52.89491507314867, 51.366489010472456, 56.11015250605922, 57.3330847678646, 54.90703998073455, 54.83767678660732, 54.18228403214486, 54.132760186349195, 53.60887665902415, 55.98787653830744, 55.70725448669926, 57.544582889926055, 54.91249207527407, 52.490538320233746, 52.09188822777041, 53.73528288256738, 47.58577523692962, 46.12419420673002, 42.97633524863951, 44.7424530213879, 40.788343029637495, 41.6140333298714, 41.61604158339962, 43.162000640746086, 41.66787570522678, 44.42240722717778, 43.087746251013975, 42.18380858821254, 43.229410494527514, 42.06313294749106, 40.7362735656, 41.59562564665272, 42.297427884994015, 41.37095620555263, 41.58358397022371, 42.46040628802392, 43.741397473119925, 47.812378406524665, 50.8027228232353, 51.06015974475492, 50.38206038936492, 53.01230769003592, 52.004172263606904, 52.1779058056493, 46.82831064347298, 45.525369874892704, 45.498415347068544, 50.738070395685014, 55.87632825297695, 53.59461884344778, 54.87343703546832, 50.626769219675374, 46.46563260785995, 44.047879711274184, 41.40078975308327, 39.931309069356615, 40.24610673227618, 39.38249495721633, 39.465194209929436, 37.375484820335146, 39.73704191946214, 41.831501299335116, 40.27452430417461, 40.75177085015082, 38.67253026654644, 38.78410993083831, 40.077891965066236, 40.69417084417036, 41.44806215840001, 40.47514569374823, 39.93751033659905, 41.84085222982591, 41.88234306150868, 41.50511695492653, 39.54498306397469, 43.953264297977576, 42.595084790260564, 39.52537121311311, 37.268859109570904, 37.47773316598708, 39.97958167906731, 41.35594921727335, 45.550829979681204, 47.16122181184831, 50.39347056419619, 52.214183807373054, 51.11457478615546, 49.241627339393865, 50.12944013841691, 49.409481248547955, 50.490772801060835, 50.77219501618416, 52.71217184682047, 50.09147159514889, 50.175178896996286, 50.94004892533826, 51.82812844553302, 35.864073999466434, 11.699028957274653, 1.2508992514302655, 1.4156102389097216, 3.87038087171893, 1.4875675906096737, 0.32533737800775037, 0.1945548005882771, 0.300259551093463, 0.3804614797474877, 0.272385411325001, 3.663971779807922, 8.49797873727737, 33.81066614581693, 38.85369670006537, 38.82031732989896, 50.47237688495267, 23.35745353852549, 0.7508339492544052, 0.13345217933097195, 0.16990970609889877, 0.1343595798337652, 0.0817209431120465, 0.10885128045394536, 0.17316507415906077, 0.15970245784809514, 0.14454061255579995, 0.09103892416122461, 0.1671986894742135, 0.21423979752486755, 0.14617003560546907, 0.157336272719887, 0.14528517340940816, 0.10717393094373327, 0.16413583930942321, 0.15626066995243873], [0.0830316506025772, 0.015917140952942353, 0.03561396054142425, 0.007549116111946323, 0.05382801503724149, 0.050108527929912654, 0.02944920504946382, 0.021896464862830697, 0.01925178953716832, 0.032323187727841644, 0.04757879452118951, 0.05012747328428011, 0.05644584472681727, 0.06482890356452235, 0.03907072162556072, 0.01379468382501434, 0.02184883334613856, 0.016962448773424954, 0.05351195780320033, 0.04722498447423981, 0.08324789424096385, 0.05664122779102576, 0.0431462480956989, 1.1322287998853193, 19.1066123208692, 39.762494179510306, 37.611478144122714, 33.17557950173655, 33.428548843629905, 26.868873065517796, 2.557908743619919, 0.056985155303752234, 0.09732560254633428, 0.29858151210411904, 0.40337210521101957, 0.2129351344680594, 0.45346736066764404, 1.059707117176825, 0.9060237508627677, 13.12718354886578, 40.020911693573, 53.12861381038543, 52.66624089210264, 55.06189907750776, 50.55662547388385, 52.90099474691576, 51.71126534861904, 51.94534455576251, 50.40329610147784, 50.83116000698459, 50.57336222740912, 51.125275011985536, 50.88380998180759, 51.156975607718195, 48.98628104117609, 51.03293849575905, 53.43096579274824, 50.124690148138235, 49.039617430779245, 47.78616912903325, 43.620682608696725, 41.03009047046785, 38.06084056054392, 37.94771156003399, 38.182512483289166, 39.5587113595778, 37.320646162955995, 36.93351999405892, 39.546646148927756, 38.091003587169034, 40.52233965166154, 41.30077323605938, 41.35949896227929, 38.53972665725216, 37.76559199056318, 36.772828332839474, 38.27442930590722, 38.754794136170425, 37.31937139264999, 41.073005122523156, 42.97611167353969, 44.73809526812646, 48.3055889991022, 49.60750210669733, 50.87792642654912, 49.88220137934531, 47.983989946303836, 44.70029146440568, 46.48083963701802, 41.870069965239495, 47.02856333025041, 53.41274638329783, 50.05340499262656, 49.6760533701989, 46.41962320573869, 47.14123341345018, 45.962961258426795, 42.73148129063268, 39.3581291937059, 38.56504163434429, 35.281625563098544, 35.48742448129962, 38.30820875783121, 37.76902014209379, 36.41307246300482, 37.61279606050061, 36.118514230174405, 37.71739782825593, 37.730247512940444, 36.549523876559356, 37.93911372461627, 38.01263463112616, 37.82911477550384, 36.92000350644512, 38.08307255468061, 37.147873601605816, 37.08424883504068, 36.083318802618216, 35.51903878488849, 36.973139855169485, 35.001242776070875, 35.13157529215659, 35.420238202618016, 33.26984190171765, 35.08407931174002, 36.767372315929784, 38.81211957623882, 41.55042817515712, 45.93038597414571, 46.3392303066869, 49.605713505898755, 48.31839946008498, 46.007138913677586, 43.77876981612175, 44.254294441592315, 46.4530731785682, 47.772825225707024, 49.69616336207236, 50.024889361473825, 38.10594781752556, 18.40000321788173, 2.23519966006279, 0.08054269988450312, 2.9105423246660544, 3.6053070954738127, 0.3747701819144911, 0.035773180425167084, 0.031876343963367325, 0.06421491473672852, 0.3421842949765344, 0.09383080136631766, 0.07556842204423682, 13.437510690381451, 36.85316631870885, 27.68968197607225, 34.71145414536999, 36.207210786880985, 4.177864540007807, 0.13544330313321085, 0.05888635570543909, 0.032127247334668235, 0.04839421850779364, 0.0209856016426197, 0.030275028679640065, 0.02988296977785086, 0.05076834030689732, 0.050392669941028284, 0.017001440733551018, 0.026357707026745045, 0.04747757515419395, 0.05380582147007508, 0.04824170189338827, 0.0442483268618103, 0.053822652421771526, 0.059088503326018976, 0.018013419898887797, 0.06526267786900844, 0.07875905567479712, 0.11539175610748992, 0.016654079231703957, 0.02127057485913317, 0.07681014331718607, 0.019695634067419077, 0.04685145532411914, 0.025559855181904092, 0.009705426186443338, 0.0331082439891273, 0.03555053229173345, 0.00789797100644078, 0.03393129055057803, 0.024811345145046234, 0.03187280655237696, 0.009547563235936387, 0.01118218036173212, 0.029174296313055584, 0.03874174431867657, 0.06857015522978, 0.03324551162339988, 0.05468372375734391, 2.056922297323904, 25.288218682812108, 48.05248629662299, 36.06531120115711, 35.719962196965376, 40.180673753061605, 27.47601478330551, 3.6733658563706184, 0.0742978728826969, 0.047841907418783636, 0.14306042343378067, 0.3644836129200074, 0.1902525120925519, 0.4296119036453386, 0.8113401863844165, 1.0702158823128671, 16.210152776010577, 44.88047338301136, 53.06586373236872, 52.61887827227193, 55.05866704448577, 50.592605375474506, 54.69551047971172, 53.10489916032361, 53.14833156524166, 52.948098490315104, 51.20318505071825, 52.30434733052408, 52.218066953843646, 52.65167320928266, 52.00204241660334, 51.53234251083867, 51.93098868093183, 55.56280536036338, 52.77763228262625, 51.88201788933047, 48.970352295906316, 45.77465218882407, 42.20348319699688, 39.82702109121507, 39.860251411314934, 40.02106074363955, 41.75155555048297, 39.50877174254387, 39.71472755555184, 41.68786018125473, 40.31825480922576, 42.32508451707902, 42.14369843083043, 42.503093442609234, 40.61056552394744, 39.62779998779297, 38.26813782415083, 38.62870562461115, 40.57846484645721, 39.10626988257132, 42.80230752883419, 44.193462402589866, 47.066359289230846, 49.46510830233174, 51.47801768395209, 51.751187232232866, 52.0216856464263, 49.55984530910369, 44.63988304138184, 47.514042931218306, 42.583600090396025, 48.29470049950385, 55.16320605431834, 52.1263893958061, 52.554237611832164, 48.4242210849639, 48.381224063134965, 46.92839776315997, 44.041854950689505, 40.23539081696541, 38.50833592876312, 36.78620361512707, 37.57355274692659, 39.02629275475779, 38.942381489661436, 38.65368327786846, 38.895332659444506, 37.55971070258848, 40.155590195809644, 38.44603692331622, 38.557243962441724, 39.095938359537435, 40.29654841269217, 38.92010242708268, 38.223673835877456, 40.37135585661858, 38.824255389551965, 38.20935326237833, 37.22340668401411, 36.76801950700822, 37.52010260858844, 36.55057114939536, 36.20657928528325, 36.99146124624437, 36.25328294692501, 37.721633988042036, 38.65960997919883, 40.05945682525635, 44.299436999905495, 48.6039597757401, 48.35939215075586, 50.224133999116965, 51.24204004964521, 47.41495209355509, 46.773338625507975, 47.69169099869267, 47.42657015400548, 49.035624457943825, 51.45309102150702, 53.0914689648536, 40.61772384951192, 19.724083600505708, 3.682728799120073, 0.9467258797057214, 4.365710769930194, 7.864993993313083, 0.8273058877356592, 0.1032594821205543, 0.0183726902375178, 0.08061890265033131, 0.20875995528073082, 0.17222632533840596, 1.0007529128943722, 16.451165753026164, 38.128705409265336, 27.914200405920706, 37.45076687105241, 43.55816787289035, 7.0800340752447815, 0.062487156641098766, 0.03529427588106163, 0.08337690344741268, 0.039418395308236924, 0.022101690241646384, 0.035005590968555024, 0.0277674486184673, 0.056254226984756614, 0.013486717437063495, 0.02105011965238279, 0.10172565152207691, 0.009210886745413226, 0.04745325569303767, 0.030614237090752974, 0.04814529355855719, 0.07051804869045174, 0.04233297298572237, 0.05025859689339996, 0.11314306588422869, 0.218327795906413, 0.2268235730908571, 0.0714340600215139, 0.12834918339766804, 0.16975612079183902, 0.13701739931298842, 0.1676447211854881, 0.11124608662700462, 0.11083777708512162, 0.1466716853000464, 0.14600471383140934, 0.09529164676824886, 0.1486230797825321, 0.10776089985043773, 0.09934088876170498, 0.2048264768335127, 0.11668666686502197, 0.12148365663785128, 0.11892558946724861, 0.17255093211368208, 0.12055220097423562, 0.17550406316595693, 1.8139393098892707, 27.65926007301577, 54.36933402092227, 46.85129573268276, 44.14522117184055, 43.962964319413715, 34.56189417069958, 4.940102657964153, 0.2523546176211488, 0.2884513476202565, 1.825777268217456, 1.3793290502602056, 0.9729225320681449, 1.3676303360731372, 3.7434139943891958, 1.9233616705863708, 18.133456591636904, 43.89994359785511, 53.26689304844026, 52.711928659869784, 56.7295967378924, 50.83439204000658, 55.621731127462084, 54.29264383931314, 54.88466678127166, 53.726030011330884, 52.91659793546123, 53.716365291226296, 54.59501543352681, 54.48212961996756, 53.887870927010816, 52.83873496517059, 56.187772289399184, 56.53852631968837, 54.11185003096058, 52.787269546139626, 52.59637171222318, 48.54408087268953, 45.64493156248524, 43.296855649640484, 41.78458582970404, 41.677077585651034, 44.67059519983108, 41.64936211801345, 41.740827868061686, 43.37715441180814, 43.459712459195046, 44.72307651273666, 45.07565836752615, 44.77700125786566, 42.01318548571679, 41.964838350972826, 39.292955090922696, 41.20664811903431, 43.43908863682901, 41.64243913465931, 45.60514303945726, 45.63126994717506, 49.399871441625784, 52.02998930408109, 53.92859689650997, 53.0404624631328, 51.53092653520646, 48.24423528486683, 44.219526552384906, 46.56945382395099, 41.94224549878029, 51.402625806870006, 56.00768058530746, 54.493049498527284, 54.93405334411129, 49.54947848473826, 50.11377026957851, 49.89221911276541, 47.23127926549604, 43.10355732517858, 40.60641957867531, 38.38419683517949, 38.39980394609513, 41.062046020261704, 41.264412864562004, 40.102638198483376, 40.81365016198928, 39.19232276178176, 40.67977966800813, 41.34903015628938, 40.50748955818915, 41.21681882489113, 42.85321204893051, 40.624540928871404, 39.50957975079937, 42.868171968767726, 40.794712958797334, 39.91220712661743, 38.44789220440773, 39.211267809714045, 39.7017405879113, 39.043810059947354, 37.792326865657685, 39.27861098320254, 38.59191379239483, 38.53743207070136, 41.07900242651663, 42.476919466449374, 45.24318279758577, 50.46919192037275, 51.56186619112569, 53.55417136223086, 52.55570457827661, 49.94197830077141, 49.30105516987462, 50.410136715058364, 50.26354989697857, 50.53012594099968, 52.45364058402277, 54.25476158818891, 41.20332587149836, 21.190742138893377, 3.0450198054313664, 0.662050977829964, 5.049914804197127, 9.629719814946576, 2.265994188285643, 0.270617954553135, 0.4854274150584975, 0.15494515909062279, 0.5292850600615625, 0.47140221441945723, 3.3790816991559924, 22.21076430812959, 47.96928890289799, 37.79017740680326, 44.74266482937721, 47.964040771607436, 8.38022232055664, 0.18783207261754623, 0.10371263078864544, 0.120398745902123, 0.17567471691196965, 0.1972876813623213, 0.17518466578856592, 0.09522944808967652, 0.16156866335340087, 0.1485888356523168, 0.12002474177748927, 0.14981609318525563, 0.13115596867376758, 0.19027276745726987, 0.20807488881532224, 0.12595410143295604, 0.1701237050996673, 0.14412952977563107, 0.16584383233660654], [0.09744092176157622, 0.018305188315289638, 0.043620579094896396, 0.03696320225454627, 0.12929451291359242, 0.008756025870811314, 0.014529427261872879, 0.013243191492473407, 0.07586663709052148, 0.012235075325494813, 0.07746466585705358, 0.06061308341281069, 0.0250024285407797, 0.040849842086073854, 0.05296094140278236, 0.05022077130213861, 0.050365581072025725, 0.04911110443513721, 0.02656918942868229, 0.010023125721472166, 0.020114546266174125, 0.05650218283276885, 0.009116140821377837, 0.026608426536944126, 5.016191736344369, 36.066738943899836, 42.544682333546305, 30.85014939308167, 36.29192613786267, 32.85509636325221, 5.136979654912026, 0.10567731689661743, 0.513235119682166, 0.15051144055060803, 0.1267929217447677, 0.025664091020101504, 0.3222384910670019, 0.045376261095366174, 0.8320708933376497, 1.8074985329181918, 19.616036030554003, 44.66289558718282, 54.64142099503548, 52.46562734726937, 53.396531305005475, 52.57404950357253, 52.71902030514133, 52.31762847592754, 51.90492060876662, 53.13743522090297, 52.75706337344263, 52.810215411647675, 49.98000175722184, 50.5031753355457, 48.524363117833296, 49.48162540312737, 51.54660424878521, 51.104470760591575, 50.78627240273261, 48.81927436397922, 47.05669064675608, 41.141677979500066, 39.38236159663047, 36.759241242562574, 37.491441849739324, 38.61780928027245, 39.00171518325806, 39.531760754123816, 39.52021721870669, 41.21277093887329, 41.83040695805704, 43.51301354746665, 41.82097365779262, 39.94673575124433, 37.41492817478795, 38.86839774347121, 36.03006086041851, 38.4870296139871, 38.053474349360314, 39.46996773442915, 44.56763298280778, 47.643692954894036, 50.7476370565353, 48.18770608594341, 51.61480642134144, 48.95654163052959, 47.859164437940045, 46.354790349160474, 48.22919691762617, 45.00171776740782, 44.16423682243594, 53.817327099461714, 50.51620544925813, 51.04081069269488, 51.145228109052105, 50.2703316750065, 47.32593390249437, 49.217234119292236, 49.013157121596805, 46.48113381478095, 41.891725370960856, 37.244195245927386, 37.87677157309748, 36.73784863564276, 34.34370840749433, 35.60129480977213, 36.60457826429798, 37.212325988277314, 36.36645901587702, 38.411676960606734, 36.883376413776034, 39.32767591168804, 39.773033588163315, 35.463525479839696, 36.92666761336788, 36.90351778461088, 36.67960928332421, 35.28086462328511, 36.746826940967196, 34.89069469513432, 33.90257120132446, 34.290717186466345, 33.981489289191465, 34.55717163701212, 32.53691369487394, 35.280876390395626, 37.01910611121885, 39.04968184809531, 42.24788834971767, 44.16020462589879, 47.293723398639315, 46.62769317626954, 49.45731455279935, 45.816201856059415, 44.191877765040246, 48.40679791665847, 49.41682000314036, 47.96669621621409, 40.628357395049065, 26.25888566817007, 7.805224426331059, 0.9843695404068117, 0.36421750461862934, 8.046268782308026, 12.066304010729636, 1.5097884305061833, 0.22396762795265646, 0.04895744251928503, 0.025313678573095993, 0.08032333060738542, 0.37224812853720884, 1.9031303303857006, 17.8169075904354, 32.658240449044015, 33.94316381023776, 42.947403846248505, 14.083560359093452, 0.7115680820518925, 0.049284424167126424, 0.140107108520404, 0.060173264674602024, 0.04240755164515107, 0.0456850290028078, 0.06138603931533233, 0.013241437151126806, 0.012431167021033265, 0.011257501168837471, 0.013857554745740228, 0.05601426526423424, 0.03784596536969466, 0.06486866352779251, 0.07198875364396842, 0.024212141814191016, 0.11821822984324348, 0.040569128318419384, 0.030510608377235553, 0.045361571359418096, 0.07869258988648653, 0.04339037350408974, 0.03968697041273117, 0.04322262323131004, 0.06004267349658955, 0.02886542115330456, 0.04264600800290223, 0.02766038017016986, 0.010227286238073102, 0.048603540541784424, 0.04436215986647914, 0.014983106445851586, 0.008685141670397453, 0.0445975365507747, 0.009977393145222339, 0.05790976980220407, 0.019943227938887094, 0.041392454501962474, 0.026894723170346795, 0.05963679245342651, 0.022409489047863794, 0.029969635389504895, 0.03461112080502414, 8.501221556817333, 42.25292075064875, 47.93237547720633, 32.83662592211078, 36.697765934851866, 38.3189207507718, 5.367566481713326, 0.06273995416479246, 1.2155786757507634, 0.20404224794718528, 0.05252553916145718, 0.16588607442475137, 0.1304866989413577, 0.9127729241886448, 1.0912086526232383, 2.4231351239065972, 23.213133850405296, 48.6778062389743, 54.05469717517976, 53.84697629559425, 54.00505173590876, 51.183592811707534, 53.66904189509731, 51.83163504446707, 52.2698304730077, 54.72046852111817, 54.35000065834292, 53.70528067311933, 53.7359889091984, 51.34218992725496, 50.64858936494397, 50.795309543609626, 53.255012189188314, 52.80380233641594, 52.35783277019378, 51.349250193565126, 47.89600726096861, 43.45478203988845, 41.17146838095881, 38.46502903969058, 38.82093314201602, 39.93278780291158, 40.09819415307815, 41.09294645247921, 42.560964092131584, 41.56280717542095, 43.06931895594443, 44.35261257233159, 44.1034596966159, 41.238238888402144, 39.9402795299407, 39.83720748655258, 38.21477397795647, 39.47489815373575, 39.82199653502434, 41.929917489328695, 46.64856410795643, 50.16583188887566, 53.31864872286397, 50.560073237265314, 53.52529487302227, 51.90029613433346, 48.00878717053322, 46.1563301855518, 46.59235654338714, 44.490801595872455, 46.704614777718824, 53.522666885006814, 54.218722851045676, 51.84636354446412, 52.85996675491334, 50.4291170643222, 48.555796992394235, 51.68949227179251, 49.069141111066266, 47.180359055919034, 43.497453504993075, 38.01613338531987, 39.65826111455118, 38.44107904741841, 37.52111065772272, 37.67331430988927, 39.11605619615124, 38.102535355475645, 38.098275661468506, 39.43297193896386, 37.71914720535278, 40.499154521572976, 41.54265011510542, 37.210023556986165, 37.821830934093846, 38.65852740503127, 37.05842394982615, 37.130881894019346, 39.100982527579035, 36.19034067276986, 36.57440739293253, 36.23677761323991, 36.3572100670107, 36.099204401816095, 35.64686490643409, 36.907247958644746, 39.17674310745732, 41.808202420511556, 43.81335727630123, 45.735295126515055, 48.531121361640196, 48.74256849288941, 50.539978934872536, 48.98808140908518, 46.35257421001312, 49.99623252499489, 50.18404345358572, 49.71282951293453, 43.651422223737164, 29.50204645433734, 10.231501613893817, 2.098668818512271, 2.211534284776257, 5.021046159728881, 6.548186665581119, 3.517029251783125, 0.2340819344164864, 0.058721497414573554, 0.08791930688124511, 0.07743036810068354, 0.5634370758648842, 1.8665860977865036, 20.991750494126354, 43.85989227602559, 36.27824883307181, 47.52135815158967, 20.77380007313144, 1.27523155222016, 0.05663571195797094, 0.08832161029380176, 0.03249385679561285, 0.03215080645355967, 0.02914232363353574, 0.05850239626822933, 0.007728340945416882, 0.019921181843646114, 0.03664748592963142, 0.01926181762809715, 0.07815823589842166, 0.0368302132213308, 0.013792173929452417, 0.029649205708635912, 0.024412768750241207, 0.05079829434473669, 0.03240476460045865, 0.009631277493862136, 0.1878227416666285, 0.12753543714361806, 0.08637534860040873, 0.15990586951375008, 0.1568205270075029, 0.14723820732005183, 0.09349487181152068, 0.2218800077154752, 0.17914834342175917, 0.10120920100880247, 0.2585727234761561, 0.2921620936643693, 0.11691963420279565, 0.10249599889521638, 0.16796814818536082, 0.13494864016050293, 0.18255587186544173, 0.2103721566738621, 0.2059533921701293, 0.08552856097418456, 0.1291917652011879, 0.1414515315404823, 0.10002631528843796, 0.1374600142721207, 8.783925406394467, 49.0394958373039, 56.09245477184173, 41.17979165046446, 45.542749897126235, 45.34549782353063, 8.919453101773417, 0.1692231534229171, 2.4480946362018585, 1.1617016119341697, 0.6968413593788302, 0.2586437857920124, 0.6304827620906215, 1.0761572925313827, 1.3137133131104133, 4.094220241231303, 23.15913458024302, 48.66220305042882, 55.158393306116906, 54.68796776187036, 54.33627236273981, 53.07386928989042, 55.34426266147245, 53.79802903821392, 54.551920352443574, 56.78014432230304, 54.85864185517835, 56.15838589206819, 54.74414394747827, 52.93124014331449, 51.58323918619464, 53.13690177855953, 54.19790683254119, 55.07143043702649, 54.315032728256725, 53.556556163295625, 49.14365045485958, 46.065331197554066, 43.815542036487216, 40.44174671173096, 40.98640703385876, 42.39169420734529, 42.29388598472842, 42.71457195281983, 44.55942738440729, 43.03069929922781, 45.35831612925376, 48.00830079663185, 46.46284772503761, 43.655340671539314, 42.19725839553341, 42.34790094437138, 39.88176168933992, 41.46787012777021, 42.4198019120001, 44.16591167449952, 49.26969582034696, 52.069028654406154, 54.5698259722802, 51.79774576617826, 55.68653652744909, 51.20711134326074, 48.36903725900958, 46.385937890698834, 47.12977224780668, 44.966632166216456, 47.15069417030581, 55.95751347080354, 58.18339186329996, 54.10759033695344, 55.83845776896323, 53.8975787931873, 50.65225678105509, 53.579694224942116, 52.143992993139456, 49.1884909906695, 47.24118325018114, 40.031419723264634, 40.65745745935748, 40.55819403740668, 38.082962728315785, 38.63464017068186, 40.48555958655573, 39.81345753515921, 40.01422013005903, 41.17565747230284, 41.56931438753682, 42.24482890098326, 43.34165696174868, 39.133875523844075, 41.19426127403013, 40.867912230953095, 39.8147479949459, 38.8998394627725, 40.084720811536236, 38.40467552984915, 37.93985897494901, 38.52191517429967, 38.61852707401399, 36.597219897854714, 37.66292787367298, 39.385593629652455, 41.23823496603197, 44.287458081399244, 45.59080677647745, 46.02506806773525, 50.205239941996915, 49.3056208087552, 53.234862973613126, 50.25347725037606, 46.89603820923836, 48.9730038181428, 50.824158576227006, 51.31004218132266, 43.42504262924195, 29.159488216523204, 9.809523224830627, 2.00204098416913, 3.108194725167367, 15.030455820022093, 19.959504258248117, 5.251315274546224, 1.0192180833508893, 0.09981655275389072, 0.17924716876399133, 0.14479879950804098, 1.074159580372995, 4.662296868139698, 28.01603690270455, 45.974206693710826, 43.17316762862667, 55.73348729841171, 24.262340414908625, 1.3362917015629432, 0.20320777901478354, 0.3588750525828331, 0.12588821021058869, 0.10164146612007773, 0.14770939735875976, 0.21360798949195495, 0.1323600290643592, 0.1035800592733487, 0.13134295541432597, 0.09663534966567833, 0.16304649292461335, 0.12838492906021495, 0.12932927798359625, 0.18846452416431522, 0.08781302750350968, 0.1778109224453088, 0.17612500807210324, 0.12331004855373215], [0.05085433367639781, 0.1065729809324107, 0.0738801864246207, 0.022557504895714023, 0.049949905594750765, 0.05689888997303863, 0.03079912283517901, 0.06341763937305059, 0.07013135048891268, 0.04087115082168772, 0.04488045665165109, 0.056095079879366586, 0.029369600853251836, 0.040834819101878715, 0.04481313284486533, 0.0102611655189145, 0.0253090265041758, 0.03968254242452883, 0.09061397518962623, 0.020565423483569777, 0.0415826894553198, 0.06816622771082387, 0.056301023465611284, 0.06520956499321807, 0.8083679490993101, 20.152769242563558, 42.66990007892732, 36.89630846823416, 29.346989277870428, 34.22596669966175, 11.143946897599006, 0.05996027690989356, 0.8717423581307935, 0.33718158761339806, 0.06459555318278652, 0.011256134659502537, 0.1974928703519606, 1.4044285421409917, 1.0552186999590167, 0.30533583354084726, 5.865767800038861, 26.769358611875965, 46.55983617228847, 53.07355550027663, 54.35633528617121, 54.24252379325129, 52.02730640288323, 52.738098713659475, 51.100481710126324, 49.51139619273525, 50.121069800469186, 50.398742229707786, 49.21232723420667, 48.40499754874937, 47.233981778544766, 48.85702325451759, 50.378067416529504, 51.39468692964124, 52.872008431342344, 51.192076898390255, 47.82531438335296, 40.67520618438721, 37.685430511351555, 37.8077966936173, 37.641786298444195, 38.73222089582874, 38.7886598802382, 39.31740322420674, 39.22030887296123, 40.96717173053373, 43.39373819289669, 44.829914031490205, 45.107355040888635, 43.35554215215868, 39.514345430558734, 37.741175236240515, 36.712388530854255, 38.61173745124571, 38.64400286828318, 42.438750882302564, 43.133994917715754, 46.78125789088588, 49.73459866739089, 48.360866961940644, 45.29691534657633, 47.46545653189383, 49.14223840159755, 48.36466773863762, 50.520900526354396, 46.38897772758238, 46.06336609009774, 52.72013425827027, 51.641133369938025, 51.77628647896552, 51.51493503201393, 50.39012870480938, 50.26656227727091, 48.85350096610285, 48.20306216516803, 52.10278849447928, 47.91193992860856, 42.01746086920462, 33.374176948301255, 35.865709627828295, 36.78666645480741, 36.07529363324566, 36.121471697284335, 37.09121104209654, 34.36196704064646, 36.862909486216886, 36.10875537318569, 37.96665660796627, 39.05753835555046, 39.486516214186146, 37.94729578879572, 37.26707835351267, 36.16836363269437, 36.677157801966516, 35.592740120426306, 35.53731310752131, 34.77002297678302, 34.33486738512593, 34.86206923761676, 35.305191163093816, 33.75862806074081, 34.40347356180991, 34.278291117760446, 36.27890779126075, 39.63335406395697, 42.27997726009738, 45.90463953633463, 47.80605946817706, 48.483750897069136, 49.322510534717196, 46.62366490210257, 48.48959915099606, 45.98272608172509, 44.060093971990774, 28.1991135304974, 12.238149912126604, 2.648717006368022, 1.104559174949123, 2.0845902062231496, 2.4739129024167217, 3.984073222644868, 1.119378012034201, 0.20821289189400213, 0.06798073484171784, 0.22492612651999921, 0.1325500035478223, 0.2626035410550333, 5.375425930946104, 29.298389150250344, 22.51061381832246, 31.86719056098692, 38.352166760352354, 7.234866205723056, 0.09385155468818643, 0.009220523173890768, 0.044048753296655994, 0.03905042412600691, 0.051647414708690303, 0.01628051177718707, 0.03809495160596506, 0.024562479567623908, 0.00990586351573227, 0.01163124961162647, 0.06389815653223666, 0.07423395816717418, 0.02708989747559592, 0.06777474145975805, 0.04092919347327083, 0.05259331879055789, 0.1007155645939131, 0.022145497064376553, 0.035057918604223, 0.1322425111767746, 0.07169273727002644, 0.038574254515791134, 0.04916698671877385, 0.016150822667705438, 0.021658562003604828, 0.025818660750143954, 0.029058027148787535, 0.06423177633194194, 0.0338654414630465, 0.02665607720583437, 0.08659890837847226, 0.037919843058672645, 0.02204062920364161, 0.003050677267075967, 0.03916715294302952, 0.03369677571519729, 0.06823866132406459, 0.04515378916215512, 0.0710737535489663, 0.057118125184769594, 0.04975358790327465, 0.027311953806108045, 0.05393696806183266, 1.5294626715683168, 27.00045877887357, 49.0333612503544, 39.53218044773225, 36.3843567909733, 40.26857014625303, 12.19374083703564, 0.08622002427376087, 1.0657829911478105, 1.222021413906928, 0.015699034763289797, 0.011747113706904554, 0.05405106536683537, 0.3484853681537413, 1.6657807245369882, 0.4295330272326547, 5.996332716557288, 30.299113258238766, 49.27839955975933, 53.96509455096338, 55.66826612718644, 54.21045057235226, 51.509490782214755, 53.701762307074766, 52.54219593540315, 51.81354507323235, 51.18249454805928, 52.165601330418745, 50.2598471795359, 48.62697624391126, 49.3466527231278, 50.2008782663653, 50.88856389445644, 53.132245925164995, 54.049519646552305, 53.390518311531316, 48.640747685586255, 43.84310060931791, 38.869821563843765, 39.47943241365495, 39.44083629115936, 39.26383541476342, 40.716657792368245, 42.00477200169718, 41.32624903032857, 42.856283264775435, 45.43008373629662, 46.337582911214525, 47.00642155062768, 46.33796730349141, 40.738266129647535, 39.48477468182964, 38.61327109798309, 40.217861744665335, 42.20755461723574, 44.62634301954701, 44.90460380431145, 48.36026683930428, 51.26064777374268, 49.737662038495465, 46.838218550528254, 47.133749531161406, 48.4952042179723, 48.57800152993972, 49.95276874111545, 46.96724883971676, 47.20727828241164, 52.59590887254285, 52.78463371338383, 53.752753119314875, 52.447768795874815, 52.24597461761967, 50.99563675542032, 50.533863959773896, 50.91382395836615, 53.86661560304704, 49.81060635659003, 43.27081503406648, 35.41875554669288, 37.96438163326633, 38.35876418698219, 37.815559064188314, 36.84709841205228, 38.39801142292638, 38.24070084479548, 38.93774132574759, 38.30434914558165, 39.98116631661692, 40.59697843367054, 39.95191327987179, 40.582928503713305, 38.71877108850787, 38.071513329782796, 38.171282737485825, 38.033215307420306, 36.88784791577247, 36.06439728890696, 37.128869718120946, 36.68206468705208, 35.624942779541016, 36.47148439961095, 36.92873862481887, 36.02616986920757, 38.14660318436162, 40.930525026013775, 43.597042483668176, 45.958183811556914, 49.234798492923865, 50.663615965074115, 51.79119933036066, 47.312978313815215, 48.727981198218565, 47.018710336377545, 46.74031619102725, 31.188273391415997, 13.896785916820651, 4.356355426772948, 3.442963626115553, 4.621030101853033, 9.146078824996948, 4.41171330790366, 1.922071088225611, 0.1187288963926896, 0.05368651093674764, 0.057376641554818045, 0.059907206168939034, 0.505589408980262, 5.376764930063679, 37.38429838611234, 27.39532966767588, 34.23941650698262, 46.34207402506183, 9.685896000554486, 0.0573645182134163, 0.022302761508692658, 0.07736312090269021, 0.050079221236369306, 0.02437180411371012, 0.0173735756036495, 0.029980833679738066, 0.04767473171194715, 0.028103956569647117, 0.021768321335736304, 0.016317559789205273, 0.06178582995949734, 0.04450881207782415, 0.06601729745706243, 0.014685029295393297, 0.018490589253844756, 0.007299196206018209, 0.03823459028236328, 0.008607372254764122, 0.1337234050996842, 0.20770529735713236, 0.20312151751450955, 0.17677670374753016, 0.09738155760832372, 0.10851473802880895, 0.11845343415775608, 0.12677710969001055, 0.16659176397708156, 0.21433336750393917, 0.12891681624516366, 0.16984080415098898, 0.08519168147036145, 0.11190491458100658, 0.16598235635507494, 0.1281363105461482, 0.16287338769724294, 0.21460895997381982, 0.18304817528734285, 0.18684533604931447, 0.13103368571929394, 0.2342436402555435, 0.14999374897489626, 0.16243907713120984, 1.6460985161604422, 29.14017838816489, 56.62115104736821, 48.59315756828555, 40.29814873972247, 46.48758611371441, 17.469199280585013, 0.2532549394715217, 2.5298275149637655, 1.9983537110590168, 0.21691286215378394, 0.19081485127249073, 0.7083924943881651, 3.0616893883674376, 3.360278101698045, 0.4914935137475691, 8.229770987264573, 30.489112869385753, 49.97028604630501, 53.63644699896536, 56.20804702081988, 55.932849607160016, 52.58671091448877, 54.59840043898552, 53.650508696033114, 52.04505512791296, 53.05934083077216, 52.969153773400095, 51.65875657912224, 49.92635942274525, 48.87152033467447, 51.67212009429932, 52.039042134438795, 54.54968460144536, 56.43682318349039, 55.59827927620181, 50.39521601892287, 45.621389496711, 42.498402287883145, 41.02055126620878, 41.08882796379828, 40.48937605273339, 42.525803965906945, 44.84386197982296, 44.24523376649426, 45.14758679174608, 46.83840682429653, 48.548595520757864, 48.76423566572128, 49.35176357146233, 42.87674234759423, 40.36225988018898, 39.85282244220857, 42.37755406287409, 42.694293299028956, 47.12622250280073, 46.41245311306369, 50.801232322569824, 53.7518705860261, 52.01610411367109, 48.36718197791807, 48.17190285651915, 48.81490484360726, 49.2400074005127, 49.732613948083696, 48.03964053430865, 49.27226497280983, 54.341755836240715, 55.30177554776592, 55.91873691928003, 55.86491023340533, 54.39011473809519, 52.15519528235159, 50.89648315983435, 51.94160261461812, 56.77528842802971, 51.75705117564048, 46.804129231360655, 36.873001744670255, 38.64944711808236, 40.240148651984434, 38.33768144730599, 38.018349524467226, 40.527403431554, 38.560789785077496, 41.21678352355957, 39.19967328348468, 43.079062123452466, 42.481571397473736, 42.94937679844518, 42.205981746796645, 40.204062846399125, 37.76975754768618, 40.28146689937961, 39.03174484929731, 40.299054807232274, 38.18354406664449, 39.0429118371779, 37.723026429453206, 38.869931390208585, 38.301513271947066, 39.55194134866038, 38.533674440076275, 39.57687585584579, 43.71870656167307, 44.99752475369362, 47.590027086196415, 52.31952298072077, 52.36781520228232, 52.751540676240005, 48.680218496630275, 49.82550351850448, 47.02287589350055, 46.69021575681625, 29.581011610646403, 14.927614215881595, 3.9215663315788394, 2.3351941137544574, 4.430084709198245, 6.034089451836002, 12.235321883232364, 5.548777532192969, 1.4462023973464968, 0.19146098514958737, 0.29712156302505927, 0.4528597916566557, 0.8803570474828444, 9.799283877495798, 42.73148129063268, 30.743137328855454, 42.92199080990207, 50.43269426591935, 11.871171978212173, 0.17800550877807603, 0.107422296648785, 0.1619529943432539, 0.3174278266247242, 0.1189181584143831, 0.1626601854279157, 0.09640104167403714, 0.19694485701620582, 0.1723401047169201, 0.06872881969977772, 0.1167370907721981, 0.15589929095679717, 0.142089590850857, 0.2030569669460097, 0.12671655043959618, 0.13364394646017783, 0.204952881341019, 0.19391088836616088, 0.0669777495486121], [0.033385364804416895, 0.03192739223220176, 0.053399787209327185, 0.05820874710597339, 0.02428057453324718, 0.03470985038626579, 0.10017984696934301, 0.042322669103140795, 0.09289450402702056, 0.030327526769871195, 0.0326882477759594, 0.046058259378638, 0.05589446060419564, 0.05004273246853583, 0.05237846177131419, 0.04421343921773857, 0.02824935431201612, 0.01654526793337878, 0.15037746709440986, 0.07224639667378319, 0.039376777581750386, 0.022927337671600045, 0.029680123102040063, 0.034074732853520306, 0.03081897791895655, 6.183176780900648, 31.315771995052216, 36.88329796637259, 27.102179565737327, 40.11981425746795, 19.153382662803896, 2.4900306568991755, 1.736096564319826, 0.07573497721985464, 0.09821675432425353, 0.019471181796923764, 0.08887959809433069, 0.44812377482171983, 1.017256959551765, 0.5836022873559307, 0.5713617957888112, 12.78866142995896, 33.30073448919481, 47.030085209877264, 55.82957360052294, 53.17128135311989, 53.20819870118172, 48.93221509072089, 52.01752793404364, 49.73017815620669, 50.17621048035161, 51.15377103128741, 50.653166770935066, 50.27091218579201, 51.361711563602576, 50.636677126730646, 49.51079999246905, 50.43542031318911, 53.87761000664004, 51.379574037367306, 48.66093612486317, 40.62641974418394, 37.76081846606347, 38.67686448558685, 39.341180632191325, 38.25410358367428, 38.80735781884963, 39.1746917078572, 38.94517421722412, 41.69257879257202, 47.99089724017728, 48.351649392035704, 49.69375110441639, 45.86563156497094, 42.26568806555964, 37.9277466958569, 37.092662319060295, 37.01607804144583, 38.22758836130942, 38.46383663915819, 42.0550371754554, 48.010038406618186, 49.850281130883005, 52.87508356955744, 52.87289096463112, 50.55271487082205, 49.65388805635514, 52.59854862766882, 47.483503357056655, 45.48786417130501, 43.90419152475173, 47.36239233324605, 48.704592104881044, 51.73526240933327, 51.11241748256069, 51.13612821025234, 51.285943138983946, 52.72955579142417, 51.684475560342115, 49.014855507881414, 51.56505115570561, 46.33974805954964, 37.35119750422817, 36.18730475825649, 37.14423364208591, 35.954033559368504, 37.703222382453184, 35.44264670341246, 37.30905163672663, 41.17028774753694, 41.070153559407885, 42.73313260847523, 42.55600229386361, 40.4961342965403, 39.66815725449593, 36.25268282428865, 37.98619393379458, 35.878261212379705, 34.97176224185575, 35.653466255434104, 36.99093172627111, 36.07204983311315, 34.321849038524014, 35.287862131672526, 34.53088783448742, 35.16922220107048, 35.62882200364144, 35.871506890942975, 36.9499155013792, 39.99230977027647, 39.57999414013278, 46.40123905674104, 48.13227515066824, 49.550804245856504, 48.19540962096184, 47.89165735244752, 44.047973848158314, 29.446627286172685, 14.600808216679482, 5.2898878628207795, 1.6829062830055914, 2.8857546612139675, 3.886925429105759, 12.379688639794628, 2.453160132131269, 1.6950740881504553, 0.3607196084433987, 0.03465900896117091, 0.07292888142288693, 0.2464664505133706, 0.156601625044019, 13.740532417451183, 30.048687573402162, 32.32952033319781, 40.041739479188, 25.887796109722508, 1.76134106132292, 0.06511339797608315, 0.04899803368795303, 0.06795546926197506, 0.08288148204765974, 0.06280617097452765, 0.02403106352674865, 0.031975245914391937, 0.05805776266741657, 0.10758107603197137, 0.0036332294374944707, 0.056129576818596934, 0.03245133891581528, 0.045324864256526196, 0.05130807989306989, 0.007007942504940495, 0.05245435044109341, 0.08499704151143951, 0.016591106804328102, 0.02043734890438857, 0.0343930347251796, 0.046892134592898434, 0.024514307958945155, 0.049268654247205106, 0.023010458211384477, 0.0365748722857285, 0.05676471733398015, 0.05708986803168251, 0.029213385949391994, 0.02922098745682067, 0.025377704371367733, 0.023736594650413723, 0.04361512454887552, 0.07848989068260116, 0.02775615265202378, 0.03976046888818664, 0.03447771808432956, 0.06871226453973402, 0.015049147055364184, 0.03497983509254071, 0.046779228554617976, 0.037103097570399125, 0.03829339136099143, 0.042526996243865266, 0.08841400049746999, 8.785692434157095, 39.68456060655656, 41.12129342171454, 30.238628348996563, 46.26649779658164, 22.9833927846724, 2.808627135330631, 2.805798125843848, 0.164178678946149, 0.3532314054187267, 0.14390244599311583, 0.008275458915910174, 0.14613992835004486, 1.1800840448948646, 1.0048114015690743, 0.6203868877022498, 15.706206656271412, 34.98654957740538, 48.846966297395774, 54.63121106547695, 52.941536365016816, 52.188633488070586, 51.02395234569427, 52.36448118763586, 51.84194303327992, 52.46888291451239, 53.03215096073767, 52.212579557972575, 51.66295351520662, 51.056782584036554, 52.77251751192155, 51.31941272366432, 51.861970655379764, 54.69887979568974, 53.26058195483301, 49.60725499737648, 43.06038771906207, 40.1703461523979, 38.85151978461973, 40.25579106423163, 41.0714126402332, 40.93613401536019, 40.55309887855284, 40.89312522642074, 43.24487247774678, 48.79006839567616, 50.970906211483864, 51.953055935521284, 46.74433662045387, 44.60635854351906, 41.43291396479453, 39.41040262099236, 39.163324679097826, 39.345283431391564, 39.50770878022717, 43.96782021368704, 49.998178020600356, 51.77339569214852, 55.48519342176376, 55.20043719199396, 52.513770518764375, 50.88308826569588, 52.88703895384266, 48.99979360641972, 46.04016527052849, 46.447264148342995, 48.40981029695081, 51.827795044068374, 53.194929322888775, 52.755337530566806, 52.785810424435525, 52.107624776901744, 53.919516609561065, 53.98787959929436, 51.66417729470038, 53.91436261515464, 48.25927365210749, 39.11186710480721, 37.79314271865353, 38.80891107743786, 37.096298356210035, 38.36383581161499, 37.836916369776574, 38.310605326006495, 42.720024047359345, 42.15124507104197, 44.05505372631935, 44.315302987252515, 42.47053384780884, 42.37141947592459, 39.32699734164823, 38.651055289853005, 38.65191821129092, 36.55386594034011, 38.3907550381076, 38.8102093819649, 37.060695002155924, 36.003447578799346, 37.346086655893636, 35.70908154210737, 37.38578496440765, 37.00271452626875, 37.37295096920383, 39.639947568216634, 41.2035180676368, 43.248896829543575, 49.39483119595436, 49.75982342996905, 50.41941312051589, 48.953737135856386, 48.67983802672356, 45.84032443261916, 35.03188433185701, 16.347689705510295, 6.109927988821461, 2.701492497036534, 4.789229179582288, 6.5858924100475935, 10.153008122597972, 6.1233076837755025, 3.668052760824081, 0.7046044041072169, 0.20014791659289793, 0.012278640830528834, 0.505934363050807, 0.052517150498686306, 15.75968130942314, 38.909633621092766, 32.6593053725458, 42.10549454535208, 33.387101158019036, 3.3752539561640833, 0.07278191511549296, 0.018585229840790553, 0.022155333633324312, 0.08118095837773816, 0.016025953208877435, 0.03448044535734, 0.03136045460949742, 0.035292774348730044, 0.038512722333712925, 0.0466641889614684, 0.026091575742729252, 0.0195215693149235, 0.023534452775493268, 0.050188496017888676, 0.06943778044754459, 0.04983196252836816, 0.06619989451381468, 0.027789257226451754, 0.03605075706277163, 0.1679967232649365, 0.12581978323719195, 0.18844049964700976, 0.16380769320793692, 0.04298094547383728, 0.11445873762450873, 0.1981097703138667, 0.1033270434145966, 0.18635903875673973, 0.1507565733646193, 0.19729497451936046, 0.13412057572314817, 0.15742693156484636, 0.21345532349040433, 0.1254435727793363, 0.0863325166245622, 0.1242322881796187, 0.10748251115963345, 0.13795829317983122, 0.34383104693505073, 0.07885257202771404, 0.0883893784315836, 0.14169582165777683, 0.2232557330881396, 0.14181790542939018, 10.458250891777778, 45.59134414119106, 47.61504788552561, 38.6955585018281, 51.89043921809043, 28.938737223225257, 5.436480564455833, 4.56599336478018, 0.3625874533768623, 0.5406348058773626, 0.30292189049143947, 0.1320270106436745, 1.4857547201456562, 4.3482959366613825, 2.1519762806354032, 1.528190230169604, 15.80629671773603, 37.83319404048305, 48.71644158517161, 56.182567304180516, 53.97937590076078, 53.55397132135207, 50.25754867061492, 55.78097935645811, 52.717117955607755, 55.218083935399214, 55.76277955885857, 54.44486318096038, 54.123166068907715, 53.173548483079486, 53.72354715101181, 52.318797342238895, 53.442238684623476, 57.82641695391748, 54.57497996668662, 53.23831465936477, 45.48891928888137, 42.115559347214244, 42.29991859005344, 43.62899411109186, 41.45628344628119, 43.97343312540362, 42.522666069769095, 43.673367884851274, 45.198310882814475, 51.45132595492948, 53.97852082406321, 54.443129493344216, 50.24225534931306, 47.70898080641224, 41.67444959763558, 40.732025638703384, 39.74378447378836, 39.85098285059775, 41.71021769123693, 45.6931100353118, 52.921987272078, 53.42708264627765, 57.09880159747217, 55.25148291741648, 52.37931951399773, 50.436396983362016, 56.0142780119373, 50.48279862250052, 47.690702561409246, 47.414583390758885, 48.41847873503163, 52.18803336543422, 54.50596586350472, 54.666943857746745, 54.298511705090924, 54.184119701385505, 56.508375060173776, 55.245234581731985, 52.26177000230359, 55.95552875149635, 50.58572946056243, 41.043018602555804, 40.14948306545135, 40.80136529860958, 38.05139941553916, 41.08399952611616, 39.52234706571026, 40.69083682952389, 47.59342778113581, 44.97897194277856, 47.388127003946614, 45.995748350697184, 44.54337312329201, 45.785375948875185, 40.51080003861458, 40.603018883735906, 41.60566691429385, 39.52797566690753, 40.866539401392785, 40.97161185356879, 39.366978060814645, 38.852920070771255, 39.44096180700487, 39.02360200881958, 39.37973360861502, 39.16403462809902, 40.84928881737494, 41.69889380854946, 42.93023955437445, 44.709375673724765, 51.95996715176491, 52.14416949979721, 53.17230509173486, 49.59476224837765, 48.935607940919944, 45.990092292908706, 33.873416223833644, 16.97202121057818, 7.172708405602363, 3.3450938713166023, 5.894276567043797, 12.170553745761996, 23.177732498415057, 7.355714921028384, 6.1595788213514515, 1.0039585924917653, 0.3191020045309298, 0.2635419987622769, 0.817856714129448, 0.35718487876076854, 22.08040825782284, 41.22537743660712, 42.16962137529927, 50.36589630188481, 37.382192073329804, 3.5072142558713115, 0.1979070328055851, 0.09477919523393917, 0.1165666362090457, 0.22522172920646208, 0.11839573241529927, 0.10117160907435803, 0.17437972188476594, 0.17483093235040867, 0.22080264294580107, 0.1722138227834817, 0.1550276667600678, 0.17882336892427939, 0.09786997696444874, 0.13859573961986651, 0.16979102375766925, 0.1760550029575825, 0.15975677348192663, 0.08308394376428858, 0.11131544822766898], [0.05340449481962189, 0.04685577222957246, 0.023402277710697344, 0.020252026489845688, 0.03635903850438134, 0.010498212274884986, 0.037924811138861605, 0.09132990733750405, 0.024443760837217974, 0.027957101345002174, 0.07285595751337468, 0.05120758447916277, 0.08228189567284239, 0.03110080251410123, 0.08457038416377, 0.023795322950689063, 0.028367647863624078, 0.041067713661299604, 0.031595580399997776, 0.037075840162053224, 0.05538301264506675, 0.027889448120408965, 0.03594184234257668, 0.0345025125199989, 0.03289406495769659, 0.23328200072771121, 17.42465292253802, 42.06900473563902, 35.960254438461796, 33.32675941528813, 33.43110230661208, 5.122781165184514, 0.8896823599934579, 0.054491742123519225, 0.02714524158246575, 0.11377340302832666, 0.07008933822714514, 0.07623267390074269, 0.5256154989042591, 0.5753804478914507, 0.2067691685571786, 1.874228100622854, 12.700089408505349, 34.22786512682515, 49.3463977690666, 53.35918249622468, 50.60530208772229, 50.08154015387259, 49.82217342622819, 49.556005308705, 49.929438483330514, 52.01034215188796, 50.750316035362985, 50.54974171423143, 50.008701739772675, 51.212120209970784, 48.557185511435236, 51.332509517669685, 53.98941324603174, 51.04643144915181, 46.94076891868345, 40.73681877505395, 38.57003088920347, 38.78361963456677, 37.6046218410615, 38.923036359971576, 38.520675705325225, 37.852943174300655, 37.789600818387925, 41.51332255332701, 50.057782357738866, 50.66284718052034, 53.087158280034224, 48.4437584107922, 43.727155347024244, 40.8409773149798, 38.34702845542662, 38.06288019303353, 38.267714208172215, 37.58746147155762, 39.8177368410172, 45.575454619623, 50.512773375357355, 50.79703930885562, 51.1628552406065, 50.79614500845633, 51.69876867725004, 51.58384323120118, 53.585005114155436, 51.1989841922637, 44.484168867911066, 47.05372533490581, 44.60877080117503, 50.316792149697584, 49.69716748883648, 53.743335508531146, 53.1315359761638, 49.240234897982695, 45.50583647143456, 43.9781125130192, 51.84657143008325, 46.23117685317994, 37.400034935243674, 34.88266952576176, 36.47497138669414, 36.85025592004099, 37.87196666963639, 36.3185590313327, 42.15311604161417, 43.06165464462773, 45.48700909460745, 42.88804269606068, 42.02720795908282, 40.96251979950936, 38.651965279732984, 36.6105834130318, 36.72717586640389, 36.725061708881015, 34.457661105740456, 34.94072452668221, 36.53517192409885, 36.37343691241357, 36.25497348846928, 35.37427194656865, 34.777408799817486, 33.743609305351015, 35.257361781212595, 36.19303926344841, 36.31616246315741, 38.52937944473759, 42.13491624401462, 47.73718657032136, 45.17083075738723, 49.58817658885833, 46.479670770706676, 45.62792808778825, 30.500258284230387, 15.477653088108188, 4.681914602556537, 0.6658748597387345, 1.4907416460975524, 7.373417067912317, 5.295629232160507, 10.69076801500013, 5.546266234690144, 1.1248841617376575, 0.23114964095575197, 0.06849615879717373, 0.06684956005624225, 0.037947088975699685, 0.9505232856158288, 21.441010928923085, 36.126947326044885, 26.754000571466264, 38.208098103923184, 15.90994142716931, 0.21168530798487126, 0.030666537913343603, 0.04393619582838109, 0.06621060442299613, 0.0035413192357913025, 0.018165093816576466, 0.05907665194583036, 0.07149194562507254, 0.016764968543523745, 0.03905757938721969, 0.02660131532578699, 0.019653399640153495, 0.03176960684809714, 0.023800022900104526, 0.043760696576247295, 0.04522894238752704, 0.07949417066429892, 0.027049861720673023, 0.029556317547816905, 0.024392025004471504, 0.015117745440933975, 0.058272792056443236, 0.054836604263513326, 0.018383896188630212, 0.008103985455818474, 0.015968376913318233, 0.06883194279526511, 0.07167861060870272, 0.05173315143873615, 0.016411332781576825, 0.003914780874413649, 0.04526469954139283, 0.08116780464807827, 0.056280231839346315, 0.060201487353732513, 0.03825285764891775, 0.02965558913626498, 0.010949010010658494, 0.03617875503316041, 0.015276720176541038, 0.020967696252609455, 0.06639215193929211, 0.0886296312655172, 0.04935416881175292, 0.032118600117222916, 0.9849229623233119, 23.21560690479894, 47.2874907524355, 36.33226771508494, 40.44227623170422, 36.6729373316611, 5.83908881871931, 1.5095213416122621, 0.1741864225797115, 0.16123852542331144, 0.05336753490771498, 0.07524092711748616, 0.030756392365982457, 0.8999741690293436, 1.923079137359896, 0.341122129391278, 3.621187301412706, 16.153182310442773, 37.21331050319057, 52.171312301389634, 52.90164586036436, 51.961936181591405, 50.237277861564394, 50.53480140624508, 51.98397990195982, 50.923712253570564, 52.73591395347349, 52.74459415866483, 52.979528442505874, 51.76207573183122, 51.971024313280665, 50.09648046185894, 51.26239715083953, 55.26706257174092, 52.42085741412256, 48.09970378875733, 43.25745936362974, 39.944821634600245, 40.66290170915666, 39.35829001088297, 40.10238324442218, 40.288837032933394, 39.127509517054406, 39.41319927092522, 44.66336627160349, 51.41315737078267, 53.69516488044493, 55.12251930852091, 50.85811061243857, 43.70216984902659, 42.285621550775346, 40.26415747980918, 37.543519158517164, 39.75350802944553, 38.82134499088411, 42.24459355877292, 47.7678987287706, 53.89236988559846, 53.41577445307086, 53.05842299615183, 53.41843382004769, 53.286814766545454, 53.71799307484781, 54.983628180719194, 52.094057298475704, 45.65732232985958, 48.359313703352406, 46.75573502817462, 51.78617085179975, 50.75401483043548, 55.42685993256108, 52.170629808979655, 51.025674266199914, 46.52471919213572, 45.65178394317628, 53.3966842774422, 48.39349323703397, 39.021789873799975, 35.56106305891468, 38.74231315428211, 39.32279648319368, 38.842835657058224, 37.48553476025982, 41.62477670177337, 45.54699782402285, 46.68645812619118, 45.15462744620539, 45.89984639998406, 42.433361545685806, 40.32794306355138, 39.88937108747421, 39.115762018388324, 39.25073077601772, 36.95227676822294, 36.414531584708925, 38.92873556383195, 38.90709584759128, 38.96972433213265, 36.86703974200834, 36.92627537635065, 35.4912958606597, 37.357892990112305, 37.08015780295096, 38.29351555916571, 39.29165286402549, 44.37555059309929, 49.87855749745523, 48.14008458968132, 50.12363503056188, 46.93208871349212, 45.58467218952794, 33.140693941423976, 19.5631036450786, 7.048754153713104, 1.5513825921281692, 3.095469330587695, 6.43259245541788, 5.149253731773746, 9.89783735044541, 4.5493223109552945, 4.264677868735406, 1.8901345374122744, 0.10763972772345429, 0.10516476577087756, 0.04133536179940547, 1.170720366701003, 25.12993927924864, 37.28786691542595, 28.75627640754946, 44.86265013294835, 19.842262652612504, 0.2930404594348323, 0.018679523772950617, 0.05249990585951075, 0.00528001060311292, 0.041385981059002305, 0.02366493478597653, 0.05357207655305824, 0.03961923674890592, 0.06850595706172528, 0.003772910009326053, 0.008358558388276687, 0.008438332081441919, 0.025986815134303707, 0.06058419806762569, 0.02311431675127918, 0.031500660190959616, 0.013906076839644343, 0.019679902451893976, 0.07047615134187284, 0.05298182112915863, 0.17768652508816413, 0.21384081893390228, 0.16080616072060602, 0.08049647413915204, 0.07783924454763051, 0.09039524942636491, 0.21066584414051426, 0.17758160168605466, 0.18304998325484415, 0.09787825837491021, 0.07092838070445484, 0.18410084138233818, 0.21749055373572537, 0.13890556089820402, 0.16641888857608841, 0.13246844582740339, 0.10549684190341543, 0.07817138196720232, 0.23097624461497032, 0.15048209938310808, 0.19781072023174456, 0.15324254400066792, 0.17300496178288616, 0.0944304030628935, 0.13783452401478447, 1.1717471696676747, 28.366783088253392, 53.699020570324315, 47.65976290549002, 43.92661963739703, 45.31784119144563, 9.121120783590502, 2.8211647464383036, 0.45307025133121404, 0.2620965440667445, 0.32361747997422374, 0.19747494389453243, 0.274870386046748, 3.043038763346211, 1.8421525508165362, 0.6697411522749932, 3.585442251736118, 14.400006398077934, 38.64746632114534, 52.70327198889948, 53.81584052116641, 50.768504065852014, 51.60316482667, 51.144796648333156, 53.700942531708755, 52.945850972206365, 54.86681999698762, 54.219083709101525, 53.52347097089214, 51.91972363379694, 53.308811418471805, 50.831128628023215, 51.70590739096365, 57.51784801483155, 54.0667349292386, 50.71018626613002, 44.016787082918235, 41.987854819143976, 42.89971566969349, 41.5715422937947, 43.354973408483694, 41.64376489577755, 40.44062883623185, 40.63827706921486, 46.54049496496878, 54.08271074295045, 56.555353287727606, 57.51913455224807, 53.22333905004686, 47.244411360832956, 45.256005025679066, 42.271414726011216, 40.646631717681885, 41.07003588830271, 40.543528295332386, 43.3499135509614, 48.864636575022054, 55.26164970090313, 54.26054708419308, 55.696997488698656, 55.48690357515889, 55.56104029378584, 55.12593961531117, 56.84176475771012, 54.05708982098488, 47.17432252822384, 48.79966251311764, 46.034360162673465, 52.695807718461566, 51.45185547490274, 56.350291775118926, 55.05749033343408, 50.05778628010904, 46.690349117402114, 46.536902073890936, 54.65148971926782, 49.741619709999334, 40.255743995789565, 38.14130406225882, 40.10705478729741, 40.72462020381805, 40.625019458032426, 40.51568731184929, 44.52281205884872, 48.50515919346964, 49.61571947220833, 48.95521194704118, 47.69811191866475, 44.23245860684303, 41.9558443561677, 41.36320167972196, 40.98193553186233, 41.31022222580449, 38.046767096365656, 38.01755720569242, 40.71949366600283, 40.86546467196557, 40.81251659700948, 40.18967951497724, 38.19687228049002, 37.89658738720802, 38.72117942379367, 39.440502889694706, 40.3939369417006, 41.56740027089273, 47.63277307633431, 53.292517892776004, 49.83484268188477, 52.3590055588753, 46.99653325542327, 47.1528200949392, 32.28959844958398, 18.532036081437145, 6.1248771221407, 0.960791192708477, 3.3294767093273903, 13.107149062618134, 12.265277024238342, 21.29432801277407, 12.505370205448521, 6.92492590796563, 2.06386856975094, 0.17235194843622947, 0.2768561778770339, 0.11942734641413535, 1.7739698675370987, 29.955164540198545, 48.206278508709325, 36.83566078062981, 50.98473256634128, 22.526083646282075, 0.4081579484045506, 0.1365369242886382, 0.14097913108285398, 0.14916286533398015, 0.14183999940512643, 0.20037426493100582, 0.166905905991312, 0.23704136271149884, 0.13334910986163925, 0.1102084894814799, 0.10320078446379594, 0.09567313557190281, 0.11063369892297253, 0.24639367216056396, 0.1445861335002607, 0.22164756131749, 0.17465837870634374, 0.0900476293698434, 0.13870450878335586, 0.1360432265867149], [0.05332783623147876, 0.01582470478399867, 0.04490721227240659, 0.009112833236764756, 0.08066638477987821, 0.12436823814266151, 0.06854649843467821, 0.06811512964627436, 0.062184019479900605, 0.04460335498855961, 0.024970913598794612, 0.014395095659570109, 0.10369796786577472, 0.0875426903967896, 0.032636575145466674, 0.03768022224727658, 0.06614958551982719, 0.02268994234562401, 0.07653006923294838, 0.05462757334293378, 0.024646404499728835, 0.0630946835172513, 0.03709708761063315, 0.030569587571306095, 0.07708386653253148, 0.09273934823971602, 4.889321692528264, 30.2621429581796, 38.13089409182149, 32.22986859659995, 38.37830935755084, 13.142287615806827, 1.408136285120441, 0.502717774361372, 0.07338729311501788, 0.11184849986626257, 0.05665731180699603, 0.07631625409328169, 0.7899561596493568, 1.2594457283135385, 0.7058105329352041, 1.3175056321967034, 2.8354353097177323, 14.415523294479618, 34.44975360747307, 47.1972527042512, 51.220874940195394, 50.45345537124142, 51.38548504921698, 52.71344661712647, 49.193868560175744, 50.457342440082186, 51.703695174186464, 52.693101283042665, 51.37783642738096, 49.94452784138341, 50.167977425359915, 53.958579494107155, 51.574084374212454, 49.53052559206563, 42.4820577713751, 38.67404037906278, 39.637649059295654, 39.109219504940896, 39.70472943398261, 39.58088844053207, 37.311518807565015, 38.71813566453996, 39.77057818443545, 44.24234690204744, 52.72060494269095, 53.54843293466876, 53.533449480610514, 48.79896825359714, 45.389322465465916, 40.65531584524339, 39.20389375379009, 37.97584672128001, 38.43739201945644, 37.84485524700534, 37.94464426655924, 39.66927905236521, 45.568586549451275, 48.69782209396363, 49.697065507211995, 47.47931818808279, 48.108631103269516, 48.92705717394429, 53.86563108813379, 49.14652555219589, 42.31561591548305, 48.258763743985085, 45.996372007554584, 48.06525753390405, 48.17218526717156, 47.54030319952196, 48.72951876732611, 49.1175784603242, 53.58646031348936, 54.15629048501292, 49.57719787474602, 48.54546154699018, 38.08353539436094, 36.55129678787724, 37.09837721240136, 36.903098091002434, 34.896413510845555, 41.63207623266405, 47.248016019021314, 47.045041207344305, 45.99936869836623, 43.22959092355544, 42.76601383762975, 39.46502554801203, 38.154577362921934, 36.46073710533881, 36.91877580458118, 35.94719686815816, 35.23257240172356, 35.92442750930786, 36.519078439281834, 37.58301350378221, 38.810993855999364, 38.280120665027255, 37.832546849404615, 36.500098090018, 35.70585735382573, 37.590564066363925, 39.73621429935579, 41.04774113624327, 41.42401018450337, 45.84687086843675, 46.54819065524686, 47.67657810641874, 49.54995701389928, 38.47791794807681, 17.37432302967195, 5.370590629116182, 1.052688648623805, 1.1282995655652017, 3.1045260833155726, 3.7386806741837537, 3.3144885974545635, 4.690012826073555, 4.009718659424013, 3.1708344865229825, 1.9524788952642873, 0.39704804939608423, 0.04163409778547864, 0.07758516382666365, 2.3525927672463083, 29.847542547410537, 29.08365703398182, 33.243848354585715, 34.58432620571506, 3.9024261457304803, 0.10128544207902686, 0.0210596248883033, 0.03702062437491071, 0.023716770210153153, 0.025976323560180686, 0.065393571651751, 0.01622632637830271, 0.02535816146841934, 0.00980256422002229, 0.05624542846494625, 0.10804377015559904, 0.04249249547419529, 0.023132383019753525, 0.052584960771303986, 0.011085938651024575, 0.04595645395438037, 0.016087497839884415, 0.024109353882170493, 0.02978423062051016, 0.035288024603599505, 0.04403728879086914, 0.033385866592007304, 0.02478929904980525, 0.00616938840868252, 0.033761732310297034, 0.02541711001897291, 0.05537371999854523, 0.023749074222700253, 0.017779717116706797, 0.061084338568992196, 0.06660562233939286, 0.032484043209302815, 0.04665614503826346, 0.04400380308769884, 0.027737237941173297, 0.08003427797267515, 0.04516161475030165, 0.02440914132391974, 0.07138765807594023, 0.015526287682023982, 0.01455771218564722, 0.025149774061696186, 0.06621513966350787, 0.08740320876841584, 0.02018765020634859, 0.012442507995142332, 8.57290385230895, 38.21209499912877, 44.086566048283736, 33.16859376045966, 44.96169390216951, 15.33508473826993, 2.3973668679114315, 0.47467291955986335, 0.0705606738225587, 0.2659840419167473, 0.07953376208822574, 0.10027700223990026, 1.671999887593331, 2.311951864150263, 1.397883332064075, 2.6509297134414798, 5.513907171064808, 19.1504918759869, 36.19851489220896, 48.93903609245054, 50.13539429633848, 50.9970841100139, 50.84746529979091, 52.24380162454421, 49.16085397043536, 51.71375997604863, 53.51867783454157, 55.49295186996461, 52.58011348785893, 51.96378361794257, 51.283625018212106, 52.793490425232925, 53.93309585509762, 51.27439960356682, 45.24801123526789, 43.053958954349646, 40.54925887815414, 41.028152819602724, 40.11388363376741, 41.996970407424435, 39.12421080373949, 40.14129315653155, 40.18826353934504, 45.16357829493862, 54.03291625361289, 55.44081964800435, 54.880897383536066, 51.58533765423683, 47.7019166177319, 43.20596648800758, 39.41872589049801, 40.40345653410881, 40.436737845020915, 38.59422799079649, 40.06612093217912, 41.776560660331484, 47.5132506124435, 49.871301112636445, 51.622325604961766, 49.77277117390787, 51.60056821761593, 52.13678759913291, 54.61037151275143, 51.72800210214431, 43.78262550600114, 47.42667605800014, 46.97378743079401, 49.84312280531853, 48.27705767846877, 50.779392565450365, 48.74609078130415, 49.26206288799163, 53.568033018419825, 55.103182023571385, 51.00729796194261, 50.40050337391515, 38.548775565239694, 37.798029991888235, 38.69829239383821, 39.57277305664555, 36.57369744393134, 42.73246188317576, 48.433246458730395, 49.30760160569222, 48.90302088952834, 44.88905552894839, 44.938434247047674, 42.26952022121799, 39.76700882757864, 37.76375632132254, 38.53853425671978, 38.47180689534834, 36.685237884521484, 37.250851508109804, 39.22436068134923, 39.68913801254765, 41.6310211150877, 40.06943141260455, 39.600759167825025, 39.5960444788779, 37.90375747988301, 39.75688911253406, 41.026940807219475, 42.43707995260916, 45.54973563840313, 49.21024053327499, 48.455603968712595, 48.37243795394898, 49.86595492209158, 40.27962730776879, 20.605650025029338, 7.19969186090654, 1.9988277049795276, 2.869729327578699, 3.6953303938911812, 8.19447651986153, 6.685879018998916, 6.6324225068092355, 5.462943325119634, 6.346924458780597, 5.495772092573104, 0.9032152112453216, 0.14468649101834144, 0.09659315354280895, 2.3965223325837046, 34.26105622322329, 34.635034607302764, 33.52445863908337, 39.843989264580514, 6.371496146725071, 0.14471780869268602, 0.03370606070083957, 0.05646320044874184, 0.06126204032390829, 0.035867654387989355, 0.05599347363796927, 0.0672652853292323, 0.06674820662385995, 0.05336781452980734, 0.03568234921042477, 0.02316310697595679, 0.04067822689971617, 0.009102540845502048, 0.011462982229497886, 0.1062464282938069, 0.0376384359814467, 0.015554747848411002, 0.006407745175003525, 0.06307194602765864, 0.030869486095804363, 0.18073126493442446, 0.1786212749298542, 0.11833312004924783, 0.10732714852858936, 0.19775235965367288, 0.22411235728331153, 0.13790483556447491, 0.10626668365852487, 0.15788465377784547, 0.16910264779242778, 0.17169067666174906, 0.10079324590943514, 0.1844927566426416, 0.15301751333378977, 0.19132316593200932, 0.17556980883161868, 0.10048920859492595, 0.14476585772729691, 0.160866329266179, 0.1539163030083141, 0.10735475067650119, 0.13259647444130915, 0.13223595346414274, 0.20067155301090212, 0.2340583082649016, 0.19157045911396706, 9.430460468415292, 41.75670954488939, 50.107078706064534, 42.88396735345164, 49.95800118292532, 21.06217861175537, 4.475884754811564, 1.8444888125504217, 0.15484884651678224, 0.6753403969830083, 0.1478578958420023, 0.19788784996396114, 2.8304862591528126, 4.341578877741291, 2.524500200825353, 3.8232923275040047, 4.917777507535873, 17.413405526068903, 37.44295743203933, 48.34427533611175, 51.27112442447294, 51.10443938163019, 52.182149810175744, 53.94797732753139, 51.21278701290008, 52.83382808008502, 54.92312169844105, 56.34463179496027, 55.88317671129781, 53.913205515953806, 52.639972779058645, 54.43952091278569, 55.36647896612845, 53.195176432209635, 47.49879667835851, 43.27194075430594, 42.967015697110085, 43.2953808384557, 44.639455503033055, 44.24931303147347, 39.18943589733493, 42.91353810218073, 44.99727372200259, 47.51383504559917, 56.111109564381266, 58.069670584894, 57.155111143665934, 54.760311957328554, 48.65058498997843, 45.70845434742589, 42.09107591259865, 42.18017647343297, 41.78585667763987, 41.74153781706288, 41.68182757592971, 42.00401498425392, 49.28035290010514, 51.711606594824026, 53.497296994732274, 50.48201414846605, 51.658285894701564, 55.23425586761967, 57.631012316673036, 52.21418772974322, 44.75691480021323, 47.48829649340722, 46.92009802787535, 48.87037892495432, 48.32674626381167, 49.623324947972456, 48.33506953331732, 49.85176378680814, 56.7917113919412, 57.19901423300467, 53.04213339282621, 53.23176822354717, 41.60809093906034, 40.11985348116967, 40.501382427830855, 40.448293147548554, 37.686265976198264, 47.15847223035751, 50.99209485515472, 51.09196232211206, 51.43179255147135, 46.945562055034024, 47.55376869632352, 43.47179335932578, 41.8364905541943, 39.87049271983486, 39.5563736269551, 39.721313215071156, 39.89317186417119, 39.92142861889255, 41.000429507224794, 41.87727928161621, 44.33437355103032, 42.73290511100523, 41.42834440354378, 40.56759988107989, 39.718371437441924, 42.31707895955732, 43.27201527933921, 46.49271265152962, 46.72902760967132, 51.126153622904134, 50.17905812109671, 50.75958067371, 50.068423748016365, 40.813822746276855, 20.29318028880704, 7.125925806260879, 1.6985375410126102, 2.9227075557554922, 6.481087659635852, 11.796339038879642, 10.18673070015446, 10.701957556509203, 9.723075166825327, 11.018077058176841, 5.793944789517311, 0.5624890880238625, 0.4429433657036674, 0.23514587732572712, 4.693376258496316, 39.21344864752985, 39.55795434213454, 42.31576104317942, 46.364737479917466, 6.597320725840907, 0.17485978322163706, 0.10339792953023028, 0.15278946428048998, 0.1320543446608128, 0.12224994374499207, 0.17632889471227126, 0.20254900468693626, 0.2504282588920286, 0.12382991581914887, 0.12038844201954142, 0.12329268900136794, 0.1479755209818963, 0.09853793668650812, 0.1232896016670331, 0.1993238511345079, 0.1493576355278492, 0.20093234466208568, 0.11369731517568712, 0.12726167562387644, 0.15391650219117442], [0.044753795504690184, 0.04200225282881049, 0.04539242938100811, 0.013484306175321823, 0.03863293685079102, 0.05018846920481132, 0.032381981145590544, 0.012034336349085696, 0.015699442705109475, 0.1170155177673986, 0.04625895143216176, 0.07347603674016653, 0.06075632270245303, 0.11769859240420404, 0.03948537054501715, 0.05681013485657112, 0.04108903005779271, 0.022098907427261436, 0.032023925056320526, 0.051820657831887086, 0.058516331407571995, 0.0283910614258099, 0.08248560611278781, 0.03128710360596738, 0.04178723110066306, 0.012859483906668762, 0.22834681635422094, 16.915037016714773, 41.636288858229115, 30.985520193653723, 32.146339762595396, 26.797148604546827, 4.136866456077946, 0.32624899199412716, 0.08783086203038694, 0.09128487668931486, 0.04391854899304529, 0.02423479503411199, 0.8413791067657933, 2.7620627178299815, 0.40454041993906426, 1.4077576538247447, 1.238495736352859, 1.9788674986170185, 10.389536849914059, 29.5123524819651, 45.493061311783336, 50.22615794212588, 51.9871570217994, 52.43170669001918, 52.40460703449865, 52.94919283159318, 52.854051820693485, 49.29628164537492, 50.285675987120605, 50.63403737160468, 52.8184720008604, 53.37551524562221, 50.90163323187059, 46.598746084397845, 41.35117569277364, 40.997126871539706, 40.80580934401482, 39.15944937736758, 36.768780446821644, 39.341129641379084, 39.65765314717447, 38.216386072097286, 38.83960754640641, 44.61617231369019, 52.0075455019551, 53.299844880257886, 55.27689987613309, 50.5756607363301, 47.78518853649017, 42.81078377077657, 37.28457604685138, 36.6390049073004, 39.517181304193315, 38.056522030984205, 37.83905798389066, 37.86517704686811, 37.64537918952204, 37.82827538828696, 39.78289442677652, 41.00262603452129, 46.46879011584867, 49.25437896482406, 51.44228881405246, 51.028412080580196, 47.446687990619296, 47.71875927525182, 47.04792414942096, 50.76782941818238, 51.68501292505572, 52.70034197838076, 52.21786691296486, 51.5594696229504, 49.47529469766925, 49.879251756975734, 50.036778065466116, 41.46930179288311, 35.43992457851287, 37.22982368161602, 37.03765107739357, 36.79838649688229, 38.16959611831173, 44.94466297088131, 49.37782772125737, 49.42908133229902, 49.90535905284267, 44.07078635308051, 39.899824203983435, 38.773354791825824, 36.39714764010522, 36.77464831259943, 34.969797134399414, 36.09042221500028, 37.111289655008626, 37.40295317865188, 38.785031687828806, 41.22975480171942, 38.99041875716179, 42.50567828455279, 41.96799585896154, 39.87393263847598, 39.19475070891842, 38.312233109628, 40.20339212109966, 40.836713698602495, 43.42717247624552, 46.05899264735561, 46.352472228388635, 49.814477735950106, 46.940459051439845, 24.95477407209335, 7.281524760107841, 1.6238847855598697, 1.0738996007750112, 2.717713704032283, 2.5247593224048615, 5.9194586738463375, 4.48269251854189, 6.378223992163136, 1.9452685982950273, 5.233870042908577, 4.671894907951355, 0.5386478189499148, 0.3553747355697617, 0.05777702974756399, 8.651120816507648, 33.928717720893125, 25.53306479607859, 36.45632051652478, 18.586262849069414, 0.6505621104471145, 0.024420672862399972, 0.08140922959653601, 0.009511278439012748, 0.05133762407386976, 0.06066379077251881, 0.09400934581795047, 0.028070731336371075, 0.02568921487357828, 0.01068842520321449, 0.022142222038500255, 0.03129028095563333, 0.05574248408177688, 0.06913151381717575, 0.03548815358249891, 0.00872603065574602, 0.03542469851973076, 0.029884879252002127, 0.04891480206541958, 0.022815268584376863, 0.040782365061703234, 0.023311406276339007, 0.02210348480260901, 0.036548158799808834, 0.04776038034188171, 0.01740812425381474, 0.060176995522793264, 0.047780118597250794, 0.04873150786865623, 0.05680738460092295, 0.10114630519021904, 0.04816975474597947, 0.0658997795694778, 0.05835460641631677, 0.09229206014424564, 0.028721542180245443, 0.023840910927843184, 0.06366426988895382, 0.028589242626161828, 0.05755823120594986, 0.016767420024881442, 0.06919690708239233, 0.0783363206972999, 0.09924240049815948, 0.07134733120760611, 0.008972483056206858, 0.03688213099995929, 0.40063717132133825, 22.33815504658607, 46.61074853712513, 35.05120592732584, 38.80476513216573, 33.029769312950876, 4.9098984464522335, 0.6609707325696945, 0.12118084506402094, 0.06634149054485945, 0.11281115829103416, 0.1422939218220211, 1.5428036331169068, 1.969558365883366, 1.5108837523768026, 3.2653802777490313, 3.9160269643029864, 4.798410957859409, 12.722021341323854, 32.72792723871047, 48.178857218834665, 51.11584171172112, 51.585510238524414, 53.142032238744925, 52.14594633348527, 55.08970475965931, 54.25542446874804, 52.59119026122555, 52.10960165146859, 52.480285244603316, 53.63617635542347, 55.146339862577385, 52.61052754617507, 49.67579057139736, 42.935828931870006, 40.879746021762976, 41.937381759766616, 40.784687380636896, 38.80875418263097, 40.86297004453598, 40.80564460446758, 39.54729726237636, 41.06598015754454, 45.91352762714509, 54.79141243042485, 56.1771858123041, 56.81488083254907, 53.2762675131521, 49.358400221793886, 43.91031434459072, 37.64889363319644, 39.37515620262393, 41.36036972845755, 41.02140242053617, 39.39241070901194, 41.47576978129726, 40.27722681722334, 40.982884745444025, 41.8335291647142, 44.09131996093258, 47.205226882811516, 51.67714072811989, 53.79091385872134, 52.923760183395885, 47.70893373797017, 48.323353413612615, 47.035862861141084, 50.493573373363866, 51.791018901332734, 52.16074151377524, 53.95723019876788, 54.30910210455618, 53.26813643978488, 52.81473398208619, 51.052499355808386, 43.676003717607074, 37.58426081749701, 37.83437075153474, 38.979212545579486, 38.74593350195116, 39.05319236939953, 46.233075280343336, 51.96294423072569, 50.851705381947184, 51.34901877372496, 45.16479030732186, 41.8639628348812, 40.43055226725917, 38.19709193321967, 37.98401701834894, 37.8594268521955, 37.52952806411251, 38.29103662121681, 39.21364868840864, 39.57094130977508, 42.87681687262751, 41.783636616122344, 43.799217131830034, 42.448305776042325, 41.81949100186748, 40.30155727940221, 39.89149701210761, 40.95454562094904, 42.10475321738951, 44.56791539346018, 46.43327305393834, 47.341431187045195, 50.94290048845353, 47.102284277639086, 28.570281536348407, 9.992566512477014, 3.128719997982825, 2.502878870694868, 3.461511043771621, 5.669053581453139, 8.310088380690544, 9.1177063603555, 9.961251289613786, 5.598571531234249, 4.036416272001882, 3.7313404487025355, 1.6900617893665069, 0.265492427973978, 0.07035665694744357, 9.605854153633118, 40.80005130460186, 26.896419871237974, 43.24466066975748, 24.9815873945913, 0.9151900848073344, 0.029760194611885858, 0.0328241785868041, 0.07322153467084132, 0.05532186733739031, 0.11424232544677873, 0.004798915047544025, 0.04968998345336126, 0.03231807792138669, 0.03661082479201498, 0.04414781229570509, 0.011621507846059339, 0.06359077141349835, 0.021006498605974262, 0.037083646598001646, 0.06155146068082221, 0.03207646145094787, 0.011039240803990153, 0.0488934550254095, 0.03900515216012155, 0.06243865178417295, 0.16647675885788857, 0.09876993875349722, 0.15858053740474487, 0.16130906679937917, 0.06438489432536787, 0.2480094128799054, 0.12082240784600859, 0.2170632298915617, 0.14271324770825525, 0.26177601287922553, 0.1511627531820728, 0.1162371494536919, 0.1905226346946532, 0.17663617257870015, 0.1748889252062767, 0.1094672381277046, 0.12456723714187262, 0.17141845497873523, 0.17692414502943718, 0.11479373255203809, 0.10944589491813414, 0.23949500443714283, 0.19484235935153502, 0.14426604664373782, 0.18068480936269607, 0.15519724798298654, 0.8830051376454292, 26.49548892051943, 54.457391231290764, 42.14912306877875, 44.261868538395056, 37.868507139144405, 10.73852385244062, 1.4838933103507566, 0.17170086563114198, 0.36159016011703404, 0.26270402114718194, 0.47729336927014016, 3.0297348191661224, 4.138023555278778, 3.611506646679294, 2.949043574833101, 2.611389280326905, 2.589630912388525, 12.877413880440498, 31.358396391714777, 48.30926818232383, 50.931003939720895, 52.36209246420091, 53.66566081200877, 54.279233255693995, 56.74762787357454, 55.11276829627253, 53.049950676579634, 52.33272960109096, 53.404940866654925, 54.59836906002414, 58.28644429483722, 55.65215695288874, 51.32756733125257, 45.23263554419241, 44.530484214905776, 43.08875430014826, 43.490679571705485, 39.63164391056184, 43.04331364170198, 45.03514028364613, 41.35163853245397, 43.03146808378158, 49.42690441685338, 57.81038230465305, 57.872085109833755, 59.124101746466856, 54.733635917786636, 52.39353810587237, 46.81704167396792, 40.87951460192281, 40.620277312494096, 44.7075988400367, 42.45250663449688, 40.664458890115064, 41.50671728195683, 41.80149124514672, 42.66086293805031, 43.651186881526826, 44.249567985534675, 50.91888773825861, 52.21647054918351, 55.18691678200999, 54.50268283967049, 50.11967735905802, 48.089340886762066, 47.39994118290563, 51.65660319789764, 52.96152868578511, 54.76083755493165, 56.75297406411941, 56.43599556338403, 53.14339722356489, 54.62579819463915, 53.84088485471664, 44.58707224938178, 39.146784044081166, 40.12639207224692, 41.96594053699125, 40.72923291114069, 43.22883390611218, 48.65266384616975, 53.57210836102886, 53.08930773888865, 53.61050052027549, 48.159335582487046, 43.72681017844908, 42.64571474444482, 39.832202542212706, 39.39290885002383, 38.28606305583831, 39.26429433207358, 41.48013537929904, 40.703372724594615, 42.78986184827743, 46.51081438987486, 44.33518940402616, 46.39659889282719, 46.24890204398863, 43.0960028402267, 42.75525477624709, 42.00555255336147, 44.929644215491514, 43.627727185526204, 47.20961993740451, 50.153747066374756, 49.53644837102583, 52.77369422297324, 47.83485358761203, 28.286323508908673, 9.1977011388348, 2.7276613250855477, 2.848721112935774, 4.524586864056126, 7.871621328015482, 13.482620889140716, 12.665129323159496, 17.61023986724115, 9.221947270054972, 14.70977754362168, 8.457367497105754, 2.8940347846477263, 1.1297479007513294, 0.21225037443782055, 12.335359973292197, 44.21702800258514, 36.28291645357686, 49.322785100629254, 27.6606015236147, 0.9709367095943421, 0.11442246336129405, 0.279574349762932, 0.18687813993423216, 0.13987011156014859, 0.29091600569025167, 0.1744666575424133, 0.11839984630745266, 0.18734297144316858, 0.16263266754967554, 0.1474562819085775, 0.10982847922751982, 0.1103315691673948, 0.18454763918153702, 0.12792919101493974, 0.08569860951073709, 0.11606310959905387, 0.10378145612776281, 0.15815882132418696, 0.22080639677663005, 0.18406071369686436], [0.045316904602992925, 0.03779794314816114, 0.06576703185395849, 0.07694693597694559, 0.015250410802001435, 0.025001660537635608, 0.07409734936851649, 0.06430822424590588, 0.06939248932946114, 0.057674561657251856, 0.022059915467135368, 0.0070926186820161686, 0.06423367622999415, 0.07439856747946433, 0.04376076552416048, 0.048958354163914926, 0.005114251201326449, 0.05702498421493558, 0.04434922064143804, 0.024538106480312925, 0.09834112103788123, 0.012265606802107107, 0.05252530933507989, 0.04950805289310314, 0.05928233123174118, 0.029124310991216092, 0.05232919082646409, 5.449969105182156, 29.489965554206606, 31.68060733426002, 29.721440307555664, 27.690635112024125, 13.25357114115069, 3.501597421784555, 0.06037150141632846, 0.17951195939413964, 0.03831126419226489, 0.08473774373170831, 2.0208542649784396, 1.6415249099654536, 1.2717087735091488, 3.936570868376763, 3.486592639838496, 1.466255882574666, 0.9023365390396888, 11.411850663923449, 27.810355655608642, 45.14002053968368, 50.34921053917178, 52.393357676844445, 51.58456102494271, 54.16186025065761, 50.82236997542843, 53.47102888168828, 51.00097117885467, 50.61690053632183, 51.84502601623536, 50.903904284200365, 46.49346182423253, 43.96463524910712, 44.98108610030144, 47.75563739961194, 48.51060344326881, 46.548025915699625, 42.01946912273284, 38.66340683352563, 36.8839059337493, 38.47128129774524, 37.019157102031095, 46.498337330356726, 53.60167518738778, 54.5698965749433, 52.19346192575271, 52.63565032712875, 49.668506729987364, 44.805234478365996, 38.20004940032959, 37.42138831846176, 39.16964361744542, 38.94364449285692, 38.37173938751221, 37.4897591529354, 38.550823042469645, 37.45847432844101, 38.122143283967056, 39.788860351808616, 45.32716074297505, 50.05714301140078, 50.90097035131147, 52.76195849141767, 46.05205789689095, 49.07485208203716, 49.684462931848344, 51.77779659148186, 51.817385073631044, 51.961610624867106, 49.602520696578495, 50.83978922136369, 49.07790368603122, 51.04579210281373, 41.952663313957956, 37.51997317037275, 35.58976304146552, 36.32661165729646, 37.559118424692464, 37.369942511281664, 39.03818930349043, 46.835151257053504, 49.76049415526852, 51.87189425191572, 48.59813113366404, 48.13825284281085, 39.81771722916634, 37.984762268681685, 36.642284008764456, 36.776566351613695, 36.12685318916075, 38.07660064389629, 38.60481839026175, 39.68078336408062, 40.10026124215896, 42.68725264456965, 41.32344453565536, 41.91344745697514, 43.38844691553424, 43.91242065737325, 39.76970741825719, 41.99475426827708, 40.11686855746854, 42.653881119143584, 44.121435919115626, 47.00227168298537, 46.592293785464385, 50.90273149551884, 38.35689321640999, 14.374012850945997, 3.902133684004507, 0.9272577469387363, 1.33004299815624, 4.097916094526168, 4.292783612205136, 9.113124051401693, 6.619489962054837, 6.296710275834607, 4.651314721953485, 3.03461964091947, 5.303202348370706, 1.9794534026615083, 0.08667822912215226, 0.6733309790011376, 18.033379277875348, 34.71061868052329, 27.667801034065988, 39.27840309758341, 6.011518172679409, 0.25100356027964627, 0.07180897579077752, 0.04000068724816365, 0.03198416317783056, 0.06685084708395504, 0.08020900730644503, 0.0242391636505002, 0.050492215405909285, 0.016185702650897926, 0.030066928555888515, 0.04063327669075901, 0.021226610988378528, 0.08778502698987724, 0.05311449989676476, 0.03433028446330178, 0.06650788484201317, 0.08668461829544076, 0.046092143447528926, 0.0701652345578036, 0.03481118083601037, 0.04013523527030503, 0.0809308689748568, 0.059880078995540265, 0.03743033585769515, 0.047788331059799086, 0.06188064483144592, 0.03914371065254654, 0.05084372335864652, 0.045216742437332876, 0.06490025699378983, 0.027502991236566056, 0.0160095349870502, 0.03670571627275598, 0.06388147496768544, 0.041161463671033426, 0.053001187831884435, 0.02863846569051666, 0.03552609408694891, 0.01139690618841879, 0.05129276579546352, 0.08298645907592389, 0.03901236870836827, 0.044677428029958284, 0.01910194082395925, 0.06371627193725397, 0.04124101807153033, 0.028893517427927548, 0.04534361042803334, 8.98066855246021, 38.267820112166866, 35.97415139598232, 33.45164768157467, 33.859154485887096, 17.05065884897786, 3.5388035543503302, 0.1043403325902839, 0.0914931913176852, 0.08692031290622489, 0.0790531951333246, 1.9487841451360335, 0.7299239164398563, 1.5376667990799875, 4.495812356472015, 6.508331462260216, 4.330152032836791, 2.6961497385655684, 13.045855164527895, 31.79305188117489, 49.12036726551671, 52.94253656941076, 52.815510611380304, 53.10196914980489, 55.352185849220525, 53.05216289335682, 54.44336483555456, 53.08475778948877, 51.90728579798053, 52.847493617765366, 52.961736571404245, 49.58498770190824, 45.5909832831352, 45.17461192223334, 49.05200035341325, 49.734967370187086, 47.166571924763346, 41.91981738613498, 41.27251255896784, 40.4038409263857, 39.87716074912779, 39.858270614377915, 48.69974797771823, 56.841635319494436, 54.3273058245259, 54.477909149662146, 54.61981265775619, 51.93202418665732, 46.974815091779156, 40.80507978316277, 38.35297869097802, 40.38932423437796, 39.927567128212225, 40.34288729390791, 39.06843469988915, 40.25379065544375, 39.69066381454468, 39.82978636218656, 41.58130899552376, 46.61157615723149, 52.449800583624075, 53.21738489212529, 55.027021361935525, 47.44540929794312, 48.48450399214222, 51.59815988233013, 53.93300564058366, 54.26594426555019, 53.963215735650834, 51.61691665649415, 52.24141290110927, 50.41363939162224, 51.955138714082786, 46.117694839354485, 39.81786627923289, 38.10090364948396, 37.22741534633022, 39.019169730524865, 38.44339324582008, 41.03653492466096, 48.998965986313365, 52.470428328360285, 54.073230374243956, 52.270128573140795, 50.42066827897103, 42.20034137848885, 40.693857054556574, 38.23295808607532, 38.11284334428849, 37.1059238526129, 38.148799711658114, 40.590467299184496, 41.62016399445073, 41.94004897148379, 42.371411631184245, 43.76763028483237, 43.718777164336174, 46.32851439137613, 45.04772716952909, 42.214238336009366, 44.14186362297305, 43.71266611160771, 44.18247192136703, 45.62040890416792, 49.24488290663689, 49.560590559436434, 50.979217713879, 39.78608723609678, 18.073728699837964, 5.976091325283051, 2.488520299234698, 3.8682976028611584, 5.914592483351308, 5.855499525224009, 8.548168405409783, 8.836887209646164, 9.833643840205285, 6.331553670667834, 5.136513873454064, 2.0162051531576344, 2.0935140886614403, 0.11644980780059293, 0.30178906095604746, 20.212036255867254, 40.5134750950721, 30.237622261047367, 44.42242291665847, 9.55577431186553, 0.13791651074444095, 0.07086636588698433, 0.08965273402751454, 0.01473558247990666, 0.046711299538372025, 0.021999842682552916, 0.04226832282579234, 0.01649083738635865, 0.013702141361371165, 0.013988004197486708, 0.013527871680355841, 0.06078253823122191, 0.019238633892288613, 0.03806169955961166, 0.029842369033083804, 0.09416584225912249, 0.030759464378558823, 0.03316612576224631, 0.032747435728989305, 0.06963832694436274, 0.04081065668874691, 0.18468006514012816, 0.18376195472815346, 0.24217027539928115, 0.15554397937751588, 0.12211813831761961, 0.16579495592703744, 0.13159800140607741, 0.1680934954915316, 0.16837722381516812, 0.1115624886006117, 0.11449030044698909, 0.09304120220364102, 0.17732385906480974, 0.19493887110823588, 0.14465785465173184, 0.19372923359755548, 0.08265445189129922, 0.15298907615004048, 0.13041568259077688, 0.1458472061541773, 0.23484560150292613, 0.30923892894098837, 0.12919677541621272, 0.15577515406954676, 0.18978492266708807, 0.15214732938235806, 0.18232993721481294, 9.409818014790936, 43.10719728469849, 43.88504643594065, 40.78513060846637, 37.36430214297387, 24.105608386378137, 7.33749992424442, 0.1503220636157259, 0.2923867106437683, 0.11832824773004941, 0.4088619832069643, 5.552938676649525, 3.8929067984704053, 3.7176207332841815, 7.970895046187986, 8.519562559743083, 3.6274601519107823, 2.116503590537656, 13.975367661445373, 31.071986882917344, 48.49080331863896, 51.43064329701086, 53.57444217128139, 55.20641880650675, 57.37734479288901, 53.30411241900537, 57.04650855833485, 54.27668371508199, 53.70517084675451, 55.58772810043828, 54.29014921188355, 50.55069877255348, 48.30243149111348, 49.37253252152474, 51.466219194473766, 53.02891892771567, 50.96672496488018, 46.13438060206752, 43.78906211545391, 40.40245632971487, 41.96182204831032, 40.57538186350177, 50.21503410031719, 57.89052809438398, 57.97152896081248, 54.835578318565126, 56.94930438072451, 53.62010248245732, 50.23359083360242, 42.61250403619582, 39.99114874870547, 42.957672611359634, 41.920554791727376, 42.27871817927207, 40.97075285450105, 42.89383603680519, 42.01566050129552, 41.677913050497736, 43.72022451892976, 49.376266617928785, 55.65819740295411, 54.208583524150235, 57.96861856214462, 49.61195007447274, 49.09541314648044, 52.05428838729859, 54.91433558925506, 55.55705124332059, 57.10251215965518, 52.70721397092266, 54.37883792384979, 52.988389076725134, 56.19478940963746, 45.79278530613069, 40.87089715465423, 39.52982310325869, 38.20969843095349, 40.825856577965524, 40.70326682059996, 44.11096319075554, 51.22349116110033, 54.47467319426998, 56.544602071085286, 54.210936946253625, 52.07116242377989, 42.79961286052581, 42.1500644376201, 40.24942113507179, 39.06799931680003, 40.095095480642016, 40.4617743338308, 42.541638574292584, 43.67391309430523, 44.55472838494086, 45.70391224276635, 46.25993959365353, 45.99767031208162, 48.5072184378101, 46.86853062721991, 44.40510565234769, 46.80736518675282, 46.539526139536214, 46.654333914479906, 48.402098917192035, 50.928991763822495, 53.15586251597251, 51.68720552998205, 41.592907444123306, 17.299945085279404, 6.087253747447845, 2.7901890537431164, 3.9948602309150085, 9.0919412912861, 11.958479035285212, 17.53767994142348, 16.20888388925983, 15.597122600001676, 9.314195532952587, 8.928931509294818, 9.60339286634999, 4.850844221730386, 0.255721022465056, 1.3524348288774493, 24.260194878424368, 47.89295957934472, 37.919976480545536, 52.18900611323696, 10.548548756107207, 0.27981229667221347, 0.21571512964944686, 0.1957296117419197, 0.21532719804634973, 0.140555898148206, 0.14374349807058612, 0.17248078910333497, 0.10267838144734984, 0.1278542139897904, 0.07513619523735778, 0.10647765661199247, 0.14488385058939457, 0.17219186670357184, 0.13444973306069452, 0.05787246515073123, 0.26161491991050784, 0.1923289168025217, 0.11251731760679715, 0.16177553773647355, 0.12076377147628416, 0.17802069264073528], [0.01567683736568377, 0.007802478625484172, 0.029787070891489426, 0.04414313532892735, 0.06638711874162959, 0.029532902070411274, 0.1120171158183967, 0.027308111875167778, 0.016675564167540402, 0.04083489571067114, 0.015887962579126322, 0.07533104204001927, 0.01881435141718436, 0.04505991657835342, 0.04953767368269544, 0.03245321200079015, 0.004547901551104001, 0.020006190790163896, 0.06404735215549028, 0.06722446816462664, 0.07126580413070417, 0.0353384216976983, 0.03598371670851785, 0.10589972754279453, 0.0874773660794862, 0.036252176899823456, 0.05157016240240586, 0.27362157079961996, 14.980732913940185, 34.76695960567844, 27.943567191400838, 34.83398506718297, 15.515493173753063, 4.20008868940415, 0.07280177977536956, 0.00434973567251056, 0.06296269039833738, 0.03900569991298741, 1.0804900406829774, 0.7922973243459579, 0.8849864861657544, 4.735235792975272, 7.917999432932946, 2.357661204953348, 0.4387728749744354, 1.7745920535056823, 11.439752444144219, 30.09332218477803, 44.70564157732072, 51.72363258177235, 47.70178717951621, 51.61313156927786, 52.32409254197152, 51.49766483614522, 49.21025622275568, 53.29161574763637, 51.695171863802024, 50.67123320794875, 48.971156381791644, 49.875662788268066, 50.59279757161295, 53.286759853363044, 52.17139074879309, 53.103844042747255, 51.32522959862986, 44.53304944499847, 37.513513026698945, 39.36221238105528, 38.167038732959384, 45.16058160412697, 53.369768973319765, 54.325266192036295, 49.3117985417766, 51.63356711787563, 53.23189766176286, 47.49649424706736, 41.88841881290559, 38.61062349811677, 38.81948578742243, 37.6783977016326, 37.84787547203803, 36.21458484280494, 37.88456532262987, 37.383863003023215, 39.466657254003714, 42.555433550188624, 47.4000588540108, 50.89455335370956, 52.40634464448499, 52.43059273689024, 47.84573816484021, 52.187103763703384, 50.726338586499615, 50.43313357137865, 50.238756595119355, 48.71522957278837, 48.94369979058543, 49.42799483576129, 46.2796651932501, 40.380098819732666, 36.13665519222137, 36.38601203118601, 35.160020320646225, 37.32792215962564, 36.49481857976606, 35.39433879237021, 38.080962319527906, 48.40641352438158, 51.746656894683845, 50.404233547949026, 50.590934445781095, 50.82409581830425, 43.89047107388897, 37.1522548890883, 36.064338453354374, 37.37768527000181, 36.1535959089956, 37.721849718401515, 42.40386924436016, 44.47671244221349, 41.6983917451674, 43.04436091453799, 43.77614575047647, 43.19042605738486, 44.069237016862445, 46.00194177319927, 44.67547070595526, 44.39156955288303, 42.89633850897513, 43.73472159908664, 45.167131962314734, 49.09148293156778, 46.55203065564556, 44.44259958882486, 24.795529765467492, 7.888303168358342, 1.7523943801080029, 3.071579399608797, 5.989155759734492, 4.582531058019208, 6.330091607186103, 4.5023063305885564, 7.8560794265039515, 9.028752888402632, 5.718087621273534, 3.214067831154793, 0.9331064298748971, 1.0798347597160647, 0.06950859761526508, 2.793578471868269, 33.552809530688876, 31.59910832681964, 25.65362668806507, 29.784608117995727, 0.9968766918586147, 0.0677061306252595, 0.01200112164951861, 0.043397674322008126, 0.03867942306603636, 0.03419708475590714, 0.01672524496942999, 0.01856681308709085, 0.0957699920681696, 0.021710113975249475, 0.02353842302616085, 0.05524643065948641, 0.0891357089482969, 0.01612094140821888, 0.02381745714604134, 0.03781009330264023, 0.012401046359070368, 0.05378118791286984, 0.03916356765154389, 0.02122628923145033, 0.08650093339383604, 0.03692726123957865, 0.017421402472762332, 0.03736346787322433, 0.03006673894912726, 0.0580962470942928, 0.028329037032240344, 0.06675124799291934, 0.03582664570140262, 0.044003898848689375, 0.029496480335271167, 0.06339174943164953, 0.02749565019903164, 0.08831273133475935, 0.029789133583225554, 0.020376555997157292, 0.048634724150742256, 0.028784618029491078, 0.015018941166119711, 0.07746000038159472, 0.02115951509275023, 0.038854830387619235, 0.04425060597338504, 0.03285073502469928, 0.03129847809642313, 0.04288649832409236, 0.05053702005816083, 0.049738197196875854, 0.011777039974056666, 0.6366340191133562, 20.776353536113618, 40.729444719129994, 29.45297956466675, 32.470235363129646, 19.38571249285052, 5.969773857824265, 0.09566795681753466, 0.04336894602484761, 0.1238011951828676, 0.14866784996082708, 2.4418732668122938, 1.8009084607324295, 1.5036064073924096, 4.74094529305735, 11.447303006725928, 10.692624276684178, 1.6267539993409188, 3.247420970470675, 14.411211629067699, 33.77321143304148, 47.92757057374524, 53.635442872201246, 50.231374694455056, 52.862892843061886, 54.912880389921135, 52.07775200566938, 50.87285480191631, 55.75131054847471, 52.9415677439782, 52.675701648958274, 50.21346907461844, 51.74169117404569, 52.30137417393347, 53.792082725032685, 54.386859170852176, 53.976759679855846, 53.33912741753363, 45.41499045587356, 40.76171798090781, 40.68929926041634, 40.94626941988545, 47.12055075553156, 54.96085097712856, 54.77256544174687, 52.5573637408595, 53.599965033992646, 54.289913869673214, 48.7233998698573, 43.187158723031324, 41.397781295161096, 40.10610949608588, 39.03631048817789, 39.249240275352236, 38.99116400749453, 37.99980063592234, 39.592024049451275, 41.62760473066761, 43.21007713194817, 49.21935219918528, 52.70368776013775, 54.8304674702306, 54.26556771801364, 49.61996347673478, 51.63952519816738, 53.01747737392303, 52.55577910330988, 51.56622394438713, 50.888630574749364, 51.460123831225985, 51.63638730202952, 48.99809914250528, 44.72774413324172, 38.98708474251532, 37.834257002799745, 36.79370710926671, 38.5095989319586, 37.87480646564115, 36.89792056237498, 41.431086140294234, 50.22132950444376, 52.33549879443262, 52.212579557972575, 51.979480943372174, 51.48439938022245, 45.287332996245354, 38.08149576187134, 38.22225786024524, 37.73212632825298, 37.96233023366621, 39.37233601847003, 43.89353444499355, 45.05075523930211, 43.095481164993785, 45.26390860157628, 45.72410852678361, 45.68979955488636, 46.8489658448004, 45.081800799216, 45.87468439532865, 45.885886684540786, 44.25112516649308, 45.275130502639286, 47.833472913311375, 50.78901413948306, 48.10239845706571, 47.208490294794885, 28.576357287745324, 9.472966213380138, 2.55602355445585, 2.6948256934842756, 4.480812232340536, 5.590844952291058, 6.842109964739892, 8.037445900901671, 7.981094189228551, 8.817725450761857, 7.823503161630324, 3.024234675591992, 0.9684426337480546, 0.8087269072571109, 0.13284061134101885, 2.8562456898150907, 38.03656108917729, 34.327728671412316, 27.65805590537287, 36.51073555792532, 2.1845390623615635, 0.05815435869378909, 0.0143403462284515, 0.05697061112450977, 0.015730436707306054, 0.0887803973690156, 0.03411270783192689, 0.06837878646629472, 0.0553720154529137, 0.0027512750239111487, 0.021314261023015268, 0.04679618974126155, 0.13019025355817812, 0.008017359106170555, 0.04978862493449161, 0.012488136191912478, 0.04647907147544526, 0.06049559233830341, 0.031022316806258696, 0.01675553800117585, 0.02020091693397732, 0.058677229023869, 0.09700633540389039, 0.14887529124896373, 0.1054977688698038, 0.11339670227419947, 0.20067671644351176, 0.16686167207456407, 0.17389753082346532, 0.181890141459242, 0.1917366235847435, 0.19607032168536417, 0.08410510832383748, 0.11656400086658618, 0.15412023561375757, 0.15146181858595342, 0.1499010829795753, 0.0997343285369777, 0.13172736301297142, 0.12774136157766466, 0.1329363723315539, 0.22657629523065784, 0.14888431576471176, 0.18191727629352003, 0.13270164299155437, 0.20274555220478968, 0.17613300603003273, 0.1646140160700006, 0.1831547840828857, 0.8244694012307352, 25.037206603634743, 48.85281847369287, 38.2282865432001, 46.04715493417556, 22.817158814399477, 7.273554013621423, 0.6353913632131393, 0.07274550295645192, 0.5422624669248058, 0.17495274033036926, 2.505648309184659, 1.8800909408638555, 2.588088195170126, 10.936963423605889, 21.64680592475399, 14.414257349506503, 0.7964582236543779, 3.3061388519502457, 13.889082381802222, 34.76702236360119, 47.629109582593365, 55.499710113771506, 49.10069265673238, 53.97001712552963, 54.301983002693426, 53.617078335054465, 50.24505984398627, 57.607125082323634, 54.65553760528565, 54.80779224826444, 52.78652821817706, 54.44958963701802, 53.07229641945132, 56.78132887809508, 57.16678019492858, 57.01942851466518, 55.546586359700854, 49.08110041772166, 42.522007111580145, 42.626906979468565, 42.97627641308693, 47.789079527701105, 58.14026932562552, 56.695876121521, 52.869686388200336, 53.600926014684866, 56.769593146539506, 52.165817060778224, 45.792722548207934, 42.32691626394949, 42.39607549482777, 40.84537429194297, 41.698274074062226, 42.08658087638117, 41.08959282598188, 42.26133031229819, 43.82705027057279, 45.24750917188583, 50.80165593854843, 55.94436176361577, 57.277908786650634, 56.90089056568762, 50.650119089311175, 53.63237165635633, 55.11588265818935, 54.45641456111785, 53.48466696277742, 51.825280804787916, 53.17200699160176, 53.684009659674864, 49.63132266075381, 45.346894187311975, 39.83573659773796, 39.97236059558007, 38.05913040714879, 40.19533557276572, 39.348044779992875, 38.74106191819714, 43.361068771731475, 51.71819617671352, 55.14966995485368, 53.47050720645536, 54.86497256063647, 54.16198576650312, 47.94355423219743, 39.82862534061555, 39.22041869932605, 40.22981320658038, 39.40346394815753, 41.052255784311605, 46.769278972379624, 48.18235597302837, 44.29433007394114, 48.30667157326975, 47.40058052924372, 46.94795470083914, 48.89426615930373, 48.31723059377363, 48.807813198335715, 48.7192343127343, 46.578816521552305, 46.25538572188347, 50.697760197424124, 52.992491875925374, 50.11956361032302, 46.163402218972486, 28.74636261693893, 9.678920065203021, 3.012924276051983, 6.46372675895691, 11.551344856139153, 9.653570767371885, 12.164744715536795, 10.854629931911346, 17.017371654510498, 19.629862385411418, 16.3368502355391, 9.585826531533273, 2.5118873292399995, 2.5262459007001694, 0.5556695571830196, 3.8816459188538217, 43.74566108949723, 41.19679512516145, 35.07589332519039, 40.10635268303656, 2.5972832114465776, 0.16233881154368002, 0.1287523831330961, 0.12491957630000769, 0.1365558619821264, 0.2963604699940451, 0.11942536990729072, 0.22777162221891267, 0.24497225730409547, 0.10499664777589422, 0.08161919897482281, 0.14120659790933132, 0.3235408711817957, 0.09733886352830357, 0.13077943645898374, 0.11573222090279865, 0.18356416614786272, 0.14953582757903686, 0.13334062160743823, 0.18435162792523063, 0.23197321611787045, 0.17538168828093237], [0.06781630939052952, 0.0559511702627905, 0.0276449779724522, 0.011479947246581076, 0.034982696430937904, 0.0733317594013868, 0.05033161273346313, 0.010143282781955937, 0.03816253205220546, 0.030277807663585392, 0.06787407242002026, 0.04406792081652149, 0.05266423554970853, 0.02976279931082841, 0.011605885398063448, 0.055577055055407755, 0.031420933420679746, 0.028874097099047036, 0.052827412277580275, 0.020244932515666853, 0.0103144277818501, 0.0843192528813116, 0.02656467525558847, 0.009219374042004347, 0.05569711252446136, 0.045884774937745065, 0.15163110869546093, 0.028872790919136138, 5.39945044825154, 31.21955429354022, 31.311072995585782, 31.813326612595592, 25.260360048663234, 6.697261737238977, 0.38528357422159565, 0.13838967728999355, 0.07085267589577744, 0.40344473034624134, 2.6390500799302132, 1.256846054907768, 0.47778810885164047, 6.832833068986093, 7.760585402288745, 8.893643906039577, 3.1497159552189613, 0.7188620358224839, 2.6789513711006414, 12.847725460606238, 33.07928139163602, 45.36317986826743, 49.4063158958189, 50.96823899976669, 50.196143965567316, 50.221156920156176, 52.37086288390621, 53.40976538196687, 55.03733719548872, 51.07841837790705, 50.84426072336013, 52.04329398370559, 52.01753577878399, 54.12064006251674, 53.79262793448664, 51.43229069248323, 52.49931658467939, 46.566590493725194, 38.673271594509, 39.32501654471121, 38.320434785658314, 44.21008932975031, 51.32233881181287, 53.31400463657995, 51.340213052688114, 53.550186234135786, 53.03350417844711, 48.819388112714215, 43.312400002633375, 38.203352036014685, 38.30009729631486, 38.27457835597377, 37.28718834538614, 37.99131654923962, 38.17842145119944, 41.136818162856564, 45.437332276375066, 47.42660545533704, 49.933176502104736, 49.83902785085863, 52.76179767424061, 51.48454450791883, 46.63182735443116, 54.86678469565607, 49.770782532230506, 50.37224269682362, 47.76359588869157, 47.00574298058787, 44.27450641509026, 41.59374683134018, 39.994439617280044, 37.37335497333158, 36.946522651180146, 36.06596623697589, 37.20667777522918, 36.700476292640936, 35.403838772927564, 35.52630693681779, 38.835096820708245, 46.51338354233773, 50.878424567561, 48.930555928138, 47.28198766708375, 50.05711947717975, 47.13679329041512, 40.640246099041356, 36.488676148076216, 36.41742237152592, 35.874907585882376, 41.610648324412686, 45.790082793081964, 47.67057295768492, 46.08873205800211, 45.92567128519858, 46.23711139925065, 47.1193269760378, 47.438521615920536, 46.197860240936286, 45.1971027928014, 46.25162809125839, 44.38863954236431, 46.99934167246665, 45.99104542886057, 47.57183513333721, 46.56394289385888, 36.23501254666236, 15.901642672477232, 4.02256197025699, 1.541429945538121, 2.440321969409143, 2.222398514709165, 5.886182265896951, 3.4509355983426495, 8.55333318633418, 4.021266607507583, 5.029803341434849, 4.656640320054946, 2.9604993472176218, 1.0094763254446368, 1.1157392782549704, 0.12505311308608902, 14.006719166232696, 37.81891269068564, 19.08586690502782, 38.09610659076322, 13.08594669065168, 0.11371005521786791, 0.09065637049535591, 0.01870993171788512, 0.02523495154755731, 0.08966981012734676, 0.03024636741517292, 0.09306733346273822, 0.05185685165586972, 0.08215985020562526, 0.07828153008895536, 0.08839229722657511, 0.036767903460009445, 0.039806437994083094, 0.07388276814092552, 0.014778796542105416, 0.020631954389353915, 0.011038215203781523, 0.04545999450549003, 0.02925800291010209, 0.024505651165400783, 0.0196685777571533, 0.011302075037101825, 0.025630821736769813, 0.06509337243774245, 0.035585921723395586, 0.02543120603677967, 0.023545926857379176, 0.00484295217545643, 0.09750000246229673, 0.05585707168305113, 0.023411842318431988, 0.036299739468602404, 0.04113766898010527, 0.011629989396991029, 0.024082715089823452, 0.037123467848305745, 0.08475141840115671, 0.02920769008567497, 0.06251379734866562, 0.06087088349064993, 0.01565880365594621, 0.02913923629920089, 0.09269369706030815, 0.029125389259969516, 0.05048217965410121, 0.08711138289541968, 0.039505759975121874, 0.02157167805689237, 0.026881912265033014, 0.17432051860997755, 9.01386651300615, 38.25990869152931, 35.219867844735425, 40.13276592377694, 31.664808027205932, 6.25983166117822, 0.30483380080230776, 0.1712085162439654, 0.11592404165815924, 0.9077844660609, 4.311966944125391, 2.827911223134687, 2.282277172611606, 12.243468646080265, 12.022419552649222, 10.795704164812642, 4.784732672476, 1.9627340546538754, 4.507207332118865, 16.150383699324824, 35.298279946850194, 48.03203113617436, 50.38784196299892, 51.37239609995196, 51.98547432499548, 50.742812541223344, 52.93384459710891, 55.260068985723684, 56.18437159445978, 52.75520416998094, 52.968581107354936, 55.96137700542327, 53.73537309708134, 56.2748489072246, 55.01601519123201, 54.230121258766424, 55.44123149687245, 48.98193897739534, 39.56664239206622, 41.18122723794753, 39.08806224023142, 45.96159235123665, 52.96803982027116, 56.2824426158782, 51.203953835272024, 52.89374620683732, 56.123896491143014, 51.71638404169391, 43.58839365743822, 40.43182703756517, 39.959656038591945, 39.48228397677022, 39.492792006461855, 40.329606148504446, 40.040652982650265, 41.891388047126036, 46.173172843071725, 49.38049101060437, 51.29068136215211, 51.547055321355025, 54.581793123675936, 52.61914891581382, 48.325047877527055, 54.52382833726945, 51.02738834196522, 51.19328498840333, 49.647843683919604, 49.11509560000513, 47.09340010919879, 45.838214197466456, 43.16550723968014, 39.62340693319998, 38.771213177711736, 38.61687183380127, 38.59686774592246, 38.42302437751524, 36.55380710478752, 37.06781802638885, 41.84313897163638, 48.75719501126198, 52.135524595937426, 51.85690295311713, 50.654488609683135, 51.95085156348444, 48.18630187742172, 42.0230031782581, 36.92335321057227, 38.89306552948491, 37.033418839977635, 42.85916228448191, 46.574396010368105, 49.20152894912228, 46.80117960899107, 46.98529174250942, 47.21104768014724, 48.61697419997185, 48.712825159872736, 47.64573258738364, 47.38442820887412, 48.17802959872831, 47.154067408654, 47.80014061158704, 48.29295896714734, 49.16875754633258, 47.945648777869444, 39.023201927062004, 19.200672718786425, 5.434389450857717, 2.299187981313275, 3.5718659479771895, 4.053250594485191, 5.683932112109277, 7.224580280242428, 9.499318657382842, 8.388496560435142, 8.628607392311096, 6.482463430973792, 0.8532031529372739, 0.39310579158125386, 0.18182249589552804, 0.16886607984140997, 11.422775445445893, 41.124650970582046, 25.14096506180302, 38.818952345079, 19.136173263672863, 0.17147103925385784, 0.06840582170914258, 0.04771151542363148, 0.047472783274227576, 0.0034835660218020844, 0.03401003672831482, 0.02537944530617566, 0.13750188863806187, 0.07522510740184978, 0.04831438065476475, 0.06688301511589559, 0.006305530851316308, 0.08118082814279103, 0.10088919842195126, 0.017726424210254225, 0.006795677256905624, 0.041527527294331984, 0.021905715374516386, 0.026859498447588375, 0.032274621583881884, 0.09613321733570869, 0.03837070495430981, 0.1766426230390226, 0.15460330001529188, 0.1344386707510679, 0.07975143065015156, 0.08079201553858097, 0.13320954396359383, 0.14523246656021765, 0.06906029062285539, 0.11170449831913556, 0.0776837670033978, 0.13899335457432654, 0.11404001694773475, 0.3633919069843908, 0.13907121975095044, 0.2011535755328594, 0.12923549349990585, 0.11950351087556732, 0.11722562504151177, 0.13056470201380793, 0.15580074140621772, 0.1162646749928113, 0.22087920577295367, 0.188739427155064, 0.18476516218675723, 0.15444683421763683, 0.1835888954660585, 0.26222353080107325, 0.22610971704125407, 9.802494337481837, 44.92373320364183, 43.652092949036636, 44.6863748950343, 35.45294684748496, 9.005514806316747, 0.6202059683780516, 0.36864383807105405, 0.3448461440782393, 2.041342275277261, 9.160116007251125, 4.105794420165401, 1.4116102793524343, 15.805826033315352, 16.614761929358206, 17.614727058718284, 7.827478483799966, 1.8159235389001909, 4.202871120745137, 14.359364759537483, 35.6292809209516, 48.298697394709436, 51.04099504409298, 51.95497789690572, 51.28003604950444, 51.148044370835834, 54.44368646990869, 56.51209346709713, 58.394450679902114, 54.692631460005245, 55.80598054393646, 57.988238257746545, 57.92578235749276, 59.574389842248735, 56.070822900341405, 55.67273762918288, 57.740568037955995, 50.44996838415823, 42.88432036676715, 43.25608261169926, 40.596370466293834, 48.612561533527995, 53.511268477286066, 57.53765206183157, 53.0525198290425, 53.97381397985644, 59.12066575019591, 54.024898928980676, 45.97409294497582, 42.29438804811047, 41.71662684409849, 42.4346794620637, 41.68109801507766, 42.54881258933775, 42.25312863626788, 44.75536938636534, 50.407857817988244, 52.138897834285615, 53.22485700730355, 53.12435019400812, 56.101413465315304, 55.4042160895563, 51.79259569414201, 57.99516516347086, 51.826975268702355, 54.04883323177215, 50.03878631899434, 51.61433573692076, 49.25331992487754, 46.43033912104946, 44.657027721405036, 41.26656232341644, 39.579688195259344, 39.36763309663342, 40.92217037754674, 39.90171478640649, 38.122786552675315, 39.085469553547526, 42.87128633068454, 50.6001010248738, 54.1146662927443, 52.129997976364635, 52.67337960581626, 55.232953640722464, 50.260361010028475, 44.45985017284271, 38.08715181965982, 41.209589896663545, 39.442001235100534, 46.87372384532806, 48.8279624139109, 51.81264685046289, 49.69058182931716, 49.05014114995157, 50.102673884361025, 50.83529810751639, 51.37656950181531, 49.65362133518342, 49.02882306806503, 51.02397195754513, 49.047815184439386, 51.57639465024395, 49.549592233473255, 52.25277600749847, 49.72486726699337, 40.09290287571569, 21.31033520544729, 5.399082726047886, 4.213487996209053, 5.524556406082646, 6.315284169489338, 10.46622605093064, 10.667928053486733, 18.149714816001154, 11.530373904012865, 14.790834303825134, 12.42993224051691, 6.7792088754715465, 2.6056508527648066, 2.3416628376130135, 0.3036797046661377, 18.927562006058235, 46.69363998597669, 28.79134631926014, 49.0525887089391, 19.817789023922337, 0.3091776725505629, 0.39130759936186577, 0.14550782920372102, 0.16400129894816107, 0.15376847868244495, 0.12861372121880132, 0.2990877123609666, 0.18513245538117426, 0.2387747285707343, 0.18264761855525358, 0.16364053282285893, 0.13409829788631009, 0.21944001767664187, 0.19851668557572752, 0.15415645625081756, 0.14434332959353924, 0.10964731475518597, 0.11249625018887943, 0.10447251340073925, 0.17637447694376593, 0.13984617897339408, 0.12305167007951007], [0.07489784996235564, 0.036595579642321796, 0.009297266031705565, 0.026555618181103663, 0.035243553199595025, 0.01940007351579205, 0.03652800302652102, 0.03982847451322502, 0.06255688213352716, 0.03885156302262218, 0.03808518398493048, 0.019946144818658793, 0.039551250276065646, 0.035750013926336845, 0.043739767054155956, 0.006730648362258029, 0.04016735733697011, 0.09293224917904985, 0.037485160939996286, 0.037936386727397485, 0.034194257891466545, 0.03484298114574725, 0.04849248843628073, 0.045732530284552805, 0.01674518049243958, 0.025553801172082464, 0.004531568556558341, 0.06563548689648029, 1.0191776951955211, 16.934658673501787, 33.407654377721975, 26.157064860866917, 33.2761961413968, 16.038212737729474, 0.9628905800561752, 0.1733200690679012, 0.05725948372855783, 0.8742855248912689, 2.4687214003455256, 2.0088328132706303, 4.248611350213328, 9.086420555268566, 10.938580420709426, 8.82241072193269, 3.191862067868633, 1.804746254797905, 0.3207471017395297, 5.6845817546690665, 18.470637259944795, 36.809122024043916, 48.479604951797, 52.67461123005037, 51.875663649651315, 52.93924570083619, 50.56789052101874, 53.430667692615145, 53.786964031957815, 52.59948999651017, 53.142036161115094, 54.334699492300714, 54.063408759332475, 53.1303043519297, 53.63428969537058, 53.16243248601114, 53.98472993604599, 48.43115191305838, 40.253963239731334, 39.935051010501006, 38.04317420528781, 42.353941394436745, 51.51552730990995, 53.27297272220735, 52.18131434532904, 52.79409447023946, 53.429083055065526, 52.700910722055745, 45.69403571467246, 38.89851370165425, 37.67438511694632, 38.58179799972042, 38.60973704245783, 36.26168074146394, 40.71335123431298, 44.71744398916922, 51.72490735207835, 50.85876172588718, 52.8226807040553, 52.0121072184655, 52.917825637325166, 47.84373775605233, 44.84573295039516, 52.34059787565663, 48.5926398154228, 48.47483534966746, 43.301644863620886, 39.96342935869771, 38.35701873225551, 38.85411247130364, 37.79727297444498, 36.778311806340376, 36.61967546709123, 37.83572789161436, 37.789330174846036, 36.95801911815521, 35.93595927761447, 36.53542687816005, 40.34688026674333, 45.83228749613608, 50.59327610077397, 49.524559667033536, 49.553918607773326, 50.52550931130686, 49.10405805034023, 45.9886763172765, 37.38838549583189, 34.39493848431495, 35.36857666507844, 42.45618974008868, 49.11921408868606, 48.45554513316001, 49.112801013454316, 47.68270877099807, 46.53733745698006, 46.730267078645774, 47.55236056543166, 46.563232944857695, 48.063119842160134, 44.58673100317679, 47.53487463920347, 46.95987870616298, 49.92108775723366, 48.93481169977496, 42.65090011781262, 30.161255674977458, 9.91647449231917, 1.750020978431548, 1.4741492848242483, 3.3966291575662555, 2.709706920769907, 3.8276557191725704, 6.630123997888258, 7.039775358092401, 6.209129633442049, 6.6809770368760635, 6.337290137044846, 0.567557709592004, 0.19019762955365643, 0.16027262644662013, 2.6347876892935846, 32.27388543467368, 59.55683331335745, 26.349766985062633, 33.01955153865199, 3.2203674027996683, 0.17248581464011825, 0.0411045816426556, 0.08680028991112787, 0.0195251488607497, 0.047760345867925116, 0.04837251140645916, 0.04420334217889656, 0.06667390375608398, 0.05128749511054447, 0.07842694123786303, 0.03472699926445081, 0.03025829348893416, 0.02242015490698959, 0.06826417971282236, 0.03748683867255046, 0.0507157905057313, 0.04617166720450886, 0.035668785623725385, 0.08131139250772615, 0.04728577738147109, 0.007324050492306631, 0.10974381119012834, 0.15442104769810555, 0.04842870012526551, 0.035467151282054764, 0.03232926280508119, 0.023727449475817626, 0.03499212697328579, 0.017004432306895335, 0.024419952739751147, 0.020661387487404773, 0.007053304007352, 0.05510797941937082, 0.03552826594621424, 0.06352519045674032, 0.04886360440943991, 0.05223261395228967, 0.04358682143051298, 0.020418911083270947, 0.058038962869754726, 0.007666592343500065, 0.026733955788996913, 0.015382637577732245, 0.05812955659724051, 0.036672686391900626, 0.06745925879166012, 0.11220741971966722, 0.030631181040418246, 0.05352281326908739, 0.011644611142635828, 1.38759495510209, 26.03986836248829, 39.93853799758419, 29.409578538710072, 34.42528978470833, 16.529299366858698, 0.7015777439359696, 0.24072866646512864, 0.010304106662290232, 0.2311649320707206, 3.696422528836035, 5.137518490514448, 6.258052376008803, 13.632062212113413, 11.137087652760169, 11.105936188851635, 8.326772182218491, 2.982650197321369, 2.074301829261165, 7.71160823683585, 20.84323386992178, 39.512101834820164, 50.45322002903108, 52.15006874453638, 52.61276329717329, 51.07564918456539, 52.04028552578342, 54.839826245461744, 54.92101930802869, 56.256449068746264, 54.138533915242846, 55.62175858405329, 54.40211326845231, 55.614384528129335, 55.39608501618909, 55.74584668682468, 55.40918965493479, 50.94796819071616, 40.930058263963275, 42.531487480286636, 38.45312072384743, 45.26758778479792, 54.0111667110074, 54.52848811303416, 54.95521453119094, 53.05750123916134, 56.46520937642744, 52.61716419650663, 46.38050540801018, 40.89789090618011, 39.90852009865546, 40.168781126699145, 40.10321478689871, 39.19690409014302, 41.58915765823857, 46.921886628673924, 52.05083277917678, 53.41251496345767, 54.23231778606292, 53.099635339552364, 54.7521024365579, 48.67931635149064, 47.44634282204413, 55.33134237412484, 50.493251739009736, 50.614927584125155, 44.171787385017645, 44.0064634046247, 41.64142324078468, 40.595409485601614, 40.04964305508522, 38.142594522045506, 37.929460771622196, 40.21230766850133, 39.85441492449853, 38.486959011324, 37.66426932427191, 37.5982754461227, 41.2843345826672, 48.128333168645064, 52.296231946637555, 51.50675689020465, 50.45343575939056, 52.7097438996838, 49.197751706646336, 45.86833407801967, 38.43860795420986, 36.69754235975204, 35.360692701032086, 45.52988844533121, 50.49766832782377, 50.19415924626012, 50.64725183671521, 47.55667909499138, 49.00828946021296, 48.9995974879111, 48.759124817386756, 48.45507837110951, 50.04914137624925, 45.79178902410692, 47.90174568853071, 48.000252093038256, 50.939542939586026, 51.40741109848023, 44.95838734411424, 33.08971881866455, 12.057770894419763, 3.437415678654948, 2.669214087147867, 3.9274604282071515, 3.6123271574897156, 6.631263446423316, 6.537981638985296, 9.821189334315639, 8.865983351584404, 6.486540244471643, 4.291542182045599, 0.5199711469392623, 0.15075504118877073, 0.05578921927559761, 1.3694081503537394, 34.79444757584603, 51.038472960072184, 24.39111182766576, 40.77443038263629, 5.645234498285479, 0.040493630353481545, 0.06007792120198569, 0.03366864496661771, 0.036141155437836726, 0.04136277625577585, 0.0201039110505653, 0.07865774054681102, 0.03296798861195003, 0.005616016287897384, 0.017009404217523914, 0.017123551318241705, 0.038637521887017835, 0.031635129689088756, 0.05009179656964637, 0.02204579455147107, 0.05753348273555598, 0.0521095572490125, 0.03945809781491276, 0.06316738143082588, 0.061857658363277876, 0.10113544972433199, 0.04831515057312866, 0.21824833726690662, 0.1703714579343796, 0.11877964971767319, 0.19051652131301744, 0.12838709708904067, 0.1270741066564956, 0.13810564253118732, 0.1617551444759292, 0.18640298156007645, 0.0596031611935506, 0.11802854647319164, 0.12055857482576564, 0.09866763537208881, 0.13729355868793305, 0.166246319610265, 0.117847167496239, 0.1666113145409092, 0.18032572863082733, 0.09410170537810172, 0.1462513328559937, 0.09642969336240523, 0.18539010607186826, 0.12244700454175474, 0.1572314106048115, 0.2568667529210929, 0.1106051468260346, 0.13376094340797395, 0.19736805930733684, 1.4077974903968073, 29.211496883823028, 45.24668939651982, 37.50191457809941, 42.904955956243704, 20.434397382120935, 1.462849794376281, 0.8554412328427838, 0.11723366896471671, 3.3862503209421715, 8.229531722684062, 9.975132557653613, 12.804311686946502, 13.53264875950352, 23.593892051327614, 16.9147075376203, 11.38311832181869, 4.3177926444238235, 1.7392436535127702, 7.617942037120943, 20.822041303880756, 40.14868682430637, 51.046690325583185, 51.53607660724271, 53.27760896375103, 51.42560305133943, 50.64385898651616, 55.86648310384443, 55.10140518988333, 56.974187897097686, 57.13131804620066, 56.348173695225874, 57.93682382952783, 56.298077183385054, 56.4831385304851, 57.073741574441236, 58.128243338677194, 53.01940718004781, 43.99627700928719, 43.1145634958821, 40.74901342391968, 47.07771847324987, 55.63281182319888, 56.83124888327814, 55.79717874526978, 54.10590764014952, 57.54504965197656, 55.79753568095546, 48.91914575330673, 41.97293020063832, 42.120230890089466, 42.38647353264594, 42.684099058951105, 42.37958977299352, 45.35764932632447, 47.6241595514359, 55.62124475356072, 55.90417315883022, 55.87408073486821, 54.876747515893754, 55.93059032194076, 48.99953080761818, 49.86597845631261, 56.984778296562936, 52.44634889787244, 53.36390110754198, 47.0564043137335, 43.97001674098354, 42.803907855864495, 43.08315315554219, 42.89849189019973, 39.44462137837564, 39.73218994755899, 41.91495364712131, 41.20341608601232, 41.20708742449361, 40.2389209501205, 38.82109395919308, 44.00680857319986, 50.05897083590108, 53.96545148664906, 52.78219007676648, 51.190115713304095, 54.70818758010865, 53.04275312731343, 50.14298800499209, 40.10304220261113, 38.12640297797419, 37.8729433398093, 46.98442097633116, 53.1936937762845, 51.45218103162704, 52.83868005198818, 50.614641251102576, 50.183592381015906, 50.45826811944285, 50.76947681365475, 50.401079962330485, 51.562623208568944, 48.14586616331532, 50.671499929120465, 51.626444093642704, 53.73885223942419, 52.73953430114254, 45.385152985972745, 35.11832944808468, 11.458899494140379, 3.650595271779645, 4.281222916418507, 7.8662148310292155, 7.5869003995772335, 12.055257635731852, 14.284391595471291, 14.932799589249397, 15.52634244964969, 15.060519806800352, 15.22926409398356, 1.560700305046574, 1.5287804243064698, 0.357196124931497, 3.6936177890146937, 39.56913701949581, 63.364615363459436, 35.441811238565755, 45.708658310674856, 6.694014995328843, 0.2737733174956614, 0.1821045847910066, 0.297408263769842, 0.14326982590700352, 0.16019057842992968, 0.09754396824827118, 0.18028653557262114, 0.14710142998205078, 0.08936480754205296, 0.16581205500950738, 0.1370665974794857, 0.17936442618168172, 0.13004668868116795, 0.1820422865210041, 0.09459689695147738, 0.1759243543229757, 0.11787761183034991, 0.1662318558702546, 0.26810570710128356, 0.1706923721658607, 0.1280538871463749, 0.1235011645082024], [0.018612215287923332, 0.061406865415553895, 0.02298982554836379, 0.0035805726234215286, 0.009364359054504143, 0.0489489006389293, 0.01990175193866655, 0.04733739638580911, 0.08626678628065894, 0.027046510086004293, 0.02987743479259793, 0.117063520836734, 0.0602727335306906, 0.03249602482443856, 0.01574656477333197, 0.08410513130647522, 0.028154612218420354, 0.023230055399659662, 0.05728836141286358, 0.018975168594249317, 0.03622392740761561, 0.05837685744007749, 0.0070381268479620986, 0.08377363740075981, 0.024033338807883765, 0.062268128273107355, 0.02595123035022088, 0.0291875611254645, 0.05048232138036721, 3.614283194465022, 30.927908420562748, 38.01916145509289, 45.787815663122366, 19.976707773823893, 4.439251288290947, 0.27818675002744125, 0.10169568216247905, 0.17284176973325593, 3.2698983578912677, 2.4326780053877064, 4.700402204067477, 7.488251809150943, 7.0622833890299646, 10.40084602371339, 5.955926420227175, 2.8011013327106355, 1.5311745410003972, 2.922934072632944, 10.63082831521188, 25.87670168569011, 44.19485092163087, 53.83004342356036, 53.31482441194596, 52.70667660620905, 51.47213805106379, 52.565863517022905, 53.60274991681499, 54.65974630848054, 53.6611226297194, 53.638349348498934, 54.32810991041122, 53.31154923285208, 53.00456493131576, 52.718722205008234, 52.047475230309274, 44.15621165306338, 40.54257908175069, 40.34962592586395, 38.506308063384026, 46.27877873759116, 51.53428408407396, 54.10087523921844, 53.803292858985166, 51.92798414537984, 51.98163040222661, 50.935800998441636, 47.524507814838046, 41.983026381461855, 38.16363019327964, 36.71973905255718, 38.113765101278986, 38.139476237758515, 43.88330490358415, 51.094123548077, 51.24712344138853, 52.42366190879576, 53.75391414088588, 52.347685598558, 49.64380364264212, 46.7673413215145, 44.73373359249484, 53.66335838071762, 50.408155918121345, 47.86911156869704, 42.74780227291969, 40.36661371108025, 39.64594487221011, 38.21891207848826, 39.66334842866467, 36.294801235198975, 36.29597010151033, 37.07945962106028, 35.388984757085005, 36.1026756994186, 36.023043740180235, 38.09784027837938, 38.455195657668575, 47.177644775759795, 48.74481601099814, 53.06331026938654, 49.10812162583875, 49.78533844793997, 47.86637767668694, 46.73277347318588, 38.90987288567328, 36.671415452034246, 34.2928352663594, 42.17344568621728, 50.1599326441365, 49.07606801679058, 48.46003232463714, 47.78465117177656, 47.33758726427632, 47.53350180964316, 49.46143696385045, 50.45511061145414, 46.52747661836686, 46.84250962349677, 47.831068500395745, 48.76439256052817, 50.245153980870406, 47.16500297669442, 38.83142548222696, 24.612062861842496, 6.514915160594448, 1.3263657761196936, 1.971224637762193, 2.619121007380947, 3.3992814152471484, 3.282840218274824, 5.853681506649141, 7.806071167992008, 9.680310545429107, 5.250998543154809, 1.0905906341729628, 0.30687778467132204, 0.07375059499134941, 0.20730470998152611, 9.360504015799492, 29.48178545121224, 34.398684347829516, 38.40778204702562, 19.414296765481275, 0.7995657827104292, 0.1232395454820606, 0.11265201884652339, 0.03944848724190266, 0.03719116320773479, 0.023868767799989834, 0.050106336918449214, 0.03957915885914718, 0.04598715492794591, 0.08238551672548056, 0.0719826096188157, 0.03994599623124927, 0.052361305232249925, 0.04108257959747026, 0.017458806715665326, 0.05901636465662911, 0.03507512493900234, 0.09180972352623941, 0.02775665827005381, 0.01789403467198774, 0.034516646842201876, 0.09812093204668454, 0.07175294411999565, 0.0225008201349767, 0.03360367304975948, 0.037574888988127636, 0.029559487236603618, 0.021583569656697013, 0.023653234708152955, 0.023730395083886482, 0.15913870906637562, 0.03350084872856256, 0.027693496235916694, 0.06301704050612546, 0.08616825971271723, 0.04352954486685415, 0.010708740897356503, 0.02827338840542061, 0.13274858885955426, 0.03650724970465226, 0.021752128152236826, 0.02672869468017692, 0.03879471546820095, 0.030637901546733997, 0.06451086216275731, 0.026997258293352304, 0.026910948912583055, 0.00926155292789542, 0.025592264531540777, 0.038003932699681296, 0.05237426743992875, 0.18127822106884373, 8.161534003673061, 37.27442495284542, 40.483092415717344, 49.864527179348855, 24.114015986842496, 3.88485245646969, 0.3485508533495088, 0.15168717100975976, 0.15403697717814677, 2.4171971457619823, 4.967390587252956, 7.029717910674311, 7.87021613890125, 7.263089130001684, 10.221301490260709, 7.20305823510693, 4.732784311617575, 2.7006928238176533, 4.337397140841331, 13.237975797345563, 29.413514637177993, 45.277789869616115, 53.62208720176451, 54.084656238555915, 53.41117351285873, 51.532809272889175, 53.915860960560465, 54.45733631810835, 55.476677956119666, 54.75333013842183, 54.47801897602697, 55.37024836386404, 55.32263078997212, 53.60431102014358, 54.347839432377974, 54.184441335739635, 45.843352502392186, 42.255180035868, 42.22900998207831, 40.581214427948, 46.505899660048954, 53.85978675657704, 56.282532830392164, 55.229988328872196, 51.57712813346617, 53.51828951989451, 53.326411093434984, 49.01935054409889, 43.15125334647394, 40.17811636770926, 38.44454250028057, 38.99406263905187, 39.131537791221376, 46.143704075967115, 51.651276619203635, 52.62757416694395, 53.890793092789195, 56.381066691490915, 54.545519044322354, 50.70136485561248, 46.42964093915878, 48.03532984948928, 53.3889062173905, 51.411827687294256, 49.81582703128938, 45.246108885734316, 40.864111454256125, 41.21174720025832, 39.088128920524355, 39.79168838070285, 37.576161123091175, 37.991500900637725, 38.31532001495361, 37.407150114736254, 38.23489573694045, 38.01748660302932, 38.753013380112186, 39.268102953510905, 49.51450663228189, 50.942822041050086, 53.0417097768476, 48.74279206798923, 52.07017790886664, 51.31920091567501, 48.418055119053015, 40.668644059088926, 37.98373460769653, 35.77727586992326, 43.55438670804424, 51.27146567067793, 50.78666071737967, 50.04427763723558, 48.58940778240081, 48.79683056185323, 48.821317918839, 50.04695661606328, 51.209429464032574, 49.78578559813961, 47.56544951469668, 50.939131090717936, 49.55508747408467, 52.26238581442064, 49.67355482039913, 43.39014137944868, 26.64903794565509, 7.978464730324284, 2.150222981168378, 3.3826772868633275, 4.18614270225648, 4.504646514692615, 4.061020319500278, 7.895982188563194, 6.959169180162492, 7.233830699997564, 4.438261870414981, 0.9225931907853774, 0.3837323993925126, 0.08326014398687309, 0.19050317606137646, 10.20270259149613, 42.28764941615444, 46.70471283697313, 37.89413198348015, 26.984049543257687, 1.2783381919707022, 0.09815875380750626, 0.014610193038900054, 0.05389890498331478, 0.012109769196549972, 0.04568019115756597, 0.023968340077948187, 0.06981121766711436, 0.04341187759212429, 0.11273535389092662, 0.04742712443394046, 0.05330337504405649, 0.009156171788251209, 0.013877490268749817, 0.04994743879163458, 0.038980097254557956, 0.05574606554282289, 0.050427308606524626, 0.021816916207993226, 0.022704595692395683, 0.0404183468931625, 0.022541748382331386, 0.04065013828597242, 0.07762827159416291, 0.15246612921116814, 0.16278747859741413, 0.11658531343263966, 0.17078410353391402, 0.17499265351122426, 0.11041750124986134, 0.25524281506096164, 0.21970992577412438, 0.12497114933907025, 0.10694595849922589, 0.25263495983616, 0.2666545833551115, 0.09538828875989684, 0.04782325317782741, 0.20902663048717285, 0.09989511507052569, 0.07893178551908463, 0.16874344448649115, 0.08490903333069817, 0.19316389135295348, 0.14506476991359266, 0.0967309880821455, 0.14703746164037337, 0.08152115504227339, 0.2151223767789141, 0.14075132717768993, 0.12996706150231824, 0.25723087451150345, 11.038314527080907, 46.53448589386479, 46.71185939542709, 55.43739934121409, 28.4235123280556, 6.297086333074878, 0.8840532072128788, 0.28033608630780255, 0.3778336449496208, 7.095560287275623, 11.067206705770186, 14.713336113960514, 17.915627764117335, 19.108995160748883, 21.017089005439512, 13.604256529961864, 6.983081909918017, 3.1704640676898346, 4.843350043219905, 13.261308016315585, 29.855777563587313, 46.9403100013733, 55.36973845574164, 54.63826740941694, 53.19753769905337, 53.84607022808444, 55.0583375653913, 54.538721576813735, 57.53769520790347, 55.46214165226106, 56.11049767463438, 56.95216378858013, 57.1346991292892, 56.267623901367195, 56.96614311587427, 55.49610545558315, 47.92550348466443, 43.66781380868728, 44.848812010980424, 41.42325316706012, 49.47965637330086, 56.15588734226843, 59.13120908121909, 56.01318759302939, 51.72151057950912, 56.10755197463497, 55.05013588936099, 50.360754074588904, 46.23897060271233, 42.12361589554818, 39.273880604774725, 40.87631787023237, 40.872654376491425, 47.8321942206352, 54.59601563792075, 55.259461018346975, 54.98351050961403, 57.43088514574113, 57.58449300642937, 48.876238945991766, 46.91324564718431, 49.609369154899355, 55.79369175818659, 55.05632146712273, 52.45327188122658, 47.85202180185626, 43.974268590250325, 43.89524852075885, 41.42755992950932, 44.638416074937396, 40.24473782508604, 40.41752607591691, 40.26754640763806, 38.0659592536188, 39.733488252086026, 39.51086628821589, 40.710899752955285, 42.1363792880889, 50.32018107752646, 52.90086530870008, 55.399128775442804, 49.14711783009191, 52.81944082629297, 51.2758901042323, 50.0990653038025, 42.86972914972613, 40.272398379541215, 37.06949287845243, 45.678922822398526, 54.64685347772414, 52.683154152285674, 50.53011025151899, 50.69012334269863, 50.44726587110951, 51.038272919193396, 53.63279134996476, 53.741946989490145, 52.64732330076156, 49.7398114973499, 51.45763704853674, 51.328767576525294, 51.75057142011581, 50.227985766626176, 46.09874586905203, 27.867857602334794, 7.751713491255238, 3.035645095571395, 5.242879236898115, 6.607065854534027, 8.960432064148689, 8.912478147014495, 15.367615895886576, 15.74793283016451, 14.859339479477176, 13.817158860545005, 3.2791750084969307, 1.0088037615341525, 0.19929610342989046, 0.32926927831384445, 12.995615486175785, 39.95709473086942, 45.5814480012463, 47.406075769855136, 31.603497459042458, 1.691192289994609, 0.19969561828240273, 0.26090889327949096, 0.16702169252018775, 0.142280729787965, 0.21545780071568107, 0.12971319528597017, 0.15172596570224534, 0.1673324331040344, 0.1866261889376948, 0.17175954796614187, 0.1302761933015239, 0.12880525852162994, 0.08315908166790202, 0.09629026536018619, 0.14832510222350398, 0.12759925992858986, 0.2488117827282798, 0.220484379378538, 0.12419741585730545, 0.2545855882307214, 0.24790897875303225, 0.19842924430005013], [0.04677030363030011, 0.03366900885838174, 0.05523063392648774, 0.04244210987141536, 0.04621721879248658, 0.07260959129780531, 0.047274542702061516, 0.015147422729510696, 0.09230677669327106, 0.01900978427710793, 0.015941893253775857, 0.003951763290153336, 0.09974893783369373, 0.007863732143079923, 0.11046499870116673, 0.05857241670450857, 0.06715899062973839, 0.129677189153529, 0.04497075543528603, 0.019565395289851774, 0.01806723949078831, 0.05399574232738345, 0.07717170617392949, 0.05121074459185043, 0.06324009083571934, 0.06404070634274714, 0.03488491296828274, 0.014085462072774047, 0.06265655783335529, 2.8662371923846583, 31.607904241931056, 34.996626146378055, 28.90755634154043, 30.315616630738784, 12.722953884832322, 1.6569922864437105, 0.12279095503711894, 0.31460905207260964, 1.4190452545881274, 3.5813808825708207, 2.36384678271509, 5.019326690704593, 4.765145826724268, 6.674014829820202, 7.734102049181539, 2.5984354076846956, 2.0836130457539714, 1.750692806897625, 7.0682802027271645, 17.511131378912157, 33.1853344363551, 48.93538436582012, 56.2828819213375, 53.72406098150439, 53.33123560874693, 55.9201999633543, 57.75761465872488, 54.797499948932284, 53.4619721289604, 53.725371053141934, 54.88412941655805, 52.098607247875584, 51.14889160279305, 49.840938045132546, 45.74967845793694, 42.20966877475862, 39.24367050970755, 39.73206835408365, 39.71733200934626, 43.09074686419579, 52.17056312868672, 51.07892828602945, 54.096921490084746, 53.09983930280132, 54.576733266153646, 54.496760060710294, 49.103763872577304, 41.29674103952224, 38.044111651758996, 39.07364360747799, 38.71987327452629, 40.11899055973176, 45.505883539876635, 50.95271033625449, 52.722515136964866, 51.67977656087568, 49.02695601986301, 49.73932512344853, 49.95636947693364, 49.3252444267273, 45.267003351642245, 54.57678425696589, 51.70803723796722, 51.07150323929326, 48.43876915593302, 41.958331138856956, 39.206933590673636, 37.09340364702287, 35.61075556662775, 35.2623196571104, 35.80187305327385, 37.11987572331583, 36.88825191990022, 36.94310626676006, 36.201895975297504, 36.995850378467196, 38.715021302623136, 46.33770058231969, 49.47987602603052, 50.087859092220185, 49.90407251542615, 51.8558870592425, 49.82686458095428, 47.84487132103213, 46.349793249560946, 37.318206448708814, 34.698733898901175, 41.35647873724661, 47.917035087462395, 50.43938582943332, 49.5550835517145, 48.7898918890184, 48.7585090052697, 46.426577568054206, 46.80818103974866, 48.485661091343054, 45.82968696471184, 44.861720531217514, 48.47294476724441, 48.17447985372236, 47.127885587753795, 43.60761327128257, 36.41890502745105, 18.099841879260158, 3.984555674176063, 1.8270086473034275, 2.543767618556177, 3.5566341588574075, 3.1131572588797543, 4.101984818135539, 3.9880397194816224, 5.09330504363583, 4.9123974865482705, 1.666821255799263, 0.5273885327962138, 0.1675826374201044, 0.03330097255867816, 1.5117954582937303, 23.436424578389815, 30.30557928546783, 20.814777074321626, 33.8200641447498, 10.735535006369314, 0.037073193328274835, 0.061707983935071584, 0.022317020320183328, 0.032349859078925465, 0.023078063555482416, 0.04310837270872247, 0.05386827678810205, 0.021093150811089624, 0.05863088836532928, 0.058743173872391065, 0.011707656348364489, 0.049700011544290094, 0.0757865502589172, 0.05945951970774801, 0.09440887599222123, 0.09864633812779382, 0.08750161276228967, 0.05723280471659476, 0.08735599476964244, 0.0430597874125646, 0.050360980714040424, 0.057176087397120656, 0.0895258545454952, 0.0931739422582811, 0.00690916839483825, 0.02449023364592464, 0.07149710139680295, 0.05688610779602201, 0.08215867043022188, 0.07882482432309659, 0.07364965524644622, 0.12830786061503235, 0.06297123227869311, 0.014654291932651354, 0.03517418010761181, 0.027513469404150403, 0.05933728654898944, 0.027895454249735323, 0.059357086091392466, 0.018132153951052218, 0.016010145942169814, 0.05178865067841065, 0.01616669600949653, 0.03870340161806634, 0.021332254513136802, 0.047099564389716235, 0.025282297696497653, 0.010603504356808, 0.055216852004729935, 0.05422567595697699, 0.02775202535333172, 0.0766104701606016, 3.306518831560689, 37.89492430225496, 40.01745216308102, 40.3328146473054, 37.44409884175947, 14.078399500539227, 1.4509254213302367, 0.0660133904086486, 0.14628940742583046, 0.8616840526942284, 3.161361227112432, 5.248256806404361, 10.660496142602737, 7.949541662969898, 11.020894300553108, 9.283943272406056, 4.670629453274512, 4.124629151436591, 1.8206026813676282, 8.273797631263733, 19.623982752523116, 37.00546410775954, 49.99390263711253, 56.69951608104091, 54.52172986922726, 54.839877236273985, 56.50710028986777, 58.39831421452185, 56.670329724588704, 54.710709664129446, 55.71551107591199, 55.74587022104571, 52.88170453040831, 51.76633150346818, 52.30215080322758, 47.84944088228288, 44.21250158740629, 41.191437167506066, 41.61922262560937, 40.72669121526903, 46.06915550847208, 54.94590282440186, 53.969271875196895, 55.47390484040784, 50.98510519150765, 54.638400770002804, 55.663661264604144, 50.91169018899241, 42.73538012658396, 40.560727888538, 40.39739647219258, 39.394324825656035, 42.49962606737691, 46.66721105575562, 52.180165090868556, 52.873055704178356, 52.18527201683291, 49.13597045406219, 50.355729518398164, 50.747660590756325, 48.888645402846805, 45.870573751388065, 56.52847328493672, 54.021792411804206, 53.02915819229619, 49.840137881617395, 43.11433992078228, 41.43550272910826, 39.456619908732755, 37.3697385480327, 37.383192277723744, 37.58001289060039, 39.011058269008515, 37.526241117908114, 38.346565615746286, 37.498855129365005, 38.51427047483383, 41.13274282024753, 47.27236217068088, 51.96149295376193, 52.24018519924533, 49.61231485489876, 52.68985748291016, 52.89344026196388, 49.78726433169458, 47.04047556846373, 38.853720234286406, 35.56087478514641, 42.32535908299108, 52.34611665048907, 50.27774887700235, 50.29799222946168, 50.702341525785386, 50.079763320184526, 48.77341008955433, 49.33639180275702, 51.12786769866944, 49.01613420055759, 47.85280235352055, 50.23430862734395, 49.31008838838147, 47.497000232819595, 44.70721052538964, 40.28584818686209, 20.45488392153094, 4.624130245177977, 1.173438814378554, 2.9786432510422123, 4.686440527439117, 5.69892684298177, 5.785906382145421, 6.412861462562315, 5.62578885785995, 4.910872665143782, 1.9227138666375991, 0.38453204196787655, 0.07177357486779652, 0.06933581414482287, 1.3180854075377988, 23.65122337495127, 33.034546759820756, 25.52655170040746, 40.99718962946246, 14.130266962512849, 0.0512822205951858, 0.06224981877171706, 0.020045883720740676, 0.02049897684745731, 0.025228841996361173, 0.023052305764248295, 0.01185205530360221, 0.042035140983399846, 0.005441808851525909, 0.03447598672562069, 0.023668859071368654, 0.014984085123174855, 0.02218466330950539, 0.039633731132433306, 0.01437166294518618, 0.08206166071637024, 0.03594678744012791, 0.06997640920622696, 0.06096524254028356, 0.07427869004107292, 0.02954188062088384, 0.024198377129411506, 0.1559993267179497, 0.18857088781172232, 0.12416807468980552, 0.13883440665179683, 0.17015779601229777, 0.1622452415646084, 0.20458774851454845, 0.19440708351471733, 0.20438626739046267, 0.27539429825640493, 0.14203570422626313, 0.12419357775680481, 0.1067977894337908, 0.18043891046076052, 0.12000973411505261, 0.22330349100933922, 0.11496742000623096, 0.2341518629222147, 0.19922721680373917, 0.1317942578105196, 0.10138129500011284, 0.18615479971612656, 0.13463007015807016, 0.19808232904441897, 0.12556948699057102, 0.16592204991367557, 0.19788582749184103, 0.227633404635614, 0.1014033200279359, 0.2999076409445655, 5.8009550456077825, 43.760330753941695, 47.20589368574081, 39.11999817817442, 39.94452745683732, 17.281033377493582, 2.678672637670271, 0.1904113834062892, 0.6519557775989656, 3.0828167450043464, 7.855519998458124, 13.39168171728811, 16.046233004139317, 17.187082805941184, 14.135934787411845, 16.94818300585593, 7.93593398024959, 5.350549278720733, 3.278838420106519, 8.34189978338057, 19.748423868610015, 35.94340001383136, 52.169343271563136, 59.00506957884758, 56.350311386969786, 55.396186997813565, 58.47716169972574, 61.14189840132191, 58.215916156768806, 57.32992333750571, 58.00015049595987, 58.02284532977689, 54.75308695147115, 54.46271388761459, 53.7398132201164, 49.70425128936768, 46.67003516227969, 44.00724787865916, 41.919464372819476, 43.05641828044769, 47.82452598694832, 57.314269158148, 55.96919036680653, 57.15216152129635, 52.024443072657434, 58.28105103585028, 59.03322827431464, 52.52830682262298, 44.9153354091029, 42.043254375457764, 41.570216532676454, 42.383586668199115, 44.71170556160712, 49.76123940560126, 54.742998615387954, 54.58496632114534, 53.56009021882088, 49.21325291356733, 49.984704679058446, 51.47845698941139, 51.021253755015714, 49.49501245252548, 57.947229877594985, 55.350828709140906, 56.33012687006305, 52.58731103712513, 46.1489208282963, 44.05234729090045, 40.783569505137784, 39.34284763951456, 38.3383600173458, 39.6377275066991, 41.56350535731162, 39.97786368093183, 41.23521474099929, 38.620919719819106, 39.882142159246634, 43.202503035145426, 51.30258575562508, 54.58638229677754, 54.25455370256978, 50.72390671699278, 53.91194643512849, 54.78284989633868, 52.09737562364148, 49.557966493791156, 40.62015964138893, 36.638828400642645, 44.433060384565785, 53.680299097491854, 52.94193644677439, 51.12995832197128, 52.085443773577296, 51.115488698405606, 49.58058288020473, 51.23735673965947, 51.64985672120125, 50.52516806510187, 48.52993680584816, 51.56588662055231, 49.56688988593317, 47.754888226909024, 47.80871883515389, 41.148706866848855, 19.272485433086274, 5.317231685884538, 4.012801642379453, 7.373594064866343, 8.821038872964921, 8.323992202358863, 9.445110521008893, 8.958106098636504, 13.189208968993157, 14.021547686669136, 6.6250195234052605, 1.473709856790881, 0.4541098632879796, 0.1955062205031995, 2.6711980710106515, 29.806696945621123, 38.59044682595038, 31.08092204216988, 47.495042970103604, 18.0826638590905, 0.10893813950280029, 0.20413733478034699, 0.10276450505179745, 0.10336108836195163, 0.12723916029978183, 0.10411196178005588, 0.11682630171098056, 0.17094741815761214, 0.14481756866218584, 0.18554919189022434, 0.09935679274701303, 0.1900723435345196, 0.18164554490677773, 0.11543593639808318, 0.22983379301524934, 0.200228754190668, 0.17142597796215167, 0.1686063453915619, 0.26640876106196837, 0.09371254803432573, 0.10109632561403899, 0.12162583489571849, 0.24837474488923628], [0.037158688740624536, 0.03456836160753043, 0.05370298182711967, 0.04038949219149448, 0.0583731534049636, 0.07068290315087765, 0.09217906983629351, 0.03570245135755789, 0.03220984501944434, 0.03369615901441824, 0.02407279616642383, 0.04470064815494322, 0.0958536105651048, 0.04779593831288719, 0.03090648814254711, 0.08577940880411095, 0.028186017992876233, 0.02424380805854115, 0.02239101866800939, 0.04203760778651603, 0.018658670859651703, 0.021526256703861782, 0.04683166344259535, 0.06781840847144205, 0.0995642876613044, 0.043140467962310206, 0.024693183743605213, 0.09815532173360549, 0.03149028544524505, 0.7666284759198466, 18.868893154205818, 32.86737730426173, 31.64653958812837, 30.525594834358465, 25.565094870905725, 5.836650085064673, 0.6297342635450826, 0.015556921622896147, 0.6424075028588695, 2.714340955980363, 3.327951642774767, 5.259034008749071, 4.4051403960874005, 9.134586280392064, 5.726230952047533, 4.37952829945472, 3.4403496115438403, 1.0144018417885228, 4.42305140918301, 14.218244744885354, 28.126839937702304, 45.35198150142547, 54.84401925917595, 54.08086722896945, 57.21635895390665, 53.43269163562406, 53.60047101974488, 52.92366604651175, 50.03578962818269, 50.274787487522254, 49.68731057259345, 45.350149754555, 44.034865287042436, 43.75851077418174, 39.56705424093431, 37.88643237083189, 38.82050560366723, 39.67979492679719, 41.956962231666814, 43.75130145780502, 51.37890723443801, 55.037164611201135, 51.905826676276426, 51.717545063264915, 55.79502928641535, 52.591853141784675, 51.60436507194273, 45.55534462774954, 39.56552059419694, 38.41586997432094, 38.60219432461647, 38.899098134809925, 46.68456362139794, 52.31980931374335, 52.02821247039303, 52.02785553470735, 52.35662468018071, 49.12026528389224, 50.991600636513006, 50.157622368105, 40.13905348316316, 51.089102914256436, 54.55109665470739, 49.89474511915638, 52.833710408979854, 48.87651351190383, 43.60158066595755, 37.85603400199644, 37.36950712819254, 36.159695194613555, 36.45845428589852, 38.899149125622166, 35.87202856617589, 37.36372555455854, 37.02670766461281, 37.06291114130328, 39.65775512879895, 44.094395099147675, 49.57711942734257, 49.38977133843207, 51.821750671632834, 49.396894362664995, 51.34808132725378, 49.46842662749752, 47.85152366084438, 42.40441837618428, 34.87281260951873, 38.09177237172281, 45.247089478277395, 50.06521132684524, 50.26906867181101, 49.12435631598196, 49.13539386564686, 47.09667921066285, 46.92581684358659, 47.84406331277663, 45.390146163202104, 48.28467099897323, 48.68079116267543, 47.7984030016007, 42.48521920173399, 39.19984979014243, 27.849726446213264, 10.678259576520613, 2.4499827671435574, 0.9742673534539439, 1.8932892261974275, 2.9323901716739904, 3.4856027316662574, 2.9730568153242913, 4.783236288255261, 2.1022722509599503, 2.8373057899936556, 1.7215582992761367, 0.13685593862206707, 0.28570136776374233, 0.451308218461852, 8.362045076585586, 33.193308614915416, 25.925594029888032, 23.6716785353999, 25.987955793257683, 2.9066138257903438, 0.033304887267971234, 0.05186832765297544, 0.051115010414392724, 0.07822903008350442, 0.04499820053517338, 0.036610208091235934, 0.08434410477357526, 0.019207592009596767, 0.050048811376214995, 0.031189689780735684, 0.016848144624682686, 0.024560233014785958, 0.08300615519645714, 0.03307745874589009, 0.02762528376713876, 0.05276573070835683, 0.03086177350562667, 0.046750071248219865, 0.021838665444163546, 0.01379437930506444, 0.040928435046225786, 0.0487924961283082, 0.027757223259897965, 0.057314680363502235, 0.02303947953717603, 0.03546898989307304, 0.03146824318044369, 0.03686489402166298, 0.02560516353696585, 0.01175522753563259, 0.035636249869581194, 0.011549384498427953, 0.036932742598676876, 0.021301480761218457, 0.03905787433107053, 0.03644714244611321, 0.03528061270293209, 0.052234391276274, 0.06476202408873266, 0.07987800369700117, 0.014072162786408538, 0.055845859986279285, 0.031166170881460273, 0.05688637592679551, 0.08811752447077344, 0.010247272514407674, 0.06038152567681767, 0.0161471473608887, 0.04860732118569074, 0.04948684374891943, 0.07147249465267505, 0.11477730762694152, 1.5322248781881027, 26.376313586388868, 38.10814826719223, 30.717722331323934, 35.738844486974905, 27.812793408670736, 6.281076688920298, 0.2944348313875737, 0.10499366769386877, 0.1093403126804098, 0.6436097093166844, 3.7061492714189717, 8.46582216601218, 6.859306616167869, 10.290593101132302, 6.679946434113288, 5.196187832663137, 3.6333093864302484, 2.4682507159248477, 5.171972099811801, 15.244391695145639, 30.42286207599025, 45.59958504092309, 57.233303593051055, 54.83529590791272, 61.44903175292477, 54.05651323256954, 56.39893700999599, 55.32017538624426, 54.70439464815202, 52.86311249579153, 53.07614426459036, 48.60645832553987, 47.44990041179042, 45.08935528416788, 41.327806211286976, 41.74752335394583, 41.78264425646874, 40.8281982329584, 43.82203748149257, 45.06892365794028, 55.27587613751812, 56.56736750756541, 53.10811550386491, 52.79398464387464, 56.12088803322085, 54.89021301269532, 53.70521007045623, 48.15276169007825, 40.673978482523275, 39.94836353486584, 40.151824720444225, 41.03202812133297, 48.420765476842085, 51.214293203046246, 53.7652458683137, 53.30634817000359, 53.33945689662811, 49.95569875163417, 51.64674235928444, 49.24034864671769, 43.82840741065241, 53.271341016215665, 55.42755811445175, 53.01805788470853, 54.153564437743164, 49.34968863764117, 45.776636908131266, 39.60010413200625, 39.26691447534869, 38.385789317469445, 37.87218632236604, 39.80115305992865, 37.43080985161566, 39.14219487097956, 37.43548531686106, 39.11953533849409, 41.28212628826019, 46.51077908854331, 51.42494409315048, 51.87665208693474, 52.99370781067879, 50.89529075930196, 52.53791270717498, 51.77355258695541, 50.14143866877402, 43.45990073296332, 37.32400763419367, 40.59591547135384, 48.954737340250325, 52.054923811266505, 51.1826906665679, 50.04792936386601, 49.85478008947065, 47.660111996435354, 47.93879247480824, 48.718869532308275, 47.318897170405236, 48.96080916927707, 48.99001513758014, 49.989607641773844, 43.67754128671462, 42.44551304847964, 30.962790058505153, 13.219790708634163, 2.5194413238956086, 2.77444465987144, 2.725222836579046, 5.138597142311835, 5.712942452199998, 6.595548795115564, 5.910550480888737, 6.529530402152769, 3.1405363832750632, 0.4721270868134114, 0.27920852745732955, 0.1865212348920684, 0.13726182732610934, 8.316630894137967, 37.77349164409023, 28.305486248385524, 27.897791170304824, 33.8426060061301, 4.024154942843222, 0.01853602209819421, 0.020809029867391915, 0.023885238690361865, 0.023621587616000927, 0.007747205381747336, 0.01890050566514894, 0.041476287503516486, 0.023988139620351217, 0.08918770333571781, 0.022177575080985987, 0.08438944951781342, 0.039493188472284425, 0.09529811255032979, 0.06753181497896872, 0.01509897054112967, 0.0333666454459871, 0.06429608175230604, 0.0995097192184579, 0.026866155751650373, 0.03540458488127878, 0.006109125538533855, 0.02081180502089762, 0.08210355806494914, 0.13520722547846456, 0.19259134788186322, 0.19278093932136414, 0.07792519195185554, 0.23882501458208408, 0.23280221518249283, 0.1895436356144567, 0.11617636037690025, 0.07850235493312921, 0.10681321078370656, 0.22199761753361072, 0.12873750570560658, 0.16925365904406195, 0.1982098367185362, 0.15785508278396823, 0.1517255673365247, 0.2188294915662658, 0.08807307604940669, 0.24757678770730573, 0.23882395738074857, 0.0701635338426117, 0.2051685963787379, 0.10231605250268214, 0.25504458214967485, 0.20718259556639582, 0.10691287116177621, 0.11621615864456662, 0.2398380739313941, 0.1354762295921964, 1.6037052941899148, 30.52681665266714, 43.64624077273954, 41.02497962213332, 39.471823015520656, 34.83959797889956, 8.81202232453131, 1.2155680118068573, 0.1899884415850524, 1.4968583372331437, 7.239378402310034, 12.997596283112804, 15.067702647178406, 12.186837465532365, 20.273513524763047, 12.532679707773271, 10.874450648984602, 7.050960977231303, 3.414980701861843, 5.42688399553299, 17.175417677048717, 32.00053741855006, 47.44179679501442, 58.97593029083745, 57.881428195584206, 62.412110913184385, 57.94629635349397, 58.645133279985004, 58.33147310441541, 54.032225916462565, 54.38465087644516, 54.66956007865168, 49.31339886880691, 49.169581244068766, 48.11664058316139, 43.52360002456173, 43.77782844728039, 42.4630734997411, 42.53564127029912, 46.66237085096298, 48.05387089329381, 56.68497193244196, 58.866809952643614, 55.3716996408278, 52.549852401979514, 56.80265872709213, 57.262129091447406, 55.21402820464104, 50.90914064838041, 42.49307570918914, 41.06670579602642, 43.065337750219534, 43.051821262605735, 48.80482435226441, 54.30837254370413, 55.8614585476537, 55.71549930880147, 56.71212650114491, 50.87325880604406, 50.93899773013208, 51.25620372833745, 45.72935665807417, 54.73109814428515, 58.776885694073094, 54.65585923963978, 57.686102005743216, 52.868694028546734, 49.40418212644516, 41.440907755205714, 41.27849025111045, 40.494271170708444, 41.18019957696238, 42.2863511116274, 38.7605639426939, 41.360487399562714, 39.144607128635535, 40.18559240525769, 43.07925431959091, 48.48877545325987, 54.3193434130761, 54.04886461073353, 54.23617739831248, 51.01736668617495, 54.844748820028, 54.4750811207679, 51.35499646586757, 46.28245399844262, 39.50855208981422, 41.6874247981656, 48.54113125031995, 54.933919983525435, 52.461226447936035, 52.236913942521625, 51.1743595523219, 50.0526205185921, 50.48257896977086, 49.999288051359116, 49.66331743424939, 51.59572016808295, 48.93375658219861, 49.982543453093506, 46.39148019975232, 42.762134613529334, 30.302074647718864, 12.743925817551153, 3.773570647162776, 4.260037704821556, 5.870785001785525, 7.213003404678838, 10.342258561042048, 11.134170389944508, 11.797137241209708, 13.137969086247107, 10.0898697299342, 2.88985746041421, 0.7645013868328064, 0.5442949288314389, 0.6449537952580761, 11.328500297761734, 43.15275953662011, 34.3036727751455, 34.10727970061764, 38.0872106552124, 4.895792132423771, 0.09226756065242714, 0.2213783273773809, 0.12582189763986296, 0.13812585193062984, 0.11941269115214387, 0.11516295628802431, 0.16601287729797826, 0.13823175592528236, 0.12962782244768836, 0.1536583458824504, 0.1905098257045592, 0.07439822273989839, 0.22772141281635533, 0.2118826828776829, 0.07394749490964798, 0.14127752232936122, 0.1544106901893693, 0.13685152595562322, 0.10731606323632503, 0.10111131029383791, 0.1294080318222123, 0.11111884708366088, 0.09694497176115552], [0.0914288322711664, 0.06207696252292203, 0.04745384558073936, 0.04556483746836743, 0.0016432495002875165, 0.09773362097480605, 0.20046516892410096, 0.04474827584119574, 0.015616084678068519, 0.03840538958508161, 0.04540973147677799, 0.05733262214268889, 0.03922614937407836, 0.0968552475434638, 0.021930059733530207, 0.026808362078642654, 0.016905568660266938, 0.03607158316299319, 0.05646841750750619, 0.10184929811305578, 0.012350101512105716, 0.050987418470603806, 0.04943186161859382, 0.057422947739401174, 0.041006675605932554, 0.042424712014654954, 0.01399514222172119, 0.017119402952131726, 0.04946051713740153, 0.14366523452824162, 6.037536724921196, 31.535052099535545, 34.129323420986054, 43.57404170497772, 34.9265294690286, 17.263259157057732, 2.897200872821193, 0.2300959636246966, 0.1126360918785776, 0.4955868747445845, 2.366285026073456, 9.037912603347532, 5.828486652143541, 11.15873815551881, 6.7270217403288814, 3.705781304067181, 4.201295308528408, 1.2337423140002837, 2.6005213731719605, 10.581852620647801, 25.515014048545595, 41.42255498516945, 57.34323586187055, 54.69179207278837, 54.37784948656636, 51.8896076756139, 53.50163905851303, 48.82158071764054, 48.96905791374945, 45.50650327436386, 44.435088249944876, 40.644917641916585, 42.82113882803148, 42.156261782492365, 43.343155307154504, 43.40190456759545, 40.96177847154679, 40.932768621752345, 40.13982226771694, 41.8413229142466, 52.52830682262298, 53.71444332984186, 54.0570152959516, 48.347758400824766, 52.904775911761874, 53.155584027690274, 51.65454787592734, 50.25906662787161, 42.02505850022839, 37.82187800253592, 39.07307878617318, 38.70225791008242, 42.9663057481089, 49.39603144122709, 51.198478206511474, 54.376327606939505, 55.85799509479154, 53.86566246709516, 51.378687581708355, 49.59992408752442, 42.75803573669926, 49.131291066446614, 51.39748750194427, 51.87629515124906, 50.93901734198294, 51.66964507872059, 49.312335906490205, 41.60835766023205, 35.6480259280051, 38.22215980099094, 40.491301936488, 38.07140350341797, 37.10861852092128, 35.44547865467687, 37.38353352392874, 37.40928388410999, 36.92654209752237, 38.681343832323634, 48.277606810292895, 48.32443206541, 50.94488128539055, 50.76935129780924, 52.446784280961566, 49.45247434800672, 49.37584692432035, 44.6548508059594, 40.0411158223306, 35.43287215694305, 41.67307676807527, 44.25801284851567, 48.576656156970614, 48.00576694550053, 50.109165406996205, 48.582700529406154, 46.9586431595587, 46.03189691420525, 48.14798424320836, 46.98883364277501, 47.94957899278211, 44.809874642279844, 39.73625352305751, 35.17529010772705, 17.997111082077026, 6.404295006105977, 1.116166816603753, 1.4617400087656514, 1.8009115250841266, 3.565008174027166, 3.954703005090837, 5.313742737616263, 5.387350916862489, 3.28209521309022, 2.270985894626187, 0.37972211297000613, 0.21735383768475827, 0.008639930991546042, 2.317321834064299, 19.04998310150639, 33.33150156082646, 19.451955441505678, 29.526798571309737, 14.792328726860786, 0.3185397266380249, 0.020178480133894953, 0.06816428950837544, 0.012882401426923613, 0.024474875498262626, 0.05718090225972476, 0.04298408260388721, 0.055777758600250374, 0.030987948186755664, 0.025352214710907112, 0.04365290417486141, 0.03226426024470599, 0.039057142717102845, 0.04698223802411268, 0.0353403905436637, 0.02541391734754847, 0.00479312438044637, 0.07559404002442476, 0.07718987777949342, 0.03946670864318167, 0.04178375306148683, 0.014806866961260958, 0.034183061516453186, 0.026341377862639008, 0.0401530200014672, 0.0196343757617738, 0.037124490575684656, 0.03225883251176246, 0.045151276393763484, 0.019490358892888315, 0.07347097289898703, 0.039024963193843444, 0.03498737339771563, 0.059697608343295516, 0.03823780785164526, 0.10408678813086403, 0.042452325653885646, 0.03651879848011079, 0.04839133035631911, 0.05096414854990379, 0.0728396934667422, 0.05370412712856647, 0.010948526417656292, 0.012467144425177287, 0.05258306087325177, 0.029836715304202614, 0.01224347547958455, 0.01529408643217457, 0.06433028757812516, 0.07221467297283873, 0.057294919125495426, 0.03474312158481729, 0.019760152077182166, 0.20571369858038044, 10.126202644840365, 37.25183994539323, 37.34003051634758, 41.87634967988537, 40.2924495358621, 16.941524782488425, 2.859134760595137, 0.1657479334502451, 0.1424012660619713, 0.2703281281696212, 1.694389879703522, 5.324209582421088, 7.474942226563731, 10.889542948815132, 8.015875806731563, 7.139516818907953, 3.572638164604864, 2.6278556354584235, 2.7527581203368405, 11.664767053819473, 26.808547012267578, 44.12799412204374, 58.02256684149466, 56.8665345253483, 56.08739099194927, 54.67702042671942, 54.684147373322524, 52.448910205594956, 50.75902369714553, 48.569988127677675, 46.19708753401234, 42.866822673428445, 44.300092035724276, 44.192124874361106, 44.736204685703406, 43.61505792986962, 42.372431447429044, 42.35880121108025, 41.32068318705405, 45.91276276496149, 53.514975117098906, 54.10176953961773, 54.28389695382888, 50.498264528089955, 53.79151790372787, 54.23814250576881, 53.487969598462506, 51.08627880773237, 45.14176991678054, 40.33570151175223, 40.162787745075846, 41.10054408350299, 44.270607579138975, 53.364756184239546, 53.21423130650675, 56.0570946047383, 56.03038326386483, 54.79412671058409, 52.90153603399954, 49.8237306071866, 45.46689910273398, 50.169891542004, 54.28483440030006, 54.29967664903211, 52.822288467038064, 52.472048267241455, 49.93784412260979, 42.58979743526828, 37.77156183796544, 38.76493738543603, 41.700627496165616, 40.09452281459686, 37.99582335256761, 38.197060554258286, 39.3432241870511, 38.81011916745094, 39.559382084877264, 41.84142881824125, 49.58795301375851, 51.11584171172112, 51.92637205123902, 51.42253183549451, 52.97065604117609, 51.36588104309575, 51.5830038439843, 47.17374593980851, 41.461747307931226, 38.08583782565209, 43.64151039431172, 48.204956669961255, 50.283397090050485, 49.863738782944225, 50.89727547860915, 48.42173822464482, 49.094063851141165, 46.64763058385542, 48.39220277724728, 48.79311215492987, 48.10854481112573, 45.66463755023095, 42.90853315784086, 36.343932843977406, 20.658529458507417, 8.654291072199422, 1.765979876922023, 2.527202713874079, 2.9517083350689184, 6.587999213126398, 4.5941059723977125, 6.181950059629256, 5.489170253276826, 3.06236844870352, 0.9716856984361526, 0.05091800707422438, 0.12582125412600656, 0.07616837614125783, 2.085273188929404, 19.179015351879983, 37.74475243783767, 22.610808803189187, 30.769077923990068, 20.93273647369877, 0.5907083963674884, 0.02583344816230238, 0.08798117614201001, 0.05320001446131257, 0.0165285020991559, 0.008326354924769653, 0.044774648417989095, 0.061740967850651474, 0.026849579524188757, 0.041029543330472325, 0.10272985489498224, 0.03698787411614772, 0.011123409926620944, 0.03578284079389226, 0.037985780246315465, 0.03936956486394329, 0.010267776857701041, 0.0797806492435836, 0.045475634190464215, 0.055233150525319005, 0.04752619492430841, 0.0567297186071594, 0.04777425419419043, 0.029680946646558664, 0.12948985001252544, 0.22437354730021572, 0.08250262092558608, 0.238020193252352, 0.1327252538213807, 0.1413571648299694, 0.3413082887568782, 0.12720209696600515, 0.17254550821117817, 0.1927921701703341, 0.09106590577791776, 0.20113996981132418, 0.09903954041581, 0.18350346134074275, 0.14967668050479505, 0.09666742576706795, 0.1405961177642307, 0.1238890348242656, 0.1516447603822716, 0.2603546746315495, 0.14127644980626722, 0.2175072238089577, 0.12588179805466246, 0.1601807418609819, 0.13112485018228331, 0.15228393818101577, 0.16049768775701523, 0.14347815585713233, 0.29986320784495724, 0.29463505612746366, 10.413577056700184, 42.88221013161444, 46.09606296785417, 52.38062566326511, 45.26044122634396, 23.109724483182355, 4.010026075186269, 0.6268906064571873, 0.33225922755176024, 1.7570414081696542, 6.125967541048604, 21.133320600755756, 14.937862388549314, 24.89825075672519, 18.503508683173887, 9.650777059216654, 9.563749471018392, 2.623099271328219, 3.4945344588448926, 11.824569317602343, 28.534044719511463, 44.29171385303621, 60.641474569997484, 59.56030853333012, 58.78049427463163, 56.62799166094873, 57.46121291191348, 54.942011833190925, 54.367541497753514, 49.490011430555775, 46.61398057014712, 44.938218516688195, 47.56108391669489, 45.84240328881049, 47.29561790343254, 48.127062320709236, 46.07382705134731, 44.52619706430743, 44.07368890700802, 46.296331344112275, 56.57544759012038, 57.65677052159464, 55.95582292925928, 52.58498114924277, 53.47454724773284, 56.65297715894638, 56.27886933665122, 54.72327693816155, 46.8540374694332, 41.45274939075593, 41.50400692416776, 43.49019712017429, 46.26859626462383, 54.1649510783534, 55.49945123734013, 56.349577903747566, 58.948120686315725, 58.10783132430046, 54.20335108234037, 49.28613839610931, 47.37113921873031, 49.93288232434181, 54.624707775731245, 57.25973252327212, 54.73252196465769, 54.810122136146795, 53.576481803770996, 44.94079943626158, 39.99161943312615, 41.11333885500508, 44.10060813350063, 42.089338302612305, 39.815336350471746, 39.73672812984836, 43.03277815541914, 40.29359094558224, 40.44581813196982, 43.388595965600786, 53.12021993821668, 52.80769724999705, 54.07270085427069, 54.44814228242444, 53.86811002608269, 54.19407467688284, 53.04172154395811, 49.31745852193525, 43.79305508828933, 39.10383801306448, 45.25050586269748, 48.476588649134484, 51.32286048704579, 51.871203914765395, 52.718934012997536, 50.00794472232942, 48.348829207881806, 49.1831644119755, 49.931717380400634, 48.614593321277255, 48.61800970569734, 48.06476723763251, 44.40664322145524, 36.400058038773075, 20.725527463420747, 8.783685161221413, 3.4220468517272704, 4.645862627413965, 4.1417694187933405, 10.82990134915998, 10.199503898620605, 13.922752987953926, 14.240761110859534, 9.164704199760191, 5.421795210530681, 1.0169410248917918, 0.36850563580951384, 0.2730130211960885, 3.9689076235217438, 25.51118189288724, 42.71210085961127, 27.601683601256344, 41.65639100536224, 21.83132794595534, 0.7593437764913805, 0.1456757709984818, 0.22340737253187165, 0.13672510612635844, 0.25589527682431285, 0.09957049297349108, 0.11570178422956698, 0.09980323048488748, 0.18767424318338596, 0.11040152831664009, 0.18622909492302328, 0.15075335579533733, 0.07913064662246935, 0.14233909036603667, 0.1079411756607794, 0.11802877629956893, 0.08652144922844826, 0.1532239280641079, 0.1417203517931123, 0.23413965148070168, 0.14891987756615685, 0.08942063236909528, 0.13805832894098374, 0.15213435185292076], [0.021782168374967673, 0.004652767017814181, 0.019314116535467968, 0.04554867684360474, 0.019868227931100036, 0.03106463167275633, 0.0190687864538162, 0.035172831792865074, 0.015773694819560456, 0.05005125519669345, 0.046987497217712865, 0.01602954041558288, 0.07688569490827861, 0.042753225838344906, 0.05139324588761215, 0.055701207264416644, 0.011762651885228773, 0.06100140955118884, 0.05690243696012805, 0.09300881200620244, 0.009302557784042532, 0.04008452024971766, 0.03187413379970578, 0.032531000568621585, 0.018956705875274156, 0.07038952978027445, 0.016073162419601314, 0.03428471755356558, 0.035774478944198745, 0.08624767238694815, 1.311566183163274, 23.976450620159028, 35.921085649921054, 29.534096141015333, 31.7444242969636, 31.94653226483253, 11.946166715314313, 2.7160481675978634, 0.06484610223842245, 0.16353305068708238, 1.3001234036299492, 2.5575804902661234, 5.460191782443754, 5.661349065842168, 1.9760631265178805, 4.763097859198048, 1.4424315287220864, 3.2058205575712266, 0.9371418746248369, 7.2656975061662745, 22.824701532240837, 36.634498103972405, 51.23720768959292, 54.456822487615774, 55.231278788658884, 52.383512527711936, 51.97838267972393, 47.840442965107584, 48.51310591543875, 45.46436525160267, 44.15103804680609, 44.853601224960826, 44.27950743705996, 47.291640620077814, 49.834360230353575, 50.87466301456575, 49.88195034765428, 45.626061039586226, 39.80658162024714, 43.22424473301057, 50.10010865426833, 52.91875916142618, 55.22656017734159, 49.567129150513686, 47.1510785625827, 54.150304948129964, 52.68386017891669, 50.37955399482481, 46.282783477537095, 39.417521722855106, 38.34675781188473, 39.426543174251435, 38.86511079726681, 43.64279693172824, 49.22355698001001, 50.574425189725815, 52.017127852286066, 52.609876432726466, 54.435606387353715, 50.97721730509112, 43.36897234762869, 50.55324831316548, 52.00709050701511, 50.84355469672911, 53.83869224979032, 51.626801029328384, 49.741976645685014, 48.04576335414764, 41.158850116114465, 38.4352857066739, 40.11278537011916, 37.1508232239754, 36.91745004346294, 37.0487396178707, 37.80764372118058, 36.469907606801684, 37.14718718682566, 37.34644751394949, 40.96795228219802, 48.783447434825284, 50.926814848376864, 50.08064193110312, 50.223463273817494, 50.89132916542792, 48.24135626516035, 48.03451399649344, 45.469338816981164, 38.41214764502741, 38.78528664189, 41.1806506495322, 45.448746373576505, 47.26649038253292, 48.54958395804129, 49.30378121714438, 50.57935168666225, 47.26592163885794, 48.82976670419016, 50.702914191830544, 46.37634769562752, 41.854839401860396, 37.06410746420584, 20.55443367650432, 10.187535766632328, 4.1033277396232855, 0.25920287675915227, 1.3684849224744307, 1.6359458286916058, 4.898431887549739, 3.0237357991357006, 3.7619202271584546, 2.648761623328732, 2.644528650468396, 0.7928051487092049, 0.07789749021251356, 0.06477946024988929, 1.05288366396581, 8.814900363645247, 33.87164331251575, 29.481048045619843, 22.573863998536144, 28.605945687140192, 5.600063993084816, 0.03147553633748284, 0.06829884519139606, 0.02106147690586025, 0.04851833624284595, 0.07522193579784325, 0.01981173277712397, 0.016524173702383717, 0.02156345601824503, 0.05344744553909667, 0.01912300058099772, 0.015754066689330486, 0.015908685257478107, 0.010984204089899939, 0.04221815938851045, 0.01540162027888601, 0.06195801588135862, 0.03681579544659584, 0.03248941348565202, 0.025210823608382095, 0.03733745152731577, 0.0728297956107605, 0.05195158991902586, 0.050371989397512335, 0.026500072976153706, 0.014272566599350785, 0.02936349513249532, 0.02998830686743942, 0.03935013687418353, 0.041983399404993946, 0.033763762443296375, 0.02985372820178107, 0.03965020968368457, 0.019274481061485507, 0.06260078280202805, 0.0535810704252893, 0.05030405655082676, 0.04905684242746042, 0.10037421113661221, 0.019621177982058258, 0.04150244557569104, 0.014541419410717585, 0.04499834609187899, 0.033822712909069755, 0.03573169293362768, 0.011240118633835547, 0.04837669807696535, 0.04509324523349924, 0.04993485196703865, 0.02967183786113897, 0.04405659803700063, 0.03129923843868798, 0.06677197833215037, 0.02353716281152541, 0.0732852808470207, 2.94037587219669, 29.386748383122107, 41.693888864209576, 35.920512983875895, 39.66221486368487, 33.10610648124449, 13.771187701532918, 2.2509636657853282, 0.027908014261253902, 0.11958131476515725, 0.4791509179819015, 2.368338877154935, 5.7963080175461315, 7.54594644231181, 7.140262559536965, 6.97383443194051, 7.002737887444035, 2.8515859140503794, 1.8380978006509043, 8.004947593135219, 22.857873016788115, 38.6784295112856, 52.547957897186286, 56.986739481649096, 55.948574389180834, 53.34107683550928, 53.47721053707985, 51.19224556030766, 50.090902851473906, 47.020455791104226, 45.48121575386294, 45.45768545519921, 45.736954289097945, 48.8853584566424, 50.43306689108572, 53.34993354735836, 52.0412229722546, 44.82765866864113, 41.083042467794115, 44.847168537878225, 53.45344489620578, 55.170180028484715, 57.30904848344865, 50.84508442109632, 49.63453115955476, 57.11647187509845, 54.35297773730371, 51.83251365538567, 47.384326227249645, 41.18408664580315, 40.06967067718506, 40.766342455340975, 42.633951556298044, 46.47557973861695, 50.694728205280924, 54.62454303618401, 53.50988780298541, 54.176992754782404, 53.374903355875325, 50.69016648877052, 45.275954200375466, 49.61877499857257, 54.87124835291217, 53.647241361679576, 56.22579574584962, 53.507153910975305, 52.000744112076305, 50.70613838011219, 43.2323875734883, 40.00662249903525, 43.34940756520918, 38.129603632034794, 38.84745228675104, 39.59857440763904, 38.26431743560299, 38.93885920124669, 37.69461277992495, 38.799540535096206, 44.36770585275466, 50.666400847896455, 50.329359423729684, 51.465897560119636, 50.74061601392685, 51.46492873468707, 49.97825630249516, 47.755543262727805, 46.1852341313516, 39.38256555987943, 39.83638771118657, 43.23307398826846, 46.11477267357611, 48.87438366490026, 50.50108078987368, 50.416679228505785, 49.71608508017756, 48.23345661163331, 49.57617805850122, 51.12993478775025, 47.81310012263637, 45.11212464301817, 39.705000077524495, 23.902486485819665, 11.921687203068888, 5.236387223966661, 1.8249881363684133, 3.5701025974365974, 4.426425628123745, 5.251232904772605, 6.125206110938904, 4.9630725479895075, 4.965835857775904, 1.3163762347352121, 0.40689715154228673, 0.044803813385266456, 0.15315157872053886, 0.6547964316221976, 9.325044808849212, 37.312197377604825, 33.068973402823175, 24.01270704884683, 34.89807659579862, 7.999919604870581, 0.11464042303663109, 0.008744172575402885, 0.024472738112953883, 0.09815713736198603, 0.03777869901950321, 0.0630658901026172, 0.029331108765496366, 0.043231958012667396, 0.014725720055491455, 0.05544378640009992, 0.019096986150308963, 0.021171713127724586, 0.05739905728748249, 0.02053954311826777, 0.056233714980584, 0.018715776968747377, 0.012200301637001818, 0.015182865787327532, 0.025009537836717024, 0.005084429792458973, 0.03780000392467745, 0.06084643379454652, 0.04493778684146462, 0.026848139278891108, 0.18975829345084008, 0.06953409302138513, 0.14369468294805096, 0.17804223503316605, 0.09258891155402507, 0.16203501171642737, 0.15930681940047972, 0.09889518646823783, 0.1005734246404421, 0.14250540805439796, 0.17550512036729246, 0.1238765246084621, 0.14338058689909597, 0.12641132568880437, 0.0807630114497677, 0.09522849814065042, 0.09499761456203076, 0.11051215907378543, 0.10125858303640159, 0.1898078746612995, 0.19523379963732537, 0.16773591629199444, 0.14284450921320146, 0.1446799333057096, 0.11537390625885419, 0.15156177773831353, 0.12905048326619212, 0.12070655236921965, 0.17650720933752675, 0.1343466789131203, 2.6195605579883825, 32.86068574074776, 48.78370238888649, 40.1128363609314, 41.77388952624413, 40.57337753234371, 16.0899664509681, 4.0993563398238155, 0.28899686350937814, 0.5230906569669324, 4.863876786924178, 9.61079143708752, 12.045236960534128, 15.028476003677616, 9.42611938522708, 12.213750808469712, 8.45486992789853, 5.852134621912434, 2.4591017874979206, 8.456269233457505, 25.37550122507157, 40.57160462102583, 56.42015703262822, 59.10529790386077, 59.97828022126229, 58.718336474510934, 56.42772720706079, 52.165832750258915, 52.631559295039025, 49.27619911009266, 48.53662836936213, 49.816317327560924, 49.23730880983415, 52.76562198515862, 52.26945784784133, 55.795856906521706, 54.76439906704811, 48.643724764547045, 42.30869685449908, 46.9808163181428, 54.64815570462135, 56.14834070205689, 60.44531683767996, 52.36396735714328, 49.94555550236856, 57.75318238043017, 56.89666225064186, 54.24772877846995, 51.55579828446912, 42.12747943016791, 40.971407890319824, 43.54039561363959, 43.13489314048521, 50.14306253002536, 52.96668268019154, 55.8787012869312, 54.47463397056826, 57.77251182063934, 56.6080464086225, 50.877820522554465, 48.341184508415964, 50.5345150732225, 54.933206112154075, 54.03204940980481, 58.543779234732355, 56.29812425182712, 53.676302202286266, 52.38006868670064, 45.13798090719408, 41.29543881262503, 44.514884948730476, 40.77503442764282, 40.809700335225756, 41.87651441943261, 41.2280015022524, 40.67288021887503, 40.14935362723566, 42.018288489310976, 45.739060601880475, 52.93051058246244, 53.96983669650171, 53.29883290875343, 51.4867998707679, 52.22202462534751, 52.26832428286153, 49.9596760349889, 48.18532128487864, 42.13100564095282, 42.83290593854843, 44.83890018155498, 48.47609443049277, 49.60795317926715, 53.11745466724519, 53.48441593108639, 51.376440063599624, 49.14737670652328, 52.37117275114983, 50.12843993402297, 50.436918658594934, 46.34458826434228, 37.989578939253285, 21.736037884989095, 11.852130832210666, 6.010739091903933, 2.8536441777983024, 5.02093437217897, 6.505053831684974, 9.013809638638651, 8.54269964079703, 10.359553271724332, 8.467527416444595, 7.520933487722951, 2.184587601692446, 0.2584252668724906, 0.31396936865583547, 1.868477783376171, 12.21177883686558, 42.06678075175132, 38.98742206635014, 31.4467046337743, 39.294202404637495, 8.013815091502282, 0.33768469287503156, 0.13045023315616194, 0.1534249801789561, 0.15892019014685385, 0.1346265921188939, 0.15579282005708064, 0.0884732267548961, 0.15282608328327058, 0.12242193048399304, 0.09817335544334305, 0.1184284367087868, 0.16350087499426258, 0.156761339054473, 0.114840678420038, 0.1419916694923755, 0.15755822371330955, 0.10963478921762398, 0.12393712216327268, 0.17255470126626954, 0.17920820553216243, 0.1861180121740026, 0.15309144081848283, 0.17913109112170436, 0.1428102957265031], [0.0559519210289563, 0.07938038362490554, 0.021775078231228456, 0.05049894931876371, 0.04332236787905136, 0.016899654461491494, 0.03613128056449275, 0.0140779007849614, 0.01698611131418617, 0.029003420401544824, 0.05101937965880479, 0.05970064971235491, 0.05122160771861673, 0.012894901109018154, 0.02635845970813065, 0.057809105848953615, 0.043370585453005574, 0.028623548043411107, 0.09513348791628115, 0.06552955991919003, 0.03592000500629506, 0.047042628735183716, 0.05298661683956462, 0.047171109340964794, 0.060502517773138906, 0.028978112686966217, 0.041931366713176814, 0.022290251292889158, 0.06773936351941479, 0.04210071427927863, 0.14982010748597885, 8.412568146182645, 32.00919408952036, 29.679200303169992, 29.61901741643106, 34.857476142144975, 28.52876324807444, 12.496151654951035, 2.0342009875082203, 0.0653218045350044, 0.40386445459819614, 1.769313523846288, 5.498424595402134, 4.863732639820346, 7.554332469740222, 6.40027016401291, 2.9965493611751066, 2.314826471190299, 0.45668747336153065, 3.469865692238654, 15.864118337631227, 31.49609119661393, 43.990440522470784, 54.73212188290012, 53.60125549377934, 54.84553329406246, 52.39379305993357, 52.794647524433756, 51.65927040961481, 48.98379033611667, 47.49343872070313, 50.79312870579382, 52.16305963454708, 53.23997382194766, 54.09361100965931, 56.833398342132575, 54.568782621814364, 51.604051282328946, 41.108075034233835, 41.382464439638206, 50.44803073329311, 52.701895236969, 53.846705652052364, 54.500890316501746, 53.35405988077964, 50.85381953947006, 54.80206951018303, 53.868494418359575, 49.38941832511656, 42.5833059126331, 38.35382592293524, 38.583586600519, 38.52768105845298, 41.76591927005399, 44.930820926543205, 49.3365369304534, 51.16270619053995, 53.52172943853564, 54.22352383213659, 53.717542002277995, 45.48234147410239, 55.25710367387342, 50.6331548383159, 52.36733275075113, 51.61129590003721, 54.898316629471324, 53.50283145904542, 51.60063882027903, 46.68047651167839, 38.836646156926314, 36.35656287593227, 38.459525954338815, 36.2925458723499, 37.65384758672407, 36.8339192482733, 37.92412242581768, 38.15640518742223, 37.541824694602724, 36.90305102256037, 41.401150611139116, 47.49617653508341, 47.43792933802451, 50.775062268780125, 48.993192257419715, 51.72352275540752, 47.50839864054034, 47.46617040326519, 43.86696823181645, 41.43580082924136, 41.088478872852946, 42.74704133310626, 44.857566741205034, 47.77346849441529, 48.243164477809785, 49.39914972551408, 44.57630926562894, 46.03249703684161, 44.46112494314871, 44.1540268928774, 39.45302701765491, 24.46720188663852, 11.974674501726705, 3.551900103207558, 1.4756682226734779, 1.6937423209028861, 1.5696440444838617, 3.7617086643172852, 3.6503234024970763, 4.159329870054799, 3.0030622116981016, 5.151316898484384, 1.1050760697933937, 0.2078839184175576, 0.12147753559533628, 0.49969877506936755, 5.730600472419493, 21.29527722635577, 29.011850203237227, 21.348919560832364, 28.72416788531888, 15.659980543198126, 0.4660545223422589, 0.07230199167444822, 0.0847283285111189, 0.042954335409787395, 0.02661497084303729, 0.04723055776388896, 0.002957030679211922, 0.014379929033889165, 0.033276764180270896, 0.02663023514492858, 0.04737000491830611, 0.08922821406515376, 0.03622514931785484, 0.0312405924928645, 0.044371299295415806, 0.04146895604208112, 0.04118524687064271, 0.029307241296215408, 0.041249092638252244, 0.05058583135025636, 0.07393975742161274, 0.034827352952091925, 0.08614566011895096, 0.06818893455689953, 0.016026053757917498, 0.020095472592079354, 0.09385592138935482, 0.03617397081407328, 0.04400661463038095, 0.005582801588330298, 0.05049439875649349, 0.025144689153098775, 0.036825344732572, 0.01738725984919696, 0.040312159445977984, 0.010541852473491624, 0.032748259273507906, 0.027210841691421888, 0.019058472995135575, 0.046445474689525944, 0.05205608431189772, 0.05399291546294286, 0.04618132374279442, 0.09060236895757337, 0.10571678574647635, 0.01685506622907856, 0.05985103277189117, 0.08677446508720037, 0.02898612213621457, 0.04525972380032463, 0.03510962187823269, 0.02245271747421113, 0.04409502500728254, 0.06128174027488117, 0.014044393056763277, 0.3095263957736954, 12.996251890736243, 38.88626413960611, 31.70407879737116, 32.89255107602766, 43.73865965873965, 32.3985363975648, 11.221796139594048, 1.3900631065330198, 0.007419257026706492, 0.10563803190786032, 1.2817553118351968, 3.32325509478969, 7.925922130384754, 7.212425345374692, 7.585557968385759, 6.911838429589426, 3.1875153462732992, 1.8636726347669479, 5.0417347012027625, 16.882742181901012, 33.556182769037065, 47.64847824650426, 56.64833307266236, 54.83847302775229, 56.96102050042922, 53.64408385369086, 54.68067607572002, 52.02165034509475, 51.49008681697231, 49.30449508851575, 51.31821640076176, 53.361320187968595, 55.27773926334997, 56.22126148593042, 59.78167926111529, 55.71949620400706, 54.13822797036941, 40.969980147577104, 45.17377645738664, 51.99929675748272, 54.51424206456831, 55.17460838440926, 56.04198171246437, 53.448910636286584, 53.891436361497455, 56.496466744330625, 55.28281088798277, 50.671213596097886, 44.911993549716094, 40.015918516343646, 40.7618474191235, 40.8005690574646, 43.93273461249567, 48.168066778490626, 52.61133555443057, 52.811482337213334, 55.68888994955248, 54.5081506236907, 54.43838342543572, 45.90119569532333, 55.17697749599334, 52.67188126041044, 54.80866693681287, 51.932820427802305, 54.96919778085525, 53.982215696765536, 53.22972074631722, 47.879035165233, 41.13479029747748, 38.36490269630186, 38.19685659100933, 37.99739230063654, 37.8283969817623, 39.27540248440158, 40.00710495056645, 39.08486943091116, 38.82891516531668, 39.094651822120916, 44.57378325923797, 49.79086506751276, 49.91765960570305, 52.38483044408983, 49.525218625222486, 54.507526966833304, 50.03864903603831, 50.139273520438906, 45.50253775811965, 42.768053470119355, 41.84930493754726, 44.335197248766505, 46.45851742836737, 48.720940543759255, 49.22414141316568, 50.03632307052613, 46.752157826577466, 48.392222389098144, 48.03533377185945, 47.096867484431115, 40.651389552700905, 27.549023820507912, 14.2610054439114, 5.474223081142672, 2.8997835084315273, 2.9254853292818996, 3.8645926790852703, 5.164564703741382, 4.346413689274942, 7.797540993459764, 5.373557411855267, 2.7847303402039314, 0.5567908034689966, 0.07932760782780186, 0.07225006623494049, 0.22047844985800408, 5.660659709284383, 24.604047498395367, 37.10227212598247, 24.99013031682661, 30.90190506750538, 22.876088503868353, 1.1154286755669502, 0.04966771710784205, 0.024202554223818645, 0.09138642164367823, 0.08290842535995668, 0.02174457644052323, 0.0232920223366349, 0.020481667090808193, 0.05091496187472536, 0.08931845156175476, 0.08344696984896738, 0.05061639059755591, 0.08486963342875244, 0.028771893309068777, 0.025271984237817027, 0.022513569753256538, 0.0027531256050532383, 0.04500915559249059, 0.016716879289296847, 0.02024451308252831, 0.04044847713122445, 0.03442486950887307, 0.041694534461825125, 0.034639443075584794, 0.010116946594338986, 0.17505265351745392, 0.189291485435059, 0.1544045155206996, 0.133840739126167, 0.16180857144776853, 0.2463163279237286, 0.09525495881755507, 0.13651525932213954, 0.11838642444701926, 0.17402591183781627, 0.1577647303741786, 0.20917814735683704, 0.12992572339792408, 0.09915823041791878, 0.14159765515115955, 0.12011887866162485, 0.16860974682194574, 0.1126665362126885, 0.30022872371538994, 0.14820303377364913, 0.08917483305858989, 0.1505867469935648, 0.18147187277434335, 0.08208894110735386, 0.1232531282209581, 0.15103293192242423, 0.21636042082982682, 0.19778897865645348, 0.11265228697729689, 0.09832065116854445, 0.37907391065551393, 13.483857416337537, 44.94118775090864, 41.9894669132848, 39.26265870371173, 47.04646110534669, 36.721409982250584, 16.89406998695866, 2.7190980555549746, 0.25845162029708585, 1.1042917183329983, 6.744515021001139, 15.98165314043722, 12.531891311368636, 17.380236002706713, 16.682428698385916, 9.03597201070478, 4.8702408325287605, 1.963691603272192, 4.726108927880564, 17.160108666266165, 33.74382895808066, 48.25642993373256, 57.8703631893281, 57.27691642699703, 59.36804963696388, 56.468759121433386, 56.25972817021032, 55.82464710358651, 53.90962439198648, 51.28489978851811, 55.43280232337214, 57.18442301596365, 55.55938113120295, 57.83348114259782, 62.077422911121005, 58.798274378622736, 56.88800165730139, 43.12409485540083, 45.415959281306115, 54.308419612146196, 56.31735563278199, 57.761799827698745, 57.30624006640527, 54.329545497894294, 54.42787147337391, 57.34521665880757, 57.891359636860514, 53.51288449379706, 46.70175144749303, 42.9208807791433, 42.194144033616595, 42.76470768836237, 45.65154467859576, 49.66900879336942, 54.40387833502985, 55.48693495412027, 57.6404534616778, 58.0859209645179, 55.769224013051684, 49.800180696672015, 54.975457883650265, 53.87164408160795, 55.003502830382324, 52.430529978967485, 57.33841526892878, 58.03207074442218, 54.29265560642366, 52.6878688412328, 45.06642903051069, 40.83625870366251, 40.875631455452215, 39.82311833289362, 40.64633361754879, 41.364158738044004, 42.6000387437882, 42.082183899418006, 41.09944189748457, 41.30681760849492, 45.06172218630391, 52.37314178097633, 50.7280408951544, 53.10103562570388, 49.7404351542073, 54.19440023360714, 52.02198374655939, 51.29580005522698, 48.289428833992254, 44.49246468082551, 43.360766749228205, 46.33322515795308, 47.77038158908967, 51.002547971663944, 50.743145942687995, 49.9283637539033, 47.288683152967884, 48.73870888063985, 49.144572211850075, 48.42252662104946, 40.04524607812205, 26.36163607720406, 14.551146107335246, 5.23152397524926, 3.212531242639788, 5.502257731653029, 4.977320557640446, 8.792455580926712, 8.040170477282617, 11.925615456796463, 9.962673148801251, 12.149118973362832, 3.3148815699162024, 1.09433907174295, 0.30563788668763253, 0.8666898550525789, 7.292364720375308, 27.940133156314975, 38.07463945881013, 30.881608763048728, 40.134982062924294, 24.325423894389985, 1.0838327580882658, 0.22098610568190777, 0.17001982357713485, 0.14081904935019632, 0.18307523351282845, 0.11315124004238075, 0.12731017665036265, 0.1723356307634423, 0.09899519158587342, 0.1808912394147727, 0.16019771836938398, 0.18245758278475654, 0.1897980993793857, 0.1323083947382627, 0.1385642534061786, 0.07783924454763051, 0.165494097877414, 0.15398924990046411, 0.10861564713019518, 0.1349762652910525, 0.2227230261891119, 0.10694165308509143, 0.2447749130548008, 0.21414893949704789, 0.12742731915486435], [0.010007837479333244, 0.011620138463894687, 0.037740003918447805, 0.08444263900239622, 0.013636823747337106, 0.0902231477741753, 0.032613136685423316, 0.04701729420752776, 0.04514353890572825, 0.04677241803297112, 0.014640267735587494, 0.0874758645471546, 0.03186897611275556, 0.07638206870685663, 0.02949807379815367, 0.07118147317199938, 0.04720086419594385, 0.010361127544104332, 0.03211689365637158, 0.042265258474095214, 0.030362757238289042, 0.029045402019795392, 0.013258924065608413, 0.04218212644299192, 0.01018994519742386, 0.05664667084572777, 0.06495665638677536, 0.04936279496178032, 0.00990078243757448, 0.019931343999961694, 0.047223011797834794, 2.179632667572268, 22.938709143669378, 33.0571670686045, 31.404545037977158, 27.82149518689802, 34.09927022072577, 29.232685527493878, 10.739583872979688, 0.8066301552518722, 0.12779606025545828, 0.5470058994908487, 1.4323411088797355, 7.921650669267101, 5.158356572351148, 3.006432998564936, 7.3146594724347525, 2.4355501609463848, 1.7914364270625578, 0.533837215794671, 5.843642200193098, 23.023073442520637, 37.352523265346406, 51.03890834316131, 54.6827902332429, 53.45794385479343, 52.3216724395752, 53.479344306453584, 53.32123356480753, 51.77019896045808, 52.892310619354255, 53.394134736830196, 54.05760757384762, 56.13407896411035, 55.92945675696097, 56.56426883512928, 56.52617869838592, 51.498100219234345, 45.80183813648839, 42.49655485153198, 50.363927272058305, 52.57633624538299, 55.46805658648091, 48.61458547653691, 48.85272041443856, 54.0361875103366, 53.251999808895974, 54.56923369438418, 49.980888212880785, 44.74079385880501, 37.46679367557649, 38.86484015372492, 40.77158666426136, 41.30609981475338, 42.031730451891505, 45.34606656720562, 48.18174016091132, 53.52658925517913, 53.94608282273816, 55.6546711921692, 41.92295528227284, 48.04876396732946, 52.195054408042665, 53.718859918655895, 52.64105535322621, 52.42160266445529, 53.19234840331539, 52.10497717703543, 48.77346892510691, 40.455722116654925, 36.859524480758175, 37.584186292463734, 36.43513187285393, 36.652807727936775, 36.78650563763034, 39.84791163475283, 37.13850698163433, 39.2438901624372, 39.10388508150655, 38.764913851215, 42.86344551271008, 47.66757626687327, 50.011121842169, 52.380398165795114, 48.32808379204043, 50.75665850793162, 49.45547103881837, 48.788562205529985, 44.94059939538279, 47.25451538639684, 43.09162939748457, 46.884977125352435, 47.86333783980339, 50.3380710078824, 48.86256948594124, 48.78767574987104, 43.966082603700706, 44.689191156818026, 46.14155069474251, 30.894587885948923, 12.741544938856556, 5.876964205695737, 2.3403395279761288, 2.5856222500724177, 2.502679074964216, 4.468530310738472, 4.359387909212421, 3.60276147723198, 7.230034826263306, 3.612798087058529, 1.238150935499899, 0.21200792293154427, 0.06655155185369716, 0.44638849374267364, 3.735335627871175, 18.2557443264992, 28.043705301900065, 30.81350268856172, 24.006319469021214, 26.992472833202733, 4.803173695841144, 0.004921188425918621, 0.08270178080326127, 0.02160240584353526, 0.0006317840328143399, 0.1243865782875688, 0.005364794032497993, 0.07236586042469548, 0.029835627459350134, 0.010435479249985469, 0.017609419601578868, 0.030829480984398437, 0.09525987710202895, 0.12522355232748295, 0.00932813458700454, 0.044507479084835905, 0.035700980468743274, 0.06113880358996892, 0.05283906447490858, 0.013984890050074507, 0.03084598634872706, 0.07468595004249966, 0.07565340417767726, 0.05369721701548946, 0.009988429599381503, 0.03623452240360841, 0.053465452435756886, 0.037671630571205775, 0.0211094684838768, 0.09173540533670495, 0.014026611198430822, 0.043828020383033066, 0.05506677921080301, 0.02576443896208319, 0.034683324591887575, 0.03681029110485989, 0.019753333894656073, 0.03911214016918694, 0.01309760127051343, 0.03178201938769029, 0.04256185324442002, 0.03258829628447852, 0.031574876873844096, 0.023300671469300024, 0.002347816494406171, 0.10127495433534346, 0.06553291538429838, 0.021723311754965016, 0.013314730698062528, 0.03976551740760765, 0.01077220936666333, 0.059623148427495075, 0.05189810549059222, 0.0026040949301058126, 0.061731418564675324, 0.06963150876183664, 0.06544640873588863, 3.4715062235632255, 29.427490042101955, 37.2040537095839, 33.79958545008014, 34.96140326223066, 44.38521923557405, 33.956492024083296, 9.96876851204903, 0.4684757891922228, 0.14856425955170585, 0.14284788000006832, 0.5772830425731598, 3.4528426056908024, 3.8219280781284457, 5.379792509540435, 5.841969309314605, 4.724649315880192, 2.156375954228063, 1.4689657500674649, 6.74896102759146, 25.06090948658605, 37.549343878223056, 54.02367122711674, 55.852390027815304, 55.528006092194595, 53.785559823436124, 55.62530832905924, 55.56850064185358, 54.46515752423195, 55.44657768741731, 55.36277624868578, 56.49785134100146, 57.27392365855556, 57.555832247580256, 56.97231300415532, 59.28459336680751, 54.58132636162543, 47.20594859892323, 43.92310911609281, 53.09827819947274, 55.329491015403505, 57.678649502415816, 49.720042751681426, 51.570711135864265, 52.92802772214336, 56.009257378116736, 56.22246957594349, 52.75987963522635, 45.37961067691926, 39.59410682801278, 40.9104738696929, 42.11464151259392, 42.18258873108895, 45.45470445386825, 46.96668794078212, 50.737191784766416, 54.235341933465776, 55.85331962954614, 56.420914050071474, 45.97573249570785, 50.816223621368415, 52.111421631228545, 53.11760371731174, 54.11306988808417, 53.53035473054456, 56.05238383816135, 53.76905841212119, 49.57651930470621, 41.51261652669599, 38.51248579640543, 37.42096078011298, 38.53615337802518, 38.71671968890775, 39.46951273948916, 38.9604087029734, 39.20963218135219, 40.76394588716569, 41.87195270292221, 39.52325313322006, 44.076403187167266, 49.56698402281731, 50.37619644595731, 51.124404245807284, 48.848445030950735, 52.17281064679546, 50.52716847388975, 49.31287719357399, 47.01012819044052, 46.16120176930582, 44.37036521973149, 47.80771470838978, 49.55737421589513, 51.01665673717376, 50.11462534627607, 49.03173346673289, 48.55396524552376, 46.61098780170564, 48.898078703111224, 32.655951746048466, 16.80288664756283, 8.461553646672158, 2.6265350224510318, 2.9055920483604556, 3.496268636757328, 4.352991994350187, 5.34618515160776, 6.793339704313587, 9.57165991106341, 4.806798946472907, 1.2406516916328862, 0.27953178591785893, 0.06229769160610534, 0.28521585188085036, 4.177565459282168, 17.820057253683768, 32.41840712485775, 31.16698668849084, 27.78068880881033, 31.58085753840785, 7.928801150091234, 0.03326235406641518, 0.054385516371938496, 0.0077654607781779865, 0.022230090408195412, 0.051025232570546294, 0.07988966355520873, 0.05242401335929191, 0.04029971817808767, 0.04562175780114147, 0.037566917843275496, 0.04271844544658258, 0.024632277838405103, 0.026605659044317664, 0.036542853640933196, 0.031185953186885006, 0.04398584981719333, 0.049092553616050756, 0.05522913622459578, 0.07655322807089937, 0.08165920408622873, 0.03763882668628808, 0.06297705454691764, 0.03905234700669685, 0.02264146621699535, 0.03822345519438386, 0.16697273950182623, 0.15367135405540466, 0.061442860056676214, 0.17300516096574647, 0.16658672311853978, 0.202261813645882, 0.18318628561833214, 0.13100992167188277, 0.18049511067088575, 0.19749929016876608, 0.06491767017230873, 0.14218866134122496, 0.11418399551222402, 0.16217047138319862, 0.14835741581215015, 0.15718461795439645, 0.12457153489512783, 0.07828972722974517, 0.09696028585876189, 0.21240956750848602, 0.11992976219663698, 0.04821456322867063, 0.0938869709329259, 0.1014093874442962, 0.09094337767530834, 0.11839489737946181, 0.11934916714146254, 0.09414249956006966, 0.09601700179759534, 0.1318352435144686, 0.24435158818960193, 3.208550282063023, 32.462078794356316, 45.26719554778069, 42.13451616225704, 39.752566660604174, 44.84452486038209, 37.703238071933875, 13.684062054080348, 1.3332410781614243, 0.3972034733141623, 1.4605093651240872, 4.6115056064821065, 14.403802271812195, 13.61965379407329, 12.817556550425868, 17.345711300449988, 7.6685185490116, 3.759545232019117, 1.5124185022807892, 6.822217664410991, 25.453038638637913, 38.51860077150407, 55.42625588755454, 58.39946346898233, 58.241858713088504, 57.38424816439229, 58.420710948205766, 58.4159884145183, 56.09689097250662, 57.50858729885471, 56.50924582635203, 58.538397742855935, 60.251057532525834, 59.39462369488132, 58.03443593363608, 61.92141848225748, 57.70119528616629, 51.61866211122083, 46.3898681056115, 55.012132044761415, 59.24960582487045, 60.529906672816125, 49.07886466672344, 51.897950556970414, 53.55024899205854, 56.8538966486531, 58.80613480844806, 54.341724457279334, 47.181833867103826, 40.67749292619767, 42.49787669028006, 44.6051622206165, 45.463557243347175, 47.58098210057905, 49.45323136544997, 52.39618962810886, 55.08463313502651, 58.27768564224244, 55.79451545592278, 48.74208604135821, 50.545862490131015, 52.469051576429806, 56.020385142295595, 54.93369640842561, 55.259461018346975, 56.70603113789713, 56.33978766779746, 52.6969648176624, 43.8427044499305, 40.32354216421805, 40.71021333817513, 40.90358226530014, 41.51886094001032, 42.286884553970836, 43.600447100977746, 41.284754276275635, 43.78651649721208, 45.298186194512155, 41.628106794049664, 45.39623368170954, 50.780388847474136, 53.2640963985074, 54.04222796040197, 48.03208997172695, 54.940407583790446, 53.95229585709111, 51.12152914847098, 47.87677195764358, 49.82613109773206, 45.63958537194037, 49.911038644852184, 51.554880449848795, 52.7992602317564, 51.71774902651387, 49.92173102594192, 51.06142667032058, 48.91124609977969, 48.063253202746, 32.915616573825965, 15.061470000974595, 8.328328382584358, 4.17475704223879, 4.6846004455320305, 7.111534139802379, 9.27236835802755, 12.229532464858025, 10.791971049001141, 16.7281949135565, 11.441413567912194, 6.1258454572769905, 0.7330912303540015, 0.14844989794636929, 0.6943399903755034, 5.689893624474926, 23.477240762402936, 35.417115995960856, 40.33066518845097, 35.54282011524324, 37.608567745454856, 7.659276464293081, 0.07342088607049758, 0.1824998095511429, 0.08406300413151903, 0.09210051518053779, 0.18619250656375963, 0.19169148568424488, 0.18276217934345046, 0.10142180572954879, 0.16284496583525213, 0.16203942438287122, 0.10193657084938981, 0.1555669466934858, 0.14503241035967104, 0.11809910317101788, 0.10087271220982076, 0.08762033340791542, 0.22943418623218614, 0.18488215913455333, 0.1600181626816911, 0.12946941078670565, 0.15519125717541865, 0.13736221548770705, 0.12019116671815996, 0.12694629254720866, 0.16807112572414262], [0.056740263807437116, 0.04486863974541907, 0.045578527459574324, 0.014215346534676371, 0.051581105968404206, 0.05572304460069826, 0.023439398501068357, 0.021198062721880215, 0.010047042986468203, 0.04377076297157234, 0.04384510797418414, 0.028338957870859775, 0.05490933282060489, 0.026539124308093905, 0.031698682428067254, 0.04446023444254552, 0.06364646600559354, 0.030904115185201652, 0.03065874296871405, 0.0524877978398675, 0.03693376149561617, 0.016316289998470776, 0.009912944083372432, 0.03504309097244855, 0.07095626630489865, 0.06233744390849626, 0.05762996384873987, 0.03758088362613513, 0.047303795769450166, 0.044562246710542715, 0.012219364777387632, 0.08936754247594265, 6.983986016242736, 26.32271832035434, 33.175391227968284, 21.556736538487097, 28.511210641553326, 36.29107890590545, 27.34626473919038, 6.920995202756698, 0.6628489962989285, 0.16570267297567862, 0.7092453034654741, 2.8501569455669773, 2.298691801486477, 3.445549938947924, 3.324603654684559, 3.293338442041028, 1.602695529018679, 1.2477244604979794, 0.5332138040854085, 8.515649014903653, 21.12039835222306, 38.60775624552081, 50.83671800551876, 56.241736258229906, 55.655334072728316, 60.39406714900848, 54.026271758540986, 55.08463705739668, 55.15184294792914, 56.91622703306137, 54.23221188206827, 56.386663913726814, 56.539805012364546, 56.08348431125764, 53.40947904894429, 52.04648287065568, 44.60437382421186, 45.25309462701121, 51.77020288282826, 54.95011152759675, 55.63763633851082, 52.74569634468325, 46.56468814419162, 55.04760203822967, 54.73504012630832, 57.42582528821884, 50.92426923013503, 46.41217070241129, 38.06168779250115, 39.31131178332914, 38.934858383670935, 42.12419640633368, 41.58734160084879, 47.16492845166115, 49.20246639559346, 53.62503682413409, 51.67774477312642, 58.1607872439969, 43.683938672465665, 48.59731135829803, 52.83519698727516, 53.99351996760215, 53.1409300527265, 51.49768444799608, 53.743249216387355, 50.67883083897252, 48.06173132311914, 40.73024880501532, 38.5368868612474, 36.771180937367106, 37.72441494849421, 39.376442740040446, 39.70110908631356, 40.121198854138775, 43.43946126199538, 47.22404641489829, 46.0962002508102, 45.53609363494381, 46.171972597799, 46.53346999999016, 50.97216529230918, 52.33856608790737, 49.47671459567163, 49.234959310100926, 50.280047385923325, 49.737693417456846, 48.95822824970369, 48.655507564544685, 47.50360550418977, 49.93165462247787, 50.324919300694624, 53.459516725232525, 49.57740183799498, 42.92846664305657, 44.999811495504076, 44.93106411349389, 30.1137577333758, 15.97042339463388, 7.160694676060831, 2.287195089363283, 0.5327377264057437, 2.341333603666675, 1.752834911307981, 3.0715436079809746, 2.991832220746625, 4.179615878289746, 5.607207609761146, 4.417466444353904, 0.5786354022641337, 0.3034889487729919, 0.3371033240710536, 3.5783650702045815, 15.565073893916225, 28.43274166507106, 31.484057364925263, 26.799776592562278, 26.218471527099613, 12.353989270425613, 0.5733496407347342, 0.009655425542845361, 0.008372699413749, 0.07539044449766798, 0.06057575577870012, 0.04550461146620013, 0.03507128683850169, 0.02633980738239423, 0.11096523879396339, 0.004522351561219342, 0.04499771789978108, 0.018028408409126343, 0.08344084114557312, 0.010350650334129892, 0.01948510161450794, 0.02110015668515717, 0.12046112844179716, 0.013234427446619639, 0.021160530159249905, 0.04266325647251741, 0.07562600121262573, 0.08876748878749148, 0.014705304769919285, 0.030217066467289003, 0.011335509986947141, 0.014082999100097486, 0.028574784631810846, 0.07932229117760736, 0.058264598746093056, 0.027617417959376212, 0.030445990776042306, 0.03002883674907348, 0.03853663193782972, 0.010381064982333732, 0.020994953660955353, 0.013506691264469298, 0.0652909311916559, 0.0543962377724388, 0.0652719245502545, 0.016969713202166944, 0.036617179491346886, 0.07626036797920543, 0.08846951122846335, 0.04242567345499993, 0.02430266467854381, 0.02831087117233584, 0.020963745154139977, 0.05007950468890129, 0.055432069085298054, 0.07193849061525638, 0.09919877945175094, 0.027003030765861757, 0.04103262683436756, 0.01745805211905991, 0.02846928666375818, 0.03741745025880876, 0.031171780560285817, 0.1352274348779071, 11.294639456656672, 34.58502046523556, 37.83806170186689, 24.71412293372616, 32.17970344328111, 44.57710158440375, 29.507775075974006, 6.678837383947065, 0.3657863301134879, 0.18030176540055584, 0.49525007184955383, 2.391164129780185, 2.618484602820489, 5.271967534096011, 6.7510379225977015, 4.99009620758795, 4.208745360374451, 2.019054509939686, 2.1000328227396934, 9.438980837022106, 25.735855256357503, 41.34024404710339, 54.8944805514428, 58.3457701436935, 57.7492247089263, 60.8012915426685, 56.19839014545564, 57.04577507511262, 57.65468382066297, 57.1624695101092, 56.23853952653947, 57.48411563134963, 57.39332452897103, 57.07956237177695, 56.6531301313831, 52.835279357048776, 46.961553558226555, 45.60649625716671, 53.29238453219014, 56.20092791895713, 56.65858222592262, 51.505482119898645, 46.45548543622417, 53.81015700678672, 56.87785056329543, 58.94046421973937, 52.46655694900021, 48.622347847107925, 40.45500824528356, 41.690609762745524, 40.68228998491841, 43.43550751286168, 43.60488330164264, 49.33924728824247, 52.21228538020965, 55.67621677152572, 55.06649609534971, 57.62565828138783, 45.095493793487556, 47.452806888088105, 55.01433641679826, 55.738947237691576, 54.267113131861535, 54.7953151887463, 55.30084986840525, 53.29229431767618, 49.83668227349558, 42.79232117437547, 39.60940014931464, 38.35765023385325, 38.79158596838675, 40.09769601206626, 40.23224115371704, 41.34958321048368, 45.47387307690036, 48.917776846116595, 46.318684931724306, 47.727451247553674, 48.23620227075393, 49.07827631119759, 51.11788918895107, 51.23903943646339, 49.75797991598807, 50.41140756299419, 52.48952634872929, 51.35193701713316, 49.96333952872984, 49.11017302543887, 48.38740179615636, 50.20880145411338, 50.473106445804724, 54.1494498714324, 49.94116244777557, 46.213016279282115, 44.936433838259795, 47.65974329363915, 32.151744788692845, 19.633969106981834, 8.697188073588956, 3.4385156583401466, 2.5310488429761704, 2.816037718326815, 3.774842720839285, 3.0197457680779123, 5.719541840014919, 5.2998791202422115, 8.669968785778169, 1.9583505608381766, 0.21577416438489191, 0.04750910733315734, 0.285279069456362, 3.134131152783671, 14.561903207532822, 32.83803601418772, 32.72248495009638, 30.18793759807464, 31.313502903907533, 18.53478370174285, 1.463312143760343, 0.02118491282265994, 0.036734551822225896, 0.07972105526395383, 0.06193056695103165, 0.029081465608830896, 0.08625848954843898, 0.01368843126035626, 0.07371605974772284, 0.04407689170611482, 0.051679326101176204, 0.07773547027740749, 0.013211666016779361, 0.011027030320087028, 0.03505063310806309, 0.009161959582519148, 0.07457390968357364, 0.015017388880463138, 0.03432795555601197, 0.029444985820220846, 0.03354139010151548, 0.03278239998185346, 0.08920697044701346, 0.025026860999904817, 0.02826415513071322, 0.005569954772645067, 0.16298641630959126, 0.16198348464264026, 0.16590459843076047, 0.10476549606650107, 0.1887690441142167, 0.12681205862111625, 0.11746209340109942, 0.09210881191275774, 0.14908781936091764, 0.08016917839526169, 0.12800971451666088, 0.16313151336245, 0.170199072829658, 0.3117197974314613, 0.1401159185315332, 0.2552681112842214, 0.19277062777790333, 0.1736273316125716, 0.14469589857805162, 0.13449770548651296, 0.13382504964547773, 0.07455351642302929, 0.08383421197293267, 0.22279978819912483, 0.17004357230278755, 0.200130817510428, 0.17521612135873688, 0.11081333888033706, 0.11337684527520211, 0.1313565458141027, 0.1568311756296504, 0.2070405781869927, 11.187421467996414, 38.46227945819978, 47.24302676416213, 31.173748854667913, 40.144497732962336, 48.092855330436464, 35.49359436958067, 8.956285138284008, 0.9517259823699152, 0.38337555563738274, 2.9263977706432347, 10.508996555882117, 9.838210459678404, 11.71445465856983, 10.51509682209261, 7.986014802609721, 6.8613800791002095, 3.1093422635909054, 1.1960495623850054, 9.921488261991932, 22.68690082334703, 42.018292411681145, 53.11966688402238, 63.20080149558283, 59.90247257294194, 63.12546845405333, 58.65719456826487, 59.55515846129387, 59.941378562681145, 60.00088091819518, 57.219826329138975, 59.220050765622055, 58.682089851748565, 59.42388849873697, 59.04728604901222, 56.81862669606363, 49.6474475245322, 47.75429987138318, 56.534494123151234, 58.55813510956303, 57.49677704226587, 53.20207980371291, 49.21651240318052, 56.18332432162378, 57.4950158980585, 62.19936939977831, 54.39257406419324, 49.60687452746976, 42.91236139112904, 42.43489519242318, 42.47342855699601, 46.54775527215774, 45.71909573770339, 50.78597430259951, 53.36857657278738, 57.48471183161582, 56.76938526092037, 58.567129104368156, 49.00870915382139, 49.6102124644864, 53.83653886856572, 56.99929891094085, 55.751035982562655, 56.0590636345648, 58.26996641774332, 54.63239954363916, 51.936762409825484, 44.75928391179731, 41.62219185982981, 39.93638069398942, 41.47220042444045, 42.21034342242826, 43.65596825076688, 44.07393601632888, 47.171635704655806, 51.54999317661409, 50.341499159413004, 49.29899592553416, 49.94157037427349, 49.69271167632073, 52.997947892835064, 52.38981969894902, 49.03411434542749, 50.3198790550232, 53.55455967687792, 52.09981926025883, 52.130033277696185, 51.82072301064768, 51.11106426485124, 52.847242586074344, 50.96141015329669, 55.492065414305664, 52.50885578893846, 48.4829193545926, 49.36971233737085, 48.432352158331106, 34.30837569698211, 19.21767423229833, 9.9063184953505, 3.923307863935348, 2.9606832083194488, 6.37922223537199, 4.610134247810611, 5.5629598421435205, 8.109614570294658, 12.009856200987294, 16.670998911703787, 8.276262840917035, 1.3950731989837464, 0.55622702404376, 0.715402627904569, 4.30046949655779, 19.290175322563417, 35.77420465407833, 38.31554359005344, 36.44812668523481, 38.46820223715998, 20.732328853299542, 1.335183386841128, 0.14155620979445596, 0.1457394329049895, 0.10729973024177937, 0.21878826071418103, 0.16999472653673542, 0.22576873130615682, 0.1033733457687401, 0.2072643677914335, 0.0754167749396255, 0.1370847997285666, 0.2022409607325831, 0.14321626103933782, 0.14615086808560357, 0.07573963503443426, 0.06728762445310432, 0.14696855969246359, 0.0836757543466745, 0.1392382115966851, 0.11718482319866458, 0.15013078678279154, 0.14607016838365985, 0.13907935560470627, 0.13428609668006822, 0.15744320327235808, 0.09748466538205262], [0.04065953818480334, 0.0427475146528694, 0.04561156883174854, 0.038889411596521255, 0.035579586176261786, 0.049792765639722354, 0.06612910032873193, 0.05304001699832659, 0.0488995224417698, 0.0025208994573462876, 0.05486298833162554, 0.03235936239962617, 0.046509944818793766, 0.05657701430121257, 0.055939908770303574, 0.017786265253239585, 0.0464435862827926, 0.04292325522269934, 0.08272089469697207, 0.03390828876065151, 0.027428046770153508, 0.0462911194641023, 0.0399763026695338, 0.023559787303149223, 0.07120164426704569, 0.036070755788034974, 0.09838189989809068, 0.030021200767688216, 0.017219268258721117, 0.024828128216247407, 0.06803754792218247, 0.08850318845361473, 0.5621458806337849, 10.159136825992215, 32.987607755968654, 31.213862934420188, 26.120473069529382, 34.72260152139972, 38.777704700346916, 26.177710256268902, 5.45488138352671, 0.43110997325951056, 0.16666258114480204, 0.845341190936104, 0.7163015248314027, 3.5038576875963523, 3.7067731734245055, 4.5079520921553335, 2.0019152231754798, 1.9633452089563495, 1.371810479510215, 0.9553248182900491, 8.907972324279047, 21.215411886092156, 39.21958323447935, 50.2565602333315, 54.50187875378517, 53.98975449223673, 55.54386031243109, 55.45739950672273, 56.016501995825, 54.76202603309385, 55.572399477804865, 58.28346721587643, 55.89017421968522, 55.30655691700598, 51.54597274718746, 48.677990590372396, 45.03723090694797, 47.28892633991857, 52.0870441006076, 56.98746904250115, 57.658668948758034, 56.073525413390136, 54.786497700598936, 51.98646668464907, 56.59639304684055, 53.62220095049951, 52.96960876834009, 44.0545791195285, 39.986865520477295, 39.01443935209705, 40.881424796196725, 40.02992137785881, 41.472733866783884, 44.98996634637156, 49.46921502390216, 52.86514820591096, 53.47007966810658, 55.48490708874118, 45.72166096779608, 52.9111615304024, 55.24014726761849, 51.88052346629482, 52.110672458525634, 50.20766788913358, 49.59839828552739, 49.37468982511952, 48.06309238556893, 41.380381661076704, 38.47174413742558, 37.35713205029888, 39.105991394289084, 38.08277837691769, 41.54439949220227, 47.0784362669914, 50.55861019319104, 50.53278530797651, 50.724679423916726, 47.453787480631185, 51.952895118344216, 49.58559174691477, 51.68322040188698, 50.712433784238755, 46.03797266560216, 51.25904744671237, 49.8238286664409, 50.135633560919, 49.554777606841064, 49.02063708151541, 49.78240059268091, 52.07032303656302, 53.208155555109826, 47.63094132946384, 40.897271171692886, 46.33668861081524, 45.96783676455098, 37.53245022989089, 18.6641336641004, 10.212800733504757, 4.34311056329358, 2.0364249713959235, 2.2020610253657065, 3.2722444255505843, 3.6556617483015987, 3.6853898821338533, 3.9860108735099917, 4.914767088428621, 8.68266942039613, 1.344690354120347, 0.16597926135986082, 0.12599273524697752, 1.9178618947344444, 10.566543609865251, 26.692315416951335, 27.508560649810303, 28.71314798631976, 27.854215598875477, 20.94643731271067, 4.404535370488321, 0.07071743073362498, 0.021813281120792515, 0.048362058136732354, 0.00879055249594873, 0.035581566513546055, 0.07262114390370346, 0.03852610205931049, 0.007056825138973974, 0.025316064936980128, 0.04246452560407981, 0.03602797743834315, 0.027826207562259613, 0.0010296152275611438, 0.05095877444311496, 0.015482091112062337, 0.0836971588432789, 0.05473883229217703, 0.003709817880712029, 0.03243771404208195, 0.03679546730352506, 0.02297586551116359, 0.024203567375098507, 0.06362770834276754, 0.04804389799133905, 0.03108575271682874, 0.03153990112966107, 0.1188611921163336, 0.03171479325711487, 0.017051010452691587, 0.01520218556716798, 0.015362842823378743, 0.04559127133219473, 0.038322498871674465, 0.11167679657979358, 0.06506631421225686, 0.004055402297977238, 0.057609930649519935, 0.02005298918623838, 0.009945381203696374, 0.08139728628579648, 0.026962301701367385, 0.04916875638187893, 0.03345869857096865, 0.062356971489686164, 0.06023119241299649, 0.026134792677757722, 0.06546467227200348, 0.01982262654740724, 0.018227386340919523, 0.011529802333473439, 0.05242334303235816, 0.042746829004177166, 0.023610021603564103, 0.0996858275104915, 0.03359528055654899, 0.05848725070996631, 0.07506560023513532, 0.10510274329252782, 1.2418907928851344, 16.046446773313708, 37.26522307242117, 33.29647479518768, 26.812243846154985, 38.432375308006044, 43.40224973617062, 25.319693742259858, 5.096496872363552, 0.2676306406576788, 0.03374154589349224, 0.16115670723299827, 1.5223412407982735, 3.8242547790850367, 6.18902160275367, 4.433751635013088, 3.6822076141834263, 2.4469939210722527, 2.7739139141574984, 1.577841185273663, 8.81657619630137, 24.918237193938225, 41.27630941329464, 52.79362378581878, 58.27954092333394, 56.48002809093845, 57.524402295389486, 57.81678753514444, 57.133232162844756, 56.770216803396906, 57.426562693811235, 58.35456409761983, 58.234547415087306, 57.43198733175955, 54.50849579226587, 51.90263386695616, 48.46834382703228, 48.56193942408408, 53.254368920480054, 58.936243749433956, 59.11340152063678, 56.39007637577673, 54.95777583891346, 53.27762465323172, 57.354410694491484, 55.984499377589074, 55.08286414607879, 46.238743105242335, 40.61833966162897, 41.691480528923776, 42.00224991767637, 42.22731944053404, 43.71989111746512, 47.390107800883634, 52.32337867060016, 53.65651384476693, 54.87018931296564, 55.92171007587064, 48.23612382335048, 52.70056555348059, 57.303098247897246, 52.78528090446226, 54.12694331138365, 52.15191618088753, 51.29216794044741, 52.067334190491714, 49.12425041198731, 42.81764791857812, 40.68021897346743, 38.34975450269638, 40.92236649605536, 39.500993682492165, 41.40020924229776, 48.53931911530034, 50.15752038648052, 52.507282918499364, 52.07267645866641, 49.0816613166563, 53.12317348295643, 52.44195192090927, 52.261930819480654, 50.90766191482545, 47.15599329240861, 49.882068018759455, 49.717352005743216, 50.59650421142579, 50.18889934785905, 50.32029482626146, 50.664686772131155, 52.31432976261262, 51.67386947139617, 50.27195553625784, 43.368572265871116, 46.86570259832567, 49.10315198283042, 40.825625158125355, 23.3823037147522, 10.798506698300763, 5.428902054986646, 2.921956176719358, 3.4422764758909907, 4.183337226990731, 5.547482169443562, 4.359673751938728, 4.932282432433098, 5.998239969053577, 4.790723112321669, 0.2892064651654613, 0.08032426523465304, 0.21530153410088634, 1.9887953852453542, 10.317492715774044, 30.399771082785826, 31.042394561152307, 30.32081573240219, 29.916992033681563, 26.35069070323821, 7.006727918501824, 0.06788591613932964, 0.04925595633986016, 0.042808276916583704, 0.016779993442938696, 0.029583444721215678, 0.023523666257519397, 0.016593770875084787, 0.05367254132344838, 0.05383985109567162, 0.018055757748023156, 0.04975456083493848, 0.07457297505630602, 0.022285405786768086, 0.15127363674823316, 0.04583250092823179, 0.053752942251101624, 0.02064980232276984, 0.045293481464708046, 0.050409424283932296, 0.07327100096811211, 0.015194883791639682, 0.03472332204241426, 0.005314651183829073, 0.01383883442970053, 0.025912454809933424, 0.02373505864412554, 0.15522427556495513, 0.18430537153636256, 0.13107888490682648, 0.11166638544490261, 0.10325947445967507, 0.15492813661694527, 0.08679276692771143, 0.25598909195152025, 0.2357620418432259, 0.14390860534002706, 0.1402142229339769, 0.08769855098498446, 0.2473435598996378, 0.15191820780596427, 0.14729270681498513, 0.12344943825155498, 0.09845747447182095, 0.17075295439891278, 0.14656689979376333, 0.14548542879281506, 0.1721186593415276, 0.1633006962196481, 0.15925927598389888, 0.08298265161894022, 0.2772551564679992, 0.09133837260906735, 0.12337513538377902, 0.17278800568272992, 0.11155080575976642, 0.19132302803618295, 0.297178253531456, 0.21300847972593, 1.1702641460203356, 18.13425479396697, 45.002008022800574, 44.33756243798041, 34.76135846107237, 45.91286866895614, 47.61161188925467, 32.18645972590293, 6.872763777932813, 0.9717715002836721, 0.1724778779692227, 3.232166872870538, 6.9016064366986685, 10.096874102469414, 9.869160902115608, 9.915756698577635, 6.817752536266082, 5.666930108301102, 3.7695980216226275, 1.755491336507182, 9.77084473256142, 23.4704021100075, 43.45965362364247, 52.26402536515267, 60.99904567964616, 57.78047423208914, 57.825859977353005, 59.30642135681645, 59.302244032582934, 56.92051810602988, 59.549408266621256, 61.96343491154333, 59.44529679513747, 59.047195834498254, 56.02664524509061, 53.5092092329456, 50.647075330057454, 51.101387777636134, 56.29671219856509, 60.70122403483237, 62.66261308423935, 56.715946889692745, 55.72898049508372, 53.396864706470126, 58.457118388145204, 58.19515505144673, 58.13192252189883, 47.45115949261574, 44.18171882629395, 43.351011814609656, 44.60408749118928, 44.421524693889005, 46.643814117677756, 49.14197168042583, 54.056328881171446, 57.28077211687642, 58.10334021045316, 58.18171701123638, 51.20766831982521, 54.3022418791248, 59.38668481765255, 54.98714654676376, 54.70321793710032, 55.522106847455426, 53.76812881039035, 53.634266161149554, 52.172681208579775, 45.7015392088121, 43.000159725066155, 40.53569532209828, 43.535782906316946, 41.64373351681618, 43.74194268257388, 49.734857543822265, 52.48324271171324, 55.293581716475956, 55.907444415553925, 51.293219135653594, 56.122841373566665, 55.31610788837556, 53.54356135091474, 49.90280951223066, 48.06579882098783, 51.17619914393271, 50.971455343307994, 51.550832563830966, 51.0454979250508, 49.749786084698094, 51.09205253662602, 55.4094720655872, 53.72288819282286, 51.9123613449835, 46.96781366102157, 49.309500032855624, 47.142492494275494, 41.22990385178597, 21.268377611714026, 12.375920222651574, 5.972500395390296, 3.3822330784413124, 6.049249412552004, 7.412286285431155, 9.445290950036819, 10.982198157618123, 10.9289921868232, 11.854698023488446, 11.507415290801756, 2.808248136312731, 0.46865217327590913, 0.5191448138606164, 2.8389879965013076, 13.676903728515873, 34.51550822104178, 34.760707347623764, 38.52045605259557, 37.48316564867574, 30.458188902947214, 6.83035118925956, 0.0946856175939883, 0.2237618873797117, 0.15781789687612366, 0.152287416220192, 0.20577394373474583, 0.1706170963664209, 0.14835251284943474, 0.13092336905819754, 0.14439176167211226, 0.1111897255384153, 0.13969850786510976, 0.2051725340706687, 0.11625365864846016, 0.20177511798758663, 0.15045657333347107, 0.1810225315632359, 0.11947237706232457, 0.11025482247914038, 0.11445103077999047, 0.22953967653935958, 0.06599215445138755, 0.07692881033665712, 0.19305634793014298, 0.14027282866018434, 0.16241404137784438, 0.08467554505313597], [0.031835118856941985, 0.13465335923096827, 0.02661766555731095, 0.04205255033147912, 0.042716752392269915, 0.01768129014019524, 0.019427290704521923, 0.025681734024997682, 0.04358542715049079, 0.028609091964279933, 0.0425072618189358, 0.029753380259799383, 0.03398201706248426, 0.03778891863241311, 0.057386397684533755, 0.04006705727548369, 0.018108675271392833, 0.05197779395647588, 0.05299934539042654, 0.022077901296377666, 0.10831082840600323, 0.02499586891292805, 0.04130212890525018, 0.04622387609654858, 0.023173274877931804, 0.03315631983681552, 0.022092014551162723, 0.01803112993647735, 0.09390597757432731, 0.05347866745245072, 0.058804349823584484, 0.04633436895786755, 0.032237002836360086, 1.6959958451409496, 16.791356840441306, 30.372124256626254, 29.081999832584014, 22.53411666039498, 31.18810865186876, 36.79850809035763, 21.108823437844556, 5.5648852356018566, 0.49027095999448533, 0.4799096514621089, 1.0597279547683656, 2.0274726517738837, 6.385493614981252, 2.119772150631874, 2.7748033115940713, 1.580883841360769, 3.4541448325880113, 0.6031299911199078, 0.47114563625185724, 5.066378462699152, 15.88561979032332, 33.21048859627017, 47.05636509003178, 50.57983413819344, 54.137749441208385, 56.42976291718022, 55.747525461258434, 55.393759050676906, 57.89427003552837, 56.664371644296956, 55.19163539332729, 52.09261778862246, 47.90595831409578, 45.54218507582142, 46.93276728353193, 49.48773253348566, 53.60145161228796, 55.427636561855195, 57.14175939559937, 51.999763519533225, 57.111482620239265, 55.639750496033706, 52.61622282766527, 54.157737839606504, 49.8655273837428, 42.888854626686346, 38.85544607716222, 40.602308934734715, 40.5114354625825, 41.85028160772016, 42.55085614419753, 47.04149538470853, 49.30081198292394, 53.33807229995728, 53.12405209387503, 58.74813079833985, 43.5771756787454, 51.23972585124355, 54.781916372237674, 51.98289340542209, 50.30089086101901, 50.143392009119836, 48.68087353244905, 46.5438642809468, 43.30595554844026, 40.86089118834465, 38.84782883428758, 40.287695623213246, 38.85146094906715, 40.08563472378639, 48.78499284867318, 50.26318119418237, 51.13835611651021, 50.95158461601504, 52.62662887573243, 53.52003497462119, 51.39099990167926, 49.138492538082986, 52.632841910085375, 47.29886954830539, 49.80205166724421, 52.405085563659675, 50.28491504730717, 51.523109251453036, 48.07299637025403, 50.291900788584066, 50.14143866877402, 51.591946847977184, 46.652082474001, 47.195291519165046, 48.80700911245039, 51.7338974245133, 43.5831690603687, 28.96476018813349, 14.287893291442627, 4.586702008401194, 1.0105809016573815, 3.2326250547362916, 2.8242876885398744, 2.129911477527311, 3.033558639787859, 1.8624085284048513, 4.150807049966628, 3.9631432102572535, 4.898503470805384, 0.2547687598534169, 0.10988883163419463, 1.9626882119524864, 10.30221704513796, 22.845976468055483, 28.35459432294292, 26.008458022148382, 29.665919157766528, 29.060132618873354, 9.917262888723805, 0.4325822410323928, 0.03241544386612312, 0.02714089211827565, 0.030227885543999654, 0.020387597239365982, 0.037560337148005926, 0.033531346688828165, 0.0804324291886822, 0.021288769447334835, 0.04199094920148773, 0.061831753100118333, 0.023541066029499617, 0.10245941053595274, 0.025133048447089332, 0.012578693530221861, 0.05056367608748617, 0.02436761935842374, 0.01924630626285028, 0.05108171623320349, 0.07148416983264108, 0.07064884288176414, 0.07348194327806273, 0.05237781442701817, 0.07132274744611594, 0.0362065103986571, 0.03662223184120752, 0.050694171504508105, 0.03127920523946805, 0.03724637133399806, 0.10513929334739525, 0.0016399255166048064, 0.03903065522712085, 0.06309086073850913, 0.033477207255219264, 0.028231527446018114, 0.020103478210888082, 0.03964905289091891, 0.05475898806546485, 0.017776899828365254, 0.017949361541879275, 0.031645833852610765, 0.013474324049668448, 0.11201891612501876, 0.03583757394564248, 0.02226371209197227, 0.051029365614897786, 0.06231750263982724, 0.059496464297896436, 0.03218892315823225, 0.028020523849033543, 0.024537821112561132, 0.03533066888790458, 0.04821421082822546, 0.04240712263591347, 0.0257069364024867, 0.04981906926860252, 0.0354984766172786, 0.06232116454010529, 0.028953933036856117, 0.047202882837624326, 3.7481404504468365, 24.2358349984692, 35.740268307347456, 30.91289947109838, 25.34934489957748, 39.99103499997047, 45.70232368284657, 22.11917696460601, 4.175805295667341, 0.3073918603120312, 0.18633130637388076, 0.6107255383845299, 2.138471805280255, 4.5603789821747815, 5.1920134502072495, 6.206457518762158, 5.3096580793780666, 3.489050740195859, 1.5343158692121508, 1.7675699077306257, 8.149579109684113, 19.586094617843628, 37.118761770186886, 48.782266801403416, 52.854106733875895, 53.572088749178, 57.03000322464974, 55.44162765625985, 56.38041165567214, 57.919435962553955, 60.74661762483659, 58.01209803550475, 54.22865429232198, 49.82675475458945, 48.600798345381214, 48.75801478662799, 51.17113928641043, 56.10107614148048, 57.49287428394441, 58.55360869438418, 52.326002736245435, 54.827788491402906, 57.734009835027884, 54.33446022772021, 55.26303429757395, 52.79340021071896, 45.19254892103134, 40.483751373906294, 41.797004053669596, 41.5403006153722, 42.69760770182456, 46.48429524513983, 48.25919128233387, 51.359966108875895, 55.107794730894035, 54.81344438368275, 59.176179055244695, 46.58854399957965, 51.501520526024606, 56.1327257464009, 53.688069312803215, 53.5660953675547, 50.85904413653959, 50.78477013495661, 49.71736377285373, 45.93517518812611, 43.75153680001536, 40.963563149975194, 40.95882492680704, 40.008595451231926, 40.88757115025675, 49.8755294276822, 50.2456364324016, 53.04651860267886, 51.5393086402647, 52.28817539830362, 53.89167562607796, 53.72521415833504, 51.38173134096208, 53.767226665250725, 49.77938429001839, 48.97953848684988, 52.26550409870764, 51.630562582323634, 51.867944425152196, 49.0485918137335, 51.12362369414299, 50.66521236973424, 50.78127922550325, 47.37774056773032, 47.57520444931523, 49.48420240033058, 53.055563588296216, 45.49624235399308, 31.677096812955796, 17.45451588784495, 6.57494556519293, 2.010708196509269, 3.564697816487282, 5.005768037611439, 3.237969284096072, 6.2700832659198396, 6.711133689649644, 9.090805765121214, 4.255566693121388, 1.953601428577977, 0.11350095151893555, 0.07292956324113954, 1.371922267060126, 8.755074412591997, 22.85213262804093, 32.24158275511957, 26.944757200056507, 31.137092344222534, 33.88178656178136, 14.110798278162557, 1.010534507372687, 0.025286413503870852, 0.014996601084637788, 0.022875308810222535, 0.025003870701297157, 0.034975954857204235, 0.03088922052073383, 0.02729387604631484, 0.005613679240923376, 0.041109710601308656, 0.04965060270361362, 0.033383468736804305, 0.009642436522089187, 0.03595618350851921, 0.010069689503119839, 0.04123896112545364, 0.05071508953528059, 0.08235521028719603, 0.02360993924911224, 0.0336615548228785, 0.0051819728950278894, 0.042932582343177456, 0.06804540798428559, 0.06371752066057056, 0.008774846735891075, 0.02717227874053342, 0.08520879587458988, 0.1518335244468143, 0.1997653782487877, 0.19448107228644435, 0.08243075421740932, 0.11984965238239496, 0.14160186863474308, 0.1735557790004438, 0.06366521217710068, 0.2295650953366872, 0.13180689826127023, 0.14522312028754145, 0.1027247297667688, 0.13840201130557445, 0.18781929427096922, 0.074998605846157, 0.1797319645242345, 0.13390731216678697, 0.1384992891501996, 0.1494315476907838, 0.13012987050798633, 0.23406311929706605, 0.08871586212227422, 0.15168070522767885, 0.14675054639097185, 0.11762704745295549, 0.19273805371936292, 0.284521010133528, 0.14679697131918323, 0.22827045270992866, 0.12257929260451948, 0.18426706714014854, 0.17086615155060447, 0.2909316951709409, 3.4195990475916096, 25.59815456790309, 42.938951138527166, 40.12125768969136, 32.693386846973056, 42.20825279912641, 45.368604506215746, 26.03584008832132, 6.6566549097338035, 0.7956431061029435, 0.9690183028578759, 3.1508350564587504, 9.242414197614117, 15.33523771070665, 9.21997824022847, 6.047216153913929, 6.378828527465944, 8.413323202440816, 1.4261071143611785, 1.1359783406219175, 6.219159624268932, 16.926125557191913, 36.362332682455744, 49.35319131420505, 53.60263616808, 55.44304755426223, 58.30775060961324, 57.26567099171301, 57.357548590629335, 61.63368909589706, 60.87989976329189, 61.01087554808586, 55.64407294796359, 51.2300415192881, 50.18613799925774, 51.56736927647745, 54.95418687020579, 58.57895897280786, 59.00904686220231, 59.433580675432765, 53.236090675477065, 55.56928903825822, 56.42198877949869, 56.51337608214348, 57.95690244243991, 54.315479878456365, 46.76294826692151, 42.2306259985893, 43.6409612624876, 44.63015948572467, 44.576681890795314, 48.03804020727835, 50.71778781952397, 54.82858865491806, 56.90387941175892, 57.43796502390216, 60.94331664423789, 50.799894794341064, 52.993719577789314, 58.00614387758317, 56.782913515644694, 54.96829955808578, 52.95918310842207, 53.1780945101092, 51.7881908724385, 48.2563671758098, 46.32996566833989, 42.79830278888826, 43.504694200331166, 41.890854604782604, 44.02166258904242, 52.10746788209485, 53.33509914336666, 55.51745883880123, 54.326533117601954, 55.14360989293745, 57.19801402861073, 56.1024332815601, 52.00226991407333, 54.197083134805005, 49.54601110950593, 51.01412288604244, 53.55237491669194, 51.70329901479906, 53.86889450011715, 50.48021378055696, 51.562650665160156, 52.435644749672186, 52.692458014334406, 49.839780945931714, 50.43109393888905, 50.889983792458814, 52.0954026714448, 44.51781888161936, 31.19054836611594, 17.530009746551514, 5.647912986816899, 2.2974837114734035, 5.761188585912028, 7.75030339917829, 6.318079348533384, 6.242586470419361, 3.9127743388375933, 11.015634402152031, 10.231310398347917, 8.64858598478379, 0.8794487123527835, 0.3027108485900587, 2.635615799696215, 12.877597251246053, 29.10227848637489, 37.35208788225728, 34.22408788434921, 39.68265041228264, 37.96484055057649, 14.999514202917776, 0.8470452769148735, 0.22882461007083618, 0.0761406667410366, 0.12682053155355877, 0.17318543677608814, 0.18778601541153847, 0.10998086177653844, 0.13390866048153371, 0.07648663204764167, 0.18898670501526327, 0.1310917551839544, 0.135807792445825, 0.18376526422798636, 0.15677808573649776, 0.16531579857391698, 0.12482429028398569, 0.2368469755615919, 0.09130124032737748, 0.154340194778577, 0.23055341004604296, 0.18587661786906182, 0.15799132386042228, 0.12745777881073375, 0.21669851075257027, 0.1248259756774191, 0.084024983187837, 0.20284437754702186], [0.03403891058218095, 0.027541586746191307, 0.14347297710276422, 0.05442207408768516, 0.019888425839223692, 0.029136489873992342, 0.012061138892726553, 0.0367368615773176, 0.0495217390538704, 0.10426033768923053, 0.0995292084952516, 0.03603864138224914, 0.0708845068490313, 0.04708683966929394, 0.02443631063215435, 0.04960090657996555, 0.013122506788931789, 0.03687961823156765, 0.04041755399216087, 0.06100879846921852, 0.039231025523716406, 0.0197936799151883, 0.06976443267757855, 0.05102825478740758, 0.015024482854641976, 0.00840001236346941, 0.006886832143795947, 0.04667565346725526, 0.0504603959439743, 0.04355992791393111, 0.10043078672982032, 0.019825401700912945, 0.06421866090667826, 0.0387322103544589, 3.4734433841320778, 22.63054813108137, 33.04663158232166, 29.104276933977683, 21.47789493683846, 34.526938007723906, 39.8087546133226, 18.032887020418723, 4.77361128214867, 0.26158565535180034, 0.47465974284756574, 1.0889858944762139, 3.101663733682325, 2.352985984856083, 5.72363434299346, 2.8573873446833704, 1.766092767638545, 1.349926718300389, 0.3494381363834104, 0.5686136851868322, 3.037879130532665, 11.183191191765571, 24.43910594909422, 40.034796883983, 51.81241543062272, 53.07517936152797, 52.76791657170942, 56.944130774467226, 55.04534275301042, 55.359959986902055, 52.22495071349606, 48.521888102254565, 46.512171529954486, 47.32272932606359, 50.98276353651478, 54.52529138134372, 56.48287180931338, 56.887934977008456, 54.240366489656516, 56.03073235481016, 56.05677297038417, 54.073857953471524, 54.26068436714911, 52.53702625151604, 46.484522742609826, 40.58279906549762, 41.50645840552546, 40.17501769527313, 40.306162141984515, 42.380185973259714, 44.31840165968865, 48.72472563097554, 49.77929407550443, 56.84402012055921, 53.59721545250186, 56.263987864217455, 42.952271507632354, 51.59966999484647, 54.79253030592396, 51.83732248121693, 52.321813644901404, 47.258335774944676, 44.490515262849875, 41.21205706750193, 40.11803742377989, 38.714272129920225, 38.15173756691718, 41.680878362348004, 37.77730418789772, 43.667692215211936, 50.592985845381214, 51.17811326057681, 52.95999896141791, 51.261895087457475, 50.78225197330598, 50.746499569185325, 50.90960348806074, 51.6521316959012, 47.48786503268827, 48.479581417575965, 54.92826000336678, 51.158309213576786, 48.2511111997789, 47.26651391675396, 50.23455181429463, 50.43116846392232, 51.24238521822038, 49.326593722066576, 52.153622411912494, 50.912961036928245, 49.74887609481812, 44.031048820864775, 35.31042752727386, 18.652782324821718, 8.08137595653534, 1.590277795349398, 0.9607905798381375, 1.4488583322494262, 2.4098887895384142, 2.1387608349323273, 8.403364304573305, 10.39607249921368, 7.803076928661716, 3.446235863431808, 1.7632325017644515, 0.14838376923674537, 0.8451681163522505, 7.09088727351158, 20.606616889276815, 28.712640039382446, 25.748022448632028, 24.668713654241255, 32.21254937110409, 16.560484170913696, 1.555976055322155, 0.04343677161922378, 0.047468772803943966, 0.023499274018010306, 0.026470900347997105, 0.08778939369104563, 0.03792320618466024, 0.029438234670388124, 0.08345761847111487, 0.08013745469431724, 0.017129346773388888, 0.046950100635689114, 0.05686905850926715, 0.023492471157242695, 0.03413777805924897, 0.15225041417344926, 0.048330403383701086, 0.020427244204667308, 0.03644304387571831, 0.05737338568113985, 0.003503240596112465, 0.04632683831357187, 0.0634920763062133, 0.09579148083444565, 0.020871858653281967, 0.061828589156991055, 0.0372016892558144, 0.03091468528333691, 0.021380274819450516, 0.061352883029969475, 0.07633037309372619, 0.029142976723491188, 0.04004445385127779, 0.06633517031948413, 0.04307835355340954, 0.029158704508576664, 0.03364740517891703, 0.014433783099746272, 0.08134981947800807, 0.04715210653000301, 0.10856894641033105, 0.0422104180700356, 0.048563045134106954, 0.05586706913046299, 0.0435088106971835, 0.00645826819480487, 0.007412467093672604, 0.0696109009966735, 0.005871451548075364, 0.0267979720111696, 0.07354024256910048, 0.020240801386535168, 0.030862282954096317, 0.03675802092578623, 0.029757882941574342, 0.038716068881894314, 0.1138664214240928, 0.061838529147808595, 0.0513018899026417, 0.05915773086129658, 0.05445981157883521, 0.0769268031862955, 5.87264665672856, 30.393073635716593, 37.90294162688717, 30.51489656971347, 24.93779609280248, 37.45454411352835, 43.53258225225633, 18.783207016606486, 4.180714141937995, 0.12874550366353604, 0.037596626732979095, 0.28778426889931, 1.0876519208954227, 4.777255654335022, 9.83318394230258, 10.38995752411504, 4.989976575297694, 4.371779166883038, 1.8684967823566931, 1.6342744087019276, 5.552538104595677, 14.366176935934252, 30.230169757719967, 44.201609165437766, 52.925101633994814, 54.80049663974393, 54.999584382580174, 57.7997487591159, 57.0558516440853, 56.424032334358465, 55.392813759465376, 50.79437209713844, 48.731009267991595, 50.35661205168694, 51.34993268597511, 55.15733818854056, 57.9212284857227, 57.50328033201156, 55.127869421435946, 55.17751486070695, 57.2801092363173, 56.844581019493845, 55.42565968728835, 54.69125863044493, 50.077323605937345, 42.724299430847175, 43.2341722519167, 41.398459865200905, 43.42523090301022, 45.61343493000154, 46.113678332298036, 49.687259581781205, 53.52717761070498, 58.22475325676703, 55.217350452176994, 55.90334946109403, 45.91308047694545, 52.95799855263003, 57.73447659707839, 55.32374474310107, 53.9552729360519, 49.806958552329775, 46.539953677884995, 43.73336445900702, 43.43930436718849, 40.95754231176069, 40.797815553603634, 42.43550708217006, 40.0339614191363, 45.96744060516358, 51.86615582435362, 52.53955225790701, 54.00312192978398, 52.383194815727975, 51.7198710287771, 51.88926250703874, 51.24234207214848, 51.56958149325464, 49.46233518661992, 48.39778038763231, 54.86518436862577, 51.57734386382565, 49.74356912797498, 49.44883831085698, 50.390936713064875, 51.622451120807284, 52.52406281809653, 49.80151038016043, 51.79389399866904, 51.41135700287358, 51.09078953343054, 45.83660602569581, 38.06330773138231, 20.429088454092703, 11.0662555310034, 2.271788754770833, 2.6954542533043893, 2.568429030718342, 3.280054354859937, 3.5243640840053563, 7.587215660079834, 12.547331721551958, 9.638830500264323, 2.4013265006003843, 0.11542121218817851, 0.28818747629561736, 0.6316504639483268, 7.302062290330087, 22.806068312737253, 30.964974818691132, 29.616471798189227, 26.91677305006212, 36.50261232929845, 22.30636815870962, 3.879142220943205, 0.02601637272164226, 0.025070072189273856, 0.006978527601477841, 0.04011858817971042, 0.04301487167756404, 0.08540884441425724, 0.05070901445804104, 0.02120274543431738, 0.08706863518924483, 0.0035314398138002767, 0.04229070025406057, 0.11890780090564683, 0.03877397363765105, 0.009175131506767244, 0.05396968001619943, 0.03066820415457891, 0.016595431370660663, 0.07307831453339708, 0.031741267340558196, 0.024359230695652868, 0.016156039726469788, 0.05069626675498101, 0.08616442927309582, 0.008274050271739403, 0.04829191129594561, 0.03414056661929335, 0.03624620524445369, 0.12546976532546744, 0.19378652165253318, 0.2773824189939807, 0.1823705551965583, 0.13416779738280082, 0.12314709399135844, 0.16295194235299865, 0.11845299748763924, 0.21080199328641738, 0.22225980346481647, 0.18446326225755677, 0.13608522352672395, 0.12886018702580085, 0.1265022833080542, 0.15370630298651036, 0.16489812743759927, 0.22141133044515887, 0.07673487517862551, 0.11697210356472962, 0.15186390749389125, 0.07067218558081696, 0.16714380693531808, 0.1237547166285015, 0.10828339479743473, 0.18075332826664373, 0.12879894595713387, 0.13747893664385044, 0.1990586161733635, 0.21963530881029947, 0.2091942811685224, 0.17276031926514643, 0.14267330388388327, 0.3302634152914247, 0.14851795719756236, 5.890518936418719, 33.79587096552695, 45.423658893954375, 38.649988405166134, 31.13204621499585, 43.32952507080571, 48.42265213689497, 22.593913193671934, 5.915834894103389, 0.5816621237224149, 1.2575281795955475, 3.826065688363968, 9.69262678777018, 9.230844186198327, 11.311372287811773, 8.007341709829147, 5.692038670662911, 5.054690289881922, 1.1267114959416853, 1.7410972185673255, 4.805480049502465, 14.089257601768741, 29.062007511815718, 45.891648646323915, 56.604331924069314, 60.131907693801395, 57.46727297382971, 60.13936804186914, 57.939530264946725, 60.8228841904671, 56.02044790021835, 53.05145294435563, 50.68853478277884, 53.57779579777872, 55.01792146313576, 58.932894045306796, 59.45787191390992, 59.96133950448806, 55.56576282747331, 53.641220523465066, 57.20673737987396, 59.424755342545055, 57.99471016853087, 56.24085764731131, 51.49686467263007, 44.54211012009652, 45.42117995600547, 43.81507527443671, 45.02806432785527, 46.27788443719187, 49.66709075435516, 52.82264540272375, 55.772660009322635, 62.196196202308904, 58.07952750113703, 57.43578418608635, 48.50249590412263, 53.149131728756814, 57.35297902937859, 57.668718061139515, 57.44902610778809, 52.410490589757124, 47.946001791184955, 45.250533319288685, 44.96321970416654, 43.6321202401192, 42.56521594139838, 44.23499638034452, 42.71747842911751, 48.03765189263129, 53.878869087465354, 55.28964757919312, 55.079734094681285, 53.53338280031758, 53.04640485394386, 53.58777822986726, 52.97224852346605, 51.66032160482099, 47.82949562995665, 50.68345531340569, 57.436702020706676, 53.88759636109876, 50.64256068198912, 50.54162633034491, 52.51632790411673, 55.33334278291272, 55.196938437800256, 52.52813816070557, 53.434982299804695, 53.11585434021489, 50.532365614368075, 47.07717326379592, 39.714700098960634, 20.525198290424964, 10.294284051464452, 2.6122924060590806, 3.6881656944751744, 4.147105313116505, 7.17276135759969, 5.799558191530167, 14.560807885662204, 20.358858416157386, 14.999998615634057, 7.381860950300771, 3.709660283019466, 0.570652888667199, 1.2520738787228063, 9.535347588600652, 25.242642702594882, 37.315562771212676, 33.4014727223304, 33.86534790838919, 44.087617243489916, 25.21061851132301, 3.848420011420404, 0.09452938162271055, 0.17082029352745703, 0.1007786519344776, 0.08907927125091515, 0.17857800628389084, 0.16855734640792494, 0.1752631438355292, 0.20782849961711516, 0.20970293290672765, 0.10144576129894103, 0.10669286603168135, 0.23554683242353702, 0.077895958036665, 0.09093534141298264, 0.24646416757135625, 0.18741754244171804, 0.12110710910130894, 0.16996322500128902, 0.12535607021662498, 0.2110247256895227, 0.13390806293295276, 0.17847887450648894, 0.26682741279082917, 0.14945292154387121, 0.19822515847702182, 0.2054662675025963, 0.13074704626154515], [0.06094607118997843, 0.033903607963434154, 0.041880781927536574, 0.05139939757364412, 0.035613711562848864, 0.07865693615449053, 0.03842896594095134, 0.028213267740342888, 0.05760342273260317, 0.009883768582386116, 0.02355595877874763, 0.008265644371990235, 0.015664687211204682, 0.01919765776443866, 0.04482094694169299, 0.022793592126559348, 0.03300054734873195, 0.039360379469731165, 0.03603098816388557, 0.0442396279334301, 0.018716533480572606, 0.06867641928575693, 0.059713439550250776, 0.007801818832259386, 0.05389454977346524, 0.020281549603227648, 0.04612487455409381, 0.03417520145435007, 0.0711611795028852, 0.01812596204540422, 0.11040240165687377, 0.0824021867987129, 0.03207251609813783, 0.04661569942630107, 0.30777033839014273, 6.542996879546873, 22.431187783518148, 32.265132665634155, 26.20028545779567, 29.38408705496019, 31.786948673186767, 37.23037281344014, 20.625512907581946, 4.035596006339596, 0.4782711732531748, 0.11364758074764283, 0.7394060624703285, 3.889668146448751, 10.350097417831421, 12.952311538880872, 2.8551846886834795, 2.8899177668556093, 4.026587547794465, 1.3527241036776574, 0.4489981875784936, 1.0005344246183674, 5.226612187200978, 18.45275321314412, 36.47965469667989, 51.62058407260526, 53.86389347814745, 55.29025946894, 56.94022017140543, 56.00506436440253, 53.866592068826, 49.52747398807157, 48.650714428194114, 52.395977820119555, 53.78884284727035, 55.26086522686867, 58.90856358312792, 56.33989749416229, 56.28447440362746, 55.79910855139456, 51.187283762039684, 55.8710644322057, 55.823792026888945, 50.27414814118416, 44.806630842147335, 41.09023609469014, 41.174822007456136, 42.568483275751916, 40.979640945311516, 42.857691395667295, 45.68249610162551, 50.0518556564085, 50.86037774239817, 52.812459007386245, 52.58862110876268, 56.83976042655207, 44.23254097661665, 49.25767375576881, 57.06733634394985, 53.0378697764489, 52.369038981776086, 48.87917287888066, 45.50013726757419, 40.85209331204815, 41.17890127243535, 39.29566937108194, 37.632890362893384, 39.42735510487711, 41.013977373799975, 48.28978969204811, 53.405282112859915, 53.170202701322495, 52.28412751228579, 49.3705556469579, 49.8317636212995, 49.16378005858391, 50.522991149656235, 49.63574709430818, 45.77269492610809, 52.42003371638637, 50.700094007676654, 47.86562850398403, 46.93116303413145, 47.21097315511396, 44.64049493112872, 47.322070367874645, 48.86558186623358, 51.71152422505041, 51.30907727826027, 52.497151436344275, 48.28137620802849, 36.56981037509057, 22.191252477707405, 9.237853461696256, 3.006752916882115, 1.0720732471635266, 2.426101416349411, 1.9681607763613425, 3.1664402061893098, 2.6504070576160186, 7.851083307496964, 18.002078763900265, 13.344147493762355, 1.8738323089576538, 0.01871941014072828, 0.7832210823412865, 5.2760085559660395, 22.779492293634725, 33.15426926459036, 44.54445569745956, 23.36067968799222, 26.232901926963564, 23.696183543051443, 6.261696748195156, 0.15705887228250504, 0.055275767996546724, 0.029481574179484483, 0.01752747692197802, 0.06832321444826742, 0.004627833249903615, 0.02903783115588369, 0.047567751363761006, 0.06640033375832342, 0.15124231907388858, 0.01530648748044886, 0.049230652455721176, 0.037263378485917084, 0.06461546380793856, 0.03410386334684107, 0.03531655371789971, 0.06616203444859674, 0.0485154289391733, 0.01772255738145642, 0.0750451916528325, 0.07461800570449523, 0.02234477568568001, 0.027443822435734254, 0.040687186297990625, 0.035901136260720036, 0.008678070678856344, 0.014230228750215424, 0.029786931080443245, 0.00955795138818963, 0.10916693166138665, 0.029042109756940798, 0.07501339134309562, 0.07513843987497591, 0.05291157469694173, 0.025790991569538752, 0.06803370982168183, 0.07022675141812333, 0.04934939991442427, 0.015761852057860987, 0.058414001213086236, 0.03147028288954208, 0.0590127831955831, 0.04052004123467111, 0.013001722493960012, 0.007300295542189552, 0.05752143600294667, 0.07656553910384256, 0.04517797455792466, 0.020667703882340464, 0.026219384106356772, 0.02437906854245211, 0.09054251450804934, 0.041284700404972806, 0.035465894897858945, 0.014775843273157315, 0.018443792772990082, 0.05095668302308168, 0.04052278382944004, 0.056869353453118, 0.05272741099038432, 0.026402469544160753, 0.08846226403669966, 0.5846988349672287, 10.52316023457435, 30.183093470911828, 36.905196559044626, 25.89086732556743, 33.040771561284224, 42.353086317739184, 42.89770741616526, 20.560246629099694, 3.6140213762560203, 0.26489910819838125, 0.10445490870023928, 0.08845513941900385, 3.08805359948066, 6.975276393275108, 13.512430902450317, 10.865753773720035, 9.162569449793908, 5.411755904074639, 2.842081520826586, 2.112314989489894, 2.2894112285106414, 8.109714590734052, 22.82441127684809, 41.30107133619247, 53.58191036408948, 55.94793896521292, 57.342196433774895, 59.528533412564194, 56.82246277409216, 56.1472620502595, 51.559857937597464, 49.94559864844046, 53.49477491071148, 55.322324845098684, 57.32400448091569, 61.00440363730154, 56.482487417036495, 59.27418731874036, 57.36207892817836, 54.148269238010535, 58.787028943338704, 57.3562228295111, 53.90078336961808, 48.177288270765736, 42.62403188213226, 41.854537379357126, 44.70785379409791, 43.06618498217675, 45.13052055912633, 47.36933885082122, 51.810626829824145, 51.379597571588334, 53.632234373400294, 55.72708599029049, 60.28691584064115, 46.84897368954074, 50.311422424931685, 58.31442648364652, 54.50445575098838, 53.106895646741314, 52.3936479322372, 46.568100606241536, 42.86834847542548, 42.92636033027403, 40.845511574899, 38.95880053120275, 41.13415095113939, 41.05402869562949, 50.020166827786355, 54.23035267860659, 55.009723709475615, 53.502141121895086, 50.67052325894756, 51.698972640498994, 49.92554356974941, 50.88621047235305, 50.32946140535417, 47.81290400412775, 53.035524199085856, 52.018375166000865, 51.109001098140595, 49.344813131516986, 49.22791081090128, 47.68221062998618, 49.56135149924986, 51.135296667775805, 51.93166725097164, 52.450373249669234, 52.92362290043985, 50.17798731403966, 40.41881261333343, 25.590647151393277, 12.254520904633308, 4.33780457704298, 2.624107075314368, 4.137041491846885, 4.147667682939961, 2.8876476951183814, 5.892226638332491, 9.194275929081826, 12.455481579226833, 6.921841454121375, 1.6179980433756307, 0.17294162163330665, 0.6979618702203997, 5.0510841608047485, 21.703037023544315, 37.68988240149714, 45.339708405156294, 24.777510396895874, 30.233850902126683, 31.916488870497677, 9.640012114278733, 0.41210903155226863, 0.08588185008134573, 0.06927635040014021, 0.032496679829613816, 0.022827993304799163, 0.01917342065773424, 0.07453190508268534, 0.06051784336206414, 0.03607160614563092, 0.07449912418040537, 0.009310414973315934, 0.03296377895880611, 0.017490628092820128, 0.020250789257847977, 0.01262827761351101, 0.04693295558794372, 0.018037170539760304, 0.02615333775118474, 0.025974034872506897, 0.0734875740243062, 0.04477824137035397, 0.0031393926427324094, 0.048419779031387264, 0.03771352025890543, 0.039437754350083495, 0.08383628041032823, 0.04930149260607939, 0.02290009558501263, 0.12844393315214303, 0.1674462431260655, 0.05625970834385484, 0.1281468672377448, 0.23702293063604066, 0.19343012222839942, 0.08730936299769149, 0.14676732371651358, 0.12680809028566847, 0.13755709293388552, 0.16407807627993246, 0.10754069553748255, 0.13130984509423857, 0.15854583362177496, 0.16592025726793275, 0.07684180573109659, 0.12263720119071585, 0.07912315428256989, 0.18582058619827996, 0.15456065956142642, 0.08766825220757916, 0.17612716844004972, 0.10442179071927264, 0.09893247962839181, 0.10648612954443502, 0.12673924196391337, 0.09523609007198004, 0.10995060896440861, 0.15163987274131469, 0.1376837119460106, 0.2303918421028122, 0.23339152065736635, 0.1467912716250266, 0.1732332713060802, 0.5382468791738634, 9.890802579541361, 35.00616535063713, 47.05920880840671, 36.53852947296635, 39.74182721107237, 40.437447794022106, 46.22060606556554, 25.44320329543083, 4.750317306287827, 0.7516703946936516, 0.47787112213911553, 3.225837393153099, 9.08287767441042, 21.023174562761863, 23.435045865274247, 9.922206055733467, 8.52538041530117, 8.857096241366479, 3.339318426386003, 1.955856546278923, 1.9760590815736403, 7.747584706352604, 20.782909777856645, 40.11973188769433, 53.93160143206197, 59.906916618347175, 60.76035376518004, 63.101663589477546, 59.616551399230964, 59.40222917064544, 55.287235321537146, 53.01330397205969, 56.62962336694041, 57.98392757292717, 58.466245743536184, 63.24075475815804, 58.3967334993424, 59.53925325024513, 58.31074337805472, 55.638699300827525, 60.59362949863557, 59.72584824408255, 56.38352993995913, 50.88110746875886, 44.21957754319714, 44.096995630571925, 46.966903671141594, 45.2870858869245, 48.414701492555686, 50.10634130047214, 54.56451116069671, 54.21933866316273, 55.44147468382313, 58.08758797184114, 60.754270169042776, 49.61502521268783, 51.44199855865971, 60.03275802058559, 57.61328712586434, 56.29222500708796, 53.574061701374674, 50.062559804608746, 45.857076875625125, 45.58703345637168, 43.464333011258034, 40.23798742601949, 42.29855752760365, 44.72528872951385, 53.74607724528159, 57.3715239955533, 57.002915336239724, 54.08009844441568, 51.72076532917639, 52.1675350589137, 51.7992284221034, 52.232367915491906, 50.38266835674163, 49.04648942332114, 55.85706941543087, 53.168045397727724, 52.58031745110789, 51.061544341425744, 51.43209457397462, 48.32443206541, 51.32601015029415, 51.6023293618233, 52.294749290712424, 53.51868175691175, 54.67534557465584, 50.75367358423049, 38.960251808166504, 24.91098080911944, 11.634754057853453, 5.042916805513444, 3.6714880216506223, 5.469359832425272, 6.090252889740852, 6.164698495018867, 7.956449447139618, 16.399760150140335, 26.812677268059026, 19.48056717072764, 4.465320341048702, 0.5340686969218716, 1.3093075108143593, 6.6986335862067445, 28.26353453820752, 39.16004950000394, 51.42871741325625, 31.303332198050718, 35.600216157974735, 36.949891967158166, 9.91754431878367, 0.5812412043732982, 0.2552284892167776, 0.1858540795623295, 0.12942444142555037, 0.1943502551124942, 0.13493118867758783, 0.1437248974557846, 0.16075176847798212, 0.15637374453006253, 0.2968664251027569, 0.14037120967142044, 0.11396048936031519, 0.15299207921470367, 0.12270111590623857, 0.11364831619205014, 0.1478488406827373, 0.23521608162310817, 0.11641156469141284, 0.1374633084501951, 0.1501899440923045, 0.14814464255206047, 0.14253044380776345, 0.31971990040713744, 0.1369259743801048, 0.16238063994434573, 0.29338084762134864, 0.12442385612596428, 0.20773053229335817], [0.040762216949294654, 0.03228353501688088, 0.07821015367705016, 0.06883476199882646, 0.04441916829936447, 0.028797614711126494, 0.023877010906055093, 0.04961597552943615, 0.03504851870539208, 0.05568671288088926, 0.010850484400326687, 0.008717953216194386, 0.02267942395842364, 0.08102561872933181, 0.030205709213811546, 0.04481455010752525, 0.06309134720434105, 0.028011077984927163, 0.06051381757002204, 0.026640416453442266, 0.05204729728340622, 0.0833659177465785, 0.03224135038533038, 0.04768788544160705, 0.02717402542100078, 0.0010809750787185266, 0.03680800433240591, 0.06915421300237218, 0.09715347791150694, 0.009656392728849765, 0.0257959577345079, 0.043790872779584704, 0.051667329164281975, 0.04941520686711996, 0.0658103464651973, 0.49275299293860314, 8.477406886316116, 32.16235480000896, 36.44497702198644, 20.34550274572065, 22.121818680917066, 31.46735199036137, 30.583742010977964, 20.726119741316765, 3.908397218873424, 0.2825638393480932, 0.1341049015642174, 3.331693583919156, 8.878002474384925, 12.593026353466897, 12.220799307669363, 8.217114479311052, 3.380471443937671, 2.629975921684696, 2.410858105267248, 0.7241821180908912, 0.8280248459308379, 2.6116035397975677, 13.142623959049104, 34.37095319071124, 52.12115303162606, 57.582876989918375, 55.15147032276277, 55.807549492005386, 55.65491437911988, 52.399758984965665, 53.670544162873306, 54.379626320254424, 58.4993270135695, 57.36057273803219, 56.41517562250937, 55.92643260955811, 52.254870553170484, 55.201849245256, 57.880910442721465, 55.661056810809725, 52.65290875588694, 46.11308213203184, 43.76120544249012, 42.2437188702245, 43.03572777778872, 42.48514467670072, 39.95719279012373, 43.09206870294387, 42.826441872504454, 49.341643856417754, 51.872937602381555, 54.18868926263625, 54.10987315639373, 57.391371188625214, 45.94221584258541, 48.08417512524513, 56.19013747861309, 54.273479138651204, 52.69616073177707, 50.96035895809051, 49.61001634597779, 43.5512331224257, 41.85647110785208, 39.51152524640484, 39.79257875873197, 38.79517101472424, 41.50233599447435, 49.496393126826135, 53.0831378506076, 54.836774641467684, 51.853557171360144, 52.10677754494452, 52.06440417997299, 51.62028597247217, 49.6000535257401, 51.06545102211737, 51.808398923566266, 50.21459479485789, 49.02760321094144, 49.434121577970444, 49.46985044787007, 47.29207992553712, 49.090945566854174, 49.62634909537531, 50.82433116051459, 50.47538142050467, 53.4890482502599, 48.32097645728819, 38.3898058245259, 22.592816891208773, 10.080169708498063, 2.3811500735821265, 0.9944144852699773, 0.7985824935378567, 4.393050670623779, 3.9975058695962353, 0.6519481167197227, 4.147306334587836, 3.9648379193198298, 6.787438988685609, 4.182708667170617, 0.8630902224010037, 0.24246786991434716, 3.8775823433553023, 14.847836148354316, 34.881437901527654, 20.78872076926693, 40.447257641823064, 42.701377099560155, 27.3405518070344, 9.11992936365066, 2.1427802837664083, 0.0454223144709343, 0.09529774482812613, 0.12752721702019054, 0.04374615239700483, 0.04017892143418712, 0.0833270081409043, 0.020890560774733464, 0.030278606310246453, 0.03348833468231944, 0.07698124139419488, 0.0703234087315298, 0.11657592885556722, 0.05470859097136606, 0.06244693702507404, 0.03543495260659726, 0.037432316194979415, 0.07606639451677762, 0.02236579905354208, 0.03933232149950439, 0.012233546980085873, 0.06060222028604439, 0.043202915619457924, 0.04998434507738679, 0.05114977165395695, 0.10244021237257028, 0.1515854345334153, 0.0451937483082856, 0.05616546037697023, 0.02254174263667195, 0.014165134259289312, 0.038419278759148814, 0.10031925964980357, 0.03449009040430669, 0.0245515781364614, 0.009394279575996823, 0.03514727126927145, 0.009744318555139247, 0.07438092447456814, 0.01538624297902589, 0.04009731391805314, 0.014399441293320589, 0.07900640248290955, 0.04979666119681732, 0.035047120594930266, 0.012710313181272678, 0.02860503552872087, 0.06293848201993012, 0.044743227321774735, 0.041624732360604315, 0.04387247263483944, 0.026367158636510856, 0.06374742490269485, 0.0568591529924062, 0.025824138278802557, 0.05078678387367437, 0.013450226754010206, 0.05191787055903866, 0.066134623822666, 0.06027494369435215, 0.034230635576551004, 0.025247143836872234, 0.0777168236973305, 0.02989862286936372, 0.9874487848531817, 14.546496137495964, 37.74988289802305, 40.619422235796534, 24.40353593518657, 23.474489219727058, 42.21119849912582, 41.25382638746693, 21.059223105830533, 2.935104451833233, 0.1917374509597017, 0.14744673645304096, 0.5798244932966848, 1.8585825014498927, 7.687290522360033, 11.125696109187219, 12.659678209212519, 8.602780545911482, 7.014923710976878, 3.688999933581199, 2.0785311248994645, 2.048331080905853, 4.750940963145226, 18.279009865176295, 38.27850857088643, 55.45275149806854, 59.51939821243287, 58.58112804351315, 57.845291399186664, 57.28809910435831, 53.99429659689627, 55.33000092352591, 56.55576121422553, 60.144745611375384, 59.0369741378292, 57.23757505416871, 58.97306696061165, 53.906965025009654, 56.41936471385341, 59.54449353679534, 57.1606848316808, 53.291235277729655, 49.03529890121953, 45.758597927708784, 44.655341102230935, 43.42290885986821, 45.16539827469857, 42.17183751444663, 45.67567509989585, 46.539828162039484, 50.57347989851429, 55.4883470073823, 55.53578415224629, 55.68564614941997, 57.737112429834184, 47.493238679824344, 48.92870064704649, 56.55578867081673, 56.93963181587958, 53.49876396117672, 52.37166696979154, 50.84621014133577, 45.21163517428983, 43.05153100721298, 40.88931268261325, 41.41843649648851, 40.45522397564304, 43.89374233061268, 50.45835833395682, 53.454413721638346, 55.992646140436975, 52.827313023228804, 51.56789095171037, 52.70972428783294, 52.690763550419966, 50.50047674486714, 50.824389996067175, 51.48738822629375, 51.71741170267905, 50.29813343478788, 50.662639294901204, 49.95573013059555, 48.519248347128595, 49.61003595782865, 49.79207707989601, 50.61477853405861, 52.10842101804672, 52.556485129940896, 50.22047442774619, 39.862047856853856, 26.49176855241099, 13.289831492208666, 4.437624975558251, 1.6995735370343732, 2.8463544528330527, 2.6745507169154386, 4.251074598681543, 3.580595918240086, 5.893731847886117, 3.7408112566317286, 3.4687328627032623, 0.5687584451610043, 0.1177392103859494, 0.28286644407818395, 3.3399536052057823, 14.743582490951786, 39.02567302027057, 30.58442842575812, 49.042288564866595, 40.14244241099204, 29.904877793404367, 14.84247426832876, 2.9578090915756845, 0.04532729658568579, 0.02203031382974117, 0.015263909271227257, 0.06491049192845821, 0.07517715795866906, 0.03391184723905979, 0.026308683145250526, 0.08636578782311372, 0.1040605266368197, 0.026490506453199253, 0.04553847638289294, 0.10203399425072056, 0.004498605708396363, 0.025016290901769555, 0.06681425106381217, 0.04062255145981908, 0.05814030864125779, 0.016981168131854747, 0.06916817112435257, 0.030187190953461878, 0.03878631531411121, 0.04814113753156797, 0.049228392496344545, 0.04830649761002391, 0.06424170866188023, 0.0664238986228743, 0.05727748679477842, 0.019242920154224963, 0.17419530919963316, 0.15036042929897386, 0.20244806494203307, 0.1964348569632538, 0.1996983149118962, 0.15239094534227926, 0.07766064646984301, 0.1616450729629686, 0.14753120530757213, 0.132855887134229, 0.09602573519993214, 0.19100977468394464, 0.12338517879646634, 0.1841304276979739, 0.14367435097454057, 0.10968440107160038, 0.06767703460589533, 0.120665988013629, 0.18663893664075484, 0.1152243582351554, 0.1753328884801557, 0.2177909827761112, 0.2046752970425352, 0.12542134090777368, 0.1224468360024114, 0.10878141323525099, 0.1602464722048852, 0.10945176315163413, 0.16712128395034423, 0.11774713939596569, 0.17706087640216275, 0.17070121282050688, 0.22173771454441935, 0.16160096162028853, 0.14472687917370952, 0.7848451274537271, 15.47906514137022, 43.26555905803558, 49.35907486946353, 30.666849190188994, 31.211725242676277, 42.5051526869497, 40.07328318011376, 26.32543848406884, 5.423098418020434, 0.7130800944662864, 0.3569089645339597, 6.473209088848484, 17.236794925505116, 23.696501255035404, 19.597169430025165, 14.453640887814185, 7.937442621877117, 6.548239617578446, 5.631586120974633, 2.3611918284047038, 1.9403767898198099, 3.7929091578529732, 14.773875936385124, 38.03338396933771, 55.78963994979859, 61.9122205242034, 61.62921759390063, 61.98524328970141, 58.56632501848283, 57.73696337976764, 59.04643097231465, 58.709852387828214, 61.68338160361014, 62.524106348714525, 56.49751401716664, 57.64201064263621, 54.45319429520638, 58.59428759544127, 60.2741289138794, 60.07121686012515, 55.66837203118109, 51.115614214251124, 48.22529415930472, 45.71829949655841, 45.96349470077023, 47.32725181887227, 44.753839661998136, 47.35253149463285, 49.386821716062485, 54.36622358137562, 57.2446745441806, 57.45687869287307, 58.47767945258849, 59.853776347252634, 50.183525700722974, 49.98927424030919, 56.85407315531085, 59.71607761998331, 54.742641679702274, 55.64338261081327, 53.03441416832709, 48.208859428282715, 45.46507127823369, 42.17417524706933, 43.88980819332985, 42.91017270857289, 46.26864725543607, 53.83351864353303, 56.047822121650945, 57.81071178374752, 52.87705652175411, 54.3812737157268, 53.698016443560206, 53.379519985568145, 52.15424999114006, 54.35020069922171, 55.22627384431901, 53.0531866319718, 51.194595060040875, 54.430719114119015, 53.62533100189702, 50.99637023864254, 51.80671230439217, 51.719255216660045, 52.52069350211851, 52.746143494882894, 56.22960436728693, 52.207786421622004, 39.581739594859464, 25.574406577694802, 11.251634590087399, 3.6754273070443064, 1.9811992251103925, 4.1496180815081445, 8.52452043564089, 8.370146732176504, 6.160647176927136, 10.354404180280625, 9.875781862966477, 13.722711128573264, 7.518088298459207, 1.6404838884069075, 0.5361324765028492, 5.237980686849164, 18.076856790050385, 42.25937697195238, 28.491596829506662, 48.45783187497047, 49.49154899966333, 38.84537735292989, 18.298300081683745, 2.930724390091435, 0.1651997975404224, 0.19778398376318718, 0.24700366200939303, 0.20717979168459294, 0.12508871319193032, 0.2252104064269412, 0.1297446814996581, 0.21342939907504668, 0.1635337708097312, 0.10532468662507112, 0.13402902821619667, 0.34537174168132967, 0.09805464245859655, 0.1676033984028524, 0.14047985626084192, 0.13679531042373952, 0.2505044539969775, 0.06620298950902878, 0.07577574075830561, 0.10614501357439066, 0.1953734727876802, 0.1294998091555411, 0.1495682484199924, 0.122735520914918, 0.11641088287316023, 0.2180543791262373, 0.08748046107470028, 0.21508799475287238], [0.06036557189579453, 0.03695389811670588, 0.010005603375424062, 0.01688448400537093, 0.03088141025434579, 0.02012968990921734, 0.07119239758579962, 0.024836587742151275, 0.037595803188460494, 0.0400796594218381, 0.03174837855171533, 0.018083072612963377, 0.013257742374985209, 0.05124218867070252, 0.024473366305051793, 0.029311826332442226, 0.0850983183350294, 0.05982451846883182, 0.02734208787460962, 0.042685308313417825, 0.03780333640714807, 0.10268296265313703, 0.0374727962808984, 0.03040155767643404, 0.044202143251295054, 0.05737111040000474, 0.02340845812502648, 0.023246888266575914, 0.015494842645561984, 0.06664384246593522, 0.018370907167874036, 0.045546344105875304, 0.06245718728150092, 0.059503585085152626, 0.08920415124345211, 0.036874975738746506, 1.0557499359692297, 13.524258809704936, 26.629710466631, 31.63986763646526, 22.8949394149165, 31.242959076358428, 37.782132625579834, 36.225681228022424, 21.533527874177505, 5.5148848218302575, 0.4328244473905333, 0.3404810976597571, 1.451245829943688, 6.074738935116799, 13.666019151287696, 16.49099349975586, 7.14777046634305, 6.355089852886816, 3.2542515329776274, 1.7215466547396876, 0.4873563631648018, 0.0815994568890141, 2.1097249994354863, 12.64664907609263, 36.237875876888154, 52.15986682522682, 56.832060813903816, 53.77155696192096, 56.643014338708696, 55.437262058258064, 54.836398093931145, 57.22614918985675, 59.19560655470818, 54.884251010033395, 53.079027206667014, 52.979901067672245, 57.649074831316554, 56.80714984093943, 55.33094621473744, 54.06765276385892, 50.96299479084631, 45.37987347572081, 45.54231059166693, 41.87818534912602, 44.748258129242934, 42.590432859236195, 40.70347470621909, 41.15930903342463, 44.35262041707193, 49.868661357510476, 52.54361583340553, 56.653459610477576, 55.041102670854144, 56.077487007264175, 47.244536876678474, 46.7694672461479, 53.22173480064639, 53.352459553749334, 55.12882647975799, 52.339836935843195, 50.90336691948676, 46.81806149021272, 41.93648745936733, 40.35836888897804, 40.68667127240089, 38.02296223178987, 42.66230244790354, 49.08073563729563, 55.109669623836396, 54.44040736844463, 53.62375420908774, 53.21455294086088, 52.85559723454138, 52.31873458431613, 51.9955587387085, 52.88481889232513, 51.19519126030707, 48.15162420272828, 50.4456655440792, 51.7905992077243, 50.242698577142534, 52.80542619766728, 50.22633837115381, 48.79624220632738, 48.765208413524014, 51.65071179789882, 48.07699718782979, 37.77598234914964, 23.567980873969294, 10.323206628522566, 2.1339206301396896, 0.6349511384483307, 1.2569426432732613, 3.3964820686847936, 1.863183809384223, 2.7610740353984218, 2.099079441639685, 5.640616888000119, 4.725798080044409, 2.197218614239847, 0.04659201581812194, 0.3421312816921742, 3.084981893339465, 15.712808985863964, 26.033900476271107, 24.107130266004994, 19.292689561843872, 25.533931639886674, 43.55242160058791, 19.936362274231453, 5.633908164116645, 0.2515504244835146, 0.10502197464267093, 0.014027438573389044, 0.059290570507366816, 0.053636569664963794, 0.1011867086673456, 0.038130643642357284, 0.022461556213637515, 0.008349978203524747, 0.021750454250122273, 0.02895293712255455, 0.06625926632794642, 0.06039485177626053, 0.06239730218845991, 0.040870844386518, 0.02591042659215389, 0.003493735360191955, 0.029306821863076864, 0.03801867989222369, 0.07110416723956024, 0.04953008558180544, 0.038203100238235733, 0.03831702517345548, 0.013960305330974442, 0.04919373084821048, 0.0028628952314911954, 0.022191492983350353, 0.035537585405813116, 0.030264707560080196, 0.06988824780790076, 0.039399610832333565, 0.003389753528021937, 0.01579370982419219, 0.04410959216916273, 0.03533859789792088, 0.025911405269477158, 0.06999675650149584, 0.05640063021752623, 0.05402428676344214, 0.02605783531532413, 0.07189725210229236, 0.019119465085227164, 0.04304808541952122, 0.03206979648600663, 0.01866762642748654, 0.03482018236912066, 0.06654834960617366, 0.026862982232424042, 0.040312845094670216, 0.02574105029775491, 0.057775313710613604, 0.045280059604274656, 0.03558216406212699, 0.05781698889369446, 0.04368617920385253, 0.08179612698093539, 0.062043415532717784, 0.019267664794179223, 0.08281010563575453, 0.03613887632626199, 0.09717308210148927, 0.11717327059276643, 0.13506496295092568, 0.06212164460110569, 0.05173931461608699, 2.441188568069089, 19.951628138942105, 34.47363299708213, 31.40168170775137, 20.62828798447886, 30.26403157941757, 40.684855215011105, 41.245408981077134, 20.06188008093065, 4.145994792061468, 0.4169146704577631, 0.1259832127740787, 0.4922712768518156, 2.0098955304391923, 5.973092182990044, 12.389225882868613, 10.036236220790494, 6.480760632022736, 6.020978929535036, 4.412691939261652, 1.7277180139095554, 1.003956631306679, 3.220280130063334, 16.210361642222253, 38.9761923205468, 54.96289453198833, 58.86274637714509, 56.93287749444285, 60.363696236764234, 56.5504660144929, 55.80740436430901, 57.81149233541181, 61.442673590875444, 57.118970424898215, 55.57066186781853, 54.475418444602724, 56.120150627628455, 59.270272793308386, 56.32097205808086, 56.94294229630501, 52.96156790948684, 47.47763549127887, 46.587924265092425, 43.27186230690249, 46.44402819295084, 44.55646991729737, 43.46089701498709, 43.69769050228981, 46.66470073884534, 50.60209751129151, 54.68401009036649, 59.03103174701814, 57.89745107773812, 55.9512141443068, 48.11215731405443, 48.99636153251895, 54.30235955022997, 54.22882295423939, 57.44304057090514, 54.25920563359415, 54.22147635490664, 47.86815843274517, 43.69963992026545, 43.62534630683161, 43.177756801728286, 40.29781533825783, 43.07109186726232, 51.18139236204086, 54.84760822788362, 54.558388340857725, 53.0071811522207, 53.22902648679672, 53.64229917526246, 53.27847580755911, 52.76748903336064, 53.52175689512684, 52.25814573226437, 50.40538672477969, 52.47796320146131, 53.878531763630534, 52.090421261325965, 53.90486655696746, 51.61415138552266, 51.021696982845185, 50.08397594574959, 52.024635268795876, 50.5654311949207, 39.77107240307716, 27.46755030847365, 12.86507704565602, 3.7999145109807295, 2.669752432454017, 2.2121974104835145, 4.302728781777044, 3.1804134047800496, 3.5769137932408244, 3.1226976888795055, 5.078222549730732, 4.574491670054774, 1.2272894021964844, 0.18120666845671593, 0.3849060767360272, 2.4905172759486787, 14.815988463740196, 30.14843148569907, 32.8775970397457, 20.01391145490831, 32.673929929733276, 50.00865467133061, 26.999903763494185, 7.767347568465818, 0.42094211724977343, 0.027824439814374335, 0.014927220331775326, 0.05700798855433541, 0.07141270149018496, 0.07218171587033619, 0.06678411316487097, 0.035755365050487944, 0.05373248004264409, 0.10865028196525191, 0.028414921234211618, 0.05271034255143135, 0.056290528061048645, 0.0714423107884584, 0.04115826142350993, 0.07591483934271721, 0.014255385162428984, 0.06140902961393999, 0.07151666728238906, 0.06611871217647869, 0.04707529855471465, 0.052859963353482954, 0.036724611831408356, 0.03997652100459222, 0.03991965046753326, 0.013740423732557365, 0.02171639206578895, 0.036692627660569646, 0.07744748250491197, 0.15629163522633815, 0.1767862338813082, 0.19222327327776342, 0.07642485471742769, 0.10344852197674975, 0.11899777027147433, 0.19317277797287513, 0.07304272974931425, 0.1264841729895242, 0.15656537376344204, 0.21882369994155823, 0.20430271784144066, 0.09851775793058258, 0.2223073775249143, 0.12641494162380695, 0.2171059469542196, 0.14649968323928697, 0.15603412243147052, 0.16266913333487126, 0.11576996605482795, 0.11288763684851509, 0.1810039615919513, 0.1800315968331791, 0.14059311469956753, 0.20241806493891826, 0.12817253884408744, 0.22677072834584022, 0.19435390169101377, 0.12797144076396383, 0.16972031384225816, 0.1284726691101828, 0.16878634541025087, 0.2929388761760727, 0.26021714652738265, 0.1449969098452599, 0.11550429442356672, 2.3286055124575094, 20.507667256939797, 40.40968525794245, 45.534069691934896, 31.12218341519756, 41.360216756020826, 46.862945172094534, 44.2829159767397, 27.2305489355518, 6.517324966769065, 0.7448651437317172, 0.6751638290382201, 1.9749097045390838, 15.377137449479873, 25.115591249158307, 27.2987413021826, 17.484231764270415, 13.388526170484482, 8.297065131125912, 6.172647668469337, 1.3810872526899463, 0.9049242001868064, 3.4391569658633205, 15.11228430655695, 37.66941547393799, 53.4016146967488, 60.774442918839, 58.752563076634566, 63.748842900799175, 59.86948936216293, 58.220250375809215, 61.16305566603138, 63.32525830115042, 57.1576096934657, 56.422086838752996, 53.393464011530725, 58.197288820820475, 59.62126608817809, 57.982794007947376, 57.89418766575476, 55.0789809996082, 49.30236131914201, 49.49218050126107, 44.82532878075877, 47.193228352454405, 45.6562711346534, 46.16763445638841, 46.093729157601636, 49.399961656139745, 52.98869894396875, 56.85160990684264, 60.26469561361498, 60.08123067117507, 55.76220689281341, 50.7687041067308, 50.6506682211353, 53.498626678220695, 56.52325653260755, 57.59987654224519, 56.5928864479065, 54.98256914077267, 51.38272762298585, 45.94454965283794, 44.85108698568037, 44.954763074075025, 41.52907479193903, 46.33599435129474, 53.445196151733406, 60.45389898361699, 56.99837323158019, 53.927235834060184, 55.68088046966061, 55.02211055447979, 55.32485869623, 54.68952494282877, 56.687996079844815, 55.35576697318785, 52.08089774654758, 54.97234744410361, 54.815754659714244, 53.33170629316761, 53.62032213518697, 54.238303322945875, 51.22599755564044, 50.17872471963206, 54.263547697374904, 51.752795404003514, 40.01413383791524, 28.350964169348444, 12.16570177385884, 3.628190693355376, 1.8705809092329395, 3.1705040268359648, 7.548486176998385, 7.25695699453354, 7.9504894056627835, 6.631210984722261, 13.55479250031133, 10.477121414676791, 6.5293597790502735, 1.0582095072154076, 0.8100997368174215, 4.294174092431223, 19.782428856818907, 32.57455079786239, 32.754395392633256, 27.647265465028827, 36.15189752271099, 52.7695208211099, 30.556599209385535, 9.340306751189694, 0.373928067424605, 0.18321438572339474, 0.0926735872522958, 0.14289700155777318, 0.12269910109499771, 0.26446544114620457, 0.2005433711794115, 0.17188806687631916, 0.12929301138126081, 0.14997573058691718, 0.12809367009228276, 0.11041376274079086, 0.22262398634226094, 0.140466985983714, 0.1651080508506106, 0.23088091263367286, 0.10730107089564686, 0.16274837746975884, 0.14524824797145783, 0.23969896768610324, 0.14472821216669776, 0.10469036582376688, 0.08249176545969902, 0.11833888103043842, 0.15381456653196968, 0.09242265515269772, 0.1014545406665533, 0.11740697337494743, 0.15821831571238656], [0.031444283780611815, 0.023285836176646334, 0.014284938919327915, 0.036096143941845626, 0.07053330150102416, 0.10708960764590772, 0.03787383181794036, 0.020504726337329037, 0.040021072847828756, 0.059948034824863564, 0.06795271900632689, 0.005479144146515718, 0.05764189566816053, 0.024043071954961748, 0.07459005881701747, 0.016068870412005533, 0.032925283040611014, 0.04871265444483969, 0.08340491162192437, 0.05074995419671459, 0.03951830083444234, 0.10697269496778328, 0.02616325284414474, 0.03373147183728795, 0.02333378178938743, 0.01810665088405292, 0.05464111777743506, 0.03070215142572359, 0.02106953806604349, 0.040614890580576275, 0.03506235808374421, 0.09362225691157003, 0.040432948528999285, 0.06505656191298077, 0.025368252761601925, 0.14099376336220773, 0.04396534164346034, 1.3168872460242242, 14.110470760253168, 35.47594762617542, 30.731005437912483, 24.71545457839966, 19.780542196766024, 26.279676191268432, 27.647783217891572, 20.603437808252153, 6.201424627534806, 0.6236093599469431, 0.1762954932787726, 1.604172301388556, 2.2160472168076426, 8.764144893615477, 9.735613023081134, 7.631926757674064, 4.355412096746506, 3.5218035117272413, 4.791728219678325, 1.3163106576088937, 0.4553965539220841, 1.3963484595860205, 14.203815325613945, 35.875268443938225, 55.68861930601059, 58.77211609194356, 55.60512773452267, 54.044722587831565, 58.61366802646268, 58.022931621920684, 57.69616680760538, 54.17825183560772, 51.76140108416158, 56.54950111143051, 58.23924641455374, 57.82744069253245, 58.041205944553504, 53.8574960923964, 53.69578461493216, 46.65754241328086, 45.067652810004454, 43.68227166514243, 43.69603526207709, 45.02424393930743, 43.25111689106111, 44.2770363438514, 44.64675503392374, 47.5440098393348, 53.86040256869409, 55.619091372336115, 54.425192494546216, 57.30680096533991, 46.467354528365604, 43.88834514925557, 53.74280598855788, 54.52900978826708, 55.659240753419944, 52.99595140641736, 54.37464491013558, 46.40167443983017, 43.760773981771166, 43.389023503949566, 42.83143897210398, 41.41658513776718, 45.010441118671054, 49.89477649811776, 54.366717800017334, 55.38710278849448, 54.183747076219134, 53.48610255026049, 56.60465748079362, 51.771383516250125, 51.36148014376241, 50.54770992648218, 51.11416685965754, 49.41781236279396, 49.35012009836013, 52.55103695777155, 52.14388316677463, 50.45118824128182, 51.31371351980394, 53.27957407120736, 48.461291405462454, 42.62291792900332, 32.37746346381403, 20.19932189295369, 10.063299594386931, 1.2968020141124725, 0.6819559645748908, 2.2088420679492335, 2.9659529126459554, 2.4604008274693645, 1.3627288442465568, 1.892157009532375, 1.5051302482043545, 2.0053203307813217, 1.6457383935489964, 0.2740003553129012, 0.26022587992971946, 2.594033282610678, 13.147830905452853, 28.61875418693789, 24.2763001303519, 23.158581526048724, 22.77991198724316, 29.993566505370605, 20.794276806616015, 5.757433897064579, 1.2800180695710646, 0.014034629266168323, 0.05168998621464257, 0.017693218129176288, 0.03433572368756418, 0.08033183418334493, 0.036560940976825454, 0.02380436087297576, 0.035830797897952224, 0.06497396997386409, 0.16114015973383383, 0.007987577438114152, 0.0057694704024001, 0.0646374658531239, 0.022747996488525983, 0.01906341043180756, 0.06939176920681231, 0.0546565889230659, 0.01947743115916608, 0.02472907113241813, 0.003748502208656001, 0.06632000943946262, 0.05241552127465125, 0.04532975955836235, 0.026171794724500468, 0.024310306405588508, 0.031945278470013896, 0.028752536182442022, 0.057460501369449406, 0.06206805675080227, 0.025795266340156237, 0.029747902731140776, 0.022280355352127267, 0.012531137664712245, 0.030691619631984544, 0.11048519277885077, 0.0746219050920298, 0.07275789059818753, 0.01894928439850769, 0.050705387031719576, 0.05481456774437139, 0.027185168169859438, 0.03174771971610044, 0.03942160904707928, 0.12614151718275202, 0.04459717648945028, 0.041963484949402274, 0.0229506861163123, 0.026490711381719, 0.03733263666471166, 0.02813927896861588, 0.0705074843379759, 0.027260382682265296, 0.013473783000071925, 0.0963701070436547, 0.019016238567869992, 0.06855136309299739, 0.0384566446976556, 0.022158790605082627, 0.03874474738333975, 0.06451065531901776, 0.0732268283383981, 0.055096530235342445, 0.08826030027722159, 0.06931918237598673, 0.07195356722560621, 0.03389636077167046, 3.114118729868243, 18.769292408420196, 41.92946641675888, 30.785757803147842, 29.056418134320168, 24.012006905771074, 35.55697202682495, 43.43175380460678, 20.851776792157082, 4.710983287903571, 0.8219988596054816, 0.10079538329474388, 0.16349730502453544, 2.4217936733076653, 8.294423414814858, 11.195897709938789, 6.527391729816315, 5.944379943032419, 4.7086102539493195, 4.286242079350257, 2.360454667960444, 0.6564096902166644, 2.1219522530032746, 17.590437781426218, 39.45408213523127, 57.68256010547761, 58.20896963919363, 58.68030909569033, 55.76382683169458, 60.739208267581084, 58.75489296451692, 59.38937164122059, 55.028088246622396, 53.6501556827176, 56.93508971122004, 57.54573606675672, 59.032181001478634, 60.47331079359978, 56.10924251617924, 53.63989476234683, 48.11514223775556, 45.81576647297029, 46.024950396630075, 47.33038187026978, 47.20364616763207, 46.837308560648275, 45.96654630476429, 46.470472812652595, 50.66253339090655, 54.280837505094475, 57.80603631850212, 55.81189155578614, 57.480275630950935, 48.616393689186346, 45.82006539067915, 54.850036175020286, 55.2899339122157, 56.869664576745805, 54.65802046560473, 54.47699915978217, 50.32776301906955, 44.73629882258754, 43.26816351183, 44.11264588755947, 42.57502186682917, 45.11557632876981, 53.08219255939607, 56.06325664827901, 57.03413740281136, 54.993822420797045, 55.05483488882742, 56.63302406187981, 53.40078315427227, 53.675321609743186, 52.451193025035245, 52.7170120516131, 50.87505525158298, 50.098657377304576, 53.51288057142689, 52.434468038620494, 51.31864786148072, 53.19527056909377, 53.469142221635394, 51.22888834245744, 46.43788183889082, 35.30759165363927, 23.741894845039617, 13.127518911515514, 2.7280280666966594, 1.2965129844604002, 3.498977278509448, 3.8815025071943965, 2.905332681632811, 3.108629863108358, 4.927686395183687, 4.630114801468388, 2.8880737625783492, 1.4354691990921575, 0.09531345729145313, 0.20649273339058125, 2.382608459841821, 12.293521031256645, 29.141070727379095, 30.07252577812441, 25.256333735681352, 24.376514727069488, 32.61208984159654, 30.18144411425437, 10.266992199805475, 2.259457313245343, 0.05536884384890718, 0.04938091294118955, 0.056663233666650714, 0.06169735446512219, 0.029207063808796868, 0.024220775625097658, 0.06125637127326862, 0.07466128967221707, 0.06421027990478663, 0.06128560901889878, 0.05303609079771465, 0.02802322047852701, 0.11163427103911677, 0.03660160109340664, 0.01037434064557836, 0.02141991986953203, 0.03641629208540244, 0.021704268724387212, 0.09550425914987441, 0.08380264915045231, 0.06893199387817614, 0.02257325374821742, 0.05533811606226429, 0.03335936761070644, 0.04478414024737093, 0.013520755681149183, 0.01455047648520239, 0.06659788485135763, 0.034660181075695067, 0.10448231166529079, 0.12332546224276866, 0.09686663927089784, 0.16777688667418497, 0.12302517875908844, 0.332054007918604, 0.14803504601361292, 0.1810987573117018, 0.14557717548262689, 0.2264588999171411, 0.1307548756801313, 0.22759675498931642, 0.2291249165371541, 0.08443960529421607, 0.16183126297208572, 0.1854349988242311, 0.15824227894265808, 0.13067996760289516, 0.17281828147749748, 0.15230140498568936, 0.1269832792721929, 0.18336026418593623, 0.09729511990782716, 0.09340452706261028, 0.2290174190796191, 0.11968259924962638, 0.18218482484019574, 0.11623167192503331, 0.09521499201054535, 0.15300881057496996, 0.14050348241242672, 0.20361385157992765, 0.11041707990150298, 0.15972105846289666, 0.3282234150796168, 0.2564036680926239, 0.13589296610124652, 2.8060839685701557, 22.00408285663974, 50.361844493496804, 41.355086295835434, 36.86152881191623, 29.168648912060647, 37.27779819119362, 38.04056190675305, 25.774831848759806, 8.430549271645086, 1.402005865689247, 0.3285935887646291, 3.6346084264016922, 8.245520284098964, 19.736050751901445, 20.22779437803453, 17.1503419645371, 11.68644207139169, 8.274000613920151, 9.591321772144688, 2.682471698330295, 1.352457259931872, 1.7243257765808415, 16.64595457815355, 38.42618188550396, 57.83137482981528, 62.137003714038485, 63.81360515471428, 59.59485284743771, 64.72659564787342, 61.719181076172866, 59.83227783633817, 55.1004598986718, 52.84044904093589, 56.246698056497884, 58.46293918548092, 61.71095586592152, 61.87515020370484, 57.88382084138932, 58.284843967806914, 50.454957639017415, 48.67309547239735, 48.37330087538689, 48.72914221978957, 50.92990567607265, 48.353681179784964, 49.05110997538413, 48.763247228437855, 52.52328226643225, 56.82643613507671, 61.545184735328924, 58.902389772476695, 59.69778368549963, 49.7421766865638, 48.768864062524614, 54.07098285613522, 55.75351884288173, 57.45170116424561, 55.630583916941, 56.81523776823475, 51.77969894101543, 45.933990632334066, 46.27735099484844, 46.944848183662664, 44.832514562914454, 48.324082974464666, 53.76213542876705, 57.37128080860261, 57.85460310597574, 55.06607247937111, 56.45074759760211, 58.83245783467447, 56.01177946213753, 54.96868787273284, 54.27052951628163, 53.41925359541371, 53.91615906069356, 51.055033206939704, 55.867953992659054, 53.92208576202393, 53.8483295133037, 54.227763914292865, 55.19120393260833, 51.60118795210316, 44.483137284555745, 34.86601906438028, 22.956357848259714, 11.392501611863414, 2.12166739086951, 1.5592493958050206, 4.522003983297656, 6.689389050006867, 8.428094848509758, 4.758195386778924, 6.452120955913298, 6.685273503103565, 7.002924200027221, 5.522747703136937, 1.5487522752054277, 0.630347011310439, 3.6150478115004883, 16.590092182159424, 35.8858000078509, 32.345347096843106, 33.84386116458524, 32.76534272778419, 39.44219735360915, 32.09831818457573, 11.7087632994498, 2.2384640526387, 0.20411200791357026, 0.30969015472838957, 0.21640984882270137, 0.14954666006228617, 0.15564151769203527, 0.11583941958604321, 0.10215234717414265, 0.10781642590318957, 0.13702524405333305, 0.28232322645283514, 0.11091883684838973, 0.1636133979885809, 0.2156601551800005, 0.14424816615158512, 0.10861739381066254, 0.14876453025687128, 0.13735840036984415, 0.06196103426778029, 0.1340691252581535, 0.1597523148502073, 0.24160340097883057, 0.10552306509306354, 0.09739049785440007, 0.233381760697211, 0.12508884342687746, 0.10431486782768082, 0.09645009428382882, 0.16607240232969486, 0.11614731798369078], [0.06318147361819303, 0.018590446899554903, 0.024573507403293927, 0.014892236926713058, 0.05517159919104269, 0.06176490426784562, 0.019737571635614, 0.01763774953301876, 0.0306639964166548, 0.024694317553733146, 0.02099341765466717, 0.019387507758614038, 0.055129583098835526, 0.03279057414000554, 0.03895347952962883, 0.05322219270672049, 0.01819161961095468, 0.06486838007526052, 0.07560032194540386, 0.04964793288719751, 0.04629458218152004, 0.016187420603068128, 0.026999123717447924, 0.010123114559739348, 0.034638991083709464, 0.07174610295483182, 0.060821524445688536, 0.02221964479934785, 0.062276432666206555, 0.0845268780305501, 0.08903241731346616, 0.10912891071770461, 0.0436692601520448, 0.06510200624864909, 0.048259758585763556, 0.04512764641173905, 0.05811550654470921, 0.09371639379570562, 2.213789402477203, 16.22470182757224, 34.39454624729772, 25.190998815721084, 24.520708899344168, 13.827094224191482, 24.91181823515123, 30.962344869490597, 25.814889054144583, 8.052081244607127, 0.5633897009876467, 0.3985785092076948, 1.9887723413205918, 6.540825847656497, 8.532374981910952, 3.4538800726013803, 3.3572358133331424, 3.465613352675592, 2.725113500510493, 1.9590602646912298, 0.15465631329965207, 0.18264346635870396, 1.4119993294439008, 12.189038895791578, 30.67731995736399, 52.92128909018732, 58.29241414223948, 58.49639700305078, 56.606077378795995, 58.7618943952745, 57.280815262948316, 52.758742147876376, 50.88130750963765, 58.15918299459643, 57.18953778666835, 58.83387381030668, 57.31353567492578, 56.611141158688454, 55.48886868261523, 49.71137431360061, 47.04372721333658, 46.32026172453358, 45.652038897237475, 46.76071251592329, 44.578748979876124, 44.87995170777844, 45.03512851653561, 46.10730055839785, 50.1144370725078, 56.50068329226587, 55.10710831611387, 60.17960371509675, 48.59468729265275, 40.53913916310957, 53.26229210822813, 52.574347603705625, 59.047827336096, 52.65634082978772, 53.89290725031207, 48.32730324037614, 44.04817781140728, 43.19954164566533, 42.76419778023997, 42.848313008585286, 46.93999621175951, 51.317463305688676, 53.2502112080974, 54.590814575072265, 54.920136774739916, 51.58593385450302, 53.92246623193064, 53.70626518803259, 50.94607760829311, 49.280458804099794, 50.085007529104914, 48.62660754111506, 51.3398325827814, 50.91649901482367, 52.95574711215112, 47.711989264334406, 50.964732400832645, 43.60859778619582, 37.298680889991026, 23.886216494344897, 14.56816036855021, 5.355012935976829, 2.054164748518698, 0.18913186335515594, 0.6000875188939033, 4.473348942495162, 2.164820081764652, 1.5120359486149204, 1.6997457535997516, 3.1411004691354694, 3.990955021112196, 2.146107434265075, 1.7747450259424027, 0.4867900096841397, 1.6652797643215427, 12.024654323054898, 26.5477603866208, 24.605694893867742, 22.384335071809833, 23.088851590310377, 26.940513195530063, 23.16923664462182, 9.603757646776016, 2.4071080742343782, 0.09434925902995372, 0.05943278323919062, 0.004893090714880776, 0.016208620171152776, 0.0434370972065916, 0.07685237774445165, 0.040961614314226374, 0.026711641562982436, 0.018601731374679555, 0.05328776217215965, 0.04386871880401046, 0.013348038285790433, 0.0660451217704723, 0.06492937599579174, 0.037961027945481965, 0.013769178842795233, 0.0888038779638948, 0.07793565671290122, 0.03303959868067215, 0.02454707353946663, 0.037271483696155974, 0.09161499163676655, 0.014198747324577023, 0.07288524505471991, 0.039588168053136724, 0.022522766638787526, 0.07164152429228829, 0.06655362795197195, 0.029770130772263776, 0.07060759670792088, 0.06712509123908897, 0.038710001465534015, 0.0725519585032617, 0.03226221478994816, 0.08848986618461148, 0.024175348526407636, 0.032349387934852036, 0.05449159273637399, 0.02952844726913158, 0.010843015043064954, 0.05169780797234947, 0.026381191452063864, 0.018549827002589742, 0.04210503118473195, 0.06860013225025709, 0.04464510294999327, 0.021209600006019878, 0.02059080397650119, 0.044622365460400625, 0.041732789062324076, 0.031611562909318075, 0.05118114678489585, 0.04995297760732713, 0.018489930418229873, 0.06380057608288142, 0.024460430910450318, 0.06592633983781261, 0.02627182282477377, 0.04459632996229395, 0.05065408212343051, 0.06054094091298119, 0.07281792890881339, 0.018784136909450737, 0.03206485713411483, 0.11565398800397113, 0.04934753832076827, 0.047204334574240836, 0.1243864020873462, 4.778617697377359, 22.915686791942967, 41.31517225696195, 28.85183515087251, 20.65916488247533, 16.26990322143801, 30.857709761588808, 41.06863167978103, 26.911707308984575, 6.426881974743259, 0.9535262277049403, 0.1733296451669547, 0.3864237582010608, 3.5367590188980107, 5.9561872578436335, 3.3414703367217897, 5.430319991803938, 4.698182142549946, 4.4835907413113505, 3.8245827872906966, 1.3457762377877391, 0.3750728785751328, 3.33834616887954, 15.804155103621946, 35.10461291959209, 56.11623217982631, 61.76902655632266, 60.34737133210706, 58.04006453483336, 60.53193061582504, 59.53460131922076, 52.90683515610234, 54.623495763348, 58.88713567487655, 57.637915688176314, 58.978268023460146, 59.73142585446758, 57.695566684969016, 56.42671131318616, 52.039787384771536, 48.060762497686575, 48.85225757475823, 47.152098378827496, 46.7486394605329, 45.31885316295009, 47.47205395852366, 46.31568039617231, 47.01368578018681, 52.330317343434984, 57.81345744286814, 57.18159106469924, 61.32004853217833, 49.34973962845341, 44.60678608186784, 53.48739301004718, 53.080702058730594, 58.61629993684831, 55.26866289877123, 54.838826041067804, 48.601743636592744, 46.499282621568256, 44.44706716845113, 45.04836651586717, 43.37894693497689, 47.80285489174628, 51.73520749615085, 54.438367735955026, 54.488734891337735, 55.01447369975429, 52.20515058886621, 54.588092450172674, 54.96402025222779, 52.070829022315245, 50.8282692201676, 51.392804191958525, 51.6114253382529, 53.92716130902691, 53.835954435410045, 54.104071970908876, 51.088267449409734, 51.900405960698286, 45.89443352914626, 40.12183035573652, 27.262755517036688, 17.855458605674006, 7.811524243124071, 5.027660746728221, 0.8381014149035177, 1.703852965466438, 5.526775977303905, 5.327853464311169, 4.363743701288778, 4.6154549429493565, 3.649408509654384, 3.428990427524813, 1.641051896637486, 0.21009233539863942, 0.1718812333720346, 1.6169624150760713, 10.760300851637318, 27.747811502025975, 31.353593449438776, 22.369655601439938, 26.31655823799872, 29.11381809942184, 28.910009784083215, 13.346030231445068, 3.893598116213276, 0.12096781133403703, 0.0778573165617643, 0.020009747353352366, 0.04630303596176448, 0.029024131588577747, 0.06422956999872001, 0.08518833366613235, 0.06363313224527144, 0.0066392315690585926, 0.04909097930536636, 0.10087923927893562, 0.017389537045551885, 0.11415249397677761, 0.05229507693119588, 0.02722699274008553, 0.027684351061320597, 0.06437760116832872, 0.02650634149059413, 0.03372345472716036, 0.04513239615686959, 0.02572870862129475, 0.02604587668282611, 0.03286533283009645, 0.0322008166732567, 0.01794651361002076, 0.024939312471918045, 0.022246262524276975, 0.04804034334337039, 0.04016195641710393, 0.038325536410294236, 0.19866005126987735, 0.10323115218911441, 0.160615083070532, 0.17367729586699318, 0.21257438366451573, 0.25648280497520204, 0.12847594030561948, 0.11078739914322093, 0.17594859334489993, 0.0745262053885287, 0.09708158055981321, 0.1643478464815886, 0.24639843722745297, 0.20717821354346894, 0.1269840453601172, 0.14775479572915262, 0.10225727823713135, 0.16890513500378979, 0.10396386166253399, 0.15049069488961853, 0.097078608138667, 0.10300535543431198, 0.15455313657800998, 0.10209620059017213, 0.12881684177104505, 0.11926881217908476, 0.198040240173859, 0.09620304625000685, 0.18881562226001294, 0.13276332839121743, 0.14876791636549658, 0.27930254176739727, 0.1126597333519209, 0.14016605132529814, 0.21087932220149427, 0.13864187343466666, 0.11693378384675711, 0.28894734358595264, 4.738127070088541, 25.83912734062441, 48.15729594999745, 37.91098640811059, 33.494570178370324, 21.439879325128373, 35.219742328889915, 41.40906595414685, 31.843956401271207, 10.896071733966952, 1.5325186882288226, 0.559932254254818, 2.949323043707879, 10.921387691651622, 15.407613285126226, 5.765965542485637, 10.567679136030137, 8.434976646977088, 6.499255587977748, 6.1473174921927916, 1.0873158228012825, 0.7549243071867574, 1.8907448336962733, 14.084013392848355, 33.818522653272076, 56.96957518977504, 62.33619343849921, 62.9298637759301, 62.15343060032014, 63.8042228452621, 60.452922313444084, 55.337959412605535, 53.67125411187449, 59.56947511242282, 57.88182827734179, 60.89979402480587, 61.83495375417895, 60.77899286823889, 59.38343709514987, 54.887996873547955, 50.3184199333191, 50.804319227895434, 48.712111288501376, 49.61011048286192, 47.902130080807595, 49.42910094414988, 50.43676960852839, 48.95652986341908, 55.76737657670052, 59.858087032072014, 59.504344155711514, 61.25293677853, 51.98969871767106, 48.28271373625725, 60.19393997807657, 53.38596836213143, 60.92104934876966, 58.416231601468986, 58.7401330855585, 52.13619532123689, 47.45701951365317, 46.75874740846696, 46.98179298831571, 45.81475057909566, 50.12652973974905, 54.48441636177802, 55.72384611252816, 56.57938957214356, 55.620409288714015, 53.36492876852713, 54.985671735578975, 56.721191098613126, 55.04543688989455, 54.62038924617153, 53.997979702488074, 52.535355321822635, 55.72812149601599, 53.563043763560636, 54.20182135797317, 50.24858213240101, 51.92950994737687, 44.721299679048606, 40.68464732939198, 25.98831076775828, 16.561333364056004, 6.665796974012929, 3.2982458174228673, 0.7755572000338186, 2.586413343106547, 10.925010000505756, 8.13320762688114, 7.141774633238393, 6.980829979142835, 10.284984111785889, 11.411606496380223, 7.270959856048708, 3.8907266960990046, 0.9288198921468951, 2.458923564803216, 14.582783945145147, 33.38263750076294, 34.350246998571585, 30.56322409260658, 33.602164714567124, 36.71783670302361, 32.32680016948331, 14.458242808618854, 3.877310228924598, 0.24882836087096125, 0.1580406752445044, 0.12048565857713261, 0.16969029851738485, 0.08689221280116229, 0.11945126367913139, 0.12500411410245205, 0.17687487025414744, 0.13630026440706947, 0.30394875474514504, 0.20600487327864095, 0.12107012237632468, 0.19642882019041047, 0.20314682905952777, 0.15833302971816834, 0.12156801824007304, 0.29723209419077445, 0.16553983332649355, 0.17197540089968713, 0.07598568715395466, 0.1350175727519297, 0.12329586826625372, 0.13231740393225225, 0.15233312102575458, 0.13861164360517456, 0.09696459127289635, 0.23987070927696846, 0.16813441990844666, 0.1557865994231355, 0.20770327488501228], [0.04552631090665537, 0.060444233803859646, 0.03813581473584618, 0.048799421563143694, 0.05117161665111781, 0.008385477760325997, 0.03596521185470685, 0.03172752180797679, 0.054038325324654586, 0.024278919783330733, 0.020276706012326385, 0.060526201381318034, 0.019122144477742336, 0.048429596448136915, 0.022197211829705105, 0.05668721604912032, 0.08411759555700325, 0.0737310674101595, 0.021697408407025283, 0.03265691477985632, 0.13609400289433618, 0.017812869571630034, 0.10812006485197814, 0.03460835522761749, 0.050246806800245285, 0.04232784402706931, 0.016113069854796897, 0.12552998749719513, 0.010690406498108661, 0.06451969515652427, 0.09150216220727853, 0.0621739607454548, 0.06320031172025108, 0.053430993800922755, 0.055964166944425915, 0.031300749547118624, 0.014998521092498015, 0.02230107420003943, 0.021850915190072793, 3.2806338850528967, 18.340343967560802, 33.92349704619377, 31.417635948427264, 24.639429238534746, 13.89855980873108, 17.481674378918065, 29.21673324800307, 30.16675876032922, 10.11136333788595, 1.3824402252512595, 0.08920048934317405, 4.943591115936156, 7.437556155266301, 2.192255835379324, 4.271559176906463, 2.6968766027881257, 3.1565408793187912, 3.4679148033741987, 1.9641668229333817, 0.34521346791617336, 0.14689892230014648, 1.000335609480258, 9.724820621552007, 27.645945587465842, 49.55637793387137, 56.9838055487602, 56.29692008418422, 55.06778263276624, 54.54463651103359, 56.16287308354532, 52.293823611351755, 57.686172608406316, 58.80384414426742, 56.75871249168151, 63.03000973116968, 59.494157760374016, 55.61014836834323, 53.2069553098371, 49.453498086621686, 48.50280184899607, 49.18171705738191, 48.44379371212375, 48.88902979512369, 48.291515534923924, 48.554035848186864, 45.73621296113538, 48.153769739212535, 55.097686782959975, 57.10543040306338, 59.39005413363057, 52.19702343786917, 39.715731682315955, 54.15549424386794, 57.71834388855965, 60.00388937611734, 55.409323015520656, 52.98914217179822, 48.80630700818954, 44.703154794631466, 45.61478814771099, 45.64146418725291, 47.91476011276246, 51.647483687247004, 52.2965810375829, 54.97840358364967, 56.68960425161547, 56.819528841203265, 53.46659660339356, 54.38756519748319, 54.330063250757036, 52.99978748444588, 50.811822722035075, 52.017096473324685, 52.21481923134097, 52.98417252878989, 52.63173187932661, 51.02615671773111, 47.19356175391905, 38.43175949588899, 27.62123073301008, 18.387075085793775, 9.175568184544964, 2.925841529523173, 0.3589167890529479, 1.688571166126959, 1.1494190774617659, 1.6638720011518848, 2.626119741509038, 3.6362832784652714, 1.7007591959930237, 2.9319739101394533, 3.559503127490321, 1.803445008493239, 0.8521484643701585, 0.08006432394106543, 1.4154060305126253, 9.659446477890015, 25.806287296356697, 28.21780754673866, 18.65176643094709, 23.31594897854713, 27.073120686315722, 22.543230287490353, 6.546533876849759, 1.2863627484729214, 0.03761886243498133, 0.037937099189167066, 0.045173159695320556, 0.03060674858129313, 0.05057392634391304, 0.0414350719731902, 0.0328974855402785, 0.042724585641295686, 0.0224740281250448, 0.014591356852061808, 0.04599410334541913, 0.12820250820368528, 0.05308794345886958, 0.017849885024911454, 0.016228059652231393, 0.04068875294779578, 0.03014030254205629, 0.09230552796995448, 0.007540267317615931, 0.02024020192273442, 0.03736463998774848, 0.03210872524387894, 0.0473396142103499, 0.07537990312782988, 0.07580400174183231, 0.016393251191343994, 0.05608642308582222, 0.037275716331937624, 0.0077556658652611086, 0.04353950400986979, 0.030255828601037784, 0.06316764190072013, 0.06171907305777554, 0.031167166795761838, 0.0791989510217982, 0.03028287916564413, 0.01902772605629458, 0.01820757530719763, 0.07136054622429995, 0.023145419921004967, 0.021791924504683386, 0.05641404058664076, 0.016968594713797493, 0.022157614660118858, 0.047719800664532575, 0.037312139982297536, 0.03213282636997681, 0.18508380879798245, 0.06854803061052676, 0.03561952233975453, 0.08598012384027244, 0.06195280648347351, 0.024329856969416145, 0.03744097298852379, 0.030734781025638504, 0.04694065477158274, 0.015000835635639248, 0.030505910343039903, 0.04027035019751038, 0.03973804549464295, 0.11230575476562786, 0.02166699854687097, 0.05605984366528931, 0.023309609800156568, 0.10317833042673527, 0.07777018172125663, 0.0521758851414967, 0.017742377991277366, 0.030996273647272782, 0.09473391943761418, 5.143656999834123, 25.5910688061868, 38.267749509503766, 34.07879544842628, 20.50149540747366, 13.260607873239826, 27.48112955401021, 42.70340104256907, 30.703984229795395, 8.301730790445882, 1.48737772337852, 0.18021838439087715, 0.6180385524226774, 2.3275641231767596, 2.3692498476274553, 3.633440785831021, 3.516882408049799, 5.4944791813050555, 5.723394588116677, 2.601325459057285, 0.8170229653196951, 0.42505125965802903, 2.008993875595831, 13.694473985702762, 31.929489566433816, 51.34047585148966, 58.88063238513086, 59.082136307993245, 58.07653081032538, 56.647379936710486, 55.691918019325506, 54.241296091387355, 60.29269349190497, 59.09402893435571, 57.086485355131096, 64.2083328770053, 61.19237538306945, 58.085328686621885, 55.056862754206506, 49.769178282830026, 50.52287740092124, 51.36559863244334, 48.495180683751265, 49.43465109794371, 49.094707119849424, 49.546379812302135, 47.09791083489695, 50.91351801349271, 57.073721962590376, 57.697637696419996, 60.256172303230535, 52.179149196993926, 44.744339681440785, 57.94347616934008, 57.62734097819175, 61.50092078793434, 57.2758299304593, 55.81053441570651, 49.85630981383785, 47.02355054117019, 47.21100845644551, 46.49858443967758, 48.13265169820478, 54.36175207937918, 54.18698303161129, 55.892198162694136, 56.91108088339529, 55.51177532442155, 53.378810036566954, 55.555533286063906, 55.226583711562625, 52.02596887465447, 52.20453085437898, 53.430044035757746, 54.48223944633238, 54.65872649223574, 53.29356516561201, 51.775717735290534, 48.455909913586034, 41.74791951333323, 30.688665413087417, 22.80583885408217, 12.612656835586796, 4.124850765351327, 1.258215452394178, 2.8621922481444577, 1.9040724346714637, 2.314506798021255, 3.6594774790348548, 4.573425275664176, 5.251655540158672, 6.172318679671134, 4.451183628651404, 2.166336322984388, 0.3638886996815282, 0.1026768339497428, 0.876152940815495, 9.83460384030496, 27.181619328837243, 32.47610519009252, 23.330538234403058, 24.951873479350922, 30.60401478121358, 27.85828505792926, 11.593755483627321, 2.6709968043911845, 0.06596824484727075, 0.06689333432023564, 0.06444355367773003, 0.003292344969644722, 0.07895086110839922, 0.02596122588241293, 0.058653813546463374, 0.01760084707770617, 0.08885240197301873, 0.013789165119129806, 0.026569562896545378, 0.058333205750151995, 0.04095044858272999, 0.05329901983420696, 0.05325336099391984, 0.05769114363037291, 0.06271510610296842, 0.06686192471534014, 0.025389595971172376, 0.012982680420992116, 0.023143267213937738, 0.033340843604697336, 0.03914653368654751, 0.0637378411427621, 0.035643359165518515, 0.02865322245915811, 0.06020386222629778, 0.004298381447311371, 0.06590911052039554, 0.08657790990846773, 0.07428147860111729, 0.1734135317946634, 0.1697400635889461, 0.11891933818978649, 0.1424906532009763, 0.15558191605152624, 0.09753160358917329, 0.1434019760739419, 0.0981416317423986, 0.2347128691091653, 0.08523438321126085, 0.11869942499024254, 0.1372580428517634, 0.16829171308105992, 0.10916743727941668, 0.14563804882909023, 0.1757485831096288, 0.25258666565341337, 0.19001159276212418, 0.12732721444579864, 0.13716632680546853, 0.19046430476009849, 0.19366002521447598, 0.22290008443017162, 0.11271823182581894, 0.11750447338507061, 0.12051546705826638, 0.13390777181954155, 0.20449854523664523, 0.0960626682987617, 0.16688701426309926, 0.1622592916171397, 0.15532841755738183, 0.13164692378092197, 0.2078234587585734, 0.15640057292917084, 0.1339308004225454, 0.10828501890383421, 0.12183922102614758, 0.17243490043667056, 5.890284084504651, 30.300225250182617, 46.83680649726622, 42.63101370103898, 32.571289347064116, 21.070497958890854, 27.491753293621926, 39.27036223873016, 37.145076951672955, 12.56724069195409, 2.21106703242948, 0.44551595024043517, 7.024457521976964, 12.591279918147672, 9.71769073317128, 10.464427644206632, 9.077089236628625, 11.227753239293254, 9.712142540562539, 3.9032723970951575, 1.2351683407060563, 0.9461841023256703, 1.4346064002283159, 11.456304846271394, 30.61026311689808, 53.10598957923151, 60.438393854325824, 59.59840651481383, 60.85819336675829, 61.423269625633, 57.659555404416984, 55.876689111032796, 57.00722209868893, 59.60901652612994, 56.76111690459713, 67.00388062384822, 65.18751728919246, 61.5315152752784, 58.37332871652419, 53.19034014978717, 53.28339838212537, 54.42533369987242, 51.602592160624845, 51.9672784497661, 52.24514307514314, 52.0124759212617, 49.35124189622941, 51.603482538653964, 58.54769376016433, 61.83049009692285, 63.32847072232155, 56.298214466341086, 47.55357650018508, 57.472536794600956, 59.02306541319817, 63.61400358138546, 61.4823091414667, 58.184490126948205, 52.58459283459572, 48.94295846262286, 51.07671999162244, 49.08546209335328, 50.99323234250469, 56.33966607432212, 57.03317249974897, 57.91003011888074, 58.4305247183769, 55.771663727298865, 54.12267969500635, 55.54600192654518, 57.42927697397048, 54.304281511614406, 54.5373369801429, 54.86412925104941, 55.13024637776037, 55.33781428490916, 55.56580205117503, 52.10285125240203, 49.212142882808564, 39.851473146869296, 30.389555269672027, 20.20449353802589, 11.052859656272396, 3.472777806943463, 1.1935566509923627, 2.868561196711756, 3.7180901919641807, 4.047176559125224, 7.583445772047966, 10.407185554504395, 7.226612558287959, 7.79323079893666, 8.928156841185785, 5.882575156227236, 3.024991447887113, 0.5208580928944773, 2.3657670280625744, 12.217468234800524, 32.1725647295675, 38.42288317218904, 27.640940643125965, 33.1440201113301, 38.27462150204567, 31.38866924470471, 10.36250191350137, 2.14879842535142, 0.2717898852161823, 0.19311640922340656, 0.16883526778509542, 0.18429781790942917, 0.17732493158790374, 0.13358123450269624, 0.18853016257766755, 0.1255355646172839, 0.10179630015045406, 0.12897666303380845, 0.18476857893889953, 0.2732927045754848, 0.10057511003387552, 0.1622166051979988, 0.18399714372090756, 0.1501115732976506, 0.19776124627359454, 0.15512790170408067, 0.109934750944376, 0.1032380776239499, 0.1133433748937903, 0.17074029862640366, 0.1328174295204301, 0.11814339071392052, 0.2563403739083198, 0.15080972454480587, 0.14709706328088237, 0.07272520162645849, 0.0887542661099184, 0.15774940861569298, 0.14994329442420315], [0.08078423974614951, 0.0513832331184418, 0.06380949334632005, 0.0791747349825117, 0.03383006352270323, 0.046952743639027884, 0.012785200191090905, 0.0362415359385552, 0.013319979357953756, 0.05234779144126562, 0.027790440832294767, 0.04030100903624008, 0.04827973815882879, 0.03947166523205177, 0.02557261437628298, 0.05607665546478764, 0.06316181580205599, 0.03400384290744701, 0.052555179103247585, 0.029492994635215694, 0.061739868514480135, 0.040812502960644426, 0.03707737616834141, 0.028788576788839795, 0.031523481950223926, 0.04972808866671497, 0.07261156014377072, 0.048905038274824626, 0.014199796865033287, 0.08151898701344767, 0.06381724615611377, 0.05679302045234269, 0.038589396243614536, 0.026568373545042934, 0.02850454394525338, 0.0725369968061005, 0.09476312270928776, 0.0141847116361943, 0.11015331582917322, 0.2426601886268585, 3.349536200684886, 16.65736475298482, 33.628546576346125, 35.36106924856863, 23.174086655339888, 18.206400909731467, 13.787969562315173, 31.009619235992435, 29.04915782713121, 9.87128878793409, 1.5183166438533415, 0.29222920296653626, 1.9375358906484421, 1.6615125729191689, 3.4495071201555194, 1.6547522453531143, 5.277713806398454, 2.8405481192373463, 2.4431823578573044, 0.5124903290021805, 0.8996603181285243, 0.3805652386959522, 0.7385447957823355, 7.774865771493605, 22.174109758869296, 38.870931594602524, 51.28131081981044, 53.62242452559933, 52.78554370326381, 53.548048542391875, 53.56291040297478, 56.55014438013877, 59.603999814679554, 57.0583462715149, 58.58051223139609, 59.699164359800285, 55.327102291968565, 56.06018151006391, 55.22506183193576, 56.478157120366255, 56.40799376272387, 57.62492872053578, 56.94095365462765, 55.89361413832634, 53.13742737616263, 52.15195932695943, 48.727196724184104, 54.25738957620437, 57.38122793935961, 61.9905855578761, 56.03806326466223, 46.2891024158847, 56.37719531213084, 56.56778720117385, 60.771367780623905, 55.09912237044304, 56.65385969223515, 50.68141175854591, 46.89084106876005, 48.03015232086182, 49.15693160026304, 52.53073476975965, 53.307442511281664, 55.15411007788874, 56.38271408696329, 55.63838551121374, 53.42070487237746, 54.364183948886016, 52.40735661598944, 56.09341575253395, 56.43435993502217, 52.542756834337794, 54.49703854899253, 54.24619513173258, 53.01828145980836, 45.8114008749685, 36.58160494219872, 25.28420021457057, 16.14814598714152, 9.096861904667271, 3.911609885192687, 0.9869947092187021, 0.4299723020484371, 0.4535800675230642, 2.932585309590063, 1.7989313410174463, 1.6245436211747508, 3.7170627761271695, 3.766051953838718, 5.772317330683432, 6.558268627812786, 2.005729850742125, 1.1612021226075389, 0.29851578176021576, 1.0941281217721202, 10.621287149767722, 24.39802892746464, 30.721723148899695, 25.942842652720792, 26.154742817724905, 30.48708696519175, 17.7499193914475, 5.335161820534737, 0.14326112314818368, 0.08867309143346164, 0.02354759692905411, 0.08174333586207322, 0.060537665887104894, 0.015462687062550218, 0.05535099400027145, 0.05968778709610624, 0.060263168922955954, 0.057450477108960195, 0.05326234720527165, 0.09106581384736685, 0.05204655800855929, 0.060040961290078784, 0.08545364523606916, 0.04536362830549479, 0.04691402555533475, 0.02795269633943756, 0.06499245567547698, 0.08614225868856715, 0.037342894582017776, 0.028583860858493758, 0.026665909944342512, 0.05066063983606235, 0.07016991535502096, 0.027247129361175244, 0.013591060527570307, 0.03898866594799104, 0.02084676352810235, 0.02071199334046293, 0.026160945004272847, 0.03036678303033114, 0.05581753388527901, 0.06480677128438989, 0.039577550074506196, 0.032433990854769945, 0.08877517264937201, 0.02615568772589247, 0.10590754930050143, 0.003734971420095873, 0.04114601167760069, 0.03723165861541226, 0.07895122116972363, 0.09087588532917923, 0.01638821799368147, 0.0869344165849109, 0.020036322943445657, 0.025269569145635735, 0.06461861242930736, 0.0600058859544656, 0.0776574059179233, 0.09011217993834326, 0.035559962834081346, 0.05732427561475385, 0.07438290864229202, 0.024445907798625773, 0.044188939725920084, 0.048065624244871645, 0.07126235673504491, 0.059618176516866496, 0.03879244018706583, 0.007961111494355024, 0.04217242393943091, 0.07972042707185592, 0.003119520321976574, 0.058505950916198, 0.024397326332907525, 0.09698611834356863, 0.11613542829910595, 0.07125271934895747, 0.04066175600934414, 0.0524012299044238, 0.40804226912798425, 6.675018466288044, 23.927668102325935, 38.32001509204988, 35.498289446676935, 16.809939069132653, 14.853621644358482, 21.172293270787886, 36.77586816972302, 29.47919668689851, 9.474162536282694, 1.3148519036269959, 0.20248716606968836, 0.44131355961003615, 0.9286852445333236, 3.0918681044732375, 3.484862139148097, 5.205250468946272, 6.286183124588383, 4.697337362074084, 2.6283282810641877, 1.5133849988060615, 0.535944264021612, 1.6513483634879513, 11.038744026614774, 27.07032599756795, 43.8527927860137, 55.030704467527336, 56.60950160795643, 56.53751434818391, 57.140296351525095, 56.7451960040677, 59.03804102251607, 60.20083158246933, 57.411673376637125, 58.668275264001664, 61.656591815333215, 57.31865044563048, 57.47021475145894, 57.01250945368121, 58.13227945758451, 57.45085000991822, 58.36533492611301, 58.76039604986868, 57.385981852008456, 53.7241864973499, 51.71767842385077, 50.26278111242479, 56.16132374732725, 58.70230182524651, 63.43845398195329, 57.18226963473905, 46.26189685636952, 57.2408345437819, 57.60369300842286, 62.1817030445222, 58.74114505706295, 57.414097401403616, 51.983611199163626, 48.07186280527423, 49.52625805331815, 51.407905317121944, 53.63824344450428, 55.148799188675426, 56.58456710077102, 57.25346849810693, 56.63806038518106, 53.64597443611392, 55.17918579040035, 53.68973239775627, 56.16035884426486, 58.041205944553504, 52.74898329088765, 56.783733291010705, 55.187736557376006, 55.18621075537897, 47.957270760690015, 40.52633262449696, 29.431996845429946, 20.729571427068404, 12.777562102963849, 7.01338908364696, 2.86767719253417, 1.6732240348092973, 1.3424381781970303, 5.794558150153007, 2.401125969425325, 3.287856684577081, 4.431051083149449, 4.3237389576050544, 4.3234825326550395, 3.9160769745226833, 1.9250718239815006, 0.18160368586259504, 0.14378862064932624, 0.9443610582140185, 9.846045394097606, 25.69036360709898, 34.58100788054928, 29.05821457985909, 26.45287629096739, 32.484391197081536, 25.341327574945268, 9.7653926380219, 0.9170568878612212, 0.14145761427860107, 0.04896331841366426, 0.021946499980385267, 0.04416673849787443, 0.02626615951979353, 0.06819410565038843, 0.024930881674311338, 0.0442045679195754, 0.03899660261888658, 0.06661460088986544, 0.07391012514070158, 0.010921832083934739, 0.029860998376182495, 0.023514185919456428, 0.05336434032107073, 0.027585140759906465, 0.0740787564145942, 0.041008889600033724, 0.04496687136950993, 0.0507647396936532, 0.05268845158899504, 0.08605477910849356, 0.05695686750714818, 0.015643187911219655, 0.008955904913525428, 0.05175980746806149, 0.06081660999165428, 0.028707639599639564, 0.00216622349163968, 0.044664155556670124, 0.08446826464346341, 0.05416649183438671, 0.20537038393799337, 0.18106017712383501, 0.1807568829146124, 0.22869189299883383, 0.1028359427507366, 0.16019595636715814, 0.07224721638786216, 0.10060310288662873, 0.17313685147993027, 0.13683059643353188, 0.18706872728803467, 0.13083562134735047, 0.1944291621686951, 0.07474619519686507, 0.07964468395878231, 0.1944451427627956, 0.18934221577740487, 0.24444443804602473, 0.11150241198558962, 0.12278476504669075, 0.20966707999187134, 0.18336049401231352, 0.1673659724333594, 0.14048532612862127, 0.1553302561684001, 0.28102427841194216, 0.1972042237438502, 0.15991546093456208, 0.1289072861113856, 0.20379359112872233, 0.11850941220238326, 0.14657912655703484, 0.2307915408164263, 0.13591155139428956, 0.15297079729216714, 0.30273395380185497, 0.12795206640035878, 0.1667888017912065, 0.23956942221810743, 0.4264373272176712, 6.4243167446505645, 26.636653061836, 46.94041590536795, 45.461117529099994, 32.24498933361423, 27.807015757406912, 21.842534157537646, 40.63062452500866, 36.94282777847783, 13.341459689601777, 2.7617621662155276, 0.5109649253708701, 3.5236776692252008, 6.4290142732281845, 10.70323330740775, 7.337785276674456, 11.137612269770715, 9.464551748767976, 6.725182639014337, 3.0042918747471226, 1.9866100121890347, 1.2080979803877494, 0.9875227583031502, 9.930977456031307, 24.313076273087535, 41.385445440969164, 55.60375098259219, 56.33908556353662, 58.64656886746807, 59.6870913044099, 56.69757450780561, 58.509991938068026, 58.64150116520544, 56.186434761170425, 59.03268698723086, 64.75704108515095, 58.4756084411375, 60.98363468723913, 59.124603809848914, 60.861080231205115, 59.76023566338324, 61.65344215208485, 61.96944398264732, 59.24956660116873, 57.28264700981879, 54.37140111000308, 51.52494099832351, 58.49764823913575, 61.69072035820254, 66.48786144871866, 59.9730791584138, 51.03799835328133, 55.02115741852791, 57.51813434785413, 64.039517987159, 61.17526992674797, 61.3000758232609, 54.611301114482266, 49.86538617841659, 51.98385046374414, 53.73592615127564, 56.46684108241912, 58.16894969632549, 58.37104981945407, 59.08216768695463, 58.291049157419515, 53.25052107534101, 54.65511398930704, 54.95879565515826, 57.99821676746492, 59.649087459810325, 54.47760320478871, 58.42907736378332, 56.855724473153394, 54.91824619231686, 46.52284037682318, 37.897226733546105, 27.674882873412106, 18.39425302320911, 10.477572487246606, 4.942143271046301, 1.6076489922500428, 1.3140229352058903, 1.174625821651951, 6.853970231548433, 5.411940745769009, 4.416491245069812, 8.179708305866487, 8.219224224167487, 14.167952114535918, 14.169578917564886, 6.311334833022087, 3.9536312174412513, 0.6108349357401172, 1.8069642325562818, 12.697862482840016, 31.17108948769108, 39.82641704620854, 34.924525137870546, 35.76909380574381, 40.86834761404222, 27.74701918325117, 9.168450063274754, 0.8563083217990014, 0.1823058360887151, 0.09376998164600904, 0.18711319103115992, 0.16527691195088048, 0.08935786678545898, 0.19731138412269855, 0.18438676071743812, 0.15529846351954246, 0.18091661224682487, 0.2281393291008088, 0.11115859938605178, 0.21550103871812745, 0.1738738127413296, 0.16343883719415436, 0.1202694379213837, 0.14430652672965683, 0.13663374248050875, 0.17614178539764497, 0.1652420702720842, 0.14735860569823175, 0.30122669113259165, 0.18426236336029347, 0.1685026630518898, 0.11188930170910974, 0.07636650946111449, 0.1403891514506071, 0.150538100410373, 0.11630019082898095, 0.11879113337565815, 0.19957146607339385, 0.1691510645492423, 0.2176669224976532], [0.0686290214258817, 0.020691423879695997, 0.10958973558679705, 0.014289531616433976, 0.006887620735553004, 0.05406148799304521, 0.05473242779713004, 0.05131517386724872, 0.03888819351672165, 0.08850539478683665, 0.025124483584095875, 0.02199072623625398, 0.03825634717941284, 0.054074791109850334, 0.014254149845651081, 0.09203273172099745, 0.0358602348264427, 0.05172091318414577, 0.07864384371186457, 0.006171092475509091, 0.024329293894791798, 0.04226194131338308, 0.04021611117247132, 0.0989678958731313, 0.049403160134510654, 0.01918678506157331, 0.007258307699474597, 0.08328124204830778, 0.033779877102783615, 0.017415155025739825, 0.1079021051766411, 0.02900297032488931, 0.013244869225027581, 0.05428686339948928, 0.09827758936632065, 0.03804348198877227, 0.022242489541249893, 0.051995601670275775, 0.028248676324203133, 0.03214991396112788, 0.054490217608549905, 1.9427137869981028, 16.50339211187055, 36.82703156625071, 37.49285782537153, 20.960024402987575, 21.64859256436748, 21.20599231412334, 30.834485407798525, 14.785326315510659, 13.424148155796914, 3.6350749433040623, 0.5604640418483365, 0.06629995325760496, 1.6432232962500666, 1.9625910107166538, 3.3308287012961606, 4.789301743430476, 2.2062964497074007, 2.448095371646266, 0.5141084905593626, 0.3388795448887733, 0.27919957955037394, 0.5108619018668129, 5.752553978273946, 13.492286589837844, 24.595722267704627, 35.61637632308468, 45.72430464529222, 52.92634110296927, 50.72267901512885, 57.69372317098803, 64.66486930847168, 54.374401723184896, 60.2012316642269, 59.53214983786307, 61.35163145680582, 57.37939227011896, 59.128741910380704, 58.45562396510955, 61.01962243357013, 61.37720138795915, 60.86601065051172, 60.60165466800813, 58.99153740175309, 54.73250627517701, 56.24168918978784, 56.2716600202745, 58.3835425684529, 55.76211667829945, 59.117343502659956, 45.96485576322002, 60.74782179247949, 60.330673802283506, 59.2194780995769, 56.45768627043694, 55.63026228258687, 53.03489269748811, 50.54936516669489, 50.896487082204516, 52.689692743362926, 54.280429578596554, 54.017250307144664, 55.1248295845524, 57.59525991255238, 57.16296372875091, 57.0291167689908, 52.76367256718298, 54.30713699709985, 55.20180217681393, 57.26201534271241, 53.655929411611254, 54.70801499582107, 49.49108223761282, 39.53263152030207, 24.827248011865926, 15.809196329885914, 8.471254648700837, 4.816134187483019, 2.3956366123691684, 1.5443008753561205, 1.906118563586666, 1.0733561073580096, 1.3690532984272128, 5.373156349505148, 1.485213187913741, 3.4588923713853283, 2.6118499136740163, 1.921483222996035, 2.924083572241568, 3.614789180217251, 2.3420283534834465, 0.41163607951133485, 1.3719508268179432, 8.533546789999932, 20.097048051895637, 26.683325344516387, 27.570049685816613, 27.40123087360013, 27.70510277440471, 20.11236098504836, 4.4091010093688965, 0.16585325521807517, 0.063211967748019, 0.038380304036001046, 0.05154485085738763, 0.018787873503301415, 0.013935940862152607, 0.07080071981275274, 0.03822126418292042, 0.06504346947035482, 0.054048747950864416, 0.06068970752699722, 0.06969717781870596, 0.06493443983697123, 0.0677910897760622, 0.03470241167252103, 0.03470406642243747, 0.03153469556221559, 0.05715913770179595, 0.02858758213058595, 0.07684303147177543, 0.043975875352419196, 0.027431480759274096, 0.04355839956852217, 0.04122905560859269, 0.0172684645099986, 0.04193842621339906, 0.028896215972640825, 0.026644530345595656, 0.08493843578523205, 0.07291820981810171, 0.044532970660516334, 0.03672786770508655, 0.03724550948508325, 0.06929158022807491, 0.010186758271658854, 0.031571383512909376, 0.07722573069434974, 0.012027676172193982, 0.010198262997061737, 0.06452608432981276, 0.03333898967192058, 0.03427086668389459, 0.035578318300747105, 0.058052618387005026, 0.056457780376677556, 0.0550234645995642, 0.043311378347777554, 0.05557848763982615, 0.03606149761547004, 0.060978545657088684, 0.101622007486801, 0.02631543812552287, 0.051038049221519506, 0.06109628954061097, 0.0393493248209838, 0.03745776180538439, 0.06277774528209722, 0.08376639786987536, 0.059410156832346996, 0.03864225247995027, 0.04515581163427523, 0.08579885211562918, 0.06491685045822974, 0.051970761269330985, 0.07518155530335442, 0.032631469169451345, 0.07132298493337247, 0.08093819277541292, 0.07516618757959335, 0.02949299271999588, 0.04953125769632959, 0.07482156292685578, 0.028172649758597536, 0.07428474979655397, 0.18591363523756305, 3.9026835512730385, 24.579542490743822, 42.98585484104772, 38.106653844156575, 18.689587885333648, 11.702609100649434, 28.601121171828243, 39.696159055156095, 21.479014773522657, 16.403562888022392, 2.4508341666190856, 0.27064534985730726, 0.192255127213655, 1.0560852986189628, 1.8252329167819794, 3.868281423084198, 6.205230307194495, 8.612755133259682, 3.6697643851080253, 3.383514222598845, 2.2179211291574665, 0.7389748468995095, 0.9609156053873801, 8.05457587203672, 17.9257631686426, 29.48815145800191, 39.852065424765314, 49.746306942355254, 56.14366915918166, 53.798103563247196, 62.406905927965724, 63.069413861920765, 55.534266194989605, 61.28004427879088, 61.98293693604008, 62.81891953560614, 60.23527391495244, 61.55442976182508, 61.06759302077755, 62.43694736111549, 63.2344279750701, 62.758636628427816, 63.89224083192887, 60.044070136162546, 56.79240172909152, 57.30139593924246, 56.847361979946015, 59.20873472767492, 57.180583015564956, 59.55967310936221, 49.17103252103252, 59.18038775843959, 59.26796251727689, 59.70895851812055, 58.375642914925855, 57.237990825406975, 55.26631339903801, 51.31500790196081, 52.10858967996413, 54.34403081094065, 57.314528034579375, 55.458956687681145, 56.64530108051916, 57.19671572408369, 57.7545944336922, 57.8212708042514, 55.51615661190402, 54.038234987566554, 57.75571623156148, 57.00282512172576, 55.42533020819388, 56.59052125869259, 52.64902560941635, 41.971671119813, 30.123897060271236, 18.34763369252605, 11.780485799235683, 6.571233532121105, 3.9221115410327916, 1.8963925564481368, 2.529263919399631, 2.2656735345240566, 3.2933617311139263, 6.012332554786436, 2.7743961205405574, 4.5867142658079825, 4.779507585110204, 2.844006914284922, 1.7215943360520949, 0.9242422410076665, 0.1508143823593855, 0.14003190932975662, 1.020499227508422, 7.961760826649205, 22.762800647366433, 29.647535008768884, 31.409136172263857, 30.904250644868423, 31.48917801918522, 27.46200603823508, 8.108205949106525, 0.8094035161118355, 0.03569151545243879, 0.07010931780021037, 0.05586832934509843, 0.034787160149144555, 0.03430817899624667, 0.07895154292665182, 0.040986140619122216, 0.02090920735481045, 0.08995152363974242, 0.016994838970863534, 0.04098004638968457, 0.03184653165179395, 0.04832773356728497, 0.04519163007517496, 0.06391509856668211, 0.06213282948480018, 0.07805639983064706, 0.040530980970229835, 0.00425067954629119, 0.05132882172361978, 0.0359335073059605, 0.023033408290376107, 0.05029278356702097, 0.03929679800245551, 0.024433884048654188, 0.01987009335519566, 0.03697719868092287, 0.014488642656003997, 0.06471055064110026, 0.03945195762019965, 0.053111707506280754, 0.07961454605984111, 0.012497367551400056, 0.15754080287391142, 0.07397822269629087, 0.22707575391377174, 0.12489649407084912, 0.07417418032644257, 0.12802710471254203, 0.11488672030428726, 0.1606393220924562, 0.09848537539402324, 0.16189242743196028, 0.13093905853888682, 0.14164620980380044, 0.09837810010198625, 0.1370329662196098, 0.10923329019738783, 0.15816858128434227, 0.21517871488486567, 0.12416815129859794, 0.21031709027386483, 0.15474619073492868, 0.12080320202174688, 0.1910444325016391, 0.12288160622119905, 0.24773585820390334, 0.1998402250389899, 0.10252566948052376, 0.19831370291931016, 0.2215961414960123, 0.14747157302354613, 0.12832726562215438, 0.21111314755774316, 0.11307086209736525, 0.1481540960770461, 0.12773724768551128, 0.1428206379134809, 0.21559422565323694, 0.10372874927857231, 0.2304494365929596, 0.1045128632517111, 0.12713903260807838, 0.25765206965227283, 3.902874766818939, 25.31105079958516, 52.10961341857911, 48.7585521513416, 30.543578901598533, 31.204733617844123, 32.36429606714557, 40.35563107459776, 23.276007483082434, 18.12020878637991, 4.530185066884564, 0.8187683587593417, 0.9460164822878377, 3.711547433368622, 10.025188865200167, 12.272245114849461, 12.370286718491586, 10.627343289313778, 6.26493662595749, 2.9894631091625463, 1.247722621886961, 0.7781513576065341, 1.2270719558000565, 7.419466184031579, 16.48129936187498, 27.129006616530884, 38.650678742316465, 49.04217089376142, 61.15861162062615, 56.503330892132176, 61.62156897206461, 62.57084923405802, 57.264447212219245, 62.63591743284657, 63.0082013530116, 66.06397874893682, 61.429141413780954, 64.13262721030944, 63.23787181608139, 66.00154246053388, 65.90862935589206, 64.63985243151265, 66.9716073620704, 62.71879319221743, 58.708514859599454, 60.386085125707815, 58.79914122243082, 62.580655159488806, 59.6095891921751, 62.09386940925353, 52.40765863849271, 61.48405459619338, 59.6122250249309, 59.68210989429105, 60.38927009028774, 60.362256726911, 56.31119358924128, 52.82891335025911, 55.300041860149754, 56.33606141613376, 59.994793399687744, 56.323819698825965, 58.1979085553077, 59.4553380627786, 58.19138173134097, 59.02552081692604, 54.39826150094309, 55.59093267686906, 57.24225051941411, 59.501488670226074, 56.9591534522272, 57.42059676877914, 51.74828860067552, 41.639085508161976, 28.4350597858429, 18.755746503030103, 10.66795943244811, 6.399567079159522, 3.5757319340782785, 2.5144692294059263, 3.829127343431596, 2.7826468261980244, 4.243575517208346, 10.934970859558353, 3.2210849513930664, 9.6082369935128, 9.710087218592244, 8.134137228611978, 9.545177048252476, 8.933164727303291, 4.650026713648151, 0.678658354426584, 2.092971330688846, 11.092202990285813, 27.284418767498387, 34.2273905200343, 37.35800281647713, 38.721705021396765, 38.04521776014759, 29.07390994410361, 7.721887788464946, 0.7156384604111795, 0.191100969790451, 0.17693143818647633, 0.13746499384362854, 0.13971398284118022, 0.1484868233843196, 0.19759236985156614, 0.1894310819766214, 0.06716052280558694, 0.20504453610027992, 0.10431479121888838, 0.15952625762551062, 0.17244341933438856, 0.16681449638018686, 0.1371217404882754, 0.3237562644625864, 0.13169377771837096, 0.08937276719558625, 0.15486462792802244, 0.19159089833978685, 0.23322279745292282, 0.08502400014549495, 0.12621788848792354, 0.0757144077590877, 0.1325364744350795, 0.21827556403173556, 0.17985656106423947, 0.15203318228164028, 0.19513897327405794, 0.12688846823068398, 0.1577283105542583, 0.11049623976671889, 0.16862540565911802, 0.1005827479304806], [0.06492782849818468, 0.02746197680431989, 0.07515302618905421, 0.03653189858361598, 0.04913924667503565, 0.054994203871296304, 0.048854507115339084, 0.02311319443247011, 0.036917390196674296, 0.04088667176303364, 0.03732272348697147, 0.051834830458486275, 0.05305733441585495, 0.07344858014896032, 0.023304195473751715, 0.0603882251157155, 0.015700768994828387, 0.04168792312303859, 0.05477649317453465, 0.033605806604628606, 0.04458682281115363, 0.0471331152103601, 0.06258821896006984, 0.03998831492818652, 0.002959390469421182, 0.04389894863350257, 0.043465247107369286, 0.03167996306963746, 0.0886645648748644, 0.031168988169801813, 0.05084034108046082, 0.03023133485487873, 0.03751670077983891, 0.07020561505229243, 0.03424970733542596, 0.037289096057535186, 0.057925405656738635, 0.06497084433513303, 0.053174580342226455, 0.05081638551106857, 0.03811028102532991, 0.042532278420103174, 1.7072253457961546, 13.417305581031309, 33.88612078082177, 33.32879120303739, 33.91382055897867, 13.451903827728765, 16.190531119223564, 26.820737738763135, 12.618462924034366, 15.742510153401284, 4.046127570252265, 0.9377872270922508, 0.9386879013430689, 1.1826381207473817, 3.154444617609824, 4.070607082497689, 7.880233382025073, 2.701577073143375, 3.4132151449880297, 1.9428119688264787, 0.7296351932229534, 0.244827956982678, 0.11084328525729718, 2.0773833413277907, 5.475236033239673, 11.273181150036475, 18.887255730167514, 27.922051029820597, 38.40624840028825, 39.10487351878997, 62.34896859815044, 64.21520879191738, 58.067250482497684, 58.876294243720274, 57.7687345781634, 60.43861350705547, 61.81206672422348, 60.07801825000394, 62.16196960018527, 62.35961391079811, 60.265405562616166, 61.14618555192025, 60.97358165248748, 59.7201019717801, 58.66719661220428, 57.330394021926395, 61.613320227592226, 61.55755981322258, 63.161444433273815, 43.258718444455056, 53.234898274944676, 59.201211621684415, 62.91476657313686, 60.064693958528586, 56.7864122698384, 53.90223072421167, 54.37316617658062, 53.16362488654352, 54.568802233665224, 54.51628561942808, 56.1536947373421, 55.825804202787346, 56.79894816490912, 53.74159789854481, 54.01420654789094, 52.68915145627914, 55.333872302885986, 56.52443324365924, 57.23023237720613, 50.86310378966793, 45.472186457726266, 31.246826533348333, 17.386325482399233, 9.69969686000578, 3.818692122736285, 1.5747764658543373, 0.6507992299814379, 1.0566183732401941, 0.6322641923062263, 2.581905559186013, 2.7883153865414285, 3.606952039464828, 6.035369615400992, 2.3806497262370203, 2.240473286759469, 3.8358824003127316, 2.487236213299536, 0.47856847665482954, 0.4534799857966362, 0.24572507658552742, 1.9726963845952867, 8.676271054052538, 20.943421010048162, 32.22908804493566, 23.30321108141253, 24.046437471143662, 29.70141072427073, 19.899448848539784, 4.424231552308606, 0.27737763860533315, 0.048486133736948815, 0.037756317760795355, 0.03294234764912436, 0.03361878030362629, 0.04183816062586923, 0.1076730908525567, 0.08899075745214378, 0.05488852587258143, 0.046540883279615836, 0.04162698082866208, 0.004500463950417696, 0.025504716003554005, 0.035702995279984134, 0.0759847984919625, 0.05271076773022933, 0.06073688322137441, 0.06457336727649936, 0.023601282455567873, 0.037883859908869194, 0.07339002804890757, 0.030133838675195174, 0.030220726452347253, 0.06842190955555247, 0.041026551757128014, 0.04307340845585831, 0.012872843522458308, 0.024733700218700597, 0.013268504952711445, 0.05222180062123845, 0.0433350466341982, 0.051587774763785066, 0.016583857697344596, 0.03920798925983329, 0.045801072171138185, 0.016087559126918356, 0.05376788096562509, 0.02591370161803019, 0.038109423006854715, 0.025599113357583844, 0.07908088921178734, 0.03192888801887391, 0.030833679146223494, 0.08556048385798933, 0.013973447569315473, 0.03382481965086153, 0.09641110040848294, 0.11456153130218868, 0.021948110680246068, 0.012509870106324315, 0.05600191975733446, 0.014207769925105236, 0.050986679195756876, 0.02066128023509537, 0.01623108378431249, 0.02196924130041753, 0.04886360440943991, 0.035500794033249544, 0.05936291219005662, 0.03455741421109246, 0.047255007459992365, 0.004681156799873157, 0.0590415804406568, 0.07337005613672157, 0.04572231067164291, 0.03266292857006192, 0.05404896628592284, 0.01999276509929088, 0.021613406866127928, 0.04593943531114248, 0.04699976994625984, 0.042574091499010404, 0.06939148575428032, 0.056078524719322884, 0.08253024605613563, 0.04893267872713266, 0.08949697303074984, 2.4775398690854353, 20.105257572666293, 40.46409637697282, 32.911356879818825, 27.285113027018888, 15.731306883596606, 22.631503228218328, 27.901956727427823, 23.41531438212241, 20.880406172044818, 3.9021020598949927, 0.6283449477726414, 0.1958206229873242, 0.6796057293972662, 1.8573443807901877, 2.3763248228257705, 5.153594814961957, 3.635340438735101, 7.765875208762385, 4.389994163667002, 2.4392175770575, 1.1611208560005313, 0.4523261348086019, 3.015529710438944, 7.50032437424506, 14.268223585621005, 22.880322702469368, 35.53255919487246, 43.03311547925396, 45.250156771752145, 65.90075323658606, 62.949612909747714, 57.10142174074727, 59.34338577332036, 59.54410914451846, 62.41062825725925, 62.18605687541347, 63.03762305167414, 63.57170866381738, 64.08023218954763, 62.2681442383797, 63.79049847202917, 62.18830047115203, 60.48908264406266, 58.82643699645997, 60.526321626478634, 62.75563209287582, 64.62744205228745, 64.99018284582323, 45.33612728118897, 53.95710468292237, 58.589117911554155, 62.14109082375804, 61.38155914122059, 59.427485312184984, 56.92556227407148, 55.29032614923293, 55.90689920609998, 55.63253725728681, 56.2605244113553, 55.90042337294548, 56.36203927378501, 57.36099243164063, 54.79485234906597, 54.80868654866373, 52.3435906440981, 56.05675728090348, 56.71859056718888, 57.40533874880884, 53.899477220350704, 48.178213950126406, 35.55703870711788, 21.859820042887044, 12.050888115359891, 6.136537348070453, 3.033450039163713, 1.607952117919922, 2.149872419334227, 1.798392873137228, 3.7346026349452237, 3.664776110841382, 3.57481042223592, 4.912606352759946, 3.5552924631103395, 3.5771491354511635, 3.6612827499066634, 1.9122036306127426, 0.4753157286153686, 0.2739509579635436, 0.06896131206303835, 1.6667621750985424, 9.987395847997359, 24.04223269031894, 32.955644361434445, 26.655770694055867, 28.90653064174037, 33.3874463265942, 25.923122936679473, 8.215584264647577, 0.8395751229216977, 0.014739428241286549, 0.037258517658037525, 0.017996341883835774, 0.027339739815121698, 0.04846645293817405, 0.042720467918702675, 0.0691553085081039, 0.03746917268501655, 0.06448790250766663, 0.04517728890923243, 0.057779140319795384, 0.021823996775633386, 0.004690192806940045, 0.0875667991837667, 0.020276167835559578, 0.024055741134009535, 0.01517760563611744, 0.028092857870844104, 0.012257478609230491, 0.022258690385628613, 0.029401064084302035, 0.022965444800173564, 0.04517865637617727, 0.061005446834549795, 0.025076890371799953, 0.027619344670505776, 0.024380688818411964, 0.018912311080062104, 0.026515607324038303, 0.059719836384418516, 0.008621289199518581, 0.04210397781383607, 0.05870287381713429, 0.03522180013298508, 0.1304185324378552, 0.17870716870792452, 0.14595052077164575, 0.1083722303531343, 0.10205595799150968, 0.22343273004216535, 0.1483010317409231, 0.09244018324440526, 0.1922245756272347, 0.09644385066724594, 0.06990978253945228, 0.2266342421212504, 0.22845892566106013, 0.14235562254344264, 0.1502358174372104, 0.12060414173550184, 0.13001455895362363, 0.17745820024321157, 0.11905764770363608, 0.17488385370421797, 0.14837826872544904, 0.1346496207218978, 0.10746309083075294, 0.12765919864778558, 0.1974188662584751, 0.10021720141653093, 0.1574921562907196, 0.14413360536338823, 0.21030130886262466, 0.12212234414032391, 0.14217824254545475, 0.09485472384239398, 0.12426729073687909, 0.14263775740419665, 0.12109099061138208, 0.2573171360117774, 0.17294716810987842, 0.232064196719758, 0.27209028361305115, 0.2437977372638641, 0.11564749923925247, 0.2185260288176998, 2.820882090637761, 20.443879712012507, 46.96009835889263, 44.67009313644902, 43.35490280582059, 21.695915960496475, 24.695499520148, 37.99771393499067, 21.66758860311201, 21.08523822599842, 5.8910862092048895, 1.4148340999118745, 1.7117968682319888, 3.720517648804573, 7.8666340343413825, 11.334087714072197, 14.89642745064151, 11.151982853489539, 10.10632505339961, 4.300405267746219, 2.426228648231876, 0.7707100698063452, 0.3295887369782694, 2.428676942663808, 7.682156139804472, 13.05940499228816, 20.297104620164443, 31.536793631892053, 46.858269706849136, 48.393810949017926, 62.61523869729812, 61.5296599941869, 57.96919122818978, 61.04474129215364, 60.19116293999457, 62.21445483546104, 65.00383661639306, 64.11834193814185, 65.24895337320143, 66.63677030994047, 63.94085076547439, 66.48250349106328, 63.769117632219874, 60.82801465065249, 62.405250687753, 61.68833555713777, 67.0768210195726, 64.08953605159637, 65.15984104525658, 49.51602458953858, 55.558224032002116, 58.6372846172702, 64.537223615954, 62.957473339573035, 61.099603483753825, 58.65375464962375, 59.2569524242032, 57.3431025012847, 58.27532045302853, 57.52877573813162, 58.21781850630238, 57.52268037488384, 59.31333649543024, 56.12139009660291, 56.16729751709969, 54.84339560231855, 57.65950441360474, 57.66879650854296, 58.80212222376178, 53.41293857943628, 48.014643269200484, 34.34807792786629, 20.079613116479692, 11.32051141031327, 4.7464768155928585, 2.4847477145733374, 1.1017684085715203, 1.8658344736022336, 2.117578565113006, 5.097018057300199, 5.67900610546912, 7.184486302637286, 13.023798696456417, 9.517224277219466, 6.623051964467572, 11.10929766008931, 7.949275432094452, 4.890194910187875, 0.9642491297375773, 0.8141296044472726, 2.690719217061997, 11.057241924347418, 26.247212694537257, 39.70207791174612, 31.594058275222782, 35.55442248621295, 40.19510415292556, 29.626144363034157, 8.66211816187828, 0.7485529071381016, 0.1565438160492528, 0.12580711214292434, 0.11250018788081025, 0.20892818818890282, 0.11998050786074131, 0.17525361370175116, 0.16159448051644912, 0.19124263476940895, 0.09974124631093395, 0.16875933315004074, 0.140982854270166, 0.09409111038210893, 0.12805896630931285, 0.27361645333228574, 0.17204738252105253, 0.16661399584864417, 0.11139324445637966, 0.15096182364129251, 0.09448033667379811, 0.1288418162373766, 0.14152640897420146, 0.08045788629040604, 0.21253276976846883, 0.18681631663874274, 0.16590547177099413, 0.12755080486737913, 0.11902790817041552, 0.11566363305093781, 0.12690836353407753, 0.19499859532281277, 0.13151961528966505, 0.12067606206983329, 0.21440450642858783, 0.1820467757962404], [0.04411860519359189, 0.008587160940101791, 0.04448098010353504, 0.06109677217600327, 0.03174855858237753, 0.03279196458958811, 0.020729986830584465, 0.020985182209481156, 0.03580547103117551, 0.01317057210291105, 0.03414219455613244, 0.03645266594004728, 0.05516985251057533, 0.00305874943977312, 0.02057318203902293, 0.0552960769874194, 0.07880516650695955, 0.012448320687267811, 0.04233606798093646, 0.06477078047370718, 0.03856093607722752, 0.03931663967969437, 0.027918130452294024, 0.0107796672326062, 0.011785228496357318, 0.024767923281498017, 0.05560001854093806, 0.0341225175877973, 0.05750543242620845, 0.035778209792389985, 0.017772249674664873, 0.06710597734537817, 0.017658374535160202, 0.02514022477572003, 0.07205684353867847, 0.06540070393032606, 0.07777876190600858, 0.07388083759935633, 0.05375095425293811, 0.1269342726276767, 0.10251666794741347, 0.028700670114748424, 0.009627784132927416, 1.08152432066779, 11.836196203385631, 30.831043527972316, 38.70889456041398, 27.33476827221532, 14.495652414137318, 17.923749031559115, 26.601086970298525, 13.50176303617416, 11.56126453030494, 5.258513804404966, 1.6904154155523547, 0.34890984215082665, 1.2902485915730078, 2.131059261098985, 5.9042187948380755, 2.111600627822261, 4.21185678051364, 4.944687418399319, 2.7956700757626565, 1.0317548364400864, 0.49312711963730477, 0.03881713503130502, 0.21032410763925125, 0.5591481479425584, 4.122146781413786, 11.275686563984042, 21.299103498458866, 26.845330999743556, 30.669671335527976, 52.7426290512085, 61.27147389996437, 59.93888785762172, 60.67611694335938, 57.997969658144065, 59.79496432888893, 58.69518664575393, 60.581266187852435, 59.37504714535129, 62.49848150437879, 64.50538181489514, 62.74721076411586, 60.44627781837218, 64.80811818953484, 55.60384119710615, 63.64952848803613, 43.07930531040315, 48.94183666475358, 51.171217733813876, 51.87313764326034, 61.163247862169825, 60.57914026321904, 62.99116257698306, 56.06761440154045, 59.09977912902833, 56.5686305107609, 58.50626176403415, 57.204207451112815, 59.27066503032562, 58.52984305351012, 59.81894177775229, 53.754577021445, 56.22075157780802, 55.84305870917536, 51.915310967353086, 53.21041484032908, 55.03464252718034, 44.24273913906467, 36.11875349475492, 21.591761342940792, 11.579149557698159, 3.9852570429925, 1.1717930123690636, 0.6201716476390439, 0.5901202247027428, 0.5277139669464481, 2.807062109631877, 1.7921690522663056, 3.362820778162249, 2.554983145767643, 2.316606491804123, 2.5104147243884305, 1.7879853541812591, 3.909505778743375, 2.0381732453261656, 1.0097174899232004, 0.21311108954250815, 0.6837738605756915, 2.847485321183359, 9.75713408762409, 16.09364563418973, 19.15511242804989, 19.06333092720278, 27.236293246669156, 29.82839353622929, 23.684926340656897, 5.7296453752825345, 0.29182262478336213, 0.07600900687036977, 0.044736374665292046, 0.05280617632031922, 0.04365083190702623, 0.057786816520796674, 0.023005310100533312, 0.03338092532489569, 0.010837651469985084, 0.012093569309781156, 0.0070038008420998535, 0.027983734391689784, 0.0588943038676535, 0.027845941987189076, 0.031047304679128914, 0.10307274052813169, 0.07134029085958196, 0.0673298052542152, 0.05689548471221521, 0.09194637829017255, 0.04288889234885574, 0.025333589198248043, 0.01311769096871778, 0.041171020617888826, 0.00358049146598205, 0.06282958645193328, 0.034921915015025486, 0.05232552509574641, 0.07134553856186329, 0.0439327790762388, 0.042189021234310446, 0.013502711437702661, 0.06728757082694961, 0.05380934164408715, 0.059370569238859805, 0.021033355733379725, 0.04850943813160543, 0.04021119671843706, 0.011020062750415697, 0.05905125996158008, 0.023487556703208436, 0.026198473736463536, 0.041818265322475665, 0.054952685736239924, 0.03155464640698366, 0.03098842699170834, 0.01739951725598545, 0.048037600748601465, 0.005131510204650583, 0.02340739326281173, 0.05861272059020497, 0.037975851746816794, 0.062290490379617106, 0.04420770888006495, 0.06795111788256515, 0.027326806335740035, 0.04539250215936092, 0.06076424022115046, 0.0404277965877085, 0.06855631202098823, 0.04011523654504169, 0.04178057379660107, 0.04385732707657641, 0.05846760055470852, 0.04280898554791366, 0.02503733725226935, 0.033035113235875484, 0.022478251184727398, 0.009566668511158036, 0.06591775199218143, 0.03387599815464309, 0.048960300027242595, 0.059847849676565784, 0.03362362964018699, 0.0829736271031922, 0.032485533250315536, 0.08779946008637067, 0.058267935059003295, 0.04659172853515033, 1.657745381516795, 17.223605955800704, 38.04167585988199, 43.592033616958126, 22.756093394371774, 15.122619751961002, 22.57987895319539, 22.574648472570605, 25.4283590855137, 19.662141530744492, 6.415000625195042, 1.3815109912426242, 0.18578382929967296, 0.2500934937908765, 0.6545075858312269, 2.4056104642729608, 6.038184896592171, 12.620705539180387, 10.027242225985374, 3.9967755732997774, 2.2058671953216678, 2.050296801232523, 0.29721162432143766, 0.4392876860595519, 1.5994329750537875, 4.741078653643209, 13.413462638854982, 25.746655502626975, 29.97728474678532, 37.49287351485222, 60.32980695847542, 60.397762021710804, 60.63645393617692, 60.034189685698486, 58.64747493497787, 61.25350944457516, 59.151115109843595, 60.64216098477764, 60.3604995050738, 62.81029032122705, 64.63444348304503, 64.9276053520941, 63.07076315726004, 64.5488848224763, 58.070419757596916, 65.31258206213674, 46.87433181270477, 51.89869188493299, 51.001763497629476, 51.18611097335816, 59.41612220579579, 60.67352033430531, 63.317119383042865, 59.19393954738494, 60.654147748024236, 57.34954695547781, 57.72248591146162, 58.011129210072184, 59.925889122870664, 59.60857722067065, 59.39415301046064, 55.09507840679538, 56.732275716720096, 56.25800624970467, 54.39839093915878, 53.352851790766564, 57.59342424331173, 48.37133969030073, 38.85225326784196, 26.60465044360007, 14.225317758898582, 5.4936917654929625, 2.340342469753758, 1.7904698079632175, 1.546267943997537, 1.5516643899102367, 4.154810809320019, 3.3504341783062106, 4.601824706600559, 5.388701192794308, 5.593337618535565, 2.8995209547781178, 4.555734895890759, 3.189949667261493, 1.7118845086905266, 0.6007614311191344, 0.1644937249441301, 0.2611298943238874, 2.1216306186491445, 10.620531112917009, 21.14937682305613, 24.562827310254498, 25.70714350669615, 26.11931597032855, 32.316064642321685, 29.14203759162657, 9.414388556634227, 0.8374370634555818, 0.04864029360995178, 0.017508535398050182, 0.05319213907745096, 0.05558988319769983, 0.030562585527678172, 0.04259632337057302, 0.03627009186593275, 0.03233847501237066, 0.051486053609199105, 0.04958424799805207, 0.029352063185445247, 0.05084575349164586, 0.033567709052154136, 0.0760429981915701, 0.07194253555949658, 0.01705128624434433, 0.007374041081000601, 0.07253764798083613, 0.043689101829283664, 0.09554991799016153, 0.03549493729106842, 0.04126563247653746, 0.021744070822493206, 0.027200229458450794, 0.08696866837600548, 0.011180993883059391, 0.05929401024214684, 0.09636097527559727, 0.022127518896013502, 0.05999822124478318, 0.04970076997133513, 0.08630997831782988, 0.008456404095575696, 0.034672867491721146, 0.05369244045728157, 0.1910327266781561, 0.10505945166392673, 0.09059847723091803, 0.10732101982519512, 0.09776096265282362, 0.16326147251792494, 0.10541575915750959, 0.11991784952941442, 0.17375439495569275, 0.12097096761628506, 0.1485381359534879, 0.15009429035407884, 0.08680742218970292, 0.07106174129031359, 0.11391041019270498, 0.13351852254521462, 0.16194922519066643, 0.13515284855759915, 0.22087126910205812, 0.16487493029525205, 0.21637539018786725, 0.2796302128943705, 0.15071282974414288, 0.17285653990843605, 0.22320262787322845, 0.14400550014069005, 0.2463000408944584, 0.1854918578699712, 0.13407526928330624, 0.09047441695246006, 0.13198148969921375, 0.19848386636905133, 0.07426342956962124, 0.18389963604990514, 0.19744593980571917, 0.15479902015818706, 0.14098700646671558, 0.11319671502156604, 0.235758196081846, 0.22230389948573806, 0.2872529409585461, 0.177794742668348, 0.15198101169399678, 1.663445933691917, 17.965745848994104, 43.41346379249327, 53.221009162164506, 36.500070633426795, 24.805880900352236, 28.43046472918603, 35.3702397500315, 21.546599172776748, 16.990387708910053, 8.028776482228311, 2.0970003403002218, 0.7954365687985575, 2.968158755571612, 6.545340986021104, 12.986176302356105, 7.780331104032456, 10.074647991887986, 11.938086632759342, 6.519298409262012, 3.2964025485900144, 1.3556316831419546, 0.28653140870794175, 0.398928580745574, 1.068372981202218, 5.075444040759917, 12.649928177556685, 24.587479406787505, 32.16345306365721, 37.79655910307361, 56.457654891475556, 59.96787809556531, 60.66984115108367, 62.38043385167276, 59.25966278199227, 61.34293163976362, 59.52823923480127, 61.38742700699837, 60.43738580519154, 64.67600883976107, 66.50295472914173, 66.46554316243818, 64.72474821152227, 67.61349539602956, 59.97265946480536, 65.03082644554877, 48.2576850921877, 51.77036370000532, 54.57115957813879, 54.21092125677294, 61.94135196747319, 61.020787377511304, 66.09611865012877, 60.929431453827895, 62.49772448693553, 58.040919611530924, 60.82154273986817, 59.97787621713454, 62.72077398915445, 61.71763958469514, 61.62455389576574, 54.663539240437174, 57.620723939711056, 56.685874077581595, 57.88148703113679, 54.17613767808484, 56.19817441509616, 46.37178597911712, 38.56670471929735, 23.588006534884055, 13.933250231127586, 4.62695288081323, 2.217365623481812, 1.3868797354159819, 1.2463125298100135, 2.1367665548478407, 5.30215262405334, 4.151186048984528, 7.088842247762988, 6.519422944514982, 6.804742524700781, 6.774156862689603, 8.832033276557922, 10.822667517969686, 8.055829069306775, 4.5523567545798524, 0.8631797627575937, 1.2519451759515272, 3.408343806382149, 13.17853129679157, 21.31403596170487, 25.626268156113166, 27.745183514010524, 35.9526881863994, 39.19322490692139, 31.28297705804148, 9.165030737077037, 0.6818416642565882, 0.15444096598413684, 0.19665507659796747, 0.17547263823930295, 0.1817218319422776, 0.08979734844498097, 0.11520623259486691, 0.15406308545460626, 0.14114313518568394, 0.16566775468808992, 0.16042883177438091, 0.08649277455744245, 0.20260779427424555, 0.09901195358965667, 0.1714618155552495, 0.19759831469385855, 0.1477812257625403, 0.17474692314863208, 0.17976273061527362, 0.2311530883514112, 0.21576707041071308, 0.08800137021969404, 0.13274520275092896, 0.10919042757802433, 0.11656262956920171, 0.14728153725304913, 0.16710674360154137, 0.11667881446379809, 0.15168401472751172, 0.06379101147514678, 0.13002804210109095, 0.14245860008222444, 0.21222097198328665, 0.13427794550455388, 0.22208323552002832, 0.06522631167524284], [0.05247376310909468, 0.017427605869729194, 0.04460228246546561, 0.031392210869178656, 0.024075180615088152, 0.046172360514080336, 0.055622265734259164, 0.131011821569935, 0.03998089153620024, 0.04423456409225061, 0.04742813567000051, 0.041420477998232653, 0.031322498783288945, 0.08353657149259122, 0.059002383552010984, 0.03876776449502476, 0.024656966936984853, 0.12394787803772958, 0.06451251691267376, 0.05935264278143164, 0.04025061577258091, 0.04555118578155676, 0.05911564582117623, 0.044054912643567215, 0.03861035257878323, 0.08883276713951942, 0.03981753860810592, 0.02628432921013765, 0.01579345797278708, 0.023693065534556107, 0.05111076245685259, 0.062109571055419026, 0.04735771686800065, 0.07579952012747526, 0.048815421309442296, 0.03716207867968948, 0.08609494509836359, 0.08805636767177813, 0.07572567691245387, 0.09633112082918806, 0.02305674141332988, 0.09534733369946481, 0.01436976591996368, 0.09915456085676148, 0.5766744623261114, 8.357760867764874, 28.592650813441125, 35.87532727949081, 30.15939843270087, 16.443819153693415, 19.995992106776086, 19.056908046045614, 15.769905947869825, 14.20320833882978, 6.924240473778018, 2.86823931720949, 0.333844845693919, 0.16341433770233588, 0.5049627490582005, 6.750256390340867, 26.22336272270449, 10.723215822250614, 3.226326708832095, 3.5680649261320796, 1.7049583384106237, 0.654716084320699, 0.1823560454912724, 0.4056408592770177, 0.0648372156185008, 1.271968140236793, 3.95827089105883, 11.025829622822425, 16.289885736280873, 24.329716928543586, 33.958598336865826, 47.36119208797332, 55.97625847785704, 56.424373580563454, 58.03591858956122, 58.48593211943104, 56.8829692563703, 57.9776753148725, 62.67077553656794, 61.043372384963504, 58.75239441471716, 61.69272076699042, 63.68121731665827, 61.55350016009424, 60.13251958354827, 63.07570534367716, 59.616602390043205, 49.794638387618534, 55.61807940083166, 64.42454176564371, 57.48801838967108, 62.800527541868156, 62.56112175603067, 63.689368001876346, 58.47864435565088, 59.64887957419119, 59.4375854153787, 62.02929150673651, 58.98982332598779, 60.47660558454452, 58.14308166503907, 61.94382306068175, 52.17696443680794, 50.31215983052408, 48.969536442910474, 35.050590115208784, 21.113285133915564, 11.061566337462395, 5.6179470592929475, 1.549421652190147, 0.3288360096273884, 0.2912792845839455, 1.235213447963038, 1.658425790167624, 2.6368236445611526, 2.870058316376902, 3.5403695606416274, 4.218604237802567, 5.422764526259515, 4.874059750187782, 1.4562610705052654, 2.9163243885963195, 1.7114292686024022, 0.7456474727199924, 0.18867286943620254, 0.47064810811031255, 3.676932026301661, 12.186727639167541, 21.098613508286018, 27.749329459282663, 23.66824450031404, 22.666814365694602, 28.40113324503745, 23.724544240582375, 6.423984323778461, 0.4008154859465938, 0.10620500591974105, 0.041522199152818615, 0.07340196369876785, 0.08350025892498032, 0.028181293145603234, 0.052271266918509245, 0.024363354163905306, 0.045588770055121956, 0.04967499877356234, 0.0595571116484221, 0.0036052765649548105, 0.0740719918582228, 0.020409802297851252, 0.016382085459847606, 0.03509651411384825, 0.019815254866355853, 0.013318570713782984, 0.029815004372428504, 0.09892013795193165, 0.014739948223465154, 0.03339634284437184, 0.015287762376359634, 0.037980720235575596, 0.04957069590267155, 0.012472919770516457, 0.057211507472299764, 0.03708420584218637, 0.038901439176932465, 0.09378109758179035, 0.03611191386176694, 0.058475487429888985, 0.019810786658537485, 0.049669195657535914, 0.06933926920136137, 0.07834574357876856, 0.05242989308411076, 0.06064352391648197, 0.053714572737414035, 0.08079432146323305, 0.026953556807711724, 0.060979641162820404, 0.02861929817065116, 0.05473272657142051, 0.07257795952741178, 0.013327794412391321, 0.045202290188641324, 0.013954765557671988, 0.005947795082559629, 0.04425647420688503, 0.038540002724696557, 0.04473927430808545, 0.023511510357380878, 0.041720278846520575, 0.057530671192873875, 0.08960394188761713, 0.052904473061883645, 0.03509749087595171, 0.022693730650409576, 0.019016786320735852, 0.04369699253490375, 0.10591156360122467, 0.10556705386167574, 0.0051712491005028215, 0.0540182653123573, 0.0333268050434849, 0.05458549213325305, 0.033658348744915384, 0.05057104202287813, 0.07795762811456958, 0.10310218128706179, 0.023995545775359197, 0.027306660138551268, 0.03542528840743246, 0.039456159612464334, 0.05046751673123048, 0.10992255482462146, 0.10349284016316938, 0.02084613342078463, 0.04198953193882781, 0.03271737443884054, 1.3028484703071657, 12.962685227394106, 34.90783545278734, 39.87792953368157, 28.707617444376794, 18.08642933445592, 18.328551361637732, 17.052978930934785, 26.010676122480824, 21.519832918720862, 8.509799780384187, 2.0990196254945572, 0.16464662077205797, 0.3620196596509026, 0.8025284592182407, 6.134371709439063, 14.867128326046853, 11.304854289177927, 3.7121588328192314, 6.270857934028872, 5.5487966537475595, 2.586380248108218, 1.5741024310550384, 2.3840663558052433, 0.5985724421278124, 2.2481743702965398, 6.255953907966615, 13.666788916434012, 18.242474948206258, 28.299420302914037, 41.674869291244015, 50.66485935641874, 57.992941179583156, 58.802679200326246, 59.43674602816182, 58.83050841669883, 58.97840922878635, 58.55804489504907, 64.53160285949707, 61.40029630353374, 60.54925180250599, 61.32030348623953, 65.45547400751423, 62.750419262916814, 63.407475102332334, 62.53951734112155, 60.11546904040922, 49.92722234418316, 58.244655363021366, 65.39175118169477, 58.74926044094948, 63.52759376648934, 62.6757961703885, 65.05330162663614, 60.334953108141505, 60.40301015300136, 59.86868919864778, 61.084416066446614, 60.36750093583138, 59.92580283072687, 58.061264945614724, 58.54373608866046, 54.631536622201246, 54.255240117349935, 52.52944430997295, 40.80920219421387, 26.41350942273294, 15.69836485770441, 9.14951580186044, 2.4108318744167208, 1.1642542168978722, 0.6827246878416308, 2.496228737215842, 3.2869540491411766, 3.3543271307022344, 4.534333953934332, 4.6415171315593104, 5.333313403591033, 6.733494631705746, 6.175262908781729, 4.876899055896267, 2.0742822174103033, 1.6496261978341689, 0.14019732303436727, 0.23354527450376944, 0.3122877443750059, 4.01625112179787, 12.565440324044998, 22.887204500936694, 24.66110229492188, 20.877842903137207, 23.177199056071622, 31.902493853722852, 30.17390924115335, 9.841226762340916, 1.0623346148960053, 0.07632023008960871, 0.05068668682548789, 0.055151926053147164, 0.03215832560653648, 0.05967025134351946, 0.03963291524879394, 0.053935056672461575, 0.012956139304855419, 0.03403899485185262, 0.07723320771249072, 0.031223123772971095, 0.050103582832361424, 0.037206971432052316, 0.03173835237600631, 0.07318760463667494, 0.010910274689987062, 0.020248653787759044, 0.07010188674734485, 0.015768041090679266, 0.014531782982240041, 0.04497878786717211, 0.14564209377333043, 0.03440164172300889, 0.00879434654639373, 0.039235687168735656, 0.044908625704626885, 0.012143335338952321, 0.018516107642602538, 0.0403472232902723, 0.022937792856546662, 0.03538168651322204, 0.030765257918486194, 0.05798897563269543, 0.040903889589131846, 0.05057680683450834, 0.08489699808940773, 0.1288756620018713, 0.12097819948629027, 0.27011141721760074, 0.09632807946012867, 0.1372754943346785, 0.13259074410363553, 0.16859094702428387, 0.33330061683251017, 0.23046982985350395, 0.1285204729966579, 0.07747918322321869, 0.07222994876604888, 0.14560895280972605, 0.150612625443647, 0.12927531475020995, 0.1218760392117885, 0.14202393711574618, 0.176445723120724, 0.22601083041198794, 0.14256864095166807, 0.08784721034669107, 0.1883266436597032, 0.11138507029822758, 0.15528003144408428, 0.1578258182252607, 0.17642107041132066, 0.15380051647943838, 0.11442787194203947, 0.14767129214540606, 0.1392827979138782, 0.16584308157044073, 0.11025317539010318, 0.21653954750828205, 0.2232596707800704, 0.10967619626993134, 0.12181935636627099, 0.28431352288011585, 0.12383717067179181, 0.15378550115612247, 0.3086435866932715, 0.25781993483824117, 0.22497284256162184, 0.06843949127341471, 0.1911955356838242, 1.1300977271410728, 13.232047134830108, 40.40212292825022, 49.30981774483958, 40.87139529566611, 27.684553477071947, 30.20712583295761, 26.82373639075987, 23.13540227951542, 20.272381920968336, 10.363915927948492, 3.994763887697651, 0.49073208363786824, 1.3679984259989955, 3.3460362207505012, 10.287623866911858, 42.87830737329299, 25.938524123161073, 8.198299359890724, 7.565391102144796, 3.038835453410303, 2.6088397397148997, 0.796538019372571, 1.5635608160688033, 0.5691765453065596, 1.5828500519837103, 5.056045468776457, 12.722381218787163, 19.906879778831236, 30.008853943117206, 41.12022653702767, 49.31288111594416, 57.443750519906324, 59.14836160598263, 59.00823100920647, 59.349237949617454, 59.50311645384758, 59.07135763475972, 64.5123714785422, 64.61636527892082, 63.14314265404979, 64.35668868403282, 67.1275294211603, 64.23147878339215, 64.10843010871642, 64.03755287970266, 57.88459354831327, 52.19615659406109, 58.17477441603138, 64.13994635305097, 59.01083546300089, 64.36235650893181, 65.18545020011165, 67.95247447106146, 63.80503477588777, 63.45921900964553, 62.22840278379379, 64.00467557291832, 62.09648563015846, 62.677070940694506, 59.684745727046845, 61.9366608127471, 58.5832029773343, 57.00682593930153, 49.58911011295934, 38.823667034026116, 23.950347246662265, 13.130079238645493, 8.118549729547194, 2.3765334438893104, 0.876728916360486, 1.1328566242610256, 3.0725575406705183, 4.994243623748903, 5.444548389604015, 7.464282695324191, 8.820820200827814, 10.541762075116559, 12.478467649029149, 13.646649506784255, 10.435233443014084, 8.524821477551615, 6.32417324089235, 5.35676182277741, 1.2869351693699438, 0.9033207475177704, 5.49320048862888, 15.765165763516581, 27.523408782097604, 33.97419368067096, 30.193809386222597, 30.798797722785707, 39.04168413531396, 33.418786064271, 9.845510971161628, 0.8410762875310837, 0.19822267635214716, 0.17546168318198574, 0.15812531263837892, 0.13703170983541396, 0.10846477377438739, 0.10292728341394856, 0.10869114509513302, 0.10997263399223167, 0.19275346740839944, 0.14383077080692017, 0.16785868954273964, 0.16882118708904714, 0.19995783485712545, 0.09539087813708091, 0.15798720230738963, 0.08488379839447238, 0.18899056609840165, 0.144018309130784, 0.13502783833011506, 0.09557325302833512, 0.16995102888153446, 0.27008874101504204, 0.17476970660350016, 0.14977355998369957, 0.15822798374199099, 0.19702152709566778, 0.10253276345470261, 0.0737691879452717, 0.20218522017521245, 0.16381821925601653, 0.28374174549694986, 0.12430209411127914, 0.13178279713517235, 0.13604645947775534, 0.21487542067564305, 0.15911039445669423], [0.047644796826305895, 0.039371522218589826, 0.06717209839412282, 0.031115124527845654, 0.06601706763068516, 0.03757300441183391, 0.08325290445598864, 0.04596471238220411, 0.049459896606182864, 0.03176750202152518, 0.03813816662577372, 0.05863848412709852, 0.06695617651266438, 0.022301009082565867, 0.03400894888346234, 0.11609849520027639, 0.0440813809813511, 0.0821912138452453, 0.0889549121981667, 0.04661945708756966, 0.03746203274556226, 0.06217813209420251, 0.02800526912324131, 0.06862767311113496, 0.05142372469567964, 0.11175555807928886, 0.04480087160763722, 0.08390607868110941, 0.04474673983490756, 0.07997494446293962, 0.007813345103885138, 0.0276434208987461, 0.007029659661178988, 0.06302132676806181, 0.03218437259596202, 0.04993115176236437, 0.02510870791851513, 0.038212017501674356, 0.11833815324691035, 0.024843122472145387, 0.06354835695557057, 0.03545462191405316, 0.0363297701152342, 0.07459458639664997, 0.051286583465914574, 0.46945515599462295, 6.304072564648044, 26.505043814259192, 41.14782825593026, 35.439351912467714, 16.664356377816972, 26.323308637065274, 22.910436699467322, 20.194311065058557, 19.99727668300752, 13.67000820175294, 4.3424383671052995, 1.1479202417596694, 1.2359832131093549, 7.583149633099956, 10.029289703215323, 7.316215182504347, 3.6970567270632717, 2.1735623094343373, 6.199586997109075, 1.6417625810830825, 1.6005856615881768, 1.0848995202010678, 0.2715585573065666, 0.8370899336953318, 0.021338821801867698, 0.7724669239213391, 4.098254153805395, 10.251814588423699, 15.887122058099317, 20.90502492843136, 27.81766107005458, 35.65439585716494, 42.82396685692572, 49.69421002172655, 55.882498141258, 59.531726221884455, 60.29388981480753, 62.10385576371224, 62.53727374538299, 64.21205128392866, 63.25207079610517, 60.853894449049434, 66.10732093934091, 69.76411527202976, 55.09158749734202, 45.864121452454604, 47.72145002119003, 55.908566213423214, 60.74069484587639, 64.41358266338226, 62.685735456405155, 62.39367185100433, 60.98945156220467, 62.80565407968337, 63.69471419242121, 63.58687254690356, 61.70555083982406, 61.89631923552483, 60.12699688634565, 57.182673638866795, 53.07342213969077, 42.23122612122567, 27.297388084473152, 12.728974723046827, 6.245597870119157, 1.365783390018248, 0.8707996409746909, 0.3853595088566504, 0.8696414998942806, 0.6896143923363378, 1.373506904609742, 2.2587929617974067, 2.227965828872496, 4.495073479990806, 3.6930970943743184, 2.84361933508227, 4.97777113991399, 4.354619287675427, 2.5859482970929917, 1.7186692284960903, 0.9992508902665108, 0.265777749760497, 0.6086440468507429, 5.819668673699902, 14.903639708795856, 21.036022286261282, 17.703566781936154, 17.318484167898855, 28.82010513736356, 24.82393360907032, 23.75437778811301, 8.171095271264354, 0.261625369349795, 0.14459226220365495, 0.02997112351529781, 0.06762075012609844, 0.03620002929481768, 0.06104711052631179, 0.01898776882538392, 0.011376446852790973, 0.006220713905584548, 0.07198821738242142, 0.08707629606848763, 0.046310574266939394, 0.018770948705834248, 0.04716323012666357, 0.032464852706799587, 0.03384125989771659, 0.014619442592975835, 0.01958073237009587, 0.03602017866327398, 0.03548189464415755, 0.025005692075337135, 0.016684132860973477, 0.04497656238175208, 0.06018434230598712, 0.07930678555801993, 0.0240383566837878, 0.016670186230311954, 0.03782083002489902, 0.12357188208449273, 0.13810217981376957, 0.032817176543176174, 0.013751931330789963, 0.017398381530637705, 0.10497194144033617, 0.09053843125941292, 0.05923424772317371, 0.009841799413064315, 0.03833763676905825, 0.03506849061757807, 0.049135757144540555, 0.00431909550717401, 0.025735542125579332, 0.03273723909871713, 0.021306276471624454, 0.01955713686202803, 0.05450000055134297, 0.004453897295940307, 0.0443871190110522, 0.0073603946610444025, 0.015845782735625345, 0.01335571735962144, 0.05519187370795877, 0.04644024996988235, 0.05623656865810195, 0.04755122301679465, 0.06818367919373898, 0.04723038156366637, 0.021308490465725624, 0.053545029818891525, 0.017695568103884018, 0.01893057270095714, 0.04639201324373003, 0.06626731791203061, 0.0900748331520346, 0.03827902338197155, 0.08809392130182636, 0.01350158720367378, 0.028499108551430608, 0.009116567915395625, 0.05793667097966518, 0.011524144774152627, 0.03549094597298292, 0.008037334848796169, 0.01706754071487775, 0.029146221105850516, 0.03137318699079896, 0.040521669171510205, 0.0071982459274060545, 0.024482264416292313, 0.05110816541878928, 0.024038034926859603, 0.020519992554440133, 0.10039703289587652, 1.037831691003615, 9.734034269086777, 32.256413236741096, 43.64800191694691, 33.95329529239286, 18.71044312753985, 19.324017532410164, 13.736653193350762, 23.169040526113204, 25.507887101942494, 13.455017209053041, 2.3323437763798625, 1.2384147148939872, 0.22394295992149463, 1.0875230955500756, 1.3873103381164613, 4.883143469210594, 3.746752666850244, 7.6830901542017545, 15.574913159493478, 6.491637364510567, 6.5461009452419905, 6.524053302503402, 2.63614286818812, 1.5778817572901327, 0.31612798992183905, 1.6829983361305731, 6.341305663508754, 11.513770511073451, 18.06533286648412, 25.466198190566033, 32.59966181170556, 40.39629820854434, 47.94715496801561, 53.393318883834354, 58.19822234492148, 58.95704407845775, 60.92133175942206, 64.47844297655168, 65.23203619064824, 65.28534120129001, 64.83383324838454, 62.44006172303231, 67.11163597722208, 70.05781450579244, 60.418978121972856, 45.46877007330618, 49.156304021035474, 58.945053392840975, 61.20432684498449, 62.80881943241243, 64.00628374468896, 62.91244845236502, 62.495567183340754, 63.56203217660228, 62.37008271678802, 61.92328945282967, 63.0947131495322, 60.717223382765255, 59.47589520485171, 58.9716156836479, 55.46696616757301, 46.44266713050104, 32.55010266457835, 16.809988098759806, 10.047699347619089, 3.1243605286844316, 2.2923196659934137, 1.1815929316705274, 2.3487260457008117, 2.554805168221074, 3.614088791993357, 3.8596926581475044, 3.9146967905182994, 4.842840625393776, 6.467236789964861, 5.517076446164039, 4.688500752372127, 4.922536813443707, 2.061324912694193, 1.422233160945677, 0.3183417082313569, 0.24775095013601167, 0.8476879327527939, 5.5287641286849984, 16.46047745981524, 25.9271570944017, 24.020287029204834, 21.104628462945264, 29.930324169897265, 28.09402342765562, 28.411064686313754, 12.293529856589533, 0.7078560489800669, 0.1250647806051758, 0.058274764732848254, 0.052102072569992275, 0.03395792359726564, 0.053835066876584486, 0.03438880208939795, 0.05501825137123947, 0.07864020479422423, 0.03508870384746021, 0.052788357115200454, 0.057405170669118245, 0.012189736326916084, 0.04711103655638234, 0.02814014464797032, 0.022352957504711325, 0.024937786041728915, 0.02133713449321447, 0.02333952936403934, 0.05501166301509065, 0.04297395875196784, 0.04722484657841344, 0.041808076353082736, 0.05048317556840278, 0.05213016501417564, 0.06374412689418082, 0.022283659106300726, 0.022460160018395514, 0.06136489145818257, 0.011558652247091936, 0.05969682693361275, 0.02167591389508978, 0.019841983674033996, 0.04014573833574692, 0.04881802983882447, 0.034176480821183616, 0.051595167512254375, 0.014573166094299768, 0.16127905147450586, 0.22086935388224743, 0.0857863802042219, 0.12164986707390317, 0.1509728246638852, 0.07049590108856078, 0.23180380343429505, 0.16702155462436138, 0.1616724223018654, 0.22369228063091157, 0.1262203476301605, 0.09846578652579939, 0.14850133308960548, 0.14993883579248382, 0.12519735212047256, 0.1491945354087699, 0.12388526567167814, 0.18987343646585944, 0.2629198740807272, 0.12435472435167721, 0.14960554158014638, 0.16616992532245575, 0.2274945435384589, 0.14835867219634596, 0.1493812770011925, 0.23700391633376, 0.16672625837306823, 0.2425184776826251, 0.07291719858204165, 0.20416454622341743, 0.11383620691635918, 0.14456036230248792, 0.08542202112655486, 0.16589264745914167, 0.13653385993694106, 0.16728659040264546, 0.10872350464905463, 0.12156198146722971, 0.18688189376506115, 0.074227484724214, 0.1775320664408707, 0.13799197040498257, 0.10907300162099062, 0.21184845406922603, 0.15025866217911243, 0.9484271464809295, 9.419798485694393, 37.361846739246005, 52.98322723757837, 46.91929394199003, 28.525356669579786, 37.13813827883813, 33.410666758014315, 28.3325368742789, 27.552502962850756, 17.859941874780965, 6.378840294576461, 2.1288262067302584, 2.5251643071251535, 12.193196608174233, 16.09930855612601, 19.720341659361317, 10.357889206178728, 7.12018737869878, 14.375078755040324, 2.6056746321339763, 5.694074380782343, 3.9811191876088423, 1.3946052111925618, 1.6851572331882294, 0.12028229287675313, 1.4299398828898708, 5.2150191318604255, 11.10694129620829, 17.306012991935976, 24.74100293651704, 30.138017592891572, 38.41744676713021, 44.00524354750111, 53.71512189988167, 60.67838407331898, 60.840417185137355, 62.42913399973224, 65.38092544001918, 66.52408061488983, 67.44571993427893, 66.49483542288503, 61.322649063602576, 66.06982308049356, 67.89666698824975, 60.09660243988038, 48.13267131005564, 52.57316304791359, 60.897970122675744, 61.882347752971036, 63.95167258477981, 62.59097491541217, 63.47633623307752, 65.12944267642114, 64.1440373851407, 64.43768170572096, 64.80301126357048, 64.66490460980323, 62.578199755760934, 62.01127606053507, 60.86684611535842, 59.53598983826176, 46.617393032197036, 30.743717839640958, 14.443732980758915, 8.392841565993525, 1.8922273670473408, 1.6791019516606487, 0.8078365292279952, 2.443192408930871, 3.3062172993536922, 3.5332222667432602, 5.587756085780359, 5.350539963091574, 9.595490271045316, 10.02760112285614, 9.087760044682412, 12.693844995191021, 10.025630131844553, 5.666374602625448, 6.252558115989932, 3.829703686698791, 0.5696409171627415, 1.231019453656289, 7.697908868712764, 18.733769462954616, 27.84403116472306, 25.113694783179994, 26.275126241868545, 38.25007138713714, 35.90560013248075, 33.14792679202172, 13.55215568696299, 0.7497894343349242, 0.24798307477706866, 0.23061198512873343, 0.1306051054909345, 0.09998959669422719, 0.12843405827879906, 0.16592949628829956, 0.18692065781402975, 0.13502486590896884, 0.1410271188304309, 0.32114120801129653, 0.14406041332310246, 0.086558987536738, 0.15932119120993923, 0.13839055063022723, 0.11703139877006893, 0.06315777468825541, 0.09589468053872548, 0.1313167092420401, 0.13852832388252984, 0.10322698467080632, 0.13105839971573124, 0.11691741254781524, 0.14558033176487492, 0.19346690977052336, 0.11507133217228037, 0.07089697876043859, 0.22764811352376016, 0.16348291789331745, 0.16497245328801294, 0.218325114598678, 0.12265770936444884, 0.1188596369578473, 0.15931414320103585, 0.12785314912757567, 0.1784013923738272, 0.09787166235788215, 0.16842829123620065], [0.015416780201297615, 0.06832924356023151, 0.09810351886816564, 0.05313743273877809, 0.03248801154475058, 0.07286986200920037, 0.03385995627350865, 0.020684419920848265, 0.04660886592201648, 0.029662022359609127, 0.036351392946897015, 0.043596282616377845, 0.03315347382017682, 0.044703321801798965, 0.009415651513864438, 0.0039979878384920385, 0.022508052004981908, 0.01918797824351538, 0.13517250637373618, 0.037350379261038, 0.12312189735952886, 0.03923420861904179, 0.008220749704407589, 0.057085842239640416, 0.015705679618423025, 0.09429439181281675, 0.02343454724928785, 0.044562518671755834, 0.032212472701024626, 0.05860542743316582, 0.023875283377785838, 0.00965901562238052, 0.03470968184692245, 0.052001764847626614, 0.02859742061475352, 0.07013371003971947, 0.012188401418708026, 0.019858247720666473, 0.03952431845508757, 0.04926221527820153, 0.004257764901980878, 0.02905896560649478, 0.04092046007093403, 0.006777772824505285, 0.09945017886498284, 0.08183280727074993, 0.1816160964869684, 4.955784784209344, 19.619275908316336, 36.33509966634935, 34.51435112184094, 27.658542279274236, 24.19964328888924, 14.469644158117234, 16.82617768164604, 22.50666791392911, 17.94490041271333, 6.014331492685503, 1.861857435395641, 0.906189532289582, 1.1347653476461288, 2.771735282674913, 2.5856224952205538, 14.239895247643995, 24.826783211000507, 13.492147345696727, 7.211612924452751, 10.17820837036256, 3.142071746049389, 1.3308451228564786, 1.0701527566679063, 0.10353702811464187, 0.24258554101951663, 0.6522600677224898, 2.021807155782177, 2.7412489056587224, 5.013436271298317, 9.476229625363505, 16.75331965569527, 23.669707544388313, 38.86635811098161, 55.114925599867306, 64.67866036199754, 62.675376476780066, 63.4692406654358, 61.770901449265025, 65.24317179956745, 61.339464264531294, 68.64840492125481, 54.9452595556936, 44.59259102421422, 45.95304158426101, 45.00494195568947, 55.67980966260357, 59.76632710426085, 63.64841061253702, 65.60839153105213, 64.87097417154621, 63.05668184834143, 61.614838184848914, 60.65665414256435, 62.03715585893201, 59.73743884794174, 59.96461860595211, 56.40698571358958, 46.704395124989176, 28.96924149605536, 15.989638105515512, 6.750930057417962, 2.4339338992872546, 0.8422898933772118, 0.9906091733324913, 1.5031786238954914, 1.0277291976155774, 2.7110044898525363, 1.5476027755968034, 6.8376600357793995, 2.966611625686769, 4.504988251193877, 4.445190247028105, 3.8720062038590832, 3.7949563899347862, 2.0006731801456024, 2.8435524096412044, 1.4996161311864855, 0.5317545598072391, 0.44712209953896465, 2.6733114930891224, 9.896523356437683, 16.821921910009078, 18.7092742612285, 15.57668410962628, 14.521745001116107, 18.72753877793589, 29.274162630881037, 25.741705471469512, 9.790114356625466, 0.8580018664079329, 0.148629606851647, 0.04437515654811456, 0.03169962663143393, 0.01508113026859299, 0.0275562075342262, 0.030170120599289096, 0.018302206318044377, 0.0370211951104143, 0.020668502529001525, 0.11040708245409113, 0.023809288733548695, 0.07319568686427609, 0.02752522885378811, 0.09778045959049657, 0.005737630351852145, 0.0317990590983461, 0.035684183991003426, 0.039115802069465, 0.05318065158902638, 0.03232964201860371, 0.028981253647455768, 0.09614156003320411, 0.0555767945855135, 0.021212869286236745, 0.02276876896259285, 0.05906791471305394, 0.05648065576209657, 0.05615651247001464, 0.0867600626342239, 0.00482743697976994, 0.041184028790843104, 0.05758727742959896, 0.026195666024221048, 0.035906242236735365, 0.023936867270798936, 0.07911555469036102, 0.04618723794156986, 0.07619597062829041, 0.05129966441722167, 0.029236144506402557, 0.023676334174289822, 0.08539645677252163, 0.02817915192985487, 0.04941242596795482, 0.05765300011262298, 0.014521896617577202, 0.025901436550362457, 0.08519004970308273, 0.03441753038655847, 0.03740544183059566, 0.03682114274030732, 0.05146374512884406, 0.03354062784403082, 0.012073728590152197, 0.04982456211901961, 0.11119111981843749, 0.010840987782895325, 0.08314171445465858, 0.057173023045423536, 0.03028539384925558, 0.07851890243229367, 0.05945306924742557, 0.02626288066347761, 0.05897676174138343, 0.07235758667511326, 0.05477165915973244, 0.03860805431501039, 0.06483340816151711, 0.03283258257133346, 0.032234348341702454, 0.030117427156637275, 0.050031739106822404, 0.051622700712253014, 0.04172620453661488, 0.023091077474096132, 0.052918936801894065, 0.05074552237807263, 0.015892795636318624, 0.024647157181114442, 0.02366960409187502, 0.10137562594947316, 0.03687000765855755, 0.09782326858370535, 0.04937390323668238, 0.3407045501855112, 8.471915568074873, 29.057604651297297, 42.70248713031892, 34.91202454413138, 30.46665337777907, 20.761122972734515, 15.50713852528603, 25.706308041849447, 33.904261742868734, 21.43418992719343, 6.395474576180981, 1.8021724445204583, 0.3028312776117556, 0.4572846848637827, 1.3188767457200636, 1.7287407719319867, 3.751388172949514, 12.116163219175032, 8.711713590929586, 6.708298796607602, 10.324072491738105, 7.736098535599248, 6.213765384689455, 5.407915903675941, 0.22188008432426762, 0.5966111957546204, 1.0285599433606671, 3.0427835641368746, 4.214298455945907, 8.04833096842612, 13.422795918680007, 21.246280939348285, 28.080489289376047, 44.33675050735474, 56.58577911315426, 63.92580063112321, 63.32001801460021, 61.79765593621039, 60.94576812559559, 64.4892491063764, 62.32805452039165, 69.0237129888227, 59.07107522410732, 48.055451608473255, 45.131026544878566, 48.304059274734996, 58.70657720873433, 60.22991987966723, 63.1379690477925, 65.45429729646253, 64.5418990811994, 64.40001518495622, 63.96320043071624, 59.90374342087777, 60.98413675062118, 60.055570525507775, 62.31171000388361, 58.90616309258246, 50.96508149177798, 36.103946547354425, 21.12051602332823, 9.290035693876206, 3.89467112960354, 2.014937614721637, 1.3476663299145237, 2.586767582162734, 2.543733052669033, 3.9867029266972698, 3.4080969422094287, 5.3793723256357255, 3.8938692500514374, 4.36253757246079, 4.386072774087229, 4.151606232889237, 3.964447153191413, 1.9509457388231832, 2.269471859739673, 0.8528660742505905, 0.4274401975975883, 0.24112300256327276, 2.105887450518147, 9.22219535996837, 21.496428135902654, 23.94672101543796, 21.501772365262433, 14.774763372636611, 19.830964265331147, 34.95274266889019, 30.939038145926695, 14.704477440926338, 1.2867223807880956, 0.16456127857729314, 0.05173205976344405, 0.023948852716374303, 0.05772356830176808, 0.02954668016172946, 0.04272893319026597, 0.07498071003224581, 0.013733126745078594, 0.044868842758719, 0.06947783918510522, 0.024915914231490706, 0.01900686739733623, 0.07367721142908258, 0.027903676288382664, 0.018364749736182632, 0.0519231029395615, 0.024703631267672586, 0.0179783598850331, 0.02764333854429424, 0.018191313175784967, 0.017123219985214454, 0.04335182012930032, 0.05842717026450461, 0.014195974086291127, 0.03125307398037084, 0.06271492607230622, 0.03111830379273142, 0.09363416191791335, 0.02350758607198875, 0.03864488016153055, 0.03765130242813499, 0.03725787414418113, 0.03272664027228471, 0.07677904780833952, 0.0243804091963196, 0.04777120516425179, 0.012451328539980516, 0.06348199458912977, 0.1211914707035307, 0.1792815048247576, 0.2203328778306323, 0.2680472086273855, 0.1391530072977466, 0.14879567939187252, 0.20129026094030952, 0.1349334409760852, 0.15327537852910258, 0.17500097322608196, 0.19351730303418255, 0.17601202542503036, 0.1453932990590411, 0.22495966584932423, 0.1039393085445608, 0.0764550309207651, 0.10706332316922565, 0.24814237510004353, 0.14739876402722252, 0.16437004770963423, 0.21366109470686606, 0.1672954770225671, 0.15284027123162824, 0.1803428123915388, 0.15755442391720512, 0.16171806582039402, 0.15291839687814637, 0.09990506655266208, 0.0980165678887598, 0.15179943353418382, 0.1520413641006716, 0.17139884312787365, 0.1134022564116505, 0.15122200242213665, 0.15511109373502194, 0.24687102154618312, 0.12712782474174616, 0.14248159804171132, 0.13972458549805228, 0.11285199077739833, 0.09119506820195145, 0.1423813324541815, 0.19277517834017355, 0.2217268973829285, 0.22034954790386463, 0.1969050357659017, 0.35727025159905035, 8.404609657103016, 29.93858664266525, 51.86677163647067, 47.499479170768495, 40.15812404694096, 34.56667946230981, 23.951592599191976, 25.024531464422903, 31.55779204060955, 23.951786756515506, 8.129648566246033, 2.5751904614510077, 1.6272799646662128, 3.4323749426872503, 5.9515294432640085, 8.359093493030917, 26.861765730765562, 42.80104844800888, 32.52010241631539, 12.623326663048038, 14.941893604493911, 7.777521216100263, 6.969210938099892, 3.90059954697086, 0.21840673360613086, 0.5067812885728575, 1.5004871425128754, 2.7172562576109365, 3.356582493551316, 5.727067397486779, 11.867532018692264, 20.789416989972516, 25.710689329331924, 41.85359993288594, 56.75368793549077, 64.04476611844956, 63.80346190544867, 63.78419130079208, 61.957351315406065, 64.87820309977378, 63.01682664502052, 69.19253180103918, 61.224774160692775, 50.671103769733065, 48.27656738219723, 50.925598913623446, 62.01218212804487, 60.9816264337109, 62.98179595701156, 65.77550803461384, 65.44406383268296, 65.83444164645287, 63.55588582254226, 62.73900908808555, 63.25989984696912, 61.217984537924494, 63.82699612648257, 63.65445890734273, 53.686449373922045, 34.15753702963553, 18.253577216978996, 8.482110788745265, 3.5315959540105637, 1.4528287514563532, 1.67388336072045, 2.502530515193939, 3.214633878200285, 5.6983664343434, 4.589814899429198, 12.231179860330398, 7.223504079926399, 9.647980409283793, 9.4272147070977, 10.515353737338897, 10.434174403067559, 9.432697200006055, 8.892887869188863, 5.073983448167001, 1.5208272059117596, 1.0668101618366859, 3.909044655099992, 12.068866299044702, 22.455518245697025, 25.735002140845022, 22.680246522349698, 21.708838209029167, 28.787518085971957, 40.06508542645363, 35.955669187730365, 14.494838522326562, 1.3642878638159845, 0.2791078022170452, 0.09925155524885464, 0.1533941834444, 0.07798336100794616, 0.1078510607382463, 0.12747651732136167, 0.14244278802746727, 0.12908400727375863, 0.09675347276272313, 0.2198550228269831, 0.13529233784685213, 0.12340374876775088, 0.12216806426764497, 0.150925648969508, 0.11974420037961776, 0.11090366064660973, 0.1129384131561364, 0.22076505867223586, 0.1856651776019604, 0.11092265962713188, 0.12118920308327484, 0.21818695830241328, 0.19610356990127795, 0.1011113256155964, 0.18018050900390073, 0.25986704434598645, 0.11927290308860042, 0.25672467425465584, 0.14685295702468965, 0.08439121918091852, 0.12324713741339023, 0.1607304712336871, 0.12206613626931945, 0.14973119532148685, 0.09704434868669319, 0.1350147995136438, 0.18769575493229976, 0.14757759959226655], [0.02942396245235878, 0.018259958484240116, 0.05668487948095126, 0.03612448153416476, 0.014440299635152183, 0.07374508681917384, 0.05863993203327541, 0.018902315547870054, 0.0590485250276904, 0.021315105634951786, 0.026347604242243597, 0.05453751204655536, 0.1256247832169456, 0.05710926920836491, 0.016408525069334334, 0.05883178726259259, 0.02288229553209197, 0.08631376279217583, 0.036825792894007704, 0.046277184324759635, 0.06211026819543012, 0.00972556280753305, 0.04990589767394047, 0.03490627149961168, 0.04571804739234429, 0.04279904555709612, 0.027157897354974866, 0.03680578267742549, 0.08527448025321768, 0.014649816063953745, 0.11542431484427183, 0.04328262706797931, 0.021299695776354884, 0.04398354389254124, 0.04424016036453747, 0.05184830594507437, 0.07087910592916512, 0.0061376862539609355, 0.040867910269768014, 0.0343420094389829, 0.011686158005989367, 0.022662615989364927, 0.03340460127219558, 0.024634721658883557, 0.04199675231751415, 0.0699690241186369, 0.029157530478832704, 0.10251211738514324, 1.7416709877790946, 12.460705195703815, 28.683514479667913, 31.19948156418339, 23.923865364443873, 14.753894402134804, 16.40847271488559, 13.64454907755698, 21.346509264361476, 24.135567449754287, 10.667042578420332, 4.19328926071044, 0.42978537659491267, 1.307250717955251, 0.8729202949231671, 5.838087633732827, 10.137933473433218, 8.892249503443319, 10.182293518897026, 14.444068343408647, 8.520317616001252, 3.112469373210784, 5.817933024898653, 1.4364735710044063, 0.12236951474821377, 0.2315260965617434, 0.09287335233943117, 0.054891843033293565, 0.2785663619156807, 0.438092925976361, 2.1340155024682326, 5.229605936234997, 16.456053026260868, 30.591835821828536, 47.019722307882006, 54.018607447224284, 61.84625410264539, 62.80201019779329, 67.41165807170253, 65.30893425787649, 66.18789426742062, 51.47042005292831, 37.89680703993767, 36.516277866978804, 40.48437110839352, 52.89477779019264, 62.29722076846708, 61.36822700500489, 62.191520737063506, 68.49622480330929, 61.231371587322606, 61.38374390140657, 62.80644247608801, 58.91295663772091, 52.88812545038039, 39.439396781306115, 23.276962580219394, 8.683983414403855, 2.6390912648170226, 1.1098066933693425, 0.204437043698084, 0.24827948951673126, 1.557854135190287, 1.0881271405566124, 3.7963944288992115, 3.123500303876016, 3.570746356441129, 3.364294118458225, 4.463419462403944, 3.358674832890111, 2.723689925286078, 3.483735438316099, 4.319247353461481, 2.5424202844019863, 1.0723850755922257, 1.7948439861497574, 0.7566503952107122, 1.4835547607752586, 4.665816214776808, 15.53200537158597, 18.358155450513287, 16.9872498127722, 15.63774952965398, 18.225830370380034, 20.04721433885636, 28.34464523100084, 23.694179211893392, 7.587090634530591, 0.6047840055919463, 0.051029315819182706, 0.02616518338571393, 0.04412997010794859, 0.04211751841789773, 0.04061125549337557, 0.02644905343561644, 0.07831451017409563, 0.028438135613537127, 0.017894839064308235, 0.06774199120099507, 0.023801018814406088, 0.04412022929999136, 0.06202121430467214, 0.008139120163245788, 0.056798796755291765, 0.05837065595833044, 0.023561597185870333, 0.03298207313843793, 0.018227470610591195, 0.0572274421011248, 0.0713303087339286, 0.05718778555972442, 0.025326500969728636, 0.04299937754929547, 0.09227494574001721, 0.024473322254996148, 0.06675994309085993, 0.04180789249198091, 0.044773135394338644, 0.04334717763647918, 0.028991297060143084, 0.035690163307252436, 0.04960826102403864, 0.040036762328518015, 0.026299926760276, 0.05771736682002103, 0.029939602827653292, 0.046851033975760785, 0.02954196106011589, 0.033400429923447876, 0.04738517728964648, 0.045288808328369935, 0.07377101123453149, 0.05476666426646614, 0.06904515272547161, 0.02368263907790665, 0.04410354007456092, 0.029128570440075094, 0.022298676344836434, 0.07297621033484898, 0.029125875725801435, 0.06964130702638818, 0.01740443937089895, 0.050849197056865504, 0.01826563711097885, 0.03160392884315262, 0.1196969404155689, 0.02758884862545998, 0.061555283459564375, 0.016761092138626886, 0.015127862589584004, 0.01602928090329853, 0.007031522691249848, 0.059365708410980246, 0.04533040690265837, 0.019967022629815246, 0.027640864080298814, 0.07085423105426374, 0.07252590385295692, 0.027719914777985508, 0.043063633173944495, 0.01654003363763613, 0.06228954809147024, 0.022188200720495755, 0.04658606331495028, 0.06754999424541189, 0.023653161929800146, 0.027667962525400425, 0.007990309499174116, 0.03692785495771997, 0.016679664653155114, 0.04893546728717704, 0.060644876061668324, 0.037591275608827995, 0.0532824914872406, 0.07863679570296118, 0.11673647790185868, 3.8212416633482906, 20.082754934987715, 36.021368888116655, 38.4722226665866, 30.07427711640635, 12.939104918510685, 13.098652228232353, 21.41590383745009, 31.662652684796242, 23.06060660269953, 10.374397481641463, 4.623664954016286, 0.9551068203103159, 0.15567073628546732, 0.6931012568454589, 2.8926313115704447, 2.0644706535723905, 3.6564521058913204, 4.555131341180494, 7.047887309905022, 11.336495068765457, 5.151924865861093, 6.799467917411559, 5.605605321545755, 1.7900399407071454, 0.6216788183777564, 0.6036394702330713, 0.3924149641346547, 1.333459627724463, 1.5307777687426538, 4.91165223621553, 8.24924849694775, 20.567552043545632, 37.12692422251548, 50.714053723119925, 57.66561154396304, 62.78396337263046, 62.05559099874189, 66.34009791958717, 66.70707487290906, 66.24889496834048, 55.152419536344475, 40.3334383041628, 43.283209723811, 43.034566756217714, 58.98418295768, 61.98260353457544, 63.018442661531516, 63.55502290110435, 68.57575478092318, 60.72679004361553, 61.76829307310043, 61.72094222038024, 61.71915361958166, 57.63977881400817, 47.30120335855792, 30.948261599386896, 14.803700658582873, 5.359545725007211, 2.4160140608587573, 1.0202987576203963, 1.4965242003240895, 1.323653824867741, 3.090003017456301, 4.578497880889524, 5.702579059908468, 3.93228960133368, 3.6930546837468303, 4.574287216509543, 4.591310303057394, 4.309567924468748, 3.9060513963622436, 2.570444638690641, 1.4495018461058218, 0.7700375058958608, 0.4744578940012763, 0.12556873622440523, 0.8035519526850793, 3.8725085123892757, 13.921170311589396, 27.110332212140484, 25.02690842074733, 17.513673074783817, 14.376620246518044, 20.361868835264637, 31.818647307734338, 30.31457131908786, 13.322196929685532, 1.8459649720499594, 0.023017563676882177, 0.06544546644774175, 0.04980855471184177, 0.02121927378128373, 0.021175530160807317, 0.04335085868895535, 0.053271207012115955, 0.07901433149292585, 0.021392505413161653, 0.03589822129616815, 0.028608707005097985, 0.11967096237405656, 0.09536008140252483, 0.060026455415232535, 0.04398650099192897, 0.04297176007962516, 0.014549639534145115, 0.04449529445640022, 0.026859795306659034, 0.07457100621034062, 0.022988802820984876, 0.03875500913108549, 0.056678325598759044, 0.04189796911011781, 0.04458460498661284, 0.04893324563219663, 0.12062592927606837, 0.012843514803887136, 0.05839451193629254, 0.042313920379045515, 0.059297802377372026, 0.07975143065015156, 0.07806340953515423, 0.08871822933396024, 0.04626395398630731, 0.03511460144974051, 0.031726851481043046, 0.036352990240219145, 0.04288680475926207, 0.11527408500232043, 0.11944262220734551, 0.1594463240114912, 0.19684607763924908, 0.07547099864290607, 0.1427151169627905, 0.12374450467647084, 0.2087496284155115, 0.2011445203735944, 0.1149321876225933, 0.12092556158501296, 0.13641035124178857, 0.2703238687207622, 0.1618141332460988, 0.23835379389985917, 0.17486316933026239, 0.1366917200146183, 0.18871354870498183, 0.13888090818880067, 0.16229319866866837, 0.08634622959840683, 0.09847186160303893, 0.12817748011119906, 0.11816416701842701, 0.159596155487722, 0.15182528134074905, 0.13170692378715163, 0.14324869720205186, 0.19579275270863888, 0.13389574423913034, 0.16013315247912563, 0.15238613431011477, 0.14271563790257902, 0.27598669872649256, 0.16613456270387097, 0.1198899256245744, 0.15756655874992573, 0.07620840423530148, 0.14900711965897392, 0.12869144849959882, 0.1137277365271603, 0.12165721385709702, 0.13762718997895718, 0.17912329234663518, 0.08416864765627731, 0.16613647792368166, 0.2747050336291713, 0.21976220361407728, 3.3050756444854126, 19.874426088025494, 40.24490256463328, 45.4919748152456, 34.95446851176601, 24.386785453365697, 25.459991039768344, 22.42471391154874, 33.06786729443458, 31.496026477506085, 14.077358111258476, 6.418281687844185, 0.9765331963858298, 2.9996754902024425, 2.866356089230507, 14.355493380177407, 19.38423768166573, 17.79823906960026, 24.22047107450424, 26.778221207280314, 17.057628900774066, 8.270244944480158, 11.117106118509847, 4.250439174713628, 0.7985110941433138, 0.4718191194678507, 0.3085043731956713, 0.22623120326428647, 0.7775308876749009, 0.9642966884759165, 3.539537773016961, 6.826485693454743, 18.68862102108617, 34.04111716055101, 49.13309927909605, 55.81642581570534, 62.85329126542615, 62.88947120789559, 68.17694387128277, 66.21582938778785, 65.49984778127363, 60.25691363119311, 45.38495686746413, 45.8303302334201, 46.52526832395985, 62.467628140603345, 66.18183028313422, 61.70815921598866, 62.36386968243507, 70.2376865571545, 61.509616682606364, 62.72896389807425, 64.29755895368515, 61.315784915801025, 56.33541422505533, 43.56328264359505, 26.196159124374393, 11.01440473910301, 3.638875720001036, 1.7575402846259458, 0.783135341780801, 0.7903940555068755, 3.7406023904200527, 4.759071546216165, 9.500938596264008, 9.138673390111617, 7.055742346471356, 7.71041730719228, 9.462171850665923, 9.786882323603477, 7.632425388982219, 10.544884281773722, 9.920195841020155, 8.84604496340598, 5.462823202533107, 4.56850613317182, 1.8655622365974613, 2.15233983532075, 5.9345593087134825, 18.995836742462654, 25.1332889833758, 23.618424515570364, 23.13983259662505, 25.32807976968827, 29.67953174344955, 39.944076384267504, 35.040521390976444, 13.369978262532143, 1.695472453871081, 0.12565780926736134, 0.11767322723303111, 0.15481434191667265, 0.15091395846778347, 0.1755911060759137, 0.1465100560697817, 0.12487430050368271, 0.22674990607605827, 0.1433643918003767, 0.15527048598854773, 0.08957387293658911, 0.27845601461106734, 0.10392404807310912, 0.13879945772069116, 0.23841736387581597, 0.17692298057579225, 0.13777061696014098, 0.17159211178941114, 0.115477642224681, 0.19244793622243792, 0.167630992889885, 0.16533924086439997, 0.141543937065909, 0.14602804886958293, 0.1388045292227499, 0.15107307492965652, 0.18807273147807968, 0.12273737484769476, 0.16746859757169602, 0.17258808737800968, 0.14518901405315246, 0.16004155900689865, 0.16555494058036035, 0.16774900107374116, 0.12219775783559009, 0.14972324332883283, 0.13044831793635123, 0.17269140199547814, 0.07194645026878965], [0.01588588073519209, 0.04338865363669973, 0.03478707204903326, 0.04543511963058864, 0.02458503702655435, 0.0654800170131268, 0.062242169383793115, 0.05453255162724564, 0.057670359664987174, 0.07768997997646371, 0.028562908353764686, 0.10584128269505118, 0.04297136554434415, 0.05371488683346299, 0.04036224244402782, 0.02922047609313121, 0.022084732885442434, 0.027703964827401985, 0.06434136520951025, 0.03771796356886625, 0.09686702231485998, 0.05978401156983549, 0.04820483391203227, 0.029914316180492603, 0.06000191378857821, 0.062304969441386006, 0.016960738482134, 0.13100984506309032, 0.01921324573847796, 0.049693909653973196, 0.03038968139838788, 0.049239500771246614, 0.016952102756007545, 0.012885950329232843, 0.040461351238791986, 0.08399086929256878, 0.018418343332145485, 0.03991215046675455, 0.03069292198145582, 0.023367378575306748, 0.021758710762726206, 0.07385450715739882, 0.06999306395770082, 0.013317960716273277, 0.04766146306909862, 0.06299218478342218, 0.06559473867978781, 0.06848451426072467, 0.031790930905469486, 0.7416012414520787, 10.81164271600785, 29.02309956089143, 33.35583594537551, 35.07463424436508, 22.09035146620966, 21.77754048378237, 16.68532536875817, 21.41312679936809, 23.72401079823894, 14.72487964937764, 8.811876216242391, 3.021689057350159, 0.6147748952911747, 0.7884671911597253, 1.9110506989302176, 1.112510554732815, 2.178110052501002, 6.1010276406042045, 9.896835184866383, 10.332413411909535, 8.956098825700822, 8.119990219992976, 2.138776034116745, 0.2836696106579996, 0.779136301529023, 0.08384263894009976, 1.0764906939960297, 0.7221637522020649, 0.3523269313718042, 0.2927499588939452, 1.4961610133609464, 6.414981993936724, 16.490848372059485, 29.551042741344823, 40.54319097149757, 45.72512834302841, 53.22317431049963, 55.81419006470711, 58.62305033591486, 49.266302970147905, 31.531935776433638, 27.14793205261231, 36.600746108639626, 48.82075309753419, 63.38030092177853, 59.21142155124296, 65.05456462983163, 69.05972034700456, 60.55563742114652, 38.539734501992505, 22.964922343530965, 19.538663356534897, 10.500682111709349, 4.145481942161437, 1.0560096704190778, 0.31434781609043, 0.049293701491889455, 0.24781663451463948, 0.6507190052540072, 2.200154508313825, 1.091714515801399, 2.1606030435331407, 2.8861419952684835, 3.4482218084796785, 3.2472942288844817, 2.654697149991989, 2.6414076695519113, 2.976981636977965, 3.692890189347729, 2.6159693829474913, 1.1591023062506032, 0.9266172974340378, 0.4984785195800566, 0.5627146855958047, 2.0148749793729475, 8.197011841881661, 16.7138704176872, 19.28450357529425, 14.823407626921131, 13.1114891652138, 21.50144876972322, 28.322772133734922, 25.21648245473062, 22.343803259634203, 7.7700417464779274, 1.2571518772071408, 0.06859509905259456, 0.017579637933522463, 0.03698002554536347, 0.05349458675951727, 0.07939267167521101, 0.04366280586128274, 0.03244206925193149, 0.056346096248636325, 0.02859810243300613, 0.028215903082802415, 0.036031830860602285, 0.08586108143771849, 0.06197979193060629, 0.036632313558291045, 0.030968035646383802, 0.06700914383174912, 0.0450956009538664, 0.10251567969399114, 0.0033028432470370806, 0.02206341265850971, 0.08044457934316128, 0.03082548009021388, 0.040861551739996484, 0.05695386827292462, 0.030526587056116234, 0.05667948622196432, 0.04807912654453709, 0.049419140728611144, 0.00550759569441359, 0.06752921794090541, 0.031246918463899247, 0.0307215181284494, 0.048402737405511646, 0.018230157663985606, 0.03526717552074021, 0.03968680953426708, 0.03610830558764358, 0.07930167575156497, 0.11867999700048279, 0.015522608544767625, 0.07688449215023749, 0.05576799480965542, 0.10628440327221349, 0.02256480954407204, 0.026861536241466963, 0.049643547033831004, 0.06901078602118839, 0.05502592374180114, 0.023656210959738782, 0.07444562826065287, 0.0789056159555912, 0.04635783806142788, 0.01167436408239507, 0.03717026815960004, 0.022347411028139537, 0.07415329676962669, 0.051750514821539965, 0.04769329785279209, 0.022826351961421392, 0.04388527013361455, 0.06416216192226257, 0.020663306537655093, 0.03361073638042135, 0.0458785696255584, 0.03484527174864085, 0.04076772129103061, 0.003370807216044576, 0.055231836684528864, 0.14908023509046725, 0.08061679590853953, 0.03580033441164321, 0.016024909414080604, 0.06136627807732552, 0.040610129344126875, 0.021154495301626382, 0.10864779984037723, 0.05927597653240927, 0.030471009292429498, 0.02880106402200557, 0.07615172905066321, 0.04873875506041993, 0.02630519169953562, 0.04574994346307171, 0.05685742163369733, 0.06807833444327116, 0.053694424625005455, 0.07398992851977387, 0.05495612547101994, 0.024525914190998, 2.3859684601906808, 17.287832806187293, 35.268595449386105, 38.40389890055503, 35.82570145207067, 20.95680609826119, 15.885033395982559, 23.373011619813983, 34.069687704886164, 32.299565192191835, 17.93353730632413, 8.570004240159067, 3.169361636523278, 0.5389831203126139, 0.08067011562806946, 0.5186162744798969, 0.9646601205871952, 1.005552729531642, 3.0261855644564477, 5.530197264686708, 5.806803299534706, 6.188599457663875, 7.233590945120781, 3.3958324261250037, 3.03266090731467, 2.166049989961809, 1.7394891693707437, 3.8295825835197204, 2.0456837261876752, 1.4805713079629408, 0.9903110731993953, 2.6946026086807255, 9.340523462141714, 21.69846353992339, 34.35665222906297, 43.7573262183897, 49.17749266470633, 57.07162741691836, 60.201902389526374, 63.435194492340095, 54.44837762463478, 36.1209657115321, 34.052856814476755, 39.10801925966817, 53.85846099545879, 66.11146296224287, 62.82124550111833, 67.17004006908786, 70.27379589696085, 67.0070577436878, 46.90558525823778, 29.967378800915135, 27.448554269729126, 16.48841650255265, 6.588778293901875, 2.0941750080354753, 0.5073124326525197, 0.45540608405586214, 0.8945446281183151, 0.9590224489088982, 3.24955792677018, 3.6367284674798293, 3.145208661594699, 4.799114042712796, 5.0183161900889495, 4.114582000240203, 5.185266973510866, 4.846773291787794, 5.306161776665719, 4.314158078162901, 3.029830917235344, 1.4675366590099952, 0.5346560718551759, 0.3080449043022048, 0.6935216858983041, 2.427306809732991, 9.109075184791319, 19.33535514339324, 28.869878053665165, 22.021084370151645, 14.340036299920852, 18.936069626961988, 25.32244920730591, 29.183746114853893, 28.03819633299305, 13.303666672398968, 2.345221653099983, 0.07653517903940332, 0.04046385634630438, 0.03943129239844219, 0.08517512631031775, 0.09826406025357785, 0.03845209413538537, 0.08499504202195714, 0.01945839387424771, 0.048267791017649636, 0.025306668868588827, 0.06553971824506599, 0.05183195762877023, 0.08219120618436607, 0.07106351095341867, 0.016761557537040884, 0.078574443806804, 0.09617204267171123, 0.08611111721444516, 0.015728640231123615, 0.014012784269007464, 0.04858666362481252, 0.05247414998349644, 0.03406409572269167, 0.017001957842899908, 0.04114015110497994, 0.031282859478866866, 0.03186824258356806, 0.04330271006291432, 0.03753194209909247, 0.04241399827503389, 0.008241039543082158, 0.07235638391707214, 0.04505345079627249, 0.10383611650116022, 0.01615505913392671, 0.0010931099114391293, 0.04620084366310508, 0.04185925868730392, 0.029020711005995833, 0.03664876912690459, 0.27725264369960756, 0.12179265820210981, 0.3222283480628845, 0.22232168804733987, 0.1322977614378737, 0.1392704332547803, 0.1622023406408487, 0.11096472551505412, 0.11299048415234975, 0.11716776242059086, 0.13808665887242363, 0.21695940965606322, 0.1221963482338094, 0.24302398846034082, 0.1292176742947871, 0.22474767399891732, 0.20099167051094197, 0.1492345711636928, 0.1614952568084963, 0.14789572526370326, 0.19238464203813385, 0.19487335526895141, 0.12877827690493676, 0.16051909225361963, 0.13934344143396424, 0.14237236922546742, 0.09930757925875726, 0.18874834441850263, 0.18253138769538174, 0.2320336298115792, 0.13110923731038648, 0.21211908228935736, 0.10220538344114058, 0.1056182515176554, 0.08973337244242431, 0.11053720248803017, 0.08176153045027487, 0.16341444495464527, 0.17636669349045525, 0.20911140577687373, 0.10985150783052368, 0.2785146356590333, 0.2769374444840416, 0.12062672600750962, 0.11572431487542008, 0.14989709932236903, 0.1814964182314373, 0.14122021895262504, 0.138872557830426, 2.217135919678596, 17.415821706095052, 40.51148645339474, 46.488715756324034, 49.45393739208099, 33.142141296017556, 31.61626869632352, 27.188508972044918, 31.18969721178855, 33.200706205060406, 19.76405059137652, 11.528895170457902, 4.014190161420453, 1.041791323692568, 1.218061781217975, 3.5657428829900684, 3.511559751725966, 5.514492584813026, 15.655550226088494, 24.641394345991074, 20.25981660812132, 19.765192001096665, 13.754355830530967, 5.815562442425759, 1.8173123030893266, 1.9981062340159572, 1.1697837782482947, 3.184364212136115, 2.2329322849550555, 0.8422979219786583, 0.6273462142675155, 2.0864567641289007, 7.397246937597952, 18.773620743905347, 32.96761543520036, 42.63999985110375, 47.928833576940725, 55.225854150710575, 59.98132790288618, 65.69753916032853, 62.91446455063359, 42.56651032355524, 37.63372190536992, 44.718683458143666, 61.327646163202104, 70.55066816268429, 62.635784072260705, 70.58849550062611, 71.60464040694698, 70.44008085804602, 44.65570196028679, 25.58642471990278, 22.725669530130205, 12.061654040890357, 4.493319199931237, 1.4251939375554363, 0.41117216730790757, 0.3758420002075934, 0.6400565935238716, 1.2184818425486166, 4.373773692115661, 4.2555814020095335, 6.761487116736751, 8.292138634189483, 9.404776788526966, 9.134029303827594, 9.322408976093415, 8.340164134579322, 8.789399073969934, 9.767397949772498, 7.31696141342963, 4.751616591407407, 2.467294147899074, 1.5194557246661957, 1.2521384752565816, 2.6584162923597523, 11.215094770154646, 20.916456676298573, 27.551022268110707, 20.786308511610954, 19.211888736294163, 29.07438651207955, 38.66140642473775, 37.72584269123693, 32.91079598088419, 14.143377484813815, 2.4417301003010046, 0.19752784992658323, 0.12943801650356862, 0.10758577981182646, 0.15455359623076456, 0.15686112966748977, 0.17559515102015388, 0.22474945132290164, 0.14247626606975833, 0.1390437784815027, 0.09005614826756139, 0.1271657384331188, 0.10324599131220773, 0.27091381770949213, 0.12945382855832577, 0.087623160272356, 0.17361055428702987, 0.24477753307550187, 0.3449919459319884, 0.14339146534762076, 0.15368883618183676, 0.25314676785661333, 0.10879685756780448, 0.14361312522763206, 0.19245429475220943, 0.11207124759112636, 0.16463345938151883, 0.1307676846702253, 0.10478759770311656, 0.18782401337258278, 0.12490855229477729, 0.08199356316078095, 0.12535400177922942, 0.09488864621568112, 0.2104783977472013, 0.1514479064292485, 0.08396997807487365, 0.2746165045086415, 0.22445286804389572, 0.1374897231618243, 0.15597669648066645], [0.06342692052825324, 0.07885926763617224, 0.06556594909559335, 0.06666999670767015, 0.06300024785882523, 0.02678701695385239, 0.046642788295303626, 0.007790260001896851, 0.03134378453626508, 0.0342605589708734, 0.04474276383858054, 0.08378569562468799, 0.04347374685288918, 0.028630103840823137, 0.023297572643646312, 0.04348278285995607, 0.05698373038021307, 0.08870371962867438, 0.024508255864343336, 0.0157839220933496, 0.06849481814330624, 0.016401344910264015, 0.10919726108230891, 0.022075221903862494, 0.04732802713049516, 0.08321607860946849, 0.06655458556187731, 0.04938639813072739, 0.0811183077072905, 0.01678948718754034, 0.07378260214482585, 0.030111204607472308, 0.04038782978069879, 0.062498992699528896, 0.02868553221736464, 0.06580895984605437, 0.03732867982058275, 0.026433892555594928, 0.1046333305778042, 0.06512458285977764, 0.05664476328679631, 0.03533856725440391, 0.0100632754319738, 0.02816432429808042, 0.042542498033013076, 0.01689213530851468, 0.012563887923475237, 0.045014897421483076, 0.11214145954938666, 0.03889111231171316, 0.8533427035135608, 5.978839926181301, 23.429876181387133, 32.28113397475212, 32.12774576679353, 27.28369705138668, 12.597035015783003, 14.4712640969984, 15.44546513788162, 22.158304568259947, 17.157137470860636, 13.37981164455414, 5.02776223805643, 1.5511477402141018, 0.13989548439220076, 1.8760505318641665, 0.6577173103728603, 1.0873876512050629, 6.613921177002692, 1.9265072888905004, 3.2183285057544713, 9.299229729560114, 5.406498947451192, 4.944137305982651, 4.5238788762400235, 2.4613336161259682, 2.403293569241801, 0.7178317394948776, 2.5456251059809043, 0.8456641736049807, 0.45117936247298795, 0.712520543846392, 1.5970702373212384, 6.222304384554587, 11.345067408777053, 19.018886550780266, 20.59665995259439, 20.397295682660996, 23.46050597006275, 38.63086292820592, 34.62959427987376, 29.044356846040298, 29.311886026013283, 39.40449553151285, 41.77337961812174, 33.5933276145689, 29.28027564479459, 22.170057950481294, 19.443747881920107, 7.733551936764871, 0.44243394787753787, 0.3246693493377778, 0.016380447946909456, 0.09209014235004302, 0.029864072303978667, 0.12145072251798646, 0.4398464399480051, 1.5432333777989111, 1.1127463872394254, 4.051544363460233, 3.1856882572174077, 3.834970449247668, 3.413752509701637, 4.9900226631472195, 1.8658752907668392, 3.2115052976915917, 4.318474156241264, 3.9660791043312322, 3.001334897933468, 1.7060606470031126, 1.2563355339150275, 0.4110755482988973, 1.6983669179101146, 5.08194487902426, 10.237882329571633, 22.643807703448882, 17.81547200295233, 10.628577855325515, 18.76314409317509, 17.437008388580814, 30.168404194616503, 28.630888039065947, 19.589369796937515, 7.862403758110539, 1.3184891665174117, 0.04151412841653632, 0.05717621380162816, 0.021792795929697253, 0.03758477535279047, 0.1164938655171183, 0.052790249352373426, 0.03544364387409822, 0.017458917798414346, 0.04298171539220118, 0.02325509881390439, 0.05823052315522106, 0.013566318760445763, 0.07843925227080623, 0.04958819718130174, 0.025440165435054132, 0.07193384812243524, 0.05590630432350501, 0.03212769549610394, 0.07077791337524691, 0.03339334361014828, 0.012419099221006038, 0.06179125003156163, 0.040814927628924774, 0.05407303293806411, 0.0354596397899572, 0.06242597685946573, 0.04801793910202481, 0.10028988017790741, 0.06076082346900817, 0.02989286571861275, 0.04390781993166574, 0.020585933572522575, 0.04907119508472182, 0.02070661348801467, 0.02083903178572655, 0.06375040115428067, 0.10149852177428623, 0.023976389746812564, 0.10674066991815645, 0.02361772078720312, 0.044031788279572805, 0.03266698883606061, 0.008835041136931508, 0.08678385732515205, 0.05973577484368317, 0.0299537428955157, 0.07182191501581861, 0.012668797919046015, 0.0743324157872027, 0.04751569951974577, 0.05080668300750756, 0.01078900584440318, 0.0075604647469346324, 0.025514278696068836, 0.010702186057554379, 0.05269574857647381, 0.04096832141400345, 0.06883384269331733, 0.006369495362554107, 0.042102740581838355, 0.027229300579957427, 0.03238395382199557, 0.029613362369878642, 0.019508260452458938, 0.04157150840206493, 0.02327299079737596, 0.06818161075634342, 0.06074480840095109, 0.013062277913934762, 0.11108461061432479, 0.06204914970083102, 0.06156444587113877, 0.013068391295570522, 0.021467018955116792, 0.07203828122827315, 0.04365941209177818, 0.025034945142725785, 0.04063278639448747, 0.023441200722910227, 0.1589255527623238, 0.052146823596089124, 0.026460019984252514, 0.023465667655991933, 0.08102315958709487, 0.07653422142949796, 0.06091347031836068, 0.06673954216943634, 0.028188998074901682, 0.05528719802837699, 0.11820684577668868, 0.05489389231849102, 1.6048129960413904, 11.986936811477909, 31.76286728151383, 41.24303986949306, 35.23188206457323, 29.64312038113994, 13.470774350627778, 16.14088862173019, 23.521161502407445, 30.04140765436234, 22.83897895966807, 16.44005269773545, 6.582329917338587, 1.4524768413074556, 0.18378625503711163, 0.36864491059414806, 0.1201623771339655, 0.8090411258801338, 2.545006842382493, 2.1271285558900526, 3.7828875020627057, 3.532209069498124, 6.279033624356793, 5.265404918501455, 2.157667394607298, 7.2111618518829355, 5.316228049416696, 3.2311154325162215, 2.914700282196845, 1.7921267642128853, 1.3110084711543977, 1.7761633304818985, 3.3961699951079587, 9.76199390426759, 17.131489092303863, 23.095294083318404, 27.26037463834209, 26.395597919341057, 31.63402330490851, 47.48096558355516, 40.71992512672178, 32.88369828654874, 36.673074614617136, 47.617448376071074, 50.65976027519473, 40.84444469021213, 37.93859204938335, 31.970847037530717, 31.984989143187004, 11.026237549320346, 0.9263293096615423, 1.1476074327384274, 0.19053553561529807, 0.22341579949903875, 0.10119974748381685, 0.8463627845048906, 1.5152055914363556, 2.7500889474345795, 2.59789853326736, 4.746027704208128, 4.56364925830595, 4.594751202291058, 4.730529439064765, 4.803626729596046, 5.667915113510625, 5.816566569189872, 2.96994956270341, 4.018585667494805, 1.927751170531396, 0.8511746134008131, 0.4566399452667083, 0.18723689890917272, 1.6371828461847, 6.479216689063657, 13.349765308441656, 23.995417241127264, 24.945278013906172, 16.62282043887723, 12.911246284361809, 14.129963959417037, 31.725102701494773, 32.795615580774125, 25.54835419501028, 12.979514156618427, 2.6100716090971425, 0.16072395948633073, 0.04276011296878419, 0.004703258436488649, 0.07087200429410705, 0.015503513803254935, 0.056082209602238677, 0.058451106681698756, 0.046733684627519506, 0.023360319075084502, 0.05189358940227859, 0.09933620796448762, 0.022339024280588475, 0.053143580594370445, 0.12848865736516255, 0.04393097876961674, 0.05581047821549639, 0.07177158303919338, 0.05552518324205472, 0.08609953396503003, 0.05237202663275023, 0.03622486203488323, 0.06686419233559601, 0.007833799651463427, 0.03412661998863182, 0.029774756028106617, 0.05189883327412029, 0.019317370493926348, 0.045115749066274975, 0.05400780438175125, 0.025338566854536056, 0.02033995997701441, 0.0756666574987673, 0.023814471318356456, 0.04004505906073798, 0.09534285974598701, 0.02374887503983994, 0.02810904339346434, 0.051718898372904915, 0.09224430222304598, 0.02326318104150555, 0.039593346807504856, 0.25124107817969016, 0.17854377747543398, 0.17867217381154338, 0.17104290335649447, 0.17800221460000162, 0.13728772109795, 0.12563071273747953, 0.14559698651634878, 0.2445731714608208, 0.13034319535138147, 0.102197477413762, 0.12037393231425556, 0.14637343194936553, 0.08846555821477406, 0.1787621278556124, 0.1763245892981368, 0.15942243739001213, 0.13829981517647544, 0.15786911751474106, 0.2812940026483228, 0.17429137662533792, 0.18535788441377302, 0.2286887367165858, 0.17133747948513878, 0.09184681750353306, 0.1453354900642749, 0.12510179797367704, 0.16519656464938196, 0.24916078174306502, 0.16254279011439893, 0.24663362622020707, 0.11032334138308802, 0.1184885516282051, 0.1751210192038167, 0.20148241111347753, 0.15127348353064832, 0.12890521767399005, 0.11173481241829934, 0.26711711660027504, 0.12480416515421484, 0.20745950570750624, 0.23512447282912272, 0.12361968597096783, 0.12483313859951113, 0.14140437116786359, 0.22770883365263864, 0.06459089536820689, 0.17631138194232218, 0.1660373308245213, 0.11128639051270102, 1.3031236490895672, 10.558326244354248, 33.79366267111994, 45.97952935003465, 45.65345879523985, 40.3896576358426, 19.782415128523304, 22.702168649242772, 25.97035219592433, 31.48761299348647, 23.44697771533843, 17.582530283158828, 6.480763573800364, 1.9435953396943308, 0.4735125108591972, 3.301771292763372, 2.554840224404489, 3.883380587062528, 14.54377499318892, 7.299279858989101, 12.060995082701407, 20.155869876184774, 15.852722871688107, 12.007551808511058, 9.062938305639452, 8.958925874002519, 7.335566195749468, 5.212132757709873, 6.095327946447558, 2.6395320411651366, 1.1438995671849097, 1.3681238192704417, 2.432847647897659, 7.410578583517383, 14.12758602250007, 22.234659387219338, 26.211368114717548, 24.51328189142289, 30.868702203996722, 54.64111112779187, 47.66168094450428, 39.193511239943966, 41.898342409441554, 50.665310428988555, 51.78788492756506, 39.63127128539547, 34.59317899519397, 27.52050034461483, 31.00584983825684, 11.059320780538744, 0.5907608580685432, 0.8916767626520127, 0.2723173520738079, 0.3362184925185096, 0.1419299840927124, 0.5036150471818063, 1.6325165739943905, 3.4743136600140607, 4.158262985367929, 11.372401425915381, 8.846692154484412, 8.590227000174984, 8.882588705708905, 10.574161833332433, 10.405614645250383, 10.08167197627406, 10.373086429411366, 11.344313333111426, 8.238326657202936, 4.5452386333096415, 3.271403322296758, 1.2480109160946262, 2.2877329443731615, 6.76057271419033, 13.952057996103841, 29.17588568502857, 26.2162200866207, 19.76728850795377, 24.644953896922452, 24.703046160359538, 41.002888833322835, 40.08039443723617, 29.663806961428737, 13.548861876610788, 2.4489433390478936, 0.21920538026719324, 0.09830843206615218, 0.09547897824837316, 0.14278671554019376, 0.2009861087126117, 0.1432210567497438, 0.08612219484583025, 0.15485448492390497, 0.17919597876889093, 0.0882395239727151, 0.19280337037578707, 0.10692112192872072, 0.157970838669327, 0.2618011712066589, 0.11438770595216945, 0.16833059970409642, 0.13613471280663245, 0.11346640861442975, 0.11770661334477125, 0.20891174794204775, 0.10076683885868519, 0.13733137278787552, 0.12795789632946253, 0.14263604136724628, 0.1391831298749293, 0.13427144907895597, 0.13062932919110024, 0.20233557259123172, 0.13962226679488537, 0.17469018667695985, 0.12892479888133465, 0.15749921962138147, 0.13257966647225042, 0.14725533704603874, 0.11064830821968856, 0.1270793850022939, 0.14617855450318706, 0.13636786400550796, 0.20553883135078416, 0.23662675592687824, 0.2161437558430818], [0.09729593962190614, 0.06066860563512291, 0.06951347759534275, 0.049998042729472926, 0.019145197978603746, 0.07587201502774993, 0.07831264858043964, 0.04766921970933195, 0.07625391751888298, 0.05434157356860177, 0.0740958861405811, 0.010534161908341753, 0.02501494258702282, 0.04248819389050046, 0.06782110510093552, 0.006098165693167117, 0.023798322184912624, 0.019754433230827415, 0.038140434246029586, 0.018718201637027726, 0.10603064430817481, 0.0748752733512271, 0.0018010512834617629, 0.09106031333607051, 0.030838438467453086, 0.04699133914865313, 0.016005645175614668, 0.09039491234767823, 0.022474035785924044, 0.03349464724681551, 0.032094797765415524, 0.06467204706202592, 0.04029000801364741, 0.08254958977622372, 0.025758601372100176, 0.010556256841687907, 0.0417176166909837, 0.03698797370757788, 0.02503340339077817, 0.03304869597477298, 0.02420983205909931, 0.05657207303410096, 0.048129753465013164, 0.03847511890794962, 0.054350444866764935, 0.05965188821597446, 0.05466982692239746, 0.024814294583554712, 0.032733818516135216, 0.09119976432092729, 0.02798380717004259, 0.17046813823042378, 2.3085747034318986, 15.950416364977437, 33.504642824972834, 33.18959020799206, 32.66097237986903, 26.836797883433682, 15.139442797630066, 17.493292439368464, 21.78605594942647, 25.837674102475567, 17.670305082874915, 13.106565610055002, 4.678633539907394, 1.4638640947880284, 0.39830461745300605, 1.030948299073404, 0.6075573051648756, 1.6871642609757764, 2.0617889781152052, 0.8756573738590364, 2.8372229299237652, 4.945236550223443, 1.7917181022705573, 5.23625974693606, 7.289200838535064, 3.356009582358022, 2.9301200999367625, 1.049297391887634, 1.3559627556993117, 0.5325553974797649, 0.6538339187541317, 0.40906714155308666, 1.0950802771314498, 0.8073614934279073, 1.3925391027042944, 0.9072372341348279, 2.4493917149882165, 6.2549934175706685, 10.795335462016444, 10.455866090713009, 11.401044534098718, 10.537516109405026, 7.852188925589285, 3.2663549867368515, 1.1090163357796208, 0.07192412646667612, 0.09588918768830838, 0.18426821627203496, 0.1477893462945377, 0.0747488305393246, 0.11279281814612689, 0.27436473737320594, 1.31896794082657, 1.2839670383161115, 2.307757624695378, 2.637276678316055, 2.296694334476225, 2.1547481706065517, 4.378180475004258, 1.1301977475804668, 2.9657440464342795, 1.7247902097240573, 4.109473358238898, 5.919254710597377, 1.893498460131307, 4.072055662831953, 2.090950084309424, 1.329092068537589, 1.765009090304375, 4.007156616257084, 7.274093829816388, 11.063334345817568, 21.28297078994013, 17.79747420741666, 11.00407321606913, 15.553718632267369, 22.17086791992188, 29.111423492431644, 26.10124953331486, 19.316645437671294, 6.0021540041892765, 0.6375206586334013, 0.02482752875244666, 0.04122695652768016, 0.0210896382979568, 0.019184423595546715, 0.0747496732360413, 0.03998238157721297, 0.03782857134337387, 0.023530110972182407, 0.021242227690714984, 0.018648732784053972, 0.013474524190138667, 0.04484764893629378, 0.030378898710853634, 0.06039805402378402, 0.03458249209929378, 0.03530688951873491, 0.009551888759878856, 0.058470247388486905, 0.02361845240117081, 0.016915715494824034, 0.042198444115779096, 0.02499115172653429, 0.026946054891713207, 0.0362872101006008, 0.05115496189964395, 0.057735530764705716, 0.012824708302955956, 0.04298402897773251, 0.06632520351558924, 0.018493764688290896, 0.0976459881771476, 0.06588097977181596, 0.031243396374667366, 0.03650852907148581, 0.04455730927387073, 0.016800530344968843, 0.06382236745388759, 0.024257208851556626, 0.09473962679265008, 0.022760206014819206, 0.03264026768926171, 0.03847321517945778, 0.05620378392538237, 0.015020285650426823, 0.0680342767267458, 0.08058023819279286, 0.02052254362722799, 0.05118486614176824, 0.08438158945571031, 0.028075241679025274, 0.023863317084408576, 0.05453365479385661, 0.03829000908280573, 0.042930322383800824, 0.040884346686183445, 0.05748524983984329, 0.03709672754930873, 0.030632537016044223, 0.04921459525282826, 0.0297717280655859, 0.015931106735801986, 0.05434556488668727, 0.018881571802100348, 0.03257053453595408, 0.046489279597036304, 0.050812302262432156, 0.024517418275917732, 0.0413541232926711, 0.017899483472349185, 0.1233657891111028, 0.0059021070351704, 0.04969990429198069, 0.08441487597602029, 0.038874687386616584, 0.041738867970003236, 0.04490567626611841, 0.012575567891490797, 0.04982226768568639, 0.054555871343660745, 0.01950842516136266, 0.050570295087151954, 0.023955870081760713, 0.063397774713174, 0.03393339346193018, 0.037576022798255566, 0.0652632447740724, 0.08101863966834161, 0.07445256901724685, 0.02624174621286652, 0.05920103781165616, 0.047740837438933315, 0.07042155991638861, 0.05844398206400295, 0.31118120697717516, 5.798508957509072, 22.917085116909398, 38.61165115910192, 36.91919549818962, 29.15122574375522, 24.038990851371523, 14.142788148695423, 19.858981755472, 29.94723939126538, 33.52790248009467, 24.811231013267275, 14.138711825493845, 5.1600319147109985, 1.0283792691846048, 0.30034409655678657, 0.11361784121442227, 0.08200199778882727, 0.39413608790886023, 1.81177428412822, 2.043022275451691, 3.2011362669929384, 4.5532098700923305, 3.832301031197271, 4.96617857486971, 3.5555226572098273, 5.187800824642181, 4.810204054078748, 4.392144112817703, 2.3841045989144236, 2.4499687936998185, 1.3244785031964703, 1.2975074278731502, 1.4258893002425472, 2.257307609242778, 2.5065818332856704, 2.4488158620172933, 5.029158601837774, 12.267903051068707, 16.541262595884263, 16.95795362995517, 16.892116646612845, 17.540260860996863, 12.517229491664517, 6.551347605643734, 2.575259348077159, 0.6654478729732576, 0.7454348067122122, 0.93961940297196, 0.29204892715619457, 0.40470350473638506, 0.17553847583551563, 0.7512093323373026, 2.7026518025705895, 1.9955504421264896, 3.1386345240377613, 3.766614078514038, 4.306897280677672, 6.150301435301381, 5.079234030938918, 6.8106378470697715, 6.316415773284051, 4.423413247831406, 4.474366797554878, 1.415875979488896, 0.4373747032255896, 0.20628800405369652, 0.4587606911457354, 0.2810948810750439, 0.8459914463662332, 5.2786085970940135, 12.229219655836783, 15.43390199061363, 21.789595888506984, 23.89175291984312, 14.767321655827185, 13.791649726129348, 21.488999166796287, 27.287242874022457, 32.743049936909834, 25.571533441543583, 10.499570119765497, 1.808369421670514, 0.0617117645789779, 0.09984165745516939, 0.04284673453038258, 0.027451441180141225, 0.044348420079557166, 0.04303651366142496, 0.009967471348993, 0.016726478370988083, 0.13178921695197784, 0.03142935655740721, 0.0020857368578999155, 0.03189184766773495, 0.03564862985043757, 0.03384192256377109, 0.03730235703950448, 0.03869298282229612, 0.02527732004020964, 0.024768718097719456, 0.0599716839590861, 0.013452433087232133, 0.035646569073921254, 0.06234831852658142, 0.04715080418053174, 0.07139703499213343, 0.061843190792827844, 0.04368301909116488, 0.03683417772633895, 0.028714362021175124, 0.06310359695025029, 0.05340344527916563, 0.03099512068494674, 0.017045463976119796, 0.0316608012954314, 0.013701207691713447, 0.03534172736709157, 0.026786145528838522, 0.0366737014584003, 0.12091531132858609, 0.004848343519223554, 0.04955034477696304, 0.02793928597032303, 0.0913195345070093, 0.2096004609859759, 0.17966506972668633, 0.14887035764273138, 0.2514549852499078, 0.11512426884784815, 0.1665714779688466, 0.23693104605040244, 0.09554674638615501, 0.14444077597750773, 0.14408503538898884, 0.10133817957173433, 0.14105722608585514, 0.12002104923369424, 0.1535551691608083, 0.12421773250905738, 0.16219524666666985, 0.08860569101788345, 0.10743211023509504, 0.1695132709198421, 0.18914242004675252, 0.16102150803612125, 0.14882783976293382, 0.07600496192612956, 0.11841394232525942, 0.2209805438835775, 0.1920733651927402, 0.10012315646294626, 0.20248923450708392, 0.1198196447184009, 0.12307563330978157, 0.1146389598086957, 0.12014815854209086, 0.13102950287922738, 0.22061504333490328, 0.06157771451398731, 0.15384239084537954, 0.17037179501306626, 0.11589401101152744, 0.13218044273314938, 0.16457162076427093, 0.10130389713712278, 0.1530288974003446, 0.11682363572500407, 0.17694041673694888, 0.16545963924257986, 0.17927462535519756, 0.15903764674740453, 0.1279740837673026, 0.11401148783343454, 0.24186488210914597, 0.12505759470044606, 0.4220451919301864, 5.594276045599292, 23.09346429763302, 43.57364162322014, 47.31503755815568, 45.089865192290276, 40.14024196132537, 24.28845359433082, 25.428592466538955, 33.4053833253922, 33.66854298499323, 23.29069675937776, 16.196387217890834, 6.595615965704765, 2.2215985963421483, 0.8372598826404541, 2.3748745264545565, 2.713884735299695, 6.391505137566598, 6.8316132118625035, 5.427337029287893, 6.359162744014494, 12.504951492432626, 8.042963204845305, 13.454753429658952, 15.113763040111913, 10.315170672632034, 7.632140036552184, 5.095253971315199, 3.59337279392827, 2.7543574667746022, 1.5266505773029022, 0.8947120642950459, 1.6773028094922344, 1.4308960831934407, 1.972387130222013, 1.6602613368342, 4.442527938273646, 10.1262330432092, 13.945634134354131, 15.319413888838985, 16.39123585916335, 16.98377263161444, 10.096212202502835, 5.3345661105648166, 2.045464441180229, 0.5620549306754143, 0.6591147773208157, 1.3347877177499956, 0.36185580876565754, 0.44045495890801956, 0.22446955343888653, 0.903489470722214, 2.8241768815825066, 3.89778892359426, 5.972094920373732, 6.367939537571323, 6.697462268414037, 6.137444886469073, 10.278492589150707, 8.43340769890816, 11.204936812000891, 10.01858457442253, 11.070128871548562, 11.331568571829028, 6.839049045116671, 8.01318015783064, 4.497793153409035, 2.049727934983469, 2.8385070158589274, 5.52506729479759, 10.139725016009423, 15.828945463703526, 29.13741703956358, 25.875781889884706, 17.207806648746615, 22.728285751035138, 31.4609291092042, 38.74898510594522, 37.73364820787984, 27.941886455782, 10.023867026452097, 1.3671256986356553, 0.12214005609313328, 0.14261719560430897, 0.09753816896268437, 0.15305148167235239, 0.1494300308366937, 0.17443791392349428, 0.1163726857292556, 0.13921041792679217, 0.19047645491457757, 0.07748650702377481, 0.11404776209664923, 0.125583085051227, 0.11880035707426649, 0.20113264601076805, 0.15125097586743294, 0.13088409939119894, 0.07870021246133313, 0.10600547065898296, 0.16292894439351174, 0.09845925179580528, 0.14227642437383053, 0.12643421639598187, 0.09642508917398031, 0.1774861777742063, 0.1975491778143952, 0.16167092076953382, 0.1631035358314553, 0.11985591898161559, 0.1650461662680872, 0.13318878298084583, 0.23931488184438598, 0.2628112428130642, 0.11400015739303444, 0.09106713917947586, 0.12515828163633425, 0.18871546392479252, 0.09566922852348897, 0.2577152872277845, 0.13167992684869997, 0.19782642503419232, 0.14496888634898972, 0.1996276049964851], [0.006803098254867139, 0.04185981410104902, 0.05293470289137575, 0.04076572563198786, 0.07356813583042353, 0.07015786479197203, 0.05151693078298723, 0.02794476924464107, 0.05168391879828227, 0.07160613869106577, 0.039680577409003055, 0.005255746683331146, 0.047236517927939856, 0.01143107754028132, 0.008811794198869217, 0.01021690000103967, 0.018008055368198023, 0.06315641105175018, 0.03912001172260892, 0.06694888335562522, 0.00677587675689269, 0.011900044966398949, 0.04529240894161406, 0.07810844018334344, 0.03141215979872692, 0.024508930021716703, 0.03159444084421041, 0.03266460247217648, 0.04778041737154127, 0.03343706424798697, 0.019675641087815166, 0.043101474086964325, 0.03947625409871821, 0.0420108636570794, 0.035488234021730965, 0.09049397517716692, 0.0656852443071623, 0.03089823354516299, 0.04945485957808072, 0.05412957405731563, 0.024766119144436334, 0.0340612726886907, 0.01829083182758862, 0.031212210850489717, 0.04319841485290278, 0.06936502507737569, 0.02893365660472022, 0.032363231143643784, 0.04927215143857945, 0.043800307152372216, 0.013479374484309267, 0.0342022137145602, 0.08794333905942979, 2.2734013392079264, 12.04835230304349, 28.541191277965424, 36.89891292202857, 33.06764371933476, 26.005953588793357, 20.398174293579597, 16.52499064322441, 17.726797019281697, 21.461320961675337, 19.131415428653842, 17.681423041128344, 11.541337909237033, 5.167643274030378, 1.2409246640820657, 0.5807166486497849, 0.7443769312193318, 1.404676019184051, 1.3853289283091024, 3.0547433610885375, 2.1134917005415885, 1.3700277622668975, 5.2290048330060905, 1.9294712524260245, 2.019485602936437, 1.6193591058254244, 1.9082053870924058, 2.4928912904954728, 3.143323962726901, 1.50156824579162, 0.4699965656524705, 0.16253304547600209, 0.04221446684471542, 0.03270880574540746, 0.11682879149673447, 0.36963282693778315, 0.35086042458011263, 0.2883962199332253, 0.2951529928513112, 0.5866325021751466, 0.28065958991646767, 0.17862486022133983, 0.09514510947009248, 0.10487011303344082, 0.1891865160676741, 1.3071019130368389, 0.4312813624499306, 0.37589994709818597, 0.8086780614910588, 0.3080597357644189, 1.129131966060208, 2.3044650400838544, 2.468153146966811, 1.9587263729303115, 2.6074894637830797, 2.612713815704469, 7.350107892867058, 1.7964825562892424, 6.44498126160714, 4.584642273764457, 3.490523345047428, 3.4833669806680376, 1.856385606431192, 0.5734797531077939, 0.6123918715503909, 1.0014262735362978, 4.2650421588651595, 13.108888633789556, 13.87005594468886, 14.54274635161123, 18.104864474265806, 19.68064335084731, 12.960100385450549, 15.502014929248443, 20.659041327814904, 32.66498104218514, 27.088382628656205, 12.060691099013052, 3.874806776162117, 0.36294604381245954, 0.035173712793978, 0.020109490085873875, 0.010626332819341652, 0.02531681953358554, 0.03303088826097308, 0.023101653317890825, 0.010710129431719262, 0.0400495559968535, 0.05506910428765321, 0.03235246377786802, 0.03539076848556438, 0.057772854568376664, 0.03946883836761117, 0.05226015098272793, 0.012984144606537396, 0.031474473390487895, 0.04411813021907884, 0.023006390284506545, 0.04800466279829702, 0.010049216760953349, 0.034969485244683685, 0.021420572959487478, 0.08363166598663216, 0.013052634782187883, 0.037800501881828236, 0.02650152662799003, 0.00879223118611281, 0.031114381422559102, 0.03019433472335579, 0.10014095268542729, 0.06612333934754133, 0.04845421851402329, 0.02249762937877207, 0.0388376776789946, 0.02517920141408761, 0.032962974566485614, 0.04260838542494082, 0.046094269341518807, 0.025060894455940976, 0.0670796545642999, 0.05070681961613798, 0.003252140675378483, 0.031506323495939854, 0.06348854081044275, 0.03855904000961492, 0.024478418654912425, 0.021782457573159088, 0.03888259724443478, 0.010588467966074185, 0.02485624172784869, 0.016542580879984364, 0.016247255900394053, 0.06858458832627343, 0.013617510670765996, 0.0177674577946985, 0.056905501311825174, 0.027209001165183804, 0.014943701755856315, 0.037976847661118356, 0.019248656237558014, 0.04073146618001404, 0.016246342340544347, 0.0600861374949736, 0.00957558577459666, 0.035507129580383344, 0.06266762397342152, 0.029884251059904218, 0.011581607114133096, 0.024838093104922486, 0.09054460592808262, 0.0587698107495183, 0.026855214100871837, 0.03661974588589322, 0.05506002614575048, 0.05953913922571848, 0.04229323983552956, 0.02731944997644713, 0.03402799765969958, 0.04827029229472241, 0.02048406877645081, 0.029866632952865575, 0.013846525952460305, 0.03885857655756897, 0.0662571672470339, 0.012454809451986466, 0.005028718920995392, 0.020901510086391243, 0.06869807659137635, 0.055085973543745864, 0.027984554105768764, 0.026700496898903966, 0.016502483838027524, 0.061739979597229155, 0.030538256490422837, 0.027878830141778436, 0.2023049290742605, 4.375564744395595, 18.73677399850661, 35.39741393058531, 42.842076440011304, 37.932045613565755, 25.35186698359828, 15.113397279093343, 18.633707838673747, 21.033768884597286, 28.48977488856162, 29.59988017236033, 27.436704789438558, 14.539403511631875, 4.9009505394966375, 1.0543351860777026, 0.5636181790501841, 0.39475815130337594, 0.3377796264906084, 0.2944424922668165, 0.6121885211717698, 0.9751750757136654, 2.003450218227602, 4.42573921334359, 4.970948176999246, 4.405985176563263, 6.401237028260385, 5.351074876323824, 2.1789594907914442, 3.885206940674013, 2.5054460619726493, 1.6154529154300692, 1.0686660557985306, 0.5701980163012782, 0.3300845490828637, 0.6262105042415281, 1.3806110524362134, 1.587964209818071, 0.8948111654289308, 1.1489596698553333, 1.2373820283720571, 0.8641123062660618, 0.3097224223517603, 0.3386642128950165, 0.15103709944073232, 2.08193427132022, 3.18216523335826, 0.8092778776922535, 1.4902169065129374, 1.4177642330046625, 1.90549882909944, 2.793543905981126, 3.4686634857808394, 2.4751138831338575, 2.7487065570969738, 5.67829909824556, 7.191748080715057, 7.179447527854674, 5.370285664835285, 3.5175300894245027, 3.5973486063941835, 2.51759780991462, 1.3689917662451345, 1.66470562738757, 0.5390320273656999, 0.22265550319946584, 1.6968990934471933, 4.659923343889175, 10.628731808354779, 19.97099288048283, 19.522646357936246, 20.771221114743142, 22.536972145880423, 14.451534575031651, 13.497648469863401, 21.851290848947343, 34.101670711271225, 33.29208566296485, 19.043621017086892, 7.190842993797795, 1.0865833201716024, 0.013953558969191246, 0.03165148566627214, 0.049295176211143696, 0.01634653514972137, 0.06336612379058235, 0.06186376408403439, 0.03053274831824726, 0.06859668485459781, 0.040767196520802476, 0.025437284944458835, 0.03544225342451565, 0.011296369597285746, 0.013766912180149268, 0.08754547895683397, 0.05962866809098952, 0.05230055062941486, 0.05394706510067467, 0.06298148253511998, 0.044481462738927335, 0.02284781582983992, 0.025434406369083354, 0.06341633319313969, 0.12977697976654576, 0.05141909752461699, 0.03679496934637427, 0.027368086983539888, 0.03678593716974701, 0.03315216764026592, 0.045389617838326006, 0.10326714299979711, 0.04403868307089133, 0.019933806972638256, 0.04629275506182064, 0.03927018793840562, 0.01769899251690555, 0.08055334084577138, 0.015701391441266865, 0.005863704483941078, 0.014378715742139087, 0.03876393788584298, 0.03337767711209674, 0.021000046230432008, 0.05196470534428955, 0.11317062206686505, 0.12553740322830217, 0.12010705026407396, 0.16879448126400673, 0.18154477370121788, 0.16141559898612962, 0.13052645890462783, 0.14180059184230145, 0.21169296886411407, 0.16627812758088115, 0.1383236098674036, 0.07595911922474062, 0.11728299736616113, 0.11928535201736998, 0.1577751338481903, 0.14156957036785542, 0.06802692228267271, 0.16025310652630945, 0.1381100245541142, 0.14215138350282946, 0.17559263825176225, 0.12380460427413065, 0.1493480747505542, 0.11703397282549452, 0.10107151968705078, 0.09517939190470404, 0.14029386543458508, 0.26574946579433256, 0.08522833877753827, 0.17255022731279174, 0.13395408949544355, 0.18356418146962122, 0.1199766391167237, 0.17273517625947155, 0.1425936460615166, 0.28481224611882244, 0.18450662283407104, 0.09383694539147039, 0.1387193708890869, 0.14341231826091969, 0.09189962394415371, 0.079705442392057, 0.14621632263785408, 0.13304644384451453, 0.12324030390910565, 0.19461340631448454, 0.10579723263940505, 0.08378853015000783, 0.08866652605995055, 0.12763677525424189, 0.12426821770326746, 0.18564988648699177, 0.20174753882231253, 3.530175565711914, 16.77914061853963, 37.88716977642429, 49.77683474940639, 45.74944703809677, 39.33325744444324, 30.79328287032343, 24.665054082870487, 26.52551466418851, 31.601151881679414, 27.045968078797866, 24.794268723457094, 14.85980231915751, 6.472031887500517, 1.945768455343862, 1.182507947087288, 1.1733753210113895, 4.284324040335994, 4.347833096981049, 8.024052477652027, 6.059081813981456, 5.263790863175546, 13.409218634328536, 6.447534234293046, 7.250846922397614, 6.3979191933908774, 5.6253500426969225, 6.339554325226815, 8.39030477308458, 5.657746859135167, 2.2140607814635, 0.8797481608006262, 0.31118577286120386, 0.32724496758272575, 0.351334878153378, 1.157789783131692, 1.1863126461544347, 0.6806007243933216, 1.0578051353654554, 1.2122354680492033, 1.0388744285991116, 0.3706865961993895, 0.46883775041468684, 0.27282631024718285, 2.2049915261806983, 4.96434731829551, 1.7380974634039787, 2.1819956504529525, 2.1616500712210134, 1.7066096562531687, 3.003075694845569, 6.284403839418966, 7.760871735311325, 6.396557150348541, 6.594336782732318, 7.701257592247379, 15.779099983553733, 6.188441091968167, 14.085040073240958, 9.467864190378497, 9.28961011671251, 9.466907132056452, 4.133970766298233, 1.61179787929981, 0.872366750432599, 2.0783406447979713, 6.2948682327424335, 15.752743617180856, 18.06935133472566, 21.069978244843025, 27.447634473923717, 27.60424687016395, 19.74092625802563, 23.19513605486962, 30.00882060297074, 44.76447320753529, 37.988861145511756, 19.679684331340177, 6.428145958531288, 0.7558715595833717, 0.13122742935534448, 0.22713841990597788, 0.1488305210706688, 0.10468268196188635, 0.18901555588649166, 0.14387212423307283, 0.19638921344472518, 0.12421564874990333, 0.14978382556188494, 0.21756134025992888, 0.07888591983505795, 0.19075244575017886, 0.12439724223147477, 0.13933366615205042, 0.18470381386578086, 0.16553149828987737, 0.14484594455890118, 0.11471590567981044, 0.1766816628796439, 0.12951156094429955, 0.21209928657739394, 0.15189346316601002, 0.16505505288800887, 0.11162366838224473, 0.19416216520532487, 0.15286017419590106, 0.16993100334319378, 0.11527573975223689, 0.17829041687711594, 0.20876553240081958, 0.16038544055434967, 0.17531460962228237, 0.15613690078739198, 0.14913887146019167, 0.13942308393457245, 0.2179542973998093, 0.091838107083834, 0.07831461742640504, 0.1672245985678127, 0.21821965493502157, 0.1678297773844773, 0.1322909432553476, 0.1070650851714515], [0.08988362526701343, 0.027840611930455894, 0.03296183309547844, 0.06509630655449244, 0.06259172381232343, 0.024978312092923352, 0.045943196802850694, 0.026227452927419258, 0.03570017224598316, 0.031176867384103038, 0.038197120921986724, 0.05397220427590994, 0.061570252817604816, 0.022050128693902687, 0.11530843638484517, 0.01221440340046801, 0.00916483432745501, 0.07060951958861082, 0.0056599595700390646, 0.00844299276885126, 0.032065567680664604, 0.013674539213459338, 0.015005429290355215, 0.05205983431228707, 0.011557246475750882, 0.05550060331100418, 0.05258251695082553, 0.08579108398407699, 0.09823370018913861, 0.020787887755901586, 0.07440592958441666, 0.034395398106426, 0.02503828720129546, 0.08861107661599114, 0.012504172327387477, 0.01425930561738149, 0.07257058210070096, 0.06479554043541993, 0.04380840470173186, 0.0691470960455556, 0.03637244504305624, 0.03904334930402618, 0.019684912666918773, 0.047182968382032654, 0.048800340868652835, 0.02597559769187243, 0.03620130483121161, 0.005968540264744192, 0.01854358721644648, 0.05937083353919368, 0.045050907384363875, 0.06574957271016414, 0.04078463651239872, 0.04949701739655388, 0.42320789889462535, 5.340238348130257, 17.696257445120043, 31.053294827861173, 39.11696226366105, 32.64481221475909, 27.299168840531383, 24.3584345617602, 18.092232481125865, 20.71522535816316, 18.095619447769657, 19.651084369228734, 20.752466301764212, 13.2106751203537, 5.740723619537969, 1.922664224140106, 0.22078879207613009, 0.3774579247880367, 0.9991896032325684, 1.9003632208031995, 1.515679707930934, 1.8559785379517464, 2.8802456923069495, 4.213523787836875, 9.037673338767021, 7.505865212409728, 2.0314283620926643, 1.5983426787199515, 0.9971701954641651, 1.3111354578887264, 0.9062186436307047, 0.9406560118640623, 0.25777862737736396, 1.6280308534060757, 1.2788156179651138, 0.8554894657384965, 0.17539184660680834, 0.194955755686087, 0.03875935284961616, 0.14490857990759035, 0.16769885295821776, 0.1886261687163384, 0.1034555470030154, 1.1314633248313781, 3.644165526474676, 2.0287084435262988, 1.4237469506840554, 1.0697038904313119, 0.9955247611768785, 1.9496946253122824, 2.872622811025189, 1.7201032225162753, 1.5887442711860904, 5.151465458254661, 6.251870720617234, 7.346631202005572, 7.276192297858577, 4.57829293704802, 2.912497381048818, 0.7626890679520946, 1.2331659707330889, 0.9821917056556672, 1.7393854717093131, 8.340859374692364, 13.75557961002473, 27.06401098159052, 32.14236836279593, 19.23144567397333, 23.822679981108635, 21.272137203524192, 15.763730176033514, 20.80321784942381, 30.322355262694824, 29.354577102968772, 21.439793032984582, 9.002518115505096, 1.1498290877188406, 0.31059956238154446, 0.04960246556889146, 0.09606195583699212, 0.050135122672204054, 0.024595852272825378, 0.06198070357523619, 0.09518834747253888, 0.017143645804495584, 0.10070448696252801, 0.2092060789225563, 0.12201516077883783, 0.0575169850321066, 0.011270096611922548, 0.029357385581299186, 0.06206177866026279, 0.03712318056533414, 0.024390944820498268, 0.02510922502786402, 0.03925693844775519, 0.03406672340427195, 0.03409975328512731, 0.01236789390414713, 0.03199867671355605, 0.052550211023058624, 0.05501704478275873, 0.10991275656006991, 0.03646121548128225, 0.056211869983423146, 0.06554429178997394, 0.04213117393514803, 0.011638605013309468, 0.03976557869464159, 0.03103349594429376, 0.028428741460365635, 0.10537006201282625, 0.02491682013046117, 0.09914185911897691, 0.045129255196380044, 0.0027900608585050874, 0.050249331059955785, 0.07865338916740111, 0.037498410430646716, 0.006641142000819767, 0.010769802892971183, 0.03501582590322341, 0.03895676987726362, 0.0445946024340247, 0.01440797455518717, 0.10054548541384359, 0.053634256079432466, 0.052302327953399196, 0.008984973162202346, 0.06632524181998546, 0.050625713887594403, 0.028263467566801176, 0.06547396491852499, 0.0567852714729886, 0.07471940510215298, 0.017053391070916288, 0.07516769677280419, 0.02393063131509529, 0.022729696563234734, 0.04921802732672903, 0.027712929971335877, 0.01513133584071071, 0.06483923042974164, 0.02372571811710875, 0.027614736651641228, 0.05858774612387342, 0.01348144579453454, 0.023246970621027777, 0.008616664901285643, 0.020627453622798768, 0.09620548240960607, 0.025412019364716067, 0.014924091820214546, 0.051583346775582725, 0.03660047111371833, 0.05201082383733123, 0.06801744577504935, 0.025005176881208055, 0.04714394386316981, 0.04791403842729427, 0.049116064854446924, 0.05268730245710862, 0.01424635873146115, 0.036854900404690735, 0.08558956455559501, 0.05438154803649072, 0.03531953763036478, 0.05998614003821727, 0.014587019836800474, 0.0457977818235034, 0.01840601697744381, 0.05344420498717697, 0.03595992201758969, 0.017533486881743998, 0.02611181387046893, 0.07191131747658215, 1.7315076363663522, 10.748028735960684, 25.746100487247592, 39.04313933464789, 41.596861193257, 34.672050014618904, 21.94652403554609, 17.408641807494625, 16.398142172444253, 23.93513825631911, 25.352969169616703, 32.21036461091811, 25.424432792971214, 15.614436922534821, 6.18221874198606, 1.4833387852676454, 0.1434340291926938, 0.5339953976292764, 0.3042074166718991, 1.0911862215688153, 0.7066946596868577, 1.231292058383265, 2.712922528866799, 1.693792331122583, 2.3976527106377388, 5.889712889348307, 2.988944130559122, 4.618083911557352, 4.076319524357396, 3.015616983175278, 2.6023813120780455, 1.8611889164293967, 1.022959779347143, 3.6884552144235183, 2.022809076213068, 1.7481069843615256, 0.992612217462832, 0.39946386170002723, 0.3192599718609164, 0.7224915765466229, 0.8369950000797549, 0.8577744302249725, 1.0211796974462848, 2.108174437476743, 5.227512371155524, 2.8266766571229507, 2.270698581011065, 4.308085758839884, 4.9515476438307, 3.8791834058300143, 5.362022701771029, 2.8029058681380365, 2.9779538944844277, 3.569562290945361, 5.779223643964337, 3.2603807266681426, 1.7486003449847622, 1.4989549666643145, 0.4076617685777526, 0.6840606226075081, 0.22151237744237148, 0.7027659769500456, 1.0695054430154063, 6.316767315710745, 11.449602496239448, 22.81377773131094, 36.08810409422844, 24.918980483085882, 17.369525970951205, 19.218233170047885, 16.150546477686976, 19.55727892537271, 29.465574295290057, 33.02674908791819, 30.148904131304835, 14.841153410173233, 3.417596922766778, 0.5218295536694989, 0.07299697897847622, 0.0792865225324227, 0.022814040928478205, 0.06682697578423447, 0.05219830087416115, 0.06258245797887926, 0.052869401556710084, 0.027866306519436262, 0.03249207181074927, 0.06786050500288125, 0.10906318037380135, 0.09785459391892919, 0.029295361187729626, 0.021097329820716576, 0.014457956046587037, 0.0749619178954632, 0.01205023171590461, 0.013459626652841127, 0.026845189840382627, 0.04800868859033912, 0.0261123635385546, 0.03607585793361068, 0.02293830805067574, 0.04965178247901702, 0.022062972157953248, 0.0205094090497662, 0.08238734001474035, 0.03900088888082293, 0.018563593602589062, 0.012674352056497048, 0.046695575583726175, 0.03201162934513583, 0.0904565287994281, 0.051198962159575, 0.025382865888757572, 0.04194186594817908, 0.09736330173308812, 0.027847418621663126, 0.03721365554919166, 0.015358516341826368, 0.07315786510345436, 0.09101064785593942, 0.027209870674977862, 0.061283073267869415, 0.10517798844845065, 0.14580527050120218, 0.09281273180198285, 0.1508710422222653, 0.21308087503477452, 0.12890943115757358, 0.14827317678399626, 0.13018726581527343, 0.2003785550233818, 0.08436577740095316, 0.22398848086595538, 0.1429491415018997, 0.19257571968820789, 0.11801728498070471, 0.19972168059358675, 0.09798430792626836, 0.1288972810030945, 0.118191332496222, 0.07124217031824012, 0.1255798291775488, 0.1416913936695745, 0.0936062686565903, 0.1206411284604861, 0.17024016578591641, 0.08125342263449585, 0.23539041259115745, 0.1511589074206929, 0.15879885714140632, 0.2483336366112194, 0.11702268068949062, 0.13690132167070143, 0.16636756068516165, 0.21261049704926632, 0.25450479659822683, 0.18167683193760534, 0.1763132818403744, 0.15424314676032913, 0.1805904273304247, 0.2268265608337618, 0.17732087132190505, 0.153743427607321, 0.2289315865885827, 0.20468145638944643, 0.19430114887654784, 0.11537389859797494, 0.13531777196593825, 0.110685900154133, 0.16310856136823856, 0.09188748145055387, 0.14447943277416692, 0.1317985172593786, 0.09033455228012416, 0.23496865054532406, 0.1308106775245359, 1.1673391610383987, 9.436492093147772, 27.02956080436707, 45.38318395614625, 51.099924733561856, 45.817825717310754, 38.082711696624756, 33.32688100876347, 26.005310320085098, 30.57486176490784, 27.574989911048647, 27.60684544040311, 28.115902408476803, 17.766224684253817, 8.48307078884494, 2.641402766589196, 0.5539605069545008, 1.1308839172124863, 2.3262346848364803, 3.938847068817385, 5.020451920647775, 6.62700375241618, 6.775825340901652, 11.775405349269992, 16.962130954188687, 23.430729296899614, 6.531073854815576, 8.309635346935641, 5.216083565065938, 4.3345843111315085, 3.211016227160731, 3.18483391596425, 1.0547386999091795, 4.08510759472847, 5.075643101046163, 2.3086430997617784, 1.0453448684946185, 0.5798002236312436, 0.43558135268188297, 0.7657119896142714, 0.5722373423557128, 0.5935472117797022, 0.6145434141639741, 2.8198742866516118, 4.995696371601475, 4.7115329100239665, 3.190892752139799, 5.0112760259259135, 6.007016762610405, 5.906022104524798, 8.426447453037385, 4.399924134054492, 6.612502259592857, 13.690782054778069, 15.655793413039177, 15.126462694137329, 14.920925594145253, 11.041441636700785, 7.859150642348875, 2.5530104387191037, 2.1802901548724023, 2.1951498091220856, 2.5155089026497257, 9.813009231321274, 17.10773914091049, 32.111399289100405, 38.69178125935216, 26.024118085061353, 32.961845628676876, 30.024592453433623, 23.18491435820057, 29.605061623357958, 41.53235389340309, 40.471611638222974, 32.95172199126213, 14.5349722139297, 2.8934905557863178, 0.44192036253310024, 0.13000954873859882, 0.14551696097177846, 0.16898615646266169, 0.1424951731197296, 0.3184474283649076, 0.1393525272367462, 0.11721570420289233, 0.2694022955913698, 0.2763688233831237, 0.21307891384968836, 0.1902883803291667, 0.19596188960056152, 0.095950827122696, 0.14604056674626567, 0.11617668213382845, 0.19983616477299124, 0.10907735300040054, 0.1915459289786316, 0.15995851507590664, 0.19303757877599811, 0.13826966195577575, 0.09997622079906926, 0.19494881492949304, 0.1758475923129628, 0.16867412885110225, 0.12370945615393501, 0.19579197129895612, 0.12578265861638133, 0.19675391726195815, 0.1882872667403952, 0.15215754899526798, 0.08727658975629077, 0.18218837948816438, 0.12467942305750425, 0.1223088329237315, 0.1089135327586724, 0.15932872951511415, 0.06562279281957496, 0.13369130601565685, 0.10423213033185852, 0.11504644963649974, 0.16902271417840836, 0.1346713163319134, 0.21708759148755383], [0.06533989187089667, 0.046187973385977174, 0.02042077459214676, 0.03781811424320744, 0.05612850812594256, 0.02016066092877619, 0.025017771366683227, 0.15096606776839303, 0.0522845393917974, 0.05206501689709483, 0.05392947189149357, 0.061476836056118055, 0.0233729901693521, 0.02800257440896765, 0.020060544728391597, 0.028718627215693557, 0.02192269188291844, 0.06718649318622005, 0.03597198790239711, 0.046442517590138226, 0.050929981028480883, 0.01766430597091394, 0.06115041365246139, 0.01857437629012331, 0.07512897868911106, 0.06330844886120289, 0.05947088462210471, 0.028340273626869725, 0.029585547632567828, 0.05633946575765168, 0.033769247632834225, 0.02078787626458272, 0.07082170296099878, 0.031035533738172347, 0.016501537719441038, 0.06120150022569203, 0.055944516789168126, 0.029867146231774843, 0.04698195074114108, 0.02821881996257411, 0.07523974734208277, 0.031148307626285864, 0.03731702762325445, 0.09151997375151805, 0.027266095782960617, 0.02353310254552672, 0.08056084084655009, 0.11061289963582832, 0.04681387105055394, 0.028043119612360196, 0.09905143010039484, 0.02460262832051564, 0.059430959949930834, 0.010201105183260816, 0.0472538851411833, 0.26500013987383536, 2.7824453144304218, 13.885115884965467, 28.60354127422456, 37.58701432135798, 37.768278814131214, 33.25446621064217, 27.852281870380526, 22.746597336184596, 22.062575201834402, 21.927312266442087, 22.637072993863015, 21.56767995126786, 24.20067487224456, 15.511358995591442, 11.636484803691989, 3.721903716364215, 1.9478463309426464, 0.24416394261342866, 0.17933810340060344, 1.2595724698997315, 4.711511336988019, 2.3699151796679345, 2.826844828744089, 3.478165182375139, 1.2967554359666764, 2.0298931218924063, 2.8604070794197822, 2.4393180877931657, 2.8769293283262565, 2.1095112302610954, 1.647873633811551, 2.9212631429395373, 1.7109394626271341, 2.236496738849148, 0.8597558400323315, 0.18575785891903987, 0.13934333418165484, 0.8804014192954187, 1.6872047104181784, 0.9842691522452139, 1.1843362618838589, 1.2142717910389746, 0.7443072478617392, 0.048883794656684326, 1.9325440617338305, 2.8138034382174095, 4.63532567024231, 4.370549013537746, 2.905075276090253, 1.3486226527921616, 1.8534266684324512, 3.7429362006725806, 6.292119141547911, 1.3942698485428289, 1.0783628903089033, 0.23260756756269166, 0.9140401561894725, 2.1016512907320455, 4.137109643028629, 11.382966329974513, 23.42060762066995, 23.921527631821174, 30.993825812493604, 63.04880180666524, 26.8549310007403, 17.609488733353153, 17.772498515344438, 23.542079502536406, 35.30454004964521, 31.44080146666496, 27.19709307916703, 13.306298582784592, 3.854428101931849, 1.1312630388044542, 0.07213056417963198, 0.06307711712114754, 0.02180324728420425, 0.009668073654475232, 0.0742759857507002, 0.01713238431200866, 0.03562487729434525, 0.02490477531307167, 0.040224323635019606, 0.014877999182640305, 0.017126939342086835, 0.07725550853196653, 0.04125658497815171, 0.012152928674984123, 0.014736406982035167, 0.029893637552196463, 0.01729823851717576, 0.020339871876903122, 0.09443881470830211, 0.012861948794565134, 0.04676553090253184, 0.032287710196068214, 0.062249309323247404, 0.04101981784427359, 0.0675455739180888, 0.035686474593897025, 0.04215429829914243, 0.017757027507609418, 0.045419433980339, 0.025982965542484197, 0.03290005576526446, 0.029457898232184594, 0.021687613972913355, 0.014574283625059312, 0.047820725087677284, 0.04633370629181305, 0.062070098375120474, 0.017885182526022676, 0.038862529571258256, 0.029157413650424253, 0.04673405618016278, 0.1040198473680404, 0.08907962365136032, 0.024011738958858678, 0.07196829909639013, 0.013288309283164, 0.05505551005743685, 0.042463177289333076, 0.04561038905634515, 0.06430289993483214, 0.036409125332870794, 0.08143613460443674, 0.01927984750739509, 0.03421356713759803, 0.02603748993527505, 0.038879088561741576, 0.010604273317561997, 0.02613705263713435, 0.054398321531592846, 0.023311141976005128, 0.05373781201459708, 0.04615332322916196, 0.03769918292340252, 0.02274172988930537, 0.011181773377522346, 0.058712335002999154, 0.04456841754877279, 0.0397700181741628, 0.09850221400659892, 0.022624045377597216, 0.09037147771807448, 0.04777988494043389, 0.04440857713381129, 0.014331822542683973, 0.010937355898110377, 0.04436155465701896, 0.08985659002416557, 0.03416100967555277, 0.03180245095263085, 0.02801218115153813, 0.05892678982608261, 0.05055445238887783, 0.025290196062996987, 0.04185482686866195, 0.04653812536308843, 0.025179800877888358, 0.0818200059415352, 0.039901038361412865, 0.029347955038951292, 0.06287691536389532, 0.07144060241238726, 0.047523023320301894, 0.034959457153754855, 0.09143440939125516, 0.02549061040964819, 0.06252584408127493, 0.027113791757954225, 0.010270102892161138, 0.019182485393098286, 0.019591944066867716, 0.024635198548616424, 0.5291903103070875, 5.710246803299074, 20.050183573076804, 37.78409773303617, 45.12753171305503, 42.06966369382797, 33.57744593774119, 22.990256932473955, 16.3406971000856, 19.94547001777157, 23.8482165721155, 33.06976179922781, 33.13209610600626, 30.449810720259148, 19.433677196502686, 12.528646530643588, 3.1844394726137963, 0.994180552661419, 0.22132606485918646, 0.23877765502660508, 0.14089556621207347, 0.22005002284722947, 0.6170786136100369, 1.0630437058787192, 1.3857887036377385, 1.8049797583972256, 1.4851256700292712, 2.704619361508277, 2.120879484761146, 2.5425489871732654, 2.6085097703241535, 1.6627087732476573, 2.704528411549907, 1.5873172638877746, 2.383850625445766, 1.5722940958315328, 1.2806222371516691, 0.8429953684249233, 1.9975512186365745, 1.1590205493473238, 2.070660889148712, 3.3111467380677504, 2.637698578257715, 1.1367734786002868, 2.6028870526821386, 3.1945751222871968, 2.9004316801025025, 4.119326106963619, 3.6131562484848887, 2.928505309166447, 2.069585914573362, 1.3466424687254814, 0.979760081296967, 1.5664949941058315, 0.710369675390182, 0.2120892048603104, 0.21544614085747352, 0.29578596533786866, 1.074006240214071, 4.02410640351234, 10.834593484478614, 19.00157517002475, 33.681373057826875, 38.75548055095058, 57.531089936533284, 36.25503232402187, 16.254042137053705, 15.623467199264036, 23.936167878489343, 33.74002033664335, 32.763059908343905, 35.168182772974816, 21.335095167160038, 8.125910057175545, 1.9134442027538054, 0.15414612938559827, 0.04894661386647532, 0.06109521701751698, 0.03507265047500691, 0.024483034334656213, 0.06284539084581119, 0.011869182156759405, 0.027260593356444474, 0.04513187138664146, 0.04136037840057285, 0.024678197148586475, 0.012812406846111821, 0.04057616100556428, 0.0747456282918011, 0.046131409284087925, 0.0508165693721704, 0.04120957782311786, 0.014665892419044771, 0.017517791655395302, 0.01932611155714239, 0.04315368297900404, 0.06768268833477652, 0.026536151886947697, 0.028170424273177504, 0.09766163169256142, 0.03861135998440366, 0.048672714450907324, 0.052673987848984624, 0.03243448881192073, 0.03175937191342875, 0.011915316929169481, 0.022162439098822016, 0.04971351001351591, 0.02962529801973893, 0.021626541443589716, 0.02799451707922403, 0.030240694534093625, 0.020904350357370514, 0.01324643874766245, 0.023021277288095127, 0.08851962870046978, 0.06675350795229597, 0.12431733160009309, 0.042289712000638253, 0.048491423574065974, 0.023628599235727906, 0.22081332221146555, 0.13363410989123006, 0.16770354141631436, 0.14455838579564326, 0.13499063710051198, 0.14986000534507538, 0.1650862173447686, 0.20219805980882338, 0.08647045075532891, 0.18262572376237762, 0.1458138506859541, 0.12359411395605534, 0.10389788617049495, 0.10709284053694819, 0.21774366918590762, 0.08405944948355037, 0.21475854630191482, 0.14568350848651704, 0.14716037278694494, 0.13938243530931013, 0.2063251899615411, 0.18114116793918997, 0.16619329100414632, 0.11498563757707035, 0.2934554339416566, 0.1448534828640761, 0.09651226997976342, 0.07544155788397597, 0.22031403206769498, 0.16695556381056387, 0.16925292359965463, 0.0868008874597088, 0.17932491136654732, 0.10783027677286057, 0.12276140702587944, 0.3408843969866153, 0.16101055297880404, 0.12625975519298546, 0.15332782490839883, 0.15945528724020527, 0.15102487267746081, 0.07725527104471, 0.2151099048675068, 0.21278130401286388, 0.16401761662094824, 0.14257165933808974, 0.20442507740470672, 0.188290668170779, 0.11591971326138704, 0.20740209507846064, 0.1850724553749446, 0.12294493870989931, 0.22490735736585435, 0.11927168500880081, 0.12702226548665954, 0.6226436601531121, 4.828702442107662, 19.575555209190615, 40.06338311779884, 53.43793584454445, 52.19150466303672, 44.689477489840606, 40.321796709491366, 32.67404367846827, 29.797430346089026, 30.300627293125277, 33.02638822986234, 31.655574767820298, 34.482442640489154, 21.508856165793635, 15.705640854374057, 5.172833550360895, 3.0035539788584558, 0.4656050125918081, 0.9417127229032979, 2.9194215901436347, 8.815336727326917, 5.84402168950727, 8.91298903572944, 8.625836237784355, 7.424523099776238, 8.827130313842527, 8.293050585254546, 10.92512276864821, 8.137426626297737, 6.446451660125486, 5.424690900310393, 9.806190190776702, 7.100779000789889, 6.430738645215189, 3.3644255178589977, 1.4311579014024427, 1.3876015741017558, 2.663965955857308, 4.275958605350987, 3.21963073265168, 6.281272317132642, 4.466657378981191, 4.455941463670423, 2.8997138863609684, 5.225658560952833, 7.2977344451412085, 9.618903879196415, 12.337545714070721, 9.925531245047047, 9.441388191715363, 6.778975494446294, 11.121356987184095, 11.259038063787646, 3.297971006362669, 2.5698508899058066, 1.2765533909682305, 1.4377284843114115, 3.009438514709473, 6.026773741168361, 14.86522597651328, 28.344070603770597, 30.324336059631843, 36.80681174801242, 69.9115179431054, 33.501073468116026, 25.637386114366596, 26.23461404154378, 34.259291156645745, 46.973995316413145, 42.40214340148434, 41.80665700666366, 22.073814753563177, 8.193117418596822, 1.6269666653486992, 0.25320005693262626, 0.11081809628634684, 0.1953930386732663, 0.06790726700977934, 0.16539738693785283, 0.17423293943847382, 0.12122307949128652, 0.12714493914597458, 0.33438319100006936, 0.21930376127842935, 0.14133412090520706, 0.20664169152657832, 0.133964263143078, 0.1335121486936846, 0.12590789867024269, 0.12263008423389928, 0.19631660363126188, 0.22898625462285935, 0.18836212885235587, 0.12919695927731453, 0.09722796464038473, 0.14991458144880113, 0.1757141704400701, 0.12051640934641324, 0.2696021219655391, 0.10886624981198581, 0.15491174233536567, 0.1254077428471177, 0.10281386409675884, 0.10469219677390591, 0.15224702806482393, 0.09129153399337685, 0.12831165275025752, 0.1168882705631756, 0.11504857170004999, 0.12846433407356664, 0.27816364481564493, 0.1431124561255978, 0.17486897627672843, 0.09860028858266531, 0.1297450032565863, 0.20998486858462134, 0.21301943478324722, 0.23030671441266615, 0.2397957092691814, 0.07840514603641727], [0.05401702808035959, 0.0432899278858977, 0.07483262523648239, 0.08375676048378791, 0.1132456373964106, 0.03166466620900939, 0.0071803276096620875, 0.06456850261818017, 0.03477682562304601, 0.02846824669940097, 0.051278830656120857, 0.11068379341234123, 0.038965851849605965, 0.010680816034906575, 0.0015374741844660152, 0.05069696006455249, 0.00973352341867623, 0.061156906247619665, 0.0416871378829162, 0.06536557879899779, 0.025013389343756343, 0.10422444646997799, 0.01827014936885286, 0.07948180600520104, 0.020155907353206028, 0.027105000899023107, 0.0275957778907351, 0.050967301001712206, 0.06612450380118624, 0.03597534336750546, 0.0726712996801061, 0.09390131975974768, 0.07385229316329764, 0.04227123012946498, 0.023593558374071316, 0.057051889222836306, 0.06326952010333058, 0.03962104854684684, 0.026857711547504992, 0.06317145318814343, 0.14431999455536568, 0.07044470343258112, 0.010078305119438278, 0.021210915762029832, 0.06084987352932654, 0.05379008219367074, 0.04997598322769327, 0.039438654503394524, 0.034265006111273845, 0.06214569593148847, 0.03342040183563386, 0.019698602658125664, 0.011124736216339854, 0.05250826387876465, 0.044546760243153384, 0.056762825096807176, 0.09455297713077838, 0.8013679279435066, 5.558597185919362, 21.64203828380954, 34.00731809677617, 38.14686990553333, 36.444929953544374, 39.284043465891195, 24.544909923307358, 22.88165826951304, 19.002685200783517, 21.217531927170295, 20.9131089333565, 23.649915264498805, 22.256801166842063, 23.292805033345378, 13.851642377914922, 8.858398468263688, 4.343823944368671, 2.027815246293622, 0.6164618209004402, 0.21948751512794726, 0.13048124439533682, 0.4242756722434875, 0.8636485472802193, 2.0800547205632736, 2.8983802805023813, 1.6998994614808791, 2.9380678024984177, 1.5101365408589764, 0.846739148180331, 2.525342284671722, 0.7589542973906763, 1.6634524301175149, 1.6238011900455722, 1.5468162178031861, 0.2994251587698537, 1.9296840410078726, 0.366599639697421, 2.0922285318374634, 2.517974602599298, 2.0469642574748685, 1.1049011565985218, 1.5894424530767626, 1.7116267354257646, 4.039918213121353, 3.2028599035355354, 2.559809377116542, 3.6445761496020905, 1.4313286470790065, 0.718996070565716, 0.3317541917485576, 0.16510956770470067, 0.5481100466943557, 1.0486354919210559, 4.329559754940772, 10.764462486390146, 18.391546587790213, 26.43652589090409, 27.184578757132254, 25.992421411698867, 22.322449876416115, 23.40112520802406, 53.10032175433252, 24.360197667152654, 19.84426502258547, 21.155993861536828, 31.28736422907922, 27.716154052365212, 21.755349674532493, 8.245784063493053, 2.602531833033408, 0.4000282233520862, 0.018493676588179606, 0.030002460341840505, 0.07045721364838463, 0.0418277916258141, 0.06010307569897944, 0.07025086020510043, 0.042697010306461204, 0.030723280130675247, 0.0616751455761973, 0.05423668847088853, 0.0675386484832533, 0.04579142712417149, 0.050109619605204755, 0.06239058742780359, 0.04151573720117731, 0.03443726864192755, 0.04356314931365271, 0.057543637230992324, 0.041241010410651084, 0.077412050938414, 0.061345195337649316, 0.02752976792473947, 0.03554509306747106, 0.047490116013514425, 0.04022895463652188, 0.037493132084848425, 0.04105820267971966, 0.01227962621112144, 0.0185896942181693, 0.023058013119284185, 0.08618994766185362, 0.0739128141093158, 0.06112912023860601, 0.024763562325989048, 0.030331613848947232, 0.024829104978350863, 0.02484485191563445, 0.010771011396671736, 0.05813434464676727, 0.08698521587516993, 0.06344531812975485, 0.07549896851302156, 0.01312136723314442, 0.02129493453990548, 0.03426535468127939, 0.057680456703829194, 0.02570074066639908, 0.022839854261086836, 0.028387619775810072, 0.011698003640518555, 0.07507225753919733, 0.0647943529991373, 0.02337940424049814, 0.02107024286693383, 0.0381092774501491, 0.0066436983404621, 0.04505582183839814, 0.020483534430123625, 0.04517193778508133, 0.06347931711183441, 0.03691240679472685, 0.023653205979855794, 0.02175290764669978, 0.094676616060878, 0.03144648436817431, 0.009433266748073361, 0.07855391265043328, 0.04070452286771709, 0.025951471667917028, 0.0794720613668042, 0.03523812163621187, 0.059077827890794125, 0.02905629195963904, 0.036552425909547076, 0.07123267082797904, 0.022657400845820387, 0.028427896848429116, 0.06957143214681456, 0.0839557748047575, 0.015777385448135676, 0.048344120187985326, 0.0233248817629271, 0.04047070517234745, 0.025787858269928444, 0.02955155056570807, 0.07938727075534482, 0.028321004600354263, 0.056891060554452484, 0.047383032243458495, 0.015331996293107589, 0.07130261465546585, 0.06079207219543958, 0.0823014232540323, 0.03473386341225236, 0.027674022280881484, 0.012489903939797754, 0.07025559462847249, 0.023877449491391742, 0.059255054671197176, 0.0025980785064729714, 0.03711499108542358, 0.060899983340453726, 0.01869316396844243, 0.1121665565897861, 2.2911789917176772, 10.257034282530508, 28.55127569167845, 40.45401980800014, 44.437018056069654, 42.10596130740258, 38.68934154510498, 19.866957895217404, 15.206129954707238, 18.384598109029955, 22.200909353071644, 31.474200448682232, 34.539689633154104, 32.74432470721583, 30.219220461383944, 20.37418507760571, 10.987782632150958, 4.72610108314022, 2.004041147808875, 1.0028629028989424, 0.2267192012720531, 0.05704820433992052, 0.4394106584931574, 0.31063765227313966, 0.5292562551556096, 0.700399807143596, 0.6198746506725589, 0.6425850513962008, 0.6126945069239986, 0.9184205243664404, 0.5084038627964835, 0.7810400606643769, 0.9066295731932887, 0.25946674808379144, 0.5933817367880576, 1.4995085111548825, 1.3367726822053234, 1.5562951156208593, 0.9651640838673039, 1.8043856418901876, 0.66510031420377, 0.6141878267930401, 0.9637475566517923, 0.6135239043543416, 0.690001787677888, 0.1517860576390259, 1.446304256396909, 0.9147269386918315, 0.26125651333601246, 0.2574037039472211, 0.21271352055332354, 0.021194515734790795, 0.430440902709961, 0.6375324257439183, 3.418317903434077, 8.766160011291504, 20.15571298137788, 30.7823629917637, 35.66913220190233, 41.286021201841294, 31.204158990613877, 25.992529276878606, 63.16394690544375, 23.97518369459337, 13.598757366980276, 24.63454588767021, 34.99089164118613, 34.95218569232572, 30.63871991249823, 14.705964999814189, 4.0516237914562225, 0.8509774530126203, 0.04696700436573836, 0.02843659386158951, 0.027472125554096796, 0.048369190415307406, 0.05632522801357893, 0.01975726775614725, 0.06986918754034466, 0.040199682416935126, 0.06269829047303047, 0.06692067599825322, 0.02694715805832417, 0.019963368390416427, 0.10621459734055305, 0.0337933334371736, 0.0248307041868928, 0.01063193962533748, 0.05138923158688892, 0.09455001237051142, 0.017623331758283803, 0.0424288182459291, 0.03385689958269077, 0.015747160406693095, 0.020362115239784605, 0.03174387778516018, 0.02996999928126893, 0.06073117969677814, 0.05022185148611184, 0.04562438931316138, 0.04906560647331419, 0.020437812387582757, 0.05630934318046897, 0.029877204966220646, 0.054784108088502, 0.1127226444922628, 0.033075114516841794, 0.0413489866731388, 0.0766568414626583, 0.04741300160305635, 0.05671533530638103, 0.041304484625617345, 0.05386805462260401, 0.034834017917033167, 0.07638293438621106, 0.04268943369689007, 0.05981829400444704, 0.03295148707806103, 0.002570201285115834, 0.15323561856583243, 0.2326394521421002, 0.15148795750592986, 0.2266831491743365, 0.13633809382877043, 0.1376051266467379, 0.1321848094343178, 0.1908466132778314, 0.0779235908280938, 0.14270875843301897, 0.13238043764666205, 0.27113138667998776, 0.157957018443173, 0.08523685001437703, 0.10801429875315198, 0.1010873087591702, 0.20562657906163126, 0.09133382970767637, 0.0845295440165266, 0.1743201662095324, 0.19680331461131575, 0.19879647620743324, 0.13601921739116793, 0.10352213536539387, 0.08330785594279728, 0.1454079773036703, 0.10917368089599956, 0.16216449589738924, 0.10260898154228927, 0.16264192189180082, 0.22674538615730502, 0.17833020748390307, 0.16649373536629064, 0.14768730338302352, 0.13084702073566376, 0.15575777919542405, 0.08832830590225997, 0.10725460766303925, 0.18610642892458748, 0.14093848245759166, 0.24750161916017535, 0.12951660180284133, 0.15383223251950356, 0.13279435495215078, 0.19456157280552774, 0.19160687893388734, 0.17096716790430008, 0.13211627520861166, 0.08686485580138623, 0.22892003398268457, 0.1197646089619206, 0.11314866598695518, 0.06655867647139296, 0.15950684495750936, 0.26402628890449004, 0.1704715243390491, 0.15236810060037723, 1.784538816540472, 8.472627478261149, 29.584849649860015, 45.728305462867986, 53.69056001786263, 48.275916268748624, 52.08732258888983, 36.63032077973889, 34.00255633938697, 26.04014096721526, 30.600227732812208, 31.082196812475885, 34.73709467918643, 32.32025177248063, 31.03296518325806, 19.897681820777155, 12.631637184850632, 6.124554016897756, 2.7596855163574223, 1.5242141725555545, 0.5750243089372112, 0.7232667349519268, 1.3190506783223923, 2.91772271356275, 5.858621731881173, 7.125178594743052, 4.42008609733274, 6.906228949946742, 7.259675197062954, 5.868444327385196, 7.389995455741883, 3.6248571690051787, 7.2010421368383595, 7.031454540068104, 4.3306339940717145, 4.112612725265564, 5.673434378639345, 7.38730961276639, 8.073444433750646, 7.528851282212043, 7.050142182457832, 5.156288012381523, 4.664666470020048, 6.908627479307114, 10.853160023689272, 9.432780550372216, 8.863247498389214, 9.004695030950732, 4.441862115936895, 2.7928251316470485, 1.1239329869708707, 0.6847418892768122, 1.1769097442588499, 1.765755443803726, 6.277148435192724, 13.456626361416234, 23.326810021554273, 32.89418082083426, 35.990331172943115, 35.190665798802534, 28.995133061562818, 29.94767673553959, 60.4141692961416, 30.13897857358379, 27.44928579176626, 33.75149719176754, 45.74567764036117, 40.16896940046742, 32.54457408382047, 14.695553068191776, 3.5326863729184677, 0.6345164908036109, 0.23817802268651225, 0.09394940709875477, 0.18143537634563062, 0.1218162460492984, 0.16533384760541303, 0.15599056267209593, 0.1361906678686219, 0.18509658714455945, 0.30559170690755694, 0.17624917560287062, 0.14404052568058814, 0.1539718137393075, 0.17432925201231436, 0.1585103637508808, 0.1872932370151243, 0.09897307462749944, 0.08953831113514402, 0.1956913992762566, 0.26283208040460465, 0.11645037470565689, 0.11986837557126438, 0.08107110903027558, 0.14366307416029517, 0.10451537602010275, 0.09682769902170667, 0.18334325703401722, 0.12894119316291425, 0.14128077054216018, 0.1328454376949418, 0.17456991087284782, 0.14767420327951833, 0.2014058023210495, 0.21129236616674932, 0.1616863651020873, 0.12477248741854584, 0.15950673770519996, 0.1869344320749083, 0.22932952329997094, 0.11022519785910846, 0.23905491756816066, 0.16668461383350436, 0.20812364265082345, 0.1556110120708904, 0.16644994578053876, 0.19548196615951677, 0.11807362308665631, 0.08301272823084747], [0.015617444484134116, 0.028237211818416274, 0.033150202624740145, 0.03204589262754927, 0.05320077671879723, 0.04049905425598545, 0.02475604891867167, 0.03300577972925479, 0.05352542945934881, 0.04698025385638879, 0.022917121889129765, 0.05005030524766734, 0.03059289579640233, 0.01078798790507379, 0.02244899620211894, 0.03589082854769884, 0.0364473377985339, 0.039582606254806446, 0.13240771037676644, 0.011266367678951112, 0.03228093031793833, 0.060618078306076996, 0.0452657682340472, 0.025352350691513672, 0.020740708231084773, 0.060305717446270495, 0.0650433392354077, 0.07709047787131802, 0.01961295785863073, 0.009203637638429721, 0.022684637186748367, 0.024819209037588972, 0.0650987503749709, 0.05645187000834173, 0.06442393416598921, 0.04548102361901153, 0.08122771272375699, 0.05768471998312782, 0.03589928615838289, 0.042941737093872605, 0.03066683285719445, 0.04214959834972697, 0.025670495515148488, 0.07118157276342954, 0.013649925766062113, 0.026397512955290657, 0.01869589507189249, 0.024141481694495006, 0.04786873964833156, 0.018818076519716172, 0.029510369509338375, 0.052839359418759425, 0.06166972167369339, 0.03980237389764479, 0.026882848807520447, 0.019227376230241313, 0.08441066249243676, 0.05682532254966998, 0.1839400548487902, 3.365737305533502, 11.3822102931238, 23.285480007048577, 33.08400784769366, 37.742783408011164, 40.74718952178955, 32.499276591885476, 30.18190303156453, 23.01702710890001, 24.154139872520204, 22.79501115122149, 25.19862194215098, 19.85597525873492, 21.318964419826386, 18.481535565468576, 17.19860084595219, 12.306119684250126, 8.473029521203811, 5.725840185919116, 3.0063793111232022, 1.6713512256260843, 0.4875907247825977, 0.287412746899551, 0.22504701519445067, 0.16476735622892458, 0.3846835741592992, 0.36791740285773433, 0.8101987153772385, 0.5074186737258588, 0.5067006961232232, 0.4319155913206839, 0.37815935489150787, 1.0831825026581365, 1.0091690322564495, 1.1372837544448915, 0.21478511423112887, 0.7481669826853661, 1.861460172841626, 0.31940957351076993, 0.05848698640963244, 1.5745813279382646, 0.7958954861087184, 0.5162787870053323, 0.4465485141882974, 0.6340026603110376, 0.38874460624591, 0.18017376743016705, 0.8386045814521852, 1.9146731303584192, 5.936223374259088, 9.565530227076623, 16.853189083837695, 24.98387217521668, 30.548491670239358, 26.004494467089255, 20.105681188644905, 17.74546946248701, 16.46469989130574, 16.303701304620315, 23.86553775879645, 33.035225329860566, 30.69593160383163, 33.09728899309712, 34.89838646304223, 24.311528898054554, 15.658878357179704, 2.1655501329129745, 0.45745589019310096, 0.21632243819054098, 0.04381831021859281, 0.041366250464512457, 0.022119718205724514, 0.07621323825010369, 0.007499374023022792, 0.04552911861889786, 0.060687685054877115, 0.05358159902595705, 0.012121239447996262, 0.06497841328382492, 0.033200641853674766, 0.0398563907571858, 0.05907483248701019, 0.025142750950650345, 0.07979372636445108, 0.06057444959878922, 0.02653941350628532, 0.02469640897376643, 0.07972664004492183, 0.08147070815245952, 0.019060001340544513, 0.061839697431893124, 0.04471120867697943, 0.05920311007949133, 0.04485193136779051, 0.02494001344236876, 0.07280734923457907, 0.05039442428237489, 0.05412705362804475, 0.03097924925837546, 0.05542320927845375, 0.07423773498064087, 0.05608086511793156, 0.03262686498102642, 0.07309303874330175, 0.03888078161605424, 0.08384124466007756, 0.06086529870968192, 0.04111248767003417, 0.04251593393423865, 0.05679579752106821, 0.08051432398778778, 0.01901142370526589, 0.06263264822923849, 0.061692593228672786, 0.06195083380706849, 0.042422088163514296, 0.06599259878238363, 0.05351330994838669, 0.049645037074843724, 0.01988708135491658, 0.056161334993497986, 0.059290976533966686, 0.0874777261408106, 0.03289855806337249, 0.023151259426207795, 0.05942563563885708, 0.022595671396101677, 0.05212300209208362, 0.01265225999598061, 0.06097530127472936, 0.015749409832360766, 0.051929047781853914, 0.014486402806435383, 0.03302884280621525, 0.044248384318404624, 0.03734145816715975, 0.018163209240282738, 0.02078659689774917, 0.04015625672294729, 0.051987163211789825, 0.06021482494449424, 0.0588803074412769, 0.06858268076734197, 0.01866293605417013, 0.024822340421979467, 0.043047311670717694, 0.06239839769419163, 0.045994294867400205, 0.060390056065854535, 0.08557350735270208, 0.07631947932344291, 0.02762856262345468, 0.02837750933042938, 0.0530525999924829, 0.07680280419487147, 0.021605824510897362, 0.030253884652929924, 0.017207043410669413, 0.047146445140242584, 0.08213525878325587, 0.03735961062052558, 0.010431328011045774, 0.0491915513280659, 0.003363189668649988, 0.07886109092543203, 0.07852903011465266, 0.03479052327513214, 0.017091741432405768, 0.034010741529205156, 0.0414534351007352, 0.04693833352517217, 0.02380533571985941, 0.02057949651873881, 0.043709606172577034, 0.06678262695429787, 0.6201741604074356, 6.29708388159352, 18.446420546500914, 32.55435843621531, 40.98537152813327, 46.027962776922415, 42.216234822427076, 32.09345836793223, 22.2584112997978, 18.723381065553237, 18.342110995323427, 24.35183713513036, 26.40381528485206, 30.357652671875496, 29.280381548789244, 28.913965494401996, 25.337736645052512, 17.951843007918328, 11.10761006032267, 5.821283219322082, 3.4857601167694217, 1.678707630884263, 0.46323243829031147, 0.16239563994590314, 0.1680743279716661, 0.1129875423747205, 0.2509656389273944, 0.26525239730554245, 0.5007118190969191, 0.37038478820073995, 0.24640525540997907, 0.3815845033574489, 0.0573574663740733, 0.40698001161217695, 0.2091828664584506, 0.09466699399654904, 0.054088235952921455, 0.0937623514102832, 0.16967381230525433, 0.5748562598901411, 0.43331149544927383, 0.2110191026041585, 0.44659254892218503, 0.3328488088182865, 0.4865315316184875, 0.19603224711552744, 0.16543402126239193, 0.11275996829593375, 0.6925103885512198, 2.4331773721402694, 5.491546229008706, 10.795318791943213, 17.3951429705466, 28.70489335829212, 40.77124541805637, 35.600855504312825, 33.95741770344396, 25.521617358730687, 19.797590778719997, 14.364187313664345, 21.53940946825089, 38.90835885078677, 27.603793836409046, 29.44992207711743, 37.79385266765472, 30.205343115714292, 20.81850528717041, 6.606692739071385, 1.5929316464931735, 0.31581248427110337, 0.12639009739242255, 0.026972333622735836, 0.04337572207253787, 0.04366233854764893, 0.04061830733271857, 0.01710515946239954, 0.05973216273912019, 0.060810672810241106, 0.01665037711180987, 0.09399416195529123, 0.04431046042290907, 0.02816817963555936, 0.0527628617090804, 0.047407596852750554, 0.008430878045938669, 0.02298463913311641, 0.014487877525689622, 0.028761644967861717, 0.038089887764785564, 0.03212867991908664, 0.024124428577300523, 0.03770413951227262, 0.02156599943015364, 0.040657243751470125, 0.015721995375990387, 0.0102404227307547, 0.08692741454128297, 0.08426635451014004, 0.045980800228614005, 0.010232949543053345, 0.043279761899142496, 0.06678090325646824, 0.03522417500555035, 0.011474937031556283, 0.08543894400880223, 0.02159158676682461, 0.05555892941511928, 0.03837850372937899, 0.039483704303781834, 0.020115674330642628, 0.04742698270767447, 0.008274623880072707, 0.03147381647009283, 0.07396906028471648, 0.02178377715960866, 0.1375734106066727, 0.03803349220223966, 0.029920138448717135, 0.12079602377789637, 0.15747292748382016, 0.10520316209764251, 0.10108394563318261, 0.15146180326419492, 0.15578483742090965, 0.1460581101597317, 0.09302143713519459, 0.16016825462781614, 0.10558189298476904, 0.12174732877963013, 0.14928891744104125, 0.13450594859257822, 0.06740017043006036, 0.13295431411074055, 0.1154472515167248, 0.1245805517499966, 0.14048074492283408, 0.22462151463954683, 0.10736812657165913, 0.07718874396936548, 0.21295229483756328, 0.17616939520643604, 0.15390006194431938, 0.09817375380906368, 0.16613416433815034, 0.1862051163709933, 0.1559317271195112, 0.0750092544683045, 0.1584996998069748, 0.167846585353536, 0.13470810387403737, 0.14650598048202454, 0.11314833656914773, 0.08610256767321019, 0.16692381712698168, 0.11153357644234935, 0.14989227296844607, 0.262261038465846, 0.0739372446532211, 0.19386640930127716, 0.26500259135519305, 0.25413604783675364, 0.16871214213390506, 0.1361681908489235, 0.14675765568690916, 0.07849799589284005, 0.21794953233292028, 0.1976930491265751, 0.14427606707378743, 0.09158407998902184, 0.2130142407071206, 0.2838573328429653, 0.19500694568118743, 0.12665972969825232, 0.17478167289687743, 0.2807198657143501, 0.21377130411565307, 0.5239954987360586, 4.679700914890536, 16.939369440078735, 33.76347218790362, 48.544994784939675, 52.04543559781967, 54.518023229414425, 45.473649501800544, 41.567235531345496, 32.26457568906969, 33.226413419169766, 32.95416562787948, 35.2697015577747, 30.790035147820753, 32.14652215280841, 28.448513515533943, 24.806110359007313, 16.87750385653588, 12.657270854519261, 8.934934696843548, 4.543517203100266, 2.431272080829067, 0.7667010397680345, 0.9211481650990825, 0.853528832235644, 1.0680714489952212, 1.4075014740228655, 1.5555737672313568, 1.7397692511158607, 2.135590824388689, 2.0672984373184944, 1.9642908678900812, 1.519996398879636, 2.4708701237555477, 2.5595492749444904, 3.7386806741837537, 2.336190886074497, 4.1819354699504, 5.118954402785148, 3.1634197360084904, 1.203546682673116, 5.26587805440349, 3.181884538742804, 2.0693449339559002, 2.388634201019041, 1.9519036551637037, 1.2193154687843015, 0.7359213430073954, 1.625526420051052, 2.9366645745692717, 8.33973071267528, 12.749668167483422, 22.468875877318844, 33.370038847769464, 39.402118575188425, 33.29533338546753, 29.135669623651815, 24.047692629598803, 23.33110501689296, 23.55842794141462, 32.78820622351862, 41.520633851328206, 38.7986619241776, 43.46266208156463, 48.36704469496205, 34.49090711532101, 22.369498706633046, 5.623155476585512, 1.3867599805516582, 0.3374181249208989, 0.25633055266113053, 0.06938732589685148, 0.12070809220594746, 0.14746645555621193, 0.09802821242520887, 0.16397257065100057, 0.13518893129883275, 0.23026601982212838, 0.19162595452320194, 0.23743648021932573, 0.10148153760500493, 0.09936067681278914, 0.10865654856447252, 0.16562918982198163, 0.14558403963042846, 0.1163584901200187, 0.14984852934796966, 0.1753305748946244, 0.20032666022739104, 0.12327640197209774, 0.09468387091352094, 0.15489059830865554, 0.11243255763885476, 0.19123474406378885, 0.17573244929794343, 0.13571121940209022, 0.23170628044153416, 0.17620941563960046, 0.21919137617993742, 0.1475237742547066, 0.1304434609389113, 0.1689734700466356, 0.12046926429555302, 0.12715296774742105, 0.14291901892471698, 0.13243887483352615, 0.16781200414463399, 0.22080203007546165, 0.15834357108800642, 0.15874731474586073, 0.18025716376160422, 0.10455414772995057, 0.13974496343683812, 0.16434597722705335, 0.1593488929492812, 0.2779292219108151, 0.19068110764266985, 0.1343496819777835], [0.047158970677804564, 0.040462301187818094, 0.06257397355511785, 0.0812332438785703, 0.0716438685213366, 0.052577640801187486, 0.02622084924951196, 0.03065877552745083, 0.010026608548697927, 0.034957748777683706, 0.08369908938484807, 0.03698800052065523, 0.04096730634750378, 0.03198839581361221, 0.03618686407383892, 0.08081093791031069, 0.05965461931942452, 0.10820693156171231, 0.10197947943402876, 0.01623017788534203, 0.02146373435314144, 0.019311969574060173, 0.07489354454822118, 0.027996219709635745, 0.027759542591088725, 0.06035590386619011, 0.054569254899697925, 0.08722627310142403, 0.07252870773475978, 0.037838208729461316, 0.03899414347664964, 0.09695477768658631, 0.0676890392036688, 0.05027498734453994, 0.03657387254098731, 0.09182257848160882, 0.05782057801561971, 0.020167917696638935, 0.03900470782912547, 0.01447171594331702, 0.012927308543435028, 0.059723050123260873, 0.0531807626717754, 0.036123500941621686, 0.04074578819375846, 0.10034342972381462, 0.026536778163825794, 0.02177232606036048, 0.03977357282213146, 0.027064668285029552, 0.01214824787776677, 0.08153476076380861, 0.09061312483203027, 0.01675160413968467, 0.02037518278455302, 0.07160990784365324, 0.053171604090640624, 0.003964861239036245, 0.11559421782411876, 0.08876073189199933, 0.6960108587818762, 4.507958466006864, 14.22844094614829, 26.61046535738053, 32.282391094392345, 42.214579582214355, 38.73170706533617, 37.313425079468765, 36.26554819845384, 29.75064039230347, 28.042293248638032, 19.793182034646314, 29.00158928286645, 25.428270832184825, 19.238668718645652, 18.75175941374994, 13.83491837209271, 22.124385872194846, 20.18253218743109, 13.139799852525035, 10.577114397479642, 6.858828577303118, 4.472907185554504, 2.1420624900248746, 0.970165902568448, 1.0039253749193684, 0.563228638662446, 0.21851225455682124, 0.30884393400722937, 0.3022905421112814, 0.13504660748425992, 0.17206449692528095, 0.4407171754827423, 0.37794472769864146, 0.2391629666090012, 0.1698409114032984, 0.14916911661144228, 0.08654098447051742, 0.2876782729741066, 0.391447916026077, 0.4844287428404055, 0.4730945639312268, 1.1449059002822446, 2.29492828730614, 4.182623845915641, 9.065817325345932, 10.975513458251955, 16.5768482992726, 16.57321422330795, 21.620218138540945, 23.797535627119004, 22.23110179747305, 17.532133709999826, 20.456586230185724, 22.490729362733905, 19.570813063652285, 20.95319751770266, 20.660847579279256, 29.94103812402295, 34.43120864129836, 36.181801672904726, 34.06512598837576, 20.085884986385224, 8.331820272630262, 2.0103928134326012, 0.18442345632901117, 0.022948723016006332, 0.016778428708353353, 0.020725005343856833, 0.029969196804168246, 0.06527625294702669, 0.08636044819028148, 0.03970525310104413, 0.05645383502386751, 0.07011150881167381, 0.034648413965178114, 0.025703398991496335, 0.10056047009364252, 0.04105074864421641, 0.03859561304712007, 0.06111835287283025, 0.02886670243535792, 0.021711039026418043, 0.0174484568678083, 0.047888336177434654, 0.05368829209117159, 0.07066985667352715, 0.027197831603247794, 0.018147554233550064, 0.07777853207963129, 0.04354368684993636, 0.07172720356573982, 0.050181080286781636, 0.04672577860014093, 0.06845850557569536, 0.008957224499975002, 0.04047838520378836, 0.028016160978304765, 0.05597229130686291, 0.03925006280863478, 0.056180897048644485, 0.051928913716467164, 0.020228561216724977, 0.05542829610227097, 0.08558607119466029, 0.015198249790456989, 0.05320147385880832, 0.03342217149873895, 0.05079132677506536, 0.024400683713235685, 0.023149430391288573, 0.02074690779761201, 0.09645739510174721, 0.024684959789738063, 0.024569129210806662, 0.02787722518757707, 0.0069281903579981345, 0.06448790250766663, 0.0180496979925421, 0.03222422448978309, 0.06023961171928433, 0.023903052149821195, 0.04387835235965829, 0.0245716055900219, 0.025100547166901733, 0.04699943286757316, 0.03856971161440015, 0.07563706352225236, 0.09810810773483208, 0.024692971154206225, 0.031554443393683726, 0.0711781100460118, 0.057568090757535356, 0.025338156997496565, 0.0437845908586056, 0.014004465511759684, 0.03544974576441511, 0.03796305041760206, 0.04295885149810103, 0.034871713273347385, 0.027051759703505426, 0.024896486241730954, 0.016850054098833955, 0.10182642272763676, 0.02593577452634852, 0.06423818465742855, 0.05103025044645033, 0.09019555328714271, 0.09460014516427633, 0.05355929437604162, 0.029434032678123445, 0.03160004669259633, 0.041622629449252165, 0.011097108212960585, 0.02205873760695179, 0.027890658539329326, 0.04529703228223709, 0.022917784555184267, 0.041092071426852096, 0.06036415846357423, 0.0068588172660149155, 0.023333942667851527, 0.026582753015381676, 0.03725839508396964, 0.09560349051870647, 0.05296721949332184, 0.024089604135482542, 0.035959152099225795, 0.05467800491098916, 0.05967369107829948, 0.008793358292971409, 0.03254665174491463, 0.021607781865543896, 0.0424689804053595, 0.042697083084814014, 0.15313786574669425, 1.3660905606323674, 7.925585787142477, 21.11236337692507, 34.19623905612577, 42.327516386585856, 47.43233603815879, 42.20479326863443, 36.117890573317005, 31.996554251640077, 24.014395629206014, 24.039749829999863, 15.188536163299316, 23.664841844189553, 24.843582722448534, 25.719196950235677, 27.472990635902654, 28.34694177873673, 29.482915093821866, 21.182773843888317, 18.426667490313132, 13.111852965047284, 8.149567342573597, 4.723048988849887, 3.1433497032811566, 1.247443643308455, 0.49594616998107205, 0.49391079694032675, 0.2555760326645067, 0.36468101845633605, 0.3279061627484137, 0.22529853718175044, 0.18493013156037177, 0.27163960940895543, 0.18780944238026298, 0.26954616690354966, 0.3092181526364819, 0.17248501790867699, 0.152710112893293, 0.13640645951513322, 0.20657639019191268, 0.4846974251972091, 0.6645688330454211, 0.6138664988740798, 2.929961734241055, 5.343065396431954, 9.96815368052452, 15.207161538062559, 20.941453941406746, 24.84232952517848, 28.56311928841376, 31.828423815388835, 31.2744596312123, 22.655288480943252, 22.395778586787564, 15.8730907594004, 14.28345807137028, 17.19321347052051, 16.714931418818814, 27.399146133853545, 37.6323216192184, 39.33219840449672, 40.65981480383104, 28.20296333682153, 13.267358272306382, 4.659483548133604, 0.38933225697086704, 0.045686676091845, 0.06735948350040183, 0.05734556136772998, 0.025915980729604923, 0.04404490753527611, 0.037102925200616164, 0.1138585996663859, 0.038797603619675484, 0.0574703264470783, 0.024167205011772535, 0.04860493482180661, 0.10813573901090892, 0.04601936126428266, 0.09765174149745896, 0.08347712306966705, 0.07090090879149015, 0.04174252603984168, 0.031529671940652114, 0.005752000246091836, 0.038327827013187835, 0.07410410626400864, 0.031848540717375376, 0.04218646250064335, 0.12681744421922392, 0.02606166575494553, 0.07698216836058325, 0.058801913663985274, 0.0775130826138681, 0.034222959375549714, 0.03240869463151021, 0.02806990204619304, 0.06194615300985114, 0.08992398277886453, 0.01019125520777438, 0.04093354485268074, 0.09353369714752321, 0.07108683833071301, 0.021943579270173947, 0.044883360124884114, 0.059179671619447975, 0.0038778183290794975, 0.047062769186713045, 0.07101267335876342, 0.07649125155782507, 0.02124959362610694, 0.01530418059818687, 0.08203735274653282, 0.021192326638547164, 0.04546871258606834, 0.02111323763646426, 0.2595889237859557, 0.21008366328333655, 0.09356847753928554, 0.17450621832282315, 0.16048408203548, 0.17703184166983252, 0.14143729762684915, 0.10425475290826253, 0.11346658481465233, 0.1881055200412389, 0.1833478382398044, 0.07560684901451872, 0.16418716720035, 0.10200808515712138, 0.11314004749780703, 0.2174698693617698, 0.2086021871336045, 0.20208958175874528, 0.23687814001835164, 0.09466272688681081, 0.1265688793313119, 0.13672198048762738, 0.16058807081032186, 0.102222781297901, 0.1687709623647313, 0.15469700789018986, 0.14010905438373167, 0.25485920419375746, 0.13634889566850278, 0.25200661452066514, 0.13218410463342745, 0.33756444771443644, 0.2225032815289113, 0.18854788985223542, 0.1441761232431858, 0.16260537949781265, 0.11641511167850226, 0.08930684532970191, 0.1809608614853313, 0.15814910732930706, 0.13727281302694352, 0.1831403356646338, 0.17725520226503574, 0.15712120119602452, 0.1789221483012361, 0.1627682191469977, 0.13542338484717956, 0.12428007674433532, 0.2608922538497756, 0.09834999999692363, 0.17259567164846007, 0.2665455230782109, 0.14160085739868303, 0.15942692666524844, 0.16316629375421232, 0.12729896112315117, 0.18827718502331167, 0.217462714100557, 0.18013563157329637, 0.18484033073388761, 1.0112455595404872, 7.331585970617111, 20.232493377500965, 36.519702096139234, 47.85640701170891, 58.22323137714017, 53.33034523071782, 48.34729163877426, 48.815838367708274, 39.86696258667977, 36.52203982876193, 29.12240416772904, 41.12312909095518, 36.572544267100675, 30.38459151021896, 31.01785032979904, 24.31111312681629, 33.80831664608371, 28.396791181256695, 18.93021745066489, 14.322562140803184, 9.084252465155817, 6.411673964992647, 3.1440763223555783, 1.8612244629090833, 1.393066538918403, 1.1206803615054777, 0.5703428375624842, 0.6770884257651145, 0.8950807670912436, 0.6436067675390552, 0.631475612040489, 1.1217440592665826, 0.8674999470672301, 0.6820360667282536, 0.6673490580531859, 0.3420745605422605, 0.5106433523037742, 0.6331588604277181, 1.0055426171710415, 0.8556617435909087, 0.7942118087122518, 1.9388003647327425, 3.7265887423869106, 6.1323281545792865, 12.372607781041054, 16.585689321641002, 23.304776107111287, 24.664257841725505, 29.267567165436287, 33.60152536822904, 32.06583115362352, 25.395470011618833, 27.83334074481841, 29.539565886220625, 28.480453375847112, 31.825591864124423, 31.4667950137969, 40.564069747924805, 45.47638731618082, 48.515526017835064, 47.70344241972893, 28.960131791330156, 12.956478076596415, 3.6841685541214484, 0.33163783831461785, 0.1288171941714902, 0.17031266834707032, 0.13472501909540546, 0.0902985308259245, 0.18190157149107228, 0.198479438380849, 0.2860486200980602, 0.16588889362831272, 0.27058608529548495, 0.12160356471975967, 0.21378153905032143, 0.2163481787447968, 0.09315175635199394, 0.3772140943234967, 0.17069228023530977, 0.09842896067927923, 0.21732302562844372, 0.12470562326451465, 0.08979045365366245, 0.1797954425696404, 0.21395369432866576, 0.15090756929449498, 0.26639003787309895, 0.28245462585360775, 0.13122635683225048, 0.1628029535734846, 0.20217768187003754, 0.18147070832069845, 0.13996395733087294, 0.09220821182093314, 0.24546218585343133, 0.09203473887135906, 0.15523680876339638, 0.09679242067279355, 0.13554678629002265, 0.18994089816847157, 0.20465009274982637, 0.14794484682140813, 0.3289586449823072, 0.15877069574930977, 0.1886144475710969, 0.15310349904241102, 0.13226511077054087, 0.14963586334018938, 0.09678110555415192, 0.14238784420153788, 0.10836429368223875, 0.09814386105825824, 0.13295932432576535, 0.13980759878552732], [0.025613546454077287, 0.06147866317581746, 0.09282149584783662, 0.02859700884249422, 0.04094315159525122, 0.026769655486268383, 0.04024085198198596, 0.02612882676804739, 0.014097971330967643, 0.021493293855699803, 0.029083543622325507, 0.05579126856079506, 0.008436232042919484, 0.012607056020398535, 0.02400997695663283, 0.026587502760512215, 0.05194636136894265, 0.049553991355482614, 0.04124536562050062, 0.11573667953451795, 0.03967090171851939, 0.078681719098841, 0.07140379954850481, 0.08067304974481945, 0.07197937672777523, 0.06516468756261372, 0.031239950894227916, 0.042732706173293056, 0.07732211987698272, 0.05201383456287365, 0.03805333770991814, 0.0564404093329945, 0.11426159255807439, 0.01906578338915302, 0.06588412073230551, 0.014680435640677331, 0.015028178271266722, 0.03018687685741292, 0.05526141150884571, 0.059453532730619756, 0.09521273971204797, 0.02827699476432416, 0.05467082283669903, 0.05175951252421064, 0.04347764240998415, 0.042044636643221306, 0.04681382891571811, 0.035056102975842454, 0.020666775000732274, 0.024055245092078566, 0.07005422075669612, 0.061620948685994076, 0.05465941578750649, 0.034130672593751264, 0.019422489248456496, 0.022588096701750354, 0.10058460186325735, 0.02187770720000469, 0.04328032114332722, 0.018876213017070008, 0.048113638805525924, 0.015633048737541805, 0.8656801511683773, 3.1917944069831603, 10.773803610955516, 21.54482233908869, 32.81434293716185, 33.43078459462812, 35.5609610772902, 38.52753200838643, 34.99527685103878, 34.93710810138334, 29.42202421926683, 31.788341114597937, 27.385896367411462, 24.315270839198945, 15.711554808001365, 20.83135889422509, 47.48810821963895, 25.52406099534804, 19.553032959661177, 21.734366955295688, 17.020942972552394, 17.158782905147923, 17.431052269474154, 12.172844409942629, 12.6951374161628, 10.78026669640695, 9.588977175374186, 8.37627935794092, 6.50986461870132, 7.006525916437949, 5.304236873503655, 5.111825004700692, 4.73726071657673, 6.192309529550615, 6.297812952149299, 6.642154397503023, 7.327851383916794, 8.827288189241964, 10.599271866583056, 14.52805511413082, 19.749078904428792, 20.63764479852492, 17.797491858082434, 24.356192927206717, 18.94396339693377, 21.288654304319813, 23.806725740432743, 26.924943347131055, 23.37855196768238, 23.34939306782138, 28.218460621372348, 24.519596907400317, 31.225096602593702, 34.31290603453113, 36.74915682884955, 36.80749031805223, 37.172780652200025, 33.48737262910412, 28.81300368616658, 9.391934948582804, 1.9440633274855155, 0.5610770347618288, 0.04848084773027128, 0.05348325631911716, 0.011071441394667472, 0.0530111852792963, 0.002853021794562078, 0.1589449654303251, 0.020774479302006866, 0.0655827647255313, 0.04908120019301292, 0.0154490641040367, 0.029332612213047764, 0.06390272624670498, 0.031621523967553536, 0.027827839329538327, 0.03744778351017064, 0.0205165145152639, 0.07058428465238503, 0.0622776392546873, 0.05671069664399951, 0.03821619268086168, 0.02393923065204534, 0.09767988756779702, 0.05960231466639427, 0.10372288104507232, 0.02960592557135369, 0.03307267835724258, 0.023462507543304277, 0.018213813178121083, 0.04693261084837779, 0.030846470899339166, 0.028144750751615055, 0.01054848104925646, 0.04403191085364069, 0.09512734389112842, 0.02784300787043908, 0.05688845585550993, 0.016194106635427283, 0.03447511721582663, 0.04384938657524125, 0.027749771139614528, 0.012307931244703791, 0.10153229859086776, 0.05528166687356369, 0.05544495468418445, 0.0346147099269494, 0.07450595002381072, 0.03051327436321205, 0.06277176213540858, 0.07258427975278708, 0.058431544626552256, 0.03933701378804061, 0.0682774483556709, 0.03963451637255569, 0.015673094068563754, 0.01712343257461344, 0.01717860048126069, 0.019706696377045686, 0.026398051132057464, 0.11490847720133682, 0.05498657363557047, 0.025243790286983696, 0.0259161377776294, 0.036391187384123766, 0.030213737815258004, 0.04382738836049553, 0.00867046342576824, 0.08083770502238505, 0.05006609431978676, 0.03533542629391436, 0.08617087207253903, 0.07860117261448214, 0.06762624297651552, 0.03541897967337601, 0.08658620664068768, 0.03556212703246744, 0.06428432996354758, 0.07283086813385449, 0.05718804219917906, 0.03477995892265632, 0.05524528918847923, 0.03302811885312681, 0.06003796588629485, 0.04972309760388829, 0.025409506596324426, 0.09859501023686702, 0.015225368345366612, 0.0277082989698336, 0.04650006228457055, 0.06945681773246297, 0.02967242008796142, 0.04560973022073027, 0.017930578981195728, 0.06117593204121917, 0.07337731865024374, 0.08179961268099085, 0.035569243989284, 0.04056280043216483, 0.03888883703057805, 0.012204821555755072, 0.032873418888137225, 0.02100445315121643, 0.059252212484998096, 0.05159874131242114, 0.024384197501105168, 0.02816197815381231, 0.022220868624806888, 0.0503122077263411, 0.029876695517751, 0.05424635650049295, 0.07518638931815663, 0.037707713312439384, 0.038377094127598314, 0.036615260441096566, 0.10376135398062969, 2.071914331566903, 7.051868515629923, 16.87712730899934, 30.796097170922067, 40.00174307054089, 44.7319410693261, 43.77590648589596, 43.34943109943021, 36.12868493603122, 30.27621642235787, 27.83010086705608, 27.292947961438088, 19.493754179246967, 18.91594590679292, 16.89920436951422, 30.972694043190252, 44.58852744871571, 31.446057442695867, 30.287034319293117, 29.128646619858284, 27.79929064935254, 21.993580710503366, 20.7293027447116, 19.025493783335534, 17.39146182613988, 13.085385791717037, 11.907011655069168, 10.561935805505323, 7.331497226991962, 8.28145900080281, 5.6001242995262155, 6.167332856885849, 5.275440302587325, 6.604992391601686, 6.274779323608645, 8.967418786018126, 7.209554170408557, 8.242392193886543, 14.097172944776474, 17.110506373067057, 24.870437229833296, 26.48020148277283, 27.80895340827204, 34.29741267235049, 25.670900806303948, 24.611452933280702, 22.93223527169997, 23.553050371908373, 22.251101962981686, 21.735237721473943, 21.7401740243358, 20.92326394973263, 25.669000417955463, 30.463205614397605, 34.34529696741412, 37.77767681306408, 41.314525065883515, 39.66709036980906, 34.785700690361764, 15.773866561151321, 4.956454528916267, 1.0854025641756675, 0.10782986308538145, 0.02006476587285438, 0.022773120342002764, 0.025111596069989667, 0.056746158854014454, 0.058905270416289575, 0.0656008750440613, 0.03742595000432865, 0.0315702592788805, 0.05812056272500946, 0.016572280193588907, 0.05207447425252007, 0.06636487920918772, 0.029931911304893515, 0.015999030006388505, 0.024377906004027016, 0.06756626595292362, 0.00862864651642139, 0.0387746975907395, 0.032490895865785505, 0.05525664261151707, 0.038338678648635265, 0.04071224886443346, 0.05120982528634129, 0.02581411593353316, 0.020374301783440095, 0.08223640537189861, 0.03131546418092424, 0.032763688284302914, 0.04240167575077184, 0.030970220912187815, 0.012751632133468747, 0.05044931448214958, 0.011935587615645941, 0.012500147492955289, 0.08499036888561903, 0.03231504804364616, 0.045275447754970485, 0.02235092162605255, 0.035701114534130024, 0.05504011169015881, 0.02235689328142232, 0.0710914348582587, 0.03778958512890724, 0.04326651240849207, 0.11200895698200311, 0.03667745145878965, 0.026055661540838982, 0.045731484574536165, 0.0592300035960732, 0.04281769596761273, 0.04078310050611054, 0.160529357831805, 0.18943958555258092, 0.19801390207102224, 0.14445199150471918, 0.12664173429291095, 0.0777449774285478, 0.1848392888543106, 0.2930835135761769, 0.11389003225391912, 0.11525969787110245, 0.11082542008690296, 0.31049617115528355, 0.13399346641475154, 0.11927654966712, 0.1586629071783635, 0.1570448528734907, 0.19202441217437868, 0.17340188725821434, 0.147580326865277, 0.23846507583174015, 0.09461376620757003, 0.1199532657741539, 0.0946386717259884, 0.17517243902529442, 0.1496629981744674, 0.11532792566163887, 0.08444276923734335, 0.2095037960116902, 0.17824411452297242, 0.10384324111885603, 0.13886796130288032, 0.16675593661925486, 0.26469428693094565, 0.1260828425086314, 0.17680627474140737, 0.07691430829225049, 0.11148772608008116, 0.26182850522379725, 0.12635339411997026, 0.07755327158637586, 0.17559911935560166, 0.16397915900714938, 0.17686515625926758, 0.15813741682758256, 0.10881022580208317, 0.1961036311883119, 0.12314461186648377, 0.10731069295997582, 0.12986897160449337, 0.2141853286734512, 0.1018748394844513, 0.11205864544477194, 0.15076463260958273, 0.09589879443087886, 0.2025029781244455, 0.1869829714057907, 0.1468992440570747, 0.16625874555639683, 0.23123368080104553, 0.16749501228332522, 0.09921002562247938, 0.13211969196075393, 1.7162379718595937, 5.718424945108353, 15.397928953170778, 29.749342087776434, 44.661099141643895, 53.5031452486592, 54.580687015287346, 55.97432474936209, 48.463323193211714, 47.533945037472634, 40.566132914635446, 42.03822589689686, 36.20326488248764, 36.22015068607946, 25.091048978990127, 30.9916587029734, 59.7460170715086, 38.07440803896996, 31.073353828922397, 33.30319381529285, 26.682209430202363, 24.623445580082556, 24.293623278217932, 18.33394854299484, 17.975383112507483, 15.41731526774745, 13.239157411359972, 11.415947579568433, 9.217710129676327, 9.22484492101977, 7.511332996429936, 6.831661260897114, 7.269327169464481, 8.519191895761798, 8.059431766310047, 9.486824927791472, 10.790114787317092, 12.592828273773195, 14.887830595816336, 20.22536054734261, 28.158493464992894, 28.762638491968957, 26.127199934374904, 34.104702703414425, 26.996965908235122, 30.161147809797722, 32.44141770947364, 38.567795138205256, 32.64047211216342, 33.29688664405577, 36.84976562376946, 34.76754403883411, 42.62512230104016, 47.09842466538953, 48.56781905697238, 49.541284653448294, 49.26269831195955, 44.510182026893865, 37.3653180368485, 16.043127467555387, 4.493190742308094, 0.883619724021804, 0.18401654106715035, 0.11325536671304896, 0.13491231227113357, 0.17317595260758556, 0.135411188727425, 0.3703472192489332, 0.14530251764001387, 0.18825450882075295, 0.15412878515499254, 0.15118003612564457, 0.14773622575786807, 0.15846640562578557, 0.13341882386274878, 0.16047084403614845, 0.13698703158766995, 0.10936886477734774, 0.14214470321612974, 0.10076980361895216, 0.1423284111003722, 0.20487559839121758, 0.14031666421121167, 0.2731185268250204, 0.15413073101832023, 0.1864372103685333, 0.12075465502998523, 0.14857676210663012, 0.2500800566086846, 0.1848238445217571, 0.15404210996723947, 0.17184610057982708, 0.10527001859079446, 0.10268313885335961, 0.13654299170499848, 0.16574185071212633, 0.10747028439636193, 0.25966951623559, 0.1088947942480445, 0.12230534722367603, 0.11819488714419066, 0.22452671891979634, 0.12262941007652592, 0.169345696847285, 0.1654851652922169, 0.11281207759654331, 0.08706149524979054, 0.21618235135270705, 0.14275211900953325, 0.14045894206050905, 0.2111721669714297, 0.18417210288105473, 0.1924272671702408, 0.19498797734418225], [0.05049379354703331, 0.029186063423572533, 0.021996345491178577, 0.020659696348311923, 0.02902632643048081, 0.08453596383333208, 0.008208519110696451, 0.004319532656095802, 0.027871042858028126, 0.0037876504985991147, 0.048281270334677356, 0.04977943954027949, 0.06949891426390217, 0.072233013117746, 0.006698442504726231, 0.07177751255972732, 0.04924432329472996, 0.05334752086069315, 0.016024682460533037, 0.04023724753830222, 0.025662775264091553, 0.04025908487458383, 0.04210614201222216, 0.04932682330329572, 0.06587720295834927, 0.025272355790460305, 0.06705093392801863, 0.04608367434552601, 0.040455421718258056, 0.028794722729212338, 0.004733799489199995, 0.05551594039124828, 0.0450828226072894, 0.10034610337067036, 0.03526330294628297, 0.00562558185324193, 0.10853170687633176, 0.010671936118254259, 0.037008692555490046, 0.016331060173650904, 0.03797683233935987, 0.0839332594806629, 0.010780950429879371, 0.052097594786074855, 0.08020411200460889, 0.05629423975704178, 0.055421661780846704, 0.034023228762370926, 0.08398536878127245, 0.07489695363948423, 0.03332284436891637, 0.062428187023127274, 0.05932770278905669, 0.028128724192239107, 0.014823441273502767, 0.014548070011510244, 0.021762361171685403, 0.06613822443591011, 0.07414021198787997, 0.12019484394019651, 0.00968658425394566, 0.02154791783992081, 0.026256288476889173, 0.015369686861372283, 0.2588561453646229, 1.5348440408706667, 5.774096615852849, 15.06717508839023, 23.883576739218928, 31.686514423739528, 36.050163007551625, 45.56071043014527, 47.86407524539579, 36.97542659697994, 36.496097272442235, 34.07434748065087, 35.43590414908625, 25.892228388017227, 70.51395477787142, 46.9554268160174, 23.43026645721928, 25.230271547071396, 15.645878641836106, 21.226514154864898, 13.364456545922065, 15.094062935921455, 14.178745496657587, 17.09077488991522, 17.123820858616984, 18.270378689612112, 24.1020429518915, 19.477650888504524, 24.363262999442316, 19.21998254714474, 21.495665234904138, 21.149971062137237, 21.221948515984323, 19.000455333340554, 33.29564717508132, 34.046400593173125, 20.324631814033758, 20.283923495200373, 22.70080758679298, 19.408205324603667, 20.890565110791115, 18.938703498532696, 28.568953814045077, 24.991458039129935, 30.7193991445726, 31.729762477259484, 31.90965806284259, 36.49324963169713, 42.11443362697479, 44.04366708570912, 42.09340972285117, 34.4695419649924, 28.930300204984604, 23.91494785585711, 18.080302592246763, 11.477357187578756, 4.046240338394719, 0.9192062854286164, 0.02533683358060737, 0.0557288860211209, 0.04516668625236039, 0.05183871069382276, 0.03225897040758883, 0.06257124245166779, 0.05942299263551832, 0.023928832923693043, 0.022536613678018895, 0.0213592074015328, 0.033790648298999, 0.033828715207956495, 0.08285679103386018, 0.019793842708872213, 0.12098659580994038, 0.04790126774159651, 0.009619123508943426, 0.02508920331996295, 0.03959715043404891, 0.01687913288121983, 0.02910422608106127, 0.012255423578373607, 0.04437684194154797, 0.02316820529109288, 0.05553030837026816, 0.04098434031250016, 0.030875741203706113, 0.028729955740873853, 0.017826235890688918, 0.008517476624899335, 0.06374873874348498, 0.013046045468429164, 0.012694343120881147, 0.028997492796230703, 0.07455560784306257, 0.03848077263683081, 0.020925722295238126, 0.035155583323249896, 0.01831986655991885, 0.00259238240335347, 0.025451620364741936, 0.08881614303156253, 0.01774926895215627, 0.06008853918061622, 0.014976808245504096, 0.01906583510008791, 0.03511678096988509, 0.07826167308995802, 0.038167300949534105, 0.034183283681951226, 0.07053219067353396, 0.02198024040779039, 0.008265426994541721, 0.09365952708908627, 0.020699165198170853, 0.062751755749266, 0.05589711892929289, 0.031233893053966667, 0.03808046105287729, 0.0805085476848387, 0.03531350468796107, 0.034919455872788545, 0.05148647495755746, 0.03987381159658394, 0.0755495532986618, 0.03002258164117173, 0.10838124720800309, 0.026212238421243046, 0.01876526816387571, 0.029255279467531273, 0.03540844213397753, 0.06607198847397681, 0.025522477752078446, 0.0863991662739746, 0.08820330333565513, 0.014487460007770889, 0.021783076189157945, 0.012231099329167798, 0.04911253318911599, 0.010158661997035868, 0.0435821712768126, 0.027404135250816905, 0.027065122192124688, 0.07678916016894002, 0.05997199039425581, 0.03116883878265658, 0.04981248091245371, 0.010846065030613495, 0.03132839957552572, 0.04332667712362544, 0.12870822582514058, 0.03924633196044353, 0.0401739418626793, 0.005840895173605532, 0.06593239959329367, 0.046310352101441354, 0.059979831304160826, 0.03564838087186217, 0.02875979678074439, 0.07827665776975694, 0.06573710079875685, 0.05548322460644188, 0.03873715545201013, 0.10035456098135441, 0.04361277265894798, 0.04947823292065052, 0.08782816540089347, 0.05026172636257065, 0.03499440608486053, 0.05206857920594273, 0.029794496198695515, 0.033566996590384555, 0.017859420904348937, 0.07303096263879731, 0.023442734813978596, 0.028031111184147098, 0.025120496096449996, 0.05879136080282831, 1.0169489309191704, 4.018578313050732, 11.413419611992376, 21.19811031126207, 32.418048227986986, 39.35458337107013, 44.60781766522316, 52.28347639883719, 48.79589703775222, 36.99824694664248, 31.915447481216926, 30.24789494852866, 19.60377666258043, 20.23657460366526, 71.93237796906503, 37.90185905271961, 24.926529084482503, 28.406777535715413, 21.409478995107836, 28.766605969398256, 27.752149643436557, 28.299649761569118, 30.590557129152362, 32.87744602849407, 29.538575487752116, 31.369990917944143, 31.711199860419, 29.19205761724903, 31.822779524710874, 29.853688901470555, 28.63478687501723, 32.26316951936291, 32.670248785326564, 28.552389644807388, 31.88535897962509, 39.84516205326204, 30.57635226557332, 28.99577044671582, 33.264103474155554, 24.31178777448593, 22.42654173604904, 21.42573133591683, 23.803711398955315, 20.63513252042955, 26.739164206289477, 30.39780205295932, 30.729181535782356, 34.646338878139375, 40.34491123691682, 43.29299211502076, 44.827913622702326, 41.484908903798754, 39.84503261504635, 33.458288254276404, 26.133054071857085, 18.2885588753608, 8.114961741432067, 1.5286713333860522, 0.0558906416558931, 0.0889819551018938, 0.04680307687170083, 0.02695510430531877, 0.04224803681755739, 0.07370436158511909, 0.012674535917598876, 0.05907133529563585, 0.03998449214944436, 0.016452862407952067, 0.10013868506517141, 0.035190018975446304, 0.03986346557916653, 0.05201186188646863, 0.08239192888140678, 0.014633721514274518, 0.013572527903072057, 0.023775142279543707, 0.059926672463095, 0.03798832365822408, 0.021462104501082532, 0.0484565818952697, 0.01346878714919571, 0.04698476228382319, 0.023299183343507113, 0.06262024909618401, 0.03205940833375339, 0.04011501820998327, 0.053920550797615326, 0.03826431449382536, 0.07234170567244291, 0.12086635831022456, 0.045087124190984235, 0.04823840005443462, 0.028646685813944188, 0.028794360752668113, 0.05163951251175135, 0.064987123703524, 0.053765563549654144, 0.06481396484999888, 0.03492555776310544, 0.025893789077658328, 0.024857235726930445, 0.020615667360083714, 0.030688015188300805, 0.043841591630611694, 0.018323348429534706, 0.10284289116820983, 0.024291594708037954, 0.03160721152990816, 0.08178560093285576, 0.05310655939542959, 0.03694514173173136, 0.039097258911257794, 0.16326148783968342, 0.24767167535760712, 0.1376789162356046, 0.10564707174536683, 0.11480168454469213, 0.1847516637175314, 0.1377427160379387, 0.1384346619729073, 0.15260189531310914, 0.0675373231511443, 0.13144809332105423, 0.16993189200518594, 0.192115101662855, 0.14577379960927273, 0.09535445065628137, 0.1473129621797031, 0.17029236701707687, 0.16127994013649805, 0.11111710040319352, 0.17906284800940947, 0.2307191301858233, 0.18148010055865013, 0.1739003500270267, 0.12027355947441633, 0.14151425881972238, 0.12573389712000085, 0.17474332253538793, 0.16162861739435505, 0.13466858905890297, 0.18127040697201607, 0.23282328260041055, 0.09524870754009294, 0.1787535936361359, 0.1847032163171999, 0.1307785171534746, 0.14392181269584164, 0.1792072862266533, 0.12305514045780706, 0.1385049275573223, 0.14519129699516684, 0.1473411848588336, 0.1253780339574141, 0.15493775868127424, 0.10320372624142517, 0.10774665061504611, 0.13191068785325175, 0.1413032015965831, 0.11990474942590922, 0.1317144161270511, 0.16021074186409676, 0.1364952950708328, 0.17566420618564854, 0.21013955705829207, 0.15218670630166609, 0.14590503047070197, 0.1363558057815798, 0.09362952708597146, 0.08697754733504788, 0.14707743610826232, 0.37985740409743407, 0.1118847128424433, 0.17715061594161297, 0.1118785381737736, 0.20931103296818274, 0.6002195311650154, 3.18351379325313, 9.816391295002354, 20.73617277606841, 35.277197207174, 47.26066174045686, 52.14304770192793, 62.894538910158225, 64.1468575692946, 51.345061102221095, 49.80480517110517, 47.03849477152671, 46.587928187462595, 32.50505228196421, 80.65142246984666, 60.52310136056716, 34.714941132453184, 37.13378052557669, 25.195562493416574, 32.263473503051266, 25.2685401516576, 26.167657221517256, 24.467990283043157, 28.039873146241714, 26.74650296088188, 27.79837085354713, 34.51280178562288, 27.85866552783597, 35.50482411538401, 27.65889725377483, 30.633020708637854, 29.95983804425886, 30.433368144496797, 28.629676026682702, 44.2767107871271, 45.32208519597208, 29.08438071127861, 28.89900165219461, 32.170054412657215, 26.61291683873823, 28.614796515434023, 27.719288026132894, 36.83519009620913, 33.314580455903084, 41.516374157321074, 43.443273805802875, 43.64465613518992, 49.112604894945704, 54.09087711764921, 56.75166399248185, 56.50770825724448, 50.630919087317686, 46.88684417355446, 36.29156135743664, 26.314540178545062, 16.859984590161233, 6.563315247335742, 1.5614894368956167, 0.19086473891811986, 0.10294813632724747, 0.15611025624938552, 0.22024270928194448, 0.07597588888940311, 0.14235369200187345, 0.13035278677219345, 0.19241064306228392, 0.10842164302425039, 0.12617817448992885, 0.1701922546471319, 0.09225442990540497, 0.1553297352286116, 0.12441993375579197, 0.18407381380036955, 0.1708568359214452, 0.18206266445978997, 0.08223309587206572, 0.17268433866481628, 0.1254824287588558, 0.13116931392540856, 0.12966085615898335, 0.20142742132227268, 0.11516316313176386, 0.27234229589662245, 0.23244687295969457, 0.151714091339419, 0.2557876874362269, 0.15511141549195015, 0.19644153724995353, 0.15886570597367902, 0.1320642731603115, 0.08038405073626388, 0.1585177948037463, 0.24673625135854368, 0.14448536229470085, 0.23168544284999373, 0.145803339959633, 0.14791959656342385, 0.13938073459411823, 0.18796126568509688, 0.1597702106641185, 0.195519519789565, 0.1703761463924762, 0.08379601482902804, 0.09164502228339834, 0.1663572797852178, 0.17599662705775232, 0.1537537238290233, 0.12544465296330953, 0.2302679197201806, 0.07407939992845058, 0.17437581483635212, 0.23344897725168737], [0.0782459223222348, 0.12436380249357994, 0.06017361707504719, 0.016423977062767072, 0.08487815232647043, 0.123304869799364, 0.02602669958686156, 0.03942470787273299, 0.030799818059970296, 0.08095156100969161, 0.03386713834779878, 0.061926092997553854, 0.05532424987083482, 0.0069277172987048915, 0.1538609761384226, 0.022192622963038665, 0.02322747942901427, 0.06444985092046761, 0.005837808796880587, 0.050276998325341174, 0.005982184290675627, 0.0359799858603266, 0.0555347555106686, 0.06304509847635223, 0.0051244995425335105, 0.03409440216097621, 0.02343927401178066, 0.06039610816045635, 0.03754229960782874, 0.05275054684569759, 0.01851275600793381, 0.02785657337235828, 0.03740349596726798, 0.03899378341532523, 0.01934375647725838, 0.03357838448737899, 0.04257550876167032, 0.03856356758924742, 0.05203222833393563, 0.026418452053481055, 0.021242229605934793, 0.029043346988938512, 0.05021026823669673, 0.06917443772357318, 0.042347961495960915, 0.026713177569270618, 0.060937199891815265, 0.03138538885621294, 0.04817467303045335, 0.02125680442869423, 0.07033868452473994, 0.03748201997950673, 0.02982032102262301, 0.02881789497370201, 0.0722107659244249, 0.058957456325691555, 0.0516063217524319, 0.08561050173856559, 0.014318122975378027, 0.08720365818589927, 0.01640864764340222, 0.060872319905507954, 0.03598609158108312, 0.02773591069384448, 0.032427528903128645, 0.05924757382261658, 0.10813766955247811, 0.1950716035019967, 2.22282997542812, 5.757241700926135, 10.967603018206935, 16.150410175323486, 28.5841392701672, 36.88361960072672, 41.64920914557673, 39.06879948031518, 46.848416712976274, 41.664631905094275, 50.398102883369695, 69.4625634531821, 39.238312552052165, 34.28621430550852, 33.69852558259041, 26.16785334002587, 27.410015021601033, 24.707896171077607, 28.101985839105424, 20.64089055984251, 25.605487438940234, 19.8545475159922, 21.7587346799912, 22.0176758304719, 19.09514723285552, 22.625449049857355, 15.16659736633301, 15.541946618787705, 22.869608748343683, 26.628235655446208, 71.40151654520344, 49.04858004662299, 22.91747343155646, 25.700897132196737, 28.126508497422744, 31.27680128620517, 29.01524893699154, 32.26340093920308, 42.526086376559356, 41.312705086123565, 41.65399443718695, 43.8508943588503, 39.94326445364183, 38.735327413005216, 31.44938361260199, 24.3525686571675, 17.9423116483996, 10.310588363678226, 7.607946367033067, 3.2411473845281913, 2.029146890967123, 0.584891276253808, 0.08997491996494994, 0.031377779687905026, 0.01222915059301041, 0.034690606257607864, 0.03860286789976301, 0.029868559663995143, 0.01346668232262375, 0.05746849549693927, 0.027023891340039914, 0.08593163047466548, 0.040013622642765125, 0.026270955230199525, 0.04447983480208824, 0.05558333314594723, 0.03948364684718751, 0.032937371908056165, 0.04775451210838172, 0.05658673212653207, 0.06307636252454212, 0.043531797165351535, 0.021416623776237813, 0.03673951224153561, 0.023180246278042757, 0.011820191791611574, 0.04127562992394932, 0.09558814577758314, 0.021583899074504455, 0.010950957789205977, 0.037633337666310614, 0.020336246365801464, 0.025680627027947097, 0.032483897652597196, 0.04369131965382446, 0.05019855475233448, 0.08116715347334262, 0.0520300220007137, 0.07863597598888221, 0.055608905160859715, 0.009065801183873368, 0.029494335289083184, 0.0374674643089454, 0.0436268610158755, 0.0844042809800275, 0.047373276113742785, 0.026599271786248973, 0.04860536383104421, 0.014823796546777651, 0.03566799655316338, 0.031039858304504907, 0.1146619730899411, 0.05663839326570592, 0.09079646499406907, 0.048068393652717915, 0.02708056269423856, 0.0164127960095122, 0.02445584012856407, 0.04317042966102881, 0.004963732639988584, 0.005916824541805733, 0.05572121748099885, 0.05037930170674959, 0.029200626755013104, 0.06360109444827804, 0.04016580983936306, 0.06484087751877886, 0.03593796593767982, 0.01438650494110921, 0.024755143019701206, 0.06299544448753999, 0.03103874556179489, 0.01315820840142307, 0.014601029669715753, 0.046455253801879384, 0.0034736432679628414, 0.020377574894096584, 0.10503640773916438, 0.009993438856796393, 0.05031503842122132, 0.09599263254072397, 0.0469043345430926, 0.0595861233981146, 0.04989890712163141, 0.032408683140191345, 0.06532243272710232, 0.04506491147161973, 0.05258240586807651, 0.014400109705034525, 0.04176287333511057, 0.0695559571707441, 0.06025433975962862, 0.02143303146435609, 0.02197922725651053, 0.05567805225690527, 0.08157109631405723, 0.01581206337563814, 0.01704882518688758, 0.053426198090516755, 0.017005924263127872, 0.035811557599733916, 0.09689621792565431, 0.05684198496202308, 0.04789082596318857, 0.024456788162370364, 0.07457221662926097, 0.059430910154215755, 0.03636420576743061, 0.01058072664759933, 0.014061582154564321, 0.03384877138981416, 0.04759625749542348, 0.0344221001010268, 0.030811255752679803, 0.09486511965552646, 0.06447587492725541, 0.03353636839517182, 0.05300672664757698, 0.015772920113147026, 0.043885277794493784, 0.057143773808474504, 0.029515724463929093, 0.01860196311627665, 0.034299008923793034, 0.07896566958797556, 1.4244049282804614, 4.967300372738992, 11.276147442479289, 18.282206596866732, 28.47039249635512, 40.978534836922925, 49.43566699181834, 49.35696855668099, 46.54617455697829, 46.0074487809212, 38.76717313643425, 58.24376106262208, 67.82880213952834, 30.771376432911044, 32.588602689004716, 25.83348697231662, 21.321961110638036, 19.820113028249434, 17.369118044453284, 17.177761293226673, 18.07899840416447, 24.29812615917575, 19.156853960406398, 28.03723142993066, 23.610385617902203, 27.115688208610784, 22.225792869444817, 22.167182853144986, 19.349006952777987, 22.286664132148992, 24.929357113376742, 69.86710102327409, 51.13931317483225, 19.667260223819365, 20.061970295444613, 21.173538623317597, 20.043484164822488, 21.631400815902218, 24.557953765315396, 39.254519785604174, 38.81193914721089, 44.2192009956606, 46.425848007202156, 43.599666549313454, 45.44721272683913, 41.59395471695931, 35.13270101239605, 27.80355622691493, 17.993739804913922, 11.888614758368462, 6.936604274857429, 4.235068876897135, 1.2860332693784469, 0.14672690491762855, 0.060767718260326696, 0.05171665373528677, 0.05761580654389917, 0.03868978440521225, 0.03307178586481079, 0.014607461935449994, 0.07629619025054478, 0.04539219955463083, 0.07727584050547692, 0.04052168449326869, 0.08336518996305044, 0.031069423552722703, 0.06090432322854477, 0.013106674624366627, 0.03902664475683724, 0.07521598329467159, 0.04449173214755232, 0.03477638129204993, 0.024558940241413734, 0.032299963772417076, 0.00604523332684391, 0.01958852539950561, 0.05017156164432245, 0.015499184448872844, 0.06347473590604721, 0.03875161153114131, 0.03132740174600434, 0.034344058724180344, 0.04677275894209743, 0.04704070585449377, 0.05985033180144045, 0.03394667359609758, 0.058701851089755376, 0.06936543876485479, 0.053888122295780536, 0.05484303557163766, 0.038285952647246664, 0.022491929684615424, 0.039461499245296565, 0.045738754748937585, 0.08341714604607514, 0.019108684312912728, 0.03866590544461243, 0.018256892217323184, 0.05180974107896609, 0.04923844740035073, 0.04479571200546719, 0.022599034522089268, 0.011869802687978073, 0.045427274890244014, 0.03406108499714925, 0.03485333865448352, 0.04747472530711563, 0.08400340249101002, 0.004652193409480876, 0.16526842369667946, 0.1670476169355454, 0.2778872709360815, 0.11924628153323166, 0.17811228611296226, 0.17585988036326825, 0.1671441133704878, 0.11217126803052042, 0.18413507019079503, 0.20142072571381447, 0.1763857844015283, 0.18347045827296474, 0.19241433560607896, 0.12276702245036442, 0.2475175384672419, 0.07758697179416496, 0.08993246337218631, 0.142035826800331, 0.12414955834467566, 0.17320691788148496, 0.07463623859709309, 0.08591610953331956, 0.15987655898976713, 0.1327087369657332, 0.08369838458395774, 0.10089302120069343, 0.12857150977417348, 0.22830423718738943, 0.16239724873054415, 0.15377086887676872, 0.13778072932074148, 0.156825767048905, 0.1499304547905922, 0.09381046173192802, 0.1108449859724891, 0.08801044836159676, 0.16350337244089574, 0.10547674741716155, 0.23215220490049934, 0.10795414552933748, 0.11017768508604459, 0.10748087939235473, 0.13097880318039848, 0.2141274124263756, 0.09734558978027875, 0.13041700026200664, 0.12528453292625566, 0.19236388105538585, 0.12668651213208515, 0.16918573768869524, 0.12002303340141812, 0.13289063688247435, 0.10511093277243838, 0.1421787175199678, 0.22895493694851476, 0.15023472959235792, 0.2336968220169506, 0.15808150773086857, 0.10664167603658092, 0.15573965355513558, 0.13905545366146874, 0.16275881158728756, 0.14262396782155962, 0.1553893521908791, 0.11835797194151149, 0.2538250008177373, 0.2814528586403016, 0.8723562703497949, 3.741342982938213, 9.348813391500904, 17.458008758483395, 28.358012668548096, 44.85338157223117, 58.123803215642134, 59.99752336932767, 61.087765770573775, 64.32195609615695, 56.83656369486163, 59.80081650518603, 79.18187510582709, 50.74711538130238, 46.079004579974765, 44.874911462107015, 36.536995826228974, 36.85150323375579, 34.61858810917024, 38.126889351875555, 30.650702753374656, 37.9780863946484, 28.41093917046824, 33.56230166650588, 33.22179286710678, 30.93873416223834, 33.017217728399466, 25.31849349698713, 23.23196711078767, 32.771673433242306, 35.647837654236824, 84.18357956794001, 58.44944623208816, 30.18842201079092, 35.90165815045757, 37.81984621478666, 40.715947843367054, 38.698476745236306, 42.825708389282234, 55.515936959174375, 55.38725968330137, 56.47385035791705, 58.368688552610344, 53.166739248460345, 52.72784171565887, 45.21486720731182, 36.12401731552617, 25.836646441490423, 16.851575028511785, 10.842021472992437, 5.829130411148072, 3.6607618101181525, 1.2266755512645169, 0.24028487173059296, 0.20771723300699266, 0.13915434029073487, 0.18616641360905864, 0.154927370529021, 0.10872072374988949, 0.11182638290788859, 0.2759037160825345, 0.1795316172102767, 0.14947884595922886, 0.11003657169039212, 0.19072509641128202, 0.18883828314081316, 0.13933856911476583, 0.13645761886671667, 0.19026611781408712, 0.24023570420761264, 0.13942380405722127, 0.11726409797706913, 0.15766604292777278, 0.15171068990903516, 0.13029719943240767, 0.1450420477457585, 0.11041020809282219, 0.20263938774024287, 0.18781727179884913, 0.14967095016712142, 0.07466068446275688, 0.15432467383723106, 0.18035756724496044, 0.15240049079781579, 0.21875919533833382, 0.17664277625660743, 0.08367459755390884, 0.16087012906228343, 0.13598829808254398, 0.13683856374794437, 0.10963563191434068, 0.23533474864257922, 0.31258164634627683, 0.16313851540607793, 0.14160367660224438, 0.12473052112205375, 0.1620725500247171, 0.11144984303222549, 0.12449216818617237, 0.1377500551602533, 0.1087389643033666, 0.1943635850423767, 0.25206776365878125, 0.21453265761656148, 0.16849025242751645, 0.13401465640673715, 0.17823389491006253, 0.3137949151137183, 0.10786533295627564], [0.004480436496857193, 0.03432829263469866, 0.043510193485886826, 0.029004523568155787, 0.060991684064990094, 0.0255486530612313, 0.06642739964468826, 0.023824252345929706, 0.05700834861565983, 0.04146079337524791, 0.07391672115772963, 0.12764332530599448, 0.0746152631097263, 0.07852686208582695, 0.05176145455709869, 0.014867418550796088, 0.010900917883601882, 0.051135124052844705, 0.12377426719232915, 0.043183085433537924, 0.009583525318321923, 0.08473320083031732, 0.05021909740002406, 0.08812256532931521, 0.07603513046858773, 0.02905296330760804, 0.03637912532975597, 0.029123751747031367, 0.02081483106819853, 0.04429790424183012, 0.03489507512459832, 0.01318447468351693, 0.040411532541076024, 0.07020481832085118, 0.05012773375417437, 0.03449347268249239, 0.03133560080201395, 0.004114729104443424, 0.012177580426777563, 0.044119018881071004, 0.03943323443133024, 0.021039647230457877, 0.040959863803319396, 0.04738159199816085, 0.043180660765257575, 0.07003084741412632, 0.10073964273737324, 0.06673466985023792, 0.0471589591864857, 0.07613598594381925, 0.06327914216765954, 0.03291863339742826, 0.043151231497646346, 0.030232154568957708, 0.010414317986297031, 0.04917468973285249, 0.07750338394074671, 0.01134767642079462, 0.06450048933226256, 0.049978434709050966, 0.020288800625430963, 0.0414287364260564, 0.04755278583616019, 0.00815407898757727, 0.028591755394553466, 0.008953870950086464, 0.04017808639834966, 0.02416708243770465, 0.1128067609463488, 0.09718463470738742, 0.10278798564667664, 0.16152920982530042, 2.3005446310966247, 7.190792983578098, 16.255660114749787, 20.637515360309234, 35.67749469510971, 47.3473382765247, 45.955261645778535, 48.6550800261959, 48.96531597260506, 50.85272912056216, 46.62257840556484, 44.57429708973054, 47.69679792465703, 37.140295582432906, 42.489612256326986, 36.58837103074597, 34.69290917919528, 37.92502457095731, 26.42629046593943, 26.126782201951553, 27.78928860541313, 31.792871452146965, 28.871468574770038, 27.68186273113374, 34.013189884924124, 36.39278988684378, 81.73594213301136, 60.807261390070764, 31.329125704303866, 46.31296611601307, 42.30832815170288, 52.01675914948987, 44.99836021854032, 50.9719927080216, 44.672564229657574, 40.98128441841372, 25.49390777464836, 25.140174704213297, 13.470934187212299, 8.926951692950341, 5.0596584620014315, 0.7332215265881631, 0.8771572514407097, 0.3912561488968711, 0.036739374345709244, 0.022003843576737472, 0.04263200008520677, 0.01562092443853016, 0.017962174362412864, 0.06556242509114166, 0.01973478116034981, 0.011939780989421472, 0.03773249242635023, 0.01843494254224483, 0.018830898916348815, 0.021333564523487322, 0.037390847855638114, 0.07645350640579578, 0.045244409702718265, 0.029514000766099464, 0.08521248075750568, 0.027100808482857484, 0.030495458988532908, 0.03402189576938268, 0.028038289427997607, 0.03606053617512507, 0.019944562847095153, 0.025975641741928075, 0.023206465637251254, 0.0440653276088978, 0.026871535604098634, 0.06304894806817174, 0.08603047113865615, 0.019278183181379593, 0.09902974215125847, 0.048483613307677934, 0.025919782440929164, 0.06897884781562513, 0.03472831693568057, 0.029748797138792374, 0.13739812968959733, 0.020757200188874718, 0.06367995170876384, 0.03555073530503339, 0.03019255356893184, 0.07388484423920032, 0.05174907840668194, 0.024400704780653603, 0.06687880163231204, 0.07587602166759391, 0.04538274602964521, 0.0357167350669061, 0.03728402072503682, 0.016386482804532976, 0.048893221368592595, 0.019491017728503195, 0.015723291979802233, 0.04922517109662295, 0.009254116129370467, 0.03655157938239075, 0.01178888177814623, 0.008438150135559902, 0.05241435682100635, 0.044684353464793776, 0.03011241311117286, 0.03940994152799249, 0.04412876351946785, 0.040709192173615585, 0.05983995897094569, 0.029748582634173577, 0.05705418365616953, 0.008189381276738019, 0.05658312002196909, 0.03641086435245891, 0.037588115496140335, 0.05583233087353649, 0.04098521748317346, 0.05113603186703498, 0.07020467276414556, 0.02268748320338707, 0.018503913438067805, 0.009912560081800387, 0.07462088619509051, 0.031349265895363305, 0.0755563561594294, 0.04884608397861162, 0.02552685977500533, 0.08081027141381657, 0.11955126113588772, 0.10603235268424596, 0.021658661595034986, 0.053969526798614574, 0.0334269595482657, 0.019611858522459384, 0.04134284264798607, 0.07926984479831112, 0.013487210606164752, 0.03961300079320227, 0.040078881842594956, 0.04211338537354623, 0.036214424086914915, 0.025116179190996676, 0.02692975445590433, 0.06516573710306998, 0.01634328119126299, 0.020964396328875617, 0.007511670691817398, 0.0035937443082671495, 0.03442542492261818, 0.03377063042153755, 0.059599047301397215, 0.045370638010001955, 0.03859138424177805, 0.04428778805078999, 0.033586114314534975, 0.0046251912041747525, 0.08786623230985097, 0.027619515125068928, 0.01963038827412792, 0.044388532443272496, 0.009272828784530923, 0.036725178736472325, 0.060460313989390294, 0.03001252865238536, 0.010565477667466528, 0.04480619974915059, 0.0177684786068576, 0.03509582846515602, 0.10052434904801269, 0.017784792449205153, 0.0642726854270985, 0.10935813188552858, 0.032422020730953065, 0.031645946850579594, 0.4270708512875342, 1.4029391446421224, 4.92255348351694, 12.7334628951165, 24.44969438737439, 31.037734785387595, 46.87189602082776, 55.090661817981356, 50.77684302483836, 61.06626725965931, 51.399687951610936, 52.69293654349543, 47.74207776592624, 41.587937801114975, 43.4149189918272, 33.48789430433704, 34.7090732666754, 29.5196206338944, 30.220491309319776, 27.630446341729936, 24.47795310328084, 22.191478013992313, 23.363295908897157, 24.978165126615956, 22.011684410033688, 20.811547002484723, 24.771236565805253, 31.342769668948268, 89.91927716039842, 59.0610888696486, 22.223935627168228, 38.532160405189764, 40.29547368326495, 49.70965631546513, 43.92127736922234, 52.913656157831994, 50.614641251102576, 49.525457889803, 38.25775138793453, 36.08637825135262, 24.137726714534146, 17.04378293406579, 10.183258421959417, 3.2783243444658097, 2.6048026402150435, 0.9820028190170565, 0.3380750606377279, 0.04578940848249101, 0.05466669362278716, 0.022594924460375504, 0.10198884102846346, 0.0068282010409259995, 0.03843403361257046, 0.035435634424849864, 0.021163289990997123, 0.01827429773496284, 0.04315051520543714, 0.02129900438200322, 0.03449372166106778, 0.03024868100070425, 0.08495037143509235, 0.047079891251820716, 0.03540106087682709, 0.026052507173810757, 0.018466534093022346, 0.031138116741673123, 0.03032043854135179, 0.020157121602566015, 0.023494072281004443, 0.0494677604987256, 0.040211001366016366, 0.026298488430198164, 0.026937422996026375, 0.08203074140774627, 0.05132824332723695, 0.0381811709714032, 0.05836716259739572, 0.06956690456718206, 0.060542423293114676, 0.04864871674667924, 0.007541098044208823, 0.05953468059399917, 0.07860108834481047, 0.015955876273613785, 0.016464514605280374, 0.10445844802644946, 0.007273733837439889, 0.020150807122850133, 0.056752528875104846, 0.03109200207907106, 0.031227005923527385, 0.06988060225041644, 0.007662737006021123, 0.06256542018344326, 0.042958342049631386, 0.02935570210308558, 0.05965975976939644, 0.11937456295615244, 0.06145076608405479, 0.04073590565953524, 0.07436089893622745, 0.038406508073451064, 0.023433036140857205, 0.03551326977509645, 0.025616005596314228, 0.02532602216477596, 0.09569621014018213, 0.14529488740428803, 0.24450316634630007, 0.11450863293101711, 0.2062102001641066, 0.12543958912213005, 0.13852719007240188, 0.10604794257350507, 0.10543255180480982, 0.10798808322438311, 0.10273998257734122, 0.14818153734649384, 0.18677522368248434, 0.21520293858503142, 0.1399374047234174, 0.15408220700919628, 0.17473244408686317, 0.10558575406790742, 0.1904315774839732, 0.11569711109322887, 0.1939484266744506, 0.1517002251479895, 0.12195711429681509, 0.2533330804397983, 0.22575678033453805, 0.21166986365231777, 0.1370406270988526, 0.16565010402231448, 0.17666882324603297, 0.1520341169089079, 0.23560746062186458, 0.25745276421789204, 0.13925334949406887, 0.20782925038328096, 0.13160166330635548, 0.09267122004060976, 0.08054024074226618, 0.13044554469806532, 0.10912884176979143, 0.26287194762018423, 0.16118394931958568, 0.2180511768787138, 0.09478674119999332, 0.15388017430180503, 0.12868763338173592, 0.20041943347502142, 0.17736913486113473, 0.12263759955643647, 0.13237469198722995, 0.17064335786046522, 0.2165607987873016, 0.13677925322084658, 0.16047346405684948, 0.12722533241274858, 0.16083150290914122, 0.12539652731990622, 0.10581306767679992, 0.09404997146057506, 0.18085820570347771, 0.21584865877464895, 0.10028942818603209, 0.21351651859379586, 0.2366527722727868, 0.16174892384198405, 0.25223201290974695, 0.12719916284925517, 0.09730718579263457, 0.2149408599061351, 0.22198960425392275, 0.18002502379878876, 0.3586679636951416, 1.2021399000960014, 4.361328011558903, 12.826928073360076, 25.82215132251863, 35.58096516516901, 55.511712566498794, 64.81677486050513, 62.50272158653506, 68.57347196148288, 64.21086672813662, 66.79209616876417, 61.10430248322026, 59.878267626608576, 64.09983619566887, 50.15342150965045, 57.54274329831524, 48.062154939097745, 46.1026172484121, 48.43987526432161, 41.56689036277033, 36.28849406396189, 39.30506737001481, 44.34630147872433, 39.347813360152706, 39.91647074299474, 45.169199051395545, 48.26504345863096, 89.9457060906195, 66.76930719806303, 43.579909570755504, 57.18090072754891, 56.822243121362504, 65.67823717671057, 58.465249461512414, 65.4980944818066, 60.24960233319191, 56.28176404583839, 41.664545612950484, 36.73118452872, 23.07477028139176, 14.342030825153476, 9.160321931685171, 2.757361266882189, 1.8140893405483616, 0.6513240921401209, 0.22270428767848402, 0.06990284944373755, 0.1162862403678798, 0.1283850975995583, 0.1579350776850216, 0.14173129152867103, 0.12063178218780987, 0.17762837901471124, 0.1639120343832239, 0.09682334764229675, 0.11778575788822868, 0.10705243705982163, 0.11512327293354659, 0.16832632493347893, 0.23204740407245777, 0.12834236521514195, 0.11822154700395562, 0.12684038089167687, 0.0994501022561904, 0.18232014661114063, 0.09088831127531107, 0.15702795297388109, 0.09755218837169871, 0.10559671678610387, 0.09623436392435143, 0.10158289869826648, 0.1097065946387668, 0.1568740918751686, 0.2158186740932926, 0.13287074923996003, 0.1388972871486218, 0.13223599942941822, 0.14753460673795593, 0.1303155702208319, 0.06507243525477187, 0.10266893558324346, 0.30746301455843833, 0.09540768610613962, 0.15315088924140702, 0.13988744046899582, 0.10555644354392445, 0.16275498114766615, 0.12012270144036702, 0.14471811512785573, 0.17613029407878078, 0.2064384790437837, 0.10523529948606607, 0.11090761366029901, 0.1022875540318989, 0.21873135570316546, 0.24993961737040551, 0.14327480547851132, 0.10912338722377055, 0.18640834417554641, 0.26058042542107646, 0.0920730815719693, 0.06317492739688005, 0.1696972852392543, 0.2050719160826937, 0.1427944377064705], [0.010125679039065878, 0.013198193403020983, 0.0432882271707058, 0.042315042697854584, 0.026765101093558535, 0.05205501561924335, 0.014173560268846492, 0.016038538118253554, 0.025409855166329973, 0.09089817848777579, 0.052966579809905066, 0.05234873372941248, 0.03303230169319338, 0.06407978448776469, 0.023628903755677805, 0.024930332006225665, 0.01926126029913224, 0.013363166607075162, 0.025259349532725833, 0.058930156782509825, 0.05415582022960148, 0.030883821516087463, 0.1350744164759113, 0.02766846622821064, 0.041522053596113, 0.09774942536868396, 0.043330737389624126, 0.06410564378564877, 0.058336293084486845, 0.013741602550350852, 0.0739094663050867, 0.08654454677936532, 0.060959734368107976, 0.062178890521247546, 0.04656212306731651, 0.053669499954388994, 0.006410810484310553, 0.010135829704062594, 0.035075132599881584, 0.012137448910864131, 0.07383835802395498, 0.05448804574928457, 0.023307141081820575, 0.056745530661916545, 0.03509989639203395, 0.010542847430183282, 0.060531464405357845, 0.09670627408570821, 0.05858545552097982, 0.03683693564286636, 0.03576583747241286, 0.016146166768345623, 0.046504555390246456, 0.032774804220084226, 0.029536759323110024, 0.052099770475779815, 0.03457285854364595, 0.0759274031846754, 0.0670432347443796, 0.01862509897158992, 0.05344945268945829, 0.011733198677369905, 0.052553899736414035, 0.025656173501404065, 0.008887028821083087, 0.04306987679052738, 0.0286289336415188, 0.0415272974679547, 0.06052074300485754, 0.00933284315490915, 0.005388644743605607, 0.04687062284398464, 0.05463431108622782, 0.07248297994655949, 0.14414212426110623, 1.705459543774205, 3.7233062088489537, 16.347317080343924, 25.18062414661531, 33.306606277342766, 39.168996426366995, 42.09212318543465, 46.41730508496685, 47.696374308678415, 49.69066027672061, 47.402388741893155, 48.638963007157855, 44.51585769653321, 53.29294150875461, 56.36996638390326, 43.29270970436835, 50.00974116786834, 58.468595243269405, 53.60464049923805, 54.07552103842459, 51.46966695785523, 52.54915029771867, 45.692309871796645, 54.96686397060272, 49.48095075545773, 51.79924803395426, 52.71992245028096, 45.02658559430031, 35.51271984654088, 28.135624085703206, 22.605101754588468, 14.139299200427148, 10.040948948552533, 2.76967064507546, 1.5580816326602813, 0.43904636836340355, 0.2564158642123784, 0.08411902814142166, 0.0615862678856619, 0.04433040169157809, 0.045532014431251634, 0.044939491387096145, 0.05464869821744581, 0.07111386591268164, 0.09915208639276606, 0.03759445487371376, 0.04982236727711655, 0.02353233071194301, 0.06473757822306887, 0.06219668674372858, 0.03580239901859914, 0.034393728034751075, 0.017673020221052632, 0.029171837170818643, 0.08199180881943434, 0.06826432526952798, 0.027764185083909865, 0.02429605717019689, 0.043051651558808746, 0.02366532166037829, 0.018881020218794866, 0.041504115647365974, 0.06552694755936823, 0.0429357769298217, 0.013654824898337886, 0.01607074924263983, 0.018295550929202188, 0.03442363227687536, 0.004522473656482274, 0.061759920865898175, 0.09999551089300264, 0.1560297710520606, 0.0591122214081547, 0.028028404978554577, 0.04192128116565366, 0.03961392009871141, 0.05694937899768834, 0.03742754729765077, 0.04163207914379816, 0.0153398372030126, 0.07068240519372687, 0.09822058476387494, 0.025193923708772468, 0.09933914208123762, 0.044879529685262716, 0.014866641929162847, 0.020924077121420734, 0.0390222703947896, 0.06912376100738203, 0.03405455792803438, 0.029193663015781395, 0.03144873092101226, 0.033854091870448286, 0.028638299066393126, 0.0589946000987003, 0.014305871314248972, 0.05090332499915554, 0.027285654007667498, 0.054745083569639155, 0.012644822239845753, 0.08716449577121005, 0.006376501715426604, 0.04938893005131714, 0.04163159267796625, 0.058438178947976524, 0.028044621144691785, 0.019836249505920757, 0.08352660468869633, 0.06068222667841662, 0.011203649018200175, 0.05884599819358799, 0.020669621017370975, 0.02178974881497843, 0.024479535228062062, 0.08554379080211924, 0.026730334108334877, 0.04902054518160801, 0.062189079490640474, 0.05202811827222186, 0.06921854906625326, 0.03772696893241617, 0.06193301077151011, 0.05908962947526767, 0.04365012327569627, 0.07451355727689882, 0.028843838541257768, 0.008463954849679385, 0.09762784721510065, 0.034607458904746084, 0.0652355736782474, 0.008973395658446657, 0.03842338115998334, 0.006714739110095487, 0.035731501411646605, 0.0367257647937344, 0.0269922825522841, 0.06391632813780058, 0.034100040568098906, 0.07579545220059734, 0.018598873866721988, 0.03562864644693271, 0.03941678652359594, 0.09653856211732473, 0.04845059874858107, 0.028028606076634703, 0.027264649792003538, 0.06443316552547679, 0.03173171805458204, 0.03738892880538779, 0.012988911588646233, 0.04158681100835243, 0.013983547480987206, 0.03129616259567199, 0.05794261199151797, 0.000745480458370425, 0.015822337572312644, 0.13542969741167563, 0.02955127860449495, 0.014864196193464583, 0.061189848028363726, 0.033939970326760126, 0.02498431822224971, 0.07413196888181471, 0.011236724864330985, 0.05483552024910047, 0.1268224697560072, 0.01973899272871354, 0.03194137525203968, 0.039984319779661395, 0.0342627614736557, 0.036025338265444004, 0.059895270519078746, 0.04225313130225386, 0.03432382251166048, 0.2200213405153444, 0.6464213745728616, 3.6671437515366465, 8.027575746659311, 23.163049105674993, 34.92466242082658, 39.50012291631391, 49.63220911641275, 50.662992308216715, 54.726952199013006, 55.19670309558992, 58.387798340089866, 53.395425196616884, 54.12742184054468, 51.06983230959985, 52.00440760581724, 58.964222015873084, 46.28904358033211, 50.09228744814473, 57.27531609996673, 54.5528656436551, 54.373048505475445, 50.72172587917697, 51.62886419603902, 48.197449253451445, 64.48362834991948, 55.0927524412832, 54.33999076966317, 58.82042792535598, 54.45081733888196, 51.38930151539465, 38.6220258282077, 32.42054285541658, 22.745971718142112, 16.172148931411005, 6.226242444207592, 3.479576009896494, 0.7269913318657106, 0.5266655296567948, 0.03570823532138621, 0.07384492339746607, 0.06787147538195695, 0.06568634747377326, 0.04338156732340013, 0.06046734284609557, 0.032557411449811155, 0.05891647445218218, 0.008146776254439067, 0.03059609612870601, 0.03752846022947662, 0.04730595613739664, 0.028152559102783282, 0.034928656588759155, 0.07084825556845435, 0.07046199403703213, 0.05521589822526421, 0.028463761254604307, 0.03279417475324965, 0.04526354657906679, 0.04507965866416212, 0.01961361860946542, 0.04202621605908198, 0.007745384965317265, 0.02498074250686313, 0.04340568377125648, 0.014573202483476171, 0.030683864906971014, 0.02345025396695541, 0.01645269961426816, 0.0421466680634166, 0.026690612449460936, 0.0027142830320724077, 0.03046795643205124, 0.07181220868181798, 0.05300639722976954, 0.003473977473819809, 0.016090048912672267, 0.04337980532117429, 0.055460372203660596, 0.04256201795332375, 0.019984228964594584, 0.035558648993291204, 0.053193832131763624, 0.07044693274844079, 0.03196746820674068, 0.03325055248194164, 0.09635554371221412, 0.04784689848161033, 0.06420318210016816, 0.030413014521341653, 0.040131397169804385, 0.03504530496654972, 0.018509927228273406, 0.06457463132157441, 0.027654598121561354, 0.02274789498187602, 0.015912337581657113, 0.036825287275977676, 0.0296031178591112, 0.019446575052795873, 0.06432345407384057, 0.09088951403335219, 0.02673128980302042, 0.08800243508190879, 0.1165940391740972, 0.11653376337621482, 0.14909365695090065, 0.10488671415875997, 0.1411330841121174, 0.14611650138132035, 0.13739907963862344, 0.09702185634523632, 0.1440913632752434, 0.10996379333758548, 0.1554582388170304, 0.23120815475140852, 0.15732537894960374, 0.16422629897152224, 0.11838064048319094, 0.194787017159885, 0.21532833185647765, 0.13428762885591677, 0.13379947763056527, 0.27063088611729685, 0.15202702293472906, 0.2274173678409669, 0.1905266796388934, 0.15975188584096972, 0.23387879854248417, 0.12574597066568752, 0.12932036072015762, 0.19130117920858247, 0.13869906955909345, 0.16349140614751848, 0.21483860249000214, 0.14023165909513352, 0.17472519689509947, 0.12469654512261191, 0.1490266242575261, 0.11817863841931667, 0.1904460718675006, 0.17235407816065898, 0.11053986081312742, 0.11144566785303817, 0.18045185734668087, 0.15300346328125847, 0.11885026770253336, 0.1056293674534367, 0.1999081617161151, 0.189893078960238, 0.26160036423994654, 0.189571505893142, 0.11549427399351714, 0.17364349606777393, 0.08669156671291398, 0.1348829864253921, 0.11511820909236709, 0.11777261181944802, 0.27482031454001704, 0.07471310019853615, 0.15894533315252873, 0.14373893218655742, 0.1408424916406793, 0.0804512213254648, 0.14086838541252, 0.21615140140056613, 0.14422420292131363, 0.13945738935182173, 0.1590491840315442, 0.06273263036423633, 0.1304529297856554, 0.2252705596507557, 0.17074414438778357, 0.1936711794546535, 0.09549954004826085, 0.22443325619303414, 0.2137538832762549, 0.43132625520229345, 2.969294772032769, 8.404989146417188, 22.47867003563912, 34.075767378653254, 43.725194161938084, 54.23298066662204, 56.46786874340427, 61.435680004858206, 62.16603709805397, 67.97146658743581, 63.682256744753936, 64.92100008072393, 64.24711727326917, 69.56379198258924, 75.617719311868, 58.76191008475519, 66.74277628621748, 73.84527867840183, 68.72941755479383, 69.76652360731556, 68.37028534181657, 68.03410683908771, 62.828882355843824, 70.51083257121425, 62.796875815237726, 69.83125840463947, 68.63594747358754, 62.356593685765425, 56.85118236849385, 41.339894956158055, 31.051315992109238, 20.11244727719215, 14.041893020752939, 5.259384080286949, 2.3420526231488874, 0.6500384127420764, 0.5640753803233947, 0.1345942478867308, 0.22637911952070652, 0.23240420186231214, 0.18023533025576224, 0.14696359544271423, 0.18062859383081237, 0.18952439148579875, 0.1430980996378968, 0.16621377619524158, 0.14591051566023983, 0.13101208203982923, 0.1773666987015355, 0.152449780894864, 0.12418790870616514, 0.19247199138326032, 0.13795688357805053, 0.15203453059638702, 0.14432232346265547, 0.19144759393267094, 0.08598023109258184, 0.07289917253318333, 0.15409535307797695, 0.14294759400429266, 0.1262141959441285, 0.1250601457732339, 0.15177052137592148, 0.1680577191854677, 0.14169462656061496, 0.14187321697752323, 0.16979395021354, 0.12967541182954467, 0.12252888401910184, 0.196466603646836, 0.21369178418911275, 0.24150699647443913, 0.20361722236679447, 0.20294069012086238, 0.25817659473226917, 0.1160896545456302, 0.19972518927627997, 0.16158016999402355, 0.11650380933837545, 0.08998902364363594, 0.11863577074461407, 0.28361941657720074, 0.1093546844898693, 0.1737457381621484, 0.15616334614253816, 0.20652098671322872, 0.12557303397766045, 0.144961669800743, 0.3100126471009947, 0.1787832105952886, 0.08327209495849187, 0.1863474708290831, 0.3158515241117247, 0.16769232588910288, 0.17833950779130384, 0.12919545774498295, 0.10357022270440094, 0.15863364261965598, 0.22785357830505218, 0.09297586256457914, 0.17203609038504863], [0.0808373909263361, 0.0210366977919494, 0.04345993811805402, 0.044918810843580195, 0.057476803720478094, 0.08713909995652015, 0.05092318199815289, 0.028812561086529208, 0.0193337551994069, 0.06667909783221061, 0.07091091389978124, 0.06740767809171831, 0.051309117942207286, 0.03115671161081522, 0.11159577512092168, 0.03312926161132994, 0.11030701604942161, 0.0634661250777783, 0.060263632406150146, 0.0069758989622876535, 0.045859260379426905, 0.02724941613362922, 0.013548941013493366, 0.06266156421794046, 0.05598474023563247, 0.01260351860940817, 0.06146876915027538, 0.012948578974652677, 0.06026475855539884, 0.018621804793515516, 0.010693679608765149, 0.01716026991245247, 0.020703809606211803, 0.019341684209423202, 0.02908298054770116, 0.009964733542273603, 0.03616837454178641, 0.06112899000365889, 0.016206410007491227, 0.02607586327940226, 0.015574956290243615, 0.03366842280111967, 0.017053402562235153, 0.04658620504121627, 0.03569954788432487, 0.04192101303488017, 0.058421731040242224, 0.05443625820560321, 0.05658110138028861, 0.025259037351896687, 0.019583124479639436, 0.046006674848256573, 0.013629274908453228, 0.018752698576258078, 0.018988119310609276, 0.11076483019297162, 0.020193273291712808, 0.02090739555686953, 0.028744593765887044, 0.041463976470573295, 0.03794418933290628, 0.016671697338742596, 0.08914691681462912, 0.002322426664778182, 0.010974626075626622, 0.07020471872942102, 0.028338004091394045, 0.06055817023039826, 0.032709227093765815, 0.05708999443619002, 0.04435810343092007, 0.05420537462698356, 0.016858737705455675, 0.04471317752294483, 0.10460779686728794, 0.09432483614692766, 0.022821847364426624, 0.23226037651540773, 0.9191841608093632, 4.650467489996265, 7.384883136518541, 9.96948826697565, 12.835829892466146, 11.289560967876065, 10.364414068960375, 21.630218221295266, 23.06418772666685, 23.79828283863683, 30.2516721910046, 30.51545354627794, 30.688371235324492, 28.644133883137858, 30.337015121213852, 33.487760943751184, 35.64333085090884, 34.845956140948886, 34.69010860689225, 37.54813186583981, 38.683481524067545, 32.38077590542455, 28.68045306974842, 24.31919517055635, 12.161328331116708, 5.797357251567226, 2.5567521347153574, 0.43206289470676457, 0.17531578939768577, 0.004602410622136367, 0.056764832247168794, 0.07060444042567285, 0.012933271580315646, 0.013132751299699229, 0.022540244934779984, 0.019431908299485524, 0.038797136306041674, 0.059900326699378996, 0.03497868213021467, 0.028427864289692337, 0.07494943066229744, 0.015989417518158595, 0.050825134235163855, 0.0549105700526026, 0.045046686239901094, 0.08255285331078115, 0.022230666889358434, 0.012435827708442607, 0.013898776979335855, 0.03268387724435137, 0.02996967369390111, 0.051421457075423775, 0.12080380723120705, 0.025494670675646876, 0.011893991914187229, 0.02571206727635957, 0.02860965503890428, 0.06043938446729895, 0.014756427732326332, 0.03280955779876921, 0.02152543507456299, 0.029535072014456796, 0.045809866860508926, 0.038290541513913104, 0.03884259596346848, 0.04224490351794709, 0.03817446770206575, 0.06642221322944088, 0.010817081051608248, 0.016602203587911302, 0.023014085637705944, 0.04706472654135958, 0.06448876052614182, 0.02120268414728344, 0.054997057548814246, 0.021962821483612064, 0.053837001248593294, 0.024769501422622034, 0.05319254127361121, 0.06344798028529172, 0.07163423113524914, 0.043688596211253636, 0.0071251228350334836, 0.08680695487606911, 0.10157804170082654, 0.033468768796733314, 0.04297329991635296, 0.04255659405081984, 0.057128911702743465, 0.07947779936535705, 0.07038724683826009, 0.04503932413494876, 0.13808485090492234, 0.04763150903125925, 0.10455518194864835, 0.04971183994184098, 0.04324271771756392, 0.05174840041886895, 0.05629750712203884, 0.026949789570344072, 0.008087630436244992, 0.027907016431732524, 0.030664344986660347, 0.036595384289901105, 0.039717790129924976, 0.043564915146318176, 0.03655400788111072, 0.09810826095241694, 0.07145364122885851, 0.053206020590638926, 0.05584535053780964, 0.018074325804087906, 0.06547667686977694, 0.039863285548504324, 0.06518357929082648, 0.045470884445333676, 0.05389335084586375, 0.09839234167649862, 0.09873690504220226, 0.0378944740570601, 0.020434688664071506, 0.0732071781831403, 0.0266652989892229, 0.02087352680973709, 0.019499507897924033, 0.03862624507277243, 0.04480443774692474, 0.025799171473350258, 0.03353624965154356, 0.03518852127355433, 0.03451790705683731, 0.012348185334685109, 0.007234199391302443, 0.028189777569364638, 0.023533870548670812, 0.03017556365399111, 0.11168959790900831, 0.009650043775177291, 0.03125467127369296, 0.08146624185986097, 0.06479843624777372, 0.027221731631265535, 0.010405694709099349, 0.025558970350351547, 0.0789240480310494, 0.029274182687062892, 0.012578177378482878, 0.044925981426551465, 0.08725045083631432, 0.07893089685709247, 0.023458140842135877, 0.05074650680105533, 0.010776642142915198, 0.06343325607538705, 0.033769331902505896, 0.05107482527232459, 0.027535921525991255, 0.02374052276624547, 0.044078764791089686, 0.02867955290111563, 0.04928944204303046, 0.08961707263463929, 0.041435374577920285, 0.025400187136725556, 0.03199549744867029, 0.03606910103811853, 0.011746918354483863, 0.03117531988649599, 0.04671328370609591, 0.04078139979091864, 0.030496062282773278, 0.07654164482148425, 0.0852979991524931, 0.13107001360866333, 0.09341060213984982, 0.6905803985653386, 2.557385107201915, 8.32059641038218, 13.124623221735801, 16.385941640023265, 20.302776367433612, 21.578948920772923, 21.661226518692512, 31.210020972836404, 33.73204615808303, 35.0866327747222, 42.601803810365745, 42.857032437478345, 40.357882515076675, 42.48311681132163, 43.49715932723015, 45.22064093620547, 46.65828374124343, 47.44902180087182, 46.29086748246224, 47.08031115993377, 48.510352411577784, 41.37858521553778, 38.83367300033569, 33.29558441715856, 21.300280209510557, 10.86628427428584, 5.468848453414056, 1.709404467575012, 0.7297030992565617, 0.1556910989024947, 0.019603092561385805, 0.03919700738943873, 0.06335992996971454, 0.07145859015684936, 0.041817031920917576, 0.03561943807008286, 0.003965280193369836, 0.05347364191566745, 0.05376116620496877, 0.062041741630603234, 0.11044940881190762, 0.035281650752069495, 0.03450660725995418, 0.07748106779951243, 0.07635999771375811, 0.07716362394632832, 0.016537176129678567, 0.04518254044195337, 0.050679175333390315, 0.026783224818627202, 0.09641937415806517, 0.026108588640307708, 0.04295075011830177, 0.017183894148817467, 0.03715978807679588, 0.01605407246613815, 0.014960985657037988, 0.07646132816350268, 0.024060347237654274, 0.03672795197475822, 0.041785492081074946, 0.021694296174832893, 0.02900881749097138, 0.05353192588494671, 0.030771078271490913, 0.04125783370146829, 0.013744808628313966, 0.023568733294885007, 0.03730312695786838, 0.012504522812612837, 0.020507285070996133, 0.03798087345316045, 0.10238826395042482, 0.049830633365819534, 0.04252311600852878, 0.02468742276241462, 0.013206606963649394, 0.09061367641533576, 0.036716947121725935, 0.05291336351224492, 0.06138376403419722, 0.05136272494470881, 0.039065496905917124, 0.06387348850107481, 0.07946047045650982, 0.010471063076458391, 0.053733908796622876, 0.08264895904088214, 0.05407190678881542, 0.045271916089639555, 0.06883216496076315, 0.0440188299023336, 0.04637449664334136, 0.09865259706613519, 0.09206316073334987, 0.02301181227179064, 0.0427307449882069, 0.05314170750939558, 0.2276824495845264, 0.10871043518906641, 0.14765483657679251, 0.15018462744210997, 0.2074515690366107, 0.150832507999674, 0.18168616288852307, 0.15139424963103187, 0.12751370322920624, 0.18601233800572736, 0.13126780218895406, 0.24264316615318102, 0.15598901517448888, 0.198392640619028, 0.28590496329049914, 0.1859735279914833, 0.2229127708461977, 0.14643835024006907, 0.17650679565004765, 0.14916245164650102, 0.3086342710641123, 0.14450653696492796, 0.11430885252212325, 0.09331235136356085, 0.13737890088269789, 0.1462644482812574, 0.11305993002268577, 0.13645421743633288, 0.1649022336688734, 0.09473796438185439, 0.11439633210219684, 0.09298465725394989, 0.1403007908694206, 0.11199571898267155, 0.1506288205423663, 0.15477114987950172, 0.07767377721686518, 0.14295006080740882, 0.1716101301773902, 0.1398645650835768, 0.09384551025446385, 0.11081515450871761, 0.1553748884508687, 0.12671974502624045, 0.18802526467029126, 0.135991990626339, 0.2281242065251835, 0.13036080005188144, 0.14274739990791968, 0.1743753245400806, 0.10903564717380271, 0.2233216472931447, 0.05461604371967335, 0.1801249523076319, 0.13592877305082737, 0.1950762919600933, 0.18470756769660981, 0.12691658365750505, 0.1257462847617365, 0.1410402342556946, 0.07748262295799871, 0.1566231521146913, 0.17730440043153303, 0.15387174733463796, 0.10125934146344663, 0.16910736689404135, 0.11606563002832475, 0.10256677775854066, 0.15003807482219514, 0.12167523990595534, 0.12311885599046947, 0.1852661377239612, 0.11733246366343192, 0.15527984758298244, 0.16804677944990898, 0.13629597431469348, 0.16725976200353715, 0.6146247420580156, 1.932405307888985, 6.5341573280672876, 10.4346715634869, 14.471091512710819, 17.681942755176177, 18.113513300495764, 18.332622781876598, 28.690096216817057, 33.33892268519248, 35.028303207889685, 41.46016659275178, 41.46201010673277, 41.75199485594227, 42.3289127503672, 43.77205471838675, 46.58107580677156, 48.604230419282, 49.40475871486049, 50.50691727669009, 51.326516136046386, 52.540030787068034, 48.614040267082956, 41.928007295054776, 33.56203886770433, 21.128788302021643, 10.489986788841987, 4.489276707172394, 1.101690941760617, 0.4079647103865301, 0.16066656417904362, 0.1708889962925065, 0.15919492459825932, 0.16108469496811592, 0.1315714028333464, 0.11082964889224499, 0.07293935384481184, 0.20440773317410102, 0.17186197392161817, 0.1428857860305617, 0.08790338757417857, 0.29840463772416115, 0.12460366462267215, 0.08907625286449349, 0.24738970903619645, 0.17502481388228555, 0.16975887870836645, 0.07878252094791782, 0.11282432734245255, 0.17189476248477736, 0.15835726874009257, 0.19342197105288508, 0.1450699486679608, 0.24409625108443925, 0.1359449375060297, 0.17024630981106914, 0.1029265939348167, 0.08344464094167756, 0.17569028381859103, 0.1396234159267718, 0.17120057957306986, 0.10152531186899832, 0.09274107193754566, 0.123169923411502, 0.10931153841797384, 0.2105063139911621, 0.16112119139682862, 0.13862621459749438, 0.09965301596469457, 0.15667996519515592, 0.12306207355352179, 0.08147774083960442, 0.11030066518052933, 0.16825644239302606, 0.15908169680305068, 0.12885496230615726, 0.14909747206876356, 0.3181522393659238, 0.12112793137109089, 0.17984177556730088, 0.20715805010930186, 0.14666122053900074, 0.10703211274719047, 0.14180796160813303, 0.1952454748172914, 0.2571342248589762, 0.1269352762028575, 0.1956040805746471, 0.16474703957717265, 0.21205597196615514, 0.2187529287391132, 0.2024266451236702, 0.13998510135758307, 0.3161536691890609, 0.2677419991983522, 0.1382048815608986, 0.2413385643834068, 0.09146686087572768, 0.10970834131923415], [0.01457991724413249, 0.03760746304666804, 0.07155530109641052, 0.04906646066134976, 0.016822379172569322, 0.06046311787119316, 0.026004015723423615, 0.044410124631418336, 0.09085683272250238, 0.010497298715035281, 0.09711672101289996, 0.045222982223476135, 0.05450721326915007, 0.036140308910680395, 0.14843492858832882, 0.06915497142941722, 0.03454953499679123, 0.007996286421398362, 0.03599533443188956, 0.011583416996854208, 0.031062038465132637, 0.1397737376992741, 0.013799737132484875, 0.030687883038133867, 0.015656850131739293, 0.12697525067074647, 0.08081676017853522, 0.005181379176886572, 0.04210006693498262, 0.03508187417361525, 0.059017670836540005, 0.030714602269712957, 0.0449712687141953, 0.0802440788116186, 0.021571308419468905, 0.020448156489780354, 0.027893458590692574, 0.07964165025060216, 0.05552103104550512, 0.03324366535150236, 0.04837001012938638, 0.036037982546634255, 0.03424976862245991, 0.057345580519928094, 0.017120354816377643, 0.06408116344602839, 0.03574391586645957, 0.0242544662567877, 0.031163181223335768, 0.05422220557868, 0.05140538455077237, 0.07508141995077172, 0.05533787091412852, 0.11369066553250437, 0.04282836757239796, 0.0688982323833531, 0.011338328232898588, 0.025791181176300013, 0.02751258648781767, 0.05046783465771906, 0.058945693045614235, 0.010966011416918088, 0.03193843538963026, 0.04803042250475095, 0.06965331162416166, 0.032455150203238574, 0.04286956778096576, 0.015134506487107326, 0.050711948574791034, 0.04641488479870943, 0.03255404066294432, 0.06842637584815103, 0.037639378269593564, 0.00980028223561784, 0.04995380115184573, 0.06272420722750888, 0.11149472812370909, 0.03840321389537665, 0.05984856979921461, 0.01864719294732617, 0.043358887290401806, 0.06429501689009129, 0.12760017157321976, 0.10443496743157026, 0.29479792642016567, 0.45416955685903954, 0.9491546848608602, 1.57786337117995, 1.8817288981330011, 2.3543835743781063, 1.9275054095252868, 1.7072059790934286, 1.640938025328421, 2.191598593227325, 2.477960788434552, 2.8447362299888366, 2.8996717208816163, 3.7702905651061767, 3.4796054276727864, 2.2340344709734765, 1.4723739220250038, 0.6234579196860713, 0.13478201603697193, 0.09414420027526156, 0.03047860888463836, 0.036118425609123324, 0.019140934699305126, 0.022229490944394664, 0.04031839157124201, 0.03323664032523671, 0.05115949714015569, 0.09566670043333884, 0.036201140122307886, 0.047064921893780275, 0.03270978633795054, 0.050973345435434775, 0.05572116002440453, 0.11283216442191794, 0.04557305376135534, 0.0284652091607812, 0.11205673788584049, 0.05246355115706402, 0.028608431213445244, 0.05871074154011666, 0.04698036876957744, 0.01669954846522981, 0.013218229475070634, 0.04873020168874533, 0.07008370748090167, 0.011127381134898433, 0.044540374900304505, 0.06290920980034337, 0.01816013722770637, 0.18179689323709858, 0.06751916686733885, 0.02943609728507938, 0.08275027416886822, 0.03740053120700102, 0.0016287973712972037, 0.033297268523564266, 0.015576538261807254, 0.03695088356072384, 0.038175260603067376, 0.03277162878563808, 0.06099431940744962, 0.07380585291332777, 0.04812464365855821, 0.04494720206205403, 0.025945342964522784, 0.057467587682749, 0.05903824795818618, 0.0217409739120593, 0.07560055943266039, 0.07986884894630603, 0.04012377459495779, 0.047089697177251505, 0.03378921954502021, 0.0498376966964814, 0.031185497364570058, 0.011067085227208033, 0.030091994952770974, 0.07307981606572866, 0.0484415665719538, 0.10429468141087603, 0.0896274914304095, 0.03533443421005242, 0.02856386979410966, 0.004159338404274276, 0.04436215986647914, 0.07046920292439961, 0.04953194334502182, 0.07856699743218, 0.06841676144470131, 0.03561299144020004, 0.07454885094757042, 0.018227024364375302, 0.08504076981015744, 0.0679860974571878, 0.06294348074363605, 0.07112188685324884, 0.03774724727977188, 0.029893365590983344, 0.03349488856451165, 0.08081793229305938, 0.01008795399684459, 0.02541418547832197, 0.019821661276622646, 0.01954658400087107, 0.027739440443955606, 0.032027088999447804, 0.09561589348220056, 0.08518849454459645, 0.04043209434096371, 0.04556539288211254, 0.06055395674681472, 0.02747205086052418, 0.015784653707317287, 0.09392014254004726, 0.06119145681300472, 0.046263050002556656, 0.01278134581122187, 0.09140054830500195, 0.054772528669526505, 0.0522939354601887, 0.03512952101206587, 0.048813651646337206, 0.05716536216618073, 0.05898497803437133, 0.014176718466314337, 0.05044330835282322, 0.0356819431838249, 0.038543166667823835, 0.05443575641801281, 0.08157710244338359, 0.023822616748211366, 0.03384122159332037, 0.007068453396054646, 0.042828957460099654, 0.032559242399950186, 0.029705668303875193, 0.0623200920170113, 0.053612935852499745, 0.06769231039910548, 0.024930686321890643, 0.012886709713887785, 0.015122861950658264, 0.01802085286697313, 0.0941511333709763, 0.061142254816067804, 0.07332111844011853, 0.04358312505627832, 0.054241265846236106, 0.08356746781857745, 0.017683921652215145, 0.054141624620364565, 0.009596342926905041, 0.017442987000028935, 0.03645105332496666, 0.035665675306752805, 0.15191986255588072, 0.0315528633373399, 0.035060381576899564, 0.03750487238228802, 0.038439108945068814, 0.03763896075167483, 0.02634889893083563, 0.035439162259741176, 0.03968267265947596, 0.04036995694942532, 0.028351427867047252, 0.021542198993566058, 0.023162944182272882, 0.008493710662268342, 0.07235169545897553, 0.04100462632073511, 0.04371710234291611, 0.10266958675797909, 0.12180345238096292, 0.3946958223898565, 0.40822027731807004, 0.8630489149401266, 1.886331799530214, 3.1057665328825674, 3.5693700948069176, 4.351864312925647, 5.197500355782048, 4.848402056001849, 3.949662759419411, 4.005611202409191, 5.319395853627113, 5.502269989059818, 6.362863500272074, 6.047810883291307, 7.576571818320983, 6.948059066649407, 4.995489956871157, 2.994416082097638, 1.501162648200989, 0.3769268419954085, 0.11358674570557573, 0.05392911566060878, 0.11002428364008666, 0.0190955248375934, 0.0562615622766316, 0.1068570310129754, 0.02024874571830996, 0.027081725232663657, 0.036864235186048096, 0.03339264263969756, 0.06167790732316433, 0.04666381740882512, 0.04431358989207976, 0.07960033512884572, 0.019565755351176186, 0.06193710551146538, 0.013936347846362381, 0.06766282367489992, 0.04122118788561033, 0.12246803365527623, 0.03069682902986965, 0.015348990996097846, 0.08782229716739348, 0.06128203521873202, 0.04179492262342284, 0.060168874990795894, 0.017184395936407873, 0.12038595223378752, 0.02077110851514003, 0.010458994318821259, 0.029554235703882673, 0.11094539711672453, 0.042446756194676125, 0.023067451322511322, 0.027267260236605525, 0.030452623182246764, 0.03525306801161459, 0.03131315251061272, 0.019651599333531434, 0.015613171628736442, 0.085801970093481, 0.035287886707773136, 0.05930763894631978, 0.036150739197769476, 0.020009820131705176, 0.03808259460774641, 0.051150683298586845, 0.020047172663673278, 0.02573313469427728, 0.02080153178183302, 0.04718358125237208, 0.03816273123506577, 0.024562713224440817, 0.02776958600377604, 0.045629020314663656, 0.026047912561484886, 0.06826757348232693, 0.04695873827703538, 0.05747277409799638, 0.015611128089198423, 0.06811639369134942, 0.04688733888249244, 0.07570710694116932, 0.02203405042359185, 0.04243863183223913, 0.030432858113800327, 0.05579173587442887, 0.01163634505393284, 0.07641314123306545, 0.04204541422246445, 0.026206544472745834, 0.05914501380175353, 0.024171416580136267, 0.15739593564742999, 0.12496572543656635, 0.14629034205309807, 0.1742500998079777, 0.13491995782861788, 0.15782756490572808, 0.16480293335212817, 0.15366416815067493, 0.13660619395875162, 0.14899870801356532, 0.20825697259316522, 0.11993763758049858, 0.1633629638461336, 0.15131515871372916, 0.25784846395254135, 0.18468695993144668, 0.11419062983364829, 0.13401071871480635, 0.22663975795430524, 0.11766792590459509, 0.11913626364642575, 0.19983647120816095, 0.09698770414557188, 0.19066166433115161, 0.14377795670542026, 0.27981735285251375, 0.19585315108058915, 0.19009990737803523, 0.1484903473887713, 0.1943804083331939, 0.16271396480020017, 0.10853292495613137, 0.15962108398877806, 0.11886709099335056, 0.17182789833074616, 0.11620268315797853, 0.19593579664586053, 0.16757949645961487, 0.1558891326309212, 0.12241890443669212, 0.11645792067171105, 0.08519161252244827, 0.15810951590538025, 0.13779712360232108, 0.10120281183551397, 0.15019657841372877, 0.13311940605842298, 0.07416245918120108, 0.09317781100229872, 0.1694823209677012, 0.14405863599911814, 0.21596450659055866, 0.22408319997691342, 0.15801876512987, 0.09295273437014512, 0.16969201455433525, 0.28328252175161917, 0.07999602720261582, 0.1902599737889344, 0.12234182066975102, 0.1295808152926545, 0.13888714414450432, 0.13434140822820126, 0.19901133322667694, 0.16248784628846955, 0.0804974317490574, 0.19978558764823023, 0.1585895619204929, 0.06099724586332037, 0.1977046323759902, 0.1649836994587414, 0.13418339493293918, 0.08888101535699061, 0.13891797152257737, 0.17423191288065526, 0.18232832843017194, 0.24525097541270718, 0.12918418093073752, 0.14313680239983145, 0.09824903726938272, 0.09606743336565073, 0.21336622746481052, 0.37609995733345714, 0.3577189646180599, 0.6396012308616793, 1.0279432119381045, 1.9101565211049973, 2.325244776664242, 2.979155855794107, 3.8591905947654483, 3.1345278024673466, 2.702327471586966, 2.5036613835442454, 3.821834186392446, 3.607304317335929, 4.909506699731273, 4.912592134168071, 5.842392925293216, 5.914065905155675, 4.288261119396457, 2.2420630724199357, 1.1532511105460506, 0.1912178901294547, 0.16045670205306622, 0.13534778729081154, 0.13520385469159774, 0.087311209269589, 0.10475673968152655, 0.17377553898240292, 0.1273120459048979, 0.38838117413463136, 0.18939273161513193, 0.10247796518547882, 0.10439485506785494, 0.12280855207673966, 0.19278991787183672, 0.20438726330476426, 0.23249674528356523, 0.0942243330721413, 0.12838278401402697, 0.18873153644944393, 0.1512910422658728, 0.2382279409756584, 0.16828261195651947, 0.17231745915787836, 0.1441995348901518, 0.18038788900500347, 0.14176849275827408, 0.1340943448726208, 0.10573789912966952, 0.17977708710297463, 0.16978046706607267, 0.13538485062458824, 0.2228782509243296, 0.2083804966100762, 0.11591147781620104, 0.19101357448004908, 0.09588446858669482, 0.1938269557731767, 0.20757742196081147, 0.08181429858649931, 0.11520292309503402, 0.1688096191613905, 0.12116673372445569, 0.23411797119244454, 0.30537416858057825, 0.10739295548128505, 0.09353630184646576, 0.08190164793162577, 0.2076794189070502, 0.1175457425415516, 0.1736887718640989, 0.11673408004665568, 0.18926643435993504, 0.22613335851459737, 0.15724596627537282, 0.16562882209977797, 0.18040616786287678, 0.10204305707086479, 0.12132837827647887, 0.19560455554916015, 0.1922840853371928, 0.16748451687876256, 0.1924823335702381, 0.1659452164125058, 0.1257305186722548, 0.09906177994825187, 0.14280735394887387, 0.12230680279073217, 0.26138175338987385, 0.07677168570338719, 0.21643450153210472, 0.12778620836475205, 0.08964682748961834, 0.1858464033613282, 0.1230128217608698], [0.03159917526758246, 0.0825563007064404, 0.04987343852858871, 0.012853161766073637, 0.012140736385669199, 0.034940699490928845, 0.01741222090898983, 0.04116120703157879, 0.0361832098344401, 0.05690953093430689, 0.06906092647583255, 0.019375129692977475, 0.009351695621115787, 0.013721403684617292, 0.015278978220697854, 0.03096499427732441, 0.05479156212400525, 0.02936239579632398, 0.008067240048530362, 0.043544678933798306, 0.026821994613255226, 0.02570783655579773, 0.04436546170543279, 0.030794532053292762, 0.05577071825222624, 0.04908778088828249, 0.017156705688384753, 0.008630232318424651, 0.054523186202371315, 0.023498291510247418, 0.05495069773807641, 0.027076289838840886, 0.04734882641763938, 0.019805651954224995, 0.02546641926821922, 0.061179773972159436, 0.04074086990928458, 0.0063975744001987965, 0.01542707546539004, 0.021064114163539583, 0.04126115469262004, 0.019715872195158756, 0.021273336606100205, 0.016203477805961045, 0.012880328201478528, 0.08485188317154685, 0.04211873266725771, 0.05983214487411803, 0.018759225645372947, 0.013750741979287518, 0.03987322936976149, 0.0608077540152496, 0.08133740885363472, 0.026190952668266914, 0.06248375904115458, 0.019415843435713363, 0.008102420721233131, 0.028457749379618515, 0.05801243324493689, 0.03646462074210567, 0.07200217550440181, 0.02611099415638995, 0.048954642467921784, 0.04949438588453397, 0.06056699173284635, 0.05591396520274782, 0.07068251244603627, 0.04808263139679067, 0.016734033913141298, 0.045756370940756415, 0.03350060358042679, 0.043424962373871, 0.03650598182913758, 0.02669862764436872, 0.05080135869643381, 0.043547433019886096, 0.1083999167707178, 0.05851291465542971, 0.029742769942048098, 0.01486095276871516, 0.029330352253671137, 0.026863564459246494, 0.010606337924517933, 0.05252269697525809, 0.011964712363307276, 0.014950951820449724, 0.08376632892196217, 0.05133605742406461, 0.032162366720337066, 0.07103522698725424, 0.028451921365734552, 0.04832959899138059, 0.04979646584439663, 0.08943187087894448, 0.07142529597566014, 0.04740381620884423, 0.028038042364642028, 0.02980832408572878, 0.06994614107233864, 0.022126306561873327, 0.011819559769074043, 0.05790168374416329, 0.03278765917545365, 0.06577687608378549, 0.04809206576957818, 0.07727256931004024, 0.029712032579306154, 0.05653142823927826, 0.017525473602056023, 0.015554556326429932, 0.016373501444656043, 0.031581727615106976, 0.06924284171433219, 0.04270827945982737, 0.034671687716317755, 0.05468067472740527, 0.03981634734138366, 0.07092648846728188, 0.013029747905450003, 0.006802445643716642, 0.032421220169072194, 0.032315733692338394, 0.022148503959479354, 0.0903531528949257, 0.013220667549889657, 0.033376639062959346, 0.04480656364091462, 0.029542198547372417, 0.10779230179445398, 0.06627051249867486, 0.03262433689087629, 0.07467987496526012, 0.021449400848078153, 0.07318919043867819, 0.0172087766845981, 0.037578252114115224, 0.010443491572063538, 0.04162273287112194, 0.08720583387560422, 0.05880307428719056, 0.015384096975227999, 0.005523138660787335, 0.05217711088217555, 0.03531333231817811, 0.05565767814855903, 0.05125222059207098, 0.01900284926617338, 0.02326222726203982, 0.028476723462283134, 0.04205017162847423, 0.026248187097089908, 0.01877666372174938, 0.03826482777273463, 0.05980911244067454, 0.02900635834873444, 0.04652355437076861, 0.044601194620613134, 0.029744895836037975, 0.015382795583366629, 0.013867238097103133, 0.02731084106339803, 0.01872782753179631, 0.02487329484504317, 0.04824449045343265, 0.008273193210874113, 0.03220702581588299, 0.0849533515171178, 0.07326763784212452, 0.09681711934747235, 0.05201728195853291, 0.0819792373165969, 0.003194838256252209, 0.06671783123766223, 0.057267527651762774, 0.1446602295242971, 0.050108696469255996, 0.024592383809748198, 0.063191884753084, 0.03712064481430477, 0.04719877277591056, 0.03656082223319719, 0.013660717072085509, 0.03918556203584998, 0.10139752074234909, 0.029588541121131955, 0.015339323924103332, 0.0792588897409939, 0.03645585286581228, 0.003540453077631913, 0.06469201897421191, 0.06179415350479465, 0.03623119375157741, 0.04601032142677615, 0.05265224627369354, 0.04197597984344729, 0.011867287046756717, 0.022719425239389943, 0.026097848087609298, 0.015693287188637883, 0.04109581376636221, 0.017047291095819206, 0.08315004183039551, 0.02793336411066834, 0.011126740493871754, 0.05806273840848477, 0.025700340385458646, 0.04087928667544358, 0.05855706813294561, 0.04587019245410639, 0.1648662428581907, 0.010725348725945, 0.02518168545418209, 0.04642657146999433, 0.02941590703783497, 0.051229908281276305, 0.033419869404526494, 0.04216081770737806, 0.05945869616322941, 0.019073166561523275, 0.027276767387745843, 0.005668767187143526, 0.06743492017830573, 0.048693452451017596, 0.04015031188065487, 0.024843461466051882, 0.05351697184866475, 0.04785107749123727, 0.029917430327904802, 0.057726870140721726, 0.06669964431033981, 0.02681635620613252, 0.012843585667020131, 0.013462706326296734, 0.05557565311450632, 0.03310106574527679, 0.04070376444067206, 0.10332541930819712, 0.04057182877835247, 0.06297926088013957, 0.059487079720824, 0.09297133498494664, 0.027426250293971072, 0.07264067914577262, 0.03465800155555049, 0.011622501845141093, 0.05241215431822404, 0.0816200952976942, 0.03365584363740298, 0.03833043171213039, 0.016799358230444695, 0.026082853831711317, 0.02472822652048161, 0.046303645001664284, 0.016192601272656072, 0.022838820042389057, 0.04332306884950207, 0.05746999702927086, 0.024269690339062965, 0.01994029190691729, 0.022879240756493904, 0.0238125465224467, 0.022588460593514388, 0.04895738889313033, 0.04915528855617008, 0.061852406830556934, 0.06222341555140673, 0.017325405910190557, 0.03793201619578946, 0.05989419416554513, 0.05292349119460391, 0.019451403321938652, 0.02669428584105786, 0.01766974327995652, 0.018805127718576023, 0.15661264138837017, 0.09085362281409964, 0.04169529288887017, 0.10066594507905746, 0.07636694613123134, 0.04799491049902094, 0.05807645138232939, 0.08485150012758472, 0.014870727093019074, 0.06342471419503132, 0.013783834104786718, 0.03489871021179903, 0.03010124354923685, 0.003740787942660973, 0.00955308864509026, 0.01804407682239769, 0.011058902450566812, 0.09213064541859974, 0.04794978408984119, 0.058689758391870614, 0.07298344986573344, 0.0034398999677280025, 0.05201078936337464, 0.011371577406422266, 0.03120552290291075, 0.0613963240457158, 0.05300390744401563, 0.030719918919907465, 0.009465931779554775, 0.05150732020997713, 0.06739441710974901, 0.03675068180347162, 0.04202762183042304, 0.03620353031663164, 0.05306937731802464, 0.03901537177303145, 0.00832544519535957, 0.024031155457299565, 0.0282251535944881, 0.09057205485840959, 0.01518576159968131, 0.0726324973267413, 0.05944455034970757, 0.025185908513864683, 0.021938457972400134, 0.03824950601424902, 0.05360798692450889, 0.019097702442518166, 0.06491642910987139, 0.049266133817934224, 0.053945797225159985, 0.005733049146064948, 0.019750991580827583, 0.03701881640740941, 0.020791116816502427, 0.015458427613691218, 0.017739361520075513, 0.038296260360267856, 0.028756701785530296, 0.047989701101135825, 0.015452345833182337, 0.055369196249352354, 0.0339356878952634, 0.025819208503009814, 0.017310591684954784, 0.01059732106964915, 0.01592974214168686, 0.034161599563254465, 0.02581028932435138, 0.025096094280841853, 0.0322646739321851, 0.014087742141958688, 0.09076651861710895, 0.014884013930455813, 0.024862966064604062, 0.031900341667595415, 0.059613886424490524, 0.03466560114775935, 0.06598189653408143, 0.2087568756072752, 0.17176466543347607, 0.09896237237919724, 0.1629591282577284, 0.10328975025444262, 0.07639798035304393, 0.1256357382742628, 0.1016998956460626, 0.10966476623810108, 0.21105978187293778, 0.10023422389020843, 0.1258371351286769, 0.22522130019722447, 0.13908162322496215, 0.12421051596081066, 0.10981596135083707, 0.14774457611624273, 0.10922366047217962, 0.13775080592641908, 0.09566719072961039, 0.09806439475787264, 0.09924967833344014, 0.09709775267589478, 0.09295109494198715, 0.305425496471505, 0.1678423105829185, 0.0853658822034636, 0.1839595288038254, 0.10414224523570269, 0.18804476926884345, 0.1250878858169721, 0.18070239874143756, 0.27548521757125854, 0.11789200662244713, 0.18873095422262148, 0.12961182653182937, 0.09656413413223722, 0.24150345714822893, 0.1046217856327853, 0.1139427544248681, 0.164190921031179, 0.10679310097569421, 0.1691341493278742, 0.1355683440042119, 0.3115814419523362, 0.14924186432073194, 0.1075278175994754, 0.10572805489984252, 0.1497472372026213, 0.12547350383453792, 0.1648823307046006, 0.26422976185717895, 0.16231333145931845, 0.15948052217643108, 0.09648926435939728, 0.1290557079858357, 0.09471894241869451, 0.267727259666689, 0.10278345806704414, 0.1725353805288192, 0.07905084324339706, 0.10493923714684864, 0.17735335344989456, 0.16476090576860214, 0.21748676926137941, 0.1560949498126584, 0.16102230476756252, 0.16130044064935178, 0.08984778767391559, 0.18453711313345741, 0.07571813860727895, 0.25753461305172215, 0.11941235407345718, 0.10731786354294709, 0.19248835502132294, 0.21399397523172442, 0.07395599082472824, 0.12345016603508305, 0.12623093496527404, 0.12915044241855222, 0.16220145197885652, 0.09369431514172785, 0.08638271836624031, 0.07885942085375709, 0.11408012931145008, 0.18171335900983504, 0.13214569298490403, 0.16201763684230466, 0.2284394976713004, 0.08707399014383556, 0.11131390839094117, 0.14766142493294132, 0.16735446579273672, 0.1947189885522089, 0.09769683343268211, 0.1253711238443371, 0.11132369133373422, 0.26615294898229264, 0.10461691331358687, 0.18364705686126986, 0.27173279634406494, 0.12212992074989504, 0.1443333551287651, 0.14753621552259694, 0.1682289091930274, 0.05881938812953811, 0.21542904177500358, 0.18315475343936877, 0.09453272942693965, 0.1415589523892249, 0.22596805206229612, 0.2554061143629013, 0.12773459702129328, 0.13915339034170876, 0.1961700663331055, 0.08517272079423552, 0.23267688319808055, 0.1552860528951691, 0.05083706988502414, 0.1355132009954222, 0.1023096939729106, 0.10462875703289624, 0.19128458574414256, 0.12238999993930902, 0.09860666243419533, 0.0960379159979282, 0.1493908684220045, 0.1917915367671559, 0.27699943631887436, 0.14251168997537705, 0.17541199471921692, 0.0895224684368699, 0.16357031320371937, 0.08735951111321488, 0.09619659578968441, 0.2325591661276356, 0.14058891653774247, 0.2370549224677586, 0.19659611847131483, 0.09868825079813119, 0.08186959481287388, 0.1666295167899901, 0.10405737035457166, 0.14305429473038644, 0.20056705861803026, 0.11120981236378993, 0.14239290038183813, 0.22384911415077027, 0.15605952590703964, 0.072516503954126, 0.10892293265750332, 0.21934036495945147, 0.23053542230158086, 0.09436733870496673, 0.21610899077307796, 0.1372560357014018, 0.12710683393262087, 0.11496739702359324, 0.12190343451596077, 0.096510331777315, 0.11150261116844994, 0.16761870483957952, 0.16551711115865939, 0.14874611350317157, 0.1570316761611931, 0.21824525759345104, 0.17951942109052213, 0.23597613277454532, 0.13265419150552443, 0.19781562319445997, 0.07458877178930468, 0.16339138570812442, 0.13092778172464142, 0.26411261169179795, 0.11717192993889894], [0.017915954362721215, 0.06997906753132421, 0.022703919619802507, 0.02123658162271304, 0.05483733204704139, 0.0381589429302802, 0.025117600284096216, 0.052095821292530146, 0.08725442683264133, 0.06029997944771763, 0.027605390378965006, 0.08490960023576215, 0.04577346619278674, 0.05264668447536327, 0.1091644342147535, 0.05604727982333111, 0.043018192668715795, 0.05105083905941537, 0.05988762879203405, 0.012491907259719747, 0.03892053774888477, 0.035467702865360246, 0.013705020894356554, 0.0707161283841537, 0.03772758563319522, 0.01901350363398031, 0.09660010962116142, 0.03825191536077088, 0.09608360548173228, 0.022882647932537144, 0.008830007939268986, 0.02251010512061898, 0.0735826991618641, 0.026833181412169532, 0.014082897593447519, 0.03078106039714429, 0.06850739730702293, 0.0484133247406252, 0.10997449558588768, 0.08819846932085292, 0.00900331330710962, 0.05322784260516206, 0.04833827110668344, 0.038860782890790896, 0.014815335105653974, 0.028635225138596954, 0.02154016119968747, 0.050628835695885846, 0.05511461757123471, 0.031339831522575794, 0.04968439484195364, 0.027392912062726198, 0.01015136213672738, 0.01915444274463, 0.015479608029577763, 0.051011554070658265, 0.03873601781144258, 0.025424276771504554, 0.050668549693880544, 0.04109347719819315, 0.06799182013398217, 0.033401008319830706, 0.03953142775102489, 0.03562515691643761, 0.010622173919522715, 0.047013919590221304, 0.012119721636296281, 0.03575111326250819, 0.056092310471520315, 0.06126423899625098, 0.053941009175633235, 0.05499397787535864, 0.05839132884096715, 0.05865932554907857, 0.07341933857289053, 0.06089844350372592, 0.04634455792726048, 0.025626345868072203, 0.0479660366451548, 0.031993741192103874, 0.12270630232148594, 0.01139240542186364, 0.010637775300100688, 0.018277095871106274, 0.09459897304975218, 0.023834025712623715, 0.044848223502236995, 0.03814447919026979, 0.04486690072583095, 0.0291139496520402, 0.034192377145612435, 0.06535890617317731, 0.011530738875960872, 0.06341300837154831, 0.04833929383406236, 0.028499181329783414, 0.05848021802282142, 0.042774312408460725, 0.02032104909660355, 0.042668948505794814, 0.011458313881209301, 0.023377337718322393, 0.045847929939026796, 0.0844694290971083, 0.008161914151822849, 0.03762101514204856, 0.018542344238789334, 0.049207133556445765, 0.026769084750764796, 0.08079389245399544, 0.045426033827806675, 0.03482074161330539, 0.05774756983643579, 0.009207471908490744, 0.027735125453722094, 0.029443377035579858, 0.050588313475131035, 0.02933423823466705, 0.02980594346750408, 0.0117465132854939, 0.04494452841519829, 0.016772460883423206, 0.031639337427012866, 0.0248087442765433, 0.008263214915660361, 0.07806956888206544, 0.014212292716688207, 0.03731115938975446, 0.027782653548544454, 0.0970616392911442, 0.09942720388813366, 0.05082672769804636, 0.04899208501522099, 0.017861299734983235, 0.03178353049612093, 0.02025074903823195, 0.06825102598316247, 0.024474624604467424, 0.015268941511279874, 0.08038285563910201, 0.061136719830814874, 0.03817265590412482, 0.03834524785258597, 0.052433895893515124, 0.022203133689359795, 0.01625822819468956, 0.004636454611881486, 0.012888524384658425, 0.018993826665645166, 0.14438970855647518, 0.04600256478654281, 0.005975899975671764, 0.02549994902144517, 0.07892877479354221, 0.01931715024364812, 0.06481655422718295, 0.024133194538374102, 0.023023705786815094, 0.0449276170242698, 0.04004002586307545, 0.005755589846822043, 0.03298337931834883, 0.05940974697530751, 0.06564716973732557, 0.08156962542524261, 0.10407088414555597, 0.018250805648764776, 0.12831348370039655, 0.06221488133193024, 0.053563519350944035, 0.01146021952492095, 0.033641912328499946, 0.03967512286298218, 0.027088499365134106, 0.01896551014074395, 0.036549047461801, 0.05467888591210208, 0.05405082404913922, 0.03103933927993621, 0.10634263361533804, 0.04506332183917684, 0.04267844799605589, 0.027309138432986317, 0.022413150948141853, 0.017212819713618488, 0.06809853618183444, 0.06763120722626487, 0.03666913557437159, 0.07168119232500754, 0.008787776384833119, 0.0817584201333023, 0.040513387761048736, 0.057086654292840155, 0.05153375790424405, 0.048952405491182883, 0.02686161285025939, 0.012667175727866352, 0.043420224120059324, 0.059353274803969173, 0.07164392980837053, 0.100590301557414, 0.053663064815825036, 0.08960058642250877, 0.04870726118585275, 0.11404786934895862, 0.04199261161228342, 0.007387619031848567, 0.027072620277683583, 0.061311498960299846, 0.007721614214636747, 0.02383996289403689, 0.005471506249910642, 0.009529809148291187, 0.02903739065532723, 0.056005056887384386, 0.051677897347197424, 0.020419353499047218, 0.047546913772220575, 0.051108920015394695, 0.0029756346456481205, 0.031553757744991494, 0.0687606736356693, 0.046026056872740875, 0.02167852817013139, 0.06817628644526967, 0.04515249830400271, 0.006446357442802119, 0.08711558105724473, 0.023539579818926515, 0.03275493572976801, 0.022332298028613293, 0.027133937955142993, 0.024863737898187774, 0.029688335564588348, 0.03097720763405725, 0.0456299242984143, 0.021941303989038836, 0.11487287709549551, 0.03366349685576654, 0.0269625008842277, 0.02079390920698643, 0.012669170429299196, 0.06865535186783922, 0.031817973809196584, 0.07852549844932172, 0.0797317345296183, 0.04465567496334834, 0.012304515450171406, 0.036934021965510426, 0.062580083106314, 0.027143483410679528, 0.0545426371747688, 0.05615636308286941, 0.021844177446778745, 0.03114909286640825, 0.08868406947341659, 0.06794433800443526, 0.05288360099638662, 0.06195219744357371, 0.01003298623066756, 0.09422298475739457, 0.03582468068587684, 0.11626803811879889, 0.023468216813559976, 0.031400413755627896, 0.06900676405958592, 0.0352827271056031, 0.005127444671797416, 0.04836685001669873, 0.03726210294952316, 0.0582773502795927, 0.01136298573035146, 0.05209735729881833, 0.02414823475954754, 0.012700374148065045, 0.05067647870389685, 0.016376290004700422, 0.021817134543051644, 0.036263928688581915, 0.019468680519850987, 0.02734925654236107, 0.03443497420859433, 0.025131138972938064, 0.009881394667430751, 0.06134313839157263, 0.02102689761217804, 0.03424754313703987, 0.05162778753607024, 0.022155287668048855, 0.031869590898314794, 0.0382423086182004, 0.01002032375488911, 0.03558723939462535, 0.0311778805353829, 0.07054915952105677, 0.10626248549669982, 0.03673361336451866, 0.041174556113659375, 0.09175224394928064, 0.033866471851304654, 0.029119350571906375, 0.05694394743430519, 0.05453111521238762, 0.04145056227101915, 0.021384589809684024, 0.03247600311653749, 0.019408799257249604, 0.0650873126822614, 0.05057061684408015, 0.04409981688724891, 0.045362065486129255, 0.051030644981731335, 0.056775990317785935, 0.022782177416487567, 0.06351500148734739, 0.02198433131730605, 0.019309198250994086, 0.08318922722772246, 0.038205191658269015, 0.04816715387747653, 0.05834417229878807, 0.03569872433980627, 0.03512872428062462, 0.019836984950328068, 0.06408995813539912, 0.16563723374518657, 0.04280268447473646, 0.019785599602806955, 0.03993312212368173, 0.029801952149418574, 0.03316807162557398, 0.028240848820836797, 0.07517286786629308, 0.050702460575848825, 0.06612700890869865, 0.02409414703687353, 0.03635645295763689, 0.03677705054982536, 0.03014150146965779, 0.07882862411920102, 0.020890137511155298, 0.053221449601433934, 0.05552949631706842, 0.021187241729949752, 0.027859105292948026, 0.01899048077663587, 0.048347284131112604, 0.05002218982084625, 0.05973757515030523, 0.006057920221674947, 0.00504586061710612, 0.018987711368789597, 0.14915805430181567, 0.22486505399067558, 0.12449186941188191, 0.1622550474900392, 0.11000592051254166, 0.09043848742881129, 0.1234130031098762, 0.20332065440954702, 0.16250899031517968, 0.16465832659554097, 0.1530329117010678, 0.1385479663769084, 0.12134351617386266, 0.15273209961671985, 0.18931140372109032, 0.20566811634888574, 0.11475761916728751, 0.12061197115408799, 0.15810833612997688, 0.07313117460017243, 0.2352898405684579, 0.1717188227320871, 0.0877093528247168, 0.1830836911235125, 0.1318157848811919, 0.16515996096835983, 0.10429128764137145, 0.11857560985992033, 0.2255250540592017, 0.1613814467864652, 0.13391960021709243, 0.13826927891181362, 0.16507739201188087, 0.1390505813422703, 0.10214172919551212, 0.21000639565529364, 0.18515703148178517, 0.12917196948922452, 0.18170888505635724, 0.17177794939808308, 0.13768121449937745, 0.1959327169724049, 0.1463198211164244, 0.08184256723090526, 0.10116474492655647, 0.17320161655304894, 0.1536376615084948, 0.12667019445929797, 0.10263472975742433, 0.23915905956058736, 0.1417666541472558, 0.17663799586795992, 0.08948831623720546, 0.12662555451595014, 0.08457436782097624, 0.10220038854787428, 0.10782423233913799, 0.09635294667415081, 0.09403323243942954, 0.155409163224601, 0.1753359834753698, 0.15497735010520106, 0.17705761286760532, 0.12135971127258194, 0.1142685179929099, 0.07753554431180801, 0.17131933852309184, 0.11237759083028763, 0.22135854698717597, 0.2611027441678509, 0.19064775217444668, 0.14487504057826536, 0.12547894305880034, 0.08550990673322832, 0.19956100131234816, 0.18080994216424806, 0.18215425793201695, 0.27425871080448555, 0.10407892806876091, 0.17557347073189675, 0.15586215101422804, 0.1607892608209964, 0.20419188024055576, 0.17960110138500893, 0.2874186304548095, 0.09895059760780105, 0.1904673537900371, 0.1275202992462343, 0.19183289019330857, 0.13532226124117452, 0.19810449962894763, 0.16658937378275782, 0.1133964571260637, 0.17979709731955684, 0.21386712639322206, 0.1939929363828513, 0.1413227061951353, 0.1343436298831817, 0.1495270482114246, 0.1796805447027568, 0.09278361279998096, 0.10405640508378707, 0.16801667219448477, 0.12565006411844684, 0.11878096738890295, 0.21428919487422515, 0.18196028446958912, 0.22190015582788378, 0.19696160369823057, 0.1516628553790431, 0.12097121276442083, 0.12288036515876172, 0.153929203928959, 0.12533440525012632, 0.1274215811563115, 0.22840726069144665, 0.2081878101753612, 0.08204802435131804, 0.2391611433197414, 0.17353106500400653, 0.13903054048217114, 0.09893144540969404, 0.1890701319902174, 0.11175215664890506, 0.15651108877312753, 0.1446930334092148, 0.19676497957158476, 0.12438759718450809, 0.21009829556269033, 0.154475393975454, 0.1904971852538086, 0.14623955042371828, 0.16098629863512132, 0.14208528543672255, 0.15197105255098114, 0.08057433165489666, 0.14634303358053008, 0.17435598848087175, 0.17586636146710766, 0.20938610958476223, 0.1406673486194303, 0.18696665373300353, 0.18017549878887593, 0.21714140150335529, 0.134729768840536, 0.15681067511679667, 0.11393120181896996, 0.09668593445131857, 0.13032009013958518, 0.2130801395903672, 0.1345055655486161, 0.12784590959669123, 0.15898129331969446, 0.12263918535843973, 0.09739462706831195, 0.17372724479965626, 0.2069804096414197, 0.13140929862856865, 0.11207635739758132, 0.14434047974646091, 0.12946637707852549, 0.18352716410111997, 0.18417346651755995, 0.16531932257836865, 0.0943233575972338, 0.19910897879350573, 0.12189380479075256, 0.2392473741764984, 0.11277840803227118, 0.12041348543378616, 0.19433646552985717, 0.13306852249849227, 0.13441081579414108, 0.07337409342008253, 0.14796024518868617, 0.11834689431012639], [0.02683467336840207, 0.011827538574805424, 0.08690119135163485, 0.02105724235485879, 0.016138726139381047, 0.021786910459218968, 0.04070389084517956, 0.01676020347663472, 0.061452271446826, 0.04486172963234206, 0.013460082475156074, 0.04457262337147709, 0.04307830375769446, 0.03287724166687939, 0.05841926040668642, 0.03731319335319343, 0.05585692612634552, 0.015057817255447229, 0.038929412877487565, 0.02226102503857786, 0.02540626412918491, 0.020314916562769684, 0.06727902128571464, 0.016207955589878465, 0.031405829997252555, 0.028057577606711178, 0.05239440023057884, 0.037004624628612114, 0.04083925092052068, 0.08149502378317618, 0.04424269228512722, 0.04309904175780473, 0.08564082349860862, 0.05005614666808998, 0.021321764854233594, 0.013960483446416837, 0.025280930229552814, 0.07089199152805152, 0.05802467916040652, 0.021609528546011256, 0.04657410851289188, 0.033784232312633146, 0.03883199330659644, 0.03468158557229946, 0.08706681956086429, 0.007122797758183292, 0.014636395161130257, 0.0289371786939521, 0.0434132757025861, 0.12453473969212464, 0.031446967003566605, 0.01644770855144147, 0.010503446570627633, 0.036644245377711715, 0.05700582818638894, 0.015328427280990348, 0.03259501487557446, 0.01661628045351996, 0.04223939534577151, 0.022953294645694476, 0.01267149263331967, 0.08643314227341645, 0.03098938460161369, 0.053921585016313105, 0.06298129101313892, 0.035001258741343216, 0.036851456839471095, 0.028728205229966875, 0.01194836213178332, 0.01012038728672891, 0.044583168571754817, 0.029339721508985086, 0.060732780820539886, 0.10546872647659433, 0.02521926972774729, 0.09062129899018234, 0.09759261483146299, 0.037624688533645485, 0.08645205698426693, 0.04193838407856323, 0.026202292684766076, 0.05618028800874468, 0.0063260802022752265, 0.044239536002879186, 0.09269967254611755, 0.01530063839914698, 0.04311661964522735, 0.060358960557007985, 0.015723268039554598, 0.06123597418228465, 0.02129730941247075, 0.021684392573191755, 0.05916875486652698, 0.03050964693689058, 0.026664910199601325, 0.06713732566323972, 0.04887101247966771, 0.05994991557071767, 0.059488186717874585, 0.022276224222995585, 0.017116020673946027, 0.005288144062844015, 0.09043804309781521, 0.028546646222352024, 0.016681114474551815, 0.03511483510655742, 0.016995990017969764, 0.023534636636595094, 0.034870985489819324, 0.05175800716143943, 0.0461690242011701, 0.06951390660458034, 0.06160776814325683, 0.11307318334377582, 0.07149897065133819, 0.057608206951690305, 0.06975780601703352, 0.05897092415140041, 0.029464982630264376, 0.019115506325878443, 0.08060217895094426, 0.10640077968879093, 0.08222765664780333, 0.0663383342626114, 0.028162924272398797, 0.0442252024978159, 0.043065862489804145, 0.020240021892072215, 0.022253120926419095, 0.04326933161205342, 0.048861528311165116, 0.07071972133651858, 0.058233001449656104, 0.070316536922849, 0.0734336873997123, 0.07260766075623613, 0.07252567402657963, 0.07407095763952502, 0.053784853643587524, 0.052668835907693834, 0.011917777986626231, 0.011497257960840099, 0.02033120933769932, 0.1079587497177624, 0.06431459043655666, 0.01554226061524523, 0.037234677001833916, 0.03353276395148808, 0.07255678485718466, 0.029930020982940352, 0.03658158704638481, 0.056144779833454284, 0.03771192679602293, 0.0072465645292052825, 0.03520255983476678, 0.03618057449198058, 0.06545921006510336, 0.03336410203407849, 0.04565221362657124, 0.05511487804112896, 0.09594967799080957, 0.04086052518217795, 0.016325025316027385, 0.06672652633560282, 0.029089622530004675, 0.03277025748825362, 0.024985339034408815, 0.03260582820662568, 0.05712796175371736, 0.04258318496267161, 0.046593869750898693, 0.07160240018199529, 0.009250788434949375, 0.011332301036154312, 0.06351947161038557, 0.03438907405061107, 0.08007277389087024, 0.007844819826254202, 0.041270581404528314, 0.012321145303787725, 0.01870584463880908, 0.043314404395078464, 0.03768170462741006, 0.04255462137441482, 0.05132810543141058, 0.03851183750216038, 0.032093317300501856, 0.02890701972759299, 0.012281150726090756, 0.011745552802758833, 0.041184174347548716, 0.04914694968911429, 0.00784269345345937, 0.05058254866350082, 0.03450510189718297, 0.044995856306125084, 0.059929407396984685, 0.06396314377085337, 0.014567607168799207, 0.021210057743554635, 0.02081258643058039, 0.034371231862854575, 0.039915011805151744, 0.06652717493594655, 0.042229742637925574, 0.05093262786225927, 0.04021878481932706, 0.013803742814718956, 0.061877473227439396, 0.02637563539939302, 0.0444119977163932, 0.04470811751220496, 0.029534062693616556, 0.051679015835566874, 0.06799894475167798, 0.009171367142229311, 0.04554562015278686, 0.06216847555591695, 0.05596184952845497, 0.022085213605614922, 0.053993363624378565, 0.030547166092982216, 0.05027477283992114, 0.007011718360797292, 0.011443251635008042, 0.10367347603483547, 0.005435377064596621, 0.0022386013241034123, 0.07274639927932332, 0.031519705136757226, 0.022569145601723465, 0.1687684036310642, 0.04364541183496195, 0.0068509572039117984, 0.006288500237954601, 0.01671393751166761, 0.03620857500561303, 0.0623332457466712, 0.0303833132925173, 0.11054349973076776, 0.020586944808582627, 0.03064975675736224, 0.04392457427456976, 0.059367037573528875, 0.04226970178405604, 0.022018717173787377, 0.012927923328994263, 0.029156743323490508, 0.04059701774930281, 0.1127227517445722, 0.05100565902408093, 0.08748213880725446, 0.03771268905350759, 0.04794599961549525, 0.04760076209241825, 0.012726360808066543, 0.007991828747288956, 0.054366980874610525, 0.05422007968469013, 0.051972412188807805, 0.0823077588011661, 0.004617581078256931, 0.06438124008596906, 0.05145831739590053, 0.05037317683379497, 0.04384083703400628, 0.033609709822602814, 0.026380952049587524, 0.04489521150507274, 0.007046913876453596, 0.05396124155771348, 0.07582143790298894, 0.05756008896916624, 0.10148991860689656, 0.040729577773280685, 0.020744739768786297, 0.02424205563241436, 0.037873134677929264, 0.0300547554187717, 0.06317901064551647, 0.040274797337910825, 0.056778227294524836, 0.017594871591896783, 0.03466572372182723, 0.05479574879451145, 0.073924841689727, 0.03404011717066169, 0.05965830803277993, 0.0202642341009191, 0.0202191689787733, 0.03416346881778971, 0.019122364728020567, 0.025867067930859425, 0.0038004022715012395, 0.020588846621854652, 0.020045113802376776, 0.024490674146481102, 0.1280125490419807, 0.05602756072016013, 0.02006448433554221, 0.12403102922103099, 0.009415505957158824, 0.02513834594508573, 0.018670370937475277, 0.04333204739997464, 0.024462528076143037, 0.05093130253015026, 0.05128922263881372, 0.06805257856725686, 0.019163959471869375, 0.045538395943660895, 0.019732299035475142, 0.0405392432284932, 0.04638636717572809, 0.054671002867361235, 0.042507932145869544, 0.013837852879547545, 0.03147873475456671, 0.06225693572853362, 0.04486928708971508, 0.032618958953647845, 0.04269417961158099, 0.02193074538222244, 0.03729058992898753, 0.027762763990810322, 0.05072597564468461, 0.02760024226811384, 0.12323276560393073, 0.03661185134983352, 0.03852438985279972, 0.024420243853162375, 0.047062474242862196, 0.02036906748769745, 0.005850749937141495, 0.08288539675695282, 0.04734288540578658, 0.04250893189061073, 0.04757566505201882, 0.02202471564223449, 0.004485310731275428, 0.06141137767342791, 0.0035036478197247155, 0.005891205604007889, 0.031680416976732594, 0.010096665374153565, 0.05693402276524613, 0.020240782234337062, 0.01804983588836847, 0.09757275783246565, 0.034264439206209876, 0.00972187409417764, 0.0703868178290225, 0.12118403965066518, 0.2114877492309578, 0.20527758004684604, 0.12227468838494633, 0.07934317473442325, 0.19383999458964796, 0.14717905001053888, 0.08635850998783305, 0.14159181756117653, 0.1100659205187713, 0.14243367158116835, 0.17565479862593836, 0.11819360777735712, 0.12566954573436132, 0.15542944923283594, 0.11297356127010239, 0.21635087537429026, 0.11950478258152163, 0.14509861567808738, 0.12108141451232857, 0.3914801836494477, 0.11871231825000818, 0.1021368568763137, 0.10961015949085837, 0.11487123000645831, 0.075284747346755, 0.13868373247884935, 0.17076536502328613, 0.16556805600562405, 0.18380445728619255, 0.15641053207218647, 0.17447384344714303, 0.16216719252688272, 0.21826028823852542, 0.11020570858231477, 0.1479064198511262, 0.16041295843258982, 0.1321883027952525, 0.16500246861288625, 0.09106484091570301, 0.07791965313616299, 0.13045789403540473, 0.11348412822811835, 0.11800236158793974, 0.19002403403001447, 0.08919065277422629, 0.10194415511984019, 0.18169670425836118, 0.08588122188924782, 0.2510205367880483, 0.13697475885912297, 0.061302348040044315, 0.1547594746995357, 0.09818290855975882, 0.11319460827977428, 0.2273043085851016, 0.11389587750478138, 0.09993367993663396, 0.08140293235379843, 0.10890637749745961, 0.17276862365824563, 0.16900454257284442, 0.12646683641979772, 0.259249975844737, 0.18090824656669172, 0.10974488371322233, 0.13256874205845018, 0.07505629226685533, 0.1600838777038359, 0.13219084620716112, 0.0870999681853479, 0.12825562107947566, 0.15523596606667966, 0.21959977765237132, 0.10386485245919998, 0.21590518074170237, 0.21619768843295115, 0.0985944509926823, 0.16673958830295071, 0.14809424928840131, 0.18916088276572768, 0.14289756846283713, 0.10488999301507589, 0.17512944617098378, 0.16679632477462294, 0.03533620004271788, 0.15083828430262305, 0.22109207096359423, 0.14567707334795307, 0.16313542041086382, 0.11998591644148673, 0.12711389726328273, 0.19987587877098592, 0.13409431422910384, 0.1228294279726763, 0.1510154038307167, 0.11603130928931699, 0.25175889232946985, 0.11725078336894514, 0.11200548660370613, 0.08571270552854385, 0.17371840414501008, 0.14142067351889226, 0.2002303476535505, 0.12339371301594282, 0.12734896368196896, 0.11608312747651532, 0.08620208249457421, 0.0978995019930505, 0.1502427581938044, 0.18654976400636858, 0.18313950828967557, 0.2117445725466936, 0.3094816868824344, 0.13555487617850304, 0.08556648998731568, 0.16190299944531533, 0.14650231858174648, 0.09493348534188925, 0.10670952844403445, 0.11043112229315505, 0.25922049678141074, 0.1658310846335465, 0.14464749714299557, 0.1917388452397239, 0.13606266989823312, 0.16689096727678854, 0.09832969100605096, 0.27171315384968636, 0.14749420326082938, 0.11218074453814376, 0.17253086061006592, 0.1277897476909622, 0.16187436307870573, 0.19889041390870849, 0.1746713102705056, 0.2212618360476148, 0.07190215506500776, 0.1268154523906208, 0.15467114476186616, 0.14856663442427112, 0.10354663485721236, 0.10537671165600901, 0.2256926128100003, 0.24072613837497853, 0.11890077587938118, 0.0932129208118685, 0.2243549160418972, 0.11245118889717326, 0.11525346957627805, 0.10970182191099852, 0.22440059020394282, 0.1516496480232285, 0.08004809819882916, 0.14118154683420736, 0.1284841757508055, 0.11026421471709207, 0.11475815542883451, 0.1588127233328358, 0.14889402975959165, 0.14391375345087823, 0.1174486868624245, 0.1508659094331726, 0.16717920019741983, 0.2115687706898297, 0.09124193746115893, 0.053611595198632254, 0.15949017488427703, 0.19161228751463277, 0.15671595600583862, 0.1656456147470782, 0.29342353404048954, 0.17705137691190168, 0.12457893530447638, 0.13581778223235763, 0.12264590394953567], [0.01138143600039785, 0.03480946096862036, 0.028916184054387194, 0.04168144968007842, 0.03756255497254672, 0.027080660370448907, 0.041525887866174026, 0.03723294947356467, 0.06710328837676395, 0.02567300828354013, 0.05738719441597501, 0.03020601947942088, 0.018611428132581136, 0.08585993230583207, 0.04031289105994567, 0.03989377967833031, 0.03736999111189958, 0.014092150977962922, 0.02624306196887647, 0.06285417787430268, 0.0826952690559049, 0.023228333617049842, 0.02390558023997132, 0.02086716827996556, 0.012196703896587415, 0.0679815698775553, 0.04952322909488313, 0.04604899354519383, 0.06363548413519898, 0.0011625920512503194, 0.03374208981591848, 0.02407178301514397, 0.03295714463738184, 0.026795173875026168, 0.030981593487423756, 0.005413205043653087, 0.020972511115213557, 0.01624440605331573, 0.031137733697710984, 0.0187830567254775, 0.042794916343184254, 0.05564261685996767, 0.016039112684196763, 0.04901962204565925, 0.04403117157879376, 0.040985788218677044, 0.034350233392850045, 0.04335807523720207, 0.02691743767730171, 0.05160737512332778, 0.03220870354843717, 0.025584611313177213, 0.035030676517635584, 0.017274899648562554, 0.013701934517631608, 0.009125489966883775, 0.04598336279272072, 0.042173879506487044, 0.016406655814799092, 0.05689328603987252, 0.057108943620997096, 0.04748709379665313, 0.05926318286407379, 0.056120333967790495, 0.02287832911186401, 0.049882237048399065, 0.061053978504552964, 0.03292569289765051, 0.036713112851664904, 0.009550753992141016, 0.07120543640227088, 0.015008538649717887, 0.08802578544184085, 0.047088172662282185, 0.03510301436988577, 0.03624504845168802, 0.06996206037940518, 0.036031991739066384, 0.06780666434356282, 0.08090054721481378, 0.02091363151257317, 0.08170012084226455, 0.04000505777977167, 0.045881844651434696, 0.05440207919286144, 0.00042994907186854817, 0.08613046859541247, 0.015927712966297424, 0.008747533786170667, 0.029952203058787895, 0.03384716260517317, 0.09380990248774329, 0.05509781343261561, 0.04706180008548883, 0.033205169433307265, 0.06615422801264832, 0.027293288073832953, 0.03412118842524867, 0.04918744126635213, 0.016077839386379047, 0.01976239288436069, 0.023237428995930863, 0.05018139438283059, 0.021696355036129395, 0.035463497042655945, 0.08439842040740675, 0.02430526554704674, 0.0622986147420541, 0.10849672730170912, 0.06400749643122958, 0.04377920143005829, 0.011980374073309284, 0.026204343885183338, 0.0056830772307641325, 0.011604157869794197, 0.0188889549744706, 0.06763417964741107, 0.09081098236023419, 0.010935253944368133, 0.055916669493120526, 0.06303738780139435, 0.09859010727415163, 0.06127777576987302, 0.0076998080006770555, 0.05275271487452331, 0.02503009197572547, 0.04998970769285675, 0.08084158142728191, 0.013712360974281065, 0.10757070320147662, 0.03115398433780478, 0.035712077252326474, 0.022666580494373076, 0.04285942094640867, 0.013351531646725152, 0.10047433882831566, 0.0082047336787406, 0.051355435618109284, 0.09828261490310393, 0.014110176069211337, 0.048570916687528935, 0.04099763576842604, 0.02392532424099984, 0.031773527303049644, 0.00717439521629844, 0.04127395602183477, 0.0361431549273191, 0.013685728885203361, 0.01207790281172962, 0.021461665915745883, 0.017457333911630898, 0.026666875215127107, 0.03636693687088067, 0.066846901731145, 0.044655824350493575, 0.041711166230661255, 0.024024159159331072, 0.06009562549391582, 0.02347303359138389, 0.038261372716196125, 0.07636146860257273, 0.07521370035265723, 0.0322121815876134, 0.0741858172020124, 0.03104419819259596, 0.020951070229432756, 0.043984206558595744, 0.05289645595175605, 0.028972799867211334, 0.020280425369198767, 0.09991422130335724, 0.041369498677311406, 0.011930044011903868, 0.009097105451679278, 0.03601198152248417, 0.01261639367458561, 0.02467449311347258, 0.019526259688239907, 0.04537805374110899, 0.045769137796014554, 0.012164558847284606, 0.07888856283839672, 0.06288157700891457, 0.061272750233089736, 0.06355787559802975, 0.012514009853945145, 0.05909088968990311, 0.031160942331377058, 0.027247047006723382, 0.06717160043697204, 0.061250863101093046, 0.05562012834895042, 0.06672966729609237, 0.041993994400986744, 0.06470342602340445, 0.03854343479859733, 0.09222105911542332, 0.18897573463618758, 0.03141443124942241, 0.06800629153487182, 0.013376076146209193, 0.030590559228233276, 0.0358486017813125, 0.03973788844661848, 0.03353353003941236, 0.023719648785528638, 0.011709519857240301, 0.012422094624789973, 0.06475876821505447, 0.01801026170141995, 0.01982500333519232, 0.038349932480242946, 0.00370052307956822, 0.04357631453463147, 0.03373596877340348, 0.03180837855794497, 0.06518211606289111, 0.04772345107349177, 0.05254016761037131, 0.03249325158615266, 0.044368483922294075, 0.07032790566764532, 0.05992779478190407, 0.054205209918079846, 0.04572066741304533, 0.028577452533007152, 0.006040885777873618, 0.03223056003691689, 0.025381291578073176, 0.024596995659052365, 0.04572937017186515, 0.033118218453901435, 0.04427278421879296, 0.020768174398390037, 0.04768600469575294, 0.05747383512977151, 0.06610524435076984, 0.10903810631603965, 0.10541349153725371, 0.08786625529248869, 0.01297513924298748, 0.025737382651817416, 0.10577854775493184, 0.038704121740715164, 0.05665976711879334, 0.04186918335636297, 0.023372415603408893, 0.04075068349559461, 0.014042379203132324, 0.06448236369197408, 0.03483091526093983, 0.022001755987143806, 0.023032385562997193, 0.04842192407757525, 0.06441782078435344, 0.012589639011440019, 0.03539245004855818, 0.10051697928218112, 0.016874741282193892, 0.02435609548082275, 0.05727876233117235, 0.05912213841633451, 0.061520951229237744, 0.030147442481510585, 0.015169900706818989, 0.009123130416076992, 0.024090510034453005, 0.049311290870630936, 0.05599211766234329, 0.04155384241453102, 0.060871825778796795, 0.0669305891759934, 0.04222288232056364, 0.024439271561981692, 0.030479424768277717, 0.038908552303309404, 0.09749422615934765, 0.049202115680541725, 0.020774555910799294, 0.02882776218616674, 0.024659029628720977, 0.03379565085314455, 0.016815428839876287, 0.017496873624622822, 0.09290545142345852, 0.07630460189595338, 0.04240553683391021, 0.039658487263706424, 0.06189140453634243, 0.0513348929704197, 0.04358048588337918, 0.051114137074159044, 0.026343157101843147, 0.006885609275946815, 0.026597546173199534, 0.10920073912148515, 0.053984362091268265, 0.017764341732066487, 0.013038761887489068, 0.004131607457830181, 0.02951426506643334, 0.024940107288139484, 0.0274376918171202, 0.02188182875303732, 0.08529652826367848, 0.08538468200112544, 0.0164843677738381, 0.039865767673378995, 0.017964907381082737, 0.054247271975562464, 0.049119948920223026, 0.10366096581903197, 0.0146983094295607, 0.030890829305374817, 0.10821957967334217, 0.04511538517451094, 0.011715418734257261, 0.03504515940984411, 0.020766567528968858, 0.041231120215548624, 0.08865976150357917, 0.0588653112701591, 0.03553443678444432, 0.05995291480494123, 0.026823758530700882, 0.040820834166820974, 0.05774725574038683, 0.08076949255360712, 0.04044198070562655, 0.029363585147826426, 0.01763324110558437, 0.06840441210736191, 0.02322234089426216, 0.023705769187560486, 0.044207122822802876, 0.03747421737399794, 0.11836416193193967, 0.09364394486070642, 0.007487945906412338, 0.025241685460411736, 0.030228952321434216, 0.04484162365476932, 0.03798589515950411, 0.03197498544449768, 0.026312207149702217, 0.07204802586667, 0.016303666784698446, 0.01960354072282151, 0.035208481694421465, 0.014399266050707911, 0.022213125391112223, 0.03697462845593691, 0.09833027323287341, 0.09458396538731553, 0.12322654496998557, 0.13138224040308308, 0.14915837605874385, 0.13280768488203326, 0.10660285070057839, 0.21947766323724102, 0.15266685956908813, 0.1533940608703321, 0.24742709412690134, 0.11409160530855579, 0.1036384198514204, 0.2295974855341258, 0.11184655400293489, 0.23908572962447522, 0.19644544429836736, 0.08793999891607993, 0.181872061784229, 0.11853332180650004, 0.12689385382879165, 0.2960322779272833, 0.1359812347518821, 0.16345426620494935, 0.12138389666835148, 0.13412269012581918, 0.24025228235029408, 0.11673630936251533, 0.16907074789126075, 0.09410755828984323, 0.09787280382888933, 0.19236263999294853, 0.1562246178547221, 0.10121912950830114, 0.10511500069931631, 0.16693333193900126, 0.10368038614791247, 0.1342925931056661, 0.1597261606084724, 0.16602590079269103, 0.19152882989616166, 0.09631763768172073, 0.1251924721403949, 0.17333482392132285, 0.19715763027629546, 0.20338279946196466, 0.12395901695614862, 0.11065042262235958, 0.09575267848108085, 0.13160742428754607, 0.1140039265456219, 0.09882286010730652, 0.13567879856113466, 0.08218571333394897, 0.15399111915499936, 0.17408819478606025, 0.12011579898816925, 0.1180422134817608, 0.1459090447714252, 0.14265071961187548, 0.23171556542717645, 0.15697542998579242, 0.11244105355393504, 0.16090195235465804, 0.10197557238561493, 0.0888288447693471, 0.22968085122204598, 0.08641594359951635, 0.14696068430860199, 0.17236910880573336, 0.14398875345866527, 0.1455144635251453, 0.12451063090514754, 0.08112581536894845, 0.10551417081226265, 0.10791099179656276, 0.15996881129760898, 0.1934435594105913, 0.20924482764976643, 0.3272826591086003, 0.14915027084850496, 0.20363985260407771, 0.1323942119075406, 0.11323489684371218, 0.1438432886836029, 0.15194736511236237, 0.19956273267105704, 0.1496719307596645, 0.12121460655884397, 0.13398752157245913, 0.1600313853592642, 0.27247516618620965, 0.19247726206817936, 0.1684361053330283, 0.12431232904594754, 0.10960312680371347, 0.08490976111422624, 0.10612864993632802, 0.09839233401561938, 0.08630704420107989, 0.18311059613141323, 0.10150609838385737, 0.17151659084183557, 0.110259227484705, 0.16195210568126173, 0.237832271884526, 0.11048252679287426, 0.14766830440250137, 0.2101564722796602, 0.1857509028406874, 0.16174840290219555, 0.1647157065810696, 0.20062146618241267, 0.15598444929046018, 0.14268128652005427, 0.13214874201484267, 0.21001413314332887, 0.1929883959312593, 0.13824048932761918, 0.19950991856955713, 0.1266218619721551, 0.18575344625259602, 0.09817151683232478, 0.10819952349148451, 0.14359150622640887, 0.0948683678683254, 0.1595097867351386, 0.1310901463993134, 0.10018333266939848, 0.1885688653396022, 0.12676443859574296, 0.08414346634620622, 0.15138772256191702, 0.122961777322475, 0.15958713097197397, 0.19135881966400534, 0.07079089856556348, 0.12468244910480515, 0.2732347883284092, 0.1870716843874224, 0.08841857404237793, 0.16969956818126863, 0.1011443823095291, 0.12605838898208835, 0.18660147494125753, 0.1668423513371137, 0.21310137554762826, 0.154701114121464, 0.11405595923743903, 0.13212863986770954, 0.12127824548271396, 0.21214344388534948, 0.12775254646135917, 0.27816980416255616, 0.15754167621414508, 0.20489095079322017, 0.18381256249643144, 0.12820370330084718, 0.15003994407673038, 0.13173407394318812, 0.30918156427721827, 0.190039447719051, 0.120442665722822, 0.12466875145271902, 0.19808406040312784, 0.1271159120745236, 0.0827066531224597, 0.1147866462387385, 0.0815122607614725, 0.19878120041422306, 0.21672656489235742, 0.10272879003276748, 0.07807463272324494, 0.08148900999297058, 0.10142984199187449, 0.15140011786453186], [0.0519868720983786, 0.09764198153730362, 0.099606238636038, 0.04257313388910505, 0.021639342772804444, 0.03423654977532645, 0.009461277795414771, 0.030468391186948267, 0.04272262445620952, 0.05527404812915672, 0.045362578765038526, 0.024960762933797898, 0.0252766861024523, 0.07782802902041905, 0.01231075332109486, 0.037603919890018246, 0.09423362571866283, 0.0681127547737091, 0.029666523126164274, 0.04528087548791401, 0.007992351123492324, 0.06793474658362328, 0.06736087011954478, 0.022879765526722037, 0.061842493652816743, 0.04318120851812344, 0.054213736476677085, 0.03687051327658757, 0.07270323788566936, 0.09951368755390567, 0.09333577067140611, 0.05484314665438668, 0.03080600038951924, 0.04701601484069421, 0.008880173291770682, 0.03206891931533333, 0.04617928211847621, 0.07930035041945596, 0.030156325270992615, 0.08338534573633825, 0.016365777363159483, 0.03074345697138098, 0.0537395510341852, 0.01719613814906728, 0.0068963369009115046, 0.03130894668790842, 0.01951163315454558, 0.012763200061125381, 0.027486568226689295, 0.0037838059342316086, 0.023577690777939656, 0.01398088149501071, 0.07918522272619509, 0.020721261089126912, 0.03655674664544002, 0.03206329239952949, 0.032585335354651176, 0.040523243482194604, 0.026438328204676512, 0.020786650523903872, 0.08095868562738742, 0.024440098936939915, 0.07193464485387649, 0.1420372210803532, 0.03264552305242227, 0.030378611427882028, 0.06219635732592114, 0.07490076875734715, 0.0674323384620009, 0.03523935120733034, 0.02748718301224853, 0.04311865360866632, 0.0234409459986754, 0.027609839434585268, 0.06691927405735178, 0.053532607703199314, 0.060259066522121436, 0.025754952878360788, 0.021902333096330686, 0.030747092058581692, 0.029395825958119768, 0.002028023624124246, 0.05158511260824819, 0.034878144581471725, 0.031057491733302033, 0.0248311331961304, 0.06850974153607123, 0.0018380170607293447, 0.011533559994742034, 0.06557790006721212, 0.0793962493058174, 0.026194336861672423, 0.008969547981846957, 0.01172737066348594, 0.05261591455388454, 0.06589690673976176, 0.054432354987629, 0.04912774386485258, 0.08697401566971695, 0.06331669196726815, 0.058618837802280346, 0.03975386904071897, 0.06815361024271097, 0.053115802246236035, 0.08017787349320228, 0.04152968000139921, 0.027194772997210105, 0.05601205893101231, 0.03977372987015594, 0.009023743914440274, 0.04609107858531418, 0.033767772913579984, 0.022984826824657863, 0.037965996025670926, 0.010035746062414782, 0.05516039132471046, 0.0432796010206784, 0.06502027998888685, 0.08049031479224082, 0.013963716337457301, 0.046090251210355954, 0.04781651160409374, 0.04230290403469436, 0.03932327017067902, 0.06899832177066034, 0.057693618094368335, 0.023504818579362288, 0.000981342650887992, 0.007393155932321304, 0.061900049838567936, 0.03339150499913, 0.010049074077077452, 0.01351467581586011, 0.046813955320225614, 0.007293535773867682, 0.030474941238700867, 0.003622441961910696, 0.019801147357230226, 0.03115387325505576, 0.01756771569020085, 0.08221279454207228, 0.114810326016478, 0.062182839704497214, 0.02015653171486432, 0.04449437132045146, 0.053443381442658366, 0.03815466049878347, 0.041625716783587015, 0.12734287328297092, 0.05397629901586522, 0.03363865645482175, 0.0271343152534457, 0.01944689680972407, 0.062446515676715685, 0.06905748674105253, 0.04837369118186255, 0.023850004391504392, 0.03338114749039373, 0.024806819480633544, 0.037464273552740776, 0.05576999046869817, 0.01976419893664218, 0.036999495669959054, 0.016526979499406392, 0.041153626591568036, 0.019340333979456656, 0.03042698604986072, 0.03415452091083412, 0.01542489211480584, 0.027937328615676493, 0.035101911203274806, 0.04128317205956386, 0.032389691820548426, 0.05275230501748381, 0.04433436619658624, 0.026167667425808408, 0.09875099339912977, 0.015297781848799319, 0.06023870773553368, 0.07044304102178543, 0.05464549596992232, 0.06447912314005437, 0.017691875560088985, 0.01683583933739893, 0.08429903582098984, 0.027229348460452694, 0.08716840281962387, 0.02119223087755663, 0.08477250880171215, 0.0369692390273896, 0.03826547894747027, 0.010072962613776326, 0.03254522299093585, 0.06760097739677276, 0.04262477970652042, 0.025165835095028725, 0.038766098253789454, 0.02069626555537745, 0.0167430182092733, 0.0401585320040824, 0.014848636947722446, 0.008917207897250212, 0.04369730280051309, 0.017197404109362154, 0.009323180870964162, 0.0608189044249875, 0.06439113028107152, 0.06854656738259139, 0.02659373871621586, 0.0031258757395159096, 0.022704392679095752, 0.05685899594438173, 0.027152906292148178, 0.04561714212139768, 0.045091058052475416, 0.05733389001820357, 0.030079413873834476, 0.013182963575086287, 0.04537906114672942, 0.08454792246583008, 0.007974691360422802, 0.026946872690572377, 0.03283286219342582, 0.02680435735401848, 0.051384443537362164, 0.02505609874553498, 0.09467567377273114, 0.05326055072908921, 0.032185640471476706, 0.03785950980419594, 0.09009338014068143, 0.017275859173687718, 0.0158188930494831, 0.013483368675224485, 0.004303566904948844, 0.05962459633367197, 0.034866986510854577, 0.03085480976639496, 0.04529969060733434, 0.06962916453278835, 0.029968266007340247, 0.03540923886541878, 0.08588106101078373, 0.017816709587350488, 0.031734962436941364, 0.1311350851169517, 0.01135242616592516, 0.05741026898425433, 0.026223599505160126, 0.030852314234981616, 0.028321904753665292, 0.028847946687751723, 0.06719551004108883, 0.07840608066368489, 0.0613160725052078, 0.05822569680129809, 0.0716763889537223, 0.019812979585220738, 0.011769626158169441, 0.02332469024094603, 0.028518538456410173, 0.025991459542344657, 0.019342632243229498, 0.03518127408179064, 0.029863649040400505, 0.03559678868060151, 0.10491954102631539, 0.02811508016630767, 0.06093718073961716, 0.027686664646851922, 0.01744510714835938, 0.03871986484755913, 0.07779847334830031, 0.023910496609225392, 0.06751573479343807, 0.07460816147466821, 0.035680656156112114, 0.0596251938822529, 0.030636447894897674, 0.05462557768389102, 0.007300300330239078, 0.019141375199861584, 0.06577614063937819, 0.03456388382361301, 0.056677034740606626, 0.03276966760055192, 0.04552041202963841, 0.009500804101868023, 0.010827039237013988, 0.04288245721029178, 0.0359997087939372, 0.06112337840961353, 0.006587818929655177, 0.10106938230174203, 0.014738098121128015, 0.07734034510870134, 0.031612509027904565, 0.04589198765555217, 0.00791609377389954, 0.056765165495415854, 0.0669263297271344, 0.03271250595008174, 0.06752092120868546, 0.024859922780324856, 0.01703282544058898, 0.009781709391503565, 0.07885369817696272, 0.030325536856487877, 0.037467226821688876, 0.01766099455586124, 0.013028223390480684, 0.014975012726931563, 0.027973826959609028, 0.039658939255581754, 0.028768227578351097, 0.014174708443123006, 0.002555853415903966, 0.03725917266321279, 0.04324594294772514, 0.03128756517394176, 0.015977879276409025, 0.0459156176375766, 0.07706849880877041, 0.05125051221599983, 0.13083651000934263, 0.03771009201544427, 0.047734835140046575, 0.04391385670450907, 0.06167135344097211, 0.06619634752672526, 0.0048593306564725935, 0.07426431057073417, 0.03569067275572208, 0.045955595935905175, 0.020242134379523418, 0.059743435722925974, 0.07120350586070169, 0.047863338728465384, 0.019549803485372858, 0.041467986940856905, 0.02784965942884165, 0.007938724968792691, 0.03693361210847094, 0.04203126457850299, 0.014747018257396357, 0.07791468888641366, 0.013868516506326777, 0.035614830051218314, 0.03859550579481068, 0.05329497872040637, 0.04611229922081675, 0.006162717698081847, 0.15561620614701704, 0.23420168928080992, 0.18564061682310798, 0.08774143658698567, 0.15871673251592344, 0.15191744171803997, 0.1175368482607507, 0.10725970214773571, 0.22136709652841094, 0.14457605178317717, 0.1653719834622837, 0.15555315711084874, 0.15989589504897594, 0.1494481564769822, 0.13339893622023444, 0.14586399880147752, 0.2148549354845478, 0.14873964772109063, 0.1385607294017269, 0.15034880008428328, 0.10682231956912626, 0.1971334065761297, 0.15265250308138711, 0.16656927163562468, 0.22618925228955286, 0.09648345741293124, 0.1590991176424488, 0.1702864681400599, 0.10819766955870776, 0.203311629893799, 0.19257717525526402, 0.14872547509449144, 0.10639901002568584, 0.1177861945583455, 0.06747150087669011, 0.10019431070935342, 0.14253919253185873, 0.16996400641097179, 0.14140129149440797, 0.2934586208674216, 0.07685463004294904, 0.09790062048141995, 0.1538542652082059, 0.21153760623307, 0.08017452568897317, 0.11137404629299719, 0.10552467387770453, 0.10466065693406329, 0.23659018288937309, 0.08002708440706616, 0.20654925535763466, 0.1282806338502034, 0.14636996923194778, 0.08332533040835012, 0.182648231425593, 0.15773261596839275, 0.18304224576680891, 0.13282588713111418, 0.08678462341307633, 0.1702374997999399, 0.10508612684545018, 0.09828494381039374, 0.22238205577577316, 0.2590708338445233, 0.1713151097177498, 0.13868665893472013, 0.15411874940318449, 0.19414005590783012, 0.12470211458182144, 0.2634830712791412, 0.0916244681443899, 0.10921843575253602, 0.10431175751070823, 0.1712110749776325, 0.17278719362953018, 0.11215552492367645, 0.10087972191432792, 0.18409508040114758, 0.22312600375904193, 0.17838007980777373, 0.1878547947853804, 0.17406934902312296, 0.14659250245219277, 0.11346001944114124, 0.14060644462945002, 0.16515643696390814, 0.1776043544974058, 0.09362528295887095, 0.12519120043444057, 0.13330590250270982, 0.2896889779836901, 0.17280012519369203, 0.17373323560722415, 0.0989313151747469, 0.19621927982136128, 0.17323118754692618, 0.19590306936973528, 0.08695483282809296, 0.14655894780110928, 0.17150117715279903, 0.12875287342936764, 0.15332373399888316, 0.25884621686512427, 0.15048704831109894, 0.18368298638491862, 0.0783015096620206, 0.16110530273327905, 0.16942337816280706, 0.12819339175738637, 0.11216542277965816, 0.16809309712581097, 0.18926692465620656, 0.10746342024856037, 0.13481471266958023, 0.15838163033608468, 0.18355223049800243, 0.11227901829707046, 0.19220717010959504, 0.29742098082938506, 0.2098121310794546, 0.11683027004642833, 0.10204286554888373, 0.12886081521789874, 0.14516783938292535, 0.1365553103988209, 0.1461745861677393, 0.1216925917974403, 0.05553116255830373, 0.14542359017556714, 0.15167364189701696, 0.130976137194422, 0.08920140864868319, 0.08182440328622058, 0.16194246829517428, 0.10277736766804611, 0.115118837284465, 0.13152762856935302, 0.11493202674412921, 0.13404730707406998, 0.09804096012826889, 0.14190960615392656, 0.2827230630622756, 0.1011781897696276, 0.11426323198623235, 0.099543955687794, 0.14655795188680773, 0.17320918550174083, 0.17106994626022157, 0.27294321526442805, 0.14099057643644272, 0.12035810493773992, 0.11425917172023367, 0.1458055769363719, 0.0926588936859081, 0.13801673036669532, 0.15348485761111783, 0.15824476106753274, 0.15469625712402407, 0.15617324399851984, 0.15354177794389187, 0.21404283631953502, 0.1053507412753759, 0.1454553675026663, 0.10027675709176449, 0.10632666834299603, 0.10398508229803655, 0.10311842235105653, 0.12361803122105137, 0.11866583969564208, 0.1811398502679602, 0.12030650891603963, 0.15411291181320144, 0.12417519930750133, 0.1393834005800947, 0.08918142141473871, 0.147790051095428], [0.05304311965441993, 0.024929738288084348, 0.07280587834576446, 0.01025286304103511, 0.06218098960216008, 0.018525174293186397, 0.02251920241471981, 0.03817529507702397, 0.03553747432306409, 0.05579452060403363, 0.0438115073578252, 0.0625262156339182, 0.0723500790134553, 0.04255563261047487, 0.03698278346189088, 0.04261861269872996, 0.043900921309907595, 0.019116982960352497, 0.055273795320141705, 0.05822711406395801, 0.022826574126919432, 0.03071195926637419, 0.03880784621522312, 0.01314311934214446, 0.08124262079476349, 0.017369703029192263, 0.013388324934508533, 0.020105257450092225, 0.05923821222818187, 0.020301919881134264, 0.1258958021419183, 0.0361737601398941, 0.018214709500992493, 0.05370276732250087, 0.09183856673658856, 0.027029734675682364, 0.09185521382718317, 0.03799620670296493, 0.01665395857285588, 0.03735833125369203, 0.030820948680141763, 0.04756768241584782, 0.04530211527561469, 0.0493628102835388, 0.07589164220037, 0.038262947026880524, 0.0754852861826939, 0.03235356694447898, 0.021540364212987405, 0.03198726391870409, 0.02904632515574415, 0.040274058063063896, 0.0358465256830377, 0.03365564062410305, 0.02041776386660434, 0.02518821635373658, 0.0421114280188997, 0.02472290220940786, 0.053197743010617075, 0.05346764344722033, 0.05813719066340597, 0.03367110027841503, 0.051388794916772076, 0.07224325571329364, 0.04314737807538721, 0.04331584464037611, 0.034517558486831766, 0.03469137617597177, 0.05122923412390294, 0.002366206435028524, 0.02211317964529078, 0.023204831954752727, 0.02320253943663932, 0.02600741140814799, 0.040635689867720495, 0.0550838514801956, 0.05065793171525002, 0.03481709503478581, 0.0363317389611996, 0.05337930967911117, 0.058899268117402835, 0.07185475720513253, 0.02293271369360868, 0.10898353787319315, 0.0280326510208749, 0.051382470860957145, 0.004206343644088315, 0.07141780363576067, 0.014250157569955676, 0.053837242566289446, 0.0391758825149267, 0.007023380134224652, 0.0909786636851007, 0.04822929509945455, 0.01173011421586477, 0.031571546306593284, 0.03233937516568169, 0.06002529862246687, 0.011604850221755765, 0.032989285856245026, 0.052443946967081684, 0.030596733896902976, 0.027461385001398386, 0.03673195095372297, 0.07099853903656045, 0.03811587729761678, 0.046418619477340294, 0.051739057976632356, 0.011288844698649502, 0.010521352918247783, 0.0570835478063072, 0.03872319733002975, 0.019602971902537732, 0.02147182424162184, 0.046788161139815085, 0.04942683225137092, 0.042583843798286496, 0.02302095553116693, 0.0297725688470828, 0.05337043072006876, 0.028914351189028353, 0.058340502737630764, 0.09059238683192, 0.022861025100874326, 0.03755073806631469, 0.04913346654164696, 0.022991361554651972, 0.010322337639668297, 0.03719944844863588, 0.0361750126936503, 0.015837966723577873, 0.027593447068225474, 0.03361198127329831, 0.025476583339754614, 0.010451002106551203, 0.05377258091504055, 0.06288103308648833, 0.02254252404635472, 0.057986631403647126, 0.03185793104010724, 0.004361307909411769, 0.03734917650299688, 0.03514032668223785, 0.032030335297026945, 0.031028805570977352, 0.028676005914026213, 0.029508618998431393, 0.03967277480349426, 0.06882533145647857, 0.017605535535802765, 0.07105261718313541, 0.13961213911252637, 0.015732646870967603, 0.05110074968768224, 0.023552610974518523, 0.028698986636534817, 0.05922665579184409, 0.03458262999512015, 0.05805612323925861, 0.09234699630929578, 0.03396046317873463, 0.06843451936278613, 0.06753727718586884, 0.019239763871976928, 0.03217021529112132, 0.04290367784579435, 0.03759404884711389, 0.06438929933093249, 0.0190265309591327, 0.052303262580666816, 0.0641487630444669, 0.03519047862820087, 0.039770221187462734, 0.04604656887691348, 0.08842781306274476, 0.019990074215456843, 0.03327423609012077, 0.09860773495728932, 0.044781796018322634, 0.05371102575032462, 0.06546084949326131, 0.04967956082715143, 0.0362019828190246, 0.03452391318616367, 0.043372121459293755, 0.022149055542784835, 0.0344263595498858, 0.02119088639324952, 0.03913822163256907, 0.011839109375291776, 0.05275449602894726, 0.037685546558350325, 0.01129053583774235, 0.07221520923438572, 0.012503886002025778, 0.11004488374437056, 0.03353433826217248, 0.03863265722869866, 0.01078037969437578, 0.0167494801609146, 0.04413376224317378, 0.009191689539640661, 0.01858505172534816, 0.05037056830441279, 0.0283161073832983, 0.09648221635049391, 0.09076925355099863, 0.022239111093503815, 0.03082142748509444, 0.09886907819177836, 0.02495733085989712, 0.032632120344186985, 0.07871318232989119, 0.04369654054302843, 0.02781107924097488, 0.00566054945774076, 0.0807899087967892, 0.02321942209927065, 0.05403303548753743, 0.024651646456350724, 0.038696974140381625, 0.016408015620864688, 0.05278423173172821, 0.03371291335732226, 0.005736436212300173, 0.05987270156882944, 0.05812312145867656, 0.02937613558324595, 0.094077987295966, 0.04774136987004069, 0.028750787586754853, 0.08675123730133619, 0.025658360682427887, 0.028399865691279693, 0.03809504736695559, 0.05476822708583167, 0.01654786880188171, 0.016765646531336734, 0.025924093600723053, 0.008191847122244297, 0.031203238045676585, 0.06494270592567421, 0.05468922809907987, 0.03903224869000335, 0.0784882665762017, 0.046008984603348284, 0.10479848381252059, 0.0412585691458756, 0.044839405830228524, 0.014250368244134852, 0.03498844592080962, 0.05023939489957787, 0.0822920463378391, 0.10610590478585613, 0.05493391658209505, 0.020612614499705455, 0.01969010099738596, 0.05457937875161729, 0.016350323454506935, 0.04997779119519457, 0.029771624643716122, 0.020739296714084286, 0.052860174027662125, 0.04441398188411709, 0.07281327109423376, 0.021494192093791022, 0.04090842482964358, 0.025576887231680657, 0.09447601593790517, 0.06543321670183251, 0.02839130465872586, 0.018887547287909735, 0.02117668886879279, 0.04641154848579918, 0.036764494368746396, 0.05510947329082316, 0.09659594210285334, 0.014232004158979943, 0.03705440885237148, 0.02494976191120523, 0.029898481143097726, 0.04158830104936515, 0.012221075068678589, 0.03598093963979233, 0.007645617334938218, 0.046170357194158344, 0.019913478829567472, 0.030564278581990834, 0.006160916433849883, 0.03344286353357377, 0.03511096253210018, 0.08785586714023545, 0.06968312776617466, 0.01708745517046942, 0.026396624293298494, 0.047588014389358224, 0.09845006640159315, 0.10419732695745845, 0.03444411746797062, 0.007823320526269176, 0.055084437537457676, 0.027695294627318942, 0.04196933020026453, 0.02334793526378851, 0.06323604206103953, 0.06300616205760068, 0.03275427306371351, 0.08326326962560417, 0.04999227025696347, 0.07105368204535016, 0.07287909336868795, 0.0626498852075348, 0.0413061240537753, 0.025733605838350715, 0.03670560902044658, 0.05456500311171817, 0.05539442735513853, 0.022723885786329067, 0.02381872885199564, 0.03388679999437544, 0.045486225356017394, 0.03524336550805358, 0.033931493563877965, 0.04094157728456682, 0.055233705939064105, 0.02170830600774817, 0.010539692105545152, 0.06711930727526065, 0.016501068490587415, 0.039487098073286396, 0.014296558557919437, 0.041131521124512925, 0.05491721586534574, 0.07567201245335803, 0.07235016328312698, 0.02113213894077607, 0.06945926921382066, 0.033405466951550014, 0.017030684224840616, 0.07687513821668203, 0.001408375321789795, 0.06998770134223085, 0.009199531407155579, 0.06640598748720462, 0.08107181383116592, 0.057666065742171584, 0.030195684953322335, 0.02397402636556616, 0.045883924580149116, 0.010447525982594779, 0.03708403730284303, 0.030436692383861354, 0.12483747465716255, 0.18108190337736763, 0.16008864277072493, 0.12069470864991028, 0.20522133387144537, 0.15112705348480135, 0.11931083210173155, 0.13948875299144176, 0.10835622677639609, 0.14333410068385063, 0.15960642106590733, 0.15935854565712715, 0.1382908213042444, 0.15902508290544634, 0.1088560301990759, 0.12612593495437216, 0.15916372949798263, 0.08505009310019594, 0.1028240760487895, 0.19860492358284615, 0.16042472554310677, 0.11998838324460293, 0.12178980835503149, 0.07602164732112039, 0.2026290302315066, 0.21630844942504363, 0.17282473193781991, 0.21906069690181365, 0.13388808335988753, 0.24767901447992174, 0.18873185820637212, 0.07195886855404224, 0.12078252530867055, 0.1300784966517841, 0.2703130209157544, 0.19314774221950964, 0.2417146216236776, 0.17261441015908796, 0.1084483488492908, 0.10806997802348868, 0.13250777678143594, 0.08540663808103531, 0.1661816924329727, 0.12691716588432753, 0.18050477870049017, 0.1195452090412859, 0.1576958131045103, 0.10050147366259368, 0.14593760452924237, 0.0789136139135207, 0.20176341216410362, 0.1349174757037432, 0.17821192350839415, 0.13134306266663537, 0.0985838023705348, 0.12846578964062277, 0.08825086207399446, 0.12842826665409152, 0.13943515748025911, 0.11079692927699898, 0.2444070682770783, 0.13306548879031213, 0.13871322686393417, 0.11553531332362084, 0.11597783635220221, 0.20884266213303615, 0.15909508801996708, 0.23573332886782386, 0.10618071327166212, 0.17882929844481332, 0.1681118203146804, 0.16741072728989587, 0.14672166487622648, 0.11756787482168406, 0.11332827530080274, 0.21334154411189019, 0.2131432958788449, 0.20696907154014035, 0.16586093141907648, 0.18592797640350558, 0.12606110859421954, 0.19019404426217082, 0.07422946889193789, 0.24379905493509388, 0.12907793985739832, 0.09537976986217885, 0.1699813506415775, 0.12074846503955704, 0.16259396478774088, 0.3131544043219859, 0.062204022035603566, 0.0980277527724543, 0.22669402762286125, 0.15127792684060914, 0.06899322728596388, 0.14710835541688627, 0.13751166391997569, 0.18197093309173662, 0.12406255373911512, 0.15510971477675825, 0.1779264485042903, 0.1308216479036116, 0.11850532895374684, 0.10225725525449361, 0.1627625654181165, 0.15405936226729425, 0.14434792612108494, 0.22713708691298964, 0.13489513657987118, 0.0908831631644599, 0.08443651029900198, 0.10850831055112424, 0.14407662374358024, 0.1027368645994894, 0.12507400430378415, 0.14442614369815396, 0.1988476202372582, 0.18157846624812773, 0.15224595554172993, 0.21504129403300826, 0.13824464152416877, 0.14298776765504193, 0.11868172069831241, 0.11654980525734926, 0.13925178667470334, 0.20643025125947692, 0.1788477305202715, 0.13214792996164293, 0.12320602913537335, 0.19716521454674585, 0.08393800156491418, 0.11989678977237594, 0.0710342004294357, 0.1997154599596416, 0.12421296744216835, 0.13883653637622634, 0.14301563793372724, 0.16095404633350913, 0.18443387512478138, 0.155606139751692, 0.08111220198653399, 0.08677377560806852, 0.09140798701874672, 0.21900690220777067, 0.08318401782983735, 0.1530076920866005, 0.19583378437786333, 0.14797898369931406, 0.13059232714435748, 0.12579792674871224, 0.08980475651520876, 0.20704030239533996, 0.08512674785789945, 0.13600915099584288, 0.10645085885640114, 0.14114129657466568, 0.24562292642170386, 0.13226920168005651, 0.1798851974308491, 0.18978345177827344, 0.20380888224369098, 0.14583891708283656, 0.08454386986071065, 0.20238722223908673, 0.19268379937256538, 0.1470842849343054, 0.10787896932132783, 0.1572788927343584, 0.12358445358733017, 0.13963869171998194, 0.10010424941297501, 0.07474811807755502, 0.11858912365090464, 0.10847163792218893, 0.2142332551339942, 0.11862575031456449], [0.058618064053476825, 0.04058913470456197, 0.04074890617161028, 0.03251899214040849, 0.03187081089333421, 0.048745282129534794, 0.0480190116251188, 0.049609609338785374, 0.04120624917108686, 0.016270730749613816, 0.04236016910703432, 0.03669484548511044, 0.06286007292088001, 0.02636204116917666, 0.027208422768800974, 0.024817167413270762, 0.04114462888889736, 0.036874125381150556, 0.07427068442226419, 0.04962325719515643, 0.07001934077350364, 0.06448027993282003, 0.05639155207562351, 0.01371679853858246, 0.027822290937746727, 0.020384324128709493, 0.00784413944441645, 0.036178739711401925, 0.03159847621235155, 0.050680109960657936, 0.016991320712071274, 0.031675824279626535, 0.049868186995867765, 0.017261437568513137, 0.05070164086176984, 0.039854280184954405, 0.041340873802020665, 0.03211851584755125, 0.03178784931679407, 0.07766164238414458, 0.047084074091887286, 0.009001433518865417, 0.036584076832138726, 0.05980345105091411, 0.054673933153671604, 0.07378586567938328, 0.015431713170161652, 0.08622862744115053, 0.06696894719836212, 0.05345729742980292, 0.03059264681782694, 0.024892016118692777, 0.02477714123444692, 0.043023520810229164, 0.04151542693556797, 0.06308529510973923, 0.11495242766555279, 0.09862851892267505, 0.04810510458604944, 0.028604160273267377, 0.05050253077980973, 0.10247554434763809, 0.02751483112543581, 0.06914776254204974, 0.03427951581655972, 0.04631749204089565, 0.028711910539817427, 0.04952894794123788, 0.016521067215850758, 0.018203409704109354, 0.014265238968355042, 0.0875519447389149, 0.03716791243923288, 0.0659196442293544, 0.026268189652792873, 0.06341303135418604, 0.017092214491699013, 0.06121521319953665, 0.052048423432654915, 0.05612306890168017, 0.05234473858088736, 0.02476599465514864, 0.009865241703547297, 0.07401956846156428, 0.02689129684210545, 0.04169564528931533, 0.0827572149254622, 0.044454523257070014, 0.052401950027072625, 0.009990463562820469, 0.05588192357531479, 0.024128358608352083, 0.041694408057317625, 0.14438327341791124, 0.026728711917155215, 0.06646052528653415, 0.06547505276337748, 0.08009871362798637, 0.09842147600025901, 0.04131850020419206, 0.021821932168677453, 0.057034483705196655, 0.022808659160810135, 0.013978884878358053, 0.037278470418025414, 0.01437789315523039, 0.029300739124958074, 0.07272104942990888, 0.037254790640285904, 0.032334200241753173, 0.05978543266293503, 0.07578553136197791, 0.025085416930397193, 0.05546474656570823, 0.06289005760223636, 0.06445468493526982, 0.1009536340772625, 0.06969880958598468, 0.02248304497991358, 0.06183041244625084, 0.022934529321989226, 0.1049614766792905, 0.027559490220981742, 0.01145590453468744, 0.020765360940488118, 0.05174905925448384, 0.045970477193834326, 0.024706980987121503, 0.026646997148711837, 0.0478749564518371, 0.051523549782653014, 0.07094143484268459, 0.04463024467470185, 0.04266266658481571, 0.03272156877022597, 0.07980492656990405, 0.016009886429885465, 0.01923057273210537, 0.006458118328854683, 0.06325487250221834, 0.02023058177362527, 0.015173829780260642, 0.011916399985972432, 0.049806704609504635, 0.015982455694146695, 0.020704418646111604, 0.03920962102711201, 0.018448343335260308, 0.027418152744611426, 0.039772113424635706, 0.039531753338392706, 0.017126512248069048, 0.018965083046726162, 0.038134627299563545, 0.012791921655016561, 0.04934265451025098, 0.03492723932609924, 0.03684581077146915, 0.05141170477614768, 0.02760564318798002, 0.04267464819995146, 0.03864192689258245, 0.030378274349195343, 0.052305641283671704, 0.011312806013701184, 0.00979627846860357, 0.043438257829796885, 0.044317382027304945, 0.028584270715533246, 0.01963768334638688, 0.041299723389167944, 0.0714227142593553, 0.0629134232839269, 0.05408566955837512, 0.057349468416143815, 0.01440990413914645, 0.04077351674617779, 0.0417863960648256, 0.05404610494752565, 0.039391206847804214, 0.06952706033424025, 0.04325657624811415, 0.10910626515866288, 0.05240638184571459, 0.06192193314012501, 0.009387681643748957, 0.017595955606309638, 0.002968341249206494, 0.05236786677532139, 0.06974040816027312, 0.03823601520590244, 0.03348223279200254, 0.017480036927266948, 0.02270054500249605, 0.034273839105040796, 0.027518745834728884, 0.0347607530983946, 0.09019956758786594, 0.04376220193901851, 0.01747479497064506, 0.01688002728887143, 0.02177645527427235, 0.02541369135161081, 0.059600453072738264, 0.039976827439761935, 0.032492113945585106, 0.025482055122753786, 0.03484385448598093, 0.04696336544809803, 0.02284808970627285, 0.01638666091997537, 0.022026148226652897, 0.018910535671297583, 0.028173074937395515, 0.033827631193543636, 0.02583301532262516, 0.027182454303387674, 0.02525470129424526, 0.045514248852287574, 0.023848809294342518, 0.04769373835334855, 0.09300837533608561, 0.03095245150278413, 0.04400276503856144, 0.05209635755407715, 0.05931194819089386, 0.014047100219965704, 0.01509234483819455, 0.02615526637753412, 0.05606104642333043, 0.009822412600530493, 0.045139651009512526, 0.06198978554757853, 0.08996253998409356, 0.027583830749555945, 0.003828121247821518, 0.04812634054331049, 0.014602036117726277, 0.030901573688512853, 0.05542058925775271, 0.003397239882859492, 0.04836949685047712, 0.057093460984047384, 0.01876243363855587, 0.014014488814638989, 0.03234150872055081, 0.020738886857044794, 0.048646571700491255, 0.017462234959126483, 0.09065710593976321, 0.050602007296777544, 0.0411312836372564, 0.027745475301579125, 0.03323881984538129, 0.017058129324727965, 0.05118901067743859, 0.150236246446448, 0.041260503517884406, 0.0376207355199562, 0.035191531999096755, 0.019497935502459447, 0.038248858669953006, 0.031081809279238506, 0.029557838232346603, 0.011085690630059089, 0.04127284902478418, 0.03060754148229476, 0.0521664890731054, 0.0196197894476955, 0.049122990289282416, 0.006010945146572927, 0.06975543114446825, 0.15267159399246016, 0.066570068198827, 0.05662178447950752, 0.01835252488813093, 0.01953191533234091, 0.020751946740933967, 0.05521891278124625, 0.01578039808889791, 0.03623845626509959, 0.05769197866621037, 0.011352049825232358, 0.018493486981418346, 0.03418955028117184, 0.04218287720915772, 0.04835890185448432, 0.1487822881749561, 0.020782647714499506, 0.0060007494739106595, 0.10493698484835126, 0.07002205272475559, 0.05072433238608703, 0.08747754994058803, 0.020712855189377745, 0.03009588667942632, 0.06338911408919, 0.06100942283087681, 0.015585474677443987, 0.07908851178663392, 0.010887315992506282, 0.06508142146612368, 0.053565017052836, 0.0509376265859652, 0.06362757044694116, 0.016438975149104675, 0.04493433178492612, 0.045281982484964595, 0.06442983304300616, 0.029717588631976998, 0.0032681547858256607, 0.005575487842678183, 0.05786348660025866, 0.038167350745249184, 0.0320545781493908, 0.006893931863634217, 0.019991968367849628, 0.005946418997125641, 0.0347177104483689, 0.011158003584451733, 0.041708186148635806, 0.05094506913014958, 0.05411498774323733, 0.1083557977671585, 0.026381191452063864, 0.043658347229563424, 0.03704607764619493, 0.04873295577483312, 0.03224678960959277, 0.06363688607610042, 0.01794033319569163, 0.02628000847424471, 0.026981490288650798, 0.11361820127574668, 0.047635841258471055, 0.07562295218268711, 0.02266448332868036, 0.03271055242587482, 0.011512931162160973, 0.009734867902983342, 0.03420254313236764, 0.009985434195597567, 0.018694648263795723, 0.03904281304247918, 0.034498272223338004, 0.030466069940537698, 0.05211732921100432, 0.026622413387221676, 0.05669294638679393, 0.012391884905105878, 0.034987224010570396, 0.03821168042298767, 0.14188109236138483, 0.10924196231269068, 0.1419917307794094, 0.1271468926701815, 0.11136670717068257, 0.219868965627205, 0.16052650798472667, 0.15315968393077775, 0.12219231861132769, 0.11933581422894232, 0.12080615146025536, 0.10311248516964336, 0.15310503121825958, 0.13209009032335975, 0.11077871936703883, 0.11444022894025811, 0.14533757382342893, 0.10294526349753143, 0.16672189167189985, 0.1326675367571654, 0.1202993996201023, 0.22108280129971045, 0.15621000089712683, 0.16131439877133216, 0.07533704816934562, 0.08803958268535715, 0.11056082097873574, 0.16708814298673985, 0.11413356394416864, 0.17726467111177985, 0.0783802941441536, 0.08730052234304529, 0.18696752707323722, 0.16161974609619187, 0.09023425604907737, 0.08760108927925749, 0.14663103667478408, 0.08632014430458508, 0.13287392084396657, 0.19597102136861896, 0.13997832914033245, 0.06106201476687866, 0.08983259615037711, 0.12081906770265873, 0.1876551675940714, 0.19202087284816852, 0.1127293017963248, 0.211251717541487, 0.14545486188463627, 0.13168144370279006, 0.15215278392837894, 0.11384772887874035, 0.17940381842274822, 0.11374664357713155, 0.15440116005559124, 0.2796171281126238, 0.20045605247780202, 0.1260227658936093, 0.18252700567245486, 0.06846504030568946, 0.16450566059399038, 0.11808519867519218, 0.09097640372572408, 0.11078336952073921, 0.08744005759757373, 0.13089995741123153, 0.17086443551365407, 0.13962755280156292, 0.08875461851036356, 0.10642137213219559, 0.07043518862056156, 0.15117988290805973, 0.11092230722668672, 0.20702623702105016, 0.12964901243967394, 0.13365088721677182, 0.13682247590153448, 0.15360563903325988, 0.10524370347059543, 0.17819948224050386, 0.19181120990505143, 0.08111616266110251, 0.13585850746641237, 0.16543173832037758, 0.10744164036887308, 0.12480789600240609, 0.20419364224278158, 0.1297089051935942, 0.1158590161151463, 0.14228172570226655, 0.1577407518221486, 0.131754451881974, 0.14872116968035698, 0.1994640911899267, 0.08923363796765767, 0.15216744685124967, 0.19398308449214507, 0.16230272880244642, 0.20426562386414698, 0.09113330619349595, 0.10436839439095029, 0.165091656569031, 0.11841591117122482, 0.07289516589333934, 0.19173323747611817, 0.13221200555562973, 0.12296835801774457, 0.20641042490399655, 0.08908716195653524, 0.13163840488320397, 0.15527675258776835, 0.27643519724088333, 0.1381772257868321, 0.21769240258201478, 0.22435986496988805, 0.15286158379768172, 0.20220771251666933, 0.13623223579939336, 0.08171895894432261, 0.15778061903772816, 0.10928273351202089, 0.14981290625949062, 0.09980021975934507, 0.1784592166903519, 0.08983950626345412, 0.15143878998294955, 0.19166638864384544, 0.1625105684563037, 0.14914455583258984, 0.09187856418711525, 0.1849022306381695, 0.18968220559820054, 0.13602560656445642, 0.16071809125283074, 0.2127511507921642, 0.1346479200067059, 0.11274387278864462, 0.17423951247286412, 0.1335050393977473, 0.08235374705926066, 0.08984902873635293, 0.15945456711755646, 0.10774946215772822, 0.08827769813398201, 0.11265636256505406, 0.10132180061191322, 0.13319609145964348, 0.1765869284469274, 0.10096458913457972, 0.08878180697079628, 0.126258100443069, 0.1121881602692508, 0.08090727346678896, 0.11308918692051403, 0.1398114445469072, 0.0906581784628572, 0.15387966868377503, 0.2292939002114919, 0.13778557099642294, 0.09508534695111936, 0.13161373685204214, 0.13446500885390467, 0.07869480388058771, 0.15378701801021255, 0.12171523735648203, 0.08855070122667859, 0.10964366817666639, 0.1604579124719866, 0.14454153186130908, 0.06252495924972239, 0.1379849070743207, 0.13323329268924652, 0.11774644991683385, 0.12879171408712864, 0.12950360895164553, 0.10076051097243063], [0.01877753706198306, 0.019344537886941147, 0.05539884768246163, 0.09752895292495528, 0.01454723497567278, 0.1234111798206164, 0.027119748091565508, 0.0725330591141697, 0.00998443253563657, 0.019740837085391247, 0.0093843960841637, 0.03190151952777899, 0.04402334216020761, 0.07936288617671498, 0.07134650383264789, 0.050632723592101574, 0.04806311913735924, 0.047041759225389654, 0.04599505329444524, 0.10692613214374551, 0.03488197885153275, 0.07858646372633596, 0.06579251193832006, 0.028858168215881434, 0.03598383928258573, 0.054861678321275024, 0.07731750802767855, 0.026202790641916857, 0.07716123375200457, 0.02165413976106192, 0.01581316271180948, 0.025851962592212424, 0.066207003809752, 0.010544167016632857, 0.06190993620323078, 0.05295193603923244, 0.12906094802723778, 0.06314570880344798, 0.060541664866069635, 0.03636787915902753, 0.05843441745626831, 0.028888382723615057, 0.01896728554950847, 0.047078971946311575, 0.04692123444270223, 0.05374073464002821, 0.050908932762761275, 0.04745126003399492, 0.0554346201580859, 0.04074925474161583, 0.06642420505804401, 0.03851607396838166, 0.029315162645352465, 0.08581497826643529, 0.02012166705343031, 0.04817270801492757, 0.028634771231501818, 0.03807822790657801, 0.012337066526074084, 0.05312507191011983, 0.005411216087879674, 0.018077895773815054, 0.051198598267810966, 0.06831310208766692, 0.030139747128311186, 0.03685002042461307, 0.03671252296396321, 0.049528289105623007, 0.06124395681845565, 0.06374415753769778, 0.06442876051991217, 0.007152046995132321, 0.13171570315476389, 0.010718691421883001, 0.018045800520227324, 0.019839896084440332, 0.031473425765251445, 0.04731287774179251, 0.07181043135783366, 0.029701429922434113, 0.04049135890278605, 0.03732896710355436, 0.051976200493593375, 0.02941394202230919, 0.04213279421110788, 0.05212480239870568, 0.0651507600841503, 0.05765466252341867, 0.04069534130394459, 0.052565004180876486, 0.04811585663006671, 0.03451475843546852, 0.025189455500954104, 0.02098718744462296, 0.05852577344123876, 0.07440473448725478, 0.048142926346871166, 0.060906655966274204, 0.07303932831893045, 0.014061110052880983, 0.02816295874635539, 0.04875590010816532, 0.05842582961063712, 0.006637522235377542, 0.026819158172715577, 0.051334015799746405, 0.022049850987030134, 0.047844171208599885, 0.04600970089555748, 0.04048763571547405, 0.06500535659612187, 0.018369612479282003, 0.020229555215806733, 0.019656737868283546, 0.02114217086214452, 0.04710687669895349, 0.09165573219257979, 0.04499626616316457, 0.004887729057020718, 0.04535527028624089, 0.027398803278863914, 0.056458741817022526, 0.06941325797308838, 0.021641307788330223, 0.044981833066671126, 0.03436947752150797, 0.05936090887013463, 0.02234851036431088, 0.020739380983755957, 0.04003386268572461, 0.009194597800923212, 0.004267501879498483, 0.0432435029576863, 0.039524211202778166, 0.050942636800989996, 0.034023991019855586, 0.00628072731835287, 0.027568882458933422, 0.05182529266382899, 0.06079538935615171, 0.05760703483716615, 0.05173512794558079, 0.07367296730198207, 0.025216082801982283, 0.01426248583987716, 0.03277909431246019, 0.023305371418715488, 0.01976717135778839, 0.019470758533345598, 0.05549087399436582, 0.02483125385497847, 0.05676552555674026, 0.057311811364225806, 0.07243847789903803, 0.030211366773132357, 0.06256245159273667, 0.1072193063314884, 0.007746267402845045, 0.019471978528365012, 0.03964711085803086, 0.04762894263671291, 0.07754139722354951, 0.050860967997822075, 0.08728725370019676, 0.049319606755049004, 0.058781715755861615, 0.034000223142004786, 0.04202942596748472, 0.016896295165943525, 0.014381377897675962, 0.039343954544634595, 0.01586903063129754, 0.040302230946479306, 0.05491047812205169, 0.016159860589992137, 0.030360527922429388, 0.0868353384336637, 0.04146251324263792, 0.09783018635766161, 0.06521045365521023, 0.03703473188403634, 0.08042889752335126, 0.0309625945069016, 0.0025691493506348065, 0.0454052766754983, 0.003302396761418711, 0.04044997866355604, 0.05391510391247369, 0.05971052075525927, 0.036637381229910164, 0.017818033004239682, 0.07700853710693699, 0.033263204424011136, 0.014728027895363349, 0.021465816197075674, 0.06833690443947431, 0.023789763067578597, 0.04027503099472773, 0.04302992147483653, 0.04681863994788259, 0.10646288643681234, 0.03441851097910154, 0.02024333905278435, 0.054737932138866, 0.024426669415627277, 0.07425828911964932, 0.03295701057199509, 0.005693196294633973, 0.06678544615785922, 0.012802412271529678, 0.025144150976331967, 0.06384754110307944, 0.05613610005727219, 0.08128396656003692, 0.046617584002594796, 0.06092550939009075, 0.02747811061600524, 0.015839885773828194, 0.03598184362354298, 0.026757139524805452, 0.07541633060862941, 0.03344617686384628, 0.015841341340884326, 0.009440216123156491, 0.08114142057996604, 0.033480060932737206, 0.04782273606847852, 0.057657945210174213, 0.05135845783497057, 0.08589331075669297, 0.04930837207563943, 0.004407201364125696, 0.026109559656751734, 0.05696833584337466, 0.006173983978618298, 0.044933446953373576, 0.048386354615250905, 0.056822526328746355, 0.06827846725261019, 0.03170285377681496, 0.03727170969209364, 0.030976091060907613, 0.030410723918448054, 0.04773213084967387, 0.05215867880671736, 0.050918577809727965, 0.05896889018796145, 0.025971123738394632, 0.031245662079703425, 0.048789416454852595, 0.06599702677058597, 0.009540758459948966, 0.06108587840572, 0.07147042621527949, 0.034750050850092404, 0.10977386481939785, 0.040394590506630565, 0.05055890719015753, 0.021002020822056842, 0.031052443213881026, 0.05339446672869306, 0.0177157889946454, 0.10202760507743205, 0.03991884607521277, 0.06418827785960128, 0.04062374272654134, 0.07578623616286824, 0.03423969456625562, 0.022043379459289775, 0.012889858335256578, 0.026713928335436413, 0.10778204387714786, 0.08057030203241496, 0.05131800456212894, 0.025391346482079358, 0.04162006305470582, 0.03750828147355107, 0.008581187369512215, 0.05347366489830518, 0.01940172443526887, 0.04213442980882622, 0.029558391730871894, 0.05685624951917318, 0.00522609860185654, 0.021012236604527123, 0.02691940652326711, 0.08936664615307124, 0.00789988957788615, 0.04001024419501905, 0.026326441063335346, 0.028678832778466806, 0.08047301652691058, 0.038333396472397356, 0.016319888696495085, 0.03239744846078177, 0.0646061098743831, 0.03027037086506044, 0.030641511736077168, 0.05225517141122011, 0.017681010518102877, 0.04689742059957597, 0.014952236932942705, 0.03659050814026306, 0.062186126221692374, 0.036053292813801, 0.11755624560699349, 0.0389379930622395, 0.03798221027658832, 0.09069383985573247, 0.05098840289358651, 0.06625316826806915, 0.0057069719919273934, 0.02063554159605936, 0.04395469685175246, 0.028486006532705603, 0.04513241147862808, 0.0416872987613803, 0.06387467210691783, 0.03332094447086415, 0.026161262930761424, 0.012903911260617597, 0.06661235625224729, 0.08473372943098507, 0.019002757335622466, 0.061886114699225274, 0.06942508637063927, 0.13716214396540197, 0.09135804574696288, 0.07196948653267277, 0.018420718204710754, 0.07716626694966709, 0.04438266420977251, 0.08107539912265155, 0.04438465220793601, 0.02403270487012642, 0.051010952691637704, 0.03091516983394902, 0.09982976010970532, 0.005813164227161436, 0.055819587000916084, 0.050776296129990975, 0.06010776032663642, 0.026121924315849622, 0.02154666720138442, 0.014524856589794641, 0.06811905967732591, 0.05230634991500167, 0.049459306718481165, 0.00909310551510463, 0.04244349266011869, 0.004699924038798218, 0.010061799755109655, 0.13208144885157386, 0.2730238383575794, 0.204815537097954, 0.18575061172727617, 0.14400124069183104, 0.22700055472312436, 0.06660664123633216, 0.20664861696141384, 0.18859682754883844, 0.13839502458370503, 0.08422501640574587, 0.37403660676171707, 0.13772292032597527, 0.16740750972061388, 0.16929144250048747, 0.09520310998683977, 0.1444474256206905, 0.1264902404058845, 0.11369286420484705, 0.154815046717563, 0.15293122118999883, 0.14585498960748797, 0.12366286268638027, 0.21102847952035167, 0.24114774720322704, 0.16995999211024854, 0.16983576329244723, 0.18983776741210492, 0.14117135786481444, 0.18567018781698522, 0.08575175303004443, 0.17068150903909438, 0.2391806172747766, 0.11859715991323033, 0.15442130816799982, 0.13602811933284806, 0.24863925972773185, 0.16567950647684837, 0.16014268261290368, 0.2343149783630525, 0.20035500548058943, 0.09475563036938829, 0.12001750990748407, 0.11819463433517564, 0.15761803985843736, 0.1028440862653717, 0.17291572786146597, 0.11164738646438045, 0.19104516794604642, 0.14794948931422927, 0.15167472974186944, 0.1526634734604628, 0.11001621673424399, 0.22133280643292014, 0.1967603677222806, 0.18052564693554757, 0.12435389697671899, 0.0904629179727166, 0.09508943019975578, 0.12549028882095892, 0.10732403821161679, 0.17808864463961896, 0.16361257061362267, 0.08820578546052979, 0.09901520946333486, 0.13308646427767892, 0.20076598100844892, 0.09568391442899743, 0.1349510150330682, 0.1279836828489938, 0.244202446192503, 0.09023266258619486, 0.18415124996775584, 0.18890473360736526, 0.16269409247944433, 0.12408221921613141, 0.15837678866040322, 0.14698679258506145, 0.1412882935255766, 0.23141404854193812, 0.12073357995118826, 0.1911004488506625, 0.11501917690639535, 0.13317035090538765, 0.12420550574578586, 0.10859559094833751, 0.22323118763104563, 0.12434370800732605, 0.2206716572325076, 0.2801160045689152, 0.128943614000755, 0.0886786149273957, 0.059061180800199516, 0.1393370062954003, 0.1112111300350197, 0.3472636111320988, 0.19761311551255567, 0.11305514963403826, 0.1026575438558094, 0.1262768542754554, 0.1391444884000286, 0.11182311171245192, 0.12515772239214953, 0.13525653089727127, 0.0962859905895687, 0.22460455345290326, 0.12522530666882956, 0.18171323643576714, 0.1680100072295435, 0.10492265134328797, 0.20414899463855452, 0.13161840998838026, 0.09131848496655304, 0.08414489893062461, 0.12066953500071842, 0.12968917076866474, 0.12464524787520209, 0.18599140848363602, 0.0814650314409406, 0.14168494320925207, 0.08471009561852103, 0.11270222058820148, 0.13769463635981083, 0.1554507924424064, 0.14627502029461248, 0.163391845360879, 0.16113700345158577, 0.09798029362554513, 0.13328011598317854, 0.17869149454899375, 0.1459255463053142, 0.10316462511376989, 0.21442185065919356, 0.1596933567235547, 0.1726349106719417, 0.09427884022795385, 0.09914343726010093, 0.1560225545038139, 0.156761339054473, 0.13727659750128948, 0.20548647690203883, 0.15239724258501686, 0.2233954062384944, 0.1318934815184724, 0.09364572984556999, 0.18735194999364116, 0.24906047019025973, 0.04825491691008211, 0.10368525846711091, 0.1775448447874477, 0.20610261077602066, 0.17142217816604724, 0.10647895896146375, 0.12238439983658253, 0.14745476505448743, 0.2611742661364617, 0.22131789836191365, 0.22579902242268288, 0.11296197802068726, 0.1563816505574411, 0.10651510298973131, 0.16898958853656249, 0.09855490553403094, 0.15395572589289758, 0.08658882666138873, 0.14477073004649532, 0.0941194020091526, 0.10628073371105617, 0.13714267001036676, 0.12008286486830443, 0.13537947268735978, 0.12116002279423899, 0.16465664120210757, 0.10442030450869953, 0.19248490762566367, 0.10111450488048215], [0.024399048115517345, 0.06771922306788546, 0.01853450141366451, 0.05024743882278281, 0.02949672739862675, 0.029086102355992603, 0.03227317750814461, 0.06222613516353792, 0.041375477993560415, 0.025958948686058005, 0.03890179157737763, 0.06365080589368459, 0.01012307721295304, 0.043463573205254735, 0.03968065018735586, 0.05225904398567734, 0.0650881707007366, 0.032525205113474405, 0.0354893678318589, 0.025248926906515996, 0.02033795091143299, 0.02227138446253394, 0.009801746421163122, 0.011674013597169712, 0.030171129920129335, 0.0437291260928877, 0.09540492818961221, 0.021451398422340714, 0.043351889077213504, 0.020588147566623746, 0.04865494504150364, 0.10801891826333539, 0.04247062749439671, 0.04079487910794635, 0.07198935119254936, 0.03337998303674883, 0.03485094079928052, 0.09662687673323578, 0.004614329513823313, 0.03316306141054919, 0.059675809311410116, 0.04193340833749502, 0.0019199885883285936, 0.021010171997571186, 0.02215650383262865, 0.06885586006026115, 0.04866980331679506, 0.027724360003166144, 0.05234628990893403, 0.03144727918439575, 0.05238570130219864, 0.0348960557171414, 0.04587547079990468, 0.02898554373983174, 0.032134565389564926, 0.06046125627753716, 0.027815790681709206, 0.0542641029272589, 0.035689182714709354, 0.026203742506162777, 0.058045838508875146, 0.07247292121211368, 0.035354023078276266, 0.06064772207830703, 0.027481921903428533, 0.00806894555177179, 0.020940894666578502, 0.036386858987351584, 0.020420571578846827, 0.047702873951845595, 0.06044614902367035, 0.05138186565149696, 0.06250655781778117, 0.05154503854892908, 0.03848684388363073, 0.030347581036509048, 0.03993908994861188, 0.03583223048237062, 0.013433954088888584, 0.05897973799296926, 0.02279587123813408, 0.06532483058230532, 0.03428231969836258, 0.023371984678951484, 0.013529788815386355, 0.028716185310434912, 0.07754222459850774, 0.05736758639555305, 0.03637847032458071, 0.018907078699539268, 0.03407084495730458, 0.04550879047582707, 0.046556986447784214, 0.027747823361067042, 0.03387999713360783, 0.027853802049292192, 0.00906479569347275, 0.014781766090421908, 0.04642549894690033, 0.08972620952033228, 0.0655276217167416, 0.08157128017515906, 0.0834357006956012, 0.04801926443413381, 0.03579990540240561, 0.060185284594133984, 0.06636179187485287, 0.009120173316689269, 0.03746775159191701, 0.0458003060832139, 0.08433959251570125, 0.020418870863654924, 0.051100029565033414, 0.0243684180050848, 0.022357940906658772, 0.017660542563985915, 0.08121344050572765, 0.08895383201419346, 0.03619701090839602, 0.040915469008107344, 0.036409887590355454, 0.05487537597336116, 0.03567858388827693, 0.0030099594544979835, 0.03851485588858205, 0.13816309912550834, 0.05015488391021087, 0.02018100630882527, 0.01452411731494771, 0.020448070304888873, 0.01890345701887723, 0.028716514728242354, 0.051815919578075416, 0.009433424753707745, 0.04580945700346943, 0.03359754051592562, 0.03437128548900928, 0.052126058782901497, 0.061276687925020536, 0.04137360490858555, 0.010705110598205319, 0.02853734591495126, 0.043609237163177425, 0.020990316913793647, 0.041906070489917076, 0.04088769449041255, 0.043222435539768594, 0.015545133444961282, 0.04934681436767982, 0.04725329142304198, 0.06853170527686035, 0.024197800648248485, 0.029891306729686838, 0.029381829531743165, 0.03585351240490714, 0.039745089673106714, 0.047584854276670564, 0.07271407802979793, 0.021001111092646758, 0.0026998688483745943, 0.08852189632072564, 0.07480333769513715, 0.07517927236134007, 0.021484066326651844, 0.003760465868606022, 0.02569929659066181, 0.05024153228488661, 0.030933845142323165, 0.024200887982583335, 0.031918819708329056, 0.04462831413313266, 0.03278139640667266, 0.05435524057717093, 0.029265093053841305, 0.013594249368555123, 0.05894874973643211, 0.07318291617857833, 0.06684454984121746, 0.01089800579187971, 0.012355056185756, 0.03929723084213273, 0.04328822334026618, 0.037284779152081865, 0.04022077281749056, 0.037628132098865126, 0.034498900415435914, 0.05916640297659944, 0.015450654694089487, 0.02192774231755926, 0.04283888979003795, 0.026414311348250317, 0.021585082680347468, 0.021414444256093235, 0.041271699892897765, 0.02438040536587998, 0.042763054746413426, 0.06017446743264314, 0.06131552092190232, 0.0268516632833428, 0.028689349250447367, 0.0162770988554844, 0.03176794635252126, 0.0650928974632294, 0.06257653611922456, 0.056368607742291306, 0.02970172295106515, 0.023243944573726867, 0.09718907801734825, 0.04110204972206585, 0.0332575430342507, 0.08144948751695695, 0.05194427377934899, 0.02407309877115392, 0.09106907738192428, 0.009272200592433014, 0.02668116850057437, 0.03417101478384387, 0.05580598510982049, 0.034353014292015184, 0.04028213262978581, 0.08117440832598556, 0.053899958354210666, 0.01893170268064545, 0.0221850406078081, 0.051192557664528016, 0.01451458526594985, 0.05632766417317814, 0.022220401311173074, 0.043987450940955075, 0.025538119352272442, 0.06395818718198328, 0.053462414897137114, 0.01883115747102326, 0.10942023863355, 0.02581723391138498, 0.009481826188763785, 0.03280912112865237, 0.03546901670615039, 0.015353712012931226, 0.020410683298964175, 0.0396709400229156, 0.018799891507613565, 0.037663437260855595, 0.055363772346848444, 0.033106596900090095, 0.009785618355137207, 0.052068793710561535, 0.09549171062967471, 0.04507875084997185, 0.03384379181830633, 0.0781796480559053, 0.027503918202954437, 0.037062786023823485, 0.05754806138875504, 0.05948503043562655, 0.05399981791514063, 0.020722829654151877, 0.06168573291131085, 0.05762190460377644, 0.057352398702454184, 0.016565588415570317, 0.04379526629383045, 0.005866050628209186, 0.016925339474372806, 0.11781150610336374, 0.023711717860292525, 0.019109936866668925, 0.060519961595174775, 0.06052432829634317, 0.07288069449244969, 0.03829729840940526, 0.06588639601344062, 0.06383493129584579, 0.015123802323585317, 0.034465288307758114, 0.014670853795964393, 0.03761600875746339, 0.03229206157547813, 0.0304368800754028, 0.036151769586027636, 0.058168588776982603, 0.06651638841797268, 0.029784010370231928, 0.0764646606459733, 0.032805696715630835, 0.06051790081865846, 0.0818674880710821, 0.016918283804590185, 0.05377185696195211, 0.060218559623125105, 0.08631066779696173, 0.013053684322644147, 0.06962424624831447, 0.038446340815074025, 0.022804828721188733, 0.04303844420299415, 0.014426771480019295, 0.04687068030057896, 0.0384017544978809, 0.07718623886185308, 0.055467374247288516, 0.17414920602834996, 0.05458050107042636, 0.021440828324205453, 0.07015591892864435, 0.0337973783814138, 0.038913298218000325, 0.0748041344265784, 0.09800355971580553, 0.022178745280290325, 0.015292658635805693, 0.0313081365499285, 0.008536264931242312, 0.03064372956061796, 0.017364650679331635, 0.03757635604650263, 0.046503180262422374, 0.014661920253157377, 0.041171713927460295, 0.008048821379610849, 0.011858139956940808, 0.010007327073253691, 0.06545347206655049, 0.09546338835911405, 0.04568813548934075, 0.039880886418564666, 0.04924112870808571, 0.03750471533426354, 0.03776027460492427, 0.05768752386493068, 0.0031176297606209354, 0.022297667023996194, 0.018329812296395822, 0.027894293626530037, 0.03666516340848419, 0.05157893410913887, 0.034219305136150895, 0.023706768932301673, 0.016851417735339175, 0.029609325086517684, 0.02255214036502425, 0.030439214728352045, 0.026975876779385635, 0.07686422146376103, 0.027286083016905095, 0.01349924297462548, 0.049462826892493233, 0.15565409685575193, 0.05656933810021128, 0.04077899810527602, 0.008358506677341799, 0.0653925527548117, 0.11298886004595027, 0.1788044005872742, 0.12846601946700004, 0.16281894948934356, 0.09614019639669888, 0.13018660697965853, 0.09627492827994209, 0.18455485572978375, 0.10159312597205562, 0.09623113103331098, 0.08897571148531092, 0.14010811975646403, 0.06394959550591246, 0.07597323056430587, 0.2109861761451729, 0.1355387270450592, 0.10176875928957617, 0.07406721913045453, 0.15884099197724175, 0.11109364279095205, 0.13258798618710813, 0.16758429217002085, 0.11134460553406708, 0.09053446292396515, 0.09432370999767896, 0.24719930554349578, 0.17681494685671023, 0.1014534145173046, 0.11210168426435803, 0.09425190457653615, 0.10287161946537034, 0.30853572151353287, 0.11922537499377805, 0.09294278288800871, 0.20872169684979225, 0.11228742228159982, 0.07125899360905733, 0.23482091815000583, 0.08082473515382699, 0.13122001362423744, 0.16644872003985992, 0.12321415732824996, 0.08043410692123637, 0.14903129739386423, 0.13473142359045245, 0.17231390450990972, 0.11320548672829905, 0.16119654380506085, 0.10707293757267537, 0.11674176390853622, 0.12586717343618795, 0.14648446873311075, 0.16207117106645338, 0.19520655755073796, 0.17142951728836184, 0.16597464951055665, 0.08515391333569443, 0.15036974492813313, 0.1323613314138305, 0.13311277173699873, 0.22010870518222933, 0.23714984076157694, 0.0724589094639786, 0.14700680280164366, 0.18515484047032174, 0.07100956304179085, 0.11643198859547416, 0.17387312326219775, 0.1306208256151407, 0.17393595779374724, 0.14234857453453925, 0.1933418842212808, 0.07144195072713398, 0.11789352347653721, 0.13577045332039558, 0.12684286301655154, 0.187395233961363, 0.35360531761280956, 0.08735705197097794, 0.12674978333375148, 0.12515765344423632, 0.09714293654166883, 0.14622995900290628, 0.10510625197522103, 0.15987576225832587, 0.13803769053230364, 0.18547687319017228, 0.16860303589172904, 0.18735738921790354, 0.09463278817072993, 0.12815344793301436, 0.0840390179186098, 0.13243570322951964, 0.15040368262317874, 0.175829803751361, 0.22261269420625704, 0.09515284695812772, 0.09707620262258476, 0.17403191796714262, 0.21454005802591003, 0.14962486231759672, 0.16116942429254133, 0.1669697824024385, 0.09807841416688697, 0.22172394028354078, 0.14101314538669202, 0.1645653541650503, 0.23675780292720566, 0.15577161474333656, 0.17982247015160902, 0.21423170763638713, 0.09956838623169931, 0.16333919979872244, 0.16512654421310272, 0.24568671090227945, 0.15831594595745688, 0.17573225011508312, 0.09581418001964208, 0.15697633396954308, 0.1130881603626955, 0.15038214023074797, 0.21334511408161735, 0.0831341838103629, 0.15871771310846652, 0.13195178080951014, 0.5264067757994898, 0.11136086191982032, 0.1559755933140555, 0.16676036460745722, 0.145800658651898, 0.10969707982674723, 0.1648707168116685, 0.17612211225974947, 0.12648177513432118, 0.07026481066620158, 0.06879806638725343, 0.13469226117576324, 0.18179995758879572, 0.14255534166530257, 0.12630272506465837, 0.11244191923328947, 0.1304389869854335, 0.11780802040330826, 0.10740303719836859, 0.11622218009565147, 0.09761270931771687, 0.11290674308134664, 0.2274415302540987, 0.12961591744134504, 0.1638632805477227, 0.15850562932750872, 0.20122546522367388, 0.14107735887650522, 0.17762408892233528, 0.1172142869402324, 0.14089579603845073, 0.11278186308880968, 0.17413746956134998, 0.16032723319386283, 0.13952287454758922, 0.18694190909304928, 0.1271469462963362, 0.15336689539253712, 0.07355557198846534, 0.20145426504313949, 0.10022235718826134, 0.1079154197847651, 0.12534849360705386, 0.15134544983025522, 0.07152936135929439, 0.1653943532296727, 0.1885982524723776, 0.1673185822343634, 0.12886414003949012, 0.10743427826392074, 0.17531275568950563], [0.07374535494994733, 0.02779389588883327, 0.07864497752199251, 0.0385440208558594, 0.049183882787943854, 0.05552187374222183, 0.07590000788050313, 0.034011825543618014, 0.05581561100458907, 0.06478802511288274, 0.008053171801410856, 0.038924824010821125, 0.01667501832989435, 0.021508217248464787, 0.03825550065225652, 0.04015731392428279, 0.028569025565840067, 0.04040404403161618, 0.031182754769801136, 0.030920587990793492, 0.012982121176807391, 0.06052277313785688, 0.010147872606232282, 0.003055061684027615, 0.02346431742602539, 0.03263419644246179, 0.06573074992986457, 0.07249361324694849, 0.061930249024543076, 0.012628153124223314, 0.04904816648171795, 0.059215643277932564, 0.08875644179962336, 0.05489544364653769, 0.04254240993290179, 0.07439674419020453, 0.049705707408007116, 0.0670826269854461, 0.041399747659001625, 0.02829409193157429, 0.026558270760541482, 0.033611690159887075, 0.037094410133337787, 0.05414459321107115, 0.011382079514254247, 0.018373441003683596, 0.03841337988213186, 0.0244350676544972, 0.049929316981785724, 0.06337064753977523, 0.07754674451726098, 0.005491421184307265, 0.04290109995992915, 0.049205877172249946, 0.02272771814117028, 0.018242162261759082, 0.027848759275530616, 0.04940569588554002, 0.07211806928558696, 0.06288844115671612, 0.04060924451257433, 0.018994993034509883, 0.060689833931504726, 0.019282720337111144, 0.04262861397658144, 0.033582854610417164, 0.04772853789730899, 0.015392496171707829, 0.0227357218447592, 0.019356157525532672, 0.029394230580017455, 0.017009614891703093, 0.003534121600340211, 0.041249084977373, 0.04371472747035084, 0.0830235607140968, 0.05158007174970643, 0.020987229579458797, 0.03553188571165647, 0.022183232640306798, 0.07522349861720878, 0.022348332248868483, 0.039437536015025074, 0.015909725221835317, 0.044787426764566096, 0.07136273723576339, 0.019224911342344938, 0.026460954611520135, 0.03041732376591573, 0.059241621319444916, 0.03896305562868234, 0.05003574574666639, 0.0628079521289516, 0.03983504371717572, 0.012844911956739043, 0.023794012940338543, 0.015509411722661988, 0.033172177856848124, 0.03987889075952192, 0.07399300819322949, 0.05077055813143811, 0.014651072448149565, 0.04116151729718812, 0.017851461250815662, 0.09648603146835681, 0.049483810040739276, 0.05499725290123494, 0.03041208180929384, 0.0643934898318783, 0.010009969118982553, 0.025234673840684757, 0.04769900520782798, 0.0319603665716826, 0.03598957728113859, 0.041133221839704824, 0.0355726071152716, 0.019375122032098232, 0.04923768897330569, 0.03956086850995499, 0.0432112506560741, 0.00684614856577208, 0.030774655902097305, 0.02253514470442409, 0.027694315949995673, 0.00893470247261106, 0.05681451304905838, 0.05432335216732276, 0.08846509856201949, 0.024058535439713348, 0.01757757524178634, 0.04988807463838209, 0.02125094960173292, 0.0042869571611405385, 0.060151258798977064, 0.014927891616318977, 0.03638584392085191, 0.054112003830772255, 0.035960419974740476, 0.008076618879943365, 0.01883697973924779, 0.056795537051173954, 0.054812300124115525, 0.0717715677174349, 0.02772691299117381, 0.009616022768069901, 0.028265771576233452, 0.09269706018629575, 0.021145239044281266, 0.042901103790368766, 0.06709257846758251, 0.028131978150697488, 0.0286355200824478, 0.019795403613017935, 0.04294400471412847, 0.01064257771377602, 0.009277507666528467, 0.005254208283018201, 0.07359231356531382, 0.037157371069394776, 0.014937845971285096, 0.03176825278769097, 0.009362974350581007, 0.03220770380369598, 0.10433529173174214, 0.014991178139743787, 0.027147377052554683, 0.045932789498399344, 0.05919505849540715, 0.002337881531040635, 0.027645506573119955, 0.040212859129232746, 0.02078008898083241, 0.016234376047167088, 0.01792954476249795, 0.010487628770211052, 0.06260878842083678, 0.055201415333055684, 0.059566162977247476, 0.11490058649571673, 0.06646165143578284, 0.021246791659523884, 0.02443768575997843, 0.03663270043269281, 0.04230457410636929, 0.031575752129297585, 0.017993721863134735, 0.03450219842394994, 0.08836760621277556, 0.016897233623650768, 0.04260147148142419, 0.025092503243696787, 0.020506013365041827, 0.04048300088353215, 0.03410579388841026, 0.028496997979199214, 0.036234254272834915, 0.022822125071299174, 0.028184010842514616, 0.012544958848476171, 0.007473369647238044, 0.01684517986441572, 0.05805489749857976, 0.022326927752264088, 0.033511060680593216, 0.029010935724082015, 0.03563306677425581, 0.013635292529098451, 0.05228707897326639, 0.05478526871170729, 0.021979958870478218, 0.033530534635628426, 0.0732817185381728, 0.012839115543981955, 0.04785280118906691, 0.07765135382332149, 0.06630301760930209, 0.03561541227804076, 0.03208844881174305, 0.04219168338984732, 0.012711996659486285, 0.05316863166949442, 0.0590012765549604, 0.016305273654119625, 0.04833853540701732, 0.026549918486947016, 0.01231619063013744, 0.0220650042061724, 0.0184743826638066, 0.07821859596597572, 0.009018500042598574, 0.018358029229866884, 0.03794733412383545, 0.048278811192440416, 0.06495654913446595, 0.11750623538729646, 0.06234625008918586, 0.030321702586426854, 0.01711067721067417, 0.025528533677119884, 0.050494280012865225, 0.05163182098899157, 0.11359512670746735, 0.004807067659473228, 0.02094575166401844, 0.016869254177436233, 0.06062711431314388, 0.06131374359791798, 0.014435741412002715, 0.031137829458701517, 0.08965660277153216, 0.12147326082471879, 0.011028242654227203, 0.013957132769358015, 0.07140629699513798, 0.033972310728483626, 0.045753444484885664, 0.022030557062657132, 0.05206911163705011, 0.041084667187063925, 0.04215324875868617, 0.0065499794530502016, 0.067842134214457, 0.0642783391559797, 0.021179080978336356, 0.042514106814539245, 0.03833284105865225, 0.044439599864305034, 0.03831619779849726, 0.07756467097468915, 0.04423254545057013, 0.029256363481944127, 0.050378007018157554, 0.010191166150053183, 0.06887221603744453, 0.06433659248174199, 0.03094716166566697, 0.0375413075239668, 0.01077012273467957, 0.03371058828047207, 0.008860373749367653, 0.03819052107451904, 0.016862757751838337, 0.026078998494232376, 0.0747679980591901, 0.08871381666751639, 0.03257449521052261, 0.03644587840103815, 0.011592470240899393, 0.04636187917522846, 0.027797822089445208, 0.0349257837590431, 0.029293643235559427, 0.04840259567924565, 0.018802452156500473, 0.020639305002987385, 0.025264987939848535, 0.036882835800849625, 0.04134940419105753, 0.02403242524803406, 0.025880662161075783, 0.03458534577681172, 0.05376487024008267, 0.0259135426547859, 0.028693978336729833, 0.03526202740988905, 0.033597211098118175, 0.04696759808387968, 0.029103264640716296, 0.01823709650535978, 0.04924967441888106, 0.053144503730319204, 0.04275608334630247, 0.04890429899997769, 0.053007780018472866, 0.01779081773072962, 0.060645634488713365, 0.01331857550183251, 0.00910088034992617, 0.03258273831658787, 0.008950229159616416, 0.012700148152127382, 0.06292352032276892, 0.02008282448044948, 0.02397867460404673, 0.03945193463756193, 0.03818826111514242, 0.03996863795985137, 0.015435405713956685, 0.056072740755494566, 0.021603374944759474, 0.008370983376798612, 0.05658243054283723, 0.022922624315645908, 0.049926731435041276, 0.07018486939130292, 0.03875211714917133, 0.009954077259246862, 0.017207648620129596, 0.03774384967982769, 0.08767717713189703, 0.003522023635600964, 0.054303135107000994, 0.02915746153091952, 0.04242723627436546, 0.01241548807405296, 0.028346691528455387, 0.0848255833731063, 0.01757252480714552, 0.020619829132732366, 0.02053420540065535, 0.020672767723519957, 0.03420398337766528, 0.13990791033833258, 0.11551922547721094, 0.34453808480212766, 0.1337642835513238, 0.1891880176000057, 0.1629918248903367, 0.19399742565808759, 0.12626127204707555, 0.13626628074674837, 0.1454044532992186, 0.11999540060998933, 0.31748390426078155, 0.08570784087022466, 0.17170733141322292, 0.12165146819766491, 0.13595935528076467, 0.29178042866049275, 0.1584239796765389, 0.13332243468011581, 0.09971677746263244, 0.08315958728593204, 0.08678458510868012, 0.11529155180699403, 0.07744922918537933, 0.1626152160667604, 0.11770336513197231, 0.14450215494200108, 0.23350680156821207, 0.19350440211353764, 0.09436065841826702, 0.11660494060525972, 0.21949626385204254, 0.1285235526701135, 0.0887882727528772, 0.13890050471790377, 0.1577432186252648, 0.1283061905433574, 0.1649121468466136, 0.1525288871339252, 0.17426699970758733, 0.10751149226580897, 0.15622647178749885, 0.138783645665934, 0.11126009071426046, 0.11505260132253171, 0.1517184427188289, 0.06971957056873268, 0.10406193623860037, 0.1697773261055831, 0.11871729782151601, 0.18946161824128321, 0.09830972675474421, 0.11765699382991561, 0.11209560918711847, 0.08744265463563704, 0.12600071022226927, 0.13205817510043422, 0.21762886324957495, 0.18927558144975096, 0.13060689813667728, 0.16953306663180553, 0.10178513058851804, 0.11866993826603699, 0.11070411006409316, 0.15165876446952745, 0.1807659380738774, 0.10911892859205123, 0.14171040797185513, 0.1517276817391957, 0.11132344618559846, 0.13894119930844154, 0.06675456515363147, 0.09532222133730689, 0.3503243775377351, 0.18136624457134357, 0.15489211516274562, 0.15579548604305715, 0.1257480084595661, 0.10205003613185498, 0.10019755892215237, 0.17328942555092997, 0.11182954685101587, 0.15811218189135676, 0.2904539627413596, 0.09772558471248036, 0.15852361707197082, 0.17795479375748866, 0.13333208738796173, 0.13569879345595837, 0.10283272518145462, 0.13465116821950482, 0.11555733069056466, 0.16726374566074342, 0.12793847600058203, 0.11405374524333786, 0.08473942146426247, 0.09557047979004922, 0.30710142105817795, 0.15769037388024792, 0.14229709342602762, 0.1113191943976187, 0.08887341576478175, 0.13523246041469036, 0.13763895708947413, 0.1597703332381864, 0.07523702006907233, 0.18423308347982748, 0.16093075726061098, 0.18096928845249838, 0.09593684601807788, 0.1405092433936173, 0.12294791879192477, 0.2384442535619582, 0.16742387335867653, 0.11501375300389145, 0.08182008255032763, 0.11864608994895413, 0.1466010060281523, 0.13749655666610888, 0.16074358665895078, 0.09551641696523275, 0.15083779400635153, 0.16965781638939537, 0.16087578279116463, 0.11530072187944768, 0.17831405835045924, 0.1155519680750947, 0.12328682076786796, 0.1095280348653755, 0.1442929056863631, 0.09008318351040925, 0.11002829027993065, 0.07037357216881168, 0.16846791330364444, 0.11874678454572156, 0.06713400084164835, 0.16484466982224297, 0.13788822677827653, 0.12204160613398399, 0.1375015209158582, 0.15448303953293832, 0.17615376701278074, 0.1304889205963381, 0.11982358241033171, 0.1263529191454572, 0.2512877176125204, 0.12572039865077506, 0.15526325411854253, 0.15616175267965565, 0.18463140323517785, 0.12302504852414133, 0.0904567433040469, 0.10456933925348906, 0.16374737144477908, 0.09683498451786657, 0.12144410351832068, 0.11149354068742645, 0.15632825422911875, 0.15422480661542187, 0.10292464807148903, 0.09532695576067894, 0.09392573498189451, 0.17100337321960157, 0.17495323062664078, 0.1587742810407954, 0.1649301345910757, 0.14028526992807466, 0.13297293004730057, 0.0942873131603964, 0.22862902782376737, 0.2321985378981598, 0.06510008336795915, 0.09079169992718006, 0.11185116585223906, 0.07863974514146967, 0.10148110093488809], [0.0165261214809312, 0.045555027712497025, 0.03639265827293839, 0.08865602299450867, 0.02116527415872101, 0.037808921188116074, 0.021788674376664624, 0.041967939750681964, 0.009522325426880873, 0.03532484661968004, 0.051435740784771984, 0.034999067729879776, 0.025283471726241614, 0.022135643258450494, 0.01662825057733684, 0.041417781368739186, 0.05900595352173813, 0.05099578415073695, 0.04796578383613979, 0.031029247986753623, 0.04070679048797296, 0.03369275375359482, 0.04489374827713736, 0.07592382555406901, 0.025148297427222136, 0.03367455916539316, 0.00657247610375165, 0.061813079706964, 0.021865202729860624, 0.10466356806817556, 0.036589010438371095, 0.06586207272184473, 0.0787107844746882, 0.036186549977789965, 0.0155121160130347, 0.04802956065583614, 0.07680155547155489, 0.028997506202769377, 0.02269335718254649, 0.06230163312847577, 0.026418348631611275, 0.03812303638926918, 0.05654992926264963, 0.026648523578900966, 0.029245649742323066, 0.04735706952370463, 0.035223968161810795, 0.033843282369836684, 0.021548634132130012, 0.051242112061910094, 0.014263813087205975, 0.04005401079813319, 0.01867934565750822, 0.026790362842861685, 0.010101046439470544, 0.026349042572321433, 0.01835272024055162, 0.03032497952752296, 0.006343849611678913, 0.05459468901878404, 0.004483563093198163, 0.04278278151046365, 0.04357984236952278, 0.04110184670876592, 0.06723749932021865, 0.033203495531192714, 0.057060400459675066, 0.005548937629247385, 0.10340971962338495, 0.0657457882358182, 0.013208784568574161, 0.04072063752720433, 0.09964403741422201, 0.07231566634389662, 0.07614889452534337, 0.05444761162864105, 0.0445369734699207, 0.05612412227257606, 0.02900808013134426, 0.030672070983376716, 0.044298670329754396, 0.03582253947012848, 0.05566819270531978, 0.029887631422870105, 0.034322340131527, 0.04829676829338555, 0.013526235125027599, 0.02869915709109797, 0.017994350055232644, 0.011325724171324363, 0.09033902623360196, 0.056467502032436674, 0.030140149324471434, 0.03144177867309942, 0.04251100798888553, 0.020971411779042215, 0.02943708170806208, 0.06129065370788017, 0.034601655788719654, 0.0392900679200407, 0.04938231488209098, 0.05837643992215876, 0.05302541919292943, 0.043984202728156126, 0.06909536978890819, 0.028147349704898177, 0.015641593490727246, 0.09270572464071936, 0.05274243780501908, 0.018069577974177176, 0.024317404210206964, 0.0633219090260325, 0.08248356831890923, 0.04031856394102497, 0.015707320961800796, 0.01177614748162488, 0.05784127388089415, 0.028329399008784565, 0.06225811167349739, 0.03415433704973229, 0.06326738271802183, 0.056975165517219616, 0.03935901966366557, 0.02221776596871355, 0.03630659595552472, 0.09936259969347909, 0.0349062217038966, 0.030416791334808357, 0.048161369913648215, 0.030598095618188385, 0.1082035301313285, 0.03125762262742125, 0.04060884614685371, 0.015439996495842935, 0.05656197982569856, 0.032929734011451085, 0.06063334260796828, 0.043073232255635724, 0.035265930627863255, 0.0994706487343196, 0.06901137590889009, 0.02536389755175239, 0.03182697342708707, 0.04803116944047713, 0.01850172051138455, 0.07690254118173354, 0.01959570364335612, 0.016325820132248824, 0.05378435568643674, 0.0638802875314028, 0.012533265473921935, 0.049041440229742765, 0.1035809709179786, 0.007235130188130444, 0.022665015759787733, 0.02841893745015466, 0.06504653382205194, 0.02914992131052479, 0.037715967909823504, 0.04560238726797604, 0.06560658239909718, 0.020237461243185307, 0.061244060240325436, 0.03137405841581283, 0.03631370525146204, 0.018842999275112828, 0.0343769813527263, 0.07232885837795273, 0.03229240248460443, 0.13508587715125855, 0.04991939614316629, 0.037337826910398664, 0.03354764903985685, 0.0293874736845253, 0.02197089221989436, 0.05402032225843399, 0.041719838345964114, 0.03378339344635606, 0.02756808572749217, 0.06831119452873546, 0.02527968916711548, 0.10030307987284276, 0.0016455128112988127, 0.015494484499457385, 0.06315690134802172, 0.04516133129776967, 0.055431184253745505, 0.019241589076456525, 0.059795790171671304, 0.035597187046322136, 0.025279001603203437, 0.06465880140181511, 0.06765212142659772, 0.02584034678406052, 0.032628205634893916, 0.13057714328169823, 0.026880178991104328, 0.04589483367219087, 0.024726688598973617, 0.03299850572441374, 0.008497003882732845, 0.08033164266136386, 0.054995889264729717, 0.031267350028839805, 0.014459734328181274, 0.03826836326850518, 0.016670975300873962, 0.06507225139367004, 0.03486939585737644, 0.044014490014242555, 0.11084166881177696, 0.04682088841594035, 0.05794653819212991, 0.054400018416345126, 0.013726366019146818, 0.03015893188515498, 0.02057343484803794, 0.06815657500297793, 0.026727599174445196, 0.019103450017170082, 0.01894270753367774, 0.057213066461225676, 0.023688382822118943, 0.0663779946344514, 0.12132881494659571, 0.06952931263273762, 0.041617412390487815, 0.09873029370341571, 0.022246505757192933, 0.01922007541232292, 0.044805537083096085, 0.03928822164814319, 0.02506164713732658, 0.027262567948069305, 0.048598606935552055, 0.031185455229734222, 0.024771497081664783, 0.05527694011107088, 0.015447230281067953, 0.03247942752955902, 0.03831021465180862, 0.0462547532703367, 0.02049343037088552, 0.028790896120030555, 0.020273350547218037, 0.07632866471765504, 0.04137158243646545, 0.07946171151894717, 0.05973973934869132, 0.09079330871182104, 0.10512535054717334, 0.11253757297151512, 0.06464331110398616, 0.012179553103182587, 0.037818401526179046, 0.03932674054897601, 0.006325045504772495, 0.0240805221631402, 0.03211378525461882, 0.037541859107272285, 0.025695069700539596, 0.016442169735748923, 0.02280657923209571, 0.028420243630065557, 0.04058624655308743, 0.0075945532655403505, 0.05181499261168703, 0.059088062825462515, 0.06108955179731693, 0.055065526657046816, 0.01093420631913168, 0.0265260586785453, 0.04366602726100434, 0.050499286397450396, 0.01786332986798258, 0.06010701339091024, 0.04484823882399548, 0.029091311753877712, 0.07909810320744592, 0.09249872768357878, 0.06696346200882428, 0.030327873424656933, 0.04567373303636428, 0.05039276953245844, 0.03872161918890573, 0.10009612888097764, 0.004196937520793009, 0.06680701919380697, 0.03032497186664372, 0.07432312314068118, 0.02598720966958471, 0.009956651314672445, 0.010411276617237638, 0.04688692519501333, 0.07662894820133526, 0.05460495076652977, 0.033483136775753194, 0.06317077520033045, 0.039769493403934666, 0.06705156212011654, 0.05930345610625321, 0.04280669111458044, 0.011878680689410578, 0.048931648338874506, 0.027568487923652418, 0.033056847150287325, 0.016397232933330442, 0.039431395820311965, 0.016909621265386383, 0.017538336218304692, 0.031095738672921737, 0.0539873919690088, 0.019489847529198856, 0.022278438217096755, 0.06738728483117397, 0.0768350794791214, 0.037695620614554615, 0.07772797027662878, 0.02068075035969096, 0.027604199112242753, 0.030654556298207854, 0.07893877990183332, 0.01761491628243558, 0.03579248584085896, 0.03170849026871785, 0.02729447934055521, 0.03647689730109226, 0.020464432027731693, 0.015841920694877065, 0.037895117570916494, 0.01929934061462841, 0.01622700628133551, 0.02877481210406029, 0.011647492590841028, 0.0344216519395911, 0.05823516947848182, 0.10257273026171232, 0.016520377736718907, 0.02208543194067334, 0.007506711708922541, 0.024839326506480578, 0.01637521748160643, 0.008668229321859056, 0.03562563572139029, 0.06217258944807034, 0.09445448120635364, 0.04327293222529754, 0.02452094036514961, 0.0220218887777939, 0.0204258288572272, 0.01813396574899314, 0.039065186640307795, 0.0663152290508151, 0.08411979422934594, 0.08818972825763688, 0.13937529536985582, 0.056338136595103054, 0.18149339984501564, 0.087113979933483, 0.08881137030379427, 0.1172771750979366, 0.14127582161416932, 0.18129984007006694, 0.11993520142089938, 0.3009018085656628, 0.1288992115446637, 0.1277080290920792, 0.14770139940083027, 0.15381577695089002, 0.17231068694062773, 0.1392453208926224, 0.18953825767722823, 0.11074532559441944, 0.18662199077586974, 0.1252763434463451, 0.21239039998862053, 0.08538146443184345, 0.13167865514274568, 0.11614347222231089, 0.16390103336063125, 0.08712877309130085, 0.1661275300167261, 0.1287596150031013, 0.11362629116422708, 0.3784632160057945, 0.09337047445437602, 0.2598992813258402, 0.11708169244229795, 0.2129583622539236, 0.11731174098508013, 0.24135005570227103, 0.10166228072898043, 0.13015836897876956, 0.18018320563339418, 0.19340125603541253, 0.12160138136917546, 0.08717345899992412, 0.17015908304001057, 0.14035109220252884, 0.1873356169990955, 0.2235078526240203, 0.1704459829676536, 0.16384938371277627, 0.15048245178355327, 0.14534030109643936, 0.13157114236345216, 0.14560020408563076, 0.15825914819875073, 0.14765802350255752, 0.09271313271094715, 0.13565367087721825, 0.11859867676732042, 0.16658802546801108, 0.17067976235862703, 0.1403494221308539, 0.14545509171101356, 0.20217213539346574, 0.1279613973512765, 0.09811606738836536, 0.14990526581964186, 0.1712565499568178, 0.15272741115862323, 0.1119106985448349, 0.20575114495811925, 0.184522649393447, 0.16608841356731233, 0.18946583172486675, 0.2668569837847064, 0.12190242327990071, 0.18258498320656438, 0.10146102943127194, 0.17571702028714842, 0.19327322742150677, 0.08387561902524003, 0.12029135569689736, 0.11324721553753461, 0.14065337517569143, 0.15200299841742362, 0.12136093701326078, 0.1386973075568676, 0.16996088077224072, 0.08296372158633125, 0.16539096712104737, 0.11518880409458954, 0.10700173736099275, 0.08321861436049785, 0.2082262524674016, 0.08046309568829114, 0.15473482199013233, 0.19671959652295037, 0.11940582700434232, 0.09376126356543073, 0.1448748873606805, 0.0919987174171594, 0.16522215198605292, 0.10449440819361519, 0.20167885137902153, 0.18297545822157016, 0.14875405017406712, 0.20205754396175185, 0.11788272929768409, 0.2415042385579117, 0.06679994820226585, 0.10605821581256968, 0.15826520029335253, 0.14154405963997688, 0.19087842124844753, 0.12884966097772121, 0.16264213639641964, 0.15494468411610973, 0.13238754694259938, 0.14452391183905064, 0.2073280296979412, 0.18423548899590972, 0.12521999767951428, 0.1213914196517679, 0.1561708384824376, 0.17980066728928398, 0.1438545654978483, 0.14987981637879727, 0.1604938879609108, 0.1571990357291314, 0.22119317924784077, 0.1068285172204337, 0.11066942926376097, 0.12542045224578152, 0.14878997969771587, 0.14044726688054301, 0.08585642362313886, 0.1023498523019014, 0.2252057486123616, 0.18560841048677124, 0.14907274275056778, 0.17624883852418394, 0.08698176081863143, 0.12875293471640156, 0.102933197612724, 0.1495278142993489, 0.12487616975821796, 0.12849196686499542, 0.1322428176119443, 0.1284685322353917, 0.13497088735382404, 0.18200746016396632, 0.1917539678153492, 0.09607753806537199, 0.08850526455188952, 0.09702794674423434, 0.14756923391213342, 0.19496448908842381, 0.0710283475176942, 0.1509796428464113, 0.1798082209162174, 0.10838709245886534, 0.1056384762388564, 0.11052744252787483, 0.1646454256748961, 0.19422285469068637, 0.13277426812677615, 0.20586763628788535, 0.12652402488334527, 0.20516383131184887, 0.18279518241122847, 0.10022248742320847, 0.07493030144682816, 0.0909427418223312, 0.08252864493237388, 0.14948738017870536], [0.04332909796146616, 0.0149390458564965, 0.03523389283086985, 0.013628487753111028, 0.04264479758398187, 0.025231988702510155, 0.007855880699465953, 0.05062962859688748, 0.023592512664054672, 0.00947801490134049, 0.0423302035778761, 0.08704387522753208, 0.0644848381559695, 0.04987382923343009, 0.021747043243639415, 0.037804822617721175, 0.06404214658804479, 0.05517213162215007, 0.01788535106536602, 0.03440601225461691, 0.008383307816280473, 0.037349697442785386, 0.06334958778273675, 0.015168385767948725, 0.11731371749192478, 0.019305662755223534, 0.022077441643623096, 0.05077160384145476, 0.07688077662380473, 0.025603430263037165, 0.025968134080270128, 0.022540965057428808, 0.07097974689977785, 0.026577472754363573, 0.02005796492730658, 0.05080289470272199, 0.03453418642522828, 0.019632784214111108, 0.06874072470612104, 0.02976582727334913, 0.06443726409587168, 0.022208180293560992, 0.023417189612143466, 0.03778431827442781, 0.04494809455448582, 0.07947867270559072, 0.022673590198880243, 0.062987461851369, 0.0431100427803974, 0.0437225224149804, 0.06712806366023517, 0.04024876183980415, 0.03227471734487242, 0.04092854995941443, 0.04061416662748783, 0.04543605425785627, 0.02868678477112084, 0.052583336664904515, 0.026362165658464356, 0.026619165174422726, 0.019413137230120843, 0.045447327241662054, 0.04414018589041887, 0.08004262067017057, 0.009946616520474275, 0.0601337077246318, 0.046449730307945324, 0.0629184334989517, 0.041431831421270486, 0.034648348847704555, 0.03375425912259567, 0.00260540446165138, 0.02832531384492834, 0.016511910549935796, 0.011290191098176425, 0.009000436646953948, 0.031758975462927934, 0.008553686728250355, 0.040531287405399546, 0.0346815204548259, 0.044067966781796954, 0.02009704690276375, 0.019956042674640496, 0.048686281868046334, 0.018366875630172513, 0.07077940724669926, 0.07691948704661862, 0.046393817380791715, 0.028122628047581644, 0.023176011727041295, 0.042381642551551905, 0.020846150657762925, 0.037924209759841045, 0.12304011747361192, 0.05225589536430855, 0.020955731874452006, 0.006821133879824512, 0.07475494392096035, 0.02844213267728206, 0.05696024978533388, 0.009756551064070194, 0.06221607642909212, 0.0398956757459429, 0.004322773208015509, 0.024375990784216314, 0.025273784544439088, 0.024722143782362826, 0.06557320394823629, 0.009401040301928598, 0.03492284198141387, 0.006124194488004451, 0.05463107819518736, 0.046146282881137826, 0.026093257305723046, 0.027566999797859502, 0.03422499333898868, 0.03539863620854674, 0.01925869581980571, 0.1011038102930592, 0.04659913660537812, 0.004391882957274756, 0.059149028102476756, 0.06779521898997408, 0.04635840496649185, 0.03560346513686161, 0.05044462602405299, 0.06339396725619031, 0.05341257704722305, 0.0550457117928853, 0.022003334128267823, 0.03604811405943286, 0.06390282966857476, 0.03784623350046816, 0.030194116388297373, 0.024050932017064864, 0.11552265755111173, 0.01141008577354613, 0.08800337737005565, 0.009375447219598198, 0.07608710187337092, 0.010047804286342957, 0.04047590307891369, 0.09015627595926486, 0.0020906596910208464, 0.02572979838136704, 0.019217627761404843, 0.0270210434081814, 0.010400904744352785, 0.0531209503570872, 0.01590085200845234, 0.12916391024426108, 0.023740047791732416, 0.022800722489914587, 0.011651058730128552, 0.06692587007437983, 0.020692898598950238, 0.07428048268681572, 0.0211235893995411, 0.043464580610875166, 0.053876301559108886, 0.047164923180976225, 0.039750413984180465, 0.022220569850516417, 0.020384619072560343, 0.0903127953830746, 0.019666461439262477, 0.013604474727124458, 0.0774369641177116, 0.03812295978047675, 0.03655573157894035, 0.01995868184753964, 0.029890442965552214, 0.059364432874586315, 0.015136277107822319, 0.01832493806197759, 0.028840952305003043, 0.014303116270551279, 0.04102626064371678, 0.038057030253713174, 0.04614974559855558, 0.047168316950480786, 0.057454686762104114, 0.10397031212285643, 0.08877330339483677, 0.04345421927169927, 0.02176989373120089, 0.027009739780858643, 0.031219381433460983, 0.06151917390525342, 0.02645905662868773, 0.029965096318553534, 0.03629625759898655, 0.016493304189474835, 0.020681361314810572, 0.02254159707996634, 0.0438929578259347, 0.07797510258012241, 0.046395131221581856, 0.06117159598356774, 0.03192144738990934, 0.022943973270875793, 0.03303563800610362, 0.013514191265248004, 0.044495524282777504, 0.0619341905469135, 0.02819663980194638, 0.028983900481234157, 0.029468215521304842, 0.05765567375947872, 0.027635422940816612, 0.021199156312392126, 0.09536704514175655, 0.035121277906000614, 0.032853439315071994, 0.025087272778393763, 0.003942149844313522, 0.06053236072822925, 0.03319141049418719, 0.02805523529288269, 0.057535677577459046, 0.02982949875595589, 0.03510869874228393, 0.023469162932146462, 0.03068701927399924, 0.04821405378020099, 0.03141670844577734, 0.06754692223283552, 0.01845782941898271, 0.06386676224909964, 0.04606339982860992, 0.030367522305178068, 0.019652315625740636, 0.02455193819778581, 0.02254506937348314, 0.025664290202961817, 0.012267029810426457, 0.05234252458678619, 0.04726602763478314, 0.07174586546757529, 0.11915710123796618, 0.051509415460450035, 0.10444706395989466, 0.014811542970428785, 0.010900645922388761, 0.038068900786099896, 0.029535181181986007, 0.039757906324079925, 0.034317042633530595, 0.044850376209304224, 0.014403625090997067, 0.03171544060141089, 0.04485085118381728, 0.021165672524441636, 0.04095616742908474, 0.05494880167046382, 0.004832564023203187, 0.045242946474782886, 0.06025695594989004, 0.04793659971666433, 0.06589258600386881, 0.03674858272255909, 0.004944230914266119, 0.03688893003028728, 0.03686966291899162, 0.0432530599045417, 0.04063999145141533, 0.020163047292660323, 0.02818210328358316, 0.05022642886145942, 0.01184568911295144, 0.03349064443741114, 0.02781369351601649, 0.030078475416127234, 0.06410781181447449, 0.03262503786132701, 0.0151325328530924, 0.040708318833381905, 0.07309961177769207, 0.05917189199657691, 0.05573467381538884, 0.0251706269749951, 0.07805952546937812, 0.04258640636239321, 0.05476199496056765, 0.06529155172287457, 0.041472732855547825, 0.023633492622344245, 0.04185406844161692, 0.021252962497753963, 0.040761094630485585, 0.013339016642872126, 0.05165180056205681, 0.03397647441635209, 0.026189749910225792, 0.012622111563330457, 0.02579658209616619, 0.06876573747684879, 0.04328250832435104, 0.05647216750789554, 0.035045469675453446, 0.06809929460887948, 0.03467399364096984, 0.1051693699593025, 0.06916693006191524, 0.019265445054418618, 0.004134510452258251, 0.08646369385983675, 0.015512851457442007, 0.015068685170263054, 0.0058061607471186555, 0.03133705445385027, 0.09781215264792405, 0.023180165838810707, 0.02906948399369515, 0.022580592870532025, 0.06388433630608263, 0.04572531756674571, 0.01665812992160359, 0.016296890737008185, 0.03297446588534982, 0.09493864111361966, 0.028201213346854336, 0.05420340961145778, 0.009369993631187226, 0.05276101160674326, 0.029867259229743676, 0.10171759993799272, 0.03250556261909585, 0.02492662988633158, 0.010852487720248681, 0.01287138891301208, 0.009731065234049194, 0.1108073863771654, 0.02944745836899646, 0.027861189052102067, 0.022594087509318225, 0.05058833645776876, 0.04056344777646084, 0.03034761934090526, 0.04842741309755272, 0.03745712212196762, 0.054976698762226495, 0.07283295955388777, 0.022440661165502765, 0.08544469732911357, 0.0797961472022918, 0.059545869308133284, 0.05634115498152472, 0.016101434894446886, 0.008239826251332077, 0.02019172004844633, 0.0230194827271325, 0.08023968912781247, 0.1108217045604702, 0.18682524922393984, 0.090847923119943, 0.16912837302492512, 0.173492745286034, 0.15643899989945276, 0.1405343710775337, 0.13663873737377508, 0.07957424983502397, 0.11328037948377671, 0.16242298928479995, 0.1708571730001319, 0.14636437679010053, 0.12096208865724264, 0.15455336640438727, 0.09193819647114124, 0.14076016783233614, 0.09361797448007331, 0.08583327244606712, 0.12158856471820224, 0.18488819590739666, 0.2073546742359477, 0.12862063133187834, 0.2580278817444079, 0.1084764642761119, 0.14482588837704352, 0.1285566629902009, 0.23633691422160596, 0.10927634433873239, 0.1555876923544753, 0.1109559155039249, 0.16712891418607007, 0.08873052504514495, 0.07558972694941106, 0.21999115665112773, 0.1440033244509851, 0.13358034584070408, 0.1894361994439556, 0.10232398917357768, 0.1348032673159915, 0.10262032730444785, 0.10061014323465287, 0.15532383635159464, 0.17524702534560235, 0.11399448834239476, 0.07937017167287488, 0.2623893428714045, 0.17435877704091612, 0.10476406348208267, 0.20318548585618698, 0.12372034226333904, 0.11241477673813222, 0.14855100623061582, 0.08428362213195333, 0.08482644905246074, 0.08624179649256891, 0.13687064751021324, 0.11827386314830474, 0.12358034735605603, 0.21166747345799403, 0.17218002298426244, 0.14344385043988306, 0.27165821002375695, 0.12533630514817853, 0.1861412093163498, 0.11642543088284232, 0.1437677064489934, 0.109584464901878, 0.08940117373581856, 0.10212269191059375, 0.0856655374950459, 0.09979626674565578, 0.06010243984600229, 0.06720546918410449, 0.1332442017812883, 0.1428358524196571, 0.11848249187272404, 0.09648027814804547, 0.09698025011006864, 0.2206769738827021, 0.1390085384369858, 0.13344127023893018, 0.12996094812068248, 0.09286287991750626, 0.16889876115225977, 0.12497697160729479, 0.10171520208278972, 0.13600695998437945, 0.11200563982129098, 0.14302107715798965, 0.1913394836047965, 0.2044545105027576, 0.1547223194352081, 0.1598574067916601, 0.161189480474399, 0.16036120153242545, 0.18563085686295264, 0.16900792868146974, 0.21829643226679296, 0.1402516999552327, 0.1648847515424413, 0.11977023204728482, 0.15352515383593499, 0.11919015793189888, 0.22187438463011097, 0.20217811087927512, 0.11917991533635125, 0.12882710734923042, 0.07920924724350054, 0.1302624343624038, 0.10606056004161797, 0.1604546182939122, 0.23082930895109333, 0.08782138552276358, 0.20053721183250028, 0.22366038072974453, 0.1767947374572677, 0.22143213739318235, 0.13832290506651326, 0.16892214215570883, 0.2142162173385582, 0.20714283560312566, 0.1792364435330514, 0.13292898724396385, 0.1416476500490981, 0.2607687298328646, 0.279135687817489, 0.1765040990205542, 0.09763504078070964, 0.2507548881394248, 0.15516945431309362, 0.10693868832482446, 0.17811423197628992, 0.09657126641081226, 0.203281813751786, 0.15084245182093114, 0.16997391958871197, 0.11780212918717055, 0.31995499746934064, 0.10610867802414203, 0.13453818557243194, 0.10507372388195609, 0.1345424909865664, 0.2223035317635344, 0.11720111788881403, 0.1315918727026832, 0.1013803756946037, 0.10831354801813442, 0.0764895738252709, 0.30623261606500995, 0.1574767119581661, 0.07817372619625061, 0.08294908164609825, 0.2838255248723492, 0.12644271997194137, 0.20109899942913365, 0.16740459858650164, 0.23846035673012658, 0.1469804646988069, 0.09587675408129731, 0.10958230453393153, 0.1006990630600241, 0.10873668136135226, 0.1568743983103383, 0.24844369280242154, 0.11853328350210383, 0.10338428550429883, 0.13580169438594772, 0.1647479742044403, 0.12949983979905808, 0.16529561981799143, 0.19524288544010734, 0.1261471862333917, 0.1810003609787072, 0.17457593232393268], [0.101371803170731, 0.09977915234142735, 0.09248848508803115, 0.03384498308502859, 0.025357765017918525, 0.04458152914359685, 0.04147597723790715, 0.06341573947499837, 0.026472882600501183, 0.08713027462363244, 0.07447413439231534, 0.055648021610273476, 0.012075957906011854, 0.02242483187376732, 0.016367571924122113, 0.03754657054800661, 0.028262632530963713, 0.027037696244435448, 0.01853125320086556, 0.012742903519181475, 0.014640850920019852, 0.03666035237631971, 0.031355923199425303, 0.031677984647573, 0.03716108276538792, 0.032300036550769885, 0.032406630024554274, 0.031179795755193602, 0.09063857427287488, 0.041383426155774825, 0.09655027560168698, 0.03144115622666094, 0.01708458425597318, 0.037591547570041114, 0.09309113581454562, 0.05105076628106256, 0.03645705945429303, 0.03230442240413639, 0.019705271453506524, 0.0355681523139919, 0.008122508504217672, 0.025632915072022908, 0.031035667803559094, 0.02562865562316391, 0.042738229667227116, 0.03632752164717644, 0.023240472280210065, 0.023633055952227405, 0.025457567122254162, 0.10524280714772402, 0.015416735193632064, 0.08910792293928324, 0.0504297562574427, 0.04335018070114236, 0.09522580151115695, 0.07377839632212155, 0.03627134058924933, 0.04796921207960095, 0.09353385802598731, 0.033111047870930166, 0.022860368180479256, 0.036840578390946316, 0.029804811572595954, 0.024889415250189846, 0.01952121691447833, 0.0924934876421767, 0.03193862882683114, 0.0323792883465367, 0.030938493380803737, 0.021832981071765387, 0.03949342978998058, 0.054127183862991875, 0.09580861056043256, 0.05229298934160222, 0.07941651233141461, 0.0905585793718215, 0.05117385745829633, 0.05985836040288691, 0.04376309826188991, 0.07889839174646525, 0.04740051436989058, 0.062164756199044574, 0.02005196071320003, 0.0496612474953215, 0.024200252129606182, 0.029652425193137703, 0.017898209851175066, 0.011584648483192489, 0.002915429710898729, 0.04403046677790342, 0.06782829100566526, 0.07240921334033051, 0.06982930500300662, 0.05409172548341656, 0.05566042074332795, 0.032960032788856376, 0.06869673593750886, 0.009439553457101988, 0.03709703781491807, 0.009615041217916917, 0.02097184078827981, 0.02622948497563841, 0.02586131078010846, 0.048088629865237785, 0.08340091264295964, 0.010221119230282644, 0.01746384182854766, 0.08445588466260703, 0.06159973571137075, 0.06041257905082838, 0.05090878337561604, 0.01986565196045464, 0.004790990825577249, 0.011687955439781711, 0.026533122009207166, 0.013442435639820272, 0.03947815782721004, 0.03542503559841745, 0.03450556921081678, 0.0513606105420378, 0.023929853735852148, 0.02200906255072163, 0.021743827589577245, 0.020528486554300594, 0.02530110898547836, 0.06671754778513024, 0.019495725338797898, 0.02585640015651382, 0.013644533464685084, 0.03626231990394093, 0.01804517232812941, 0.029233323387621395, 0.02722658096782623, 0.0649316436160476, 0.027486999151146704, 0.019647565880610098, 0.05251685555483546, 0.044002864629991596, 0.033303987114660205, 0.028312832357422, 0.05651533656242875, 0.03520542117316396, 0.03382559339966505, 0.05157561311798711, 0.013808272309571266, 0.01694550482375968, 0.03149659800974112, 0.04943470763523252, 0.01508684336928831, 0.11685204992611563, 0.028236060771310044, 0.011569604431579431, 0.0591760786670831, 0.009701567018524775, 0.05132172391900132, 0.040690407697712226, 0.07108301555197086, 0.045390985305270845, 0.027975213578751976, 0.04106492893169484, 0.038935553072200674, 0.019652811667671608, 0.048376464420148445, 0.05256841710257915, 0.01918074445829036, 0.03331789544092552, 0.07712016377838389, 0.03532747430126033, 0.014361035390456599, 0.04527157901095287, 0.03192923275843984, 0.06752567861469523, 0.038752025218620416, 0.03156652268502982, 0.027765828342507445, 0.07363070989207876, 0.04368950785588353, 0.06316102673149397, 0.06575714931973527, 0.041639973679857875, 0.03724168287590146, 0.01508702914560995, 0.06209012774390079, 0.008047450082226387, 0.02884203440419609, 0.04664205668133594, 0.026608732972113837, 0.05603468150741631, 0.00636280406334047, 0.025018905176811164, 0.004540453261260184, 0.03949871579665811, 0.059673694908739104, 0.029861450368057818, 0.04109274558422547, 0.011439322561566389, 0.018380893123967033, 0.018137100963823257, 0.01203963097425238, 0.01184690815036095, 0.042522717642808155, 0.09121690170779344, 0.04012529144904787, 0.035020380295933254, 0.01823417771036827, 0.02604194282133493, 0.048574015513182654, 0.05603410311103348, 0.037955297607808344, 0.07368454289051794, 0.04609631862671626, 0.04386092385938091, 0.022950659303234953, 0.051659959398450396, 0.10018902470267589, 0.05109267512096032, 0.02519329934711418, 0.02248697501096514, 0.07946018700397785, 0.04473100438894284, 0.10546252116440766, 0.04539363596948885, 0.013259850074386886, 0.016633423586045543, 0.013800372027852123, 0.02564919252519406, 0.01876570674921236, 0.026730165568991538, 0.02649915367064457, 0.07802951780538406, 0.03546218703230543, 0.017082113622417374, 0.058576791066556215, 0.01241604827584759, 0.1508227020742432, 0.05761248172230779, 0.03797059255321661, 0.024398056031655402, 0.07540597309989315, 0.08299226602238995, 0.05769624194550899, 0.07485904760899083, 0.029833821407068643, 0.12885240357249014, 0.018959854496642947, 0.06268682979768322, 0.0338518395719509, 0.026990537787036552, 0.02868706247799339, 0.032494515631227724, 0.08746955198265853, 0.02861265235790803, 0.04981613515185253, 0.010012806517132109, 0.05865576324023067, 0.0048966511085088696, 0.06390879366306529, 0.02390898741601456, 0.02430826286605049, 0.08426043265048536, 0.037021723711082054, 0.03134120281996026, 0.01294999336448288, 0.04455032638244091, 0.0329720450475091, 0.06824958573786483, 0.02628127443453958, 0.0540799928468562, 0.06114437687961806, 0.0507143234473563, 0.03810635099427835, 0.06385486107319593, 0.03643272084093863, 0.07501670850380775, 0.014208990877734558, 0.05387878368398356, 0.03036075966402648, 0.006778143898343608, 0.030713468459585024, 0.03745245664650875, 0.022445602432614373, 0.008977326647108121, 0.016795571840878938, 0.1146644781974535, 0.03511710655725291, 0.058786411874837456, 0.06573959058451076, 0.05763153049854502, 0.0675800095702852, 0.03711747321029825, 0.03735486853627428, 0.0225750042591244, 0.03763195104716766, 0.062111340718524116, 0.024196433181303646, 0.040644189613240386, 0.09078361003869966, 0.04531551798384997, 0.019118942230218844, 0.027956999838352207, 0.01297901947832396, 0.027728021903444203, 0.03278898833800228, 0.06754411835103266, 0.022930202840436852, 0.013760757621287579, 0.042732376755485614, 0.06187777966260911, 0.06713911830898255, 0.03587379075226284, 0.05091625656331739, 0.018568785763495875, 0.0759616396540115, 0.03973410780271215, 0.037152514071954836, 0.04154461105504344, 0.09371855416365209, 0.07738922917914969, 0.02644518277637901, 0.03504886344495801, 0.031505519103619366, 0.025472381347489935, 0.04690706564654266, 0.04049023275353736, 0.021946201206094796, 0.047293660426211935, 0.04794493858372012, 0.01137815522886212, 0.04737650900478325, 0.06909212923698849, 0.034403951478100596, 0.02889259429197879, 0.005102237506258872, 0.01199408991998362, 0.014934553708430501, 0.034818247997111855, 0.046772498472203175, 0.01762671786690912, 0.018578888547997323, 0.021269975395332423, 0.023633992494714838, 0.05587838041866499, 0.029820213770313613, 0.021802584618149747, 0.06349888299742053, 0.04416151377823084, 0.014103419173719182, 0.029665136507021326, 0.056796609574267944, 0.015299498843359611, 0.0499117735683197, 0.08221287881174395, 0.1366021796580284, 0.2471042033885756, 0.23299700069812038, 0.13890189899792596, 0.10025146086850475, 0.10192762294243421, 0.15578134405997493, 0.1317313313484192, 0.1626963600997002, 0.16668657501859052, 0.12983439039559136, 0.12842104244496555, 0.11021965138253667, 0.14372305884476633, 0.09019221314379285, 0.1957162818120372, 0.18757203173252845, 0.10005026319695097, 0.13607512648788192, 0.1047369363086839, 0.1090821793543235, 0.07830746216519226, 0.15269460727370557, 0.1189125583116566, 0.13087927303727598, 0.1112884283065796, 0.1340827463014472, 0.13184052952114614, 0.19319733875172754, 0.13012536591099155, 0.1574427436196035, 0.14669305915313383, 0.2229654470518712, 0.21352333677632196, 0.18841005531289887, 0.13157052949311274, 0.27187703537844843, 0.13268694942516665, 0.22957041198688172, 0.2025822069375746, 0.11149102025815558, 0.180115268956269, 0.12631592475959372, 0.12585761265889292, 0.11125789204191779, 0.14877062831674853, 0.09018847463472236, 0.07930992651850947, 0.11895677690664608, 0.32294969645238697, 0.14245475432084453, 0.1698155538930047, 0.18574230733417696, 0.13635522355475735, 0.11791493563402085, 0.1883576548988781, 0.19739240558157045, 0.1744411161710178, 0.27053910878396803, 0.15348046026643247, 0.09965755120520631, 0.16613790284722083, 0.16336121716566626, 0.2032005777882953, 0.12741574356632848, 0.19068757342475076, 0.11257156429271545, 0.18525135222702258, 0.14352012215362442, 0.13651772612525573, 0.1398210206459607, 0.16316823961754, 0.1287585731235243, 0.12057966522632108, 0.2961622064392413, 0.16328742757679957, 0.16249829572775673, 0.10849773853776917, 0.14034332407097663, 0.13320246531117347, 0.23173692395850537, 0.08058350938822954, 0.13957322184597293, 0.15675050657122366, 0.12816383608526763, 0.1908130586267479, 0.08855794075756304, 0.12299214504779347, 0.17095275012956512, 0.08569159214535067, 0.1542878096863147, 0.11930161606400244, 0.17469686696365958, 0.18789643932494426, 0.13865028508007526, 0.13268183195783248, 0.13117971739942028, 0.11719020879677228, 0.10092162692378606, 0.15077140482683338, 0.19523473426459298, 0.08436918649221621, 0.16178899024042392, 0.12181970110583691, 0.18146920678836687, 0.11982147566853993, 0.10755471494649688, 0.2729844614382713, 0.20346795779562768, 0.12491722441008016, 0.171589583699261, 0.15972867337686403, 0.14556154728897158, 0.14765033197979774, 0.13289647447245737, 0.08905166144212408, 0.12251527063668737, 0.11382055574006612, 0.12030513761865518, 0.1660309416512328, 0.10547929082907016, 0.18518690891083212, 0.10093806717064112, 0.14055157741231306, 0.20514829504874446, 0.17068757645545468, 0.23234885967066213, 0.16278758584972353, 0.15144141000365058, 0.17644213782923837, 0.16351667172726125, 0.15179528133763423, 0.29952303416305975, 0.1483451890488786, 0.1555345871395642, 0.2113094192839438, 0.1585575241234995, 0.16184926603830632, 0.14311383508386152, 0.11188996820560387, 0.2414154489674876, 0.187480422938543, 0.15433861663745296, 0.08519788678254812, 0.1160487071460774, 0.1093886681501904, 0.10325040397865158, 0.16414532347792582, 0.11180354582686579, 0.248632165753553, 0.0941492181511656, 0.1284927482746782, 0.19833722181858557, 0.12581936954971285, 0.16058603301644325, 0.15853699296712875, 0.2737517444597137, 0.1301212750014759, 0.09003726420022788, 0.08637476637358628, 0.16568088543511209, 0.09839546731522969, 0.09651008662917922, 0.11208760356830974, 0.0803042320354331, 0.12519662433694448, 0.1657782858538051, 0.1443761794437324, 0.06874940448230313, 0.11725314291975192, 0.14757006128709163, 0.15483349411477967, 0.1486792033838649, 0.11806506588454209, 0.14413858493489606, 0.19396779337717643], [0.004350623855697773, 0.019439942646591414, 0.050576898765059254, 0.06937525235116482, 0.04796802464331831, 0.021489499805254803, 0.028492079694725336, 0.01290736057149667, 0.02773956876368292, 0.060708193228610104, 0.03566868220185561, 0.08006313650478279, 0.035175267952464284, 0.058103364051109364, 0.08024816206025501, 0.0601537715673687, 0.04249028148009412, 0.038836352346885594, 0.009442705908910403, 0.025207594547781254, 0.0628633441163167, 0.023036897820871205, 0.03806412422789201, 0.0932647006946706, 0.03213055300406151, 0.04904648108828453, 0.06274349732144226, 0.026992234671788833, 0.054219309766326225, 0.011778583641224092, 0.022586056992651957, 0.0505222843569373, 0.03409368969920663, 0.04645103648785622, 0.03746297886414874, 0.023340647852408792, 0.022595728852695996, 0.013058413957966673, 0.06956103633368207, 0.04808951469679033, 0.032292965559228774, 0.012240560515032662, 0.030375324910686865, 0.05975631749137275, 0.054455881547783656, 0.012263509636414389, 0.054271790619579055, 0.036308174096648736, 0.011534743600585049, 0.048724452198873607, 0.01113346770345684, 0.09337463431180486, 0.0564789244033877, 0.07217184865787145, 0.03421409573826579, 0.04076409003426952, 0.05239736882128543, 0.08025376982386075, 0.0337043293421307, 0.006052714175424509, 0.05895649871578621, 0.05314350781601764, 0.016161515339908582, 0.04608881862593755, 0.0323769977436431, 0.025730012885985837, 0.033193099718060226, 0.04371104258743506, 0.095400883245372, 0.09783942537802844, 0.046692097544549935, 0.02267813884593066, 0.01833420198020195, 0.03998907718567118, 0.08970655170419524, 0.05502039641742745, 0.021072037427896456, 0.02088830656101627, 0.040468403078134985, 0.02080652667509933, 0.02705441228294325, 0.03232354012828681, 0.08400207715890101, 0.07878662717919196, 0.033294342067693515, 0.027201868886608752, 0.0034998971011279334, 0.022168307332322005, 0.059196981376097094, 0.009387435538003282, 0.021523184691285415, 0.03482900387156875, 0.0985601072710368, 0.0463972686068906, 0.06732670259812186, 0.03014915277280154, 0.04883427856369846, 0.0315370072325271, 0.026596161469276396, 0.0395870189212503, 0.06426084936866838, 0.05692765274415574, 0.009503316870259662, 0.0736173493186793, 0.02668360466017358, 0.04525992681362456, 0.03916984574208337, 0.03773405907615539, 0.017352004482921575, 0.043506910799131285, 0.023562633319787925, 0.006425348439088633, 0.016287201639985847, 0.0380687399076358, 0.07103996907150553, 0.012019949217867709, 0.03865665876336637, 0.020006732797370325, 0.013953315736275288, 0.05928594333630416, 0.01395035576405785, 0.061629521209866776, 0.033263610450611, 0.06312686687095032, 0.026361206133339195, 0.02614347245393982, 0.023689045488173445, 0.02638266042565867, 0.05173636134713889, 0.009187998911065441, 0.04261393190151261, 0.026334810573908112, 0.03366636585504298, 0.01808258231669184, 0.037240445643903754, 0.08797711587601131, 0.021793067890910373, 0.053585981048883936, 0.033864277009401596, 0.023550567434980504, 0.01935012458312896, 0.014068513335059247, 0.048946667492630026, 0.016038937441584085, 0.04395003520673321, 0.07753364441375579, 0.03396451195341445, 0.06418564251714176, 0.009412461715269714, 0.03763352152741244, 0.013396966406294416, 0.043256292795582164, 0.023736625293930693, 0.013622586003264353, 0.047114066434122866, 0.007073473665983447, 0.07810441822174095, 0.04507290559910959, 0.037934590251215046, 0.03975271990883254, 0.02501417458387873, 0.009266691462647532, 0.0662326141290607, 0.04255444134375261, 0.030777829421323635, 0.01613309539313759, 0.04850607883605746, 0.03615896315163663, 0.03329761709356981, 0.031215279032626463, 0.02616087414113985, 0.022501687729550947, 0.024406063565683943, 0.0895726548567895, 0.032104710943155715, 0.0087005773844618, 0.03275624190967891, 0.03664964246713827, 0.044568754627459475, 0.05063333263200137, 0.09872077889139615, 0.07239892477950743, 0.11884718036819851, 0.06339513937071448, 0.04005998628394258, 0.030229149589074716, 0.019973137926670815, 0.031070557362850637, 0.017762265633791685, 0.030087003889944286, 0.016764665938793652, 0.058875182313063455, 0.07819841721005018, 0.058982442283341964, 0.06314692688324759, 0.05884704390360464, 0.11553049463057712, 0.019995461728784348, 0.02926475597515462, 0.06957095717230151, 0.020313886174511527, 0.05299234717723824, 0.13722860975371254, 0.009354263930881937, 0.047511597118911245, 0.09921374114891214, 0.03207227669566149, 0.087352731235085, 0.0337743612697288, 0.020076197819904457, 0.0502508900488817, 0.03153937827465275, 0.0554142154062227, 0.11881380957821686, 0.05830718557380381, 0.05096682602719915, 0.007407486085749923, 0.04877766466609413, 0.020457858993341366, 0.026594594819471244, 0.03907898388382408, 0.04969211700823038, 0.046517770406940294, 0.09415618955127655, 0.019816503589672428, 0.10109032714559187, 0.030531976484663548, 0.09332254033295379, 0.01694252474173423, 0.03942655031419089, 0.03271816350940255, 0.048060361220831835, 0.05624410696327687, 0.05077094883627949, 0.07192264791698226, 0.03934862385053308, 0.03988549443742922, 0.06589179693330681, 0.011276222442487075, 0.013998096448279197, 0.05004208512423981, 0.04017878736880037, 0.042955365798045556, 0.059821143851525364, 0.032466698978697105, 0.0837970260650881, 0.0553246942018309, 0.0233749762522958, 0.07029671056736862, 0.03908163837848171, 0.02185904529816922, 0.017159718329146985, 0.02782197109603834, 0.04591988091687522, 0.08791544579810674, 0.05387588787162977, 0.02393461305708174, 0.05581577188305317, 0.015399959783310132, 0.07266490284593836, 0.017663114704191685, 0.014099185580327628, 0.04182454341301515, 0.04326047563564874, 0.05962951461814585, 0.03311452207966678, 0.014602573336883178, 0.020652010571211576, 0.04738017090506131, 0.025234361659855615, 0.04254945411136554, 0.03324033286903174, 0.03778254861132272, 0.04443151380626425, 0.03740438462926015, 0.022881418361418673, 0.09012714929638371, 0.03741959147455712, 0.01593572528837549, 0.022135078268606338, 0.05294393042042371, 0.028012711667425694, 0.02849706884233221, 0.03529674268417782, 0.06914976203153211, 0.06842267564347676, 0.06261480987192163, 0.025581552707139524, 0.043912768859656594, 0.039749272513173284, 0.031856017735516357, 0.030502474438699505, 0.027728899074117505, 0.03463056411654238, 0.05227565660231537, 0.03358708724619881, 0.05296442327239821, 0.014003761668479251, 0.023565511895163406, 0.05108821265880139, 0.03162785759946752, 0.013581152137879644, 0.009030711484111605, 0.03507960272291976, 0.08686590534184249, 0.01947046741993437, 0.005334266386325321, 0.04110319885395227, 0.04797114262117013, 0.022545653515525406, 0.0029532960005810545, 0.04735079143316515, 0.0804719823082128, 0.08922440660817009, 0.030324493061691046, 0.04897114400181079, 0.025698783311752543, 0.05365120194431755, 0.02733911928390303, 0.02034139639187244, 0.11888441990219778, 0.03038153788375278, 0.015983352017018105, 0.09904401436928781, 0.05866259291407563, 0.09357321962353685, 0.08077497008226572, 0.06280857266017026, 0.13724457502605455, 0.010567016546584426, 0.09030867383004197, 0.03081691905766005, 0.037589306762862595, 0.029054891933957418, 0.09172592882908161, 0.01608571477024065, 0.04170327169460155, 0.05587070038722408, 0.059915839979845675, 0.06983106700523246, 0.022190814995537364, 0.0022066554576609166, 0.033584022894501686, 0.05482924981944023, 0.0398700999005908, 0.040965031066368666, 0.027992860414087776, 0.03442323774159436, 0.046699819710826686, 0.07083314831458754, 0.018638689371366656, 0.009248084144576663, 0.161168183230104, 0.07670418569637884, 0.11701797690963554, 0.1703616520089488, 0.1407715978641664, 0.1388848152372145, 0.19254054093072492, 0.07798776601351078, 0.06672105646782345, 0.12280152705047401, 0.07937267678038729, 0.12929310331181174, 0.0701822876749981, 0.14100724650967505, 0.22158238255689222, 0.17548805192833947, 0.16154695242162675, 0.20399125713494518, 0.12744280179181408, 0.15560770257105752, 0.18625495805134698, 0.07788776855675444, 0.12280585544724619, 0.19118769094347957, 0.1971573851281597, 0.16741584475723006, 0.21506758617056956, 0.15252380031010798, 0.08433752407830569, 0.18988512696758394, 0.08948136781973225, 0.17606145341790494, 0.12692035281009253, 0.15077485222249262, 0.14892534743393623, 0.14545637873872636, 0.13895307367126788, 0.16842723403486515, 0.12361163438688363, 0.23533865569099305, 0.0846512983703325, 0.10676342272950758, 0.1386347181734539, 0.09030096698552371, 0.11008612225733458, 0.13775201634533946, 0.1590049960800717, 0.13185401266861346, 0.09149126077611601, 0.1615679891960275, 0.1038117012790134, 0.2092714721877729, 0.10237116486795488, 0.19400004567878862, 0.12023890931760112, 0.20087680328757535, 0.2156993635599652, 0.15221422417990624, 0.1438189117658523, 0.1459798619391457, 0.13963570397707725, 0.13558087720265313, 0.11736605661891161, 0.11581708812305044, 0.2016840148116312, 0.0829809125993521, 0.17786522275738179, 0.21652421042803796, 0.21203369412931705, 0.24742344754838178, 0.18891055587558978, 0.13796918695011448, 0.11126160756835055, 0.11322818591349548, 0.1847179098835876, 0.14019157737493515, 0.174732597304448, 0.07784013320962269, 0.1840096615975903, 0.12776139477688458, 0.0851544112928452, 0.16124923533249289, 0.27039324564318507, 0.19893697673274627, 0.11094048649312989, 0.09146285423588368, 0.15049184402150495, 0.15132370825496413, 0.15063720154425791, 0.22880291446082054, 0.11034502933222441, 0.08012659922843018, 0.15371672178228057, 0.13783329827410562, 0.16442978724596963, 0.12476919324047143, 0.2908509188602048, 0.1071511168453482, 0.1545447096108429, 0.15204715572537916, 0.26864546200921463, 0.18451624489840002, 0.10106149159612195, 0.10736493964589412, 0.1855769242730833, 0.09268528541489955, 0.18150649994852083, 0.20472709990797505, 0.12737748513538993, 0.16209786156973532, 0.22477565152991205, 0.09487975959575946, 0.1344958515537362, 0.1503722117312493, 0.1653519732457015, 0.13159446207986725, 0.08841231510403658, 0.14379893219278705, 0.14107763466815795, 0.23389346146535492, 0.12111385833592185, 0.1458577168804984, 0.11208393400715244, 0.11999096496090775, 0.17494158609019173, 0.09444345720112325, 0.19265638874663463, 0.10887218699339898, 0.19677558222845679, 0.0646459311246872, 0.11996840367153769, 0.16375962885156756, 0.12019829899673501, 0.09353918233706106, 0.10782132120502573, 0.1696517183295181, 0.12910640768466458, 0.21245179427487237, 0.08301518737308441, 0.13633718984501977, 0.1500431156807369, 0.17626661176402725, 0.15175716080252202, 0.09960220901355629, 0.2718165757194642, 0.20227719669140157, 0.16588973632502943, 0.21757336784034007, 0.205740220544319, 0.13802023904938854, 0.13408588726193676, 0.13629491711335798, 0.2395156581675814, 0.060362415613546494, 0.2663652779113862, 0.08678318316777868, 0.18532812955879396, 0.1729926584108222, 0.2235164634522892, 0.12679007189768937, 0.15166811074220365, 0.14726578648532593, 0.12187134309281265, 0.11213535382863014, 0.09676332465342938, 0.08702470770766658, 0.1406489318657306, 0.12871600927845125, 0.0937702267941448, 0.13221562149063235, 0.14529942264479978, 0.13965542308024823, 0.1306123220391812, 0.22722797558432628, 0.11304093870304285, 0.08498630861962035], [0.028967094427395253, 0.024903455726622094, 0.007354921920435324, 0.026951271950477557, 0.03544495771488836, 0.022674388845541307, 0.044910885664003516, 0.037765541459403695, 0.05867362074974564, 0.02438906215942435, 0.02006708520404514, 0.010447136235363301, 0.03768959916346977, 0.039254092431116494, 0.057098268185772245, 0.05807362834832842, 0.06505527488526798, 0.04763168906192145, 0.06330764829932202, 0.02358026674858505, 0.026403423323626482, 0.00900544303153912, 0.030984891495937784, 0.009236347677576686, 0.04427322471934942, 0.07439453019610337, 0.013152275050449516, 0.07245550803359478, 0.021692369463703325, 0.027862004935741428, 0.04889688326887066, 0.009603645660043245, 0.0035779174105564676, 0.07362504084143909, 0.05482833817481034, 0.04323523686898332, 0.02416410618611882, 0.08513443171977998, 0.04201886927588813, 0.038537214164652174, 0.0387128628039312, 0.06544733570227701, 0.07188962952744576, 0.07751658363568206, 0.038075037150373386, 0.06996807416961079, 0.03485997297590779, 0.020272649576767318, 0.03345556910179796, 0.040406510834732366, 0.03290559075051739, 0.02590267186714036, 0.04147179439784058, 0.02333310571679425, 0.0459498732591108, 0.004989965405735758, 0.028774476940593416, 0.03755269159052161, 0.030016814914321708, 0.043521723109147245, 0.0830194085175472, 0.056492277315907904, 0.07184438437463776, 0.050004355293968995, 0.0485403765924275, 0.020471041451298425, 0.020002938746925325, 0.043718707297117486, 0.08162034810670922, 0.06903039021117073, 0.11759355408890594, 0.01915427229006685, 0.03208233159966767, 0.03945825486293724, 0.024899770843706308, 0.02165520462327667, 0.052034028640557686, 0.046752706590679385, 0.02810272316808903, 0.08976049961582308, 0.008019772283132038, 0.04009351795238834, 0.030705028085879264, 0.040098600945765936, 0.013672909361400433, 0.05692779447042173, 0.02315558973819979, 0.018072910456647797, 0.09595025255675278, 0.07584078162307702, 0.039568215293148835, 0.028617999651619506, 0.005889001664810724, 0.04690459884342648, 0.007419395401337816, 0.0625524158409286, 0.04437838943915502, 0.037222618777905746, 0.024059456660442298, 0.01819989910619634, 0.04716764279310742, 0.04559217531594538, 0.04994617091611989, 0.06008127666709404, 0.02041897045508508, 0.07128296450020806, 0.018311678995228103, 0.03016302279467064, 0.10238857038559453, 0.01982909615992779, 0.01855339122665746, 0.0702811896260227, 0.08357034830917275, 0.025917968727768432, 0.03593611583534268, 0.0014822417588513947, 0.05914088841828127, 0.04288195542270138, 0.052227435197921536, 0.07073972389222154, 0.08574624485786884, 0.016363180325096174, 0.006776652899720977, 0.06979484636817249, 0.05138266238293821, 0.0335207938276712, 0.016868216128298835, 0.04989162545591112, 0.020929299925844518, 0.038304342587869016, 0.0045380946680633055, 0.03593850602966643, 0.017986777276101134, 0.05011629223102524, 0.09855245405267324, 0.020814080302032734, 0.031786933841724554, 0.018429899768483256, 0.08394353271972749, 0.02838112143499236, 0.029099409303237355, 0.08380326202079173, 0.05102194222291151, 0.04158610237702247, 0.017073508539807894, 0.08233869343154854, 0.01764668211821587, 0.06400557355053964, 0.017538916529907335, 0.09062418714165689, 0.014245888544997622, 0.02086077527623744, 0.008664862365431843, 0.049231219360785144, 0.04314208823827006, 0.08106713303394857, 0.006100113950519553, 0.03310316482618932, 0.01743858199446432, 0.050633524153982444, 0.03162773311017983, 0.07882932125921212, 0.04714160346456113, 0.04206648164038216, 0.012181157099774048, 0.031637569679127585, 0.05173990067334906, 0.021540910050633456, 0.018644314371950684, 0.037006221921934236, 0.08755529254314401, 0.04462655596134644, 0.06852210619516912, 0.053051588756422845, 0.04732421201263224, 0.036637304621117736, 0.0202778187550364, 0.014014837384644537, 0.01073916224882968, 0.0346306751992914, 0.029129723402401133, 0.05205128094061248, 0.010196374590328385, 0.038008877797232526, 0.042291408885390534, 0.01750718899852326, 0.048488370713687716, 0.07762086352393513, 0.10135695638675844, 0.02893685310658428, 0.08179769746118015, 0.03256640149160259, 0.02859083417382452, 0.03773399778912145, 0.023388265962562254, 0.008686375071955545, 0.018671952909038916, 0.03708912795709987, 0.0013825490614474422, 0.022577122492235036, 0.012226416616730634, 0.016192252702650525, 0.004035282913865823, 0.00970102022326882, 0.01793058281163535, 0.020767289566837495, 0.01595389593632952, 0.04401559318085352, 0.031389146517481537, 0.07150837821104834, 0.07035892456769943, 0.04339004025584267, 0.03510643495246768, 0.04874165470321332, 0.013282334754964518, 0.05514628381558484, 0.034544842708255016, 0.013068318517217714, 0.032705132353810534, 0.026086450614515814, 0.10391692345541331, 0.023963628637213862, 0.025046608831372955, 0.052612501632181875, 0.004437863075685117, 0.04562001495111374, 0.022929308432785254, 0.031680256098268494, 0.056111221351931174, 0.02815235991992297, 0.0283482869065577, 0.010221018681242582, 0.037226273017304565, 0.02732890350143275, 0.03228760677419844, 0.044588362647881435, 0.05519950394368461, 0.03453940348399263, 0.07538354204547021, 0.02399880547947701, 0.027317220660587473, 0.012946728872315539, 0.018240204907112548, 0.053977275777968674, 0.0652328004399615, 0.06359231125022616, 0.05560777901161102, 0.004007754023111756, 0.03629017486086777, 0.07101185364468444, 0.02927617643088583, 0.0647549071319161, 0.05244891887771026, 0.02686535327454969, 0.04502859507356921, 0.03429342797326465, 0.05300990208202312, 0.024816336207872918, 0.0572199076263895, 0.03500906900773126, 0.04494488464608308, 0.08636771836468289, 0.016567252741585818, 0.011028300110821523, 0.01746534527609906, 0.026126082258058653, 0.025432964208565896, 0.1448250610020853, 0.02391197132847963, 0.08667043034708308, 0.061972065933889924, 0.05720016937102041, 0.09667121790229313, 0.04261356034886934, 0.06685516015896875, 0.03116752302664663, 0.03363314828264617, 0.0984078549569653, 0.06459779782040466, 0.08725786656742135, 0.10091814122373059, 0.040696092070110386, 0.02936253369215035, 0.033376344119108496, 0.05360359341026314, 0.013000265011684069, 0.025018638961257476, 0.013903182942510374, 0.051283159052893046, 0.05257461092344696, 0.02860517342454724, 0.01981735011682876, 0.022584632069112796, 0.03590326215470991, 0.028551786672323946, 0.0438846534328355, 0.004061511849173375, 0.05778806141367363, 0.05329757575846968, 0.024373568031155778, 0.030065861778453957, 0.02944305719387147, 0.03518156136476225, 0.05221005649335923, 0.02401138655841351, 0.01631034132573874, 0.018620517765802723, 0.01163937493167337, 0.02812299002412587, 0.024311267845933477, 0.04401309573422036, 0.04225825260002767, 0.03105073100737026, 0.02448359166362113, 0.010372693556541157, 0.05731805881124832, 0.050920948851853616, 0.038194117857323545, 0.02741739240234658, 0.009425033218107157, 0.07091420041697641, 0.021836062660440806, 0.02619946007466605, 0.04107651218110996, 0.03198228243197645, 0.022435497732893116, 0.040681907952192335, 0.0743354954606583, 0.05078231758107582, 0.05524941074151186, 0.02988909465080548, 0.045754980491173845, 0.022846952065705292, 0.05295037705030653, 0.08079011564052875, 0.04005766886797163, 0.01515402066175856, 0.06564805073843849, 0.029780597448529258, 0.032968842799985604, 0.014212231429654264, 0.0632339812845232, 0.04940591805103806, 0.019703409859850522, 0.009435463505196235, 0.08121783018953378, 0.06792763728768596, 0.05553769728829784, 0.021688514126224384, 0.006912118312151682, 0.03799671615143457, 0.043363499139705976, 0.08728909231121502, 0.11330608173363632, 0.11628846202286021, 0.13864106138146695, 0.13519050943995678, 0.10705746259660491, 0.19625948411562752, 0.13943681223017557, 0.11668236911176674, 0.15488229391555633, 0.13204291462898254, 0.18789386526951868, 0.19577874862138303, 0.14327183305736513, 0.10944682188452252, 0.09792102906372278, 0.11955446338341122, 0.12345210423753147, 0.13289291982448873, 0.08166160960231097, 0.16940546702713738, 0.18985258355256052, 0.14344228762051753, 0.16095761630323627, 0.20214356031389008, 0.09672498195281914, 0.11314953166630962, 0.11462541537419443, 0.20886471014349692, 0.10733167610822186, 0.11433974118723024, 0.140347185154115, 0.1309049982697733, 0.1658152419352724, 0.18838399300171485, 0.14056565810836133, 0.12031732607753047, 0.10770509800603313, 0.21796594193625837, 0.09562327856979064, 0.12003394249345987, 0.16957492567598823, 0.13283805260735174, 0.1524712007132269, 0.28872238952786694, 0.13125142322913294, 0.2535792857769036, 0.16858576826991575, 0.08361135699575947, 0.143258104761762, 0.0919765774761477, 0.09316331661877134, 0.09879230852088622, 0.08934241479202625, 0.07074091898938341, 0.0929135183293012, 0.1470467006607402, 0.22716184687470237, 0.14698945857103796, 0.1246249159016917, 0.2293523527201145, 0.1239490807957707, 0.1879993708984506, 0.10832389786599145, 0.08453720489576941, 0.1269365325870533, 0.1486475792743506, 0.10519898691845518, 0.14117656726269953, 0.20906360189039863, 0.25791397979182584, 0.08849617874910755, 0.1351362857366762, 0.08430304246083384, 0.16086416889823255, 0.17210195862477826, 0.13169175524625087, 0.14190067356872943, 0.12733594784813543, 0.09835379213214883, 0.13600073935043427, 0.1122523201329093, 0.18197635699424053, 0.07570025811512625, 0.15353802411306292, 0.19308418756531132, 0.1430784111782428, 0.09959054915534873, 0.15878436275787894, 0.19444071477459324, 0.13681760358233608, 0.32053054400509406, 0.12930722997313546, 0.14423855940901464, 0.12215314853575923, 0.14342960120449144, 0.17448277603234016, 0.13799992239763662, 0.10781470220535995, 0.1697659267172698, 0.0680021699818392, 0.15157198202946495, 0.22147822524270705, 0.21512606932270914, 0.20865239653616183, 0.11167584663076748, 0.07880243157306988, 0.11012647210830644, 0.18652436053079946, 0.13358386984515574, 0.25206742658009457, 0.1538088821595715, 0.19405780870827938, 0.0827138849924649, 0.19295360021773847, 0.10364873905576046, 0.11694829355204299, 0.14466255843158693, 0.12188301827277868, 0.16334436323133208, 0.11744522414500676, 0.27417287831344916, 0.17733677530721312, 0.14814747707738032, 0.19876077651016175, 0.19783396333936723, 0.1124287884862673, 0.18505802227845117, 0.13693247080570267, 0.141866552012582, 0.10053528878357142, 0.13910935560782112, 0.1404622975256174, 0.09239939672331657, 0.18284730703359653, 0.06771136300578233, 0.06729939922450051, 0.0958491902377817, 0.1598535763520387, 0.11088679139051708, 0.1334709791286338, 0.16616964953080302, 0.1861381296428942, 0.08224651773249911, 0.1498109910396799, 0.2171734239785902, 0.10302900456853452, 0.1633116819204823, 0.15794846890193803, 0.13400074425003222, 0.1376707344165733, 0.1170442613863176, 0.14854714514747744, 0.11685243297007777, 0.08980752209261542, 0.16836420032045535, 0.08942476158300716, 0.20572031758004622, 0.23206108640278542, 0.21503075266317015, 0.15871002158570677, 0.22058868991030803, 0.08296258011532408, 0.21386168716895967, 0.08824024409536393, 0.1389434669286974, 0.15121041917272154, 0.2072551900581006, 0.1493194383839446, 0.17212166240619076, 0.22333384341289922, 0.12211951727588331, 0.1273190096441296, 0.12354391221437724, 0.09466209103383365, 0.12270267106472485], [0.05164340806884631, 0.020160816061580857, 0.029810639586479917, 0.09951166508178558, 0.011191831154358244, 0.020858136103338292, 0.05903205030687875, 0.050137800149499416, 0.03752986983125729, 0.08654622451191948, 0.06811201166842254, 0.02319019967539897, 0.009324894992694741, 0.030696016976669915, 0.04935156028237074, 0.05198779523432736, 0.02890305522258484, 0.038937043113213395, 0.06785782369514627, 0.013259388506412508, 0.05064957752643574, 0.0428672656867533, 0.0721354364988304, 0.014478806087056236, 0.10038894300739612, 0.02889111765750474, 0.033068434230142066, 0.030848805552288413, 0.02072393856642227, 0.012704355890051493, 0.03536068421277789, 0.016202060543301127, 0.039849764096640775, 0.026046359318218408, 0.059719503136171456, 0.015386116574518384, 0.03175885097364024, 0.0431067677545211, 0.02089595594894021, 0.0429217996556432, 0.042981213604610775, 0.08637088230781018, 0.017995225310686137, 0.02103413714306249, 0.042850591783081336, 0.016235402604985624, 0.021803176421071255, 0.055150570077521194, 0.06709584200213994, 0.0595780871357889, 0.03572231984787411, 0.009289953722468308, 0.009305694914092461, 0.03980791654377695, 0.012595767714834262, 0.01662197440201717, 0.049333522742193554, 0.03771403736825432, 0.03285952205319078, 0.008211443651347392, 0.0058274575126087, 0.018912345554018696, 0.011512956060018512, 0.0138310078839441, 0.04617849687835382, 0.028448186687103687, 0.046754012770590284, 0.0648796875330229, 0.03826295085732014, 0.02402561855682683, 0.05883528062352731, 0.018770358818132552, 0.022233671869241425, 0.01913955765626123, 0.05105591822235335, 0.01767022400012901, 0.03583482368999431, 0.061974168845242074, 0.05552370852280048, 0.03531157797683151, 0.06544645470116409, 0.037668738589291616, 0.011882408664772108, 0.07958607823257485, 0.0248229188183623, 0.03711278475220165, 0.07784116742832047, 0.045942434545366034, 0.10461564160763256, 0.009508283992838717, 0.0759153219781095, 0.04115794349702136, 0.044773330746759335, 0.04037762548954737, 0.042558961262505864, 0.041490931274189104, 0.032625034030887394, 0.024494954662758018, 0.02328216853070884, 0.065413543563937, 0.041348484885548396, 0.005643170274373505, 0.052523930376816186, 0.0179072899082976, 0.13091636701456963, 0.05850829131480667, 0.03417458475357102, 0.02467403346071801, 0.0980633682000541, 0.08936854605112346, 0.05896841138300877, 0.10794719711186425, 0.03700158708999234, 0.022668105009342396, 0.1073114054217454, 0.023596892771761746, 0.06087123206065548, 0.029055832306884473, 0.06444186828429661, 0.03604130736822563, 0.010452714313061969, 0.06846065062188333, 0.02460875127825045, 0.022216308486437606, 0.052336196700531634, 0.031219921525447603, 0.031015778245824962, 0.044003875866051645, 0.06371446013931306, 0.02632603120629586, 0.007734050215672582, 0.004690595960710198, 0.022021467429435542, 0.01682278519916919, 0.06794658264205342, 0.048690943513065583, 0.042788553982973106, 0.06628332148876882, 0.09292435847342977, 0.035532923760793866, 0.038431739179237236, 0.021514993296155048, 0.02384698792030254, 0.025571940218909614, 0.021997852769169598, 0.06516942964686502, 0.030860779506544915, 0.042905409204503225, 0.039249947895446134, 0.022900516933370984, 0.017371014954762596, 0.010058215421233929, 0.017769798193307176, 0.02464332291105342, 0.018987594540381146, 0.04215252863603734, 0.01520074149143071, 0.037764560866860614, 0.010309091979457487, 0.06880657762409219, 0.029721434393356887, 0.03144755880648811, 0.034017375850629424, 0.07041078872017323, 0.017359358926994667, 0.045507997574825446, 0.08193048348109569, 0.054633334324124365, 0.03789059765216324, 0.0692604004495567, 0.02315305590239023, 0.05965470741953581, 0.0360650522634387, 0.0885469627176081, 0.03254308943606673, 0.026104614559200504, 0.023543492612999775, 0.01115072766439088, 0.05440652250282226, 0.022594847851583076, 0.05817649480436118, 0.05705177047920804, 0.03159089002668137, 0.018936776097924, 0.026835408812809377, 0.09660356467769993, 0.050919022140724045, 0.028184843963132273, 0.026629176028373263, 0.05668657636570354, 0.017462491598581115, 0.10572824642182359, 0.06278973072767258, 0.03544498452796571, 0.055618167163864266, 0.03899932989189702, 0.013133298094955184, 0.04025690918487888, 0.05577811866157478, 0.06311606503121796, 0.03502682692581608, 0.029180074531224467, 0.027382880141357743, 0.0384796081831859, 0.05727457183022654, 0.07363145299736532, 0.01789884570415222, 0.03613062172887787, 0.024735314749001015, 0.07808333548206477, 0.07400067673335153, 0.0347741213326733, 0.01747940681994923, 0.06220950339470179, 0.05275388315860784, 0.019902646346318147, 0.010463934628322962, 0.07432142242548928, 0.027940689826444275, 0.05170921502154201, 0.0695319403143179, 0.03267616656939349, 0.0532140338703269, 0.021640995607501077, 0.009045159902363535, 0.045941067078421195, 0.06525006040089554, 0.010668331674570519, 0.012363680420563588, 0.06328659237272317, 0.07358941775296005, 0.009473239300742505, 0.034303525012106664, 0.010057859190349138, 0.05841681275576834, 0.01209496263219344, 0.04275420643088799, 0.030299014892549287, 0.07569000785869938, 0.055173499089094906, 0.04107881427532242, 0.05484571687937264, 0.05047727669138582, 0.03801032953384904, 0.030515135956868052, 0.014794490810844206, 0.022941427943747372, 0.04804926060680901, 0.007858503114191756, 0.0227994718513782, 0.042895767987976154, 0.04175761797195, 0.054201360326260335, 0.06919085498779051, 0.02933287459816183, 0.0342626005951916, 0.027913055119795666, 0.027487114064335346, 0.0687896853853618, 0.04180595428953248, 0.027087426842040113, 0.0676258063063987, 0.03722359937044882, 0.021591494836273695, 0.05040290104525705, 0.01800908384123637, 0.04692871529128283, 0.043903062525655956, 0.05245020207498343, 0.035263762599037546, 0.03640416108312146, 0.07589021727683083, 0.010493518071128957, 0.08093215600256959, 0.01421374828374434, 0.034058189184795466, 0.04204619563214722, 0.06886700663955943, 0.0704455231466601, 0.011797883311256528, 0.0028433688473136678, 0.030967677500279202, 0.022855756331175085, 0.013562924033331295, 0.025355031999248653, 0.009879466041081376, 0.043798081666952184, 0.05465157487760148, 0.04510268726716599, 0.03227166831493378, 0.06543013702837691, 0.02635637786419642, 0.09513665952028767, 0.06767953971340772, 0.03446112461988965, 0.006873489764984698, 0.06531001444184972, 0.019351742943869005, 0.046205516799443194, 0.05572740364098742, 0.06764666688057684, 0.04459191346541048, 0.04449112693809214, 0.045713718995572104, 0.015532068773022583, 0.10797849180357111, 0.025657240278838624, 0.027311323698790326, 0.019070648047472202, 0.02586609499919559, 0.025142042319320386, 0.029116044902513107, 0.04573552568833675, 0.03198692875523721, 0.049954222500204086, 0.019981248882569132, 0.057199265387269764, 0.029981913863711303, 0.06181441269995225, 0.0259135426547859, 0.04708970866857037, 0.08876498367997909, 0.1035617114675622, 0.02454281792104725, 0.018915545886322375, 0.020874806176570636, 0.03828514825492617, 0.024231746004173355, 0.04866453646231563, 0.0253676398912625, 0.056369776026375835, 0.0223343932790862, 0.060478975891225764, 0.02356428998492418, 0.03945791395381093, 0.02600665872676238, 0.07065003797892602, 0.06258287166635837, 0.030548244361735644, 0.02860135256102489, 0.05618405333089252, 0.06360988147676953, 0.06409504878965598, 0.023692188363882805, 0.037687450286842165, 0.04063410023527761, 0.054956489362783974, 0.052026662705165726, 0.07364860570598995, 0.058122186831408934, 0.01803232311841942, 0.05803035970236506, 0.12431520953654282, 0.06703991758366747, 0.11432065793703641, 0.15269727325968205, 0.13905405938144655, 0.109298859662827, 0.12295464504389994, 0.1668735617591489, 0.13110396662546744, 0.2190536335711518, 0.1179138707718061, 0.18859192458612306, 0.10866042496936937, 0.14767116957133816, 0.14663946364195118, 0.17416157068744784, 0.23180090762194128, 0.10091598085578411, 0.15271379011532954, 0.16077023119695727, 0.09071087765116846, 0.09880291117775826, 0.14336782387427746, 0.13931809924542904, 0.2922463326925232, 0.23897529038931095, 0.12584180060413577, 0.12861408894100498, 0.11677536452489516, 0.2089341483529537, 0.13905959053625985, 0.13366469212116736, 0.12352142753379962, 0.13083205137762333, 0.14357638365078357, 0.08226778433327714, 0.09629338333803801, 0.08839779773787146, 0.12617078940233878, 0.2001903118986276, 0.11595578068086218, 0.20570176293052014, 0.12922847613451943, 0.2021557870771616, 0.1874167303885183, 0.13335051946341991, 0.13070757741168623, 0.10365412465386814, 0.11476679690062039, 0.152332661373, 0.23267188830481422, 0.1990571452845489, 0.11694888343974469, 0.07924284019898023, 0.13685509592535036, 0.07066871520251998, 0.10483390005726008, 0.2197995733830237, 0.10477990618035679, 0.07283015567208491, 0.09043478722413702, 0.11326683504927544, 0.129130462845487, 0.19062640896487623, 0.13288901277607487, 0.10022142256099371, 0.14873204812888177, 0.12043567134007332, 0.06908486672346631, 0.0971808885374377, 0.12340986981026589, 0.18024680625286796, 0.09240195545698367, 0.12394019417584905, 0.11359924826049998, 0.14278904444748355, 0.11321108683102554, 0.18745927891183287, 0.1169025504420842, 0.11365771609088106, 0.126784632673427, 0.11508798692375423, 0.18584264953049923, 0.20373947467775116, 0.0667970217463951, 0.11947066102537418, 0.10452465334486578, 0.1104235073791877, 0.22045131502372606, 0.1642923510723537, 0.20803463855578055, 0.159897442546583, 0.14767185905047003, 0.09124214430489848, 0.13169126494997932, 0.20682956692912888, 0.15182678287308063, 0.11279014449927116, 0.07930494694700164, 0.10361331515014173, 0.13706612250497266, 0.1463510162167011, 0.16149999123186837, 0.10881491426017978, 0.22261436427793196, 0.11568719025460944, 0.09525600835801133, 0.09556825047418957, 0.1336337421690264, 0.19734130751702095, 0.21546952186092255, 0.3228737311738153, 0.1528890710324049, 0.07936535297983116, 0.21362354107681783, 0.1799212954938412, 0.2295708409961193, 0.18122390543501224, 0.11642758358990955, 0.12860206136059377, 0.13658229201551408, 0.16288422018049226, 0.09662457846946294, 0.17050428225869135, 0.18405486078512284, 0.07773579203433569, 0.2229725103825331, 0.14752950459238023, 0.1980953985044072, 0.21171438868247697, 0.11038180155258988, 0.15533636955003585, 0.07986008490045225, 0.0875055198107035, 0.12407357008346628, 0.1253033863500722, 0.14981393281730915, 0.169763628453497, 0.3146049458413355, 0.1284379500054544, 0.1255864481772146, 0.13261245503540964, 0.14364032134894403, 0.11429299450209064, 0.14498385570703015, 0.3040969774367348, 0.1641714164326268, 0.1977233862083766, 0.08913236114406779, 0.14408788523606716, 0.11231740696295617, 0.07256688189602668, 0.1064096892913503, 0.11853618697533685, 0.09087433017069295, 0.16016537413722085, 0.08625255236702581, 0.16357870952736947, 0.11826888357679691, 0.18754953939107158, 0.16773507359527773, 0.18885492257052855, 0.11902163391031566, 0.1720427400282314, 0.1124524146378521, 0.13775246067633554, 0.17055740279536094, 0.18856604613604086, 0.08541036892922656, 0.16423345423273503, 0.14022782865551212, 0.20169725281096276, 0.17232056947485094, 0.12832129779722423, 0.11788977730658748, 0.10444074373451934], [0.02669800136749062, 0.046728042389957175, 0.03615502545970582, 0.028525454315146612, 0.03639756889653303, 0.04115876704153996, 0.05927314966796868, 0.007156003360456277, 0.06450408994550667, 0.03595723687941509, 0.04273605397752216, 0.054594007200531425, 0.03541971894822294, 0.016241142518758293, 0.04761467807956281, 0.011657341608717557, 0.022757197204496593, 0.009735926061928754, 0.017596049452080362, 0.06933684836352064, 0.042080091192357005, 0.07352977780805481, 0.04583819296150919, 0.019976640863704587, 0.10860567266542105, 0.04125723998332697, 0.025906285886923154, 0.03897596037976685, 0.04168094789248802, 0.005696634114194181, 0.012015639015683725, 0.035540086682885885, 0.025707336683427135, 0.01343900931157893, 0.06947376359734805, 0.04294682774812945, 0.03203711900559645, 0.0856194343237627, 0.020582300400541678, 0.06715659277453538, 0.011007898231788028, 0.06903795915986262, 0.048069473836691155, 0.04569855428511097, 0.04820092303317882, 0.046295773448242296, 0.07127029340594046, 0.01422416612190465, 0.05595669375672456, 0.09136012184523767, 0.04528763621384579, 0.03043900596939268, 0.019049377616254554, 0.060672799966508345, 0.035221409428143696, 0.06136579544193322, 0.0275948298569288, 0.024045736025718432, 0.03623309748006925, 0.02328224705472108, 0.011555194317723715, 0.003974586246430033, 0.022096254847823613, 0.06528190667590787, 0.10269269196977539, 0.0668379001980347, 0.08165530469869414, 0.078125937631534, 0.09902326104741904, 0.011986390736344601, 0.028528719764923858, 0.016435780562460423, 0.03926880898014192, 0.06092070984924513, 0.02538146011741652, 0.020694944053708066, 0.012826800680599146, 0.02850984910412902, 0.039230090896448785, 0.0318481327755557, 0.043852110017812064, 0.012776959000245459, 0.029421497564462405, 0.03202138547485154, 0.05539408644601222, 0.03273792857784898, 0.03176388417130276, 0.09472546182693013, 0.06404151456550726, 0.033940426149075074, 0.05132264705495008, 0.04050495696344203, 0.01355045595236363, 0.00558701315669403, 0.047489081794816645, 0.05125594377938298, 0.01795379719096086, 0.0599760506602545, 0.013826560743543652, 0.0584780499939957, 0.031597463061071696, 0.042612261829837676, 0.14822822274459949, 0.05313879637528331, 0.0911202826987832, 0.025961792787476897, 0.12014179235144008, 0.0058481667844218115, 0.002346146662133716, 0.021928244105149663, 0.05799847129251688, 0.09771570983913638, 0.029535533582431175, 0.060822252229216604, 0.0885179509679156, 0.021975722404256947, 0.0061417407743001905, 0.020279896768531012, 0.01799930664410274, 0.018592856246076764, 0.03964686570989509, 0.0507937859173023, 0.03931744024157524, 0.06604805588722229, 0.06100917768274104, 0.03805936299144261, 0.04091344653598724, 0.05808488601037572, 0.018645748871588902, 0.03213322090525781, 0.03442834371760969, 0.045152272308065046, 0.018610420726960706, 0.05255749651921853, 0.05814516946913735, 0.01911208382807672, 0.033432195759228164, 0.034735521992608424, 0.09190572966491023, 0.01874625769203469, 0.0320825346129676, 0.05305823456916598, 0.03877808369936482, 0.06647898034463007, 0.07297088602377523, 0.03162949319718586, 0.045107651516915336, 0.07301145804024513, 0.03254217779143684, 0.09032989446554454, 0.0570990649172135, 0.07343996932069141, 0.05535335355107823, 0.042606949010082794, 0.019517248579030557, 0.02349125116222328, 0.06924779830320228, 0.017241931054741144, 0.04082540005084969, 0.08453070847017151, 0.12034871269978824, 0.028181716409181396, 0.04869475097004925, 0.061518109043038664, 0.0604763865140417, 0.05125826119535393, 0.022452121840850003, 0.019393676681624308, 0.07054533674231461, 0.017023938820667325, 0.09177668981494443, 0.02071409816703489, 0.020650769508774244, 0.04594335768131479, 0.07230778329915578, 0.03178455322349985, 0.076686711230826, 0.03588114519633594, 0.014817723384757918, 0.027299635112285617, 0.021059230353022297, 0.04822568682533118, 0.014914180557694168, 0.05153534370624731, 0.1199270272627473, 0.051427876892229246, 0.03085513343854297, 0.03113240172575799, 0.027243770065627275, 0.04772555398484392, 0.023604427246497046, 0.03808275931665013, 0.03215870098961938, 0.05577911457587635, 0.03897444735611639, 0.04398065191062708, 0.047960532303418846, 0.03581350346306159, 0.008243727554086476, 0.02033930114139953, 0.01738987412423857, 0.04596153311731835, 0.038928183306369095, 0.05774198122502816, 0.05105371571957104, 0.024746930557152918, 0.017266775286125562, 0.015677240519453923, 0.023447859942192034, 0.04884399255857833, 0.09611316881473027, 0.00940178532243496, 0.05262565919228139, 0.04501516172181695, 0.009620620253225489, 0.1195834368287075, 0.08127517953154542, 0.017273124239798036, 0.029780480620120803, 0.05982285605803613, 0.02776917040107712, 0.035306169396086086, 0.015020396733175845, 0.037652980160689166, 0.03943904137779628, 0.05529924093054668, 0.07290760716122967, 0.018631072542179498, 0.052349212534365155, 0.08273304485145115, 0.05196351790800691, 0.04045396615120192, 0.05178753602048082, 0.06554649812319586, 0.024125928194412304, 0.020859564857317076, 0.006601000430002328, 0.07003512218474381, 0.018628036918779536, 0.028320242342869603, 0.02502116896662741, 0.0702065037142846, 0.017995774978771806, 0.03706821375676701, 0.05749885556137851, 0.02042107528165704, 0.012531153944080636, 0.02898363235046066, 0.08872266498304184, 0.04098104230398613, 0.005441692980727362, 0.045460392871210654, 0.04505363465737432, 0.013359571739490475, 0.04873466798134389, 0.03709116958141808, 0.014254163252189757, 0.020383259266494744, 0.025197373019651543, 0.010578291445610025, 0.053755328614985755, 0.045257647702049826, 0.03543394137053721, 0.027547278779468713, 0.036172342877234184, 0.02672288390327125, 0.017554368523340073, 0.04291380935859296, 0.04086240592803206, 0.00814854687515406, 0.01169202336665964, 0.10005988526127993, 0.04683699924498797, 0.020687597270514217, 0.04197651993543391, 0.018865035794254754, 0.012601160973821197, 0.02059984572922751, 0.031408781350980845, 0.04403098388725231, 0.019203874567944198, 0.038324329821813496, 0.10222707139027697, 0.05692052812645993, 0.04600469068053269, 0.04036559407869655, 0.04983423780950327, 0.10757277163887217, 0.01726668718601427, 0.03212182343216433, 0.06311447539877507, 0.0424005227884458, 0.05540187756020216, 0.028492428264730883, 0.03682161771482037, 0.01565515516220682, 0.03687273876200761, 0.05276144444642048, 0.020169783120734558, 0.06524698838831917, 0.03460556283713349, 0.08617858657793653, 0.037749943909265345, 0.02553540740102049, 0.035370666338431264, 0.04103177264633198, 0.05996610300855772, 0.044021109013908336, 0.02814864439349021, 0.05022260225227764, 0.024944705730904976, 0.024997249786411564, 0.07486354454510635, 0.030259705005934646, 0.09895558484018811, 0.016831284944689082, 0.03781385862478807, 0.048437023670562816, 0.09266277009080495, 0.07953616760430798, 0.06998442248591492, 0.057435680120702715, 0.0373556422850778, 0.022536378105982177, 0.04156242259928296, 0.04959275923489083, 0.05532425370127444, 0.11087937565941004, 0.03857071902002058, 0.029598207235516562, 0.03927937716305737, 0.028490191287991982, 0.0515733914630067, 0.1128229407233096, 0.06260729837982405, 0.04716802583706956, 0.019708573292460174, 0.055451282570439006, 0.05483452050435928, 0.05509758360623833, 0.030989348212437286, 0.06682863819503015, 0.016058376922662702, 0.027895808565400304, 0.07787244679826884, 0.04168899181569296, 0.056004133751435634, 0.06279389058510143, 0.02587526698686904, 0.003531237518707771, 0.04985911651484428, 0.023166069821003946, 0.11281753214256418, 0.1596697152502114, 0.11900299499111792, 0.12108910603508835, 0.10872653069635553, 0.1365008262256461, 0.23597622470509624, 0.1453029160057345, 0.19082824248940716, 0.17163116695179095, 0.23046803720776113, 0.16135434259570416, 0.11413347201361773, 0.13486820092845347, 0.2197013762328894, 0.18508442166832187, 0.15127265615569008, 0.10056669072758767, 0.12523823057211217, 0.21450454218974038, 0.10328864708783166, 0.13231484519858516, 0.16848473659446164, 0.08492898992112569, 0.20390658909755371, 0.12898040154287893, 0.07803206121729267, 0.18257747554490644, 0.15317764103172288, 0.12641753866187028, 0.15135306474422255, 0.16582019086326324, 0.12572252837520453, 0.15343685454178244, 0.23753737399895347, 0.1275218927091168, 0.11456323967825983, 0.18313878816702675, 0.14215581149103182, 0.15420701805382006, 0.15947278468839585, 0.09644274750063497, 0.1583308387067049, 0.11211833901583187, 0.14484919277170014, 0.1609795110961122, 0.1517640096285651, 0.05870992565647729, 0.16337185046605526, 0.1351313827739608, 0.16422240724486692, 0.10481188269031626, 0.14763504086482912, 0.16449799971474757, 0.19951595534240046, 0.18580471285648886, 0.1259832127740787, 0.23937357950114438, 0.1338089005120339, 0.10789022315293552, 0.057410866532835274, 0.1307392321647175, 0.19099805353870317, 0.10278458421629283, 0.2559201593600935, 0.2479293566918181, 0.16776922579494216, 0.19340209873212924, 0.2792316939561598, 0.06229912419052375, 0.0895675373894553, 0.15773964865553766, 0.20881551197699963, 0.12467009210658651, 0.08155578221645086, 0.10954796847316528, 0.10577532252477062, 0.08672469235475987, 0.13233784315807204, 0.15846490409345398, 0.19088690950264856, 0.11515340317160853, 0.10801032275682497, 0.09616975972969687, 0.11713289009827761, 0.07306785743323065, 0.10062253853726773, 0.22287671874848106, 0.13530857891084688, 0.15233071550967234, 0.16283425592607068, 0.16139951113971973, 0.11600011418904028, 0.09554557427163086, 0.14687822260443242, 0.2106122639510901, 0.19981145077655393, 0.13488991186022758, 0.07983920134363637, 0.15850063443424242, 0.12143144008493233, 0.17200638149534503, 0.15854295313117966, 0.10420317986919996, 0.1560470233521154, 0.08867422524358957, 0.26719452212414435, 0.15633962297391507, 0.16925206558117944, 0.1299147376970899, 0.16137450602987122, 0.20049245697596382, 0.1926636512601568, 0.11453427389384278, 0.11733138347945868, 0.11124144413418348, 0.10049510747194292, 0.1506920534396364, 0.15075488797118589, 0.14769294179014622, 0.13682999888495093, 0.20614054745003102, 0.11297001428301297, 0.18769434533051907, 0.11888333971822455, 0.15790023600622533, 0.23333060134562755, 0.12249254846885321, 0.15188823844636642, 0.09083139860341627, 0.21450920000432, 0.15303236011776233, 0.05641305999409768, 0.11651598247549227, 0.1553690048956102, 0.11968265287578107, 0.13814406950146924, 0.11422175598601181, 0.17438252576656882, 0.10438019980586345, 0.10081903242896642, 0.10817235035281028, 0.1646071059569236, 0.09389951945312562, 0.11947363344652039, 0.13274606076940415, 0.1642193122496528, 0.11559795633318926, 0.1305238542056853, 0.20773871411238948, 0.1125461761389048, 0.16870072742383327, 0.11151565764580043, 0.09294670525818102, 0.18430633680714717, 0.16555806621909142, 0.1704761055448363, 0.17802999294813604, 0.18595983033939717, 0.14542559732592877, 0.16656821443428918, 0.16337056343834247, 0.17975727606925274, 0.18171579516943426, 0.12225934364382299, 0.1392693760534448, 0.10434270746284917, 0.183806112036109, 0.20794054763692044, 0.15129559282814303, 0.21792828105390075, 0.14353124575028497, 0.1725783580613713, 0.061995630798440796, 0.14487635824949513, 0.08089161462961666], [0.04483097503262182, 0.017120483136104963, 0.06628592618771138, 0.029942456505171237, 0.04245726692099725, 0.014857763927730342, 0.05361338401393545, 0.005866858850969303, 0.029236657785311825, 0.03761793929903257, 0.031242519203994065, 0.015553488591385466, 0.002101510129455898, 0.06747712396205434, 0.0170719342291235, 0.052275426775938084, 0.056488240032546946, 0.02366177275806906, 0.01588887518136612, 0.02541623667873923, 0.014897286403743971, 0.07058991539862848, 0.04230409913185624, 0.0315526315957428, 0.05101046622580579, 0.07301298255521445, 0.019904952270970232, 0.07131630464667274, 0.08810633192619971, 0.0019880510714551016, 0.04974302738123844, 0.056645391478894226, 0.02084452655136345, 0.02276799712900914, 0.008993085075710571, 0.060102865024800264, 0.03667593077425996, 0.0392124823655092, 0.02611487056128681, 0.028318551203776753, 0.036338967000765186, 0.033593112527723276, 0.04861859033905691, 0.086116066142436, 0.01716903587352605, 0.00730235344587615, 0.022204604578174414, 0.03294564182719877, 0.06147299412517779, 0.024200851593406934, 0.0682118022814393, 0.05429621350260512, 0.032448125176972924, 0.04226222859635469, 0.02232891191998797, 0.09305632477926631, 0.051314273713937694, 0.057317534041020184, 0.005270329645774778, 0.02729718363092792, 0.03976324978735178, 0.05026271078555335, 0.022686655828428846, 0.06962358741269958, 0.06544122232064124, 0.034279351107655995, 0.02175107286612113, 0.012661839925473737, 0.07826984724811009, 0.07046181783680955, 0.010991430214245715, 0.06177323547402217, 0.03646849331656291, 0.03390507502180915, 0.008347949028135309, 0.018195718181349577, 0.027578471964525602, 0.017901477216172124, 0.03227750973535642, 0.017669802651770653, 0.007059970408708098, 0.011169675891588052, 0.07029408288578834, 0.0514299798035814, 0.024742286149111968, 0.021992248836003488, 0.02420843586385731, 0.04512877256098775, 0.09402405470609666, 0.03383422338013207, 0.10483010026115565, 0.0043403745568808055, 0.014154590974231402, 0.040884886778170065, 0.019687574822455645, 0.07540522233372735, 0.08234296054128679, 0.03784599218277201, 0.03813743118136641, 0.03768027204299166, 0.06210703530438966, 0.022407177377552278, 0.045778242750994624, 0.06291291766589688, 0.049069785482941136, 0.026171425087077003, 0.09899736727557837, 0.0555246431500681, 0.05063823176427715, 0.015958746230500122, 0.011393114053193602, 0.03650738377003901, 0.13220869605579685, 0.0532206030742776, 0.08481176314695228, 0.0816521101120499, 0.060703799714364355, 0.029277141701670426, 0.0119175395417598, 0.06365465931594372, 0.036109060184248996, 0.08583848950483146, 0.017760181874637643, 0.05050946770596409, 0.04990389435401848, 0.043707292587045705, 0.0363665308442808, 0.020844831071313352, 0.0209474983444858, 0.024039452189519524, 0.08491543016486591, 0.010100012220772765, 0.031602115129991885, 0.05760544520472327, 0.0056664282249497076, 0.02638670728511868, 0.059800390529656605, 0.014264392441198712, 0.03176423274130831, 0.07336072518580383, 0.04662257123498186, 0.04040657212176631, 0.054558686716782476, 0.08820468229391883, 0.039994221466082724, 0.06865542847663164, 0.011330048737656927, 0.0324902868258857, 0.03841951624640534, 0.07544875144958496, 0.048503183023703676, 0.01693759113550186, 0.03960090809531751, 0.04154982428336817, 0.017443693716139082, 0.03796714898799697, 0.0412997157282887, 0.021224822173075333, 0.056960602185779044, 0.04069859717762278, 0.03901632172205756, 0.013805000156524682, 0.048309347457102234, 0.04108886534888898, 0.04667028702134567, 0.0541520472465744, 0.02417513976744827, 0.048328917173127976, 0.03765009967009387, 0.06430125284579492, 0.09118266523845735, 0.04056353587657213, 0.04409086514985369, 0.07575337099091661, 0.05803315592328868, 0.016395149174176397, 0.04757029477566962, 0.003661895011206188, 0.020458466118021358, 0.06408541523400815, 0.08895865070723719, 0.044381350368982365, 0.020903687691316012, 0.017851355913726073, 0.04454911213308092, 0.04714048497619168, 0.017105257138609886, 0.02918201847933233, 0.03198899527741296, 0.04103666794816813, 0.030097985760338848, 0.05386201401932105, 0.052298750322792804, 0.11092918669624675, 0.014171661328404181, 0.1213155692863849, 0.07914495714489492, 0.047087100139188195, 0.021098507680900155, 0.028030825816395304, 0.04426762461662293, 0.02773383268034987, 0.02047652855605608, 0.014767632725828839, 0.07449109557895892, 0.08056206658722893, 0.0030126182584001896, 0.04667726991277549, 0.019161841238758737, 0.06202598703244041, 0.057706951854690436, 0.059725631839565696, 0.025890690252004613, 0.02890723231699198, 0.01671713401353167, 0.01296919727352478, 0.0366779609072593, 0.04891458373036116, 0.0371376711184219, 0.06494305066524014, 0.0941321956774881, 0.0505592787428008, 0.07142994612936052, 0.06155692671816196, 0.041324387589890155, 0.028399241329621405, 0.01250639206714808, 0.020117321419679833, 0.038425698575954285, 0.06994562013255012, 0.01612433517772344, 0.05599769095199243, 0.025680289949260415, 0.025180279682841034, 0.011193330771470023, 0.041170396256230535, 0.014675790275026475, 0.07613836081638452, 0.03672375381293316, 0.06126760212223857, 0.03962041652430931, 0.0012303743137782742, 0.015386561863124372, 0.030141976444170843, 0.102088876789616, 0.02710123557687527, 0.01899539140023051, 0.043657830120214534, 0.04033231138882618, 0.048393145984699654, 0.014869032123486602, 0.02617682409172337, 0.013113788708353476, 0.02446691584472935, 0.014732573669584048, 0.03310327590893834, 0.035491271560350736, 0.056161396280531926, 0.06186158839432944, 0.05362874024637765, 0.06393721552505609, 0.015158026343992641, 0.04016462623352005, 0.06667359732091427, 0.07047969832896225, 0.03246289535215305, 0.10161128225586108, 0.06932944029329285, 0.014148243935778739, 0.07637911160746891, 0.0032659783779132754, 0.06799784924594626, 0.02949646309829287, 0.08383163791750708, 0.04074234462853882, 0.04060324221368759, 0.05066540490295138, 0.003091207866917455, 0.06520126060011887, 0.033477318337968284, 0.07945708434788451, 0.01885661265752729, 0.02032111421407711, 0.04476000464731648, 0.035846851270405516, 0.013041341688574083, 0.03410147698295694, 0.04113419860180828, 0.087387343087504, 0.0375576481793917, 0.05818898586796657, 0.03893385235700877, 0.004874269849801016, 0.008736710879020393, 0.08122895378619432, 0.05084215670884137, 0.027399460199258985, 0.02859257510863245, 0.03092127172426591, 0.02116759157469196, 0.04982339383493509, 0.013868694621769172, 0.03036678877599057, 0.019902537178788936, 0.09709211426877207, 0.04810178359489768, 0.06028792122378946, 0.0017698018388229333, 0.02462467824619624, 0.06661436340260891, 0.012161445657482312, 0.0403596262537664, 0.14611493856195482, 0.025773084264308698, 0.03375236305498308, 0.047774572120679, 0.04140098106055971, 0.03093621235400919, 0.02526272798047191, 0.12006843943269023, 0.05923486059351314, 0.06129526938762396, 0.025703893118207494, 0.036025805579077814, 0.13367924779172868, 0.010834870570819947, 0.034289992068924253, 0.012904869828132853, 0.0760743388485524, 0.1296753658642692, 0.036840850352159435, 0.06953479782227548, 0.02627067177766754, 0.06964215738398415, 0.04497478505776775, 0.07581366977143673, 0.056029525735685905, 0.10236981655320815, 0.03335721873407883, 0.03796057595360664, 0.03210193578965001, 0.03330754942350811, 0.0338512841582058, 0.005358578186602362, 0.02458301838487387, 0.10185563366018957, 0.05432012693716153, 0.056266208599892356, 0.03454353652834412, 0.0806210860009155, 0.06439142139448274, 0.009543620755956059, 0.1756781949511459, 0.08772777723929576, 0.120946008471712, 0.22511508976740224, 0.15031446402351703, 0.11384611243322013, 0.14353924370821447, 0.09174729502128978, 0.14232271140621555, 0.13535684245007654, 0.20232745205923436, 0.13009501350743155, 0.13762809396270784, 0.12889585607955534, 0.15904029741162257, 0.1430582783875927, 0.1473986720966716, 0.17362247461513167, 0.16571922047484308, 0.20458509785033044, 0.21304846951557746, 0.1679944862881976, 0.14773806436888634, 0.13630366583745326, 0.19472058201509138, 0.15327672684384933, 0.08755644167503042, 0.20791807061722203, 0.28508154134596553, 0.175122827171318, 0.09630599314527166, 0.14252529569691227, 0.11949619473589045, 0.14786705825357668, 0.11414491736720647, 0.11327143157682112, 0.2016894233923766, 0.1179363860959007, 0.1469118998295838, 0.16951022188990347, 0.11963795930627855, 0.11866675900115121, 0.16294216707108483, 0.1583927079674698, 0.21303506297690256, 0.1060398756676624, 0.17167535490326344, 0.21601612559489666, 0.24615862106363623, 0.1012058761872111, 0.22452958408863316, 0.1628598892280171, 0.11010374994047227, 0.19656585799830575, 0.09468023965675985, 0.18475670457607318, 0.13562964635991281, 0.212899879101784, 0.0874040054998571, 0.12849347605820627, 0.06630075764992545, 0.14339207821796018, 0.14654342685976338, 0.14379160839223093, 0.11558723110224932, 0.12079953246058957, 0.12221606733698039, 0.1341545287399523, 0.21269351033674133, 0.24139931515580226, 0.10691529966049618, 0.11960198381735433, 0.1563183257296201, 0.2400190851861431, 0.16782626870178408, 0.13222167358523415, 0.06461682744444379, 0.11951931526944523, 0.11733727469559639, 0.16997396555398742, 0.13968652624997402, 0.12628552639075827, 0.1474457252169809, 0.11140343342577258, 0.16121978691268354, 0.08340658169359931, 0.09152536701050498, 0.12670235483035927, 0.12838167318653676, 0.1754163614203853, 0.1834353561242742, 0.11685517556484669, 0.14736933092917168, 0.13015369584243144, 0.08767761380201386, 0.1794541963646489, 0.14936400937937921, 0.23181187800101696, 0.17119002288147328, 0.13063576432966417, 0.12709433903857587, 0.1407991770294405, 0.14699593967487737, 0.07626355490497044, 0.17528609582974067, 0.1166784237589567, 0.13160285840351738, 0.13440402825513195, 0.11322558121455294, 0.1157096442916701, 0.13781639837449597, 0.19417760953787835, 0.2607528871345905, 0.1827605399152925, 0.15420721723668038, 0.1493437846581782, 0.2019553018673774, 0.10790972775148769, 0.1610044242754098, 0.15216864194841156, 0.15669730942576163, 0.17165965010081569, 0.0839418166827771, 0.124717750436356, 0.14935207372951895, 0.12703687478337558, 0.10109726790218584, 0.06876615882520715, 0.16334227947217805, 0.12966122388118698, 0.14626958107035007, 0.1286112084504097, 0.08817794582536144, 0.19902268664971476, 0.13026041189028373, 0.07588320757232367, 0.22782347104962797, 0.14106527000906008, 0.11516934546131281, 0.1546311702939772, 0.17080768372022337, 0.12563132560781895, 0.24790681838508577, 0.1730894459591758, 0.1609512884169817, 0.14304660320762666, 0.1115818016771828, 0.13008341493625797, 0.22602094277258844, 0.12240091669223002, 0.14853295719911977, 0.1259882766152582, 0.1467827680490671, 0.21113807605879925, 0.08242073378735974, 0.11162042016944579, 0.16726202962379302, 0.10872699034911011, 0.14137437116474877, 0.19659123083035793, 0.15218535798691935, 0.17636580482846306, 0.0954732019454241, 0.1584171614940128, 0.19182032635135038, 0.23847204723185111, 0.146495929408458, 0.16143859694561652, 0.11519888581167306, 0.13636349730433958, 0.17283456850676768, 0.17568280680045006, 0.19409487204205608, 0.10555501095950605, 0.13682934004933606, 0.09113296145393003], [0.04360259135043429, 0.026945365412581353, 0.03332452593191016, 0.0716191698466578, 0.02952114645121319, 0.010880460463193877, 0.04576735281115098, 0.028822570025259932, 0.017056047480793732, 0.07617340933892035, 0.07504905273597087, 0.06914488205145444, 0.04906318563547346, 0.01992164341162049, 0.039029609517104207, 0.05318785664595423, 0.054887365249376145, 0.04733591017523601, 0.04748913925141097, 0.013892703817316122, 0.08508607624999939, 0.039354718079970735, 0.028068521172709526, 0.07747829456122653, 0.05470977457720907, 0.06975066607757922, 0.03353072998804912, 0.014914267700195554, 0.007168661048185201, 0.0730243206564938, 0.020295224272676056, 0.01737352006227499, 0.04035563110524128, 0.05534791049637622, 0.06809088296347088, 0.023671919592626156, 0.06994417222637324, 0.06627246602288177, 0.057521853520865404, 0.020389238582743753, 0.07055066105338835, 0.012429539084194169, 0.09910358536627986, 0.012448017124927813, 0.052483312395070834, 0.05293698966382973, 0.050596276959103924, 0.02312518753892472, 0.015005678268930605, 0.06643029545704204, 0.05686926535300671, 0.07607515090175214, 0.032155590672646804, 0.014936886446159935, 0.037140616726490765, 0.09173610247671606, 0.0393107024982812, 0.0419174583869115, 0.06637042568575952, 0.021859554746638865, 0.027869843930426626, 0.09889880240324045, 0.02742103131998691, 0.018577413828743082, 0.013152809396776701, 0.07012755069280825, 0.05125985082779681, 0.010250056286402529, 0.01789486396216577, 0.01736673635370549, 0.008590735697878465, 0.04930763663123212, 0.046564233639547904, 0.03672261234192598, 0.01995523828232, 0.09174560962785637, 0.04853410233232764, 0.04367023691414826, 0.05296097587673895, 0.054196790611792, 0.09243500449003712, 0.038038479434626724, 0.07079020908643162, 0.009855486531441492, 0.06118885211406216, 0.04805281142433805, 0.12768719916141805, 0.012576660524392802, 0.03819927362905395, 0.049482886904790524, 0.03286724804990715, 0.05476319771860877, 0.04598954129183004, 0.0717940447371333, 0.04519505065775687, 0.004236298639537586, 0.05757813033978305, 0.031528036342933774, 0.03919893793100792, 0.10053181840527443, 0.077067349676884, 0.07692137162291235, 0.06662752479314804, 0.005969506971943643, 0.02782645079517557, 0.02675186500944678, 0.028667552133781776, 0.0880785918824615, 0.027098891347826972, 0.019464873062867313, 0.03200723583089008, 0.09305787227687337, 0.007652719448801251, 0.03899514705183045, 0.02523028415687863, 0.02521916247543789, 0.09683752792977518, 0.07831903775372813, 0.0457015305366968, 0.03306110659914632, 0.03399943407144278, 0.07912667062614234, 0.08383739123781843, 0.0288526140784304, 0.04539522177149211, 0.03827637654819316, 0.020478888106862866, 0.05534519088424503, 0.07173561521114842, 0.033779792833111943, 0.06518572433701446, 0.03867528236080562, 0.025922544187896197, 0.08958157212022813, 0.0014201334547138803, 0.03556584638933982, 0.02326793078663609, 0.0461846677165839, 0.06008181675908066, 0.03785827640263784, 0.04896992592201118, 0.037841345859511245, 0.015936268253191825, 0.0927890979895188, 0.09044407987065854, 0.05085328413594154, 0.05661921042408194, 0.03642406404739426, 0.03195373991113757, 0.1138212298974395, 0.008939504886286394, 0.0942716696449826, 0.05371624280908897, 0.014582220295954858, 0.06924887848717552, 0.0552987429733959, 0.02191534509972459, 0.04015867373034839, 0.03154843917957718, 0.08250792225402209, 0.028441548535239794, 0.09609464480872117, 0.055644398014391624, 0.07529523509043841, 0.04949602914313155, 0.010607727416490596, 0.028279875254919453, 0.04092887554678225, 0.027077402581550905, 0.04379445807107034, 0.013690741973057871, 0.028886727973698612, 0.06893285955753058, 0.035736297122052604, 0.060912424608344035, 0.01959580323478628, 0.056072246628783406, 0.09606763254851104, 0.014442822937252782, 0.033290335427849524, 0.05161751429700563, 0.03290230423332222, 0.0633551993767821, 0.034733415250816656, 0.00591021463943405, 0.08735773378923055, 0.025285986409853065, 0.022265793935906504, 0.030444487328490907, 0.02592742033753424, 0.04463363844420641, 0.05152277220340987, 0.05276477309845148, 0.02386460219690156, 0.02354568937012265, 0.037966539948097164, 0.011831848776989408, 0.035860261639520045, 0.033772361780246424, 0.07067738731782283, 0.05798859258873328, 0.021222891631506143, 0.03935067696617015, 0.024750831859907316, 0.03324646923330522, 0.029460579539919575, 0.07955994697347765, 0.0827559432195079, 0.11644282107872349, 0.054157065122478434, 0.041546350074631554, 0.04794942019807716, 0.04150035798609738, 0.07720925214309847, 0.02882688118505382, 0.04292437754150841, 0.01259605020975634, 0.031937334138239105, 0.08410123191894063, 0.045035378782138716, 0.08169642829846951, 0.05281235481942854, 0.028726052522899646, 0.04769609024327609, 0.030382323123875166, 0.06155243744292568, 0.03205327005426009, 0.04095244041133312, 0.01539851666518277, 0.026639179221444556, 0.017808311348480564, 0.06137267108105364, 0.093457525025212, 0.05744306137785316, 0.04609184084279884, 0.01927271139838042, 0.05254932619150608, 0.05475175619545964, 0.05166651328064261, 0.04884497698156103, 0.025451072611876076, 0.06288923788815737, 0.04536805629369713, 0.06516517785888526, 0.028541917544639403, 0.009596480822731412, 0.05259382440858791, 0.028206484031773386, 0.017018120382882414, 0.006502067835460748, 0.014461268419249645, 0.0481411605142057, 0.0797225721180439, 0.12640694366587749, 0.014866593091057674, 0.0532721646220213, 0.043734059699120066, 0.028047375230779572, 0.028460771596479802, 0.08563842564340561, 0.01619366038921139, 0.05934721504848811, 0.03535291225078606, 0.05871091390989962, 0.06327865953226725, 0.07787241615475186, 0.011329021222228485, 0.03714970252927273, 0.020244497760769822, 0.020934976637363437, 0.05393695274007417, 0.03205720774619089, 0.073342714458704, 0.07450082489559728, 0.005388155883748926, 0.03575922996406594, 0.11317972319140551, 0.006761708439538076, 0.0102847361291248, 0.02017727737585383, 0.007901016205939795, 0.06773890386666022, 0.0313128805493996, 0.03974978962252217, 0.009277765263593005, 0.034436379979935386, 0.007388602976026315, 0.03149638733556194, 0.016475324105891972, 0.05679946325178589, 0.035482143622732935, 0.07759975014074195, 0.03672389170875953, 0.03911285263095652, 0.028617019059076428, 0.030876553256905852, 0.0638267724594522, 0.061834579964558926, 0.051080555609998204, 0.012060681155191795, 0.015923986906155704, 0.02817334498338882, 0.031778284709059426, 0.021274995186456272, 0.05970206697501483, 0.01839795773248038, 0.03240826562227261, 0.06157126788410449, 0.013376627729514675, 0.019410252909085924, 0.031351395619792805, 0.005282872899120013, 0.025724002926219857, 0.03281770131340431, 0.051850673156760396, 0.10482829995453359, 0.04469283405811556, 0.016044098958973924, 0.016890421186784105, 0.05046480094953891, 0.031391709081588254, 0.0198358453945407, 0.0028319333092264474, 0.026135949470523386, 0.06447809658223583, 0.11562806358861348, 0.0035524406778295677, 0.03275609252253368, 0.023638606259238817, 0.04040444622777643, 0.019286782518329642, 0.020444301152301413, 0.03358878030051147, 0.04135675097425138, 0.030082616121357972, 0.03534126388389738, 0.038460475137276996, 0.015762872870020088, 0.045443550428195346, 0.035580041998576735, 0.033364818326287696, 0.022155703270747777, 0.03749284863231644, 0.07017007623348506, 0.032453242644307115, 0.04412905080243946, 0.023602793563998515, 0.015453919186256828, 0.046129635790543216, 0.04128399560408246, 0.012508183755280991, 0.016315518164887063, 0.1329687318854755, 0.1704755846050478, 0.11704462910852126, 0.10613555238852579, 0.16504507842323474, 0.1652578516833244, 0.1645357678494146, 0.12244002548076453, 0.06448046379392186, 0.1747482867851373, 0.22911435984555753, 0.14733482632906209, 0.20604322364013042, 0.1170271163385722, 0.14008142925318212, 0.17296756137042277, 0.1701792771176946, 0.13422290974807355, 0.11428153382674341, 0.11328400307965857, 0.1435369607662001, 0.09092114580374572, 0.10758155100648442, 0.19671273237514883, 0.1945674563607862, 0.12480924431715282, 0.09600637615808556, 0.08053081786079754, 0.15747537896517785, 0.2171593586043004, 0.08924987903165241, 0.2237238740969089, 0.2076123249266417, 0.15252927017788734, 0.12664373378239333, 0.08995605888025415, 0.11562113049289874, 0.20864634444156002, 0.1334671333672539, 0.06672570662152383, 0.1905131198826336, 0.1717980821887332, 0.2318046001657363, 0.18368902315776195, 0.17116428232721745, 0.10687571589744861, 0.208238065543194, 0.10322415014548648, 0.08514405378410894, 0.2068338263779879, 0.08937315790042763, 0.15273070533669766, 0.1359298149304044, 0.12617495692064687, 0.1040473192810051, 0.11313296118450743, 0.20507570055703964, 0.12462569731137446, 0.14850761501058457, 0.24141849799742623, 0.11828496376232756, 0.20101076142201502, 0.1138645445086783, 0.11808808682666672, 0.16043091553353495, 0.21739992553428297, 0.16235750408903246, 0.1404901678043027, 0.11560223110380674, 0.09117989200017146, 0.08865716446551586, 0.13760604595224704, 0.13104546815156937, 0.1304514435750823, 0.08661729448865499, 0.24019058162887252, 0.16566197838514082, 0.18540905908711497, 0.09796918535064306, 0.1661428364534532, 0.12994994709808982, 0.14033765502033696, 0.14950855484893247, 0.2440671397433166, 0.0985880081932391, 0.1468827118796687, 0.14345770130955404, 0.10597908659087074, 0.15536045535437523, 0.17280268392735915, 0.10518792460882857, 0.10486029178625154, 0.11856963437411094, 0.1490838969907453, 0.15555974546699755, 0.14481641953029942, 0.20085519960811063, 0.1814398809426254, 0.21924471122122582, 0.2026070281863213, 0.2897586306977657, 0.14691706326219345, 0.10206054685817612, 0.16319885249099425, 0.15401986277391835, 0.14959798795321297, 0.11346719768499175, 0.2068221971632973, 0.11122502686996615, 0.13974566823772847, 0.09315567872216625, 0.21166805568481648, 0.11799541317046651, 0.18037625979031288, 0.11206508824421514, 0.18002651000936187, 0.1586758234207669, 0.13200865517700874, 0.23289172489556575, 0.10976808851644879, 0.2525598066107881, 0.17907041695810136, 0.20582369348454863, 0.11815402401430954, 0.19904252832695363, 0.19737697657077544, 0.17206086566851986, 0.10409656341277784, 0.17661613171860097, 0.10040262533772377, 0.18060320567700172, 0.09541408294030736, 0.11900978253012705, 0.13959323206255514, 0.11718347488391785, 0.22375266368110336, 0.11380148015075153, 0.1270283941900538, 0.19010862545861354, 0.16871788779333716, 0.1274146710432345, 0.11704704994636199, 0.10012913194875564, 0.17747025846713976, 0.13349302713909458, 0.19596601115359416, 0.12827756183762706, 0.10742744475963617, 0.19403248184150268, 0.2110650832013738, 0.12176789057951783, 0.23079552447363255, 0.20984809124662032, 0.13402368092248518, 0.20040227310551753, 0.13628865051413738, 0.15749235547357993, 0.1833041865498789, 0.12425162423882755, 0.17528693852645738, 0.16531383738883082, 0.1940356228019922, 0.17123346006677997, 0.14215403416704747, 0.17560996716060948, 0.10449301391359299, 0.12969650989097933, 0.14802490300949545, 0.12730756429054085, 0.20228006186023836, 0.09162629143364968, 0.09151003759114013, 0.14661701726576976, 0.1585034229942868, 0.16774595204380252, 0.12014834240319268], [0.09769512505661096, 0.04541778306086217, 0.020027884484959707, 0.02705147242053382, 0.01943771524595157, 0.05409485495258724, 0.021236091326441497, 0.032215586848436825, 0.05154989937680864, 0.026333715068176392, 0.06339595525435383, 0.01622050602529799, 0.06595070143380473, 0.01395329275363756, 0.009240435714262628, 0.027898384536045696, 0.033035649497422485, 0.09656928990396763, 0.032639597362327966, 0.032438246473189325, 0.039880871096806186, 0.05774993704812181, 0.023553932476187908, 0.07995011555331369, 0.020039871845754887, 0.06715882209039505, 0.05044638419583921, 0.051576455814703825, 0.0391642494697965, 0.03337637859306509, 0.05158657966662319, 0.029600536142806375, 0.026288146243220376, 0.030996388560461424, 0.008425833356957282, 0.04843639547846491, 0.04672164938622906, 0.02638566349032185, 0.02917726681898198, 0.01493114940521698, 0.030144050627225832, 0.024748420598165646, 0.028025156765755628, 0.026069188738361965, 0.014882171488997918, 0.06944977738443883, 0.02331556804898766, 0.024605196630281788, 0.05723977994714534, 0.07112974691535197, 0.004376532949296939, 0.013420329215155255, 0.04920665092105347, 0.032439204083094676, 0.03222079624632194, 0.03291351209965444, 0.04605914421019055, 0.021854496651118802, 0.029879794343404716, 0.05155540754898422, 0.01809662853878352, 0.03476778195509988, 0.0082217360426101, 0.048849301547893596, 0.01787592818389737, 0.029891201392597253, 0.0425019106947847, 0.10472401240540129, 0.025191430092578935, 0.04315444906692832, 0.045844065025448806, 0.008354604416977494, 0.07750735227619449, 0.02898387749859643, 0.06321492484740673, 0.014485035339490542, 0.06031237858077211, 0.018369915084012093, 0.052281490361858765, 0.03929561439661249, 0.0513167979736482, 0.027912808056440086, 0.04298561477973577, 0.04375450275537949, 0.021479423833830703, 0.038540719016905756, 0.014267004801020508, 0.037015629481644406, 0.028058629062387253, 0.04579136200669793, 0.07186263258899413, 0.05934226995093688, 0.033568337244252046, 0.027415990461445144, 0.08352609140978706, 0.04247105267319468, 0.03602679766293976, 0.013456214688748363, 0.061072762980456316, 0.051742777333504734, 0.01961963048445121, 0.003594892721946141, 0.04336893453352875, 0.03564966023869572, 0.014245134906002111, 0.055531587737101706, 0.02167782145402124, 0.025144495715897892, 0.026596238078068823, 0.045020853755094355, 0.029484238250241167, 0.03408393356949091, 0.03357692892032285, 0.06681469539480825, 0.03384607476032069, 0.02378948919114567, 0.04577919653046035, 0.04428603370944339, 0.027080007280493458, 0.029391158567441088, 0.053177640863483956, 0.07151222397242823, 0.04276383232565657, 0.03747788693515524, 0.03743330444840174, 0.04458904446613404, 0.07616621577331135, 0.02780340303997359, 0.052047638192532525, 0.006014265180114778, 0.021893743335479693, 0.0461365956993353, 0.07919434683337327, 0.01019935179952412, 0.029930980508065516, 0.046747845762799826, 0.026619509913988655, 0.019995628352907878, 0.08645839253140074, 0.03693857252778065, 0.06261333132222777, 0.04119974508460972, 0.005617083065331944, 0.06255475623953728, 0.0375015935259721, 0.028460938220603332, 0.07600373618545071, 0.047612701572718165, 0.045140459232272646, 0.06666339302976286, 0.012572740069440296, 0.03931318079271624, 0.008893485027064961, 0.0865612781396316, 0.03419262995462745, 0.022990817632225734, 0.04248638209255953, 0.0721740932954896, 0.03588680275565675, 0.04762491301423119, 0.028150605578576366, 0.01174968297428061, 0.023652211980774038, 0.013408084257295536, 0.02251579332345676, 0.09570204773016515, 0.06682972603988263, 0.03305504301322564, 0.0300569387693559, 0.06558095675803001, 0.06903569153960674, 0.08832223082502043, 0.025778002548782576, 0.037478361909668294, 0.03509612723944649, 0.026070674948935068, 0.09868584528204896, 0.05201982537044152, 0.02078260366444386, 0.03403548616915941, 0.0253337960419876, 0.0076966852347757075, 0.041491934849369916, 0.043382260632971605, 0.009201789451312394, 0.017581340563934178, 0.030059983968854915, 0.05615531737285276, 0.06296302364658445, 0.03602749480295085, 0.03636803237661239, 0.01930751477278048, 0.0224471460997818, 0.04371372389517004, 0.012539435354542109, 0.05945361316985181, 0.013161878920190278, 0.07433812314223859, 0.0326202574726795, 0.03928418819522185, 0.028361032694397915, 0.0032820813066791747, 0.044348308996808146, 0.056415143753251726, 0.02889797989008648, 0.05020738391566181, 0.0622029188689926, 0.07785163985024537, 0.04710968441119598, 0.014912597628520622, 0.048970990784225926, 0.030871506652704654, 0.08438928863934933, 0.019483780112838554, 0.0483897713673932, 0.047842914824404066, 0.04227674979295942, 0.02600466115249982, 0.011549660290080694, 0.06377286285222059, 0.061819522506407196, 0.03260511957529572, 0.008277293696488825, 0.045701760363074086, 0.040923022635040746, 0.05236732668333477, 0.04164249410912876, 0.0012391461402125237, 0.06078823409493893, 0.042773327985478025, 0.07367801582140308, 0.05181033096666779, 0.03303953356319859, 0.07150719077476571, 0.00675579424076263, 0.03905142770118771, 0.05059222052354486, 0.07130236184645085, 0.009374652403376756, 0.03691095888854996, 0.035475651027574655, 0.01761931362712095, 0.02005903361996095, 0.05283495058275519, 0.032200173159400304, 0.07539222182165231, 0.03359899225254213, 0.016906244732860117, 0.05544211632842499, 0.017640702801966862, 0.058747536743119846, 0.07730587115210873, 0.039821924461472424, 0.025179327818595117, 0.024820888685362957, 0.10749695191700613, 0.06660853347350514, 0.04748412137550693, 0.03462126763958124, 0.02229948839803617, 0.026010006530991486, 0.032504405826330185, 0.026827301687350678, 0.016506902250130812, 0.021974923757595882, 0.06384507429996325, 0.07058039292572968, 0.04870172620059983, 0.0024342424641813965, 0.058846886855580156, 0.02887722082255829, 0.013759500279481855, 0.01497913044952457, 0.07154339609006721, 0.06640261670033779, 0.013754231509782616, 0.01581344041868203, 0.042745810107237873, 0.026323374796418414, 0.013838301040983249, 0.057175401748428424, 0.12294903728029422, 0.021378880539428324, 0.04686422984025652, 0.0080634527013547, 0.004681809889828606, 0.018700796119388075, 0.026822640042331432, 0.0496177566838601, 0.049233238002465624, 0.020374192615910884, 0.03578334641192229, 0.10018425963578687, 0.044325353172157085, 0.05939652429773443, 0.020689227122573123, 0.023804906710621812, 0.02628172642641491, 0.014077128951377688, 0.0443923284089373, 0.06136269278583988, 0.012990525161336749, 0.03371154589037742, 0.005683705901666995, 0.08951807109218451, 0.03259937774630324, 0.012546754367048702, 0.030025395099073652, 0.07782253617000195, 0.07373333503041538, 0.07943021764437999, 0.016306430446885286, 0.003240067369094299, 0.023189563822421818, 0.07017048226008493, 0.018250311522053617, 0.015091805703817837, 0.02897210464242005, 0.03167093855388944, 0.03205989096914569, 0.002845634312947251, 0.03746549929341963, 0.06294780914040823, 0.0424815978734724, 0.03204088241252447, 0.07513040361265022, 0.12014436640686567, 0.03842495547066774, 0.02279498640658154, 0.05311769831384863, 0.05157243385310135, 0.0459080831628413, 0.06744217503094865, 0.06436172016565839, 0.10336519459322577, 0.02604991779662669, 0.03462936135850126, 0.02220080286685017, 0.042676869854931875, 0.040234512604412534, 0.019840208265269478, 0.0025909505371424944, 0.0322938657125398, 0.027338964151098367, 0.0453465560361022, 0.07178735678955432, 0.06047697257130377, 0.030782743875357895, 0.05679159552880353, 0.05589274456724525, 0.02809814004708202, 0.0385902849056067, 0.2572222943267515, 0.20571443402478773, 0.11161223835041446, 0.07668622093455446, 0.14436375349760056, 0.06968273706133328, 0.18328998327976276, 0.1407513731429654, 0.12322682076163831, 0.09193245081170913, 0.2780589359181543, 0.18508796099453204, 0.11626406212247188, 0.10445339950702845, 0.13405476877045247, 0.10217285534787564, 0.16263329574177343, 0.11145662291035538, 0.1091882212448024, 0.12639650188746954, 0.10037622594785306, 0.20832359159906066, 0.1002000333861478, 0.11324150818249873, 0.16812551796676653, 0.10349719154257929, 0.09812545962631704, 0.1553664768054601, 0.12027041851392678, 0.12794298825845604, 0.1378279816239111, 0.1371954381465912, 0.153331900496156, 0.12051080158280751, 0.11571472345460808, 0.15704888249597243, 0.22365123363992861, 0.21596003263708086, 0.15452237048697087, 0.1280131389296824, 0.1702751913258145, 0.17098175421837838, 0.1095537524369936, 0.21043520571003038, 0.15691941363676903, 0.1262797883922054, 0.15720340243029982, 0.13539887003360257, 0.22081194325320183, 0.18844662835040402, 0.10780249842472615, 0.2760467293762392, 0.14787792138034297, 0.07802253108351462, 0.16538856160496512, 0.14954443840730577, 0.16356738674784863, 0.17728305722196258, 0.16864065080881122, 0.12625918828792151, 0.14245348261489024, 0.09939702002391701, 0.07719544723870293, 0.1285661778022205, 0.15367512320799215, 0.08738941152489955, 0.21798221364377007, 0.22019588598801246, 0.0797367830490393, 0.12191466536493072, 0.17201450202734242, 0.12879620336236494, 0.18540479963825596, 0.11832116141674981, 0.12729447950879413, 0.16163652342173362, 0.14795322782329975, 0.08685367857857097, 0.10776572620436069, 0.16073427102979154, 0.1586356497700176, 0.11593603093417422, 0.12799320532189262, 0.10847626509325159, 0.14566242574684082, 0.1166876934228405, 0.1440705869707369, 0.13962985106533574, 0.09258351829503814, 0.1524731006112791, 0.1506193210521052, 0.1655497924695092, 0.07173542368916735, 0.11825623546516704, 0.13304330288402497, 0.12779213022440672, 0.15019455594160866, 0.0903272744448435, 0.1525588105282476, 0.12460268403012907, 0.052821498078804825, 0.10511955892246579, 0.11067251659809582, 0.13970494300367373, 0.1546171355632044, 0.20785509818984618, 0.06812960870804326, 0.12873306239564575, 0.14642328895147771, 0.08827758322079336, 0.14966859061631466, 0.11079708249458384, 0.10271884621151033, 0.20261867272277034, 0.1154276549876217, 0.15959503699935254, 0.12430540361111203, 0.2562192554074911, 0.19627022466832594, 0.13941712377052154, 0.15587226337482854, 0.1326404938534383, 0.14540658302364812, 0.18384545831190002, 0.17400774023225232, 0.1751104931557371, 0.22620075893017555, 0.15704764143353508, 0.19348414674881967, 0.15575333588546322, 0.10924183207774356, 0.08986920749227847, 0.19280114872080667, 0.1303204731835473, 0.1765464790045254, 0.21768651902675631, 0.07512935407219395, 0.12682251572128267, 0.17660206634431116, 0.18010486548225726, 0.14740086310813505, 0.1026341168870849, 0.1300087213636406, 0.19945774798191365, 0.1369201061466048, 0.35830584925509273, 0.15366297305351304, 0.11324576763135773, 0.1625470802067749, 0.16409042561727186, 0.2326671232379252, 0.14356715995217526, 0.15671312148051877, 0.11864886318724002, 0.15271952045300316, 0.10121101663718302, 0.21853393484507838, 0.22745587142004123, 0.16221951633211107, 0.09874341678955863, 0.12735314652203553, 0.1411608471384933, 0.13979564781390852, 0.2247130927900153, 0.18535710300409025, 0.19533326849341395, 0.22388259219306134, 0.08117375715124993, 0.17268417012547294, 0.18132743455709951, 0.15793205929859994, 0.13358291989612964, 0.10728138243599285, 0.1037426920787942, 0.08130954623582863, 0.13262184727336132], [0.04551843935323339, 0.087085489123579, 0.045167685997101574, 0.05820417739150505, 0.030287598267257698, 0.019025669110217885, 0.011983976601773213, 0.04018462495878339, 0.05079355992136463, 0.05179330466255065, 0.008029298586470467, 0.009893795715705042, 0.03385072874446069, 0.011954605748366204, 0.02308296651819781, 0.010663013109156202, 0.062312955907996626, 0.02419376911054696, 0.047778505982170184, 0.04473446710636059, 0.021131367107192357, 0.07097376375308923, 0.03486402558102723, 0.019998495436964497, 0.024994252467407815, 0.07367908068361782, 0.035111498793647174, 0.052079917307222084, 0.05357958038427657, 0.1069520642199824, 0.034311515309156916, 0.03065757851506914, 0.06429350769688046, 0.09234667455236759, 0.03613523357818204, 0.015713089603870627, 0.07562150427651021, 0.01978602286638512, 0.012985529310460533, 0.014516563688014305, 0.027188324452107473, 0.0315941171720624, 0.02601293490208205, 0.030394720341709834, 0.025511940212679968, 0.052023253613902684, 0.010402456072399454, 0.07706660657159745, 0.008693195169701452, 0.09034008343493746, 0.12876477843571094, 0.07287286507386355, 0.052656138000348886, 0.04355425886329144, 0.07702565917204465, 0.041942547766431686, 0.028819746991258957, 0.021119747468600833, 0.03232905596134163, 0.026651254682351026, 0.044841236780367555, 0.04527427564044634, 0.04639833729954497, 0.02396001461743107, 0.03526317271133585, 0.01186494664814804, 0.0524112158605168, 0.039546243891480475, 0.02021703733912399, 0.04907926199056449, 0.08070982962606416, 0.067957675595197, 0.04031136654497635, 0.01617375167927915, 0.048127194731346065, 0.023029685103064104, 0.03828278104324014, 0.027137009967719356, 0.008550590775426357, 0.033555604862950505, 0.0198926335771478, 0.07698120308979865, 0.10056596294405962, 0.00905926358104954, 0.027440489953263637, 0.03510954143900064, 0.020347094170809276, 0.016651003388687968, 0.05922756743647399, 0.041200767811988635, 0.02469094293642669, 0.07070283675866743, 0.03075041879539288, 0.050648960825656696, 0.024693769800867287, 0.06729848757987061, 0.10665084610903457, 0.008731727477072949, 0.011158728495150084, 0.03769499625289633, 0.04474355290914255, 0.033412511130013776, 0.07829177268450299, 0.02811308642248473, 0.019475092675777215, 0.0606066789177637, 0.03709901815220233, 0.0022132203523670476, 0.048076636758783174, 0.09987560281109426, 0.03267153939833084, 0.03639375760910973, 0.032232245430350304, 0.026237959823300763, 0.07462409610349326, 0.0699338223785162, 0.07160315860904033, 0.02390841476529116, 0.027573099772956584, 0.038497722332155516, 0.01602012806782319, 0.05541046157539372, 0.04060364824028746, 0.06382406433863987, 0.06512220798721237, 0.035995617884421544, 0.06988378917618145, 0.04299400344250664, 0.024770928261381005, 0.0846313264581465, 0.03356721109500335, 0.011327062909972044, 0.046933553136524656, 0.031827419673302965, 0.02605429790433376, 0.030202780842720985, 0.017886446571097742, 0.05485330498026264, 0.03354574531136501, 0.0035602825453444837, 0.038289595395326614, 0.01754281400222211, 0.024629203910608927, 0.0466409037190099, 0.044707255663290146, 0.05298890744245822, 0.1219467338054411, 0.04690131615667094, 0.014920670280022728, 0.029519937947512637, 0.013401065934299222, 0.07624818718120938, 0.07089564576745033, 0.013467651423847964, 0.04984498985352055, 0.07535405532126466, 0.006643525970679138, 0.04023369672077318, 0.02793573515279399, 0.044593089410374244, 0.06099261103137847, 0.002821861407644446, 0.09118438893628698, 0.037363080998822566, 0.03718865043934315, 0.026693862577479695, 0.029056581157830455, 0.0849487856330891, 0.015304661318359357, 0.050298008286664565, 0.06116322647299498, 0.03810353562115662, 0.03351721619706481, 0.018567374246495388, 0.03580018502449797, 0.03383827598525151, 0.08521238116607552, 0.05842827343111558, 0.08655337211225303, 0.026903552333674124, 0.029725406559244282, 0.022230781802547075, 0.03923938737340993, 0.0504759130548806, 0.0420346315349302, 0.05985414308886375, 0.03758379092980777, 0.06857104389177215, 0.033240646965080695, 0.11007800938621645, 0.04269844289087961, 0.019122236408293247, 0.045388610432705576, 0.035716505240528815, 0.025979851395071998, 0.036807230583602385, 0.026200094012423392, 0.06493743524075517, 0.09354927937590307, 0.0016493108118846714, 0.07034294397359894, 0.07873552145376321, 0.04858242332815163, 0.03728575974462494, 0.12311832738980172, 0.08214275112315532, 0.03961103194723687, 0.035650874488055706, 0.12646588647077162, 0.01712182187475264, 0.042229409389678514, 0.029065837415175575, 0.03105351573697502, 0.05029741839896287, 0.02144900631279715, 0.026679766559672934, 0.027096315377181577, 0.006644506084417264, 0.02675557479022011, 0.03581503563891015, 0.027760446574839375, 0.0632151699955425, 0.05306875295636635, 0.02167136524803937, 0.048195702143974846, 0.023175320332689632, 0.04315785049731213, 0.024082075406406677, 0.04725173626455569, 0.019805931576317357, 0.06564521621311865, 0.08749133952322506, 0.04368606046022427, 0.03599522334914054, 0.009023959376668979, 0.03290113977967732, 0.011576012757066037, 0.02246028450768321, 0.03727347935519872, 0.09352720838280455, 0.060256611210324114, 0.02710983874426494, 0.04366911842577881, 0.04117279794187315, 0.02026846482148094, 0.06416560931792183, 0.026072193718244954, 0.023206957848742608, 0.02099912309448325, 0.05527552667885058, 0.0354577437223446, 0.04874837712474889, 0.04573769754760208, 0.04622692895692684, 0.02826161746446404, 0.015164879958085237, 0.014446745307425098, 0.04717330418286785, 0.21149511899678938, 0.0362009102959306, 0.04077129509119738, 0.019795734946045185, 0.030168996365260214, 0.016612723890331485, 0.002981823439063925, 0.041485809976415294, 0.02267533113368817, 0.03689179519912408, 0.04212310319886573, 0.032689036846521406, 0.05595633752583977, 0.02533587980114164, 0.03560590129646082, 0.062129067993091966, 0.03319491534644077, 0.020650805897950646, 0.04333621874872235, 0.020897932455784852, 0.029041226840608066, 0.02742324339886827, 0.014143787219279237, 0.0402679025465923, 0.02268846954158958, 0.058290247369797966, 0.04196306360104392, 0.02389319834389514, 0.009738147716909167, 0.05415539888124313, 0.046275299748465906, 0.052217161958856936, 0.03699910113467805, 0.012820570470554935, 0.020533180758056623, 0.04006058383252352, 0.05870890292909838, 0.016568304197261893, 0.0053507123788398125, 0.026192513572412635, 0.06560675093844053, 0.04872930919631355, 0.08460400776276666, 0.02205073773380249, 0.004048404563593889, 0.029867619291068088, 0.05170974362220976, 0.07525964264547633, 0.0419493506271993, 0.08484524885012258, 0.030592378687053442, 0.010119745688092326, 0.015932095946834212, 0.013333338016133397, 0.06354839142952716, 0.03578848686189421, 0.036707156518053626, 0.02018844310735022, 0.022049739904281114, 0.0224550923467764, 0.015008155605755748, 0.020240433664331516, 0.08905320127885188, 0.06196800949833086, 0.056498317919190855, 0.033629352316981366, 0.03661456713152509, 0.08404887747019531, 0.01896228682580254, 0.08918630139481637, 0.09721890948111973, 0.06797127365585297, 0.04470301153618963, 0.055929436348378665, 0.02702104149296159, 0.03622743609030882, 0.05335295625451592, 0.06248284739652469, 0.02032015468895195, 0.07086798999338381, 0.023015047078050917, 0.045120521794043245, 0.01428074458794248, 0.036850384316377105, 0.03908277601904927, 0.09614508403765579, 0.03680991572177699, 0.030935791005650838, 0.06970302306956823, 0.02642996252454337, 0.01577897891101818, 0.02745839534327388, 0.023315585285965956, 0.018203949796095974, 0.14365306905200406, 0.16531388335410627, 0.16156507806191522, 0.07609551351877951, 0.18878359978477802, 0.09251301522336661, 0.20880477142430123, 0.10855566244572402, 0.17665362406161525, 0.12364653735271386, 0.09338875331224934, 0.12049040066138392, 0.14984639962354016, 0.13833608177881088, 0.17982338945711815, 0.08961097457476201, 0.1255834987387061, 0.11773314296958909, 0.09109569127641379, 0.16744762208432923, 0.11348506285538597, 0.2032875747329766, 0.1008700002585688, 0.09872374365166312, 0.10951132648774695, 0.20501280473845623, 0.12503781431024114, 0.1664963247434747, 0.1912156378309573, 0.2268182257971456, 0.15308931109405335, 0.10564868053000782, 0.27634786321751537, 0.19488827866171637, 0.11230359439768138, 0.09142544616254107, 0.16466823977328118, 0.1155487658275712, 0.08382076712986154, 0.14393797715104398, 0.12058682048753386, 0.07284784464225655, 0.1380747998313558, 0.15366320287989033, 0.14428925910784354, 0.1453369609530895, 0.08730374757320651, 0.1597934231282242, 0.12045371271069012, 0.1720785163342953, 0.24967128741404704, 0.19012060707374928, 0.08720073939090775, 0.13648853817534062, 0.10807987587947039, 0.22080011485565096, 0.0952474664776556, 0.12113790583586502, 0.15799319311495752, 0.1594887193172209, 0.21236970029290647, 0.11543252730682013, 0.15504401507637194, 0.2140368914772426, 0.1553242960043492, 0.14534574032070177, 0.16412450120814387, 0.1356856780306947, 0.14553448906348598, 0.15217769710767656, 0.20284296794524118, 0.15801937800020943, 0.12794635138444363, 0.07917789126475973, 0.14308366654140336, 0.10190893039708177, 0.163898091583002, 0.10916548375520976, 0.14164522921125736, 0.12154802334524932, 0.18860723102285018, 0.23435686805075218, 0.3196124948801533, 0.15923557322352164, 0.09076565293775452, 0.11707427671119092, 0.1345462141738784, 0.095718449672624, 0.08933146739558828, 0.17651223487431006, 0.07917808278674081, 0.22727996231086794, 0.1417379411718538, 0.12902037601076788, 0.15014954061517793, 0.11732122515358272, 0.17994866015449648, 0.1452368026178691, 0.13258026402083137, 0.09433130192900858, 0.13079786853444192, 0.18377058087818085, 0.16183699330975934, 0.13381053994019187, 0.21221927126809476, 0.13358960018282937, 0.14875527591474597, 0.12577369538766722, 0.14148300243241174, 0.17474981896098585, 0.2129177902374537, 0.10707874451914143, 0.13164494727407733, 0.12449063601032381, 0.1866726291876647, 0.11232605609562128, 0.17923042208196657, 0.24735083773491845, 0.18671853317608758, 0.08472481216754645, 0.1467852961392172, 0.14633891202749746, 0.1981816140394057, 0.17657145347085693, 0.24744633825555926, 0.17626098867866302, 0.13550144920666374, 0.13735519812232064, 0.19592327876917778, 0.1407345498521482, 0.19096077570030767, 0.14060650591648396, 0.16167928644966695, 0.1476962819334961, 0.13209569808696547, 0.156744301259037, 0.17251593721730096, 0.10086834550865235, 0.11242701882316221, 0.2418352804717518, 0.16660432781903975, 0.1314375825947331, 0.18896211359289386, 0.1155204512178898, 0.16130303002653584, 0.1025889253604316, 0.18868308904911243, 0.18197981971165827, 0.13239110159056802, 0.22684096328673825, 0.15973949053835484, 0.16815395515051582, 0.16066670207487, 0.2254135576227019, 0.1415206173494939, 0.314456386071059, 0.1878125220537186, 0.19243339587363506, 0.13936225655338458, 0.1813618319048997, 0.11835248675197364, 0.12037400126216874, 0.14371386578967496, 0.0697279132662281, 0.10374598625686862, 0.14092913618491543, 0.11680765513090358, 0.17568905807791219, 0.14521457074630648, 0.11059128063460512, 0.1808215100919047, 0.0707373030543808, 0.10715219702932144, 0.13341998831639368, 0.11668536451555069, 0.11405411296554151], [0.0018419241091431752, 0.04013397888610921, 0.046409870753245014, 0.061253042621237624, 0.04174763201585701, 0.06235856112212904, 0.023433560911085338, 0.02096984129879744, 0.05078644679498769, 0.015164745892698487, 0.012493076501414182, 0.07139564071211123, 0.04264758231358663, 0.04585294015405159, 0.03052669047798601, 0.08301268992645126, 0.016200696906795906, 0.11488631427768739, 0.04650309982319032, 0.016347615333694606, 0.01963001289104502, 0.01608921196161499, 0.0628409015705749, 0.008311833728164917, 0.05366571931048267, 0.03713955569471564, 0.014410742047813632, 0.041898260223529035, 0.0876491459747476, 0.02888443162514558, 0.008880079445999958, 0.04556107214621959, 0.03827673660951757, 0.07269231347186912, 0.05936356719523188, 0.02521910310362376, 0.06268355094136731, 0.03442630975417072, 0.019385048616377097, 0.034693666778865366, 0.051429221376536355, 0.05849394631842452, 0.04516690841785843, 0.023803933778957977, 0.01090079052148447, 0.033496102813871644, 0.03427218435512435, 0.03809985073824083, 0.050589297898113735, 0.026528948745239648, 0.14483616927698736, 0.023667443723928545, 0.014954846419934786, 0.01257306661441802, 0.07363925943331373, 0.03768374242128865, 0.04035406828587575, 0.03196050638272878, 0.03704711569533233, 0.015558521789047989, 0.0456528686317465, 0.04054020083839855, 0.013847506545003385, 0.10956767991545702, 0.03787812957119557, 0.04283497508074488, 0.009741440937373667, 0.024987685178676923, 0.0335606150779753, 0.027326503731009942, 0.045717767770251924, 0.11999372287743515, 0.0445340738271273, 0.029464025020359025, 0.02563367541428776, 0.005999460530978057, 0.010667630704119803, 0.02045248871699216, 0.05344010258634245, 0.040366655110471675, 0.030589228150464838, 0.016471055080933918, 0.03932502834246524, 0.024976936965099266, 0.02437186157030444, 0.04917121552411587, 0.05040404251626423, 0.05387816698320451, 0.024343738482604106, 0.02452279046748675, 0.009551357286381386, 0.05585654308238337, 0.05140139706312649, 0.03183761438835533, 0.011646986015201097, 0.01925643011476965, 0.07171116934548463, 0.007798029569863914, 0.012728338272521093, 0.07956860376702202, 0.03666220247865685, 0.056078386823496515, 0.020942518772977977, 0.06837334724203234, 0.059830187519471494, 0.0939175914672594, 0.06905941728262172, 0.030125264236102664, 0.0641528424626637, 0.04172641138035444, 0.06658522907884852, 0.01429515757462791, 0.02454557392235485, 0.02182600201077519, 0.011049559050720307, 0.013655191662931635, 0.036898789581872767, 0.047138485486709306, 0.0779129422059463, 0.042148510504874497, 0.07261942786675307, 0.08593739911673531, 0.044284968847228635, 0.022286091435460315, 0.00875112482331573, 0.04553851851772878, 0.10057271217867252, 0.006976987285945084, 0.06503723351465118, 0.07591392769808732, 0.03466200053451523, 0.03561360431053946, 0.021177585191664197, 0.02799110224230155, 0.04139965955889033, 0.08550336434235496, 0.034254020410439665, 0.02903269262113158, 0.03977123625396241, 0.025526871266324195, 0.03920550713495862, 0.06434515734473545, 0.08379723290882765, 0.0421470970726542, 0.05763001747489457, 0.026640728634271412, 0.0035697458858316346, 0.07423286266144245, 0.05314034004245074, 0.012873533959200066, 0.02496407051841098, 0.0317179131501865, 0.027221900170608878, 0.012279377232546048, 0.011378080535289502, 0.05134353061176596, 0.04285774321385449, 0.04866829029314461, 0.01894830380596461, 0.04481758381570539, 0.01017772130698206, 0.04587832447742263, 0.021748491149816303, 0.026627957948573658, 0.02774090175667117, 0.04805217174092128, 0.03736855852748117, 0.04180688508636048, 0.025292220450336897, 0.012205574237140677, 0.03095248789196053, 0.03240483737881145, 0.036139546653195735, 0.04888754465707368, 0.029827051105037816, 0.06233061423465129, 0.04444922958951324, 0.04015162955188463, 0.08097176274825489, 0.012390020438620161, 0.025013483189527067, 0.036451662364866466, 0.07195673882961273, 0.02515535692744438, 0.04918950204286845, 0.0422912786504434, 0.006621540204862194, 0.044463781429634947, 0.023642714405732772, 0.051281879686059496, 0.01848022791466886, 0.07014273455546749, 0.01975188407325937, 0.059887839466213226, 0.05725352356450693, 0.02279895091158969, 0.05144974104158821, 0.027253085694786523, 0.047187802396834864, 0.050496765968179515, 0.04905303880091637, 0.025284339320815863, 0.06326198179815566, 0.05952689331024886, 0.06871950407061847, 0.02755407397935708, 0.024045483216703422, 0.041890166504609014, 0.05852706046895154, 0.03846566921340362, 0.0866979252426855, 0.037476726311949954, 0.013981387113040734, 0.023516388422238733, 0.055749156707597364, 0.014171074313532202, 0.04298427412586828, 0.06745319903617905, 0.03000116756846828, 0.08037383878423322, 0.01409222950197516, 0.021154148646840648, 0.09727904738317575, 0.049608130789091515, 0.04124807757175258, 0.04231549468972991, 0.024850023009123343, 0.058486963426994706, 0.052720129324664036, 0.04115117894064996, 0.05056107521898324, 0.023563780536454533, 0.0620440092508591, 0.048273866094889185, 0.08723286911845209, 0.008383452415376181, 0.04156531841163674, 0.12242179258816666, 0.051924137158259276, 0.1349162959283398, 0.034791607289545, 0.030915334542852738, 0.03918171627447009, 0.03526403072981104, 0.014038474069938306, 0.03835979969270768, 0.02252228400339523, 0.05634930998747868, 0.024845635240537026, 0.022697467244260257, 0.04293314158736218, 0.055880452686500166, 0.0667001805718868, 0.030170913500290726, 0.01185366791868282, 0.005331360519067535, 0.04077154406977277, 0.028351385732211416, 0.02017726779975478, 0.009974154508522442, 0.07758644319349721, 0.044840987801792166, 0.03533572123776521, 0.06243956725924246, 0.018854142023971485, 0.07157656003630931, 0.0289099749117609, 0.047621783545060505, 0.04434890654538909, 0.018741222579152356, 0.04209147908935144, 0.06499434791264996, 0.03401756354217087, 0.029102222761139277, 0.04236603351009469, 0.05274845925610393, 0.049025409839927196, 0.004523771217904024, 0.05568393964260336, 0.05267618269088769, 0.03432561132696367, 0.06299705327218098, 0.04434540935401474, 0.03477254319154928, 0.038800909289068757, 0.03567867198838823, 0.043568427659451, 0.03200792722524174, 0.0451990113323254, 0.035371110669427344, 0.00689045143043322, 0.0828487930759307, 0.03085863254513712, 0.017725855389970447, 0.042315594281160065, 0.03390347772848702, 0.10164089921501376, 0.03665721524626978, 0.0300484734977926, 0.07210589614847014, 0.01489889327316515, 0.03539937165295405, 0.08747371950096662, 0.043765281612474116, 0.05990238747589531, 0.0640538179375712, 0.04324485893331228, 0.07454331979275712, 0.0306777591862145, 0.022274885484347903, 0.07480948172028988, 0.06200886496733274, 0.05335205993164451, 0.04279794239048516, 0.08304881863296033, 0.02332548314194766, 0.03937838636639138, 0.04856289574696172, 0.06692716476297186, 0.0355099679361428, 0.04227948472684911, 0.026866628810943618, 0.03757388924338645, 0.036962160374969244, 0.042419690308311296, 0.02473087335426, 0.02459425114906363, 0.016111763674886, 0.03701154240256837, 0.051606241313199845, 0.02198264975431225, 0.054975932674302216, 0.03356219704953894, 0.08468857620872798, 0.07571817691167516, 0.0479006395494986, 0.014696418149997632, 0.006878584728486115, 0.08744349733235375, 0.0426353708720736, 0.025602848036214713, 0.05756840868402393, 0.08596979697505314, 0.06435700106404482, 0.038026631884877725, 0.044366733411387096, 0.02433341927826405, 0.08989164620758065, 0.00964250163956275, 0.027544262308266856, 0.027452994423407703, 0.026379705241490758, 0.11174677105079736, 0.2072300930177012, 0.17006091653339325, 0.2333218219780153, 0.16204624256539732, 0.1452024818788613, 0.12616342729738644, 0.18551002947553513, 0.17697239324690836, 0.0907418276033094, 0.0933566925326182, 0.17929520247684372, 0.13344226615323176, 0.15055660909462362, 0.06823512965873366, 0.23806828825223833, 0.09165695793325863, 0.19332138370842705, 0.14936420856223953, 0.13228024866792465, 0.1546187290260869, 0.1106488521421148, 0.16956832199808092, 0.09209348249339289, 0.10408013082680204, 0.1701735314582625, 0.13148619853440793, 0.23687438618752266, 0.19245858484458542, 0.10751955917165165, 0.08544293532688772, 0.1920721088085444, 0.14587429502317983, 0.1863675729762162, 0.14692683854410726, 0.0915820881604187, 0.10122258456483965, 0.09429515023986179, 0.13231812405490107, 0.11564327809478968, 0.20345661969434833, 0.20432890272669255, 0.22140446629735733, 0.16940454772162825, 0.16806446075920137, 0.12012454005138529, 0.22716904810119062, 0.11638092117444163, 0.21875819942403227, 0.08357530489804284, 0.22306295472287366, 0.14731141468209608, 0.14287476968621055, 0.11767806890871256, 0.149049622217013, 0.18909977959288707, 0.1433762201979276, 0.1089674576876625, 0.15430198231291387, 0.09141627609008744, 0.16387477186658692, 0.20816528719038735, 0.12507290879805244, 0.3567929788222236, 0.08981440156217545, 0.10914438569377508, 0.14864947917240282, 0.15768098164229624, 0.13527870148179993, 0.10099949210040993, 0.11341382433930713, 0.14002931995257256, 0.09373213690254958, 0.14068711368787673, 0.10946255733048725, 0.1301491759236782, 0.25097382074642566, 0.08635532306206804, 0.11519018305285324, 0.13474008038399682, 0.165180032471976, 0.1049108612501333, 0.13108953352897398, 0.12153718320112075, 0.16160572668717754, 0.14764254852648706, 0.1551893725991249, 0.13608646458916127, 0.14104055601262278, 0.09572201964235115, 0.07372725995317583, 0.12450883059852547, 0.1579178253849668, 0.11962919526042477, 0.16101525675865913, 0.1505823956141549, 0.10451141534553421, 0.11916948121882255, 0.08921491477878825, 0.13107470206675992, 0.16841347509574506, 0.15252093514127119, 0.12743609086159738, 0.14739427475198624, 0.11581118924603348, 0.09519652163069095, 0.19568888650786495, 0.09358670277100417, 0.18347680148097778, 0.2141387811711719, 0.16166906683675705, 0.11072382916726413, 0.08627980211449247, 0.1716925459162843, 0.13864182746939122, 0.14945275300452787, 0.08935689385379515, 0.21072719246149066, 0.14204103619821612, 0.08878300206795817, 0.2043970079431611, 0.15530712031308683, 0.12121558715138706, 0.1968379877507687, 0.1226075918924424, 0.2004006949643935, 0.23198286882571637, 0.13755969763282808, 0.17453280157379567, 0.18998960603869733, 0.18742843621200134, 0.14723293663513276, 0.11115787160252372, 0.10790565216373052, 0.18060829250081895, 0.14308607205748558, 0.24087217005510486, 0.20917131385255247, 0.15353658386776525, 0.08729586452846566, 0.14875561299343265, 0.13564646965073002, 0.1922472365080349, 0.1981348673542661, 0.11486722336661433, 0.2571604557095036, 0.1316606214330081, 0.10355875436817447, 0.14537335012949285, 0.08045346596308293, 0.13800608174454781, 0.13125641812239924, 0.1819767093946857, 0.183533507309133, 0.14980092464435488, 0.15011664479970932, 0.10676855551860026, 0.1783359378215767, 0.2102738829149354, 0.14021255286230197, 0.14710155255611868, 0.11615186088508177, 0.20693372424331405, 0.0976455208635138, 0.11097001152173167, 0.17332811299110615, 0.18416125507604691, 0.1458882684669187, 0.09594505081974691, 0.16877894500090232, 0.12474990314653805, 0.25763374482912405, 0.09965939747710383, 0.15300517931820887, 0.0746125971237498, 0.13164575932727707], [0.006788446344510322, 0.0689826016464541, 0.014864046806319347, 0.03653737994271421, 0.05010448681611208, 0.02027319732963318, 0.03668681305322436, 0.02336796463256882, 0.04498691989048835, 0.03655432197715967, 0.056547596524920196, 0.058961508930811, 0.05581381069796701, 0.08589978419965313, 0.0495372370125786, 0.020854518253115878, 0.038437408229876915, 0.07816858574627869, 0.043712819911419384, 0.03734172246749363, 0.06508052514325227, 0.05343716463915283, 0.01751573470931861, 0.022516207010935874, 0.04074840438401988, 0.008708236348484794, 0.03500466017172702, 0.05409562487095114, 0.025053739194728197, 0.025518540060147647, 0.014071836241430814, 0.011167151631877549, 0.010437263277239137, 0.04133020219723544, 0.0037861231108000807, 0.04553033286825784, 0.07977543218481926, 0.06873138609432405, 0.025122646888297413, 0.018607308494768316, 0.028361076744453564, 0.03321931907726872, 0.054764492407200806, 0.059881457953803965, 0.04025359202416674, 0.05895934473242491, 0.017655101424503713, 0.0378035202682499, 0.020553424631455736, 0.06526878358976496, 0.05334541411890138, 0.01687960211007345, 0.05696659299334692, 0.040044266159736344, 0.035048292709454414, 0.028116658307431687, 0.06445719004278222, 0.020692745381365382, 0.028833122886416894, 0.06619822444213976, 0.04104844271956433, 0.030800248984427705, 0.016837005706263647, 0.03236188282889705, 0.0937661971716631, 0.014974898771352827, 0.04498695819488457, 0.024101660444190907, 0.05006358921227436, 0.030721552602405992, 0.17649858318749936, 0.06252602794237676, 0.024138635677856304, 0.020473558050129684, 0.08738069344432124, 0.051503309739693526, 0.010887421329595871, 0.034698293949928016, 0.051721395819538066, 0.037918770535578655, 0.08340533297028273, 0.024859867238950346, 0.013733484891183196, 0.031361887193915826, 0.045812437085494886, 0.02728153053941506, 0.02849905684049572, 0.026711900117656878, 0.05372169735510984, 0.03230646785889422, 0.03823336071124481, 0.016784555496527784, 0.0346451542610603, 0.06672284145268702, 0.07206071994357532, 0.009220426455290328, 0.01353538987572275, 0.02934974768469411, 0.01633358826380103, 0.026166016506331585, 0.041553738992661245, 0.03330970596101496, 0.028849754655253024, 0.053542605150611176, 0.05524383745186272, 0.032319705858225786, 0.015081713453025348, 0.02083509983945518, 0.05087986738691407, 0.0373982367736678, 0.07268112092729538, 0.04857011229520844, 0.05736487827474072, 0.07246589618584803, 0.038363526710459304, 0.011515213146565423, 0.010933971704704868, 0.038066403339466745, 0.03847334541440491, 0.03906427116523828, 0.07700820768912954, 0.026676788392867294, 0.021320240339264277, 0.04717379447913939, 0.03574871157686557, 0.06427247092247972, 0.02202705604084317, 0.04500369721603009, 0.054254921363486405, 0.04876859801551027, 0.030455520909820354, 0.0659327443328596, 0.02541030141254587, 0.007582727262014224, 0.05297148660306008, 0.03847145700767156, 0.008546382079892343, 0.07732171385038285, 0.04650192004778693, 0.021979736704980175, 0.07235346512208063, 0.07518188472116187, 0.02745410908133753, 0.04994249752452297, 0.02947679379083697, 0.0040435767732560635, 0.013947701269400217, 0.0466257811433846, 0.054502226036763, 0.0561840495004529, 0.06332465928168067, 0.06314744399259649, 0.013990459509284027, 0.05540465079848805, 0.015677684850450006, 0.0692566083143315, 0.017364537681362802, 0.02832080541749395, 0.009423864934022629, 0.04467681515961886, 0.04556960636569608, 0.05768320695947736, 0.07904476816615752, 0.024989326522054694, 0.030503682942400058, 0.03268021151363369, 0.028910876980291742, 0.009514094769744384, 0.023178938182912046, 0.056132982079420364, 0.0374970123201849, 0.04392192744079136, 0.04913478038243709, 0.03085994638592726, 0.05326418581628992, 0.04091237784333287, 0.031174389089667992, 0.06587938630893346, 0.030028162591700113, 0.08477157417444453, 0.04480684326300698, 0.005546509130527416, 0.04254845053618474, 0.08158906873676085, 0.019232769489228245, 0.04136695909584242, 0.04998546739619586, 0.03047539131535638, 0.01779464817035102, 0.08040165543676385, 0.08014253385725521, 0.026933843450200175, 0.03285354273694177, 0.023709507696630976, 0.03237798599706542, 0.02612934962305571, 0.019594240415420745, 0.033866491003502766, 0.0848344776539072, 0.043479526986277876, 0.03340314953557907, 0.00930836664572839, 0.05367928672762168, 0.04894007913648121, 0.014347374127546867, 0.00676232322509731, 0.011997909825896064, 0.06419171376394169, 0.07187400899466968, 0.03985041910181603, 0.00647990060256674, 0.06582703186018814, 0.03126405968120502, 0.06829030331104033, 0.03641642232034956, 0.027316464148762248, 0.062474129315946376, 0.054897083074695645, 0.044778831258055665, 0.03251144617435432, 0.05367565547086058, 0.0798516119680097, 0.10238870062054166, 0.026982298511410915, 0.06724448604208809, 0.012909699054885537, 0.06430257051702469, 0.012847267677106205, 0.03669085033658532, 0.07887724005887586, 0.023552775683422244, 0.0300658694393332, 0.02342233772299463, 0.08775182473923891, 0.040950011912613146, 0.04655208731550844, 0.06365381278878739, 0.014038255734879886, 0.05973007897996615, 0.13919406961048805, 0.030268143464420593, 0.019702040477685874, 0.06824246878104825, 0.039123642979370016, 0.049040210658624295, 0.010918784969215913, 0.09600266829253205, 0.05101892766692946, 0.03506722657250301, 0.022758539773583896, 0.09976642762100506, 0.011560811657428501, 0.05320556476832398, 0.023894456643310767, 0.05809048611310221, 0.0074693524736850975, 0.06164801840279853, 0.052237808028416294, 0.02401049981164115, 0.007419742056123553, 0.05035676340001726, 0.07009233363092908, 0.028192037528741266, 0.03767831468834512, 0.015484187320145148, 0.0363522318131741, 0.07815399177132115, 0.09762931810391527, 0.0521508647098897, 0.02077870044646965, 0.07999512321886518, 0.05483628250658513, 0.02081904072134245, 0.04469647680619552, 0.014949117997480978, 0.06388523262895404, 0.040597841293821414, 0.09685474192543377, 0.02133295356836771, 0.04375164907786154, 0.0451509929412315, 0.060340382924844185, 0.024726918425350904, 0.11485387811497336, 0.05013423401021189, 0.05053005631892912, 0.058481489728775725, 0.04237900337865276, 0.04187340833126538, 0.005076182377149141, 0.04361175376200869, 0.036552904714499755, 0.06947175644698643, 0.026461381705537922, 0.015698645973668223, 0.11874511447404662, 0.08820282070026284, 0.0077040013744525855, 0.04612235029438331, 0.0446251003942903, 0.060172050425242034, 0.03519743087611372, 0.0214712975561739, 0.03859433751072615, 0.029633100625247728, 0.016159613526636557, 0.06871618690990633, 0.01777672554336248, 0.01743874095770861, 0.028240810516440583, 0.049513898143965396, 0.07498142249401539, 0.008640696121860416, 0.06731329605944696, 0.015736590308557837, 0.02075157327307088, 0.052114483194365624, 0.11070009576336992, 0.07962488058593967, 0.006645754328928889, 0.058213757320998184, 0.03775398502306592, 0.011218953539707489, 0.05509651108314434, 0.06041179764114561, 0.02627728120123427, 0.05083054281590928, 0.01649452418449425, 0.010420467757109192, 0.10094697677320051, 0.04210824109313469, 0.06711064282083704, 0.04475176537169084, 0.04808759181610039, 0.040181146919607155, 0.046931350633742354, 0.057569079010957674, 0.03738567676214922, 0.007447110547218473, 0.0460355831760793, 0.05903563559836438, 0.0558628288338021, 0.04590035333568531, 0.05963033816266445, 0.08194603506595859, 0.019341063678204533, 0.013727097633114506, 0.021355696803619786, 0.056082952707525224, 0.021332553287427274, 0.045754317825119344, 0.020417804086220362, 0.1020455621783772, 0.18605707754050532, 0.14583565354827913, 0.1342021181218086, 0.16628537477264482, 0.14330811498145904, 0.13248209751421405, 0.0811528506117963, 0.1081210760880382, 0.16191464398176442, 0.15899897462898688, 0.12092139406670487, 0.1109351545211769, 0.18717962617595352, 0.15677981709520664, 0.0901058137476925, 0.11785002500419656, 0.20098275324750334, 0.15832363748021666, 0.15864199297803064, 0.17326710174881643, 0.13507528981614497, 0.1531864510428521, 0.09268006835613521, 0.11701209335437707, 0.08148161724450127, 0.15483236030465172, 0.1374040132448558, 0.09608914429742484, 0.1026334350688323, 0.10535554464666114, 0.24623342188856295, 0.22657140758970093, 0.1441266033197603, 0.07901361137027703, 0.14751573033150167, 0.15382354508244223, 0.15388486275990165, 0.1486394127770778, 0.16528990480207628, 0.149472855151661, 0.11844766551568625, 0.16394044092345625, 0.14376893218967224, 0.1074506648846211, 0.11017881889617252, 0.14818097044142986, 0.08251619600360433, 0.12621274037707236, 0.11708540796873071, 0.16068415355778512, 0.11257749381324939, 0.14092308409031362, 0.08619749362790778, 0.07811525836586952, 0.13692888551421706, 0.15067749776907507, 0.12219684619096019, 0.14829605216941527, 0.10196003612251052, 0.08761384464319676, 0.130584834804458, 0.09008257064006983, 0.20323126727054197, 0.11845210882564707, 0.07878111900701638, 0.07592168050788103, 0.10830201073399476, 0.19515532159036209, 0.09434680754859602, 0.3513243061400229, 0.17028204015185758, 0.10605600947934775, 0.08416706185427406, 0.11689645238220693, 0.13488133167547567, 0.13699395702250544, 0.12816530697408224, 0.15326241632142376, 0.14234426912040482, 0.2271815353343564, 0.11348484835076718, 0.1495852862154284, 0.09903238515459722, 0.20311408646164403, 0.24464671590155174, 0.12438840923770783, 0.10165968369091712, 0.07720812599384978, 0.09113961109711279, 0.1751387005131091, 0.1898180023436585, 0.122384162349326, 0.24550088861536598, 0.17033304628585616, 0.1557042909365508, 0.12552385113292164, 0.15988357635515352, 0.12132172863329611, 0.1534328402410592, 0.23431681697407078, 0.2092046846425341, 0.15116002590906236, 0.16472850024940508, 0.1829915920332555, 0.13834135246372994, 0.1521931874055055, 0.25905787163684446, 0.2289161575777877, 0.1269492573074756, 0.12626990585798217, 0.22044915465577958, 0.14552983124890637, 0.20415719177934433, 0.1555780243248709, 0.14433405992965545, 0.22358723465473423, 0.08812438095769576, 0.1074355040045996, 0.1945532990559455, 0.17854219933430995, 0.1593667887631924, 0.13392695466116553, 0.16397191181538567, 0.1444190803674921, 0.16090680935209797, 0.10967612732201816, 0.1984824108019952, 0.14512981077836407, 0.10800552704641897, 0.13184779203466832, 0.13368928354353676, 0.17036002790254934, 0.07293846518281968, 0.1412286918850676, 0.1640992509501596, 0.0953575686341332, 0.23873460088526052, 0.07892773291396518, 0.13002506967994476, 0.1371964034173758, 0.156351420727949, 0.18674074972589172, 0.11117856363735854, 0.17285369006135773, 0.10510411458991228, 0.19075005555585509, 0.09609934858857624, 0.16651342382594464, 0.10474642813806573, 0.13341949802012215, 0.18167499332658707, 0.14896948942013327, 0.291927119176234, 0.11332950870236082, 0.3362685946687576, 0.07875452043428537, 0.10229862400240476, 0.11234801217553117, 0.13759945759609823, 0.19542141456998166, 0.2495621045630786, 0.21210521609792787, 0.13958713400267786, 0.20845690621964394, 0.1140255838512413, 0.12719309543289486, 0.11997814830993453, 0.11688212653802288, 0.10619039662302503, 0.20098154282858297, 0.08580092055302474, 0.10962551955374018, 0.19074912092858748, 0.15353148172218956, 0.14763533197824033], [0.03094147729326881, 0.03927285392438212, 0.02867454843175027, 0.02512290927341148, 0.03702001916545053, 0.06656088280461489, 0.07591507682997374, 0.033754312748750376, 0.031686122416548675, 0.03899088760297145, 0.04284532109816228, 0.09685379197640766, 0.016138381399815122, 0.023080032401447816, 0.026719018989693255, 0.03508212698263026, 0.02310123005431266, 0.07176008405944995, 0.06717468777130689, 0.06461596176508935, 0.020086848357271765, 0.06367914731644335, 0.06567798945451937, 0.055511811177336404, 0.017505072680632436, 0.030782967956075748, 0.04900924538472488, 0.038772357192130825, 0.04696806156707387, 0.03651666875568129, 0.008545350734024279, 0.01937522162352839, 0.0886912323955086, 0.026002179027625152, 0.018790493524002454, 0.0099429699419547, 0.06666608965925633, 0.011270315904590872, 0.03666201095667578, 0.029013362307582172, 0.04119245575801019, 0.041021656455291856, 0.02190526529786087, 0.016167910258856513, 0.061422535744045055, 0.07633762794636911, 0.12965100426827708, 0.0602830603959099, 0.029603989284125068, 0.01499773776759544, 0.007398475455345527, 0.08765983290129131, 0.042773956177575935, 0.0043111540482289375, 0.03122482831860262, 0.01914785821892081, 0.04537072227967363, 0.0658937811010307, 0.016430029157368888, 0.023151018108511646, 0.04356108470669678, 0.035678882662567406, 0.0483111132897677, 0.04143350915382466, 0.03746453402263503, 0.06618919226551248, 0.024333516954474395, 0.03334728257370091, 0.028361492347152486, 0.004460067176560481, 0.035675094357781836, 0.04387928698692591, 0.006989361042337072, 0.01555589123463799, 0.03655015445885159, 0.016983899235304807, 0.037063659364057165, 0.09739773738528452, 0.018130102750634956, 0.0336487228501468, 0.029006712664399418, 0.0690147620175154, 0.029902955096575524, 0.034621937966514985, 0.03688795709862344, 0.024122164787484274, 0.08598947011294865, 0.04283437753216394, 0.049855910436881166, 0.06377408476245981, 0.06893965475741895, 0.012483953351845906, 0.0224402915280793, 0.02512859364580964, 0.02943778842417223, 0.073932571516883, 0.028406645569409576, 0.012683851546758126, 0.03756847683220141, 0.009812619124028471, 0.06866049231781114, 0.046867615948881836, 0.03007942153471372, 0.008088520055847063, 0.025701738495920456, 0.005801185484855406, 0.023338634956387744, 0.08172300388856281, 0.032710123416637225, 0.01986594498908568, 0.0895468453546205, 0.02165115967903647, 0.01959409102827551, 0.11402845668095736, 0.0840449934044192, 0.06523715948025066, 0.05534328332531357, 0.014727298196615472, 0.03492462313583782, 0.023798513706893693, 0.04436374949892202, 0.005181321720292251, 0.0388419562800517, 0.026968395930805036, 0.015606921308884218, 0.021459821559068178, 0.04072155300227385, 0.04256207540991806, 0.08858829316112304, 0.06668514992681242, 0.04111903772178677, 0.029894759871005535, 0.017433273005149057, 0.0421461126496715, 0.01421882744668232, 0.05677293745740768, 0.03670319967392472, 0.01979814812300667, 0.0452149038263146, 0.028447692560392524, 0.017249992214924386, 0.01095929474104196, 0.03866983930610361, 0.07156462438644902, 0.01587991961353128, 0.05052796872933546, 0.01995739098938723, 0.05661427298740995, 0.021728664794335925, 0.01771963284080548, 0.017383147872263388, 0.017580425088864662, 0.026181945389497186, 0.0800223499836941, 0.03761810017749667, 0.030546966910121903, 0.027998985287042397, 0.06364678776252174, 0.03131159352168682, 0.020284707800695495, 0.01678134367290524, 0.01960993755698925, 0.05328106273326182, 0.027132899906005592, 0.02857168772137694, 0.006494880973121092, 0.0363612869724391, 0.07233580679542596, 0.08082208448960897, 0.037602265140101794, 0.051494296715264364, 0.05163593871158458, 0.06071769654931081, 0.09064247366040946, 0.023602002578216697, 0.02440654620107624, 0.0030990274700020714, 0.05124423412546035, 0.028100041860354044, 0.025875667267809474, 0.01827962587647621, 0.060176991692353646, 0.014029335598611544, 0.054274816666879964, 0.009524474303508479, 0.04303758618451896, 0.05252075111193042, 0.07340902702942972, 0.03270134021858535, 0.008078460363791356, 0.052051081757752166, 0.05119621573436645, 0.05256733691860592, 0.009572711987270704, 0.023204571484858473, 0.046651341666978215, 0.03319283541772635, 0.03438512103692178, 0.05961577100078425, 0.024037295652012673, 0.023061345601754806, 0.059935045804107384, 0.04407122265547515, 0.0358698990256075, 0.034315552592517874, 0.0635134808028177, 0.02298706188617695, 0.07684475516960507, 0.08340610671908626, 0.035102033777342695, 0.04214888971839701, 0.04402676274278953, 0.05444635907488485, 0.025054687228534493, 0.09266184312441657, 0.06239290101333492, 0.06298305301536476, 0.040738295853859, 0.024836706485779538, 0.04967419821168146, 0.039150521174193396, 0.024439143242254376, 0.03712015451803323, 0.06401672012983792, 0.0561036370814808, 0.03247478503673788, 0.03170229070219061, 0.1516639279021371, 0.014341920539135895, 0.023142414941121976, 0.031957350100480744, 0.034239909070874416, 0.06388383451849222, 0.07007800778674503, 0.06934863845667533, 0.008220707569571753, 0.00735418216678344, 0.037270683134275104, 0.06292212221230711, 0.031962764426885594, 0.007694366382389901, 0.021990557696910638, 0.04094799710137229, 0.038579716722691254, 0.013616046485220714, 0.03318106064633016, 0.06824107450102607, 0.06736495336818119, 0.08009202568040741, 0.05032513546006334, 0.06150813840870416, 0.03349082063763373, 0.006523210904560984, 0.0425031632485409, 0.027246562456111276, 0.010744467407705323, 0.028922025474809834, 0.012527632812458663, 0.04447939430153178, 0.018921693741914727, 0.039665558255247535, 0.04884877677766546, 0.01937172634737386, 0.041634155242072965, 0.03836657957083756, 0.03749159990899986, 0.04041002334786519, 0.053551710105591246, 0.08612869127142815, 0.15210942335186467, 0.03659529235935019, 0.06610973362600611, 0.02144010437111701, 0.07924732947421652, 0.04251470436312018, 0.04889376912145846, 0.0764746121281097, 0.030024420252190005, 0.07612623364454316, 0.03157216492259214, 0.06555887810405224, 0.028803969410458402, 0.04123353722294973, 0.006700001493652141, 0.005676513293667907, 0.02516879985529569, 0.03804407953735321, 0.03172738391215042, 0.02075211719549712, 0.05945227251598432, 0.050960429193031405, 0.04847349711663781, 0.081771504915049, 0.022766187246288025, 0.07431458126032546, 0.06604873770547491, 0.10283677778657406, 0.032045440635673945, 0.02571538060663208, 0.0161493307114729, 0.0585472583770752, 0.03685345632895347, 0.02166630140685987, 0.019789943321337624, 0.0636684182550638, 0.03318539670398159, 0.054089798772286986, 0.11134530267407818, 0.027898926543252125, 0.03594032931892622, 0.024274141309903036, 0.05691181387632124, 0.028790103219028924, 0.03075415730446337, 0.03364704894803224, 0.04922747319083541, 0.035994112521650336, 0.06129608910170294, 0.1221016904098853, 0.049199863382044344, 0.015178261598902605, 0.03584770928888071, 0.027300855107305032, 0.03747633560710857, 0.03039784789566071, 0.07050861814810384, 0.056971783239033916, 0.0785501741413628, 0.030034616882462176, 0.041018534647000414, 0.0530947118456806, 0.043602495589443756, 0.040557146703283635, 0.021747386067985527, 0.011378667550161483, 0.014131274130646021, 0.03506801564306502, 0.030092084968102076, 0.03873312582952842, 0.016452172928820216, 0.02561262331812853, 0.029472111078399806, 0.04024103584308778, 0.05784995748751587, 0.0561548768722963, 0.0373614032662684, 0.024617124619262836, 0.02704032009557611, 0.061374030887119235, 0.07991055477290385, 0.027119483791231632, 0.04711445330852463, 0.08025128769898608, 0.14022189913497818, 0.10026341950100276, 0.14021014734621973, 0.21268401084648025, 0.12699595036646052, 0.2255862644843517, 0.15617803970892585, 0.09599195072247137, 0.14380296181526878, 0.06301443963762253, 0.19002086242600796, 0.1126956015885357, 0.13281911491386353, 0.10824554239309604, 0.1354507801513518, 0.11980571723993748, 0.12087391959803721, 0.1508569768479755, 0.18903729746178274, 0.13684221032646396, 0.17090770415961745, 0.15917469987705832, 0.12545284244322008, 0.08553953901413949, 0.08093165804541881, 0.12836994438041605, 0.1732391548613387, 0.10502975043510238, 0.1256359681006401, 0.09021943990862177, 0.13018996244476688, 0.14581018878567606, 0.13827254244637105, 0.1335573019159417, 0.09538595985260703, 0.11594946045548686, 0.2547137087751781, 0.13754535646688554, 0.11718031094079057, 0.17701157098335607, 0.10773941874504091, 0.14066552533017052, 0.11442235610898464, 0.17171952753297745, 0.13542756768724612, 0.14836153736518276, 0.10446442351225885, 0.146206317529563, 0.1064299829604645, 0.13039869076061633, 0.3161694506003011, 0.1432495092552516, 0.2683374333766199, 0.10625882359642176, 0.12875578456347989, 0.17773314919923583, 0.1806336806546296, 0.2281216631132749, 0.09792928749154653, 0.14822474470542324, 0.13947560692266112, 0.13958569375738022, 0.1295665354137459, 0.1528599137260068, 0.12764893306960023, 0.209543923697164, 0.10889573653619136, 0.11883209609696943, 0.16083968472817253, 0.28563088767470857, 0.1866116026236165, 0.1668394861682769, 0.16718460877816524, 0.20939493491764993, 0.10406912980420936, 0.09402686624877876, 0.13903755784755753, 0.13429602517956687, 0.15696211537766844, 0.14421291078530973, 0.10671260811749006, 0.07958588671059379, 0.16878367942427436, 0.12874401745296296, 0.1447565880634131, 0.15155407089379527, 0.20652187537522088, 0.16395937861694446, 0.14772239020995556, 0.10529559826658619, 0.1501602198808424, 0.28572364560058044, 0.26682869981854196, 0.09035885258908234, 0.09727219089625344, 0.07555359824290199, 0.18307161757782583, 0.11558268820085835, 0.15436709978647772, 0.18957015757839527, 0.12171876136093371, 0.09960797765562612, 0.0744917544145738, 0.17350353180400788, 0.07815301117877807, 0.1185825123121181, 0.22747919113645632, 0.1342082774687198, 0.1259591576132563, 0.14096540278725087, 0.1440761181255502, 0.11147451872426657, 0.27565378755811726, 0.16136820878713362, 0.11602567088219429, 0.21473479757626213, 0.08952496588350305, 0.19719221148519747, 0.12991150480604943, 0.17945156102218937, 0.11011158701993766, 0.10949798889698521, 0.20570758519874466, 0.15359612422124033, 0.11533792310905074, 0.1462618742258318, 0.12099746659758592, 0.1429480536570472, 0.11342575232828818, 0.1179993125580011, 0.16715355157371492, 0.15992090015882449, 0.18527739921644812, 0.10568371373078517, 0.16038364790860685, 0.10617179600822349, 0.1776057640991865, 0.08064860387915566, 0.20349437250725685, 0.10261534007206079, 0.16521879652094457, 0.15763182944107443, 0.13486964117375114, 0.16846245875762356, 0.16533637569556314, 0.09026900579732272, 0.14038343643469198, 0.07720519953797902, 0.15557869848224426, 0.1183420296518072, 0.16157941922785776, 0.18920933016605918, 0.18700721042771495, 0.10363786060723568, 0.13934524940146556, 0.13708453925867237, 0.15875269268308917, 0.11219539213925601, 0.12590050592177338, 0.1510893006718928, 0.15144131807309968, 0.20522157901958113, 0.1308487827378896, 0.11868640915640902, 0.08709669698991122, 0.17497308762563815, 0.17804010530873654, 0.11838331413004669, 0.21383121219133178, 0.13270164299155437, 0.07999241892849246, 0.12641325623037356, 0.20940503195649196, 0.12102234913336656, 0.1766755035327327], [0.026964919806848613, 0.027905342529617974, 0.0375533695783346, 0.02406654680418151, 0.032999026664202256, 0.0348215306838674, 0.037442991630204266, 0.026372756824017535, 0.04596160589567116, 0.08553677343673284, 0.022665123012097135, 0.04173109983845104, 0.01758341857742879, 0.06470437597243056, 0.019044315690294873, 0.055142009044967355, 0.10940602004167535, 0.00895275533454673, 0.022104471140811523, 0.023805950505418644, 0.05229819107860808, 0.017167147466792695, 0.04112747618027272, 0.049634518687643354, 0.041145287724512244, 0.03930345147607788, 0.09772717817536286, 0.07648036544842106, 0.010305025967799369, 0.01870242597144698, 0.04579942125166136, 0.060497465423278274, 0.022018598430159114, 0.043317775181945295, 0.07817718125278912, 0.04447571324905561, 0.03143165865161967, 0.016140936303042596, 0.021498154683579362, 0.013827492497981557, 0.012625002587634711, 0.01366763293082195, 0.042448453079428405, 0.04137014602160743, 0.048589072971334385, 0.05722495997625013, 0.03573991688749483, 0.036648566113604654, 0.012483914089839787, 0.055537003978726365, 0.042482195422053344, 0.03262718673795462, 0.05288588010796136, 0.012426047638479262, 0.04434315705551736, 0.05029776696896842, 0.050894492005388585, 0.06046645801454302, 0.053299942970155716, 0.04361149712255405, 0.05494572965788746, 0.008736430299318126, 0.030407366538119894, 0.027519919864472844, 0.051384328624173525, 0.07839834317564964, 0.07463446127310877, 0.03445362461911094, 0.018705771860456275, 0.028146937932638873, 0.027221248995873238, 0.03798901696779555, 0.020388474410039284, 0.05435249032152276, 0.02410155510710132, 0.015838480960097046, 0.04774968958489838, 0.035238263362477866, 0.01921537929334708, 0.07988261554630534, 0.025488325552414023, 0.07694024036848739, 0.024759737632027077, 0.06912407510343098, 0.027597158764218612, 0.009646187480088443, 0.03151322786335743, 0.07709345029246423, 0.044288446886404875, 0.06269143015566854, 0.04617801807340115, 0.0513266422034752, 0.04368876092015736, 0.03415543638590363, 0.06311872718675483, 0.06255303254170765, 0.03169947532906888, 0.04053586861118674, 0.020742652179192633, 0.05362210592495338, 0.07935245972006552, 0.038067636741024834, 0.07713742373931794, 0.09576472138325054, 0.03038801324193276, 0.024827934779046525, 0.06591673309524214, 0.0734011669673266, 0.02472595506978612, 0.034820289621430064, 0.07661002582960552, 0.028944075400490436, 0.03498340123182824, 0.08627784859028556, 0.02235903066673106, 0.06360025558200094, 0.049160260466798666, 0.11105975872206111, 0.026892976489879435, 0.1018056157796133, 0.026075671757421186, 0.02685975125660339, 0.0315130076130792, 0.07448061549615476, 0.02334113623346052, 0.06139600994966685, 0.016963934983998057, 0.036280717505442525, 0.10104921886757498, 0.12470392254932273, 0.0511421567399896, 0.022123272853693175, 0.015489689746661293, 0.02617209349879094, 0.06244435530876922, 0.059173247972202886, 0.016432268049327597, 0.0640955199337294, 0.04355451550274607, 0.023006805887205467, 0.03473055774285909, 0.03214856947682077, 0.029923553285639615, 0.03489286113049715, 0.01219923198673754, 0.07573562073371104, 0.05402555080851721, 0.026342898547168703, 0.026639799752663222, 0.08094686489071577, 0.015811421777001552, 0.035398406382169456, 0.04320648558918507, 0.07298308980440901, 0.047370889749858654, 0.024071135670847954, 0.012933931373540434, 0.00875534501016861, 0.021930986699918588, 0.03354209873284544, 0.019840698561541015, 0.005063256558646719, 0.022797824762340997, 0.03984810934672433, 0.0266388114992409, 0.04091151599441806, 0.035708603043589866, 0.0329263900376616, 0.032427027115538236, 0.00656998296636307, 0.07676208662169595, 0.07713978329012472, 0.008305727049798496, 0.05544805734027779, 0.0435015443532217, 0.027888465612646074, 0.036231389103998105, 0.019998618011032383, 0.029656179023966677, 0.02998825132606491, 0.03974772501556624, 0.030355896920927113, 0.02165137418365527, 0.012679260764871875, 0.031751720610285, 0.05067155658898335, 0.015368138406155332, 0.12875495718852167, 0.04844243225130824, 0.06518239951542308, 0.08192050901632156, 0.0420840097320897, 0.036452769361917055, 0.008322614500479353, 0.007875493029132485, 0.023580586590293436, 0.07012112321512354, 0.011824651380940791, 0.05451451791750808, 0.03494914177985441, 0.021228857541216478, 0.026003550325009613, 0.051700853171848485, 0.02407913554399725, 0.012525588315310738, 0.05092006785074069, 0.041880019670051914, 0.03073201161779223, 0.023837911693619627, 0.07496159613853501, 0.039881909145943584, 0.059103216044604785, 0.046274368951637904, 0.021336318609575113, 0.12023513250413442, 0.04298626595447141, 0.055594426099090814, 0.05193280927356213, 0.07162431029662972, 0.03406333729564663, 0.010729505710544126, 0.04323053691956786, 0.045639515719226295, 0.04148517795387776, 0.0767341933603729, 0.021310428668174054, 0.019340741921276338, 0.028974362686576865, 0.023415910245309916, 0.027045157940817938, 0.024827231893376, 0.05752442757629099, 0.034108111304381204, 0.09932380500099353, 0.05380595936590145, 0.031607575421672196, 0.03317579379185073, 0.0352051951772263, 0.019235546557953762, 0.02164066618969364, 0.02223830478596351, 0.04350031478210323, 0.07430310526321973, 0.05330340568757346, 0.007533926982432605, 0.03989976665545856, 0.0401554178566702, 0.03189175190674442, 0.06937029576229473, 0.06691040275918861, 0.06160750767336257, 0.031524318901281205, 0.044700395345928214, 0.03486073140295283, 0.07643111365576906, 0.03727012389009038, 0.08815818841779426, 0.05405535928965096, 0.027246393916767933, 0.0277865989013545, 0.0033400420826153773, 0.028403144547595616, 0.056852158609657526, 0.08461029734462501, 0.013856252396268951, 0.03588845750557319, 0.001817594353680409, 0.04984009838212402, 0.03989079959630486, 0.04752953506765827, 0.031034819361182953, 0.07415256898609862, 0.030790333891467705, 0.03194184831133293, 0.03890748744109466, 0.083031865107196, 0.03957452019676566, 0.058854390686798486, 0.10565103241993536, 0.05903096629246589, 0.0016154201594256467, 0.0260001833685824, 0.059011113123908165, 0.042251687226516586, 0.02291511282354834, 0.01818353929857333, 0.004821076534778601, 0.04594516947925572, 0.03485839483478377, 0.07829418586146447, 0.012427291573746311, 0.033750057130330996, 0.006044034399242411, 0.07442689741090422, 0.014277667787316588, 0.07520818451960241, 0.05821078489985197, 0.02121108047093355, 0.02571611605103939, 0.013773895071579084, 0.04098041411188822, 0.09144307384567876, 0.01133923604708886, 0.042618470972463976, 0.050277626517439084, 0.03661367080865368, 0.03475515682610773, 0.03282929605413829, 0.0331328890376514, 0.030082813388998472, 0.026387241631445867, 0.04653015421823629, 0.011529417374291489, 0.051044461377445734, 0.04926234934358828, 0.004788799335308854, 0.03153659737548761, 0.019941209297206615, 0.039456492860711394, 0.07112536489242507, 0.015701518803384277, 0.028295400026704998, 0.04273224652053849, 0.031804699420688615, 0.03375964855114299, 0.08341425023372136, 0.041927019164206526, 0.07484334280654308, 0.013172968042894237, 0.06019800548411666, 0.06589136026318997, 0.019707899135086807, 0.04446229138862222, 0.04296824373605271, 0.017325402079750935, 0.06686514994550137, 0.023316131123612006, 0.051884381025428736, 0.03016474840772008, 0.022842717514703834, 0.03955359450511394, 0.05195794078791815, 0.026162467604022355, 0.018113461405699773, 0.05824718939801378, 0.05977801693182799, 0.01297241005475723, 0.04638841263048592, 0.051919709170056935, 0.0355959996100395, 0.046574234917399385, 0.06215456339921202, 0.1418400300486434, 0.11735619706732613, 0.1368286658919627, 0.124234632408667, 0.11751024202714044, 0.13251863990820226, 0.13650448812592414, 0.12579402736117765, 0.10574833324719822, 0.21220863796770575, 0.13931629127792775, 0.2307841710505947, 0.12727107552270736, 0.13391195465960812, 0.16156596672390738, 0.16936048234422363, 0.11576760650402117, 0.12288795709009133, 0.14181317100601812, 0.09124894716566609, 0.1624817329068338, 0.09592279596554656, 0.20320321313075482, 0.2031393520413868, 0.17057961934516508, 0.1398740186085624, 0.14223746114200161, 0.14866401952120567, 0.09920494645954141, 0.12176900140700803, 0.17976812387426055, 0.13169829763712423, 0.09496919270003996, 0.159528540567525, 0.13462662276241089, 0.20110621597738038, 0.23893165402114394, 0.11248632935026001, 0.16660348512232306, 0.1367429406532357, 0.10222571541465099, 0.08309356582861754, 0.23797985106225938, 0.10088642518366538, 0.11291982786309336, 0.16311377076612366, 0.1203496166835389, 0.10799566749483348, 0.09787295704647418, 0.15191472976678802, 0.08432718955220715, 0.10218833798482534, 0.11846814304590227, 0.08278514649118147, 0.18117245497001758, 0.10178179044516818, 0.127176440681421, 0.18996096967208773, 0.1664425606929487, 0.17564905296650626, 0.1200784215583436, 0.1199390548431585, 0.1922490597972947, 0.0994367493436702, 0.11335883454810228, 0.16720975178384012, 0.16543402126239193, 0.2122289239759407, 0.1269918671178241, 0.18757359455189399, 0.09271266539731333, 0.26471518580952, 0.2238509067965131, 0.20115933651405, 0.12435870034800423, 0.1016344640764498, 0.1215258067954452, 0.15860494496601243, 0.1567413288378908, 0.17540778123563336, 0.13640480476521677, 0.15583751362658319, 0.15717770784131943, 0.10067195886926306, 0.11119943953329518, 0.17898202573339786, 0.1678109162997815, 0.1936764194960556, 0.20831248332415858, 0.1668437609388944, 0.13175561633561889, 0.12257828136845944, 0.1332422712397191, 0.13945182755349145, 0.23065401271225947, 0.19827207370150476, 0.19634813581022525, 0.12267673132760872, 0.1253739890131739, 0.12883576414277478, 0.13449562172735893, 0.1805861832033242, 0.10860856847777482, 0.17976542724476707, 0.08180160450959399, 0.1271759733677872, 0.12238170320708906, 0.12952591743200056, 0.09805412151880803, 0.08141275360098771, 0.16337845414396257, 0.21893908810471335, 0.12766497495073464, 0.16698868945240977, 0.27643890510643687, 0.08213724295097975, 0.11819264250657252, 0.24085929977797696, 0.18041277154078408, 0.1922659750186628, 0.16201276452310626, 0.12764186973893835, 0.13693205711822357, 0.13575978937648958, 0.09297865112462352, 0.15743672216851867, 0.09769179257414035, 0.12178547229738006, 0.16490633990014755, 0.24684790101262832, 0.14920879996591999, 0.09794230332538005, 0.12151990025754898, 0.13446819577966967, 0.17801612675670656, 0.16552792832015023, 0.09380362822764343, 0.12055078371157571, 0.28368278737029723, 0.07156494614337722, 0.057717803490137866, 0.10211925983669297, 0.18616023894038894, 0.19190327835179147, 0.16498371478049986, 0.12543763559792312, 0.19899159880174747, 0.04950465146271933, 0.10575098391141623, 0.1852495289377628, 0.10504813654528511, 0.10786677320157328, 0.12110206058188794, 0.21191999135959536, 0.12652853714121928, 0.11971325042747682, 0.13463419171110277, 0.13715121955160173, 0.06657370711646735, 0.12520574078324342, 0.12860399190216296, 0.13434364520494016, 0.10779083090563936, 0.21071142637200896, 0.09562106457568946, 0.14536781897467954, 0.1692489092989314, 0.1874467763569086, 0.14647287016193714, 0.15438760029933146, 0.10688078739950735, 0.21566982320960493, 0.10055264067505637, 0.09976322537348156, 0.13263461029817983, 0.13666515208540425], [0.04083275066448316, 0.059923110154247096, 0.04424080770883349, 0.054357309014566486, 0.031821440357053955, 0.0424846583947299, 0.06729657236005991, 0.022629814019667047, 0.009676573399995125, 0.05941828119478399, 0.06313768786288078, 0.04025083793807895, 0.03338257624437252, 0.03060587524105945, 0.06471914614761068, 0.045548385730193514, 0.05859258013867563, 0.011832905020715009, 0.045442627292246594, 0.05252376949835209, 0.06944358739401064, 0.056252231325713865, 0.008993424069617064, 0.03293025878167922, 0.02611899785997887, 0.06970592654280125, 0.014544245317548275, 0.007586220622948943, 0.037980157160951246, 0.051148373543495135, 0.06207335807923829, 0.02508646647085346, 0.015974145555388064, 0.01582126600682856, 0.027180761249075015, 0.032568642298781106, 0.04400464961485517, 0.08478452106036487, 0.0588023120297059, 0.008313631161957259, 0.0289960065856576, 0.05315055965536064, 0.026198006422829725, 0.09323582684080448, 0.06969223655159436, 0.06319967586727393, 0.049157582989503304, 0.08605325459352425, 0.03359643734931465, 0.036576699405427904, 0.04696824159773608, 0.043844828352091775, 0.02576817938637349, 0.044631064388780825, 0.05048652720307151, 0.07273024248500025, 0.0031751603303071595, 0.02893539945474796, 0.03922188992521936, 0.0897238499695255, 0.048762197350902904, 0.05448017419586259, 0.027482251321235975, 0.024208156241764946, 0.023996013088993007, 0.07125068921595812, 0.034709540120656454, 0.062364816230030796, 0.028171364646104556, 0.03401659061050704, 0.0340031610891944, 0.06313386508413861, 0.011922370683732293, 0.029619954556467074, 0.03191492032079447, 0.021739899473745498, 0.03877054156375028, 0.03363563423796046, 0.018333966408165234, 0.005862254662544377, 0.06348073820493395, 0.07866085852466284, 0.044900420902957844, 0.0636793350079848, 0.030802281032646858, 0.02631114611792709, 0.0445507898656351, 0.005413409972172832, 0.034336256118671554, 0.04569930505127676, 0.04324832548116965, 0.06040813574086755, 0.028968538503132524, 0.01650922349654138, 0.026941241944328915, 0.08161324647165115, 0.02837603461117514, 0.03850077136209415, 0.08210750341775917, 0.03440591266318675, 0.05763948249119905, 0.07721520464627013, 0.07883550358876106, 0.074916350985727, 0.046160206529161626, 0.06478879120080702, 0.0374057712484031, 0.05536898174473355, 0.01661972784917922, 0.0044198805980774905, 0.03698024388042189, 0.045555606108879855, 0.03605922233433493, 0.0856402489326654, 0.02123235856303044, 0.035230771022578405, 0.05517300113194412, 0.032467361644751606, 0.013511046474318833, 0.016260398138735085, 0.07282364392472852, 0.01110464747574541, 0.0451516900812426, 0.02227086160752562, 0.05318717099726201, 0.05578886304471282, 0.05736041198214216, 0.03461134297052219, 0.060562310935629, 0.0316393795618487, 0.06283152848482132, 0.03010023422839661, 0.022997898199865897, 0.02456389683028383, 0.0326599178445195, 0.013181271478383532, 0.027283706229120016, 0.03390669146732938, 0.04591801932321922, 0.028324769922502102, 0.05064783850684763, 0.018478347168814753, 0.05474721712450828, 0.042607462288992065, 0.035280731446560354, 0.02505899647310857, 0.022842945425861308, 0.01584874749589231, 0.03563880477280867, 0.018895867002767422, 0.007831961998055059, 0.04331015643753833, 0.051674626151760744, 0.04488378147324247, 0.05890911234722984, 0.028595685425605026, 0.04495938669048971, 0.07124335009364352, 0.036155220812126514, 0.0036611296414893364, 0.07191410603662653, 0.055221084640511585, 0.050199508531800205, 0.09065861513297405, 0.03001321813151721, 0.08823364041745664, 0.059497069507356615, 0.022621258732772643, 0.038975941227568735, 0.030748049668487043, 0.024085296806128278, 0.010323039567728919, 0.017153865417405482, 0.03589244499321907, 0.013536417391151192, 0.02638517510927012, 0.011240486356039203, 0.0585395630238758, 0.009857569332985629, 0.02707859576349297, 0.02617952455165646, 0.036828217562288046, 0.04319036326881859, 0.034441692799690275, 0.04930604316834961, 0.06628066316367158, 0.05315011915480418, 0.04264614972916823, 0.036787806424282254, 0.0063624952341459935, 0.03130868813323398, 0.024296488094654296, 0.04313412858473678, 0.06436273140171844, 0.04038069750212374, 0.022909370994555856, 0.14600528073647331, 0.03737387517767568, 0.0336449115627235, 0.02414088797635369, 0.039697075112452435, 0.016863910714164376, 0.042826467674345746, 0.0667584338976491, 0.06747842631152562, 0.05710973652199872, 0.028208747821589632, 0.036528167735424735, 0.05102768022146437, 0.08889457511325037, 0.019152274715804288, 0.03263859761758678, 0.03927861490557271, 0.026359218135175687, 0.02670113275188112, 0.04037357288442793, 0.029096402408134554, 0.02547318382459062, 0.03922100509366682, 0.04337259643380681, 0.024501826471438812, 0.0930178595045882, 0.03668524257297959, 0.013423776610814517, 0.04331638856280235, 0.026370232564307032, 0.020337594680548198, 0.03746556058045357, 0.03229245994119875, 0.056929426237700455, 0.09547789040352068, 0.05348580739190502, 0.0538871493641167, 0.011667547815088785, 0.028125552588232586, 0.044499350891959284, 0.026748808318628903, 0.09933440765786557, 0.0031981817512367404, 0.039442592195325324, 0.027605219924401854, 0.0411828643371982, 0.05758321716360027, 0.021821556785594554, 0.005229641758506337, 0.012922509002589412, 0.0006807003627463634, 0.04176088916738668, 0.049514085835506844, 0.03331124962818238, 0.04158859216277638, 0.10805644124986664, 0.04288411962108747, 0.03934779647557486, 0.03580094345154301, 0.01759027889479072, 0.015629607087541974, 0.030798592319291447, 0.04888035875234393, 0.03670680794804808, 0.0373637130213601, 0.025517088323531133, 0.04474799621910338, 0.016493093515295657, 0.03073676519336239, 0.07048018096435456, 0.03532504580254036, 0.037992985303243326, 0.11002142613212909, 0.03621491055274683, 0.030421730686700156, 0.05253601541382171, 0.024562921983400182, 0.02516912161222389, 0.033576247102070245, 0.08096122903929603, 0.022305800962532242, 0.06030630733397219, 0.13235924765467644, 0.0805066860911827, 0.03562277055255348, 0.04890995272885888, 0.052537256476259044, 0.124729203450824, 0.030864805298587008, 0.029208795167505745, 0.03762446253770783, 0.05131978188611327, 0.024710598837343917, 0.09542012737402994, 0.06998212422214209, 0.019316232853358793, 0.044204453006386764, 0.02457525791420091, 0.058509823490655234, 0.03847014316688142, 0.023211837828820272, 0.03712078271013114, 0.059340136396067764, 0.03862719502179854, 0.03257316221753436, 0.041020637558352564, 0.007156292558647693, 0.029016424744059483, 0.054881397424446005, 0.024669528863723242, 0.05325784260827688, 0.02495465338260176, 0.056515328901549505, 0.05002758307983318, 0.014890354265639139, 0.020515438161730286, 0.031629041205310536, 0.011584295125137414, 0.04527447865374627, 0.0804032412387671, 0.09165654424577953, 0.026444326673123627, 0.07559052368085231, 0.04840873587395876, 0.06944868953958636, 0.003527109501808281, 0.098711087879154, 0.006462151302971067, 0.006852960523833791, 0.03702161645877265, 0.06283891740285101, 0.020153848491909526, 0.08700855091334352, 0.048155084162229495, 0.027958936125580824, 0.030075275083823554, 0.0180583605317459, 0.010792398656297837, 0.004319795041209868, 0.04352394859456728, 0.04818167507408127, 0.07311569962410197, 0.0693120347756532, 0.0322514129502158, 0.03635446112903376, 0.04243195920641865, 0.04008214537715239, 0.07194757641803834, 0.02562253649586872, 0.05681753909635929, 0.05051660381497876, 0.03364164802816606, 0.0558599291910087, 0.04005928914393148, 0.07764951521230322, 0.02142262415990474, 0.20921233020001845, 0.1360859896146482, 0.1015129931751759, 0.15439072593806252, 0.12183440233310386, 0.11811089326417255, 0.1799823833449233, 0.13530379852219937, 0.1260709834675635, 0.2392000146210194, 0.3360922105850712, 0.10475086378714732, 0.13878827283699668, 0.1494170533072564, 0.2400029973397332, 0.1276625311302562, 0.14114866634049725, 0.1997694231930279, 0.12477965034063786, 0.12899333310704078, 0.21101413835440913, 0.1283694004579898, 0.10339966854981839, 0.1401849430535109, 0.07250911886653594, 0.1421503875885279, 0.0923020575916575, 0.25031504641857844, 0.16257790758484797, 0.1116065156736201, 0.15594989872507511, 0.16571286194507154, 0.0994126252349346, 0.1163064804108393, 0.1883528285449551, 0.12271633807329402, 0.1703702781589762, 0.13946868148782562, 0.10246709439783327, 0.16766375080952722, 0.06627847215220814, 0.10296518944444195, 0.12206288039564125, 0.11592738180150909, 0.09360343413127047, 0.11496443226332627, 0.14531005594518878, 0.12924025856679486, 0.1123824171842106, 0.10255293454974891, 0.1085484458974773, 0.07929651231895532, 0.1274762568514674, 0.21787811761661885, 0.15077183383607096, 0.3167361411596498, 0.12934332803612755, 0.11302090550382292, 0.15910627290366158, 0.15174006172005208, 0.13830643417614122, 0.16905683573455582, 0.1660022899628647, 0.12657214286586932, 0.09577259676711214, 0.18458543795972102, 0.2112763089638564, 0.14296008123745843, 0.10783107350430182, 0.08277470471277353, 0.10099119536818997, 0.27725359364863367, 0.08311907655649609, 0.10579697983039003, 0.14951753339940502, 0.20598071086550915, 0.15864272842243796, 0.09240936352721146, 0.20635868332559065, 0.0903183801640426, 0.14701789575478724, 0.17489566678001037, 0.11540423567977645, 0.12232082219974649, 0.082529311428868, 0.12309670838857852, 0.14404552057385445, 0.1258655186862715, 0.1347653459637396, 0.15473410186748351, 0.1528749137275642, 0.16245171758196048, 0.22161320993496528, 0.06988010429326566, 0.11137197019472239, 0.1345197075316983, 0.15232647138257183, 0.09332260161998773, 0.11957850322247514, 0.22753217377729956, 0.10809375739265835, 0.16410660539423266, 0.1471200459186108, 0.21417161569960658, 0.1290077049165003, 0.11281868893532984, 0.1458707097316942, 0.17085243857675986, 0.11773160313286128, 0.18390221010533073, 0.10702861938625575, 0.19430740015400996, 0.13869344647372925, 0.2074535761869723, 0.1632536430993388, 0.19935360598948695, 0.1666681735866493, 0.10859611188812603, 0.2771699062037853, 0.12908258235021947, 0.1275261751406135, 0.1559057260953611, 0.1398927877627073, 0.09501473662713844, 0.141750474370295, 0.14810667523453314, 0.0726211668863412, 0.11964909822469759, 0.15291769207725603, 0.10719688293794472, 0.12733030944101273, 0.10705278946026679, 0.1226088635983967, 0.11594916168119639, 0.17084451722762278, 0.17400823052852385, 0.07872566190217772, 0.12224433598138633, 0.09942865945518979, 0.19657353419930707, 0.183096990409878, 0.2188428981049407, 0.1629625296881122, 0.17710376200416397, 0.12967510539437496, 0.08099163506901072, 0.1762025668135574, 0.06434492751835816, 0.11463912068715981, 0.09687109790261715, 0.22790801651295156, 0.2853661889751112, 0.18596303258692065, 0.33230277198937636, 0.16012633429659953, 0.07686205343493531, 0.12606048040212164, 0.13180145903700782, 0.10055687714127765, 0.19061338547016346, 0.13240237840481345, 0.10876014663447296, 0.1902999022915479, 0.21415080875158313, 0.10679332314119225, 0.20660983759068674, 0.13167957444825482, 0.08998787451174953, 0.12383231367435187, 0.12351714510230288, 0.18345384948676635, 0.08291680636184831, 0.15590434713709742, 0.15508797320146717, 0.18497689356726987, 0.06281943195649693], [0.05319307370471859, 0.05526509256132188, 0.03364380073523329, 0.02663779643274123, 0.011931732278167, 0.08431015175677116, 0.018322092045338887, 0.038462405678846186, 0.059905754432322524, 0.026321413611332257, 0.0637937157655195, 0.05503892425387617, 0.0033578969587031156, 0.05626088428881861, 0.05140534624637616, 0.005846823257724605, 0.05909375485873992, 0.07768392022098265, 0.022491134868393985, 0.050862285669051835, 0.03641698922541353, 0.0770244870575205, 0.04489248806250192, 0.10117746198609953, 0.017793636934290973, 0.027431386913503372, 0.05635407122392809, 0.09573095222754825, 0.11327824209846797, 0.11423535404666779, 0.00912160877393739, 0.01508355014882381, 0.06462555318590134, 0.04301915793950039, 0.011566946106482179, 0.021891563815335115, 0.022787005685630347, 0.038944876362239166, 0.021744344698926135, 0.03645217181333611, 0.034518213492007024, 0.01720933592878282, 0.03755057718785059, 0.0648102646453246, 0.07218183844440407, 0.04040209816828851, 0.05306727057623287, 0.0838121869451096, 0.0197789499596242, 0.04676718948288791, 0.09199784407692571, 0.011311168500763035, 0.05365076910464033, 0.025993453286167596, 0.0781571327318107, 0.03129642498078606, 0.026410925239625, 0.03025718074622414, 0.02640336203659254, 0.032402818737130974, 0.06185518006884283, 0.020421395123365427, 0.026114579447875583, 0.028668902363748323, 0.03449742569618168, 0.05117551603865239, 0.014028877861076787, 0.0012155375847097247, 0.013146431714807068, 0.014156300307912453, 0.0396288090175198, 0.037263841969111276, 0.020186773035675287, 0.04931496426222786, 0.055501020828922915, 0.031546658025153225, 0.03477715887129307, 0.03250956925893984, 0.05710086905427518, 0.035255772301987294, 0.041141472606649326, 0.04962958125097137, 0.023139070967332493, 0.018130591131686684, 0.027284315269019817, 0.0622980248543524, 0.03882371572657459, 0.031599456804894635, 0.056347731846354665, 0.0251708778687903, 0.06065241819728286, 0.01588597075052319, 0.04099364061990092, 0.022981088315587372, 0.0763459629829853, 0.008711634906038882, 0.024784493763300202, 0.013932847782158324, 0.02226125103451552, 0.04736068928914686, 0.04297536069286927, 0.028692432754342596, 0.029919435563046607, 0.06656261416332376, 0.043567447066907926, 0.07203910094235214, 0.0328269709772881, 0.023280676574476307, 0.01929598323430025, 0.03245027022316091, 0.03491031644385188, 0.03408235542836689, 0.024907908612681974, 0.03124679780505117, 0.05820131605310787, 0.03674143512222556, 0.05726198883607023, 0.013807240963703202, 0.02518621877947402, 0.04897790472774256, 0.040380789432674646, 0.050128488350779786, 0.03646020424522219, 0.037676414790292906, 0.0059984909509488895, 0.02308167949048502, 0.013676401764725246, 0.005626790835747436, 0.06315826881496657, 0.039102020147707195, 0.03898893407876453, 0.03865842459603183, 0.04036059535499062, 0.04885804261110964, 0.032095998608236836, 0.05841357986472788, 0.08344222776471608, 0.022627678549578114, 0.0716662765931218, 0.040865657971270626, 0.045752149796293634, 0.03905845272745337, 0.03156135350676074, 0.025296200277103532, 0.07021057930204176, 0.025446623556255817, 0.0741737742998427, 0.007691745404078956, 0.05243264333975892, 0.07727518933074129, 0.028991373668935512, 0.030576166351355856, 0.014892079878688581, 0.04077343630694574, 0.005945145854756477, 0.02906246662830874, 0.039163674903853286, 0.01602971182775594, 0.043385581624123364, 0.05503219034102175, 0.025086590960141153, 0.020755353916977203, 0.0638350960047495, 0.04210545253309031, 0.005622811008980799, 0.07820916542362782, 0.021757260941329504, 0.04168248772921582, 0.014545686520455826, 0.03728633431056815, 0.01235666880083661, 0.009115387182382327, 0.06549029791307065, 0.04109362658533839, 0.026375543468842105, 0.05277079454953632, 0.028178627159626737, 0.05766728382197119, 0.1038891604290374, 0.03679125765038114, 0.045010729903174986, 0.03676157557375489, 0.05222378095852272, 0.028187956195324663, 0.06228409737588898, 0.028411619395257968, 0.04955720892476459, 0.007029558633333974, 0.029679165492134712, 0.09736457343904242, 0.016363235866470684, 0.03585470367162939, 0.04001829960954286, 0.09564299767296161, 0.1251270788751783, 0.026360763717562925, 0.023359480208807418, 0.025608817776364666, 0.1340046972637215, 0.11112321378482927, 0.017772584838131746, 0.046378035969551534, 0.027788987180458444, 0.02067061884689235, 0.06625880667519185, 0.03313224935423463, 0.01103020766975298, 0.04189054954857115, 0.07341700966560072, 0.09704589618430023, 0.060924873537113594, 0.03109078208405164, 0.05601477854314351, 0.010162195577586611, 0.041852252813236374, 0.02728084872116245, 0.03361483495081625, 0.03352718683139932, 0.018414848055990956, 0.014109598630438409, 0.05649108987962527, 0.0313913049702082, 0.042269870323399385, 0.025311116008989276, 0.020969299291591012, 0.027571653781999505, 0.02832573136284707, 0.03014087902321931, 0.03096641537042395, 0.012906870275225132, 0.047130759489992936, 0.03357186124870374, 0.06332325351033961, 0.030802847937710827, 0.05025041890480826, 0.03829902210723489, 0.034039531113399614, 0.05184226917223104, 0.07069791847419354, 0.028810584579684564, 0.04998803762118182, 0.03216321324749339, 0.03345576062377903, 0.02679998682241046, 0.009915067104532594, 0.04370615494647815, 0.04808032164169897, 0.01639848931752626, 0.020373012840507493, 0.04831742202382415, 0.059167398890901, 0.027194905147377043, 0.05094414599420083, 0.03984419846787088, 0.04249831774241982, 0.04510927562331481, 0.04499469185248018, 0.010641509021121648, 0.09421353889328819, 0.052650120379703666, 0.004573033544264975, 0.041351920789888794, 0.1123538880699104, 0.0631627121249274, 0.03485694309816726, 0.024332051811319207, 0.04493495997702403, 0.02259914368961848, 0.040235136966070825, 0.016681422824941335, 0.09674892986133214, 0.0500645085177835, 0.03308537243414791, 0.06933862568750497, 0.09658097274481289, 0.07934366503069479, 0.07831916798867526, 0.06596472084281907, 0.012389898822162182, 0.036153960597491076, 0.06417720022821619, 0.05706231184904614, 0.04742437034785267, 0.008922157782850968, 0.033924139119804866, 0.037764694932247364, 0.05740392960668091, 0.0658834389140529, 0.012593965492992392, 0.02318408629376321, 0.023867626328982657, 0.021647221987105666, 0.0393901304942706, 0.050988904681176915, 0.018171389144094243, 0.0469222495092019, 0.058153971819387335, 0.03035881571591862, 0.014318310666919477, 0.04845456325358922, 0.06043838855299739, 0.04668994866792233, 0.05943259171720955, 0.08677222044958223, 0.018457285496556473, 0.018935785929281867, 0.021485514232828733, 0.040082447981882485, 0.03212927172200815, 0.029231226221928676, 0.04304827311106267, 0.02593129291199148, 0.04926801839422795, 0.06472078557576864, 0.03659188709852677, 0.016658445932872353, 0.025428484509428664, 0.039272593454487865, 0.042678945953206676, 0.005383659905243305, 0.02385133546927283, 0.03849938091251158, 0.054885775616933266, 0.017850576419263117, 0.03866405151183567, 0.031264013715929566, 0.017293092321544405, 0.041001224890351295, 0.0325569901014528, 0.05249856903608288, 0.019258693904585896, 0.01723543462914325, 0.03362428081492263, 0.006017623518052842, 0.025956464645963524, 0.025860433609435157, 0.07925854500142798, 0.03324546948856404, 0.03453018361582391, 0.04812570085989372, 0.030781613895669583, 0.04462473650252627, 0.09125750436778031, 0.037621440320846536, 0.031095644827151013, 0.027812092392254743, 0.09392852354193888, 0.052390960495798826, 0.0919563374331882, 0.044354805422406045, 0.08715986860014739, 0.04981590915591486, 0.13817161802322636, 0.15858439848788325, 0.12593765352522174, 0.18246654601347062, 0.12239857246318173, 0.1959264656949428, 0.11531890880677009, 0.16030834146565007, 0.09530657016101385, 0.08777503720334462, 0.14183391666700765, 0.20095247745273576, 0.08530569067525287, 0.1417657041982297, 0.13238970731054583, 0.1409436305684428, 0.13532341037306095, 0.21220286166475666, 0.23744305325371606, 0.16959695836469052, 0.26253667690100213, 0.2651759110871823, 0.2298315713602689, 0.16234952145286147, 0.08477845364400456, 0.14079369183990265, 0.106143320520078, 0.16272890351472363, 0.18933476940278085, 0.14125110761773202, 0.10816406894234881, 0.10527702829530163, 0.2021978299824461, 0.2866475169937457, 0.1511017572615416, 0.11274707503616811, 0.12344715530954062, 0.1417016286042429, 0.13555463103036727, 0.17554359330284983, 0.18188139273514672, 0.08476246538902484, 0.15216459700417134, 0.1460305463162161, 0.11531234343325901, 0.13285764913645484, 0.11269296624607618, 0.12909174476179386, 0.12376921867290813, 0.22257144803241377, 0.14286370737658394, 0.1136254178239934, 0.18612455456487595, 0.1327101159239969, 0.21000886245840983, 0.16935585517316096, 0.18442091291710255, 0.09246163370628512, 0.1355022306163465, 0.21979036500617383, 0.12910757213830948, 0.1228796297143544, 0.15721521550609222, 0.1427601629327382, 0.12112353402640551, 0.25541967411916106, 0.1612606960078401, 0.08335242693823192, 0.18806874782087343, 0.12811128245366196, 0.17896981429188483, 0.09957198684494342, 0.10307424972134252, 0.14347835503999265, 0.26510101833170463, 0.11339028245739399, 0.1486304342266052, 0.16388083928294722, 0.22712996229529384, 0.16582730015920055, 0.2545922225521457, 0.1597905426376289, 0.1590631268317661, 0.08810791772820296, 0.15827649242935643, 0.22599380793831042, 0.1752176994998609, 0.1953832327478355, 0.11102708507209055, 0.10789157146768225, 0.26990647337609724, 0.09769867204370038, 0.1471428293734789, 0.1467056689603675, 0.12378387393489962, 0.14160030581537755, 0.15694228902218804, 0.1736731436704436, 0.14906806961422966, 0.2446875330661574, 0.1333670363190674, 0.13237427829975082, 0.11406533615363222, 0.2122326318414942, 0.09836752808863118, 0.14694194579797407, 0.17551140228827156, 0.12847512825241975, 0.1839779149140081, 0.14705561792417882, 0.1483174260225027, 0.14047567342077533, 0.09675952485732495, 0.11837734630511654, 0.11375421252582343, 0.1819547992800513, 0.13975855383661487, 0.10998628567904235, 0.09373726969164226, 0.12795693105867795, 0.19298173096631804, 0.14960544964959546, 0.2139646034207075, 0.19589160869438804, 0.19036978483200076, 0.12003167487320401, 0.15521702837319146, 0.16222690141970114, 0.08745808364643205, 0.08712242222240857, 0.13174236301452885, 0.12105326078111127, 0.1240303167592614, 0.21872720350661587, 0.10229104739283362, 0.11431264465734844, 0.13002120859680638, 0.12099783431978957, 0.22599518689657414, 0.11631677663254163, 0.19957607792269802, 0.0649510256405319, 0.13130483487921377, 0.10757672465256146, 0.13610817552093538, 0.056195916202400005, 0.12242973691994145, 0.1718586337782683, 0.11690377618276304, 0.1694177091121674, 0.11386806851313, 0.13089663258964016, 0.09299715980887414, 0.13635301722153542, 0.08921833919180978, 0.14744863635109318, 0.17380500272397073, 0.19541189975796208, 0.10926700572693542, 0.15449716619426204, 0.3330698405061999, 0.09614906003398281, 0.10712044268486001, 0.07971390000274105, 0.2778328786934576, 0.192174197685334, 0.31533453733690325, 0.14896496950138002, 0.18055367043181775, 0.18633881403553873, 0.2443572419184831, 0.10576510291186073, 0.19805740054336288, 0.10105634348527079, 0.22108154491551463, 0.11299778497026813], [0.07364411643075366, 0.045018306512746124, 0.06014513775646206, 0.05410803932576411, 0.04010164231482533, 0.012793913483619692, 0.03602967432309543, 0.060817395231776664, 0.025097222345310356, 0.028878961757366216, 0.06984522431007317, 0.054247310279958674, 0.08638643389267307, 0.02138323574927786, 0.012549728703414722, 0.0562080855090772, 0.09159983841762429, 0.04493306390941144, 0.042971752418745915, 0.02455336503654478, 0.05359257706591199, 0.018252655751101913, 0.026484289649693717, 0.0928049713313099, 0.021251081751899856, 0.04537677054383582, 0.03773846791215962, 0.08091241391676088, 0.04397116391168487, 0.02275785220967185, 0.055899198858007315, 0.014606270668727737, 0.034058116406442664, 0.09365549746660456, 0.11592110754140925, 0.052530809846376224, 0.047668342538658655, 0.03567903971059188, 0.03799372074765064, 0.014846228558810489, 0.01946112306247796, 0.030707263147398352, 0.02391798511868523, 0.02980502607721475, 0.06738763723161913, 0.033032290201874516, 0.08531345880680508, 0.006135521576769891, 0.014991495108622459, 0.14813593979324066, 0.011671137894623944, 0.03689279494386527, 0.0544163016151757, 0.05459858074543938, 0.06675031336565172, 0.012902993870328271, 0.04470678068877709, 0.057945741460688656, 0.033999759658810594, 0.027847935731012016, 0.04139007579895758, 0.028715262174486157, 0.06836684315555519, 0.03560823786462988, 0.05014301337782414, 0.04935392366361715, 0.025564149104719682, 0.014975608360292691, 0.03714127556210564, 0.04437289275829831, 0.032492447193832166, 0.04349619705951022, 0.04966222425742496, 0.0850775037261267, 0.03000687109306455, 0.025039346317850777, 0.07558418047283927, 0.03008923129058413, 0.03477046326283486, 0.07537162171736841, 0.026667139515460982, 0.012797456640269489, 0.01336639854050572, 0.019208844563352968, 0.06902760165112634, 0.0183358222561618, 0.034876757962328774, 0.011400203239322912, 0.030263087284120343, 0.025123589176444278, 0.0465292425736064, 0.05154097445249077, 0.05110149279296879, 0.02253449736012807, 0.029501494380735585, 0.019721818952670982, 0.011567713152016363, 0.032444091724051584, 0.06004454658156442, 0.004519877097223916, 0.0908216156606232, 0.04839648612804952, 0.026262930459192684, 0.028019413021543337, 0.04589967917831195, 0.035825481247757716, 0.026104166397764802, 0.0393210829896552, 0.0770783047342012, 0.04273181751130089, 0.002042075113070408, 0.1956400560635713, 0.02636301601606031, 0.024788412303032897, 0.024667590661274812, 0.02755438041452679, 0.08035488576898653, 0.07373417006625284, 0.06320307346721811, 0.02311715510703864, 0.03248197477190726, 0.05566600169385633, 0.04523554606543434, 0.07505091432962688, 0.044635676238084995, 0.07851354747770295, 0.012953433099262899, 0.024667764946277586, 0.06119065625112384, 0.08832613021255502, 0.022407738536956812, 0.037852810365298105, 0.024364422856559678, 0.0412601089826034, 0.020035719649205287, 0.0192610745228106, 0.03382071341958738, 0.042672970467397285, 0.009755209452592799, 0.021760122279726693, 0.001773701106656283, 0.04894182581694857, 0.0373394433559189, 0.015751265680357333, 0.015890263715728877, 0.01275424928134007, 0.029235056661550077, 0.06505426364920794, 0.05627000073511755, 0.06137543665846029, 0.028855082796766397, 0.06969098016739854, 0.033130567791240836, 0.14700986715334077, 0.01887455826715356, 0.042380102714824106, 0.023940119314037507, 0.05517129275587298, 0.045027518720035596, 0.03896460695672901, 0.053269425857692, 0.08044712275506989, 0.07730032467553694, 0.023186302203084194, 0.0608843551467984, 0.02341311210916648, 0.04296678816899658, 0.015314828262724465, 0.14148215973569503, 0.009144557895319117, 0.05398169993573139, 0.011671222164295616, 0.061243964479334896, 0.027655450394377116, 0.028833758739394047, 0.028989575277533264, 0.06296248738503744, 0.060599236373579314, 0.04356232959957373, 0.021974222787145167, 0.08633685268221364, 0.028345959914487698, 0.04358699380029594, 0.08084860645354756, 0.020506095719493685, 0.04884526809497226, 0.049176934370470625, 0.009909598194363137, 0.03790316915500068, 0.035663204673197, 0.0331242437354259, 0.039584613405168056, 0.04278692987657363, 0.01936347749564917, 0.04127459953569117, 0.01895980661614768, 0.012643619481804631, 0.03757951998962991, 0.011156303826869737, 0.0514120648374721, 0.04925332099740063, 0.08007404559682454, 0.021968065355453762, 0.04654783552752868, 0.03138671610354176, 0.026476716870562206, 0.011097862809566001, 0.002794925277421792, 0.03318163138183375, 0.037181977813522664, 0.030607462958282525, 0.020578990900708784, 0.020845982118419582, 0.03871325350877258, 0.09146935066148158, 0.033644965188878204, 0.05290669471686406, 0.03393164678146282, 0.0361037090600979, 0.0335877116078571, 0.06341507297850425, 0.0187685776637086, 0.031224217363483006, 0.021696479525417093, 0.09058205230582146, 0.0597788404763466, 0.021709029960836616, 0.005747881087083971, 0.03599286379833375, 0.045069519490484274, 0.02324580808260268, 0.01920592576836146, 0.0661068684571693, 0.06651216727350989, 0.029726318203874176, 0.07082209366584016, 0.016205147877635977, 0.03522669543482123, 0.0824266173426182, 0.024111288254179304, 0.01523667197268937, 0.04966902711819257, 0.015911471902302677, 0.03521925289063685, 0.01306971567006962, 0.02354834003434066, 0.040480039953704805, 0.0497921297867452, 0.05916509679668854, 0.19044026492103455, 0.06473034635306367, 0.01147621448317002, 0.05081995931123534, 0.06028094982367851, 0.06529563497151099, 0.04317217634149617, 0.02055573821698706, 0.012671928345826606, 0.04643664169575899, 0.05589545268805758, 0.009822781280344053, 0.030808900032312642, 0.022835738453713637, 0.0710145655959364, 0.042213478591293103, 0.022192747452326363, 0.022087839371975393, 0.0447507388138723, 0.02095579507670576, 0.022136734933742595, 0.030371852617170063, 0.05303101163477667, 0.0035148497009950303, 0.06916150615941133, 0.042918252668553786, 0.050940376841613365, 0.029924185308177146, 0.014658970814648897, 0.03726270432854372, 0.040263110666625926, 0.06248920592629622, 0.02199007506151834, 0.03106603169843795, 0.06493553534270295, 0.03976065274928847, 0.017865321696585706, 0.06627468001698295, 0.04148062356116791, 0.04506706417868695, 0.021223550467121027, 0.0372185661727863, 0.04325017175306717, 0.10113845278899516, 0.035152323619132085, 0.05438301509486572, 0.01401446583200126, 0.05627169761986983, 0.039701185174166195, 0.025277894606152852, 0.03951998622787576, 0.07386320991621864, 0.026680502004080245, 0.02525600938937597, 0.004287384733963277, 0.05869085772804195, 0.02888377661997032, 0.011460555645997727, 0.010209364568694465, 0.04133161945989536, 0.06536120443695015, 0.04027366735822251, 0.06003352640677364, 0.007825025071900698, 0.02106872409762394, 0.026482123536087816, 0.01852491190807233, 0.06281097051537325, 0.07445191784251122, 0.02582848965821247, 0.052176792955686974, 0.006708352330831752, 0.03330387220147156, 0.018902110619350307, 0.03957159374089491, 0.04257181621787529, 0.06910006590788403, 0.034498563336749236, 0.07021213446052806, 0.015818043649497054, 0.04526841506782559, 0.025054941952769316, 0.12071211416754993, 0.02431613633469228, 0.013432814533101215, 0.0621590526744483, 0.04808814722984549, 0.02431430346933344, 0.10199267146808487, 0.028727201654786066, 0.008162629486422145, 0.015157737145801226, 0.014644992582860493, 0.048202087486823725, 0.07121618461584853, 0.04184468386454448, 0.04108374022067555, 0.05329482933326114, 0.02242185562218149, 0.039565396089587486, 0.04928504469834509, 0.01877286584086476, 0.03286515279943424, 0.2585638981432684, 0.18903702167013, 0.10987390058055041, 0.15224465319225866, 0.13813498369868726, 0.10231834310557573, 0.13568082103325477, 0.21700028810770283, 0.09378591627483407, 0.12225692280598226, 0.11622942728741516, 0.171413904416465, 0.22999574400244222, 0.14475494863525515, 0.12870309303604788, 0.13930870700747738, 0.15024954573281352, 0.18649665879145746, 0.09691199167601525, 0.11948009922860131, 0.2017354499548674, 0.10361869308737018, 0.06128746678211516, 0.14981013302120472, 0.12794367007670865, 0.19377262481758672, 0.099474479173941, 0.15292791169016592, 0.15238457149074924, 0.12080474185847467, 0.18453519791364673, 0.08719267248506508, 0.16824833718278717, 0.16902973154379478, 0.23063763375243834, 0.09456184842894155, 0.1843380222036954, 0.10748674762585472, 0.18626096418067334, 0.17243249492058832, 0.13263597393468504, 0.15064051104409082, 0.14225843662936843, 0.08333604031753156, 0.1085915613258558, 0.141389018765861, 0.16934457835891556, 0.10147622861568967, 0.1567652614246453, 0.1893554844202534, 0.10867246021065982, 0.15911333623432344, 0.1949643971578729, 0.10201002335956982, 0.17036034965947752, 0.07031469065095149, 0.13116701566163572, 0.11712251726778285, 0.131036811358025, 0.2233632458674331, 0.09749480072529086, 0.15108881037562125, 0.12806767672901193, 0.11669332416908396, 0.1894361994439556, 0.1513988155150606, 0.11691571949350259, 0.10350451534313541, 0.225695094934875, 0.0874196490152709, 0.13166982980985797, 0.2187846907444539, 0.12763138199525495, 0.2440138659890621, 0.1370452236263983, 0.09605300026915728, 0.16997790324591822, 0.13068082562137034, 0.12428401443626612, 0.2561061501863503, 0.09437218804152743, 0.19266394237356801, 0.11355347450702422, 0.1502999083529557, 0.18998168468956025, 0.0934931940789665, 0.10292529924622468, 0.12493884341130335, 0.1615538165694283, 0.07362158578490058, 0.09953738265340367, 0.1659686587029888, 0.1797507183566209, 0.09120259118536789, 0.09554052575220985, 0.08152944411361411, 0.11743279819887494, 0.12478874380429908, 0.14581803352602069, 0.09321737944358781, 0.22062944578787974, 0.09097228217269145, 0.13858375800473077, 0.11796210366751879, 0.19193497907009818, 0.2025304500374102, 0.12652870568056263, 0.1565933359726783, 0.12992031481717864, 0.13133002385016412, 0.16168809646079618, 0.23048346621855614, 0.14350997914950694, 0.08810743509281067, 0.13518021321825444, 0.1200033066373679, 0.18469906412065032, 0.11054195223316071, 0.24270175655763, 0.0903326064167965, 0.18992441195634105, 0.14366915689841395, 0.16119747843232848, 0.13776813483526631, 0.2486833863921704, 0.10882636727464777, 0.13357524369512835, 0.11853848523910969, 0.12381815636951117, 0.1877044270476026, 0.06229909354700677, 0.09891270689906613, 0.2263465761056831, 0.17411696904849622, 0.19821424938498006, 0.074743353010666, 0.15518862183295912, 0.10496464062241778, 0.11282929159220188, 0.07966196690235408, 0.1154910487633559, 0.20623157401719402, 0.17189209649880088, 0.1036238871634968, 0.06694294617421205, 0.053694470590280916, 0.10666196204481587, 0.16946981841277692, 0.1440488913607213, 0.15347433156303822, 0.06900310215930786, 0.27767809828923595, 0.13842842601720365, 0.26981981351010265, 0.09391444284589061, 0.15808143112207615, 0.14773624107962655, 0.13269667874180502, 0.1620675551314508, 0.140704411953207, 0.2359380428829501, 0.19872446394255086, 0.1475753166502522, 0.09858963996051781, 0.2548614258487379, 0.06465963643765257, 0.11549721577114637, 0.10972081323064144, 0.1511163435756199, 0.08419906134687125, 0.12810981156484735, 0.11696412858943786, 0.13026977348471844, 0.18759587238873207, 0.1564648017407425, 0.14424645011463474], [0.0366952323595122, 0.027707132600968885, 0.05905229418027786, 0.05744857338046836, 0.06467141886992801, 0.014202724278513944, 0.02020625082115012, 0.046870703283216686, 0.03245562134731201, 0.0330837598190673, 0.04223326664237727, 0.032610543477799625, 0.019429539172579686, 0.10080197931177194, 0.08650501664247244, 0.027180353307255337, 0.030682549150961063, 0.04608948129199205, 0.03323806141833625, 0.021418445150277788, 0.005079884975848179, 0.029748525177579255, 0.022682101435719, 0.08053447210019635, 0.013144197610897884, 0.02350016076478266, 0.053550308164689815, 0.033522452408027266, 0.013992065421095299, 0.03912967592177372, 0.06883118436822007, 0.038936020385834484, 0.01614332075170692, 0.16854858236207118, 0.09200931241315219, 0.06882255055731343, 0.10329309039779248, 0.04096239572390914, 0.03858768403710377, 0.02535311103377852, 0.01526651013973019, 0.028744622494184205, 0.0304490321451017, 0.023621384602700992, 0.03491561394184828, 0.08847498109624272, 0.05122992743347442, 0.05081368888157511, 0.039237839875802885, 0.0704862024154394, 0.09462789286889377, 0.0632719409411713, 0.026631008893732103, 0.028953630432126023, 0.03731129345514121, 0.053931092167453426, 0.04659493078267382, 0.0485758311415632, 0.06952152917942694, 0.021986920694490115, 0.07478838365885519, 0.09649393749573539, 0.05055808364563892, 0.0793519004758808, 0.03606262759515836, 0.020481856697569453, 0.008322043764975764, 0.01077365727284022, 0.05683851458372609, 0.022964190331197554, 0.013324956056631863, 0.015056936254334307, 0.06972065841358516, 0.054411685935431914, 0.07702909124594542, 0.03682078267898291, 0.03321184972000699, 0.051691721403791066, 0.11369906951703372, 0.05754901899866039, 0.07439975491574696, 0.07455240559553908, 0.020564931272078427, 0.023240311401745966, 0.0630077593509228, 0.051371795425732295, 0.06560435308323753, 0.12519185927005547, 0.02307725724794211, 0.07702131545351398, 0.01788832923217166, 0.038335012917917584, 0.018176433833075628, 0.014994904199885506, 0.0639244371784791, 0.054147715019362594, 0.014378707123649938, 0.03632329284183441, 0.06276757546490239, 0.1480415577609693, 0.016694362049982432, 0.02260302584017477, 0.013953509173476169, 0.017929071703204708, 0.07987391278748551, 0.02473167200092106, 0.018603843862130758, 0.036593109008765994, 0.017878408393552227, 0.03408422468290214, 0.041420045158555435, 0.04268502486088584, 0.003933641959109434, 0.0719964834711244, 0.05224303274805989, 0.020905202630186276, 0.08700059125981024, 0.018856564777032025, 0.04027549447792192, 0.04967392242002872, 0.04582276778115381, 0.022098041747907, 0.012496698182076217, 0.019113684951838468, 0.030139111275334033, 0.09947981114589399, 0.03564275012561872, 0.012075094141877227, 0.010199416916997684, 0.0495465258286605, 0.01380127696921268, 0.07954852460252662, 0.06482030805801192, 0.05519295389193201, 0.019239806006812764, 0.05478063771020501, 0.06372184522690312, 0.01552485030955605, 0.05069340541658383, 0.07055371774420624, 0.020966457105391932, 0.033695427400450555, 0.011968964151287032, 0.03259862698013744, 0.04716196225114888, 0.013631502309093073, 0.023875877095927155, 0.07305556172204596, 0.11787674615099547, 0.049555232417919946, 0.0868515182106245, 0.006742448989121665, 0.08435708996389182, 0.017835264236876563, 0.019147494327156775, 0.07894976560266749, 0.02688225700459894, 0.03169449575756106, 0.022164413690446846, 0.08419369107052203, 0.0393950526091841, 0.05097766617132772, 0.040364774364617564, 0.029447692025813366, 0.021754127641719197, 0.05232400441121671, 0.011827715732637915, 0.04207745201945786, 0.06412178142777374, 0.020414398825396935, 0.017431271600446874, 0.01919435592548501, 0.014872717006402391, 0.025915712598831426, 0.04823097666244834, 0.031834063570826285, 0.016776013616172057, 0.01953420976567413, 0.02644786025367437, 0.013432691001423426, 0.003369007388227469, 0.07265420825851542, 0.024853939633636225, 0.06253949959852523, 0.01516716768814912, 0.06198129729337751, 0.01586773306987579, 0.06229056315796991, 0.01734906845095177, 0.022030698788923123, 0.07045957319919141, 0.04167924334685649, 0.05085773127634199, 0.022647989455670602, 0.012645217732736662, 0.07045185103291465, 0.019978004500209805, 0.023459833896448536, 0.020273141788258668, 0.04721832717017782, 0.0390259399559469, 0.06783744575636041, 0.05573222233403114, 0.00775146195777662, 0.009230610636633732, 0.028109765431332975, 0.03719236596577591, 0.014034999861201693, 0.03675474206947031, 0.06962433051798614, 0.036843014550545526, 0.10032544964023175, 0.03766046867014901, 0.07779009234640868, 0.01819232632706483, 0.06421139073227683, 0.15699589985512918, 0.023226481599492893, 0.048744837798538714, 0.02062442757549786, 0.045580381392351085, 0.026850479677499785, 0.03480817777134719, 0.0007050180283840747, 0.019159435722676497, 0.04028933002583442, 0.06389657073023339, 0.06431180953739152, 0.034232355443941015, 0.0730532787800316, 0.04992123858462419, 0.02430450328956208, 0.004988013796748654, 0.014332480420688949, 0.020450014252996734, 0.07080562277546815, 0.03213955645239161, 0.08498196490108968, 0.03598457089655342, 0.048958875103703434, 0.08139581539698186, 0.011445588203177098, 0.08477329787227415, 0.023206117067245707, 0.05535098633939221, 0.01920213746357589, 0.005253532210425024, 0.028756023797717307, 0.027497061716032126, 0.026799138380034317, 0.04992894925958207, 0.028608523143996156, 0.018277781519798503, 0.09083905182177983, 0.042750912252813585, 0.0865984870301139, 0.04126025453930901, 0.008546241311236255, 0.027723582423922997, 0.026489908904618314, 0.08161379039407739, 0.07284515567364232, 0.024411678990168918, 0.033278844108985316, 0.015432868047707505, 0.06072759440529251, 0.021889604545468767, 0.03125589318393219, 0.02226523660694159, 0.031116871208313013, 0.028381479581096963, 0.10032324330700983, 0.02363213281627865, 0.042393244953165134, 0.05680997780854664, 0.0677628670969317, 0.009333319087032109, 0.011831683110475782, 0.0741194356833735, 0.0598926849723343, 0.008713122074221893, 0.025389391042652632, 0.005857890834205694, 0.021570333572585258, 0.025435676159817847, 0.06690805853014031, 0.01742880288211088, 0.021970564717306726, 0.006966299401791467, 0.06495991226045356, 0.029791627199419086, 0.007682580119674846, 0.04269820540362308, 0.014115654555479846, 0.048954765041989666, 0.06285280657691822, 0.025426433309011405, 0.040484379841795856, 0.04366005943607419, 0.0290601147383812, 0.04965333380706368, 0.048841813038433754, 0.039165138131788665, 0.020561376624109767, 0.043182407445724935, 0.030973718103562153, 0.021358828188010284, 0.0072356027686187345, 0.021548362170916893, 0.07631069229495141, 0.03441189580987539, 0.03166808104593187, 0.024430679885910887, 0.013911595545528878, 0.050373896956443794, 0.12810818745844788, 0.03107616704167618, 0.021048219754330574, 0.04476867293217971, 0.03398829515302374, 0.05778253025886032, 0.03275149599498799, 0.03428961668584136, 0.03713024389599601, 0.06785941715802878, 0.06508755783039717, 0.03960851151796599, 0.09137409528897655, 0.026155588134462317, 0.02199503931126768, 0.018504713999948675, 0.04157292566472485, 0.04506698756989452, 0.03894549689345783, 0.04619910847395659, 0.059707326168615016, 0.02652285643102181, 0.06750815818386693, 0.0645241384664851, 0.11848145765402626, 0.04899584650692921, 0.028980541185686187, 0.01834272087791995, 0.01895871685607539, 0.042843336930438396, 0.0559505267489341, 0.03201890526519668, 0.03962241218335206, 0.07412545713445834, 0.06140460162573765, 0.12356013029573426, 0.07083822747752552, 0.1610861965004475, 0.08966572687871034, 0.08864785649723585, 0.10797086156784527, 0.13191160715876088, 0.11751952701278272, 0.12171008158475162, 0.17947694917600002, 0.12137679503329339, 0.09154890123153887, 0.10631316987377022, 0.1993223649239348, 0.10185584050392914, 0.1470381817630222, 0.24859985216490685, 0.1924529464374627, 0.10166061831818474, 0.14590509175773592, 0.15232239579481466, 0.1705209523319237, 0.13920608186914077, 0.08816371957260756, 0.08378261595123238, 0.2519595154350804, 0.1448146422063151, 0.08891433252081757, 0.1582001900720981, 0.10983767994349042, 0.1105835278248114, 0.10842726610961462, 0.10385021251896698, 0.1197453341897457, 0.11847925898168357, 0.25973291767220347, 0.19910416776134124, 0.19960917292102692, 0.18899375302416666, 0.15237931612758868, 0.10711834360394748, 0.1341470517218113, 0.23226288928379937, 0.1107367990358222, 0.15595932160654377, 0.15027625155785393, 0.09386182026637178, 0.15146584820843514, 0.12292042389632234, 0.13793834425028295, 0.10634100184805932, 0.25206742658009457, 0.17722016140337915, 0.1745666320165319, 0.19605694579020624, 0.1647730865665982, 0.15270761544665984, 0.09488301546943766, 0.12004256098260803, 0.10369728604752211, 0.09829491827516787, 0.11291654900677743, 0.13096648448657605, 0.17083006880937085, 0.11090179139207448, 0.2103935611704665, 0.12208004842602438, 0.08647294820196207, 0.2289141197839091, 0.17406795474310077, 0.1876153157002503, 0.08784076754724787, 0.1902455866577164, 0.09870531923708417, 0.19083054075317998, 0.11729159287267155, 0.1421559493868582, 0.15273799849373682, 0.11538254773064006, 0.1976468387029825, 0.2266697119921446, 0.22063718327591497, 0.17558667808771136, 0.15569433179353515, 0.1818868472811676, 0.17095570722895284, 0.16610019599958775, 0.11114775158104398, 0.10810330284819489, 0.19978515863899263, 0.11181437064923587, 0.10533901246925516, 0.12820210983796468, 0.09192370208761386, 0.10440115231059252, 0.052454576437031074, 0.17030951206482228, 0.1501908940413306, 0.039822196422685543, 0.13395484026160934, 0.13848286422510303, 0.2877955150700385, 0.0983496169529615, 0.09116985624836338, 0.14348814564366497, 0.12928790923568512, 0.13552993235568847, 0.06306898892827092, 0.15170201779373232, 0.13564280775045195, 0.10080479851533329, 0.17424406303513437, 0.12720425733395163, 0.09560117693317514, 0.12205131246798462, 0.20008092986479883, 0.15874814212081895, 0.1062767653756084, 0.19722814100884623, 0.1717597318272437, 0.11132049674708998, 0.20301503129303458, 0.0839000955344208, 0.13801810932495903, 0.131678318064059, 0.12718861381853783, 0.12293065117011148, 0.11021852523328797, 0.08405569565272139, 0.11713982319399235, 0.1374479866917095, 0.1296593852701687, 0.10707361173004874, 0.22853623925437852, 0.11751542844238783, 0.14185921289026737, 0.13963516771553025, 0.1088562983298494, 0.14618741047959175, 0.09710280119531578, 0.2014078247931696, 0.17321575853613116, 0.13971157732509798, 0.16715224922424363, 0.13066898190206097, 0.10982361456920063, 0.1388561788706049, 0.11017286639300086, 0.1591797254138416, 0.13979115853867224, 0.20388159930946367, 0.11586343644246941, 0.2551486628550676, 0.17277346533392707, 0.16708103369080252, 0.06746615358297864, 0.07298872055065247, 0.14457929999597613, 0.16709874564361188, 0.12135838594047293, 0.10241722207396262, 0.1544649598579253, 0.13693648510642592, 0.14890421872898457, 0.13439272079736958, 0.22702727586992327, 0.11355348216790347, 0.1361526545858191, 0.13165141305615827, 0.08713253458300907, 0.12992917079358332, 0.2799561986279103, 0.1567532644877511, 0.11426776722674409, 0.09389308431456167, 0.08185246508688697, 0.19922363151225353, 0.13671068835162348], [0.02775308446988704, 0.0705334700403675, 0.05907379826831241, 0.052446360144043164, 0.06758207800768076, 0.059087679781500375, 0.05060015336400078, 0.043774758120097464, 0.03984542803898935, 0.06310063602042294, 0.07340193305525088, 0.06435379881652133, 0.028777558529268832, 0.035552474324621504, 0.10940961299404021, 0.03073964568395769, 0.020002551872523564, 0.09399603120982648, 0.06279534998259718, 0.04042979607719087, 0.027799806257169095, 0.035444069052896196, 0.06726097225421859, 0.01965816470704252, 0.03906162816189951, 0.02151707705530909, 0.04680144127398249, 0.04156652500011748, 0.05067911787679599, 0.025598278321746378, 0.04281262446555399, 0.022029413676430142, 0.0466883322224021, 0.07643866728270247, 0.050985656468377966, 0.0745256538052232, 0.06584200121822857, 0.043727605408358, 0.04430195301650994, 0.015476017950042604, 0.05906948136285909, 0.046560138899592624, 0.03455110164659639, 0.06936288769206694, 0.048206270326890295, 0.019896613403914437, 0.06318135870500438, 0.02601735905984477, 0.026871181288433653, 0.0943100429891098, 0.017163345755468455, 0.026831515170934222, 0.042430220186830535, 0.04269766531163647, 0.039717410916402456, 0.022322059263505285, 0.013731811946678548, 0.09654538029985082, 0.07156748189440659, 0.11508318355246899, 0.010050325673223745, 0.040781775174001535, 0.033534817067125154, 0.010968711876851178, 0.031124087756559737, 0.0240008260363773, 0.04747259558268613, 0.012854501462331223, 0.018534315637342872, 0.01048504418107651, 0.03785685147909868, 0.017648631811983163, 0.02852101866606503, 0.04869846649648202, 0.06001514029659091, 0.036536387858852264, 0.057536895657258655, 0.0112443340326389, 0.026495671801028714, 0.022602324869724053, 0.03322727106992276, 0.046164684313079046, 0.04343397156786054, 0.03720622066588652, 0.03526665075051208, 0.04844541616377331, 0.02405694580727047, 0.018325660099846222, 0.06411601661614354, 0.04431450153670965, 0.010771798552013935, 0.030747620659249447, 0.06616109216044988, 0.08229452846271378, 0.03810816279221927, 0.059304448190115155, 0.03666628572729327, 0.058386510147923426, 0.015322796534746887, 0.04081341843571394, 0.043214031555239237, 0.04625525888836673, 0.07881347090005875, 0.07750766637224345, 0.020445532638639696, 0.01552049031165699, 0.06447476409976521, 0.05719083458966306, 0.03517178991328805, 0.007308721072941779, 0.05263873631314886, 0.017360684259103674, 0.008197160899609087, 0.11386796892169984, 0.02562750457605768, 0.022879376737100464, 0.046241300766386335, 0.039819649180337306, 0.0291170101732977, 0.013429589302939995, 0.03918364298559966, 0.03997135374154295, 0.014985769558998366, 0.040127765913043296, 0.04746242193505169, 0.06267071513819598, 0.055507352545617096, 0.023688629885474523, 0.04550997791210971, 0.008862917161276265, 0.01765362287480985, 0.07580257681829315, 0.03551821487264768, 0.004389584693501914, 0.03872597439875526, 0.02240204650367941, 0.03960376177283545, 0.04191074362625519, 0.011993522057309748, 0.016445349000634688, 0.011677299156754969, 0.07238239260210146, 0.03713512004563405, 0.022176941143228643, 0.03876809774327182, 0.026048701632046894, 0.05796887348556231, 0.027947680378753333, 0.05777570441545499, 0.04197918975185003, 0.04416139120416295, 0.00723374069615778, 0.03199912870543138, 0.04071680325714331, 0.022782409158084663, 0.02745331043467647, 0.030698721267042622, 0.028165358516778198, 0.05377282989361594, 0.04610525504235299, 0.016333977053422603, 0.01848770493280984, 0.031219306739888368, 0.06526185049405021, 0.05914000741716835, 0.03142946380971661, 0.03948718234295807, 0.05832869349227798, 0.026694624834964355, 0.03447336287448003, 0.03352454765850017, 0.043317725386230216, 0.008272605238392228, 0.03206398570910096, 0.055686073197472485, 0.022421072297278914, 0.026697773456333146, 0.06417633071842213, 0.08157644360776871, 0.04870189090950355, 0.09155255547093769, 0.028879649321278258, 0.043375971051113266, 0.0654846518450687, 0.05164644943790571, 0.014410730556494769, 0.023633791396634716, 0.025928278356009436, 0.0288066353964349, 0.059486501324441166, 0.06833994580853371, 0.03940356001558323, 0.014834726706237323, 0.0169329984383958, 0.09269324506843284, 0.007613190748323236, 0.02153701257831868, 0.026238836993974064, 0.06526303026945361, 0.06804564547154211, 0.012979248347091339, 0.01562661072614813, 0.040015813654228564, 0.041078366113886725, 0.08259218426481371, 0.056563205566377416, 0.05681568899402215, 0.013728494785966413, 0.0443025735477286, 0.10751343812913665, 0.0869318578512438, 0.01723118284116349, 0.048601498917466214, 0.045086947990761655, 0.01366181640825685, 0.02853942009800625, 0.04636572493660835, 0.022189704168047157, 0.025184661705767917, 0.04116332909512905, 0.02272271750224454, 0.028286925179042646, 0.052481320566467704, 0.06438606643989202, 0.02900562098910732, 0.07078384289578085, 0.10783903315783509, 0.02049717271039563, 0.01341587537148547, 0.05720828607257816, 0.057571266191981496, 0.080217020586133, 0.01569147539069696, 0.08008742915286172, 0.024257233749414166, 0.0541347413203649, 0.04081848993777268, 0.030149256194671317, 0.034477047757395816, 0.038030370393948215, 0.013762402795104971, 0.04429378268879749, 0.03348895904397772, 0.03709722167601989, 0.011578511161309098, 0.05575144731049096, 0.01018696511539841, 0.06169535880607944, 0.011214310089276444, 0.07836695655339188, 0.009343851838381061, 0.028473609314870932, 0.036661723673704176, 0.06154246680859116, 0.0671828695903382, 0.03337257496652103, 0.01571761622589322, 0.018473739149950204, 0.14666653718919526, 0.020656340883203575, 0.04071273533026538, 0.030045349774281346, 0.015964345375616706, 0.04852703134078653, 0.03630268124623164, 0.02974635331831392, 0.06503079837608723, 0.033370996825397015, 0.016116521080895778, 0.0163117834862562, 0.03779092578277473, 0.005936003552990095, 0.012210532741230583, 0.03215138101950288, 0.021618118306862253, 0.02812477117854982, 0.023860679826729243, 0.07324854693105144, 0.06377400049278814, 0.02171832643779776, 0.06917343414839237, 0.04322776751172158, 0.03502889919365126, 0.06884724923199223, 0.06351423539942311, 0.03159991837286901, 0.052610931151937095, 0.02693650177529743, 0.028194716921256437, 0.023564052497667652, 0.04078480888218169, 0.009477035266407316, 0.06880244841018031, 0.03098572844699506, 0.04030751695315685, 0.05017618881538511, 0.03497732998502832, 0.05206779013538072, 0.08459403329799253, 0.04160723874285337, 0.03830497844084617, 0.04025857542611418, 0.06407912565214981, 0.10411249038072364, 0.0640989366858717, 0.05225149035874394, 0.022546199353171453, 0.07318896061230092, 0.011215127888135614, 0.07888434169393393, 0.024881800336222497, 0.04215399569441234, 0.07366001275518248, 0.07734802897058188, 0.09554669276000032, 0.04872927855279657, 0.026018213247880343, 0.042289700509319385, 0.02254940734635438, 0.03698274515749466, 0.022740398811536933, 0.02079093870106003, 0.04055692836822521, 0.04324240362151496, 0.026012812328014164, 0.03435718947120252, 0.04401681126065312, 0.0638728066828222, 0.04755810248635469, 0.1037979040354971, 0.010117116091292231, 0.03220053322072471, 0.061621921617657914, 0.042343556490396304, 0.041251145753889315, 0.03451634423747178, 0.07995997510489919, 0.04475855291069997, 0.013249786551891556, 0.07538155021686709, 0.007934640283741417, 0.04262577945126161, 0.05542622383443579, 0.0773077480675232, 0.04981114791946546, 0.022232932594394492, 0.015464096664330892, 0.03926091444408221, 0.03610494246165599, 0.015385815885008104, 0.04905892618661446, 0.04629208856532651, 0.12821395355727405, 0.17643922669512613, 0.14159515770452638, 0.19036658258447725, 0.19357744093623855, 0.17736748011121828, 0.13642026441952876, 0.17515432870676442, 0.13768512154779128, 0.1995628705668834, 0.14546528068040648, 0.1835784766702883, 0.12096413411200048, 0.17770043724486906, 0.20314710485118054, 0.11283513684306415, 0.21392272905476634, 0.1570841378622478, 0.20993576234867498, 0.1303148194546661, 0.10581568769750097, 0.12264031150768842, 0.18385584646415326, 0.14508968309289025, 0.07996047306204997, 0.20889106356809217, 0.11766670782479549, 0.13049589199644904, 0.16796157515097052, 0.22808277649023842, 0.19698656284280364, 0.11085443183659546, 0.22124125892596863, 0.20681971503842264, 0.24799360082514826, 0.17083446615405623, 0.13811915632217162, 0.1524261547432792, 0.10931556037957631, 0.11650920259736239, 0.1633431528124117, 0.19404239501924286, 0.08134166064161448, 0.18392202113905262, 0.10564579237853328, 0.1032731184856065, 0.1711071781333416, 0.14498054620719728, 0.144698150876549, 0.16523543595065995, 0.1266567189727099, 0.17103066127146446, 0.21053767763078216, 0.22961645387113097, 0.17699719917389656, 0.13268524870997475, 0.1717437512331432, 0.19201479011004974, 0.18324705171248606, 0.18704689378219266, 0.09532029845661695, 0.2500038615037357, 0.08898455980083636, 0.13575301715923896, 0.1810689258479303, 0.1670196240827922, 0.1636510895144555, 0.10462920136389234, 0.09993112886384611, 0.11294719252374866, 0.08751046873869435, 0.18443053498143153, 0.17531269440247169, 0.14318183304802065, 0.17921733730021985, 0.1401942893261871, 0.13922429943998016, 0.13556434502524717, 0.24599720633799033, 0.08601550944149496, 0.12029943026361928, 0.1795760809534019, 0.15338074626220813, 0.09603740271901894, 0.07861901480223864, 0.08457747047706958, 0.1477167364810744, 0.15410736533662966, 0.1814107083144688, 0.10777851221181693, 0.1259078297223295, 0.1001156488012883, 0.12167052846522101, 0.16776839841998395, 0.088103344183295, 0.13983245067779096, 0.14004819635902682, 0.14619718576150556, 0.11659992272935568, 0.05895729927766708, 0.1290239919457705, 0.13138182671560397, 0.11056334906888586, 0.1729951252139384, 0.1414607858826076, 0.11925466253512329, 0.1555035912221478, 0.1432865572672698, 0.19226882486574112, 0.1243089582590807, 0.08968247356073511, 0.07961554197414268, 0.10245594015765576, 0.18559494266106238, 0.13868115842342377, 0.13992818102480906, 0.15330642041179443, 0.17284780650609927, 0.12607387161903805, 0.11817462411859345, 0.1507942495687354, 0.14165140387992706, 0.21372394456017405, 0.09719211938640765, 0.07888713791485756, 0.20522485787589706, 0.2388243710682277, 0.14552198650856174, 0.19453849823724842, 0.1236522906730252, 0.10081234448138746, 0.21650174873009806, 0.19576698151086608, 0.08377421962758226, 0.11779149588678153, 0.17895939549611461, 0.13848775186605994, 0.20093433649068881, 0.08855952655956631, 0.1169407246033511, 0.1343431702304271, 0.14974135364736282, 0.07404124108894218, 0.20243603736162188, 0.09434139130697136, 0.0896625859182208, 0.16821449141829245, 0.11513852574411901, 0.1133614162644071, 0.11585330109923117, 0.1074947455837842, 0.08778075988013899, 0.13125012087966167, 0.27238390979266935, 0.09982854202990571, 0.16832467018356248, 0.11084044307109811, 0.11281636002804003, 0.14712130230280662, 0.10403222734889678, 0.166189904895521, 0.09283608216191493, 0.06791351062636222, 0.1267758456449355, 0.16317594646205827, 0.16151171237710985, 0.1614372333091113, 0.10082066419624514, 0.12628137419420865, 0.11782114348945119, 0.1691705691477945, 0.28102930394872544, 0.20733887750294902, 0.1114556423178123, 0.09160433535373981, 0.17071176951210346], [0.04531537242714436, 0.039872336877329696, 0.014834983345691957, 0.02525411906742281, 0.029610792144892678, 0.110302611043857, 0.01571477403969414, 0.03603941513105266, 0.023477743116898403, 0.013017543167206309, 0.04657260315012067, 0.024074441340241223, 0.01214988922114454, 0.052213404297588334, 0.06650711109320964, 0.040341056282481844, 0.017742215197593454, 0.04756137368179137, 0.02398560961498128, 0.02425470757448385, 0.026464097487229495, 0.030540939713377627, 0.039864315936762484, 0.03416868204611444, 0.04888458755768595, 0.008511282804031527, 0.03220909808371817, 0.05505430346895611, 0.062143930098823005, 0.041618212952368686, 0.03568078256061962, 0.006219863547988597, 0.026231377212811383, 0.033522218751210364, 0.07098284189499195, 0.03791399014693114, 0.02516175184639231, 0.014673956452057728, 0.008131939046565563, 0.02231489442619345, 0.04228702303202402, 0.047975785113991275, 0.030023431998767683, 0.014268795531543513, 0.015164702800252746, 0.039341399641407114, 0.02682341762157458, 0.025059032862284975, 0.06387759090190934, 0.02655902344192709, 0.09005469270050527, 0.034944204343182426, 0.0421850222553457, 0.031482662870398456, 0.040104936492899736, 0.016047852789802898, 0.07476474984639114, 0.027008897084141933, 0.05988911500260715, 0.024108844433700847, 0.039287616438683004, 0.03008794234765153, 0.06081610820406388, 0.0602195976722625, 0.08725277208272489, 0.024914406953499686, 0.029699742613780885, 0.03466037642811576, 0.04237302023196413, 0.004238679736567241, 0.04866075198796969, 0.017369459796276306, 0.048591670009397694, 0.04892862995245284, 0.03385126117556807, 0.03114570292734331, 0.04716791092388092, 0.07666872348636389, 0.021774798609136094, 0.01338789496766103, 0.010133356197677072, 0.0756166166355533, 0.009133141270027527, 0.08417374214097377, 0.032275238284660925, 0.07814403262830551, 0.0431450491680974, 0.050208081055672905, 0.029314446353143262, 0.045788106133019736, 0.04795816509173282, 0.0043510902117216785, 0.04538703229158156, 0.06332841311250964, 0.05542102975830917, 0.04433415935284669, 0.04447818771305104, 0.06640509882521245, 0.029288723035865737, 0.03546969086352376, 0.028420919702658733, 0.03942900179554859, 0.027850630445285674, 0.03518874343905238, 0.06439754243699775, 0.03313872662763442, 0.059231547263240626, 0.010872298753970574, 0.10211271744581962, 0.07099043382632156, 0.021889826710966807, 0.02052928520096166, 0.10816068283372349, 0.051394540576204184, 0.0871871260084933, 0.01908220065337035, 0.007908995969281083, 0.046058473883256804, 0.06250017630537191, 0.030542280367245118, 0.019757438210710403, 0.06506266763373729, 0.015452678123819492, 0.020109980382145416, 0.01257196919346649, 0.10879362467676403, 0.04080681475780664, 0.05474912085300011, 0.01836410622232624, 0.01984198941969343, 0.06340581863637894, 0.04193427401684946, 0.07710242118205755, 0.026516128263826814, 0.02353383990515384, 0.03748823678301227, 0.05013838620676149, 0.12295898876243061, 0.05939246403173574, 0.019505778327584267, 0.03650266083798582, 0.06476175595795916, 0.06763994062860167, 0.012683369868975735, 0.008715555360991388, 0.022461945003259088, 0.03835562068308073, 0.03995848346441504, 0.02683262599842443, 0.04452191984220859, 0.012907876723235654, 0.034070331678395314, 0.04712251255348806, 0.04466014891682614, 0.05542664901323377, 0.07289600859005606, 0.04447467903035783, 0.018622436816053047, 0.0784967854739197, 0.059582859863557165, 0.06638706511547489, 0.013868922532926646, 0.019056211120539138, 0.032269710960287246, 0.08377714608345302, 0.06790850807221667, 0.02463349591820471, 0.032344691815876195, 0.035333714087403593, 0.03876661919357796, 0.05888255973977428, 0.08234083081685728, 0.0074385610059835025, 0.03895297774203843, 0.018198669535077868, 0.003998465685834808, 0.06231831469302697, 0.03556822892278433, 0.06559191947622646, 0.06952529067113515, 0.02653859762264596, 0.037041098074687105, 0.03781082108616829, 0.04276368676895096, 0.02964649375738396, 0.04740365533038013, 0.06448481517333178, 0.03507549649164562, 0.034089031884627, 0.03678047496284689, 0.05390026861982, 0.032937322112341086, 0.053224866353576226, 0.028862621101941315, 0.028423409488412644, 0.024179054476741343, 0.0220801804079524, 0.005120498169544003, 0.028747686845881325, 0.023987208823523214, 0.03500224699476554, 0.0153946383450661, 0.019045041558603128, 0.021892548238317815, 0.012238335029612626, 0.03382814064201328, 0.07047474174009216, 0.00851451569507199, 0.04045087881686707, 0.006331918749868149, 0.050189016957677184, 0.013954308777747136, 0.03437167619385066, 0.01691688186368875, 0.02664632299133847, 0.053631819919833255, 0.03346494601799115, 0.02696040180331517, 0.03020247440755127, 0.048122628847317356, 0.008791488080826259, 0.012997376860209532, 0.017172860567488017, 0.042381642551551905, 0.026264236639103582, 0.017194479568711212, 0.0367914836463188, 0.05130028111800071, 0.06649458555564766, 0.017008234018219576, 0.015622704635344207, 0.06208080828430192, 0.08176385169668544, 0.05431455747795202, 0.035393131866810784, 0.011285252703894532, 0.0038942619275692254, 0.039232304890549956, 0.05232278250097748, 0.017767013463702415, 0.01940117285196339, 0.042007056200095726, 0.015208633154660705, 0.034523131776480906, 0.04815656654236298, 0.06660559935675514, 0.01415567690386407, 0.03865883445307132, 0.04380818636667344, 0.056206568654987125, 0.03670978803007353, 0.005532288144628007, 0.015638299312652842, 0.050036584612943476, 0.01697159203280124, 0.016907671571619088, 0.041174801261795145, 0.05882336412586513, 0.029980058015714732, 0.022965282006489656, 0.04612367562649231, 0.03641871675368279, 0.08372718182903144, 0.01821995337283419, 0.060513503473973086, 0.027448030173658367, 0.02573889567546787, 0.041126418978937214, 0.0399429778448276, 0.040815456229592526, 0.029438144655057022, 0.020826017867112835, 0.06292610586951337, 0.07085951706094128, 0.07023213701623102, 0.05137945247453548, 0.03815505503406448, 0.010219780491634963, 0.020628263760778694, 0.036180421274395726, 0.01425074554243756, 0.018670752066217603, 0.05229483561349973, 0.04551281626786917, 0.032169724994849776, 0.07010746386743362, 0.012005178085077676, 0.08445538670545624, 0.06060121671086358, 0.00985914268606012, 0.04824775781842971, 0.011650315624842, 0.022622285290591182, 0.02016656172101296, 0.016203567821292147, 0.07543314623856738, 0.06301203412154029, 0.09450600828014075, 0.006827839064381777, 0.036494103635871605, 0.08187504935889475, 0.044224922875723535, 0.03905503597531108, 0.05661977349870628, 0.016394618658288833, 0.017648959314570795, 0.01635235933316571, 0.018832668579453905, 0.0667536381872431, 0.04833097794964429, 0.03736502303171062, 0.03709855083856852, 0.023934308537131837, 0.0952885211295178, 0.0652372590716808, 0.008058045078219186, 0.054592605259629993, 0.030287646147752964, 0.06528238165042093, 0.028251328903640953, 0.028449851013119185, 0.02654424369064791, 0.014528448584549611, 0.051656603933342045, 0.006286680300329482, 0.01948699002124129, 0.033547721818209655, 0.018011703861937407, 0.061437581710877924, 0.03345027160380156, 0.03424142592496449, 0.01553861116389594, 0.04306543348056655, 0.021010281165100394, 0.021799606451344107, 0.05571588933948548, 0.08857353064682215, 0.05079717585636724, 0.04210229242040266, 0.062295228633428776, 0.07490046998305668, 0.058035335443433256, 0.05457593901683727, 0.07196968571553308, 0.05249032976045724, 0.07907973241902168, 0.04379139754981284, 0.05923695584398605, 0.02796518357260333, 0.029193017586705186, 0.01779549278228754, 0.028204662657733408, 0.26490465467495306, 0.2125621722230027, 0.10497749557778721, 0.15114701773610809, 0.12506419071747413, 0.18285286883192678, 0.09172513975851959, 0.1032828554631241, 0.1015455672337163, 0.09413387341004226, 0.311656212133746, 0.12598880521592595, 0.0744211134470759, 0.1529388973910001, 0.155246231644865, 0.09927263032765159, 0.12142983130029134, 0.1575761654924962, 0.07831014347292724, 0.08969373505322203, 0.14365342145244922, 0.14164034157030045, 0.1730387615821054, 0.17170791364004537, 0.15151265618060866, 0.0670696494560088, 0.09904949955882565, 0.10584299873200156, 0.13080839458252155, 0.1603528358522923, 0.10398337392196541, 0.12395182339053963, 0.13180800142788118, 0.0808606033904418, 0.1445094787425572, 0.07981411962499542, 0.10178634866831765, 0.10695070824435643, 0.1465106995836381, 0.0925020984704456, 0.0755758454362231, 0.11337843107720537, 0.10249180073339133, 0.13673658212346418, 0.12306437181729464, 0.10354618286533702, 0.12802112922673264, 0.13947833419567154, 0.20015271230330392, 0.1243271068820069, 0.20450661980336715, 0.11590849007329634, 0.149065051227808, 0.18135794017824436, 0.12962806759582413, 0.10298311590187012, 0.2324792018700992, 0.19068550498735523, 0.16243356129815503, 0.13395188316222162, 0.1145212657208885, 0.11943355938720128, 0.23333551963010143, 0.12612549828425532, 0.17154587072230157, 0.10920816251347143, 0.0988437053597262, 0.13661766995585736, 0.23740686326017305, 0.148216470955841, 0.13889405425758133, 0.19704596530045235, 0.10021933114096042, 0.12710311074530886, 0.1860379406641568, 0.09246079867044765, 0.13209572873048245, 0.17798859355670793, 0.0844779479948263, 0.19578355965354752, 0.13566856362646626, 0.17598689774111395, 0.1874107855462259, 0.12415918806988387, 0.09150184811122956, 0.20302237041534918, 0.15680696725124316, 0.10950059359592777, 0.13835814511103017, 0.1282367676556591, 0.1457028139022089, 0.16568109993973087, 0.13161249578960482, 0.13488621931643258, 0.13268342542071498, 0.1035528018650028, 0.15097359075180947, 0.09394068135729722, 0.1761398548560758, 0.08047831785534659, 0.15262006691867305, 0.10222596056278675, 0.09345015525938043, 0.17130268377161798, 0.18084573379207045, 0.22954191351609848, 0.15823334635746095, 0.12882523809469518, 0.2972571605876569, 0.17960488585935486, 0.12796763330698013, 0.12309929010488334, 0.2116005326951704, 0.12908587652829387, 0.2292104119495038, 0.12938325653874105, 0.1723048799941617, 0.1472535597220544, 0.11226026446468408, 0.20994944467900262, 0.11236400809139015, 0.15831502665194774, 0.13279901276673042, 0.0902742994648795, 0.14845161398331966, 0.18546691404715662, 0.09345278294096071, 0.1965141930286923, 0.08111531230350656, 0.12006890674632405, 0.10635730419908801, 0.1845171029168752, 0.18615840032937067, 0.13788032075089796, 0.12771605769352568, 0.10173662956203185, 0.1337553509661267, 0.35806370418398614, 0.09204953202917691, 0.12051368973428205, 0.17664413989311264, 0.13155506983880075, 0.17665903264236066, 0.09560567386929067, 0.13660579559303102, 0.11509779284918502, 0.12302023749197684, 0.17839998277204652, 0.13994413097539257, 0.07621965806690917, 0.10373831771674658, 0.12773408374238399, 0.2165068202321568, 0.0927152700962559, 0.08836874768378274, 0.09468716509159535, 0.12792740603007619, 0.1504435651605168, 0.17984434962272647, 0.12958531988964928, 0.14548363614707224, 0.0938079719461741, 0.19243638361653975, 0.1427258575154889, 0.2650152471277022, 0.16308324982322034, 0.1946056688264493, 0.13509051964407967, 0.14231547953621035, 0.1560351949545645, 0.20346222745795406, 0.17384727545563253, 0.1300638030853964, 0.12336283201171507, 0.08095891545376471, 0.13084447732375515], [0.024095809447669217, 0.02257798051071023, 0.024063601196112654, 0.02952027694141913, 0.004967290160786962, 0.012858951475561388, 0.07967034790424571, 0.032963675536936334, 0.024311183576261806, 0.10988105584176318, 0.03466583480457625, 0.09017016513333206, 0.01414101206577353, 0.05158643027947796, 0.06094638911646701, 0.06555361508001244, 0.02159109455533326, 0.005423403589145071, 0.015774793198121893, 0.06733667706289599, 0.02149897056721872, 0.06303454178475565, 0.020615734392777085, 0.059456091464286855, 0.009988419065672544, 0.035653410239085075, 0.07405673904765038, 0.009979628206741427, 0.06628933527897443, 0.03184204429177748, 0.06744455756439317, 0.029116923988406217, 0.09635418007570891, 0.05149286413084596, 0.04449858097359539, 0.040154008254889524, 0.033593001444974256, 0.021419368286226547, 0.06531498635247832, 0.024625451994999766, 0.09155538999625752, 0.09190148553780972, 0.0685654514499249, 0.04235056619490347, 0.02066116340668692, 0.03578820723980185, 0.03301509918885366, 0.043077867087577625, 0.08307707961648704, 0.11074398494055195, 0.026449153027046594, 0.043136400035432274, 0.07504563598382859, 0.02108519498799597, 0.04229877482078249, 0.07363403471367014, 0.026426543857181267, 0.03215850180675907, 0.018345151291859728, 0.055167818547136364, 0.03720468082915872, 0.0617995505942212, 0.05408966853733986, 0.053039791002388925, 0.04890996805061737, 0.046658485436872135, 0.02768274419189942, 0.03711430160629173, 0.0388790923921812, 0.05403246858247346, 0.04535980552675263, 0.028496057606272163, 0.0701941007507905, 0.006551214769828104, 0.05032655272272326, 0.06856575788509461, 0.07122631995908676, 0.0878951444681133, 0.027525064144884388, 0.01059986926960729, 0.05271110863935563, 0.0166066775413891, 0.05185246580250321, 0.039384132025823484, 0.024427217168493137, 0.003950464052914252, 0.04819090643356885, 0.021446677405507337, 0.03317924118750999, 0.04058168066905872, 0.03619049150016039, 0.03165973834843645, 0.00048392526291389656, 0.04771073784438833, 0.06320158725664501, 0.004663640678289437, 0.02637596864764008, 0.04710979166350538, 0.05138066289345584, 0.03157764819691018, 0.06234363389892444, 0.06218622964356215, 0.04050514082454386, 0.024614014302290255, 0.034141041593806404, 0.08215123937735636, 0.09299703723480625, 0.0783935014999682, 0.03897684521131939, 0.05366053289523529, 0.01783760080504562, 0.06211922376326496, 0.007730101032422916, 0.04081147640282589, 0.04936473316422874, 0.01875546989932416, 0.025028169095035524, 0.03662517361883675, 0.044695327674309095, 0.05477828198983785, 0.01712072445380111, 0.09241304841012725, 0.023801269708201293, 0.027245710183295514, 0.01717191253368172, 0.07234043396648861, 0.04287363187740407, 0.010780434278140386, 0.04720063436956656, 0.03923072674942594, 0.048953435879441044, 0.002584852716667698, 0.018478707230139165, 0.020040791151264024, 0.025673326210028706, 0.04006588899139916, 0.015731226735477968, 0.05510861527234797, 0.0292333425398195, 0.06750114081848053, 0.02012212862140469, 0.058270677653772224, 0.04121057756785904, 0.011531437931191778, 0.021194781950344483, 0.052783902313920765, 0.06108699306364983, 0.10726242942074615, 0.056188573249645775, 0.029117760939463496, 0.05730397811520004, 0.033064155629084956, 0.011060245019654113, 0.05560701675412636, 0.021250591455628316, 0.043170153869376074, 0.07001282902614725, 0.04844640058675601, 0.02913658563498288, 0.0688123615879205, 0.037983861196065144, 0.07192897580323682, 0.02922593830003133, 0.055494007293976126, 0.040128493696571364, 0.04327329228662195, 0.027167779889198083, 0.06659223878335568, 0.01072323336566408, 0.02626275617418991, 0.009549755205009735, 0.059148805936978716, 0.03648339755712979, 0.06417944103539472, 0.07524145571815391, 0.07767778385670916, 0.059807871378237204, 0.01544487264548098, 0.04106560691950783, 0.024325599435776956, 0.027588343007429957, 0.026517656609235753, 0.011654098183968136, 0.03308863979914496, 0.01616757701060945, 0.04558287883898424, 0.05609151374007906, 0.007440939230183441, 0.031128617251412045, 0.08758664086100557, 0.12700223228743962, 0.09163179194494601, 0.049826596082458575, 0.04432676277393776, 0.045615452897524646, 0.048152812711534, 0.017806191200150118, 0.018208818284854777, 0.056807357787845604, 0.08427936268309433, 0.03410996140671834, 0.050831852826259794, 0.05819523331498908, 0.014454907016648401, 0.03466360165827698, 0.06653028525291912, 0.01284967032035873, 0.03263202841363607, 0.03507352381524059, 0.03660932709012301, 0.038547077546677286, 0.024904168188391675, 0.02508193889122096, 0.019966392522497524, 0.013335030112836151, 0.034385438963410356, 0.04142037074592325, 0.050977708306163556, 0.06496673044297965, 0.08784145702637973, 0.02729592533151229, 0.045237177832713055, 0.008526650527792593, 0.05248277996396346, 0.042004574075221054, 0.08055338681104683, 0.030108191966710073, 0.04609646418342187, 0.07109967030344472, 0.07984237294764289, 0.03263765915987953, 0.05064857395125493, 0.040943124782173865, 0.048672825533656344, 0.04577950296563007, 0.04774115919586151, 0.03411011845474282, 0.08630203398605509, 0.019660281024933345, 0.04565379176769526, 0.041156273425346425, 0.03475121147329769, 0.06307389955186556, 0.05538290539275735, 0.023218368728374763, 0.02423383167854721, 0.1131380939736001, 0.07338905511724372, 0.022669246480349573, 0.04053893679332349, 0.020009329835433635, 0.0009363659879572, 0.04314313777872632, 0.03593773228086291, 0.04845018506110196, 0.035142272545565525, 0.04515522174657353, 0.0356011898557265, 0.044444556453175126, 0.04381848258837577, 0.005174007017030231, 0.027689365106785012, 0.023430795333678686, 0.08610193182023303, 0.033015367319627155, 0.0054320263875378, 0.043509929185552944, 0.059638029685424226, 0.009556577217975452, 0.08363306792753358, 0.048689074258530335, 0.030239689043693008, 0.06084105585731807, 0.05370105894642973, 0.011420945069872806, 0.025837069842964414, 0.0359579186976677, 0.06132370274093363, 0.019485595741219098, 0.015147707139652584, 0.028069507510912035, 0.015352725674728713, 0.043866010683198134, 0.13302232739665817, 0.03247530597652639, 0.022530584566054807, 0.05948584248882629, 0.03915556586317478, 0.020775574807738586, 0.06965588567958725, 0.026812046961558443, 0.051730263287261616, 0.025154939409525647, 0.07165098547815316, 0.08345139017629047, 0.05441777633442994, 0.03847337605792188, 0.07592276835273351, 0.008923449598613286, 0.040941784128306374, 0.033721999160104224, 0.032137334797411196, 0.11351392904837286, 0.038530112529594096, 0.04572933569790856, 0.04446967264577266, 0.022799243940220728, 0.05241163720887515, 0.017685063123222322, 0.004801768246257017, 0.005955118404310798, 0.044205176959475206, 0.042027671626138116, 0.05317580608290531, 0.013093225950855884, 0.009072132900567546, 0.05556918733242539, 0.05591538629584736, 0.045176986304502335, 0.05917378423374988, 0.03649190879396854, 0.013759152667086213, 0.058358758612866365, 0.03994043060247937, 0.03673439860464104, 0.07241991558863271, 0.00884484897758211, 0.01652424073507709, 0.019587090899867397, 0.05409371348158006, 0.0199095641202744, 0.03137589702683111, 0.054869392826672525, 0.053604068384776195, 0.020116327420598077, 0.01095291801668223, 0.02979729433483895, 0.08846925841944833, 0.051192707051673246, 0.07733063111382146, 0.012316382152118511, 0.03458889276390115, 0.022885572473188082, 0.027484143558408947, 0.021160894051013936, 0.012149196869182971, 0.03861186560243368, 0.017379723459241853, 0.006880797764977381, 0.060326309889675155, 0.02344161824082896, 0.03540759943726082, 0.09461378919020777, 0.11281360977239187, 0.10606434451596392, 0.15215244684969226, 0.08441715891803465, 0.15683027164589974, 0.1317212343095772, 0.16058391861377225, 0.13576411011238254, 0.16007863766243383, 0.1363773328522521, 0.21244168191427187, 0.05665297957978422, 0.139249503732689, 0.14756258426895066, 0.1727652375496203, 0.19627191006175934, 0.1565403073665596, 0.10589251865542705, 0.22636269459560995, 0.15877579789488547, 0.14390575549294873, 0.13300222524952504, 0.18399271573270523, 0.11576546145783317, 0.14076226691324867, 0.15426070549555365, 0.10479882855208651, 0.16161562454315925, 0.1300216222842855, 0.11081491702146108, 0.14105808410433032, 0.21229284635234266, 0.12734740852348267, 0.11831282638013364, 0.10763233497498498, 0.1357062398305824, 0.13953572950295864, 0.1110070288902329, 0.1043033765088166, 0.2730777709474487, 0.12629294978274455, 0.19491904475275548, 0.16249604342925936, 0.08956600521360675, 0.09496243580454782, 0.08358400765686266, 0.1444003418568642, 0.12147692272499686, 0.2426513786157293, 0.1336920874253396, 0.12370970130207078, 0.17143693301946888, 0.22933696967459496, 0.10856534579708692, 0.12466629997136132, 0.157736630269116, 0.23299651040184885, 0.09642181797854363, 0.1529829780901632, 0.13762752705764386, 0.14665349837272398, 0.12797101175472622, 0.12470970651315105, 0.11869245359013159, 0.13358449803725367, 0.12713131044180165, 0.23855017287836922, 0.16716913380209478, 0.14957860592872868, 0.19289698632013416, 0.14983328419827646, 0.26837065094901674, 0.11079145940921961, 0.14076526997791183, 0.2031272172086662, 0.1683931278004762, 0.25072640499040005, 0.13080552941368473, 0.116337675511116, 0.18834951904512223, 0.09219399322905848, 0.143944856620604, 0.1584720133893913, 0.1607345161779273, 0.07850249282895558, 0.16472784141379018, 0.17422972186919183, 0.11534923822769236, 0.17080610557909937, 0.16057169185050074, 0.1341196717393975, 0.08523297360948018, 0.12973821571757718, 0.14940453543057367, 0.1020168032376997, 0.15512290681081434, 0.13878874781150974, 0.11509939397294676, 0.09719872306431494, 0.14993984702854388, 0.19991222198211378, 0.1572109713789917, 0.10645504169646772, 0.1131091358500623, 0.14411935612799662, 0.20321740107911251, 0.16724727477037138, 0.1643841284056825, 0.12462432601399, 0.18395235822085412, 0.1298648806949777, 0.11404367118713357, 0.1816040689065572, 0.12379307465087022, 0.12789382839635496, 0.11750250453910521, 0.17238599338358448, 0.20773754965874458, 0.14896107777472467, 0.13178439059805486, 0.3190337614186349, 0.10604162234812976, 0.14473833984905674, 0.17554697941147512, 0.15098768676961624, 0.15958763659000397, 0.05865432299493302, 0.1297697019312651, 0.1253523700119507, 0.11897658794036797, 0.1872884413047183, 0.05384746600963897, 0.07958371868176807, 0.09085789758471713, 0.11563228473307625, 0.11163915868007368, 0.20900707992334522, 0.12708145343968946, 0.12963954359292984, 0.11598636291079945, 0.09451440460379086, 0.22477278636107523, 0.10206477566351814, 0.08185745998015327, 0.0839994111729245, 0.1625929688734393, 0.19486981594274122, 0.10634549878417485, 0.12908576927598447, 0.17744214304031866, 0.12944299607507645, 0.08105927297184545, 0.11136924292171195, 0.10371554958363695, 0.1123930121802034, 0.15126533235513395, 0.10464011045593409, 0.17061619238267023, 0.1516801076790979, 0.10827797089493084, 0.26935271438091035, 0.23467948299742517, 0.24098296169071431, 0.12582603451465407, 0.15030389201016198, 0.19791083260168954, 0.10387583816003415, 0.14192747132432076, 0.1225381843265026, 0.07205844466244021, 0.16935196344650563, 0.15806830037505398, 0.17810624934011893, 0.11648867144099168, 0.16066066530202666], [0.07946211754554704, 0.07010759410238074, 0.05974339358809014, 0.007109717285681156, 0.0170865569323782, 0.04476756976556875, 0.017145574430844957, 0.04034336603757355, 0.1670396342993744, 0.02683686437986551, 0.032282225006530364, 0.0285090217291708, 0.07673138181769079, 0.030126011171828837, 0.026087657202996557, 0.01896340914461161, 0.04829130991692505, 0.030701892871049144, 0.018802176364847732, 0.05653237052742512, 0.024416476615794727, 0.08496665080348331, 0.05346991489791582, 0.038787058419397766, 0.1344150599212416, 0.013908423941522358, 0.049501587111022205, 0.04260594543490199, 0.044074991808062604, 0.05212522757750365, 0.062234447217516364, 0.02404409468234066, 0.02488598509150888, 0.052731570847813165, 0.006543043484505747, 0.038347274155145696, 0.028898835993341865, 0.08637141856935718, 0.07336229566604861, 0.029815942830135746, 0.008788711969710646, 0.04307250447210766, 0.03259019235209112, 0.015430392626102175, 0.026437043092183532, 0.019635708754762046, 0.0326367398543704, 0.03238346352572403, 0.005807581840218195, 0.05205566296353937, 0.023383495150013797, 0.037260214542789806, 0.11006279488004024, 0.042348723753445575, 0.02888648091034303, 0.03971168440916846, 0.03709500002103948, 0.061289765045888005, 0.050380772595564206, 0.017263211062057846, 0.03158267947935289, 0.060783342623542395, 0.009699727449896596, 0.07227060505219045, 0.059976452856414744, 0.03686482124331017, 0.057784479952627615, 0.10324825893246359, 0.05943446863262404, 0.038638686340662746, 0.008036505558618135, 0.05236131289312917, 0.05333517152335375, 0.04520229401908094, 0.031644667483746045, 0.04419933936949219, 0.10209958669879746, 0.027126790354809454, 0.02031933689009278, 0.009350184512685144, 0.012450416895350622, 0.012227756312988218, 0.059103120283614245, 0.01011251956374655, 0.045985067338352247, 0.09541854157202667, 0.10731028693337595, 0.04032993651626091, 0.035505762113438505, 0.06477984329385143, 0.03420906637104289, 0.036538463957127065, 0.024462719598124107, 0.09335715984625202, 0.0495363062157506, 0.0701381380279218, 0.022967268089433352, 0.04259627740529757, 0.022598088403502782, 0.06608151094687563, 0.031385419499729915, 0.0011916219955310225, 0.015824594658859555, 0.05750788007712653, 0.03874315775089687, 0.006465161070903584, 0.09073519328188512, 0.02896637430474643, 0.03937865449716488, 0.029912466078155467, 0.05612363963718376, 0.027478348103261767, 0.010383482947344742, 0.07516978053195823, 0.007697514046148788, 0.047540516938052835, 0.11733018072141756, 0.04358876346340103, 0.05393417184090903, 0.021972598680745692, 0.04338898305450717, 0.12153975725654634, 0.024376973291979204, 0.012231372247990823, 0.01885571633465588, 0.027993074918706572, 0.039332650917311834, 0.07996077183634043, 0.06284516484987351, 0.047060911423496665, 0.05193527990711793, 0.04961856490662021, 0.0468152423479384, 0.03272861677912935, 0.05691476714526934, 0.061855589925882325, 0.0388414008663066, 0.03853433367405688, 0.03297457696809884, 0.03380144630829173, 0.04844344731780791, 0.030203196445419907, 0.015445834085825953, 0.09303141159996872, 0.04967864918252153, 0.02411690942432371, 0.01867513408914449, 0.01977722243135495, 0.015578020641940738, 0.030258209219262488, 0.04557947357816081, 0.05100756275257276, 0.020212266526575533, 0.04284203841140674, 0.032394587122384584, 0.011669660302539988, 0.0367275727612357, 0.05991080295174353, 0.034893079465555574, 0.05316765107695134, 0.03051540408764155, 0.017904148947808052, 0.07533146338837762, 0.043202892636820193, 0.1053322708955215, 0.028431824964260864, 0.06546312477439642, 0.03582813574241535, 0.05215517012402416, 0.01650853018696991, 0.006834628997415665, 0.036236954732768, 0.030017533121750723, 0.07268227772006104, 0.05967331952565621, 0.061459330947048245, 0.04917509575945236, 0.07508468348532915, 0.038753549733589736, 0.04399532249437706, 0.038082678877418084, 0.04673401021488732, 0.048657473131653764, 0.020722858382449038, 0.09367112566025988, 0.07765744422231952, 0.010578531805696267, 0.024736864161827875, 0.06169025283006411, 0.06950413898354577, 0.024417055012177558, 0.005334576651934655, 0.036013257058878104, 0.05058194728448026, 0.01867934757272803, 0.012665891572983276, 0.049910911719404885, 0.07805115978924498, 0.0358485481551578, 0.0515377224092522, 0.021259838136874383, 0.03560310890597682, 0.013690302430111314, 0.08293375988761265, 0.0776182281814756, 0.02844404598187295, 0.05164697803857346, 0.04257834328699016, 0.04290695670211027, 0.042927047357924526, 0.016183023258382757, 0.04036060684630948, 0.02984670509073523, 0.03233598905705637, 0.049305572024276184, 0.029559131005718827, 0.11464639852244048, 0.06561379894734391, 0.04484129423696188, 0.04209968006058086, 0.04212285038985072, 0.04352525094403856, 0.052837635720929796, 0.05409029289899815, 0.018528091172958096, 0.05133089016101534, 0.0027624939027572834, 0.04606418506873231, 0.03916348338187222, 0.029876929174567905, 0.024309408167497288, 0.01855673520044694, 0.041547932046195196, 0.04394392182509746, 0.057980801474543354, 0.045835109457613966, 0.01599704583866462, 0.02592706219142964, 0.05283013955059071, 0.09444905730384974, 0.06776614595324763, 0.03401459878190391, 0.035620908958897475, 0.132413502001474, 0.10318630540202703, 0.05850331940417809, 0.06029126519757894, 0.019401103904050206, 0.08271912503386698, 0.03932804289844729, 0.03452687794643064, 0.07147097779858498, 0.08352751633332622, 0.017246657817233956, 0.017874114470736637, 0.05000563083036293, 0.024472559997511488, 0.010000626676745955, 0.02796042808181336, 0.021792033672212593, 0.08638889303491001, 0.03453613228855595, 0.0611043487855744, 0.08818738402858858, 0.010118471109308302, 0.0445255013032546, 0.033227569844213226, 0.06660269588352212, 0.033718528781807235, 0.12196802338885686, 0.07232941762213746, 0.029070445434040124, 0.05163449080540769, 0.0441718866087256, 0.02112780288312464, 0.03047061475714849, 0.02317117771223909, 0.0311361976914228, 0.027612578198914568, 0.024359136849882144, 0.015806070652850453, 0.06058343581014103, 0.05588466233964409, 0.037265370314520214, 0.031265249032707464, 0.047732716906935944, 0.1220573032755525, 0.046730306179773425, 0.04828617712783237, 0.0592219137075928, 0.02412608715765659, 0.022442859837845452, 0.04570697359139881, 0.036841922875253424, 0.0488679328062121, 0.016525882078454863, 0.04188771119281169, 0.06430805570656253, 0.020960205827929804, 0.017852642941438866, 0.03775873476819646, 0.023986107572132064, 0.02493736277815075, 0.01888772157291251, 0.06254184765801316, 0.012392618434293377, 0.061408056682276155, 0.007888005638960749, 0.016025510793101164, 0.010226239570446554, 0.03690621680429867, 0.013656153103276608, 0.05471606798950703, 0.08224493959137509, 0.02487718465647871, 0.053233825751850684, 0.017101777184213844, 0.08530424276907599, 0.0346651989515991, 0.02414926897824532, 0.020069111506604863, 0.009614920559068842, 0.00959498599366916, 0.07143906257565945, 0.03325149093964889, 0.010057832377271788, 0.026307940039963975, 0.05451359478155932, 0.03505761599949291, 0.044100973680014574, 0.027962314573326902, 0.02387850860794706, 0.025942611861072724, 0.0664035130232092, 0.0521836341208508, 0.01943509905569015, 0.047548193139054125, 0.01649981402161141, 0.009650360744055963, 0.040870246837937066, 0.045367355323246414, 0.031891520165147326, 0.04440113458962691, 0.023619532585144046, 0.04964525157946253, 0.014278807343103954, 0.05415809168029697, 0.1110373123458797, 0.04725056031959192, 0.03486154345615256, 0.013881698964283833, 0.030978695759850166, 0.19931525562799748, 0.15864609920930478, 0.11581499670301715, 0.09872453272222512, 0.06682245586548122, 0.1890779307652866, 0.09131938128942445, 0.13016020758978783, 0.22926108100481574, 0.1691452269592593, 0.17876433418883433, 0.1719051659587891, 0.18382031530622514, 0.11134490430835756, 0.12941394602098774, 0.16175669197353626, 0.1429620424225446, 0.23999248661341208, 0.11956458340489096, 0.1429341261785838, 0.1342715256877484, 0.1836199986357843, 0.2638560641677149, 0.11983220089947987, 0.18207484525778603, 0.08586413046765713, 0.15027053654193878, 0.12679322051905817, 0.21545357191033904, 0.11934169012332156, 0.20064768171118152, 0.14271231308098764, 0.08386288664393848, 0.12059653448241374, 0.18561208770880777, 0.16017671223850022, 0.1655750120839765, 0.21487964948098506, 0.16610814799224177, 0.1341537779737865, 0.149828978784142, 0.15213030690868057, 0.1235701430649046, 0.16679134520311512, 0.10058648643955108, 0.16128479713393798, 0.1660242153992576, 0.11619712135964826, 0.1995114813889227, 0.11178726645847482, 0.13491287917619751, 0.18018355803383937, 0.1381861583720292, 0.11668081395328046, 0.10898620385916964, 0.07554615952915723, 0.17260601383543786, 0.11608353350311519, 0.2540057975678675, 0.2436605002731085, 0.08450600213461346, 0.1940332938947024, 0.07708015100609872, 0.2479078449429043, 0.13857142398914984, 0.13978457018252344, 0.1990125130020803, 0.3402264193902093, 0.19398306917038657, 0.15507134909351028, 0.1427357860149876, 0.19880847314432745, 0.15135200754288705, 0.22849114731915537, 0.183005963842715, 0.1535234377989846, 0.2966685905571907, 0.09337627373996282, 0.13762948824273002, 0.11205103053080459, 0.11212824453269282, 0.15810965380120665, 0.07688024036225773, 0.08751329560313495, 0.0797488642556052, 0.14324390149164584, 0.19676223697681583, 0.24226804354017784, 0.1434598923210175, 0.13984671523494108, 0.13178783799371413, 0.09612110548562582, 0.14188552034958718, 0.26244376575754536, 0.1760489355412222, 0.11742759646186907, 0.16806093675474967, 0.12130775518955723, 0.09790378442454724, 0.13327216399052452, 0.10392113693899686, 0.11493594911430152, 0.1271493594732977, 0.1475049438135278, 0.0841273938215548, 0.15259722217677102, 0.19664795198027166, 0.21878789299197737, 0.13589524904326086, 0.10750532525801852, 0.2320374755729591, 0.1088081190602914, 0.11539639860031106, 0.2645053390053011, 0.09602760445446738, 0.1532001793384552, 0.18711103066321344, 0.0987091190331886, 0.13312222526198433, 0.05118143406786746, 0.13521387512164731, 0.27775335876691726, 0.06384449590358042, 0.10437377998905797, 0.0958198031050063, 0.08851706996680268, 0.14290545916845723, 0.11519478724127817, 0.1146150655263374, 0.07928279168423145, 0.1157389241721361, 0.16277687594054208, 0.10977349709719421, 0.14107539769141905, 0.20729331059321282, 0.11055679901713326, 0.15346798835502518, 0.16913445576304392, 0.08339574921034998, 0.20174157865826162, 0.14223199127422226, 0.16370574222697368, 0.13753141366666363, 0.19496442780138987, 0.1558163083128391, 0.1323662037330289, 0.12534759728418243, 0.12560530160103114, 0.09633951715283817, 0.14358294136341543, 0.14945129743747174, 0.09872453272222512, 0.08053392051689087, 0.24236936632904316, 0.10045622084890643, 0.09424197607703748, 0.10180131036547885, 0.2279376947591382, 0.20720323397507592, 0.08476019776876896, 0.07654844768225186, 0.14710176706073746, 0.09143014994239615, 0.11765480281845217, 0.15518371887024374, 0.12352988514448367, 0.24255327339614594, 0.19426125101745131, 0.15048694105878954, 0.10700768986416441, 0.1157744323474265, 0.167393536276875, 0.13461232756174382, 0.11643516019948068, 0.13244679618266322, 0.13556923266620408], [0.019714908839593974, 0.01802509507885383, 0.03538575444009996, 0.023899800106582623, 0.06112182708156686, 0.025046089806804256, 0.028755273031551513, 0.0199513542165439, 0.01846090717721851, 0.08113114734090145, 0.032167759979323994, 0.08675176590200394, 0.04879107503520866, 0.0937517564142904, 0.0379418834082542, 0.038059121673746456, 0.0682708983039183, 0.12959792969688294, 0.023284171850630836, 0.015247385712310433, 0.04762839105340743, 0.026366266144079067, 0.022548468888647134, 0.014293957689416506, 0.07678454065875662, 0.040910006801207224, 0.02647219886702876, 0.0672776346665717, 0.024845361364104097, 0.019823953794736057, 0.0692749331374803, 0.03647073412374143, 0.05424900333427134, 0.042915709256645174, 0.03648290726085825, 0.050948865095814394, 0.000593498669097185, 0.04201840579269394, 0.021078834543004635, 0.09652250491443182, 0.06504880910318706, 0.012267623528567775, 0.017971809833280502, 0.012251852651036555, 0.07532313601264069, 0.025442601594653343, 0.05337108955568364, 0.01898572720106571, 0.022219445616487535, 0.048965605186118234, 0.03096245278063561, 0.013297682368917572, 0.02421207095105802, 0.11384451897033762, 0.06453337748685191, 0.07768416536911842, 0.01982896400976085, 0.047363064161712126, 0.10108663460179683, 0.042125903250228976, 0.029179718300339677, 0.0715553317399275, 0.07005441993955644, 0.06612400584403547, 0.006772216293029488, 0.0949053775759474, 0.040069037612767956, 0.05890637741334016, 0.06402401328687707, 0.02233652108829589, 0.037460305217293, 0.05951357487168524, 0.053055978440228975, 0.008465429568933624, 0.03271733996488395, 0.030658099454857653, 0.04486496252338252, 0.07318459391113251, 0.06171587081025205, 0.012573306016894359, 0.015098788595247655, 0.06129469482168075, 0.05132247085472749, 0.05841983880306925, 0.020232521891293508, 0.02152911995747878, 0.04912511235283268, 0.03326590488394422, 0.007535581253544098, 0.014634397586867695, 0.05143194098866755, 0.045018601456596974, 0.042216577416946816, 0.04992816401945968, 0.05890451965012378, 0.03370098536834121, 0.037697685221510555, 0.02308192272340098, 0.05543106167967762, 0.012870261806153483, 0.04854686918758577, 0.046899316667188565, 0.02198663724195813, 0.055719781066140825, 0.03442906767069813, 0.0185290583589625, 0.03651787917460165, 0.07095950685681836, 0.04067538088307746, 0.04518955780733978, 0.024664650798865387, 0.00966039170781451, 0.014857198937886186, 0.042752501885256464, 0.02112118388345886, 0.03510749981468243, 0.05316811456014553, 0.049774548068882964, 0.018229502658810348, 0.0444162571652522, 0.05718247657040915, 0.06516271105576908, 0.08273055506569725, 0.03051197009852096, 0.03335411990842512, 0.03766315380832361, 0.032021822144968376, 0.048447863814691385, 0.036537885560744235, 0.042930138522698995, 0.021500989208899198, 0.03152741772693492, 0.023833726938333244, 0.031006625410349622, 0.055449313724473606, 0.0035431607196392914, 0.046017890375468044, 0.03889663963608685, 0.014393164160391016, 0.03138740558267361, 0.06269405400680919, 0.014341890853228829, 0.03903918944659733, 0.05785502515913499, 0.0400195061980236, 0.02930537012646035, 0.031360412474661585, 0.036500600061469504, 0.026542376351332473, 0.031223778778146354, 0.03328797204660312, 0.0662141437492063, 0.06910332944244146, 0.05586866259334549, 0.02320440103029532, 0.06566435308946718, 0.011056580246546337, 0.06289524018704411, 0.016311636014330774, 0.020119087252345298, 0.0018405815400558735, 0.001764165466621278, 0.02754680955061509, 0.0186366745601258, 0.03795889056017322, 0.05355154539668753, 0.03255136701608858, 0.05116623105301012, 0.014106916365093522, 0.09723933338518105, 0.013773724617015932, 0.04089392278523695, 0.030167104128087242, 0.1089348836291221, 0.060771433786759456, 0.021079137147734725, 0.019812770826261372, 0.03429982097699277, 0.023982014747396595, 0.04229177277715456, 0.03770539206602881, 0.040752388041226134, 0.10387005419620585, 0.018384750376665787, 0.05255158998132233, 0.030623443552383015, 0.0616859206028523, 0.05197815018736067, 0.07663441806911461, 0.06924219053959654, 0.02671880448507446, 0.07531398892282479, 0.03641364908206367, 0.05284130911252672, 0.047472465347739, 0.008597929263487458, 0.012734195014702217, 0.030691918406275012, 0.07134369995084501, 0.04068581117016654, 0.060568186830008225, 0.03583758160652172, 0.013541381640900529, 0.04759771306247962, 0.05502527639750512, 0.039504580199718475, 0.05454141143408995, 0.09461913648391924, 0.033062171461361076, 0.020737655370706515, 0.023512105990742004, 0.03472051433017177, 0.004462771466933191, 0.07330100863210617, 0.05138968740920386, 0.060704757324269706, 0.07101075813895272, 0.05785250089942448, 0.027473353209995457, 0.04860812940845086, 0.04611288527807882, 0.017566089668581565, 0.12536988278189976, 0.0668633496388793, 0.021889706052118735, 0.045421134695530906, 0.051413918770248854, 0.03198390462315612, 0.0390067724360814, 0.01751546849376492, 0.008874807803471003, 0.08776392892844255, 0.02732452530894549, 0.06305210435041977, 0.04543691227633146, 0.01817619060015967, 0.028581177635538964, 0.007441782884510055, 0.0345431036886669, 0.09879001025711337, 0.03921904390858066, 0.05531356294429111, 0.02553103495419266, 0.05056588625114772, 0.029547419436576388, 0.08075108346078666, 0.05203152736348491, 0.062464262103481646, 0.07258203511516895, 0.08181635170213639, 0.022354568204572125, 0.022996473276326736, 0.008021506514670628, 0.011034478609930846, 0.05152926479856815, 0.037456892295590336, 0.05003751157933185, 0.05024853815895416, 0.02665175455472162, 0.05095983930532971, 0.012273241825882467, 0.04384067232510255, 0.047008285013538216, 0.030365607085367365, 0.009670748258940876, 0.03305122023448348, 0.03236500463718849, 0.046352743576731414, 0.03410421574728624, 0.02496735703560614, 0.08290040441938946, 0.00461336424303872, 0.12110370767092514, 0.04514835376833235, 0.01874757153282483, 0.04716457461097068, 0.09846203269497042, 0.028939576549155098, 0.025430725316607186, 0.11568850026495996, 0.019471386725443508, 0.007766276661817346, 0.06661808658992091, 0.1338100956091958, 0.08266558314883903, 0.006291233735429424, 0.028590353453652035, 0.04756618471395585, 0.06358988275150619, 0.0516666894808652, 0.02212824859476138, 0.03955488536326636, 0.005885134357207966, 0.06684047425346029, 0.04455471606624704, 0.02865695713778898, 0.05352176372863112, 0.014391771795588636, 0.10523152267259937, 0.032290123373029694, 0.02123399224552897, 0.07885397396861546, 0.042524843536798036, 0.1074629069696511, 0.00545324175618589, 0.021433544743265358, 0.009852729572523988, 0.026954181169370012, 0.053194705471997304, 0.03614645293583313, 0.03535503814477594, 0.029064653809332562, 0.04867001016053462, 0.02952627732508606, 0.045787788206531156, 0.013298882254128976, 0.04491241017897283, 0.021650497012981967, 0.024474965513593728, 0.009403042664240685, 0.03416534956364382, 0.04359367025655605, 0.042861761345017346, 0.030537565096071174, 0.016927266185502374, 0.018254094081179752, 0.017978488204760418, 0.08975899042261225, 0.029888014466832244, 0.006149979092315921, 0.02682654134508583, 0.11140962341620077, 0.06214492218268495, 0.06042839493602515, 0.018992533892272942, 0.03982638692363136, 0.008170953031719453, 0.03263380956806002, 0.0259656596162747, 0.012689876828282591, 0.004662143455202421, 0.09911983409115385, 0.04387489730311979, 0.04641106585040689, 0.012489868508231257, 0.07151141958010775, 0.02187023975796277, 0.03773586321321707, 0.03449654469506876, 0.008398217802506783, 0.05828922081197943, 0.028415003588663477, 0.1417915826483119, 0.14165803820135134, 0.12877712777305034, 0.09460251237596236, 0.14128905961350088, 0.13969388069404712, 0.18719505518674853, 0.13150653050791833, 0.15399360127987402, 0.20867867335196466, 0.18136553977045322, 0.22842494200073907, 0.3880932170056528, 0.2293217092031433, 0.08519064725166367, 0.1737077095575871, 0.2155823512904106, 0.22310412428792448, 0.19037265000083756, 0.09839143769274797, 0.17722311850276687, 0.10941830043110157, 0.12342876153847865, 0.22767688778619613, 0.21056046108565024, 0.22973080015470906, 0.13014700023397324, 0.18659035134459698, 0.09395686113425801, 0.10101365706612987, 0.17205576352294416, 0.10611643083393575, 0.11232713627959452, 0.12550905031422455, 0.11683421539923838, 0.2256007282243621, 0.09992631783168163, 0.14615546461314927, 0.2545177894494226, 0.18453959525833208, 0.17750994182161747, 0.13557136239063355, 0.10203476033864484, 0.1888766794675781, 0.18306193422646294, 0.12944907881319523, 0.19245164408799142, 0.16210783603450946, 0.09295821955968296, 0.13919226164298673, 0.16255281054444853, 0.26331238688961156, 0.08549488374903318, 0.24284725197620932, 0.12181837577372791, 0.12186429508390928, 0.12661157341133203, 0.20869220246470746, 0.18150905868218792, 0.0819341377204945, 0.16388123764866785, 0.1578196588783495, 0.1964642440960292, 0.21450587518272862, 0.14909620036280927, 0.12689658876268134, 0.11608128886549704, 0.2715786594536997, 0.196529928474657, 0.1222190780625228, 0.14032660803246882, 0.18709884986521738, 0.24548918279188298, 0.1665962838958348, 0.09305593407442493, 0.13984970297784577, 0.14401711403362213, 0.1413791209098793, 0.15965804007024537, 0.17017175413427815, 0.15296900464642435, 0.15157432625851325, 0.20627049128374747, 0.1218277526899211, 0.06403149796589729, 0.2761583943520823, 0.16365210075051556, 0.15994140067167822, 0.16259390350070693, 0.19066149579180827, 0.1926079566680616, 0.12943879791325139, 0.2146468813260717, 0.10623442369603342, 0.16651716233501512, 0.11606956772025555, 0.28677404407531987, 0.19293521410755574, 0.17197302602712186, 0.18707458019977619, 0.28025705667753376, 0.21788479790331858, 0.10600842775837069, 0.2092200370445367, 0.08851453421577331, 0.13574673523825986, 0.2519459097135452, 0.28596955982427447, 0.14570863617043342, 0.10916412777958379, 0.17586947178408024, 0.08920605880238357, 0.1142278923502853, 0.10693399220584862, 0.08883556336044304, 0.12810153781526512, 0.130940989080456, 0.14939135871827602, 0.0988194739986812, 0.12480991847452619, 0.14859565383484288, 0.19101202698244205, 0.1491879470526211, 0.14135518832312477, 0.18230117827413544, 0.14576855956787063, 0.09904862621859198, 0.25027232935592053, 0.09578589605347765, 0.12447078667220571, 0.10318430591254465, 0.12630079452308918, 0.11281350252008247, 0.15535990377106976, 0.2001042955464894, 0.09745422104794173, 0.11930530094691824, 0.1372871235493691, 0.1159838654641663, 0.11261625020133872, 0.1558244748101119, 0.1120710407473868, 0.08418196992528054, 0.13203154588418622, 0.10951557061484746, 0.13224229667215578, 0.2007487440301526, 0.14137818628261167, 0.13844911039115923, 0.12516038837812601, 0.1237319331736334, 0.2165852829573616, 0.18015889000267754, 0.1846794522697887, 0.10108215298743979, 0.15956191135750664, 0.20036133336684397, 0.16541992524458518, 0.10133978835637532, 0.16073376541176151, 0.1340975624419028, 0.11135847172549657, 0.15974013405221124, 0.12451302876035053, 0.10185838391583774, 0.20463562900981597, 0.0799171507899319, 0.145565377728593, 0.07785416027951626, 0.18381064727662072, 0.1673512022581793, 0.09450617681948409, 0.2654282604494403, 0.1430097237349518, 0.14298378399783565, 0.17609444116392445], [0.09650817140936853, 0.025385897681717912, 0.09807834521897378, 0.0931522696309032, 0.029530442928174333, 0.01016806764152622, 0.01828929773652025, 0.0714411463348135, 0.024922301489559394, 0.07683452789581592, 0.04873124739876197, 0.059520749285096125, 0.06812327316090946, 0.054478814389796994, 0.023336991697790164, 0.0672463323139856, 0.023606658477576512, 0.038571006302992185, 0.046180385285087173, 0.06050959642555925, 0.016311362137897842, 0.03933944228676058, 0.014735220503362437, 0.025694341917011528, 0.04790176952918691, 0.11377139587796505, 0.16101925573762388, 0.030237151377443826, 0.014230829171626078, 0.014323187774167427, 0.03355453233985651, 0.035516035352503104, 0.0787281976532071, 0.06151100357754096, 0.04029806342817122, 0.026147693598402605, 0.03700592314764377, 0.009597427898927802, 0.035275491405158274, 0.02335979238963656, 0.06652679955286366, 0.10210328690347173, 0.020921154495989604, 0.032081856625154614, 0.058319121223664096, 0.021932350336423805, 0.022497658107069232, 0.06516814261915223, 0.021502310710568583, 0.00919976985202201, 0.035909639836679545, 0.042883587189980095, 0.044256267363145474, 0.041323858989222396, 0.07456786524985107, 0.034831547283477364, 0.06501375291977199, 0.04774759816486509, 0.04878011231701221, 0.025755215263474854, 0.03302308182502466, 0.05810724045600622, 0.017337410507964033, 0.05357236766646947, 0.07492106242646134, 0.023001012347278096, 0.044014601096991575, 0.03139981046138752, 0.03754805292814009, 0.016329930193962592, 0.03853789215246516, 0.04307523940599734, 0.05124419965150376, 0.038378607151248766, 0.061559761243481795, 0.06570386790460156, 0.008214647814090694, 0.07508528869478934, 0.03779384074732661, 0.05256132312840032, 0.009153151486609733, 0.020019926746646245, 0.025160723373353965, 0.022802622387966803, 0.022863922828447916, 0.06695826793269766, 0.028079248318869262, 0.06461414613670881, 0.05360379259312346, 0.042329054445989674, 0.03026405638534456, 0.08063843789240045, 0.04297485507483925, 0.04561742940436929, 0.0072113761956232696, 0.022465622225295634, 0.02559626925616495, 0.014404286799441664, 0.02811087051316375, 0.0350469826991039, 0.062361728895695946, 0.04822299402627734, 0.010198564644181922, 0.03908151580441383, 0.0411026127966902, 0.019449951585322138, 0.02749627647590974, 0.03628240289887594, 0.08243053971279053, 0.06621026734430945, 0.041429196078810966, 0.04471844820786388, 0.06708627356396568, 0.03874170218384074, 0.08366553473376459, 0.06343779131589879, 0.038373688866774884, 0.03327824272996476, 0.026384230905903444, 0.04571499836240565, 0.023418419183261936, 0.015486366840289726, 0.05585145242812653, 0.015054951129000516, 0.048626063526758266, 0.019802135610652548, 0.00856152093488603, 0.025585760445063634, 0.10542648438844951, 0.03258815072777291, 0.025069062868433616, 0.0269261346904621, 0.02875285985459003, 0.05016048018249774, 0.042276366748997284, 0.03531407542346466, 0.052278510279833316, 0.03226298087787244, 0.04613915826344202, 0.027519762816448367, 0.03997278249552173, 0.05814547590430706, 0.06866071448330918, 0.0415947515096876, 0.020489146024168983, 0.038119362997672254, 0.03569199042695184, 0.030925925708405917, 0.07133073774316619, 0.020654544407021136, 0.04331820802162251, 0.02012379486264, 0.08382128806965006, 0.026965582472903114, 0.012116650581329822, 0.01994218031365064, 0.02257221569908002, 0.04828173764831117, 0.008097188340710297, 0.046352138367271235, 0.05080740313015638, 0.023722423939034346, 0.05999764284840035, 0.02112733556949083, 0.050529906931783886, 0.028918712144537322, 0.020478290558281927, 0.05797738855284068, 0.056836672142268195, 0.0719183961290025, 0.026555656485499877, 0.05860139014980486, 0.030058559045315753, 0.05797374197432111, 0.029723056584536552, 0.06395681205415918, 0.05616065317524537, 0.05078926982898867, 0.016745320303485762, 0.10574363712822238, 0.05258081623563363, 0.02564727922060317, 0.04589241666478976, 0.036136972597770156, 0.008175717140998571, 0.07063133011181509, 0.027426238802652207, 0.02999982308416117, 0.09043252726476039, 0.07491771462223223, 0.02502180098916494, 0.03272316223310848, 0.021457084709958687, 0.04712469973451188, 0.047958475357342156, 0.0338763045898128, 0.013796358684738799, 0.0227611004224708, 0.09474456039888245, 0.03292078227405587, 0.046951514067909414, 0.03045684432670955, 0.09076989706485503, 0.024001082675831936, 0.0311406180187459, 0.036672491039479935, 0.016221718359438163, 0.05939061009895898, 0.02135088002579587, 0.0192056289092908, 0.057735959773943316, 0.0750620532480459, 0.019752083256119685, 0.03294141685229636, 0.09457956038175092, 0.03652872697960946, 0.05506283002755335, 0.06035356729802105, 0.032170920092011654, 0.04313250830877693, 0.05065244652571217, 0.004825557670330689, 0.011094925819986291, 0.04484894745532544, 0.012569597193730936, 0.00955177671951993, 0.027387965049955155, 0.046316783409565694, 0.05693233737181272, 0.06320495421307222, 0.05020485199507206, 0.03866600886648221, 0.02541675378808812, 0.09713203511050633, 0.043767928446252505, 0.12207504587187884, 0.07086953749099086, 0.033200653344993634, 0.023510407190769914, 0.012828795382031992, 0.051015763723802184, 0.02978573981372099, 0.06284851648454225, 0.00932981136194881, 0.01269018613628202, 0.021844690725688013, 0.051200433048389615, 0.053388123520680016, 0.020582057167625716, 0.020522625981679848, 0.07183027303507251, 0.03219669128978445, 0.022536799454340534, 0.019797431830797466, 0.044051151151858994, 0.023713958667471044, 0.03562956958288147, 0.0899162452908293, 0.02036470078652905, 0.06772152899253754, 0.06234510861817868, 0.043640903407527555, 0.025100369051459338, 0.0460380882835917, 0.11102742981165649, 0.03716484808753576, 0.021139880259250923, 0.015653729281057755, 0.10570881077118459, 0.04586759541604308, 0.058322748649985566, 0.042291830233748884, 0.03486221761352593, 0.053925767856379675, 0.02680146537210432, 0.02768813553566654, 0.0983652604683753, 0.010005576562346711, 0.06825093405261155, 0.013843190597159969, 0.018931930591802926, 0.021136553522439736, 0.0695535746372996, 0.023584824971734517, 0.07218634304139884, 0.015046823893733805, 0.027460461865449627, 0.04988999751907203, 0.04261158001158507, 0.03192231115404397, 0.09815028853594296, 0.014555082588847128, 0.008986287002992487, 0.04452234502100656, 0.04577959106574136, 0.06097440878229757, 0.029146876111025774, 0.010842765106879657, 0.02870857997256662, 0.027444536812723647, 0.023489678766758695, 0.04769133283726631, 0.030427962811964176, 0.03779321638566833, 0.016967851608510942, 0.047356594549191576, 0.018148829769943992, 0.033465853832181425, 0.015286854562169362, 0.04766677205841388, 0.09017955737128373, 0.01529183126084747, 0.019224635550692197, 0.042399193625897176, 0.048703158785018234, 0.01182661448124676, 0.0887524581424171, 0.037783896926069455, 0.09071620962312145, 0.04690294026307041, 0.0355226390304104, 0.01062283179752769, 0.02566271780749723, 0.03819641229065676, 0.0678731301318734, 0.01719048250496628, 0.042793070071286736, 0.04063563624156579, 0.025399608740342722, 0.045440279232758674, 0.011852051473162588, 0.04694953373062515, 0.024914814895319364, 0.048975211928688714, 0.04157361131341707, 0.0336052511908835, 0.01735901610264855, 0.02243744934188022, 0.030130172944477493, 0.029068296557412516, 0.02594524911875206, 0.0441243163790674, 0.05269527360196075, 0.051740490561050755, 0.022865851454797293, 0.028713465698303717, 0.01803103800592644, 0.04262723884875736, 0.06369995043402718, 0.007943817059464392, 0.0458228750334632, 0.05152999641253583, 0.3867709186048277, 0.10864979166898037, 0.11394680702998755, 0.21710970078504857, 0.20743454656293317, 0.24190517833396313, 0.12874283767755956, 0.12408890716371038, 0.15696476604188644, 0.17391315901712065, 0.12476788323012092, 0.15184742128176076, 0.3521396075525592, 0.15600491915979695, 0.10443178050580526, 0.1920685848040927, 0.0778870637558641, 0.1344792274457793, 0.15156727824960986, 0.15353021001623524, 0.069953472533774, 0.1718844049760411, 0.17143535487834485, 0.11909179224242127, 0.12515244404635123, 0.1793700799105629, 0.3436161745940486, 0.1666561306844796, 0.10812375739577318, 0.15398624683580092, 0.12926074375789012, 0.255957375911455, 0.12044696347607721, 0.16308277484870728, 0.14936777853196667, 0.1494057611712525, 0.1317912853893734, 0.15240447445502206, 0.2482708327231869, 0.1519274315045726, 0.21340240213659503, 0.19296876875863922, 0.19809830963851946, 0.10594826687367694, 0.13976403902615273, 0.07619495939223037, 0.1387925169640972, 0.13041223519511763, 0.11716180225653995, 0.10550384394704335, 0.2159658395835469, 0.12650496461578917, 0.12732765877679472, 0.1618288268124865, 0.1305511882228236, 0.1600609716748999, 0.17230840399861339, 0.1845177617524901, 0.12266942284881108, 0.4409441520129481, 0.15104791660222316, 0.2569679224923734, 0.0973786541350907, 0.12912146897325594, 0.24142900872374737, 0.10622979652497078, 0.21956196355242885, 0.126168146399, 0.13912525959312916, 0.15688437277511244, 0.16044113514644487, 0.13538675052264046, 0.11486406708436628, 0.23372012641160722, 0.1535274827432248, 0.1315024242766442, 0.11142224088431367, 0.21667732076058466, 0.1429925786872064, 0.12497306455888095, 0.13052218413401034, 0.15765882637952605, 0.15807810630048477, 0.23012155096136758, 0.1772029857121168, 0.17490081489086154, 0.1642992918289477, 0.10973577492780263, 0.19142162355203785, 0.08229280476488414, 0.17628957907999718, 0.1991463792059691, 0.13691788449162437, 0.09943943831228441, 0.16321552256422658, 0.10235039622432764, 0.09698545184707451, 0.183708680973899, 0.14899812578674287, 0.11388656953650136, 0.12722220677401752, 0.0883687400229035, 0.12529743384690056, 0.11717897028692308, 0.19924828422165689, 0.11474376063673727, 0.255473499456721, 0.1347925114415346, 0.1892448766457458, 0.08378728142669124, 0.10425672175422793, 0.12640715817049628, 0.13004956917176325, 0.1372418477530441, 0.1832143244363608, 0.162464986224809, 0.11778277780620322, 0.1164777240445537, 0.14984437715142004, 0.11221787681983364, 0.09031586739565096, 0.1355303307214091, 0.10837324158919436, 0.11048997316749827, 0.09244233595147248, 0.1906413476793997, 0.06123171473342565, 0.12377398373979716, 0.22806527904204785, 0.08599870913331548, 0.20816372437102182, 0.12635122609114455, 0.1490990502098876, 0.11092883429580158, 0.1482348111007483, 0.10721805760817182, 0.17421551859907566, 0.09835253574795301, 0.11988211918862597, 0.1342568321213607, 0.23277187810069133, 0.11995041592707557, 0.17274538055062297, 0.12592432359533925, 0.09541428212316767, 0.16805402664167268, 0.1418112711079659, 0.08515850220236086, 0.18250731721280083, 0.12183139160756143, 0.2146059875526736, 0.21933432818660814, 0.10444670389857023, 0.07700575620777185, 0.11587757842555163, 0.09401139893358755, 0.11096503195022384, 0.17812999806577162, 0.07317039064101635, 0.10628430368078333, 0.14850358538810285, 0.24029843148685273, 0.14929785002623835, 0.09507799250704628, 0.13888809409353042, 0.09084099002422825, 0.16829830143720875, 0.20684761596062493, 0.1715904110742192, 0.25109901483501157, 0.09707470875113242, 0.20541878537304942, 0.13453171979035103, 0.1670422083548, 0.14808395306669897, 0.13445671978256396], [0.05921713331894529, 0.02506907244453267, 0.025200073479584632, 0.056100419512198824, 0.06122349844043774, 0.04112535028628284, 0.05933609528226718, 0.036872589374862375, 0.07558044196376879, 0.020582187402572845, 0.021726707439689387, 0.031637824403362415, 0.024112780210411838, 0.01302022255972148, 0.06354119020303892, 0.008274515670153403, 0.032589533516476234, 0.01977113394757673, 0.04355392561504438, 0.06761225421101817, 0.09967983670292363, 0.008981792939706676, 0.03984315275785424, 0.030508348417858926, 0.013768425203799723, 0.01856205568108107, 0.003732232895169047, 0.10625075669057908, 0.05028007033791754, 0.02664031877723192, 0.1130536710843444, 0.01834551709884357, 0.03321140155857129, 0.031009413970394, 0.015167928988023873, 0.03657234036513875, 0.08734481754682719, 0.02744236112301869, 0.04471115505082473, 0.09830866955340871, 0.0633488102034936, 0.04381502370139764, 0.020600004692471797, 0.05150234829934855, 0.027900428075583714, 0.018851043198317773, 0.04019959431682383, 0.0772425999504424, 0.009141637185107796, 0.055379304779513236, 0.051109130689573866, 0.0272147812985725, 0.03380216260050093, 0.053481199373040474, 0.03301447482719537, 0.028927878386551337, 0.029761989172848485, 0.05908444306002029, 0.02183438492788663, 0.050327751650324756, 0.0349976236541425, 0.03841024658252155, 0.05312589162419881, 0.03794197150836549, 0.04087062222101996, 0.021857562918035735, 0.03070758873476617, 0.09516879690871125, 0.017130298637634805, 0.025622396684822538, 0.07635878729483775, 0.06349206864533406, 0.030165527902183034, 0.06310637401897581, 0.058834181287355965, 0.03192695747730473, 0.03136978939085478, 0.0657871493228501, 0.04010431979212069, 0.08114905847657113, 0.02744594066884489, 0.07818675735184262, 0.013262494992945465, 0.049127406786165895, 0.07814099892012535, 0.06938045408817069, 0.017820580246587916, 0.049752071049184575, 0.05058529125826974, 0.028696391513691317, 0.04862400658068158, 0.040417102000285546, 0.051790125397664886, 0.019041178560244943, 0.05046754354430784, 0.023309515954385844, 0.08103177807624302, 0.008784208330325782, 0.09982697921054018, 0.0232975343392501, 0.01357708516861162, 0.058552789531888506, 0.018745106644928455, 0.02872699864148613, 0.04296737805669827, 0.012746728213143446, 0.04160167694452309, 0.036040874528548414, 0.06285980862054615, 0.017673757580679753, 0.061066059711118864, 0.04368671163495991, 0.0318569389562453, 0.03373155993739924, 0.02897752279926452, 0.01760030315527993, 0.06100905893911278, 0.017228570481341694, 0.021545332293176366, 0.07461595258885816, 0.032324972712705215, 0.029687916131449804, 0.01698666864315108, 0.08490586172669165, 0.028239446879935362, 0.06835475428811005, 0.013770143155969921, 0.0773223343816015, 0.053388418464530865, 0.03468885574670088, 0.0069158841131044735, 0.06512932494402894, 0.07826619300871127, 0.07855482429506318, 0.022717354886774576, 0.04689936263246402, 0.11817553576322333, 0.061281238487290765, 0.02741005136481216, 0.030217361411139853, 0.04308626341122774, 0.06583146750926971, 0.03070769215663595, 0.03660510594566022, 0.06520268552365803, 0.04468374442489398, 0.02972103411241645, 0.06485145719301316, 0.034781368524436994, 0.08954900572256697, 0.08314025122672321, 0.03255200286906573, 0.060961707044513, 0.033330758057174184, 0.05308314391802396, 0.011443884615155478, 0.03691563968576732, 0.015454233282305782, 0.05514317349861226, 0.05604821828103835, 0.044822551895894354, 0.018661869276735573, 0.033801971078519864, 0.0552806671288225, 0.08435612469310723, 0.023169015429072806, 0.021235784891271786, 0.019741997708596533, 0.04037792809427746, 0.013443051382989414, 0.01368269517702321, 0.008793073882829518, 0.0398358442790566, 0.010200687665342083, 0.02514636880087276, 0.026912161246723226, 0.05133726784298497, 0.024592152068151102, 0.02666885555241137, 0.0506657496425173, 0.04759086806687617, 0.024846612002640486, 0.02770662123727943, 0.055399223065544526, 0.033043436781172796, 0.07893704854312443, 0.025041351552992582, 0.01568003003710821, 0.008798272747005667, 0.03696459653456846, 0.04448441217743582, 0.0240781415449155, 0.0736207660708216, 0.027576305850919698, 0.06758552540334002, 0.03331765029278975, 0.02015741271597724, 0.008888441295693479, 0.05208563998401646, 0.038483492248962005, 0.04313086888061897, 0.038808413120287086, 0.10607684707088817, 0.0772708762557276, 0.07396499235783854, 0.0360760034903163, 0.08761087988292979, 0.029671631017399412, 0.04419138354639854, 0.021628500713456063, 0.05798322231238408, 0.040664000646962274, 0.06358611742935835, 0.03677976250107731, 0.05556154943582031, 0.002006406897224576, 0.05114071266425233, 0.016665737174691695, 0.021484006954837712, 0.08390587949824911, 0.06195009453222156, 0.0414071710509879, 0.023918756952268944, 0.040759432219689896, 0.02321358067884801, 0.033532036167960015, 0.06019766840542998, 0.022042561660430605, 0.03528522838267588, 0.021857963198976173, 0.015489063469783194, 0.03650718458717869, 0.05468865353313666, 0.025653202995477666, 0.05860547339844127, 0.08164724545373071, 0.01710245134158721, 0.046215958577851136, 0.028927878386551337, 0.03329754814565663, 0.004009125081093742, 0.031353789644556186, 0.025403402790787722, 0.07059451192617416, 0.02561931701136693, 0.04386461640317594, 0.023963360506440365, 0.027260786793645353, 0.03157748157278665, 0.022821851194866245, 0.02324651671393264, 0.057658757263373946, 0.006781094773266946, 0.038802755560966275, 0.06064208750162394, 0.03230625335427542, 0.0651780174924962, 0.0394802798907603, 0.022762251469577034, 0.06131162536480735, 0.008677782438274835, 0.016837900113915245, 0.07657365963583992, 0.05668381461873651, 0.02854117635457266, 0.04479039535527268, 0.016059045334376635, 0.017901237813695785, 0.05781370620693892, 0.02178663658278604, 0.05575743045717959, 0.03481007000852016, 0.012534970019553459, 0.017206290729283806, 0.05667644102246531, 0.03144498666628234, 0.03114739981209559, 0.020971003837222536, 0.041192796667136496, 0.03443513508705843, 0.03665431177303676, 0.04338963422924281, 0.0746096783287583, 0.037707418368588534, 0.04711032409461276, 0.037088790878413186, 0.016235381537567706, 0.04857480841418428, 0.020093733572491237, 0.057716784593198574, 0.013020420784971887, 0.05177910905331374, 0.09946402207377458, 0.011662097099507529, 0.03957936953332636, 0.03284099804718168, 0.05852728646488921, 0.006536133371428737, 0.05938076586913198, 0.029959930970724073, 0.02322655054740608, 0.02898546330059969, 0.018219286876340068, 0.04772620515957956, 0.07544042407384804, 0.025153593009998722, 0.042788814452867356, 0.014326834352687003, 0.013366238619651527, 0.02799768293757112, 0.05588242919334481, 0.0922992307272169, 0.06044069447764947, 0.05468874929412719, 0.052159962003990534, 0.06800239980821648, 0.0961144098771676, 0.030264320685678435, 0.03818780146238785, 0.07851458935727997, 0.061753278883594664, 0.0862726315315212, 0.0899216845150917, 0.0496201545390631, 0.047102774298118974, 0.06677292062029724, 0.09817284982531302, 0.02983695087623933, 0.04013980115433374, 0.03306248555741003, 0.056080895761448535, 0.07401360063663415, 0.06291400168030974, 0.0955795119666765, 0.043061407688524456, 0.04213780442613267, 0.0575937278899214, 0.020072827033037623, 0.009220395811773356, 0.07892479879721519, 0.043644369955384926, 0.0229048510758026, 0.0335992910268326, 0.03241563921854381, 0.01029107550669822, 0.0542559594126238, 0.025812817414501504, 0.043666356678811774, 0.011557205298524952, 0.03315604404516278, 0.03836846031669167, 0.0313858102045713, 0.14515716011726087, 0.1458702960442151, 0.09519066105807021, 0.1397917560872532, 0.278501091224532, 0.11884241530130948, 0.19952983685558845, 0.1265946352073262, 0.20189591473148716, 0.17178299025662486, 0.17350605989415802, 0.21435261163259708, 0.10225445903356999, 0.10875991680809569, 0.1148184312267169, 0.1065915585645745, 0.25264220702792367, 0.11997765035278375, 0.13310518746654834, 0.14141923327359462, 0.1760015453422262, 0.13524241955770602, 0.1589538826937637, 0.12872083563237421, 0.16809248425547155, 0.10830557304284266, 0.13852596433172304, 0.24203026517023965, 0.17633592739941614, 0.11600327813216757, 0.21597323999289544, 0.1664618048216066, 0.24778632807635495, 0.07959382338148933, 0.08024383366348282, 0.18178537127471742, 0.2423347391548657, 0.10553836386891143, 0.3256514434131884, 0.15926103798612473, 0.15340734483493915, 0.13575133176580553, 0.10932561145314287, 0.13797280288511707, 0.08261519754605909, 0.13163532520974838, 0.16602977719758788, 0.20033695644909338, 0.10115373624308456, 0.14025971323492067, 0.22334991593755063, 0.1384254842395744, 0.10785463070797344, 0.12431668042535744, 0.1112372612941169, 0.09685167757373664, 0.141724948320658, 0.08700114284311572, 0.13592411523624776, 0.2022508432668063, 0.10414116505172946, 0.12245451220341268, 0.12235636101855386, 0.06319791003460846, 0.11853327584122458, 0.10852644385229196, 0.09048227701456317, 0.20314166562691813, 0.09780898870479676, 0.11121173524447989, 0.15551129806666605, 0.20682224312857275, 0.09417282132011268, 0.12320735446748235, 0.19495589358191337, 0.1255569537921298, 0.1503295406338669, 0.17062714743998744, 0.08879247091470227, 0.20788655376001713, 0.2466107355130296, 0.15680526653605123, 0.18328296591437634, 0.21132673287103254, 0.11854642957088449, 0.19658579160609554, 0.2337576187546215, 0.18001972247035275, 0.1396211636282744, 0.07575848845825081, 0.17399586586942598, 0.14023530567365308, 0.17795707669950303, 0.14144048455261415, 0.16917708089515088, 0.07242577616125345, 0.22401558505671643, 0.09593310750900738, 0.2552854248713101, 0.07843100916474097, 0.09376669512881387, 0.11012029743963674, 0.11433884486435883, 0.1712139554682278, 0.13090081542970675, 0.1273222348742908, 0.17119461940901895, 0.170512632617066, 0.16317430703390032, 0.11423849500715734, 0.12398350112620862, 0.17679775584368937, 0.1189407273646324, 0.10574375204141102, 0.13193207702809764, 0.14755011235754337, 0.1437361895917885, 0.08526500374559434, 0.12752660414985112, 0.11371308892604806, 0.09804717310133482, 0.1275077354042761, 0.19762730346091334, 0.19088923840993838, 0.0984434703845651, 0.19372365647746673, 0.08164932155200551, 0.13567659222791273, 0.1864222103669759, 0.11941112833277834, 0.07596746958311527, 0.16181997083608182, 0.16968803089712897, 0.1191887636518767, 0.11308763176202775, 0.18201257763130052, 0.2552482083199486, 0.18097164800330517, 0.13179041204913972, 0.14296067878603935, 0.14861589387780236, 0.15953102269239966, 0.12079200181629389, 0.19391986691663343, 0.12517915753227088, 0.19624926450271762, 0.15293866756462282, 0.1501401024119508, 0.10229120827129773, 0.16285619668422208, 0.20393746244090222, 0.11241879103885544, 0.16812922583232004, 0.1542461651467508, 0.13545226636192492, 0.15654815210690423, 0.16282069616981093, 0.18423093843363947, 0.13644625012192035, 0.24912537315920477, 0.2146259977692558, 0.1397434925480235, 0.1460039170999681, 0.18831404917422803, 0.1806395335663711, 0.07887208428714546, 0.14894266102102496, 0.1382376701240578, 0.15459907120994984, 0.12024727499773426, 0.09752472411961326, 0.11456497103696871, 0.0888267839928308, 0.10146575619376476, 0.17693149947351028, 0.08346400764440337]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.032538898935120915, 0.05340026218384024, 0.013139104083811325, 0.04540077590894315, 0.04882522340443346, 0.0342352167823382, 0.038301967715303746, 0.04903069967704435, 0.04921836823585534, 0.04379065444452628, 0.049408093740743016, 0.03401595475752989, 0.004601781472428552, 0.051952198958925666, 0.05294916663138617, 0.011581261416957265, 0.04911722930809183, 0.026467600424263268, 0.023335681687439644, 0.01892680929402911, 0.02358477709123925, 0.028340654755612055, 0.0674397312104702, 0.05399737409466217, 0.031826567400487206, 0.0387171222527902, 0.032623486533280344, 0.013986040139570834, 0.05851450811831221, 0.02993492969131518, 0.020432723648545724, 0.025334112053256364, 0.015371288942743935, 0.02859280301978992, 0.03150168483355834, 0.0960988199879085, 0.043854262724879294, 0.026010824329850656, 0.038004710278924436, 0.02657909494554324, 0.052315382091628934, 0.04741491299242743, 0.12110000746625087, 0.02267428733889134, 0.03391004310199811, 0.03151898692932821, 0.03659064986652905, 0.04064001826449268, 0.05813191997848692, 0.06093580178135346, 0.016055935975013962, 0.10039640470377861, 0.031575702333582506, 0.08016445163276889, 0.07005751493477053, 0.029895916663771196, 0.011862689561601128, 0.029950619172004443, 0.05471868801020807, 0.08853159499384704, 0.055250471773286985, 0.03337497282172403, 0.06331276959709584, 0.10669553201765784, 0.05555742788278768, 0.01172414543332472, 0.02448221270535742, 0.035878057862001086, 0.10232470163534726, 0.042716212300283295, 0.035548364262907736, 0.04476907129790034, 0.005343316278735837, 0.02228572179803685, 0.011158089769343215, 0.02205314516510454, 0.031084841072198846, 0.01589757985540576, 0.03236980417803411, 0.04346502111143163, 0.03737989279832091, 0.10283156838868895, 0.03103210549471119, 0.08573013402882122, 0.05478674343096153, 0.013213438552714164, 0.04638079388607894, 0.03850116206693553, 0.059229923156841155, 0.02809673044530134, 0.03420024103815517, 0.053527754536199, 0.05113973207170925, 0.06515790768448385, 0.01197924217840116, 0.032599458185535286, 0.0019432269079017364, 0.037071676474184766, 0.01679240981297147, 0.03530569442157303, 0.03253711011981772, 0.02683667285788444, 0.012585619922667261, 0.029643563471073588, 0.031698201707894766, 0.021545650219664942, 0.028448546748428095, 0.06789379918407049, 0.007813915839388726, 0.04997628966286298, 0.04423066470471602, 0.022160512387692448, 0.013286117314090653, 0.01661787391640246, 0.08089996498799132, 0.08027848382029804, 0.0381284449700146, 0.02796515675952598, 0.010413389104688841, 0.011525394455079111, 0.051025366635933045, 0.01761499480644782, 0.03299076440593889, 0.011462180710007108, 0.03914706228721527, 0.03199317428703991, 0.03926346934730968, 0.12354487748516184, 0.09182895999401809, 0.005377027977843799, 0.04285582799404379, 0.09810112101296264, 0.029359869621393662, 0.0576841990433393, 0.009988422896112166, 0.03591063958142073, 0.03702036007457683, 0.04967823932548204, 0.025503630073921337, 0.06529378869961347, 0.014559852443785678, 0.005478345978659608, 0.03053387255227614, 0.01153589656291109, 0.0456234087206183, 0.06828497133908734, 0.019349774097903602, 0.044713794223723874, 0.08350475586109585, 0.012022180448947175, 0.031954235953068545, 0.027548550485423016, 0.03501497171518784, 0.06672424339358846, 0.0403004574529346, 0.02684216570830153, 0.04550333209936658, 0.019954642648958874, 0.01486136071053484, 0.023323204030372927, 0.007338284884744715, 0.05904008273876483, 0.031297440047285734, 0.01495622537819849, 0.0024812517738375334, 0.024930213262597402, 0.04046459179071169, 0.013342898793428416, 0.058779685622862274, 0.04028764846284063, 0.016337144826989503, 0.035712038947930264, 0.06631686081809383, 0.016919565086643544, 0.05726930114530748, 0.02451118998109333, 0.04337347360448011, 0.049022410605703635, 0.015485040550570817, 0.04286586757629149, 0.055121439584200425, 0.035551662271421765, 0.019599972668314175, 0.08869740706417831, 0.07114146806059346, 0.01218192701813795, 0.043509653393900206, 0.05839147439767277, 0.02597901635923453, 0.0639892980125883, 0.020755397967032848, 0.0225362210579577, 0.047274086879746574, 0.07778988550266913, 0.010627734760243085, 0.04903177986101759, 0.04675048110525935, 0.051755103688206405, 0.028748782351613048, 0.07077062021820776, 0.029674586201567325, 0.07087457834953262, 0.02339147970140461, 0.014543364316435351, 0.0759446554847302, 0.011123558356156273, 0.026861932691967776, 0.02890740468677494, 0.02155553849954759, 0.07694735732530394, 0.05490256443379387, 0.04342962784932987, 0.018080663266441515, 0.030609989133212837, 0.04244014485588959, 0.03695274515437984, 0.04517828482353399, 0.013104489358562618, 0.04451842265083425, 0.02714859321713448, 0.022929612952735157, 0.07212917756048903, 0.042714572872125336, 0.016002615297874136, 0.022016484027488098, 0.027654393193041606, 0.04023545106211978, 0.06516720799188461, 0.09352001481719556, 0.04806494242661903, 0.03354717789578342, 0.032383417560448574, 0.02424419493294291, 0.02143825426877987, 0.06863059956700572, 0.024230843935642513, 0.02326615729309138, 0.028254040854892908, 0.06373614808844943, 0.041059087511272206, 0.045897580097399415, 0.028898835993341865, 0.0413636266133718, 0.04861503952152787, 0.04399790421068188, 0.0639352505095303, 0.021069681707529292, 0.005236979923211039, 0.05562585485618442, 0.005701401575107969, 0.005889024647448453, 0.03680129340218921, 0.043040593079621756, 0.013907903959343751, 0.03600186916188367, 0.0232212204906729, 0.03958899542809494, 0.08605624999730818, 0.00756091338717529, 0.04881793790827355, 0.0672750759329046, 0.04288329607656887, 0.10529621113692561, 0.01752101688555652, 0.017994629677325007, 0.028367144160813866, 0.023743623507118995, 0.07734573070680903, 0.0182269171120659, 0.051463281645649867, 0.014540638001034818, 0.042755711793659196, 0.03650153085829751, 0.03437833349791265, 0.06777783645497215, 0.07746857290546741, 0.027897978509445826, 0.039876052403762456, 0.03447401787965529, 0.01928058486702221, 0.05193065273605528, 0.01928602217606479, 0.020278328203506047, 0.04403204491902744, 0.0034583954848424205, 0.026756227880175558, 0.03486322884958598, 0.025699114644779794, 0.023152873956508214, 0.04631623565669983, 0.008734403996758403, 0.11361590301197384, 0.021171812719154744, 0.05831767714792683, 0.010717631347717778, 0.052954452638063705, 0.04579137349801679, 0.024505894398316744, 0.07306230329577962, 0.012556297907365427, 0.05547672818084398, 0.025310390140681018, 0.06092865418101992, 0.07449085809170239, 0.018097233748243704, 0.0032385665549701384, 0.043895769368616805, 0.02540672952759891, 0.025412203225817893, 0.04274877869794446, 0.027680108849439892, 0.03652023872540843, 0.023488374502067606, 0.022399447550396287, 0.005733757777394908, 0.06191224595832248, 0.05607456404475435, 0.02350313127070906, 0.04888104440103616, 0.03841609566382343, 0.06136358144783205, 0.06275768143936031, 0.028073186648168394, 0.050647681458823146, 0.07485056701566904, 0.036050159514190695, 0.050831481273616516, 0.007759429272189136, 0.059258463762460224, 0.04964160117050333, 0.04130532732233405, 0.015867565488142353, 0.05805826062456735, 0.02524176015398435, 0.06202514816616332, 0.011224170598471838, 0.06736028023184308, 0.05971381110289405, 0.0745376967073929, 0.010966201023679348, 0.013333293008467844, 0.033710902376521024, 0.026712844321023554, 0.03279388747027805, 0.04119889089657415, 0.03420915064071456, 0.02401614204920348, 0.055977316843646194, 0.018584793170673714, 0.053592737944376086, 0.061796321533620364, 0.05252995182790103, 0.1520679933169196, 0.15861707979873305, 0.062375706169874444, 0.13480553493624733, 0.21001056317360173, 0.11790876096535115, 0.12775502858623383, 0.16205226401648215, 0.129430171763224, 0.14247318639630271, 0.12289693564056389, 0.13375343574631599, 0.15838104810926223, 0.13753889068480463, 0.22728909407892536, 0.1277723268515641, 0.18645389576352414, 0.19141734878142036, 0.10111815145900173, 0.19159984624674245, 0.1615360586513435, 0.09579120504279291, 0.24060848259156753, 0.16120541510322403, 0.12982012583844124, 0.17959198493870998, 0.08869023648120704, 0.1427484417874967, 0.11502332144206572, 0.16014847423761122, 0.10406483205095415, 0.12534876173782733, 0.08228546564256953, 0.1093959536463503, 0.17613934923804578, 0.15989825459978274, 0.09704761988212986, 0.3291971434748942, 0.150517339427625, 0.15246802910922036, 0.15322835605231025, 0.13481075965589093, 0.23970356421364894, 0.09071448592529183, 0.12587920101659913, 0.16280903631160337, 0.15943489397966093, 0.1588277233343932, 0.15833070081087852, 0.19339134285767234, 0.09533432552651053, 0.2101101392819997, 0.1590100062950965, 0.1887360410464387, 0.12905796028433308, 0.1266735269417686, 0.09550550021231176, 0.12427203282113038, 0.19130389115983443, 0.141245270027749, 0.2104507419731348, 0.17428583014876614, 0.15003787563933482, 0.2256580316010983, 0.1412078236500102, 0.0822705345889253, 0.16350824476009415, 0.1602752158238042, 0.15048114943408197, 0.07074019886673459, 0.11243913833412433, 0.12564948955250363, 0.17270332232357996, 0.13658272102475166, 0.07766284514218569, 0.13388595363545802, 0.1206090906634927, 0.12978929846036819, 0.14188100043083393, 0.10706701571302069, 0.12778710468762344, 0.22338543177372028, 0.1222904697961865, 0.14034697064949622, 0.20702819820613633, 0.1556206034917024, 0.17966828729596832, 0.10600279701212723, 0.10183446665084171, 0.07632716318532344, 0.14955465802021567, 0.16705186106264594, 0.12578612133379907, 0.22354416519163117, 0.1076939054614594, 0.11902580142862375, 0.2271592728192768, 0.09747464495200305, 0.11952408033633426, 0.10477705633327847, 0.19531846767471683, 0.09850185394527451, 0.13373678099484215, 0.052894287922930334, 0.12661963265629547, 0.11327911543870166, 0.1178293789346372, 0.32615372129986364, 0.11510656455591803, 0.14220055102580978, 0.16495034399051822, 0.09908981876628054, 0.1636477800146226, 0.1248655824231044, 0.17919703597022643, 0.2311517400366645, 0.13159055503145342, 0.1442910823971033, 0.15315309557462894, 0.08641185269000069, 0.1095965461084439, 0.13138757237503607, 0.1159174839455274, 0.07674692574167445, 0.11203379355250828, 0.15486983732590753, 0.14258609243458317, 0.1543813949871448, 0.26499401117044113, 0.07902514099353745, 0.1413809135556221, 0.20388153802242973, 0.0911144680914379, 0.20064349887111496, 0.130847311849075, 0.09482869217472692, 0.16591717759447713, 0.08909850005781458, 0.11937498430451078, 0.18844698075084917, 0.13538816012442112, 0.12440208390715624, 0.1914528492958315, 0.15821564972641008, 0.16692884266376498, 0.13376402308142957, 0.0901828975146336, 0.07208621534969538, 0.13879077028362982, 0.16766929728609903, 0.16113583899794087, 0.11919485405087472, 0.12187839110171604, 0.16155453669207712, 0.14315235398469434, 0.12459896084281707, 0.16591677922875653, 0.10354703322293297, 0.10503860641150706, 0.09427093420057528, 0.12373504349060598, 0.1468278906278072, 0.18683223594580928, 0.18032557541324248, 0.2402639575302601, 0.13131278687186781, 0.11615300235608894, 0.08458061143755914, 0.22244367988840227, 0.18540942680931863, 0.11212729458366671, 0.12930424223023076, 0.11922333719989947, 0.16619183543709018, 0.1905181607411754, 0.13649598454996464], [0.03699222549555763, 0.057615971252802885, 0.013547097614425565, 0.05752574524752075, 0.032113026827573776, 0.053797693277198466, 0.034500041886443095, 0.006507740716540045, 0.07336656277578685, 0.04766825060810774, 0.00968896104173074, 0.012952324186992503, 0.010502199762530867, 0.033120237095581914, 0.06535672282259311, 0.02672484891879703, 0.07311818940985589, 0.049587549837005716, 0.029808915888650284, 0.024903834940144615, 0.06789526241200586, 0.013265810238437788, 0.03148529821285798, 0.03247234121625943, 0.019478291092861085, 0.1525672068518977, 0.034924289887590755, 0.0994700588466179, 0.04881994505863517, 0.011755199764945335, 0.020007906827114282, 0.0353711030085481, 0.02503965275302049, 0.06148170837531648, 0.05023056190581091, 0.0358717797714616, 0.06418404139338002, 0.05944707843985769, 0.023408856490747105, 0.018854356528590285, 0.05903487717131934, 0.0455138236734896, 0.01776360628765918, 0.02770309148716831, 0.01541903441501481, 0.05276341712282551, 0.054607674209100586, 0.10171989820176557, 0.03984014969319105, 0.04815156781865705, 0.04044525190106323, 0.02445973185521941, 0.03721762005419981, 0.04584700297263842, 0.032779603760929844, 0.019650446371205395, 0.0430202151408359, 0.0558535936438749, 0.04776899883102986, 0.05205477047110758, 0.010866398919343708, 0.021497310071642843, 0.029699334671961206, 0.0323762814514339, 0.014623143755260014, 0.025034814907778657, 0.009215961120301678, 0.02603017571081798, 0.0906032499586863, 0.030543724442982388, 0.021543474529959986, 0.04810742200202039, 0.039106030617990804, 0.05963891068653715, 0.03050242655820424, 0.05364901093285411, 0.06620848235944587, 0.04862858395602915, 0.016327047788147486, 0.06372771729084273, 0.03752109429408466, 0.11063880872942748, 0.01671272517752744, 0.030299874826244293, 0.01833710353821516, 0.027575869180802858, 0.048821143986236666, 0.05059919958453506, 0.0750900077964029, 0.0526751293199918, 0.04951948675537302, 0.02366493478597653, 0.03346462809150258, 0.0317774209449248, 0.028266604696851105, 0.05783185482986512, 0.04425858477911642, 0.009378546045251913, 0.030760150027251056, 0.028846232566021146, 0.01102084894814799, 0.09066754005729191, 0.04318467889642043, 0.07369201224777969, 0.04178834192815327, 0.05716654960246337, 0.017645822184520866, 0.03547864260091897, 0.01646325247542512, 0.04488899853200682, 0.15165652749278855, 0.025647392218572, 0.031759414048264586, 0.03777474983625355, 0.031850779609334086, 0.04781170057192926, 0.06938076818421965, 0.035728498346983426, 0.05769639133265423, 0.012302868361134204, 0.0753837182456928, 0.017333700727190704, 0.05369940036607366, 0.036731759431741895, 0.010224435433384874, 0.03156698425300419, 0.016631267048538696, 0.02719729917214042, 0.020376128903139504, 0.007695553818672536, 0.06166255875160137, 0.07298330430902782, 0.0261166229874136, 0.05603016158866306, 0.017907115623294827, 0.029850208027769002, 0.022526296388898647, 0.055866869947602676, 0.04669288661511195, 0.0725635570744353, 0.01059764474179716, 0.05985591275196883, 0.037342254898601004, 0.04141225021392588, 0.04543057672919766, 0.05310677390004839, 0.08290269502228306, 0.06131784599875251, 0.02757117497704683, 0.017469288713689295, 0.022427386776994795, 0.06476295105512105, 0.02296707848267209, 0.03205061747482227, 0.08973321922483946, 0.052720389794558294, 0.031025813997633038, 0.024419173245288195, 0.002058581435008936, 0.029334353147855693, 0.014582216465515236, 0.054736717889506015, 0.061610284742088094, 0.04828857881347499, 0.01996774275246407, 0.04754620514089062, 0.04632868841590901, 0.03542859407682573, 0.02958878052360829, 0.03398036614300744, 0.03680861337230571, 0.020387242923701004, 0.017931779824017037, 0.09548234137436075, 0.06536119677607091, 0.008241593999217355, 0.06013569189235569, 0.03316352106330376, 0.028476127828922004, 0.051966237520138105, 0.03662528087114615, 0.009170375058367368, 0.005686073113353022, 0.015328530702860126, 0.02233914110899693, 0.017196168792584253, 0.08193118062110678, 0.013706543494106061, 0.03352820572833862, 0.06559414113120687, 0.030511565987140905, 0.03816514441202726, 0.07308728542299041, 0.010042723208185165, 0.05887554620482749, 0.01929595450600309, 0.03855183112224744, 0.03725085677879472, 0.03591522078720793, 0.05159684907524817, 0.06587236894354706, 0.07830979107248207, 0.032880267714180296, 0.06113699179202799, 0.09745408315211536, 0.036218633740058834, 0.03241738589901117, 0.004063102918031115, 0.04655193409792358, 0.036592630203813314, 0.04119005024192795, 0.053174201128703934, 0.0585135581692861, 0.037067976269510486, 0.07353763020927868, 0.05203245432987329, 0.0865703332988966, 0.030369324527019938, 0.029554584273888223, 0.058464405968064265, 0.04187575256031367, 0.011007514230215983, 0.003705534731007872, 0.04790601365628743, 0.042749682681695114, 0.017288392372128945, 0.06733720566356374, 0.03488274110901741, 0.03582412527213174, 0.023850686209757003, 0.02985405953480832, 0.007667117113728197, 0.08347692388680675, 0.0894268989683159, 0.06407644434441483, 0.02290083102941994, 0.073414841636775, 0.04794174016663625, 0.05060042532521391, 0.021597148565154885, 0.0545294298189542, 0.0392656910022901, 0.04092340567900289, 0.05985239257795676, 0.06002264029736962, 0.01767662083429675, 0.05480035681337599, 0.008780860526096678, 0.03807440895827548, 0.02036062711399169, 0.02826449412461971, 0.03002211432753792, 0.025560828113567927, 0.03494148090061161, 0.04706796709327929, 0.04479790684737025, 0.03549870644365588, 0.06728608461637652, 0.04028382568409847, 0.03575877797219061, 0.03482582843712261, 0.023274285485967997, 0.10867297348956909, 0.09466616662159082, 0.07254230579541576, 0.008472065805577704, 0.07089916977190203, 0.04371294631592689, 0.03148543419346454, 0.05929897066145655, 0.037508128255966215, 0.009891615237950558, 0.03810962985059427, 0.008268482727749694, 0.02401600032293749, 0.02804034062841487, 0.012946465529591568, 0.02114968043902228, 0.1279801358619044, 0.09159363310543761, 0.039722785023191286, 0.06340791005641222, 0.04153055717207251, 0.05764839209375843, 0.047686376248396216, 0.0077233991995003205, 0.024669639946472262, 0.06749336502604908, 0.050142500098914876, 0.057808332100150094, 0.03305356063309216, 0.037357274052356525, 0.05289628741241271, 0.06900904700160027, 0.036460617932701306, 0.026875936779223626, 0.02063622341431197, 0.03446012487514846, 0.012736690546115561, 0.046121584206459024, 0.0990196910776919, 0.049211427479261355, 0.0307167396550217, 0.004982487429984876, 0.041244905967746055, 0.07762944370868706, 0.03813194982226818, 0.0913348715872534, 0.03634181301740389, 0.028072096888096105, 0.011843622590775692, 0.04040250036444876, 0.02138766948313963, 0.04127723870859031, 0.034401404235752366, 0.04501348015882316, 0.041733467050137064, 0.03673022342545371, 0.03304855807894661, 0.04801480197197488, 0.03300595975991699, 0.07196786242627329, 0.06771319395592136, 0.08099659931876006, 0.04218602583052651, 0.0805460247060945, 0.05361959698700136, 0.021886860035480033, 0.01779600797641662, 0.053549139880605286, 0.06723431239445364, 0.09070124792596025, 0.022025451086641803, 0.035356348155126456, 0.048602073483409426, 0.04410876479420451, 0.01978855861741449, 0.01776426512327406, 0.012240204284147871, 0.012356756900947903, 0.04949296096099481, 0.03648605588222704, 0.03903209164197888, 0.04258961627079595, 0.04124697057470199, 0.0775234784270006, 0.08014235765703263, 0.039843401736429626, 0.03882771470553933, 0.020098944885596152, 0.036804905506752195, 0.03409317258985774, 0.1896681861891862, 0.1364231908753995, 0.21472091606307417, 0.12590141756640327, 0.11260621444953066, 0.16337859203978894, 0.11101543287476225, 0.08991809922360605, 0.14923012785373196, 0.1044157692681878, 0.17503091194216283, 0.08907477431479963, 0.10252497234051267, 0.14965650174886952, 0.11657926899891709, 0.1629634949588968, 0.1836747126353364, 0.13197323127139, 0.14022055082023144, 0.13306545814679516, 0.258042651919588, 0.15538789662382296, 0.07453391223304695, 0.14307543875709658, 0.12803205364053288, 0.3583280045178629, 0.09393032384856094, 0.33659169991170207, 0.23586986105768915, 0.13245549894148304, 0.16818354146615153, 0.12318706079836815, 0.21141699335027128, 0.1528922579581699, 0.14788987235196177, 0.1525038820240767, 0.09167158255173315, 0.19075357956030678, 0.13991538735647358, 0.18528677613264133, 0.2218470046476972, 0.1627893018866739, 0.13008131585534544, 0.2065496384015968, 0.14628683337040488, 0.092811789513836, 0.12848655828425, 0.20049999528113874, 0.08261259284711654, 0.11355076255577226, 0.1599275804455242, 0.18572496310357126, 0.09169121738523246, 0.11218616844064767, 0.16137487375207488, 0.11413192451601067, 0.17398586076113487, 0.2914815624394725, 0.1054629042083698, 0.11442409512857277, 0.1941671294550742, 0.0734378932224166, 0.24377293133687591, 0.12710396876378408, 0.1875072513376513, 0.11926456805198424, 0.08250740131423359, 0.1176368380566278, 0.2309585939491949, 0.10453486529689644, 0.1351896207779646, 0.10237234464335827, 0.13273636209628276, 0.22775862936771687, 0.13240908933503012, 0.17333522228704346, 0.13846674573517617, 0.15138235994644705, 0.1375444524831349, 0.19647550558851612, 0.11991636331884131, 0.22509802132844928, 0.1328828074638882, 0.13485992717887127, 0.15212339679560355, 0.1131034974429396, 0.22103384828134892, 0.1979910420073617, 0.20661080286147135, 0.08942957261517163, 0.1735146860441854, 0.14572005088050521, 0.11419534127438262, 0.19527218064233182, 0.1520380699225972, 0.13540239403805426, 0.1433936716808427, 0.15615272816390763, 0.1066145028979067, 0.0912979691319408, 0.07599170094416027, 0.19700114915688194, 0.28275885469009804, 0.2067880296418744, 0.1559595207894041, 0.14355323247371182, 0.16794406238102144, 0.13668389059603214, 0.0997414531546735, 0.11632580114828965, 0.2535051897528672, 0.2017701384160788, 0.136079830267737, 0.1521148319326101, 0.20012560811254287, 0.1596138061534974, 0.2520136012425346, 0.13792556590370594, 0.14942520448277075, 0.059419001317432815, 0.14364998937854845, 0.08855216445461397, 0.12857314920233143, 0.18975895228645495, 0.10263730381284991, 0.18378737352548108, 0.18830628104267583, 0.06264416636118005, 0.11995867435489932, 0.1661508344113827, 0.14040317085962142, 0.12637101414222873, 0.07926519464461074, 0.1444496625974294, 0.06337265085969722, 0.11451623252322597, 0.11259471546978721, 0.12040043129555641, 0.07182829652822788, 0.20455024084977566, 0.17475213254651717, 0.14967389194475067, 0.1961454749107361, 0.13988560185797755, 0.13198743454150616, 0.23023413524271982, 0.14623608770630053, 0.13681924301049403, 0.13419897716131904, 0.19525249218267782, 0.13765899794957331, 0.2552586271157188, 0.12964403286816614, 0.12743407605035653, 0.17539776080558378, 0.12230835028833921, 0.1337613111301776, 0.10016039599694553, 0.1292288438567231, 0.16130637016988572, 0.11033047366166308, 0.13575045842557185, 0.10235779663367618, 0.13025045274726807, 0.1450712203739151, 0.22351208142936232, 0.11138847172861138, 0.08864429418838794, 0.18570061682933764, 0.1640193939449326, 0.14334220589408952, 0.14359866148762165, 0.10619233482547345, 0.19914424948153958, 0.14769206844991253, 0.10950496795797542], [0.028657026085702163, 0.02739705085273712, 0.04334250450014107, 0.06659421529020033, 0.04027847839038699, 0.01450865383019611, 0.011209036531527678, 0.054674557515329895, 0.024846535393848054, 0.03753389562329939, 0.0672117740877213, 0.07442359557195057, 0.10781489372734102, 0.025153052918012106, 0.0669608726316402, 0.037970255474529924, 0.033764992014414845, 0.05491025212611403, 0.06583505280075536, 0.004846370364013579, 0.06325178516788349, 0.03752515839052297, 0.05744348272621151, 0.03209721285759682, 0.040840331104493914, 0.042832672986532414, 0.1332818933071629, 0.02682550329594843, 0.06922242547115011, 0.046722813839873964, 0.05061063727724457, 0.1381801828862198, 0.009049206761823548, 0.04186426890232871, 0.026417988570286866, 0.03713451483617387, 0.03161179273569536, 0.028046599566756238, 0.05919549899596361, 0.07854006944164153, 0.014619838085866746, 0.038785560717505795, 0.05898198646102702, 0.04104217228990409, 0.09126160293817522, 0.03366951830685139, 0.015626404840018482, 0.08221370618670218, 0.023336880615041144, 0.029265527808738333, 0.009914438912434684, 0.07758249784068716, 0.01980344370578326, 0.017013935627596035, 0.052065304180066434, 0.0623235279213517, 0.009214947969021817, 0.03201635419240883, 0.011772904056875456, 0.0676314830179176, 0.034592305685603814, 0.04368862302433099, 0.06060258417780842, 0.11064730464450775, 0.03843556961885864, 0.00837503310908834, 0.06676531336720913, 0.03433020019363012, 0.04765183717433003, 0.05696853119579535, 0.01662208356954638, 0.0512976304537827, 0.06620740983635187, 0.019316121770609773, 0.0494255413932185, 0.02873699417367818, 0.02792571855318402, 0.025333836261603623, 0.00652242997368317, 0.06364084292022933, 0.024947256803692832, 0.047800550162191355, 0.05203091449314549, 0.059563071812473, 0.035858771598507325, 0.05972813311663847, 0.035859621956103274, 0.033984357461092934, 0.03185738137202158, 0.043413260380827615, 0.03125859555908509, 0.04678040449958175, 0.02049213951273311, 0.014272314747945677, 0.033909464705615275, 0.1325980066171577, 0.04734102381213058, 0.04313816586809774, 0.03269476718419502, 0.0059571250758674605, 0.02249868274966796, 0.07431691016761527, 0.04162037715075478, 0.04521344059837922, 0.042279611131356615, 0.06842496624637036, 0.0825171765961474, 0.028909634002634597, 0.01093143786889531, 0.011862228951236654, 0.01925684188702895, 0.06536202415102912, 0.02071063161917752, 0.00524102486745124, 0.10562641801492823, 0.04198202044673024, 0.056362333482191454, 0.05722264639071881, 0.023289471263847044, 0.05158004493662908, 0.05528815946872196, 0.06795400603403969, 0.01227964249048983, 0.00789597534739803, 0.0471930003034011, 0.04688186518427345, 0.034007899343006076, 0.10560979390697134, 0.04424718539080313, 0.007182533464079062, 0.010464674860779798, 0.02549604580347096, 0.06382242874092152, 0.04128589167169506, 0.02508335423866107, 0.026199314517960436, 0.032183809521337675, 0.07997754916188218, 0.01743830620281158, 0.015478266418100366, 0.04149014986450634, 0.09287409544471772, 0.028324394539419203, 0.022554390748301824, 0.02496104638632988, 0.028244397723146027, 0.03368475962610495, 0.01635368849571434, 0.014223184571751665, 0.015702778060409813, 0.026552071194014242, 0.045164081553417834, 0.023599221679051558, 0.06673817087205187, 0.032723732968612064, 0.06504761400602518, 0.013980315547556648, 0.032483503117316195, 0.045889620443866144, 0.03082998085676903, 0.061942540905288154, 0.08972467734448372, 0.07849797291020233, 0.03363206809867294, 0.01968401251360774, 0.05357658115005302, 0.045571169185061614, 0.013420103219217591, 0.06920606183308749, 0.06403087743467863, 0.033451240705025774, 0.022246710685712677, 0.06082746162710171, 0.04437336007193212, 0.03822667659410546, 0.03857675196242429, 0.015443580829718662, 0.03044031406452339, 0.06551960843705362, 0.02971561787079179, 0.010279944249158426, 0.013108662622530135, 0.011858701116345342, 0.021955867320479407, 0.022654842112153288, 0.025972004739507556, 0.03473403961247495, 0.06854616901687077, 0.07241303611907267, 0.03663249358895325, 0.04680025766813948, 0.05907174515267534, 0.03925624896862334, 0.09053406455824453, 0.02120184145056673, 0.03604736712370669, 0.08869875537892503, 0.025628642216625235, 0.043799862821376136, 0.010705028243753459, 0.11345506285227115, 0.021946162901698582, 0.07678421124094918, 0.07283454535589104, 0.02464548327899989, 0.026104039993257295, 0.04862544682597922, 0.05681674236491804, 0.050319746031516024, 0.02740524799352692, 0.027176252821640625, 0.014681777252154726, 0.06111564858245754, 0.03644656404973038, 0.010417068241945198, 0.030685615417877996, 0.02525556505837989, 0.00943129407166834, 0.07419877940969122, 0.00716084168450306, 0.026831218311863563, 0.013929719270597545, 0.057889843855293534, 0.024354249208925233, 0.02859555710587771, 0.036126408245294325, 0.04832027570134209, 0.04766915076141877, 0.013198147437745526, 0.05803536608695023, 0.02510359045118094, 0.026335804572989865, 0.013240785976391167, 0.03954295354384569, 0.0027471482040240403, 0.048089625779539354, 0.033809405961825, 0.0556419771765509, 0.08952235352368125, 0.07074927700863731, 0.07548292663188712, 0.06476785401783644, 0.023812722722669283, 0.026286999026553768, 0.04646809726592995, 0.07739995441008961, 0.024232659564023058, 0.05569636558873519, 0.06330235846220486, 0.022737562370997284, 0.0726167312372596, 0.05759866915703301, 0.03640780383120141, 0.05259020847358531, 0.016379329458540006, 0.02510717574266657, 0.011845337670116175, 0.043828920536344095, 0.03180094175942002, 0.06550905940633628, 0.04845385462225926, 0.02161775249987841, 0.050254115279042916, 0.02285172479347356, 0.05227520078000042, 0.05818379562227957, 0.08814515726220223, 0.03789053253468968, 0.025581847650990374, 0.029184171186399557, 0.02971360688999055, 0.04118761791276836, 0.04490039025944087, 0.05733389767908281, 0.03530315100966442, 0.047467481945791555, 0.014022458044271317, 0.02092551928193819, 0.013092663833841443, 0.03923042797513547, 0.016137280148423968, 0.007002641655309427, 0.03416803853225804, 0.03891253213007604, 0.028052237973878943, 0.037063460181196856, 0.003775163504835819, 0.011214745801783377, 0.008875889902664049, 0.03566084512239022, 0.05508608079605526, 0.027911176289161368, 0.06344295857894806, 0.015275903335291774, 0.04539416457015661, 0.05495052536829345, 0.05382646753963444, 0.03347467916506914, 0.07172071480102117, 0.044762505924389254, 0.056051730794171174, 0.06345960566954267, 0.07055059976635442, 0.07019518859564297, 0.04093381681389386, 0.03614354563216048, 0.01642942969356814, 0.02618257932725453, 0.03512016324807079, 0.02862507638882005, 0.019349324021248088, 0.024691199575881326, 0.03910902219133512, 0.03292827078351571, 0.03352904842505532, 0.015964017873029077, 0.02707569995113919, 0.03533089871428186, 0.04849310896749939, 0.02113722576459329, 0.03676851249990925, 0.024323881483606757, 0.0634453640950303, 0.03884395193909446, 0.0404040823360124, 0.03667808348132718, 0.03844781170388864, 0.059798203348632784, 0.055146532794160236, 0.05791232087499192, 0.01087617994691696, 0.08163548600409301, 0.06013513647861058, 0.0718983169645071, 0.009674984725162147, 0.030911686049113353, 0.03640870398451244, 0.05576595701577683, 0.052142135137992526, 0.06195569080450843, 0.00972410053720758, 0.02583648761614196, 0.040734821645122384, 0.020138856151231357, 0.017296744645723415, 0.0468744992488815, 0.02721825167686949, 0.034800842479472203, 0.059874160966325196, 0.041306476454220475, 0.016220611362387578, 0.02744564572499404, 0.10103283990775386, 0.09586378421273925, 0.15438833574373878, 0.152458299792582, 0.13700236866791404, 0.07999043476076857, 0.0790232181128475, 0.09889060526245064, 0.06945103376863465, 0.13472207731777622, 0.16658381198442754, 0.1360760917586665, 0.18439642874704254, 0.1407223077671182, 0.16959188686263177, 0.10079402731911791, 0.12474982653774562, 0.16401908750976288, 0.13949163348203705, 0.15116538852453232, 0.14171494321236688, 0.10993349456018019, 0.14188254792844096, 0.13316503425519313, 0.2835997740828222, 0.1013991142052316, 0.19992559787727174, 0.10767697491833281, 0.12817404037641902, 0.12947687248308815, 0.09043350019642422, 0.38631105134564064, 0.14710994887976878, 0.21793505327115137, 0.13138459995388985, 0.1675233268930066, 0.1385534975317217, 0.11694207291809783, 0.14475124076970164, 0.21499883744024464, 0.12805246222283573, 0.15612747790592332, 0.1485730848845936, 0.13817754754376027, 0.1717358911710401, 0.10218481398037366, 0.1436283090902913, 0.1544959557753417, 0.12907142811004194, 0.1475998008203122, 0.15394052670847985, 0.13604832873229059, 0.07345426452135848, 0.09997448177948114, 0.14068922809054776, 0.19425075561288865, 0.23190318035983273, 0.10037723718391312, 0.0752770864675122, 0.12481939498214953, 0.10429891021621805, 0.14006413098785186, 0.17146720881423644, 0.2986356591986072, 0.12209688703860007, 0.18285961040566046, 0.17967853755239518, 0.15445041950912247, 0.11320550971093679, 0.2113376419630743, 0.13829682743357075, 0.15766915324474537, 0.12790916547659906, 0.22622375688966245, 0.180246208704287, 0.09993444602455824, 0.12405155271652246, 0.10687041456901258, 0.12346344999969007, 0.12877721970360126, 0.1501161545034378, 0.13160587678993904, 0.12379527332321291, 0.2429217923312418, 0.14213419248980863, 0.10511113961617793, 0.19333279841849882, 0.11572334194375623, 0.14703410617526502, 0.1731161824277332, 0.215373745548629, 0.10762413783419518, 0.07414300054792436, 0.09429605422361244, 0.10004363653640594, 0.3012588361818945, 0.17486353705246604, 0.15443391797523345, 0.14182965721814864, 0.11731528797216954, 0.06969477996350297, 0.1724838534550321, 0.11665854377732163, 0.2142996596352708, 0.1401076294601925, 0.1710096398188222, 0.12342072527615294, 0.18906958040691194, 0.15757219715704843, 0.11489128618831597, 0.18119793505437914, 0.21957409838514946, 0.07623294969239543, 0.1646983470287054, 0.09196914642328217, 0.14369819163074418, 0.18387898231946653, 0.11518243790393877, 0.08787624507902131, 0.18933945786087744, 0.22122549283648693, 0.17252704549220302, 0.10581253141525293, 0.11253031045799294, 0.12385590152154047, 0.3124704103796713, 0.19212210370648294, 0.16862057930519506, 0.1455580232845199, 0.1248371605611136, 0.09844776813782032, 0.2045430702668044, 0.1768986649450756, 0.22510546770307327, 0.1455786616932, 0.11501143175748088, 0.10791050916117047, 0.13393397202655194, 0.13320497807956513, 0.1064038363796088, 0.10764801679479499, 0.14861931062994466, 0.13534574949693295, 0.1929639883699917, 0.10318117261293436, 0.10694785073639886, 0.10784910721403938, 0.10945969216165044, 0.10286573591011186, 0.21727349038325974, 0.14261437640074762, 0.08377759807532834, 0.10406788874177203, 0.11693009130296209, 0.0841999117044672, 0.19341783417809397, 0.21019895951594078, 0.3378796775735194, 0.1398923587534697, 0.09612950180927593, 0.17552097838732506, 0.2012053171112653, 0.14024558657359693, 0.23758615847797165, 0.15677085386649256, 0.08747989416963632, 0.11882296432891201, 0.10581220199744548, 0.17784815431842882, 0.13806384477403857, 0.15523239609695252, 0.1320474651912528, 0.1563926362582753, 0.11115968723090426, 0.1557933103533522, 0.20669406129708215], [0.08566009060990426, 0.05716145894820652, 0.012329488958893044, 0.06919516806280421, 0.012724306734819568, 0.06551088269559607, 0.03853133443983332, 0.04766917757449612, 0.02668294965499832, 0.024422919415237925, 0.03997122350659582, 0.027272724358725454, 0.032622785562829625, 0.048516417192595626, 0.04215998267154059, 0.00819821522811488, 0.011550252093002202, 0.026331568106768594, 0.012387307529758303, 0.04044670746811936, 0.020163127731892373, 0.03118006963162653, 0.02390344476988239, 0.03588970622888977, 0.060108840510609655, 0.05173808121452889, 0.04679676430720476, 0.08559416874401993, 0.015879215770250848, 0.034514379221946, 0.03416037765301524, 0.03467986187446983, 0.03281477102709394, 0.056110298215982415, 0.06409307228281133, 0.040924030040661176, 0.05750812139482268, 0.03396199535458319, 0.05738354017657619, 0.0225908967531136, 0.043823852864724976, 0.12133204017675693, 0.03618495268446784, 0.05204706745702894, 0.04134103851092439, 0.024404318800436395, 0.00476058000781303, 0.015204695462729904, 0.07808515877132455, 0.017902927037568826, 0.011339675590035417, 0.014922006145840692, 0.03764651437860824, 0.013203924698304507, 0.0516596376415222, 0.03764141989391177, 0.022987485149755113, 0.05769274858457427, 0.04521734381635343, 0.059315265351606, 0.06538207267200755, 0.05180670737078594, 0.05674723520754807, 0.05648376224862953, 0.013102336651495388, 0.01692027180275369, 0.029089662749620698, 0.0439401718247081, 0.030600903330430872, 0.0443791555270793, 0.038302657194435596, 0.031628663907007824, 0.033108121415059415, 0.0062610182700858965, 0.018388712966454127, 0.04903845631727769, 0.05206434657016108, 0.042158542426242944, 0.06247681062368136, 0.08250077465368856, 0.02027376998035658, 0.046393744602438905, 0.01458183246394319, 0.018659613147798567, 0.028423784871495543, 0.09793094224146298, 0.0959646090444538, 0.05018529377036518, 0.022737104633462527, 0.03271561626705431, 0.031086258334858768, 0.03441686389006434, 0.03161636245016369, 0.012976307527072007, 0.05823144629116982, 0.057552849438281796, 0.06425558251418895, 0.050586421237958056, 0.0663756657271616, 0.011576228219294741, 0.036564135563469706, 0.15119546513643958, 0.01403509945263185, 0.02089128855826153, 0.062339056523576866, 0.07930518443425817, 0.04116410667437219, 0.053021263165940205, 0.01844233720593395, 0.03430534830136645, 0.015092611053748237, 0.027970004180866866, 0.013884480821058877, 0.04307078460471765, 0.03219429343458145, 0.0508790131988785, 0.012113323844518634, 0.04037020592800072, 0.023736596565633535, 0.031007990962074652, 0.04663816112424097, 0.021866890038513852, 0.009353088943528072, 0.041299677423892484, 0.07934880548066671, 0.022474771230331352, 0.028149831829772844, 0.054616545507263754, 0.023348927347650452, 0.04937774133718303, 0.1281644566164863, 0.012849045001090536, 0.061218488225412954, 0.028882037600382205, 0.04133319377057976, 0.031106216840506084, 0.05076676599621292, 0.1414269247963544, 0.04896490804610714, 0.04161872240083833, 0.07764993656066156, 0.03375952214663548, 0.033476100258168676, 0.03170423656551829, 0.017652625045288476, 0.029301576076015353, 0.03161146714832754, 0.015328172556755525, 0.04645380972614212, 0.050276121154667876, 0.019289551926175916, 0.06734089054647954, 0.05656491777288818, 0.008165504231358008, 0.050865334698990475, 0.08587619635246455, 0.08615415603403123, 0.04007542678605645, 0.056784022749672015, 0.027997483754710808, 0.009129668976510725, 0.03214647039590824, 0.031009906181885354, 0.009497824019842572, 0.022746690308615085, 0.07784592483433024, 0.01965147675946355, 0.038123852272908536, 0.03829219626382955, 0.021286701009939277, 0.029456080688584237, 0.03124275669125059, 0.03890992743113349, 0.03233804600313306, 0.06232088491801293, 0.04410057148385433, 0.0365761976178375, 0.012515855168232755, 0.006818567964083125, 0.026660859509701693, 0.03922170606411753, 0.036390880948954055, 0.011655552793414363, 0.007979308955386401, 0.07609411157787808, 0.06000757134789902, 0.12091839866292094, 0.042359916298019315, 0.02294396944043617, 0.06261079940163801, 0.046786533202975995, 0.004385417653998781, 0.043484881940868594, 0.0251734193654791, 0.04799116049863158, 0.025472842915464314, 0.027499235490517273, 0.04140687610713705, 0.07384117722751633, 0.03417795170999823, 0.05841857475799419, 0.009817936731832884, 0.041463126112977346, 0.026909117962444024, 0.018319108132873813, 0.03553968831716526, 0.04597583597886466, 0.026757313809808225, 0.02194216775317346, 0.03246484887635997, 0.046896091437027346, 0.09717744114177843, 0.07185767600012403, 0.0409754345403804, 0.030480729032968803, 0.033711565042575525, 0.024747277211938656, 0.04072000933510642, 0.04897281790392534, 0.0420496468582461, 0.04032187344085786, 0.05219017268128453, 0.02422605397089595, 0.042158144060522325, 0.032735565196602576, 0.018825949988357963, 0.023058311893574657, 0.0419651894950338, 0.06479629120158573, 0.0452830933124548, 0.07385736466535638, 0.07067681275187962, 0.012628097582848804, 0.049327505121548335, 0.024428818292254885, 0.03203666701372112, 0.08313223028615599, 0.017484972448719126, 0.05253311960146793, 0.09392755827115429, 0.029534901559893644, 0.0439552407741787, 0.06875457557579202, 0.07037607727632408, 0.02030646661296487, 0.05465594923964912, 0.03969455468318155, 0.05387047546044473, 0.005038769515756999, 0.07911111904127945, 0.042123785017118345, 0.019851561688307314, 0.0706964246027412, 0.03441617058049287, 0.02214265296295766, 0.07308115671959615, 0.0060998266675479475, 0.06644085980951786, 0.021125947035128073, 0.05641208706243385, 0.041649618726824565, 0.027905015027030345, 0.09475757623271597, 0.03715590018058016, 0.05412022395419979, 0.07369724462830252, 0.02566689873234399, 0.027219601906836036, 0.05101408982168763, 0.01997751803437789, 0.06869809191313482, 0.06396567186100349, 0.05840009288682092, 0.06909340860382204, 0.01344472049705444, 0.021244031827776663, 0.023259015438417276, 0.11229922769651299, 0.06232610963765652, 0.041723235945908294, 0.07125118717310891, 0.029257409191960772, 0.06447876307872996, 0.028979719556387395, 0.038931113592679464, 0.010188379505228613, 0.02830769956832932, 0.04916071628911361, 0.015554945116051504, 0.012470895383176545, 0.028137873197274826, 0.01817548196882971, 0.032818923223643534, 0.06192260346705876, 0.059137479327018225, 0.01657655113376677, 0.042142990841380054, 0.03397046828702573, 0.10139822554323943, 0.04347717509635034, 0.03275454119448701, 0.020434612055279074, 0.05923879828544394, 0.0848122304605861, 0.07862357302538811, 0.022895340094222658, 0.06087107884307062, 0.03961586596203908, 0.025745823025523175, 0.02934814656093236, 0.053278458034319263, 0.03782726133302335, 0.029749187843633756, 0.058771404212400805, 0.019290356318496408, 0.041833663689753706, 0.04885739909725324, 0.0360557634473568, 0.02991809682439893, 0.013350132578653435, 0.005054906200272062, 0.11741756071006099, 0.05124621446274462, 0.045000885673347986, 0.09844871808684642, 0.048746392957025, 0.02218053601081333, 0.014532513638597824, 0.03520414563677004, 0.0338266046357251, 0.022299794833205884, 0.1144307217891178, 0.06179550181954138, 0.023782684415158246, 0.004412695172152693, 0.03137557143946329, 0.056202742045805346, 0.0427919362611588, 0.05758235531468546, 0.010512171354475281, 0.02381260206382121, 0.10505551397199593, 0.007052773491464436, 0.042242375427796956, 0.07627440270997825, 0.013404142734925113, 0.05046644803857611, 0.06145517492005902, 0.06675038231356491, 0.029125138366174315, 0.019627459903037357, 0.07031714979318843, 0.11928379685888368, 0.12244760209033567, 0.10318799079546045, 0.17552130014425324, 0.13585597937626226, 0.06823842383680806, 0.11398037700282951, 0.2153123052971017, 0.09035381939141982, 0.11827086008364156, 0.25360297321552233, 0.1609841842324503, 0.23886390120512058, 0.16113746310434035, 0.15971692158810555, 0.07178020152834154, 0.16969990525995532, 0.074589760042727, 0.09674788798175513, 0.22188112620384465, 0.10591760803494724, 0.15363101186531206, 0.14989902986393822, 0.11357571403946608, 0.14219429974834766, 0.11198087985957823, 0.2053098783137337, 0.15384640514610276, 0.22787435460955868, 0.15326978608725533, 0.1620962987503698, 0.19530135327048842, 0.11823225691313706, 0.11857394744912464, 0.1594645569040891, 0.2013660730012963, 0.15830764156435767, 0.10781590496340107, 0.15383299860742786, 0.15973972036473214, 0.12127649114136735, 0.20167512819170955, 0.1273245791033391, 0.11246520064530835, 0.14956648641776654, 0.1391848459118797, 0.11444440411944544, 0.10490217381307196, 0.15990012385431798, 0.11024998846433817, 0.08230332315208451, 0.10868523855723682, 0.16101724858726227, 0.12762018178980197, 0.1969679469062436, 0.1755423215968955, 0.1456486361642038, 0.18807191942487994, 0.15700958218545685, 0.11086775410559871, 0.16150106375496234, 0.14442220600622316, 0.14977832505058858, 0.16098200854274536, 0.1279976716144912, 0.10133982666077153, 0.11930415181503182, 0.13799511136547213, 0.11784074001855428, 0.1115274630607136, 0.12207621032552374, 0.1599790002670019, 0.13498271575137494, 0.14415520904285295, 0.1307926897800738, 0.12114480828806279, 0.21156264198643548, 0.08585442413365649, 0.0638330007542766, 0.15104751823650253, 0.06710595436274044, 0.16519104881632715, 0.19141311997607832, 0.1790533485191484, 0.1050660323591963, 0.2206247113645077, 0.15075858051498092, 0.1823189055487033, 0.09411393214137324, 0.15833184994276495, 0.18639487634983756, 0.16138297896231377, 0.11603113308909441, 0.15027281948395316, 0.09688912395147548, 0.26624714715346215, 0.14369600061928073, 0.12811593260736237, 0.16199529771843266, 0.16510169232083907, 0.125434824055241, 0.3718429599558154, 0.11644088287627506, 0.13698007550931748, 0.15706529209931053, 0.10094979597676186, 0.17492408864200118, 0.10910456444347098, 0.13166652031002507, 0.14388497918844223, 0.09965812577114952, 0.10198213009824676, 0.18240594845866004, 0.10040644811646593, 0.17001990018592728, 0.15409362171926808, 0.11652938901416718, 0.2007303425982114, 0.07118406254918345, 0.0847756497622017, 0.2402378952190761, 0.13467991183842384, 0.22511902745933304, 0.11970133776025427, 0.1921430179068158, 0.17249111596855426, 0.2563056701253499, 0.1339896053316132, 0.16382174326046822, 0.12893406854521844, 0.17405600377148198, 0.1916096674939317, 0.11063850995513702, 0.08312017972310705, 0.16678958320088927, 0.12831285550829866, 0.16045650287020594, 0.18827392148875421, 0.1284232564390667, 0.15573525621045023, 0.1540938975109208, 0.08954993268895535, 0.16975045174119935, 0.0984430950014822, 0.138700096116912, 0.21057368376322333, 0.09566730564279903, 0.1539764562321286, 0.2366047385599344, 0.12990624944288887, 0.10560557276250855, 0.123774420409914, 0.18436886490352694, 0.18183771040170424, 0.13875559152614686, 0.23945322200175256, 0.14004330871806991, 0.1283600388635551, 0.07492755885205923, 0.08023947462319367, 0.10447753893752253, 0.21132566034793857, 0.19575421848604757, 0.12452882549334919, 0.09176781851678126, 0.21543023687216545, 0.06659373265480803, 0.18081306780297912, 0.18495510602670331, 0.13253154082884713, 0.10940772075686725, 0.13131890025350357, 0.13058613715392928, 0.11457564264175393, 0.0912564624882033, 0.1286451461454553], [0.03999608305973872, 0.029131715231004263, 0.04779796461544691, 0.027191361990727247, 0.001379453228324682, 0.016333810429299073, 0.021682718671077204, 0.014460377842037669, 0.027706102212710727, 0.02551491454904599, 0.03515069185185336, 0.056550277832655184, 0.09787745398258972, 0.06708612800726006, 0.02700110213951238, 0.0750892187258409, 0.02928523159015083, 0.06220159736732322, 0.03650313964293849, 0.048983516321787914, 0.03786537803769593, 0.0487388393300916, 0.10953600984066726, 0.03508766962876243, 0.041663228278799404, 0.02417427025765421, 0.046972841955721385, 0.010137487326808756, 0.04689643234615365, 0.05750300009704887, 0.0943460874259472, 0.04154936846105322, 0.05329354613598797, 0.00479239228767373, 0.06813998919941726, 0.08204099166417315, 0.011252291770952364, 0.019827914469304587, 0.032318031956111236, 0.003847582035720529, 0.0203257471307992, 0.04729943289872139, 0.009589452923636043, 0.12875475800566136, 0.06190080443517335, 0.05342795243186336, 0.01763182192770464, 0.11313228702713406, 0.042844283049024885, 0.03463839353512853, 0.034937880287367495, 0.012093192969088354, 0.03437212435528636, 0.03776637266480154, 0.007963499294654017, 0.03220201943129782, 0.02034875083594553, 0.023437464129059546, 0.016926450301863013, 0.020240493036145647, 0.07361487485468388, 0.04038722840167823, 0.010467374363102981, 0.053570605664243626, 0.0562872453742931, 0.004860877196469735, 0.014888295404342635, 0.07580554923943936, 0.10123124901926327, 0.0617490079434168, 0.018957579215507836, 0.03461811901821244, 0.1321674345601951, 0.04784823530503819, 0.03224773572817926, 0.0451459635740086, 0.08021808544834776, 0.01897943953442718, 0.07731150189835219, 0.06041804891860774, 0.019035951925381538, 0.015041434465186491, 0.0617795595298371, 0.04226383355055605, 0.03226345585238549, 0.08334635186099237, 0.040031422695685784, 0.07774340694830303, 0.024389343696736523, 0.06503177130775106, 0.05016253329813481, 0.0391532254645661, 0.012518553712946034, 0.024221340614941814, 0.036283425626254855, 0.004906704576100193, 0.057477133138285535, 0.019750602791206013, 0.040192006215933836, 0.09101152119617309, 0.026151815151435234, 0.022085533447323308, 0.017760833049373283, 0.032969754444615494, 0.014105826605021233, 0.02765599240158354, 0.03722903093383197, 0.039051592410091436, 0.039941177538205544, 0.02563474793738175, 0.026667901772945642, 0.03771579937048016, 0.09027209313165757, 0.02585683299619104, 0.058691072232660756, 0.045392892864202304, 0.02620315070324127, 0.06488104350864887, 0.06454940404622786, 0.03487693799299098, 0.027080376917916923, 0.016766910576411796, 0.06850282376211497, 0.014004835149183149, 0.018847367891501036, 0.03996452406769799, 0.039384932587704355, 0.0500198724048753, 0.0405232971083493, 0.029986265243121216, 0.05250159891382341, 0.034435851379267635, 0.07389795200358476, 0.004353823230391549, 0.02878563118077094, 0.023901251843199137, 0.02082568461886577, 0.07616259983830875, 0.07163557944999588, 0.047130556476693, 0.033395243508200494, 0.023197563695571115, 0.033911395247184464, 0.056006087275642547, 0.017894701168481863, 0.025711184360026836, 0.023893989329676957, 0.0427530994338374, 0.02443691392639472, 0.027160076875119444, 0.08175392319718677, 0.0152133034181691, 0.06295289596422546, 0.026001514446350838, 0.05004537164143497, 0.008765794449455796, 0.031976824055515954, 0.01955257289321913, 0.014691560194947788, 0.015343121804987953, 0.04829657294096486, 0.03236058047942577, 0.04328902773258667, 0.027118733025065837, 0.038763895751007145, 0.053447012699419455, 0.0419591948570263, 0.018495063207322554, 0.05447088537978069, 0.047841662270647865, 0.0427766336548713, 0.007454840853179415, 0.017910924995498314, 0.0697983933552619, 0.050550794319039395, 0.04091745317583123, 0.043092974341444434, 0.033503618136408835, 0.055678236118007096, 0.01649684351568501, 0.03194992670849447, 0.02987265440395042, 0.10650981698305377, 0.027764679210621025, 0.033292361730409246, 0.026600746505503214, 0.003722361134057264, 0.08248366024946013, 0.05792581551377812, 0.05588516029679487, 0.05687943517020153, 0.021334554692129457, 0.054556721701256694, 0.06492317068360506, 0.03897756916440783, 0.02060838952480305, 0.021879771806960626, 0.04037246205693772, 0.03474263511898537, 0.1314568420451495, 0.016126688982870792, 0.017999574774876237, 0.05265920235204601, 0.01701943613889237, 0.008966420427896082, 0.09373231310277216, 0.10397843265485379, 0.004627748501426991, 0.028907149962540117, 0.039145219845757376, 0.06234596663665387, 0.10194161936881081, 0.037344173948851325, 0.05262622992778498, 0.035328263371822335, 0.054518708418453896, 0.056090713178198186, 0.05000295718350718, 0.02498339125586133, 0.07999026622142523, 0.06641193999037628, 0.03113429396293096, 0.003744579359678732, 0.09081859727420154, 0.020253361398053747, 0.02773814384014376, 0.033235751663244543, 0.046991591957668145, 0.04477011317747735, 0.006010654033161701, 0.034856862658935214, 0.004358690761540446, 0.041935767888301806, 0.06393020582054892, 0.01946467771044662, 0.03526334891155843, 0.05340025835340062, 0.024923806852330605, 0.006826674131931918, 0.06098221904868561, 0.020579812530007575, 0.05806461532389926, 0.04123200121666155, 0.032110016102031354, 0.14588733383965108, 0.016260861621929273, 0.04274518957601921, 0.03715960421569405, 0.10871025898884382, 0.049403466569680365, 0.08149627250649276, 0.0297287926678696, 0.03022797938977038, 0.028921493043702458, 0.028735837380912517, 0.026245519195893602, 0.04075522256654598, 0.10890446993852816, 0.03936994407746581, 0.05725822734436201, 0.042762143101783535, 0.016846825038233114, 0.05032630757458749, 0.03450234781109518, 0.04003155293063291, 0.030427794272620833, 0.06667366626882745, 0.043407602821506804, 0.05509523937719003, 0.032460853727834846, 0.03534422481372472, 0.0190433006237952, 0.03272346866827819, 0.04634709367828985, 0.10097718362005488, 0.031958035749172976, 0.021719985018153826, 0.014251224347390236, 0.004958850265886154, 0.032538098373240044, 0.026791998440580025, 0.03674887766640994, 0.007568777758522981, 0.003909834579850037, 0.03154328149262696, 0.031133594907700058, 0.017828783133037148, 0.008498056296018824, 0.0400457255572321, 0.01686080422763142, 0.04822975092176949, 0.04180076404384548, 0.014286439494049598, 0.0314692122816679, 0.037119300329997655, 0.008032873823052093, 0.02508993493393064, 0.03168339897397786, 0.046517437158693234, 0.047770937033478296, 0.022381854341215184, 0.021630580642170483, 0.054428781187462236, 0.04575600704899238, 0.05208957384550764, 0.050338407933351495, 0.03755654501278074, 0.03053624359440179, 0.04826747692160068, 0.010491831720085635, 0.03253582309210493, 0.04465099416613098, 0.02941244240519741, 0.010694212039872524, 0.0876621388259434, 0.013569021135598663, 0.09626863869808375, 0.039398182078354785, 0.005622245540331689, 0.02505192739678727, 0.062344986044110796, 0.09568907786160709, 0.03162135159777057, 0.05333789113548495, 0.024568156279142828, 0.013904074477332254, 0.08983595161548547, 0.03043573668917581, 0.07794174711189925, 0.04354227341771607, 0.03384180765058245, 0.007622303364182553, 0.053472894979941274, 0.030578317143203273, 0.035020656087586, 0.05787642965573938, 0.017688384114374078, 0.037602349409773465, 0.04422598773793829, 0.058663385815077254, 0.04050864567679744, 0.12275261999738794, 0.05747129554830252, 0.03245825285933191, 0.00606038510957132, 0.04204365988111785, 0.039091030616433396, 0.0605752693128682, 0.057746933983458634, 0.008005801233417926, 0.03834676853711567, 0.019980492370743907, 0.10779957962973465, 0.13220414549352663, 0.12244587839250604, 0.08752063472544955, 0.16004345890495086, 0.12032736949021779, 0.20785787142813208, 0.11953987706933292, 0.28368202128237296, 0.08058370091021061, 0.14282524976278507, 0.1726081742033843, 0.22230751542074068, 0.14437118455046608, 0.11579022141954592, 0.14031356921599758, 0.08619109679374003, 0.23487616841110492, 0.09974863905940326, 0.1426623335048076, 0.1085145311850694, 0.15331982695046933, 0.30407712043773744, 0.2802957594394684, 0.22413334809243682, 0.11193374246959725, 0.15528920917741715, 0.07870935955114904, 0.13805580085083363, 0.21538466996242925, 0.31939694838177773, 0.12395921613900893, 0.14995791138179843, 0.13938933010062865, 0.20627583857745896, 0.15518586391643172, 0.15209673693583858, 0.13949273664864803, 0.1838063265407278, 0.08050369068739877, 0.07653607536227473, 0.15090919340089445, 0.16828026772747118, 0.17942839452335912, 0.12786011286680737, 0.1299165303428327, 0.09249866639654483, 0.2187106560074514, 0.05804620240063918, 0.09353590348074514, 0.18531794058940104, 0.18357907421886924, 0.2000762873719777, 0.13131096358260802, 0.14445344707177532, 0.09118340068286465, 0.11098463614020618, 0.16018288690716992, 0.13769828293833042, 0.09394826562774759, 0.2844929713154993, 0.14889769165986969, 0.1508099237276662, 0.10895118598015079, 0.1781602432170222, 0.11743154947555835, 0.1446136054132254, 0.09597924132380756, 0.14642207853255734, 0.1595739849031933, 0.12945983468765213, 0.12611200747590873, 0.2291939410591318, 0.11109338998193703, 0.11137319593540124, 0.21534135535119042, 0.15887417890612157, 0.1123726265805383, 0.32371317967772484, 0.10867310372451622, 0.10123117241047083, 0.15115791150639135, 0.17628603975378698, 0.1611923303214773, 0.19657855973609034, 0.17085314337765017, 0.1869823432136928, 0.23344496295096415, 0.13133829759974636, 0.10436650215377731, 0.13033317492133187, 0.14350976464488815, 0.26529401120158935, 0.1198975328776625, 0.08975294598888967, 0.059407770468462864, 0.16348429685158117, 0.12959866514129023, 0.14317149086104286, 0.16266563997393654, 0.07447054143995047, 0.10065777858178462, 0.15253510776787035, 0.15943881634983326, 0.12997672953192266, 0.13574239918060843, 0.14465742564249426, 0.13759942695258126, 0.13957159773957345, 0.19292937651757272, 0.06275436044820855, 0.09932424167111036, 0.16056271330002816, 0.13158574399928893, 0.13279993207223956, 0.1345350446119424, 0.13451037658078058, 0.14026182763759168, 0.14677910614878903, 0.13710369145677936, 0.142631015830463, 0.10832074924462265, 0.1636318453857976, 0.16113553256277116, 0.11699836505877396, 0.11427152105757307, 0.16128059897211292, 0.26261981276254504, 0.19760926975117576, 0.14357089846124574, 0.17112436914636245, 0.1062737393283075, 0.17844479891561693, 0.14094752229509816, 0.13466413042718364, 0.13614969748643138, 0.09399603120982648, 0.13958820652577186, 0.15644016435309765, 0.2541464666325239, 0.14392737449417192, 0.11402317833515907, 0.18245275643083358, 0.12951390517334785, 0.1028945408160648, 0.21314297412191668, 0.10955680146693222, 0.1910628339335803, 0.14721147085149444, 0.12617557745186553, 0.16318746842443943, 0.10317199487960148, 0.2145607423998656, 0.11158780780650916, 0.10991367586557904, 0.1788646610633981, 0.15009862641173025, 0.11040532811274452, 0.12051169024479967, 0.1344021590005967, 0.12745271496955426, 0.1443017310192508, 0.12302648876943897, 0.10988436534159607, 0.11039264169671845, 0.2895243916540377, 0.0850582136321933, 0.10372244437495548, 0.2050586014745697, 0.2749451562281578, 0.10569731179144114, 0.12319659859302545, 0.17905808294252043, 0.12813993414203007, 0.10961471771400784, 0.13981823208591632], [0.027079945993459514, 0.06518880401047007, 0.011190786401951506, 0.035754870923776785, 0.05238141887070191, 0.08163769233731494, 0.0764422525741881, 0.10857509809636301, 0.004178759690764691, 0.009813547048026757, 0.04284292324295929, 0.006347507681517352, 0.01279722777150211, 0.04729341910851579, 0.015613947292759776, 0.004758445974138956, 0.03939275051497164, 0.025119203323077773, 0.02677024728918989, 0.04248230267436274, 0.012784775969902835, 0.018030813925208587, 0.032934460773943894, 0.04471398574570495, 0.06142433605066711, 0.042688790183033676, 0.05538946310538919, 0.019780440000636924, 0.031044414612434568, 0.06527783874902995, 0.01620681986453072, 0.041792413685470826, 0.031019172015329523, 0.014897174363385045, 0.03916253343284611, 0.02384401549915633, 0.00475939879599478, 0.035411016189403115, 0.03443278319713089, 0.02960246476915575, 0.029596000902294636, 0.050336167126172976, 0.11583784910579843, 0.015562672070377778, 0.05274810302521914, 0.06718588797675987, 0.03853172131423508, 0.013851471050011535, 0.08593738379497683, 0.026290955870682677, 0.07819590444165854, 0.023943796536074053, 0.05062362629800074, 0.07184472145332445, 0.020137743408521338, 0.04102730635373343, 0.08072119837086048, 0.0370120326988399, 0.06109461563849642, 0.03803294827981341, 0.06909884016720519, 0.01935820489551031, 0.020559863600459312, 0.06140030004204281, 0.06487689897297852, 0.07440542396638664, 0.02223097907018758, 0.008149645253715497, 0.05765645899960111, 0.0064253867434848465, 0.029496821244397474, 0.008085087981946286, 0.05708694540625138, 0.05185274542459557, 0.03859614547822745, 0.03315530477031585, 0.08637794563847204, 0.027069293540872397, 0.032818808310454896, 0.03149071445448264, 0.058106868903362946, 0.023496732521321506, 0.0484942197949896, 0.02298668075743462, 0.04608141055570976, 0.02822189963602972, 0.053568931762129075, 0.05243903251304742, 0.031612302184165005, 0.047129441818763176, 0.026982055278494958, 0.05544879661512472, 0.055509876805327596, 0.028059669026744463, 0.03456497549890511, 0.05955463335398705, 0.02776829897606325, 0.07624003600569502, 0.05761047074150655, 0.024851886517999154, 0.09775797490991893, 0.032366107803799456, 0.04473810985444054, 0.030702959648483706, 0.010378440173583166, 0.04013829579156253, 0.013328970357355092, 0.05113222824049093, 0.007919882078685107, 0.0517109846846471, 0.03863111739197085, 0.05136072928566606, 0.043140628840774305, 0.05112820627888845, 0.09069224639284997, 0.02923924716249589, 0.018855769960810582, 0.022759474400851517, 0.07258641713809583, 0.030412872795075662, 0.051300258135362986, 0.047444269481685855, 0.026590318133633946, 0.043339240965583635, 0.04088158876965604, 0.014980649218834458, 0.03192955451536804, 0.014992276518305224, 0.04387166441207932, 0.044001884037448515, 0.019328068911788926, 0.07369546730431818, 0.020194110242770087, 0.025088038866318045, 0.046217571192931746, 0.04902300049340533, 0.0507860369379482, 0.020311743043543353, 0.045155777160318634, 0.038417037951970295, 0.0685552471587735, 0.051103055612334324, 0.024828798543181152, 0.053128002196430206, 0.025407171943375183, 0.04728971124296227, 0.008646528923793907, 0.04655801683604237, 0.04370227088070205, 0.053737834997234814, 0.044516277604646264, 0.07455902459520487, 0.006315996569971885, 0.0428319375421251, 0.030301033534229766, 0.017156472031567848, 0.010639173410562499, 0.053398764481948274, 0.017806828968347083, 0.038511136531709664, 0.05126304158400144, 0.07629970659411724, 0.07719471945517486, 0.169402142205546, 0.04805072000430477, 0.011659670516007371, 0.06482897251243554, 0.0766791576038926, 0.07432942038341876, 0.04422904059831654, 0.034557207367352905, 0.03780058615149991, 0.007374375286857568, 0.03924458527997617, 0.10516100427916936, 0.05387358960785693, 0.06439080086326407, 0.04779334893570312, 0.0750337922645192, 0.031514761954425805, 0.028691584311966455, 0.0078830394739916, 0.03655875762624126, 0.06838968023657799, 0.04500285068887376, 0.0762953322320696, 0.03346188166629403, 0.005327748414504552, 0.04063742888730861, 0.07256020927020619, 0.010684636898428924, 0.02902897517947901, 0.029976673822309223, 0.04076132062642325, 0.011655704095779408, 0.02727979535026656, 0.09822774768596697, 0.031457041059770895, 0.04487346226890241, 0.07052092152016778, 0.05799292098550547, 0.05561151752068151, 0.05578834976580355, 0.019696721912271554, 0.0611344866845156, 0.017366293937929215, 0.014697136357426645, 0.03830207113717352, 0.02240616805671204, 0.005750484828416619, 0.03306924245290218, 0.03555209894153861, 0.047215936975854064, 0.0475955986598086, 0.04551281243742955, 0.014631858005398705, 0.01029108795562699, 0.023347404747900945, 0.05455721582796785, 0.010233784578890811, 0.01941777780772217, 0.06584637558027621, 0.0716203343003027, 0.04560915182434744, 0.003089504518298312, 0.02309079976722358, 0.11652621741016066, 0.018374306683038032, 0.019688612871593045, 0.04472346608376792, 0.04660838711706381, 0.02146032334665858, 0.05487344160135235, 0.03989137416224807, 0.052388317492460056, 0.005773038456907437, 0.024559348183233413, 0.08062130816641354, 0.03862033087399699, 0.016491584322084824, 0.05521933412960461, 0.03329920672601269, 0.02451768640669123, 0.08834578802869206, 0.12677357036380038, 0.05629240497646313, 0.050070181398862795, 0.05280360226489363, 0.023300972158810305, 0.0312533899916396, 0.0407933660842959, 0.05588932781510296, 0.1277209989606373, 0.007552315965445052, 0.03980104090465654, 0.0512615132385925, 0.046968502067630334, 0.044279295966149344, 0.04652734267555418, 0.06981390663572858, 0.03424137995968904, 0.04410455897150021, 0.05210224110933562, 0.007151426463913654, 0.014335174177352701, 0.010501997706840837, 0.013987938122403239, 0.0281355423747652, 0.029788587745579503, 0.04831313193144818, 0.026298817848005605, 0.04462052301894273, 0.0789789382308241, 0.03651241696770153, 0.051576570727892464, 0.03299928713409651, 0.05113027471628401, 0.02793409763985584, 0.025939470900583173, 0.0752159679729131, 0.029463178493202697, 0.008458037778074223, 0.02014757614702948, 0.042155991353455095, 0.01579710646652647, 0.05165946144129961, 0.039052603646151485, 0.046293398575677026, 0.045502941394525195, 0.02036322798249462, 0.06527171770651495, 0.017109539570106615, 0.06402657202054417, 0.04329453973520187, 0.08212709228598303, 0.036144380667997945, 0.009004658749026638, 0.012134650774720696, 0.06917118951077424, 0.027520827678663116, 0.027234975376256534, 0.04925669178426747, 0.04848761228664268, 0.007685187212642163, 0.017885452572015986, 0.04003568214454478, 0.07483363647254244, 0.05045553511609474, 0.01118922262497607, 0.037028944089768395, 0.030228188148729747, 0.0488201825458917, 0.031852279226445866, 0.057992633702533866, 0.025914509840790304, 0.06152274770542018, 0.020653943028000575, 0.06854615369511229, 0.042155696409604246, 0.04722060628175255, 0.09244255045609129, 0.041874641732823466, 0.02126166908701341, 0.03016116694667407, 0.024981520086106275, 0.02541929719999673, 0.03046802346474461, 0.017679826912259864, 0.03655994123208427, 0.008428677458376175, 0.03241889126178238, 0.057754721267208944, 0.03749435016464803, 0.044170511480901516, 0.02719016880878518, 0.07112176427918096, 0.06424264711958748, 0.029830228454703768, 0.03765915482935887, 0.07704054426041342, 0.004450183684727358, 0.019677324566028772, 0.04726354934034809, 0.10175141505897047, 0.028378915101770433, 0.04405511565686714, 0.013471998972818257, 0.05615136435916347, 0.034597641487996426, 0.027280433118463527, 0.043783614096502145, 0.046160616386201114, 0.08980557622928774, 0.18823961607150494, 0.18041623425820183, 0.13992928419142, 0.22888914531757756, 0.15603655859106974, 0.19312731831544833, 0.20672536364966826, 0.1130991307417712, 0.1685467590728114, 0.11224947794671021, 0.17470305695408778, 0.10041176476666044, 0.21892635572341182, 0.09132917189309675, 0.1900226091064753, 0.07418080698698759, 0.10054582249253027, 0.124177681432376, 0.139771178965607, 0.21783687144277558, 0.1368447230948556, 0.20395828471068414, 0.12887996741600577, 0.20785289185662426, 0.19009817601932635, 0.16903786739755064, 0.12951379792103845, 0.13755278751975106, 0.11168477921596459, 0.09846702758823672, 0.1673505587443229, 0.1044888617170434, 0.17033154475352458, 0.14462938682446558, 0.15764986315081198, 0.08800478697183632, 0.2201837051900164, 0.1375696720976022, 0.11697038752777923, 0.14451890162402584, 0.14047513715922832, 0.2007391679310991, 0.1391470624554542, 0.09703181548825196, 0.14925594501678022, 0.12063732100350243, 0.1275384861735567, 0.15503382610697902, 0.07246450190582583, 0.1969316649821497, 0.17004360294630452, 0.09230065565075606, 0.1232291266862904, 0.12036146040284827, 0.09913807464463097, 0.17710746986971748, 0.13810340555444842, 0.13673766996831666, 0.27656150981783867, 0.15773071607034053, 0.14456806914700618, 0.13539571375135454, 0.17210951225171167, 0.26721229536398766, 0.17709044739604, 0.1010677658562218, 0.28536245046604064, 0.2489269717085746, 0.1619328615526038, 0.0998320124082027, 0.1706078267025371, 0.10304084062696466, 0.10584895123517322, 0.18908055078598762, 0.12349011752033427, 0.21095151832747847, 0.08528659210330056, 0.11943987961257659, 0.11442650830553425, 0.16200966952789217, 0.13030329749228495, 0.11922604149027217, 0.13747538199588177, 0.1363764595120184, 0.13475020806635582, 0.101991729179938, 0.08161274851450036, 0.07592552626926093, 0.209577463026489, 0.1248532867119197, 0.182673788118747, 0.12162460915503964, 0.13813841577258804, 0.1268795969325208, 0.15353673708535012, 0.19099250706213136, 0.12768529160248657, 0.16431213146255863, 0.15326054706688852, 0.22483123886969783, 0.11715509132632326, 0.2646767894827551, 0.2101961556341379, 0.08361265934523075, 0.15106791149704688, 0.09480097511362645, 0.10804287383272763, 0.0923517230717886, 0.22050160103507582, 0.15886518503389052, 0.15363496487900136, 0.08171980930191856, 0.1520225183377343, 0.25133072578858945, 0.07989178561875898, 0.17414284749857842, 0.11608622247172941, 0.1423167205986477, 0.18241891066633886, 0.17760821558054418, 0.21031045595244055, 0.23477138290482186, 0.1576808284247114, 0.11131911778882628, 0.11273720016282414, 0.15934270295885303, 0.11921012984408487, 0.10535893075528646, 0.09429878915750212, 0.17047625876242117, 0.2346986198737737, 0.13692773638233063, 0.11414482543665556, 0.1329871792826922, 0.20529083336793608, 0.1903571597030086, 0.11297783604071987, 0.09391350821862299, 0.11056455948780622, 0.10930648223767359, 0.2079999807380861, 0.1568923860548004, 0.10800728138776557, 0.1425763784397033, 0.2501586265861988, 0.08278682422373565, 0.11403037190076806, 0.10059113659325147, 0.11129637263835439, 0.08832367107031808, 0.22488820516774732, 0.12438685407922154, 0.14696278338951452, 0.1397206171626045, 0.10278240086570864, 0.11833409298091166, 0.13338107104984023, 0.10728507497978788, 0.1356763011145015, 0.17004269896255386, 0.08641998854375656, 0.13562261367276793, 0.39291610821120204, 0.13720296113000763, 0.10678213059661851, 0.16978207585071364, 0.3240669284376406, 0.15915134951712626, 0.1330829862385027, 0.11701936352877848, 0.09763075068833367, 0.052049024811675476, 0.11933009921302719, 0.16405775962818056, 0.1226800408274416], [0.04924439224264315, 0.022342337610860987, 0.03453456563875079, 0.05717545920502275, 0.05214743263598892, 0.061009556896263556, 0.005410216343138488, 0.02731816677917396, 0.011736817485202226, 0.033491563742920276, 0.06353179796508725, 0.05518682901897738, 0.04740930139838208, 0.040690507289142384, 0.04453664405211326, 0.03406806022769982, 0.08591748083070402, 0.020418801915741736, 0.033743231286925655, 0.020035441942332734, 0.011746627241072637, 0.04276176771870063, 0.04949327505704376, 0.02533298015834824, 0.05997775903632564, 0.04166386796221618, 0.07548591437479181, 0.09382200667694693, 0.018539431189457257, 0.07388880491376885, 0.05527206396143283, 0.04842339113595025, 0.019301686758896517, 0.04530219571484674, 0.0773065989356368, 0.05014574065083458, 0.04936824950780119, 0.07727318218037968, 0.05178078678586791, 0.01785929258462162, 0.09788581966272286, 0.03538499601305493, 0.05077563346393647, 0.060782258609129544, 0.04158755028319936, 0.06651198341240806, 0.01864525474487774, 0.039117774745870026, 0.0526081042874965, 0.04255234226284008, 0.025645168648371776, 0.05001532184260507, 0.08183017192829041, 0.05634946320506354, 0.007150352025599851, 0.05632605538853715, 0.00232581157639112, 0.01714675229102854, 0.06465244287204358, 0.026098146861899766, 0.030476373823119268, 0.03489032154902816, 0.03610250247161716, 0.08831575738206025, 0.06721293088048697, 0.014007430272026649, 0.04501002127184503, 0.017675944761703574, 0.023505804917564797, 0.056070442491721724, 0.0035731240941752353, 0.03141825785860419, 0.0179065199899337, 0.041785281406895775, 0.026441135916919, 0.0558028556406498, 0.060333959277599096, 0.03465677964531126, 0.004081046133632622, 0.05223424955000801, 0.021813830788878184, 0.01900299099243937, 0.021252194494609872, 0.060561468238912286, 0.022468487394132444, 0.055074030233006326, 0.06448761139425539, 0.052926072910908735, 0.04399722239242927, 0.024988491486217228, 0.03310559332490929, 0.05570732447649202, 0.03741630495736196, 0.03988362518289397, 0.05788533542785914, 0.012469988526596178, 0.04425323365496532, 0.0665892357186925, 0.020798971132946112, 0.05733426923172609, 0.0428832654330519, 0.025532643738833648, 0.06381995044648647, 0.015036698126594627, 0.06138669049006797, 0.003050729456815809, 0.0037031177236067675, 0.05425698597044234, 0.003946787549085134, 0.05166890730540599, 0.017566997482771837, 0.049661002347185734, 0.035618250633800225, 0.026801346628476056, 0.021320184797889764, 0.0173575930943292, 0.0169042011933221, 0.051535404993281256, 0.030539510959398844, 0.01751633608833917, 0.023130360547633424, 0.027381711857273217, 0.041701076852698485, 0.021071562453383402, 0.0689581711025488, 0.052351104771538134, 0.026121389969522436, 0.07319816898915076, 0.05185634986827931, 0.04187754520605649, 0.015612994470903951, 0.0050286992899923316, 0.04148623898565289, 0.07670695127378549, 0.05750209994373783, 0.028723652752476837, 0.047734586161471186, 0.04454946070308647, 0.023172600720558437, 0.06757803306344055, 0.03152435720567742, 0.030766759450817784, 0.020766885455457434, 0.09174704987315402, 0.05265745184113903, 0.02522662034138076, 0.07114499972592439, 0.05019425699907926, 0.047987793542204366, 0.011492562799474165, 0.03771380754187703, 0.015008555886696183, 0.03331383517492683, 0.018364640568653424, 0.06538568094613091, 0.0761738306872787, 0.05976867065915178, 0.09989283212851133, 0.030583601234660997, 0.034586789852548996, 0.006108818145754237, 0.06149405005177664, 0.03806491712889364, 0.04735091400723304, 0.02270973614236761, 0.06096481353104596, 0.06587339550136559, 0.057886974856017105, 0.06559306860811288, 0.04375562890462818, 0.037020294957103274, 0.0389579841266236, 0.00865337679222707, 0.0185889606889818, 0.04411434957517251, 0.0192801175533884, 0.032282960450937676, 0.020350715851471312, 0.01905922759174099, 0.01874049479562429, 0.025139033508997773, 0.02163187724598233, 0.022262208644420873, 0.05887088072936862, 0.014586811077841108, 0.0384562348406161, 0.029643203409749175, 0.01929041952075016, 0.03101667073825675, 0.061661447924111164, 0.041228052033411886, 0.08499522588305897, 0.05330252085602092, 0.03182977539367013, 0.024134044895970055, 0.03940417671636228, 0.051266136579215534, 0.07617723977854175, 0.07040456808622807, 0.04254810196617919, 0.05043996054859412, 0.05582790671577377, 0.04824471644937031, 0.05879153700305089, 0.01291406862888365, 0.014770201993204895, 0.047331953331107096, 0.02877694565892941, 0.05770406753365552, 0.05892768614895402, 0.021597455000324596, 0.03740090659008392, 0.01041215761835056, 0.09195806879189708, 0.04755090509030608, 0.007179148313063648, 0.02429603035711954, 0.02045756787993014, 0.02282596508701963, 0.031639588320808064, 0.022466997353119716, 0.02604610459398358, 0.014247075981280256, 0.015825078251861757, 0.018114756094291806, 0.034737598090883226, 0.0739608861265644, 0.08409037645305358, 0.06865440957969235, 0.22918574391834198, 0.03897364679423552, 0.014907302045744034, 0.03884837609685717, 0.030925289855428764, 0.11409273911868373, 0.04543628791467317, 0.02033033982790526, 0.008909938680458694, 0.05411492262576377, 0.010956508096217388, 0.09574590626383021, 0.02102468361807687, 0.07430768646900693, 0.0060911574250748085, 0.016847633260993228, 0.008469777117903915, 0.03232770764659489, 0.046745842442877834, 0.039665496968213594, 0.016206021217869657, 0.022781947590110284, 0.021552761430822073, 0.03512377918307339, 0.02946599769676405, 0.006624297163779698, 0.017864773943719846, 0.017291089001622413, 0.052852030513027025, 0.019388132120272326, 0.06449433764623058, 0.04895689476641917, 0.018253452482543165, 0.054102063839954716, 0.04314549732953311, 0.012618600007807537, 0.06390765602249773, 0.05850702726973161, 0.09001625040846487, 0.01224791783193547, 0.05524085736983726, 0.046294187646239035, 0.038048519016874414, 0.03716102913923321, 0.028502259088019212, 0.03828333645698525, 0.0760617213804395, 0.04985700594261289, 0.026919741686733983, 0.020328116257705038, 0.037727394111214146, 0.042979600989530166, 0.04729606594229418, 0.030289090223490234, 0.05661187513220695, 0.046577234151622945, 0.05386249282427373, 0.06814968787253865, 0.02526920716909151, 0.028907174860397657, 0.009645349571421262, 0.07799682883365501, 0.0407530430464014, 0.021331848486536936, 0.04668295045473403, 0.035972428402953574, 0.014527411493022117, 0.04642670170494145, 0.03792702130252316, 0.03713806948414253, 0.015620658222976473, 0.12059487207161805, 0.03625849329475914, 0.06807416692496308, 0.031192309801436724, 0.039592611363097545, 0.03492466527067366, 0.015221791672370127, 0.006939904321165335, 0.014441006351262333, 0.05610891542727909, 0.06548864316315421, 0.03963543567806482, 0.02262955163455298, 0.044898930861945116, 0.012856444452829179, 0.06976398834658247, 0.02766693979802151, 0.0032840898934556476, 0.017132045318102165, 0.052945213617696885, 0.0712640191458406, 0.030271544894804398, 0.04225295893247089, 0.029063650234151753, 0.02618993185610781, 0.037162293184308276, 0.057246529181758245, 0.023054215238399567, 0.018260420052214496, 0.0391628896637309, 0.06359804158789978, 0.06487624013736364, 0.01863427862014261, 0.06481028762796233, 0.013278046577808358, 0.03081542327098789, 0.009184259444385046, 0.04652500610738512, 0.02075912115434485, 0.07938698730281285, 0.03670113506696878, 0.006815001345990647, 0.0327703609101234, 0.024804877447745493, 0.04675260316880961, 0.0575619965280977, 0.04936523878225877, 0.07915654805518928, 0.015403976956863078, 0.039344521449698557, 0.024472818552185933, 0.07667176485542329, 0.1100446922223895, 0.14181678694102073, 0.13567746556814642, 0.14904591435145947, 0.0785557589223308, 0.17121093708180612, 0.06884072216287737, 0.12978058037978987, 0.06726290279578778, 0.11991394248100058, 0.16389606911088192, 0.1094658438476824, 0.09599534449197593, 0.17883418608577023, 0.11404759355730588, 0.15773825437551545, 0.11021527702048903, 0.12431396847410549, 0.1977522217578465, 0.1544811396348861, 0.07892194128925763, 0.13521457992253766, 0.12620501821079563, 0.18362332345737567, 0.15235602705469056, 0.15592415817081928, 0.1553615431992277, 0.17058029350253845, 0.12424586325763695, 0.14422489240044548, 0.1529921558234961, 0.11818491267941653, 0.14575233382563438, 0.16906331683839523, 0.21410916421201923, 0.14577795180582231, 0.13037423723407332, 0.14558517344055638, 0.1569333717587494, 0.07154022448606069, 0.2950879366647813, 0.17840862424383241, 0.13835241477335655, 0.1516184376011933, 0.1339450956232125, 0.14951227803624448, 0.08545449559366511, 0.16059646713397197, 0.13165965616222353, 0.08711325214995493, 0.1513521760822304, 0.19469163921331206, 0.262874307170991, 0.30165300374069526, 0.13110646407210058, 0.20506229401836473, 0.10698103000439944, 0.14515968820741101, 0.2561193422204064, 0.12806537846523908, 0.09027311968947611, 0.1517334427203863, 0.1159939778247668, 0.15779414815047096, 0.2810658616644721, 0.15390550116858176, 0.17255545203243533, 0.09254817099821183, 0.18438558094203475, 0.11848295152547861, 0.11832503016076742, 0.10346407356161265, 0.08786855355626152, 0.2008914508886876, 0.20172867773761674, 0.08704540740338065, 0.12408549807244733, 0.12509841952593098, 0.06656184041452023, 0.061300551563861876, 0.1309538593575839, 0.20866594097066313, 0.0796845052090864, 0.13690198050631633, 0.08898522629733048, 0.09272056376381267, 0.2573653076204562, 0.18912322188337005, 0.11598172807885755, 0.16658584977830612, 0.1263208277223091, 0.13832131160363076, 0.10105853449673423, 0.17978408914660254, 0.24438852894931073, 0.1135698994321208, 0.11295633961356456, 0.1254737643044322, 0.13835216962522076, 0.12555827146335957, 0.1404348256126527, 0.11112888283546894, 0.24659553632861186, 0.09519519629858195, 0.23400457485789256, 0.13893877847060082, 0.05289077540979751, 0.23716669469591112, 0.10176206368111795, 0.2014414560530455, 0.25625651792412807, 0.19144322723150256, 0.21153167671253606, 0.20002888185122322, 0.2576743781326279, 0.07608626683753344, 0.10041210184534712, 0.13595593852862237, 0.14841363134403385, 0.06538038727857413, 0.09689406521858708, 0.13906000422373896, 0.09083622495733923, 0.12557602172056515, 0.2950953523958883, 0.2150161050620579, 0.13375014156824158, 0.21066135486527798, 0.1111369267586739, 0.24278896800693006, 0.06696343902618655, 0.12441945878127891, 0.14511335520975052, 0.22015284716842637, 0.13642999373616713, 0.1649446136528446, 0.06546670240500281, 0.15813942397794417, 0.10914283819616803, 0.212395777925849, 0.1299233332036003, 0.10774632885811791, 0.09393225439013013, 0.11822214455253656, 0.14365608743842573, 0.12006185873742066, 0.13545986595413378, 0.2509752456699648, 0.1343334715573057, 0.1229576634303216, 0.08969184281604906, 0.1372003411093066, 0.13123853763024654, 0.1435377115323659, 0.1548996075026451, 0.14443437148246074, 0.14665020419464958, 0.26837193797672954, 0.12252915214987532, 0.11306255770426606, 0.06795044372519178, 0.17298781673514074, 0.10322192082962683, 0.19032729759572015, 0.12482695626996218, 0.12509623617534676, 0.14055326280574645, 0.15190703824402826, 0.22633058018982413, 0.10735811380248879, 0.09707237984384261, 0.11637654681239398, 0.11927186120902339, 0.07888125435959908, 0.08492440871533849, 0.09939974729692745], [0.1003895099124601, 0.017371589520705805, 0.04245764613451977, 0.05881304109108545, 0.018732650055279656, 0.021546044754945946, 0.04732564076661103, 0.13327610168245532, 0.07462303890215774, 0.044055774492482026, 0.03689867466868412, 0.03696377299004986, 0.004134185822500337, 0.02159773653763677, 0.03246477226756754, 0.039848998008716496, 0.055616508583508195, 0.021683812261589115, 0.0329943267147868, 0.05274018933696132, 0.022955638874742775, 0.03005099009662386, 0.03371658674891918, 0.026026523386638974, 0.05034638290864326, 0.05437147781072606, 0.008641495726131385, 0.016651667969962283, 0.07105288531390891, 0.054901016936186826, 0.014020550485339858, 0.012246739014141984, 0.017283633050899354, 0.07570301603165365, 0.05562429969769813, 0.011302431267986615, 0.02010994590818882, 0.03207209474977947, 0.025583172983099377, 0.03724498088441549, 0.028458128593141035, 0.036871689221551346, 0.01780695920329421, 0.0030706984961720845, 0.06271921999512181, 0.055061592795555635, 0.011253121061130397, 0.07283596261855095, 0.020717262110162168, 0.0688273769112364, 0.0896184362711445, 0.07734923938950224, 0.06483616607804453, 0.024361322115686153, 0.043147029505381664, 0.03810357009511321, 0.06008051440960938, 0.008500464684930781, 0.04951518517167819, 0.006199772413369389, 0.049141169555725596, 0.03597410996594737, 0.04067305963666689, 0.034528728048767776, 0.007308780444755911, 0.02656891172180974, 0.010241023152165357, 0.04211929957232168, 0.025854301075601292, 0.04488463183083842, 0.03788746818299255, 0.055977462400351806, 0.059943924763149796, 0.044846676004629944, 0.003916134216612385, 0.04056827029994419, 0.045260145148682984, 0.0813342908757829, 0.01156979020790107, 0.016661969937324043, 0.021739543242860707, 0.07469049294389064, 0.0521934783506778, 0.01898249239480544, 0.04874036384506091, 0.043627236398958394, 0.03042406917008902, 0.03537708615523673, 0.017163943304049394, 0.06204451103844951, 0.039265974454822085, 0.02246079970181229, 0.0463638556820731, 0.04609652930089543, 0.08072325148649755, 0.0319611364900465, 0.003978302251667746, 0.012116124853491785, 0.01363385707185033, 0.019537751007104115, 0.010561498798309796, 0.015437929973667188, 0.03122240365032227, 0.022202042014067693, 0.020386461514018236, 0.03429765677860668, 0.008781257934207398, 0.05348785667710247, 0.03635955561373023, 0.00761836902388642, 0.041272917972697366, 0.035094618046235655, 0.049312754098566315, 0.0606470555818129, 0.03952577785258332, 0.06624769073941054, 0.0147644936805591, 0.040817781306442716, 0.026776058066095558, 0.0649844577175475, 0.051348533165911515, 0.03138542907582897, 0.0227816641375783, 0.06202957232392604, 0.09723292122925482, 0.03567044037364183, 0.03904404644403727, 0.07334604694117462, 0.014936241017083728, 0.07565803900961915, 0.09291495857459885, 0.0261627261586968, 0.051804508698443254, 0.00953705442483507, 0.031006112131440354, 0.021913667367170417, 0.022846268332232873, 0.035478945205649065, 0.031459768332781336, 0.0791233534654302, 0.03361782269372094, 0.022968861552315856, 0.047467171680182225, 0.08417694438849727, 0.015155722334560369, 0.04218383864950269, 0.047663018227584904, 0.05679105160637729, 0.03720860319933103, 0.01608811454066346, 0.0673723461166505, 0.012908540346900062, 0.08121931640010688, 0.034846332780415976, 0.04992103940176387, 0.014098045066930355, 0.04917555924264654, 0.053509579100195444, 0.07110089604412356, 0.0643692584708333, 0.01174749962369641, 0.05177407585565121, 0.025827089632530848, 0.05690424109718973, 0.06303256910835063, 0.02017024851914856, 0.029389909844124512, 0.036405949898424654, 0.02835574094206095, 0.026338303934842832, 0.04041291532977935, 0.05099314114739818, 0.025310374818922534, 0.04429561363893651, 0.026914562932365847, 0.04509955779799531, 0.05241168317415061, 0.05569783647754981, 0.019239149086417693, 0.03645027957616314, 0.03636888656464796, 0.032424456890552275, 0.02654623743447085, 0.06818016285016652, 0.024911698832687353, 0.034067945314511176, 0.05206201000199203, 0.008687727217141901, 0.03140275798467619, 0.05258777614442572, 0.045821419466407075, 0.01281943474520719, 0.0226800253374442, 0.04978587467884345, 0.05692056260041653, 0.06371927883235678, 0.07855915269183536, 0.0389989506783745, 0.03494874724457341, 0.01504898521929018, 0.05671836135368194, 0.03595212324252052, 0.024732794319730134, 0.03774229835178103, 0.014752308094513514, 0.016793844312609687, 0.02420838606814223, 0.00012052425899450863, 0.03594774121959363, 0.03323167607548737, 0.05934003297419799, 0.03149617666138276, 0.0737391189942437, 0.014562516514542363, 0.043169380120572545, 0.035019219672727975, 0.0323225710270626, 0.02996464432667821, 0.021538516025870078, 0.025439546819055275, 0.037455195410838055, 0.05079614546810908, 0.038075040980813005, 0.005072932727935334, 0.06440153375508324, 0.024745965286368327, 0.04567031628422199, 0.033457905669967015, 0.052812305023713466, 0.030570916733854724, 0.03365598153322935, 0.029433666871139602, 0.05461031338199974, 0.030121880042697155, 0.0705231431751482, 0.062378119346835924, 0.02134674315100476, 0.06226990559709169, 0.030672291233654947, 0.016499561212596395, 0.03177985327408439, 0.021113695373999018, 0.07007239236226005, 0.05679614609107376, 0.03831070877851979, 0.048965961417003025, 0.04520574141474021, 0.08711736604210832, 0.04246159914820906, 0.09556753801241999, 0.08063733472578949, 0.05284924578342227, 0.00403842339555042, 0.04353861534787763, 0.04233943876780329, 0.0197517998035877, 0.014272028422583977, 0.061995634628880414, 0.03562222663012724, 0.04636208601896802, 0.038663978733482866, 0.016531438131125707, 0.059730098132164254, 0.013375585849937654, 0.07464621306186722, 0.09246294371663563, 0.03599277186778284, 0.07365439733069751, 0.03557969725901081, 0.016112985585125226, 0.052678281771800214, 0.024074035313641353, 0.05213860347266159, 0.00652572846100215, 0.04094118657972544, 0.053802420039691275, 0.008663120473014011, 0.09163347733837944, 0.005935116327412788, 0.05712111292767429, 0.053562619197633, 0.01678912904143574, 0.017080610174865975, 0.034811288088319764, 0.006626585851453486, 0.04493220589093624, 0.03627785616704533, 0.04218476178545145, 0.0054728885598090155, 0.01704601364420547, 0.023367470505857663, 0.013976549267798904, 0.03820987245548637, 0.006686576760389032, 0.05857751118920504, 0.05248575238510967, 0.035309241408662456, 0.08576623209181332, 0.08753522103952785, 0.0290307276056058, 0.07703709686475416, 0.009174419044997663, 0.017742012184293523, 0.047864357625404676, 0.05443758353771222, 0.04488829373111648, 0.04726743723656382, 0.0380367748889952, 0.013667163701968328, 0.045585525672762625, 0.04313674860543782, 0.023573609444523053, 0.07202890431207996, 0.0287265274974127, 0.026085299567409584, 0.041923947151630156, 0.02977279292780065, 0.024580333246699265, 0.011268550071925407, 0.05205322680394015, 0.12058212436855802, 0.09527231836991926, 0.03170733922161162, 0.03916149538370871, 0.008051993941227275, 0.036060359974902485, 0.02808569111831246, 0.04726043902337552, 0.08297725835995329, 0.04492736421525479, 0.05417718259137004, 0.007340142647961095, 0.031389200143636234, 0.027789971603441144, 0.11844096224634879, 0.05713590608549215, 0.04591036610485566, 0.05268879249812134, 0.05013888799435189, 0.0659448791655802, 0.07273776546841668, 0.06120678240192994, 0.0562263222321147, 0.01942569724163942, 0.05410553804869133, 0.031154683393035686, 0.031935451477165186, 0.11685934308315478, 0.019653464757627057, 0.06916369717087477, 0.07232055398485354, 0.0010965233119467515, 0.13893988163721177, 0.2452738661198847, 0.1976323443194551, 0.1661809263450484, 0.1101706370771412, 0.10501851192525319, 0.11822179981297064, 0.1327509024450856, 0.11057775918274157, 0.16461351045197056, 0.14416507625531766, 0.09399019361984345, 0.10089171119034292, 0.14968138428465014, 0.11917925650073637, 0.12801647141215303, 0.17492067188985888, 0.145375280671062, 0.1368711224847263, 0.21176729471452777, 0.20880728419269287, 0.14758484678403025, 0.13914649555039021, 0.09539139141599018, 0.11678309435205114, 0.12925351188788492, 0.08825456993954797, 0.09665293904441981, 0.1599175753372331, 0.24319985160423865, 0.11152267501118684, 0.08094492668826735, 0.15016933632714136, 0.16110249885147618, 0.1699639757674548, 0.16282420485250412, 0.16167879615339542, 0.16570855653093708, 0.16449853597629457, 0.09429947097575474, 0.11449617634136831, 0.08815834929625835, 0.12828190555615773, 0.11187206473081343, 0.1550910069096473, 0.09366721861184606, 0.1202594174913341, 0.19391323259520918, 0.12868856800900352, 0.1903983445898179, 0.22400812336033393, 0.23120812410789154, 0.2244803399568604, 0.1392706630811576, 0.10607405084996455, 0.10733921441339678, 0.13288158172320935, 0.11237265722405528, 0.16283131414844146, 0.12941992150679713, 0.2390658419819609, 0.1805918216104469, 0.08895760116678092, 0.07241668269759224, 0.10723574657834346, 0.12561544460514862, 0.18840688370889236, 0.12553764837643794, 0.09859244384232069, 0.18933529034256938, 0.14029110751805768, 0.12063008147261797, 0.1759129702564209, 0.20775207468578893, 0.15718526146825285, 0.14749838610089597, 0.14236925890849483, 0.18896173054893173, 0.13234331302585142, 0.11492294860222649, 0.21689344948578268, 0.20670175281984193, 0.11999624330670604, 0.1444668842539672, 0.12046173365125734, 0.09840367977777797, 0.11162633436822123, 0.08623337718628107, 0.09845402707616169, 0.16622788753480683, 0.13388462064246978, 0.12248756123646615, 0.1642822540335117, 0.1510966397942074, 0.14153066842306045, 0.14659170572075153, 0.12587883329439548, 0.0891886686065024, 0.11422796129819848, 0.14727330946874234, 0.0942313657592862, 0.14022618922735416, 0.10630183177249086, 0.24594358018329068, 0.2045379681212287, 0.09803209649098497, 0.1570345413300299, 0.09469739236538449, 0.11044870401101728, 0.12241439983969736, 0.07680413718785971, 0.13394872687997358, 0.0944285950953922, 0.1507864967589417, 0.11102579804437776, 0.13041271016963069, 0.10646546049223793, 0.13225968686803696, 0.13474104565478143, 0.16019293798073647, 0.13752579058129943, 0.2671104669570923, 0.1626799504963621, 0.19484018366183006, 0.16262339788579172, 0.16583209586960657, 0.11181632417344278, 0.18184158680660112, 0.1071150724085108, 0.22720560581693727, 0.25620807052379657, 0.08331541723060994, 0.17051053353615347, 0.09300541057581864, 0.141019549881739, 0.1104121079908744, 0.19791530655516734, 0.15859175293195635, 0.10503642306092287, 0.18257438054969236, 0.15937728416775504, 0.10175549830760687, 0.15319579731552832, 0.25725299913075667, 0.27563068234632093, 0.20314131322647297, 0.1122605555780953, 0.13099311370282404, 0.26437133490558595, 0.10328853983552226, 0.09883530137519683, 0.09487067379297749, 0.19247762979038302, 0.12672973481277305, 0.21771204507639333, 0.09022730763160414, 0.19225382486418371, 0.16085874499572864, 0.16159494016920367, 0.14045056105861742, 0.14352275749608395, 0.14810060781817283, 0.12239443558839061, 0.157813805966608, 0.18355532549321654, 0.1367719907073244, 0.18629703160014846, 0.09852564863620267, 0.08650791245482622, 0.16826229530476755, 0.17609223483070252, 0.15578214079141617, 0.06640270097000946, 0.23848574488393723, 0.16385310690008825, 0.08348307557283871], [0.023163388513268966, 0.027933503921714523, 0.05719528556050313, 0.10820405107111701, 0.045356725853297024, 0.03819383440479156, 0.03281000979064453, 0.029823636268115336, 0.030758792136405266, 0.05848887864680541, 0.0599261706755046, 0.028782421272368203, 0.042148843753121557, 0.03431954008016375, 0.0903768326726652, 0.015402273368841458, 0.06339759085207217, 0.038345393409291585, 0.020831395804341284, 0.004491545250564213, 0.07693738286052981, 0.04831602391336234, 0.04244851819690197, 0.018891787584570628, 0.025040026220883575, 0.04729169541068616, 0.0569449701616841, 0.018637925198662187, 0.07613905029551638, 0.0781206746074942, 0.08693535887305776, 0.02483941843703149, 0.01388779798177101, 0.04552666330710054, 0.04093387427048818, 0.05848358114880901, 0.060477799946262, 0.05325115849113753, 0.06093309749098075, 0.05465585347865859, 0.040543724842850244, 0.10735024607950643, 0.01699125176415809, 0.045743845403194434, 0.01655464293435216, 0.05658249182987118, 0.012958728682039487, 0.052775954151706356, 0.050079087170982556, 0.03783018012801486, 0.01603234333977584, 0.06396876685621758, 0.05450787593520457, 0.04664564197282157, 0.01810158895809324, 0.027394765995502956, 0.01858084781786367, 0.03908263046234366, 0.07252426442479895, 0.02279192780054385, 0.007195611542556436, 0.0829415739844403, 0.02688649921647964, 0.06975547710974371, 0.058535667466780836, 0.07492644036368978, 0.03487591526561207, 0.06857762458704172, 0.050426695736185204, 0.04685219459896607, 0.006526302548140408, 0.025749486841021046, 0.022240767758640072, 0.0697411206220427, 0.04418295274879183, 0.057342677046695066, 0.06536170239410093, 0.022776000832598058, 0.11200520315117414, 0.03679689988794346, 0.07267983389958259, 0.010689600190568355, 0.018286930524834225, 0.011608217178182978, 0.01181381602486175, 0.03747130623988567, 0.04937040604530804, 0.021330052010354497, 0.02702253919485356, 0.021735979018792994, 0.0376626328685351, 0.021158212743278955, 0.047070556470463355, 0.033580491229170756, 0.04692082841610236, 0.015267260905895984, 0.06021457979635847, 0.012931044179675801, 0.04077553538785827, 0.026633638490532196, 0.008744845775166347, 0.051348717027013345, 0.0313593227145893, 0.0789113233106271, 0.032461497241691235, 0.030971691801002434, 0.026231379128031196, 0.054721671922673146, 0.046891858801245696, 0.051036022918959784, 0.05591028031983203, 0.022049071492567178, 0.050119425530635545, 0.02742657971177851, 0.017196532684348283, 0.014051138460936566, 0.0703738786039814, 0.07670587108981225, 0.08421871916300828, 0.025547080665766716, 0.0359158949445813, 0.020865352651585015, 0.07096620246527657, 0.039984158901197296, 0.06678962133704655, 0.09575781893105277, 0.016481895225062486, 0.07665943850072161, 0.06389968870808521, 0.048094559385771715, 0.034132637609277046, 0.04818377798543342, 0.03801565384492278, 0.054951356573691296, 0.06892832431701884, 0.018297946869185375, 0.04634796318808391, 0.01841515832160029, 0.07649777096606071, 0.033472767775698055, 0.08738437832723703, 0.0638022729676337, 0.043739391671073054, 0.011241945753534956, 0.05799414672618432, 0.035481381365248275, 0.00951472966511163, 0.033802231548414115, 0.08083969685098819, 0.029653417276999647, 0.048327676110690644, 0.023322960797456965, 0.02228061007636209, 0.025123072067095388, 0.022196717702993946, 0.09083283884871392, 0.041884788567380565, 0.01613151342157395, 0.08382620635412394, 0.05852259417635299, 0.0631995456323268, 0.0377679584668048, 0.03357933826684471, 0.029672948688629176, 0.024021562121267763, 0.042454076164792624, 0.039573110594984987, 0.012374040802129576, 0.03249730419127211, 0.022226934125947378, 0.031175758471832644, 0.06998672841056701, 0.04140123003913511, 0.09425182030686448, 0.03167858985703319, 0.09819309752915176, 0.041752412404504516, 0.04814598303768904, 0.06365090165467513, 0.10117518670496442, 0.01884352979100039, 0.07863451276094684, 0.023120119867305604, 0.033118724071931456, 0.06748874551586567, 0.05389656075426648, 0.03568425293891661, 0.04752002025563871, 0.12694116741899522, 0.02157427317973587, 0.06814539778016268, 0.03974322424901109, 0.06866989221664206, 0.0029271163821836276, 0.05961226231809105, 0.05315861506988445, 0.061860485227718476, 0.02523156543893199, 0.02111796248373726, 0.018416098694527344, 0.023133955415218108, 0.010622354907794826, 0.04409533910333149, 0.05703359887364411, 0.020288231805147185, 0.055088164555209304, 0.03603352008447532, 0.03430988737231782, 0.034898614450808496, 0.01349354806851836, 0.01528461854304037, 0.04142089934659101, 0.04355377239745952, 0.05028222304498477, 0.03790158335299742, 0.06013622432346306, 0.02865125744363233, 0.03055296729378883, 0.011131317869219328, 0.036442450157576994, 0.026165865203966538, 0.03411744991617818, 0.02741709362805611, 0.03662552984972154, 0.014792907881670663, 0.035722951870411634, 0.049029462445046634, 0.05955978912571746, 0.05666349796698459, 0.015686843431584777, 0.019337497538917007, 0.03189179978723968, 0.04589313678743859, 0.04443285446013174, 0.05648499948062724, 0.06806646774132406, 0.02981392610367508, 0.02369097219930301, 0.0315810879316902, 0.04495424624051779, 0.03224269103919787, 0.032337716585325624, 0.04449146784721844, 0.09296932783458503, 0.04178526608513729, 0.0021579854130264254, 0.028498202652460145, 0.032466059295280326, 0.01961709090298222, 0.044784745456831115, 0.0768263460767846, 0.027240366720023657, 0.010631248230985817, 0.07365407557376931, 0.03592589622243278, 0.05277927897329773, 0.01911366963007998, 0.020198588026687503, 0.05362439269740736, 0.05672512591005333, 0.05882680769108477, 0.037079023257378614, 0.03783318319267804, 0.05426848495018579, 0.045796854857115016, 0.03607349455236428, 0.05010402716335751, 0.02252996978049557, 0.02799749141559005, 0.06591796649680023, 0.0189760783236594, 0.016312164614998525, 0.02417751847045316, 0.06177326611753914, 0.06293868886366968, 0.03319128792011931, 0.0034209809476329436, 0.05219127967833512, 0.024324092157785932, 0.05568130813058346, 0.0357958413059673, 0.01627084374758265, 0.022264681193196488, 0.04532882876153435, 0.059203933624009934, 0.03672577245461364, 0.047324840204730156, 0.09867217061260054, 0.015145734463247563, 0.007802995734833062, 0.05993650137116352, 0.04441883122067779, 0.01652355700160467, 0.019691939608404235, 0.08495097664455253, 0.02965206513181329, 0.0425268238740823, 0.016394762299774636, 0.11578953194041407, 0.05945498063679665, 0.021942589101531816, 0.08696512138891606, 0.10116773266946116, 0.01374252760151942, 0.0499325881772224, 0.08204527409566988, 0.030911036789597526, 0.05312686455586264, 0.07877608580935387, 0.02816661681619383, 0.02272473805914483, 0.048324810941853834, 0.10621490377572276, 0.08228215614273664, 0.045316831824640115, 0.0369413381051873, 0.03449271808588698, 0.02787272442102192, 0.055063056023491014, 0.047778724317228606, 0.04093809924539059, 0.042366228862515384, 0.023615767262996207, 0.009190150660522764, 0.0789878171898665, 0.017523267268834096, 0.02033360910812213, 0.07044187656814052, 0.03623217434412049, 0.0859746769551308, 0.05736863976644893, 0.04263262444686505, 0.015275625628419222, 0.04318178691450627, 0.051187183557739185, 0.04427707431116893, 0.06220725492664403, 0.05719493699049758, 0.01625967227042683, 0.030832715790658712, 0.058166937857505784, 0.05928717290742263, 0.03827392506683546, 0.05918193923970384, 0.02297414372855377, 0.044557435678378235, 0.03056000381137335, 0.09393290556486576, 0.01407502987046516, 0.025045333294979027, 0.03532981853030863, 0.06871391162877122, 0.1883349480528024, 0.1361093246528218, 0.14343104144978908, 0.15241913737789278, 0.1897332423757161, 0.13520765448770217, 0.17786710733367553, 0.11226569602806723, 0.16722380183637145, 0.21529483849242811, 0.15858810635343676, 0.18019203096628192, 0.3419181560316394, 0.140132665213558, 0.13057216371019043, 0.15589475571628542, 0.24923958154695652, 0.1103821462921558, 0.11039451861213292, 0.16805966504879538, 0.23695001438740762, 0.09542744351370681, 0.0991919689301041, 0.099620878576271, 0.10339351686378641, 0.1739518464572968, 0.10932451594741115, 0.09599473928251574, 0.18969306872496683, 0.1851727822495084, 0.20467676793134984, 0.14648129712910424, 0.09792981609221428, 0.10904827230279485, 0.12012568152239246, 0.21107772365212443, 0.1565581725369538, 0.10619685474422672, 0.2210976327619245, 0.15550748294880315, 0.1668116771766255, 0.14602994876763514, 0.12244136613463202, 0.1742127300390313, 0.15010737513582553, 0.13163814441330973, 0.10955808083376578, 0.18882470806279492, 0.12130835273813818, 0.16135512400538693, 0.13672449325601901, 0.12037603905604732, 0.21566050758044567, 0.19490789051257795, 0.12141390433234554, 0.1693040523077211, 0.10631447222324149, 0.15042678783497504, 0.11808074004347287, 0.0964778496493255, 0.09336754799850526, 0.11114356108009817, 0.15869833108398224, 0.21796257114939152, 0.20231003121983623, 0.14494797214865685, 0.17251221402998895, 0.20898320862362463, 0.1505069972406472, 0.1934455665609529, 0.11714130174368621, 0.10744865007338025, 0.07423906797362913, 0.15535869335214939, 0.17641659645784288, 0.17828390512975956, 0.1952465320186269, 0.13868477435842638, 0.18151063682331195, 0.1515880085888409, 0.14720327371070463, 0.09671575059333155, 0.11043463863672749, 0.10078365448862316, 0.14252218537993971, 0.12818664252277345, 0.1171250836623292, 0.1519712210903245, 0.23171388003374302, 0.09460390665598455, 0.16426729999722975, 0.09349333963567212, 0.1526851077834445, 0.12155096512287857, 0.22763355785319883, 0.1683283933708745, 0.16190713632010645, 0.12602694873367587, 0.21044724861220007, 0.18423124486880918, 0.11035128827056578, 0.18461916115014784, 0.12703911176011448, 0.1867634259284504, 0.12899127999140372, 0.08241007750433299, 0.13994604619520326, 0.13341606594622135, 0.1768636394051775, 0.19513940228329552, 0.11801791317280262, 0.1906257807727783, 0.18458375256628762, 0.18327224068343642, 0.14987056203667196, 0.1002691191951594, 0.1499613281339407, 0.22100156533621976, 0.1552167679032972, 0.15800125235992094, 0.12503288070400878, 0.091393324095876, 0.1959852399604936, 0.16942835773431486, 0.15662960257501374, 0.14037781334932775, 0.25798317285314687, 0.15029428526759148, 0.15935394912958145, 0.28105213336886903, 0.1912178901294547, 0.1009453986320765, 0.15090571536171823, 0.1722661312669516, 0.16927892462380473, 0.10659861423435713, 0.2903281404606758, 0.19136632732566328, 0.26826254062114224, 0.18115745496846017, 0.17389782193687656, 0.14388721616518113, 0.07744546003279186, 0.16403649302740253, 0.15075280421203183, 0.13068583583639515, 0.11189291764411236, 0.1669227292821292, 0.31422465979572267, 0.12430531934144036, 0.1896448664727711, 0.19460692521064513, 0.08688837470066163, 0.13444414061884727, 0.21741730040840565, 0.18613575477032893, 0.10245504383478435, 0.17740570789863988, 0.15315818239844617, 0.14703367716602742, 0.19744233919247506, 0.1382043606211101, 0.1466578650738924, 0.14581613362796847, 0.16722945556525262, 0.20665080797287727, 0.20197278399380947, 0.14085458050812447, 0.1444292080498511, 0.1889323587379148, 0.20222292702284553, 0.15907276421785355, 0.10759691106936625, 0.18740048932452358, 0.09761966539606934, 0.141124427318573], [0.03543360812229014, 0.022137878319969582, 0.052647496528563, 0.0432130049974207, 0.022944308434342666, 0.10063619788495765, 0.03524665585568836, 0.05658087538435094, 0.06793364341701232, 0.032003750130834605, 0.05227461089229873, 0.029793822041322148, 0.022565317077321873, 0.07131892466737379, 0.046747033709600094, 0.02511312824583823, 0.024308345220502348, 0.03694781920902672, 0.0043967648525722325, 0.022863011183818022, 0.041224413115771553, 0.08717963366859383, 0.04901823159607668, 0.03192143781381029, 0.04346440058021296, 0.05150129875889228, 0.051622612612141724, 0.034673346296673825, 0.037241579454031684, 0.05958421583918314, 0.01817362420561333, 0.040515862225044164, 0.010374207537801517, 0.031092427257869034, 0.040904521611669374, 0.02503815505112852, 0.027608941196494048, 0.016287418059824456, 0.04052850650623441, 0.027997280741410873, 0.020782402566363736, 0.014984796627334531, 0.035443061647275766, 0.04269418344202061, 0.0066226486383276365, 0.0181904245137928, 0.012635701005497288, 0.01157663616111442, 0.041880375900936705, 0.035851133701902245, 0.06568864573754611, 0.03348957191431715, 0.11249599737986443, 0.019649908194438587, 0.02558197214027807, 0.1082937676279295, 0.0911550401079078, 0.05052275550101073, 0.06529247868926295, 0.04216667827999881, 0.054859219179038084, 0.026528772545017065, 0.10197513571549809, 0.06016545057777436, 0.061851985482198585, 0.039089299257724516, 0.02633308304563886, 0.022406277224241246, 0.027790302936468395, 0.014947761064245096, 0.00188656524950338, 0.00761041559481753, 0.031040365837754744, 0.04909250382033568, 0.03220991779779715, 0.019309278690226136, 0.051328185870642626, 0.007424241386263842, 0.01398822636298475, 0.021574405329902808, 0.07359795963331577, 0.01728984602396527, 0.03366758010440296, 0.04890276299368951, 0.02071570886689569, 0.04719797221402969, 0.0885428105210585, 0.013959177266505939, 0.034481391475926486, 0.02185542170228737, 0.1349046054266153, 0.009380860588393145, 0.0183829634765824, 0.03322821718850925, 0.07970461501709877, 0.037250730374287215, 0.027363519184291366, 0.028908078844148307, 0.05360362022334049, 0.0661796927752514, 0.0560873500522106, 0.017983249441209822, 0.044902742149368416, 0.04842820216811473, 0.031044763182440115, 0.04548750855329056, 0.02064977934013211, 0.009565453304188147, 0.07211453762025603, 0.03672988634676703, 0.04327290541222019, 0.05224669464833794, 0.056845688997136976, 0.0466078125511206, 0.05581850298650323, 0.07071460386918438, 0.04593431784380828, 0.033243266985781735, 0.04560120749257265, 0.02288758153876951, 0.049557408107624906, 0.03157607388622578, 0.131051198489243, 0.11098682715166962, 0.04460595968750216, 0.01385724160730118, 0.014213395883299172, 0.007055249870679672, 0.04940746171820549, 0.046926378723113775, 0.015260669676917455, 0.09533561255422332, 0.031206156840668093, 0.009541184596356847, 0.025558141060173515, 0.1033524392292865, 0.07702955855957924, 0.03996595665211639, 0.07907546530928343, 0.012535697803081525, 0.0017460358761919423, 0.04798580554404086, 0.05685158021327469, 0.021444128247939294, 0.021315080737094247, 0.02298698910782414, 0.06046456194693043, 0.0714824537956907, 0.021203534504879388, 0.037620222241046934, 0.0384192940809073, 0.05528513342142106, 0.05517678943672969, 0.05865200940940169, 0.015239213469378171, 0.05994006751045104, 0.0244202840727784, 0.021535137578124003, 0.026276394454461914, 0.015521980352669716, 0.03625998716621149, 0.018656004873675205, 0.05170745301931616, 0.04368208063345763, 0.04028070770624665, 0.03459618209050067, 0.027847981696287473, 0.15445736026571644, 0.0603310251608491, 0.07967297558582599, 0.030007347982797413, 0.03291128278379479, 0.018896416670853095, 0.04006245308705876, 0.02086880770812352, 0.011519633473888522, 0.04883589117877907, 0.035184702325251796, 0.010420967629479786, 0.04377144862026457, 0.10932239388386089, 0.0958208220019456, 0.05694492036596902, 0.015132170876548176, 0.0514115285759251, 0.052532211787277655, 0.044641900702469775, 0.02615617419172439, 0.01159668468209284, 0.07521524018938504, 0.03997851666363497, 0.03265488464685698, 0.04858633037656546, 0.07803710973671368, 0.014638926124110099, 0.06658543592258807, 0.038457575494483594, 0.05759507237422851, 0.008260389008829671, 0.047902233012381105, 0.042442952568132075, 0.044140423377675396, 0.04012111243942092, 0.048474186595769665, 0.0485275982458505, 0.0024352757252692698, 0.030715441135990045, 0.060807884250196724, 0.022119833118913156, 0.06741770618264714, 0.01638586418853412, 0.033627360488378236, 0.011450870379415012, 0.06375233169584986, 0.03406038402669853, 0.026003548409789804, 0.0555030586228015, 0.047676325174829656, 0.05399720172487921, 0.017274263795585405, 0.021769330656576543, 0.013172183760381756, 0.04085617763320765, 0.00859987321159532, 0.03850064495758664, 0.024105837538598046, 0.071018181530939, 0.04150359470757746, 0.05400109728197417, 0.05155615831515001, 0.04683974950063614, 0.17039139154216937, 0.021739378533956986, 0.028815010652667093, 0.03609555022370431, 0.00875102427427567, 0.04845950835114045, 0.012419971603629811, 0.035516008539425756, 0.0663402111780259, 0.06700895997064729, 0.06184162414302269, 0.03525615534594944, 0.006092209359555836, 0.01242134577384399, 0.04311563522224465, 0.0428013323295501, 0.021454932002891457, 0.03597456578826232, 0.004097331726487967, 0.07585105486214161, 0.01738815234162875, 0.05787579763320185, 0.012479410450454923, 0.06090097542431566, 0.05946394769595035, 0.06678537720994604, 0.03082640131094283, 0.022801283649319125, 0.037816777419779575, 0.032743375462990616, 0.031791043903438315, 0.020644142848229217, 0.03482979677257038, 0.04842283572220514, 0.025936165231189905, 0.0445737533511654, 0.015342509892258435, 0.0586262037376723, 0.016907271290678653, 0.06638538738292071, 0.04663854416820311, 0.020114130663475203, 0.023890241244507414, 0.05973323143177456, 0.024038919758412148, 0.039849308274325826, 0.028409646718852946, 0.041486660334011244, 0.1044301793820435, 0.03554056931827818, 0.008277200808328005, 0.06286664595527035, 0.02984465772075759, 0.0259574624754849, 0.08602609677660851, 0.020294868041791266, 0.03721335294446157, 0.04822198279021729, 0.05872614373783431, 0.040899365839938966, 0.08517628310308342, 0.017691132454802434, 0.03857552239130582, 0.0713324920845128, 0.05071359949426786, 0.01920923718341416, 0.04474409300112917, 0.05403442593712, 0.08941526209274608, 0.01787481161074773, 0.009900995984583372, 0.05908312538879053, 0.031206754389249032, 0.02603104905105166, 0.1744934706197631, 0.0611873199382136, 0.02905508728637811, 0.04664733885757385, 0.05246849242417563, 0.03649646318667839, 0.07943165022879839, 0.05818007243496757, 0.06097741184696075, 0.004102012044900368, 0.07955704350024462, 0.0613051366000887, 0.06611825252372412, 0.06109865292185738, 0.09571854926405415, 0.024560838224246137, 0.030839060913891565, 0.004740300224042468, 0.08523311150530655, 0.018803494036077492, 0.028865244953081976, 0.04912502808316101, 0.034699083020490025, 0.007813959889444373, 0.03266280599599404, 0.031863944830312844, 0.04582881221487638, 0.05098584415991941, 0.03189544636575926, 0.03857508189074936, 0.0851638418351931, 0.036922166754882184, 0.05943748701904571, 0.04702479037786684, 0.004394944436142161, 0.025489264010121266, 0.010504018263741127, 0.030155754535489028, 0.05455406720659906, 0.055472418936269904, 0.03489160857674095, 0.08357080796192731, 0.025049805333237016, 0.06497153381426489, 0.0320963682456603, 0.08576408704562534, 0.010201705604671471, 0.15996139556650193, 0.14285333454608917, 0.10775191363908591, 0.20439372908684517, 0.18787272124280854, 0.36132864834320166, 0.15315341733155713, 0.23259570852162378, 0.10797584880023234, 0.1386115057093482, 0.12956638219616107, 0.1074797455822268, 0.06037946873074097, 0.24776532194547116, 0.15723721755127754, 0.11472077033812962, 0.0860005937096092, 0.2827605707270484, 0.08931270590232265, 0.14740362102466245, 0.17349728052654576, 0.13902713905178732, 0.14079571431202276, 0.15023367239102242, 0.17679968638525856, 0.20108047542312454, 0.11076610189892593, 0.18090977874254027, 0.117539728751346, 0.12922121362099726, 0.12097776281617342, 0.12541207890476913, 0.15823376004494008, 0.14184068888425827, 0.0665191846388963, 0.12220857499708092, 0.1520573293730136, 0.14628885584252496, 0.10013331478882222, 0.11866595460883073, 0.13941916156440012, 0.16844373556875414, 0.22305146340400944, 0.13866001439671363, 0.10725976343476966, 0.16501708557048153, 0.11659858973636744, 0.13420748073727856, 0.1650236126395964, 0.13309325181668805, 0.1197088760654292, 0.09114777759438561, 0.1589171564386737, 0.07487833004204497, 0.09016700885108403, 0.2657082502640063, 0.1661256914057078, 0.10924271307885648, 0.1503632638242937, 0.14232698617683304, 0.09924410887423063, 0.1127664034344977, 0.22685515123509595, 0.16406581887314398, 0.28643215435647196, 0.17509530929307784, 0.06322351652347753, 0.09812093970756378, 0.0789323524241486, 0.16879995113178609, 0.11331908224571137, 0.10379948983750037, 0.13737203673489634, 0.11599629141029813, 0.1360196770439225, 0.08833212868100213, 0.19753894287972681, 0.15712861692713154, 0.07696425722491357, 0.19289793626916027, 0.16025849978529638, 0.2368545445102838, 0.07091020143801166, 0.19581740541804224, 0.12755953826971594, 0.14049554574153117, 0.18473373726010325, 0.17446163200563, 0.27876753660459674, 0.16865877644909968, 0.2473332330344185, 0.11867476461995995, 0.10030345525592567, 0.1133336379162727, 0.15920967945168096, 0.21275194752360546, 0.11164020055965071, 0.0896167508777111, 0.11376021865514979, 0.13135631598772543, 0.2440999129847173, 0.10645566222768639, 0.18041433436014961, 0.20410266164089405, 0.15662721238068997, 0.13587867090057942, 0.10796975840123431, 0.1798504936478792, 0.18721973853966883, 0.33637002470993227, 0.13754416136972367, 0.0795755828280122, 0.1406009441181537, 0.16122928640294462, 0.16265253987043135, 0.2179574996473328, 0.1099993244955136, 0.09867466805923371, 0.16457713659732573, 0.26143050722537503, 0.16121724350077493, 0.12750468637433746, 0.281551530764949, 0.20228478096185193, 0.07941224522167638, 0.10521849151700736, 0.2232966115397792, 0.09943869520699787, 0.12602342472922418, 0.24496338600593232, 0.19542948913670358, 0.1392982422464317, 0.1163062659062205, 0.20770520542658147, 0.15991869382560253, 0.30948426093785997, 0.16657356172800067, 0.15093291148303017, 0.1256207382727054, 0.14966597059561362, 0.15053857538488605, 0.15030891754694525, 0.1868462706765821, 0.12233667255889986, 0.12234674661510414, 0.189243053356486, 0.19915310545794426, 0.10865598932028779, 0.08654917395042797, 0.11841148318302248, 0.13925193989228818, 0.11781834726852757, 0.16758438410057178, 0.17521028376875386, 0.08634532561465617, 0.17223305159038113, 0.09398269361906475, 0.1319494978674958, 0.10341427018565517, 0.15553939817172868, 0.210478734825888, 0.13059893082226479, 0.16385097717565877, 0.24161775746653158, 0.09031392919320254, 0.09610502530009517, 0.14802747706492103, 0.252041885208699, 0.14177174097107303, 0.09197166685255305, 0.11258020576450134, 0.0985364121715388, 0.14097896254351064, 0.11160894417234006, 0.15725411745088716, 0.19510612342386477], [0.043547210854388056, 0.010665073885672517, 0.060833678430607246, 0.025997494399968176, 0.05186344767289777, 0.046258070431048834, 0.07123685366804562, 0.050053806269481305, 0.011496077227826801, 0.02075277794633181, 0.01638800348906267, 0.03825398762860606, 0.06145615168216248, 0.07552810283678194, 0.03650014040871494, 0.07067418507029934, 0.07152641958166515, 0.039616340936552134, 0.043946832959209724, 0.037294401216410825, 0.040840871196480534, 0.051728949446471474, 0.07285294678783225, 0.03030206200726811, 0.02504915607372119, 0.04759141581974203, 0.06121427474182941, 0.18084944165762395, 0.009694350470278052, 0.02903987661064152, 0.08685197786337907, 0.04712672220663198, 0.012301420454957314, 0.022795440313676675, 0.05076022360533957, 0.014265234180305515, 0.04674316496558247, 0.049151247442369504, 0.08663755751425221, 0.0849249143333685, 0.054314342973333214, 0.05336584568384194, 0.018687992874953537, 0.04485039536150233, 0.04492754041547737, 0.03030509380022845, 0.029541330952798168, 0.02469288496931474, 0.013496329925293404, 0.046734806946328575, 0.03128471532686344, 0.044717885133239536, 0.020620622033733996, 0.07223119748936546, 0.044034703244124694, 0.033469791524112225, 0.020113910413196972, 0.010227225908649065, 0.10714602236065174, 0.09376592138001034, 0.01537956748037569, 0.02866736444224033, 0.03356479025716263, 0.011620429577305915, 0.0035155056637801952, 0.04565258517921452, 0.02280171074333691, 0.026352878757602265, 0.069350048058456, 0.09396760168695643, 0.03368716131174757, 0.018574516101169492, 0.01689363301040665, 0.05129035644894166, 0.03521349573988588, 0.03664859675712163, 0.05139925967781775, 0.041459805121825594, 0.013421431424156314, 0.05191892776037416, 0.037695915558405464, 0.028070214227022185, 0.07924213539808989, 0.06259862243408157, 0.04555308567960897, 0.11379601028297218, 0.02036130510180468, 0.02515798269380485, 0.039773542178614486, 0.01738001074221346, 0.050289665589169155, 0.0253945219165255, 0.006225191210697015, 0.013430278782071847, 0.044089987979180394, 0.043159539721185164, 0.028000866032896504, 0.030859352667785944, 0.040190037369968436, 0.026275048054934993, 0.015251975536586778, 0.049921096858358195, 0.03247070561854109, 0.04582360664743089, 0.013498395489859245, 0.039450908079743385, 0.037822239626679695, 0.05347348869808259, 0.06477639589819216, 0.0526383685909452, 0.07466138926364722, 0.0019417384230051072, 0.060176524378719835, 0.07807417307049036, 0.05225289229964537, 0.021477623527208646, 0.041691274757707314, 0.0061893421262803104, 0.034355496416889855, 0.022949318649367462, 0.006141746998764575, 0.0673592996393, 0.05980053608636222, 0.06673166678557474, 0.07002838061101015, 0.021236604605350765, 0.026140256799877654, 0.029738864808854078, 0.0668129870187371, 0.04575743197253154, 0.013049102159247044, 0.009879215147286173, 0.07208289818898325, 0.06459949087471732, 0.04829065108131017, 0.022175219360618822, 0.020559325423692505, 0.0369349297797007, 0.04107801754388117, 0.07032012987521387, 0.03642658830710477, 0.02621115632205, 0.014415046504338183, 0.05455464943342152, 0.027391879759248228, 0.03314994981572513, 0.03976516117672286, 0.06860780079037913, 0.004965201134778439, 0.02712164032873848, 0.035491037903533834, 0.058034691929576866, 0.07917054448156588, 0.03698330823211901, 0.005460533476810182, 0.0285216755864601, 0.09795319709566333, 0.009434001234870766, 0.04835044424380026, 0.05226816043197628, 0.07469515841934951, 0.028885678433242346, 0.01501041460752247, 0.013574913309346284, 0.012335951868144256, 0.015612299246112666, 0.011458561902174787, 0.008693977536994123, 0.030978496576989853, 0.0309415290042037, 0.03554369495700925, 0.010916312420440298, 0.035446260064359636, 0.027595624673150243, 0.08139730160755497, 0.07309054895754784, 0.02296572633748574, 0.04581720981326315, 0.027480263323072466, 0.06021670952078797, 0.05357433268199525, 0.0664472030175309, 0.04182897523165711, 0.07198561268347888, 0.0037120246927389096, 0.021008999883047035, 0.02626501996400616, 0.031282700515622576, 0.04413977220293976, 0.09230493042137354, 0.04576118580336052, 0.07398287284999125, 0.052421630825847394, 0.02551207810850634, 0.014900138166042106, 0.06917575539480295, 0.02936957978583392, 0.04704641320952966, 0.03748106236960139, 0.0299259128364464, 0.04564229278795181, 0.05347230126179996, 0.029221449024795048, 0.05275589796984869, 0.03372180763812315, 0.011640991377193603, 0.07549408087206465, 0.05049096668259271, 0.05812600194927185, 0.023648919717919444, 0.032327270976478056, 0.05138882939072867, 0.05525233719738261, 0.02872229103119143, 0.043998796703113664, 0.04844225605108565, 0.09031982807021949, 0.04629375863700144, 0.05669359756152957, 0.06950010170018481, 0.03180351964528522, 0.08420584888588037, 0.0742142237422447, 0.006936951052217234, 0.0088072273572306, 0.032835872918968244, 0.01932192680185601, 0.008428742575849737, 0.06497260633735888, 0.10257495191669273, 0.06377883067715072, 0.030483668895378232, 0.07420974978876692, 0.034565266612316334, 0.06556449352853722, 0.04548982213882189, 0.008662656989819821, 0.08171601716669337, 0.0429837416947609, 0.03680806178900023, 0.03661353674326693, 0.10485010281685861, 0.023502221541298975, 0.0447180766552206, 0.03733120791073288, 0.03747343596431517, 0.052252064924687154, 0.0973949947905156, 0.05042540104759317, 0.03359271416200265, 0.031928430281339154, 0.024494782292975054, 0.08949797660593065, 0.03799507289283699, 0.010354817852437978, 0.07344216799303409, 0.049576418579465924, 0.07269364646485738, 0.01738895290350962, 0.010024072797668558, 0.03850287044300668, 0.06496222584598488, 0.05697911087002966, 0.038689435835206704, 0.0480507085129859, 0.040486176317978295, 0.023641300973512476, 0.0267851572754162, 0.036032830605343465, 0.03594384949293829, 0.01708428548168271, 0.02080762026561124, 0.043408759614272464, 0.030209474535959385, 0.0399775015971353, 0.0388586531663614, 0.054698869315606934, 0.057886273885566386, 0.019721742343878555, 0.011425102054471932, 0.04239704091882995, 0.049664618282188336, 0.012435666829978508, 0.03903907070296907, 0.07510764314041984, 0.03672338992116913, 0.02613301535377339, 0.021902241165779775, 0.038680909276609464, 0.054203574320361506, 0.012196811148896815, 0.06767064543260683, 0.03860814241512168, 0.0431135323108925, 0.022996940589960546, 0.10029622338592045, 0.06500581624887644, 0.06679660039803674, 0.012584739879164244, 0.04414436490004582, 0.04133298309640058, 0.004261202721541087, 0.06512639848815818, 0.042469202570857546, 0.07029333211962255, 0.035395135186732776, 0.06438312466226279, 0.018016392320034005, 0.025733770547254432, 0.09633722654994457, 0.01313113006612947, 0.05002591300815825, 0.014741265894694915, 0.039812922928362124, 0.03248054601792847, 0.04169720810868087, 0.024974345672695387, 0.06501405169406245, 0.02177560108623678, 0.02482165477328724, 0.02216094714258948, 0.03453074286000864, 0.016020015069854357, 0.033348581092732574, 0.09234894217262346, 0.04665692644794622, 0.01936522034567691, 0.015367146322293388, 0.04281550495614929, 0.05284480247346144, 0.038703727205434156, 0.060842354376349723, 0.03329157649028686, 0.04140040266417688, 0.027460214802094048, 0.05490436090997631, 0.013372372111095297, 0.027711146901692116, 0.013793775053214163, 0.02726517456223167, 0.033833698609903935, 0.016135244269765193, 0.020317820036002708, 0.016885010690818873, 0.015503027337423016, 0.04179260903789152, 0.02919556674427323, 0.07654392010261936, 0.0615763355557236, 0.024042328849675196, 0.03426887102485184, 0.010917454849057382, 0.17338569215949506, 0.16146424556932143, 0.15331516913588972, 0.15021933122507988, 0.11819982841130226, 0.1119133645308114, 0.14120238442574778, 0.16093431190857965, 0.1866789111086438, 0.1668598181417873, 0.12802809296596435, 0.09831760979948506, 0.15846422993608061, 0.2545607669819748, 0.19139422824786556, 0.13181540183722973, 0.0921438834179313, 0.11832923598347173, 0.14031168463970387, 0.1644524940920453, 0.17313441532033105, 0.11340467724949123, 0.19128912098465428, 0.11907750470263344, 0.14607718574904627, 0.1778967242928282, 0.19979782973326024, 0.25567255974296604, 0.09680773477039992, 0.11864039025479749, 0.25957436811539436, 0.2149229640922239, 0.13085904831607498, 0.11680637576407003, 0.16710940958751788, 0.1345065154976422, 0.14878296233232946, 0.09595180005435983, 0.1783729858335949, 0.17900963554218893, 0.17660991108465582, 0.13729544326422677, 0.1640763142777066, 0.19794565895872732, 0.1338727922449189, 0.1334260097674785, 0.17981830263330092, 0.11162795081374147, 0.11352840811014177, 0.17655361894397967, 0.16393109465078, 0.14337667985068214, 0.1382443810542745, 0.17328265333367934, 0.1350029557943344, 0.22757571821491565, 0.1623995163508, 0.1316652026387953, 0.21223845410971873, 0.19974429550911152, 0.13144977871448765, 0.11389698067139234, 0.19757355473214583, 0.193116455188682, 0.10249817458492133, 0.14462350326920712, 0.11049589502715296, 0.14165341103028867, 0.1839951825358214, 0.11959840618674794, 0.14959844760596752, 0.22681585092458034, 0.14276906487441834, 0.2182801912027982, 0.21389150331097267, 0.13458810386157807, 0.16822166200126373, 0.13051228627802866, 0.115699102921832, 0.13259344073312898, 0.17272845000749634, 0.16702445043671518, 0.17380924685107124, 0.12603094771264062, 0.16470374028769233, 0.21475785682278298, 0.11057733783438323, 0.1132495750883414, 0.19228175642990297, 0.10531671164977936, 0.11702337016862248, 0.16681909290773256, 0.1073276005204647, 0.08482539951200448, 0.19762315126436372, 0.1414187276555646, 0.11848352609142182, 0.10351255926634036, 0.21347757068372544, 0.05779276136308909, 0.14709027574187325, 0.11887354911455225, 0.16416176372478086, 0.10941727387328302, 0.11225457243140667, 0.1493039787296326, 0.1010252786199412, 0.09263633239653804, 0.2431028955165417, 0.1232024055394915, 0.17665959954742463, 0.10510023052413618, 0.1654304206491478, 0.14705491312328847, 0.3123010436613714, 0.12876617271573315, 0.15327510273744985, 0.1285132564484112, 0.18873620958578205, 0.16385056348817964, 0.17582488546688713, 0.15260477580370443, 0.15152800858261126, 0.11955542099331656, 0.18749992753709518, 0.13448485053114353, 0.11179690384456228, 0.1210835135932411, 0.19752280906804148, 0.18181426811122126, 0.09286433548456238, 0.13219605560504621, 0.1164080866522366, 0.1662948742629059, 0.11309250408122618, 0.12084854676598504, 0.20250863185332668, 0.1468522828673163, 0.07143385317777434, 0.1537943111672517, 0.15603029199184912, 0.18651679158210757, 0.11190515972914235, 0.13856633716533262, 0.10047790879804282, 0.14826891733513725, 0.15491457686068552, 0.15595256471105162, 0.15785515939276065, 0.13731442692299045, 0.14019220556703307, 0.10918560122410137, 0.16768434325293188, 0.12549584295840996, 0.1682852319772205, 0.15295372885321418, 0.22985338954435242, 0.1616815847134398, 0.1826788596208057, 0.1498861595868103, 0.1115799400835268, 0.12082787005290871, 0.08475493474472916, 0.11506003237539723, 0.12155531650228847, 0.04878029617811403, 0.13683416640325902, 0.13365882388766737, 0.1815373273265939, 0.1395387632111388, 0.09321056126106171, 0.22598371089946842, 0.140932277145405, 0.15180684926529087, 0.16909471112153224, 0.08419315480897505], [0.01374603724182253, 0.040437020286316835, 0.06057076471587343, 0.049209320737469586, 0.023181224955366026, 0.05106514958184093, 0.046737538049778635, 0.03381258905715039, 0.01250798648764049, 0.06167609169478379, 0.04831157677296189, 0.057293781484927864, 0.028431330837549704, 0.07545766871302359, 0.06775707547222415, 0.022555758215246663, 0.03944875537267616, 0.015337618420861903, 0.06926082179791505, 0.03737230086699128, 0.10806569559199196, 0.06752420006500137, 0.059768211006397204, 0.0608221258247091, 0.062246857841889706, 0.03474397577285286, 0.08857787436535282, 0.015119776531543224, 0.04797516075233298, 0.015313389932646628, 0.0404947143678944, 0.029226340496191577, 0.09504304357594061, 0.02467312947696736, 0.003059832735978548, 0.06173724083289985, 0.035753545591667775, 0.04999712725440341, 0.04234132334409703, 0.03753644286564762, 0.028128404350530718, 0.02038362124303897, 0.05456198089485688, 0.05403698084034747, 0.04149321038576384, 0.03414820451589842, 0.011051298070308423, 0.07419164713111616, 0.01854031985144942, 0.010938214874195476, 0.02403742205652018, 0.056955726036141, 0.04749258281663061, 0.06359364807365403, 0.03560816891671669, 0.03551120899858014, 0.04814034463056634, 0.04713647450590807, 0.016160906300008777, 0.004835646090683558, 0.021069854077312256, 0.08995610484552961, 0.059105100620898514, 0.022890921682119373, 0.01816416685018809, 0.0724590550206842, 0.04572882241899929, 0.0036733597563955215, 0.02605661148986509, 0.0288700636461257, 0.011642821369722728, 0.05017241583235803, 0.02262088718012937, 0.052585389780541586, 0.032401489574582346, 0.11823465476834005, 0.014824994516769245, 0.027638489207733544, 0.05611576808376178, 0.03426533169864166, 0.09435065330997591, 0.03228593287208388, 0.017296520565005562, 0.021676584222023527, 0.030287912363306652, 0.025765873461721406, 0.022578645091984543, 0.04744758281195837, 0.04227183150848554, 0.050539513674354365, 0.05020479070803812, 0.011167438914849153, 0.017435059905232444, 0.04708715759578252, 0.07146074286391658, 0.022196851768380692, 0.04604598281965141, 0.08550167894892155, 0.10068869022952934, 0.04105755916586326, 0.067772941153136, 0.021579361918772903, 0.014482822302999276, 0.02840326903688331, 0.0068945016415279, 0.05398522010974346, 0.03691075970568965, 0.019238936497018706, 0.03931998365348385, 0.03342910076401407, 0.0204422940019398, 0.03391976475775723, 0.04049095287618618, 0.07258444063125119, 0.04348596978572108, 0.034661475764287096, 0.04383390776873116, 0.03836868248218971, 0.0682567946252323, 0.03170302806181773, 0.023197904604697422, 0.030586950954109914, 0.012273130743133446, 0.0996049516083252, 0.024632262516646616, 0.024953743653191675, 0.0629755798276634, 0.03314074909975452, 0.08004856551246298, 0.020642622163699522, 0.047255953578578855, 0.01648572374946408, 0.014645694510921117, 0.0230628835232628, 0.04511869467434384, 0.04957831847751814, 0.05840520269327587, 0.08288325937164408, 0.043484881940868594, 0.009848502682401769, 0.03919290498860421, 0.07202914946021573, 0.05717211140079364, 0.06906686365724572, 0.08062234238511132, 0.038438909762208505, 0.047634895139884566, 0.10452793986206094, 0.008531255673827424, 0.1346152233740976, 0.08779792791052211, 0.039065987202188665, 0.06794195547099076, 0.03234812005933735, 0.03878183753019379, 0.06248327640576228, 0.016319720157151742, 0.021062972692532406, 0.03570371157219333, 0.02991152187478879, 0.06859824767396336, 0.04524206930410959, 0.016357116739175493, 0.06705695537910347, 0.01977628014320808, 0.030625136606695674, 0.013009635224607925, 0.02417830754101517, 0.056904084049165256, 0.0353229773651448, 0.06349340546876192, 0.03470249977263232, 0.040905540508608666, 0.03633965264945742, 0.03443332711955713, 0.045479100738321586, 0.03958117750082766, 0.03858134848996997, 0.11296906433398686, 0.021626451428258614, 0.009593540960321984, 0.03402951068335003, 0.027106651818499933, 0.027746218406865676, 0.054527012811553095, 0.045288314201658776, 0.04850528210461621, 0.028913182904943827, 0.029225097518534433, 0.05040775804269699, 0.015809145538256537, 0.0189382795454754, 0.05473504015695184, 0.07419749238197842, 0.108058724191881, 0.040396869618205294, 0.06269868883875108, 0.030273881462973454, 0.026394285809909625, 0.03451472396151193, 0.006790941875923666, 0.030499111312711914, 0.02339783440073652, 0.015881736199521733, 0.0226623248759537, 0.00824862668636225, 0.0227894131169324, 0.03443765551632932, 0.07055817637592554, 0.03843067431702249, 0.03834704432876841, 0.07055506605895297, 0.031121172792007847, 0.04322983594911714, 0.04234313514203795, 0.062375422717342456, 0.01536062308361814, 0.032161876424065525, 0.08888545100607219, 0.019756773629436092, 0.042974410743843165, 0.029451928492034637, 0.010784174702430685, 0.03345590618048464, 0.019724728171563437, 0.019182998672007553, 0.040128482205252496, 0.02519278223776529, 0.0170372495983517, 0.00859533414064396, 0.056014763221385024, 0.010266979168649885, 0.03437508528511371, 0.008085597430415934, 0.03014671852842214, 0.005391057920567091, 0.008553852394763983, 0.024957508975339514, 0.0307654379491484, 0.041923395568324674, 0.08844795351427409, 0.030563351615602453, 0.041283091620331815, 0.0583762675523758, 0.04801411249284302, 0.06297122078737424, 0.04149897136695443, 0.04957144283839772, 0.008779711394210257, 0.030056839177925742, 0.028920675244843288, 0.06030723430036057, 0.024997284260368156, 0.06512796130752371, 0.05214709938774186, 0.06222982770733296, 0.02677673988434817, 0.013333171392009865, 0.007685150344660807, 0.03382756607607007, 0.045240108119023424, 0.01799537278261156, 0.03670093588410847, 0.03683086822650606, 0.07466084534122099, 0.1068637955693468, 0.02820515295400495, 0.04770999090866216, 0.04272018063573107, 0.018726061699130846, 0.06449734071089376, 0.07550430048497454, 0.054650850924513036, 0.069040747719907, 0.07006309205485929, 0.0573314423672855, 0.03804376544130426, 0.07486721410626367, 0.03784934764788036, 0.03566048889150543, 0.052562399481933926, 0.0656667892490664, 0.04726181798163922, 0.04522798094718207, 0.04483616527830882, 0.016858402541988803, 0.04040477564558387, 0.04317217634149617, 0.056451927464936054, 0.071282772978227, 0.03309150879842139, 0.04752071739564981, 0.06757610252187138, 0.052902013919646704, 0.08733122714705045, 0.06546255020845322, 0.03764261499107365, 0.024526875631342974, 0.0887427211648995, 0.04523702844556782, 0.055860611009261305, 0.022845117285126643, 0.059047552096026565, 0.06255799296101736, 0.0092529229474284, 0.06305723330907284, 0.023986440820379124, 0.021517958056422013, 0.07432594234424253, 0.033775376336228465, 0.02060143153123077, 0.09823330948429723, 0.031828180015567815, 0.035022012063211976, 0.050621653621595715, 0.03334352874287194, 0.048494560704115904, 0.10422150469234875, 0.07704025314700219, 0.022567431479992888, 0.028774423314438715, 0.020462532129679478, 0.053847910340635054, 0.027883279197398695, 0.03631884953187358, 0.0738766241157728, 0.09951417785017722, 0.010522424483731871, 0.03318959869624626, 0.03013153083532328, 0.00880314123576447, 0.12173886350806683, 0.04849818429999775, 0.033305243498856024, 0.03891377319251338, 0.020629612075525428, 0.03140062826024669, 0.032846023583964955, 0.10532224280459267, 0.03870083522352, 0.022098388402692737, 0.03734672502163918, 0.021783340489491824, 0.0480553433449278, 0.07288225731181522, 0.017172217053631623, 0.05566507855790758, 0.050153761591401794, 0.018783453175978317, 0.03442154085684208, 0.014586553480776568, 0.05322466717071591, 0.17772034020914187, 0.12450948943414035, 0.26286830104166464, 0.18996424852840363, 0.133544217134195, 0.11833750207217471, 0.09489380964829076, 0.0938079183200194, 0.13886721053671452, 0.1399442229059435, 0.04940419818364805, 0.15488920402863335, 0.08244167097033032, 0.1551732081439226, 0.09043330101356392, 0.16673647798597815, 0.08251507751523487, 0.11985062531405881, 0.22236541634605778, 0.15687147185446756, 0.1871519550801285, 0.13400701084925284, 0.11983321979641916, 0.10224129764303085, 0.1906124968081713, 0.153262171173288, 0.10779791721893896, 0.17602451265819613, 0.10729386966915862, 0.1304674088474243, 0.1447823592611859, 0.14490804364604337, 0.2107707828643822, 0.13844596943066967, 0.06302788065025403, 0.14802375387760902, 0.14105953967138646, 0.1271295714222135, 0.09737101623848562, 0.2138509006509858, 0.112021321641101, 0.10009911662388234, 0.16190295348003989, 0.13161597382878104, 0.1334014336668676, 0.1449593408934532, 0.07252493092129308, 0.2838562296763543, 0.10251616232938345, 0.13600918163935985, 0.15523244206222797, 0.14767728295297394, 0.2195808399588831, 0.1948835595601028, 0.13631647482754725, 0.08902774417712804, 0.12275576861875674, 0.1056703684791442, 0.1591703484976484, 0.07894263332409245, 0.20244757464576155, 0.19928672651369728, 0.15909645165647232, 0.10851002658807463, 0.09523393736491281, 0.1890165977660687, 0.1754633379319022, 0.11873485655674051, 0.1355353409364339, 0.1648245983186268, 0.10881842294287299, 0.18198921194960996, 0.11544175100542846, 0.1884713576685998, 0.20810801445716814, 0.18435872189940947, 0.20731401028892688, 0.08902461853839698, 0.20469926027280672, 0.1331182416047781, 0.19947411161997627, 0.12223884313096925, 0.11120193697992833, 0.1232294867476148, 0.06962859762772437, 0.08716714643542806, 0.13919345674014863, 0.19139200659288516, 0.08843310673030154, 0.20134548055789164, 0.3284288492173918, 0.10655312393341335, 0.10265022005525329, 0.18049734764762465, 0.20350206403001664, 0.17160591669380668, 0.15022385114383313, 0.17133547233477717, 0.15919357628351258, 0.13074715351385455, 0.14493573006362687, 0.1716045837008184, 0.08017921414706977, 0.12217943301244129, 0.21195052762425717, 0.19371060233923698, 0.19342931017519968, 0.10808867056884112, 0.11045821882303684, 0.0654282907564794, 0.1700048695408529, 0.11392878098112923, 0.114049868838441, 0.21142946526167855, 0.1346800497342502, 0.1839667453520721, 0.13976722595191773, 0.15911876013682735, 0.1344610405184569, 0.21375849512555908, 0.08701277971868554, 0.10438671155321984, 0.11813736926283568, 0.1889117203292347, 0.10737174250666173, 0.16128962348786094, 0.15770037898853903, 0.10286805715652243, 0.21406689148035743, 0.16017839763193362, 0.12820633098242745, 0.18853036176052787, 0.14319645000561593, 0.0693908192577862, 0.22267920595984306, 0.16959890422801818, 0.12309329929731547, 0.136407210281299, 0.1986639429965327, 0.09958317172863793, 0.10747898715518175, 0.199140633546537, 0.1900189012409218, 0.14305421812159402, 0.17345033465854584, 0.12450980353018931, 0.16172505254226346, 0.1909714090006967, 0.1503428399202324, 0.19318826827070407, 0.17443851147207523, 0.11152252179360199, 0.27750912993665666, 0.1551497811751981, 0.1066707184297904, 0.13282711287179302, 0.23639450871175338, 0.09284155969057353, 0.19640226758295493, 0.08843849998928847, 0.25304374435255605, 0.17661904285271324, 0.1936260568759134, 0.12346330444298445, 0.06987023708080092, 0.12767687229619873, 0.05657894484278175, 0.10432021512139229, 0.15823333103570247, 0.16695452193098684, 0.12188553104117034, 0.13344603530581922, 0.06711799726491013, 0.10764512098244122, 0.08824851784494617, 0.22239146333548332], [0.02621271148053629, 0.06302706093617505, 0.04375059187652604, 0.005025163315416825, 0.009004659706636543, 0.030633992583100355, 0.056564412154858155, 0.021235620182368065, 0.0075781972883569625, 0.04126405816585307, 0.053918007385706714, 0.006607154510059064, 0.08062772798321902, 0.10939570849821453, 0.011824683939677574, 0.01369090668196159, 0.012917469101657551, 0.02625947348743437, 0.03520422990644171, 0.07244631497850341, 0.04095432881806647, 0.04246344542010658, 0.01627683838559014, 0.05989572251095407, 0.010585957112902356, 0.03674176837047262, 0.0464301644223592, 0.032404944631120855, 0.054576145860576825, 0.01865094294771552, 0.026847698778334646, 0.07442496686933503, 0.025481551419943575, 0.02326793078663609, 0.04865846904595533, 0.02233794601183505, 0.026654035581516165, 0.059586977586150176, 0.09654516579523202, 0.044430939240321043, 0.07206003812532272, 0.040822013942224365, 0.012693826969142162, 0.028817603860290784, 0.010293807567758186, 0.07516128461687796, 0.07206209890183903, 0.0551513246741266, 0.05384124920613343, 0.023390836187548215, 0.03896863657921072, 0.05427654419514922, 0.011038255423397548, 0.058226439906584646, 0.052455396151110056, 0.00781808670933148, 0.04574048227720684, 0.06873071193695068, 0.007738696538933343, 0.012664871718434077, 0.03688307711854577, 0.06887711900015993, 0.0319330919263584, 0.048409260644186894, 0.10229937476857055, 0.07493164976157489, 0.049805792964874744, 0.05143286795505593, 0.038114835418039755, 0.09822105973838799, 0.027941212681452596, 0.043673760918599945, 0.024629223062807036, 0.018194231970776475, 0.10704570314696721, 0.046072968266784184, 0.03325207699691096, 0.05193942061234867, 0.03233849799500839, 0.03655714118072102, 0.005644635896333644, 0.02961456512791976, 0.054404683891803994, 0.09189812241182213, 0.02820040512409422, 0.10593701304206926, 0.026840459247450196, 0.025842599082557906, 0.11183221283699236, 0.06141061158550363, 0.022742170389861833, 0.012906492976922423, 0.04882541492641453, 0.05565244959847582, 0.04271712011447357, 0.0384463369846344, 0.02606113906949759, 0.05848369989243727, 0.01564582516889899, 0.06273033593090312, 0.048434143179967526, 0.023042042101282748, 0.04756616173131813, 0.044049733889199076, 0.00410757863128017, 0.0305181160388935, 0.05065458774146053, 0.02999075643357731, 0.012371141159336173, 0.09187489462595794, 0.01991832816612817, 0.10674679096067145, 0.09489129687989913, 0.028274788431102232, 0.03395869351562954, 0.03398611946331878, 0.09561456815009156, 0.01731266395278996, 0.04989339894945583, 0.016989551048966187, 0.09960605477493617, 0.029681963628278147, 0.01742090068517193, 0.04893717566324819, 0.01600708159047269, 0.008944027677869365, 0.05168300332321275, 0.008002214984322388, 0.033374873230293874, 0.09667555395994457, 0.06390694356072815, 0.024916793317383817, 0.020995528226898565, 0.03242071838148179, 0.08469848172558893, 0.01460021282846649, 0.04941935523322994, 0.013592237430143983, 0.02075081293080603, 0.049562517914079854, 0.04171593129755028, 0.046772452506927714, 0.026297061591439193, 0.028083674391851794, 0.04480772043368028, 0.07337378698491281, 0.055222743220867655, 0.038157008558271394, 0.07833635134081687, 0.03068764938131696, 0.009252438396816293, 0.0435129628937331, 0.07920160934689545, 0.04385220960924222, 0.015553388999955309, 0.042120464025966586, 0.05095953287016, 0.04649515549141554, 0.012624808192823925, 0.06904555875207148, 0.03977824978890919, 0.04293986017845812, 0.013246460772690274, 0.036763065614767616, 0.06540557624952448, 0.020624875736933564, 0.047697400253626614, 0.024116440195470087, 0.030029602836997762, 0.07472282951517452, 0.02955881882488968, 0.02277980445914211, 0.003098068902486815, 0.031649007371837096, 0.040764944222305095, 0.0584017706193751, 0.006330469886081354, 0.02287930204352785, 0.04901431305634399, 0.016214647367897055, 0.05517300496238375, 0.055712215947888555, 0.004208025207082111, 0.05017105219585281, 0.06245827895679301, 0.06874067107996634, 0.02913151030248452, 0.03869333905318091, 0.09885917267491741, 0.04774940230192677, 0.07657735984051421, 0.07364765575696385, 0.04796807443903339, 0.0345364272324068, 0.05900570454316274, 0.09731457088022463, 0.047275331772623524, 0.06748498402415745, 0.017675234215153802, 0.09174229246714423, 0.01310258563007078, 0.050901011413624214, 0.037346594786692056, 0.04791185890714969, 0.03971284886281337, 0.014399293821395166, 0.04068822817756765, 0.026226340184709238, 0.028851315559398745, 0.08813137534044443, 0.056778054924741875, 0.018553496563747045, 0.009072062995044455, 0.021104816414956606, 0.03165136500742407, 0.014116647596951696, 0.08791079564440636, 0.01848208950832486, 0.0411009312336964, 0.04403282632871021, 0.03554001007409346, 0.019528157671072313, 0.0814246203029348, 0.0262733492549629, 0.03998228581622243, 0.061327395284728664, 0.06952038004754052, 0.0532168798869656, 0.033694109729220795, 0.048463472856148604, 0.02908210720746748, 0.047977838229628346, 0.07097109776711272, 0.051233068393963965, 0.010645103888706335, 0.024965579711621808, 0.020221327431499958, 0.03462574542349866, 0.016344955093377543, 0.005055690003979591, 0.1044918341381896, 0.0566244121610878, 0.06380199334554135, 0.06267884716151223, 0.0692038095345901, 0.04993518904572533, 0.04809848558638365, 0.04565237450503534, 0.027861447606776512, 0.031183172287719867, 0.0347563136188734, 0.02482903411521787, 0.057980962353007454, 0.02230391255579889, 0.03567253179367512, 0.036187151356810526, 0.08908078810500522, 0.020841803108792634, 0.08051033266970227, 0.04797604175344591, 0.045956492258776585, 0.0389994524659649, 0.08303661485232654, 0.034447070736918724, 0.05107945244338724, 0.035650024130459756, 0.019796476136111928, 0.0476125292029352, 0.017188230206468896, 0.029697499891382553, 0.03228475309668049, 0.10921199295309283, 0.030015208044900533, 0.05559915669202324, 0.03172019034654143, 0.048680118690695495, 0.0737732865156666, 0.042709210256655375, 0.04775417886013466, 0.026368801895108436, 0.07527249760084576, 0.01726453830938666, 0.02209676621151307, 0.05216479984923236, 0.06251950853414114, 0.0638314455957903, 0.02728172589183575, 0.05080764061741291, 0.015279459898480246, 0.09212074756261804, 0.11757838554800519, 0.016732928831310525, 0.05533426264000516, 0.0387583760875127, 0.0036699317523368425, 0.011364255521085956, 0.07975191328554385, 0.06335237634278114, 0.016009416243421937, 0.0371129724437431, 0.08764920726178155, 0.006322173632666349, 0.02225365335752647, 0.026229793326027935, 0.023412711828226046, 0.07499912678594552, 0.06205282692286757, 0.03666789834237388, 0.015152804497178766, 0.07422644284463699, 0.023822074741004937, 0.026116230367352406, 0.08503693937053604, 0.04558595085156061, 0.06818717255467369, 0.011120898115839209, 0.01581011272426094, 0.04071022256187374, 0.0542259632399486, 0.03965046249269959, 0.015476061042488344, 0.0709537152321108, 0.041393917729897846, 0.06465513184065781, 0.06363291391021302, 0.01567163275584819, 0.04360613450708409, 0.042070285266926216, 0.025396147938144785, 0.033752604372679226, 0.10371201025742678, 0.03385447108397081, 0.05830074660480023, 0.03328219574365405, 0.12990762840115255, 0.012916709717002609, 0.13719215929027528, 0.038601626837325674, 0.027030257530690684, 0.013699658278886591, 0.0989455950536555, 0.0461724256315539, 0.020560143222551674, 0.07031373304104613, 0.06437335704122821, 0.04122306480102482, 0.031665123946544145, 0.036611989245659886, 0.03436931664304387, 0.027507160670093955, 0.034268388389459545, 0.048689491776449066, 0.05581857959529566, 0.11407804555229603, 0.1572034177520583, 0.10950297612937228, 0.16003817289827332, 0.14029702171683311, 0.06530792302181644, 0.09643377661104165, 0.10415935963993112, 0.0922452368503136, 0.11734509645330331, 0.14692492332429657, 0.15577152281278567, 0.3089222894801248, 0.14036895737292307, 0.1200318357516681, 0.20356981684604, 0.1266091142690951, 0.1663513196211669, 0.15589457185518357, 0.12629551617729087, 0.13376253687085646, 0.11643777255930247, 0.2930838200113466, 0.09275238705618728, 0.1736808964802373, 0.18280172480210183, 0.08676265201140797, 0.1804848297709419, 0.09801429260762469, 0.10517631837677573, 0.16278606899563344, 0.11335305058427396, 0.157348545448434, 0.16046223320787953, 0.08901439126460783, 0.12964496749543375, 0.21929513512840196, 0.19464558200730434, 0.12164180782893974, 0.2119285562225888, 0.13592828275455585, 0.1743184654943405, 0.1922533192461537, 0.06649551252203603, 0.21708897044581754, 0.2739656055646558, 0.12050284192927423, 0.1673114729384261, 0.18900340573201257, 0.16930538530070938, 0.1390271850170628, 0.11140604578559438, 0.16950522699663717, 0.12779462767103988, 0.15421628771770388, 0.1322465407992563, 0.28237124484392906, 0.09972360330603777, 0.12411128459197861, 0.15646682421286262, 0.2344978129070613, 0.06942078095650481, 0.296748110483731, 0.24371571989069063, 0.1410702495805679, 0.2476676610568839, 0.1640062938414274, 0.21238721306285552, 0.16482070659197148, 0.07923877993298155, 0.1246305543088144, 0.11107711061354607, 0.14838646586623885, 0.28721708804368973, 0.15684580790900415, 0.10257205610433895, 0.12664836095345597, 0.1676385465168184, 0.14822002560380967, 0.2249819130426453, 0.11860528810610695, 0.10742434210354283, 0.08874901840763708, 0.1319378686528052, 0.2564412217226721, 0.14713040342734707, 0.13732570373723585, 0.213852294931008, 0.15479361157744162, 0.09666026284497592, 0.10400804195312724, 0.11036296345053181, 0.08920024419503828, 0.09523601346318761, 0.16072559891448868, 0.11650809176987219, 0.1781467141042794, 0.16579682518157268, 0.1602479430936998, 0.20209842241339146, 0.2047188721236683, 0.19807803895204298, 0.1637683162886289, 0.12799995455650554, 0.08916133458936408, 0.13067178578386385, 0.15913261100649834, 0.16091781037469066, 0.20658694688350926, 0.1522585806707221, 0.28670282854187873, 0.23627464659512046, 0.1729567901742074, 0.17669111640462953, 0.09794572007752235, 0.17718620838657503, 0.1344314388810627, 0.18081312909001307, 0.1009864379621802, 0.17673859853417645, 0.1399081248429514, 0.12193927976993785, 0.11006681684164271, 0.15841950572306113, 0.09278461637516176, 0.09928625903182453, 0.10524509775061762, 0.11414131675396236, 0.20490729910952432, 0.19481208355676746, 0.11909017579690104, 0.2047015891800965, 0.14388451953568768, 0.208622963438111, 0.14344789538412325, 0.21217555829113532, 0.10562799615605224, 0.13865788467228413, 0.07686368520221404, 0.10846888000566153, 0.10193913724393615, 0.13569412031962028, 0.107900082704521, 0.13500179134068951, 0.19153249179643972, 0.24547502548704225, 0.13365929886218042, 0.2036229680262266, 0.09533844707954316, 0.12241092946140036, 0.11694524452210435, 0.13273806281147466, 0.11800957047530722, 0.21324834185502223, 0.2006230136800197, 0.21685618696914566, 0.26556131460012933, 0.1113358721317303, 0.14010490218718208, 0.12543851659903604, 0.10895287903446345, 0.0937996292486787, 0.0706924869108104, 0.13073584605609218, 0.10235701522399342, 0.1271033865369616, 0.15199634877424087, 0.16146743249508644, 0.09553052064391876, 0.1283084428418548, 0.1892859696020042, 0.08520494245233075, 0.14407738983150453, 0.09245521388947965, 0.08030155072769812], [0.12296554647506246, 0.040229601980817896, 0.029912527365189408, 0.042057085571990865, 0.036892825587382244, 0.025909323425542925, 0.023874624542170958, 0.02784928404575875, 0.017536426744153424, 0.022883743438268864, 0.06488924831031792, 0.03254966630089668, 0.055194719724597475, 0.08045740365501373, 0.013488149063871994, 0.024405061905722947, 0.11982203491272465, 0.05436269461267418, 0.04635928979804439, 0.011818425001336202, 0.048826682801929214, 0.03318599808300215, 0.02904047224400265, 0.07424561802538172, 0.054252734182462584, 0.04436951048011261, 0.021668812260031704, 0.04164112281174429, 0.03421185493108726, 0.014236453214600204, 0.05953150898999265, 0.042275148669197675, 0.05219068212975418, 0.11190761887137929, 0.0728766878526057, 0.01745291932996723, 0.028123566505288886, 0.006156828875968894, 0.05041454558170611, 0.04658945325401522, 0.015787084121257067, 0.029372418141593377, 0.03501235935536604, 0.0166458897517934, 0.040455310635509036, 0.006328603504375825, 0.023271562043397177, 0.01766260334050223, 0.02600908722548235, 0.06628852322577469, 0.03673418793046186, 0.02795509610986037, 0.05782252004850776, 0.05493040406896223, 0.015247702681189104, 0.041617094463999235, 0.039425493112855384, 0.13867714412270055, 0.019654443434950326, 0.025428712420586138, 0.06649811722097859, 0.0225521135519469, 0.010435859421117893, 0.03669413685378048, 0.042502787865458, 0.0144311391387976, 0.021423514737116716, 0.04224831260921013, 0.006874186904995793, 0.04196506692096592, 0.029098614487015916, 0.017229696630590388, 0.01804201796110119, 0.015641445061191916, 0.040314384931398016, 0.03319754685846067, 0.029348546841872797, 0.012591933444773239, 0.013870364693444104, 0.03207571068478208, 0.01042962346541425, 0.010270811523491097, 0.03858032193215143, 0.014743840907730404, 0.026148312214401462, 0.04187848366376373, 0.07185225975849936, 0.038327934265497236, 0.030528465886750532, 0.04799970237898731, 0.01847970889010016, 0.030429726729409832, 0.07153237208483681, 0.014922322157109457, 0.008180201628185328, 0.04574105301271043, 0.07169488997709367, 0.02639861420668181, 0.07491740052618327, 0.025902516734335693, 0.011467124849948431, 0.15720769252267577, 0.07988261554630534, 0.07930729883692919, 0.057123817218047, 0.011229844437161041, 0.03645544683921241, 0.010527483536861839, 0.04444870864972473, 0.018318759562868266, 0.0820696739960582, 0.0006657757729689981, 0.015843177079072884, 0.11201245800381708, 0.08794751423861712, 0.029455352905056173, 0.016159726524605386, 0.0247871597492767, 0.022526880530940912, 0.051453724698794466, 0.02692899028319986, 0.014804620408423006, 0.018028297326377323, 0.04302673454907152, 0.01976324515717645, 0.0530805200668833, 0.0497199145085629, 0.002370465644485047, 0.04520287241546377, 0.017934286846749244, 0.027684780070558194, 0.027489739830695817, 0.004063527139219186, 0.09812945094440254, 0.04605735539488735, 0.018854427391723282, 0.037189542931774934, 0.007720154817140992, 0.029516530771469398, 0.03672661515133035, 0.05489335988738364, 0.06450827278557324, 0.08507396439991652, 0.016355341330410975, 0.13983992769593193, 0.04452055620570337, 0.026941167250756296, 0.024477690871384357, 0.018707378729877454, 0.025608287260477102, 0.049085103410987124, 0.021554676650632775, 0.06225500518696443, 0.07318564345158877, 0.014632056230649114, 0.039348627680972706, 0.08041876218011303, 0.09538422849389816, 0.0558778096831614, 0.009344433107593609, 0.08421521048031508, 0.026603648063516425, 0.016567679835603605, 0.04048411554146198, 0.036842018636243964, 0.03052488442570452, 0.03803052744197269, 0.012385628839594223, 0.08711466941261485, 0.0863983772034126, 0.022951140023407438, 0.021537219422058235, 0.03250061752154462, 0.041044317336092075, 0.04040019443979667, 0.018502720256125735, 0.021839795423851862, 0.03398844070972935, 0.005621257286909367, 0.07478545720298445, 0.006015504806137254, 0.023278326599768574, 0.06534419728503113, 0.02218714160394044, 0.04169535034546449, 0.07060784185605665, 0.02640669260384335, 0.007135663247261678, 0.06841775735900288, 0.008683751220814884, 0.008354963520692002, 0.02186892974761225, 0.06490826261259856, 0.1112003741605628, 0.04752358639492624, 0.019342457958226724, 0.051523917504856666, 0.06876794381007072, 0.08701888543944206, 0.02385794297761975, 0.04750012878268477, 0.012199465643554445, 0.029123610020765377, 0.04496095334029487, 0.03426130590659957, 0.051872276836225105, 0.007508715986454439, 0.02529905586984129, 0.04164339043200017, 0.01524895140450568, 0.05395021755248309, 0.11397897506192808, 0.05260490587041263, 0.03507281518391064, 0.030996593488981167, 0.07679063871863388, 0.0964239783464901, 0.05117127191155188, 0.07005497918374116, 0.0233745108538818, 0.024372277173003363, 0.02885533752100122, 0.04345928311287876, 0.07615143793725199, 0.0429435986875286, 0.05479852586323696, 0.04198785037583402, 0.04303957801312209, 0.0750546068734219, 0.05670671298679325, 0.006954693169738617, 0.004161609854969767, 0.03140473832196045, 0.07882026609994712, 0.01038415901993792, 0.0497442186479607, 0.09454200675170268, 0.030791890965173804, 0.053537847744601394, 0.021318520471874266, 0.07021465488979894, 0.03322734001783594, 0.0380394064010151, 0.025985244654058933, 0.018156377651217966, 0.04042307365565531, 0.07935845818851264, 0.0016333174097516966, 0.003231235093534774, 0.038016741689775264, 0.01574057683859381, 0.05915851610141897, 0.06888939172870691, 0.013420009373446867, 0.03720131770317112, 0.040325853267624494, 0.04339618045055578, 0.07041729280665036, 0.009209949245315888, 0.028071767470288663, 0.06712888337431416, 0.05343796520103371, 0.04047589158759483, 0.03474890937908523, 0.03812219752299209, 0.06156780516668674, 0.08488592811890187, 0.07851330999044642, 0.05025677743457979, 0.02629028554374893, 0.01392837478629043, 0.04377506072482756, 0.09199802793802754, 0.024958688750742905, 0.08102211770751784, 0.06107162533988876, 0.018707685165047165, 0.04534541456509502, 0.05413374923650296, 0.04165742516277298, 0.03478617189572223, 0.03679578139957401, 0.026314532226552407, 0.01844612742593933, 0.05664733351178228, 0.04723816884741668, 0.029662330709998647, 0.020090671136013923, 0.0044069988296307145, 0.009376085945405066, 0.0440354731624886, 0.04191679189041738, 0.009382018338768713, 0.03657596779146022, 0.0278968102253613, 0.032576172943076784, 0.05580550630486781, 0.04698971504225366, 0.04186462130277388, 0.05653585239704098, 0.0734294279508533, 0.06659227708775191, 0.07921182895980536, 0.0513385970055336, 0.04717602379499905, 0.09024612275102446, 0.04731347145993383, 0.0618287768485325, 0.062223584090750066, 0.16806161091212304, 0.04278764999922245, 0.010629898001019274, 0.040150392319886916, 0.04824598815532462, 0.02206021807186546, 0.044039215501998706, 0.06439794846359762, 0.017923982964167674, 0.01850756193180719, 0.013758668116474105, 0.06735720055838747, 0.041824869000382965, 0.02957339364764912, 0.0015793206600186926, 0.01030126064565153, 0.028029659447530587, 0.07818037583943337, 0.07044445062356611, 0.04824462834925902, 0.043132607900207086, 0.03162238390124854, 0.08847167925728906, 0.06674130417166219, 0.046900339394567475, 0.027306981895479466, 0.025758001908299424, 0.006092396093487379, 0.05815972513969868, 0.012768070465103995, 0.025532691619328918, 0.020397349538642074, 0.00853610501038812, 0.04991810145457426, 0.036016823198165626, 0.015134007572346639, 0.06252080705317278, 0.020330362810542988, 0.04935342187602674, 0.06953677432912012, 0.031733842033352104, 0.05452580239263274, 0.017647329462511886, 0.2053865330714372, 0.17511735730353864, 0.15003378472981915, 0.17869298075956686, 0.11055846142792895, 0.1400770931955307, 0.14423344194168045, 0.06542207012253423, 0.08827795860387626, 0.14577706314383015, 0.1536979373063772, 0.10126936955437546, 0.17398979845306567, 0.1221467900059877, 0.1377532267642598, 0.12458339393619569, 0.15986503702738594, 0.2262998294205435, 0.12237524508588737, 0.11962920292130402, 0.18176742949553076, 0.1365169906808484, 0.2521757360908293, 0.26502600300215906, 0.1703075815232531, 0.10132242880401113, 0.14031303295445058, 0.12332332485745992, 0.13410163802965996, 0.21567671800092345, 0.13124224549580005, 0.16412056351621307, 0.16078109432372356, 0.1362098353884874, 0.22712430856641264, 0.22934548857231296, 0.11265791772354035, 0.09165328071122208, 0.20610411230835224, 0.21872357224985478, 0.13214471239236095, 0.20242235503129422, 0.09983814111159695, 0.1708149155902286, 0.06385406817219431, 0.17951649463465139, 0.11742918226387232, 0.15730840244120167, 0.1646248791967669, 0.21582501730130565, 0.12829281464819947, 0.142259968805217, 0.14581388132947107, 0.15319457157484948, 0.12193795443782884, 0.15661820318670044, 0.18428635723408193, 0.16742249440041282, 0.14796337082741723, 0.09969411658183222, 0.18952727197639405, 0.18773287955311038, 0.12866693368602183, 0.11872110527849968, 0.12923570800452464, 0.21446806108278615, 0.09744780123113625, 0.15914048639035996, 0.0891064290678309, 0.13944556095427083, 0.1832538545732537, 0.08878955978059, 0.14476677703280605, 0.14348828353949133, 0.06382401071248517, 0.1340075777543168, 0.16012202888246507, 0.08041064164811566, 0.11199981755306644, 0.08909929678925584, 0.17870309312016736, 0.16970303089868638, 0.14075691961953718, 0.14695602649402234, 0.1510726918856944, 0.158539398483211, 0.1466402910169094, 0.17714532993493542, 0.10961613497666775, 0.11854201690444063, 0.2294174242284029, 0.16186618125967442, 0.13855863032081436, 0.10851985549614315, 0.13785530031929094, 0.09811357760261144, 0.2934904288380377, 0.1419717512063442, 0.2037548730450292, 0.12243297747186116, 0.07663582767089529, 0.2517949444271865, 0.12022688173718991, 0.1775096047429308, 0.20475349929784575, 0.10553985007948453, 0.11599125055175637, 0.10214277107508914, 0.24545608779355405, 0.09568029083311559, 0.1299599675281394, 0.1323963569537286, 0.08582480717450382, 0.21073624762075566, 0.13427244499325752, 0.1102132162439727, 0.142247159815123, 0.11561267288221468, 0.10657943139273314, 0.21867953751596714, 0.10471141791992611, 0.10262010513894981, 0.11101602276246395, 0.19474661368275845, 0.1298291963194647, 0.1537484378223458, 0.1949551274939891, 0.16173839779390445, 0.1605431933797175, 0.20174104239671461, 0.13863367629387688, 0.18282354298618533, 0.16463793333499663, 0.2938143920994574, 0.3316450395411061, 0.10683152028509688, 0.09589290321474114, 0.1331677308846866, 0.19173176658730354, 0.14322914663822423, 0.19995699216040874, 0.10545871370742399, 0.15362184945373766, 0.10836320583738628, 0.22663099390845146, 0.09506968811394707, 0.12196964749525632, 0.09632008150219919, 0.1099471156034739, 0.16397502213235826, 0.17060693804054491, 0.22791520241768132, 0.1718470198853362, 0.13395364516444747, 0.11696232062193657, 0.12297224974439991, 0.17252940504300981, 0.24392110806319023, 0.11261333140634722, 0.12961023306894687, 0.1981378704189293, 0.1289335016401545, 0.061411944578491875, 0.06941751742194738, 0.09246901879387517, 0.13068168363984556, 0.09441088314258284, 0.09829776812224619, 0.13064753144018112, 0.12431559258050497, 0.13422582088218582, 0.16848677438834023, 0.13746154644796926, 0.10753311892791141, 0.19037753764179446, 0.10108799823830206], [0.03796513417675611, 0.04306859742369383, 0.03581891970468625, 0.00880778947424504, 0.07572376935352242, 0.1272613615278275, 0.07072959620986255, 0.02699862192985752, 0.027390751694779725, 0.03448596502083444, 0.052293828207879305, 0.047503415299879934, 0.04545288137911309, 0.016382847717332265, 0.0355866035416482, 0.020997694340504466, 0.041135412851168264, 0.04024020463768994, 0.03368826064791891, 0.02409814410061846, 0.03287984253538232, 0.026041914093037768, 0.08968006038377363, 0.020359273053585522, 0.02837483568357364, 0.09723449937037884, 0.08429717422733385, 0.010684391750293154, 0.020636773082397638, 0.06885389121429575, 0.06489371460291647, 0.060685409773742004, 0.03749247324923354, 0.05881387612692291, 0.031019461213520942, 0.029539126534796054, 0.037159282458765854, 0.03945665756961511, 0.05607722620029123, 0.0018469338453630168, 0.044955521776911714, 0.10042278877189083, 0.04397515522977037, 0.06197588488219246, 0.026271317206743746, 0.02102204444517772, 0.025934108285113208, 0.036059241486533035, 0.1450296984084191, 0.007591581323199095, 0.07104153189087106, 0.041477616666065115, 0.02200883655478397, 0.021398551762104038, 0.04879517743604318, 0.03578649120285146, 0.04737404986254631, 0.028470508573997407, 0.06626332659394511, 0.009417899024312296, 0.03344368324765275, 0.010078685290570702, 0.04831336175782546, 0.035163148441502166, 0.06841956532650417, 0.024369618847906113, 0.031264595942752015, 0.017128107626171365, 0.0524597360392011, 0.015491108924541024, 0.005242695417931123, 0.014937435156635702, 0.02319120899623921, 0.026093617367047458, 0.05756081675269431, 0.020993237624004967, 0.05532215845080153, 0.003250739692086955, 0.06845214704592383, 0.04873734928907887, 0.010599350245038589, 0.004559525020135146, 0.01947922763534852, 0.07114064834651447, 0.033257500899414864, 0.015224261348316026, 0.07268089876179734, 0.022943122913279844, 0.07445852152041851, 0.03329890029084298, 0.008263811506631394, 0.03133536139953762, 0.007512723583908331, 0.011960611877692564, 0.017830903281367595, 0.020277558285142147, 0.03449135061894213, 0.02570442554931487, 0.03196776315059153, 0.02190507760631942, 0.05273420619027269, 0.01592333860424978, 0.05811808443057442, 0.050100602750335975, 0.034815811837512645, 0.07737270466262296, 0.059049176202426036, 0.033300765714938604, 0.09994490312472468, 0.04105209695896314, 0.07729927513508067, 0.004918327087521433, 0.07959235249267471, 0.08524835665499972, 0.057916178127690676, 0.11153029758603343, 0.02481691077381613, 0.027861321202269005, 0.061942391518142924, 0.028400338750572938, 0.052386314172538063, 0.05734295666878743, 0.016628970699985663, 0.03824041255058781, 0.015740650574556522, 0.012494668049076873, 0.053250748634098045, 0.06026580043497586, 0.018555787166640646, 0.07928410169458197, 0.03592912911347324, 0.05986812802392149, 0.05640651760322433, 0.028559459042885614, 0.027277535390889934, 0.02791415062552739, 0.01130626362282783, 0.03616246034301097, 0.043897833975572745, 0.07782029919326305, 0.05230734199886361, 0.08415591527497576, 0.034006918750462994, 0.05467748397120065, 0.10794513633534794, 0.03554856344576805, 0.021508573479349577, 0.03551765179802333, 0.06088787149037085, 0.047445349665659095, 0.010430045771382509, 0.03719001790628799, 0.06957637341392618, 0.08429373449255383, 0.04323830122068044, 0.028851365355113824, 0.050370326986716646, 0.04815954279394881, 0.10167869799319776, 0.07035424377048208, 0.05906988738945896, 0.006554536239784812, 0.05683196836241311, 0.01459641494758187, 0.04859445090856283, 0.02626026064277657, 0.015372094292674335, 0.016736253652901902, 0.10478788115564855, 0.057591713078680544, 0.016246980108741312, 0.12088028578868798, 0.05812478386947225, 0.04147542182416205, 0.0233521755604494, 0.05603451296807297, 0.023691177127822757, 0.03716414711708504, 0.03360459618570824, 0.03814088240746529, 0.05769443397800769, 0.1023346224739667, 0.01658151538351611, 0.049273158844199874, 0.05950553860935954, 0.03382476985514645, 0.047027820255607374, 0.004982056026722515, 0.028948034159839157, 0.024405253427704016, 0.01565592795340044, 0.020621131482203642, 0.05438467750566141, 0.051671806948199395, 0.0306417319863554, 0.0209251630510534, 0.05521610506900376, 0.05362104872361787, 0.04230907870336406, 0.02422170259148604, 0.015469294570897137, 0.045453367844945004, 0.0357428471738052, 0.007688173519131998, 0.029070590990745736, 0.06220597555981048, 0.036734651413656054, 0.06789645750916774, 0.042587938538241776, 0.07432393519388092, 0.024047377369096203, 0.08502286633536701, 0.042223430073429505, 0.0539414496761897, 0.018488984299643386, 0.058521521653258995, 0.042500979897956696, 0.04144091339361283, 0.013794196401572516, 0.04944352913768061, 0.041841673139002056, 0.026342875564530976, 0.03663022596869738, 0.05524466482682094, 0.09849274515985482, 0.028387435914708242, 0.07709616990459543, 0.05327851166047397, 0.03585093068860231, 0.012818405314558938, 0.01465153688895366, 0.03866344630237549, 0.011777372264693822, 0.06840499433418436, 0.07098919276388423, 0.013167446464179985, 0.046050736395221566, 0.1050283408333217, 0.010289117194441779, 0.05767727743894343, 0.04817625117157737, 0.07249109281767761, 0.023572054286036762, 0.022346485976970965, 0.0434361664097636, 0.02756011075220041, 0.038505375550519076, 0.03258528938937572, 0.034660273006245974, 0.037469754911839, 0.06311999506226952, 0.06597245066997505, 0.05175491982710458, 0.03416420809263664, 0.05755597124657324, 0.031793158306109334, 0.0036563322552660062, 0.02064226401759492, 0.04948552990812929, 0.02441938391946737, 0.03722023624446123, 0.02580991394126848, 0.05078384209604514, 0.007596908028297608, 0.053100472826871185, 0.008033888410746811, 0.093562938723593, 0.06738148554558716, 0.04188485751529375, 0.09099128881409284, 0.025847752939068505, 0.09437815586645758, 0.005913116197447263, 0.02508605852903378, 0.023882812106861703, 0.03228762209595692, 0.025987023893263073, 0.051134028547112985, 0.05761964081396019, 0.03491361828280553, 0.023221216660233277, 0.04004127075595241, 0.07376355719902823, 0.02431759190174841, 0.07232002538418578, 0.013188823190097128, 0.12461386891382358, 0.03406180895023769, 0.037877240909203407, 0.053541574762353016, 0.05820914164125439, 0.07361299027839015, 0.03466993337497115, 0.07617158604966057, 0.04156564399900456, 0.008746332943349356, 0.035660615296012936, 0.10803155871408601, 0.05241408102935361, 0.03806069981487047, 0.051142263992299, 0.02732450232630776, 0.07036845470147748, 0.06091098053260677, 0.029505625509867267, 0.04660478650381969, 0.03825576878303001, 0.07216500749270763, 0.04495463694535917, 0.016880624837452368, 0.0378734985696933, 0.026366530444412947, 0.04329814417888561, 0.040101761058453596, 0.017135423765848243, 0.044818380547146645, 0.05805614239145672, 0.057760512891916506, 0.013885426939645363, 0.017121551828759334, 0.10191116737382067, 0.049487977559047366, 0.029759388304345553, 0.04250104501543026, 0.0721576300659968, 0.05094562071345506, 0.02640981058169517, 0.04363946699266953, 0.035591456708648515, 0.03256736676238718, 0.10113062337040903, 0.01503100034765779, 0.018015518979800325, 0.009649623384428842, 0.06357838377176274, 0.07850021754782047, 0.04839657422816081, 0.007905970400785127, 0.08212652538091907, 0.07352532683721474, 0.03827081091942326, 0.05710959096529311, 0.039044031122278784, 0.04183914504885193, 0.02636307538787444, 0.06764354890272503, 0.023681673807122057, 0.045523955186288205, 0.04102400068434016, 0.02870640236764185, 0.02113765860427051, 0.09000852824218812, 0.14455489243470854, 0.14651837578463942, 0.12206028335757795, 0.1389043964445591, 0.27564367519751676, 0.2894653415968341, 0.1337936706840992, 0.1347409537242305, 0.1360923941096952, 0.11964750476181508, 0.19053204225436335, 0.1570785300986421, 0.11163200341886091, 0.13122606571883927, 0.2010220842015359, 0.183831101824199, 0.17930176018947558, 0.13160025370457482, 0.16144870930621702, 0.13954219528503958, 0.1338429761029059, 0.15703800404744764, 0.19424707839085212, 0.14346911601962584, 0.14844128711810037, 0.18972530570482055, 0.13539166880711434, 0.0734017032288736, 0.16251873495357652, 0.2089739542814993, 0.14249555616369172, 0.1235391624692467, 0.15852349449790296, 0.2822815512697543, 0.16824498171767882, 0.19313933057410104, 0.17435588122856233, 0.12061257636354816, 0.23155229676875377, 0.09591616930500155, 0.15703516952212782, 0.17036929756643313, 0.10568970453835304, 0.12464311048989335, 0.11996562277237255, 0.10293286819491657, 0.16672521649349123, 0.2704521731263207, 0.18563949833473853, 0.17096145288838496, 0.15326237035614831, 0.13729418688003095, 0.08407601230447331, 0.09596066369164376, 0.1904709697250397, 0.1982801176247097, 0.15288481158354592, 0.22639070277012166, 0.19523920821807078, 0.07823897390476159, 0.09776198154976291, 0.2769333995398014, 0.10801159446277928, 0.1466388814151287, 0.14673082728780087, 0.20438588434650054, 0.14741477526483998, 0.17414252574165023, 0.15705396931978965, 0.08455949039348672, 0.182842557288466, 0.12644134867455692, 0.18383139293761025, 0.1882415772565911, 0.23634639839010857, 0.22498142274637378, 0.18407485567994658, 0.09201149576373639, 0.1560383818803295, 0.11627794363565984, 0.08469726364578932, 0.09838793667093401, 0.14202479513422137, 0.18630875274538997, 0.1554403430031192, 0.1029057410215178, 0.18599275679838273, 0.09687196358197159, 0.1782595741772844, 0.08287762096452136, 0.18119562146884782, 0.19138667462093217, 0.1390926242475548, 0.20197218644522852, 0.19684027069278304, 0.18585686812237387, 0.12572382306379656, 0.08394913282245399, 0.13839156186628726, 0.09104258606150266, 0.14662316129092248, 0.10243569245381702, 0.16300100262366957, 0.18160750098045797, 0.13115062138005612, 0.22680272017755818, 0.16725738713097188, 0.1743806258685166, 0.11746604641478871, 0.08078771012444651, 0.2026047605660654, 0.11302845146987708, 0.2222985521920266, 0.1704624691797841, 0.1735602682756801, 0.18139742434986178, 0.12050649616867305, 0.1445391569887438, 0.1729722498285194, 0.11004185769706966, 0.18374366054852165, 0.20912588483864264, 0.14979234445960293, 0.15294940811732124, 0.1333841966885713, 0.2633645115119796, 0.17818526364862922, 0.1427565316759771, 0.1018967495990857, 0.1934984725930037, 0.16207458781859568, 0.1778700184677878, 0.1971283197523125, 0.10484863958892324, 0.12022676682400128, 0.14848561296539922, 0.12607991605276062, 0.1690349256199214, 0.09981891996557675, 0.15573934711996587, 0.2537491121479581, 0.12263600609355396, 0.1159356861946083, 0.12202620776670596, 0.19042027002621084, 0.11827439174897249, 0.10307794992601681, 0.13719750658398674, 0.17031796967550633, 0.33058802206670085, 0.0645328029209087, 0.08867108428310003, 0.1622403539236515, 0.17354571260511878, 0.16002583888269242, 0.11798992798092867, 0.09158770358490367, 0.10093449720091398, 0.16935449153665574, 0.14627503561637095, 0.1937279312480842, 0.0974917287127145, 0.16658082424152285, 0.18000095331620786, 0.22390819485149077, 0.13728369147546832, 0.13269597394091467, 0.18877687353280284, 0.17544931852288786, 0.12110294158300086, 0.12955254664824856, 0.11985106964505489, 0.11495228976972642, 0.12089681030521471, 0.1309933741727183, 0.17035219848396319], [0.07970083820363207, 0.014134959013561809, 0.0829793880843828, 0.13351712826519244, 0.04111670881449696, 0.09317220323869298, 0.0402446173041338, 0.041452695825888265, 0.04983327253871868, 0.0196378480552906, 0.015417906350546308, 0.06647203958803607, 0.03617924915987157, 0.005904875485406768, 0.028111956442796418, 0.013931887299423257, 0.05356345040303084, 0.01019138927316113, 0.044142920824308554, 0.04401808679704705, 0.06503937856083916, 0.024239282394128463, 0.03213280338733908, 0.029373055909790342, 0.05364674714303786, 0.01904021328946035, 0.03579702491181032, 0.09426512725410924, 0.03613784210756421, 0.1159231223526501, 0.024877014201915553, 0.06911412362129458, 0.03579528206178258, 0.09744302850336799, 0.008744860139314928, 0.028856749038001703, 0.047878235308153015, 0.03253703351102529, 0.017656922798543688, 0.05898803089474959, 0.06481765739379391, 0.020959769157812964, 0.21289241740540152, 0.040583140066554474, 0.02434648299259284, 0.029962495450050603, 0.06504758336250821, 0.032308589922444474, 0.08813650812953712, 0.028914395239084, 0.048008102533077045, 0.026936469216560645, 0.09773805662388764, 0.007796845006410994, 0.013303011468040847, 0.0569514129611273, 0.035588568557173975, 0.082358175047463, 0.048912028827133684, 0.034515796484605926, 0.05372280818260005, 0.05316514979987856, 0.017126776548402927, 0.04637097646932929, 0.031141811200687965, 0.027782967644593412, 0.04062717480044212, 0.03671759829646157, 0.06585392154633038, 0.05171181972048456, 0.045432392357578205, 0.021896727247944763, 0.04133308268783074, 0.02844543834667533, 0.03512518495441445, 0.04323418732852705, 0.015982917262121074, 0.02339327617758705, 0.04076152363972318, 0.031436339448837024, 0.060048920943612055, 0.031534578733807134, 0.024468143500628012, 0.043120587980675126, 0.05498199242978327, 0.040556545324263074, 0.055886320920000156, 0.034014457055637916, 0.02171278379166559, 0.035227170409334284, 0.09069180206185387, 0.03638150403276086, 0.04778446997666071, 0.06480843369518557, 0.036684288793513854, 0.025154857055073785, 0.04992126539770154, 0.050935983327367616, 0.010228791600844313, 0.1127988319363325, 0.045660257549776186, 0.04760225979431022, 0.03140099023679092, 0.10416315943603555, 0.0777111163422946, 0.017523184914382237, 0.062170674228259636, 0.007654896574921065, 0.041079143693129865, 0.024294745244626558, 0.03906663454648468, 0.002354506596607427, 0.06431662823043524, 0.014489195196919385, 0.038825439424404216, 0.0862401647252902, 0.0444811869472746, 0.04388718535342524, 0.049259254348374186, 0.06639757584179602, 0.022993261452704188, 0.047934734292568705, 0.07729512293853107, 0.021113861998122548, 0.014676262376709812, 0.03608204026315962, 0.019005107310330196, 0.05587042459557134, 0.026363464177496014, 0.06255359561633199, 0.023872019843228405, 0.010114582255482674, 0.05547626469764979, 0.06787236404394911, 0.08937560938178532, 0.02670979912152454, 0.07554235207217355, 0.014397489684333485, 0.008250707572686576, 0.019690878576629108, 0.010541835236513327, 0.07618280157687203, 0.016364001954394965, 0.02007337095546386, 0.05451153783548263, 0.032658423973067154, 0.05919045430698222, 0.0701865471238571, 0.07467214513810412, 0.018702349362654552, 0.028236740674342842, 0.06497878866690783, 0.03829937833811968, 0.023346060263593833, 0.0673782526545467, 0.04183985751062151, 0.022203212213372032, 0.07368241316608845, 0.045676467970253966, 0.043190845904210885, 0.05664578601417523, 0.06612085722266667, 0.0036688853241127707, 0.03835780786410455, 0.03977605877744575, 0.010054132172597513, 0.08332672468837231, 0.09186808410431109, 0.06696062748350444, 0.017091130477286155, 0.04690470226529626, 0.04860102011251354, 0.07317194579950265, 0.014308357269563263, 0.054570323592352296, 0.044634580732353275, 0.044277277324468865, 0.0462539833519728, 0.019807532700079105, 0.06745856931252826, 0.08759424045321443, 0.01180919842989815, 0.037783873943431724, 0.034600092969354124, 0.032793565713349855, 0.020026298682956446, 0.03871464778879478, 0.023534966054402535, 0.015380155452857576, 0.014859546997374105, 0.026511868814967816, 0.014055245649820615, 0.03638626143877064, 0.013733387214972848, 0.026573672958259142, 0.019688201099333745, 0.10120206873022741, 0.05686856438255599, 0.06605675098516288, 0.07457403991852077, 0.033195202629412376, 0.043549302274421345, 0.07957893063224132, 0.08655077507418972, 0.043202187835929856, 0.05653389504239444, 0.03289415305780788, 0.02256812478956436, 0.08519234796685558, 0.028811875437836976, 0.11465802007625181, 0.024666117857240384, 0.03287742169754159, 0.03208647613533803, 0.046812024778656425, 0.06186499748559249, 0.06276633440246505, 0.0576305958712774, 0.06964796433045019, 0.017689330232960564, 0.09558335006717714, 0.04853016847083646, 0.0625602912247902, 0.04499969823706535, 0.09454101849828037, 0.055840834449496, 0.035655746807254134, 0.03922072164113483, 0.06562044859052667, 0.022014206831133174, 0.022677715582352494, 0.022505307494993174, 0.08219896665503902, 0.12137805907836846, 0.023467197916620684, 0.07309330687407525, 0.049524994927548596, 0.026386165277912255, 0.04737264409120526, 0.05919996145812254, 0.02699545415629062, 0.02202329454913495, 0.03395423488391023, 0.029802513308823112, 0.03452153448315878, 0.03472965758954806, 0.035473938821063894, 0.00823894429260925, 0.02854344397482853, 0.08756555046045011, 0.012838557257407136, 0.036412902146337495, 0.01806625698302542, 0.03861679920866605, 0.07841446932645575, 0.02343174336748498, 0.05584893965973489, 0.05000373476275033, 0.023180916604976502, 0.022572334442708283, 0.04469304473229474, 0.020504285836772575, 0.017650137174754374, 0.09004205224975463, 0.03865794579107915, 0.049682579213573094, 0.023424561293194854, 0.04006301999212273, 0.04123455611988902, 0.04195436084222409, 0.05948560883200938, 0.05361869683369033, 0.006224834979812225, 0.030147042200570146, 0.05823031248104188, 0.04397723132804517, 0.05232267141822846, 0.008560896573227741, 0.06823670013897842, 0.060844825009905526, 0.031182747108921893, 0.01348548690833512, 0.013409203703274891, 0.06477318598978943, 0.03424554747799712, 0.0174639203525599, 0.03124384645132288, 0.03897992105433538, 0.04378831787635723, 0.054973228383929505, 0.017595022894261826, 0.07289895036768529, 0.06613339808198714, 0.018133130713155674, 0.008273889393275304, 0.029366320081716104, 0.019768061935000365, 0.05476920384793513, 0.05562410817571706, 0.04660218563531676, 0.045424754460973125, 0.02308175992971707, 0.08632461059718363, 0.0249003779683863, 0.05908656512357055, 0.01411665908827056, 0.022640508607090003, 0.04031489821030729, 0.0154051442833377, 0.062088978612014366, 0.025060494175000537, 0.044960405587429, 0.026085437463235953, 0.010096510241348899, 0.05869746523638887, 0.07358559497421788, 0.04363068762505728, 0.03776574830314325, 0.012519403112932079, 0.020915058351332144, 0.05415729494885572, 0.020224454985450835, 0.04784857238372488, 0.025176437751900767, 0.012392984241277221, 0.07407403731298062, 0.05392426249360847, 0.034543885098349665, 0.006917253974074077, 0.015456993114053002, 0.06516713138309217, 0.0497434678817949, 0.05966201589833345, 0.060603564770351497, 0.05036575727224831, 0.05086414726270784, 0.08535438322372015, 0.012041501186397529, 0.03379699533745166, 0.05074099479844013, 0.07895233965809308, 0.031010813996075626, 0.055961129405806144, 0.017745923063146974, 0.019020344799144134, 0.028809431617358522, 0.05224963259552756, 0.04034478713067309, 0.059729665292487036, 0.06830981557047175, 0.09077042566552278, 0.011633020232341463, 0.26233115083267616, 0.13791496324683392, 0.127788131245442, 0.20804625244871264, 0.12900315435423007, 0.15291776868604845, 0.14517084244758854, 0.1144626140294056, 0.1300556978751575, 0.16050606875890688, 0.1279140607784352, 0.1558621969795035, 0.10313702296585807, 0.21771681014328234, 0.1766644412231061, 0.12205176445985995, 0.15079938235782808, 0.2397455458318995, 0.1476485699775719, 0.1420742690923714, 0.250059939139793, 0.1926561895637743, 0.14605601107881916, 0.11850050259982386, 0.2035593980502698, 0.1722499208464738, 0.14208660310795232, 0.20419623161996567, 0.1580771103861832, 0.1783732922687646, 0.07223292884807433, 0.18558867606184176, 0.12433571771027581, 0.15584719697794608, 0.19687390195265894, 0.1278153043841162, 0.17099013522027, 0.1036613641847526, 0.11219442686847142, 0.14377357468249338, 0.16638917968638484, 0.09863281667593027, 0.2321761834525293, 0.19131325275426914, 0.2576057060110954, 0.09671028838643143, 0.24067790547926582, 0.14889154763471696, 0.17168532936803757, 0.10599827709337396, 0.14364338570064114, 0.09570989247050979, 0.18508719490660777, 0.09822868231323459, 0.1340297176953285, 0.14970571523712528, 0.1450016902339074, 0.13931137299345386, 0.27954839470405735, 0.18851124020593782, 0.07688520461200707, 0.11957250475402802, 0.16990379190012334, 0.12692445904136668, 0.08630836187230964, 0.1331749780764503, 0.12014834240319268, 0.11625757335775322, 0.25963847435289816, 0.14294790043946237, 0.10261543966349095, 0.06865161335876874, 0.21628629416227343, 0.1836021181436316, 0.09610327095874856, 0.20273228356194115, 0.13098726079108255, 0.11793866903791506, 0.14918437708289395, 0.11370118391970474, 0.19725372834551722, 0.09984019422723402, 0.09171517295462471, 0.10037606506938897, 0.14147428435183343, 0.15359491380231996, 0.1490409041364347, 0.13749307862693264, 0.08699263160627696, 0.17062607491689344, 0.18961843643938342, 0.14953074075521963, 0.16341871972526276, 0.0800934582648258, 0.19195885036981877, 0.13592304271315375, 0.15387029176758182, 0.11868550517265836, 0.11075189096793053, 0.22146175435233503, 0.1224170198603984, 0.14640033695726626, 0.12037004824847945, 0.25298051145528594, 0.268262816412795, 0.15896813192915532, 0.2579338367908232, 0.18191488609919626, 0.12109595486113142, 0.1309516683461205, 0.16556433281831204, 0.20276033770172827, 0.18393372696253563, 0.1630304663652374, 0.07938686472874495, 0.17701943104545917, 0.15365708949825457, 0.11292053266398369, 0.12494172390189864, 0.11918832698175985, 0.17419394556312792, 0.13492201094425496, 0.13809514712662468, 0.11566334959840584, 0.1050808484996519, 0.13956689395971839, 0.14274085751704632, 0.12194273482647636, 0.08496265182451856, 0.13144879812194457, 0.10385336880121501, 0.11289886003660579, 0.12967784798914386, 0.12846406594279314, 0.2512945970820804, 0.13345922733987534, 0.1541851385827026, 0.13602281800441204, 0.17211222420296363, 0.15374235508422698, 0.0717639068381921, 0.16521231541710515, 0.13220190851678773, 0.16953711157604573, 0.16910830152130898, 0.15190351423957657, 0.17061044672323813, 0.17222801073183938, 0.10026178007284481, 0.15969853547792282, 0.11027890828347976, 0.13381470745849994, 0.2561721410001478, 0.18126021800262315, 0.1320364794904186, 0.1980476712267245, 0.11491558649727415, 0.18779825749656848, 0.12876349140799817, 0.11480795880479198, 0.1834740129209334, 0.15734977118911284, 0.14228129669302894, 0.1424091108023159, 0.15172463270925707, 0.09311481559228513, 0.18985108202022893, 0.14865638928547983, 0.13815978962567546, 0.15897531783388508, 0.20924585420758496, 0.1744499415039055, 0.21812510436340687, 0.1627110536660879, 0.11132966681954362, 0.1109979201048132], [0.05252626694498524, 0.0026890519262862305, 0.04291925624373459, 0.07651440273489683, 0.06396106767257856, 0.05314005275947913, 0.029744886259938923, 0.046043849264782284, 0.06739201925454602, 0.03774882925133552, 0.054379203807442426, 0.01794473437081662, 0.03135932462980911, 0.08438983256177557, 0.004202123457235435, 0.04740893367617842, 0.012995932784472263, 0.06717864078499618, 0.01051914179697633, 0.054583144073765126, 0.06323663577918084, 0.05826484389422883, 0.0042916255094291225, 0.06178585294213507, 0.0396033940506318, 0.032520298320319385, 0.044606040126734206, 0.011979482538487402, 0.07729480118160287, 0.05915290833781323, 0.05977057821808323, 0.01573219392148237, 0.04148572570674362, 0.048059127819273746, 0.04493609761759158, 0.03924912435092753, 0.05021340536674665, 0.05719005701041991, 0.014530656832991349, 0.07347855716943741, 0.030768870023049177, 0.05531969930856459, 0.029514605975559646, 0.01647428605675457, 0.06697267804655337, 0.041801384575064146, 0.04204482816520237, 0.04017417934993583, 0.028274123849827918, 0.06180412796956878, 0.04067690539804678, 0.024922632822586645, 0.0405612031388427, 0.04032420617858729, 0.035141215344230016, 0.04805551571471076, 0.04191809807032828, 0.05787213956336341, 0.03512945972503193, 0.07479227538551055, 0.07729968882255978, 0.09043160029837201, 0.02805228010871478, 0.03990623243753949, 0.03582161633417972, 0.0214175698948243, 0.05907255720587508, 0.048927657020789, 0.041685157545631936, 0.06166912795555207, 0.028658096693576347, 0.08033733469464126, 0.0165006720400866, 0.02642242613458826, 0.03189023313743453, 0.0811853327397858, 0.008626295584103754, 0.06006475981144656, 0.031588605169447205, 0.0259422134953521, 0.021871046065503073, 0.10039501042375643, 0.02185131355579342, 0.03524678609063549, 0.01498479279689491, 0.03179502373020495, 0.09364618949832455, 0.03182221985151691, 0.0668233138839564, 0.0645331783039916, 0.09308877626373883, 0.050276086680711284, 0.03362008265309757, 0.03564860686779984, 0.0758398469958094, 0.01940012905716656, 0.035494814717000535, 0.05017934126719352, 0.02086593870884709, 0.02487976637278353, 0.041223685332243486, 0.0070039013911399155, 0.0697700787455805, 0.023634858174069275, 0.09497598023904909, 0.02721152925533393, 0.031319840458191694, 0.05895387869508517, 0.05177759219922366, 0.03219930748004587, 0.008562852012654467, 0.08644124748365534, 0.03780600622356419, 0.07484119009947585, 0.026493678057205775, 0.023822741237499064, 0.003873063317094479, 0.13161859384948207, 0.036416996886292775, 0.02161208153401892, 0.021542802287806428, 0.008352804110355435, 0.049599408878073584, 0.025601032407834165, 0.04067955223182517, 0.020020495566930023, 0.03536335019875438, 0.01020171613838043, 0.06758777770183741, 0.024626250641660827, 0.027859241273554585, 0.011821366778965439, 0.025752148996557922, 0.11138041248364795, 0.07399782688627321, 0.08943149549586159, 0.02609275360291283, 0.08083213556317553, 0.017320788315226956, 0.017390220779024305, 0.0495288789933247, 0.03707651814986621, 0.030747595761391907, 0.04555681652780022, 0.008935978009004988, 0.045736184523951624, 0.08002999554117841, 0.05565041563503685, 0.04881784980816226, 0.037336570526202845, 0.034360334262131684, 0.03405657273927524, 0.13354043265984905, 0.047160552649368206, 0.014830721024003242, 0.021443009759569844, 0.04701492316540211, 0.037065773766728184, 0.06223959149792791, 0.04385947595320402, 0.07263612092262314, 0.0155523136040316, 0.07020808951628786, 0.03277040687539885, 0.07079338835131738, 0.04078055326376231, 0.014349998936297433, 0.08171388744226388, 0.01784295767485615, 0.03146279054964262, 0.03539621154026639, 0.015774970355954383, 0.01309078596081705, 0.001528544352397383, 0.008601094164224643, 0.00978827668023446, 0.04755514538696697, 0.008357193794161564, 0.06393819228715955, 0.012563670546026721, 0.06591229744616055, 0.05798673865595653, 0.050335650016824086, 0.02827911682787442, 0.01926219684161967, 0.02346830682889108, 0.029157666459439263, 0.019307384537833355, 0.016479861261623523, 0.01430235784350624, 0.016250291523794015, 0.06403197294041034, 0.04459603118800348, 0.015378245021096401, 0.03656316263180587, 0.0327084188710057, 0.07635109577207796, 0.03238631720324198, 0.011098312886221515, 0.028469916771075902, 0.035392438557239315, 0.04708449160980602, 0.015684492499267143, 0.07069959620674772, 0.07659394564407487, 0.04989952765285008, 0.04678378294732782, 0.012594132117115924, 0.05800142073102536, 0.037279650193428805, 0.016185062967481154, 0.023852817849406314, 0.026312255030197483, 0.026842418517316544, 0.05888075943315222, 0.05250199344910441, 0.047319404810907385, 0.04544909307432752, 0.054808829745818535, 0.04834697003506365, 0.05718709608059257, 0.020503031367796565, 0.029071866527139664, 0.028193481604478536, 0.02078127067145561, 0.03909768025961615, 0.015952307261496542, 0.04780692784416099, 0.04154441953306237, 0.06324941029531822, 0.04847885207122853, 0.0795987569877217, 0.02209354098135185, 0.06661433275909194, 0.019652633552229213, 0.010514971405838527, 0.039022473408089536, 0.050968561216347644, 0.0561682642587731, 0.06870947597968964, 0.052140476557636456, 0.0726543308325833, 0.010796920490270902, 0.019908426479706844, 0.06859026503779235, 0.0524901956950705, 0.015934726501244213, 0.05030023760252422, 0.04743469338263235, 0.033670272903456804, 0.003715231728311929, 0.04740377024356877, 0.06841044121932599, 0.100994351650438, 0.061394956578770955, 0.04750608511629605, 0.009281893519894972, 0.11678626595605766, 0.027603394719922257, 0.020676339608466914, 0.09885887390062695, 0.016236750919732357, 0.05300500678018697, 0.041925326109893864, 0.012052447625225591, 0.03878588630487362, 0.10636865762212586, 0.04569987195634073, 0.05521245466004457, 0.012283943116574759, 0.03880388171021496, 0.09426339589540036, 0.037090809520093665, 0.02176202792343834, 0.07112794660872991, 0.04328585995901977, 0.06470403889374388, 0.03480415580974471, 0.07621820249985303, 0.004926209174652374, 0.08247759283309983, 0.0030066197899530733, 0.03192393334522363, 0.019246061114714514, 0.06443169463666217, 0.05074541895620285, 0.037730554223901806, 0.07027022690782625, 0.04103741871433393, 0.04921570991075808, 0.016787240634702386, 0.01670871470724383, 0.01542142365172866, 0.04891204797933179, 0.03853102034378437, 0.05216722834795233, 0.014790096338988553, 0.05483816708287886, 0.11273935286989135, 0.06975322481124632, 0.07713271995946284, 0.03790669698989199, 0.019200453985362284, 0.0012519773947367926, 0.07647003858320175, 0.03330569932117097, 0.06480578303096757, 0.03977883584617127, 0.04055667172877058, 0.04814990923830098, 0.012737422160083249, 0.060625831115870714, 0.023398631132177772, 0.04537862447661258, 0.05747248681502477, 0.026523285440259406, 0.020960345638975985, 0.026023721420055917, 0.1245437718687519, 0.03972195381779344, 0.02848124912669582, 0.07076470601943231, 0.03378887480545429, 0.03668088736313005, 0.018983139739101453, 0.06781553564172599, 0.025205654430113016, 0.04133743406724065, 0.08628598444404141, 0.029957138580240072, 0.029873895466387756, 0.05610896139255455, 0.056553870785020055, 0.026243858700317722, 0.026078699719941905, 0.060785077812690894, 0.034369163425459016, 0.024905386268191283, 0.039397626664609685, 0.023362921858807246, 0.021706425261894063, 0.047257784528717886, 0.04516306265647854, 0.13228490648250427, 0.054788559059342073, 0.06438216705235743, 0.06089746291118284, 0.043213774915784604, 0.025953176213548552, 0.048839840362028736, 0.0014656567931993895, 0.04668934728890177, 0.09236320672977356, 0.09575535212793658, 0.21335830611567344, 0.1486539837693976, 0.2594338982335983, 0.1359712143218325, 0.18166072876943698, 0.15654153310723845, 0.13201000349175546, 0.11283777218552367, 0.1827614132555262, 0.11284500405552889, 0.09799212968397526, 0.1455793052070564, 0.11660728483430802, 0.11930108746333469, 0.10160804170394137, 0.18994157232584494, 0.12631395591362832, 0.13743145451430352, 0.21186699339699364, 0.19317178205857355, 0.09557204260941475, 0.12597186701192012, 0.13796051483481162, 0.13679376292613246, 0.12516123107484273, 0.14269152145472266, 0.21658212667511356, 0.0949130537769487, 0.07305014548042128, 0.0988451762485408, 0.19190209857638807, 0.11420208284811628, 0.07778981655475595, 0.21780281117366207, 0.20298072587578528, 0.13431615797021698, 0.19192508121411647, 0.1032981925433682, 0.10272600913360234, 0.13030702067959693, 0.13320228145007165, 0.29606644544870625, 0.1392737427546132, 0.14508055132483283, 0.09817254339014331, 0.18062854786553692, 0.12726144579749915, 0.15760890809037995, 0.11667517554615775, 0.09222247637808324, 0.11779827576491142, 0.12587668058732826, 0.14594531137376063, 0.23892547935247424, 0.1318940177800194, 0.20393334088786957, 0.10712837169487631, 0.10963260586703978, 0.14556922348997287, 0.21685793364961303, 0.10937854046783141, 0.11852831925235449, 0.1510084783958812, 0.1014312592545344, 0.11759769096369706, 0.10252596059393498, 0.14850729325365636, 0.22352030921366908, 0.06424993261574738, 0.1318782363687792, 0.17476586084212029, 0.09497539801222664, 0.11471336226790182, 0.14343922326882041, 0.09785558983323075, 0.11449445264353869, 0.0996793847110483, 0.17681983449766714, 0.09876349595405402, 0.15158264597337093, 0.13681642380693268, 0.14417843682871712, 0.13095320052196904, 0.09519579384716288, 0.20299747255781006, 0.12504225762020196, 0.2437680283741605, 0.15795767727878787, 0.21883984907500206, 0.17402048793531236, 0.08548873972388045, 0.07503613649356751, 0.08402083865216664, 0.1704207480314278, 0.13372786373140352, 0.1446571651726, 0.12744814908552554, 0.16043765710726862, 0.22628283759038295, 0.11848531873716463, 0.1612147154106248, 0.1290329398527261, 0.18365347667807536, 0.09492588574968039, 0.22313070753889702, 0.11923462167502412, 0.20818434745794345, 0.22085764805876443, 0.17825917581156378, 0.24186065330380396, 0.1213745044303998, 0.2495964712673618, 0.13930139852867973, 0.07520996950446598, 0.17667095297046248, 0.22864591240161852, 0.13207564190510782, 0.14148585227949007, 0.09657400134470194, 0.14063607691036117, 0.1822242783682962, 0.16157448562162538, 0.2608655020594597, 0.08366535087266276, 0.15014387156453826, 0.10843838970627516, 0.20122281455945587, 0.10513524840315504, 0.13464977393948263, 0.12901325139307207, 0.11224716436117889, 0.22917538640960572, 0.28032480949355715, 0.1572120285803272, 0.19360809977496826, 0.247129867334039, 0.09253586762614789, 0.08101805744151916, 0.10574299361436598, 0.16725829111472254, 0.19864112889814764, 0.08018211762030279, 0.09878232639523284, 0.13659010611234174, 0.17109124350451654, 0.21651454239843354, 0.18280604553799476, 0.2417435950689739, 0.13247978392868273, 0.11921739235760705, 0.2077166661019287, 0.08818550711317409, 0.12882145362034922, 0.12182593706154055, 0.12296866445291428, 0.1993976560451331, 0.15772529216783662, 0.1130488217477837, 0.22628688253462317, 0.120471945603288, 0.21583854641404845, 0.16577607952058315, 0.15868765181831776, 0.19835053642670955, 0.10009093480485101, 0.27959748561824527, 0.17810365996293484, 0.17022636088152088, 0.21036921489623286, 0.17670908882733316, 0.09565958347652229, 0.15265591983352939, 0.0985707022670296, 0.15747334117129927], [0.043723200402793386, 0.026246451907941414, 0.021281842097279527, 0.052028014850352085, 0.011928264772699726, 0.018058642069058075, 0.050336979179372715, 0.08565539449092843, 0.051934621071503054, 0.11245097439255446, 0.011886063861780831, 0.02491226382253151, 0.06265050190831385, 0.04360199380185335, 0.04418449258551963, 0.1235814352009085, 0.05978502280589554, 0.0766583966211446, 0.034897484471120184, 0.0510631041270831, 0.04990595513053479, 0.04130859851777073, 0.022665213027428237, 0.053486561988510435, 0.030681152955719063, 0.026920371794051705, 0.045012281231221654, 0.03315313674149013, 0.02413370207162394, 0.05244511908160583, 0.003328369775479059, 0.02115948061879364, 0.04785780757365208, 0.06743017043317519, 0.04376559570852307, 0.04602474686239035, 0.07752535534241507, 0.030612645543090282, 0.004733460495293502, 0.07176582971888204, 0.07500369266997423, 0.08202765407341142, 0.0902135716751218, 0.03223249823936532, 0.036670028066803376, 0.060874621999720414, 0.035923628602176905, 0.0846452309539722, 0.037342143815851984, 0.0221985352465943, 0.031126456883465572, 0.03688786133763291, 0.025614008022051667, 0.04201862795819198, 0.02621543875354673, 0.03219534680547734, 0.033909736666828394, 0.0633178104556376, 0.006645551794433907, 0.032351961990277615, 0.05558673074589141, 0.0388261710383719, 0.01989350883260129, 0.023056802700363824, 0.1084940383330949, 0.029192988858408028, 0.026324322830224713, 0.06717197582005494, 0.02375603604671215, 0.038460524932992075, 0.026121188871442314, 0.05258522124119824, 0.016480608197349696, 0.03740507027795238, 0.07304528082210211, 0.050668473085088116, 0.07486437192006458, 0.03464580543579594, 0.0605126109815413, 0.06696766783152858, 0.007161881648860271, 0.025743436661639044, 0.06633615857290645, 0.04658555769692025, 0.03867458905123415, 0.0215393070116519, 0.028303532050021236, 0.054264715797598326, 0.0317177331195243, 0.03292502640115638, 0.011021553749038328, 0.019131207297886574, 0.009964421361444459, 0.01145448535680771, 0.06480919212223062, 0.049170093205306804, 0.028858656596933163, 0.030422196085114154, 0.0525038703645189, 0.05292162577050829, 0.06644826021886642, 0.011614840965898288, 0.028201027570532698, 0.029420476752303304, 0.008630426713235436, 0.029669637273576473, 0.017543317705032327, 0.05762437906777186, 0.049090810766023014, 0.040169766683491974, 0.009564701580412446, 0.0695809776023511, 0.014362362637785415, 0.063944895556497, 0.0335800698808124, 0.04676825434510266, 0.05100564370232244, 0.03504711676449065, 0.04948729574079475, 0.047637181912338546, 0.0155716065707947, 0.06024058848138779, 0.03944718872287101, 0.03576031397847879, 0.05976423117963057, 0.03470688945643845, 0.04117227317164502, 0.04751237852859402, 0.03286796434211635, 0.03465238613106551, 0.07352616953393144, 0.06269673148410455, 0.03558023352055781, 0.017874170012111147, 0.03531417501489482, 0.03131021839386273, 0.005965480222291644, 0.03057290664723804, 0.01271773370042924, 0.014821808548614144, 0.06550914367600795, 0.05105758063314904, 0.07361095248451156, 0.07254924655200974, 0.10120473471620392, 0.050084648969312834, 0.019393427703048916, 0.0949118740015453, 0.04532170797427816, 0.03102033646897443, 0.04767011986264298, 0.05797777159680283, 0.029099043496253512, 0.008493296974789231, 0.09240186352643276, 0.06464694236074725, 0.033564070134513804, 0.05874507377044328, 0.04137994428615897, 0.024187605933196122, 0.02631811751803804, 0.008141241269186139, 0.03789718983875167, 0.01671196292004278, 0.012096249659906232, 0.0069124999196989645, 0.05041033209812257, 0.05427415783126509, 0.01946020184174901, 0.03505532156615969, 0.06272824834130945, 0.05859917998614331, 0.014298949709853098, 0.046424840111285455, 0.043412042301028006, 0.01780755866709496, 0.0467114910603531, 0.018836721184573347, 0.03962626943605081, 0.04873590138290198, 0.04958624748753444, 0.01743152823990151, 0.0713536284503437, 0.03901814118087773, 0.03419631866798286, 0.08462590255564259, 0.030310155726188136, 0.032492152249981324, 0.03901158729868551, 0.014529445456461081, 0.05286609588731682, 0.013197887925461177, 0.028562825999312827, 0.07551280406093405, 0.02734556591378585, 0.010647657834323905, 0.011708870597724474, 0.010474656986433172, 0.002602106453137352, 0.013596550505157682, 0.019379979029538173, 0.014017563700045069, 0.011746625325852826, 0.040895834174608035, 0.04616817001313452, 0.027788855030291507, 0.02511244068192619, 0.05967302458180536, 0.013798077594518903, 0.03937881537562898, 0.045453183983843175, 0.05978162520595136, 0.03197872586878798, 0.019770584279491056, 0.07811898155318153, 0.0776674263479729, 0.030859057723935095, 0.05310816818007058, 0.05277659766556275, 0.029779471299280564, 0.04022955218510282, 0.03315741534254724, 0.03997651334371298, 0.054690021000081496, 0.02816287256146391, 0.07484180296981528, 0.09092225663123593, 0.05798609131166051, 0.04112098741555407, 0.021606766799044226, 0.05019703406780478, 0.045333509558751706, 0.08085037611665265, 0.01942277461620829, 0.01627210204699828, 0.03738237109275595, 0.029189598919343085, 0.05105885999998258, 0.0011247304299162823, 0.03936737385247985, 0.09853053627715957, 0.07788655813783407, 0.045271559858754765, 0.0611465142649268, 0.07424451485877076, 0.027949051676137794, 0.01373453826207908, 0.026554978497686888, 0.018566039338287328, 0.022398815527858756, 0.03461849057085572, 0.048684125330539486, 0.06841140649011059, 0.05788418629597272, 0.018074080655952136, 0.0720870963508083, 0.031127274682324742, 0.03603162784730235, 0.016331952666082693, 0.03755101002752781, 0.07332580689821513, 0.005812053878476183, 0.023752245826706774, 0.015486340984822282, 0.09319075788821905, 0.05040930937074366, 0.019613059365280697, 0.022357343358077833, 0.055568605105602936, 0.0020976691561255365, 0.0637527492137686, 0.06063509694931488, 0.05360209570837118, 0.025602235165875287, 0.08352602246187388, 0.018797200623779528, 0.06069382908002985, 0.04246340328527074, 0.05336931606213893, 0.014344182413732334, 0.01611985547858621, 0.011558068105049673, 0.014527112718731647, 0.01978367863733682, 0.06274469241860413, 0.02451507021642981, 0.04566930504816194, 0.02993271761243382, 0.013212406249236197, 0.028445672003492236, 0.04994560784149555, 0.04333586634827718, 0.03993439382963604, 0.060256890832416476, 0.02260802647910051, 0.008823416710290457, 0.06558395982269319, 0.03899186436507491, 0.04467716756006403, 0.012943971913398035, 0.07465887649525559, 0.030432272056538253, 0.02482764941129473, 0.07724045490425441, 0.017312028099812807, 0.0438007514833683, 0.08210046306973504, 0.08326359138253235, 0.04489619209761581, 0.03190607009004922, 0.028012968306880326, 0.02125464023030814, 0.03505012749003307, 0.013954346124533445, 0.03129050503635118, 0.02452680285299017, 0.07298529613763094, 0.05125130511700146, 0.05697506975622908, 0.04395698362420644, 0.10081036031366357, 0.011884193649635682, 0.027668098506006985, 0.012178138713352384, 0.01919027459206841, 0.0349933450530854, 0.05901714989675149, 0.028795529036752643, 0.02775807936315335, 0.041023292053010196, 0.060181864011552066, 0.01551953461697145, 0.04254531340613481, 0.01750538294624177, 0.03347493963496339, 0.06612778265750216, 0.006972265311501801, 0.01939196447511354, 0.010477187949413014, 0.05543118042330589, 0.04534619214433817, 0.05564629791244384, 0.09006961609327024, 0.05313889213627385, 0.032453403522771214, 0.019897833398933855, 0.041387003786381216, 0.040719304534216086, 0.04154525839933946, 0.05415511542871114, 0.026961127671623425, 0.04494883382933275, 0.1923430587856039, 0.11522582912397002, 0.16058987877782316, 0.1795239256875169, 0.20498827460312075, 0.08419978913039931, 0.11305461337249126, 0.15694498565168152, 0.1602960840588616, 0.18039289922002824, 0.17981358353168736, 0.1598126059698482, 0.1505793006189408, 0.09944003586086536, 0.15347525086854735, 0.15670611943689086, 0.14347833971823418, 0.14596565866902952, 0.10965230964845228, 0.15181952035955845, 0.08678729705993207, 0.14576618469530536, 0.16469938890828242, 0.20015318727781697, 0.10564797572911748, 0.15487634907326392, 0.1394784720914979, 0.11518374791428929, 0.12668892530904663, 0.11416396231300409, 0.08198205652015825, 0.14812020434727594, 0.11959280608402145, 0.1403170625769323, 0.19899572035478008, 0.2159489243621788, 0.13150862958883086, 0.173207392855998, 0.20568952084549014, 0.1919494581318671, 0.11482126575203673, 0.20131361130024159, 0.09909003327089934, 0.23325195475932092, 0.11226366589506788, 0.18041398195970446, 0.12273667770768366, 0.22719742399790596, 0.1010856080439783, 0.22046611584242315, 0.1567830653080056, 0.1488408479358881, 0.14626215001748455, 0.16996650385760492, 0.16066397480185957, 0.15922734543921488, 0.17356690259710436, 0.12148476746534148, 0.12111729807070187, 0.15616189057548202, 0.17036457846481956, 0.12138473936506819, 0.09454036732354472, 0.12429015080053961, 0.20603372414986934, 0.18721834425964665, 0.15280035805077324, 0.16465173823939216, 0.13573254728990217, 0.12395658845742866, 0.12381396586856536, 0.18039990126365618, 0.1914995959809711, 0.10414844288701013, 0.09783899636879083, 0.15862343832850456, 0.09742600602969047, 0.17506815913704135, 0.10889379067286369, 0.22739993167981026, 0.16966368462289536, 0.15633260560852869, 0.2234602479204055, 0.17556139718621008, 0.30131028664688914, 0.21925808711638375, 0.10424059560342182, 0.09612694307560883, 0.1530226154793655, 0.13206364496821357, 0.11799679978960946, 0.07688902739074922, 0.1325681904751447, 0.1017004702120058, 0.19561520417130765, 0.17259354192403056, 0.14207071444440272, 0.10366641270417361, 0.1278688692517819, 0.12081132255374424, 0.20874691646425955, 0.10379271762024972, 0.13271809856016792, 0.15963150278454827, 0.12960197464112314, 0.08328648208970986, 0.18278756749726113, 0.23813211869808937, 0.1498700870621589, 0.09368365885870111, 0.15201237533361683, 0.28475347185327166, 0.13707373741894, 0.22552805712386487, 0.14551386597656435, 0.14828947913502494, 0.12729437991736398, 0.1945138914931205, 0.20834439854708411, 0.17500556975362763, 0.13314050411985767, 0.18456849209483595, 0.19894615446607913, 0.1628987452075366, 0.22278645826924234, 0.08550365545576619, 0.11575026227341545, 0.16276126306864525, 0.19186249183070278, 0.1542107259193736, 0.21948809735476973, 0.21657509398796868, 0.17866540159429276, 0.11593959324302212, 0.08049514880704303, 0.1615087705994806, 0.14700848819507709, 0.11453009871465546, 0.14051975411993844, 0.1468126607998725, 0.16710294380543694, 0.08328168637930386, 0.23383772090798427, 0.14860268652198777, 0.17935224538368566, 0.11891563032423297, 0.06668332663755264, 0.1988671095140519, 0.17230598316077264, 0.0966296346497632, 0.1463806944628877, 0.1307985580135738, 0.1187966721913507, 0.10646696202456953, 0.16841278561661321, 0.17046937929286113, 0.12363060272388882, 0.24988059795671896, 0.19757447403765496, 0.1919051476063267, 0.12049299769944723, 0.12263396063879614, 0.19613104181424265, 0.19429790066374888, 0.09951430808512435, 0.11986169528456465, 0.15320759506956225, 0.13379541736456657, 0.06231926464205308, 0.13915850780904293, 0.08288911994426482, 0.10847862464405837, 0.13576384964248828, 0.21768137091590514, 0.1545095768186354, 0.1521761496100695], [0.02633250847969565, 0.01174440845892194, 0.05967443035314641, 0.027745921547795017, 0.06436876817456176, 0.024195619212884097, 0.044254647087185614, 0.024771736484141122, 0.07826184162930136, 0.014207038311137548, 0.029904414494071278, 0.026297758731450287, 0.12058829903722772, 0.030317205650311325, 0.005180293726058858, 0.035035851441564105, 0.04791106217570844, 0.027018072902255004, 0.03649621803854262, 0.10932222534451755, 0.04082023661824004, 0.08822490701511984, 0.015837815421212827, 0.03311671309113022, 0.02767169528881148, 0.051211441731861526, 0.07581815138579377, 0.03365801932710794, 0.04265880933211696, 0.017439372980246143, 0.04408993052258607, 0.02389776805836347, 0.050330226114320184, 0.030216321446782643, 0.03482807307474075, 0.07517292149244778, 0.041991186688744256, 0.08415462058638373, 0.022855974666233507, 0.04625424765230668, 0.06030103281861352, 0.01154313417857573, 0.019213293618973226, 0.026685186631737218, 0.08057772542440123, 0.056607922118517666, 0.038816238708433606, 0.034486547247656894, 0.02128119475298351, 0.02681145898907656, 0.012146781777001679, 0.03978086597917061, 0.04769157798540208, 0.030070387442866643, 0.02828128102626051, 0.05278389465304152, 0.03901960057837348, 0.02200796321455029, 0.018504327125546914, 0.059029085546611786, 0.06060711175744092, 0.019014834711748748, 0.038155614278249206, 0.05069782957434655, 0.03201145506013305, 0.016205335569177425, 0.05325407345568942, 0.01944067234533929, 0.02462896450813259, 0.03789288442461722, 0.08317839474447312, 0.053636213434079004, 0.018777284252968048, 0.037577819274438005, 0.022183477788442568, 0.05133841314443177, 0.053144204956028736, 0.07938710221600148, 0.025154872376832272, 0.02701659626778095, 0.04939102147135043, 0.08562925557095198, 0.056318674131386706, 0.03372041335810096, 0.02462172497724814, 0.06015743729808639, 0.002004818701196552, 0.058156656957561934, 0.03279523195458516, 0.05518820797724109, 0.08034368556353354, 0.008393424964930502, 0.030480043384276574, 0.01895772668743326, 0.04570058824854993, 0.10993554767581726, 0.06044440234320299, 0.058586953222871795, 0.05752473018102108, 0.03397385439565105, 0.008973892657987533, 0.05695226714916288, 0.07046354153463918, 0.0038764925181655396, 0.0653511916677798, 0.016611574758445064, 0.073496307426643, 0.1050310068192982, 0.00900151108526775, 0.051348203748104074, 0.03556542121054184, 0.052931768774625756, 0.03428857097582471, 0.04474517701554202, 0.049531418574793686, 0.018074925267888654, 0.08562591542760212, 0.02711705720773147, 0.05371155435099237, 0.07020418246787402, 0.02384065237316874, 0.028794659526958585, 0.027392337496782986, 0.004848777316510677, 0.06093628441674575, 0.03475198905254084, 0.06982624831218874, 0.016815861679553505, 0.012875814985994612, 0.05057007675209353, 0.004487954213419148, 0.022326406812475576, 0.031743264914820754, 0.0519703169383349, 0.027850498295118733, 0.07771479356433116, 0.09507532652106979, 0.026777278061114976, 0.03551991175739996, 0.05996811398935895, 0.0888642993184828, 0.07248746922179576, 0.06578702674878222, 0.041619542114917314, 0.010620257742102108, 0.04170927399348828, 0.023992341612615896, 0.04684504699863253, 0.05502948988108866, 0.03961158353054235, 0.03992983560648657, 0.0882010433762785, 0.08562286639766348, 0.1063974625280788, 0.06203283585848347, 0.05623554593072303, 0.029445759569024368, 0.10852738614043883, 0.02615893593869142, 0.05423039888903018, 0.08465407926949763, 0.02582935150712729, 0.0891221262093994, 0.02374196875720255, 0.0036844893381179824, 0.04140689142889554, 0.029752123875603564, 0.059576413233674345, 0.030625058082683437, 0.010555647801788104, 0.02224283236559601, 0.00939667743119982, 0.05349507705578881, 0.052818521827219, 0.013977063504318077, 0.04079780939425673, 0.03172983922394774, 0.05146965166674026, 0.035527733515106866, 0.04568849938110479, 0.0989760930139211, 0.05113572160142565, 0.017916247391352252, 0.028477895576807282, 0.07312025784725144, 0.012744935567400629, 0.023685249522508636, 0.03164734113060179, 0.08148835881823495, 0.017785999037685896, 0.01600968533180534, 0.022913542343303565, 0.04910241699807587, 0.05486236396996726, 0.03026873718256191, 0.0036145905182967267, 0.05075352416644174, 0.04470790683802578, 0.03394511077673205, 0.06950996125177031, 0.02289696037018251, 0.050427902324665944, 0.011472431924043885, 0.02285503046286683, 0.013268549960376996, 0.007408843497790757, 0.015181754002227418, 0.03546390689969544, 0.037563991387404745, 0.04774865153576097, 0.022315352163728208, 0.05513673452960868, 0.012651785979077462, 0.037093996445858674, 0.047149582270292506, 0.01915244708558725, 0.032612857063330954, 0.022954876617258115, 0.015348899065546933, 0.01017223228700459, 0.023167757129657175, 0.060464703673196424, 0.010201470990244661, 0.04222043850008519, 0.020658752144945246, 0.01678893751945467, 0.024687150801201502, 0.029802689509045695, 0.06450327789230693, 0.02643090098225061, 0.023156030238756252, 0.056229784949532444, 0.08527210538065241, 0.026794698900513114, 0.05578959848912013, 0.03608238500272555, 0.11838735141340764, 0.07943973245639956, 0.051797996951086875, 0.021865869226354747, 0.058275749155830954, 0.0194602707896622, 0.08458404351145991, 0.03966551228997208, 0.07823371088072177, 0.024703334408601927, 0.04344241002634649, 0.05881633526915985, 0.05025201619813039, 0.02214333669643008, 0.0055731752147567615, 0.10070631791266704, 0.0175198313644937, 0.03975933890849833, 0.043608559175364436, 0.031170426499879653, 0.058198638575812506, 0.051420656513542905, 0.023728458796657866, 0.08195078481108913, 0.07539586073929265, 0.008231493129935718, 0.013609014755685725, 0.04256058153846572, 0.05374730384397892, 0.10488852212626128, 0.06046136352984656, 0.017568240460428982, 0.02610131655068648, 0.0631597780081774, 0.06099180663905798, 0.08634772346985918, 0.020012698707080657, 0.027768126606280287, 0.0619870774267662, 0.09810007913338561, 0.030187457169015563, 0.0736970454454422, 0.0625467621120474, 0.027002594095744917, 0.02245745189758318, 0.012169938699732865, 0.10450696437469414, 0.052941180164775545, 0.009055274178183848, 0.09782367461030522, 0.02436489400063311, 0.021599506200741858, 0.027688396005560795, 0.08612164326252476, 0.05237785273141438, 0.020332053949635838, 0.1785707897356441, 0.058505858985647086, 0.02213148340102165, 0.08168274596814187, 0.0110752584277502, 0.024371129956336755, 0.004630196152345068, 0.056772876170373736, 0.023369008427365653, 0.026238218377975207, 0.01255517463094645, 0.0027374576705868447, 0.05717702202438828, 0.024162501231917453, 0.03564216023791702, 0.07813035029797785, 0.012265096396027554, 0.08614329290726493, 0.0746096783287583, 0.08679013158525191, 0.04396057657657131, 0.030087264359838543, 0.04481342012783693, 0.06271566534715314, 0.0480690524883328, 0.02453407302739159, 0.012978114536963405, 0.03674251913663842, 0.05007732516875671, 0.044261423134875875, 0.08673013157902226, 0.07925291425518452, 0.05222371584104915, 0.019879228953692703, 0.07326404488975964, 0.05873578112392176, 0.0603764311921212, 0.0328461921233083, 0.08832508067209875, 0.0360202361198683, 0.01914483025640009, 0.0256725735286431, 0.03665548771800053, 0.010754991540565126, 0.06729176898877468, 0.03275048858936756, 0.04715398727585712, 0.026044264067745498, 0.02288158307032239, 0.05699048727570523, 0.04463488716752299, 0.019633186410271355, 0.04370717384341744, 0.0007035325360183996, 0.03449993846457332, 0.04802728920514065, 0.012848791234465617, 0.023167395153112953, 0.038800851832474434, 0.04916895939517887, 0.14458896802558055, 0.1789787928423574, 0.1312306775681434, 0.18758660272484828, 0.13757495810427975, 0.07936326155979788, 0.145716005936265, 0.16531337773607624, 0.1740532152114376, 0.10938969470800892, 0.11082044051539515, 0.18332882393752375, 0.16522334708321482, 0.13295887999476927, 0.09512287759852987, 0.09967957623302938, 0.2316095541802145, 0.15194198717513394, 0.12881938518295366, 0.14585780881104932, 0.11640073220816352, 0.15209974000050178, 0.12250541108510188, 0.12344436674949624, 0.18182589732591184, 0.344365286009927, 0.17820734230260696, 0.15139354483014153, 0.1273958635846934, 0.12391413952554427, 0.25863689100069387, 0.15309156339255073, 0.12296487231768909, 0.18791723095120924, 0.12178918016293358, 0.22134278089769427, 0.16958542108055086, 0.28069308328051723, 0.1527466093220057, 0.1234090654179454, 0.23520973841509513, 0.10643086396157743, 0.22473814386513927, 0.14465339602001254, 0.18311943678605944, 0.206111834474629, 0.16288187595144396, 0.16681959852576259, 0.11760385797148752, 0.1774556108660275, 0.10668961015800316, 0.16254161033899556, 0.10442834843190447, 0.08585858399108534, 0.17124662145731911, 0.09310546165872967, 0.21927751510614352, 0.08397579268221894, 0.16388453182674226, 0.19063456014039057, 0.34659640983708445, 0.1638594501081013, 0.10891658178861104, 0.11945907777595906, 0.10860230187855421, 0.11162871690166574, 0.13265642848226333, 0.11945171567100672, 0.1759635473811819, 0.07864845556116874, 0.14564187926871164, 0.24989657855081945, 0.11968420037338812, 0.15111255910127394, 0.18687743513334185, 0.2164286639421217, 0.19917264070001342, 0.10846147959631298, 0.2964656385442903, 0.11669481037965707, 0.17925778674262186, 0.149200817329749, 0.15179915774253108, 0.1649506810692049, 0.1444574154072231, 0.18584281806984257, 0.10900690355488371, 0.14456243073988345, 0.16281821404493627, 0.20107451525907363, 0.18863572949363341, 0.14228716492652893, 0.08594508297861585, 0.22132238763714993, 0.14475897825773687, 0.28158422739755723, 0.20600829003078325, 0.12490432348943527, 0.11994404973642481, 0.1670829795541302, 0.07063509926440255, 0.1850324349417802, 0.22554500298874997, 0.08866150818404653, 0.11051579033054652, 0.06347393917460596, 0.22960375213334638, 0.14300794641096748, 0.07280403207386694, 0.19172231306231793, 0.1393413576748102, 0.138235877478315, 0.10652481698461118, 0.1259098138900534, 0.14483989246429937, 0.07357118486036217, 0.2528256850857889, 0.19861935667933958, 0.11501114064406966, 0.11397515994406517, 0.12370315891119743, 0.09340024463111356, 0.18200756741627572, 0.1615442404703748, 0.16819031368340218, 0.15451045015886908, 0.17470368514618567, 0.14828572530419598, 0.14849368753212114, 0.14948161919751476, 0.15792724826643545, 0.17194645809790782, 0.10194848351661237, 0.13183532012326102, 0.17675474766762028, 0.14153603103853044, 0.2769139102630077, 0.21314708035319083, 0.1462119406149272, 0.18813280809310176, 0.10696846616244125, 0.16393988934015075, 0.16226632430428461, 0.10336657355148947, 0.1261936494659993, 0.17093396565366178, 0.2210014121186349, 0.17910951808575662, 0.12307803116498456, 0.1021372705637928, 0.20129360108365937, 0.1709662945640664, 0.16476868922191282, 0.15463279440037667, 0.1448592438452667, 0.09689496154145849, 0.09426400110486055, 0.17179000762201127, 0.08206919902154515, 0.14163196056840882, 0.17688412459627276, 0.10303177014594117, 0.21330881683576494, 0.11698884258587515, 0.09525478261733249, 0.10717657394707204, 0.1158866489065751, 0.24896161420451057, 0.15869499094063239, 0.11751586511250466, 0.10761194937531987, 0.07172875106334686, 0.19982165506770536, 0.13862961602787818, 0.06401627962928146, 0.13389883923434442], [0.08380666345117554, 0.004108999245574758, 0.047027341450654694, 0.022764473124557448, 0.06894488713794178, 0.04923716803351718, 0.00887452818137864, 0.08783060156049267, 0.07175868977942775, 0.036323492024694724, 0.040194124449044466, 0.053759561250767404, 0.04553133644343865, 0.0650675016485395, 0.039059046445594686, 0.06204546481791524, 0.033589780045252655, 0.00856980904861684, 0.029613046358609875, 0.03309933821700754, 0.056252587556598656, 0.06135358783085981, 0.026704547588803598, 0.04587630583574215, 0.02043322735135594, 0.02998259951240353, 0.022843811105215744, 0.05288925855570743, 0.04056966457996638, 0.06251557084221034, 0.02481524644780063, 0.02364349773063535, 0.06839403927686714, 0.0525226088751468, 0.023286994884631807, 0.0107701457173173, 0.053698186116713675, 0.02627933240165153, 0.06989342656226889, 0.04204897653131236, 0.05507231419605594, 0.05121909878066471, 0.030843760863307024, 0.029821837876713084, 0.049271029119770375, 0.04107450886118797, 0.04553781371683844, 0.031136894831433896, 0.03312964465529208, 0.0897663372058061, 0.05707612441432092, 0.020035135507163022, 0.014446072107661637, 0.035939643670233994, 0.04402465983143738, 0.006910870546445011, 0.046138989724098675, 0.07370258426113475, 0.058173212117605635, 0.049980966629640716, 0.04707207332455343, 0.032476075894890294, 0.007096746938318135, 0.025192678815895514, 0.023074635312021263, 0.05619880052343492, 0.009590875931955394, 0.017169169938912796, 0.022053510972088384, 0.0023016307292686358, 0.04188560445101992, 0.015416531222722223, 0.027046977399638104, 0.014561810756042121, 0.0286958878108811, 0.00710387107720899, 0.025868646071983442, 0.03495018748987106, 0.032099765845604485, 0.024927229350132328, 0.057539638252027576, 0.06339772491745892, 0.017690803036994992, 0.027299497216459245, 0.050679125537675236, 0.03211813854924854, 0.007403229988525592, 0.13101693903726916, 0.056703579687182946, 0.03819164339332812, 0.02343823979308288, 0.033281981239035245, 0.027305859576670394, 0.03700177861197341, 0.03849098841930109, 0.0638379228691901, 0.01788224266361325, 0.04847641974206894, 0.0635745992974168, 0.012286605272111634, 0.027632486908846808, 0.04850419425976373, 0.038619239198704886, 0.0674606147672861, 0.07521527083290201, 0.012846100350631582, 0.06796974914088365, 0.01920325212150572, 0.04198875819002429, 0.02216212691799287, 0.04404950406282179, 0.026756440469574545, 0.037458593010782235, 0.02679250788904967, 0.045359380347954656, 0.05511319264769555, 0.054148132537281325, 0.024370697116659536, 0.03608821876226895, 0.04860388911178997, 0.05882466264489678, 0.04981071124934862, 0.026442685329745856, 0.031554397428408265, 0.011309374897410313, 0.02596813982592956, 0.06396448825516048, 0.06750841099288195, 0.018405281533036503, 0.09278988706008082, 0.06372455717815508, 0.029135338826886112, 0.016027132984280826, 0.04127994682940264, 0.0369304022000682, 0.025949491330632762, 0.02871472974337878, 0.03635595117004649, 0.027569740477408615, 0.05912187028556101, 0.0644277646056106, 0.005362467998037896, 0.05786044523119927, 0.021954543903590213, 0.04889569966302765, 0.04825212068915848, 0.01829811349330891, 0.0638726074999619, 0.012528726402970572, 0.021909453883586873, 0.04117878108856179, 0.03508814077283587, 0.011168269162637093, 0.0493771820929983, 0.04140538989656395, 0.048003096148491874, 0.048222545864841634, 0.046821692808260845, 0.022642511927011996, 0.040821929672552694, 0.06501903126557028, 0.010818986695319896, 0.04014047148126749, 0.06435024416855266, 0.01971888866636061, 0.04615940213684113, 0.06210206339376108, 0.04081965439141758, 0.0632851138230293, 0.04505920028614421, 0.03588277696361465, 0.030824497582450993, 0.02380804575589155, 0.029793521351811868, 0.021727958078225775, 0.039455948938285156, 0.04806008159873947, 0.017469650690233516, 0.024186577460157777, 0.02412384443525826, 0.04289371870277871, 0.007890130575340723, 0.04309078716042061, 0.0434783510413141, 0.048399109979190176, 0.033181102781166, 0.012105892791653113, 0.07497457366797232, 0.026407424217811035, 0.04392853111869866, 0.012676957713049507, 0.05361241108227161, 0.051997011272056456, 0.01436299178749323, 0.010853038345944258, 0.035046752872726614, 0.05877267974879473, 0.11548106663770254, 0.02340559678662929, 0.023513257037848238, 0.030002741879152677, 0.019355709364096967, 0.07268229304181953, 0.022012954277376977, 0.03719836443422302, 0.03161016479885626, 0.008176447797356354, 0.017822206268207203, 0.017602869549826268, 0.028838998780796127, 0.08610295837805157, 0.07943953327353924, 0.05377473362210778, 0.08738397230063716, 0.07102369736399382, 0.011446716267645601, 0.019957348854551395, 0.02419636231817065, 0.01236222389589755, 0.02338686210644101, 0.04624444555731551, 0.02844044345340902, 0.1207725661656549, 0.025591906385436177, 0.017051332209619786, 0.08224829505648344, 0.05190225768714182, 0.03784187062973938, 0.010040421113972704, 0.028762022266164426, 0.03994599240080964, 0.02718667736307027, 0.026531291059068134, 0.03283883001835596, 0.02063985658629287, 0.04695074031910589, 0.017480184399192373, 0.05354086613102306, 0.01593693953773548, 0.07048611814576773, 0.03573806295471807, 0.03890724995383813, 0.047409171163434946, 0.010120664035991557, 0.07448817678396741, 0.028256005870418686, 0.029407893758146997, 0.03735286138591267, 0.01950015332700024, 0.028576651971126278, 0.020537151008724205, 0.04155257453901633, 0.04343833443858931, 0.027263355103411505, 0.07758276597146066, 0.05145842464820993, 0.046324792858814044, 0.020581999711031397, 0.03480333226522611, 0.027024906406539585, 0.020217705750837922, 0.033415157963792165, 0.02225482930249024, 0.09402377125356468, 0.004272544174455106, 0.017433324716083946, 0.044047224951247056, 0.023655057997412743, 0.014036225601880541, 0.04533920925290835, 0.021588376858421875, 0.0839526798095434, 0.09360136569387491, 0.04668680770743278, 0.029232857989207394, 0.04242620205566768, 0.02482985765973647, 0.010437928816123355, 0.061696802881816705, 0.050904654161704165, 0.023669021865052563, 0.06087509314379385, 0.015287425297672953, 0.06912152403064313, 0.051682298522322416, 0.03660457734499247, 0.01578282850283769, 0.03265796432031259, 0.05431751840777936, 0.0390619307666296, 0.05118197415985408, 0.06523351290173109, 0.09647437161014927, 0.05164913457608031, 0.01674154732045868, 0.01752076599176132, 0.04784494495740341, 0.05093358930260424, 0.07343063070889443, 0.09369754037188907, 0.030224639246420517, 0.014801046608256237, 0.07033241792551934, 0.027913623940079447, 0.03777455065339323, 0.025079330361838785, 0.040836515986630996, 0.021632622266488693, 0.044566291654782916, 0.07786660920828581, 0.10360658889816654, 0.021067751165960106, 0.0506216689433542, 0.04162359472003676, 0.06314406937529003, 0.06184324441898254, 0.08870778755555231, 0.032453353727056135, 0.04115055457899167, 0.02589567939961149, 0.020846719478046703, 0.060802433534615466, 0.07556107526104297, 0.044589936958565835, 0.01955770568231181, 0.053991950192158265, 0.013910648469332487, 0.01946707748086943, 0.014341213823025747, 0.011345298675399636, 0.09289468788812238, 0.048899886333533836, 0.10081132558444816, 0.008501729687615749, 0.042843298626042185, 0.027513827550255006, 0.04454063920063838, 0.05134315522868307, 0.07523244652416437, 0.06843725429667581, 0.014914128846759278, 0.034956676254589716, 0.06666304062931769, 0.056343671580355977, 0.06558288729959919, 0.058236406710479534, 0.02339971897703025, 0.06751928178052749, 0.03484580801018784, 0.048577842122364434, 0.025279930484811627, 0.04971542906376624, 0.16382918963509221, 0.10834145660121595, 0.10319548313535991, 0.1936671651539303, 0.1606710534542799, 0.11504933012709503, 0.18811884997112138, 0.20121227318961776, 0.15000764580984272, 0.19428077093776197, 0.07908138716893812, 0.16240310164228564, 0.18502279755569276, 0.12880150469080096, 0.12731447440361784, 0.20054277363083056, 0.1279835526140467, 0.08483286120838697, 0.08295819043151795, 0.24677464768530863, 0.14950774279573273, 0.14298329370156412, 0.16781074776043817, 0.17986716372111153, 0.1557941377283104, 0.11270980485865187, 0.17849735254722257, 0.16606694778367398, 0.10290383346258633, 0.17325371053190003, 0.11122502686996615, 0.12158415205175839, 0.12594395842883857, 0.11899553329473543, 0.12492996445226094, 0.1789219491183758, 0.10646393597726861, 0.17426559010580664, 0.19428749718973715, 0.154664387866374, 0.12709041666840354, 0.101465763854644, 0.0789762722448476, 0.11409609458379208, 0.18117119858582176, 0.17130269909337645, 0.18620713884311338, 0.1438506278059175, 0.12207686916113862, 0.18627965672602578, 0.27335708660464136, 0.16062377050759333, 0.10385899954745847, 0.1519778094464733, 0.16831707059135362, 0.0752311441746931, 0.12964761815965176, 0.15699999076464485, 0.1389507294422196, 0.17853964060064287, 0.20386351963445065, 0.11806656741687369, 0.09946036017349652, 0.14403629687524613, 0.05015838876246445, 0.11286363531384738, 0.16081742221309295, 0.0725290677960842, 0.20138931610891897, 0.097093784340447, 0.12331507409051543, 0.16078809636735147, 0.22867218921742133, 0.12278541622142639, 0.15372602208968134, 0.11112984810625354, 0.0921108803501533, 0.11322574975389628, 0.16414058905455375, 0.10290371088851845, 0.16595522152079692, 0.23100045299337757, 0.10947869880305183, 0.09013428157495876, 0.13450582601851033, 0.12420607265084983, 0.123854530224156, 0.24508062810186418, 0.121920227163261, 0.0998671605221687, 0.1114284385356211, 0.081269234689253, 0.10464227848475981, 0.16980962437247077, 0.150921925782196, 0.13000279184310667, 0.20580000604592985, 0.2415014959631428, 0.13371272583401975, 0.09711740283115257, 0.13594122964047617, 0.09952861860754991, 0.18762443214654925, 0.12198644014255655, 0.14474551043202802, 0.17776072836450993, 0.14485133781788812, 0.21870455794757415, 0.14572135322997648, 0.12332041372334766, 0.27092313333865137, 0.16760941985393726, 0.2559705985890281, 0.12047464223278147, 0.14879593986176676, 0.19597612351419466, 0.25915890331229857, 0.11138518521141623, 0.20657966904822858, 0.11658498401483221, 0.14607361577931913, 0.13484195475616764, 0.14633944828904447, 0.15229110876398702, 0.19726477533338532, 0.09002550475059018, 0.23346446754951633, 0.10962649248540403, 0.1407423026619419, 0.24858843745483508, 0.06895903678190324, 0.11331739685227794, 0.1543299598439086, 0.14835643521960706, 0.20211305469274524, 0.11649743548684544, 0.13518883936828183, 0.13936548944442503, 0.19776829428249793, 0.2100976673705924, 0.2038943316907652, 0.16035858151172439, 0.11892439437008674, 0.11974828362825418, 0.13338689331806478, 0.22425717854451752, 0.2615888729210823, 0.1329438187061779, 0.12312283964767573, 0.12806590706590684, 0.23500117863858902, 0.1453994584059523, 0.17808844545675864, 0.10829878550383354, 0.168897979742577, 0.1352263470330546, 0.23732602566240296, 0.1100003280706944, 0.14768102146204443, 0.19853502572063478, 0.21124983296519328, 0.17969284807482075, 0.1741069792619636, 0.18888334443251933, 0.06061063959233223, 0.15834565484716048, 0.19800599604364366, 0.1716272752251356, 0.17140797489593107, 0.18672371193045573, 0.07323316388553189, 0.13519694457852072, 0.10818109141602632, 0.10226134616400927, 0.1383653463375184, 0.2143355585154026], [0.04724272324012653, 0.020716099571737073, 0.06169584910235098, 0.02298435951102405, 0.022523996209905996, 0.02419035618884429, 0.049409962995278264, 0.05725838822282611, 0.028828578069806102, 0.021039074579734477, 0.032015978809325926, 0.055639920230474205, 0.05250126949601597, 0.05757472890939924, 0.027169122458285382, 0.023249755350632534, 0.09137309171379575, 0.00978361982326474, 0.01738137629393849, 0.016050830956608537, 0.009994626293079028, 0.04417520759987735, 0.05582169374270786, 0.08413601231070296, 0.031812963594171795, 0.049715363946292675, 0.023497400933035442, 0.0875050908014659, 0.007019210221891802, 0.0034139374873766136, 0.05340354487059578, 0.01366899848254698, 0.10046784240271776, 0.057851964637877486, 0.14172064290652353, 0.011352396480018094, 0.0778115734518055, 0.04597989624486335, 0.018215833735021374, 0.051943515352303946, 0.04385030971119001, 0.02986970305022213, 0.06961442500112519, 0.07245473428479127, 0.06902386314205586, 0.0017148400577078125, 0.017656097338805278, 0.012698249211685072, 0.033933684575341405, 0.073095444259384, 0.049181262767242814, 0.012923429265708454, 0.038687662341661995, 0.05234260885645786, 0.049203172881877234, 0.05819359388683112, 0.03772794186408001, 0.03344723406518179, 0.0661715492606163, 0.015594693588002797, 0.01778585348098028, 0.0579382682729873, 0.0637392392532239, 0.0331099255521211, 0.05536626213260236, 0.07087815598013901, 0.025845355083865505, 0.05224436957148775, 0.02396293149720277, 0.04091027493198072, 0.05413129775514526, 0.078732549032617, 0.040140417855112784, 0.017552460964408614, 0.027134437827513586, 0.02296120067307305, 0.06132869380376032, 0.03974027481050261, 0.051207925388289076, 0.03593999224023954, 0.087113979933483, 0.020540697995813626, 0.003054927858043342, 0.04611718686177366, 0.0347888876774138, 0.04668207711450035, 0.046036196046418724, 0.07434193059922227, 0.043613642168742035, 0.029038371247870308, 0.052297053438040524, 0.11601620203545017, 0.024274928465245232, 0.02192255781753169, 0.10059246192536048, 0.07314763782966523, 0.04501258383595175, 0.03692037793957899, 0.12347248217631733, 0.008109911145912784, 0.009505456170788216, 0.009096500242219098, 0.1018436290624161, 0.029908235357593627, 0.05007436040848975, 0.08721616840170276, 0.06378562970747871, 0.03398479413120978, 0.05700192879885436, 0.049120803108258594, 0.037528490872993585, 0.041957823559641845, 0.020167482941741907, 0.07931083816313937, 0.01935172762211052, 0.08085701043807692, 0.009464421628734038, 0.008573205690951118, 0.038961125087113156, 0.0486345173070027, 0.03071769151926762, 0.057901158973935156, 0.0357880195482604, 0.017770644720463503, 0.03225224798605327, 0.09120622244212898, 0.021398509627268202, 0.07357459395162522, 0.048939006613387216, 0.018234775258949208, 0.05845186127830417, 0.06436605622330982, 0.024222604660016876, 0.03652605716319334, 0.07822393559880796, 0.05045664211314532, 0.032357079457611806, 0.02048802370535991, 0.10699464338681391, 0.052603339220607476, 0.014890735394381469, 0.030352466762246146, 0.021060833392003854, 0.06664599517300245, 0.033936499948463136, 0.014091078454868929, 0.02923167246814457, 0.03861598332502669, 0.03476317010579571, 0.05962629704886387, 0.03280679605180218, 0.04532869852658722, 0.04260389998014416, 0.04850294553644715, 0.05949814203045061, 0.06923348011989748, 0.015484218921272025, 0.04465176408449489, 0.020172529545943105, 0.03758326615957964, 0.08692418931112175, 0.06005842809475238, 0.03129132858086978, 0.01573863672092557, 0.013268378548203938, 0.03400183192664578, 0.052632236057111335, 0.10460071821486759, 0.06255693192924223, 0.042573731437685995, 0.10185808514154727, 0.03513813567077441, 0.0028656450083344095, 0.061314233894189524, 0.03579679125499341, 0.041845733405000744, 0.01380763071093468, 0.02619388678501691, 0.08047865493403328, 0.027153093983689626, 0.03132743430474112, 0.030496179111181732, 0.028501525558831713, 0.07960940560986919, 0.031109168194234375, 0.04013113669991013, 0.043188287170543786, 0.03954557356454673, 0.02524481684480223, 0.010087780669451723, 0.03695655644180314, 0.06609176886418174, 0.020395386438336105, 0.030453745501055837, 0.001969386416491151, 0.012718271877196048, 0.05455495586859123, 0.053188074981012655, 0.0749998928738698, 0.02613956157508637, 0.04026443216829531, 0.04652821601578786, 0.10281900454673076, 0.04431310342624784, 0.03007863246415171, 0.07372790346703223, 0.0416051320010616, 0.04642233883421268, 0.03100284668166311, 0.014281796043618553, 0.04716477762427061, 0.03396952599887887, 0.036943222681481036, 0.022940972121432427, 0.05449236265473789, 0.06183057715515457, 0.050658226659100865, 0.015291789126011635, 0.11568555848733073, 0.06734794621626217, 0.012557509283895695, 0.031877031527279366, 0.06342454565568797, 0.015403808417519736, 0.023294885590251897, 0.006444967950829455, 0.013603861856785034, 0.061301206569037134, 0.0449083230998968, 0.0182977361950062, 0.039892216858964775, 0.0439222377064007, 0.00947046797767642, 0.053617057405532374, 0.013116058243829156, 0.027025373720173395, 0.027084703399469296, 0.02476799031419139, 0.07901824620221892, 0.08849971041443849, 0.03295498426943537, 0.055674796383227074, 0.05081774531713417, 0.074052877964512, 0.017031471380182815, 0.03240361929901185, 0.03608081069204115, 0.03154431188088511, 0.03450287641176293, 0.007152169569200206, 0.027302940781678886, 0.0601963660559587, 0.013938510129528662, 0.023182586676651434, 0.09717325830171186, 0.07295215517402658, 0.05428238561557186, 0.06262635481694052, 0.014885409168087909, 0.006292846350510035, 0.048418928673791314, 0.044511183119949796, 0.035752384968462496, 0.033111392610496095, 0.03897730869451358, 0.10606886443471718, 0.028545311314143965, 0.07585220399402803, 0.01658572695187984, 0.0429211369895887, 0.02393477202032603, 0.05922213970353046, 0.05245652996123799, 0.03649463606697898, 0.05846962685726824, 0.04555272178784494, 0.01578222520859732, 0.04345635665700801, 0.036782516587165096, 0.04007862903357994, 0.04946941141820243, 0.04843923383422437, 0.031465492924795516, 0.04850523613934075, 0.031216677143088276, 0.010498675758079177, 0.050084193146997885, 0.04111347209301688, 0.12218424404460577, 0.035454415070313605, 0.03912839655494017, 0.04417644866231469, 0.030408839342154326, 0.027948059592275854, 0.022162979190808632, 0.03832994524629847, 0.015407144730429978, 0.021927970228716735, 0.011832610076864161, 0.046430991797317425, 0.02847032662811539, 0.08640963869589953, 0.015798156964592636, 0.07425307972176422, 0.011343535715563884, 0.02348723494628024, 0.028348018775784203, 0.04551022306024548, 0.03623807705157707, 0.01611386850145796, 0.04018901847302914, 0.018749402482963858, 0.025321791444214124, 0.09720442275847159, 0.0912228542109651, 0.009420082374896494, 0.05522204991129618, 0.03287782389370184, 0.008074989985494364, 0.04569669269145497, 0.017627911048851187, 0.04869342180750063, 0.09477960892141828, 0.03288326311796423, 0.033856715721588944, 0.03775277077370594, 0.021972506750194777, 0.06724008869740271, 0.11057476377895764, 0.056175557415812254, 0.047643023332761186, 0.12558905287615715, 0.027343706235349662, 0.025938936554255988, 0.031550287366694504, 0.00437601967038767, 0.07716346306786423, 0.05777882622374643, 0.019027427282004107, 0.05257767144470446, 0.012575552569732312, 0.015114540320580766, 0.03983727303303538, 0.006573282411291956, 0.04054140359643967, 0.05335816948284065, 0.030283082178944064, 0.07336716798524703, 0.04062774936638532, 0.0731181740880974, 0.0568572377725955, 0.023944924600542556, 0.12933192864781426, 0.1297636345149048, 0.17409619274398974, 0.0990561645237669, 0.17583421641780486, 0.15660001625937803, 0.1897431555534563, 0.25751968965895716, 0.1379505097265205, 0.1481117160930749, 0.1536860169782754, 0.07961181112595143, 0.14151746106724586, 0.24371932050393474, 0.20242272275349787, 0.16119110458079847, 0.10220128487074569, 0.0695653340869373, 0.06679727455541011, 0.1596317938979595, 0.13554890069269365, 0.1884506886164027, 0.12763730385490965, 0.13453627035262125, 0.07656851152498877, 0.16029505750104306, 0.1452426248860936, 0.21970169798981762, 0.11994293124805536, 0.15816364767810992, 0.13673711838501115, 0.14760626660239312, 0.14245366647599206, 0.13294777171986719, 0.20346668608967336, 0.071793025840194, 0.10275507450944955, 0.11753362303058948, 0.11684707801548705, 0.1644233367856472, 0.18651550455439478, 0.10398501335012336, 0.2453680949345712, 0.17570103969304793, 0.18089159181521786, 0.08929988925134943, 0.15111052130739536, 0.09586265040261131, 0.08424888004458721, 0.11085607126475343, 0.0868447689760116, 0.16364436326248033, 0.1545286370861915, 0.13328831312396835, 0.13791094894611067, 0.13131894621877901, 0.09256659541279079, 0.12263563071047107, 0.1708130769792103, 0.11763190445039542, 0.11002734033090454, 0.11547793333809223, 0.18249754193088702, 0.16580036450778285, 0.1607828410041909, 0.2038907463992796, 0.1158075043631177, 0.10363293466188254, 0.16115471540439516, 0.07428678759043256, 0.19937209935197908, 0.09526740774632463, 0.07048984133307973, 0.1220956919414382, 0.1343221794213018, 0.11159495540684271, 0.15256049592168103, 0.14303690453450527, 0.11757408013387073, 0.13129472251861327, 0.13000113709319022, 0.16309737648454406, 0.1105204021798507, 0.11916074015560651, 0.10033754616855614, 0.12904490614610334, 0.1981788561228783, 0.13498121421904336, 0.09900325849171608, 0.23851687869718, 0.11936754559076602, 0.1848796463661617, 0.08331577729193435, 0.10394321559297462, 0.22932068264532476, 0.2072775751472481, 0.11452038471977558, 0.1202626733650123, 0.27875249063776386, 0.12758064399202987, 0.1148379588079068, 0.1325924601405859, 0.2995445765554905, 0.1036935628602101, 0.09741116690659717, 0.2730262285519031, 0.2050856443782968, 0.14215680740533337, 0.19013487163089937, 0.1366328691402751, 0.1619628921992356, 0.2659163810312748, 0.18574799170657513, 0.13899114824110462, 0.049690205618859305, 0.18152732221830278, 0.08641864022900982, 0.16772873038726469, 0.15057222196652045, 0.17377707115825147, 0.10994433470430875, 0.2057798579335213, 0.07813339932791649, 0.11481885257507525, 0.18980289508979167, 0.270308148596556, 0.11668392427025304, 0.165030446143881, 0.13999798695646948, 0.1165659926951893, 0.18868941693536698, 0.1821464131916723, 0.19194653167599635, 0.196460199151789, 0.11848046940060393, 0.0745638969144033, 0.20958581338486365, 0.1491095609362087, 0.2221488279681052, 0.14334467269720572, 0.12381684635916065, 0.13804041780531406, 0.08531707474180768, 0.21724664666239293, 0.10903610682655727, 0.13442520292535906, 0.14019087257404483, 0.18400987610220912, 0.12632983691629865, 0.11843164661718954, 0.13024862945800827, 0.15969901045243587, 0.20251281469339327, 0.1273602098526974, 0.17771845563284813, 0.24632352915021682, 0.07259834512707687, 0.07614868768160382, 0.14161337527536577, 0.09630386342084217, 0.22234753585390507, 0.23522843096044757, 0.07387114658711419, 0.11219259591833239, 0.14190174609182343, 0.14674046467388832, 0.1807400596237952, 0.15206056226405407, 0.198240939888262, 0.17783218904608683, 0.19278011194640593, 0.15024597576308638, 0.20800163548800255, 0.1289221022518412, 0.11903234381949711, 0.13354050926864147], [0.058062987387060165, 0.0185286829758796, 0.10875014918706111, 0.05324982166770966, 0.058738941236609415, 0.01066577102568361, 0.03832275934156872, 0.03367309210701816, 0.08764229714870454, 0.0021256225074701494, 0.011203841497791151, 0.0056199333912152205, 0.07388564097064157, 0.04369594299444749, 0.07837720680981874, 0.01766014228304548, 0.01126282356469141, 0.06404483938709864, 0.005350982424833122, 0.006031334576677652, 0.0285956988321437, 0.020500304094786127, 0.058488403672292355, 0.050840191693315585, 0.07597610339402192, 0.044895916305963075, 0.011689424413376519, 0.11428121206981522, 0.0587098184041679, 0.08257334616275565, 0.08031612938089717, 0.015570134724370174, 0.03417929619430535, 0.024062969173575123, 0.07728625930124715, 0.0634899121078272, 0.022991715870316953, 0.012749161499912941, 0.03482839483166895, 0.028172755095687126, 0.06386908732594983, 0.04933044689917757, 0.011061473633162679, 0.022630216215827295, 0.07954637189545939, 0.00929192831409314, 0.04043257314591639, 0.03611463730433776, 0.028926673713290406, 0.009220785559004834, 0.03256133765042309, 0.08743505504342818, 0.06546166154646105, 0.023666524418419408, 0.0332982759291847, 0.02269857041087122, 0.034959568236503875, 0.025757733777525927, 0.015867225536625954, 0.03068472867110564, 0.0306778128123692, 0.09581660851836206, 0.0537119718689111, 0.053153443976395556, 0.031283033763869636, 0.01761982882125003, 0.030161078846562776, 0.025929239796354406, 0.013587699316802525, 0.03576618604241841, 0.04651087561562177, 0.06644240730712492, 0.043613278276978, 0.07692419848735295, 0.058879008922245235, 0.02784245054147417, 0.04049916150829485, 0.02511318953287217, 0.05941573778287538, 0.04637766441690826, 0.0339825073587558, 0.037358185696986415, 0.03453526277876189, 0.07947888721020953, 0.04376588299149468, 0.015849488685959052, 0.03481286622944378, 0.029017692619574167, 0.018295453252991842, 0.10488810077790292, 0.028817303170780503, 0.04412631586854977, 0.050606481250255346, 0.03714086570506615, 0.052353824383669326, 0.041479845981924765, 0.023453984815146656, 0.019555319318427675, 0.08579456968413246, 0.027952732728613962, 0.04428812512947668, 0.07612379748494395, 0.008568781533188397, 0.011622056556535105, 0.010898397454330999, 0.03406993331267469, 0.037866416086833325, 0.11679486912344733, 0.05797016434371472, 0.06156674030447199, 0.02836051558504903, 0.04899873465840374, 0.0526607038843776, 0.06873876352103488, 0.027033515319588686, 0.018952159143443552, 0.04049382187546261, 0.08552767231219238, 0.011310114172257243, 0.03365815722293431, 0.01933192807970749, 0.0085982768758831, 0.0328381558609826, 0.057446639008459546, 0.023318977140250708, 0.03641233141083391, 0.05894165193181365, 0.008681891542378693, 0.032741778169668494, 0.03358796058643249, 0.059118016863301884, 0.04076493656142585, 0.06130622827538079, 0.0432702585784418, 0.01950468473707236, 0.016845068781666698, 0.05618031099138241, 0.13819588768866756, 0.05343776218773377, 0.11457393426568278, 0.011228629230191151, 0.025413760299523993, 0.02662796369423309, 0.01118090769816791, 0.0007221046619252453, 0.05444859222118413, 0.07128430515407555, 0.07284625884025328, 0.03180224602411111, 0.037244712753641995, 0.02162581366006165, 0.03581719983729624, 0.040934805067316185, 0.04625456940923487, 0.040938631676497965, 0.07000449398953108, 0.02635856696044005, 0.01754032230124839, 0.05731925007797057, 0.0552736689156342, 0.026495775222898494, 0.04089111507299446, 0.049950955135207024, 0.054020735945913105, 0.015327948476037672, 0.03995326640565069, 0.07624626430051942, 0.05504355142493883, 0.006635548601362615, 0.04624778570066537, 0.015525419129839828, 0.027327195125361605, 0.040212709742087516, 0.11425490461049542, 0.07847631560458292, 0.01606924771030824, 0.05583102852406521, 0.06485914871577295, 0.04104269706013222, 0.04321453334282964, 0.031608056141844684, 0.027885305499958418, 0.05106143022496855, 0.03404490138974882, 0.024554540981508555, 0.03384391439237422, 0.005324638097531973, 0.043821489483478575, 0.03498042881068203, 0.04450894997365052, 0.023173625363157164, 0.07273272460987491, 0.031723250867798924, 0.04341691078978681, 0.06163352018883152, 0.050687100512967, 0.023093366161769917, 0.022127155004249468, 0.08380994996837071, 0.02225204074244586, 0.03495832334362692, 0.06550800986588001, 0.04757492960761151, 0.12191320979787458, 0.03794006777987365, 0.05057119907090261, 0.011750329360966722, 0.08144294512608359, 0.0563013835269357, 0.04150627218487282, 0.009826397215346656, 0.04497034940868617, 0.03231928450986743, 0.02545193063035127, 0.03251786982159942, 0.0012093800333170823, 0.04728277048636829, 0.02256260321085011, 0.07704347837716341, 0.046984750792504325, 0.02818893295742812, 0.040908677638658596, 0.07654874645654233, 0.07288431042745229, 0.048287008333230214, 0.0034476005877818795, 0.04063279405536671, 0.054931419135461894, 0.028188653335335757, 0.003758038566898435, 0.06727761168393397, 0.07660998752520931, 0.03386886204562841, 0.03277230677345107, 0.10594648954969262, 0.026606268084217465, 0.0070804795400509915, 0.04071046771000951, 0.033295575469251604, 0.026833660217122208, 0.05199095917745464, 0.04034943345393385, 0.0036053936327657397, 0.02324199104951995, 0.012470580329517684, 0.04457351203346926, 0.0193791076045243, 0.044564709683219274, 0.032226250792342814, 0.049716470943343256, 0.03682681945182624, 0.07985717376633998, 0.02442998083067998, 0.04268488696505947, 0.05136200865249961, 0.036382821703990625, 0.011188251608532044, 0.03449269127280962, 0.02504886496030996, 0.08047312377921997, 0.013058400551427998, 0.03398866670566701, 0.021818038526802294, 0.06718113057075009, 0.049416087868232886, 0.029961470807451877, 0.03263455267334658, 0.027972074533482234, 0.028983626604801225, 0.03209914531438582, 0.061610395824837114, 0.004194673252171807, 0.03948714020812223, 0.022171990300017982, 0.07210025008046819, 0.037469513594142856, 0.06289563855276474, 0.023662502456816937, 0.017613368784828533, 0.0246105860588291, 0.033660022647029934, 0.05893532787599872, 0.055509321391582496, 0.04164198466065911, 0.015387837399518298, 0.022251751544254444, 0.03609804767033747, 0.08530680916362232, 0.04023139079612109, 0.04186667441841095, 0.03552779097170119, 0.04793874859329193, 0.03576570340702611, 0.04769814718935279, 0.04438266420977251, 0.044775211492613445, 0.03128985194639573, 0.0823903200967658, 0.02291323399291404, 0.014844672442714294, 0.06363831866051882, 0.04257476948682339, 0.06975577588403417, 0.018748349112067974, 0.04304180349854212, 0.08665078785270454, 0.07576830204456084, 0.04577389520202433, 0.01289752974820834, 0.05737787878681576, 0.05534020365185796, 0.06460389588028193, 0.05236500160648458, 0.038835934828966856, 0.06259906676507766, 0.04788796079435176, 0.020695288793273994, 0.014049172487800882, 0.033662504771904606, 0.03075497893376216, 0.034613549303744114, 0.04104044476163484, 0.021269709179778735, 0.08428099445037304, 0.0076932579489244575, 0.0163031573362288, 0.023595990703230905, 0.07926914765830002, 0.0331593229014787, 0.0345830321912804, 0.039931049855846557, 0.03635001015819369, 0.08388154088489472, 0.022667373395374706, 0.014734221716231156, 0.015807625811336743, 0.04398246753900763, 0.030261480414699164, 0.034521274013264526, 0.016358897893599445, 0.03991249520632048, 0.07942538362957778, 0.016715841240159447, 0.06716564027292114, 0.017485987515218796, 0.04571251240709136, 0.047140772259163286, 0.050374624739971854, 0.04485953479043899, 0.05536371489025413, 0.01815270042918142, 0.03137560208298026, 0.22764288880411657, 0.1273932512248716, 0.17156316898763183, 0.17385686687644453, 0.13886964669631374, 0.12387490816294186, 0.11356493518237146, 0.14882431575848212, 0.15493676276697269, 0.10154037315758968, 0.13412233772537402, 0.12839758483272407, 0.15438910183166304, 0.1439100609070832, 0.12502704311402577, 0.1425331557590154, 0.12749173182753787, 0.17694985494017604, 0.11152616837212156, 0.17380465032352557, 0.09402484377665866, 0.15468709471244968, 0.18074750599841918, 0.10100529904687598, 0.1552509354247201, 0.13005735262507392, 0.09851100103509042, 0.27754075404617096, 0.17692636668441758, 0.20869719735797376, 0.1383459643130341, 0.12102214995050624, 0.22327022747166697, 0.1964567977214052, 0.17046807694338983, 0.18589387016911663, 0.11419491992602426, 0.20766037396125256, 0.15872954150601742, 0.13120049370392678, 0.23187953888648943, 0.1421319708348282, 0.09783960923913027, 0.14609955551643528, 0.24268759925278927, 0.24870154267597586, 0.16701443000666558, 0.2131808648306516, 0.21056853565237216, 0.06337757680505034, 0.13198564189576334, 0.1970450613167017, 0.2566476517747487, 0.10869683712841043, 0.17060378175829688, 0.20084065925930777, 0.1159102903799184, 0.18004166322850412, 0.13332834887889125, 0.15336413747600972, 0.2022221302914043, 0.13915138319134712, 0.21857286743339033, 0.10498828209576108, 0.11486815799388195, 0.1425480791517804, 0.06275934768059561, 0.08096962536294615, 0.11443867378177182, 0.08304839728460198, 0.1503010881283591, 0.11131438336545423, 0.13161012091703955, 0.26548780080291534, 0.17133354179320798, 0.20254733461526134, 0.10812098415748728, 0.09328877883813075, 0.16551292831859282, 0.21215351028067453, 0.12116547734025987, 0.1134727365006843, 0.13737864041280362, 0.22404261263868502, 0.12833792190518112, 0.07912794233209665, 0.14526606717657659, 0.1585049092048599, 0.09277893966364284, 0.16500841345517867, 0.12806644332745384, 0.12503189245058646, 0.17621557498651166, 0.1132610817289641, 0.13659222051501274, 0.1294103760512606, 0.1620932037551557, 0.1790466222671732, 0.15286475540168826, 0.1981692800238248, 0.10531626731878328, 0.14298887082165287, 0.06960222888137065, 0.1837448862892005, 0.11318370684861176, 0.17942388992636435, 0.12107658815840561, 0.22319582501246085, 0.13999452423905173, 0.13426423253070924, 0.17725913995696654, 0.1952339834984272, 0.19967649672781268, 0.1905326398029443, 0.10024412940706938, 0.14412261966255405, 0.1527541935924561, 0.17945680106359144, 0.09111333428130997, 0.09160876334194215, 0.16228181460211355, 0.12952519730935175, 0.11284475124651387, 0.21516449629299103, 0.23313627548275456, 0.11681816585722471, 0.1753189456799338, 0.08936345922730624, 0.09185098502184115, 0.28501912050189515, 0.18106471236434676, 0.1676928315071329, 0.12120815609852154, 0.14508969841464875, 0.14436220599999353, 0.12257040598459783, 0.1584206854984645, 0.2511921711266041, 0.13008586641761566, 0.12652235481167032, 0.1263522373272046, 0.08467612727995842, 0.10822471246243485, 0.10698357341630806, 0.08148363971662137, 0.129787904180346, 0.1607150422228921, 0.135004993588213, 0.12535124386270202, 0.10526609622062215, 0.0838583437425475, 0.2021349954508966, 0.14625808975148588, 0.17235499746616811, 0.21385542056973905, 0.19117805355739212, 0.1550042704348603, 0.0944794403509267, 0.08836977424160128, 0.0934593329927133, 0.11181081600126722, 0.12478768660296356, 0.1306289155036211, 0.15874277950534899, 0.18061101977382937, 0.15395350423791718, 0.13475782298032316, 0.13694327264543504, 0.10640701564449458, 0.13974059673566974, 0.14372600062239554, 0.20707047093779812, 0.16338098223411268, 0.2538230396326511, 0.129667597732717, 0.11490663859031855], [0.02559535952675487, 0.04153017795855, 0.023712346052390434, 0.008822834483468005, 0.05233833025540075, 0.025781438453122977, 0.018697356384608056, 0.026923598939432736, 0.06860751733784715, 0.022848181636823763, 0.03646372824967389, 0.04181124412664964, 0.10158114435691988, 0.04868668406420658, 0.021004543166547533, 0.01073568804009307, 0.12801500052333842, 0.03330597128238409, 0.03460119996640471, 0.03742492727694973, 0.010981061214190579, 0.053379133478888584, 0.019528201721127958, 0.040577248850416754, 0.04196607049614672, 0.027517646498557542, 0.026386107821317933, 0.004686404023349526, 0.017781605523440148, 0.07160702735305795, 0.061180268098870595, 0.06503501185967077, 0.03350041205844572, 0.04409035953182367, 0.021323139982057676, 0.015037808954084833, 0.05875411743838942, 0.0698682988783525, 0.056632157310002276, 0.016759178834035993, 0.05345509875746024, 0.04752433333065241, 0.03858063985864001, 0.024846182993402886, 0.09651816119590113, 0.04117645218127197, 0.1081048426849227, 0.038782063526131456, 0.08000849145314387, 0.029286344332860845, 0.08268782268128089, 0.048395915392545924, 0.03044425558689381, 0.08620269536491364, 0.019815877312794328, 0.02326139797186179, 0.056178326823658524, 0.028053691625715266, 0.05502449498782235, 0.09926270948903215, 0.04895914706491655, 0.08344027424050916, 0.06884599284779641, 0.040253737580872355, 0.052770491944806236, 0.03238892190218453, 0.03863464522686216, 0.035959558125825665, 0.025589207840722897, 0.028312658072419228, 0.048605877109953476, 0.02147329513043646, 0.0391198470137052, 0.011650722609051775, 0.038542082653410976, 0.014907191920604919, 0.02870776025848764, 0.04920598059411972, 0.03137540098490014, 0.04727658049594011, 0.015201607170785147, 0.059112665739150784, 0.020486669644953746, 0.07111399614762876, 0.0336068982799207, 0.00880010752758432, 0.017624239572474075, 0.03382963451346563, 0.05391539502588492, 0.06596117385572965, 0.0588845324161793, 0.05934026663101489, 0.012779583808996025, 0.04007925339523823, 0.023227935251329216, 0.05353027113503026, 0.045519006258297356, 0.0850415665415987, 0.07854679569361672, 0.04435775103047491, 0.0665314267239263, 0.019607564599643794, 0.03247336011319872, 0.04277495592231712, 0.03090064289168485, 0.009644287582036228, 0.05521426262754587, 0.03298447099364093, 0.029844389589984092, 0.047029245179146535, 0.03472885702766719, 0.046915381530960726, 0.1117861326483469, 0.08519841538321588, 0.022438064127439455, 0.025890345512438687, 0.022548219910071745, 0.0332730065190023, 0.0920638655342402, 0.04170784140906988, 0.0055196979683974105, 0.04980774265864203, 0.02917912266697855, 0.07279298508599882, 0.043870955780749364, 0.014748350292774699, 0.08709927870621605, 0.07724923427186667, 0.050878446293814536, 0.04379576425098124, 0.010707128282275893, 0.04407809446415594, 0.05639226070695347, 0.06546683263994994, 0.027781473773141063, 0.01223256351471308, 0.0679209876445032, 0.03421415702529973, 0.04794460533547306, 0.04588266053507405, 0.10226310050535588, 0.05150886770758418, 0.0673275682774763, 0.04090978080526956, 0.046651839624129, 0.017123405761536092, 0.02971351495943964, 0.039503212732773636, 0.1092523811084609, 0.015683554999169805, 0.05079676216888813, 0.03769256392373674, 0.020066738549259402, 0.060758839301284284, 0.03905383704770957, 0.012588735027689368, 0.03264854909972318, 0.038722377615950765, 0.014653890694101012, 0.027256151961703456, 0.04038875674708717, 0.03540106087682709, 0.05924280875572755, 0.035510806802419886, 0.056726891742718805, 0.03160299038544538, 0.017209803242416635, 0.02740030098075588, 0.02989150208210753, 0.028887451926787055, 0.027586291807012695, 0.028479025556495594, 0.027083830059235616, 0.023648264712744185, 0.013050280019430625, 0.04589291079150093, 0.06570166157137963, 0.03349488856451165, 0.0168643263168633, 0.03597529740223, 0.021643171297206033, 0.05539284155313527, 0.010198156702362243, 0.014773836122795701, 0.022139904622529304, 0.009872410371298752, 0.042530405335128314, 0.017370501675853328, 0.06489547660514232, 0.056358323011907845, 0.06079285743556196, 0.023074317385532686, 0.04335653157003465, 0.046190386562938654, 0.018663539348410505, 0.014030394715166861, 0.06634041802176545, 0.04508202204540853, 0.025594641319325855, 0.025882927866111842, 0.035538213597911025, 0.02012226268679144, 0.047593154839330146, 0.031964938201370745, 0.01712864771815798, 0.13394161758403625, 0.03858760359787172, 0.043384451644435044, 0.045767762668190465, 0.03722927991240736, 0.0885850296265656, 0.1022223522886634, 0.03769915994076479, 0.0761826177157702, 0.047494360140614936, 0.020712500873712764, 0.02558271907600424, 0.017288296611138412, 0.07839884879367967, 0.05064360587106598, 0.0138899794171354, 0.008302065149520435, 0.11461049198142945, 0.07446134838485911, 0.033058923248562126, 0.05560418988968577, 0.041276572212096185, 0.015139811645982968, 0.054832620606307066, 0.040090890270808054, 0.06266870032695514, 0.028990858474806435, 0.04306403537010474, 0.011827356628923407, 0.022015352132579973, 0.052850184241129514, 0.005987989321921862, 0.054425977305659366, 0.01693657223856257, 0.007122898786028307, 0.049216774772972836, 0.054720147407703826, 0.0323076821082542, 0.06125136488868345, 0.023627009603285024, 0.0553154781641018, 0.07670733431774764, 0.03530719595390462, 0.025980688346129273, 0.02848389596047421, 0.010498834721323465, 0.04958748088909253, 0.038670478989520383, 0.04930227018532254, 0.0138409411714923, 0.06664678424356446, 0.02056826950020848, 0.05849452471480735, 0.02923331764196196, 0.02550506074311993, 0.05867505333416405, 0.05957905240657349, 0.012676274937186992, 0.006869184350850242, 0.026467150347607753, 0.030470955666274797, 0.11390362265369586, 0.009297341682888087, 0.12935066715844218, 0.057617078249853466, 0.018149360285831556, 0.07828350659580001, 0.07939015890681937, 0.06922080902562988, 0.06818118174710582, 0.09168808408562215, 0.03212720711505221, 0.030836270438627373, 0.02341313892224383, 0.017781975160863613, 0.014939760233485892, 0.03022472926175162, 0.042398841225452004, 0.04125630918649897, 0.043423667685278965, 0.010978535039260263, 0.05928479420441774, 0.08686788950956638, 0.06402271093740579, 0.006092791586378289, 0.03918971040195996, 0.06140432583408491, 0.035049112423533396, 0.031965962843969464, 0.06469071662474064, 0.050846638323198405, 0.014265761823363364, 0.016783253147056507, 0.016033372770424093, 0.05278018295704838, 0.026702582573277817, 0.024400624341421553, 0.0399228259019794, 0.0031717124558429447, 0.032629795267336795, 0.06494285148237983, 0.033738201919702754, 0.041147256570477644, 0.07951576668288439, 0.07087153698047323, 0.013738479784449503, 0.05427002095647397, 0.027349561062310974, 0.0753383505188169, 0.005404892032064739, 0.05372741237102498, 0.09162429194416731, 0.008848761771655372, 0.02300773859925328, 0.02767052125906752, 0.03262597248859463, 0.0386113140191282, 0.06344198564728422, 0.03416170298512425, 0.038203249625380964, 0.03950008326360295, 0.0541846749312695, 0.03045323222214657, 0.02274964932322262, 0.03346100449562073, 0.019854051474061225, 0.02766029973093781, 0.005596970863294818, 0.05230765992535218, 0.012257104183757498, 0.05337196289591732, 0.012312079610813771, 0.006843668356117222, 0.024561918408219374, 0.027502659903538805, 0.048051639309813904, 0.030371933056402112, 0.05576632856842011, 0.05887057046375929, 0.01217952341727552, 0.019599285104402134, 0.044173441767211885, 0.04123842486390664, 0.03355150246211598, 0.04554427949891937, 0.07696064895079022, 0.050916091854413675, 0.09482676929403698, 0.1251542443529733, 0.12371592193601594, 0.20707589484030203, 0.18113202084937405, 0.15681632884567784, 0.12899198479229404, 0.13756234829704608, 0.16734450664972106, 0.08077191339144785, 0.07490662932996789, 0.14099647531345968, 0.2835609181033027, 0.17535947173112826, 0.22873199004079067, 0.1026548395654367, 0.2926385084227208, 0.12943436992504906, 0.21403612538931832, 0.10199844777103394, 0.15847762115299702, 0.1289092166529548, 0.1453389987469681, 0.2043489589085502, 0.14785196632146835, 0.12087608762686292, 0.19383135311786207, 0.0707969889645615, 0.11264775173678515, 0.20209102200404291, 0.14523318668286647, 0.19117877368004094, 0.11853375081573764, 0.10228941562555491, 0.12709566437068487, 0.1892379358891518, 0.1444952141854071, 0.18062272559731238, 0.21047131909478098, 0.07847248516496151, 0.09567024742042828, 0.15978953140156885, 0.15637668630769178, 0.12192324554968266, 0.3314613623003806, 0.09501933315468412, 0.2127869270982281, 0.11405984330321513, 0.24595776813164835, 0.0992168821094017, 0.11002386229172831, 0.11794181765928385, 0.3177795835560368, 0.13971693994056794, 0.19248495359093915, 0.14787234426025422, 0.12736050862698786, 0.11819220583645568, 0.22029005351566502, 0.11762874050726814, 0.1290882820443761, 0.13839798168309275, 0.1421679616455109, 0.14160519345633446, 0.13499511105398979, 0.1204902551046783, 0.13276236312043282, 0.20413906613905586, 0.1539972172148766, 0.09173378123030548, 0.2106151291199269, 0.07963568242567201, 0.10390649699876386, 0.16611363318177963, 0.12501778111102121, 0.09285544886464074, 0.10438271257425509, 0.10158726539943488, 0.11699393707057161, 0.10554637714859941, 0.08684216427706903, 0.1692476529147356, 0.12415556447400201, 0.12244928748376908, 0.1479737283361535, 0.15286925999868303, 0.07429454806110553, 0.1083372048132362, 0.11339323189590247, 0.17170823539697355, 0.20706045050774852, 0.16705711642580648, 0.17010510448486577, 0.1783499725523495, 0.07129139912825438, 0.19322094958155386, 0.18505696507711566, 0.1834716533701266, 0.15657148714507782, 0.2038483510935499, 0.18246823140690405, 0.16735339326964271, 0.1133329407762616, 0.09924670591229394, 0.09439422073022974, 0.12842236777707455, 0.11023584648125595, 0.10546635926490831, 0.1371198405902232, 0.11464325756195093, 0.22087021190072262, 0.1665027292385217, 0.19798207877864762, 0.14501122036768546, 0.07642714532032129, 0.15382288624682736, 0.1412728491930231, 0.11296730999264026, 0.2036878863169301, 0.1337305450391385, 0.0762465630748099, 0.16282757563937098, 0.11177180680416285, 0.17454752578370034, 0.13534394152943166, 0.17962011568728956, 0.15000517900672652, 0.15226647137634217, 0.09825656791367839, 0.24075642949150455, 0.11803949386962961, 0.11171696256966361, 0.18626994273114592, 0.1846645748422992, 0.1294408203853715, 0.15840859663101936, 0.07445164971173772, 0.186853303363727, 0.11316399540632002, 0.16382275449652828, 0.22869460495008578, 0.09486722639731823, 0.2956443616459447, 0.09839798008362133, 0.12292113635809192, 0.13746315523261024, 0.17179458882779847, 0.13864679171914054, 0.16971055388210282, 0.1634377187057849, 0.12288985698814354, 0.21869240779309504, 0.2315242732724836, 0.15120136401345655, 0.10266679819793471, 0.11348507051626522, 0.1384904638173119, 0.12803765374325937, 0.06076711305086652, 0.16920210132675786, 0.09652812799979603, 0.12973941081473905, 0.11109345126897098, 0.15781023599688085, 0.15264407611422, 0.10758987072134212, 0.1258430416665731, 0.14015485111984516, 0.061442810260961135, 0.09203357441771416, 0.12049279851658691, 0.08967491227292246, 0.1568224575490721, 0.09377339839815133, 0.18343422231414627, 0.1578751542875844], [0.05033516738143179, 0.033525206494115056, 0.02245069500209103, 0.021878421576994083, 0.04621476348068926, 0.03240230545822171, 0.027273727933906262, 0.015165255341168134, 0.08258100704199846, 0.08177818520174873, 0.03600130991769895, 0.016377444882246277, 0.006957425709603535, 0.04257087776016805, 0.01764078324119891, 0.02056160645048705, 0.012292681306961083, 0.08425630343657348, 0.0357938533078038, 0.09817965268608063, 0.028026135443078897, 0.0673653670556603, 0.04473578860802997, 0.025149011804211526, 0.0215936073237249, 0.03528016837193601, 0.024364761850466172, 0.02369665274126155, 0.04127944504181224, 0.02186210581942672, 0.012498000531547494, 0.020313441843515443, 0.045064708458319794, 0.06682195790833043, 0.053717993319995945, 0.019723017880272482, 0.10171055192908934, 0.04797361325472594, 0.06202315633756019, 0.04686409194443015, 0.06260643653090923, 0.007046466672627797, 0.01764760716938444, 0.03148218215022597, 0.11842845969142453, 0.039306496675576896, 0.04004038592439987, 0.031590639132886164, 0.043737089576860594, 0.019332136838666854, 0.08965386783764248, 0.02409049279747471, 0.03138057590882865, 0.03080256256995903, 0.027180044956865813, 0.02296357937607794, 0.03921841571648275, 0.05752509024234549, 0.03128525733406986, 0.03327418246396607, 0.06274446642266647, 0.033780949625877604, 0.02293349701851126, 0.035156510289638274, 0.020385385160484625, 0.022422577660050125, 0.053236962881900614, 0.06036196745211079, 0.07073224687408056, 0.012869890253510208, 0.09486173354690114, 0.023172384300719828, 0.04282665153544757, 0.009470352106877874, 0.07208000237662947, 0.04518738977851407, 0.01383737407459487, 0.05379672417597425, 0.033830308670839, 0.06287577006244852, 0.03870332883971353, 0.012271840842590939, 0.0721514553973271, 0.03863580585006745, 0.04140435184742655, 0.024118236671652526, 0.009765623460313486, 0.05278437728843382, 0.021720356570797104, 0.025412837163575237, 0.07776587630712217, 0.07317432067206792, 0.01809042897225628, 0.03326898072696021, 0.04168839809755164, 0.011871367422563416, 0.037014020697003415, 0.006432870464895162, 0.020650166214533874, 0.041984016105772994, 0.03054307709868637, 0.0051839723845102615, 0.005680394486614293, 0.022832576425806172, 0.024787561945436944, 0.06675354625669218, 0.06628251709644833, 0.08682409226293526, 0.04794583873703115, 0.021584255305389245, 0.037865025637250756, 0.034718890223772295, 0.0427211880413515, 0.06970634023028036, 0.022745895492393645, 0.07425710934424594, 0.059009760978721806, 0.0570343304876118, 0.0302656383569082, 0.027618327688786293, 0.03573212194286528, 0.0059140249692474405, 0.04545532903003116, 0.06174976637046184, 0.01745408569883195, 0.06495415127926296, 0.009079898159290034, 0.044878499297004555, 0.05077738397484345, 0.013851665444822322, 0.02120982983239716, 0.028525245556187247, 0.03146468853247503, 0.032298201770191236, 0.0702113913552415, 0.016755955519094583, 0.14471045424861295, 0.0553024661607079, 0.02460405132883499, 0.028461156555661754, 0.043357519823456966, 0.03963535523883278, 0.030436713451279268, 0.00845512185591243, 0.06403072038665414, 0.03489280367390283, 0.015095041467688017, 0.031537777150891004, 0.05263435812066159, 0.09065341339596818, 0.04152469276901215, 0.037263991356256514, 0.04773162906208346, 0.038330182733555, 0.025964498993069417, 0.057490654590149085, 0.023415287798871438, 0.0373512028055566, 0.0414190913790897, 0.02930684101527497, 0.03399991287639545, 0.03040330627212121, 0.025542463070803115, 0.015117625739695805, 0.02158880778287928, 0.03356536482310584, 0.018157469326510065, 0.09407081671299473, 0.041083115859017263, 0.026643377383269613, 0.08220481190590129, 0.06621645733473763, 0.015233370133735722, 0.01335226134547303, 0.04967907053087989, 0.023639803271620505, 0.05078273509899455, 0.055941345185161605, 0.037664800897360816, 0.006287926150816343, 0.043653348505857496, 0.01717649182424911, 0.029730941544497208, 0.02127688167796981, 0.034795158107074044, 0.014170906731798766, 0.046505478526195215, 0.05295216969604935, 0.015443058932320246, 0.05472705752078084, 0.028942836253272913, 0.050557585688488144, 0.03113795394798921, 0.09037505534868087, 0.042959977647349726, 0.05544291305986624, 0.04595182678331772, 0.04420590091256365, 0.06852543867763973, 0.07043369474910921, 0.03200330005417908, 0.05153371959984784, 0.03834314494123382, 0.04612327343033207, 0.017575424449938922, 0.054371581232595834, 0.06033780120853936, 0.07303296978915892, 0.0693264065851127, 0.09086983323457742, 0.04521457440850716, 0.039500125398438786, 0.056338059986310626, 0.0487232877452287, 0.09288875836758845, 0.04389749306644644, 0.04604106453517753, 0.06009783948801699, 0.014560981465864086, 0.053140282585856416, 0.03470561775048414, 0.0338116429385639, 0.02090338508658592, 0.03821770570451214, 0.027701151369500066, 0.013310699160361003, 0.02801355819458202, 0.020481808817074187, 0.0479440575826072, 0.023397248343474442, 0.004316605242615145, 0.06513773658943754, 0.046520057179394274, 0.015323963861221509, 0.004504161761067207, 0.10274297032024592, 0.009204673772347311, 0.045806411803970416, 0.022450164486203465, 0.042449464315488454, 0.019698083633556962, 0.057082142034966143, 0.019746674675374262, 0.046237301787421595, 0.07588581227126621, 0.02450403088944093, 0.015582224549425226, 0.030429619477100434, 0.021655189301518184, 0.03041272915358986, 0.04139030562533487, 0.05289743271385951, 0.06851555614341652, 0.10248876702521117, 0.050813826777401476, 0.03454753167686924, 0.03764100237599304, 0.02529526756505572, 0.06486161551888912, 0.054654911190511725, 0.02845904406821055, 0.1170570397328946, 0.15736510826935693, 0.07292649122856318, 0.027979457705852487, 0.03015584646603994, 0.04757851106865753, 0.018202902170859517, 0.046100030322709394, 0.05000067807193245, 0.04940834271931841, 0.039297016337513924, 0.06144908835150062, 0.004550681971464186, 0.03903675328699812, 0.025650173117737138, 0.06268773378143389, 0.009289749751558468, 0.07069869222299707, 0.05580844425205743, 0.03070171284038694, 0.022536092738230384, 0.016637434056329153, 0.041275970833075624, 0.021089113527728666, 0.013539577503838848, 0.033481344130010374, 0.059028250510774316, 0.002737725083152914, 0.029431138780989477, 0.06799152902057094, 0.018077767454087734, 0.11317309653086048, 0.03875349993787466, 0.03830896209805243, 0.04552279456308292, 0.09746888397081245, 0.010842893426606973, 0.04301099144222756, 0.029347771177849466, 0.023560561051952745, 0.04107746596057569, 0.013705225822876298, 0.023009749580054514, 0.020671095736625216, 0.044441495931917624, 0.04784569189312959, 0.0872141535904619, 0.02583034550620904, 0.02424675558182982, 0.07161078884476615, 0.018546044443463607, 0.05399815550434494, 0.05436065298835597, 0.034050512983794176, 0.02453559754236091, 0.03354911609823185, 0.02374595241440881, 0.0450680026363942, 0.025826614658017794, 0.03833475244802333, 0.02064408922207452, 0.015311969797156993, 0.038619844408165065, 0.009693244430837373, 0.07411790350752492, 0.03659910364677349, 0.040441187804624926, 0.04413066341752007, 0.02343506052819712, 0.032600051903676604, 0.08663248601219348, 0.03909949205755707, 0.027611346712576288, 0.053674678708757126, 0.05120659239530083, 0.022028624605868134, 0.04248749292004974, 0.014568085973751883, 0.026111859835744388, 0.042080424440604065, 0.028571241475161047, 0.14539247168408287, 0.04831803489416357, 0.015495992735058311, 0.051009156215455265, 0.007034697168086085, 0.023594734319035086, 0.028822889866968317, 0.07845576146557447, 0.08264796312658057, 0.01504345310686697, 0.16109381141441484, 0.08293438807971056, 0.18355816001853636, 0.2223234500495657, 0.12416753076737928, 0.09383621760794232, 0.09385797450499189, 0.08232268219393107, 0.1846091253983398, 0.16194004745733354, 0.167907795778686, 0.1793456876710538, 0.1538316809361981, 0.13791540757783, 0.11536390881144232, 0.10258419093705955, 0.07237686144728815, 0.12429243374255397, 0.1395318530980618, 0.1677684443852594, 0.09340851071981654, 0.13289773085665318, 0.14976045988019437, 0.12452705583024411, 0.09933269928179442, 0.2058757568198827, 0.14565154729831606, 0.10075723977699395, 0.11779588557058766, 0.16469267797806572, 0.16626000194059265, 0.16620674350809667, 0.19705385600607242, 0.13706806836830032, 0.11223623994737865, 0.12514456866248963, 0.1913209442770289, 0.22771179075202636, 0.24812040369837518, 0.12922269983157036, 0.18923854875949123, 0.13672009591133366, 0.0875248482090331, 0.11048012127679203, 0.29473737483063056, 0.13919497359423869, 0.09525924890993104, 0.10614557281857538, 0.12007896548076985, 0.10138196915748621, 0.18587050448742606, 0.0838820388420455, 0.0971501607507948, 0.07068324789044357, 0.0502021745177767, 0.22729154556028305, 0.1332660199653718, 0.1346289516697007, 0.15415264113295465, 0.16123075729175923, 0.12821258225988957, 0.13639852284423767, 0.17774123908771625, 0.0874708160277336, 0.13906247102685515, 0.11064201097695098, 0.13576515199195954, 0.1185467360060542, 0.17022734147406396, 0.13204365007338986, 0.20932713613635112, 0.1689880563607139, 0.19013724650346464, 0.07705934405807527, 0.14184732320568255, 0.1268276408494961, 0.14396203231186638, 0.21827090621715595, 0.12299051328051476, 0.16598914389408406, 0.11988071724772455, 0.14472597518995886, 0.25008045497440523, 0.17347841944184997, 0.09713663929893125, 0.26505627879692667, 0.2383448153493866, 0.1417374968408577, 0.10194103714198836, 0.12141997174870585, 0.19318794651377588, 0.10646079501677906, 0.08440972786516913, 0.14928974481599946, 0.1749555595339306, 0.12932696439806493, 0.1431978596073966, 0.10234514852204632, 0.19260173603411646, 0.17961170404188095, 0.21074423025692665, 0.15637749836089151, 0.11370293826105134, 0.14250471857526611, 0.1296763311350538, 0.24997815159299683, 0.11262874509538374, 0.14252920274532613, 0.0744903218301554, 0.07248795185718807, 0.12598900439878627, 0.23910986139409005, 0.09611351355429619, 0.12535633834739848, 0.17823014107923354, 0.11924905477151757, 0.19991959174794538, 0.1653980764169847, 0.12329816653002655, 0.08249722766659914, 0.16670820934157218, 0.15668777929198358, 0.10826188304852094, 0.09047162839241567, 0.11500249151140453, 0.12822884630652207, 0.1590732545141251, 0.1522067011964898, 0.13306248572564897, 0.09318514246373408, 0.12627809533789275, 0.15376861657827132, 0.12231779615244559, 0.13996009624773456, 0.13864774166816665, 0.167733189018984, 0.17748856796853005, 0.27857172453115064, 0.15986034856928935, 0.14280790553217934, 0.21617102857318618, 0.11241663067090897, 0.11575430721765566, 0.12513449460628534, 0.2265050030884243, 0.13424269013827847, 0.10245715057657612, 0.16957523211115794, 0.17491215299214088, 0.19405741034255874, 0.1550573603280129, 0.14897578666287084, 0.17010321990857202, 0.12470992867864909, 0.11264887788603384, 0.11566826022200047, 0.12797756180647882, 0.12269694838793048, 0.1562744442133173, 0.15993873468570172, 0.162641201769152, 0.1138094551260433, 0.07348539833460124, 0.14086034148931503, 0.078531596509199, 0.0847672917429478, 0.33653828826162124, 0.17865407881477188, 0.08738836198444329, 0.14598318676073707, 0.177636637442535, 0.09039012429815146, 0.10710378793338615, 0.18053077972464024, 0.16781767319527366, 0.16095085940774412], [0.046351215231322476, 0.08639265452661822, 0.06027312423553198, 0.061194218559971744, 0.0005153330423655139, 0.08598226888646042, 0.01652503555129853, 0.07992025344602524, 0.03764275288690002, 0.07029854917838689, 0.021803396671349486, 0.0692887686853928, 0.017911834724908395, 0.02480617213633753, 0.005184460765561991, 0.04851464369905092, 0.01827741954325428, 0.0567738184585206, 0.06873664145748462, 0.027562311339762904, 0.03273798220400368, 0.04135280945188096, 0.016845578230136347, 0.01059450761174723, 0.01285502719016926, 0.07742954838660455, 0.06133705565345384, 0.058106807616329005, 0.07256710406152472, 0.055087819815643375, 0.04776162140431905, 0.06567618148701806, 0.030146980913536205, 0.045095742680132396, 0.0338960466756215, 0.020184363689153426, 0.0199018323778986, 0.06568106146709574, 0.016428868534163605, 0.06539606909838415, 0.030236739605184526, 0.017039092039809595, 0.0471230756281124, 0.05576619833347298, 0.027186748226203268, 0.06258317427108846, 0.04595086151253312, 0.05210011904578536, 0.013493646702338612, 0.026231620445727345, 0.06585769835979709, 0.0027228677654713997, 0.03340343681855067, 0.03814112372516144, 0.0337278827153627, 0.05483787596946763, 0.031054076896379554, 0.02959768246528843, 0.04265211372365875, 0.08980738419678905, 0.06284159871058599, 0.02611992291114744, 0.018336235943640915, 0.028859024319136818, 0.03699379214536279, 0.04631484903755688, 0.06771843399732344, 0.033431310927675616, 0.049359983419098204, 0.03489602507362443, 0.04462142700269338, 0.11967661610293774, 0.031666575683160655, 0.0592360710124335, 0.0535894820706979, 0.046989600129065015, 0.020274166430857395, 0.011681911006059137, 0.05741259789154415, 0.009205166941448566, 0.006177803405725788, 0.03623535743944588, 0.03343636327753625, 0.02512828529542012, 0.013254754632080515, 0.03348116409934817, 0.06400589530746784, 0.09357422319871765, 0.012389864348205588, 0.07095314832704683, 0.03536130091355693, 0.03216663383007531, 0.06634698339527653, 0.031312227459444154, 0.037158577657875516, 0.04757817015953122, 0.04735328887979831, 0.041244856172030976, 0.01707842107862234, 0.02954458682647636, 0.00508773306782748, 0.026974212453370134, 0.0260928014834081, 0.02297214232385159, 0.05052291254903521, 0.03880966567404328, 0.05296048558046741, 0.06489663339790798, 0.015496156486352126, 0.0479815001299064, 0.0264608588505296, 0.0653408648025605, 0.05919020532840683, 0.03390155484779708, 0.059901878027425665, 0.04757474574650969, 0.0202684763127998, 0.03074976379021762, 0.06717566070297072, 0.08618376533230467, 0.021954212570562962, 0.054068861589316404, 0.01825196435675025, 0.04275848503194509, 0.02169940406606803, 0.06022352004243482, 0.01373480830807239, 0.023163963079212174, 0.03966910524233695, 0.0665312658454622, 0.05390938889655856, 0.013790275946620011, 0.020799168400586616, 0.11839202454974575, 0.04719089739204896, 0.057315714582200014, 0.021603260031570832, 0.04435951686314037, 0.0731193385417423, 0.044856600673689, 0.06813086509223908, 0.0431718775672057, 0.07949823859117686, 0.0551157437204834, 0.017044891325396397, 0.04743101616059581, 0.01560400251389271, 0.11008633676195338, 0.022890624823048714, 0.05889247674795409, 0.011973982027191068, 0.02708361746983663, 0.022777333825586304, 0.021515326544402108, 0.015901817279236934, 0.016619532496758526, 0.00839866692155239, 0.04686261339473629, 0.03996583790848813, 0.036950397094891924, 0.04193704342469574, 0.04556018348422743, 0.031230453319186648, 0.03756848449308065, 0.05215187594594975, 0.030635490284992323, 0.028089826077883764, 0.05524419751318713, 0.01757203259565417, 0.009781113758142437, 0.03279132490617133, 0.059785087923369104, 0.048307079836846366, 0.10635271533242158, 0.09117835216344365, 0.05644247010951081, 0.06409444741063541, 0.0324062776241091, 0.08974363035973042, 0.07084747415877159, 0.007323269082623865, 0.04282519979883106, 0.02487088932896093, 0.05074968223550147, 0.050101744221343156, 0.06901320685902912, 0.0199145398613426, 0.07853309804153058, 0.06634572701108071, 0.06870947597968964, 0.02385638015825422, 0.03634918661367509, 0.018832538344506777, 0.032504474774243376, 0.028938306758420605, 0.0076858517939164765, 0.02370637631224048, 0.026078259219385447, 0.012292568308992252, 0.018931108962504134, 0.019728060654034058, 0.06080582347368041, 0.05172239939471887, 0.03383942128669831, 0.06948704756195508, 0.004838561534040398, 0.0569862048442085, 0.028593777866673567, 0.045630154124791586, 0.022590868024816437, 0.0060143997243064795, 0.10637964332296003, 0.06609692463591214, 0.07538120547730116, 0.06686236138545698, 0.1264978629807311, 0.10799074154948035, 0.009874952825597458, 0.009212048326228416, 0.0489210878168383, 0.00599337061078498, 0.031528760296022224, 0.045337290202658025, 0.033192276173541625, 0.03208194472526591, 0.03824838369543995, 0.039327905002620914, 0.028675525193853725, 0.030717549793001626, 0.022202817678091027, 0.024137383124100107, 0.03707306692376733, 0.04576628794893623, 0.08967394700213786, 0.001978024416941128, 0.040168770769190405, 0.030335882873905283, 0.029819821150252418, 0.0921651806622263, 0.0182692970960371, 0.03055323733978214, 0.01158897783757458, 0.031489923468700824, 0.07675704576315419, 0.01455077717471267, 0.025770831965811314, 0.058869547736380375, 0.007462169441785063, 0.041488246136014505, 0.04144155690746923, 0.0172756772278057, 0.0665444195751221, 0.07162942010308467, 0.016306505140457905, 0.09902411906589424, 0.035226649469545776, 0.01895054844358275, 0.06703302279234895, 0.05967500491908962, 0.04241747248377051, 0.063064779275127, 0.07049800016947332, 0.062085803177568226, 0.055875201153779225, 0.03672796346607708, 0.02940151799139717, 0.054985225320823734, 0.03811870033161775, 0.04505515534190401, 0.020477748551075498, 0.017630843250381372, 0.07822794989953119, 0.036934673140246066, 0.05253186321727211, 0.017613290260816296, 0.050001635681837804, 0.0278525322585577, 0.0378354316607358, 0.026828841524078485, 0.08656654882455066, 0.0691814933933558, 0.03123783266111728, 0.027406711221462297, 0.04525513110321857, 0.016819224805541096, 0.057559839990590854, 0.03405475328045507, 0.07258015053887522, 0.03899608550953769, 0.09162063004388925, 0.006374390185585306, 0.03553856599835619, 0.016155342586458694, 0.03912426351058868, 0.007244116878287206, 0.042100143543775045, 0.04485418749672752, 0.0841094597032474, 0.06631249411692543, 0.05537896003994731, 0.048736054600486835, 0.013845616223050222, 0.0099628537540294, 0.008043013475534898, 0.10237638958759847, 0.013446294807738835, 0.01921944722022501, 0.03881528492896788, 0.014236291378526198, 0.016784090098113786, 0.053463418472317926, 0.007629495014571735, 0.038449845667327606, 0.041151339819114056, 0.0719009293243289, 0.025544755588916522, 0.029265786363412778, 0.06213384838173948, 0.02319872048833678, 0.0787791348392925, 0.03128285564842724, 0.019498783944835587, 0.011148625710648636, 0.08783845396171655, 0.06924788257287395, 0.012274092183478419, 0.03818987756066265, 0.026129008713929404, 0.05250048042545396, 0.017006619487919154, 0.03364702213495489, 0.05434348878841247, 0.03307193525195603, 0.05174856129733305, 0.08718306574249461, 0.02304199230556767, 0.04073024426977481, 0.07058486687920748, 0.04852716157573366, 0.07068118711392726, 0.03148448807487805, 0.052504827974424254, 0.03764957873030536, 0.014372134089259612, 0.022767445545703657, 0.04389411078826074, 0.057127325900740204, 0.04560645519485397, 0.0140889611793682, 0.02340491496837668, 0.11613948090422539, 0.0491104953952374, 0.18483159733155083, 0.16234549183037975, 0.22119711693977157, 0.17560294979522306, 0.07366522215306759, 0.1580777232565226, 0.11208991715384108, 0.08363505209525747, 0.22039520674415175, 0.11642706265012104, 0.1271503630484785, 0.14820232897275878, 0.12422861095758216, 0.13098680113832797, 0.0849631038163939, 0.0857409741729498, 0.1434520016153974, 0.1469187180121099, 0.15330519467111559, 0.12165944317295668, 0.15268489327882567, 0.14719616441476732, 0.23805293585023574, 0.10934263392682038, 0.12249228033807971, 0.18075795543770637, 0.13635415103166335, 0.13652387015040846, 0.16706002755991875, 0.11853037236799156, 0.14175542329828586, 0.13817011649089475, 0.15981292772677638, 0.09476063292353384, 0.0827954427128838, 0.17483252581329117, 0.14504857481487338, 0.25119938767485084, 0.12293426710511408, 0.31628322997881525, 0.13350761345317289, 0.15366933158328458, 0.07426853937607619, 0.20778376008233718, 0.09565876376244331, 0.13959228211352903, 0.1851843654989235, 0.2832338904901859, 0.0890818759498577, 0.1479399898239682, 0.11731235385541955, 0.13158707699227717, 0.10581626992432341, 0.11941169523784231, 0.10557440830574882, 0.23113264912559142, 0.1084521946106707, 0.20498700289716645, 0.06628627858815656, 0.12723221188230863, 0.10212692071593578, 0.21647841369192447, 0.2727476176956008, 0.07535819985693501, 0.16707579364940045, 0.1215245197677324, 0.1588925803380628, 0.1499214149530857, 0.14540678220650843, 0.18005292472099105, 0.1642588270647872, 0.20875068561684704, 0.11398452153849988, 0.1278399647543988, 0.1985403423708293, 0.28249602524503586, 0.08543970243584725, 0.07641532458364964, 0.2019634836864087, 0.1284973141587069, 0.2344140948186959, 0.15056934147592516, 0.10482891282487301, 0.10199225778060575, 0.14790946888106485, 0.11191402336642628, 0.225550809935216, 0.2378323791368354, 0.16916695321279188, 0.19621164958563544, 0.11455973099556663, 0.15044612389418388, 0.16193181967302678, 0.11383881927618097, 0.10222298048076131, 0.18555593346395802, 0.20194376458323773, 0.17534585068783454, 0.21095234570243668, 0.1246380006834384, 0.1349877719316752, 0.1399123689700519, 0.15750798366723523, 0.18891204208616288, 0.2216331128992381, 0.1573137037696377, 0.09948201747911592, 0.22544744935247207, 0.04334850679902781, 0.1480821297774392, 0.14292185345003683, 0.14492223159440104, 0.19371077087858032, 0.19908069482734128, 0.12535425458824442, 0.17192370528655668, 0.16074780014253434, 0.17270686164979013, 0.10432000827765274, 0.21763558950155013, 0.04903121295595362, 0.25679274882760744, 0.13046109628292824, 0.2053351132499595, 0.10729998305079438, 0.13576176588333425, 0.08048287607849607, 0.17421852166373886, 0.26088673801672074, 0.1253465554046054, 0.21373520605266097, 0.13357119875088816, 0.12197699427845017, 0.23339231738880759, 0.2082423096702945, 0.12486329948109005, 0.1312715866633, 0.1366837220566888, 0.22190015582788378, 0.1310338236151203, 0.1413282220281901, 0.08722693193703891, 0.25320885162199697, 0.25559395912193483, 0.1881457396572636, 0.09966931831572326, 0.17984876228917032, 0.1689909521730677, 0.13089546813599526, 0.12195925934300308, 0.15845425547130648, 0.10524413247983302, 0.12991509009753505, 0.04469861802194388, 0.11409768804667458, 0.15398347359751502, 0.12693481655010294, 0.1647539190467327, 0.14317345204612902, 0.10389662212541989, 0.1456834318777246, 0.2270635424722587, 0.15373469420498417, 0.13132348145929076, 0.15774688052554287, 0.13519620913411343, 0.12555134602852408, 0.19835664980834533, 0.08941955984600129, 0.08951108437031509, 0.18017980420301039, 0.16084679402410984, 0.09740184361655867, 0.158742748861832, 0.2377451676875353, 0.19072125064990214], [0.02735351216078045, 0.07094449153350246, 0.030836387267035824, 0.04137628238588091, 0.030952145067614414, 0.008690714002436688, 0.051741248988095796, 0.015279230072102962, 0.029582898883569627, 0.05626862560729346, 0.11259748104719386, 0.0216892323336534, 0.07733328177803948, 0.0868876162736166, 0.08021878258835885, 0.039621481386524056, 0.030475123184582883, 0.038883256080049666, 0.05540917071724131, 0.04366108216345311, 0.025921527206176714, 0.026820715246421677, 0.04062296514729819, 0.033744227201227224, 0.06270703536668612, 0.06637568104892008, 0.03837004228825531, 0.042956783060705474, 0.03653319710264764, 0.025888700338621295, 0.009643658432328414, 0.04312561734789803, 0.040735016997543075, 0.0273409923688779, 0.07042185869067907, 0.01572838167644917, 0.013847082323815315, 0.005336559383243684, 0.05444602199619817, 0.05459204601544527, 0.0074583351717240395, 0.070606937872306, 0.03410897315329602, 0.02200140741713826, 0.02224788854589626, 0.054486122868594625, 0.04374258242727768, 0.06829709085004945, 0.05217793825713377, 0.03296313927538934, 0.01815007657804076, 0.02643785897582289, 0.022399771222544294, 0.0349314030139677, 0.017714254903577028, 0.03767037035657033, 0.06615101044336635, 0.01837981868565323, 0.07252994113631787, 0.05911839990726402, 0.012741941121226598, 0.0451183652565364, 0.06097418661679953, 0.01635537963480719, 0.05169762411124764, 0.03206906487203894, 0.0447238567886093, 0.0303795192420723, 0.10623443135691267, 0.008567630486082166, 0.07530839648097754, 0.03563124731543564, 0.008842225126441448, 0.045643464902475964, 0.04525812267656288, 0.02360182063233468, 0.03165751094779661, 0.031238160163704908, 0.029131667350508997, 0.07638170098465297, 0.02123615644391506, 0.07172580928571763, 0.027157211706282634, 0.025510023077649456, 0.048278566044304645, 0.023186227509511576, 0.021380611898137197, 0.031168262301493558, 0.03135426653428905, 0.029256478395132773, 0.02769035144498752, 0.019088951803203073, 0.08148394615179108, 0.01972172319168045, 0.030752699822187427, 0.04018503481582288, 0.025546289679984895, 0.10550905334492845, 0.06134483144588529, 0.035095096851188334, 0.04997243241016423, 0.03663082734771794, 0.055445130884407036, 0.04892614782757817, 0.027698173202694427, 0.004657202666895765, 0.019215469308678183, 0.03661303495567653, 0.08236804225992772, 0.04664727374010029, 0.0632423009993809, 0.038526117381068974, 0.00824504714053605, 0.006249711769933422, 0.012655463201114008, 0.055955490998683445, 0.02540942807231219, 0.055828305081494396, 0.10236503616456064, 0.08447828507351299, 0.06906614353459689, 0.04352809313023764, 0.0461027882392368, 0.023340904491863424, 0.012431240756995978, 0.01632874658811958, 0.051937095535498475, 0.03085382534341226, 0.014496303535246802, 0.0375137819848474, 0.0935749663040042, 0.035577287912488945, 0.026420798197749163, 0.03979873114956483, 0.04441585496909196, 0.01887813398254014, 0.01627494997885679, 0.03765713235723876, 0.03430303471583513, 0.029449411893203378, 0.060623877591663794, 0.04792946743808928, 0.02656243636362976, 0.048586380172280536, 0.013756660008502584, 0.06641000178792784, 0.02006692241036123, 0.05031272866612962, 0.01668500811642697, 0.07147381998478405, 0.06264800063124107, 0.008688587150836905, 0.051925454829489036, 0.028750611386532267, 0.02353189787226579, 0.04070625805686559, 0.030357570823041663, 0.0195118687265823, 0.023232386222169287, 0.03596131629761189, 0.04913417900341654, 0.04078598865758508, 0.03785056572767996, 0.04525433437177732, 0.0322975697476537, 0.038978400369805676, 0.04094991998206224, 0.03737828018324029, 0.021675563409864422, 0.028398291380595297, 0.0556273372363179, 0.096471996737584, 0.04034579453629352, 0.03825595264413184, 0.05174298034680467, 0.0420090020634234, 0.036449314305378545, 0.08207247787786108, 0.01095189816213303, 0.00971525030646233, 0.026701297460784836, 0.042499516670021324, 0.027015100481108795, 0.023737822306312384, 0.03209368119226589, 0.045247857098377524, 0.07084434085916128, 0.027121136625928265, 0.03144462277451831, 0.0248587851397573, 0.032226400179488045, 0.044729943357167706, 0.032117395443961985, 0.027308801354299632, 0.08117181894880149, 0.030156830889022643, 0.03984493391227819, 0.042484754155720436, 0.002951880174335994, 0.061997327683193076, 0.055699996845496286, 0.09420337290653298, 0.025373370228936116, 0.014365510301544301, 0.05083955967077806, 0.0516963447444141, 0.03634870397828279, 0.08293436509707282, 0.03954082381941619, 0.026141248883739598, 0.01935883500282803, 0.006222373443550521, 0.020027256292861798, 0.08899664100740226, 0.060303809887339035, 0.035819383187880444, 0.04586630072745104, 0.07921677022691696, 0.007270108326338232, 0.044318171097866954, 0.014081624929883308, 0.029142557290352644, 0.022068369247379805, 0.016828276134366472, 0.07419854192243469, 0.03160355920572916, 0.03568352898582816, 0.11051722291496494, 0.03159590407214578, 0.034990924215244676, 0.02593004035823528, 0.05485217500057432, 0.050259133154946956, 0.01613091778821282, 0.03497499341685926, 0.01089003081658795, 0.03308106702001345, 0.007827287904107043, 0.042971101244010275, 0.04396313147979879, 0.05343912582423899, 0.034875719913191376, 0.03388034187317376, 0.018989691706073862, 0.0182881792481508, 0.013300419218027064, 0.03625695728847096, 0.01648883981209609, 0.03828301470005705, 0.017360665106905565, 0.027379551489326744, 0.026371931364279122, 0.040956424068539374, 0.027649112932023504, 0.03647275659586153, 0.08542011356762341, 0.03499594209114871, 0.04989300824461445, 0.08379208479797648, 0.005432054637030008, 0.007065219068599324, 0.03657687560565049, 0.031713088711483345, 0.02342734027714018, 0.07630707635994881, 0.07786287836009458, 0.05303132956126525, 0.06469469262106765, 0.031078515101164102, 0.03146596215364914, 0.04158853087574244, 0.04905783451132236, 0.03619871545402754, 0.03462163536178489, 0.05588403414754618, 0.03085537858667874, 0.08424778453885548, 0.07537179025671176, 0.04090460205090143, 0.01268510505812423, 0.026394274318590764, 0.07199103658598277, 0.016096359561948527, 0.013025458770683937, 0.07122744610833545, 0.04034310173723967, 0.07045660843892444, 0.08519787912166889, 0.004462906011124893, 0.05853029719043163, 0.028618277358492056, 0.02415462584805585, 0.008299838706490495, 0.06757260916093666, 0.09786829923189456, 0.0892890184637039, 0.07577879744912348, 0.03586764672711011, 0.07569872593927769, 0.03694107763529305, 0.05817932166880178, 0.11778729006407723, 0.049599481656426386, 0.03391425658558165, 0.03354158928437579, 0.024728810662523876, 0.04371570040201468, 0.018034558179938508, 0.028408744650322105, 0.011721796416226896, 0.009367985523215706, 0.025061823337549166, 0.03570376136790841, 0.047626134924470424, 0.030860672254235517, 0.026605440709259243, 0.07810511536175206, 0.026118388820079066, 0.02941828191040024, 0.03044725865155699, 0.04030005908721397, 0.052018591968883435, 0.01670866874196837, 0.04161478470890753, 0.05940664431921417, 0.08662049673617848, 0.021285199477607687, 0.029142978638710997, 0.047996687823005264, 0.10493695420483429, 0.02711027349916197, 0.0012145106677874744, 0.04954936418441996, 0.03092823354827781, 0.03288459228051286, 0.05354226041104525, 0.04643242821217545, 0.07771843248197148, 0.03989487901450165, 0.04038966839171706, 0.05980548501435307, 0.06691020357632829, 0.019411421193170453, 0.04772793651828843, 0.023215417374646472, 0.013433729050560825, 0.08751527977085884, 0.022846120860307448, 0.042256888963522456, 0.08540395677330033, 0.004714067458295294, 0.04382486410078503, 0.13616955448542872, 0.12409279122948648, 0.12723077163701096, 0.17637171902723853, 0.17003418006483587, 0.12343403988427694, 0.11499561204184448, 0.13460347158533914, 0.1884414342742774, 0.1391194832901801, 0.20604466388542808, 0.1151931478131202, 0.11663002232390067, 0.2012886827991855, 0.20012842731610422, 0.09246432267489935, 0.15124083286331547, 0.20133696166017365, 0.13621403355031245, 0.1494544230762028, 0.15124713010605306, 0.11405903891089464, 0.07844997750174615, 0.21308072181718968, 0.17518261267292887, 0.21918034451382779, 0.10569467644898162, 0.11884368700726379, 0.11711331655181224, 0.10807362460200826, 0.16490600282146087, 0.20236198730286092, 0.1519277685832593, 0.062288276385515935, 0.35028392809533304, 0.07620542415327604, 0.10641379552262445, 0.155324510508968, 0.14894627695602758, 0.11627985885547054, 0.23398297117842784, 0.18243009555003337, 0.11286810926732518, 0.14206239472954504, 0.10181988799764265, 0.14283517826228373, 0.20238271764209195, 0.11743620729013798, 0.1444832785355468, 0.14477604669668984, 0.10100696145767167, 0.22893077453538296, 0.0982404264411138, 0.14302337542176247, 0.10652732209212358, 0.16924653442636614, 0.10700755962921728, 0.07172934861192781, 0.1428785541605565, 0.11972173102079861, 0.13849807873127923, 0.10920833105281477, 0.16567900085881834, 0.12785927017009066, 0.14693984671706153, 0.06529643936383148, 0.20286143066421633, 0.10115393542594488, 0.3577288931175586, 0.11660432007404105, 0.1319177511839136, 0.12453337605561941, 0.10279367767995405, 0.23472336451372794, 0.11286848465040808, 0.0853109383775342, 0.1486599439334485, 0.09574527041085305, 0.22988106064017744, 0.2120760128262543, 0.1122285714072566, 0.26062773901128, 0.12805155057820583, 0.11034054771786737, 0.06927065070598357, 0.11273376042804412, 0.08101399717552048, 0.11216137017453871, 0.11595178170189743, 0.13861886015342129, 0.09291100556090956, 0.15082818726378103, 0.08960244035528553, 0.15191825377123971, 0.1354429200892487, 0.13997298184662096, 0.12942555991391982, 0.15024879496664773, 0.15168067458416187, 0.11911682033490752, 0.15706195195596065, 0.20330861150737733, 0.18890706251465506, 0.09309406993129561, 0.11951703998831012, 0.17869229128043498, 0.22933963566057144, 0.1086847865653615, 0.13271238354425277, 0.16060639563347065, 0.15224613940283177, 0.22293132549572378, 0.12284838864880225, 0.12818570789550582, 0.12784173441750388, 0.11781728240631281, 0.15855838214197468, 0.1620402824013464, 0.24672692040762595, 0.1537282743881787, 0.17021784198380288, 0.15229651734473246, 0.23429282310028232, 0.18985433023302786, 0.21255285659384346, 0.23483334409613765, 0.1467861694794509, 0.08226538647807415, 0.16540140123857608, 0.08883831361609121, 0.12082801560961431, 0.2691929697269394, 0.13654483031601677, 0.14599392731343547, 0.0815472326752159, 0.06851032376289368, 0.11120782053518681, 0.2572722126158976, 0.13124515662991232, 0.17393212735412583, 0.32573307774239973, 0.10463769727897261, 0.1111071642428156, 0.13325106592908983, 0.09742247436435954, 0.15294520995549618, 0.10267327164089489, 0.2111299248832849, 0.11957154714412267, 0.150554571300745, 0.18270628556849497, 0.10029279131201968, 0.18937618411596746, 0.18843339035107246, 0.15078245181470148, 0.11415231777655502, 0.17905921675264838, 0.12420416509191837, 0.13912562731533282, 0.1385393249051225, 0.10919352257323843, 0.23377672498745306, 0.13753487638408138, 0.1758535371552552, 0.1193328035033999, 0.1461952398981779, 0.12404389183727965, 0.1522076664672744, 0.10750989880292647, 0.1688099562400772, 0.11809829877869737, 0.2052913543077246, 0.1650794298057595, 0.25588640552614966, 0.11020364014491921, 0.07997681371747487], [0.07021509155991577, 0.01841167453676462, 0.028166329533222224, 0.017350031806516553, 0.05404292568263989, 0.04761895285018029, 0.032742490631438075, 0.034043193013677676, 0.11149990687807722, 0.013389234663918616, 0.014207818763210409, 0.07994863700361983, 0.021455002866024454, 0.02707069356655402, 0.05205555188079035, 0.030946684775934107, 0.05114059009018445, 0.01859639557228694, 0.03517615661445645, 0.014659903526696709, 0.022427174187595808, 0.027284093103521777, 0.057727720498317675, 0.06677169487961838, 0.05459866118467143, 0.03405172723315416, 0.03615448919815883, 0.025987360971949758, 0.018829939391223655, 0.03890900429518473, 0.02042079565956468, 0.025139113948229822, 0.027333712618377422, 0.01623246657301582, 0.05243118777270279, 0.07011526264250278, 0.04149296523762807, 0.02438521448282465, 0.03822850371380487, 0.04986667780265693, 0.042376203327289516, 0.12100735679268838, 0.05233186447331983, 0.018525371560826898, 0.04934657688042329, 0.014737084969848156, 0.054876023317657174, 0.039854192084843115, 0.06462864052023619, 0.012061001954510087, 0.05213898268618411, 0.02171058894976253, 0.03958678143399377, 0.04099395088551026, 0.124620066565131, 0.03643101629530711, 0.047078194367068435, 0.030365003791126995, 0.02375401165937224, 0.06640037972359888, 0.07092578366639153, 0.02633046494015763, 0.05878582581757538, 0.04097629638929521, 0.04721658432015008, 0.09514385308589667, 0.026457987936033357, 0.05512332799093378, 0.047002432101796714, 0.009229238381639365, 0.02086645581819598, 0.072559351251731, 0.0356433017089242, 0.09214373020034644, 0.005472403530391955, 0.06332161025174203, 0.0480880782819323, 0.015094700558561713, 0.0304528625847231, 0.05051984819733808, 0.006046117679591501, 0.038739549476773515, 0.035901335443580346, 0.03503523091034543, 0.014087140762938127, 0.032932193153688026, 0.006512088744315289, 0.04332909796146616, 0.06216937570922798, 0.07314168532649357, 0.052614619865292506, 0.03380934084435144, 0.04642372928379525, 0.08980597459500836, 0.1021464866015219, 0.04818985689311259, 0.12769407863097806, 0.03341643350018609, 0.03854696263348864, 0.015118999909909983, 0.013223715622218387, 0.07309087837535529, 0.04459578603986771, 0.03990664229457898, 0.0998658198683012, 0.02890529411454355, 0.10081132558444816, 0.06293722180529468, 0.037906765937805176, 0.05832056912984099, 0.016896902290623517, 0.04268617782321188, 0.009736343579847487, 0.08235781498613857, 0.03710979317885734, 0.06404441037786103, 0.1089589004855483, 0.04475433942711642, 0.025427157262099848, 0.030259304724994208, 0.035976657208295605, 0.03816755375854912, 0.018100458978404923, 0.01959949960902093, 0.05465080495923758, 0.05024044060959451, 0.013932755851607411, 0.05563102978011293, 0.1023881337154777, 0.031200121983044574, 0.04072114697567398, 0.027848619464484435, 0.03890010618394421, 0.030999043055119056, 0.04415668359386825, 0.01864078079139994, 0.012915923519270315, 0.04298540027511697, 0.033195769534476345, 0.03957957637706592, 0.1598563342685661, 0.017320322916812955, 0.03049596652178274, 0.04121771367687372, 0.01593749303626077, 0.03418026529552956, 0.0910159798278924, 0.062157413246290344, 0.05072401829003807, 0.03638981991717893, 0.05421736007255893, 0.051723391478580814, 0.034194395787292914, 0.004906648077115778, 0.019129514243573915, 0.027530459319091136, 0.07510370544848904, 0.0695676629942271, 0.04743450952153053, 0.04666749846130129, 0.0799310552857576, 0.009764879397417029, 0.0361592619259271, 0.03158595067478957, 0.057779741698815945, 0.019360152674057794, 0.026345338537207535, 0.04664440857126348, 0.04775404479474791, 0.07085741798002874, 0.030090851566543984, 0.028966443252659617, 0.004806225441561471, 0.07432639433611786, 0.032472567212197094, 0.051039121744613496, 0.03556311145545014, 0.021504474908954675, 0.012985972683846712, 0.03447918514270456, 0.039226976749036586, 0.04349433163541459, 0.017501021990732803, 0.017450640218392495, 0.11207097179947362, 0.01411100344416956, 0.029733067438487085, 0.03829120801040723, 0.060629535150984605, 0.014956943585627503, 0.0952157887419866, 0.042263496471869375, 0.025606789558585134, 0.055625782077831615, 0.03868273256586925, 0.016666411332065062, 0.08843980233875975, 0.009696745452651334, 0.061820334559606935, 0.029235315216224522, 0.03327155095194617, 0.014600367003661251, 0.05310115847556342, 0.017900504284508286, 0.03999776845317214, 0.06410829061942716, 0.009389566220042687, 0.03825941919198921, 0.03142261498367354, 0.034697765349260265, 0.05321755787477859, 0.08094682658631956, 0.009880947463604952, 0.043024171984964804, 0.03588723176489434, 0.020596281505159793, 0.02011832307964083, 0.07133200944912049, 0.07781750297233944, 0.03494500107462368, 0.02801000929227279, 0.01997946198248575, 0.011791887715639127, 0.05662961772853329, 0.05338917306113628, 0.03825403359388152, 0.022758386555999037, 0.029934676882300167, 0.03374915314658034, 0.031026961214299646, 0.06815437633063524, 0.020798511480191545, 0.049526703303619746, 0.01925714449175904, 0.041918829684295965, 0.0583883487589417, 0.02287598488281571, 0.055218537398163355, 0.038542270344952424, 0.04475095714893072, 0.06229482260682891, 0.05402660800985271, 0.019250337800551808, 0.01279056663700049, 0.03226213435071611, 0.010496574761946837, 0.032838715105167324, 0.03213810088533548, 0.03606091155820797, 0.03548533437893756, 0.07452195360054893, 0.07690021993532296, 0.015869278652263025, 0.022853751096033284, 0.014368437715024959, 0.0396947960008777, 0.02969836174029737, 0.01831311349486632, 0.07714438747854964, 0.018078175395907416, 0.04757342041440068, 0.01822978802656214, 0.047573175266264915, 0.026449919114970875, 0.03839916895113645, 0.048259157206743, 0.012745589614965984, 0.028046042237791325, 0.033662998898615765, 0.028048641191074447, 0.0562689358729028, 0.0660912249417555, 0.04710118849611571, 0.00973549417986144, 0.024333057301719824, 0.03321635814744138, 0.02678507875140396, 0.054577314144661354, 0.041839175692368905, 0.044728970425503875, 0.11273038964117728, 0.06427472322097709, 0.08804759596504512, 0.021695046940998688, 0.036924848062617165, 0.03940939760556625, 0.03336569932740062, 0.02398388783237146, 0.038242749118756865, 0.02943945275018773, 0.025311640779217406, 0.027793882482294596, 0.06838779566028426, 0.09473345212398038, 0.06885088814963257, 0.03592546721319518, 0.03416842157622019, 0.1182641568143041, 0.08040577698979648, 0.04933921094503134, 0.02860976229121368, 0.03625227649125361, 0.036962600875525706, 0.00610115343607181, 0.03313259792424018, 0.01697000240035836, 0.036910637131621765, 0.0610465397908082, 0.04945084910779711, 0.022000652820532842, 0.016622091230425625, 0.09261190951351198, 0.04575560485283214, 0.1043539536335776, 0.01484872025978421, 0.02259920497665242, 0.052757763393944314, 0.034477652966855996, 0.01809108780787116, 0.034831068478524685, 0.013465135782626609, 0.03771532056552749, 0.06184281157930532, 0.024876516244764772, 0.04210177531105377, 0.02285495002363478, 0.04297002489047666, 0.03767982005111633, 0.058112947811042114, 0.07976492145849813, 0.030632954533962958, 0.013655147612875989, 0.020816784592405446, 0.07387860828349668, 0.08524706196640769, 0.04050951135615188, 0.027874149344561082, 0.024486144651628794, 0.10879382385962433, 0.024886751179433158, 0.041801522470890515, 0.052077898665541605, 0.023606191163942702, 0.017782607183401144, 0.030415014010824026, 0.06952065583919326, 0.03480918900740724, 0.03205470838433793, 0.009092557762238768, 0.12260622059505795, 0.030531775386583422, 0.06009591660732704, 0.0941535312261793, 0.11474274173979798, 0.06883146782075206, 0.1856542378664017, 0.14177713423005997, 0.10492511048552491, 0.1191264117557195, 0.10254057755153026, 0.30666527188112663, 0.11471676369828564, 0.10116998496795855, 0.1704338328131745, 0.1451195605219372, 0.05950481082583147, 0.21349534392356875, 0.1611766101972711, 0.1976194893640857, 0.12395564616928179, 0.1547013286260828, 0.08201571076267189, 0.15213573081118448, 0.16608476698879274, 0.1717467389760479, 0.15328906085943023, 0.1111007214433724, 0.07347077371612673, 0.12539937716698454, 0.11091608659274156, 0.1711473058188154, 0.13129752640041614, 0.15876548635142465, 0.13617519289255142, 0.10429168600709209, 0.18019503403094508, 0.11607280061129602, 0.1450327780818747, 0.08171866783091138, 0.12093257895039937, 0.08855602553775234, 0.11694218783128647, 0.10202525318750452, 0.2010620893129418, 0.19667288048132775, 0.13627527461897943, 0.14629559741625864, 0.12456475501699794, 0.10811873185898989, 0.15810867320866356, 0.269609690914231, 0.17183698413352813, 0.10241250297234905, 0.15919308598724105, 0.12611825875337088, 0.10636832820431841, 0.24292301807192065, 0.12506604465025087, 0.12189896822336221, 0.08956883973892658, 0.12411226518452169, 0.2343728026795772, 0.1699250125356259, 0.18435366571910922, 0.11979725962925343, 0.13827347707363868, 0.21377821422873006, 0.26307128369808197, 0.133423910686566, 0.1302146304759287, 0.11850742037378012, 0.12926616766039403, 0.17711765883911043, 0.177795278929895, 0.15450390776799572, 0.12397079938842405, 0.15159383085706543, 0.16812835249208635, 0.15185742639005184, 0.13613577000796795, 0.12404814362525941, 0.23710902359697128, 0.08898030035197736, 0.15104793192398164, 0.15600513366441573, 0.13003625456363926, 0.08824517004071705, 0.11429545364432758, 0.2017014662945463, 0.09819660621184496, 0.18163203111579343, 0.17781766401904245, 0.143538155863362, 0.14242928955824147, 0.11030139296405739, 0.13310627531140082, 0.17603727568301464, 0.15939654361817146, 0.20567225322367685, 0.09630348037688002, 0.10654773067442641, 0.11862934326692937, 0.13346408433731527, 0.1793535783766739, 0.16919499203082056, 0.15288763078710726, 0.2504130290640939, 0.10025452522020187, 0.15637945954597768, 0.17543464027825864, 0.10786610670507916, 0.10349211237964132, 0.11353037695610717, 0.12727082271369236, 0.14188293097240312, 0.10959666102163254, 0.13720167410229483, 0.16410217740603034, 0.27004369504509435, 0.1964479723885175, 0.19813111352343715, 0.13927838524743436, 0.09261101319064056, 0.1738669026282526, 0.09924240815903872, 0.20091077162613794, 0.13899180707671951, 0.09613962183075567, 0.10105124133969508, 0.20912409219289982, 0.1651025963045897, 0.10114319487324647, 0.09610466523877076, 0.07379244637465285, 0.2304657236222298, 0.1392322361108757, 0.06545408493688991, 0.14284046426896127, 0.20019469392155448, 0.23359156153615446, 0.16340010378870273, 0.10271359850922901, 0.19238003018882968, 0.15402655838237655, 0.13359297096969622, 0.17477632560316594, 0.17007656004880706, 0.2666658295258399, 0.23765985613628743, 0.0887842967565502, 0.09840554903231322, 0.1646430814458478, 0.1722110495451958, 0.2005007766908215, 0.09896087850774489, 0.12166683592142598, 0.0680668507852862, 0.15848162013196176, 0.22818494197582045, 0.16809985402130312, 0.16414955228326783, 0.12163830680712578, 0.1513879370665358, 0.11667402641427134, 0.2611861251775296, 0.09577533170100182, 0.11829568133238824, 0.11579280313585075, 0.1754897373217729, 0.20178052656833204, 0.11785515779328924, 0.18255119872910364, 0.16243137028669158, 0.08406153324270442, 0.06319715926844267, 0.1905950300034977, 0.19644872315468329, 0.19173527526999676], [0.12459818709401355, 0.05039271973674336, 0.023027857983364694, 0.055699249909770106, 0.026146741734156688, 0.03976805698907664, 0.005259606330054662, 0.047967951864965504, 0.06170694205549456, 0.03544966149474344, 0.02855488358275785, 0.03385843941941857, 0.03714930799399172, 0.04406915804851921, 0.03026668789736446, 0.04110057500281161, 0.036072747616638104, 0.012669183835837872, 0.05686280723180502, 0.026132745307780085, 0.029865535531914043, 0.023052326831666213, 0.03544782671416479, 0.017516916399941813, 0.057528564451082106, 0.03509706186671411, 0.08913560935686674, 0.02315693039206728, 0.035310501623297894, 0.011230861418880524, 0.08324492181981764, 0.04647193536643059, 0.05622913760523643, 0.014192499877554516, 0.01665676436987856, 0.07418253068481723, 0.059505481152765216, 0.044239562815956535, 0.0600418767651483, 0.05745125851864296, 0.02135630584351959, 0.020171702170984882, 0.03349144882973164, 0.04774171460960661, 0.059399416279648586, 0.057016867513377825, 0.01995750398735606, 0.03495505980906948, 0.022610778649968487, 0.04633297467784536, 0.006389900114417317, 0.021878078752647967, 0.04371079743929929, 0.04645493587539081, 0.029714570245555336, 0.02073527475248181, 0.05170806972009521, 0.017331572917981014, 0.07904037848235139, 0.018450578396779396, 0.03361406886289197, 0.03432481842596204, 0.047464555489920804, 0.08381800921333414, 0.09948143525229347, 0.05138834675533637, 0.045572004220899076, 0.046289476205504713, 0.01707822955664127, 0.03507936906610285, 0.0361197815847493, 0.05725860655788453, 0.027734487685525132, 0.01989167405202264, 0.08545369120134462, 0.020120251705990206, 0.037924837951938954, 0.07529466818537443, 0.02151730305124675, 0.02252069628617216, 0.059443159900125, 0.011730373728149121, 0.02826423556994527, 0.05894011209508585, 0.007835733065862329, 0.11488464420601247, 0.09173279297688315, 0.05834877265677337, 0.027145634202526945, 0.03206623992281816, 0.026336348495416106, 0.007226499250053519, 0.07232987727489203, 0.02778181659748718, 0.039203484662838524, 0.05754657134774232, 0.03968076893098412, 0.019954788205664487, 0.05677958327015081, 0.025395408663297855, 0.041691987219476895, 0.04543514261322637, 0.01635270981839107, 0.014558121085076805, 0.0370579558394609, 0.018844604229314194, 0.029042312770240733, 0.04122220295211, 0.009499488345858072, 0.04473015786178651, 0.05530477591579961, 0.034081600831761476, 0.03552135583313723, 0.04419305744851309, 0.031034432486781192, 0.050644486872178894, 0.07050017585917827, 0.017703215576588147, 0.08930734328685269, 0.010224574286821149, 0.0661275375093664, 0.05429555083655062, 0.0334875762552744, 0.01743269843920585, 0.05450897144093629, 0.02588668744260025, 0.011445825690433625, 0.07845242898310385, 0.03353650629099819, 0.03826327261424834, 0.06321699711524191, 0.03108104702175385, 0.0460652575918263, 0.09199634254459413, 0.041726836559152415, 0.018588125653144334, 0.07113742311635325, 0.055310100226873354, 0.0114695351540802, 0.06319219501869333, 0.06574263195357015, 0.020903206971143524, 0.017051981469135613, 0.06142035239346086, 0.014727884253877548, 0.0264521426851711, 0.02146086918430463, 0.10293059291378145, 0.02944620006958083, 0.07290165465805801, 0.041418302308527694, 0.04071304942631433, 0.027899058693419063, 0.0424262939862186, 0.008387895725337009, 0.007594952588870882, 0.007573270864198886, 0.031067445130658247, 0.0055659873948072, 0.03337530990041072, 0.07462210427489012, 0.030364434970843217, 0.061291117191074364, 0.08995254253668171, 0.05324111124801059, 0.038412904907618804, 0.05588941591521425, 0.035184039659197294, 0.04797490411287835, 0.01522255967551422, 0.04867238503309989, 0.0481454735892194, 0.05005165739285369, 0.10759406122228793, 0.030576281264544498, 0.15041739559702336, 0.06389192440697262, 0.0564299752154658, 0.01968553319813744, 0.049743448729596795, 0.026701607726394173, 0.029737208143717823, 0.01952867286520139, 0.045140401775678324, 0.02360135714914049, 0.030679111331400853, 0.034740785016648235, 0.04400756074896744, 0.04155674971820366, 0.04393891544051228, 0.07416330953879703, 0.04304850676787957, 0.012992544760627132, 0.02559777078849654, 0.0251612845327585, 0.016471819253638387, 0.06292332497034824, 0.04282697329237577, 0.03250115378309162, 0.042004643023134246, 0.042701989877969034, 0.03926203676289128, 0.04282403917562577, 0.06343066286776336, 0.04019363415277293, 0.009399801154711075, 0.08328305767668832, 0.04313241637822601, 0.05985827613321524, 0.03704656411202685, 0.021923473292601206, 0.018898220807914774, 0.027353048677586263, 0.014216917014921145, 0.11165792017333931, 0.05635617413528024, 0.02331638967828645, 0.03093587719054232, 0.02383988820046427, 0.05827987453930321, 0.06880205004445969, 0.04876095628846557, 0.02108647243960971, 0.11858338565235177, 0.04019755269250563, 0.023389907305940025, 0.009196246805180226, 0.07394056181393324, 0.0343940191481623, 0.026953152696331664, 0.016141382549258492, 0.032374511788328814, 0.080728093162179, 0.02350444128105958, 0.12221956835879434, 0.03049294813536108, 0.029495269916350805, 0.08352473543416108, 0.07518291893985964, 0.023586378215000998, 0.04890883424048943, 0.05227261523325598, 0.06063673637747284, 0.03029116249132541, 0.06680180213504261, 0.01589267785030027, 0.055930754019608425, 0.0377775154136602, 0.015071300402914566, 0.043982283677905805, 0.03103745087320286, 0.0621420148790123, 0.027890357849819046, 0.056721739801428014, 0.04428768079848059, 0.02753864113812245, 0.03748774648674073, 0.038936303838366465, 0.0788584019568178, 0.064142802880416, 0.04642852882464086, 0.018591818196939367, 0.0065376669836921565, 0.060265919178604126, 0.0201732266859542, 0.01894166948454034, 0.01802665023734012, 0.05486290023151425, 0.042702985792270595, 0.01798420513589536, 0.05831293506367553, 0.0669509747756585, 0.05576688015172559, 0.07499526570280714, 0.06184985575776908, 0.025517743328706394, 0.04469902021810413, 0.007335244952100179, 0.0198750939941214, 0.05556956271550829, 0.037257628996045365, 0.05034090537998465, 0.046047292830001925, 0.06226535503482146, 0.0311736210865239, 0.05022432211966765, 0.05628117412749318, 0.08624545839284697, 0.014454455024773076, 0.027466651855877815, 0.004211669391576922, 0.07926797554377588, 0.06274691024314492, 0.03507173116949778, 0.012937360574611494, 0.06864759139716625, 0.07068442000496773, 0.12008877140620064, 0.014774333122336577, 0.05787735279168814, 0.034742692575579694, 0.050593948051814115, 0.022843408909055497, 0.024847328294849685, 0.04672407022406978, 0.027007458754064097, 0.015139382636745372, 0.04912094100408497, 0.028856329604863163, 0.012840929257142688, 0.05077055813143811, 0.018123704001247402, 0.02432799346054033, 0.011689050945513433, 0.04922679903346205, 0.010886845806042754, 0.05095460309436725, 0.008995714672510664, 0.02543623731922238, 0.028393369265681798, 0.06308842074847029, 0.11105520815979089, 0.026175684535936005, 0.08330423234691543, 0.023290670191448544, 0.055735367124960314, 0.01703711553296495, 0.018230642214597716, 0.017345031167590813, 0.02898104680371621, 0.023760663217774803, 0.046913956607421564, 0.039500313089980234, 0.050613617359270016, 0.01924278034317878, 0.04233762313942275, 0.17235004853817726, 0.03446042364943893, 0.009839242594617029, 0.05406843641051843, 0.07343846012748058, 0.06338317307733721, 0.029054120100373705, 0.015562092716385041, 0.04486525746723337, 0.05888367822814373, 0.03268365890929296, 0.02369121734743878, 0.065415657966608, 0.07905031464272931, 0.07397433096963553, 0.020450203859757994, 0.21380419993112165, 0.22419321020284008, 0.22793751089803635, 0.13711605611587727, 0.09659483893624238, 0.1290872248430406, 0.10954447511223056, 0.16998395534052005, 0.22192085552359783, 0.2070317375323465, 0.11448359717765164, 0.17382934899820437, 0.08814928647611411, 0.17552260249372453, 0.1717082966840075, 0.19557686913157665, 0.08990032598376275, 0.17096866943663167, 0.1036951180186964, 0.13766190908368559, 0.13213449277945105, 0.11140895691970665, 0.09788914448431424, 0.06904652402285608, 0.1486642953128584, 0.1113177618132003, 0.1441738862664469, 0.1287023422698821, 0.1464838865062883, 0.14174567865988902, 0.2145758802972494, 0.12072811774428814, 0.17228437948130793, 0.1300084149284709, 0.09627915708528412, 0.16552933792193092, 0.12620753097918727, 0.16704407760933523, 0.23559203161106956, 0.20855467436054062, 0.18778572429812726, 0.12019631482901112, 0.10032685158113319, 0.12336215019346246, 0.1939189629328828, 0.10176775571439536, 0.08425325440663485, 0.16089536399850923, 0.11708525475114585, 0.15102911680456133, 0.08592174794044226, 0.13610419186372913, 0.10002258444024671, 0.12283677475587015, 0.10230535025437994, 0.13040858861659804, 0.1547481825635318, 0.12232276040219492, 0.21218036932329978, 0.17917109623311028, 0.10083337359490896, 0.20343884645450502, 0.13636440128809021, 0.14650864646800105, 0.37701696457882083, 0.16307676871938093, 0.14081393188286212, 0.10414104247766157, 0.1281025184078082, 0.13571049927944137, 0.32782992167818936, 0.12676276852406804, 0.1943937995501103, 0.1322073630628086, 0.15793581312942892, 0.13690938091566487, 0.1924922314262198, 0.20431989353270302, 0.13500022852132398, 0.09859317928672799, 0.09932773503204508, 0.09045962379464219, 0.12627455601168255, 0.18738653120254317, 0.2993562415001854, 0.12380109559143744, 0.1786579858631857, 0.21291665642732577, 0.12053199157479311, 0.1414887634136023, 0.08330122162137302, 0.19699042392594202, 0.1668704667639348, 0.11143502689176991, 0.12245082732049689, 0.15666301933027085, 0.13328302711729081, 0.11530757070549073, 0.16932341901044692, 0.13471214881827756, 0.17617362401177808, 0.2003264916880477, 0.053932298755934166, 0.14866552105353725, 0.19129661332455375, 0.1567864820601479, 0.09060007835467977, 0.16356629890299615, 0.08937301234372201, 0.1402523434690891, 0.13408889032659993, 0.07609197419256934, 0.14212735898552403, 0.10553835620803219, 0.09548971114019233, 0.1660874942618032, 0.12942756706428143, 0.11165654887595486, 0.1651655380884486, 0.14658193043883772, 0.20653574156665033, 0.2657847977694004, 0.1422144785042732, 0.20965287672175517, 0.14858241583551132, 0.14270840603257381, 0.1337950496423629, 0.19283568396443324, 0.19548656268706247, 0.10686244725460008, 0.17274216298134099, 0.08212260301074675, 0.14743121551169505, 0.18516875262702667, 0.0940964729975789, 0.14131303816553087, 0.14975089910289935, 0.14729148107430629, 0.17595954840221714, 0.16143911788540502, 0.07875665781959411, 0.10802478649683538, 0.09216257596328374, 0.14858158846055308, 0.13449549915329104, 0.20479420921014202, 0.07033284693475693, 0.27399925214629023, 0.23898964687701196, 0.10513458956754017, 0.09734362859519259, 0.24310232861147774, 0.09738223176569709, 0.21035954686662844, 0.11973805635446504, 0.12589836853646463, 0.10850427326776328, 0.0992655286925935, 0.09248319142047437, 0.1919860464911307, 0.24797785005742506, 0.09735489008767952, 0.15129301877271745, 0.126984259864736, 0.19657289068545067, 0.1376685740486268, 0.14016997369547046, 0.1440503775712944, 0.10885478147575933, 0.11086232254221556, 0.1154631095367574, 0.10513416821918181, 0.1704352270931967, 0.28417173532709, 0.12007632247743108, 0.25994610461977224], [0.06033285994142775, 0.05526004787234049, 0.04318298967254739, 0.021567177290337223, 0.046887174173588717, 0.04059340564473983, 0.017017430903750564, 0.06672055084979342, 0.07867929826100027, 0.018964652122268756, 0.1140533238949795, 0.05362963656924906, 0.0651088091094167, 0.009730264672168322, 0.0723494508213574, 0.022825379029757554, 0.03771564232245569, 0.025232021261246938, 0.029827487775154655, 0.01139214207913967, 0.0025307752883001683, 0.03072116189756461, 0.05888562026103178, 0.12516681585581074, 0.06060766717118602, 0.025650259302628618, 0.02958244497647449, 0.021267600522767154, 0.027273521090166706, 0.0141205144257495, 0.041831488000048746, 0.01995646402299885, 0.0418071034214189, 0.0565722415734443, 0.07208557183583898, 0.05401350790634752, 0.04211642291216601, 0.04838632780217356, 0.007367292325192642, 0.05932964482194474, 0.05560960996175005, 0.056605340402212836, 0.015137499975671452, 0.07187717293779697, 0.023053554487564874, 0.021506677411736983, 0.06022259690648606, 0.03177321320700069, 0.0172790058798367, 0.0642585625962144, 0.04316553818963228, 0.08123490628936599, 0.080190674822417, 0.003505327946303653, 0.03553703765294725, 0.029412450066076654, 0.03251037365126033, 0.027781332046875072, 0.028451281682317777, 0.047729568285567146, 0.04136482171053368, 0.02663135746373765, 0.02684795158734966, 0.03607709133516877, 0.055166608128216, 0.056542724205721775, 0.03012628887870139, 0.022212596790444468, 0.016594785941584457, 0.026266801118430112, 0.02827071858900449, 0.05193221555542081, 0.0377811121964647, 0.06803302800342922, 0.02744833660882808, 0.033669039501898715, 0.010154797083457873, 0.10564831280780417, 0.039988908646327835, 0.029989444508006977, 0.03526974957616579, 0.00643078335410645, 0.045196521546571486, 0.0382787475903188, 0.023133407662352248, 0.0362177872129025, 0.05554274963815847, 0.11912040562639314, 0.013756093103438618, 0.07674183125697798, 0.0427891630228729, 0.015169319437606441, 0.026906356215476993, 0.04237437620759011, 0.04088131680844292, 0.051330510947492816, 0.022062841923006123, 0.035527220236197594, 0.059030575587624506, 0.018014660961325132, 0.008613514364697039, 0.020724693163027687, 0.02195394443978946, 0.05141239425527954, 0.02845940029909534, 0.10386281466532139, 0.038878843413605806, 0.03058252105068776, 0.049357102928502906, 0.028594565022015767, 0.021786573380532286, 0.05514027002537924, 0.03151955000395256, 0.08249089211946534, 0.03213724286686028, 0.07199620767947167, 0.017201556305911754, 0.058209340824114705, 0.0517191473514803, 0.06978773707223516, 0.011187624374044039, 0.05776089976631826, 0.07351545962475001, 0.05689801663280495, 0.02548919506220808, 0.04880032554689435, 0.026956197895830678, 0.015383055095650978, 0.05321906706798942, 0.01040590442566862, 0.06388829315021154, 0.03362018224452773, 0.045789006286330765, 0.02832428154145037, 0.031461086004011096, 0.047603022051794876, 0.03497320843199569, 0.037102863913582224, 0.02546111410934358, 0.04853062046271178, 0.028914950652829105, 0.05757085633494201, 0.033297383436752905, 0.03233991525766831, 0.050811639596377654, 0.02635850758862592, 0.06234334278551321, 0.022523808518364545, 0.1195175379454609, 0.010637228504844732, 0.04343243173113273, 0.05592307015772789, 0.012701650642068877, 0.01652866489283981, 0.02493381387584152, 0.026779865523079233, 0.051172286978051554, 0.02701740832098069, 0.014619065294673127, 0.0402105417132618, 0.04101770344160257, 0.04394397545125216, 0.049725280954472484, 0.03860609312992423, 0.017339689619538766, 0.02843292813087183, 0.034420043154950106, 0.09741601624315786, 0.06988459356850193, 0.047580116022858894, 0.04784437422189982, 0.06391598339823466, 0.025335039019644744, 0.029357609662017035, 0.02247197500940773, 0.02677988276005753, 0.027742828467800736, 0.04190355389108581, 0.015320872696447036, 0.020810987222038453, 0.03693706716500944, 0.027651711885306626, 0.025712886990438548, 0.03497110169020391, 0.04749679246977453, 0.03558811656529865, 0.0974286949983047, 0.03484932818419991, 0.02848723227338445, 0.039535047516467116, 0.017157347287021337, 0.012125635835071726, 0.034617092460393906, 0.01567346179076741, 0.0305105451749818, 0.024975703563541177, 0.04138589295889101, 0.07702809533164387, 0.03196513929945086, 0.11453255019601315, 0.04198862795507716, 0.04292788239376199, 0.03710461825492882, 0.021371321166835485, 0.048179403623385776, 0.06185424927201483, 0.017423380894826788, 0.059962586664985267, 0.04038037574519554, 0.0315270921395671, 0.027273199333238508, 0.05535684308157333, 0.03938133963533948, 0.020705816756573417, 0.026375129781362992, 0.03350680123173422, 0.01775000631178339, 0.031196040649627967, 0.031485200536647634, 0.016750983608466004, 0.013191839661298981, 0.09106534653373304, 0.07246295440821879, 0.05405290014741402, 0.01446842463807233, 0.04897995401294001, 0.013170974299071297, 0.045970975150985104, 0.05283743270762986, 0.028301526814879432, 0.11029097416828718, 0.04465097501393288, 0.050493406672631545, 0.006924523669670547, 0.035953015734952305, 0.028098321992964036, 0.040893240966984344, 0.007365471908762571, 0.014915159235017435, 0.03045605908658716, 0.06757230272576695, 0.022026201852807598, 0.05780858107872548, 0.0027673322268040672, 0.01833736975376885, 0.06544495316883249, 0.013947751065115295, 0.028551518541550445, 0.033649787712361545, 0.06775200397016541, 0.06400351277402332, 0.023324764934518648, 0.039803768177666975, 0.06561793582213503, 0.07748143552171607, 0.08180364996435181, 0.05700199391632792, 0.03692954035115339, 0.0572115496071356, 0.08584025916793654, 0.017133284465319688, 0.040262631861673254, 0.030232014757911527, 0.08683051207974073, 0.025574696220217213, 0.03317846743870647, 0.018930620581452406, 0.029625677233261448, 0.028410292147929152, 0.0421633304757697, 0.015841504134568238, 0.07438755879599242, 0.058878882517737735, 0.026378812749058973, 0.023564874126966444, 0.020650618206409198, 0.019241644617831035, 0.029702383701899843, 0.03532528328979689, 0.05158554544792541, 0.09640848038778191, 0.08076527140914433, 0.10821338968291398, 0.07208505855692972, 0.08198692883935668, 0.053459572710938034, 0.029314093952698093, 0.043263425074157216, 0.04860872312659218, 0.04907565754688075, 0.02618509018042636, 0.07646350385320765, 0.020923312948716265, 0.057105415786105784, 0.06345063861038897, 0.019979417932430105, 0.04090706119313836, 0.092657124022803, 0.032676637713466926, 0.038793849788846514, 0.03929470658242222, 0.02055579375836157, 0.030724396703824885, 0.04974775797417087, 0.06112573796042031, 0.018593612757901994, 0.04006533357765406, 0.06797758622034904, 0.015632180185357652, 0.018775457133268638, 0.046947871319829464, 0.044907491894498955, 0.05409053038625468, 0.057204539902628436, 0.04682495634281828, 0.04283274959532484, 0.02579272292824763, 0.026938420825547753, 0.03424767720242662, 0.046648606733088537, 0.05151149921960408, 0.05221838386909616, 0.021941411241348234, 0.030910128975407253, 0.10822815219721488, 0.08720545083164208, 0.04064605886777563, 0.027107921609234427, 0.027115371814298055, 0.008292975516298847, 0.0247519024677815, 0.028773988559541684, 0.03879369274082203, 0.03538028074188098, 0.031904648996949676, 0.013792446848275441, 0.048068393652717915, 0.029484952627230557, 0.16474714682948205, 0.047428388479015524, 0.05377443484781731, 0.04222137312735281, 0.024408827227870786, 0.05005295591188535, 0.018252060117740786, 0.009680224766564226, 0.012512762088238472, 0.049634028391371814, 0.0166899532139782, 0.04501480166049254, 0.02789388376949055, 0.04052874782393056, 0.07534601905893895, 0.15829141582212142, 0.09723613113765756, 0.15118728331740827, 0.08894348982721569, 0.11411408232825418, 0.122933822774118, 0.1412816745259108, 0.18137206683956808, 0.16289330598327423, 0.1933465573576189, 0.15834067527565265, 0.12202769397727906, 0.16797944032136472, 0.12114450951377231, 0.1168438834288428, 0.1551144645218888, 0.10591148699243223, 0.11241656938387502, 0.2162342614704563, 0.12842706389605038, 0.2549251796857965, 0.07818291159046274, 0.17239544690857012, 0.09726581704472342, 0.14973473464769704, 0.17867284796891675, 0.12361088362071784, 0.07587180818401038, 0.16185861231098253, 0.16783278044914046, 0.06350957375440387, 0.09893501537942118, 0.09100434295232258, 0.19101411074159608, 0.1418160821401304, 0.11722845190595235, 0.12645199729670442, 0.1764836291512174, 0.11928783414224464, 0.13342133663114042, 0.14706363120386678, 0.08522323663196257, 0.18283929375390853, 0.10413298323269814, 0.15422555738158766, 0.12803861901404398, 0.15182630789856758, 0.11621291043176768, 0.16395502723753452, 0.09543040061309453, 0.25643029730887185, 0.13655443705858725, 0.08982428409639867, 0.20489639001748255, 0.1467169610963714, 0.14457963707466281, 0.11157334406649876, 0.10141521737339998, 0.14363655219635657, 0.14304638870300787, 0.09264741768880237, 0.11328584169067683, 0.18368027443366666, 0.17471974234907858, 0.09717186402168967, 0.13650415104723748, 0.1380796721505542, 0.07981690052416056, 0.14756442287996893, 0.1146908239611695, 0.13219620882263108, 0.16357129379626245, 0.14328151640872802, 0.1383968478729648, 0.09664518623462609, 0.08144130569792564, 0.20514984254635152, 0.10041160388819634, 0.16241246323672034, 0.12240018890870195, 0.07759211224413688, 0.1740019026422693, 0.1090602539179306, 0.1055970615256698, 0.09720541101189391, 0.09411100568550249, 0.2703221220402949, 0.10339157100045875, 0.1349156830580004, 0.11376126053472681, 0.10284561078034102, 0.10174622098284383, 0.1097126467333686, 0.14398890667625014, 0.3434132225811482, 0.1035226256616654, 0.1331267298589791, 0.17766288361482083, 0.15582122659731298, 0.12783808017810508, 0.0924848614921493, 0.08946557874761282, 0.19763939232835848, 0.12033521423056243, 0.2099347817561319, 0.10396122632007446, 0.16827263749174534, 0.14300008634886435, 0.1301686498787134, 0.11535969532785878, 0.12436181066497681, 0.18622207755763687, 0.13030492159868443, 0.09290975683759298, 0.11321079571761432, 0.17486513051534855, 0.15105600649070355, 0.1622083161266581, 0.10546038377909892, 0.10845998572486062, 0.2110200372314261, 0.13852423297301417, 0.1206837076273176, 0.10002443837302347, 0.10767637736975186, 0.10821302196071034, 0.10715196720294415, 0.1753898547782052, 0.09639819948783807, 0.18970347219897857, 0.14172677160991778, 0.12881748528490145, 0.1566358078872004, 0.10952991178078998, 0.17974025359557522, 0.17279074827749885, 0.12121110553703002, 0.10671881342967672, 0.09289841107543438, 0.14028626584237622, 0.08779507040256455, 0.1226149999626702, 0.13271900254391855, 0.14408161863684654, 0.07968548580162949, 0.08180997785060637, 0.16302724879595543, 0.31815374089825543, 0.13066605544619023, 0.12328367980737841, 0.12511378724969205, 0.17973383377876975, 0.10856765938261825, 0.13899082648417643, 0.17274801589308247, 0.14461202727210137, 0.12759209700649785, 0.10514401244900881, 0.27615695410678465, 0.12476321775466205, 0.12275232888397672, 0.23072312916478804, 0.15924298895462868, 0.1628694653270706, 0.11070969484506116, 0.07801198205279727, 0.20219873396619675, 0.12089337057043469, 0.1540089230383596, 0.09269452443526638, 0.16041386241634048, 0.09444657517897506, 0.1650871826155532, 0.10344337386589858, 0.0686798130552615], [0.07925052406086076, 0.03133597618509685, 0.030427167995742736, 0.03384052062286966, 0.058856382515401616, 0.04773675802073652, 0.06462320129597379, 0.023971998147786628, 0.009653462442539392, 0.025555856202939348, 0.044540202530521544, 0.043039080055971304, 0.011847787236254062, 0.03713306692999698, 0.10185430066720133, 0.031711682940142295, 0.016855646540681203, 0.04873953647010269, 0.12447960434421418, 0.025385876614299994, 0.04182474259587546, 0.040319958221047156, 0.05257029018755402, 0.01891638092215984, 0.07512223711537738, 0.03690966419995793, 0.01157156944710521, 0.02644542983973459, 0.03251522681826065, 0.07821827420904752, 0.03493062926516418, 0.010539064871057147, 0.06511967989706224, 0.04510168369198519, 0.015893487988280195, 0.07873967365031281, 0.03915311438181708, 0.06073456963584308, 0.0892468529843515, 0.02389014548351688, 0.04005193086941877, 0.024607969868567683, 0.031906273103349155, 0.033951438662986604, 0.04717588589917268, 0.03346198508816381, 0.03769703021633529, 0.08193444415566423, 0.05064268656555684, 0.042766708985812245, 0.07126846245580143, 0.03287563671267802, 0.03451914428883503, 0.014656684042194919, 0.07847268434782183, 0.011633692474495019, 0.03553577743831181, 0.06360475251811647, 0.018957048699620272, 0.027786049233268828, 0.06407656691848271, 0.07640487514436245, 0.09055271113832151, 0.03386583216788788, 0.05256414233196167, 0.02272570141470961, 0.044729054695175546, 0.03148162290604124, 0.07925892804539011, 0.050755971817359816, 0.03196666381442018, 0.066144184599961, 0.02292687035796623, 0.030805772478361765, 0.016848910712606965, 0.008798410642832037, 0.06097055536003844, 0.01285700465462381, 0.10089942569574041, 0.0016314184693093864, 0.04628189959593358, 0.04264387061759349, 0.06004566890037349, 0.042873869364660595, 0.03320958976063036, 0.043737851834345254, 0.02163212622455772, 0.04164603343533893, 0.013181109642309528, 0.04712124467797337, 0.041141304067305984, 0.07515802108232053, 0.0281377257253494, 0.015865689530337772, 0.05879992566582176, 0.036348711639162035, 0.034851166795218186, 0.01569195132281992, 0.0697867411579336, 0.10030144810556404, 0.03650917641578182, 0.044459885872539975, 0.044826796022994865, 0.0595221933608334, 0.07947593011082181, 0.04861746802024784, 0.06487550469295633, 0.030838130117063562, 0.010542618561415903, 0.04956049544195976, 0.05947225974992879, 0.10958022077477748, 0.0029591759648023835, 0.024895070894290845, 0.04505497531124181, 0.0505487718469193, 0.029211453492603, 0.08619854316836403, 0.028681960332417683, 0.05422690935853509, 0.014842603047708831, 0.03154383307593244, 0.04349147795789665, 0.04139826527886814, 0.008081076554052772, 0.05488788618916466, 0.07773089673249953, 0.018219164302272182, 0.04600977750434991, 0.028317132025897026, 0.10675486552739337, 0.03837340158380328, 0.05003445105807436, 0.04439609373108514, 0.08535355584876192, 0.04806363624670813, 0.027138210810540665, 0.051477255089388746, 0.01469485724585191, 0.03244855801665014, 0.0366331102897323, 0.026779197111365297, 0.061540226001412644, 0.037410651228480765, 0.045236549640615145, 0.052596471242366306, 0.06264569470658898, 0.017800995208803686, 0.028633947686983213, 0.02369622181680414, 0.04202076917394035, 0.0032431001196645444, 0.02665721676162174, 0.05064356373623014, 0.047801718446275884, 0.05971707846789111, 0.010508862812252296, 0.03676337971081657, 0.06914612311389177, 0.03399357349882203, 0.007339735663751321, 0.05328128489875986, 0.028068898471012235, 0.052602010058058854, 0.02293317717680287, 0.008994983058542976, 0.01449295285818798, 0.01813204669874282, 0.04111618787470845, 0.056466023482742815, 0.01041891930189224, 0.022317774916788744, 0.06469458536875826, 0.02938282927648435, 0.09486441485463612, 0.04584268989762472, 0.038215610454039234, 0.01644098229946629, 0.04230538232912941, 0.04011718623880898, 0.09589401404223136, 0.03952182100845441, 0.022009857366943074, 0.021944058075126623, 0.04082676751779453, 0.060975837536276355, 0.018538165229162382, 0.03446057303658417, 0.048319099756378325, 0.02046898833566135, 0.09581719074518451, 0.03550546333914803, 0.06012469086976302, 0.003781194771422194, 0.04012600391081745, 0.025166003634372068, 0.03375202980673602, 0.03757840150126046, 0.08844481255378454, 0.08231813163166085, 0.02444323032133041, 0.06425914482303685, 0.09231556372176256, 0.03355304995972303, 0.017275112237961545, 0.019228615377458836, 0.0827561577241267, 0.024126449134200815, 0.03849000399631839, 0.03995866349507724, 0.02322814401028858, 0.051499575061062654, 0.039674058000767426, 0.0485936043814065, 0.04702791218615828, 0.01105322861187761, 0.06879563022765421, 0.0071266253249749785, 0.0052166072512796575, 0.05601100556011643, 0.05360058268472072, 0.016063790291457648, 0.031926298641689846, 0.029869444495547685, 0.052160011799705606, 0.0720994993143024, 0.040963322690297524, 0.05980364257289518, 0.016190743509439692, 0.0641672678982779, 0.012105959824346488, 0.006420095469952832, 0.04416159804790251, 0.022793316334906607, 0.06402533095810684, 0.01922324127067001, 0.08920256544144885, 0.013475293150892662, 0.02464936734477599, 0.06722853609150456, 0.05880836412430771, 0.04673489887687949, 0.014699995780604021, 0.10621897170260068, 0.04331879790932421, 0.03431970478906747, 0.045323841529147285, 0.08438712827140286, 0.07703973986809293, 0.02652783791774944, 0.03546818550075254, 0.025690316124969435, 0.05129437841054413, 0.09042514983804957, 0.059624377998613545, 0.04880199561856928, 0.036838203518381046, 0.044058356208786856, 0.012015674447250223, 0.07412296734870442, 0.013554736468640548, 0.04143763070685729, 0.028483399918543238, 0.04109335462412527, 0.13477369632211425, 0.018050071460405187, 0.028322305034605727, 0.0555917218087181, 0.030142506960058407, 0.0291266571354842, 0.07380776047225922, 0.029044806386434266, 0.037813525376541, 0.005060830453951513, 0.0633982228746097, 0.028098670562969583, 0.02440603483738678, 0.028334313462818825, 0.06770085994034045, 0.008010170328611088, 0.020331988832162275, 0.017043682821695844, 0.055076405105571595, 0.06593357170781781, 0.02750310998019432, 0.046146934055873466, 0.0514338102432028, 0.032291203557002934, 0.049098977263295845, 0.031195263070384824, 0.07054286227831918, 0.04986220001873951, 0.05784584359536248, 0.14992633323755958, 0.02596808811499467, 0.029272924387647264, 0.07231160607789794, 0.03334717532139152, 0.04683853142083653, 0.052141460980619156, 0.0052953280523539556, 0.02043085247879067, 0.018116286354920557, 0.045993816062447526, 0.03294990510649739, 0.0528767598312228, 0.08599259575167972, 0.03256494209410683, 0.07429173651842341, 0.013413612539279125, 0.0694154260019141, 0.03626904998635573, 0.03415362075752309, 0.02580311108050087, 0.062335923223966555, 0.01936850494765226, 0.015278517610333381, 0.05016292783341581, 0.05619404694786476, 0.04803619497726041, 0.02360771376369221, 0.0458912598720241, 0.05839014906556376, 0.05185545737584753, 0.020895404365634727, 0.06302334540974229, 0.013592243175803414, 0.048685826045731385, 0.053917417498005014, 0.020391655590144858, 0.0542400477664365, 0.006688959772638496, 0.055585359448506955, 0.06289744268982642, 0.012640503419172621, 0.012544746259077182, 0.03532385070537848, 0.08262139519736653, 0.02167580472756057, 0.02295171458935065, 0.026221596185238134, 0.11601231030879483, 0.06792565311996207, 0.029094312903321082, 0.041743889676346894, 0.040078353241927205, 0.035628385977038456, 0.05041230094408797, 0.05420294229782397, 0.08046461254238121, 0.04475055495277048, 0.08322118841592344, 0.20053466842059167, 0.12020494097903853, 0.16738529317080977, 0.21436496096993649, 0.20471214587169312, 0.15766720738141768, 0.19387704260166616, 0.15085573578553815, 0.22176135601776265, 0.15624278946028602, 0.13113315457538252, 0.22611160161754779, 0.14502838073718935, 0.1020027914895646, 0.16266914865662976, 0.16903068149282088, 0.2002259962741406, 0.16242737130772683, 0.1663492052184959, 0.1123041153374699, 0.16498828066452859, 0.1405778235845989, 0.25035802395113055, 0.15607156880920933, 0.2179066007656436, 0.12768644839525223, 0.17209302603958115, 0.12139051566801726, 0.12470517893351855, 0.18360239393528432, 0.10259532985547859, 0.08454298119871848, 0.11320284372496028, 0.11925762729539026, 0.16190278494069654, 0.17202849079283977, 0.13752994277784902, 0.13939977953991584, 0.19075140387060183, 0.07716796000397975, 0.2506060525774956, 0.19114958573012583, 0.12519693843299343, 0.1524517880452256, 0.12789488559769047, 0.14605942783096146, 0.1218135953850804, 0.18688891113044756, 0.2137325860319599, 0.17410766874109546, 0.1793560298580316, 0.1613846337122302, 0.20607235030301158, 0.20936534860201422, 0.10337788867013109, 0.11936303333289201, 0.0991006589104091, 0.11016220244909487, 0.16573193753438611, 0.13325829779909504, 0.1835049935165913, 0.13140963570725533, 0.199651139217519, 0.1179196700573929, 0.1291253606999113, 0.137714140958363, 0.09606921068963506, 0.16648359236217317, 0.15390864212907132, 0.15626473021843743, 0.09227546667980571, 0.1483248877188852, 0.094732777966607, 0.14932317689301508, 0.12125078889150774, 0.14445225197461345, 0.13528901302526075, 0.2145907730464974, 0.2672179031275934, 0.16715261694644729, 0.1704010595717738, 0.1397893965364464, 0.0998648699192751, 0.16956646806530415, 0.15917736586303483, 0.27255441032109723, 0.07942967372195375, 0.17329762269171978, 0.19046510149153972, 0.159322508881169, 0.1251845967565333, 0.23181379322082768, 0.17281854194739174, 0.13480178110541838, 0.15075680319099657, 0.08610204673342167, 0.11296263685630215, 0.23307943175877296, 0.13182637221630544, 0.1427517666090881, 0.08223684970289469, 0.17465068718358395, 0.2074236527926499, 0.12501529898614655, 0.12085031642909012, 0.24524104691320853, 0.1595431115598448, 0.1411051525463981, 0.11380657463544801, 0.1620958544193737, 0.18718973853655402, 0.16728078345617942, 0.13490054516061661, 0.06943137595249761, 0.19068590335307584, 0.13014125457454112, 0.09279556377159973, 0.21926014023202084, 0.1398913934826851, 0.18330965641765826, 0.20295162985642112, 0.10748590492913801, 0.13441545828696222, 0.16231864810951296, 0.15665319808308156, 0.12465113909133982, 0.13339951844705691, 0.11860004806470488, 0.113717409661941, 0.21991393498836026, 0.2536751080544726, 0.15220195145135926, 0.1786967805556713, 0.0799717728589331, 0.12067578627818054, 0.1600945416477419, 0.08082842769762201, 0.10160192066142637, 0.10960206194149871, 0.13898270595217907, 0.1015571121787352, 0.15112382059376087, 0.1762612031832818, 0.12573011264565492, 0.08759923534648073, 0.12474401959127958, 0.11546405182490427, 0.21506740230946772, 0.08076256711877162, 0.1464070019222075, 0.07464579937438812, 0.10009104971803966, 0.1383587426596111, 0.13450133674327405, 0.1295496048706193, 0.10174738543648874, 0.10791211794581144, 0.16545976181664776, 0.13926824224331688, 0.14475686385506584, 0.0868546515102348, 0.15772300922582227, 0.08252219447205145, 0.16648441973713138, 0.14394467275950218, 0.19733894796621418, 0.18897037202071762, 0.06501562217430723, 0.13849302255097898, 0.1887619041747624, 0.13642642376643999, 0.11842796173427375, 0.15064837110619392, 0.25252334082559236, 0.14797199697744462, 0.1420499841051717], [0.03114313270235735, 0.050867276731878526, 0.056810996705485936, 0.030640019779844634, 0.016572082925948407, 0.060200430152397004, 0.035975527228607286, 0.040044338938089154, 0.04428022293253772, 0.05084571901768927, 0.05816542866429495, 0.031853179379756895, 0.03877932476180215, 0.005037276123109604, 0.00894998496909055, 0.01334770312232356, 0.02881739893177104, 0.06164921349996041, 0.01879086890708535, 0.05131443459240179, 0.021969597531302322, 0.06133199181227435, 0.042862037136670084, 0.004797676379131454, 0.060494684524113135, 0.05691723011794591, 0.052888714633281195, 0.05067779254468699, 0.027903325803157304, 0.01548894472615493, 0.05833001499394736, 0.03428191750220234, 0.030600752028065826, 0.04867344606487502, 0.05213675337032445, 0.01561680288549753, 0.04422778421412072, 0.04135727574447951, 0.03682906408944438, 0.03532064079697575, 0.043191447283231446, 0.017406080714276722, 0.04634301809053268, 0.04642600456493036, 0.05678750844972749, 0.04295800880138432, 0.11218554024854976, 0.04302967632670076, 0.048266978964449904, 0.042805469204341216, 0.030152774453463576, 0.05369458933390918, 0.1184061895154657, 0.017698674590416977, 0.05770649220193586, 0.11105023624916231, 0.02703985852760173, 0.014653766204813316, 0.03395811511924671, 0.02802972456500415, 0.013421906398669367, 0.07439466809192974, 0.03487484274251807, 0.047764800669204806, 0.03277789155441908, 0.03486470739927984, 0.0403853974515392, 0.03009797043858036, 0.05387374282544179, 0.04108894195768141, 0.013463592115459184, 0.023024487196497863, 0.012230733522183955, 0.054551500812052726, 0.03288356955313394, 0.04415328599392407, 0.046477259677504344, 0.03233299748371205, 0.020919798520363627, 0.030949795092906685, 0.024135787745997794, 0.05094470906882517, 0.03212687961246458, 0.07880046272710448, 0.018786293446957585, 0.0254412513646868, 0.030041415912790165, 0.05347375299841647, 0.05761473402080517, 0.03333069677014024, 0.09052862533398214, 0.0784570025280118, 0.022784194142948237, 0.047293055216751756, 0.06902685088496055, 0.09926146076571557, 0.02928881113597703, 0.014596981852645836, 0.04898907045923895, 0.019364362327201713, 0.038798637838373264, 0.06460086217210179, 0.04064054303472081, 0.008239829124161794, 0.13736714909393943, 0.021803205149368416, 0.07783339163588901, 0.057253025607356144, 0.05335035538601299, 0.08197908409901204, 0.03896429286068005, 0.04589202212950876, 0.04900877424065144, 0.03402541594339475, 0.0965167209506035, 0.06277946897992684, 0.07650445891363968, 0.04390544505910047, 0.05212184912975758, 0.07492717580809709, 0.07194243596806642, 0.0571454898454249, 0.04773544034950676, 0.07072008139784298, 0.06491466710764555, 0.025081619049512574, 0.05029263034943612, 0.04184565296576869, 0.00799264223690355, 0.022865669508915276, 0.03320736810564995, 0.039151421327504425, 0.025070916801210374, 0.028568761265506188, 0.012448342712295633, 0.031217115728424925, 0.04611779973211308, 0.057967506018617464, 0.017648610744565245, 0.04669386337721541, 0.016086785378114834, 0.05129871446819556, 0.05418505797523165, 0.01352212793614355, 0.006305125303521392, 0.08661528733829338, 0.10910434227797294, 0.030023667570804397, 0.020864396956899477, 0.06585279539708169, 0.021708635425555612, 0.031553238720422795, 0.043141452385292905, 0.027097108278183207, 0.04544854915190128, 0.028020100585455378, 0.08112828217206464, 0.007257024023396474, 0.02961086875368511, 0.034208357739712925, 0.05341110615840843, 0.030047904677508824, 0.10050390216131365, 0.013709216183351894, 0.03943787692415138, 0.04023733180797389, 0.03149859749922349, 0.049385926986653964, 0.030269870992689848, 0.02725960701824196, 0.020603662762310238, 0.03857407448512893, 0.058497202192102714, 0.02801518421620131, 0.03669782173669627, 0.08187882617236146, 0.0048859589151106775, 0.007224197155841056, 0.018445522216479146, 0.025704203383816827, 0.017813064924050725, 0.054247750780515136, 0.07719206113007761, 0.10042017641206903, 0.05301107419654728, 0.09167024955874489, 0.06408068847151534, 0.02553709470967372, 0.05707256593591264, 0.038121358656715, 0.10956996285747136, 0.036944789331286185, 0.0650205021543849, 0.04623360924362656, 0.030802058867148818, 0.02911269326784438, 0.019187551149497592, 0.014137468909123733, 0.02578633950061856, 0.009914084596769705, 0.03440633401154511, 0.04287471972225655, 0.04049052386694858, 0.017548666913963614, 0.0692450097431579, 0.01939294698287643, 0.048256793825496594, 0.0305458560826317, 0.018633330586336313, 0.056142784174411535, 0.0395605314312683, 0.06099589371813401, 0.061824088390435905, 0.028407218220132976, 0.09432642960981016, 0.025256047693772182, 0.0747374464727698, 0.04594050783423647, 0.058795823264987244, 0.01957278612310127, 0.05017251159334856, 0.020913461058010018, 0.07898324364495855, 0.06532874529159839, 0.0046244528869377275, 0.07806272005602237, 0.01214428911841805, 0.06270780528505003, 0.037429018186465386, 0.02827475587236545, 0.03142729003523146, 0.04004202918299744, 0.022011454660265196, 0.012237454028499704, 0.0033701660962129434, 0.035835225886154565, 0.014858410314416454, 0.0784327864887253, 0.05284728842877573, 0.0442548232874082, 0.11235312964286535, 0.005693167087531859, 0.06034697894187224, 0.029184226727774067, 0.06247085045963045, 0.04220761801867236, 0.049947641804934516, 0.06811887581622408, 0.020796473686312957, 0.010284514921236663, 0.028451900298316634, 0.07661683635125238, 0.003379898764485974, 0.048479648802669785, 0.022799762964789427, 0.029037785190608234, 0.05156711720290685, 0.016103922764980988, 0.037443646635379524, 0.0518356042072898, 0.014359085696689306, 0.03453158555672534, 0.0806191707811048, 0.031213051631986618, 0.026248805713088765, 0.03426289553904245, 0.06425061060356037, 0.03007703517082959, 0.002937140403270361, 0.06807833444327116, 0.06693408253692812, 0.02691836847412971, 0.06664178168941891, 0.03229561239300716, 0.005715203606673787, 0.04479416067742052, 0.05485251974014025, 0.045123249067053686, 0.015014552439923489, 0.014304678132306906, 0.060006468181288054, 0.01860267366282642, 0.12088838333804762, 0.014520236122001325, 0.019258217014853033, 0.05509287216550401, 0.016301945002088626, 0.05469677406513403, 0.045300690352075526, 0.037710390789734746, 0.027032609420618223, 0.016190743509439692, 0.06613544353674497, 0.03758811166570072, 0.09555855946194741, 0.019758342194461057, 0.0038198053634034535, 0.06342458779052382, 0.01168166968836299, 0.07672773523917122, 0.07329706327929612, 0.08364511082970327, 0.028934788499628345, 0.021567368812318292, 0.036640889912603364, 0.03193820173281335, 0.05222663463604066, 0.04181678294234219, 0.014007360366503558, 0.036141883221364794, 0.029653495801011884, 0.04116899814576872, 0.04635628673338121, 0.06933804346068252, 0.024535451985655293, 0.038688941708495544, 0.07880309040868476, 0.0265536914699741, 0.04793008413886832, 0.11410921000905576, 0.03061674028304556, 0.04127330484709913, 0.10122360346177894, 0.048740961393641855, 0.040753223077063604, 0.02387681938407402, 0.14053461622566948, 0.03504103402637186, 0.04118399431688651, 0.06176565886445104, 0.12245980587096945, 0.04057800344702217, 0.04781145542379349, 0.07572327139637164, 0.050849775453248335, 0.037113776836063594, 0.06407924056533845, 0.039695451006052956, 0.017264385091801806, 0.07241154990849957, 0.053620700153612325, 0.050916325511230584, 0.013618170463990782, 0.019680521067892833, 0.08404307052372925, 0.011890116466900275, 0.0071743123830416275, 0.03328973787926859, 0.009237842506638939, 0.06356911410787894, 0.038338000660822276, 0.03392105944634926, 0.07269529355389458, 0.1273934121033357, 0.14806161394282696, 0.09277052801823424, 0.08997866613489967, 0.1250850895960485, 0.18441844611398636, 0.11607940428920331, 0.2395236561255109, 0.17115116690195378, 0.10537572340258669, 0.13585450848744762, 0.14368723657342697, 0.08969252463430168, 0.17378407320187939, 0.16517148293074102, 0.16775903682554924, 0.13853823706027002, 0.11251668175382, 0.10291337891812287, 0.2762141655529699, 0.1347047637306875, 0.09136773675920502, 0.19883551604805455, 0.1843801876830478, 0.154883197899307, 0.16390196798789888, 0.1401924813586858, 0.19755017372869677, 0.1677494913700127, 0.15824036372284736, 0.10700502387818792, 0.10968270035640848, 0.12126064078221399, 0.30851283080635533, 0.09820487996142718, 0.14543570968652927, 0.1399763832770048, 0.2124363192988019, 0.09422281621805123, 0.14971503086628454, 0.13218358369363895, 0.1957350203226651, 0.15547524596894943, 0.2293602281039761, 0.1895886662626459, 0.2615586277698317, 0.14261019356068105, 0.10982746033058052, 0.1752469640585684, 0.12262464500963689, 0.12856420129537582, 0.2331946054173093, 0.1572594034575647, 0.09242571950439485, 0.24330301300412227, 0.19213498930536932, 0.09983427236757933, 0.11581986136133633, 0.10423414514309938, 0.06982297711675206, 0.16591897024021995, 0.12926754661865775, 0.08284728388271986, 0.19197092391550544, 0.23029237324672364, 0.16059093597915866, 0.07247452999675467, 0.20318231425218045, 0.1254487668554629, 0.14846290611932356, 0.09763339369167244, 0.09861564864554713, 0.10612813665741876, 0.08965919980959547, 0.12842851946310652, 0.15590304478762612, 0.12333305417409829, 0.0548777278632887, 0.16813953737578086, 0.12851331007456587, 0.10778944428649642, 0.09709958362603381, 0.13318751127489153, 0.06665051509175571, 0.09302474663502748, 0.1421266541846337, 0.1525379422931902, 0.16740403168143766, 0.1239397038795775, 0.2069528457979041, 0.1716202578597492, 0.14159762450764257, 0.16010253960567136, 0.19289333974161457, 0.16935610032129675, 0.09144763206882824, 0.14217726195291167, 0.1389041819399403, 0.18668864042528216, 0.1081165485084057, 0.0986943718406462, 0.17709294484267313, 0.09750341921443902, 0.2643878517612334, 0.11304462358595864, 0.21072101779282096, 0.17061691250531905, 0.14922747718951396, 0.19548585788617212, 0.12462951242923738, 0.19795310533335134, 0.14667113371674093, 0.14927937198550473, 0.20327283520131342, 0.10841493975491294, 0.14719642488466156, 0.11979230304038334, 0.3207573060306811, 0.06998090614234248, 0.17410537047732264, 0.18673575483262542, 0.12755300353972182, 0.1528018749048633, 0.16873889392422092, 0.19014555089656385, 0.09725914441890295, 0.10636232207499205, 0.1050907846600298, 0.18024695947045283, 0.2055764615896248, 0.13072125974201387, 0.24223019879671837, 0.19606431555603782, 0.08536456453223383, 0.13341320077738456, 0.14455283931907148, 0.07514758696479183, 0.10996653593235439, 0.10317985494170459, 0.15996701865186616, 0.11169279249565256, 0.12164134817618517, 0.16587067605747333, 0.17811973248758625, 0.1915795602385075, 0.25452506728470325, 0.12605839664296759, 0.1410213578492403, 0.10994080303897781, 0.17298962470264206, 0.1140278744541349, 0.20955752941869923, 0.1709169125364673, 0.18527329298517398, 0.18076532520353797, 0.13697895702094803, 0.1710117542214932, 0.12074416728630183, 0.11242575477808715, 0.25121973497011973, 0.07757360355988627, 0.25561453624358105, 0.170120824609072, 0.17923866518803183, 0.11099765963491895, 0.08767170726411766, 0.14824579680158248, 0.19273299753906267, 0.12006295424315239, 0.12686739315188703, 0.1042324137843905, 0.14647103155091887, 0.18278461039787341, 0.15927335667994716, 0.17109507394413795], [0.01938345132305497, 0.05844985412794256, 0.026171172278061993, 0.04067515871757942, 0.015895306489490453, 0.02990343964718763, 0.036524256856571284, 0.10233374147285378, 0.05003509457193075, 0.06041981092083359, 0.03748973448490424, 0.029158828997864362, 0.03129278223270611, 0.023390728935238816, 0.04454433940531266, 0.03358384286383948, 0.05521420517095155, 0.04106703184304699, 0.016107283975748767, 0.018846161303020293, 0.07225495387589739, 0.028979543356164813, 0.05543437884038976, 0.05669443259736704, 0.020068596312475782, 0.07507682342322604, 0.10070233425546078, 0.062323102742553725, 0.013726576693325996, 0.030253411593636682, 0.03825534743467166, 0.04055860227033977, 0.04467510678354771, 0.015310099585011843, 0.013465257399084588, 0.05510582671230359, 0.01809977332971269, 0.02595006015091654, 0.05762061757606365, 0.018089833338895155, 0.021123690906191067, 0.03614980074006223, 0.035373481711552995, 0.035290839976721236, 0.030351618319870006, 0.04950804523222389, 0.05047134717085189, 0.06641906460807209, 0.032789876999994444, 0.04497016554758434, 0.03752532692986631, 0.06194078273350193, 0.05041950600101583, 0.07177375872889835, 0.0388629317674185, 0.00852546692194958, 0.08487882648384379, 0.06355216824299385, 0.01846752617688429, 0.05774238725162803, 0.06168162284959709, 0.05240988669796817, 0.01794161256252518, 0.028115156775100097, 0.026266555970294342, 0.046889870803082184, 0.03754180548111758, 0.02106047524589925, 0.04157804313205904, 0.07719630525717813, 0.01660762940563502, 0.06001309484183308, 0.038468469264766866, 0.03339367685839534, 0.032928676810115576, 0.058056579061573556, 0.07739265359217122, 0.01200424824585958, 0.057771770553963805, 0.03338813038182355, 0.05806246644727165, 0.04347061355327887, 0.03376690723422555, 0.031244170123470888, 0.024061929209217913, 0.028812095688115207, 0.10673813416712707, 0.04677089734844143, 0.03996414102373585, 0.0036298045456679843, 0.025592687795118942, 0.09943894035513363, 0.019461387362811836, 0.07186978785020691, 0.03389020142475924, 0.027596377354535847, 0.063333630171274, 0.06013668397621763, 0.0401610026376382, 0.0790973294586424, 0.010565335941200536, 0.021036027465015653, 0.04126034263942031, 0.07311371545637808, 0.055835249668528, 0.05217354857332764, 0.03334294268560987, 0.0811120947342246, 0.028627644698586197, 0.04135796522361137, 0.015848305080116035, 0.02701457188044104, 0.04586547718293244, 0.06402793182660976, 0.05198999773710967, 0.03260481314012601, 0.04622237839465661, 0.014190978235414913, 0.049133964498797734, 0.017640381045038664, 0.06275895314531461, 0.020365566465883486, 0.05632253138408546, 0.06770013215681238, 0.00866674598411567, 0.07043907268633766, 0.009555419467599883, 0.04738240788180021, 0.07169685116217983, 0.013457249865056047, 0.013376346192202501, 0.011797971411367819, 0.019235680623340513, 0.05256665126991369, 0.023814413861762133, 0.058290523161450704, 0.040415937546640635, 0.049611107040677345, 0.07167307179301016, 0.027628708180160295, 0.014568017983448603, 0.02948989580956198, 0.06829220320909254, 0.012646341009155638, 0.047491728628595034, 0.05907515807437801, 0.002137917021642469, 0.03459784450129636, 0.032930967413009174, 0.07437934633344412, 0.059833860911068425, 0.06676057128295784, 0.05033105731971803, 0.03180278611609773, 0.060071616298368866, 0.038424185552303834, 0.03649346778289445, 0.04780813060220211, 0.04024531827458451, 0.03042150086032287, 0.03138248346776011, 0.026139477305414698, 0.00659799209848467, 0.06136987869056964, 0.043971129437728275, 0.05634482454268202, 0.023035725706347057, 0.06781859233254386, 0.011770939041349677, 0.0524032332243458, 0.059523415271072626, 0.03125766284703728, 0.019014068623824466, 0.043276230233811566, 0.09469045926966975, 0.038321652344518134, 0.02011833265573988, 0.05964959378264124, 0.04713044156350436, 0.015462695681039366, 0.09186793088672623, 0.02125833085888336, 0.016605750575000723, 0.04340380302540237, 0.06507210583696443, 0.06177392878359365, 0.09305269352250523, 0.06432590555519828, 0.025077972470993, 0.04421541955502284, 0.040823109447956085, 0.048808583974718094, 0.03400352881139806, 0.03855039853782904, 0.03828825857189875, 0.03311870875017297, 0.017299175059663194, 0.0756489915112334, 0.03610019654696507, 0.021576027521082473, 0.034153517335653305, 0.06953568648426764, 0.007953315113310613, 0.031651026013517575, 0.058054035649664944, 0.055471829048568205, 0.03079078779856284, 0.044334592192523906, 0.004241574112506163, 0.031453116774378766, 0.030835481368065364, 0.028480908217569514, 0.009928720706563083, 0.014803097808673499, 0.057592375744735046, 0.046574947379168966, 0.08629369128855967, 0.022549922540483457, 0.0230460429954673, 0.05732836269382989, 0.04327137706681125, 0.06737711118353952, 0.08037027647538532, 0.054030319705845854, 0.015082489117048683, 0.05678181641645009, 0.047663903059137445, 0.031204168842504584, 0.03972676484995792, 0.06038556296017863, 0.04283729249671583, 0.004097575438208878, 0.04852074175892819, 0.06722081392522782, 0.026476983086115895, 0.06985962676304965, 0.05390592617914081, 0.07455291887444836, 0.021078882423499902, 0.10407304451350244, 0.008028324697196724, 0.023813067462235212, 0.06456402100382314, 0.04397719685408858, 0.05166166777452154, 0.0670845039008606, 0.0767829088914779, 0.08735099987637612, 0.015225237152809578, 0.035867470526887525, 0.03565786504036477, 0.025286775480415073, 0.022142147344927636, 0.053830355435850165, 0.04864467180243904, 0.017182789066986694, 0.030366447866864266, 0.030468057938701207, 0.06283065131414803, 0.05826204001242596, 0.017856136302373583, 0.022308817433734095, 0.0772677276343588, 0.007926824271693946, 0.020940906157897368, 0.03215503908934132, 0.025419505958956097, 0.01224394470843817, 0.032255369794344714, 0.014697276168472826, 0.03263479399104272, 0.05101599738061909, 0.04085987017700269, 0.029480574434743296, 0.04322076929853328, 0.0426615366051274, 0.07148173367304188, 0.03142222427883216, 0.0366886631555615, 0.041032741747556195, 0.10012232142710879, 0.016661694145671303, 0.03338185995216331, 0.03420281892402038, 0.029166127900562944, 0.04384947084491292, 0.034533883820498185, 0.03912651580908606, 0.027237246826952024, 0.035057688777845715, 0.025937952131273288, 0.0218846709392364, 0.03151337342006305, 0.03392146547294913, 0.03183921168167745, 0.018991744821710933, 0.05613061486773434, 0.04452858480714983, 0.034769881036012404, 0.03633673385446591, 0.0734003778967646, 0.04747593189559637, 0.015568694479072527, 0.04292565690834196, 0.016228509728886908, 0.03980191424489021, 0.01362129514511194, 0.009114989774271606, 0.047017746199403083, 0.07977218397202031, 0.02345101430922026, 0.07368635851889849, 0.0043214651128848, 0.023067866925210245, 0.0207141537084094, 0.032152319477210124, 0.07928309045852193, 0.05564581527705154, 0.030964977040346113, 0.03607662402153496, 0.07441827126087681, 0.037134675714637966, 0.04863914830850498, 0.003338143142173067, 0.023484409997059454, 0.09221317607068247, 0.018905812739244392, 0.06594170756157368, 0.03896273387175414, 0.0027218816666713646, 0.03369966769711145, 0.041976780405328165, 0.03307818269897853, 0.04474339586111807, 0.09564627652927753, 0.030584987853803945, 0.033916451427484715, 0.05030411783786071, 0.016734279061277068, 0.034548535252050046, 0.03771909737899419, 0.03205706218948528, 0.030856135098503965, 0.003652382832613864, 0.06020465129685979, 0.014049750884183714, 0.02054639002909103, 0.02364659081062963, 0.045277194435437845, 0.03409227626698633, 0.0890886941323838, 0.03763373986247086, 0.12279579671280039, 0.11948813549092702, 0.11396815790043724, 0.06321632295786854, 0.10450868041164453, 0.08171505955678803, 0.1425130382901238, 0.19598910104363196, 0.1480861593999209, 0.1680465649452902, 0.3275544364606181, 0.10621622910783177, 0.16843737703898262, 0.17630462504683003, 0.15474249819113364, 0.14610746154381385, 0.19177192491629433, 0.11509694249158907, 0.10845041728668636, 0.0891291052703896, 0.15713093051266286, 0.1789831442217673, 0.13055147933623484, 0.15445588937690183, 0.10621897170260068, 0.2803855449441941, 0.14367211399780166, 0.1825741354015566, 0.14602735939045108, 0.2136820242289574, 0.09962342198817961, 0.09248158263583338, 0.1524153835470638, 0.18918067847769107, 0.14474652166808807, 0.135987194915933, 0.11143664333729014, 0.08808295092275066, 0.20149381050179083, 0.126752671485226, 0.18049235275435835, 0.2323489975664885, 0.171273909509182, 0.13373327231214893, 0.06900202197533462, 0.138060703813549, 0.19457717035566607, 0.13494929899611782, 0.1928727779417269, 0.17309474728761182, 0.1547815993187889, 0.1155084772636333, 0.17671814398659816, 0.17109469090017582, 0.10451570543791018, 0.10581641548102903, 0.17252129983277092, 0.13432099964589844, 0.1389615619254689, 0.16626683544487725, 0.12609084812744012, 0.13098865507110474, 0.1402048460177837, 0.20389024078124957, 0.14883507163293902, 0.10626509019564237, 0.1268704881471011, 0.07337949433994871, 0.17910600940306343, 0.16345238162865564, 0.18772855881721745, 0.2676608245218954, 0.12458109567242286, 0.18117686763646143, 0.0945721829550401, 0.09831867466169981, 0.14362873809952892, 0.15902030251679883, 0.14999607788218608, 0.15822827485540222, 0.13093366527989989, 0.12252021956467822, 0.16103278485036668, 0.13964082144441145, 0.07665222961335413, 0.10622362185630108, 0.22970461526945715, 0.21138153880113558, 0.13236911486714117, 0.20069899428034985, 0.13806206745005425, 0.13207807806470703, 0.13589399265906504, 0.11381179169421235, 0.23959762957547945, 0.12747544479826767, 0.24399213973552952, 0.10371482180010888, 0.15416393326895853, 0.17718948724289096, 0.11530072187944768, 0.20003927000347646, 0.14117443753827003, 0.1421233446848008, 0.18946927912052602, 0.1244528525538983, 0.11423291022618932, 0.19271724677133947, 0.15951686538755894, 0.18300726619218627, 0.12101025260504215, 0.15707849945512511, 0.09613568413882487, 0.1854043399855014, 0.1741707790642977, 0.1275647017023256, 0.1308486601638217, 0.17686221448163833, 0.192693252897551, 0.07923773805340452, 0.19584758928225887, 0.09808046728252404, 0.15802101742836738, 0.2011082997365344, 0.13382129581464877, 0.14485340625528367, 0.12238431556691086, 0.14089483076766615, 0.234695632130869, 0.11057116316571353, 0.08615632406285695, 0.10669681138449139, 0.14747644534274457, 0.13831156696523392, 0.07693921381066884, 0.19941834041908865, 0.14086620972281502, 0.12756704593137388, 0.11971640670972487, 0.12215436661555884, 0.19158300763416677, 0.30615441380969943, 0.08715724857944636, 0.1349451467995682, 0.2510234172786436, 0.17653926245627866, 0.20452866781382792, 0.117756393738091, 0.08663160501108055, 0.2918502652356702, 0.12977659672258363, 0.16604238700482155, 0.16925827089336612, 0.10468376214585959, 0.1407762710005045, 0.1354917964988178, 0.12528730616454156, 0.14975011769321658, 0.187039615946912, 0.13664748609787034, 0.13751831356315844, 0.11812650613606938, 0.0818144747867219, 0.18547063723446863, 0.1452226453130284, 0.10769015929150967, 0.1705920452912969, 0.15260871349563523, 0.14196258879476978, 0.1627634540801087, 0.193971976217243, 0.119418942429606, 0.11616452431847012, 0.1406834364658402, 0.23979691968810177, 0.16209179415337502], [0.049007280369199095, 0.07542016870913006, 0.042897461042288816, 0.032785521790144906, 0.05994957849203099, 0.02067993639127141, 0.07756691561230729, 0.06646224132348454, 0.039736662705939625, 0.023038765160186638, 0.05117561563008255, 0.038911256593682116, 0.029481087713652564, 0.06211424036131752, 0.021818894630057678, 0.05628391289182248, 0.06475095411822682, 0.02555616455332887, 0.028833578708731843, 0.0017289792876615522, 0.04447380185968453, 0.012064283683655724, 0.03554336170876219, 0.06760981039053972, 0.04844074685787482, 0.05037376289105704, 0.0428670511821345, 0.10577100944975693, 0.019951557229843833, 0.03295344826314719, 0.03866634594516889, 0.032922291467266704, 0.027984000607243473, 0.026837934987739693, 0.07314474201731144, 0.0414262849446987, 0.036468995104153315, 0.04916500638148958, 0.023402666500318917, 0.03707380236817464, 0.04477503529239086, 0.08025836635140643, 0.04690588970157889, 0.09932064105786624, 0.03286717144111472, 0.06701587774460355, 0.046885278105976126, 0.0441342142350491, 0.02891993980043598, 0.024491587706330805, 0.046663717817394965, 0.043339842344604196, 0.09082845682578702, 0.056904528380161336, 0.005529850069808984, 0.08989085713701864, 0.031598558566803416, 0.06098724458546889, 0.058800094205165104, 0.05610305868509797, 0.03264428582042456, 0.06424350896850228, 0.014179013857257464, 0.03916506918387548, 0.0072527636169275695, 0.024381399364961732, 0.014578147581027401, 0.03485919539666465, 0.04057862397824084, 0.026015618125036843, 0.05022532569484846, 0.04184300996242993, 0.021896087564527992, 0.015638357726857066, 0.021382439017836607, 0.01786500185487732, 0.061862752847974344, 0.09424577587314191, 0.017410692563580892, 0.037767437527016286, 0.03837516741646874, 0.050826425093316266, 0.025399863464577545, 0.05680972882997125, 0.02727279713707826, 0.05961335782382277, 0.04108271749329664, 0.03334797971371201, 0.06911508123119993, 0.033572324731897925, 0.008816323693721526, 0.022724106036607298, 0.012821937937499776, 0.06603317845973276, 0.051272973913939736, 0.05135213377915564, 0.04383609111931536, 0.04022876311454081, 0.030289161086623228, 0.015838205168444305, 0.03525838083136947, 0.04917317287876241, 0.04752938951095266, 0.013375899945986609, 0.06683875055563065, 0.047210118538069154, 0.04410882225079883, 0.033492781822719885, 0.026992751781137723, 0.03649292769090783, 0.020234946559573856, 0.036933137133957884, 0.03082391727084835, 0.07837758985378089, 0.005666890750533992, 0.03400701068101391, 0.022521954585587787, 0.052305062887288874, 0.026767859010085947, 0.02911774561770501, 0.07609134600047143, 0.06496489949284062, 0.06686260653359276, 0.022619921909344774, 0.05854956047128766, 0.08653775157947695, 0.11628001973393465, 0.061021270380625804, 0.021941309734698267, 0.05553683543938303, 0.017570841328931913, 0.023963034919072545, 0.01776265825385288, 0.037082014830722924, 0.007805185788686598, 0.02092245493024107, 0.018639198819836302, 0.0011945435436510091, 0.03193714453147785, 0.07943891274232058, 0.015307221009636359, 0.045228333347627235, 0.035436798878494775, 0.039366971656319596, 0.004169867803988558, 0.08368780490972343, 0.042860646687087514, 0.08668903862276385, 0.04615890034925073, 0.0330177192095547, 0.05576788755734602, 0.06422668950812471, 0.04495597759922666, 0.02801521485971828, 0.04847175426661007, 0.021225268419291225, 0.0031010149893606264, 0.011156323936677748, 0.033540669978866657, 0.08601561669380435, 0.035306759283787785, 0.03273691351134931, 0.024374956565518534, 0.051271227233472376, 0.028111943036257744, 0.01823063072327885, 0.01893707870265409, 0.04616232859271188, 0.06558829588034461, 0.04746550160850729, 0.04502067372443215, 0.06443972323810862, 0.030033347091727683, 0.08794454947835015, 0.0396459540652652, 0.018460924414196805, 0.01808007720917944, 0.057922356626799995, 0.0544298307279185, 0.0483949079869255, 0.04445979011154944, 0.015247428804756174, 0.06738160811965505, 0.06735133998576673, 0.03969396862591948, 0.019328474938388795, 0.01864856041427101, 0.005925611091492277, 0.023425842575248212, 0.1263653374307098, 0.03903569608566262, 0.007968994060290918, 0.025173287215312163, 0.05393730897095896, 0.03768404885645836, 0.015274344346365862, 0.08849170479562976, 0.006602403328513667, 0.04153971958364691, 0.033142158701535196, 0.004174033407076833, 0.03089561160924214, 0.05330000042675003, 0.06503264464798474, 0.047848809870981404, 0.013593668099342576, 0.0446055191869457, 0.004937894409522414, 0.01956311426305723, 0.03363129051942979, 0.019564136990436146, 0.05671106819664279, 0.04251881442483395, 0.058998173898867065, 0.0220041710793251, 0.008099148568186549, 0.04704014277986942, 0.07631427758643705, 0.10188638442947019, 0.09270796927833751, 0.05481974266829991, 0.05621849281352855, 0.021297340055987723, 0.01081834509668331, 0.03768869901015874, 0.013290859398341948, 0.008141615694659132, 0.014021930401213469, 0.052454170410431204, 0.0870529533694348, 0.022920791450287067, 0.02640890085228509, 0.048513984863436034, 0.07548470395587145, 0.026262524432592818, 0.005650284837165307, 0.04315955887338327, 0.10415172174332604, 0.05482842627492163, 0.07064038527108009, 0.029823425593936158, 0.0050002151833576786, 0.007801232774997311, 0.055128698267282984, 0.05914399107437461, 0.02821909575422685, 0.05307470545953801, 0.08720912805367863, 0.03516089614300478, 0.008433280689191193, 0.04054772765225461, 0.0414500528225495, 0.0494265066640031, 0.04533570823109439, 0.0331816581949111, 0.0246209837871814, 0.05006338236853481, 0.004124366969335824, 0.09423960120447221, 0.05691264508171909, 0.09640915454515527, 0.01726487921851297, 0.07153626381149215, 0.05440854114450274, 0.05854571470990778, 0.052800545574075756, 0.013100311306545572, 0.07645784246344721, 0.05446867138567952, 0.035052854763043505, 0.09590571220483511, 0.03922603829132934, 0.05929172730013248, 0.009402247848019246, 0.04738126258035341, 0.024983239953496286, 0.018102759157397577, 0.03446417364982828, 0.06966475697775042, 0.05184086340088999, 0.09001903130763, 0.06299537937006643, 0.03548797738227633, 0.09207664388081721, 0.05044686683123151, 0.02639325733687128, 0.03466077096339676, 0.055364806565546223, 0.004846077335382542, 0.029500820223362218, 0.008876922206142017, 0.05976017091363188, 0.04900043920403527, 0.03228353501688088, 0.023060001117447694, 0.023378186160698537, 0.0810348883932156, 0.06337200734584082, 0.057040390243092855, 0.014240304721639523, 0.01865604892373085, 0.04666628804238093, 0.07203581442515697, 0.025113091856661825, 0.054069305920312484, 0.03553802590636957, 0.03986834938968382, 0.03068783707285841, 0.02388719412978859, 0.027099942803503047, 0.047969066522895336, 0.025141714816732753, 0.01102019202775292, 0.03389363349866002, 0.06729916173724398, 0.04549466764494296, 0.08615457738238959, 0.008106601646079892, 0.07354136871834917, 0.017743611392835458, 0.04460834988182591, 0.03200339581516962, 0.04013207132717775, 0.024848054163157943, 0.07181034708816199, 0.041320832941921494, 0.04265140126188917, 0.06368958526441167, 0.08083885415427147, 0.03128060526514967, 0.08082548591999278, 0.029573820741666906, 0.018672690268666036, 0.01687296395820956, 0.06353095526837053, 0.06079603287000811, 0.031963561158326846, 0.048171198821716735, 0.04751384175652939, 0.062899085948424, 0.037273464033440236, 0.07495215793530788, 0.0364318015354295, 0.07514367991637799, 0.09134738946393614, 0.08374694689747789, 0.014800765070944064, 0.023815513197933475, 0.06519509359232842, 0.10084244407593243, 0.028362792781403953, 0.008787017000178176, 0.17192908322378514, 0.16324803533573307, 0.10546471983675035, 0.2916103264977855, 0.14497192005716986, 0.0957581483488602, 0.15402007727853714, 0.12748657605580746, 0.09953440257137823, 0.11199969497899856, 0.11959535715680931, 0.1294521125213754, 0.13378312931426112, 0.19097461124822018, 0.12083210651912998, 0.202749443931445, 0.18678565780001302, 0.12855428811763564, 0.09782106991136268, 0.09961150166007782, 0.19479251767118133, 0.13164885432249115, 0.22071218328370204, 0.20867188581295554, 0.17265668289074976, 0.13482870143507758, 0.16088555807307844, 0.19586235945743902, 0.2190922750460525, 0.05914924643753518, 0.11134757029433405, 0.1249418234933288, 0.10399000824338968, 0.13467410489195777, 0.18397307323832668, 0.12087470100771998, 0.15645367814408195, 0.195024443129378, 0.12933514621709624, 0.12444833263514504, 0.08126937258507937, 0.13093671430983853, 0.20348482705172033, 0.2067546894954097, 0.12334842189785936, 0.141150014655244, 0.1446409700738807, 0.0974953446477171, 0.08254654840716431, 0.10320697445422412, 0.076257357253663, 0.13627942681552904, 0.18714915119832565, 0.17326059000146005, 0.13041902273412675, 0.15278289124609964, 0.15180718634397755, 0.18256382385809578, 0.14951189499228232, 0.2543097046474295, 0.11052662281379586, 0.27110009964916015, 0.12658014848467805, 0.1785482054636363, 0.12238403211437887, 0.1983859450105698, 0.12000362073341686, 0.07816653263064162, 0.15950791748060336, 0.14535189966761297, 0.18985005546241038, 0.11545705744215559, 0.11339602045594685, 0.14798220126859604, 0.077288810374035, 0.2218782916785248, 0.2403403211745524, 0.2236669231206179, 0.19968271736175786, 0.1991907663403019, 0.12078754318457459, 0.19248771150746655, 0.3073498786937806, 0.13519602527301158, 0.1918977012317027, 0.09027951652364385, 0.11334288459751876, 0.1847200396080171, 0.1736826125171877, 0.14464476986998512, 0.11401114309386862, 0.08551595116695089, 0.17872875706563074, 0.14835732388159922, 0.153704556306043, 0.21072708520918124, 0.09711249220755794, 0.09524508394421109, 0.08887350769533266, 0.06778265514801587, 0.17838643833754525, 0.12709882831381214, 0.3022605727516836, 0.13330767982669417, 0.22210169823900347, 0.1068044467378528, 0.14176919755916442, 0.12294896067150178, 0.17450038073284013, 0.2334643756189654, 0.07328534213405463, 0.08709930168885378, 0.0881663778977048, 0.18978415657916378, 0.11999159315300566, 0.14644804891319047, 0.13681631655462329, 0.20525640537661893, 0.1058373679857581, 0.1640044705521676, 0.23728248122478687, 0.15187913732182595, 0.16799802561440777, 0.08505668145634475, 0.13145261323980748, 0.1594799705931256, 0.17449253599249548, 0.25639619107448286, 0.2018637390386674, 0.10915049907541084, 0.10101664480903458, 0.10023002572838338, 0.1911487889986846, 0.16413347975861642, 0.10388605011206481, 0.07824757707215126, 0.14344654706937654, 0.13149759792272123, 0.136889539238426, 0.14891583262191666, 0.20655022062841924, 0.13673727160259602, 0.16332631419983604, 0.11800802297770016, 0.21701507360464145, 0.1402329308010878, 0.14787064354506232, 0.17173112610415106, 0.1391030890086005, 0.19211497908878714, 0.13268825177463794, 0.13737418178108432, 0.18969066320888459, 0.12170268883628231, 0.2430994174773655, 0.13245191364999742, 0.1358384512845547, 0.11915513239200078, 0.1655795013592128, 0.19775260480180865, 0.18350545316934588, 0.12711398919383365, 0.17359311812587325, 0.10235499275187332, 0.1226988865903789, 0.23125395148752198, 0.09844180031289017, 0.1323659126196177, 0.20714934735048204, 0.09217630425888686, 0.23653859452855205, 0.11511917436315168, 0.18121529460674335, 0.19016805855977922, 0.16409368915182931, 0.0871821694196232], [0.017291232643108216, 0.007967705596163268, 0.04199760267511011, 0.01545139779937604, 0.046832188212823485, 0.03416622673431712, 0.02430619442865493, 0.016128073686793927, 0.08835419201322141, 0.026025897109760873, 0.029728472826161215, 0.08354329008368716, 0.029708543048811056, 0.05804282012245348, 0.04616206046193839, 0.005143811182689763, 0.0440983651506324, 0.06522255018353462, 0.06630972087863954, 0.020345833956173832, 0.02911982746163924, 0.049553129506567796, 0.05618235644614024, 0.007388490456862436, 0.02578388418882124, 0.028493931712282282, 0.04003125798678206, 0.01674339933801563, 0.018238188180651878, 0.025298690062857447, 0.08583770043426946, 0.01191256954635103, 0.02225225907750428, 0.027707896773673357, 0.019229986674843297, 0.036328391156970494, 0.09595286491657458, 0.04186456767661918, 0.011083788816787062, 0.028473722312839764, 0.034972300617805416, 0.037491450521854625, 0.04506455141029531, 0.003816357728341715, 0.016408856402361588, 0.02140593301925448, 0.02986120713514186, 0.017976666830720443, 0.08884974364792148, 0.03950810803460979, 0.08146272551628851, 0.030815551590715206, 0.036587374840652755, 0.03626418149759693, 0.03795450087636709, 0.03888186180002747, 0.1365469140751708, 0.06569376320488031, 0.04791801442362128, 0.054540959442214626, 0.013467237736368853, 0.035136860134380485, 0.05207806337444533, 0.05307452159843618, 0.0584491991227673, 0.07336611844479077, 0.014068337134836663, 0.01873023113265874, 0.04381977727696781, 0.010018570371152414, 0.016093101773050525, 0.058993067922851736, 0.029098422965034846, 0.016442989449827902, 0.051501812037801555, 0.03454707968499392, 0.028930111532850616, 0.045351684994755254, 0.024125089328135216, 0.05496970437947781, 0.06839441465995005, 0.01675881685749177, 0.041112430213439854, 0.04217030187588065, 0.04507961269888667, 0.022382787053262996, 0.031169530177008242, 0.02133748497843983, 0.020966633305614515, 0.01153445057195401, 0.010131492688801261, 0.05033088494993506, 0.030751286389967127, 0.02033563924112147, 0.016805582694829475, 0.08221100955720871, 0.04916450076345955, 0.015944644467033926, 0.027103453401416063, 0.06101284341345872, 0.07836684930108248, 0.04185452426393186, 0.07732061068377188, 0.06025785993364069, 0.020187747882558935, 0.011338961213046025, 0.009165257591033175, 0.019487899750651374, 0.07735767401754856, 0.017486935549025095, 0.06705099521505256, 0.04678076839134578, 0.062259996249791116, 0.015769462183778806, 0.012290492210717452, 0.035271032773438966, 0.02821867632108831, 0.055540631405047836, 0.07337787023354923, 0.017329284230307225, 0.008675829871677825, 0.06450173805557913, 0.039816515880727, 0.029855066940428752, 0.02514852916881923, 0.01892511240927683, 0.06406930440496053, 0.025092526226334518, 0.038872959858347336, 0.0755574286825234, 0.006193969297342964, 0.006545113358316162, 0.044360229324909954, 0.09021953950005193, 0.04855853287623294, 0.01756137822784724, 0.03768523246230137, 0.05400210085715498, 0.04760563441161667, 0.02844874210084879, 0.06293891485960734, 0.02299397582969358, 0.11488784645353595, 0.025614540453159043, 0.01811041812142057, 0.043901070697052826, 0.11103542776958597, 0.050959651613788265, 0.01503900022080709, 0.03518466019041596, 0.02622991590009582, 0.04537324270894451, 0.020793888139568513, 0.04754905881840856, 0.0706956891583339, 0.04082908110332586, 0.061804166273965, 0.02621787491314594, 0.029665513805324034, 0.032920334112620166, 0.06579278006909356, 0.019230331414409222, 0.0774357843423082, 0.04739924649437589, 0.07011541586008764, 0.03764775161060595, 0.04461846990330566, 0.03422404722040219, 0.05777124961417529, 0.04627055000333537, 0.05895937537594188, 0.04319522026625853, 0.02799115395323644, 0.08769992228236892, 0.028491070373885097, 0.03267109889777438, 0.019124408267558585, 0.05431798572141317, 0.07340651426103807, 0.02951685444361741, 0.04046606650996593, 0.04194792953409976, 0.03847252570032593, 0.03418984905546231, 0.11693652644152604, 0.01463139356459461, 0.03581159207369051, 0.06506547151554017, 0.03305951313626382, 0.054623689277157675, 0.040541855588314996, 0.07207599573678548, 0.06001377666008569, 0.023192783306923606, 0.060559254244811116, 0.026163647379425746, 0.032949403318906986, 0.0631940336297116, 0.10687570823656936, 0.04098331375468162, 0.048511288233942566, 0.049341566665398504, 0.020246669620035157, 0.04020624779044621, 0.05144474997876152, 0.037480242655522404, 0.0667921187836797, 0.0275041978250468, 0.02531443891536084, 0.025023386791168202, 0.07821232170587586, 0.024601335547143416, 0.09934642757739752, 0.040745742228483005, 0.04893552857421098, 0.007286652952672975, 0.06560803030527408, 0.017070336935801372, 0.03288598656053505, 0.02358232177944193, 0.016155861611027392, 0.020438021146542123, 0.020841726500000206, 0.032188275813936226, 0.08001992914585337, 0.020960925950578625, 0.037805853005979335, 0.020546051035184535, 0.054150480596769246, 0.04415564554473085, 0.07751719650602149, 0.023753979100635456, 0.03742160245535835, 0.032439686718486974, 0.06754417197718736, 0.06390863278460118, 0.044908736787375905, 0.006074305884765402, 0.03142697976962213, 0.060681805330058264, 0.05903394254405172, 0.016046605024096227, 0.024385859911900856, 0.04468209733585677, 0.06705510910720595, 0.08120879035202727, 0.015088114117632712, 0.04567657522256336, 0.03280417603110114, 0.03636516337733596, 0.0378554763512746, 0.029321272196548603, 0.042708398203455636, 0.01765197578577265, 0.0052553703426383444, 0.018053804223816243, 0.10451521514163864, 0.032638773817809365, 0.09480819932275242, 0.02650133893644858, 0.11110960040241481, 0.0649531017388067, 0.05535078332609227, 0.03475257127936329, 0.006484025028429085, 0.027423883082285046, 0.05274724883718356, 0.059275919075814955, 0.03329580529562889, 0.029095636320210276, 0.02957435508799409, 0.015221068676891587, 0.06646074745203219, 0.0274059240661201, 0.03505370895107908, 0.03746879347149403, 0.09432370999767896, 0.029979464297573415, 0.047052840687214374, 0.023675688745213613, 0.00936350295124876, 0.013252029274289888, 0.045232010569663784, 0.047761648217396396, 0.03001041999537378, 0.02895413988059567, 0.12359604449762453, 0.024053038758856636, 0.0682516388535019, 0.01552398941825114, 0.03820721796082874, 0.040720216178845976, 0.048674813531819856, 0.03858952647856167, 0.05029825726523996, 0.015392590975088459, 0.0360750190673336, 0.06587613809613452, 0.02314892860369817, 0.027452561583730484, 0.017856425500565, 0.022314902087072694, 0.03331856193741964, 0.06878923339348647, 0.025282902905957836, 0.02853775960243037, 0.028114030625851407, 0.03137655586244599, 0.031734416599295316, 0.029337995895935647, 0.04037560684786689, 0.07553285258191247, 0.0640693886746322, 0.06240190254644521, 0.0167781146123044, 0.07813070269842302, 0.03638117844539304, 0.054781618302748095, 0.08359239631963354, 0.0889370853321687, 0.040939482034093914, 0.040316120120546514, 0.04790638903937033, 0.027304174183236978, 0.016659049227112727, 0.07064727240151937, 0.045201317256977486, 0.03948212999309744, 0.027247416644146847, 0.041961895316959395, 0.1080592068272733, 0.025762177087486755, 0.007564585342357356, 0.06495902359846138, 0.06388529391598798, 0.04168691571741816, 0.02181313939452652, 0.03789111093107251, 0.0876921694725752, 0.02050351208796905, 0.06855979772104372, 0.1219942312567465, 0.04336271006914397, 0.09054462891072036, 0.011489702418686883, 0.0333102154094846, 0.04000480497075666, 0.03117553439111479, 0.012650407020813756, 0.12298885086971907, 0.05114933881427973, 0.009575835710781957, 0.10287113682997805, 0.07988687499516434, 0.22777922181112153, 0.11353426102188327, 0.16407257576863613, 0.17159862353676752, 0.12459881528611146, 0.13632287932259424, 0.23344992720071348, 0.11128318826517752, 0.1739108607533478, 0.20545825422290834, 0.11118018774375801, 0.07612549053925662, 0.1920828340394843, 0.21863436897195157, 0.10934392095453317, 0.16578214693694346, 0.2103925958996819, 0.07724868268856118, 0.06402978575938652, 0.28983205256442873, 0.22869494202877247, 0.09721760713164845, 0.1354336504253649, 0.21628730539833346, 0.2018924826575864, 0.1222691189257368, 0.16199329056807105, 0.09616990528640249, 0.15218969404457078, 0.1714098594722248, 0.12698935434943245, 0.09283779819886531, 0.20197056233882907, 0.1334270056817801, 0.17489454829164092, 0.12160821487346005, 0.11326620685717753, 0.1397352034766828, 0.12430947153798996, 0.19391226732442457, 0.06648536951791856, 0.10847616550182143, 0.10930484280951562, 0.0990947523725129, 0.2611548994337359, 0.088648745159228, 0.18983787466441432, 0.15932462328384, 0.1404535488015221, 0.17031706569175567, 0.17215544688365153, 0.15822711040175733, 0.1714925816462886, 0.21115319863442453, 0.2115084336049134, 0.22807870090248125, 0.22122537026241904, 0.18151097390199863, 0.20708147196039078, 0.08438233256099686, 0.23563974356699377, 0.13965603595058765, 0.12660148403336927, 0.10139110092554363, 0.15194669095498903, 0.17113969090484804, 0.17996615760268705, 0.07860144074525564, 0.10916477129344018, 0.1245886569602355, 0.07914317982091058, 0.15083511269861652, 0.09028559926176265, 0.13096129041044943, 0.2838055452992839, 0.09958328664182656, 0.08328539424485738, 0.16004681437005921, 0.2529091273825015, 0.12085047730755423, 0.17552874651887726, 0.0851034204806051, 0.14070254269867175, 0.18910555589583614, 0.13488519275861402, 0.19127401373078748, 0.1698710339804811, 0.13316684222269443, 0.14147174093992482, 0.1587293423231571, 0.20716935756706423, 0.12212260461021816, 0.15198707911035708, 0.1676654821682361, 0.10441145619317409, 0.10212270723235223, 0.12131022199267343, 0.13325394641968513, 0.18921594916572496, 0.15634847895031975, 0.11738755304606692, 0.10741029205101152, 0.0715274997656384, 0.14525089863567583, 0.1368683492464404, 0.17151766336492955, 0.19806092454781457, 0.10667151516123165, 0.15092730371942445, 0.07741574348220903, 0.24172073500531338, 0.1467997598792276, 0.05949516577886478, 0.11761970833064088, 0.1357331601602416, 0.24183209354598678, 0.2577452872308993, 0.10906571612483072, 0.12407101901067842, 0.13074759784485065, 0.13024864477976678, 0.15492202323530951, 0.13213599431178263, 0.09097846450224038, 0.1944710824999117, 0.11071797625552263, 0.18806669470523635, 0.2198126734865289, 0.09833419560304574, 0.13482225097475514, 0.16856938931009463, 0.18567623991158702, 0.09280962148501028, 0.13045800128771415, 0.17893135667808596, 0.1189311359438204, 0.10578296808225494, 0.15191215571136246, 0.13275620377352162, 0.10059738020983436, 0.23798312991857531, 0.2789389257950168, 0.10997421979423493, 0.1890346008322893, 0.20747953124584692, 0.14445234390516437, 0.11742310718663278, 0.2488268286951127, 0.14833691529929638, 0.1386712299239251, 0.15827054758706402, 0.15640031245927657, 0.211768091445969, 0.16157163577454706, 0.143545602237986, 0.16122406168330103, 0.1490163893228577, 0.1310048961350995, 0.19886099613241612, 0.14632398863473248, 0.28563122475339525, 0.10487089444312359, 0.14233506074355495, 0.2627995369895812, 0.18553534102055336, 0.21757712167116905, 0.09870042393524801, 0.13831234837491668, 0.09983906807798533, 0.12101040582262701, 0.15418498536511777, 0.21526833185024802, 0.06887086006181856, 0.14088174598591943], [0.019305988342591354, 0.035447210013385744, 0.06505859970685936, 0.036583820192684094, 0.029888428154311357, 0.009959985712362875, 0.06271686427475465, 0.017780548322104642, 0.02841004125413395, 0.010304844021917352, 0.04032814770095772, 0.013608170143749206, 0.11226620930697649, 0.058797692519522486, 0.016302546381109183, 0.029340510579547095, 0.04169150841452422, 0.04301287601852129, 0.05152270325549668, 0.05098580202508358, 0.06309975501931002, 0.04759869365502269, 0.008156041130273333, 0.07890352453555792, 0.05281481013122586, 0.15352107824817782, 0.03646427600253974, 0.023917454602797667, 0.004071464767724637, 0.044286148622632034, 0.03842094500038413, 0.014143929903155134, 0.003978784647657566, 0.019269011193706144, 0.03166148694412362, 0.12063658555909512, 0.014789132025813865, 0.03794729198899962, 0.07147706819758301, 0.04141826400413148, 0.05548816970399311, 0.009875270752086034, 0.008194878915204637, 0.05927724440792396, 0.022939901513558243, 0.01838689159241415, 0.04904548134354334, 0.07763139723289399, 0.021106990189441753, 0.08391012362534962, 0.02497704804784829, 0.036226899828761816, 0.010806800151664403, 0.03902538837264142, 0.028989379925112573, 0.023687271994628736, 0.05082549429648826, 0.05476703581910941, 0.03153577574618882, 0.05167327400657439, 0.05226309276035717, 0.041251375580266605, 0.014841790994509094, 0.02805932237195873, 0.05115212737432411, 0.07691874394133207, 0.1090730858906623, 0.025451296692593925, 0.03357124071748507, 0.052136037078115254, 0.030622432316322962, 0.02815681663642247, 0.11158280525236361, 0.04300814542558886, 0.042916149757201635, 0.029755396986260053, 0.056683197917957465, 0.023593318971594977, 0.01930950277094399, 0.051280244088341156, 0.043083674034043666, 0.020402198875202768, 0.09011505276805933, 0.05088526064590101, 0.036544293886230844, 0.030582425289697228, 0.03865450605629914, 0.01797770871029746, 0.03757758178718148, 0.012127620960405518, 0.014753330821892428, 0.041904082491753564, 0.017782745079227516, 0.04504668240946147, 0.04722886087913667, 0.051831026831942226, 0.038916669004867156, 0.09126971580929334, 0.06612407479194865, 0.038516571925532435, 0.04544567632218523, 0.02003988716751337, 0.05054314876155508, 0.0365614504252951, 0.049217157816934975, 0.04047528254769502, 0.05039296871531875, 0.005191919110309814, 0.03996909378216632, 0.07640848341848581, 0.04359705253474174, 0.00529290912973304, 0.029901786812490998, 0.06358402983976469, 0.01936847430413529, 0.06281192429483899, 0.028273945734385523, 0.04922188840986741, 0.0116331341879202, 0.05240594517559775, 0.03658142616792071, 0.015563009149064461, 0.05522722483522469, 0.038483630144788374, 0.015458523374681753, 0.04755442526431815, 0.032171904514994354, 0.04156680079177023, 0.057611738617021235, 0.0713415472437778, 0.052902496555039, 0.06527636786021533, 0.03942340552326172, 0.01913194274229388, 0.029480139679846265, 0.03550608770080632, 0.04555731831539062, 0.027003358268449386, 0.0374315079722193, 0.03392235030450168, 0.002226728397691923, 0.0045600909675892086, 0.03309297585679639, 0.07722287318639218, 0.01923518266618973, 0.09059712125529205, 0.03869379487549586, 0.04242275849044804, 0.0361187971617666, 0.013329337121948842, 0.09135361775876054, 0.012121719210558842, 0.050118379820618904, 0.020436337668328516, 0.03816030656678542, 0.040710303001105785, 0.07485244393108353, 0.04741463720077469, 0.035253899217012434, 0.0033007089739605306, 0.03312553459357831, 0.02634035322004028, 0.04716094335420959, 0.02967230708999259, 0.03419419277399298, 0.04548078230131538, 0.06556519066854831, 0.05864734393394282, 0.04678968948522403, 0.06906111799781361, 0.03376729027818769, 0.06610091595399765, 0.05873236437177947, 0.06290338370167921, 0.017674067846289086, 0.046673140698863615, 0.06813529308044142, 0.04773686527304592, 0.06320160257840349, 0.014948620040330195, 0.06174245023078496, 0.012070714991780059, 0.03464634169734294, 0.02229700244272188, 0.07606611872512488, 0.08822523643292728, 0.040399244490770564, 0.030157539520352602, 0.05745771663984465, 0.012327628322846949, 0.05631363710328456, 0.03983705086753734, 0.07117409574528856, 0.12395550061257617, 0.027791932788527304, 0.020934030518776948, 0.08585961820978312, 0.04364009135432782, 0.023014493579525622, 0.08345240141235052, 0.03393953365664329, 0.026489353490873214, 0.03814721029371985, 0.029219183319758986, 0.01209976600347868, 0.022040115924732342, 0.03219597499757525, 0.0435845882842137, 0.027770501478845556, 0.017694798185520114, 0.05497231673929961, 0.1250228449522007, 0.05062829177345961, 0.022265336198371746, 0.008548403594402537, 0.04112915774326652, 0.050061214339709094, 0.06011161374889555, 0.030142148813953808, 0.13283621399633347, 0.016869579764804053, 0.046794274521450845, 0.0292761170590717, 0.021097879488802245, 0.022973174627329555, 0.04088492508256628, 0.033599363805185405, 0.0809685068745767, 0.020779761478244778, 0.04408620733527407, 0.0010665749000655787, 0.03421164808734771, 0.01891490428768579, 0.0629046515771939, 0.04014201897887453, 0.0813149624774533, 0.01857133875150354, 0.025101347728782607, 0.014641303869505084, 0.037435721455802845, 0.05962228274814064, 0.05313736379086491, 0.022935232207659754, 0.12414930553566064, 0.025193088672935002, 0.06377001300514226, 0.0590836041937432, 0.048022309633632826, 0.05363365086997229, 0.03880299687866242, 0.044733647392281604, 0.009352041318291619, 0.0455486883349236, 0.03120535819400703, 0.05908252784020959, 0.03428121653175162, 0.03793958131404173, 0.07719850392952081, 0.09324626861921242, 0.02387831325552637, 0.05053602414385927, 0.071188528841782, 0.06919721351756204, 0.008480417121562266, 0.04437626354516514, 0.014294320623570634, 0.04789411248038373, 0.08811315776960504, 0.06727100800602667, 0.0649760460721389, 0.03196579813506575, 0.08112072088425198, 0.06870455003433651, 0.017221817416289163, 0.12597617242605458, 0.06501555322639405, 0.021154106512004812, 0.027375293955687555, 0.06021263776347042, 0.005728884500586578, 0.03470399364408466, 0.03562568934754499, 0.03308351467093153, 0.020781142351728295, 0.056137593928724534, 0.030295217011664665, 0.05393385774486008, 0.013279843053990796, 0.017363827134813034, 0.021763701825552893, 0.03101279433335989, 0.05888391954583987, 0.013037679788296022, 0.040376457205462846, 0.04643448132781252, 0.03846641231869017, 0.054345683630315535, 0.025900408077324112, 0.05525499169204024, 0.03372837684207386, 0.03866727291155727, 0.02229800601790269, 0.028526505770822688, 0.03181245797614177, 0.03294793626053199, 0.03268881085058374, 0.0842670976154266, 0.016024645113746728, 0.06185373599310556, 0.07657668568314084, 0.028956775223055196, 0.0548973971707446, 0.03795844239873752, 0.007527691505533914, 0.058386165408357504, 0.0037368964554081044, 0.07636169842895, 0.03888947671399482, 0.050268172992453466, 0.08501727389351976, 0.031254481666931705, 0.06680632971467511, 0.04790979046975413, 0.05634705002810206, 0.03737012900772595, 0.030636547486327832, 0.023089612330940944, 0.04188787207127579, 0.022059879077958967, 0.053554429717722445, 0.05037940129817975, 0.0557607782614087, 0.04331511302640842, 0.026146960069215106, 0.03368200937045678, 0.024812996064523057, 0.02779837750319031, 0.051307482344488946, 0.07009160584740101, 0.0574584788973293, 0.04820457727257763, 0.011214127185784522, 0.04950161775453918, 0.006800093274984148, 0.03290437267071778, 0.01990454049871093, 0.03166386373190871, 0.0932467129502085, 0.024369503934717467, 0.0360314401557609, 0.036669292622396064, 0.03547824040475873, 0.18958721069558976, 0.11238496059611922, 0.23577768535863972, 0.13812188359518207, 0.15164897386585513, 0.07506314875377763, 0.18099453871048268, 0.16128375525436095, 0.11525547672663966, 0.16174953671232348, 0.092519243518191, 0.08089181381247698, 0.27732719937639855, 0.12226337326630471, 0.1423545040550732, 0.22459136141884714, 0.13846696023979496, 0.1849973174713312, 0.11616699112158631, 0.19963301357723054, 0.1741744103210588, 0.10340161441314606, 0.15087372353000028, 0.16077922506918832, 0.139895775505612, 0.2631055431500558, 0.10021103440874046, 0.0924916643529169, 0.08570079286132129, 0.11150110963611834, 0.22210991070155175, 0.13734867105320578, 0.15720988353413923, 0.08529390824297745, 0.1780599316642169, 0.23791799712325298, 0.13284730694947705, 0.07313060003422922, 0.13888332902664138, 0.1250686263665557, 0.11468998892533203, 0.1293688540857646, 0.12047691751391658, 0.20789007776446883, 0.0826492041890179, 0.1701033731261569, 0.12063222651880597, 0.18241103528247726, 0.13859952409421245, 0.15323082285542644, 0.08269784311133047, 0.1700350074397941, 0.11076037922213156, 0.11123586701409471, 0.14376401390519836, 0.13289647447245737, 0.10235280174040988, 0.1427813529247238, 0.11824122780273039, 0.17822185200789284, 0.11014269018966345, 0.1427011588408101, 0.12010509673986705, 0.11286173541579517, 0.12606639460089708, 0.22544236252865485, 0.1362571949439664, 0.2058573553879415, 0.06198917650767873, 0.11962866665975702, 0.14547369232581508, 0.18860649557844286, 0.25287022543770654, 0.10916687803523195, 0.16623073738188515, 0.10620308303905111, 0.15511330006824386, 0.09855825333826004, 0.1587296794018438, 0.20291615998552692, 0.12093555137154557, 0.19991334047048323, 0.2220828065107907, 0.15508956666434967, 0.13707554538644132, 0.20531113469792953, 0.13740778239744325, 0.11972065849770462, 0.17213629468554453, 0.10034790367729242, 0.12868916555758447, 0.1313090483627973, 0.17686255156032502, 0.16759589074119446, 0.11073862232508198, 0.16438058907947234, 0.19608196622181326, 0.21568938909519106, 0.17746667317565412, 0.1900894119734726, 0.0828699294417616, 0.128584778417022, 0.12626691811507748, 0.10980302978667522, 0.14414387094157358, 0.1815201516353315, 0.1564431980612778, 0.1030393084511161, 0.15544558304452127, 0.20569480685216768, 0.18242450310818611, 0.1369840898100407, 0.118990408166522, 0.06959919517319049, 0.12565666779635415, 0.15106639464295682, 0.09045564779831518, 0.15916382142853353, 0.11185275165424233, 0.11368803019004484, 0.11025258550240148, 0.15852792248610528, 0.1549190814576803, 0.11729670267912651, 0.15314943367435088, 0.1591543985470649, 0.16681097237573517, 0.20849968456933576, 0.1360849324133127, 0.1253371018796198, 0.18368194450534162, 0.12836169361347152, 0.23514506527252738, 0.23513487630313445, 0.07779318734162277, 0.09875718338955795, 0.12339986470197478, 0.13681325220292614, 0.2991482026634678, 0.09747296721944887, 0.1260895917432443, 0.15065221686757382, 0.19861777853821555, 0.2851382624958792, 0.0998287182301283, 0.23316120398381066, 0.19882894301366424, 0.19731830955753404, 0.18286287394021788, 0.1312745590844462, 0.1426388758925661, 0.07103235415753818, 0.14288122014653298, 0.14707138401366052, 0.1506303067529394, 0.11829352096444178, 0.13866500928997993, 0.16522351562255816, 0.17640056989846692, 0.11082201099563992, 0.08925966963532472, 0.12035403701086199, 0.14573148091233548, 0.21578082934983317, 0.18765775697125545, 0.09172661830821345, 0.15418041948108904, 0.12825497756561927, 0.13585467702679097, 0.1669605433820717, 0.12814508991376047, 0.19394329388535794, 0.17697594789487703, 0.1957861183872146, 0.11886319926669521, 0.19135079106255887], [0.03194435150362551, 0.059795897423980705, 0.026152609967656677, 0.01229399419014132, 0.02310792183233125, 0.06772940437639914, 0.019224248676290436, 0.04883719352825035, 0.0627760943626204, 0.05777471999247229, 0.02424919365664884, 0.056227161098391785, 0.03641541491472914, 0.042059276583454305, 0.052505869854001276, 0.045673652597132235, 0.05730722632799899, 0.08501755734605175, 0.028841482820890607, 0.07157456054682694, 0.04968593467868144, 0.038141380364616076, 0.028115685375767852, 0.07020039033264884, 0.04866760081401275, 0.06898152912336011, 0.04866195857645043, 0.03962408225502699, 0.028387257799265847, 0.0556552917846749, 0.03697551328748946, 0.06378326632623231, 0.06078772464646928, 0.030651085919910864, 0.021097011894228, 0.091642992150399, 0.0360236720242087, 0.0062780637264011376, 0.03904994149061461, 0.014406612833901761, 0.050513263671628894, 0.0413652009240562, 0.021753541584457123, 0.028328786138445142, 0.051740268395552715, 0.058559335753201484, 0.06715010400981673, 0.045348766199763746, 0.0008308449175655693, 0.008822844059567058, 0.04836287785081133, 0.032346093756777626, 0.10951114262664512, 0.06595356660264154, 0.030537731720194704, 0.01176362481689261, 0.012379956916124831, 0.01774588092831114, 0.011355707895070797, 0.03808763163584856, 0.02023659747905068, 0.01214036579063583, 0.03612458495603454, 0.03178367988326617, 0.06148984805951196, 0.03680941393418658, 0.056570464249459974, 0.009799301643074762, 0.049894218663534814, 0.015936036511594733, 0.1490825180324816, 0.02232032982001622, 0.09258887324962886, 0.05320745317505733, 0.02012002379483273, 0.05905788279168549, 0.029415041358480533, 0.07080154718771096, 0.07731567707753952, 0.0399883110977469, 0.009169372440796466, 0.042440999043925155, 0.020016134611421058, 0.0508262335713352, 0.04763201081884965, 0.06069125885504389, 0.013827563361114553, 0.07817383344856002, 0.031339375700260845, 0.012150613174232985, 0.05478688515722752, 0.06623445274007898, 0.038292889573401025, 0.039279668276468595, 0.026301880284482916, 0.09789081455598916, 0.010454861274469766, 0.022136418922473828, 0.0892345036470121, 0.0263659137436339, 0.009208453458643729, 0.07400237744854343, 0.02511178950719055, 0.02125582575137096, 0.045546233023126284, 0.05148621831810282, 0.08573401043371809, 0.043018721269383546, 0.01190055345725869, 0.053977559230500655, 0.06562722846865654, 0.054406196915454445, 0.027241780152243954, 0.0426033522272783, 0.0341248618168456, 0.030469262611962138, 0.07355772469553255, 0.08087945681425833, 0.020931697781047514, 0.007338033990949513, 0.029977637177874005, 0.037417699237384146, 0.052530315719665065, 0.01960843602465766, 0.06667771121306766, 0.040421139283646504, 0.054242342199769714, 0.052150071808888074, 0.02667374319336828, 0.012457863269974629, 0.014507418513418207, 0.07697100645952648, 0.022330756276665677, 0.03283008129426068, 0.04211520866280602, 0.044567954065578605, 0.04154337765348535, 0.022034328130464402, 0.08911938361463048, 0.0741727170985072, 0.06676744309163864, 0.025856976637676842, 0.06494353330063243, 0.045135154073397, 0.022138975740921114, 0.0533769884327006, 0.0377353499343078, 0.03871547899419262, 0.05021667656218333, 0.0468839680956256, 0.02163160911520883, 0.08940938619836684, 0.019681093718616233, 0.02977629011917499, 0.01635590632025513, 0.07026488727499401, 0.030299081925242662, 0.00648883318776385, 0.018180419405501698, 0.0316002382145774, 0.03912730487964807, 0.07427984683383858, 0.03827364927518272, 0.0471071103557704, 0.005745671881032327, 0.03397289295530608, 0.04696382893129222, 0.04261425748888043, 0.02244310498598122, 0.055921714182101914, 0.002560016146162525, 0.055398977917408755, 0.045885525703910864, 0.0450356813868688, 0.03639674535201442, 0.04264884252822207, 0.030944526323207447, 0.06007960659541911, 0.04573023585121959, 0.021646691471218102, 0.02381181107803939, 0.030355171052618857, 0.02173092092327293, 0.0513814787770952, 0.050226229678599105, 0.10040311563399532, 0.04807249222311282, 0.050538234307520816, 0.01704437804648713, 0.030193244963283503, 0.0669411305458315, 0.0748500230932428, 0.03362218939488934, 0.07618624131165205, 0.019007983970485868, 0.01638734273822798, 0.05295048047217631, 0.07356458884333411, 0.01745144461071299, 0.016506463664794163, 0.030165642815371676, 0.06813386049602302, 0.07436734939654989, 0.02237075564241217, 0.00830444289491542, 0.052480236552054846, 0.01456558182384939, 0.06088748078552946, 0.05195877582375562, 0.04265526234502754, 0.03629869758902538, 0.02105102172091363, 0.04802114901042754, 0.06524528001224802, 0.012527964145485914, 0.04120044222462081, 0.0582352192741969, 0.04326529049825284, 0.06189382537418316, 0.0031914665117754692, 0.075240038455494, 0.05730244593935148, 0.046271944283357555, 0.04030441429706351, 0.032080464260352236, 0.01400473843058271, 0.022904920023715785, 0.03844494270461221, 0.09086971066050953, 0.032009386622737494, 0.02945693679183962, 0.021063466819243568, 0.06062997182110145, 0.03980785908718263, 0.036645536235864126, 0.10888397708655366, 0.05439667827299526, 0.03961398521618497, 0.07388377937698558, 0.05636680743566925, 0.08350985800667156, 0.08412589995010246, 0.04928039837508433, 0.019100456528605956, 0.0070604525652954424, 0.015614770837278377, 0.05401096066399928, 0.04010609711610502, 0.0930543176289047, 0.0469021511925084, 0.02773391311958192, 0.02687807799497199, 0.03141190890493172, 0.01396923408573193, 0.06818606938806272, 0.0363182443224134, 0.0440334162164119, 0.07126867696042023, 0.03611851370923462, 0.04200427530093059, 0.07338009188852965, 0.0484609677486362, 0.050450034604798404, 0.051916893796935204, 0.04431741267082192, 0.02148364497829349, 0.03249271532460567, 0.03860749890126529, 0.014426234260862394, 0.05440233583231607, 0.03466727888031352, 0.03561596769178587, 0.037088350377856724, 0.03828621311714092, 0.006940336203232649, 0.052194654295641574, 0.016150928004795027, 0.01777178236103106, 0.025774612609717636, 0.092750295636154, 0.028977631966793732, 0.025673127027168393, 0.024748095010797826, 0.0217536450063269, 0.06262140205851005, 0.04693562923479946, 0.024249607344127955, 0.04173256306638641, 0.0643988601082275, 0.02135827851992461, 0.05704542344075538, 0.02966296273253618, 0.047933926069808584, 0.060289219742821115, 0.05388490472649855, 0.06155234551237476, 0.04587499199495201, 0.04023804810018309, 0.057015821803361184, 0.02175435746809648, 0.08754585433991686, 0.05360093508516589, 0.021964815227435004, 0.029559427864789486, 0.026298679952179233, 0.03761009455868795, 0.025287796292574178, 0.0356320095729203, 0.05957227635888323, 0.03008555981420702, 0.04116223358939733, 0.03948598724579619, 0.027258138044647155, 0.02458809563259204, 0.05905230950203635, 0.0467167885583495, 0.015776078310614873, 0.023878217494535833, 0.015441612941363167, 0.060426483546654065, 0.053186194235158545, 0.004173460756353433, 0.07512640463368547, 0.026582122908063957, 0.049626287072896964, 0.012751920374050256, 0.04578699530552953, 0.05199544845269092, 0.032053189615028045, 0.043059461825196786, 0.005792922747787089, 0.060626604864674236, 0.05573940440832127, 0.04396957044880237, 0.016822513237956072, 0.02148318341031911, 0.08642202633763514, 0.030500699029934984, 0.08829044583704203, 0.044061914687195135, 0.016967156383719657, 0.022729307773613164, 0.08617703141945024, 0.009192925814028469, 0.013227713643573226, 0.020930902964826074, 0.02305461743455981, 0.06758695032687918, 0.03420569175373643, 0.04557434844994738, 0.04163985876666923, 0.011447653767742939, 0.07124892721373229, 0.14599093957053078, 0.15020672141784622, 0.11859914408095422, 0.07284337068877875, 0.11032439092354429, 0.07749621335777544, 0.19977241093593262, 0.12892682135345476, 0.19825060791786642, 0.13497044302282796, 0.14914489291127653, 0.13113917602646735, 0.12879221970515867, 0.16293099750914883, 0.16598920518111798, 0.14415781374179548, 0.21143328037954148, 0.11130099980941704, 0.13149742938337788, 0.09874587593179557, 0.19456600079373007, 0.09736450449112924, 0.10753024609819536, 0.18666096932945714, 0.23974942223679638, 0.1471469815700285, 0.17281929271355753, 0.11430253229674794, 0.15806774879174848, 0.11294706228880153, 0.14143060201839094, 0.13027556510942598, 0.16128367864556853, 0.09361877121151456, 0.18438058604876842, 0.17187879721243537, 0.17550766377920107, 0.11445833159790886, 0.11225575220681007, 0.12131440483273999, 0.2085673607765667, 0.14688704793732013, 0.10885736319206415, 0.20368912737936745, 0.12904755681032135, 0.11281994531952566, 0.14713021956624525, 0.1517959401732491, 0.11034345885197963, 0.09066008602178867, 0.17176828136847866, 0.2781632770934413, 0.133230657346787, 0.1086140766499504, 0.11559958810046797, 0.1753357536489925, 0.1565081469954983, 0.13035831792700675, 0.21535857700772826, 0.09519377137504278, 0.12117909838355358, 0.12085939457099285, 0.1308210043897552, 0.1821835990995169, 0.15850414311693561, 0.18035741402737557, 0.09966018654766584, 0.12068931539092334, 0.12681287067431596, 0.20370893841308935, 0.07780862401329702, 0.15795603785062992, 0.1587977080095199, 0.2230855696383984, 0.10869777175567805, 0.15423376984413595, 0.149108718239492, 0.24794850888992512, 0.20441954624989342, 0.14701513783825984, 0.1751117801834499, 0.2162052114163676, 0.17786157617886222, 0.15015640476297948, 0.13600305293596562, 0.15577340738907938, 0.17618494679129895, 0.16816987445758236, 0.14243347239830803, 0.1023863104262179, 0.14483897315879024, 0.1124960127016229, 0.1777437212125909, 0.14342554093849275, 0.15300404550808092, 0.1102066815139786, 0.10195111885907189, 0.16511961877826722, 0.1631899658710726, 0.1238485700601051, 0.18290005984806246, 0.08685467449287254, 0.16487165143893612, 0.16327645719772385, 0.1884883648205188, 0.1593399603640841, 0.16272542547554741, 0.1545203480148508, 0.17237601891881035, 0.16344493525403161, 0.12661678280921715, 0.21768253536955004, 0.07398062055149386, 0.24207923351035965, 0.13910184794616315, 0.1808987930417061, 0.12672467097159357, 0.08958056088416808, 0.16697322979809778, 0.13667216945079066, 0.16589457800071086, 0.14824359046836055, 0.11507637303082213, 0.15435321827328977, 0.13668081092257656, 0.1458072776515638, 0.15076611882015584, 0.0999822039457579, 0.20528481191685125, 0.11109986342489721, 0.10770848411465846, 0.11718098509816394, 0.10977284592245856, 0.10383426256838346, 0.12367403990919552, 0.0813504706527437, 0.052700866043808005, 0.14242170528779108, 0.26829618720277665, 0.1299904118622503, 0.15199113937635578, 0.1431587891232583, 0.10101352683118275, 0.10762882629229177, 0.1063264308557395, 0.16315458793072932, 0.12484114421831986, 0.12624226540567415, 0.13824539229033456, 0.15632909692583546, 0.1551448016036903, 0.09848377427026149, 0.12934927287842, 0.09999363397758815, 0.13304108122904457, 0.10228316434809279, 0.0917194477252422, 0.0637692507476576, 0.11043063965776276, 0.11559009627108613, 0.12259766339294373, 0.18299044290136907, 0.13991667438418637, 0.20922847933346228, 0.09328721601876522, 0.14202899329604643, 0.17850921158829045, 0.07739389465460855, 0.14894065387066335, 0.15199604233907116, 0.15714876503954012, 0.18297086169402446, 0.0950686002690946, 0.17713958427550333, 0.1264850003644824], [0.043869293369953676, 0.06901953474528368, 0.026326345302344813, 0.09923661653433116, 0.04766058589842531, 0.06686478988417695, 0.012487245614700502, 0.06263358285650611, 0.01667201718045098, 0.022237914081122127, 0.0607846143294967, 0.08389769001833855, 0.012641895783975, 0.028653076902452498, 0.009358743630019168, 0.018684440142204686, 0.047017562338301254, 0.04103967101283131, 0.04525453738507725, 0.013611699893860327, 0.03608205175447849, 0.0173213686268296, 0.023217910990840005, 0.10278941823109504, 0.0490390308832209, 0.016502322959563425, 0.03989806594026666, 0.06538713651318705, 0.03750401436381283, 0.09206655450285443, 0.014168003258565742, 0.09854160624766543, 0.04032854223623872, 0.19573039315160246, 0.08996349759399892, 0.05199958149704242, 0.04995295845512902, 0.001351550869707529, 0.11474921518275816, 0.012879008615028956, 0.014096185388494165, 0.020010613032706806, 0.0073474204832417594, 0.09396110526135854, 0.057860537161750186, 0.04261465585460106, 0.029610637012088013, 0.05394052654024094, 0.03001307449003141, 0.05586610002923877, 0.05253515356490689, 0.037914836674087474, 0.020923288050858725, 0.07714999524215538, 0.006579079781658948, 0.025999426856757175, 0.02699088827226191, 0.030537187797768466, 0.12662226799875498, 0.016558358460784923, 0.03990907845417819, 0.058592944030439666, 0.058412526493831995, 0.034383742078658075, 0.027328549185767773, 0.08498858390075546, 0.007029410682603598, 0.041765328646907886, 0.023880967750184, 0.03383878160328154, 0.07076012481364512, 0.020741097020706343, 0.05270763443061902, 0.0014648585056420418, 0.019692711441987948, 0.039662248755414645, 0.038141361212417964, 0.08794160003984168, 0.13711323691231592, 0.039401319208404714, 0.014170045840493856, 0.046853163700190284, 0.043057830057918065, 0.01581092381985077, 0.021317367509548223, 0.02029440072815745, 0.06856067872215664, 0.09555985415053946, 0.03910684650163016, 0.0950050456148963, 0.025679956701013352, 0.03569723046835392, 0.05059815004407879, 0.007972710544333584, 0.04941858148442642, 0.07692862647555529, 0.011808650677032288, 0.03641594351539689, 0.030116412090137604, 0.05696524467860019, 0.019546905757799264, 0.050734973347355286, 0.022303709542498957, 0.046444191492252776, 0.04184655311907973, 0.02133017075398276, 0.055373574441839615, 0.06308150297451405, 0.08560805791808714, 0.01688852894961113, 0.055496186814120704, 0.04416252501429089, 0.014176460869249799, 0.0763966856644519, 0.02020119655606968, 0.051915698699773326, 0.043192971798200766, 0.042669549884815375, 0.045014786338734056, 0.03093226508597934, 0.03228407127842788, 0.040384899494388414, 0.03566110176184485, 0.07494161656546978, 0.04380968789900503, 0.04290058285058026, 0.08928265227305313, 0.025075837000904065, 0.03966551228997208, 0.015424668034087988, 0.048951662385896336, 0.014758561287195453, 0.04895798261127165, 0.010280679693565735, 0.056799375151674596, 0.05256912573390911, 0.04454911979396017, 0.018925757838353034, 0.031718416852996714, 0.061565801846764745, 0.0716203726046989, 0.04828810766940156, 0.05456902890376026, 0.003706230674006586, 0.012524735084885072, 0.0717258935553893, 0.08068451808104593, 0.0361674245927603, 0.059144994649555416, 0.03796593090819736, 0.015526112439411302, 0.029500174794286012, 0.044052687158147176, 0.033248840275430874, 0.03649846650660038, 0.04360428057430733, 0.04432192492869593, 0.022697252739641457, 0.08903614050077815, 0.07815632067861096, 0.06006620005674421, 0.06643341343489385, 0.08940954707683095, 0.0548115800014667, 0.009860606871605402, 0.03593362221914915, 0.04344594169167742, 0.01998615567572415, 0.020185516651479468, 0.04354854767781593, 0.017986225692795652, 0.07315263272293153, 0.01877578846629589, 0.03236271786473451, 0.01796363567512843, 0.06347197415908018, 0.09139468007150198, 0.08294460769262045, 0.05231011140670988, 0.02727643222427897, 0.06270687831866165, 0.019805395314770362, 0.02077161987882949, 0.014665088984334182, 0.04206953450076042, 0.032749159426818934, 0.053535668224456816, 0.04918319713925162, 0.04997321765028662, 0.031023262924845182, 0.012764290778807575, 0.046696831967921994, 0.018103339469000217, 0.047865529739928823, 0.061191728774217836, 0.034280875622625315, 0.01572543032272088, 0.023716308642178777, 0.036808532933073665, 0.013895626442747252, 0.06350413453014148, 0.013904658619374519, 0.033228492980161985, 0.0846486170625975, 0.006717810643866899, 0.04623842410623066, 0.028883811093926914, 0.11529299971317092, 0.039859455108882925, 0.09394919259413596, 0.04368530586361886, 0.051694640198782574, 0.04214668721561471, 0.014634505796787, 0.02810212561950809, 0.05580198613085574, 0.01440767769611651, 0.01997755059311467, 0.07178737977219206, 0.03292362829069457, 0.05786711402658013, 0.06469796381650433, 0.061391091665192965, 0.0027548215321956146, 0.06859257862332367, 0.055330087460817835, 0.02702677949151445, 0.02001740440215555, 0.03525801310916582, 0.015521832880744291, 0.038871217008319595, 0.09259744577350155, 0.01624287387746717, 0.017130020930762255, 0.08763832115237752, 0.029753102552926833, 0.046934832503358205, 0.07876133095593223, 0.019672109422484235, 0.06718041810898051, 0.06688914381928983, 0.06778237169548389, 0.0878577746991669, 0.06313133316354887, 0.017817845312698234, 0.027423090181283416, 0.05845314447557735, 0.08307392333423899, 0.03189344687627689, 0.06380772751365459, 0.030186583828781883, 0.026174983565485286, 0.02756393544616238, 0.11187405655941657, 0.09123639864546639, 0.07887643566655536, 0.044530385113771886, 0.02654766810366944, 0.010751417740398358, 0.02906098616339507, 0.019330386327759876, 0.04159143051853584, 0.02602227159865922, 0.024342200561096112, 0.043811599288376114, 0.06752803050462278, 0.04119533624860548, 0.04446899082752005, 0.024557634061502836, 0.03498309862709815, 0.04332563907448803, 0.037826805510708404, 0.019831980480962706, 0.01395150298072446, 0.029593784992973653, 0.04190016395202087, 0.016940109649552934, 0.015048170293260728, 0.05433111646843534, 0.030203227088936878, 0.06580989447332199, 0.023649090172482595, 0.05582593786980837, 0.07630473979177975, 0.12128642730174527, 0.02275440864445221, 0.04949425181914722, 0.0730813252589395, 0.06280994778799434, 0.026079913969301892, 0.031110510763321674, 0.08616583887487651, 0.10172787317705732, 0.09634424391533099, 0.012571197359882777, 0.046356053076564305, 0.01934353814219996, 0.04151900839661399, 0.026567042467274496, 0.04189945532069091, 0.027715546161597295, 0.07604135876341213, 0.05159419458059054, 0.02405394848826672, 0.025992767637475364, 0.025093920506356705, 0.04787009562395754, 0.052935534096773595, 0.06495204453747119, 0.0197820104808817, 0.021394836235671275, 0.04509991785931972, 0.04522643344957502, 0.04773603023720845, 0.04750355702614592, 0.016505023419496515, 0.04998547888751473, 0.05025221155055108, 0.01882158711762919, 0.029191812913444255, 0.05769404327316631, 0.0839616660208952, 0.053659422067745086, 0.04812564723373902, 0.09032529027711961, 0.01180275371523514, 0.04154474128999057, 0.0051279435865581036, 0.06194399647234429, 0.025934022100221728, 0.05227301742941622, 0.05220821788234096, 0.01672931289630792, 0.06207977023516452, 0.02593296489888622, 0.017107758415682663, 0.003896754825555329, 0.04004510502601343, 0.11275524919432019, 0.03318846871655795, 0.022266180810308265, 0.037414550616015355, 0.017846493170626702, 0.005601780459044442, 0.03725783200934529, 0.0027879586653603663, 0.010131026332777356, 0.02135982984797128, 0.06904138357288415, 0.05052691152799995, 0.017035631237611655, 0.008275565210609667, 0.23832892668583702, 0.18730190913042716, 0.13133223018338605, 0.2656524177760847, 0.191913896330422, 0.21046546618303946, 0.1535353581270864, 0.1790138183822555, 0.10315691060837238, 0.18016884914569317, 0.1477695352608158, 0.15762174772399087, 0.07409784732566727, 0.11186013674183239, 0.1204009828788619, 0.10424176005706673, 0.21519268832860455, 0.15168439777147386, 0.206598928498645, 0.24265908546024756, 0.13041146910719334, 0.09796707094797204, 0.12474285513763467, 0.17813827181535383, 0.26750641183987744, 0.10826018233332904, 0.15083073067568964, 0.16852808184921744, 0.1942664757370949, 0.12512370808831147, 0.085786004821139, 0.26605219309849126, 0.11507274177406104, 0.23165532027281102, 0.20799930658071272, 0.13599914588755177, 0.17556567195682757, 0.12786105515495425, 0.21522176902621024, 0.13811993773185438, 0.13461114778634042, 0.15832241173953782, 0.13086450286209583, 0.15731672215605938, 0.2253018926468588, 0.13662533083510014, 0.15386405581187818, 0.2722465042625704, 0.14112542323287458, 0.09970620544927736, 0.1425215571878418, 0.1346814286925139, 0.1327411118414133, 0.20297563905196808, 0.15257895864065618, 0.16800308179470802, 0.13750616340867935, 0.0817022046014186, 0.17109176444430507, 0.12270344481352838, 0.12147575061047271, 0.23345293026537667, 0.2788544722622441, 0.2390499686401698, 0.24652763029500363, 0.23455712343415908, 0.16569514999226218, 0.13395318551169288, 0.15905117586014733, 0.12693229612083207, 0.20794016459295828, 0.11942197613778616, 0.14060661316879336, 0.0949057912634265, 0.13647237372013832, 0.1925231047695683, 0.07788341717734452, 0.30594131879268155, 0.23441887520734342, 0.16588970568151246, 0.17030759684501157, 0.13324838462135485, 0.1300458766279682, 0.07363005871734313, 0.1148918454325007, 0.2157966720481073, 0.11861460373526621, 0.2356839928055002, 0.17584170875770433, 0.2334635329222487, 0.09882663692077322, 0.12184861326409925, 0.1367170622031535, 0.08448116556410828, 0.20034193602060119, 0.2442060774492641, 0.1103311937843119, 0.10571683937263106, 0.11873484889586126, 0.15314393316305455, 0.1159453695459712, 0.10103331488226691, 0.15226219660572468, 0.08445898731870037, 0.2647276270774103, 0.14384857469028042, 0.20624818280339244, 0.18163616799058455, 0.20691530748961434, 0.16289764204092566, 0.17564836348737442, 0.14108540279971016, 0.1986403168449479, 0.214847243961788, 0.10315527884109367, 0.165078847578937, 0.2152048844483591, 0.17529418571822106, 0.13486984035661145, 0.07084857732538255, 0.08579040216582437, 0.082769418706096, 0.14326311497678682, 0.09495482089058047, 0.13656222051189792, 0.13315394130204955, 0.1479037845086667, 0.11050523363894994, 0.11230504230385828, 0.17781012571386753, 0.16114913828430638, 0.09376361545535827, 0.16780946073272537, 0.06921284937209661, 0.1190185082715846, 0.1426226961156053, 0.21521515002654446, 0.1290157028744298, 0.11532417949168913, 0.15229884625202225, 0.09290347491661388, 0.1223269815466577, 0.10779607860792069, 0.10649486294677181, 0.15488931128094274, 0.18683911541536932, 0.14835049037731465, 0.12818626713969056, 0.2623822029319502, 0.13345119873842887, 0.07201684608815179, 0.08901258329710654, 0.08049028414872386, 0.09525803849101068, 0.21888445071395368, 0.11854738718078983, 0.11857508892013181, 0.12317042136865279, 0.24584349845686268, 0.1575729632449727, 0.09508901651227668, 0.19587906017418832, 0.20561828999029053, 0.21344291286603098, 0.10318808272601136, 0.16319460836389374, 0.185056061093365, 0.09290687634699768, 0.11406666148574122, 0.1795210605186801, 0.09346152400417675, 0.1669099662573107, 0.20823832601308825, 0.2407012251956809, 0.11051138532498192, 0.17159476245362915], [0.09104124540763517, 0.06113434112780999, 0.03259608356822883, 0.09882810780958784, 0.03732622067834582, 0.03941269178364066, 0.06967870743885156, 0.07749437474675717, 0.024748119908655365, 0.05627569659883457, 0.07212257388258173, 0.024456353407473336, 0.03960861110939615, 0.057646059356029, 0.07900497755937039, 0.03388047210812088, 0.059686500068393454, 0.1116772102672727, 0.035222887977837555, 0.03174553253507662, 0.013022578280088643, 0.06434059146070673, 0.053643889635080294, 0.015279606412795764, 0.03045971907164541, 0.015197948143336804, 0.059097091171650164, 0.037710015406651844, 0.02683825291422827, 0.08342495248202356, 0.0208265847721768, 0.03085522345387407, 0.05195466576204185, 0.048737345458639246, 0.03261965226321932, 0.049961078987126394, 0.03197429788058564, 0.09557260951447873, 0.04563557419685587, 0.042117242626244986, 0.006914626771298748, 0.04136911180290965, 0.01974201494557483, 0.03345528181882636, 0.019023407235621445, 0.023328798387439984, 0.07987542198069635, 0.08117237819298621, 0.026328080491493308, 0.012095503681789965, 0.03100249428121794, 0.05844945193178231, 0.01822366889926695, 0.02246018300103324, 0.029257824794659694, 0.045009373927549015, 0.0469591711167126, 0.0346627283180433, 0.025541463326061928, 0.031427726705348304, 0.020498800647234725, 0.021540699376454277, 0.05085770829370426, 0.06557025450972781, 0.040171007745929306, 0.023845643435995427, 0.02884181798435748, 0.014400883453838048, 0.04592433954859453, 0.026079370046875654, 0.057300469432506836, 0.0692828085213419, 0.02310295758258191, 0.01748648738758939, 0.02441842630956202, 0.07744751314842895, 0.023115226480689262, 0.03456208734743057, 0.03821669063801247, 0.03183363264636888, 0.026338512693802198, 0.03736914458474325, 0.05332060436147356, 0.07504132290881488, 0.05489917449472893, 0.027554278907876824, 0.02622151383078627, 0.05003875264176919, 0.09776823282722505, 0.06505479224987569, 0.03015447708387529, 0.06434848216632683, 0.016870843809879115, 0.05260104478727426, 0.029262248952422413, 0.061152045419740106, 0.01339256618877933, 0.0739683478229469, 0.054344760494366776, 0.058139737905754205, 0.01285018742970762, 0.02681905666606561, 0.03869114804171747, 0.10970335408684709, 0.02191995120336933, 0.07209907796594404, 0.06254653228567013, 0.03762127944238244, 0.03667285110080435, 0.08879597193651623, 0.043519915141645944, 0.03579053231665204, 0.060448849483603434, 0.05868721114952238, 0.06180685907301884, 0.08587085671963231, 0.042047501812058116, 0.047009552889052904, 0.05164060418704345, 0.005212842886741724, 0.014437973600692086, 0.07180869233824554, 0.02413293789891947, 0.006247595452042598, 0.07249357494255228, 0.04167628241702915, 0.014688457538854453, 0.0338952231311029, 0.05507167451263917, 0.09991048279428676, 0.05154295478977504, 0.026542433807926796, 0.05406056485709645, 0.08680451105559066, 0.035594053746711825, 0.07334283703277189, 0.16174235080759372, 0.014348041581650896, 0.004646812120617758, 0.04919930796829924, 0.052310214828579664, 0.04404628266310019, 0.022670068109648365, 0.03572370263657743, 0.037555208189352866, 0.008916034825116156, 0.03279500212820788, 0.0345071473519408, 0.10442833311014599, 0.05731546177318501, 0.0398400501017609, 0.054063598565276594, 0.04126978467308706, 0.03829942813383476, 0.04604858751859396, 0.05195476535347201, 0.031178010770330028, 0.031056239179545836, 0.09975567174654815, 0.07744901468076053, 0.05455221327382231, 0.0445935643848873, 0.004767363237577581, 0.07605650432167516, 0.04371175121876501, 0.008936093879803535, 0.07253040844995169, 0.04905259446992029, 0.02064917604589174, 0.00802318185320004, 0.04731386599521484, 0.024060410439908027, 0.040441743218370026, 0.02453222100983464, 0.033010161752181674, 0.015629903946612633, 0.025859167649140282, 0.09037022133387866, 0.0499668782727132, 0.03327041331137861, 0.05317586353949962, 0.049332362118988275, 0.03659435773208257, 0.036098679692874995, 0.08448156392982892, 0.04029044851420387, 0.08081659930007112, 0.024972131678594217, 0.019345987708337845, 0.033059356088239344, 0.06457319873715602, 0.04113390365795743, 0.04419470453755029, 0.11621019081963647, 0.06616086233407259, 0.0862229660513901, 0.03902096038443908, 0.010334554826840758, 0.04714604677452196, 0.08086821064352989, 0.07181207844687086, 0.06860068383356256, 0.034079804355579044, 0.016504908506307873, 0.0522970496076009, 0.022033104305005363, 0.036047455223817984, 0.034177469074605935, 0.04245304577653447, 0.08297213323173985, 0.026692217403662302, 0.03476107102488318, 0.0036804144685682392, 0.11034600226388824, 0.024607567672407436, 0.023025835511244597, 0.015994341548291907, 0.04079255786153578, 0.011518168330733335, 0.02373035677949027, 0.04314059053637809, 0.021645770250489155, 0.06915777531122008, 0.058406240742413275, 0.034783394826996716, 0.03746686292992484, 0.06185080570679519, 0.0336914092692877, 0.0207609731719018, 0.04172756051224086, 0.031052435553001783, 0.05172805695403969, 0.056457205810734344, 0.019667543538455522, 0.00995165929423585, 0.011503957399737932, 0.010945070403507881, 0.02547684380964887, 0.04857223052831908, 0.07976656854753533, 0.07853926504932104, 0.04716578502989104, 0.09052969019619689, 0.03720566525214142, 0.03633862609163888, 0.02913408627312991, 0.004373393904027199, 0.03845908851813405, 0.06864283399115648, 0.09925972174612746, 0.0653164878848099, 0.047853643885783614, 0.06625175100540923, 0.031349955374495156, 0.051052639366037426, 0.08738735074838323, 0.039929785810771494, 0.03617154997623256, 0.049902595834986824, 0.026430971845383608, 0.02468255235843601, 0.07743723990936434, 0.022323020703850255, 0.009422506085566936, 0.021748640536961537, 0.03554186400687022, 0.059507561081479636, 0.05314961353677416, 0.012284069521082266, 0.03644949433604076, 0.023712150699969743, 0.02953114581384486, 0.11340747347041485, 0.008190289090928293, 0.03548276798439122, 0.05512176517156824, 0.05283272509733516, 0.05832148077447088, 0.012911436159253843, 0.015026498623492738, 0.033325586963685296, 0.03425763251500265, 0.025632216016792005, 0.04010663720809164, 0.06986937140144649, 0.02041265980580882, 0.09849836058433979, 0.0853198709627313, 0.009087444125344197, 0.0368983835552729, 0.03764255753447933, 0.060351958513380065, 0.034702626177139824, 0.10508648690677459, 0.033937744841340094, 0.07278884821120771, 0.024432426566378247, 0.03565945084236803, 0.06315009082637488, 0.053453842373264414, 0.016935898081189203, 0.059356641760396386, 0.039934298068645506, 0.01600371654926529, 0.0268866351970862, 0.04303017811429116, 0.03932187206021721, 0.047952967185166576, 0.09335113073428793, 0.021640930490027514, 0.11070817799097109, 0.08082813658421079, 0.15469512331389612, 0.03241217650112606, 0.008675847108656121, 0.03278580907311651, 0.04088826522591614, 0.04393216237545975, 0.03872800836219423, 0.055752504511826464, 0.018307040332846584, 0.00314899459725336, 0.026065505770665985, 0.05751898069114936, 0.04333025475423183, 0.027575388460630373, 0.03161559061657998, 0.041041436845496784, 0.01269682428814591, 0.10167340432564098, 0.03471354676050044, 0.04038346690997001, 0.01734281334305002, 0.029290848929855614, 0.05879205028196016, 0.07049177953552815, 0.06185793798537024, 0.01265093562148151, 0.03337302695839636, 0.0717235110219448, 0.09372450666682375, 0.05945126894080351, 0.03934971552582518, 0.057751672237270305, 0.033123987095971266, 0.041095564787786816, 0.017113398738025178, 0.05792835509524711, 0.012313228742700192, 0.016848313164026026, 0.013548082995018172, 0.02510598064550469, 0.22379118258193617, 0.2525471048730035, 0.23953264999774196, 0.22136602400531694, 0.1638933111943545, 0.12460299812617803, 0.08060664524354282, 0.1324431955694191, 0.13220774610677075, 0.11911064566623782, 0.26191139593720436, 0.13401870135097735, 0.13431013651913212, 0.15638630837202072, 0.1483813024336292, 0.08506711557387345, 0.1533160271543649, 0.20387776886984227, 0.16897707065987974, 0.25218774834948204, 0.15997038943873298, 0.12275923133617449, 0.15823526157727166, 0.16913597261713398, 0.13319717930449596, 0.2689472087208302, 0.18939965704996742, 0.19346194552077403, 0.1222394789839464, 0.22236992094305255, 0.07361131254583597, 0.08962353841672022, 0.1305468368434137, 0.20426484245446422, 0.15047751817732088, 0.171663036209441, 0.11045179900623138, 0.26720840363733234, 0.10532915291766967, 0.08106511056182847, 0.09092390372027313, 0.12204269397883646, 0.12502590164301858, 0.09279420013509451, 0.13284018233178124, 0.17304125902873857, 0.14794993364522535, 0.22685579474895234, 0.14495143486607462, 0.17346159615103277, 0.19644938199029816, 0.171102489675245, 0.0859698965664833, 0.15280069512945993, 0.1147044603262217, 0.17103862858587698, 0.17440132556423066, 0.11951903181691324, 0.059332027355389255, 0.16531158509033342, 0.11160551209843929, 0.1284666323373395, 0.21086335692915226, 0.1539746635863858, 0.10175506929836928, 0.17345981882704845, 0.1334584152866756, 0.12220455303547845, 0.1662914575107636, 0.1407706325933818, 0.20820759056556612, 0.15054684913446828, 0.20122154285350155, 0.23635110216996363, 0.158645884704686, 0.15052475515873204, 0.182330948450873, 0.10978334898790044, 0.196195071442954, 0.13944497872744838, 0.10090623621738727, 0.14648425422849196, 0.13443971263064494, 0.22164538562778505, 0.1747190069046713, 0.24260147564834167, 0.15676605815608657, 0.18577814492727482, 0.18327369625049253, 0.20570304995823294, 0.22116432837661237, 0.17848033007354508, 0.1667373972914873, 0.1351020262847024, 0.11433340564009645, 0.1325108104896161, 0.2014547706611695, 0.25963902593620364, 0.10326825382728731, 0.13636786400550796, 0.15812290712229668, 0.20128278392216853, 0.162067846244862, 0.24312524996217222, 0.17686103470623496, 0.261560435737333, 0.11588664124569586, 0.1644172387257699, 0.13767214401835395, 0.1204004466173149, 0.2996400004673389, 0.14697379973386565, 0.17739469155428872, 0.14364381470987875, 0.3265711779315626, 0.2082801084484785, 0.19531354939024295, 0.216707841703488, 0.09254653157005388, 0.11707539519956035, 0.10966708748451165, 0.12613400186021484, 0.10991206708093805, 0.1504552709839998, 0.20391932147885525, 0.10770390290887126, 0.10664967399451042, 0.08457475852581763, 0.12558542161939606, 0.22569204590493636, 0.08641476382411296, 0.11186562959224948, 0.23343007020171613, 0.10456229890546492, 0.26245813756700487, 0.1537836625451042, 0.19327475959735532, 0.14775111850711609, 0.06622925100307311, 0.1177072645195069, 0.12085797730833293, 0.13862400826427246, 0.13025529442294953, 0.12258707605783017, 0.1479459346662606, 0.16926070705296534, 0.09131008864290292, 0.13520212333288886, 0.17047423629030106, 0.16661937378587263, 0.0901769909767374, 0.10299289118378394, 0.21650643718819465, 0.24784810540656893, 0.16081080321342717, 0.13518957481268915, 0.10715081807105772, 0.16269130391939995, 0.12368798270941743, 0.11048311668057596, 0.16931649357561143, 0.1645902826661064, 0.08186259276924596, 0.16703185084606373, 0.22812576934454903, 0.12035950687864136, 0.24011089316298886, 0.18984032614577204, 0.102908177181117, 0.1069100596190941, 0.08175606058249552, 0.24266490772847207, 0.18963565809592126, 0.13667748610098518, 0.12794583810553437, 0.08644891602377738], [0.05222751563715358, 0.033725147781473015, 0.026052417158479654, 0.03391089729003368, 0.03155302804624362, 0.09107882202032114, 0.023137284067249107, 0.0072821253730404765, 0.03342550781164919, 0.10055783475118299, 0.03958976534645885, 0.014186812632326639, 0.01562169052645444, 0.04510470590884647, 0.11103146709501745, 0.02811829582036984, 0.05314786302586717, 0.03870494145479414, 0.08412583866306851, 0.076129320978878, 0.08732891356151912, 0.039095378165403684, 0.05581335104521244, 0.07131313304266623, 0.03200190960459652, 0.09208662600647058, 0.04652912382997813, 0.01666984915162527, 0.043309643158629056, 0.019396840624751586, 0.0215437637281514, 0.050600061433449875, 0.04846661764707777, 0.1331704121924216, 0.04253983204703658, 0.026102299058449366, 0.061297736190740144, 0.0444171688098821, 0.03605876651201998, 0.029098334864923553, 0.012985066784876249, 0.050118847134252714, 0.037579125454348904, 0.021773888879726012, 0.01697969915825994, 0.027173870288196112, 0.044578066426179105, 0.025829587079164003, 0.045293795560757, 0.052686670434571085, 0.02805460327034516, 0.041824351891034076, 0.026979954282362616, 0.060169744500589956, 0.03228284553774903, 0.11293382428946996, 0.042613319031173186, 0.020392504032521, 0.02207598224612734, 0.03798024143062292, 0.08980573710775183, 0.062093161452080936, 0.06565301498818783, 0.021058868376478072, 0.06302061047585261, 0.013928578757200272, 0.08290050401081962, 0.040785084673834425, 0.010261335973477653, 0.023518529637987097, 0.04079929560482983, 0.04052189516744787, 0.019314319548767903, 0.0057114052469842145, 0.002746336390226779, 0.07469282185118045, 0.05631218153622843, 0.06160492212661813, 0.05089591309848813, 0.031157381937748967, 0.03954229087779119, 0.03907772749962826, 0.01396113366354257, 0.09481362322525633, 0.06521006295036885, 0.027348448319600958, 0.09346628141018654, 0.08315882885888701, 0.060268600486339106, 0.07679767140577878, 0.09561430001931806, 0.06298610970618264, 0.051317805379268625, 0.043374580601530696, 0.04333808034237835, 0.02727949466075628, 0.04303540666437438, 0.02395066642953504, 0.033409155664905425, 0.06482722583196818, 0.04805388011699242, 0.002442023762869799, 0.09287492281967595, 0.013494943306150456, 0.07346900405302163, 0.06556538985140863, 0.04027744800212883, 0.05956874086311268, 0.028852491504362518, 0.0247136919173382, 0.05609779183061854, 0.06366124001121329, 0.020145929057992274, 0.05594185463363125, 0.04982118750171316, 0.05818763372278022, 0.028728862150361942, 0.0394653181935991, 0.05246890611165474, 0.1443518944565327, 0.008137985395507948, 0.05074555685202922, 0.0454898604432181, 0.04934046732922716, 0.02116762221820893, 0.0378822319720301, 0.027386628226527286, 0.05141517515444467, 0.023155246913853674, 0.05809240899379215, 0.011042008296616617, 0.017823939542135885, 0.03944185675091801, 0.05300330223455545, 0.04259258869194216, 0.05959834250050688, 0.0159510470468611, 0.00570844958401135, 0.07808674457332782, 0.006856499850043968, 0.008342030998920242, 0.026712807931847153, 0.04537353382235573, 0.023741126060485843, 0.04148976299010458, 0.07644812846856733, 0.020195973751645897, 0.026016240571475318, 0.06309114802148073, 0.017949306000504765, 0.005752115159280478, 0.047626686507775906, 0.011947043502943651, 0.04667874080159011, 0.025830498723793897, 0.0955474971523208, 0.056371549519920544, 0.0362283094305425, 0.029772806334339326, 0.0222788940394117, 0.05059730351692246, 0.0598840588223069, 0.06521405426845436, 0.06317785768319042, 0.05218425082162984, 0.025921414208207882, 0.05508763595454155, 0.08982379380012713, 0.026144922275336522, 0.0510064595859618, 0.051929503604168856, 0.10551078470363733, 0.07554432091813895, 0.050769776721755346, 0.04429748289347176, 0.02586319918684181, 0.08137068771306546, 0.008230672458246832, 0.016341174449471217, 0.039468497458484866, 0.05887649232341398, 0.09338631715265014, 0.012453875782328748, 0.017420475506373954, 0.055643926870318196, 0.06507690154737042, 0.022917702200732405, 0.06674056106637563, 0.056819105746164444, 0.052110966850793174, 0.05239531187520874, 0.018562184000808387, 0.09853824312167783, 0.007579153461847455, 0.07746550855377028, 0.05215993136047356, 0.016297819618616375, 0.06738369187880909, 0.0506677529624393, 0.041908560275670984, 0.055383035627704476, 0.0536514432620137, 0.06472336729207347, 0.0057812897026568895, 0.051749664463944016, 0.05375887560207517, 0.06527350269137852, 0.03398574024979626, 0.0378351635299623, 0.01973472944941492, 0.1006348495702109, 0.011829895252782491, 0.040768180943785176, 0.02310415842540322, 0.04267049600340186, 0.03472411494341589, 0.01059611448116841, 0.04154927270006269, 0.049318833006245476, 0.012028938302049234, 0.027236090034186363, 0.010185854287908204, 0.019154184189955556, 0.03735606363343616, 0.03738574571006241, 0.05137218613057368, 0.03266883510795813, 0.030738814478559844, 0.055878901358453505, 0.035313217404989466, 0.034211605952511874, 0.06689302022418668, 0.01763209963457719, 0.015490770888244434, 0.04898735442228856, 0.02342266714080207, 0.0153879092202612, 0.055854164379378485, 0.0524165669846679, 0.026108199850686138, 0.08799878084250996, 0.0598704569312113, 0.04098906324455335, 0.038552873001824466, 0.04067822306927654, 0.021812488219790885, 0.060131631626357, 0.02992463155439304, 0.02671054222681109, 0.017622519705084064, 0.06924975948828845, 0.04344742790225052, 0.0339674920354399, 0.03873039089563874, 0.005893724596863914, 0.09574425151391376, 0.035408308068590785, 0.060573649036908345, 0.057597297859648545, 0.0230246193466648, 0.1029597195766626, 0.038624789505716295, 0.038740905452399485, 0.043041343845787554, 0.039481452005284454, 0.04599544782972625, 0.1075312573342554, 0.04819820342104762, 0.07711936704694264, 0.09235365361335779, 0.05599459212633872, 0.050865288733715014, 0.047245768439625545, 0.05287977821764447, 0.049322399145533005, 0.0981822956894194, 0.009693112280670433, 0.07460087597850831, 0.015057237901454492, 0.027877891684071194, 0.03787151057152979, 0.004930356583152448, 0.015307223882466076, 0.010847533046598396, 0.04495844057190322, 0.04560984896435853, 0.0299835781897268, 0.08605680924149291, 0.01563543605903584, 0.07911032997071743, 0.07098189960684508, 0.05989127537055362, 0.08203168369589314, 0.07122644253315465, 0.01604091777886835, 0.07259681295122832, 0.052114904542723973, 0.05897955413186743, 0.018481633686009916, 0.08199906367207728, 0.01798488120848854, 0.031501315196134874, 0.031678553467856786, 0.04019125161932842, 0.004356366163495207, 0.04578973790029845, 0.015174494361534957, 0.03701659858286862, 0.05525201161001479, 0.027961274608969692, 0.011948355428513982, 0.017126772717963305, 0.03526345999430745, 0.04976134071306837, 0.016509522270831852, 0.050891048440168944, 0.022434438616337798, 0.011905868192233387, 0.06029092428845264, 0.04066076009504257, 0.018198081562595985, 0.060843174090428706, 0.015941718011163175, 0.03646855460359685, 0.09780029360685619, 0.01372636984958644, 0.0839082773534521, 0.04786250752306754, 0.016841449016224475, 0.0812085452038915, 0.00828062330612973, 0.025058716851016207, 0.0015941103465006417, 0.06343857655602117, 0.03640268253342759, 0.05099340161729244, 0.024555701604713837, 0.024738852159991383, 0.0808567576290619, 0.019040289898252776, 0.028577331874159076, 0.041851551842785654, 0.08110742925876573, 0.03348048228109556, 0.04550993194683425, 0.05817604664292547, 0.03269789282292609, 0.06565919731773677, 0.05259941301999554, 0.11528330870092877, 0.04888942540292779, 0.010060706164597744, 0.19349203745443977, 0.11429004506358217, 0.13865161807306353, 0.1267959631138271, 0.13158025880975108, 0.13911770596619577, 0.2049983563202043, 0.0894451165391553, 0.11561831128933739, 0.18117270011815334, 0.10439011298360364, 0.10900308843702079, 0.08371086415624426, 0.23172517216974692, 0.2849799580872059, 0.17262305163087385, 0.24824625662257596, 0.12129365917175047, 0.22214835299359215, 0.3513894542571037, 0.22385038585672457, 0.14875558234991568, 0.16742131462500942, 0.21388183528136825, 0.18820316560806769, 0.14613041353802528, 0.18969728220855037, 0.07365725483865508, 0.1513358890529602, 0.140244989025016, 0.16441722340401144, 0.1847756269478029, 0.2703090985455821, 0.15530997016016515, 0.2984702148504796, 0.07610760238622466, 0.1452766851552071, 0.08931816810922277, 0.20822228413195382, 0.08383783556881451, 0.15832904606096207, 0.10482458442810083, 0.11541680718261389, 0.09746418785183661, 0.13764790499642973, 0.10708671183355394, 0.10580060342627187, 0.23974770619984598, 0.1708908042600078, 0.19949568465592402, 0.1174614115828468, 0.0750599388453749, 0.10772322364632161, 0.2081387192611733, 0.11523405690827679, 0.16419340315605366, 0.1917268023375542, 0.089776809627731, 0.08424379322076998, 0.09754904741120916, 0.1942060007563522, 0.21851302064474554, 0.19621954029125555, 0.12433665999842268, 0.23371782814783437, 0.1330980934923695, 0.20205864712836283, 0.14121352334416684, 0.09365414915185782, 0.10569818513167482, 0.13315757255881064, 0.12855929833266044, 0.1449111846065329, 0.12551017646347323, 0.20046418833155788, 0.146986210358239, 0.09975790106240781, 0.1644461202405153, 0.2379183035584227, 0.2095288011215387, 0.3102235357847906, 0.18430652066824899, 0.1877821696501586, 0.22284077390307383, 0.22576315418606807, 0.1512774365443376, 0.16311904145104272, 0.15008874387750704, 0.2074001338933745, 0.21586643201449227, 0.18419830308806512, 0.11757436358640272, 0.1313394007663573, 0.18552248606518393, 0.12927176010224128, 0.16847407265055567, 0.16274295356725493, 0.24491424912646895, 0.11656097481928526, 0.19708342699994966, 0.12816443363384855, 0.14750160367017792, 0.20602807042098817, 0.08222306012025765, 0.1401299685840645, 0.10642061370515055, 0.1198716008014256, 0.10521295270131481, 0.12940711251670314, 0.24243877389498297, 0.1263468287464592, 0.12466936432305845, 0.1002271299160296, 0.1948527934690637, 0.14895807471006148, 0.22991459996950245, 0.15239535800872311, 0.16705400610883392, 0.14826937698789183, 0.2805194877568753, 0.16493595685930024, 0.164201554331568, 0.12918418093073752, 0.15594798350526443, 0.08557205178564595, 0.13078208712320175, 0.07322932578503125, 0.13051826176383804, 0.1267527557548977, 0.14347029579502923, 0.09732178742847136, 0.1649036279488956, 0.141518380372755, 0.09909871304708143, 0.10293050098323053, 0.15088133844396762, 0.13561706719619615, 0.12467521723479995, 0.1586930603990632, 0.09828685903020444, 0.09981592456179281, 0.10854535856314244, 0.20325955123670642, 0.10046238019581764, 0.14581368214661075, 0.23123057048407294, 0.11532987918584578, 0.2512330955435192, 0.22204332233917332, 0.14672639929959852, 0.19651212459129674, 0.09327167209478156, 0.1181405408668422, 0.20867275915318922, 0.07327034213249722, 0.1370355096315184, 0.12748530434985317, 0.15634795801053125, 0.07056320191270883, 0.1788403760761984, 0.15110192580088494, 0.09502828872251896, 0.2636864829447962, 0.09666122811576051, 0.17446350126016527, 0.09963595518662084, 0.1711194202183716, 0.16798356187439736, 0.1375809489118476, 0.20859818815463976, 0.20421820302163401, 0.26212259105617003, 0.2156920091158921, 0.16491617646909532, 0.1967597242084242, 0.15998417902137005], [0.05174055567852432, 0.0241693826166973, 0.036547492303314714, 0.03754770052769492, 0.040945162576052456, 0.058929984412726864, 0.1082295005119616, 0.03638079157099128, 0.05365174203630417, 0.03200745991160793, 0.02276253875254864, 0.1112254482183245, 0.014358124256344333, 0.003970033290135044, 0.05919700818917444, 0.06359435670498399, 0.07326525530868, 0.027065173903059576, 0.031013849619475585, 0.04055745696889297, 0.06285417404386305, 0.021587480535550464, 0.03728006388090792, 0.07561055688007225, 0.018069597126375285, 0.040973818094860164, 0.033104651036762425, 0.04821855454675613, 0.009173457604652692, 0.07023282649536287, 0.01293068794879101, 0.08686022096944433, 0.06374608041838774, 0.03954923929526441, 0.019722803375653682, 0.025948411146659526, 0.03981687594205141, 0.05849635949538601, 0.03326909180970923, 0.06199928503783961, 0.03359099429461264, 0.0766244665869782, 0.0056472808148922225, 0.09052929183047626, 0.04201593515913814, 0.02514030521495208, 0.021741971741580678, 0.03142491324744638, 0.049596555200555635, 0.035030845056978926, 0.12470537045549963, 0.014081569388508798, 0.009450748874505442, 0.07800927776242457, 0.049592801369726665, 0.01523571819322364, 0.04100223995685097, 0.00979991547102409, 0.07765050346572554, 0.04561211275417478, 0.04918154238933518, 0.04281714821474687, 0.0018852767853757308, 0.04977795332970639, 0.052221950008383686, 0.018272823015708598, 0.034514605217883666, 0.015144505849738997, 0.016864310995104815, 0.08234142836543822, 0.04496363464802985, 0.07932447452819155, 0.09845321502296195, 0.034129259161530964, 0.0708221166484779, 0.0843639770943311, 0.05911375358400326, 0.005516595791109027, 0.11901050265277587, 0.2497984733312361, 0.26566924106690193, 0.4290212192122014, 0.509573495195758, 0.447838238530582, 0.6899566804209064, 0.44640203817717494, 0.45486798389784755, 1.3462988936132, 1.2077240069066326, 1.2480633777956809, 0.9376747040979324, 0.05528540538263418, 0.24409133279996537, 0.16437643688292275, 0.7589571165942377, 0.5071138933060632, 0.32060755116324274, 0.1449559088195524, 0.035112195933658275, 0.2207459984046798, 0.057575192392593434, 0.028784238815968557, 0.05316088269014032, 0.012152856854241223, 0.008368953243799267, 0.04290219163522125, 0.044454718609490705, 0.05683285319396565, 0.047577940333153934, 0.044826462774747805, 0.04938201993824013, 0.03831401827835268, 0.012216666232674353, 0.07855834829951487, 0.05790596617566002, 0.0497784742694949, 0.0868412449715599, 0.05539364594545576, 0.037545674225135196, 0.0208860753299368, 0.028103104296831355, 0.015536319603392435, 0.040720020826425285, 0.05315046389437011, 0.00323629486487217, 0.02352960152371276, 0.031333086118402506, 0.0183970843922467, 0.03345188038844255, 0.054256974479123476, 0.04832635077858164, 0.06667041805602851, 0.04322217123943471, 0.06966206800913619, 0.039497712221477306, 0.030987963508514148, 0.04308885661885143, 0.04970563846009393, 0.05262028508549256, 0.0721388379292142, 0.09861183352768423, 0.09962736734098966, 0.13168194932082009, 0.053320416669932105, 0.03045730780990374, 0.027078789200693853, 0.06330089523426949, 0.06829300760141305, 0.1462141929134246, 0.023123808580661015, 0.08348925024150841, 0.02140815275901508, 0.021016777590698293, 0.05061548661380526, 0.03089908773319856, 0.020762913289570042, 0.02950129711309508, 0.013598995283246042, 0.0374893514409421, 0.02020706670478948, 0.09795998463467245, 0.03904398898744295, 0.04439412105468012, 0.03788482517965379, 0.022950666964114196, 0.054964471998954975, 0.03871005892212834, 0.06965691989828503, 0.010463164709959059, 0.025046241109169302, 0.037179376945019736, 0.05218760628673819, 0.057379606315085006, 0.04070360739264758, 0.06986635301502482, 0.0886789366843239, 0.018259485424946875, 0.03108599786496451, 0.03694527579711811, 0.009190228226925097, 0.04949164328976505, 0.0644309132269794, 0.060678974635178046, 0.05258286169039146, 0.03149925058917894, 0.0479018384771001, 0.07429306951141165, 0.04148790905732782, 0.016506281718912146, 0.06396013687575056, 0.09230938139221362, 0.07913279932953658, 0.15042073574037323, 0.021534737297183564, 0.05369457401215069, 0.01532504500280465, 0.03421214987493811, 0.006302239067266666, 0.04668656638973663, 0.09581253293060488, 0.03001148868802815, 0.05240901718817411, 0.06019115665807359, 0.02683413136119564, 0.026953374861829707, 0.016595956140888796, 0.03610118096994777, 0.06781750448769139, 0.03433050662879983, 0.11445287705188799, 0.015805068035279552, 0.018331924783847025, 0.021285191816728444, 0.051108222875383594, 0.05549306500582926, 0.04688290323341086, 0.02231500550894247, 0.03964360600577728, 0.04632972646504641, 0.022433936828747395, 0.06399205975955533, 0.034396191007427634, 0.04407110008140726, 0.03664318051549696, 0.05490277127753343, 0.015876933785846398, 0.07061212428755338, 0.03427166724577546, 0.026327871732533942, 0.02766822299529468, 0.025693455170239174, 0.010548937829181312, 0.03931100510301129, 0.029999694764433853, 0.047963064224008596, 0.04331586379257422, 0.07323081965648359, 0.039521663960429936, 0.05331188245045562, 0.022626267032577627, 0.009479048162428363, 0.011550043334042834, 0.022318299687016877, 0.005944888257691938, 0.06439149034239593, 0.05968254705470416, 0.03747657692480472, 0.09782793405916422, 0.01864192226240712, 0.05286853204691603, 0.027221296876368505, 0.042960180660649654, 0.1406676703763585, 0.06495388314848946, 0.09457630450807272, 0.2957679163063726, 0.3743442676721081, 0.5253042220588654, 0.6518064823842818, 0.6210873372131779, 0.6731344927703181, 0.6460147963896875, 0.6127896856877112, 1.5883079075044202, 1.5046376230255252, 1.4058094615897825, 0.9016207677702751, 0.08489209512669234, 0.31119033874523255, 0.41223690694858955, 0.9184309431622106, 0.7920071915272744, 0.48653370730819245, 0.1776247017926747, 0.13465072388850874, 0.22702298577754731, 0.023374882406525077, 0.021459074623342005, 0.02487618491173752, 0.023207467297212254, 0.03982869667872306, 0.07854243665332757, 0.03797898887686672, 0.01168920799353791, 0.0603778982504962, 0.04582597768955654, 0.04311822842986834, 0.028564534375383973, 0.059968259546064565, 0.07987588929433016, 0.04190805465764096, 0.015572643662322194, 0.050055974298307014, 0.052794370905406056, 0.07098455793194233, 0.030764256258525198, 0.05120255128150025, 0.07421727277218335, 0.03416968562129525, 0.07423598063929428, 0.04384166057852488, 0.08784363271608468, 0.011359508648785132, 0.05327507575613357, 0.05688359502763037, 0.02000210945674729, 0.03233913001754592, 0.03370007372371132, 0.016211213378776467, 0.029074884913561326, 0.07209319441068558, 0.03441387614715965, 0.01666602637288311, 0.04667491419240833, 0.00886071848893358, 0.040408368597948746, 0.060854975674902244, 0.0983337589329289, 0.03638749100988911, 0.07603741341060208, 0.007204919989641396, 0.025023434671663472, 0.029659229969125123, 0.04960565249465647, 0.08068245730452961, 0.004928884736727923, 0.08929898526759879, 0.0141962374290151, 0.023443954808998014, 0.019156811871535836, 0.0522890669714299, 0.031462145120566415, 0.03240313283317993, 0.025447956549244064, 0.05411810572108915, 0.02666358295227251, 0.07281995138093349, 0.08692325468385413, 0.036061110741068284, 0.016347538724902178, 0.0568828480919042, 0.03616545957723453, 0.06336988145185095, 0.044042268362376964, 0.02237317839547271, 0.031410198613640763, 0.04204062234249808, 0.008896093556447136, 0.012622552063886919, 0.06404403882521777, 0.09427270386368038, 0.04741102126577208, 0.16222855616961757, 0.10436847099974271, 0.19667862614075984, 0.08783730482983013, 0.10972269780693517, 0.16933042105407486, 0.2781847888423551, 0.16371989953181437, 0.1504105314492218, 0.09556819684803487, 0.11707695035804665, 0.18142662762153536, 0.11444179175962364, 0.10726570827706207, 0.25593112973916915, 0.25836097677388503, 0.3196458963136519, 0.11525194506130873, 0.14771302861552085, 0.08336118332320645, 0.17414578927620766, 0.1009227071077593, 0.1335001364350319, 0.1785200287497813, 0.10878679117247944, 0.12909120850024686, 0.22012753562340814, 0.08683908460361343, 0.09853237488817784, 0.17718607049074866, 0.08430721764002116, 0.16194066032767296, 0.16512609988210664, 0.23156775642306576, 0.1433771701469537, 0.10005648383089613, 0.19640908576548102, 0.11528617386976558, 0.11744110259197413, 0.14443935105396857, 0.06845017053907917, 0.18653480997008665, 0.15240904033905076, 0.24801531175692237, 0.15953295323396885, 0.10730364495107245, 0.08885218746839993, 0.19168428445775665, 0.1812333436382394, 0.1103522228978334, 0.20716021047724834, 0.0973466010163388, 0.11532493025785494, 0.15043708405667736, 0.2097306959331036, 0.10799895401202864, 0.12446953794888913, 0.14814606747559964, 0.2208550127163049, 0.12156700700401299, 0.19747161907294106, 0.10812097649660804, 0.12342070995439446, 0.0908690058596192, 0.12997364985846704, 0.09811986718446979, 0.10743182678256305, 0.1698818051766965, 0.18349109668164484, 0.16754232587352877, 0.21487660045104645, 0.14692740544917124, 0.17017731593260843, 0.16277071659363088, 0.16323502716277877, 0.17044229042385856, 0.1710540422749135, 0.22112058475613597, 0.264126431917952, 0.3407309955406574, 0.6616263812588108, 0.8414387390498193, 1.080604402288314, 0.9275386867023284, 1.3167917608253419, 1.0758352904550492, 1.1480973612877632, 2.6801918206676363, 2.8290477298921157, 2.773584435063024, 1.5264007713525527, 0.3740419080901531, 0.8545035412234645, 0.895705281967117, 1.5211512917472472, 1.2009398999714083, 1.0447988010221914, 0.33334299681648133, 0.24856858045583774, 0.4632302932441235, 0.169752933866074, 0.15645551675510022, 0.15199199739483096, 0.11533325763359187, 0.15080632311442208, 0.12407376926632659, 0.1592622484050451, 0.13436330302107719, 0.17748749544543607, 0.1521084580810801, 0.15002805439214553, 0.08556046853623084, 0.08698687062508638, 0.28246896701955027, 0.1291425976782076, 0.13228138247805257, 0.1400115926780047, 0.11002612991198418, 0.12474876167553088, 0.09833335290632902, 0.1290349470030877, 0.15317433153189, 0.08454808334429419, 0.0816340534196746, 0.11837573752047555, 0.15535775872488178, 0.17597275575803173, 0.21218878096870838, 0.09367900870500073, 0.09680146817117931, 0.10418945157359685, 0.17967947217966282, 0.16868094703362835, 0.1782533228998223, 0.12421580962836744, 0.19197306896169342, 0.18931944764429526, 0.15816160988423134, 0.12850480649860638, 0.11105149263335813, 0.1681771676146215, 0.22105329159286716, 0.28886423836792674, 0.16824272941918145, 0.17101484921670732, 0.18164825685802968, 0.17395008445507096, 0.14763168539972077, 0.21485168727174883, 0.13149349169144708, 0.1502879114160615, 0.11655629402206791, 0.1156797898452609, 0.09792507400796299, 0.13481167896140006, 0.1290167600757653, 0.17359697920901163, 0.09590832456465691, 0.15441197721708208, 0.12617347071007376, 0.24070787483886366, 0.083366722138899, 0.20187182892714778, 0.11014619121147741, 0.1265259247813975, 0.16410001703808386, 0.2137214317917824, 0.14473665445562334, 0.12472676729122478, 0.12948747513996017, 0.12466354205483392, 0.11727670012342355, 0.21043109947875624, 0.19645453010114933, 0.18212241931788384, 0.23152834886024076], [0.06690501716108092, 0.027231920600658464, 0.014379253918905894, 0.081162495658763, 0.003588056823636796, 0.06764810712587449, 0.057545177067720124, 0.034305784971483295, 0.0373381908021627, 0.0450255690262683, 0.03836476394245702, 0.06159489020524968, 0.05134988914153749, 0.022121313583826827, 0.05197789354790604, 0.06438862517355912, 0.012672253933194424, 0.07658420866655727, 0.011639075199772995, 0.07278457344059022, 0.08045875196976048, 0.03680486720235598, 0.07513182087531013, 0.04436229393186589, 0.05911977120464849, 0.02028464459844174, 0.0586822583910919, 0.023358852016709508, 0.02571517950855196, 0.03364602622065333, 0.09664877918699095, 0.04444979266413758, 0.08419507002878575, 0.026999309493769563, 0.04562141689201517, 0.07419088870407113, 0.023938223246424913, 0.030353261578467586, 0.07642271733211894, 0.03180976900752754, 0.04980155266821385, 0.079464546044267, 0.016787181262888255, 0.05921041089740973, 0.04074187348446539, 0.010744209810640785, 0.037316602444456476, 0.05590875197442309, 0.0864141815972905, 0.0639603054150939, 0.07057772693975319, 0.04576801164676586, 0.005045286051162909, 0.10562877756573501, 0.026966396441322663, 0.024639837210997943, 0.018357356987713326, 0.04691660344119995, 0.04027125035082141, 0.035523860940649625, 0.1373172308047933, 0.05184845533221961, 0.07693038847778114, 0.03921941929166356, 0.011073148813128713, 0.0429609582398928, 0.0775648778184287, 0.05279832391909534, 0.032555860121764486, 0.328451004480162, 0.3426059804135754, 0.5578041845752347, 0.48096090795532354, 1.3812539534222696, 3.1904335896815024, 3.960628725828663, 3.02227373565397, 4.338228683317862, 10.113741274802916, 13.719342793187788, 16.155155262639447, 14.576935691218223, 22.21415323595847, 23.75982399909727, 20.289832545864968, 23.824450931241437, 24.12558697885083, 25.838403663327618, 28.30926545204655, 18.86631223463243, 15.516888556941865, 14.251812388820035, 14.56692482194593, 22.150334312069802, 20.856140428973784, 19.872551195083126, 10.846034057678716, 17.272474765777588, 14.702324059701736, 6.933874795513769, 3.49180743098259, 0.8160423727766161, 0.04359320294292223, 0.11825410574073754, 0.07583305179592102, 0.07963755168020725, 0.03317153817343135, 0.0540511611278259, 0.013242376566443954, 0.04784576084104277, 0.0343282466694232, 0.016351802004200798, 0.018960088153459856, 0.06954959098009333, 0.008395377531527512, 0.02494040031677052, 0.024924398655252113, 0.09362722882219861, 0.005791428397529789, 0.025822249872069207, 0.015045809784844039, 0.028099277687649575, 0.04361723895154653, 0.0671327751009695, 0.020838127801975897, 0.019109337402868177, 0.0527515504208784, 0.047151623894610716, 0.06175671478793506, 0.049948921171768065, 0.01624817137546357, 0.03099427798823003, 0.0565413873822939, 0.06046038293730348, 0.020187881947945685, 0.03446192518177052, 0.050931111008169196, 0.049134565877818295, 0.022653401866855643, 0.04571528564537725, 0.07055438424070036, 0.02152993967155776, 0.022855488200401588, 0.08241786861852293, 0.041655218829551054, 0.030290848395276456, 0.08594311413265045, 0.05786540182006936, 0.0353390307375981, 0.0006682145659954498, 0.036472599547837055, 0.038878943005035964, 0.0620711594068956, 0.03744579934244675, 0.02537174612253664, 0.04990061166726294, 0.05954098932805562, 0.03288360785753016, 0.02051162495908718, 0.05094655534072269, 0.010692458656135826, 0.07159799517643067, 0.046145018836062764, 0.04781119495389923, 0.02329033119754205, 0.049517946918645216, 0.08650972042232753, 0.030923897490626386, 0.023498389186457764, 0.0465431853738283, 0.027142106367635633, 0.06355426732390639, 0.023141014915440353, 0.020811284081109112, 0.06279933747024306, 0.023018848789375157, 0.04503731698458714, 0.08794206735347548, 0.008550607054794749, 0.14568284965090214, 0.052161727836656, 0.05514003253812271, 0.06481523655595318, 0.020357583829712485, 0.03279805115814651, 0.05824723536328924, 0.019878696522585327, 0.07638556206779135, 0.10244480890011597, 0.002213019972494353, 0.06541632446310212, 0.11528453444160762, 0.02542926400389162, 0.03471788664859149, 0.06835804846618446, 0.012645542362494575, 0.012805050486818919, 0.11706417967234889, 0.036294890132041714, 0.057216425756773645, 0.08974861759211748, 0.02828833478082332, 0.044716188248487256, 0.044949799100117344, 0.04055571028842561, 0.014967256086698223, 0.01531016182965569, 0.030492835137392246, 0.13074513104173446, 0.006685658412489801, 0.03289388109659476, 0.04582491282734179, 0.023758677134831107, 0.034475155520222844, 0.03055389617539702, 0.06503968499600887, 0.04100762555495866, 0.01597666502704904, 0.025811442286677422, 0.04186794612436526, 0.05469377483091047, 0.08137244205441206, 0.021212220026720918, 0.0409388346897979, 0.03845411277706585, 0.03707247320562601, 0.05407291802487547, 0.05771491916910295, 0.09358990501852767, 0.05886787766470544, 0.03248775490529595, 0.02376969539440207, 0.038659838028252125, 0.05656979392252623, 0.055295682452138395, 0.10226474759439308, 0.08025301905769495, 0.05119487125005934, 0.062351398200037024, 0.01641867573433105, 0.018917060825192643, 0.029954277241842884, 0.039021799250716166, 0.05390737025487808, 0.07316674406249678, 0.26022425582332, 0.2785725212625919, 0.7987826569907127, 0.5816525016580859, 1.2646633386611938, 2.7728122184353494, 3.404481497503096, 3.755717734175344, 5.737162597717778, 12.113263607025148, 15.882870208832527, 18.926040126431374, 18.5783730014678, 25.949665615635535, 26.68309980823148, 25.12141400767911, 26.62067920930924, 27.115350884775964, 30.230632597400298, 30.99431218639497, 22.29641514439737, 17.11279311487752, 16.26574452846281, 17.476455665403797, 26.73638520702239, 25.69727090097243, 23.933863486013106, 15.552016323612584, 21.994416175350068, 18.724236142250803, 10.650170503124114, 5.056008696556091, 1.1556129902601242, 0.007936683344474484, 0.07173671837775938, 0.004410533367791364, 0.0039905278179268805, 0.03388334110739731, 0.13149215869845884, 0.02953915526309321, 0.026073339019691753, 0.026654535453886758, 0.031022531310877496, 0.004876142455970929, 0.034092463958527774, 0.020772818806430986, 0.07834965828806162, 0.013519939797509824, 0.030750865041608774, 0.024093522675215237, 0.037183670867835326, 0.033468496835520195, 0.01391486195291603, 0.027570338025989554, 0.021431602710377307, 0.013749716379078887, 0.018173855947210424, 0.034865201525991006, 0.11534553036213883, 0.07564098589242467, 0.03969676101640348, 0.07597280921594751, 0.001370554997382926, 0.030334825672569777, 0.061566453021500385, 0.03485575183144501, 0.05073925194841239, 0.0424883624298438, 0.017152235565346577, 0.07567298538502186, 0.013704797771248608, 0.01852100102921888, 0.0402866946833749, 0.004879046886813857, 0.04685978269985607, 0.051132588301815336, 0.04719218825020137, 0.15450056762464587, 0.11066539198040001, 0.07347681048897005, 0.0338137726629934, 0.03188547956186437, 0.05680371503976565, 0.023255792123475866, 0.035825534873912414, 0.04720101358308908, 0.022155827760035475, 0.03621038297311433, 0.053442917959464174, 0.06374316162339623, 0.07196246916728635, 0.018945496093722123, 0.01756358839150879, 0.06758132724151497, 0.03363822744558415, 0.043676959335683815, 0.05021238263936774, 0.06509688878131491, 0.037821699534693075, 0.03722138537634765, 0.08708364285168149, 0.05394816060640639, 0.027534538737287926, 0.01560443726878974, 0.04439788254638834, 0.06380429927019343, 0.049505030676241846, 0.26683807673473514, 0.19120244579690118, 0.15081976029661395, 0.2601100780790852, 0.20052055708102642, 0.200701997345013, 0.20804206960864607, 0.16448574230795907, 0.19735750261574023, 0.24440795693907047, 0.11991442511639289, 0.15578246254834438, 0.21485590075533237, 0.11071223825696977, 0.14749686924680588, 0.1899469349413149, 0.1166917919932354, 0.2904457502788113, 0.18589940132392993, 0.23034141819563606, 0.2557675393238183, 0.2088070390445571, 0.2267700082231914, 0.1358585840752048, 0.18489524391630005, 0.1367260101101091, 0.17041846508941344, 0.23738325243034672, 0.20134399434731853, 0.16295672274164616, 0.17580292938697725, 0.0936202267785707, 0.2547458385027224, 0.11699940693835098, 0.09060927140977114, 0.17689253624168136, 0.13118872659340983, 0.15481409676853689, 0.1657487914687203, 0.0951492999710383, 0.13300444690450547, 0.27529954850192995, 0.12536278880772092, 0.12710553924402884, 0.14947169069801608, 0.12347393774337347, 0.10968423253225704, 0.1715549565250835, 0.13613311934374994, 0.10230235485059601, 0.1589557059830235, 0.13577508049145823, 0.1566768242346664, 0.13524249616649844, 0.10943916866615896, 0.12146592170240418, 0.09520307168244355, 0.11221578539980036, 0.12936943631258704, 0.22615552909912603, 0.303222656610512, 0.10829880082559203, 0.22885474796977737, 0.16654274967168609, 0.15284823854604077, 0.11686616126568088, 0.15040205851677926, 0.20680192647682083, 0.19080619447894637, 0.39327715012815695, 0.4378277369804921, 1.286497334799459, 1.721926511776063, 2.231652366538202, 5.239997765710277, 5.618424117565156, 6.260900016753904, 9.48126300688713, 17.149792832712976, 21.1784258965523, 24.960118301453132, 26.351449681866555, 35.60113399259506, 35.6992442377152, 31.232482425628174, 33.69173203745196, 35.66832811601701, 39.39801185361801, 39.95469031795379, 30.925488318166426, 25.491148387232137, 22.663101842326505, 25.48505694635453, 37.25835107987927, 34.39429129323652, 30.80554812185226, 23.597739896466656, 28.682843754368445, 23.930464752258796, 15.133200345500825, 6.31238357674691, 1.3857834329528194, 0.1576036374054609, 0.17144410360244014, 0.19813454559733792, 0.1304018317211059, 0.2040752510149633, 0.18519244006564542, 0.1339020721253849, 0.20410476072180658, 0.11167186297356121, 0.16169347439802464, 0.08955148784744163, 0.16133952645524857, 0.17041386856186777, 0.14080239459872246, 0.14338979527594584, 0.24651333509433657, 0.08332422724173916, 0.09418645768516487, 0.12446753845940675, 0.1537443775563471, 0.0760101406804977, 0.13730515725910664, 0.1574375342217184, 0.13986006048658203, 0.1404170217292924, 0.19516452996721192, 0.16900426678119168, 0.11368109709433011, 0.12266684113250625, 0.1351504430415169, 0.11483917688770641, 0.14861505118108567, 0.13434284847349892, 0.19122956530942073, 0.11075384449213745, 0.11825491013305804, 0.12902765384604856, 0.12047961414341005, 0.22254357775372846, 0.17201827117992988, 0.20585396927931618, 0.16143452135785935, 0.13533313968969932, 0.11054310902592637, 0.20202297807460834, 0.12076312796242776, 0.08931412316498258, 0.12090835525023362, 0.08794543047946307, 0.18342680658303923, 0.15099809024362795, 0.2022690455158872, 0.09832802859525527, 0.20203158890287723, 0.2950878140907134, 0.1500140349831312, 0.10811988099087631, 0.21972785223155256, 0.09974427235823485, 0.284787149078423, 0.22448962494250269, 0.25322827961175676, 0.1528560986081439, 0.1937311334956077, 0.14839233409973884, 0.15427814165671028, 0.15430369834986427, 0.29526450460956943, 0.20963680419710376, 0.1495833863173762, 0.13751190906811145, 0.18509539204739756, 0.17359408339665783, 0.1878995956071923], [0.04547569930793778, 0.05909459755545663, 0.05895765933899149, 0.05889346117093679, 0.02760283739095734, 0.06796617151027726, 0.03557800803513777, 0.07500896335489328, 0.02878550669148324, 0.03853948561534767, 0.027814942239333066, 0.02317023350887241, 0.06057816512522198, 0.02273921712091373, 0.011793733987536643, 0.07928954857972362, 0.007166793708869767, 0.06108950200160185, 0.041988861611894066, 0.11100054778639348, 0.02616748164948677, 0.017344033338069435, 0.04348620344253798, 0.013653884525410833, 0.02787446535582985, 0.059909171184464816, 0.013278897893014214, 0.02467378256692281, 0.04255902637997943, 0.023271661634827336, 0.03264965609677377, 0.019841209925230474, 0.02155982476148394, 0.03512896559832077, 0.037296530940840324, 0.031044707641065605, 0.05909616420526178, 0.015156013447971595, 0.01941734305282514, 0.07274439212896171, 0.013621341110387397, 0.0118350510245129, 0.0373702822253108, 0.02207250803739073, 0.03596940618609229, 0.04483379806662279, 0.022591632197520906, 0.029725726400952668, 0.08048135922440598, 0.05026639949890876, 0.006914710083360514, 0.05794774478061065, 0.08218218932949728, 0.0644581706353253, 0.028886735634577852, 0.030882295085898334, 0.009227222612788601, 0.021024340793730754, 0.017761612543836236, 0.0401300220419803, 0.006500254601104967, 0.03879237506959227, 0.17671465062566344, 0.0768220330017709, 0.20325990363715157, 0.17232084526650368, 0.28013025380430684, 1.0330828038915512, 1.4370803126404363, 2.575231401189681, 5.381769384107282, 9.360649143495868, 12.462148627927228, 20.01691402927522, 22.563291249736665, 30.46647490993623, 33.92940805804345, 52.79028584880214, 58.1685378474574, 72.37891627896217, 71.02324316578527, 67.2638866978307, 76.11043960817399, 71.58855868924049, 81.56226742652156, 84.63745271005939, 75.15652702700707, 76.52097840462962, 67.9491247669343, 60.81601612029537, 61.86932548399895, 61.55754020137172, 69.65476743636593, 73.42577334373229, 71.91171492299726, 71.15051623313659, 63.35920641499182, 61.45709614599905, 55.88383566948676, 47.468974897938395, 41.63996804145075, 19.087392707024854, 7.440609720445449, 0.9008375807635246, 0.08840398772829965, 0.060007353012840596, 0.04657533808401035, 0.03588184233634703, 0.047859684489066565, 0.026134438362092744, 0.025220056883089488, 0.016038689420618597, 0.0413332550576137, 0.08057996240114013, 0.06953451436974349, 0.04930317799951281, 0.05226457897093027, 0.057219762069683884, 0.030186670013673367, 0.036588041337146875, 0.025726000500482418, 0.057820535880783876, 0.018715575870667255, 0.036321572974444404, 0.048587483338891506, 0.038003040207249504, 0.03743180674650977, 0.052689447503296606, 0.04684401661037438, 0.03523250238128728, 0.05434291422246926, 0.051469088592115915, 0.022677081644595153, 0.006000671907508325, 0.03733212721624202, 0.06625853088353911, 0.032815291966882446, 0.010547400865283225, 0.1285043085414556, 0.035065506705113, 0.06675050488763279, 0.013491787981512326, 0.0477781689034835, 0.03026212009811594, 0.030675813322886828, 0.04123766260642198, 0.00747204814556866, 0.05821773714776482, 0.026572309321753924, 0.023987831269961693, 0.04722996787618726, 0.02067809778025314, 0.039010702467132966, 0.04580005710463851, 0.016032284925571613, 0.06695072962752274, 0.1049443469533036, 0.06270466049412085, 0.028903254405445153, 0.013561659988256232, 0.03824654125398205, 0.023226481599492893, 0.023086371779021238, 0.022752424476728327, 0.06701863566113096, 0.021675098011450424, 0.08625392366441027, 0.028473536536518126, 0.08359479417483653, 0.0815432949832851, 0.04414261055869922, 0.02883750490934378, 0.047307587904675354, 0.07310762505738005, 0.10400284787700062, 0.032887553210340204, 0.04675655235205928, 0.07594192821171976, 0.042570644103351145, 0.05958240787168184, 0.11192100242741647, 0.06554426880733621, 0.03265163643405803, 0.010053245425825159, 0.03543676440453818, 0.04441383249697186, 0.0873991944676926, 0.030471298490620913, 0.015590170796419826, 0.06977716505888008, 0.06120759445512968, 0.03770889691828239, 0.04784941508044158, 0.08094955385933, 0.0788647528257101, 0.035804092072911804, 0.06072831835838095, 0.04476180112349891, 0.06991177436805542, 0.10396756186720826, 0.019875884979903218, 0.03361037631909694, 0.014013252540251181, 0.046117351570677374, 0.028620121715169762, 0.0355017171691983, 0.008882008072349333, 0.053943384048198505, 0.024747007165945346, 0.0087567929163455, 0.021238029528889927, 0.0384085190542523, 0.04059684920995947, 0.02594068706516297, 0.016986852504252907, 0.04446125333948482, 0.0431715902842341, 0.0383250652662208, 0.03599353029482788, 0.05201928910889453, 0.06893448366393005, 0.019018929451704025, 0.043337973090068954, 0.04414375586014602, 0.03290452588830264, 0.0553285591154089, 0.02509636241161535, 0.020973832616882942, 0.01630124786207753, 0.05570297309708211, 0.022075710284914223, 0.04371563911498074, 0.025422258129824075, 0.04321250704026992, 0.029295230952782497, 0.0513519307658557, 0.031271111520548026, 0.034833270981306994, 0.10102222192912333, 0.08266552186180508, 0.4126395934051083, 0.27161009970211214, 0.34360069961797807, 0.8872400104038177, 1.961825290514577, 2.7594168340006187, 6.189954636558411, 10.393419996384653, 13.950021305391866, 23.04524660110474, 27.50255942344666, 36.03141407812796, 39.793602497346946, 62.4650001525879, 67.60188518031951, 82.19656175182712, 80.74519065118606, 77.07042401836765, 88.73574902934413, 81.96580871458977, 91.65138798375284, 93.55081927391791, 86.00647757130285, 85.88266403444352, 78.84668504038166, 69.5307970046997, 69.92873714816186, 69.1720962524414, 79.97275044841152, 84.50581012233611, 82.99719595140027, 80.7137175529234, 76.7088834701046, 74.11578101496544, 67.81054742874639, 62.718204836691584, 52.73723579222157, 28.317361224082212, 12.101552390283155, 1.8036548552974578, 0.08165856823325157, 0.0951178520617466, 0.040313768230618975, 0.03234413257169147, 0.034307041355679115, 0.06043989774620822, 0.01976067493219049, 0.021117468357026097, 0.04967175822164263, 0.02481579228544668, 0.026803336541859374, 0.06433643160327789, 0.04894647597064895, 0.08023493172180268, 0.042172060047666875, 0.019426335009836385, 0.02851705416105688, 0.041962473713342226, 0.0334778048038002, 0.008072098961190112, 0.033506992753715284, 0.013571142241539014, 0.051345361561904994, 0.013162470723111785, 0.10148730624707476, 0.011889153111335492, 0.03577384692166121, 0.02985811980080701, 0.06237283334015839, 0.07265652950492597, 0.018171444685468753, 0.04600414675810645, 0.005748844921453706, 0.01715937742002068, 0.0510331615805626, 0.07566749253460477, 0.030470702857259783, 0.032820420925535505, 0.05718288642744865, 0.01597592575220211, 0.045780947041367336, 0.005970783465947475, 0.06383763941665811, 0.050494257030227495, 0.024545778850874594, 0.008984740462995345, 0.03545920695027998, 0.004283346492992414, 0.027959367050038233, 0.01942761054623031, 0.017332197279639302, 0.01094585564363027, 0.019522320081089294, 0.0756903525982653, 0.04216172169112871, 0.052677404601126916, 0.03391946215302714, 0.0009575911122562004, 0.06007304505234765, 0.05512651491669878, 0.03925138047986454, 0.03649128060187063, 0.006189232479946147, 0.03644339244572386, 0.08295178593647096, 0.03312588699402348, 0.0665202035358356, 0.04548118449747563, 0.02690288009152057, 0.051605417768681244, 0.09688586041691805, 0.029537123214874058, 0.17228189735643326, 0.15578926540911198, 0.16832854658845933, 0.12813077173045567, 0.2085470134812978, 0.10823280235091526, 0.1594116355502798, 0.20341719680976486, 0.13908741484966972, 0.1523883559650952, 0.15997307074646797, 0.063519942754459, 0.1491463025130572, 0.16588909281117303, 0.14517381486873474, 0.1440330180189302, 0.10734817764211087, 0.16816786730722075, 0.1723823774485819, 0.16561074242476495, 0.12554178525122905, 0.12373602408314906, 0.15131616994978922, 0.16803688159392727, 0.1079810658589967, 0.08384188817393395, 0.2117141282125827, 0.1290908407780432, 0.08402266194142642, 0.13716258829639805, 0.11864432794672829, 0.09334832685248506, 0.15685723794083442, 0.08132386441913345, 0.17055026285590666, 0.10719578743221299, 0.12322810012847187, 0.12588608048615918, 0.10410823093186464, 0.32649748027324677, 0.15659448510456472, 0.16858170800391706, 0.08590791239252976, 0.10552857326523912, 0.14687500503515044, 0.22474767399891732, 0.11598812491302529, 0.10803396423016826, 0.17512713258545246, 0.1295624138607133, 0.1099175139660797, 0.1392416130270689, 0.179057470072181, 0.20314243171484242, 0.11481263960200934, 0.0978381153676779, 0.06928940453836996, 0.17004724952482408, 0.13071307792298256, 0.1546258383220242, 0.16378232037588475, 0.11482733316839704, 0.2625656350245399, 0.1496444741684583, 0.5819090491821689, 0.7206956825910077, 1.2103695230137919, 2.081717070071928, 3.776330524875272, 5.855831946096113, 11.330278112042336, 15.260410654929379, 21.949593290205925, 31.437571394828062, 36.13694544761412, 45.51573653374949, 51.345116015403505, 75.992870484629, 80.7651476706228, 98.62722919833277, 96.14800883877663, 93.60565400892689, 101.55676903263216, 97.08567496268981, 107.81761707798128, 106.8481013082689, 98.8380487503544, 100.58666490739392, 91.17929150981288, 85.66099520652526, 83.37397883015295, 82.50285179384294, 94.40031051635744, 98.79058807126938, 97.12518107506537, 95.73511662021761, 92.65797015159362, 90.42345077760758, 81.13272866895123, 75.86617008332284, 63.92765591221472, 35.11873345221243, 14.664782074189956, 1.8879056505618559, 0.1968071910162126, 0.2428188301142185, 0.1589888316248694, 0.18396152063242852, 0.1203341723509854, 0.16873707063496116, 0.1204352576525942, 0.10087481129073328, 0.14741787026005407, 0.22281406807803342, 0.16303543061498674, 0.1532748116240386, 0.13368194442122214, 0.21790273968250523, 0.15611715104070403, 0.14099059175820122, 0.1471636056779854, 0.14035201150803797, 0.10269246214339811, 0.12692474249389865, 0.11403151337177524, 0.15552269745497935, 0.25536054745316505, 0.11535803291706309, 0.1764503043265112, 0.09817400661807868, 0.16754169768143087, 0.13244284316897392, 0.11947689698107782, 0.12673219395500998, 0.14659921338240947, 0.15463207427772785, 0.09866898368683555, 0.15520722244776067, 0.19539043397432376, 0.17488247474595425, 0.12887572328890526, 0.09958271207588335, 0.17082965512189174, 0.1417969912290573, 0.17430803137681178, 0.1399572157571393, 0.17420525302089032, 0.11796525228888759, 0.0900817049607154, 0.13061618312231957, 0.23904897272586825, 0.12031127398292865, 0.12305887896687755, 0.11857544132057699, 0.1494901840605082, 0.14678914190059708, 0.17050619747850204, 0.18012820052043085, 0.15011666012146782, 0.18270245512887356, 0.10475305479861076, 0.12080851101106214, 0.08630241703001723, 0.09949190001333914, 0.12021854670057375, 0.11563893437625901, 0.21157732023106468, 0.14611912140202138, 0.1970235648895464, 0.1567095055455162, 0.1664525658012398, 0.14218627114690122, 0.0815040482989242, 0.17086584511543476, 0.1530440812630038, 0.07595868255462378], [0.0471662791566022, 0.12142731087102045, 0.10089132814638077, 0.06353185159124194, 0.06482585453458371, 0.009965787870779393, 0.010375695663594432, 0.011507717933836243, 0.04561308951627824, 0.02048086844414713, 0.052683311139023116, 0.025473662629543294, 0.006071977935085494, 0.052774479432452115, 0.024556438964340958, 0.09397514765301059, 0.042002283472327456, 0.0281218868575149, 0.030666627928674705, 0.055513419961977395, 0.03133084339600417, 0.07002976723015308, 0.030963502321091872, 0.025380297578991424, 0.05762762728057081, 0.07348129976420634, 0.03583794166784614, 0.05933409962322443, 0.04572773840458644, 0.022606373644403877, 0.022968066736094417, 0.04067455350811924, 0.04326540158100186, 0.055076968180195945, 0.05673029700354223, 0.08003463803399956, 0.039406214510240865, 0.03839349990049678, 0.042468394348097425, 0.02063715229592016, 0.06501189898699522, 0.04234652508110289, 0.04088202543977288, 0.04562141689201517, 0.0471165064241617, 0.015484217006052214, 0.0383073111785756, 0.058767861055751006, 0.025928519673705585, 0.0674684901511477, 0.06861788250746266, 0.06805608724995006, 0.044205966030037215, 0.06132885085178479, 0.03067267427761709, 0.008033108916283857, 0.05401621602715985, 0.022993249961385326, 0.059844463567940466, 0.05016454044849642, 0.07472632287610924, 0.29711476016429167, 2.7219508444109275, 5.085417647515574, 8.334323725392743, 10.844802433444608, 16.76721857440087, 21.207349454202962, 25.560699855127645, 31.949032775817383, 45.94076064325149, 51.08470985966345, 56.33319808590797, 74.86652266594672, 74.31164849189021, 80.65493691352107, 82.49690548066171, 78.94397551013579, 81.96725999155353, 84.73714367035898, 87.50643114889823, 81.7793784602996, 69.97019660088324, 76.57349894123693, 62.74300598329114, 70.8892628454393, 77.02975688442108, 72.20794800789126, 70.20399339737432, 74.94096925181728, 72.16984610403739, 73.3701462899485, 84.65055342643493, 78.85436504117905, 77.63251535354122, 71.80861150064777, 76.00851289687618, 72.63718082058814, 75.72967944606658, 83.1993470653411, 73.62826178150793, 73.95832138676798, 61.65718801559941, 28.373927685522265, 12.669115431847112, 3.116055890437096, 1.4423431528191415, 0.2089726978973035, 0.03809065385270984, 0.00806367103641312, 0.10307588914950049, 0.028923904305444132, 0.026889672735705975, 0.06394890985722024, 0.024737955837119973, 0.06907625589519739, 0.09231051520234154, 0.06629785417669243, 0.0256099151973162, 0.02281913349795486, 0.02319742963018437, 0.04850440876438253, 0.03774521331633291, 0.015854455808538104, 0.06038236454309476, 0.099453718191193, 0.04309380554684228, 0.06640271629176794, 0.060283585166138035, 0.030421981580495357, 0.026982300426630725, 0.054475876442607374, 0.03278899599888152, 0.07739546513485332, 0.027907368832177697, 0.024881878860234737, 0.026686552183462248, 0.015621904073463333, 0.028888376977955623, 0.0929948079189466, 0.02681249320777434, 0.03129735577761406, 0.02307442272262227, 0.0544800860957513, 0.015063537059411889, 0.07389048264632303, 0.04662272828300634, 0.07140262743398067, 0.067854123490472, 0.0408193173127309, 0.04136955613390573, 0.020705835908771526, 0.058401196053431886, 0.02071297967866544, 0.04888618485100808, 0.055478191408779354, 0.07510611096457129, 0.030201407630116712, 0.010208144573675049, 0.0366357954279069, 0.012217217815979835, 0.05112122721789826, 0.07331354949142664, 0.03985102814171584, 0.024673119900868307, 0.07596132555796255, 0.037875176302247474, 0.05238578940230993, 0.018224988485716524, 0.016929346114216794, 0.08752068069072501, 0.03694503064898234, 0.02210441176899739, 0.0360949220316064, 0.043112260604938196, 0.017472381793683576, 0.04466518594492828, 0.031357175753181504, 0.05083233546165209, 0.08490122689474976, 0.024605627554739197, 0.05731342780974604, 0.028577358687236428, 0.04593982984642348, 0.0018051369261229413, 0.014068018250738182, 0.058982216287404306, 0.010962389736256052, 0.007766088970275897, 0.031143619168189265, 0.06543494806054138, 0.04262165406778936, 0.029255145402144522, 0.060611034127613234, 0.053198233306888616, 0.03797365690491373, 0.034932456384863586, 0.06849586002288327, 0.05183735088775716, 0.03041336692178682, 0.024160214459463477, 0.018321846897203117, 0.033978071709674214, 0.0184210667747163, 0.01839372318147892, 0.04531975061963162, 0.03469854675894303, 0.0819049804140964, 0.021834264269038554, 0.0445566427773766, 0.04056548940077905, 0.016993977121948715, 0.01645218250491927, 0.018409655895084143, 0.04308645110276919, 0.029752537563082673, 0.07390647090130276, 0.06594261920620358, 0.07916925745385309, 0.06678271888484878, 0.049109740798631986, 0.06528728461313633, 0.012669390679577426, 0.023898840581457463, 0.02728833531540248, 0.004552878249782108, 0.08334549384251719, 0.056560145045119914, 0.0760353219905688, 0.03465348546723685, 0.03814525293907331, 0.02708929801179517, 0.12868524318741215, 0.08796944733588927, 0.03735441271395933, 0.039812095553403905, 0.060118891584176215, 0.5300881653543442, 2.881383424805057, 5.8702564624048055, 9.43995064304721, 12.578740100706778, 18.322622699122277, 23.9792884549787, 28.932271195996194, 37.48725668076546, 52.71802010074739, 58.033522021385934, 65.3017916217927, 86.39327033873528, 85.38028686277329, 94.22609452278384, 97.76963433911725, 91.61753792916575, 93.17980227931854, 96.91803286152502, 97.13689327239992, 94.32488333794379, 80.77270215557468, 87.55665317658456, 73.05353256963915, 81.84570573991346, 88.26198947045111, 84.0435117290866, 82.98038467284172, 87.0394572904033, 86.70560083081646, 86.4026055797454, 95.13019300276234, 90.91640641612392, 88.14442819164645, 83.59094081386444, 85.81227317933114, 83.08187992342057, 87.17554000116165, 96.18089399030133, 88.425536617156, 88.11819537993401, 75.76684782581945, 38.85440664906656, 18.60035396391346, 3.7652324236208394, 1.5100588288999375, 0.21678976714611056, 0.12540286286704003, 0.013757846487175315, 0.029148988598476977, 0.03635633421400863, 0.018301158692807924, 0.07729196665628303, 0.09615659067827849, 0.04117781964821681, 0.02166863989024874, 0.049191819458839395, 0.045824728966239965, 0.009560683449249594, 0.03885139448327884, 0.03384730433143916, 0.052880383427104646, 0.005923211799874421, 0.045165460511681535, 0.034352140951781504, 0.03155602728046718, 0.008337243907003394, 0.036639924641818776, 0.05495002741114267, 0.05170870174263274, 0.03728588614913245, 0.023754653258008823, 0.07353357760415924, 0.006658864008533138, 0.01801709329048472, 0.06726720820992224, 0.04381098258759707, 0.05448659018222844, 0.06743471333456617, 0.04564430759919267, 0.042841329780076785, 0.05870478520650537, 0.05900700689263402, 0.04211769461812031, 0.08204843037791791, 0.08239836401997075, 0.07785776855363961, 0.08580763914412068, 0.07494908592273151, 0.023729554302389586, 0.03312821590131329, 0.019533625623631864, 0.05258858053674621, 0.023871993030151053, 0.03476525003451013, 0.0716356560587883, 0.05215348856103036, 0.03547248325400776, 0.009574715307192698, 0.011840326497481476, 0.09146356669765326, 0.09420488976062306, 0.03652763530431736, 0.0348779262464133, 0.07969172175733313, 0.029704381276162404, 0.025611267342502554, 0.03348494091281488, 0.03096319588592216, 0.07318011995765471, 0.03537604427565971, 0.06289176597830749, 0.0725953956885684, 0.08897738155698584, 0.04506733613990007, 0.12352855981237466, 0.20859438835853533, 0.24596788049224885, 0.1656627751165821, 0.11376197299649639, 0.13311091780422196, 0.11757964959308026, 0.16430197313668268, 0.08122034295792542, 0.13609429400774742, 0.19242276257324606, 0.11018154616918295, 0.13841370180729898, 0.22571869044294282, 0.14024495838149903, 0.1538150568282412, 0.15070665507547318, 0.1531782539020623, 0.15521151254013663, 0.1422916695235237, 0.1353713674771209, 0.15606206931894825, 0.17953984499458345, 0.08388283557348675, 0.14622154735749768, 0.15637084871770876, 0.1766021429531036, 0.12515193076744197, 0.15588833589947995, 0.13569982001377692, 0.1829805144018704, 0.1639284286648035, 0.06579967486041208, 0.1524634325816747, 0.17667568739383452, 0.20287459205475547, 0.1898560922352537, 0.13715172516963176, 0.10586332304463272, 0.07714558257571152, 0.23530870165315368, 0.15042007690475834, 0.14967278877813972, 0.09856563076497087, 0.16507530825272684, 0.11337880646028828, 0.1300824343437149, 0.13010969175206077, 0.11547981025350672, 0.1786132922936832, 0.26759613605756916, 0.21714533919528609, 0.19699869767552425, 0.16848459869863527, 0.10241966589444107, 0.09073008347543017, 0.24920282464834953, 0.18713315528246666, 0.22118159599842566, 0.1251433122782938, 0.17553196408815924, 0.8753706118272198, 4.036209857271564, 9.429816219114489, 14.700435438463765, 20.038930293052427, 26.432976145898145, 34.64738222860521, 41.26917854432137, 50.85342730245283, 68.17328822228217, 72.08952380764869, 78.01556617982926, 98.91418195539906, 99.73685203060028, 109.31776677408527, 112.12080232558712, 106.07700255609329, 107.93126383135396, 110.09902446500718, 109.82373683683335, 108.11437576047837, 97.62849961557697, 102.03196417900824, 83.68336754460489, 91.89247254402407, 100.05707433146816, 94.53243163324173, 95.104030793713, 99.47975635528566, 98.50122697891729, 99.40771025996055, 107.69651782128119, 101.94167906238188, 99.70834424418788, 94.81691329709946, 97.67261843527518, 96.50024552499094, 102.04871269964404, 108.91657890812044, 103.02135852075394, 101.36659683719759, 86.59119313763034, 48.016777038574226, 22.292171139870923, 5.032305323308514, 1.8851150067583209, 0.42770195451955645, 0.22943711268805692, 0.17870935971938795, 0.21099636511456585, 0.18820488164501806, 0.10900332592427732, 0.3357182371039545, 0.19081161838145028, 0.16082391863869083, 0.12449093478461429, 0.22809537097571358, 0.11292111489080614, 0.13713939115405083, 0.12251802089233553, 0.16388813243998637, 0.20704465377474987, 0.09984617737392265, 0.11621393698958621, 0.2220070097715624, 0.11573872498927579, 0.12622744926521856, 0.1285040787150783, 0.09681842935782287, 0.2199150687984882, 0.19926090935064902, 0.10106366728582691, 0.15345832032542076, 0.21117990445946494, 0.13575735321689036, 0.1318895285047831, 0.11495501704273686, 0.1679210950650515, 0.1463058476726855, 0.10968813958067088, 0.10024059774173845, 0.11208869907404147, 0.1369198763202275, 0.12174808720667517, 0.14972330461586678, 0.134201152851024, 0.19517730831378893, 0.1716518513257465, 0.20622182937879718, 0.18380703134161813, 0.2940174360429087, 0.19909587869000053, 0.11181718985279722, 0.1890138398495413, 0.1986158020313709, 0.18964696555368363, 0.22647169358547659, 0.10878722784259628, 0.21764988470221722, 0.1753634553883345, 0.23521810409522828, 0.22802181121322418, 0.09991416767720254, 0.10340017416784841, 0.18236608124308049, 0.0984078549569653, 0.21830539549550704, 0.12524219890755992, 0.16601183541840123, 0.15059229347013658, 0.11209146465144812, 0.1405917817065793, 0.15189951526061182, 0.23352983017121595, 0.17180129975801514], [0.03629536510655477, 0.03792719367230612, 0.01881761112130217, 0.028533818080059947, 0.06197133048948261, 0.02299482427206972, 0.03752234684784086, 0.04797921335745243, 0.05433020099336582, 0.024970542046151338, 0.018119772054976033, 0.08505025397866003, 0.008741497013327337, 0.06282682853540586, 0.06770089058385742, 0.039592473467271176, 0.01918509392248046, 0.0224069130772184, 0.06468699343742863, 0.07029298738005661, 0.029369212063630263, 0.01327545528540448, 0.06227582362630676, 0.025461422459733103, 0.03706029240762995, 0.07252133030804896, 0.06974792348281031, 0.04875052983181612, 0.042591975821602734, 0.06361025302941281, 0.06909593669397217, 0.05671928832007032, 0.02736888563020095, 0.05995831572480741, 0.047162682373797706, 0.08339238608436239, 0.037841395655226324, 0.07428540863216886, 0.03367285461976163, 0.024698814489848675, 0.03998640353881544, 0.017749368543586424, 0.038867980286839514, 0.06864156994608141, 0.059746117030660954, 0.03850261763399167, 0.0608109409410146, 0.056433928229155085, 0.04879551068429024, 0.0299007315263753, 0.015268939596060065, 0.023108871781357357, 0.025914804784641154, 0.04239430598494026, 0.05268558258971861, 0.036359080639217174, 0.05275691686678798, 0.017266842318818938, 0.12297832482163945, 0.5615117436935825, 5.951372058160844, 12.149335684314853, 27.58767289500083, 40.13832392231111, 47.11621653649115, 60.14939754239975, 60.780228414843165, 73.04092607190533, 65.86338873832457, 69.3763497567946, 77.22272965215868, 82.23113352252592, 82.36749079919632, 77.92393176786362, 85.08983535151329, 78.52948296454646, 70.21185382719963, 60.9645680458315, 64.05909453668903, 70.03639051991125, 60.081226748804895, 53.270878176535334, 32.621997748651815, 34.06829134110482, 42.53379383394795, 44.228461711637436, 44.377186221461145, 51.939896383593165, 27.88515917716488, 38.42296554196266, 42.23685080005277, 54.39818697590982, 51.46273220739057, 56.83015846437024, 58.35066918403872, 49.864527179348855, 58.30768392932031, 51.79774968854843, 51.1002306784353, 58.034161367724025, 68.8733293164161, 68.54573295962426, 71.0294875790996, 76.99802490972704, 67.52239442640736, 35.84847865566131, 16.816054044231294, 3.551882942838054, 1.1206157649717023, 0.025080617389551578, 0.12041196857969608, 0.14762186415253148, 0.14592102638656093, 0.02854226994508457, 0.008894439764140595, 0.013088271277205599, 0.06667465452224978, 0.08864729725305112, 0.14318203223088097, 0.06971705780034104, 0.08281896161215921, 0.06458735604199671, 0.07801129257366543, 0.041964396594032165, 0.020971706722893065, 0.07409128961303542, 0.00884226821888719, 0.027526416290070743, 0.13011934445990672, 0.020491425135743715, 0.029440040722669616, 0.047891852521007104, 0.04935862361303261, 0.03724392368307999, 0.027977530994722923, 0.03145691274004358, 0.09206434050875326, 0.05859967411285447, 0.038276614035449685, 0.026171095669269565, 0.02820293895990378, 0.009292774841249471, 0.04134251323017863, 0.046524274493417436, 0.018845856783070394, 0.03841160638858715, 0.0306754858202992, 0.02453084779723037, 0.07848226810775458, 0.0182123844241423, 0.044626621078820004, 0.048409540266279256, 0.01972001098516968, 0.016300146610686378, 0.07785691053516443, 0.042312962769140164, 0.06589124535000132, 0.05224306722201648, 0.02759479921341183, 0.03281369467356032, 0.042116913208437544, 0.07828974255150364, 0.03821248098486855, 0.02234759297402155, 0.042515179337633234, 0.03165687509481946, 0.06598264730024724, 0.028580357921459985, 0.03387517461012449, 0.0413874481173773, 0.11036498592265191, 0.019627885081835335, 0.0036751555143705304, 0.006863850463677439, 0.044329340659802964, 0.02173228647499796, 0.040822465934099696, 0.047728388510163755, 0.1212764451760919, 0.02219284512853671, 0.028418768910811316, 0.033032182949565114, 0.046955202781264825, 0.07666246454802252, 0.026038370936387972, 0.08467029735085466, 0.03733998344790551, 0.05037199322795195, 0.04552276775000557, 0.057282964323437026, 0.032254362388724284, 0.035591433726010785, 0.04294315435653252, 0.03260093290478953, 0.01511673707770364, 0.023065869350947683, 0.04387412355431626, 0.08149650999374929, 0.0639295929502095, 0.024700815894550854, 0.0012568263721937736, 0.059131990307040756, 0.04229387568850671, 0.04133349637530985, 0.07301983904213676, 0.05908150894327029, 0.046940321523335674, 0.004245881920665382, 0.038373822932161634, 0.09981227798327323, 0.04408618052219672, 0.0502661926551692, 0.08124706410472432, 0.023391627173330036, 0.07724455347464931, 0.03762049803269967, 0.019570824938015114, 0.025731723177276795, 0.04580231323357552, 0.030394592021982518, 0.06898910573293125, 0.0375616739714338, 0.06537052772698865, 0.020371248923061837, 0.03485445331241335, 0.025699767734735243, 0.028194063831300988, 0.046788256900805625, 0.03693834653184299, 0.0347505334854847, 0.1248879904948896, 0.056055001989607854, 0.02646129552064644, 0.07503754609534818, 0.12739248513694734, 1.0096748341475765, 7.7547293036214775, 15.233997414189002, 35.016893033058416, 47.1947737663023, 53.32677587386101, 65.3113425931623, 70.15395179871591, 81.59805513197377, 77.21226476853894, 79.25468214096563, 85.82468355855634, 94.17345631507136, 94.02528485944195, 88.77058752121465, 98.75138790376725, 90.93660662251135, 83.35326871564313, 75.23507641207787, 77.20511821008499, 79.9644507131269, 77.47979394851193, 65.24116746840939, 46.702633980781805, 44.63177942460583, 51.24096924258817, 52.89956308180287, 56.38905655953192, 62.40319144341254, 39.743811930379565, 53.85025931942848, 53.99476335894678, 66.59269071394398, 63.86086579292052, 69.39588316025274, 71.6114261073451, 57.558825016021736, 67.36209500220515, 60.420990297871256, 62.883807305366766, 66.03062291299143, 80.2655553817749, 77.34332684547671, 82.9185288952243, 88.33474943714758, 80.03123298768075, 49.164125227159076, 24.889666649603075, 5.384470916563465, 1.5057068366196849, 0.17300379732924123, 0.3132083675553722, 0.05398657991580906, 0.09851277835907475, 0.025694744113171776, 0.03769617602829972, 0.03421187025284575, 0.04193339684617616, 0.06329617996309554, 0.03484789943022113, 0.05024019163101912, 0.013916757062918717, 0.07654604216616961, 0.03639913171589856, 0.0448066670627844, 0.02294333550267883, 0.04170141776182479, 0.023918732054411404, 0.08228666073973141, 0.129634594664939, 0.034622700223999645, 0.03338730300686533, 0.0092723413610891, 0.026316598748728156, 0.045275447754970485, 0.08195324395332607, 0.054651038616054484, 0.09265812759798381, 0.021880861567032915, 0.06504631931743314, 0.026785795043613163, 0.03975755392363475, 0.03630472287054985, 0.03307397687627423, 0.03701310905237352, 0.08366961032152177, 0.08441266964279837, 0.018394085158023144, 0.023041955916391268, 0.06565779537683533, 0.029032286594531713, 0.042189182112774545, 0.03480514023272741, 0.06620124282856142, 0.047410879539506096, 0.08071500071955305, 0.029553837338162046, 0.03745258305101626, 0.05174956870295348, 0.04154391391503234, 0.03023524190329256, 0.07445744133644527, 0.057387244211690086, 0.08422944439394821, 0.04620230689104046, 0.03347268733646601, 0.02807446409978213, 0.05789505325317864, 0.018461554521514524, 0.08207881342499487, 0.03202528677760594, 0.04415790167366786, 0.06101219606916271, 0.027146553508036082, 0.02746088129858817, 0.04683011977542793, 0.010777835324857264, 0.1638191998485596, 0.12947224531202547, 0.19641458627677735, 0.08712984561439484, 0.20161252348653733, 0.22168211188287507, 0.195196904842892, 0.19599553618219592, 0.14682448919742339, 0.1406293353366275, 0.11674203203930972, 0.1319887828562529, 0.11252746061091462, 0.19892759981655306, 0.1711210136812541, 0.09845538305178766, 0.07558392766382425, 0.060627528000622995, 0.18433007021104136, 0.10499291692770298, 0.11327752963669839, 0.1286301461438979, 0.13170222000729653, 0.19620260974812895, 0.1377274708882455, 0.17200466545839466, 0.19251132233729287, 0.14023748136335804, 0.23995983594607925, 0.15983511363306355, 0.2458259243998797, 0.2012467165026934, 0.10726219193348963, 0.29775965297895096, 0.15560926539042305, 0.1751392520964146, 0.1193745935996694, 0.15972709523574, 0.17262942548240387, 0.12651569750760833, 0.1041140761827269, 0.07966912216356686, 0.1336717860953462, 0.10614673727222028, 0.1299877765197908, 0.19797106243429646, 0.1582834485077089, 0.15610190589101086, 0.14898976010660972, 0.10462219932026441, 0.1359187372990193, 0.10521250837031873, 0.10053119787405576, 0.17980815962918345, 0.21251390868377304, 0.12494419836589407, 0.12853387953533282, 0.20808133927564468, 0.32958637742746266, 2.0089009644523745, 12.26232740186876, 24.022271748512026, 49.779341143946496, 64.48657404991889, 67.7590702426049, 81.99168066824637, 85.3327791152462, 96.03568000178184, 91.69263562848492, 92.7986498801939, 98.87338146086663, 105.71089636894965, 106.18725253689675, 102.03256822401478, 109.56288353089364, 107.64202825484738, 97.08184672940163, 85.1720952987671, 89.47931274291008, 94.19930473450692, 85.00817944926601, 77.03483243142405, 53.72514355567194, 55.616792863415135, 64.48854700211557, 63.79094169985864, 67.06248867896296, 73.95597580940493, 47.52532759020406, 58.88015385596984, 63.66727329069569, 75.21257769676947, 73.55683542067005, 79.60953897045505, 81.35463283907983, 69.99311108742991, 80.43562150770619, 72.40902439240487, 74.78402737648257, 79.79240771262877, 88.86130409855997, 89.69949107016288, 96.16776973970475, 100.85562967484998, 90.47893662606516, 58.06094723363077, 29.079350271532615, 7.434473662607132, 2.128490108636118, 0.4807615412339088, 0.6884639121351704, 0.15671898971401876, 0.24696636884923906, 0.14685062811739985, 0.07237810250972548, 0.10564807532054764, 0.12831011291352973, 0.29049692495215323, 0.15771369359666304, 0.17092314849217094, 0.1848924093909802, 0.2238245993371933, 0.16320694237947464, 0.10350411697741478, 0.09452539796550428, 0.09793168534674952, 0.09863106233458366, 0.14771276814562662, 0.30426545549304257, 0.13493501911720923, 0.10655687776424232, 0.19285885046326345, 0.14730994379328144, 0.11132353045527013, 0.2133392918133928, 0.12604049316817714, 0.21873065090227514, 0.20322993427755373, 0.1926581201053435, 0.10325971194693159, 0.1328638697704, 0.16755246887764624, 0.1937612560727904, 0.12807981922261177, 0.09695432569471099, 0.30599040970686947, 0.07233382262770208, 0.19178779825808542, 0.1353141100656602, 0.16948054364371687, 0.155368177520652, 0.1599157673697318, 0.16058537418082838, 0.17050264283053337, 0.1615634079902403, 0.13616710300407103, 0.13352983000297702, 0.20240778403897441, 0.0986436338374211, 0.11222461839356732, 0.13481817538699797, 0.20606216133361865, 0.21770216254217012, 0.08986062730752653, 0.13356655625806702, 0.12548904775852157, 0.16971933324971508, 0.08630604828677832, 0.1079203610518767, 0.20947381133033385, 0.2493567317123375, 0.11544555846241214, 0.10717296567294868, 0.12987784290265653, 0.1338211579188224, 0.20325463295223253], [0.051349257118999965, 0.03440629570714889, 0.020311756450082027, 0.02884630342915414, 0.03702022600919008, 0.006479872831879485, 0.04760794033626876, 0.03263812647351334, 0.06855009904792232, 0.06558944501223103, 0.04979437442436334, 0.04589196084247482, 0.07482865690103463, 0.018629615059903553, 0.036109937354922295, 0.06613569634575998, 0.021023662805917765, 0.07048252519340285, 0.04039319239616875, 0.030609184740892345, 0.061697143790943015, 0.12127593189718262, 0.05389341213289769, 0.024991044474224892, 0.10686387217813924, 0.041630037519479954, 0.0227146927312377, 0.07472723452073914, 0.04541727744283215, 0.011987710322794175, 0.04042644827296177, 0.049996568010218685, 0.01962121628645447, 0.04795817275261206, 0.03139830892905593, 0.018332282929951628, 0.03484546710106154, 0.023534335947084813, 0.02822916597999152, 0.03626688578796964, 0.035758919698456605, 0.04278180857879981, 0.007235939847305418, 0.03404778954122336, 0.006689086655950955, 0.02527717256828422, 0.04300972356671288, 0.04752793011345691, 0.03817393527095837, 0.0548324827104807, 0.012453812580074997, 0.02576145696483793, 0.057263061359164216, 0.11819363075999484, 0.08922207770088027, 0.026828165451485305, 0.038103336438296304, 3.307030946016312, 9.530552491064995, 26.13125566513308, 45.34065369636782, 56.5121405355392, 70.98550211998725, 68.95806820161881, 76.05200413734683, 69.22107096641295, 65.29545307159424, 62.65159122405514, 64.17911514159172, 70.71097543162685, 75.25059330847957, 61.83963706416469, 46.85950133108324, 62.196317795784246, 46.215405002717056, 57.469528336678785, 38.39272799030427, 30.194452654930856, 50.8458375161694, 50.621415184390166, 24.127901177252493, 25.6993576019041, 26.7251201598875, 24.734895806158743, 19.735815409691103, 26.592698981685025, 22.293961701854585, 29.608362297857965, 26.55592676131956, 14.787069809052253, 25.49737907225086, 23.898817108523463, 19.691447519486953, 32.288074608772035, 26.56395193069212, 28.50467597284625, 26.362822594181186, 28.840956457199592, 29.242085487611835, 38.495058705729825, 45.06701346366636, 62.175352727213216, 55.98774710009175, 60.74620185359832, 63.42025026198357, 68.51336556096231, 57.32465167199412, 38.6628302451103, 20.391518031397176, 15.985674550456388, 5.26341921860172, 1.4132340180297054, 0.03041775852081276, 0.2588552260591138, 0.0407107703147396, 0.08809582886075781, 0.03557132391799842, 0.045289988103773327, 0.014581019453133547, 0.04094761022697053, 0.04324224657349048, 0.012833196557156984, 0.028482084162533287, 0.03888152855178041, 0.01261514112082941, 0.036491460632532835, 0.05148682352756301, 0.023480958770960573, 0.023474058233982614, 0.027537179825406884, 0.0412074557595676, 0.023984098506550637, 0.01293290002767237, 0.0402166091296221, 0.03733292394768327, 0.04639757504206031, 0.032812170158591, 0.018043190075625336, 0.05196027735608721, 0.08796699585453158, 0.08809910771707374, 0.05419887054050642, 0.0536831746238374, 0.04021121970107479, 0.03548788545172542, 0.034896339169673385, 0.05255634355689249, 0.02244471568584202, 0.05410705490278141, 0.028631796895135796, 0.056339243592153636, 0.054080341416861744, 0.050261707210372535, 0.06499642401092476, 0.0417156478450183, 0.05434364583643694, 0.0851905093558373, 0.05687112311622309, 0.021420618924762935, 0.05295263700968316, 0.008096273823250687, 0.028240061665494597, 0.009739652122070473, 0.021399884755092285, 0.03894047901755379, 0.037778890541484283, 0.016877481961743008, 0.03042688645843056, 0.0727966852906731, 0.011151637393800963, 0.058195106910481575, 0.04444880824115488, 0.0772722552139913, 0.04949951101274741, 0.09448622022905658, 0.034241916221236034, 0.057174168346870335, 0.08008473252336826, 0.03852748867845343, 0.0462968114973797, 0.021257940154041977, 0.05324713269909544, 0.016114875907078385, 0.02746726855665686, 0.12425446642502663, 0.08584458756470874, 0.06669795125602715, 0.014534574415114139, 0.06929638359936015, 0.018518172249558474, 0.04684344587487079, 0.010318024564654598, 0.052861204415920286, 0.047978776687335585, 0.001600091218865747, 0.038253229201561025, 0.002752256574064133, 0.06940751231365627, 0.05522361273066171, 0.05530529685558812, 0.03288543880766919, 0.0899709592903814, 0.03268291963444602, 0.021572530329708132, 0.04723218953116767, 0.022264072153296684, 0.02245484528342082, 0.0356333693789859, 0.0764731259175366, 0.013707166898154445, 0.02138083023319562, 0.050593679921040614, 0.047739853015950615, 0.022921982717009324, 0.007376909601472079, 0.04607712812421303, 0.06368436054476807, 0.03407927192447167, 0.031554876233360944, 0.06927825029819243, 0.026735430508251154, 0.040977468503819364, 0.040035172696075136, 0.020278423964496584, 0.01210237166003114, 0.01937355538229308, 0.01707439911701987, 0.04332853105640219, 0.06525419727568665, 0.07661007179488098, 0.14184477979377394, 0.07613472955962343, 0.22160789328477076, 4.615715780565816, 12.44618065895573, 31.301184700381373, 51.61146456195463, 67.34883739102271, 80.03756369313886, 78.02051621098673, 85.77550488133585, 80.1000705842049, 74.54055801514657, 74.07293304320305, 73.43753260950889, 81.68593191331433, 86.01295732682752, 72.56312647173482, 56.411763160459465, 73.65693430746757, 55.29751977612896, 72.08104364333614, 57.702972119854344, 43.38059825281943, 60.02610568077334, 57.859211890928215, 34.44937705993652, 38.553553012109575, 35.10727620893909, 39.718461651955884, 28.81470795600645, 36.54970430558728, 31.72277673598259, 43.860861101458156, 32.60233882934817, 22.63364091996224, 36.435586867793916, 40.03798184856292, 26.767256221463605, 46.55590987974598, 38.10810512112033, 36.98244371721822, 36.48259255193895, 42.07021674802227, 43.32574390595959, 50.72471080287811, 58.58056322220833, 69.47895896050238, 65.31026001899474, 72.05582280312815, 73.36023838289323, 80.00912650938957, 70.90667816900438, 48.537130432744185, 26.855807650473814, 20.187643035765618, 6.815748205108028, 2.0055285841226578, 0.27526250048991174, 0.2717491906256445, 0.07105396549788214, 0.018243313308865316, 0.017588260253110242, 0.023335143510672837, 0.07484874372640926, 0.009546567321634822, 0.06488249907570501, 0.01847790092259886, 0.043870055627438335, 0.05167324336305742, 0.008141121567947971, 0.056467536506393266, 0.039228945595001986, 0.06667781846537706, 0.08450695208363956, 0.02231396362936545, 0.03929594764485955, 0.040158068520888206, 0.0435778045756442, 0.03221709604164766, 0.03738195357483722, 0.00587864559248931, 0.013354347019846882, 0.0890364699185856, 0.07969529938793952, 0.05266316302661454, 0.051680122832617456, 0.02579519356180343, 0.013291737526625156, 0.01404334638913673, 0.07626740066635032, 0.034281971128357035, 0.018964221197811347, 0.04423135418384787, 0.02372361137531698, 0.018386439600538824, 0.06052058212639344, 0.10680636195766349, 0.059326971175089005, 0.027028865165888306, 0.06946208075650277, 0.01704406203521836, 0.04165823721597272, 0.050185875997187636, 0.05174503346244174, 0.013041005567497304, 0.01748831259206899, 0.01729141267377042, 0.06828713936791306, 0.00996865782766573, 0.04642962049993296, 0.05187879241402111, 0.038239527719035264, 0.0429586484848011, 0.0375423455731042, 0.05453564662245974, 0.023536145829805927, 0.04166292184362969, 0.07338749229787819, 0.05219468493915854, 0.1042186318626327, 0.024741843733335697, 0.12203491818640502, 0.15091302384051586, 0.10360053680356472, 0.1561828660628488, 0.15471182403064546, 0.23063844580563808, 0.15518177300691605, 0.13688930941204872, 0.15780246786532864, 0.3097259769997289, 0.15785342803405178, 0.14287222627430193, 0.11228573688816641, 0.1257745687279009, 0.09593008146170648, 0.10874497809357221, 0.14184827315470866, 0.1752824339294626, 0.07654897628291961, 0.09648239255071649, 0.1634151650772941, 0.2071034893273346, 0.16920534953955682, 0.09017920497083858, 0.19706258940840923, 0.19115465723218458, 0.1225233298816508, 0.12891949755289864, 0.13172961531146882, 0.18527824191316483, 0.10157730625641924, 0.1612921056127356, 0.1386277008080675, 0.14755670071369217, 0.14581461677387839, 0.12666644828934825, 0.12141965765265689, 0.2126263857128159, 0.08548270295103712, 0.13328671966108585, 0.10316722981271245, 0.26596960882025383, 0.12315281666815282, 0.137669968328649, 0.09995133826328863, 0.22393666267875703, 0.155757304220911, 0.06948182284231148, 0.1683369122685925, 0.14077950389154498, 0.12426489288167608, 0.132117485627532, 0.2422100353625513, 0.2711730925065856, 0.26397738185140396, 0.16602714185512837, 0.622429829691687, 6.146526644306799, 18.668885615564164, 44.14020053801998, 68.31541138310587, 83.41485777208882, 95.0047085362096, 93.75622595510175, 97.84890544029975, 91.07519965017997, 89.68715129360076, 85.39305810005435, 84.58625793457031, 94.84319317725398, 97.4090979176183, 82.03811368634625, 67.42048340459024, 84.8906417046824, 67.9264848462997, 81.3558566185736, 59.50397545291532, 46.44406741665256, 67.97662058184224, 70.36790140213506, 38.69579776640862, 42.82570054454189, 42.836389003261445, 42.26462510324294, 34.830764801271506, 43.06393746406802, 36.82191679554601, 45.77901778682586, 41.19111553315194, 27.765705354752082, 41.792587464855565, 41.43305909249091, 35.69523165302892, 47.76558453036893, 42.09017768982918, 44.226324019893525, 42.03785719410066, 47.212910805979085, 47.87665820890858, 58.76827609154486, 64.48657404991889, 83.19384005761917, 76.50497513432657, 84.13155324997442, 83.04664134979248, 93.53367067152455, 83.5840452871015, 58.0841794321614, 32.79555282285137, 25.000087253509033, 9.03994341050425, 2.961424291133881, 0.4870024918308182, 0.403892248268089, 0.22369828676023792, 0.17271565633916086, 0.12383295718820826, 0.18169005461517843, 0.2392609952197921, 0.14645233900556642, 0.17443014579194208, 0.09455492299410606, 0.13943823715371473, 0.11097700590448034, 0.08602709269091006, 0.17025050797289418, 0.16717736158640156, 0.14994680310689634, 0.1371762706267257, 0.19435138892262213, 0.1450169200618421, 0.08089550635627202, 0.07649768669638904, 0.1796563976113835, 0.1432307554228652, 0.2005169717895408, 0.13272562154358433, 0.13965569887190096, 0.15860803996122655, 0.21986827614807317, 0.1687952626736895, 0.20288948480400348, 0.15937783575106054, 0.1122173865235621, 0.20603809085103775, 0.16597670262619374, 0.15040663972256646, 0.16894417484441113, 0.14343013746603844, 0.08824822673153493, 0.16922157528179307, 0.1901363271979555, 0.13911513191077018, 0.18216426304030806, 0.18578065769566646, 0.20195098113148444, 0.11462597461837916, 0.13302981973655764, 0.10023038578970779, 0.13852466198225177, 0.06771046668291092, 0.14337243572358163, 0.15154806476446891, 0.11390653378780811, 0.13731433499243953, 0.13429663804990633, 0.09485372792809241, 0.20346959722378563, 0.2729214583673785, 0.19126575530296375, 0.15593978636447461, 0.14266938151371095, 0.1604076417823953, 0.10504566208128968, 0.27231952776351287, 0.11170044571401612], [0.05356290265016499, 0.05928264149735051, 0.05733318521731323, 0.09423779323697092, 0.030564958485023632, 0.055096970735898906, 0.10600646657328452, 0.04638174000466543, 0.0770108660142268, 0.07297477775043057, 0.012625906571385362, 0.0899169271090819, 0.0525010779740349, 0.023051872924571077, 0.05591144477347693, 0.034341706834252805, 0.019457558838410244, 0.05178744792036953, 0.006868651919742867, 0.06179930161564581, 0.031707341136831435, 0.06914078348105954, 0.05465842370364455, 0.06252432722718486, 0.022077411000106125, 0.019578721389294635, 0.023443493241023634, 0.034548768908866954, 0.02561800700101641, 0.01684580422607401, 0.02165004502110664, 0.04940557714191176, 0.07346380997689501, 0.07594885364655526, 0.048243827787378145, 0.04233510654059149, 0.028713180330551924, 0.028521861362781738, 0.062221982966988325, 0.03053980398802988, 0.015540915173328212, 0.04956475872125837, 0.07130146552357944, 0.02808156190440059, 0.016087474857246684, 0.08679760094251364, 0.038656934555019104, 0.02175850200376684, 0.09828823798846814, 0.03900583397837416, 0.04562341638149754, 0.10420933155523193, 0.04923947012772964, 0.032886001882293535, 0.13771216445151838, 1.3698222055550546, 14.560165597546487, 46.236727006973766, 57.4999463173651, 70.33764423862581, 78.05660201657203, 82.27540139229068, 74.64249257118472, 71.25941691860076, 55.05375231465986, 59.67369248790126, 44.95586526009345, 45.91777163167154, 50.19183720311811, 37.544374235214725, 30.820409982435166, 41.93830351675711, 30.98825408566383, 43.191543932883974, 38.561538957780414, 27.653743259368408, 19.333046828546834, 32.898428747730875, 49.65007943491782, 32.03992978219063, 44.01898361021473, 23.642747133008896, 20.488981085438883, 16.666968676351733, 17.057275887458555, 17.32531301436886, 20.26663564866589, 26.045310651102376, 23.104040968802668, 26.36020048972099, 21.013862855972786, 22.514589140492102, 21.428928067607266, 14.871838112031261, 20.42611529750209, 20.34093514565499, 17.459483569668187, 17.187773143091512, 16.85396179076164, 17.901575872975013, 18.5372136100646, 31.522714284158525, 47.83298261703984, 58.56417163725823, 66.34646784874701, 64.64764225867488, 62.37828439281833, 66.78439263374575, 54.90649084891043, 55.748988505332704, 41.514091337880785, 24.91426775532384, 12.752963939020711, 6.404587222683815, 1.8199385750678279, 0.45372053740486024, 0.3170648235226831, 0.04310125958234553, 0.02509988450084723, 0.0586750992994395, 0.06368284752111762, 0.07633496962127186, 0.05129069352762834, 0.015455301974960154, 0.046116462908685214, 0.05482703199489944, 0.04742073909109158, 0.025517419656558384, 0.0533146518583019, 0.09440132236528782, 0.01526430859455779, 0.03473170687474551, 0.042162660148835955, 0.04947875769087865, 0.05363874918510837, 0.038799668226631424, 0.043050667135826046, 0.06556155941178722, 0.034388216032135877, 0.081806369576483, 0.03309130961556108, 0.03331122664554465, 0.04768805781139001, 0.028867830499826424, 0.0591008028676433, 0.037286181092983296, 0.05496589309205452, 0.033794766021592, 0.035783943960503224, 0.007603844954451967, 0.017556728074146856, 0.06254757033480753, 0.08200084099606161, 0.05259384739122564, 0.017350795979221022, 0.002317204578561829, 0.06695480521527991, 0.10787811130285264, 0.09339821449811421, 0.0212477607607481, 0.0665279716673878, 0.04273675111753326, 0.027019861717558196, 0.05022875776874924, 0.0288055973472975, 0.0355840448079811, 0.052845645170178146, 0.056572938713455395, 0.0526925961246654, 0.039155286241082415, 0.005246368809528048, 0.0407902519368837, 0.05056677108270027, 0.15265044996575003, 0.023751156066634485, 0.06710209327960207, 0.07943021764437999, 0.00865299757870455, 0.06283797894514377, 0.04085337375140479, 0.08047904563887466, 0.02017396787602094, 0.05243406060241884, 0.0389355760548384, 0.016678666823633736, 0.03517254067945384, 0.05082632167144649, 0.1120043910979744, 0.032247954063237674, 0.06545571670416864, 0.03591900526155387, 0.03605149250717894, 0.04715126000284668, 0.010612165938401896, 0.015635054930293515, 0.0014804465993825768, 0.059361881801798466, 0.0744725332685536, 0.0715965319484953, 0.02198618908052243, 0.012894613826046548, 0.04666180642802389, 0.036485691990463004, 0.02576129608637383, 0.06377210825561516, 0.0675451985350059, 0.07154970865456328, 0.08191540687074585, 0.04998794569063091, 0.06801102595824389, 0.045003716368228204, 0.059222580204086925, 0.03943778882404009, 0.030727461055522005, 0.005264007983984607, 0.02378984542203046, 0.03216358096969705, 0.036996921614533475, 0.020117760005016482, 0.023425574444474715, 0.040058032759735664, 0.10898493215321534, 0.04198805721957357, 0.05123139449184941, 0.036012150061827515, 0.03487497680790482, 0.04032883718008957, 0.10445965078449058, 0.05652288635892253, 0.024303417359929413, 0.32896563170417664, 2.731741080361028, 21.10527957639387, 55.67423989695888, 69.3742238321612, 81.3548211128481, 88.43905310476981, 91.61730258695542, 83.73359741703158, 80.00492172856485, 64.57973818625173, 66.93774161800262, 54.47253942489625, 52.108091538952245, 60.325825752750525, 47.838501391872285, 41.04145749922722, 50.653543318471606, 39.17904161637829, 52.57738744058917, 48.58523830290764, 39.63529955956244, 21.078407418343332, 30.15664100646973, 55.613670656757975, 40.87541180272257, 38.11790712418095, 24.608603331350512, 31.89697115652023, 29.46634896339909, 17.900781593015118, 29.522119183694166, 32.99325204664661, 33.70067111907467, 31.53531489833709, 28.65449482394803, 32.03538767753109, 30.10122576067525, 25.260042336679277, 24.56879911884185, 29.12285916266903, 31.818296255603915, 27.20950738076241, 28.975797737798384, 25.572939611250355, 31.352442233793198, 29.5229644544663, 44.95417079617901, 58.60731378678353, 68.15209173387098, 73.04401689960112, 74.71498581670946, 70.96369374182918, 80.5708412970266, 66.46148743168001, 67.82161635737266, 50.35874974343085, 32.539033735952074, 16.48988739136727, 7.568369651994399, 2.0216889943807357, 0.3646017130344145, 0.11397844646126033, 0.13011575916842108, 0.08626150793486065, 0.04034918830579808, 0.08091478878932615, 0.012307332738512948, 0.021975013772926984, 0.048844383263419715, 0.02780195130335708, 0.02588574132401376, 0.0470564068265019, 0.046172682271008535, 0.041664974959266764, 0.06886669254351048, 0.045521802479220976, 0.030010414249714346, 0.0390746554870519, 0.027423877336625612, 0.022257499118906357, 0.015665729090781705, 0.03393946853916972, 0.038861778805092465, 0.03463640936740464, 0.05167993514107601, 0.07127054621495547, 0.004705586386168557, 0.009666366236013992, 0.0364854583336461, 0.07825226553024785, 0.014819976640865208, 0.057568496784135226, 0.045580760605873606, 0.03760776565139813, 0.08135253909013926, 0.14769461186182115, 0.012328250769285426, 0.020644619737962083, 0.005895572305176288, 0.07094999970567804, 0.10166097837950915, 0.08069704361860791, 0.03456659194442534, 0.05678689174894845, 0.0183841624041839, 0.04513566352186665, 0.03007218583426889, 0.06212586191512885, 0.06928234120770808, 0.05559218146147267, 0.04880202626208625, 0.05020321639735372, 0.026573950665131695, 0.10332255413936031, 0.009927004669612695, 0.034536944341755686, 0.03439897573703239, 0.09372803067127544, 0.04266351694241167, 0.027712018326705987, 0.06108202498346087, 0.09494309208445972, 0.11835617163488943, 0.16835650879769556, 0.22595073847520739, 0.14783016345914335, 0.1175358293638114, 0.24527562812211054, 0.15407989342366496, 0.1856976597299499, 0.1932293305834455, 0.08039286840827235, 0.2488502250203202, 0.17228522217802464, 0.20857615546593744, 0.0989750358125856, 0.1291097784715314, 0.10416779426797744, 0.14943032195010494, 0.07426168288915388, 0.15677715110923016, 0.13332209760142913, 0.1938489118530866, 0.15514072601593312, 0.09662702995082063, 0.0692276501907937, 0.20350767179362236, 0.12604103709060338, 0.12226442280676096, 0.18497594361824377, 0.13181817507551563, 0.30217759010772555, 0.1890346008322893, 0.1193532580509782, 0.26365694259443595, 0.15122693602836904, 0.1656520958509176, 0.10392420129069399, 0.1328381905031781, 0.11682296922850995, 0.13952918711208528, 0.08485962065958208, 0.07937763336925738, 0.14392158286946435, 0.09800118484324026, 0.1316067501301727, 0.21718002765649752, 0.11115160500330311, 0.11083563203893362, 0.2531434890002974, 0.14985105743811977, 0.22625239325627206, 0.24497248713047276, 0.11371018545281504, 0.0746101992685468, 0.5765765256458714, 4.081230822109407, 28.65364366962064, 65.38087444920694, 83.33916387250348, 93.8502687023532, 98.80662272053381, 100.33019681130686, 95.87538057757963, 92.24219891332811, 74.71452297702913, 79.52877736860707, 63.48929182175667, 66.11070986716979, 69.85387479105304, 56.3631610716543, 47.949677052036414, 62.56140024431291, 49.131338134888686, 62.99395922691592, 54.69077225654356, 45.17349012436406, 31.316519206570042, 47.79495916058941, 65.68053176326137, 51.460782789414935, 61.79603599732923, 38.67313431155297, 35.052692505621145, 28.47499147538216, 28.685683550373202, 31.010756723342407, 33.72148713757915, 38.9776945883228, 36.83323283349314, 40.23587326849661, 35.54868405865085, 35.020015239715576, 36.41097791733281, 25.723421342911262, 33.97675891076365, 35.67206613479122, 31.133646542026153, 30.19108530013792, 28.43511469902531, 32.84935009094977, 29.589817331683253, 50.17816774306759, 65.33916004242437, 78.88641865022721, 84.28924037564187, 84.25692789016232, 79.94760021086663, 92.50490357798915, 80.50601236281857, 78.36211542929374, 58.83593697701731, 40.42614744555566, 23.2313395315601, 10.138412983186784, 3.4065873199893586, 0.5369554387946283, 0.4780294878348228, 0.35897829059150915, 0.2157927343561765, 0.17557586092622052, 0.19931242110267763, 0.14236381968423245, 0.1807760504344779, 0.14340982081428652, 0.17241937949532465, 0.11691188139300193, 0.13483694454114284, 0.11964397309648415, 0.09747629204104025, 0.22548184670027227, 0.2272906722200494, 0.12144150648025737, 0.1399462147345466, 0.1230261899951485, 0.07387615680213898, 0.15694285592725202, 0.1090555118336793, 0.2364945444729059, 0.08591368869547883, 0.18007126486589833, 0.16439719786567075, 0.09232620468303081, 0.14905357523070228, 0.14158803308683057, 0.18424544813892535, 0.0661648000260034, 0.23138185752735985, 0.1528811956485433, 0.080388187611055, 0.10382113948224053, 0.2533373552104158, 0.18780855371827082, 0.13856911040361852, 0.10720376240750475, 0.12309161390388206, 0.12361701998499133, 0.1624956603852972, 0.24430399880774561, 0.22195025797813173, 0.14231630691116856, 0.189732828688237, 0.10693024603589889, 0.15209727319738559, 0.13927193478711192, 0.21674795406720332, 0.12167812039655064, 0.1421929973988764, 0.13414977899482175, 0.27673838419779656, 0.12983543227516836, 0.0822481265171401, 0.14614921333568712, 0.13692258827147946, 0.20630044532158684, 0.11140845130167662, 0.1480627171094379], [0.06727149064141898, 0.018998622376051162, 0.04010107157932174, 0.0165533616522988, 0.05834325299327893, 0.020188454598669085, 0.031972813585232344, 0.017499491730104053, 0.07179789815939243, 0.05351317971343956, 0.025806656152370478, 0.06396607405716373, 0.07412430034169266, 0.020179336237150337, 0.031125231142786723, 0.04864005995313487, 0.06460869159068792, 0.018097381220169125, 0.07394970124286991, 0.040975844397419886, 0.05458828835417667, 0.059421889468907356, 0.02097585125856342, 0.014921433495117292, 0.029957494811124863, 0.06846853366662418, 0.10709461020005327, 0.015823212827766137, 0.03330666459195557, 0.04754848042202573, 0.03382372797556943, 0.014229917526996184, 0.06353072544199324, 0.017968954240542748, 0.051480518623946175, 0.033915306126037915, 0.018297366557582732, 0.06674101305825096, 0.03777831214510145, 0.01270927513213528, 0.062355443144277226, 0.04880769531272593, 0.04363300121058861, 0.01442917220805201, 0.07752754635387853, 0.03566163036251261, 0.03909641238410146, 0.057722626013621214, 0.022762310841391166, 0.053196107412898735, 0.07186346762483159, 0.1210963991921275, 0.8682398654280171, 6.288661572241015, 16.489659893897272, 43.65089662613408, 65.9324695217994, 81.22658314243441, 87.20686404935776, 79.81867974804294, 67.47080741390106, 61.93978301940426, 52.978402722266416, 39.994239576401256, 31.51019996212375, 32.75405610761335, 28.019755309627904, 27.514093152938354, 20.592568920504664, 26.46825198204287, 21.217208331631078, 16.38012476505772, 14.722116339591242, 25.928596604254942, 24.14167654129767, 22.610342041138683, 71.05281783688453, 87.41504776862361, 49.8880260990512, 50.386802534903254, 69.2457583642775, 50.22419675703972, 37.423835877449285, 58.645937365870324, 44.732517657741425, 37.867597149264434, 38.053505728321696, 40.483182630231305, 40.23741475997433, 36.76215164123043, 40.41567863956575, 46.72441490234868, 40.64436851009246, 60.339463833839666, 37.58789685464675, 19.931871160384148, 19.427479851630427, 26.98425154532156, 32.52024362164159, 21.80964312245769, 20.334484807906613, 16.642112616569765, 16.213326954072524, 21.22953437989758, 40.98814072147493, 56.465142696134514, 61.16779388919954, 63.05150431971397, 66.68776112218058, 67.72777757337018, 68.64116422591671, 69.4033670425415, 57.021558361668745, 34.37382828804755, 23.161099687699352, 11.181963489901635, 2.8387931037333707, 0.43818191474964546, 0.10990833623274682, 0.1280896328089218, 0.04405420401223725, 0.03601439852988528, 0.06909474159681028, 0.07135047216809566, 0.038046833623441, 0.033435030284548, 0.018751141502551975, 0.07521627440808282, 0.04923824821749041, 0.023936352076669856, 0.017794525596283136, 0.03210390463561541, 0.0031080337911618934, 0.02153397887013853, 0.0414011572607823, 0.018466936289182594, 0.04506553583327801, 0.04845139931046194, 0.032452821295948765, 0.027262903111536178, 0.009663453186681915, 0.026590143848631172, 0.036441795152401736, 0.018895796139634425, 0.026146404655470003, 0.045174465875231454, 0.036762625114211155, 0.047332815180021914, 0.05334875426225124, 0.07410929267925602, 0.05668701303582038, 0.033426193460341425, 0.09269305354645176, 0.03721917138224648, 0.055423937061981815, 0.017143973307083213, 0.050138788402921734, 0.05290685559532816, 0.03813563470518397, 0.004928127267292791, 0.06007654224372199, 0.046243403677738486, 0.03372581810840676, 0.00526872469157341, 0.0305896686510213, 0.04288657110244517, 0.057081647908254984, 0.06853929720818996, 0.05092444987366757, 0.023072195321982427, 0.05327535920866555, 0.024039781607326963, 0.026571686875315446, 0.07579932094461496, 0.022773484233766798, 0.061736103192332296, 0.0370803983852027, 0.019825857523227894, 0.028149299398665468, 0.031702480308951876, 0.0738735291205587, 0.010601414851994525, 0.018803151211731376, 0.0340103201808468, 0.11806411593551598, 0.017861265261026642, 0.010122446148025413, 0.0410124634002005, 0.018889966210530653, 0.1199951631227328, 0.01457354243499257, 0.035286362192803816, 0.0566129399944217, 0.025455253536722837, 0.05906857354866882, 0.028253673132689252, 0.05482797811348593, 0.02916352703206001, 0.10796238097452349, 0.07236864898473987, 0.03637421853660095, 0.04354883879122715, 0.06462058127527276, 0.02361894652788197, 0.027392224498814153, 0.047282835603841854, 0.034605256401963776, 0.03873275044644552, 0.0379356206394732, 0.015934399956266488, 0.013671696069650354, 0.02353208364858743, 0.03160293675929068, 0.024178807413385763, 0.0554262966127886, 0.042284927781551115, 0.0397778207796716, 0.07016055376058625, 0.029191240262720856, 0.029394366560624014, 0.004332126183961068, 0.050863748896987214, 0.03934050714897533, 0.031003515093377045, 0.0477975509279678, 0.03449745250925903, 0.03192704557741602, 0.20653915831879263, 1.6545113873097206, 9.637699877062152, 23.583013357654696, 55.42547141352008, 78.72295779566612, 89.9832510179089, 94.70257620657645, 89.087201241524, 76.64001449461907, 71.4296007156372, 63.84790628187118, 46.751267448548354, 43.16860591211627, 41.91385146110289, 38.87166507782475, 36.657134102236846, 28.350114976206136, 37.66712480975736, 30.60281845831102, 33.71154392919233, 26.24230580945169, 46.1349924918144, 38.38287107406124, 28.77757487758514, 61.21685489531487, 82.45585395443825, 49.366405779315585, 50.175731951190585, 69.02795699334914, 44.563059499186856, 27.27288503800669, 33.87017634607131, 46.66208059557023, 35.24936406843124, 35.8038067817688, 36.65515330529983, 35.16739437657018, 33.36917984870173, 37.99689415962466, 44.308474140782515, 41.410438783707164, 51.22120441928987, 35.83040437390728, 24.7567924376457, 25.66346791482741, 31.5253814958757, 43.486631685687655, 29.695182000437093, 29.833180789024603, 30.361255368878766, 30.3833245846533, 37.18022531078708, 57.30259226214502, 67.88275826361873, 67.54717596115606, 71.10740938494283, 75.1631401431176, 77.63399800946637, 79.31049746851768, 79.8627358098184, 67.3172309321742, 43.73117577645087, 30.525889012121386, 14.807188626258606, 4.5296967317981105, 0.9257206681274599, 0.29235386079357517, 0.13710882424587204, 0.11590675105370822, 0.09643248958332885, 0.08008346081741395, 0.05911353524894484, 0.04378161460701977, 0.07671317956860989, 0.028066607868118633, 0.08111099156761363, 0.02733294078479371, 0.017275497197143493, 0.08552894401814669, 0.05540209589526058, 0.031618325550469666, 0.01318383212727044, 0.036602911103757164, 0.01821678176882767, 0.041085291548722216, 0.04747841019003142, 0.032736817750358777, 0.04942089506995775, 0.04437396145095268, 0.052291047308714166, 0.053962969085982734, 0.04644610288162385, 0.04223615862429143, 0.04660808834277334, 0.028753970682080236, 0.02120762924483467, 0.08648799416879493, 0.027308671119352503, 0.0576464883652666, 0.028667404661856355, 0.03646068305017487, 0.09540919529935045, 0.03784817936379583, 0.01935402205544374, 0.022530159387256832, 0.08519901293179682, 0.03321919650320084, 0.04448135548661794, 0.04911528344476416, 0.10339927018409777, 0.021448447068612424, 0.026299832914505276, 0.026772468944170305, 0.08077451042951116, 0.020658619994778308, 0.005187265604974763, 0.08425971252783652, 0.06524084436316645, 0.030007512691701134, 0.03960365452052605, 0.05334987275062069, 0.07108085518402439, 0.006686922457564863, 0.0346383705524908, 0.17238470635587172, 0.1281708151462578, 0.12312964250844334, 0.0743341701285493, 0.15131787066498112, 0.18640148002774487, 0.08407461802445113, 0.1192732401672871, 0.12736444631891866, 0.12326344742529816, 0.149268401606429, 0.19974636394650708, 0.19452280875655914, 0.22093152957818202, 0.18684847700980403, 0.18723289993020797, 0.22296831222070804, 0.1873395546910263, 0.08513108391555087, 0.1174253135198547, 0.1711414682288324, 0.12670437730247938, 0.16415137557252762, 0.18794015230190372, 0.16776709607051266, 0.18713565272909982, 0.25989986355266265, 0.14854925955014844, 0.08341222010072201, 0.10070672393926691, 0.14652992839053755, 0.11044981483850749, 0.16867561506167536, 0.09363963944657196, 0.15482284549263217, 0.10368751842648753, 0.08091244456027785, 0.13013858858856464, 0.15184118532605712, 0.10671333590101813, 0.19309172587048626, 0.20693671198621874, 0.12445496695656931, 0.13266499334525678, 0.11518087508457324, 0.12350245919679442, 0.16019488384406413, 0.20255318752700285, 0.1774201716386503, 0.10400278658996667, 0.2061819928067346, 0.3355539265659548, 2.0740613389399747, 12.635529156654114, 30.742041026392293, 67.70833046205583, 93.7221876267464, 103.34156513214113, 106.96159901157503, 99.48868366979785, 88.88894896353446, 80.23767517459008, 72.94571445834252, 59.53296569085891, 50.85670248154671, 51.2518185184848, 46.609214890387754, 43.7816959042703, 34.716666975329005, 41.035334679388235, 35.708289223332564, 31.584838744132753, 27.344007415156213, 43.3342162255318, 37.0677121223942, 37.5890657209581, 89.5544025974889, 101.09328608359061, 66.0991310304211, 69.79255245577905, 90.98018415512578, 70.07317450738722, 55.65133717752273, 78.97216166219404, 64.8770106992414, 53.31174927373087, 52.79300405133156, 58.40758277523903, 58.85759238273867, 54.71208641605993, 56.80976606184437, 60.56685932220952, 58.22365107074861, 77.62896953090545, 55.24881570569931, 32.00690538652482, 31.362663930462254, 41.615606200310495, 48.95312132373933, 36.64638288559453, 32.47598948017244, 28.98813359199032, 28.994479986929125, 36.41849710095313, 61.19382273766303, 76.52774841554704, 80.91630012758317, 80.75582811909338, 84.61343211512413, 90.77984517620456, 92.57012474921443, 91.45341027167537, 78.35675747163835, 55.53286983120827, 37.47330481006254, 19.31935775664545, 6.779355964353008, 1.9231991373723554, 0.7303262045306544, 0.45723311182472015, 0.2254364330081209, 0.17482199976521154, 0.17567025828025035, 0.11598411827318131, 0.2058795106507117, 0.17985715861282042, 0.10579016930874317, 0.20623609393594727, 0.21166730491865068, 0.15084982158676272, 0.12370864410073527, 0.16562862291691766, 0.07280595495455688, 0.10293960210777099, 0.10908508282755652, 0.14689100095100943, 0.18974735371528134, 0.18567055553918888, 0.13167241918704203, 0.12776802909830887, 0.20779799399597032, 0.09109614326828912, 0.17291404246803255, 0.08265832063531683, 0.1339737319898221, 0.18311985047353854, 0.15273911698210627, 0.2881448205199934, 0.19501529603956208, 0.14699937174877814, 0.21940882257636518, 0.12708797284792508, 0.10373183661290716, 0.18584451878503447, 0.32539897147686253, 0.10352781207691278, 0.06872242286560998, 0.34025608231463744, 0.16445705997607402, 0.16037899009402723, 0.14117835990844235, 0.12643269188101255, 0.09207961630196342, 0.09646525516385034, 0.1588973760484688, 0.16462680973833607, 0.21039118629790124, 0.07584782197110115, 0.1765267905448714, 0.17164563069180136, 0.1533036778170255, 0.09487913140366155, 0.18178662765891324, 0.140879554974456, 0.1447366850991403, 0.13354619364103965], [0.03706161007885972, 0.04333135025996355, 0.07318251781285771, 0.03495829653054957, 0.11934535202359962, 0.03927626301564517, 0.07309487735432002, 0.08277832830865538, 0.07268671336914263, 0.0036594006768052257, 0.03264440456405282, 0.048000943441424644, 0.055528416133095185, 0.06493853074648688, 0.010945790526156705, 0.013424695916323653, 0.058921963472159646, 0.10881848422990692, 0.0376689684156689, 0.06825678696435306, 0.0458284406622331, 0.04881804899102257, 0.028107034327882915, 0.022005511733192592, 0.08706307339091456, 0.08368025128279002, 0.039177970104520364, 0.02622447476061362, 0.07959858078749911, 0.03388374713399718, 0.04272353993127904, 0.025866851511020816, 0.015117563495051958, 0.07720043447109, 0.09932500775903465, 0.05565560205028423, 0.053271850525972345, 0.05162661925198571, 0.03523001642597299, 0.0511281258396564, 0.07683133330917166, 0.04242988693858347, 0.026430906727910045, 0.053227735352852655, 0.03280722506103977, 0.11739089318941678, 0.03978719386542517, 0.14834866708805486, 0.04362930866679357, 0.16381777492502045, 1.0432206598981735, 13.14490972026702, 24.672008445186002, 48.09430660740022, 67.19085216522217, 88.1947208219959, 72.02058422950007, 64.8149391912645, 50.88144871496385, 44.62891217200987, 42.66876259157735, 36.77848046825778, 32.20735615299594, 25.713648757626935, 14.380069971084597, 17.266944223834624, 14.159875954351119, 17.95525154759807, 23.409381797236783, 16.31427405341979, 16.225575535528122, 19.62774234433328, 27.80822384741999, 20.804655398091963, 35.12544462757726, 46.05952216732887, 51.74509579135526, 63.71983305100472, 76.72775791537377, 48.933380034662065, 35.20771634194159, 39.330856953897786, 61.32207247518725, 59.68940942518173, 43.418441280241936, 65.24980060515865, 63.984087051883826, 47.641174793243415, 56.2767747909792, 61.09472797762964, 64.04472297237766, 51.135347658588046, 65.49004185584285, 86.08576436196604, 52.33423579123713, 55.00822928643996, 54.95207271268291, 45.058345025585545, 28.709054993044948, 34.73673774350074, 31.56983175585347, 20.22893971012485, 21.78225713391458, 11.741826918817337, 10.144584832652923, 26.222680230294507, 31.640503060433176, 37.20965485418997, 56.84838964093117, 53.602479273273104, 63.29678973843975, 56.55195651515838, 63.45857966330744, 64.80947925198463, 61.47616278740668, 48.24411761376166, 43.12861342583933, 26.971241043459987, 11.460717512715249, 7.051785165263761, 1.8117301574637814, 0.18112785333106596, 0.06111714245390989, 0.07050937657514889, 0.06347500020638108, 0.06008922482930845, 0.030773244385096817, 0.054325619787578626, 0.09036653645096288, 0.034911224258042155, 0.04383194275320538, 0.018887576016206897, 0.042548699514760126, 0.08665949061152436, 0.018823902618380326, 0.02942177527133496, 0.015121774105805785, 0.01605643680499446, 0.06526422536661548, 0.016383249913492513, 0.048217171758052804, 0.04128693355127208, 0.033231714379883585, 0.05151045350958744, 0.04178223620739676, 0.020188669103287885, 0.0874811965191076, 0.032254940785107114, 0.030151924095867626, 0.0450609507970512, 0.017989263231415423, 0.04597447617279907, 0.03557575190620076, 0.05401253497468368, 0.02508634006634595, 0.07032168503370016, 0.08226943142231434, 0.06394299565844479, 0.08712288187516314, 0.03889457119869129, 0.040497150527493614, 0.0661466514030772, 0.04463733098800144, 0.017956062895996917, 0.03138596533737596, 0.15133625677516385, 0.018000164662577936, 0.058315026483708815, 0.034993655318694736, 0.006097208083261766, 0.04520176924885281, 0.09825236975185334, 0.042917134180184335, 0.028500387918264158, 0.03611104435197288, 0.039522786279239004, 0.05974915839972035, 0.04900470248333389, 0.0835566123526904, 0.04063059538302403, 0.05647422445397224, 0.03157614666457859, 0.028987043356943517, 0.03344541460636162, 0.020074527748229525, 0.022254593730453524, 0.020482866018409693, 0.0483990065573204, 0.04654235416843046, 0.029561036649430474, 0.014671633290427347, 0.02728814570864122, 0.027297819483905073, 0.009571404849749901, 0.0367709563203877, 0.038363059396825494, 0.04338279306407898, 0.022841388352155205, 0.055072172469789946, 0.08105340473834546, 0.006751604218621769, 0.02692472891912105, 0.026237693607747078, 0.06723019084142101, 0.03082009066166657, 0.1259560472962837, 0.03356252646734638, 0.06946293877497797, 0.038081667641358036, 0.05906086670415056, 0.061866931857601296, 0.062203914783294165, 0.04399642949142764, 0.10711914799626797, 0.050940599007111405, 0.032772911982911254, 0.023031590746775753, 0.0545277291037623, 0.07911258993009407, 0.017321414592105056, 0.019672245403090795, 0.05093495293910946, 0.014943028556092855, 0.07505950217525806, 0.09217582162349455, 0.2588619369893305, 1.7900867640010774, 19.02593112760975, 34.29340008766421, 59.644470830117505, 78.3233545672509, 95.39771433799498, 80.54836611593925, 74.43832535897532, 63.238354267612586, 54.64220546906995, 53.550774589661636, 45.28307330223822, 42.72511528384301, 35.5388585213692, 22.90648295033363, 26.305687389066144, 21.538530857332294, 30.472819343689952, 33.39631872792398, 27.033404727135938, 23.835147234701342, 23.453545724191976, 31.463435503744314, 25.804849747688543, 30.074284961146695, 41.760851567791356, 55.24740365243728, 64.2638304925734, 69.52699230563256, 53.81683288082, 42.89598157328945, 41.765931037164506, 48.11480491392074, 46.99427789257419, 36.11760031792426, 40.37707467232981, 38.27062852921025, 35.86022223195722, 40.23345316610029, 43.48647871325093, 42.86600289806243, 32.39108781660757, 53.136682125829886, 67.63972820774202, 40.00731675855575, 43.58271798779888, 44.68996386374197, 37.47386963136735, 32.950207956375614, 35.534234046936035, 32.7328537356469, 29.265294151921427, 30.269336585075628, 22.47665393737055, 19.988239542130504, 36.36351331587761, 41.934388991325136, 45.40974232458299, 63.26246115469164, 61.975602103817856, 70.81942112215104, 64.34300745687177, 71.59092780082457, 72.93311580534905, 72.8415676855272, 57.99230575561524, 52.79879739207607, 32.919044725356564, 13.37226108197243, 8.027182529049536, 2.2117970835778022, 0.2516391527869048, 0.11599732562899591, 0.06077476626923008, 0.08116059576071079, 0.011529165522886381, 0.015753720992154652, 0.023143700053614956, 0.06943846992667645, 0.04576017839774009, 0.03266318520951656, 0.06956982336217357, 0.034420633042651805, 0.06140521832651669, 0.029099461014172243, 0.011951414034551671, 0.06782987680766853, 0.04405357582013934, 0.01650730636151087, 0.009784700007237976, 0.08443212061519585, 0.029095308817622643, 0.06988706037161813, 0.04586417866390079, 0.032518819770625526, 0.06020835533197369, 0.041751811025483955, 0.02782757694442426, 0.031783970996677395, 0.04053699859087506, 0.01765681363101448, 0.020475660961481835, 0.022579202420949455, 0.05037220390213113, 0.07518263548732766, 0.023057716260213527, 0.06429061188452667, 0.05938932690168581, 0.10045278877500566, 0.049988397682506236, 0.028818781720474366, 0.08674141605414691, 0.03997601921700182, 0.03401698131534842, 0.031472751607878074, 0.022988180374546398, 0.021978313696660826, 0.03597135204941996, 0.05445149569441715, 0.03440641828121678, 0.026642458077760476, 0.06126205181522716, 0.03511628684317393, 0.06228467960271144, 0.08814550200176817, 0.029470412278427716, 0.18782439641654494, 0.16522987415232968, 0.20019665510664064, 0.10695035584391126, 0.24177102101666315, 0.1026967905401703, 0.1672568355476664, 0.16705229007188352, 0.15733284064598624, 0.1008809706376445, 0.15170784006195684, 0.22298770956695083, 0.11154624753661695, 0.1911136255629601, 0.2823570568955714, 0.1716701914706538, 0.11160647736922388, 0.15917250886559486, 0.18241618339332843, 0.17169269913386914, 0.2198079697066738, 0.09992169832149822, 0.11488501958909536, 0.2209541291719483, 0.14372741022417623, 0.13371528456768683, 0.22141030388734034, 0.16628062502751428, 0.18907733321670564, 0.26078647242919095, 0.179338563053358, 0.19817091945198276, 0.1797835069197801, 0.1349275114555513, 0.16934393484505916, 0.13037290424108505, 0.24394396812685076, 0.1806335887240787, 0.0795250210250097, 0.1376778437125106, 0.15874029738047432, 0.1281061879689655, 0.21010309127309632, 0.1581403432834533, 0.2456396118166947, 0.1514124365583543, 0.11529927397327078, 0.2347650243750503, 0.3167912075596471, 0.6497987804393615, 3.4727157844651133, 27.30965921955724, 44.06120792511971, 71.91745727292954, 92.8162770117483, 107.90540756717806, 90.94015244514712, 86.26782509588426, 72.17804385769752, 64.62607314509731, 61.83640110877253, 54.96989988511609, 46.963777542114265, 43.229857644727154, 27.18114079967622, 32.33802599291648, 25.383167497573364, 29.052464385186475, 38.56819521996283, 29.137064026248073, 26.549458772905414, 29.497892664324855, 42.22451494586083, 33.21590146710796, 49.991086375328806, 66.25010305835356, 68.3184943660613, 74.49149700903124, 90.46830700289819, 66.05232930952504, 50.51084356923258, 52.249536129736136, 84.39785080571329, 81.78033551862164, 54.35166374329598, 81.94938967304846, 80.08682081776281, 61.58261983625351, 73.21645213711646, 78.9127612883045, 82.27433450760381, 70.3005386167957, 81.23886016107376, 103.58523061198574, 72.73301216863817, 73.21601283165717, 76.82748809937509, 63.48585582548573, 43.323912159089126, 50.90489272148379, 45.705845971261304, 30.63950046416252, 33.46845896013322, 20.670455425016343, 22.0486625548332, 43.40530918490502, 51.562207437330684, 53.75574196538618, 75.69038514168032, 72.49375543286725, 83.18419102699526, 74.09729096197313, 84.32560859187957, 87.07894771329819, 87.43082354145666, 73.4107820449337, 64.17997021828928, 43.7483008446232, 18.791598927590158, 10.805800345636184, 3.2328667707981604, 0.4164977041223357, 0.269770446804262, 0.2298802639087362, 0.29150969318805203, 0.18131044272693897, 0.2025063795548293, 0.15182806990079342, 0.17622568734711216, 0.1839778383052157, 0.1890269093095295, 0.16161718736252478, 0.16106644675375956, 0.09612213204344434, 0.12044714733717904, 0.11422999909207707, 0.16215033859254854, 0.13822452405527716, 0.0920176551106476, 0.11400250162208274, 0.1614353180893006, 0.18856875808729281, 0.11735877878363095, 0.0950958040512858, 0.1218299207187468, 0.12769822316664842, 0.17233985956878434, 0.10594925512709927, 0.12700787835544156, 0.13723700607736267, 0.10834490399687521, 0.12009591900653417, 0.1112569650755294, 0.14074170511336098, 0.19831494398174748, 0.13740266493010905, 0.1930460057431652, 0.11107073676201606, 0.3339522818644201, 0.1783628734729944, 0.19949182357278564, 0.14757654239093104, 0.10204658873619572, 0.12875350162146554, 0.2229565297884326, 0.16616644728327953, 0.15166182882122456, 0.12714867765504506, 0.18652350251232425, 0.13670693452079452, 0.16375615081239134, 0.23556744018870018, 0.08310615265321347, 0.10073321525968852, 0.20157334575008964, 0.15611785584159438], [0.05221097962930799, 0.03911677883156846, 0.03379092792109136, 0.03286600315703019, 0.06075972796327645, 0.0336282491503704, 0.047103659129671516, 0.06905023188840959, 0.04301152004289531, 0.1304807081337898, 0.06534978972687837, 0.10657786091248836, 0.04326809821049533, 0.04910489146207129, 0.0835987242058881, 0.07422588360045226, 0.05591527138265872, 0.07431296481480522, 0.027142497072477016, 0.04765400903359537, 0.06327692817355837, 0.027234320371081273, 0.04002284251093384, 0.01644022004198163, 0.0579301247583522, 0.030177019221047242, 0.011993604411761607, 0.0725972572822244, 0.03474093057335385, 0.02421143701330068, 0.05049028869477972, 0.06540829586165567, 0.08161474800398273, 0.019196880185195518, 0.08007948482108694, 0.051315403693626006, 0.028619788466922702, 0.06326033853955808, 0.019542621411082726, 0.04435645634188287, 0.011340722257661964, 0.031764964355275996, 0.06614177908387876, 0.09115374541931576, 0.0036128129549099198, 0.022116669175785877, 0.016778578095498587, 0.13961673564007207, 4.4574280419657315, 16.308834706583333, 35.14280111558976, 59.6920060342358, 72.77752322535362, 72.25014486620503, 71.39890424666866, 59.545972270350305, 40.80771953828874, 47.39456753576956, 30.01685165589856, 35.67986772906396, 30.089976403021044, 18.88538868196549, 22.687887299445368, 19.57815770179995, 21.59963550106172, 18.41886197367022, 29.20918268542136, 22.157267101349372, 23.617251726888842, 40.563336264702585, 40.852328654258486, 67.42562170951598, 53.33162784576417, 63.5187448993806, 62.18600588460123, 42.4589353992093, 28.992018699646, 19.472489049357755, 12.598569643112922, 10.616542062451764, 11.569069066355306, 12.162371681582544, 9.411524245815894, 11.304306137946345, 22.768515540707497, 18.79807476074465, 20.296265232947565, 20.928768996269476, 20.632771253585815, 19.496138980311734, 19.933010608919208, 27.947003187671786, 24.686585933931415, 28.648434762031805, 36.45945449029246, 45.3590613795865, 57.70767111932078, 72.43374316923081, 88.2049503634053, 60.45224374340427, 66.69500966225901, 48.22475287222093, 44.058760366132184, 34.94929882787889, 29.176097493017878, 21.19100493769492, 16.412429405796914, 23.625210215968472, 24.158138728910878, 38.69868070848527, 47.745058767257206, 59.42113107250583, 50.46722681291642, 46.72205363550494, 55.780187037683305, 54.56111046575732, 62.40450151505009, 63.97862711260396, 52.62044722034086, 31.374129018475934, 23.31706685404624, 6.710088377998722, 1.232070403714334, 0.1929490036901928, 0.06650193233884151, 0.04571009923012988, 0.1320331699905857, 0.005074043555425541, 0.032204574334525296, 0.0074632778752505066, 0.01744550934451963, 0.02821758847623583, 0.03568222663635689, 0.013178455147651896, 0.0387611493257986, 0.03426391826642137, 0.08841478190715275, 0.051278903434473666, 0.03304558182736078, 0.018068210507232337, 0.031208016519104282, 0.11190204175129054, 0.018405484546336438, 0.04313327056626159, 0.11016923513623977, 0.09195325775973259, 0.049043508667138316, 0.029759643028580376, 0.020229409659101118, 0.024172374190041618, 0.026861871404933835, 0.030532461035275654, 0.09055796650148208, 0.041666805909405795, 0.02768337812965676, 0.03151508754179363, 0.02754970536296887, 0.04237877355227548, 0.03353328489127659, 0.016810476081445813, 0.03230693134208841, 0.018507109939931862, 0.017441565906929395, 0.03489954907807612, 0.07224296459988241, 0.047639334619405775, 0.09654629194448072, 0.024161482334978158, 0.04972611982074957, 0.04687304368182536, 0.08136454368791274, 0.02034131978308001, 0.056445162908564654, 0.009972861735150218, 0.03614423511129233, 0.020283991508486292, 0.034086323763814666, 0.03166153865505851, 0.044706941567241185, 0.02420827881583283, 0.009983185727539803, 0.050380243994896455, 0.026248131555715398, 0.0641327977721249, 0.06370759982195112, 0.004128302746046816, 0.0349520375922082, 0.035303066739992756, 0.021608507733852155, 0.04126912200703256, 0.06235404503381541, 0.06760289261658346, 0.006836970353634247, 0.049388941542636004, 0.027164131395458698, 0.051611619250428294, 0.051735323298001484, 0.07710606776057713, 0.01589374654295464, 0.044445862633086024, 0.030282997909272392, 0.04525152665953483, 0.004315284698555667, 0.05470967115533929, 0.024460666482487035, 0.0035222273671083274, 0.08674805037557118, 0.029722543305627284, 0.02959908249097005, 0.030400510051197586, 0.05802472129524235, 0.07746684154675854, 0.010628623422235252, 0.03754329169169068, 0.05442332664144136, 0.08136920150249236, 0.023449773246782924, 0.02351968643075276, 0.09375858991857498, 0.07403734936228684, 0.04955226382721336, 0.022281012272522337, 0.08920945257188813, 0.27411640231167117, 6.15607516419503, 22.379753743448568, 46.11768307224397, 70.77532583667387, 85.6988617681688, 82.41569672861408, 80.67962431138562, 67.95830311313753, 50.06527408476799, 57.2453962602923, 37.355374828461684, 44.2729845354634, 37.208866457785334, 34.85970797077302, 36.845207829629224, 31.463874809203613, 25.976325965696766, 24.259784990741363, 30.64042025996793, 21.53126270540299, 25.445301763473022, 31.23834833022087, 33.172810308394894, 47.41657203243625, 45.512782989009736, 45.36236009290142, 48.455658881895005, 40.484963386289536, 29.783788342629713, 22.617588620032034, 16.99387077362307, 12.079653797611115, 13.089605281429908, 11.911677314389138, 8.161379070051256, 9.098433794513825, 15.0973577268662, 12.04302768553457, 14.588053649471654, 13.428760863119557, 13.72919382587556, 15.130573338077916, 14.672934720593116, 19.360934880472, 20.06345687373992, 23.742065468142112, 28.736331155223233, 39.013713713615175, 44.97242158459079, 52.824998824827134, 54.571155655768614, 46.96709978965021, 49.343820771863385, 37.39110762073148, 40.05886454736033, 33.3098030090332, 31.17489418675823, 33.60372581789571, 27.739303881122222, 31.29333603766657, 36.89250769153718, 46.679401782251176, 64.00835867851012, 69.7734034445978, 61.025458920386534, 58.53823692567887, 66.98853631173411, 62.85871590337446, 70.9306360060169, 73.56374663691368, 63.07525034873717, 40.22692634213356, 27.4015191678078, 8.382067795722715, 2.085414884551879, 0.23983203715855078, 0.1212114426157167, 0.0469045490477114, 0.053075429412626454, 0.013781389326698357, 0.08285016437331516, 0.010818029085414545, 0.03121276626423482, 0.05003089641010569, 0.05410790142993774, 0.1293536242578299, 0.016110344497006268, 0.029154063930975336, 0.051733239538847446, 0.02748871135765747, 0.05051365054603066, 0.00697057034196933, 0.022272947281899474, 0.029932809542984735, 0.04573969320664483, 0.03683065372188726, 0.05272827283929914, 0.023958233463007118, 0.013963927969246382, 0.012736789179935813, 0.01907965532624193, 0.021996535097939834, 0.016198555691047542, 0.02578176021005117, 0.09256810460600162, 0.11787358986874742, 0.0270934195648278, 0.055107650001563376, 0.030188116004630446, 0.05275247738726678, 0.0869842812479023, 0.034010113337107246, 0.028340618366435654, 0.0451707695009968, 0.07467255882558323, 0.03798073555733408, 0.02065453100048246, 0.04706414814497675, 0.06071400017507615, 0.07400030901114787, 0.047290864205288316, 0.08145681897839231, 0.02607690324375947, 0.038854792083223025, 0.07317026040606922, 0.021295403768759102, 0.07266645800442466, 0.0636446695294111, 0.13944278771598495, 0.16773476716010802, 0.14287731309811916, 0.11626823730165921, 0.21998838341284185, 0.3245890633233132, 0.1212844814384176, 0.26627831161022186, 0.09825931816932656, 0.181637822740501, 0.16129532318201759, 0.2149204972891077, 0.17254414457467296, 0.1725404826743949, 0.1686437304822668, 0.15931958242529826, 0.2334000855203598, 0.15093485734635784, 0.11590531080841057, 0.20043208924753053, 0.23659994284952843, 0.20397405080016584, 0.09307815062422907, 0.19979827406425632, 0.08987755785065313, 0.13716738400680406, 0.08930454706592907, 0.1217609957881993, 0.12913654558360577, 0.12361672887158011, 0.1671160898742176, 0.18027725058697885, 0.08720530527493647, 0.1377997436230221, 0.15141064391261147, 0.0890374351893702, 0.15154993401900416, 0.17642120830714705, 0.12404227539175942, 0.11890709610475649, 0.14526163918837426, 0.12773494942173844, 0.2485472219245088, 0.1833757544837652, 0.11776163377949309, 0.08564752676794607, 0.30920880636380565, 0.3745033381687057, 8.073451788194719, 29.272852559243482, 59.045799470716915, 84.54838352818643, 97.32101717302876, 94.4107832447175, 91.4535593217419, 80.84331266341671, 60.57459423618933, 67.03915842117803, 47.49000664680235, 52.34667362705354, 45.55372468886837, 33.19940005579303, 35.86272078175699, 33.42269274496263, 33.578928593666326, 28.664522363293557, 43.285053237791985, 32.91829947502383, 35.45078169914984, 56.57584767187796, 59.40469241911366, 88.88905878989928, 69.47164766250118, 83.68205747296734, 83.01788253168907, 58.87296415144398, 42.49309532104, 29.49761025367245, 18.982226117964714, 15.679864998786682, 17.326421083942538, 17.099345268741732, 12.025006355777865, 14.291536192740164, 29.399839293572214, 23.526123300675426, 27.631585790264992, 26.746285269337317, 25.698398582396973, 25.104437989573327, 26.35052792487606, 35.141338071515484, 30.514661227503133, 35.4646590448195, 47.273134877604825, 61.37826435027584, 75.88729596907093, 91.14268795136483, 109.51572095194172, 78.63972510060957, 83.99766706651258, 64.0415576196486, 60.19674839511995, 49.81459540705527, 40.845825364512784, 36.00902518918438, 33.09624956500146, 37.80595710200649, 42.85526344853063, 56.10199789847098, 66.36508341758483, 73.86282736255278, 68.12679244625953, 66.76995831151163, 75.80262768653132, 71.99886214348578, 81.96480458782565, 82.6585542002032, 73.93809764615952, 51.01767655341856, 34.63163391236336, 12.844453223289984, 3.3503822069014277, 0.5315900041211037, 0.18872036688750793, 0.08320457196884579, 0.22652053935152872, 0.07819384366514222, 0.2182309164275085, 0.14172827314224937, 0.1151056452504089, 0.14401400371664955, 0.13919770086724914, 0.21729380703501164, 0.0980061337712311, 0.15536172706032955, 0.3036253124235138, 0.16480098748880048, 0.18214019255772715, 0.08640378578415803, 0.14923579690437164, 0.18217861952800907, 0.16918448130449942, 0.19502617448808687, 0.18488225106510425, 0.22263872587392408, 0.15880075703945853, 0.12826829217374325, 0.04760833104111014, 0.13284123953311675, 0.15187415775031815, 0.11304382685451739, 0.20698805519890404, 0.19070758364133297, 0.06765612806644171, 0.1646991744036636, 0.11296259855190594, 0.15183312608109367, 0.15961834139400916, 0.13546530517839617, 0.10496646391167756, 0.16994258659260889, 0.26132788208703844, 0.21800073764977917, 0.11596909528898618, 0.13395502412271115, 0.14985798287295526, 0.16558224395398172, 0.22188825082154046, 0.2248143542918467, 0.12728028389955723, 0.1505968593541653, 0.2407597849566129, 0.16600196820593652, 0.15736026659367547, 0.1534896686432823], [0.015347679070527516, 0.028625206623767174, 0.0639266396812614, 0.05614856430780023, 0.06163224465243759, 0.04527221486393002, 0.03956964404712762, 0.04157531968948822, 0.02381396761554624, 0.05705513360519564, 0.00859835539989534, 0.03927638942015268, 0.06557383980121344, 0.020012478456802426, 0.098744627208479, 0.059600855268898516, 0.012442397870003216, 0.06785282880187997, 0.051932529651469765, 0.04806322255922903, 0.012573681399977256, 0.04874421726732005, 0.06626915652304888, 0.13032916062060865, 0.12676155044426843, 0.04992660120009415, 0.08966557366112549, 0.030515563050885836, 0.00682402394651886, 0.02116770457266079, 0.02326694636365339, 0.010191258080604096, 0.023464120158384887, 0.048919249205820026, 0.06234356495101125, 0.07365157812713616, 0.04147516518470742, 0.04290733974607241, 0.05550497001217258, 0.03006764293287791, 0.0310457629271813, 0.018390813962586464, 0.07694882055323932, 0.05134422009089782, 0.01693192208486219, 0.25572275382376486, 2.544662899548008, 11.552160709134995, 39.507340077430975, 70.57934853338426, 73.9371641220585, 75.70783184420678, 66.56772090542701, 53.366470260004846, 56.55037579997894, 41.430886099415446, 45.65077981641216, 30.572198475560835, 26.151910866460494, 15.773593956424346, 15.81743036547015, 17.102702817609234, 17.86114408123878, 20.883010625839233, 33.99936353006671, 38.63136499158798, 58.86993215930078, 84.18126536953835, 63.75375370825491, 68.80438189352714, 65.95462306853264, 52.156779919901204, 52.61232791408416, 42.48413270519626, 24.583623716908118, 14.68936356805986, 6.982894126446017, 4.19535291771735, 3.6412443412888438, 2.223103560747639, 0.9478134794100639, 0.7742512959145731, 1.5094051413959073, 0.8766116129775202, 0.5346546622533952, 0.32617618299780354, 0.346052824489532, 0.5793052082580905, 0.39483849860487447, 0.371342919045879, 0.9757516028419618, 0.7516663497494114, 1.4557276281618303, 3.2031496686320153, 6.3394072363453535, 11.424639551870285, 15.82951028500834, 23.440907847496774, 45.17044244274017, 46.07480372152021, 61.661992919060495, 70.04833805945613, 68.11062443640925, 66.59531870195943, 40.829292574236476, 27.49137870727047, 22.975136195459676, 24.920443527160156, 13.070065994416515, 15.15074412668905, 16.862677297284527, 32.3637390905811, 60.902708345843905, 79.00692955140146, 77.13100894804924, 76.36346386324975, 73.34458028116535, 67.59163210468908, 68.31625861506309, 73.9487978719896, 59.655218124389656, 41.36679849316997, 25.452185523125436, 5.6792664527893075, 0.9152692063681541, 0.27823602480273096, 0.08763071389928942, 0.05207379626470709, 0.018562074833279176, 0.04973889433688695, 0.030417120752615795, 0.025733852901706294, 0.04937344741436744, 0.03535373579530466, 0.041834820482519366, 0.06518865845376445, 0.03251247273217286, 0.03515595104545355, 0.03799100496595906, 0.10243560818414535, 0.06396982022711346, 0.033365201370249835, 0.07426843978464603, 0.06530248379755406, 0.029494668537330244, 0.022927975439797008, 0.040456295058491736, 0.031584952845268195, 0.04697630850357875, 0.021722277536267237, 0.018776589028176763, 0.03840752313995073, 0.012366474726267401, 0.023417547758248065, 0.04244418980012979, 0.05298688880077774, 0.014399483428156425, 0.05312611378969685, 0.05571090593753804, 0.01566921096039756, 0.02926939463753614, 0.05124956992785296, 0.021228237009997812, 0.03898273259701748, 0.018915478853629004, 0.028266143128876726, 0.021805963065895825, 0.04740568163293985, 0.049967253655796094, 0.02339582150471547, 0.0713927908650329, 0.04626777676504947, 0.04691712438098846, 0.008248263752208123, 0.048035520819887045, 0.032981977377447395, 0.06398653243518164, 0.0282501203999404, 0.059076471915168155, 0.028408311810644887, 0.014637256052435167, 0.045615897228520726, 0.03502131492320088, 0.028515378343722517, 0.010675407454161154, 0.02330062933446419, 0.016314267526350675, 0.03442878421816615, 0.046715175943268884, 0.06453612008162084, 0.03010766145082251, 0.018984558916981184, 0.0352939656154523, 0.10403722224216308, 0.04779152564644333, 0.047912349203421224, 0.10239338141775901, 0.061553046482825474, 0.059967876502102425, 0.008283001051524715, 0.018082132240036325, 0.04445095711778249, 0.038987244854891495, 0.02910110810320945, 0.02580733797062309, 0.018721413460650274, 0.08070039908371626, 0.06086848946588655, 0.06979475443762156, 0.02030586714916412, 0.022537647896716674, 0.036497328866032824, 0.07869435188871238, 0.038610693487909534, 0.02881636088263364, 0.024041863451261195, 0.041905913441892595, 0.021692156874304338, 0.02381131886654804, 0.029272819050557675, 0.012621856839095634, 0.3502295971397431, 4.084944571218183, 16.884546472180276, 49.35474849516346, 82.33431539227887, 82.19526736967026, 85.18004986547655, 72.93960340561406, 61.641059229450846, 67.09503650665283, 51.64957823291902, 54.45162926950763, 48.04011121872933, 41.81348585313366, 32.02982575662675, 24.52543143303164, 20.778226467870898, 28.352397795646425, 23.91036456631076, 35.12695866246378, 28.7315752813893, 53.861430229679236, 65.59770307233258, 48.33725429350331, 52.57521052514353, 57.4114929476092, 47.65704078059043, 39.671503036252915, 32.402086142570745, 21.802912335241995, 13.741607146878398, 8.540155003147742, 4.488373581440219, 3.514491968577908, 2.0616987636012416, 0.7565136638379867, 0.39275406529345824, 0.8891737388987696, 0.7638179138302804, 0.2892140341141532, 0.05965839996333084, 0.1778823524833687, 0.478530693198404, 0.4742615916315587, 0.16199162049639612, 0.20878211054350101, 0.47215123390478475, 0.8469523044843829, 1.8120357346150184, 3.9981057470844643, 6.306525026598285, 11.326164526324119, 18.560845890352805, 35.97930146801856, 38.59499677535027, 44.46944821265436, 47.65976290549002, 51.81572983341833, 46.59415691129623, 36.021364965746486, 32.8547570782323, 30.269087514569684, 30.658257238326538, 22.859518451075402, 26.54797023342502, 21.665862760236188, 36.281606381939305, 59.93504001248268, 80.92022249775549, 79.3168987766389, 81.74080587202504, 80.95852052011799, 75.31193133323424, 78.5639056851787, 86.6923039959323, 70.50618064018988, 49.24320020983296, 30.900971543404367, 7.228422732122484, 1.4755316751618541, 0.3350057140473397, 0.12717289369433157, 0.032176910899579525, 0.015660479473280572, 0.03488715377546126, 0.0624118157241854, 0.025453667734719576, 0.029411634182437297, 0.01957928637913879, 0.03096633301597209, 0.05485633102756354, 0.04232888207620671, 0.054233838623810204, 0.027234490825644424, 0.04931592187213321, 0.01714857941072795, 0.020885925942791567, 0.09781887889989922, 0.03113661329412172, 0.019593081707435272, 0.06834465724926803, 0.038942612572422916, 0.04646887867561272, 0.0342735518220692, 0.08055940060125244, 0.07643614685343159, 0.07451031672497911, 0.07375735954772081, 0.028702481912689346, 0.01654082079297833, 0.033539896230063135, 0.04811867583362807, 0.03408466901389822, 0.034855966336063804, 0.06085264676761243, 0.044914382855377855, 0.014432181975984526, 0.08558570347245663, 0.021750599806827885, 0.031207097213595148, 0.04037293320101115, 0.05831694170351952, 0.11694329099789744, 0.03316164414788927, 0.09805727780105607, 0.036171285675898675, 0.03645946497037526, 0.01881198229027852, 0.04054129251369065, 0.005306691051490846, 0.04630257630900991, 0.18731597450471696, 0.10175253354733992, 0.19309099042607894, 0.16946681534811375, 0.1432617360185231, 0.08049340212657567, 0.1940458577366606, 0.16926456813610372, 0.11570166931637835, 0.268574736772045, 0.14096097479904854, 0.13646436044045035, 0.1111684436158788, 0.20133709955600002, 0.14453413145196053, 0.13542827248813646, 0.1119162296996482, 0.24880407588376155, 0.20808434234030787, 0.13779897753509784, 0.1407083496451378, 0.20950724340734944, 0.19456273725917264, 0.18592000908909306, 0.17203711694286716, 0.22212739282798385, 0.35752995540538146, 0.14924485206363663, 0.09982006909746317, 0.1691730053073937, 0.20516354019843763, 0.17722060573437523, 0.18447535112500194, 0.1319048655850272, 0.22102814858719227, 0.2041300722668248, 0.13790892647399058, 0.11406511398813418, 0.15507049107503507, 0.12741994172815355, 0.2017287390246507, 0.10894816759372912, 0.13319483507544766, 0.15843573146529738, 0.11725239981446536, 0.6277456218677183, 5.580200129939664, 20.54001896612106, 58.03202367598011, 92.1856697144047, 92.1716433186685, 94.29281403941494, 83.47002198619228, 71.21411354311051, 75.84993147080945, 63.3011749482924, 61.072911754731216, 45.571971554909986, 39.50649676784393, 28.417056106751968, 28.625763462435817, 26.444929568998276, 26.623571957311324, 31.246326431151363, 48.32580881734049, 54.98146303238408, 75.42138899526289, 100.35644531250001, 85.45148572614117, 87.39757753187611, 86.67866983721333, 70.10133712522446, 67.12899638760474, 51.580215038791785, 31.230005448864354, 20.00835737874431, 10.147272636813502, 5.840973517587108, 5.357416858596187, 3.2772939868511695, 1.1721244526486243, 1.3471370550893969, 2.377211278484714, 1.974470889376056, 0.8958122278413466, 0.9704176084168497, 0.976411541623454, 1.2367837443467111, 0.9199408105304165, 0.6711535732592306, 1.4166611889677665, 1.3117798297635972, 1.990773730701016, 4.034313636441385, 8.3296541437026, 14.130820997299688, 20.566683238552464, 30.837180076106904, 57.141398537543516, 60.46230462289626, 79.05934026164394, 88.20483269230013, 87.30697078089561, 83.33288023548742, 54.24883096448837, 43.75207416472897, 37.632176491522024, 39.90574698294363, 25.73097778904823, 28.557963332822247, 30.698830235388975, 44.63244622753513, 76.05249835598853, 95.0257481298139, 95.88779095680484, 93.0210247347432, 91.56796701492803, 86.51456571394398, 88.9382766908215, 99.11888260995188, 80.35838219427293, 60.85545555237801, 41.3269393674789, 10.818677486911898, 2.9434407141900834, 0.38835699639974103, 0.20459289662539962, 0.09793084265003282, 0.1450550099534373, 0.1568862113861307, 0.15514215093947228, 0.12386808998041576, 0.2682480462376149, 0.10934601237456645, 0.17093292377408476, 0.1938394123628255, 0.1334639464414889, 0.1542752152008395, 0.2418253519722531, 0.19932371323868153, 0.2630846136279645, 0.16997491550301352, 0.273987791470943, 0.1008457305931276, 0.2080716252807648, 0.17270834786036324, 0.15793673243493805, 0.14603247685778528, 0.17316168805043544, 0.25679219724430197, 0.1525617982711523, 0.22320461970183159, 0.19031928431603218, 0.1264141065879695, 0.09750336558828432, 0.11517001195780693, 0.17049864385156863, 0.168554603813156, 0.15520040426523457, 0.12876916045863784, 0.10584192620890756, 0.11361788717969773, 0.1955400969112112, 0.09887886113457142, 0.1397122055171959, 0.13514399258119447, 0.1109085942528421, 0.1967753524020795, 0.14243593920142422, 0.18370434491624757, 0.13507743486233298, 0.1845854839249965, 0.1200482453550062, 0.08807906685697456, 0.19130300249784224, 0.15165341717581596], [0.0777237874365622, 0.01719335533468233, 0.115736901700016, 0.02560978496236907, 0.028936498790919304, 0.043313477428690086, 0.0477351607274144, 0.05751575163054851, 0.024350311516994433, 0.061918428287871426, 0.05641860647066947, 0.06864887842487905, 0.08597236336959947, 0.01802566389913761, 0.08426502151715179, 0.12236656530970529, 0.01468619853708773, 0.08342828496449417, 0.04297716099949133, 0.017033336804278435, 0.020552723661005017, 0.037479147149790684, 0.09329104645838661, 0.03009873269606502, 0.05011566403892733, 0.08085103495226753, 0.07632406819010935, 0.06312101395920881, 0.12920661198516048, 0.03610937428029795, 0.056296652934003266, 0.01893696378946545, 0.020821375374291694, 0.059027810010217854, 0.05572350808389245, 0.15620134410358247, 0.051846429029659885, 0.018622358292040807, 0.04462053451026159, 0.06351594377549426, 0.05496445284675687, 0.031018076509597804, 0.09086794099740444, 0.5818048612244668, 2.830985135609104, 13.994555896328343, 39.335814829795595, 57.91602350050404, 70.00082246718868, 64.22779960017051, 63.380838286492136, 61.25905175362865, 54.058058646417436, 57.984543385044226, 67.48502992814588, 47.70086934489589, 15.657281952519572, 12.943138095640368, 12.795758958785767, 18.98805476004078, 22.591249904324933, 42.81101126824656, 59.0959430509998, 47.101519415455485, 54.4627413442058, 55.285187844307195, 55.083711378036014, 60.568357667615345, 49.0278071741904, 40.49656183488908, 32.34712393053117, 21.537203135028964, 14.495063078018928, 8.298821372370567, 1.7389261866769485, 0.6552753897924578, 0.2732622142760985, 0.16893720344430016, 0.016808219952508807, 0.11013351245633057, 0.06504134740680456, 0.09906331978497968, 0.10279802139848472, 0.07054470088933745, 0.08347908425475321, 0.1422169453073894, 0.03516770666465163, 0.03224472117219721, 0.06546882446855307, 0.04542338316358867, 0.21595067104264615, 0.1728868310249621, 0.20830260078993537, 0.06571388067377192, 0.048075713622834415, 0.48621768071766824, 0.8000262321964388, 1.0464518349016867, 1.8018647836100672, 5.425327304870852, 12.169798689503825, 22.093293243838897, 35.37765695202735, 54.55208901436099, 56.243807269680886, 64.76292856277959, 49.9457633879877, 40.68842457186791, 34.863559738282234, 29.6113609498547, 54.54890797215124, 67.31842333270659, 65.27293082206481, 51.928345003435695, 52.450941993344216, 42.88719154173329, 64.1463751177634, 57.71852431758758, 48.13636618275797, 63.90788324417607, 59.3477866726537, 64.23283984584194, 61.19880807015204, 41.67088808551912, 21.174766325181533, 4.783604500755187, 0.9472061249036944, 0.37313093761763266, 0.03706912923183653, 0.05323561456715388, 0.02238875296297333, 0.07574456097978739, 0.04022914232806333, 0.012988066976709713, 0.06691358202407438, 0.09814704032314402, 0.05240712495100114, 0.021607961896206104, 0.05673128142652493, 0.055893035680656476, 0.039282571749701616, 0.06373260493179964, 0.04495953607763495, 0.032007061545887304, 0.012219349455629146, 0.023125907661573544, 0.03282068139542976, 0.01773683917558482, 0.06228971280037396, 0.05150351658343308, 0.03368411228180893, 0.10330489581270565, 0.04247646508437972, 0.06800566334277391, 0.030625963981653896, 0.009274252750460179, 0.08538151805799815, 0.0626562743808233, 0.04046568729644341, 0.0362572139279256, 0.052375646398192456, 0.07314278849310453, 0.023906980265652942, 0.03337754687714962, 0.05404313252637944, 0.02659581289927085, 0.07414931311242043, 0.040570124232720946, 0.012273417068495145, 0.03860436177121536, 0.025992386508733038, 0.05034515333752479, 0.032269270459730784, 0.0697424995803064, 0.016515181745372472, 0.021224387418178302, 0.07897307765820334, 0.04725902176071559, 0.08940945514628003, 0.04440676916630999, 0.0433492575651936, 0.07472415484728352, 0.041890610835605094, 0.06429006796210043, 0.04312970059653444, 0.014952842142402887, 0.07329982119582354, 0.030701532809724732, 0.04928085036695965, 0.07708892271283173, 0.040156356314377445, 0.06471729221483392, 0.0371060278567095, 0.026807391062198628, 0.050901884753857894, 0.0448826591544334, 0.01928836065945366, 0.031408021008715994, 0.03202009461669913, 0.027420119675357017, 0.04601806657569063, 0.0809037188188203, 0.03853688474684473, 0.033087536632534, 0.007442494867474682, 0.07935579220253615, 0.04877608652497011, 0.06065556681865166, 0.0577578813798966, 0.021072746059226415, 0.007071350644823285, 0.09777954794586667, 0.04777961297922077, 0.09731079406675794, 0.04683637488332968, 0.04010353072155868, 0.06428040759337526, 0.12601118264419417, 0.08106578471920184, 0.8400541423789917, 4.879196584224701, 19.24341674773924, 50.7653465578633, 69.96489355641027, 79.98974215599799, 72.85189136382073, 70.87445197566863, 69.54701208299207, 64.45879974672872, 65.5748317318578, 74.33912861731746, 54.5314573472546, 29.83510078922395, 20.44653319543408, 17.735388971144154, 22.204723858064224, 26.829110037895944, 42.93122799165788, 36.21944465944844, 35.71434144050845, 45.03826249030329, 51.27453688652285, 45.74524225727205, 56.60375141328382, 48.49077193967758, 42.8534395464005, 29.133090665263516, 18.05931595063979, 12.558505573580343, 5.7258240061421555, 1.8881889192327377, 0.7624547063342987, 0.055425882925309485, 0.1945162357221688, 0.0484530923647746, 0.072683380886672, 0.10090154775929067, 0.06330882041384617, 0.08771004230384866, 0.12355324316529498, 0.0806315890663574, 0.05590250452740058, 0.01891468212218775, 0.019525508922074112, 0.15799297861033873, 0.0986774949236743, 0.1721202528044101, 0.12670675217504465, 0.14542539814306846, 0.10756442894137676, 0.13643814491168146, 0.24219842146961923, 0.23644660269060444, 0.8269668478638896, 1.3966480306079312, 3.7672639662219636, 8.908691098613124, 15.83228438131271, 24.640715775951264, 35.55166113761164, 41.81341132810039, 47.489834062514774, 40.37375634716403, 38.06221731247441, 33.32811263299758, 21.674582189129247, 45.52473837329496, 60.741934314850845, 70.16264377101776, 68.36885759907385, 66.02104448503064, 56.172616251053356, 72.90309398405014, 67.07475785286196, 57.40930818742322, 71.99781094827961, 69.20187488678964, 73.70731322996079, 69.26576245215632, 47.444232586891424, 26.9566596323444, 6.606473576638007, 1.3650430426482232, 0.4900778445505327, 0.054446669340494185, 0.0740248851117588, 0.039297085285427115, 0.07644994409694787, 0.023726390359262307, 0.03269986932977073, 0.016022865874542585, 0.05800022180342387, 0.05358136536914015, 0.07017156244405816, 0.033779520871898824, 0.022335615189325426, 0.051724126922988126, 0.032715279188367634, 0.03756244772023732, 0.0485351863467405, 0.02404271763929677, 0.05003728941383381, 0.0635993171242937, 0.018679282455254468, 0.08297637735884036, 0.03161087726062584, 0.05010513416040809, 0.1298110247139008, 0.018571514951726122, 0.03072566840977919, 0.022646606666967276, 0.01044740245091699, 0.08882181208220222, 0.040987102059467186, 0.06710996100258443, 0.024024930992914785, 0.02259461227954636, 0.021703590736574224, 0.012705065478991358, 0.02042724995032674, 0.07096536742943911, 0.025509640033687317, 0.06225672505435444, 0.06787833186887926, 0.031085243268359094, 0.01635598867470699, 0.0452997901987645, 0.04263516019789442, 0.03321292607354061, 0.0462679069999966, 0.04411655590839444, 0.022185050183907155, 0.14774403985469572, 0.1345418627944685, 0.17912076425648507, 0.21224916401890018, 0.11071108912508335, 0.11995961664304619, 0.10724490132903862, 0.10057840421194993, 0.14308150617345688, 0.09563384292226645, 0.19036750188998638, 0.14593860044354393, 0.16075823426006303, 0.1548940303825563, 0.1987911748789972, 0.17082708106646616, 0.15641715107185228, 0.2132802264344308, 0.13593065762712112, 0.15541952073333726, 0.17940144355018295, 0.13117024855267617, 0.2071840817769689, 0.08414297604993468, 0.26313146756541345, 0.18633962608873847, 0.15552493443171825, 0.14487635824949513, 0.15441177803422176, 0.1506516039972344, 0.20854025658580566, 0.1276983763842333, 0.19767668548851244, 0.13423325193505134, 0.1756194053638366, 0.2302444774296976, 0.139539621229614, 0.19829009208948384, 0.12059924643366568, 0.08803834928379906, 0.15495038381026638, 0.1618175346764826, 0.22134794433030391, 1.2343379013961362, 7.420467859314335, 25.217478736754387, 61.79569867349441, 84.17791566541119, 90.94148605100571, 83.19015302965718, 84.50786544430642, 79.74744950571369, 72.34541923769059, 72.78525029459308, 78.50934551608178, 62.37072206312611, 26.209499105330437, 21.542435576838834, 20.40543656195364, 27.956630645259736, 35.04284343411846, 63.13139907775387, 79.6995730553904, 63.472919848657426, 70.98085018896288, 75.8371602335284, 71.51274711854997, 78.042920789411, 64.28435625568514, 51.60680478618991, 43.21485850118822, 27.725708946104977, 19.0330502294725, 10.436485659691597, 2.7749155894402535, 1.4590653200303356, 0.7715339514036333, 0.6022775497648024, 0.18762178148233122, 0.25496705405173764, 0.4229672553558504, 0.2828592122081788, 0.09920405779754925, 0.15787962824106216, 0.4365046418482258, 0.39175597530218864, 0.17082541099479123, 0.18764032081009882, 0.18430367082117066, 0.31620144243201903, 0.40664363772638384, 0.43962375351017524, 0.48927470861423406, 0.4172564376025431, 0.4886905206066947, 0.8289881555303451, 1.0122843747658115, 1.472663441973348, 2.5637290506593646, 7.247447208050759, 16.253290022573164, 28.64347884731908, 44.75775026505993, 66.83752506009995, 72.08701349073841, 80.8348560333252, 65.60126066207886, 57.42705691245295, 50.67238246240924, 41.99575055030085, 69.20640914670884, 74.73316992482832, 76.31716420573574, 62.53741102833902, 68.15360576875749, 58.891603254502826, 79.66320483915268, 74.8037176747476, 67.44111507169663, 82.91261396100445, 81.41511578713694, 85.9594326634561, 81.57826285208426, 58.93643986794257, 37.62968970883278, 10.511753001520711, 1.802895631520979, 0.66752789361823, 0.11392367117467428, 0.20893471525801768, 0.14218162865408007, 0.15097576644151442, 0.13684135230798877, 0.08767083392388399, 0.13989839552631303, 0.24228491279627049, 0.16495553806664484, 0.14824680803764254, 0.14702973947409662, 0.1075339922681451, 0.10657918624459736, 0.1254576228318676, 0.13784903372007032, 0.14533938179093023, 0.1379663983900701, 0.14588782413592263, 0.13467375249151262, 0.10296135900482055, 0.2292648654791617, 0.15354606803626786, 0.17786408894725386, 0.2701908758571071, 0.09359101584601788, 0.12943764878136496, 0.10467796286027278, 0.0711426554968761, 0.179976315928563, 0.29100193011183895, 0.21170151840534904, 0.11599799212549003, 0.1643922489376799, 0.12165456319287901, 0.12422892505363112, 0.09136980519660058, 0.18757151079273995, 0.10883808075901001, 0.20020518932611714, 0.10932666099359913, 0.12475115953073387, 0.11059180157439363, 0.11391435554551502, 0.15884811659493756, 0.09705509690027084, 0.20201442853337337, 0.17087146820079896, 0.08094938531998666], [0.027240966183824405, 0.010734385690621791, 0.030476883271588918, 0.10436691584125643, 0.02509406797828213, 0.049773736015683225, 0.038436561702720584, 0.018166509164016575, 0.03109587656874811, 0.0113758789901171, 0.05059512399677789, 0.05998613620777765, 0.04631940343026673, 0.06545632191362881, 0.06517859971931865, 0.03568712193819304, 0.009555682810323854, 0.027874093803186572, 0.03295300010171148, 0.0178095524109179, 0.05262057619890379, 0.051519068168295976, 0.04135929055572037, 0.10289650200115097, 0.02128179421678426, 0.07583463759792429, 0.08873703679250133, 0.06486858691900008, 0.049347618760000315, 0.06855356176534007, 0.06956648321882372, 0.014455677892622209, 0.04472033278415761, 0.05160841317246518, 0.040778526961202585, 0.05158926097435817, 0.042189871591906396, 0.03789369264737733, 0.04222754396558289, 0.013807320445325347, 0.0740477604971778, 0.06263824833196498, 2.7258467385845804, 12.951003428428406, 39.61069845384167, 65.27472726760372, 75.88679390568888, 70.76181719380041, 63.135501876954116, 59.09790815845613, 48.85468159952472, 32.851862369045136, 29.845171474641372, 32.92492828061504, 91.3939549846034, 56.68473659023162, 19.677123023617654, 27.578853445668376, 50.65243328771284, 62.940662061014486, 42.68156128544962, 50.88588491562874, 75.58539113690777, 65.1414765081098, 57.70501175234395, 41.18234903581681, 40.797172284895375, 33.24913570957799, 21.906229526765888, 12.140746674230023, 4.558647746039975, 0.7462309252831244, 0.1837680681097892, 0.11047164068347025, 0.04054136912248308, 0.03129418608882735, 0.07297144526795996, 0.07655906566088239, 0.08188870104570543, 0.08420324418693782, 0.005952845038395496, 0.018524733792629935, 0.16852627388171612, 0.14923660895757138, 0.06739748146144614, 0.03751079041150309, 0.0130771036304894, 0.057744804259029135, 0.08615384959886152, 0.1983565425560359, 0.10439048836668653, 0.10006448178882561, 0.15503445429907692, 0.1028665479633116, 0.027650842375512567, 0.01731837130782585, 0.019960160397233504, 0.06521562474869913, 0.08256747792925566, 0.2288848552252016, 0.28927758876835147, 0.6161395736759709, 3.246964994938143, 8.289780309123378, 17.27329061877343, 26.97035066543087, 41.059065018930745, 40.03291806867046, 51.50333658341439, 55.32197967652352, 35.43094627318844, 33.62424373626709, 25.09327100169274, 21.60076906604152, 16.435347814713758, 17.256528369842037, 27.73766629157528, 23.828934200348396, 27.60977545092183, 43.7323328756517, 47.98813589157597, 58.05494208489695, 67.28465957026329, 68.02939999488093, 66.50288412647863, 37.186328518775206, 15.962766928057517, 2.8406971693038945, 0.4856333088490271, 0.31002928653071005, 0.1943286514330295, 0.06371918690180586, 0.06340597568440341, 0.1074586092163959, 0.008544564536291986, 0.07997394088775882, 0.03571126136868712, 0.03993117242991444, 0.08324299127824845, 0.03631759314767776, 0.08437878557390745, 0.032294819492005536, 0.0053544518455202065, 0.06019131370609807, 0.0446033894625162, 0.011832531552851923, 0.017436735722566807, 0.022511627720368486, 0.01925307273444149, 0.055541638810668266, 0.016042867472635645, 0.043953179997662385, 0.05015811680125133, 0.021065345649877866, 0.02017787300921496, 0.06838025735510934, 0.04758999472664249, 0.015960788812428232, 0.02252004511143652, 0.015841329849565464, 0.006760832705279633, 0.053314176883788846, 0.04267952051914988, 0.0590845349905712, 0.016915910847244725, 0.07900316959186908, 0.008709609561089066, 0.0364136912168995, 0.02265123766846955, 0.04816444192622458, 0.04676746144410103, 0.05227660272090186, 0.009812915025489225, 0.05006421740437227, 0.031299248014787034, 0.009181174025270007, 0.042968236075173465, 0.05313318861167758, 0.04299991381084246, 0.06075566769727777, 0.036074210844573476, 0.045589582108321695, 0.024834975127070665, 0.09620067903832083, 0.05172716063116828, 0.02808800470384379, 0.023406096658999884, 0.046913450989391536, 0.027525736387037945, 0.027584571939622684, 0.025963045341233094, 0.045502761363862984, 0.0072877101540084815, 0.013038404698994373, 0.030541587057673646, 0.024164531364916794, 0.08495656142552054, 0.0886051624172157, 0.037013618500843164, 0.06165579419522997, 0.07142580159369015, 0.060309172502809, 0.01802434622790785, 0.04971534862453419, 0.05783808312468952, 0.07727156573485944, 0.06324015212275329, 0.046287741016356215, 0.061654239036743684, 0.04725821353795548, 0.07018614109725722, 0.03487028068892899, 0.0579546434023688, 0.039881771250117215, 0.04765748324233198, 0.05020020184137168, 0.050197811647047924, 0.0868554559025553, 3.4576389289671376, 17.41473520955732, 48.48458243954567, 75.27966591619676, 85.80081201368763, 81.69305493754726, 72.29663279748732, 69.37944058449038, 58.084293180896395, 45.207830475222686, 41.40287645401494, 47.033701635176136, 95.72680904019265, 65.93892574310303, 19.081516996506725, 24.523744813857544, 39.91400749452653, 46.549292841265284, 42.5045721761642, 43.726923927184075, 60.77107752523115, 54.49906249200144, 45.161067978028335, 36.131316846416844, 37.11297627418272, 24.661378822019024, 18.02850965530642, 8.850555689104143, 4.293952968812758, 1.3505095579931814, 0.19191369714756168, 0.03385290826460527, 0.09715674144606437, 0.038411468492760774, 0.06206445613755815, 0.0800640864538089, 0.08181131084359462, 0.1453979721953792, 0.04953303502031392, 0.03098629726727884, 0.06160899388393568, 0.04674495378088567, 0.016792787111274177, 0.08910855113138115, 0.13106990635635393, 0.05779254685847029, 0.04354086764637501, 0.25452013367847093, 0.2672840318372173, 0.10176376439630987, 0.386377762282087, 0.33732705238846045, 0.1864060305900151, 0.0686283932337838, 0.047939411259346434, 0.09755127672706881, 0.058812688690640276, 0.10846770023025813, 0.1629103744222272, 0.47051968113068615, 1.979832646827544, 5.864974010375239, 13.098714005562568, 21.22162295926002, 29.874783408257272, 33.50257181352185, 42.47150659561157, 49.998115262677594, 41.71860764103551, 41.01084732240246, 34.83853501658286, 24.64691115963844, 24.40802901021896, 25.98542586449654, 43.33835040369342, 34.87120051537791, 37.833135204930464, 52.23788669032436, 59.56062232294391, 67.68212902930476, 77.82684526135846, 79.0633410792197, 77.79356002807617, 46.05407399515952, 22.745034271670928, 5.21429741574872, 0.23576996319236296, 0.38152965146207046, 0.12267896064346838, 0.06396639964453156, 0.04201394333053501, 0.03461285216373301, 0.10522360132346231, 0.048209629622438264, 0.04580479152801056, 0.04142612789667422, 0.04616812404785906, 0.018887788605605884, 0.03158979452094965, 0.04409995861351491, 0.027019742973929933, 0.014013113686814906, 0.051178637846943834, 0.011408946217758762, 0.02890832207706427, 0.04464466627987643, 0.008621104380806849, 0.02309118281118572, 0.02114009284864991, 0.032194205334470156, 0.029128545542217554, 0.02937785162019634, 0.04042113545320688, 0.03645841926035862, 0.021417405185920578, 0.06166599082550215, 0.0748589173740437, 0.014327451053466049, 0.036818867459172205, 0.03939907074034695, 0.02853057561292043, 0.015312092371224878, 0.03132332807346698, 0.08138417852141204, 0.036859473949598695, 0.022198221150545344, 0.04439228627410147, 0.04324177925985667, 0.03667182837342543, 0.022202017116210154, 0.11954919269849217, 0.05932933838677503, 0.024324827602193243, 0.04834775527518603, 0.131900820640787, 0.15622570569957459, 0.17797964564975233, 0.1710968359463638, 0.1549184226220654, 0.1381430276218922, 0.10928579020283877, 0.1068171178321204, 0.17785325646400454, 0.10412889998406173, 0.13562532562401988, 0.12768747495307078, 0.14672479051495754, 0.21506882723300688, 0.16355424067906796, 0.1804191300705556, 0.11192791254049349, 0.17501981898901925, 0.11304630897939207, 0.13023264886390779, 0.1953708987322546, 0.2416594786148879, 0.15947925047047679, 0.20433319281906853, 0.15263198724677488, 0.11745521393153938, 0.17292990048806514, 0.1731240578115948, 0.27072064097850557, 0.13493981482761522, 0.15024686442507854, 0.09733901674588842, 0.15976529237964462, 0.1252131488534712, 0.11270340036360488, 0.19334802824643352, 0.16236015475325047, 0.16560234610111485, 0.0895535409630787, 0.16044519541244354, 0.2580133873608805, 0.18407389040916197, 4.909369416775243, 23.788827965336463, 62.48458846922844, 88.93891211478942, 97.4742014177384, 89.17483483591388, 80.9181671757852, 79.18702125549316, 65.65551488630234, 50.75561515746578, 43.77551424887873, 47.25020862394764, 98.33499693101453, 66.8592942145563, 32.58795745911137, 41.59921461536039, 70.97294269069549, 82.10731998566659, 57.41608996545115, 66.25606506101548, 100.8626820964198, 79.2392986051498, 71.83122788706135, 53.40253253136912, 53.799193982155096, 43.31225879730717, 30.150455428707986, 16.924727232225482, 7.0098903294532535, 1.417471771278689, 0.41272481302580527, 0.2641674942306934, 0.2914712968612871, 0.29114607721567154, 0.2546042348107984, 0.1267492700548422, 0.2291901106195104, 0.32465344535246976, 0.09967883312774282, 0.13242562151243611, 0.5534067786028308, 0.21933569182311335, 0.22508049323674173, 0.21447081899931356, 0.249169867545847, 0.21354731532835194, 0.3585530811500165, 0.3740432564048998, 0.4907703880340823, 0.28309761877021483, 0.7852949129958308, 0.9743989367158183, 0.5069895419141939, 0.10658899217002815, 0.13240145909930431, 0.3001298677296408, 0.3880458421284153, 0.2946107558185055, 0.561737034830355, 1.1327855313016524, 4.349580022596545, 11.331617601456182, 22.509839150213427, 36.069680721529075, 51.16226296271048, 51.313988085716005, 66.22418403625488, 71.23501977612896, 47.80340794594058, 45.14433122450306, 38.13677372470979, 34.0314563628166, 28.680741363956084, 30.12001391380064, 42.66805264257616, 39.38891587718841, 44.34774098857757, 62.86154785463887, 68.57468005149596, 77.93532233084403, 88.71134404213198, 90.65127772669639, 87.07247580251386, 57.09474978908416, 28.524238794080674, 7.636564470106556, 0.7566424891833337, 0.5926141166879285, 0.328002781757424, 0.10770599432890454, 0.15511863204019685, 0.2077443525195122, 0.1171913579286587, 0.1887744680167206, 0.16425646751398043, 0.1423120168187926, 0.16970880720163548, 0.137087052027064, 0.19260866146895195, 0.19767789590743282, 0.1990552147429797, 0.16096846410824409, 0.161528060693414, 0.1380987477398688, 0.09217874041848606, 0.1466451939796248, 0.13233326195228484, 0.19890248745439515, 0.1467287894939223, 0.14155239467659306, 0.144297257065773, 0.11163618625892748, 0.2190354006785539, 0.0923714115314426, 0.1786854884196674, 0.14065240990490685, 0.18192895147348606, 0.1495909093007926, 0.16778332181274894, 0.15554165047022606, 0.14923789598528417, 0.15739144637219368, 0.1480530490798335, 0.23528417151781822, 0.20970386753399528, 0.11610042574184558, 0.12521698695397185, 0.0883992916093238, 0.0975373875530016, 0.15149183391082674, 0.16933607478295604, 0.15689126756643096, 0.10091234193814379, 0.09132306617234023], [0.021595928570135467, 0.01210898491403749, 0.03783927359167607, 0.05318527492964941, 0.03309407902340735, 0.0580069748684764, 0.023790691949186787, 0.033724125054094105, 0.013180417290347959, 0.010709925460809422, 0.024245953104729136, 0.04594143863106447, 0.030858383566561728, 0.018925974258191643, 0.05733082183606683, 0.020786267479941733, 0.06382754620825572, 0.08872192187775528, 0.032241618516103875, 0.05867324536666275, 0.03865290493253739, 0.03054058539771265, 0.08564865291719476, 0.0373159819132378, 0.0237606268285984, 0.05499065688420689, 0.10499840977812007, 0.05016947788516841, 0.06088432067284181, 0.03098998598063425, 0.06898296170777853, 0.07128937665613429, 0.0406637899727831, 0.06308832881791938, 0.07705863925718492, 0.025616448012090502, 0.08279524353002349, 0.026944110943605343, 0.04071913982531236, 0.1431885899435128, 0.41465017584062397, 7.7171024968547215, 26.67611602813967, 46.51505054966096, 75.62110039495653, 71.96370201726114, 58.95442393518264, 56.01324250621181, 47.88516190744216, 34.22604906943537, 29.06259390615648, 16.15644866420377, 23.69565990663344, 18.767721499166182, 21.138498129383212, 25.22921250712487, 49.5435360939272, 49.26358084524832, 44.24550048766598, 57.41739219234836, 49.41456856266145, 54.76762717769992, 27.90506716697447, 25.20011636518663, 22.832636487099435, 14.82389105904487, 10.348242136739916, 4.843985957484092, 2.6873334761588805, 0.6894117774021241, 0.08341376759832905, 0.0218704427712627, 0.05488749548432328, 0.06951357718677291, 0.03372950299132255, 0.07554249762887917, 0.043785778294888236, 0.07453818700366444, 0.08842920734276695, 0.18981726689925119, 0.1250389174768521, 0.05420365859003318, 0.10885913285516924, 0.13871109713950466, 0.05773032902769985, 0.05000417143286717, 0.046373186632990844, 0.06947909556930104, 0.05983293394468004, 0.12998342514038086, 0.0450739091742904, 0.11524981533687924, 0.231533435684058, 0.5883212663954305, 0.14717426962189137, 0.17384856248334532, 0.05542597102542078, 0.024167978760576057, 0.03772922506135318, 0.017635794093592033, 0.055945501212150826, 0.04839992586282953, 0.03592822129928297, 0.13053220456405995, 0.6726064436858701, 1.4729054031833526, 3.954550522950388, 11.70756011239944, 20.339730978012085, 21.13589171440371, 30.500426946147797, 52.229108425878714, 65.53824386289044, 60.886108875274665, 48.51835404672931, 43.15486584940265, 23.34668859358757, 20.81387100681182, 17.558784254135624, 22.971802180813206, 29.676578198709798, 47.10644199002174, 54.40799290134061, 61.80193131969821, 69.29858484575826, 66.82306720364478, 63.65649069509199, 44.51430836031514, 18.96611302129684, 11.375481467093191, 2.7080882076294195, 0.18074465615134086, 0.015602632174118152, 0.019729719234390125, 0.03331890284654594, 0.04714855571247397, 0.06753135532621415, 0.08653399774864798, 0.07551888679905285, 0.09949163188256564, 0.013716240252007642, 0.08184767703736022, 0.10381007717261392, 0.016919890674011364, 0.02392724137603035, 0.0303995639326111, 0.030612264414347952, 0.04250436983702164, 0.03883256021166041, 0.04898636999930586, 0.045327557055580045, 0.049156215522558465, 0.05117562329096179, 0.014761673519387843, 0.0465304070272513, 0.032145428516331224, 0.04595232091002888, 0.03315328229819575, 0.02435021767122371, 0.03121035500249315, 0.058450719807297, 0.02299820463503561, 0.05091550962759122, 0.13084403299275907, 0.012068749976254279, 0.03736781925263424, 0.031575123937199676, 0.05198830085235739, 0.003801119521320347, 0.03794790485933904, 0.00868989428835771, 0.05188330467189512, 0.04515909432103077, 0.03582793655955503, 0.04244990864648454, 0.05192238664735229, 0.02612413256429136, 0.022517963267502286, 0.031118889849993493, 0.04061476034562915, 0.02023003976641884, 0.04454143976251926, 0.04367594043874452, 0.010530888797685264, 0.037211338133220716, 0.04752609150243863, 0.1289099367756036, 0.06626925611447904, 0.0430298984921988, 0.0027805594530241986, 0.03484148344385528, 0.01007760031854794, 0.08697435274840364, 0.07334135082219878, 0.023413146583123073, 0.059095788822178884, 0.053828903699233654, 0.040534386231053265, 0.018146081429515636, 0.0784547808730314, 0.02788650825799954, 0.03407340369097168, 0.03736947017211107, 0.03975937721289454, 0.012169735686432932, 0.07578700991167177, 0.04505433179738541, 0.025117768823439558, 0.051139368179945216, 0.053566204489118634, 0.08017143069375908, 0.01839241700156802, 0.08185513107286346, 0.04082705097032651, 0.025731635077165502, 0.09506863857349081, 0.5278782774844478, 8.845820407713614, 32.198360197005734, 56.33119375474992, 85.31650127903109, 79.99240936771517, 67.23923067892751, 64.25188295302853, 56.819211129219305, 43.87832741583548, 42.86679521683724, 28.374245397506225, 33.45243215560913, 25.419878921201153, 40.35880819443734, 38.88862148407967, 48.8425693204326, 46.188254356384284, 41.86909329506659, 47.58991725983159, 38.30833427367672, 38.484162361391135, 25.386060245575447, 22.17453141366282, 21.793469229052146, 13.927622610522857, 8.743023910830098, 5.1805160026396475, 2.143546126542553, 0.6984977027581585, 0.01728687743325868, 0.07572344759659422, 0.02942554825436204, 0.05850508906728318, 0.028801056361126325, 0.040551378061213804, 0.09210353356695945, 0.20471884148015132, 0.11520535925463324, 0.28841371738141586, 0.12570781182617913, 0.15884482241686315, 0.12553505133837461, 0.14625026033289973, 0.10952940616275995, 0.06516821156706541, 0.06223727025151734, 0.09088994304258978, 0.1369399937891191, 0.3193412078244071, 0.06596780817715392, 0.11911112064075087, 0.20750833615179987, 0.618301964094562, 0.43161638802097696, 0.2198344916706124, 0.3568127438906701, 0.024732821132807482, 0.037006516865785086, 0.08509362221605356, 0.05035781294047352, 0.0707056406404703, 0.023507101521376642, 0.09005014979911428, 0.3906551375985146, 0.8547854002925658, 2.8559147398318014, 7.428930863257378, 14.455439294538191, 20.034390149577973, 30.34912543912088, 47.91048472927463, 62.90665903399068, 57.280046478394546, 47.27526864697857, 41.30351105043965, 24.45830595108771, 26.403124947701734, 22.62482343181487, 32.64089180577186, 41.403041193562174, 56.35681075434531, 63.62854380761424, 71.44188557901691, 80.0415409764936, 78.67208465453118, 74.54521779091128, 58.16434875611336, 27.35522931621921, 16.86462083170491, 3.8851179519007286, 0.2487126969161534, 0.03935051608770605, 0.04509251361953155, 0.02615641933986016, 0.029326110041790435, 0.0708700277872624, 0.05232178658667592, 0.05328972335724581, 0.08421915583312513, 0.037122510238400394, 0.015429548014165654, 0.09121056616065965, 0.052078500044562166, 0.11109363513007281, 0.011557311593224446, 0.060960079107673905, 0.08056472491232619, 0.05538899579175538, 0.06290242992221348, 0.0718220912160412, 0.07594261002997238, 0.024591424284623038, 0.008984161109002608, 0.044214220627421336, 0.04534521538223471, 0.02083616661688974, 0.05699726715383511, 0.05379929057052059, 0.04466194156256895, 0.04029221051642972, 0.038698808920960275, 0.01766221646610047, 0.05741144875965773, 0.04653648593493047, 0.08006323609621295, 0.013782148711353302, 0.07705297786742449, 0.04969213999086811, 0.00422418104379528, 0.017408687328439088, 0.030020321681795102, 0.009518887607320663, 0.050880947570887305, 0.040735691154916445, 0.00804997051149727, 0.13217865008740656, 0.13560834911561784, 0.11873253531032994, 0.2351800601689085, 0.1334132620644185, 0.18336031015121168, 0.08825401069536325, 0.09185509125311529, 0.09029749660722672, 0.16681904694245708, 0.20249836627514134, 0.16051756007777107, 0.11142982515476405, 0.10339527886601226, 0.22423414994151364, 0.08335415829694079, 0.17385853694811945, 0.2304871434405927, 0.09714796973933136, 0.0992142161234252, 0.27530025330282026, 0.12066506104724062, 0.13851189895743324, 0.1496796376041828, 0.20701079268849668, 0.14096033128519214, 0.23278218964415215, 0.10278898922185745, 0.1500959144604783, 0.0983337972373251, 0.15795505725808684, 0.22186076358681728, 0.09238229764084663, 0.11728934823505341, 0.17701711745992785, 0.08264678335117717, 0.21505611017346385, 0.07863078957363483, 0.11740122771551532, 0.281802715673562, 1.1583394052520877, 14.510076930446012, 42.70760190102362, 66.25136606154904, 94.40319738080426, 88.17887444649973, 78.45906857521304, 74.83812470589915, 66.67020459328928, 51.68152986034271, 45.21375325418288, 28.315515748916138, 34.53812852982552, 30.454972559405913, 32.581626753653254, 35.07752503118208, 68.05788424707228, 68.7369171265633, 62.59667411927254, 74.50781406894808, 64.61430211221018, 67.31375571220153, 35.86651763608379, 31.48000163416709, 31.781690735970777, 19.887728806464903, 13.302338950095638, 7.580076946366218, 4.3898053996024595, 1.3305054701143697, 0.17566215307001146, 0.31558976718975656, 0.2128084235253834, 0.2374496262881064, 0.12719660411558806, 0.17788589180957887, 0.14887072536493504, 0.47147879256836833, 0.1726413304887472, 0.3916930028748128, 0.3029907464740738, 0.29253882506201345, 0.2472658326188403, 0.36053479739254524, 0.355342437302874, 0.3530921612776095, 0.0997512054539496, 0.3061489286201616, 0.22399379751614987, 0.5158981945245497, 0.5181802785204304, 0.3463490553680928, 0.8149069078987645, 1.966964698606922, 1.1909584484754072, 0.9071874077762327, 0.4833403770481387, 0.20528513367377943, 0.12048055643155692, 0.10219058262244349, 0.22382176481187346, 0.23189829271887583, 0.14515899872827917, 0.4096032805260151, 1.272965893149376, 1.9269801796444002, 5.39138654547353, 15.37963305750201, 26.489069961732437, 27.204074898073753, 43.215968531946984, 67.22285086108793, 80.88868664157006, 77.52532482147217, 64.01849408303538, 55.36203884309339, 32.1792386424157, 32.750869181848344, 28.62653224698959, 37.79036175820136, 44.14680188701999, 65.55161522280785, 73.1142508599066, 81.06608759972357, 88.61455563575991, 88.00468198714718, 86.84061665688792, 69.30104024948614, 34.9276904905996, 20.569752493212302, 5.035280931380488, 0.5778071692874355, 0.13414326724746536, 0.1787413515511059, 0.10819008528825738, 0.17051169798979837, 0.20181334577500823, 0.2087710329121159, 0.24133333966376322, 0.3419516493956889, 0.11309977425562759, 0.18689346169271778, 0.213762846504969, 0.19130410566445322, 0.18972486137382447, 0.10050510491935477, 0.23851617389628965, 0.1658405381585321, 0.1180506404489279, 0.19747374879737056, 0.2246263103499528, 0.261996952636588, 0.23060078492328046, 0.17273775031489713, 0.14044815554253517, 0.11251564753512222, 0.16140449071122756, 0.21609587534781427, 0.1596059154478773, 0.21339345422963943, 0.1851171642662056, 0.1488805619338828, 0.08611024387421147, 0.21626403164719382, 0.20070121593533025, 0.16106758056388748, 0.18569136248721232, 0.2248269028120464, 0.09433433563718874, 0.05850423487924761, 0.2710844101684709, 0.12018987969044717, 0.09726847536982068, 0.09948047764238813, 0.1474779928403516, 0.14554047987105387], [0.07940909660030758, 0.01878914712447553, 0.05598410821309494, 0.03254949776155334, 0.011983447043495554, 0.031127117634300264, 0.020846179386060086, 0.011437884231488551, 0.10447777642477905, 0.06641885010345329, 0.10261210718102033, 0.048885924381113825, 0.026574741650913513, 0.025862011750559175, 0.012565367430779002, 0.00462544305557986, 0.07820239320637719, 0.041700046464440324, 0.04095449735740981, 0.07259908823236343, 0.13389877794731048, 0.03684547369278247, 0.06057574428738125, 0.020750232619203387, 0.004835108871526656, 0.0931932017086975, 0.06578046137527113, 0.055210968449471466, 0.031466191980026426, 0.030487223543346893, 0.021949809480218158, 0.10683275368665496, 0.05000651183147585, 0.0443014818724365, 0.04680958095817797, 0.05854479157395902, 0.015230362281023015, 0.0715576070210626, 0.11349133711548583, 2.264234269818952, 13.718421036197295, 40.1998306089832, 58.038942736964074, 66.49259182714647, 63.36159513842676, 63.187147725013, 52.2502774576987, 39.41725107931322, 34.92408975478142, 25.28226060252036, 20.464903616136123, 20.798436480183756, 22.61885358441261, 34.05691254523493, 24.603049255186512, 30.923274140204157, 39.23204852688698, 45.79703323302731, 40.37054784836308, 23.426883412945656, 19.406204915815785, 6.976665892908651, 5.156648870437376, 2.60361538779351, 1.2376904247268554, 0.7219032823078094, 0.4654659216682758, 0.07655151203394898, 0.0756223239905892, 0.04173951148385963, 0.05916606206747313, 0.008390687158211105, 0.045289815733990366, 0.04778430526775699, 0.056183789030558644, 0.0633895239462295, 0.08582662280288436, 0.12238856735489062, 0.16465402118140654, 0.07939631825373059, 0.21909432816168956, 0.1075757287382599, 0.024327508909928224, 0.090387174859643, 0.028679776981833483, 0.01336487211031659, 0.0434023053235104, 0.06746141915960659, 0.12584841194292232, 0.2726809374026714, 0.21985540587094524, 0.15239020989787194, 0.1416600913169884, 0.2840745340912573, 0.11700309182126677, 0.08558171981525037, 0.09372665937389098, 0.1828541252161226, 0.07963782747186, 0.059034723953734485, 0.03436858119863657, 0.041290518842757716, 0.07511648379506604, 0.029268858375989144, 0.05957378938253369, 0.05758735020795177, 0.07954747506207036, 0.2093296948700182, 0.8043092152764721, 3.5863012508038556, 8.832555932383384, 17.269527104593095, 26.75413589323721, 34.4664119135949, 46.19702477608958, 58.72860916199223, 52.187994141732496, 30.504247334695634, 26.875841156128917, 19.258449231424642, 20.228614153400546, 26.83026517591169, 36.53224191358013, 48.96945407313686, 52.97430776780652, 59.417698998605054, 63.09343445685602, 69.29828674562516, 70.30356668656873, 65.72687064447712, 36.21627538434921, 14.251415248840088, 2.1929638231954267, 0.34500671610716854, 0.08306455407892505, 0.07577826884845573, 0.0328912036192994, 0.07935663489925285, 0.029955683013183937, 0.07351769660148891, 0.06787859999965276, 0.04061259614724306, 0.05091333010744664, 0.05621843152649461, 0.02378678873121258, 0.05240272760631577, 0.026638765533965443, 0.04207318874015924, 0.054839779697959466, 0.07603827142907728, 0.06563119680410431, 0.0724438941406627, 0.0470004249514351, 0.02244212439343814, 0.0993366139910875, 0.01284005783212882, 0.045498306562583295, 0.05174244025481805, 0.04818751266406429, 0.028878153534606103, 0.07703937980676852, 0.05540162858162677, 0.08679805293438897, 0.05030555808315835, 0.04577273457881905, 0.02741660524700438, 0.0540728873813585, 0.04639145016910569, 0.06224690380716517, 0.00953666084716397, 0.02763303274649286, 0.0074145460647771205, 0.023011143860076706, 0.06263133055800874, 0.03636425173270606, 0.06308682728558779, 0.044592150952667005, 0.04134324484414632, 0.05694138103975885, 0.016163535896808873, 0.033616573970404365, 0.024559083882899537, 0.0346456905226073, 0.04009448322317293, 0.028987393842168876, 0.030274653296557166, 0.03498775644167777, 0.02233879062377157, 0.11543101045273005, 0.027018302728632287, 0.042741232731890295, 0.06834122517536725, 0.02976011800309343, 0.05938762618649391, 0.031609103767081134, 0.043194427365256895, 0.11886712929774677, 0.02048485593179301, 0.049700946171557715, 0.035138170144731, 0.02611688920296729, 0.09080424078650053, 0.06881940193594464, 0.05371785159372995, 0.05244779272846157, 0.05264032211515212, 0.05244591198260746, 0.07156379701149079, 0.03457375103607774, 0.04631412508446844, 0.05625438403278109, 0.08795135233911776, 0.13047631078910443, 0.04672491292078649, 0.037376008732544805, 3.5720262748579827, 18.332103067828765, 48.08425749501875, 69.02324230440202, 78.17199030230123, 72.78159464559248, 72.47275506296467, 63.04052168323148, 51.37976231113557, 48.74911100633683, 38.370582288311375, 31.52561095453078, 29.239379052192938, 30.796446261867402, 34.715756985449026, 22.188520546882383, 28.05821611035255, 35.48225479741251, 37.06000858737577, 31.7002760594891, 20.92985941517738, 15.28808395708761, 7.273630499839784, 5.4246026469815165, 2.387839921059147, 0.9711941151369003, 0.6623981688772479, 0.5356500249716544, 0.10644040175623472, 0.10606787618129485, 0.09843011747204489, 0.10523125454182587, 0.12097585525724197, 0.15730397445299935, 0.009407928389977784, 0.3231386137345145, 0.17491432868184584, 0.7986841687271673, 0.553042488473077, 0.7214876336436118, 0.5118185618231373, 0.3483982179914752, 0.08985891127057614, 0.19971176741584656, 0.09418997402873733, 0.0687868048947665, 0.026685728638943647, 0.29818394311493446, 0.37865360417673666, 0.9245624044729818, 1.2657465256990925, 1.1812194484856822, 0.6898667723421128, 0.7073635463753055, 1.4049097679315077, 0.6399981256934905, 0.18265314971006688, 0.505069725575947, 0.6008394495133431, 0.12481142000685777, 0.6085147312091244, 0.5766732365854326, 0.020766211298084068, 0.0447226042348531, 0.054019261226658864, 0.013866241225191664, 0.021512620338809588, 0.030561246789030494, 0.26534426656942217, 0.5552795877860439, 2.779222842185728, 7.616208349504779, 18.12275440462174, 24.758279015941007, 30.286328292662102, 39.72707517685429, 43.72538635807653, 43.125381392817346, 29.16354198609629, 28.734487641242247, 25.506784915924076, 28.519251500406575, 40.27444193440099, 45.76966293396489, 58.46142122822424, 59.63407654916087, 67.80857055417954, 72.6254843127343, 79.76575912967806, 82.41991719891949, 79.36146474653675, 45.518827361445275, 18.220001728303973, 3.3413619812457793, 0.3592139698805348, 0.11032366314001622, 0.04385083448141814, 0.020478256084325335, 0.013334281261890166, 0.025690942401847532, 0.08330199537017653, 0.0144053133572602, 0.025685763647479397, 0.09270046161667955, 0.021070909363427953, 0.07419629728481655, 0.05047696259533686, 0.08652111214976158, 0.029724789858465234, 0.02085066483085675, 0.03428187919780612, 0.11769065573330849, 0.08831538199897736, 0.031153202928122015, 0.036074605379854484, 0.06987868703060574, 0.018772078685522563, 0.0064922700497141534, 0.1157583598227751, 0.009630836993305674, 0.0233757461706597, 0.03749082999063596, 0.005896879921502044, 0.0551008164972788, 0.010631986548222843, 0.091204866466503, 0.09091998901098006, 0.05389499793490095, 0.01605017403621347, 0.018275213210032355, 0.03771715151566652, 0.0332048170328621, 0.03400344071128676, 0.025418268726958383, 0.012089704396203162, 0.030745778217791554, 0.018279183460699937, 0.19330564826246233, 0.12173851110762167, 0.15266482177520954, 0.18871843634593874, 0.07474485454299758, 0.0685829182545985, 0.11343857664014063, 0.12530203037444623, 0.28145092809873246, 0.2276603402870317, 0.2376951268243213, 0.1480143003526234, 0.17601444626287108, 0.09607650384667421, 0.2770694873986706, 0.25713088471562634, 0.13539517748980753, 0.14086282361418972, 0.08635022857737157, 0.2681876172221476, 0.3330402695123227, 0.16509398547632081, 0.19382263503728375, 0.164989429796415, 0.11960810485986934, 0.21929538027653772, 0.22719736271087201, 0.2510699034938889, 0.1173636894072256, 0.1490798673682636, 0.14055160805583, 0.20182607815630976, 0.19428460137738338, 0.19576874351309193, 0.12160273734480144, 0.19616353926399063, 0.25080411694943905, 0.2364019397646189, 0.3137064472802224, 6.2595168909718915, 26.926153398329213, 57.53596936502765, 82.41857574832055, 89.22801433071014, 82.89261771786599, 83.93596818370204, 71.86277158798711, 59.34045184043146, 49.84988104912543, 41.073577788568315, 32.888942495469124, 30.09092365541766, 35.08316932186004, 49.45454143708753, 35.6265744855327, 45.40919319275887, 53.08333004674604, 56.73757091645272, 50.22722874918292, 30.881063553594778, 24.537882997143655, 9.343450530882805, 7.30380186150151, 4.042981093929661, 2.2065795958042145, 1.1034425251906919, 0.8915580496672662, 0.23394967699723862, 0.16002176329493523, 0.1020137618686403, 0.19036215459627492, 0.21896389403170158, 0.23863130158955054, 0.15220365216655118, 0.22758475805242218, 0.21941001767352705, 0.6062860895068415, 0.8692492628770491, 0.8734277515642105, 1.138307493059866, 0.5908890092565168, 0.28721123513194824, 0.5509429785513109, 0.5319923534989357, 0.2509127175735851, 0.1532354347047306, 0.28102191886113537, 0.27519404287299803, 0.8257810663311713, 1.6258364098687328, 0.8006412475820511, 0.5367031200758873, 0.7208157438905008, 2.0148163889684985, 1.144304919627405, 0.22285488524263908, 0.43165585687083585, 0.3917040958279564, 0.14298925386561503, 0.38767389111941863, 0.37783474811623174, 0.17212175433674168, 0.14043171529568013, 0.2152519528904269, 0.20117556225628624, 0.2653611205037563, 0.25120170126038216, 0.41321777528332126, 1.5118465716800384, 5.3061990391823555, 11.431353669012747, 21.5807375215715, 35.4384183883667, 47.07665551093317, 62.841390794323345, 77.69623033462032, 73.6084851910991, 47.27288776828397, 40.72208243031656, 33.456389827113, 32.44139809762278, 40.393148545295965, 52.776608544011275, 67.52592455956244, 71.21860073458764, 81.35047512669718, 83.14279433219664, 90.73574204598704, 91.64668113954606, 89.36087285318683, 54.86703964971728, 24.347685306302964, 5.290137913919264, 0.6364130793559937, 0.2385561636859371, 0.2135590671171104, 0.17135836304195468, 0.12956321059215453, 0.09558036232427244, 0.1431275020924307, 0.21028168169000458, 0.16979981844703998, 0.19287388110833784, 0.15266733454360118, 0.14382557673079355, 0.23622360981760487, 0.14296290044101978, 0.12748603213338122, 0.14059522910223854, 0.17940643844344925, 0.15816502663637363, 0.17233242851591882, 0.15832844851238115, 0.08008908390277818, 0.290434350890498, 0.12322348061828844, 0.09921345003550092, 0.16061263158917427, 0.150702579487716, 0.09113685318058537, 0.13246547340625717, 0.21411906206800094, 0.1554301540337263, 0.11463346695827861, 0.17750713793981462, 0.1686865547972341, 0.15048323319323603, 0.1365860152028261, 0.08999375040612875, 0.18125062658181115, 0.1268110856894524, 0.10031984953750527, 0.13590018264949322, 0.11473140363851864, 0.15624220723346358, 0.10726897181161951], [0.033129759568480716, 0.027738888860650124, 0.06833664396958006, 0.039820262050676736, 0.02377234414340027, 0.015363691265754884, 0.009983263293942137, 0.011786206216070683, 0.058781428472890015, 0.04192295506776821, 0.016294567575377804, 0.022455548169091347, 0.025143248907801126, 0.041386570946704, 0.05385747111793007, 0.036676168261516484, 0.019466627404213916, 0.06352471548222727, 0.02264629448613813, 0.05591570422233594, 0.12071398342208517, 0.05925078373101931, 0.04591236942477765, 0.01898002367646944, 0.0492235699728612, 0.02200176173280324, 0.04823911634664382, 0.04692837821259614, 0.02575036784213397, 0.0424997273442005, 0.04234650209846516, 0.015242101620852709, 0.00880382496923689, 0.02714657649067381, 0.029212210004428224, 0.05441132204366788, 0.07946979374654832, 0.9072077550715016, 3.2921622212856048, 27.043746056095248, 61.30140550674931, 63.59020656155002, 60.77048524733513, 56.57260387174545, 53.63201079830047, 53.36316762431976, 33.333972654035016, 20.103812179257794, 17.018179662765995, 18.454506512611143, 18.98890003081291, 29.242569900328114, 54.309561021866344, 50.031981006745376, 73.29575461726036, 51.880460708372055, 37.33120910583004, 16.07048599950729, 6.822482914693895, 2.476230532892289, 0.19431040321867313, 0.22919314432769056, 0.018041763236866366, 0.02770844835697884, 0.0044912531795430815, 0.14272355925171606, 0.08429718188821309, 0.07215053609181797, 0.07006096233042979, 0.07904289891162226, 0.09475788266788568, 0.02823583286015257, 0.14813699699457616, 0.03031764998130741, 0.05306299963605501, 0.23262953896436, 0.23374603550520637, 0.525400381415121, 0.2662685056847911, 0.5824020420832019, 0.15182515876668115, 0.1172943048239235, 0.055449106880734046, 0.08891783354263152, 0.2537280906953158, 0.05212035908874485, 0.13060495227334962, 0.5208240785906392, 0.5127885823528613, 0.39350670071378835, 0.054879589456944704, 0.2804379760017318, 0.09202962140402488, 0.1621144090688998, 0.3332322205026304, 0.00394103997443322, 0.6884354136643872, 0.15496420403642042, 0.1086622022933537, 0.6065832090473945, 0.5625065548285362, 0.04466371505611366, 0.037952321356222514, 0.02446977526790673, 0.025061059164844697, 0.06211570358925289, 0.06664232561184515, 0.03363289164319154, 0.05485608587942777, 0.03416261079931452, 0.06706417958822943, 0.11073692927076934, 3.5519579581675993, 16.252181952999486, 22.6664182063072, 32.18643619168189, 39.489881607794, 52.92500749711068, 49.744989025977354, 37.53863580765263, 20.923852305258475, 16.099134010653344, 22.738319173935924, 26.24513972190119, 35.19183074274371, 43.43576246692289, 55.74897673822219, 66.18369733133625, 69.9451954134049, 70.08452584666591, 71.00774195886427, 52.6700024450979, 31.612097255645264, 10.241106517853277, 0.7641116012969326, 0.22512625932933825, 0.05473251972768096, 0.08590448797950823, 0.0810927510141365, 0.1086234535661436, 0.09522263756802968, 0.02829125549103464, 0.02018189114037781, 0.047729495507214344, 0.039354672114695274, 0.02766188170250145, 0.022606973108204625, 0.09445503278965912, 0.03630456199208575, 0.0906201651800544, 0.03666477270364281, 0.04477421174787226, 0.06229039078818695, 0.06949935093401902, 0.024482735560365745, 0.07416594488125655, 0.046528974442832896, 0.01879400795235509, 0.051242552562466556, 0.018978388078751105, 0.06639228983511848, 0.09499963703415087, 0.01556376949132931, 0.05333727826514552, 0.018244043007613193, 0.053971468831502625, 0.022820125581816803, 0.016022987491000566, 0.03937671246427683, 0.007698348603181302, 0.041650185631888534, 0.029217262354288853, 0.012157941762838635, 0.04878884954978863, 0.04560806397949496, 0.034435962462016655, 0.0532445663045491, 0.03738985577177617, 0.06349299561172243, 0.06389197803312732, 0.04632655869147951, 0.0271391473530281, 0.03453994357597924, 0.0218969838873994, 0.08611831844093339, 0.014652679317570744, 0.018299094085851987, 0.0686861332806368, 0.0016337497706239623, 0.022762917966071158, 0.004359690027476679, 0.03748731747750313, 0.01076457242766816, 0.03003852393087601, 0.06956987698832828, 0.031595754685000546, 0.12648344520599614, 0.05800061633870487, 0.008181851590052247, 0.03197086006102543, 0.07987350676088564, 0.04062453945798259, 0.02661089717049993, 0.054173340660429774, 0.033821839568836075, 0.036479241530140566, 0.06052446619216954, 0.018129800145904866, 0.028165239773149935, 0.03530830295095521, 0.026927402565976786, 0.23525706732705717, 0.050512401822714076, 1.147039179359713, 5.200636290734814, 33.76428411852929, 72.32197915354084, 76.00815203882034, 72.73454973774572, 66.45029298720821, 63.286116969200876, 63.433523562646684, 46.316296208289366, 33.7867828338377, 28.868785673572173, 27.415114102825044, 26.923462652391006, 29.864997094677342, 47.530822830815474, 44.15384646384947, 55.384812124313854, 42.650907962552964, 26.43546488977248, 12.092910428201, 5.742088114061664, 1.934068270267979, 0.3221868873844224, 0.08476373709497914, 0.06047600730051918, 0.02592007355434039, 0.08050920652045358, 0.058612153685141, 0.05322087886593035, 0.18562449833318112, 0.34348747182276945, 0.32021608023393544, 0.544189453846024, 0.4471821608322282, 0.5272986247174202, 0.1431038606190874, 0.4560799043505423, 1.5618077617499138, 1.8642036256290253, 1.1534521320173818, 1.2516190063568855, 1.6886992560278986, 0.9504078821309152, 0.9903221661525389, 0.240405683796252, 0.3215345481951391, 0.43671295647659614, 0.24578401939042155, 0.6153395327348864, 2.002069176204743, 2.628167954183394, 2.5052671038335372, 1.5025367035019783, 1.8286834993670065, 1.0287026195756852, 2.2530214392369796, 1.4732655257947984, 1.7600404278885935, 1.9578142992911802, 1.1709777722435615, 0.37741499322076, 2.3944643139839172, 2.7801024336968703, 0.37046087605337946, 0.052556925783714945, 0.23875936084697325, 0.2211373620816777, 0.13416120902665202, 0.04407416060266476, 0.0767637413716124, 0.005840815691983388, 0.06203453657367538, 0.04831403974563845, 0.1430443049438538, 1.9518431035741686, 11.29076611611151, 18.787168610480524, 32.149995411595995, 35.19426261225055, 47.27293875909621, 40.31622694384667, 34.098273938702, 23.177126492223433, 18.49091591373567, 32.852486025902536, 38.06444914110246, 45.80543494993641, 53.40605481978386, 65.80170162262456, 77.96359477504608, 77.13970876509144, 79.13155894125663, 82.06524864319833, 65.65483631626253, 39.868770799329205, 14.924865614983345, 1.8492890581969295, 0.17489399670833544, 0.10478942865325559, 0.024190563032583847, 0.04179681103015619, 0.10700938291847707, 0.06249868243391957, 0.03817610713022371, 0.037360606534827145, 0.041936085814790386, 0.02703336784766326, 0.10355913741213661, 0.030221268459553682, 0.047273274826546835, 0.048400523411410476, 0.05568923331016014, 0.01791870461836938, 0.020175184040600737, 0.022913674493470503, 0.04050796768898445, 0.06542681220678553, 0.04835703259994907, 0.03834013804613102, 0.024913851539754582, 0.02575044253570659, 0.036424588817622394, 0.1426494019406457, 0.05883443026593136, 0.0472185033704004, 0.0410992305185045, 0.046544081696699706, 0.05440661443337318, 0.08424940864525496, 0.03250223013662523, 0.0225255360466338, 0.017816102462670496, 0.010008920536136195, 0.0741454060640066, 0.12620927765965462, 0.05896031766408875, 0.04928691778331996, 0.024247812783165325, 0.12946099914129705, 0.07678857028123832, 0.14202874814791067, 0.14925453541499956, 0.10451870850257336, 0.07096657784835947, 0.12562420865100238, 0.08780263169037719, 0.22880859883321872, 0.11722886559343147, 0.13560321632652514, 0.10460964313918546, 0.09513833725284185, 0.12001170296101801, 0.15478464834872754, 0.10270796776298555, 0.08319260567546853, 0.10602518210127469, 0.15474844303342605, 0.10237687988387001, 0.26050810672102437, 0.27273103955291933, 0.13756300713266098, 0.12591660142906252, 0.30469054236046733, 0.08417758024147443, 0.12677075882111827, 0.17991677557508792, 0.11244035641392393, 0.21308128872225363, 0.15452529694284164, 0.08061711000458849, 0.15099000035514756, 0.10153234455614321, 0.13724895704898143, 0.35892641111727686, 0.15411268198682418, 1.6375356143520725, 9.345346996861121, 42.92653291456161, 83.39238259100145, 86.0235163473314, 83.23609967385569, 78.4818418564335, 73.80220320916945, 72.60872794735816, 47.78381570692986, 33.59527703254454, 27.77090837878566, 27.683727818150675, 30.206510020840554, 39.51159977143811, 67.61027905248827, 65.33155456666024, 93.19267549822408, 64.46280448667466, 48.32632264783306, 20.773778500095492, 9.028879384840689, 3.547916691149435, 0.5367294122134486, 0.41685488495615225, 0.21954981339794977, 0.07264388139329611, 0.20607674764769696, 0.2988572424698261, 0.21823039548772, 0.12719205355331784, 0.3390146521550994, 0.32638060589951856, 0.43071108659909624, 0.3037127383774327, 0.3102826777725451, 0.31696514016197574, 0.30931903109435116, 0.786298733324774, 1.5657774455124334, 1.4065037211102824, 0.9750153004161775, 2.363694545722777, 1.3073409324692142, 1.248558454455868, 0.17621326140098034, 0.5074708289917439, 0.98215677204632, 0.2763479245045493, 0.4016376515069316, 1.841275288212684, 1.3729100914732104, 1.431570853437147, 1.3633702743437983, 0.7576456966419375, 0.3969806949457815, 1.0728615209940942, 1.0343587999382327, 1.0975419321367819, 1.2966293072508228, 0.8163026588097696, 0.3415817821458463, 1.1004306351946247, 0.7607646550863021, 0.23223483514401222, 0.23220751644863238, 0.25052709955601926, 0.14254964197114592, 0.2666715905070305, 0.1450381253755862, 0.16074288185806046, 0.20673660982039668, 0.22170593721732018, 0.30146230913458333, 0.36010465434482025, 5.243320993838772, 20.43246561481107, 30.976483052776707, 44.486879225700136, 53.52859750870736, 70.49077357015302, 68.3162429255824, 53.3617869500191, 33.286817919823434, 24.829371975314235, 37.16472802623626, 42.22142804053522, 53.97945042579405, 64.24112781401604, 76.59918262112525, 85.62900435539984, 87.31171684880411, 91.50341264663204, 93.93258356278943, 77.18785193658645, 50.15018947662846, 21.53713841592112, 2.2377607226371765, 0.2772920819059495, 0.24576760978708345, 0.11439768807782282, 0.2342474706951649, 0.1852397383340905, 0.15341617016782685, 0.12580381796484993, 0.0656385665699359, 0.18219930390196462, 0.12349144285244328, 0.20848618610010994, 0.1275932308166258, 0.1163517255636473, 0.2014812619815911, 0.1456525278908591, 0.13642623990533814, 0.10449855272928554, 0.16352569624300928, 0.15858481217536236, 0.14468445322446286, 0.11033703903517417, 0.15778682434991484, 0.09347023442387582, 0.15562596610717236, 0.13944516258855022, 0.26927828127818726, 0.16464017031173553, 0.13563110192696895, 0.14192747132432076, 0.1994737745412896, 0.10358925232844007, 0.18390568814450697, 0.16534422043590777, 0.18352567789054688, 0.15765934731931458, 0.12828889227802717, 0.1253370635752236, 0.2067134739650834, 0.1913774662440823, 0.1500403271206925, 0.15438603747996593], [0.01829301326295301, 0.028033886337652806, 0.06474394441371964, 0.05010722558044138, 0.033693730515698274, 0.042729975069842996, 0.07366046474705781, 0.0786835270663423, 0.017378068709325407, 0.01574720541435865, 0.027529499793965972, 0.0981501889445128, 0.016567953712036534, 0.019067825013471228, 0.02662217398474534, 0.04776131496914933, 0.00933726922789168, 0.11356541781776375, 0.03671502807147561, 0.062978406692104, 0.0375834193771645, 0.10867511853575708, 0.1365380734205246, 0.04520468804384432, 0.09630287516741984, 0.07696655548868642, 0.019081853998584614, 0.011621052023744392, 0.036779341152718956, 0.058081331362407056, 0.004779903139288147, 0.024658014562221307, 0.06891339326337462, 0.10006777596690002, 0.04445676406424853, 0.12868770999052834, 1.172607149327955, 11.36070982102425, 32.182043137088904, 58.533887017157774, 68.86388424904116, 63.83741001929007, 58.891877820414884, 52.17586225078952, 39.33189638199345, 26.982533547186083, 19.318916490001065, 21.059223105830533, 24.352233294517767, 23.581065900864143, 21.857119491023404, 40.5382134837489, 59.287778331387436, 46.62470040782806, 24.323488204709946, 6.706218959823732, 2.8947623843146912, 0.47288824113145955, 0.04358631198204333, 0.018290310887800112, 0.0900580098612174, 0.07177639407135787, 0.09448355424308008, 0.041922319214791066, 0.08920739179537182, 0.0317053301560302, 0.05253321153201884, 0.05484824113908315, 0.14414774734647046, 0.5166788074758746, 0.18444168922160903, 0.609026171507374, 0.5352908216657177, 0.11198264186180408, 0.7518642455820115, 1.9627097849884343, 1.5841141583458072, 1.8922533527497325, 0.5727072300449495, 0.1404837020222218, 0.4609035922875328, 0.10220588139829137, 0.14407810995415335, 0.03999285016869826, 0.20569109898661414, 0.0710302627375049, 0.6973793369627769, 1.767013666610564, 2.55864639436045, 1.7895849457671567, 3.0989036108216936, 2.0673646273151522, 1.4412747972434568, 1.5819745054168086, 0.18224442648070474, 1.5366972382030182, 1.8420873414124213, 1.656587179149351, 1.1625212647261158, 7.650544777993233, 7.7393884235812775, 0.590881348377274, 0.0831845464305051, 0.25761701346885774, 0.02867042113305821, 0.057113559300740885, 0.018067478893264648, 0.09028565288791734, 0.03610622565892916, 0.11080376278128355, 0.031478064427632964, 0.22189804142521274, 0.02073710187218122, 0.05391016264536208, 0.36446951690220064, 3.979012384530037, 13.875485485599889, 27.668991473413286, 49.069356841425744, 53.79451459453952, 48.240736530673125, 41.294254256832986, 17.88961852750471, 18.224014312990253, 16.326871725820727, 17.650393170695153, 33.10036020894205, 35.03540662027175, 57.0036841207935, 64.89587729977023, 65.9533129968951, 75.11437723713537, 68.88081319870489, 53.694290191896506, 18.111332462679957, 2.0135705461425166, 0.1713921934846909, 0.10231102696589886, 0.1168704436971776, 0.04915132405116193, 0.037839177830685536, 0.0408570088386055, 0.05931026279746045, 0.029605103942054897, 0.022743327182627494, 0.09318341876590445, 0.050066136454622594, 0.02097267773933709, 0.014785031540199153, 0.0938677114825095, 0.018680579059066314, 0.038448026208507444, 0.039277672617425846, 0.015908805916326183, 0.017175848310392712, 0.07032947614789009, 0.02062620106904257, 0.0153368303079098, 0.027956812146810756, 0.04591107856662524, 0.03451297728104457, 0.0524340529415396, 0.06362078290793204, 0.050344678363011736, 0.015650085575367897, 0.044811773038799727, 0.04064792046143163, 0.043563436596624316, 0.052657662515318206, 0.03776826490197451, 0.04518844697984957, 0.015568846739047478, 0.0286718518022568, 0.004567431526318674, 0.03051474716724648, 0.07253875880832635, 0.01937494583187565, 0.014416181272076023, 0.022977652411246975, 0.030179338552238002, 0.03628032680060114, 0.03450194561493493, 0.03171693255764342, 0.05979034328652967, 0.021486067731354027, 0.04935069843345592, 0.031778016578285925, 0.04117108190492277, 0.09101201915332387, 0.05507335607563296, 0.06540176113166156, 0.03747004602525023, 0.021597278800102013, 0.11148090789755506, 0.026810767594724897, 0.10526834851911954, 0.003333409197605966, 0.026450009130301978, 0.06094976373377347, 0.050122068533974315, 0.0423552967878359, 0.06304840797618513, 0.03327145519095563, 0.0028203493416038977, 0.0657234720945839, 0.024583472291969007, 0.014089837392431595, 0.019900995426841324, 0.09143203451868989, 0.027950574275887305, 0.006314637721516193, 0.33681680718737267, 1.7311281470521804, 15.215488729938386, 41.6659027530301, 70.41686827136625, 78.12627115557271, 73.86400407360446, 69.50930241615542, 61.85970390996626, 50.74070230607064, 39.721634849425286, 29.952422803448094, 30.122004516663093, 32.51127708342768, 31.620283242194887, 23.948758686742476, 29.584029874494, 49.27370840503324, 42.45273805433705, 23.47949024169676, 8.375490961536284, 2.8422121847829516, 0.46828402206301695, 0.06970248680802123, 0.020533017964372714, 0.057109870587385474, 0.014228793292967303, 0.18155669402931968, 0.10927760838380746, 0.055343536134328575, 0.11809340347686123, 0.647329219406651, 0.2110225806433347, 0.5793136045817406, 1.7169372569168768, 2.200025070098139, 2.620088116776559, 2.894429963442587, 1.725596379368536, 2.5742495829059235, 5.215402053248498, 4.4541347219098, 4.210395697624453, 5.959402130496118, 3.432694370708158, 1.9834045777397773, 1.781406436235674, 0.6645063202707999, 0.25709840258763683, 0.22539101931596958, 0.09143743543855606, 1.3322944386351494, 3.0838068983247204, 3.0042487286752273, 5.174057329854658, 6.0750483120641405, 6.068066002861147, 4.547478306678034, 3.716875237803306, 3.331561939370248, 4.120062531963471, 5.986622398899448, 2.6551582736353723, 4.065017950150275, 5.528697938688341, 9.609889291947889, 2.500170228942748, 0.6287195954111315, 1.3885136477408873, 0.2677629593639605, 0.5915357713257113, 0.49792279939978357, 0.05935897449812582, 0.19575231858799536, 0.025057590701767517, 0.03650300557755175, 0.25380048600416033, 0.06481073195895841, 0.07429768136071582, 0.30877667148747756, 2.9486366289277233, 11.493241806184093, 25.062290160886704, 42.914526539464156, 48.38405993676955, 34.54137232995803, 39.41549777984619, 29.976421825347412, 30.640785040393954, 30.2257159063893, 29.838615232898345, 50.004532260279504, 47.26148936056322, 65.48890829086304, 74.98198155433901, 75.25955984669348, 84.71200127755442, 81.05695632196243, 66.45201098534369, 26.27593032775387, 5.124444250137576, 0.39716899935756966, 0.1992368695115851, 0.14875020441268721, 0.06233965790259743, 0.03743762135385506, 0.024805153239398234, 0.012984594683192912, 0.02450183604753787, 0.029233959240598545, 0.014213209149367629, 0.052050403769939184, 0.022510444114525473, 0.0262658684063823, 0.036672452735083724, 0.04113811331110136, 0.01958040103706862, 0.019408642209225127, 0.023075060490819237, 0.10314216341582999, 0.013453135972902661, 0.040589755235780636, 0.055812845427182414, 0.011383366541967038, 0.020656419407215812, 0.03599039699521757, 0.0695961538041311, 0.01567157912969349, 0.07323818176143593, 0.022041853029100646, 0.05500933793824046, 0.05320876701584747, 0.03294078866019845, 0.06414651840684876, 0.016484969152858662, 0.038169453656601335, 0.0419389165096706, 0.06410654010852018, 0.021381213277157758, 0.024725384334282532, 0.011458896108031755, 0.10795451325154114, 0.10147464281368641, 0.18735794080120904, 0.12110150133770321, 0.1047710655257106, 0.1673720245279612, 0.23036771033319736, 0.2545246995624996, 0.09755337580798135, 0.12190995392419639, 0.10098901201760578, 0.16408840314515177, 0.09911932081224457, 0.13941516258543538, 0.1590512218254228, 0.17147618736470902, 0.11726658776282303, 0.21896265296926423, 0.162824358070089, 0.1848214083621579, 0.13144296053196156, 0.27496096828291494, 0.19819603181414067, 0.10144160910239143, 0.22078116184040425, 0.13770517772964894, 0.15621755452406022, 0.11740040800143635, 0.23603133707036897, 0.08505367839168157, 0.08896419718380898, 0.1387952748806246, 0.22798073357872425, 0.17213295454219465, 0.09390276766592458, 0.3742489969778446, 2.400287562800992, 21.37345006389003, 54.556321251776914, 81.31015316132577, 88.48103031035393, 84.67413471591088, 80.50309411941036, 72.318386262463, 55.82676518347956, 42.7432954695917, 30.46646118164063, 30.416094026257916, 34.59243374486124, 35.40681977425852, 36.252369034674864, 56.318453896430235, 74.40420858321652, 58.81944341044272, 30.59537772209414, 9.470490217208862, 4.198917371611442, 0.8006103589169441, 0.3306446512860637, 0.10939678868218776, 0.1886215875105512, 0.27787204110814684, 0.3262011881076521, 0.2420702396381286, 0.26009288706606437, 0.16360792812080155, 0.4266690228494906, 0.24778355483806905, 0.4489068086108854, 1.4392204558657062, 2.34800580047792, 1.918074193020021, 2.6254708343936555, 1.341671967698682, 3.7411240656529707, 4.986100292974903, 5.828089512163594, 4.115838629584159, 4.803302153464287, 4.41739191932063, 2.3294115595279203, 1.5967575508740641, 0.5504927027129358, 0.27996119352117665, 0.6188189202258664, 0.18211423749885253, 2.331149414662392, 6.896618162432025, 10.207888945456475, 5.572562294621622, 8.106969912205974, 6.46046874023253, 6.117843822125466, 2.8736254669004873, 2.8086413539225057, 2.4081808424765065, 6.199603667182307, 2.3831879900347803, 4.598109241454832, 16.30851895578446, 12.482823441105506, 2.6805034039481996, 0.3186585009098053, 0.9537299458057651, 0.15494011823208104, 0.4683782815212204, 0.31380033901622223, 0.5931535651606898, 0.2186183424125756, 0.6937311036932854, 0.13228538145701732, 0.44087125108607356, 0.17706587129542906, 0.14767288560828856, 0.8455658079155031, 5.310701429843903, 18.654082590533843, 36.42518866446711, 62.40860431425033, 69.53609220443234, 62.17177552561607, 57.750087630364206, 28.696719138853013, 29.39188668804784, 29.523839143014726, 30.135368031840173, 50.71015096479847, 51.88403398759904, 77.99407159128498, 85.05088621570219, 85.72475725604643, 95.55753523303618, 91.75384029265373, 79.17840773059477, 38.951779488594305, 8.917965542885566, 0.9419132540783576, 0.30284068517146573, 0.2521395460972863, 0.11347629880953221, 0.1807872046746554, 0.11219129356886111, 0.10570207685833016, 0.20279890256783656, 0.173342622696392, 0.16891468045932634, 0.19417462179497366, 0.10763091005144582, 0.11897095719412451, 0.19827857012710265, 0.08166113462779792, 0.1648435819773905, 0.14816724214582674, 0.10243950757167994, 0.23581568331968403, 0.17496098343643451, 0.10386742651462556, 0.12925743425805725, 0.15178118531982746, 0.1296073525783516, 0.08146696964338904, 0.1828572202113367, 0.10550489348749961, 0.16853537500625657, 0.17949148952480287, 0.1351093347635, 0.2871134516692931, 0.18275451846420768, 0.13716655663184582, 0.0898089699987923, 0.16729382227265066, 0.2065770030622521, 0.1193160874648921, 0.10810304237830062, 0.16620423073970503, 0.19928380005782653], [0.08110903038252747, 0.042642487828890165, 0.01302679272128209, 0.01185728289607552, 0.10203304430169445, 0.016759707434703747, 0.0213547142958569, 0.033837597997438525, 0.04044831625276035, 0.019364471494730924, 0.03195217709177204, 0.05692697475634276, 0.04547408669285717, 0.03532912905117677, 0.011003972031176092, 0.01717840895927962, 0.03168109496454558, 0.04663416214527623, 0.026829121146170844, 0.03617667893488561, 0.042856165072730476, 0.030160973509473187, 0.007946319294147073, 0.07821972211522442, 0.06813404435712485, 0.05353966337298194, 0.02322482493435664, 0.07181354933568547, 0.05772590486993713, 0.04848303874173472, 0.03223250206980494, 0.058000620169144486, 0.019301730808952165, 0.032921000609114286, 0.02657246445455859, 1.4214522415591826, 20.10284531501032, 41.4911219381517, 64.88598115982549, 71.81058053047427, 61.74180138495661, 54.48788765938052, 38.05922454403293, 39.5775269692944, 27.728756627728863, 21.655176262701712, 17.151251954417077, 17.004163072955226, 26.934719854785552, 31.840592968848448, 44.668406517274924, 53.85681359998642, 28.546209950600904, 10.062936775145992, 2.6415601516923597, 0.3529614053906933, 0.1192105818359602, 0.018041765152086175, 0.03385195448513954, 0.030801332998840563, 0.024403885960759177, 0.023207519008147142, 0.04970172758124048, 0.10907342296934898, 0.2767425210725877, 0.05913155363692392, 0.1699268051813687, 0.1947042796640627, 0.7677644923810036, 1.8190448875388794, 1.527220301570431, 3.2163957578520623, 3.075342913789134, 0.9979118911489364, 1.7854398585134938, 4.20635026308798, 3.1483377323996637, 1.6414106709341851, 5.333685538461132, 3.0703529234855407, 0.7677923779814475, 1.17083239939905, 0.9245988702581776, 0.21913831693030175, 0.06551674326821681, 0.6338922823629072, 1.2698498151956068, 3.000229770137418, 6.742529811397676, 8.247677587693738, 3.5063005887692977, 6.067899302128823, 4.047211860456775, 6.383735902847783, 3.1964129978610627, 6.423255743518953, 4.390685971706144, 2.827195390578239, 1.3197640593974822, 3.099753784556543, 16.877048861595892, 1.3318830800633277, 1.1735422668918487, 1.6134935689549295, 0.6272566126238915, 0.24566245655859673, 0.29100499446353606, 0.05575265006853208, 0.21657023699052874, 0.03640622952051702, 0.27174548276009103, 0.1929453724334317, 0.09103454979917697, 0.34306060763136037, 0.10372476562136605, 0.20317451547711127, 0.3456496783802587, 2.1009646308037544, 7.5310208432136045, 26.02639109857621, 54.32167722332863, 54.192199783940474, 37.165241856728834, 22.298250813638013, 19.37305304311937, 19.338028238665675, 12.060417513693533, 22.184198094952492, 33.16905267776982, 39.42207559462517, 46.129497251202984, 57.962809531919426, 65.58579083411925, 65.28044216094479, 51.4187349811677, 25.563600447870073, 4.7867365133377815, 2.2020656831802863, 0.11190400293637669, 0.0815035273591357, 0.05780853894388965, 0.04249907616946486, 0.031153997744343458, 0.08320006737185102, 0.04964337849448766, 0.04484141681102976, 0.025045463529926155, 0.017707120709782167, 0.03299715357922739, 0.08099281484441412, 0.02306507261950643, 0.05542638088246027, 0.048106073687273654, 0.05211829448178892, 0.10110586340869628, 0.026786262357246973, 0.03409398081261785, 0.043602323219660795, 0.05056727670073029, 0.044017136848020944, 0.07579099356887803, 0.041438890921492735, 0.0052780001011166365, 0.023230842555001862, 0.020594689957497102, 0.04144203188198228, 0.024174140022707083, 0.07094020910200573, 0.052417865503699555, 0.04602993710807735, 0.02221402171398363, 0.04128100786117777, 0.0134836042472612, 0.07717120055589946, 0.14349626617566233, 0.024399371787665353, 0.0643229561166898, 0.03842970521579828, 0.06779013216615686, 0.011266195309168149, 0.06843129413262491, 0.04879248463698933, 0.023639770712883725, 0.0697076885450271, 0.0605851671688499, 0.0615103294201676, 0.019504506621629964, 0.06248860454727566, 0.016906459237478914, 0.03340117685917405, 0.10724132369843223, 0.0743638253920982, 0.055606273648839806, 0.026479082167028423, 0.003140294950665726, 0.06317907959342965, 0.029473421088750326, 0.04252336115666455, 0.05641958706321255, 0.03923359574870237, 0.053861270914034504, 0.07353822775785962, 0.07346240037511434, 0.0037767133964676292, 0.028690111507932027, 0.06411284118169738, 0.07301960155488023, 0.04133983958332289, 0.060382058107925046, 0.04671180898684167, 0.1497903526309998, 2.13442244837361, 25.874846404598607, 50.285766201634566, 76.39382300838348, 80.42528213993197, 70.6485705221853, 62.466451429551654, 51.03951631053802, 52.78115064867082, 38.19371085013113, 30.372092877664876, 24.432235917737408, 24.752368004091327, 26.131559648821433, 29.568922865775328, 37.522871801930094, 45.72670513583768, 28.931176854718117, 9.976929003192533, 2.381831830547702, 0.2879492229511661, 0.10247205098670337, 0.012436515272354648, 0.08633656922968165, 0.018253940863594897, 0.0910067791119218, 0.02008563410791178, 0.18674287945032123, 0.6833794785122718, 1.069151081385151, 1.2330731821637, 1.7803444545115195, 2.809602334614723, 3.840371307826812, 4.169306418588085, 6.816088961016748, 6.512076835478506, 6.19357890659763, 4.953063149606028, 6.2722136032196785, 8.341993920264706, 6.957199660039718, 6.437367941102674, 8.057654442325715, 4.009879721749214, 3.887234315756829, 2.7703960384092023, 0.9874745254074374, 0.06942482590074502, 0.2998047400145762, 0.6833362711533424, 1.883708469329342, 1.552614706658548, 2.872609818173993, 2.947274831033522, 5.473924490713305, 9.00963133381259, 10.230931889626289, 10.838934567666824, 8.237819690858165, 9.904704440024592, 8.930211182563536, 4.309312480111276, 6.850676911492502, 7.328054856869483, 9.835774667801397, 3.6826503517166262, 1.7278261242374298, 3.2601233211255845, 1.45689073349199, 1.5555253504745423, 1.077394187450409, 1.3813261495482538, 0.7620551761600279, 0.5694566883387104, 0.5240027918930977, 0.22280092200925275, 0.30635975601692356, 0.22125791367744246, 0.034007301794425134, 0.19269490764746744, 0.09914124624863749, 2.125298279908396, 7.656033644753118, 25.98253115530937, 48.625787765749045, 50.92995666688489, 25.248436043339392, 21.348966629274432, 24.673895105238884, 25.327191352844242, 24.35219014844587, 32.38088573178938, 47.82221571091683, 48.482111346337106, 55.45461854627056, 68.04680747370567, 73.50143586435627, 76.52064892553514, 66.25347629670175, 42.92710950297695, 13.779030480692464, 3.9592411873802065, 0.22609749027798254, 0.0374044114423375, 0.01793380038091733, 0.05110720780888393, 0.05721806901537123, 0.05151525305043306, 0.012828596199171679, 0.07575628978590812, 0.09137280826126376, 0.0593861744498774, 0.07752517148131326, 0.0696348106007903, 0.04444203219346462, 0.06134814094571818, 0.02116778692711265, 0.031930113759552764, 0.05717850440452176, 0.08243957955029704, 0.06017624858706709, 0.020778654481194193, 0.02075539988225266, 0.02565662549327939, 0.0307359071748872, 0.09861332739913657, 0.034392820220560796, 0.03570644267564339, 0.03523254068568349, 0.08068522288193626, 0.07558401193349593, 0.01960127501778545, 0.06935486675149972, 0.004421863808191472, 0.024173356697804505, 0.040610347679185296, 0.05505762446010786, 0.05322075629186246, 0.11468918453301154, 0.061522019921892115, 0.2562889234433251, 0.11755059953899154, 0.14698498461756015, 0.15953702882172602, 0.2046538925459308, 0.13924124530486523, 0.15165904026118018, 0.08722833387794034, 0.17144811790316336, 0.16109445492827124, 0.0886964034889975, 0.2266176486568105, 0.12114503811444007, 0.1097485302917419, 0.18874434543953789, 0.22227535504967938, 0.14317683815475435, 0.20184803423621964, 0.06426599747951954, 0.18339807828587873, 0.13591161268132348, 0.18605831860294267, 0.1750886596498951, 0.1641353030478762, 0.07824589933959708, 0.16292180445405746, 0.13966188886232916, 0.16262276969369382, 0.25639976104421003, 0.1918725582260278, 0.2060262164882114, 0.18783172021710104, 0.15038664482774275, 0.13695153107325878, 0.2954522574380521, 3.276664201290377, 34.97523746182842, 61.36826230633644, 86.77068864145588, 91.48875867166828, 81.77504031888901, 73.80057934791812, 57.33145698424309, 56.97356816261046, 39.89856904552829, 33.15575976525584, 26.570759204126176, 25.898457111850863, 39.12179462371334, 44.35362846620622, 59.91214513778687, 68.7731441374748, 38.930547698851555, 13.793415773299433, 4.291531885823896, 0.6933836062108317, 0.446306123969055, 0.12822925999400117, 0.1439460363960074, 0.14715847288889272, 0.1342503356957628, 0.1092171257421855, 0.1114121361845924, 0.2957300715629132, 1.2954642407355772, 0.6900104904367078, 1.1884232490293443, 3.5879915471999877, 2.837668364086459, 4.888005737335452, 7.661845616755947, 9.623404798969146, 6.452131742431272, 6.7712930421675415, 6.100530970481135, 14.755589846641788, 11.963046635350874, 9.846206211274671, 12.23711048403094, 6.860789272093005, 4.921082594702321, 2.454805076122284, 1.6782762927393762, 0.7140699413514907, 0.5008680091029214, 2.078452677496018, 6.721668195339942, 13.094465098073407, 18.49574827378796, 16.974417778753466, 10.85485742938134, 17.117588212413175, 15.196707440960793, 17.126352748563214, 10.361561525252558, 15.666089634741507, 16.281825265576764, 11.320036803522418, 9.557404056672128, 15.569506172210941, 33.6218197115006, 9.459828234487965, 2.8183418656549146, 3.993956614886561, 2.562043902374083, 1.691362790523037, 1.10757339385248, 1.7049799114465716, 1.212579656031824, 0.9395546225770828, 0.9253342533784529, 0.556666819799331, 0.40483404611868246, 0.5255590535459981, 0.23010848150137933, 0.5442008532343373, 0.7494719062120684, 3.3864130993043227, 10.580487635827835, 36.52818226045178, 69.65278271705874, 68.22787977034046, 49.24422002607777, 34.73410975548529, 29.751807297429732, 29.17607395879684, 21.95470021617028, 34.08481236427061, 49.09027091918453, 57.63070244942942, 64.34835756978681, 78.0785123763546, 84.74884017821282, 89.36616020817911, 79.99637096158921, 67.7907786830779, 30.5407920575911, 5.966773734938714, 0.28493475889967335, 0.229269860372428, 0.20343354512606898, 0.13794013689602577, 0.11700054840935815, 0.19349649608615907, 0.1735610190418459, 0.12947324122632706, 0.16768288768587575, 0.21916799517648838, 0.15727106331577226, 0.1650609670867843, 0.08787789216805851, 0.19760885606369666, 0.0961172367416082, 0.11713690439900083, 0.14247942235200636, 0.17769093775460798, 0.15004665500694706, 0.12924594293919303, 0.20576517968889207, 0.17888198997224533, 0.2146791489494424, 0.18015942626422454, 0.15428675248497917, 0.09322677168153948, 0.07514848328766323, 0.15118869291918893, 0.13384970235488108, 0.1835553561367335, 0.16873161608894027, 0.17565738800312244, 0.1333970822874577, 0.18486884452642935, 0.10704206422932687, 0.21891665705029043, 0.4080272538046683, 0.14246770120676489], [0.027579406591793223, 0.07062054359384122, 0.017272840787266052, 0.04845694195659411, 0.05687837030798678, 0.0730890933904917, 0.030929229462579377, 0.07366609549330128, 0.06605173310925884, 0.08932375289019077, 0.010057381343006367, 0.08930936575897279, 0.03719088741608205, 0.04662707583197663, 0.07957611142867997, 0.019633266849503405, 0.10344788612377259, 0.05077842968486009, 0.04330183672268064, 0.035707561164012844, 0.030982811567223364, 0.030910264956013813, 0.15025909118835004, 0.045931594401237466, 0.09999027085160056, 0.04121042435027419, 0.015882623903903992, 0.049480833789153446, 0.06887730286126176, 0.040955730758967905, 0.030411963065665577, 0.049424993640352646, 0.018778172914960214, 0.0344640510757604, 0.5433509859346575, 18.31977309719209, 54.853193683008996, 67.19632779398273, 71.19594512447235, 61.058701007596916, 46.809283225767075, 43.78679890786448, 36.03648178039059, 30.05892888192208, 22.024198732068463, 14.574798980066854, 31.727087420801965, 38.90924922881588, 47.33993676400954, 64.26412467033633, 49.68992287112821, 21.15699994948603, 5.771142580816823, 0.7418513538375978, 0.037421108328647194, 0.023487227285400997, 0.06051795061437353, 0.06857263735465466, 0.060489946270301465, 0.12050871782365347, 0.06682420254594858, 0.19273368701819452, 0.36988097813821613, 0.2531086626432596, 0.26180993525251267, 1.9787901543801831, 3.1435769556030153, 3.386507481336594, 2.8592845461060925, 3.498401180390389, 4.7581522407070285, 4.532550746394742, 6.261154480518834, 5.229281360103238, 4.997234921301565, 8.647488701728083, 6.19199917201073, 7.312481086100302, 11.818566130053613, 2.1409735420057854, 3.914050825180546, 3.403671773210649, 1.5875051699338423, 0.5753912344094246, 0.5241937010038284, 0.6976969876597006, 2.7184037960344747, 4.968775183923783, 7.357963419729664, 6.512014567852021, 4.144397897105064, 7.8917028827051965, 5.955366011588804, 9.980696439743042, 5.603322011809196, 8.183585078485551, 7.273787394646676, 2.8306257484420656, 4.3908693425117, 3.2330989260827345, 5.7181091943094815, 3.228870365888842, 1.0557518971543158, 3.8080978009008595, 2.5316521525382996, 1.7626746671815074, 2.5053595246807223, 0.0769320815320938, 0.25609887235106965, 0.15549488846332798, 0.08597789452441278, 0.43481072951709077, 0.04326713677015036, 0.04215784528623185, 0.052769733517761194, 0.002753775343374019, 0.03784687318388493, 0.07800180074428359, 0.6447658892120085, 2.693256009970942, 12.11126123705218, 39.79711301865117, 76.36992792929374, 63.85186003100488, 33.94974946975708, 29.105308517333004, 26.72257846401584, 25.09427905082703, 14.55621773196805, 22.219685739086522, 33.736207792835856, 34.75436095268496, 46.3753161122722, 54.82043796969999, 62.46445886550411, 62.34652496153309, 44.89058917568576, 24.349611190057573, 5.709608927849801, 0.18089396668778313, 0.03530606597421631, 0.04760785989703671, 0.035335112197865406, 0.05171866854652763, 0.12380121816550532, 0.042163039362358476, 0.04160653011152341, 0.0084601454774759, 0.04583511711849321, 0.02817614503475207, 0.04401405717456534, 0.06729244314614805, 0.11505581889181368, 0.07357403470744049, 0.19162169507434293, 0.07164211417998999, 0.07538066921575416, 0.026578508888281165, 0.044063488997879534, 0.020952895433912357, 0.04284783386655393, 0.05238988797270483, 0.06552304817183364, 0.012229118991883533, 0.027769078470526204, 0.029899475142179482, 0.043667720315316995, 0.015263346196602912, 0.06450832641172795, 0.06390529647169095, 0.05021879479529397, 0.0313899451641426, 0.029399834513183565, 0.08834896729357782, 0.019227169386501756, 0.03774912802562599, 0.03687688712811759, 0.030108942732875867, 0.024249507752697796, 0.10804479671341759, 0.022987954378608736, 0.05881781381885371, 0.06752944010640345, 0.04070755274545762, 0.030628237347569198, 0.06178158966283645, 0.03992511267443338, 0.061482631511265234, 0.08723584920047753, 0.043025780769605795, 0.0886777186045243, 0.05317951777889844, 0.07383540092456727, 0.052799342816034635, 0.05012618625656732, 0.0648317227680837, 0.04017154017703668, 0.01821987293360214, 0.03183188022024209, 0.04103479103275365, 0.06645342365147607, 0.04879595884572595, 0.04479391552928475, 0.049582876700667605, 0.024312845987057494, 0.025694903076416063, 0.05053477925098231, 0.038940509661070766, 0.04251666937864596, 0.05445512695117824, 1.1578880875341355, 23.633098102385, 66.46682185511436, 77.91499660861108, 82.69187081244685, 70.74990103321691, 53.481458463976466, 54.49312402356056, 45.67522794969621, 40.51861732236801, 29.999299049377445, 25.201538224374097, 32.57545098181694, 30.771752980447587, 34.65424245403659, 42.646997359491166, 41.978888280930065, 20.883612709660685, 5.112495239703886, 0.6393202298110532, 0.09842149898289673, 0.05267807492806066, 0.09019129383828371, 0.0746401073411107, 0.21495333181754236, 0.5769981804393953, 0.22626000817023942, 1.0665294672212293, 2.4194201490571423, 1.9331560740547797, 1.9241527636204998, 4.433229959780171, 6.294475995725201, 6.632881914415668, 6.079535013244999, 5.41585527120098, 10.087681047378048, 10.495246687243062, 6.067663469622213, 9.411492866854514, 9.36082466956108, 9.857035875320435, 7.694320880597638, 9.006888616469599, 10.69150738177761, 6.726176959853019, 5.897720408055091, 2.1967658256330798, 0.833208809696859, 0.2229058300896037, 0.14053444768632614, 0.5651229595945728, 1.671796659788778, 3.6946099035201536, 5.324983760233849, 5.531192566117933, 3.5777747534936477, 2.201024293899536, 5.533214547941762, 9.870810258773066, 6.376826157492976, 9.977522261681097, 12.639688830221854, 9.420581979136314, 9.47947342549601, 8.068908702942634, 7.4759502756980165, 4.511847496032715, 1.9727159964461483, 3.130819691765693, 2.4289654820196094, 3.0583296331667134, 2.4476891611852953, 2.579686478261025, 1.6849589083463916, 1.1414499244382306, 1.6668300811321506, 2.113160015113892, 0.6443120587256648, 0.03219839583541597, 0.23052838961443595, 0.0978387052553796, 0.0710369200415669, 0.06369410518316493, 0.17354563599632633, 2.270633616755086, 10.533250531842633, 34.10355344895394, 58.86831614278979, 48.41808257564422, 26.265926322629376, 24.88513827323914, 24.610890073160974, 31.678350010225852, 24.529602873709894, 34.76265676559941, 45.471099961188536, 42.97835919164842, 57.684356551016535, 64.58376253804853, 73.61596122864755, 75.86336951101981, 60.37970735180763, 38.678049041378884, 11.6026984876202, 0.16797875084223288, 0.05354443227031058, 0.02751761777026038, 0.03839208646827648, 0.06813274200765357, 0.04183256052314274, 0.05866532018708606, 0.02117253667224319, 0.07741639465694466, 0.002394804018436961, 0.02538266862111707, 0.04769926184728261, 0.057960542279385754, 0.07966310837336125, 0.10728009540828005, 0.08212768983456396, 0.03651520935818553, 0.028041407405849428, 0.03079849081264148, 0.07567977292403098, 0.03942960317456915, 0.05684606054978025, 0.04016978583569008, 0.0248289498455462, 0.003378140113894798, 0.011980089663167395, 0.061468075840703906, 0.030507768106256283, 0.045476373465311144, 0.04579329637870674, 0.04195762054634191, 0.0553989319521333, 0.07413406796272724, 0.0332001285747655, 0.07583022493148044, 0.029041539021437208, 0.08042685206859343, 0.13434012120048847, 0.16856955784943797, 0.12418914210772324, 0.1623347819211983, 0.1058319823876504, 0.11491642919399085, 0.23421711829160494, 0.22263667275828702, 0.150251169839213, 0.19909244661609973, 0.1261494232101306, 0.16458545631218344, 0.22718570285266448, 0.126005528915313, 0.1902874303801406, 0.09978669064660227, 0.15574210503649327, 0.155403294991101, 0.14246869712106644, 0.09322209088432212, 0.14657888140889908, 0.1001120328662857, 0.22956527919778902, 0.24557181303539585, 0.1265280928102232, 0.124754223882431, 0.15607510813541953, 0.12267254848754215, 0.14822229322406555, 0.1322823171053202, 0.18788761399205656, 0.17841083057705434, 0.11260210821825652, 0.2006267368673317, 2.37390423013318, 32.006299380333196, 75.05891492289882, 87.56871054249426, 89.89127928210844, 81.60908483689832, 64.24708197193762, 62.522345204507154, 49.66316446181267, 41.62046993932417, 32.20567541737711, 25.644660149851155, 43.52622409020701, 51.234222765891786, 64.38121134235014, 83.56297431453582, 64.09296420312697, 27.61616106956236, 7.383219561269207, 1.088139152815265, 0.31852143245839304, 0.20581905099172748, 0.1639935154948504, 0.18269531518941928, 0.1820385786554506, 0.36021423556150933, 0.2484608684936839, 0.6698206415580166, 1.705350820575991, 1.4910652416367687, 1.463091387864082, 5.2721764003076865, 10.618133564149181, 10.970118238079934, 10.326830898561786, 11.128325077795214, 15.100322058123929, 16.598699823502574, 16.8957644508731, 12.728113762794003, 16.252829144077918, 17.1170743819206, 19.1778935540107, 18.282402715375348, 23.803195607277658, 15.829788773290574, 6.515397121829372, 7.2849372221577555, 4.929475976574806, 2.287456662424149, 1.5203594632687107, 2.710257768630982, 1.7727209603594196, 2.285625896146221, 4.431938029104664, 11.660980005418102, 19.344906114762832, 18.596239397602698, 17.100824002296694, 20.353488691391487, 20.391294456297352, 22.8026323164663, 17.520188131640037, 13.166707311907123, 15.949732891974913, 10.589102141318783, 15.807556779153886, 15.41756041588322, 7.285374566431969, 10.729144484766069, 8.864369296258497, 9.051090786533972, 7.029428145577831, 2.3279825910445187, 2.2608897138026456, 1.9191458580955383, 2.7780833936506704, 2.5924626185048014, 0.7521685357055357, 0.11599361776344239, 0.3025053531652497, 0.16115555810111185, 0.16509752480253098, 0.3756356161207922, 1.1924050676245843, 3.948904271087339, 15.868569247184263, 52.35516163610643, 97.81067017586001, 84.05733416157385, 48.89453680284562, 41.12635327923683, 37.87646955059421, 38.972403310960345, 26.13738632971241, 36.2621396587741, 50.032235960806574, 53.53464580351307, 70.05609650765696, 74.46196940637405, 84.83778384424026, 85.96137031432121, 76.81195551349272, 57.28756566201487, 16.82486172645323, 0.4126174687858551, 0.12762333807205, 0.12832910423317265, 0.1647592203751687, 0.1687024128172667, 0.17534623373179667, 0.1677101144507047, 0.12281540090278273, 0.3075438827997254, 0.14767182840695306, 0.09405705777387466, 0.19731193570600403, 0.15181886152394358, 0.3363237529993058, 0.1832632161676884, 0.2120961302951459, 0.1425909647537816, 0.07824211486525114, 0.138545714078411, 0.2342918884730147, 0.14055317087519553, 0.1726781333526296, 0.16249680951718362, 0.14093751718680705, 0.10099853449050458, 0.16786155471157643, 0.1614877951121138, 0.14712890189501548, 0.18536577511939312, 0.15478155335351346, 0.13311928348435512, 0.16112344369532602, 0.281057465340822, 0.18642694479034794, 0.21311119679481755, 0.1357349528059844, 0.11321354597326248], [0.10235962758381521, 0.06831536204704354, 0.0644765337628703, 0.030377215232640028, 0.0033983373038110236, 0.06056216537892338, 0.06491552512612074, 0.12221591411939553, 0.06268993628421618, 0.0827217067501718, 0.07802989318846695, 0.10256244936176848, 0.023236396692452893, 0.09147228477823158, 0.03544110429262923, 0.04494874572922145, 0.12850791681557894, 0.011923992874911957, 0.12652118269714618, 0.1574836220712431, 0.22740000828860268, 0.3923810111178506, 0.1621036378726844, 0.19370240519844717, 0.18539257287498445, 0.25096669612872985, 0.16189467973045765, 0.21193393415981726, 0.05084279639225814, 0.07409020942906219, 0.1932294531575134, 0.08700412292514118, 0.0978088508089704, 0.8632887923909772, 18.65417672741798, 56.404153762325166, 64.10199349926364, 68.78304419978973, 51.47363247409944, 56.09559659034976, 53.026738089899865, 24.500710695020615, 21.76688732639436, 20.5112797598685, 22.925278948199367, 19.981826466898767, 37.82390979028518, 65.92913550715294, 54.215639868090236, 41.803781909327355, 16.04582998060411, 2.5060255921656087, 0.20406222752025052, 0.04632525251156861, 0.09135569385703533, 0.051578244630007014, 0.07405364405243628, 0.04639426937266704, 0.14926037300498257, 0.3018657923225434, 0.5038754557890277, 1.3220061842472324, 2.1325992816878907, 4.29774001721413, 2.231847014158003, 5.091548802391176, 4.943850972960073, 2.431260068570414, 4.882237401700789, 4.1332564046305995, 7.567205198349492, 5.919032116090098, 5.82078900068037, 5.83210454833123, 11.785477015279955, 5.744148829290944, 4.916203656504232, 4.828749020253459, 3.8724864490570563, 2.100190698139129, 6.907312014410573, 3.4530772124567344, 0.788816772401333, 0.33965785957632527, 0.6939519821636139, 8.187399093181856, 29.680753561758227, 41.84281733728225, 40.50994496191702, 37.32907141408613, 15.180517858074559, 7.785437539700539, 4.565540821321549, 11.558705183767504, 5.212778968195762, 4.959609585423624, 6.438450024973962, 1.3035112282922192, 4.364924334710644, 5.952632609874972, 5.905207232121499, 1.1867727892052744, 0.9728982624027037, 3.3732096658598993, 1.4983054466785923, 2.908545347952074, 2.034221579951625, 2.0598836868040027, 1.3908355683088305, 0.81343608037118, 0.5212257538110979, 0.2706395582325997, 0.9060239960109034, 0.23858240985822296, 0.11442606397453817, 0.30180245217296386, 0.12333542904666356, 0.048247248369960055, 0.028325654754054644, 0.07107779083232726, 0.9429843675705695, 6.3608621108916505, 24.692130204169985, 51.45952763095979, 58.49686768747146, 49.951415523406006, 52.645389572266616, 48.47931861877442, 42.30759466848066, 12.494555250290903, 20.557132267182876, 28.300147902581003, 41.31056739437965, 45.4783877249687, 51.6225334905809, 57.14037087655837, 59.50199857834847, 65.07707118988037, 45.207728493598204, 8.04883401240072, 0.4200799312562712, 0.019778858029073285, 0.08874457509767625, 0.06841730536712755, 0.07325548768764542, 0.07707933895289898, 0.08108980157562802, 0.06858834215710241, 0.03894508320597872, 0.08326758270061786, 0.13379737854965273, 0.3033523399743342, 0.3377391464046894, 0.3252557130350221, 0.34743490839196794, 0.4329244371864104, 0.09833988763632313, 0.054482813368761734, 0.09627138129285268, 0.16830997661717478, 0.04578299249612516, 0.0714371013905733, 0.04494008510523746, 0.030402509540679957, 0.039427741580913146, 0.09950233413086784, 0.10743121391222363, 0.02843762808028729, 0.05676878526085808, 0.055330776939949686, 0.18574699579227358, 0.14047156718950118, 0.05133475124415371, 0.09885767880346506, 0.06866524972382092, 0.054546425479554364, 0.08215865510846339, 0.018146313171112732, 0.04809876903891564, 0.007494733445421463, 0.03117245280243937, 0.0642118503850314, 0.007876558848957141, 0.057261019734846014, 0.07673506670060658, 0.02356049784969899, 0.04641643229631647, 0.057900358412054286, 0.04892218715300964, 0.05412483963394358, 0.0140452204317215, 0.05702863079345515, 0.10239597845582232, 0.03395112456693765, 0.09414119721059838, 0.045577025927242734, 0.1696525610262348, 0.24996419347101645, 0.040270480432457505, 0.14000983067577885, 0.13114040176714623, 0.14195144987635075, 0.08752065004720803, 0.1382094780884443, 0.05620071574324562, 0.0775360958951135, 0.08145855033710118, 0.10258844272503931, 0.056494353414182706, 1.735305593859765, 24.162367043956635, 68.15435101909023, 74.66785461671891, 78.76417406143682, 61.16544046709615, 63.45665770192301, 61.085180928630216, 37.763175810537035, 32.804415418255715, 31.049337156357307, 30.723668644505164, 18.776454656354844, 30.562939720769084, 50.78172245333272, 49.92985817693895, 39.243003706778254, 13.940368352397797, 1.7987960192465016, 0.1404939982439241, 0.04196322830994764, 0.08932773654739704, 0.13688313474337901, 0.10511392817622232, 0.2025487595388005, 0.581065800882155, 1.4057740376841639, 2.0251686270198515, 3.2139268709767252, 5.949422640185203, 5.897437016810141, 6.594613309829466, 9.076274364225327, 8.401758093987743, 10.46315973804843, 8.105810361523783, 6.644174418141765, 8.558837252278483, 8.074352952741808, 11.083534552204995, 8.872188541197009, 13.191221144891555, 12.36717333716731, 8.595386878136667, 9.058566824082407, 5.602789059762032, 7.3713641974233814, 4.653370043923778, 1.7403041643481103, 1.4293472372716474, 0.0990394484852591, 0.37275803665960994, 7.426853477954865, 29.932014711441536, 44.983533659288966, 44.10532674481792, 37.89051948055145, 16.691112825947425, 5.0866075965666, 2.0996825060536786, 5.431428061377618, 5.210341705429939, 4.8854257983546105, 5.725726437184119, 3.5273722967793866, 4.564073364580832, 9.0536158123324, 3.5905643768848914, 4.00910456334391, 6.6075762529527, 3.1255445941802, 2.246476474308199, 2.128233438537967, 3.8816076757446414, 3.855819562750478, 2.6383599879280215, 3.1249974235411617, 2.0060093196169024, 0.9370328449914533, 1.9903483986854555, 1.6175809238226184, 0.5575361150887705, 0.5070412068838074, 0.30755586441486116, 0.0835624116382772, 0.04379684826539409, 0.05232975773152806, 0.8533476677633102, 4.965714754596834, 22.122112858679987, 47.208117669628514, 47.89236337907853, 40.43490609815044, 38.674409081858975, 43.40662317891275, 39.586426827215384, 19.338851936401863, 29.773403867598507, 40.92453164439048, 51.225773980540616, 53.32046085788358, 61.06750280626359, 67.24338054656982, 72.39339766963836, 76.1295101719518, 58.69212719701952, 12.39959761019676, 0.22974508003361765, 0.03916821014436503, 0.049972221735985055, 0.03919407710312836, 0.029875362524762753, 0.03930335188464772, 0.02505664458318103, 0.058153983310706196, 0.10568860137174207, 0.06581703441277628, 0.03518451463371035, 0.18118134158993923, 0.17726212769987124, 0.32083982902188457, 0.21711828096980051, 0.2919425635087875, 0.15123809026854654, 0.018292013518211823, 0.11874012724165955, 0.03921351275376735, 0.06622244048142625, 0.08257992685802522, 0.03120781542102416, 0.0049171746040003435, 0.03125241705997577, 0.05450446684394152, 0.040175397429735436, 0.04495116273662256, 0.051619425686376716, 0.03524081443526572, 0.0053126129111455336, 0.05026969750742278, 0.0857326161536959, 0.06915789788528796, 0.08605231230537738, 0.014944967716151189, 0.24832992874566587, 0.16418064013123512, 0.21412874541936383, 0.1764918416137657, 0.15483455131611518, 0.13443595879981596, 0.15383702822990958, 0.16410193225789457, 0.20476757999389403, 0.1479040909438364, 0.22493908872767804, 0.16068206979863106, 0.08438229425660065, 0.1747626432728383, 0.12245084264225538, 0.12974877240917376, 0.284151541249406, 0.23778056094963707, 0.1820803917343578, 0.24497800296352756, 0.23150889022696405, 0.4505295666956133, 0.1790947479105765, 0.3057330041643112, 0.21413130415303094, 0.339681547014944, 0.22260152464432104, 0.3482244079632144, 0.18867020345022603, 0.2110731730898542, 0.2779486499005749, 0.25770581838104034, 0.1446714144079916, 2.910674459511234, 31.054145982188565, 75.79533207801082, 83.5838334791122, 88.76921469165434, 70.7209696308259, 73.44683647155762, 69.23341074297505, 38.11156072924214, 31.669283451572543, 29.893261694139053, 35.831906641683275, 29.164224478506274, 51.894522405439815, 82.93610895833662, 69.64151766992384, 53.00547099882557, 20.4346288019611, 3.3799139770769306, 0.39050063298594573, 0.08472894138145833, 0.3365691462832113, 0.23564296113627575, 0.12425226775268394, 0.19842178260366763, 0.4968584887683392, 0.8148493593738926, 1.3999795937730422, 4.007769486596508, 6.318411279109217, 10.053440716958816, 10.386234214228969, 16.27047294570554, 14.953433217540866, 14.549254544319647, 13.747456381397864, 15.676129921790093, 19.63210205877981, 13.907782281598738, 14.993895407645935, 16.86344804302339, 22.513016270053004, 18.78278143944279, 17.906845577301517, 17.500215422722604, 15.202485092224615, 11.949636051731726, 18.602107263380482, 8.039781182043015, 3.0408255659764816, 0.3664394966777294, 0.6619961872216195, 5.229632902529932, 20.284372606585105, 30.846897748208818, 27.398848033720448, 26.5813535259616, 14.670871553882478, 16.15073965441796, 18.558716043349236, 23.86452970966216, 21.342104442657966, 16.58125900453137, 17.08420099750642, 9.40252338686297, 10.791644511684295, 17.185560926314324, 16.194706482271997, 6.786462808808973, 9.40949147747409, 10.041881492061, 8.821703714709129, 6.374245728215864, 10.195885512136645, 8.450781837586435, 3.6686663666079125, 4.042288550446111, 1.9803099502478878, 1.1032482452930943, 2.5364783838871987, 1.2964829538137683, 0.7794772412988448, 0.8154839866103665, 0.2456427834207012, 0.21499745848198093, 0.09323693766829469, 0.23700223094032657, 1.5713032070667514, 9.027072152783795, 29.930614425290017, 64.6263712452304, 76.95090939921718, 66.17942979258876, 70.79743231496504, 61.873683237260394, 55.040565306140536, 23.00103364452239, 32.41692839130279, 46.18547339593211, 57.67462515061902, 63.14068725032192, 73.23442443724602, 80.62120453003915, 86.01081571271344, 90.23793051319738, 70.8945894241333, 17.861695174247988, 0.4834983750216423, 0.13387317528888104, 0.2710145429497765, 0.15780309605742657, 0.1064927485441008, 0.23257477899953244, 0.14432534184907714, 0.22073536510429076, 0.3033999599997075, 0.2592336428501914, 0.21971389410957215, 0.2783086192944358, 0.318226580538096, 0.47184878239227884, 0.521450309503463, 0.4487574827526847, 0.2218123927952782, 0.1219487562775612, 0.1936684062163676, 0.35437486825450776, 0.10753435232946951, 0.18576689875654637, 0.2032859659483356, 0.1359215105373052, 0.08965413596841598, 0.15995465399276826, 0.2307880014902161, 0.1454071499287121, 0.10382629525397094, 0.0983592466781697, 0.2257637670564075, 0.22514769446945962, 0.17212774514430956, 0.19033380934307653, 0.14006160289770173, 0.13034489606657337], [0.02048935861356797, 0.10143151206354942, 0.033487614559670614, 0.02932142541413346, 0.015818842296158115, 0.033757047682640054, 0.07518075091103393, 0.045980099258163286, 0.059272119279710524, 0.07821414499513565, 0.11804000714853888, 0.01084486323018228, 0.04933771324313937, 0.058359053556717215, 0.01069563409058197, 0.05489359737464017, 0.04475800132739448, 0.02996822004206479, 0.23483037167499143, 0.06239984943080814, 0.348201425325486, 0.33929611285848005, 0.2879886611575081, 0.26140611498586597, 0.32629489598255007, 0.41653864386100925, 0.2539401131892397, 0.21744961399705182, 0.014975676350595971, 0.06504294086968707, 0.13860589794574246, 0.09052461869413815, 0.27958167356348806, 13.994094037240552, 42.903583126683394, 60.93974336501091, 67.16961645310926, 53.55601487621185, 53.03232746739542, 52.77223510126914, 26.313834151914044, 19.118110749029345, 22.065830769077426, 20.00041654033046, 28.757525682449344, 41.72994721320368, 53.649206469135905, 44.62336594058622, 24.11196654842746, 6.362866932345975, 0.7196015864610673, 0.08737290999101055, 0.0354680169614092, 0.04193102963449013, 0.08495541995451336, 0.10714486556788606, 0.05690038001405136, 0.3939753013753122, 1.173914646910083, 2.4165401487581195, 1.6355929379501652, 4.951340248507838, 7.129819248953174, 2.7665234333084476, 5.2761203435159505, 6.037676459358585, 7.07852396272844, 6.784624688086971, 4.086775092347976, 1.5521321325532853, 6.727538022302813, 8.774500931462935, 5.880746841430665, 11.225085046983535, 13.304236396666496, 9.395706307503486, 4.637468264948938, 8.7574258735103, 9.717405380741242, 7.140555756707346, 5.484528618474161, 1.450971141457558, 0.46779743365703097, 0.18302874729758312, 9.583080872412651, 48.809613566244806, 68.39716142223728, 64.2345186202757, 73.92140403870614, 67.95213714722665, 55.26092014005108, 20.808093355548, 2.1326659619808197, 4.370673058494445, 2.4736608901331505, 4.483205858738192, 8.407155275344849, 6.095903554270345, 5.997837926110914, 7.6229258987211415, 1.962752563338126, 1.385927580056652, 0.7636581998198264, 1.7011416270848245, 1.5319672274974085, 2.4711101237804662, 1.8289233768178572, 3.5943234783987847, 1.414235080442121, 0.25514006734855715, 0.9078526785296779, 0.881547854552346, 0.34671300841916, 1.5188231199018418, 0.9656560961757937, 0.6272000446915627, 0.14390016305110148, 0.21614531866244732, 0.12146151669683958, 0.07071153185660801, 0.12531992618835744, 0.03007168979233792, 2.3127003014087677, 13.679723912669768, 37.112595804276005, 45.20259018867247, 44.264845617355846, 83.48338157899919, 96.93926857363795, 53.95052294577322, 25.434181844034505, 18.955238249994096, 48.35934508231379, 51.59176249657908, 39.88757071956512, 53.91760249291697, 56.6203312720022, 56.503617225154755, 58.29760736034763, 37.51036728582075, 2.552022982028223, 0.3042956087137422, 0.1523084836381097, 0.09272610257950523, 0.07804886918635139, 0.09644067906323942, 0.01161596519992717, 0.07187629193668404, 0.09323184318359821, 0.09799999740695763, 0.22531652492621254, 0.3314410150051117, 0.6076901141674288, 0.44914058800185885, 0.4827705914935758, 0.2970256794604563, 0.24578752807311474, 0.08096361157274054, 0.12325195610643395, 0.009762829154609673, 0.019750773245769165, 0.16729043616402536, 0.058602282642236644, 0.05827741539706627, 0.16360310176687856, 0.08792910514579666, 0.01297973002487373, 0.0334142156756453, 0.07716327154588315, 0.08843519048945558, 0.04771734535273525, 0.14210273691963765, 0.1275299825975972, 0.08300245499178287, 0.020895182200136687, 0.040757494017241463, 0.005164784754836752, 0.08077821829506467, 0.045450943176664656, 0.05023782058889347, 0.009214161771289524, 0.043237948820235274, 0.03259671176032674, 0.08200805754430833, 0.045143512092650905, 0.027839566220439253, 0.09394194540237227, 0.013138530475478019, 0.10524252369519203, 0.03606610946477421, 0.03156353877256474, 0.04641732861918788, 0.12263070476511795, 0.0643451496838562, 0.15858246794631406, 0.09432272174425664, 0.12150636348392695, 0.2567034536191533, 0.13374378303847007, 0.26660595209367816, 0.1725690117886951, 0.21193670739810314, 0.09206151364431267, 0.2211042670833488, 0.0564215635700572, 0.051785904253202106, 0.11957233621468467, 0.18688177119099325, 0.9782766899274242, 21.152750061404323, 54.7648815185793, 75.84302025456583, 75.35528921311902, 65.78547085485151, 58.53242789545367, 61.31803635627993, 38.23964180484895, 25.96287419719081, 25.93875946537141, 25.89005735612685, 32.447275769326, 30.02235866362049, 44.379574944896085, 38.08437870394799, 22.022176750244636, 6.126500493095768, 0.4788531549274922, 0.09081312740642218, 0.042886701337392294, 0.11418732799469464, 0.1881493709140247, 0.44831670640457066, 0.7693279859039092, 0.8228371436557462, 2.1590495397967677, 3.890955174161542, 6.119270093979375, 7.284603330396838, 9.58996561265761, 9.650221063244729, 9.74176133832624, 7.91271060705185, 10.996981570797583, 14.464638233184816, 8.837448108580805, 5.389386136685649, 6.385586280976573, 7.867316036455094, 6.051588125767247, 10.436658243979178, 11.474881191407482, 8.02908536887938, 4.564017961102148, 4.971636062668217, 5.929468072229817, 1.9785584893918808, 4.146298775749822, 1.8417611718177798, 0.15407578719239082, 0.40815114554378296, 11.405671950309507, 53.47039345772036, 79.38427725145894, 77.2469542103429, 85.91551780700685, 78.89330633224981, 61.381088456799915, 24.76438222392913, 3.902663939422177, 2.556438099953436, 2.5946079098409225, 3.168316815168627, 3.2817478381818344, 5.183867667951892, 3.655641891302601, 3.9953108131885533, 2.49948283357005, 0.7917940352232226, 2.2548026855914824, 1.125033579526409, 2.14170114167275, 3.03901931451213, 3.235888711867794, 4.650588593175335, 4.07519331382167, 1.5305881466596358, 2.010262272050304, 2.9600382235742386, 2.5744280507487636, 2.8708572541513755, 2.4427043189925532, 1.6617416638520457, 0.8583885875921097, 0.697348387010636, 0.48463917187144684, 0.030853762141158505, 0.08947330857476882, 0.06587673564471545, 2.068698968618147, 11.56627731938516, 37.617969666757894, 46.98505640029908, 39.993545316880756, 69.01257345753332, 79.31221546665316, 42.844374948932284, 27.095795908281882, 29.256731617835264, 54.0162814817121, 58.44523360652309, 48.85275179339994, 61.41039248435729, 63.98423610195037, 70.3394171499437, 70.15093941842356, 51.101819238355084, 5.343957735646156, 0.46896351140833675, 0.14665224198852816, 0.15789387747645378, 0.025139891527472966, 0.03405557682497367, 0.014347444033069957, 0.032506202302512624, 0.0830773783907775, 0.1111029584201113, 0.18833648022865096, 0.2031442396823437, 0.4661737869103109, 0.20384617540384495, 0.24078177168003975, 0.17843603486976317, 0.11545312741110403, 0.14228857452830962, 0.12830773804096446, 0.09957252310649042, 0.0994729393372132, 0.12141311526178353, 0.04075089416977379, 0.03693482635783092, 0.026946031909075477, 0.11358010372327221, 0.059598285043912555, 0.027303708784822977, 0.04524719826276264, 0.08726477668049835, 0.020987476642814376, 0.08006595570834414, 0.07768093247807796, 0.026999771061743942, 0.0385068464393337, 0.04879759061300466, 0.1861454840869673, 0.29137075548210456, 0.09037404411262082, 0.1715644713371031, 0.10311596320881959, 0.19834030149204118, 0.16392651344499282, 0.24245075551011872, 0.16532842370290912, 0.14786699696654274, 0.1818557594332003, 0.07854265115794637, 0.23108191878324558, 0.17661656072783857, 0.09133591346683041, 0.18727373241657214, 0.35465099698593544, 0.3364060001988565, 0.2693436132563699, 0.25759764676613195, 0.5159425050500901, 0.544246941083862, 0.46212210109637636, 0.5401950714088256, 0.5158259983985655, 0.554400057561936, 0.3957531769429484, 0.422399124551204, 0.32962210776825107, 0.17259066143343527, 0.21146666649128162, 0.3317915155522285, 2.119137707256502, 27.142087721055557, 65.09358436830583, 84.63573471192392, 86.34942608494913, 74.28641196220153, 72.37218549174648, 65.28736514429893, 40.6069020302065, 28.985644848115985, 31.832693315321404, 27.708807453032467, 41.99840207253733, 55.88284330983316, 71.08768770771643, 57.815285267368445, 29.80946025540752, 8.424864776672857, 1.314568389807978, 0.19570748712266647, 0.18566595901164318, 0.162276528595436, 0.11648045131756414, 0.36427949645346214, 0.618096468669753, 0.5045205324647889, 2.4774543123860515, 7.173054064473799, 6.814539134502412, 13.96141088777973, 20.170086506874334, 13.851005973354464, 15.344060101816732, 18.893309908528483, 20.185419051877915, 15.349473953247072, 14.228500762293416, 9.95039220779173, 17.894758793615527, 23.291116452986195, 17.386478454835956, 27.507087799810595, 27.70058616515129, 24.549361813452936, 15.761485599702405, 22.485181170125163, 16.423899396773308, 16.581904234424716, 11.940395928198292, 5.499138957069767, 0.8409504652503998, 0.7947834328778329, 11.961785593340474, 48.788648497673776, 66.8451109240132, 67.14728247734809, 76.73608902961978, 65.46212634732647, 53.88727080437445, 24.658827320221935, 7.3183249273607816, 13.833774020594936, 10.130177967010006, 12.14766965758416, 19.264348476163804, 16.975066931016986, 12.716876172250318, 17.744883068146244, 11.286237739747571, 4.630776701434966, 5.532635017748802, 5.97678852658118, 5.357732119098787, 6.874311643262064, 7.7351370646107585, 11.080776145381313, 6.534646153450013, 3.344722717039047, 4.0868814866389, 4.669191904606358, 2.5531472313788632, 4.225798354994867, 2.6976561738598734, 1.9461994257665451, 0.6986032390306074, 0.5864876809139407, 0.45123240640086515, 0.17678364450412412, 0.23027764903681897, 0.6177105442170174, 3.499778912913415, 20.351909937397128, 49.69314705940985, 61.58320426940919, 57.42027513442501, 92.32393326297884, 102.87695254048994, 70.81053303134057, 36.0245930763983, 29.370741190448886, 58.627678732718195, 65.98473902671569, 55.08180902850244, 72.85444090443274, 74.49074391395816, 83.69404423621394, 84.49978536175144, 60.95287153797766, 7.039407145592475, 0.696458192842622, 0.3009180496296575, 0.24620840145695597, 0.10393350159809475, 0.1464811285897609, 0.08382917111439091, 0.24220465742532285, 0.23565215419136712, 0.2728579037131802, 0.3882165878049789, 0.5505314361183875, 0.9937452921463598, 0.6822281402926291, 0.7514251239838139, 0.4858433395143479, 0.46937333780430984, 0.20723118086255368, 0.34649859573091235, 0.2526043929279812, 0.16856083976885966, 0.3672261464018976, 0.16863153436251227, 0.16810762215285532, 0.35386977116427115, 0.1938325022497485, 0.13136670413997867, 0.08421330292138361, 0.26804098799344034, 0.19615944835447496, 0.12476862633540747, 0.36754839362636693, 0.3113385001497884, 0.1965543360359246, 0.15740117568883205, 0.23662151588547617], [0.05291401468698056, 0.04114056862289867, 0.014146005043820029, 0.030473472265106057, 0.06981169264162741, 0.035117263605277386, 0.013781482214859177, 0.01712845811139672, 0.049644826400664546, 0.0180650005988296, 0.09141659018613639, 0.01483599170892229, 0.006243296262372526, 0.020169857814307177, 0.028313912541395234, 0.044207685897427226, 0.02448397853802289, 0.038837693000753085, 0.23275845624025793, 0.10306833552256708, 0.18261792498730844, 0.21536220826448935, 0.2073997814929293, 0.307797703050798, 0.27100179524671647, 0.2116162834628936, 0.20061000550706543, 0.03559933209251012, 0.1507362567128674, 0.06776729508513404, 0.15183369298615765, 0.6675451765618017, 12.634829013578354, 46.1878268180355, 67.19231128692627, 58.163842770361136, 53.25432185203799, 40.444935598681056, 45.89910899439166, 33.199149024102, 22.03378696595469, 25.5847498678392, 32.92748566596739, 30.310850950979418, 43.485329458790446, 47.48981837303408, 31.66162894618127, 17.411159969145253, 3.6933540096206054, 0.866192510772136, 0.1604717326981406, 0.04354291310113284, 0.03942706742353978, 0.06242478559274347, 0.12377910120713136, 0.8682904272310196, 1.182666435357063, 2.311368411587131, 1.449735962575482, 3.1766243951935924, 6.573980662130541, 3.6203356567890417, 6.761291488524407, 7.73418834132533, 9.15045520951671, 7.287758386904194, 6.257647391288511, 15.273371146571252, 8.324019658950068, 4.258077500327941, 3.6614344966027046, 5.336654772681575, 7.019046612324254, 7.008338541753831, 6.430089002655399, 8.675513056016738, 5.530943985908262, 6.100981552754679, 3.624140601004324, 6.737014468639129, 3.183919023121557, 1.2519141647123522, 2.6357942675390555, 9.120834450567923, 34.955817807105284, 56.3618706118676, 49.82490339586812, 54.246983528137214, 56.37741496486049, 62.45537073381486, 60.659050710739635, 49.74390645180979, 17.150414528385287, 6.89018008209044, 4.038140889137022, 2.5650312775565736, 3.314381958015504, 2.850874003864104, 3.0745733937909527, 4.457694272841177, 1.2611197223586421, 2.655453186842703, 6.0744736848338965, 0.9011327391189914, 1.3177450193512825, 2.141869313293888, 2.3475061885772215, 3.8670713718860386, 1.4390298531901453, 1.07068975365931, 3.0144069319771183, 1.2493885260435844, 2.401592976623966, 1.64953108035749, 1.243145338469936, 0.40859615069723904, 0.9129943542422787, 0.4293299526456864, 0.15716229415228292, 0.08648950336200577, 0.028753710212185982, 0.10693144879394001, 0.0380511658506528, 0.9379576050466107, 4.497104287147522, 25.91286986104904, 34.98627501149332, 74.45465810837285, 101.94008658009191, 52.30612808658231, 35.45839894202448, 28.393672896969704, 22.0438596125572, 24.099562052757513, 26.019344560561645, 45.56660967488443, 54.853393723887784, 61.27587872166788, 57.63459344064036, 58.49898968973468, 33.27397607987927, 0.829430157619138, 0.09636459887147912, 0.080474954729359, 0.0070361316677243005, 0.02599021081902808, 0.04042600011152606, 0.07672237262370125, 0.033913153418970686, 0.12380073553011303, 0.1471417874939019, 0.304010532075359, 0.6140656204473588, 0.200713197550466, 0.3203069076182381, 0.2748862900320561, 0.05691509273263717, 0.09173547428461815, 0.0613377642847838, 0.09323264757591872, 0.051848041644740495, 0.05882758143988829, 0.053598445299411976, 0.0655332218194681, 0.00450090492977911, 0.13827799699239193, 0.022519516510768764, 0.13106475824550276, 0.10595906105253006, 0.023732419471226396, 0.06918013741772983, 0.045563466170982975, 0.04980858152491912, 0.09163517805357134, 0.029114365254739122, 0.05184593490294872, 0.024303005587670113, 0.04838941896694803, 0.020831531784947843, 0.053895212439519745, 0.06732891659222304, 0.01997538447950877, 0.07981964311892949, 0.017558514974230242, 0.01547941459237688, 0.031367558159775315, 0.070670293343644, 0.06405720787663614, 0.021152505388243065, 0.07039321466319023, 0.057394158155206716, 0.043852600314083605, 0.010211708797742764, 0.029272391956539887, 0.11050992209704653, 0.06748064030562678, 0.14628234409516858, 0.15731620121627085, 0.10602417852609389, 0.14355534687638283, 0.24973225269106128, 0.1739580211259665, 0.13483676068004102, 0.028029402808075952, 0.13465974840425676, 0.0024980039621192605, 0.08942052511678589, 0.9893945868938201, 18.375376616754842, 60.99902214542512, 78.47061603300034, 69.66887227950558, 62.74863850685858, 54.382117025313846, 58.02695597371748, 40.975593059293686, 33.61053505251485, 30.10553840667971, 34.728912615006976, 25.117097439304477, 35.594081571025235, 43.71762790987569, 31.350392795378166, 16.389151119416763, 3.4379939831072286, 0.5227626487612724, 0.21253367375221946, 0.2191300738242365, 0.3371971851635364, 0.2296481239459207, 0.44126502027915376, 1.679622156004752, 2.0949170714424503, 3.2018494029198927, 4.510634012760655, 5.935200125940385, 7.421975520349319, 9.653583515074946, 9.517878332445699, 11.619190093009703, 10.509550590668956, 7.140274816943753, 9.522812674122473, 19.29800437342736, 17.398408343715055, 5.60029786440634, 5.898599999566232, 7.426108227622125, 8.176079623160824, 5.84699337520907, 6.633261894026111, 6.433587266552833, 4.514276914058193, 3.4874786052011677, 2.42159461302142, 4.303614256843444, 2.3409869642026964, 2.9710902369791463, 5.084377729123639, 10.88711892404864, 41.75639967764578, 67.53714253825527, 61.482634698191, 62.36006498336793, 64.94297319842924, 72.89564932546308, 72.09543089712821, 55.88932306535783, 20.3451556159604, 6.966247587434708, 4.473190576799454, 1.428820781650082, 4.406799558670291, 2.3993032930358766, 1.8960764379270616, 1.638743581791078, 1.3096543954264734, 1.305902770930721, 3.8660022808659464, 1.6229235597195166, 2.3342054313228977, 2.918580241741673, 3.3860360614715086, 4.429953309797472, 2.8971332119357203, 2.7135307413916436, 4.78396192673714, 3.7745125063004035, 4.263118726591911, 3.7474094187059714, 4.36476057575595, 3.5137038173214084, 2.296547490742899, 1.144061364954518, 0.3757527356426562, 0.2502302098418436, 0.30630269778832314, 0.11411111756798722, 0.03538335658489697, 0.7666640223995332, 4.688640486809516, 23.642737327083466, 33.60403568513932, 69.58545131068077, 94.6030499858241, 46.984872048900975, 34.86202609154486, 29.18904523695669, 27.00110793113709, 38.460632062727406, 32.34704548312772, 53.63056736607706, 63.993924356276, 70.14391837581512, 68.3397065439532, 69.99452314069195, 41.450215539624615, 1.3951898894963728, 0.1548242857379298, 0.012651245887090844, 0.04032797150073513, 0.04805646949417649, 0.049159390957004605, 0.05936932817642247, 0.044883873403793385, 0.04316183032407876, 0.13274062154514174, 0.11084752172351846, 0.31237155439392217, 0.10065675968484533, 0.28758582148340445, 0.06990857978141116, 0.07662664993756241, 0.09611283939692283, 0.05640510417100403, 0.04069968885291488, 0.1374223227462461, 0.07786500808452407, 0.05187116983917452, 0.031434035439404755, 0.04465533788466165, 0.16494731028233806, 0.028339881006808534, 0.03074508682343989, 0.04784635072874446, 0.0010709528531503655, 0.025674668779116006, 0.018041407005981575, 0.07981348377201827, 0.01714360941531918, 0.03237875974586895, 0.04721488360495818, 0.11130581850246077, 0.14784804395129605, 0.09884593467558585, 0.13853362521096585, 0.12910207162701315, 0.10217314646128686, 0.21856036487846606, 0.09572460901953521, 0.11773996115211519, 0.0846043371805741, 0.21189644181680298, 0.16924322492653326, 0.12643987012486305, 0.14506811005694253, 0.12576889967726124, 0.21736087037190316, 0.18400385465112426, 0.20258524064575473, 0.5146419941898316, 0.18902258857363657, 0.36795328641610764, 0.3944692442253713, 0.3145418508398918, 0.569796770090057, 0.43424903385100827, 0.325221729374701, 0.2900907144911828, 0.20464181900024417, 0.29057224671686854, 0.14263567364504262, 0.357235532494322, 2.0231584123065396, 24.394294831060595, 73.5150307993735, 87.92322220340853, 79.44338736995574, 72.74380653135239, 59.400138547343595, 61.49709647701633, 46.096961190623624, 33.18883711291898, 37.99483099291402, 45.9485936164856, 41.851489697733236, 56.0641509486783, 62.20996372161373, 41.83032066591325, 21.746249775732718, 5.06904028115734, 1.3471692920692506, 0.5520338264684523, 0.3169469072693779, 0.2755799366822166, 0.4084769780597379, 0.38528124531430585, 1.8905776426676784, 3.2520518187553655, 6.683704064738366, 6.075708250845633, 11.693459191629964, 16.4028960850931, 15.757479879163927, 18.516003393357803, 20.026717993520922, 18.351871813497237, 20.150458966532064, 16.153612790569184, 29.713483779661118, 20.35295132667788, 10.881452079742186, 13.121491209153207, 12.88674912145061, 22.75941760309281, 17.321643637072658, 19.54753379667959, 22.18938150713521, 16.960789503589755, 14.613217615312147, 13.235280148444637, 18.64638690025576, 6.9131534041896945, 4.302043347589431, 5.374062907311225, 11.586980569747187, 48.387766576582386, 67.97028203164378, 65.59245886341219, 64.24631710975402, 67.35842366372385, 74.72099488781345, 70.31558482877671, 58.08207704174904, 23.397226372072776, 14.15661548414538, 12.195486291762322, 11.813324862910855, 10.393421957569739, 6.9294003517397, 9.552501093956733, 12.530909738233014, 4.233214086101902, 7.788740175385629, 11.583151355866464, 3.2908675939806047, 4.716360367113545, 5.833925018387457, 8.154006485016115, 10.078880229303914, 6.250979852291846, 6.798157845774005, 8.172891716803274, 6.154031119038982, 6.796372186753058, 7.238626287829492, 6.013356783697683, 3.7311806121180138, 2.974518878806022, 1.4971531278664068, 0.32143664215841605, 0.29177629178570164, 0.46006389863548747, 0.3909514604076263, 0.15536797833779167, 1.3702862709760668, 7.667731133199508, 33.807277217988045, 49.49724428115353, 82.93779557751071, 100.48567956493747, 63.41786938328897, 54.956932529326416, 41.40764605614447, 31.863156403264693, 38.327687248106926, 39.360149214344645, 62.860971266223544, 73.73347543901014, 82.32113622849988, 80.4429171162267, 81.29567177064958, 49.04941551146969, 2.836775044279714, 0.2797838594884642, 0.13574420714810972, 0.15517572091231424, 0.22202349598369292, 0.1735392927883133, 0.17687483961063047, 0.18298512625117458, 0.21584901117509414, 0.35884303010759816, 0.6248561220784342, 0.99180941860522, 0.6196678069330032, 0.6908617060511344, 0.6436219054364389, 0.2022688769765439, 0.4000653632946553, 0.22924563667226225, 0.17807365995982002, 0.21790725960125848, 0.22632978345838287, 0.23711383462913577, 0.2024788003895552, 0.1720172905873868, 0.2646074432038492, 0.1967226302311305, 0.15940230459936205, 0.2794596510789087, 0.12254099586918471, 0.16819202972035255, 0.06738694009160803, 0.26347911826545195, 0.14332719057077362, 0.1547491325125579, 0.19613383037428703], [0.03826343349271244, 0.03823971541057672, 0.03357558826645536, 0.045191430892314643, 0.017733795891305613, 0.0339003405984371, 0.032286097580987605, 0.09342351072137395, 0.05080681324245469, 0.06528374528692615, 0.06174801968999448, 0.05351820908066246, 0.021209157590243607, 0.0069456657811608775, 0.05560581016564562, 0.025837349465056777, 0.029478228290475188, 0.02084272049908196, 0.012822775846166957, 0.08848271858427795, 0.23084066237413117, 0.29907723227816246, 0.24252209361762772, 0.30118590461150296, 0.2623460129384072, 0.1699016928192108, 0.08418636726996592, 0.027882564820409305, 0.04686298494737956, 0.06221690763448996, 2.87430795931047, 10.88780337764371, 46.65637354696951, 69.50800018925821, 58.30658174330189, 51.223977535001694, 51.57878729604906, 38.494254619844504, 46.05307379076558, 37.85337855738979, 15.954485824031217, 30.178521948475993, 30.613100951717747, 50.8419975157707, 52.651720277724735, 28.673922323411514, 9.496477880785543, 0.8143630467595593, 0.05430307765040667, 0.031127634743649154, 0.09939190255658281, 0.06628531331737196, 0.15285421403185015, 0.18371565237400994, 1.28329778390546, 1.4741500202686557, 1.821043702863878, 1.7309749294673245, 2.228126646049561, 5.182333530918245, 6.493135709916392, 6.072344818422872, 5.822573679108774, 10.856188093462299, 8.484298490708875, 1.851512429214293, 7.769526935392811, 23.108688977456865, 11.218209132071465, 2.5656877842641648, 3.846436517853891, 4.371061863437776, 4.390261865431263, 6.175589936394846, 6.023644670363396, 4.770231669948948, 3.8204152689826105, 2.8937026089237583, 6.767217699558505, 6.7465242551219085, 12.500724157979413, 16.403497188322007, 35.10776258284046, 45.36805537439162, 41.141980002003336, 41.953643906501036, 41.63588485410137, 54.99763104223437, 52.846924874090384, 53.87991636030136, 44.82811758595128, 57.3675427898284, 30.190681296010172, 19.310708930415494, 16.626309387145504, 14.530723306440539, 11.343878930614842, 11.154684385945721, 8.56581416822249, 8.909365746282763, 13.65062875132407, 15.800393550626694, 13.932909965515138, 8.71609683959715, 9.2150644909951, 8.023204755398536, 9.873383333606105, 8.737007975578308, 8.110132813453674, 1.4399561454211514, 2.268876640066024, 4.747517224281065, 3.199339821454018, 0.9449098223159391, 2.011786725732588, 2.888912904647089, 1.978096262581887, 0.8101301964732909, 1.618585418308935, 0.12417112371974415, 0.12613373372944134, 0.08347854033232698, 0.10069541648150453, 0.03904947034654118, 0.1263283430448463, 3.7072365034011106, 17.492890396425803, 41.506391725232525, 58.86952423280286, 62.93002459310717, 67.21517870503088, 43.627491843315866, 23.500306260201242, 13.13135498954404, 22.58452303947941, 27.261294434147498, 40.61974779252083, 54.226140053041526, 61.80817181064237, 63.85153447428058, 57.78399652050388, 20.002363997121012, 0.4706942266033542, 0.1338812958208784, 0.10749246264176984, 0.07852391264731846, 0.062104848123365836, 0.034056074782124454, 0.009257698548026383, 0.033862963168611454, 0.10500982448819185, 0.07309451729299561, 0.08691563210900753, 0.09809953521095938, 0.230911111819648, 0.09843770940337451, 0.07921314663103513, 0.05715947861092226, 0.02498709912141485, 0.010049380512247163, 0.07490919572451422, 0.07420592701002475, 0.04537165690694125, 0.08604881128356343, 0.07132602630243187, 0.03543380730515046, 0.014791376663432007, 0.04759975468679782, 0.053935841912583965, 0.07621961976251296, 0.048159401067682815, 0.01257604095078404, 0.05618874178898912, 0.028028832072572365, 0.047176832017759164, 0.11489893174580029, 0.05226525695874326, 0.07283403207698176, 0.06392436440012629, 0.06879835750066465, 0.023016621388735312, 0.03779842961399305, 0.03237450795788919, 0.07040364111983968, 0.10284239321105904, 0.026844090504211285, 0.13206865518323838, 0.11594009120017292, 0.02811605884363094, 0.0704819965927351, 0.0918613578523359, 0.0301083222016572, 0.06596231532673683, 0.030684665468851888, 0.03976585831673395, 0.06564748383337451, 0.018669283092622797, 0.21364437866835825, 0.17413298028611368, 0.2136327341319092, 0.21636996628536334, 0.1900341310688565, 0.025628831823386496, 0.006883079749381831, 0.039953304710046905, 0.01805322774265322, 3.1378046975981806, 17.96948779013849, 64.34631401492705, 80.37410305392358, 70.20026714571061, 62.74142134574152, 61.37697781285932, 43.07422584103, 54.205857476880475, 39.011073958489206, 22.321520274685277, 35.71885608857678, 25.598625252323767, 38.15490291964623, 46.35285269829535, 27.140571724983957, 8.630692132057684, 0.9357578908243488, 0.0188184040223038, 0.07661110601357876, 0.12260612100362779, 0.434677368931232, 0.7012893884412704, 1.4561372706967017, 2.186810604987606, 3.5282604684752807, 3.3771898909922573, 4.305752929179899, 5.719787478446961, 6.0418557447771875, 7.892438327112506, 9.625397363016683, 11.524137335438883, 10.19643170218314, 8.576597744418729, 5.952344315667307, 6.308187621255075, 10.191402243029687, 10.713261827345818, 3.8494344344062195, 5.229948163032532, 5.829557459200583, 4.303972663417939, 6.570177924248481, 4.9026969748158615, 4.908399120453866, 2.2734390920208347, 2.724838444302159, 5.800293635937476, 8.504740903454444, 14.03631639096045, 18.137810422528176, 37.40583612072853, 51.18331824579547, 48.86191837249264, 51.089726571113836, 50.41782848296627, 61.304876804351814, 57.90377393845589, 62.838688281274614, 53.30534404323947, 65.07051298695227, 35.469122702075595, 23.801293257744085, 19.47423842645461, 17.473335419931722, 13.02848102584962, 11.3822102931238, 9.799763387249364, 10.275081107693335, 15.070317887490797, 18.392111409095026, 15.670224793495672, 9.823069130220722, 10.322884994168437, 8.89634249671813, 9.021562203284233, 9.371651391829214, 8.746000989790886, 5.549058471956561, 6.000188406436674, 4.747565273315677, 5.0780950727001315, 4.609639048576355, 3.8885443873943824, 5.633259011853126, 3.978830484613296, 2.925152418113524, 2.2901224032525094, 0.6203115046505006, 0.4864251066840464, 0.1363989058881998, 0.09342024718681652, 0.052177934426694154, 0.020958805802248178, 3.419642438811641, 17.874352662794053, 45.04658968217912, 69.25136735362392, 70.42761556563839, 62.22458239524596, 34.778656113532286, 28.84037006285883, 19.850715360333844, 25.30250003260951, 37.192925945405044, 47.49506258195447, 59.53964940963253, 69.66433801958638, 75.53625952812934, 71.27525544935658, 28.2931209764173, 0.6518311197719266, 0.00897483686135421, 0.022858069916706414, 0.032573181369732467, 0.043489110746210626, 0.04977155266509903, 0.019674511108126853, 0.07084933575242758, 0.14507521935287984, 0.08388406897504484, 0.14149954993157618, 0.17079541099167642, 0.162939332545765, 0.09618578628907282, 0.06004074295502036, 0.0240465174354012, 0.0050818274875411825, 0.06833269861677001, 0.07779276599326441, 0.08099474538598331, 0.021426429701668602, 0.045553503197527705, 0.0479718167785435, 0.0411328234739842, 0.08300859901693561, 0.04845863118046715, 0.019470999851041747, 0.01157595051242219, 0.0705976682084222, 0.026331328704292258, 0.013487314028034528, 0.06384588252272337, 0.06910964200693755, 0.07249107749591913, 0.19596610308414508, 0.2530487392458224, 0.1550810171231147, 0.2198480820703891, 0.1737689353044956, 0.12253982375466055, 0.11936157010495664, 0.1834028893180432, 0.28508589272537543, 0.18858182754728103, 0.1866015975153254, 0.13230615776152382, 0.11719288244362801, 0.1340858566184198, 0.2114127032578953, 0.10618651255724892, 0.20262671664597529, 0.10764252394437791, 0.12027234905549597, 0.18227139277563942, 0.3951883249946179, 0.6520941024345737, 0.4275867655392616, 0.6081356709041904, 0.4411264196518929, 0.31395416947141774, 0.19951109834496053, 0.1212078266807141, 0.2024500414488777, 0.16881950169561372, 3.6142724079470483, 25.61137491656888, 77.55488380309075, 91.9055889498803, 79.26684148849981, 72.36419954607564, 68.72219254893642, 52.581494162159586, 58.776505224166385, 47.08166437764322, 24.292426955315378, 40.779552998081336, 43.886587927418375, 66.97799298071092, 69.08494903195289, 38.04046776986892, 12.279901581425822, 1.4326905675472752, 0.19622422874935214, 0.1835995287664475, 0.12885834841478255, 0.262068352031131, 0.6746908157102524, 1.49026949078806, 3.292637073224591, 4.804362174003355, 7.215830452980534, 7.893680737864587, 10.707715595922163, 11.442070564916058, 16.861849677178167, 17.076650434924712, 17.586097678830548, 24.60068210478752, 18.582189467645463, 11.78126537030743, 18.3945805411185, 40.186663212314734, 23.310014432476414, 10.187504387670948, 12.58492567846852, 13.200773096853688, 11.439544558525087, 17.45199772619432, 14.594732465282565, 13.057747790890357, 10.092990955998822, 10.925448325372512, 11.68963291952687, 8.538627239965624, 17.33497381210327, 21.21805948595847, 42.26867691163094, 53.3067717859822, 56.60441037147277, 52.768265662654755, 54.62416256627729, 63.941603860547474, 64.75848059500417, 68.62709076173844, 60.0556097492095, 68.70604807330717, 42.053252497027, 29.203314819643577, 25.812567011002574, 20.133010302820516, 17.637053189739106, 15.477896275058871, 12.090344217515762, 12.322559318234845, 18.42643410928788, 20.715988259161673, 19.07335258299305, 11.042678163897607, 11.410594524875766, 13.414596203834781, 16.54395922537773, 17.966730363907352, 16.00443720817566, 8.837995279219843, 8.773858643347218, 11.297615555024917, 12.015631891066029, 7.53618170176783, 8.146982990926313, 9.206660812900914, 6.776474983461442, 4.742489236016428, 4.071360913015181, 0.7632532150995347, 0.3283314334769403, 0.48142518788095445, 0.2613223049669497, 0.11386677382453797, 0.3601017738542249, 5.0547491254345065, 25.00660034918016, 51.751759898278024, 67.47702829299435, 70.97859090374362, 75.37469710073164, 59.56963200722972, 32.44408492119082, 21.262919633619248, 35.28725024192564, 41.5107887021957, 57.19755511130057, 72.69069763921922, 81.54565226647162, 83.07793401902723, 81.26628537331858, 36.35895944410755, 1.5876729738327766, 0.40542678366745677, 0.2073326109037284, 0.19665844738483432, 0.09304671803669584, 0.10776623948326997, 0.10072421372657824, 0.34121862582622037, 0.3288529248487565, 0.21093517001117432, 0.2572999143552396, 0.38242686299547074, 0.5035022483958352, 0.28148267478231465, 0.19820157829071247, 0.18618915109865128, 0.121454399740023, 0.22046633034704194, 0.11361720536144511, 0.1527685500801571, 0.1304354783027403, 0.15251574106514454, 0.19596645548459024, 0.1098964312264035, 0.2044853838461061, 0.22322476781424017, 0.16088823938081342, 0.2247152225144448, 0.23239779736726518, 0.2779523271226114, 0.2175360900019446, 0.24420704272004867, 0.20162637435620834, 0.3524384124865455], [0.06316275042932361, 0.02199930833622573, 0.006059513205752498, 0.018721740963237903, 0.08106534038820574, 0.023052736688705704, 0.0732847982116284, 0.03537772200821388, 0.024719878077326764, 0.04783282161600167, 0.03483735806038303, 0.025427138109901742, 0.056187856957436576, 0.022441459812163826, 0.08332641059232336, 0.022144051073419473, 0.05424798060689242, 0.007918250790211342, 0.05287394828854069, 0.1292483024899998, 0.20677209501304936, 0.18677815013835508, 0.22828597365127457, 0.22463820003453763, 0.12812261289406207, 0.01999311558451624, 0.12161791354658143, 0.051247819416945985, 0.11880836269307522, 0.31784914433956146, 12.583617568016054, 52.825367527623335, 69.63906226619598, 68.13021275304979, 54.15929894293509, 38.92218128327401, 47.59449466582268, 51.23949443140338, 87.92543442018571, 78.92088059456118, 36.5759410396699, 25.5783740551241, 47.02950077672159, 44.77201200300648, 23.63337855185232, 5.810061318259086, 0.49249993877545484, 0.02811928215857235, 0.06503318090953174, 0.09698413417584474, 0.00926155484311523, 0.2084115844580435, 0.9260606273047386, 0.49988232973602514, 1.4817776819390636, 3.0310522452477486, 2.2030445596864148, 1.8744667523330258, 5.448940463604466, 3.85333278006123, 3.72694052996174, 9.009902957947023, 9.50410787136324, 5.733746213297691, 6.585142256752138, 3.262431145675721, 7.379295720208076, 12.376508578177422, 17.48062906726714, 5.432563097246232, 4.324633748300614, 4.758759227491194, 4.925209418419869, 3.861897275332482, 5.44392228126526, 7.349684276888448, 5.867275461073845, 10.453360676765442, 17.98877996783103, 32.74084360368791, 32.37744385196317, 36.126284445485766, 63.86257986868582, 60.042359982767415, 44.54267101903116, 39.36862545628702, 42.45147505114156, 47.04654739749047, 46.42580878350043, 49.12767856351791, 45.88604357934768, 40.402828954881244, 51.42244162098054, 29.45156751140472, 36.905749613238925, 44.523639678955085, 42.30053832454067, 41.82548830586095, 42.962485359561065, 46.385702548488496, 47.0052566066865, 46.265846683133034, 42.25710591962261, 38.9035931710274, 30.650500751310783, 26.108472577987182, 25.151984960802142, 21.523159088626986, 16.651879318298832, 13.055364951010674, 16.716043410762666, 8.649484207553249, 4.379879841881414, 3.181481760355734, 2.65547770165628, 3.6028703230042614, 3.197606133837854, 1.584670031743665, 0.8794434416678645, 0.612310788804485, 0.3493671047110712, 0.13075251612932454, 0.0467658986247355, 0.04010186448032337, 0.0819180651958431, 0.044467883830469464, 0.508680267319564, 7.366286198939047, 28.049514332125266, 31.879887273234708, 51.885398972419004, 69.59179770561957, 29.302662572553082, 41.13521391345609, 28.557000390944946, 22.297811508178714, 28.744468112145704, 43.22938303793631, 52.69529781033916, 60.50492117481848, 59.72458524088706, 58.79800373508085, 23.376212273874593, 0.5765447789622892, 0.04785619878901109, 0.06299092073834713, 0.08776742228937727, 0.0267643426665135, 0.04549109001433657, 0.014146943501527271, 0.07724264591571785, 0.01125812170005614, 0.09127922296043366, 0.08787226908269428, 0.3029116555567711, 0.08392309349390768, 0.04506983741697285, 0.05617018713946304, 0.009261673586743494, 0.1204248771612202, 0.04744030497667771, 0.019046395619009292, 0.057503766184973146, 0.008546396444040922, 0.04225123523464126, 0.047295885911631974, 0.03735157052776025, 0.02778957132250071, 0.02136810742799313, 0.07418407052154503, 0.0143064669476101, 0.08514133417197774, 0.05370889985633474, 0.055297145680073774, 0.0736350306279717, 0.1334203713603558, 0.08961431471811188, 0.08284475579256974, 0.09317987943969427, 0.029924233188672416, 0.03793072150719743, 0.09870706591755153, 0.09982808237715114, 0.032869186252355576, 0.04874094607188337, 0.038709645234649225, 0.027438524937737855, 0.03728082230795295, 0.05129196140314302, 0.058577518850084276, 0.11782877372517703, 0.02725075678749671, 0.041733666232997374, 0.010242868466452967, 0.05022329173140949, 0.03656934496135481, 0.18312015690870825, 0.13554542265351743, 0.1323615612402078, 0.11443890360814911, 0.027094388666052013, 0.11633120972903506, 0.02933462702428862, 0.03228499441437664, 0.09110640118559522, 0.4662549309432507, 21.199730250143237, 68.67693624188824, 81.76592473060855, 77.56524670508601, 65.38162362190985, 47.696335084976695, 57.46517058341735, 63.70457110866424, 94.59681341725012, 73.77864545391452, 25.62154366124061, 26.637355166096842, 39.67168346528084, 43.47664533122894, 21.025410313760084, 5.698258569163661, 0.46976306205314977, 0.1343473224269767, 0.03939801353901144, 0.3998794797207079, 0.49172330948133625, 1.4312536317494609, 4.544356590317142, 3.510678199029738, 5.345721331334883, 4.446969041901251, 4.557252853147445, 5.3121350561418845, 7.8379821008251565, 7.127860515348374, 8.467298938382058, 8.12744321361665, 11.81576849952821, 7.734167748881926, 7.005199665023435, 5.648852394473169, 3.666557602344021, 5.732114507306007, 5.0208044436670125, 4.8863632448257945, 1.1340633659593522, 2.986535304977048, 2.5268984850375884, 4.675332375111119, 4.611802726022659, 6.310473382472993, 6.0267497166510555, 12.084121377237382, 19.583605873969294, 34.40621922093053, 35.255329993463334, 41.136523985093646, 68.15708098873016, 62.62707641047817, 50.83925185665008, 45.27152584445092, 49.45186245825983, 54.24071165823168, 54.64273498904321, 55.59134060336698, 52.27022271002493, 47.34267065601964, 55.01628191240373, 33.34938364644205, 40.760909972652314, 50.59627279158562, 45.67156445595526, 45.03866649443104, 46.01052784150647, 49.43248594960859, 49.74183544035881, 51.18875857322447, 44.0204898003609, 41.58226997621598, 33.439782511803415, 32.44721105021815, 30.41034579277039, 24.682287016222556, 22.397569148771225, 14.748116750870983, 14.284750492342058, 8.915321865389425, 6.087154707600994, 5.8175064671424135, 4.345122248895707, 5.321223678127413, 4.180775919268209, 4.088998340791272, 3.310837361120409, 2.1996720567826302, 1.3721041669768672, 0.5285398710158564, 0.036756622815324415, 0.13020919125166633, 0.0935887099213658, 0.051753697916865356, 0.55096737079082, 8.864225149154663, 31.776038600552468, 41.350642250430205, 58.220964247180575, 59.837926049386304, 21.226059159924908, 26.68813220916256, 31.895735609915953, 26.456933982910652, 36.823685784493726, 51.68963739948889, 59.75297927856446, 69.04451724021666, 69.60963664516326, 68.7108176754367, 32.76526231919566, 1.2240324866387153, 0.041903622838999, 0.04038036042343705, 0.05294853843928826, 0.03682170198449204, 0.01618893362671858, 0.05719977866617903, 0.04344714828015816, 0.024771223205231854, 0.06559425604439552, 0.006470092283111187, 0.10581096859588739, 0.032732278679407416, 0.07811934927538519, 0.05350973614821992, 0.03525878685796934, 0.12003125352484566, 0.02809120886658709, 0.040433906138904636, 0.0530159656679438, 0.035071635408507246, 0.09681501260568058, 0.03894682605600646, 0.16059734047420565, 0.034067772944728215, 0.07958074626062187, 0.01778489395585512, 0.032921843305831, 0.11365454448687454, 0.013057435280643405, 0.004360325401648879, 0.07445688209226055, 0.0822160887201467, 0.18954332917928698, 0.13186927314006514, 0.18169920170499435, 0.1253598546909709, 0.19449011212395084, 0.13283999847067943, 0.12958247004257095, 0.17271456849430838, 0.13572056567476642, 0.0788373192171416, 0.08704839514628535, 0.16181666133624895, 0.15120787576081293, 0.13518575969482624, 0.23262111199719293, 0.16254554803092636, 0.12315257152001705, 0.13037344050263205, 0.1307680830359459, 0.2542517424350785, 0.3274841095891691, 0.45220107861584236, 0.3994036471891788, 0.38342556585707976, 0.2544173246790325, 0.2602771465336123, 0.1771088488279812, 0.1323697430592391, 0.2124955225735903, 1.0390101180922602, 29.420725914739794, 84.78017207114928, 89.97109167037472, 85.91644348636751, 73.62517095381214, 57.291170320203236, 62.91675129244405, 66.01048546452677, 94.00751652256136, 83.29502936332457, 47.67560928098617, 37.082479846092966, 62.783684884348226, 59.48913712655345, 30.7416291775242, 8.094960595330885, 0.9834642696284479, 0.19429783937671494, 0.3722359630609713, 0.3444799234069163, 0.4238414842515223, 1.324589555301974, 4.764587869567256, 4.770967114356257, 8.508145520764014, 8.699238492596535, 7.112081310441417, 7.9714137796432745, 12.657289485777579, 13.027926991062781, 13.803390360647633, 19.615135846599458, 20.868778305668986, 13.03995886156636, 14.4256135917479, 11.700253717360958, 18.91552229081431, 23.625082738937873, 29.099697566801503, 12.758713153100784, 10.515193900754376, 13.6690717358743, 13.701850002811803, 11.006294258179205, 13.081601685093297, 15.263509327365508, 10.935010083260076, 14.042770651078994, 21.200181322713053, 38.167007353998, 40.006528362151116, 44.122832282896965, 70.38444595952188, 63.62515880215553, 58.10172027157199, 50.72708775920253, 55.3605208858367, 58.25610083918418, 58.91090131575062, 62.49215472129084, 59.494165605114354, 54.48658935485348, 61.83186292648316, 40.17377038155833, 44.76422217584426, 50.398542188829, 46.507629425294944, 44.98424360829015, 47.170282486946356, 53.77267483742007, 56.49940067721952, 54.17800080391669, 45.675482903757405, 47.6644697496968, 43.441673478772564, 36.613352606373454, 33.40648551141062, 28.681980832930538, 22.320084687202208, 19.529016287096088, 23.52454846905124, 14.936384635586894, 12.309808673397189, 10.535287222554608, 8.277412095377523, 10.052286559535611, 8.502371791870363, 6.522463271694799, 3.941832973111061, 2.9860906062587618, 1.1653475775834055, 0.5170155797273882, 0.12219411891794975, 0.2514502201830187, 0.22460397122608078, 0.16544882208108902, 0.954706309543502, 12.454702988747629, 38.94659803759667, 44.708073446827555, 62.89185993133053, 78.69961969314083, 41.0929621419599, 55.80267006351102, 41.6158180082998, 33.62271401189989, 42.245527082873934, 63.19703602021741, 70.89730370429255, 76.81151620803341, 76.55180038944368, 78.53017330169678, 39.88069088228288, 1.9042350904595469, 0.31704735671800954, 0.14811330955595742, 0.2216415092228882, 0.11597941449332623, 0.12517833015731267, 0.189820637686118, 0.23991786964958717, 0.14155547435004867, 0.27548818999240476, 0.5416755210007391, 0.44176971900366974, 0.1713828012467392, 0.24399613871449427, 0.2102049962887841, 0.1054043980735925, 0.21366886283841827, 0.07479108794922791, 0.17735364456330577, 0.17960529954683396, 0.1100980808898326, 0.2874984568165195, 0.1821505960317389, 0.3505102917551995, 0.17234013536043707, 0.17901574892382469, 0.29216108242830924, 0.21422564022002683, 0.21608868944308451, 0.1878291155181585, 0.18898076017297086, 0.1808983640324685, 0.26276941441239854], [0.005323582332611325, 0.04279742145069665, 0.01115967652895638, 0.033967882740281286, 0.12090814840649405, 0.12252760465226828, 0.09715576851440054, 0.03962589405296792, 0.016986741421503887, 0.016378059667805513, 0.08281150757665597, 0.02080794776819887, 0.060055367573494875, 0.040936306599647775, 0.07995845058992987, 0.018689055821948478, 0.07332415214829868, 0.05873137228791753, 0.04285533769777225, 0.09370538511223371, 0.08085025354258477, 0.1274434836100667, 0.0939618866710413, 0.34393642998991475, 0.059347540635855935, 0.05301243783305249, 0.06802063270081436, 0.08441996279983752, 0.09613923112591428, 13.859189018126457, 52.74226819315265, 66.93920073970672, 64.4451145971975, 54.396347384299006, 41.28613102820612, 47.24436429239089, 34.44813759096208, 21.097495632786906, 25.381349478998494, 26.01214505011036, 37.917779953249045, 45.082961820787006, 43.86558363514562, 21.730801520809052, 3.9303980383180805, 0.3676037664615339, 0.20155194125348525, 0.011435059282267767, 0.04033731011253211, 0.11903689438176733, 0.5812389367530423, 1.3475878825110774, 2.164110132763463, 3.972998900759605, 1.68854444498016, 3.3142618354289763, 3.028437495231629, 2.228368852407702, 5.62485239198131, 3.824071163131345, 5.754560760913357, 5.586556330803902, 6.764983419449099, 4.816606342792511, 4.821721113497212, 3.7682832921704943, 4.3977604566081885, 7.856036770728327, 13.48199527109823, 13.329773968265904, 11.203533584071744, 13.990792382148005, 10.525433248089207, 16.066604814221783, 15.51889386869246, 18.997125241064257, 25.933419158381803, 41.99306764910298, 50.6040390845268, 63.361442165990034, 46.96270673505722, 48.363110557679214, 60.61247648731355, 60.05825734907582, 52.438586527301425, 36.67662828199325, 46.52349933501213, 44.43998336791993, 45.47134707050939, 40.49762871957595, 37.867330428092714, 48.78031738342778, 57.69397028030888, 36.26521087461902, 50.693692699555434, 63.644409794961255, 62.010154262665786, 65.23525645655971, 61.17878437042237, 56.41132385500016, 64.00346748290524, 61.99430004242928, 53.32784275854788, 50.33229727898875, 60.33005014542611, 53.349729584109404, 52.145189316042014, 46.50642133528187, 46.59838522634199, 41.89454163274458, 35.91553157375705, 18.233439768514327, 11.460998942775111, 8.069527456837317, 5.526972095812521, 3.5800715463776744, 1.0075408809127346, 2.0811809310989995, 3.1962663992758724, 1.747218690091564, 1.4776574772211815, 0.1954166954683681, 0.16449697315692902, 0.1364633338826318, 0.12506310287262165, 0.14667375373744196, 0.1563004299157089, 0.22165776560864142, 8.04346085556092, 32.949454861302534, 37.045240863676995, 56.20292832774501, 91.12108353645571, 82.52545249077582, 44.05425356280419, 42.20979036823396, 20.08449842852931, 24.96278747435539, 35.41893205335064, 46.04977115508049, 60.99271105181787, 61.83835837148852, 60.98364253197948, 21.90785534920231, 0.7106628725605627, 0.05472462902206087, 0.12427478307677854, 0.10212314390246907, 0.045308404857473034, 0.02339286440532775, 0.10684562396378287, 0.057793374233428514, 0.09878143773324068, 0.15328693113500072, 0.0657582295037085, 0.0670748052277392, 0.08294130585366681, 0.05314698968563349, 0.094286133384993, 0.03040628443892685, 0.03021107757494094, 0.0654060818675545, 0.047823896691683805, 0.035509109917667606, 0.06782171031039569, 0.07999935968508644, 0.05416196808519383, 0.07827687993525498, 0.029304240146772038, 0.09586420556109759, 0.04485327585209762, 0.0211304975973983, 0.022943875594665448, 0.1141509541400498, 0.013078329371168249, 0.09028646494111708, 0.06203141093494431, 0.061091275495146556, 0.04133556098226578, 0.04358481428015136, 0.09863509961794462, 0.05474106926891593, 0.041933446641891234, 0.03166551848182515, 0.02721243323908458, 0.055269267740509206, 0.05724119337936563, 0.073784310520897, 0.025178144212752104, 0.025650272709167293, 0.08133190834233839, 0.052209884123576265, 0.03956113664072849, 0.03608682831268638, 0.03701568693823872, 0.1107063010755566, 0.08036957933537422, 0.13471637762361957, 0.07095028315821002, 0.1770211164388926, 0.042691099938125386, 0.011799740116863001, 0.06288333518070079, 0.06767635278764271, 0.05797951444683056, 21.15213817165744, 67.42988924826345, 76.36805303635137, 73.44148635864258, 65.40154141764488, 49.36571544216525, 53.05458299575314, 49.09268317684051, 33.85361609920379, 40.561033833411436, 45.65762827473302, 39.64626650656424, 35.50787964174825, 38.51141106697821, 20.313362844528694, 3.5655256817417764, 0.44435900425718683, 0.11823518336900782, 0.2019895766411097, 0.12464886381020471, 0.5109983574478857, 1.4420536328707974, 4.2796583810160245, 4.548359369077991, 5.7872595998548695, 4.51187446232765, 4.28872739115069, 4.7741403118256605, 5.879496095641967, 6.0869188750943835, 8.041768843127835, 7.774409795961073, 6.093864902373284, 8.53591884336164, 6.057546206058995, 5.3944793343544015, 4.567679003361733, 6.88212255316396, 9.480405969004478, 10.875463601081602, 12.078786953803032, 10.376430249983265, 11.135587346169258, 11.550579993955552, 15.898696972477822, 16.282838217673763, 19.59287835705665, 28.171454937227313, 43.15951385805684, 52.38544625620688, 65.34208220820274, 50.312104917341664, 52.440488876835, 65.08547290678948, 59.62957759057323, 56.503723129149414, 43.439853499012614, 52.24607267687398, 50.51167511170911, 50.648679579457934, 47.50921841590635, 46.53794542435677, 52.510714992400146, 61.657643010539395, 39.90591564486104, 57.16660368827082, 65.32841274815222, 61.02266619282385, 66.45013609240132, 61.1620750734883, 59.072279391750214, 66.81985086010349, 63.80618403034826, 56.24661568672427, 56.8940774086983, 66.11085891723633, 57.423903326834406, 54.35264433583906, 49.49522818288496, 47.02356623065087, 40.55027477202877, 34.03506102100496, 20.55366881432072, 12.465690528192829, 6.820947797067705, 4.585649832602471, 1.7034284914693527, 2.3525966896164805, 2.5800895017962304, 4.608880069948012, 3.1108920901052417, 3.3959116089728574, 2.11503196627863, 0.9400496992372698, 0.2642377904586254, 0.25173715075417874, 0.07686991349703844, 0.03610417637373171, 0.2286742270112999, 6.770046218749016, 25.65752160164618, 37.580491419761415, 63.14588831317041, 79.44728620590703, 78.09371548314249, 41.060508451154156, 41.156155447806086, 25.946535564238026, 33.00199893213088, 45.17521596723988, 51.84256276776714, 69.72862566671064, 71.70009520746046, 72.12553116583055, 28.384072895972963, 0.9436162368905161, 0.03837300704852228, 0.07832021752913153, 0.10388368290037879, 0.01413381562733482, 0.10421022021722409, 0.03490200438987344, 0.06851798464213649, 0.05352581250331095, 0.16385863805490156, 0.07951035810213897, 0.0821755167036768, 0.06050431807976096, 0.07720890740353255, 0.08393811647810283, 0.05743403686210514, 0.02000812324695289, 0.03841019295636685, 0.002830178489074892, 0.03430962307198394, 0.057316120608799884, 0.05780623301923756, 0.043353118648331974, 0.07486883821266313, 0.016968443411432447, 0.07349062305424484, 0.02057826311718072, 0.04759335785263008, 0.06285171490162611, 0.014587266900156055, 0.03156134201544187, 0.028107836804983598, 0.19183224667945217, 0.20588600707630958, 0.08673672759605032, 0.15360775343593092, 0.21775368961595723, 0.23356788941929418, 0.11371403121419492, 0.11570957534375692, 0.15134889722591446, 0.12936528411603745, 0.15674129819437382, 0.14931257423614303, 0.3136998282805566, 0.12558519179301877, 0.25577198263377915, 0.17206060519862562, 0.2241357995737945, 0.14578581186792544, 0.10709551418380392, 0.2928411233569345, 0.19088943759279867, 0.3437692696048368, 0.28366691402850613, 0.4566176980733872, 0.19217628144448806, 0.14973675711981713, 0.23061151015422038, 0.17327275547769763, 0.3196587359472629, 29.154616632769187, 84.89279900827717, 89.0906999957177, 84.72951858274399, 75.65894342237904, 58.52699541276502, 62.25347065156507, 47.65052572373421, 31.38206005096436, 35.15069292437646, 35.372012661349395, 48.873493286871145, 62.573794934057425, 55.88236478067214, 28.777835715201597, 5.444519462123995, 0.7863607558031237, 0.3985796430178227, 0.21796151394805602, 0.21440024697972884, 0.38874221605158626, 0.9520254308177579, 6.039218441132577, 7.302313322021115, 11.271222906727946, 7.469718610086749, 9.207731619957956, 7.457868149203639, 10.17191198564345, 13.974538080153929, 9.681175428052104, 12.31713075791636, 14.500765223656932, 20.2210263283022, 15.87033921672452, 14.638027587244588, 11.782525431725288, 9.892696103742047, 14.447348425465247, 19.30391734646213, 20.387638807296753, 15.666599542863908, 17.689618833603397, 15.595813508956665, 20.7641000516953, 19.95518376750331, 24.10913851953322, 29.79829522871202, 47.42478155320691, 51.10515325300155, 65.04919098269555, 54.68901895707654, 57.41277164028537, 72.40907930558728, 63.268878152293546, 61.259392999833636, 48.72142691766062, 58.866182373416045, 55.543338637198175, 58.81357946703511, 53.52336506689749, 53.00353334796045, 56.05517264335386, 66.45061462156235, 44.39729229096444, 57.20945558240337, 64.180691934401, 60.71881194268504, 68.104905620698, 61.974519529650294, 62.82899218220865, 67.44597096596995, 63.466730348525516, 62.34661909841723, 60.51641764179353, 64.26748221920383, 57.02297041493078, 54.593156230065134, 49.437894898076216, 51.36676357638452, 45.807270619177054, 42.52768278121949, 22.468799391100486, 17.77849581933791, 13.636976941939324, 12.129807183819434, 9.63142212360136, 6.237533477044875, 8.68919820554795, 9.031283797756318, 5.17524286623924, 5.429229082599764, 2.0968461421228226, 1.042178780321152, 0.34719910652887437, 0.33090404865722506, 0.3142834034177565, 0.2699907124042511, 0.5384422009510379, 11.179170762338947, 44.69278404789586, 48.5149690412706, 66.83513241429483, 96.57947740247174, 93.61797809600831, 55.937113223537324, 54.236534333998165, 31.682262574472738, 39.75765005234749, 51.19540699066655, 62.22663379484608, 79.5241803507651, 81.77586401662519, 81.69496120945101, 35.16206387550601, 1.4759952502865947, 0.34842567458268137, 0.2158151960541164, 0.29976812101179556, 0.10826582074045174, 0.251083693076526, 0.2137757474256139, 0.2316512906503293, 0.26533577831522115, 0.3343713319590015, 0.35219577711916744, 0.3053042707183669, 0.18828366612715108, 0.16473110494834764, 0.2349881091786008, 0.30206788631696857, 0.24921146612013542, 0.14906466818384587, 0.22480995694716133, 0.16550928174007326, 0.2359510357341459, 0.22917898702284983, 0.12376993113467771, 0.1800060248182666, 0.17522070256452407, 0.19388288019164918, 0.1734127044197052, 0.125933654546257, 0.1735287514184752, 0.1279161905028647, 0.0874219932443192, 0.21847657018130828], [0.036814707601743366, 0.09011638576104757, 0.09077037970024733, 0.0973217414631959, 0.02393493672922975, 0.0936317180974349, 0.026421483846441395, 0.03211528678695041, 0.0516425462199315, 0.03956572550739493, 0.02195473159513166, 0.011175775866685136, 0.07752825115476886, 0.0462906904548647, 0.07333391976933326, 0.028172312679910855, 0.03560026288933812, 0.023547863144607797, 0.03370090492910916, 0.07485022227610312, 0.06420940656455294, 0.12782720939045952, 0.11155462087762934, 0.042203994422790506, 0.10991723817442695, 0.058488319402620684, 0.05818130200608604, 0.33848363064950515, 8.968080685984704, 47.50189927316482, 71.16144395643666, 71.38053970952188, 64.48043161822905, 50.339804695498565, 51.97001626414638, 39.51043482749693, 19.664540060104866, 21.652673790531775, 21.764655497766313, 14.112361342676225, 28.09197791161076, 46.559632209039506, 20.844088946619344, 3.692266042194059, 0.04626211920572866, 0.015608357723742245, 0.05365636920736683, 0.2435636361159625, 0.25938324450004485, 0.8298158369237377, 1.2473444808875362, 2.888592741181774, 6.423392536178713, 3.950946355058301, 5.128848581544815, 2.899682752547726, 4.589923254905209, 3.208222273857363, 4.33712943907707, 5.5992147999425095, 9.731128773381634, 5.570261334219287, 8.62151868881718, 8.050733910452935, 14.091598276169071, 11.167406593599628, 23.790683246427967, 28.08077758358371, 32.349906852168424, 41.29440330689953, 44.217553600188225, 50.16715372762373, 56.60570475362963, 60.60504359583701, 58.13468387050014, 54.51530894925518, 56.40583253675892, 59.14645533407889, 61.06832650399978, 58.58511317160822, 63.86350554804649, 61.01959105460875, 55.5764042177508, 57.664795690967196, 58.476832220631266, 42.10075632218392, 42.4788845739057, 40.00705395975421, 38.26641590364518, 38.26989504598802, 39.76662443530175, 62.29726783690914, 60.085274634822724, 59.39609458369594, 63.36437217650875, 61.00263072598366, 61.122619951924975, 60.15767766583351, 61.51245647861112, 66.75900705399053, 67.37528985546481, 59.644004068067005, 61.048345950342, 68.4225626914732, 63.54624071428853, 61.955319527656805, 62.26648115342664, 64.53064580117503, 68.2153360305294, 57.048638405338416, 48.64081044350901, 41.362248543770086, 33.558928428157685, 25.387970439849365, 15.1272814889108, 6.761440048294683, 3.617459333712055, 1.9837629843142726, 4.019312286569226, 3.085618543048059, 3.721886310846575, 1.8327327336995833, 1.4026133427696845, 0.052399598137145086, 0.017412885490264145, 0.06945173090864575, 0.12147312292889242, 0.0034414431560904754, 0.08047995728350456, 6.723766173085859, 29.986653327941898, 26.982276631939797, 36.14790454987557, 43.42912581659133, 50.80756695039811, 50.83620417502619, 37.93396757495019, 18.804254454951135, 30.594771715902514, 39.27510438426849, 47.91886683433287, 60.705083647081935, 59.827763188269834, 43.23059505031955, 15.916585922241213, 0.2765117141027605, 0.028654241356097405, 0.022002596768640706, 0.07410275028838266, 0.10606841244284185, 0.08308421955594132, 0.07195348295593454, 0.025521868712178646, 0.06883784933316131, 0.015802206696882364, 0.08377702350938514, 0.03326327337192432, 0.040906735605770544, 0.0064469803680455495, 0.06724832414258873, 0.01889848893868827, 0.10084543947971637, 0.09589330924134101, 0.08773471033501049, 0.04641832836392907, 0.0663164088262185, 0.008101322342671694, 0.04758988747433309, 0.029296711417696172, 0.0120285025895423, 0.0465341646885199, 0.022957270642021493, 0.005153859383426607, 0.08512756757197842, 0.03161758244518311, 0.0518932331713938, 0.024702047380889137, 0.021478355141176332, 0.0646028693224634, 0.08612931180264681, 0.036999185404349724, 0.06846710108220577, 0.035149136693367077, 0.011992769375924143, 0.06345033600565887, 0.015973605463401448, 0.04320358594639167, 0.05238365201700119, 0.026484343275848417, 0.07470505627533121, 0.03949555951441008, 0.032378752084989706, 0.04725692267980307, 0.05919746784192901, 0.06180344232087655, 0.002289756845247241, 0.07493702769880334, 0.05893953752914264, 0.10075816674338234, 0.11873956033659559, 0.06558680966977151, 0.031715425279652404, 0.08005468655497798, 0.3332653461444763, 12.435313732393327, 56.290424639178866, 79.04885968854352, 78.63374740846696, 72.7670975654356, 58.63166386081327, 60.901676762488584, 55.82001086204283, 29.962034571555357, 28.74587232066739, 28.08978726786952, 19.916952425433745, 29.00810826209284, 42.23733325158396, 21.38876299704275, 3.6239410504218075, 0.07487040103202866, 0.05276337498798967, 0.15118663980355188, 0.7325897798422845, 0.56757039600803, 2.523991028147359, 2.664511900755667, 3.972971199020263, 9.090740065420828, 10.392878709300872, 7.042629862985304, 6.145893671820241, 5.058649432274604, 6.521059553469382, 6.707729072340074, 7.08846717111526, 9.333202358215086, 6.861975298773858, 7.270592133845053, 10.801045452394794, 15.133748496732405, 12.302644464277453, 23.821032585636264, 30.07381427672602, 34.49928529800908, 42.481481182959776, 48.02578280048986, 53.706131827446725, 58.078825396876184, 60.51006732448455, 58.29959992439517, 55.19252969372658, 58.86979879871492, 61.21850229078724, 62.75028197996078, 62.2013972651574, 68.65334710767193, 63.75573450519193, 60.24473074943789, 59.46136674573345, 61.36348878183673, 45.728682010404526, 48.62769011528262, 46.94016879604709, 44.670846231522106, 44.74926617837722, 44.893472117762414, 62.868925832933, 63.074799276167354, 62.466753452054924, 66.26472565435594, 60.60904833578295, 61.469412388340125, 61.77029348188832, 63.07743510892315, 66.25619842160133, 68.33110870853548, 59.08327379534322, 63.8977909857227, 69.69795273196313, 64.73822155306416, 64.84820089032574, 66.08614798515075, 66.97608670880719, 70.60621676906463, 61.70223643702846, 52.91006326675416, 42.068298709008005, 33.832482368715354, 23.83352141226492, 15.802989179088225, 7.5784432791894485, 4.701531846677104, 2.0782276315073815, 2.8270909574724015, 4.252861238295033, 5.743979677077263, 3.4948480033105422, 2.5028707808063877, 1.9318931934333619, 0.14596043394938593, 0.1493641166316886, 0.08350597394089546, 0.05245258843886757, 0.09985513294175749, 6.259596809264153, 26.981980492991788, 34.285673018424745, 45.150030428363436, 45.35580188997331, 51.61531240709367, 48.59214167441092, 39.377407643102835, 24.91222616164915, 40.61365242927305, 47.32647911194832, 57.197041280807994, 68.36385265473398, 71.47251144532235, 58.423009457126746, 22.987295542993856, 0.3709143694610365, 0.06590796138850913, 0.09126134246828095, 0.030146107573302525, 0.046129773686369585, 0.015096106329902768, 0.039033263756503025, 0.08947202920793526, 0.04445723137788234, 0.018283402689942913, 0.08600381127889119, 0.014842379924600885, 0.09672628430229041, 0.10445245721888159, 0.027534946679107608, 0.05737795156516856, 0.020194763332725536, 0.050630471293604186, 0.03744959147767194, 0.05299002593082767, 0.05199502710433257, 0.058722493328875115, 0.02540544058466631, 0.04472353886212072, 0.008190535196673968, 0.09917675442392788, 0.03138385668036438, 0.03910841315143532, 0.0469103828072548, 0.07271476750892979, 0.04191074362625519, 0.20932908199967878, 0.1238507534106893, 0.19728253325147016, 0.16248421503170846, 0.17066664693336334, 0.22098039066599262, 0.09617819435774319, 0.0980223288699504, 0.10060161667605562, 0.20128318228788916, 0.10319748262484228, 0.19632195092497334, 0.12758686462597502, 0.1638113091429395, 0.0956953980869824, 0.12116009174215218, 0.15122521999141864, 0.1480414351869014, 0.23311626526617238, 0.20235552152077999, 0.1525368850918547, 0.30905549684839867, 0.28381253202115336, 0.22008622816253096, 0.2659868917638256, 0.14095601054929918, 0.1531892089593795, 0.5716177304425548, 17.538433036496563, 71.80624238906368, 89.62486405526438, 91.31266778515231, 83.3345276309598, 67.63903002585134, 68.25587764863046, 52.44014370825983, 28.499494521848618, 31.5404002512655, 31.714735877129343, 20.924609322701734, 40.853242566508634, 61.56671462520477, 26.89220528448782, 4.8984961163613105, 0.23466736348646305, 0.19726518902086443, 0.22530633595681962, 1.0185790434479713, 0.49939384143198695, 3.4437439326317083, 4.670262221367129, 7.696307070793645, 15.03079608563454, 12.108813678064655, 11.909626895381558, 7.800932372770003, 10.796881856456881, 9.57751012617542, 12.48587308391448, 14.67716205504633, 18.87873241978307, 14.045494737163668, 16.242290716017447, 16.886084041287823, 23.2831814981276, 16.611098435617265, 28.047459010154974, 31.307795855306814, 37.337139729530584, 47.37595981167209, 52.85959020737679, 58.48502212955106, 58.86942225117838, 61.73627868775399, 61.452852141472604, 58.99329462359029, 60.93953155702161, 63.22376305057157, 62.014492404076364, 62.991221412535644, 70.283860698823, 68.2840951796501, 64.91756800682315, 59.619959938910704, 62.83780182561567, 51.016582212140484, 51.70095735980619, 50.97849207539713, 48.01605532246251, 50.2437380052382, 51.69935311040571, 67.37016724001977, 64.86689882893717, 62.25004250003446, 65.04327212610553, 59.64821669363207, 60.66767600274856, 61.58134114357733, 63.44115257263184, 65.11965636284121, 68.56460740489345, 64.49171627721479, 65.0002045016135, 67.01244708030455, 64.08999496890654, 66.03433347517445, 70.54683992939611, 70.95271110534668, 76.52252381847751, 64.57340355842345, 56.66206529063564, 48.58938817054995, 41.714340102288034, 32.65233335956451, 21.81248684083262, 10.274420188319299, 10.474881741308398, 7.423627328488135, 8.412286716122782, 9.958240870506534, 13.180055137603516, 7.389479173767952, 4.030672451180797, 1.2345934683276762, 0.1172127471035046, 0.3152515546929452, 0.18969265503748772, 0.23134361441817977, 0.24901242115564887, 9.020825778284381, 41.83762804154427, 40.71507315481863, 48.13613084054763, 50.83272111031317, 60.66380462338848, 63.66543762145504, 52.95468414983442, 31.632024857305716, 44.56514227774836, 56.50697869639243, 67.5622143283967, 79.31347846984863, 80.01672806278353, 69.2329635927754, 28.52972815113683, 0.6057343836272917, 0.17844705121411433, 0.17430936436980002, 0.2362195495516062, 0.22167889431359308, 0.2032475389780537, 0.1581788928278031, 0.15933407680882564, 0.11136581084781116, 0.26364906721057435, 0.22927327712457027, 0.1851619038009836, 0.21634581919399, 0.22076455305420586, 0.14825037800736968, 0.10380446174812895, 0.12352352661471214, 0.3954736774246539, 0.08715089004967483, 0.15038773267259523, 0.15472818766870808, 0.13613328788309328, 0.09947699194233264, 0.14169355403752099, 0.10448293219650946, 0.1740099006001988, 0.1585897457815947, 0.21357155435027617, 0.24481864135351875, 0.17566333284541485, 0.14865980603762213], [0.03495951077990955, 0.02873067777874249, 0.04197676508356968, 0.06073003056489172, 0.04987433485146012, 0.043116420462367036, 0.03126615493167793, 0.01585763028537434, 0.04371722874742362, 0.01910281607941274, 0.08068647160525284, 0.02521889051422477, 0.02166869351640344, 0.06295729713935046, 0.01809670323235614, 0.02678721230627308, 0.04049793193717638, 0.03895573182812622, 0.022161699823975083, 0.1577818601001655, 0.062207381331151536, 0.0556275517409367, 0.042585012082371025, 0.01988110203866757, 0.04105487785812828, 0.06817220319663325, 0.05812799377787498, 2.8958822209988875, 24.26578425591992, 70.52861659757554, 70.33075655660322, 67.87099899784212, 48.3545833249246, 53.04589494582146, 30.978946301244925, 15.390634325242813, 27.00385162907262, 35.98468688226516, 39.16014363688808, 47.480526278095866, 56.026731537234404, 32.18781490479746, 4.167434467423347, 0.13683816538222376, 0.017829637321072723, 0.10309923950943256, 0.31928810260949597, 0.3395592487387119, 0.7430460832772717, 1.4076251512573612, 2.553530888211343, 3.507770742139509, 4.526142083829449, 4.6932355434663835, 3.65002358632703, 3.187205724177822, 2.7684762833579897, 8.239293521450412, 4.811461664015248, 12.040578165361959, 11.45130382430169, 9.74322340180797, 13.019462516230922, 15.519291989264952, 23.895065361453643, 29.79925032584898, 39.01059150695801, 49.554707004177956, 55.99197149276734, 55.48148285958075, 64.31504487991333, 65.83209606908983, 66.84777029099004, 60.26691175276234, 58.679026480643984, 57.04165658643169, 62.62386791167721, 63.04779767990113, 65.26674916667324, 64.24937655848842, 67.82576622501497, 62.58121605842345, 65.45504254679527, 65.66577580667311, 63.818645400385705, 52.33722463730843, 32.87151540479353, 35.98249035496866, 38.82945645240046, 29.740269645567867, 53.64262865435693, 51.95714696761101, 62.50321972754694, 65.26338377306539, 64.8661575009746, 62.755636015246, 65.36521634747906, 64.94376551720404, 63.47959572269071, 59.32489572032806, 58.97390242545836, 61.44941614520166, 68.4527257180983, 57.59276136275261, 63.106605775894664, 65.77104437735774, 65.62374368790658, 61.717047306799124, 64.36767524288547, 65.6412531483558, 67.27283754656392, 63.18266837827621, 51.334631519932906, 37.0058524224066, 31.093773688039473, 21.302490465102657, 14.615582804526053, 4.956061801602764, 3.0963089629527065, 1.248739496354134, 3.7589453545308884, 3.1291541553312734, 1.8070600854773677, 1.070891142852845, 0.13902257316775862, 0.04473371634019479, 0.036659735675540664, 0.05222070511550673, 0.08160132614354934, 0.17641799073786507, 4.771603028620444, 29.20734113262546, 42.054072272393014, 42.081885799284905, 27.54715677230589, 34.53625755925333, 51.05008709815241, 33.71132819883285, 16.66342285371596, 33.73948689429991, 44.02071729783089, 57.89976919850996, 63.81490345924132, 65.36884453988844, 50.579630174944484, 10.812463471966407, 0.3133134441750665, 0.04372102471308843, 0.04926408070229715, 0.05665684449336222, 0.02414892040823977, 0.027452364316089984, 0.04333035051522236, 0.011054844099787936, 0.022551249787812273, 0.08691278226192921, 0.06620419992794914, 0.04337574888561522, 0.0467007351858962, 0.02812859970295141, 0.03438976352974292, 0.03149146905108806, 0.11683361785065745, 0.04970307972642684, 0.0834986424794601, 0.0144747726341349, 0.03423583348311725, 0.05422486773421688, 0.026726231707500357, 0.005125788485466113, 0.024647605342550144, 0.011670668665770323, 0.01926203404793576, 0.03407949408996971, 0.013554311289842571, 0.04580928846412609, 0.06257428765116681, 0.03686995020196323, 0.05385395477435762, 0.03959020584701531, 0.07168994104910283, 0.031043780674677224, 0.05033975624809823, 0.05213808253287308, 0.02070961846789766, 0.06297412426060726, 0.05356869427487255, 0.059933862198264375, 0.038704022149285006, 0.019511857235263434, 0.05225817064544367, 0.0645762937323701, 0.07194997427324135, 0.04696266830808694, 0.06004442017705691, 0.031968174922850826, 0.03738059376877162, 0.06344156046848624, 0.09660351871242447, 0.09475663394456911, 0.06872793103778554, 0.06435304805035554, 0.07629278115928173, 3.5844469503048932, 30.72918349696744, 82.07690592735045, 79.11062917401715, 76.5209234914472, 57.258693095176454, 61.904885691981164, 48.109219458795366, 28.479202139762144, 29.02623941821437, 29.2895402831416, 29.48270524701765, 40.71209607585784, 48.25132300776821, 24.837559923048943, 3.097622956960432, 0.13657682214773473, 0.03699912028687616, 0.4299666329977974, 0.8175060910082633, 1.4343792704805252, 1.7747335039800214, 3.740825475223603, 5.430295476990362, 6.690766782529893, 7.162838741656273, 9.588168186526145, 6.921584538875088, 5.7827856463770715, 6.251017605104755, 7.021597623825074, 7.949274451501909, 12.530031127314414, 9.783588513251274, 11.483984031984884, 14.285559481190099, 18.690978365559733, 25.639690506842832, 32.99850802267752, 41.28959840343845, 54.05494820687079, 58.70062697318293, 60.08353310246622, 69.16770319784843, 68.26540116340884, 69.62281580894225, 62.90476452919745, 61.7004596033404, 61.96718077505789, 64.3871655002717, 64.79392313188123, 66.82575010484265, 66.42659402662709, 68.32429947391634, 66.66015548090782, 66.36193767670663, 63.56679393399147, 64.68485378449964, 54.05075519315658, 39.12017468483218, 40.93679689591931, 45.52211430764968, 36.02318102313627, 55.83062479572912, 55.39983087970365, 62.98854243370795, 65.90433828292355, 63.27226708012243, 62.44297996644051, 63.310843590767156, 62.616827257217906, 63.57447393478886, 58.40199732011365, 59.503198823621204, 62.32090403956752, 68.29190069629301, 59.50153573866814, 65.50176189791772, 67.37147731165733, 66.62302632485667, 65.97907512418686, 67.3925639737037, 68.57234231887325, 68.8956868263983, 64.0498181312315, 53.10431080479776, 36.85953232549852, 32.15572599441775, 21.49184680754139, 15.37928298596413, 6.292405964866762, 4.1984525707460225, 2.695171597503847, 3.9261508468658697, 5.562193999367376, 2.790099329525425, 2.8838057335345977, 1.7941515652402755, 0.2233414276833496, 0.1183100071765723, 0.06745100802471561, 0.01355654252092204, 0.07687541400833477, 4.10953807734674, 23.289694593798732, 37.77992433117282, 36.91138998154671, 27.00862123120216, 30.841906532164547, 52.6870608329773, 38.42748411240117, 21.710550323609386, 41.76369920853646, 48.966131825600904, 67.9764009291126, 71.83257718240061, 77.66455327310871, 64.15290978647047, 16.811898293033725, 0.3829616536536525, 0.01371821388602257, 0.027460894705126845, 0.0745782150977081, 0.040757241208226457, 0.027183521080822236, 0.034451828142928506, 0.07274200193463795, 0.035324191614504785, 0.033539195259612416, 0.06997824781724522, 0.03298856956403583, 0.03312017963898759, 0.0493598570145907, 0.017425288453758243, 0.03702977529516624, 0.09587303089398531, 0.011629921406687749, 0.07809790647438458, 0.025814623466782996, 0.022268630376446153, 0.0660286202365833, 0.019623983779080936, 0.03697066012048914, 0.03466050666306288, 0.05617366517863928, 0.055433620413344716, 0.08017929075586219, 0.030901972054233475, 0.061376095494075175, 0.15586533793999305, 0.10107839915661082, 0.09873225488850186, 0.15233678292603264, 0.19936650691013183, 0.13070348650217056, 0.1428983651942784, 0.1411427368199633, 0.1141172539322607, 0.12849165276894647, 0.14828606238288267, 0.16232506792631843, 0.17224219868019705, 0.1164539370145048, 0.13713759850830803, 0.18977068875345493, 0.2386597694168168, 0.16124540489287148, 0.16254701891974097, 0.16461818358830868, 0.11800832175199064, 0.1016076356773415, 0.13621470770768582, 0.10679263366206039, 0.22969696971197284, 0.18048528942369646, 0.16421863809227943, 5.107126495530529, 41.2473270200914, 94.17769247485747, 88.70016528714089, 87.11567678759175, 63.82474468600366, 68.17291167474562, 43.594367427210656, 24.558406799070298, 36.351612844774806, 46.55694930784164, 51.72299715780443, 61.15694461330291, 71.69165426684965, 41.96721922966742, 5.631531207792221, 0.2727763306710028, 0.14721188453897355, 0.5517921104065834, 0.9588091087437446, 1.9854595319878672, 2.2081000045422585, 6.471590620856132, 10.014009129616523, 11.009048742632713, 9.647340082353162, 12.059047625910852, 12.037206888198854, 12.074598843051541, 8.618821078731168, 14.169698549855141, 11.209272992226387, 22.191644714724635, 21.044641694714947, 16.854781566127656, 21.02758134565046, 22.67314114878255, 32.584413597660685, 37.202606354990316, 44.002384139645486, 58.089694284623675, 62.890800891384, 60.223726457165135, 68.50917646961828, 71.10797420624765, 72.99692492331229, 63.812244092264486, 62.52392199731643, 61.5323232835339, 65.75911252729355, 64.425663563513, 66.50046794645249, 65.731534342612, 68.62592974016744, 65.2643172971664, 65.57480427526659, 66.30391797711773, 64.82136795597692, 58.031611827112016, 44.18889284133912, 45.059376608940866, 49.11552706072408, 41.78081643196845, 58.515702909038914, 58.741384321643466, 68.10378382282873, 64.47208481450235, 64.01734482857489, 65.03535286072763, 65.03853782530754, 64.04656256398847, 63.7206724382216, 59.290461232585294, 61.76335480905349, 60.37850318416473, 66.53303146362305, 60.2268918098942, 67.31566198410528, 70.58329443777762, 69.49160468193793, 66.5612489946427, 70.56249018638366, 72.9735319076046, 74.81641830936556, 67.76981753687706, 56.24655685117168, 41.22440861117455, 36.26314770790839, 26.480464281574374, 22.404617647970877, 9.335434186843134, 7.841475952056147, 5.443163302636916, 8.0219064508715, 9.97718886021645, 5.238276825797174, 5.5214170390559785, 2.533390252820907, 0.14780929522408595, 0.12400059254779933, 0.3011558433213542, 0.1502144282623645, 0.46868349095025374, 6.949046523340288, 37.69360080842049, 58.281541332121826, 56.84756594319498, 39.35720351434524, 46.73762152271886, 63.68750095367432, 45.84450175685268, 27.131307086636944, 47.49628636144823, 59.37796538875949, 77.65266064674624, 82.47286919624575, 84.33615192290276, 74.71005931977304, 22.287821231349824, 0.6479496893382842, 0.13820837492183333, 0.17101003818454283, 0.2788457082163903, 0.11006573665766947, 0.14450662889547888, 0.13556477403448475, 0.14840117475438505, 0.17237258684490958, 0.19283724678379877, 0.2036877790646207, 0.17622720420120225, 0.1695861105596827, 0.1925034009881558, 0.09240711888959331, 0.09295483345105764, 0.20563944933875916, 0.13517984549605078, 0.1601240207110682, 0.11096746810982305, 0.17907277650890813, 0.09316381457592211, 0.1887048612679205, 0.12326050564766892, 0.13147294521331787, 0.16615918476975736, 0.10627121123815737, 0.18136857347863336, 0.16202903623061796, 0.13094986037861917], [0.06174774772878136, 0.04897550687253956, 0.058082633711878336, 0.04439093029847549, 0.08035992662752829, 0.0863234767870557, 0.03828018017473721, 0.06729304069472898, 0.0288952449561968, 0.04798734538076867, 0.05343878491511268, 0.025174085861973228, 0.09830600356743222, 0.03752888540827459, 0.017357443707183968, 0.023799802649826295, 0.02235250168239638, 0.041449248430229006, 0.0955484624231054, 0.04844164701118585, 0.07000373556248604, 0.02663886321017579, 0.017562814642705264, 0.06486138569251185, 0.05472234224960689, 0.07457083001011804, 0.7269317608687186, 14.885211433133772, 48.898129693923465, 79.10360028666835, 68.63457464402723, 57.73463349188528, 50.18354923494401, 28.189217390552646, 16.891987208397158, 24.625334201320527, 40.85719631564233, 50.7397727043398, 44.76590095027801, 53.226877027942294, 34.073217838041245, 7.5393715693104655, 0.12085935626659663, 0.19553496412211852, 0.06228602791745817, 0.21499211118826944, 0.2734761060245576, 0.6308842534499784, 1.9898171626752423, 2.698554151481198, 2.5035464090685693, 2.895396337393792, 7.376684402265857, 12.862905033173101, 7.2379271253462765, 9.940722584724426, 11.245113649675924, 18.660332887403428, 16.137864474327333, 20.092131360884636, 21.8542581219827, 23.035526967817738, 31.75966662745322, 47.4887397212367, 49.72143911546277, 53.75072525393579, 60.83665955451227, 60.888807465953214, 67.96102523803711, 67.85258739225327, 61.43150268062469, 64.14261748713832, 60.067992671843506, 65.51874183839368, 66.11856245225476, 65.86380450956284, 63.76317524140882, 66.79072333920386, 67.23932481581166, 67.77399878348074, 63.982702455213, 66.75160946384554, 63.54224774145312, 66.7507230081866, 64.89532816794612, 68.36127173516059, 41.85429811477661, 33.89945291703747, 31.217610759119836, 38.170141327765684, 65.95732950395154, 58.10563871937414, 63.50649533733245, 59.71863108296549, 67.1063486222298, 62.24487673851752, 64.38554948376071, 64.2500590508984, 62.59922758225472, 58.47211753168414, 60.48170074339836, 61.79581634459957, 58.379761403606786, 63.91767348012617, 67.81801562155447, 61.97807711939659, 59.49680536024032, 59.492180885807166, 60.854522028277, 60.734591637888265, 64.16786186156735, 67.47402375744235, 66.61404409716206, 58.17215427275627, 52.48889484713155, 44.776393290488954, 41.74876282292028, 27.85718091072575, 17.945743722300378, 7.068493971901556, 2.372627253493955, 1.9711795305052113, 2.3888526280080122, 3.552159469935202, 2.6376115506695164, 0.5140574078165716, 0.0657569041715995, 0.04137308013835742, 0.047677424511001, 0.015368508043578796, 0.22699171406847818, 2.994775959560948, 18.41581625323142, 43.094790827843454, 53.96855800382553, 48.22774956303258, 43.375436413672666, 34.9808935196169, 27.23839955945169, 16.776206685650735, 30.919149767967966, 45.88789493806901, 47.968700547372144, 61.50889496649466, 64.75917485452467, 59.14336058401293, 12.473833368670556, 0.36246684049406364, 0.027881940458751017, 0.06949070180135389, 0.03260177943194586, 0.0034890852064915724, 0.029667781425579905, 0.07013859001979714, 0.02086647880083371, 0.06496262421170551, 0.05644924615720107, 0.058314520865678794, 0.023545555304735902, 0.07518780658081656, 0.033534027996563145, 0.04353229512250231, 0.028383402461786906, 0.11107616832539921, 0.03911025176245359, 0.021621466111091357, 0.013426619754623503, 0.007672000924245485, 0.058441270112751, 0.05634667081457954, 0.011729919821053985, 0.03633079667305274, 0.02009641871066584, 0.0022475444430094813, 0.026557504672617204, 0.023185515047741995, 0.053677459607922265, 0.05257227052483828, 0.07391698162762389, 0.027745360388390483, 0.04390599281196633, 0.0345625048653493, 0.05574459082356865, 0.09035030304784737, 0.03434330412757493, 0.0527563652834825, 0.04032511782321719, 0.06382592976273549, 0.06335113911078342, 0.03359214342649906, 0.062082359612348585, 0.05164656052065473, 0.039694186960977894, 0.03156429528438997, 0.05184105875331068, 0.0629963408104114, 0.034622378467071446, 0.015113528126910811, 0.09755256375478161, 0.00896582383692505, 0.018802207008364703, 0.046018959068122416, 0.704020951544085, 18.77223026367926, 61.2930194793209, 89.00074435818581, 75.34490277690273, 67.28462034656157, 56.69557017664756, 40.783494980104514, 26.525440139155236, 24.876985626835978, 31.925490710043142, 44.26612431003202, 40.3489944242662, 44.99850926860687, 29.96118537841305, 5.666533948913698, 0.18929621985843106, 0.12167706319521512, 0.1409500503852483, 0.795199571838302, 0.7590587304965143, 3.0871095340098105, 4.001876615708874, 5.065375316527582, 8.184041054018083, 7.951795554930165, 11.15441374240383, 11.11193153166002, 8.1218038259014, 10.433724311090286, 11.61184153249187, 14.985103414904687, 15.55864610979634, 16.26718992187131, 18.66212933294235, 25.583924208917928, 28.981704827277895, 44.88680801083965, 51.56881270870086, 55.697228908538825, 62.758224779559725, 64.30701186580043, 69.77527049279982, 71.30595191832512, 63.42789103907924, 68.64336859795355, 66.33800337391516, 68.26481280788299, 65.92491503684752, 65.89013145815942, 63.54535425862959, 66.23262497686571, 65.48573901576381, 66.15129070897257, 63.628147648226836, 67.85951429797758, 62.88349351575298, 67.7061104005383, 66.36380472490865, 69.44151601483746, 44.98043106448266, 39.66292089031589, 37.1040960281126, 42.36241763637912, 66.06261376411685, 61.05559841279061, 64.49969045577511, 60.14356497795352, 66.54934852353989, 64.45840358734131, 67.23053870662567, 66.42405233075543, 62.74435920100059, 59.71561478030298, 60.6204035974318, 60.87182360310709, 58.72294918183358, 64.407499067245, 68.68713440433626, 64.35215834648379, 62.12674671603788, 60.778588864111136, 63.46988393414406, 64.80459982349028, 67.75185308148785, 69.7951961332752, 66.84510307927286, 58.92724583225866, 51.99704531700381, 47.13191386192076, 42.84773642016996, 29.010218497245546, 18.230058685425792, 8.847505065702624, 3.37414613173854, 1.9526116429798066, 3.9646106669979715, 5.223852799784753, 3.2104509155596457, 3.1014992392832235, 0.8298193915717064, 0.5054144344983563, 0.06468634992357224, 0.043178764697644985, 0.1335548657563425, 2.780902106915751, 17.239972045344693, 40.37743945275584, 46.35627300508561, 43.946827688524806, 40.807637168515114, 35.55210828781128, 27.858755742349935, 26.634660497788463, 43.73399203823459, 56.45697632143575, 55.43566565359793, 68.6649259444206, 73.2720870356406, 73.35560214134955, 18.9705531443319, 0.23556089779782682, 0.07386201481905676, 0.036941724979589065, 0.020658175663782224, 0.052082426245174104, 0.013189332638566774, 0.07074437404592192, 0.05080259975887114, 0.027697027901247628, 0.05249385759534855, 0.030729858910725005, 0.05529715334095302, 0.0738406333050901, 0.0256470340724674, 0.016577845822358807, 0.02736549952157563, 0.0877127159507044, 0.01777167319350185, 0.06832016541832878, 0.06313946135642548, 0.009208920772277541, 0.020639699538268393, 0.0574128047352837, 0.047578679608000864, 0.01612531385504671, 0.05019958514059263, 0.033101084897474896, 0.045980398032453754, 0.021411494817584757, 0.12671186964237882, 0.22766855274957998, 0.1684866977795478, 0.14352553073436985, 0.2324670670373786, 0.13948302265376816, 0.11215523381026522, 0.15653564955197996, 0.15097930576772461, 0.1246268847476571, 0.230635887071971, 0.2535233460366726, 0.25972078283948286, 0.19902054160352678, 0.12271014808286583, 0.13504112229472207, 0.1349350344389677, 0.10857110677827751, 0.22535153514435216, 0.20570220726151622, 0.13608382924670173, 0.12947952314730615, 0.1890047693685178, 0.09313965216279031, 0.13050586646122317, 0.1645848587636025, 1.2265555512520576, 26.46370203264298, 76.39967518468058, 97.85341616599791, 85.76964486029841, 76.63012227704449, 65.18351254924652, 40.51800543262113, 27.226787382556548, 33.57688503880655, 55.77475847736482, 69.4908437421245, 60.23727040137015, 68.54530934364566, 43.89523283127816, 9.884591506373498, 0.3239362644812753, 0.3292066736086723, 0.18283224574500517, 0.566085288601537, 0.7870100919277437, 3.336103553733518, 7.881374791745217, 7.873261369043782, 8.679064762207771, 9.178881606748028, 16.032572369421683, 21.673813404575473, 14.600497368843326, 18.466057892768614, 18.09012028478807, 25.833363417656194, 22.372995499641668, 26.711956685589207, 27.656182973615586, 30.22727897090297, 37.13872271199381, 56.61105878891484, 58.647341574392016, 56.30928339496736, 66.06459848342404, 65.33483366812429, 72.45978770717498, 74.0050603497413, 66.22735331135412, 70.18807641921505, 66.97169365421419, 68.73014711564588, 69.12119957708543, 66.34608345647013, 63.26180611887286, 65.48064777928015, 65.40694252137216, 66.58515976321313, 63.80972593061386, 66.4191101443383, 66.91426231015113, 69.99031835986723, 68.44663035485053, 71.91808485215711, 49.78842535326558, 44.06298475880777, 41.96579540929487, 46.40608318390385, 67.59189098112046, 59.6123662302571, 66.33607356779038, 62.07194335999028, 68.84480584052302, 66.20774930523288, 69.40077043348744, 68.01343594827961, 62.83307536955803, 59.97915098744055, 59.98845877185945, 63.874711759628795, 59.848689033139145, 65.62758368830528, 71.90717281833773, 67.6749824708508, 66.00926952977335, 66.27221738138508, 66.30770698670419, 67.1841606017082, 72.53968638758506, 74.8797881218695, 71.77669125218546, 59.1366494086481, 57.20325823753112, 50.87234097142374, 45.60413891269315, 31.35001232547145, 22.106886217671057, 11.782017484787973, 7.449715502800481, 4.874419627651092, 9.314586789377275, 12.2211483986147, 8.17734850991157, 3.136279385897421, 0.3268961830725593, 0.34496623602124954, 0.1664541745858808, 0.12998714832769287, 0.49322953027102256, 4.722005148087779, 25.926725633682747, 56.79743805239278, 71.60966104076755, 64.91910165356052, 56.33190370375111, 50.36405671027399, 41.92441832634711, 27.874513864517215, 46.04876702831638, 64.10536281524166, 66.1190252919351, 79.7596323874689, 83.34489053295505, 83.06915575458159, 23.896277373836888, 0.5799747691039117, 0.18447944203451758, 0.19224280851983255, 0.13390086170646454, 0.1905677572733933, 0.1631749658695152, 0.26302786183453375, 0.2269668621762145, 0.11154771076455233, 0.2502711036152417, 0.11480703949928285, 0.15658913781085324, 0.28171648481680506, 0.09885090658621443, 0.11426209051522518, 0.08717868371956772, 0.23616515730898227, 0.16731292850548224, 0.11169513672470086, 0.3117864470808737, 0.13411954916532964, 0.09121232050200624, 0.2677137458757047, 0.10138299571530474, 0.09246212400255666, 0.18747639331606128, 0.10391066451707195, 0.1302953608213894, 0.0969554212004427], [0.027954125093416344, 0.013515948479424321, 0.0910604895362931, 0.08148497270960962, 0.029369204402751023, 0.04926144152939801, 0.10649197479529728, 0.009813228163928276, 0.1363200141537574, 0.02588936491989561, 0.07793837632503241, 0.008293321213474678, 0.022348362892385454, 0.07685232411829696, 0.03913484318482299, 0.0525528195524408, 0.024732878589401805, 0.04962904881986399, 0.04789763648483542, 0.042938657420417, 0.0986978268971847, 0.0418116846272061, 0.06859371243345161, 0.0962073669858998, 0.030041053936245943, 0.041099954471592946, 7.987405773132079, 55.197813126348684, 70.47662950331166, 66.0102815012778, 56.11156455932125, 46.313158312151515, 32.79784937058726, 21.473452852618312, 25.06461024284363, 49.17832420718286, 46.995085900829686, 31.140598943156583, 56.41339878882132, 41.39135645281884, 7.275786332545742, 0.029813393672567703, 0.03101844997746089, 0.13178304228330814, 0.052562916591282816, 0.6882356179337348, 0.8432023960255808, 0.8042436994371877, 1.5966018818078505, 2.2038689928670085, 5.270404959878614, 8.828143265939529, 6.150083743756817, 13.088553105631183, 15.203211711299035, 19.727388197375884, 31.800665201679355, 31.6514229389929, 39.316418709293494, 41.419942686634684, 33.75301514902423, 45.98910385562528, 52.01902627944947, 60.33062673384144, 63.178742085733724, 68.4115957444714, 65.72707460772607, 69.77337991037678, 66.43115966550766, 63.718801467649406, 63.739091888550796, 61.82958010704287, 60.13320207595826, 67.35566231512254, 60.928184140113096, 63.0923754169095, 62.66884180807299, 62.66210317611695, 62.691744527509144, 64.21911939497917, 67.29902328983431, 65.28871051726803, 65.72017515859297, 65.44384810232347, 62.95058957992062, 65.60230009017452, 61.22760218958701, 37.44349087438276, 23.368553846113144, 50.54984761822609, 62.47235459666099, 58.71917978409798, 59.760835786019605, 61.31289020661385, 64.57437238385602, 63.46540850977745, 61.07035436937886, 61.33656955534413, 62.229046052502056, 57.85392453593593, 56.0934510538655, 56.67602500607891, 59.666220372723, 63.778990237943596, 61.495476538135165, 59.56752961681735, 56.5649042590972, 53.26259805310158, 55.736899760461625, 62.568021205163774, 66.68306212271413, 61.39541295266921, 61.82579894219676, 60.442065192807114, 61.20355021569037, 59.603140815611816, 59.713735964990434, 57.118170261383064, 50.17691258461245, 35.42680817265665, 18.811061728385187, 4.901136361783551, 0.7326850811800649, 1.987379409613148, 1.3188902288675308, 2.3678294593288056, 0.8125518310454585, 0.326737909307403, 0.05412111261619195, 0.13895534129152376, 0.02220823775015531, 0.09375552556687787, 0.9605760139323051, 11.881301499182179, 31.25577542089647, 47.92124379065729, 41.45842506039528, 34.224064350128174, 24.556243611920266, 14.562176792852341, 16.547499164458245, 26.757777813942205, 44.50232944180889, 57.41390912763534, 57.825824676021455, 58.542300501177394, 50.71921163989652, 5.76484864757907, 0.1461117669579483, 0.05570369705017056, 0.04450883123002226, 0.0572921956829246, 0.01551522154195775, 0.06892918233549403, 0.012380614794129807, 0.013404478856001892, 0.009083302462503556, 0.03250294259839481, 0.030307681262192708, 0.02838422217586589, 0.04210584323793169, 0.036561124837927284, 0.08549801704864349, 0.05186507177929725, 0.01710378624979527, 0.034421851122451406, 0.06394100382984166, 0.05725576437168545, 0.029210064958240238, 0.11849274979003015, 0.057726069578840855, 0.011873688668973986, 0.03952972703583298, 0.04559285330375837, 0.05151398517491837, 0.047047600645812294, 0.01406369943006505, 0.0589192170469511, 0.027284493384462212, 0.08080978111754503, 0.08275046569084929, 0.024369387106309016, 0.09201361782728665, 0.04007495947242264, 0.13302226610962423, 0.014105445476278905, 0.07077258906417316, 0.04046993142354392, 0.05658053447522464, 0.031768260448570215, 0.04547401391450436, 0.08860864045639193, 0.025945867734750914, 0.052177838665703614, 0.009719134372238432, 0.012360933037745136, 0.1043128070511645, 0.01720395416111475, 0.1016617751109504, 0.04604421698698594, 0.06746420005877173, 0.031355023046114275, 10.939814986721164, 65.34329814295616, 79.83367104684153, 75.4495123893984, 67.88459393285936, 53.311894401427246, 47.05481575381371, 30.561480599064982, 32.78865533490335, 44.08380077731225, 53.32965881593766, 37.94460896522769, 49.453156840416696, 34.79540855653825, 5.395582500965365, 0.04237414638121282, 0.11236775426133988, 0.16906635054657537, 0.8174821890650258, 2.2330315699500423, 1.732171252369881, 2.6176332033449605, 5.36015026031002, 6.949905522408025, 10.879569342059474, 8.62916240769048, 8.44282530969189, 10.260013322676382, 11.287258536584917, 17.922613505394228, 26.44382738297986, 31.55492674919867, 32.622138953978016, 36.12959884828137, 37.80594925726614, 44.680997325528054, 53.29336512473322, 61.57419850749355, 65.2700400352478, 69.67788588616156, 66.13970402748355, 70.74985396477484, 66.6610497813071, 64.72799985639512, 65.6213588868418, 62.89671974797403, 64.5532347309974, 68.46901139905377, 64.13241540232013, 62.96369029629616, 63.58701767459993, 63.525969905238, 62.410757695474935, 64.95674856247442, 67.87304647507207, 66.26516495981525, 67.80110236137145, 67.45763609486242, 65.340995711665, 68.30788827711537, 63.58184799071282, 41.51331078621649, 27.8445214609946, 50.85057181696738, 60.731543956264375, 59.344852739764804, 61.165620896124075, 63.53252418579594, 66.74222715439336, 65.17330261968797, 63.14760631130588, 63.60828476567423, 65.21668795616397, 61.557104818282596, 55.2118944352673, 58.673982312602384, 58.12170866997012, 64.7483334233684, 65.81371584246236, 63.262990674664906, 58.345228856609715, 55.30739630422285, 58.28751510189426, 64.1501876615709, 65.47643515371507, 65.63457335195234, 63.802257737805775, 61.89089459757652, 62.58467558891543, 59.13337815192438, 58.701129036564986, 60.175446002714104, 52.466984487348995, 37.44482840261152, 20.340450732938706, 6.081930110531469, 1.4296846836805346, 2.7079185651194666, 4.021566913973901, 4.99424901700789, 5.00202952854095, 1.6143962043908335, 0.38226981497099327, 0.12623684916404948, 0.07531096287552388, 0.09515669271950761, 0.8835735135982115, 12.159046492268963, 28.519206393149595, 48.44031064741073, 39.23173865964336, 33.36054278958228, 29.28621803560565, 19.891580573974117, 33.02778851601386, 46.13341177663496, 55.50127121710009, 65.90237709783739, 66.02136611938477, 67.05645607363793, 62.87110667074881, 9.072685395517658, 0.23475411528300857, 0.059602418088264046, 0.017306774651872057, 0.03009712774186365, 0.024323825942232244, 0.01230262800104796, 0.09371824772848238, 0.09043314779597907, 0.06685446301895766, 0.06599965445216625, 0.04505630064335081, 0.060929473895098896, 0.05464656849301631, 0.02780230753424187, 0.008089557147374558, 0.0495753039215361, 0.051161841369203986, 0.04069050345870276, 0.052271872127969424, 0.00585053974176727, 0.04324838293776397, 0.07015516816247856, 0.09181159278077465, 0.05576115364449159, 0.10156072811373781, 0.09277619706887393, 0.010468304202321076, 0.03855850374806793, 0.14870958643094187, 0.1375981092813515, 0.12811637693835845, 0.24449283948108075, 0.15441240622631966, 0.13607987623301246, 0.31192228979160713, 0.16509040018483517, 0.20989543548034084, 0.13936349761582192, 0.1434227370566899, 0.11053278216070707, 0.2378177621792401, 0.10435145618694444, 0.11206341817254022, 0.1981623699107478, 0.11056103548335453, 0.13523226123183005, 0.1704162893997085, 0.14505346245583028, 0.2751671685086143, 0.12108578121349697, 0.22750336887134662, 0.1500677071031063, 0.1636748229183497, 0.14572274750999867, 15.74732094041763, 78.33681614168229, 89.65767075938564, 84.06691258953464, 77.5570724856469, 63.50122367182086, 48.18824345065702, 33.65164149192072, 34.21861617795883, 65.64830556992563, 59.79494471703807, 42.50189711970668, 68.5624187223373, 51.38788946213261, 9.233771254939418, 0.3440715066127239, 0.14549356464657093, 0.4925330644173007, 0.8410970025485562, 3.0354913876902674, 3.668981872258648, 4.585456165575213, 7.7822981726738725, 10.649885150694079, 14.468861645267857, 16.402216534460745, 15.644779397595315, 20.330554592993952, 22.50429880234503, 24.43715064756332, 37.96926106176069, 38.856952267308394, 46.57449406962241, 46.22127679086501, 39.46808891911661, 51.69271646007415, 55.90790333286409, 64.04375806931527, 66.64490530567785, 71.97266071073471, 69.62305115115258, 75.63907269508609, 72.1881635727421, 67.32545222005537, 68.64036406240156, 66.52095056349232, 64.84330969472086, 69.93323218437934, 64.68845059794765, 63.44312552482852, 63.12915155964514, 64.90311407273816, 62.92045400988672, 63.18200942008727, 69.71787837243849, 68.35054797510948, 71.17620775776525, 69.96530932764854, 68.667985393155, 69.13338245884066, 65.6504903301116, 46.893143500051195, 33.2485826553837, 53.394491672515876, 62.88426230030676, 61.44212445905132, 61.45976335771623, 62.94984825195805, 69.56041874424105, 68.63794003763508, 66.31912892864597, 66.46956751423498, 66.78720889552947, 64.08695905439316, 56.000114333245065, 57.643826700026, 58.52932530064737, 66.0530274914157, 69.46430498553862, 66.35279855420514, 60.779181142007154, 58.9544435470335, 61.86616405364006, 68.35498809814453, 72.16457443852579, 67.2793565257903, 65.0951611611151, 61.59045280948762, 63.24658732260428, 60.25965929031373, 62.8926718619562, 62.78337109473444, 55.83585723753899, 41.8633391780238, 25.668886669220466, 10.064858736530429, 4.411839804341716, 10.252752034894883, 10.331050388274654, 8.708235429179284, 4.319350805974776, 1.089323218311033, 0.12486900683612594, 0.2711948187601182, 0.18637318073982195, 0.2842544728229123, 1.794141636740777, 17.736573526936194, 42.873223981549664, 62.91052649098059, 57.10053528508833, 48.19421329805928, 37.310785324342795, 24.36626753499431, 28.311816953843643, 40.644184158694365, 59.98523066120764, 74.45978856855824, 76.28895451945644, 75.90751186493905, 75.53482394064628, 12.278762132890764, 0.44039618464246877, 0.09550628162199452, 0.11535558909658464, 0.11486414369315871, 0.07036284693787176, 0.12073543388396503, 0.2641042153681478, 0.17434054414831823, 0.11770756329379736, 0.16922353646687924, 0.15767008787201298, 0.12202819193442985, 0.16343618652993636, 0.11381215175553677, 0.33897797186528483, 0.10577399719266162, 0.23822515241561398, 0.14425993326210207, 0.1397039011240967, 0.1273191552008352, 0.09981195622634503, 0.22752644343962594, 0.18099993196946962, 0.16551421534630562, 0.22026841919268333, 0.20696203885299547, 0.13778586210983415, 0.12592179550518914], [0.01626773343061007, 0.07176019897263858, 0.015203262878311499, 0.026907507262583223, 0.05663087794316873, 0.0013879171831743613, 0.022058427341342456, 0.028611750289377187, 0.07671075873076916, 0.025995751549940438, 0.07227090382648092, 0.07777406578703273, 0.02071246065409674, 0.016647228490441077, 0.007361919654818673, 0.010925448976547248, 0.04052464925353566, 0.03567010329495515, 0.033200002170257994, 0.07007326570249374, 0.04635830537506169, 0.09469785201813906, 0.06677336495129332, 0.037644101201646754, 0.06981114105832192, 0.25614252404099513, 22.725032144977202, 66.80102348327637, 71.79699344019737, 63.52230641149706, 43.127734814920736, 38.35005652519965, 22.360173271548366, 21.72153296009187, 30.225453107587754, 48.53621652049404, 24.922485120834846, 46.39215092505179, 33.25129301317277, 3.264305793469952, 0.1569707721712128, 0.0676815775072863, 0.1702159880510261, 0.06675968262096567, 0.4273254376265311, 2.197345846122311, 1.0045941390337483, 3.134938180446625, 2.403880699026969, 5.9762477297936725, 12.093767466083651, 8.489630952958139, 19.563799865784187, 20.260852113846813, 25.63591914792215, 37.08657480055286, 43.868674462841405, 47.39938812871134, 48.29068791481757, 48.885652634405325, 52.9526758963062, 61.4824934928648, 62.4458158400751, 65.4680295144358, 62.99367681626351, 62.55608151035925, 63.14605305271765, 60.63115873644429, 60.573135114485225, 59.60425869111092, 57.73835189880864, 61.675128936767585, 64.76651360911708, 62.79445571284141, 63.16726523060953, 64.75459352616342, 61.947761120334754, 61.99893236160279, 65.82676949039583, 63.53692900749945, 64.05571737597066, 61.14074130212108, 62.829984541862245, 58.68747918836532, 63.167845741395034, 60.09529629061299, 67.46405309246433, 42.677289824331964, 26.166749192822365, 62.78374371990081, 60.98640780295096, 64.0818678179095, 60.69961586306172, 62.50801678626769, 63.18223691755726, 61.41914329221172, 56.646364042835856, 59.09046742223925, 57.67201677445443, 63.45814428021831, 61.919374927397705, 58.52347704672045, 54.15927933108423, 63.34544674042733, 63.62657870015791, 58.799133377690474, 52.85903323081232, 47.639605845174486, 53.39871998756163, 56.45263033528482, 64.84071700803696, 65.11685971290835, 63.67088971599456, 63.889993313820135, 65.45409333321356, 60.426858163649044, 63.66153094076342, 72.27035291733281, 66.12563840804562, 63.0241261759112, 50.10353680579893, 26.616568565368656, 10.086229770414292, 2.3564940546789477, 0.7901452301490692, 4.379560659008642, 4.379956818396046, 3.0874272459937684, 0.1880041359653396, 0.026571621757841883, 0.06085966030255922, 0.05271242248014577, 0.021724238721353394, 0.8210548554216662, 8.36284916247091, 26.986126438263927, 54.875853215494466, 39.929704819956136, 25.900783077363048, 36.960949128673924, 16.32746400371675, 12.382215626778143, 32.14089551279622, 46.7708832217801, 56.35418668870003, 60.44155920705488, 61.82088813474102, 37.00789597726638, 0.8206408002203511, 0.026255880535069494, 0.048569441968274694, 0.019678098314832297, 0.015884367711541635, 0.026497776627600677, 0.05763697738368666, 0.045556073422513665, 0.05804300781399493, 0.017898656097390962, 0.04148265752460688, 0.09151335475185225, 0.05827585257770074, 0.008626971656696932, 0.06935416195060938, 0.012826505736748298, 0.044270340398314505, 0.07226992323393784, 0.020667853269485698, 0.05160299693084052, 0.06149799540458668, 0.04812508032867505, 0.02915063760273399, 0.0365073109916862, 0.005606396138788231, 0.045280641831097104, 0.04658711668584616, 0.0943066798631222, 0.027524502985479853, 0.04062816688430406, 0.04177295122175448, 0.023113565985113386, 0.12320127939024281, 0.01485961594528729, 0.04208268056954107, 0.04721804754808546, 0.019364295294508338, 0.02507215977886752, 0.05866265037066995, 0.10550289399801724, 0.097176039200877, 0.044392899144440896, 0.04008371968783679, 0.04305035303977709, 0.01891314803111938, 0.010345580747290965, 0.012359561740360674, 0.1025856694867534, 0.027051338355147073, 0.05526195160083233, 0.03862477418395781, 0.031038073319641334, 0.042950447513571674, 0.9140614227902506, 30.81976083017165, 77.03705249294158, 79.46336792361352, 71.93798695841144, 52.14863707942348, 49.310653209686286, 32.96135925477551, 28.481594785567257, 27.227242377496538, 47.62178259511148, 29.4561743351721, 36.97928228685933, 32.76425819243155, 3.79824897454631, 0.1573283820142669, 0.06459001436709397, 0.40053381073859434, 0.9646576078188036, 2.488917439214645, 4.432322421381551, 4.20697097816775, 7.674039285029135, 6.961869732026131, 5.7755616211122085, 10.111135840415955, 10.98225405139308, 12.367029190063478, 16.052203832134126, 27.028760640851914, 35.77488322411814, 42.714921043765166, 46.939090144249704, 49.77667000985915, 49.51980575438469, 52.38051583690029, 62.46344297162948, 67.17910074418592, 66.98257430907219, 66.66761582897556, 64.07927513122559, 65.55632206701463, 62.75149006997386, 64.09958516397785, 61.98458040914228, 58.854023025881865, 62.97832465940907, 66.91671771387901, 65.86503613379695, 64.72698788489065, 64.83202111336493, 63.64496677152572, 62.257522459953066, 65.97505861713041, 64.64763049156436, 66.5061632279427, 62.79036468075168, 65.20825486029348, 60.10263112283523, 64.10179345838486, 62.517905081472094, 69.57616313811272, 45.46570277983143, 30.67960277680428, 64.05453282017862, 62.119976705120465, 64.6314428698632, 60.225362085526996, 61.33569094442553, 65.1299721963944, 64.28177141374158, 60.25792168032739, 62.06858973349295, 60.62321201447518, 67.24563198704874, 61.044443192020545, 58.96773645954748, 56.62601478638188, 63.37984200446837, 64.68808581752162, 61.78864625192458, 54.816860768102835, 50.310512435051706, 55.59858522107525, 59.69871720960064, 67.86775127533944, 66.27736353105115, 62.33499711559665, 63.89590432566982, 65.38742872976488, 62.14255779020248, 67.65557458323818, 73.79002817215459, 68.01857425320533, 65.11135270518642, 53.11798810958863, 30.675488210493523, 10.79619740286181, 5.203597189918642, 5.08209785146098, 5.525529153885381, 7.428742589489107, 3.8464931470732537, 2.3029980736394084, 0.4315299733031181, 0.08830084931105377, 0.02520892371032988, 0.020311913498106505, 1.11678128040606, 8.218175970738935, 28.572619268971106, 49.915937685197406, 37.05241880109234, 20.50009119895197, 23.55640595959079, 19.47869816134053, 20.087493158155873, 46.94913141189083, 53.54009005331225, 64.6117643387087, 67.85407789291875, 71.30090775028353, 46.29144799324774, 1.5349488416987083, 0.020978781544873794, 0.03983423932485523, 0.06432749135720153, 0.046295083969110445, 0.04005039486313059, 0.016475927400132342, 0.026029233422671116, 0.022267544446813486, 0.03244197732138057, 0.05324992508957944, 0.028762845810683026, 0.014517970416965264, 0.02058820885365769, 0.11067112231807363, 0.04837295573745524, 0.030379647561799616, 0.010733253795713668, 0.011403396868357256, 0.04028664871809944, 0.06757863827290074, 0.08324499842861006, 0.033121849710662524, 0.006518201647146095, 0.03720200718230298, 0.06501693218465775, 0.04524909433037524, 0.028888888341645082, 0.11596253757635433, 0.1595511861265667, 0.13856210835999058, 0.09816804645402778, 0.20221839178233378, 0.08725428127593572, 0.15933142614460763, 0.12983098896520753, 0.13744679159454762, 0.12544946399547402, 0.25865873982829435, 0.15806214102814276, 0.17430622340931048, 0.1449295094296817, 0.11727437121613372, 0.13387083105983275, 0.18406209265512807, 0.16927691747344312, 0.18409385466046874, 0.17989972245789346, 0.1190698208407529, 0.18570473838237025, 0.11456736123129246, 0.22332092717049584, 0.1608587756392456, 1.8394808038588495, 41.28531517521028, 86.84045976208103, 88.59290415240874, 81.07817634459465, 57.99993476560039, 52.262299522276855, 32.710623702695294, 32.666018509095714, 41.42246477065548, 61.25781228465419, 34.37801345702141, 60.37474947590982, 43.47726506571616, 5.173521926326137, 0.41796172878915266, 0.18762015737593177, 0.5206001970556475, 0.6987234229041684, 1.9647690293289002, 5.447381321460971, 5.961234857959132, 10.412697465189042, 11.451720576132498, 13.276163012750688, 21.116785849294356, 14.922255277633669, 25.45547639170001, 24.65413812668093, 30.741223212211366, 42.5618270135695, 47.95055566295501, 52.916825432931226, 50.74511889488467, 51.07611986898607, 53.28460647213844, 64.24727416807606, 66.34482045327464, 70.17987082081457, 68.67203327917284, 66.99167420787197, 68.11676686809909, 65.42540511777325, 67.43634546956709, 66.01130131752261, 61.13880365125595, 66.66166951579433, 69.87239622300672, 65.74983612183603, 65.61638532146331, 64.970237593497, 62.98097618164555, 64.47269278187906, 67.8952863139491, 67.20449416868149, 68.24498130429176, 64.67622849249071, 67.58333236940446, 64.13201139819238, 68.14977753546931, 65.87036271249094, 72.09457582043063, 50.11133840007167, 35.677894776867284, 64.86770291482249, 64.6274891207295, 67.28571861020981, 62.782920022164625, 64.45286912302818, 65.97006936227122, 68.14743195810627, 62.55875656681677, 66.0042175169914, 64.85157412867393, 70.47061258746733, 61.474601684078095, 59.82689242209158, 57.0287480661946, 65.8390308195545, 67.81021010491156, 67.21700652953118, 57.18453284232848, 52.346540266467684, 60.065537268115634, 62.616387951758604, 71.14221649785196, 70.37161196431806, 64.48463639905377, 64.3632782659223, 66.03021498649352, 63.836237230608546, 70.5733080833189, 76.86653137207031, 72.25838968830725, 68.18961312693935, 58.54685829531763, 33.25252463740687, 16.509689477182206, 8.714108197919785, 6.988695311930872, 13.817869790138738, 14.438774124268564, 10.396031314326871, 1.2632473630289878, 0.15932152828862592, 0.16554747888397786, 0.24267492815852168, 0.12091075310543661, 1.79416173888791, 12.505443749889253, 37.83705365273261, 69.59551611254292, 55.95516397107033, 38.53101899546962, 54.7273640478811, 25.216445192213982, 20.5665930240385, 47.39426551326629, 62.3718281715147, 75.76687136004048, 77.68902886298396, 78.56323888224941, 58.634542880519746, 3.0017940603917648, 0.17015729039426775, 0.26316961874404265, 0.11499008088703118, 0.21427430212497714, 0.14885918808079537, 0.1196582453145135, 0.10184699218840369, 0.135916929331518, 0.11778817872606939, 0.11621371482408817, 0.16031347425474277, 0.09401580393915215, 0.08266313166748132, 0.19143617922259917, 0.09468747918764431, 0.11481132959165882, 0.1702861617048902, 0.14555707333549378, 0.16541900593907605, 0.121541450310859, 0.22519949733489947, 0.06049158952889904, 0.11480329332933312, 0.12461102672762449, 0.15878781015353818, 0.11627566835452473, 0.13122747532061993], [0.053765291588441025, 0.05001439104577707, 0.06941692753424568, 0.055782814780550624, 0.013909832585693128, 0.026333749542132984, 0.02589824770937764, 0.1122678563960137, 0.035212074646786336, 0.05991633793699646, 0.09356965731468894, 0.016238304162998835, 0.06092912149465373, 0.021964363235559677, 0.04417028165452423, 0.015680409250630727, 0.04165436081107586, 0.05306858058658339, 0.031166833547514775, 0.03711405262771634, 0.04012426489122933, 0.07465627945719228, 0.03310190461155388, 0.11228442687781588, 0.02027443073119127, 10.626778468008965, 63.797499902786754, 73.06516631957024, 67.31797618250694, 45.50630323348507, 39.902911109309045, 23.339122341525172, 23.22858798888422, 36.76796851619598, 49.62741990243235, 26.076124791176092, 52.76923448808732, 44.08499710021481, 5.113201266334904, 0.12172541100411646, 0.1372146975970076, 0.08573236334468089, 0.07585264066414488, 0.5628756866339715, 1.2794960266159427, 2.473253699079637, 1.6498616626185756, 4.2451390720182856, 6.268379976672511, 4.726554116895122, 14.07497036841608, 21.206274724775746, 25.242083764845326, 34.03306453458725, 40.222301867700395, 50.70618152618409, 59.2542891348562, 62.46043059133715, 65.15796615231422, 64.19534983173494, 62.513198237265314, 62.575218754429976, 65.8955051052955, 61.476633471827355, 56.68914141193513, 56.496682474690104, 58.025783185035955, 56.775315884620916, 57.97991891061106, 55.97105741500855, 58.928206812950876, 62.15447395078598, 64.33468810973629, 62.24414717766547, 60.20835076608966, 59.02161021386424, 59.982437933644945, 62.694219543087875, 61.56672246994511, 62.7197894742412, 62.37781370839765, 58.05822118636101, 61.21492508919009, 54.3124008178711, 56.96184419816541, 56.7111772875632, 69.06572941810855, 44.68902249490061, 33.67929812400572, 71.20691991621449, 57.27636729517291, 64.88759717633648, 60.21847048113423, 64.61442370568552, 58.01438085494503, 62.71941684907483, 53.67006955608245, 53.56306729778167, 57.62013166181503, 64.45088440372099, 58.71448078463155, 58.35603498643445, 52.13648165425947, 59.58354465423092, 61.98845571087253, 58.98055868764078, 51.951859612618726, 46.424820346217004, 50.4418686897524, 59.03578958203716, 63.56065934704196, 62.96990725301928, 58.481825397860625, 60.27997716780632, 59.568521976470954, 57.614295174998624, 64.86169776608868, 62.927502509086366, 62.93362140655518, 65.4638365007216, 66.88490729178152, 58.19306442814489, 30.680942266218125, 13.792216508619248, 3.930110234406687, 3.594763764450627, 6.762394164839099, 2.42290664584406, 3.8110055029392247, 0.29223104157755453, 0.07753169088954888, 0.035216648191694296, 0.03965845278974983, 0.091299363411963, 0.22773222997784617, 6.841945715488927, 23.536388143416374, 41.778678740224535, 41.26155345670639, 44.05243750541441, 38.22443085332071, 33.61525366383214, 15.525930600781596, 31.377455188382058, 44.665519652828095, 47.92010630330732, 53.383320762265114, 58.055910910329516, 16.616109263512396, 0.2904406940985111, 0.0367971220534415, 0.10022873103979135, 0.05911457712852186, 0.01763065555883992, 0.02490915542077874, 0.026442896003925034, 0.05874802703939139, 0.020406667083021135, 0.057815318822019526, 0.0275086009153916, 0.021040045596178503, 0.06368146856285392, 0.10908548885415639, 0.05013376286613846, 0.09059871471817456, 0.04175122113778226, 0.07648009731764756, 0.09099741751748709, 0.028141718958654714, 0.1262505085117394, 0.0064680626289167955, 0.009328237051264414, 0.03855555047911983, 0.026376041425992886, 0.021036579048321135, 0.0837110326955876, 0.061223283935818947, 0.11008642103162505, 0.07828424970108656, 0.08011650985046741, 0.050478789715036276, 0.02618310792792228, 0.04812973814325468, 0.015047954831032023, 0.04576667099289837, 0.02944264542161217, 0.049896394353239774, 0.02165752012402781, 0.09818568945892396, 0.053745227745704116, 0.05777026136075297, 0.06315574838569568, 0.026613745102358442, 0.05305308262787519, 0.01845479762602237, 0.03437148850230921, 0.010247772386778268, 0.07114655488441068, 0.03771401438561659, 0.02557254734358961, 0.06087968584089991, 13.344412253748986, 73.7566880256899, 81.48757765370031, 74.39925070731871, 55.77965359533987, 47.4854370855516, 35.203950866576164, 32.12428427511646, 33.820205350076, 47.6018451875256, 31.49542243249955, 42.86329254027336, 39.302619811027284, 6.074697259933719, 0.16408916923307604, 0.03278320437417396, 0.10985907677921558, 0.2562600725720967, 1.421616735958284, 2.6039644787388467, 3.3321201416753956, 7.024535479084139, 9.076241024078863, 12.682559355612725, 4.7294404910456755, 8.644983287780516, 12.342751679881928, 24.41448719270768, 30.48037971219709, 41.377757595431426, 50.994648318136896, 59.26645240476055, 61.328230596357784, 64.2243439920487, 62.0957717587871, 62.60063179077641, 62.28233537366314, 67.7546222748295, 61.872024074677505, 60.04825530513641, 60.34059347644929, 59.32864158384262, 59.767021363781346, 60.18495382801179, 59.020500183105476, 61.85485978280345, 63.59715307912519, 65.4893122949908, 62.63305802499095, 61.77281948827929, 60.620650706752656, 61.14176111836588, 63.869291044050655, 65.42915490365797, 63.66582201373193, 63.885357072276456, 61.93753550129553, 62.88701188179755, 56.693393261201926, 58.082230014185754, 59.75907464181224, 70.96589811386602, 46.406024348351266, 36.8306323020689, 68.9794921875, 60.02297562937583, 66.92992825661936, 60.90577956168883, 64.44273371850291, 60.8479481358682, 64.50138491968956, 55.37296656639346, 56.383671145285334, 60.88934090829665, 66.97847935461229, 59.84183273007793, 58.253519919610795, 53.66290338577763, 60.99391521946077, 63.198334324744444, 61.5541708853937, 53.87936330610707, 46.81679456464706, 52.28414712413665, 61.73327807457217, 64.78999683933874, 64.26845888937673, 58.96611259829614, 60.280255656088556, 60.47976309253324, 59.356474722585375, 68.63215846400108, 66.06430038329094, 66.71903025719428, 68.47146680278163, 70.45758247375488, 57.48619056517079, 34.53457878481957, 15.25234430067001, 5.230162912799466, 4.721513380927425, 9.005422630617696, 6.928458982898343, 5.805634923519627, 2.6300435825701687, 0.32081292401398387, 0.11719285180011105, 0.044575473218555414, 0.029785144180359862, 0.08942582644522191, 6.849383509928181, 26.57910796903795, 46.30707471601425, 43.29907571115802, 42.605031921017556, 25.327061914628555, 33.42883517665248, 28.192300373508086, 43.96897731288787, 53.56046676635743, 55.65693047738845, 63.61788672785606, 68.02171999408354, 21.70460008805798, 0.3159823719291918, 0.029471482886301897, 0.04455994078589063, 0.020952636879237912, 0.03464652555844477, 0.025600228015513673, 0.02985596709373978, 0.030202181378920234, 0.01709652948193252, 0.03987159377204315, 0.06553607166654642, 0.0184364938702915, 0.022532438498831565, 0.07331731098313486, 0.010427948605689791, 0.055006702595780936, 0.022195823295342348, 0.008940009546706514, 0.02109625538240277, 0.047411151500719215, 0.07526174172638886, 0.08917865583733206, 0.0455585670387072, 0.0313780803774153, 0.11687573736473439, 0.023008828359325568, 0.036470718801982945, 0.1691507734358311, 0.21144379110586262, 0.22006390436041742, 0.17350823558386297, 0.15640403564658859, 0.11509915648569023, 0.13897251698278612, 0.19415333987243716, 0.23265284335901662, 0.13909927389073756, 0.17695112664613033, 0.08638981234041915, 0.2049545973779694, 0.0936084520071745, 0.19001370716479518, 0.10429082798861689, 0.07565994656855062, 0.19078681245446208, 0.1834108719542142, 0.08998542303039182, 0.10594347116327095, 0.15763282535537598, 0.09615554879870146, 0.22726419622138624, 0.14023034142390375, 18.228360299141176, 89.63124182916458, 89.53352774343183, 85.43297998366818, 60.73186951298868, 56.27085985675935, 36.645994570947465, 33.96046146269768, 48.437753262058386, 64.31850441040532, 35.77536567564934, 67.26697752552649, 55.650199690172755, 6.893018897502654, 0.4461388103663922, 0.25864295841705415, 0.2303285019532327, 0.1826720720817966, 1.514831372807103, 4.653397500514984, 8.286514935954925, 8.404309595784834, 10.822728314707357, 14.021873243393438, 13.066295616088375, 23.032236099243168, 28.889729169107255, 31.71630874756844, 36.987381981265166, 43.95655516655215, 51.939884616482644, 62.059540825505415, 63.147378813835886, 66.9612366153348, 66.0084693662582, 63.38726312883439, 63.784430565372595, 70.05215844800396, 66.04670463069793, 62.23520417367259, 63.42381569647021, 63.17179556815856, 61.97715536240609, 62.40760410985639, 62.522058871484575, 63.48109406809654, 66.1617555925923, 65.95256774656235, 64.64291188024706, 60.41891144167993, 61.32009952299057, 61.6519751856404, 65.31875979515814, 65.47146943307692, 67.51083912387972, 67.61431909376576, 63.212717656166326, 65.86939780942856, 57.619943388046764, 61.29962082832091, 62.89673151508455, 73.13817731795773, 50.07524867211619, 41.026262237179665, 71.67077941279258, 62.417013875899784, 69.28451138157999, 65.64025294396185, 65.27187962685862, 62.446961172165416, 67.91004227053735, 58.88558633865849, 59.71909000027565, 63.90583576694612, 71.79776222475114, 61.815883190401145, 58.9552790118802, 53.53129609938591, 63.983745805678836, 67.8670217144874, 65.05407041118991, 55.73878249814434, 49.46044068182669, 54.558741354173236, 63.85609619079098, 68.86767325862762, 65.05113647830102, 57.84931575098346, 59.96071192526049, 60.644200617267245, 60.44314776697467, 70.81519280710529, 68.26089828245102, 69.01848839175317, 70.94313267738589, 74.27409571986045, 62.66608045947168, 36.395849335578184, 21.557550430297855, 11.018960572058155, 11.660191609013467, 16.347733832174733, 12.715216029074885, 11.374772498684546, 2.1191786469951754, 0.2726352785623843, 0.183679401093433, 0.09018681222392667, 0.21928310754799077, 0.5298758057817337, 9.945894229796625, 34.625550316226104, 58.829920061172984, 56.132129546134706, 61.99344888810189, 55.71448341492684, 46.032740223792295, 25.56944674061191, 46.6716904024924, 60.481339885342514, 66.77641453281527, 72.36490557270666, 78.73201062602382, 28.029070938787154, 0.7644384450489475, 0.099037678822154, 0.2285877816499241, 0.13523904877083917, 0.1286239714752282, 0.14194614854791474, 0.11799899846195214, 0.11125545588231857, 0.10369884886688764, 0.11810441982121238, 0.17418302114932768, 0.10847850206999049, 0.14986288583567067, 0.24089962664631107, 0.07356829670888763, 0.26520756584021354, 0.33592455990372166, 0.12098085781138752, 0.109889758600583, 0.11328594128210699, 0.1710177143855441, 0.15351381573465564, 0.08735212602562482, 0.0856274705860884, 0.13341445716158037, 0.16793131467796144, 0.10507509517934054], [0.13153476850880733, 0.006453066936603958, 0.08736226136886305, 0.017348871183311267, 0.027721856810873555, 0.0563548602944901, 0.007420543575614331, 0.01591587690786729, 0.09261337274144735, 0.051981662700493494, 0.06194998727991216, 0.0713921090467803, 0.048021168162625645, 0.02850957331247628, 0.03578794676990759, 0.027800700664820693, 0.013115270130877054, 0.05363974509940994, 0.03035764168617466, 0.04643507504595384, 0.011417548427538527, 0.04254725543902286, 0.03444066624187174, 0.02117427952227093, 0.1452069864758561, 30.060078136382568, 69.05553125566053, 66.85733302947014, 56.76724756917646, 48.93491760376961, 33.78849298723283, 22.411256259487523, 22.00371023147337, 41.70520097978654, 31.159283153472412, 42.76230719781692, 43.97000889624319, 8.137260906157955, 0.18851778259681118, 0.020778593194160252, 0.05711650490880974, 0.03061903471637878, 0.08294820830586457, 1.63016842257592, 3.850789123004483, 4.288437135757939, 4.8356156195363695, 9.504727605850467, 9.273803945510618, 5.6347107791131545, 18.68429856915628, 32.94122965105119, 43.579321215229655, 52.30452383718183, 63.96719732592183, 62.67814959249189, 61.7949769573827, 57.413006982495716, 60.30505288031794, 54.7503883607926, 60.38031531918434, 59.33296795814269, 60.44377534620224, 60.5672868605583, 58.18747112827917, 56.08726547610376, 56.377054106804636, 54.11708247277045, 58.11218907756191, 58.187180872886415, 61.489769489534446, 62.197459205504394, 63.40794970912319, 59.11302105073006, 61.70815529361848, 58.67439808384065, 62.68186407704508, 60.544968574277824, 61.86108458426691, 59.16166236323696, 60.28539396101429, 53.36886682818013, 56.02415454003119, 51.958759061751834, 57.0520547897585, 56.26550974384431, 70.393553703062, 41.58851831190048, 40.05975884775962, 71.26945034150155, 55.147767605320105, 62.60061610129572, 57.86670754032751, 62.050036922577895, 58.747554209924516, 60.78750833388298, 53.44817323069419, 49.95051337826637, 53.36218310940651, 61.449267095135106, 61.05617500120594, 58.60427787227016, 54.77290668795186, 56.018651454679436, 62.1022319024609, 60.597261613415135, 53.86181462195612, 45.272906518751576, 49.21521409865349, 56.63354181474256, 62.82040219153128, 63.55849812107702, 59.50458342029203, 60.974821121461936, 61.73325454035113, 60.54061474338655, 61.865336433533706, 66.31698731453189, 60.258631629328576, 61.53869713506391, 64.92149037699546, 66.29419049909039, 56.35980352278679, 43.14378907603603, 21.575181484222416, 4.711249518779017, 7.228077073251048, 1.901613721443761, 4.7924940624544705, 3.5611005127429967, 0.4004994287125526, 0.04978679781479221, 0.05452169999179821, 0.012404145184724082, 0.022617365090897488, 0.16530908764370028, 5.636084589266009, 36.44518882997575, 31.36150290889125, 25.639615981809555, 49.08114356379355, 26.7441907236653, 19.39470256528547, 14.469972656619165, 28.961259472754698, 50.37010108270953, 57.23249950716573, 59.44168036983859, 40.02782290981662, 3.876756194137758, 0.024563942795559287, 0.003128593197024818, 0.03727782690416902, 0.064171688225601, 0.020615673105743144, 0.09216160303161991, 0.006017216055038115, 0.05250296638076825, 0.0761573981013029, 0.03903085057954154, 0.021769039543165315, 0.004334131419102872, 0.008675603875740161, 0.04238568366535249, 0.037729439565971974, 0.08353461796838431, 0.03757186294082673, 0.032869121134882016, 0.018677664094514424, 0.09617757382652453, 0.06185654370534805, 0.051791860586813385, 0.005321141384962586, 0.08156640019508139, 0.05092796621724002, 0.09684019391575167, 0.044146808720524275, 0.0488475127325904, 0.026152305447706775, 0.029523890961201924, 0.07167130979078432, 0.049769897915182576, 0.01574391985477339, 0.027574630033585335, 0.03872334288673536, 0.04778599066119041, 0.07318899891669713, 0.04871162788702115, 0.030074769465793526, 0.006382622757941605, 0.09165770869942443, 0.043513150585274545, 0.04389876094196112, 0.031044542932161884, 0.049902140012671875, 0.09740054892796664, 0.05437761417499954, 0.039024419271417206, 0.013687702519218288, 0.06661535931691047, 0.3005880495953945, 38.5706506236907, 79.69562715099704, 73.83609248745826, 66.12466566024288, 55.86893066283196, 42.50798463821412, 30.350206052103353, 25.51276849162194, 41.73711730587868, 30.56745436883742, 36.86809093721452, 39.85644671224779, 7.271522716168435, 0.042353090454613974, 0.07859878242015839, 0.17253974722998758, 0.19792453025377568, 1.9594844935401796, 5.070785245587749, 8.316162170902375, 12.831905561108744, 10.21304392045544, 8.481675405656139, 9.487070075927242, 7.974626691110673, 15.183039942095357, 28.593860864639286, 42.4471761334327, 52.780032773171705, 62.435464705190356, 64.41484566657775, 63.32135946519914, 59.256673935920965, 62.15259513547344, 56.970285138776234, 61.46707073334725, 59.9674544795867, 62.831977105909786, 64.39842662503644, 61.541132926940925, 59.00154336806267, 57.69549215993574, 56.40417337417603, 59.23085297307661, 60.47027487908641, 63.427032040011504, 63.58522907380135, 65.47940046556535, 62.28008393318423, 61.57399846661476, 58.78136111843971, 63.15288974392799, 62.01094658144059, 63.44886395239062, 60.24539362999701, 60.64339260901175, 55.61571028924758, 58.57481302753572, 53.54417324066163, 60.373639445151056, 59.377851640024495, 72.51912532314178, 44.16497030565816, 42.81494540552939, 72.57006122219947, 57.21323282487931, 65.47161063840313, 60.198572297250074, 62.297063873660186, 60.568875420478086, 62.38882380147135, 55.88015256389495, 52.76921879860663, 55.42427116824735, 62.13636829007057, 62.781990420433786, 57.88812760383853, 54.51259466909594, 58.33409324769051, 63.61282687033377, 64.41498687190395, 56.16969016290481, 47.526468999924205, 51.22293418453586, 59.18376491915796, 64.08900653162311, 64.78318368234943, 59.51708009166103, 59.70436934501895, 61.2125716670867, 62.65650595388105, 65.53238776422316, 67.09727225765106, 63.52779380736813, 62.39910825606316, 67.18907925390428, 69.23620347053775, 60.547341608232074, 42.50421524047852, 18.20214709927959, 3.6378107964992528, 3.017182008874032, 4.335846824030723, 6.201542298639975, 7.324581107785625, 3.095839013976436, 0.33410353826419004, 0.07049759414287345, 0.0847732672287572, 0.039867859093412276, 0.1727015909648711, 5.941974059227975, 35.73388268870693, 33.33141134631249, 29.653169493521418, 42.14694615333311, 24.132768838636338, 22.65449223979827, 23.64904449832055, 36.98017658725862, 58.98407313131518, 63.70810908655967, 68.31005342545049, 49.67288801746984, 5.0619010771474535, 0.024647770051453865, 0.08832806841500344, 0.05654909422681217, 0.014001906778092587, 0.041342999696010546, 0.04623798743611382, 0.02502889304812397, 0.048378096187427166, 0.06368654389535228, 0.022404574593829534, 0.031342623913059794, 0.021319501064417344, 0.013732420028968444, 0.02132418760729413, 0.04331405582507292, 0.050517714642468965, 0.010181454070393118, 0.01725857623011595, 0.009897902904589091, 0.015074527548295597, 0.052936897733278816, 0.07582468611578788, 0.060055857869766416, 0.05509569136906536, 0.042063792671767936, 0.07383176966780618, 0.16766008890924916, 0.07162395789618455, 0.3101244959379396, 0.09499465746264305, 0.19043223631958808, 0.13613302741319905, 0.24532170064987677, 0.15097449473556013, 0.17236780645626207, 0.2464105414166566, 0.221853056742299, 0.13970793074657842, 0.1302479706223934, 0.12329700973726089, 0.2170451655383072, 0.1740242417661413, 0.09179651617042481, 0.15180982168643706, 0.07107562280350155, 0.13991413097227776, 0.11931285457385164, 0.14503357481331597, 0.2856448917619644, 0.15194344274219007, 1.0168107286576302, 50.41961708376485, 87.98134388462191, 83.52406440242645, 76.25279026646768, 65.99266221446376, 44.625974316750806, 31.721186214877715, 31.416335682715143, 55.54718255996705, 40.51684441105012, 55.584256802835775, 54.80631351470948, 10.580227778803918, 0.6221788592876927, 0.20085870829080382, 0.4233185219908915, 0.17057116173448103, 1.5736903370388093, 6.8018242812925775, 11.508149754616523, 13.530110005409488, 10.990854828588425, 20.123367155751875, 17.673256666429584, 12.706298520488124, 27.343979958565008, 39.14645848735687, 48.37758802598523, 56.68011996053881, 65.1061555647081, 67.91780856347853, 64.70939605466782, 60.232547867682676, 63.11684708441458, 56.84843670937323, 62.95307636260987, 62.392553975505216, 64.67405157704508, 66.45893004632765, 63.71585576764999, 60.830952505911554, 59.54709799058976, 58.972847307882006, 61.77682815059539, 63.37187567064839, 66.35854874887775, 64.68569709408668, 67.32143571299892, 62.10176906278057, 62.85815500443982, 59.92748944990097, 65.05195233129686, 63.92391004870015, 66.44582932995212, 62.52124694085891, 63.396543456662094, 56.38657762158302, 60.4198645776318, 57.72516881265948, 61.95896340954689, 62.61397569410263, 73.88436901953914, 47.294864808359456, 44.82268510326263, 74.61664415174916, 60.06371336598551, 69.23326169290851, 63.56881003226004, 65.71811199188232, 62.98305896020705, 64.41767761784216, 59.87024245723602, 55.71769583609797, 59.32093412645402, 64.659299542827, 65.57124668552031, 59.641242719465694, 56.3855891842996, 59.48350852535617, 66.1472349782144, 67.48322563786661, 59.674865276582786, 50.186891094330825, 54.79058481031849, 62.173819080475845, 67.85799241835072, 66.48908522821242, 59.91120376894551, 60.467344868567686, 62.49301764272875, 65.40538926278391, 67.94205665588379, 72.43226835804602, 65.85083715377316, 67.46246061017438, 69.89365546934067, 72.27709154928885, 62.808360515102265, 49.04623839163011, 28.332725148047174, 11.127851451596907, 14.921011886289044, 10.58907860709775, 12.317614190040096, 10.089139188489607, 2.175333014419002, 0.25617422475930185, 0.16991470099216507, 0.336317072712606, 0.14616131752489075, 0.6552188831471628, 8.564130490826022, 49.007830542902795, 45.530006116436375, 40.72313362552274, 67.82363245564123, 39.18090081983997, 28.688072273808142, 24.860356738490445, 44.68727704017393, 68.56607437133789, 72.19221930350028, 75.33826612657117, 59.057319471913004, 6.543818125801702, 0.15588544008712615, 0.14980628725982484, 0.12703630021743237, 0.08690442424267532, 0.1538950210857776, 0.33711751201941126, 0.1473453523771417, 0.1617004304763771, 0.19119426397786987, 0.15181109339239138, 0.09863968848461106, 0.2095511862106862, 0.08249136709397839, 0.20498295795292626, 0.20038362652544053, 0.1890928081927761, 0.17277701998189574, 0.1656536127050077, 0.12803655057664842, 0.15490924488873253, 0.20202352965791381, 0.11455091332355816, 0.08224142324780265, 0.14837730345466446, 0.11538539757771839, 0.26389084455947726], [0.08384186519129623, 0.0362943155660985, 0.05089445753143199, 0.03558875624871543, 0.06569664369547559, 0.037562960999146584, 0.002856261867676832, 0.01857746170923835, 0.018525476897916487, 0.021328671136870984, 0.06373654645417007, 0.03692919944202708, 0.044085004577232946, 0.06825366898650123, 0.037122004620370366, 0.0291895835975846, 0.014509463968176036, 0.04988746176804266, 0.05018273120625846, 0.036868961948540904, 0.11417166149664311, 0.027118614281437574, 0.02201224947648664, 0.25932894418797187, 5.202887731213724, 62.47082487229378, 72.13189325025006, 69.02554081332299, 45.711996247691495, 59.03253401479414, 28.26335018680942, 24.399507661019605, 42.416805221188454, 38.82392591045749, 55.31853191314205, 54.6322936396445, 12.516394026817816, 0.5353934161605374, 0.08113038125297717, 0.11779445298616925, 0.05132574205016417, 0.15655792738881805, 1.9036874295242372, 2.958795322525886, 3.095194764675633, 2.776662269907613, 9.821588435480672, 8.25245209278599, 27.263869470165623, 19.34543759592118, 32.69555787886343, 47.49788276610836, 62.66804556692801, 57.92610006947672, 54.23969576435705, 52.874463835070216, 57.065555587891616, 60.35331372291812, 62.738844348538315, 58.709938679972005, 62.01515528463549, 57.42574291844522, 60.49402483047978, 60.436236550731046, 64.53770214511503, 58.544744137794744, 61.563525738254675, 58.084646194211906, 58.66760061633203, 56.03223070021599, 61.65867067152455, 58.58860015869141, 60.77203458355319, 57.380082607269294, 58.28005867619669, 56.89040607021701, 61.486600214435214, 58.25955252493582, 61.46826313387964, 53.9096636156882, 54.59840828372587, 51.20239273194344, 51.87809551915815, 49.70956610095117, 54.922046969013834, 54.04839392631285, 68.62897349942115, 41.889975993864, 42.991314780327585, 67.38000454441195, 54.05477562258321, 56.49181873567643, 57.845773850717855, 60.28825729124008, 58.66269765361663, 59.40905801711544, 53.945922005561094, 46.23289092894524, 49.90799488559846, 59.63279785648469, 59.91618517906436, 59.39661233655868, 56.712244172250074, 52.61586589197959, 57.68929089269331, 60.59550046920777, 55.60688495635987, 43.73078746180381, 48.6680160030242, 57.966826038975874, 60.921657316146366, 59.88342554338517, 55.99630571180775, 56.69939448756557, 60.92686230136503, 61.789214995599565, 60.64026647998441, 59.705098905871, 58.24556535290134, 58.86810433480048, 61.61254752066828, 64.75567610033097, 66.15063959552397, 56.165485382080085, 38.13399276425762, 15.404116492117605, 7.242844306653546, 3.994768790660366, 4.358848583313727, 5.792383195892458, 3.932219243818714, 0.7139615245884465, 0.0036071927423754167, 0.06219663311757388, 0.04826303744207948, 0.05654129162130337, 0.13556033072452392, 10.349903260507892, 53.31207875282534, 39.85988270851874, 36.15583558236399, 45.97281032992948, 33.2064877786944, 16.310971417734702, 14.715194336829649, 28.16562041159599, 51.00694102625693, 56.244893766218624, 57.450536220304436, 13.481174515139672, 0.09533978773341065, 0.022945779323157285, 0.014941990506955454, 0.032668421420479016, 0.05221061956798358, 0.046177470320535284, 0.0645286660461176, 0.04689341012929236, 0.04014477306496232, 0.021170060293027954, 0.08066445423830902, 0.07719169340787396, 0.04449931641800269, 0.03433729799824857, 0.042232753363468, 0.02701005770734722, 0.07625194101203835, 0.03129422439322357, 0.06204423141635715, 0.025678441762143088, 0.10095621579356732, 0.040319073389494614, 0.05827335513106758, 0.028080623446693345, 0.039856972984008254, 0.03284441862976359, 0.05825020395399583, 0.06400054801375636, 0.06697249418545155, 0.05043344497079811, 0.034935210470951376, 0.030021940042535146, 0.04493371125370745, 0.01771043595527449, 0.03885879489262739, 0.07557294196299008, 0.003266382968098286, 0.08682612239593461, 0.013416183721874992, 0.025096002350290938, 0.015671771609284464, 0.07101811258302582, 0.055170511346190214, 0.07199298244931045, 0.07098785211001674, 0.05941882511721023, 0.0706449511551088, 0.046636701726745215, 0.06254957748516914, 0.24483906525758006, 7.364224012820952, 71.95365290487968, 78.89908790588379, 78.2887984860328, 53.30533227612896, 65.89160626934421, 35.20755552476452, 26.33116122215025, 36.30131236968502, 38.29768896102905, 44.5462207640371, 45.61051276422317, 10.304322377327951, 0.31319044109794403, 0.0707787177675674, 0.10882282028755835, 0.12389325596872838, 0.5123293279640136, 3.5492426974158136, 6.550908790480706, 7.948267382960166, 10.746566672478954, 10.52642462715026, 6.4104261609815785, 16.7495326072939, 16.375571873880205, 34.6250404081037, 47.21734308427381, 61.72608444767614, 59.32093020408385, 60.1134176408091, 58.2323234311996, 59.817616016634055, 62.58399701887562, 63.08351478269024, 58.16364665185252, 62.7046295135252, 59.69682662717758, 62.59461487493208, 62.21415673532794, 66.34396537657707, 61.289791368669086, 62.87913968486171, 60.98059485035559, 60.48075937455701, 59.02814096020114, 62.95926586274178, 60.401739305065526, 60.63547334363384, 58.41895372636857, 59.055428889489946, 58.545042237927845, 61.810391872159904, 61.490342155579604, 62.60762145442348, 56.68405017545147, 57.70644733982702, 53.68360565554712, 55.1190205543272, 50.957817262218846, 58.15921045118763, 56.924432631461855, 70.7352392135128, 42.916523025881865, 43.77211355393933, 70.49405267161708, 57.419059199671594, 59.69261792398269, 60.65934488850256, 61.76677903821392, 60.386367536360225, 62.853036311364946, 55.06945356245964, 49.58006120497181, 52.25337220776466, 63.683311862330285, 62.097101442275516, 59.714394923179384, 56.144237902856645, 54.140977551860196, 59.51331069392543, 63.24281792486868, 59.42649687490156, 46.74095161499516, 51.33553758744271, 60.24680176088887, 63.93889742512857, 62.218957716418856, 55.58909700762842, 56.11500447796237, 61.6844641777777, 64.60730852619295, 63.15161889599216, 63.24672460556031, 61.29356468877485, 61.33688726732808, 63.91751266294911, 68.25561092745873, 68.55506035589403, 58.97365923850768, 39.47009325027466, 17.31266140937805, 5.801394351067082, 1.2099991041806437, 2.9634825548818036, 8.053839447036866, 5.621427672524606, 3.513388066522537, 0.21442940428612695, 0.25347483734930715, 0.10437154301231909, 0.06720632720257967, 0.17535735732845723, 11.580294889788474, 53.599502194312315, 42.27358379671651, 41.09406432797832, 31.89133078821244, 20.406766245442054, 19.455552254953695, 27.61099530804542, 37.20857620239258, 58.6071765038275, 62.38648606884865, 67.40213455692415, 17.959481823828913, 0.057425713316807826, 0.042174408107154795, 0.015621510495792235, 0.07703980881600611, 0.02862393874825249, 0.05294701775475856, 0.08020285562041306, 0.031379108850453655, 0.02849561327527608, 0.03300799372335596, 0.009875238193349253, 0.04822217431219836, 0.00510024328363098, 0.005826818786801831, 0.022454230497861584, 0.05265742502806168, 0.018677736872867234, 0.03950900818792082, 0.04989909864361248, 0.017191704415205507, 0.02986609669131858, 0.04870821113487886, 0.05876665063683064, 0.030596733896902976, 0.07993641024034831, 0.023661380138007865, 0.18505482003092769, 0.10107727300736213, 0.22330110081501547, 0.08133360905753029, 0.18230376765131953, 0.1375739621899782, 0.1756082358019006, 0.06970903685977382, 0.22371659626162824, 0.1615838472160601, 0.15224266136365552, 0.2679794864548791, 0.14565332462230038, 0.19368743584040674, 0.131358384425121, 0.1279745510809364, 0.11371701129622037, 0.23604583145389635, 0.16303317831648936, 0.19218905979106504, 0.20356422440419275, 0.15159717100041528, 0.12386119518909725, 0.41057474130103666, 12.373065717758672, 84.430280962298, 85.997785599001, 87.87875821513515, 63.98921751206922, 73.28107710807555, 39.21613939346806, 32.022522303365896, 53.47471198728008, 49.34475821833457, 69.02482694195163, 69.70945312130836, 16.331553074621386, 1.0489671773487523, 0.18283121918718662, 0.32295518164192477, 0.13994881943348916, 0.6412558582040572, 4.03117525000726, 10.544651881341013, 9.480212792273491, 10.776420812452994, 21.61058479739774, 21.00896381562756, 37.75864547298801, 23.149903282042473, 40.822149938152684, 50.696065733509684, 67.79118660957583, 62.27530648631435, 61.44905920951598, 58.765773619374926, 61.34285711473035, 62.50317265910488, 63.056309223175056, 58.48217056643579, 63.10233823714718, 59.56418383506037, 62.54926835336993, 63.345984105140936, 68.19309619165236, 62.203307459431315, 66.40771173661756, 62.82778409219558, 63.128763244998076, 61.78023276790496, 66.77554376663701, 61.52309002414827, 61.51662988047446, 58.66657295534688, 59.33641179915398, 59.50346554479292, 64.05153612936697, 61.75070908761794, 65.04141292264386, 58.67207996306881, 59.98084152898481, 57.070638979634936, 57.51577700338056, 52.84693271883073, 60.267688382056456, 59.564815336658114, 73.1965970993042, 45.47717179021528, 48.49556507602815, 72.34442295566683, 60.46801951623733, 60.944105040642526, 63.53395977327901, 62.06311802710257, 61.53445705290764, 66.86414226408928, 57.24772222580449, 51.85883668161208, 53.45645335412795, 66.85863525636735, 65.23005147134104, 62.247449813350556, 55.890044781469534, 55.77723349294355, 63.4174967581226, 65.3118799578759, 63.125644960711085, 49.00601840788319, 54.81838657009987, 63.79080833927278, 67.0948717671056, 63.281143403822384, 55.580459948508974, 56.72866321379139, 63.28507361873504, 66.21995572120913, 66.03801265839608, 65.31594745574459, 64.11117576783704, 65.7281061910814, 67.94888157998362, 71.75672638800837, 71.74972103488061, 62.75557325732324, 44.82936882203625, 21.05664610862732, 13.970950092038802, 13.026487481209541, 15.213683459066576, 16.16835011589912, 8.763609490086957, 2.9544486009305526, 0.2046717117510496, 0.38957875342138354, 0.12918096336145557, 0.1504057357388158, 0.38016733262808095, 15.413485073274183, 67.110200389739, 52.75614946119247, 49.77220243023288, 66.4488495549848, 50.274144218813994, 27.862823240218628, 28.661908103573708, 45.84030874313847, 69.6138100470266, 73.44287487768358, 78.198207424533, 23.093889874796716, 0.3138568763050341, 0.10847641831083644, 0.11258277215904768, 0.15590698247955692, 0.14778349338279617, 0.17907613197401648, 0.15876786122398992, 0.14156258364598598, 0.1756783941340062, 0.10186583029046174, 0.24090953982405125, 0.07474250265307004, 0.14380129174359385, 0.14989693078302568, 0.08975349757219515, 0.15038020968917878, 0.16264198317883477, 0.14748180795821453, 0.17493364941929618, 0.14064623523623715, 0.1814186756288813, 0.16364189645936414, 0.12189269396326236, 0.09803614143522517, 0.18064192376069485, 0.18929868666154726], [0.006827703083775217, 0.07660695381702916, 0.09076283373419317, 0.025239693631808606, 0.07275553104738075, 0.06198359555715035, 0.07855622623596462, 0.06460916656520098, 0.02427363760709282, 0.07415591679032772, 0.08194218164369946, 0.07420268645810504, 0.026678592529928973, 0.014762915539435081, 0.037214069236670776, 0.009892441655298876, 0.05986622429542965, 0.05917888254888597, 0.014781740234954464, 0.04495126998893196, 0.02863800603776209, 0.09510369475690589, 0.03662914195428452, 0.4604408445377504, 31.809494456937237, 69.10406666417276, 66.3151438005509, 56.31082488644508, 44.77882908236596, 37.719425693635024, 22.13971841719843, 30.127448766462265, 37.23315769626249, 41.05850411999611, 48.85976106889787, 15.25050667024428, 0.8957503279370647, 0.1096340767558544, 0.05605580638192835, 0.0067593225544588945, 0.44321407053259115, 0.6709637673151109, 1.3261775023514226, 5.8784963815442985, 9.583269146180923, 17.715220143718106, 9.029369681112229, 7.447020344195828, 26.686184752372007, 42.25697648140692, 53.196976800118726, 55.62539069883285, 49.99359276986892, 53.962678370937226, 62.125452333881015, 65.70632919188469, 66.5483130178144, 61.27505894630187, 60.716297703404585, 59.821969847525324, 57.795014458317915, 60.061971833628995, 56.661429866667724, 59.93722869503883, 60.111978130955855, 61.28868526028049, 61.41522484440958, 59.36848894242318, 58.2742339564908, 59.15302530411751, 60.504497558839866, 58.93063476008754, 60.17675607435165, 59.0590766937502, 59.589004593510786, 58.9499798897774, 62.17305029592207, 61.42743126038582, 59.33388187039284, 53.02946021479946, 52.45273059414279, 48.31553220748902, 49.20487080850909, 47.30509042739869, 54.95342593039236, 55.07286994687973, 67.43197594919513, 41.62676142108056, 43.690387049028956, 65.59381992586198, 54.227144179805634, 56.80661247622583, 56.72104204854658, 60.38218236738636, 58.172240564900065, 61.8336279930607, 53.98167048731158, 46.39078594023182, 44.801869084758145, 56.258622061821725, 60.85294131309756, 60.95903750388854, 57.5933301064276, 54.883411622816524, 55.99215584416544, 61.96696896706859, 56.63745634017452, 43.86351654606481, 47.65071007513231, 57.99360798251245, 59.44567726504419, 59.23213166575278, 58.82627225691273, 59.773995337947724, 62.79689934945876, 62.43968517549577, 61.20461317800707, 61.844567483471295, 56.522464213832734, 55.68998821320073, 57.25727711954425, 63.88780070889381, 64.63065839582875, 68.3826800315611, 56.1668150655685, 37.97415617973574, 15.322934216068639, 2.621117493798656, 1.5973222496048098, 5.443711944164769, 5.397497598201999, 2.5372998752901634, 0.859045094299701, 0.07516621056223109, 0.039252161889547305, 0.10208532214164735, 0.06541461608703099, 0.4450280748067364, 15.15787107329215, 46.106108157865464, 31.17464903862246, 63.37313475147371, 105.08348972566667, 41.12962061359037, 13.80626545798394, 37.998435651102376, 47.7232111653974, 51.76573922557216, 53.5922928779356, 26.65620411595991, 0.6741430322008749, 0.026889950442578525, 0.0293072221440173, 0.03970898777967499, 0.014939013297759719, 0.04385789015120076, 0.035230499061365286, 0.028542917289380586, 0.056689399399704514, 0.04625170424039807, 0.01567536934969887, 0.027463254255933628, 0.05589214701866431, 0.16890400119366186, 0.03591707855042431, 0.022541689010517254, 0.03342576828154345, 0.012653993269909295, 0.0378639952489926, 0.0033474532650753616, 0.016485189403136893, 0.07183036496562344, 0.03332590489017387, 0.029130384153235826, 0.03508250236571316, 0.00377053537616326, 0.046272583966774326, 0.04063696923455404, 0.03791263800174479, 0.09032234083861114, 0.012939969103993669, 0.03770454553887248, 0.013632743371530406, 0.07721019443124533, 0.03100934693770063, 0.0904391845688224, 0.12172340385375485, 0.03302590102858601, 0.038541864318352555, 0.05103911408373425, 0.07592517386881575, 0.0814773271521253, 0.030613223939473112, 0.00921937978766378, 0.03464311646718172, 0.046972524029232805, 0.02062628916915386, 0.03437887358989927, 0.014309691220161416, 0.7457502510759139, 39.558793729351414, 79.94502713603359, 73.84902061954622, 63.422501702462476, 52.48753770705193, 50.64178013032483, 26.728367882390177, 29.02465281947967, 38.25504887488581, 39.695209841574396, 43.96286233778923, 17.644252700190393, 0.8436901795287287, 0.03816202260373581, 0.07901692853098916, 0.056586529113232135, 1.360048884826322, 2.7874985529530436, 5.719156467145489, 7.751126606618205, 7.163450631403155, 16.39245669687948, 12.09474805862673, 11.02177095028662, 28.994613347514985, 40.74456937851445, 52.497704490538574, 57.98879915668119, 57.51296466396701, 58.36236961426274, 62.653305299820445, 65.37868968902096, 66.20585087806948, 62.12986500032487, 60.30422526021158, 59.984465799024036, 59.280380741242446, 60.40917611891224, 58.35277941919143, 60.39711875300254, 63.56768823439076, 62.905823569143976, 64.16175473120906, 60.361232988296024, 61.834188891995346, 61.09885823342108, 62.162369681942856, 62.02615753296883, 60.647177696228034, 58.98393192598897, 61.27002654537078, 58.62625883471582, 63.28437543684437, 61.10647547629572, 60.35420410094723, 54.824368184612645, 54.65490610368791, 50.236367871684415, 50.83391743321573, 48.61462470023863, 57.58686604038362, 57.948583095304436, 68.92187256966868, 42.74617056692801, 46.21968823094522, 69.2960431498866, 58.563445998776345, 57.82485192821872, 59.81674132808563, 62.610163150295136, 59.1424584388733, 63.426404460783935, 56.03941648237167, 48.70660035840927, 45.797625510923325, 59.12754166510798, 62.12945707382695, 63.19674968719483, 58.45112108415174, 55.667152174057506, 56.058502735630164, 63.48982526410011, 58.342836210804606, 46.9699788093567, 49.877451389066636, 62.11645833907589, 63.53222608566285, 60.84900325344455, 58.58104567373953, 58.6460550369755, 62.99921128057665, 65.4644444680983, 65.40351829221173, 63.38942043242916, 57.8380467814784, 57.46959109460154, 60.076178658393125, 67.41735335319274, 66.24769472306775, 71.27924057745165, 58.54136305470621, 41.923441656174205, 17.559819759861117, 6.796453575934134, 2.5946076646927865, 6.362595308211542, 8.509658575057983, 7.773165424023905, 2.2952200135877057, 0.4171162435123998, 0.09584320709109308, 0.054465243142218366, 0.013873273912336559, 0.47366578973108725, 19.34079350963716, 53.391161580239576, 38.13315729941092, 58.81935711829894, 87.42623436835505, 35.711803667006954, 18.380509038125318, 42.636301056031265, 53.97644981261223, 58.71076630007837, 63.14927724099929, 34.66444061648461, 1.0241334260471406, 0.04364571060925242, 0.038641861775108886, 0.01665914498810326, 0.035324892584955504, 0.03177456726740686, 0.021243792425300327, 0.04394931891452401, 0.0975990423091477, 0.03358748561191944, 0.03348865260880801, 0.062092517938224547, 0.10593500589170765, 0.06663713153571853, 0.05671850307994793, 0.025077468768182783, 0.03663448158711676, 0.0186603351856672, 0.0470108590689638, 0.045326572632597345, 0.014321518660102402, 0.05397882327557572, 0.05687421428099756, 0.026926247688430934, 0.03868631785735488, 0.06457728198579242, 0.07291866180997703, 0.13753925840700829, 0.31259601815573634, 0.19741135859681716, 0.17539218368549503, 0.22854943128843463, 0.16668504284274194, 0.20898284090142097, 0.12279025789710785, 0.13838357923011627, 0.3483497399476267, 0.16491432253631855, 0.13198596365269155, 0.11715211890517704, 0.18925102067089852, 0.18189253165356575, 0.20644808578635418, 0.17368826624606887, 0.08223688034641166, 0.2216944305766975, 0.1712905182953804, 0.17227157049121397, 0.15226000559426126, 1.1744591209196276, 50.27479140989242, 90.51630112432665, 83.32616513775241, 72.30312824249268, 59.738105650871034, 53.00014834250174, 34.15257915373772, 42.967407934127316, 48.16650959753221, 54.79255384014499, 63.16169938733501, 21.168286569656868, 1.104640073833927, 0.2601108135234925, 0.21653603882558886, 0.15802225849080473, 1.2528465856467526, 2.3858750587509525, 7.313782332404968, 13.747874113821215, 17.559364764921128, 31.792793004743515, 23.19006835260699, 15.608583765645182, 33.408011313407656, 46.09199546998548, 56.33055048604166, 62.20647673453055, 58.393579913723855, 59.660999698023645, 63.890581669345984, 65.26185404869818, 67.3320496466852, 62.103149737081225, 60.70927666079614, 60.77738861883841, 60.25649785995484, 60.46239483741022, 60.07120509301463, 61.1097938014615, 64.90946439004713, 64.28296773664414, 66.8326848553073, 63.523177177675315, 63.83200107082244, 64.54980657946679, 63.87835564151887, 63.25948015336068, 63.26723467919135, 61.30329608917237, 61.603498612680745, 59.70995872251449, 65.29199746347243, 64.1725451715531, 63.87592377201204, 57.447151214845725, 58.3113121217297, 52.98879308085288, 53.55918415131108, 51.72977109109202, 60.01120459648871, 62.106589655722345, 71.97007194642099, 46.024628762275945, 49.58481511762066, 69.10081109692975, 61.346057768790956, 61.78497491344329, 63.29559341553719, 64.71776247024536, 61.25054805509506, 67.51507528366582, 57.94019706787602, 50.923512212691776, 49.38025566839403, 62.59842741873957, 65.76760445871662, 64.52908077547627, 59.67594785075034, 55.544515348249874, 60.43803299626997, 67.08653280811926, 61.42787841058547, 49.19870092022804, 52.35551072705177, 64.06961825586134, 63.88274869611187, 59.93800140196278, 59.92518701860982, 59.397996933229514, 65.63257294316446, 67.48123307381907, 69.40833276317966, 66.91518014477145, 61.29463941820207, 60.70153782444616, 62.467235903586115, 71.01996406432121, 68.93007816806917, 73.3848944017964, 62.15425429805633, 46.61082698452858, 20.000214538266583, 7.839543204153738, 11.680374164735118, 19.339155920090217, 19.508839614929695, 8.654505821966357, 1.8708346375534612, 0.2710995480658547, 0.12538228574539387, 0.19737506135096475, 0.20580809593441027, 1.000600921050195, 23.90294344194474, 59.66994270201653, 43.22943010637837, 73.66715600413661, 118.43041327691849, 54.55991022048458, 23.911396149666082, 51.640886260617165, 62.90853000456288, 69.3491598867601, 70.91735486061343, 44.373601175123646, 1.5839392451509353, 0.19082134769808864, 0.12273863123189058, 0.17137521697628885, 0.14256720070637044, 0.11937991024986391, 0.11042610441725101, 0.10665220208466054, 0.25891970001882125, 0.2126724888840991, 0.13701298664654457, 0.08102206408136314, 0.20859878570322068, 0.3257491655888096, 0.15030082765846484, 0.17450238788320174, 0.15460078724690024, 0.10977167380793441, 0.13811478962100324, 0.11797696577324984, 0.08397790708488996, 0.152298616425645, 0.14567141961907187, 0.09985752313608125, 0.11629990737644896, 0.2380289266546888], [0.04983661268206854, 0.046710031662857344, 0.03375199533277943, 0.06449499648184547, 0.04577243197408896, 0.04372623411097354, 0.043848187647639744, 0.07543104715765485, 0.024572929006911094, 0.14719400404682084, 0.03135138604369375, 0.028467612761643626, 0.0958419047416218, 0.019429799642473943, 0.03158996306029299, 0.036451428708049564, 0.05419825383972737, 0.02889291987934661, 0.0404674033333938, 0.05287317837017679, 0.04710273599372276, 0.05771671564528539, 0.06887783912280876, 1.7911684801501615, 41.35614141341179, 63.85979890823365, 67.57482867087087, 54.9405840904482, 36.11749049155943, 21.5511255879556, 31.270690233476703, 43.25241127321797, 43.37248679130308, 46.93351645623484, 25.44088713584408, 1.5435900683364563, 0.06274831218404636, 0.05963442524174049, 0.09556818152627639, 0.0895486380003633, 0.9192875520356241, 1.6009743439574398, 5.494586556188522, 4.288662672042847, 9.628684309221084, 11.57431229468315, 15.733741694881072, 22.15890076852614, 47.71048307418824, 54.63853805295883, 51.00072406953382, 49.98289646640901, 64.87986618472685, 68.57628037852626, 65.4573606675671, 61.72641000440044, 61.19622322820849, 60.38413963010235, 60.3706152977482, 57.536793062763834, 55.75163610519902, 57.305404601558564, 58.94633208551715, 59.84597867535007, 59.83763187162338, 58.719956413392104, 60.11153490312638, 57.80154520465482, 56.03139523536929, 59.32954765135243, 61.479324217765566, 58.55218487401163, 59.62848324929515, 56.809389514307824, 56.91181436661751, 56.74560000819545, 61.14337713487687, 59.526909551312855, 57.011328820259344, 49.350131865470644, 49.8113045384807, 46.42977037737447, 47.37753268211119, 48.25998360110868, 55.107386804396114, 52.45811208601921, 65.08344111904022, 40.67619854404081, 43.86341064207016, 64.2664937819204, 51.405697022714925, 50.97697411814044, 53.93000502740183, 61.799020921030355, 58.18638855411161, 58.88091087341309, 53.591731979000954, 47.32542791674214, 42.945262232134425, 49.209181493328465, 54.452080342077444, 59.24817415975756, 59.20487119305519, 57.20777680796962, 51.66012940868255, 59.763295112117646, 57.619798260350386, 44.43594332664244, 47.27857520503383, 60.95369523571384, 60.1800940113683, 60.087235819908884, 52.63797237027077, 56.48643332142984, 61.075575044078214, 61.73896551132203, 58.83847082814863, 55.54099305983513, 55.07391721971574, 52.576253875609375, 53.89440951808807, 59.30224795495311, 62.085895230693204, 64.71258101924774, 65.16230821609497, 61.884183422211684, 41.589326320155976, 18.167265461337184, 2.4292961868547627, 4.927408397197723, 5.980430447286175, 7.32990425440573, 3.0065837646684344, 0.5390093511631412, 0.09100234346284021, 0.10140338131496984, 0.07914647399898499, 0.027580641908571128, 4.679781323479069, 27.49036281339584, 55.634333702825735, 87.06836515857329, 90.52937830648115, 85.17466837360014, 28.944914956246656, 33.16506362730457, 36.99213589391401, 45.51207304000855, 57.3244986995574, 55.01130050228488, 2.8893436299216364, 0.2166379898065521, 0.0711100124904225, 0.08520876523107292, 0.07498042657971382, 0.0486096577538598, 0.07332935388530455, 0.011551903970088932, 0.021290359079777714, 0.06562922029725968, 0.013338182564644564, 0.05127285517031147, 0.03198709154892112, 0.12778856025467958, 0.010016504806586573, 0.027426460968150247, 0.05124411155139247, 0.02104220021846554, 0.04994443189653178, 0.0407232805305431, 0.030438613349331484, 0.018661461334915894, 0.03851083009653995, 0.017703154289554206, 0.014920450029744497, 0.0321130670471898, 0.06581676628200278, 0.020075544729949008, 0.014180881196572898, 0.04711256107135166, 0.02279698589606391, 0.09503316870259662, 0.05923384935745309, 0.07487881267743726, 0.04240141911131721, 0.06073134440568186, 0.00784887530420336, 0.02678337995143187, 0.023516945751203645, 0.03508005854523471, 0.054152334529546, 0.05240204195762354, 0.05644960621852548, 0.03993981390170032, 0.02519274967902851, 0.013711801730096342, 0.018858702162340767, 0.056574685393922755, 0.06774969038463409, 3.023221478346856, 52.95753179057952, 73.66017418522989, 75.81435557334655, 62.863803217487956, 44.28533215676585, 30.39732744616847, 42.846779361847915, 47.070073773784024, 36.28605434971471, 44.419598810134396, 26.055612756359963, 1.552500957923551, 0.02104432802767523, 0.011714209272946802, 0.12632670361668835, 0.6283844779095342, 2.327052499017408, 4.782813652869194, 5.138548602980952, 9.911059660296287, 8.576433985464035, 10.80848716920422, 18.44228832952438, 23.835663026379002, 45.051892726652085, 54.71441238157211, 56.6790020850397, 56.41291633729012, 64.76930241430959, 68.99136912438178, 65.6308235660676, 64.32843192931145, 63.65126609802247, 62.593426396769864, 60.46138286590577, 59.084152406261815, 57.63241260282455, 58.436416118375725, 60.20286337021859, 58.765259788882354, 60.20225148047171, 58.06317906225882, 59.18579278453704, 58.218650048778905, 58.547485874545195, 59.95111388544883, 63.27879390408916, 59.53695866369433, 60.619776018204234, 57.358136946155184, 57.45665904014342, 58.26400833745157, 62.218887113755756, 60.46157898441438, 60.47044354100382, 53.07870164994271, 52.187213590068204, 48.972956749700735, 52.14280451497724, 50.1497305593183, 56.58681069650958, 55.51368551869547, 68.0275486361596, 41.97009432700373, 45.60890851482269, 64.65119200368082, 53.70388038696782, 53.87409948533582, 57.02633188616846, 62.91982250828897, 58.4435038412771, 62.71259584734517, 56.29967358804519, 49.41319181073097, 44.61070452966998, 50.87404720244869, 55.782862094140825, 60.54459202674128, 60.765272417376124, 58.981225490570075, 55.61025427233789, 63.745940346871656, 58.57662516255533, 47.48422507316836, 48.81215918448664, 61.436895939611624, 61.49259359605851, 59.65603005501532, 52.77366284401187, 58.02114302112211, 62.71931486745035, 63.246661847637554, 61.54702432693974, 59.22369856988231, 57.31603030235537, 55.152423458714644, 56.25605683172903, 62.2081829655555, 64.73310678235947, 66.1972059742097, 68.71242584720736, 64.38078772637152, 41.01178084650348, 20.394834395377867, 5.614236987406208, 5.115848375904945, 8.6073403012368, 9.254156793317488, 6.146879167326036, 2.6085266855455216, 0.20159507200362223, 0.1757473880124669, 0.03501470358441434, 0.023880630671497316, 4.343785210963219, 33.00607035236974, 58.51813477854575, 82.29436212970366, 90.0173834831484, 76.29756804435485, 30.218991002728863, 42.05069511167465, 45.63726725116853, 53.08508334621307, 63.78626623461324, 63.194306050577474, 3.9392032690586585, 0.11399660274506578, 0.03378521290517623, 0.02894602126381811, 0.0670711892927366, 0.13671660255039894, 0.05525217248847889, 0.05749498298692127, 0.023376087079786008, 0.08234224041863795, 0.029235734649363066, 0.09030310437083246, 0.05554787859681153, 0.026586623674619104, 0.05411383478091129, 0.035133933678509734, 0.07179641194881932, 0.06769901366844293, 0.019673084269367883, 0.00411451364221472, 0.0576814066528553, 0.0599522827824037, 0.027884010811366385, 0.017867018581337987, 0.020962785629014817, 0.027499570653984146, 0.16375441945368246, 0.1742603040991291, 0.10487694653772539, 0.27525686208278904, 0.13121540177493327, 0.2089396948295255, 0.12988047824511606, 0.1479472216939734, 0.06613332913407395, 0.2250725412440877, 0.17989702582839998, 0.15691397441250665, 0.16256920482602813, 0.09937766098207045, 0.14057981541320203, 0.16973387359851794, 0.14621201722371965, 0.08634031539963138, 0.11361563488120034, 0.15621743194999235, 0.1943101274270204, 0.26193103843158294, 0.19519704273871838, 5.488304390061287, 64.37920308882191, 80.59499525254773, 86.26414591266264, 69.70150639933925, 51.960473137517134, 31.728605378058653, 43.95912039664484, 55.637471598963586, 54.208191287133005, 60.85547516422888, 33.415750149757635, 2.4134949186155876, 0.19383446343483465, 0.12183447128101704, 0.19068783389464503, 0.5946140964665722, 2.206582292433708, 5.915127886879829, 9.755105241652458, 12.699656967193851, 23.464971588503932, 21.916721866976832, 25.012040676609164, 27.089884896432203, 53.003341151822, 60.244868032393924, 60.42956067669777, 58.34797451573034, 65.85104896176246, 69.46324594559209, 67.42100900219333, 66.23322902187225, 65.8148847087737, 64.95691722439182, 62.116677991805545, 61.65561514516031, 56.65556984563028, 59.349057520589525, 60.47642907788677, 59.85896956536078, 60.46926290758195, 58.656186519130586, 60.025654608203524, 59.6071102542262, 58.97292967765563, 60.33925594822053, 64.79014981177546, 60.498759131277765, 62.862626506436264, 57.65790800894461, 55.99418370954452, 58.13828460631832, 64.08819852336761, 63.12340920971286, 65.02302092890586, 55.251565287190104, 54.75822133402671, 51.760706824641076, 53.3803476056745, 53.37900615507557, 60.02905138077275, 57.864993464562204, 69.89305142433413, 45.507040639077466, 48.76167043562859, 67.87680410569715, 57.31434368318128, 55.74992202943372, 58.636162819400916, 64.91189625955397, 58.75530481338502, 64.1962323650237, 58.58092800263436, 52.64162409690119, 47.21641740491314, 54.00596957052908, 59.01462447258734, 63.85632761063115, 63.5307316626272, 60.152641342532256, 57.15608781383884, 66.49467852807814, 61.67737645487632, 50.18094085877942, 51.336322061477176, 65.9659351841096, 64.00185146639424, 59.49866848607218, 52.33934271720148, 57.29243724576889, 66.00828109248992, 67.07727601451259, 65.90929615882136, 62.958540224259906, 58.384036787094615, 57.71928525740101, 59.517197762766195, 66.81759157488423, 66.11220821257561, 70.1916536208122, 71.91000476960214, 68.25303000788536, 49.38202857971192, 26.433556656683646, 8.945445668312813, 13.7092887778436, 14.579127315552006, 18.483585003883608, 10.696576064632787, 2.1174790349698838, 0.2479637693613768, 0.36841321496232865, 0.12057099311101822, 0.18027251616360682, 6.2340180527779365, 40.353132524798, 65.89137877187422, 90.07763893373551, 91.37938730178341, 95.61166394141414, 43.15526593116022, 45.129728240351525, 51.46566614027947, 61.070417127301624, 73.00396165540143, 72.03058627343947, 6.002983585480721, 0.27852189817255546, 0.21133506790764872, 0.24575791111396206, 0.11575816063991479, 0.22525039621658866, 0.14789897347650222, 0.2068286016583443, 0.10851552709937097, 0.16152691156152757, 0.1844737729838779, 0.18550183233474532, 0.1601140156027771, 0.18096764902434043, 0.12776288864833693, 0.16819112573660192, 0.1920380332176724, 0.1924804336721859, 0.1718047777971914, 0.148413983744479, 0.15815918904639062, 0.10882533305594999, 0.12234112352973993, 0.12512132555486696, 0.1320021893949278, 0.06408651457017948], [0.10157828684896232, 0.051448002022000096, 0.07643548035693747, 0.03667285876168359, 0.04255641402015763, 0.019624512379748688, 0.019411040064428123, 0.07179324800569205, 0.02089781371215659, 0.0493984793372933, 0.0298062518178936, 0.08665574444157463, 0.04479910577497175, 0.04738967039532239, 0.06597592870915128, 0.08046900222618734, 0.030049030826757514, 0.06404186696595242, 0.045004911465390075, 0.04310108338212294, 0.05187314634601917, 0.04678704265144564, 0.34784445899628824, 12.700123729244357, 65.19011782061669, 61.034656878440614, 57.64222245062552, 43.005827549965154, 38.208007889409224, 22.61132851723702, 30.424674211009858, 31.14952821885386, 42.20555028607769, 43.89041616070656, 3.3000991373292865, 0.24961663470152887, 0.09840223187160108, 0.06087168022209118, 0.1264903859625901, 0.6271661529617926, 1.8343084233422435, 4.697673215020088, 5.308511766695208, 8.655993380854207, 5.359173099840842, 25.06515545229758, 46.08270729741743, 49.16873401211154, 57.17431506802959, 48.263199944649976, 56.910488605499275, 68.10144609020603, 64.75605264786752, 60.8665793941867, 60.94653691014936, 63.36412898955807, 61.6195724856469, 63.309968902218735, 60.45236533687961, 58.19009127155427, 59.876541783732755, 56.299108766740375, 57.43270512550109, 58.11233420525828, 60.15342581656672, 56.9675120230644, 55.24960802447412, 53.86055554113081, 57.70448223237069, 56.29275060469105, 58.0915613328257, 58.38112246605658, 59.88266852594192, 58.14733743667603, 59.08761585912397, 56.150654900458555, 62.08370262576688, 57.6476235543528, 54.74827028089955, 48.63350699024816, 49.82684889147359, 45.62136204011979, 50.10979690859395, 48.26183103745984, 52.67794132232667, 55.98204397386121, 65.84473394578504, 40.853344548133116, 47.52409596596995, 65.15571078946515, 51.741675484565, 50.22632660404329, 54.784803236684496, 60.3701759922889, 55.59101896901285, 60.819326600720814, 56.43095139534243, 50.25546196968325, 41.851772108385646, 46.165488919904156, 47.785569006396884, 58.072726111258234, 57.2108401790742, 60.08110907769973, 53.42414871338875, 58.97412207818801, 56.79348822562926, 43.945599986660866, 48.05907980088265, 58.483217839271795, 59.25259467094176, 56.465997772832075, 54.57714119265157, 61.53654375383931, 60.0861140220396, 59.89146640223842, 52.52490612768358, 53.83242430225496, 50.76997103229646, 50.23300640044674, 50.0726402959516, 54.292781122269176, 55.30415250409035, 61.219780983463416, 60.86467704465313, 63.871346366020944, 54.990292287641964, 38.95577638379989, 11.721485507103706, 4.150344700582566, 5.806324770373683, 9.599560710691637, 3.3994706696079624, 1.397354057238948, 0.4020615126336775, 0.1206025406117401, 0.06185000897535394, 0.06712025722428676, 0.16842056906992392, 11.429925926270025, 40.933451114162324, 69.74270697562926, 92.448790150304, 58.31039820947955, 24.19067086712007, 24.269345768036384, 39.68223856341454, 54.02740924589096, 52.17309697981804, 54.78794897756269, 10.000468127189144, 0.04306595058991544, 0.06127381892574411, 0.11280156687022218, 0.013916876764156887, 0.049561594778131095, 0.02775959047158399, 0.026930070467173096, 0.1082105628184734, 0.03169803699899105, 0.03439181664537999, 0.08848765219051032, 0.09933028610483294, 0.04764419927772495, 0.048706479776169986, 0.0372346195452396, 0.02612921172722934, 0.026515153416943167, 0.031174839166323506, 0.02330586746064646, 0.04130744555544469, 0.05366272390669873, 0.08480873709965138, 0.002375237893448362, 0.1084999984971458, 0.05640880054523868, 0.1133941128970154, 0.02793841454530916, 0.060231560135200146, 0.04992295079113496, 0.08536313960869467, 0.05876544787878952, 0.04460797832918264, 0.01601878932917551, 0.0480103854750914, 0.10882840506852635, 0.042917946233384074, 0.05054644293962948, 0.0882565770899096, 0.04037495184269163, 0.05568860128762261, 0.08777503720334462, 0.028945739726505937, 0.020596756479672847, 0.017946086516002976, 0.052688846124276045, 0.09397639637632717, 0.027202204050075625, 0.3349642840123946, 16.920473421773604, 74.66388517810454, 68.66447094948062, 64.62339024389944, 49.21430803114369, 45.78377562184488, 26.395029175666075, 30.506455629102646, 35.67683573692076, 38.598213118891564, 41.15689677576865, 3.7881910368319485, 0.3419135595040937, 0.07818067461372384, 0.3175872954870424, 0.5701798140521973, 2.7337880672947055, 6.035007776752596, 10.487445092970326, 7.883090338399334, 5.672166472481144, 8.77739760183519, 21.288132629086896, 35.80959227777297, 48.75967394921088, 57.781195948200846, 55.60922268898257, 60.13398654999272, 66.90424457673105, 65.9331912379111, 64.21588736195719, 62.90068526421825, 64.8435018908593, 64.47582675564674, 63.073677478298066, 62.93907742346487, 59.672300046490086, 60.26074578685146, 58.695496512997536, 57.437392357857, 57.57528720363494, 61.61782310855005, 56.45569762875957, 56.47834147176435, 55.597718377267164, 56.913198963288345, 56.30975015701787, 59.50244572854812, 58.64166982712285, 60.70797051152876, 57.25550028585619, 60.09187990619291, 57.53375322588029, 63.73440857856505, 59.107533654859, 57.71158564475275, 51.178262310643355, 51.44703488196097, 48.73751255773729, 52.62455394191127, 50.128130066779356, 54.85194244692403, 57.622151682453776, 67.79874109452771, 43.71550198524229, 49.83411312103272, 67.32040020727342, 53.466502466509425, 51.82435904779742, 56.226462548778905, 62.281213575793856, 56.367157966859885, 62.708092966387355, 58.90149154970723, 51.99320531660511, 44.136093816449566, 48.30131361561437, 51.23766660690308, 60.419264454995435, 59.39133282630675, 60.20843705823345, 55.75318151904691, 59.76227529587285, 58.56582687747095, 45.36949096187469, 49.989270317939024, 61.846740476546756, 60.45330278335079, 56.305776796033314, 54.03653267891177, 61.54322747261294, 63.39072658169655, 62.292694353288226, 56.78829892989128, 54.805023054922785, 53.11224575965635, 52.466505958187966, 51.76843781625071, 56.17962160418111, 57.67038114609257, 64.13658880418348, 65.05932246485065, 66.98212715887254, 57.10953320226362, 37.471155351208104, 13.36046455367919, 4.228118927248063, 3.955433546535431, 6.81533488535112, 6.230847306789891, 6.581139968287561, 2.111298360170857, 0.23845312486012138, 0.0865733057200428, 0.07564021214362114, 0.11876881723442387, 11.8392115254556, 47.37747384655861, 78.52954572246921, 100.1589539743239, 69.72062403155913, 26.034531977868852, 28.36469638732172, 44.48898946085284, 60.84657922867806, 58.62919668997488, 64.50746851582682, 13.584668213321319, 0.07537688474140822, 0.07910052404528664, 0.0401171709170505, 0.008266734132062524, 0.024890506925481944, 0.06472434022373731, 0.0769614150387145, 0.046259185088978666, 0.048825338317622105, 0.05085251421757764, 0.05177438995170017, 0.054111938713298696, 0.031134870444093982, 0.0029657839519542555, 0.042052240065869786, 0.054745596848548427, 0.019860898384884484, 0.07274358007576197, 0.04777834127326647, 0.0035564995074133963, 0.02610552428861059, 0.041923062320077614, 0.05232348730186782, 0.02017934389802958, 0.02805659126850867, 0.253430848580695, 0.12737380791335337, 0.19023360504258066, 0.12063850077890581, 0.1972043156744011, 0.15925337710688192, 0.20784440360242323, 0.16630717763496985, 0.21020165614543423, 0.16121739671835977, 0.0911853235635546, 0.12167742325653955, 0.18672533603685518, 0.1646887709296519, 0.11409339029341937, 0.13244471242350916, 0.18791159254408654, 0.17388107525485177, 0.1973375383644335, 0.15290656848059547, 0.20119659903068698, 0.1316500953849285, 0.43969530612230306, 23.450574528786447, 86.51947652139972, 76.68698879980272, 74.89104532426404, 56.38645995047785, 52.49051086364254, 33.32965020210513, 40.570074896658625, 41.644808246243386, 57.745984831163966, 57.13170636084772, 4.828869142839986, 0.6059537299217717, 0.2170606864796531, 0.41284135032084684, 0.39533290110768815, 2.2865376020631483, 7.6153552339923, 15.522983920189644, 16.829254781046224, 21.10898425502162, 13.928750291947397, 30.074347719069454, 46.95594849125032, 51.96816490542505, 61.03462549947924, 58.129270999662346, 60.85422392814391, 69.79468622515279, 68.97566395421183, 67.17263667814194, 65.43348520032822, 67.63062830894225, 66.00881453483336, 66.74266645985266, 65.09980132502895, 61.259981355359486, 62.571884739783506, 59.43512608928066, 58.19001282415083, 57.66239912279191, 62.29851122825377, 57.83524228680519, 55.87162140877017, 56.33732049695907, 57.28383156561083, 57.769875987883545, 59.04928253542993, 61.139203733013524, 62.7025741915549, 59.272896858953665, 62.41723352862943, 58.72996630207185, 67.9104031285932, 63.74473617922876, 60.44685832915768, 54.41095429082071, 55.32880067825318, 50.67173919370098, 54.82927899206839, 53.260856520745065, 57.50393144546017, 61.49480973520587, 70.28212701120685, 46.30147357140818, 52.36662672412012, 71.00372545180782, 57.285290687314934, 53.656066694567286, 58.686514285302934, 64.57719649038008, 58.78122383548368, 64.76170870565599, 62.02146245587257, 55.846883020093365, 47.45108496758246, 51.35974253377607, 52.12143544227847, 64.20337107873732, 62.92782022107033, 61.745127554862734, 58.21590831202846, 63.758954771103404, 61.27716133671423, 48.67695116227674, 53.39885727051766, 64.20394766715266, 63.26571279956449, 56.757951551868075, 52.957708297237275, 64.63698910128686, 66.23740242373559, 65.38406725852721, 58.85794147368401, 58.880640229871204, 56.01643923790225, 54.98197686287665, 53.82010021517354, 59.20551838413362, 59.76884918828165, 67.30359677345523, 66.19635874225249, 69.68854688828992, 61.99085620141799, 45.41224087438276, 16.179872078280297, 10.958218747569669, 14.855558314631063, 19.023197235599643, 11.139504813378858, 7.595499215587494, 1.3215388093263873, 0.18162006482241616, 0.3389140188453659, 0.11696748405454621, 0.24570566391752613, 15.996571875387623, 56.25275027367377, 76.25535549656038, 97.59784237031015, 66.07615378595167, 35.718950225460915, 35.51983502603347, 53.79779369600358, 71.80330061143445, 68.21389259830599, 73.11389000185075, 18.516121064462972, 0.30513459756489725, 0.20426102733660131, 0.1577716558090141, 0.10404656085396007, 0.14180783903406513, 0.14132687371344338, 0.1429081557979507, 0.14826430548583308, 0.08331294276661451, 0.11702805096583983, 0.22217168803176573, 0.2546858844617682, 0.09462488214335135, 0.13226895653192075, 0.13359013644437637, 0.21713375594587098, 0.18588950346794822, 0.13381257773407046, 0.14758545965436967, 0.06783974402013325, 0.059524219663393114, 0.15952706967871036, 0.17442348082700085, 0.18058386961779288, 0.1534650772209129], [0.020772952871817737, 0.02544633818850402, 0.021276642275493474, 0.0155087873610037, 0.02560145375619252, 0.05090384593894405, 0.016072061168210163, 0.038059466413312384, 0.008338271422431836, 0.008695214768991837, 0.05125632682334512, 0.016545285170357076, 0.018784265229178053, 0.039868314915727225, 0.04265335861653571, 0.03851134720588884, 0.0237382015198349, 0.012525370937862225, 0.04920586568093108, 0.021585731939863295, 0.0397889367154529, 0.01967477923890035, 0.5018966200370942, 38.53170541024978, 65.61792681294104, 62.54729540117326, 53.12154962170509, 47.67215759523454, 24.67809400250835, 25.53256077151145, 49.55748404225996, 44.02374536760392, 58.90672006914693, 11.656962517769108, 0.49884804975121255, 0.1063254272805587, 0.07829181864977845, 0.024787037175208814, 0.42461707166606383, 1.2773693665381403, 4.190448974409412, 7.55854215352766, 4.203369752053292, 6.444597849922796, 14.734575748443605, 38.735131294496604, 53.401249916322776, 52.749081350141964, 48.46631203928302, 59.469113426823775, 69.44292022335914, 61.06896585033786, 61.412204619376894, 60.98623914103354, 58.49747565484817, 52.834479193533625, 54.69920535241404, 56.20131623360419, 58.352908857407115, 58.192562364762836, 62.968848213072754, 57.01159161906089, 59.43308645679105, 59.96650918837517, 60.0825015191109, 61.134524345397956, 60.13786577409314, 56.46575850825156, 57.01643182385353, 55.362599742028024, 56.114106255192915, 55.9033533834642, 57.66375234050136, 55.526084130810155, 56.433763734755985, 55.48682905012562, 59.7149165984123, 55.27989656694474, 51.69698399882163, 47.08013465327602, 48.3405843857796, 48.4111988159918, 53.343955855215754, 48.37246541054019, 52.97991283478276, 55.6833044944271, 63.87061680516889, 42.0452194829141, 48.147976398468025, 61.86751727134951, 49.51722091244113, 45.815574276831846, 52.86953733813379, 62.61377173085367, 53.25720871648481, 61.34275513310587, 56.01913390621063, 52.77971506118775, 43.45546060992826, 42.40505772252237, 43.751972183104485, 51.451624055062574, 56.13158825905093, 59.21938396269276, 54.40260748709402, 57.67901820521201, 53.1908029894675, 41.49618571804416, 47.43413248369771, 57.934646914082194, 58.76858988115865, 57.19835135244555, 52.648853025128766, 54.372954368591316, 59.44680298528364, 56.62042148651616, 54.589782991716945, 48.90313856063351, 48.072745338563, 49.38192659808744, 54.49491262435914, 55.68548533224291, 56.86098437155447, 57.5029783095083, 63.24824648518717, 65.70194398203205, 66.66339535867014, 51.70936692145563, 31.99432046182694, 8.898779269187681, 6.1640861149757145, 3.6796519448680267, 5.660646961581323, 5.283765042981794, 1.5372889032286983, 0.34082525499886085, 0.09144383993360305, 0.07822859341338759, 0.03960056335575158, 1.2924744140717292, 22.872050423775953, 35.31944897867019, 32.74966697539053, 22.638557610973237, 23.028647130535497, 32.378379337249264, 38.0787383356402, 44.62491919917446, 51.28335437467022, 53.845121014502745, 20.506661168990597, 0.133009732911183, 0.07767661940306425, 0.0276324677566487, 0.06114703137427569, 0.008947425277813548, 0.07221417501568794, 0.0719227628301709, 0.0270823419334427, 0.02617187707895233, 0.0267445124805935, 0.028801895227403413, 0.050801588522811095, 0.029372052334609534, 0.026973197386870464, 0.026282523157856157, 0.047078037319043954, 0.018623907704867663, 0.008567595054515669, 0.028656235099920345, 0.02524148436233161, 0.08985202414013686, 0.028674071542017406, 0.05347121341694748, 0.04606238093167063, 0.07819188248005607, 0.061918095039624366, 0.055029179615479325, 0.05850063043556387, 0.041774663428265246, 0.01853223187818883, 0.03478462439811519, 0.08458024371535548, 0.04441790808472903, 0.035785541253825354, 0.019890848592284228, 0.05669904827711083, 0.08369425537004586, 0.06155003958772268, 0.030665835027673075, 0.024239326444184108, 0.06754073224240734, 0.03619161381896946, 0.018546117221816413, 0.03649505741533734, 0.05216593748979992, 0.036598582706984975, 0.09583266572125497, 0.9471007724923473, 45.24198255231304, 74.56396672033495, 71.41678240991408, 60.305625546363096, 53.51745013267764, 32.39507490588773, 28.35540037001333, 40.072098624321725, 35.23083479173722, 54.35454276300246, 13.56847764984254, 0.5269696359192172, 0.05413169612086589, 0.07321876909343467, 0.16948556918050015, 1.9647728291250046, 4.270927185012448, 7.766473860509935, 9.205317401116895, 5.761915695282721, 10.015124063338003, 17.21269392198132, 36.825580289286954, 51.71707830121441, 54.15163463161838, 54.3947470572687, 59.76335394767023, 68.74149845492455, 63.36689033815938, 63.359833994219386, 62.501788062434045, 59.69999982464699, 55.775068344608435, 58.800592499394575, 59.623701880055094, 61.45873961910125, 60.45122784952964, 63.794240413173554, 58.10917669726957, 59.09536646258447, 61.01010284116192, 61.026098266724624, 62.166778426016535, 59.87294889265492, 55.87703035723779, 56.92517395942443, 56.010167367996715, 56.92700570629489, 56.360297741428504, 58.17014994159822, 56.4966550180989, 57.64018674050608, 57.06881899987498, 60.886179477937766, 57.69393497897733, 55.022290983507716, 49.5509885972546, 50.62937367346979, 50.9521572820602, 54.510696241932536, 49.86988513700424, 54.21054863160657, 56.20605445677235, 67.6621170966856, 42.703706987442516, 49.87139524952058, 63.68062503876225, 52.68880236533381, 48.442318900938965, 55.490210133214156, 64.58404102633077, 56.28945973611648, 60.53649625470562, 58.789005817905554, 55.51117127941501, 46.65405542619767, 44.26359830364105, 46.39089576659664, 52.65242238198557, 56.88127871482604, 59.683388586967226, 56.94109485995386, 59.846441515030406, 55.15239600212344, 44.29727185157038, 49.78723687510337, 60.54434099505025, 60.924940339980594, 57.03668694342337, 53.24774403725901, 55.44681302962765, 61.76513556511172, 60.3166199499561, 55.918940882528986, 51.50300710431991, 49.35924745375111, 51.28015764297978, 57.22232880130891, 57.375783689560436, 58.604983898901175, 59.733394884294086, 65.62766213570872, 67.66446267404865, 68.64270179502427, 54.29220845622402, 30.10978045002107, 8.000030902124221, 4.093724796848913, 7.033516726186199, 10.902007260630208, 7.3836372936925585, 4.3091516629342115, 1.8945342110049341, 0.04793013776502302, 0.1000580006849862, 0.07122200688407307, 1.3738872519423886, 26.40818088285385, 44.86570565931259, 50.07384838596467, 31.63402330490851, 30.038975784855506, 34.95298585584087, 43.25819284685197, 50.11270338489164, 57.2759436791943, 64.87382573466148, 27.365449051703177, 0.26565848519244506, 0.09567371013784602, 0.023210094978792534, 0.02041820819760042, 0.01290346597201161, 0.020463181389195305, 0.04934398367279961, 0.016462582148491375, 0.03512669031718566, 0.043527212129124714, 0.03707426968180845, 0.07439457616137882, 0.01187128219528184, 0.0144250899170255, 0.041738695600220276, 0.06690212134872714, 0.005969926405082187, 0.04515307286994592, 0.02934188762259099, 0.026068621833297997, 0.11925155221815072, 0.051570530124609514, 0.07261527567020348, 0.03141724087688471, 0.041535088582144636, 0.15834703380542417, 0.16317786168186896, 0.21924347015878848, 0.08409027686162342, 0.10944052464178494, 0.09475166969481977, 0.2736636749919384, 0.09555141952249313, 0.07951480907297905, 0.18800140869232917, 0.1451244481628941, 0.22450039613871808, 0.19090426905501276, 0.17381640211228402, 0.20402815192937854, 0.26100578808015396, 0.13836637289533693, 0.10732730940705347, 0.17546413466334346, 0.18677991214058093, 0.1471312154805468, 0.1500431310024954, 1.5048125362203968, 55.82165041277486, 81.35748832456528, 79.94148131339782, 69.84053873246717, 62.89101269937331, 36.69062722113825, 36.843854611919774, 66.29235482984974, 56.92968468512259, 71.63583109455725, 16.763745315613285, 0.8072731175249623, 0.21557659030922, 0.28995003010476794, 0.16350836733416205, 1.4217952038011243, 6.580637904905505, 15.40479604274996, 14.253276413486851, 12.842515572424858, 18.756072059754406, 19.085005944775, 42.17117855625768, 53.48565147769067, 54.119584944940385, 57.40007885040776, 62.02965236479237, 71.55452820562547, 67.8111122500512, 65.2946372185984, 66.83055108593356, 62.42627066950645, 58.33761945847542, 60.32774771413496, 61.302923464006, 64.93641107313096, 62.007447827246885, 65.92282833591585, 58.375015335698286, 61.18068671995594, 63.94433775255757, 64.11296829100579, 65.25830430369224, 61.76122888442009, 56.38118828496626, 56.62437131327968, 55.757150957661295, 57.25255458585678, 57.070619367784076, 57.94864585322719, 57.510226849586736, 59.1448942307503, 58.22730279737904, 63.03862325606808, 60.69852152178365, 56.97301118604599, 51.75217566951629, 54.32985928750808, 54.122793443741344, 58.7754971750321, 53.73929546725366, 56.82041921923238, 59.51328323733423, 68.40024440519272, 46.00552681953677, 53.13758819333969, 66.23676699976768, 54.66661437865227, 51.221851610368304, 58.99453409256474, 68.2531790579519, 57.33739545268398, 63.77343616177959, 61.95681002832229, 57.52639093706685, 48.6428108522969, 47.60107640297183, 49.38019683284145, 54.74459502004809, 59.42262549554149, 63.38204637650521, 60.31584724303215, 61.78640657855619, 59.28278515415808, 45.8836744677636, 51.71663115101477, 63.12944965977823, 63.38356041139173, 57.856215200116566, 53.55061769485474, 57.575071473275464, 64.03489351272583, 62.33663274395851, 59.44881516118204, 55.385969223514685, 52.25590998126615, 54.39304474861392, 60.82669281190442, 60.960151457017474, 62.20278186182823, 62.848505973815925, 68.5904715138097, 70.4239599166378, 71.32463808982604, 56.71013393709737, 37.49789022630261, 14.073656374408355, 16.126020877592026, 11.504787302786305, 14.77074686558016, 16.741256406230313, 4.4992787511118, 2.021386481581196, 0.10816405362059033, 0.17274610067327179, 0.30742599718993713, 1.9933979189203632, 33.2809422093053, 48.91163441442674, 41.23408902075983, 33.76875954289591, 35.21530612822502, 45.113611221313484, 51.31958138558173, 59.648283373925, 65.99500779182681, 71.46690245597594, 33.80605736086446, 0.5508102308357916, 0.2634845728114728, 0.0946953698932644, 0.12294126914874201, 0.12149275776239173, 0.17621977314833673, 0.15609225318316491, 0.10280377471879606, 0.11467599249895542, 0.16084314744559028, 0.1359001213624593, 0.1614670341293658, 0.060087336422575105, 0.1360192480346849, 0.14505324795121147, 0.136912981528909, 0.10745218173871118, 0.1339165511871538, 0.14685200707566354, 0.13489443177898086, 0.2172594862960039, 0.11584888077190808, 0.15385034283803356, 0.15749989377875484, 0.13979627600600644], [0.05235285911288473, 0.023963193882316835, 0.03252693264174365, 0.027325990452100674, 0.005820293632906772, 0.11404976924701084, 0.05413281460923534, 0.08023599658401744, 0.001193260106975363, 0.02806915702568668, 0.04123536051220952, 0.06175933863907572, 0.036133712893652345, 0.03832839008781218, 0.005447186309949405, 0.0703845655305251, 0.08971454200124548, 0.06102619249553931, 0.02052823183006577, 0.060469196778872324, 0.022344065139130242, 0.04599649353974289, 2.553186945376858, 45.658546109353345, 66.19028691322573, 67.9300542031565, 45.704112283645145, 29.54265671391641, 29.301619222087247, 47.94322867547312, 57.26403144098098, 53.598717720277854, 33.026274481127345, 2.184539552657835, 0.032755736291648886, 0.021048945622638832, 0.07382763279301506, 0.5374467156587109, 1.1616221839381804, 6.264461038574097, 7.68871630391767, 10.369111107241723, 5.969389955843649, 13.353035584572824, 46.48429916751, 56.82807960817891, 58.678665622588134, 50.06377966173234, 57.74933061292095, 63.99076292591711, 61.69325028696368, 61.31122712166079, 58.208538178474676, 52.05340193163965, 55.52078108633719, 50.853431224823005, 51.36791283084501, 52.14061583242109, 55.233004631534705, 55.45274365332819, 61.157097585739635, 58.20435693187099, 61.851521845786806, 56.94308350163122, 58.77997652176888, 56.23158516422395, 57.41464653322774, 59.484269465169604, 56.98518230069069, 54.47606563568116, 55.61720471228323, 55.550987259034194, 58.040527374513694, 55.43193940193423, 57.09839367097425, 56.826981344530665, 58.66538839955484, 54.789368875565074, 51.461943810985936, 46.41757180613857, 49.03654229256415, 48.5635240616337, 50.55750800717262, 47.38882518583729, 52.36760339429302, 56.29284866394536, 64.56708462007585, 42.43192988057291, 48.20340733374319, 61.741805307326786, 51.47283231058429, 48.04121732711793, 48.27546127380864, 60.13074667223039, 53.546369767958126, 59.5524912495767, 56.36085471799297, 54.56053387734198, 45.646939816013465, 43.74641026220014, 42.844586756921586, 46.40013687072262, 52.66395807266236, 56.89812137234596, 56.125912589411584, 57.2788344660113, 46.77161670500233, 42.15129213948404, 48.21964594625658, 55.3443685654671, 58.25590472067557, 54.42472181012554, 51.974503455623505, 57.11370268175679, 61.910251494376894, 59.20816598399993, 53.43269163562406, 45.99252808478571, 45.776499625175234, 53.02403165448097, 58.58822753352504, 61.007270889897505, 62.605613200895256, 64.56986950289819, 65.74154030892157, 63.32082210048553, 62.77784839753182, 61.89282048133112, 50.76468367730418, 26.069162584120228, 5.420873943836459, 2.553760592014559, 4.69094782106338, 5.616325649522967, 5.865758484409702, 1.2393801082526485, 0.14535269639905424, 0.03880494274199009, 0.09906886626155147, 0.05960911369672226, 8.230985941425446, 40.1609520758352, 26.120241649689216, 29.014860622344482, 21.969046285075528, 40.798866748809814, 44.95697529085221, 54.429475722774384, 52.304680731988725, 52.916342981400035, 35.69909126527848, 2.0988990126117586, 0.11837206029843901, 0.04774448784789251, 0.045543318058574395, 0.04203016524233165, 0.029707110464392655, 0.029790650437315627, 0.03137949764007523, 0.01984480096237554, 0.1051567907955858, 0.010303764795554022, 0.038501326775839256, 0.04345350297949007, 0.06714189154726845, 0.030875147485564795, 0.027260809776283083, 0.0682448206709758, 0.020707063564670183, 0.029831318214776057, 0.0912476065117986, 0.08446718445949017, 0.0345997137558316, 0.033697170250478296, 0.03419321984232914, 0.039730694881009485, 0.09422964206145656, 0.005948190096645586, 0.03808761631409007, 0.05737499446578084, 0.053964949423267, 0.06213979322403189, 0.04241262314720981, 0.06455800721361753, 0.020300222996381984, 0.03564416355783901, 0.02653023194251282, 0.024938358692452315, 0.07125341648896856, 0.019886142897209334, 0.044367055168315295, 0.09920086321090499, 0.11381436574963794, 0.09500555123292631, 0.049616875682747176, 0.04614840494468809, 0.0312198851362712, 0.055201120389204834, 3.661834823508417, 55.99972994096818, 74.61223540767547, 75.0555887529927, 53.26675576548423, 37.89933304632864, 32.76545647651919, 42.87103137662334, 57.99319613364435, 53.271356705696356, 36.89659480125674, 2.5200522330499466, 0.028786958428099755, 0.19582825322305003, 0.19620432578507932, 1.394960675989428, 4.242747406805716, 7.287368111072048, 5.557419494275124, 6.968365177031487, 7.192757110441885, 17.417639724669918, 43.06251364369547, 56.679206048288655, 58.19164060777234, 54.23953886955015, 59.088392488418094, 65.45405018714168, 64.51163799531999, 63.972567050687736, 60.318961604948974, 57.462417079556374, 56.87476758033999, 53.212717271620235, 54.60781412739908, 53.95402169996693, 58.95942103478217, 59.239042881996404, 63.78983951384022, 59.34202471087056, 62.4534801513918, 59.89558096854918, 61.63711724742767, 58.683462681308875, 58.79418334653301, 58.2226469439845, 57.87497981902092, 55.298202268538944, 56.04908120247626, 56.05872631072999, 57.97654959463305, 55.3478830091415, 57.8975530593626, 58.029136811533284, 60.17813674865231, 55.71122000294348, 52.26332326089182, 48.58656014165571, 51.245350530070645, 51.83016023328228, 53.636670574065185, 49.2483385147587, 53.59795678046442, 56.17389494372953, 67.35880805600074, 43.78105263556204, 48.74528277304865, 64.22772507513723, 53.084177278703265, 49.65289177433137, 50.6579795191365, 62.085251961984945, 54.869185186201534, 59.90628511674943, 60.03020455760341, 56.12311593947872, 48.1204217480075, 46.240955322019516, 44.955727977137414, 48.66473690156014, 55.3286555505568, 58.18927149618826, 58.77637970832087, 59.20672255177652, 49.38973211473035, 42.986639315082186, 49.273786852436686, 57.36107087904408, 60.46037089440131, 55.185187016764, 51.97638619330622, 57.99187821726645, 64.30194808590797, 61.414891442944935, 56.72476830021028, 48.70928718197731, 48.65203626694218, 53.47444526610836, 60.39124304248441, 64.22440282760128, 63.675161177112216, 66.65955143590128, 67.00423363716372, 64.65365525214904, 65.32137209369291, 64.00916668676561, 54.464965328093506, 26.91231135399111, 5.989053778110012, 3.4171907123058074, 7.511122659329446, 7.746040273097254, 9.287378288084462, 6.557474347852892, 1.394017223388918, 0.029573657947982994, 0.0896130123686406, 0.02574760609516694, 8.783309594277414, 42.34182127060429, 22.327617599118142, 28.425279355818226, 23.336043280939904, 41.27942377521146, 49.815211219172326, 58.66535702059346, 58.852971830675685, 60.791426781685125, 44.86052813068513, 2.811960659680828, 0.15251341215785474, 0.02854256871937504, 0.03622123843900139, 0.056866591706150965, 0.021129965166290923, 0.05845181531302872, 0.062228368309837204, 0.053765919780538934, 0.10116803910463087, 0.004420241617011808, 0.05182011773990047, 0.04597521161720638, 0.03188634907165843, 0.06086460540011045, 0.06119380104205301, 0.07304680533707142, 0.03582080428097998, 0.04029806342817122, 0.026004672643818685, 0.0906848076791052, 0.028421777721133926, 0.02019224290345465, 0.003597857003408154, 0.1028355673676537, 0.13150758770925383, 0.1541301181479808, 0.09838949949029954, 0.16397986380803972, 0.1180948130786419, 0.21843926169939581, 0.09588796194762954, 0.1662907220663563, 0.10811693155236783, 0.14179653157630276, 0.10182463008189395, 0.152021782893327, 0.10543119582918384, 0.15992227911708817, 0.10147413719565639, 0.19731127687038916, 0.1408332526203125, 0.15800713591517943, 0.11768654950203435, 0.13513055539900257, 0.11807846476233776, 0.150132977794255, 5.725356263499107, 67.1523972480528, 82.01919217263499, 83.7797401797387, 61.07010333768783, 42.42572076859013, 40.8048758199138, 58.92259782360446, 67.64106965834095, 67.93362356001332, 43.725586398955315, 3.267624854080139, 0.07666035780623075, 0.2749437772698941, 0.1601606243920903, 1.7244324160199014, 3.619908363588395, 13.434786604296777, 15.303291966838223, 23.719619704831032, 16.454227162945656, 18.825245018928282, 48.71957163656912, 59.45357691857123, 60.49896309452673, 55.15333737096479, 61.42522688834899, 66.17459743253647, 67.5039985102992, 65.24304236135175, 63.15585505577826, 58.18502749166181, 61.25161493978193, 55.35026388783609, 55.69132181905932, 57.57149427167831, 60.35000324249268, 60.896879703767844, 65.57086229324341, 60.48587414526171, 65.3653810870263, 61.59883883691604, 64.37881085180467, 62.36831765021048, 61.45635089566631, 62.229140189386186, 56.87578739658479, 54.146970933483495, 55.88007411649151, 57.528822806573686, 59.51057287954516, 56.62644232473066, 59.0330635347674, 59.205879242189475, 62.888796560225956, 60.01985734508884, 55.64802277472712, 51.10771063835391, 54.10175777250721, 54.3254780000256, 54.698338508605964, 52.70780624881868, 56.82812667662098, 60.64750325295233, 70.2903796780494, 48.00419015269126, 51.68561304769209, 65.44223208581248, 55.269015912086736, 53.42210908089915, 52.19543880031955, 67.28145107146233, 56.24683926182409, 63.11060659347042, 63.26756023591565, 57.990662282513036, 50.76116531125961, 48.469724501332934, 47.623704556495916, 50.859852144795084, 59.96585023018622, 59.80901033647599, 59.97750359196817, 61.974978446960456, 51.26069091981458, 45.96852710170131, 52.91681758819088, 58.701097657603604, 62.62005536786972, 56.9561920627471, 54.01426146107336, 59.75962377363636, 66.28704394063642, 64.76208133082237, 59.64249787792083, 51.50328951497232, 50.62433735016854, 56.67563669143185, 63.03218664661531, 67.02804242410969, 66.40361678215766, 69.22288310143256, 68.95443608683925, 67.97424362551781, 65.88743286748087, 65.7302713394165, 55.76038691305346, 31.317895958500525, 9.85808510934153, 9.595298074906873, 13.463331653225808, 15.525564839763028, 19.371389958166308, 5.056912312584539, 0.7997680912094732, 0.14260656230391996, 0.19164214962192122, 0.1869544422914905, 12.296463789478427, 56.235244735594726, 40.298337013490745, 40.249754536536436, 31.751513981050064, 51.98405050462293, 59.10389761770926, 67.9864735757151, 66.59924107213175, 67.73352776804279, 54.26355161974507, 4.331099285233406, 0.2578324373931654, 0.23020505454511414, 0.12900750573363998, 0.10039845015853645, 0.10669023068922182, 0.17517922656430354, 0.14346834993170154, 0.2181674537038611, 0.2308446613530959, 0.13360956443413613, 0.2119236839033904, 0.09977759718294106, 0.17871467636958246, 0.1635857115709974, 0.1588744546977743, 0.21315305583900024, 0.08264451573092131, 0.13858496842365112, 0.15001248748552415, 0.2189066825855163, 0.19126777777508383, 0.07584679541328261, 0.13079023829871608, 0.14080953453817677], [0.14605135326423954, 0.05509787855008918, 0.08524202876874516, 0.028069779472125155, 0.030771917137768, 0.03698841420813434, 0.03364148714970197, 0.039673050595146996, 0.049704412719415086, 0.09838716292213048, 0.04734000491519128, 0.07962370081053627, 0.028201810895435275, 0.06533055325909969, 0.08249374962742291, 0.007445906831567446, 0.07235919545975424, 0.013822376945867174, 0.07607756407871362, 0.011478695650434783, 0.012222238564713588, 0.0611984703479515, 23.396569375068914, 70.79116436742967, 64.99652139602169, 62.05421424681141, 56.7205713641259, 36.443968972852154, 25.90491725552467, 40.40832811786283, 57.661430297359345, 43.98850679397584, 11.352153170493342, 0.12302126404979538, 0.17383150936615083, 0.020081495317900856, 0.20180542442587115, 0.6338036000247925, 5.3376731180375625, 3.697233233721026, 3.5891358986977613, 9.85680151370264, 17.572787115650794, 46.595686635663434, 62.54787983432893, 60.30015776234289, 55.75026719800888, 60.58134463525588, 61.03355861479237, 62.71628679767732, 65.25426034004458, 55.87122524938276, 55.84634957774993, 53.450903200334125, 53.15031236217868, 50.00513238291587, 49.221305539531095, 47.74150509988108, 52.96550596913984, 56.122770770903564, 61.326700871990575, 59.20364741356143, 59.36876350833524, 54.51485395431519, 55.025377888833326, 54.43361382330618, 55.856418301982266, 57.86456592621342, 59.9394291447055, 56.3787171917577, 56.257300223073656, 57.99947977066041, 57.192656070955344, 56.94995157180294, 56.40413022810414, 57.1288626424728, 56.90735463173159, 53.727096896017756, 51.43424403282904, 45.00431437646189, 48.98561816061697, 50.09107543576149, 51.3834846404291, 49.355619261341715, 53.36808235414567, 54.39090313449983, 62.08551083841632, 40.94377479245586, 47.2747116704141, 62.65971445268201, 51.09374700054046, 45.777566509862105, 45.748721399614894, 58.78769182389783, 53.13823146204795, 57.001679789635446, 56.46080063235376, 58.62210504470333, 49.393199489962676, 46.41037033450219, 43.042713519065614, 44.21355278261247, 47.923985527407744, 49.980801920736994, 51.22246742248536, 48.08192368476622, 42.90248878540532, 42.64295731821368, 45.384384201418975, 55.91726995283558, 56.057965370916556, 56.58792857200869, 51.7245464940225, 55.278680632191325, 59.985913153617616, 59.30820211287468, 53.36452084202921, 45.69817381520426, 50.242110221616684, 54.934312220542665, 59.18561627787929, 63.252796434587054, 60.32556295394898, 59.138308571230986, 63.130136074558386, 61.66688411466537, 63.40220343682074, 66.87554067181003, 63.28006867439517, 52.86769774652297, 27.166743739958736, 12.32856152519103, 12.989504433447316, 4.548006355762482, 4.660525427710626, 2.892995846848334, 0.8477448684073264, 0.12889201031817546, 0.06717560707681602, 0.06873274973082928, 0.3617850835284879, 24.10861292193013, 56.68093189116448, 43.4619285983424, 35.328423361624445, 39.703897891506074, 35.392354073063025, 28.005544562493604, 49.40801035973334, 57.48959518248036, 52.294768902563284, 6.8164454064061575, 0.1565290152305557, 0.01856022473094204, 0.09892103427480306, 0.026196453179563248, 0.06937193519045269, 0.0428989089484657, 0.1052620972416574, 0.022548413347272624, 0.04258140380824766, 0.010612707945608325, 0.023514138038961158, 0.07284945342689753, 0.03759937698862726, 0.01277147381070761, 0.02943420504790641, 0.06468223603141886, 0.01797838478289064, 0.02396121354503257, 0.12716567714608487, 0.025369072475680904, 0.03921958400056728, 0.031031961853225386, 0.007510545021373659, 0.08339362714679972, 0.03688706460619166, 0.05431207152263773, 0.050724198320700284, 0.020766266839458578, 0.037279765106617443, 0.03451800281782785, 0.07598772494783325, 0.0983899744648126, 0.04919961440346895, 0.05642940831040183, 0.03848103693716469, 0.0548240902172702, 0.03134361408170193, 0.03900545476485164, 0.015870582916954114, 0.05013077512323376, 0.02493414137842915, 0.06628837000818984, 0.08005105529821689, 0.017634053158784108, 0.051689078400452296, 0.05886112843009253, 27.853252656998176, 80.19761208565005, 72.44005034046789, 68.86194659817603, 60.9997203273158, 41.48760357210713, 32.6090068586411, 40.471274314388154, 58.75292393469042, 47.04817125874181, 11.652650852357189, 0.1731848698710242, 0.04758041479714936, 0.13199809848541214, 0.5748575469178538, 2.143706943719618, 3.8541329435763823, 7.5956644454310025, 6.67097891530683, 9.225154788263383, 18.546256634496874, 44.738809139497825, 62.264688630257886, 62.93890876154747, 58.84174992961269, 61.70171476179554, 60.718968837491936, 62.636384194897076, 66.21178934651037, 59.44600282176849, 57.75405314660842, 55.77563316591325, 54.92051724464663, 51.89039607201853, 51.422472999941924, 50.339130047828924, 53.99959964136924, 57.60222604197841, 62.826599536403535, 60.01249113390523, 61.78299803887645, 57.95811837719333, 56.970834270600356, 56.57645171688449, 57.04843444208945, 60.027753076245716, 60.42745436391523, 56.127297186082416, 55.00216137978339, 56.44972778135731, 57.375426753874756, 57.21623736043131, 57.80823676816879, 55.80433314846408, 59.19791683073967, 57.519620926149436, 54.4326332307631, 47.315225831923954, 50.50070031996697, 52.45685692756407, 56.15865261323991, 51.70854714608962, 53.81944125698459, 54.78826276717648, 64.48994728826708, 42.10409425920056, 48.0589307508161, 65.2112280168841, 54.477093296666304, 49.02992133171328, 49.80334604940107, 61.86478337933941, 56.49019487442509, 57.19627249625422, 58.405594133561664, 59.94154330222838, 51.0054583703318, 47.30489823126024, 46.0796086249813, 47.3071575164795, 49.90307623340238, 53.489271825359715, 54.91141734584686, 52.16101215731714, 44.439473459797526, 44.38009269775883, 46.917089569953184, 58.92260174597464, 59.08524282516972, 57.09751506005564, 52.21604301083473, 56.92653109950405, 60.68248687251922, 59.86672016882128, 53.85761376350157, 47.33529267772552, 50.71341829915201, 57.64938077618999, 62.901006898572376, 63.11161464260471, 60.815655262239524, 59.55988099498134, 64.35257804009223, 63.1098731102482, 65.71670778336065, 67.4931884581043, 67.005582932503, 56.3146335078824, 29.10393568777269, 7.046863080993776, 1.121704467842656, 4.323988518407268, 7.798886856725139, 12.133880565243384, 5.4273973357292915, 1.076559458048113, 0.10406176003837779, 0.0537469782566111, 0.5687412847915004, 25.841771018120554, 51.42021371472267, 41.62025028659452, 30.75491032292766, 43.51925011604063, 45.657455690445445, 34.24036179819415, 55.64115470455539, 63.8133619677636, 63.18175838839624, 11.888828527542854, 0.006966923284644802, 0.06494194749862918, 0.059299920610482657, 0.04919242466829958, 0.12012659316702236, 0.007371002584770923, 0.009419125722601049, 0.020321638984305244, 0.06585582910526185, 0.02824050408127087, 0.027001171087425564, 0.04738067652309134, 0.013625718345264754, 0.05295089415965542, 0.0452426974962075, 0.018752014842785655, 0.011692010917730871, 0.024001030964897047, 0.17068150903909438, 0.03803953280552261, 0.08103655080401129, 0.005260780359798622, 0.07896277377562178, 0.02306373579607856, 0.17781246994291583, 0.13875913085235705, 0.17442142771136376, 0.13068395126010143, 0.18807715946628203, 0.2207196756236015, 0.18848536175585565, 0.21353827549084542, 0.12072458607895721, 0.2177263402770604, 0.13502449818676518, 0.19849362632920667, 0.11414193728518103, 0.22082712711586108, 0.13030038635817268, 0.14797947399558561, 0.2096372791716168, 0.1616183364944112, 0.16061843853564034, 0.10967487093782234, 0.07844617004476248, 0.1536269362775549, 35.02132923372331, 91.19194507598878, 80.20533131014916, 78.60469049023044, 70.40076301943871, 51.2895203405811, 36.26650133440572, 50.034679597423924, 65.36389843110116, 57.15501308441163, 15.480210473460538, 0.29653014314751475, 0.3392697287903678, 0.26207720800753564, 0.6521738981527667, 2.8637001543275775, 12.572275054070259, 12.44701220143226, 13.12270224094391, 22.242557079561298, 25.1338126197938, 52.67693327319238, 63.94566743604599, 65.53183863239904, 61.96915764962474, 60.507498172021684, 62.099764731622514, 65.56713604157972, 68.16184274611935, 61.23455655190253, 61.4363468077875, 59.44895636650824, 58.6179159533593, 54.87919115251111, 55.287043125398704, 52.225433165027255, 57.74079161305582, 60.82279005358296, 65.52526473999023, 62.00681240327897, 63.60216194583524, 59.10656482942643, 59.2966389656067, 58.029348619522594, 59.78369535938386, 63.90196830995622, 62.21945193506057, 57.62337153957736, 56.17047463693927, 59.83743575311477, 58.85068508886523, 57.81794855671545, 59.78764518614739, 58.04631287051786, 60.913298745309156, 59.25055111608198, 57.078091482962336, 50.22063916729343, 54.11941628302298, 56.64097862858927, 56.65505601513771, 55.190768549519206, 57.780164364845525, 58.246993095644065, 65.77889696244272, 45.20723819732667, 51.97786492686118, 68.3135364901635, 57.76944060479441, 50.42336294727941, 50.806707951330374, 65.10623793448171, 57.45013613854685, 58.21961887421147, 61.23344652114376, 63.816648913968, 55.56449197953748, 50.63771655482631, 49.84975553327992, 49.01228243304838, 52.026294431378766, 54.37936352145288, 58.67528453949959, 53.368356920057735, 47.426083780104115, 46.5129913053205, 49.04191201733005, 61.972468130050174, 60.59059750649237, 59.559645652771, 51.24056523846042, 58.02807777158676, 64.48075717495334, 63.95241783511255, 59.583160261954035, 50.65362568824522, 54.112112829762125, 61.59110000056606, 64.37853236352244, 67.9034605333882, 62.989350441963445, 59.574315317215465, 67.18012840517106, 64.81058536037322, 68.81825139445644, 71.78040181436847, 68.86514725223665, 58.524328201047844, 33.48937696026218, 18.979213737672378, 21.19013221033158, 11.781673296805351, 14.342399527949674, 9.986964387278404, 3.480671576915249, 0.4636115292387624, 0.19490304883689652, 0.10867582333664741, 0.6702772912479217, 33.46769802031979, 75.18777262779975, 57.64944353411275, 46.861195794997684, 48.19455846663445, 48.338364324262066, 41.09895160121303, 66.94078537725633, 70.38592861544701, 72.02155697730281, 16.304590702056885, 0.24223035201430324, 0.127753772202038, 0.19474066884046604, 0.07467432082780907, 0.24496854943854196, 0.06765901621791624, 0.1618530045473768, 0.26043391876643707, 0.1567671919662145, 0.1471690142587308, 0.19175851837761942, 0.15275768695339081, 0.07647501815470957, 0.09783708880985938, 0.18359093325993708, 0.13145350190179964, 0.1952252347743319, 0.11516657222302691, 0.282385187644151, 0.19504954016977744, 0.09140548191123432, 0.09806462458424992, 0.18813077029922318, 0.2064450980434495], [0.07779376190756598, 0.031145250935467984, 0.06099049279826784, 0.031889691130228104, 0.05508398937602198, 0.03458177580708458, 0.06544417942002898, 0.04785994878940044, 0.015431880751895088, 0.011744287800073866, 0.08478834383910702, 0.028495356635821444, 0.05906155235284279, 0.018982469412167708, 0.03783655014910525, 0.020378285440646356, 0.07093966517957949, 0.03010749482669898, 0.05224472963281217, 0.014462418508745972, 0.04186610751334698, 0.44081655240827994, 36.42412570215041, 61.61699941081386, 61.66664092771469, 53.74071928762621, 35.987103062291304, 29.964056553379184, 30.25653789120336, 41.354835264144405, 44.44500007937032, 33.96627833766322, 2.7138266351915177, 0.04373201807480186, 0.04045128867390656, 0.15399539392561684, 0.7977464158208141, 1.147460711579169, 4.45768250573066, 6.7938133305118935, 4.442841727887431, 14.066535311360514, 39.92531176536314, 62.04270601272584, 66.90931227899367, 60.72705676478725, 67.85397591129427, 62.95729683291528, 59.36675917717719, 60.966356646630075, 58.10400701338246, 57.53085851669312, 51.11903059867121, 51.34440998877249, 53.126350602796, 52.114206514050885, 49.12532121904435, 48.084798782102524, 47.30841659730481, 51.55672396382978, 55.8677343399294, 58.32248303198046, 56.88929603945825, 51.294109513682706, 46.845827948662546, 48.46771232543453, 55.882964903308505, 55.5763610716789, 58.14767868288102, 57.76942491531373, 55.71528750081217, 56.213961955039736, 55.327671035643554, 54.96871532932405, 58.828335423623365, 57.015674806410274, 56.04918318410074, 52.6386470179404, 51.04626670960457, 42.76443704482048, 47.50140897689327, 49.23892874871531, 52.927862982596125, 47.063668543292636, 52.73396845786802, 51.62683240828976, 65.39238268329252, 38.79870114787933, 43.56736190857426, 64.31044786207138, 51.111582017713985, 49.03851524476082, 42.93148686808925, 55.81160522276356, 55.00283602745303, 54.706857896620235, 56.02233456027124, 57.651816568067005, 51.45694671138641, 49.46358250033472, 44.61532508173297, 43.06900124396048, 42.699310010479344, 45.03756038604244, 43.63900399977162, 43.91216178094187, 42.17301422549833, 42.304197895911436, 45.063675526649725, 52.77575738968388, 55.657405084179295, 58.28355350802022, 53.9827020706669, 57.31416325415335, 58.541072799313454, 57.53300797554755, 53.372820577313824, 46.98489558312201, 46.1069671569332, 54.90247826422415, 58.769107634021395, 59.80992817109632, 60.68421663776521, 61.00882022611557, 59.452957184084006, 62.94990316514046, 61.06131722850185, 59.76396191504694, 62.55244155083934, 65.01000650467412, 54.730180309664824, 29.499169395815944, 6.78271645499814, 5.277282835975771, 6.7548308545543305, 15.102444060387151, 5.1434025360691935, 0.824292833285947, 0.06243299039441252, 0.16748626355922994, 0.07441942039276324, 4.308785411619372, 25.08441232865857, 42.722950135507894, 37.51703531511369, 45.567868755709746, 38.75756725188225, 44.41013805327877, 46.96767245569537, 45.31174190582768, 61.688735638895345, 31.298225272086363, 0.36724909839610903, 0.05477059046707807, 0.03990260884165764, 0.037891103270193266, 0.04537605425162662, 0.02537381839037182, 0.039797765878780235, 0.03640622952051702, 0.03729696378051754, 0.025589313177812486, 0.08423834633562835, 0.01207485856984051, 0.04833132651964984, 0.030941898641627164, 0.04391274587701886, 0.028992811999013348, 0.027451711226134535, 0.010401698602964322, 0.10927161757623959, 0.025465469319193114, 0.034494752049325936, 0.044727645093394865, 0.05868677447940554, 0.02247800795181144, 0.06547376573566469, 0.11950067635024748, 0.018617079946242513, 0.02789700174734237, 0.01438171593397255, 0.0665579869922611, 0.06798022922368781, 0.0004907512559457832, 0.04426886950949988, 0.043470448844375155, 0.07280794678316002, 0.016142568070321314, 0.03835114289916331, 0.0011567992295303774, 0.08228020261852972, 0.03219926534521003, 0.006392649412455579, 0.013845770398244984, 0.03704779751358494, 0.017250223956521482, 0.039780605509276354, 0.7428055316690476, 45.55105355478103, 71.63615272891137, 69.12343532808366, 61.43137716477918, 46.95569353718912, 38.790970156269694, 27.91688919067383, 35.250517245261904, 46.739751369722434, 33.05422921334544, 3.2161611510861308, 0.13991563250460934, 0.01958064235476477, 0.299689918756485, 1.0066650891976974, 5.13123877586857, 9.02508939466169, 5.917376385581109, 5.976763521471332, 14.767026497471718, 40.46537114727882, 59.655986908943426, 69.14005833287393, 63.12579401077763, 68.83698463439941, 65.20607010010751, 59.435008418175485, 63.21991520543253, 62.70812042297856, 59.903833635391734, 53.104149987620694, 53.44319182057535, 55.60895596781085, 53.31988819183842, 52.07044070766818, 51.0962494727104, 49.88764955151466, 54.1910622965905, 57.58014309790827, 61.35170205946892, 58.5674625058328, 53.80897637336485, 48.25572782947172, 50.27158683346164, 57.1327300994627, 57.3695118196549, 59.6376145270563, 60.2908185989626, 57.0495758518096, 55.36827933403754, 57.89411314072148, 55.903322004502826, 59.43773054307508, 58.79914514480099, 58.77696806384672, 54.40969128762522, 52.81764045838387, 45.027377913075114, 49.031537348224276, 52.8106507947368, 54.508021185475016, 50.70176493737006, 54.02212189089868, 55.31762976800242, 66.43704322076613, 40.3877592086792, 47.02658645568356, 66.55413381515011, 52.197356839333814, 51.10116420253631, 46.213447740001065, 59.91400041887837, 58.242501981796764, 54.92807565196868, 57.23224063073435, 60.340040422255, 54.04587184229205, 51.79137975938859, 46.45224555846184, 45.09337963596467, 44.576878009303925, 47.550909288467906, 44.38933380188481, 45.271408173345755, 43.985463034722116, 44.385062340767156, 46.259088439326135, 57.02448837218746, 58.17542552947999, 59.94035874643634, 53.62270693625174, 58.994545859675256, 60.92115133039413, 61.70755517098212, 55.45848992563064, 50.021037593964614, 47.23940641649308, 56.983664343434, 59.99880598437402, 62.7800331577178, 59.37787517424553, 61.60464002240089, 61.43783730845298, 65.41584237929314, 62.87251480164067, 62.932068147966945, 63.98169048370854, 68.4316155218309, 59.525595557305124, 30.555657840544182, 5.49799019290555, 4.1926116712631725, 5.511599836810943, 14.05689706725459, 8.962520726265447, 5.3400549773247015, 0.12068808198936525, 0.08534996289639704, 0.10843303475168445, 4.696151335393229, 29.319593483401885, 41.85662015791863, 32.444488925318566, 47.10269220413701, 40.17343698009368, 46.543354372824396, 55.044989739694905, 51.678729288039676, 71.54552244370984, 40.369794753289995, 1.1547287409344027, 0.027060033453087655, 0.032231824081991954, 0.04358977469946108, 0.04941648240351389, 0.021226882949591647, 0.0040423697059703695, 0.022030354049357197, 0.022142091803553126, 0.005181282458286132, 0.06125778470548892, 0.015680130586148273, 0.026520067870977427, 0.020871395170087778, 0.04139115981337044, 0.009581611056121127, 0.021646252885881453, 0.023119439964272806, 0.04332981425367537, 0.03891409111900195, 0.021825295294665044, 0.031051673295517123, 0.09204542579790277, 0.05590619324075599, 0.25074505157047705, 0.2944725229134483, 0.10338483708760432, 0.17135883801646773, 0.12101898600737895, 0.16296130394743336, 0.14060834452750223, 0.16282354601688925, 0.252613631948348, 0.1272126996228772, 0.15179054691426216, 0.20561724811071352, 0.14984465294307278, 0.23003959487522804, 0.16550791810356802, 0.1282248779710743, 0.24866535268243284, 0.09420807668638807, 0.17152659595012668, 0.15039188486914482, 0.23221565230238825, 1.7358759309976333, 54.725116529772365, 79.98899690566525, 78.63189604974563, 69.34243694428476, 53.401881417920514, 41.33635305589245, 43.06891102944651, 54.691403758141306, 55.06167942477811, 44.74138221433086, 3.9639757333263277, 0.38724105144220017, 0.15097378993466978, 0.4009336167045178, 2.1008177870704285, 6.1803698347460845, 14.167295117532055, 12.468847055589, 13.101404751500777, 19.315178471226847, 44.902972098319765, 63.194196224212654, 72.81510737634474, 65.95991826826527, 71.7707057153025, 63.88552965656404, 61.05300572610671, 64.23014909990373, 65.27580984177129, 60.75564692097326, 57.29872088278494, 55.49742337196104, 59.783032478824744, 55.737539106799716, 55.31147164683188, 54.24638340550085, 52.71221891526253, 56.397968184563425, 59.862935081604995, 63.14230718920308, 61.53187221096408, 56.64259856747043, 51.328304736844956, 52.740507048945275, 60.41189824381183, 61.31032497652116, 61.317530370527706, 60.663188811271425, 57.250628702102176, 55.6668266173332, 58.047458202608176, 56.15405167302778, 63.02020380573889, 61.308069613672075, 61.68588799815024, 57.03827550334316, 55.360952346555656, 46.94279286169237, 51.84930924446353, 55.500965272226644, 57.77452399653774, 52.34712077725319, 56.586320400238044, 58.637253238308816, 69.28269140182003, 43.95621392034715, 48.809523351730846, 70.70983009953653, 56.73893590127268, 54.132081616309385, 48.98362167419926, 61.028875304806625, 60.60666745708835, 56.83219417448967, 59.468823171431026, 63.41881859687067, 56.52363308014409, 54.81793549753005, 48.33899190348964, 47.53075222815237, 48.296324360755186, 48.969501141578924, 48.000252093038256, 48.97688696461339, 46.64386510849, 46.30996550283125, 48.993815914277114, 59.94787793005667, 60.973471826122655, 61.09333945858864, 54.24982332414197, 58.42422146950999, 64.0258877508102, 64.59405875975087, 59.044108929172644, 52.58972721715128, 49.70156838816982, 59.40562986558484, 63.542843941719305, 63.981663027117335, 63.38972637730261, 64.5365450459142, 63.98107074922132, 69.17982332168087, 65.66462655221262, 64.43979978561401, 68.04344992483816, 70.83792686462402, 61.41566414986888, 33.97877108666205, 11.25016370127278, 11.52964924612353, 18.34237575531006, 35.21560815072829, 9.009556808779317, 2.650538702164927, 0.20844999610656695, 0.2756751460894462, 0.1973262615501881, 6.371642745310261, 39.01097982160507, 57.86442864325739, 49.393591726979906, 52.8238848716982, 48.04643800181728, 58.75157071698097, 60.77596479846586, 60.12181151297785, 77.46757968779534, 46.98174199750347, 1.9685742186923183, 0.1774734147493878, 0.15204389219082173, 0.10871657155333989, 0.21666788255735753, 0.1918278646565253, 0.0950190956674276, 0.12836262824073916, 0.11226132932689883, 0.08818453418151026, 0.13426755735230061, 0.11373174316700428, 0.11927112576461608, 0.08068284034849176, 0.16355344394762672, 0.11952126879365214, 0.10939331830389078, 0.1290711369966307, 0.17899299611247357, 0.0753382049621113, 0.09411015532790654, 0.2280908817004773, 0.230628946315377, 0.11141677867741355], [0.06273212857664594, 0.07341436666226195, 0.045634620417390144, 0.026506456403782772, 0.03558319445038515, 0.082786709310547, 0.018704957892036727, 0.04215067470326059, 0.044947217383812514, 0.03166456278713961, 0.059689625707124515, 0.04133481787697923, 0.025161928046614896, 0.07049315849379187, 0.08438103021152558, 0.08072330511265224, 0.04630901910845311, 0.05319201650338308, 0.07239903203181683, 0.0581412585902839, 0.06522900064385707, 4.197485706498546, 46.22884304292741, 64.66487715321203, 57.128827341141246, 39.37013556880336, 26.4015285430416, 20.46393871307373, 39.09196499855288, 51.82850107069939, 52.6975884745198, 17.728920982730006, 0.10326846067102687, 0.02461509065582387, 0.1462184523622836, 0.10950001902998456, 1.0199794521735561, 2.8863719442198357, 2.6679366202123704, 4.414441806654777, 11.820861697196962, 39.11746824941328, 57.834359753516416, 65.91161820196336, 57.67191479282995, 61.07033083515783, 61.96831041766752, 64.22337124424597, 59.047690053139966, 60.00303822178995, 65.02102052011799, 56.25593916062386, 50.808025867708274, 50.2664642180166, 51.28317394564229, 51.70087499003257, 52.01082852578933, 48.303706261419485, 47.650980718674205, 49.14056747190414, 54.16507659419891, 54.99945886673466, 53.940320860955026, 49.456173143079205, 45.15277216511388, 46.68110801327614, 49.36350714775824, 55.91891734830795, 55.73660166032853, 56.952548180857015, 57.963723444169574, 54.18605342988045, 55.154827871630275, 53.83450708081646, 58.361824404808786, 55.99641946054275, 52.94055969484391, 50.75731746612057, 47.88480889412665, 41.67122148698376, 45.844282104123025, 48.69734748717278, 53.51845425944175, 50.10410554947392, 51.4928363984631, 52.49055793208461, 62.885466467949655, 39.38101622366136, 41.543277694332986, 62.00298024762062, 50.7295431629304, 47.57390614478819, 39.47845966585221, 50.71567366200109, 55.60667314837056, 55.86844036656042, 56.44826865965321, 60.3748240009431, 54.61494499637235, 52.499740200658, 44.415052783104684, 44.24852463506883, 43.181471286281464, 44.31386739976945, 42.98398387047553, 44.51670492849043, 43.653842326133486, 42.50559983714935, 43.13558740000571, 52.539866047520796, 56.82009758487825, 59.191099751380186, 51.63388482985958, 56.81810894320088, 56.37079400400962, 58.35131637511715, 52.587824867617705, 44.89326815451346, 46.595306165756725, 50.144607943873254, 58.95060746900497, 57.03634569721838, 59.44672453788019, 59.603411459153705, 62.253364747570416, 59.59915568751674, 60.000037608608125, 58.21291946595716, 61.21128512967018, 61.2801972512276, 65.38797393921884, 51.282773863884714, 21.785846102622248, 5.382543561920043, 4.193553040104528, 14.985159308679643, 11.232323781136545, 7.751076106102237, 0.33132824686265766, 0.1343985430655941, 0.01068517315997592, 0.09001762170584933, 12.267686340116686, 41.0053599265314, 43.45977913948798, 39.64322666968069, 44.58779004312331, 33.57408838887369, 29.0863654305858, 53.20863408427085, 52.20223626782818, 54.266826798838956, 7.80795390567472, 0.12141721383217843, 0.05679238076892592, 0.03507142090388844, 0.07695946151450758, 0.041063641903982054, 0.02203539490789896, 0.02998087198413428, 0.02435356164501319, 0.020799932573291085, 0.06635910290623866, 0.052195562109831846, 0.026723471875753135, 0.03166725941663308, 0.044602374396016525, 0.05529204353449806, 0.06020881115428864, 0.06304134847596288, 0.030707989015706608, 0.04037148146439464, 0.02502933163346062, 0.039022438934132944, 0.02641563476513951, 0.03839085689715801, 0.07074314830524307, 0.08128964327155583, 0.03937854341441586, 0.05327333290610583, 0.013728338695551841, 0.026671814567018903, 0.026498159671562816, 0.0259200927065385, 0.07389862616095813, 0.04355098766785476, 0.005190695284850775, 0.09590611057055574, 0.013558792904199613, 0.05976029348769977, 0.10489900986994467, 0.0785131644337408, 0.03867096162491268, 0.032743854267943295, 0.04449517954321158, 0.07067397056568055, 0.05604227343874593, 6.613097969562777, 55.94141606361636, 74.2910638932259, 62.50591047348515, 45.95902712114396, 34.401288801623934, 29.994064646382487, 35.17981260053573, 50.578382861229684, 56.28275248312182, 18.55492115020752, 0.13689804281438553, 0.10223409641654262, 0.16111657954752445, 0.23003991663215623, 2.7792245582226784, 6.6307432420792125, 7.287725537054001, 6.22013678473811, 12.214149909634745, 37.48139273735785, 59.798074768435576, 68.24015678897982, 63.126962877088985, 63.12524880132368, 64.87631251735073, 65.1906551853303, 59.1954614270118, 59.67033493903376, 64.99558787192068, 58.65483722379131, 51.61156262120893, 51.924724655766646, 53.57353610377158, 54.490013584013916, 53.68495887325656, 50.88013079858596, 49.902425119953776, 51.881060831008426, 55.818661566703554, 57.52535150897119, 56.20067296489593, 51.09178973782448, 46.61056026335686, 48.41290112464659, 51.8849322103685, 58.22595350203976, 57.52279804598901, 57.4801108914037, 58.794069597798014, 53.669441976854884, 55.45554030326105, 56.28321140043197, 58.69242529715262, 59.23418306535291, 56.17971966343542, 51.86185298427459, 50.29818834797029, 43.39632303484025, 48.262721415488954, 51.15411619986258, 55.959125564944365, 51.53777107115715, 54.179483459841826, 54.57886703552739, 66.5011739730835, 42.006450776130926, 44.246379098584576, 63.834028936201534, 53.562577001510135, 49.39334461765905, 42.74673931060299, 53.31536962139992, 58.5111568820092, 55.96607208251954, 57.3969566437506, 61.7155921074652, 56.213302996850786, 54.17356068088163, 46.355445384979255, 47.01727082652431, 44.72977592099098, 47.58982312294745, 46.090983498481016, 46.994623061149355, 45.22591652408723, 45.54233412588797, 45.17818127909015, 53.66693558231477, 59.6932533479506, 59.7304884079964, 53.31185517772552, 55.25280867853473, 59.35667476346416, 59.029078406672326, 54.046934804608746, 47.656068032787694, 47.05765554981847, 52.39060025061331, 61.85323592155211, 60.5440507396575, 62.15139489020071, 61.7839825537897, 62.91324861588017, 62.08680914294336, 62.520952763095984, 60.90550499577677, 65.38507138529133, 62.13012779912641, 67.80293018587174, 56.162763257180494, 26.763422104620165, 6.124460370309892, 6.771576433412491, 12.021267356411105, 12.682709386271815, 7.678403412142108, 1.2973130254014846, 0.2900419300121646, 0.03891425199746605, 0.06816974405439631, 13.620946215045068, 42.62074885829803, 38.19935121843892, 48.029438449490456, 49.910556193320986, 37.03532118951121, 36.68929361527966, 59.72920579295005, 59.6614743048145, 63.46750697781963, 12.552557299214026, 0.26621386829403143, 0.04369419631398013, 0.09213495849361343, 0.04017615202634085, 0.08268455914672344, 0.0067110403418360704, 0.034352236712772044, 0.059453911944142276, 0.044728158372304136, 0.04217091091578046, 0.03956039736588155, 0.015862402055532705, 0.044903370341466325, 0.05579168990915341, 0.07577530408818876, 0.03501783688402465, 0.060363806063129063, 0.01231488923827607, 0.028073715248836145, 0.04100261150949425, 0.017128620905080633, 0.08074823361370834, 0.027153492349410252, 0.1486614301440216, 0.1732106257470385, 0.14705803876201953, 0.13338510067232195, 0.17564525317040183, 0.15480516418333978, 0.09388848778701599, 0.1796404016955245, 0.15618377004659947, 0.12084617955429901, 0.2819888750391622, 0.16068717194420679, 0.18347315490245822, 0.23852948850441366, 0.16278550209056947, 0.11737682015424776, 0.223205232572171, 0.12254463478682504, 0.1428947186157588, 0.15319311600779334, 0.1255720380633589, 10.216175933038036, 69.32065210034771, 80.84133578884988, 72.6718702623921, 55.07077540120771, 40.12314827211442, 30.68374283852116, 53.21963241023403, 63.63586295035578, 66.38773902770012, 23.87077804534666, 0.3612082499650217, 0.24031222106948977, 0.42832980953877975, 0.3911716953640984, 3.7423042087785663, 10.40670604475083, 6.992625526843533, 14.810077451890516, 16.332725863302908, 42.44383819641606, 61.35478896479453, 72.2301015546245, 64.1589855378674, 64.13907950924289, 67.60245784636467, 67.43891069965979, 60.21932948020197, 60.70305970407302, 68.6102088805168, 62.74071139674034, 54.97605016154628, 56.874387110433275, 55.97789802858907, 57.07136069574664, 56.39741120799896, 53.17903195658038, 52.840178397394, 55.722316388160955, 58.00345313164496, 59.63783025741578, 58.46099368987545, 54.08697043695758, 49.70770689748949, 51.21343028160834, 53.75937800253592, 62.589033342176876, 61.56645967114357, 60.71679584441647, 59.41772645519626, 54.2147377229506, 56.68722337292087, 57.28625559037732, 61.425109217243815, 62.235023744644664, 56.70075555001536, 54.484565411844564, 53.288775951631614, 45.77639372118058, 50.64987590236049, 55.02301662198959, 58.11187921031829, 54.79176544374036, 56.91175160869476, 57.016745613467315, 68.60374481447282, 46.02214590195687, 47.28174840250323, 66.42687643727949, 58.1121616209707, 51.49036530525454, 43.757655697484175, 54.6498344790551, 61.39076494401502, 58.74635396465179, 60.66539710567844, 65.0905131524609, 60.350979912665586, 57.79617940225909, 48.984225719205796, 50.01097279210245, 48.35259468324723, 49.752508209597686, 46.70927063111336, 48.72820085094821, 48.47677300053258, 48.0501603311108, 48.285114226802705, 57.44808866131691, 62.4280906492664, 63.39724948329311, 53.19560789292859, 57.419749536821925, 59.74547970679499, 64.2192017647528, 56.16899590338431, 49.991980675728094, 49.419428379304954, 56.17975496476697, 65.07293701171875, 62.91840261028659, 63.91545734097881, 64.19751105769988, 68.72232590952228, 66.20058705729824, 65.13077235990956, 65.4262915734322, 67.80198881703039, 67.2291031191426, 70.79869531816053, 57.89227354911066, 26.193599777836955, 9.54512703803278, 10.998694665970342, 26.83043972138436, 23.310336066830544, 13.273263400600804, 0.9723255350705117, 0.2227337820635688, 0.11352506030591265, 0.1894042229339961, 18.379508833731375, 57.514400251450084, 55.49223799859324, 45.0256363807186, 54.89527679258778, 48.29193130616219, 43.632736052236254, 69.47747630457725, 66.61277324922624, 74.49391318905738, 14.769633893043766, 0.39233391203226586, 0.23334799154150873, 0.12484296750757964, 0.1794405599995967, 0.23622693463919625, 0.1499861493826874, 0.18447083120624866, 0.19058516279103296, 0.10065434650788385, 0.1606454967611259, 0.1617533518301864, 0.11930497152911079, 0.1024731847968313, 0.0832889948581015, 0.126742038184837, 0.09592775255441667, 0.13333081568200744, 0.055506835436268206, 0.15597263621466775, 0.10118139201715108, 0.12304465271412365, 0.2137644399678515, 0.09257146773198921], [0.03528380345913672, 0.035690657433963595, 0.0523487375598521, 0.06727738185755669, 0.04903368358950942, 0.017522901461850253, 0.04469989355833781, 0.0776110882420213, 0.09081773925572635, 0.058709354920973705, 0.0399514431163909, 0.02220935815374457, 0.010684607212521858, 0.0629178780852066, 0.015694653697972818, 0.09122782612159368, 0.004928781793663098, 0.08406167113853079, 0.05740494467318059, 0.023324215266432975, 0.03913558629010955, 7.369390264634164, 52.73176016346101, 58.52058233753328, 58.485465357380534, 54.411789755667414, 24.613869113306848, 19.454930559281383, 38.61486750264322, 39.82744862956386, 37.27617432994228, 5.264573866321195, 0.0493176915352383, 0.03276620105269455, 0.017552445642650127, 0.6646661568553217, 1.0646670768337867, 6.746771854739036, 11.741872026074319, 6.7025995927472275, 29.84483415080655, 50.41221949361986, 64.54239329984112, 62.44561972156648, 60.54251709292012, 61.17875299146099, 61.85916262288248, 62.933507657820186, 60.511024382806596, 59.62531005182574, 60.47469931264078, 57.22668655457036, 48.413226681370894, 45.89404129212903, 50.73760363363451, 52.804382847201445, 54.51063740637995, 47.654083313480506, 46.18432414147162, 46.68602274310204, 49.58655664997716, 50.42810509281774, 47.72650987871232, 43.89360897002682, 45.41619854588663, 46.47916478495444, 51.15063313514956, 52.2929959912454, 54.485224370033514, 54.465310496668664, 57.96033843871086, 54.565095593852384, 54.83683347702027, 56.24702753559236, 58.79207703375048, 54.59949085789343, 50.93996655556464, 48.31264534304219, 46.368569635575824, 42.573139129146455, 44.47307248269358, 44.50876605126166, 51.8147845422068, 46.049979040699625, 53.912205311559866, 50.41685965753371, 64.12934026410504, 39.923413338199744, 42.72826102472121, 62.37102408562938, 51.593900188323, 51.65752887725831, 39.699598973797215, 46.62663413632301, 54.07894134521485, 56.624045756555375, 53.855597665233, 56.497498327685946, 53.99695988624327, 53.35888439609159, 49.71122526353406, 48.50291559773107, 44.8867727095081, 45.47832496704594, 48.416450869652536, 48.79852894813784, 46.60906584032121, 46.90988417594664, 44.87604502708682, 49.25434366349251, 54.59162258332776, 58.081622046809045, 54.690030928580995, 54.44870318135908, 58.07932746025824, 56.83666959885628, 54.34493687845046, 45.41739094641901, 42.40412812079153, 44.38070458750571, 51.85096056230607, 58.259172055029104, 60.30915175714801, 58.47590261890043, 55.12532772556428, 54.53286155577629, 51.50745114972515, 53.3939778420233, 56.03743960780483, 60.615908561214326, 61.10575768255419, 64.90207072227233, 43.32919559171123, 16.921656016380556, 2.985041372237667, 6.624278195442693, 9.48402435548844, 12.98087521906822, 2.46370199226564, 0.05730162239483288, 0.11860591629820487, 0.05471113821371429, 0.711416335355851, 24.454103131448072, 39.35561495442545, 13.922163651835534, 31.906708440473004, 32.646583164891894, 27.62900487069161, 42.18349479859875, 50.715446164531095, 54.96246699363955, 32.75344225668138, 0.39683804937428047, 0.054696222481828545, 0.03079740105256919, 0.06715622505233174, 0.004541097253921532, 0.045879630657333526, 0.042535660698288874, 0.07125992823632495, 0.011212565324028895, 0.02628141041514614, 0.05425264225191167, 0.058111936574982065, 0.03018146253100807, 0.05088531044161609, 0.02135032652727058, 0.03753174674667178, 0.031493208070676175, 0.020946810780573758, 0.026849139023632295, 0.02099737449879608, 0.04796373455094234, 0.02347953767786103, 0.008289741667648478, 0.034091973662256234, 0.014792519092049091, 0.09681008666032746, 0.08401621914198322, 0.029208343175630418, 0.0339775316176876, 0.04113626320876422, 0.041075646501755526, 0.07266998966975559, 0.08183481442111154, 0.05333073970471179, 0.040965624784509984, 0.022865809319961457, 0.049580896363383344, 0.026144389844229145, 0.0702733142421611, 0.07520954049522839, 0.053411535167646025, 0.045028074133780696, 0.016393856400804176, 0.06262521334593335, 11.208738569290409, 64.37217420147311, 65.13562825418288, 64.51773335856777, 60.77792206118184, 27.925432112909135, 21.40419360130064, 40.39000672678794, 44.03207648184992, 41.92667761156636, 5.296990784906573, 0.1127256858613222, 0.008993040068045018, 0.05782805503376069, 2.3829700533420812, 4.918157977442588, 6.5804422766931605, 7.7993124338888355, 9.905092754671651, 31.615448920957505, 53.36264202671667, 66.56360241674608, 63.6123130398412, 63.904557074269945, 61.35328277464836, 63.49864275224748, 64.86861290470247, 62.22695542920021, 59.42446116478213, 63.34888665906845, 61.28129551487585, 50.170597568635024, 48.99139973425096, 54.684112071990974, 54.87566886409637, 55.82269768561087, 50.478629143007346, 49.23900327374859, 49.48096252256825, 50.647855881721746, 52.49395470465384, 50.71082953483828, 47.70768642425538, 46.6411155269992, 47.98238569690336, 51.06127762025403, 55.49631334120228, 56.72872204934397, 55.36203099835304, 60.09686916105209, 55.35046785108505, 55.31183250488774, 57.49135240431755, 60.61277458744665, 55.897156038591945, 53.575077595249304, 49.541743570758456, 47.01784349256947, 44.03328849423317, 45.94966442354264, 46.70118270381805, 55.138836368437744, 48.50849320811611, 56.207756765427135, 53.15086541637298, 66.4354193595148, 42.02998891953499, 45.76705848017047, 64.73139662896433, 54.63832232259936, 53.18586864779073, 43.03624945302164, 47.303192000235285, 56.948037455158854, 60.38908966125981, 55.956379905823745, 57.6372802642084, 57.03893446153211, 56.05827523816017, 51.27905545696136, 49.71023290388046, 47.3016308969067, 48.48809688322006, 49.85773755658058, 50.333407309747514, 48.773606208062944, 47.83189612050211, 46.31223655516102, 51.07779472104965, 57.7967167669727, 59.92350824417607, 55.254683571477095, 53.31949595482119, 59.562834539721095, 60.852043090328095, 56.9925485118743, 47.436615344016786, 45.3618384176685, 46.802791703131895, 53.58357344904254, 59.951827756820194, 63.37222083922356, 61.83302787042434, 56.97668252452728, 55.78415255392752, 54.451935214381066, 55.092968171642674, 59.83573344445998, 61.63901959696124, 65.01652940627068, 64.18327285397437, 46.117404583961736, 15.881990617321385, 5.330406927293347, 6.470666902680551, 9.389189289462182, 8.724897657671283, 4.605077822362223, 0.9781797338397273, 0.059297779394734296, 0.06267068832511864, 1.0718057905474017, 26.848280622113137, 38.954097609366144, 16.61881962130147, 33.4351227360387, 40.055377560277144, 36.73261619383289, 50.18105068514424, 56.50633935005435, 62.72928553242838, 42.427983976179554, 1.2139090943721034, 0.044958088171458056, 0.03676409217258615, 0.07301074557847555, 0.07019747153765733, 0.0181123026977143, 0.05371391007135953, 0.03199936619268791, 0.07400705824576079, 0.05183976023427902, 0.027571839558321144, 0.01437260619094295, 0.03522857618067534, 0.019510930268875053, 0.06851372519327749, 0.03938386006461036, 0.041919323811007124, 0.044276403984235185, 0.03220889890085786, 0.026554989989005753, 0.054141306693875985, 0.019432546067682487, 0.02504763347397168, 0.08374750614166261, 0.10066347061506203, 0.22111935901545712, 0.24488861582452254, 0.1323897532758213, 0.1695055027882899, 0.13946903388827078, 0.13281416598587267, 0.17380725502246813, 0.1461981050670147, 0.10596696707990863, 0.14125765000860538, 0.1665325453805347, 0.12578545483730494, 0.09178631187927339, 0.1796094210998666, 0.15238254901862916, 0.29368639412906866, 0.1394366590125907, 0.12679194881310388, 0.19577894780424335, 16.481083631515503, 75.3822123619818, 72.71285903069281, 74.3460790572628, 69.79450579612487, 35.23524745818108, 28.30006749399247, 53.04162740707398, 50.4295995158534, 50.25071590177475, 7.400047019604714, 0.14965302370969327, 0.10846733250805449, 0.20952536904763794, 1.9211760523819157, 5.274309679385155, 16.19162742168673, 21.294035796196233, 12.66367510441811, 34.22062443148705, 53.69899311373311, 66.81998422068935, 67.04835245686193, 66.84598169019146, 65.98555487971153, 66.29513971267208, 67.896831727797, 63.864607734064904, 60.849595531340576, 65.56198596954346, 62.278667957552024, 52.45253447563418, 51.89912726802211, 56.55051308293497, 58.0728869284353, 60.33143081972676, 53.96908752379879, 52.33064290015928, 51.950863330594956, 54.31931987885506, 55.88702455643685, 51.824586545267415, 49.81793726644209, 49.86391528960198, 50.87732238154258, 55.21237296442832, 57.962028980255134, 59.96739956640429, 58.61137343991188, 61.397330991683475, 55.42425155639649, 57.495878819496404, 59.67733244742117, 63.05195539228378, 59.811481429684555, 55.02449927791473, 52.583439657765055, 50.447465911988296, 46.905730385934156, 48.461146277766076, 48.63641738891602, 57.92864961008872, 50.844005769298924, 58.334728671658425, 56.460631970436346, 67.69780282051333, 45.44616153163295, 48.07673046665807, 67.87041064231627, 57.20569010703795, 56.726309791688, 44.315573630794404, 51.6111703841917, 59.31246572925199, 62.18680212574621, 57.3422238903661, 60.2351797780683, 59.14119151330764, 57.574161483395486, 54.442113599469586, 51.841825362174745, 49.46737935466152, 49.71374734755486, 53.150783046599365, 54.10794727263912, 51.32866559490081, 51.258117844981534, 49.880318641662605, 54.83727670484974, 60.73195580513247, 61.22133816442182, 56.49740026843164, 55.482710561444684, 61.00831816273352, 61.617952546765736, 60.55096980064147, 49.35842375601492, 46.68709747252926, 50.388293035568736, 57.92544111128777, 62.62867673750847, 66.05686356944423, 64.68408107757568, 58.75077447583599, 60.221620144382605, 56.340842785373816, 58.05339274867889, 62.03626940327307, 66.1035240850141, 65.97043806506743, 68.10264633547875, 47.73340932784542, 21.492184131376206, 8.197876234208385, 13.436671303164575, 20.874583413524014, 23.89504574960278, 8.480396712979964, 0.6518509154838901, 0.27295194866676487, 0.15353074627778224, 1.6024201050881417, 34.62325965204547, 52.93397011295442, 21.171136171587055, 42.57098967029203, 43.89565252488659, 40.40901061027281, 57.487551627620576, 65.20976105043965, 70.12270619792324, 50.37754966366676, 2.069610674535075, 0.18203851736841664, 0.18327031014186723, 0.12675568221076844, 0.14579071483064085, 0.1721949923423029, 0.22805378772318366, 0.16303307106417997, 0.10047554158635678, 0.27334317444793643, 0.12631696663917075, 0.18761323194109625, 0.11291170733109598, 0.16748036468221297, 0.14291126611492327, 0.18744277737794385, 0.08737526954181733, 0.14583300288406112, 0.05699763104559914, 0.12531477041662703, 0.14305662363767624, 0.15639850449177528, 0.15309879526255593], [0.03920615447925464, 0.0915280023529645, 0.0147061484242459, 0.030637993477284912, 0.06200750899170676, 0.09144997629787653, 0.0512556258528944, 0.022745489465793776, 0.11245765467925418, 0.004509517673267833, 0.05973683204501868, 0.011895466633441468, 0.02384278018237843, 0.0617980643836481, 0.06118337075496393, 0.036417893209164186, 0.05026805041838558, 0.026771199153435808, 0.06191421097384826, 0.10298336105000588, 0.0464120694255877, 36.809020042419434, 62.839362928944254, 62.658996658940474, 52.58003111808531, 40.43023847764538, 30.956141641063077, 31.116735243028213, 39.40502112911594, 54.98293784356887, 29.564361149264922, 0.6789462809120456, 0.04051470160183888, 0.0539983278741279, 0.3004312773625697, 1.2852001334390333, 4.4867036323393545, 4.3819954702931065, 8.49930057602544, 22.685777064292665, 46.174369165974284, 66.62579551819833, 67.31812523257348, 59.82777103301018, 60.7696811614498, 54.40544728309878, 57.69374278283889, 62.15624686210387, 61.71039888935705, 57.12348507296655, 60.37630665686823, 57.94910869290752, 49.921593742985884, 45.18621821557322, 51.37794625374579, 51.692536031046224, 53.24238215723346, 52.001760005950935, 47.346800911811094, 42.82507688768449, 44.6465196917134, 43.95423704578031, 44.9235253180227, 43.51324104493664, 47.98300935376076, 48.480652224633005, 48.72404313856556, 49.49998601790398, 53.523039510173184, 52.40430893436555, 57.525076943059126, 52.85634248487411, 54.09073198995283, 55.762501070576334, 57.47138754014046, 51.14700886511034, 50.37609446433283, 42.673885207022394, 42.90223383134411, 41.332387539648245, 44.126754653069284, 43.89789612062516, 49.21803820517756, 47.170921833284446, 56.02842207877867, 51.88499496829126, 65.02231097990467, 38.711922630187004, 39.57272206583331, 61.317922607544936, 50.3900541797761, 49.63214243611982, 41.835125569374334, 43.04627895355225, 48.76437687104749, 59.19508880184543, 52.450498765514745, 57.20905157827563, 55.439027124835604, 54.90505918379753, 51.770085211723085, 49.673068446497766, 51.68615825714604, 50.935961815618704, 50.11530391631588, 52.030216801551084, 50.83601982362809, 48.57092165177869, 45.933794513825454, 50.271614290052845, 54.5290490119688, 57.5150631320092, 55.562773981402, 51.483532536414366, 57.08324155499859, 55.64952896487329, 54.870075564230646, 48.85574063947124, 46.66083720422561, 42.517978837413175, 41.44088422098468, 45.438579590089866, 50.93780532959969, 50.20225109592561, 50.34537053877308, 49.79734482303743, 49.44266450020575, 49.075436515192834, 52.55784227002052, 56.64785062113116, 63.33937491140058, 61.62345170974732, 56.469727946865945, 23.199580100274858, 9.764416948441538, 7.777214290634279, 9.706851263200084, 5.298339099653306, 4.22474225682597, 0.6831985591880737, 0.05478621483029378, 0.019654826478912465, 0.016441026349521933, 7.225895254842698, 40.43421576100011, 48.681269691836455, 34.7625587063451, 16.56716004494698, 14.96094455642085, 34.859880555060606, 46.023914890904585, 50.4751068545926, 53.75807577563871, 10.60315893542382, 0.19367150121158172, 0.03464446095148883, 0.03232573113975025, 0.10647208715278296, 0.08409203120297001, 0.035472919924124595, 0.039126301304467266, 0.026225803923162243, 0.053320267282786875, 0.03882703671772634, 0.038750830121458545, 0.07459737495669434, 0.04507181009337787, 0.021642138993728067, 0.016017820227951292, 0.01758587771966573, 0.06368865063714405, 0.012807131373143245, 0.04216994181455624, 0.026618592523699327, 0.09015842866633209, 0.016673133753600623, 0.043674730019824165, 0.056930977565747116, 0.03548150776975578, 0.022789853617488857, 0.0022946566957304437, 0.08684805549320676, 0.009428733422781431, 0.047790365023238045, 0.07592053137599461, 0.04360799993117971, 0.05402672292304136, 0.03631107756988176, 0.03977913462046174, 0.10554230922172148, 0.0293635449282104, 0.05351556224688407, 0.056403717551861084, 0.003981315131832456, 0.040364820329893025, 0.06159490935744778, 0.21339034391266687, 44.339939394304835, 72.7260381944718, 69.28194615148729, 59.6252590610135, 48.809758693941184, 36.19321969247634, 23.96652702362307, 42.32439025755852, 56.24266978233092, 30.005821950974006, 0.5466358483799043, 0.01348620990381366, 0.12849662467957507, 0.6495756956358111, 4.47655204803713, 7.752015513758506, 9.314044521700952, 8.50648537758858, 19.979739765967093, 45.79022792077834, 66.57087449104556, 69.23756845535772, 63.569939674869666, 62.48521604845601, 57.1813557224889, 60.466921252589074, 63.361846170117786, 63.08083188149237, 57.57086669245074, 62.444662663244436, 60.41889967456941, 52.70945364429105, 46.29847295822636, 54.83986939153364, 54.05740753296883, 54.51492063460812, 54.859308658107636, 49.59106737567533, 46.4252321950851, 46.218425227749734, 45.945294903170684, 47.78075625819545, 45.657141900831654, 49.38973995947069, 51.90983141622236, 52.02667490128548, 51.68429905368436, 54.395637435297814, 55.27663707733155, 60.51460158440375, 54.728183823247115, 55.87832081702448, 57.52586533946376, 58.80129460365542, 53.07725429534913, 51.62909169350901, 45.53782732255998, 45.696020433979655, 43.84602277509628, 47.362706122859834, 46.12995616851315, 49.424170524843284, 49.455796595542665, 57.41553298888668, 54.5025965475267, 66.51503562927246, 41.45565586705362, 41.700094053822184, 63.84313667974165, 53.92500008306196, 53.083537932365175, 43.66409932413409, 44.837919589011904, 51.66399294330228, 60.158956358509684, 54.441380116247366, 58.989850782579, 57.51735379618984, 58.42009905845889, 53.92413716162405, 53.0924181784353, 52.73809086891913, 53.4811838980644, 51.619493653697354, 54.93142535609584, 51.95881005256407, 50.39755767391574, 46.49061418348744, 53.56513438686248, 56.80815396770355, 60.68032956892445, 56.94058887420162, 53.08798982251076, 58.69601818823046, 58.452944986281864, 56.46704504566809, 51.88586573446951, 48.864134511639996, 45.58663729698428, 44.87290713094896, 47.69279318471109, 53.40183434947845, 52.3511568961605, 50.379095077514656, 52.451389143543864, 51.24546427880564, 51.1451300497978, 54.41346068536082, 59.171703630878085, 65.87071572580646, 65.44286358741023, 58.25635579324538, 29.248169083749097, 9.396389780506011, 6.0653639801086925, 10.456480922237521, 7.973880950481662, 11.111799151666704, 2.851148814924302, 0.3147359162328705, 0.024193707823513017, 0.01617609590832745, 7.933697248658827, 41.85604356950329, 41.41503187917894, 39.53129791444348, 25.41446408917827, 24.330297439329087, 39.619355124811975, 53.03569286100326, 57.147854758847146, 62.40398768455752, 15.018198413233604, 0.16971056920386132, 0.03225818133702682, 0.0704230078225655, 0.06288548022688878, 0.0583145400178769, 0.0759260242264117, 0.03503414689593258, 0.05055541382922281, 0.045289463333545193, 0.08043249813659538, 0.02904203314814837, 0.026101435294314742, 0.04442651891299794, 0.026992023997609655, 0.05050052745988773, 0.03221992290608826, 0.058637538008512034, 0.02903236511854395, 0.025628533049096024, 0.01035824896872885, 0.05160175969884281, 0.028361712597430717, 0.09422977995728293, 0.21755947100539363, 0.07340692794851719, 0.12471378210090822, 0.13013275099858163, 0.19953028118658453, 0.11497263706499532, 0.18536381393430695, 0.2766504679476061, 0.23427183229115703, 0.12075642469309031, 0.14954782451593107, 0.12169388648603233, 0.12192933594868069, 0.20366214576267427, 0.17489926739325448, 0.18563246564759364, 0.10020797771792259, 0.08836939885851838, 0.32972758275366604, 0.35014719672260747, 51.91785658559492, 81.41450389739006, 78.07725721789946, 68.8397930514428, 55.432590515382834, 43.55932497209118, 43.04188197658908, 52.00006161966632, 68.00733274029147, 39.85798820372551, 1.078138334616538, 0.21370773413969626, 0.22724216353268395, 0.7245875318204203, 4.9717635396988165, 14.614743417309178, 13.47191576034792, 16.53501033782959, 27.27198681523723, 48.97309795502694, 68.0174446105957, 72.31424423956102, 64.54504874444777, 64.86194095303937, 58.99674630934193, 64.0139715902267, 66.53239603965514, 65.08513558295466, 59.05738222983576, 64.98877863730154, 63.021372672050234, 54.35386811533282, 50.270896496311316, 56.07669861085954, 57.328648567199714, 57.153165648060465, 56.79772830778553, 51.25084577068206, 48.45400364168229, 47.711349917996316, 46.81544134693761, 49.582022390057965, 47.621708070078206, 51.52496845491471, 53.99053504390102, 54.03680332245366, 54.33827669389787, 56.74834566731607, 57.362522156007834, 63.41941087476669, 53.87000453087592, 55.356818168394035, 60.34954432518252, 62.01485718450239, 55.54691191642515, 53.92476474085162, 46.96641729724023, 48.01383133857481, 45.00187858458489, 48.7071494902334, 48.538448349122085, 53.81259279866373, 52.092860975573146, 60.012942206475046, 56.97286213597944, 68.87725168658842, 43.61281041176089, 44.41805339628651, 65.50724144904845, 56.00605672405612, 54.75993933216218, 46.14765390273064, 48.03829123896938, 54.548350995586766, 63.601444152093705, 56.18172399459347, 61.05372351984824, 60.09428039673836, 59.67192742132372, 56.00355817425636, 55.345251098755874, 56.31549642932031, 56.20292440537484, 54.654910026058076, 58.5080268306117, 54.43368442596928, 52.04697708929739, 49.76591094847649, 55.84451390850929, 60.813729378484915, 62.40148129001741, 58.02715993696644, 51.49951619486655, 60.2822482201361, 60.40237472903345, 60.19441066249725, 54.71980956292922, 52.536371215697265, 47.82638519041, 46.94547968526041, 50.82981855638566, 57.27339021621212, 53.68738682039323, 55.1392952857479, 54.4578109248992, 54.49419875298777, 52.75687902204452, 57.3348419897018, 62.90691006568171, 70.3653440167827, 67.66337225514074, 62.640028076787154, 30.080001815672848, 14.638349221598718, 14.944092092975495, 16.497163388036913, 13.471388201559744, 7.571164340742174, 0.9536348896161203, 0.29001683297176517, 0.11922424118365012, 0.19510411627350316, 10.579853192452463, 57.94193860023253, 66.22379179923766, 47.03854183996878, 26.53808193822061, 27.266118949459447, 46.831836854257894, 62.37997885673278, 64.7427362011325, 71.37355789061516, 18.128428113075998, 0.34028513236872615, 0.11244579563818632, 0.1481479060866179, 0.2627184542436754, 0.223642852638037, 0.1602507163319857, 0.18557261885894885, 0.1379011123771629, 0.12619734200979435, 0.1557710325165141, 0.11387690150689696, 0.12614333281113257, 0.16387031323486762, 0.12726822567562904, 0.13114171943837596, 0.168167055254021, 0.15744154852244163, 0.1200816084841086, 0.12023811258615986, 0.12073871274028095, 0.17892328211136405, 0.10643918367643511], [0.03907298158493735, 0.0406589214840243, 0.0807332489339094, 0.07755737781765, 0.11286607913432584, 0.007510816503781826, 0.06165500895510759, 0.04166797802392994, 0.026275496216370698, 0.04455923215456067, 0.060258242977602836, 0.052587653570357835, 0.05076617993895085, 0.038278571390096224, 0.09317045655822562, 0.13993829338540956, 0.037920138002523494, 0.014946805369559557, 0.039635519947736494, 0.10915924013862688, 1.6436557375615644, 45.060945557009795, 60.42581089081303, 53.61552507646623, 40.77061391645863, 33.23378747509372, 23.153564814598333, 34.82371237970168, 41.804087854200795, 42.039575192236136, 9.93607653725532, 0.02760670996541458, 0.21554067610732972, 0.018645151323007963, 0.23184734787191116, 6.089764554654399, 7.464309171322854, 5.244872781538195, 8.79837247633165, 34.879119780755815, 62.156992112436605, 64.09709838128859, 60.67519910873906, 62.73365505280034, 57.97338031953382, 51.421974858930035, 56.374735986032796, 61.45763743308283, 59.85394108679987, 58.84734322947841, 60.328912658076135, 60.35137214968282, 48.93589035157235, 42.49988886617845, 51.48526622403053, 52.41842554461572, 57.0131488000193, 51.70632316220192, 51.91944514551471, 45.14453126538185, 41.99651541248445, 39.351931848833644, 41.553083619763775, 44.274137712294056, 48.25168778819423, 49.90452358799596, 51.4680980097863, 50.659556311945764, 51.090440442485196, 53.316267844169374, 57.639429723062825, 55.309537918336936, 54.436583057526626, 55.20278276935701, 58.25265699817289, 50.61908529650781, 45.34372491221274, 41.396122132578206, 41.35322709237376, 40.85249731617589, 45.77165549801242, 45.48440464081303, 49.39964786652596, 48.710114802083666, 55.38548284961332, 52.455468408523075, 63.63034025315316, 41.879495420763575, 42.222369409376576, 61.61883900242468, 52.316851846633426, 51.89967247747606, 42.27580385823404, 41.97458151848086, 41.75710178190663, 56.96970462799073, 55.5861238510378, 54.506330643930745, 53.00276848577684, 55.88513005164362, 54.52281636576499, 54.73716212857155, 53.006537883512436, 52.742770256534705, 53.670885409078295, 53.097713378167924, 52.60721314337946, 49.91041891036495, 49.09555435180665, 51.730567332237, 56.12879160911807, 57.02795182504962, 57.178998378015336, 54.442396010121996, 54.76328511391917, 57.59991184357674, 56.51665518360754, 56.57288628239786, 56.000647775588504, 50.53271862768358, 43.65835305183165, 42.090209068790564, 44.40679227152179, 43.67534083704795, 44.53576372515771, 45.9219999467173, 48.78129405360068, 44.28845044105284, 47.19999444100165, 55.13213696018342, 59.23712484298214, 59.48017843307988, 61.72711995340163, 40.373250361411806, 18.31736868427646, 4.666298666308004, 6.829986899129807, 3.1385546057455005, 6.4568508440448396, 7.2399750928724975, 0.05153620172472251, 0.06466333664232685, 0.0645827365318133, 0.3578511301067568, 20.87156907204659, 36.592167885072776, 36.062946011943204, 46.39009952545167, 28.050302728529903, 29.225984158054477, 35.78783096805696, 47.69175375661543, 50.84038934400005, 28.42514599523237, 0.39735926495444396, 0.08708574193259401, 0.10405353225407102, 0.0871582598155064, 0.04792371794821755, 0.06828024457659453, 0.03065271385674996, 0.06223828914845663, 0.03045711437270286, 0.045917586483542, 0.020393373542315057, 0.05796386327053751, 0.05798996005567813, 0.026339589047335812, 0.03484849697880207, 0.028339499878066204, 0.12109444566792059, 0.05674511697443743, 0.010288724574380586, 0.06980649090462154, 0.029957642283050284, 0.015666037441171225, 0.02154581301334885, 0.020084929307021444, 0.03805970007012929, 0.04137857298877451, 0.0710129185068992, 0.04112140876391242, 0.03449701966958181, 0.04311602209664641, 0.018334761224386674, 0.03580307700641213, 0.06608171779061518, 0.1256069563509476, 0.07525412681242151, 0.040442444188820745, 0.07209659584106938, 0.0477776671158931, 0.02075356893211363, 0.060085516963754936, 0.03481615274663895, 0.1626137451779458, 2.830521805632499, 55.915073425539084, 68.2447067383797, 60.24564466168804, 49.74314551199637, 43.15331259081441, 32.42403768724011, 34.587413111040675, 40.21288033454649, 48.81179440406061, 10.380733090062296, 0.04079949095725052, 0.18915300738186608, 0.10623925771083563, 2.169630378484726, 6.32199534485417, 8.277549378333553, 4.779597799624167, 11.157338849959835, 35.41622561793174, 61.825367481477805, 67.41472536517729, 61.54844814731229, 64.94904110508581, 60.69339498396843, 54.541098533138154, 57.703038800147276, 63.210862375074825, 60.8126115029858, 61.388203636292495, 61.324598481578214, 60.50896121609596, 51.384249502612704, 45.26190034804806, 54.030868776382945, 56.11163516198435, 59.70143933450023, 53.95751653179046, 54.808674781553215, 47.842423762044604, 44.31460088299167, 42.526125600261075, 44.28177848938973, 47.89156713793355, 49.46414732163953, 52.41588384874406, 53.71230171572778, 51.461551573968705, 54.36205410188245, 54.88505509591872, 58.20727517527919, 58.72572621991558, 53.40887108156758, 57.712146543687396, 59.22730322807067, 52.5047137660365, 47.050869849420366, 43.16169077350248, 43.60983725517027, 43.008588898566465, 48.68515283830705, 46.448134914521255, 52.192853958376, 51.078512514791186, 57.0657987748423, 54.09683127557078, 64.57670619410854, 43.10235315753568, 44.54007833234726, 64.25676238152289, 54.30605834530246, 54.09298343043174, 44.18364863241873, 42.88091574945758, 43.65776077393563, 59.52656830510786, 57.28795789903211, 56.58692836761475, 56.26995378924955, 59.567976767017, 57.12922742289882, 55.790581318639944, 54.76932164161436, 54.958697595903956, 56.85381035650931, 56.18688975611041, 56.98286810228902, 51.683420442765765, 50.87055237062516, 55.27644095882293, 57.20150493806409, 60.12119962323097, 57.95894991966986, 54.23456530417166, 55.23562085243964, 60.82912075904108, 60.84178216995732, 59.36478622498051, 57.37741931792229, 51.57966590696766, 45.83085190865302, 44.07525393270677, 46.276668502438454, 45.561793004312825, 46.41796796552597, 48.77349638169812, 49.996130543370406, 47.95966340649513, 50.16571814014066, 57.689792956075365, 61.46712564652967, 63.306301486107614, 63.67601233143961, 43.77643600586922, 17.234161053934407, 5.881626432941807, 7.589398459080727, 7.69242000195288, 8.64701311434469, 8.849257384577106, 1.6876899811529344, 0.24174449905272455, 0.025606875743476615, 0.48997227763456686, 25.146199464797977, 36.444839739030414, 39.59429902415122, 48.515435803321104, 34.22710026464155, 36.880328732152144, 41.66518888165874, 55.23393031089537, 58.44553170665618, 35.99421039704354, 0.8126565092994321, 0.08646089763891313, 0.05734973271647769, 0.051240365381442735, 0.03951853449125925, 0.0822713543030043, 0.06655062488730877, 0.04169969789443478, 0.05297249783912013, 0.03542769009307508, 0.05763701568808287, 0.036209540276397625, 0.05199411545970267, 0.06082555406817025, 0.05998554632007595, 0.06447994285413335, 0.045370795058026436, 0.10322972726557525, 0.023967300113590977, 0.07100272953750626, 0.06404353320718774, 0.06829623283157427, 0.08215897686539159, 0.2404400658222937, 0.13736347187190287, 0.13027155080870276, 0.17711295505925534, 0.19392339092108513, 0.1637640415180114, 0.12118281390998634, 0.12280421601908824, 0.1534989383071661, 0.15750858121581618, 0.2456618283664988, 0.17028994617923615, 0.15953047110909419, 0.2686712332069874, 0.2557280704739594, 0.06442283099937825, 0.10277421138579808, 0.2154500019406119, 0.23362520811778886, 4.246406487880215, 68.52736057773714, 76.1944724667457, 71.28377483737084, 55.904769359096406, 48.25545326355965, 32.627806778877016, 48.10229255307106, 56.11432983029274, 58.29825847379623, 13.546301549480809, 0.1371922358990677, 0.3022078659024931, 0.20157372879405178, 1.0815212563160927, 14.10257306791121, 16.9743138359439, 12.624570054392661, 15.768565477863437, 40.30978641202373, 66.03525130979477, 69.01440128203362, 64.36624357777258, 68.15034235677412, 64.11916171350788, 56.276555138249556, 59.79993789426742, 66.29274706686697, 64.8349864252152, 63.35513891712312, 63.53835675024218, 63.704869208797334, 53.90836138879099, 47.22258337082402, 55.91915269051829, 59.47951947489093, 62.413856367911066, 57.29532018784554, 57.5178833161631, 49.2751871385882, 47.22509761010447, 43.33674615429294, 46.07234439542217, 50.71497548011042, 52.312788271134906, 54.5084487238238, 58.17001658101236, 56.353002132907996, 56.304223537445075, 58.118151080223825, 62.10327133055657, 59.08379939294631, 54.39639837511125, 59.707318967388524, 63.6795699211859, 55.865777077213416, 48.496604504123816, 45.91132717747843, 44.75148231752458, 44.38221862239223, 49.96032322606733, 50.53796283660397, 55.77158920226559, 53.88793368493357, 59.60602375768847, 56.588818950037805, 66.79186082655384, 46.518608139407256, 46.399732866594874, 66.00637482058617, 58.002429393029985, 57.555781256768014, 46.22377534066477, 44.878316079416585, 46.77087145466959, 61.52160736822314, 59.73161805060602, 59.24225922553771, 58.18242696023757, 61.82921140424667, 59.95754265016126, 58.8193061274867, 58.17773580551148, 55.93023730862526, 57.37320669235722, 58.03977427944061, 58.11522106970511, 52.86595621416646, 52.72514312498031, 57.78557723568332, 60.392058895480254, 62.056136208195845, 60.53978320091002, 56.635330415541134, 56.608144467876805, 63.21488672687162, 63.71348273369574, 61.74608461318478, 61.3157025460274, 55.453273173301454, 48.87876103001256, 46.78379174201719, 49.99286713138704, 48.30330617966191, 49.79617595672608, 50.65888166427613, 53.48384326504123, 49.67215061187745, 52.794827953461684, 60.47095737149639, 64.70987458382884, 64.22020196914673, 66.18590170337309, 44.784594966519265, 24.1658010790425, 11.139729369071222, 15.107168555259706, 11.04775273030804, 14.805738329887392, 13.754248945943772, 0.487005801330651, 0.23790007066582483, 0.16423775964686949, 0.8415769413113595, 31.32632709318592, 52.76746942150978, 44.78709351631903, 54.17539635012227, 37.953563736331084, 42.258792538796705, 50.16329411537417, 64.17345908380324, 67.36644883309641, 43.697043311211374, 1.1358527022023355, 0.21541368937300098, 0.19606825324796862, 0.17225591165404167, 0.12162539822560166, 0.22857589196533928, 0.2288552535878074, 0.12857193878341105, 0.0859722790999278, 0.28587330853746784, 0.08812021343938767, 0.10212276085850694, 0.17002624339394032, 0.13005036590320448, 0.26092908735717496, 0.11446564773758573, 0.13946558649261154, 0.18905228214158168, 0.16817025750154452, 0.20110040903091433, 0.17318185148460252, 0.17663975787018577], [0.053472649831805504, 0.11203114288829027, 0.06635883477546516, 0.07366357506403039, 0.03627121801518145, 0.05863396420834526, 0.05034464005861552, 0.035296440079447725, 0.01799815942743613, 0.08098753649861583, 0.017330724475604874, 0.05234545487309656, 0.05145562076640706, 0.05377948719767794, 0.019514726234539863, 0.05954889918587381, 0.019863799942897695, 0.0473055730934345, 0.02971059999488775, 0.07138461670688084, 7.449540957327812, 54.36036748270835, 59.98450110035559, 55.89814447587537, 41.42954464881651, 25.28469639439737, 21.25711060339405, 41.597743726545765, 46.60201341875138, 32.24829785285458, 2.0454662797912477, 0.030768299287545587, 0.053203277995870005, 0.29133217529423777, 2.086673475080921, 3.3970890554689595, 5.636644997904378, 7.118524784041989, 22.412838935852054, 50.06471318583335, 66.54920731821369, 63.70763447976882, 60.81081897981706, 61.06436883249591, 57.605873846238666, 49.19908531250493, 51.49782173095211, 60.65826623670517, 57.91801606455157, 58.98622651253978, 59.14319192209552, 56.3880681222485, 46.98593501121768, 43.74801843397079, 50.09398583442935, 55.19782097108903, 54.33299326127576, 54.859202754112985, 54.680762367863814, 48.15071813521847, 40.79860787237845, 40.489972252999586, 42.21798027715376, 45.32034758598574, 50.559127946053785, 53.12626431065222, 52.14844096091486, 50.44432409348027, 51.825778945799804, 51.38741485534176, 53.369286521788574, 55.53167350830571, 55.139687522765136, 53.7858186998675, 55.266489905695764, 48.751637012727805, 41.33293667147237, 40.13429172577397, 40.47511431478685, 42.38170785288657, 48.626160390915416, 51.77929885925786, 54.853158381677446, 54.201809590862645, 56.31940311001193, 53.36540729768815, 62.220459984194854, 39.203277941673036, 38.69122820515787, 61.77642414646765, 51.63017426767657, 52.40100237631029, 42.52259154473582, 42.09392355334374, 38.44690768949447, 44.22992867808188, 51.107145817049094, 58.272751300565666, 52.89995924119027, 54.87013439978323, 55.04397776819045, 56.17720150178479, 54.0741168299029, 57.8714692977167, 56.61166283392138, 57.50335485704484, 53.66552352905274, 53.74607332291142, 50.917809086461226, 56.392653372979936, 56.69868846093455, 57.196468614762836, 48.70379586373606, 50.10171682603898, 49.612612955031864, 55.45952150898596, 56.23649204930952, 58.20127002654537, 57.92531559544226, 57.75719888748662, 47.08905020067769, 44.19418411870157, 41.661956848636756, 44.42135995434177, 45.64161715968963, 50.30255786834225, 51.04434867059031, 50.38291938843266, 45.97783488612021, 50.76632322803621, 58.466245743536184, 60.3991073946799, 61.61331630522206, 55.34499614469467, 29.294249088533466, 9.445446864251169, 8.874011462734593, 6.643166859303752, 16.041839949546322, 15.09248810429727, 3.6475252816754007, 0.11390536933416322, 0.05937476740068486, 0.08757383953179083, 6.20970965393128, 35.9664321714832, 46.725952471456225, 42.648856562952844, 30.32189242301449, 24.671261233668176, 31.06036686128186, 42.352799984716604, 49.891234597852154, 42.82131533468924, 2.086042954075721, 0.40864413844481595, 0.06654956002509402, 0.08854367620041294, 0.04871914320955834, 0.07139574030354139, 0.06162158070853161, 0.0942315113159918, 0.04834876651124609, 0.016710733348924308, 0.04529398325229845, 0.04302668858379607, 0.040280814958556045, 0.024355758402136066, 0.025569153574085044, 0.030614380732238777, 0.038948641684387005, 0.007307857308807153, 0.03437166470253179, 0.06659521886538114, 0.03330321336585668, 0.04768531521662109, 0.03064213609773546, 0.05103127700426886, 0.0411250744946301, 0.04067638445825827, 0.060403922257284005, 0.07361020171834577, 0.05631293613283385, 0.08039119067571818, 0.037538859873048724, 0.04715017598843382, 0.02701781817802018, 0.040457823403900674, 0.048531302280964396, 0.052468021280102195, 0.08051816208828842, 0.03146217576408338, 0.024569318817567923, 0.02440493358599563, 0.07819577420671141, 0.05381841212511063, 11.199076790963451, 63.81234607388897, 66.4954786915933, 63.3827563255064, 47.11684411571872, 30.17382883256482, 22.405941447904034, 41.94520296589021, 46.57655723633305, 35.49596740353492, 1.7780129731662813, 0.08855421757025105, 0.06620338021387016, 0.6267145288086707, 5.756443498596068, 8.985723507019783, 6.276874849873205, 4.423226935248222, 20.10841900302518, 51.25568205310453, 67.77876838561028, 65.15897812381868, 65.17062756323045, 62.687535824314246, 59.53090644651844, 51.48667827729256, 55.12750856338009, 61.37197286851945, 60.22913932800294, 59.18575356083532, 60.29079506474157, 59.030219816392474, 50.2456364324016, 45.897461598919286, 52.045188488498816, 57.629533583118075, 56.620625449765114, 58.10797645199684, 57.10355551012101, 50.762149826172866, 43.59257882641208, 42.16460466384888, 44.02203913657896, 47.51232101071266, 51.24296572900588, 54.47854457363006, 54.04457746013519, 52.58508705323743, 54.77178489008258, 54.44791870732462, 57.019793295091205, 56.5387498947882, 54.08127907783755, 55.00753110454929, 58.2615097876518, 51.66388703930763, 43.58783668087375, 41.766786113862075, 43.05511997592065, 44.400147776449884, 50.898165856638265, 54.41950113542619, 56.93381494091403, 56.03250134375788, 58.10633297889464, 53.781100088550204, 65.04198951105919, 40.15249544574369, 40.532918284016276, 62.48392558866932, 52.81976638301727, 53.80430090811945, 44.62551932181082, 46.21968038620488, 39.38964936041063, 46.27633902334398, 53.623212922003965, 59.81566659865841, 56.354108241296586, 56.62783084377166, 56.66792923404325, 58.31049626873386, 56.82560459260018, 60.22782141162504, 57.147995964173354, 57.78729915618897, 56.508539799721014, 55.787568938347604, 52.70013409276163, 58.64871048158216, 59.63013064476752, 58.35238325980402, 49.17439006990003, 52.739094995683246, 50.270276761824086, 56.993733067666334, 58.025441938830966, 61.07356679054999, 58.83140663946829, 60.60627129770095, 49.06766629988148, 46.40817772957587, 44.67666702885782, 44.868902391003026, 48.96165640123429, 52.088707185560665, 53.20354677015736, 51.279063301701704, 48.72816162724649, 52.38310067884384, 60.66766031326787, 63.13177170292024, 65.13063507695352, 55.758594389884706, 32.86678894873589, 9.613646922572967, 8.16383300289031, 8.698205928648672, 12.500049510309774, 12.185378343828264, 7.34442682996873, 0.7119608093653956, 0.03748345639436476, 0.11297706995279559, 6.7776418885877066, 37.24765477641937, 43.43121643989317, 55.32355254696262, 35.797731030371885, 31.01177065603195, 35.63519193280128, 51.119783693744296, 56.423000751003144, 52.397436941823656, 5.073323509385509, 0.6072341386348971, 0.03462365017302575, 0.015616080847628897, 0.06074687683834665, 0.056479633034717654, 0.07927811854789335, 0.04004445768171742, 0.024159666706597614, 0.03718755876405105, 0.1013016984647801, 0.057762347672495155, 0.029759997344245354, 0.019555865156073726, 0.10533213299969513, 0.017449732404202223, 0.020060623252403834, 0.05866764909437588, 0.06900192238390446, 0.08789540493800756, 0.049873269989245364, 0.06043869115772748, 0.08532432959445062, 0.18088745494042674, 0.18160196982564467, 0.2064096281725553, 0.1514546786464991, 0.22627393564870282, 0.16201241212266107, 0.09968558236235574, 0.10248156579872293, 0.2268639152809497, 0.18287529988634973, 0.2817486911531418, 0.11968220088390574, 0.13721966184675694, 0.176583067363789, 0.0753438969953887, 0.15183796775677513, 0.15992845378575787, 0.1100625727145422, 0.1538646840039761, 15.85268953154164, 76.45044634419104, 75.35208071431806, 72.80568584319084, 53.961517349366225, 36.2037237997978, 30.947990955845004, 55.05897691172939, 60.12774213667839, 42.258847451979115, 2.6835706974229505, 0.3483867879596449, 0.17323195363485044, 0.7962451286373601, 6.842280097546117, 13.689796559272276, 15.68146630640953, 14.610543539447171, 27.90794030312569, 55.1978248934592, 70.51096593180011, 67.03486734820952, 66.21567249298096, 66.05181155666229, 60.5263255488488, 54.15412141430763, 56.883051626143924, 63.811389015566924, 62.30636381333875, 60.64376523417812, 63.188312668954175, 61.45912793374831, 50.47480875445951, 48.36986880148611, 54.009993922325876, 62.42803965845416, 58.19716722734513, 59.64726748005037, 61.66915124462497, 54.24037433439686, 44.48931893994732, 45.48044696930916, 46.03805111300561, 49.264337862691576, 54.38768286858836, 57.60910980163082, 55.94423232540008, 55.84344702382242, 58.6888010271134, 55.94121602273757, 56.93194789271201, 59.56863572520595, 56.99134434423139, 56.73724535972842, 61.82261397761684, 53.859331761637044, 45.29834701168922, 44.492554895339474, 45.73067457445207, 46.507739251659764, 53.28950159011349, 57.10161785925589, 58.684509954144886, 59.14167004246866, 60.58316461501583, 56.01647846160397, 65.66757225221204, 42.713497223392615, 43.26349981369511, 64.9070325205403, 56.026158871189246, 57.04102116246378, 48.163203039476954, 47.48196971031928, 42.20164360538606, 49.45817747423726, 56.114800514713416, 62.99084878736927, 59.482057248392415, 58.409375298407774, 57.750801501735566, 60.44362237376552, 57.93065786361695, 63.56590747833253, 58.834038549853915, 62.86269318672919, 59.97271437798778, 59.43748343375422, 54.59234037706929, 61.798307049658995, 60.65791322338966, 60.127216539075306, 48.770731110726636, 54.64363713418284, 51.83523970265543, 57.86414623260499, 59.891121233663256, 63.77076895006242, 60.82755181097216, 63.342293154808786, 49.98187665016421, 49.48163717023788, 45.59488996382683, 48.413061941823656, 50.68680893990302, 56.29115027766074, 55.57006958992251, 55.98543290169009, 50.54742751582977, 57.02399415354575, 62.81382437675231, 65.94019659103887, 66.73060909394296, 62.52053306948755, 36.5560624676366, 14.591312158492304, 16.8771331925546, 14.12059243648283, 30.56038037423165, 29.036135558159124, 7.4505681280166876, 0.44348685912066893, 0.25364257996120765, 0.39483662935033925, 8.725198699582009, 51.91375378639468, 57.662442268863806, 49.46019357250583, 37.69412248365341, 37.08391151120586, 43.00267004197644, 62.546177525674146, 62.960807354219504, 66.59686411580732, 8.478565946702036, 0.8603937154816044, 0.10703029711880993, 0.19916657328365311, 0.12984197466604172, 0.1497139889867075, 0.24354226226287506, 0.224487173461145, 0.09449958846333528, 0.1674319938906739, 0.24129618439943562, 0.31635655991492734, 0.11991353645440071, 0.2095875753870895, 0.18357460026539144, 0.12012743586373907, 0.12192365923716177, 0.10640577458205724, 0.18413591288751174, 0.15509679853435487, 0.11389091325503205, 0.1402207040378163], [0.09054376323136593, 0.03522963721245047, 0.037799456171811595, 0.05969819057011797, 0.06384383706796555, 0.06241198809396836, 0.0853683183630628, 0.0457626145573393, 0.04412350432586767, 0.03843363524684983, 0.02235373699917428, 0.04562153563564343, 0.034292857237761064, 0.02705043820183604, 0.05704481057041595, 0.03787639055160746, 0.024862270839812777, 0.01947166826275568, 0.06219692423098511, 0.3796818473887059, 20.588373945605372, 59.93155302539949, 61.11595584500221, 58.634487967337336, 41.164627767378285, 31.518927235757154, 34.56589106590518, 47.100570201873786, 48.170988944269, 14.30542040255762, 0.11550600279963787, 0.08375227886943087, 0.11352798676178341, 0.34890696166023133, 6.597243749326275, 4.381641966681327, 2.8267342669348565, 5.635076540131723, 34.345555843845496, 61.937668861881384, 64.60193487905687, 59.02297912105438, 58.74569500646284, 58.682019249085464, 55.61001108538721, 46.2075210386707, 51.52996947688442, 60.77489399140882, 59.15946583594046, 60.5031757200918, 58.804907106584125, 56.49018310731458, 44.33096893372075, 41.84576303728166, 48.19952810964277, 55.35066004722349, 58.782533907121234, 56.661214136308246, 55.601154373538115, 50.769908274373705, 42.153888748538115, 41.22965282009494, 40.68556124164213, 45.489338982489805, 52.77128196531727, 51.85094095045521, 53.276314581594164, 52.89625260137743, 52.91044765903104, 51.20540903460596, 54.867686840795706, 57.17820213687036, 56.82216467395906, 54.536136734870176, 55.597714454896995, 46.876885275686945, 41.868053866970925, 39.75337859122984, 42.101407435632524, 46.42264735314154, 53.369180617793916, 53.457355499267585, 58.966932373662154, 54.34279918670655, 57.97107788824267, 54.39626501452539, 62.51899550038, 38.033168238978234, 38.01332889064666, 61.411008296474336, 50.037276206478, 56.13885641098023, 45.772502729969645, 48.58408120370681, 40.35710588578255, 40.33814122599941, 40.845182095804525, 49.91653388546359, 53.119976751265995, 55.536278370888006, 53.98678918038645, 56.32794210987707, 53.01779116353681, 54.27662880189958, 52.59664627813524, 56.055898281835745, 54.07880798462899, 53.51272367662, 53.00799308284637, 57.7564222581925, 54.246681505633944, 54.20250777275332, 53.201969977348085, 54.67199979289886, 53.24834808226555, 53.8354366825473, 53.27374935150147, 58.10544652323569, 57.422730538152884, 57.10758378428798, 53.86143807441958, 45.90030139492404, 43.136222823973625, 40.88969707489014, 47.46212643961753, 53.9304207986401, 52.86625431429956, 52.52982870224984, 45.63102676022438, 44.994932067009714, 54.40245059228713, 60.27667060975106, 59.573550455031864, 55.387753901943086, 52.212328526281546, 22.963714253517892, 10.637681676495461, 7.698985559325065, 7.5015157941849, 4.831111267689736, 12.709306978410291, 0.9622468210516438, 0.09056254770726928, 0.011129933165296192, 0.6436579422123971, 20.800207430316558, 34.67310120982509, 14.015285622689033, 30.652346226476855, 45.43257836372622, 28.333388028606294, 33.81074851559055, 49.16737687203192, 46.49387367310063, 14.117419239013428, 0.03259714843044358, 0.04375158396038798, 0.041353518083210916, 0.04303593526504213, 0.05595780841465439, 0.09047031838206515, 0.0373044369682189, 0.04932310394642334, 0.01132581131382575, 0.017385788960382342, 0.08197608103434886, 0.13226691873804217, 0.06991660838285763, 0.06433438614852006, 0.04021180958877649, 0.057139847607862566, 0.07906992649359089, 0.014128714439369017, 0.057629404604555144, 0.05330951906920922, 0.004217270451913318, 0.11543431995256294, 0.057031752601746595, 0.09166545384833891, 0.02896274879364477, 0.05793993068378299, 0.037133212486702594, 0.08553469733845803, 0.014320759275447459, 0.03923389835343246, 0.018114258137141025, 0.07950941581399211, 0.023320800429510496, 0.006449147439261358, 0.0760828577462704, 0.05178236875743155, 0.039692570515457666, 0.02713425013597214, 0.012285748211246346, 0.03097364724042916, 0.3899364551949886, 27.434755371462916, 70.21679601361676, 67.01147433250182, 65.00043984382384, 48.47064625832343, 41.66352187433551, 39.21427626763621, 47.57645176303002, 50.78224020619547, 16.688688801180934, 0.06854148055877417, 0.11030823412922122, 0.020383895119471897, 1.7451075969203826, 6.35264523567692, 7.8640898869883635, 6.50223070575345, 6.835318380786527, 35.58177709579468, 64.6415037493552, 67.3186194512152, 61.998281248154186, 62.799821515237134, 62.28321790695191, 58.534491062164314, 49.49138426011609, 52.9698754895118, 60.15113907475626, 62.09206511897426, 61.843626114629934, 61.36823092737506, 58.51189820997177, 47.05870282265448, 42.939253161030436, 51.283734844576934, 57.33823483990085, 59.804813400391616, 59.42954063415528, 57.82708375684677, 52.28192706261912, 43.799283812122965, 42.438056622782064, 41.74231836872716, 48.604395158829234, 54.12276598715014, 56.07325869221842, 55.510751585806574, 55.42476146451889, 53.74953677577358, 53.248908981200195, 55.473983287811286, 58.394611497079175, 58.76354963548722, 55.60858334264448, 57.45921642549577, 48.7224781128668, 43.855942449262066, 41.447360054139175, 43.78037406552223, 48.404417037963874, 56.444801284420876, 55.279123860020796, 60.062238554800714, 57.44187954933413, 59.39858528875536, 56.885777673413685, 63.34104976346416, 37.72556420295469, 40.28342808446577, 62.69650236252816, 52.84969798980221, 58.4809781659034, 47.74366240347586, 50.737089803141934, 42.235258317762806, 42.020932166807114, 43.92387790064658, 52.72409192977413, 54.43408843009703, 57.247141715018984, 56.380384199080936, 57.0450415918904, 55.768384625834805, 56.166093349456794, 54.28179064104634, 55.58314284970684, 55.410660543749415, 54.68945826253584, 54.720892137096776, 59.16663200624528, 56.30357242399647, 54.32920032931913, 53.448585079562285, 55.91028028918851, 54.82746293467861, 56.24585082454067, 55.857253766828975, 59.291190793437345, 58.95077220855221, 59.033714648216005, 56.672024188503144, 48.74192522418115, 45.6857987373106, 44.24765386889058, 49.293990981194284, 56.267051235322036, 56.75404879354662, 56.17545604705811, 47.396414972120716, 46.65496541607765, 56.32304306953185, 62.17444665970341, 61.84671694232572, 60.72422089115266, 52.15483834666591, 21.747026405026837, 8.316971159750416, 2.810637350043943, 6.769180845829749, 9.543835597653544, 6.377173777549498, 2.360981491304213, 0.11505512175180259, 0.05956399111798214, 0.7400010369958416, 23.554260423106534, 36.199005188480506, 14.764944699502761, 29.201896882826283, 49.742259056337424, 35.50429067304058, 43.35457332672612, 55.071069578970636, 56.44424430785641, 25.475743278380364, 0.05916383275161347, 0.07307374864936837, 0.03950518923961828, 0.023756855760791132, 0.03554025522222923, 0.03664906407075544, 0.028056363357351195, 0.051341446852611924, 0.03162326873280108, 0.02701612512370752, 0.04594086406512126, 0.010331846706028427, 0.08478327233704828, 0.0718612153263342, 0.06964341376817997, 0.05743974804758065, 0.09007376062894061, 0.03743272605201891, 0.04090104357249314, 0.07440921610161182, 0.08552848436539212, 0.3158261819231895, 0.13977759878241247, 0.16330831113361544, 0.07977212268498637, 0.15832682440598167, 0.1514307460597446, 0.11505005024974385, 0.1546767372037134, 0.09034840314979516, 0.16021038946365157, 0.1016750743973159, 0.15113152743827912, 0.07295013270190648, 0.11240775171186655, 0.19340281885477806, 0.11462495572143987, 0.08576772596326568, 0.21190695254312408, 0.1385769091786877, 0.556096114939259, 36.76670551300049, 79.79342752887358, 75.09553417082756, 74.80871477434712, 55.22707400783416, 45.12533126338836, 48.13928442616617, 58.39091270200668, 60.82101321989491, 21.31403792288996, 0.21814453235316664, 0.327681208690328, 0.1900400759111489, 1.808926153086847, 18.087131438716767, 13.64820178477995, 10.743130676208004, 10.460308174933157, 39.11879793290169, 67.1443328549785, 69.32261328543387, 64.37140149454918, 64.42087042716243, 64.67052928863033, 61.46007714733001, 51.7892381452745, 55.84724387814922, 64.89110377527052, 63.08009839827015, 63.36336412737447, 63.224398474539484, 59.854874610900886, 48.35404203784082, 43.680263411614206, 54.1629663590462, 60.51107929598901, 63.81433471556633, 61.91997897240424, 61.074621908126346, 55.51738431376796, 45.603974173145915, 45.35922611913374, 44.093951871318204, 50.18036034799392, 57.63169873145319, 57.15049843634329, 58.20491390843546, 59.429889725100615, 56.2758687234694, 56.95471725156231, 58.06237889874367, 60.91618168738581, 60.26575465356151, 57.77321392490018, 60.33417647884738, 52.298514766077844, 45.43163699488486, 43.70577058484478, 46.25877072734218, 51.191202209841826, 57.8054165840149, 58.790519852792066, 62.37007879441785, 60.04853771578882, 61.046541660062736, 59.7470368877534, 64.12917944692796, 39.8818636709644, 41.85687903435, 63.58102429297663, 55.28050453432145, 59.89648311368881, 50.108161280232096, 53.192218965099705, 44.01197041234663, 44.3382017843185, 44.50687154646843, 55.17269819013534, 57.475392280086396, 59.19559478759766, 58.400851988023334, 58.714288588493105, 57.76518091078728, 57.64496418737597, 54.1633782079143, 57.16376389226606, 56.255056627335094, 56.60137837932956, 57.67937906326787, 63.39619828808693, 59.724926487092056, 55.645190823462706, 55.45392036437989, 58.25491236102197, 57.08893683648879, 59.00885466606387, 56.61646381501229, 59.80087141836844, 61.85073344938217, 61.55565354131884, 60.79430580139161, 51.65481067472889, 48.41132825420749, 46.440415690022135, 52.61710143858387, 60.167742467695675, 60.31884001147363, 58.24114091934697, 49.61750415063674, 49.10205764155234, 59.29592117186516, 64.9546540168024, 64.9425378153401, 64.65806007385254, 55.79736309666788, 32.213894744073194, 18.147765398025513, 15.25865637486981, 16.402576411924056, 16.09826030269746, 20.752330979993268, 2.7610254960675396, 0.21089809135563914, 0.13528852272898922, 1.1474924582627513, 30.715094343308483, 49.61502521268783, 22.08560539830116, 39.372932218736224, 56.90851957567277, 41.73972175967309, 50.15424520738664, 64.67528712364935, 65.80227821103989, 36.151673947611165, 0.26635050773620605, 0.1867426649457024, 0.09559584496122214, 0.06797682779330401, 0.17667070782232672, 0.1378365005216291, 0.08629480211604988, 0.09962356754488523, 0.10045367743699782, 0.20903813712779554, 0.09040700121512336, 0.12916049349211878, 0.2567905731379025, 0.11893234636274078, 0.1431102191488589, 0.09801808474284988, 0.2299417041602635, 0.13568486597749496, 0.10855035345640876, 0.11224997590386099, 0.11979234900565879], [0.007577607879460219, 0.06571195779308196, 0.031018788971367384, 0.0670146520039247, 0.04957141602532037, 0.0236157481107981, 0.025880503197831493, 0.016359547153115273, 0.06336485974550729, 0.06524017020579308, 0.020612620245364886, 0.011104261558953554, 0.07922463028902009, 0.043346227687453075, 0.14805940760960504, 0.01296503454326622, 0.04863592307834376, 0.031192666032321514, 0.07665095790739983, 0.5228387059703951, 38.972171891120176, 61.10963298428444, 58.431411174035844, 39.62588979351906, 23.175794847549934, 14.834622663836326, 29.31405705790366, 42.03864166813512, 33.49058505027525, 4.884369700185714, 0.0690718355678743, 0.20952691654524497, 0.05964274878703779, 0.6736450750500925, 4.974414571639031, 8.879111524551146, 3.679342813068821, 15.842040296523804, 51.77521567190848, 66.88708028485699, 63.49060973813457, 62.82718004718904, 63.91833243831512, 58.05742494521603, 56.53316051729264, 46.11647105986073, 47.02812794716128, 55.29337383085682, 60.58316069264566, 59.77362271278136, 60.03560566133069, 48.02133483271445, 44.874448622426684, 44.05618336892898, 47.93486618226575, 53.537587581142304, 57.15327939679546, 54.258464305631584, 56.938608077264604, 52.32652441147835, 44.828113663581114, 40.182799677695, 40.79335974108788, 44.69203095282278, 52.66804126001174, 53.76937220173498, 55.417771800871826, 50.723608616859686, 51.639101582188765, 49.69318628311158, 54.96872709643457, 53.34517178996917, 56.384039848081535, 54.875194257305516, 53.20456658640216, 42.83354136251634, 41.30832772101126, 41.22150997961722, 44.804791250536525, 52.54472194179412, 55.74984750440044, 57.353449713799264, 57.506359392596835, 52.54029750823975, 57.2057254083695, 51.68020802159464, 59.340483219392844, 34.042799857354936, 34.93762193187591, 62.915198033855816, 51.1169909661816, 56.42180835047076, 51.11806569560882, 54.728164211396255, 48.01618083830803, 45.38849876772973, 39.819705870843705, 43.301205558161584, 45.656173075399096, 56.594573067080596, 53.559494018554695, 55.17760115285074, 53.37993575680641, 50.78377385293284, 52.45009868375717, 53.2820333973054, 55.008601911606334, 55.29357779410578, 55.06692755606867, 57.56249243213285, 51.13912490106399, 53.10983742437055, 55.93529324377737, 52.99365289749638, 53.30996459530246, 55.59013643572408, 57.80324359093943, 56.86438898886404, 55.19447126696187, 57.393379442153446, 55.58387633292906, 45.95920755017189, 42.37559287778793, 42.893832114435014, 49.89833801023422, 54.74805455054007, 58.86435062654557, 57.53575363466817, 53.03630082837997, 46.74923173842892, 49.94791284684212, 56.38904087005123, 60.46715659479941, 59.06874141385479, 63.95091948970672, 52.761456428035615, 31.039117420873335, 10.897314144719033, 8.621741283324457, 5.891961388049587, 9.028130212137777, 1.3583201001728735, 0.07959439794743255, 0.03760175952207177, 0.05300596822053195, 5.838129308915907, 38.48524101318852, 54.96483610522363, 41.1641021697752, 44.400214456742816, 22.00548118160617, 29.09212935355402, 45.855511849926366, 44.54820156097413, 35.754106429315385, 2.1798765899673587, 0.16332332645693134, 0.027024663173623627, 0.07245586043403995, 0.032380590696007974, 0.08982733312633731, 0.049509102433559396, 0.06006156905524193, 0.01755665338057424, 0.0699471216648817, 0.025553308960591114, 0.024493970239775318, 0.0471076121433608, 0.054400979856690096, 0.0539433648960004, 0.005030345900224583, 0.01888996429531084, 0.11786149334042303, 0.03025067857496681, 0.07033001240943709, 0.040404706697670684, 0.04605608368893305, 0.0906024072619696, 0.05429792187867626, 0.01082607109339968, 0.03629865545418955, 0.045437452368318074, 0.14571361574194125, 0.014570016515321069, 0.025932296487172286, 0.04729622299031866, 0.06295257803773688, 0.036968335043638945, 0.07590140982140457, 0.04127174585817322, 0.06588922287788122, 0.08004709462364835, 0.06357104081900851, 0.09082330105405662, 0.10463850933217234, 1.1832324824025555, 47.462251955463046, 69.00563086232832, 65.30320759742492, 48.9226209732794, 31.452048863134078, 21.4038739281316, 27.19848159820803, 41.76000825820431, 41.90858764033164, 4.593925543369786, 0.036367607197814414, 0.21037534359962712, 0.2022280598119382, 4.694141610976189, 7.289302820159543, 7.868879100968761, 3.0634816663880504, 17.209526608067176, 51.95624874484155, 67.72907980026739, 66.00186409488802, 64.77736680738388, 64.18222558113837, 60.629958491171564, 57.53328646382978, 48.56464193713281, 49.70292552824944, 58.67221724602484, 61.74431562423707, 60.33660442598405, 61.72735529561197, 50.93868394051829, 45.82006539067915, 45.054971787237356, 50.9733380809907, 55.433912354130904, 59.41588686358545, 59.04571710094329, 58.88191107780703, 55.24695257986746, 45.936771592786236, 42.61025259571691, 44.103361637361594, 47.56853249765212, 54.94726780922183, 56.49422314859206, 56.357689365263916, 53.93578660103583, 55.56734746502292, 52.64284787639495, 57.064720123044914, 57.188949431142504, 57.725666953671364, 56.331056471793886, 54.80508189047537, 44.29528713226319, 42.71924349569505, 42.4954330536627, 46.34322720189249, 53.87928485870362, 58.74583228941887, 58.452125210915845, 59.10929479906636, 55.21338885830295, 58.70809516599102, 52.772454753998794, 59.28433841274631, 34.758404916332616, 35.595011172756074, 64.06759431285244, 52.16152991017988, 58.1544683056493, 52.45526836764429, 58.27590488618421, 50.48473627336564, 47.64300654011388, 41.87362363261562, 45.80178322330598, 48.3892531548777, 58.01438085494503, 54.72086468050557, 57.45654136903825, 55.40814630446896, 53.05992918629801, 52.68000056666713, 54.66245274389944, 56.85664623014389, 56.543142949381185, 57.70666699255667, 61.06122701398788, 50.29863157579976, 52.04753406586186, 58.220273910030244, 56.03340741126768, 55.192498314765196, 57.84904510744157, 59.08594492943057, 58.97392988204957, 55.86367076443088, 59.58338383705386, 58.87833387620988, 48.463374184023955, 44.987012801631806, 44.605829023545795, 51.761577590819336, 58.320463011341715, 61.89256944964009, 60.799820653853885, 53.839398276421335, 50.245510916556086, 51.47323631471204, 59.50685839499197, 61.53584949431881, 61.47611179659444, 67.30440478171072, 56.03915368357013, 27.51819399095351, 6.326079022499823, 3.3749141808479064, 9.097437512490059, 7.8780804910967435, 6.168628219635257, 0.823241944514936, 0.03689780132845044, 0.1584239796765389, 6.127143761804027, 41.97355385749571, 39.06603028697353, 41.08801603317261, 48.019581533247425, 25.72827723718459, 33.76210328071348, 52.490663836079264, 51.855016293064246, 47.50242879313808, 3.710491825495997, 0.20969272861557625, 0.08890083405159174, 0.06121217183047726, 0.03433710264582788, 0.03590536506606206, 0.05492752357836693, 0.049680020479905995, 0.03565928613346431, 0.047248055212079525, 0.04922489147453059, 0.03775677741354993, 0.026515373667221398, 0.018148391184607343, 0.058573899084642056, 0.08190580012817537, 0.010601438792242159, 0.06653553295520044, 0.03291563033276508, 0.053897978016926404, 0.08059637966535746, 0.18865664369396626, 0.2015932946796379, 0.18968326279953604, 0.1636773816520168, 0.14272974924214427, 0.10939836682331179, 0.15751307049105245, 0.13117721995278714, 0.09501394755657643, 0.1383622666640628, 0.18017476334446864, 0.1488413841974351, 0.12172873582570784, 0.09893219617585983, 0.2401877317817942, 0.17837254150259882, 0.16894872540668135, 0.24027256835852903, 0.26455314289177617, 1.9063369905756367, 56.20055921616093, 76.99640889321604, 75.04514740359399, 56.41145721558602, 37.12840295607044, 22.836092095221243, 40.25905055384482, 53.51755603667229, 44.572120174284905, 7.115801678549859, 0.17144643250972996, 0.4735834506009856, 0.17438038072038084, 7.111860186822954, 12.859793613033911, 17.685712152911773, 10.328273350192655, 19.25520739247722, 56.92459344863892, 68.68478098223287, 68.6819568757088, 67.3709987824963, 67.34580932124969, 61.27101890502438, 60.497366689866595, 49.610847888454316, 51.952075342978205, 61.18065534099456, 65.05410963489165, 63.296923099025605, 64.4744303918654, 51.74446036738735, 48.343569309480735, 47.803325576166955, 52.784076736819365, 59.05045140174128, 61.317530370527706, 59.13941075724941, 61.10814640598913, 59.79642345059303, 49.34151049583189, 43.45467613589379, 47.37628144602622, 49.47041134680472, 57.57554215769614, 57.83077470717892, 60.270077105491396, 55.67635797685193, 58.10618392882809, 55.873107987065474, 59.17848933127619, 59.33997331127044, 61.52563172001993, 59.111357965777, 57.28190960422639, 46.76709813456382, 46.016250579587876, 45.33023195881998, 49.26511449198569, 58.587297931794204, 61.155865961505526, 61.78131926444269, 62.322147430912146, 56.88156112547844, 58.21336269378663, 53.884591825546764, 59.999696362403135, 37.095906119192804, 39.40302464269823, 65.64390074822211, 55.66468500321912, 60.063219147343794, 53.467145735217684, 59.94939588731336, 52.49934011890043, 51.42186111019504, 43.991401503163004, 48.060727196355025, 50.12088152670091, 61.80621847029656, 58.73507715040638, 60.97957503411078, 57.32426727971723, 53.23056405590427, 53.34219863337856, 54.81065165612006, 57.67553906286917, 57.47856939992597, 59.14892642728744, 62.52254132301577, 50.261019968217425, 52.58728358053392, 60.72861394574566, 57.9806367043526, 57.87530145337505, 59.94155114696872, 61.15535605338312, 60.50545853953208, 57.5552595815351, 62.12720563334804, 62.08420468914894, 50.59196995150659, 46.658774037514966, 45.47102543615526, 54.66113482752154, 60.447340780688876, 65.89756042726579, 63.96422416933122, 58.220324900842485, 53.133630521835826, 54.85238175238333, 62.09472448595109, 66.83736816529306, 63.883180156830825, 72.94120373264437, 57.55962517953689, 44.1604164338881, 19.628617032881706, 13.996116999656925, 14.449628303127906, 20.49717099435868, 6.009257416571341, 0.4072432394229597, 0.08282918888594835, 0.24139004549191845, 8.70199493823513, 54.38225823064005, 70.85342022680467, 50.988090115208784, 53.653324957816835, 32.47266134908123, 43.33786402979205, 63.624621437441924, 60.65445761526785, 57.22185027214789, 5.35834449914194, 0.3725860958858844, 0.22034443043653043, 0.2270563106022535, 0.10428616251315802, 0.10058017387505501, 0.2662126425533526, 0.14272951941576698, 0.12072333735564064, 0.14895686429114113, 0.14930751805584278, 0.13566723063347802, 0.210237585669083, 0.1945349895545552, 0.223060441954482, 0.19846469884918583, 0.17456284754218596, 0.2932663940854611, 0.1295911574796323, 0.13944510130151627, 0.19638423387321735], [0.03430896806680868, 0.06895827835485821, 0.012443343030979798, 0.025157590073743658, 0.06473197045946313, 0.015722057620634236, 0.053937393240630634, 0.01816692859715512, 0.019017887572127006, 0.04214958685840811, 0.11676260916095589, 0.04462259528677791, 0.03858937326097681, 0.0528281860263838, 0.03394149101128982, 0.036665232356397376, 0.05192949977372924, 0.058290730005190264, 0.025319000968949932, 5.9434518121903945, 54.89763021469117, 59.88103681995023, 56.485182085344874, 37.261100661370065, 27.885653395806592, 32.46043336006903, 56.987398439838046, 51.266299909160985, 22.65359990058407, 0.4080362017116239, 0.10542423975083137, 0.043763940958606626, 0.4845583036301598, 1.5008147829963316, 3.6243958002136605, 5.886104308789776, 9.838109458646468, 33.37589102406656, 59.709719457933986, 64.88697744184925, 57.90915935270248, 61.934868289578354, 60.991079345826186, 57.64798833477882, 53.605315146907685, 49.92527292620752, 45.46640880646245, 51.70815490907239, 55.574164544382405, 57.80127063874276, 48.480365891610425, 44.84624678088773, 42.43394597884148, 44.625566390252885, 50.48363016497705, 56.125802763046764, 59.388959792352495, 55.9214041309972, 56.41788598029845, 54.3308908708634, 47.75502943223523, 40.391046154883604, 41.207181561377745, 42.58844421755883, 51.81177608428463, 51.00650172079764, 54.135074384750865, 50.331818749827725, 51.37660872551703, 49.74993121239447, 53.29778171354725, 54.39640621985159, 56.89378715330555, 54.34665487658594, 48.649698534319484, 40.098786430974165, 42.242906939598825, 40.384052568866366, 46.66154323085662, 53.730783923979736, 58.11804909859934, 54.00315723111553, 54.03227298490463, 53.960858391177275, 57.66423086966238, 48.43495268975535, 59.97487168158255, 32.81279556212887, 29.79710086699455, 63.18277820464104, 50.71455578650198, 59.991569211406095, 53.555485356238584, 58.44883826471145, 53.38149293776482, 53.60553872200751, 39.95207409704886, 42.19015890552152, 39.67738659151139, 49.7417805271764, 53.18660605338312, 56.59827578452326, 54.09781186811386, 56.3692956586038, 55.310518510880016, 53.50096048847322, 53.467839994738185, 55.83903043500839, 55.3575594963566, 53.59534448192966, 52.958296652763124, 56.725219372780096, 52.83726799872614, 53.18556270291729, 51.64483216501052, 53.53403783613636, 54.0151910628042, 58.21539055916571, 56.790864159983975, 57.89361107733942, 57.44934381977205, 45.41869317331622, 41.39687915002146, 44.856566536811094, 52.581427481866655, 59.770908432622115, 55.50611926663307, 58.05376145147509, 52.669657276522734, 52.956190339980594, 43.93350731941962, 51.70938261093632, 56.33170366287232, 57.829903941000666, 57.8869979612289, 61.04944421399025, 52.366540431976325, 18.426057561751335, 5.685938404452417, 9.530265177449873, 2.3098482479972224, 2.7108228350839307, 0.40498634439802944, 0.1772079652836246, 0.019961175463733175, 1.0198959179462925, 19.91606204740463, 35.45358619382305, 33.260914587205455, 40.31002175423407, 33.28144035031719, 31.852579732095045, 47.387232703547326, 49.29544618052822, 45.39885382498465, 10.434959857694565, 0.18544805296246084, 0.08196995999183386, 0.05820366411259579, 0.020037799577919707, 0.061071889640222636, 0.0786419361529331, 0.01556477881216955, 0.06414663332003741, 0.10517947465902376, 0.03867471162530203, 0.0153074968012891, 0.06305216946789334, 0.09047041797349531, 0.019250649981380954, 0.010753797401013154, 0.03286232593499365, 0.0601522853567956, 0.0545112275698733, 0.019816275678514954, 0.05327652749275008, 0.017147095115374655, 0.019809277465326652, 0.04933569460145889, 0.10365308277429112, 0.01805570412186846, 0.018881512430286216, 0.02124402225167761, 0.03525107618301146, 0.030614378817018964, 0.02494588167586875, 0.06673189661195202, 0.03213433556318764, 0.04308830120510632, 0.05411395352453955, 0.021153160393418326, 0.06884148825080165, 0.037682505189290935, 0.07161257382962974, 0.042218423688844334, 8.16997935695033, 64.25373431174987, 65.79137794433102, 64.00460497025522, 44.02535353937457, 34.402379220531834, 29.619709714766476, 47.92165563952538, 59.332442360539595, 25.52653012737151, 0.6711279552790427, 0.10263442332225461, 0.06308317304618898, 2.0665926558356134, 5.026941482097873, 7.416905366605328, 3.9697896665142434, 9.032638976650855, 33.4747386747791, 61.103973004125784, 65.96432701233896, 62.692689818720666, 65.41394787449991, 63.7475210620511, 59.155108082679014, 56.90422065796391, 51.84611251277309, 47.70972997911515, 53.62580168631769, 58.44879904100972, 59.61312717007053, 51.47394626371322, 47.69424446167485, 45.19278426324168, 47.05856553969845, 51.91237703446419, 57.8619340158278, 61.261342417809274, 56.29692792892457, 58.6542998590777, 56.823847370762984, 48.90196184958182, 42.69553669037358, 42.22428352602067, 45.52999042695569, 54.04653472285117, 53.45985012669718, 55.827090740203865, 52.36493226020567, 52.79967208062449, 50.51827646070912, 56.90664860510058, 56.30093659124067, 58.80905305185626, 55.14305291637298, 50.464018314115464, 41.4709178093941, 43.60318491535802, 42.67818020236108, 48.12122583389283, 55.65010163091845, 60.9089566815284, 54.61705915389523, 55.8757398974511, 54.80870616051459, 57.17576634499335, 49.61318954344719, 60.011514463732325, 32.58071872495836, 30.732697940641838, 63.14942236869567, 53.5566306883289, 62.88794932826873, 56.08127209448046, 59.965053989041245, 56.656420999957675, 55.47441082616007, 42.50348960199664, 43.821300075900176, 42.572123235271825, 52.55223328067411, 54.997332942101266, 58.44148774300852, 56.26329752706713, 57.74332546418714, 55.294224985184215, 55.37981110234415, 53.8287490414035, 57.89951424444876, 56.305847398696415, 53.48485915891586, 51.91781343952302, 57.97655351700322, 54.19953069379253, 54.703759224184104, 54.58642152047927, 57.40863746212375, 56.959176986448234, 60.04495266945132, 58.75775629474271, 59.35539999315816, 58.673586153214984, 46.91564613772977, 43.31696956388412, 47.82815810172789, 56.20314798047466, 61.11368087030227, 58.94598691694198, 60.45779781956827, 55.4665856976663, 55.73937869841053, 46.68653265122445, 53.75286686804987, 58.9382206240008, 61.51462947168658, 60.80309583294777, 63.443737414575395, 54.03833304682086, 22.233404228764197, 2.2825355587467073, 2.930888149046129, 5.029736170845648, 8.058405576213714, 2.680241095442926, 0.1405597132660689, 0.062118488318857655, 0.6766888343038098, 25.66374444192456, 35.55784671537338, 33.445097323386904, 43.19416407615908, 33.95764127854378, 39.44862611832158, 55.548296513095984, 56.937317617477916, 55.72112398762857, 14.841021030179917, 0.19844320242203053, 0.08400271301187816, 0.0657063270468385, 0.05610282502828106, 0.04676861440642707, 0.08758223585544095, 0.05263851414765081, 0.05478664383953137, 0.04977951997951154, 0.020065667941385222, 0.007818349094445547, 0.07876153013879254, 0.01790640890718468, 0.0373711938699407, 0.04447931769273935, 0.02605245354765606, 0.040019441080550035, 0.04063778128775378, 0.0822843318324416, 0.040316097137908784, 0.1015544461927587, 0.14554199672514392, 0.15358829480265418, 0.22856879799116045, 0.10697106320050456, 0.15090758461625348, 0.18703912565064046, 0.05580670523246931, 0.07615628727381268, 0.12325247704622247, 0.2219652886232061, 0.09646335526579812, 0.11787239477158555, 0.15684041465001722, 0.11789572214887989, 0.18368381375987686, 0.16269663589135294, 0.24929287062296945, 0.34663946397842904, 11.367295480543568, 77.39212113042032, 74.96332676179948, 71.23142688505112, 51.00218319123792, 39.41597630900722, 45.376006018730905, 69.60329025022446, 61.37821335946361, 33.256992217033144, 0.8690426642856292, 0.2211124335806216, 0.18105397181164834, 1.9040882467262208, 6.313876528893748, 11.048031218590276, 13.684701400418437, 16.13112486177875, 37.624763211896344, 62.09096293295584, 68.4052336600519, 63.232309895177046, 67.39126959154683, 64.39357465313327, 60.72067114614672, 59.75906287470172, 54.69469462671588, 50.03204376466813, 55.88661662993893, 59.40675558582429, 61.50757312774659, 52.32250398205173, 49.99134917413035, 46.651913812083585, 48.701218866532855, 54.02346726386778, 60.288531857152144, 64.3138603241213, 59.70080391053231, 62.027789238960516, 59.2894688729317, 51.5976538965779, 44.920532549581225, 44.69576112685665, 48.04306476346908, 56.58260591568486, 54.99871361640192, 59.76964542942663, 56.49985959452968, 55.586308202435895, 54.08409926199145, 58.1749273884681, 59.061779206798924, 62.24405304078133, 58.98150005648213, 53.488197095932506, 44.294906662356475, 46.02230279676376, 45.665410257154896, 51.384480922452866, 59.32895929582658, 63.35182059195734, 57.067304964988466, 57.74857751784786, 56.48337387269544, 59.11695911038307, 51.45384803895028, 59.23076668093282, 35.58844512508762, 33.573707918966974, 64.21654239777597, 56.57961314724338, 63.54138874238538, 57.727337883364775, 62.95588085728308, 59.67690490907239, 59.09378182503485, 46.54005958187965, 46.06365634549049, 44.47464143076251, 55.456697402461884, 56.911590791517696, 62.182930746386134, 58.682482088765795, 59.89712638239707, 56.211941934401, 55.828200770962624, 54.71594602830949, 58.79633280538744, 57.678308256210826, 54.37997541119976, 52.859903996990575, 61.56302367487262, 57.943719356290764, 57.815571600391024, 57.256571092913234, 59.71731708895776, 59.049137407733554, 65.00424454289099, 60.98818855900919, 62.15426998753702, 62.219816715486594, 48.95230547074349, 45.061302492695475, 50.71572073044316, 58.865519492856926, 64.61652609609789, 59.146353352454405, 62.162444206976126, 57.33868983484084, 58.1659020147016, 49.325385632053504, 57.044896464194025, 62.02699299781554, 65.71806100107008, 63.95573616027833, 68.59240916467482, 56.634506717804946, 23.141581973721905, 12.39603707867284, 20.03888910816562, 10.285352814582087, 9.811004900163221, 2.740414421404562, 0.36861371549387134, 0.1388336099203556, 1.679493330659405, 31.50666786778358, 50.40552400773572, 44.035669372927764, 47.91803921422651, 46.779045674108694, 45.74849782451507, 62.062608118980165, 63.504530229876124, 63.26433997000418, 19.442998709217196, 0.46147613575862306, 0.22878748545002556, 0.18549211833986545, 0.08331499588225158, 0.15667899992437134, 0.19160620477651397, 0.1845674808587759, 0.10690675778014046, 0.29745787562381837, 0.18349414571158348, 0.15695635439647784, 0.14398907521559348, 0.1584911809092568, 0.1506463639558323, 0.11742323742157991, 0.09184513211009965, 0.1612268349215869, 0.14714373335722955, 0.16495320915935502, 0.08627540476980709], [0.05876711412002483, 0.00809203831463932, 0.033427806075422034, 0.026012270320807735, 0.07019289033187014, 0.04606372158553812, 0.024610955696252566, 0.016403411432439764, 0.06435693977701087, 0.12039595734207861, 0.05516667707612919, 0.06453144694528272, 0.028355020819412127, 0.0657770369622496, 0.012572112834952291, 0.024134918236203735, 0.007865586554661633, 0.04971283585614255, 0.07823383345478967, 16.207482622515773, 54.890919039326334, 56.008563118596236, 49.16188947616085, 36.97069621855213, 15.742740592648907, 34.636493729006865, 55.19842893846574, 36.39990114396618, 13.697755048351905, 0.08641086443657837, 0.4907454135677507, 0.08544207730841252, 1.0679713059817593, 4.235555741094774, 7.331838473196953, 2.088059542640563, 19.552187688889045, 50.16888349286972, 62.16393863001178, 58.67065614269626, 64.09245821737474, 64.44927230958017, 60.6379875829143, 56.587818745643865, 53.555838369554095, 49.1439603221032, 44.140659455330145, 44.57318313660161, 46.813040856392156, 43.70434676447223, 42.460108187890825, 42.60950734538417, 46.98953182466569, 48.93604332400907, 53.13224984753517, 53.34075912352532, 57.34241608650454, 53.25767940090549, 56.73374268316454, 56.90067091295796, 53.20229553407239, 42.2153248325471, 40.34420521028581, 41.49169068182669, 47.535666957978286, 50.48120614021055, 50.78016527237431, 48.22978919552219, 49.828511976426654, 47.14534797976094, 49.37038698504048, 49.574444370885054, 51.192080820760424, 44.25695773093931, 41.30986136774863, 39.818282050471154, 41.9571348159544, 41.3203654750701, 45.96820546734718, 53.6948001000189, 57.43539194906912, 55.45016665612498, 59.69597155048002, 55.53891028127363, 59.33505073670418, 52.38429307937623, 58.09558568462249, 29.886934911051107, 26.396462801964056, 56.42078853422596, 47.20896097921556, 55.95124160089801, 50.72881752444852, 56.85741109232749, 53.07146095460462, 59.380401180636504, 45.61641200896233, 42.05136975934429, 42.047639585310414, 43.67738046953755, 44.34599553385089, 50.1928727088436, 53.614940643310554, 55.89435154391874, 54.010672492365686, 57.04816379854756, 50.434631916784475, 52.926172441051854, 53.46262716477918, 52.083749309662856, 56.145500906052135, 54.36674133423836, 51.536300182342536, 48.88675482042375, 45.175153209317116, 50.32411913717947, 54.115113442943944, 55.63539274277226, 55.01301457805019, 57.20683936149844, 51.09053457936933, 44.35271847632624, 41.34243272965954, 44.78196305613364, 53.9744847051559, 58.802714501657796, 54.88429415610529, 58.20430201868857, 57.010740464733495, 55.962549794104795, 50.400154282969815, 47.219257200917895, 47.87514809639224, 53.1245659243676, 56.90653877873575, 60.91081588499008, 59.93798179011191, 50.77062606811524, 15.932291092411166, 6.751095287261471, 4.440208346612992, 10.247710808630913, 3.4706577658653264, 0.1654163705966165, 0.04026994417091051, 0.04485439051002745, 10.452129052531335, 42.64971556202058, 37.67431843665339, 15.430782725734097, 25.5733161587869, 19.57199565825924, 40.07925302751603, 48.293531633192494, 48.000483512878425, 24.109493494033817, 0.05896358885952543, 0.03037855971694714, 0.03608716539137306, 0.006804202379088008, 0.01722350089450277, 0.063989351638743, 0.08040974532524425, 0.02802180130064728, 0.046552914690466664, 0.03504568418007224, 0.018010164025209604, 0.018518421228133866, 0.061947486002839385, 0.04723656006277569, 0.026464961251364123, 0.0653464495835285, 0.04352694399835121, 0.02713854405878773, 0.08220997533851093, 0.047678186768485654, 0.03257491272844134, 0.08191633383713423, 0.047819874730081334, 0.04176972982203288, 0.06856263224636355, 0.020819218836784847, 0.012904984741321495, 0.16692960875168925, 0.04879848693587607, 0.03644961307966902, 0.03013942345616318, 0.051769988776575175, 0.022299881018097364, 0.04886102269313509, 0.014888751226657582, 0.0459906253062429, 0.03576600218131658, 0.029089170538129348, 0.0462523554151337, 21.028150089325447, 64.71505603482647, 60.700682747748594, 56.66960016373665, 40.51599325672273, 21.55326916325477, 36.51086891851118, 58.6475847613427, 42.32834008432204, 15.224491550076394, 0.06874305361341085, 0.20150511795955323, 0.31121473098474167, 2.6881034864533335, 7.928148075457543, 8.476123290677226, 6.52172782728749, 22.880746318447976, 53.55376343573294, 61.438300148133315, 63.18099352621264, 64.6990684540041, 65.89727017187303, 62.60471497812579, 59.217363942054014, 53.89130692328177, 52.13036667916083, 46.525903747927764, 47.01546653624504, 48.8769998858052, 45.679781821466264, 45.275150114490145, 45.8764337724255, 47.59019967048399, 52.08941713456185, 55.12111117762905, 55.767274595076046, 57.98337451873287, 53.72095838669808, 58.08556402883222, 60.449015632752456, 54.994140132781006, 43.44323458210115, 42.35613792173324, 42.800730736024924, 49.597174506033625, 53.388255103941894, 53.605687772074056, 51.08438038056897, 52.10124700300155, 50.205239941996915, 50.75712134761196, 52.13904688435217, 53.6202476101537, 45.90264697228709, 44.358574574993504, 41.73419906247047, 44.86256776317474, 42.514283964710856, 47.4566900345587, 56.222626470750384, 58.386460811861106, 55.3503894036816, 59.86343714498705, 57.278744251497336, 62.030836920584406, 55.22268487561134, 58.293151547831876, 31.611805039067423, 27.28592888001473, 57.88481712341309, 50.09812393496114, 56.33803829070061, 51.651708079922585, 58.216241713493105, 54.735624559464, 59.40278614720991, 47.451520350671586, 44.16116952896119, 44.13707833136282, 45.324556289180634, 45.793718830231704, 52.55214306616014, 55.196852145656464, 57.09129810333253, 57.167341093863214, 56.84407111137145, 52.11692079421013, 53.97488870928365, 54.53497571329917, 52.67082222046391, 55.40166654894429, 57.764157172172304, 54.3905108974826, 52.10216483762188, 48.44095783848917, 53.074732211328325, 55.487825332149384, 58.195610046386726, 57.596067920807876, 59.34643345494425, 54.09001811858147, 46.67346331381029, 45.11768264155234, 46.61585938545966, 55.979823912343676, 60.83204684718963, 57.73788121438796, 58.94831288245417, 59.11673553528325, 58.80850392003214, 53.95239783871559, 49.44440603256226, 50.64698119317332, 56.347973654347086, 59.77653311144922, 62.984875017596835, 62.28100961254489, 53.090005920779326, 18.2694314372155, 2.8814275514694954, 3.1810846203757874, 9.286016245042125, 7.831049311545588, 0.5199063665443852, 0.06600431992762512, 0.09137822450288842, 12.298718171734965, 40.68329018931235, 29.94067530478201, 22.38933805496462, 29.225578192741644, 27.08021233158727, 46.36941294516287, 54.57334826069494, 55.86627914059547, 33.05780249257242, 0.3453428754883428, 0.017591385891841307, 0.1184358447790146, 0.05084484567745559, 0.032688707428713965, 0.0510386391092212, 0.06618703189756601, 0.052537317763292984, 0.028670139595746037, 0.029595050953268528, 0.026605883125035514, 0.002559317569736572, 0.0327172058994972, 0.015659594641728027, 0.030220228495196472, 0.034342430787341255, 0.021417500946911115, 0.06864848772003766, 0.13019172444699273, 0.058372670769571304, 0.11987360029090798, 0.17860236787988296, 0.13151779200040525, 0.1650619476793274, 0.14366972380347792, 0.11406267782853496, 0.14044766524626365, 0.2470655465919164, 0.14749204289288292, 0.24133884017505955, 0.1584248223732556, 0.18916825253155925, 0.09554907529344482, 0.31068279017363826, 0.1535616655864062, 0.17120324555904637, 0.15234550100661096, 0.2646303339110267, 0.23414342063328913, 27.62477655564585, 72.58908471753521, 69.81044630850516, 64.28734510175644, 50.65989755815076, 26.034473142316266, 46.57564724645307, 65.7776927947998, 49.676261255818034, 19.20310066592309, 0.3093566919767088, 0.6223416376498438, 0.2336216534698202, 3.3782116684221455, 12.90124620160749, 16.51432179635571, 9.511950650522786, 25.5099973370952, 54.06255368263491, 62.32070007631856, 63.70546148669336, 65.97867504242929, 68.83783971109699, 66.27810093664354, 62.077650408591, 57.542817823348514, 54.106998059057425, 48.19729235864455, 48.453964417980565, 50.502006469234345, 47.78543172344085, 46.633623799970074, 48.78058802696967, 50.73946675946636, 54.48465562635853, 57.99211748184697, 57.59563253771875, 59.557111801639685, 54.94535369257773, 60.457397737810695, 62.22768499005226, 57.850053156575854, 46.45609732597105, 44.14111445027013, 45.356429469200876, 51.20249863593809, 55.007334986040675, 55.00089053184756, 53.331243453487275, 53.437731881295484, 52.11827793428975, 53.17801606270575, 55.11819685659101, 55.75183614607781, 48.175789925359915, 46.19293766637003, 44.36370111280873, 47.10195479854461, 45.16612783555062, 48.940369698309134, 57.63966898764334, 59.75790185313071, 59.873439188926454, 62.286245976724935, 60.01510343243999, 63.49157856356714, 57.65709215594877, 59.075201557528594, 33.538940029759566, 29.870186390415316, 55.963177373332364, 53.094285226637325, 58.51650307255407, 53.493798240538574, 60.21383816196073, 56.8097189934023, 62.871883300042924, 49.24195681848834, 46.80226218315863, 46.93330464824554, 47.280975695579286, 48.71819880700881, 54.87857141802388, 59.353744752945445, 61.44951028208579, 59.786276278957246, 60.104651143473966, 52.76530427317466, 55.319645866270996, 56.293370339178274, 53.519003391265876, 58.349508162467714, 60.88898789498114, 56.76325067397087, 54.0321788480205, 50.77375611951275, 54.141797327226215, 59.19805019132553, 60.96943570721535, 59.41560053056287, 62.84717629032751, 56.77491188049317, 49.441142620578894, 45.916998924747595, 48.95679658459079, 59.156441688537605, 63.53739576954996, 58.855505681807, 63.81127134446175, 63.35444465760262, 60.9876198153342, 57.13861365472117, 53.00634960974417, 53.49443366450649, 59.401401550539084, 62.875821359695934, 65.66830181306409, 66.50752821276265, 58.708314818720666, 20.84098635181304, 12.352028085339455, 12.866280232706378, 20.720043989919848, 10.966918564611866, 0.4155363863514316, 0.15935034851633734, 0.19748289588718645, 15.462243076293701, 58.81799605584914, 50.46942726258309, 22.742610246904437, 34.6286254544412, 32.37728107360102, 54.87184847554853, 63.190952424080145, 64.88136453013267, 43.38892152232509, 0.9606338688923467, 0.08055160182618326, 0.19469801306484208, 0.20076498509414736, 0.1614342608879651, 0.17627767407365386, 0.15182517408843965, 0.15705982223153114, 0.16803968547573014, 0.11118930419005695, 0.1706048236378739, 0.14134225675896292, 0.15374240104950246, 0.22065561535137318, 0.1619735408213831, 0.12150264795749419, 0.25580618079871903, 0.10324470428449493, 0.2427535594230698, 0.12824187746211407], [0.023178608765104608, 0.0389655722275136, 0.06914718797610653, 0.04281620209616038, 0.04728298499098709, 0.06665141141462712, 0.068462343676196, 0.02282642282455439, 0.05780915181422907, 0.019600552979916818, 0.02309006623803608, 0.027813714583434408, 0.013191455659726936, 0.08057528160392277, 0.05349375172367981, 0.0577672774482879, 0.03517897198757818, 0.09578645529766237, 0.14939552623658411, 28.094747104952415, 61.29947177825436, 56.18385776396721, 39.308417074141964, 23.651825458772723, 20.92897492070352, 38.94892792547903, 48.11405181884766, 37.75786099895355, 4.171219554639632, 0.07832944122773987, 0.15108850394045154, 0.43307713383147795, 2.7991386767356627, 4.933108581650642, 5.799447384572798, 6.202391982078553, 35.48984850606611, 56.24821601375457, 62.92128947473342, 53.704315770056944, 59.694210406272646, 59.01617773117558, 60.032695262662834, 53.17739240584835, 51.645644095636186, 45.66058574184295, 45.33437005935177, 44.31715434597385, 45.97228865469656, 41.45747976918375, 42.71479160554948, 44.84833740418957, 52.34305720175467, 55.013897111338956, 55.572650509495894, 59.55588409977575, 65.17326731835642, 53.240409205036784, 54.779617863316695, 54.59168141888034, 56.251506882329146, 43.26051096762381, 40.820008324038604, 41.13587679401521, 41.423402217126664, 43.41487192338513, 45.874464742599, 41.86535527629238, 43.579678150915335, 41.97222809637747, 42.63763466188985, 40.497263939149924, 42.257101997252434, 39.13229480866463, 40.127133400209495, 40.160006784623675, 42.9653839911184, 43.58156481096822, 42.29572165396906, 47.38811915920627, 56.8239297405366, 53.08353008762483, 56.62474393844605, 53.117105576299856, 58.25917597739928, 51.42296329621346, 62.46769482089628, 33.72180877193328, 22.508152531039332, 57.09858978948286, 50.273218539453325, 57.04172718909479, 51.788269319841945, 52.661314395166215, 52.29976992453299, 57.97105435402163, 49.608102229333696, 42.89408706849621, 40.654652964684274, 43.726206133442545, 39.87285790904876, 41.348681065344046, 42.1989881607794, 52.656129021798414, 54.377484706140336, 57.18250497694939, 54.038391882373446, 53.47831664546844, 51.21046496975807, 51.23455224498626, 55.21385954272363, 54.28923922200357, 50.12312512243948, 45.58824154638475, 43.398974557076734, 44.029107247629476, 44.92799682001914, 52.74728490460304, 53.045620379909394, 52.95315442546722, 45.0431066174661, 41.498813706059615, 42.541650341403106, 42.30565309524536, 50.10478411951373, 56.66195938664099, 57.08073908282865, 55.28385423844861, 55.913520166950846, 58.79701529779742, 53.840747571760616, 51.729457301478234, 46.86149389513078, 51.47780195359261, 51.94425413685461, 55.995034863871915, 57.42376604387837, 58.95833846061461, 33.73339937579247, 9.948817376167545, 1.6518466270739034, 8.48721085056182, 4.403960252961805, 0.9292147032195522, 0.23713949857459915, 0.04466445433096059, 2.193967459663268, 23.333138765827304, 35.96008577654439, 29.788524604612785, 23.839516755073305, 24.720622301101688, 37.80627089162027, 50.32079688964352, 47.22341491330055, 39.95003838692942, 4.39069724852039, 0.2230292468542053, 0.10158286039387027, 0.05567207294065626, 0.04831568300423603, 0.044514347063077074, 0.019510813440466603, 0.024923477434523167, 0.040365708991885185, 0.029022840730425332, 0.04514070438040842, 0.03949991855469923, 0.07740330221431871, 0.04100541156085749, 0.06416493516054846, 0.07396909858911269, 0.03203176979666516, 0.015001928268541253, 0.09025333929927119, 0.10038734188363438, 0.03851635359047401, 0.02710462168550059, 0.08788304793978892, 0.021243754120904113, 0.07809971444188588, 0.034200949669485135, 0.05153457378788341, 0.0368498633765886, 0.008089541825616072, 0.018015478760184302, 0.01869176585798062, 0.025680703636739525, 0.020069795240077282, 0.020833234415359555, 0.04851670447556723, 0.02805100457232085, 0.0772211035232871, 0.09492042354278027, 0.2429184981531674, 36.91484558966852, 67.69816367856919, 65.52486465823266, 46.29945355076944, 32.35255837440491, 26.554942246406313, 36.09490548410724, 52.243134821614916, 37.58519434159802, 4.973862988333549, 0.07866353983239782, 0.0686024994619431, 0.6436996786825119, 5.115460551554158, 9.32021244879692, 8.82301280575414, 8.513378943166426, 33.73420738404797, 59.021555300681825, 63.40538055666032, 57.37314393443447, 62.18826124745031, 61.17809011090187, 62.65405055015319, 55.85601822022469, 52.36579910401375, 49.24980155883297, 48.058679719125074, 46.094690138293856, 46.339940255688084, 43.54467099712741, 44.18959102322979, 46.01486990528722, 52.425195555533136, 56.55884811955114, 58.127902092472205, 60.209052870350504, 65.75509209786692, 54.03205725454516, 56.77169553695187, 57.48221328181606, 57.21693946469215, 44.82328130352882, 42.51473503728067, 43.153783275235085, 44.674894117539935, 46.54082052169308, 47.966594234589614, 44.59466203566521, 45.59317588806153, 43.23405065844136, 45.80558007763278, 42.35072505089545, 44.350368976593025, 41.10809856845487, 42.89433417781707, 41.6219251386581, 45.53497183707453, 45.56527214665567, 45.22464959852157, 50.29876493638562, 58.795156094335745, 56.12393963721491, 57.48853614253383, 54.208477620155584, 60.64743265028923, 53.97518680941675, 64.21028621735113, 35.4099968940981, 23.607657609447358, 57.19262469199396, 51.53749258287492, 57.76815406737789, 54.20245678194108, 54.387094513062515, 53.35485219955445, 59.47573831004482, 51.784688195874615, 43.933032712628766, 42.330085539048724, 46.058165027249245, 41.362946725660755, 43.04074056686894, 43.645052294577326, 55.61347846061953, 57.15635845738073, 58.7957719064528, 54.8754374442562, 53.025290735306285, 52.12753865026659, 53.672968187639796, 57.31009967865483, 55.93082174178093, 52.45681770386235, 48.651589116742535, 46.18775229300223, 47.11089388016732, 48.387229211868785, 54.238660258631555, 55.618754048501295, 54.62236612073837, 48.390967230643, 43.84261423541654, 43.59841139085832, 43.08622829375729, 53.3312120745259, 59.37509421379336, 59.334474148288855, 57.49479232295867, 57.40300101618613, 61.496174720025834, 56.26219534104871, 53.06893102584347, 49.97273360529254, 53.33842923564296, 53.783241702664284, 58.447045741542695, 61.16907258187572, 61.11407702968967, 37.20480288228681, 10.441425884923628, 2.6244164522617095, 5.077387575180301, 10.635428274831465, 2.224945113543541, 0.20568100194777214, 0.046201617411908605, 2.3840482148431965, 31.37288562713131, 33.06078741627355, 32.73744094756342, 25.395069929861254, 27.151730868124194, 46.504169894802956, 57.46934398528069, 54.990723748360914, 50.904508329206905, 7.527172998074563, 0.2693097521701167, 0.12182957597918088, 0.10381019208580257, 0.03524977383354018, 0.08516947258143656, 0.053511988446717305, 0.03462427070424442, 0.05223293953965749, 0.05537664645441598, 0.048544406214909214, 0.047801714615836266, 0.06955285451465076, 0.039837905055572914, 0.06160546604904437, 0.11291285646298241, 0.02745404396386397, 0.04746063695018811, 0.08950466455350961, 0.10421866250614967, 0.18342464621509277, 0.08971361503485711, 0.13153541202266372, 0.11190296871767891, 0.19308205784088184, 0.17912632605481535, 0.12698118019128038, 0.11267048922637779, 0.2333971130992136, 0.05950679499355536, 0.14411770137808017, 0.0927159519145085, 0.16172042537120082, 0.19749539844211073, 0.1911697338425344, 0.16132014443076428, 0.1626274887953074, 0.27760740369558334, 0.6502494852869742, 45.049213747824396, 77.43602814212923, 72.88681614783503, 53.96372956614341, 35.852840331292924, 33.552758539876635, 51.55577082787791, 58.088717614450765, 49.544332335072184, 6.4228939048705564, 0.2524966809658274, 0.1986951534185679, 0.7151611569908358, 5.345469809347584, 16.45676689763223, 15.221858659098226, 11.299787567507837, 37.63092133306688, 58.15340142096243, 63.61020672705866, 57.54640679205618, 64.86075639724731, 63.9185481686746, 64.44164722196518, 58.0770093394864, 56.141421641072924, 50.860205158110595, 50.09068712111443, 48.056663620856504, 50.45580487097464, 46.18002130139259, 47.571827288596864, 48.247530075811575, 55.969308037911695, 60.17275525677589, 60.80539041949857, 61.56704410429924, 66.05004649008474, 54.812401033216915, 58.572447838321814, 58.1561549248234, 60.4763545528535, 48.811712034287, 43.58592648659983, 45.29942958585678, 46.56271911436512, 48.815924659852065, 50.62301551142047, 46.583554744720466, 48.29814826288531, 45.401003283839074, 48.700885465068204, 43.959277291451734, 46.54920262675132, 43.91526829811835, 44.12287935133904, 43.147613386954035, 48.871747832144464, 48.13563269953574, 45.81918677976055, 50.26556991761731, 60.778930110316125, 58.61282079450546, 60.1415135783534, 59.59027936381679, 63.75814284047773, 57.05193319628316, 65.74012433328937, 38.08080934709118, 26.037287442914902, 58.904174450905096, 55.08491946804909, 59.13456270771643, 57.83343799652592, 55.25340880117109, 55.87913667002032, 62.68277014455488, 55.006393617199315, 45.56651161563012, 45.110030097346154, 48.76708330646638, 43.72582174116566, 44.57634456696049, 46.035415280249815, 56.836540160640595, 59.40362161205661, 62.44108546164728, 56.68313626320132, 55.15024262089884, 52.20207152828094, 53.73543193263393, 59.5190961899296, 59.421362492346, 54.873907719889, 49.69534750907652, 47.68630950681625, 48.83439117862333, 49.90858324112431, 57.419800527634166, 58.890877616020944, 56.775084464780754, 49.88248771236789, 45.33517022286692, 45.967111126069106, 45.62676706621724, 55.29413084830008, 63.18804987015263, 62.55512052966703, 60.05084799182031, 58.97768359030447, 65.57390213012695, 59.172056644193596, 56.682826395957704, 51.54904396303239, 57.86518958307082, 57.6713264373041, 61.923493416078635, 63.490088062901656, 65.64888215834095, 39.70279178311748, 13.243702457797143, 6.95917800549538, 18.487432849022653, 11.510632614935599, 1.4573606824682606, 0.4136991542914222, 0.11383126564924756, 3.1104272892398224, 38.14836040619881, 50.37630234995196, 41.179242518640336, 34.981881956900324, 36.666622315683675, 51.66363208524643, 66.28010919017177, 61.955029272264056, 58.677367318061094, 10.092349648475647, 0.3501953683312862, 0.19488211931480517, 0.27489971189248946, 0.14573227764377672, 0.19047668474095483, 0.13977750685186158, 0.140308344496354, 0.14078503504635828, 0.1379325373038169, 0.0781656516295287, 0.13334515684794995, 0.19214320176791763, 0.1690247979375624, 0.22145090654732721, 0.18373193940328014, 0.10004296237903257, 0.12447503079930622, 0.2378101319435143, 0.18820520340194627], [0.09531836791504776, 0.048229260625497955, 0.11099490171839153, 0.01662912774801014, 0.09254227212119488, 0.10867570842345876, 0.05505864335704715, 0.012030079773056411, 0.10225724759361438, 0.028536108682953545, 0.07909457920299423, 0.015890204343914745, 0.06930311751221457, 0.01564518452787231, 0.05300614059031491, 0.005190657938064467, 0.04707540580702405, 0.026119536036745678, 1.3456193429808463, 39.54535961151123, 63.73537348162744, 51.372929542295395, 41.20226683155183, 22.569935744808568, 19.50983197458329, 40.1365117872915, 46.49607804513747, 19.661849314166655, 0.8544005790064413, 0.14575596508239547, 0.21384575254013463, 1.004644700836751, 2.944645372129256, 7.073797016374527, 6.1728388840152375, 17.281390313179262, 39.729408987106815, 61.13696798201531, 59.88406881209343, 59.356761055607954, 57.230667760295255, 61.14038436643539, 57.38341269954559, 55.856614420490885, 49.17116588161838, 45.92774229664957, 44.56834293180897, 45.92925240916591, 42.56262717708465, 43.70255816367365, 43.29405899970762, 49.80639765339513, 53.8380999718943, 58.76343196438205, 54.276228720142, 57.68914576499694, 54.60815929597425, 52.985466910946755, 56.431021998005534, 56.82006620591687, 55.88493785550518, 44.08833895960162, 41.11468815034436, 40.04585796786893, 39.44958317664362, 41.94816435537031, 40.44850887790803, 39.58910972841325, 40.083650004479196, 41.360110852026175, 41.59553935450893, 39.8888768688325, 40.128647435096006, 40.413580171523556, 40.76408317012172, 39.3703709110137, 42.18977451324463, 40.06583852152671, 40.249613331210234, 38.262666117760446, 44.43086777963946, 43.45709623829011, 51.31063053684851, 47.20944343074676, 55.62807360003072, 50.675096742568485, 59.669287666197754, 40.302404511359434, 24.046764989053052, 59.09260903635333, 51.45582491351713, 57.45271705812024, 52.84255927608859, 57.38164371059787, 51.839691592801, 54.142636714443086, 49.02053117752076, 44.370176945963216, 40.263573046653505, 40.977071792848655, 40.80835888462682, 41.049796458213564, 38.86885666078137, 41.848387102926935, 50.33838087512601, 53.346450482645345, 52.68033789050195, 54.28383027353595, 52.918868987791, 54.79178897796139, 54.55729007720948, 53.198918373354026, 47.30175249038204, 41.893078588670306, 40.93456506729126, 42.836102670238866, 42.245574151316, 47.27453908612652, 49.338651087976274, 49.521704181548095, 44.08932739688505, 41.892996218896684, 41.68136473624937, 41.30889646468624, 46.19682081284062, 54.100953686621885, 54.93005252653553, 56.7042778384301, 54.490711765904585, 56.012544324321134, 57.41994957770071, 55.83588861650037, 52.474436990676395, 57.10599914673836, 54.396971041156405, 57.81743472622287, 57.167768632211995, 65.47842771776261, 58.75730129980273, 32.83967556491975, 4.937639409495938, 4.007227954364592, 12.775407741146704, 2.3209990561008453, 0.09538249713518927, 0.033526918700625824, 0.6114852524572804, 11.115200827198645, 37.94788806669174, 35.28267283593455, 19.621799953522224, 23.01910988746151, 29.121851113534746, 40.54336355578515, 42.625181136592744, 51.02727067086005, 17.53214743829543, 0.098851366238969, 0.09312808423513368, 0.03109112873883738, 0.03848858673365847, 0.07444428760678538, 0.010425215587019922, 0.06077386611591905, 0.03686340781108987, 0.01223187116275151, 0.08964708029863336, 0.04256574497107537, 0.0669583292197316, 0.06159487488349119, 0.035502268752503785, 0.030525698394124067, 0.0564218508530288, 0.020226963923402855, 0.10324265116885786, 0.021219880905963724, 0.023259392736719984, 0.07774947436466333, 0.07915663232486095, 0.00849143155069361, 0.061618018399683706, 0.07135706052424447, 0.08180873678816904, 0.07918211240922252, 0.0495013534542053, 0.06239749371044098, 0.09770362863257047, 0.029673879485457178, 0.06852525481653791, 0.0290038455803428, 0.09472831933488769, 0.04466870994937997, 0.10118371326356165, 0.04275566582838374, 2.1835699917808657, 48.95578461308634, 69.57243688644903, 60.22278508832378, 47.42006686425979, 28.521181306531354, 23.849010852075395, 40.85638830738683, 47.12067627137708, 22.29818609453017, 1.0337819663747665, 0.23248117837694385, 0.22985481446789158, 2.515911190740524, 5.355074713307043, 7.534119515649735, 8.3451828072148, 15.548594055637238, 42.99511947939473, 62.519168084667584, 60.20888028606292, 58.872567992056574, 60.293254390839614, 61.9216852034292, 59.80985364606304, 56.78341557902675, 51.32293108970889, 48.04974063750237, 47.31838726228284, 47.8434867243613, 43.657890212151315, 44.72837563483946, 45.295350320877574, 51.21920401050199, 55.886032196783255, 60.303115229452814, 58.04672079701578, 57.760909449669626, 56.39218268855926, 53.34266539542906, 59.475067584745354, 59.69842303183771, 58.33150840574696, 46.27645669444915, 42.9471920382592, 40.91593380897276, 42.04332890049104, 43.58931149205854, 42.08995019235919, 40.51252980386057, 40.6082474031756, 42.28422126462383, 42.247523569291644, 41.862527247398134, 41.85987964753182, 42.125808500474506, 43.93588819811421, 41.680588106955256, 43.644016788851836, 42.398546588036325, 43.39007469915575, 41.32202463765299, 46.17594595878355, 48.58818400290705, 52.0432076915618, 49.03849955528013, 57.79409270132742, 52.89791176396032, 63.583777796837595, 41.903280673488496, 26.327313377011208, 59.805170336077296, 52.80158227489841, 58.25797965449672, 54.26353985263456, 58.28676592919135, 53.170143865769916, 56.273989908156864, 52.9766337333187, 46.41637548323601, 42.041324569332986, 43.52298813481485, 42.85170585878434, 43.27422357374623, 39.11678183463312, 43.846297341008345, 53.48182716677266, 56.29415873558291, 56.331252590302505, 56.325569075922814, 54.63709462073542, 56.55172901768839, 57.29206462060252, 54.7355539568009, 48.77723047810216, 45.5904733750128, 42.01850029730028, 43.45952418542678, 44.41562544914984, 49.03796219056653, 51.696383876185266, 53.04206671253328, 46.01017875056113, 43.137419146876184, 45.4625335047322, 42.86123721830307, 47.31238211354902, 56.73255420500233, 56.71577822777533, 58.86566069818313, 56.340721191898474, 59.46229242509412, 59.03001193077334, 57.98198992206205, 55.404514189689394, 60.04639610167473, 57.5795586647526, 61.63778405035696, 60.178905533206084, 67.38815522963002, 59.23649726375457, 32.30160482468144, 4.297820425802662, 2.4630371505214326, 8.703066725884716, 3.8848921704676846, 0.20139190548610306, 0.021742096230868372, 0.19205114864293607, 14.542903246418124, 38.08261363737045, 35.692493838648645, 26.105683772794663, 26.302643629812426, 35.949236500647764, 45.95270033805601, 49.90853225031207, 59.11337406404557, 22.822818794558128, 0.2565922789395817, 0.026345087643412334, 0.018048240510266156, 0.06535744294524193, 0.057034349639809905, 0.09964727796614171, 0.048949253039374474, 0.043523508094010815, 0.014652517481496739, 0.07234464745007216, 0.05078277723383039, 0.0639038370741952, 0.07698170870782868, 0.09621908813114129, 0.01826850419503547, 0.02711363279470994, 0.017899941209883943, 0.018972219155740835, 0.017904191082643888, 0.09708498199019702, 0.1238715143934373, 0.2655745525994609, 0.07755949222032102, 0.21468581391438363, 0.22333453289203106, 0.26580557407390687, 0.18272033562102627, 0.16238211083316034, 0.12656572304906386, 0.17670366492482925, 0.07759049579861664, 0.1739926636219025, 0.11339257306028759, 0.21520067096477558, 0.08035025093704462, 0.3126119527845614, 0.14369419265177943, 3.3667490318898237, 58.002413703549294, 77.87326258997764, 66.37694466498591, 55.13659669506935, 34.652128296513716, 30.18840239894006, 53.11443051984234, 58.663458593430065, 29.04924608046009, 1.1684875574804123, 0.41089493540986893, 0.42008826629288737, 3.0881330274766494, 9.760038602736689, 16.638837437475882, 15.543555771150897, 22.810141694161203, 43.459280998476096, 63.222025440585234, 59.85884012714509, 61.48557255345007, 62.50198810331283, 65.18212403020551, 62.621734142303474, 60.97137335808047, 54.21497306516094, 50.40368049375473, 49.65531579909786, 49.667577128256525, 46.2319613272144, 46.643155159488806, 47.553556888334214, 55.38461992817541, 58.857055018025065, 62.95129952892181, 58.185682527480594, 58.03566363550002, 57.295790872266224, 53.8936681901255, 60.748723937619125, 62.59094745882096, 60.587722409156065, 48.87480728087887, 45.10570372304609, 43.511699553458925, 43.50444709101031, 46.53856908121417, 43.92669024006013, 43.59293183972759, 43.67196367632958, 45.87757125977547, 44.94715367594073, 43.436860730571134, 45.12763761704968, 43.81600095379738, 46.863764947460545, 42.129162126971835, 47.120201664586226, 45.14738282849712, 44.34241440988357, 42.09872061206449, 48.2808074643535, 49.900052085999526, 55.94307130382907, 51.30980683911232, 60.11446099127493, 55.776813799335116, 64.55698843925231, 45.778264691752774, 29.008731918950236, 61.62788006567187, 55.93794476601386, 60.183773194589925, 56.48297771330803, 60.92988644876788, 56.02066363057783, 59.74127884834044, 52.47781415139475, 47.562088043459006, 44.57724671210013, 45.02850755568474, 44.90125410018429, 45.12880256099086, 41.39305091673329, 45.23843280730709, 55.03863550001576, 59.42974459740424, 58.19335468353764, 58.22415313413067, 56.804733660913286, 56.75278579035113, 58.8510851706228, 57.27841477240286, 52.66576236294162, 46.73861780474263, 44.69504725548529, 46.58458240570561, 46.884329934274, 53.07963517404372, 54.71522823456795, 56.437219342877796, 49.58611342214769, 45.72339465541225, 48.52181357722129, 46.96597799178093, 51.53485282774895, 58.75453210646107, 59.96874101700322, 61.05717912797005, 56.6107528440414, 61.440692793938425, 63.21793833086568, 59.84484903274044, 58.44177015366093, 61.79621642635715, 59.991922224721606, 63.63928325714604, 63.67758127950854, 69.36376679328181, 62.309529166067804, 36.55984755485289, 8.781993639084602, 10.975571313211995, 22.492725849151615, 4.078579054724786, 0.19461476995098978, 0.17140609031963736, 1.0123386750778844, 17.974529996995006, 56.0630605297704, 48.512811737675825, 29.729359572933568, 35.474731691422, 41.100034175380586, 56.0195771340401, 58.52878009119342, 66.15836666476342, 27.9646126685604, 0.3903713479878441, 0.14072310449855943, 0.14097009124534746, 0.09401911343898504, 0.2964443412999953, 0.17811348121012413, 0.1712200228845881, 0.17113204534736373, 0.1606887654070893, 0.15689042486971425, 0.13821582129645732, 0.20074777875936803, 0.13346645920988054, 0.15922297873804647, 0.07482087344772394, 0.15542748804774978, 0.08726181958111064, 0.20567418376524604, 0.15812339741856823], [0.01983417723808558, 0.09179362035807102, 0.060778091090821454, 0.05558037987699913, 0.06160912411888281, 0.05567076293030574, 0.04510559457083864, 0.02714345851282199, 0.03784539463419107, 0.03797466814097378, 0.024092009651564786, 0.05073682344969242, 0.09461801033467056, 0.036056671261547074, 0.006490365842417364, 0.04146988683890912, 0.07695437469069036, 0.1072229758926457, 6.082019834749161, 54.087350906864295, 60.02585857145248, 51.63336707699684, 33.956531247785016, 24.24686078102358, 31.53559534780441, 42.490255525035245, 41.20590286870157, 14.58640625399928, 0.14418594449037506, 0.0258830102205637, 0.05832749073423686, 1.2422967581979691, 4.848469716887321, 7.200026733260001, 5.602095290537804, 23.735222893376505, 48.82190627436484, 64.25446387260192, 59.58567450123449, 61.272199538446245, 60.546019769484005, 61.28495508624662, 54.34676078058059, 53.244437479203754, 48.21218952055901, 44.34506593212005, 41.24206319932015, 43.556143929881436, 43.49218968422183, 45.60803382627426, 46.234408886201926, 53.76087242557157, 55.79247974580335, 55.594666773273104, 55.803823240341686, 54.105338896474535, 51.88880751209875, 58.285055775796216, 54.23663631562264, 53.33742903124902, 50.01536192432527, 40.590133897719845, 40.70056822992141, 42.2532110060415, 40.08685850328015, 39.93905575044694, 40.96234329285161, 39.600370853177964, 41.90865824299474, 40.10455231512747, 41.82314665086808, 39.868645283483694, 40.858659359716604, 38.7962535888918, 41.96192402993479, 40.33355597526797, 41.25870973833146, 39.58307712308822, 43.81005856298631, 39.73339411520189, 42.212991022294574, 38.19472282163559, 41.54551736770138, 39.72488649429814, 48.596644555368734, 49.970066393575365, 60.533899645651545, 41.65607329337828, 29.471255848484656, 60.64604413124823, 50.399816959134995, 55.645939996165616, 50.03265565441501, 52.169021637209006, 51.47646050299368, 51.30504508172312, 48.12451278009723, 44.10859800154164, 40.67099355882214, 41.53273044093963, 39.69782214010916, 41.615229652773955, 39.389869013140284, 41.41751081712785, 40.84301694746941, 50.13352332576629, 51.75135981652045, 54.83041647941836, 56.28035591494653, 54.60515476042225, 53.66204830908007, 50.53668806629796, 43.08525554595455, 41.26677020903557, 41.78458975207421, 40.615817577608176, 42.33043070762388, 41.37828711540469, 42.35591042426325, 42.874275176755845, 41.157151729829856, 42.79388227770406, 41.12185824301935, 42.12592617157967, 43.002442544506444, 47.909257027410696, 54.01690906093967, 56.23447202867078, 57.879663129006666, 56.07687119514712, 57.566297131199995, 58.56691729637885, 57.81075885218959, 57.724521621581054, 58.63584902978713, 57.13463637136645, 60.73339923735588, 57.88528780783377, 61.222863966418856, 52.20362870923935, 20.970548122159897, 2.2049206783694606, 10.15044975665308, 6.132685580561239, 0.717331943733077, 0.13623146971146907, 0.06973592654591607, 2.5966946107725946, 25.94764363381171, 38.85553629167619, 20.673554097452474, 22.42481000961796, 24.68678205244003, 44.8447209788907, 47.158817398932676, 51.60297655290174, 36.2378405755566, 2.4343717338577395, 0.20403895376911088, 0.012659288852685883, 0.023397773113702575, 0.04122293839651731, 0.055125438563165166, 0.06611010900908901, 0.08813008831273164, 0.04013500544392774, 0.02943811018110043, 0.06307121058325134, 0.05326526983070278, 0.02627435857580314, 0.03959728832987528, 0.08914754500672703, 0.026832652811501777, 0.053598249946991285, 0.024266403821867802, 0.06790021900087595, 0.014703020870295024, 0.047103525064284765, 0.06666127862709184, 0.019091667584894646, 0.052209761549508384, 0.04418360775396709, 0.035033859612960974, 0.06463739690521071, 0.03498420179370911, 0.04955792138653417, 0.04521290050639261, 0.027150439489031994, 0.004850360724489175, 0.01667419478537575, 0.07753631039973229, 0.0544429499836218, 0.05840835514508429, 0.18997296660898194, 8.900273692223335, 64.1537570184277, 65.41854489234187, 58.10541906664449, 40.225023992599986, 32.75017688351293, 28.909211581753148, 42.067051395293205, 46.72233996852752, 15.884862772880064, 0.11810324004580898, 0.08339279211096226, 0.05094553261334377, 3.6327803567532575, 10.500476187275304, 7.573675638244999, 5.023419683979404, 26.464804218661403, 52.994535430785156, 64.33194637298584, 60.24044359883955, 60.75771401005407, 62.872130409363784, 64.73607993895008, 56.206368246386134, 54.976850325061434, 49.25390043566304, 46.45111983822238, 43.492801573968705, 45.71326709562733, 44.61926706375615, 46.64602633445494, 48.386860509072584, 54.61307402580015, 58.484182742334184, 57.19290710264637, 55.678707476585146, 54.69858169555665, 53.266489044312515, 58.63493119516681, 56.59229809238065, 57.09398492690056, 53.688571376185266, 43.956190386126124, 41.97517771874705, 43.975590428998395, 41.91766400491038, 42.0552921295166, 43.57097441150297, 42.613731738059755, 42.73917698091076, 41.79131269454956, 43.78079375913067, 41.7748858082679, 41.88936410411712, 41.85675744087466, 42.7308694008858, 41.28795493033625, 42.4316043238486, 41.95931957614037, 44.83047493042485, 41.774238617189475, 42.88784657755206, 41.41656552591632, 42.84361008674868, 42.72899450794343, 51.82699880292339, 51.80300566457933, 62.81321248700542, 43.99844607999248, 30.306320613430394, 63.866941544317434, 53.801100254058845, 56.550681744852376, 52.705990191428896, 54.74313197597381, 52.62060411514775, 54.663288208746145, 51.107216419712195, 47.16520693994338, 40.77854494894705, 44.69660051407353, 41.41453373816706, 43.622714396445986, 40.46901895153908, 42.690606271066976, 42.49647248175837, 52.72305642404864, 54.519772606511275, 57.45581573055637, 58.385821465523016, 57.293884600362475, 56.35299036579748, 53.03387288124331, 45.95983512939946, 42.86125683015393, 43.287383125674346, 43.35900560502083, 44.55647383966754, 44.71646339662614, 45.5993850000443, 44.950589672211684, 43.192987365107385, 45.50160815638881, 41.52542698767878, 45.422035032703036, 43.99370001208398, 49.20388237122567, 56.93820407313686, 58.21215068140338, 57.896529320747625, 57.45376825332642, 58.24011325836182, 59.7118571496779, 59.63238208524643, 61.059344276305175, 60.82024835771131, 61.033185989626, 63.838237639396425, 61.53122109751548, 62.411306827299065, 56.966845220135106, 21.900585236087924, 2.9913120164025218, 5.638826816312728, 6.616341279399011, 0.7193585833714855, 0.1568690816601438, 0.01112744337954228, 3.548218223356432, 33.341982133926884, 35.79249466619184, 27.91310606464263, 24.13687163783658, 26.102579216803274, 50.90063694984683, 55.62599866620956, 57.82118058973744, 46.293550383660104, 3.651061543533879, 0.17529113668828242, 0.10126369284285654, 0.00910598249550188, 0.038193554782699195, 0.009167607565740905, 0.019793706728265654, 0.053420153656794186, 0.027050449693154906, 0.03421013123325763, 0.015478439745493235, 0.005409831862761489, 0.01406417919262763, 0.031672440086221026, 0.041443652157942136, 0.011083071566967955, 0.031329768957690365, 0.025796729568091613, 0.003916675266208909, 0.13298549388925876, 0.2365548049490298, 0.15392990872984932, 0.11159170719404375, 0.25749787147487363, 0.17980167852534404, 0.11951502517706926, 0.14812572018033074, 0.06008506880231923, 0.12934432395042914, 0.08126811620088355, 0.12128041351153968, 0.15094976541736435, 0.13308418133566458, 0.2653578110039234, 0.17843287858751514, 0.19213131208333278, 0.34417878956564013, 12.394362226609262, 72.07160642070156, 74.4191998820151, 66.30051335980816, 45.82772577962568, 37.01731751042028, 43.426693947084495, 54.3326049466287, 54.12980271923927, 20.786320278721472, 0.21678915427577114, 0.2242869946865305, 0.19678163432305862, 2.8866344978732448, 12.94772824933452, 16.119953951527997, 14.007370279681298, 27.688852394780806, 51.84624979572912, 66.17530345916748, 62.063651469446, 63.574579838783514, 64.8073729392021, 66.43280706098004, 59.03471877498012, 57.29428468212005, 52.03481381939304, 48.118935169712195, 45.08173804129324, 48.72265854189473, 46.637063718611195, 49.32353819570234, 50.58038327001756, 57.565175333330714, 60.93645249643634, 59.02703877418273, 54.94574592959497, 54.95579111960627, 54.29364796607725, 62.0940145369499, 58.0567071514745, 58.93558086887483, 55.44794659460745, 45.882572281745176, 43.74415097698089, 46.09336045480544, 43.374396985577, 44.233454888866795, 45.2561423086351, 44.1110534052695, 45.319602335653, 44.068330949352635, 46.300751855296475, 43.33882501048427, 44.188100522564305, 45.427867597149266, 45.9238983738807, 45.1182984536694, 45.90972685044812, 43.6728972004306, 48.366887800155155, 44.90187775704169, 46.234730520556056, 42.05932040368357, 44.57679563953031, 45.1210323456795, 52.52377648507395, 54.088064778235655, 64.58729267120361, 45.17595337283227, 33.631955116025864, 65.26815337519493, 55.28060259357576, 60.04758457983694, 55.959874737647276, 57.4396594878166, 55.03120653090939, 56.717394244286325, 52.53724590424569, 48.35744665515039, 43.74878329615439, 46.57517263966222, 44.34412064090852, 45.77446783742597, 42.54350170012444, 45.10422498949113, 44.92215248846239, 55.12548854274135, 56.54497077388149, 59.42839530206496, 62.19673748939269, 59.717815229969645, 59.0973747161127, 55.86254504419143, 47.775476747943515, 45.1460962910806, 45.87587287349086, 45.69149794117097, 46.92942150177495, 46.80082659567557, 48.73382552977532, 46.36813033011652, 46.36216048271426, 48.04292355814288, 44.13127322350779, 48.24488247594526, 47.06986196579472, 51.44071202124319, 59.86473152714392, 61.49655518993255, 60.679360743491884, 59.456973691140455, 62.89268362906672, 63.10782955538843, 64.50673111023443, 64.69292209994408, 64.59580421447754, 63.231580334324995, 65.43969038994082, 62.36767830387239, 66.27598285675049, 56.055576647481615, 28.065011616676088, 6.6530453485827294, 21.107542783983295, 13.579597569281056, 0.9512723357446733, 0.2619131119741548, 0.18188556025345481, 6.13064447718282, 42.86902704546529, 51.629240743575565, 29.777967545293993, 31.74149036407471, 36.6664340419154, 59.03117295234435, 62.43417424540367, 65.29212297931795, 54.441992005994244, 5.324714097284502, 0.40238425015441837, 0.25561280488487215, 0.12380387649060258, 0.1388135843820149, 0.20000482669040082, 0.15736700816740914, 0.12391548017941176, 0.22419308762877221, 0.11209374759346248, 0.08581999614233933, 0.08929107924022021, 0.08255512093103702, 0.24379185370860562, 0.10095841446591002, 0.09727075065095579, 0.21024809639540412, 0.117106115325324, 0.12301174923777582], [0.06006962830020536, 0.04346687504420838, 0.02490678054821347, 0.05614216364319286, 0.024195624958543528, 0.053249879124303984, 0.026610966118413116, 0.009148458240463609, 0.10702614492226033, 0.027405987268373854, 0.03717783327785231, 0.008522530889979774, 0.02295529988083628, 0.01774145677054842, 0.05873558577150107, 0.05729784175092655, 0.06740328074703295, 0.04323369703225551, 16.955257000461703, 48.88538983560378, 54.70245307491672, 47.496125544271166, 35.98764042700491, 14.733167617551743, 39.093655540097146, 48.10039804827783, 34.83500880579795, 6.025487694048113, 0.03771635095378564, 0.05069104969621666, 0.27760387969113165, 1.995894875257246, 3.990751057863236, 4.163461106438791, 8.055304942592498, 40.38939875941123, 60.67865471686087, 65.43645051217848, 58.95837376194616, 62.66766117465112, 58.062331830301595, 59.49225541084044, 54.35690795221637, 52.83277296250867, 46.35248007312898, 42.95602521588726, 43.62391856408889, 42.910141329611506, 39.74167031626548, 42.71308145215435, 46.46182006405246, 56.84412602455386, 55.643837605753255, 57.688777062200735, 55.181711796791326, 50.489701994003795, 56.1188405559909, 53.946314242578325, 53.238161686928045, 50.60001473273001, 44.47368437244047, 42.58312940597535, 40.50231595193186, 40.35297562999111, 40.76334184215915, 38.90780579659247, 43.58093330937047, 41.15656337430401, 40.412827076450476, 38.41391663397513, 40.4760713731089, 38.39397530401907, 38.64171612647272, 40.15817111538303, 39.99973873938284, 38.99190141308693, 44.43566876073038, 48.82554231151458, 51.09264481452204, 49.35997701460316, 50.75819999940934, 48.112820194613555, 47.84558519240349, 44.12161634814355, 50.242996677275634, 49.470023032157656, 59.81922811077487, 37.17708741464923, 27.37376839883866, 64.75422090099704, 50.71775251819242, 53.062784671783454, 45.73049414542414, 52.50343507336032, 47.86559320265248, 49.81293232210221, 46.724312920724195, 43.89235773394185, 40.6972106810539, 43.62928044411444, 40.63400168572703, 41.60705543333485, 39.57655814386184, 40.35869052333217, 39.06681868337816, 40.500703857791045, 43.709732178718816, 49.346758627122455, 49.8935801752152, 52.10709917929865, 46.1150864631899, 42.97767277686827, 39.266816416094386, 39.367295772798606, 40.61987330836635, 40.345154423867505, 40.37629019829535, 41.06989468297651, 40.66580818545434, 41.08858085447743, 41.893082511040475, 41.4697136417512, 41.568235735739435, 44.907910362366714, 48.1948055759553, 51.86848571223598, 55.895108561361994, 55.9952780508226, 54.154599943468654, 49.44986597184212, 52.674807348558986, 56.966272554089954, 56.17116105171942, 59.24937048266011, 58.879463518819506, 60.429709726764315, 58.1126283830212, 64.89113907660207, 60.519029940328295, 62.69305067677652, 40.274806714827015, 8.935496576370733, 3.535910806348247, 5.1753453381599925, 1.2645037472248077, 0.0051701636496751064, 0.10402659660265332, 0.9598814479766354, 18.55057908642677, 36.737577992100874, 32.733520538576194, 23.936356152257613, 26.41678656301191, 41.99608002939532, 51.51637846423734, 45.249136955507346, 41.134511809195246, 10.554322485000858, 0.12279138404635653, 0.01661568482015883, 0.05601586255755636, 0.013276382251792859, 0.029613023375972148, 0.029314233763744275, 0.06595188120920813, 0.07562752572759505, 0.03855601779275364, 0.015198696994282787, 0.0581821715158801, 0.042495383625669826, 0.05198521351802254, 0.041559852374297, 0.07382714249674352, 0.04997789078662473, 0.06878820683566794, 0.015635536608075904, 0.10711663522787633, 0.029821142651921803, 0.018152821088029493, 0.005594398244284094, 0.041862031925589814, 0.030435734773956002, 0.029290155620284142, 0.009345683746129997, 0.03773177613414103, 0.04134204591654482, 0.06868057148230654, 0.018428549538516713, 0.04181124795708926, 0.021893911874823032, 0.02148208598936758, 0.06433024927372895, 0.03627442792358418, 0.16346393423455377, 23.939980422296834, 58.06459896026119, 63.612564071532226, 54.51956472089214, 41.344943046569824, 18.439254376196093, 37.85683416551159, 52.84649341337143, 38.15358892563851, 7.091167232682628, 0.2049760938051247, 0.06878999948141075, 0.5732274956760869, 4.954529625754203, 5.281257177552869, 5.02989649772644, 8.765141175639245, 39.49624369221349, 60.95212236527474, 66.10605009140508, 60.45633869786417, 62.785304823229396, 60.173963346788966, 61.97204843644173, 57.78099590732206, 55.096353177101385, 48.70313298317694, 45.675498593238096, 43.560403623888575, 44.76032333989298, 42.56857741263605, 43.931483376410704, 49.88206017401911, 60.32433132971487, 59.00299072265626, 58.765314702064764, 54.8342368679662, 50.25539136702015, 56.056168925377634, 56.510626500652684, 55.33339377372496, 52.56640872647686, 46.776280403137214, 45.15448231850901, 42.08078361326649, 42.48022210213446, 43.02576887992121, 40.59264421463013, 44.89543722521874, 43.520152261180264, 41.51475814081008, 39.643634596178615, 42.763276023249475, 41.134158795879735, 41.17401399920064, 40.73057436173962, 42.27315625836773, 40.859871372099846, 45.12408002730339, 50.02538750248571, 53.44640816411665, 50.75524645466959, 54.0609258990134, 48.92343290390507, 49.9575932564274, 47.14790144274312, 52.90861983453074, 51.642486587647475, 63.00117638803298, 39.718551866469845, 29.09322173364701, 65.22927091967675, 53.13708612995764, 56.1335337546564, 49.26884074364939, 54.03675625401159, 49.177265167236335, 52.01189933284637, 48.6908834211288, 46.684951936045, 41.34244841914023, 45.77977872663929, 42.04314847146311, 42.45364019947667, 41.45850743016889, 42.707809786642756, 40.510258751530806, 43.28615934618058, 46.13859322763259, 53.294106452695786, 52.32424551440824, 56.109191525367, 50.20692656117101, 46.39768931173509, 41.11615903915898, 41.47431458196333, 42.43021188243743, 43.674473993239864, 42.13453969647808, 43.02492557033416, 44.51648919813095, 43.560780171425115, 42.714799450289824, 43.53457873867404, 43.97952456628123, 46.351523014806936, 51.349497302885986, 54.45673619547198, 58.75466546704693, 58.702019414594105, 55.57506668952204, 51.51382892362533, 55.86484747548258, 58.048015179172644, 59.713857558465776, 58.956000727991906, 60.48056325604839, 60.51385633407101, 60.270971405890684, 63.46018391270792, 63.95400639503234, 63.704131803204945, 45.40605921899119, 9.377950718325954, 5.011737394717432, 3.597776144742966, 2.6591090809914375, 0.06927675642674008, 0.1156513526615116, 1.0858564559490451, 23.290737944264567, 38.78358041086505, 40.56104952289213, 27.16066210500656, 28.583468544867735, 50.79316792949554, 55.75266768855434, 53.30388492153537, 50.793442495407604, 14.948562614379393, 0.16227913329437857, 0.06209218085953786, 0.03401035465480339, 0.06184479574702921, 0.037258456371003584, 0.023916707667071494, 0.06334965290021032, 0.021328205738456982, 0.015350301964058271, 0.017239519792999473, 0.12463898127598148, 0.053718583207697644, 0.018224992316156145, 0.006789194716651354, 0.03543089234059857, 0.05585609109050805, 0.03385057935731546, 0.036054809667891076, 0.20113894325350562, 0.19140283907613448, 0.1644875196319434, 0.10687659689856153, 0.16511785677604138, 0.16920706557650722, 0.16874994091208906, 0.1330303866416216, 0.2574186273399861, 0.21977427715976394, 0.2446663583959303, 0.21986605449309274, 0.16265382689814414, 0.09765750247864954, 0.22455017653203782, 0.16249541523716143, 0.20645936260059958, 0.28731971318202637, 29.839466387225738, 67.31549724455803, 70.0835060304211, 62.57284179810555, 48.46429986338462, 22.429895362546368, 52.13830163401943, 58.911501438386985, 46.23868034731957, 8.2855196345237, 0.34857264089007534, 0.22151125895400203, 1.07344938622367, 5.740379431555349, 13.727480730702801, 12.031735181808473, 16.112848577960847, 45.38731421193769, 62.42688255925333, 68.90470827779463, 61.56458870057137, 66.63724883910149, 60.55893613446144, 63.37633932790449, 59.02980012278403, 57.045892746217795, 50.892015580208074, 47.5169062614441, 47.02738269682854, 48.00955595508699, 43.59496754984702, 46.115961151738325, 51.38800713323778, 62.1032674081864, 60.90681506741432, 58.732861011259025, 53.88878876163114, 52.54739307588147, 59.115472532087765, 58.95567124889743, 57.21495474538496, 55.4984353434655, 48.79146868182767, 47.68337949629753, 43.39779784602504, 44.72854821912704, 45.07231650813934, 42.9879689985706, 46.996941181921194, 45.30739591967675, 43.93165203832811, 42.114578754671165, 44.22275466303672, 43.16604068202358, 41.79667849694529, 44.14449945572884, 43.73837332571707, 43.70329164689587, 48.73358234282463, 52.9943157780555, 57.30824439756332, 54.07778424601401, 57.1766371111716, 53.262068533128314, 53.28771298931491, 50.741843715790786, 54.40323506632159, 54.57677641222554, 64.17234905304448, 40.986916941981164, 32.484763822247906, 67.26773062059956, 57.062135281101355, 59.9368796040935, 50.64337653498496, 56.70301091286444, 50.377726170324514, 54.68403362458753, 50.989855181786325, 50.142305512582105, 44.691191565605905, 47.74689051412767, 43.6884258639428, 45.60881045556838, 43.12821334408176, 45.21807962848295, 43.88710568028112, 45.588500422816125, 48.43569794008809, 54.87637881309756, 53.941658389183786, 59.2260088459138, 51.67388123850669, 47.96032628705425, 42.4882786504684, 42.91484425144811, 46.263454037327925, 45.08619777617916, 43.31098402700117, 44.91961863733108, 46.50530738215293, 45.5782748037769, 46.945240420679895, 46.38838152731619, 44.72552799409436, 50.68422409795946, 54.58828856868129, 57.86988466016708, 60.11784599673364, 62.20331530417166, 57.27622216747653, 54.9424550610204, 56.054309721915956, 59.67193526606406, 60.6459068482922, 61.11383776510916, 61.03940686871929, 63.671058377911976, 62.15951419645741, 67.02931327204551, 65.94477007465979, 69.36362558795561, 45.08862572331583, 12.426230503666787, 8.763898764887164, 11.935541014517508, 2.33238275493345, 0.22263325600614473, 0.24610379981177471, 1.1732859645159015, 29.453232557542865, 51.48623112709292, 43.7648924704521, 33.51322889328003, 37.9460092513792, 55.08913601598432, 67.31537957345286, 59.53121631376205, 60.61338255482336, 18.051624182731874, 0.262393050736958, 0.16696673337249987, 0.11644012444923002, 0.07090061767807893, 0.0973204697572416, 0.09537920295711487, 0.1252352504900867, 0.22154530390135704, 0.11442594140047029, 0.10207992122178117, 0.26631912877482755, 0.15779131362515111, 0.1025915377202534, 0.22582779668511885, 0.19030828329343952, 0.21696256593831126, 0.15570936243860953, 0.17369103948435477], [0.038753622511942545, 0.008038775094093816, 0.07873504647925016, 0.023185737213240038, 0.04960731107501253, 0.08153214840398681, 0.04319914263643084, 0.010928480769507589, 0.012504157005628992, 0.020730210911302317, 0.04335923586040736, 0.011740545460563755, 0.022381383197141752, 0.02594828282693221, 0.015113750292408853, 0.04990278352652827, 0.054528008725854664, 0.6208975312690581, 31.322787154105406, 56.71312670553885, 53.449549982624674, 45.63020306248819, 31.69092316781321, 25.662087240526755, 42.87695807795371, 36.103805342028224, 32.58378601843311, 2.3368361159678432, 0.04697438562288881, 0.059150613904480016, 0.07288044934431392, 5.716044556710028, 9.483895897865295, 3.7487292962689556, 11.039665783605269, 56.291424843572806, 61.80111546670238, 62.60708408970987, 61.094931940878595, 60.52634516069966, 58.592094990514944, 56.35441418617003, 52.32934067326208, 48.51949545644945, 43.135367747276064, 42.192916331752656, 44.083753708870184, 43.033707757149976, 39.91261505311535, 41.292504879736136, 47.32204291128343, 57.26874220755793, 54.46687159999725, 54.86633754545643, 51.9615831682759, 52.344312360209805, 54.32365802026565, 54.68020146892917, 49.73353178270402, 43.75131714728571, 42.430725712930005, 42.13959955400036, 44.454378466452326, 41.130738489089474, 41.55990854386361, 38.31673206821565, 40.02068811847318, 39.778685723581624, 39.95831458799301, 40.20594950645201, 41.21926246150848, 39.67833580509309, 41.154127582426995, 39.779058348747995, 39.72443149935815, 41.37928339742845, 53.37867275361092, 54.43926595872449, 56.59376898119527, 54.48211393048687, 54.71006639542119, 51.136438077495946, 54.89051895756876, 51.10534152676983, 53.70378625008368, 48.41772563995854, 61.64763312185965, 35.11886289042812, 30.78067441140452, 61.7993700119757, 49.20933054339502, 54.329208174059474, 45.53509735292005, 48.75360996492448, 44.41292293610112, 48.216668867295795, 41.96793310103878, 43.619902057032434, 39.71529237685665, 41.785754696015395, 41.853933334350586, 41.828422238749845, 41.07073014782321, 42.01537809064312, 39.69908514330464, 40.66084638718636, 38.0655199481595, 40.62991849837765, 40.79224578795895, 41.441672617389315, 38.87359096157936, 39.31664620676349, 39.48593178103047, 40.31223789338143, 38.517074969507036, 40.18025405945317, 41.638606979000954, 44.017253844968735, 40.041221726325254, 40.68661243684831, 39.733684370594645, 42.05481360035558, 39.18258743901407, 45.71676192745086, 51.33208590169107, 55.417724732429754, 55.943259577597345, 54.22078209538614, 49.6999837506202, 51.07426066552439, 51.013918922793486, 49.750852969384965, 50.23473616569273, 55.314927254953695, 59.11839469786614, 59.191723408237586, 59.79822381850212, 56.96701780442269, 57.3936971541374, 55.96302440089565, 46.974920995773815, 15.942560838114833, 2.7592530750459243, 2.483991432574488, 2.585961535092323, 0.04584685741593281, 0.016700211131284316, 0.08087197979611736, 9.84307223750699, 32.4132433245259, 28.924169540405277, 27.030521785059285, 19.018621790793635, 29.98554525836822, 45.817802183089725, 42.507866967108946, 47.70062223557503, 16.975588606249904, 0.44426069985474315, 0.03749358407672375, 0.06405691293278529, 0.03870270064761562, 0.02769334876399127, 0.03313672713815205, 0.004585847322408471, 0.03516708996387259, 0.0717806228766999, 0.032534800364726016, 0.04020855754553791, 0.021057876292616132, 0.05537303818029262, 0.1430430638814165, 0.05360908243024061, 0.023664697298720002, 0.052957245028547706, 0.002540466779347269, 0.07012801800644206, 0.036612544659404986, 0.024601226379614205, 0.06092841286332377, 0.028737055460712122, 0.031830861323302796, 0.03773661397938286, 0.04832310639622231, 0.025293310210409186, 0.021288713905960325, 0.05358346445005267, 0.026755094070047624, 0.03722448803244099, 0.02070407965220511, 0.05301020851719284, 0.03364027290034198, 0.054051823793880405, 0.6665721223238976, 39.476820115120184, 63.48924867568478, 60.281808914676795, 53.21663964179255, 39.488351883426795, 27.07440330136207, 43.026612189508256, 40.76285939062796, 35.38504277506183, 2.243420457647693, 0.027735236536471114, 0.059736491135892376, 0.9461000165151012, 14.373654934667773, 8.684361923125483, 5.6688505987967215, 12.953942264280013, 56.51563928973291, 63.74047256285145, 62.907196398704286, 62.435433326228974, 63.12386028228268, 61.75277617669875, 58.46245281157955, 53.762590423707046, 51.3622606954267, 45.34741194017472, 43.5682915103051, 46.162311800064586, 44.48533381185224, 41.842754579359486, 43.56453387968002, 50.002802495033514, 59.73317130919426, 56.96766891787129, 57.13160437922324, 53.4060783540049, 51.93550725137034, 57.917443398506414, 56.87922339285574, 52.3085952574207, 47.721956006942264, 45.8085532342234, 43.22393878813713, 46.048394403150006, 41.172401905059814, 43.85439703541417, 40.89787129432925, 41.886649823957875, 40.860812740941206, 42.36522213105233, 41.35736911527572, 42.16857018009309, 40.898326289269235, 41.89493386976181, 41.22967635431598, 41.29031619717998, 43.181220254590436, 53.10294189760762, 55.31218551820325, 58.411085451802904, 56.790468000596576, 57.24652198053176, 54.08836287836875, 57.31936431700184, 52.524659018362726, 56.52437440810665, 51.001320269800004, 64.82258781310051, 36.90189000098936, 32.52820407190631, 63.389432199539684, 50.735038403541814, 55.72241444741526, 46.79149527703562, 50.34442916993172, 46.592132968287316, 49.73455159894882, 43.85650727056688, 42.97457018206197, 42.72800214828984, 43.01820655022898, 43.98070912207327, 43.51579058554865, 42.577238005976525, 42.912498674085064, 42.15069593921785, 42.5475025177002, 40.346848887781945, 41.93994306748913, 42.306570929865686, 44.632002999705655, 40.391203049690496, 42.263675889661236, 41.32790819291146, 42.24295008567072, 40.41205436952653, 41.5948058712867, 42.13739125959335, 44.90701213959725, 43.4251210766454, 42.11751660993023, 43.448357197546194, 42.80007570020614, 41.21750523967128, 47.774621671245946, 54.087390130566014, 57.940048017809474, 59.25950980955555, 54.808302156386844, 52.45280904154624, 53.102165268313506, 51.1318685162452, 50.72374589981572, 51.50804342762117, 54.77126321484966, 60.0738017020687, 60.844445459304325, 61.15366551183886, 58.92887361588017, 58.94454740708875, 58.167212086339156, 51.26498199278309, 16.780127094637965, 4.811467057274235, 4.2634972353135385, 3.8409133303549985, 0.28930228744303027, 0.02884095038978323, 0.07108632505180375, 13.29588665116218, 37.50062804068289, 27.943869213904104, 34.419688640102265, 22.756079666076168, 39.98792063805365, 52.09565370313583, 48.91181876582485, 56.44456594221054, 23.57023427563329, 0.5566512528927096, 0.06557802264128001, 0.08786876040000109, 0.04482526767758593, 0.018414878699507926, 0.05552287731740264, 0.008979845161159194, 0.05229318469402291, 0.01984927874629296, 0.055559553776777564, 0.03726079293917264, 0.02710547587353616, 0.0368097931477091, 0.05860857605453461, 0.016632808800486308, 0.04019832261086952, 0.05212648396169947, 0.06352000787193257, 0.2218223979035693, 0.23342507530844983, 0.21791743324889293, 0.12048336031335978, 0.10263555713238255, 0.09818798772269681, 0.147351956055049, 0.07553037045703781, 0.07698868776881888, 0.20536872918807692, 0.09025821927934886, 0.12414096283816523, 0.15242908119914994, 0.13777961083237203, 0.10104967852032955, 0.16644478234792912, 0.1668714013912024, 1.603512240032996, 49.13033793049474, 72.90846763118621, 68.2761327682003, 59.03692706938713, 42.65809374470865, 36.65077594018752, 55.55883984411917, 46.849036447463504, 43.90508974752119, 3.1271368313220242, 0.24165551027944013, 0.3289161730677851, 0.35526671717243813, 11.897971572414523, 22.395864878931356, 11.53790093237354, 15.63941751756976, 60.07417432723507, 64.73449530140047, 66.75716354000953, 64.92048232786118, 63.85059310543922, 62.938077219070934, 60.17436342854654, 56.126838268772254, 53.20336634112943, 49.15968510412401, 44.60646052514353, 47.32614963285385, 47.56356285464379, 43.04934232465683, 45.423945226976954, 51.88730916669292, 61.88805480157176, 58.80079646264353, 57.33056660621398, 54.898053830669774, 53.1090372608554, 58.51748758746732, 59.273877451496745, 52.76529250606414, 48.73958356918828, 47.58147239685059, 45.83810044873146, 49.032768972458385, 44.55230436017437, 46.30933792360368, 41.61243692521126, 43.73831841253465, 41.91324349372618, 43.651332009223204, 44.026683222862985, 44.48683607962824, 43.23645114898682, 44.8537463526572, 42.70324414776218, 42.831646857723115, 47.25095387428038, 57.115652099732436, 58.888877207233065, 60.631115590372396, 59.14245059413295, 59.146027795730106, 54.974802847831484, 60.55738679824337, 54.89298220603697, 58.695743622318396, 53.37890417345109, 66.80964485291513, 39.60959234545308, 35.74084881813296, 64.15750288194226, 53.818444974960826, 57.91374460343392, 50.12118354920418, 52.527961654047814, 50.0267485649355, 53.722088029307706, 46.29182454078428, 47.39023723909932, 43.954676351239605, 45.7875842432822, 46.219009660905414, 45.09401505993259, 45.61822414398194, 46.32139136714321, 44.420755909335234, 44.78270046172604, 42.1770699562565, 45.08096141199912, 43.206127305184644, 46.53741198201334, 41.914063269092196, 44.977814843577725, 42.951396819083925, 44.67137967386554, 42.76312305081276, 44.26746576063095, 45.21241180358395, 47.93677245416949, 45.355127242303666, 43.52698503002044, 44.51815620545418, 46.52388372728902, 43.05425313211257, 50.536393888535045, 57.3066048468313, 60.65922329502722, 61.64039634889173, 57.19521737867787, 53.15022214766472, 53.01765388058078, 50.58601971595518, 51.423277085827245, 51.21575232475035, 56.95490552533058, 63.364795792487364, 65.91239483125749, 65.63385948058098, 61.87382052021643, 60.86791300004529, 60.227036937590576, 54.27591100815804, 21.06823475130143, 5.985604543839732, 9.390064958603153, 7.827841303040905, 0.4272954989104502, 0.12446548534376968, 0.19424497930993959, 15.297373110248198, 49.14952224300754, 40.78612689049014, 37.81542962597263, 29.062892006289577, 43.84764663634762, 58.32100429842549, 58.03531454455469, 66.38551112144225, 32.066086107684725, 1.0766749228200605, 0.2017804806030566, 0.1723936695845858, 0.11917574781804316, 0.14142652643063378, 0.15365168091750916, 0.1257855544287351, 0.15389696694910526, 0.16175865315862242, 0.2053750264308145, 0.08972642402495108, 0.12516485467072458, 0.1451356177248301, 0.198486884755473, 0.16316958793228672, 0.18878548436107176, 0.14285092903000696, 0.09460212933200021], [0.06100546981718752, 0.06427619410979171, 0.024216320823817968, 0.025170144339602803, 0.018618234823788368, 0.06570173051929282, 0.05281423939572227, 0.0402735754276716, 0.0236748268962988, 0.05829894246773855, 0.02462659155078713, 0.05057199580234386, 0.006268115595899403, 0.03498640429649142, 0.09181040534449202, 0.04717972783011295, 0.09412123295929163, 2.7902081752977064, 42.53073046284337, 60.63558709236884, 43.11291217803956, 28.83674579281961, 15.524286147086853, 20.395326652834495, 37.440384357206284, 39.41374840274934, 22.893866646674372, 0.2693263303127981, 0.03013183535527318, 0.028224213221561045, 2.7761624128587785, 9.40696252930549, 2.137466697923599, 2.6530602958894547, 25.052023356960667, 59.45527138248567, 61.29834213564473, 56.44870012037216, 58.53127079625284, 56.20971010577295, 55.86311771023659, 49.077538905605195, 45.105268339956964, 42.340264089645885, 45.189254130086596, 43.64279300935807, 44.72225281500047, 41.45418105586883, 42.57322149892008, 38.43601526752595, 45.929778006769, 53.686131661938084, 59.190601610368304, 55.47982369699786, 55.47887056104599, 50.69978806280321, 53.68672786220428, 54.97567753637991, 54.0467151518791, 45.551147691665165, 42.70023961221018, 41.37070909623177, 42.11653601738715, 39.72954627006285, 40.37595287446053, 38.91720379552534, 40.30027466435587, 41.259651107172814, 40.63399776335686, 38.850409753860966, 43.48871054187898, 39.47578068702452, 42.35699299843081, 38.93856502348377, 38.99261920682846, 47.35952115827992, 54.36314452079035, 54.35579399908743, 53.68491964955484, 50.3523523576798, 57.55192164451846, 52.28315868685323, 56.563892287592736, 52.91442494238577, 58.461558511180264, 48.93078342560799, 62.95085237872217, 30.304492788930094, 29.22264425985275, 62.747120549601895, 48.478298802529615, 55.06125973116968, 42.180721682886926, 45.85286032768988, 41.04312058418028, 42.46311272344282, 38.42682123184204, 41.724322534376576, 42.99693945915469, 41.04606236180952, 40.373093466604914, 42.62860928812335, 39.48684177091045, 41.59257796502883, 38.757508416329664, 39.08489688750237, 40.31150833252938, 40.61124801635742, 39.59216133240731, 40.80976701551869, 39.620688730670565, 39.83099445219963, 37.92173370238274, 38.20897279247161, 38.51010099534066, 40.391760026254964, 40.704714175193544, 43.836083489079634, 43.16226343954764, 45.286740718349336, 44.53007236603768, 41.23056280997492, 43.14398911691482, 47.22212053114369, 54.30763121574156, 52.57242564232119, 53.08482839215187, 52.897111600445164, 56.87189640537385, 56.212855846651145, 54.30038267566312, 54.73571477397796, 58.252755057427194, 57.98441786919871, 59.63353133970692, 54.626025692109145, 53.76442217057752, 56.017000136836884, 61.938665143905155, 53.20643363460418, 57.09098431371874, 18.967274042867846, 6.022587101305685, 1.7572798147316904, 2.942643737600696, 0.4936272218342751, 0.04625258907195061, 0.08885416397524458, 3.261862156852599, 28.434755802154545, 48.413010951011415, 21.705423785794167, 18.43424943185622, 45.1396361474068, 38.140350926306944, 47.368244509543146, 40.379365336510446, 33.375726284519324, 3.9306475991202943, 0.12476882551826778, 0.02063517004341608, 0.08213230934474738, 0.02592764058781247, 0.039874677275938374, 0.0268209335814801, 0.0726886056063156, 0.10316742133469352, 0.010104593426559963, 0.13260742949862636, 0.03837840413794883, 0.06325693710917427, 0.045299889790194656, 0.020450753527843667, 0.03707533071358358, 0.017850021005518014, 0.018261232105414235, 0.08532963858376588, 0.051465177713262464, 0.02366527377988302, 0.018724422270972884, 0.07101690216410546, 0.015931850798698445, 0.039577255130655346, 0.07597505385356565, 0.04641015803621662, 0.07446042907934997, 0.025567364758781852, 0.030799570996614716, 0.07288567406395752, 0.055971509897180145, 0.08735286147003213, 0.09115336237535362, 0.17569337881380515, 4.554199778264569, 53.36835299768756, 65.396081478365, 50.17156639406758, 34.888498167837824, 22.19996210067503, 23.294997638271703, 40.47722062756939, 41.56585877941501, 25.597644659780688, 0.15411272795209963, 0.009331853943876922, 0.03327849553897977, 2.6367201920478576, 10.057446437497294, 10.854539717397383, 3.567693526706388, 25.81992929981601, 64.18378668446695, 62.88117539498114, 59.03129454581969, 59.587918096973056, 59.592538649036044, 57.36755847930909, 52.28930896328342, 46.701673000089585, 43.795130022110484, 47.17987268201767, 45.9656951504369, 46.32026956927392, 42.647550413685465, 44.57769386229977, 40.87715333507907, 47.79599074394473, 56.66511297225953, 58.999142877517215, 57.304278881319114, 55.178181663636245, 52.0706368261768, 55.74341481731784, 57.639108088708696, 55.03189686805972, 47.03007344276675, 45.06284006180302, 45.05470898843581, 43.05706939389629, 41.39563575867684, 41.86277827908916, 41.519461062646684, 41.37218782978673, 41.11630808922553, 40.68467870835335, 41.64096432347452, 44.03837580834666, 40.60472119239069, 42.05425270142094, 41.1562809636516, 40.56385401756533, 48.05007796133719, 56.97113237073345, 54.28646610629175, 56.5576635637591, 53.60462480975736, 58.454443331687685, 54.25824073053176, 58.65859485441639, 55.47900392163185, 59.500527689533854, 50.497531044867735, 64.53284232847153, 30.91398008408085, 30.770256596226847, 64.47160628534132, 49.956232193977606, 56.09800492563556, 45.188261770433, 49.155982386681345, 43.78288830480268, 43.92888676735663, 41.245122648054554, 43.72589234382876, 44.28636374012117, 43.28348428972306, 42.2677198533089, 43.25538835217876, 41.335450910752826, 44.23200361190304, 40.52999219586773, 43.32732854350921, 42.65181403006277, 42.875291070630475, 41.710358896563136, 41.83726718348842, 42.022571717539144, 41.457828860129084, 40.60261880197833, 39.22118748387983, 40.5324475995956, 41.95151798186764, 42.18639735252627, 44.96207437207622, 46.17348271031534, 47.615789213488185, 45.40725946426392, 43.39769586440056, 44.42450961759014, 49.12452497789937, 56.24498790310275, 54.15654936144429, 53.618078539448405, 54.579816249109086, 58.620543941374756, 58.652742678119296, 57.18852581516389, 54.66947770887806, 59.08207355007049, 61.089099376432365, 61.20606053260065, 58.066415017650975, 55.30309738651399, 58.928826547438106, 64.12589642309374, 57.77577131025253, 58.63386038810977, 21.30252968880438, 5.880784594243573, 3.547727191640485, 5.565447605425312, 1.3387477181611525, 0.033896299484636516, 0.08903217982620963, 3.25017741610927, 35.57999633973645, 41.56021841110722, 30.38700180668985, 20.357817026876635, 46.35586507858769, 43.54993481789866, 51.62045855675974, 49.33681541873563, 43.67540359497071, 6.285830601569145, 0.16762569156144896, 0.0859325651019331, 0.0875484896823764, 0.09140212644612597, 0.02628615441461725, 0.05024851134587681, 0.035608126781880856, 0.023552478824351585, 0.031161474762484435, 0.05400759370757207, 0.03140452190212185, 0.04293224909493039, 0.02784420296760096, 0.019230718288810986, 0.002576723566181177, 0.03619273996821815, 0.031078570642538612, 0.222712300958172, 0.14484438173953565, 0.10955877797377687, 0.12319069971600849, 0.1313465560275701, 0.1674151859216152, 0.17098360815115515, 0.15029420865879906, 0.18835474376476583, 0.17455699463044444, 0.15529052684864691, 0.14258449897170067, 0.18066161222034888, 0.16373119166781827, 0.18456450843762967, 0.18271566248468815, 0.2501358584530892, 7.9587121644327725, 63.00977814582087, 72.99657190999677, 58.15933988940332, 41.41409835507793, 26.350329845182358, 29.781852652949674, 48.14490126025293, 52.137611296869096, 29.3249043726152, 0.5159715551041788, 0.1746132867711206, 0.2191354824049819, 5.533312116899799, 16.50640449216289, 10.755733251571657, 8.67253303527832, 30.544979187750048, 63.06902946964387, 67.33660744082543, 61.0629528568637, 62.881077335726836, 60.385426167518865, 60.517978745122115, 53.067326776443, 49.062810405608154, 44.38827083956811, 49.79700357683244, 49.122089186022365, 50.196398919628514, 46.03032404376615, 47.17382438721196, 41.58304268313993, 49.02445747006325, 59.65581824702602, 61.89492287174348, 60.93600142386652, 58.29770149723176, 51.37060749915339, 57.303172772930516, 61.59238653798258, 58.43647887629848, 47.517859397395966, 46.67050192433019, 45.92064280663767, 46.21700140737718, 43.77848348309917, 43.96051676042619, 42.921857449316214, 45.23408682115617, 45.12839855686311, 43.115449951541045, 44.12864523549234, 45.62857920123685, 43.196497886411606, 46.43478708882486, 42.08176812817974, 42.26579396955429, 51.035515492962254, 58.239203268481845, 59.55298154584823, 59.957385755354366, 52.6530146598816, 61.70325625327326, 56.08698306545135, 63.48166281177152, 58.21927762800648, 62.36086906925325, 53.15173618255123, 65.80192912009456, 33.607283407642, 33.02784735156644, 66.71121689581102, 54.27828011974212, 58.67428825747583, 47.932147979736335, 50.39572592704527, 46.44857421998055, 46.9477899612919, 44.70861081154116, 45.322751998901374, 47.245748889061716, 45.36282293258175, 44.967616681129705, 46.02646050914642, 43.67247750682216, 46.45056678402809, 42.58278423740018, 44.52609116031278, 44.84840800685268, 44.71150159835816, 44.08600122697892, 44.9994820164096, 44.538725114637806, 44.223205735606534, 43.426933211665, 41.65920726714596, 41.85914224193942, 44.009550309950306, 44.902599473153394, 47.64220637659873, 49.040970648488695, 50.75043762883833, 48.644297430592204, 45.48205514107981, 47.48932415439237, 50.90472798193655, 60.84431209871846, 56.14091173295052, 56.60694422260408, 53.45567672483383, 61.03592772637645, 60.38438281705303, 59.37783595054381, 56.20943946223105, 62.07938801857733, 62.77936243241834, 64.9807652350395, 58.64447039942588, 60.44287712343278, 62.27325508671423, 67.04959977057673, 58.61906913018996, 62.984965232110795, 22.830098713597945, 15.12943781191303, 7.259912010162108, 14.885116315657093, 3.106916277639328, 0.14342551029497577, 0.26285350022296755, 5.032844158910937, 43.6929169777901, 61.07719890532955, 33.19371261904317, 25.375697343580185, 54.95404174250942, 49.49738156410956, 64.72778020366546, 57.046002572582616, 55.408236518982925, 8.262174667850617, 0.3275703710894431, 0.23153027940180995, 0.192556444916033, 0.08220838187562843, 0.1184905587785667, 0.17543646356751844, 0.22709585606090485, 0.20350814676813542, 0.06837026756857673, 0.1945661693330734, 0.1621484693380133, 0.13408435508608818, 0.15617420926930445, 0.09367534680472267, 0.16781880700540158, 0.21212996073788215, 0.13959441183795854], [0.022722014616574013, 0.03484590377117838, 0.014838558103468631, 0.025766608906128717, 0.013854564130005818, 0.035375159444107164, 0.017513748626374913, 0.014038725921343413, 0.01902049227106956, 0.028966437507000183, 0.029779174440209905, 0.023505609565144105, 0.03805452514620077, 0.02341067403434746, 0.03252897426606186, 0.07571753339781877, 0.033948619459425254, 6.751390445616938, 47.036521819330034, 54.18186433853642, 48.81456751977244, 30.90276798894329, 24.02892408832427, 38.594859492394235, 39.27788534472066, 39.48182113708989, 12.63531832925735, 0.043135561169155186, 0.17754418595183283, 0.27005628953056954, 2.9211104156509524, 22.514259661397627, 9.03194962009307, 3.466090165799664, 34.58730328467585, 63.71692657470704, 59.71101384009085, 53.61628209390948, 48.20890649672478, 45.63769086714714, 43.086640142625384, 43.26641413473314, 46.29531937260782, 50.01657001433834, 53.70221730201475, 54.82931429339994, 53.4115461380251, 51.50657253880655, 46.90105099831858, 39.266463402778875, 41.60421563733009, 49.122877582427, 53.889424185599054, 53.03192738563784, 57.2236349505763, 52.383559596154, 54.021419786637836, 53.806469978824744, 53.774126114383826, 48.95172103758782, 51.3338392011581, 49.79026102250623, 51.891851271352465, 45.420630824181345, 42.29477636275753, 38.32939347913189, 40.44539451599121, 39.01222321294969, 39.658323872473936, 39.85733709027691, 40.965288992851015, 38.88714275052471, 42.010533963480306, 37.01818043185819, 41.427395189962084, 48.67751598358155, 55.599797233458496, 47.119201460192286, 53.0129901824459, 52.137203370371175, 52.394071548215805, 51.52488608514109, 53.957814631923554, 52.23039104092506, 56.307079022930516, 46.408326779642415, 58.13101645438903, 25.699645896111768, 31.712445212948708, 62.189865496850786, 49.37315617838214, 54.19380011097078, 41.4241906135313, 43.20975549759404, 38.42302829988542, 40.31280271468624, 39.151063349939164, 41.291528209563225, 38.55662815032467, 41.38946979276596, 38.13328281525643, 40.741713893029, 39.93301530038157, 39.80211796299104, 39.255963217827585, 40.49696583901682, 39.85734885738742, 40.471643017184356, 41.14218396525229, 40.59835518560102, 38.11096452897595, 39.38385209729595, 38.9156505369371, 40.396286441433816, 39.62222237740794, 39.94971283020512, 44.07127664935204, 52.32358263384912, 53.67927928124705, 54.75309087384132, 50.49497758188556, 44.99380242440009, 45.25784853966006, 49.49374552695982, 54.47833276564076, 52.225837169155, 49.91431382394607, 55.599926671674176, 56.43901578841671, 55.428330821375695, 53.073057359264745, 57.22862420543548, 58.1329188039226, 54.241366694050456, 53.1453231073195, 47.791750661788456, 51.90938034365254, 49.92641433592766, 55.02085931839482, 54.91305689657889, 54.601761910223196, 35.98131364391696, 8.256862798044759, 4.258087306253372, 2.6197623149041207, 0.5710747273218247, 0.06378214783786286, 0.04619953365275457, 0.7472041020950964, 13.507414190999924, 42.11490431139546, 36.05163781873642, 25.932171844667007, 43.369682296629875, 38.52685343834662, 51.039885013334214, 46.10522170220652, 46.03447391140846, 21.583512598468413, 0.16011354062826405, 0.0772903502107628, 0.06702039000247756, 0.021848955920206446, 0.059276792416048635, 0.025646551437075102, 0.03027389486951213, 0.13440166870432516, 0.010713092276766416, 0.007545011317087038, 0.07984781217190527, 0.010635658982209863, 0.027214348458895282, 0.033902412866272276, 0.04615530356644623, 0.05575018709585552, 0.08200956673751916, 0.028682565541877866, 0.0842915281593319, 0.02650729527005986, 0.033017481722298174, 0.06848975430212675, 0.02082765346483117, 0.019753098322619355, 0.05725713949950953, 0.06838470832594941, 0.03078340845663221, 0.03257328479160224, 0.016566777767072764, 0.0042246320780607, 0.05665910062229922, 0.042264124663967284, 0.07025303589480539, 0.08717283846870547, 10.956408573735146, 56.167787813371234, 60.23160649884132, 55.55678844451905, 38.88895880791449, 26.345799507633334, 31.147698433168475, 42.259114173150834, 43.2630761977165, 14.5562461691518, 0.10267864957812334, 0.10323251582561963, 0.67535130607505, 4.774167278120595, 10.266233221177133, 13.592859102833657, 4.474790413533488, 36.134364528040734, 64.54746100210374, 62.2493286286631, 56.53754572714529, 50.64982883391842, 48.388280407074966, 47.061193527713904, 44.903058390463556, 47.52696321856591, 52.01407232592183, 56.121201822834635, 56.698766908338, 55.624814110417525, 52.60541669784054, 49.09624468895697, 40.18039526477937, 42.90891755011774, 51.930270887190304, 56.88299671296151, 56.54406470637168, 58.76289459966845, 53.18009884126725, 55.211290390260764, 56.07128181765157, 57.44401724107804, 52.449518172971665, 52.07057014588387, 50.259003869948856, 54.05918436665689, 46.84184674293765, 42.746570648685584, 39.82227894567674, 43.356950283050544, 40.84265216704338, 42.203039969167406, 42.55588854512861, 42.964999598841516, 40.3943056444968, 43.48538044960269, 40.094667942293235, 44.67850269809846, 51.45794691578035, 57.821117831814675, 51.12894242809665, 55.526080208439986, 51.314560751761164, 53.51149597475606, 51.9933347548208, 54.29440106115034, 53.35778613244334, 58.863879942124896, 48.34767603105115, 58.1037167579897, 27.848388917984504, 34.51659471757951, 63.14271903807118, 51.23061418533326, 55.70709759189237, 44.4423956255759, 45.45247654761038, 40.119363184898134, 42.367081334514005, 40.23194305358395, 41.98182613618913, 42.36588501161145, 41.71104531134329, 41.79189712770524, 43.3140826994373, 41.946799370550345, 42.72420529396304, 40.90421376689788, 42.92500319019441, 42.792740867983916, 42.46731750426754, 42.699286476258315, 41.00893712812855, 38.84874666890791, 40.679465878394346, 40.497711089349565, 42.64516953499087, 41.59888905863608, 42.00845902965915, 45.696377369665335, 53.87900244805121, 56.14157461350965, 56.188933310970185, 53.36132803270894, 48.54251976936094, 46.045884086239724, 50.958405617744695, 56.177695720426506, 54.886816240126095, 50.75073572897142, 56.047410272782855, 58.643936957082445, 57.53078791403002, 54.58046736255769, 58.42650036658011, 59.75712914620677, 56.56512783419702, 56.36977026539465, 49.457240027766076, 54.25538132267614, 53.747599124908454, 56.779756007655976, 58.56630540663197, 57.16348540398383, 38.57274124699254, 7.0452137243363175, 1.6074335070387011, 4.804082705128578, 3.649763729303114, 0.02869558712137082, 0.07724581751972437, 0.7062822592354591, 17.819647366000762, 42.870599915904386, 33.192488839549405, 31.804385569787797, 51.904759791589555, 46.40596551279868, 57.99891887172576, 53.759154427436094, 55.48808420858076, 26.540556953799342, 0.2685064017291992, 0.055723297409713275, 0.09662635579344728, 0.031637320700552196, 0.0973830744624138, 0.030218022161974546, 0.03030423961219288, 0.050221686777208126, 0.01059019070629391, 0.08991825244119091, 0.038649365606327216, 0.012251253187235807, 0.04398083194128929, 0.020297051392375462, 0.07106710390578355, 0.033999288514737165, 0.011345370496142537, 0.08812849484984914, 0.1716109881958654, 0.1730651762937346, 0.11283501426899627, 0.15508956666434967, 0.10863141321967687, 0.07514479840474744, 0.10464518961887206, 0.12051825561831075, 0.1422742180406086, 0.1373102287611654, 0.15382121617515243, 0.14796942292201906, 0.13513896704441117, 0.1324593906681384, 0.25328829493974486, 0.2511070894017335, 16.216787465157047, 66.55548311048939, 67.78271429000363, 65.09933456297844, 45.72823093783471, 36.31285590510215, 50.49867637695805, 51.936887925670995, 52.157509480753255, 16.859992434901578, 0.420650819977445, 0.2760452278439076, 0.8040854563155483, 10.232788151310338, 37.50143212656821, 22.82291489262735, 9.811104920602615, 38.539357954455966, 68.02729760446857, 65.13574592528805, 57.416952886889064, 53.36517195547781, 49.682697865270804, 48.25830482667493, 47.59734622893795, 51.22780969066005, 55.18901525005218, 58.411473766449966, 58.608776830857806, 57.293331546168176, 56.2167586049726, 51.07010687551191, 42.28567254158759, 44.09792915467293, 53.34857248490857, 59.34241302551762, 59.37791832031743, 61.08853847749772, 55.00686822399017, 56.217527389526374, 57.42403668742026, 60.43127475246307, 53.856440974820046, 55.40411018556165, 52.11916831231887, 56.69716658130769, 50.474585179359686, 46.25611920510569, 42.08325078410488, 45.42006992524671, 41.546878430151175, 45.35713941820207, 44.17797688514956, 42.82675566211824, 42.713175589038485, 45.79658216045749, 42.24612328314012, 47.04788100334906, 54.23440840936477, 60.03591160620413, 54.14580598954232, 57.68758073929818, 52.58109408040201, 53.33204361700243, 53.685005941698634, 55.83131121050928, 57.48529234240132, 58.74525570100354, 48.911771697382775, 58.56900791968069, 30.449491047090103, 38.05330960981308, 64.57485875775738, 54.90228606808571, 58.0277326030116, 45.74506182824412, 47.623900675004535, 43.44376017970424, 44.04742471633419, 43.7278417618044, 44.601518338726414, 42.95534272347727, 44.67913027732603, 43.43797468370007, 45.58779439618511, 43.68561744689942, 44.24624181562855, 42.15637553122736, 45.07790980800506, 45.534587444797644, 44.87023207449144, 45.222060834207845, 43.25449797414964, 40.314599160225164, 43.56718932428668, 43.62413821681854, 44.00083480342742, 43.81982134234521, 45.37608838850453, 48.968822571539114, 56.76769864174628, 59.122642624762754, 59.7311826675169, 54.839516378218136, 49.94406500170308, 48.02073471007809, 54.25186295663157, 57.8698258246145, 55.94458533871559, 53.24253512967018, 57.422051968113074, 61.39493442350819, 59.93384368958012, 57.04431203103835, 61.050899413324174, 62.69214853163689, 59.36309176106607, 59.4137256376205, 52.56634989092427, 56.465213298797615, 56.27688461734403, 59.869446216091035, 60.44758004526938, 59.30072999769642, 41.707903492835264, 11.358401506177842, 9.818872194136343, 8.275097896975856, 4.090342733167833, 0.27088151944260447, 0.32364113676932554, 1.3798579573631289, 21.98397678713645, 57.20519981076641, 48.97259196927471, 32.27328923440749, 54.791902726696385, 52.38801933103993, 63.99054719555763, 60.29721990708382, 65.04176985832953, 31.48339056199597, 0.6222709736997082, 0.14038792570992825, 0.12192895290471854, 0.11382983306482916, 0.2555679121325093, 0.15985469484040815, 0.14704604182512532, 0.3366405456777542, 0.10141412186766825, 0.1748391907782324, 0.17450874641297326, 0.12793050102529027, 0.12524719380082625, 0.093252029600403, 0.15175127724726356, 0.19676732380063305, 0.14747687435198217], [0.0369115564371309, 0.01945046677945122, 0.030471208475289807, 0.020295727975486268, 0.059454340953379876, 0.027358683254269343, 0.03293450290877973, 0.01777377227441438, 0.01781842753952069, 0.05528286580116518, 0.0577558052816218, 0.08386715375367673, 0.08696489156253877, 0.06945153938666468, 0.038487564006279555, 0.010943565998346576, 0.48846737451611033, 22.635307927285474, 59.54771380270682, 55.454430272502286, 45.64763015316379, 28.296576584539107, 26.75010761907024, 48.71893229023103, 35.55730935065977, 32.94051185730965, 4.099365900601111, 0.11712618682894016, 0.03049843907055836, 0.24400531644782714, 1.4747326148133126, 3.153054137383738, 10.262062761091418, 4.7136470675468445, 40.60921230623799, 65.99059120301278, 59.058621698810214, 52.80315906770768, 48.98368443212202, 47.76767907604095, 50.545258445124475, 52.80200196850685, 55.78679623142366, 56.93679201987482, 60.58789499344365, 57.66322674289827, 56.909829647310325, 56.838199323223485, 54.45699507190336, 43.30233520077121, 40.59985745337702, 40.71991728198144, 48.62863148412397, 50.03387158916843, 53.93247219824023, 54.40514918296568, 49.55118471576322, 52.711963961201334, 55.148587380686116, 51.9468899696104, 52.39451085367511, 55.89185691648915, 54.04829978942872, 54.15600022962017, 47.77054240626674, 39.698794887911895, 41.324280000502064, 40.35796096248012, 39.61752730031168, 39.61984149871334, 40.18405483615014, 38.78614564095774, 40.256924629211426, 39.2882364796054, 40.8664099631771, 45.85963426097747, 54.41484920440182, 52.41957479907621, 57.508069545991965, 53.03808550680838, 55.56078533972464, 53.67783977139381, 57.46550790725216, 51.90008040397398, 57.92405259224677, 49.24120764578543, 61.2256919953131, 29.27098551104146, 32.797943507471395, 61.054017697611165, 47.96045572526994, 54.18772828194403, 41.13198972517445, 43.78495931625367, 40.345581962216286, 40.81863941684846, 38.96589609884447, 43.008357478726296, 41.51929240072928, 42.08336845521004, 39.625434798579064, 39.831225872039795, 40.06265355694679, 40.32292635210099, 39.02998370508994, 39.38876290475169, 40.042304300492816, 41.69364567725889, 39.92691993713379, 41.00437541161814, 39.25036991796186, 42.12878165706512, 38.76257219622212, 39.073596539035925, 39.77382590693813, 44.717259637771114, 50.33219529736427, 54.27690729018181, 54.36442321346652, 56.41892148602394, 51.86745805125083, 49.61639804224814, 47.05975794023084, 50.83163461377544, 52.7491323409542, 56.34368650374874, 52.11171580899147, 55.957721356422674, 55.4207214232414, 51.83598887535834, 53.22644948959351, 54.81461717236427, 56.67866083883471, 54.682237179048606, 44.70603381433795, 50.547003899851155, 53.692972275518606, 63.016912937164314, 65.28231313151699, 58.15148338194817, 56.673067538968986, 42.200902277423495, 15.910038505831073, 1.9099034056548152, 3.09655214990339, 1.6213043562827574, 0.1353477413255361, 0.15525419895927753, 0.10368720433043857, 7.453783981261715, 30.067864041174616, 34.93873196263468, 18.12002835735198, 11.63266049277398, 20.74536681175232, 32.348202582328554, 46.97002195542859, 49.15675509360529, 33.379201504491995, 1.7202724973040244, 0.07942990354833104, 0.059244045987725265, 0.10657770003402427, 0.05801570060993395, 0.025290489091628024, 0.00866678907656141, 0.0728821807030228, 0.08001028409888668, 0.01785886357538402, 0.022391079955043334, 0.0364253051098316, 0.02890816885947941, 0.02398787148957772, 0.11248321903328742, 0.028725424330801736, 0.04400543868541718, 0.05920856462551221, 0.03954388051023407, 0.09188716735450492, 0.019338935868994846, 0.09654670563195983, 0.03268938158608733, 0.02876178860934752, 0.02445778407667193, 0.04655687153459557, 0.08054194911833733, 0.04838062810801691, 0.027282919073777816, 0.03708670711925915, 0.0065092661891192685, 0.059874900241172126, 0.07759324605426482, 0.7800159543271988, 30.281156647589903, 67.09066698628088, 60.72421696878249, 53.88696485950101, 34.53143304394138, 29.479247677710752, 47.75830068895894, 39.41956135534471, 37.86298444194179, 4.92942939842901, 0.14698095499507843, 0.08949436067092804, 0.863412530912507, 6.450959444046021, 10.156930492770288, 11.851342435806028, 5.070873498916626, 41.52688610938288, 66.7839611730268, 60.399009335425596, 55.48871178780833, 50.32733548072077, 48.28010536009266, 51.10162311984647, 55.3713309380316, 58.880640229871204, 60.796667068235344, 61.64515810628092, 59.292900946832475, 59.424778876766084, 59.59113836288453, 56.459525862047755, 45.695255571796054, 42.946658595915764, 42.91638574292583, 50.84657492176179, 53.64994779709847, 55.63980148684595, 54.88074441109934, 50.63417857693088, 53.08307901505501, 56.90402846182547, 52.61816832327074, 54.891397568487356, 57.220822611162745, 56.654675545230994, 56.19954724465647, 49.48959173694734, 42.06627084362892, 42.70302449503253, 42.10072102085237, 42.5375985330151, 40.437757661265714, 42.19918820165819, 41.14142694780904, 42.0299732300543, 40.179548032822154, 43.9361313850649, 47.410107966392275, 56.57414928559334, 54.594866383460264, 58.954898541973485, 54.472366840608665, 56.01800818597117, 54.45362183355517, 59.919040664549804, 53.16413087229575, 58.16300338314426, 49.97372988731631, 59.301667444167606, 30.770544890434515, 34.436660735837876, 62.68126003203854, 50.334368290439734, 56.37973308563233, 43.74618276473015, 45.79069076045867, 41.56653342708465, 41.871599689606704, 40.34499752906061, 44.590625916757894, 42.94011608246834, 43.1037102976153, 41.47236124161751, 42.911412177547334, 41.865555317171165, 42.20482856996598, 41.55415834919099, 42.88097066263999, 42.13222157570624, 42.106753626177394, 41.303652255765854, 42.22851184106643, 40.94841103399954, 43.34326513351933, 41.07314632784936, 41.895451622624556, 41.80382113302908, 46.19957039433141, 53.29583621794178, 57.328487750022646, 56.34565161120508, 58.67539436586442, 54.7825635633161, 51.94926300356465, 49.23721467295001, 53.782257187751036, 55.69326339229461, 56.805227879555, 54.08416594228437, 57.05356882464502, 58.01545558437225, 54.51761138054633, 55.1087204102547, 57.528356044523186, 59.40932866065734, 56.887562351842085, 47.47632541964131, 51.790273651, 55.846024021025634, 64.96499730694678, 67.73617144553893, 59.388261610461825, 59.875180721282966, 42.275082142122336, 17.260138911585656, 1.733305185071884, 3.99092119066946, 2.2362118767153834, 0.4437138050073578, 0.27360297018481844, 0.18128479410323406, 7.968194494324346, 35.74850136233915, 41.37948343830724, 21.856713525710568, 19.000321972754694, 27.62154648380895, 38.81864640020555, 52.7450373864943, 56.86580496449625, 39.26615353553526, 2.4283506504950987, 0.025282985260409695, 0.021094979846008846, 0.11813330133595776, 0.07222483895959393, 0.010421112228575493, 0.06690912339235507, 0.02848081820223841, 0.013311478654823959, 0.019239074392845074, 0.054068984163384286, 0.00245198194827554, 0.013300875997951916, 0.011253947478478715, 0.038223987625491236, 0.028917382981988694, 0.014627440550905323, 0.16204480232009966, 0.1255188868831723, 0.1865727313223385, 0.1558355677632555, 0.1754572398720249, 0.14347480039202398, 0.1354684767824027, 0.18054288391384388, 0.19006796151159272, 0.12057498442910372, 0.16776063028843174, 0.17497351663487573, 0.19533663928028078, 0.1503774211291344, 0.08255417864289015, 0.21793456297487984, 1.0937422586064185, 36.787745106604795, 75.9005771144744, 67.26544780115928, 59.47853888234785, 41.012408425731046, 39.94247997960737, 58.53078834472164, 46.07098725534255, 44.728665890232215, 5.677420487326961, 0.3387062251567841, 0.1850737424026574, 0.9837887231861392, 8.02907899502785, 13.97158943837689, 20.91121246737819, 9.458818224168594, 43.372373042568086, 67.88921448492235, 63.61733759603193, 57.094334017845895, 53.08973919960761, 51.03759042678341, 54.93852484610773, 57.56475563972228, 60.81121906157463, 63.88525509065198, 63.25707966281522, 62.42841228362053, 61.36406929262223, 62.31094514170001, 59.46316711364254, 47.37916831047305, 45.51145330552132, 44.88657659099948, 53.325999244566894, 56.420180566849254, 58.15862601803195, 57.34484011127103, 50.87153688553841, 55.33682976999591, 59.49372237728488, 54.54477771635979, 56.85391626050396, 59.77575255978493, 57.16234007189351, 58.176308062768754, 52.070844711795935, 44.88243849046769, 45.076917448351466, 44.7103484215275, 45.00749149630147, 43.683228723464474, 43.85276140705232, 42.56564347974716, 44.33263594104398, 42.01403664004418, 45.906549730608546, 49.612165804832216, 58.051172687161355, 57.69539410068143, 61.83205120025143, 56.43930604380947, 58.24851889764109, 58.18776138367192, 61.564776974339644, 54.82620777622346, 59.94458313911193, 52.14718972482989, 62.698592985830004, 33.5786344159034, 37.95987090756817, 64.78720803414622, 52.99056991454094, 58.56348522247807, 46.35193094130486, 48.85603089486399, 44.91761822854319, 45.402780117527136, 42.24074571363388, 47.6606297492981, 45.05565820201751, 47.109987812657515, 43.4601870659859, 44.565950286003854, 44.376899888438565, 44.509236735682336, 43.7173572663338, 45.297225213819935, 44.610986940322384, 45.04187107086182, 44.23955809685492, 45.793150086556714, 42.8987076205592, 46.768400361461026, 43.46078326625209, 43.69998116647044, 44.880920533211004, 49.81418355818718, 56.42765660439768, 60.07435083389283, 57.403973763988866, 59.917883565348966, 57.1390921838822, 54.21021523014192, 50.24145126342774, 56.810417175292976, 57.81124914846113, 58.768754620705884, 54.36409373437205, 58.62577638318462, 60.609899490110344, 57.02046794276084, 59.21392402341289, 59.50188482961347, 62.71478452990132, 59.313626750823, 49.308660645638746, 55.53191669525639, 58.32489528963643, 66.24505889031195, 69.24936694483604, 62.075767670908284, 60.837279288999504, 44.57758011356477, 21.295206623692668, 6.701874934857892, 10.766106940084889, 9.03505123430683, 0.2563272125177807, 0.33539053533346425, 0.21931249468076616, 11.199963246622394, 43.956598312624045, 48.70589825414842, 27.142105371721332, 19.428609494240053, 31.21493962503249, 46.9226985592996, 60.583709824469786, 64.54409168612573, 47.936019359096406, 3.425625279065102, 0.14189004026834043, 0.19382775250461795, 0.2427922315414875, 0.19219554089490445, 0.19942284501608343, 0.21280218756967978, 0.241300581744121, 0.1715297369106162, 0.12035125611169685, 0.14434043378118547, 0.13886357927995344, 0.18226379318343056, 0.11906232850085344, 0.27179184640126847, 0.11553430208756078, 0.09875232639211802], [0.012268218204318997, 0.06408756028019613, 0.09429452204776388, 0.0441249790451219, 0.03544739387448757, 0.049387819223826936, 0.04857623716816307, 0.054800981175034284, 0.024428908307585987, 0.05580946697943634, 0.03175300763799779, 0.018841959310755618, 0.042186734461856466, 0.05793048098923699, 0.1674406353624598, 0.005085875783416053, 1.4427596595018142, 31.115837020258752, 54.65668293737597, 42.01389151234781, 41.97170642114455, 31.583271757248912, 29.703266005362238, 32.480564924978445, 32.21057445772233, 25.467123869926702, 1.6252491575094963, 0.05088201243310206, 0.10512393328451342, 0.7144262641668321, 3.9992569627300387, 4.544175670992944, 10.1353858940063, 3.0607389490450583, 39.91092451157109, 65.836379297318, 56.64383019170454, 56.43306163049514, 53.70620635248, 58.565332658829234, 57.01904020001812, 57.932309181459495, 57.92733953845117, 59.170793640998106, 49.205310113968395, 54.02456552751603, 59.16948749173073, 54.80075943854548, 56.533211508104884, 46.77979876918178, 38.490779399871826, 41.86171139440229, 46.99495254024383, 49.701717438236365, 51.88461449838454, 56.4487511111844, 52.43073786458662, 50.871811451450476, 52.53012288001276, 54.66046410222208, 53.682079853550086, 54.73881344641409, 55.232290760163345, 52.627456495838786, 53.40316403296686, 43.238733968427105, 38.72141476600401, 39.71893625874674, 39.94267609811599, 39.94743785550518, 41.70366341067899, 39.727428190169796, 40.86936350791685, 39.132090845415675, 41.969584418881325, 42.06263872884935, 49.28490284950503, 49.36892394096621, 52.34668539416406, 49.82881792130009, 53.814346098130756, 53.859433743261526, 55.54165201802408, 50.85969524998819, 56.03881243736514, 50.03181626719814, 59.39175251991519, 37.60903842987553, 40.08976105720767, 59.196363572151434, 49.78695054208079, 54.04457353776502, 42.33074449723767, 43.42766669488723, 40.92053082681472, 43.28439820197321, 46.97046910562823, 46.8669028435984, 46.69269861713533, 46.349832473262666, 43.72951661386798, 41.74161626446632, 40.802859721645234, 40.139433953069876, 37.80507064634754, 39.18294829706992, 40.20552981284357, 41.007579988048924, 40.99088245822538, 40.830363381293516, 43.51128378222066, 44.48572604886947, 42.171433510318884, 41.0767392189272, 45.44906016319029, 50.753669661860314, 52.68116551060831, 53.60043571841333, 52.19243034239739, 55.1269123631139, 55.63066628671462, 52.8511021983239, 51.5919860716789, 51.03812779149702, 54.151336531485285, 52.9267607965777, 54.03267698903238, 54.51840762169131, 58.46691646883565, 50.36377822199176, 48.56860745337702, 48.71091104322865, 50.29372469071419, 42.292701428936375, 47.84159221956807, 53.43786916425152, 61.03608462118334, 51.037939517728745, 44.3174877474385, 58.40091866831626, 56.19724481336532, 54.67837756679904, 28.78439784049988, 6.372436044677612, 4.094111395459022, 4.686275297595609, 0.265313561765417, 0.12033915958337246, 0.04966948677094714, 2.2721022992364825, 25.938900670697613, 35.01409246075538, 35.15592536618633, 23.857204683365364, 24.717507939184866, 41.24511480331421, 49.600849766885084, 48.265110138923895, 36.62519816429385, 7.244907963660456, 0.1329106164555396, 0.03695433478682272, 0.03821321642927585, 0.049157019914878954, 0.08760930174180577, 0.05230543443993215, 0.0833916889443513, 0.047228397395942485, 0.06558466462358352, 0.02510775796948902, 0.04420414274077743, 0.08350739120355538, 0.05681516422379402, 0.007251882137009695, 0.019001698219067147, 0.05920387616741562, 0.010767564001012473, 0.06698481287927398, 0.018671711591342767, 0.018927205744529926, 0.0677965673047208, 0.025560728522137772, 0.0388652568442687, 0.03346938932795198, 0.038347852551528526, 0.003438925120844356, 0.044615501312599073, 0.02198455922846352, 0.05397777373511946, 0.09234590080356406, 0.11624435834105938, 0.03544655117777086, 1.848115043774728, 40.12924755773237, 62.492856825551684, 49.75279062025009, 46.157518663714015, 38.94980653639763, 36.773463756807395, 41.29869830223822, 37.49961606917843, 28.779336021792506, 1.254480497971658, 0.03583389289316631, 0.13893108694784104, 1.7531594874397403, 8.578753086828417, 8.554442236500403, 12.013195118596478, 6.911743312112748, 43.38870579196561, 65.3589758565349, 59.28350687026978, 57.62714093731296, 56.580958520212484, 60.25384633771835, 61.321566489435014, 58.31466574822703, 59.84472351689493, 58.74471049154959, 51.3231978108806, 56.208545161831765, 60.34206044289374, 58.5710475521703, 57.96747715242448, 47.815108376164595, 40.204400170233946, 43.70961842998382, 46.02915909982497, 52.071523281835745, 55.369138333105276, 58.528411388397224, 53.89150304179038, 49.208126375752116, 53.6619580945661, 56.742422888355875, 54.701139080908995, 56.58688914391303, 56.39672871558898, 54.89659470896567, 53.6334659976344, 45.73779367631482, 40.79762727983537, 42.563207687870154, 42.769139966657086, 42.18534615732009, 43.863967618634625, 41.1239488663212, 42.33474531481343, 41.175359372169744, 43.28327248173375, 44.02137233364967, 51.71025729948475, 51.75962425047352, 53.69754575913953, 52.36745434422647, 56.72122247757451, 56.95401514730146, 58.47150564193726, 52.783684499802135, 57.664638796160304, 50.87467870404644, 61.69403476099815, 38.02850846321353, 41.35731420209331, 61.99151515960694, 52.47940271131454, 53.86233629718904, 43.557320640933135, 45.52862151976555, 42.59868160370858, 44.859684821098085, 49.096076027039565, 49.50137453694498, 48.51076818281605, 46.957792005231305, 44.755816536564986, 42.458700056998964, 41.8362356001331, 41.23743872488699, 40.172166132157855, 42.24602130151565, 42.537641679086995, 42.238592332409276, 41.71893319775982, 41.482218157860544, 45.86620030864593, 46.7589396046054, 43.328603313815215, 42.68154167359875, 47.50241310365739, 53.984608342570645, 55.18379065298266, 56.62257879011093, 54.579871162291504, 55.568355514157204, 57.67233056406821, 54.39344090800132, 54.29197703638385, 52.2818878389174, 57.344608691430864, 54.847953396458784, 55.06157352078346, 56.37690113436792, 60.59701058172411, 53.30599907905825, 50.51018461104363, 51.66527555834863, 52.671798890636815, 44.64266007946384, 49.2129744252851, 56.018349432176166, 62.897994518280036, 53.835707326089185, 45.01448508231871, 59.10100290852209, 58.08136709274785, 56.00383274016842, 31.122832567461078, 6.571235493306191, 1.9492496814458602, 2.557848927474791, 1.82287079191977, 0.20564882625495234, 0.04908724462673549, 2.105853129779139, 29.639603976280462, 37.4170894007529, 40.248009081809755, 22.801885104948475, 27.719339016945135, 45.66172322919292, 55.37243312405002, 52.68515848344373, 45.2872270922507, 9.235301959899164, 0.08798806327244929, 0.04778404862830236, 0.07560570754351155, 0.11127894413807701, 0.05821936125416429, 0.02749311827844189, 0.052730647711864406, 0.009036588336100743, 0.029787247091712012, 0.04838019909877931, 0.07852378241237133, 0.0028986049836666715, 0.0712809496889672, 0.022486794980302937, 0.041479206298507994, 0.08270168121183112, 0.11053272853455237, 0.25825243743677295, 0.15676949022998735, 0.2530924981880573, 0.1303033587793189, 0.1313773067968507, 0.07897586621824773, 0.13098845588824443, 0.13798708276402566, 0.1388835282095017, 0.08051302929919574, 0.08824186820176341, 0.17428978316245541, 0.2580798225056741, 0.19055375318613746, 0.17671880282221303, 3.040093798791209, 48.90316993959489, 71.86349330409881, 56.834700569029785, 55.6689093958947, 43.33977422406597, 41.90680688427341, 43.32239420183244, 44.18914387303014, 34.25065017515613, 2.5289118866766653, 0.2312218830470116, 0.4116013297630895, 3.016885869926022, 12.063139638593121, 16.076352884692533, 20.671765496653897, 6.302238856592487, 43.69379951107887, 66.6567430188579, 60.90515590483143, 60.66107465374855, 59.05802157617385, 63.93868953950944, 62.10659750046269, 60.992079550220126, 60.622753097165024, 60.482838230748335, 54.01961549635857, 58.95534569217313, 62.37773526099421, 59.653496203884, 60.13457098314839, 51.005685867801795, 42.107200776377034, 47.21856686376756, 50.371662186038115, 53.36635258889968, 58.984720322393606, 61.030977695218986, 54.01121770181964, 51.50430148647678, 53.190524501185266, 57.18079482355426, 56.32038762492519, 59.87634174285397, 58.05972345413701, 57.60830963811567, 57.86900604924848, 47.80053677097444, 42.58509451343168, 45.38153656067387, 43.993166569740545, 45.085852607604, 45.672364619470414, 43.752572305740856, 43.479163492879565, 43.83953517483127, 45.60742193652738, 46.205920711640395, 54.843815295926994, 55.062067739425174, 56.383404424113614, 53.507832481015114, 57.61891180469144, 60.98599203171269, 59.89123498239825, 55.71747226099814, 59.31931418757285, 53.732874547281575, 63.067707630895804, 41.25395190331244, 43.187370531020626, 65.45033570258849, 55.15472589000579, 57.60536786048644, 47.30847543285739, 47.67056903531475, 44.889655651584754, 46.483420556591405, 52.15368124746507, 52.161910380086596, 50.74376175480505, 50.3195809548901, 48.23523736769154, 45.616545369548184, 44.39764530427995, 44.07621883576916, 41.28941012967018, 45.080322065661036, 45.55465036822904, 44.065224432176166, 45.01642273318383, 44.30208459977181, 47.97131676827708, 49.23506129172541, 45.30108874843967, 46.073587786766794, 49.882013105577045, 57.065061369249904, 56.75753578062981, 56.49670993128131, 56.29562962439753, 58.4903722424661, 60.212688907500244, 57.503296021492254, 56.800293537878225, 55.32954985095609, 61.69159504675097, 55.864796484670336, 54.75653471485261, 58.124317046134706, 64.61271747466057, 54.94229032147316, 53.454131310985936, 53.253329492384395, 54.33997115781231, 47.34092520129296, 53.228944117023104, 58.19944220204508, 65.93585060488793, 59.349002607407115, 50.21854069925124, 59.67084484715616, 59.71256709867909, 58.78143172110281, 33.860668520773615, 9.781629289350203, 8.385591064729999, 12.287727690512135, 1.6550290175983984, 0.3351833851587388, 0.14477134291683474, 3.2642650988794144, 37.97664296242499, 48.16994559380316, 48.685035167201875, 34.75612994163267, 37.614561127078154, 54.86069717714864, 65.4647425682314, 62.27150963198755, 55.31568427239695, 12.69107384066428, 0.22000434868518384, 0.19843028617962716, 0.20543085891873608, 0.184950111133437, 0.14546296709487516, 0.12646983182358165, 0.33210493744381014, 0.08399924263358118, 0.1495962412727456, 0.14723960160007402, 0.15681881097055253, 0.12505920348508706, 0.28722689396912054, 0.1187099050730467, 0.091936327216606, 0.19073758364444782], [0.019965532588802522, 0.024565396447395606, 0.04667948007643704, 0.02163720347227589, 0.059614081776911215, 0.039919995207099185, 0.05742886959905586, 0.04512091249888463, 0.05345314523325332, 0.026869384812251217, 0.08247707955419056, 0.06975331674179724, 0.07067547975889138, 0.07015254048089828, 0.08566507784229133, 0.16325751950423564, 3.272451085429038, 42.428497806672134, 53.421579560925885, 52.948631932658536, 41.758321639030214, 16.967710525758807, 24.44599755348698, 26.947038058311712, 34.9266000716917, 25.97167599585749, 0.8345874002383602, 0.04406795912091771, 0.5665436543283925, 1.6783707973457154, 8.957268672604716, 9.795751783155627, 10.31544033558138, 3.1312974854823086, 33.80225658416748, 67.92740268092003, 57.045214176177986, 59.45877798141972, 56.90333420230497, 58.581806613552956, 58.91142299098354, 59.05546026845133, 56.927837248771425, 54.07737631951609, 50.0697926552065, 57.367691839894945, 54.27727991534818, 55.451221773701334, 54.31518570069344, 45.182138950594016, 39.61516211109777, 46.79614328568982, 51.73000251093219, 52.34542239096857, 53.315730479455766, 53.57090419338596, 50.659266056553015, 49.605646825605824, 48.78227464614376, 48.92976753173336, 51.280455743112874, 49.352551967866965, 49.744361446749785, 53.36421881952594, 51.372141145890765, 47.672016389908336, 39.08863490627658, 40.41883222518429, 38.26784756875808, 41.39522390980875, 40.331567333590606, 39.687423936782345, 38.96283665011006, 37.63984864757907, 40.38609612372614, 42.18559326664094, 39.39459154682775, 40.68298424443891, 42.96657639165079, 41.37722023071782, 42.44658777790685, 44.38907100308327, 44.13226950553156, 44.50994276231335, 48.80482435226441, 49.67774783411334, 61.5729158924472, 40.25614407754714, 42.9301767964517, 56.787298725497344, 50.45158047829905, 49.73317484701834, 43.436178238161155, 46.174424079156694, 47.03434882625457, 50.93180410323605, 52.864265672622196, 53.870667411435036, 55.167108812639796, 53.35345191340293, 49.08326948842695, 41.34945377226799, 39.105759974448915, 39.772425620786606, 37.817233916251894, 40.308982326138405, 39.31737576761554, 40.61378186748874, 41.245671779878684, 45.97657188292473, 47.93537609038815, 47.01549399283625, 45.23980171449723, 47.87311630864298, 50.5913306051685, 52.672901076655236, 54.85331527648434, 51.842111695197325, 52.27378814451156, 52.57910151635447, 55.37584950847011, 54.197475371822236, 54.613795741911865, 55.19065087841403, 56.86414187954318, 51.74036933529762, 50.2371209667575, 52.53903842741444, 56.852064901782626, 51.03565669828846, 46.554803771357385, 38.872551533483694, 40.63595894844302, 39.409088626984634, 52.171630013373594, 50.863323442397586, 64.31120880188482, 29.952658145658432, 32.86540827443523, 68.18195666036299, 59.095915594408595, 62.78330049207134, 47.39631299049624, 18.013498744656964, 4.569619596004486, 1.6875719423255615, 2.1952566937092812, 1.1698215310612035, 0.22893183173671847, 0.5984036576363349, 16.750799532859556, 54.66286851513771, 24.6141593686996, 17.878347596814557, 23.71356160409989, 35.37391108851279, 42.16438108874906, 47.202406698657626, 41.44060181033227, 11.39691427830727, 0.059664555479802435, 0.049033086040928486, 0.06319057474273347, 0.035008789385638894, 0.021567280712207, 0.06150210929674007, 0.08663338233506487, 0.05875964093232348, 0.091728181127579, 0.06426630391468925, 0.04548851212847137, 0.03739963488412961, 0.0029871726479952137, 0.040541005230719046, 0.024965319241727554, 0.041892526055415796, 0.014980811054908462, 0.024339285596544226, 0.0325595488351199, 0.047359291178685044, 0.10171268931439809, 0.026854432691189072, 0.022766757981791612, 0.010135796187715906, 0.033064228407437765, 0.053101901580849965, 0.05981520283967257, 0.02176169659041109, 0.06266590793647113, 0.07203441248425553, 0.11110173267943245, 0.08812704694367225, 5.507868682184528, 53.35537779715754, 59.824378182811124, 57.378886284366736, 49.49497715119393, 28.38036233378995, 31.39688268784554, 32.8929982262273, 38.42296554196266, 26.21644562290561, 0.45721325482572284, 0.03505953504974323, 0.5654396296989533, 2.310362813934203, 8.066707272683422, 9.92324548382913, 10.258000166185441, 6.07210555384236, 35.19224651398198, 68.63157795321557, 59.580414602833415, 61.82502231290264, 57.67092635554653, 62.19840841908609, 59.99920998850177, 59.35680812405002, 59.354729267858694, 55.9915517991589, 51.68214959482993, 59.436738183421475, 57.53546337927542, 56.87047650737148, 57.06092719108828, 47.239155384802054, 41.953898860562234, 48.27426495090608, 54.12652361777521, 53.54576180058142, 53.44973433402277, 55.78907512849378, 51.14644404380552, 49.21738709172895, 49.073451795885646, 49.26785622873614, 52.018967443896884, 50.15399025332544, 52.452530553264005, 54.316264352490826, 54.50883311610068, 49.05629534875193, 41.14379998176329, 41.089067228378795, 39.71401368418048, 42.45009045447073, 42.37252950668335, 41.64556134131647, 41.7373251914978, 39.86974354713194, 41.8320268969382, 44.16486832403368, 42.28777493199995, 42.13195485453452, 46.044487722458385, 44.5350851551179, 45.11164219148698, 46.48495028095861, 47.397932929377404, 47.95774928985104, 50.8943925365325, 51.103760811590384, 60.890976536658506, 42.68266347146804, 42.71909444562851, 60.53300142288209, 52.192630383276175, 51.770355855264974, 44.80406953442482, 47.86198462209394, 48.22368990990424, 52.630704218341464, 55.531073385669345, 55.56033426715482, 54.619589082656375, 54.93959565316477, 49.412744660531324, 43.75043069162677, 40.53086296204598, 42.34195070881998, 40.44193890786941, 42.27135196808846, 40.18007363042524, 43.033762670332386, 40.97903297793481, 47.74321133090604, 51.161094096399125, 50.43351404128536, 46.7020966160682, 48.88552319618964, 51.04812199069608, 55.371134819522986, 58.11425224427254, 53.110994523571385, 51.35715769183252, 52.48488226244527, 56.34785990561209, 56.44671540106497, 57.04406492171749, 59.3051387417701, 58.10917669726957, 50.32430741094774, 50.20236092229044, 55.000882687107215, 58.964312230387044, 54.21884444452102, 47.650341372336115, 41.54010841923375, 43.866642675092145, 42.466242774840325, 55.52908474399198, 53.895805881869414, 63.957967988906375, 36.17390986411802, 37.29170299345447, 68.82210316196566, 60.74657447876469, 64.8921000572943, 48.535094722624756, 20.96765341297273, 3.059881175718, 5.050126612186432, 4.396034123436097, 0.9196026286771222, 0.14924261508689773, 0.40104031743061164, 21.621141856716527, 51.571142596583215, 27.265971860577984, 23.108065320599465, 27.403168524465254, 40.92899530164657, 48.993635485249186, 54.887228088994185, 51.12325891371697, 16.475845306150376, 0.048954730568033074, 0.09174970053737203, 0.03575436913618638, 0.06308370164685673, 0.040678514182687774, 0.03775678124398955, 0.08441355064391129, 0.09216904174536468, 0.06127923516736877, 0.03197197471895526, 0.05267767273190041, 0.039215994878642024, 0.052110890242000746, 0.03364138755827181, 0.012814465707408325, 0.08298610667547873, 0.07707621331416792, 0.1600153281563713, 0.10793037382104706, 0.1711234651626118, 0.16224614554835906, 0.12239476500619804, 0.18637425326291593, 0.15759867315571155, 0.128926039943772, 0.12685079968744709, 0.23181835910485638, 0.1827896359346567, 0.15923408701294856, 0.23281404358004373, 0.16956148849379632, 0.26860761726575516, 8.0283494341758, 62.733478546142585, 68.11718263933736, 67.37823163309406, 55.500694628684755, 27.73132185782156, 33.293576163630334, 38.75275058131064, 47.91577208426691, 34.01107572740124, 1.1906632901199403, 0.12299376915419295, 1.2520846652407802, 4.35403436422348, 17.460187635114117, 18.198817007003292, 21.77422804217185, 8.019681486391253, 36.44318842118786, 70.89661336714222, 62.780084148530044, 64.14324898873606, 60.40348083742204, 62.82514825943978, 62.46103855871386, 61.299350184779016, 58.28477728751398, 57.74833040852701, 55.25408344884073, 61.24319361102197, 59.76091815579323, 60.48976905884282, 59.735771840618504, 49.36587625934232, 44.52322390771682, 49.796834914915024, 57.01660048577094, 56.593596396907685, 57.07906423076507, 57.86051019545525, 52.316789088710664, 49.535663896991366, 48.45969500080232, 49.501221564508256, 52.078744365322976, 49.768162388955396, 53.01155851733301, 57.04856388030514, 56.209525754374845, 52.51621415538173, 43.69257573158511, 44.018516848164225, 44.317617185654186, 44.49984658148981, 44.11884323243172, 43.684683922798406, 43.16445604447396, 42.441065080704234, 42.94747837128178, 45.89634764579035, 44.23412561416627, 43.60197290297478, 48.239422536665394, 46.108955798610566, 47.715448794826386, 49.439789402869444, 48.09683261379119, 51.38646956413023, 52.914777955701275, 53.62972405649001, 65.2537896556239, 44.20697496783349, 45.94874658892232, 61.26786139703567, 55.22201415031187, 54.3000178952371, 46.53963596590104, 50.6164651532327, 50.47229451517905, 56.351880335038715, 57.31840333630962, 57.777167674033876, 59.84190333274103, 57.7897035691046, 52.10271789181618, 46.25524451655727, 42.81466299487699, 44.81520906571419, 41.48126502190867, 46.27537804265177, 42.69113186867007, 43.78267649681338, 44.468502921442834, 52.42540344115227, 52.969812731589045, 51.70458947458575, 48.222450440929784, 51.64276115355953, 53.828250900391616, 57.50180552082678, 59.9432259990323, 53.96942484763361, 53.34599941007553, 52.686982385573856, 58.02088806706091, 58.38795523489676, 61.16316941476638, 60.879731101374475, 59.494750038270034, 51.556700429608746, 52.651026018204234, 56.442181141145774, 63.170626701847205, 56.692330298885224, 50.9370247779354, 43.95937535070604, 44.525032120366255, 44.783096621113444, 58.16336816357028, 56.0819741987413, 68.251861141574, 38.778504863862075, 40.165035263184585, 69.86529673299482, 65.86675413193242, 66.10494398301648, 53.53877213693435, 22.05188282074467, 8.791538726898933, 4.285072232446363, 3.1975286670269507, 2.496340524765753, 0.2404857246625808, 1.1095628935483195, 25.5176341918207, 66.88914345156762, 33.3700623819905, 30.689775443846184, 32.917150220563336, 48.809488050399295, 56.06600230739963, 63.51719948553271, 59.315611470130186, 23.026970317286832, 0.1220195581235232, 0.19170472368357644, 0.10136522247546143, 0.10695929608998761, 0.1499248163834695, 0.1438464909311264, 0.17699624922487045, 0.2687277092087654, 0.1195755078186912, 0.12603424189071502, 0.19585882013122882, 0.15599672201900713, 0.19706786009332827, 0.1346554429901223, 0.11923061503518013, 0.15423332551313987], [0.0552177406667221, 0.04912896194465218, 0.04283897405970962, 0.021647317748096202, 0.05449627353359134, 0.06024870518294554, 0.048965846503814386, 0.06203088616471618, 0.06059747437135347, 0.07342759700071427, 0.030866655400924148, 0.03622357500717044, 0.040215417862899845, 0.016870518222511295, 0.01292316017732505, 0.04664846500682254, 13.413880371278333, 54.075140568517874, 50.95882531135313, 43.94684337800549, 27.479652781640333, 17.738283680331325, 44.496975406523674, 45.54296562748571, 46.46231820506435, 17.74201189318011, 0.2046436882547794, 0.6916663435197646, 21.398576767213886, 9.580851985562234, 4.747775120119895, 5.085439710847793, 8.699616020725621, 6.651869618123578, 21.700199188724643, 60.9065208896514, 52.44887882663358, 60.686507301945845, 58.13287173548053, 64.13847546423635, 57.31510854536488, 58.68158778836651, 55.812079829554406, 58.11309122270154, 58.181830759971376, 53.085252008130475, 53.047220706939704, 52.97256623545001, 50.90306097461332, 45.83396234819966, 43.72589626619893, 53.47054643015708, 51.62363175422915, 54.63116791940505, 52.11568916997602, 53.25896986069218, 52.12619719966766, 52.66966512126308, 54.16506874945856, 51.42342221352362, 46.99574093664847, 49.50306900085942, 49.147831701463275, 51.47979451764015, 52.6159639512339, 45.30548180303266, 37.83715171198691, 38.04788104949459, 40.51747199027769, 38.31180557127922, 40.03521657759144, 38.858772247068345, 39.50112312070785, 39.8770038543209, 40.34240092000654, 39.49116422284035, 38.97810251482072, 41.212959212641564, 41.253587122886415, 42.20214959113829, 46.52405238920643, 43.11395160613522, 46.4299076603305, 44.638702407959975, 50.20366707155782, 48.933395724142756, 61.119556580820394, 34.92192852881647, 37.99512909304711, 58.302314204554406, 49.4714625420109, 53.99652450315414, 48.213048519626746, 53.604989590183386, 48.27790491042599, 54.04887245547388, 51.308857625530614, 54.698197303279755, 50.604874549373505, 53.34792921620031, 51.27299147267496, 51.661851329188195, 39.999558310354914, 39.54603425918087, 35.93049149359427, 41.78060070160897, 39.892336399324485, 39.324369353632775, 40.956769604836744, 45.86271332156274, 50.974322595903956, 52.078885570649184, 53.322433810080256, 53.08103938256541, 53.56683669551727, 55.068202326374674, 51.193163394927986, 49.54832138553743, 48.89616066409696, 49.31936871620917, 50.08532916345904, 52.64251055256013, 52.38646999482186, 50.244373429206114, 50.04071612511912, 50.974251993240856, 53.07122561239427, 53.53730909286007, 54.884447128542014, 48.155789759851274, 43.10987234115601, 42.304896077802105, 42.16921344880135, 42.07584927158971, 46.59327045563729, 57.34575010115101, 56.18466577222271, 57.94613945868708, 60.28919866008144, 57.231299261893, 55.62723029044367, 60.289261418004195, 57.5937968684781, 31.794673781241144, 5.73884823629933, 1.8944873877110022, 5.286803899272796, 0.7850194890652934, 1.2078766116211492, 0.08965430450775931, 9.60423029238178, 33.46861977731028, 56.663281225389056, 22.337156803377216, 13.55021901669041, 27.961904271956417, 42.60512605790169, 46.767172659597094, 46.9016864222865, 19.288380838209584, 0.1690599154080114, 0.007927116342715078, 0.09305586512651175, 0.03691318820440962, 0.0656189164146781, 0.03171170017712059, 0.04985716682107699, 0.03659910747721311, 0.028882786451328187, 0.04934977912794679, 0.03668657173552821, 0.08534643889194535, 0.04178946807740196, 0.07619466827881914, 0.07498585814309698, 0.061360903970536694, 0.038164102532450235, 0.039603087615462086, 0.046865179789282625, 0.0544497681661479, 0.02669406559077963, 0.05325218887939569, 0.05969187034474266, 0.04274124039276954, 0.021697659300820484, 0.039833381306380033, 0.03065656153334966, 0.06157803244047588, 0.035412690091517665, 0.04436661849819845, 0.02993337070238927, 0.02689567694981252, 18.667204879945327, 63.922545063880186, 55.69000782505159, 51.083505692020545, 35.39084788291685, 19.506229277580015, 37.95750571835426, 42.344206071669056, 47.269726337925086, 20.07550443372419, 0.08355420683660815, 0.9187017705652022, 25.523635418184345, 11.189283613235721, 8.131580333555899, 10.167755253853338, 11.702701276348485, 4.639165180344736, 25.235409851997133, 60.89250233865554, 55.853280405844416, 60.6087855369814, 60.90636791721467, 64.87538683799006, 59.73614838815505, 57.550325239858324, 58.43611017350228, 60.07603353069675, 60.370540772714925, 54.84103825784499, 54.18565334812288, 55.925306889318655, 54.02163943936748, 46.633619877599905, 46.394347452348285, 53.71125836526194, 53.75871904434697, 55.8203403411373, 54.1573416802191, 53.72810886752222, 52.85740936956098, 52.59470470489995, 54.84617264040055, 53.64630391520839, 47.33324520049557, 49.23603403952814, 50.24163169245566, 53.504694584877264, 53.92842038985222, 48.16797264160649, 40.023053307687086, 39.401530219662575, 41.828131983357096, 39.70882046607233, 41.31121458545808, 40.752221922720636, 42.35732247752529, 40.40945383810228, 42.381649017333984, 41.15410012583579, 40.74716990993869, 40.24327870338194, 42.02015945988317, 42.98173242999662, 47.337885364409416, 45.56298148247504, 48.485355146469615, 44.92552180444041, 50.23881543067194, 51.86512031862813, 61.513295865828, 36.11940068583335, 39.74424731346869, 60.158042446259536, 52.09598710460048, 55.97897275801628, 49.39602751885691, 56.44688406298238, 52.16287920551916, 56.59034867440501, 54.9024429628926, 56.8541790593055, 51.37778151419855, 56.87559127807618, 53.455931678895034, 52.49853211064493, 41.128345843284364, 41.33025769264468, 39.01133675729075, 43.50399209607033, 41.3572592889109, 41.84185635659003, 43.164820824899984, 49.14162651185067, 51.03269923117853, 54.070414112460234, 55.77455843648603, 55.686799326250636, 56.35883077498406, 57.62331662639495, 53.45939905412736, 48.084508526709776, 47.89184562621578, 50.29611341414913, 50.098163158662864, 54.74412825799758, 53.2396835665549, 52.239341889658284, 49.80945710212954, 52.549389562299176, 54.5609143472487, 56.506323660573656, 57.46365654853083, 49.69516315767842, 43.25762410317698, 43.53551226277506, 43.93176578706311, 44.742429487166866, 49.42792423309819, 59.80078120385448, 57.04627321612451, 61.19989456668977, 62.98815019669072, 61.29265469889487, 57.94170325802219, 62.67053627198743, 58.644313504618985, 34.558069859781575, 7.109130707479293, 4.95150940072152, 5.287263306879229, 1.8463288944575096, 1.6008293388351318, 0.17201436413151605, 10.125876107523519, 42.389026995628114, 45.1994130688329, 18.45863872958768, 21.964519869896677, 39.203634877358716, 48.49472961118145, 53.20109136642949, 54.240943078071844, 26.760021409680768, 0.23176206696418025, 0.05902499463709612, 0.022524488421397346, 0.004498037366917538, 0.04601178465471153, 0.03696894025309913, 0.0493585508346798, 0.02544530396980624, 0.024757006528577017, 0.06816254282790808, 0.04572187400152607, 0.04604189957101499, 0.08974192964453852, 0.045225184726258444, 0.10716082317934883, 0.11255971291252684, 0.1648694604274727, 0.15131759487332838, 0.3190173364935383, 0.12221295702000781, 0.3582298533330041, 0.14826660374960593, 0.11917592401826575, 0.20309360127054876, 0.0936038171752326, 0.20703071097452797, 0.13192101471847104, 0.14003941699141456, 0.1090909127566603, 0.14545297730834256, 0.10339490348292936, 0.16043751921144225, 25.235527523102302, 71.08407912715789, 63.9488680901066, 59.59190322506813, 40.02634417626166, 24.51014203409995, 54.5112963645689, 56.59739717360466, 58.3493826466222, 22.020054747981412, 0.47800356341946515, 1.4950702267308391, 31.10889050268358, 17.092073194442257, 13.629676430456101, 12.042008849882311, 20.590158624033776, 14.334458689535818, 24.20753705886103, 63.37202472071495, 54.14077751098141, 64.03897277770504, 61.380060795814764, 67.8348425895937, 59.767558728494954, 61.675077945955344, 61.25587463378907, 62.03030740061114, 63.54473060177219, 58.25536735596196, 56.45047695406022, 59.036315179640255, 55.78598430079799, 52.125663757324226, 48.85631722788657, 57.90520560356879, 56.49981252608761, 58.42506870146721, 55.58132679231706, 54.777284053064164, 52.537210602914136, 55.62773235382573, 55.88998202354678, 55.334801904616825, 47.46759422363774, 51.04687859935146, 49.59015738579535, 54.90431785583497, 57.25215842646938, 50.73663873057212, 41.4537888188516, 42.329885498169936, 45.029088066470244, 42.58676936549526, 43.42823543856221, 42.50552531211607, 43.86351654606481, 42.662686840180434, 42.46063378549392, 43.812851290549006, 42.979029916947894, 43.46009685147194, 43.80002121771536, 47.21258132688461, 52.916276301107104, 47.796069191348174, 50.43114885207146, 48.576373746318204, 54.534089257640225, 53.27655776854485, 63.26757592539634, 37.77255811998921, 41.790198741420625, 61.132602384013516, 54.928765989119015, 59.54106930763491, 53.976783214076875, 59.217007006368334, 54.07625452164681, 57.762851022904925, 56.4563173632468, 58.45327838774651, 53.84536420145343, 59.38335080300609, 54.50001955032349, 55.39957984801262, 42.66040009836997, 43.04157995408581, 40.666828001699145, 44.938128302174235, 44.44998541185933, 43.443328718985285, 45.89237036243562, 49.86981061197097, 55.14368049560055, 57.93105402300435, 58.5919459404484, 58.66680045281687, 58.78300851391208, 60.34348818563647, 55.551822723880896, 49.87967145058417, 48.95012855529786, 50.84069528887349, 50.974310828793435, 56.32258022985151, 54.06654273310016, 51.31683964883128, 52.158560675959436, 52.91615863000193, 55.406973515787435, 58.96922696021296, 60.55272310010849, 53.10247905792729, 46.39604976100307, 46.622033196110884, 47.90729584232454, 48.04612028983332, 53.22216233899517, 62.69401950220909, 62.39128312756939, 63.57784717313705, 66.26663977100004, 63.091488961250555, 61.10845235086257, 64.40826000705843, 63.250854861351755, 35.11506603610131, 7.6541940531423025, 4.990257024765015, 13.384393953507947, 3.3785450698867923, 2.253669610907955, 0.4011477536011127, 13.072174268384135, 49.35918861819852, 67.12237542675388, 32.659281838324766, 24.23129289380966, 42.47689200985817, 57.05020343103717, 60.52630201462777, 62.40132831758069, 34.512876310656154, 0.6601287100103594, 0.19266565841051841, 0.18243553477429575, 0.08680622709254104, 0.09846849847705134, 0.14542234911312982, 0.24903264587684987, 0.154940654493628, 0.11904710633379799, 0.2038739077867039, 0.11566154163090453, 0.2760235628774089, 0.21542446056921638, 0.14113276235518918, 0.26111003732489, 0.1987092800798916], [0.0948337330332687, 0.015436816273347266, 0.06966745360724388, 0.02731199594094388, 0.03336519370937059, 0.03311071079224348, 0.015255384627849826, 0.01121493923898426, 0.08617694714977857, 0.009732688382838764, 0.06969913900379213, 0.022507791535087654, 0.05984561269982688, 0.06839395500719547, 0.037236078942735354, 0.04770975342140563, 27.721080549301643, 54.60151087853217, 51.3260454516257, 41.12129734408471, 24.709633781063943, 31.657557525942405, 67.56113959896949, 38.76977759022867, 48.96970902719806, 10.971114520103702, 0.05114618636247131, 0.12138512240903032, 16.178602210937008, 16.11176110083057, 7.197960134475463, 10.81189767006905, 6.5525605986195234, 4.2828938461119135, 19.025713436065182, 55.973728549095895, 54.24775623506116, 61.698627856469926, 56.2550840839263, 63.1313951553837, 57.03288616672639, 58.067289706199404, 53.196423745924434, 53.51231967249225, 47.467194141880164, 49.201285762171594, 49.30497754004694, 52.205550670623786, 49.004410236112534, 47.03377616020941, 50.75838042843727, 53.12767244154408, 54.3609832948254, 51.10367059707642, 49.932317503037, 49.949709292381044, 52.647107570402085, 54.96496554343931, 53.1291001842868, 52.61543443126064, 54.18703402242353, 53.765390996010076, 50.309476929326216, 51.54785156250001, 49.80549943062567, 46.70503054895709, 37.09380765115061, 38.32001509204988, 38.539824716506466, 39.47206620247134, 39.2648866099696, 39.55323965318742, 38.27761819285732, 40.170581494608236, 40.06644256653325, 39.88699413114979, 40.72492222632132, 43.36350064123831, 46.57584336496169, 50.705534335105654, 50.84449998794064, 52.32089581028108, 53.44105020646126, 52.031856352283114, 56.653800856682565, 52.46339159627115, 63.34415628064064, 35.100047280711514, 34.79480451153171, 60.2785925711355, 48.97881677073818, 53.67506665568198, 48.92506853226693, 53.32845072592459, 52.18752345731182, 54.020713760006814, 52.84045688567623, 51.755184127438454, 49.75710522743964, 56.789044180224025, 48.86724887355682, 53.10801352224043, 46.1225389665173, 38.67578975615963, 39.28338843007242, 39.954274546715524, 42.25891413227205, 39.96529640689973, 41.345990319405836, 49.31887841993763, 52.65027292313115, 55.21487543659826, 53.46205449873402, 53.55105307794387, 51.69396377378895, 51.396106827643614, 49.64346239643712, 54.3707460741843, 52.484996011180264, 55.079149661525605, 50.511059299592056, 49.57243611735683, 47.73201688643425, 51.0532053824394, 52.12084708675262, 53.53058222801455, 51.709845450616655, 53.67867131387034, 46.706007219129994, 44.76475954055787, 48.561770762166674, 52.49951270318801, 49.705498603082475, 48.49820483115412, 40.643156497709214, 50.44426918029786, 53.429420378900346, 56.822686349191976, 54.22752464971235, 56.49979291423675, 51.60928764650899, 57.91593720836025, 59.36679840087891, 46.92080405450637, 11.576253867918446, 13.94465256121851, 8.273430889652621, 16.381521128839065, 6.693057446710526, 0.4602159824102156, 7.282079285190952, 32.281618387468406, 29.180002212524418, 39.2659495722863, 26.763294627589566, 17.782831999563403, 37.49164189061811, 46.877850178749334, 55.37391970234533, 28.35998365955968, 0.5004256392919249, 0.07801418072513996, 0.02516447720418294, 0.07391759449796331, 0.026367340582392873, 0.05290835712765975, 0.04821205429071861, 0.03819340156511434, 0.14191536713511715, 0.04687300154698953, 0.09106887053818473, 0.09575693026906061, 0.015415204933003314, 0.037103365701172626, 0.07291510716200837, 0.031060226667191715, 0.026593926407757307, 0.05190783480723059, 0.06499409510363495, 0.03394940852998726, 0.06689182512702481, 0.032932737076114264, 0.05588579998021165, 0.0495875460065661, 0.012693547347049802, 0.008983203499097257, 0.0809314052364038, 0.05361612277826475, 0.06624106407886551, 0.03016617716169886, 0.07536563090980053, 0.09060046905952115, 36.09616456493255, 62.328803693094564, 57.82700530944332, 49.368064941898474, 34.737702646563136, 33.76469204502721, 63.761308193206794, 41.89936614805653, 52.34549691600185, 11.519753106178777, 0.05485472224292256, 0.11127641604792689, 20.85843893789476, 23.739945427063976, 10.34615053284553, 10.646060839776071, 11.267581966615493, 3.712265472258291, 18.787858947630852, 56.64033143751083, 52.90129284704886, 61.58407111321727, 58.36982211759014, 62.623926747229795, 58.47566335431991, 60.40204524993897, 55.8443570137024, 54.67524751540154, 50.96884304477323, 51.06274458669847, 51.8354985790868, 54.80360707929058, 51.067922115325935, 48.737461566925056, 52.97797126154746, 54.92080750003938, 57.310158514207416, 54.445231883756584, 50.982041820403076, 49.86793964139877, 54.09715290992491, 57.917490466948486, 55.906997265354285, 53.35267136173864, 54.90513370883081, 54.29898238951161, 50.4615197643157, 53.90988326841786, 53.16737075005808, 48.985845658086966, 39.04017402279762, 40.54701920478575, 39.22938915991014, 41.303079589720696, 40.298780241320216, 40.67576708332185, 41.50976888595089, 40.969011322144546, 41.66674606261715, 42.55858321343699, 43.55335120231875, 45.21044277375744, 49.409069399679865, 51.946493810223, 52.12967241964033, 53.697165289232814, 56.573984546046105, 54.34064188311177, 57.367425118723226, 53.97388458251954, 64.04762552630517, 35.79889205194289, 36.01046469903762, 62.217765315886474, 49.82725681797151, 56.43084941371795, 51.009039494299124, 56.878023147583015, 53.28133129304456, 56.7845412992662, 54.11399948981501, 52.618329140447806, 50.14614159061063, 55.38480427957351, 50.8323916312187, 56.12607732895882, 46.126516249872026, 40.717297138706336, 41.20671479932724, 41.84431568268807, 44.187331738010535, 40.98435171188847, 43.687202084449034, 51.26468781502017, 56.325584765403505, 57.05451803822672, 56.024444795423946, 55.43461445839175, 53.433699684758345, 52.65541907279722, 49.05468717698128, 53.498862020431034, 53.68629640148532, 55.009064751286665, 51.981881433917636, 50.697156152417584, 47.869931344063055, 50.96141015329669, 52.47677864566926, 54.64840673631238, 55.44659729926817, 56.43863531851, 50.144690313646876, 46.170034946933875, 50.573248478674124, 55.834151006514034, 53.146860676427046, 49.69126432172714, 43.482262165315696, 52.3571071317119, 56.67591125734391, 57.422765839484434, 57.09664037150722, 56.986653189505304, 57.0474930732481, 60.149609350389056, 60.62076053311748, 48.4161723813703, 13.206650768556903, 4.858001076406048, 5.779003010642144, 19.52573130207677, 7.169201806668313, 0.3047894902767674, 6.733720658286926, 38.9570786106971, 42.51141278974472, 35.25036035045501, 25.924954683549945, 24.91812932875849, 44.44094434861214, 53.074873416654526, 64.18523403906053, 38.830209547473544, 1.0959647716053071, 0.07899183149058973, 0.02281342805813878, 0.04829995138871093, 0.041172809433192015, 0.12173515564251332, 0.03244509146879277, 0.02075572738484029, 0.08187776897102594, 0.07629062845221452, 0.0630816025659442, 0.06372165370492205, 0.049280609049263506, 0.023008686633059577, 0.031216594788636413, 0.04594439190001257, 0.2562739387635262, 0.1197131355142882, 0.15566715099398168, 0.1372932982180388, 0.10167950238551825, 0.16695260671117615, 0.2242804982609326, 0.1458307965508392, 0.19827948943261178, 0.0835327027485736, 0.14458414167165756, 0.18516930421033215, 0.11475665389650291, 0.12983141797444514, 0.16580779556064837, 0.5924659246398557, 43.169578659919004, 69.81770269332394, 65.48788062987789, 55.30147744763283, 37.033363926795225, 43.02261921667284, 75.68272083036362, 49.692594005215554, 60.29021063158589, 13.873818478276654, 0.19701077122121088, 0.2520123448583388, 22.61784161290815, 20.969983300855084, 16.999364053049398, 18.512243801547637, 17.540825682301676, 10.660772669699885, 21.056904985058694, 54.99704660907869, 54.00327097985053, 64.52658614804669, 60.95457776900261, 66.60245741567304, 61.82864658294186, 63.648014453149614, 57.94814378984513, 56.835539956246656, 51.356561491566325, 53.02385907019339, 54.33616253637499, 55.93791338705248, 52.85966081003989, 51.22536997641287, 56.14442617662492, 58.403648637956195, 59.07202051531885, 54.98598944756293, 51.563258632536865, 50.45343183702039, 54.810490838943, 60.55776334577992, 58.907614369546216, 55.88960547601023, 56.79374317969046, 56.62160996467837, 51.419205665588386, 55.90718946149273, 55.46971967143398, 51.660851124794256, 41.03306754942864, 42.804547202202585, 42.37359639137022, 44.12213802337647, 41.98823528905069, 41.26868040330949, 43.476468824571185, 44.230819056111, 43.12030976818454, 44.944298190455285, 45.016214847564704, 48.37560330667804, 52.458520012517134, 55.6110034450408, 57.084045640883915, 57.89770603179932, 58.285734345836026, 56.568775638457275, 60.93783709310717, 57.53818942654518, 67.9892349243164, 39.11802914834792, 37.13449831931822, 65.19382838279971, 52.12283965080015, 58.72700099022158, 52.893326513228885, 59.13905382156373, 56.862976935602006, 58.81097501324069, 55.63722448964273, 54.03041770381313, 51.13751672929334, 60.46542682955342, 53.9793013757275, 58.07856652044482, 50.943873236256266, 42.059473376120295, 44.282751237192464, 43.90815704099594, 46.77116563243251, 43.575524360902854, 46.32875365595664, 53.28980361261676, 57.4950433546497, 60.18884089685256, 56.97033612958847, 56.25715509537728, 54.96575393984395, 53.697612439432454, 49.75556765833209, 55.05562328523206, 54.60595884630757, 58.28588731827275, 52.999673735710886, 51.30018526507963, 47.72664716166835, 51.773831075237645, 53.866784264964444, 56.064260775043124, 58.09632701258506, 60.07599430699503, 51.666864118268414, 49.031074508543945, 53.32961174749559, 57.63747638271701, 54.915292647577104, 53.6990794058769, 45.591477501776914, 54.51302612981489, 58.3904145609948, 62.04744031352382, 60.58143484976984, 61.028165355805434, 56.95228538205547, 62.78438698860907, 64.62988568890479, 51.06939300414055, 14.06719917251218, 21.97436501902919, 17.37778256016393, 21.010597482804332, 8.42635331615325, 0.36181134502253226, 9.583305428105017, 44.93286055903281, 43.64365200842581, 54.478164103723344, 37.5393065329521, 26.84909647510898, 50.14168970046505, 61.811246948857466, 70.60490669742708, 48.50049157296458, 2.2982581344343003, 0.24671401948698107, 0.09804645297868599, 0.16980272958115225, 0.10317965575884427, 0.24599849336570312, 0.1271091475181522, 0.13035002885566604, 0.22289171875003846, 0.15005780924712459, 0.26988750503909203, 0.19922678779450156, 0.144932389920277, 0.13682292023253056, 0.1626424887968648, 0.19604185385809791], [0.05963582718264192, 0.07553875145892944, 0.04770441761901302, 0.038746513216005224, 0.07574578672046624, 0.06700052534260097, 0.05657398059303242, 0.06947688923607911, 0.04131270474904487, 0.03537691761589339, 0.0760847729660811, 0.07131334754728502, 0.07107409828853223, 0.08332570579143302, 0.035454127787342, 1.5244395862663946, 38.811648891818145, 53.92602774404711, 50.11604524427845, 39.53871511643933, 21.531688282566687, 22.108078618203443, 52.39619355047903, 37.274864258304724, 44.29047830643193, 6.022612106415534, 0.032564264106293844, 0.23382592315395034, 6.5508779018156, 11.270094244710862, 7.9843173969176515, 10.661518900625168, 10.187633825886635, 4.288759750704612, 20.45820224669672, 50.27363038832142, 60.01858649715301, 56.207705774614894, 54.56297751395933, 52.56608709212273, 53.59048858765633, 51.01222053650887, 49.251664684664824, 43.654842530527425, 46.18569304866176, 50.07253439195695, 55.34832623697097, 52.427105749807055, 50.42805802437567, 51.12694986404912, 51.39593032098586, 55.759237658592966, 52.929200510824884, 49.33989840169107, 51.15256294127434, 52.16789591696955, 55.06728449175435, 49.84822188654254, 49.75884675979615, 49.297497580128336, 53.613763932258856, 54.741378676506784, 51.16980568055184, 52.246362932266734, 51.549212624949796, 41.427877641493275, 37.59218008287492, 36.68480250143236, 37.43933708437028, 38.554513992801795, 39.802894592285156, 38.43799998683315, 40.16730239314418, 38.246960947590495, 42.60366693619759, 45.33294231660905, 44.67140320808657, 47.1845716814841, 52.875377747320364, 50.81778472469699, 54.451154662716775, 53.11406181704614, 55.532250096721036, 52.76946590792749, 57.04395509535267, 51.130605513049716, 56.10303340419647, 29.629790206109327, 30.653507248047863, 55.46569531963718, 51.9486471914476, 55.502726416434015, 51.73350910986624, 55.41919562124438, 51.22886873060658, 49.66396462532782, 44.542733776953916, 48.257332078872196, 44.745763501813336, 42.59882280903478, 51.36753236093829, 55.67195707751859, 49.86217767961564, 42.08483934402466, 36.130653965857725, 40.12083015134258, 39.32766022220735, 40.048760521796446, 39.149011950339045, 48.68776513684181, 54.245363589256044, 54.89683005117602, 52.51765758760514, 52.1275229607859, 49.18982851889826, 52.630433574799575, 51.35154478011593, 56.51000284379529, 53.41432709847727, 55.109881431825706, 52.29101911667855, 51.59863841149115, 46.984444510552194, 52.39276539894843, 52.965729544239665, 53.65922028018583, 50.28210270789362, 48.03376482379053, 46.043879755081676, 53.501642980883204, 52.35407121719853, 58.597178382258264, 52.9541624746015, 55.94872343924738, 46.60100144724692, 44.92585520590506, 43.23732975990542, 49.37174804749028, 47.53315271869783, 54.63299574390535, 53.064208492156006, 63.80026909612841, 58.82204394186697, 52.08745594947569, 18.461254950492613, 7.6010586850104795, 1.0057831074922317, 20.36158838579732, 3.589284948764309, 0.16017689609960203, 2.198817470381337, 34.063627642969934, 30.39463670023026, 43.82692867709745, 74.51891437653573, 22.110939987244148, 30.338715468683553, 48.568866329808394, 49.233119718490116, 39.66974581441572, 1.5940400837890565, 0.15378209972573867, 0.0870675013791169, 0.05130203928978694, 0.022632131435637994, 0.0339002524983258, 0.02609963115725306, 0.08277693402863319, 0.07643413970306998, 0.034062666968712886, 0.041772648617024385, 0.04433261951611889, 0.09061446548589776, 0.07312101627429647, 0.0649126369746462, 0.008095806509616875, 0.026255692843528047, 0.029509216547012333, 0.08901830597390091, 0.036393045147340146, 0.037547355788129, 0.03410471753487664, 0.05653651506309548, 0.0034328390310909003, 0.047388027136724804, 0.10191310557626909, 0.030583312036469582, 0.04549295926887182, 0.05461212517994066, 0.04484293749555946, 0.05982132388218757, 2.507739667930911, 47.99072073351953, 59.137492718235144, 57.84720551583075, 46.00320477639475, 28.83299404574979, 23.10949698571236, 50.98027675382553, 37.28826307481335, 48.36632690122051, 6.380506811603424, 0.16813248936687747, 0.2951402145047342, 8.048626126781587, 13.704039665960497, 9.54537610853872, 14.23758791339013, 10.388249331904996, 4.46497223069591, 21.007736113763627, 54.369283030110026, 60.021253708870184, 59.31490936586934, 56.168160438537605, 54.388537945285925, 55.06851219361829, 54.24064890030892, 51.084898133431714, 46.696036554151966, 48.31155884650446, 53.007039946894494, 57.40795889208394, 54.792063543873454, 52.779781741480676, 53.51246872255879, 53.24598289305165, 58.53446360557311, 54.470758668838016, 48.60263009225169, 52.82586959100539, 53.39023590087891, 56.53759279558736, 52.959775386318086, 52.51049141730032, 52.094896685692575, 56.28134827460013, 56.15890756730111, 50.19085661057503, 54.86491372508388, 51.85383565964238, 44.88319158554078, 39.71130332639141, 39.42393087571667, 39.91732581969231, 38.68557606973956, 41.363817491839015, 40.442213473781464, 42.607597151110255, 38.972191502971036, 43.44332087424494, 46.76324244468443, 45.990025612615774, 49.72802085261191, 53.733533505470525, 52.11636381764566, 55.69859389335879, 55.97962779383506, 56.873355527077955, 53.82132791703748, 58.46456304673226, 52.48228957576137, 58.59569180396296, 34.089068135907574, 32.7076760415108, 55.896583372546786, 54.70266096053585, 58.500370364035334, 53.68255838271111, 57.799454581352975, 53.0415960281126, 51.11382561345255, 46.772718891020745, 47.970143979595555, 45.28813708213068, 45.423764797949026, 53.912456343250895, 56.64884298078476, 51.7588044751075, 44.55469700597948, 39.014066726930686, 43.198423770166215, 41.410478007408884, 42.488470846606845, 41.72117287112821, 50.121693457326586, 55.52257360950593, 57.391371188625214, 53.990044747629476, 53.978454143770286, 49.9959187353811, 51.6098524678138, 51.28242869530955, 58.22331374691379, 56.527810404377604, 58.26612249497445, 54.265046042780725, 51.827936249394575, 47.636828807092485, 53.08064714554818, 53.630269265943966, 54.50601685431696, 51.93546802766862, 50.8971695746145, 48.89757663972917, 54.41105235007502, 56.22453274265413, 61.03611992251489, 56.580719255631976, 56.33406492971606, 49.46035831205307, 46.317759252363636, 45.93816403419741, 51.049683094024665, 49.9451397311303, 55.529896674617646, 56.73276209062146, 65.15709538613596, 64.12673188794044, 52.7770439271004, 20.349556515293738, 6.609247182646106, 3.627920540109758, 24.269973347263953, 3.332194421560534, 0.12374898629082788, 1.8647059341592176, 37.33873221182054, 33.39601278305054, 48.87218321523359, 68.85305066262522, 28.295584224885513, 35.34427758186094, 52.80039771910637, 54.940321291646654, 50.27989833585678, 3.726426209172895, 0.20467928069974148, 0.0743888458237052, 0.07890990604796717, 0.022276842838994438, 0.0061744096362212255, 0.019179277399915363, 0.02124882179252323, 0.048395900070787444, 0.08884128603723743, 0.09087536438939073, 0.04609964344830764, 0.022509731652755893, 0.02913445782577319, 0.06266974603697177, 0.021042098711815574, 0.13900092352301846, 0.1474753421761336, 0.15528289661292108, 0.21913961927977302, 0.1748132203975993, 0.1995357204108469, 0.18372228669543422, 0.09269306886821024, 0.15198606787429703, 0.16410058394314783, 0.18493995280756106, 0.23781989190366962, 0.19644472417571854, 0.1154154665287464, 0.25469150754713243, 3.798058249296681, 58.3809067356971, 67.85637640183973, 65.01832977417978, 50.55209513633482, 32.26477769113357, 30.497573421847438, 60.8471126710215, 47.401349313797496, 56.47467013328307, 7.116504763403247, 0.31131092098451435, 0.8329920374578046, 9.296108503495494, 16.159581657378904, 15.89580422447574, 22.26193162702745, 22.26359078961034, 9.65874437362917, 25.988285272352158, 55.04030642970916, 63.14457431916268, 62.04254519554877, 59.01737797644831, 55.42547141352008, 56.87055103240475, 54.52024329093195, 53.16728053554412, 47.87223769772438, 48.97813035595802, 54.581369507697325, 61.15055507229221, 57.23473525816395, 54.70379060314548, 57.240081448708814, 55.24048066908314, 61.6543129182631, 55.3715584355016, 48.618731421809045, 52.77235277237431, 54.705132053744414, 58.56109257667296, 55.30959675388952, 54.558349117156006, 54.12855932789465, 57.84122390131797, 57.0651045153218, 52.182844069696245, 57.11719751358033, 55.885639959766024, 45.53674867076259, 41.182776574165594, 41.770798698548354, 41.317627660689816, 42.26286395903557, 44.17812593521611, 42.78653567837131, 45.05031593384282, 42.16243951551376, 46.17833075984832, 50.79340327170588, 47.887491795324514, 51.94912179823845, 58.26045859244562, 55.65593027299451, 58.11027496091781, 58.02497125441029, 58.224976831866854, 56.34541626899474, 60.38078600360502, 54.5865588034353, 58.45393342356528, 35.66768484730875, 34.44900835714033, 55.829071537140884, 58.09798225279778, 59.870014959766024, 56.289710767807506, 59.77519166085028, 53.740860492952415, 52.70801413443781, 45.85901844886042, 48.63406004444246, 46.64851703951436, 47.08799900547151, 54.46221574660271, 58.86965367101855, 54.51501869386243, 46.41216678004111, 39.889771169231786, 45.931405790390514, 43.4142247323067, 46.164006263979026, 44.3161266849887, 52.41203600360502, 58.42715148002871, 58.48711275285291, 56.731832488890625, 54.79313827330067, 51.147616832487046, 52.70424865907239, 52.380398165795114, 60.566094460025916, 59.09848082450129, 60.24266366035708, 55.486107334013916, 54.12189522097188, 49.41435675467215, 54.3934291408908, 55.85999550357942, 56.224160117487756, 54.29078071348129, 52.29031309004753, 49.92379027028238, 59.211974605437256, 57.3510649127345, 63.761112074698175, 57.611867227861964, 59.974679485444106, 52.42399138789023, 49.97266300262944, 45.433162796881895, 53.97037013884514, 52.25833400603264, 59.642439042368245, 58.24001519910751, 69.11021694060295, 65.81601435138334, 56.379725240891986, 23.63241953234519, 12.086729753401972, 6.536937307926917, 30.23852832855717, 4.505230457552018, 0.187796097128622, 2.8631772533539803, 44.2618763831354, 41.91924864246, 58.276340269273334, 87.07018513833323, 34.25502361789827, 42.4565270639235, 63.07354411771221, 62.993041392295595, 60.34259780760735, 6.011549551640788, 0.5901235342025757, 0.46792126410911167, 0.17373728055146434, 0.07211885069526973, 0.14905663958239943, 0.0987102298606788, 0.17067014029429806, 0.19215829370002593, 0.1199277627071546, 0.18254778197696134, 0.13810069360319646, 0.2607031220630292, 0.11607262441107344, 0.12513097060183365, 0.13185522308753383], [0.041426047457442175, 0.02006031490201431, 0.0460141595272768, 0.018657732401944457, 0.042114990327747605, 0.05688366780598318, 0.048890179999533205, 0.049431662435733506, 0.010248387172337501, 0.05625857070328728, 0.0401979242451489, 0.04796008414198314, 0.05028173657915285, 0.1459615217942384, 0.23368778217944408, 5.366995286556983, 46.45555603888727, 51.39614997371551, 44.273906292453894, 25.526514437890825, 18.22409668276387, 29.824271125178186, 54.01088037798482, 45.460211461590184, 41.524520920168975, 1.9210157255011222, 0.048869415186345584, 0.32677348643060655, 9.215858770954995, 4.6316994390180035, 5.041002688869353, 7.894371565311187, 7.313192015694034, 5.24330432376554, 30.135664170788182, 56.25248355250205, 56.45479156124977, 56.03464295787197, 55.37365690354378, 51.917221161627005, 47.6186917674157, 44.61320307946975, 42.64710326348582, 43.88775287135955, 49.23377475430889, 56.14441048714423, 53.85199300704464, 51.53036171390165, 55.483632318435184, 50.69160992099393, 53.725367130771765, 52.36969009522469, 51.748794586427756, 51.64325144983108, 54.1656453378739, 53.43358985839352, 52.83130207369405, 52.37070598909932, 46.38352171067269, 49.642940721204205, 52.688323836172785, 51.140536954326016, 54.815840951858036, 51.60209794198313, 51.12519264221192, 38.84155696438205, 37.28432501516035, 37.813919513456284, 39.459934311528365, 38.496415845809445, 39.15946506684826, 38.77759095161192, 39.32969200995661, 38.75127184775568, 43.657211642111506, 44.488467785619925, 48.08214725986604, 47.68559955781507, 51.27600777533747, 49.35826293883785, 55.24197509211879, 52.491373785080455, 57.50379416250414, 52.650563178523896, 57.295630055089156, 46.734687589829974, 56.383420113594305, 28.603984502054033, 25.47262695527846, 53.671297257946385, 42.44354009628296, 51.71743131452992, 45.556960644260535, 46.83214672150151, 41.16100741970924, 46.580456072284335, 46.04868858091293, 51.40515573563115, 46.32090499324184, 45.31092213046166, 43.14369493915189, 52.809732960116484, 53.589143214687226, 48.40399342198526, 38.01022629584036, 36.88836174626505, 38.96074210443805, 39.19209526431176, 36.047699759083415, 46.19835838194817, 52.885595521619244, 54.187865564900065, 42.884041878484915, 52.00572944456532, 52.40837250986407, 53.26401795110395, 54.2628534378544, 52.391859331438624, 51.34521015228764, 52.130319610718765, 50.544599486935525, 49.536734704048406, 48.97389027380174, 50.73041392910866, 54.18388435917517, 52.989530486445275, 51.02931422571982, 51.860758642996515, 52.65356771407589, 53.660667634779415, 57.26067389211347, 53.206731734737275, 56.422016236089895, 56.53436076256537, 53.67765149762554, 50.85775367675289, 44.48098782570132, 47.83941530412244, 52.763327398607814, 57.133502806386645, 60.98706676113991, 58.44744582330027, 48.98167225622362, 55.65984087605631, 28.287784591797863, 4.467361444427121, 0.5964525236237435, 13.247142376438266, 16.979518821162564, 0.04788747815895946, 0.6195145280611131, 21.128878516535607, 58.23359035676526, 51.08046977750717, 67.4462769108434, 31.72142351827314, 22.850092995551325, 43.08356500441029, 49.81095544753536, 49.940244613155244, 8.660511951292715, 0.24045468277988896, 0.1004962872473463, 0.09477488981980471, 0.026094592213931105, 0.049055467299636335, 0.06718524446290347, 0.09867425437175459, 0.09038765749503529, 0.023271462451967023, 0.08512314724465532, 0.02725676674726269, 0.12842932385542702, 0.034014039537719185, 0.025771159468398943, 0.04331054714237971, 0.004021637930324481, 0.03014054577497225, 0.0794475618749857, 0.09275104640231979, 0.05540622127873283, 0.06884641419615477, 0.03111743428293736, 0.023924328326698274, 0.029310508661212462, 0.021554893070471384, 0.009408570946224276, 0.008019864213682951, 0.06658284654540401, 0.05793172588211395, 0.19679225230168915, 8.341713470797385, 54.350600780979285, 58.10374813695108, 51.049718395356216, 32.364917762817875, 26.67586107407847, 25.26157206104648, 56.09458069647513, 48.570905962298, 46.23216136809319, 2.14033811803787, 0.07940780957259479, 0.3142423411050151, 11.676310589236598, 6.882004391762519, 7.126319514166925, 11.726066835464971, 8.254035749743062, 4.363539738039817, 33.00015149577972, 55.38520043896091, 58.86605685757053, 57.09025867523686, 57.69078139335879, 51.79683969866846, 49.52759950391708, 46.439756731833185, 44.16541353348763, 44.488608990946126, 52.83270235984556, 57.80605593035298, 57.10621487709784, 54.38564715846893, 57.333837862937685, 54.35815134356099, 55.415418378768436, 54.1780125710272, 52.48918902489447, 52.241071654904275, 57.338846729647734, 53.89038908866144, 55.46008633029077, 53.73945628443072, 47.75980687910511, 51.60875028179538, 54.69960935654179, 52.19128501030707, 55.88052911143149, 54.83230706184141, 52.28452367167319, 41.17703814660349, 38.78882461978544, 39.698869412945164, 41.70373793571226, 39.66212464917091, 40.49758949587422, 39.78163534595121, 40.98449291721467, 40.236277272624356, 43.49870866344821, 46.75029862311579, 49.50460264759679, 50.81252874866609, 51.878621116761245, 51.29051270023469, 57.528069711500606, 54.28632097859537, 58.95727942066809, 53.4145075275052, 58.19773204864995, 48.93034019777852, 56.04220136519402, 29.791489916463053, 27.690727287723174, 51.55077372827838, 43.183236352859005, 52.91997901854977, 46.96589562200731, 47.9892655341856, 41.42018587358537, 46.44667187044698, 45.97129629504296, 50.77408559860722, 46.97349717540126, 45.17004236098259, 44.27097628193517, 55.19690705883888, 55.74477195739747, 51.62166272440265, 39.742227292829945, 40.97713455077141, 39.2994583806684, 41.407179294093964, 37.8164533645876, 47.949155376803496, 54.21611055251091, 55.59913435289937, 46.77247962644024, 53.89868097920572, 50.997484191771484, 53.09152780040618, 56.20110050324471, 53.49564567688973, 53.078156440488755, 54.14566086184595, 52.491377707450624, 52.60990388931767, 49.09958654834379, 49.874956761637044, 54.24559108672604, 55.23287519331902, 53.407953246947265, 54.89251936635664, 54.748152609794374, 55.39994462843865, 59.267672261884144, 56.35896413556991, 57.02883043596822, 59.373070270784446, 55.03672138337166, 52.703781897021884, 47.9945921128796, 49.484853513779186, 54.597623809691406, 60.54046569332, 61.88612107307681, 60.298816311743956, 51.03297771946077, 57.74241155193698, 29.96907130364449, 7.484303943572506, 2.393558736770384, 15.91922861914481, 17.86222469422125, 0.06266140716991599, 0.5769205297673903, 23.797500325787453, 55.6690937472928, 55.5748313473117, 69.41922910751836, 32.31796699185526, 29.902353748198482, 48.77883472750264, 57.443821122569425, 58.10210074147871, 12.620151504393547, 0.21965257643211275, 0.10971795572268386, 0.04240665915271929, 0.030972408093211633, 0.03639794811005554, 0.0219601440063167, 0.04878091287889308, 0.02768654781844347, 0.07832808525211389, 0.051383838327901984, 0.03262180497028655, 0.00519616180099547, 0.010894469338499252, 0.042320673444098046, 0.06141963993169128, 0.15117027616548925, 0.09825512766838075, 0.17136619246054083, 0.20108415264516108, 0.18790872737524972, 0.16933817386386857, 0.16068426081009451, 0.14362237956975737, 0.0799572937971642, 0.14311484631992158, 0.052761701085875114, 0.08314148462828129, 0.16493399567421407, 0.19718674161741812, 0.3427301785878597, 12.140832966373814, 67.21729678492393, 65.40680523841613, 60.03699025800152, 35.55802322203113, 28.843609940621164, 41.444528102874756, 66.23206800030124, 57.74370985646402, 50.87893055331323, 2.427865992630682, 0.20271745209972705, 0.32428578443584904, 16.707096484399614, 8.40881443792774, 16.686908045122703, 17.13564092113126, 17.36389148619867, 9.92552928386196, 34.388827431586485, 57.861588847252634, 59.96246522472751, 59.52902370883573, 59.96184156787012, 54.03934894069549, 51.044658537833925, 48.80867219740345, 45.90860897494901, 48.412030358468336, 55.22799968719483, 60.79540798741003, 59.46552053574593, 55.60242522147394, 60.717654843484205, 55.16259024220129, 56.730232161860314, 53.69706330760833, 52.20531925078362, 54.371546237699455, 58.86943009591872, 56.405632495880134, 58.01477701433244, 56.423459668313306, 49.75244545167493, 53.96741267173521, 56.82849930178735, 53.964231629525464, 56.56389620996291, 57.36400481193297, 56.77723392363518, 43.35161585961619, 41.48005300952543, 42.176265870371175, 43.66134189790295, 42.65816434737175, 41.61794785530337, 42.84057809460548, 44.66429979570451, 42.93817450923305, 47.87068836150631, 49.22338047335225, 51.34853239982359, 54.03606983923144, 54.385439272849794, 53.54663648912984, 59.788841509049945, 55.84150152821695, 60.27752176407845, 54.207548018424745, 60.347453701880674, 50.43132143635904, 56.63803685096003, 33.0237014062943, 30.883713114646177, 52.12111773029451, 45.64042083678707, 53.38530548157231, 48.027049726055516, 47.929708265489154, 41.16732635805684, 47.1871369115768, 47.27800646135884, 52.20249514425955, 49.607670768614746, 46.88253348873508, 45.77225954301896, 55.585519806031265, 57.60248099603961, 53.78027639081402, 42.353941394436745, 41.72462063450968, 42.4124631574077, 44.40325429362636, 39.55258069499847, 50.071475352010424, 55.872496097318596, 59.13826934752926, 50.02942362139302, 52.52088569825696, 50.93142363332933, 54.66630843377883, 58.068446805400235, 56.3631179255824, 56.77846554786929, 57.04841090786842, 55.56281320510372, 52.77827947370468, 51.10085825766287, 51.37992705068281, 56.66418729289886, 55.88003489278979, 57.157923483079486, 57.39827063775832, 57.151169161642756, 57.68186976832729, 62.741876340681515, 58.3890260419538, 60.54028918666225, 62.9379830821868, 59.24500488465833, 54.644892292637984, 50.564121123283144, 51.81826368454964, 59.80341703661027, 61.93218146601031, 65.4745602607727, 60.41182371877856, 52.345665577919256, 57.28424341447892, 33.60219217115833, 6.501660491189649, 6.524984375123055, 18.172352775450676, 20.198256969451904, 0.3237170714043802, 0.5886626964615238, 30.306463779941684, 70.67274801192745, 61.50652585491058, 72.88203870096515, 42.04028121886715, 32.6881799005693, 58.613162040710456, 63.698966041688, 68.42373940252489, 16.786077330189368, 0.3632363604922449, 0.27794635163680204, 0.21662838306398163, 0.15110169597450765, 0.14647296209248806, 0.15022208914160728, 0.23181212314915275, 0.2058017680481557, 0.26078218233681494, 0.15029889711689565, 0.1455448159287053, 0.1654908036993396, 0.14976784496778442, 0.11113491960831227, 0.10859133149947851], [0.10775972773591358, 0.025379751741345373, 0.02251444883914965, 0.03334105810931614, 0.02147354219379204, 0.028035901148893663, 0.07250206319675331, 0.03537544289663915, 0.01515441615464947, 0.023245800421723438, 0.045746499897852066, 0.13919120444165123, 0.035220202839662956, 0.02690225764508209, 0.15420246749154984, 13.073378436027035, 50.92850538992113, 48.08675212244834, 37.64726584957492, 28.681904346712177, 20.417291925799464, 36.29866084744854, 35.027910970872455, 47.41436766039941, 29.378077983856205, 1.1799750765485149, 0.18979216985885175, 6.414902075644463, 9.15500613950914, 7.130739535054854, 6.960950916813267, 11.33810127935102, 12.133217684684261, 15.434931612783863, 53.25127024804392, 55.19264736483174, 58.80138481816938, 55.82435684819376, 59.47502443867346, 53.250305344981534, 54.38858109135782, 42.795721869314875, 42.453761792952015, 42.80750074694234, 55.61800879816855, 52.0220818058137, 54.76197504228162, 54.88700451389436, 55.99308544589628, 52.83916250351937, 54.99867831507037, 54.0584744176557, 54.971896371533795, 51.62533406288394, 52.44966722303822, 51.27113619158345, 50.63749690209666, 43.87661726244035, 42.53185226071266, 43.97663377946423, 50.638924644839385, 53.28005260036838, 53.64095772466352, 53.60224000869259, 47.943970003435695, 37.92635033207555, 39.048658109480336, 36.391193482183645, 39.76252555847168, 37.780508764328495, 40.182364294605875, 38.848679988614975, 38.40593068830429, 39.05797373863959, 45.80758048642067, 44.686841657084805, 49.98912911261282, 48.49713402409708, 48.32632264783306, 46.5804325380633, 49.796846682025546, 47.60245707727248, 53.18008315178656, 50.351571806015514, 55.57028924265216, 51.21370092515023, 60.86989771935248, 31.823130576841294, 26.641075534205285, 50.18331389273367, 42.5219561207679, 50.58426641648816, 43.21044975711454, 47.06610825753982, 47.854936122894294, 52.24784951056204, 52.11220218289284, 54.404137211461226, 51.135437873102006, 55.87276281849031, 48.116526834426395, 49.00597133944112, 53.48701254014046, 49.5644344822053, 42.00949453538464, 39.52533198941139, 38.126956032168486, 37.08460969309653, 38.90974736982776, 40.28683270177534, 51.02086544036866, 53.55281422215124, 49.921719258831395, 50.8339213555859, 52.1958859505192, 55.857720528879476, 51.546341449983665, 49.15591570638841, 46.16266481338009, 47.23484862235285, 49.79138674274568, 52.28891672626619, 48.694837170262495, 52.959634180991884, 53.53381818340671, 50.7917990223054, 51.17690124819356, 52.803045318972686, 53.17725120052215, 56.14545775998024, 53.29251004803566, 49.94455137560445, 53.375829035235995, 59.69208448163925, 56.21519750164401, 56.268478978064756, 53.88214426655924, 56.69058876652872, 55.05617633942635, 56.38877807124969, 57.82240829160137, 52.202255879679036, 47.30007763831846, 39.851834004925145, 21.404905511486916, 5.094219936478523, 3.5424530746475345, 9.566407857402679, 29.288751886736964, 2.6930500855368953, 0.06270867096440447, 13.051810303042013, 43.87062780318722, 63.443325565707305, 67.08379499373898, 39.18918878801408, 24.99292500557438, 43.702162004286244, 44.083643882505356, 55.57838109231765, 13.739309618549964, 0.07249906779296937, 0.036636519380995346, 0.033819954992542346, 0.016354356907428275, 0.07666679294479471, 0.011667091035163932, 0.07379888151321681, 0.044784726304633, 0.05646885800806265, 0.060194450836147995, 0.004568999133733732, 0.0354699130290218, 0.06643174336321893, 0.04881683474166259, 0.03064388852386225, 0.013103984698142498, 0.028620119799949953, 0.04780512753753893, 0.14375040818366314, 0.05750861169109422, 0.016076579171743606, 0.04516023962247757, 0.08735691407515157, 0.08380136212273952, 0.04937402581075027, 0.05170938356088535, 0.119955824507821, 0.045662586457066, 0.026926473684368596, 0.047248177786147406, 17.862371783102713, 58.91708689351236, 55.82336056616999, 44.07949401486305, 35.72384534343597, 21.45345464829476, 33.34726164417882, 42.64406342660227, 51.622200089116255, 33.82255877217939, 0.7689080471473356, 0.21817591131454517, 7.219849901814615, 12.784316424400577, 6.22235635595937, 10.866092078147396, 10.625981246271442, 5.104094503387328, 16.081854008859207, 52.09045264028734, 55.392103810464185, 59.51530325797297, 57.888735571215236, 62.158968987003455, 56.951387159286014, 55.69058833583709, 45.03542661666871, 43.033727369000836, 45.690313385378936, 56.03246604242633, 53.44786728582075, 56.43295180413031, 55.97591723165205, 56.878431074080936, 55.189787956976126, 56.49734535524922, 54.400234453139774, 54.95239042466687, 53.81029036737258, 54.89463352387952, 51.91389106935071, 53.71821272757746, 45.65659669137771, 43.91990061729185, 46.56740242435087, 53.334808887973914, 55.506417366766165, 54.61953024710379, 55.38774213483257, 50.17709301364038, 39.118225266856534, 40.01489870009884, 38.343482632790845, 40.32430702640165, 39.98009158718971, 40.54935301503828, 39.83840380945514, 40.45738912397816, 41.21241400318761, 48.01125826374177, 47.263983987992816, 51.60636155836044, 49.43564737996748, 50.751614339890025, 48.45679244687481, 52.02099530927597, 49.69382955181984, 54.924757326802904, 52.34276302399174, 57.89668229318435, 51.41728762657412, 62.918002528529016, 33.17621884807464, 26.806030811802035, 52.12584418635215, 42.89507550577964, 50.58458805084229, 44.220209044794885, 47.54392746956118, 48.581221795851185, 53.710175791094386, 53.046993209469704, 56.26982435103386, 52.673579646695046, 54.66688109982399, 50.01249467172931, 50.85488642415693, 56.02153831912626, 53.7458772044028, 43.35572650355678, 40.800168975707024, 39.51009358129194, 39.60492080257785, 41.02189663917788, 42.311634709758145, 52.99146029257005, 55.57768683279715, 51.68346358883766, 51.52134026250532, 53.64926922705866, 56.61761699184295, 53.0036392519551, 51.994636981718, 47.35390824656333, 49.28840160369874, 53.46416081151655, 54.84008512189312, 50.26351067327684, 53.73560451692151, 54.66783815814603, 53.5975920000384, 53.60823339031589, 55.304066211946555, 55.07149711731942, 59.68833861812469, 55.30668243285149, 51.20743689998504, 54.59243451395343, 60.145549697260705, 59.599030171671224, 57.99309807439005, 56.63093736094814, 58.518727056441776, 58.33921194076539, 59.505050182342536, 58.483896409311605, 54.161840638806744, 46.7113769438959, 41.92904672315044, 21.931283666241555, 6.729869381073983, 2.330767228718727, 12.498825730816012, 33.85585969494235, 1.9331981169600643, 0.06523198072588252, 14.461036516774087, 48.1031084060669, 60.62617340395528, 73.08422119386735, 45.458921001803496, 31.817341158466956, 49.05054907644949, 51.38748153563469, 64.07077535506218, 18.792491266804358, 0.06505304556940833, 0.022680444770582744, 0.07521627440808282, 0.05170033989293922, 0.0060096734406186215, 0.042159377462080413, 0.02237164813484396, 0.03270377637818456, 0.02633690390916121, 0.041162225928518086, 0.05197041269932544, 0.02634138360829844, 0.026988113118756204, 0.0599869137870208, 0.04277145107006354, 0.09954994649536188, 0.14537639915943146, 0.1208577551428349, 0.2415060618471715, 0.08779845651118987, 0.09859996682573711, 0.14289542341664915, 0.15969168665187974, 0.1564164769144789, 0.14415563805209053, 0.17573381293444865, 0.2532656953459786, 0.11916736681615153, 0.1641054869058632, 0.3435220989969469, 22.03321626109462, 68.93589896540489, 63.81336981250394, 51.58105050363849, 39.91630992581768, 30.474813868922574, 48.77784236784905, 46.976348738516535, 58.616123430190555, 36.96972347074939, 1.5397014060328085, 0.30541955162921264, 10.431553279199909, 12.895874515656503, 11.31251173634683, 14.137131110314401, 21.79070003571049, 19.73231077194214, 18.070212294978482, 55.81280546803629, 54.009601685308645, 61.394644168115434, 58.003119730180316, 64.28724312013196, 58.54175529172344, 58.514985115297385, 47.006245043969926, 45.890915163101695, 46.562538685337195, 60.83063871629777, 55.43679137383738, 59.42801090978808, 58.152130573026604, 58.64913409756076, 56.22308146569037, 56.91429722693659, 54.01588139995452, 57.843259611437404, 57.057769683099565, 57.11856642077046, 54.04060017678046, 54.64509233351677, 46.62115066282211, 48.297842318011874, 48.69999508703909, 54.47452806657361, 57.03107403170679, 56.2434934800671, 59.078037431163175, 52.09019768622614, 42.044140831116714, 43.35418108970889, 40.35811001254667, 42.949027707499845, 42.68828030555479, 44.03678724842687, 41.65784620469616, 42.84176657276769, 42.547059289870724, 50.42901508269772, 49.960848823670425, 55.8645179963881, 52.21599202002249, 53.030680071923044, 50.70888011686264, 54.3358487467612, 51.50497613414642, 55.97288523950885, 56.269428191646455, 59.91347482127529, 55.50934345491471, 64.18367293573195, 37.014395344641905, 28.82174468809559, 52.301864470205004, 43.456319608996, 51.73028099921442, 44.987138317477324, 47.228741491994555, 50.39543567165252, 55.35301739169706, 54.92767164784094, 58.23764608752344, 56.14557935345558, 58.001429188636045, 50.70407913577173, 52.11438694307881, 57.051046740624216, 54.53739189332532, 45.99079831953972, 43.184126730888124, 42.730916469327866, 41.10201889468778, 43.7247391669981, 45.4125468192562, 57.25001681235529, 58.758929083424235, 53.8303493684338, 51.672367203620176, 56.07080721086072, 59.30804914043796, 56.35283739336076, 53.30472038638208, 50.64329808758151, 51.41219639009046, 54.905200389123735, 57.651196833579775, 51.860809633808756, 55.18712074525895, 56.89619548859135, 55.213785017690356, 57.1549032580468, 57.60668185449416, 60.04566654082268, 60.584353093178045, 57.597817297904726, 51.06670618057252, 55.37971696546001, 62.69511776585733, 61.29065821247717, 61.752682039814616, 58.53738969372165, 62.343524348351266, 59.23502245256978, 61.04530219108828, 61.53794403999083, 57.16979257522091, 49.497714965574204, 47.65858227206815, 25.917031495801865, 10.625294831491287, 10.308167280689364, 11.295321949066656, 36.5722147880062, 5.016880602605882, 0.16377167175373725, 17.56720950526576, 58.9536080821868, 68.58091662006994, 74.5661554028911, 50.225812773550714, 38.22146554147044, 57.966237683450025, 58.65213471074259, 70.99497856632357, 25.662597148649155, 0.21133322929663045, 0.1492824516589603, 0.17978678577609603, 0.10207712500085754, 0.1835438494961108, 0.11928168245621266, 0.1991470993286179, 0.14696848308367116, 0.1663505535332426, 0.1542857872141946, 0.12355017881359785, 0.1438285031866643, 0.10949761351390232, 0.17141329154612558, 0.18902931482561175], [0.016662211255020192, 0.04479171685694207, 0.03229192751009138, 0.021732043242082003, 0.06883169764712935, 0.022403616983924183, 0.059120648375321785, 0.03747611344161053, 0.058043318079604264, 0.02122735409366508, 0.0694946931194394, 0.05054654253105964, 0.122758679752869, 0.056995539625565854, 0.05625598132610322, 24.31794393447138, 52.530632788135165, 42.76887716785554, 41.018613615343654, 12.158075705651315, 33.0174256140186, 40.009219108089326, 39.332127801833614, 49.78022367723527, 23.467823151619207, 0.2003461954694602, 1.2085106872743177, 24.732383528063377, 6.6992018395854585, 20.577514863783314, 6.327655325012823, 10.185363754149407, 10.112669487153331, 41.027258519203436, 60.183396647053385, 56.604826142711026, 57.2444195901194, 58.22356477860482, 57.97062681567285, 56.43316753448979, 55.73116917763987, 48.02008751899966, 39.1887887062565, 42.58850305311142, 52.48248961664016, 57.42964959913685, 53.8930170766769, 55.02914728656892, 54.70610087917697, 53.65439968724405, 52.73587472977177, 51.403716225777906, 52.15183381111392, 53.11636424833729, 48.587266168286725, 45.141279620508996, 41.44208838862758, 40.75817608064221, 39.692770127327215, 44.71275283444313, 50.533063796258745, 52.782115551733206, 54.74293977983537, 51.96412878651773, 43.87714678241361, 37.887244301457564, 38.70661566334386, 37.170588047273704, 40.00898376587899, 37.43402227278679, 40.03663255322365, 39.4047151842425, 39.55371818234844, 45.174494251128166, 49.30380082899525, 50.08189316718809, 51.023709158743586, 50.015334467734064, 51.0219362474257, 45.86146208547777, 47.87100607349027, 45.81734718814973, 48.5671091079712, 46.15988385292792, 53.23420793779435, 47.94406806269, 57.81210030278852, 36.396955443966775, 25.71073247540382, 49.108258908794774, 40.85617257702736, 49.37945942724905, 48.04930525441324, 51.642933737847116, 48.694821480781805, 53.211332674949404, 50.01727996333953, 53.07218659308649, 52.11324553335867, 50.1186732322939, 53.754157327836566, 52.39683681918729, 49.65977553398379, 49.905492413428526, 40.627372880135816, 38.034168443372174, 37.74758438910208, 37.8873384383417, 38.324192416283395, 38.72695315268732, 44.09087281073294, 53.200208833140714, 54.11659609886908, 53.99912895694856, 54.1053153622535, 52.71030087624827, 49.3358426709329, 44.065334258540986, 42.80062875440044, 50.12348205812516, 50.99945714396816, 54.40853418842439, 49.54985110990463, 51.21551306016984, 52.65417175908243, 52.59730523632419, 51.67111988990538, 54.82857688780754, 57.20206191462856, 53.59301851641748, 51.1465891715019, 54.052802670386534, 53.620126016678356, 55.30856909290437, 60.026792095553496, 58.404684143681685, 55.65754236713533, 54.65430598105154, 54.56924938386487, 59.03491489348873, 52.61393608585481, 55.47160240911669, 45.05692512758317, 27.028184052436586, 23.607055525625906, 8.983939809183921, 1.1242070625866614, 2.562076261928005, 3.111142631499998, 3.7581780408659293, 0.03714870278453154, 6.785061051768642, 38.62774072154876, 51.342401735244266, 48.15160066850724, 21.25246455592494, 24.39552449410962, 36.15271337570683, 46.233326312034364, 52.430204422243186, 21.2787385525242, 0.11554032353864563, 0.06074617969833555, 0.02583421616544647, 0.06331573052692317, 0.0267841728524335, 0.03372672975303666, 0.00835850859256161, 0.01288847171611363, 0.018745372860482144, 0.03970849748340346, 0.01156013845766504, 0.06824727215233349, 0.028338486726786342, 0.05079504613193774, 0.015132972396038955, 0.11260226143584137, 0.05436425743203971, 0.017955022931639707, 0.05350851040754107, 0.06760475421023947, 0.01852198353698177, 0.01744242201018478, 0.010235965056645294, 0.02677330014956815, 0.03643383166842884, 0.10509630815396387, 0.02664550136203968, 0.03422060748562217, 0.04873460669430995, 0.03926994279026985, 29.188017575971543, 60.17413593107655, 48.876882214700025, 46.690223601556596, 21.7675050996965, 35.09573659589214, 39.83535220546108, 46.573450719156575, 55.10804184021489, 26.927116340206517, 0.08687181954061793, 1.579677589958714, 28.823066526843657, 8.928389241618495, 24.713242361622473, 12.993702350124238, 10.509896739836663, 6.582351490374535, 45.22761883274202, 61.97491961140787, 60.9775746253229, 58.61656273564985, 60.507855107707364, 59.439303413514175, 60.06078335546679, 57.07752666165752, 50.46272000958843, 41.64906401788035, 44.50794235352547, 53.70478645447762, 58.10876484840148, 55.46581691311252, 57.0830415141198, 55.23258493792627, 53.24833239278486, 52.16876276077763, 54.03511278090939, 54.36532143623599, 54.37922231612667, 51.64784846767303, 47.83662257655975, 43.69765912332843, 43.36058239783011, 40.69305689104142, 46.972908819875414, 52.79945242789484, 54.6404835485643, 55.08612755806216, 55.61510624424104, 46.92738186928534, 40.92340592415103, 39.41622341832807, 39.156036915317664, 40.84995169793406, 40.70352961940151, 42.776819967454486, 40.65057369970506, 39.997397084389966, 47.43255961325861, 51.28862996255198, 53.04991145287791, 52.50913819959087, 51.75262281971594, 52.95815544743692, 47.3465734143411, 50.5303220595083, 48.53833460038709, 49.81338339467203, 49.00851695768295, 54.417630164853996, 49.90861854245586, 59.28483263138802, 38.64017071262483, 26.47311572105654, 50.09939478289697, 42.01396603738108, 51.215116900782434, 48.15426395785425, 53.170359596129394, 50.596939594514915, 56.023401444958104, 51.439731428700114, 54.924824007095836, 52.59264546055948, 52.2558746799346, 55.628822772733635, 53.86518786030432, 52.21214025251327, 52.47974787988971, 42.98266595409763, 40.492753213451756, 40.46303733702629, 40.0101016413781, 40.3880573088123, 40.071314150287265, 45.9867347440412, 56.59576546761298, 56.7509775777017, 55.503279470628314, 55.9878255474952, 55.22603850210867, 51.65060589390417, 45.59175206768898, 44.78326528303085, 52.38244172065489, 53.26647727720199, 54.43597509014992, 50.20806404852098, 52.74280163549608, 54.097925616848855, 54.54198891116727, 52.82746207329535, 55.83578663487589, 57.27514351567915, 54.530935672021684, 52.63736832526423, 54.10424847756663, 52.73808694654896, 56.845345881677446, 61.29560039889429, 60.771046146269775, 57.84510704778857, 56.89005305690151, 56.64517948704382, 60.93585629617015, 55.364698210070216, 55.150246543269006, 45.387682914733894, 28.974118963364635, 25.002468132203628, 9.458725067877001, 1.9709441882948724, 2.8473428901164763, 3.7586396548055836, 3.5839120370726434, 0.055648343367201675, 7.653611090875442, 45.255683391324936, 55.860340672154585, 57.141453450725926, 28.84000920480298, 28.29917319359318, 45.40394898383848, 51.716317361400975, 60.156285224422334, 27.833026955204627, 0.49119142995726683, 0.02731073955674806, 0.04791071743614251, 0.059246616212711226, 0.01957335494338505, 0.06701171022629546, 0.02405656850896776, 0.023559775811830358, 0.027635256316693082, 0.07204054118764978, 0.04002759991694362, 0.043209025170654065, 0.029176326446054928, 0.07740095032439118, 0.020237373143074014, 0.21489797430413388, 0.1835273326404633, 0.11201136249808535, 0.13892236886726272, 0.13693823178689327, 0.06773096719576467, 0.1854758925976292, 0.09030910283927956, 0.18768991734231674, 0.1218166214323813, 0.21170409246077462, 0.11416609203743358, 0.209593458942348, 0.11578105134709228, 0.14296158276979, 34.268026275019494, 69.06131282929452, 57.621833970469815, 56.359638783239554, 21.5366736150557, 47.901306383071415, 52.24792795796549, 51.32786935375583, 61.12490669373543, 29.057314395904545, 0.564570211835446, 1.720601853824431, 31.97365937694427, 12.414501636259018, 28.868968063785186, 12.875068303077454, 16.659196499855287, 15.247953207262102, 44.73061530820785, 63.5904222919095, 62.39717844993838, 61.5676873730075, 63.186955528874556, 63.16977946988998, 61.961148169732866, 60.06793775866109, 53.028734576317575, 43.98787921474826, 47.30621614763814, 56.19644464985017, 62.49960722461824, 59.24041963392689, 58.32744090787826, 56.89237902241369, 53.09417147790232, 53.22645341196368, 54.683508026984434, 55.890754730470725, 57.3725163552069, 54.30743117486277, 48.87841978380757, 45.231403919958304, 46.38005825781053, 44.15061835319766, 48.88355808873331, 52.84951363840411, 57.61993162093624, 57.833865534874704, 57.125159925030125, 48.31399856075164, 41.99600158199188, 42.1852598651763, 41.76625659388881, 42.622964997445386, 42.27318371495893, 44.34723892519551, 43.206535231682565, 43.09439466845605, 49.19710059319773, 54.14394286371047, 54.540682761899895, 53.8721186883988, 53.75894654181696, 55.314158470399924, 50.286283954497314, 53.334934403819425, 51.87775427295316, 53.254008062424205, 52.46747086125036, 57.2778146497665, 53.13740776431177, 60.29965177659066, 41.895094686938876, 29.834210411194835, 48.97838923238939, 41.30980645456622, 51.700682793894124, 49.88416648680165, 56.55982086735388, 52.86563065744216, 58.18261915637601, 54.55647814658381, 57.86057687574818, 55.178589590134166, 53.751737225440245, 56.45299511571085, 55.668168067932136, 53.89604122407975, 53.31537746614026, 45.29967669517764, 42.08771444136097, 43.34836421474334, 43.08333750694029, 42.779961785962506, 43.25241911795832, 48.78789148023052, 57.96574738717849, 59.606227720937426, 58.393164142485595, 58.28401634770056, 58.439322594673406, 53.832514516768924, 49.12927889054822, 46.89829357208745, 55.718162598148474, 57.24091299118535, 57.001805305480964, 50.57904966415898, 53.754855509727236, 55.93661116015527, 56.21951995357391, 54.321253607350016, 58.39102252837151, 59.79477605512066, 54.89549252294726, 51.43884497304117, 56.703967971186486, 54.42389026764901, 57.17003968454177, 62.57061389184768, 63.15380757854831, 61.34917997544812, 59.21303364538378, 60.91747999191285, 62.758597404726096, 55.779441787350564, 56.73716691232497, 48.79670112363754, 30.962758679543775, 26.479795517459994, 12.900922606068274, 6.321105457121327, 4.5977547572505095, 5.85924195666467, 5.547844988684501, 0.17817291431128982, 9.476602250529874, 52.84470089020268, 60.503803299319365, 59.00542259216309, 31.933947340134655, 35.82690954208374, 51.214112774018325, 61.82247669466081, 68.51289487654164, 36.91075063520862, 0.8136219639451274, 0.19770789591054763, 0.09579791597300961, 0.16322088517969655, 0.11134596150969306, 0.13121757746463822, 0.17229439991135753, 0.09438233870652415, 0.13561697526564523, 0.15300367778587728, 0.1959154799941086, 0.10964641077143532, 0.13788386007710812, 0.2312577972489019, 0.1546853633537408], [0.07068134033151212, 0.012428770123440172, 0.08201974038515361, 0.06277908976640433, 0.08149440325195752, 0.028552108429252144, 0.07197667243740252, 0.0694345935217796, 0.1391230839034242, 0.032059415994632634, 0.02563890204915116, 0.026350523037235105, 0.08256020775485425, 0.06686906465479443, 0.6618412535998129, 31.72911136381088, 46.75221273975988, 42.78688476931664, 27.185247521246634, 18.545470199277325, 33.19287323182629, 44.26519470830118, 45.53236738328011, 41.80182856898154, 16.19390631875684, 0.17938920146515294, 1.0279642946777805, 3.5401469661343485, 4.172357041989604, 5.834573190058432, 13.304962035148376, 12.562214174578267, 18.649338483810425, 59.88553970090805, 56.26563525968983, 57.948159479325824, 56.048175134966456, 59.73848219840758, 57.12259469493743, 58.838812074353626, 54.506562063770915, 43.928576900113015, 38.7322130510884, 39.999397493177845, 42.91879800058181, 51.11377462264031, 52.46079498721708, 54.77904127490137, 54.52117289266279, 55.089810663653964, 52.48269750225929, 51.15948984699865, 50.76196939714494, 51.186067827286266, 48.8448364503922, 47.18059832049955, 42.733803333774695, 39.858090185349994, 38.04363704496814, 37.496238908460064, 46.522624646463704, 50.83625124346826, 51.68036491640153, 46.4477740564654, 40.45999357777257, 38.280763933735514, 37.456230732702444, 37.34443926042126, 38.05595328730922, 38.616177574280776, 38.29710452787338, 38.0746433811803, 40.89681225438272, 49.424562761860514, 53.84039063607493, 53.02210577072636, 52.536783064565356, 52.29879325436008, 51.76488807124477, 50.01261626520465, 51.050718599750155, 46.674287011546475, 44.1457663812945, 44.27820521016275, 48.87765492162397, 48.37383431773032, 57.410351537889056, 41.72435391333796, 28.48477190540683, 48.19398972295946, 42.95364825956283, 50.13763789207705, 48.83099832842427, 51.853980787338756, 52.23678058193576, 52.596756104500066, 51.15313168494932, 51.546627783006244, 49.17463325685071, 52.49782216164374, 49.931144714355476, 53.32442245175762, 47.743976193089644, 48.8749171072437, 42.34302151587702, 39.50347262044107, 38.69316193365282, 38.944950642124304, 37.695930696302845, 39.1413672508732, 38.175150194475734, 47.38485574722291, 54.0929324396195, 57.26973456721152, 51.984948727392386, 51.34972480035598, 42.209425587807935, 42.003379560286, 46.65302776521253, 52.30401392905943, 52.04104646559685, 50.44860732170844, 48.932328839455884, 52.685507574389064, 50.00755640768236, 53.87306005724015, 53.52895052202287, 52.53823826389929, 53.786732612117646, 56.91215169045233, 53.05218250520768, 55.62785394730107, 56.26457229737313, 52.26072665183775, 50.77442292244204, 56.551897679605794, 53.08667190613286, 56.34403167232391, 53.07115500973117, 54.566480190523215, 53.22789684418709, 55.88411023539882, 48.279622908561464, 49.15397805552329, 38.51185821717785, 12.528993660403836, 0.3969680391732724, 2.769997427540441, 0.16325520591870432, 0.20005446918789418, 0.0703576298791074, 2.9305000795472056, 37.75952800627678, 36.160785613521455, 30.24241343621285, 22.44078190095963, 26.8535424816993, 33.569711023761386, 45.81715499201129, 46.64994085988691, 34.39772728950747, 1.2676513267140235, 0.09967936172841058, 0.016662927547229395, 0.029554875387299447, 0.08102395631853612, 0.07456696892697966, 0.03764212086436249, 0.015180257257945357, 0.06630721577112714, 0.06127324052936128, 0.08455148477467798, 0.03527500876976598, 0.02637367995996629, 0.021222592857215675, 0.04170644329860807, 0.02575640653019711, 0.011725123153038084, 0.04978516221707387, 0.03356182166645604, 0.08331143357340368, 0.004025156667921692, 0.04915107890302616, 0.053493475932027065, 0.08689661014584765, 0.05860301042576471, 0.09911595768625699, 0.03202454750275901, 0.013520079608556005, 0.09651187927492204, 0.696388999781301, 38.947358977410104, 56.21505237394764, 49.639602784187566, 37.97788243139944, 21.841314300414055, 34.17047300646382, 51.408674101675714, 51.14538108148883, 48.440161597344186, 17.590455432091993, 0.16867415949461922, 0.4823235638679997, 2.9032116599621314, 3.3629791438579564, 7.772540786573964, 10.954301280360069, 7.321770729557161, 19.503442433572587, 61.96491364509829, 58.47649881916662, 61.06033663595877, 58.75382215745988, 60.30943809017059, 58.77826636837375, 61.51533942068777, 56.86676202281829, 47.48260513428719, 40.8032048902204, 42.52052053328484, 44.652591520740145, 54.3606302815099, 54.140836346533995, 56.7511462396191, 56.607069738449596, 56.71523301832138, 53.593438210025916, 51.70877072118944, 52.55720684605261, 52.25563933772426, 51.32579834230485, 47.33504164603449, 43.230493068695075, 40.01240015029907, 40.307323163555516, 40.979942967814786, 48.95585521574944, 52.87328712401852, 53.39425633030554, 48.77938778169694, 42.7403772261835, 41.12610616991597, 40.97649520443332, 39.23960301183885, 40.08938450967112, 38.805663354935184, 40.269978277144894, 38.81410429554601, 43.49887340299545, 50.77956514973795, 54.56563295856599, 55.686497303747366, 54.447997154728064, 55.18015069346274, 52.89511903639763, 51.12870708588631, 52.45293063502158, 47.91471696669056, 46.58716724764916, 45.50371446917134, 50.57004782461351, 49.68641627219416, 60.11728117542883, 43.21680791916386, 31.638898811032696, 48.215703964233406, 45.43295491126276, 52.96274069816836, 49.09428742624099, 53.57232016901816, 54.081502652937374, 54.80287359606836, 53.03617531253446, 54.143989932152536, 50.90057419192407, 55.28879250249555, 52.48982052649222, 53.93068751981182, 48.97262727060626, 50.66359635322325, 43.786838131566206, 40.982225787255075, 40.62685512727307, 40.92817944865073, 40.072416336305686, 41.72500110441639, 41.5023006931428, 49.73631274315619, 56.40330260799777, 58.70083093643189, 54.82413284240231, 52.95117755090037, 45.178542137146, 42.50659219680294, 48.375105165666156, 53.74510057510869, 55.00003153277982, 53.52265119552613, 50.51067882968534, 53.33764868397867, 52.00882811700144, 57.223784000642844, 53.37952783030849, 52.72866149102488, 53.5169166903342, 56.437156584955034, 55.01909425181728, 56.384828244486165, 57.22630608466364, 53.23593770304034, 52.527738078948, 57.846738753780244, 56.825573213638805, 57.606536726797785, 54.590194840585035, 55.0306809333063, 54.07660753496232, 55.99860422072872, 54.130889215777, 52.58464774777813, 42.787700622312485, 12.741876379136118, 2.3540675784310987, 4.958187235939888, 2.507703386006817, 1.1396819160830591, 0.10391601181078343, 3.5276218575816003, 43.21003790824644, 43.48947932643276, 38.487621891883116, 26.875164547274192, 27.997448790457945, 39.39330500941123, 51.82926201051282, 54.76089246811406, 43.467466985025716, 2.201826418599775, 0.1279631899970193, 0.003898893168473977, 0.04133695143184835, 0.03704557968904415, 0.019479432563868262, 0.022400487514753497, 0.01746141332982769, 0.022352273771238905, 0.03548157288722935, 0.06598199612551159, 0.06150831077848712, 0.05006726260387129, 0.005895513890972061, 0.03494208227963217, 0.20762432186353594, 0.10852232996013858, 0.17231937437768907, 0.16685090087834867, 0.23879616371085569, 0.10698022561207896, 0.11717414393300012, 0.18099145903702707, 0.19890550584081682, 0.18480844615447908, 0.146614090809899, 0.20744245259031174, 0.16878613090563208, 0.2866140542732131, 1.3971424943977788, 46.64910147267003, 66.03286650873, 58.64309756986557, 41.69058622852449, 28.53103037803404, 44.79073739820912, 57.11825263115668, 55.38487488223661, 54.12047140059933, 19.60726757203379, 0.35480305011714663, 1.1057691035732147, 6.833686184498572, 8.31272421344634, 10.269950647507946, 20.76158973478502, 19.53701792224761, 21.718922622742195, 65.6509570921621, 58.99322402092719, 62.69540802125008, 61.0069884792451, 63.95100185948034, 61.30250769276773, 64.7561114834201, 58.889143928404785, 48.247086847982104, 42.964019006298436, 44.446894584163545, 45.48574216904179, 55.46500890485702, 57.12504225392496, 58.921091633458296, 59.301581152023815, 57.68851426339919, 54.556709566423976, 52.30260579816757, 54.5844760248738, 56.61345143471995, 54.49552843647619, 50.626871201299856, 45.874268624090384, 44.29655013545867, 42.81728706052227, 41.717046537706935, 51.620505625201815, 55.10974807123984, 56.13804055798439, 51.844767139803984, 44.596521239126886, 43.81323568282589, 43.01024021640901, 41.09866526819045, 42.34920317126859, 42.49796690479402, 42.39976644515991, 40.6861456747978, 44.6361489449778, 52.3174362797891, 57.85631325937087, 57.97940508011849, 56.005676254149414, 57.660947845828154, 55.24032377427625, 53.004274675923014, 56.26415652613486, 50.10968315985895, 48.23475491616034, 47.87211610424904, 52.61247696415071, 51.13588894567182, 62.09250442443356, 46.14728519993444, 34.25528641669981, 48.823326172367224, 45.24903889625303, 53.73927977777297, 52.454472126499304, 56.222414662761075, 56.44185558442147, 54.71439669209143, 56.331005480981645, 56.569524811160186, 52.02826346120527, 56.74793774081815, 53.34038257598878, 57.0691131776379, 51.52804751549998, 53.87965748386999, 47.11356501425467, 44.07787015361171, 42.56679665657782, 42.73808263963269, 43.17297151011806, 44.395154599220525, 42.65285738052861, 51.20184360011932, 59.47948025118921, 61.93004769663658, 56.27617074597267, 55.125872935018236, 46.84996604919434, 45.2094425693635, 51.845767344197924, 55.85848539106308, 54.7571466045995, 54.86219160018429, 52.380076531440984, 55.855602448986424, 53.31542061221216, 58.60652146800872, 55.381835045353064, 53.737138163658884, 55.77960260452763, 59.516589795389486, 57.33120987492224, 59.665828135705766, 59.35660023843089, 54.8735115605016, 52.96591389563776, 59.00589327658377, 58.3236675877725, 59.57622158911921, 54.70948588463568, 55.94205148758427, 54.54185162821124, 57.65669207419119, 52.343296466335175, 53.94870688838344, 41.69023713757915, 16.947635835216893, 5.399475453361388, 10.085172691652852, 1.5044169897033324, 0.9600698443189745, 0.13001569276375155, 3.5465436164409887, 50.87381578260853, 47.633957632126354, 44.85990839619791, 34.149594230036584, 39.50822261071975, 47.52729662003056, 62.42319553129135, 63.20092308905817, 53.86634888187532, 3.151563881866394, 0.42225749021576303, 0.11280881406198587, 0.1641326523836582, 0.2800196613515577, 0.14867813086077092, 0.09543755587430731, 0.10482593274284756, 0.1490079929992076, 0.16525127864893407, 0.14869690001491578, 0.10704099936711212, 0.1395081043724091, 0.1546298832662644, 0.1736155338585377], [0.03700415348453868, 0.016973321476290305, 0.04654875483303782, 0.05035062703574377, 0.030505998443151196, 0.07225047226154035, 0.021521083695153077, 0.08366433963660272, 0.05117896343431166, 0.0035766097942307113, 0.0374667288645381, 0.05709619591793707, 0.08940642143809989, 0.07057934338527341, 2.054329733214071, 31.870685392810454, 39.86097312742665, 36.50307124660861, 20.992127041662894, 23.365221792651763, 38.119028922050234, 51.48514855292536, 46.65376124843475, 41.41817762005714, 9.993858933448792, 0.20044400957563233, 0.15468370860382435, 4.432150817686512, 6.0336334763034705, 24.910490512847904, 15.352680490862939, 17.675761099784605, 37.6696272819273, 61.39618565959316, 56.579224832596324, 54.07428549182031, 47.460506500736365, 51.707437115330855, 51.80762621664232, 49.13235010639314, 43.598772248914166, 41.724750072725364, 40.407178863402336, 41.15402952317269, 39.85773717203448, 41.35825949330484, 44.61532508173297, 48.63059266921013, 53.017806853017504, 53.27214510210099, 53.59344997713643, 49.14777286591069, 53.05301012531404, 52.50676908800679, 51.810250282287605, 52.5220271079771, 49.67393529030585, 43.75218006872362, 39.114887329839895, 37.37220964124126, 39.26087402528332, 42.334043210552586, 43.51684178075483, 40.2382698366719, 39.267459684802645, 38.204744477425855, 40.80541318462741, 40.260560666361165, 40.42788897791217, 38.47565474048738, 41.89624001902919, 37.633639535596295, 40.84054193189068, 51.26963784617763, 51.448286118045935, 50.47994313701507, 49.64739261134979, 51.425952142284764, 52.853361483543154, 49.59644886755174, 50.03975122205673, 46.30911827087403, 47.5102186203003, 47.73105982811221, 50.90639891162996, 48.05262357957902, 55.073426923444195, 44.354220744102236, 30.871085043876406, 49.010038837309814, 44.92781639099122, 51.80066400958646, 50.46179040785759, 52.48902820771741, 48.08661876186248, 52.12138052909605, 49.441927094613355, 53.58102390843054, 50.56812194085891, 49.63440564370925, 50.07224805893437, 51.09242516179239, 47.936611636992424, 45.2958994527017, 40.34762551707607, 39.140633767650975, 39.980405376803496, 39.20541171104678, 41.74726055514428, 39.059358335310414, 39.77971338456677, 42.059383161606334, 46.963122506295484, 46.55978518147623, 47.085622049147084, 43.731999474187056, 39.27819913433444, 45.02494604356828, 48.6975710622726, 53.190736309174575, 51.37010543577133, 47.65969622519709, 50.35960874249859, 49.21971305724114, 52.177850892466886, 50.47965288162232, 49.95590663725331, 52.73063444322156, 55.82032072928644, 53.04721286219936, 53.56962550070978, 52.33306692492578, 54.308902063677394, 54.46725599227413, 51.68312626500284, 50.94372026381954, 50.7292882088692, 52.67784718544253, 53.48162712589387, 56.904126521079775, 60.03796692817443, 60.41803283076133, 63.763681227161044, 58.696477105540616, 50.54577619798722, 16.097230680527225, 1.1266326808160352, 2.295503895128927, 0.7261805044066522, 0.6100722798897374, 0.06677368670822152, 0.9352626915900939, 33.995735337657315, 42.385104625455796, 31.630146041993175, 21.16596648769994, 25.326487287398308, 45.2691920341984, 50.29021809178014, 52.026204216864805, 38.18965511937296, 2.941393727256406, 0.08463807569275941, 0.0243620460687746, 0.035283385941217986, 0.06440852813783192, 0.056995558777763966, 0.05632601325370132, 0.11389261397022395, 0.08572790471296157, 0.017150163297511397, 0.029385240538226023, 0.0671251678478814, 0.017076138136607986, 0.058677393732772726, 0.02839496464378411, 0.030766022091190663, 0.04302840845118608, 0.017136015568769748, 0.06828530075689478, 0.022438745945692066, 0.0899978949417991, 0.02865969015645885, 0.09649278070296972, 0.08685236856822046, 0.08723569598289267, 0.032275510245874044, 0.09052599765240185, 0.05971462698653341, 0.025157716478251164, 3.4671119432295527, 41.3975263410999, 49.30051780516102, 46.18725022962017, 27.962839757242513, 24.979661510836696, 36.618612504774525, 56.641963143502515, 51.15746590398973, 46.29302478605702, 10.468577511848943, 0.2084880400328867, 1.901196356742613, 5.270609903720118, 7.908319023347671, 26.945906454516997, 10.492317657316885, 8.680493485543037, 39.468222279702466, 62.57373217613467, 60.061524683429354, 55.181248957110995, 51.40282977011896, 54.01373586347027, 55.03379921759329, 51.1392504169095, 45.65529054211032, 42.07629249941918, 41.85427458055558, 42.04973020861226, 41.146424047408566, 44.14954362377044, 46.78636481685024, 50.511753559112556, 54.0613652044727, 54.71154120660598, 53.81497759972849, 48.173048188609464, 52.618992021006925, 54.08516222430814, 55.51753336383451, 54.97399091720582, 51.14172543248823, 44.2220211798145, 40.75974895108131, 39.43473700554141, 42.8877563630381, 46.52351502449282, 45.5218985772902, 42.162839597271336, 40.60705892501339, 40.47142728682488, 41.43716581406132, 40.72217264483052, 41.88854432875111, 40.582948115564164, 42.689923778657, 40.27226894132553, 44.28419859178605, 53.48280775931574, 54.33681364982359, 52.95720231148505, 52.31527113145398, 52.29332547033987, 53.75278057590608, 52.120835319642104, 51.879762526481386, 48.03752637678578, 48.8882767000506, 49.63239739018102, 52.45384062490156, 50.03192609356296, 56.534615716626575, 46.7336207051431, 33.89519714540051, 49.87945179785452, 47.75793983090309, 53.92311734537925, 51.5214853902017, 53.181891364436, 50.84211518687587, 52.52372941663189, 52.269489226802705, 55.05249323383455, 52.421469303869436, 51.91211815803282, 52.969863722401286, 51.56922063519878, 49.90006777548021, 48.080978393554695, 42.06394095574656, 40.70189399103965, 40.54632494526525, 41.48067274401265, 42.50779244207567, 40.655774762553555, 41.8592873696358, 43.445717442420225, 49.792732115714784, 51.02144202878399, 48.9577732547637, 45.47030372004355, 41.34679440529116, 45.65609462799565, 50.799326050666075, 55.513618838402536, 52.15996096211096, 49.63722582786314, 52.76523759288173, 51.62473786261774, 53.83015324992519, 52.85006669259841, 51.34936394230012, 52.82920360565186, 57.11212196657735, 55.23135723606233, 54.73899387544202, 53.63825913398497, 57.09279644873835, 56.116016449466834, 52.94089309630856, 52.32874055062571, 52.776639922972656, 52.14456173681444, 53.827187938074914, 57.06711669122019, 61.02034414968183, 61.97813595494917, 65.33244886705953, 59.848387010635875, 49.64113250855477, 16.98167612475734, 3.556655241597084, 5.068558319922417, 6.8198372760126675, 2.213815878475866, 0.1092813392319987, 0.9293252037417505, 40.741317733641594, 50.12321533695344, 34.58553037335796, 22.295650282213767, 32.880203454725205, 52.716153052545366, 58.97572632758849, 59.71973719135408, 48.808134832689845, 4.292932171975413, 0.14454749202536, 0.033407236614655104, 0.09799995144168216, 0.008082105027091118, 0.07363111591867863, 0.022921009785345486, 0.059850393088474396, 0.03543995516074281, 0.018776625417353168, 0.016912241286087423, 0.02858966397452018, 0.023963973376779787, 0.03963554676081385, 0.05961220869193635, 0.125247691757977, 0.09704946615402738, 0.15283792700257995, 0.12397322788714402, 0.12389480346633543, 0.2099829993300861, 0.17066228023219496, 0.2023478606415372, 0.17009240274708118, 0.18434533068249304, 0.15980830055571374, 0.2588271872410851, 0.23189604042037842, 0.1793567499806804, 4.681483141837582, 52.34244923437796, 60.34965022917717, 54.31895902079921, 32.32165009744706, 33.10191346753028, 50.797984600067146, 62.29085476167741, 57.49652601057484, 51.48666258781187, 12.360130721522916, 0.33923681765314073, 2.160096077188369, 7.037207186222077, 7.904248093405078, 33.05111485142862, 30.494808150875954, 25.32288262920995, 38.01527438625213, 67.17655904831426, 59.831473750452844, 57.915533204232496, 52.31592616727276, 55.75637432836718, 56.78658877649615, 54.64485306893626, 46.786906103934015, 45.6686972033593, 43.31962893086095, 45.13064999734202, 43.504658898999615, 45.8741666424659, 49.03398098484163, 52.74595129874445, 56.63883701447518, 58.645988356682565, 54.66368829050372, 50.48427343368531, 55.045507492557654, 56.35670485035066, 57.56378681428971, 57.493541086873705, 53.87046344818608, 46.716432879048014, 42.890152931213386, 41.53333448594616, 44.557583870426306, 48.774602490086714, 47.25807297614313, 44.122808748675936, 42.969333817881925, 44.04593029329854, 43.709998899890536, 43.62519725676506, 44.435625614658484, 43.072554911336596, 47.17254177216561, 41.713700755949944, 44.655964759088334, 55.362238883972175, 55.16419841397194, 54.89752823306669, 52.56226278120472, 54.527723250850556, 58.368461055140344, 54.134631156921394, 54.75508736025903, 51.02309726899671, 53.5891471370574, 52.91415037647371, 54.19605547381986, 52.178313732147224, 59.76197719573975, 49.40681011446061, 36.942776787665586, 47.82510649773383, 48.52758338374477, 55.049355337696696, 53.16849647029754, 54.70555174735285, 51.74895540360482, 54.394350897881296, 55.41317870540004, 58.85433681549565, 55.839034357378566, 54.089810232962336, 55.03072015700802, 54.73754652084843, 52.741664148146114, 49.62092837979717, 44.97996038006198, 43.788179582165135, 44.557909427150605, 43.59381045064619, 45.97698373179282, 43.051915399489864, 45.00570681787307, 45.992590842708466, 50.93416929244996, 52.669943609545314, 51.255136843650575, 47.77103270253828, 44.57331649718746, 48.34075697006718, 52.75140731565414, 58.774222404726096, 54.20355112321916, 50.55175389012983, 54.081243776506, 52.51475503367763, 56.558244074544604, 54.02440863270914, 51.78986572450208, 53.4970812643728, 58.05393795813284, 57.14734485072475, 58.40186395952779, 56.289946110017844, 60.10268211364747, 58.976538258214156, 52.238588794585205, 53.983753265873084, 53.401591162527765, 53.71344704781809, 53.93221724417902, 61.336538176382746, 63.0251185355648, 63.72301801558464, 67.8855666806621, 62.25452184677125, 55.03973768603418, 19.800797316335863, 4.8969619793276635, 6.877690765165514, 7.340722641637249, 2.0163591061868975, 0.20647348926192333, 1.204533649067725, 45.35183245135892, 56.9580904899105, 42.13229217836934, 31.159740109597486, 39.94319385097873, 56.40591098416237, 66.81848587528353, 66.90895926567816, 61.348285675048835, 6.241705898315677, 0.27655847610965856, 0.16362210074740072, 0.15086529656283318, 0.1160985335046726, 0.12322556437744249, 0.16936442003615443, 0.18151681149198165, 0.1530848984276095, 0.07022773201066641, 0.11200035381461344, 0.13682929408406058, 0.12380605984118678, 0.14364424371911635, 0.2619007319932984], [0.12485704054274868, 0.07677977559186759, 0.040049850940704346, 0.06768350038797626, 0.06929048472234318, 0.07095451962443129, 0.058211914879540284, 0.07344838862697925, 0.17283395563642825, 0.06307429408714657, 0.03601062937729782, 0.03752356492764047, 0.08275703106436037, 0.17169983907332345, 5.23124352578194, 30.477753685366725, 36.92856604053129, 34.447768888165875, 25.30822277069092, 20.242564062918387, 33.793364570986846, 54.94767965808992, 37.66727778219408, 38.74313292964813, 5.485777403077772, 0.20954729448403084, 3.1962374717958513, 2.9805066220221983, 1.4831996637005962, 8.82032205981593, 8.594530820846558, 17.69609662794298, 50.771014382762296, 57.85203395351287, 56.61223549996653, 50.804354529226984, 46.091214918321185, 43.21480358800581, 40.53950394353559, 42.4506474310352, 47.702379457412235, 51.510526287940245, 48.033949175188624, 46.27694306835052, 45.0030670627471, 47.41710547477969, 47.83824251544091, 48.71452354615735, 51.18604429306523, 51.228484338329686, 53.79275345033216, 52.11706592190651, 45.63696130629509, 51.97677843032345, 52.08534963669316, 51.63788172506517, 50.22398102668024, 47.53265065531577, 43.49025595572687, 38.62680719744775, 38.508481056459495, 37.50583694827172, 36.6152863348684, 36.77413448210686, 39.96774788825743, 41.453831964923495, 38.92126737102386, 38.55974251224149, 40.76195332311815, 37.4505119169912, 44.22828912734986, 38.60447322168658, 43.350639189443285, 50.34852804676179, 53.20951661755962, 49.47958969300794, 52.00758080328665, 52.47694730758668, 51.8362359846792, 48.41713336206252, 46.70244570701353, 45.00554992306618, 51.61612826008951, 52.43650767111009, 55.63781676753875, 52.42972197071199, 58.8407850265503, 42.30419005117109, 29.956645234938595, 49.10423455699798, 46.65123916441395, 51.686201403217936, 48.478318414380475, 52.14903323881088, 51.41223953616235, 50.77394831565119, 48.874136555579405, 53.196298230078916, 51.19031183181271, 53.15616453847578, 47.90336562741188, 48.45039506112376, 45.412911599682225, 44.12097307943529, 41.08214032265448, 39.423793592760646, 38.57555750877627, 37.6873799293272, 39.00573953505486, 39.63745686315721, 38.633777249243956, 38.57204306510187, 38.940996892990604, 40.74228263670399, 37.58377052122547, 41.06747458058019, 40.233817946526315, 44.58869218826295, 51.29680810436126, 52.1270836553266, 48.682768037242276, 52.0364769043461, 51.13353552356843, 51.29135208745157, 49.217900922221524, 47.47489767689859, 51.95552310635967, 53.34362245375111, 52.63974528158865, 52.6025612123551, 50.25809388006888, 49.80612700985324, 53.015829978450654, 51.96007697812973, 54.73242782777356, 46.968735418012066, 54.381532592158166, 53.24482187148064, 59.990423879315784, 56.48534682489211, 60.03082821446081, 58.71306480899934, 59.69545379761727, 58.35174391346594, 51.899335153641246, 16.99304707588688, 3.3913089527237803, 2.8100161446679026, 7.0695966482162484, 0.6021096845788341, 0.05986232490789506, 0.13868589284679583, 22.14439388244383, 41.22584027628745, 47.15973915592317, 65.14576365870815, 23.380748494978874, 30.507057712924098, 44.91239363147367, 53.37630756439702, 45.266917059498454, 4.238225894589578, 0.09617060242641358, 0.03866166514795154, 0.021002465153052922, 0.05949961291926523, 0.036029406192321936, 0.03439942772890772, 0.06054004459010978, 0.06614089808276584, 0.0502066484712545, 0.031232787972135894, 0.03067106357775629, 0.01348978753442005, 0.0040354514532091644, 0.08872478704659209, 0.06596958550113825, 0.04331777901238492, 0.08815613530215718, 0.03272530727929646, 0.059122663186562646, 0.025646019005967725, 0.031682556277261145, 0.03645728928067031, 0.06611277499506552, 0.010509254474703585, 0.01580017081822359, 0.05334852060543434, 0.18858152111211132, 0.17625925731995415, 6.874435688218763, 41.516091746668664, 46.12422166332122, 43.04234481626942, 30.650030066890103, 27.314981875881074, 41.65000930909188, 61.92051241474768, 44.18637860205866, 43.12560104554699, 5.953527890866803, 0.18141884416822465, 3.7162300079099597, 4.139015424636103, 4.571672466493422, 15.839651573088863, 9.633693175931132, 17.75993516368251, 51.912820262293664, 60.10737326837356, 57.648184453287435, 54.21538491402903, 47.84273362928822, 44.54409876177388, 42.566733898655066, 42.79163083722515, 48.0105326252599, 53.028699274986025, 49.98646582326582, 47.186164163774066, 46.87667739006781, 50.052914696355025, 48.67983802672356, 50.971420041976444, 51.44172791511782, 54.941082231460086, 54.65787533790835, 52.51067576869842, 47.90846470863589, 52.51127981370496, 52.79104678861557, 53.79791528947892, 52.53486110318092, 51.157995423962994, 44.437174950876546, 39.107364223849395, 40.092016420056744, 39.73049940601472, 39.162238182560095, 38.565763350455995, 40.93515342281711, 41.57428795291532, 40.380616572595414, 40.32708406448364, 42.327912545973255, 39.566293301120886, 45.76333615087694, 40.39674143637381, 44.66073436121787, 52.43105949894075, 56.32030917752174, 53.52451824372815, 53.56897438726118, 53.15617238321612, 52.46632160678987, 51.322064245900805, 49.7259537635311, 47.67107894343715, 52.088334560394294, 53.60557010096889, 58.54216321822136, 53.68763392971408, 60.50561935670915, 44.50733438614876, 31.417983078187515, 51.095394396012836, 46.03708228757305, 52.712391499550115, 51.18875857322447, 52.58969191581973, 52.88194379498882, 53.649190779655214, 51.606067380597516, 55.34988341792938, 52.81538509553479, 54.931637164085146, 49.35214011899887, 49.881656169891365, 46.887350159306685, 45.81903380732383, 41.22701306496897, 40.44194675260975, 40.30925689205047, 39.88404058641003, 41.51153003015826, 40.46143700999599, 40.23297463693927, 39.53121554466986, 41.04869427219514, 42.78785359474921, 39.570007785674065, 42.83587909513905, 43.23025772648473, 48.27805788286271, 52.82137063241775, 52.826756046664336, 49.15185997563024, 52.18708807422269, 51.99943404043875, 54.02685226932649, 52.40350484848023, 49.98336322845952, 52.035190366929584, 55.64837186567245, 53.87608812701318, 54.72673646865353, 52.336448008014315, 52.071487980504195, 54.18780280697731, 55.39499851965136, 54.70009965281333, 49.40367614069293, 55.20301418919718, 55.09989507736699, 60.45652697163244, 58.88100501029723, 61.982721205680605, 59.599614604826904, 63.44969549486714, 61.53440213972523, 54.14253865518878, 21.379986693782193, 5.27491617587305, 3.5952003732804334, 10.51333861966287, 1.7781058843097381, 0.012040171066238996, 0.0869069293501877, 25.10162368897469, 50.36741818151167, 51.2705909821295, 58.671307256144864, 28.830432738027266, 35.3472585831919, 51.68861758324408, 61.343633744024466, 54.63732211820541, 5.908200981155519, 0.08428425798493047, 0.020540904839553183, 0.08749439621404295, 0.021316086227494865, 0.05670360266982068, 0.07883663739888899, 0.027600257589872328, 0.07236975981223007, 0.08443463338358749, 0.050723635246075933, 0.02422739653998325, 0.03439796833141196, 0.05445313129213549, 0.10591328729905429, 0.16787335246561036, 0.16953798491627942, 0.15650434719939388, 0.16810814309264385, 0.10830528192943144, 0.19973307998190004, 0.22574024815713206, 0.1367844472969732, 0.21332079845090068, 0.10217090182366872, 0.13648132162709392, 0.2265494055445156, 0.40552095119510934, 0.3506472989195778, 9.401134867821971, 52.60443218292729, 55.5401183712867, 52.44246182903167, 37.49018669128418, 30.540607706193004, 45.14565306325113, 62.042517738957564, 48.06046439755348, 50.134033233888694, 6.895085496287193, 0.37097225506459514, 5.108965106548802, 4.436969939739474, 5.0866968304880205, 13.515599196957005, 14.82488145751338, 20.81392199762406, 52.315106391906745, 62.53958794378466, 60.57736735190115, 55.300308581321474, 49.86458209253127, 46.74787852071947, 43.778389346215036, 46.121577985825084, 50.535487821025235, 57.887719677340606, 53.336875977054724, 50.96763887713033, 48.67304840395528, 52.19136738008069, 50.674900624059866, 54.82339151443974, 53.83173396510463, 56.88825268899241, 56.8998864389235, 53.84952975857643, 48.57530686163133, 53.924847110625244, 56.06892055080783, 56.93875320496098, 54.1662964513225, 52.72130704695179, 47.50434290978217, 43.45515858742499, 42.97040462493897, 41.60937355410668, 40.78188680833386, 39.51776573734899, 42.894895076751716, 45.96853102407148, 42.17063334680373, 41.77822374528454, 45.88221142368932, 41.377279066270404, 48.91106174838159, 41.94220235270839, 47.67104756447577, 55.40720101325743, 57.750679908260224, 54.90847556821762, 55.51861986037224, 54.110312461853034, 56.569191409695534, 53.950711219541496, 50.936405043448175, 49.941990067881925, 57.14579551450668, 57.4571571811553, 60.317749592565725, 56.136036226826334, 63.68168015633861, 46.84685953201787, 34.2626840068448, 49.83381109852945, 49.658504686047955, 55.16733238773962, 52.61222201008951, 55.46009025266094, 54.53515221995693, 54.84675315118606, 53.44068150366507, 57.72211720866542, 54.123950542942175, 57.093549543811434, 52.48247784952964, 51.7770121174474, 48.857646911374985, 48.408586517457046, 45.33731183698101, 43.14986482743294, 41.96169261009463, 40.07965703164378, 44.5487859941298, 43.34184131314678, 43.5062906049913, 41.82072654847176, 43.17578777190178, 46.37506900295135, 39.978695223408366, 44.32395573585264, 47.596212663958156, 48.7544140508098, 55.243575419149096, 55.13584752236643, 50.36231910028766, 54.08855115213702, 53.58384409258443, 55.83815966883014, 55.86690279745287, 49.92858732900312, 53.89676294019146, 58.54571688559748, 57.1046341619184, 56.96511153251895, 54.344791750754084, 54.88912259378741, 57.18140671330114, 55.963424482653224, 58.4145292928142, 53.046004772186286, 57.17415425085253, 57.25140533139629, 64.7366722168461, 60.38514375686646, 65.39171980273339, 62.612677389575595, 66.35839185407086, 64.06443288249355, 57.49001879845896, 22.88352139534489, 8.612241302767108, 9.9469111042638, 16.447612085650047, 2.38163203481705, 0.10446084588165246, 0.24563210415503672, 29.110586066399854, 56.78897749993109, 58.6865770432257, 75.55922892785843, 35.83557013542422, 41.17300987243652, 60.48941212315714, 65.71833164461198, 64.35646118656283, 8.126665113433715, 0.3018663745493658, 0.15710454644455066, 0.14475793637815984, 0.10197384102690606, 0.21328845421873757, 0.2708604979899622, 0.16485769331695574, 0.21024270313641719, 0.20027554684108306, 0.12831383610084174, 0.13576014177693477, 0.1830237677260753, 0.15057539357052696, 0.2211752834339296], [0.06594815802189612, 0.04112087633280505, 0.023509212093608036, 0.009726215897488498, 0.019546405885428674, 0.009778003441169858, 0.022374781434454268, 0.009354446834373859, 0.006303992929808315, 0.057138583562787504, 0.05981834380016212, 0.012038684855665893, 0.07458638925586017, 0.1342236145489639, 10.368370759871699, 37.954097178674516, 38.05134450235675, 40.211727157715835, 22.11180094749697, 22.04894692667069, 45.31771959797029, 51.06651398443407, 33.54688675172868, 39.44622170540595, 2.084709838513405, 0.06556990977016187, 1.3515509472739313, 3.057727304197127, 3.9863222116424195, 8.86032239083321, 14.44088141764364, 31.173217373509562, 58.236830234527595, 57.6810460705911, 57.98585345668178, 52.455272290014456, 46.29650000602969, 43.96793004005186, 43.83619723781463, 51.18044314845916, 55.963475473465465, 54.469993806654415, 52.74415485320553, 51.436417025904504, 50.730970905673125, 52.66153797026604, 53.42621972483974, 53.80376354340584, 51.65187281946982, 55.40749126865018, 53.860112313301336, 50.21210801216864, 48.34140808351579, 47.044601901885, 50.41987596019622, 50.287476355029696, 51.43530699514574, 50.12078738981678, 45.863693914105816, 39.91343482848137, 38.97859673346243, 38.94003983466856, 38.69278146374611, 39.61713506329445, 38.69707645908479, 37.58861072601811, 39.50607707423549, 38.108936663596864, 38.32156050589777, 37.34598859663933, 39.238708711439564, 38.35771691414618, 40.698811008084206, 45.68397483518047, 52.477637644737, 47.87025690078736, 51.714316952613096, 52.92892594491282, 51.91052175337269, 45.60610794251966, 46.653659266810266, 49.30396949091266, 52.982670261013894, 52.923458160892615, 52.220796923483576, 48.38761752651584, 52.610162765749045, 41.286158484797326, 32.953592961834325, 50.03120437745125, 46.22704659738849, 51.820911284415956, 48.161010434550626, 50.07966918330039, 45.72925859881986, 45.52724869020524, 46.02663701580417, 48.574643981072214, 48.74556910607123, 50.47376932636384, 52.98154454077444, 49.96499476894256, 45.464074996209916, 42.13743048329508, 39.14593681212395, 39.35093948918004, 38.1107880223182, 39.33537944670647, 41.430552697950795, 39.96071900090864, 39.70233286580732, 40.26746796023461, 41.506689825365626, 39.195684233019435, 40.8018163711794, 39.669447714282626, 41.38434325495074, 45.947487508097005, 50.017809483312796, 50.67990164602957, 50.82279751377722, 49.912858624612134, 50.50628969746251, 50.724906921386726, 46.31029498192572, 50.07533104188981, 54.55510923939367, 52.78298239554129, 51.302668125398704, 46.39262945421281, 44.61185770650064, 44.87793560950987, 44.6193023650877, 53.29188246880808, 51.80633575685563, 53.65424279243716, 57.394363957066695, 56.22621151708788, 56.27435468858289, 55.66682269496303, 55.57665524944183, 56.13927610458867, 59.53460916396111, 59.88295093659432, 58.14271296224287, 25.687702278937063, 5.5572758374675635, 3.5732936907199124, 10.879095715861167, 1.9024219748473938, 0.035740246305302266, 0.05336432499931224, 14.609280536251685, 47.648666520272535, 37.345427697704686, 47.075741598683024, 22.73301220709278, 32.559783074163626, 50.87302346383372, 56.28605119643673, 50.588365293318226, 7.935302478651847, 0.08205321076656542, 0.095380122262624, 0.07219622557562205, 0.049745632080181, 0.0662596570327878, 0.06359337611244091, 0.030846568575549512, 0.06939571455962236, 0.051848999254645846, 0.07293906273140062, 0.040807607658808275, 0.015371521641950936, 0.05428957918118085, 0.02682766174867509, 0.010478763217707316, 0.08027859873348668, 0.0398172321729362, 0.024555828009221344, 0.026489937632915475, 0.07461475749169627, 0.062366076444666234, 0.05479297172578593, 0.028217720626402768, 0.034267599318897536, 0.0989254086368507, 0.014999862703975412, 0.11864165429987254, 0.09411092141583081, 12.989918243500496, 48.655884112081225, 47.76239564341884, 48.302690367544855, 28.248500093337032, 24.905207080225793, 48.81508135026502, 59.5726522322624, 36.166559342415106, 42.77755737304688, 2.2601292642854878, 0.1206193485807988, 2.248614901496518, 5.538645069445334, 4.536122554732907, 7.160072980388519, 11.439299410389317, 31.434204040035127, 58.83688226822884, 58.14245800818167, 62.732376360124164, 54.148249626159675, 47.644924579128144, 45.6300461676813, 46.221912214832926, 52.213956309903054, 58.406358995745265, 54.91831679497996, 54.94600480602634, 53.0980428572624, 52.1183838382844, 52.88139074079452, 55.67356524928924, 54.42393733609108, 53.03880330054991, 55.62903458072294, 56.35387289908625, 51.330603245765936, 49.76959013169812, 48.255590546515684, 52.37662484568935, 51.423218250274665, 53.54269450710666, 51.4653209717043, 49.119453353266564, 41.18705588002359, 40.92013466742731, 39.95504725363947, 41.27341470410747, 40.902123143596036, 40.00412394923549, 39.144748333961736, 41.6481501056302, 39.91431736177014, 39.69233082186791, 39.50072696132045, 39.02673990495744, 39.83895294127926, 42.62478105483517, 47.97328972047376, 53.131943902661725, 50.40700274129068, 51.61878762706634, 56.94079283745059, 53.17166574539677, 47.765529617186516, 47.288020272408765, 49.793073361919774, 55.75688815885975, 53.59237524770922, 54.94231385569419, 50.65243328771284, 53.98204703484812, 41.51773914214104, 32.88980541690704, 51.047674840496434, 49.19728102222566, 52.251481625341604, 49.76475384927566, 51.38064092205417, 48.10753676199144, 46.76219124947825, 47.08281363210371, 49.3953214922259, 50.712072926182906, 53.796322807188965, 53.26399049451275, 52.10345921977874, 48.513831553920625, 43.535033733614036, 41.39832650461505, 41.237058254980276, 40.01275316361458, 41.859848268570445, 43.92120284418906, 42.3434490542258, 40.94817961415937, 42.23429341470042, 43.22526847162555, 40.71873664855957, 42.36007598138625, 41.24498536509853, 42.79214074534755, 49.308892065478915, 51.13077417496712, 52.76960711325369, 54.323944353288226, 50.92952128379576, 52.84255143134825, 52.743519429237615, 47.87575214139877, 49.78585227843254, 55.7388021099952, 55.89263354578326, 53.72453166592506, 48.87068486982777, 47.33711265748548, 47.640264803363436, 47.80989946857576, 54.735687317386756, 55.51801189299553, 55.09656890746086, 58.32703690375052, 57.85317536323302, 58.66787125987392, 57.649608273659986, 57.94312315602457, 58.25821891907723, 60.09554732230402, 64.05067320792907, 58.83558788607198, 29.89450312429859, 8.096855590420386, 4.299736013335567, 9.684176041233926, 2.5947348965752512, 0.22917420663420232, 0.07237742835235211, 16.21844172477722, 51.47254205519154, 45.923651264559844, 47.425193402075, 28.96749015777342, 37.96939442234655, 57.42134594148206, 60.712124301541245, 58.890214735461825, 11.648628461745478, 0.24967528639301179, 0.07617628216863641, 0.028223858905896067, 0.03369776779905923, 0.046124583440682584, 0.05733127765838177, 0.03894226400241737, 0.03724737490917887, 0.07565777087884565, 0.0751457023884981, 0.012172697573870182, 0.06857603112415922, 0.0722632046428419, 0.036037821668170156, 0.23627513689139198, 0.18828769574963278, 0.061613372076422944, 0.15398693631493277, 0.09475283414846468, 0.179548854188573, 0.19539394265701696, 0.09493528564851131, 0.07330766593616816, 0.08162514381711522, 0.1446812203334224, 0.12598465301937636, 0.22971541710918952, 0.3136591643335358, 16.849156887300555, 60.56562769797541, 56.8505234103049, 56.54465306189753, 31.918291199591856, 33.409654786509854, 56.80634967742428, 58.2870561845841, 44.4040701466222, 47.20594467655305, 2.6815109627862133, 0.267659139128462, 5.044169022190956, 10.126023196404981, 9.615434542779001, 14.772333464314862, 21.350970960432484, 33.6401960157579, 60.02047315720589, 60.901763054632376, 63.35633524002568, 57.70787900493991, 49.98168837639594, 47.32760483218778, 48.044433670659224, 55.357551651616255, 60.579269701434725, 57.84765658840057, 56.93567022200554, 55.33969702259187, 54.64657498944191, 56.42500115979103, 59.15818322089411, 59.109836086150146, 54.043726305807795, 57.632706780587476, 57.03800878217144, 52.01337806640133, 50.55948880410964, 50.45544793528896, 53.87507615550872, 53.43848497636857, 55.387695066390506, 53.054759502410896, 51.137022510651626, 44.394123015865205, 43.0515859203954, 42.05569613364435, 43.670688906023585, 44.72874433763566, 41.92208451609458, 41.29521131515503, 43.121157000141764, 41.38246051726803, 43.30431207533806, 41.62081510789933, 42.17263375559161, 41.89373754685925, 44.84583885438981, 48.63305591767835, 54.62341339357438, 53.095571764053844, 53.748669931965495, 58.68791064908428, 56.85843875331264, 51.25485443299817, 50.14209762696297, 54.07585836225941, 56.826714623358946, 55.57863212400868, 55.49189283001808, 54.1490105659731, 54.31332649723176, 44.49774419107745, 37.66859962094215, 52.057136028043686, 51.04956934528967, 55.43393588835194, 50.04636826053743, 52.786147748270345, 50.12594530659337, 48.46590019041493, 47.56598295704011, 50.32236191534227, 52.69492518517279, 55.5804991722107, 57.3457657906317, 54.29806455489128, 49.837101967104026, 45.245147905042096, 43.87890008188064, 43.58898201296407, 42.197234861312374, 44.49970929853378, 45.37229153417772, 43.993017519674, 43.00966755036385, 45.29746447840045, 46.53827098108108, 43.99432366894138, 45.19332947269563, 44.69719279196955, 44.808913661587624, 50.77412089993877, 54.07603094654699, 54.96869179510302, 54.35513896326865, 51.877216908239554, 54.11716876491424, 54.23951141295895, 51.788692935820556, 50.776274281163374, 59.98786649396343, 57.03953850653864, 56.770377620573974, 50.94055491109049, 48.62104169784054, 50.69390450754474, 49.24134492874146, 56.638448699828125, 57.69985775793753, 57.4186904968754, 61.0649650327621, 59.94731310875186, 61.447094102059644, 60.39420443196451, 60.40454772210891, 60.72085549754482, 64.79210315212127, 65.78394113048431, 62.56652285975795, 31.330261230468754, 10.309186116341623, 10.570176705237358, 16.73198196195787, 4.37737835030402, 0.28041005975777106, 0.1740398239945212, 18.422092045507124, 60.71090052204748, 49.846570568699995, 58.02374355254635, 34.15703496625347, 44.35606033571305, 68.07073393175679, 69.53375447180964, 71.07374760412401, 15.68387071932516, 0.4629989346909908, 0.21325774941473238, 0.1603768910131147, 0.16794971610990264, 0.1738016166153454, 0.15786913283649953, 0.2204299564923971, 0.13237384929051324, 0.17127125884496397, 0.13730858933300744, 0.13106221483359415, 0.1992702862668422, 0.10972667380326218, 0.12943205633951774], [0.05853583600612418, 0.03322185482829809, 0.06748407237952755, 0.03451588075427759, 0.03984833917310161, 0.02278027177277592, 0.06928293875628902, 0.020323027518668005, 0.046320292092258894, 0.038240178893770904, 0.01566798043166918, 0.03634447517294077, 0.03828060535353519, 0.16037116067544108, 12.314555721898234, 35.158361158063336, 38.03689841301211, 30.926739554251398, 19.05359168206492, 34.136811225645005, 51.20536588853406, 50.14996590152864, 37.057435512542725, 36.26947449099633, 1.176052583802131, 0.03604479306828111, 0.922877807771006, 3.0374621335537206, 4.66742830891763, 10.300699087881274, 27.966295365364324, 50.02477169036866, 58.87079115836852, 57.40099668502808, 55.50032984825873, 49.613483721210116, 43.34641087439753, 45.024577340772076, 44.994218195638354, 51.167169847796046, 57.18376798014487, 54.74567759421564, 55.201323647652906, 53.350137510607325, 53.551719880873165, 55.29102825349378, 54.251188308961936, 54.7786255036631, 51.086019931300996, 54.5347168368678, 50.57826126775434, 49.833289423296534, 48.99555352426345, 50.38566896992345, 45.5292098752914, 50.07578211445963, 48.895438947985255, 50.31923578631494, 46.73148693576936, 39.39184588770713, 37.373009804756414, 38.18219869367538, 37.467817414191465, 38.75845762991136, 38.69220879770095, 38.77174662005517, 39.217845624493016, 38.84318082563339, 37.88144703834288, 38.236692182479366, 38.03631005748626, 39.5797078071102, 37.53621178288614, 45.09340317018571, 51.76169133955433, 50.25037073319959, 50.80013798129175, 54.14497444706579, 51.30567658332087, 45.15376452476748, 43.94261898532991, 45.98612285429432, 53.37235773763349, 53.20538636176817, 53.55390071868897, 50.605478594380045, 55.341987686772505, 46.88939371416646, 32.7198746127467, 50.54683523793375, 45.84753767136605, 46.59035613459926, 46.34185437233218, 45.43718322630852, 44.66076574017925, 49.47575361497941, 48.22450184052991, 50.52561521530152, 48.82387530419135, 52.89096916875532, 50.75964735400293, 51.251092880002915, 47.23959076789118, 41.35589822646111, 37.526421546936035, 38.81907786092451, 38.763980327113984, 38.73912034496185, 42.498006128495746, 39.01885594091108, 40.70724018158452, 40.458805099610366, 39.17571544647217, 40.86221302709272, 40.7840637237795, 39.14999646525229, 39.96133873539586, 45.78898060706354, 48.29914454490908, 50.29825502826322, 53.17019093421198, 51.941343738186745, 52.206284153846006, 49.642156247169744, 47.718410184306485, 53.070613722647394, 52.4823131099824, 53.25287057507423, 49.260007566021336, 46.31289943572014, 46.9227966185539, 45.75099245194466, 43.20073404619771, 49.184396036209606, 54.320131809480735, 55.074764451672955, 53.59744687234202, 54.19213702601772, 53.20595510544316, 51.35291760967624, 48.45842807523666, 51.67428524263444, 56.13653044546805, 60.27966730056271, 57.24973440170289, 36.44663618456933, 12.030834017261384, 1.5126691662496137, 8.969169143707521, 1.8111946313611924, 0.0633230543274793, 0.07852312357675645, 8.216027002180777, 42.86796408314859, 38.73286024216683, 34.684079923937404, 27.03575618805424, 30.854695420111383, 46.64939172806279, 50.969611829327, 57.12895677935693, 11.887867546850636, 0.2762798958968732, 0.019883170476063125, 0.03512182565886648, 0.0044943654117354705, 0.09982898636090179, 0.01837520683634906, 0.05789474681800893, 0.03769321509847238, 0.02990971773772711, 0.09736187680954896, 0.02764426934112224, 0.030981423032860604, 0.028240463861654845, 0.018476598573127584, 0.03944358044874765, 0.02880888577971247, 0.07533359311280713, 0.07258919803726097, 0.028641124015613913, 0.023131886977822553, 0.0796095664883333, 0.03893047390926269, 0.01725898417193563, 0.04937119894630967, 0.08993233313723918, 0.03316939312724337, 0.06506383974826144, 0.14883746182726276, 15.075631718481741, 47.163202608785326, 47.49366229580295, 38.86589527130127, 23.274211037543513, 32.61014238480599, 54.68771673017933, 52.1996122021829, 40.907814502716064, 40.87977347835418, 1.1156651209439001, 0.08105826939666465, 3.7593809827681515, 6.647609433820171, 4.65272726551179, 10.102092815983681, 26.511286266388435, 50.66464754842943, 59.71657576099519, 59.18048189532373, 58.35112417897871, 51.179639062573834, 46.14120160379718, 46.249639449581025, 47.5482891451928, 54.42239976698353, 58.394132967918154, 56.99829086180657, 56.74258370553294, 55.00255361680062, 56.02594706319994, 56.47638420904837, 55.40989960393598, 56.63441258092081, 54.178063561839444, 53.36284206759546, 52.92233244065316, 51.2436992122281, 48.61910012460525, 51.62496928245791, 48.72111312804684, 51.113990352999785, 50.862307548522956, 52.11738755626064, 50.70407129103138, 41.378365562808135, 39.195774447533395, 39.30538900436894, 40.38369171081051, 41.15718310879123, 41.316164616615545, 41.01491482027116, 40.63352315656601, 39.150812318248136, 39.94076590384207, 40.20127404120661, 41.44482620300786, 39.92568439052951, 38.68772552859399, 48.0961658108619, 55.45251223348803, 51.54751423866519, 53.852659809973936, 54.68806582112467, 52.138897834285615, 48.37994929282896, 44.84345405332504, 49.381648109805205, 55.90388290343746, 54.570496697579664, 56.83013493014921, 53.39040848516649, 55.884090623547955, 46.501620354190955, 34.41630755701373, 52.018163358011556, 48.077236452410304, 51.127165594408595, 47.79098972197502, 47.10164100893083, 45.170983729823945, 49.41799279182188, 49.365178077451645, 50.46639134806972, 51.52588236716486, 53.803539968306026, 52.61532068252564, 51.804923703593595, 49.74959781092983, 44.406172537034564, 41.52478764134069, 39.35003342167024, 41.20594601477347, 39.55012136890043, 45.693792527721776, 40.732861103550086, 41.629867938257036, 41.76893165034633, 41.69457527898973, 43.98301547573459, 42.826312434288766, 41.314791787055235, 42.642808268147135, 46.92902142001737, 50.73622295933386, 51.8903450812063, 54.56931214178763, 54.94545959657239, 54.25647958632439, 52.21779631030176, 48.66180689104142, 54.30542684370472, 54.59885543392551, 54.98041968191824, 52.396993713994185, 48.27532791322278, 48.253484233733154, 47.75068736845448, 46.068590687167266, 51.39878972884148, 55.189701664832334, 57.308518963475386, 56.586391002901145, 56.604449595174486, 55.57805553559334, 53.169881066968365, 50.219788012966035, 53.26035445736301, 57.90560960769654, 62.829274592861054, 61.402057447741115, 36.210937038544685, 10.688306727717, 3.0842660607830172, 10.694599190065938, 3.0859960711771444, 0.07208059226433117, 0.04776366302863725, 9.20023302878103, 46.4723555503353, 44.08149442365093, 32.34933810849344, 23.180821364925755, 35.61354437182027, 54.775871999802135, 55.32163843031853, 65.7006888235769, 17.55376362031506, 0.21127880641048957, 0.04401969941212766, 0.11958290822803976, 0.019087231935813062, 0.09831007149431015, 0.03947435803110561, 0.03158824319290298, 0.018429127934899543, 0.018698587870946335, 0.17447989554174487, 0.023055310744131287, 0.07369307710999444, 0.11388847709543283, 0.04145792054553186, 0.14068400337090417, 0.16454860748302552, 0.2328721896534966, 0.18769046892562222, 0.13973216976850264, 0.15294738564520113, 0.22754029430929693, 0.11243126295026272, 0.11742377368312691, 0.20459018467414766, 0.2809666992435532, 0.05850133906689383, 0.1536573652899073, 0.28650695518139874, 20.45391901846855, 57.63966898764334, 55.63313345755301, 46.97359131228539, 29.943360167164958, 46.40445540028234, 60.70490714042418, 57.71192296858757, 49.378616117662006, 43.66077315422797, 1.5979597573318791, 0.10695189568063906, 2.7037218741832243, 7.73686045600522, 12.149380791571833, 18.815949001619895, 31.76498143903671, 53.89906144911244, 61.286488732984, 61.98396067465506, 60.26899453132384, 53.89166778133762, 46.83306455612183, 48.79407313562209, 48.446617818647816, 56.07740463749055, 61.83150599079748, 59.309692613540165, 58.69703408210509, 58.30609144703035, 57.67365632518646, 59.68544390893752, 56.526920026348485, 58.298693856885365, 54.44281178136026, 56.110430994341456, 54.005196863605136, 52.867603609638834, 49.89937351595972, 52.39611510307559, 49.54442647195632, 56.01534881899434, 52.52360390078638, 54.172462417233376, 52.90897677021643, 44.54573831250591, 41.06312074968892, 41.498903920573575, 42.72270302618704, 42.50298753861458, 42.40135108270953, 43.49564529234364, 42.602929530605195, 41.79929471785023, 41.35869095402379, 42.327751728796194, 42.13242161658503, 44.30683851242066, 40.72286690435102, 49.61052233173002, 57.677637530911355, 55.16652830185429, 56.54389604445427, 55.27105946694651, 54.49346134739538, 49.88464893833284, 48.275182785526404, 50.71912142538255, 57.91564303059732, 57.641943962343284, 58.30240834143854, 57.19975948333741, 58.10939242762905, 48.147015417775805, 37.262167546056936, 51.719023796819876, 50.43033299907562, 51.936903615151685, 49.85761204073506, 48.73241347651328, 46.89909765797277, 52.19274805438135, 50.916334275276434, 53.89690022314749, 51.08233290333902, 55.89000163539764, 55.102715261520885, 54.76066104827389, 51.90924698306669, 47.439557121646025, 42.600215250445956, 43.17565048894575, 42.93956695064422, 42.443951945151056, 46.60975225510136, 41.49893137716478, 45.02632671786893, 45.32415620742306, 44.20134244426605, 45.99699958678215, 46.46568359867219, 42.21524246277348, 44.48728322982789, 51.6177874226724, 52.92780022467337, 54.057289861863666, 56.6427593846475, 57.33186098837084, 56.64677196933378, 54.764038208992254, 51.43351839434717, 55.561632571681855, 56.62314361141574, 58.023143429909986, 53.535230236668745, 50.366743533842026, 51.69591319176459, 50.4866268557887, 48.14636822669737, 54.193623604313025, 56.584002279466205, 60.146600892466886, 59.29930617732387, 59.12956953048707, 58.301867054354766, 55.47792134746429, 52.22726491189773, 56.98322111560453, 61.61056672373126, 65.5026012851346, 62.093073168108546, 41.928776079608554, 18.830306837635657, 4.092884183891358, 19.204604894884174, 4.948771586341243, 0.2319941303182033, 0.1696988787021368, 10.808450887280127, 55.26569366455079, 51.37444749955208, 47.72904765221381, 37.514725039082194, 43.18987692556074, 61.26812027346704, 64.4140455030626, 74.79412355730611, 22.775832722263953, 0.5993293982840354, 0.12442986225529064, 0.22283190260491065, 0.1054507157494945, 0.21850139143005495, 0.17443815907163007, 0.2292676080739306, 0.1803822965631562, 0.1848446208262636, 0.2761706517588708, 0.08187009277002466, 0.2569656855156345, 0.2012293569503292, 0.09744421593965062], [0.11475148280301403, 0.09362036467439706, 0.02066310352435516, 0.10239056221419766, 0.054734726060902884, 0.030003883350159855, 0.03591467303434207, 0.06856273183779371, 0.026170724116626288, 0.07346755614684475, 0.022379799310358304, 0.05188192571363142, 0.02906402370201484, 0.06209466681485215, 15.614586953193912, 33.34314315549789, 42.252089208172215, 42.8890311333441, 22.70600276608621, 24.783266475123746, 56.11678915639078, 42.99205218591998, 36.46443982278147, 32.96491292215163, 0.31950937944554514, 0.06758258362571079, 1.0412070131109608, 2.310970045866505, 6.158274633269157, 15.311184756217466, 32.58670818421149, 59.17417864645682, 59.95860953484813, 57.74551806911346, 52.95971262839533, 47.13956248375678, 43.513837245202836, 43.45840238755749, 45.11621959747807, 51.27963596774686, 57.13707216324345, 53.672987799490656, 52.71447035574144, 54.64036587745913, 51.77260729574388, 52.5474166101025, 50.53758236669725, 51.08096791851906, 49.304291125266786, 50.74613871112947, 50.434541702270515, 48.33606973771126, 49.44225265133766, 49.20322341303672, 47.22529372861309, 47.42824892843924, 49.41810261818671, 48.13056499727311, 47.46715884054861, 40.82673126651395, 37.24055528640747, 38.058879375457764, 40.04379872352847, 42.771046238560835, 37.6359341221471, 41.04604667232883, 36.989025454367365, 37.55348590112502, 37.15578502224338, 37.01821965555991, 36.62083648866223, 37.93829394925026, 38.050105033382295, 44.27024279871295, 51.814035369503884, 48.825448174630445, 50.6201639483052, 53.41460166438934, 51.7408400197183, 45.753479234633915, 44.87611955212009, 44.387611881379165, 49.83126940265779, 51.31074036321333, 54.79678215519075, 54.7149811252471, 54.47434371517551, 50.122250433891054, 33.899178351125414, 49.48702650685465, 45.87829297588718, 48.08603825107698, 45.281374915953606, 47.83174707043556, 51.964983863215295, 53.85986912635065, 52.54571430144772, 53.059042730639064, 51.565792483668176, 54.182158516299346, 51.80243692090435, 50.144623633353945, 44.01777552020165, 39.02306464410598, 38.08847758077806, 38.80953865666544, 37.60201346489691, 38.35909366607666, 37.87635580185921, 38.885122729885964, 37.90821329239876, 38.71746886161066, 41.280957421948834, 39.84245954021331, 38.735613746027795, 39.75394733490483, 39.23306049839143, 42.354474836780184, 44.67407826454409, 46.86733822668753, 49.104826834894, 50.87640846929243, 50.3434407326483, 49.94180179411366, 50.573691706503595, 54.17204272362494, 51.29402714390909, 49.604662310692575, 50.34772788324664, 50.729327432570926, 50.81272878954488, 47.7348017692566, 44.958791348241995, 46.69354977146272, 49.17551579013948, 48.50729296284337, 49.29762309597385, 44.24030726955783, 45.69740503065048, 45.73229451333323, 45.48217673455515, 50.692123751486506, 58.1012378200408, 60.07058928089758, 60.43171798029254, 42.41571872465072, 13.874825546818396, 3.7020937858089327, 6.170887995150782, 2.788989789062931, 0.22568689779408518, 0.026585978245542898, 4.32114185825471, 46.17492614253875, 40.03092158225275, 35.53774064587009, 44.36152419736309, 30.553367176363547, 38.38709546673683, 49.345479934446274, 54.061031803008056, 21.757991390843546, 0.1831324449590137, 0.035259300136878606, 0.12963295523678103, 0.056869778631915974, 0.05636002755753937, 0.07243790333309481, 0.1034344106371845, 0.04119108446062573, 0.06640103855921377, 0.008274269564407728, 0.015951445412581727, 0.020478453351965836, 0.09417964716351802, 0.033656169224770806, 0.0012496444176048822, 0.06526796387568598, 0.05720195052544436, 0.12602566170596308, 0.08444492960528982, 0.017517764842317953, 0.04711440351280955, 0.03302113213125737, 0.04332957676641884, 0.05516193116143827, 0.04350175119696125, 0.08014741383733288, 0.07833606788828489, 0.11340607152951342, 19.95730773095162, 45.26824674298687, 50.16330196011452, 46.491261374565866, 27.064314965278875, 31.376190224001487, 56.10286474227906, 46.269874957300004, 41.02017471867223, 36.74093554096837, 0.2938473032366845, 0.10171228328779822, 0.9645817344707828, 6.918537837843742, 7.614796786539017, 17.373083560697495, 34.209955584618356, 60.795737466504505, 60.610378019271366, 58.61671570808657, 55.34141502072735, 48.5446653058452, 45.028911559812485, 44.6426090886516, 46.74072803989534, 52.967796633320475, 58.145446854252974, 55.60188001201999, 54.34415632678617, 56.72014382577712, 54.38947931412728, 56.04411940420828, 53.03077813117735, 51.67304185128982, 51.63717962080433, 51.21255167068974, 51.02989473650533, 50.00677585601807, 50.161595729089555, 50.13707699314241, 50.15906187795824, 50.15831270525533, 51.35844815161921, 49.99909977759085, 47.970999056293124, 43.40074354602445, 39.18437211744247, 40.04883112445955, 40.443994229839696, 42.98036352280648, 40.66665541741156, 41.28743325510333, 39.58561097421954, 38.96590394358481, 39.06323363704067, 38.693201157354544, 39.416360701284106, 39.45885565973098, 39.366530910615005, 44.679942207951704, 53.405693961728005, 52.24229543439804, 51.32124839290496, 52.55738335271036, 52.93320132840065, 49.39740819315757, 46.52314239932645, 45.26403803979197, 52.30741462399883, 54.25166291575278, 56.59790315935689, 53.94700065735848, 56.69479354735344, 51.34391577013078, 37.529575132554584, 50.74995125493696, 48.549450597455426, 50.58332112527663, 49.04039798244354, 48.68410948784121, 52.10284340766169, 55.46999031497587, 54.020584321791134, 53.6278413188073, 53.94410202580114, 55.75963774035054, 53.642856151826926, 51.066270797483384, 45.96466748945175, 40.53825662982079, 40.200748443603516, 39.822628036622085, 39.78505565274147, 39.37193985908262, 42.21745860192084, 41.54635283254808, 39.82926468695364, 40.65119735656246, 42.59187629145961, 42.58637712847802, 42.02498789756529, 40.29008042427802, 41.756682088298184, 43.114061432500044, 46.80017940459713, 47.769220567518666, 50.36710046952771, 52.59551271315544, 52.94516455742621, 53.13618006244783, 50.73643476732316, 56.3714490398284, 54.5052323802825, 52.75544343456146, 52.83894677315989, 53.19597267335462, 52.47677080092892, 50.232194469821074, 47.02880651720109, 50.10018710167178, 52.16908439513176, 52.19621935198384, 50.44870930333292, 47.339473924329205, 48.24498445756974, 47.43628194255214, 47.50816722070017, 52.1808671951294, 61.97554326826527, 61.93849648198774, 63.27324767266551, 43.181079049264234, 13.584131829200254, 2.987412690154968, 6.049547022388828, 3.4092886072974053, 0.465787218943719, 0.0986585955345823, 5.206569856212986, 49.44926192683559, 44.00613392553022, 45.636902470742505, 44.248163777012984, 35.050127275528446, 46.66221787852626, 54.96127851547734, 61.469322173826164, 26.96011131809604, 0.13578387518082896, 0.06284135739288985, 0.07357578138790785, 0.041920603177840673, 0.07106254568263408, 0.05343591208539663, 0.08542340774569782, 0.057349667599004124, 0.04800758925416777, 0.040674626286472046, 0.09821323798068109, 0.017765132717848305, 0.01280976671560277, 0.04301581013527128, 0.2347271489880739, 0.20530779455457965, 0.17073487472389975, 0.22743691840479452, 0.1856311326546054, 0.19186914147388553, 0.18451184755371464, 0.1425795960089853, 0.11384969772470575, 0.20879236079992788, 0.08925532591679404, 0.1614920698827313, 0.13135672967520454, 0.23208072889716397, 24.989894974616266, 56.10101338355772, 59.860440454175404, 55.509912198589696, 34.37579339550388, 37.83509246764645, 63.275275538044596, 51.9366329716098, 47.75127180161015, 39.519907351463075, 0.4874078749168304, 0.16528823473040136, 1.8786824422497905, 7.870360776301354, 11.009245841733872, 21.169675088697865, 39.468387019249704, 62.47009138907156, 64.08735129141039, 62.44088934313867, 57.33436346054078, 51.47832362882553, 46.828604821235906, 47.07724778882919, 49.20221928627261, 54.89949726289319, 59.58386628858505, 57.25606510716101, 53.228693085332075, 58.01664406253446, 56.136848157452, 56.333107871394006, 53.764253508660104, 52.264715702303, 50.87464340271489, 52.35859371000721, 50.96814878525273, 51.153625903591035, 53.0287463434281, 52.54389039931759, 51.610342764085345, 52.497826084013916, 53.671509065935695, 51.06477245207756, 51.375604598752915, 46.328832103360085, 40.46029167790567, 41.84736336431196, 42.82216648901663, 46.415492949947236, 42.21221831537063, 45.14189935499623, 40.52116294060984, 41.13965011412098, 41.20740905884774, 39.829833430628625, 40.95559289378505, 42.817953863451564, 42.06410961766397, 48.345193170732074, 55.51412874652494, 54.69752657798029, 53.50597327755344, 55.07957719987439, 55.85983468640236, 50.93568724970664, 49.75775241851807, 47.12109988735568, 54.22909359778128, 55.563860477939734, 58.723968998078384, 57.894407318484404, 59.587027718943936, 54.759735368913226, 40.65134640662901, 50.620328687852435, 50.75015914055609, 52.98959716673821, 51.54560012202109, 49.97874267639653, 54.961337351029925, 58.36051041080106, 57.78509478415213, 57.69536664409023, 55.35125624748969, 58.45188202396516, 54.706701001813336, 53.10711529947097, 48.183509149859034, 41.70533041800223, 41.305327107829434, 40.777756552542414, 41.95508733872445, 42.12969949168544, 42.87566761816702, 42.767692612063506, 40.440197375512895, 43.3502547971664, 44.0880016357668, 44.089221492890395, 43.07306874182917, 44.66654339144307, 43.947772979736335, 46.52086742462651, 49.02543806260633, 49.27756409491263, 52.36110010454732, 54.21553004172541, 54.30200653691446, 55.29434265628938, 52.483603569769095, 58.41641987523725, 56.97706691680416, 53.529417284073375, 55.361603460004254, 55.88998202354678, 55.337853508610884, 54.46770706484395, 49.927477298244355, 52.55908173899497, 53.43629237144224, 53.581977044382405, 53.657000218668294, 50.47996274886593, 50.986144619603316, 51.23670954858103, 50.34382512492519, 55.80432138135357, 64.7852272372092, 65.29428028291272, 67.02007216791954, 46.927087691522416, 17.581667361720918, 9.629961040712173, 16.248467468446304, 7.683056323759018, 0.6881091827827116, 0.20497995488826307, 5.970121477880786, 58.15576268780617, 51.60954652294036, 47.49686687223373, 56.68388543590423, 40.41451369562457, 52.25944011442123, 64.71983740406652, 70.92056335941439, 34.719342031786525, 0.31327057389482377, 0.20274622636216305, 0.22258779634871792, 0.12303095506203753, 0.1163104181027701, 0.2104905632234389, 0.24136493312976054, 0.17727544230799522, 0.16050798397871757, 0.12287999743655806, 0.16384834183319924, 0.1008484348835003, 0.24424540840329664, 0.20864776936509918], [0.09450664413311789, 0.11277330588669547, 0.013457886675643104, 0.016721759269374515, 0.030451209750026468, 0.015541287683581394, 0.04785738622529372, 0.01571226797457184, 0.06515408490574168, 0.01663690928610102, 0.03231760677731326, 0.0896903106402005, 0.050285521053498795, 0.1872145751070592, 17.018058069290653, 35.99444966162405, 44.30459883905227, 35.7719139898977, 23.646616551183886, 32.471488560399706, 54.724818429639264, 32.97539741762223, 44.931358291256814, 26.616717615435203, 0.04278574244029099, 0.47340626978585804, 1.8396917538296793, 7.14963996602643, 2.0353269528958107, 7.769999090702304, 37.99834151421824, 58.866590299913966, 54.31341671174573, 51.5627722586355, 47.62647767220774, 45.01341427526167, 42.977335453033454, 42.632790534727036, 46.087206256005075, 50.11633942204137, 53.78617171318301, 53.72535536366125, 48.60780762087915, 48.976985023867705, 52.60209445030459, 49.80044349547356, 50.84447645371961, 50.327755174329205, 47.70255596406999, 49.55514238726709, 46.85848151483844, 47.52414695678219, 48.58864292021721, 49.31827829730127, 47.39419883297336, 48.17833946597192, 49.204796283475815, 47.89551696469707, 43.94325048692765, 40.447900910531324, 36.803630705802675, 37.0221734046936, 38.095765344558224, 40.69523772885723, 37.063064113740005, 39.154236547408566, 37.58959131856119, 37.707713496300485, 37.00822153399068, 38.682093005026545, 35.60941803839899, 37.31564121861612, 36.882803747730875, 43.78738726339033, 51.222047728876916, 49.972400203827895, 51.054892001613496, 52.02002256147323, 51.26512712047946, 45.55294413720408, 43.557320640933135, 44.143032489284394, 45.03253975222188, 46.66125689783404, 49.95136061022359, 50.50432851237636, 53.22868524059173, 51.36234306520032, 36.51633670253139, 48.07239624761766, 48.25244480563749, 49.290229428199034, 49.33929827905471, 53.35888439609159, 52.737781001675515, 51.384265192093395, 50.64684391021729, 49.22478860424411, 48.171349802324855, 48.10314370739845, 44.701385805683756, 41.93923704085812, 39.691558114943966, 38.779544291957734, 37.90807993181291, 38.79238220953172, 37.94381664645287, 38.280838458768784, 37.687030838381865, 37.513760136019805, 39.82041189747472, 40.509599793341856, 39.003982313217655, 38.60141377295218, 39.32115301009148, 37.80661606019543, 37.2126672344823, 38.99609050443096, 42.5182298691042, 45.15957747736285, 48.63091822593443, 50.22345150670698, 53.12423644527313, 51.05735917245188, 51.45262425945651, 52.96876545875303, 51.62906031454764, 51.68939029016803, 52.33087431999945, 53.702401653412856, 54.476097014642534, 51.644808630789484, 45.21638124219833, 42.00454058185701, 42.46263027191162, 42.90141797834828, 42.79662793682468, 44.87450745797927, 49.51755823627595, 48.235692362631525, 51.29104614257813, 49.39181881566202, 53.6848686587426, 59.27429714510518, 60.90288877487183, 48.63200080010199, 18.878238201141357, 4.852662730601526, 5.701492563370736, 3.5493481111141945, 0.1253720584716047, 0.05667867416876459, 1.920123631435056, 40.89313307116109, 44.033174745498165, 28.101944654218613, 27.89852857589722, 18.815074313071467, 33.669856979000954, 52.03360965175014, 58.62196383937713, 24.618034670429846, 0.16193293816139623, 0.07376213227548907, 0.03251785833028055, 0.041871822529262116, 0.07987209715910497, 0.06690759887738575, 0.028540779904071844, 0.05562094423258978, 0.130156836802921, 0.042678911479250084, 0.015667005584785537, 0.016769231822822365, 0.054553006174823934, 0.042099921378277005, 0.007293453898220774, 0.050580392125993974, 0.038431884735942855, 0.052066529920745286, 0.09019060435915187, 0.09484108747734178, 0.04853499099431981, 0.057635629068939924, 0.03611880865308546, 0.04190688637355643, 0.14755516853784362, 0.030525033812849756, 0.06916166703787542, 0.3276701463807014, 21.017414562163815, 45.14026764900454, 51.87940166842554, 44.566538641529704, 30.160096614591538, 34.733623381583925, 60.32089141107375, 37.78204633343605, 47.40929995813678, 29.912657814641154, 0.058699759669722094, 0.5446092087414958, 5.061286735919214, 9.379054865529461, 7.866246209990594, 10.362508777649174, 36.885266996199086, 59.43039178848267, 55.97074754776494, 54.214482768889404, 49.47416505505962, 46.578083038330085, 44.72102903550671, 44.58931192275017, 46.854174752389234, 53.78193947576708, 55.321987521263864, 55.60952471148584, 49.05828791279947, 48.68723953923872, 52.20506821909259, 48.96282526754564, 52.25004603785854, 50.76606827397501, 49.418145764258604, 50.82700229460194, 48.735418012065274, 49.83729808561264, 49.33284205775107, 49.81970233301963, 49.77379099015267, 50.35226998790618, 51.39671479502032, 49.22856192434988, 46.73030630234749, 41.89277264379686, 39.0580992544851, 38.96856723293182, 39.39333638837261, 42.19680732296359, 39.23523349146689, 40.65439016588273, 39.470042259462424, 38.3886997161373, 39.216743438474595, 39.152381266317065, 37.890378275225245, 40.4461476110643, 37.788082861131244, 46.51226174446845, 54.39710047937209, 51.80217019973263, 50.33229727898875, 53.5435103601025, 52.088087451073434, 47.18336359147103, 45.17840485418997, 47.31217422792989, 46.48592695113152, 49.864256535806966, 51.284519318611395, 52.63388133818104, 54.953351405359086, 52.22544493213777, 37.516917644008515, 48.287769671409364, 50.66738536280971, 51.64559702719412, 52.3858973287767, 54.675000406080684, 53.35299299609277, 52.3662894002853, 52.98536492932228, 49.29495980662685, 50.6670323494942, 49.74096467418056, 45.76353226938556, 44.67199548598259, 42.2265035875382, 39.86539363861084, 39.72359995688162, 39.79620302877119, 39.70563157912224, 41.725765966599994, 39.43294840474283, 40.670679769208355, 42.57568866975846, 41.71807027632191, 41.55810033121417, 39.90452320344987, 40.4591541905557, 41.540426131217714, 39.42253451193533, 42.57008360278222, 45.414229516060125, 47.29217798479142, 49.55717417501634, 53.22763796775572, 54.05113174069313, 53.045651758870775, 52.44436810093542, 53.11814892676569, 53.843461851919855, 52.933299387654955, 54.38197189761747, 54.91080937847015, 55.97491702725811, 54.11381513841691, 47.650768910684896, 43.71204637712048, 44.1715951888792, 44.55845855897473, 44.05006839383034, 48.141241688882154, 50.583462330602835, 51.39445943217124, 52.55189595683929, 51.11380600160169, 56.39387323010353, 60.51611954166044, 63.83634705697337, 50.14545517583048, 18.73034131142401, 5.343144824427943, 5.006769712894194, 3.158118897868741, 0.05695992036752644, 0.05600083191248198, 1.7912080715740881, 45.560078928547526, 44.81609159900297, 38.48298565033944, 37.48353827384211, 22.487061946622788, 39.103386940494666, 57.91363869943927, 65.52289955077633, 30.98261371735604, 0.304125537194552, 0.05207342471206381, 0.051920854471503734, 0.020654523339603218, 0.012146185186030644, 0.033667710339350086, 0.030827454681838715, 0.019232476460597208, 0.02222565284389402, 0.043062713868435354, 0.017972817238900932, 0.0249847817054439, 0.018109343683106766, 0.027422023403848854, 0.11773596217315044, 0.2287548347826927, 0.1451700150726303, 0.09735434616525328, 0.14610461169673553, 0.26981108010776583, 0.1867343758743617, 0.10420118804059683, 0.12873028915735985, 0.19680732891203898, 0.17945957430187734, 0.1672921981662512, 0.1789589818086355, 0.5718381799036457, 28.340595383797925, 57.52861884332473, 61.05167212024812, 50.449556535290135, 36.150214825907064, 43.03120136260987, 61.067785216916, 42.50287378987959, 56.41972949427944, 32.94394393121043, 0.17369410383605188, 0.7717917859554292, 6.596934862675206, 14.174628969161743, 4.8923762382999545, 11.632971340610135, 40.66365088185957, 61.81274137189312, 58.307166176457564, 56.96811999044111, 52.128840877163796, 49.27560290982647, 47.03910666127359, 47.96995962819746, 48.98905023451775, 55.015520972590295, 58.5685529247407, 55.88513005164362, 49.78644847869874, 50.176892972761586, 54.348498390566924, 49.79230065499583, 51.40464974987892, 51.31818109943021, 50.44523800573042, 51.61453185542938, 48.38936298124252, 52.57774045390468, 50.5217359912011, 51.582352730535696, 49.2195483176939, 52.52051699546076, 53.60933165396414, 52.137509315244614, 48.720760114731334, 44.32828603252288, 42.39242376819734, 39.61168296875493, 42.053680035375784, 44.03423378544469, 41.488454726434526, 42.93655457035188, 40.93558096116589, 39.85576814220798, 40.92451987727996, 43.43089872790922, 40.75628549821916, 41.168691342876805, 40.282847573680264, 47.74774166845506, 57.353783115263916, 54.6619624476279, 52.588264173077, 54.88437260350874, 54.66338234563028, 49.855713613571666, 47.49022237716183, 49.23902288559945, 48.08837206132951, 50.537268577083466, 54.38958521812193, 55.21003523180562, 57.089893894810835, 53.67030882066297, 40.233833636007006, 49.34562898451283, 53.09475983342817, 53.23334109398627, 53.71694187964163, 56.926535021874216, 55.727305643020145, 55.07349360373713, 53.166029299459154, 53.014453226520175, 53.114277547405614, 52.10230212057791, 47.349883894766535, 45.8160488836227, 43.996786917409594, 41.78535461425781, 42.700588703155525, 43.457366881832, 41.25606998320549, 42.78340954934397, 40.93695379072621, 42.382629609877064, 45.3002062151509, 45.658208785518525, 42.40787398430609, 42.658729168676565, 42.72824141287035, 42.89248674146591, 41.02191625102874, 43.549546503251605, 47.099950467386556, 50.30870422240227, 53.52632645637759, 55.79391925565658, 58.38764536765314, 54.794542481822354, 54.465969454857614, 56.04623748410133, 56.68459538490542, 55.34397240607969, 56.70784719528691, 57.419196482627626, 60.648244580914906, 56.02202077065745, 49.914764896515884, 46.05454860195037, 46.97513280376312, 47.62848984810614, 47.76070902424474, 51.39247471286405, 55.1800722460593, 53.05389658097298, 56.705874243090236, 53.85010634699176, 59.58904773958268, 64.05519177836757, 67.3287783899615, 51.759224168715946, 25.345061671349313, 9.858698960273497, 12.387815790791667, 9.704137963633384, 0.649748157349325, 0.18780073962144314, 2.4525092638308004, 51.51236980192123, 55.147112569501324, 41.84800663302022, 39.38107505921395, 30.179353490952526, 45.4952343048588, 66.97618869043166, 74.95551340041622, 39.854932677361276, 0.6861402755302768, 0.165238025327844, 0.10803328241191565, 0.12828300106188945, 0.09862746172133954, 0.14258474411983646, 0.12429247970782942, 0.12241276807241863, 0.24881628732527458, 0.12628371842325697, 0.1261482587564857, 0.140891260797939, 0.12233248971883329, 0.21294670239571603], [0.08357238610305133, 0.10019622592916412, 0.0420895217347049, 0.04854011612253324, 0.06478486116975546, 0.09410951947492939, 0.061777291909581235, 0.05320187605496857, 0.036049512169894674, 0.030652361456304792, 0.044730042948597865, 0.01539607380231422, 0.07438643264674372, 0.9294668380771914, 26.389151503962857, 39.93177975377729, 46.08295440673829, 31.658587148112638, 25.930530332749893, 34.08927602152671, 35.702641010284424, 31.282139632009695, 52.109072131495324, 17.25406119900365, 0.04667330923820696, 0.35908741215544365, 2.1709291733080343, 7.205511677649714, 4.845718664507713, 8.969248571703512, 44.95195465703165, 57.7227997010754, 55.30060668145457, 49.624219248371745, 49.20121908187867, 49.1938607154354, 49.042343478049006, 44.00306663205547, 44.40448591786046, 49.160489190009336, 55.65616561520485, 54.24699529524773, 49.42218580553609, 47.57336093533424, 47.40721717957528, 48.74480424388763, 47.88586008933283, 48.444778227037006, 48.649180781456735, 48.26645943426317, 47.60950165410196, 49.989407600895056, 49.49548705931633, 48.789527108592374, 48.83494423281763, 47.8661423344766, 46.82273695545812, 43.815565570708245, 41.372038779720185, 37.21284766351023, 35.75962520414783, 37.57763593427597, 39.26825200357745, 37.49275192137688, 37.47676434055452, 38.30505909458284, 38.67573484297722, 37.1676698038655, 37.46360871099657, 36.70049982686197, 36.387165208016675, 36.32097128898867, 38.687086182255904, 44.73323937385313, 49.930760322078584, 49.93700081302274, 49.039813549287864, 53.434339031096435, 48.64077514217746, 48.513184362842196, 46.21185133534093, 48.34086679643201, 50.01522071899907, 48.89021042854556, 50.2829420951105, 54.01684630301691, 51.40882707411244, 52.41675069255214, 35.940164058439194, 48.70004215548116, 49.05000778936571, 50.69073915481568, 51.1145120282327, 52.91791192946896, 50.645416167474565, 48.710059888901256, 46.33370760948428, 41.768555102809785, 39.74716947924706, 39.52884643308578, 38.147230763589185, 39.20709833022087, 37.87681864153954, 38.527524163646085, 36.54124375312559, 39.06162546527001, 39.46325263669414, 38.409802067664366, 37.7617206112031, 38.934128822818884, 39.67793180096535, 39.250793533940474, 39.15982200253395, 40.37898094423356, 39.558793729351414, 37.26263038573727, 37.49889827543689, 38.242877760241115, 40.24343559818883, 43.15475210066765, 45.60715129298549, 48.65957898478354, 52.79591052762924, 51.40570878982545, 49.19799097122685, 53.582918413223766, 51.2890378890499, 53.90182279771375, 54.88566306329543, 55.12643775632305, 53.31130212353122, 49.507520891004994, 45.959023198773785, 43.09144504608647, 40.32227131628221, 39.980013139786266, 42.23159482402187, 52.118160263184585, 54.402054432899725, 56.06664557610789, 52.64545233018937, 52.90631348086942, 53.18489982235817, 59.21512426868562, 58.075789482362815, 62.675023463464555, 27.37522752054276, 5.200298476603724, 1.6966464682932825, 2.449594697644634, 0.847079904089051, 0.034816662195108594, 0.8644189865839097, 32.86636141038711, 48.87241855744393, 37.94248696296446, 38.15994708768783, 35.40967918211414, 45.197957869498964, 51.7354702949524, 53.59943551401938, 28.409815411413874, 0.698467304389323, 0.11817937386372399, 0.13382535608064744, 0.05154277092867321, 0.03638631123448572, 0.023161668645878954, 0.008701762905524624, 0.045633858159905484, 0.039421482642571774, 0.04364626985343714, 0.032389936968684196, 0.02266446417648225, 0.022225047634433837, 0.021209285909970923, 0.029269461670229514, 0.0775428987558811, 0.06601472340163685, 0.039937940816725456, 0.03427519508066677, 0.13071611163116273, 0.0402671517804265, 0.029243569813608646, 0.04857712199971561, 0.05821577979311828, 0.008542888718957623, 0.07265577873876018, 0.051100259391410705, 1.1856313794851303, 30.101651337838945, 48.22103054292741, 53.49232342935378, 36.63122292487852, 29.93884748028171, 36.18226059021489, 44.35230662745815, 35.823689276172274, 56.758414391548406, 20.696803946648878, 0.1346060609625232, 0.5514682697192316, 4.764067665223153, 12.534388880575857, 9.767844119379598, 9.951288469376104, 44.60906497893795, 62.00191728530392, 56.20764693906231, 52.59770924045194, 49.137029494008715, 50.683267039637414, 49.2107347519167, 46.30131275423112, 46.32044607593168, 50.90909750230851, 55.8228781146388, 55.32116774589785, 51.0176569415677, 49.73643433663153, 50.1480870862161, 47.63793883785125, 48.15941402989049, 48.38998271572975, 47.30655347147296, 49.50595978767642, 48.47304674886888, 51.72596639202487, 51.45045126638105, 50.43338852543985, 49.13549976964151, 49.84281686044509, 49.515714722294966, 45.81433873022757, 44.00522393565024, 40.867253272764145, 37.72273617406046, 41.431211656139745, 38.50624530546127, 39.52553987503052, 39.325722571342226, 39.21759851517216, 40.28640908579673, 38.862796598865145, 38.82156856598393, 38.43871385820451, 37.17229427829866, 39.2892562958502, 40.48417106751473, 47.766223876707016, 53.074606695482814, 51.853502258177734, 52.17240664266771, 53.91868114471436, 50.727013234169256, 49.662529037844756, 48.628478511687256, 49.1964534021193, 52.36539902225618, 48.8203961618485, 51.26072622114613, 53.636478377926736, 54.91956410869476, 55.19429083793394, 36.736597399557795, 49.6040504209457, 51.596849810692575, 51.709449291229255, 54.96450270375898, 55.23600524471652, 52.52364704685827, 50.24726421602311, 48.136264201133486, 45.015269556353175, 41.32586856042185, 42.47215770906018, 40.29102179311937, 40.79274000660066, 40.27645018792922, 40.45427083969116, 38.204356162778794, 40.72306694522981, 40.26190603933027, 40.34908071640999, 39.190926398000414, 40.48970945419804, 43.65237535968904, 41.30404449278309, 41.613966649578465, 41.92696394458894, 41.53851201457363, 40.671711352563676, 39.467422116187315, 40.36051050309212, 41.076233233174975, 45.63182692373953, 48.13068266837828, 50.99036508990873, 54.18047581949542, 52.92900831468644, 50.41240384501796, 54.726826683167495, 54.244594804702274, 56.42795078216061, 57.021472069524954, 56.95822777286653, 54.91410416941489, 52.43888462743452, 48.88405622974519, 46.80267010965655, 42.090989620454856, 42.68790768038842, 43.720216674189416, 53.86213625631025, 56.676978142030784, 57.93630607666508, 55.60238207540205, 55.81872040225614, 54.689638691563765, 61.50007355597712, 60.01914347371748, 61.90747837866507, 28.707376218611195, 5.815911533371096, 3.779098002179977, 4.47908737005726, 1.423573876100202, 0.04818911378782603, 0.8571198847024672, 39.33361438012893, 53.117038896006925, 39.1749741185096, 42.27870248979138, 36.120083178243334, 49.62677663372409, 57.40881396878151, 61.62806049469979, 34.27169369113061, 1.0826523698145345, 0.03491458738402974, 0.09756997693330051, 0.04344066334587913, 0.0673657960648979, 0.08606731996781404, 0.06120732249391656, 0.05551960612196596, 0.07166529600057872, 0.07554079691368727, 0.04166294865670704, 0.0546974482225074, 0.052726330806411086, 0.057822493235430414, 0.20966062953154888, 0.270356044413582, 0.23697495821022221, 0.12132039564030787, 0.22060539062705734, 0.17116271950785192, 0.11721516794134533, 0.15881209514073788, 0.1469848467217338, 0.26302596193648153, 0.18452704673813236, 0.20049506167490638, 0.19060351825769872, 1.6930635057149397, 37.05749827046549, 58.04072741539248, 60.65679142552038, 45.761182769652336, 38.812292160526404, 44.51848176217849, 44.325446236518125, 43.440277114991225, 62.526369556303955, 23.61058761996608, 0.25740054766497306, 0.4224939662362299, 3.4593628106578707, 16.2887982591506, 8.146489752877144, 11.546927286732583, 50.132193642277876, 61.656219190166844, 61.10629504726779, 53.895750968687004, 51.79399598029352, 52.74206815227386, 51.735658568720666, 48.074078944421586, 47.97462724870252, 53.401661765190866, 59.57756696208831, 54.91263720297045, 50.26119647487518, 49.695888796160304, 52.16158090099212, 49.643493775398504, 48.82800163761262, 48.830296224163426, 47.937235293849824, 49.45587504294611, 48.96432361295147, 52.54328243194088, 51.46452080818915, 51.757215915187714, 51.98064196494318, 51.68234571333855, 52.15865873521375, 49.394270297019716, 46.51354043714462, 44.036685266802394, 40.15874770379836, 42.02334834683327, 41.24523639678955, 41.456950249210486, 41.07500945368121, 40.94146451642437, 42.750508708338586, 40.660728716081195, 40.86608048408262, 40.42502957005655, 39.130027678705034, 40.8241032784985, 43.16211438948109, 49.70668708124469, 54.913900206165934, 52.699502591163885, 54.128406355457926, 57.372394761731556, 53.45251921684512, 52.822947425227014, 50.66653028611214, 52.77720082190729, 55.318684885578776, 51.853980787338756, 54.492355239006784, 57.925550937652595, 56.35076638190978, 57.23091094724594, 39.77726974794942, 50.846386647993526, 52.85089431270477, 54.51245346376973, 55.9108058867916, 56.25026741335469, 54.401379785230084, 55.104770583491174, 49.7921633720398, 46.93958044052125, 42.83476906438028, 43.82647760452763, 42.90353605824132, 42.688468579323064, 41.91655397415161, 42.530047970433394, 38.60651285417619, 43.55475148847027, 43.716741454216745, 42.54547072995094, 40.722737466135335, 41.69152367499567, 44.58954726496051, 43.44816500140775, 44.034457360544515, 43.733376226117535, 44.122079187823886, 42.58787155151368, 42.20547968341459, 42.541316939938454, 44.38838851067328, 48.83910978994062, 49.2203837825406, 53.05726197458083, 57.94690432087068, 55.22361447734218, 51.76979103396016, 55.97661933591289, 54.3376059685984, 59.27698789104339, 57.02124457205496, 57.91031645190332, 56.7798383774296, 53.72113881572601, 50.444084828899754, 49.34937484802739, 43.56711872162358, 44.6170352351281, 45.98381257826283, 57.770374128895426, 58.26339252533452, 59.9735184638731, 57.37388134002686, 59.31776092898462, 59.04015910240912, 63.697232354071836, 62.07165310459753, 67.48357080644178, 30.712876242976037, 8.108601127901386, 8.117937839800312, 10.470912302694014, 2.630523092323734, 0.1897387888522879, 1.1708062911225905, 46.51305798561343, 61.04901667564147, 49.788080184690415, 48.18223045718286, 47.26447036189418, 58.90730450230261, 65.44757827635735, 69.72390313302317, 43.32238635709209, 1.986183699580931, 0.1759241551401154, 0.20538970467544373, 0.12408670849136769, 0.17517702023108161, 0.22676403273738202, 0.09853245149697028, 0.11769571957448799, 0.2027643826459685, 0.2887732577660392, 0.2177750941125616, 0.10292336870465549, 0.236616904036172, 0.18442515704420306], [0.08980333925254884, 0.025043473616542838, 0.039709183132095684, 0.03622167893955785, 0.03626464498079112, 0.04463530468544172, 0.082812013194686, 0.05706632614976937, 0.0634288970350979, 0.04511906239654749, 0.030554717804695812, 0.036040640871731505, 0.006226811965461821, 1.1405992604071096, 23.638520779148227, 47.06993649082799, 42.342064457554976, 29.570454551327614, 20.6988690745446, 21.222799670311716, 33.081454384711485, 30.95931483853248, 51.15775615938249, 14.157630397427468, 0.11479695012132007, 1.538328331324362, 9.337183563939988, 11.307694085182684, 16.228114289622155, 10.267753139618906, 45.651325025866115, 57.24830273658999, 51.767359164453325, 52.69916918969924, 52.92452112320931, 52.50581595205492, 49.8460175145057, 46.02951995788082, 45.788031393481845, 49.04428112891413, 54.49336328814107, 53.03799921466459, 49.55208293853268, 51.4172758594636, 45.938658252839126, 50.61752027080905, 48.95436863745413, 51.064576333568944, 53.60072597380608, 53.301378526995265, 49.219183537267874, 50.026815245228434, 50.59504508972169, 50.079249489691954, 48.87660372641779, 46.290090853168124, 43.03876761467227, 40.615339048447154, 37.42571077039165, 37.59924819392543, 35.25014462009553, 38.555494585344874, 38.33202931188768, 38.246054880080685, 37.9038869180987, 42.68021591248051, 38.32288234464584, 35.82469732530656, 37.79935967537665, 37.57892639406266, 36.259052753448486, 37.291142094519834, 39.048140356617594, 50.33346222292993, 51.59058970789756, 48.39417180707378, 49.479381807388805, 51.284166305295884, 50.88288038007675, 50.584497836328325, 50.775223085957194, 52.210598761035556, 51.941716363353116, 53.085730537291504, 51.4189624786377, 49.604732913355676, 52.33535366673624, 52.073751188093624, 33.99852414284983, 49.900624752044685, 49.127862914916015, 52.51272324592837, 50.77426602763515, 52.86292422202326, 48.55432610357962, 48.33638744969522, 46.39185674728886, 45.802026410256666, 43.68623325901647, 44.10733499834615, 41.96570519478091, 41.50673297143752, 39.03482783225275, 38.66122599570982, 37.284117129541215, 36.63409802221483, 37.5643273322813, 38.17619746731174, 39.29339047401182, 38.787369420451505, 39.10868998496763, 38.8431219900808, 39.91104610504643, 40.48563803395918, 39.38614668384675, 38.40647589775824, 36.7998573856969, 38.83620292909684, 38.82848762696789, 41.86226444859659, 43.8448578311551, 47.86466752329181, 51.734568149812766, 53.284175011419485, 48.017082983447665, 52.50622387855284, 50.54967111156833, 52.77754206811228, 48.02450803018386, 52.58502429531467, 54.59552926401938, 51.14334144899922, 46.779861527104536, 43.01279367939119, 40.92655166502922, 39.98671647041075, 39.948979346982895, 53.27559286548246, 54.3794733478177, 58.911944666216456, 55.58470395303542, 57.72243884301955, 50.58463119691419, 55.200770593458614, 54.80588597636069, 60.46451683967345, 46.208403571959465, 17.029491778342955, 4.123568150304979, 2.560385230087465, 0.8028420036838901, 0.1667361102637745, 0.11357505520385121, 27.59040874819602, 49.25003690104331, 38.52030700252902, 29.99550415623573, 24.68092595377276, 37.44097663510231, 53.764163294146144, 52.832035556916274, 36.245661781680205, 2.5513103363975405, 0.13912476929685763, 0.039290799534008394, 0.031639006093985615, 0.044834878250596025, 0.0372400970738982, 0.03004336560655746, 0.03163037611351859, 0.055603749389129306, 0.0346069609475953, 0.03545980832930054, 0.04935314225393438, 0.04421649973899607, 0.02672160262121789, 0.04420412741901894, 0.03141313464561057, 0.05749363467217453, 0.023879380032960928, 0.016242601916254047, 0.04369493558882706, 0.03656340394950202, 0.053195490712119695, 0.1620959616716831, 0.010878110488486147, 0.07235011731785151, 0.04248239843535327, 0.0017386252922381485, 1.5877337705704475, 29.561042824099143, 51.45382058235907, 50.466418804660925, 35.54083539593604, 26.612495183944706, 30.316699204906342, 42.17810938435216, 37.03195187353319, 57.29030739876532, 15.11688034380636, 0.10522976067037353, 0.5321529868148989, 6.35044135393635, 11.99353619929283, 14.694878420522137, 11.755352231764025, 44.688159573462706, 59.81457617975051, 53.40708640313918, 54.781402541745095, 52.892918586730964, 54.033155518193404, 52.8244379258925, 49.17453127522623, 47.43598776478922, 50.379401022388095, 53.87700203926333, 54.505028417033536, 48.01746737572455, 51.086200360328924, 47.45962004507742, 51.34665750688123, 48.45995779960386, 51.348755974923414, 53.69497660667666, 53.51704220617972, 50.51026698081724, 51.92137887400966, 52.18171442708662, 51.220212059636275, 49.511706059978856, 48.909665384600245, 44.98513398631927, 43.01061676394555, 40.60941626948696, 38.214817124028365, 38.732601365735455, 40.057997703552246, 39.03372956860451, 38.94583317541307, 38.73949689249839, 44.11165745027604, 38.53545519613451, 38.211498798862586, 39.983437368946696, 39.416042989300145, 38.181174955060406, 38.7754689493487, 42.172465093674205, 51.0931468779041, 52.98599643092002, 49.81147320039811, 50.212421801782426, 53.26812859504454, 50.437946319580085, 52.72813589342179, 52.850007857045824, 53.543043598052, 53.565895326675914, 52.97632778844526, 53.61400711920954, 51.81830683062154, 55.21707196389475, 54.70809344322451, 36.48758572916831, 49.87645902941304, 52.66992792006462, 53.029162114666356, 52.09037027051372, 55.316300084514005, 51.5044544589135, 50.51870792142807, 48.81040980738979, 47.14068035925589, 45.177808653923776, 44.31100799191383, 42.14615775692848, 43.06546718843522, 40.233264892332016, 40.35854931800596, 38.42092198710288, 37.071626647826164, 40.679822814080026, 40.347488234120036, 39.74015235900879, 41.08353668643583, 39.96306850064186, 41.34873990089663, 41.016993676462484, 42.10620841672344, 40.7936696083315, 39.79787395846459, 39.175684067510794, 39.39756078104819, 40.78349105773434, 45.065315077381754, 47.07190944302467, 50.57858682447865, 54.398685116921705, 55.044668105340776, 50.486438582020426, 54.67561229582756, 53.072002241688395, 54.92178809258246, 50.3130070624813, 54.5873668116908, 56.15012930285547, 53.28231580795781, 49.37603127571845, 46.16500254600279, 41.77236372424711, 42.906324863433845, 42.25514081216628, 55.744293428236446, 56.61360440715667, 60.90152379005187, 57.50352744133242, 58.5910673295298, 54.76192797383955, 57.836320938602576, 59.47058039326822, 63.194211913693344, 49.74366326485911, 15.343736506277516, 1.8817608899647191, 2.6700289595511655, 0.3271673781977546, 0.03472219589316557, 0.13211647439147198, 32.3612738809278, 54.405423748877745, 41.99092995735907, 36.400979795763575, 30.532435447938983, 44.04927607505552, 60.97634300108879, 61.90360699930499, 43.04571413224743, 3.3289746459453338, 0.1547792550897406, 0.06794788499152468, 0.06374645580147063, 0.0509381819997103, 0.05751521536900152, 0.02161953173908255, 0.0809971432411863, 0.07695242882736268, 0.04041253228581721, 0.046860824579433094, 0.027869537495256915, 0.07139112079335798, 0.012083500041626396, 0.11862296941539935, 0.1627651394735421, 0.2421137993975032, 0.12977457425046351, 0.1380332472223428, 0.15149738038739852, 0.1688358959771933, 0.2439816443309669, 0.20327580762245964, 0.11284147239019794, 0.19867290622524678, 0.15239390244166698, 0.09098826276679194, 1.9835353642702105, 36.94920555237801, 63.41042472470192, 57.668772974321925, 42.68085133644843, 30.902075690607873, 31.37415255269697, 42.139752526437086, 41.671429372602894, 63.78110831783664, 17.190548219988425, 0.253360046734733, 1.8173263991071333, 18.080363388984434, 20.109325070534986, 26.564287293341856, 15.065173699009804, 49.21901487535047, 62.023258901411495, 55.97934930555282, 56.55908738413165, 56.207399829741455, 55.97116724137337, 54.6825352791817, 51.347198793965006, 49.94519072194254, 51.82535925219136, 58.120414287813254, 55.34896558330905, 48.4954160259616, 52.2072765134996, 48.25800280417166, 52.513374359376975, 52.0012971662706, 53.079493968717514, 56.714719187828806, 56.27661397380214, 52.26915190296789, 53.92041483233052, 54.0344028319082, 55.30934572219849, 52.01834770940965, 50.1487538891454, 46.555839277082875, 45.81432696311705, 42.7863670164539, 42.35095254836544, 39.768946478443766, 43.04646722732052, 41.80624908016574, 40.55418537509057, 41.013157598433956, 47.169980464443086, 41.33607064524005, 40.69374330582158, 43.16975908894693, 42.020712514077466, 40.62459976442399, 40.28665619511759, 44.61610563339726, 54.341598941433816, 56.79774007489605, 50.23742691163094, 50.74724089714789, 55.424820300071474, 54.204053186601215, 56.030869637766195, 54.56534662554341, 54.93663818605485, 56.066398466787035, 55.3145585521575, 55.75837865952523, 54.55852170144358, 56.32506309017059, 55.45110802496634, 39.32185119198215, 51.28879862446939, 54.02635412831461, 54.66890112046273, 52.82592842655798, 59.01707203157487, 54.384223338096376, 54.13046952216856, 50.15322539114183, 49.376835361603774, 48.994761205488636, 47.64870574397426, 44.68522956294399, 46.42429474861392, 42.850274193671446, 44.07786230887137, 41.23603843873547, 39.27080154418945, 42.55089144552908, 41.78007510400588, 42.555543376553445, 42.67369693325412, 43.034284345565304, 42.51251105339297, 44.33473833145634, 43.01073443505072, 43.45973991578625, 42.27997726009738, 41.25951382421678, 41.51031801777501, 43.08800904981552, 48.12517958302652, 48.978004840112504, 54.23527525317285, 56.62746214097547, 55.70045309682047, 49.93404726828299, 56.7874320860832, 54.42399617164366, 55.432696419377486, 51.18413017642114, 56.572148876805464, 58.39276406072802, 56.12547328395229, 52.79937005812123, 48.18252071257561, 45.89953653274044, 45.79673905526438, 43.7922941484759, 57.25551205296671, 59.51857843706685, 63.73931546365062, 59.37363509208926, 61.31395709130072, 57.532584359568936, 59.23503814205047, 60.76770820925313, 65.19618180490309, 53.941583864150516, 22.768362568270778, 11.79814430975145, 5.620487284275794, 1.5376807725237263, 0.37000008948868324, 0.16936043637894815, 38.772766436299975, 61.5927513184086, 52.812247199396936, 39.56197477156116, 37.809942230101555, 50.760153339755156, 68.35527050879695, 70.77203104572912, 52.19869828993275, 4.774707584611831, 0.24035411075718943, 0.14963869786550923, 0.24097101071909552, 0.17400623869992074, 0.17105038037463544, 0.11367351282387973, 0.20581074659862827, 0.23373816012134477, 0.2650305688861878, 0.19613412148769827, 0.24661056697368625, 0.14164556628994404, 0.18543311424793738], [0.05624167080367765, 0.037183697680912675, 0.008096713366197243, 0.022271202516651923, 0.08001757725592583, 0.06752953203695436, 0.08943495821327933, 0.024817498746298017, 0.05075835435080433, 0.040732569346625, 0.06590256046864294, 0.07427556440234184, 0.07509540105538984, 1.1370730496221975, 31.67573182813583, 49.39351327957646, 43.30339031834757, 34.41070641240766, 16.47853801327367, 18.127341616538263, 32.95687598566855, 32.8043467767777, 51.57796359831288, 10.276664764650407, 0.04206320661450586, 0.41864167778722705, 6.372629221408598, 12.42827601971165, 12.387957976710412, 10.88124909708577, 43.412004670789166, 59.927936600100615, 56.32409034236785, 55.51404245438115, 56.76964805972192, 52.2331759237474, 52.30786569656865, 47.964421241514145, 43.73058742092502, 50.01699755268712, 54.842567982212195, 54.41770861225744, 52.055637682637865, 50.25272807767315, 53.33099634416642, 52.73791828463155, 52.273819523472945, 51.845622216501546, 50.68178830608245, 51.438484114985314, 50.98188100322601, 50.828065256918634, 50.602591729933216, 50.97033746780888, 49.21106030864101, 45.95687766228953, 40.90423337874874, 37.28825915244318, 37.097580971256384, 37.01477581454862, 38.69026330209548, 37.78971456712292, 38.17446770206575, 38.60444968746555, 36.40012471906601, 37.354931600632206, 36.664194368547015, 36.97508927314512, 39.02716744330622, 37.32758091342065, 36.21666369899627, 36.02937836800852, 43.644750272074056, 50.88272348526986, 52.64548370915075, 52.12289456398257, 48.544171087203495, 50.68294932765346, 52.17497187276041, 51.81317244806598, 50.321636276860396, 50.690719542964814, 50.427112733164144, 52.012585747626524, 53.48647909779703, 52.09439462231052, 48.869998455047615, 51.96855714244228, 34.48973040426932, 47.82827577283306, 51.6936303723243, 50.069208222050825, 51.73744716951924, 53.287222693043375, 50.30438569284255, 52.64834703937654, 50.007666234047186, 48.9003772120322, 49.388135710070216, 50.12069325293265, 46.42958994834654, 45.62009511455413, 42.62910350676506, 39.81745835273497, 37.524617256656775, 38.40389497818486, 37.42399669462635, 37.82652993356028, 37.353821569873446, 40.61677855830039, 39.70893029243716, 37.14837958735805, 38.89138283268098, 39.25755177774737, 36.545781935414965, 38.949728088994185, 37.02748821627709, 38.42444427551762, 39.05857778364612, 42.17085299953338, 41.29972988559354, 46.039161143764375, 49.41927148449806, 50.978303801628854, 51.00687826833418, 54.683182470260135, 54.00994685388381, 54.01918011326944, 50.4533023988047, 52.124526269974254, 57.007920280579604, 54.64762226227791, 52.19088885091966, 55.2264307391259, 47.83530466018185, 44.82569748355497, 42.27640005850023, 50.817812181288204, 56.30868719470117, 59.060382843017585, 56.4350228155813, 58.67542966719597, 58.922519376201016, 57.20978113912768, 56.083370562522646, 62.59142991035216, 57.546308732801876, 34.814122184630364, 8.681369154684006, 3.477768287543328, 0.7393212412153521, 0.042449131067241394, 0.1728621323502833, 22.72204133772081, 55.51821193387432, 35.977740364689986, 32.56355051071414, 42.34489640881939, 36.57766688254572, 52.42293627031388, 47.2456665192881, 37.76942414622153, 4.042213780264701, 0.1115806908496926, 0.15748110930285147, 0.023715534893375252, 0.03853071007817503, 0.03127037033048128, 0.028814089431938146, 0.04430674872691593, 0.05805257625216919, 0.04037014464096677, 0.03246035577068406, 0.0728529927531077, 0.036184738179849046, 0.029466447773419564, 0.025231394984368837, 0.05249253992411879, 0.005956466719057532, 0.07013976979520052, 0.0983787895811181, 0.02173157018278876, 0.03935846424992046, 0.13326986572675167, 0.027133857515910943, 0.12250063069645437, 0.030187181377362822, 0.03998973602128606, 0.06422743644385089, 1.6829181726901763, 37.51451715346306, 57.52253524718746, 50.25110029405164, 40.26893100430889, 22.661287746121808, 22.952033435144735, 36.08376203044769, 36.6810134918459, 57.58921946248701, 11.460717512715249, 0.17349505887156533, 0.6712754118827082, 6.957996391480969, 15.637493595000237, 15.895077605401317, 10.720692757637272, 45.562008734672304, 62.58943734630462, 58.86159712268461, 57.02646524675431, 59.39254876106017, 53.97180964869838, 54.716436324581025, 50.099088838023526, 44.441399343552135, 50.93047834211781, 56.358069835170625, 54.44580062743157, 51.353443207279334, 50.66746381021316, 52.770870116449174, 53.3047596100838, 53.88907117228354, 53.41562148063414, 51.661482626392, 53.25153304684547, 52.89005525650517, 53.156972546731275, 52.85260838847007, 51.65476360628682, 50.721541527778875, 48.95801251934421, 41.75288915634155, 39.5000680031315, 37.57691814053444, 38.914230638934725, 38.42651136459843, 39.14292050946144, 39.99289420343215, 40.61087146882088, 37.91022546829716, 39.70458038391606, 38.735398015668316, 39.45209741592407, 38.86056084786692, 38.8251849912828, 38.122555132835146, 37.55415270405431, 44.07024114362655, 52.614512674270145, 51.265582115419456, 51.531973808042466, 50.70817409023162, 51.88992146522769, 53.627186282988525, 54.00635396280597, 53.059933108668176, 52.58047434591478, 53.801492491076075, 54.40389794688071, 54.47139409280593, 54.667708719930346, 51.60676556248819, 55.20179040970341, 36.49234356418733, 50.83983628980575, 51.97097724483859, 50.029917840034734, 54.615117580659934, 54.923506090717936, 50.74442855773434, 54.49687773181547, 51.977782557087565, 50.62657310116676, 51.15713250252509, 50.87045038900068, 47.764062650742076, 47.44926891019268, 45.883497961105846, 41.932910257770175, 40.10841192737703, 40.18729863628265, 38.607764090261156, 38.35625779244208, 38.391476754219305, 40.983528014152284, 41.5206769974001, 38.37692083850984, 41.594088077545166, 41.53938278075188, 39.91297591117121, 40.60516834259033, 40.755042106874534, 40.3372351584896, 41.89021133607434, 44.150398700468, 42.9170839248165, 46.918230979673325, 50.946407087387584, 53.616474290047925, 52.90809815929782, 57.352731920057735, 55.858626596389286, 54.68244506466774, 51.09288015673238, 53.49547309260215, 57.06683035819762, 55.82756142462454, 54.76951776012298, 57.48450786836686, 49.265036044582246, 46.29401714571061, 44.20369194399926, 53.124346271637954, 57.60202207872945, 60.107502706589244, 58.80511106983308, 60.85871896436138, 59.998998180512466, 59.540155395384765, 59.29137514483545, 64.94873516021237, 61.52061108619937, 39.39836486693352, 9.213536727812983, 1.5329723348540645, 0.9023581120756365, 0.05077081860133237, 0.08585896703504747, 26.508613171116, 61.03661021878643, 40.78674662497736, 35.643095508698494, 47.21314614818942, 43.22014193381033, 56.69993185227918, 54.98156109163838, 46.64394355589344, 5.133597591230947, 0.196242997903497, 0.12318792647772259, 0.020973482131657582, 0.04998487367805454, 0.11005128823941755, 0.05887765677705888, 0.031115639721974734, 0.025313638353479967, 0.021735632364007256, 0.06484433257531735, 0.13894728204656032, 0.021252081496641043, 0.042599334096115445, 0.17222750511380935, 0.15704597136186016, 0.08824570630226405, 0.16676077829493632, 0.17026322503243724, 0.12309536773471103, 0.19585531144853563, 0.23939051004427098, 0.1094803382312098, 0.1908102241014281, 0.13425946746382023, 0.16756766806206397, 0.19605228797562663, 2.9773937309941942, 45.22508105924053, 64.47996093380836, 57.897184356566406, 47.29772813858525, 27.571163638945553, 23.951019933146817, 42.813709858925115, 44.24376680004982, 65.51455274704965, 13.061710365356939, 0.3307042835700897, 1.1937454150569056, 12.444643089848181, 17.548988134630267, 20.82428882198949, 14.664955639070081, 45.768148899078376, 63.4177948582557, 61.67015929375926, 60.60192531155002, 60.75916528701783, 55.810942342204434, 55.70582674395654, 52.82847404479981, 46.96529942174112, 53.46793413162232, 59.63001297366235, 56.284952932788485, 52.430863380432136, 50.879173740263916, 54.439011004663286, 55.549720333468535, 55.96301263378513, 55.80459594726563, 53.95725373298892, 55.94647984350882, 54.99290458617672, 55.16557516590242, 54.99058646540488, 53.36446200647662, 53.38830217238396, 50.62318025096771, 43.715780473524525, 42.10230565840199, 39.936765086266306, 41.503022409254505, 40.50865450213033, 41.11990490267354, 41.03534644649875, 41.573625072356194, 39.50462579727173, 41.648008900304, 39.90376226363644, 41.901178283076135, 43.25468232554775, 40.295610966220984, 40.5142831033276, 39.08178644795572, 47.70322668936945, 55.47557969247141, 54.365894102281146, 49.70219204502721, 51.59625753279656, 53.49333147848807, 54.003078783712084, 56.50615499865625, 53.81517371823711, 52.476453088944965, 54.759041109392726, 57.03638099854993, 56.95949077606202, 56.503436796126834, 53.26954457067674, 57.31287671673683, 40.69849329610025, 51.08993445673297, 53.667139545563735, 53.79043140719014, 56.153667280750895, 58.61317773019114, 54.476716749129764, 56.38972336246122, 54.17970703494165, 52.173783394598196, 54.99800758977091, 54.9615962274613, 50.591271769615915, 50.31373270096318, 47.62534018485777, 44.05533613697175, 41.74772731719479, 41.05107515088974, 40.58939256975728, 40.831187079029704, 40.74051757012644, 44.624832907030665, 45.02738968018563, 40.42417449335898, 43.65299901654644, 43.793208060726045, 41.059119932113155, 42.9829679766009, 41.97091017999957, 43.09592439282326, 44.75091357384959, 47.11916223649056, 47.15840162769441, 48.88320115304763, 54.31581327992102, 55.44467533788374, 53.6707285142714, 59.19661852621264, 58.32476977379092, 57.53706370630572, 53.08429102743826, 54.506883698125044, 59.80955162355977, 58.40057742211127, 55.99152434256769, 59.49406362348988, 51.91350275470365, 50.436953959926484, 45.720394042230424, 56.39057451678861, 60.42244549720519, 63.248120969341656, 62.15035938447522, 63.92707147905904, 64.47239860411614, 61.998908827381754, 62.62856691114364, 66.56085675762546, 62.49382172861407, 41.33195607892929, 13.259236024272058, 10.404636994484934, 2.786123271911375, 0.1260854242249362, 0.2672440114040529, 29.740565784515876, 67.81323032994425, 48.026975201022246, 44.87948494572794, 54.95020958685107, 49.12065752090947, 64.8043684036501, 62.898229860490375, 56.567849959096606, 6.812861340661203, 0.3837120214537267, 0.3156362534050019, 0.1638412478590204, 0.13764381408691406, 0.13209304742274747, 0.19068766535530168, 0.1656245166856435, 0.12807403525878347, 0.08381594843681782, 0.1423679105937481, 0.2486976509493205, 0.1059687520647722, 0.1315300034419183], [0.028885724398517804, 0.06151776047303312, 0.06028779864972157, 0.05447477327599641, 0.03333882879345648, 0.04449446325100238, 0.019198628780882687, 0.08100688787958316, 0.014207433804028459, 0.07165843185277716, 0.03401919530944959, 0.051677280646418376, 0.04966489407384107, 2.1622881918184222, 30.1299943847041, 48.87583886423419, 44.831624184885335, 35.62387981722432, 22.814346474985925, 29.567295082153816, 44.19567461936705, 43.62125919711205, 47.1353655476724, 9.059878856905046, 0.572472378130882, 14.065910673910572, 18.219393760927264, 12.714543342590334, 13.845217535572669, 11.391014052975564, 42.51344065512381, 53.94340776628064, 54.420077723841516, 51.10335680746263, 51.19854096443423, 52.61212002846503, 55.882325556970414, 47.372170802085634, 43.075614360071, 46.06025172818092, 53.70941877365113, 53.716259387231645, 52.23506258380029, 50.04559947598366, 50.10014003322971, 51.25819629238498, 48.95793407194076, 47.296469057759936, 48.70538050128568, 50.55660193966281, 50.06114382897654, 51.82126037536129, 53.06534597950598, 47.024021225590865, 42.76767300021264, 39.962833158431515, 38.22452499020485, 36.592477752316384, 36.961961100178385, 37.601189767160726, 38.1767975899481, 37.80692200506888, 36.502514270044145, 35.84357569294591, 35.81689573103382, 37.17840533102713, 35.85572327336958, 35.68969718871578, 36.74933725787748, 36.65522390796293, 36.446714631972775, 38.32176446914673, 46.16933284267303, 51.55333111363073, 54.228085548646995, 47.15075692822857, 47.994513665476155, 51.207962497588134, 51.67200634556433, 51.737388333966656, 49.50674426171088, 51.36614384189729, 50.405488706404164, 52.03526489196285, 52.453475844475534, 51.14707554540327, 51.84299030611592, 49.35516034403155, 34.96943235397339, 45.51996484879525, 50.91602048566265, 49.93784020023961, 50.1668595498608, 52.23153637301538, 52.4754842635124, 54.92371789870724, 53.185123397457986, 52.95090298498831, 52.611057066148334, 53.01692039735856, 46.946181789521255, 44.99946632692891, 42.31863221814556, 40.59244417375134, 37.22438727655719, 38.59746002381848, 37.952210518621634, 38.58248833687075, 38.15781724068427, 38.9712619012402, 37.506990125102384, 39.87724704127158, 38.214923028023016, 38.987347541316865, 38.492936703466604, 39.00365283412319, 37.82147792077834, 37.8801408890755, 38.04240542073404, 37.36818921181464, 39.068928918530865, 43.27606708772721, 48.16365803441694, 50.22149032162082, 50.89981717448081, 53.19075199865526, 52.30453168192218, 52.34748948004938, 53.66570395808066, 49.19745752888341, 53.33065117559126, 56.77440197237077, 49.68324307472476, 54.49864672076318, 53.785877535420084, 47.780575829167525, 43.36118644283664, 46.300304705096835, 51.061665934901086, 56.445577913715, 56.71895926998508, 59.8546314239502, 56.95393277752785, 59.18423168120846, 58.57650749145016, 60.23052392467376, 58.69894819874918, 39.14308917137885, 14.344373460738892, 2.4584364554574414, 0.1559203277311979, 0.18899876323919143, 0.09214939925098613, 19.11141722433029, 55.494916977420935, 45.612799506033625, 40.51281613688315, 28.260304466370616, 31.40708085029356, 51.659493984714636, 47.40997852817659, 43.20014569067186, 4.220130039799598, 0.21826249457174735, 0.060820555344464323, 0.028311319333771547, 0.04449937770503663, 0.0700794173885257, 0.028402376544451522, 0.03849577263838822, 0.0350791085962086, 0.18820840564946975, 0.03741187696915962, 0.010318682442659573, 0.034144902676944776, 0.007268346324112387, 0.02796935300613123, 0.048332349247028755, 0.04114175222874169, 0.0928900913605767, 0.047610548865650935, 0.011483683840431755, 0.0474469431285416, 0.02500329422013414, 0.04629549382614993, 0.0597329709618803, 0.04591343811743202, 0.030302897043105577, 0.08009087654852098, 2.8743675303074623, 38.20525046317808, 56.01587049422726, 52.58689526588687, 40.206396656651656, 22.418081183587354, 25.80544202558456, 40.64914987933251, 39.90248749333043, 55.345306011938284, 9.061742963329438, 0.5496485963944466, 12.527437460037971, 10.40197664691556, 10.64475469050869, 11.143290881187687, 11.04141123833195, 45.01516757472869, 54.147202353323664, 57.31308067998579, 52.16799789859403, 53.0330099598054, 55.08176196006037, 57.84080420770953, 50.13569631884175, 45.22035852555306, 47.39770543190741, 53.54090982867826, 55.65714228537775, 53.79515394087761, 50.47271813115766, 52.35787591626568, 52.810733164510424, 51.59997201734974, 49.65794378711332, 51.52875746450117, 51.80525318268807, 53.26043290476645, 54.359551629712506, 53.41485269608037, 48.87866689312843, 45.09350907418036, 41.277709699446156, 40.901499486738636, 38.3981369387719, 39.704090087644516, 40.17975199607111, 40.523830152327015, 40.19799493974255, 39.48361758262881, 38.588387581609915, 38.0940551911631, 38.65464425856067, 38.13035672710788, 37.63818948499618, 37.25064754486084, 38.082233167463734, 39.57524414985411, 38.6214727740134, 48.241466091525176, 53.704045126515055, 52.70818671872539, 47.94830814484627, 46.9774313126841, 52.04113668011081, 52.331333237309615, 53.39157735147784, 52.249732248244754, 51.606851854631984, 52.163016488475186, 53.522968907510084, 53.168100310910134, 52.721895402477635, 53.32162972419493, 52.55325309691891, 36.77393836359824, 46.48770378481957, 53.35980615308208, 50.368402696424916, 52.548624700115575, 54.603742707160215, 54.61041465882332, 55.58409990802888, 55.677903390699825, 54.39477843623008, 55.18054293047998, 54.0534302496141, 47.954238768546816, 49.10892571172407, 44.8305808344195, 42.893239836538996, 39.569937183010964, 38.71073807439497, 39.8755015865449, 40.14767877517208, 40.08234385521182, 39.95651422008392, 40.182615326296904, 40.206063255187004, 40.30409113053353, 41.02869802905668, 40.7287073135376, 42.37265110015869, 41.056923404816665, 40.231680254782404, 39.31805433765535, 40.14800433189639, 41.76649585846932, 46.30268166142125, 50.731559261198974, 51.200972833941066, 53.379308177578835, 55.066594154604026, 53.339350992633456, 54.94642842200495, 54.33328743903868, 50.5468705392653, 55.202108121687374, 57.55622840696766, 51.88380256775887, 55.64908965941399, 55.13682027016917, 50.72218871885731, 45.72309263290898, 47.7252233412958, 52.32809335954728, 59.88564168253253, 57.55972323879119, 62.554928333528586, 58.31792523784023, 62.31479298683905, 61.017414139163115, 62.792082678887155, 59.81602745671427, 43.84847033408381, 17.48172929210048, 4.51431417657483, 0.6076915850562434, 0.07732727564871311, 0.023545402087151043, 20.14454991586747, 61.4351700967358, 47.353935703154534, 42.70052202286259, 33.17561088069793, 37.474963972645426, 58.46566523275068, 54.78357161245039, 50.7144538048775, 5.951131812987789, 0.23338001401674366, 0.009757419616254348, 0.034470160626956535, 0.08718459791834317, 0.09754901676769219, 0.04365190443012022, 0.02954305656584761, 0.08227689311869683, 0.0794411727016972, 0.03366336662081942, 0.034287751261745734, 0.03456725461047984, 0.024481366178201094, 0.11973214215568959, 0.1224797701222762, 0.12613485987869003, 0.3514075952191507, 0.1462285800446426, 0.15277285549429157, 0.0744511287719492, 0.17463354213583857, 0.1508532536606635, 0.1941432734771121, 0.16758099799194645, 0.12444100883458892, 0.1867557803709661, 4.279945204334875, 45.096854855937345, 64.02511896625643, 61.476205933478575, 47.021099059812485, 32.85172900845928, 42.00671357493247, 56.37180597551408, 53.467341853726296, 59.03778606845487, 10.509821234210845, 1.1305714759134478, 16.84467165700851, 23.589063613645493, 27.19616936099145, 23.11290748657719, 13.062548771981271, 47.35778354829358, 56.440647494408395, 57.48133859326763, 52.64502871421076, 55.06179317351311, 55.075297894016394, 60.313097661541356, 52.062592044953384, 47.093533469784646, 49.855678312240116, 57.33086470634707, 56.69527207651446, 54.810208428290586, 50.25632096875099, 54.3696125092045, 53.75647152623823, 52.70309548224173, 51.75501938789122, 53.3076503969008, 52.89449930191041, 54.53912558094148, 56.77841455705705, 58.28958219097507, 51.677289778186434, 45.298523518346975, 43.8299528245003, 42.81819705040225, 41.65473576514952, 40.18690247689524, 42.39042728177963, 44.039164204751295, 41.22110989785964, 41.866108371365456, 39.99042311022359, 39.43316805747248, 40.92411979552239, 38.355696893507435, 38.703791556819795, 38.747757404081284, 40.82438176678073, 41.20018797536051, 41.774242539559644, 50.729955011798495, 56.315316000292384, 54.00434963164791, 51.07467251439249, 48.43635689827704, 54.26444984251454, 54.25158054597917, 54.56980243805916, 53.32411650688418, 53.871557789464156, 52.218498414562596, 55.30321897998933, 56.48655883727535, 54.86727106955744, 55.029374784038914, 54.14164827715967, 41.479609781695956, 47.17320073035456, 55.0876808166504, 50.98929428285169, 56.0244369506836, 57.70547459202429, 57.2248665748104, 58.29207681840467, 57.36216914269232, 56.7905346808895, 56.28685528232206, 56.09566327064268, 50.51267139373287, 50.78391898062922, 46.76598025906471, 43.36746615748252, 40.98572846381895, 41.66790316181798, 41.92459875537504, 41.497848802997225, 43.57114307342037, 41.095217504808986, 41.251288613965436, 43.612786877539854, 43.08130571919103, 43.392604627916896, 43.69086950056015, 44.44236032424435, 43.61741919671336, 42.02721188145299, 42.23615654053227, 41.49185149900375, 44.28259826475575, 47.06382543809953, 52.763770626437285, 54.04589145414291, 55.860611315696474, 57.84579346256872, 55.94175730982135, 56.06203679115542, 55.761002725170506, 51.35200761979627, 55.157589220231586, 59.2581565918461, 55.463436034417924, 57.96826162645894, 57.77624591704338, 54.43425709201444, 47.73034987911102, 52.14580120578889, 54.26253572587044, 62.19872613107005, 58.9938594448951, 64.67125884948238, 60.39597342091223, 64.61460805708363, 63.69558495859947, 64.78750613427931, 63.367486538425574, 46.53629018414406, 22.22712451411832, 6.442359647443218, 2.129666329391541, 0.33509059658935, 0.18385786893627337, 23.268762865374168, 67.27347297053184, 57.49177209792599, 54.06466784015779, 39.11911172251548, 43.02265451800439, 67.21046401608375, 61.84124523593534, 61.63386952492499, 8.783137990582375, 0.3352737835338039, 0.13539614276059214, 0.09899831722460448, 0.17288526820559658, 0.20314667584194293, 0.13342297605929837, 0.1584710327968482, 0.15581120616726338, 0.2581200574434573, 0.17712035546860389, 0.17178384827510004, 0.15772046581391366, 0.10580932150685018], [0.024717281039263454, 0.057985474610881466, 0.060396073686499754, 0.05190712234546101, 0.020947444718331102, 0.08389626509479939, 0.15338607823416112, 0.07544618505503863, 0.06831346214899132, 0.025369647041624113, 0.061448728290176204, 0.051895627196157174, 0.11833432280728895, 4.080023712688877, 32.064391643770286, 46.75227549768264, 44.240264123485936, 37.80290157564225, 30.635913456639937, 22.183866654672933, 29.32630858113689, 43.98225061355099, 45.70558709482993, 7.28242592465493, 0.6822267919778825, 14.063074800275988, 49.30274963378907, 11.564219055637238, 15.13869558611224, 9.241141388493201, 30.88501730272847, 33.9224733075788, 52.152375098197695, 52.742378019517474, 53.99213144856115, 54.779974799002375, 55.94551494044643, 48.180441856384284, 43.70801418058334, 46.56600213819935, 52.57683830876505, 51.976107705023985, 53.59515620816139, 48.53741284339659, 50.070871307003884, 50.73647399102488, 49.094389407865464, 45.32483477746287, 43.35522444017472, 41.873760915571644, 44.250980038796705, 46.19924875997728, 43.22327198520784, 40.32017284824003, 37.157946248208326, 36.67798542207287, 36.886243666371996, 35.56802918834072, 37.839909138218054, 37.77311509655368, 37.33798696148781, 38.601045070155976, 38.5878933629682, 37.27487602541524, 37.60189971616192, 36.91970540631202, 36.47282192783971, 36.28448147927561, 34.75434526320427, 37.853441315312544, 35.88456446124662, 38.176719142544655, 47.35198236280873, 51.42202192737211, 41.65266083132836, 45.43024063110352, 49.121751862187544, 47.35157051394063, 49.9310270432503, 50.62532970982213, 50.09514685600035, 52.69558414336174, 51.44099835426577, 52.34358672172793, 51.17464980771465, 52.21043402148832, 53.8273173762906, 51.951126129396506, 33.63250424784999, 45.25032543366956, 50.98479924663421, 50.3629231452942, 51.80979920971779, 49.71602624462497, 52.57250016735446, 48.736892823250066, 53.28910935309626, 49.90874405830137, 50.92664618645945, 50.50832540758195, 48.81914884813371, 47.87204157921576, 42.632202179201194, 40.93538876502745, 38.589815324352635, 38.585732137003255, 37.63884059844479, 36.692364831124586, 38.082531267596835, 38.460632062727406, 39.68254058591781, 38.67757835695821, 41.090122345955145, 40.463602158331106, 39.17269914380966, 38.32646739098334, 39.437698395021506, 38.40038053451046, 37.32980097493818, 38.61398496935445, 36.86068550232918, 41.0932170960211, 42.21198297316029, 45.66056612999209, 45.672756856487645, 47.891665197187855, 49.84908480798045, 54.49932529080299, 52.476080463778594, 49.51005866450649, 46.843454914708296, 50.59332709158621, 53.99251584083804, 49.92943063859017, 54.21316093014133, 52.15245746797132, 50.47159633328838, 42.98565480016893, 46.15473378089167, 53.916508151638894, 55.58776340176983, 60.10377253255537, 57.339270345626346, 58.13805710884833, 60.367583305605, 62.68932442511282, 58.3942114153216, 47.965684244709635, 14.438074961785349, 2.9956327522954638, 0.6699286905988571, 0.07388815373903321, 0.030266728116980487, 10.967787369605034, 59.16013656123992, 40.60182256083335, 38.28401950097854, 36.93783067887829, 28.397810997501498, 44.913331077944854, 51.471945854925345, 39.251852573887, 3.8205589257901718, 0.1183758907380604, 0.014404582700902417, 0.054416516119794506, 0.051256752002143094, 0.05229052253848603, 0.040212135176144304, 0.03938179162721481, 0.04952591040261811, 0.07367416239914394, 0.040597519536893216, 0.05239029016886508, 0.04488640149394351, 0.03188369649222061, 0.0820533333406333, 0.023152985039257237, 0.024573760212308938, 0.05136137279952246, 0.007072658261149041, 0.09176706008973623, 0.10345377733991032, 0.02096530988872532, 0.011068792645669272, 0.04645583219826222, 0.040811411285352324, 0.05725328990769002, 0.07876219663528666, 4.919511195152037, 37.82236045406711, 53.538544639464355, 51.49962209886121, 44.003058787315126, 32.288968909171324, 28.948790257976903, 40.477761914653165, 49.148565184685495, 51.067855435033, 8.338700109912503, 0.6946846073673618, 16.803035697629376, 49.9201032423204, 10.034050480011972, 10.542403382639732, 11.440833057126692, 32.447309109472464, 37.38983677279565, 52.200494735471665, 50.800326255060014, 53.14553883767898, 57.78215300652289, 56.643284982250584, 50.457220846606845, 44.588731411964666, 47.66860785022859, 54.288788149433756, 52.94019099204771, 54.57513686149351, 49.579684657435266, 51.974417163479714, 52.90189689205539, 50.675171267601755, 48.142626285552986, 46.34961674290319, 44.409647757007235, 47.3588425882401, 48.064508361201135, 46.338296782585886, 41.552173629883804, 37.186967865113296, 38.503844814915816, 38.15306725040559, 36.570940017700195, 41.416181133639434, 40.28599331455846, 39.581237531477406, 40.86702969766433, 40.51379672942623, 38.72644324456492, 38.861015842806914, 38.43358339801912, 37.445805072784424, 37.708070431986165, 37.5412755627786, 39.42212658543741, 37.944667800780266, 40.309319649973226, 49.28638550543016, 51.75437611918296, 44.5044671335528, 46.06700997198782, 50.97399703917965, 48.64090458039315, 51.03199712691769, 50.82377810632029, 51.42268088556106, 54.51993734605851, 54.100867394478094, 52.42626244022001, 51.3880189003483, 52.392985051678075, 55.89849748919087, 53.59015518619169, 36.68261774124638, 46.13590248169438, 51.54891060244653, 51.945219039917, 51.38378666293237, 50.30059276088592, 53.747418695880526, 50.7524811836981, 53.951005397304414, 51.363017712869954, 53.15343849120602, 51.664812718668294, 51.40110784961332, 49.466959661053075, 45.06994739655526, 43.70276997166295, 40.228040295262495, 38.75642976453228, 40.047340623794064, 38.94149503400249, 38.91700375464655, 39.30436134338379, 41.04805884822723, 40.92545732375115, 43.216968736340924, 42.82087210685977, 41.79372887457571, 41.43995069688366, 41.60460395197715, 39.93599237934236, 38.608336756306315, 40.35596447606241, 39.25001690464635, 43.93421726842081, 45.7266737568763, 49.25044090517106, 47.320038580125384, 49.889806855109434, 51.108161710923724, 56.868680061832556, 55.53394848300565, 49.76088639228575, 47.87927050744334, 51.46396775399485, 53.313965412878225, 51.268614107562655, 57.30521240542012, 55.057878648081136, 52.40803910839943, 45.78674093369515, 46.263348133333274, 56.51398404952019, 57.73153874181933, 60.590126822071696, 59.88402174365137, 60.113955005522705, 63.43353140738703, 63.28735643817533, 59.116613941807906, 50.491482750062026, 16.03210560737118, 2.942404963316456, 0.43875632747527094, 0.04907537792478839, 0.07122959881540268, 12.594691399605045, 65.21415018266248, 44.83666443055676, 47.013913277656805, 44.87238545571604, 33.69753322293682, 53.62775502666351, 57.17867282129104, 50.040402335505334, 4.931739674460504, 0.08167917599841472, 0.021867830411440903, 0.013743652793158208, 0.05728278429277482, 0.04729790455331245, 0.06541771874312433, 0.03467671325310104, 0.050015302690406965, 0.08556834392009244, 0.018846684158028617, 0.03620344604695997, 0.026314080234677083, 0.02658756404754616, 0.15071097581136614, 0.08881605110101162, 0.13912856909296206, 0.2170675046621792, 0.14412101087791307, 0.1525274009233521, 0.1842098250504463, 0.1620936480861518, 0.18542356879240085, 0.21216849496047344, 0.20960540991396676, 0.1728156001697625, 0.24199989744492117, 6.127409502383202, 48.14846669473956, 63.07976891917568, 59.272947849765906, 50.27518364690965, 41.65426900309902, 31.05841744330622, 40.24705594585788, 54.461329290943766, 59.03726047085178, 9.65380120661951, 0.9183728430540332, 18.23154330253601, 55.215071555106874, 18.249301833491174, 20.0809722177444, 10.972756032020817, 35.93491200477847, 41.57806519539126, 56.667293810075336, 51.84354336031022, 54.328031463007775, 58.9514821575534, 58.3059423969638, 51.951428151899776, 48.60269677254462, 51.08389008429743, 56.31773218031853, 53.85703325271607, 53.998407240836855, 50.51432271157542, 51.58655358899025, 54.75650333589124, 54.92605563132994, 49.723415990029615, 49.13335031078708, 45.13502736245432, 49.72250992251981, 51.42643459381596, 48.43994586698471, 44.016645877592026, 40.211154491670676, 41.05732348657424, 40.56081418068179, 38.15909201099027, 42.89888804958713, 41.03964144183744, 41.88159388880576, 41.69609323624642, 44.021015397963986, 41.50550134720341, 41.15937179134738, 40.0066578003668, 40.704176810479936, 39.228455635809134, 39.62764701535625, 41.09034199868479, 39.80135702317761, 42.082399629777484, 51.66421651840211, 54.92347863412673, 46.75614687704271, 47.789420773906095, 51.828257883748705, 52.07215870580366, 53.39755504362045, 53.09459509388093, 53.4907623260252, 55.75864538069695, 56.965150756220666, 54.655125756417554, 55.010457192697835, 54.956473612016254, 58.826389928017896, 53.00059157033121, 42.370199618800996, 46.605825962558875, 53.82346560878139, 55.445302917111306, 52.213791570355816, 51.730186862330285, 55.1262612496653, 54.384046831438624, 56.14777980312225, 52.864857950518214, 54.826917725224654, 54.126307887415734, 53.1994322038466, 52.940720512020974, 49.193597916633856, 46.208207453450854, 43.18143990732009, 42.5905034618993, 41.933071074947236, 40.82662928488947, 41.03904916394142, 41.31146953951928, 43.659066923203014, 42.952040087792184, 45.24725029545446, 45.43519066226098, 43.3040649660172, 42.53005581517374, 44.29414180017287, 43.9661963524357, 41.93212578373571, 44.2611821236149, 40.99010975130143, 47.058981310936716, 46.61671446215722, 50.22808382588048, 49.6850787439654, 51.76501358709028, 53.15477209706461, 61.09574779387444, 58.117084195536954, 50.768147130166334, 50.18047017435874, 52.67132036147579, 52.469051576429806, 53.05220211705854, 59.34542932818013, 57.95776144150765, 55.523730708706765, 48.255672916289306, 49.11129874567832, 60.06033228289697, 59.927367856425626, 64.05908669194868, 62.274051327859205, 63.32524261166973, 63.60281305928385, 66.01755357557728, 59.725228509595325, 52.7152273731847, 17.283092621834047, 6.639441588232595, 2.8914359692604314, 0.23354122955952925, 0.19255074522187635, 13.712271740359645, 69.95515823364258, 53.87684906682661, 47.03545493464316, 48.20031650604741, 42.41331038936492, 60.279455492573405, 66.33955663250339, 58.98612060854512, 8.215829903079618, 0.17190614655133218, 0.19315483619368848, 0.13499313454714515, 0.12468424941142722, 0.16626787732445425, 0.1320433896034956, 0.22736296027658448, 0.16678564550895847, 0.1649510794349255, 0.13753930437228373, 0.14524208862454663, 0.22281039085599685, 0.10295015879936757], [0.07648391243551048, 0.06173102785983394, 0.11401423808908272, 0.08723322151889724, 0.021915710906708435, 0.12452902467620951, 0.029594455319907398, 0.0944106609770848, 0.050217841015828234, 0.10348710982549576, 0.02803108245584994, 0.065479013437946, 0.07602868000826529, 3.002415510915941, 34.03979532180294, 49.448987360923525, 44.88732184133222, 36.68736773152506, 23.650266316629228, 20.39121012533865, 36.94974683946179, 40.82648415719309, 47.30687118345692, 4.05297480283245, 0.24615419307543387, 0.023595665115863088, 5.822028959951093, 6.6732627153396615, 5.533069910541658, 12.950452335419195, 22.696430221680675, 16.49480800474844, 38.433924644224106, 55.71705256738971, 53.68493141666536, 53.328795894499756, 55.07689037630635, 47.15770344580374, 46.45515203475953, 48.998985598164225, 49.241180189194225, 50.51028267029793, 51.863006161105254, 48.59500892700688, 47.546461320692494, 51.64016454450546, 49.98123730382612, 46.2911145917831, 41.04653696860037, 38.08826969515893, 37.05691775967998, 37.03622725702102, 37.62608897301459, 36.23490272029754, 36.55939648228307, 37.826788809991655, 35.71712632333079, 35.99950559677617, 37.05078709510065, 36.043812690242646, 36.82026940007364, 37.99987516095562, 38.2269686268222, 35.82052784581339, 37.42256502951346, 37.66417518738778, 36.6816096921121, 35.41590790594778, 37.006625129330544, 37.341379811686856, 38.0808642602736, 35.2477833532518, 45.80619196737967, 49.376498037768954, 45.99667795242802, 51.37229804069766, 50.277690041449766, 49.39097942844514, 49.63853982187087, 51.145098670836425, 50.62684766707882, 53.720271971917924, 50.29271271920974, 51.099658012390144, 50.813783907121234, 51.30332316121748, 50.72825270314371, 52.40907069175474, 36.58525274645898, 45.10465645021008, 51.52786316410188, 49.896043423683416, 48.63338147440265, 48.99091728271977, 49.53289862601988, 44.9116523035111, 48.38328722984561, 49.25637545124177, 51.10918152716852, 53.43599427130915, 49.79048067523588, 44.81687607303743, 41.74918251652872, 39.32710716801305, 37.1976916251644, 38.14948220406809, 39.38512294523178, 38.34554579950149, 38.323533458094445, 37.39028000062512, 38.461773472447554, 37.431198166262725, 38.174044086087136, 39.91602751516527, 38.78147409808251, 38.153079017516106, 36.68137042753158, 39.88772369200184, 38.86435377982355, 38.64596405336934, 39.081425589899865, 38.4321556552764, 39.50530044494137, 41.57017730897473, 41.6779601189398, 41.33738856161795, 46.577447614362164, 51.50030066890102, 53.56968433626237, 53.272588329930464, 52.942050195509395, 47.7986579556619, 46.34212109350389, 51.12889143728441, 54.01118240048809, 54.86300353080996, 51.00393649070494, 49.175292215039654, 44.81127100606119, 51.03636272491948, 53.015453430914114, 58.705412264793154, 54.609767467744895, 55.85876780171549, 54.53192410930511, 59.33506642618487, 56.276821859421275, 49.67526497379426, 29.403802848631337, 4.640018786153486, 0.579576219522184, 0.050785696028821894, 0.10864190096336027, 5.771240640071131, 49.87573339093117, 49.03584411067348, 30.17967708649174, 33.37616166760845, 30.777410999421154, 37.820316899207334, 51.11915219214655, 42.406654127182506, 9.117498474736369, 0.12138405754681557, 0.018894982171214877, 0.07927877738350823, 0.007872855771453151, 0.015701849178801623, 0.007420852404808807, 0.03510042882314132, 0.038840707556735125, 0.03842467201813575, 0.046461623822969776, 0.10608051663204547, 0.039771067714619066, 0.025913274524012403, 0.0548935667311232, 0.047908863503365755, 0.058103547912211194, 0.0228792216042958, 0.021041711837413813, 0.07715127460898892, 0.08331027678063802, 0.09683451720423276, 0.08885811698893387, 0.10673061118371065, 0.021549425117911834, 0.07408991065477172, 0.010189839860334272, 3.93505560774957, 42.595779049781065, 57.00220930960871, 51.654238008683734, 42.6737989148786, 26.794183292696555, 21.1120613544218, 34.422771623057706, 43.125342169115626, 53.89498218413323, 5.014990020182825, 0.3515027739828633, 0.33512862519391123, 8.80611131268163, 7.2863095614217945, 8.641202122934404, 12.823068461110516, 24.20724484228319, 17.162313038303008, 42.59501810996763, 54.87217010990266, 54.965083214544485, 56.3284480956293, 56.813143222562736, 50.446061703466604, 49.90175439465431, 51.01150666513751, 51.69206534662555, 51.876926652846805, 52.46457222969302, 49.40377812231741, 47.25122844019244, 53.46597686890633, 52.91287168379753, 47.834986948197894, 42.801730940418864, 39.74794218617101, 39.067218765135735, 38.79925027970345, 38.98171109537925, 37.38551039849558, 36.842442558657744, 38.70739621500815, 37.431661005943056, 37.01185757114042, 39.777560003342174, 38.41677996420091, 38.28686714172363, 38.03910278504895, 39.242748752717056, 38.61169822754399, 38.90207913614089, 38.657774309958185, 37.6384287495767, 37.53748263082197, 37.85855216364707, 39.68426250642346, 39.53935054040725, 38.0397617432379, 47.193581365769916, 52.50926371543638, 47.13159222756663, 52.123957526299264, 52.210261437200735, 52.105036012588016, 50.154766882619555, 52.472173783086966, 51.9893810056871, 53.80901167469641, 52.317157791506865, 52.4462979070602, 52.32872486114503, 53.56732699178881, 53.45384105559319, 55.33633162898403, 39.43073226559547, 46.939372554902114, 52.69715701380084, 51.5201243277519, 51.538426106975926, 50.428556165387555, 51.20396168001237, 46.50955138667938, 48.964900201366795, 49.23637528573313, 52.031573941630704, 54.184551162104455, 51.87269833780105, 48.000891439376346, 45.653839265146566, 40.64035984777635, 39.0385187825849, 39.0493719808517, 40.43968354502032, 39.405950730846776, 39.88752757349322, 40.3172859837932, 40.34366392320202, 39.565493137605735, 41.17547704327492, 43.16325187683106, 41.04459931773525, 40.25701092135522, 39.0386599879111, 41.57045579725697, 40.529588191739975, 40.83598806012062, 41.187232386681345, 42.4085957004178, 41.545505600590865, 43.21388967575566, 44.635799854032456, 44.46334108229607, 49.49449077729256, 54.412503627038774, 56.25060865955969, 55.24705456149194, 53.77895062969577, 48.873210876218735, 49.33220663378316, 51.253375699443204, 53.31414976427632, 57.07515755007344, 52.94308177886471, 51.66928814303491, 46.733138253611905, 52.381053201613895, 56.369264279642415, 60.456166113576586, 56.838732765566924, 57.44901826304775, 56.470618324895064, 61.74456273355792, 56.056631765057965, 50.643827607554776, 27.2388231754303, 4.805116249668983, 1.617507011659684, 0.0049279673464385975, 0.0332212649405964, 6.1740052988452305, 53.099976585757354, 52.262707448774776, 31.736728606685517, 39.80855065007364, 35.27437310064993, 42.799177477436686, 57.668419961006414, 50.000480451891505, 11.554835765592514, 0.10571411976049985, 0.0850695057681972, 0.0660489522100937, 0.07240657033699174, 0.00204774895175961, 0.05496253762694617, 0.01651025771523916, 0.11277355103483123, 0.04437193514839296, 0.019916774922861688, 0.05951105061197474, 0.04976650797611764, 0.06006166864667208, 0.1543539077524216, 0.1287489663809538, 0.17828571309726085, 0.1918079310487355, 0.176477684308925, 0.18706197039254252, 0.19550810507949323, 0.24136079625496942, 0.16506265248021773, 0.19463309477413857, 0.09712131754044565, 0.17260975234450834, 0.17771937493835727, 5.598887772329393, 50.868783381677446, 63.61646682985368, 59.97141607346074, 45.56122818300801, 32.12673379528907, 28.44070996007612, 48.08771702551073, 51.47583684613628, 61.90673312833233, 6.05196173152616, 0.514177254611446, 0.6177049670969287, 8.161816904621741, 12.232472281302176, 10.03867103207496, 15.219405216555442, 25.90563112689603, 18.813554394629694, 43.91448774645406, 59.1925000375317, 58.48340611304007, 58.081210197940955, 58.32694276686638, 51.491287062245036, 52.318585534249586, 52.87225161829303, 52.99975218311433, 54.520196222489886, 54.95553616554507, 51.028396391099506, 48.020456221795854, 55.494595343066806, 55.98174587372811, 50.22558527608072, 46.09309765600389, 40.21961504413236, 40.94643415943269, 40.67759098545198, 41.766844949414654, 40.298050680468165, 39.92901448280581, 41.38538660541658, 38.82807970046997, 38.39914106553601, 41.00509320535968, 37.97288140942974, 41.196712755387836, 42.770959946417044, 41.466760097011445, 39.23337036563505, 40.94270790776899, 41.62208595583516, 40.094828759470296, 38.80178020846459, 39.35732903019075, 41.132338816119784, 40.85806315945041, 39.94928921422651, 49.42731626572148, 55.7364643773725, 50.806335326164, 53.86186953513853, 55.905608746313284, 53.04300023663429, 51.927082000240205, 51.189511668297556, 53.442434803132095, 56.326204499890736, 53.26860320183539, 53.79686801664291, 53.50847574972338, 54.94988403012676, 55.077008047411525, 56.647611356550655, 43.035970964739406, 47.88573065111714, 52.60728374604256, 53.12875893808181, 52.487455337278305, 51.80915594100953, 51.21966292781215, 46.84316465931554, 50.78868466038858, 49.64231706434681, 53.69814588177589, 57.59149835955713, 55.597408510023556, 49.76600116299045, 46.488056798135084, 43.87981007176061, 41.116861143419825, 42.882743573957875, 43.748544031573886, 42.01637045029671, 42.25683919845089, 42.97047914997224, 44.62442890290291, 40.36293845022879, 43.17343434979839, 45.60591182401104, 42.71974555907711, 41.444508491023896, 40.30357337767079, 44.86853368820683, 42.585690713697865, 43.078587516661614, 43.45087535919682, 43.98214470955634, 44.19693762256254, 45.89262531649682, 45.90678115044871, 46.72548963177589, 50.80902999447238, 55.3072472541563, 59.44500261737455, 57.49618868674002, 54.45002109773698, 51.20715841170281, 49.76295348136656, 52.594206563888065, 58.21541409338675, 60.520649879209465, 55.16045647282755, 55.59880879617507, 50.50586215911373, 55.018443138368674, 57.41109286585162, 63.00968400893673, 60.07293485826062, 60.940539606155895, 57.055110316122736, 62.561686577335486, 56.27129523984848, 55.89457511901856, 31.605572392863614, 8.37339053230901, 2.1625985493583064, 0.2034060578913458, 0.14545804881040128, 7.584905874344611, 60.848277614962676, 60.04219524322018, 38.248588731212, 41.435965568788596, 44.108531321248705, 50.87069749832154, 67.24096436654368, 61.943446513145204, 15.89650240636641, 0.2584821718835062, 0.14693197133319993, 0.20812943427553102, 0.17344521719121164, 0.13338353785295642, 0.14456623053598788, 0.20101005662112467, 0.2524069873916526, 0.25896342831753916, 0.16243867876548923, 0.14272818642277874, 0.15450881073071113, 0.1499629215968232], [0.09985831220664325, 0.08416105572494768, 0.031096906957006266, 0.06472565789496706, 0.060754690935174306, 0.08516018759579429, 0.024087807659300107, 0.014383659882080412, 0.05235722581405313, 0.052315332295913855, 0.08131413510249508, 0.07051480813853203, 0.06585318610192308, 1.3830291936474464, 28.285454703915505, 47.92533482274702, 43.55717551323676, 37.02882182213568, 30.062888514611032, 29.366548176734682, 46.22970204199515, 44.253317771419404, 40.292029842253655, 3.625116535732823, 0.08903474622075597, 1.8010415761701524, 6.127247704613594, 5.249608062928723, 8.128148749951395, 10.730433963960218, 35.80336355393933, 42.95218521548856, 48.337544548896055, 53.65346224077287, 54.61858103352209, 53.78270826032085, 50.800357634021395, 50.61137391674904, 52.01483326573526, 51.62364744370984, 50.44293949680944, 52.416232939689394, 52.71248955880442, 50.91824446955035, 46.414080896685206, 50.240058822016564, 50.20570670404742, 48.28356489058464, 44.59118681569254, 37.20821142196655, 37.623080515092425, 35.35529944204515, 37.91615216962753, 40.337380286185976, 37.09723188031105, 37.57332132708642, 36.61038337215301, 37.4355088510821, 36.40851859123477, 36.87844599446943, 36.65765577746976, 37.02134970695742, 37.78163448456795, 37.641590179935584, 36.405655261008974, 38.631678781201764, 37.70513649909727, 35.61510939751902, 37.197491584285615, 37.22208092289586, 35.93362154499177, 35.13692540507163, 37.44078443896386, 45.838645658185406, 47.29972462500296, 47.78436091638381, 49.561657444123306, 49.42890874801144, 45.147986873503655, 48.35488534742787, 49.327593926460516, 51.619509343178045, 53.385434919788, 52.23169326782227, 53.09676024221605, 54.748187911125925, 52.74022463829287, 52.94868292347078, 38.5412799158404, 47.13562834647394, 53.90118345137566, 47.40934702657884, 49.3088371522965, 48.39581920254616, 52.13427728222263, 51.42064517544162, 54.13002237196892, 54.10924949953633, 52.37164735794068, 50.96585027633175, 47.54940702069191, 44.30962731761318, 40.085218952548125, 38.335422162086736, 37.035109381521906, 38.14067256066107, 36.633839145783455, 37.98468774364841, 38.191875180890484, 38.21346782868908, 37.968892358964496, 37.81368024887578, 38.87387337223176, 37.61669097408172, 39.44804952990624, 39.54023699606619, 40.83531341245098, 40.61568813939249, 39.43345831286523, 37.731706634644546, 38.33010342813308, 38.24229724945561, 38.049567668668686, 37.509535743344216, 39.89843176257226, 41.76412282451507, 43.68289139962966, 47.349224936577585, 53.24993664218534, 54.44542407989503, 52.955621596305605, 55.55996556435862, 49.83914159959363, 48.42677847031624, 53.86083402941304, 56.07836954055294, 54.324854343168205, 50.570553810365745, 44.77691496572187, 45.26352028692923, 51.88883104631978, 56.53932256083335, 57.143093001457956, 55.81252305738388, 58.72433770087458, 55.14893254926128, 61.954621345766135, 60.91934704011487, 28.29505274372716, 7.515905499458314, 0.29234126630810003, 0.0672358445703022, 0.05910728014104309, 3.2475570276860273, 48.24811058659708, 50.558504289196385, 45.483188706059615, 34.28132703227382, 52.18871978021438, 50.53908071210308, 47.99996576001568, 49.63005965755832, 11.546279115061607, 0.10985716922028411, 0.030717383168878096, 0.06273021335683523, 0.0516501879469762, 0.046603016840714606, 0.04541306395924861, 0.054346974488467946, 0.009151062939406164, 0.07406305161214645, 0.01472054513156294, 0.09721506371973984, 0.05256023911398746, 0.026270847977890123, 0.04636679745970234, 0.038579804822802544, 0.004995786237545432, 0.06884511184668349, 0.07354201223220556, 0.027633494314467235, 0.05410908503578075, 0.041301914400631384, 0.050697082638620376, 0.08245921438379634, 0.029679477672963857, 0.037757620110266635, 0.018875944886296507, 1.8804071819589985, 35.99723062207622, 55.749416043681485, 51.28821419131372, 41.042500849693056, 33.074590236909934, 29.665919157766528, 40.623489733665224, 46.19726796304026, 48.52066824513097, 3.619449446278234, 0.09830870019692568, 0.642641190319292, 5.835432679422441, 9.366561135938092, 8.639392929692423, 9.58895658293078, 38.89582295571604, 43.18015336990357, 47.91678405577137, 55.919799881596724, 56.97953016527238, 55.650607616670676, 51.43434209208335, 51.65066080708658, 51.98599207785822, 53.28188826960903, 50.57158147135089, 53.15669013607887, 52.60286715722854, 50.423366869649584, 47.294476493712395, 50.444437842215265, 51.93444821142381, 50.3796402869686, 46.17735016730524, 38.99545115809287, 39.19590388574908, 38.09837764309299, 40.93552212561331, 42.034178010879025, 37.80929503902313, 38.59877794019638, 37.716166204021825, 38.54379023275068, 39.06262566966396, 38.743419262670706, 37.12508463090466, 39.58857628606981, 39.17447597749772, 39.53629501404301, 38.88092971617176, 39.161261512387185, 38.588116938068026, 36.21871509859639, 38.639770630867254, 39.25877555724114, 37.56945779246669, 36.473151406934186, 40.70179200941517, 47.88071001729658, 49.960566413018014, 49.450705359059, 50.0510907942249, 50.585407826208304, 48.21255037861486, 49.36983785321636, 52.10818567583638, 54.22698336262857, 55.238072333797334, 54.70266096053585, 53.30042146867322, 55.23763695070821, 54.7770957792959, 53.34794882805117, 40.87881249766196, 46.99618024210776, 54.00101169463127, 52.062646958135794, 49.905386509433875, 50.054930794623594, 52.552649051912375, 54.359386890165275, 55.558047525344364, 56.31899518351401, 54.219742667290475, 53.70530028497019, 50.37695346340057, 45.37226799995669, 42.457127186559866, 40.6764260415108, 39.19981448881088, 40.32195752666843, 37.77930067431542, 39.43849463616648, 40.01233739237632, 39.93727107201853, 39.77701479388822, 40.22369823148174, 41.08794543050951, 39.52088402163598, 41.191849016374164, 40.817776495410556, 42.23080642761723, 42.876322653985795, 40.23062121483588, 39.15027103116436, 39.64516432054582, 40.43967570027998, 40.3436246995003, 40.636719888256444, 40.98586966914516, 44.28011932680684, 44.64646870090116, 50.25635627008254, 55.5613580057698, 56.030810802213615, 53.53130394412626, 56.106708665047925, 50.94486559590986, 50.867696885139715, 55.36715753616826, 58.64815742738786, 55.77485261424896, 54.932578532926506, 46.36672219922466, 47.75026375247587, 53.465059034286014, 59.0978846242351, 59.06674100506691, 58.808401938407656, 58.593538422738355, 58.20183092548002, 61.86164156083138, 58.15885743787212, 30.412654107616795, 7.757655391770025, 0.35157757480779006, 0.08290546826056897, 0.07497286529190118, 3.4466182945236086, 53.54290239272579, 56.5821469983747, 46.81683378834879, 33.68398143399146, 54.73391440606887, 55.64838755515314, 55.71977861465947, 57.77628906311528, 15.730653808962916, 0.07288804893652279, 0.04658989375457168, 0.03541278202206858, 0.0398871032220702, 0.03961287821913439, 0.06838345194175359, 0.0648482779281274, 0.08228984766549642, 0.04566024988889695, 0.060669019322602026, 0.08232911733249504, 0.07389270430130344, 0.018744721685746507, 0.16440465956205325, 0.2073312319454647, 0.1643892458730167, 0.15785071608279982, 0.21878845989704135, 0.21300650321908537, 0.07978516150145762, 0.19607962199276496, 0.2452803472237241, 0.08461739131880384, 0.17918712279248625, 0.13513158195682112, 0.16467916418708142, 3.34458984674946, 44.32798401001961, 63.015375368056766, 58.42204455406436, 47.853300494532434, 42.13781095320179, 38.30233696968325, 61.287030020067775, 54.05501488716372, 53.80342621957102, 4.792096922474523, 0.38313095908491845, 3.440505770906326, 10.610431009723294, 12.70129063437062, 16.169559186504735, 13.00281499662707, 40.67182902366885, 46.788439750671394, 50.354227250622166, 56.57991516974665, 58.333999110806374, 58.11163210099744, 53.8269918195663, 54.12141276944069, 55.10742995046801, 54.483671111445275, 53.9589285850525, 54.728485845750384, 55.70082572198684, 52.30973666714084, 49.70969161679668, 53.50633021323912, 55.911457000240205, 52.10521251924577, 49.1313499019992, 40.33405803865002, 42.3366908104189, 39.09770734848515, 42.69072786454232, 43.376362093033336, 40.99064711601504, 39.80458513382943, 39.87670967655797, 40.96898778792351, 40.504610538482666, 40.5956095264804, 39.797760209729596, 40.08607010687552, 40.96720703186528, 42.94416396848617, 39.620320027874364, 42.50809054220877, 42.0358960090145, 38.99518051455098, 41.79070080480268, 42.85000355012956, 38.57005050105434, 38.49352898136262, 42.56482762675132, 49.14704330505864, 51.493303160513605, 51.679749104284475, 53.16371510105749, 52.08628316079417, 49.40662184069234, 49.2439180035745, 53.5101584465273, 54.04166706146733, 56.69123203523698, 56.27849278911468, 56.01229721500028, 59.52687032761113, 57.43837295040008, 55.022914640365116, 44.103075304339015, 50.00128061540666, 54.307674361813454, 52.7898661551937, 51.2968316385823, 50.05305197931106, 55.333287869730306, 56.69689986013598, 56.3493739404986, 58.58727439757317, 57.58639927833312, 55.828930331814675, 53.056669696684814, 49.58056719072404, 45.03119830162295, 42.75581175281156, 41.13812038975377, 42.37846797512424, 40.3355210827243, 40.991423745309156, 42.49912008162468, 42.41434981746059, 42.81620448635471, 42.770677535764634, 42.669162673334924, 41.04516413904006, 44.18005574134089, 43.08648324781849, 43.37804871220743, 44.99026444650466, 42.16375743189166, 41.31886712966427, 41.429140644688765, 42.3930238908337, 41.96330470423545, 42.67394796494515, 45.30302639930479, 46.59232516442576, 47.676374143169774, 52.49149145618562, 59.00093147831579, 58.91627104051652, 56.42022371292115, 57.45019497409944, 54.871628822818884, 53.62795898991247, 56.42358126178865, 59.500296269693685, 57.36776636492822, 56.953152225863555, 48.8126181017968, 48.914587959166504, 56.34452196859545, 62.008267602612904, 62.52908775883337, 63.545554299508375, 59.78691954766551, 58.06304570167296, 59.819024147525916, 58.21016596209619, 32.463708539162916, 9.133924380425485, 1.466571020503198, 0.31983009449416594, 0.22131138661455727, 4.345165394967602, 60.01282845774005, 63.99315557172222, 61.28499430994834, 45.20079374313355, 62.852895106038744, 64.7812891775562, 63.46822084919099, 69.18282001249253, 19.81436283357682, 0.19081932522596853, 0.16448819378931678, 0.1754073062611203, 0.17130665210706575, 0.1194981022948219, 0.1372847793203208, 0.2064990612768358, 0.18819650064312643, 0.20069311072509136, 0.15900588474206387, 0.2728662693933133, 0.1737287003667124, 0.08409872681142823], [0.018913870068988013, 0.02759442383032893, 0.03237945305544042, 0.04719285091625587, 0.045844865587329676, 0.03224530339901967, 0.06943313029384421, 0.05132298796407638, 0.09685999728859433, 0.030372620620314154, 0.03269863975865226, 0.024349332839671164, 0.04338150220592657, 1.3896300523511826, 28.34867350516781, 49.84285216177664, 48.43282676512196, 39.1358837773723, 19.62828755378723, 23.379420772675548, 37.42395747092463, 35.598125534672896, 42.56929520637759, 2.10027699028292, 0.05878127525530516, 0.2218577298786371, 4.011901703573042, 6.5266602077791775, 7.992799032119013, 6.46594976225207, 37.63895826954996, 53.42583141019268, 55.60161721321845, 57.60297521468132, 54.20726560777234, 52.86033153533936, 52.60887622833253, 56.55491398226831, 55.0732425720461, 53.42193649661157, 54.36226590987175, 52.77079166904573, 49.16878892529396, 46.13074848728795, 49.06405379695278, 49.45083871964486, 50.92308467434299, 50.92580679924258, 47.68180270348826, 39.83558362530124, 37.98636259571199, 36.0386900747976, 36.40083074569702, 35.740915498425885, 38.679453249900575, 37.51945933988018, 36.34947515303089, 35.277361946721236, 33.74158928471227, 36.950841180739864, 37.91019016696561, 36.96398896555747, 36.41393146207256, 36.027432872403054, 36.5246089812248, 36.506879868045935, 35.7861678831039, 35.67815365329866, 35.786305166059925, 38.58386116643106, 36.28036299059468, 35.74271978870515, 36.33494277154246, 40.02441437013688, 42.0629015276509, 48.64188125056606, 49.043677083907596, 47.63127080855831, 45.608414296180975, 48.71409993017874, 48.721273945223906, 49.032113936639604, 49.11597813329389, 51.14053303195585, 51.91299284658125, 56.674016752550685, 52.43507208362703, 51.53913605597712, 37.409327030181885, 45.110014407865464, 49.55183190684165, 44.72925032338789, 48.837976224960826, 51.58340000337171, 53.567389749711566, 49.869265402517016, 52.11585390952326, 50.01145916600382, 49.8882810531124, 46.407965921586566, 40.7729555714515, 38.995082455296675, 37.97568198173277, 38.49565882836619, 37.84422766777777, 37.165653705596924, 36.93032326236848, 38.16185335959158, 37.020529931591405, 38.81730887197679, 37.30764350583477, 38.84274936491443, 38.53657699400379, 38.58795219852079, 40.77792913683, 39.41447011886105, 40.28223176156321, 41.592676024283136, 39.61728019099082, 39.84194570972074, 39.258618662434245, 38.11423970806984, 37.908009329149806, 38.6407276891893, 40.16394876664685, 38.85111970286216, 41.87574563487884, 45.099686807201756, 44.110315999677105, 48.85220266157582, 49.10184583356304, 53.04400044102823, 55.59059143066407, 56.88524815344042, 55.151846870299316, 53.472083999264626, 54.32846292372673, 56.888491953572924, 47.373508330314394, 46.24684672201834, 48.54195102568596, 55.507758817365094, 55.85594761756159, 57.299572037112334, 55.43355934081539, 56.57144285017445, 50.318145367407034, 62.176278406573886, 38.46497412650816, 8.693752077318008, 1.714765121859889, 0.20963715659754895, 0.031772577354023536, 1.5936691746596368, 43.86957268561087, 51.0924094723117, 37.689443096037834, 19.84622032411637, 32.09801420088738, 42.64550685882569, 46.35670446580457, 55.463804737214126, 11.064260025178234, 0.08839648772752093, 0.0557240903107149, 0.03510239766910672, 0.049836045777004574, 0.08029579740738677, 0.03592139545587763, 0.08534313705299171, 0.06490350520658879, 0.030323070053371693, 0.05172280542131874, 0.047745158174826254, 0.039155914433180325, 0.05713602099868079, 0.03327427439451699, 0.03526406903420726, 0.03598045317396041, 0.07611776837297986, 0.07778374147751639, 0.03795093090663995, 0.04226520867838014, 0.07764796005381693, 0.054753472232410026, 0.018238065606583993, 0.04212070151322311, 0.007361335991581361, 0.07401491064698466, 1.7439946243839881, 35.43576294376005, 55.127818430623705, 54.316158448496175, 43.06682432851484, 27.299590495324907, 19.307149379484116, 42.00936901953913, 43.3846265269864, 48.10288483096708, 2.606389484097881, 0.05262710709845828, 0.15622212040808894, 3.059624750767985, 8.680041432380676, 6.200151818413889, 6.643014377163303, 37.13445517324632, 57.87031612088604, 57.86711546682543, 60.13204105438725, 56.62170410156251, 54.80382280965006, 54.29716240975165, 57.864295282671534, 56.77039331005466, 55.73460125154065, 56.33276270281885, 54.73541667384487, 50.74799399222098, 48.018828438174346, 48.81611293362033, 49.557915502978915, 51.68704471280498, 50.48601888841199, 47.7750256753737, 42.43302029948081, 39.201516797465665, 37.882317804521136, 37.70992963544784, 38.54514345046013, 39.89061840118901, 38.38724451680338, 38.343835646106356, 36.745461956147224, 35.326430797576904, 39.44969692537862, 39.44392711885514, 39.036404625062026, 39.12042179415303, 38.55844420771445, 38.08979157478579, 38.97118345383675, 38.06046009063721, 37.09277606779529, 36.844795980761134, 40.47336886006017, 36.670332877866684, 38.08453559875488, 39.32213752500473, 41.58597269365865, 43.83538138481879, 49.9297522729443, 51.028486605613466, 50.28409527194116, 46.858595263573434, 47.15743280226185, 49.833842477490826, 50.2362855019108, 48.880839886203894, 52.761417204333895, 52.42090840493479, 57.96275461873701, 54.046115029242735, 53.54141189206032, 38.566441920495805, 46.40685981319797, 51.38998400780463, 45.85181697722405, 49.314665794372566, 52.78781475559358, 54.881042511232444, 53.47047582749398, 55.23120034125544, 52.40783906752064, 53.69127388923399, 47.088614817588564, 43.78831686512117, 40.15964592656782, 39.79299060760006, 40.81115553455968, 40.546081758314564, 38.924358198719645, 38.50964992277084, 38.21603698115195, 39.76398468017578, 40.49743260106733, 39.11639351998606, 40.29724659458284, 40.30440492014731, 41.63700665197065, 41.85041496830602, 40.729833033777055, 42.47342071225567, 44.45919513702393, 43.05835985368298, 41.53364435318978, 39.96178980796568, 40.590027993725194, 39.72784003903789, 42.12188220793202, 42.3130585301307, 39.72236833264751, 44.164048548667665, 46.18195502988754, 47.189878648327245, 51.81594164140763, 51.6443104897776, 54.89848529138873, 57.8169208957303, 56.98300538524505, 57.22529019078901, 55.1506309355459, 57.22931454258581, 57.02783023157428, 49.6245369603557, 47.84289052409511, 51.177313097061656, 57.07233736591955, 57.68081072838076, 59.72641306538736, 58.840530072489095, 55.45958818927888, 54.579157290920136, 60.9339225676752, 37.125445488960516, 8.158012695850866, 1.343665880060965, 0.22946387980013128, 0.0229642516182315, 1.5865676008885907, 50.13264079247752, 55.87144490211241, 42.21713304519653, 29.757447665737523, 42.310885537055235, 48.94960688006494, 53.636800012280865, 64.33060492238691, 14.73110935380382, 0.18713209808113115, 0.123797042986318, 0.024235461530606114, 0.013362149625355679, 0.047290423704731854, 0.01683032733478373, 0.0842456394926675, 0.04548047586614567, 0.03582284207485857, 0.07549216565225395, 0.05102703670760797, 0.03378951448887106, 0.04537987319992916, 0.09492372538173392, 0.1455635391175747, 0.09362545915909352, 0.18401431941216995, 0.23228360430127193, 0.15536791705075773, 0.16068355600920417, 0.1823013621352373, 0.18863396749140757, 0.05863602115442196, 0.14870109817674085, 0.19467726740385258, 0.1487972881765135, 2.51095601147221, 41.37575326427337, 62.654693818861446, 61.2868848923714, 51.34034641327397, 30.40191073571482, 33.02270512427054, 50.91507127208095, 45.78427768522694, 56.049108659067464, 3.374831811074288, 0.16075075724192206, 0.7974806752416396, 10.112056616813907, 14.700655091193415, 19.405251779863914, 9.624155932857144, 39.48935993256108, 55.15775003740865, 56.055274624978345, 61.95571960941438, 58.64951064509731, 59.13866550691667, 57.526559598984264, 60.56891856654998, 57.75970528202673, 56.91352452001264, 57.88964163872504, 55.49824314732706, 52.00723955708166, 47.62108833559098, 49.78627197204098, 50.448756371774984, 54.02649533364081, 53.97590852552845, 51.24305202114967, 43.18917482129989, 41.30071832287697, 38.6121649895945, 40.32640941681401, 38.661767282793605, 41.54534086104363, 41.54601550871327, 41.48043347943214, 39.17563699906872, 36.25160417249126, 39.434603644955544, 42.07670827065745, 41.750920126515055, 40.34114968392157, 39.58304966649702, 40.482413845677534, 39.43409373683315, 39.05435339097054, 38.96442521002985, 38.43022977152179, 42.00697637373402, 39.651232227202385, 39.317987657362416, 39.85847457762688, 43.05606134476201, 45.438916913924686, 51.870227244592485, 54.269431252633375, 51.81870691237911, 49.416663108333466, 49.93876587960028, 50.448003276701904, 51.15136269600161, 51.46323427077263, 54.79229888608379, 53.87875926110053, 58.52305735311201, 55.81037359852945, 53.64395833784535, 41.318427824204974, 48.65106744150962, 53.384313121918716, 47.01303466673821, 52.39859404102449, 54.889208885931204, 57.307004928588874, 55.834127472293, 57.47638463974, 55.37624959022769, 55.39906209514987, 49.75648157058224, 44.77536562950381, 42.72526825627973, 42.418244731041696, 42.770689302875155, 41.543795447195734, 41.457326796747026, 40.599473061100134, 41.45278861445766, 41.61520611855292, 43.2338898412643, 40.13216580114057, 42.47780592210832, 42.55200932102819, 44.886396161971554, 44.42805936259609, 43.70872412958453, 44.09650533430038, 45.50884100698656, 44.3495923472989, 42.662400507157855, 43.792725609194854, 42.90459117581768, 42.69037877359698, 44.15831796584591, 46.50562509413689, 43.063462857277166, 46.08332703190465, 49.58226165463848, 48.51636540505194, 54.27045499124835, 53.05075476246496, 58.98275521493728, 59.20673039651687, 60.028039409268295, 58.35712932771253, 56.73979097797025, 60.22310280030774, 59.649016857147224, 51.188778185075336, 50.40194288376839, 52.44838460799187, 60.17748171283353, 61.42046905332997, 61.172304614897705, 61.45638619699786, 57.60492071028679, 58.54541094072404, 64.42093710745534, 36.68812082659814, 11.468874081488579, 4.211422868313329, 0.39150129703264086, 0.1014112490379522, 2.2520234411762607, 54.49888598534369, 63.75394982676353, 49.247475593320786, 32.0752703374432, 44.83855109060965, 57.03316073263846, 61.40750169754029, 72.31039247205182, 21.928032021368704, 0.40040964320782696, 0.2965786518348802, 0.13238042232490357, 0.09731216536414239, 0.2035670436077541, 0.11834985140951411, 0.20444334094082156, 0.12425958389236082, 0.09647332973057225, 0.15404586379806842, 0.1465682174649931, 0.15009484193738432, 0.11862433305190456], [0.10969794550610167, 0.048062487114821716, 0.05890121781117013, 0.05050302490652089, 0.08016330250088247, 0.044007085774454384, 0.13083073370639356, 0.1244602453023676, 0.03029467500445824, 0.045226276401550546, 0.0012426831920991743, 0.014574913732377032, 0.024023567356409568, 0.8619045634423533, 26.661009019420995, 54.34939661333638, 43.993452902763124, 41.55224031017673, 25.190663453071352, 27.69189223166435, 32.72099641061599, 39.02344511401269, 37.680774657957016, 2.4940861425092145, 0.09528167230347473, 0.2616203744565287, 2.7889314438066175, 9.183112863571413, 4.762857123728722, 2.6719568044908586, 27.244945995269287, 52.53650457628312, 52.254560685926876, 53.82155933687764, 54.905569091919936, 55.87791289052656, 54.3665099143982, 51.68810375275151, 50.38400980734056, 45.94254924405006, 47.54475116729737, 47.218688457242905, 48.67804550355481, 48.65471916814005, 51.515656748125636, 51.12276861744543, 53.41613138875654, 50.57114216589159, 46.55515286230272, 41.024552083784535, 38.12661478596349, 37.46262811845349, 35.76746602212229, 35.25980934020012, 34.59086087442214, 33.57599858314761, 33.58713811443698, 34.335522420944706, 36.056328973462506, 36.635800330869614, 37.32077952354185, 38.16958042883104, 36.5355053255635, 35.93377059505832, 37.54104022056826, 33.91376956816643, 36.20652437210083, 35.42938124748969, 36.37402134556925, 37.70119451707409, 34.812015871847834, 35.403105289705344, 36.919748552383915, 37.44061969941662, 40.884652906848544, 47.45636055546422, 48.99748333038823, 49.05049808563725, 52.81823273627989, 52.3468501337113, 51.39274927877611, 50.56319936629265, 48.21383691603138, 49.3542189751902, 46.6406056188768, 49.229111056174006, 48.98468071414579, 48.902091287797504, 37.71304007499449, 42.228339256778845, 50.67924268784062, 44.792671126704064, 49.22383939066241, 51.130680038082986, 51.568094914959325, 47.98412330688969, 47.910080725146884, 44.28465750909621, 41.7266720341098, 37.8165671133226, 36.67809917080787, 39.12311646246141, 39.59083164891889, 36.795989928707, 36.995567967814786, 36.39312328830842, 37.871001766574004, 38.595090912234404, 38.237762989536414, 38.00795916588076, 39.66469772400395, 38.60686586749169, 37.29081653779553, 38.94845331868818, 39.75759906153525, 37.72999255887924, 38.64011972181259, 41.21814850837954, 39.44464491259667, 39.802929893616714, 39.049654391504106, 40.55710754086895, 39.25434720131659, 41.120536404271284, 40.81365016198928, 39.855454352594194, 39.469438214455884, 39.91502338840116, 41.12212496419107, 40.95635383359848, 43.10523217724216, 46.78377997490668, 48.36684857645343, 52.37999808403754, 53.32335556707075, 53.63887102373185, 56.88714658060382, 56.17804873374201, 49.29650522047474, 44.8108160111212, 46.98148704344227, 52.46530571291524, 58.174931310838275, 56.79221345532326, 57.15390697602303, 57.98931690954394, 57.45936939793249, 47.57269805477512, 27.96647579439225, 7.294202841097309, 0.26297923057310046, 0.03527607363198073, 0.05805555250375502, 0.9634602430366701, 41.37058750275643, 54.08547209155176, 48.328366202692834, 22.524912818785637, 27.194233671311412, 49.93663603259672, 43.46704729141728, 54.55150065883514, 17.344815038865615, 0.21032830580107628, 0.027813963562009797, 0.058478390903122006, 0.01504000954164733, 0.028576288079362244, 0.07360209650810688, 0.032166737251945084, 0.027827347118046977, 0.033075681421905756, 0.05981046075542128, 0.05176041267752167, 0.04930524643690837, 0.06480213645244799, 0.047647232985905105, 0.042845669668167836, 0.033539022889829455, 0.052704152561003165, 0.061333075826687206, 0.024126389762386683, 0.07148397064978076, 0.021511936605337168, 0.06794072973031191, 0.04451738460169685, 0.09218029557697235, 0.0388465911119936, 0.03974145075546638, 1.0722029305273488, 31.855643103199622, 59.26794290542603, 47.82212941877304, 48.13815086118637, 26.76910169662968, 30.350874816217733, 36.379697015208585, 42.456028922911614, 44.26242943732969, 2.5966406781827254, 0.024287421444070437, 0.059578370588320884, 5.442192516019268, 8.87237681496528, 9.058496221419304, 7.300911074684513, 29.886976095937914, 52.768873630031464, 52.733980224978545, 56.89308504904471, 56.68193601792859, 56.88295356688961, 55.45554422563123, 53.8899419384618, 51.08665535526892, 47.065315938765, 48.77249617730418, 48.975922061551, 49.713221749951764, 48.616770236722886, 49.878357456576445, 52.38703481612667, 54.498093666568884, 52.754341248543035, 48.04914835960635, 44.22330379486085, 40.5581195123734, 38.98244457860147, 38.623029954971805, 36.59335244086481, 36.64348817640735, 34.20904559473838, 36.87325669873145, 37.343576338983354, 38.38560104370117, 38.80340406971593, 39.15011021398729, 41.36519816613967, 37.649344705766254, 37.80454112637428, 37.561169824292584, 35.98271000769831, 37.73398160934448, 36.447765827178955, 37.51070853202574, 40.20046995532128, 37.52513893188969, 37.82020707284251, 38.81256280406829, 38.160496219511955, 43.16339308215726, 47.55234879832114, 49.70221165687808, 50.311508717075476, 54.52984133074361, 56.150348955585116, 52.48574518388318, 51.95089078718617, 50.20743254692324, 49.425362925375666, 48.93723572454145, 49.941986145511756, 49.182866311842396, 52.57519483566285, 40.75683463004328, 43.82202963675223, 51.05995970387613, 45.094764232635505, 50.08890244268602, 51.68845676606702, 52.561333179473884, 49.6649452178709, 50.61800272234025, 47.850586214373195, 43.69957716234269, 38.777524271318995, 39.08968610148276, 39.98448071941253, 39.86269897030246, 38.44358151958835, 39.63032991655412, 39.21868108933972, 39.29806593925723, 39.918490763633486, 39.77510852198447, 39.93572173580047, 40.238524790733095, 39.965096366020944, 39.08698358843404, 40.99674640163299, 40.73195895841045, 41.08733354076263, 40.557205600123254, 41.59600219418926, 41.303362000373106, 40.373446479920425, 40.667898808756185, 42.13941912497244, 40.30276536941528, 42.040846040171964, 42.592445035134595, 41.46011560193954, 43.134155734892815, 42.359275817871094, 43.37014905868038, 43.56289432894799, 46.369299196427875, 48.44597454993956, 49.960229089183194, 53.6651744381074, 54.923435488054835, 57.313959290904386, 57.39115153589557, 57.21956353033743, 51.589930749708614, 48.20677664972121, 48.846468156383885, 54.90798527194608, 59.34310728503812, 60.21878034837785, 58.07820174001879, 59.56457214970743, 58.90009518592589, 51.91742120250579, 31.642805491724324, 8.170662829952857, 1.0892781110540515, 0.6284759181641764, 0.07329265827373152, 1.058005789114583, 45.56256963360695, 57.79830924926266, 47.832080471900206, 24.28859283847194, 29.78828730121736, 53.22417451489357, 50.170370071165024, 61.41999836890929, 21.54576566911513, 0.15141663472017935, 0.029112446204488798, 0.06112283448718729, 0.0329833027095564, 0.03865960820187484, 0.07716399932941122, 0.034330717302979, 0.03629709646526364, 0.03572051954125205, 0.025724194448200927, 0.047565648452408855, 0.0574232924789671, 0.017344575345275864, 0.2950241062189302, 0.13123490637348545, 0.11262704438019185, 0.17158555407677928, 0.1802447378154724, 0.12033066366829219, 0.3012270894983123, 0.21556555864311036, 0.2317547738071411, 0.2793812343189793, 0.2306091352816551, 0.1259646351419149, 0.14252639886352325, 1.4719203979738298, 38.72447813710859, 67.63371913663804, 57.25864994910456, 53.450259931625865, 34.69769447080551, 39.85840397496378, 46.18216291550667, 49.910077664159964, 50.35248964063583, 3.801522682751379, 0.2873386815190315, 0.6985668958194795, 12.977412746798608, 19.931157289012788, 8.236443919520225, 4.815244299750175, 31.96532237914301, 54.79772744640228, 53.3286899905051, 59.04808621252737, 58.55081596682149, 58.45080729453795, 55.99488581380537, 54.37683751506191, 52.14314576118223, 47.85277489692935, 49.5259246518535, 49.55338908780006, 50.73203386798982, 49.74662465433921, 52.04221925427837, 54.838967246394006, 57.85914128826511, 54.18493555438135, 50.04229684029856, 45.818194420106956, 41.696116770467455, 41.28446009851272, 39.277355824747396, 37.994548582261615, 38.14371239754462, 35.51679126677975, 37.54490375518799, 38.0136348355201, 40.46228031958304, 41.48197889328003, 41.51736259460449, 43.097869888428725, 40.25309639592325, 38.652785055098995, 40.89851848540768, 37.06921046780002, 40.31075131508612, 37.349738382524066, 39.11465198762956, 42.1934066280242, 39.60336754398961, 39.27444934844971, 41.604074432003884, 40.1650470302951, 44.39089882758356, 52.13239454453992, 51.32378224403628, 51.40321024002568, 57.71562176366007, 57.750264137021965, 55.9567250743989, 53.56311044385357, 51.371054649353034, 52.483387839409616, 50.34830447166197, 50.55646465670679, 53.03368068510487, 55.36793808783255, 42.713191278519176, 46.43963513835784, 52.65486601860293, 47.18067284553282, 52.987035859015684, 55.26139082447175, 54.94938588911488, 51.89096481569352, 51.70709194675569, 49.89692595697219, 47.70144593331122, 40.81243814960603, 40.5440931166372, 43.15828223382273, 42.220208183411636, 40.49748359187957, 41.682980752760365, 42.954515103370916, 41.684655604823945, 42.271363735198975, 42.28039303133565, 41.96422253885577, 42.960147626938365, 42.50426230892059, 39.427543378645375, 43.57128820111675, 43.67641948884533, 42.80197412736955, 42.97172646368704, 45.73722493263983, 44.118698104735344, 43.44121848383258, 44.329082273667865, 43.27047771023166, 42.51859072716006, 44.63382297946561, 43.59740334172403, 43.89765685604465, 46.49232825925274, 45.10782964767949, 46.12637112217565, 46.762446203539454, 48.99108594463718, 51.83286666870118, 51.93402459544521, 56.353002132907996, 57.290515284384455, 58.55872738745905, 62.365705351675714, 60.206805352241766, 52.849666610840835, 50.91785223253312, 51.26430734511345, 57.73660252171179, 62.29037231014621, 63.040337331833385, 60.31513337166079, 60.451761291873076, 60.900249019745864, 58.29789761574038, 32.729758985580936, 10.57177899345275, 1.268322664883829, 0.6176926484031062, 0.24765629231208758, 1.6552964742145233, 50.67321400488577, 66.69631973389657, 59.287821477459325, 32.54264623888078, 38.114318155473285, 62.00082686639602, 59.25573256707961, 69.64873483104091, 27.56967902183533, 0.5970007974293925, 0.10325172164988133, 0.19265260427228867, 0.23262201598094356, 0.11088316779463522, 0.16435947569627918, 0.14014680719664022, 0.10943570594874122, 0.09769053618994453, 0.18155228136287582, 0.16477006818017653, 0.19953665503811455, 0.1400594118862383], [0.04831559107368512, 0.032827112703554095, 0.03836807344228991, 0.028178110050277847, 0.03992894311405478, 0.05095388680215805, 0.052963680167111664, 0.0644126037255891, 0.028416060789998983, 0.00914833470878582, 0.04407997904044967, 0.01358686236574525, 0.085651594694824, 0.8902064867077336, 28.175898982632546, 49.99089810156053, 47.46195777770012, 33.970655702775524, 23.421984372600434, 20.59949386504389, 36.61714161595991, 38.373363248763546, 36.84503524534164, 3.4135760030438824, 0.04199132841501025, 0.3045517272285877, 1.5806406544100855, 4.946596141784422, 5.206932675453925, 5.850368084446077, 19.246433050401752, 50.19631262748472, 52.272521218945904, 56.69784122897733, 53.64776695928266, 56.25083615702968, 52.352745456080285, 54.28551689271004, 51.673030084179295, 53.99756393124981, 51.96367379157774, 50.24112962907361, 49.97240804856824, 54.064758054671756, 50.52019842209355, 50.131468003795995, 48.96034632959674, 48.43538022810414, 42.392145279915106, 37.22844300731536, 35.83393450706236, 36.86827136624244, 36.541039789876635, 36.84364280393047, 36.262979045990974, 38.33950927180629, 35.911813166833696, 35.88789063115274, 35.18016169148107, 38.170945413651005, 38.874634312045195, 38.765031522320164, 36.72286518158452, 36.81691577357631, 35.6844804363866, 37.34911472566667, 35.682370201233894, 34.95209940018193, 35.37902193684732, 37.105837560469105, 37.61253718406924, 37.67610703745196, 35.20003241877402, 36.566068433946185, 37.13807552091537, 44.71355299795828, 48.929865590987674, 50.842005360511045, 48.74729494894705, 49.68396871320663, 47.86403994406424, 46.989539669406035, 50.76914733456027, 55.20310832608131, 49.18255644459879, 50.96348116474768, 46.73363247225362, 46.82052473868094, 39.22259561477169, 40.358313975795625, 48.60581113446144, 46.76048109608312, 49.02784639789213, 51.900551088394664, 50.50408924779585, 46.44724845886231, 46.00313809610183, 40.189761884750865, 39.00571600083382, 40.509533113048924, 39.137562551806056, 37.269925994257775, 36.746740648823405, 36.363066165677964, 37.042048054356734, 36.909405262239524, 37.77604118470223, 37.91668168960079, 37.73204003610919, 37.722367471264256, 37.3315974204771, 38.32221946408672, 37.11907948217085, 39.442052225912775, 40.10786671792307, 38.50337413049514, 38.54127599347023, 39.46270742724019, 38.43973367444931, 37.8001598388918, 39.09191793011081, 39.00262125076787, 41.073165939700225, 39.770236938230454, 39.7321036554152, 37.4881862824963, 38.81664991378784, 39.41986337784798, 38.78944043190249, 39.44994795706965, 40.78838617570939, 41.291759629403394, 44.33449514450566, 49.431677941353094, 52.043054719125074, 52.42563878336261, 55.537172671287294, 55.30733354630009, 52.61069228572231, 46.15904446571104, 45.90803238653368, 50.34965376700125, 57.24405873206354, 56.67212224775746, 59.823625087738044, 55.69673861226728, 61.74535505233273, 59.77881985325968, 37.562519119631865, 5.419973759881912, 1.1962498484119293, 0.19925355490657592, 0.04554311121483484, 0.6915501433034098, 37.81558259840935, 56.40717790972803, 37.97730192061394, 26.92870882249648, 31.692360716481364, 47.274809729668405, 49.640406870072894, 57.986794825523134, 22.888520456129505, 0.22153039583035056, 0.07465405014133261, 0.01935836960441403, 0.06178290350362659, 0.004598656791307393, 0.05037383183897023, 0.017739503246341503, 0.020113521623575402, 0.023416994259722775, 0.06671336494506368, 0.02851023406331097, 0.05245408997119916, 0.056965926496852795, 0.1258583787468172, 0.1047369363086839, 0.039714913469769304, 0.03782141225172147, 0.05051223711381036, 0.020291535559320645, 0.05944208354659139, 0.06978533921703216, 0.009366227351429482, 0.045540694207433736, 0.06811708317048128, 0.03180216750009887, 0.09882969361159111, 0.9880194897132536, 35.75675795155187, 56.22522307980446, 52.80168425652289, 41.52230478102162, 30.841231884494906, 26.729528903961185, 35.86877299893287, 44.06058426826231, 42.25694510244554, 3.554193218869548, 0.05874949026732676, 0.3967583455866383, 5.8420575626434825, 7.023959871261352, 9.403998198047761, 6.239371597766877, 23.101624788776522, 49.85720019186697, 54.41925402610533, 56.426385756461855, 55.26126923099641, 56.17394593454177, 52.775929973971465, 54.603546588651604, 52.714034972652314, 54.58902989664386, 51.555504106706195, 50.565548866025864, 50.86514342215754, 55.295742942440896, 52.4993008951987, 51.01085947405908, 51.04402703623618, 49.14310132303546, 44.19583151417394, 39.08401435421359, 37.788278979639855, 38.06548072445778, 38.27642186995476, 39.39706264003631, 37.76301891573014, 40.346437038913855, 37.12835588762837, 35.34483063605524, 37.76957319628808, 39.900859709708925, 41.48188083402572, 42.21427755971109, 38.46049477977138, 38.21472298714423, 38.17304780406337, 38.27098546489593, 37.53127744120937, 36.75535809609198, 36.22737961430704, 40.3259426547635, 38.0088181649485, 38.393900778985795, 38.42492672704881, 37.23855487761959, 39.704376420667096, 47.6952995792512, 50.846394492733864, 51.48579182163362, 51.08545903236636, 51.45287921351772, 49.5790845347989, 49.62099898246027, 52.44681173755277, 55.73067103662799, 52.15579148261778, 51.453977477165964, 48.25538658326673, 49.7696921133226, 41.52522694679999, 40.99173361255277, 49.446418208460656, 47.90901384046001, 51.6547949852482, 54.346874529315585, 52.76959534614317, 49.11281278056484, 47.590831172081735, 42.603945424479825, 41.11783389122256, 40.89922058966852, 39.158551154598115, 38.99521581588253, 38.23342484812583, 37.61777354824928, 39.422530589565156, 40.03046266494259, 39.5157810180418, 40.45874626405778, 38.678351063882154, 38.873049674495576, 39.356940715543686, 40.97361226235667, 39.321749210357666, 40.814085545078406, 41.54628222988498, 40.041362931651456, 40.42067966153545, 41.58503916955764, 38.986327725072066, 39.70074038351736, 40.75961559049545, 41.22002340132191, 42.837691230158654, 41.8707210786881, 42.31035993945214, 39.52385325585642, 41.79452119335052, 41.0395473049533, 41.84224859360726, 41.70174537166473, 42.85045854506954, 45.09472108656361, 47.41228880420808, 50.301310554627456, 55.06028698336694, 54.37792401159964, 58.11390315332721, 57.535741867557654, 54.99637980614939, 48.91492920537149, 48.23573943107359, 53.63563506833969, 60.58083472713348, 58.8467784081736, 59.694135881239376, 57.87475232155093, 63.36549397437804, 60.251343865548414, 39.518534521902765, 8.494715325294003, 1.6814121051180748, 0.5893912767210315, 0.04479314561092085, 0.47462045785880863, 40.831277293543664, 59.420017119376894, 45.56317760098366, 35.793239916524584, 38.507147450600904, 56.29875967579504, 57.08241393489223, 63.65328611866121, 26.76934292239528, 0.37441241885385207, 0.033362872462960026, 0.06915712413648445, 0.0071768170117490725, 0.014877859371594124, 0.04599408036278141, 0.04230734351421556, 0.011921591189269339, 0.027225724864570845, 0.028025083987402822, 0.06399630771709547, 0.05180021477562766, 0.03268249828608767, 0.18977609733420034, 0.352085491101588, 0.1545648577232515, 0.11281054542069474, 0.16673690699521573, 0.1888073638321892, 0.1275157180404471, 0.20386662995142324, 0.10916343830045193, 0.03982989177588494, 0.16686732580344524, 0.09190258104354145, 0.15677054743132285, 1.3156846718442057, 42.652367084257065, 63.93523393138763, 61.896483975072066, 47.86316133314564, 33.46542304561984, 30.410422278988747, 48.68616088744133, 51.158062104255926, 49.107274393881525, 4.446165936608469, 0.10337857814926295, 0.6669197423804192, 4.978267319740788, 9.789798605826594, 13.125356704958024, 8.86863487382089, 21.981525305778753, 53.38587422524729, 54.0727557674531, 57.60368516368251, 53.92152094071912, 57.87771371103103, 54.0160265276509, 56.550540539526175, 53.77392999587521, 56.494968398924804, 52.85705635624548, 52.2288260152263, 52.142659387280865, 57.689702741561405, 54.58402887467415, 53.35895107638452, 54.23373376169513, 51.84948182875111, 45.81007511385026, 40.63456650703184, 39.79961941319127, 38.9620247194844, 40.751402147354625, 40.3222164030998, 38.54159762782436, 42.411309980577045, 39.678971229061005, 37.716432925193544, 39.34092175575995, 43.426195806072606, 44.660761817809075, 43.879460980815274, 41.2203646475269, 41.40618693444037, 39.894795725422526, 41.434882994621034, 38.21636253787626, 38.762674177846606, 37.952336034467145, 41.66015648072766, 40.839886896071896, 40.644968632728826, 39.53600083628009, 39.73890112292382, 41.80932421838084, 49.075593409999726, 53.6760982390373, 55.444589045739946, 52.69426230461367, 53.43960285186768, 51.836832184945386, 51.02296783078102, 55.7606928579269, 60.10480803828086, 54.0118884271191, 54.467659996401885, 50.51791560265326, 52.406564297214636, 42.869278077156316, 44.881987417897875, 51.676736723992136, 49.56664669898249, 53.26368454963931, 56.822596134678015, 56.31070721533991, 50.810112568639944, 50.00179444589923, 43.824959647270944, 44.40368575434531, 44.66652770196238, 42.180349057720555, 41.03449921454153, 39.67913989097842, 40.63753181888212, 41.56230511203889, 41.48281043575656, 42.072970251883234, 41.0887965848369, 42.832337194873446, 41.82880270865656, 40.927347906174205, 42.853823938677394, 40.369116183250185, 43.65949053918162, 43.710979492433616, 41.890376075621575, 41.792230529169885, 43.381037558278734, 42.498810214381066, 41.23165322888283, 42.62887993166524, 42.042924896363296, 44.138949301935014, 43.016735661414366, 44.10942954401816, 41.642741157162575, 43.24802606336532, 43.94432913872504, 44.45353515686528, 43.918755285201534, 45.51965105918146, 47.15023917536582, 48.821827826961396, 51.641615821469216, 56.93711757659913, 56.58825412873299, 60.31967155395016, 59.32467606759841, 58.39496058802451, 50.376549459272816, 52.08299621458977, 55.63642432612758, 63.931515524464274, 62.30773272052888, 62.199565518286924, 59.79679215338923, 66.16647028153943, 62.27357672106836, 41.86080924926266, 7.604596662905909, 4.196556595063979, 0.7707057184269352, 0.1705204007486182, 0.8902292241973262, 46.575713926746005, 68.47978222754695, 50.02637201739896, 38.653051776270715, 43.89442090065249, 61.71181094261908, 66.71275446491858, 74.08179759979248, 32.64298635144388, 1.1266548667223224, 0.1269368466831023, 0.11616817855786894, 0.16978176941554393, 0.07922489075891434, 0.17145701984484352, 0.11033746038353252, 0.0920720090488753, 0.09360615374340166, 0.16876238217997938, 0.1685607784818257, 0.10660429094587603, 0.20839407168809446], [0.011572371924205894, 0.05038321641604266, 0.06078719604580153, 0.05441132204366788, 0.11626391656576626, 0.07925703580821715, 0.029481367335744926, 0.03075618360702309, 0.017801016276221604, 0.08695795080594479, 0.061462908577654636, 0.026578560599216053, 0.08491187551689726, 1.702454885648143, 21.79044115927912, 48.09582848702708, 40.168569318709835, 28.483385347550918, 12.278062970407548, 31.18447457590411, 48.40291477018788, 37.136282997746626, 40.88369977089667, 4.0655810554181375, 0.041093017545438586, 0.11890577843352673, 6.004936925826534, 8.087110461727265, 12.878310142024873, 6.981263891343148, 21.31145896450166, 46.27515446755194, 51.904473458566976, 53.08061968895697, 55.89243742727465, 52.85185137102681, 53.91991669131864, 53.20712789412468, 55.07614512597361, 53.288564143642304, 54.5600357363301, 52.426784115452925, 51.688770555680804, 50.99740966673821, 50.25065706622217, 46.80275247943017, 43.19568595578594, 39.08724638723558, 36.15342724707819, 35.051323598431004, 37.7124870208002, 36.16297429607761, 40.85752187236663, 42.60738142075078, 43.145636512387185, 41.98053567640243, 40.86941449872909, 38.80616149594707, 36.38163074370354, 39.90100091503513, 40.68377656321372, 40.76884884988108, 39.17856700958745, 36.84874972989483, 36.576145002918864, 35.708681460349794, 36.08390323577389, 34.662848134194654, 36.1517680844953, 37.45290456279632, 35.182307227965325, 35.66028333479358, 34.52579267563359, 36.74458334522863, 35.8392414739055, 37.723171557149584, 40.805209221378455, 42.38939569842431, 43.619631413490545, 44.2342197510504, 43.417315560002486, 46.6928868909036, 45.86568255578318, 49.265942112092056, 49.5771155049724, 52.07131931858679, 46.0780357545422, 47.74760046312886, 39.841098477763516, 38.6186525898595, 46.96928062746602, 48.00436273697884, 51.94935714044879, 50.50947858441261, 50.362252419994725, 49.49027030698715, 49.17699060132427, 49.29073541395126, 48.34380465169107, 47.229204331674886, 44.82794500166371, 42.22396189166654, 38.5902036389997, 36.93888971882482, 38.76735748783235, 37.37039358385148, 37.108771493358, 37.04952016953499, 38.316634008961344, 38.30880103572723, 37.129030535298014, 37.909405692931145, 37.972351889456476, 38.29794783746043, 38.82035263123051, 37.87408082715927, 39.55397313640964, 38.27840266689178, 38.34561247979441, 37.266003624085464, 37.90715817482241, 38.05552967133061, 39.12317922038417, 39.451073677309104, 38.68543486441336, 38.20723518248528, 39.45749851965135, 39.66703545662665, 39.302353089855565, 39.75457099176223, 41.232371022624356, 39.10524614395634, 39.84654272756269, 41.888073644330426, 47.563033334670536, 53.15621160691785, 57.201532394655295, 56.4787180193009, 53.90549413619503, 43.63781159923923, 45.64490018352386, 52.00945961859919, 58.663956734441946, 57.60707409151139, 59.077943294279045, 59.341820747621604, 60.87824452307917, 58.535899193056174, 35.40689822166197, 5.354423599858438, 1.152372254479316, 1.1036136385894593, 0.05004650928200253, 0.34968444897282513, 34.093755368263494, 54.149249830553615, 42.555217819829146, 24.086910447766705, 24.984884146721136, 46.28834932081161, 44.92515702401438, 50.92156279471613, 21.467061350422522, 0.8008666000058575, 0.007340678430703139, 0.04691601738393788, 0.0388061799739878, 0.009300780460058201, 0.04007017142289589, 0.057650809101159536, 0.03330132495912333, 0.09350928192537639, 0.05467962135650939, 0.02437227334256374, 0.05977903199832767, 0.021483011040536147, 0.023887295636438557, 0.005692419194195781, 0.04950063333155648, 0.07915589688045364, 0.03157584214462869, 0.06354973591383427, 0.043104006007554076, 0.03930792159911606, 0.03166130499824161, 0.05955973549956276, 0.03388514907489862, 0.05554991256025049, 0.029020134524832812, 1.9204801993985332, 27.722861305359874, 56.34658905767626, 48.07904858742991, 35.58389517568773, 20.496443394691717, 25.569709539413456, 45.21729515444848, 42.163800577963556, 47.162724079624304, 4.91788488241934, 0.047179252855599894, 0.5161132507266537, 6.021192208413155, 6.693709540751673, 12.303346568538297, 7.855797506147816, 21.34025308393663, 46.85468466051164, 52.61784276654644, 52.04987179848456, 56.06177399235388, 53.971393877460116, 55.27029460476291, 55.95557974230859, 55.930782518079205, 54.09737648502473, 54.805364301127774, 54.645284529655214, 54.14406053481564, 52.519191234342514, 52.923473850373306, 49.58694496462422, 45.03497946646906, 42.032483546964585, 36.717393475194136, 36.84208170060189, 39.35050018372075, 37.194726313314135, 42.964164133994814, 43.993774537117254, 45.06267139988561, 44.04117245827952, 42.37438086540469, 40.023645585583104, 38.758967538033765, 41.63033077793737, 42.53192678574593, 43.05173104809177, 41.64614185210198, 37.63379643040319, 38.16741528049592, 37.202072912646884, 38.074474719262895, 36.319170921079575, 37.631548912294456, 38.75187589276222, 36.55753335645122, 36.7255873064841, 36.58311897708524, 37.46973153083555, 38.07602013311079, 39.538699426958644, 43.9172020266133, 45.5693631787454, 46.17524385452271, 45.962569021409564, 45.583064017757295, 48.214103637203095, 48.83565025944864, 50.54043000744235, 52.48643944340368, 53.50984857928369, 48.50741847868889, 50.1578773221662, 41.14413730559811, 41.01802918218797, 47.737182647951194, 49.6881107361086, 52.32486524889546, 52.007537657214755, 50.92672071149273, 50.4728828707049, 51.03320521693076, 50.82284458221928, 51.4291920200471, 48.11110611884825, 46.79338193708851, 43.999512964679354, 40.70819723990656, 40.399534163936494, 40.17592376278293, 38.524009719971694, 38.168568457326586, 39.33064906827865, 39.01092883079283, 41.18099189573719, 39.6829249781947, 39.092267021056145, 39.74778921373429, 40.461911616786836, 41.1369829024038, 39.471058153337054, 40.67317047426778, 40.68682424483761, 41.3163411232733, 39.23575124432964, 39.29775999438378, 40.04171594496697, 41.18271773861301, 40.68732630821967, 40.59291093580185, 39.94087180783672, 42.197230938942205, 42.219870859576815, 42.67501092726185, 42.4221827906947, 43.551974450388265, 42.24090260844077, 42.249308247720045, 44.67853015468967, 49.54107676782916, 54.581385197178015, 58.507446319826194, 58.62712960089407, 55.7798340243678, 46.05273646693076, 46.850625007383286, 54.48101566683862, 60.71615257570821, 58.72891902923585, 60.905383402301425, 60.28515077406361, 61.62210633677822, 61.25581972060665, 37.20171989933137, 6.0454599126692745, 1.7707623493286873, 0.9495205684534965, 0.017299887521432775, 0.4310942531353043, 37.5658296000573, 59.841919022221724, 46.942937989388746, 27.07490340355904, 31.857029661055538, 53.30426931381226, 52.71322304202665, 59.807798324092744, 26.758421082650464, 1.0325798824910195, 0.015539497910668294, 0.07184329652978529, 0.02083337997206517, 0.040492868095996885, 0.06996615894980009, 0.10565524590351891, 0.01394008827065268, 0.007979368327200533, 0.01630490593191597, 0.04357077954937855, 0.06334668047906411, 0.08717515205423679, 0.0897023918467664, 0.1415797133719729, 0.10367574365509134, 0.16171909237821258, 0.19149060210874005, 0.15545482206488812, 0.1251027402618239, 0.09968552873620104, 0.12594094770329614, 0.15269931105356063, 0.15179422413629873, 0.09158508356420264, 0.1505342852925101, 2.3988169191345095, 34.44985951146772, 64.35246429135724, 53.93658284218081, 41.405892756677446, 19.83721456220073, 40.97735028113089, 57.369723627644206, 48.87302260245047, 52.05179375986899, 6.005696885047421, 0.2332576391317191, 1.0671755551330506, 16.48773597132775, 14.332201365501652, 19.68772715137851, 11.42333536378799, 25.979614873086255, 48.48880683222125, 53.175690097193566, 53.22062084751745, 59.245083332061775, 56.802270412445075, 58.84841403653545, 59.09715898575322, 59.09120090546147, 57.473148684347834, 58.356599807739265, 55.090269580964126, 56.40955094368228, 55.24560328452818, 56.5310267479189, 51.9509143214072, 47.65223979949952, 43.15082973049533, 38.23191865797966, 38.868664464642926, 41.431815701146284, 39.808295696012436, 46.20818391922982, 46.86578496809929, 47.446797816984116, 46.692702539505504, 44.944247199643044, 43.414232577047045, 40.118880733366936, 43.83121975006596, 45.3784575000886, 45.719287933841834, 45.607861241986676, 40.02971349223968, 40.18361945306101, 39.60513261056716, 40.59460932208646, 37.15338060932775, 40.45086622238159, 41.98514053898473, 38.25752781283471, 39.185364477096066, 39.12008839268839, 39.21419389786259, 39.85567400532384, 41.05199298551006, 47.57740097661173, 46.68892137465939, 48.49583179719987, 47.77566894408196, 49.33386187399588, 51.44443435053672, 51.09469229175199, 54.5157874784162, 55.31236986960135, 56.696084007140136, 51.40483802364719, 52.79630276464647, 43.29934635469991, 42.3580716502282, 49.931846818616314, 50.944959732794, 51.884449758837306, 56.98346822492538, 53.84110058507612, 54.04840177105319, 54.750670771445, 54.356680454746375, 52.8875567067054, 50.427606951805856, 49.11856297523745, 47.42575430100965, 43.63286941282211, 41.45564017757293, 43.83662477616341, 41.71257111334032, 40.55980220917733, 41.42223335081532, 40.50594414434126, 41.86069157815749, 41.1005989966854, 41.33380351528045, 41.20197657615908, 42.792297640154445, 44.328446849699944, 41.414286628846206, 42.36400227392874, 42.82623006451515, 42.657999607824514, 41.49973938542028, 40.57794709359446, 42.461822263656124, 44.00699292459796, 44.64057337853217, 43.153402805328376, 41.00837622919391, 44.17413296238069, 43.72958329416091, 43.49958727436681, 44.849145412445075, 45.89376280384679, 44.62369149731052, 44.10394214814709, 46.322983849433164, 51.20333802315497, 57.34843300234888, 62.12389123055243, 61.69304240134455, 59.329771226452245, 47.443640308995406, 51.17677965471822, 57.53867972281672, 64.15615358660298, 61.994558918860655, 61.63636415235458, 62.80476370165425, 64.26950616221275, 63.79445614353303, 39.206490362844164, 7.935143132363597, 2.9356011219563025, 1.9817430862495977, 0.19161686872041997, 0.5802805301162505, 41.328700511686264, 66.14119452814903, 54.84389374333044, 35.452542843357215, 38.40854298683905, 58.637359142303474, 60.44738784913094, 67.71631640772667, 34.203326779027144, 1.4830270794130143, 0.13397682698503618, 0.12268531917323991, 0.1024984733592118, 0.0820806980012886, 0.12821948471208736, 0.2525367013989918, 0.0625659832580676, 0.2037789128840931, 0.15779974059231822, 0.18305631114109872, 0.22116314860120898, 0.17805587139821824], [0.09524247924526853, 0.057615231977955955, 0.022082199049632878, 0.027884784560169906, 0.027649517043403564, 0.11199159742963892, 0.0510433467195159, 0.10426313391015415, 0.05044701621837674, 0.02060426988699023, 0.03520051438000894, 0.0664162760480277, 0.08633872959762813, 2.2450180880485044, 26.069976475930986, 43.367948609013716, 42.98319547407089, 19.21053355739963, 24.677831203706805, 67.65746516566124, 62.41237371198593, 39.60754486822313, 43.48073244094849, 5.312928845805507, 0.009818094737467267, 0.3821704380454556, 7.378009182791557, 6.113280144429976, 9.651760593537363, 4.021788527888637, 21.885062456130985, 45.651325025866115, 53.37179291632868, 56.86904484225858, 52.34947812172675, 50.2348263802067, 48.95946771867814, 46.173474865574995, 47.2675141211479, 48.39273229722054, 50.4137727522081, 49.35124189622941, 49.77304181744976, 46.74473670221145, 43.885199408377375, 40.70862085588517, 37.39661070608324, 35.649649789256436, 36.50510303435787, 35.699836515611224, 38.581680328615256, 42.808932412055235, 46.31436640216459, 45.955583280132664, 43.950965789056596, 45.28515608079972, 44.786234517251295, 44.27790711002965, 43.1540225398156, 41.81277982650265, 43.43018093416768, 42.69318719064036, 38.098036396888, 35.53704246397942, 34.693599516345614, 36.76511303071053, 35.28400644179314, 35.0343358132147, 36.14795554068781, 36.05509342685823, 36.27507171323223, 36.652415490919545, 36.72594424216978, 35.23542004246866, 36.72706604003906, 39.57915867528608, 35.57660741190757, 38.585002576151204, 38.04205240741853, 39.49800875879104, 41.257988022219756, 42.200223707383685, 43.65810986488096, 47.04991671346849, 48.14923940166351, 49.93913066002631, 46.972783304029896, 49.04226503064556, 37.30239537454421, 38.72262285601708, 45.0522731965588, 42.02541543591408, 48.551804019558816, 49.023002270729314, 48.57986857814174, 50.94905860962407, 50.189570073158514, 51.226770262564386, 50.91357292667512, 51.32433922060075, 50.46866240039949, 48.502637109448834, 42.642576848306966, 38.30483944185319, 36.13253278117026, 36.98637785450105, 37.542287534283055, 37.73754312146095, 37.81235448775753, 38.34839344024658, 38.60672073979532, 37.367055646834835, 35.48295297930318, 36.47875647391043, 37.29441727361372, 38.092411718060895, 40.31804692360663, 41.93944492647725, 43.95101285749867, 39.818227137288744, 38.08428848943403, 38.15708375746204, 37.72300289523217, 38.70531735881683, 39.04304519776375, 38.84506748568627, 38.0162706682759, 40.084308962668146, 43.016417949430405, 41.8741217736275, 42.96611747434063, 40.26961349671887, 41.08523899509061, 40.666235723803126, 43.708649604551255, 45.82228545219668, 52.15053942895705, 51.31600810635475, 45.64389997912992, 42.497759019174886, 47.65351064743535, 56.181229775951756, 58.76000773522162, 56.74438015107186, 59.5256700823384, 58.52924293087375, 62.566303207028305, 64.31564892491987, 40.91534545344692, 6.96657951801054, 0.8082432299852372, 0.17650299585394322, 0.055422129094480514, 0.16887185614435904, 30.590988589871316, 56.47496038867582, 46.18299053561303, 37.72086128111809, 29.71366813105922, 48.18914559579665, 46.01998467599192, 55.022043874186856, 23.759066981654016, 0.7622932762868944, 0.09697552334757582, 0.05079080966571647, 0.02440329607305748, 0.048705817110115485, 0.09851647090286979, 0.0340246728381082, 0.052671134171466676, 0.08230789669699247, 0.02617100182349884, 0.06344555561701137, 0.05103685029391801, 0.04904632787069967, 0.07044873305506284, 0.049371409620488846, 0.04633300532136233, 0.035219199264482144, 0.04148734215226385, 0.07191238999967614, 0.05058160637535396, 0.12176726238741992, 0.03304120363487351, 0.04766754963765702, 0.08504985561293942, 0.051333943021393595, 0.05020005628466607, 2.471800215782658, 32.41136843158353, 50.55389550424392, 49.91115631595735, 26.158847578110237, 23.232339735954042, 61.25481167147237, 72.6947533699774, 46.520985095731675, 47.401317934836115, 5.3458787164380475, 0.0616014977135966, 0.2341120569936691, 7.77933874437886, 8.629116319840955, 8.967836518441478, 5.540065457743983, 23.428638673597767, 47.67602112985427, 53.891138261364354, 58.54839978679534, 53.684009659674864, 54.04284377251902, 52.83312989819435, 49.30376945003387, 50.41087412065076, 51.44286148009762, 50.96566984730383, 50.96613268698416, 51.948380470275886, 49.075840519320586, 47.362274662140884, 41.816258968845496, 40.995365727332334, 37.641127340255245, 37.623759085132235, 37.249996431412235, 40.50297491012081, 44.318707604562086, 47.803984534355905, 48.599778529136415, 45.50904889260569, 48.12409308648879, 46.06306406759447, 47.66277528578236, 45.47934870566092, 44.286136242651175, 43.905933057108236, 44.45520608655868, 40.95445932880525, 38.52997172263361, 37.16346502304077, 38.37202964290496, 36.70388875469085, 36.75442457199097, 37.244108953783595, 38.38076868364888, 37.65302388898788, 38.4681277121267, 38.795229850276826, 37.60857951256537, 38.25859077515141, 41.38544936333933, 38.746204145493046, 39.30660101675218, 39.224603868299916, 41.47295744188371, 43.85888814926148, 45.43213905826692, 45.99477952526462, 50.53079274392898, 49.995028357351984, 51.9580412680103, 48.29098209258049, 50.74580138729465, 40.74110984802246, 40.871905203788515, 46.37541024915634, 44.18109124706638, 50.739133358001716, 51.86868575311477, 52.95008320962229, 52.89223217195081, 53.38257551193238, 52.87467564305952, 52.412875390821895, 54.14777501936882, 51.10235660306869, 50.01837430461761, 44.69367834829515, 41.46355159821049, 38.059624625790505, 38.95868678246775, 39.08375547778222, 39.83679563768449, 40.01279238731631, 39.99239606242026, 40.353175670869895, 39.8137987813642, 38.64906664817564, 39.1657369367538, 40.16663166784471, 39.527575585149954, 44.630665471476895, 44.05963505468061, 45.48372214840305, 42.03216583498063, 40.12971824215305, 39.16768243235927, 39.22190135525119, 40.53567571024741, 40.05763292312622, 41.064646551685954, 39.93695336003458, 42.46013564448203, 44.80331643935173, 44.309156633192494, 45.27418128905758, 41.279259035664225, 44.2209150714259, 42.29342314504808, 45.6198166262719, 46.450684455133256, 54.3108710935039, 53.880669455374445, 48.39585842624788, 43.6827148929719, 49.545473744792325, 58.883636920682854, 60.960539771664536, 57.78953098481702, 60.308834045164055, 59.610561939977835, 63.38639628502631, 64.25793909257459, 42.3240097876518, 7.316940330689953, 1.0561247674688217, 0.9325063685255667, 0.024745128335311048, 0.21393247369316318, 34.00825946561752, 61.90390509943809, 48.49385100026285, 37.33988931102138, 34.21442316424462, 53.153140391072924, 50.93385550283617, 61.0809604583248, 28.552477898136264, 1.0871898166594969, 0.07546443326939499, 0.032541679834286054, 0.040901602816677866, 0.09372446070154829, 0.05361729872322852, 0.02308924269351748, 0.06280016101476166, 0.06876605157289775, 0.06002906777505433, 0.06546104867612162, 0.048232780799510024, 0.040668551209232504, 0.16633654944598678, 0.13232932426035404, 0.10308465319535426, 0.15111646614968777, 0.15404658392071724, 0.21781468553648842, 0.17919081533628126, 0.21190721301301835, 0.1638741589962475, 0.13461526933937304, 0.14297431515109155, 0.11605010142609959, 0.19764115433058432, 3.253284913878287, 41.81728270746047, 58.606945083987334, 57.837662389201505, 30.158510015856837, 35.34988657120736, 74.18561489351335, 69.46791356609714, 50.372627089100504, 55.330412772394, 8.205500341230824, 0.1520225183377343, 1.085728733770309, 12.621025212349432, 11.859311711403633, 22.49321810660824, 8.619286860189131, 25.761884104820993, 49.49317678328484, 54.4134920643222, 59.77099080239574, 55.52033001376737, 55.001274924124445, 54.20844624119421, 50.89872675557291, 51.37452202458536, 52.26792812347413, 53.91005977507561, 53.353275406745176, 54.5334420665618, 51.44918434081539, 48.58499119358678, 44.44159153969058, 43.489357732957416, 38.88933143308086, 40.27215519259053, 38.16605421804613, 42.21857647741995, 46.985123080592004, 50.487387795602125, 51.55016968327185, 46.652231524067545, 49.38832790620866, 49.070690447284335, 49.76613844594648, 48.81193953175699, 46.42058810880108, 47.77439417377595, 47.104837740621264, 43.23615304885372, 39.80222778935587, 38.11143521339663, 40.99278873012912, 39.69428023984356, 38.53209764726701, 40.28975486755371, 39.62035925157609, 38.90693110804404, 40.65198967533727, 41.55487614293253, 39.44860650647072, 40.546823086277136, 43.88921591543382, 41.32609213552168, 41.28545245816631, 42.10099166439426, 44.69432161700341, 46.48786460199664, 47.39572463497039, 47.37795237571963, 51.92138671875001, 52.8800767467868, 54.421328959926484, 51.229963071884654, 53.42822013362762, 42.76599422577889, 41.18293739134266, 45.933547404504594, 47.47907107876193, 51.532919099253995, 52.829074167436175, 53.749026867651175, 55.76976922250564, 54.47375143727949, 55.91428110676428, 55.372688078111224, 56.44996704593782, 52.83742489353303, 52.615226545641505, 46.8565320968628, 44.48560053302396, 39.07886428217734, 40.951203761562226, 42.063862508343114, 41.72611505754533, 40.9035587310791, 41.552303068099484, 42.4788139712426, 41.38468842352591, 40.984971446375695, 40.82032603602256, 42.829983772770056, 42.42701122837682, 45.099439697880904, 46.08195420234434, 49.65506868977701, 44.23221934226252, 42.43182005420808, 41.20801702622445, 41.13260161492133, 42.88055096903155, 43.1948701027901, 43.49835172776253, 41.085089945024066, 44.65151286894276, 47.850445009046986, 47.410751235100534, 46.746309572650546, 44.561549386670514, 46.79590794347948, 44.57059829465805, 47.77740655406829, 50.12676508195939, 56.10008378182688, 56.06351160234021, 49.808562801730254, 46.904412469556256, 52.186197696193574, 62.31624426380281, 64.01122200873591, 59.714320398146114, 61.869313716888435, 62.16133417621736, 66.75725767689367, 65.59465539070868, 44.78571284201838, 9.617823266213941, 3.866940707929673, 2.535211948617812, 0.21419398546699556, 0.5801851062044021, 36.988115464487386, 70.37611484527588, 59.11311126524403, 51.28602550875757, 39.73679873251146, 60.56722410263554, 59.61100909017748, 72.08640944573187, 36.49126883476011, 2.0821713295675095, 0.1731993182892761, 0.15417907116634233, 0.12250913427241387, 0.23068301680107273, 0.17543142270897666, 0.10466217378815336, 0.13719963630841625, 0.19641988760521337, 0.17348794957562802, 0.18038939053733505, 0.18569655656333894, 0.13032926787291804], [0.015294675362266362, 0.09401034939313128, 0.032720128524928324, 0.16613840846525085, 0.05479387570953658, 0.019872650173642946, 0.05926648853346706, 0.02265907474793494, 0.037149828933780236, 0.0031987390802016543, 0.024856862259067358, 0.056404001004393065, 0.0849546385448306, 2.6517933703237966, 29.82588714168918, 41.503952010985344, 43.439869188493304, 25.40900807226858, 38.38528725408739, 48.946072824539684, 37.94278506309756, 32.406842016404674, 51.263875884394494, 6.1472395350856175, 0.06274680682127515, 0.36327239726820304, 3.8310431761126367, 7.177282869815827, 8.142051591027169, 8.46199099094637, 29.81044673150586, 49.42402147477674, 51.14397687296714, 54.78068082563339, 54.23442802121563, 51.11519452064268, 46.37574365062099, 39.333371193178245, 38.2558294265501, 37.153062897343794, 40.944982882468935, 40.612663991989635, 39.454854842155214, 37.819654018648215, 38.28336446515976, 37.78210516898863, 37.26647823087631, 37.85758333821451, 37.01163791841076, 37.282371674814534, 43.486047252531975, 50.07353067398072, 49.872281705179525, 47.1875330709642, 44.09997270953271, 41.890568271760024, 42.3015110723434, 43.845654072300086, 43.88163005152057, 45.878442025953724, 44.41976747205181, 41.96605036335607, 40.093687349750155, 36.109657518325314, 34.8332868852923, 35.815542513324374, 37.62854437674246, 36.5352072254304, 35.444827541228264, 37.953995197050034, 36.58185989625993, 34.9361078969894, 38.71902604256907, 36.13494503882624, 35.64987728672643, 35.68768893518756, 35.43691219822053, 35.160628288022934, 36.80250106319305, 39.84210260452763, 41.775933081103915, 43.16004730040028, 43.08488684315836, 43.66386005955358, 44.65981652659755, 50.05825696452972, 50.32011831960371, 49.229754324882265, 41.01386362506498, 40.59492311170025, 47.587387331070445, 44.275028090323175, 43.66331485009963, 42.49263248135967, 45.047719324788744, 46.51668225565265, 49.05288680907219, 49.208393096923835, 49.58502300323979, 46.23688390178066, 49.88338201276718, 49.4164748345652, 47.106618496679495, 41.43656961379513, 39.03192527832524, 37.681488529328384, 37.41788956426805, 39.48229966625091, 37.1332823845648, 35.60892381975728, 38.413496940366684, 36.942816011367306, 37.825470893613755, 37.29830042008431, 40.03157269570136, 38.0891247718565, 40.97110979018673, 43.686754934249386, 44.250642714961884, 41.72900584436233, 35.89410366550569, 37.18375152157199, 37.044170056619954, 35.520643034288966, 38.470026139290106, 39.8016708127914, 39.136656484296246, 38.093031452548125, 41.86117795205886, 43.487365168909875, 45.76140634475216, 46.67393399823097, 45.8874987786816, 41.488348822439875, 42.72350318970219, 40.02040963019095, 42.007062665877804, 40.94534374052479, 41.99689196002099, 40.94335509884743, 52.536677160570704, 58.03740124548636, 59.94928213857836, 59.38128763629545, 62.8082428439971, 60.25578398858348, 63.18973648932673, 60.12637322948825, 48.006370990507065, 6.816012965094659, 0.7124859779592484, 0.3307624143217841, 0.09373868695430218, 0.17321431829083353, 29.227537416642715, 58.26847199470767, 45.50004705306023, 35.910510939936486, 33.22316569666709, 52.488094683616396, 55.532465827080514, 55.1790092837426, 27.782846112405103, 0.5042912270272932, 0.07210964231841988, 0.04961512134140057, 0.021444716220421177, 0.04440882994282631, 0.033833989723315167, 0.045188523588642004, 0.031503973521232125, 0.06928928196430206, 0.06541935817128228, 0.04840636100139349, 0.04866524892408521, 0.055823566827682726, 0.019789776697214094, 0.07042182038628286, 0.05859626885203104, 0.0672890876810397, 0.03777224089830153, 0.0060991826748866, 0.02222928793109473, 0.0621536823980991, 0.038266210561437954, 0.049262847300739064, 0.036851882018269076, 0.02656812265124773, 0.1001201763809208, 2.883386285074296, 35.64364856289279, 49.06083745341147, 50.91867593026931, 28.035348692247947, 35.84661160745929, 58.08805081152148, 55.03312456992365, 39.97847164830854, 54.765995471708244, 6.913862862894613, 0.031435230536566626, 0.43263166902526734, 3.114371477596222, 6.406637641691393, 5.896398079010749, 8.001120830735854, 28.31255239825095, 51.59905026035925, 49.86444088720506, 56.93253232586769, 57.299289626459924, 53.40986344122118, 47.26877712434339, 43.16298907802951, 40.175307950665875, 40.24320810071884, 42.53068731677148, 45.15549429001347, 41.71335166500461, 41.22523623128092, 38.636879844050256, 39.4105242144677, 38.77131123696604, 39.69212293624878, 37.983154096911036, 39.7880405764426, 44.34378723944388, 51.623196371140025, 51.51671578807216, 49.33656830941477, 45.67725189270512, 43.477217997274096, 45.47840733681956, 45.96256509903939, 47.435568071180775, 47.791076014118815, 46.61136434924218, 45.5719127193574, 42.476758649272305, 37.18483017336938, 37.707301647432395, 37.06261304117019, 38.202995100329005, 37.79382128869334, 37.06847306220762, 40.94080948060559, 38.22609786064395, 36.30443457634219, 39.95223099185575, 37.598816733206476, 37.06077737192954, 37.54725717729138, 37.33989323339155, 38.04212693245181, 38.712401159348026, 41.175998718507834, 42.29609427913543, 45.40635339675411, 45.2399193856024, 47.15042352676392, 48.245160964227495, 51.74258547444498, 53.51011922282558, 50.919852641321, 43.44220299874583, 41.87319217189666, 48.67879467625772, 44.196545385545306, 45.68738729723039, 43.90556435431204, 45.39779478503812, 47.66685455076156, 51.35976606799711, 51.48071235226047, 50.07978685440556, 46.77651574534755, 49.80745277097149, 50.61444121022379, 49.96989380928778, 43.87691536257344, 40.527466189476755, 39.802859290953606, 38.47570573129962, 40.58952985271331, 38.85386928435295, 37.85226852663102, 40.69273917905746, 39.41378762645107, 38.93228138646772, 39.37986304683071, 39.260654372553674, 40.35936909337198, 44.41062442718014, 46.61603589211741, 47.7885696195787, 44.87980265771189, 37.98953579318139, 38.37653252386278, 39.583002598054954, 37.15693819907404, 39.12959621798608, 40.37055569310343, 41.73631714236352, 40.05664056347263, 43.56114102948097, 45.38964802219022, 47.859305643266254, 47.82165481198219, 47.299806994776574, 43.261283674547755, 44.304732199638124, 42.05436645015594, 42.95844531828358, 42.30809673186272, 44.19828299553164, 42.20014918235041, 53.61643114397603, 58.812806760111165, 62.99322182132352, 61.336185163067235, 65.34360801019977, 61.909372883458296, 65.74450954314202, 64.36726339401739, 48.544888880945024, 8.505414570531538, 1.4923429537204005, 0.9113524746029609, 0.07037798483525554, 0.25800615549087524, 32.07401910135823, 62.50167039132888, 47.8216822685734, 41.00476764863537, 36.606131522886216, 60.97305213251422, 61.720436234628, 63.960235118865974, 33.92197124419674, 1.0685608872482855, 0.07770095801641864, 0.0401842151017439, 0.03435106459824789, 0.04877350480866529, 0.033001700311057994, 0.020875951478017435, 0.11059486592609076, 0.056411451209456696, 0.011744094362872983, 0.03966287311707293, 0.07171113104108842, 0.015312165149577684, 0.1547929987071022, 0.2255065300531926, 0.11535524435701872, 0.29095890661401136, 0.1833615665354075, 0.1536852815338681, 0.10798012357084982, 0.20668309091800646, 0.1352827770695571, 0.13696328286201725, 0.18649344122217548, 0.13296818030217003, 0.4595681171744101, 3.7387201430336123, 43.03896373318088, 58.12090066171462, 58.22346279698034, 37.71799402852213, 51.60669495982509, 56.55003063140377, 47.49070090632285, 42.357240107751664, 62.75536144933393, 8.484606396767402, 0.13211987582185578, 1.1990140162168013, 10.68926182485396, 14.726839853871255, 18.06358741175744, 12.049087747450798, 32.78322481339978, 53.5497312391958, 51.2116652150308, 58.73105672097976, 60.66056082325598, 54.93174699044997, 51.046639334770944, 43.99071508838285, 41.48281043575656, 41.25578757255308, 45.65343918338899, 44.49733626457953, 43.53047986184397, 42.527482740340695, 41.30064772021386, 40.51030974234305, 41.29973380796371, 41.64184685676329, 39.835073717178844, 41.99408746534779, 47.24889462993991, 55.01378336260396, 54.41764193196451, 52.260663893914995, 49.2685426435163, 45.51896856677148, 47.31444528025966, 48.07653042577928, 49.98032731394614, 50.376404331576445, 49.638175041444846, 47.001040058751265, 45.06445215594384, 40.81126536092451, 39.63783341069376, 39.164575915182795, 40.63891641555294, 39.26568285111458, 39.419396615797474, 41.67500657420005, 40.55442856204125, 38.184563882889286, 42.99409966314993, 39.653205179399066, 39.223034920230994, 40.40004014968872, 38.65256147999918, 38.85514797702913, 40.3783808215972, 44.05575583058019, 45.933186546448745, 48.70923619116507, 48.30281980576054, 48.96790473691879, 49.15329948548348, 54.55817653286842, 55.779563380825905, 53.020517210806574, 45.669328704957046, 44.40744730734056, 47.48942221364668, 46.6526629847865, 47.397540692360174, 45.804038586155066, 47.51232493308283, 49.762031724376065, 52.446737212519494, 51.05468411599436, 50.95175720030262, 48.41122235021284, 52.94673742786531, 52.91466420696628, 51.15923489293745, 47.31689283924718, 43.62539729764385, 42.983560254496915, 40.11826099887971, 44.2949301965775, 40.86043227103449, 39.05352184849401, 42.3076888053648, 41.92526555830433, 42.69326956041398, 41.09636675926947, 41.855161036214525, 41.97143577760266, 46.28547814584548, 48.878290345591886, 49.72045067817935, 46.006087718471406, 40.08843529608942, 41.302703042184156, 40.82205972363872, 38.58221769332886, 40.93171350417599, 42.525094016905754, 44.20217398674258, 42.10697327890704, 45.87367242382419, 47.50222090751895, 50.76022002004808, 51.39589501965431, 51.297357236185384, 45.06486400481194, 46.72920803869925, 44.512911996533795, 45.82091262263637, 44.43001662531207, 45.9545869981089, 44.2908509315983, 56.91894915796096, 61.56939752640263, 65.9941997835713, 64.00800174282443, 68.09543701910204, 64.29014959642964, 67.55387536941036, 66.95966766726586, 50.59126392487557, 10.015314298291361, 3.11755251980597, 2.8506881815771905, 0.268100926712636, 0.3129603082854902, 36.05177117932227, 71.50607908925703, 56.60657159743771, 47.86892721729894, 43.323845478796194, 65.00906121346259, 68.69893289381459, 71.08915467416087, 41.214739968699796, 2.2194890966338496, 0.11658255551611224, 0.09975221669000965, 0.12905864976346493, 0.13971333932732383, 0.12806304955794928, 0.1889886815221079, 0.22637525843756817, 0.18597375781786057, 0.12754040139336742, 0.09690114387100744, 0.18009581032299227, 0.1680657937521896], [0.059819393340618386, 0.055351039965546904, 0.0038530801529920995, 0.052061611636271404, 0.11275622212598402, 0.019052798198836467, 0.11221970776997267, 0.07540675450957592, 0.0193205114544159, 0.08732119905612162, 0.02336754711465009, 0.03938269944140508, 0.11126131645493931, 2.5777909928752534, 29.262952496928555, 36.355303795106956, 44.33718589044387, 29.9515579208251, 23.975067984673288, 32.155476923911806, 38.016337348568825, 35.7886899671247, 53.02645567924746, 6.975553900964799, 0.04880908193186887, 0.16434809162972436, 3.2135216411082976, 6.190157128918556, 3.8521438116027467, 16.75282543705356, 37.36916588198754, 50.60543152593797, 53.071680607334265, 53.81758989826326, 55.27145562633392, 52.776679146674375, 51.66088250375564, 48.520158337008574, 43.75962864968085, 40.30071396981516, 37.04167150682019, 36.55974949559858, 35.64428398686071, 38.46388762997043, 37.438615368258574, 38.40606797126032, 37.182033523436516, 37.83480613462387, 35.44659653017598, 41.30373462553948, 48.18244618754233, 48.83729765492101, 50.350414706814675, 47.01173636221117, 41.26005511130057, 38.886295518567486, 39.71046786154471, 41.146137714385986, 42.644808676935014, 43.71722782811811, 44.38812571187174, 41.30638222540579, 37.88882501663701, 35.96473770756876, 37.260245584672504, 35.95934052621165, 39.3508178957047, 36.464647708400605, 36.42893452798167, 36.30881978619483, 37.030210341176684, 36.42846384356099, 36.65267044498075, 36.34937317140641, 35.44105814349267, 36.59674921343404, 35.671238514684866, 35.18178163036224, 37.28694515843546, 38.93750598353725, 39.25983459718766, 42.91100032867924, 42.87285135638329, 46.831460306721354, 46.75640967584426, 49.39532541459607, 49.940864347642474, 50.285071942114065, 40.07918242485293, 39.11953926086426, 43.47062057064426, 38.616522742855935, 46.75060456798923, 44.05334357292422, 49.238222722084295, 50.01560511127595, 49.93707141568584, 51.1982899327432, 50.18957791789886, 50.12726714534145, 51.81387455232682, 48.4317716475456, 45.826717730491396, 40.7412745875697, 36.095803706876694, 35.24037791836646, 37.123362710399014, 38.21318934040685, 36.90380019526328, 36.68614002966112, 35.90720438188122, 36.49923909095026, 37.732604857414, 38.363129784983975, 36.69181177693029, 39.87098693847656, 43.55356301030805, 46.86542803241361, 47.04965391466695, 40.21552008967246, 37.74453670747819, 37.89903102382537, 36.77787642325125, 37.668454493245775, 38.28811445543843, 35.95635560251052, 37.94997084525324, 38.619480209965865, 39.80618546085973, 43.98746736588017, 47.635330461686664, 48.81903902176888, 52.292733192443855, 50.184184658911924, 48.356034601888354, 42.25900434678601, 41.5531228434655, 40.199461906187, 41.4752677179152, 40.52858014260569, 47.80549856924242, 59.95841733870968, 61.00408200294741, 57.52594770923738, 61.48785537289035, 57.794300586946555, 61.748281140481275, 62.30089602931854, 51.71279115061606, 12.43819373269235, 0.25162554706536955, 0.6489568804540943, 0.07628349617363946, 0.08704900801662477, 27.339898732400712, 57.724643215056396, 47.69404442079606, 28.73688028704736, 24.191943676240985, 43.61655627527545, 47.9357094918528, 53.82135929599885, 29.632773168625373, 0.39243561786509334, 0.11227266742817818, 0.02615680046860249, 0.016462608961568728, 0.055397258050018744, 0.03788716174782284, 0.02339646884901149, 0.051698968595554756, 0.08532363245443952, 0.01533119477361681, 0.0809759149448045, 0.00930776718192764, 0.0276871970779593, 0.05281939133701306, 0.06344311179653292, 0.030190925632092743, 0.03986819617209896, 0.06705893188594811, 0.020784855962941245, 0.10858652812819328, 0.0490148876222872, 0.032900814192309495, 0.10872567267788034, 0.06171825717413618, 0.12721351167607692, 0.0922233114139207, 3.771609462076618, 34.140176619252856, 47.289428403300626, 51.1886134455281, 35.65342703173238, 31.145503867057066, 38.56706165498303, 42.23783531496602, 40.67516303831532, 56.79033071764054, 8.10741755270189, 0.08209379810479381, 0.11277777217929402, 3.1368562194608876, 6.269344879734901, 4.690951253137281, 13.854220355710677, 40.800949527371316, 51.775148991615545, 53.4457060598558, 54.068327411528564, 56.60628526441513, 52.9318049646193, 53.732090073247115, 48.69921845774497, 45.194855274692664, 41.38770472618842, 37.5807346067121, 38.780520962130645, 38.072105607678814, 40.42884995860439, 40.29096687993696, 39.10264953490227, 38.505935438217655, 38.6821557629493, 38.54428445139239, 43.006682626662716, 49.91259582581059, 50.23888603333504, 51.799177431291156, 49.31865484483781, 43.616332700175626, 40.86357408954252, 41.65910528552148, 43.10311801971928, 46.01046508358371, 47.16011570345971, 46.57693378386959, 42.18931951830464, 41.40217827212426, 36.85261326451456, 39.39752547971664, 37.439454755475445, 40.736959980380156, 37.49157128795501, 37.50198910313268, 38.558663860444106, 38.24483110058693, 38.38574224902738, 36.97450483998945, 37.399768214071955, 35.91530407628706, 38.04972064110541, 36.68651265482749, 36.9157987256204, 37.81130721492153, 39.735308231845984, 43.07092712771508, 43.304300308227546, 45.45732851951353, 50.55184018227362, 46.895979373685776, 49.705102443695075, 51.18003129959107, 50.76164776279081, 42.06809082338887, 40.63052254338419, 43.32934464177778, 40.9186206325408, 47.11079974328318, 46.77760224188528, 50.39995031972086, 51.6910376856404, 52.30104469483899, 51.48010046251359, 52.56986041222849, 51.47247145252844, 54.71826022671115, 50.183521778352805, 47.631533607359856, 43.062380283109604, 38.41503450947423, 37.43523428517003, 39.75040543463923, 40.51987640319332, 37.31229151448896, 39.507751926299065, 38.61594223207043, 40.26704042188583, 40.25905839858517, 40.57313434539303, 39.41486235587828, 42.319620655428984, 47.09139970041091, 49.319380483319684, 49.11193416964624, 43.439331823779696, 40.27121774611935, 39.056647977521344, 39.061829428518976, 38.77125632378363, 38.168835178498306, 38.43201052758002, 39.81858799534459, 40.242482462236964, 42.18901749580137, 45.73382423770043, 50.74058463496547, 51.88588926869055, 55.124217694805516, 52.269489226802705, 49.52788583693966, 45.102930607334265, 44.05942716906148, 41.824962708257864, 44.0724729722546, 43.30864237200829, 52.40758019108927, 61.54278032241329, 63.365129193952015, 59.6223408176053, 62.828666625484345, 60.4150479070602, 64.96918247592065, 64.27657035089308, 52.045463054410874, 12.481408446065842, 1.7659068227775636, 0.6196037619825333, 0.049162390191228166, 0.13885700624556313, 30.87809039700416, 64.26192422066966, 55.29115376933929, 33.81458851598924, 27.808959291827296, 47.48297775945356, 53.20725340997019, 59.743612658592966, 34.00633358186291, 0.7481314362056795, 0.21611826043696175, 0.031080028124814554, 0.007254269458503733, 0.07057854665383216, 0.04855719222236545, 0.04610488348970971, 0.07004095211384759, 0.031863795443167614, 0.07150788025389757, 0.09790304898013992, 0.03638703901801379, 0.01692867578728305, 0.1824562497917683, 0.1403263015972991, 0.22267811811499058, 0.1795449164966422, 0.200820189389971, 0.09552194812004605, 0.26606285704239724, 0.14510022446272836, 0.0861621156875645, 0.19538507135885377, 0.11097708251327278, 0.1613229789560841, 0.32888767459700186, 4.2905973811303415, 43.8143967043969, 56.56497878413047, 60.2066170784735, 42.43009813370244, 35.54319274040961, 41.80657463689005, 48.99655372865739, 46.397681466994754, 64.64601839742353, 9.862412464234138, 0.2464646272241108, 0.5221034454241876, 10.55396652990772, 14.897532578437561, 9.247166149077877, 22.11526636154421, 40.7867270131265, 53.23303122674265, 52.97482944303944, 56.5507209685541, 58.55406761169434, 56.32168200708205, 55.94831159037929, 53.35228304709158, 48.80165507716518, 43.76281753663094, 40.70959360368791, 40.2688447121651, 39.78753459069037, 42.564349097590295, 41.50279883415469, 40.84239329061201, 40.915031663833126, 39.965810237392304, 38.992015161821925, 45.30976895363101, 51.69888242598503, 51.03842589163011, 54.41506885713147, 51.55831644611975, 44.957916659693566, 43.17556419680196, 43.08997023490168, 45.30279497946463, 48.10969798795639, 48.39872175647367, 48.8534656647713, 43.889992544727946, 42.39661285954137, 37.40583612072853, 42.55626509266515, 39.96967769438221, 41.98327349078271, 39.61597404172344, 40.67118967733076, 39.35390480103032, 40.01780517639653, 40.30971580936063, 39.36723693724602, 39.738999182178134, 38.3999922198634, 40.09847264136038, 38.60406529518866, 38.31178595942836, 40.71283740382041, 42.336306418142016, 44.09795661126414, 45.55188509725755, 48.2776342668841, 53.376236961733916, 50.23315545051329, 52.38768200720511, 55.71666817511282, 51.74702559748004, 44.71255671593451, 42.383606280049975, 44.25787556555964, 42.461943857131466, 49.01511830668296, 48.21426053200999, 52.86514036117062, 55.5080843740894, 54.59043018279537, 55.68447728310862, 54.68223325667843, 54.984036107217115, 57.13042766817155, 52.56334143300211, 48.97812251121768, 46.924322420550936, 41.37199171127812, 39.600441455841064, 40.968250382331114, 43.77512593423167, 38.50027153568883, 41.8495677363488, 39.23507267428983, 42.17744650379304, 40.83761584374213, 42.648123079730624, 40.46466119827763, 45.23484776096959, 48.936376725473714, 51.72351098829701, 52.99375880149103, 43.99611619211013, 42.34896782905825, 41.347865212348204, 41.166655632757376, 40.6971832244627, 41.640277908694365, 40.06006871500323, 42.63174326189103, 43.15507373502178, 44.210971863039084, 49.87446646536551, 52.876479933338786, 53.904792031934186, 56.894030340256236, 56.08849710033786, 54.12453105372768, 47.570172048384144, 46.67015675575503, 44.207245611375384, 46.957344855031664, 45.55414830484698, 52.91524471775178, 64.72170052989837, 67.35925520620039, 63.962066865736446, 66.72348606971003, 62.77816218714561, 67.46460222428846, 65.60460644383585, 53.45635137250347, 14.68443020697563, 2.7197050423391405, 1.8314156753401605, 0.24992660919745124, 0.22772519729070126, 33.787896786966634, 69.17164910224177, 59.68886813809795, 41.40830501433342, 36.217852177158484, 54.97412820016184, 63.67485523223878, 70.10194901497134, 42.306182615218624, 1.7419896803555952, 0.2477748520792492, 0.2443802551997285, 0.10517625708974178, 0.15645999070857802, 0.19181173084483993, 0.21854826068926245, 0.21104666644767409, 0.1412239881052125, 0.09550585261275692, 0.16757750463101173, 0.13027919636618707, 0.230076888035382], [0.05412580873516779, 0.009104881244110725, 0.08199779962700221, 0.056410543395266424, 0.031891510589048266, 0.04425342900738601, 0.04726287901341435, 0.11433883720347959, 0.05027411400430626, 0.025701864900427963, 0.024375040835190206, 0.008428583612605449, 0.05031814107731466, 1.7469285572728805, 25.739663877794822, 38.87967455771662, 47.966402038451164, 29.43682920548224, 19.52809649129068, 24.339899401510916, 56.297347622533, 37.34819296867617, 52.97004807379938, 8.454067803198292, 0.05364577804181365, 0.06076263143650948, 0.9001447921318393, 2.4009536302858785, 3.282175866826888, 17.51254343217419, 36.65308229384884, 55.782469857123594, 53.30720324670115, 56.578565874407374, 52.53532786523142, 56.81328835025911, 50.57637853007163, 54.14897134227138, 50.08291690580307, 51.447878191548014, 47.9771375656128, 42.63978804311445, 37.51024176997524, 37.41623432405534, 36.85850074214321, 37.067610140769716, 37.28163426922214, 35.797444697349306, 38.23373079299927, 44.235698484605365, 49.670946444234545, 49.17134631064631, 49.63929683931413, 48.10461851858324, 40.78808807557629, 36.985660060759514, 35.749736908943426, 36.883231286079656, 39.931289457505756, 41.149597244877974, 41.573978085671705, 39.81324180479973, 37.384008130719586, 37.901309920895486, 35.53836038035732, 36.622887888262355, 34.949451800315614, 35.15934959534676, 34.5994665545802, 35.29693457388109, 35.778013275515654, 38.0809348629367, 35.28983116149902, 35.66744950509841, 34.59364183487431, 35.04819746940367, 38.60454774671985, 43.100705762063306, 44.64867699530817, 44.05928596373528, 43.11106081931822, 44.82525033335532, 44.70419030035696, 46.15459257556547, 45.835668579224624, 49.44826172244165, 46.872535367165845, 49.17021666803668, 39.305436072811005, 36.30193994891259, 44.82798030299526, 43.23501556150375, 49.57566030563847, 49.11817073822022, 48.73119361938969, 49.25153524644914, 50.408195141823064, 48.75253915786744, 50.49811547802341, 49.988787866407826, 49.92967382554085, 46.654016202495946, 41.89163515644689, 39.091894395889774, 36.75939029262912, 37.47731347237864, 36.82389759248303, 38.997239758891446, 37.735185776987386, 37.93002167055684, 36.29352646489298, 36.57850234739242, 40.0072814572242, 40.005316349767874, 37.38847963271603, 41.4665404442818, 47.70893373797017, 47.725843075783025, 45.83115393115629, 39.534847659449426, 36.935645918692316, 37.59006984772221, 41.466399238955596, 46.597714501042525, 47.59399260244062, 47.353594456949544, 44.14546043642106, 37.92310653194305, 37.19015282969321, 40.01673044696931, 48.38927668909873, 51.67447743877288, 53.85723721596503, 54.541769258437625, 54.851075603115945, 49.010038837309814, 42.67774481927195, 40.30340471575337, 41.04062595675069, 41.227542584942235, 41.34359375123055, 45.81690396032026, 54.52461281130391, 57.30567524510046, 58.02632839448991, 58.457063474962794, 63.74653654713785, 61.04294876898489, 51.612700108558904, 13.485723483947016, 0.9139004830391178, 0.5603384034287545, 0.04141416160329696, 0.11231615057876033, 27.392505561151815, 54.69925634322628, 46.07849859422254, 35.13373259575137, 32.03735474617251, 45.75835866312827, 48.5348750698951, 55.632407819071126, 26.084993270135698, 0.3945857202333789, 0.06297552237106908, 0.0258407183367038, 0.04836364010829599, 0.04140615598448823, 0.04272849268970951, 0.00829100379750373, 0.09555611564146896, 0.04028456112850578, 0.05331969271684366, 0.04979925823488063, 0.009050424841623153, 0.14125515256197224, 0.053945904477469386, 0.03933347063139081, 0.009339385545782505, 0.019302175139948245, 0.06570093378785156, 0.05306467353816956, 0.04836445982237497, 0.09359643208764254, 0.042568219435070796, 0.027994089985206246, 0.029453857118384014, 0.017677992131681215, 0.0211663639187933, 2.085250145004642, 31.2801549127025, 47.52888517995035, 54.72843877730831, 33.5637019526574, 26.49424945154498, 38.07972677292363, 53.49591239806145, 41.485297218445815, 59.09139702397009, 8.991037338010727, 0.05380569506556757, 0.11096247321655674, 2.025363152065585, 5.743945356338255, 5.832412944686029, 20.251563941278768, 39.241575964035526, 55.57654934544718, 53.49501417529199, 54.7758053195092, 54.38605116259668, 57.870425947250865, 53.114967884555945, 56.10879928834977, 52.58016447867117, 53.21424307361726, 48.258602926808024, 43.49018535306377, 39.25450409612348, 39.01347052666449, 38.16988245133431, 39.543476873828524, 38.02046760436028, 37.83938354061496, 40.356886233052904, 47.30909516734462, 51.74404851851925, 50.69548522272418, 52.37111783796742, 49.591718489123934, 43.31425136135471, 37.90853100438272, 38.23400143654116, 38.97700425117247, 43.235148922089614, 43.63304591947987, 43.81427118855138, 42.22538963440926, 38.92029070085095, 39.50738322350287, 38.016196143242624, 37.99987123858544, 36.95367705437445, 37.11174072757844, 36.68921909024639, 38.53645932289862, 35.95625754325621, 39.10378702225224, 37.598408806708555, 37.05408973078574, 36.73243968717514, 37.219488236211966, 40.82282066345215, 43.79341202397501, 46.82858128701487, 45.62966962014475, 44.55647383966754, 46.974583671938994, 47.375320465334006, 47.63230239191363, 48.87226950737738, 51.75598429095361, 48.565497013830374, 50.82940670751756, 41.21834854925833, 36.556709658715036, 45.11228153782506, 45.792557808660696, 51.42312019102035, 52.604479251369355, 52.11626183602118, 52.27968738925073, 52.72582169502012, 51.66891551786854, 53.22630043952696, 51.67337525275446, 50.989427643437544, 48.32285135023056, 44.745853716327304, 39.454619499944876, 38.14479497171218, 39.92782208227342, 38.804980862525206, 40.63652376974783, 40.76305550913657, 38.91423848367507, 38.430555328246086, 38.02731606268114, 40.941260553175404, 40.49307092543572, 39.61046703400151, 42.756247135900686, 48.81642280086395, 49.21301364898682, 47.58772465490526, 41.388920660941835, 38.499514518245576, 39.70202692093388, 43.38889014336371, 47.75302510107718, 48.085849977308705, 49.55252224399198, 44.931068035864065, 38.85182965186335, 39.969877735261, 42.877573890070764, 51.332152581984005, 53.46935795199487, 56.33263326460316, 57.35400276799356, 55.82802426430487, 52.03503739449286, 45.22519480797553, 43.128107440087106, 42.751081374383745, 43.22433886989471, 43.59149232987435, 49.157013970036665, 56.84229035531321, 60.08535700459635, 60.87169808726157, 60.68963735334335, 64.62087208224882, 63.84432515790386, 52.581086235661665, 14.745538773075229, 1.5004211976643533, 1.062227240012538, 0.01429131851651736, 0.0767853450510771, 29.258588860111853, 63.4857891451928, 47.3824474119371, 35.407368906082645, 34.56833470252253, 49.5367072474572, 55.85808923167568, 63.62388403184953, 32.29020053340543, 0.9830817772496132, 0.14524473928876463, 0.026366444259521463, 0.035973340047583464, 0.008571838224006277, 0.056569679009337584, 0.019210472500192064, 0.04604309083773725, 0.042907328254753546, 0.018645534366970102, 0.05540975294406376, 0.030174521774414088, 0.13087389510004752, 0.09821525279192195, 0.11470773918253761, 0.12225005865818071, 0.09298726961377168, 0.12598658356094553, 0.13566635729324433, 0.20827378056222395, 0.18964229241734554, 0.1718262589025882, 0.10361511545676379, 0.10164682873554769, 0.07848363174425979, 0.19889897877170196, 2.470247447490692, 38.669058968943936, 58.91646323665496, 62.4122364290299, 39.72333715808007, 31.503318163656424, 32.156820335695826, 63.09844332356607, 47.55749102561705, 63.993112425650324, 11.044689359203463, 0.16541675364057865, 0.5822062300097558, 4.784071753101965, 9.19494959615892, 9.151925117738786, 20.54848736332309, 42.093735279575476, 58.2935163282579, 53.58315767780427, 57.437364901265795, 54.22126454691733, 59.077107829432336, 54.177706626153764, 58.3318418072116, 54.1861318772839, 56.363365034903254, 51.85956624246413, 46.65816607013826, 41.08005362172281, 40.71977999902541, 40.50870549294257, 41.40965038730253, 40.28003523426671, 40.10612910793674, 43.23237580637778, 48.31614801960607, 52.76675947250859, 52.52898147029262, 55.47282226624028, 52.30041319324125, 45.35469578158471, 39.438416188763036, 40.158763393279045, 39.48086015639767, 44.97916021654683, 44.98513790868944, 46.22914898780085, 42.2091470995257, 40.984528218546224, 42.63419082087856, 40.209197228954686, 38.94463685251052, 40.174982393941576, 38.81799136438678, 38.5772676621714, 39.6823876134811, 38.82537326505108, 41.54132435398717, 39.55583626224149, 39.10313198643346, 37.73771178337836, 38.762407456674886, 42.464226676571755, 46.77231096452283, 50.09329941964919, 48.411226272583015, 48.05373361033779, 50.541441978946814, 49.55191819898544, 52.1965802100397, 52.36546962491928, 52.89768426649032, 49.77436365619783, 51.232387096651145, 43.448372887026885, 39.33904686281758, 44.77791124774564, 46.29587634917229, 52.78182921871063, 54.991147364339525, 53.78939197909448, 55.674181061406294, 55.560561764624815, 54.60940660968904, 53.538136712966434, 53.83369515019079, 53.38401894415579, 50.49915882848924, 45.699730996162664, 43.27414904871295, 39.535506617638376, 42.168064194340865, 40.1369510927508, 42.53828887016543, 42.72510743910267, 41.97087487866802, 38.987331851836174, 41.35841246574156, 44.6138620376587, 43.499846150798184, 41.114919570184526, 45.82050469613845, 52.890051334134995, 53.43670422031034, 49.8018124026637, 42.76905759688347, 39.14278322650541, 42.62930354764385, 47.33423363777899, 52.36767007458595, 51.77900468149493, 52.175281740004024, 48.71265649795533, 41.92876823486821, 40.72467119463029, 43.366968016470636, 53.24631237214612, 57.39807844161988, 59.84220927761447, 61.16272226456673, 59.53943760164323, 55.78043022463399, 45.99191619503883, 45.57823950244535, 45.40807531725976, 44.85877090884794, 45.67265487486317, 50.77889050206831, 59.902198007029874, 61.421331974767874, 64.11984812828803, 63.26005674177601, 67.27586561633696, 65.89188867999663, 55.37626920207855, 16.46052452825731, 4.514058732217358, 2.1522292735115176, 0.1575205781527104, 0.48590021388184645, 32.982700870883086, 67.69986598722397, 57.700328442358206, 48.78953495333272, 46.09390566425939, 57.694503722652314, 65.01421913023918, 72.72621862349972, 38.52712408188851, 2.34344040674548, 0.27686172435360573, 0.09046997364249923, 0.2019143008416699, 0.1521296174295487, 0.13169869600284484, 0.12985585617922968, 0.2523726819744033, 0.10829195199954895, 0.15643251879561335, 0.2863974352517436, 0.09813976248786335, 0.26958909847082635], [0.03573196106440118, 0.1192913887902133, 0.04371254028932702, 0.023887510141057354, 0.019777408207676584, 0.046990385369187405, 0.07087714474407897, 0.00813464620976799, 0.08843486873252739, 0.02551126030964717, 0.009075458679768828, 0.008525136546532234, 0.028535061057717092, 1.0204220058456546, 20.10696380369125, 44.85946909073861, 45.83858682263283, 39.546846189806544, 23.90471439207754, 16.284071803092957, 52.08214113789221, 47.390480426050004, 50.52878056803058, 11.671405665336117, 0.12640430832341795, 0.12971685718624823, 1.0044013300249655, 5.0678694536609035, 4.458407653916267, 17.937675406855924, 44.29860937979914, 55.22823502940517, 57.452501327760764, 56.179362727749734, 56.862137548385135, 56.383686834766024, 53.83476595724783, 54.551720311564786, 53.533857407108435, 52.37367914568994, 52.33633033690914, 52.1278485175102, 43.55280207049462, 37.2941780090332, 38.18897654933315, 39.53434559606737, 36.69580082739554, 36.43333542731501, 40.287373988859116, 46.92246713945943, 48.688063236974905, 47.63484016541512, 48.583912541789395, 46.74218716159944, 42.02610185069423, 40.00683430702456, 36.46267083383376, 38.20573683707945, 36.21482802975562, 37.16290020173596, 36.91307267835064, 36.595560735271825, 34.72028340062788, 36.096890203414425, 36.253188810040875, 36.046432833517756, 37.02479354796871, 36.91770499752414, 35.64832010576802, 36.835543109524636, 35.49699898689024, 37.177773829429384, 35.201954380158455, 35.14041631452499, 35.0217685391826, 41.115311807201756, 45.542130162639005, 48.30413772213844, 47.698080539703376, 48.39683509642079, 47.62557552706811, 46.40034083397158, 46.15861692736226, 48.6037048216789, 46.79616681991085, 48.89400728287236, 49.0682154317056, 49.14518802396713, 39.903640670161096, 35.99146866029309, 48.54765415191651, 49.69856777498799, 50.97262420961934, 48.3492136001587, 47.53953441496819, 46.25435021615798, 46.25920611043131, 46.44461262610651, 46.585806185199374, 45.29083567280924, 43.93272676775533, 39.84984928561796, 39.25837547548356, 35.741841177786554, 36.006267762953236, 36.690066322203606, 37.89921537522347, 37.44377328503517, 37.115925896552305, 38.74649832325597, 37.945271845786806, 37.85895616777482, 37.31906937014672, 38.85503422829413, 38.1919300940729, 41.65134683732064, 48.424852586561634, 47.138479909589215, 45.13665906844601, 39.82219265353295, 40.827229407525834, 45.69584000495173, 51.09164068775793, 53.57925491948282, 54.411056272445194, 50.337576789240686, 51.35753816173923, 46.405577198151626, 37.28254425910212, 38.03398801434425, 42.9613321827304, 51.88055876762637, 54.66793621740034, 55.1192049057253, 55.05543108909361, 55.64170775874969, 49.17084424726425, 43.44647838223366, 42.82049555932322, 48.185168312441924, 50.57004782461351, 47.650717919872655, 46.402533438897905, 48.31911333145634, 53.1174389777645, 54.98891945808165, 62.40339932903167, 64.40901310213151, 53.40686675040953, 10.135172124831907, 1.8956846912061016, 0.08459441634195466, 0.05346207398801081, 0.2267913054674864, 26.9594229421308, 58.36902979881533, 43.209174986808534, 38.70982416214482, 26.122424448690108, 39.88426808388003, 47.631055078198834, 54.20814421869094, 22.35918679545003, 0.18746350771717488, 0.03203669191157866, 0.030893818963499322, 0.03621512122692601, 0.04439967136169153, 0.019507352638268666, 0.06215581595296822, 0.03656760977220632, 0.022484450751254638, 0.04518651260784076, 0.03200943641845257, 0.07600912944443765, 0.025577994228731242, 0.043532697318662564, 0.04456572474971895, 0.03635418533738102, 0.0626080759590672, 0.01921247773533387, 0.046414804359477375, 0.046417179232042645, 0.051323953234860976, 0.006907137304229001, 0.0295288801088088, 0.024850980619028695, 0.02673072289795645, 0.016442028009482933, 1.1824553628121655, 25.300552575818955, 52.907611785396455, 53.023706097756666, 46.689207707681966, 26.65923610810311, 20.65865497435293, 55.019423730911754, 45.2996963070285, 56.49823965564851, 12.498270715436629, 0.13217975325401754, 0.04494344440078543, 1.4319883407123628, 5.0224837083970355, 6.634548431442631, 16.995678986272505, 44.06306712858139, 56.60226875735868, 58.42173468682074, 56.44743319480651, 55.81497846111175, 56.48538997096401, 54.57437199930991, 55.04407190507459, 54.840963732811716, 54.71152551712529, 53.21766338040752, 53.02989167551841, 43.751878046220355, 38.65451482034499, 39.8918657149038, 41.46916058755691, 38.149227250006895, 38.435866217459406, 41.81234444341352, 48.87175959925498, 49.93168207906908, 49.14718451038484, 50.76531125653175, 46.43395162397816, 44.47394717124201, 40.414094002016135, 38.65021198026596, 40.44761849987892, 38.852045382222826, 38.83312386851157, 39.548273932549264, 39.62041024238833, 36.86752219353953, 38.9897794108237, 37.24875696243779, 37.3314993612228, 37.73933956699987, 39.03875020242507, 37.0558665644738, 38.82584787184192, 37.626167420418035, 38.51126986165201, 37.00376179910476, 37.218727296398534, 36.70795233018937, 42.86253944520028, 47.84407900225732, 50.33187366301014, 48.633950218077636, 50.35927534103394, 48.401690990694114, 47.932081299443404, 49.74431830067789, 50.331073499494984, 50.38886177924372, 49.606195957429954, 50.68272183018346, 48.80518521032026, 40.94851693799419, 36.394955035178896, 50.02232413138113, 52.39534631852181, 51.662706405885764, 49.950254501835, 49.68416483171525, 49.06171606433008, 48.307397211751635, 48.49326656710718, 48.49622795658727, 47.86203561290618, 45.42904038583079, 40.92850500537504, 41.279670884532315, 38.953348436663234, 39.71442553304857, 38.28579241229642, 38.792076264658284, 39.179567213981386, 40.03291806867046, 39.903621058310236, 39.45065006133049, 39.38334218917355, 39.158229520243985, 41.16083483542166, 41.58035585957189, 43.31866010542839, 50.906704856503396, 49.114083628500666, 47.747129778708185, 40.689577748698575, 42.01514274843278, 48.01693001101094, 52.556732239261756, 54.72500670340754, 55.20886636549427, 53.68200140614664, 52.93244431095739, 47.38540487904703, 39.326954195576334, 41.944873486795736, 45.460223228700706, 54.03443028849941, 57.20180696056735, 56.249047556231105, 57.08252376125705, 58.4013383619247, 50.19888570231777, 44.88649422122587, 45.77623682637369, 50.531690966698434, 50.63108382686492, 49.3798634313768, 49.258203275742076, 51.590754447444795, 56.820438831083244, 58.98369658377863, 63.83905741476244, 64.50691938400269, 52.706562857474054, 10.745775334296688, 1.175440326333046, 0.7261089824380413, 0.0347682339469752, 0.20437934195562718, 29.368838840915313, 63.57494069683937, 49.41571781712194, 45.95548522087836, 36.06150257971979, 46.99397194770075, 53.935488500902736, 62.310207736107614, 27.36591777493877, 0.6683488947249229, 0.030097491633627686, 0.041901837854135426, 0.08354738099320282, 0.06357004107426732, 0.021270461861164342, 0.013351056672212099, 0.0423595026105402, 0.022400020201119687, 0.03993489944766607, 0.037779281246325666, 0.08562359418119155, 0.10335059295738898, 0.1542296482911033, 0.15032571019424548, 0.18397307323832668, 0.14081796150534384, 0.13096662238240242, 0.14298018338459154, 0.16625756578099343, 0.13790034628923864, 0.15074600135126423, 0.16540938387474707, 0.12478368762399882, 0.1610090974117479, 0.13828501435777835, 1.2685751674636718, 30.119578530711514, 62.53067239638298, 61.84154333606843, 52.52442367615239, 33.684761985655754, 23.46340656280518, 62.92112081281601, 56.188862708307084, 61.047973325175626, 15.626839457019685, 0.3061715741792033, 0.21060172258125198, 4.645487060469966, 9.90860817893859, 7.402601953475707, 21.19480179202172, 46.02036906826881, 56.75776720046998, 59.99854318557247, 58.94243717193604, 58.62991448371642, 58.41935380812615, 55.426918768113666, 57.044570907469726, 57.533796371952185, 56.075980817118, 56.15989208221436, 56.31635935075822, 48.13173386358446, 41.01993545409172, 41.738192035305886, 43.23601968826787, 39.489081444278845, 40.96142938060146, 44.49109969600555, 50.39529838869649, 51.52080682016189, 48.77684216345511, 52.53663009212863, 50.061116372385335, 45.13064607497185, 43.67749421827255, 40.621242215556485, 43.493837079694195, 41.260914110368304, 40.69789317346389, 40.63592364711147, 40.54250455671742, 39.280101483868016, 39.96963454831032, 40.06929020727835, 39.78853479508431, 40.3143245943131, 41.89070555471605, 38.61103926935504, 40.874933273561545, 39.30689519451511, 39.12701922078287, 39.16877677363735, 38.80237640873079, 39.77851313929404, 45.84345448401667, 49.535306961305686, 52.343543575656035, 53.04840134036157, 53.74943087177893, 50.84978342056275, 49.29385369823825, 52.570535059898134, 52.72474304322274, 51.41733861738636, 51.50479178274832, 53.16327579559819, 50.07991629262125, 44.25626347141881, 38.980302964487386, 51.12709891411566, 55.24838032261018, 55.40800902151293, 54.352934591231815, 52.758600942550174, 52.05739098210489, 49.44430797330795, 52.71294847611458, 51.575547418286725, 49.92069552021642, 47.25650795044438, 43.19552513860887, 44.64701391035511, 39.629463072746034, 40.477601097476104, 40.16569422137353, 41.23469306576637, 41.69522247006817, 42.60168613926057, 41.80728850826141, 41.145996509059785, 41.3051623682822, 41.563850525886785, 41.69090001813827, 43.021517030654415, 44.802206408592966, 53.41249927397698, 52.732446578241166, 50.34508028338033, 43.28848138932259, 45.775534722112845, 51.43961767996512, 54.12522531324818, 58.05462045054282, 60.06785538888747, 55.194820357907204, 57.19120871636176, 53.43191108395977, 42.1357556312315, 41.8026993351598, 47.203120570028986, 57.751323176968484, 59.91254521954445, 58.1816150296119, 57.80235713528049, 61.44352082283267, 53.43184832603701, 48.64687050542524, 49.55915889432354, 53.74213526325842, 53.103024267381244, 52.7500815545359, 51.39025465134652, 54.043459584636075, 58.33594852878202, 60.75536843269103, 69.11152701224051, 68.95162766979587, 55.544232937597464, 11.82775624336735, 5.640835069840954, 1.8855274684967536, 0.11876714716274893, 0.4894765268170065, 34.41891201080815, 69.85775009278329, 55.17126652502245, 54.56834331635506, 38.595200738599225, 54.00531061234013, 63.23716971182055, 70.15370076702487, 35.54151396597586, 1.3781589582081766, 0.13565538691416865, 0.245108513702308, 0.2062931521645477, 0.22877115245547988, 0.13624725112270925, 0.14911826369502854, 0.1842727515125467, 0.10267237531802348, 0.09514969067587968, 0.17344486479076648, 0.25292778928433696, 0.19673102655478064], [0.03502750874406869, 0.038840044890680624, 0.024257440593153722, 0.03786996690436237, 0.07956452817926485, 0.07831374408617135, 0.046508504573496125, 0.021545066077622677, 0.11155120412548704, 0.023417189612143466, 0.07286470623746996, 0.019131349024152564, 0.04463922705561404, 0.08417619362233147, 12.983356118202211, 42.073790027249245, 50.17415908075149, 40.79389710580149, 27.952735731678626, 24.401272727597146, 34.29554170177829, 47.14295533395583, 52.41171436925089, 13.514482302050437, 0.1474053983486468, 0.1333149883054918, 1.2839457104282996, 3.2613995623204017, 6.641527308571724, 24.392115954429876, 45.277970298644036, 61.08055253182689, 53.46209372243574, 53.03361400481194, 51.58944437580725, 54.38600409415461, 52.42723911039291, 54.987115167802386, 51.80878723821333, 53.24839907307779, 50.51590734912504, 52.14948038901053, 47.71447996939383, 38.25047931363506, 38.35581848698278, 40.99246709577499, 37.10244078789988, 38.464660336894376, 40.56499934965565, 48.42067133995795, 49.46223712736561, 47.01549399283625, 49.07663283809539, 46.95739192347373, 45.67986026886971, 45.804003284823516, 39.55842502655522, 36.932868880610314, 34.96532955477315, 36.057521373994895, 35.81724482197916, 34.9600657340019, 35.51153136837867, 35.62475058340257, 34.03082878358903, 35.655925581532145, 35.35816669464111, 35.14404058456421, 35.30208464591734, 39.29202548919186, 37.14167625673356, 35.51058607716715, 35.393299364274554, 34.68856711541453, 37.73136538843955, 46.1170986390883, 50.22472235464281, 51.16349066457441, 53.68305260135282, 49.565317015494074, 48.73202123949605, 48.352037706682765, 47.78885987497146, 50.55261681156774, 47.80383940665953, 51.14755015219412, 48.274519904967285, 51.674614721728915, 43.59557159485356, 40.605352693988436, 50.81070092416579, 48.52475143248036, 47.02953607805314, 47.826447948332756, 47.072764519722234, 45.31436204910279, 44.95384131708453, 43.28332739491617, 39.98938368212792, 40.80067496145926, 37.65516158073179, 36.2590802100397, 36.981216015354285, 37.3434429783975, 35.59561914013278, 38.197664599264826, 38.23372294825893, 38.389711687641764, 35.763147492562574, 37.57284672029557, 37.92285550025202, 38.44254209149269, 36.969986269550944, 37.628552221482806, 40.954784885529556, 44.099027418321185, 47.7441801563386, 45.877547725554436, 41.596225769289084, 43.49894008328838, 44.354883624661355, 50.62296452060823, 53.14116147256667, 49.121928368845296, 47.207027250720614, 45.32536429743613, 49.42913624548143, 55.260657341249534, 41.17592419347456, 37.50068687623547, 40.225635882346864, 42.50633724274174, 51.70063572545206, 54.06247131286129, 55.40583995080764, 53.922332871344786, 51.10341172064505, 43.66326385928739, 50.04948654482442, 57.78984085206063, 57.70203467338317, 55.639346491905954, 55.48317732349519, 55.752357821310724, 54.920368194580085, 59.240537305032056, 60.53613147427959, 61.523305754507746, 44.229979668894124, 10.014984819196886, 0.4866453416405186, 0.8077631686483661, 0.16580439413026457, 0.10820005209215226, 27.930909702854773, 55.81717498840825, 41.25141020744078, 33.29341534645327, 32.76722938783708, 39.48517084121704, 47.697374513072354, 57.37114744801676, 16.78746977160054, 0.16225700867512535, 0.11756398309502872, 0.05806360791827883, 0.04515012726187707, 0.04636982733744287, 0.052528863983048554, 0.04711488614820185, 0.024244694805313504, 0.08357462307979023, 0.06900231308874584, 0.01249460676204293, 0.015712142527674236, 0.020183159015892495, 0.01932597366131602, 0.03412276656637269, 0.04919226378983548, 0.09693855194435005, 0.04343575272228449, 0.029017250203797897, 0.043979418509068995, 0.028942893709867235, 0.012420465730340972, 0.021948895920368455, 0.07902040657016539, 0.06367925839919238, 0.05454783508133504, 0.07168158302984892, 15.836134187636839, 49.39656488357052, 55.71408333316926, 46.177185427758005, 26.48937002305062, 21.6155917029227, 43.6354071863236, 52.570244804505386, 57.07173332091301, 15.475019216537477, 0.25886392881793363, 0.0709200686504764, 1.80123585606775, 7.2916361401158, 4.884538362103124, 23.686430569617983, 45.940050694250296, 60.84635173120807, 56.02190309955228, 54.72701103456559, 54.76594055852583, 57.14286550398796, 53.7847988836227, 57.06228040879773, 52.83447134879328, 54.26070397899997, 52.404767851675714, 54.439473844343624, 49.828351159249586, 40.69991319410263, 39.61275377581197, 42.29158355343727, 37.88564397442726, 38.94171076436197, 42.210104157847745, 50.42813254940895, 51.19388903340986, 47.79015425712832, 50.77658414840699, 51.37646752019083, 46.62580651621665, 47.60716392147926, 41.4851991591915, 39.09546767511676, 39.37998856267622, 38.052831080652055, 37.147359771113244, 37.688831206290956, 36.656463376937374, 37.49874530300018, 36.421999777517016, 38.90599366157286, 36.88382748634585, 37.98868071648383, 37.379536628723145, 40.995726585388184, 38.90529155731201, 37.44113745227937, 37.783450541957734, 37.45611698396745, 37.464377495550345, 48.122449613386586, 51.90214749305479, 52.55179397521481, 56.82851499126804, 50.61210347760109, 50.759816015920336, 50.57366424991239, 50.902939381137976, 50.45889177630025, 51.19527363008069, 52.84907433294481, 50.455883318378085, 51.92641519731092, 44.71540435667961, 41.541100778887355, 51.12802067110616, 50.899464161165305, 50.354015442632864, 51.771014813453924, 49.84406025178971, 48.832469217238895, 47.39024900620984, 45.83461738401844, 42.309959857694565, 42.45940216125981, 39.66239921508297, 37.65520472680369, 39.459757804870605, 39.490579789684666, 38.29398232121622, 39.43790235827046, 39.90381325444868, 39.796885521181174, 37.30584313792568, 41.017366301628854, 39.19871230279246, 39.32211791315387, 39.19027528455181, 39.553020000457764, 42.356271282319106, 46.160978194205995, 50.23515585930117, 48.47135620732462, 44.51288061757242, 44.71542396853047, 46.00686434776553, 51.59012294584706, 53.55671698047269, 51.30962641008439, 50.39064253530195, 46.12325676025883, 51.22537389878304, 56.058694931768606, 42.705079817002826, 39.3446833087552, 41.6082949023093, 44.89090688766972, 54.91215475143925, 55.28410527013964, 57.05733037764027, 56.88748782680881, 53.95277830862231, 46.49707824953141, 50.33842402119791, 60.296015739440925, 59.68685988456973, 57.6554290709957, 55.506793914302705, 57.435313501665675, 55.79954393448369, 61.06946006897957, 63.50477341682681, 63.33195770940473, 47.46691173122775, 9.503907830484453, 1.3877273350954058, 0.9146257537987925, 0.13902615845924424, 0.09224960355148201, 31.221352700264227, 61.282684033916844, 45.78387368109919, 36.74393223178002, 36.55742745245657, 48.53271776630033, 56.72522721752044, 66.87307742334181, 21.477624293296568, 0.34810756423300315, 0.06924822731243988, 0.02556556445215979, 0.04203288485446284, 0.08202432159094081, 0.0698221957070693, 0.040520213604454076, 0.021693041705856883, 0.046767285243878444, 0.04338542840653851, 0.11006474840424715, 0.03705244000640608, 0.13897449348963078, 0.13243423234070503, 0.20517215102670655, 0.17565622354947752, 0.2711674540994629, 0.13981711359754687, 0.117578316600092, 0.1385423892568196, 0.1340217657026745, 0.1380879765436534, 0.10746998562207145, 0.2007086316664373, 0.13749370681903056, 0.11391470794596019, 0.1626751854294731, 18.69497722195041, 57.43149311311784, 62.7391581381521, 51.92783509531329, 36.69264331940682, 34.005470660425004, 46.21657779139858, 55.96640548398418, 63.5709124226724, 18.565501743747344, 0.37169458404664074, 0.2637609773345532, 3.516903981085747, 9.736628916955764, 11.45875338585146, 26.50975654202123, 48.35099435621693, 63.62813588111632, 58.554475538192264, 57.167286180680804, 55.42293364001859, 60.02974171792308, 56.598942587452555, 59.49420090644591, 53.93330374071675, 56.28549421987226, 53.33166706946589, 56.7598460566613, 52.59816423539193, 42.527780840473795, 42.53033822582614, 44.50685977935792, 40.3794986970963, 42.086894665994954, 44.35718997832268, 51.56793017541209, 53.28511638026084, 48.107474004068685, 52.05557884708528, 53.42520383096511, 48.814500839479514, 51.06023034741802, 43.03338612279585, 41.51061219553794, 41.33820833698396, 39.990246603565836, 38.675636783722915, 38.31956794185024, 38.86611100166075, 38.891571106449256, 37.60335883786602, 40.77975303896012, 39.120935624645604, 38.836179394875806, 39.82178080466486, 41.96814883139826, 41.03816270828247, 38.31427666448778, 39.58994911563012, 38.7138367468311, 41.68034884237474, 51.03143622798305, 51.63658734290831, 54.71795428183771, 58.56945899225051, 52.31636547273206, 53.18345246776458, 51.91729568666028, 53.982572632451216, 55.55012433759628, 52.654913087044996, 55.234930515289314, 52.11159029314595, 52.47065582583028, 47.72154415807417, 44.279648642386164, 52.66462095322148, 52.191465439335, 51.75143041918355, 54.19165065211635, 51.872255109971576, 50.241392427875155, 50.72334974042831, 48.47578064087899, 43.963788017149895, 45.57889453826412, 41.16310588775143, 39.911430497323316, 41.09040083423738, 41.73891375141759, 39.82888421704693, 42.94410905530376, 41.73961193330827, 41.99587214377619, 38.68128891914122, 41.49629162203881, 41.833878255659535, 41.67838765728859, 39.13675846592073, 42.06642773843581, 45.14863798695226, 48.554726185337195, 53.989366177589666, 50.626337758956424, 46.25185166635821, 48.162704898465066, 49.10238712064682, 54.284944226664884, 57.6104316403789, 55.85466500251524, 52.886768310300766, 46.86732645957701, 53.34624259702621, 59.95143944217313, 45.06159274808822, 42.08297229582264, 43.92898090424077, 45.577592311366914, 56.37441827404884, 57.63921791507352, 57.49005017742034, 59.2275817163529, 55.9566976178077, 49.759674379902506, 53.48237629859678, 63.287077949893096, 61.60236112533077, 61.398084086756555, 59.50347338953326, 61.42950619420698, 58.43938927496634, 65.35983485560264, 66.58837610675444, 67.10676439346807, 49.120414333958784, 12.572290743550948, 1.7021551920521645, 2.9252193435545895, 0.44697684926852105, 0.37085942563510715, 34.90686662735478, 68.54599968079599, 52.62282417666528, 48.26270964837844, 44.30517150509743, 53.24808528346401, 63.16757117548297, 74.50927319065218, 27.996919270484682, 0.9543261460719571, 0.29753169585620204, 0.1963879110952539, 0.15215100660439462, 0.25782198795387823, 0.23514725628399083, 0.18193226097331894, 0.14466393738985062, 0.1828236808820117, 0.10636756977727337, 0.17004226995331628, 0.10666034559929564, 0.2543785453083054], [0.0355333604309107, 0.04933274899339003, 0.04060490462448328, 0.029264434218226425, 0.023242699680849913, 0.011466708289639605, 0.06371009726858427, 0.0916616770348722, 0.04529964081161926, 0.05750337931057138, 0.01918621241084991, 0.09796345501296944, 0.032196013301971464, 0.11369396737145801, 6.826819585215661, 36.4549437645943, 51.11693605299919, 47.54602593760337, 35.28635594152635, 26.816893815994266, 25.900426141677368, 30.038712986053962, 53.24667323020197, 16.984019740935295, 0.21480006826741083, 0.04407596857016606, 1.0837485497036288, 4.125806352784557, 3.7550462734314705, 20.346030304508826, 47.90251447308449, 57.305369300227014, 51.452353615914625, 52.1686254778216, 46.38112906486758, 47.72703547631541, 48.81844282150269, 50.778537488752804, 50.29947096301664, 52.374675427713704, 50.752508640289314, 50.44970950772686, 45.423874624313854, 38.551948762709095, 38.306757480867454, 39.641320397776944, 37.5382867167073, 38.53007370425809, 40.3899125899038, 45.47415548755277, 48.62829808265933, 50.14237219287504, 46.212573051452644, 48.69572754829161, 45.62336637127785, 47.28904401102374, 41.96062964777793, 39.4509599285741, 37.00158488365912, 36.5927170168969, 35.1530110451483, 37.13065831891952, 35.121737987764426, 36.03804288371917, 35.994288844446984, 37.361583940444454, 35.04672658058905, 37.04892004689863, 35.491746933229514, 39.18294437469975, 36.31811188113305, 35.660436307230306, 35.608272706308675, 36.27986877195297, 38.11623619448754, 49.36045554376418, 50.134727493409194, 49.681070081649295, 39.90530375511416, 43.09833272810906, 50.172648968235144, 48.362561425855084, 50.02609352911673, 48.9119952724826, 51.24172626003143, 51.101819238355084, 51.57117005317442, 50.87378440364715, 48.719838357740834, 45.13965183688749, 49.97091362553258, 49.949976013552764, 50.314579932920395, 48.729726652945246, 45.41537484815044, 44.7840379899548, 41.291457606900124, 42.718207989969564, 40.45860505873158, 40.21737929313414, 37.67647574024816, 36.92030945131856, 36.84242294680688, 37.961483001708984, 37.14218224248579, 36.83519009620913, 38.73050289769327, 37.717107572863185, 37.52857885053081, 37.31402127973495, 37.16410044700869, 38.47958495540004, 38.23609990458335, 39.33051178532262, 38.158660550271314, 43.606868020949825, 47.91119467827582, 49.412419103807025, 47.03830649775844, 46.57504320144654, 49.16255627909015, 47.737076743956536, 49.47071336930799, 51.66997455781507, 52.53417861077094, 56.28607473065777, 54.42925214767457, 51.656626732118674, 50.66924456627139, 39.19388778748051, 38.15333789394748, 39.29147243499756, 45.23105482901297, 51.25264613859115, 52.375318696421964, 54.78531706717707, 55.36955802671371, 47.23398570091494, 47.11966822224279, 56.85823871243385, 56.65080808824109, 58.98560677805255, 56.993160401621175, 57.564975292451926, 59.558398339056204, 59.12448613874374, 60.70156528103737, 58.61961433964392, 38.03275246773997, 3.7072173818465206, 0.6178816576157847, 0.4328150704743401, 0.14544723164891044, 0.12090575055129106, 26.43880282678912, 57.900969443782685, 49.71511233237482, 39.79884670626733, 33.234313072696814, 37.769879141161525, 43.21569004366475, 52.25154046089419, 18.100838161283924, 0.3386666950198912, 0.03350886583869015, 0.03388712941218288, 0.07580939500081925, 0.05630054466065861, 0.10128974749316132, 0.032294241095622706, 0.03307076313743188, 0.08208301924769917, 0.05273283489288823, 0.0822206699259339, 0.008178198308263334, 0.0855003459559333, 0.036139615601108926, 0.054173742856590025, 0.10278007195841882, 0.02848562348874346, 0.0508269498635444, 0.03905302882494946, 0.06636774437802453, 0.08064615239779796, 0.0313988222079652, 0.031185311588248422, 0.04297528025363723, 0.03744420204912463, 0.034666271474693096, 0.06370162050570212, 9.617475155861149, 44.67603160488991, 59.163698073356386, 50.87456495531144, 38.16157879367952, 20.887691974639893, 32.3758670591539, 40.880318687808135, 57.68985179162795, 18.893072605133057, 0.08402311393330175, 0.012460611610402985, 1.8087614135396097, 5.823148306339018, 4.177260495001271, 20.41822937227065, 51.98263845136089, 60.44069628561697, 53.187492509042066, 54.63459607093565, 47.21784514765586, 50.65596342086793, 51.71218710560953, 53.912083718084524, 51.08076787764027, 53.00125445089033, 51.7824524448764, 53.29498898598456, 47.39401448157526, 39.48235457943332, 40.66910297639909, 42.0771122747852, 38.438113735568145, 40.08373629662299, 42.48799623981599, 48.62264594724102, 49.422546663591945, 49.40393893949447, 48.51136046071207, 51.494836807250984, 47.722030531975534, 47.74505092251686, 45.070469071788175, 40.462194027439246, 38.4422283018789, 39.9280809587048, 36.46060374475295, 38.39171209642964, 34.950930533870576, 36.86074433788177, 37.55796917023198, 38.65049439091837, 37.8164533645876, 38.98811632587064, 37.93553652301912, 40.64852230010494, 38.060997455350815, 37.34334884151336, 38.024609627262244, 37.47708205253848, 39.44810836545883, 49.68680066447104, 52.08785603123327, 49.887508346188454, 42.561568137138124, 44.456006250073834, 50.649530733785326, 49.91882062727406, 53.03191561852732, 50.32382495941655, 52.93154608818793, 52.369019369925226, 52.69824351033857, 54.61530977679838, 49.353320752420736, 45.707289403484715, 52.981740659283055, 52.50903621796639, 49.825464294802764, 48.47510207083918, 47.891665197187855, 47.03403111427061, 43.8799669665675, 45.88335675577964, 40.95878962547549, 41.3662140600143, 39.41948683031144, 38.087653883041874, 38.009900739116055, 39.83729770106655, 39.46426068582843, 39.15051814048521, 39.390582884511645, 39.39425030062276, 38.38287499643142, 39.148082348608206, 39.29070757281396, 39.4275826023471, 39.122273152874364, 42.11286075653569, 41.17589673688335, 44.68656709117275, 48.71736726453228, 50.838188894333385, 48.83788601044686, 49.03723262971448, 51.89701703286941, 50.743648006070046, 52.10059196718278, 54.488640754453606, 55.15934251969861, 57.2994347541563, 53.37538580740652, 54.36431730947187, 53.46270168981245, 40.34390318778254, 40.28070203719601, 40.0756719035487, 49.87128542315576, 53.585746442118, 54.48822106084516, 56.03807895414291, 56.328330424524125, 48.51835012435914, 50.732700670919115, 59.63814404702956, 58.586584060422844, 60.95396195688556, 59.28751945495606, 59.32241678237916, 61.17832937548238, 61.14589137415732, 63.51630126276324, 59.41868351351831, 40.43294883543446, 4.978091303379306, 0.5906292748066687, 0.639103151136829, 0.04616597517123146, 0.12826687491108335, 29.391998475597752, 63.28619541660432, 50.78363264760664, 49.49318462802518, 42.49011431970904, 40.43288999988187, 50.752312521780695, 60.766021590079035, 21.808968474788053, 0.8911727380848701, 0.11133679143723943, 0.05152550713729955, 0.08430313439138475, 0.018051745362519737, 0.05255149805077142, 0.049396824587376854, 0.11191280528662667, 0.07286777825004633, 0.05891976479981696, 0.09601421323755095, 0.06691542063509265, 0.09325036718960732, 0.19933275307618803, 0.17407912430503678, 0.17854583059107104, 0.14473993331193924, 0.11503006301579938, 0.20524828484462154, 0.32425642794659065, 0.21279006805871764, 0.10623551154088591, 0.14105138849587212, 0.18963714430649437, 0.11963431272775897, 0.08404296327141986, 0.19903471423012598, 11.251055059894439, 51.58039154544954, 64.68785439768146, 61.653595124521566, 46.83887358634703, 35.61576835570797, 37.46447947717483, 40.39277984249977, 64.62055044789469, 20.794270923060758, 0.27225811815550255, 0.23015899733910639, 2.764779449470582, 8.827860855287122, 6.700343739601874, 23.500333716792447, 52.508647903319336, 63.59148917659637, 56.03270922937701, 56.72264629794706, 50.289104138651204, 52.2983931726025, 53.314377261746316, 55.82705151650214, 54.63743586694041, 56.13531451071463, 54.34449757299116, 54.05507764508648, 50.6452984963694, 41.72507562944966, 42.72329530408306, 44.623499301172075, 39.12085325487199, 42.37724811800065, 44.35570340002737, 49.20973846989293, 51.64749153198735, 52.433577660591375, 49.20698496603197, 53.23534934751449, 49.38446044921876, 50.82742983295072, 46.190042957182854, 43.51942662269839, 41.14085428176388, 42.201008181418146, 37.76508208244078, 41.347327847634595, 37.64948198872228, 39.428214103944846, 39.5174519477352, 41.68566365395823, 39.95337632394607, 40.74506751952633, 39.21339373434744, 44.36202626074515, 39.89060663407849, 39.27820697907479, 40.92441397328531, 40.38023218031853, 41.387975369730306, 53.39356599315521, 53.84727439572735, 52.631500459486446, 40.69448855615432, 45.20661846283944, 52.33300416700302, 51.18608351676695, 54.677785288903024, 52.985682641306234, 56.6685881922322, 54.16365669619653, 54.74021373256561, 54.44292160772509, 53.5131198360074, 48.18312475758214, 53.65486644929456, 55.14218999493507, 53.25100744924238, 53.84475623407672, 50.43357287683795, 49.68927960241995, 45.01473219163957, 47.87459111982777, 44.43949699401856, 43.762790080039736, 42.537159227555804, 41.05003572279408, 40.09959443922966, 42.256470495654696, 40.6169197636266, 40.48066446858068, 42.9377705051053, 41.435506651478434, 41.925175343790364, 41.07309925940729, 40.092424346554665, 41.69858786367601, 41.89733043793709, 43.837079771103404, 41.29949062101303, 48.35618757432508, 52.11970959940265, 53.96644384630265, 50.66505155255718, 51.59696355942757, 53.80065702622937, 52.55710094205795, 54.23693833812591, 57.95933431194675, 56.19517772428451, 60.79630228780932, 54.785324911917414, 55.913877102636526, 57.03442373583394, 43.749297126646965, 42.32740656022103, 42.200815985279704, 51.39475753230434, 56.35313549349385, 57.120237350463874, 59.0403316866967, 60.522081544322354, 52.59632464378111, 52.54108982701456, 61.65176337765109, 62.70945795120732, 62.65245806786322, 60.65332012791788, 62.783665272497366, 65.18466572607717, 65.01451723037228, 67.28736600568219, 61.03566100520473, 42.54764764539657, 4.690355543167361, 1.8542758615747577, 1.2400019264990285, 0.2159470857511605, 0.4290890026717417, 32.09064995088885, 70.07212331218105, 62.048734695680686, 54.05263008609895, 44.014147327792266, 49.33987878984021, 58.90889306222239, 69.41694628807807, 30.541943273236676, 1.7489824083543595, 0.1825431394841402, 0.14766873341173897, 0.1409378849090107, 0.13242600455639825, 0.22087361333110642, 0.12822977327291044, 0.18989919234187375, 0.1649680252998106, 0.11025635465498894, 0.24004376853906342, 0.18335876265360465, 0.15417980661074962], [0.13122821076502725, 0.0730141929741348, 0.05300386147874017, 0.06981049754446553, 0.03858493761189523, 0.08020700781696266, 0.13583049929190066, 0.02692882940473576, 0.026549776760681022, 0.09301253519351445, 0.057258016670182835, 0.04237409275505812, 0.09507153438584459, 0.018824973226254507, 3.8599150075066477, 29.168390035629276, 49.62016743998374, 46.474328502531975, 32.40938371227634, 34.77235286466537, 34.63049250264322, 39.842475229694, 51.693850025053955, 27.7028376056302, 0.43663490743887046, 0.053618819407758214, 3.0383297128062097, 13.416708400172572, 0.8306696265935899, 19.900280391016317, 45.00759347792595, 57.645117159812685, 49.04844668603713, 50.09041647757254, 46.12121712776923, 44.36121825248965, 40.028434799563506, 44.605668206368726, 44.0789762620003, 48.25083271149666, 47.14585396551317, 45.505259883019235, 41.86209186430901, 39.566975793530865, 37.55865166264196, 39.33193952806535, 36.17516502257317, 39.97993077001264, 41.7542855201229, 44.33114151800833, 46.42894275726811, 48.15950816677463, 46.967539095109515, 50.095472412724654, 46.85704984972554, 48.91550187141665, 44.59091617215065, 41.20370634140507, 37.991787233660304, 35.43256228969943, 36.27333802561606, 35.926608347123675, 35.28077440877115, 36.376539507219874, 36.2039356077871, 36.94542830990207, 34.71854579064154, 37.22940791037775, 35.876178433818204, 36.15814978076566, 36.65397267187796, 36.53422271051715, 34.62338516789098, 36.598890827548125, 38.31449239484726, 48.24313309884841, 50.203435651717655, 50.462037517178445, 45.71989590121854, 49.46771667849634, 48.85390889260077, 47.75093447777533, 46.549277151784594, 45.620322612024125, 48.610957284127515, 51.161364739941014, 51.00628991280833, 52.075520177041334, 49.838674837543124, 47.47174801365022, 51.311211047634, 48.67454282699093, 47.00708050881663, 46.96014934970487, 45.825988169639345, 44.64032234684114, 43.34474778944447, 43.29736555776289, 39.81199449108493, 37.98027507720455, 37.27498192940989, 37.04600964823077, 36.82606274081815, 37.210682515175115, 38.00506445669359, 37.58342535265031, 38.54935999839537, 36.88871868195073, 37.16013493076448, 37.019263006025746, 37.90207478307909, 37.53072438701507, 37.31152665230536, 37.18680704793623, 37.58666915278281, 40.45471406752064, 44.92011677834296, 48.063880781973566, 48.175880139873875, 48.219575343593476, 47.583072723880896, 46.4780939778974, 46.11763208143173, 48.97751062147079, 51.40133926945349, 50.05151048783333, 51.90510496016472, 51.14833854859876, 54.17547871989589, 47.10134290879773, 35.894182112909135, 38.46668820227347, 38.51350561265023, 50.952573053298465, 54.157114182749105, 55.82840473421159, 55.69622478177471, 52.8852621201546, 48.17845321470692, 55.396794965190274, 59.353732985834924, 57.606623018941576, 58.375960626909816, 56.7665062412139, 62.371549683232466, 59.40442177557177, 64.82093649525797, 54.30493262506301, 23.04909052387361, 1.3841579782385982, 0.8220502181399254, 0.5938687848467982, 0.0372864683759549, 0.0852675394966237, 25.862079089687718, 58.097166399801935, 47.046288521059104, 27.902184224897816, 22.18528066912005, 48.33531664263818, 50.55505652581492, 47.4262563643917, 21.33701908972956, 0.6686067292767187, 0.009190156406182195, 0.05190364430628477, 0.04042771231803683, 0.059404139211701776, 0.03794067681977346, 0.06669144716955001, 0.05346038093369815, 0.019374848155665304, 0.03497168774746599, 0.029736401836177515, 0.05094454052948183, 0.026477888985086354, 0.07880642289115537, 0.030491188048355045, 0.05585943123385791, 0.04115048180063886, 0.06399236236428542, 0.026296856662919445, 0.06828661842812454, 0.025111973368292375, 0.026279045118679924, 0.0547709888327987, 0.15184357552038086, 0.030057716348599044, 0.07656899416038106, 0.03933264708687221, 5.306678548935921, 36.147308349609375, 55.84186630864298, 52.23580783413303, 38.21577418235041, 37.30584706029585, 33.87993128068986, 41.022139826128566, 58.82199295105473, 28.75069683597934, 0.2699367491708648, 0.05490259890775046, 2.067652431226546, 12.124041299666128, 3.655368305983082, 22.15004405667705, 47.10721861931586, 56.73658640153947, 49.91134458972562, 52.232293390458636, 48.89190881483017, 45.66518668205508, 43.12141195420296, 46.74747059422155, 48.22836929751981, 49.57517000936693, 49.33519155748429, 48.27729694304928, 44.32262605236423, 42.30873215583063, 38.837677740281634, 40.001378290114864, 38.232573693798436, 40.48584199720814, 44.56595420837403, 46.910743175014375, 47.666011241174516, 50.825386278090946, 47.48439373508577, 50.31643913638208, 48.58808594365274, 49.74139613489951, 46.99396802533058, 42.626173496246345, 39.182242270438906, 36.82963602004513, 37.39524572126327, 38.120754764926055, 37.136200627973004, 37.193800633953465, 39.11024716592605, 38.98919497766803, 36.95364959778325, 37.64209616568781, 37.37070345109509, 37.589689377815496, 38.807404887291696, 37.94187899558775, 37.543550537478545, 38.439510099349484, 39.01079939257714, 49.07407153037287, 51.11294700253395, 50.91481239564958, 45.400022691295995, 50.24761330696845, 50.454514411187944, 48.48507665818738, 47.70619200121972, 46.44371832570722, 50.87262730444632, 53.19605504312823, 53.674572437040275, 52.54518870384463, 51.52798475757722, 48.63965334430818, 53.5198780798143, 49.393289704476636, 48.204580122424716, 48.44604123023249, 46.52425635245539, 46.836304433884166, 45.06384026619696, 45.43033084561748, 42.47658606498472, 40.698352090774044, 38.29972859351866, 38.877991860912694, 37.99649800023725, 39.093545713732325, 39.22702004832607, 39.21728472555838, 39.63888068352976, 38.9001218734249, 39.837552655127745, 39.07710706034015, 39.917655298786784, 39.45687486279396, 39.19724141397784, 37.96941795656758, 39.345726659221036, 42.07193866852791, 47.839442760713645, 49.452360599271714, 50.120340239617136, 49.75976851678664, 50.77829822417229, 47.83073117656093, 48.481699497469016, 51.29201496801069, 52.42280290972803, 52.44886313715289, 52.577767910495886, 52.84607371976299, 57.39656440673336, 49.33558771687169, 38.87847823481406, 41.002582888449396, 41.78660585034279, 53.893326943920506, 57.162775454982636, 57.4358194874179, 58.241678284060576, 54.057662487030036, 50.153660774230964, 57.26573767200593, 61.01207579335859, 59.9993472714578, 60.22951587553948, 57.502386031612275, 64.6684229758478, 60.506176333273615, 67.72631060692572, 57.33638740354969, 25.274374677288918, 2.496360626912886, 2.5983579408737922, 1.4196421902987266, 0.024880858048075633, 0.08854648774309505, 28.8860107621839, 61.779032522632235, 53.83280477216167, 37.9110138647018, 23.23009810140056, 49.041617839567124, 56.62965082353162, 57.182814844193004, 25.946072724557695, 0.897968857278747, 0.08936928149553076, 0.05029795466050987, 0.06335847823309802, 0.01001684284288316, 0.09144121991290201, 0.0931417435828236, 0.06547530557239248, 0.03373431402348703, 0.052008920108839396, 0.10555301147002367, 0.03300015281345094, 0.024180174880330602, 0.22440987518958508, 0.1649749507346461, 0.17125518632031259, 0.18635551475228804, 0.18796364055766215, 0.26362338794335244, 0.18961209323137038, 0.10769517716741371, 0.14818558229073403, 0.1448705053377536, 0.27362249010512907, 0.12529385621629416, 0.19777494392568068, 0.07187333483729633, 5.754343559665065, 42.77297604468561, 66.08381809726839, 57.99198412126111, 45.68446513145201, 45.130991243547015, 47.9418440788023, 52.40002962850755, 63.77822145338982, 34.82778379994054, 0.5970757514719041, 0.1989397193275152, 5.395539845189741, 23.793930968930646, 3.724985963875248, 24.04697483585727, 49.02621861427061, 60.423932075500495, 52.691532334973736, 55.70541881745862, 51.05723365660637, 47.346424364274554, 45.098478717188684, 49.71954461066954, 50.1021247525369, 52.64668395442348, 51.81879712689308, 48.59096496335922, 45.57228926689395, 44.824775726564475, 41.05057308750768, 43.11475176965037, 40.10382275427542, 42.81922078901722, 46.65110188145792, 48.68988321673486, 48.9829078028279, 52.74093066492389, 50.64293330715549, 51.915471784530155, 50.000853077057876, 52.65773719356906, 50.106757071710405, 42.489235708790446, 41.567847421092374, 39.37795285255679, 41.1129113166563, 40.384786052088586, 39.17909652956071, 39.21787308108422, 40.6927195672066, 41.70862913131714, 39.09269455940493, 40.51085887416717, 38.61597753340198, 40.85584309793288, 41.24605617215557, 39.34244363538681, 38.43323430707378, 39.98030731754918, 42.5358844572498, 51.24732348226732, 53.601659497907086, 52.720110724049235, 48.427508031168294, 54.16241722722208, 51.8371145955978, 51.54529809951783, 48.70940877545265, 48.87562705624489, 53.175211568032545, 54.323838449293575, 56.1594331649042, 54.76325765732796, 53.65622358937418, 52.05413541486187, 54.58395042727071, 53.51313160311792, 51.09744187324278, 51.406905112728, 49.226043762699256, 49.57910022427959, 47.68087310175742, 47.886566115963845, 44.51879555179227, 42.2880651873927, 39.25478650677589, 40.883029045597205, 39.742117466465125, 42.31610621175459, 40.7145671690664, 41.26208297667965, 41.722894791633856, 41.64139578419347, 40.31403041655018, 40.636449244714555, 41.00013532946187, 40.79963945573376, 41.359455816207394, 39.753633545291045, 41.243694905311834, 43.57996056156774, 49.89238385231265, 51.38991340514153, 52.5656948551055, 52.67195186307354, 53.522592359973544, 51.43742115266862, 51.20208678707, 54.093807128167924, 57.60509721694454, 53.467271251063195, 55.025503404678844, 54.26717981215447, 58.87172076009936, 53.41584505573396, 40.44414327990624, 43.8936403489882, 43.269646167755134, 56.02799061805972, 60.914620584057225, 57.96835968571325, 60.82877166809575, 57.524653327080514, 54.311412380587676, 58.806440753321496, 63.726171601203184, 61.4945077127026, 62.93912056953677, 60.23914137194234, 67.08789779293922, 62.79864088181527, 69.49127520284345, 58.67270361992621, 25.92601372349647, 2.233969261569362, 4.2639659585491305, 2.0650099794710837, 0.18585234820362062, 0.30800880623921273, 31.959248588931178, 68.87214476062407, 60.85627140537385, 39.17094976671281, 32.829624491353194, 61.96778482006442, 65.46371098487609, 67.98455945907101, 32.21614422336702, 1.64467187658433, 0.08881210574820157, 0.23518844117080015, 0.2330498914084127, 0.2195661770360124, 0.29579102151816894, 0.15188489830301655, 0.21676273956414194, 0.15785422476549305, 0.10252110359649505, 0.1674971420077547, 0.14625789056862556, 0.13027348135027195], [0.06001953381083666, 0.017899740111803817, 0.037475837649957794, 0.03708674159321574, 0.010923390115250745, 0.02535245411338345, 0.033871007091816396, 0.01632224633208206, 0.023468793294722998, 0.0803365379632, 0.05089572540694668, 0.05859274101713973, 0.0639115171056361, 0.04519913390639328, 1.115532250654313, 22.844295732436642, 54.982216127457164, 46.90909577954201, 35.740589941701586, 20.73987941588125, 26.654648896186586, 42.40185314609159, 50.1609799169725, 36.13276420101043, 1.4876495926610886, 0.16298790252016437, 2.5122199952602386, 12.623421780524716, 3.1520431464718235, 10.475416164244375, 42.16773471524639, 55.80249355685327, 54.351616674853915, 57.06124098070207, 51.953463862019206, 50.335082161811094, 44.73781677984422, 41.733932341298754, 41.44416724481891, 43.67339141907231, 43.00072454637097, 42.90247309592463, 36.802277488093225, 39.05356891693608, 39.12411274448518, 42.30296234930716, 39.815034327968476, 38.965915710695334, 39.493949105662686, 42.89372621044036, 45.45139397344282, 49.3056639548271, 46.865333895529474, 48.00233094922958, 48.663622948431204, 49.44798323415941, 45.929460294785045, 41.79274828203263, 37.41499877745105, 37.47142991712017, 37.257750957242905, 36.98690737447431, 34.89374629912838, 36.25768384625835, 35.78844285780384, 38.02324464244228, 38.02934392806023, 36.44741673623362, 37.20409293328562, 36.70703449556905, 37.25864525764219, 36.91606544679211, 35.546997439476755, 36.54830794180594, 38.34203135582709, 45.86258388334706, 48.94404888153077, 52.414212919050655, 50.98901971693962, 53.773004316514545, 50.5453408148981, 49.69276658950314, 49.23020931982225, 47.13246299374489, 48.404522941958525, 54.00898195082142, 50.94877619897166, 52.79651849500595, 52.02286235747799, 50.160881857718195, 50.67815226893271, 48.3021883041628, 46.921243359965665, 46.52617831383982, 43.93991647228118, 43.602090574079945, 43.05611233557425, 43.365916821264456, 40.44316268736317, 40.728169948824, 37.85671257203625, 36.045789564809496, 37.708337153157885, 36.9095778465271, 36.844635163584066, 36.65239980143886, 37.91683073966734, 37.32649833925309, 37.53726690046249, 38.72866722845262, 37.87194313541536, 37.758100263534054, 37.35561017067202, 38.53518063022245, 36.69583612872709, 37.8667656067879, 43.664005187249955, 46.82221920259538, 47.33246072646111, 45.47053906225389, 45.073893300948605, 43.68392690535515, 41.58791034452377, 46.79964203988352, 47.232628560835316, 46.727666547221524, 52.317016586180664, 53.16992029067009, 53.066742343287316, 54.38220723982781, 41.21468113314721, 37.54045970978276, 37.08869680281609, 41.30620179637786, 54.800849653059444, 54.852821057842625, 55.743120639554924, 54.39730444262105, 52.89158498087237, 50.85611804839104, 52.86821549938571, 55.191305914232814, 57.85865099199357, 63.12506837229576, 59.68687165168024, 60.42100598735195, 58.95530254610124, 47.77278992437547, 13.00595191217238, 1.5718963429812463, 0.5474672682823674, 0.7489004046205552, 0.13771677630082255, 0.23269660230125153, 27.130832479846095, 61.08034072383758, 44.55698374778994, 38.67859032846267, 40.424225484171224, 42.378864134511645, 47.06969330387731, 47.36727960648076, 18.032159420751757, 0.700610634540358, 0.09489806143627053, 0.01914494133914911, 0.02180213071105461, 0.0184006103119182, 0.04491675006706388, 0.04455163639279143, 0.03496083994245818, 0.036158331129099094, 0.028043627145610033, 0.060562820384098645, 0.001261217133311044, 0.06579719273553741, 0.026821226610111135, 0.030882436812164325, 0.06760744317885369, 0.02322830488875268, 0.05274704582388363, 0.04587400374152968, 0.027094122450498324, 0.012289395747375826, 0.04990949445674497, 0.03522569952051967, 0.028971124049876968, 0.009903015583873758, 0.0314936064363968, 0.10269296776142814, 1.4941593788323866, 29.401176821800973, 60.80453534280101, 52.01484503284578, 40.375497879520545, 26.896582649600123, 37.62430821695636, 49.297144566812825, 54.25710324318179, 39.76320020614132, 1.2561117136670699, 0.11949460127300794, 2.163695832414012, 18.26515997609785, 4.242922442574655, 13.089928876969124, 43.88536414792461, 57.998648228183875, 55.10841838775143, 58.99503223357662, 53.962180229925345, 52.661310472796046, 44.72098588943482, 43.80793263835292, 43.93970858666205, 46.33396256354548, 45.21343554219892, 44.784951902204945, 39.4116852360387, 39.37548960408857, 40.05234949050411, 43.58134515823857, 40.55611910358552, 40.931752727877715, 41.72316935754592, 45.2032373797509, 46.52516241996519, 49.653244787646884, 48.06568507225283, 47.97398790236443, 49.356709680249615, 51.41537350993003, 47.93594091169296, 43.87992382049561, 39.060766466202274, 39.974992505965695, 38.41168480534708, 38.53166226417788, 37.04031436674057, 37.989841738054835, 37.55110502243042, 38.01234437573341, 39.963186171747026, 38.2572179455911, 37.630183927474484, 38.14664633043351, 39.49977774773875, 38.597530626481586, 38.20597217928979, 37.49856487397225, 39.33459889504218, 47.65206329284176, 50.587294486261186, 55.473983287811286, 51.39276104588663, 54.50569521996283, 52.93897505729429, 50.787915875834805, 49.87342311489967, 48.228330073818086, 50.39264294408983, 54.13872611138129, 53.59853336887976, 53.79432239840108, 53.83333036976477, 51.26859057334162, 51.52286998687252, 50.16173301204559, 48.06097430567588, 48.24800076023225, 46.41492028390208, 46.19218064892677, 43.61646606076149, 44.78119427157987, 42.442869370983495, 43.22074990118704, 39.22574920039023, 38.143273092085316, 38.347424614814024, 37.703595007619555, 38.2400889550486, 37.85839134647001, 39.433995677578835, 38.34287074304397, 37.9654485179532, 39.32657372566962, 39.98118592846779, 39.15898653768724, 39.13546800613403, 40.036067731918834, 39.29562622501005, 39.96720267880348, 46.650289950832246, 49.49955455718502, 49.413815467588364, 48.107807405533336, 46.72117894695651, 47.21733916190363, 43.560713491132184, 49.57379717980662, 50.89518093293714, 50.53289905671151, 54.91912872560563, 54.36668642105595, 55.6397936421056, 56.631749291573804, 42.03074593697825, 38.829374082626835, 39.9203303552443, 45.61792604384884, 56.27706896874213, 56.06795564774544, 59.484355757313395, 56.61649519397367, 54.28706622892811, 52.605134287188136, 56.326867380449855, 59.12662383048766, 59.744452045809844, 64.40148215140066, 63.48972328247563, 61.87955502540835, 62.00494143270678, 50.1029327607924, 15.66878822542006, 1.473007262233765, 2.7706637401734633, 1.6413428874746447, 0.06399728830963855, 0.29956820270707535, 29.734046805289488, 66.6146638316493, 51.2799144560291, 41.781714654737904, 37.950590579740464, 46.16073108488514, 53.46933049540366, 53.669049739837654, 22.32311667934541, 1.3019167848171727, 0.0464406330138445, 0.02958066190683073, 0.025475930249799165, 0.013093045920193678, 0.040491515950810526, 0.005057891070347039, 0.03329109002445494, 0.02294718700971815, 0.035065587144345045, 0.008858876047475685, 0.03483785218709419, 0.019548315359579942, 0.10415860121288609, 0.16280728963113603, 0.19976332513315065, 0.12247287533095769, 0.21381953701136575, 0.06443294335997875, 0.11014127292700353, 0.12799049337064067, 0.1299720870391015, 0.1658102163984891, 0.22124963992786026, 0.07969816455677634, 0.15431823869866712, 0.16253385752920183, 2.0462588437141913, 34.76728908477291, 70.09019759393507, 60.382072541021536, 47.367962098890736, 29.256539421696818, 38.35335523851457, 53.71288222651328, 60.75122640978906, 44.445553133564616, 1.7465209984971632, 0.5078321467003515, 3.9989556756711777, 17.3465742218879, 7.305769910735469, 13.192136037734247, 46.65267082952684, 58.956553782186205, 59.14793014526368, 62.024455224314046, 56.26374467726677, 56.298857735049346, 48.34967643983903, 46.044793667331824, 46.05308948024627, 48.03452184123378, 47.67024347859044, 47.1341888366207, 41.97886082433885, 41.97638188638995, 43.03063654130505, 45.2803276431176, 43.4372765018094, 42.99709635396158, 43.85054526790496, 48.60144945882982, 48.50315486231158, 50.97130237087127, 49.30633860249674, 49.19672404566119, 51.64141578059043, 53.45030700006793, 49.56659178580008, 46.032402899957475, 41.96356358066682, 42.242816725084865, 40.47750696059197, 40.94521822467927, 38.0810054655998, 41.39585933377666, 39.37115930741833, 40.40890078390799, 42.27419568646339, 40.52068048907865, 38.55421981503887, 39.71682602359403, 41.41341194029778, 41.07620185421359, 39.547061920166016, 39.87152430319017, 41.69284943611392, 49.54282614492601, 51.98314051474295, 56.190125711502574, 54.35816703304168, 56.05545897637644, 54.63528640808598, 53.46143476424679, 51.25191265536893, 51.31489415322581, 52.03932062272103, 57.69869281399635, 56.186199418960086, 55.691953320657056, 56.43115143622122, 54.947381557956824, 54.727164007002315, 52.46525079973283, 51.591374181932025, 51.680141341301706, 49.40561771392823, 47.641233628795995, 47.327851941508634, 48.05218427411972, 45.15282315592612, 46.20268475624823, 41.173096164580315, 40.43312534209221, 40.68727139503726, 40.54903530305432, 41.503944166245006, 39.284769104373076, 43.26366455324235, 40.87567852389428, 40.43901281972086, 42.86819942535893, 40.78401665533743, 41.90186077548612, 41.79687069308373, 41.703785004154334, 40.63713173712454, 41.49705648422241, 48.73531995281097, 51.405536205537864, 51.13111934354229, 49.49497322882376, 48.79850541391681, 48.86229099765901, 44.873307212706536, 51.761204965652965, 51.57222517075078, 52.30444538977839, 56.70681168956142, 55.904675222212276, 55.58983441322081, 59.8910584757405, 45.88268603048017, 40.97956249790807, 42.07451174336095, 45.823191519706484, 59.42698324880293, 59.6320604508923, 60.02179499595397, 59.622666374329604, 57.72523157058224, 55.98609578224921, 57.86612702954201, 63.229030793712994, 62.81410286503454, 67.30300841792938, 65.30061098837083, 62.84295189765192, 61.669072797221524, 52.008604541901626, 16.130642410247557, 2.2463296305748726, 2.764383044935042, 2.4828152118190645, 0.25893921993913194, 0.5679530109609328, 33.58636932988321, 72.9452516186622, 56.5093634974572, 53.357660616597826, 53.90726312514275, 54.88058751629245, 62.83649567634829, 65.33792449582008, 30.080333255952407, 1.7840159155668753, 0.16778240250723978, 0.0838503074802218, 0.10352559042193236, 0.18277201591239822, 0.21365928673936477, 0.13012289910787536, 0.14647544421736272, 0.16946707581800802, 0.1246626993581172, 0.1269446531190507, 0.11280828546131812, 0.10028089396655561], [0.021746114362031225, 0.025183204223491976, 0.04730435118319527, 0.041277778800576925, 0.025111396887129354, 0.038304549431608576, 0.05014903099846937, 0.03645203774794936, 0.004456842425204213, 0.010887182884729438, 0.02484055607759905, 0.04865451220182642, 0.0851025777838884, 0.08703865050788849, 0.23300628568376267, 16.972352650857744, 51.33644757732269, 49.91327831822057, 40.96967028033349, 31.170057904335764, 22.976028534673876, 34.68173042420418, 49.007528520399525, 45.53808619899135, 3.0951290649752465, 0.016081133564453454, 0.39836185954270825, 14.620349464877961, 3.834144300030124, 5.677952949077853, 32.322862109830304, 53.660389146497174, 59.768641302662516, 53.77596570599464, 54.29655444237494, 51.42957641232399, 46.707089793297556, 42.56068560384935, 38.62885075230753, 40.099696420854144, 39.83337533089423, 40.51987640319332, 38.71712761540567, 38.90974736982776, 43.54678123228012, 44.60418555044359, 43.33631469357399, 39.913787841796875, 40.47175676591935, 45.42345100833524, 47.30947171488116, 50.26402450376942, 48.00839493351598, 44.75824840607182, 47.85769354912543, 48.87131244905534, 45.5655663244186, 43.497422126031694, 36.8589125910113, 34.5183519394167, 36.6552278303331, 35.21385485126127, 36.09219120394799, 35.70579459590297, 37.02056915529313, 37.301104914757516, 35.84097123915149, 35.84055154554306, 37.30689433313186, 37.49476409727527, 36.62000886855587, 37.22501877815493, 38.598499451914144, 34.31372973226732, 37.674106628664084, 46.3164609478366, 50.70307893137778, 51.761314792017785, 50.004245927256925, 49.672315351424686, 52.049181461334236, 51.89577756389495, 53.44018336265318, 51.829203174960234, 51.747480592420025, 51.76905755073794, 48.093639804470925, 50.71732497984364, 51.5401441051114, 49.949387658026914, 53.39470740287535, 49.57618198087139, 45.761061176176995, 44.71154082205988, 45.05849407565209, 41.0055717345207, 43.52203107649281, 40.875007798594815, 41.42013096040295, 38.10233531459686, 38.129689924178585, 36.54979844247141, 35.66499410137054, 36.96079223386703, 37.62526919764858, 36.04659757306499, 36.72074317932129, 38.75254269569151, 35.564859913241484, 36.99866271788074, 38.82114102763515, 37.24368141543481, 38.09855414975075, 36.98309483066682, 38.337599077532374, 38.22532515372, 38.72465072139617, 42.314843208559104, 43.45000459301857, 40.48513597057712, 41.18583210052983, 40.63034603672643, 38.26203069379253, 39.5469089477293, 43.81617746045513, 44.96496515889322, 48.606532850573146, 51.726288026379, 52.169578613773474, 52.750348275707616, 47.60299836435626, 39.02067592067104, 39.02299796381305, 37.60259397568242, 46.90304356236612, 56.573607998509566, 55.64873272372831, 57.95592184989684, 55.23065905417166, 53.38757653390208, 50.81890652256628, 51.76447622237667, 54.27871550283125, 56.62068036294753, 57.54129594372165, 60.29756507565899, 60.18998622894288, 36.81626466012771, 7.2926020237707325, 0.6444505674223746, 4.490381834968444, 1.8210769204362747, 0.11197871949163177, 0.12052238483222262, 26.893527123235888, 56.92071814690867, 52.39953540986585, 45.74902734448833, 25.44952223377843, 48.69283283910444, 49.034836061539195, 59.969635317402506, 20.121921762343376, 0.39479519931539414, 0.045615307340819033, 0.05576804843581012, 0.016936198770699483, 0.07013016305263005, 0.06719773169606924, 0.04513662496221162, 0.020589647183735526, 0.024843965168862094, 0.07071229028365306, 0.02779520972962341, 0.06210215149387237, 0.03254440327685687, 0.019552513521405, 0.036314708826642846, 0.013387212191798515, 0.049072872817275986, 0.07319135080662466, 0.028731124024958383, 0.023627921247914917, 0.077526236343528, 0.025914860326015664, 0.08034383878111839, 0.0644664750284245, 0.01726251392204675, 0.07815710974917298, 0.11095962336947841, 0.3588938983457704, 21.349653044054588, 59.61078551507766, 55.52635477435205, 47.167827083218484, 29.932993342799527, 29.383257473668746, 44.9853418719384, 54.237142301374874, 46.80812612656624, 2.833508445370582, 0.12697602441954997, 0.8831946371543793, 9.83230140901381, 4.739985292957676, 8.76850264687692, 34.46312496739049, 57.994604264536214, 59.30917093830725, 54.89100140909995, 55.650948862875666, 55.35839103883313, 47.7314010743172, 44.23383143640334, 40.9982329799283, 42.24940630697435, 42.00344231820876, 41.68788763784593, 39.73381380881033, 39.333481019543065, 43.71656494755899, 47.196601590802594, 44.35580538165185, 41.677932662348596, 41.90976042901316, 46.35440987925376, 48.29707745582827, 51.19676413074617, 49.115491759392526, 45.23406328693513, 48.23062073799872, 50.76063971365652, 48.72709474255962, 45.492068952129735, 37.80977749055432, 36.067754837774466, 39.265216089064076, 38.01840051527947, 38.033952713012695, 37.588532278614665, 38.74231315428211, 37.3310169096916, 38.92016910737561, 38.19754692815965, 39.464460726707216, 38.97767497647194, 37.77383681266539, 39.47067376106016, 40.19456678821195, 37.39957601793351, 38.883157622429636, 48.15914730871878, 52.57383377321305, 52.221334288197184, 51.439194063986506, 50.52857660478162, 53.583279271279615, 55.65578514529813, 52.868905836536044, 53.05217466046734, 53.4304048938136, 53.17284637881864, 50.00988629556472, 52.88124953546832, 51.67663866473783, 51.15195497389763, 54.779884584488414, 51.44509723109584, 47.80042694460961, 46.651431360552394, 46.58476283473354, 43.34938403098814, 46.21581292921498, 43.4944881931428, 43.81198052437075, 40.59979077308409, 40.16494897104079, 37.70420689736643, 38.42686437791394, 39.21610409213651, 40.59688037441623, 37.416061739767756, 39.37589360821632, 39.154499346210116, 36.677675554829264, 39.15884533236104, 39.05484760961225, 38.2484906719577, 39.02926983371858, 38.58213532355524, 39.150008232362815, 39.021825175131525, 40.903119425619806, 43.141157165650405, 45.69603220109017, 44.0226863276574, 43.88533276896323, 42.83901306890672, 40.47338062717069, 42.110938795151256, 46.68205330448766, 47.015674421864176, 52.346202942632864, 52.97504125102874, 52.363602576717255, 56.50097354765862, 49.08924718056956, 41.73319101333618, 40.00351990422895, 40.89214463387766, 48.30337285995484, 57.75059361611643, 58.192778095122314, 59.66984464276222, 57.4540977324209, 56.89117093240061, 53.1577060299535, 53.48136432709233, 57.873818797449914, 58.02384161180066, 59.609581347434755, 62.681491451878706, 59.90540650583083, 37.14313537843766, 9.468630033154643, 2.4457419495428763, 6.108977304350946, 1.0138967753418031, 0.05866396804189971, 0.26287534905056803, 28.510671315654633, 65.49707858793198, 54.16037759473247, 45.84726310545399, 33.25995360651324, 52.595402886790616, 53.10470304181499, 65.87452042487361, 25.392024209422452, 0.6490984535025013, 0.020151990728693146, 0.02808142209335441, 0.023766617636166276, 0.054145991321532964, 0.022186812186132998, 0.08869906181409475, 0.012520128981240336, 0.00813871796708554, 0.027956812146810756, 0.03777258180742783, 0.09785896828097683, 0.0625320302412635, 0.2761586088567011, 0.17262594744322762, 0.21341697312891486, 0.2100069472385991, 0.09736457343904242, 0.12042715244235531, 0.22677897145190548, 0.1809324396233405, 0.10334505414169642, 0.12915537602478458, 0.1423337277505667, 0.196180714955253, 0.22390831742555867, 0.16240566037595272, 0.48641306378187676, 23.90693641478016, 65.96893187492125, 62.4528290379432, 52.68001625614782, 41.39242725987589, 32.27670758001266, 46.16266481338009, 61.38070406452302, 53.65685116860175, 3.9680067041227898, 0.2954772931914176, 1.7682245758271988, 25.811203987367694, 12.606706600035391, 7.2222405864346415, 38.106579319123306, 58.539499928874356, 61.39440098116475, 55.48053756836922, 59.53726068619759, 55.18953300291493, 51.63618726115073, 46.990845818673414, 42.90072371882778, 42.87173740325436, 43.612947694716915, 43.61751333359749, 42.21007670125654, 42.78344092830535, 48.48657108122303, 50.048211774518414, 46.83289197183425, 44.64229922140799, 44.13400319314773, 48.83272417130009, 50.23581481749012, 53.6234208076231, 50.302240156358295, 46.64985064537295, 49.819506214511016, 53.328870419533025, 51.24507596415859, 46.733424586634484, 39.615997575944476, 38.44047500241188, 42.08308212218746, 39.19800627616144, 39.984386582528394, 39.72318026327318, 40.22407085664811, 41.279294336995775, 40.95435734718077, 39.75587321865944, 41.70220428897489, 41.440248797016764, 39.7301346255887, 42.57461001796108, 42.64041562234202, 38.15909593336044, 41.85424712396438, 50.03079645095333, 53.030872268061486, 55.73991606312414, 54.22963880723523, 51.67887441573605, 57.393755989689986, 57.35791337105536, 56.061660243618874, 56.17993539379489, 54.31498958218483, 54.220974291524584, 52.09620675733013, 55.88338067454677, 54.87688872121996, 54.57375618719286, 57.41038291685043, 53.860167226483746, 48.30562430043375, 50.1236467976724, 50.25613269498272, 46.311161825733805, 47.88860967082363, 45.61498818858978, 46.82476482083721, 42.11763820340557, 42.23395216849543, 40.20111714639972, 39.1637679069273, 39.90300916856335, 42.2514537842043, 39.25688497481808, 40.85052436397922, 42.80429224814139, 40.008771957889685, 40.97944874917307, 42.15713647104079, 39.695249065276116, 41.84523743967856, 40.4690150291689, 42.08898921166697, 41.89849538187827, 43.77702828376524, 47.23644894938315, 47.67511506234446, 45.60230716582268, 46.56417039132888, 46.071873711001494, 42.82062107516874, 44.937183010962706, 48.770978220047496, 49.95119587067635, 54.348514080047615, 54.659612947894686, 52.66731562152986, 58.27139023811587, 52.74300559874504, 44.43761033396567, 43.99240955229729, 42.154677144942745, 50.37290165501256, 62.27864050096082, 61.79918958294777, 63.97204145308464, 60.999496752215975, 58.89496864811067, 56.289126334651826, 55.248674500373106, 59.03828028709658, 60.7888654739626, 62.75563209287582, 66.6297649568127, 62.25382758725075, 39.310907779201386, 9.312736411248485, 2.4113089326889288, 10.590512233395732, 4.990934614212283, 0.3327458466012632, 0.37766096873148797, 31.867210172837783, 70.11855633028092, 64.40237252942978, 58.770464774101015, 38.27952054239089, 62.784606641338726, 62.791102086344075, 76.78139240511003, 30.760876247959754, 1.1331805875224452, 0.2017056338128544, 0.17488681080360569, 0.11502674585508724, 0.12655439260866375, 0.16131312706537787, 0.1708737664645718, 0.09330744840084546, 0.1666867129144169, 0.14277148571225906, 0.16611701929040495, 0.1950954748017173, 0.18795435557201987], [0.029132975445639704, 0.02500562504264376, 0.13324404856370342, 0.05246022250503302, 0.026588211391842174, 0.07620737767748295, 0.03928695760306813, 0.03979364815618723, 0.07342807963610658, 0.04062186964156647, 0.05788648839018518, 0.05485123654286708, 0.03946520328041046, 0.07891544486365973, 0.16933877141244952, 7.930673101255971, 44.02518095508699, 48.985257302561116, 37.111093536500015, 24.61577146284042, 29.647942935266805, 43.76726942677652, 41.90024475897513, 52.093472865320024, 6.968525013616008, 0.0462800954588719, 1.0850375386015063, 4.795001437587123, 2.8333897936728696, 2.1576102750916637, 19.07768680203346, 46.29976341801305, 50.43726774954027, 57.4682378768921, 54.30186533158826, 53.60003955902592, 46.87029961616763, 39.93101096922352, 37.12010322078582, 37.24513661476874, 39.412669750951956, 38.95331313533168, 39.13913149987498, 43.0115738222676, 48.44580588802215, 48.58008430850122, 44.50717749134187, 42.19436760871641, 43.07765007019044, 44.49005242316954, 48.10766620020713, 50.64853837413173, 44.341025890842566, 47.37894865774339, 50.06688225653864, 46.380517175120694, 46.1601701859505, 42.686703512745524, 35.43509614083075, 35.45892846199774, 36.872252571967344, 36.80675683483001, 36.394029355818226, 35.87632748388475, 35.96309423446655, 35.77658553277293, 37.23289097509077, 35.94442375244633, 36.69032127626481, 37.600440594457815, 37.194745925164995, 37.78379963290307, 36.0910144928963, 35.495567321777344, 39.187270748999815, 49.877678886536636, 49.807919533021995, 57.275700492243615, 48.245231566890595, 48.807801431225194, 47.3074830732038, 45.29917855416575, 50.14518453228859, 49.58254014292071, 49.71422587671588, 47.57960927101874, 48.29376305303266, 52.0109030508226, 52.96441555023194, 48.06934856599378, 51.85294135924309, 49.79863528282412, 47.94517809344877, 43.81842890093404, 43.20098507788874, 42.716599818198915, 40.26323964518886, 38.04318205002816, 36.733173170397365, 39.81499510426676, 37.271820499051, 36.33602534571002, 36.82791802190965, 38.84306707689839, 37.54756704453499, 37.99030065536499, 36.025024537117254, 38.67112605802475, 38.486374578168316, 37.184532073236284, 36.79371103163689, 38.342823674601895, 37.10199363770024, 38.19164376105032, 37.9241185034475, 39.23116207122803, 41.26220457015499, 37.59409027714884, 37.38411011234407, 37.10563359722015, 38.00878678598712, 37.45805855720274, 37.85714011038504, 40.1963867679719, 44.65607458545316, 45.94569106255808, 48.833791055986964, 48.9839276190727, 47.62928216688095, 54.39950881465789, 53.51771293147918, 43.64941004783877, 38.30598085157333, 36.75822927105811, 39.19626866617511, 44.176847242539935, 54.00593426919753, 55.683026006144864, 58.02702657638058, 57.68709436539681, 56.98188750974594, 51.92304195896272, 51.69284197591966, 52.434589632095836, 55.728007747280984, 56.691683107806796, 60.405445944878366, 31.208444180027133, 4.76152842083285, 0.7455131928286245, 3.5572257013090196, 0.7697353608185246, 0.030258197727943623, 0.21436255545385424, 24.05451363132846, 60.87504386901856, 53.25626734764346, 48.80317303442186, 31.824328860928937, 46.54848875537996, 41.6615253879178, 58.49019965817852, 14.84409518780247, 0.41531081942300646, 0.015549112314118013, 0.07446884072475857, 0.07848481151966319, 0.05427375946554446, 0.025406317755339608, 0.01653322886164871, 0.03141313464561057, 0.03328454380314196, 0.009824560519548194, 0.016955657403976206, 0.01370480734734766, 0.039272792637348175, 0.07829034776096383, 0.031222627731040124, 0.021745698759332303, 0.024531625376473513, 0.011370802700008837, 0.08380982739430282, 0.017323155526912982, 0.07244487473320577, 0.08047634134850196, 0.047699035851344954, 0.025211712270374262, 0.0600913085884625, 0.09963022484894722, 0.04164379262816041, 0.08298062914682013, 11.067183171549152, 51.04470168390582, 55.50043967462356, 43.885948581080285, 26.107525325590565, 25.589299817239088, 48.30764039870232, 48.70460387199156, 55.14838341743716, 7.176443972895223, 0.0990679775995593, 1.7337099246440397, 7.5445706709738705, 5.605311143782831, 3.8415573345076655, 20.705519453171764, 48.67240121287685, 51.973079635250954, 58.11522499207528, 54.806984240008944, 54.92321583532519, 49.22185074898505, 41.655575152366396, 37.81079338442895, 40.14756894880726, 40.18698876903903, 41.394698312205655, 40.34623699803507, 45.24454778240573, 49.73996446978662, 49.06827818962836, 45.20451999479725, 42.01070654776789, 45.921031121284734, 47.53722021656652, 50.70723664376044, 51.833039252988755, 43.99292730516003, 47.052085784173784, 49.654099864344445, 49.94463766774824, 46.8329978758289, 46.33689649643437, 37.56189154040429, 36.7493058789161, 38.90809212961505, 37.630913488326534, 38.43061416379867, 37.38900915268929, 37.26837273566954, 37.89422219799411, 38.054796188108384, 36.936379401914536, 38.88303995132446, 40.221819416169204, 39.02496699363955, 39.85941202409806, 39.620441621349705, 37.70449715275919, 41.72847240201889, 51.31978534883069, 51.21198684938493, 56.904138288190296, 49.7914691125193, 51.108965796809045, 48.945806103367964, 48.63529951341691, 52.27298798099641, 51.36730094109812, 53.05770128004013, 49.58751370829921, 51.13144097789642, 53.81291835538803, 52.584173140987275, 50.36777119482718, 52.031895575984834, 50.32077335542249, 48.38769205154912, 46.24026498486919, 45.22424167202365, 43.54159978128249, 41.79740805779734, 40.44608877551171, 38.30865198566068, 42.12138406692013, 39.7968109961479, 39.08515968630391, 40.24737365784184, 41.48110420473161, 39.54483009153797, 38.60188053500268, 38.54834802689091, 39.13879417604016, 41.73055910295056, 38.872649592738, 39.838960786019605, 39.499279606726866, 38.64878031515306, 40.09722925001576, 39.37149270888298, 40.638818356298636, 42.99954783531928, 40.83310119567379, 39.96751254604709, 40.65221717280727, 40.92543378953011, 39.580347153448294, 39.34383607679798, 42.5435487685665, 47.48426429687008, 48.417078448880105, 51.83756566816761, 50.80537826784196, 48.05314917718211, 55.94131800436205, 55.738857023177616, 45.49687385559083, 39.65809637500394, 38.36119213411885, 41.157783231427594, 48.58878020317324, 55.48544053108462, 57.331519742165845, 60.1859304981847, 59.152735048724765, 57.937761275999016, 53.58990807687083, 54.31274206407609, 57.07585573196412, 58.14121461683705, 59.77818835166193, 62.791831647196126, 33.8275872507403, 5.473358688815948, 3.2500999492983667, 8.165538253322724, 1.2981428518410654, 0.009948268397561005, 0.21481353609311968, 25.5615137469384, 66.98348429895216, 59.41084269554385, 55.67260034622685, 34.62111411556121, 52.51313901716664, 49.63879477593207, 67.88146388146185, 21.52345326638991, 0.6920430749174088, 0.044004661106174035, 0.06449895715641399, 0.10000412172127156, 0.0782655188513379, 0.020355174483190623, 0.024060458320403294, 0.04623432936627538, 0.02654315584579543, 0.006532497805423074, 0.018992736905572877, 0.05666808683365103, 0.10653518215422669, 0.18702659245219924, 0.1562227179566699, 0.19470870765226503, 0.1497537183064607, 0.11514949612319471, 0.21760546692436744, 0.1049856007880261, 0.15282706387581366, 0.15836614003825575, 0.12664296769446906, 0.22518451265510053, 0.160841845096119, 0.13260506994781956, 0.11811742799416666, 0.2824024399442058, 12.56224065057693, 58.75504985932381, 62.45656313434724, 50.36755938683787, 34.15045715147449, 39.26880505777175, 54.05348516279652, 52.92013199098649, 61.909180687319854, 9.355944260474175, 0.2691013149676785, 2.645786995849302, 14.281596906723516, 8.944387608958829, 4.01576719937786, 22.069890422205773, 49.654084174863755, 55.486483881550456, 59.28276161993704, 58.281439350497344, 57.955105996901, 49.78977857097503, 42.123408009929044, 40.29885868872366, 41.7425537109375, 43.08030159242692, 43.516100452792266, 44.85680187902143, 47.73544896033503, 54.22057420976701, 52.05589655906924, 48.16604675785188, 45.653305822803134, 47.09973473702708, 50.783067826301824, 54.5800555136896, 53.60771171508297, 44.189041891405665, 47.47608223269063, 53.65287388524702, 51.19432049412882, 47.81151940745693, 47.44078482350996, 37.93687405124788, 37.62647728766165, 42.23164973720428, 39.892053988672075, 41.54080660112443, 40.393234837439756, 39.17116941944246, 39.61945710643646, 41.6117230538399, 38.75536287984541, 40.7587722809084, 41.342581779726096, 42.00446605682373, 41.363123232318515, 41.24692693833382, 38.401337592832505, 43.65310492054109, 53.2710389937124, 54.45610469387424, 59.20111356243011, 50.63260962886196, 53.79853894633632, 51.41003908649568, 50.456240254063765, 53.976336063877234, 52.75567093203145, 54.51956472089214, 51.78781432490195, 53.20384879266062, 57.36524035853725, 57.705713856604795, 52.010318617666925, 55.49404228887251, 54.063067513127486, 52.05703404641921, 48.34952738977248, 47.879109690266276, 47.082837166324744, 44.83706451231434, 43.38623862112723, 40.15611579341274, 45.25497344232375, 42.98458791548207, 40.91172902814804, 42.117665659996774, 42.737655101283906, 42.577845973353234, 41.20531059080555, 39.913693704912745, 41.76533483689831, 43.246221773086056, 41.59158168300506, 41.31723934604276, 43.35112948571482, 39.21931259093746, 41.72467162532192, 41.4326629331035, 43.24751223287275, 45.152780009854226, 41.901197894926995, 41.86267237509451, 41.399687567064845, 41.74328327178955, 40.76014903283889, 41.90167250171785, 44.65498808891543, 49.81892570372551, 50.03413831034015, 54.590885177735366, 53.92960494564426, 48.27547696328933, 56.405809002537886, 58.95862479363719, 48.87890615770894, 42.23329321030648, 40.93449446462816, 44.428761466856926, 49.17850071384061, 58.043363248148275, 60.7706460645122, 62.416370607191524, 62.12635840139082, 61.6825932072055, 56.47635283008699, 55.723649994019546, 59.44421814334009, 60.38898767963533, 62.63395624776041, 65.56602993319112, 33.82341384887695, 5.980167158188359, 3.1583157518217644, 12.148296256219188, 2.892886510779781, 0.166984721116962, 0.4090186328657212, 28.042191267013553, 73.09376039812642, 65.19059242740755, 61.06844417510494, 44.66388794683641, 58.84065951070478, 56.911222088721495, 76.04088029553814, 27.98876858526661, 0.990066415359897, 0.15193418840006476, 0.155424055973849, 0.13692123995673272, 0.2122387299013715, 0.1287823831362109, 0.16537480266584506, 0.07546761253428075, 0.16429392921347774, 0.2081733311135923, 0.11177162294306102, 0.15690669657722597, 0.278800294524239], [0.008399588142281339, 0.042357173703250386, 0.05929169665661551, 0.013834648716804242, 0.04706217546857173, 0.030357241405234225, 0.08124556257239274, 0.030121791942585862, 0.08026466359414401, 0.09734421082201505, 0.058795861569383455, 0.050030888749226454, 0.03782977410141499, 0.07225807951462847, 0.1219664758912498, 3.261910451035346, 36.952178708968624, 50.17579078674317, 35.84158705126855, 29.524411809059885, 29.466898095223215, 34.277887113632694, 45.3309222959703, 51.78560603049494, 14.195159635236188, 0.08800992742180826, 0.4723246149238079, 1.5081038950912415, 5.4959510507122165, 1.9756891530367637, 5.680295094366997, 38.97519603852303, 48.51352953141736, 54.18623385890838, 52.911318425209295, 50.36101295102028, 44.68433134017452, 39.77464960467431, 34.81373779235348, 40.846888326829486, 41.41590656772737, 42.56617299972042, 43.547589240535615, 47.16399492756013, 50.64678115229453, 46.83252326903805, 46.48371473435433, 46.94492663106611, 46.75851991099697, 48.324263403492594, 50.61522568425825, 46.06114602858021, 44.776781605136016, 47.44972782750284, 50.9225590767399, 46.56488426270024, 45.90027001596267, 38.97546275969475, 34.26380188234391, 36.454127911598455, 37.39011526107788, 37.04483685954925, 37.741512560075336, 36.232164905917266, 37.05735706513928, 37.00021205409881, 38.73105987425774, 37.26292064113002, 38.004801657892045, 37.59299985824093, 35.63404267834079, 36.57451329692718, 38.85084905932027, 36.96149041575771, 37.918744856311434, 48.86511118181291, 46.30266989431074, 46.36535329203452, 56.18514037901356, 52.371910156742224, 51.40236693043863, 47.08738711572463, 48.30849155302971, 47.133306303331935, 45.663892299898215, 47.02557056180893, 49.47598503481958, 53.161377368434785, 51.01175769682854, 49.07211034528671, 50.31355619430543, 49.63153839111329, 46.96864128112794, 42.847905082087365, 42.59186060197892, 40.216794859978464, 37.50821390459615, 37.55297599300262, 37.514419094208755, 36.67511816947691, 37.2717224397967, 35.075728585643155, 36.613956651379986, 37.59412165611021, 38.181406374900575, 37.96052986575712, 37.22950204726189, 38.23409949579547, 36.88646724147182, 39.31624612500591, 38.78775381272839, 38.538769598930116, 37.69645629390594, 37.67096481015606, 37.53698841218026, 37.93555221249981, 39.53153717902399, 38.474023034495694, 37.81060511066068, 36.82245416025962, 36.061941885179095, 37.37974059197211, 38.741281570926795, 40.09264399928432, 43.93591173233525, 47.222289193061094, 49.068089915860085, 50.633986380792436, 49.064626462997936, 51.51387206969723, 53.344971749090384, 51.159615362844164, 44.510484049397135, 35.11641533144059, 39.04329230708461, 38.503009350069114, 43.71289753144787, 52.23189330870106, 56.26212081601543, 59.15091506896481, 56.76898910153297, 54.46415731983801, 49.84054973048549, 47.4838367585213, 55.12083661171698, 59.16638489692443, 60.45644067948865, 28.09691421447262, 3.842018703299184, 3.5218787722049223, 4.931012074793539, 0.1635389495640993, 0.046067640125270815, 0.085916975212674, 23.12795958211345, 59.500931693661606, 43.80720699987104, 37.593348949186264, 33.78103263916508, 55.10577471025529, 52.50745158041678, 54.079113929502434, 17.87176978203558, 0.45343987343292086, 0.03414762611951559, 0.013563190248884983, 0.06552753744706993, 0.03496458611240791, 0.03223352479718385, 0.031034141373369965, 0.055595965935818614, 0.09566509164869787, 0.030325994594022635, 0.08631817545861968, 0.08968024424487546, 0.003980495178350999, 0.04812921720346616, 0.04549138495818742, 0.016304028761242668, 0.02502384835914258, 0.033818974399999265, 0.06437441424256371, 0.011852566667291667, 0.0434220091049229, 0.04254074369166647, 0.09875619513613564, 0.04423738712625158, 0.016857241918783517, 0.023770522769360293, 0.09852509705289718, 0.0541270995933202, 5.059046081958279, 46.221163042130016, 56.46237350279286, 39.0913099627341, 30.95804987415191, 29.77559647252483, 39.34382823205764, 51.15432800785188, 55.79411929653537, 14.545110560232594, 0.0831416838111416, 0.3068791023425518, 1.1827598367967915, 5.431297152273117, 4.127742042464595, 8.418186941454488, 40.24912303493869, 49.55384408274005, 55.29583315695486, 56.189898214032574, 51.004418942236136, 48.34613453957343, 41.412258763467115, 37.531073477960405, 41.31934565882529, 44.253706086066465, 43.99345682513329, 44.59292834804904, 50.05546031459686, 53.71836570001418, 48.02226835681547, 47.185685634613044, 48.495733737945564, 48.662301109683135, 51.51203640045659, 51.97464858331988, 45.32549373565182, 44.4735510118546, 47.669827707352184, 52.13576778288811, 48.166309556653424, 47.35275506973267, 41.58644337807932, 35.79727995780207, 38.03305056787307, 39.23689265404978, 38.628215328339614, 37.137338115322976, 37.230619922761, 39.30690696162563, 38.151968986757346, 41.39365103936965, 37.65347103918753, 39.155162226769235, 39.40267947412307, 38.430449424251435, 39.250165954712905, 40.14867897956602, 38.3432198339893, 39.45020683350102, 50.53909247921359, 48.643995408088934, 49.20454525178479, 55.3872989070031, 53.256149676538286, 51.40768174202212, 49.05687978190761, 48.278854124007694, 49.07799782291536, 47.722744403346894, 48.716606324718846, 52.16475409846152, 53.867513825816495, 52.498222243401315, 51.031891222923036, 52.96609432466569, 51.06732591505974, 49.344691538041644, 44.24102114092919, 43.42982792085217, 42.82532399700534, 41.85709476470947, 40.6612229347229, 40.399177228250814, 38.79632026918473, 38.89274389513078, 37.53210113894555, 39.635487833330714, 39.80688364275041, 39.30384751289122, 39.5587819622409, 38.14001360247212, 39.554706619631865, 39.117652600811375, 40.45576918509699, 41.352446540709465, 39.26365106336532, 40.87118348767681, 40.86603341564056, 40.238881726418775, 39.8747367243613, 41.77975739202192, 40.16293679514239, 39.61169081349527, 38.402302495894894, 38.43737240760557, 39.47821647890153, 40.19740266184653, 43.10247867338119, 45.9631299203442, 49.487226547733435, 52.430580969779726, 52.85598162681826, 49.79231634447652, 51.38605771526214, 56.471775424095895, 53.0584426080027, 46.29382494957217, 38.36222371747417, 40.13917899900868, 41.07570371320171, 48.17891605438725, 55.14361773767779, 56.66933344256494, 61.17625444166122, 58.42387237856465, 56.31078958511353, 53.240762218352295, 48.70381155321675, 57.959691247632435, 61.70903390453708, 62.25752638232324, 31.620708819358583, 5.153174631057247, 6.043198666264934, 6.102754464072566, 1.3864959560094343, 0.06395398902015821, 0.12030257888498808, 25.916960893138764, 64.43000170492357, 51.84025249173565, 43.444681936694735, 38.5174201380822, 57.35095508636967, 56.81576336583784, 63.03077851572345, 22.840018387763735, 0.33034593828262826, 0.07403259195627705, 0.02979505161244062, 0.015310467307215497, 0.028193493095797398, 0.0443062239566878, 0.07592915752602201, 0.0359613009758534, 0.043611696305414366, 0.029169134795665744, 0.11837151637601277, 0.026884352255071846, 0.02204059856012464, 0.1317983946853107, 0.1877279612686365, 0.22241196384833706, 0.10455795518693425, 0.17150759696960452, 0.22493890486657622, 0.17966300128929077, 0.1115828742002768, 0.18489366577517602, 0.2605068503368286, 0.1306591453331132, 0.14327347248552308, 0.1309890227933084, 0.13589379347620473, 0.26305718768027525, 5.379987157160237, 50.09534297450897, 63.523126186863074, 48.09127069288685, 39.85303425019787, 39.444405648016165, 46.22675241962556, 56.26358778245988, 59.934890962416134, 18.176718373452466, 0.19327514264131748, 0.8298641923935184, 4.415918088728382, 11.561776399612429, 5.259883201891377, 7.923547625541688, 43.34929773884435, 52.00945569622902, 58.6014106196742, 59.04635252491121, 54.80892973561441, 49.19854010305097, 43.16712717856131, 39.05540458617672, 43.868658773360714, 45.795197563786665, 46.28414061761672, 46.74840411832256, 52.12014498249177, 56.08464533282865, 50.30567223025907, 48.63731953405565, 51.08980501851728, 50.79280314906951, 52.58431042394331, 54.727293445217995, 46.39266867791453, 44.16420152110439, 49.667863461279104, 55.59087384131647, 51.52520771949522, 50.0747936771762, 43.27625536149548, 38.4116534263857, 39.5627631679658, 41.83155229014736, 41.12528639454996, 40.11524861858737, 39.28296481409381, 41.279953295184725, 40.106184021119155, 42.85210201817174, 40.77234368170462, 41.96775659438103, 41.54141456850114, 39.39883162898403, 40.26784058540098, 42.594472900513686, 40.04283774283625, 41.62147406608828, 54.829373128952525, 49.32600536654073, 52.31638900695309, 53.96269013804775, 55.08225617870208, 55.27347172460249, 49.05429101759388, 52.07349623403242, 52.07363351698845, 50.76663701764999, 51.717403857938706, 54.02937435334729, 56.31227224103866, 56.03732585906983, 53.93828122846542, 54.5778589863931, 54.55687038360104, 50.970972891776796, 47.377301262271025, 46.985813417742335, 44.346042602292954, 43.31869540675994, 44.85713920285625, 42.31646706981044, 42.13444555959394, 41.326735404229936, 39.08656781719577, 40.97804846302156, 42.16430656371578, 41.79113226552164, 43.0483264307822, 39.92903409465667, 41.344244864679155, 41.05444054449759, 43.90158707095731, 43.075214278313425, 41.69292003877702, 42.15359457077519, 42.920782719889, 41.75686643969628, 41.93077256602626, 43.38702309516169, 42.02344640608757, 41.53117718235139, 40.5447873761577, 40.969678125073834, 41.6883034090842, 42.18137671870571, 45.70678341773249, 49.45393346971082, 52.59024104764385, 54.95550086421352, 55.04043586792485, 50.24149440949964, 51.18240433354532, 58.176606162901855, 56.07453346252442, 50.18027405585013, 39.85465811144921, 43.24095402994464, 44.007997051362075, 49.381950132308475, 58.332269345560384, 60.6456950403029, 66.14740756250197, 61.29124264563284, 61.74344485805881, 56.733832897678504, 52.73391354468561, 60.29111277672553, 65.48615478700208, 65.14285326004028, 33.497955183829035, 5.597683604686491, 10.410361693751428, 13.087579377235906, 2.112115929203649, 0.27906284817764837, 0.22855480922566307, 28.735725149031612, 69.807096604378, 55.72557587777415, 51.87752677548317, 46.83970512882356, 67.4671752991215, 65.98415851593018, 70.81223533999535, 29.221477354726485, 0.5757896001300504, 0.15285637439979663, 0.149560694793059, 0.18106291971860394, 0.08270454638066792, 0.11765819658795673, 0.15472365242819633, 0.14045980007898423, 0.14358957568483968, 0.09224942735125942, 0.16493828576659003, 0.18878237404409917, 0.08458763646382479], [0.020562269116541552, 0.01525173804933025, 0.009824302922483655, 0.036135953700830864, 0.03346605684548136, 0.028900197714627273, 0.12406086068480246, 0.09499212937249292, 0.058702712938670194, 0.03308781242418674, 0.0816985350402613, 0.04698948521587638, 0.002423504544910224, 0.05898136209936873, 0.05553596209914935, 2.025367442157961, 32.56752975525395, 49.65806538058866, 43.006486508154104, 23.6585444788779, 18.917163802731423, 41.62737723319761, 41.39454926213911, 54.58731582087856, 20.71460170130576, 0.20043788087223807, 0.29285408556461334, 1.6348449909879317, 4.39178962861338, 1.5684878033015037, 1.3504231432753226, 23.118192880384385, 57.2254470855959, 53.64810820548765, 51.89890369292229, 46.00135341767342, 40.03851529090635, 38.4765725751077, 44.914452875814135, 46.28096742014731, 44.404250575650124, 45.884521699720814, 46.956183833460656, 49.8030440268978, 47.65082382386731, 48.54471629665744, 47.25927322141586, 50.3971811263792, 48.40198124608686, 46.975674090846894, 44.07812118530274, 47.76764769707957, 47.41735650647072, 48.771319466252486, 49.65185626860588, 45.7545578864313, 42.596167364428126, 36.46226682970601, 36.080180906480365, 34.25273687608781, 36.11154025600803, 36.18721062137235, 35.79795852784188, 36.48706013156522, 37.150101507863695, 36.41404128843738, 37.81048351718534, 35.605170111502375, 37.999314262020974, 36.781347720853745, 36.46790327564363, 35.36947096547773, 36.5189843023977, 36.7912870068704, 37.181519692943944, 47.91243806962044, 51.507698259046, 43.432400995685214, 42.052362118997884, 52.22386029458816, 51.83321183727634, 50.30520154583839, 48.43372106552125, 46.34228583305113, 46.03024951873287, 48.371653479914514, 50.373125230112386, 53.875001630475445, 48.423797468985285, 48.145658277696185, 50.97392251414638, 49.240305500645796, 46.86270198514385, 43.03650048471267, 38.94968494292229, 39.210624541005785, 37.58837538380777, 37.2382842340777, 35.95289999438871, 36.356429515346406, 35.13184201332831, 37.789938142222745, 39.11368316219699, 38.571595914902225, 37.99707066628241, 36.94599313120688, 37.59203103280837, 38.17394210446266, 37.18270424873599, 38.85877616943852, 37.577035811639604, 37.79785348523048, 39.328060303964925, 39.44810444308866, 39.60404611402942, 38.87375177875642, 37.70416767366471, 36.88969535212363, 37.49995339301325, 37.33531190503029, 36.632827174279, 37.402886498358946, 39.134161856866655, 41.148687254997995, 45.62411554398076, 49.955428108092285, 52.4793948665742, 51.862504097723196, 48.79395154214675, 49.74123924009262, 49.079500090691354, 54.47059785166095, 50.403774630638864, 44.33529923039098, 37.49909831631569, 38.79211548836001, 37.86500446258053, 41.38470411300659, 47.176954438609464, 50.993153895101244, 49.7222275118674, 46.833688212979226, 44.8154914763666, 48.9408560722105, 56.18191226836174, 58.16559999219833, 57.99918951526765, 30.872228414781635, 3.6686680826448628, 5.025782421711953, 6.66991203061996, 1.1225584413736098, 0.07969918345371563, 0.29046741524531, 22.990768801781442, 57.86267926616054, 48.06229222205378, 49.41854192364601, 36.80909848982288, 47.53385874532884, 40.687832293971894, 52.26886949231548, 13.422155591749377, 0.33370455967322477, 0.025787710798003023, 0.059481173182927796, 0.02627425323871355, 0.041004434798754034, 0.032495660932674524, 0.02243739954616514, 0.07760266893573346, 0.024055620475161462, 0.07835404797186775, 0.0160836118588885, 0.04888844481038471, 0.015960531215363696, 0.014931691412423408, 0.010880008471318552, 0.015646887158284026, 0.06785569397071678, 0.0247161797878723, 0.027854478121885372, 0.05002581341672809, 0.035409407404762124, 0.04079440030299368, 0.02762842664284812, 0.024995663984408303, 0.02619285065109932, 0.025678062548620567, 0.0879576036165799, 0.05832587811915625, 2.7538090703948854, 36.66100940396709, 56.852013910970385, 47.71198141959406, 31.47275701645882, 23.008986250046764, 42.3584246635437, 51.64561663904498, 58.176339441730136, 21.998673908172115, 0.07222538288202017, 0.3764689972083415, 2.1053044882512864, 4.603094573943846, 4.091667023397261, 2.7678827797212913, 25.01702012554292, 61.82261789998701, 54.984232225725734, 53.718573585633315, 46.222092643860854, 41.465065633097005, 39.655531144911244, 43.84354383714738, 46.94448340323664, 46.71538952858218, 47.24240310730473, 48.81685033921273, 52.496543468967566, 48.180512459047385, 50.21353183254119, 48.97125051867578, 52.750705211393296, 51.36684202378797, 49.00207642586001, 44.40486638776718, 47.88539332728232, 47.73818285234513, 51.48304224014283, 53.055139972317605, 47.392186657074966, 44.76910944907896, 39.613608852509536, 38.26603151136829, 36.4847537779039, 37.657401254100186, 38.16530504534322, 38.73590792379072, 37.41891330288303, 39.01993851507864, 37.725077829053326, 38.841866831625666, 37.394402411676225, 39.54803466796875, 39.257692983073575, 38.267196455309474, 38.62558734032416, 38.015305765213505, 37.25186347961426, 39.85775286151517, 48.95580030256703, 53.68568058936827, 46.39695582851287, 43.612127919350904, 53.602851898439475, 52.455648837550996, 51.97438970688851, 48.9799895594197, 45.382015089834894, 46.27715487633982, 49.831061517038655, 54.22121747847527, 54.98278487113215, 50.592605375474506, 49.63130697127312, 52.346626558611476, 50.27545429045155, 49.17627672995291, 43.49332324920162, 41.44415547770839, 41.13013836645311, 40.810002357729026, 39.32482434857277, 37.51826301697762, 39.621885053573116, 37.17330624980312, 40.04505780435378, 39.920475482940674, 39.72700849656136, 40.35126547659598, 38.09038777505198, 39.0331216012278, 38.111054743489916, 38.28521190151092, 40.10446602298368, 39.24006977388936, 37.90473415005592, 40.985599025603264, 40.247350123620805, 40.18043056611092, 40.25889365903793, 38.22309724746212, 38.02215814590454, 39.12655245873236, 37.9027533531189, 38.51362720612557, 38.77799887810984, 39.878553190538966, 43.21793363940331, 46.92540107234832, 51.908803755237216, 54.22012705956736, 51.879993946321555, 50.20207458926786, 49.18252506563741, 50.59817514111919, 56.502832751120295, 52.77315293588946, 45.88565134233045, 40.70935041673722, 40.56315191330449, 39.603453836133404, 44.66757497479839, 50.30123210722401, 53.96537303924561, 52.42026513622653, 50.55524087721302, 48.28442388965238, 49.972137405026345, 58.59481711541453, 60.223012585793775, 60.78681015199231, 31.920101373426377, 3.7801514037193793, 5.521072360777087, 4.388909138018086, 1.3555274951842524, 0.11916921308804905, 0.19062787985369084, 25.174948476975967, 63.25143144976709, 50.93209828099897, 47.833578817306034, 41.56167753281132, 56.677189950020086, 52.90080647314749, 59.04386574222196, 18.6809802439905, 0.4539250215936092, 0.021581012838249727, 0.07980713290312598, 0.05253377077620357, 0.08172823626908564, 0.0801179730784028, 0.019982154781539595, 0.07095422085014082, 0.03414080027611025, 0.07297593454319624, 0.049499909378468036, 0.028672949223208333, 0.04285551006755522, 0.1424938860920168, 0.11821445302977679, 0.2293770667165518, 0.13362750621332278, 0.187503298323962, 0.09988140209668106, 0.2355168170986637, 0.2302336296246898, 0.1274011419304917, 0.08161690071104996, 0.1498796631612124, 0.08683575978202206, 0.17677584572905497, 0.21800726471889406, 0.3222303092479706, 2.690580463217151, 43.561725462636645, 62.865336864225334, 56.042813254940896, 34.47198560160976, 28.238635332353656, 51.713234378445534, 54.88834204212312, 64.5651626586914, 26.668169306170558, 0.40560374997796556, 0.8123845174427956, 5.579762785665451, 11.410847517751879, 7.792721871406802, 2.378037427702258, 27.851369919315463, 62.91868109856883, 58.510937229279556, 56.751216842282204, 49.340129821531235, 43.576755985136955, 42.57632017135621, 47.84262380292339, 49.19650831530171, 48.86093385757939, 50.72422442897674, 50.771692952802105, 53.29297288771599, 49.30342820382888, 53.84460718401017, 50.46454783408873, 54.74366149594707, 52.31281572772611, 48.461110976434526, 43.92629015830256, 47.147622954460886, 47.538020380081676, 53.82478352515928, 55.07981254208473, 50.569608519154215, 46.60519053859096, 40.33013566847771, 39.01387060842207, 38.48906140173636, 38.74461950794343, 39.86386391424364, 39.31069989358225, 40.94604192241546, 40.35599977739396, 40.09228706359863, 41.378149832448656, 40.018597495171335, 40.958122822546194, 41.06127331333776, 39.675229287916615, 40.53310655778454, 40.96978795143866, 41.02635245169363, 41.32248355496315, 52.37884882957705, 53.94428637719924, 51.01739806513633, 47.18086896404144, 52.22472713839624, 55.85033078347483, 54.395649202408336, 52.25773388339628, 48.82972355811827, 49.173864472296934, 55.34504713550691, 54.861003122022076, 57.429947699269945, 52.0327937987543, 52.62780558678412, 54.04122383363786, 52.838346650523526, 50.27790184943907, 47.70521140867665, 43.90929060597574, 43.991789817810066, 43.80617541651572, 40.34874731494535, 39.847323279226984, 40.52875664926345, 38.280638417889996, 42.973487607894405, 42.644828288785874, 43.32680294590612, 41.749672812800256, 39.77009965527443, 40.452392024378625, 41.2578821182251, 42.29660026488766, 43.15144162024222, 40.6648785837235, 40.82689600606119, 42.873004328820016, 42.09986594415481, 42.738616081976126, 42.253140403378396, 40.308107637589984, 40.21006407276277, 42.0966927466854, 41.45975866625386, 40.72751883537539, 40.8075547987415, 42.19944315571939, 45.59397997394685, 49.74886825007778, 55.19899375977055, 57.56204920430338, 53.5464011469195, 51.67180630468553, 50.19124884759226, 50.42838358109998, 59.559123977538086, 55.865420141527736, 48.011626966537975, 42.36724215169107, 42.58134080517677, 42.564670731944425, 46.08208364056003, 50.99134568245181, 56.96483304423671, 54.23512228073613, 52.049911022186286, 50.16536512682515, 53.36517195547781, 61.76039734194356, 64.10742205958213, 62.78955275012601, 33.75734152332429, 6.4630766261008485, 9.889612140194062, 15.554970848944881, 3.8900052251354342, 0.4168953037550373, 0.6390468283526359, 27.549349377232215, 71.19301119158345, 60.711928183032626, 64.62939539263326, 50.091585343883885, 61.60384378125591, 57.299983885980424, 68.3881321261006, 23.321534433672507, 0.735125347010551, 0.15740137487169237, 0.24423419287608517, 0.16137252952302658, 0.17846663242145894, 0.12096203503108795, 0.08595861975223788, 0.21729276515543464, 0.13828905930201854, 0.22973139770329, 0.1331270669376658, 0.1613860126704939, 0.11732329359097828], [0.018083032393347354, 0.00906610378860346, 0.06045326598048691, 0.05638043997028182, 0.02825361376087512, 0.020394147291118582, 0.020083672922825622, 0.044047167494652734, 0.04391925762437525, 0.02385343646540517, 0.03366290696806485, 0.12852842498931194, 0.0018276584746819292, 0.03937519561018675, 0.03523141070599518, 0.5285819139211408, 23.089214409551314, 51.150844943138864, 43.40101418956634, 32.62989544099377, 19.870374279637492, 20.876838776373095, 38.26511367674797, 52.76465315972605, 30.42602546753422, 0.6589931838454739, 0.050995745846340736, 0.4551125191632779, 3.5950246020670864, 4.10512859782865, 0.8747281398504012, 15.034810631505906, 54.523891095192205, 51.51085968940489, 49.48850524040961, 42.7203143027521, 41.971494613155244, 44.73103107944612, 49.767130805600075, 47.41430098010648, 49.08087684262184, 48.95427057819982, 51.31277215096259, 50.43634991491995, 47.261830606768214, 45.856068826490834, 47.0244409191993, 46.96527980989026, 47.337418602358916, 46.07789847158617, 45.71365933264456, 42.78036186772008, 47.39339082471786, 50.328751456352975, 46.57379588773174, 45.920156432736306, 38.61203555137881, 36.309255169283965, 34.81952721072782, 36.81084002217939, 35.59727830271567, 36.48945277737033, 39.30442410130655, 36.790510377576275, 36.84914588928223, 37.27949657747823, 36.368126023200254, 36.80326592537665, 36.5889201625701, 36.13627864468482, 34.90766679086993, 37.83501794261318, 36.037430993972286, 38.007582618344216, 35.71024648604855, 43.81720904381045, 51.115061160056825, 50.53286375537996, 45.95598728426042, 41.82716315792453, 50.09303269847747, 51.92685450277021, 52.26360174917406, 50.06426211326353, 47.6962919389048, 46.83995223814442, 49.32946097466254, 53.50258434972456, 51.673959685910134, 49.235924213163315, 51.27379555856028, 48.95253689058366, 47.03117562878517, 43.94295238679455, 40.15028715133667, 38.22461912708898, 37.69322426088395, 38.547755748994895, 36.37779074330484, 37.443377125647764, 36.724155641371205, 38.841866831625666, 39.29595570410452, 38.5148980540614, 37.77291505567489, 36.38262310335713, 36.54699002542804, 38.58888964499197, 37.54645701377623, 38.98186799018614, 39.87556826683783, 39.04695187845538, 37.41860735800959, 38.18366173774966, 38.166234647074056, 37.16861117270685, 36.55134777868948, 37.22259475338844, 37.07773377818447, 36.791224248947636, 36.692455045638546, 36.54919831983505, 37.219578450725926, 42.085019773052586, 48.71966185108308, 48.155448513646284, 50.92870543079992, 51.29485476401545, 54.74487350833032, 52.7611897068639, 50.03229479635916, 47.861443335010165, 52.85094922588718, 51.36798343350811, 44.87577046117475, 40.106576258136386, 40.365052607751664, 39.34636208318895, 39.30398087347708, 39.97287834844282, 42.31268198259416, 42.82364914494176, 44.087479960533884, 48.11573843802176, 56.60562238385601, 58.66877732738372, 61.15392046590006, 30.972754839927923, 4.6371157419297, 4.458810677451472, 2.1774344242388204, 1.0884035450796927, 0.07190988489216374, 0.03586016970896914, 23.17814042491298, 54.43062889960505, 45.87069142249323, 37.745262345960064, 37.52452311977264, 45.706983458611276, 43.51423732696041, 53.29752283711588, 12.16080959766142, 0.42982895167604573, 0.01996236864567524, 0.09473627898842098, 0.05747936245414519, 0.042488542460506006, 0.08233694675108118, 0.030626400651770736, 0.02582430107248647, 0.042349463028292504, 0.031504414021788586, 0.03644830689975812, 0.016059964639885772, 0.004162989770843378, 0.042092134094526695, 0.029846038594241106, 0.05468079730147316, 0.027389171638435898, 0.04011738925210891, 0.033929206791423985, 0.042675701570847345, 0.03914306330825052, 0.010757397056647367, 0.01449874256767573, 0.03011071622642058, 0.05145109701721419, 0.03284420412514479, 0.05012027971867112, 0.007514198303162571, 0.6616626018958708, 29.720736242109734, 57.476215977822584, 51.3630255576103, 33.113080455410866, 17.955463355587376, 32.67118623179774, 47.12732861118932, 58.070172648276056, 32.239401917303766, 0.8685485682179852, 0.03736242216320769, 0.6704759225249292, 5.390240723086942, 6.4365898409197415, 2.500007450580597, 16.938292749466434, 56.11108603016023, 52.47305631637574, 52.7490891948823, 43.42469353829661, 43.1586548589891, 45.60661785064205, 51.800911118907315, 50.462692552997225, 51.59529655210434, 49.73577145607241, 52.726135484633915, 51.381750952812936, 48.1989711330783, 48.288836556096236, 49.00277460775068, 48.58295940583753, 48.59218089811264, 45.91882282687772, 45.595344958766816, 44.0637456986212, 49.613413118547015, 52.407882213592536, 49.39475667092108, 48.73188787891019, 40.82540550539571, 36.76155936333441, 37.21285943062075, 37.85062897589899, 37.66323774091659, 37.18498706817627, 40.861350105654815, 38.10045649928432, 37.89966644779329, 40.08317539768834, 38.446668424913966, 37.65072930243708, 39.250864136603575, 38.37973317792339, 36.55891403075188, 38.349507393375525, 38.244089772624356, 38.3886291134742, 36.70506546574254, 45.522604603921216, 51.231496718622026, 52.07380217890586, 46.39385323370657, 44.16159706730997, 51.768037734493134, 53.20835951835879, 54.13902813388456, 50.74255366479197, 50.175673115638, 48.18241480858096, 51.358557977984034, 55.72476786951865, 53.47758316224622, 50.15147209167481, 52.61930581062071, 50.519908166700795, 48.782121673707046, 45.78325786898213, 42.67934906867243, 40.80769208169753, 39.56778380178636, 40.94248433266917, 40.471376296012636, 39.16274809068249, 38.034572447499926, 40.17320948262369, 41.37576895375406, 40.87745143521217, 39.11604442904073, 38.15198467623803, 38.16752510686075, 38.90280869699294, 38.67901786681145, 41.48849787250642, 41.46423801299065, 40.77571692005281, 40.68427862659578, 39.684497848633804, 38.81112721658523, 39.86138497629474, 39.052490265138694, 39.657935557826875, 38.993678246774984, 39.74694198177707, 38.41892550068517, 37.62658711402647, 40.638641849640884, 43.316891116480676, 51.33570624936012, 51.60476515370031, 53.98659306187784, 54.313036241839015, 55.81296236284318, 53.41869269647906, 51.64309847739435, 50.85333316556869, 55.32557648997153, 52.275227654364805, 45.216549904115745, 42.08940106053507, 41.87556128348074, 41.01992760935138, 41.44526943083733, 41.88260586031022, 45.19517298667662, 45.24969785444198, 44.751749038696296, 51.066141359267704, 59.88437867933705, 62.22497463226319, 62.35884904861451, 33.2500417770878, 3.2513551077535077, 5.8081736776136585, 7.8401418559012885, 2.04235302104104, 0.06532204968314018, 0.12004957834799444, 25.101135353888235, 58.63127554616621, 50.61282911608296, 45.608041671014604, 43.1286330376902, 50.14684369487148, 48.23238580457626, 61.78198214500182, 15.844538846323568, 0.3776523272597021, 0.02580045850106305, 0.04724870638681516, 0.0159357444405736, 0.01722896310140289, 0.05090229844133701, 0.02684080398701612, 0.049760252868215886, 0.06330330075035173, 0.05112711843403597, 0.01380544352991086, 0.04350006963396746, 0.08516638524710171, 0.15604375981755797, 0.1452206994497007, 0.23684199599008407, 0.09184345437754547, 0.2199670248815129, 0.08039948740793813, 0.21840950684441676, 0.07983180859516706, 0.10464905836288968, 0.08315386460913766, 0.1774736139322481, 0.21065971543712003, 0.0965013302442047, 0.27641451286692775, 0.08301217664754199, 0.8803920423792255, 32.308927889793154, 65.85651674578267, 57.3127394337808, 45.23368673939859, 29.242803281353368, 31.084681633980047, 48.947657462089296, 63.30309690967683, 36.640197307832786, 1.142728249392202, 0.10368543466733349, 2.0359968201768015, 9.776279176435164, 9.41567313286566, 3.4230480367137543, 17.65317020877715, 58.622936587179865, 54.90114073599539, 55.63742845289169, 45.081945926912375, 46.62568100037114, 48.138935335220836, 54.134007500063994, 51.91470299997638, 51.715207330642215, 52.25453715170584, 55.42813078049691, 54.108739591413936, 49.841330282149784, 48.58231221475909, 50.501755437543316, 50.415702558332875, 48.672569874794256, 45.777189962325565, 47.262885724344564, 47.225725189332046, 50.98041011441139, 54.24341024891023, 53.03430434196226, 50.10068524268366, 41.50550134720341, 38.72447813710859, 39.56272786663425, 40.23779915225121, 39.29867390663394, 39.243478313569106, 44.59622706136396, 39.23547667841758, 40.15871240246681, 41.86574751330961, 40.71859544323337, 39.45807510806669, 40.398835982045824, 39.671946264082386, 37.77284445301179, 41.32133037813249, 40.343157937449796, 41.21628146017752, 39.22579234646213, 47.19976694353166, 54.090771213654556, 53.09723877137708, 49.50967034985943, 45.083354057804236, 52.40959236698767, 56.649988312875074, 56.94391896647792, 54.623746795039025, 51.234744441124704, 49.552498709770944, 53.98704805681783, 59.6526607390373, 54.908601084063136, 52.560721289727, 55.02777445700861, 52.340033054351814, 51.44165731245472, 49.97336118452011, 46.57593357947565, 43.64970030323152, 43.048165613605136, 44.597490064559445, 41.97968452207504, 41.1227446986783, 39.60142597075432, 42.36901898537913, 42.27482718806113, 42.96349340869535, 41.1551473986718, 40.056946508346066, 39.311425532064135, 40.65108753019764, 40.47277658216415, 44.00471402752785, 45.19207039187032, 43.66465237832839, 42.56040319319695, 42.03388383311611, 40.15555881684826, 41.77519959788169, 42.080830681708555, 42.83240779753655, 41.35116392566312, 41.83756136125134, 40.931129071020315, 40.11426018130395, 42.232371453315984, 44.669528315144206, 54.85983425571073, 52.529299182276574, 55.49345001097649, 56.18710156409971, 59.379134255070845, 56.76524323801841, 51.89735435670423, 50.65808542313115, 57.37139455733761, 57.034447270054976, 48.07674615613876, 44.516316613843365, 44.77448701858521, 45.208956195462136, 43.50798506890574, 44.493276611451186, 47.83973301610639, 46.301591242513354, 48.05218035174955, 55.228101668819306, 62.064800723906494, 65.53356447527486, 64.83550025570777, 35.086424889103064, 7.563490223500037, 11.134398868007045, 10.341927120762488, 4.855283854469176, 0.2677448490454305, 0.25976561430481176, 28.540277365715276, 64.50021213100803, 59.200066289594105, 51.991726583050145, 48.501480010248, 58.52767398280483, 58.72965643482824, 70.23194420722224, 20.91094574620647, 0.6430144896430354, 0.12932117277335736, 0.14341040304110897, 0.12098130980326284, 0.09073445017659858, 0.17317065127914952, 0.06538519064985937, 0.15188024048843693, 0.15148769703603562, 0.16831909306347373, 0.08987810177307937, 0.13689733801349518, 0.22179316398837876], [0.08007966102130952, 0.011704509642215507, 0.08411587952005287, 0.13261337434091877, 0.032850547333157835, 0.04798962066190378, 0.03157114602565285, 0.05735234124585987, 0.06943672324620909, 0.022669732946181492, 0.04443389250926914, 0.07643946401414371, 0.06366387918411244, 0.04088340439803658, 0.025540971114570578, 0.5062100014859631, 9.641047620004224, 45.02808001733596, 49.29452442353772, 45.32405030342841, 28.045605690248554, 26.039825216416393, 43.266331764959524, 50.6165082993046, 41.652064631062174, 2.0561367201228298, 0.1037376435593732, 0.7227590331627477, 3.630704687487695, 2.756966333235464, 1.8831272230994318, 13.667193901154304, 54.575003500907656, 51.51241294799313, 51.75601959228516, 44.435409884299006, 46.86518092309275, 49.748193602408136, 52.694815358807965, 49.730244836499615, 50.45916241984214, 48.90710407687772, 52.16456190232308, 48.19439764945738, 49.73714428563272, 46.993913112148164, 46.987241160485056, 49.217916611702215, 46.40173327538275, 46.49155555232879, 47.37832892325617, 48.0637199647965, 50.37967951067033, 46.37791664369645, 45.62881454344719, 38.595553751914736, 35.526636415912265, 36.52533461970668, 37.030759473000806, 35.973767003705426, 36.716255987844164, 36.85355463335591, 37.47371665893063, 36.90695378088182, 37.25653110011932, 36.45792084355509, 36.047044723264634, 37.44499706452893, 37.65687173412692, 36.926840197655466, 37.464467710064305, 37.39685389303392, 35.7366205030872, 35.496151754933024, 37.042918820534986, 40.34933567047119, 45.89892072062339, 47.556228022421564, 52.53272341143701, 51.152802205854854, 49.373873972123675, 51.37826396572975, 50.654527833384854, 53.26244900303503, 50.41722051558956, 48.84070227223058, 48.558542651514855, 52.38395183317123, 54.188473532276774, 49.499440808450025, 52.31073294916461, 48.78425152071061, 48.6145305633545, 42.04882806347263, 40.60632544179117, 38.610121434734715, 39.31762679930657, 41.555754753851126, 38.71654318224999, 36.106299969457815, 37.328616419146144, 36.74394399889054, 39.10061382478283, 38.83428489008258, 37.77575092930948, 37.712079094302275, 36.841191322572776, 37.54613145705193, 37.551987555719194, 37.11207020667292, 37.77842990813717, 37.98618216668406, 37.459352939359604, 38.6398490782707, 38.00353865469656, 38.024746910218276, 39.126085696681855, 40.424331388165875, 36.91463770404939, 37.486735005532545, 35.934084384672104, 37.014822882990686, 35.72790891893449, 38.21839040325534, 41.13491189095282, 47.92662136016354, 48.500264075494584, 47.866220781880045, 50.65392378837832, 52.16308709113829, 51.47424828621649, 51.3945653361659, 51.484226795934866, 54.17919712681925, 49.95766778146067, 48.23997951322987, 46.61928361462009, 49.02731295554869, 40.881675827887754, 41.05182432359265, 38.230651732414, 41.79276004914315, 44.231458402449086, 51.31591789184078, 54.22642246369393, 60.26835910735592, 58.369990779507546, 31.202466487884525, 2.1172336416859783, 4.372191015751132, 3.1452385696672627, 1.0669996613456358, 0.01988675576754876, 0.15897740159303914, 24.490649815528627, 56.85464582135601, 42.02151267759262, 38.613329933535674, 47.6305922385185, 51.72569967085316, 52.467749349532596, 46.64266486321726, 7.317390912963498, 0.14066123523779456, 0.07463006392842339, 0.04785596130175456, 0.07016845212708558, 0.06882602859648966, 0.06903896273504342, 0.016122056066148704, 0.02448826096951962, 0.0837794520081051, 0.018923656842220696, 0.041562081690156655, 0.02881669796132032, 0.02199014975509096, 0.0484922509490242, 0.06166848444169568, 0.11380952407395649, 0.039309304387819384, 0.021043000780346415, 0.050875546651021133, 0.038819130690347765, 0.05014258053814692, 0.011125192996264707, 0.03704494000562737, 0.04014953813185135, 0.028636184663722114, 0.019725233789593465, 0.06089555535225138, 0.05129801732818446, 0.526962404049212, 13.996205252985801, 53.24435510943013, 55.04072220094743, 50.22779749285791, 31.254233929418753, 24.051669912953532, 47.803309886686264, 55.34731034309634, 44.65071662779778, 1.8238249084641858, 0.21991552845124276, 0.20300899452019125, 4.2587727404409845, 5.851370250025104, 3.706872948715764, 13.587310910224916, 57.86118484312489, 54.300578794171734, 53.98442006880238, 45.86096394446589, 48.34714651107789, 52.13776819167599, 55.19560483194167, 51.12591043595345, 52.78854823881581, 51.213720537001095, 53.91097368732576, 49.89990303593297, 49.38350731326688, 48.97464336887483, 47.62223759005147, 49.025355692832704, 47.90172607667985, 47.21777062262259, 48.583057465091834, 49.08279880400627, 51.33922853777486, 49.76353399215206, 47.544766856778054, 41.45458898236675, 36.81382102351035, 37.85365312330185, 38.640178557365175, 38.65496981528498, 38.260473512834125, 38.56590063341203, 39.566975793530865, 39.22962450212048, 39.26289404592207, 38.24492131510089, 37.107492800681825, 38.667007569343816, 38.23768454213297, 38.17315763042819, 39.1795083784288, 39.54005656703826, 39.00885389697167, 37.356198526197865, 38.1861916665108, 41.25801940118113, 48.357885960609686, 50.111161893413914, 53.69432549322806, 51.38580276120094, 50.082936517653934, 52.52840880424746, 53.61825504610616, 54.551579106238584, 52.83644822336013, 51.80976390838624, 50.22684043453586, 54.77060817903089, 56.22575652214789, 51.688499912138916, 54.15896161910027, 52.04518456612864, 50.54756872115597, 43.0241410962997, 43.53930127236151, 40.76411847145327, 43.64376575716081, 43.109299675110854, 40.4741023432824, 38.863922319104596, 39.654562319478686, 39.90516647215813, 40.11537413443289, 40.037154228456565, 40.739587968395604, 39.91660018121043, 38.575910522091775, 38.93072812787948, 38.847926893541896, 38.061283788373395, 39.96502184098767, 39.415203602083274, 38.99773397753316, 40.29547368326495, 40.954788807899725, 39.38109467106481, 40.71131552419355, 42.179309629624896, 37.67024309404435, 37.86623216444446, 38.06777923337875, 37.95439135643744, 38.967468969283566, 40.49839358175955, 44.514512323564105, 50.76963370846164, 49.99205912313154, 51.28841423219251, 53.6124538606213, 54.155917859846554, 54.30122598525017, 51.87276894046415, 53.73657334235407, 56.635165675993896, 51.686828982445505, 49.25267273379911, 48.07236486865629, 49.944414092648415, 43.18064366617511, 41.84111895099763, 41.34851240342663, 42.81481988968388, 46.37205270028884, 53.046420543424546, 58.59791186548049, 61.87693488213324, 61.44413663494972, 33.975982281469534, 4.056854762377278, 2.0620902651740662, 7.792924363766947, 1.4799977838993075, 0.14993411669087026, 0.10959528972424808, 26.627690445992258, 62.29888777579031, 48.062511874783425, 43.978312553897986, 48.28599676009148, 56.74970672976587, 57.71433130387337, 54.095784002734774, 11.052213445786508, 0.2875430431337126, 0.03312368449124117, 0.024600159602179646, 0.09058656456369547, 0.022964954503902027, 0.048816761963309786, 0.019762247327655073, 0.01366304023371589, 0.0033023898187468973, 0.05389527755699331, 0.015609475254501789, 0.04217691321466719, 0.01850471974560811, 0.2220377758626015, 0.16525938385917296, 0.21124482275016848, 0.31426130944202024, 0.08707513927572197, 0.15626027158671812, 0.1201065906113194, 0.15427572081886953, 0.21443366373498596, 0.22332633575124128, 0.23310115801230555, 0.15577218164840054, 0.1645493888927083, 0.08033278413237104, 0.13114539666041253, 0.5745815714040111, 17.871081406070342, 63.97120991060811, 62.38691360719743, 57.605909147570216, 38.540358158849905, 36.6460887078316, 56.83297080378379, 61.128374068967766, 51.46104166584631, 2.5490934618057746, 0.3464765017551761, 3.0344975571478567, 10.312747628458085, 10.402268863493397, 5.5354360803481075, 16.2793335799248, 58.803730395532426, 56.3340296283845, 56.19306356676164, 48.698634024589296, 51.221031835002286, 53.46707905492475, 56.31122889057283, 52.0735276129938, 53.48820494067285, 52.65710961434149, 57.2981168377784, 52.08133705200688, 52.36413209669052, 50.500614027823175, 49.55282818886542, 51.05042049961706, 47.12037817124398, 51.20426762488581, 51.70044352931362, 52.22792387008668, 54.52201620224984, 52.21320713720014, 50.794046540414136, 42.039481055352, 39.68348587712934, 39.96861473206551, 41.310763512888265, 39.93900868200487, 40.18526684853339, 39.222764276689105, 40.507979854460686, 40.831398887019006, 40.27930959578484, 39.68003811374788, 38.18476392376808, 40.224008098725356, 41.46214346731863, 40.684372763479914, 41.55132247555641, 41.888089333811116, 40.95729520243984, 38.95913785503757, 39.88879449905888, 41.70777405461958, 49.60875726515248, 53.196157024752715, 55.99285402605611, 55.138369606387236, 52.72826925400765, 53.68568843410861, 54.41152695686587, 56.24481924118535, 55.57252891602055, 54.923831647442235, 52.21217555384482, 56.11835810445971, 58.460040553923584, 54.111010643743704, 57.273221554294715, 53.519003391265876, 54.252776868881725, 44.83983370565599, 46.72740767079015, 42.75058715574203, 44.95104858952184, 45.319417984254905, 42.85994675851638, 40.536879877890314, 41.66407492852981, 41.593946872218964, 41.81983617044265, 41.36174255801786, 41.92896435337682, 41.19755606497488, 40.718226740437174, 41.31512518851988, 39.152542083494126, 39.88220099479922, 41.75646243556854, 42.3150981626203, 41.1132368733806, 43.27714181715443, 42.019163177859404, 41.19857980358986, 43.6653309483682, 45.85761424033873, 39.326275625536525, 40.404574409607925, 38.832437453731416, 40.01240407266925, 42.228327489668324, 42.572370344592684, 45.238554400782434, 53.3981433991463, 53.53841912361884, 53.875621364962676, 56.30741242439517, 56.06442943696053, 56.789346202727295, 53.38163414309102, 53.26815997400592, 59.822950440068404, 54.49324169466573, 52.997551733447665, 50.53984949665685, 52.93373477074408, 45.977513251766084, 43.6167327819332, 43.41171833776659, 47.213181449520974, 48.71440587505218, 56.78848720365956, 59.618320388178674, 65.46732741017496, 62.8855449153531, 35.69528264384116, 4.377527890666839, 9.181204630482583, 13.669751286506655, 2.9450547695159917, 0.2010429217930763, 0.2577163903943954, 30.184299599739816, 69.65183350347704, 53.9020699070346, 54.66535137545679, 57.660665435175744, 64.2895455514231, 66.89484657779818, 64.65503984881987, 16.669694723621493, 0.4062566713940713, 0.13019435978945226, 0.12710989062343875, 0.17985254676351625, 0.11266305051263302, 0.1511545713630415, 0.13791458020287176, 0.12813012055572004, 0.1752488946001376, 0.11636441197967339, 0.13895912576586972, 0.11200250652168067, 0.16926813810583086], [0.04498720334302034, 0.051595565877975, 0.014268345454887999, 0.0287495254568996, 0.046716156535811966, 0.0613554111201196, 0.010169386270365888, 0.1041317421702608, 0.06468049701183073, 0.027804912233184424, 0.03062725100936669, 0.0372083465598764, 0.020237105012300517, 0.07229947124517734, 0.09637493339757766, 0.05639304211663623, 9.418404083098135, 45.54988861083985, 49.99480478225216, 39.44463706785633, 26.464145260472453, 31.389186997567457, 41.627055598843484, 49.23739510197794, 51.64811126647457, 6.679778752788422, 0.024165904577521068, 0.1684636998200609, 2.1909808199251852, 5.424693351791752, 1.8712718592536066, 10.155903812377684, 47.66096315076275, 54.26015484717585, 52.465756785485056, 49.541410169293805, 51.94564657826578, 53.05253551852319, 50.45706787417012, 52.63406176720896, 51.43959414574408, 50.72278099675333, 50.155143430156095, 50.68414172818584, 53.187080660173976, 51.04041453330748, 48.70910675294938, 47.017729743834465, 48.104798947611165, 48.68512538171584, 47.529967754117905, 47.977216013016246, 47.18972567589053, 41.74700167871291, 37.852476412250155, 36.09361502432054, 37.523907307655584, 36.62427640730335, 36.40304296247421, 35.564663794732866, 36.63683583659511, 37.20610903155419, 38.75757117425242, 38.78556513017224, 39.85596033834642, 38.151011928435295, 37.76307775128273, 36.22519093175089, 36.65764793272942, 36.986903452104144, 37.19762886724165, 36.425086682842625, 37.21518147376276, 37.00120833612258, 36.374205696967344, 38.8350889759679, 40.35940439470353, 44.60746465190765, 47.51417236943399, 50.23969404159054, 53.21658472861014, 48.76459260140696, 49.13012612250544, 48.48318607576432, 52.17316366011097, 56.16911749685965, 52.90545840417185, 51.53802602521835, 51.71090449056318, 48.78705209301364, 52.26712795995897, 49.224816060835316, 48.034427704349646, 44.32861943398753, 43.98731047107328, 43.28928547520792, 41.56530180285054, 43.17315978388633, 42.849262222166985, 39.006955469808275, 37.92842134352654, 39.6519107972422, 36.54131827815887, 37.915234335007206, 38.18050815213112, 37.34363909690611, 37.548955563575994, 37.976721409828436, 37.947640957370886, 39.169620083224395, 37.938980364030414, 37.372452828191946, 40.73479875441521, 41.730865047824004, 41.57014200764318, 41.63287247380903, 41.91798563926451, 38.8038472975454, 38.90718213973507, 36.98948437167753, 36.9562344397268, 36.37052259137554, 35.69201530948762, 37.591430910172, 35.872554163778986, 39.04017794516779, 41.99316570835729, 45.405796420189645, 47.21450721063922, 50.76855897903443, 51.658074086712254, 53.13082994953279, 50.92430845383675, 50.767790194480654, 52.74069532271355, 52.934260368347175, 54.754318575705256, 52.71083039622153, 50.57518612953925, 42.06419198743759, 41.88667728054909, 40.76783687837663, 44.999062322801166, 50.36701809975409, 55.910441106365575, 60.25829038312359, 57.74711447377359, 30.455970802614768, 2.742401347044976, 1.1322073494234393, 9.08477217920365, 1.1940679074295106, 0.08126451558763943, 0.2161735873068533, 26.474337539365216, 54.650238483182854, 46.79135407170942, 31.512370994014127, 45.119192754068685, 44.32284178272371, 49.247314776143725, 53.98429847532704, 8.623111171107139, 0.1329303968457445, 0.02386993033841493, 0.025308649205873092, 0.10715232726426856, 0.045463748336319006, 0.07163983123797564, 0.07758609845393127, 0.03966824722386176, 0.10853779727532979, 0.003829541622713629, 0.0625443604264048, 0.03710254981753327, 0.03429943410259101, 0.09850722422162372, 0.08699693702041142, 0.053361536439267866, 0.017507198574622313, 0.02870587951263353, 0.09455263239121246, 0.020155512817925023, 0.05546653155057181, 0.07323526296644442, 0.012334249237732542, 0.023340841289609674, 0.04929483913245702, 0.04269437113356206, 0.07530366971848473, 0.007119192356889647, 0.04427058171601065, 11.162163365271784, 50.84624152029715, 56.546955493188676, 46.90921345064717, 31.094387538971443, 34.16076514028734, 49.909810942988244, 56.10250780659338, 54.486754094400716, 6.47558702576545, 0.06057126650346383, 0.11782675125305692, 2.1815173664400658, 4.346257284764321, 3.1726522599497153, 11.786792970472767, 50.43603220293599, 56.04590016026651, 53.48466696277742, 50.07409549528553, 53.90067746562343, 55.385612287829005, 52.38884302877611, 53.983094307684134, 53.407631612593136, 52.05326072631344, 51.8244335728307, 52.916115483930035, 52.18777448900285, 50.994260003489835, 50.60290159717683, 48.760070108598285, 49.89348603833107, 49.9229234264743, 51.27743159571002, 51.43114143802274, 49.86582156150572, 44.83137707556448, 40.481115541150494, 37.39514766200897, 38.17959816225114, 37.920874703315, 38.220147625092544, 37.19939001144902, 39.396717471461145, 39.66242274930401, 40.98750921987718, 38.94755509591872, 41.97132202886766, 39.224835288140085, 37.76842001945742, 37.77216980534215, 38.97920470083914, 39.20390944327078, 38.13037633895874, 39.403165848024436, 39.313225899973226, 37.38392576094597, 36.26418321363388, 39.687063078726496, 42.352513651694025, 45.716789384042066, 50.2811848732733, 53.00269396074357, 54.488232827955684, 49.46698319527411, 50.187263719497196, 51.05666491293138, 51.72709211226433, 55.48517773228308, 55.61682424237652, 53.92633761129072, 52.5891859300675, 50.32626467366373, 56.072446761592744, 51.8371851982609, 50.31970647073562, 46.13740474947038, 46.21524026316982, 45.10105179202172, 44.55590117362238, 45.203802201055716, 44.48156833648682, 41.6874954008287, 39.916835523420765, 40.9149649835402, 38.46884942823841, 39.62505040630218, 40.038264259215325, 39.70418814689883, 39.5209663914096, 38.346785268475934, 39.6275842574335, 40.64550207507226, 40.28039216995239, 39.65774336168843, 42.44495999428534, 42.69533664949479, 42.12437683536161, 43.09679123663133, 42.96679996675061, 41.30973585190312, 40.802891100606615, 38.10215488556893, 38.75542563776816, 38.36039589297387, 38.38456161560551, 37.67402818126064, 38.24996548314249, 41.05418559043638, 44.65704341088572, 48.318964281389796, 50.26320865077358, 53.10263595273418, 54.4126134534036, 56.180319786071784, 52.03988544402584, 53.310878507552616, 55.228619421682055, 55.383933513395256, 58.33200654675884, 53.9464593702747, 52.04077974442513, 43.803245405997004, 43.549546503251605, 43.40957280128233, 47.33457488398398, 52.91546437048143, 59.46252776730446, 61.88515617001442, 58.197559464362364, 31.760260866534328, 3.6309385588092193, 2.4208111195795, 9.34034695548396, 2.2773501853789053, 0.10666715612094249, 0.31863962450335104, 28.1968464005378, 60.868215022548554, 48.7828080884872, 40.99373402134065, 51.33162306201074, 50.55825717987553, 56.14150401084654, 57.87099469092585, 10.540124485569617, 0.07728560046563226, 0.07216417245687017, 0.09859436672301063, 0.03465133276016962, 0.05182223980345073, 0.08604265959753145, 0.044445763041655865, 0.02329767606551609, 0.01310195935319268, 0.048518144720864874, 0.010094731002144757, 0.07973826159873316, 0.032080159740402334, 0.17253967062119516, 0.21897345480899658, 0.14375678203519315, 0.09631543900937804, 0.07606083271844734, 0.2508912824334637, 0.05916338842061739, 0.21564786712969505, 0.1511176306033327, 0.0686645832273268, 0.18075394113698315, 0.14056073982388745, 0.13468176577120058, 0.18821038215631442, 0.1890254384207149, 0.13875497865580744, 11.889310979074049, 58.48631258933776, 64.65753447624945, 53.753894529035016, 37.34179558292512, 41.806009815585234, 53.54857806236514, 59.559112210427564, 61.85460090637208, 8.675855282814272, 0.13625238391180194, 0.9856233505472061, 8.119218493661574, 14.26774113408981, 4.603203910012399, 12.427447419012747, 52.05067588436989, 57.4147092911505, 55.08427619934083, 54.71116465906943, 55.72916484648182, 57.005406041299146, 53.050699849282545, 54.75614247783538, 53.652003119068766, 53.69461967099098, 53.45171513095979, 55.712279042889996, 55.50506807142689, 52.159772688342684, 52.643769633385446, 51.9096705990453, 51.78267601997622, 53.11243403342463, 53.894574257635306, 53.1841584943956, 52.847493617765366, 45.84307401410995, 41.19512027309787, 41.35654149516937, 39.91751801583075, 41.11385660786783, 40.57810791077153, 39.307044244581654, 40.85317196384553, 41.88748921117475, 42.988706404163, 42.19603069366948, 43.19891798880793, 43.26678283752934, 40.817388180763494, 39.090905958606356, 39.75112322838076, 41.60572182747626, 41.034299173662745, 40.38274641959898, 42.776059027641054, 39.002217246640114, 38.90020032082835, 40.78688783030356, 45.34658432006837, 47.797865636887096, 53.395546790092226, 54.33523685701432, 57.66895732572002, 51.30745341700893, 50.18736962349185, 50.883617785669145, 52.13019409487325, 55.31445657053302, 58.245996813620295, 56.139280026958836, 54.072928351740686, 53.49055836277624, 58.010893867861846, 53.67165419363207, 53.37295001552951, 49.7270598719197, 49.79970608988116, 48.048246214466715, 46.16618317942466, 47.996478772932484, 47.19646430784657, 43.98645147200554, 41.55438976903116, 42.63656385483281, 40.17611988129155, 42.57509246949227, 41.35234848145516, 40.60784339904785, 41.45862117890389, 41.81242289081697, 42.58500037654754, 42.34190364037791, 42.65174342739967, 41.620720971015196, 44.99519486581126, 44.97008777433827, 46.39504955660912, 44.77251014401836, 45.29113377294233, 43.62491092374248, 43.67779624077582, 40.50105687110655, 40.73683446453464, 42.0885028377656, 39.464888265056, 40.881762120031546, 40.0566876319147, 43.13364974914059, 47.1434417078572, 49.97722471913984, 51.13079770918816, 56.493132729684156, 56.37784250320927, 58.33270080627934, 54.64276636800459, 55.358657760004846, 56.791115191675004, 56.44211446085284, 60.13314324040567, 56.87341828500071, 53.64838277139972, 46.52573508601035, 45.89310384565785, 46.19715813667544, 49.82604088321809, 56.15029012003253, 62.431240312514774, 64.17450635663926, 59.909219049638324, 33.953624771487334, 4.554194875301854, 7.742076227741857, 18.13382137206293, 3.624120008560919, 0.26739287760949904, 0.5744148093846537, 31.98771126808659, 69.10669465218821, 58.59004751328499, 46.38171742039342, 54.8352135381391, 57.29202147453063, 64.8203089160304, 68.22332982094058, 15.13059393052132, 0.34041389642703923, 0.21313086993271307, 0.15071508204264028, 0.3228791550763192, 0.180194589699949, 0.1501658582879651, 0.09915184124463028, 0.14198782373099558, 0.16078484815455255, 0.12409253075959222, 0.17153318430627548, 0.1600841994607641, 0.11839265274184367], [0.12387385096160636, 0.04223111776574966, 0.05387555462338271, 0.027361083024692152, 0.06238132159435942, 0.07548635104490865, 0.03572112475071223, 0.08084617029394835, 0.05015426720943182, 0.0299256983318276, 0.039358494893437436, 0.036736041863238623, 0.037282653258091984, 0.042251871087618416, 0.10490333060583762, 0.05942474697686492, 3.491636807880094, 39.26436493473668, 49.91580432461154, 42.32771250509447, 33.757035578450854, 24.111374270531442, 39.37421875615274, 43.78777557803739, 54.63086197453161, 13.467619784416692, 0.14513848289366693, 0.05961940991842459, 1.2808933709898305, 2.933719119717998, 3.592859453731968, 6.3088867837382905, 38.98789667314099, 58.13723733348232, 54.561114388127486, 54.25455370256978, 50.92601860723188, 52.150343310448434, 50.567200183868415, 52.76738312936599, 52.17921587728685, 51.634112327329575, 50.5746683766765, 52.260075538389145, 51.03196574795631, 48.59014518799321, 48.99886792705905, 49.82582515285861, 50.77550941897977, 48.91932225996449, 46.37747733823715, 44.45918336991341, 40.38557837086339, 34.17550148502473, 34.85741338422222, 37.13841676712036, 36.06473461274178, 37.248247054315385, 37.915359850852724, 37.66193551401938, 37.861509630757, 39.789719350876354, 42.69803131780317, 41.61478250257431, 39.496090719776774, 42.24922195557625, 40.54043746763661, 39.655813555563654, 36.71050579317155, 38.13743268289874, 35.89814762915335, 38.703112986779985, 37.730341649824574, 38.31448062773674, 36.48489106085993, 35.7296779078822, 35.39922998797509, 37.97912582274407, 43.839950946069536, 47.913916803175404, 48.653781721668864, 48.504327650993105, 40.14399174721011, 47.31963457599763, 59.67833265181511, 53.52773458726945, 52.11883491085422, 51.57810872600925, 50.7808477647843, 48.07774243816253, 50.56533705803656, 51.16704433195053, 47.51484309473346, 45.12175013942104, 42.324045088983354, 43.89572704991987, 43.786163483896566, 44.13543093589045, 45.03011572745539, 40.39526662518902, 37.746937198023645, 38.81222940260364, 36.39448042838804, 37.03246570402576, 37.906946366833104, 39.18227364940029, 38.578565966698434, 36.53304992183563, 38.975258796445786, 37.27406409478957, 38.24327784199869, 43.4896009199081, 47.022311072195734, 46.800297075702304, 46.87677544932212, 47.17339684886318, 43.811015621308364, 40.510831417575965, 39.64205388099917, 38.21793148594518, 37.467138844151656, 36.19167035625827, 38.23462117102839, 37.449331283569336, 38.37417125701904, 38.003409216480875, 36.349090760754, 36.725026407549464, 42.11078582271453, 48.30220399364349, 49.71443376233501, 50.618940168811434, 54.33176555941182, 54.07835691205917, 51.90865470517067, 55.12758308841337, 41.13768108429448, 55.080114564587994, 53.32274759969404, 49.6663337369119, 41.99434241940899, 40.9641005146888, 45.00425946327948, 48.33049212732623, 58.06204157490885, 59.52941986822314, 53.797679947268584, 25.435984173128684, 2.84378971303663, 0.5981634737503144, 5.973387341345511, 1.2197491358364783, 0.036288397536883434, 0.5238521483636672, 32.357059294177645, 55.45221021098476, 39.863903137945364, 37.31206401701897, 40.13005948835804, 41.92020962315221, 54.28945887473322, 47.21325597455425, 8.144539354308959, 0.05349374023236094, 0.04453565962913056, 0.050535146973185965, 0.009017900578797826, 0.012723268685682167, 0.04903241954443436, 0.03835116971224066, 0.10071239298990659, 0.02229544345379597, 0.06784345954656601, 0.037789715363854365, 0.04000238030247631, 0.022897624951456825, 0.047271355776296514, 0.027709384899466272, 0.09438747149561683, 0.008503257075414784, 0.024671227663695335, 0.04147949741191922, 0.09753711176134887, 0.05295726418074581, 0.0769919666251348, 0.03187793359581021, 0.007159914718114681, 0.04134026093168124, 0.006919958264446788, 0.0648797947853323, 0.0921442051748595, 0.022999014773015535, 5.218744402931583, 46.54439380092006, 55.58770064384707, 48.34207880881525, 36.632940923014, 29.211747915514056, 45.46538506784747, 51.091330820514315, 61.41642901205248, 13.458557148133556, 0.13598129603891604, 0.12565586340403365, 1.8203895250635764, 3.380536898489922, 4.167907113029111, 6.752345052457626, 42.837691230158654, 60.128204976358724, 55.979113963342485, 55.00349498564198, 54.798570755989324, 52.69971832152336, 51.61799530829153, 53.581223949309326, 53.0255143104061, 54.51143364752493, 52.60549906761416, 52.46785133115707, 52.35727579362931, 51.056170694289676, 51.039614369792325, 52.0560573762463, 51.77632962503741, 50.69580293470814, 48.24022270018055, 46.194177135344475, 44.359927792702955, 37.05655297925396, 36.83950862576885, 38.29159752015145, 37.643014000308135, 39.57666797022666, 39.5806295641007, 40.20852650365522, 40.39530192652057, 41.65513584690709, 44.6635074769297, 44.00900510049636, 42.101815362130445, 44.77900558902372, 42.40632464808803, 40.991357065016224, 39.077307101218935, 39.239332368296964, 38.93132432814568, 39.97656145403462, 38.31275086249075, 39.39528188397808, 38.10664207704606, 37.05814938391409, 37.513956254528416, 40.42335864036314, 47.32192524017827, 50.695210656812115, 51.89551868746358, 51.11544555233371, 41.7094567514235, 46.45515203475953, 58.97842491826704, 56.46433076550884, 52.73657683403262, 52.41903351199243, 51.05528031626056, 50.374764780844416, 51.768269154333304, 52.9429131169473, 49.78977464860486, 47.18697217202956, 44.936402459298414, 46.33295843678136, 46.38633797245641, 43.73971085394583, 46.313244604295306, 43.52368239433535, 39.03653798564788, 39.65736681415189, 37.99658037001087, 38.50301327243928, 39.27064072701239, 40.69274702379781, 40.64542755003899, 37.56481762855284, 40.34211850935414, 39.578672301384714, 40.61327980410668, 45.6198440828631, 48.02490026720109, 48.69363692498977, 48.866166299389256, 48.4538467468754, 46.58367241582563, 43.79976234128399, 41.05446800108879, 40.28861345783357, 38.42551508257466, 37.74535256047403, 39.08067249482678, 38.2937156000445, 40.022304134984175, 40.14368972470684, 38.169227415515536, 39.359419653492594, 44.232599812169234, 50.554044554310465, 51.39088615294426, 53.165813569099676, 56.66277131726665, 55.0608596494121, 52.33234520881407, 55.67809166446809, 43.74065222278718, 56.18978446529758, 54.31538574157223, 49.78406367763397, 43.59095888753092, 43.27964036695419, 46.492332181622906, 51.07479410786783, 59.65560251666654, 62.365328804139175, 56.87847422015283, 26.580049337879306, 2.6288249511872572, 3.7050166870317156, 5.504214013776472, 1.603223823251263, 0.04425690321612262, 0.6058410230663516, 32.98797253639468, 61.444524949596776, 51.866551983741026, 42.656767983590406, 46.05656862258912, 52.76918741964525, 61.55604970070624, 57.22595307134814, 10.84809918557444, 0.0902420854676635, 0.03671536515016229, 0.02137432806193829, 0.0291094220724077, 0.031430800633144476, 0.03944691676165789, 0.012931605339080337, 0.022994877898224422, 0.06306765593528267, 0.05648890652904107, 0.03306645006241818, 0.06899608479392144, 0.04682423622016946, 0.19070018323198443, 0.1347318219561731, 0.3056276517529642, 0.13508601504708492, 0.11235567305477397, 0.22270798022227906, 0.1887171952835014, 0.25063465830058823, 0.1973049183406176, 0.13914671005500903, 0.157139326836313, 0.15390252874743554, 0.16532459326328772, 0.18931840576471823, 0.19528920311600934, 0.1990669358882212, 5.427591983349093, 52.48918118015413, 63.97327699968892, 54.811765609248994, 43.54565943441084, 33.824123797878144, 51.403237696616884, 56.428401854730424, 66.34263961545884, 16.7177672924534, 0.269741672541826, 0.4604810181884997, 4.94350923645881, 7.530961517364749, 6.785459662637403, 8.138250324033923, 42.30802612919962, 62.860076965824256, 58.43288990759081, 58.80857060032507, 54.87724957927581, 52.89997493067096, 53.972358780522505, 54.424447244213475, 55.68144529096542, 56.08886580313406, 53.09724269374725, 56.524743110902854, 54.83438199566257, 52.848007448257945, 53.66816720654888, 53.2052412340718, 53.22041688426849, 54.35621761506604, 50.51998661410425, 48.57170612581315, 45.12007136498728, 37.68414005156487, 39.59414212934433, 40.67560626614479, 39.98215867627052, 42.72209505881033, 42.25617631789177, 40.95313749005718, 41.90688925404703, 44.5065224555231, 46.83135048035653, 47.53453339299848, 43.812031515182994, 47.3526373986275, 45.023008392703154, 43.14575026112218, 41.09362110014885, 40.25059000138314, 41.284766043386156, 41.75450909522272, 40.48642250799364, 41.77574480733564, 40.541673014240885, 39.18978891065044, 38.651694636191095, 42.18750738328503, 48.34738969802857, 52.2706384812632, 52.78873651258407, 52.204593612301736, 43.28406087813839, 46.74943570167788, 59.36901454002627, 58.783757686615, 55.909280084794574, 55.23893525523525, 51.71512496086859, 52.10542824960525, 54.09548590260168, 57.361259152812345, 51.27039094125071, 51.11972485819171, 47.25812788932554, 49.226381086534076, 49.64951461361301, 46.200590210576216, 49.22962096429641, 44.88931048300959, 40.99006268285936, 42.30237791615148, 39.14049648469494, 41.04534064569781, 40.54491681437339, 43.294463003835375, 43.36355555442072, 39.0417351261262, 43.187547037678385, 42.17102166145079, 43.09932116539248, 47.63366345436343, 50.585956958032426, 51.146157710782944, 52.6838719460272, 51.79560415206417, 49.90362928759668, 45.89602208906605, 43.214199542999275, 44.11654472351075, 40.17816343615132, 39.77544584581929, 43.39840581340175, 41.57129126210367, 41.08076749309417, 42.390046811872914, 39.62030433839367, 39.523064859451786, 46.853264762509255, 53.875303652978715, 54.66821862805275, 55.52582525437879, 59.40978757796749, 58.08952562270626, 54.039572515795314, 58.54770944964502, 43.85995895631852, 58.167855355047415, 57.58262203585718, 54.13766314906459, 46.87604588847007, 45.5956587483806, 50.25169257194766, 52.86588168913319, 63.91092700342979, 64.66617545773907, 58.07939806292134, 27.78818249702454, 4.540810277385097, 4.385657002848964, 15.486247001155732, 4.257412168287462, 0.2215882507903922, 0.7371001378182442, 38.527418259651434, 67.6965476620582, 55.3509150012847, 51.14044281744188, 53.68086784116684, 56.784784486216886, 70.68762163962089, 63.642966362737845, 14.135821038676848, 0.2721560446004714, 0.15339137956259713, 0.14179288499778317, 0.1986917366664256, 0.08924915124812434, 0.1036451690860333, 0.14165203207202498, 0.2463422983043617, 0.09721413675335147, 0.1585448223857149, 0.17210802604113856, 0.13800379880253347, 0.18697359448959752], [0.03678610187865073, 0.04628825429526549, 0.012618474560909936, 0.09314605665783729, 0.09635454779791255, 0.06898625588585293, 0.07409980851075343, 0.049713138460872636, 0.03313114235718404, 0.03582761863306646, 0.04622817768024341, 0.02071953930651709, 0.10587377248391991, 0.03986449596742469, 0.08930161294917907, 0.028914406730402863, 1.7768181211525396, 30.68073634178408, 51.02139496034192, 42.41445572145524, 33.902010302389826, 29.478990762464463, 40.367813956352975, 45.90094858600248, 54.91086429165256, 21.120304215338923, 0.262887054874051, 0.09131722858235722, 0.4323135586755891, 1.7002523522223196, 2.4037630279218, 2.349229579971683, 21.736159478464437, 47.63568347500217, 55.38499647571195, 53.19235624805574, 51.447540867713194, 53.95091518279045, 54.221040971817516, 53.050217397751354, 50.80338570379442, 50.56295617934197, 48.039868031778646, 46.141668365847686, 49.75224933316631, 50.948297669810636, 50.9863172038909, 50.927885655433904, 46.28872194597798, 45.9675229749372, 41.17475924953338, 37.93949027215281, 34.22402904879662, 33.950914413698264, 35.508970060656154, 36.10454274762061, 37.179287864315896, 39.502829351732814, 38.49028518123012, 40.114672030172045, 38.97664339311662, 40.36121652972314, 42.83591831884077, 42.06080305960871, 43.92942805444041, 42.07639840341384, 43.43788446918611, 41.158493180428785, 38.71482126174435, 36.73301627559047, 36.920725222556825, 39.52653615705429, 36.971751336128484, 36.91953282202444, 36.493939968847464, 37.76408187804684, 36.17374904694096, 36.359532110152706, 40.54266537389448, 50.44655592210832, 50.62666723805089, 50.34835154010404, 46.64883475149832, 44.355844605353575, 45.435355401808216, 49.932395950440444, 52.80646170339277, 53.381712590494466, 52.18513865624705, 47.34227449663224, 52.627691838049124, 50.28616236102197, 47.35012708171722, 42.36590854583248, 43.25282704445624, 43.43019662364837, 45.23377695391255, 46.83688494466966, 48.25750466315977, 43.32557916641236, 37.12684969748221, 36.949825286865234, 37.18022138841691, 38.128725021116196, 38.30531797101421, 38.807267604335664, 37.807800615987475, 38.627321027940326, 37.76416817019063, 38.955290009898526, 44.62612336681735, 49.22904829825125, 49.54219464332827, 48.44429185313564, 49.403185844421394, 48.263007748511534, 47.851653099060066, 47.07573767631285, 47.15627570306101, 46.15039563948109, 43.289367844981534, 43.388223340434415, 41.125317773511334, 39.28118798040575, 36.581703001453036, 38.12680698210193, 37.538172967972294, 37.87623420838387, 35.47631632897162, 40.72349448357859, 46.19632659419891, 47.432088928837935, 49.42985403922297, 50.79639211777718, 53.74104484435051, 50.64598098877938, 51.75472913249847, 56.119421066776404, 57.198233681340376, 52.93583716115644, 48.58818008053688, 43.10681681479178, 41.914404515297186, 47.30435694417646, 55.005464015468476, 58.660712934309444, 51.50359153747559, 18.981331817565426, 1.1483996289391671, 2.986529911718061, 5.40383909017809, 0.7587687202518987, 0.10073026582118004, 1.0612748395050726, 31.91942672575674, 54.79937876424482, 37.76034778164279, 39.59014523413874, 38.94615873213738, 35.26874057708248, 55.13504343648111, 43.17889428907826, 4.480909801298573, 0.052374382353117394, 0.022245144035907525, 0.02366297551611018, 0.03030735375960508, 0.07393834015895283, 0.07327474713806184, 0.05624538633011042, 0.05140560288583079, 0.0638073712827698, 0.03205359564162791, 0.062316790178057656, 0.040512537403452786, 0.012686166089899358, 0.10336033759578582, 0.038509987399823246, 0.034941634118196466, 0.008605099846458724, 0.08661435271102576, 0.01908363706822838, 0.020444937005278566, 0.04252877356784959, 0.0009595782126604219, 0.03459821222350001, 0.09838528600671599, 0.012139588211392684, 0.05925801943146414, 0.02082303395464776, 0.04373227088381687, 0.057527534062823946, 1.8536297736629364, 36.84209739008258, 58.25267661002375, 48.87541132588541, 37.49481508808751, 28.366057449771514, 46.20987053840391, 50.971172932655584, 60.69961586306172, 22.573960096605365, 0.23308297108498313, 0.02921711488236343, 0.5228265711376744, 3.9984911199538944, 3.920252092422978, 4.14303683465527, 23.579518525831162, 50.80162063721688, 57.608242957822746, 57.91998509437808, 51.981834365475564, 52.686539157744384, 56.44183597257061, 55.11290557922856, 52.62926078611805, 51.501022385012725, 48.814606743474165, 49.609459369413315, 51.72972794502012, 52.36095105448077, 52.51880291969546, 52.3677759785806, 48.990858447167184, 49.06878025301042, 44.559533288401944, 40.64128944950719, 35.85486427430184, 35.719915128523304, 37.55618841417375, 38.10564971739246, 38.78023070673789, 39.907312008642386, 41.29270492061492, 42.59099375817084, 40.85478405798636, 43.375616842700595, 44.7993823020689, 45.31220866787819, 46.47947072982789, 45.60759844318513, 44.242527331075365, 42.68351462579543, 39.71591603371405, 38.97731019604591, 38.62379873952558, 42.7532700569399, 38.8949365000571, 37.12549255740258, 38.00700210755871, 39.61644472614412, 37.579903064235566, 37.44607963869649, 42.86034291790378, 51.5664985102992, 52.6556779492286, 53.20176209172895, 46.011076973330596, 46.36924428324546, 48.48485700545773, 52.297314520805116, 52.70002034402663, 53.81184754833099, 53.77188251864526, 49.8683750244879, 54.988723339573035, 51.01468378497709, 49.993184843371, 44.217498687005815, 44.49512797017252, 45.936057721414876, 46.12501398209603, 49.047713202814904, 50.60385081075853, 44.95676740523308, 40.15711992017685, 38.485307693481445, 40.08485809449227, 38.94655881389495, 39.312335521944114, 40.22476511616861, 39.16649395419706, 39.88846501996441, 39.69777114929692, 40.21445320498559, 45.149034146339666, 51.060559826512495, 52.20412292788106, 48.9149566619627, 52.069260074246316, 49.49414953108757, 51.962963842576556, 48.75080547025127, 48.042543088236165, 47.86332999506305, 45.714420272457986, 43.78865811132616, 43.029769697496974, 41.66267856474846, 38.149313542150686, 39.48916773642264, 39.67220514051376, 40.25193929672241, 37.36261944616995, 43.645966206827474, 48.60578367787023, 49.44630445972566, 51.835659396263864, 52.842908367033935, 55.185959723687944, 53.45362140286354, 51.53947730218211, 55.695554056475245, 58.16565882775092, 55.42894271112258, 51.03738254116428, 44.39758646872736, 46.05960453710249, 49.836803866970925, 58.90744962999898, 61.26483724963281, 51.86452804073211, 18.902247028966105, 2.5339712539026817, 4.052574230778602, 5.322548458653112, 1.4203271341900674, 0.1579844750343792, 1.0279598207243028, 35.50443187836678, 61.557163653835175, 47.19364412369267, 43.182271449796616, 42.28193452281337, 41.02567780402399, 59.568506286990264, 50.54502702528431, 6.1650338576686, 0.08184931646551817, 0.09405511957142623, 0.049954042469541875, 0.019443087437520587, 0.02255669667295391, 0.06653261416020893, 0.006736844098345647, 0.04126197823713865, 0.007791287996130245, 0.0681190749990844, 0.07692299572931183, 0.06018713852691074, 0.04597556784809117, 0.16866135050452527, 0.15628100192594915, 0.10389577176782394, 0.14916640466019032, 0.23220269009470942, 0.1424082681055992, 0.15725678343686367, 0.18975676127499153, 0.20635279977033216, 0.09050905944839602, 0.11284138045964703, 0.14203362046710907, 0.21092439881495892, 0.19025151617825034, 0.1968219918349097, 0.12790833810164084, 2.3586177729791213, 41.75692527524887, 64.76829828754549, 54.55079070983395, 45.36585100235478, 38.8953052028533, 53.0647890029415, 56.28035591494653, 65.53414106369019, 26.6072392079138, 0.6324175937521843, 0.31353033898818883, 2.351583492371344, 7.95214758765313, 5.894909049234083, 3.5572036379768006, 24.1997766494751, 51.014099351821415, 58.625164493437744, 57.221818893186516, 53.42166193069951, 53.61330893731887, 57.73289588189895, 56.74009300047352, 53.52489871363486, 55.755531018780125, 51.43166311325566, 49.938887473075624, 55.264077648039795, 54.72341814348775, 53.624926997769265, 55.63416504090833, 51.19616793047998, 50.416251690157004, 46.07374860394386, 42.31700835689422, 38.36558126634167, 37.11486685660578, 39.56005281017673, 41.21267680198916, 41.461002057598485, 42.96447007886825, 42.47104767830142, 45.11333273303124, 43.58581666023501, 45.05385783410842, 48.19829648540866, 47.68762350082398, 49.12122626458445, 47.306577005693995, 48.032341003417976, 44.10200449728197, 41.630832841319425, 40.58595265111616, 39.32066663619011, 44.96332560816119, 40.419518639964444, 40.13268747637349, 39.11423621639129, 41.839189144872854, 39.04290791480772, 39.516859669839185, 45.39431956506545, 54.22484959325483, 54.668583408478774, 55.959717842840384, 48.046265417529696, 47.63453029817151, 52.815188977026175, 56.036270741493475, 56.48200104313513, 56.53230544059508, 55.759414165250725, 51.24775886535645, 55.54209524585355, 53.20427633100941, 51.78113060612833, 47.39783094775292, 47.43038662018315, 48.08488899661649, 48.73686536665886, 51.190115713304095, 53.28848569623886, 45.9011721611023, 41.64593788885301, 41.40535539196384, 43.03473541813512, 41.917385516628144, 41.324903657359464, 42.295929539588194, 41.022551674996656, 42.93158100497338, 42.39196092851701, 42.037119788508264, 47.978557463615175, 53.1066720716415, 54.06866081299321, 50.93901341961276, 54.36949483809933, 51.87929576443088, 54.45910138468589, 51.00080251693726, 51.207052507708156, 51.376651871588926, 47.729871349949995, 47.01846714942686, 45.16834005232781, 44.17701198208717, 40.07290663257722, 41.41444744602327, 41.74761749082997, 42.444912925843276, 39.20970278401529, 45.88473743008029, 50.63008754484115, 52.22556652561311, 54.02581284123083, 55.767223604263805, 57.68377996260121, 55.59969132946384, 53.30705811900478, 57.62190849550309, 59.88246064032278, 58.17622569299514, 52.67254021859939, 48.39284996832571, 47.09458074262066, 52.70540183590305, 61.14920969932311, 63.756389541010705, 54.849110495659616, 21.629172909644343, 2.5494437784917894, 9.84721916337167, 12.270785012552816, 3.5346286815981713, 0.35491618598180436, 1.3790007969064098, 39.044272899627686, 67.1255760808145, 51.529914563702, 51.21819203899753, 46.85976805225496, 49.112659808128114, 68.86052670017366, 60.79627090884794, 7.8684804901, 0.1813867450841973, 0.18528463108645332, 0.13301998316760988, 0.14481352371794565, 0.1218821602543035, 0.1647375247651531, 0.1798832515675214, 0.12545525562018156, 0.1634737248382261, 0.15575276898039928, 0.20847823410745592, 0.20745995003850232, 0.14307741526394122], [0.05356199866641433, 0.043930951956539385, 0.0684773436777534, 0.03806752948871544, 0.03328034181087729, 0.0314674943294977, 0.013168715297304576, 0.023759267022532803, 0.05059257675442965, 0.01000362208052989, 0.06664374287450506, 0.08008552159393027, 0.04203728602958783, 0.048366551242408254, 0.025130330750177947, 0.11921952974291579, 0.638204683219233, 22.58437595059795, 48.88122427848078, 49.641744398301654, 31.131134263930786, 23.820891380310062, 33.15153145021008, 36.91734806183846, 49.78271438229469, 29.49751611678831, 1.0131894616830734, 0.09369514251668608, 0.6800433188196152, 2.190881044633927, 3.2843039977935056, 1.2283431714580906, 9.554784893989563, 35.0884174531506, 50.28594270829232, 52.6831070838436, 53.02141935594621, 57.650910500557195, 53.5945168618233, 51.19722304805633, 49.127706020109116, 48.54404949372815, 46.114180395680094, 44.813028227898386, 48.45850260026994, 49.45912668781896, 49.052576941828576, 48.05822472418509, 45.28182598852342, 39.89682359080161, 35.66142474451373, 36.38218772026801, 35.23961697855304, 34.468337797349506, 32.91160006676951, 35.78537164195892, 36.339653538119414, 37.50453079900434, 36.74022166959701, 37.8787523700345, 40.32717820136778, 37.88591069559897, 42.691143635780584, 42.13151162670505, 44.37018479070356, 43.36341042672434, 43.964462664819536, 41.761812548483576, 39.674550717876805, 36.902042973426084, 37.36732629037673, 38.87425776450865, 36.14054226106213, 36.0509749381773, 35.99629317560504, 36.07291667692123, 36.8697657892781, 36.87393526877127, 41.22399676230646, 46.958396050237845, 51.241694881070046, 50.69703455894224, 51.83016807802262, 48.53530653061406, 47.45928664361277, 50.61266045416556, 52.50545117162889, 54.030602055211226, 50.88211551789315, 47.85418695019138, 52.09210788050006, 51.261789183462824, 47.75918714461788, 45.60290728845904, 44.896178553181315, 44.39079684595908, 46.03130463630923, 47.75102076991912, 47.32152515842069, 45.1509561077241, 38.796394794218, 38.16864690473003, 36.8973792752912, 38.95692171589021, 37.161868618380645, 37.93688974072857, 39.356528866675596, 37.39089973511235, 35.8947822355455, 43.479214483691806, 48.24376067807598, 49.81636831837316, 53.08953915872882, 50.432564827703665, 49.187788886408654, 52.320938956352975, 51.00642327339419, 50.27203398366129, 49.6752885080153, 49.1914092340777, 50.84901855837915, 49.407716181970414, 48.65063990316084, 46.328722276995265, 42.545380515436975, 38.67139277919647, 36.334625059558505, 34.788713070654104, 37.23311847256076, 36.2901649936553, 37.70832538604736, 43.430706531770774, 45.93914462674049, 47.77008741132675, 47.68862762758809, 51.755074301073634, 54.0227847714578, 55.441400158789854, 49.543759669027025, 59.88954836322416, 51.0136757358428, 49.499742830953295, 45.57345421083512, 48.574946003575484, 54.10563699660763, 59.544650431602236, 50.388136140761844, 12.21382043054027, 0.6867367822316386, 3.2964790348083746, 2.741882368441551, 1.9016186244064763, 0.037460446943558996, 0.894570307385537, 31.381930612748672, 57.459098754390595, 45.042027965668716, 48.473482131958015, 39.68912624543713, 38.219931894733065, 56.62865061913767, 36.68843069384175, 2.4883156005413305, 0.07250184869213451, 0.04860359799837874, 0.04410091622342025, 0.04877214883303931, 0.037917223037971605, 0.032903012864652185, 0.009526381862439938, 0.03199619458868139, 0.09040126321657051, 0.024083661208409938, 0.037707969951894016, 0.03833049299916433, 0.02844759296896237, 0.0520736200644845, 0.023638870559572697, 0.03438042108750632, 0.034334658825349425, 0.04771139668000322, 0.0459013530804265, 0.020800721643853094, 0.020956693314796975, 0.07412538818654514, 0.07877689020167436, 0.059273609320723245, 0.07605088123631093, 0.02751980112084458, 0.04050901339900109, 0.04939184884630865, 0.027227440901521235, 0.9691624499617085, 27.55131252350346, 55.244093172011844, 53.621847937184, 37.96580153126871, 25.892157785354126, 39.4063155112728, 45.890315040465325, 55.18483400344849, 32.653537527207405, 1.1864799597570974, 0.09271559951406333, 0.20776119113208788, 3.421690651485997, 3.8020867686117854, 3.2901527420167005, 11.228634791989482, 39.02798721867223, 50.71404195600941, 54.00474971340549, 54.35249136340234, 59.14962853154829, 54.851911067962654, 53.62868070602418, 51.14220003927908, 51.141144921702725, 47.76590616472306, 47.34543592699113, 50.63499442992672, 51.30340945336127, 52.126008925899384, 50.23416349964757, 48.613844148574344, 43.33274533671718, 36.604417447120916, 36.508915578165364, 37.28555663939446, 36.72024111593924, 34.2698540995198, 38.35723446261498, 38.39676018684141, 39.98763430503107, 39.01782043518559, 39.85829807096913, 42.224365895794286, 40.071082730447095, 45.212466716766365, 44.43472346951885, 47.649094058621316, 46.53263845751363, 46.20581873001591, 44.819445225500296, 42.08205838357249, 39.24321159239739, 38.1518905393539, 40.85891823614798, 38.377944577124815, 37.92221223154376, 37.83095044474448, 37.33793597067557, 37.353433255226385, 39.064861420662176, 44.68146016520839, 48.25984631815265, 51.96641945069837, 51.526768822823804, 53.26417876828102, 49.81175953342069, 47.402796668391076, 53.634552494172134, 52.994790384846354, 56.67565238091254, 52.280934702965524, 50.9463757084262, 53.655321444234545, 53.50568302216069, 50.36745348284322, 48.22482347488404, 48.14382260845554, 46.38096432532034, 48.96820283705189, 48.499157967105994, 51.262805077337454, 48.578381999846435, 39.8784198299531, 39.54230800751717, 39.08962334356001, 39.3476446982353, 38.40724468231201, 41.112460244086485, 40.473215887623454, 39.21791622715612, 38.57098010278518, 45.46579691671556, 50.78168715200117, 51.920610089455884, 54.261249188453924, 51.8485051585782, 50.92416724851055, 53.82466977642429, 53.69400385887393, 52.647515496900006, 52.53880700757427, 50.54827867015716, 53.5329984080407, 52.843586937073745, 49.85147353141539, 47.87293195724488, 44.58291453699912, 39.782000126377234, 39.35219464763519, 38.040385400095296, 39.677221851964156, 38.38964108497866, 41.019755025063795, 45.91617522701141, 49.11254998176329, 51.126188924235684, 50.59100897081437, 53.635729205223825, 59.73591696831488, 56.7334641948823, 55.30181477146765, 60.62006627359698, 53.87524481742613, 52.76048760260306, 48.77080955813008, 50.46091571930916, 56.90951978006671, 61.91576634683917, 53.14325209586851, 13.029379248619081, 1.7105474707580384, 5.758570403822008, 4.700817485009471, 0.992101144886786, 0.06329016617288993, 0.717688511696554, 34.513590182027514, 62.757142205392164, 46.98902191654329, 50.13810465412755, 42.91915493626749, 45.42104659541961, 64.38414135286885, 45.27675044152045, 4.0984833673123395, 0.07870196680267973, 0.011188424935924911, 0.023203447250829592, 0.06833609238627457, 0.05421156461741175, 0.04212728220849268, 0.022653158633939685, 0.03647905383859912, 0.05564543606352903, 0.055404578020135244, 0.035780557851877906, 0.022338072416342558, 0.04253052407875658, 0.16717874054466525, 0.10282956123832734, 0.11660375316897709, 0.05977611320333616, 0.21055014954218942, 0.16893954767334848, 0.14741734932026557, 0.17937738838936054, 0.17469740322520658, 0.1867329049855471, 0.1416987327918891, 0.22685783254283093, 0.11923381728270363, 0.1185949152756122, 0.17622553412952732, 0.23741887551882576, 1.1414913544731757, 31.3263015977798, 63.025538229173236, 63.010295898683616, 44.25874633173789, 33.924603154582364, 43.996520196237874, 49.51100395571802, 60.11712035825176, 36.86968734187465, 1.5579248604274567, 0.25409455651477464, 2.1727538108825684, 8.20752771631364, 8.101288359011374, 2.2226144902167784, 11.930953802600985, 38.817336328568, 51.65474007206579, 53.00139957858671, 54.95165301907448, 60.423684966179636, 57.87938464072443, 55.29601750835296, 53.82294785591864, 54.846988493396395, 50.16276459540091, 50.50213982982021, 53.87761000664004, 52.60402425642937, 55.618087245572, 52.75560032936835, 49.528431046393614, 44.38307762145997, 38.12131958623087, 38.97925569165138, 39.74020334982103, 38.82699320393224, 36.63514921742101, 40.77708582724295, 41.14625538549116, 42.377220661409446, 41.60454903879474, 42.43440881852181, 44.82581907703031, 40.5580489097103, 47.61351423878824, 46.32602368631671, 51.0264705073449, 49.098343156999164, 48.70078348344373, 46.39643023090978, 45.112022661393695, 39.89268941263999, 40.78393428556381, 42.41837416925738, 40.04388109330208, 40.76528733776462, 39.74772645581154, 38.62784662554341, 39.84954726311469, 40.35507017566312, 46.45492453728953, 49.81026118801486, 56.12090764507171, 52.513735217432824, 56.46288733328543, 50.96596010269658, 48.98808925382553, 52.74261336172781, 55.836253396926395, 59.29996513551282, 53.894413440458244, 52.12132561591364, 56.96166376913748, 54.95389661481304, 51.799130362849084, 49.58201454531763, 50.63917175416024, 49.12181069774013, 51.45854311604654, 49.81297939054428, 53.1570823730961, 49.284698886256066, 42.78326834401777, 41.455208716853974, 40.76592668410271, 41.821291369776574, 40.76867234322333, 41.706224718401515, 42.72081244376398, 42.99473116474767, 38.94215006982127, 47.87106883141303, 52.71381924229284, 53.15675289400163, 59.66152137325656, 54.01197864163307, 52.530064044460175, 56.38590297391338, 55.70966282198506, 55.160891855916674, 55.99548201407156, 52.414820886427364, 57.76538095166607, 55.450256870638945, 52.76970125013783, 50.41520441732099, 46.989876993240856, 42.16611085399505, 40.89912645278439, 39.25044444299514, 41.47783687037807, 41.169993569774014, 42.040308675458355, 47.36187065801313, 51.465917171970496, 53.886729517290675, 52.763539206597116, 56.40959408975417, 60.45147103648032, 59.345386182108236, 54.563950261762066, 63.135470497992735, 58.08341849234797, 54.8909229616965, 51.97844936001686, 53.85525249665784, 59.568341547443026, 65.29031084429833, 55.86284314432452, 15.17272508913471, 2.3963156727052506, 8.958852329561788, 10.587135072677366, 4.770752364589322, 0.21208085450193576, 1.0475211710699144, 39.12978056938418, 70.63265354402604, 59.607141633187574, 63.257734698633996, 50.538092274819654, 53.51799926450176, 71.63943183037543, 53.1555526487289, 5.711807906627656, 0.2498916143010701, 0.16526165147942884, 0.19378528059009584, 0.18724537184161527, 0.1310243547683762, 0.1802196254533145, 0.16914239243393944, 0.1306833230680035, 0.1283487850319474, 0.12984824126526234, 0.15561807540155229, 0.17632996723536523, 0.1498230492636081], [0.023463085939687107, 0.02104973277798103, 0.0836843268705472, 0.07890645865230791, 0.0048715315642766654, 0.029383472790340745, 0.05367139985244121, 0.02175269122686117, 0.03267923092109061, 0.06022188061427686, 0.04123585080848106, 0.016416823716774102, 0.02520823423119803, 0.009160598818843645, 0.10986148995617706, 0.0464717936401646, 0.12821330238253842, 11.479535083616934, 46.14731657889582, 51.662027835845954, 30.58766438115028, 20.69427009551756, 42.5794384556432, 39.57362028860277, 48.91463502760857, 34.52736162370251, 2.444778517369301, 0.0242419560409842, 0.1310333026753318, 2.2205581876539418, 2.5753983470701405, 3.065124158897708, 1.4985622393508113, 14.822552550223568, 36.80685097171415, 54.85609231456634, 55.308596549495576, 53.94357642819805, 53.607362624137636, 50.88859527341781, 48.49085823182137, 45.55074368753741, 45.06756651786066, 44.61755298799084, 44.26297072441348, 46.656295099566066, 45.74562272717876, 43.757337985500214, 36.88299594386932, 34.48097175167453, 35.42679640554613, 33.990546041919345, 32.717825174331665, 35.444113669856904, 35.8269016973434, 35.46796168050459, 38.6382056051685, 38.456117414659076, 37.72398348777525, 38.37292394330425, 36.47633244914394, 39.824718659923924, 39.44726113350161, 41.35832617359777, 43.13271622503958, 42.563635226218935, 47.11335320626536, 43.12790739920832, 40.5633480318131, 36.5385373177067, 38.195993669571415, 36.46421624768165, 37.168713154331336, 37.19692284061063, 35.291486401711744, 36.83680219034995, 36.524710962849284, 38.16854492310555, 40.22860903893748, 45.44785599554739, 48.5826377714834, 48.0568205156634, 52.776341822839555, 52.39777426565848, 47.70366991719892, 48.93236806315761, 51.48710581564134, 49.82996325339041, 49.00493191134546, 48.46760249906971, 52.587024704102554, 49.92879913699243, 49.231056551779474, 44.41246009642079, 44.02611055681783, 45.7679606253101, 47.18184955658452, 50.30017698964765, 52.300475951164, 47.14326912356962, 36.92118413986699, 37.947378158569336, 36.51256338242562, 38.71390342712402, 39.97328235257057, 36.72758379290181, 37.112607571386526, 38.77337048130651, 43.30167232021209, 49.06586593197238, 50.795187950134284, 52.30880706541, 50.87269790710942, 47.08996411292784, 48.14448548901466, 49.825338778957246, 50.84815955931141, 51.87680898174163, 52.88936491935484, 51.8238805186364, 51.637101173400886, 51.52210512468892, 52.550601574682425, 53.403340539624615, 51.41586380620157, 48.23099336316509, 42.679607945103804, 38.298379298179384, 36.19307848715013, 36.548955132884366, 36.8819212144421, 38.082570491298554, 40.55311064566336, 44.93714378726098, 44.336005257022, 48.80290631325015, 48.8402315878099, 55.88665977601082, 49.28705623072963, 51.03910446166993, 63.378661371046505, 49.21069945058515, 51.170276364972516, 48.56721108959567, 54.41424123702511, 60.56314483765633, 45.236628517027825, 5.877804573505156, 2.3259539902210236, 2.8014239476573084, 2.9416028386162174, 0.5182790732191456, 0.0915503721203535, 1.0464788011966213, 32.795001729842156, 53.77749150799167, 41.12783201279179, 45.741053165928015, 33.971220524080344, 34.78030350900466, 53.14829626391011, 29.10004665774684, 2.0497370054644923, 0.052524336403416055, 0.04263736653111635, 0.031257900334293806, 0.08334439067590622, 0.0511152210885719, 0.04007830727665175, 0.02173498310449143, 0.023863173442922776, 0.005124131820329856, 0.05951818289054979, 0.06909644231200218, 0.013288460585529046, 0.007893083844288823, 0.05462159402668477, 0.06529012679933541, 0.029495844482294017, 0.018241970739778013, 0.012264556304040936, 0.03675352782011032, 0.013765383834740328, 0.01873875194559655, 0.03400433320371855, 0.05838851729828504, 0.02339609921158802, 0.04106689394722062, 0.005053567461624381, 0.03619762377873544, 0.035800437833512985, 0.014236051018439956, 0.2502231618329402, 15.752977978798652, 53.30588533032326, 58.093389157325994, 35.51194321724677, 24.86114121252491, 43.58435361616073, 43.16649959933373, 54.16470789140271, 36.62332327135148, 2.4323720605142656, 0.05557216358401122, 0.22271800065232863, 2.0676159041543163, 4.669875377608884, 4.076748533594993, 2.8235166976528787, 18.659915154980077, 40.16489013548821, 55.52810807381907, 56.455121040344245, 58.03671875307637, 54.91093097194549, 51.70453456140334, 51.890529432604396, 47.161547368572606, 47.13466736578172, 45.906769383338194, 46.86503579539638, 49.15677862782633, 49.38130294123004, 45.77160450720018, 39.00550419284452, 35.99888586228894, 37.23384411104264, 35.94457280251288, 36.038270381189164, 37.98365616029309, 37.25235769825597, 38.63865667773832, 39.24208587215793, 40.85017919540405, 39.65537425010435, 39.63727643412929, 39.62541126435803, 40.72824839622744, 41.044677765138694, 42.23147323054653, 43.50482756091703, 45.889707073088616, 47.469347523104766, 44.598113721416844, 41.567521864368075, 38.77154265680621, 38.50799468255813, 38.6434341246082, 38.79490037118235, 38.917568575951364, 38.01545089290988, 38.24346219339679, 37.76760808883175, 39.87865909453362, 40.345087743574574, 47.54034634559385, 49.15981846470987, 50.278207794312515, 53.97733626827117, 52.08488287464265, 49.67562190947994, 51.72234604435583, 53.55295934984761, 53.21668671023462, 50.37251726273568, 50.25412836382466, 55.527488339331846, 52.17183397662256, 50.054181621920684, 46.73205960181452, 46.53108127655522, 47.05099144289571, 49.66617684210501, 52.57747373273296, 53.43183263655632, 49.381950132308475, 37.95949043766145, 39.59274576556298, 38.88699370045816, 40.01029383751654, 40.35836888897804, 37.0943057921625, 39.19118135206161, 41.41855808996385, 44.66107168505269, 51.276694190117624, 53.530558693793516, 53.8670039176941, 53.369341434970984, 48.65655091501052, 50.754650254403394, 52.60966462473716, 53.76886229361258, 52.89147123213738, 53.81006286990259, 54.02647964416012, 53.667410189105624, 52.37574623477075, 53.9816822544221, 53.949558042710834, 52.24555100164106, 49.25789733086863, 43.2465002613683, 40.26944875717163, 37.96222432967156, 39.09687972837879, 38.9832329750061, 41.47749954654325, 43.97141310476488, 47.713507221591094, 49.49456922469601, 50.371360163534845, 51.06365849894863, 57.372469286764826, 49.54328506223617, 55.02846479415894, 64.39916403062882, 52.88335192588068, 53.733411911995184, 49.51009788820821, 57.24476083632439, 62.87957506795084, 46.988880711217085, 7.5465009673949215, 3.577133936266746, 5.492759712280766, 7.700164721858117, 0.9940816966756698, 0.14697796725217374, 1.144341201551499, 35.786697403077156, 61.20300108386625, 47.421055301543205, 56.941153695506436, 39.69575505102835, 40.754842065995746, 60.35521215008151, 35.6083119300104, 2.416208218182287, 0.06856915931547843, 0.0143890627171664, 0.04911785366975012, 0.07667710448825553, 0.038964143473534815, 0.022382672140074354, 0.050170044790232377, 0.05256818727620187, 0.049178642746541774, 0.0297339465243802, 0.03481788793578744, 0.031484853881861896, 0.04035137165638228, 0.17335036018442723, 0.13961259876528095, 0.1423391669748291, 0.14551731337222362, 0.1232233810268583, 0.12050590628097135, 0.24524899890586255, 0.08049992919569054, 0.08394887235255973, 0.07904928042403153, 0.0749349822440455, 0.17082570210820244, 0.16082633947653158, 0.108682656840932, 0.21970998706115832, 0.14203247133522265, 0.21019869904604652, 17.687073215361565, 60.79640819180397, 63.61685906687091, 41.664737809088926, 32.77361696766269, 53.976104644037065, 51.867783607975134, 58.90041682028002, 41.77355612477949, 3.200830812415769, 0.1287355445205204, 0.5807070878724898, 8.652208293637923, 9.395920076677877, 6.434590903020675, 2.4917844466624723, 17.007344115164972, 39.061476415203465, 55.049269045552904, 56.718516042155606, 59.169973865632095, 56.73601765786448, 53.674560669929754, 54.17510609472952, 49.1282473071929, 50.07650383057133, 48.23787712281751, 49.114817111722886, 51.670174598693855, 49.690291573924405, 47.72310918377292, 40.49756203928302, 37.63929559338478, 39.60267328446911, 38.018227930991884, 36.67082317413823, 40.96406913572743, 40.48710500040362, 40.787699760929236, 43.64759399044899, 43.17222233741514, 42.18356147889168, 42.902402493261526, 40.87156003521335, 44.51213928960985, 43.48617276837749, 45.60740624704669, 46.003683305555775, 48.03744792938233, 50.6972542116719, 47.405240305008434, 44.889369318562174, 40.441319173382176, 41.301832276005904, 40.158975201268355, 40.80788820020614, 42.03455848078574, 39.406825419395204, 39.89224226244035, 40.475137849007886, 43.041681935710294, 43.04633778910483, 50.89070550857052, 52.69589401060536, 51.425269649874785, 57.00359390627954, 55.35194658464002, 49.99557748917611, 51.948023534590206, 55.29500161447833, 53.00802446180775, 52.052966548550515, 51.6920575018852, 57.21038518413421, 51.98200694976315, 51.92733695430141, 48.27361775982765, 48.28558098885321, 49.625733283258256, 51.93998267573696, 55.94027465389621, 57.18876115737423, 50.35527844582835, 39.65973984810614, 41.537143107383486, 39.73854418723814, 41.93001947095318, 41.84310367030483, 38.764741266927416, 40.57649973900088, 42.46423059894193, 46.6991352265881, 53.48267832110005, 57.348170203547326, 55.705716917591715, 55.70169648816509, 51.46499933735017, 51.694618809607725, 54.76440298941828, 55.956752530990116, 53.52242369805613, 54.67089760688044, 56.53610621729205, 55.850303326883626, 54.50201995911137, 56.296720043305434, 57.29730098478256, 55.064456462860115, 52.85169447621992, 48.5458694734881, 41.59647287860994, 40.033698620334754, 42.0526719862415, 42.057763222725164, 42.63101370103898, 46.11480013016732, 51.37605959369291, 50.16022682189942, 53.29984880262806, 54.74949798276348, 60.31611396420387, 53.58209863785775, 54.69862484162854, 64.4300683852165, 55.8851339740138, 57.53150570777155, 54.92127426208989, 60.4135456392842, 66.40176542343633, 48.80594615013369, 8.050871683705239, 5.599452593634206, 11.534523771655175, 7.433026308013548, 2.153039488100237, 0.3143631378489156, 1.3889384894601762, 41.511788906589636, 68.51620535696706, 54.8047798679721, 58.10449730965399, 44.51353957576137, 48.969607045573575, 70.07384131031652, 44.699714875990345, 3.9287969758433685, 0.15120637422848135, 0.19529142477098974, 0.09735308978105746, 0.17252096275408424, 0.13551177607188303, 0.11140920206784241, 0.10280994938746577, 0.19388494862904473, 0.096907471757262, 0.1378992124791107, 0.23616817569540394, 0.09697974449203861, 0.14184107192822043], [0.01771387760527432, 0.07297388908843841, 0.029261714606095227, 0.08466322635931355, 0.050000517193468354, 0.04999712725440341, 0.11597705494251945, 0.05048785253518051, 0.05806524734643679, 0.03230486673513248, 0.039027395523003036, 0.026506981174010905, 0.11807028294330645, 0.07403804650229794, 0.05336896366169376, 0.03870828925902325, 0.041756545448856014, 6.059779995872129, 34.330242910692775, 51.10378434581142, 39.200108666573804, 21.392153886056718, 27.567484455723918, 42.31702796874508, 51.38815618330433, 46.19343580738191, 7.692650441200503, 0.05322275961178446, 0.13182952849855348, 1.4003318716441433, 2.8076909146001263, 5.275475603918876, 1.8832147409839017, 4.857652475756984, 27.232672899000107, 51.00678020907987, 53.769937023039795, 52.63905102206815, 51.6756227708632, 48.69772403470932, 46.43456743609521, 43.541686073426284, 41.92872508879631, 39.674848818009906, 41.943128032069055, 39.561876712306855, 37.693204649033085, 35.5826243277519, 34.817754299409934, 36.526134783221835, 33.898997922097486, 35.65178355863018, 33.88158652090257, 35.272910056575654, 35.60057701603059, 36.89376284999233, 37.92759764579035, 37.781771767523985, 38.24287383787094, 36.40564349389846, 37.53704332536267, 36.207508887014086, 38.31122113812355, 38.00370731661397, 40.5226142175736, 42.91041981789374, 45.32411306135116, 42.725389849755075, 40.85309351644209, 38.025535306622906, 35.841037919444425, 36.631858348846436, 36.69208634284235, 35.8236422077302, 37.32874585736183, 35.88427420585386, 35.771098136901855, 36.8067019216476, 39.9717055597613, 42.553511588804184, 45.59697274238833, 49.84735112036429, 50.62065816694691, 52.30048771827452, 50.96029227779758, 48.9890149331862, 50.60904010649651, 51.43403614720991, 50.36209552518783, 44.010762322333555, 46.656640268141224, 53.5150614092427, 47.968465205161806, 45.12319357164445, 44.701389728053925, 46.51910628041914, 47.26271706242716, 50.35127370588241, 50.594711688257036, 49.381346087301935, 39.231840641267844, 36.50851549640779, 38.15277307264267, 37.98533493472684, 37.61209003386959, 38.2970025462489, 38.40620133184618, 41.240345201184674, 46.974011005893836, 51.64977827379781, 54.51616794832292, 52.311078117739775, 49.91673784871256, 45.45665779421407, 45.88170936030727, 49.27468899757632, 49.667863461279104, 49.59657438339726, 51.38500259768579, 53.16928486670218, 53.203393797720636, 51.04678446246732, 52.46961639773462, 51.783103558325, 51.460178744408395, 52.606883664284986, 49.781392543546616, 46.123754901270715, 43.14818605299919, 36.73564034123575, 37.83557099680747, 37.54652369406916, 38.4992987878861, 39.63517012134675, 43.148060537153675, 46.35454323983962, 51.34068373710879, 50.91048602134951, 56.85467720031739, 47.72175596606347, 50.798274855459894, 59.743471453266764, 54.66474733045025, 53.15603117788992, 57.38565629528415, 55.81805752169702, 38.84362013109269, 4.496446309551116, 1.5948868254500053, 4.696873541801207, 3.651944567118922, 0.093315921333288, 0.023125718054812283, 1.03707455098629, 33.73676869177049, 53.280911599436116, 43.55103308154691, 27.963873301782918, 28.335986598845455, 47.401121816327496, 48.62968660170033, 30.75898958790687, 1.0488297718186532, 0.019111030457180836, 0.03315642708912492, 0.09398917472290416, 0.04716648983078138, 0.07019809972975524, 0.01609472396423019, 0.02744539483119884, 0.06264483285767418, 0.04928621298242961, 0.018478079038041256, 0.013853969454254596, 0.02611978884576069, 0.06117215522775247, 0.05834456683406907, 0.036133084701554435, 0.05177283479321388, 0.027887391174332272, 0.05189288843182787, 0.03388151781813752, 0.04280571052203736, 0.033309181190786824, 0.03594980199610995, 0.023363678370632475, 0.03637748973203763, 0.08188461013618978, 0.025734620904850385, 0.042992233779401555, 0.043609926642309275, 0.045837388569188696, 0.05753213825124887, 8.590370166686274, 43.260091274015366, 58.16887909366239, 44.81309098582114, 25.492866385367613, 37.09555702824747, 48.40005928470243, 55.01967476260278, 48.1057010927508, 7.62982338666916, 0.09273098255958288, 0.10978731732334822, 1.32323315066676, 2.7499347492571804, 6.142287052446797, 3.3513998168130077, 7.545220313533661, 29.749453875326342, 51.373729705810554, 55.44745237596574, 54.778421540414136, 52.46428197430026, 50.64342360342703, 48.37361858737085, 44.651544247904134, 42.66790359250961, 42.63895650063792, 42.1797332456035, 41.41804425947128, 41.00481863944761, 37.51192054440899, 37.43947436732631, 37.93430489878501, 36.50596203342561, 36.46176084395378, 36.728791882914884, 36.84960088422222, 37.85567314394059, 39.005261005893836, 38.910931925619806, 39.151349682961744, 39.330645145908484, 37.814323517584036, 39.39315203697451, 38.488943730631185, 41.01154942666331, 39.41671371459961, 42.95095751362462, 45.65923644650368, 46.16733243388515, 44.908090791394635, 42.378581723859234, 39.297646245648785, 38.29764581495716, 38.1030805649296, 37.842956819841945, 38.85146879380749, 38.39453228058354, 37.32099133153116, 36.897053718566895, 37.57253685305196, 42.05165609236687, 44.53201393927298, 47.95547431515109, 50.83474113095192, 53.27474955589541, 54.34909066846294, 50.245405012561434, 52.316714563677394, 51.85565563940233, 52.78495927010813, 52.03481381939304, 45.75075710973432, 51.073378132235625, 54.01851723271032, 50.810646010983376, 45.63093654571041, 47.579562202576675, 46.7670157647902, 50.04528568636987, 50.969568683255105, 52.46611764354091, 51.624839844242224, 41.678611232388405, 39.579566601784, 39.1742524023979, 39.826711223971465, 39.31461049664406, 40.09836673736572, 39.369723719935266, 42.93641728739585, 49.324805121268, 52.12742097916142, 55.59420393359277, 53.24943457880328, 51.52422320458197, 48.86432278540827, 48.32977825595487, 51.01764125208701, 53.190128341797866, 52.614606811154275, 53.7054846363683, 53.68661803583945, 55.024597337169034, 53.41598233868999, 55.26738028372488, 52.9841999853811, 53.92398418918733, 53.399790794618674, 52.45388769334363, 48.63706457999445, 45.289400085326164, 39.03255285755281, 40.78659365254064, 40.44079357577909, 41.52551327982257, 41.94261420157648, 44.12042786998134, 49.582610745583814, 53.35271843018071, 53.482070353723344, 59.69522237777711, 48.32241988951161, 54.0838639197811, 59.73413228988648, 58.48486523474417, 55.029637582840465, 59.25949412007486, 59.00671697431996, 40.87716510218959, 5.761257227390043, 3.40119602218751, 5.424054005453664, 9.133637066810362, 1.897767837489805, 0.11994372031861737, 1.2110118111295085, 37.058859332915276, 58.57728804311445, 47.884977556044056, 35.387313827391594, 32.930984420161096, 50.62141126201999, 57.4432013880822, 36.43755981999059, 1.8057180220080962, 0.08682280523522247, 0.03727016219448659, 0.080161931203498, 0.0483706574736824, 0.02725222384587171, 0.08039103745813332, 0.045437670703376495, 0.06022347407715936, 0.03938163074875071, 0.013508185135921644, 0.023114418257929148, 0.034892773030385855, 0.05794196081678233, 0.16855567633625002, 0.1457722367899072, 0.3037857005913412, 0.2072746027261019, 0.12615521483483816, 0.16083559381865686, 0.2760900286657195, 0.16055430165461956, 0.12018355946507185, 0.11430050982462783, 0.08546211816851171, 0.17413727037848967, 0.21738740765760023, 0.15088078686066214, 0.2119338881945418, 0.1655347771461933, 0.2767616119836607, 10.138373759485061, 49.61795130083638, 65.06585713355773, 51.27850240276706, 33.96394060504052, 38.10232354748634, 55.00909220787787, 62.080486282225586, 55.19070579159645, 9.660818326857783, 0.18896574484965495, 0.5283725574131936, 5.808562972853261, 9.02922063104568, 10.944802280395262, 4.07375208793148, 7.259672745581597, 30.674378179734756, 53.82362642595845, 56.47053987749162, 56.572752921812004, 54.2828457586227, 52.31767554436961, 50.14369010925294, 47.74370162717758, 45.44011715919741, 44.520611609182055, 46.2626499514426, 43.33552629716935, 41.80764152157692, 39.21676305032546, 39.24892648573845, 41.004736269674, 38.592702188799464, 38.29753598859234, 37.974332686393495, 38.719641854686124, 40.693253009550034, 41.12168958110195, 40.356870543572214, 41.72198872412405, 42.90499517994542, 39.823004584158625, 41.97112983272922, 40.53658570012739, 43.01662191267937, 41.81783968402494, 45.45904259527884, 48.45036760453255, 50.47764855046427, 46.964762057027514, 44.37207537312662, 40.53041581184634, 39.92879875244633, 39.65708832586966, 40.102587207671135, 39.81536772943313, 41.095597974715695, 38.86582466863817, 37.7904402056048, 39.76708727498209, 43.934617350178385, 45.430452439092825, 48.60897256482033, 51.383570932572894, 53.840806407313195, 56.85833677168816, 53.395707607269294, 52.03049528983332, 53.585809200040764, 56.0295948674602, 52.959971504826704, 47.876654286538404, 52.988797003223056, 57.30134494843022, 54.26219840203562, 48.487622276429214, 50.42485344794489, 50.65112713844546, 52.5375557714893, 51.12936604407526, 55.54813177354875, 53.150249604255926, 43.227194355380156, 40.83702748821628, 39.74740089908723, 42.05983815654632, 42.54003432489211, 41.838973414513376, 41.30751186801542, 45.55386589419457, 50.728668474381976, 56.35932499362577, 59.242145476802705, 55.48660155265562, 55.66934477898383, 51.632378639713416, 51.055531347951586, 54.04351449781849, 55.89308069598291, 53.49985438008463, 56.42662502104237, 55.597804669410955, 58.68591416266657, 54.9647694249307, 57.51380405118389, 54.63609049397131, 56.39607760214037, 57.24288594338202, 54.273530129463445, 51.32329587013491, 46.8154570364183, 40.43804791665847, 43.78555159414969, 42.63315923752324, 43.28884224737845, 43.9440937965147, 46.958160708027506, 52.532378242861846, 56.643547781052135, 57.360831614463564, 60.88898789498114, 51.50014377409413, 54.41949721305601, 60.11207226783999, 60.1885231848686, 56.68959248450495, 62.70628083136774, 60.171951170890566, 45.18685756191131, 6.50586429142183, 5.4718024884500815, 12.225899369485917, 11.758209678434557, 1.3900452107191088, 0.1372954126207098, 1.4084497070120228, 40.595801722618845, 64.71881366545155, 55.391303646949034, 39.77455154542, 39.59117289512388, 62.457378987343084, 64.2954683303833, 45.360155720864576, 2.5098437743802227, 0.1184205613249252, 0.1287557692417214, 0.17426758193440978, 0.19782939745533853, 0.10546815191065112, 0.15688002139570253, 0.13239448769919335, 0.1777724648315099, 0.13352371662134124, 0.09676592935237194, 0.09630171837465418, 0.11108051204392988, 0.20580320829345336], [0.045665558878212206, 0.05690517572445735, 0.041326406231570634, 0.06035837449974591, 0.009902634455131428, 0.04624923360684226, 0.012055122229691234, 0.11221694219256602, 0.08370095097850408, 0.03191434575485126, 0.015193465571369857, 0.021265756166089448, 0.05780316866754044, 0.05841110923117208, 0.09690151925409034, 0.04648456432586236, 0.07127016317099333, 2.407442456291568, 28.2126868924787, 51.125475052864324, 41.54453285278813, 34.12678564748457, 32.62266455158111, 49.63447624637235, 44.15124201005505, 51.04310920161586, 13.446320333788472, 0.26208064008143644, 0.08460010837523207, 0.439001138532354, 1.8442119177310698, 3.4662004824607604, 2.2809742102699895, 2.3537537888173135, 20.95791416783487, 50.84214264346708, 53.26443764471239, 52.49680234539894, 49.88098544459189, 47.77684565513365, 45.07398351546257, 41.842982076829486, 38.97798092134538, 37.15414547151135, 37.58917946969309, 37.40321597745342, 34.537089101729855, 36.879744298996464, 36.115164526047245, 33.848760204930464, 36.66452777001166, 35.61090069432413, 35.89684540225614, 34.92760419845581, 37.18707376910795, 35.33026687560543, 36.14590414108769, 36.39188381933397, 35.85491918748425, 35.44620429315875, 37.774213360201934, 37.28485845750378, 37.92731131276777, 36.56269519559799, 39.33464204111407, 37.13640851359214, 40.78574642058342, 41.104666494554095, 40.274359564627375, 37.33302908559, 35.78493625886979, 36.04229081061579, 37.08045198071388, 37.42107845121814, 36.2665327133671, 35.74557135182042, 36.27029426636235, 36.26151992428687, 40.26041161629462, 40.56607015671269, 45.10453485673474, 45.09472500893378, 50.62267426521548, 51.42848599341608, 51.424932326039965, 50.972114301496944, 50.38395489415815, 49.73165688976165, 50.56561946868897, 42.94483861615581, 46.024185534446474, 52.95580202533353, 48.50194677229851, 47.418486149080344, 44.230301303248254, 47.93844730623307, 49.379973257741625, 50.29619186155258, 50.693873128583355, 48.976647700032885, 39.18610972742881, 36.46712664634951, 36.48118049867692, 39.28567124951271, 36.74437545960949, 39.85043371877363, 38.28410187075215, 44.965510368347175, 47.96583329477618, 51.9490864969069, 51.352211583045225, 50.6856636078127, 44.91046774771906, 41.73278700920844, 43.219086816233975, 44.49779518188969, 47.02957530175486, 48.8702416419983, 49.71304524329401, 50.30456612187047, 49.25513598226732, 49.351893009678015, 50.2818791327938, 51.1073144789665, 53.4533860606532, 51.34399813990439, 49.59156943905739, 51.13295109041276, 48.45672184421171, 45.46852296398532, 42.63639911528557, 38.46071443250103, 39.898149351919855, 39.51783634001209, 40.406555206544944, 41.960382538457075, 45.495736368240856, 51.671708245431226, 52.29136820762388, 57.09778570359754, 49.32601321128107, 49.68029737472535, 54.83733554040232, 54.10689215506277, 61.53029149578464, 55.82916959639519, 23.99561335963588, 1.0938523301193792, 3.13866124518456, 3.498420056796843, 13.216313527476403, 2.078959888988926, 0.019123266796551405, 1.0258107295920773, 27.368494772141982, 48.80415362696494, 45.26461070583713, 34.34225713053058, 27.317754991592903, 46.81210340992097, 48.11005492364207, 22.765340382053008, 0.1340644368000569, 0.06609439654576202, 0.03239258763290221, 0.08519087707804096, 0.06545411558040688, 0.01199120847177842, 0.030666287019548398, 0.059911201317464156, 0.07483060276436229, 0.007667551868625226, 0.020318499939035506, 0.10134020204385442, 0.004053387965541333, 0.03415073643648817, 0.050636829823375716, 0.0557510795882873, 0.06186159605520868, 0.04932770813484827, 0.02300626771043866, 0.014661538166805141, 0.010840107739392308, 0.07208855191786444, 0.052033450244174856, 0.05888401530683041, 0.044348496688349594, 0.06872151122098008, 0.01161555534288768, 0.04197601048696426, 0.05827623562166288, 0.05520863571174203, 0.06689796915217754, 3.594439188318868, 33.91292625857938, 57.293311934317316, 46.793036768513346, 32.967764485266905, 34.83125901991321, 54.44996226218439, 50.33189719723117, 55.89397107401202, 15.42020703515699, 0.19935424950334335, 0.236865499567601, 0.9518302316146513, 3.52929376786755, 7.984962626810997, 4.186844806517325, 4.5214690700654065, 23.394796463751025, 51.14101548348704, 55.523922904845215, 53.188810425419966, 53.223880337130645, 50.28419725356564, 46.23643282921084, 44.35864910002678, 40.418804768593084, 39.668078807092485, 38.175577732824514, 38.67453852007466, 36.78850212404805, 38.11959374335505, 37.58579838660456, 37.19702482223511, 37.75628812851445, 37.35675550276233, 38.33617917952999, 38.01787491767637, 39.743576588169226, 37.101770062600416, 39.80623645167197, 37.982769704634144, 38.71213051580614, 38.752248517928585, 38.100181933372255, 38.73713954802483, 39.07027429149997, 38.02015773711666, 40.1844431507972, 40.26755817474858, 44.449906964455884, 42.74858282458398, 41.34961458944505, 38.966664883398245, 37.379466026060044, 37.73796281506939, 38.497678849004934, 38.46245596485753, 38.46896709934358, 36.30848246236002, 37.62959557194864, 39.31395546082528, 41.8150822577938, 41.80833578109741, 46.81105613708497, 48.53934657189154, 50.482359317041215, 52.538783473353234, 54.156129667835856, 51.53295832295572, 52.64291847905805, 50.91859356049569, 51.47751954294021, 46.21458522735104, 50.51274591876615, 54.14307209753222, 51.27213247360722, 48.22751422082224, 46.29575475569695, 49.687934229450846, 53.106228843812026, 51.04784742478402, 53.6724857361086, 49.56165352175313, 41.54407393547797, 37.819622639686834, 38.70322673551498, 41.128377222245746, 38.95306602601082, 40.69791670768492, 39.854152125696984, 46.79238565506474, 51.080136376042525, 54.09240684201641, 54.94519679777084, 53.19682382768201, 48.57903311329503, 43.36395955854847, 46.531520582014515, 46.6919376773219, 49.66032858817808, 52.110209618845296, 50.99232235262471, 52.89986510430613, 51.27083809145036, 50.663655188775834, 52.84004895917831, 53.5990785783337, 55.54296993440198, 52.894326717622825, 52.06754207611085, 52.98181126194616, 51.13827766910676, 46.22685832362021, 42.79212897823703, 41.13798310679775, 42.763291712730165, 42.805531717115834, 42.57052683061169, 43.717973078450854, 50.238023111897135, 53.53363775437879, 54.170967994197724, 58.607337321004565, 51.502002977555804, 53.686445451551876, 56.66755660887688, 57.53627138753092, 62.62813937279486, 58.08601510140204, 27.39094445782323, 2.626266585242364, 4.6711501479148865, 5.909530664643934, 7.582503422614067, 1.2108788182658534, 0.08301815979423062, 1.0457364926415107, 31.709901555891964, 56.010096765333614, 48.72012469076341, 33.026741243177845, 31.83658430653234, 55.59162693638956, 55.88339636402746, 29.253719237542924, 0.6532748584305087, 0.029292191498942917, 0.04073377593510574, 0.07028437655178771, 0.005964131907544911, 0.027200894039725105, 0.07391155006424074, 0.043181668170878006, 0.02282123832452682, 0.029309148855146863, 0.018622136126542767, 0.07801906836609687, 0.014768485956254506, 0.017021979550800977, 0.16421269324998702, 0.16797058434496004, 0.11137301973517864, 0.13508840524140867, 0.12195320724840127, 0.11777171549657661, 0.2075295874308194, 0.23341906917912347, 0.16492164633687467, 0.14092643955542197, 0.11693797434770292, 0.16211857658720788, 0.1458270580417687, 0.17928718919715575, 0.35174645122981846, 0.10320764861159748, 0.1911626245465971, 3.272375824951357, 40.48657155806019, 65.27713168051936, 53.80431659760014, 46.600766105036584, 45.12881040573121, 59.88517492048202, 52.83511461750154, 61.27090123391921, 17.30145912016592, 0.456439015725928, 0.35703411265727014, 2.1417624287066923, 7.963809284471697, 7.935777085442697, 5.420516027558235, 4.3356212877458145, 23.847188911130353, 53.297777791177076, 57.61654269310736, 55.9561877096853, 55.43304158795265, 52.589895879068685, 48.80281609873618, 46.133556904331336, 43.34940756520918, 41.45979788995559, 40.162489644942745, 40.991835594177246, 37.85724993674986, 41.16043083129391, 41.29055938413067, 37.933826369623986, 41.17694008734919, 39.49928745146721, 39.44691204255627, 38.7715583462869, 42.60163514844833, 38.94544486076602, 41.71532853957146, 39.992462742713194, 41.89344336909633, 40.518942879092315, 40.66339985016854, 41.29813740330358, 40.5736207192944, 40.65081688665575, 43.540168116169596, 41.725181533444314, 45.86010494539815, 45.73951951919064, 44.27857391295895, 40.738964311538204, 39.305310556965495, 38.92908857714745, 40.235477109109205, 40.006136125133885, 40.25730509911814, 38.866613065042806, 40.0215628070216, 39.75040151226906, 45.058305801883826, 43.77147028523107, 47.27484895337013, 49.28163943752166, 52.219122071419996, 55.561824767820305, 57.877348930605, 54.70050365694108, 53.40405833336615, 54.33558594795966, 52.877119279676876, 49.20196825458158, 53.041501891228464, 56.265988273005334, 53.32958821327456, 51.96028878611904, 48.77622242896788, 53.41955561791697, 55.531414631874334, 53.0304172731215, 54.25930761521863, 51.29439976907546, 43.75554546233147, 40.13470357464206, 41.56915357035976, 43.5548181687632, 40.35400721334642, 45.31463661501485, 42.84466912669521, 50.3703756486216, 53.908714402106504, 54.95099013851535, 57.032772417991396, 56.89345767421108, 50.62382744204614, 45.13406638176211, 47.77277815726496, 47.79284500306653, 51.03974380800801, 53.34178678451046, 55.03064563197475, 55.79067545552408, 53.442489716314505, 53.40033600407263, 55.006707406813106, 55.36301943563647, 58.25730892919726, 54.71357691672541, 55.471669089409616, 54.99706229855938, 54.75505598129765, 49.87111283886818, 46.93985892880348, 42.866446125891905, 45.44512994827763, 44.036081221795854, 44.628865103567804, 45.14255046844483, 53.007424339171386, 55.58294673119822, 58.318325319597804, 60.08319185626123, 55.21362812288346, 55.52240102521835, 58.10727042536582, 60.37279221319384, 66.28891883357879, 60.21394798832556, 28.909890151792958, 2.2394645021807764, 7.8903364269964165, 11.663817840237773, 25.179743574511622, 4.454754946693297, 0.15104538851207303, 1.6020608404951713, 34.473852649811775, 63.54165938592727, 60.07490388808712, 47.27275048532794, 39.8332655045294, 64.11993834280199, 63.863678132334066, 34.47432725660263, 1.140588106166932, 0.22473478840003092, 0.15397837145193932, 0.1804243547901992, 0.13224240392446518, 0.08863570634275676, 0.1562418854765354, 0.1744182101420818, 0.12557105747081582, 0.15991958248759472, 0.1586909153528752, 0.16300137034587323, 0.07409057715126584, 0.1220580923461145], [0.03565438317074891, 0.057550451583078796, 0.03420551938395347, 0.01935558679002908, 0.04403718153855974, 0.07089779847451756, 0.05010961194432551, 0.02315840319610171, 0.04347664266524296, 0.03897539347470288, 0.052457947223897905, 0.04682835394276246, 0.056418748196935466, 0.01677552906555995, 0.05573119194577298, 0.038122722293220224, 0.051013017298593644, 0.28133638263229405, 25.392814567012174, 50.02033548970377, 48.4310499314339, 26.182173913525, 25.651092836933753, 45.92328648413382, 40.87195227223058, 50.93761313346125, 19.328326256044452, 0.9030882245109928, 0.11868446329308134, 0.294846527038082, 1.826832630941945, 4.729198284687535, 2.7457520317646766, 3.5710245995752277, 16.044566977408625, 47.91707823353429, 54.36163440827401, 50.986042637978834, 49.48483390192832, 48.05416899342691, 42.23888258780203, 40.99551477739888, 39.784867378973196, 38.71614702286259, 39.44666885560559, 36.37776720908381, 36.838202476501465, 35.25321975831063, 32.974232473681056, 35.69567488085839, 35.32037465803085, 35.804842287494296, 34.85363614174628, 36.17730271431708, 34.603031989066835, 36.86097575772193, 36.32502309737667, 36.98860576075893, 36.1613465124561, 36.108778907406716, 36.02063148252426, 37.18330437137235, 35.037042248633604, 36.06429530728248, 35.921634781745176, 37.04257757433, 37.877901215707105, 39.86072209573562, 38.11402790008053, 36.80080267690843, 35.859312242077245, 36.16322925013881, 35.741645059277936, 36.419132524921054, 35.077152406015706, 35.61502310537523, 35.522372799534956, 37.01235178978213, 40.334689540247766, 40.39024991373862, 43.40050035907377, 46.72015128597137, 45.38352127998106, 50.24072562494586, 50.29906303651872, 51.28064009451097, 50.417628442087484, 51.24701753739388, 50.19988590671171, 47.00656275595389, 53.188990854447894, 52.57829743046915, 49.041613917196955, 46.36279982905234, 44.58248307628017, 47.47862785093246, 48.75177037331366, 50.88754800058181, 51.56683975650419, 48.52574771450412, 39.83827829360962, 37.190894157655784, 37.696479828126975, 37.57355274692659, 36.95466549165788, 37.99616067640243, 38.471881420381614, 42.47024359241609, 49.711970513866795, 52.879637441327496, 52.0263179655998, 49.21077397561843, 42.18732303188693, 39.14942772157731, 39.888378727820616, 40.026120601161836, 39.52445730086296, 42.784558803804465, 44.14284029314595, 43.28784596535468, 45.620303000173266, 45.715918617863814, 46.83312731404459, 50.64909927306637, 50.14280757596416, 52.730610909000525, 51.39094106612667, 52.325022143702355, 51.21514435737364, 49.3084684495003, 48.104391021113244, 44.1368116101911, 43.33923293698219, 41.93880165776899, 41.513699100863555, 42.916507336401175, 44.33227116061796, 46.84847554852886, 52.5319310926622, 53.46098761404715, 59.84899105564241, 52.318762040907345, 50.51930412169426, 55.93699947480233, 60.5873066379178, 46.11858913975377, 12.616035957490245, 2.0078457243019536, 3.070505895922261, 3.53587991768314, 3.1926470321993676, 2.1554186507578823, 0.023344510850766977, 2.2696238515838503, 31.670379754035707, 49.15721793328562, 45.367502320197325, 32.95025110244751, 32.95061980524371, 48.81820355692218, 51.47806475239416, 13.717222752109652, 0.12792202809284772, 0.020814061149834626, 0.05163324974297036, 0.0773338410222242, 0.03998234327281675, 0.01802738951218705, 0.04497222632410065, 0.014085297363870328, 0.05829197489806722, 0.024391117190281232, 0.011179073875199163, 0.0651071083942248, 0.0997776737917335, 0.043635019852269086, 0.06327114420973005, 0.10208103204927138, 0.02318481216207147, 0.03786635096935976, 0.018655863147409215, 0.053383584449728655, 0.03936721680445537, 0.023921777253910422, 0.028743835338842005, 0.060501353319494, 0.041858182333770304, 0.05740057797201219, 0.04181491368780694, 0.052574047848822615, 0.030501867314019514, 0.05919421962913006, 0.07329147083744889, 0.6240516071838718, 29.63854689751902, 57.250593400770626, 54.159463682482325, 34.49480202890212, 31.08501699662978, 52.83219245172317, 46.53714526084162, 54.974481213477354, 18.208575863992017, 0.5241070411378338, 0.042939362221307335, 0.4048443116968678, 3.5909691164570474, 9.932404218181487, 6.670537158366173, 3.9438931980440697, 15.900777789854235, 49.609459369413315, 55.10855567070746, 53.17528609306582, 51.02744325514763, 49.54281045544533, 44.31122764464348, 41.741475059140114, 41.134370603869044, 40.25077827515141, 40.863774130421305, 39.62984354265275, 37.706913332785334, 36.32675678499284, 35.82704682503977, 38.09758532431818, 39.07099208524151, 37.840995634755785, 36.714687039775235, 37.863317843406435, 36.97669744491577, 38.32809909697502, 37.531304897800574, 39.16055940812634, 39.00600625622658, 37.71217715355658, 36.73939012712048, 39.68028522306873, 37.76104596353347, 37.44862525693832, 38.244536922824004, 38.81220586838261, 40.44539059362104, 41.18077224300754, 40.331590867811634, 38.8120372064652, 38.057020171996086, 39.41447404123122, 38.88701723467919, 38.435544583105276, 37.78716110414074, 36.879454043603715, 37.208599736613614, 38.324498361156834, 41.44391621312788, 42.65984704417568, 44.43128355087773, 47.4976513462682, 47.37902710514684, 52.73680433150261, 50.98938841973582, 53.7731376771004, 53.05599504901517, 51.73642735327444, 50.92628925077377, 48.45452923928538, 54.751769035093254, 52.014025257479766, 53.036473412667554, 45.97355950263239, 45.96530291341966, 49.24714219185614, 51.97301295495803, 52.05016989861765, 52.096163611258234, 51.859511329281716, 41.323264106627434, 37.90956651010821, 39.29444951395835, 38.65662113312752, 38.72966743284656, 39.34741327839513, 40.59841009878343, 46.2285880888662, 52.27361163785381, 55.2866744226025, 52.09611262044599, 50.560390949249275, 44.47185654794016, 40.46921114767752, 42.55667694153325, 43.15841167203842, 43.75303122305101, 46.70854107026131, 46.74386201366302, 45.28193581488825, 47.52189943867345, 48.961793684190326, 50.21938793120846, 53.394460293554495, 52.35227084928944, 54.21052117501536, 54.603366159623675, 53.91223276815107, 52.93040467846779, 50.46048033622004, 48.667047177591634, 45.734330223452666, 45.57157147315241, 45.19156440611809, 44.52568715618503, 45.548260827218336, 47.67720568564631, 49.412725048680464, 55.044511210533884, 57.08093912370744, 60.554543079868445, 52.2195613768793, 51.63989390096357, 57.770338827563876, 62.985498674454234, 47.70159890574794, 14.851762440896804, 2.3051742536406366, 3.9645981644430472, 6.200090531379947, 4.359882618150404, 1.200998858098061, 0.06411616217284914, 2.476040052790796, 34.26905001363447, 55.010366978183875, 51.106431945677734, 41.50715266504596, 35.99898784391342, 53.54622856263192, 58.72760895759829, 18.0668802415171, 0.056946157597966736, 0.0632719409411713, 0.037073549559159626, 0.017391603567727634, 0.012604960769925629, 0.026409228354872718, 0.04121962889668442, 0.03344029713902743, 0.08167330010403549, 0.01918812188500118, 0.06630248900863432, 0.03326890028772816, 0.03315970211500122, 0.04605612199332926, 0.15850567529278417, 0.24923210452881553, 0.11377417677713018, 0.10561410698198503, 0.09329452449756284, 0.1497764864395703, 0.17317521716317824, 0.12151928738720956, 0.11260708778976433, 0.11911330399133506, 0.20673061901282883, 0.1756817189555976, 0.12811122116662804, 0.14242032632952736, 0.17377552366064442, 0.16814280091033829, 0.18151575429064615, 0.8563454004545367, 32.58525102369247, 65.53984811229091, 64.2076974530374, 38.70576450901647, 37.03922394783267, 56.24743153972011, 50.787217693944136, 60.04277183163551, 24.78450398291311, 1.266751142759477, 0.45380183465538493, 0.9309573387426715, 8.721016472385777, 15.964122106952054, 6.921794385679307, 5.734373792525261, 17.875637239025487, 51.90858802487774, 58.54897637521067, 55.31566466054609, 53.75991144487935, 52.24530389232021, 47.18754483807472, 44.40844358936433, 43.07844238896524, 42.0616542139361, 43.687559020134714, 41.805798007595925, 39.67691198472054, 38.387679899892504, 36.68506530023391, 40.52214353315292, 41.20503994726366, 39.106011006139944, 38.164504881828066, 40.630173452438854, 38.698672863744925, 39.89119106723417, 38.63282803566226, 40.476083140219416, 40.38656680814682, 40.67712814577165, 39.43865545334355, 43.688606292970725, 39.13563274568127, 39.42817488024312, 39.48352736811484, 41.62315284052203, 42.31647099218061, 43.02783989137219, 43.376040458679206, 40.59700589026175, 39.43317982458299, 40.914086372621604, 39.51836193761518, 40.32990032626737, 40.00620280542682, 37.66758372706752, 39.539487823363274, 40.22009749566355, 44.48998574287661, 43.73261920867428, 46.62733624058385, 49.8992048540423, 49.64034018977996, 54.80077512802617, 53.743033486027876, 56.01221484522666, 54.51261035857662, 54.7862192123167, 52.99445698338171, 50.12753386651316, 55.09028134807464, 54.86394882202149, 54.60566074617448, 49.966340141911665, 49.36333064110049, 53.01920321679885, 51.81079941411173, 54.99274376899966, 56.008884752950365, 54.94380827872984, 44.41236988190682, 40.42111504462458, 41.41777753829956, 40.94441806116412, 40.7070440630759, 41.60783990736931, 42.4202569069401, 48.2708054204141, 53.9079495399229, 58.75728168795186, 56.31022868617889, 52.66062798038606, 47.020134156750096, 43.47380945759435, 45.96556963459138, 44.5519591915992, 43.137415224506015, 49.3003922893155, 49.48157048994496, 46.130599437221406, 50.19209215717931, 50.2035140991211, 51.027792346092966, 54.155345193801395, 53.23667903100291, 56.53425093620055, 55.24432851422218, 57.56848581375615, 56.16191994759345, 53.231976109166304, 52.340299775523526, 48.53329043234549, 48.69611586293867, 47.282858433262, 47.33464940901726, 49.67120139829574, 49.378369008341146, 51.90913323433169, 57.696802231573294, 59.68626760667371, 62.28905831613849, 54.80318346331197, 53.18507240664575, 58.05822510873118, 63.77009038002261, 49.61499775609663, 15.704544551910894, 4.2096313257371225, 8.939775882228728, 11.007766127586367, 10.859383844560194, 4.966638472772414, 0.14987681331413408, 3.241175576563805, 41.25986683753229, 60.730794783561464, 58.19407639964935, 46.71664076466715, 44.71373734935638, 61.90886689770607, 66.85392841216057, 21.107521210947347, 0.373189099012844, 0.12286475994774412, 0.12091802327983803, 0.11981436637260261, 0.10166957388601958, 0.2204382608854963, 0.10219816689289386, 0.09178048195016962, 0.11344087490391348, 0.11111900796212497, 0.07318366694474414, 0.1807034252992561, 0.19544775267281841, 0.19240259913907898], [0.08846327527275971, 0.03300582952496987, 0.02007410831509098, 0.05587674099050703, 0.06259517503842231, 0.0032969965597599627, 0.040440069316255475, 0.018021915813968066, 0.032824496513292674, 0.057703163549904866, 0.07343616952458698, 0.028164849068308552, 0.020088930201205998, 0.026658649346040144, 0.03307670797972429, 0.060218919684449514, 0.04810522716011732, 0.08823375533064527, 12.136995907752747, 48.97808328751595, 46.741300705940496, 24.89535212516785, 27.840036230702555, 48.84679763547836, 43.99029147240424, 51.692602711339156, 42.309120470477694, 4.053548939766423, 0.16962735673352597, 0.8039954869497208, 2.5643036778896087, 11.706893309470146, 6.599628550391044, 2.3624643923774844, 12.185738221291574, 45.59465462161649, 54.46843270332583, 50.92535964904293, 48.76018385733328, 46.68887430621732, 43.70735914476457, 41.28114569571711, 40.31644267420615, 39.528109027493386, 39.46923425120693, 37.11295273996169, 35.212631071767504, 35.63758850097656, 34.79471037464757, 36.99229671109107, 35.842657858325595, 34.15826659048758, 34.64547987907164, 35.74332383371169, 36.565464388939645, 37.444016471985854, 34.98252914797875, 36.906573310975105, 36.7790727461538, 37.32288583632439, 37.41353573337678, 36.12843782671037, 37.018458920140425, 35.739593659677816, 38.9103514148343, 36.910954598457586, 38.10260203576858, 36.754620690499586, 36.739288145496005, 38.28510599751627, 35.80642692504391, 36.092469692230225, 37.06751208151541, 36.350208636253114, 36.41867360761089, 36.0540069303205, 36.80836500660066, 38.326938075404016, 41.86402951517413, 44.94233308299896, 45.42830690260857, 47.781701549406975, 48.69076575002363, 47.714185791630904, 50.159132480621345, 50.61723786015665, 52.37536184249386, 49.11029854128438, 48.901020480740456, 46.86123894106957, 48.471454266578924, 54.9902295297192, 47.89632889532274, 48.05381205774123, 45.387682914733894, 48.50921492422781, 50.65790499410322, 52.748120369449744, 53.18268760558098, 51.73000251093219, 40.46885813436201, 36.89140942788894, 37.823042946477095, 36.685233962151315, 37.762607066862046, 36.68838754776986, 38.211894958249985, 44.36599569935953, 49.39696888769827, 50.74865295040993, 49.784530439684474, 46.80495685146701, 40.057640767866566, 36.26011571576519, 37.76229719961844, 37.24114364193332, 38.39444991080992, 38.20878059633317, 37.51139494680589, 39.16297558815249, 38.27189545477591, 38.819544622975016, 40.40843402185748, 46.19395356024466, 47.570062222019324, 48.705604076385505, 48.93967543878863, 50.59238180037468, 47.630498101634366, 49.84062817788894, 47.814217998135476, 46.84146627303093, 44.95357067354264, 45.532681172893895, 44.14408760686075, 43.259040078809186, 41.22514209439678, 44.11932960633309, 47.38815053816765, 50.01540899276734, 54.636439584916644, 58.86064790910291, 56.752228813786665, 57.970870002623535, 52.40828229535011, 35.07856053690757, 7.785808203681824, 0.8179960808446332, 3.498449229425, 5.386732162967806, 3.07829229101058, 0.41508690724449776, 0.015650590235788017, 3.026063970981106, 39.20061857469621, 44.76506548543131, 42.88600698594124, 20.923485563647365, 36.015932483057824, 55.61070534490771, 45.332557924332164, 6.346187053188202, 0.11060141597784336, 0.041104141142099135, 0.02237987783437054, 0.07541719628798385, 0.014551557626785531, 0.03709742085888021, 0.03963118005964545, 0.044565334044877565, 0.02687225572674746, 0.02371746735016425, 0.043224810412333864, 0.05398580616700554, 0.05962975976628162, 0.026986125120592695, 0.09386422578245403, 0.010434905641652163, 0.04234551767548246, 0.043839879424100926, 0.014399348405159771, 0.0505752248629447, 0.0241535609858411, 0.04067582521407355, 0.03024289320643631, 0.01792615865387263, 0.006947875944822426, 0.04448063153352949, 0.0435010617178294, 0.05062821516466718, 0.05718214715260172, 0.03796357135739058, 0.04711146556561993, 0.04921955184169835, 16.714978487260883, 54.754016553201986, 52.443332595209924, 28.714156035454046, 27.672347061095703, 53.203680130743216, 48.8383763067184, 59.66772656286917, 42.058900710075136, 3.6723727612726154, 0.07924529168033793, 0.4693164634368112, 3.452387610750814, 7.629324265064732, 9.00368796240899, 4.967016000901499, 13.479143707982956, 48.940707022143954, 55.850875992928785, 54.56770397001698, 51.42779173389558, 50.15078567689466, 44.256506658369496, 43.920853753243726, 41.37723984256868, 41.21867018361246, 39.783176837428925, 38.82431422510455, 38.37711303464828, 38.12159022977276, 35.51473986717963, 39.4493596015438, 37.229902129019464, 35.3244343111592, 36.56273049692954, 37.24418740118704, 38.4148266238551, 39.8421496729697, 37.422714079580004, 38.93272853666736, 37.665767669677734, 39.62567406315958, 38.54455117256411, 37.78789458736297, 38.59088613140968, 38.29940695916453, 39.502264530428, 38.52258982196931, 40.25712467009022, 39.90881819878855, 37.23065914646272, 38.845808813648844, 37.55905566676971, 39.974243333262784, 38.662159519810835, 39.205223437278505, 37.39997609969109, 38.221998983813876, 37.976901838856364, 39.864613086946555, 43.2077197874746, 45.832016852594194, 48.637676469741336, 50.65932881447577, 49.75234347005045, 48.77744228609147, 52.49933619653025, 52.49988532835438, 53.34474425162039, 51.80257420386038, 49.66509426793745, 49.93310197707146, 50.93190608486053, 56.42038845246839, 49.68970714076873, 47.69362080481745, 48.71420583417339, 50.344119302688114, 52.34021740574991, 55.07927517737112, 55.63444352919056, 52.64772338251914, 42.2048677936677, 37.92636602155624, 38.12026054628434, 39.05826007166217, 39.31104506215742, 39.373948112610854, 39.889469146728516, 46.428201429305545, 51.17265724366712, 52.36578733690324, 51.50402299819454, 49.01613420055759, 41.89478089732509, 39.22660819945797, 40.15149524134975, 40.60505851622551, 40.075114926984234, 39.6987085957681, 41.267868472683816, 40.66838910502773, 40.2466284075091, 41.25068064658873, 42.058524162538596, 49.459114920708444, 48.9586518656823, 51.794725541145574, 51.64825639417095, 53.70042870121618, 50.24035299977949, 52.1782745084455, 51.934534503567605, 48.897027507905044, 47.98377813831453, 46.81679456464706, 46.36176824569703, 45.38538048344274, 43.91877881942257, 47.0212677217299, 50.39585144289079, 52.33989969376595, 55.89840727467691, 62.55333585123863, 55.81704162782239, 60.08973829207882, 54.080718178902906, 38.81289620553294, 8.772934925171638, 1.443197494072299, 4.267245060013187, 6.1371590437427646, 3.287043037914461, 0.4663630106276082, 0.023662364560990565, 3.5114957680625305, 43.2458060018478, 51.181972872826364, 46.306811917212706, 26.568833320371567, 41.19255896537535, 61.08057606604792, 52.5686130985137, 9.574865468086736, 0.12793928039290253, 0.0365274093083797, 0.034519661398183916, 0.04034341200284901, 0.01981631206769136, 0.012631107350781321, 0.04227234478739481, 0.18454998341058532, 0.04969561419960472, 0.005795207126216302, 0.062073185709455324, 0.05250662828104631, 0.04393975047634975, 0.01698084637492655, 0.34142396803344455, 0.28440401318573183, 0.10490982703143552, 0.1449588046319062, 0.18369810896054392, 0.06584158753074947, 0.1146093198669053, 0.08899599749354586, 0.16808727485758646, 0.19786482136095726, 0.1312464896229006, 0.0695206098739178, 0.11840909298869873, 0.22604348107932076, 0.1251901125895881, 0.15262253372178924, 0.2715484449459661, 0.26522380690420827, 18.918777858057332, 64.10900669713175, 59.76977486764232, 36.408722554483724, 39.43046946679392, 60.793831194600756, 54.653090046298125, 63.65669465834095, 50.231712018289876, 5.011512839025067, 0.40151633382324253, 2.589583843946457, 8.822390129489284, 22.677232180872274, 13.504200789236254, 4.620812900604741, 14.309347675692651, 49.07731533050538, 57.354587201149236, 56.40884883942143, 53.9515035383163, 53.58467955743113, 47.37652855534708, 45.51590911803707, 43.33434958611765, 43.0442314763223, 42.955460394582445, 41.15666143355831, 40.64636891888034, 41.15630449787263, 38.43605449122768, 41.246424874951764, 41.3017342167516, 37.80711812357749, 38.26857712961013, 39.99238429530975, 42.12435330114057, 41.89448279719199, 39.15866098096294, 41.027548774596184, 40.48069192517189, 41.80808474940639, 40.12215199009065, 39.377301739108184, 41.074005326917096, 40.159277223771625, 42.02425441434307, 40.65030697853335, 42.85166271271245, 41.436950083701845, 40.22603988647461, 41.96071201755155, 39.967167377471924, 40.687275317407426, 40.680485694639145, 40.98716797367219, 39.20434874873008, 40.10449740194505, 40.22072115252095, 41.89640475857643, 47.94813556055869, 49.903084078142726, 49.52102561150828, 51.758337713057, 51.027988464601584, 53.62548789670391, 54.45454359054566, 54.8119068145752, 55.56268768925821, 53.21158370664043, 52.49667290718325, 53.79471463541831, 52.31500833265243, 60.39625975393481, 52.15402641604024, 51.35451793670655, 50.214794835736676, 53.02908366726291, 54.362277676982266, 58.27736793025848, 58.3949056748421, 56.936878312018614, 44.875554730815274, 39.96875985976189, 41.30436612713722, 40.744255588900664, 41.72877834689233, 40.51178847589801, 41.202506096132346, 48.68105396147698, 53.02836587352138, 54.47036250945061, 53.707394830642215, 50.89969558100547, 43.85621701517413, 41.45473018769295, 40.81311671964584, 42.342099758886526, 41.53044762149934, 41.320655730462846, 43.21927509000225, 43.740185460736676, 41.55223246543638, 42.90426954146355, 43.09183336073353, 51.140164329159646, 51.861382299853915, 54.24378679644678, 53.93692801075598, 55.982695087309814, 53.07148841119582, 53.86581151716171, 54.44380414101386, 53.29049394976709, 50.22057640937067, 50.27308910123764, 49.54759182468538, 48.53295703088084, 45.75947261625721, 49.38828083776659, 53.10672306245374, 55.11745552862845, 60.281240171001805, 62.10550708155479, 55.99482697825278, 58.82453072455622, 53.391396922449914, 40.78454225294052, 11.033145823786336, 3.5122866159485233, 10.266973568547158, 17.371812712761667, 10.465825969173062, 1.7928505640837455, 0.20938370406867998, 4.433806548195501, 47.62930962347215, 56.16895667968258, 54.81636654946112, 31.891401390875544, 47.61215709870862, 70.13875653666835, 61.42587800179759, 11.22686972541194, 0.21663866396392548, 0.10165134865430095, 0.10917876771981679, 0.1040253938446122, 0.11217375015539509, 0.13701436560480826, 0.21133767260659128, 0.2660412840064495, 0.12994780205190182, 0.20068911174612664, 0.13952348741792864, 0.18375086177500988, 0.12950141794018208, 0.1345973122384279], [0.028876027640616222, 0.05732740891436416, 0.038715685837932175, 0.01919426974059353, 0.08418020792305471, 0.10015763041953887, 0.022641964174146136, 0.09595103396643555, 0.19267966249777427, 0.043723924355881835, 0.055429671230095054, 0.018747314893370195, 0.03473851739639237, 0.02387787658540953, 0.05372882580324527, 0.07979076926506336, 0.02780502906159288, 0.11180117095430052, 7.655864492539437, 44.68315462912283, 53.5004388132403, 39.05859347312681, 33.25700398414366, 35.60850804851901, 40.982064970078014, 48.76781286731843, 48.214386047855506, 7.82664547043462, 0.10900814461732104, 0.10075545479213038, 1.9169874513341536, 3.645484178296982, 5.315460735751737, 3.1248782815471774, 8.694069789301965, 44.053174911006806, 54.523443944992565, 53.15968682689052, 48.199163329216745, 47.077326236232636, 41.18460439866589, 42.4226926988171, 40.93149777381651, 39.56821918487549, 38.58841896057129, 38.07268611846432, 34.884324765974476, 36.92485940071845, 35.15128127990231, 37.63701669631466, 35.59940814971924, 34.40464635049143, 37.36243509477185, 34.076398880251, 34.2579379389363, 36.03399892007151, 34.849666703131895, 36.74175531633439, 37.36442765881939, 37.65371422613821, 36.448365949815326, 37.418756408076135, 37.07508617831815, 35.99181382886825, 36.517364363516535, 37.15729121238955, 36.44210192465013, 37.83319404048305, 36.08488382831697, 35.753608288303504, 36.227748317103234, 36.323505140119984, 37.318237827670195, 36.763571539232814, 35.225841614507864, 36.71813088078653, 35.7917494158591, 47.46369146531629, 49.97025858971381, 49.973474933255105, 50.185306456781205, 50.38602982797931, 51.12178802490235, 55.65803266340687, 52.016614021793494, 50.60153661235687, 51.50106553108462, 50.26739774211761, 49.33481108757758, 45.325195635518725, 51.54210921256773, 53.0157672205279, 48.41406999095794, 45.632321142381244, 45.84217186897032, 47.8396192673714, 51.72724116233088, 55.689509684039706, 51.544505780743016, 52.44263833568942, 42.77034021192982, 36.37851245941655, 36.68585369663854, 36.277825217093195, 37.90580103474279, 38.063382256415586, 39.18136365952031, 42.079563756142896, 47.754421464858524, 48.80837409727035, 48.14696834933374, 45.38398804203157, 39.66317192200692, 40.440801420519435, 39.43712572897635, 37.99418380183559, 38.51328595992058, 38.50647672530144, 37.25745285710981, 38.47788264674526, 37.66404574917209, 37.51373267942859, 38.53927558468234, 38.973866355034616, 40.35735691747358, 43.83901349959835, 45.70198243664157, 47.01512921241022, 48.824663700595984, 48.597001491054414, 47.89176717881234, 48.95392540962466, 47.81570849880096, 45.44598894734537, 44.283873035061745, 44.00052101381364, 43.10285522091774, 41.8589186668396, 46.36652215834587, 49.398945762265114, 54.83711981004285, 55.647312825725926, 52.83252977555799, 53.83300873541064, 48.46521769800494, 22.018040610897927, 4.780345501438265, 0.676243584002218, 1.6840717172430408, 2.6937610151306277, 1.6359385968216005, 0.2655519683274531, 0.05865947876666343, 4.899382081723982, 42.64595400902533, 44.44050504315285, 44.57036295244771, 35.97445734085576, 36.704794822200654, 51.879283997320364, 34.979273580735736, 3.5240782412790486, 0.17572397636550088, 0.03329421183274638, 0.01868180671496497, 0.06816730023391786, 0.018027512086254936, 0.07905832792241728, 0.03621462710021484, 0.014623650330899945, 0.06262052871827638, 0.024883265479377685, 0.016234868258658438, 0.038766159540823394, 0.06332219247856448, 0.05941343568866292, 0.047987487107034654, 0.09163970563320384, 0.039812700762864084, 0.014366180628478048, 0.07683227559731853, 0.023840397648933916, 0.031583811374261014, 0.008244506090939527, 0.06959999956551098, 0.02335780439147305, 0.03274002765876151, 0.017477060675681118, 0.04809446362478118, 0.0550581683825341, 0.07536135613918304, 0.07441848576549562, 0.0146698885251798, 0.12760711232981375, 10.560646326311174, 50.91593419351886, 57.487124089271795, 40.54679562968593, 35.64291900204074, 43.91813555071431, 49.56519149964856, 54.280676687917406, 51.507906144665135, 8.698158860206604, 0.12542654264477954, 0.3920853318225953, 3.003789075920659, 5.6886100288360355, 8.540983603846643, 5.757516266838198, 8.735166422782406, 45.305909341381444, 56.72734529741349, 54.55167716549289, 50.41836192530971, 48.41732163583079, 42.360927135713645, 44.352153655021425, 42.893898794727946, 40.54889802009829, 40.888806696861025, 40.01225894497287, 37.717911658748505, 38.020757859753026, 37.54705713641259, 38.23878672815139, 36.93460649059665, 36.50274176751414, 37.0129362229378, 36.033261514479115, 36.52776256684334, 36.84360750259892, 37.228458696796054, 38.948414094986454, 38.13003901512393, 38.08738716187016, 39.204458575094904, 39.519162101130334, 38.78050919502012, 37.013877591779156, 38.06352346174179, 39.11032561332949, 37.94421280584028, 40.40422924103276, 38.31874816648422, 38.79029943097023, 38.1059713517466, 38.23302476636825, 38.53953446111372, 38.61276903460103, 36.772196831241736, 38.749840182642785, 38.00289930835847, 49.0330356936301, 49.22756171995594, 52.99502964942686, 52.26761825623051, 50.83550991550569, 55.089845964985514, 56.988202525723366, 51.57463350603658, 51.96402288252308, 53.718502982970215, 52.23921637381277, 51.34255863005116, 48.99721268684634, 54.190481785805, 54.17317236623457, 49.689095251021854, 48.31879169710221, 47.049069481511275, 48.70538050128568, 51.61889353106099, 55.13128972822621, 51.22211440916985, 54.563738453772764, 45.89113481583134, 37.750628148355794, 37.91537161796324, 39.65253837646977, 39.18541939027848, 39.48306845080468, 39.08570881812803, 44.42874969974641, 49.073632224913574, 51.15713250252509, 50.05415416532948, 45.38175621340352, 41.90363368680401, 41.943496734865256, 41.95356938146776, 40.33881979603922, 39.80370652291083, 40.117739323646795, 39.422491365863436, 39.66070082879836, 38.452340172183135, 39.024861089644894, 39.4049269922318, 40.79435994548183, 43.379645116867565, 47.795284717313706, 48.19930453454295, 48.46105214088194, 51.87545968640236, 51.26205198226437, 51.37425922578382, 50.58257979731406, 49.97861323818084, 46.78774941352106, 45.63578459524339, 44.46134067350819, 44.04860142738589, 44.08663272857667, 48.8136379180416, 52.5926846842612, 56.48910837788736, 58.668251729780636, 53.94029340436382, 54.84038322202621, 51.10246642943352, 27.146884779776297, 6.458262407010602, 1.8023626794738157, 5.525249194714331, 5.101766576690059, 3.8532376625845512, 0.8579647264653637, 0.04500217270106078, 4.699576054849933, 47.2298397556428, 48.25536697141586, 51.65283772253221, 34.993433337057795, 38.922020466096946, 60.272665869805124, 43.69706684543241, 4.95593628575725, 0.15536289151397445, 0.06890102860427673, 0.01173567122614552, 0.10408022275735294, 0.03534944953336831, 0.027730946444095145, 0.03468251253868784, 0.025701409078113018, 0.030574762495234612, 0.046512124338938345, 0.08678011115520232, 0.015150211289555076, 0.03255635041803603, 0.05867318024918918, 0.20319201292530184, 0.23971107187530688, 0.17090601876618403, 0.12345175949796555, 0.1647159976944808, 0.22769090719521048, 0.1352798965789618, 0.1691234853839682, 0.1936969659741848, 0.08602273365062091, 0.140817272026212, 0.14777022473994764, 0.14210123538730607, 0.1336135327695839, 0.13963654667379397, 0.24343557685853975, 0.23694478966776403, 0.2179469582774947, 12.344531455347616, 57.76063096138739, 66.62975711207237, 50.569055464959916, 45.775444507598884, 48.606552462424006, 54.90499642587478, 58.14026932562552, 58.47364725605134, 10.967244121336169, 0.3482081362557027, 0.28114256238745106, 4.844953312027839, 11.389692214227493, 14.099373394443145, 9.179134599624142, 10.666911179019559, 47.53649850045481, 58.384644754471324, 56.82576540977725, 51.80284876977244, 53.035026058073974, 43.94012435790032, 47.793817750869266, 44.0730260264489, 43.85349096790437, 42.87580097875288, 42.09556702644595, 38.68093590582571, 41.108326065924864, 40.3148345024355, 41.47572271285519, 38.95654909072384, 38.49823974793957, 40.722058896095525, 37.700602239178075, 37.53569795239357, 39.29928971875099, 38.08047202325637, 40.44408836672383, 41.3860494859757, 41.37856560368692, 41.52316378008935, 41.42980744761806, 41.250645345257176, 40.13769634308354, 39.62098683080366, 40.18620821737474, 39.90280912768456, 44.26766972387991, 39.90684132422171, 40.0125099766639, 38.92331877062398, 39.17581350572648, 40.98678750376548, 39.74540441266952, 38.51000685845652, 40.69211159982989, 39.745259284973145, 53.00612211227418, 52.85384785744452, 54.61064607866349, 54.78759988661736, 54.22847386329405, 55.712847786564986, 55.86783632155388, 52.824383012710086, 55.099063534890455, 53.934331401701904, 55.51362668314288, 52.59033126215781, 52.10334154867357, 55.27220087666666, 57.590564835456114, 51.8812059587048, 50.11884973895166, 49.60792180030577, 51.70291462252217, 55.77832391185146, 59.596064859820956, 53.599788527334894, 57.336956147224676, 48.224619511635076, 39.50338632829728, 40.56004147375784, 41.876435972029164, 42.476417403067316, 40.82407582190729, 41.34614721421273, 46.56342514099614, 51.91625233619444, 53.168025785876864, 54.06391866745488, 49.04121383543938, 43.538795286609286, 45.2099681669666, 43.30308437347413, 41.98955712779876, 41.64005825596471, 42.55221328427715, 40.93168604758478, 41.942453384399414, 41.00574824117845, 40.51581675006498, 41.3836686072811, 43.426089902077955, 43.90579969652238, 48.80187472989483, 49.037938656345496, 51.616140027200025, 53.39694315387357, 53.01030335887786, 52.7097438996838, 53.15345418068671, 50.91121950457173, 50.598704661092455, 48.652922722601126, 48.17415821936823, 47.3634905968943, 46.13028172523745, 50.685440032712876, 54.77906088675223, 58.420373624370946, 59.271806440045765, 54.46763253981068, 55.15812266257502, 52.68073797225953, 28.157385395419215, 6.970651918841947, 2.914606390460845, 8.534826463268649, 9.663297264806687, 7.858709866000761, 2.57876300523358, 0.22365089656124193, 5.615468611640315, 54.28032759697207, 56.23542908699282, 58.1889537842043, 47.96419374404415, 50.01321246547084, 68.34016153889318, 51.418887953604425, 7.305827275399239, 0.2924480896082617, 0.12034092924647755, 0.0837807390358179, 0.28434211328145, 0.11910923606445713, 0.1407878695716781, 0.11671283642851538, 0.10665102230925715, 0.11814157508553998, 0.20513157901023665, 0.147462134820319, 0.13000403290554402, 0.13534441650394471, 0.13415080555264028], [0.07228470106999721, 0.060775984349029685, 0.017913905077523763, 0.0673453951434743, 0.01752076024610189, 0.06993134791452078, 0.03495483764357144, 0.06342317435830351, 0.026786126376640414, 0.005140735339673777, 0.02232191753723929, 0.024363541855446758, 0.06956489741682045, 0.05442036188117439, 0.0665086968952129, 0.0324038797689061, 0.08900216450133631, 0.055369169436275005, 3.078993904975153, 34.852180942412346, 52.2984637752656, 41.744091280045055, 20.79107419137032, 28.13751662931135, 47.742156213329686, 47.15992350732127, 56.609156439381266, 17.24150961445224, 0.17419901706518667, 0.85025598204905, 3.9552249254718905, 4.614433165519468, 9.885892752678165, 5.969868485004672, 6.263794235644802, 39.12332827045072, 55.63042309976394, 50.58767103379773, 47.54797927794918, 46.36316460947837, 42.473887474306174, 41.33398786667855, 40.39645118098105, 41.81739645619547, 42.03691190288913, 40.22793831363801, 36.7418808321799, 37.141739014656316, 36.30654088912472, 36.814436835627404, 34.72220536201231, 34.95013821509577, 34.654399348843484, 35.85100858442245, 36.32107327061315, 36.34171278245988, 36.364466451829486, 35.99964680210237, 37.056827545166016, 37.430876531908595, 36.88137600498815, 35.246198715702185, 36.240421495129986, 37.47477569887715, 37.686607222403254, 36.72559907359462, 37.919690147522964, 37.108779338098344, 39.48011490606493, 37.0383257250632, 37.24625449026785, 35.714792513078265, 36.81523307677239, 36.2255714016576, 35.573422447327644, 35.45870488689792, 43.11743859321841, 52.068758010864265, 49.42343311925089, 50.52556814685945, 50.57420553699617, 52.59137069025348, 48.36356163024903, 49.13832779853575, 58.11296570685602, 54.69658128676876, 50.20849158686977, 52.216537229476444, 49.308590042975645, 44.94471788406373, 50.781851891548406, 50.968423351164795, 47.80233713888353, 46.82349397290138, 46.448495772577104, 47.44017293376308, 49.533526205247455, 49.78456966338619, 53.748599329302394, 50.595009788390136, 45.25573438213718, 36.732855458413404, 38.18891771378056, 36.72131192299628, 36.95783868912728, 38.40878225141956, 39.657861032793605, 42.169115389547045, 46.422176668720866, 47.74363886925482, 45.91423365377611, 43.08408667964321, 38.850637251330966, 38.499157582559896, 38.886064098727324, 35.542274905789284, 37.901325610376176, 38.37079017393051, 37.236605459643954, 38.02412325336088, 38.342749149568625, 37.78768277937366, 37.38243526028049, 38.688917929126376, 37.196224658719956, 37.68919598671698, 38.75833603643602, 40.63526076655234, 43.27864408493043, 44.9297030510441, 45.71733067112584, 45.027107269533225, 44.40176379296088, 44.857582430685724, 42.61470056349232, 42.830827082357104, 41.64758528432539, 43.06636148883451, 46.46413426245413, 50.82451943428286, 53.28598322406892, 57.84193385031916, 56.620496011549434, 55.43026062750048, 41.36568846241121, 13.708570984102066, 1.9400435109292309, 0.6497436833958472, 4.580546338712016, 2.5790302167015695, 2.0779942504821287, 0.09934065893532769, 0.06978889386500083, 5.445368655266301, 44.5202076050543, 42.157171772372344, 27.37598061561585, 26.642095350450088, 46.25979446595716, 47.748416316124704, 27.426777270532426, 1.8475199466751469, 0.06199780648814575, 0.043963169784195004, 0.06572285156336523, 0.13143113213441066, 0.06793041052597185, 0.003722505733152972, 0.1018055774752171, 0.04067058900311109, 0.08721914848372822, 0.02919245259686103, 0.033541642910530495, 0.032396012045923746, 0.06515950880824559, 0.05033103050664068, 0.03821224732805164, 0.013338068609065829, 0.03284393982481092, 0.02363005863322366, 0.08320551425699266, 0.025522720984994404, 0.0643262502947642, 0.05263187599578693, 0.06195172629950028, 0.047956782303029494, 0.03313152540114618, 0.03755663694333165, 0.03891277344777219, 0.01438066352068657, 0.024195956291570783, 0.02277428671086748, 0.06972320182549377, 0.08451360172682232, 5.158545826711963, 41.56736496956118, 59.336796191430864, 47.318842257222826, 26.283804485874793, 37.558918383813676, 52.12311421671222, 52.08649496878348, 60.85746772827641, 16.353412443591704, 0.22541721952297997, 0.5232191145900758, 3.2387866079807286, 5.610198417017537, 5.3957344928095425, 3.6128360850195733, 7.203312698871859, 40.806860539221, 57.183328674685576, 54.017269918995524, 50.75535235866424, 48.88370321642969, 44.7609430743802, 44.01383353817848, 41.66547913705149, 44.00958561128186, 43.74317430680798, 41.8572045910743, 37.39390427066434, 39.58268488607099, 37.76158725061725, 38.83797191804455, 36.92608318021221, 36.914931881812315, 37.096274821989, 38.3970739764552, 37.5468296389426, 39.29191566282703, 38.64401855776387, 37.803772341820505, 38.91249302894839, 39.006586767012074, 37.62127230244298, 38.49756902264011, 38.52487656377977, 39.951309234865256, 38.97622762187835, 39.11566395913401, 39.94690441316174, 40.28813492867255, 40.17750447796237, 38.42154956633045, 38.75842232857981, 36.128014210731756, 37.100432534371656, 36.96641299032396, 38.06110728171564, 37.667760233725275, 43.64069454131588, 53.15547812369562, 52.848380073424316, 52.83401635385329, 51.665150042503114, 54.25638544944025, 50.455957843411355, 53.76588521465179, 60.53190708160401, 55.15212928095172, 50.65192730196061, 52.226786382736705, 48.96090722853138, 47.69507992652155, 52.54012884632234, 54.47783462462887, 49.66909900788338, 48.61511499651017, 47.26193258839269, 49.72119200614191, 50.652119498099054, 53.51573213454216, 53.82470507775584, 52.1565681119119, 47.083707932502996, 38.59506345564319, 40.19490803441694, 38.518463488548036, 37.96575446282664, 39.74680469882104, 41.69375158125355, 42.910855200982866, 47.93253629438339, 50.05673508490286, 48.63921796121905, 44.04162745321951, 39.65498201308712, 40.64174052207701, 39.92812802714687, 38.97758868432815, 39.818403643946496, 38.58759918520528, 38.58618320957307, 39.98024455962643, 38.69856695975027, 39.123767575910016, 39.305651803170484, 39.50281366225212, 37.882611982284054, 40.806993899806855, 40.87402328368157, 43.69787093131773, 44.9498365771386, 47.60399464638003, 47.846165703188994, 48.5263752937317, 46.73534262564875, 47.26408989198747, 44.836672275297104, 44.01619480502221, 43.016147305888516, 44.93344891455866, 48.1305532301626, 53.30858784337198, 55.45211607410062, 60.65772102725122, 56.69851979901714, 56.3408310182633, 44.56994718120944, 18.449007349629557, 3.0865920262952007, 3.056451553298581, 5.173585174545165, 3.8412702660406794, 3.5843685029014467, 0.44531805440783506, 0.05114261256230455, 6.118933750737098, 48.752354806469334, 50.12922048568726, 36.77708802684661, 34.66226762340915, 51.30204839091147, 55.50388351563485, 34.43637832518547, 3.3464255159901035, 0.13048418617296603, 0.029867069622982415, 0.049357420854991486, 0.05771093551189669, 0.03378713195542655, 0.018454177094803705, 0.049742824367938504, 0.06587652114009665, 0.08093291442961463, 0.012539451633910499, 0.03334164416657821, 0.01893194974400103, 0.037019682086763844, 0.037194135628881, 0.17289360324221273, 0.1022165530030766, 0.08510466920392168, 0.3543034995034818, 0.1824204888074629, 0.20525901007556147, 0.14885252311585412, 0.11549776735445184, 0.15830535862234332, 0.20362983217402814, 0.19415776786063949, 0.1713088277967707, 0.13202448255352436, 0.22394749516200638, 0.1786212749298542, 0.1612631781327148, 0.19595602136706153, 0.21318230507594926, 5.719135874702085, 48.844059821098085, 65.0151095082683, 54.02506366852791, 31.751268832914292, 40.120484982767415, 59.85918921809043, 56.277947579660726, 65.55977767513644, 20.448490458150065, 0.41595169793694253, 2.2837514935001253, 10.398673030637926, 13.10258048195993, 17.19649649435474, 10.034395648587136, 8.372851206410317, 42.871615809779016, 58.54940783592963, 55.98284413737636, 53.52332976556594, 50.90799531629009, 47.14543427190473, 45.62258189724338, 43.9510638483109, 46.10238582857194, 47.021734483780406, 44.783881095147905, 40.320408190450365, 41.56616080191828, 40.80586425719723, 41.04582701959918, 39.09708761399792, 38.772801737631525, 38.94443681163173, 40.84744922576412, 39.12944324554936, 41.39245863883726, 39.84516205326204, 39.808868362057595, 40.951078245716715, 41.80182856898154, 40.8506263456037, 39.47467065626575, 40.684408064811464, 42.08483542165449, 42.52581573301747, 41.29235190729941, 42.810156191549, 41.55735508088143, 43.25231321396367, 40.07122785814347, 40.004476962550996, 37.667815146907685, 40.427073124916326, 39.77033499748477, 39.6968807712678, 39.3983099537511, 45.10382883010372, 57.36063941832512, 54.11658433175857, 55.14513961730465, 52.9112752791374, 58.21945021229406, 55.5970476519677, 55.76201469667497, 57.60406563358923, 54.47268063022245, 53.44939701018795, 55.38104272657826, 51.469929756656775, 51.396820699014974, 55.12057381291544, 55.01793323024627, 52.23989102148241, 50.1342724984692, 49.61053409884053, 51.982811035648474, 54.20292746636176, 55.21842910397438, 56.80165852269819, 53.65645108684417, 47.782340895745065, 40.285844264491914, 42.0830625103366, 41.17499851411389, 40.61488797587734, 42.38544587166079, 44.19062260658511, 44.56301635311496, 51.56953834718274, 52.01847322525517, 50.29788632546702, 46.83201728328582, 41.92825048200546, 41.3456843745324, 42.06005780927597, 39.76856993090722, 42.21092393321376, 41.14717714248165, 39.83707020359655, 43.298224556830625, 41.07885729882025, 41.12273293156778, 42.06613356067289, 41.20747181677049, 40.38411532678912, 42.356279127059445, 41.88139384792697, 45.47731299554148, 46.62630465722854, 49.31586603964529, 49.342659750292384, 50.319231863944765, 48.78200792497205, 48.845428728288226, 47.52656705917851, 46.69689947558988, 46.86210186250749, 46.82328216491207, 51.016919535975305, 55.76143418588946, 58.47895422289449, 63.30615243604107, 56.2926447006964, 56.75694350273379, 46.46801348655455, 18.26044136478055, 3.3893166338243796, 3.341483574721121, 10.841089910076512, 11.595033195710952, 7.924141374326522, 1.2197007190796638, 0.15301371353768534, 6.663033173930261, 53.234313841789, 55.11914607017271, 39.54377105159145, 38.5909685011833, 59.04630937883931, 63.96013313724149, 39.979020780132664, 4.491684552161924, 0.19321077593391944, 0.1271913870568237, 0.1509254344648892, 0.22124237741433808, 0.14723806942422546, 0.12203187681734563, 0.19451148597703827, 0.30362132876630754, 0.16548001718136574, 0.14725988760830896, 0.08572107120867699, 0.11131104322210436, 0.14861774781057913, 0.15993819842415471], [0.048916479797973755, 0.040668440126483484, 0.011259429795186848, 0.07367534217454734, 0.0684123411173782, 0.012063322243310753, 0.11664263213113432, 0.06065810640012065, 0.04390107452749245, 0.04202251202396808, 0.0040185558628441104, 0.045947008090273994, 0.03585317915666007, 0.04648981202814368, 0.06668169487027392, 0.058841328887689504, 0.10882102764181553, 0.030863476136038383, 0.3787749218604257, 23.799257547624652, 55.34658078224429, 41.13690837737053, 29.509106720647505, 34.43556247218963, 44.222009412703976, 44.15266975279778, 53.56768784984466, 24.08152895589029, 0.3448423749256519, 0.13307607612542569, 1.495427897860927, 2.4909301054093147, 4.493185349049107, 2.0553584973658285, 4.322372501896274, 34.97590034238754, 53.52691481190344, 53.2424331480457, 49.972776751364435, 50.128090843077636, 42.33308222986037, 42.764397821118756, 41.578237779678844, 42.90828997089017, 40.353591442108154, 41.07695494928668, 37.01301074797107, 36.606915996920684, 37.63821301921722, 37.01517197393602, 34.97983840204055, 36.60187575124925, 36.04050220981721, 36.8077923405555, 35.33200448559177, 35.64659818526238, 34.954833292192035, 36.85158168115924, 37.800414792953, 38.705270290374756, 37.076309957811915, 37.7793045966856, 36.81813955307007, 36.440097593492084, 36.67975441102059, 35.72893657991963, 37.28055953979492, 36.12176979741743, 39.29506140370523, 38.64474027387558, 37.81177397697203, 37.782717058735514, 37.4057262943637, 36.23647951310681, 35.378947411814046, 35.66272697141094, 45.15289375858922, 51.7500340554022, 52.095912579567205, 52.69568220261605, 51.805508136749275, 53.01549265461584, 49.92896779890984, 46.44582856085993, 38.996937736388176, 50.22801714558756, 54.51693673287669, 49.91085037108391, 47.65394995289464, 46.063260186103086, 51.3053745608176, 51.112672436621885, 47.63159636528262, 46.33130711893882, 49.24817377521146, 51.2082919766826, 54.70140972445088, 56.5767772736088, 49.87594912129064, 51.831968445931714, 48.240073650114, 38.003016979463645, 36.36716896487821, 36.75302036346928, 36.97876453399658, 37.90671886936311, 37.880631185347035, 40.207483153189386, 43.19112816164571, 45.6963106893724, 44.442952602140366, 40.444633576177786, 39.10894886139901, 37.11336066645961, 38.66890599650722, 39.22917342955066, 38.38586776487289, 38.47676084887597, 36.976524860628196, 38.958627946915165, 37.82410590879379, 39.34753879424065, 37.9659309694844, 36.80994964415027, 36.25421647102603, 38.21571142442765, 37.429346807541386, 35.25083495724586, 36.90458859166792, 37.84361577803089, 40.421534738233014, 41.51811176730741, 40.44117012331563, 39.102049412265906, 38.30304691868444, 41.35919301740585, 38.460255515190866, 43.4833800408148, 48.483288057388805, 52.683813110474624, 52.90695674957768, 55.27511912007486, 51.825280804787916, 52.77840106718002, 37.1187892267781, 10.615735034788809, 2.2482312446640385, 2.410939984744595, 3.441488814930762, 2.4463388852534758, 1.5841906445641674, 0.41605790836676476, 0.08908412058747585, 6.254600690257165, 46.118243971178615, 47.1803786677699, 39.699151823597575, 25.777257834711385, 40.852312964777795, 50.86196237994779, 25.83251814688406, 0.5304804023715758, 0.03681189988950088, 0.03837288447445439, 0.020369320296712463, 0.05416020608296799, 0.04877727013081313, 0.019338062528761166, 0.07789770471713237, 0.01848800753753993, 0.06303190261185651, 0.011008242013744049, 0.06731283640669239, 0.02386627609901611, 0.03208052171694656, 0.024063285184843887, 0.002303231374225429, 0.03128201678215015, 0.037098830460660884, 0.02069539413036358, 0.1106759639937551, 0.08138587923660394, 0.07786462504056194, 0.06902231564444881, 0.0611218883686008, 0.03765115687142938, 0.038065913043195204, 0.008090586578022809, 0.011398736180947914, 0.0328576106638197, 0.03163218791145952, 0.007072940277266166, 0.02139787951995048, 0.05224982411750863, 0.8083387764711535, 29.92375419985864, 59.253288930462254, 48.353363467801, 31.56601921204598, 34.79988398090486, 50.050274941229056, 48.48313508495208, 58.78381259979741, 24.468553143162882, 0.48916803853165725, 0.1845602489887707, 1.9865470091181419, 6.11043740664759, 6.600724362557934, 4.090230700469786, 6.270498546861834, 35.89406836417414, 56.57479647667178, 55.86249405337919, 50.169354177290394, 50.898522792323945, 44.31941755356328, 44.32830956674392, 43.86072774087229, 44.4776891123864, 43.54477690112206, 43.198439459646906, 38.81417097583894, 38.38710331147717, 39.23415483966951, 39.25315480078421, 37.01357164690572, 38.323804101636334, 38.09550646812686, 36.181644778097834, 37.14455527644004, 37.96027883406609, 37.144633723843484, 36.583330785074544, 38.86453420885148, 39.16718036897721, 38.662551756828066, 39.694747001894065, 38.86968428088773, 39.081037275252804, 39.65234618033133, 38.14198263229863, 39.36436576227988, 39.679916520272535, 42.26108320297734, 40.18854202762727, 38.21313442722444, 39.86979453794418, 39.72582001839915, 38.41302233357584, 37.95487380796863, 38.29940695916453, 47.29339784191501, 53.30769746534286, 53.665358789505504, 54.7070461703885, 52.738365434831195, 53.206359109570904, 50.86431972442135, 47.46322862563595, 44.81673094534105, 57.501597635207645, 54.437194947273504, 49.67776352359403, 50.4382130407518, 47.8304801448699, 52.69884755534511, 54.33933573384439, 50.81031260951873, 49.54676812694919, 51.37187050234888, 51.00517203730922, 55.89910153419741, 55.597373208692, 51.99689234456709, 54.26057454078428, 48.71845376107001, 39.43150889488959, 39.06706971506919, 39.76704412891019, 37.78659628283593, 39.67560583545316, 40.6258313886581, 43.25521184552101, 44.461705453934215, 48.076714777177386, 46.305764644376694, 42.95909250936201, 40.417733961536044, 39.39098688863939, 40.24133320777647, 39.54369652655817, 40.759180207406324, 39.11240446952082, 39.37618386360907, 41.55241289446431, 39.55353775332051, 40.572997062437, 39.396058513272195, 37.74863558430826, 38.37228851933634, 38.24854950751028, 37.96739401355867, 37.7959236791057, 39.38577405868038, 41.04347359749579, 42.22574264772477, 42.879943001654844, 42.690786700094904, 42.12762063549411, 40.666400463350364, 42.805598397408765, 40.99884879204535, 46.00080820821947, 49.96216674004832, 55.19126669053109, 55.74623107910157, 56.82611842309275, 53.397990426709576, 53.37840211006903, 39.35845082806003, 11.784064962017922, 2.9150574630306614, 4.330245189128384, 4.162276550646752, 5.714228009023975, 4.520722348843852, 0.5184061212405082, 0.03977029013537592, 6.292865372473194, 51.62534975236463, 52.32572032559303, 38.798497184630364, 27.3778574697433, 46.86190574399887, 56.80857366131198, 31.408208531718103, 0.9007748228407676, 0.08691981494907411, 0.024676019543661706, 0.07569875658279465, 0.029909120189146172, 0.08024601701406703, 0.02903181162001866, 0.05112856250977324, 0.030533252021057472, 0.10602295278541504, 0.01994881655029472, 0.07578344760282386, 0.057758386997926625, 0.01028454652236354, 0.0651596543649512, 0.12817436979422647, 0.15536355034958932, 0.16556013465648697, 0.10904123195477071, 0.2626652877417303, 0.12460060027097503, 0.13779373749369575, 0.21228846432941578, 0.13029608094403822, 0.12428547000332225, 0.1094483923647673, 0.1730428218481041, 0.1128963013029387, 0.1124614161709624, 0.12181158057383953, 0.13811754753753064, 0.2724106002959513, 0.14799893262886232, 1.2586502226129657, 35.41944196147304, 68.3390946542063, 55.69880177897792, 40.634291941119784, 47.054811831443544, 55.25849219291441, 54.461670537148755, 64.43785036763838, 28.615857516565633, 0.5181802785204304, 0.48006516731073784, 5.443126530416551, 7.480661532571239, 10.121481091745439, 6.716056264215901, 7.419157787676781, 39.08111180028608, 58.705514246417636, 57.28116043152348, 52.63285367719589, 54.02302403603831, 47.28472940383419, 47.69047506393925, 46.96163200563001, 46.89914472641484, 44.41599022957587, 45.19861290531774, 39.41719616613081, 41.64875807300691, 41.222474882679606, 41.24444800038492, 38.49945568269299, 40.85843578461678, 39.765832116526944, 39.65922209524339, 38.874657846266224, 39.549952706983014, 38.862816210716005, 40.5287213479319, 41.53484852083268, 41.671017523734804, 39.930669723018525, 41.545183966236735, 40.95638129018968, 40.998789956492764, 40.07836264948691, 39.78123134182346, 41.615535597647394, 40.48974475552959, 43.76076613703082, 43.27661229718117, 40.09724886186662, 41.711731726123446, 40.6302518998423, 40.25563416942474, 38.3923985112098, 40.19460601191367, 48.18137538048529, 54.46783258068947, 54.26122173186272, 56.094353199005134, 54.37115007831205, 54.62391545695644, 53.95890505083146, 50.22198846263271, 48.41078304475354, 52.767477266250125, 51.57324106462541, 53.76851320266724, 49.782608478300034, 51.52259934333063, 56.44588385858844, 55.85764208147603, 51.74319736419186, 51.54896159325877, 53.488538342137495, 52.13228471817509, 58.498350343396595, 56.61638144523867, 54.60762193126064, 55.17327870092085, 52.064553230039536, 43.14249077150899, 40.235492798589895, 42.65722690090057, 40.63928511834914, 41.630562197777536, 43.35564413378316, 44.21298403893748, 47.79623393089541, 49.66064630016204, 48.676888404353974, 44.865835097528276, 42.94525830976425, 41.32096559770646, 42.59150758866341, 42.586028037532685, 42.02803557918918, 42.25707061829106, 41.644412086855986, 43.76809312451271, 41.457346408597886, 43.2068137199648, 42.84606549047655, 40.11676265347389, 38.727466983179895, 41.4233551486846, 38.84276505439512, 39.90930065031975, 40.912713543061294, 41.309818221676736, 45.85014212516047, 45.32472102872787, 44.81544440792453, 44.6217107003735, 43.62450299724456, 45.85527258534586, 42.47754704567694, 49.12562716391779, 53.42005768129903, 59.089926135155466, 56.80918162868869, 57.426503858258656, 53.49378647342805, 55.91904678652364, 42.65892920955535, 13.849668445125705, 3.8657850796176545, 7.878552646406236, 10.729530838228042, 8.951489060155808, 7.679241818766441, 1.5954723617722912, 0.22242605986614383, 7.51698709303333, 57.633310825594016, 59.919448591047725, 50.148118465177475, 37.037800127460116, 53.7798959209073, 66.00466466719105, 37.80496081998272, 1.4262676863901078, 0.20017259994581824, 0.12550989301094126, 0.16677383243316607, 0.23826460594371443, 0.23491182214310094, 0.1299678582337595, 0.1690010492119097, 0.09370417469331334, 0.18782959049267156, 0.16111618118180385, 0.19185484627321844, 0.12892619316135684, 0.15301359096361747, 0.1802086397524803], [0.011850948306551624, 0.01319955129386677, 0.02363090324516018, 0.012841658955890567, 0.060503996322832765, 0.01600155809653863, 0.011520040458098296, 0.05745988083823074, 0.07729180577781893, 0.039898157870817574, 0.04900901172790797, 0.05371049714965686, 0.02770561766209862, 0.052693645665121656, 0.032752760040063056, 0.02386309683413035, 0.0642489520232043, 0.08172514127387155, 0.43760508118617925, 15.217513653539843, 49.0019077639426, 44.180502891540534, 34.374330351429606, 38.837395329629224, 38.06322928397886, 42.738102251483554, 53.71301950946931, 34.009640139918176, 1.347289169507642, 0.14845480090908467, 1.1267738861422385, 6.021799685493593, 2.886464119918885, 2.345465330346938, 4.156324844206534, 28.31854970224442, 53.049374088164306, 56.282548519872854, 51.27189320902671, 48.44253070892827, 46.32106188804873, 44.27220398379911, 41.23771329079905, 42.09570823177215, 42.86957225491924, 41.03523662013393, 39.85377165579027, 39.47532569208453, 39.113553723981305, 39.16134388216081, 40.43827933649863, 39.254841419958304, 40.15549213655534, 38.614200699713926, 36.531163261782744, 40.579594489066835, 37.536066655189764, 35.84091632596908, 36.04618180182673, 36.44497702198644, 39.19464088255359, 36.73763682765346, 36.95797597208331, 36.49910180799423, 36.9982861703442, 38.36877015329177, 37.052599230120265, 36.815770441485995, 36.30721945916453, 37.5008673052634, 37.07156388990341, 37.60750870550833, 37.89792491543678, 36.96784857780703, 37.87928581237793, 35.98662453313028, 48.61741350543115, 52.133406516044374, 52.135544207788286, 50.51303225178873, 51.29680418199109, 49.75356724954421, 51.86595970584501, 50.84422934439875, 50.93277292866861, 38.665317027799546, 46.384882773122484, 53.542255201647365, 45.935398763225926, 45.056262247024044, 49.13506046418221, 52.569177919818515, 49.16218757629395, 48.423189501608576, 47.410802225912775, 52.22964971296249, 50.39304302584741, 57.45050091897288, 59.773759995737386, 48.73458254721857, 51.04224628017795, 38.165775729763894, 34.92913392282302, 38.218170750525694, 38.033434960149954, 38.63485197867117, 39.72431775062315, 38.44232636113321, 41.68358087539673, 41.871278055252574, 41.627122279136415, 40.52826243062174, 39.37394419024068, 37.746611641299346, 37.88256883621216, 39.954949194385165, 37.875763523963194, 37.0071703387845, 38.403957736107614, 37.33218577600295, 37.388287436577585, 37.550752009114916, 38.900988717232984, 37.55427429752965, 37.98577424018614, 37.28494867201775, 38.317508697509766, 37.53116761484454, 37.1405230799029, 34.357181749036236, 35.22905795804916, 35.65735724664504, 36.66502198865337, 37.55951850645004, 39.89083805391866, 41.300832071611964, 42.818165671440866, 47.35484569303451, 47.772519280833585, 51.39356905414213, 53.147166621300485, 58.900609016418464, 53.827591942202666, 49.59844535396945, 28.435473595896077, 6.504766518069852, 1.026652139281073, 3.723438833990405, 1.8519420513222296, 1.9269257567582594, 2.919152907786831, 0.28295886492536915, 0.04995646713782222, 6.723203312966132, 42.651649290515536, 42.400582298155754, 38.317187063155636, 37.99337579358009, 47.42872745760026, 50.699097725652884, 15.447243932754764, 0.07251304889758749, 0.04693256105266271, 0.03179618818384986, 0.03470063817897632, 0.04733432437323275, 0.09516020140220081, 0.029441649507310604, 0.03216859884560108, 0.057740793788745526, 0.0982824846681568, 0.060549842854661334, 0.026866722656714342, 0.03798589515950411, 0.00643135792004966, 0.00774843734689057, 0.003965693880848948, 0.014708265699746629, 0.025894622198275985, 0.05075504485097143, 0.06833935592083201, 0.043729386562781955, 0.0833301567622731, 0.03115678821960765, 0.05580056886819582, 0.01412916930407406, 0.006618656841437183, 0.05105843865162423, 0.06991987957829429, 0.035116627752300233, 0.046208799486198736, 0.04023490330925392, 0.08275677059446612, 0.08076015394181013, 0.25056258474867193, 20.1763250366334, 55.16748143780617, 50.8260726928711, 35.10361663756832, 40.6989247568192, 46.6273009392523, 47.23908478213895, 60.7496339274991, 35.574861957180886, 1.2683872614176044, 0.13512525407056655, 1.1733185692179589, 5.775705768216041, 4.4654159488216525, 2.2308019476552166, 5.281580773092085, 31.42791451946382, 54.25184334478071, 59.26628766521331, 52.94801219817131, 49.92425703233289, 48.709746099287464, 45.95471643632459, 42.39525571946175, 44.72815205973964, 44.32447348871539, 42.509777161382864, 41.987391979463645, 40.67420597999327, 40.57799416203653, 41.04606236180952, 42.26169509272422, 41.86977578747658, 43.43499368236911, 40.1923349595839, 37.47192413576188, 41.5964493443889, 40.94526137075117, 37.90627171916347, 39.07624413890224, 39.21045980145855, 40.01411814843455, 37.77353871253229, 39.67549993145851, 37.176255872172696, 39.404401394628714, 39.30964085363573, 38.36797391214679, 38.558326536609286, 38.39603454835954, 39.75601834635581, 37.62086045357489, 39.0496700809848, 39.3234162176809, 38.47997719241727, 37.98903372979934, 38.53759288787842, 49.48846993907806, 53.520941042131, 53.19810644272835, 52.86157100431381, 53.23758509851272, 49.98406533272036, 52.2656649158847, 53.70138183716805, 50.51217717509116, 39.93385076522827, 54.450833028362645, 52.01745733138054, 47.41672892724314, 49.27069994711107, 51.121709577498905, 54.180762152518, 50.56566261476087, 49.735928350879306, 49.95058398092947, 53.90679636309224, 53.17363869759345, 58.1892950304093, 56.83614007888302, 51.477703894338305, 52.61975296082036, 40.10999656492665, 37.27203622941048, 40.63728470956126, 39.65723345356603, 39.86357758122106, 40.11864146878643, 39.75569671200168, 42.612005895183934, 43.6145087980455, 43.50840868488435, 42.47899047790035, 41.05984164822487, 39.97883642873457, 39.91313672834828, 41.0027515503668, 39.277924568422385, 38.936054706573486, 39.33665421701247, 39.42912017145465, 38.22758443893925, 38.73368001753284, 40.70552610581921, 39.588654733473255, 39.297893354969645, 39.94799090969948, 38.90151823720625, 39.27006021622689, 37.99675687666863, 36.595666639266476, 37.52347192456646, 38.912606777683386, 38.78495716279553, 39.80976658482706, 42.01949265695388, 42.85271390791863, 44.581153392791755, 48.53589096376973, 49.621116653565444, 54.35387596007317, 54.6008832993046, 59.20842093806113, 54.041980851081114, 50.240451059033795, 32.20565188315607, 8.46397865203119, 2.6970906171106526, 4.771846215571127, 4.5457794300971495, 5.289628005796864, 5.141017244708154, 0.10599288383438703, 0.04686331819562663, 7.293557611203964, 48.61364018532538, 48.862710691267445, 41.922394383338194, 40.819404279032064, 52.85602085051998, 57.26968749876946, 20.03861846462373, 0.15162649684615676, 0.007815023794049218, 0.027797530976033984, 0.041116475157680056, 0.07557459671290652, 0.09884500004831823, 0.0820132056551595, 0.11129193698927281, 0.047394347362100124, 0.03767946382023154, 0.01180101756847674, 0.018704567187195344, 0.07179514790374426, 0.049641815675122124, 0.10359575641491722, 0.1047542805392896, 0.09382451178445932, 0.09906308229772315, 0.09798256890668024, 0.19439770659852415, 0.09383197348084181, 0.23959571435566873, 0.11239532576573473, 0.18414121421594776, 0.12464881784492925, 0.1536841170802232, 0.18046068267956858, 0.12451048534844192, 0.07413641219177554, 0.13697278235227833, 0.10035092972459332, 0.1488670174993815, 0.21896957840409972, 0.5626478214417735, 23.82446465953704, 62.57317912194037, 56.507606275620006, 47.27871248798986, 50.81632168062272, 51.07051872438001, 52.63631320768788, 64.65724029848653, 40.13358177677278, 2.0559175576894515, 0.3169407479224667, 3.069596641486691, 12.244799310161222, 8.897587849247842, 6.113095793031878, 6.284295483942955, 34.05592803032168, 54.16453530711513, 61.911228164549804, 54.554913120885054, 53.72750482251568, 51.31480393871185, 50.8653473854065, 45.692404008680775, 46.88518501097157, 46.85405708128407, 44.58557390397595, 44.0081343343181, 43.82712087323589, 43.016382648098855, 42.576861458439986, 43.70570782692202, 44.81405588888353, 45.92870327734178, 43.425497624181936, 40.22349426823278, 43.56560860910724, 41.423688550149244, 39.46657880660027, 40.50112355139948, 40.937334260632916, 41.346939532987534, 39.95619258572979, 40.607961070153024, 39.3993454594766, 41.25921572408369, 42.397628753416, 41.271539811165106, 40.4436686731154, 39.721740753419944, 41.2878764829328, 39.70043051627375, 41.81530583289362, 41.92960762208508, 41.63447672320951, 41.414929897554465, 39.28556534551805, 52.135097057588645, 57.00941078124508, 55.95790963019095, 53.52847983760219, 55.76154401225429, 53.8516164595081, 53.59921978365991, 54.97242589150706, 53.70596708789949, 46.165057459185206, 52.23583136835406, 54.64891272206461, 49.053326114531494, 50.06849042830929, 54.68980735348117, 56.130062457053896, 52.76238995213663, 52.6220279355203, 52.42943563768941, 56.44434628948089, 55.54828082361529, 59.17376287521855, 57.453336792607466, 53.78768182569935, 55.79524109440466, 42.804456987688624, 38.396556223592455, 42.70894727399273, 42.789646117917954, 42.509137815044774, 43.025258971798806, 42.00141445282967, 44.80009225107009, 46.761183200343964, 45.00172953451834, 44.66898702806042, 43.31401601914437, 41.41763633297336, 40.76831148516747, 43.99843039051179, 40.93425912241782, 40.66936185283046, 41.218803544198316, 40.59609197801159, 41.04527788777506, 40.55696633554275, 42.27457223399993, 42.162306154927904, 41.86613975032684, 42.08531787318569, 41.18716962875859, 41.896008599189024, 40.93947979711717, 39.36041593551636, 39.64113604637885, 39.31915652367377, 40.699434664941606, 42.57272335790819, 45.14763386018815, 46.41668142810945, 47.26469001462383, 51.83172525898103, 52.47206003435197, 55.87874835537326, 58.72794628143311, 61.64590335661366, 53.68596692239085, 49.01631070721535, 34.32590084691202, 9.139318620004962, 3.8897527225555915, 9.375612985703254, 10.068452608200813, 10.229482573847617, 10.44667499680673, 1.0806791724697238, 0.15153707906363473, 8.498859309381055, 52.17252039140271, 53.975641804356734, 50.48480295365857, 50.20227463014665, 62.041282192353286, 64.72087683216219, 24.885838416314897, 0.37937847657069085, 0.12122149368928326, 0.09578782659504684, 0.10715272562998919, 0.18315637754576822, 0.2130894245760095, 0.24967945391131988, 0.20994710044995432, 0.19319292608528368, 0.18814207775698555, 0.12268513531213808, 0.08522708239334245, 0.10865274110748883, 0.09438158027947911, 0.16443583934057146], [0.05587681759929946, 0.03871764319257871, 0.053324178161640326, 0.058019676606260964, 0.029191351345469876, 0.018265861191696698, 0.07139222395996894, 0.041969058239051414, 0.026646914794259978, 0.03896571012333997, 0.057489536101779634, 0.04995516478835095, 0.031544738974902904, 0.042750004438623306, 0.03451766573914117, 0.05925368720425233, 0.04133952548727393, 0.05764436630171634, 0.13575883942746347, 8.402956378075386, 42.67594445136286, 49.204153014767556, 37.98129097107918, 26.049846872206658, 28.598495144997877, 39.6826700241335, 40.851669696069536, 44.321331670207364, 4.578522885999372, 0.03669332097014112, 1.0000862325391462, 4.101209414582099, 5.083680037529239, 3.969027255811999, 2.932380610896695, 19.009139460902063, 48.49230166404478, 54.24166087181338, 51.45400493375717, 50.2525084249435, 48.395736832772535, 46.732620500749164, 44.027306879720385, 41.63934830696353, 44.681671973197695, 42.03692759236982, 41.249754967228064, 41.89147041689965, 41.21694826310681, 43.543227564904, 44.3339930811236, 41.49328316411665, 42.30134241042599, 42.20040805878178, 43.08333750694029, 41.59901849685177, 41.47797807570427, 38.058216494898645, 38.29117782654301, 35.71632223744547, 37.27239708746634, 36.55516424486714, 36.44210584702031, 36.694055372668856, 36.42488271959367, 37.94029828040831, 38.06357053018386, 38.54063664713214, 38.91088877954791, 36.79408365680326, 37.71657805288992, 36.183837383024155, 38.35448880349436, 36.5945722979884, 35.083698841833304, 34.84448525213426, 44.242158628279164, 50.477950572967536, 50.10880062657018, 50.990106213477354, 50.50110432409471, 48.95144254930558, 49.583336384065696, 51.90798790224137, 50.575637202109064, 47.58925830164264, 37.08081676113991, 51.71872961905695, 50.98301849057598, 44.47733217670072, 52.141890602727095, 51.47373837809409, 49.441483866783884, 47.448362842682876, 49.1706951971977, 46.71053363430885, 51.91936277574109, 42.26349153826314, 56.03533329502229, 54.36838480734057, 47.963919178132095, 41.983328403965125, 33.5996740095077, 37.02285981947376, 37.20514805086198, 36.992418304566414, 36.63299583619641, 38.91959251896028, 36.5216201351535, 39.456988611528956, 39.69446851361183, 38.7420738897016, 36.33956332360545, 35.95351188413559, 38.35891323704874, 37.02903755249516, 37.95942375736852, 36.71416536454232, 37.59692615078342, 39.84155347270351, 41.7076289269232, 42.66432639091246, 41.789841805734945, 40.83112039873677, 39.0798487970906, 38.23280119126843, 36.790561368388516, 36.72328095282278, 36.141868022180375, 36.14920285440261, 36.49177482051235, 36.72086869516681, 36.036305273732836, 38.81750891285558, 40.776740658667784, 43.662400937849476, 49.02887798124745, 51.025776247824396, 49.16575693315076, 52.291858503895426, 54.24474777713899, 56.30403918604697, 51.97100077905963, 50.127027880760934, 23.8355218210528, 4.755418348696924, 1.8793062216812566, 2.747796812365132, 2.3517565669551974, 6.988511450829045, 3.3845362451768692, 0.3890221139356014, 0.07665014585420009, 10.154704547697499, 39.18401910412697, 41.580147973952755, 35.96306285550518, 31.069833501692745, 51.147616832487046, 42.343511812148556, 8.496891260147095, 0.0635109412213487, 0.0047409542716078225, 0.037280508211904, 0.05096081989787279, 0.07000245619565248, 0.0753893566528155, 0.02079735660264569, 0.037341197697265495, 0.04114443736691629, 0.047235560318034504, 0.04547980936965154, 0.053515320929187926, 0.031008783863076282, 0.036323997642724745, 0.03772374753269457, 0.01774458049405967, 0.030559911880822434, 0.01018005308710159, 0.03979654013810139, 0.03796455194993365, 0.01749625500862397, 0.1291017039048095, 0.062023937747242956, 0.019308008899491642, 0.08602952118963005, 0.04654405105318274, 0.00907775694354167, 0.05214961981701274, 0.04076085714322906, 0.1000173750423616, 0.026762630460002733, 0.0878230172900423, 0.03004484224103151, 0.13636654633427822, 12.08054711741786, 51.701020117728945, 55.10083644620834, 42.992330674202215, 34.894522928422504, 41.25342238333918, 47.543766652384114, 49.17648461557204, 44.94653001908333, 3.71658522755869, 0.06598532094710297, 0.34337951471247985, 5.300927373670763, 6.303937733173371, 4.211838149255322, 3.6957802407203184, 21.742902032790646, 50.178850235477576, 56.214263977543006, 53.194890099187056, 52.9548998801939, 49.44549645147016, 46.2221710912643, 46.79579419474448, 42.716619430049775, 45.120224337424006, 44.346234798431404, 44.82633682989305, 44.241813459704005, 42.0534368484251, 44.340668955156886, 45.76528949122275, 43.800389920511556, 44.0221607300543, 43.80954865486392, 44.89927330324727, 43.15868231558031, 43.577254126148844, 40.17288784826956, 38.539699200660955, 37.87100568894417, 39.461769980769006, 39.01109749271024, 37.31968910463395, 37.9135359487226, 39.75827763157506, 38.66912957160704, 40.780482599812174, 39.74023472878241, 41.755007236234604, 39.62641931349231, 39.16219111411802, 37.74331292798443, 38.19167906238187, 37.71435014663204, 37.973367783331106, 36.02638559956705, 45.994477502761356, 51.99286799277029, 52.231461847982104, 51.81181923035653, 51.81701637083485, 50.8984443449205, 52.96696116847377, 53.627527529193515, 54.72024494601835, 48.46142084367814, 40.31764291947888, 54.872683940395234, 49.966712767078036, 47.71242464742353, 53.80455193981048, 52.59391630849531, 50.94454788392591, 50.05517790394445, 49.41935385427168, 49.988038693704915, 51.66383997086556, 46.429562491755334, 58.6647843545483, 54.125578326563684, 49.24067812581217, 42.779106709264944, 34.35043527233985, 38.881820094200876, 39.05626750761463, 38.62809765723444, 38.55564363541142, 39.29974471369098, 38.23157741177467, 41.06903960627895, 41.89850714898879, 40.509317382689446, 39.142524350074034, 38.47152448469593, 39.462338724443995, 39.90986154925439, 40.579971036603375, 38.86724456664055, 39.9064451648343, 41.19830523767779, 41.85273308907786, 42.32126020616101, 42.89109037768456, 42.139685846144154, 40.248013004179924, 39.58190825677688, 39.02632805608934, 37.871892144603116, 38.433967790296, 36.448813100014966, 37.877583503723145, 38.359317241176484, 37.676479662618334, 40.7973958599952, 42.9495023142907, 44.96527110376666, 49.60427791841569, 50.4923495938701, 52.283625448903734, 54.00428295135499, 55.33689645028884, 56.17004709859049, 54.02638550727598, 48.490493451395345, 26.82926497151775, 5.778249915569059, 2.567610726241143, 4.373140229332832, 5.689518057530926, 9.216549108105323, 3.438223441762309, 0.0898906349715206, 0.1796293547076564, 10.00336773933903, 43.019104772998446, 46.1052256245767, 37.900470533678615, 38.363149396834835, 55.27149092766547, 50.1468397725013, 11.26260644005191, 0.0256088235220241, 0.03127040480443787, 0.02782639142336144, 0.007083404080701933, 0.029127350445055676, 0.03943324975308873, 0.029600729580007257, 0.08416751384614937, 0.00506986981265307, 0.10739548357143518, 0.039360873596442324, 0.0267679222123397, 0.047611977619629715, 0.03306999321906798, 0.03438076965751187, 0.14301939176455622, 0.0860352591881829, 0.12359601385410755, 0.13556649007143515, 0.1642518863081932, 0.09136379906727422, 0.4109317382737514, 0.135022062027166, 0.10631145383681982, 0.16350239184835266, 0.13633528994696756, 0.1190696063361341, 0.18125966641931765, 0.12044920045281611, 0.2983757715311743, 0.12745028647083428, 0.17619006425863312, 0.11659731036953389, 0.23955469800820275, 14.019904213566935, 56.995262792033536, 63.32037102791571, 51.44571696558307, 37.37002488105528, 41.25474422208725, 51.06206993902884, 52.70558618730115, 51.79979716577838, 6.172429486628502, 0.2375708826847615, 2.317206369292352, 10.670746276455542, 14.307747348662346, 7.7555711423197105, 3.803731957750936, 24.761954276792466, 51.269900644979174, 57.012964448621204, 55.02740183184224, 54.83262869619555, 52.14022359540386, 49.46364525825747, 50.11396246571695, 46.22172786343483, 49.456063316714385, 46.656369624599336, 46.216456197923236, 46.87794431563347, 45.246006904109834, 47.584484777142926, 48.36630728936965, 46.11365087570683, 47.42382841725504, 46.72946691513062, 47.61775824331468, 46.32360358392039, 47.51011663867582, 42.28056561562323, 41.42186857038929, 39.04513189869542, 41.4964916629176, 40.8017732251075, 39.671393209888095, 41.484626493146344, 41.97807635030439, 42.001798845106556, 41.81266215539748, 42.98267379883797, 43.0996584892273, 40.95250991082961, 41.63243316834973, 39.95460794818017, 40.51243174460627, 39.475768919914, 38.65792336002473, 37.373096096900206, 47.355947879052934, 54.516956344727554, 54.74532065852996, 55.24752916828279, 54.53430891036988, 53.28482220249792, 54.545248400780466, 55.4232866533341, 55.99092029756116, 52.888392171552105, 44.62118510277041, 53.83824509959067, 50.113244671975416, 50.210566520690925, 55.71901375247587, 55.70213971599456, 51.78408415086808, 51.37162339302802, 51.85278838680637, 52.394907013062515, 53.905592195449344, 51.40126474442021, 59.22153734391736, 55.08535877350838, 51.21566603260656, 45.0397059225267, 37.07901247086064, 40.9224880895307, 41.468521241218816, 40.92758717075471, 40.90175836317001, 41.453796663591945, 39.49567494853851, 43.2314383599066, 45.198416786809126, 42.04407807319395, 40.70855025322207, 38.66785872367121, 41.176139923834036, 40.72456921300581, 41.975005134459465, 40.41071684129777, 43.03894412133002, 43.74666913863152, 44.932766422148674, 46.33239361547655, 45.565181932141705, 46.46829589720696, 42.36009951560728, 42.25236377408428, 40.31301452267555, 40.22212536104264, 40.65658277080905, 39.64188129671159, 40.017989527794626, 41.089110374450684, 39.49699286491641, 43.27629066282704, 44.548334921559984, 47.702775616799634, 55.015571963402536, 55.90715023779101, 54.22618712148359, 56.85164520817419, 57.916015655763694, 59.456134303923584, 54.34223436540174, 52.634944300497736, 29.885750355259066, 7.513536387874235, 4.912192052410496, 9.666614609379923, 8.58129870507025, 14.584847111855785, 8.46505436205095, 1.793124884847672, 0.34808819753027737, 13.049151916657726, 49.90819492647725, 53.45365670419509, 47.97843587013983, 42.94585451003044, 63.44196450325751, 56.167948630548295, 12.978025617138034, 0.15940187559012445, 0.19717607767351214, 0.15660593045815346, 0.21442799468434628, 0.11788891162723304, 0.16481018054389185, 0.07455465789403647, 0.1396884414697847, 0.1583449040809947, 0.15410528157747563, 0.17137869501546507, 0.12054483886928329, 0.1440764705259954, 0.13943345676506722, 0.1599377847366756], [0.06514555834714444, 0.039181474956773946, 0.01257735096113456, 0.07651676228570362, 0.0652252314912696, 0.02846813178621233, 0.028740818867640152, 0.014039526483224285, 0.014173954804127496, 0.04528579760282751, 0.08126486032720535, 0.008974893360338625, 0.050379899255330526, 0.048152253467349276, 0.01756550361131949, 0.061853743653984807, 0.034624347313036846, 0.07307539573840557, 0.054887905341362765, 3.3210132150880756, 29.173371445748117, 49.760690273777136, 38.002106989583666, 23.13756350548037, 32.04675862866063, 39.60428537860994, 48.31535177846109, 50.728974419255415, 7.750849098928514, 0.030634402440139846, 0.26878243853007594, 3.1067307005005502, 2.8263317336959224, 1.1478512325594503, 1.948693195177663, 13.036562088997135, 40.27145701069986, 56.07915009221723, 55.43077053562288, 51.593174549841116, 51.30351535735592, 48.350311863806944, 45.68264122932188, 43.49302514906853, 44.13081430619763, 44.624209250173266, 44.18072254427018, 44.54274554406443, 48.46020490892472, 44.32007651175223, 46.092266113527366, 46.465479635423236, 46.70608174416327, 47.50783381923553, 47.705858599755075, 47.72878093104209, 46.95211633559197, 46.04210684376378, 41.99039651501564, 37.11915400720412, 37.29242863193635, 37.01324609018142, 36.60490774339245, 37.27194993726669, 39.3270012640184, 39.89012026017712, 39.64582327873477, 39.71540220322148, 38.69212250555716, 36.91604191257108, 36.44722454009518, 35.452527153876524, 39.060766466202274, 38.26435273693454, 34.706864972268384, 36.90602810152116, 40.227095004050966, 42.32555127912953, 43.53045632762294, 46.03185769050352, 45.59097543839486, 46.83221732416461, 48.21660610937303, 51.47248321963895, 47.70085757778537, 48.69251120475031, 50.34347603397985, 40.44374712051884, 54.66700269329933, 45.882168277617424, 51.19335559106643, 53.86275599079748, 50.39485123849685, 47.21416596443423, 50.55757076509538, 48.91780822507797, 52.284409922938195, 48.703646813669515, 41.1285537289035, 53.49956412469187, 49.118092290816776, 43.82686591917469, 36.02664839836859, 35.33528358705583, 35.968577707967455, 36.35940267193702, 38.19853144307291, 37.47637994827763, 36.797821675577474, 42.358240312145604, 36.55204596058015, 38.277975128543, 39.04639882426108, 38.20097507969026, 38.355677281656575, 37.322015070146136, 38.37140990841774, 38.540719016905754, 40.54057867296281, 48.03126235162058, 51.55752804971511, 47.27877916828279, 46.26900419112175, 49.617531607227946, 46.416634359667384, 45.703547462340325, 43.94692574777911, 41.702502389107984, 38.085276926717455, 35.38503885269165, 35.23923258627615, 35.93402162674935, 34.86954919753536, 39.720207106682565, 43.51701828741258, 47.045825681378766, 48.09823289994271, 51.67424601893271, 52.19146936170517, 54.47692071237872, 53.40532133656164, 55.68497542412051, 53.09163762677101, 47.689584685910134, 23.490998475782334, 3.9539410846848644, 1.5011750281818452, 3.2991898828937165, 3.4532260173751466, 3.1088098018400134, 2.7168417121133497, 0.17650127981699285, 0.13447718965190072, 13.786124087149098, 45.264312605704035, 38.22913769752749, 28.45766636633104, 34.00257202886766, 55.13638880945022, 29.38831929237612, 4.643970083805823, 0.0257751431256052, 0.011593061086210993, 0.04945668669778013, 0.05390460467747143, 0.12647294980143348, 0.021095385872608712, 0.09500060230493547, 0.06378975892139059, 0.03877274406653258, 0.057042554441478946, 0.02950118219990644, 0.05363129514960512, 0.06031300677287002, 0.03999654271249329, 0.05796182547665893, 0.07672997987678937, 0.01623033876380613, 0.04076843375280019, 0.03622659722403173, 0.041733049532218326, 0.04607286101447479, 0.03510902816009137, 0.04061251187757139, 0.05282520211391872, 0.08424131875677456, 0.03685192798354453, 0.04038171639906303, 0.03503410859153636, 0.08522332856251348, 0.016917249585892406, 0.04289695542425879, 0.05627812126711492, 0.04546248046080432, 0.05236560681594476, 4.981491508022432, 38.83049195812595, 54.773789221240634, 45.07129669189454, 25.76633599496657, 33.14523212371334, 47.1497606462048, 50.31756093425136, 54.16735156889885, 8.238048168920702, 0.04002270844554709, 0.825125601503157, 4.400119762266836, 6.066460282571855, 2.650596066828697, 3.0006357354502526, 16.201352938528984, 41.499653093276486, 58.37378371146418, 56.43767826018795, 53.942191831527225, 51.11821474567537, 50.18411405624882, 46.143986486619525, 45.68003677552747, 45.56354238140968, 46.58530019944715, 45.47124901125508, 46.36003848045103, 48.50332352422899, 47.748412393754535, 48.20472525012109, 49.07021191812331, 47.98573147866034, 49.283985014884706, 49.13238148535452, 49.262788526473514, 48.350111822928156, 47.80954645526025, 43.123969339555316, 38.931096830675685, 37.30286605896489, 39.44494693509994, 38.281885731604795, 38.01839659290929, 41.397483195028, 41.428964138031006, 41.65768930988927, 39.9462454549728, 40.79588182510869, 38.26622370750674, 38.542374257118475, 36.35223257926203, 40.221336964638006, 40.07529535601216, 35.41281315588182, 38.54650059053975, 40.06745846040788, 44.72810891366775, 45.65714582320183, 47.012163900559955, 47.52055798807452, 50.353125064603745, 48.96059343891759, 53.932174098107126, 50.11206011618338, 52.84912924612723, 50.096527530301, 43.601698337062714, 55.69606788696782, 47.90691537241782, 53.17083420292024, 53.16579003487864, 53.02584771187075, 48.513686426224254, 51.91094144698113, 51.51203247808641, 54.641197419935665, 48.47516875113211, 45.25908800863451, 56.42988058828539, 50.12501962723271, 44.43390761652301, 36.99694864211544, 37.75498982398741, 37.54389962842388, 39.71238982292914, 39.72078369509789, 38.70465840062788, 38.98238574304889, 43.530954468634825, 40.24227457661783, 39.41373663563883, 40.366158716140255, 39.911646227682795, 38.65791943765456, 38.632369118352095, 40.98924290749335, 39.541162675426854, 41.22839373926963, 49.92765772727228, 54.187438026551284, 49.75948610613423, 47.83489281131376, 49.88930871409755, 47.19757433860533, 46.99652148831276, 45.72279061040571, 41.938668297183135, 38.281634699913766, 37.73455819775982, 36.06901784096995, 37.738288371793686, 36.9934694997726, 41.92485763180641, 45.07937285207933, 49.87180709838868, 48.99816974516838, 51.86122148267685, 53.68682984382876, 56.17140423867011, 54.95343377513271, 57.11645618561776, 53.0923044297003, 50.21770915677471, 25.74530032373244, 4.89378878185826, 1.184835383488286, 3.3847492789068534, 4.615463768282245, 6.033971780730832, 4.895571499101577, 0.16790456288764555, 0.1318113109277141, 15.360666436533775, 50.21127646969211, 46.481675101864724, 36.23165892016503, 34.632288948182136, 59.76142806391562, 37.71581319070632, 6.464686268760312, 0.021723918879645008, 0.025571455668297507, 0.050671545097664486, 0.008415106210797545, 0.03948555440611897, 0.02072305373486973, 0.034613116464066895, 0.021258721563724742, 0.04469605545783716, 0.03444365781521605, 0.05474357437642832, 0.04496032131775733, 0.050932160548625455, 0.08048651499613639, 0.043200923790854794, 0.11892973400291898, 0.1263562439670486, 0.12071995124701532, 0.15606323377259318, 0.1544398474957674, 0.11499470805809384, 0.07180785730240807, 0.1851301571174014, 0.17308417527425676, 0.15700634929441637, 0.144832844455396, 0.1589412269212546, 0.13965231276327564, 0.15658149225336893, 0.13127589207743445, 0.13567323676280438, 0.17607250040577305, 0.1544198066356682, 0.17511363411622663, 5.87807668793586, 42.35222339630127, 62.28172740628643, 49.69468070614723, 34.36020981880927, 44.11485418196648, 52.18102801230646, 58.73785026611821, 58.96242164796399, 10.284059413017767, 0.18150809341140334, 1.9444711314093683, 11.573087534596844, 7.220836868209224, 2.900877114265196, 4.9376737302349465, 16.71119732241477, 44.29641285250264, 58.42537464634065, 61.433416797268784, 54.83357790977725, 55.87237058147308, 52.719702797551314, 47.66117495875205, 46.3980148684594, 48.9311364389235, 48.66960848531416, 48.651373386383064, 48.46422141598117, 53.81189461677305, 49.44138580752958, 50.87952675357942, 50.802926786484264, 51.45023553602157, 52.75951485480032, 53.133187294006355, 51.556543534801854, 50.283593208559104, 50.82151489873087, 46.33293490256033, 40.3560507682062, 39.317344388654156, 40.31583862919962, 39.76683624329106, 40.49081948495681, 44.74151165254655, 43.68047521960351, 44.51368470345774, 42.77732987557688, 43.91556247588127, 39.96968946149273, 40.018362152961, 38.56717540371803, 43.40435997132332, 42.41626393410468, 38.877705527890114, 41.016440622268185, 41.744534507874526, 45.25778185936713, 46.76607831831902, 48.34850365115751, 48.05194893190938, 52.18740970857682, 52.997892979652654, 57.362361338830766, 52.460908735952074, 54.449691618642504, 53.31616194017472, 47.970532294242616, 52.77417275213426, 49.50872113627773, 56.2708245554278, 56.614220219273726, 55.561546279538064, 51.498774866903986, 53.58262423546084, 54.67684784243184, 56.43644663595385, 50.30035741867558, 48.056392977314616, 56.735311631233465, 53.54819759245842, 48.187929661043235, 39.661034230263006, 40.00532811687839, 39.50219785013507, 41.32311897893106, 41.62913053266464, 40.231625341599994, 39.704749045833466, 46.80096780100177, 41.38056209010463, 42.333831402563284, 41.88173509413197, 41.80526456525249, 40.79354801485616, 40.9385698072372, 43.07854437058972, 41.862652763243645, 44.57003739572341, 54.34478390601374, 56.82273734000422, 51.44182597437213, 49.93295292700491, 54.1437114438703, 50.53073783074656, 49.61028698951968, 49.35250489942489, 46.592976277874364, 41.98652905802573, 39.70894990428802, 37.95146919065906, 39.96968161675238, 37.38415718078613, 44.087225006472686, 47.5267239539854, 50.827151344668486, 51.84727745671427, 55.592689898706254, 58.0908945298964, 58.74902509873914, 57.34266711819557, 58.36793153516708, 55.77135386005525, 51.940198406096435, 28.22830577050486, 6.507004230253159, 4.3905364313433255, 7.970597436351161, 12.175289027152523, 10.944007019842825, 8.099415427254092, 0.5085171212352092, 0.42758318024777603, 17.17248962771508, 56.83683041603335, 49.97806018398654, 40.32619368645453, 45.53722327755344, 66.89199893705307, 43.8671447384742, 8.491976530321184, 0.16545423066183446, 0.09430994339767965, 0.13586117345238888, 0.16936150890204216, 0.20110250811182684, 0.19320788012156564, 0.24255152671567856, 0.13771610214344918, 0.11012316260847355, 0.12478505892138328, 0.16301083919261733, 0.10784385185087882, 0.17394576371917803, 0.13159211785081895, 0.11336408991126284], [0.015166280941376764, 0.03261191860562371, 0.013150487192756227, 0.022876488585625927, 0.018434138149924336, 0.06312017892337134, 0.05511030832666063, 0.019806329942037983, 0.024615724593581214, 0.02586279699068156, 0.05806095725406082, 0.021971079911435806, 0.02997243352564833, 0.060368138290340864, 0.08467443422564576, 0.03452557176651974, 0.01578835870004109, 0.014905960434266638, 0.023601004748695323, 0.955173745751381, 16.097484653995885, 45.38552168876895, 40.48365723702216, 30.01932667147729, 27.877989084489887, 37.31630802154541, 44.01763431487545, 47.62387321841332, 16.098388760320603, 0.1980682483483707, 0.21445111521790106, 3.7243615715734424, 6.8978914618492135, 4.285862590036085, 1.4356905678587577, 10.01003969100214, 30.391047731522594, 49.78589150213426, 55.92337708319388, 54.498517282547496, 52.00069704363423, 51.83048579000658, 50.76198508662563, 46.681617921398534, 49.381079366130216, 47.51685919300203, 47.94955545856107, 49.3078447926429, 49.05696999642157, 48.62931397653396, 46.89173144678916, 48.50468850904896, 47.95158724631033, 48.14687029007943, 49.1313499019992, 48.9299322712806, 48.77708927277596, 48.50606526097944, 45.87771638747185, 37.860411367108746, 37.21251426204559, 36.79153019382108, 37.15841301025883, 37.03417193505072, 40.09422471446376, 39.46923032883675, 39.82554235766011, 37.75627636140393, 37.279716230207875, 36.33178918592392, 36.56044767748925, 35.150230084696126, 38.45948673063709, 39.509411088881954, 35.64609219951015, 35.90203469799411, 38.24732572801652, 37.94436970064717, 38.98104429244995, 38.60794844165925, 40.964237797644834, 39.78374165873374, 41.18204701331354, 44.5513355347418, 48.26417269245271, 49.804232505060014, 53.74725787870346, 45.42248218290268, 45.186869329021825, 48.52858751050888, 48.04906598983273, 52.696274480512066, 51.9130987505759, 50.75556416665354, 48.78390242976528, 53.09169253995342, 48.99259213478335, 49.89080705950337, 42.86395542083248, 48.827750605921594, 52.43671163435906, 41.97896672833351, 35.72522994010679, 36.50255349374587, 37.13373345713462, 36.23453009513117, 37.62905820723503, 38.3514371995003, 38.585324210505334, 37.703846039310584, 37.81445295579972, 37.00235366821289, 37.40423579369822, 38.10607333337107, 36.406867273392216, 37.28974573073849, 38.117169718588556, 39.27852861342892, 47.734986120654696, 50.800663578894834, 52.255866835194254, 51.87953502901139, 51.78344088215982, 50.77640371937906, 49.910913129006666, 51.06310152238416, 48.91252871482603, 47.73618636592742, 46.10173079275316, 41.59768096862301, 36.18536318502119, 37.66353976341986, 36.90335696743381, 38.389907806150376, 43.3342868281949, 49.947069537255075, 51.638995678194114, 51.86017813221101, 54.87691617781117, 53.14279317855836, 52.612841744576734, 51.39367495813678, 55.48870786543816, 45.167594801995065, 24.191153318651264, 3.3583877644231244, 1.415320106091038, 1.9877847620556433, 4.574398513763182, 8.874408602714539, 2.1276448378639836, 0.2469726048049427, 0.16283410270848583, 16.321574564903013, 42.28637072347826, 33.71443079363915, 30.843877523176133, 40.86909678674514, 50.515856358312796, 27.59196004559917, 1.4274884015321734, 0.026647253788166472, 0.026316022267565135, 0.016173977675216816, 0.04861636102319725, 0.046726858784114166, 0.03941399796355156, 0.046129861786480875, 0.06797570930493456, 0.09798964755910058, 0.012121068993433109, 0.027186081729709145, 0.06164933224358867, 0.007922559077175515, 0.03831658467289902, 0.043318365069646994, 0.028318036009647676, 0.021408279163522587, 0.02670906559233704, 0.05977305268207866, 0.024365633275480043, 0.04603354538220071, 0.01194785938658301, 0.016669443125025402, 0.09739770674176755, 0.03528470744288737, 0.052305480405207605, 0.025802578649393497, 0.03445384295416936, 0.06238719365829903, 0.10018157832805188, 0.08508054509518609, 0.05807464724526771, 0.014683017356982155, 0.052646052452825734, 1.480357906510753, 21.7372126348557, 54.344254386040475, 46.65200794896772, 32.69905663305713, 33.86397507882888, 41.522489132419715, 49.44958356118972, 52.570888073213645, 15.93202535183199, 0.201173693001751, 0.5570005889861815, 3.4133556148698254, 8.085110052939385, 2.5825223518956095, 2.815799189190711, 11.910648672811448, 34.10360836213635, 50.20165097328925, 56.737982765320815, 54.49067254220286, 55.06196968017086, 52.6836601380379, 51.43321244947372, 48.41626259588426, 50.24887238779376, 49.22949544845089, 51.70713901519776, 50.06128895667292, 51.22302047667965, 50.2453814783404, 49.50444183041973, 50.08569394388507, 50.2501706923208, 49.96714030542682, 50.02338709369783, 49.88190327921222, 48.85563865784676, 50.58670613073534, 48.10523433070029, 40.97798178272863, 39.39888261979626, 38.99539624491046, 38.690902648433564, 37.253346135539395, 41.49123176451653, 41.5369430665047, 42.171880660518525, 38.80595361032794, 40.36423675475582, 37.69718585475799, 38.342749149568625, 36.95673258073869, 39.74116433051325, 40.88079721696916, 39.27303729518768, 37.96154575963175, 39.91272095711001, 39.39881201713316, 39.82596597363872, 39.83890195046702, 42.34017779750209, 42.7108496235263, 45.19300391597133, 46.60075433792607, 51.5147271463948, 51.2925797893155, 54.411930960993615, 46.52593512688914, 48.28408264344739, 48.918741749178984, 50.16725963161838, 55.2981238211355, 52.84690918460969, 52.712003184903054, 50.382197672320956, 53.994932020864184, 50.891764548517045, 50.42288049574822, 45.02259262146489, 51.80350772796139, 53.91235436162641, 44.55194350211851, 36.4046589789852, 38.21250684799687, 39.617107606703236, 37.87671273754489, 39.07886035980717, 39.621775227208296, 41.97044734031924, 39.72062287792083, 41.057013619330625, 39.08938800134967, 39.45559617011778, 38.89509731723417, 39.287393170018355, 39.02953263252012, 38.320430863288145, 40.64180327999977, 50.044073673986624, 53.272337298239435, 54.16580615505096, 54.45861108841435, 53.69061885341522, 51.68067086127497, 51.69313615368259, 52.57210400796706, 50.70981756333382, 49.90524922647784, 46.954367776070875, 42.945301455836145, 39.19667659267303, 39.296273416088475, 40.230358416034335, 39.85096716111706, 46.316194226664884, 52.390557104541415, 53.890761713827814, 56.29443330149497, 55.4667269029925, 56.85357501429897, 53.99894460555046, 51.85784432195848, 57.16368936723279, 47.47450936225153, 25.812892567726877, 4.020891776007991, 3.1804249267424307, 5.463104142296699, 10.165871535578082, 6.474899630392752, 4.077225346719065, 0.13484010082339087, 0.27831162235909895, 17.231256538821807, 47.8798706300797, 38.699100402093705, 33.178529124106134, 44.95469639378209, 59.023124248750754, 34.37786440695486, 2.339683021268537, 0.007728080954327579, 0.029727417540045518, 0.03184530016545567, 0.04664342414828078, 0.0319494670557399, 0.05212809657678009, 0.03541673503575787, 0.012111884556830892, 0.025843472422791586, 0.019871140980432113, 0.034941484731051235, 0.05164315142939168, 0.03957803270989849, 0.010254438309329412, 0.05864171318769936, 0.11489522388024677, 0.148265469939478, 0.09054742513164397, 0.16081667144692716, 0.09039890366576372, 0.2034703939552269, 0.1479169918644813, 0.1240176456649938, 0.11904926670174446, 0.19363112837797214, 0.16527003248132047, 0.2305157644854438, 0.07731364694454017, 0.1741575870302416, 0.23103743971836185, 0.12718135130501565, 0.1196079746249222, 0.051846137916248654, 0.1164010846086087, 1.5988746501745719, 25.652469588864236, 63.13232867948471, 55.18992131756198, 42.45630348882368, 38.59306696922549, 48.56546171249882, 53.95685757360151, 56.649109701956476, 20.826754031642793, 0.3175936693385724, 1.1805517875379132, 7.534930465682861, 18.447330536380893, 10.027485412936057, 4.111331826256168, 13.398523311461172, 35.16438199627784, 49.50226099260392, 57.690204804943455, 57.18652148400584, 57.66746682505454, 56.53012852514944, 53.99848961061048, 51.22638979265767, 53.11187313448999, 52.71074802644792, 52.8106939408087, 53.56479706302766, 53.67439200801235, 53.16610382449243, 52.47570783861222, 52.87222416170182, 50.09413880686606, 52.075602546814956, 54.06588769728138, 52.47524499893189, 49.55127885264736, 53.604565974204775, 51.001798798961026, 42.901029663701216, 41.11036962078464, 40.66700843072707, 42.15376715506277, 39.403954244429066, 44.434750926110056, 44.80708191471715, 43.34542635948428, 41.63562990004017, 40.98185708445888, 39.07507135022072, 41.45957039248559, 38.73250330648115, 42.17248078315489, 42.65189639983639, 40.32669182746641, 39.63238916089458, 41.58236411310012, 41.7210042092108, 41.39018366413732, 42.41227096126926, 44.41204824755269, 44.21517272149363, 46.27416210789835, 49.05681310161468, 53.28138620622697, 52.689214214201904, 56.681555548021876, 52.56099193326889, 48.54760708347444, 50.13264471484769, 52.74530803003619, 56.54839108067175, 56.23908865836359, 55.16525353154829, 52.65310095202539, 54.87491969139346, 53.09610128402711, 51.81644370478969, 46.605523940055605, 53.24442571209323, 56.74198750526675, 45.307976430462254, 39.4865515155177, 40.35752557939099, 41.36940294696439, 39.769483843157374, 41.26797829904864, 40.93682827488069, 44.53134713634368, 42.36616349989369, 43.951609057764855, 41.94463029984505, 41.95101984085576, 41.125333462992025, 40.470662424641276, 41.08328173237462, 41.117931950476866, 44.00176048278809, 53.80279079560311, 54.895072829338815, 55.78315627190375, 56.40931952384211, 56.48635095165622, 54.448193273236676, 54.348443477384514, 56.11951912603071, 52.924438753435695, 52.272874232261415, 50.35188167325912, 45.942831654702466, 41.79148527883714, 42.67801154044367, 41.97759782114337, 43.09976439322195, 48.30396906022103, 55.22231617281514, 56.34139191719794, 57.02262132398544, 56.4287313338249, 56.83292373534172, 56.84936631110407, 54.874084226546756, 59.008023123587336, 49.844236758447465, 29.78232529855544, 5.609184484327994, 3.876715254399085, 7.203070002217447, 13.54955025257603, 22.49737189662072, 6.246314192971876, 0.9142560704100517, 0.3542502717145028, 20.073607967745875, 53.666531578187026, 42.8875288655681, 43.06894633077806, 53.388007994621034, 64.28560749177011, 41.195841989209576, 3.0217947161966756, 0.18965307893531938, 0.0952684036606262, 0.1262804165843033, 0.14736631254275, 0.11427614056775648, 0.11486628873934669, 0.22715303686357316, 0.10494970190789431, 0.19466173114074817, 0.12847430087746153, 0.23463895694623071, 0.18087012603157954, 0.17521507947915987, 0.13447804767037594, 0.13556618363626544], [0.017328544955460295, 0.02620011124940169, 0.039434215023873315, 0.055200587958097465, 0.029791190529302247, 0.07050757626852683, 0.04338838933636585, 0.0688475097018865, 0.047970744255449504, 0.0475822112733318, 0.03265340609716312, 0.043025179390585234, 0.05449828451439258, 0.03623798895146578, 0.044600738798298185, 0.08152614227466046, 0.07084952727440866, 0.055866379651331136, 0.03356716129928827, 0.0790866655147364, 8.98745229167323, 40.88961470511652, 47.42781354535011, 29.289353970558416, 22.1406715531503, 35.23643593634329, 40.65544528345908, 52.513444962040076, 29.432461646295366, 0.8452697302545271, 0.5887779773723695, 3.5842378389450813, 3.707682918156347, 2.482165324111139, 2.867438663398066, 8.038732438318192, 29.384189036584672, 48.96868921095326, 51.97616654057657, 52.19057506130588, 54.247571883663056, 52.167260493001635, 50.22398102668024, 49.72103118896485, 49.94181748359434, 49.655472693904755, 50.32658630801786, 50.867783177283506, 52.0961400770372, 51.54089327781431, 49.122230391348566, 53.12307542370212, 50.48890967522898, 49.79914126857635, 51.09203684714533, 50.788967071040986, 50.82429193681287, 50.73961188716274, 47.27708862673852, 42.607942319685414, 36.65122309038716, 36.10023206280124, 36.05628190502044, 37.405969481314386, 38.740320590234575, 40.01283161101803, 39.50172716571439, 40.102959832837506, 38.61849569505261, 37.364851274798, 36.85005980153238, 37.11055224941623, 35.79073744435465, 37.43056666466498, 35.30599917134931, 37.02310692879462, 37.52453488688315, 38.75678277784778, 38.95577638379989, 40.177610381957024, 40.31140242853473, 40.925924085801654, 42.22930023747106, 44.036897074791696, 45.856708172828924, 47.42983748835903, 49.69594763171289, 50.6584031351151, 45.85505685498638, 44.079925475582, 47.53086597688737, 51.76371528256325, 49.97848772233533, 50.78578210646107, 48.914336927475475, 50.55462506509597, 50.54643907854634, 50.02513254842451, 44.75283553523403, 46.410233051546165, 49.01349052306145, 44.55159833354335, 34.72060503498201, 36.32190089071951, 37.88818174792875, 37.60667324066162, 38.233201273026005, 39.84181234913488, 37.97971025589974, 39.68802013704854, 36.849412610453946, 37.96677820144161, 38.460510469252064, 40.59317373460339, 36.63107779718215, 38.502511209057225, 34.92897310564595, 40.63606485243767, 48.55833476589572, 53.51373172575428, 46.952692924007295, 47.92827267800608, 53.0299073649991, 48.71627684562437, 50.61461379451137, 52.769889523906095, 50.46407322729788, 50.5521696613681, 48.30629894810338, 47.775049209594734, 43.997822423135084, 38.523087962981194, 37.24683107868318, 36.28270072321738, 42.436824998547955, 50.79502321058705, 51.70058081226965, 54.07541121205976, 53.359963047888975, 53.32261031673801, 51.06887917364798, 55.82262316057759, 56.7694950872852, 45.66677916434504, 20.846675749747984, 3.561492994908364, 0.2509224928554989, 2.8553964966727845, 5.805644729445058, 4.811172879511311, 4.411857455007492, 0.42001303645872307, 0.17321666251988183, 18.840579525116954, 41.88376295951105, 39.54448492296281, 43.52596913614581, 41.95520500982962, 51.93136915083855, 20.70982229325079, 0.471815564819882, 0.017350884079332315, 0.07510613394720901, 0.03152662099549367, 0.021422771631830165, 0.03458387105755749, 0.0500740118384842, 0.10761735029518606, 0.010521686166494845, 0.04559311760409225, 0.05628695426088187, 0.04948229318664921, 0.02503539330416149, 0.024792150812103383, 0.01671565163339819, 0.01588352980287445, 0.019792343091760433, 0.032832352744956175, 0.04022323579016713, 0.03329259921766577, 0.01077130729813249, 0.07874810827835914, 0.03599091410456646, 0.13757440652097427, 0.010391608267391642, 0.05457195152919139, 0.014237997839377533, 0.0432506965232953, 0.05568325016347151, 0.09014722079999986, 0.060800426384253856, 0.04268777511653401, 0.03950277989309642, 0.03445592288288378, 0.041619741297777624, 0.10755254691767116, 12.626724416209806, 47.652730095771055, 52.7474457217801, 33.95088695710705, 21.97305298620655, 42.619489777472715, 48.6808382311175, 55.251318177869244, 30.505690766919045, 0.811026519344699, 0.15848698274743173, 3.510243796533154, 6.018842708679938, 2.9671784081766686, 2.7888760403279336, 8.796067103262871, 32.69529508006188, 48.1142165583949, 53.34993354735836, 53.79735046817411, 55.02691545794087, 53.19224249932074, 53.56991183373236, 52.10360042510494, 52.17649767475744, 52.20613118140928, 51.82126429773147, 51.91982561542142, 52.62133759836997, 53.15650578468077, 49.30808013485324, 53.501678282214755, 52.012350405416186, 50.9190446330655, 51.48274414000973, 52.29731059843495, 52.470498931023386, 52.97151111787366, 49.1602107017271, 43.07872872198782, 38.459153329172445, 38.29994824624831, 37.520941995805316, 39.62847463546261, 39.63766867114652, 42.122509787159586, 41.43766787744338, 41.371324908348825, 40.52624240998299, 39.06077431094262, 39.2114011702999, 38.07881286067348, 38.480169388555716, 40.05397727412563, 37.59819699871925, 38.70128908464986, 38.42777829016409, 40.5230535230329, 39.8655269991967, 41.180882069372366, 42.037955253354966, 42.3173652925799, 43.23381923860119, 46.80019509407782, 47.20057102941698, 50.26736636315623, 51.858283627417784, 51.2794320044979, 46.724634555078325, 47.93921609078684, 49.599900553303385, 55.146339862577385, 51.96636453751595, 52.64009437253399, 52.34116661933161, 51.79601992330244, 52.113131784623675, 50.04828237718152, 46.428985903340006, 49.35682735135479, 52.83399281963226, 45.17567880692021, 37.835041476834206, 38.796763497014204, 38.714574152423495, 38.33182142626855, 39.50822261071975, 40.31057480842837, 40.637802462424006, 42.73580766493275, 40.64641598732241, 40.18198774706933, 40.79954531884963, 41.89034861903037, 39.45921259541666, 40.14682762084469, 37.89062146217593, 42.54529422329318, 50.72158467385077, 56.209792475546564, 50.510651373094134, 50.07405234921364, 54.86711025238038, 51.00780002532467, 54.09264218422675, 54.23301989032377, 52.00931449090281, 53.64674322066769, 50.68035271859939, 50.300047551431966, 45.155615883488814, 40.78114940274147, 39.14672128615841, 39.98922286495086, 44.7179421301811, 52.11814849607406, 54.651862344434186, 54.35253058710406, 55.211341381073005, 55.28649399357458, 54.24043709231962, 56.80613394706481, 58.713700232967255, 46.91583048912787, 23.51115945846804, 4.10570175417008, 2.9600173859826984, 7.284265516265747, 10.974089637879404, 7.510943210894062, 4.618131960591962, 0.2737735626437972, 0.08390937285918383, 20.846944432104788, 45.153136945539906, 41.823389837818766, 45.71140789216565, 47.4944624593181, 59.66412190468081, 26.304710718893237, 0.6611662382079709, 0.08533992714458898, 0.060621280553600485, 0.06375874002133647, 0.06370972954638063, 0.07127790065902857, 0.030328465227578438, 0.0648856093926776, 0.025856704676463723, 0.03498399494996956, 0.06466204195373482, 0.031053559787030664, 0.011788705577923646, 0.044830139996784354, 0.016310283869144418, 0.0077695665306471776, 0.12465375145116162, 0.09781032935866425, 0.16395628362173037, 0.12117846253057643, 0.07582550582986686, 0.21072572157267602, 0.07519912169945818, 0.20743511346799715, 0.1682549102171775, 0.23698971306364383, 0.11278863530606033, 0.1410571494770627, 0.15098938748480814, 0.15022169077588668, 0.17822543729937848, 0.12278197648664638, 0.11941583211263342, 0.12339883814415625, 0.14337660324188972, 0.25894577765176374, 14.449591040611269, 55.545048790593306, 58.923143033058416, 40.059672555615826, 33.303397778541814, 47.809675893475934, 52.96357224064489, 61.77386676111529, 35.11631727218628, 1.2943043223311825, 1.074687629457443, 10.799754992608102, 11.681679333409956, 4.629928488885203, 4.681452743468746, 10.025485004148177, 34.498504746344786, 51.83564762915335, 52.980328606021025, 55.81406847123177, 57.28952684710103, 56.2371470851283, 54.91657134025328, 54.31335395382297, 54.83227960525021, 54.48317689280356, 53.3741424160619, 53.895907863493896, 54.616345282523866, 55.95594452273462, 52.50290163101689, 57.11991179373957, 53.41315430979575, 52.496845491470836, 53.70147205168202, 54.77395396078787, 54.12819062509845, 53.480677912312174, 52.134763656123994, 46.660715610750266, 39.92219348107615, 42.089671704076956, 39.32699734164823, 41.86784598135179, 41.83021083954842, 43.430706531770774, 43.34519493964411, 43.81814256791146, 43.656572295773415, 41.38359408224783, 40.40280934303038, 40.455314190157004, 38.817548136557306, 41.91760909172797, 38.697339257886334, 39.58440288420647, 41.331281431259654, 42.347418492840184, 41.77973778017106, 43.06210179482737, 44.55481859945482, 44.683456651626095, 45.76897259681456, 48.817513219771854, 49.3084409929091, 52.39524041452716, 53.046863771254024, 53.29782878198932, 49.74447911785495, 48.4930076906758, 52.44829047110773, 56.11731475399387, 52.77561618435768, 55.159217003853094, 53.6321912273284, 52.12674240912161, 54.082306738822695, 50.94058236768169, 48.58276328732891, 50.46662669028006, 54.12638241244901, 48.896847078877116, 38.606928625414454, 40.970191955566406, 40.628679029403195, 39.77926231199696, 41.53316190165859, 43.30490043086391, 41.69736408418225, 43.8471955637778, 42.8941459040488, 41.71566586340628, 42.54957745152135, 44.30550490656207, 41.09042044608824, 41.07664900441324, 39.24573367641818, 45.75839004208965, 53.25315690809681, 56.68960817398564, 51.95324813165973, 54.0895042880889, 55.34841645148493, 53.27514963765299, 56.603010085321245, 57.23920283779022, 54.42864418029786, 56.89452848126812, 51.649193840642134, 53.09967848562425, 48.255288524012414, 42.43358119841545, 41.590648158904045, 41.48623466491699, 47.17107480572116, 55.167987423558394, 56.622300301828695, 57.84993940784086, 56.783607775165194, 56.74905953868743, 57.03720077391594, 58.23652428965415, 59.87603187561036, 49.53494610324983, 24.78733789536261, 4.995238925180128, 3.2157090979237712, 10.45285959397593, 14.488585283679349, 11.817748315872686, 10.775502977832671, 1.1625421023176563, 0.35345393863897173, 25.29001316716594, 54.49055487109769, 51.42685036505423, 51.45376566917666, 54.63847921740625, 67.77122174539875, 31.49780135000906, 1.0534335312343415, 0.15984784601436508, 0.231998696202232, 0.17211282175154458, 0.16022198803482518, 0.09467867683739432, 0.16348055834251066, 0.14308184325214357, 0.12050950689421547, 0.14650107751930916, 0.10485439290923458, 0.12352060015884139, 0.0650464189088633, 0.18689928396094233, 0.09753221645951272, 0.1549010783914597], [0.05939483507386139, 0.06425130774357146, 0.03227742929612437, 0.04684431921510447, 0.08369580286765292, 0.05239703174259874, 0.061228194559413585, 0.006697933535061537, 0.004948822174957323, 0.10255197693984355, 0.08956935301783586, 0.0472360429534268, 0.06764475932164539, 0.04199594792519366, 0.05396481152744063, 0.040437809356878844, 0.10012602163178307, 0.050731556595212994, 0.07511293680797662, 0.04324291690042423, 3.8675065098270296, 32.04753721913984, 44.11070431432417, 32.341791468281905, 25.346783591854958, 27.130524573787568, 37.64126070084111, 49.35011617598995, 40.02122548318679, 3.2995259809878568, 0.08275205149285256, 1.1986708088267235, 4.816377864729974, 1.3753523797758165, 0.9416325594629011, 7.290962473038705, 26.985179185867313, 47.690863378586315, 50.671692125258915, 53.32359483165126, 53.18359367309078, 52.534947395324714, 54.22365719272245, 51.88971750197872, 53.21863612821026, 51.675740441968365, 52.778232405262614, 54.3074978551557, 51.67150820455244, 51.47560934866629, 46.611085860959946, 49.96563411528065, 51.070989408800685, 49.353034419398156, 48.36181617552235, 45.43237440047726, 46.989469066742934, 51.48773731723909, 47.23117336150139, 41.721168948758034, 35.890098925559755, 37.643100292451926, 37.34192502114081, 37.87124103115451, 38.23459763680735, 42.05059705242034, 39.701666062878026, 39.6123811506456, 39.19457027989049, 37.46389112164898, 37.53034783947853, 37.63489469405144, 37.375096505688084, 36.53424232236801, 35.69103863931472, 39.68546275169619, 38.40041583584201, 40.41134442052534, 45.750290347683816, 45.72173549282936, 47.52438229899253, 45.30643886135471, 43.63266937194332, 43.85964124433456, 43.1217178990764, 45.64475505582748, 50.124780362652196, 50.72679750380978, 48.93792213932161, 45.20289221117574, 46.713079252550685, 53.60478562693442, 51.306821915411184, 49.48969764094199, 50.66678524017335, 51.37365518077728, 49.79191234034877, 49.19302917295887, 49.27881140862742, 46.93942354571435, 48.47302321464785, 42.88536763960316, 35.094304930779245, 35.064604743834465, 36.11436828490227, 37.41168437465545, 37.36844808824601, 38.52594344846664, 38.31564557167792, 39.619033490457845, 37.17903683262487, 36.523840196671024, 38.38042743744389, 37.59585534372638, 37.182923901465635, 37.49639188089679, 36.01429685469597, 39.33598741408318, 48.97239192839592, 50.39698893024076, 45.105197737293864, 46.710137474921446, 47.545370901784594, 49.23247252741168, 49.834415143535985, 48.59818604684646, 51.54652187901159, 51.70558575660952, 49.88466070544336, 50.73816061019898, 50.61296247666883, 47.05197203543879, 41.14995025819348, 36.46066258030553, 37.839536513051684, 47.48418977183681, 53.29106661581224, 54.7434732221788, 52.32683427872197, 53.923690011424405, 53.653662281651656, 54.20123300244732, 56.501581515035326, 41.77338746286208, 19.86866608742745, 3.160475997194167, 4.4574275516694595, 7.98275972566297, 9.890931037164505, 4.107010845215091, 1.486054413741635, 0.03409480435713645, 1.5862601851263356, 24.570536728828188, 41.55256194453086, 30.445043079314697, 41.21721498427853, 44.623173744447776, 47.85455565298758, 16.275340607089383, 0.2505442446037646, 0.03556969981159895, 0.03907164093106985, 0.023270349709257003, 0.1064359967506701, 0.06782403921768551, 0.005686816218639574, 0.09945460685318518, 0.03126197783727079, 0.019365038399794893, 0.04836825578803978, 0.03156351962036664, 0.0040258360921495385, 0.07428483406622564, 0.017721122881818204, 0.03244016935387927, 0.07139990016097023, 0.02184168000014559, 0.04246650211092445, 0.022771245341808088, 0.05556440311333826, 0.02085339784952662, 0.037654841754345164, 0.04271269978715047, 0.03424804492463027, 0.05370541415627926, 0.04600073383640378, 0.03426233246441811, 0.06294831858887788, 0.04298081523889015, 0.1410594017755601, 0.05804927441321554, 0.14234082172474555, 0.06968976974847817, 0.034373679513772654, 0.020667834117287592, 6.431498604436075, 37.68071190003426, 52.75411767344321, 35.52081561857654, 31.009689838655536, 35.393158158948346, 42.21656430152155, 54.4458241616526, 41.45206297597578, 3.2294800493025013, 0.13592583127319813, 2.3626595302935574, 4.547305232094181, 1.944099977131813, 1.3526494560703155, 7.105540758179081, 30.31078427068649, 50.385602289630526, 52.62636215456071, 53.03678720228134, 55.30463495562154, 55.09414488269437, 56.40836638789023, 53.69924022305397, 54.16419798328031, 54.80956515958233, 54.8727035522461, 54.9275500543656, 53.38915332671135, 51.68005897152809, 49.008112953555205, 52.41487972197994, 51.71432479735344, 52.18481309952275, 51.138148230891076, 48.44856723662346, 48.92593929844518, 51.12699301012101, 50.71030393723519, 44.2373654919286, 38.711922630187004, 38.845306750266786, 38.30805970776466, 39.283364895851385, 40.708797362542924, 43.85021578881049, 41.5475687673015, 42.10173299235683, 41.03848826500678, 39.70914210042646, 38.53747913914342, 38.45018679095853, 37.8551750029287, 37.68882336155061, 38.48577837790213, 42.423132004276404, 39.81124531838202, 41.730668929315385, 47.45027695932696, 46.40098410267984, 48.24970306888704, 47.852319901989354, 46.059428030444735, 45.481690360653786, 46.61435711768366, 47.44159675413563, 51.68875094382994, 54.2059673032453, 50.723577237898304, 46.621495831397276, 47.51344280858194, 54.96322008871264, 52.47893987163421, 52.02362329729142, 51.4447206835593, 53.52399264612506, 51.28731204617409, 50.92635985343687, 48.30414948924896, 49.75945472717286, 51.636391224399695, 45.36915363803987, 38.12582638955886, 36.45980358123779, 37.50981030925628, 38.84621281777659, 38.552588109047186, 41.0369114721975, 39.471470002205145, 40.930721144522394, 38.101272352280155, 38.96780237074822, 40.0616455078125, 40.335544616945334, 37.28027320677234, 39.15497787537114, 36.79488774268858, 41.02694472958965, 52.10793856651553, 52.11938404267835, 48.735112067191835, 49.007418694034705, 50.23276321349606, 48.70164248251146, 50.783244332959576, 51.82064064087407, 53.895841183200965, 55.67176488138015, 53.440226508725075, 53.160734099726525, 52.07540642830634, 48.564924347785215, 42.06888314216368, 39.239669692131784, 39.667470839715776, 49.288178028598914, 55.53638035251249, 55.48708400418682, 55.363623480643, 55.782485546604285, 55.272706862418886, 54.907463596713164, 58.95391010469007, 44.60346775670206, 23.151301607008904, 3.9227763827769992, 4.3770861337261815, 7.38984787656415, 10.183622221792898, 7.202008510789565, 2.746071459785585, 0.11159687062665341, 0.9840459448675957, 25.799119164866788, 46.26730188246697, 41.13450788682507, 44.12962582803542, 47.55568673533779, 55.53641565384404, 20.345871448516846, 0.21728393982254693, 0.06275808746596018, 0.0790719872701072, 0.052626329519215136, 0.05325497360900045, 0.02354345047816394, 0.06706885272456754, 0.07137658044455514, 0.04524910199125448, 0.013288057431758893, 0.06884783145881469, 0.02429843204276216, 0.02744771224716979, 0.02195435238160914, 0.01436474229840021, 0.09005943478475656, 0.18006335883851976, 0.13718492742027008, 0.11842377123332794, 0.12466584031860675, 0.3044605627655983, 0.09863498470475597, 0.19045863570945878, 0.13033509014114258, 0.1373727108922697, 0.26443311223579996, 0.11285405155391463, 0.19552736452990965, 0.16277024161911782, 0.16008125768313486, 0.22416693338703728, 0.1253435829834592, 0.2692645836261011, 0.3258649674394439, 0.15454941339069797, 0.17939045784934876, 6.544916389449951, 43.261499404907234, 59.22499295203917, 45.1166549805672, 38.26270534146217, 38.68904736734206, 46.276237041719504, 59.099716371105565, 49.00550457739061, 4.3810977378199185, 0.31011125793860805, 3.410191487881445, 12.81424508940789, 5.38130997650085, 2.1826930968992175, 10.542907407206874, 29.87406365333065, 53.218228201712336, 57.45919681364491, 53.232615455504394, 56.43537190652663, 57.309876103555005, 59.604748987382465, 54.78624666890791, 56.40699355832992, 56.992732863272394, 56.14734834240329, 57.642210683515, 54.16648472509077, 53.44372134054861, 49.84427990451936, 53.47701049620106, 54.25469490789599, 52.732717221783055, 52.357091442231216, 49.68514542425833, 50.76451501538677, 52.741758285030244, 51.77971855286629, 46.25221252441407, 39.29128808359946, 43.74855187631423, 40.14899669154998, 40.509635094673406, 43.27372543273434, 45.12415062996649, 44.237416482740834, 44.58622893979473, 43.451765737225934, 41.846406305989916, 40.9744438048332, 41.10586673982682, 39.77108809255785, 39.68598442692911, 40.47750303822179, 43.7057666624746, 41.672657074466834, 44.98067032906317, 49.67622203211631, 50.20648333334154, 50.81853389739991, 49.396000062265706, 47.967394398104766, 48.607125128469164, 47.75189545846755, 48.97594559577204, 54.76313606385262, 54.86302314266082, 52.680604611673665, 49.55059636023737, 49.604321064487586, 57.92627657613447, 57.17125954166536, 52.277667368611986, 54.08249893496114, 54.1481751011264, 52.49451952595865, 52.753643066652366, 51.92455599384924, 51.70545239602366, 53.377217554276996, 46.460043230364406, 39.8607809312882, 37.56411552429199, 39.43716887504824, 40.94643808180287, 40.53037266577444, 43.53283328394736, 41.75797647045505, 43.272156484665416, 40.167161187817975, 41.20777776164394, 42.92546210750457, 41.404590529780236, 40.3903518953631, 42.10377262484643, 40.041398232983006, 44.12298525533369, 53.43367615053731, 53.48334120165918, 50.48645034913094, 48.3665543986905, 50.12774567450247, 50.1609799169725, 52.31258038551577, 52.08058787930397, 55.148481476691465, 55.806894456186605, 55.39535153296686, 54.58843761874784, 53.9295147311303, 52.17525820578299, 45.43262150979812, 41.57742977142334, 41.4055593552128, 53.00923647419099, 58.865915652244325, 58.676398492628536, 57.34340452378797, 57.72925984474921, 58.11110258102418, 57.44553519833473, 60.21568559831189, 47.375308698223485, 25.15378728989632, 5.4579324972245, 8.219964081241239, 14.47576403617859, 18.651499709775372, 11.674508260142419, 7.41713188348278, 0.37549318505391, 1.6030940173133728, 31.225569248199466, 54.73651101512294, 41.6684248370509, 51.88696399811776, 56.45299119334067, 62.10076885838663, 26.142550130044263, 0.33633101551282796, 0.13944286432477737, 0.1620105888334013, 0.13301028449448848, 0.2583901800455586, 0.11388574982242239, 0.15955466416574296, 0.21322030303699357, 0.11471555327936528, 0.24335316111964567, 0.07615434907136426, 0.12853770997495423, 0.13845621968709654, 0.212496365270307, 0.12086101867739232, 0.19995590431555627], [0.009129574173130095, 0.030019645609201926, 0.024992689648042285, 0.04578126496785591, 0.04870325454600877, 0.022755063649627472, 0.04494254807791403, 0.014237659803080945, 0.009850395877184647, 0.024174793112662532, 0.06108107503443476, 0.04115077291405009, 0.031129574861317396, 0.11714047436872799, 0.06891985138457629, 0.08888548164958916, 0.04778655756625438, 0.03425461412858098, 0.01623070074035035, 0.03239889636695866, 1.3705477214628652, 15.404797023342503, 43.97429604684153, 38.35184904836839, 17.716985210295647, 30.510801615253573, 44.690552219267815, 46.23841362614786, 48.919522300843276, 4.864225877869514, 0.03657378827131564, 1.9591019398743108, 2.424218188370428, 2.3362279034429982, 2.119736113855916, 3.0575297147996965, 26.828249077643118, 41.51185558688256, 47.46029861511723, 48.1678432033908, 47.952152067615145, 49.3130733120826, 51.002959820532034, 49.87745531143681, 51.34015029476535, 52.97706519403766, 51.40342597038516, 51.319408801294145, 51.245511347247714, 47.60387697527486, 45.79301672597086, 48.91163833679692, 47.561021158772135, 46.83786161484257, 49.9407466765373, 47.1378444856213, 47.14522246391543, 48.12768597756663, 46.489480618507635, 41.470858973841516, 35.19989121344782, 34.95684546809043, 36.31748037953531, 37.3167355598942, 39.57999806250296, 42.64980185416437, 41.81846726325251, 42.5124639849509, 39.89037129186815, 37.79328000160956, 36.57035558454452, 38.150917791551166, 36.623248746318204, 36.44078008590206, 35.43142480234946, 37.35418635029947, 38.544390355387044, 44.64395838399088, 50.167267476358724, 50.48013141078334, 51.30803392779443, 48.39061029495732, 47.71295808976697, 45.39570808410645, 45.22663039545859, 43.76506897710985, 49.2405173086351, 47.29800662686748, 50.076378314725815, 43.83910763648249, 46.344537273530044, 49.38410351353307, 50.21460263959823, 51.45793122629966, 49.96788555575956, 51.26450346362207, 49.02430841999669, 49.96015848652009, 49.18428228747461, 47.256766826875754, 49.6163470514359, 44.3005980214765, 36.097192225917695, 35.68124055862427, 36.11721984801754, 36.76113182498563, 37.31433899171891, 37.05492127326227, 38.168568457326586, 39.913713316763605, 38.0472142465653, 38.03387426560925, 36.458262089760076, 38.88071006344211, 36.2451950196297, 36.743461547359345, 37.973210888524214, 36.89057004067206, 43.452134440022135, 51.42149632976901, 51.563666559034786, 52.19592517422092, 50.73014720793694, 50.81388196637554, 51.28184818452405, 51.40922715587001, 49.51762099419871, 50.17126437156431, 49.650444215343846, 53.10224763808712, 50.66496133804322, 49.91464330304054, 47.51970291137696, 40.581288952981275, 37.697872269538145, 40.41579631067092, 48.67876329729634, 50.47200818215647, 52.92034772134597, 52.15741534386912, 52.829399724160474, 56.08166433149769, 56.901023926273474, 42.40773670135006, 17.43979327140316, 2.680095232302143, 2.8876300444526057, 5.4792834289612316, 7.04642475612702, 3.112285266960821, 1.580233463356572, 0.1408042791750162, 0.4910074769248886, 25.835479536364158, 37.749592642630304, 24.101111388975575, 42.052216991301506, 46.10706129381734, 45.00661288538287, 9.376017970423545, 0.13826762416189717, 0.05255828558978054, 0.023432591809861125, 0.025053415522580186, 0.06485230755060911, 0.06423093746566484, 0.05875260441473896, 0.025466057291675, 0.08389251126397042, 0.041792440498548175, 0.023645269308960246, 0.04556973660064321, 0.037389863432655414, 0.04908541367659646, 0.008046673460593148, 0.06363820374733017, 0.02179530295242946, 0.04040356522666351, 0.03031183345874231, 0.045981336490161, 0.04089291537961653, 0.05757987702025041, 0.08158463308767927, 0.07751980886584328, 0.009797436218979138, 0.03751449827705661, 0.052490226338587465, 0.056549086565932924, 0.01459600700576219, 0.03625889166047977, 0.005598754411743533, 0.06491725648482961, 0.05700203605116375, 0.028094292370482322, 0.021744455781675154, 0.05783865002975349, 1.720487982515366, 21.664391871421568, 50.26959426941411, 43.69763558910739, 24.376648087655347, 31.566531081353467, 47.467351036687056, 52.84581876570179, 51.3103481261961, 5.0612215265151, 0.07135905235284759, 0.815330094868137, 3.3599155276052417, 2.2479846256394542, 2.749542021943677, 4.934659388757521, 27.227311018974554, 45.8580574681682, 48.50454730372275, 51.57642602920533, 47.94164403792351, 49.821628216774236, 52.46237570239652, 51.95234990889027, 53.12968461744247, 52.756318123109885, 52.35182762145997, 50.990282720135106, 52.11435164174726, 48.791233339617335, 46.79853593149493, 49.2479266658906, 49.25738350037606, 48.13877451804377, 49.57175754731702, 48.06165287571569, 49.11997502849948, 51.2344620304723, 49.36733930341659, 42.95982207021406, 38.18578374001288, 38.566783166700795, 37.8604035223684, 38.485841135824884, 40.36355426234584, 44.5966467549724, 44.050323347891535, 44.85888073521276, 41.2603335995828, 39.75525348417221, 38.22398762549124, 39.46328401565552, 38.48329551758305, 37.64022127274544, 37.39956817319317, 38.717213907549464, 39.53025456397764, 45.71895845474736, 52.07550840993082, 51.898699729673325, 53.33642882685508, 49.40886543643091, 50.7143832022144, 48.70135614948888, 45.00260030069659, 46.09138750260877, 51.338644104619185, 50.40098974781652, 52.06470228010609, 45.621389496711, 46.249278591525176, 53.55261418127245, 52.546608601847005, 53.047365834636075, 51.65972148218463, 52.390894428376235, 52.50334485884636, 50.43369054794312, 50.586082473877944, 50.52112802382439, 50.36835955035303, 44.983839604162405, 37.494242422042355, 38.60410451889038, 37.857810835684504, 38.1929930563896, 38.50018524354504, 39.28813449798092, 40.21824613694222, 40.94224899045883, 39.599849177945046, 38.54607305219097, 38.31796761481993, 40.1204026129938, 38.31418252760364, 38.985868807761904, 39.02610840335969, 39.041491939175515, 47.08191933170442, 51.39514976932157, 53.10551105007049, 52.114026085022964, 52.5375283148981, 51.827473409714244, 50.90699511189615, 52.992452652223655, 49.79568173808437, 50.51273415165563, 52.80029181511172, 55.250329740585826, 52.755663087291104, 51.622231468077636, 48.78036837424002, 42.66259662566647, 39.87219502848964, 43.11201787764027, 50.64729890515728, 52.32413961041359, 55.27416206175282, 53.780029281493164, 53.90674144990983, 58.921613308691214, 57.22469399052282, 44.44426267377792, 19.48683119589283, 3.7482738110326954, 4.230329182840163, 7.40605854219006, 9.347029693665045, 7.894929032171927, 2.743547904875971, 0.1843695390609003, 1.110411964116558, 29.574753469036473, 46.682739719267815, 29.281016972757158, 47.4540267452117, 50.32563709443616, 52.28033850269934, 12.766909926168381, 0.1392858929090923, 0.07169292113112827, 0.04143046395432565, 0.020937454931798483, 0.05580446059485117, 0.027281904007278146, 0.038209225111190355, 0.031293318494253104, 0.06054297104598053, 0.026082976405779203, 0.03279369594829698, 0.04212380799975607, 0.07198974189739074, 0.014402097703198032, 0.013510706522802432, 0.01258515069381364, 0.1682731124662584, 0.25920633947657, 0.11567492518694171, 0.12322485191567291, 0.22137199949112632, 0.14810259964677597, 0.13370762368844402, 0.19070461122018678, 0.07289220879395163, 0.20659790194082647, 0.16295327534598691, 0.1844370314070294, 0.14058186852883908, 0.23386243490442155, 0.1398214343334398, 0.27554166292951954, 0.09481491791384836, 0.15911494501896445, 0.09029741233755505, 0.2225531385310235, 2.1467310911224735, 23.502757741558938, 57.973223424726925, 51.527086534807765, 28.047466854895315, 40.76059226066836, 56.53933040557369, 56.550238517022905, 56.93267745356406, 6.231691596969482, 0.17096508414514605, 4.040457784168182, 8.15887414639996, 7.112024436073919, 3.3822544063291247, 4.931694567203522, 29.641904446386523, 47.915889755372085, 49.61462120856009, 52.20934752495059, 49.038173998555834, 50.04399522658318, 53.51015452415713, 52.001242253088186, 53.32362621061264, 56.01718056586481, 52.58729534764444, 51.42379876106016, 52.449820195474935, 50.13226424494098, 46.99006134463895, 50.553903348984264, 49.93587901515346, 51.01344823837281, 52.93551552680231, 49.950423163752404, 51.57033458832772, 52.7231897846345, 51.428799783029866, 45.52806454320108, 39.85615253448486, 39.65604105303365, 39.25463745670934, 39.961279899843284, 43.39932364802207, 47.81520251304873, 46.29548803452523, 46.04080853923675, 42.05013813511018, 41.693712357551824, 38.91865899485927, 41.580465685936716, 39.54685403454689, 39.88685684819376, 39.24015998840332, 42.21968258580854, 42.12815407783755, 48.50451592476138, 55.876579284667976, 55.88306296256281, 54.5402003103687, 52.93534294251473, 52.17686637755364, 51.08260354688091, 49.57231060151131, 47.54559839925459, 53.30421047825968, 52.23411729258876, 53.90960870250579, 48.41576837724256, 48.85116715585032, 53.236090675477065, 53.38530548157231, 56.55482769012452, 52.9059055543715, 53.27547911674746, 52.68882589955484, 53.11107689334501, 52.70694724975094, 51.08741237271217, 54.28253981374926, 49.37173235800959, 39.4351488544095, 40.35342278019075, 39.57842519206386, 39.969179553370324, 39.817387750071866, 41.89733043793709, 43.013048633452385, 43.340139004491995, 41.8949770158337, 42.285197934796734, 39.91101080371488, 43.528742251857636, 39.70376845329039, 41.221745321827555, 41.7707633972168, 40.83001429034818, 47.672326257151944, 53.915398120880134, 55.02622512079055, 55.09062259427963, 54.23387496702133, 53.78812113115865, 53.61925917287027, 54.49055879346786, 52.031287608608125, 51.26908479198333, 53.31675421807074, 57.529517066094186, 55.28083009104575, 54.01981161486719, 52.296243713748076, 44.84193609606835, 42.315200144244784, 44.79884885972546, 52.449357355794604, 54.068327411528564, 57.96768503804361, 56.55634172501103, 56.717700189159764, 60.57931284750662, 60.7932153824837, 46.28769036262266, 20.36684043945805, 4.74055992018792, 7.791562320724611, 13.620750096536453, 17.848972966594083, 12.511414577884059, 4.59187267288085, 0.4467958380137721, 1.105417561146521, 31.948705257907992, 49.14856910705567, 33.98676095470306, 53.050021279242735, 57.285220084651826, 60.6982312663909, 15.991313938171634, 0.25102455108877153, 0.15201059800963249, 0.16671807655403692, 0.15102122609894122, 0.22638913995075613, 0.195407732239654, 0.2655895066357428, 0.13449433469964614, 0.10291033754906348, 0.12044119483400738, 0.13406990666783627, 0.1310544926673174, 0.14915330455668513, 0.2651850734987567, 0.06142640065762305, 0.15265320788227743], [0.06991704505297446, 0.042923531014352076, 0.014929995485281032, 0.013587141987837613, 0.02627769105827376, 0.0383501929501372, 0.07703281443325743, 0.007007847701559865, 0.04768097149809042, 0.03579841536139289, 0.06674721837043762, 0.012039679812357552, 0.1284860909706162, 0.026417661067699234, 0.024132709987761996, 0.032249168312597665, 0.0983145914130634, 0.06359236487638086, 0.04093763193175678, 0.033927237945458585, 0.12228835539351549, 5.2469055498799975, 37.75338165221676, 40.56328919626052, 34.033225351764315, 28.87003298728697, 31.844809516783688, 41.0105452998992, 48.291370407227554, 9.315003541208084, 0.10356633863862484, 0.3462088306344325, 2.296681586773165, 1.4016883988534252, 1.0771548002958298, 2.8348604373393522, 22.738940869608236, 45.67036028831236, 51.48856885971562, 51.5201243277519, 51.96707840888731, 54.14606486597369, 51.03951238816785, 50.48022554766748, 52.44847090013566, 51.25998489318356, 51.72788050866897, 50.38288800947128, 51.45793514866983, 48.384110927581794, 48.28396497234222, 48.25873628739388, 48.07316895454161, 50.74071015081098, 51.285892148171705, 49.650926666875044, 50.0354209253865, 47.6373230257342, 42.710237733779415, 38.33808937380391, 38.45539962091754, 36.73485586720128, 36.84479205839096, 37.31494695909562, 41.809453656596524, 44.86459562855382, 42.669962836850075, 43.69494876553936, 37.81488441651867, 36.80697256518949, 38.058679334578976, 38.103198236034764, 38.20480723534861, 36.839073242679724, 36.80880823443013, 36.77824904841762, 38.07541216573408, 46.62658314551077, 52.52775376842868, 49.74453010866719, 51.66296135994696, 50.44653631025746, 52.93017325862762, 49.14883975059756, 47.09085056858678, 46.473936265514745, 47.293672407827074, 49.55602884292603, 52.40379118150281, 45.956991411024525, 43.00807899044406, 50.672209878121656, 49.854038761508086, 52.73817716106292, 50.62395295789165, 50.295944752231726, 51.099426592549975, 50.524650312239125, 49.7068125970902, 48.193777914970156, 46.849573812177105, 42.83479652097149, 36.43408460001792, 34.84141403628934, 36.12251897012034, 37.4053575915675, 36.638863701974195, 36.914343526286466, 40.63058137893677, 37.46285953829366, 37.861509630757, 37.81618664341588, 36.208634607253536, 38.011524600367395, 36.997152605364406, 37.793660471516276, 38.12156277318155, 36.71451837785783, 38.26880462708012, 44.036473458813084, 48.90381320830315, 48.367174133177734, 50.02038255814583, 48.185897873293975, 50.459327159389375, 51.912761426741085, 51.34228406413909, 50.006258103155325, 47.625010705763295, 47.82980549720026, 53.20149537055723, 51.655712819868526, 51.04315627005793, 47.06654756299911, 41.45423204668107, 39.45211702777494, 42.17635608488514, 46.81339386970767, 49.29237888705347, 51.36329227878202, 53.99126852712324, 55.207438622751546, 51.39496541792347, 37.163990620643865, 13.35518406283471, 1.5532186290910168, 2.452925035069066, 4.943956386658454, 5.317755322302542, 5.93529426282452, 3.843187079314263, 0.15239788609887325, 1.481464260047482, 17.067709392116917, 34.452828745688166, 32.09005963417792, 36.84945183415567, 43.893989439933534, 27.891297686484556, 6.876182613834259, 0.1857528946692905, 0.025087146373886256, 0.0169748057716436, 0.05580506580431135, 0.03861040237449831, 0.0473773057362245, 0.011247362952769525, 0.08375107611138975, 0.06025355451950624, 0.08929189129341995, 0.00020789800821089999, 0.0910788526638381, 0.03155457554385066, 0.049758284022250486, 0.06480059661572019, 0.04330565567098318, 0.03712166754168369, 0.004730724124988962, 0.037307267663099115, 0.01849385661884181, 0.015211527051794675, 0.05459879525005818, 0.07681785782258357, 0.021747407135403445, 0.028413519293310183, 0.01639908112044777, 0.05749506342615332, 0.042702246517423666, 0.0065092297999428655, 0.04833537146389004, 0.022095163172531514, 0.022427938360300277, 0.04224077047359559, 0.08161451817760546, 0.0060097395157020905, 0.02958839556442634, 0.5520476773381233, 10.257466723842006, 45.33848462566253, 46.409840814528934, 31.299217631739957, 32.55410152096903, 41.721059122393214, 47.715056557809156, 53.04286295367826, 8.908205705304301, 0.10325209703296424, 0.9759871289134027, 5.368339678933544, 3.894090128521766, 2.372277427104212, 3.3150264524644424, 24.225734895275487, 45.54709588327716, 51.09969723609186, 51.695940648355794, 51.70341276353406, 53.339264700489665, 51.29794559171123, 51.46275574161161, 51.85597335138629, 51.7293200185222, 52.08276871711978, 51.44328901844641, 53.061180422382975, 50.56361121516074, 49.34049067958709, 49.894262667625185, 49.15138929120956, 52.012279802753085, 53.564416593120946, 52.74140919408491, 50.784903495542466, 50.328398443037464, 45.601016706035985, 40.58637626709477, 39.50924634933472, 37.64188828006868, 38.93890234731859, 39.447578845485566, 42.31027364730835, 46.60837158080071, 43.79546342357513, 45.50455777875839, 40.81550544308078, 38.76086596519717, 39.06492025621476, 38.182402656924346, 39.71383717752273, 39.110380526511904, 37.00506794837214, 38.930155461834325, 40.38227965754848, 47.7115225022839, 53.026989121590894, 52.49245243687784, 53.17766697176042, 53.02915819229619, 54.066758463459635, 49.877200357375614, 50.187569664370635, 47.79586522809921, 50.84665336916524, 52.366489441164084, 54.266595378998794, 48.667011876260084, 44.36982393264771, 52.662259686377745, 52.241746302573915, 54.69396506586383, 53.09166116099204, 52.558120758302756, 52.11925852683283, 53.74495152504214, 50.90799139391992, 49.329217787711855, 50.18101146144252, 44.72484550168438, 38.38146294316938, 36.30330885610273, 38.551179978155325, 39.015000251031694, 39.02565340841971, 39.235064829549486, 41.72409503690658, 39.63771966195876, 41.41307461646296, 40.66190150476272, 37.853778639147365, 39.711028760479344, 37.85802656604398, 38.75437444256198, 39.40494268171249, 38.74974212338848, 41.035440583382886, 48.05806390700802, 52.475276377893266, 51.74659805913126, 50.593299634995006, 50.516460403319336, 53.12972776351437, 52.71625111179968, 52.21350915970341, 51.23151240810272, 47.96657070036858, 49.09467574088804, 54.02949202445246, 53.77293763622161, 51.94102994857296, 49.447061477168916, 42.55125622595511, 40.976397145179014, 45.44249411552183, 51.17235129879367, 51.49780211910125, 51.62036049750544, 53.73534171811996, 57.0865559577942, 53.71651826366302, 40.846464710850874, 15.37876425250884, 2.565728233706567, 3.2835026085376744, 6.585993411079531, 10.186767962671096, 6.112879572376129, 3.4464574773465437, 0.11680937882873321, 1.1366931925858221, 20.85983334049102, 40.18249765519173, 32.015989595843905, 43.79054084900887, 50.57100488293556, 39.927582817692915, 8.073314014942415, 0.12493588631191563, 0.016936507121089007, 0.12496250786728437, 0.0794335118224544, 0.10441373913518845, 0.048127397744646, 0.041560714223211816, 0.027265237764485424, 0.06890808427405935, 0.009761007780569696, 0.01913466235442508, 0.04058235865687171, 0.06340429412140962, 0.032230655797907425, 0.04870804642597514, 0.022976252385565353, 0.2912093254347002, 0.13194759796944358, 0.15148253360342595, 0.17591640233032166, 0.17651980382300195, 0.141935208812356, 0.1496569460798656, 0.07655987771408213, 0.12041776786528288, 0.09686287011831038, 0.20379311615420928, 0.1249002479016781, 0.3018057923163137, 0.13266713839144478, 0.11089010855122922, 0.08613510342735438, 0.18931276735759553, 0.1777629959847658, 0.14128280833603876, 0.0751935062749732, 0.7840322162355147, 12.18196980414852, 52.43169492290866, 53.73534564049014, 45.17423929706697, 42.36119385688536, 44.29524006382112, 51.73645480986565, 57.98325292525753, 11.972527004057362, 0.21461873525573363, 2.7993651936131143, 9.606432703233535, 4.712675300336653, 3.2817456318486125, 5.398360029343636, 26.376548928599206, 49.71209995208248, 51.012032262740604, 52.25563933772426, 52.224221152644006, 54.28079435902258, 51.05741800800447, 52.05234681406329, 51.555253075015166, 53.127131154460294, 52.81702856863699, 51.71306571652813, 54.495795157647905, 51.114366900536325, 50.88752838873094, 50.72166704362439, 51.98740413112026, 54.07978857717207, 54.26732101748067, 54.97785837419572, 52.629527507289765, 51.368167784906205, 47.40178861925679, 42.10818529129028, 42.48306189813922, 39.9899406586924, 40.76879393669867, 42.242279360371256, 43.89713125844156, 50.85716924359722, 46.4626359170483, 48.692417067866174, 42.02248542539535, 40.09180853443761, 41.69095885369086, 39.9221150336727, 42.865551825492616, 40.123834686894575, 39.161955771907685, 40.38994396886518, 41.978123418746456, 50.273591164619695, 55.240170801839525, 54.06345582777455, 55.35502564522528, 55.126873139412176, 57.168659010241115, 53.56731522467829, 49.880781481342936, 49.26232176442301, 52.61079818971696, 54.55687430597121, 55.39870515946419, 51.70678600188225, 44.158219906591604, 53.570084418019945, 53.6362430357164, 55.385722114193825, 53.83786855205413, 54.75746431658345, 53.714584535168065, 54.68912486107119, 51.90077466349448, 50.719097891161525, 51.74181276752103, 48.33430467113372, 41.12412537297895, 38.568477630615234, 39.87261864446825, 40.732115853217344, 40.253786733073575, 40.217932347328436, 44.689053873861994, 41.598135963563, 44.22046792122626, 42.52117164673344, 39.411312610872336, 42.06131296773111, 39.67858683678412, 40.7076245738614, 41.02222611827236, 41.400385748955514, 42.80931680433212, 48.66028108904439, 55.24331654271772, 52.187260658510276, 54.006518702353205, 52.884540404042895, 55.89178239145587, 56.527947687333636, 54.10979078662012, 53.25180761275753, 51.01201265088974, 47.67840985328921, 56.60617543805031, 56.007974763070386, 53.79351046777541, 50.39455706073392, 46.09754954614947, 44.0333826311173, 48.6088627384555, 52.26221715250323, 53.826807468168205, 53.666460975523925, 58.329237353417184, 59.716493391221576, 56.51674147575133, 42.46564657457414, 17.013933697054465, 2.9412897844468398, 7.554737454460514, 13.423049892148665, 15.02019097728114, 15.97261796074529, 9.089499615853834, 0.42001674432427655, 2.0155759804671813, 24.553021384823708, 48.01980118597708, 42.56997769878757, 49.06853314368956, 57.01769482704901, 45.35854754909393, 10.488398228922199, 0.24088612817708524, 0.09935895311495951, 0.1449878546859949, 0.16480366879653546, 0.16529588028788567, 0.1511151638002165, 0.21756618193561034, 0.227134037883051, 0.13373888007575466, 0.23898952430294407, 0.13899545365523908, 0.12874836883237287, 0.1310318164647587, 0.17708036567895644, 0.1494251431957368, 0.1240670047099552], [0.02458706715955369, 0.021566520369942152, 0.059345705855277285, 0.008269455659413531, 0.024240431526014884, 0.0319382285458907, 0.05260132440936662, 0.013636059574632636, 0.015001051097867951, 0.08049115748895753, 0.03962857153026327, 0.05010511117777036, 0.06268078153352104, 0.07761991357490902, 0.04553502132635444, 0.012640405742962275, 0.10531870347838249, 0.020472002891643394, 0.04793031396524561, 0.08847003216825186, 0.06816171545294986, 3.479008737110323, 34.72968139956075, 47.94693923765614, 34.95405666289791, 21.663374016361853, 40.225686873159106, 39.517200916044175, 50.54523098853327, 12.107694821973002, 0.14675428490004233, 0.7527309668160255, 2.4229934282841223, 3.8404531873041585, 9.22683552388222, 11.29965126514435, 18.746909403031875, 48.61047091022615, 52.50916565618208, 53.217051490660644, 53.39160873043922, 51.55461765104725, 50.48308103315292, 51.82357457376296, 52.373981168193204, 53.280840996773016, 54.1468571847485, 54.3755352881647, 49.58295983652915, 49.53173760444888, 50.29945919590612, 50.22618147634691, 50.86574746716408, 52.989087258615804, 50.726675910334436, 48.35641899416524, 46.49283816737514, 43.02698481467463, 38.140849067318825, 36.93761887088899, 36.75606020035283, 36.94753462268461, 34.72443326827019, 38.8279345727736, 40.70627527852213, 43.18486413648052, 43.09057820227839, 42.09428048902943, 38.873441911512806, 37.40203534403155, 37.37896004030782, 37.03378754277384, 38.302815498844275, 36.75123960741105, 34.16138487477457, 37.41519489595967, 36.433908093360166, 43.22590389559346, 51.364637651751124, 52.37022353756813, 51.41871929168702, 53.812353534083215, 51.062611226112615, 50.38575526206724, 52.35735816340293, 45.52367148860809, 49.159281099996264, 48.3531948058836, 52.36242978803573, 45.04173771027596, 42.87903693414504, 49.4740120826229, 48.69737102139381, 50.952286720275886, 50.37594541426628, 49.92885405017484, 49.86080485005533, 51.52684727022725, 49.79434813222578, 47.03675716154037, 45.590265489393666, 43.50368615119688, 35.85051044341057, 35.17730620599563, 35.48327069128714, 36.37549615675403, 36.89895606810047, 37.96228708759431, 38.416650525985226, 37.56331143840667, 38.78619663176998, 39.08012728537283, 38.25145990617814, 36.96867227554321, 36.95353977141842, 37.660699967415106, 37.72436788005214, 37.00757826528242, 35.64657857341152, 36.878685259049945, 40.66685153592018, 44.5029648657768, 45.248038691859094, 46.458384067781516, 47.267196409163944, 47.36144704203452, 49.08239479987852, 50.28762932746641, 51.160023289342085, 49.70757353690363, 47.60606565783101, 53.38592913842971, 49.79217121678014, 51.394784988895545, 47.96586859610773, 43.6722303975013, 40.810967260791415, 45.00704434610183, 45.86682396550333, 51.89240824791693, 50.19677546716506, 56.58330017520536, 50.19550069685906, 35.30150021276167, 8.888607582738324, 1.5904192458237372, 2.754128498415793, 4.955497470594222, 7.964111306974965, 4.575394305490679, 1.1263322517756493, 0.049513675978467356, 3.523150845881432, 29.814380868788692, 37.40167840834587, 20.637942898658014, 35.414036935375584, 42.85201964839813, 18.457252171731767, 3.2778230165281608, 0.049422484702400626, 0.10310552143041166, 0.013806389648497347, 0.053156493006334196, 0.013585672056632898, 0.049626386664327116, 0.04828979306283498, 0.052410767699081096, 0.08793371699510083, 0.012016496076549013, 0.07340773234083768, 0.04295081140533571, 0.03040227013820362, 0.06406601405732575, 0.024371072499742432, 0.05845671061486487, 0.02500753451679503, 0.03565950446852273, 0.03289547072903764, 0.03737182206203861, 0.045527199568647536, 0.03845896594406616, 0.0248880650202233, 0.03237009912188495, 0.04074845417973496, 0.03328211913486162, 0.03678194968210113, 0.01169252994229957, 0.033443231255777424, 0.037639619587289716, 0.032386271237966516, 0.05015355474766224, 0.031019304165496465, 0.05309099631924784, 0.027871812776392026, 0.01629580863781514, 0.1148767228568754, 4.864130270096564, 42.93903350830079, 53.06252971772225, 41.704530254487075, 27.498584101277014, 42.955017166752974, 46.28421122027982, 57.54263347195041, 13.151545390006035, 0.15324600671808566, 0.5421127427008845, 4.510602633799277, 7.1528058090517606, 8.881058000749158, 12.282210876864772, 21.31300633953464, 50.659179764409224, 51.71063384702129, 52.68267562312465, 51.065498090559444, 51.54103840551069, 50.16572598488101, 53.4943748289539, 53.200259823952955, 55.573093737325365, 56.46717448388377, 54.73008225041052, 51.26877100236955, 51.69927858537244, 50.457597394143384, 52.041140602480986, 51.472644036816014, 54.51947842874835, 50.81301512256746, 49.59777070629982, 47.91132019412133, 45.67906010535456, 40.554495242334184, 39.147694033961145, 37.76660396206764, 38.77662604854953, 37.55543924147083, 41.31087333925309, 42.83235288435414, 44.4413758093311, 45.04874306340372, 44.33412644170946, 40.22435718967069, 39.12857640174128, 38.52214267176967, 39.2577753528472, 41.17559471438008, 38.35854453425254, 36.24013123973724, 38.65411473858742, 37.554733214839814, 45.41309595108033, 51.85807966416883, 52.658494211012325, 51.81888734140704, 52.98900488884219, 52.553653178676484, 51.81419618668095, 53.68417047685193, 48.32830344477008, 50.203204231877486, 52.11972136651316, 54.133062208852465, 49.098394147811405, 45.05362641426825, 48.90245214585335, 51.293646674002375, 52.31351783198696, 52.19209694093274, 51.37294915414626, 51.97078504870015, 51.99417414203767, 49.32083176028345, 48.93151298646004, 47.3995764024796, 45.37639433337797, 36.705842095036665, 37.094976517461966, 36.81100476172663, 39.563131870762, 38.11795419262302, 39.131541713591545, 40.07731929902108, 39.61345588007281, 40.140363554800714, 40.04750144097113, 40.76793886000111, 39.35776833565005, 38.59119207628312, 39.40170280395016, 39.89034775764712, 38.13841327544182, 37.084103707344305, 39.07792683570616, 43.66395811880789, 47.05310560041859, 47.58792861815422, 50.00131591673821, 49.775830622642275, 49.93552600183795, 51.22147506283176, 52.28826953518776, 53.106252378033055, 48.32248264743436, 48.85519150764712, 55.08974398336103, 51.57158974678286, 54.82760021763464, 49.67156617872177, 43.65021413372409, 41.573660373687744, 46.1067553489439, 48.734402118190644, 51.874981157241336, 53.747991361925685, 57.841369029014345, 53.56141597993913, 37.532073682354344, 10.891729670186198, 0.9481853691320267, 4.561423803529432, 8.183072228585521, 8.077972319818313, 5.234587346353839, 1.6752044640241133, 0.05382567463863281, 3.3771055600335522, 28.892678791476836, 38.02151095482611, 27.805650772586947, 40.52806238974295, 49.980856833919404, 25.277573370164443, 4.695446289354756, 0.11175473836520988, 0.08683009073138238, 0.028743074996577158, 0.03575702746128363, 0.03819206474168647, 0.04675996910420157, 0.031078354222700003, 0.05767355042119181, 0.0266109986771499, 0.04915713099762798, 0.06458889587872452, 0.05829927571598561, 0.11729147029860366, 0.09069903393185909, 0.03716451100884907, 0.019120413119033463, 0.056458952491201704, 0.13458122439201803, 0.10802932939822636, 0.11192257290766125, 0.1167649916944004, 0.10039570756376752, 0.10268835591212397, 0.09072304312740603, 0.1251212106416783, 0.1631176471710205, 0.11652905959635974, 0.15481290167137501, 0.08782578286744895, 0.1421475377414496, 0.09222499680735412, 0.09487441996292723, 0.2933810927694844, 0.1585522840820974, 0.25629995510943476, 0.12402369775959562, 0.20995880627343733, 6.360345828917719, 48.88940242029006, 60.25457197620023, 46.25836280084426, 33.28798678613479, 52.43526427976547, 48.81807411870649, 60.625553669468054, 15.671607428981414, 0.4034393983742883, 2.324922161717569, 8.561255393489715, 7.535010874271394, 15.604114224833829, 16.18506137401827, 25.60915485505135, 53.533826028147054, 52.865611045591294, 53.96235281421293, 52.92468194038638, 51.709272784571496, 49.93706749331567, 54.11281885639314, 55.13363530558925, 57.62895307233257, 58.31341451214206, 57.57927233173002, 53.4563474501333, 53.62541337167063, 51.518014092599195, 55.69337714102961, 54.21103108313776, 58.26342782666607, 53.90230524924494, 51.24114574924592, 49.60362288259691, 47.549132454779844, 41.34921450768748, 40.89852633014802, 40.38943013837261, 40.71948582126249, 38.409856980846776, 43.76517095873433, 45.446781266120176, 45.762802708533506, 46.7509340470837, 45.75465202331544, 42.284515442386756, 41.05868062665386, 40.49617352024202, 40.66758894151257, 41.85502375325849, 39.59397738979709, 37.08365655714466, 41.40684589262932, 40.16018329128143, 47.79106424700829, 54.94983303931452, 55.27560549397623, 54.17126217196065, 54.54591912607993, 54.48467916057956, 53.81646417802381, 56.682555752415816, 50.50177504939418, 52.36190026806247, 53.35908835934055, 55.66251201014365, 51.60598893319407, 45.304250178798554, 50.56646670064619, 52.74186811139507, 54.39311142890684, 55.9407727949081, 52.94419965436382, 51.520006656646736, 53.29532630981938, 51.28299351661436, 50.64560051887266, 49.75738371572187, 49.05098053716844, 39.202442476826334, 38.59935452861171, 37.62462592894031, 40.288962548778905, 40.68293325362667, 41.37459224270236, 41.52372467902399, 39.800843192685036, 43.584867446653305, 42.96002603346302, 41.712822145031346, 41.766876328376036, 39.859282585882376, 41.848030167241255, 42.11867370913106, 41.71344972425892, 38.45084574914748, 40.8183648509364, 44.03134692099787, 49.29011567946404, 49.40966559994606, 50.95809575050108, 52.06374129941387, 50.76693511778309, 53.66832802372595, 54.267415154364805, 54.31225176780455, 49.94440624790807, 50.3444605488931, 57.5610254656884, 53.15045748987506, 56.32881287605532, 53.59344997713643, 48.22675328100882, 44.65347013165874, 50.01084727625693, 51.143357138479914, 56.607693395306995, 56.67231052152572, 59.97646808624268, 53.90788285962997, 41.197089302924375, 11.810659612378767, 3.2172537763272566, 7.4037977860819915, 13.940041815080951, 17.087017259290143, 12.25493569527903, 4.7811137956957666, 0.11083234552173846, 4.463562138618962, 38.626685603972405, 49.43595724721109, 32.164100254735644, 48.71586107438611, 55.55321908766224, 34.32038207207957, 5.296227393611785, 0.2707198748905813, 0.25494338193487737, 0.2845689672375879, 0.1564294697656747, 0.21680219309224238, 0.14735243102956205, 0.12764520988228822, 0.13507902832521548, 0.11348674058794014, 0.07696349879786854, 0.21464525721967223, 0.12565135114615963, 0.1772930163649782, 0.21863511973811736, 0.17632645855267204, 0.13820057614676415], [0.08244018475975722, 0.05106567435206906, 0.015261071873077703, 0.04480440327296815, 0.02231290259759032, 0.02177519505963691, 0.04043279148097481, 0.03523915202447003, 0.08753733544219887, 0.03577188190613543, 0.02106812080338357, 0.03240894744052522, 0.07832835338288739, 0.0181674801804606, 0.04364716234586893, 0.06180544564079854, 0.08727307341271832, 0.027228093991476684, 0.03190014823039453, 0.03808369394391775, 0.05872496396243092, 2.803863907052625, 21.53633629122088, 44.01916403924265, 38.45880816059728, 22.402717259622392, 27.065589735584876, 31.125676285836008, 45.84881636404222, 23.29729026363742, 0.6499304249882698, 1.272125770488093, 4.04322624206543, 9.357824056379258, 9.036209314100205, 10.832120430084968, 24.58509852809291, 49.19039726257325, 55.29452308531731, 56.940620253163004, 54.1437114438703, 53.12182810998733, 57.09306316991007, 55.437387574103575, 51.92723105030676, 51.52955370564615, 51.901390475611535, 51.79802033209032, 52.49723772848807, 51.78841836990849, 53.42984399487896, 51.11683014900454, 52.61286527879777, 49.92589266069474, 48.92736311881773, 43.7443902415614, 41.31566255323349, 35.775448045422955, 35.71844423970869, 36.483867322244954, 37.47031596399123, 36.901827243066606, 35.76586961746216, 36.98035309391637, 41.998500131791644, 44.063565269593276, 43.960006852303785, 40.30258886275753, 40.794728648278024, 37.10079339242751, 37.16992516671458, 37.37218218465006, 38.28139935770343, 37.258731549785985, 36.51423038974885, 36.1088808890312, 35.4721115481469, 37.1522117430164, 47.925107325277025, 49.303243852430775, 50.654523911014685, 48.45907134394492, 47.59980163266582, 48.93909492800313, 54.146610075427645, 49.790092360588815, 50.59614335336993, 51.0447330628672, 53.01622221546789, 45.42369027291575, 43.76939927378009, 47.29009128385975, 47.35151952312839, 49.61599796049057, 48.03770288344353, 48.84435399886101, 49.54392048620409, 49.25628523672781, 48.73786164868263, 47.56434340630808, 44.3167228852549, 42.371517535178896, 35.301664952308904, 35.634925211629565, 35.463078329640055, 37.19088631291544, 37.49284213589084, 38.22900041457146, 37.218868501724735, 37.101628857274214, 36.93583419246059, 38.12791309049053, 37.97421501528832, 37.73625266167426, 37.62337469285534, 38.056553409945586, 36.33103609085083, 36.6333802284733, 36.512998765514745, 35.50373761884628, 35.38707456281109, 37.2420104857414, 38.93697254119381, 40.46042111612136, 41.40891298171013, 43.20331496577109, 48.48554342023788, 48.064025909669944, 50.43499277484033, 51.432471121511156, 48.48257418601744, 51.71371290760656, 53.48481993521414, 50.63775577852803, 50.741918240824056, 49.80234584500713, 49.44807344867338, 46.70384207079488, 47.7270786223873, 49.998130952158284, 52.27244277154246, 54.39477059148974, 43.05683797405612, 24.71788448672141, 10.879586012132707, 0.34109926932761747, 3.301142978091394, 5.4318992360945675, 8.502814039107292, 2.437640048803822, 1.2599563718803468, 0.06219913822508628, 3.0282712847955766, 32.16918364647896, 35.61916120590703, 25.7551533176053, 40.16640417037472, 40.140363554800714, 17.87874963975722, 0.9973101750496896, 0.0669253644563498, 0.038485150829318075, 0.030419106835559494, 0.025384399979825945, 0.023815725787332463, 0.051317000986948136, 0.054252305173224984, 0.016494047294761387, 0.026116172910758087, 0.05099353568267919, 0.027457311328861023, 0.03586031526567475, 0.05323952544600733, 0.04187083427583979, 0.014837170526715777, 0.06264718857804133, 0.04300558669192176, 0.011295438800457747, 0.04172963661051566, 0.06055951471470537, 0.056074537231677005, 0.05371156584231123, 0.011983511203359212, 0.046531533176499995, 0.03030841670660002, 0.03952160650383561, 0.04669102119101633, 0.05872885951952589, 0.016825386067672123, 0.04007880523380253, 0.026294803547282374, 0.05202400054962886, 0.011671970057631693, 0.04494637085665618, 0.07524842711826486, 0.005187047269916343, 0.037301499021029284, 3.9839604545024137, 29.25968908494519, 53.37535050607497, 40.8201220727736, 27.379546050102483, 38.17394210446266, 37.50882579434303, 51.30309958611765, 24.146057828780144, 0.5130135057674301, 0.8974332698891241, 4.34844155465403, 10.82482482156446, 12.276818598470381, 13.790399470636922, 28.945154220827167, 49.04707777884699, 54.41215061372327, 56.064170560529156, 55.510520165966405, 52.48562359040784, 56.80480034120622, 55.392731389691754, 53.49102904719692, 52.868458686336396, 53.78340644221152, 53.38178319315757, 53.57697210004253, 52.81838178634644, 53.89242872115105, 51.997857247629476, 54.186582949853715, 51.09557482504076, 51.138736586416925, 46.64268055269795, 43.34906631900419, 38.904448247724964, 36.43686163809992, 39.01529050642444, 39.03946407379643, 39.02461790269421, 36.68838362539969, 39.097683814264116, 44.60392667401222, 45.463541553866484, 45.64671231854347, 42.87713850698164, 43.231352067762806, 38.86493036823888, 38.55140747562532, 39.2290832150367, 38.70873374323691, 38.25633148993216, 37.52804933055755, 37.0554978616776, 38.02993620595625, 39.83645046910932, 50.344617443699995, 51.54838892721361, 53.22308409598566, 49.23501814565351, 51.22482476695892, 51.81001101770709, 54.490731377755445, 50.69113139183291, 51.6605334128103, 51.664808796298125, 53.276757809423636, 47.90087099998228, 43.921430341659054, 47.71104789549305, 48.49470999933059, 52.42113590240479, 49.84946527788716, 49.34630755455264, 50.22842899445565, 51.853023729016705, 49.64293287646387, 50.9058968482479, 47.06347242478402, 44.178184770768695, 38.372574852358916, 38.06330380901214, 37.84594958828342, 37.836594735422445, 39.39679199649442, 39.17305607949534, 38.82673432750087, 39.158284433426395, 39.211750261245236, 40.12969078556184, 38.964958652373284, 40.29636798366424, 38.805067154669, 39.969869890520656, 38.55195660744944, 38.7502637986214, 38.824628014718336, 36.57603909892421, 35.72482985834922, 39.387515591036895, 41.19969767908896, 43.49026772283739, 44.765081174912, 46.03916506613455, 50.84326051896619, 49.744149638760476, 51.67687792931834, 53.122008539015255, 48.052419616330056, 51.06781621133128, 54.17365089539559, 53.53106860191592, 51.92208097827051, 50.73146904668501, 49.365103552418375, 47.90123970277848, 49.19717119586084, 52.02632973271032, 54.155560924160866, 56.51086184286303, 46.45819971638341, 29.745998267204534, 12.933400811687594, 1.6894779690811712, 5.084600323630918, 9.49047371264427, 6.442378768997808, 5.871567514634902, 1.2617486499009596, 0.09388662619335998, 3.4519867935488304, 36.084232714868364, 42.19439898767779, 25.8844679786313, 42.659725450700336, 46.137016434823316, 23.91361032762835, 1.5303126001550307, 0.09275176652496861, 0.01861204100292056, 0.014512222842313351, 0.01924387201847088, 0.052334201041488886, 0.0480831561670188, 0.04148596319400015, 0.024947812217437935, 0.01575110767472295, 0.048502570153364254, 0.07122463456565334, 0.035234157131203724, 0.0055205497624082195, 0.027289555310421897, 0.03227316218638613, 0.020055132317206553, 0.16923207068635573, 0.17065555398021975, 0.1767439611496464, 0.098040584745186, 0.09391089585880119, 0.15109305450272176, 0.16880421058064507, 0.18068917606386448, 0.168206462816846, 0.1064648093175023, 0.24824328420142977, 0.24500302339513458, 0.10239419347095875, 0.18458191395526935, 0.17900580510256753, 0.18008911471453407, 0.2376841717670041, 0.22159951228287914, 0.15609231447019886, 0.13291469204329676, 0.17447117746116655, 5.339647541123052, 33.326841785061745, 58.613518976396136, 49.613824967415106, 36.279872694323146, 39.2609485503166, 41.61841461735387, 57.75901102250623, 29.31161734365648, 1.25975277635359, 2.030811446809, 9.031961387203587, 19.585959296072684, 15.20384027111915, 17.83818448743513, 32.70037847180521, 52.92332480030676, 55.793629000263834, 55.97290485135971, 54.038356581041896, 53.88796898626513, 56.84751887475291, 56.666960408610684, 55.23354591861848, 55.48121613840903, 56.04016957744476, 55.475340427890906, 56.81301378434705, 54.21023091962261, 57.202536521419404, 54.169308831614835, 56.26550974384431, 55.0172350483556, 53.97696756547498, 48.046677266397786, 44.34508162160074, 41.131499428902906, 38.25174623920072, 40.79081020047588, 40.33373640429589, 40.618798578939135, 38.21839040325534, 41.17935626737533, 46.681543396365264, 48.018616630185036, 48.6466783092868, 43.9208576756139, 42.75601571606052, 40.72429856946392, 41.57087156849523, 41.00915285848802, 41.02284977512975, 41.578025971689534, 38.819709362522254, 39.99655769717309, 39.769981984169256, 41.788755309197214, 51.38703830780522, 53.51024473867109, 53.52176081749701, 51.76305240200412, 53.39336202990625, 52.8028452780939, 56.621959055623705, 53.94086607040898, 52.634073534319484, 53.972574510881984, 54.60724146135392, 49.252409934997566, 45.15120713941513, 47.88444803607079, 49.48349637369956, 53.21210145950318, 52.177458655449655, 51.563674403775124, 52.788607074368386, 52.49714359160393, 52.79965246877363, 53.356629033242505, 49.125101566314704, 45.788388329167525, 39.53962118394914, 39.46288001152777, 38.579275915699625, 39.17532320945494, 41.815513718512754, 41.61281739511798, 40.9190167919282, 41.904276955512266, 41.1820391685732, 43.20493882702243, 42.124047356267134, 41.390238577319735, 41.366261128456365, 42.50514876457953, 40.3770197591474, 39.879843650325654, 41.476491497408965, 38.72967135521674, 39.119951109732355, 41.70414978458036, 43.20898279067009, 45.41161329515519, 47.213550152317175, 47.065417920389486, 52.95782204597227, 52.77408645999048, 54.345231056213386, 54.46983298947735, 49.23162137308429, 51.38553604002922, 56.5927020965084, 55.55376037474602, 55.02704881852674, 54.521019920226074, 53.206002173885224, 50.375337446889574, 53.140981043538744, 54.02934297438591, 56.47338751823672, 57.87360698946061, 48.03175264789213, 33.954020930874734, 15.271306018675528, 1.4150287475316756, 7.700279451185658, 12.969641550894707, 18.509205925849177, 10.132614739479559, 3.52295448222468, 0.34009719567914165, 3.9923229477097912, 41.269441343122914, 48.83050018741239, 36.67801680103425, 49.13082038202594, 52.71207770993633, 30.903342616173532, 1.8456201711969993, 0.2322521027658255, 0.13252905870397247, 0.09191124549796505, 0.10808091009816817, 0.1808764385960756, 0.09451152411319556, 0.12422652719842812, 0.08469236068307393, 0.13616077511781646, 0.12798416548438613, 0.23194160733011462, 0.10427457160286366, 0.11601592624379743, 0.23274434490069268, 0.126063552414698, 0.12992532503220344], [0.10788346625744336, 0.03326439186029377, 0.033409205460620504, 0.06591498641477478, 0.041153902383220774, 0.024434496918993614, 0.05174547779343782, 0.04065041024718554, 0.02427133742810017, 0.03158485708427766, 0.03274873041758134, 0.018466583888737426, 0.038695943752123464, 0.03782108283391403, 0.04148764858743356, 0.07558048792904423, 0.030548079652831923, 0.040780863529371644, 0.041857703528817625, 0.03712646325208968, 0.09407173601850387, 0.5787194267876687, 17.55620333456224, 40.8930036329454, 48.60636026628556, 38.002663966148134, 35.98118812807145, 40.389763539837254, 46.74979263736356, 32.796354947551606, 0.8047999405572492, 0.4981634735820755, 5.143188276598531, 10.08921371352288, 4.3327153017444, 7.385930899650821, 22.497824930375625, 44.66999115482454, 52.870992537467714, 52.395605194953184, 50.27741155316753, 55.85035824006604, 55.46498537063599, 54.17664758620724, 53.25154089158582, 50.22054503040929, 48.08130395027899, 48.78015656625071, 50.22214927980977, 50.96563846834245, 50.74563272537724, 50.36185233823715, 47.198252908645145, 42.62600483432893, 39.12499135540378, 38.455372164326334, 36.5084566608552, 37.13709492837229, 37.9369132749496, 37.63467896369196, 36.964043878739886, 37.0195964074904, 37.1104149664602, 38.64916078505978, 39.336422797172304, 39.926335503978116, 42.99184037793068, 42.42483039056101, 41.81651784527687, 39.824416637420654, 38.42281256952594, 38.96695513879099, 37.63088210936516, 35.53405754027828, 38.052689875325854, 38.84888395186394, 35.291839415027255, 37.210376570301676, 44.685523740706905, 47.652659493107954, 51.08867929827783, 44.459854095212876, 47.47594102736443, 49.02412014622843, 47.882553531277566, 50.893098154375636, 51.54185033613636, 49.389920388498616, 51.42388897557413, 45.09277951332831, 43.110794098146506, 46.641107682258856, 44.96869141055692, 47.45396006491877, 47.967343407292525, 48.44908891185638, 51.199854958441954, 50.82115011830484, 49.23117422288465, 48.668686728323664, 43.301503658294685, 41.10378396126532, 37.174459426633774, 36.9221451205592, 36.65085046522079, 37.192086558188166, 37.07996168444234, 37.65311802587202, 38.62952147760699, 42.14085471245551, 37.19682085898615, 40.02115488052368, 38.74186992645264, 39.129082387493504, 37.68614438272292, 39.878149186411214, 37.32552559145036, 37.56285644346668, 36.69512225735572, 36.52167504833591, 35.722284240107385, 35.66877134384648, 35.396103858947754, 36.22812878700995, 35.78776036539386, 38.45263042757588, 43.47255822150938, 45.87871659186579, 47.68267739203669, 48.91277582414689, 50.36311141906246, 47.50402519779821, 49.223549135269664, 52.00849079316663, 53.13577605832008, 50.53677828081193, 49.91937760383853, 50.2203449895305, 51.66032944956134, 51.86865045178322, 57.51538868873351, 55.35593955747543, 40.86459782815749, 13.097492187253891, 3.6561302263890547, 2.5420226541257676, 7.823516399629655, 10.538089756042728, 3.1276648804064724, 4.529512380400012, 0.7941230650871032, 0.03262402279482734, 4.190411221596503, 29.85401838056503, 26.699746347242787, 27.782536245161488, 48.364950149290024, 41.37986783058413, 11.369085061934687, 0.2481348367948686, 0.06607528265205122, 0.08502199299513333, 0.025575738099794236, 0.050100847898471745, 0.023891553170077746, 0.08386993465284187, 0.06219657183053994, 0.017842815948590156, 0.05845728518080808, 0.03192741329961967, 0.06344057221506393, 0.01599829360437129, 0.011225548599125638, 0.04810779738510328, 0.03788412420920307, 0.030354046818589976, 0.08419577482967608, 0.014087590839593642, 0.046704902704204285, 0.052894360701283144, 0.07048778055656342, 0.028742621089482022, 0.06406514071709206, 0.03073176072399703, 0.05464292191449673, 0.01624749913331001, 0.028746311718057242, 0.007509551022291905, 0.030688373334405404, 0.026328499924631852, 0.07400686672377972, 0.05963726359749994, 0.01415285291225319, 0.03906288454609533, 0.02084646283859207, 0.05299586352081068, 0.06802493811494882, 1.6627047283034173, 20.83161580947138, 46.79916743309268, 51.55626504651962, 38.91771762601791, 32.84427650513188, 39.19635888068907, 50.85874211403632, 35.99472030516594, 1.0876757002645925, 0.17145315876170514, 5.597760581201123, 14.022940128080307, 7.1201658056628325, 10.206407270123883, 27.574554527959517, 48.538487572823804, 54.63356448758034, 53.72046809042654, 50.89697345610588, 54.597251184525035, 56.4965412693639, 56.590937029930856, 54.26788191641531, 51.287869022738555, 50.70881343656971, 51.11477874940442, 52.304394398966146, 53.02881302372102, 52.05613190127958, 52.356075548356586, 49.339666981850904, 45.16741437296714, 41.5345621878101, 39.4785185014048, 39.358191951628655, 38.94402888513381, 40.06115913391113, 38.34573407326975, 39.62381878206807, 38.41398331426805, 38.42112987272201, 39.78222762384723, 41.816690429564446, 42.77623161192864, 44.58439719292426, 44.867188315237726, 43.41599372125442, 40.54510901051183, 38.8128020686488, 40.092016420056744, 39.36263599703389, 39.04335114263719, 40.21106035478654, 38.88660930818127, 37.195114627961196, 39.3874292988931, 46.2782492176179, 51.298694764414144, 52.70913200993692, 47.57883656409479, 48.06872883150655, 50.716136501681426, 50.79869062669816, 52.06133296412807, 52.577410974810206, 50.90833656249508, 52.55114678413638, 47.24296400623937, 43.95312701502154, 46.99285407220164, 45.50796239606796, 48.83680735864947, 48.76807174374981, 50.64889923218758, 52.234289876876346, 51.96652535469302, 52.11913693335749, 49.90648477308212, 46.30245416395126, 42.53420568281605, 38.48901825566446, 38.84944485079858, 37.97742743645945, 39.26954246336414, 38.61389083247031, 39.597083906973566, 40.2637299414604, 42.31956574224657, 39.458612472780295, 41.60307814998012, 41.33509005269697, 41.56279148594026, 39.30520857534101, 41.73312041067308, 38.97128543546123, 37.28390532155191, 38.27955584372244, 38.291797561030236, 37.912986816898474, 39.640265280200595, 37.302254169218, 38.53049339786653, 37.44687587984147, 42.62793071808354, 45.67907579483525, 48.68340738358037, 49.386817793692316, 49.91992673566265, 51.75820435247114, 48.11032948955413, 51.0888675720461, 54.787125279826505, 55.059196564459036, 52.17784697009672, 53.478752028557565, 51.61128021055653, 53.05646573343585, 52.90028479791457, 59.397871417383996, 55.560153838126894, 43.29095640490132, 16.24770652863287, 7.72353861601122, 4.916072257103459, 9.989967942237854, 9.080283026541434, 1.3475747670858138, 2.310469698521399, 0.7261642633426575, 0.0850552948372018, 3.841931675710986, 34.036382859753026, 33.29722004552042, 31.416355294566003, 53.16350329306818, 47.30826754723826, 16.966331812643237, 0.41587701968608365, 0.027840355291001262, 0.07505130503446826, 0.07577533473170574, 0.0349566379501935, 0.03874243762824805, 0.02992728030339124, 0.0820816096459185, 0.007353365804339129, 0.03343604918148729, 0.052581061383769404, 0.050887750431654916, 0.028226007782523672, 0.040869519054409, 0.018579269676739653, 0.010075628599752823, 0.017959113841155366, 0.14108915663053914, 0.1161032066410107, 0.17063535990253573, 0.14448226729948677, 0.15309612927657945, 0.12345879984598969, 0.14161660816640625, 0.14377824781883147, 0.10019958139427247, 0.12986377752836675, 0.140194948161802, 0.05496148425605028, 0.11290889578841387, 0.1750599160309761, 0.1752670049186676, 0.11752688145685582, 0.16676774969504726, 0.058773645019579324, 0.12570968108071437, 0.10687255195432133, 0.23174222528694138, 1.974540021150343, 27.383356632724887, 53.534841922021684, 60.85647536862282, 47.91590544485277, 44.987867878329375, 52.92748251268941, 56.37164123596684, 41.218948671894694, 1.672689857021455, 1.142522815254427, 11.369957789298027, 16.85590728636711, 9.981858441906592, 12.612245967311244, 29.80000538210715, 50.19805023747106, 56.35151947698286, 60.04272084082327, 51.908662549911014, 54.910993729868245, 57.46320155359084, 57.21964197774088, 57.34200816000662, 52.887713601512296, 51.11848931158743, 53.279413254030295, 54.22190389325542, 56.1082148551941, 53.965533856422674, 55.193443605976725, 52.57204125004431, 45.75007853969451, 44.36388938657699, 41.095221427179155, 41.16536125060051, 40.15956747916437, 42.62822097347629, 40.04518724256947, 40.74754253510506, 39.65307966355355, 39.604124561432876, 41.946873895583614, 43.36913316480575, 42.815973066514545, 46.47130435512912, 46.64265701847692, 45.93922699651411, 42.9807283032325, 41.94325354791457, 42.90994913347306, 40.68389423431889, 38.87783104373563, 41.041363362343084, 41.96388129265078, 40.049101768001435, 41.56986351936094, 46.39790896446475, 52.486776767238496, 55.45107664600496, 48.595052073078776, 49.24154496962025, 51.11662618575558, 52.039430449085856, 55.27811581088651, 53.1672413118424, 54.066385838293264, 52.372322005610314, 49.0007035962997, 45.54342454479587, 45.79637427483836, 46.69634249902541, 49.71273929842057, 51.007521537042436, 51.18355358800581, 55.46568355252666, 52.94625105396394, 53.68293493024765, 54.19422764931956, 47.03379577206027, 43.594889102443574, 41.592695636133996, 39.22732207082933, 39.604771752511304, 41.36933626667146, 40.630922625141764, 41.23537163580618, 42.81304305599582, 44.76197465773552, 41.668930822803134, 44.76472031685614, 44.98278056421588, 44.31629142453594, 41.203816167769894, 44.29995083039807, 41.85795376377721, 39.35818018451814, 40.22784025438371, 39.379031504354174, 37.976333095181374, 41.4245161702556, 38.771393606739665, 39.05826399403234, 39.740246495892926, 43.99442957293603, 47.223481593593476, 51.33571017173029, 51.82499839413551, 51.40278662404707, 53.110578752333126, 47.38211008810228, 51.4248852575979, 54.966510957287205, 57.87728225031207, 53.99278256200976, 55.082550356465006, 53.24477872540874, 54.299825699098655, 56.73419375573435, 62.65094403297671, 58.40074608402868, 44.410628349550315, 17.02657353493475, 6.6166462436799085, 4.69830128454393, 16.679994867693996, 21.204997993284657, 12.015086681612077, 11.059123681437585, 2.8315141652860953, 0.2046105626129335, 5.385349527482064, 39.67728068751674, 39.33128449224657, 38.88533846024544, 59.242478878267356, 54.79914734440466, 21.50066037331858, 0.8904901843878531, 0.10515495218456754, 0.1432349076194148, 0.1948696320816394, 0.11320711849557777, 0.049212890707196734, 0.1362305044406845, 0.280657169078627, 0.11012148487591937, 0.0910146544957834, 0.11178240180015565, 0.15784864764540427, 0.16577120720138475, 0.12115094465233626, 0.19813895826378178, 0.12610075364430107, 0.13152087167386087], [0.023232920568496473, 0.038826879669701865, 0.08952568600615186, 0.019303374067549745, 0.017390787684088273, 0.037630261823294625, 0.03824139697357051, 0.019328275755528482, 0.042931241689309965, 0.02206794406858183, 0.04941701483462126, 0.026273628877055262, 0.018984815556435816, 0.03808456728415143, 0.06326778491418208, 0.036548560995969086, 0.06616523669612023, 0.01989921810285699, 0.04137081634854117, 0.061400514546661615, 0.047538525109449704, 0.15844653330502972, 13.154165533281143, 45.069006027713904, 52.21820815916985, 60.23578774544501, 71.44030094146729, 62.91874777886176, 44.196816029087195, 31.35383663638946, 2.056248385098673, 0.5604849407269109, 2.2968281853583554, 8.694958206145994, 6.083807945251466, 6.832521240557394, 14.598802904928885, 36.12610793882801, 45.041353317999075, 40.77392831925423, 56.18327725318171, 55.3601521830405, 56.80638105638566, 51.29369374244444, 50.907524631869414, 46.80683174440938, 42.82572800113309, 41.19512027309787, 42.517496385881984, 40.73815238091254, 41.16885608242404, 39.13443642277872, 38.71682951527257, 35.77393008816627, 37.146037932365175, 34.47170711332752, 37.2518713243546, 36.705540072533395, 37.982750092783284, 37.49821186065674, 40.241501869693884, 40.17779081098495, 38.33313934264645, 38.705125162678385, 39.16754907177341, 38.84438499327629, 41.88825799572853, 40.19340968901112, 40.47092914581299, 39.7029016094823, 36.99204567940005, 37.0869238914982, 37.151690067783484, 36.20704604733375, 37.37062500369164, 38.142472928570164, 36.38746330814977, 34.796863755872174, 42.050702956414995, 48.044806295825595, 50.18180378021733, 49.51693457941855, 46.21935482948057, 46.51136744406916, 45.99768207919213, 48.36681719749205, 49.69159772319179, 50.312834478193714, 49.813677572434955, 45.33460147919194, 44.03622634949223, 45.631501367015225, 43.96157972274288, 44.813655807125954, 47.699814227319536, 47.68834521693569, 51.81826760691982, 50.522273355914706, 50.11673558142878, 47.56133887075609, 46.630838917147734, 43.079619100016934, 38.49645506951117, 37.22400680665047, 36.93919958606843, 37.4564346959514, 37.59836173826648, 36.8060782647902, 40.20059939353697, 39.2120248271573, 37.86349042769402, 38.71540569490002, 39.62598393040319, 40.14796903056484, 37.84396486897623, 36.861717085684504, 36.79605268662976, 38.12107247691001, 35.92375286163823, 36.37526473691387, 36.58865736376855, 35.29693065151092, 35.93969337401852, 36.89426099100421, 35.45583371193179, 38.62794468479772, 38.51342716524678, 43.953766361359634, 45.95205314697758, 50.65601441168016, 51.017845215335974, 49.284647895443825, 48.29285698552286, 50.35667873197987, 52.98948734037338, 51.92238300077377, 54.83974387568813, 53.620235843043176, 52.43034562756939, 55.697876099617254, 57.492097654650294, 51.1087461440794, 29.130360695623583, 12.605846620375111, 6.728444089812617, 7.5534965145972475, 7.635060731441745, 5.255437195301056, 1.9969941194980376, 2.3220191174937836, 0.7773632063500343, 0.03730954677467385, 4.4896988522621895, 35.044812463944965, 35.00880902813327, 33.000979115886075, 43.254223408237586, 34.53493572050525, 7.456080528997607, 0.15755088459099495, 0.0998822141498808, 0.028243449689339728, 0.04870266082786745, 0.014240203214989556, 0.08028575399469945, 0.022544008341708013, 0.03814218475693657, 0.02626084286959902, 0.036519258132865356, 0.021957504833417556, 0.046158720318588524, 0.021650253780066006, 0.026811315347590757, 0.03857858674300294, 0.04013782847792872, 0.0526826101685724, 0.05847420040217619, 0.02985983775297721, 0.05260878227530949, 0.06627504007830735, 0.058826037772720864, 0.021732133257413105, 0.06748719801825863, 0.06570630406420078, 0.0340489425035494, 0.018539683998472268, 0.0525513869680224, 0.0392515528496475, 0.08144411724060774, 0.06505393423140049, 0.02493503770130056, 0.02076017835568036, 0.09012039240089156, 0.04932623341559403, 0.03433554365690197, 0.01642812351365724, 0.07377996680236633, 0.4049526365293611, 17.009258231809063, 49.4965970900751, 58.29164143531554, 56.78989141218124, 62.873660133730986, 58.181085509638635, 48.78373769021804, 36.83768080126855, 2.083937131589459, 0.5035526876247699, 2.2072701781026782, 12.666628649157863, 11.487548485878976, 9.672417756049864, 17.44655151521006, 41.96226527613979, 49.46856783282373, 45.28193189251808, 55.77985363621866, 56.65293009050431, 57.103339779761534, 53.83782540598224, 52.40247326512491, 49.81538380345991, 45.64342537233907, 44.854122900193744, 46.074301658138154, 44.32490887180452, 44.69942069822743, 41.92930167721164, 40.95305512028356, 37.91280246550037, 38.05199953817552, 38.06972472898422, 39.037353838643725, 38.526469046069735, 39.07808765288323, 40.398318229183076, 41.01924119457122, 40.114389619519635, 40.63797504671159, 39.005708156093476, 40.65877537573538, 40.45492587550994, 42.95672339777793, 42.87382018181586, 42.52896539626583, 41.11699842637585, 39.428594573851555, 39.28831492700885, 38.91233221177132, 39.44084805826987, 39.75330798856674, 38.872214209648874, 38.45720391119681, 37.56636696477091, 43.20626458814068, 49.829421966306626, 50.71620710434453, 51.51422116064256, 47.70946325794343, 48.47034031344999, 48.00919509703114, 51.0180687904358, 52.528977547922445, 50.27535230882707, 51.41735038449688, 45.50121984174175, 46.60886972181259, 45.08005142211915, 43.52022678621354, 46.71282037611931, 47.8684800670993, 48.02278218730804, 51.04151279695573, 51.221690793191236, 52.205837003646366, 50.14587879180909, 48.1584216702369, 44.762076639360004, 39.538185596466064, 38.998777327998994, 38.3408821013666, 39.96361763246598, 38.814469075972035, 39.85906293315273, 40.84721780592396, 40.90937168367448, 39.43021059036255, 41.04589369989211, 40.62711792607462, 41.37824004696262, 39.57758972721715, 37.89819555897867, 38.40554237365723, 40.1930723651763, 37.73761764649422, 37.85297455326204, 38.40674261892996, 36.58900645471389, 37.38069765029415, 39.59474225198069, 37.594043208706765, 41.014369610817205, 40.00930147786295, 46.62842665949176, 49.40220132950814, 51.44808215479697, 52.28488845209922, 49.88990491436374, 47.196185819564334, 50.58903209624752, 54.127033525897616, 53.33987266786637, 56.07662800819644, 55.73261260986329, 54.77777434933571, 59.881229016088675, 57.24496087720318, 53.72116627231721, 33.87434974793465, 17.695241551245413, 7.31539442654579, 12.897189490256771, 10.605495687453978, 0.5862020833357688, 0.42102908355093777, 0.3837697231961835, 0.2325737371199554, 0.0549365557549942, 4.919237609832518, 38.48725711145709, 39.07585582425518, 36.104589816062685, 49.156229496002204, 41.977284031529585, 11.327707978986925, 0.11477396748359166, 0.07920068238050708, 0.012309544817394307, 0.031462514757989876, 0.021673468159391515, 0.05311540005007579, 0.026673325675449548, 0.0693034086256258, 0.050330199301242835, 0.053841073005910844, 0.01594141444882318, 0.06523050983706791, 0.014766840782437115, 0.007153317743476721, 0.021699833075305628, 0.022102207350995273, 0.04218707537098278, 0.16292051742634467, 0.1303362239512705, 0.1825601466360592, 0.11778103112573586, 0.09218910558810157, 0.09366995354573573, 0.15061169081637937, 0.16640543607213806, 0.13667583135106873, 0.09463068142893816, 0.1275938590087237, 0.0974075050063191, 0.1350749680592168, 0.12940427799138332, 0.15814786626686975, 0.25893275415705097, 0.26222101803268155, 0.08386754445851811, 0.17025839867851428, 0.10434499040486352, 0.2791491096779224, 0.761606984080807, 20.271532727826028, 57.364930491293634, 63.47492025744531, 69.59706152639082, 73.55656085475799, 66.80971545557823, 53.61527796714537, 40.247777661969586, 2.696169105268294, 0.7926743621787717, 5.118848008494224, 18.242372966581776, 13.799964170302115, 10.938369593312665, 21.052796302303193, 44.71770286560059, 52.11749346025529, 46.91803486116471, 56.525296165097146, 55.05927108949231, 60.009537589165475, 54.8617797513162, 53.86181462195612, 51.529836116298554, 46.42745225660263, 46.174565284482895, 45.9210781897268, 44.628453254699714, 45.396653375317975, 43.680494831454375, 43.52413738927534, 40.462484282831994, 41.07074975967407, 38.6746326569588, 40.75903900208012, 41.22913898960237, 41.44978015653549, 41.54596451790103, 43.611194395249896, 42.768445707136586, 41.13570028735746, 41.49791156091998, 44.10394214814709, 42.95323641069474, 44.75484378876225, 43.893346171225275, 44.21014424293272, 42.546180678952126, 40.07720947265625, 41.529992626559356, 40.99851146821053, 40.45356089068998, 41.442692433634114, 41.944834263094016, 39.10592471399615, 38.427723376981675, 46.40724812784503, 52.698090537901855, 52.9729780843181, 52.487329821432795, 48.31045273811587, 50.915353682733354, 49.597798162891024, 53.764359412654755, 53.772772896674375, 53.75208239401541, 51.8751694310096, 47.980197014347205, 47.87963528786936, 45.11636080280427, 44.78334765280447, 45.76197901079732, 48.311727508421875, 49.16236800532187, 53.73343152384604, 51.91961772980229, 54.26422626741471, 53.12927669094455, 51.89784465297576, 46.99234808644941, 42.669197974666474, 40.611989344319994, 40.20463943481445, 40.71950935548352, 40.2991646335971, 41.26092979984899, 43.060077851818455, 43.79770309694352, 42.80920305559712, 43.70770431333973, 45.07361873503655, 43.37112572885329, 41.8587343154415, 39.90956737149147, 40.18252903415311, 42.412110144092196, 39.27710479305637, 39.95813415896508, 40.78155732923939, 38.73702972166, 39.71646908790835, 42.567592897722804, 39.625199456368726, 42.88231995797927, 42.17201402110439, 47.23644894938315, 51.7769689713755, 54.17954621776458, 55.093019162454915, 49.457098822439875, 48.93263478432932, 52.142373054258286, 53.93723395562942, 55.942530016745295, 59.03176523024037, 57.86011403606784, 55.68752496473251, 60.460818044600956, 57.71189551199637, 55.75837865952523, 38.89229674493113, 24.15155306939156, 15.426696596607087, 14.694238093591506, 17.95023483614768, 12.778503471805205, 8.449189355296474, 5.7565950001439745, 2.346354727783511, 0.1702025661905927, 6.024996907480302, 45.579671167558246, 47.40298101978917, 44.726312468128825, 55.56877520776565, 50.92594408219861, 14.075598928236193, 0.23010838957082844, 0.28922607701632286, 0.11439499144832935, 0.1403788245853878, 0.06703850798188679, 0.13868929427717963, 0.10071196398066898, 0.17766882845711324, 0.08015154305124476, 0.11677549475984228, 0.07998111913160932, 0.22012300038289642, 0.11040544302593316, 0.14810307462128902, 0.09475480299443008, 0.08815977421979751, 0.1461331714545527], [0.019049883234284578, 0.013886730246726545, 0.00794736021611419, 0.06873399079326661, 0.0277794398097021, 0.01916346151471859, 0.14730942285349294, 0.045339308844338504, 0.03734061164000342, 0.029793343236369473, 0.03527684738078425, 0.023021432420899792, 0.1372815617510388, 0.02454158643470897, 0.06797059183760036, 0.025729271695919098, 0.05634038506316082, 0.0663886049522027, 0.025555137995510332, 0.058371441198452834, 0.07697718878907543, 0.04158414119193631, 10.393418035199566, 45.280500227405184, 43.346877636448035, 52.5008306195659, 67.11457775485131, 65.48713537954515, 47.66374018884475, 28.668142710962606, 5.318252973018154, 0.011468240465488166, 1.0475369831246715, 6.46164741246931, 5.439818501472474, 6.294725066231144, 12.908866386259756, 36.590849968694876, 45.12797101851433, 56.836736279149214, 55.66970171466951, 55.21619727534633, 53.739503352872795, 51.748210153272076, 49.01983299563008, 43.88694094073388, 41.49975507490097, 38.14036269341746, 38.65411081621724, 34.73925982752154, 36.52864117776194, 37.992340287854596, 36.35786902519965, 35.49790897677022, 35.34088080929172, 34.3966604048206, 36.871326892606675, 35.959179709034586, 38.842918026831846, 39.73732040774438, 39.6452231560984, 39.24657306363506, 38.37639131853658, 36.442737348618046, 37.537153151727495, 37.44101193643386, 39.239775596126435, 37.68128064370925, 37.33033049491144, 38.39663859336607, 37.44927244801676, 36.85425281524658, 37.69900583451794, 36.86013637050506, 37.47966297211186, 37.05218738125217, 36.41274298391035, 35.58143192721952, 39.73007971240629, 43.66150271508002, 47.82928774433751, 52.261142423076016, 48.525700646062056, 49.205345415299945, 48.96532773971558, 47.03513330028903, 48.833665540141446, 49.14798467389999, 49.539378381544545, 44.76749735493814, 44.70444133204799, 47.349224936577585, 46.897261988732126, 49.73205697151923, 49.51486356796757, 50.614621639251716, 47.54098961430211, 49.48493196118263, 49.369347556944824, 49.99227877586119, 46.15216070605863, 42.73393669436055, 37.02544073904715, 36.80895336212651, 35.549350861580145, 36.9024940459959, 36.57084195844589, 36.71012140089466, 37.51143417050762, 37.213498776958836, 39.06535171693371, 39.878502199726725, 37.06198546194261, 38.257261091663, 38.85142172536543, 37.78052837617936, 36.58104012089391, 36.86074041551159, 37.040730137978834, 35.761131394294004, 37.634247502973004, 36.676996984789454, 36.2556795151003, 36.68995257346861, 38.35244524863459, 37.99122633472566, 40.53678574100618, 41.777662846349905, 44.38423864303097, 46.374759135707734, 48.95924414357832, 48.6133538523028, 48.17631944533318, 50.74627207171533, 50.45020372636857, 54.51404202368952, 52.87060422282065, 50.33678447046588, 50.95737795675955, 51.840754555117705, 51.184392975222686, 35.58145546144055, 18.051506511626705, 4.35060081943389, 1.339297462855616, 5.968640783140737, 4.905487250897193, 0.7745663112690373, 0.14059674595632862, 0.05790376367287771, 0.15626114492695178, 0.11516341594077888, 5.694158711741048, 30.79875065434364, 22.973892804115053, 30.71381368944722, 47.8959092017143, 26.478544281375026, 3.372318797534512, 0.09166220563553995, 0.03141948934494248, 0.08273879051088326, 0.011683965079306115, 0.05859764014941551, 0.06545056859331747, 0.04011504119262099, 0.028454911023859056, 0.08559844351463741, 0.037195855496271, 0.020956247068581083, 0.04717906133361882, 0.06110436410733289, 0.010309986387109085, 0.03918635110641199, 0.01192202307133665, 0.010965804573178533, 0.048769892704102306, 0.011857746379269708, 0.037448476819742116, 0.021645218667183674, 0.06543318605831554, 0.0754062871959421, 0.022421763691630577, 0.0815572914096617, 0.06407086722432606, 0.02221662258248656, 0.05113837609608328, 0.10130002839310516, 0.15929583369964556, 0.06710668980714775, 0.039345061541685176, 0.06730377358654815, 0.007877829597301541, 0.04326031475718464, 0.04221650080815439, 0.0036831115768666592, 0.01566218689174181, 0.11588220559661427, 13.277770203928794, 52.208692489131806, 50.161576117238695, 60.27290905675581, 71.97928951632592, 69.39784434533888, 52.161271033748505, 33.1745243841602, 5.619298315817311, 0.15642190081698282, 1.3438009566837743, 6.87378506506643, 8.288157428464583, 9.417607841953155, 15.621388343072708, 40.14841618076448, 48.31561065489247, 54.93904652134065, 54.866353234937115, 54.64489621500815, 56.206097602844245, 53.921564086791015, 52.697113867728945, 45.45901121631746, 43.33261982087166, 39.56649726436984, 39.524308250796416, 37.297347284132435, 38.179504025367, 37.99125771368704, 39.00682210922241, 37.79546868416571, 37.47973357477496, 37.34783995536066, 38.87273196251162, 38.9309948490512, 40.18447845212875, 41.04994158590994, 41.921092156440984, 42.2816325003101, 39.18681183168965, 39.68099124969975, 39.881483201057684, 40.67118575496059, 40.134123063856556, 40.05750348491054, 38.61271804378879, 39.604324602311664, 38.19519350605626, 37.37386880382415, 39.823824359524636, 38.13177662511026, 37.97512108279813, 38.78147409808251, 37.50061627357237, 37.878454269901404, 41.233477131012954, 47.497215963179066, 50.74176919075751, 53.454668675699544, 51.25373655749906, 51.10599264021843, 49.74388291758876, 49.91443933979158, 49.991694342705514, 51.13801487030522, 49.282114044312515, 46.11769876172466, 45.65909524117747, 47.12739136911208, 47.18157499067245, 50.909611332801084, 49.83957698268276, 50.81460760485742, 48.91088524172383, 51.09954034128497, 50.78452302563576, 51.93434622979934, 48.24777718513243, 44.188398622697406, 38.62706215150895, 39.00464519377678, 37.20696803062193, 39.21683365298856, 38.77810478210449, 38.9316185059086, 39.07321606912921, 38.75321734336115, 40.67496299743652, 41.726601431446696, 39.156825311722294, 40.89922843440887, 41.11853207311323, 38.84121964054723, 38.36098032612955, 37.249172733676055, 38.182602697803134, 36.5040792957429, 39.172738367511386, 38.10805020793792, 37.67199639351138, 39.21997547149658, 39.658841625336684, 41.1702367567247, 42.00987892766153, 43.588095557305124, 48.13811555985482, 48.913003321616884, 51.87462029918548, 51.14186663781443, 48.94943821814753, 52.25478818339687, 51.722648066859094, 54.13936938008955, 55.050928208135794, 51.52656485957485, 52.52981693513932, 51.881774702379786, 51.796827931557935, 40.61347984498547, 23.70309868166524, 8.485870380555431, 4.7713505260406, 9.782957992246075, 4.588331753207791, 0.6339600045354136, 0.2085654608785145, 0.06767968527011334, 0.15194891260996943, 0.04501437648169456, 6.263420139589618, 35.73792665235458, 30.584520601457168, 39.2376418267527, 53.69537668843424, 34.77438073004446, 5.6782392821004315, 0.09491853896648654, 0.01987566856006461, 0.015404418415029444, 0.11939661862749247, 0.04821788805026201, 0.06310268913606001, 0.050391708500683315, 0.08910570894518206, 0.04059550089521274, 0.022668244820388577, 0.05113640725011787, 0.02398492013584943, 0.04469313283240603, 0.015448298973722324, 0.03185772419636769, 0.02708908350717637, 0.12101578375985547, 0.09917552868324904, 0.12239002292194676, 0.11082383428489971, 0.13487304260413494, 0.2095017888613286, 0.26680844445382396, 0.2729556258888014, 0.23111315984879774, 0.11453429687648051, 0.08548918405487653, 0.15126131805441073, 0.17164982885362642, 0.27718314420311685, 0.1486008479109695, 0.11520361257416588, 0.14829891733825207, 0.19923385112516342, 0.31811847021022155, 0.15815797862747025, 0.14791227276286772, 0.12201617967577712, 0.2807168932932039, 17.605132941276796, 58.51588333806684, 56.933544297372144, 61.290897477057676, 71.75636552995252, 71.54104309697306, 55.251118136990456, 37.02979456993842, 7.47715836571109, 0.2984919104604952, 2.3544556479300223, 13.399819654803123, 11.388630232503338, 10.016327250388361, 17.272380628893455, 45.05064541293729, 48.25774000537012, 56.34906407325499, 54.40125819175474, 55.38418454508628, 58.80583670831496, 56.07672214508057, 55.58369198153096, 47.50739451377623, 44.6496654325916, 41.072848227716264, 41.01063159204299, 38.56065642449164, 40.664227470274895, 41.566525582344305, 41.32347199224657, 39.01844801441316, 38.76507074602189, 38.116867696085286, 40.746357979313025, 40.56307346590104, 42.07121695241621, 43.245347084537634, 43.56254916037283, 43.39667997052593, 41.077837482575454, 40.80637416531963, 41.12024614887853, 41.51918649673462, 41.85494530585505, 41.412580397821245, 39.266443790928015, 41.342581779726096, 40.26682076915618, 40.02692468704716, 42.569448178814305, 40.801184869581654, 40.325848517879365, 41.177406849399695, 39.16960831611387, 40.447253719452895, 43.27029728120373, 48.534780933010964, 52.039434371456025, 56.62870553232009, 52.94824361801148, 52.78776376478134, 50.81994202829177, 53.15619591743716, 51.002618574327045, 53.88814549292288, 50.333705409880615, 47.87317906656573, 47.23809634485553, 47.99889103058846, 48.64731373325471, 50.84730840498402, 51.43640918116416, 52.28897556181877, 48.623685375336684, 51.11116624647572, 52.712622919390284, 54.248121015487186, 50.43514574727705, 45.8606226982609, 40.51604816990514, 40.485908677501065, 39.156554668180405, 41.470141180099986, 39.91957333780105, 39.712668311211374, 41.016762256622314, 41.38158190634943, 42.979014227467204, 44.26084872215025, 40.74824463936591, 41.48108067051057, 43.458963286492136, 42.00574867187008, 41.41870321766023, 39.84242816125193, 40.77473632750973, 38.405040310275176, 41.05420520228725, 40.17544131125174, 39.29501825763334, 40.88796730964415, 43.248433989863244, 43.31531824604158, 44.42015578669887, 45.018964429055494, 49.18193278774139, 50.763687395280414, 55.3116677653405, 52.17099458940568, 51.49044375265799, 52.80766979340584, 51.96584286228303, 54.19251357355426, 56.08624958222913, 53.676557156347464, 51.83139185751639, 52.57173530517086, 53.93872053392472, 43.43078890154439, 26.891173701132498, 8.24382483959198, 6.520488848609309, 13.712418829241107, 14.358557731874528, 5.751779800461185, 0.3023337188266939, 0.29629621053895644, 0.4425541930381329, 0.3921682225360025, 8.353493329017393, 41.72436568044847, 33.65182192094865, 42.89734655810941, 60.196893522816325, 41.13257808070029, 8.14335823059082, 0.17835482954978946, 0.14425147565141802, 0.1945240498189965, 0.22962135683384635, 0.18099582573819548, 0.18498020306710275, 0.1525719106317528, 0.24327799257251526, 0.19708042393528646, 0.12478895830891787, 0.11172631650321907, 0.1995073138706146, 0.19115194528093263, 0.09530703747464765, 0.17468315398981496, 0.0821801515356187, 0.19236689944180752], [0.046392626114069455, 0.09406419005244972, 0.08388787643202851, 0.04419442491545793, 0.022587849638394775, 0.07154410089095754, 0.026931026161858634, 0.05931719972361481, 0.048491312491316954, 0.04608137225131354, 0.010542746881143221, 0.018371882014757684, 0.038904231567416465, 0.006296440739289768, 0.08017313906983023, 0.011993979794844505, 0.04530129939197533, 0.029972194123171994, 0.034526023758395065, 0.10258425988497273, 0.02703644943633868, 0.11291472571751765, 3.917446617157229, 34.23578439220306, 47.50674340032762, 31.976760010565485, 53.03559087937879, 65.50337791442871, 40.00495549171202, 41.02357541361163, 11.449334794475186, 0.13670282828952038, 0.6528789441912406, 4.028917680824957, 1.6967238125301178, 0.8183397172439484, 2.7051366240747514, 14.696163977346114, 38.32592610389956, 48.76433372497559, 56.744031060126524, 57.337897516066036, 59.67059381546513, 54.544981679608746, 50.17590845784834, 45.8709228423334, 45.238248455908995, 40.874933273561545, 37.54251503175305, 38.410143313869355, 37.41464576413555, 37.663108302700905, 35.97975254058838, 35.27507912728095, 34.87296165958528, 36.32321096235706, 36.26650917914606, 36.33149108579082, 36.38593358378257, 36.80909848982288, 37.38765593497984, 37.05312482772335, 37.942137872019124, 37.45759571752241, 37.62383753253568, 38.08573192165744, 39.540393890873084, 37.170768476301625, 38.11001531539425, 38.27524908127324, 39.349241102895434, 36.595337160172, 37.7276038354443, 36.376645411214525, 37.63302764584942, 36.81884950207126, 36.69362783432007, 36.36902424596971, 38.29192699924592, 39.99721665536204, 45.404098033905036, 48.00231525974889, 48.726482852812744, 49.80618192303566, 49.2795370471093, 50.58875360796529, 49.682140888706336, 48.314798724266794, 48.94558252826814, 45.82264631025253, 43.56744035597771, 48.56210416363132, 52.247539643318426, 52.749457897678504, 49.70462391453405, 50.80360535652407, 51.97050656041792, 51.701498646889966, 51.5749708298714, 51.21672115018291, 47.1234219304977, 42.748688728578635, 38.085312228049006, 35.66309959657731, 36.935685142394036, 37.7921268247789, 37.84826378668509, 38.55131333874118, 39.315418504899554, 37.09174448443998, 38.36807589377127, 39.95820476162819, 38.52301736031809, 39.47479617211127, 35.914131287605535, 36.96284363346715, 35.1074174142653, 36.7443323135376, 35.63696484411917, 36.76807442019063, 35.131210511730565, 36.388412521731475, 36.7363699020878, 38.49285825606316, 40.89999721896264, 42.96001818872268, 43.996320155359086, 45.13210911904612, 45.74347326832433, 48.07120384708528, 49.8563882612413, 50.53225186563308, 45.95753662047848, 47.40505595361033, 48.17520549220424, 47.65202799151021, 48.96419809710596, 48.82196118754726, 48.616770236722886, 50.0535697321738, 40.004135716346006, 30.18683345087113, 6.856451130682423, 2.0647481612620817, 2.2382446450571862, 3.542194688512433, 1.8071771437121977, 0.34244896303261485, 0.10814296322003489, 0.09742900909435365, 0.2264064382160864, 0.1151925196210223, 6.463717933624022, 30.135897551813436, 39.127207494551136, 35.15368569281794, 41.755360249550115, 22.775424795766032, 1.451399905547019, 0.029521194331708456, 0.0370556460843692, 0.05133516876207245, 0.029220548871484016, 0.040821929672552694, 0.08147157383181396, 0.036280732827201005, 0.023526387784870404, 0.026744451193559556, 0.05731679859661287, 0.0740836976817058, 0.020915357125622612, 0.022605573082523003, 0.0432924866195648, 0.08548463349260631, 0.04973125260984225, 0.012576199914028328, 0.017664260005638484, 0.040727988140837806, 0.03548211680965559, 0.02694669265991017, 0.02991455941340856, 0.008794336012684771, 0.025330902144853628, 0.017492257944879033, 0.028236246547631683, 0.024660282182477178, 0.018397612992914456, 0.00813225314261452, 0.022634242007869388, 0.055032833854878144, 0.025210622510301973, 0.020773877922986305, 0.058940981604879907, 0.012251648680126716, 0.04817558467508324, 0.08913636778391178, 0.06395021603713114, 0.07406358787369344, 6.526315039204014, 43.061344777384114, 51.40451638929306, 40.21268421603788, 63.314052089568115, 72.39392326724145, 48.1926521947307, 43.48143454520933, 11.15615233298271, 0.22925466118801027, 0.2689411413044699, 5.398927302129808, 5.846170658065427, 3.432604156194195, 5.844495806001849, 19.56716525939203, 44.022011679987756, 50.54629787322014, 55.601405405229144, 54.96460468538346, 61.94161868864491, 55.66332001839915, 51.85967606882895, 47.054168562735285, 47.58955640177573, 42.205664034812685, 40.08347742019161, 39.45887919395201, 38.67732732526718, 39.593271363166075, 37.58607687488679, 37.71228305755123, 37.17325918136105, 37.55616487995271, 37.009280573937204, 39.04674399283625, 38.782074220718876, 38.244179987138324, 38.138354439889234, 38.0214991877156, 40.01376121274887, 38.3338257574266, 38.53608669773225, 38.819889791550175, 38.589489767628336, 40.59808061968896, 40.54217899999311, 39.86171445538921, 41.33832208571896, 38.39727793970416, 39.2071650105138, 37.4598353908908, 39.78728748136952, 37.722547900292184, 38.4047539772526, 37.855292674033876, 38.309624733463416, 43.187154800661155, 47.0251351787198, 50.4683917568576, 51.895506920353064, 51.56961287221601, 51.90325360144339, 50.354639099490264, 50.127737829762125, 49.794854117978005, 49.52285735837875, 46.33327222639515, 45.4696879079265, 48.032592035109, 53.079493968717514, 54.98081191893547, 52.23437224664996, 51.96406995096515, 51.71439932238672, 51.99702570515295, 53.467110433886134, 51.534629252649125, 48.56416733034196, 43.51422163747972, 39.6912560924407, 37.89359461876654, 37.61219593786424, 38.52414700292772, 40.83860035865538, 39.8398825430101, 39.9002399752217, 39.99225485709406, 41.11227981505856, 41.879146329818234, 40.64788687613703, 40.20388633974137, 37.81827334434756, 37.81812037191084, 36.5886495190282, 38.1279170128607, 37.5837940554465, 38.52603758535078, 37.27034176549604, 37.40104298437796, 39.388213772927564, 41.64698908405919, 43.25355660530829, 45.23748359372539, 44.71462772738549, 46.96094166847968, 47.27428020969514, 49.35075552232804, 50.53112614539362, 51.29504696015389, 47.88707210171608, 48.33434781720562, 49.77164937603859, 50.24081191708965, 50.90773251748855, 51.2349719385947, 49.65991281693982, 51.711806635702814, 43.266720079606586, 32.81168160899993, 9.827599467769746, 1.979328009390062, 2.14112798533132, 2.240655676972482, 0.25201658898543927, 0.04260160171637132, 0.059081972426464485, 0.03570245135755789, 0.06426095662097778, 0.14189929461046574, 7.332982824694726, 32.541426381757184, 36.358339709620324, 36.785411296352265, 49.350543714338734, 28.328894953573908, 2.592615345793386, 0.023696811704505837, 0.06284701878265028, 0.01962143845195251, 0.026847124212391438, 0.020481262979428136, 0.019563920570597537, 0.025441845082828117, 0.044857083309081294, 0.022941280471821947, 0.004542887026834632, 0.06411297141664452, 0.030078500313984773, 0.02052150366287078, 0.06679767292113074, 0.0714705870937436, 0.05497518190813642, 0.03156213300122369, 0.08462238621207015, 0.16684861793633432, 0.2308370004738531, 0.14266490756023315, 0.07038209106652968, 0.08010213804100791, 0.15340369825641956, 0.13375148988298832, 0.10597292724395953, 0.1247518107054695, 0.09975561045951421, 0.11147573680406618, 0.25005462248959853, 0.14083299215041822, 0.23950533130236212, 0.11384427382220184, 0.06067744245932949, 0.1303349675670747, 0.16135288702864803, 0.17345856244285263, 0.12591876179700898, 0.1992589022002874, 6.852444429551402, 47.06435888044296, 60.193426147584, 44.016626265741166, 61.57948586248583, 73.18591256295481, 51.87769935977075, 50.61208386575022, 14.353668497454736, 0.2014383763795899, 1.5824836780948024, 8.08288852053304, 7.670268416404725, 3.1459448414464153, 4.735326497785507, 19.92185538814914, 44.33078458232265, 50.47372618029195, 56.95825915182791, 57.16363837642055, 63.2742557217998, 59.66932688989947, 53.653430861811486, 51.306912129925145, 49.62305430443057, 44.85222447303034, 40.78618964841289, 41.50395593335552, 42.92861961549328, 40.721792174923806, 40.43856959189139, 40.64034023592549, 39.72551407352571, 40.992016023205174, 38.68978085056428, 41.25439120877174, 40.45051713143626, 40.45754994115522, 39.96693988000193, 39.71417842372772, 42.758176942025464, 40.305844430000555, 42.1348064176498, 41.58499210111557, 41.61796746715423, 42.050365632580174, 41.947921168419626, 42.65155907600157, 42.82418650965537, 40.14848286105741, 41.61483349338655, 37.461718128573516, 40.07623280248335, 40.16941262829689, 40.939275833868216, 40.249362299519206, 40.88626500098936, 43.544863193265854, 50.44753259228122, 53.23591024644914, 52.40768217271375, 54.82458391497212, 54.04083159662063, 53.58161226395638, 52.54406298360517, 51.86242957268992, 52.2206792523784, 51.18217683607533, 46.3540647106786, 47.84353771517354, 54.78611723069222, 57.022111415863044, 54.59016738399383, 53.52866418900029, 53.86926320291335, 52.83599715079031, 56.139691875826934, 53.08990786152502, 50.76082014268445, 46.28971822800175, 41.81179138921922, 39.52748144826582, 39.737379243296964, 41.62226246249291, 42.2543445710213, 43.59747002201696, 43.19497600678475, 42.02273253471621, 42.508831870171335, 43.82072348748484, 41.57182862681728, 42.967960988321614, 38.94123615757112, 39.97819708239648, 37.86481226644209, 39.605552304175596, 38.98826145356701, 42.094060836299775, 38.679115926065755, 39.70862434756371, 42.12555746878348, 43.024705917604514, 44.79822128049789, 48.16514461271225, 46.97958861627887, 49.35761182538925, 49.76786821119247, 52.379786276048236, 53.15640380305629, 53.96845602220105, 47.878038883209236, 48.46367228415705, 50.11635511152206, 52.05297047092069, 53.17954578707295, 53.29928790369342, 50.703357419660016, 52.89089464372205, 44.23874224385908, 36.69346309477283, 9.206049903746575, 4.620914882229221, 4.083470495477799, 10.760495989553391, 8.203721056061408, 0.7642852887511254, 0.704242320310685, 0.22222585044801238, 0.9053598284240693, 0.4651045120291172, 9.823441755387092, 40.7953836840968, 47.8053887428776, 44.87834353600779, 53.92859689650997, 35.09540319442749, 4.026094309745297, 0.17011035984802633, 0.12199535740599518, 0.09943108029303052, 0.1397522259503603, 0.10473260791191172, 0.19967730878101242, 0.0960775763697682, 0.14341702204077475, 0.15695047084121935, 0.12641664999987812, 0.20233505165144322, 0.07632619791453885, 0.09830987231144983, 0.18225804752399846, 0.09181307899134775, 0.1199335773144999, 0.15684124202497546], [0.0159443351590345, 0.01610029342343971, 0.024039233854461103, 0.11967619475457938, 0.03172471984139374, 0.019802101136695956, 0.01688912458297226, 0.06998328101490775, 0.06952534429728985, 0.042947716410121614, 0.023042080405678962, 0.04055055834713482, 0.030157683161838405, 0.05824109899901575, 0.054570262305318355, 0.032339719905247616, 0.025446261579711592, 0.012294540985397274, 0.019638625634533745, 0.03704011748214403, 0.03688214249127815, 0.04209331386993009, 0.5344774814382677, 23.583939037015362, 47.60491248100035, 39.27026810184602, 24.807359633907197, 44.01530050462292, 56.41291241491995, 37.61098784785117, 16.24780752966481, 0.7059466514375903, 0.04222696939963968, 4.58904758576424, 4.433109837193643, 2.000879840024056, 1.9779332390716, 2.1083837939846903, 21.891022497607818, 42.42825854209162, 51.365065190099905, 53.51762663933539, 55.67244737379013, 52.726990561331476, 52.12096475785779, 46.61931107121129, 42.438248818920506, 41.21865057176159, 40.9376480502467, 37.58197015331638, 38.64391657613939, 37.458921478640654, 38.09485927704842, 37.11374113636632, 37.60623001283215, 37.87135477988951, 38.07329408584103, 36.016430624069706, 36.79944945919898, 36.76212418463923, 38.77735168703141, 37.80359583516275, 37.78010868257092, 40.010854736451186, 39.64831398379418, 37.59128578247563, 37.78458410693754, 37.19319658894693, 37.59598085957189, 38.15364383882092, 38.61461647095219, 37.906636499589496, 37.450845318455855, 38.44107512504824, 38.189788479958814, 37.43612858556932, 37.04078897353142, 36.583699487870746, 36.91467300538094, 38.6893258556243, 40.992494552366196, 44.16285222576511, 48.74955031179613, 48.242003456238784, 46.71913539209674, 48.33369670375701, 49.7410862676559, 47.97502340808992, 51.288849615281634, 45.554144382476814, 44.520042865507065, 53.33564827519079, 50.81673745186099, 50.736462223914366, 47.113768977503625, 48.24611802254954, 51.89777797268283, 49.2766188037011, 52.31979362426266, 49.00366890814997, 47.75020883929345, 40.37279928884199, 36.858237943341656, 36.824701678368356, 36.27260454239384, 38.34165873066072, 37.40339640648135, 36.73300450847995, 37.61043479365688, 39.05959367752075, 37.26643900717459, 40.39199929083548, 38.172279019509595, 37.7947901141259, 37.2439952050486, 35.43655918490502, 37.515223180094075, 36.695416435118645, 36.71873884816324, 37.81125230173911, 37.33001670529766, 37.181857016778764, 38.57493777428904, 40.205008137610655, 39.924339017560406, 40.869944018702355, 43.776961603472316, 45.68810901334209, 46.575431516093595, 46.66905064736643, 48.89527813080819, 50.02208094443045, 48.46824576777797, 46.071002944823235, 49.87699247175648, 44.7653635855644, 46.04803354509416, 49.62275620429747, 45.06445215594384, 45.37895171873031, 32.85393926405138, 14.803510423629517, 4.687589781899606, 13.391428724411996, 10.641701125329542, 2.216236961464728, 0.11847247910355369, 0.018251430010423064, 0.10868188309212846, 0.011913346167984269, 0.079886170194274, 0.1669927803619254, 8.830569251891106, 34.23435272709016, 43.61511284305204, 53.13498373954527, 41.32088322793284, 18.54794913722623, 0.667232919123865, 0.04637085772570103, 0.055634040505655354, 0.02332510584364495, 0.06130103419925417, 0.026021179923367117, 0.023263048891338612, 0.04267464053907222, 0.05077944858179939, 0.019870713886414326, 0.0616613291804829, 0.05671076942235232, 0.030697788554994814, 0.06029879967231424, 0.04750906902876112, 0.03404110542408401, 0.01936487177567136, 0.06812059185317448, 0.024185106571343158, 0.03880426092373748, 0.01546217569886076, 0.05057971030774136, 0.054221722943287705, 0.05119173795044903, 0.06777729253254591, 0.03751476257739048, 0.040146642319497564, 0.08824264961144618, 0.04752520284044647, 0.039337496423432906, 0.015951983589348535, 0.020913646834331657, 0.04550495237532643, 0.055954345697236646, 0.07714737522145433, 0.011161249882030872, 0.015518994524984833, 0.011756758753871246, 0.03833513549198547, 0.1002893056119642, 0.8346918946312321, 29.69033983445937, 55.55324262188327, 39.64852579178349, 36.86593363361974, 55.61181537566647, 54.24697176102669, 44.77817012417702, 17.55465203715909, 0.4238373780202481, 0.20885263659781028, 4.845376437710178, 7.3590587416002835, 3.58928200698668, 4.758571934315467, 4.026977088182203, 27.51667603369682, 45.56281282055763, 53.231619173480624, 55.00993159509475, 57.20616079145863, 54.90704390310473, 54.7970018079204, 49.82003573448428, 45.73540887525005, 42.954075797911614, 42.299079202836566, 39.517855951862956, 39.044735739308024, 39.61681342894031, 38.888794068367254, 39.58122968673706, 39.80131387710571, 39.47584736731745, 40.185702231622514, 37.481812430966286, 39.3295233480392, 38.61362803366877, 39.402083273856874, 39.74681646593156, 39.905605777617424, 40.79288905666721, 41.94035491635723, 40.20701639113888, 40.84738646784137, 39.875815376158684, 39.68616093358686, 39.162473524770434, 39.90338963847007, 39.62052399112333, 39.63977498392905, 39.43774938583374, 39.472933046279415, 38.21429152642527, 38.6985630373801, 37.06534693318029, 37.91288483527399, 39.20061857469621, 42.374941764339326, 46.534227017433416, 47.90807247161866, 49.871850244460575, 47.90334601556101, 50.485316784151145, 51.05804558723204, 50.13678673774966, 52.69084984256376, 49.67434321680377, 46.04425238024804, 54.4346454066615, 54.2363303707492, 51.485030881820194, 50.51570338587607, 49.101284934628396, 52.30378250921927, 51.23111624871531, 52.961732649034076, 50.75863930486864, 50.00533634616483, 42.64367118958504, 38.38553436340825, 39.03491412439654, 38.1336554404228, 39.63250290962958, 38.93321098819856, 38.8471894879495, 40.11393854694982, 40.175198124301055, 40.53338896843695, 42.12355705999559, 41.21692865125595, 40.316666249305975, 38.84349853761735, 37.648473939587994, 38.95826316648914, 38.0476104059527, 38.5273947254304, 39.395721189437374, 38.52740257017074, 37.82116413116455, 41.21811320704799, 42.53774758308165, 41.800840131698116, 43.645977973937995, 44.797001423374304, 47.40113750580819, 47.95087337493897, 48.69602564842471, 49.99099223844467, 52.078065795283166, 49.23230778786444, 47.62016657860049, 50.584870461494695, 46.099330302207704, 49.3282764188705, 51.549408743458415, 46.57322322168658, 46.63835810076806, 37.50853553895028, 20.192510697149462, 5.462607472173629, 14.308545550992413, 11.513178233177433, 0.48841267583831666, 0.23503635739607198, 0.025819453651145585, 0.1650308598313601, 0.07805512812469276, 0.061197256098591515, 0.24151922323771063, 10.120117087518016, 38.49043423129667, 47.52871651803294, 54.74275935080744, 47.15546377243535, 23.836119982504076, 1.170127475934644, 0.014633693743587263, 0.05310862783282515, 0.012876895169967846, 0.052287825908992565, 0.03612691769376397, 0.02296021433487054, 0.11999081174332289, 0.028714777623874047, 0.030644980199154348, 0.010965875436311529, 0.10615893339197482, 0.01906187634073919, 0.02954103409372751, 0.0628564723076359, 0.06074240671530847, 0.07892591728558464, 0.08599962843882461, 0.09775024508276293, 0.11456818860625068, 0.11392835963277087, 0.2424047749129034, 0.19677496935811736, 0.11158193191212994, 0.1791157387197018, 0.1442779056848057, 0.17977432918644723, 0.13897046386714906, 0.14843517373646462, 0.22292614674135564, 0.17185091161199156, 0.12419731626587531, 0.1254630467343715, 0.17570762804919676, 0.1218091597359988, 0.10765765418088245, 0.10125295995103736, 0.07599813608272422, 0.1218346244986019, 0.19562709385589247, 0.7319519656800455, 32.612191823221025, 59.612574115876235, 52.053299950015166, 38.45965931492467, 54.48275327682496, 63.266238397167584, 48.952846757827274, 21.531401949544108, 1.22999828909674, 0.9847551584243776, 10.616128252398584, 11.991331827255989, 5.4255842201171385, 4.171318104190211, 4.359326622178478, 29.097042122194846, 45.08792754142515, 52.648409797299294, 54.602746425136445, 59.01331440094979, 56.599636846973056, 58.41372912929904, 51.66975098271524, 47.26175608173494, 44.68859495655183, 45.45708533256285, 41.818616313319055, 42.519014343138664, 42.95189888246598, 41.919181962167066, 41.43852687651112, 42.47828445126934, 41.98284595243393, 43.05004835128785, 39.93770253273749, 42.14288257783459, 41.625733760095414, 43.613963588591545, 41.757125316127656, 42.4488196065349, 44.04851121287192, 44.30891344624181, 41.919362391194994, 41.338486825266195, 42.09542189874957, 41.48772908795265, 40.71166853750906, 42.33266253625193, 42.5391988600454, 41.37674954629714, 41.855447369237105, 42.07552763723558, 39.113977339959916, 40.53601695645241, 40.550855282814275, 40.90761446183728, 42.36309620641893, 45.37855948171308, 48.80732682443435, 50.89055645850397, 53.24153884764641, 49.70936606007238, 51.859797662304295, 53.31857812020087, 53.71420014289118, 53.25052107534101, 51.66749169749599, 47.950390923407774, 55.82747513248075, 56.702147991426536, 53.307532725795625, 52.417852878570564, 51.150197752060436, 55.29099295216223, 53.75223144408196, 55.0767844723117, 53.223899948981504, 52.46863188282136, 44.20480981949837, 42.066694459607525, 40.989411569410755, 39.27509653952814, 41.382774306881814, 40.78557775866601, 40.443562769120746, 40.70302755601945, 43.9984147010311, 42.24962203733383, 44.09056686585949, 43.03977566380655, 42.937472404972205, 42.24913566343246, 38.367016853824744, 40.80175753562681, 39.57418903227776, 40.77296341619184, 41.584603786468506, 40.63619036828318, 40.90336261257049, 43.8150909639174, 44.37378552652175, 45.24841916176581, 45.633172296708636, 48.174483776092536, 50.25809388006888, 49.050439250084665, 50.714069412600615, 51.26060462767079, 53.5050005297507, 49.70647135088521, 47.04150715181905, 51.54559619965092, 47.75404883969215, 51.00856488750827, 54.40339980586883, 50.58516071688745, 49.937871579200994, 40.3291158522329, 21.393662037387973, 8.033392131328583, 21.07213947080797, 19.776694351626983, 8.924280558862995, 1.4813586012009652, 0.2285883179114711, 0.406080256666868, 0.17200739273140508, 0.2657329489386851, 0.48413490215616845, 13.793284373898661, 46.39309229389314, 51.837832389339326, 61.17819601489652, 51.768249542482444, 25.91262471291327, 1.9150998106887265, 0.09348838304680201, 0.09266631707789437, 0.13714567307502995, 0.16936438939263745, 0.08265721746870587, 0.17416371573363582, 0.19435209372351248, 0.14581267091055072, 0.08044785053859796, 0.14086055599393385, 0.21201423549604034, 0.23379895685901567, 0.1447192029727082, 0.10212074604726608, 0.12989357834862125, 0.13402187295498388, 0.13817183252784515], [0.04328788626157949, 0.018742178273837895, 0.07178374085455172, 0.0859634537670401, 0.12841974009549426, 0.034093743325361324, 0.0325497773836457, 0.03938045863422655, 0.02133137542724369, 0.05313676241184435, 0.07199071482905457, 0.0660560385233933, 0.058321473113591635, 0.047862132139984644, 0.009995894168593712, 0.09750446875489528, 0.03668774385005236, 0.0685124917917194, 0.08929942959859487, 0.08125440322703893, 0.07238407033465563, 0.02798262930985901, 0.01829648364125, 6.746659576892854, 38.71546453045261, 44.016881219802364, 27.598328013573926, 25.733805817942468, 49.73274730866956, 43.015668776727495, 20.8918849883541, 1.6051548551167212, 0.04752408435207702, 2.538980120612729, 7.205241524404095, 2.2111802908682057, 4.557891709189262, 1.3162054890586485, 6.396119315778056, 26.72482990449475, 52.713709415928015, 53.34583074815812, 59.401436851870635, 56.38945271891933, 54.14255826703964, 48.698222175721206, 44.9782580714072, 41.41183906985868, 41.516056445337114, 38.26572948886503, 39.80056862677298, 40.66318411980906, 40.67371568372173, 40.0756719035487, 40.01178041581185, 38.9746194501077, 37.69076885715608, 35.81074545460363, 38.23609990458335, 37.73012984183527, 37.119620769254624, 37.44501275400962, 39.856984076961396, 37.421070606477805, 37.80813401745212, 37.530838135750066, 39.19924182276572, 36.92099978846889, 37.3942925853114, 38.658421501036614, 37.945467964295425, 36.84441943322459, 37.27258928360478, 38.190643556656376, 37.72941597046391, 37.7242462865768, 38.24129704506167, 38.22304625664988, 37.02699399763538, 36.78065738370342, 37.14632034301758, 40.26232965530888, 43.31048196361911, 43.17705469746744, 47.35352385428644, 45.213663039668916, 50.2821066302638, 49.686741828918464, 52.83468707915276, 46.47770566325034, 45.7960565628544, 52.715172460002286, 48.34913907512542, 47.42853918383199, 46.137659703531575, 47.757947675643436, 48.235355038796705, 48.4686811508671, 50.05818243949644, 47.88458139665666, 40.94006815264302, 36.964922489658484, 36.480125381100564, 36.23828772575625, 35.23190559879426, 37.47583866119385, 37.799638163658884, 37.92137676669706, 37.92002354898761, 36.839359575702304, 37.314335069348736, 38.194475712314734, 37.67543238978232, 36.56222451117731, 35.90139535165603, 35.302500417155606, 36.96110994585099, 38.41396370241719, 38.0304814154102, 37.65980174464565, 35.597180243461366, 36.32255200416812, 36.99006488246303, 37.46664070313977, 39.81494019108434, 43.196286078422304, 42.05428408038232, 42.126436079702074, 44.30406147433866, 47.786173051403416, 48.77415926225724, 50.63718311248287, 48.731048491693315, 47.82647540492397, 47.03665125754572, 50.56434077601279, 45.09071634661767, 45.56467202401931, 44.01158602006974, 41.77111641053231, 19.483299101552657, 4.82193096030143, 0.5556609157112338, 2.434764461171243, 2.412427788780582, 0.17600338395324447, 0.10276267410165842, 0.04972985832982006, 0.09434241020391065, 0.10445577437959372, 0.148628534328553, 0.6440197808607933, 16.228337864721976, 36.49270049987301, 31.30068263699932, 37.96970428959016, 33.28267981929164, 9.522293940667184, 0.0764558889392403, 0.008999753871091433, 0.05132373873024218, 0.04729949801619496, 0.04107650452023072, 0.04037719264987015, 0.01742802913330736, 0.06792785179230475, 0.049658470426595984, 0.042955499863432306, 0.0665121136473552, 0.00874858141140712, 0.03352082064074855, 0.03211843349309939, 0.06162580185299439, 0.015697016121609318, 0.004204197640290424, 0.07195651666411469, 0.04269463926433556, 0.08637193184826644, 0.0004430251752754914, 0.08431415073573591, 0.039795291414784814, 0.029855382951697516, 0.029969662202582247, 0.047218089682921294, 0.009634626255701146, 0.05767970976810302, 0.03118967637419701, 0.032119080837395404, 0.0862094522604058, 0.03792870286551695, 0.06164309628788502, 0.0798304756021788, 0.045797176614043214, 0.04382250838041787, 0.052377822087897416, 0.029491577372555772, 0.035319809591577905, 0.0730567874627248, 0.046936763044927395, 10.689570711505029, 48.937051373143355, 50.754916975575114, 30.161267442087976, 32.37528850955348, 59.950541219403675, 45.164880521835826, 24.5061392553391, 1.3152067555535225, 0.12386826618063836, 2.057924953199202, 7.750007750526552, 4.8321011758619745, 7.740273898647678, 5.347860493967611, 9.235350008933775, 33.1453223382273, 53.74898372157928, 53.89979100996449, 59.941484466675796, 56.40993925832934, 54.621981728461485, 50.500633639674035, 48.118025179832216, 44.529844868567686, 43.28555137880387, 40.47383562211068, 41.81463510759416, 42.83558099500595, 42.1054200203188, 41.629844404036, 42.03125976747082, 41.866520220233554, 40.05906851060929, 38.21472298714423, 40.24105864186441, 39.328715339783706, 39.353304678393954, 39.526971540143414, 41.41645962192167, 40.235563401252996, 39.21432333607828, 40.500350844475534, 40.62334852833902, 39.0727924531506, 39.01357643065914, 40.23003285931003, 40.35454457806003, 39.17640186125232, 38.08686940900741, 39.88332671503867, 40.194190240675404, 40.843895558388006, 39.88640577562394, 39.65560959231469, 37.72364224157026, 38.65718987680251, 39.9710819029039, 41.928630951912176, 45.454182778635335, 45.16335079746862, 48.25979924971058, 48.420161431835545, 52.153747927758005, 51.06534511812272, 53.648829921599365, 46.02679391061106, 47.31280572952763, 54.279680405893636, 50.38473936819261, 50.11619821671517, 48.32650699923116, 50.33187758538031, 50.8582910414665, 50.247240681802076, 51.87527925737443, 49.97123133751654, 42.50417209440663, 38.82034870886034, 39.23144055951027, 37.825506194945305, 38.704128880654615, 38.43597604382423, 40.35398760149556, 39.09195323144236, 38.083688366797666, 39.2399795593754, 39.382471422995295, 40.48645388695502, 39.21821040491904, 39.41999673843384, 36.032331912748276, 37.756131233707556, 37.90545586616763, 39.89400340664772, 39.73693993783767, 39.55795826450471, 37.762587455011186, 39.448131899679865, 39.48315866531865, 41.13361750879596, 42.55045214006978, 44.71913845308366, 42.70653893870693, 44.474045230496316, 46.424067251143924, 48.429429992552734, 50.46715621025332, 51.25215191994944, 50.63007577773064, 48.96118571681362, 48.885346689531886, 48.704411675853116, 45.89188398853425, 47.96286406055574, 46.991716584851666, 45.552579356778054, 23.523820869384274, 6.940701680798685, 0.9234129048643575, 5.037480400454614, 3.447845260943136, 0.402573075505995, 0.1425703263451015, 0.08222143601385817, 0.10278577931345471, 0.03044917195614788, 0.2074067069277648, 0.5528917223695786, 16.656631269762595, 40.655257009690814, 36.72696405841459, 47.5371103902017, 40.5982022131643, 13.197702861601307, 0.21952477764458428, 0.040639225363491044, 0.05127816032918711, 0.03841758570483616, 0.0345639719237243, 0.018194143870665182, 0.09764293148632973, 0.08118238330127732, 0.04279893064390748, 0.043164385227306236, 0.02710822612918433, 0.008429633153061713, 0.041148926642152577, 0.038587638071828315, 0.04642541084678904, 0.022489462881499243, 0.022149547754276185, 0.07203134813255842, 0.1492307254023129, 0.15883049657267911, 0.15031708404421806, 0.23254660228567742, 0.21485226949857128, 0.12865395615658454, 0.19840004102837658, 0.1409462046238684, 0.14771140450912137, 0.18207686772990614, 0.1898976448442667, 0.15104866736838896, 0.16233994535380797, 0.13359772071482676, 0.1603751902979228, 0.28458906938472106, 0.162771099637593, 0.18418584649841632, 0.180001367003687, 0.08066592512712364, 0.1709475560534385, 0.18469719486611505, 0.176753445318149, 10.780749147938145, 53.89684923233525, 56.58394736628379, 40.4549454873608, 36.60215423953149, 59.99165942592006, 54.000121316602154, 27.50141016898617, 1.7735059246901543, 0.1913056225185433, 6.0862829608301965, 16.98916392941629, 9.284261964982557, 10.638393586681737, 5.026532575007408, 11.104489814850593, 33.28162862408546, 55.30760811221216, 53.51270014239896, 61.50331343373945, 60.22266349484844, 57.547701174213046, 52.31228620775285, 49.856125462439756, 46.34388616008144, 46.16307273987801, 42.92592886955508, 44.436853316522416, 44.70005612219534, 45.0504885181304, 44.300770605764086, 44.810035459456905, 44.36703120508502, 43.00964793851299, 40.80653890486687, 41.95857040343746, 42.184930386081824, 41.52060247236683, 41.33529009357576, 44.32296337619905, 42.498351297070904, 42.414059562067834, 43.25564330623996, 42.629970350573146, 39.55216100139003, 42.77567463536417, 42.06795354043284, 43.02730252665859, 42.034782055885564, 39.73710075501473, 41.518762880756015, 41.68679721893803, 41.53621350565265, 42.05140898304601, 44.130496594213675, 39.05494566886656, 41.73084935834331, 40.66073656082153, 45.28739183179794, 48.180802714440134, 47.90520914139287, 50.325935194569254, 51.36335895907495, 55.53898480630691, 54.617239582923155, 57.581735580198234, 48.79238259407782, 48.99381983664728, 56.33081720721338, 52.547926518224905, 51.52328183574062, 51.087518276706824, 51.81286258082236, 54.22863468047112, 51.82335492103331, 54.366074531309074, 52.461834415312744, 44.54657769972279, 40.65292712180845, 41.201168567903586, 39.90471932195848, 39.88747658268098, 40.80342062057988, 41.24407929758872, 41.57725326476559, 41.92536753992881, 40.10482688103953, 41.268350924215014, 42.558249811972345, 41.89713824179865, 41.096343225048436, 37.33631210942423, 39.01253700256348, 39.018169526130926, 41.80204037697085, 42.29413309404927, 41.95372627627465, 40.723753360009965, 40.33500332986155, 41.14585922610375, 42.948917881135024, 44.160341908854825, 47.07982870840257, 45.33242064137613, 46.398858178046446, 48.09050583070325, 50.2713946373232, 51.13109188695108, 52.55561436376264, 52.30960722892515, 49.22041516150198, 48.27203704464821, 51.44581502483737, 46.09549422417918, 47.53657694785826, 46.76843566279258, 48.531442995994325, 24.465534879315285, 8.030222365933081, 1.3696520727488304, 4.29817000704427, 5.319775833237556, 1.6894815237291398, 0.45656630889542643, 0.1564948477091328, 0.3628629692379506, 0.41659735683952615, 0.6209346099245934, 0.9521282091736795, 21.011089740260957, 48.66697657492853, 44.6465902943765, 50.4089129355646, 46.25347552760955, 13.965615668604451, 0.3671929901165347, 0.21542885791390173, 0.19675287538238112, 0.12913199502133554, 0.10410481417972235, 0.19554260967960282, 0.22510857802004586, 0.13847967729933802, 0.11028351247190468, 0.16123399018279969, 0.10072586847649467, 0.10173455346375705, 0.11336134731649392, 0.06679930468840946, 0.29602011245104576, 0.12268960160473663, 0.11731804588869696, 0.18958433020499446], [0.04602899098949087, 0.031181576909617554, 0.008006640578499966, 0.029601767629144654, 0.049996188796696164, 0.03489660347000726, 0.06183592827930566, 0.04315043093576547, 0.08298882628760992, 0.042498126220438755, 0.052242753125967524, 0.0551402278905434, 0.11089662795946484, 0.03913287433885759, 0.029262614759406256, 0.06005374729753502, 0.018795695261008317, 0.09561251503445449, 0.05876095477311362, 0.031961827884398164, 0.04020248629873799, 0.04570044269184432, 0.016209811437875032, 0.3172371013750953, 16.23566681338895, 38.750789396224484, 40.631154044981926, 29.496719875643333, 37.60440218833185, 51.29143837959536, 19.869801613592333, 2.3787767944797396, 0.2080301186370273, 1.4539666065285284, 4.965515204014317, 4.572863886433264, 4.39135963878324, 1.6320237036674254, 1.218618880356512, 12.454519617942072, 37.0618599460971, 53.456053272370376, 54.387094513062515, 56.85754837528352, 51.627656106025945, 51.51331117076259, 45.434857260796335, 43.75183882251863, 40.64942444524458, 42.81550238209386, 40.594856431407315, 41.67431623704972, 42.35683610362392, 42.394231980846776, 41.36213479503509, 40.37203834902856, 37.384133646565104, 37.34414508265834, 36.82356811338855, 37.34581601235175, 37.320610861624445, 39.42269532911239, 36.975085350774954, 39.65775120642878, 38.585394813168435, 38.948319958102324, 40.06450883803829, 38.58205295378162, 38.483593617716146, 37.055238985246234, 36.82765914547828, 38.07854613950176, 38.140743163324174, 37.225924845664736, 38.36085873265421, 38.29571208646221, 38.7989325677195, 38.463165913858724, 38.638452714489354, 37.46361655573691, 37.21263193315075, 39.70458038391606, 39.85838436311291, 39.40058100608088, 42.644200709558305, 45.090539839959916, 49.39629031765846, 47.80057207230599, 50.88551229046237, 48.13374603948286, 45.487326806591405, 52.088228656399636, 47.79684189827212, 46.585233519154215, 41.132927171645626, 41.71459897871941, 39.34888024483958, 40.29517166076168, 39.12173971053093, 40.43582393277077, 37.117636049947436, 36.81810032936835, 36.59326222635085, 37.10885778550179, 35.5951209991209, 38.03066968917847, 36.02589138092534, 38.2849451803392, 36.20078594453874, 37.68411259497366, 37.02271469177739, 38.13480861725346, 36.775519078777684, 36.27161218274024, 35.643679941854174, 36.71957431300994, 35.46353724695022, 37.63884059844479, 34.70683751567718, 36.31587613013483, 35.501337128300825, 35.35826083152525, 37.526974601130334, 35.61834143054101, 38.06038164323376, 38.470936129170084, 39.139190335427564, 40.723647456015314, 42.96421120243688, 44.27971140030892, 46.552717070425714, 47.70859641413535, 49.9570402022331, 48.064790771853545, 48.82447934919789, 50.82714349992814, 48.70188566946214, 50.344868475391024, 45.30447375389838, 27.61090901590163, 9.855015854681692, 0.5724880676115713, 0.15015358555941813, 0.29604021459817886, 0.0985920531374793, 0.11429183004844574, 0.07011355426643165, 0.06539331884273598, 0.05840207705454481, 0.21191692700789821, 0.5577213857923785, 2.3900690530577013, 24.512801401076782, 35.82446590546639, 41.81098338096373, 33.43521687292284, 23.656016511301843, 2.202572649525058, 0.023119091394267256, 0.026240748383345145, 0.04404453598263283, 0.08268238345701849, 0.037249807238338456, 0.10487267942798716, 0.10017407832727318, 0.054120825333220345, 0.010342434041141983, 0.05266488672444417, 0.0593914183217191, 0.10582898698386647, 0.06169817034876155, 0.009707309805127162, 0.07224232108602602, 0.044382802105598876, 0.04358433164475907, 0.03330613216084819, 0.01609338714080232, 0.04719044923061325, 0.0633868234862964, 0.04946602530957711, 0.04049646487880138, 0.05411540143071644, 0.026919680399700042, 0.005183071273589327, 0.07081989499349749, 0.016809217782030185, 0.04756125493816311, 0.0937476195394993, 0.06969994339611262, 0.020464788258616484, 0.008951072813943028, 0.06966496382148997, 0.010192845797827168, 0.016429418202249274, 0.009434979912194033, 0.0449641096225429, 0.03727889559682339, 0.05496534150874904, 0.03155609239794074, 0.389320612434418, 24.337200810832364, 48.758399178904874, 39.91559997681649, 33.52189733136085, 49.05565600241385, 53.25542796042658, 25.264096106252364, 2.4613686723093835, 0.16313401080908316, 0.6151900536591007, 1.6552342065880377, 0.9151542318924781, 4.265961464374296, 3.8956313748513502, 2.7595668646597096, 15.87387131106469, 40.649518582128714, 54.13363487489762, 56.22716465303975, 58.36661361878919, 55.37268023337088, 54.25139227221089, 48.09384769009006, 44.21584736916327, 43.302594077202585, 43.507887009651434, 42.538281025425086, 43.66950827260172, 44.467875342215265, 44.384336702285275, 42.531185457783366, 41.09020079335859, 39.84795478082473, 38.4627305307696, 38.9638800005759, 38.86129040871897, 38.92450724878619, 40.701823388376546, 39.48768900286767, 41.15702621398434, 40.27127265930176, 40.372112874061834, 41.645914354631984, 40.44719880627048, 40.2420941475899, 39.44124421765728, 38.91508963800246, 39.55703650751422, 39.515431927096465, 39.839600132357695, 40.32604071401781, 39.57351046223795, 38.43473657484978, 39.361557345236506, 38.80505930992865, 38.8378660140499, 38.35679123478551, 41.41966419835245, 42.308155567415305, 42.98458399311189, 44.47530038895146, 46.381780178316184, 51.60081924930696, 49.533549739468484, 52.87033750164894, 49.170585370832875, 48.36861364303097, 52.38315166965608, 51.94204584244759, 48.25975218126851, 43.61776436528852, 44.01855999423612, 42.79793408609206, 43.60188268846081, 43.024862812411406, 42.04213649995866, 39.96226049238636, 38.66017480050364, 37.9582078226151, 37.82180739987282, 37.78784359655073, 39.068501380182084, 39.48489235293481, 39.43560777171966, 38.47690989894252, 38.100589859870176, 37.85850117283483, 39.66888681534798, 38.69243629517094, 38.63289471595518, 35.690226708689046, 37.7043677145435, 37.62685775756836, 39.27273135031424, 37.92051776762932, 38.20812163814422, 37.64150781016196, 37.173051295741914, 39.421534307541386, 37.954081489193825, 40.3278842279988, 42.50141859054566, 41.627141890987275, 44.58836270916847, 45.10844545979654, 46.74523092085316, 50.08767474082209, 49.84910049746114, 51.626655901632006, 50.140575747336115, 49.787311400136645, 50.87436099206248, 47.72206975567726, 51.098092986691384, 46.89197855611002, 32.59176804173377, 11.929740809625196, 1.3042363764778262, 0.7543980354262937, 0.48365171518056627, 0.07605339400470257, 0.1441011538789157, 0.05569060843798423, 0.12158374602515852, 0.030892470648752588, 0.36749078381446104, 0.9724235330377856, 2.969715936530021, 27.446520520794778, 45.39983049515755, 45.09383070853449, 38.95579991802093, 30.523133547075336, 3.8120902834400057, 0.11884891938778663, 0.008327890931057834, 0.029619766864925626, 0.06816608215411825, 0.06812593148600671, 0.0170355316461815, 0.07614376939712994, 0.037490895108109525, 0.027409723862224532, 0.047436616263322295, 0.07972897661309089, 0.08626909220531102, 0.03518666734077758, 0.004868526584393676, 0.036697683840869896, 0.020256609610852697, 0.006579100370271913, 0.03273872147885061, 0.14106657235853134, 0.17745403272490348, 0.09115184552126354, 0.10472169115899072, 0.15737902042606186, 0.13488574434191952, 0.22502527361915958, 0.11780578342656936, 0.13234240904210076, 0.11382311447373322, 0.27941923228002363, 0.23394426841649318, 0.20041555707012454, 0.12479967587897856, 0.080188276967214, 0.213084077282298, 0.13651764951646328, 0.17903392052938863, 0.17318647865566517, 0.12449660383525396, 0.11535548950515448, 0.1376907446331555, 0.12947642815209207, 0.7594413454494169, 28.036992165350146, 54.57430139664681, 54.65605535814839, 39.618731467954575, 49.589117957699685, 60.178368168492476, 28.22768799720272, 3.0907232626791927, 0.4123555892898191, 3.425778251501822, 15.085706326269335, 15.965902863010285, 15.491427471560819, 6.327889196334347, 3.2098037244812136, 19.15606752518685, 40.30952753559236, 54.958972161816014, 54.475826371100645, 59.846712158572295, 56.54508844498665, 56.6541499476279, 50.133797891678356, 48.834520616839015, 43.73391751320132, 48.082959190491714, 44.87306794812603, 47.305576801300056, 48.2427094828698, 47.14165310705862, 46.044613238303896, 44.56555412661645, 42.724715202085434, 40.6040112433895, 40.718971990769916, 41.94601097414571, 40.64509807094451, 43.44034379528415, 40.920632808439194, 43.67601156234742, 41.98583479850523, 42.51630790771977, 45.033567413207024, 42.41540101266677, 42.67574833285424, 40.58792560331283, 40.26821321056735, 41.11433513702885, 41.73440302571943, 41.67016244703724, 41.37687113977248, 40.885045143865774, 41.47232201791579, 42.60479657880722, 41.484426452267556, 41.1473261925482, 39.86109864327216, 44.704351117534024, 44.468165597608014, 44.29593432334162, 47.103876759929044, 48.024821819797644, 54.54015324192663, 51.42582270406908, 52.38799971918906, 50.87291755983907, 49.045622579513065, 54.604617395708644, 53.70004038656912, 50.69093135095412, 45.85585701850153, 46.347765384181855, 43.20156558867424, 44.26102915117818, 42.79578462723763, 43.5046471318891, 42.129307254668205, 39.86379331158054, 39.323961427134854, 39.25295868227559, 38.74141885388283, 40.961292097645426, 40.254127979278564, 41.96659165043985, 39.97479638745708, 39.416972591030984, 41.37123077146469, 41.229201747525124, 40.83047713002851, 39.871084997730875, 37.188450521038426, 39.04852082652431, 40.314308904832416, 41.41585557691513, 38.31933259963989, 40.396266829582956, 39.521727331223026, 38.88548751031199, 42.890604003783196, 40.51943709773403, 42.761938495020715, 44.37847275887766, 43.076889130377005, 46.503012795602125, 47.330911390243045, 47.7444507998805, 50.86677512814922, 51.85900142115932, 53.15060261757144, 51.02914164143225, 49.41713771512432, 51.40597551099716, 48.96530420549455, 52.86317525371429, 48.636915529927904, 33.17932144288094, 13.54109166129943, 1.6064686039763114, 0.8767681400622092, 1.4438275247812273, 0.5290201162138294, 0.511057744583776, 0.2883652086940504, 0.35284253918836195, 0.255487289039358, 1.1920535251978905, 2.5219930708408356, 5.146026111418202, 33.91436969080279, 44.87748845931023, 52.69838863803495, 47.743674170586374, 34.55293155485584, 4.219808405445469, 0.2209047011790737, 0.10649936754376658, 0.1285801818894763, 0.21452703453119726, 0.14188856937952582, 0.14386794139300624, 0.23033001880732276, 0.13417830810912196, 0.16645959848838468, 0.31817592680454254, 0.28911781347086357, 0.16008280518074192, 0.16992671325081782, 0.22902288894739845, 0.24882736495665966, 0.11068636746776682, 0.20667417365456783, 0.13187800654240195], [0.01520254179805277, 0.034643530154660825, 0.06248776568099857, 0.045800765735968474, 0.014880728370870554, 0.04450739098472461, 0.08484395416153055, 0.06577251704349633, 0.0155706939685549, 0.01407780598158077, 0.029503698798737703, 0.046605836044275956, 0.0353574474912978, 0.038302867868614775, 0.03371566744341004, 0.09259049735602834, 0.06335084033649295, 0.016343669980884563, 0.019175605923538248, 0.0799190813315011, 0.059280741599298296, 0.04764472021751347, 0.058264265497845996, 0.023418200848203514, 6.0591882082723805, 34.861504416311945, 43.78371592490904, 29.136408990429295, 25.841796513526674, 42.25801198713241, 21.749228815878592, 2.9585362009463774, 0.0651815414969479, 0.5564791589013992, 1.3821598983580068, 0.5324637120769871, 1.9942853551718498, 2.031191181271307, 0.12917235253318665, 3.1887624148399603, 21.986492987601988, 46.08807702218333, 53.794291019439704, 60.097426137616566, 54.016308938303304, 53.19433704499276, 48.41282267724314, 45.281520043649984, 43.54908758594144, 44.61532508173297, 44.64839458465577, 42.57113087561823, 42.93153001416115, 43.16495026311567, 41.160199411453746, 38.3056592172192, 37.54650015984812, 36.415476875920454, 37.13810689987675, 37.56573938554333, 36.902435210443315, 37.418470075053555, 39.00371559204594, 38.89060228101669, 39.34396943738384, 42.17744258142287, 39.405578105680405, 40.59264029225996, 39.81883902703562, 38.997545703764885, 41.1495227198447, 41.755022925715295, 38.62606586948518, 39.26786368893039, 37.56207981417256, 37.72198700135754, 38.76050510714131, 36.538654988811864, 38.65667604630993, 39.16007695659515, 37.47462272644043, 36.70191972486435, 38.705466408883375, 38.65290664857434, 42.49457405459496, 44.58804499718451, 47.61582059244956, 47.12827390240085, 51.039308424918886, 43.74062868856615, 44.26817178726197, 52.740326619917354, 48.77574782217703, 47.64680339444069, 41.38743408264653, 38.531481835149954, 36.82296799075219, 36.63061103513164, 35.39596657599173, 36.45091156805716, 34.35647180003505, 34.93655504718904, 36.80121452577653, 36.81390731565414, 35.41235031620149, 36.50423619054979, 35.614066047053186, 36.65698897454047, 37.20232786670808, 36.53885110732048, 37.48389128715762, 36.90037596610285, 36.305599520283366, 38.292727162761075, 36.35440164996732, 35.72778340308897, 35.41966553657286, 36.4376578792449, 37.86586346164827, 36.53814508068946, 35.920156048190215, 37.88217267682476, 37.59583180950534, 37.959074666423184, 36.72287694869503, 38.18179468954764, 36.43989363024312, 37.89202959306779, 42.72785309822329, 44.37697441347184, 44.621534193715746, 47.7188338002851, 50.370399182842625, 49.471003624700735, 47.56962291656002, 49.963202245773815, 48.73155447744554, 45.53746254213395, 34.52889919281006, 16.575438207195653, 2.4858258760744527, 0.04054183260567727, 0.35501488874996867, 0.4345103924072558, 0.16249497090616535, 0.09195616889384486, 0.06843413631882399, 0.02095070059200929, 0.05627086258403236, 0.4482298626774742, 1.5995827605647426, 11.107951306527662, 29.011924728270504, 27.949842983676543, 38.12581462244834, 35.91360569000244, 9.828966413774799, 0.05289828307145546, 0.08110248033077487, 0.0741406639797553, 0.02688133386865018, 0.045838200622388435, 0.02134207384510627, 0.025563243205749223, 0.012127244619712716, 0.005349162487208002, 0.09739959131806128, 0.026361424468397617, 0.07715180320965667, 0.08482810380237718, 0.06621709318771478, 0.06115103035324043, 0.07110291085536442, 0.030057957666295192, 0.022048862733607812, 0.02286029731734626, 0.03204244714710982, 0.011442503741671963, 0.09141138844913052, 0.012462997974287118, 0.005881569175530346, 0.06456625798056204, 0.04025958666217424, 0.046091814029721484, 0.0445831302673586, 0.06601510644559899, 0.12167716278664528, 0.01793651041694947, 0.04270536449527548, 0.021054340796845577, 0.08487491177455073, 0.04868804387027218, 0.006000606790034762, 0.010470587144335432, 0.05560698994104901, 0.026111901970580224, 0.09416537494548867, 0.03452104801732687, 0.03186006267975656, 0.03611644527183906, 8.086864332998953, 40.60478002794328, 50.43593022131151, 30.852198831496704, 35.036006742908114, 48.52872479346491, 21.93985796743824, 3.6142049922097117, 0.033198278472428365, 0.36456962927214565, 0.28936507600930433, 1.2674384155581075, 1.223017083060357, 2.5527937277670834, 2.051290141478662, 6.22621008465367, 26.5824302165739, 48.40804523037326, 53.56305553067116, 60.479115901454804, 55.44442038382254, 54.716275507403964, 49.88878311649446, 47.617271869413315, 44.78561870513424, 46.36919721480339, 46.37122900255265, 44.904290014697665, 44.22320965797671, 45.724222275518606, 44.14904940512873, 40.6384692653533, 39.35160236973917, 38.47490949015464, 38.33173121175459, 39.901216645394605, 38.61025871769075, 38.80385121991558, 40.66248593791839, 40.83927108395485, 42.06202683910247, 43.56674609645721, 41.30001621861612, 42.16558917876213, 41.62230560856481, 40.12230888489754, 42.60345905057846, 42.236384038002264, 40.596103745122115, 39.910575420625754, 38.78432566119779, 39.11751531785534, 40.04409290129139, 38.8714454250951, 40.50561858761696, 40.12381115267354, 38.47775320852957, 40.29019417301301, 39.893658238072554, 40.58853749305972, 44.64532729118101, 47.1014880364941, 48.807887723368985, 50.11278575466525, 51.893957584134995, 45.860469725824174, 45.80469362197384, 53.10134549294749, 50.636343725266, 49.43191328356343, 43.83738179360667, 41.955338370415475, 38.70427400835099, 38.40054135168753, 37.05725116114463, 38.31127997367613, 36.622232852443574, 36.04335769530266, 37.45825467571136, 37.44924499142555, 36.870001131488436, 37.51352479380947, 38.31854812560543, 38.81113898369574, 38.791060370783654, 38.272032737731934, 40.33832165502733, 39.19544496843892, 38.2093571847485, 40.37501150561918, 38.194334506988525, 37.91820356922765, 36.70443004177463, 38.66778027626776, 39.29501433526316, 39.92917529998287, 37.11736148403537, 40.67635936121787, 39.867041034083215, 40.97799747220932, 39.651589162888065, 38.77875981792327, 39.09438117857903, 40.65078943006454, 43.38953341207197, 45.17915794926305, 47.23059285071589, 49.800898490413545, 50.892172475014966, 50.90912103652955, 48.08179424655054, 50.63857555389405, 49.8362547351468, 48.80061957143968, 38.89690945225377, 19.818740198689124, 2.7860379603601273, 0.9747322768934312, 2.1442661266173086, 0.46435573769192545, 0.07844328189328795, 0.023595031178105744, 0.06593733319952604, 0.052016351161704916, 0.12903407366285402, 1.0981096952192246, 2.3429304986230792, 11.619985353562141, 33.360538867212114, 32.85322539268002, 43.393946078515825, 41.08551748337285, 15.490730270262688, 0.42285932888907773, 0.05740382618481114, 0.05813522947831981, 0.03405536615079449, 0.02674820885482815, 0.00946580729026708, 0.01988181641565696, 0.07337629209242522, 0.04715009554920178, 0.0609110226674426, 0.04637132120889522, 0.0057066641203428236, 0.05265763570224086, 0.06364146728188762, 0.16114201366661057, 0.05618342513879461, 0.04484221737291064, 0.08743970519712857, 0.05416748391824865, 0.1471503830004123, 0.08758280276050491, 0.1848584563741761, 0.19589569960390368, 0.06766394216326937, 0.11878456034126783, 0.16744250461699503, 0.20270721716505868, 0.1943692234494994, 0.1975288764844018, 0.1861923380244163, 0.11074975358262179, 0.11135018265415585, 0.09568783679916974, 0.23176494745477555, 0.10093193846724688, 0.15021560803776787, 0.1372410203780859, 0.1902877368153103, 0.16079974090380056, 0.20031378995026314, 0.183994033403935, 0.18810696028653653, 0.1415814294089233, 9.224241856605776, 46.72130446280203, 57.405256379035215, 39.76064282078897, 37.565500120962824, 51.61281777966408, 29.70827094970211, 4.790925604681815, 0.19196119459886707, 1.4386240104513786, 7.274666005565274, 9.16621333168399, 8.92248313273153, 6.926309524043915, 2.4307879132609216, 5.69451907950063, 27.85466274907512, 50.52865112981489, 53.06084702091833, 62.44439594207272, 57.61402845382691, 56.47088112369661, 52.606118802101385, 49.30055310649257, 47.582468678874356, 48.50994056270969, 49.742992539559644, 45.73790350267964, 47.70628221573369, 48.56404181449644, 47.00894755701865, 42.063807595160704, 40.86843782855619, 40.85141866437851, 40.719709396362305, 40.947014670218195, 39.91245423593829, 40.36594690815095, 42.38382201040945, 42.49971628189087, 43.79369443462741, 45.96365159557712, 44.52409467389507, 44.553253573756066, 43.640349372740715, 42.458147002804665, 45.67266271960351, 44.35211050894953, 42.22809999219833, 42.52812993141913, 40.96690108699184, 42.16255718661893, 43.640082651569, 39.80609916871594, 43.01753190255935, 41.67603031281502, 41.54627830751481, 42.08161907811319, 42.881115790336366, 41.66512220136581, 45.827325697868105, 49.41849093283377, 49.67431183784239, 51.374565170657256, 53.95090733805011, 46.686567952556, 48.39278721040296, 54.97030781161401, 53.85904935098464, 50.61848125150127, 46.49442280492475, 43.94465469544934, 40.20146623734505, 42.09428833376977, 38.385091135578776, 40.28741321256084, 37.73460526620188, 37.635228095516084, 39.72832641293926, 39.78115289442001, 38.91955329525856, 39.50424140499484, 38.5050646720394, 40.17741426344841, 40.50068032357001, 40.515236239279474, 42.03253061540666, 40.60648625896823, 39.80955085446758, 42.61885827587497, 39.60750956689158, 40.28604038300053, 38.80951904481457, 41.29256371528872, 42.129825007530954, 42.63862309917327, 40.16068143229331, 43.0265925776574, 42.517888622899214, 42.815263117513354, 41.013102685251546, 42.071703326317575, 41.08226976087017, 42.31496087966427, 45.09574090280841, 49.01542032918623, 48.73328032032136, 51.66169835675148, 54.179538373024236, 52.07905815493677, 48.407770664461204, 51.63939575995169, 48.49956197123374, 49.14396816684354, 39.72866373677408, 21.408549393376997, 3.341596833159847, 1.0549355538622027, 1.4032140782763882, 1.4879555375345292, 0.4439588918560936, 0.26059672777210513, 0.20809437809211595, 0.18244523344741714, 0.5022033309984593, 3.6234546765204403, 5.189046667468164, 18.730139309360137, 38.305192455168694, 38.429021681508715, 50.76007489235171, 47.91269694605182, 17.465690720465876, 0.5537173812908511, 0.17922843025336344, 0.20116439269435024, 0.11313983299318822, 0.13368661755756026, 0.08431964358615299, 0.20154144584892258, 0.1434080281685437, 0.1396953822263787, 0.22680313386503728, 0.22875843539593682, 0.08180352739028393, 0.15467803955318468, 0.18565371692661317, 0.30340415816153254, 0.17926059062442473, 0.10847742188601725, 0.2531828965631224, 0.13982099000244372], [0.01576630398631096, 0.04260033384085663, 0.011630437558426732, 0.05030903995277421, 0.03128781606773696, 0.009070652435653874, 0.026470486660517996, 0.04068453180333299, 0.019400063939692996, 0.040500965645356525, 0.07261097025606902, 0.001895915113216747, 0.018237006490028674, 0.07448665992987734, 0.06031471514894117, 0.01970414338903802, 0.11097468465806977, 0.0362064759247005, 0.06267417402517411, 0.0357276173458705, 0.017525257182217414, 0.05760239234434501, 0.08041353746046943, 0.03091692417529562, 0.7095760083006275, 18.411607550036525, 38.97478811202511, 36.49587369734241, 23.450223476656024, 35.18543727936284, 32.85326853875191, 4.737311707388971, 0.4302488597891023, 0.13881882442341698, 1.5129820978449238, 0.7935440864774489, 0.9816985901805663, 1.7468498647212984, 2.3228680654879543, 1.3715829820402208, 7.680611706549122, 27.221001886552383, 53.14143211610856, 57.0436962189213, 55.84706344912129, 52.47257778721472, 50.8128817619816, 46.45031967470723, 47.468355163451164, 44.78007247371059, 45.24943897801061, 44.42128150693832, 43.97291929491105, 40.87861245678317, 40.34300496501308, 38.336975420674975, 38.50907725672568, 39.84544054154427, 39.1721970804276, 38.17486778382332, 35.94654967707973, 38.54366471690517, 38.112749207404356, 40.94584972627702, 41.74384809309437, 42.512201186149355, 44.898280943593676, 44.84042598355202, 45.71298076260475, 46.47399510106733, 47.60486933492845, 45.68566929909491, 41.78961823063512, 39.263698131807395, 38.808903232697524, 37.425169483307876, 35.8214888265056, 37.850805482556744, 37.97106535203996, 35.81681728363037, 38.22209704306818, 37.146163448210686, 37.848808996139034, 42.114382636162546, 45.0780745475523, 47.54500612135857, 48.46688078295801, 48.83647395718483, 51.91873911888369, 45.82235605485978, 44.01729699104063, 53.93364890929192, 49.9661361786627, 47.67158885155955, 46.0778514031441, 42.3269005744688, 39.41461132418725, 37.78679632371472, 36.98885679244995, 35.42232882591986, 35.62235009285712, 35.212736975762155, 34.791882345753336, 36.7716633888983, 36.44950343716529, 36.36405068059122, 37.15844438922021, 38.61194925923502, 36.525118889347205, 36.34931041348365, 37.327600525271514, 36.59225417721656, 37.927303468027425, 37.74138704422982, 36.39121701640468, 36.66798337813347, 35.54334571284633, 37.85661843515212, 37.1701918878863, 37.92308692009219, 38.78181926665768, 39.56381436317198, 39.522562796069735, 40.612969936863074, 38.925091681941865, 37.385114239108184, 36.973512480335856, 37.541146124562914, 38.44884926272977, 41.29938471701838, 44.867376589006, 47.74036369016094, 48.57880169345487, 49.43542772723783, 50.04548572724866, 47.67993173291607, 49.008163944367446, 36.78904341113183, 20.161924054545743, 5.037351942831471, 0.3908383551864855, 1.9246684327240915, 2.058805525302887, 0.4563590974336671, 0.09076942209034197, 0.11510352318685864, 0.04417017057177521, 0.13419991178858665, 0.19414428471317216, 0.21755190205670175, 3.728865923420076, 22.03731906029486, 32.429925164868756, 32.11997555148217, 41.43289827531384, 35.38201078291863, 3.796487340042668, 0.011489057947220582, 0.0417699481570913, 0.017571427386193987, 0.018755347325256275, 0.10215045493696967, 0.0725331663664791, 0.08188133127987385, 0.020275445797690944, 0.027090211571644873, 0.011770149013177763, 0.06177464124536323, 0.05382821038966218, 0.032453889988603137, 0.006183857415547414, 0.03557612345884404, 0.05349462889435311, 0.037401301125364925, 0.02914189270907833, 0.015897545381449163, 0.027256448820774114, 0.013727281494216334, 0.019375807680790464, 0.027890574269657655, 0.024611378959830732, 0.028320403221333702, 0.044990060850977905, 0.003608069673646242, 0.0364544968901863, 0.0530368683769578, 0.0253544497724262, 0.001862902828443405, 0.061323135835869666, 0.04411053445730959, 0.053307213144557136, 0.019610100350673162, 0.09931176975970307, 0.06540173814902384, 0.06652444766293611, 0.04938189736417225, 0.037212188490816665, 0.05914359653909361, 0.03372312147891329, 0.08747004993980931, 1.1771224102666302, 23.749874907155192, 47.11517318602532, 38.100534946687766, 26.041723643579793, 41.38120535881289, 32.87130163561913, 6.505900083049652, 0.06845010925204524, 0.11015831072243953, 0.4487684224882434, 0.30449053212519617, 0.24092650101069482, 0.7791255762980831, 1.8485267700687533, 3.206169403368427, 12.111605425034801, 33.01939856621527, 53.67438808564217, 58.294112528524096, 57.762709817578724, 54.83014975824664, 52.34486933677427, 48.2642589845965, 47.4096372819716, 48.27456697340935, 45.58815525424096, 46.68431258970692, 46.36577298564296, 43.757640008003484, 42.39745224675825, 40.177998696604085, 39.943841042057166, 41.14620439467892, 41.33780041048604, 39.6675100634175, 37.34921278492097, 40.01215304097822, 40.896686738537205, 42.67208091674313, 44.96565941841372, 45.08082412904309, 46.459705906529585, 46.398109005343535, 45.86304280065721, 47.57745588979414, 49.85734924193352, 46.31302495156565, 42.89854680338214, 41.73321062518705, 40.370755733982215, 39.894140689603745, 38.07762438251127, 39.531725452792266, 39.668722075800744, 39.12972957857194, 40.78220844268799, 37.70015116660826, 40.12486234787972, 42.59623404472105, 46.35781449656333, 50.011055161876065, 51.569981575012214, 51.23575249025899, 53.46970312057003, 47.60795231788389, 47.14946646844187, 54.157471118434785, 51.41660905653431, 48.92673553959016, 48.0805940012778, 43.1427731821614, 40.759262577179946, 38.416901557676255, 38.87754471071305, 37.83699089480985, 37.1871365270307, 36.04747618398359, 36.98544433040004, 38.091819440164876, 37.76309344076341, 39.16655278974964, 39.55321611896638, 39.823039885490175, 37.214691177491225, 38.44957097884148, 38.25595886476579, 37.31969302700412, 39.52919944640129, 39.60030809525521, 38.108258093557055, 37.75436616713001, 37.59105044026529, 38.874924567437944, 39.137138935827444, 38.85366532110399, 40.33161832440285, 42.082901693159535, 43.17601919174195, 41.750924048885224, 41.37448633870771, 39.69124432533018, 39.148282389486994, 38.169266639217255, 40.444190348348315, 42.99442129750406, 46.48236151664488, 49.90561400690387, 50.64474936454527, 50.33468600242369, 50.556401898784024, 48.13806849141275, 48.24509428393457, 40.43635345274403, 25.227121883823028, 6.5540113852870086, 2.095580932594115, 2.691170289631813, 5.556459984471721, 0.5021125955447074, 0.06863819915921458, 0.15331172174023044, 0.03664251401900284, 0.0848745517132263, 0.4276428738188359, 0.5750556266115558, 5.835832270883746, 25.01185828639615, 37.41664617292343, 34.26589250564575, 44.82920800485919, 40.75090792871291, 5.639525488499673, 0.06947419260658565, 0.010901135261050396, 0.05490870079806736, 0.03472468567891948, 0.09626542878968102, 0.020248157745828072, 0.02351503819227219, 0.0719656101277759, 0.006352630415706025, 0.04270952435270433, 0.052871638533448985, 0.024717583643993544, 0.021262306855210376, 0.021680876229619308, 0.0498472536433368, 0.13060250079199193, 0.06191372067757672, 0.023116289427684202, 0.027551168590904247, 0.18438640831699296, 0.10069649666547777, 0.15647476088375817, 0.10925838723778726, 0.2656210388147062, 0.16952770401633557, 0.11432680962306839, 0.12812319512088455, 0.10289409648506873, 0.11910179735071237, 0.22560440544639865, 0.12306915220594215, 0.17651552905238446, 0.15738072114125376, 0.15645787630590702, 0.17320693320324346, 0.2612255020968376, 0.17956062129908995, 0.10021331735075482, 0.15489824386613985, 0.1840020926488984, 0.17282398117165412, 0.24061530077409363, 0.11993707067543462, 1.0838225844406313, 27.004390954971317, 53.33258882645638, 49.91582393646241, 34.419649416400546, 45.60990871921663, 42.672633970937426, 8.523244684742343, 0.6166919537128941, 0.8178203096312862, 2.924895012570966, 2.570872667335695, 2.6670869367737926, 6.55785579835215, 6.257717013359071, 3.944154035660529, 12.392129417388672, 33.31390973060362, 54.418508775772594, 58.05770735586844, 58.72731477983537, 56.26383881415091, 54.63331345588931, 50.34982635128883, 50.82617859686575, 50.608118349506015, 47.86700917828468, 48.67737477825534, 48.77544579967376, 43.82317889121271, 43.89040047122587, 42.68136124457083, 41.99209097893008, 44.106232812327725, 43.089672134768584, 42.527066969102435, 38.28180728420135, 42.219855170096125, 42.0474434668018, 45.923988588394664, 46.68248084283645, 47.899309896653705, 50.10789063669021, 47.95111263951948, 48.34241613265007, 50.602768236590975, 52.92621166475358, 48.85647412269346, 45.52004329619869, 43.26411562581217, 42.73685886013893, 41.44826612164898, 39.74426692531955, 41.277956808767016, 41.57480962814824, 40.349217999366026, 42.39318470801077, 40.9885408032325, 42.122458796347345, 46.293887707494925, 48.4161723813703, 52.631520071337306, 53.21698873273788, 54.23765220949727, 54.44864042343632, 49.47602033615113, 50.304009145306004, 57.390955417386955, 53.059474191358014, 51.263538560559674, 52.56071736735683, 45.88301550957465, 43.763111714393865, 40.53146308468234, 40.980229300837365, 39.465778643085116, 38.866275741207986, 37.338120322073664, 38.552199794400124, 40.818580581295876, 40.41505106033818, 40.67191531581264, 41.08629411266696, 42.9420498109633, 39.3546578961034, 38.808797328702866, 40.867147368769494, 39.67671194384175, 42.00790989783503, 42.08535317451724, 39.891802956981046, 40.417749651016734, 39.942432911165305, 41.14145832677042, 40.73319058264456, 39.52365713734781, 43.01813986993606, 43.85734665778376, 45.536015187540364, 44.616544938856556, 43.76909725127682, 40.74391434269567, 42.054892047759026, 40.925445556640625, 41.7864764121271, 45.31903751434819, 48.10031567850421, 52.29372162972727, 52.253889960627404, 52.54657722288563, 51.352191971194365, 48.80645213588592, 50.755324902073035, 41.4800569318956, 25.671530346716604, 6.4249085322503126, 1.603775161408609, 3.6794188089909095, 6.020759276805386, 1.2842749443746384, 0.12545986746948573, 0.3595596593954871, 0.14631845747991917, 0.2474240450969627, 0.7763580377063444, 1.1781299691046438, 10.405260651342331, 31.96683837521461, 44.055406739634854, 43.76978758842715, 53.001332898293775, 47.97865160049931, 7.215430371222958, 0.12914852719874154, 0.13721812967090838, 0.17969411978077504, 0.13588801717325566, 0.18324600983290903, 0.1266933762798867, 0.12716732423512206, 0.14086009634117927, 0.16278341833141544, 0.09818610314640308, 0.1487356487421259, 0.06091636613071446, 0.15582684968267718, 0.10190250291939705, 0.16873331680413217, 0.2595177695395485, 0.27468618786623406, 0.06852235134330488, 0.1176595142591865], [0.031498978627965815, 0.026729836151184096, 0.06419301611341297, 0.019519318931645924, 0.018687776455114928, 0.030489090882662325, 0.08128818004362046, 0.02719325997355965, 0.03924671883484529, 0.0856336452547581, 0.06673423318012107, 0.027395606776999853, 0.03150839193333541, 0.06982955781202163, 0.02839780682998319, 0.0531306681824067, 0.08674343086538777, 0.04695687285293976, 0.018288307567878116, 0.06562524430093265, 0.021147592849428618, 0.026869331186096516, 0.04819814213401368, 0.06833652139551218, 0.050726768545686245, 2.109004754212595, 32.940311816430864, 46.36611423184795, 30.88572332935949, 28.746305742571433, 40.59437005750595, 9.938957518146886, 0.1399580431320975, 0.033706558657990354, 0.16614642174493882, 1.0116027403743038, 0.14775096528953122, 0.31626404713719125, 2.0414144714032454, 2.000513833857352, 2.0217913437274198, 10.219765882338248, 36.120138091425744, 55.14921888228386, 57.83493634193175, 54.13738466078236, 51.69557586792977, 50.67505751886676, 45.29994341634935, 42.61792867414413, 44.383689511206846, 46.057949296889774, 43.569479988467315, 42.41522842837919, 41.572232630945024, 41.71352817166237, 40.924982716960294, 41.84255061611053, 39.775779247283936, 39.19125195472471, 36.80993395466959, 37.009296263417895, 38.18469332110497, 39.58849783866636, 43.96250540210355, 46.27921412068029, 46.62020537161058, 48.618429399305775, 50.335454786977465, 50.73825474708311, 52.68917106813001, 50.548019793725786, 48.38669969189552, 42.529902842737016, 37.793256467388524, 35.79547174515263, 37.73238128231418, 37.09912638510428, 36.970719752773164, 37.49812949088312, 37.955403327941895, 40.17014611151911, 39.519852438280665, 46.33395864117531, 50.7871941597231, 49.15544109959757, 50.562497262031805, 51.62780123372232, 45.22285315298265, 43.682244208551225, 42.7603538574711, 52.218051264362956, 50.36964216539937, 50.75371280793221, 45.57832579458914, 44.9067650302764, 44.24806964012885, 40.90869703600484, 36.9182345174974, 37.28028889625303, 34.38084933065599, 35.585883817365094, 35.41091865108859, 34.31172932347944, 35.73484759176932, 35.75698152665169, 35.88037929227276, 36.1261942309718, 35.66020096501997, 36.80985550726614, 37.26397968107654, 36.616235548450106, 36.35896728884789, 37.612972567158366, 38.99056780722834, 36.72267690781624, 36.087582418995524, 36.2347811268222, 37.38783636400777, 37.68894887739612, 38.138103408198205, 42.92255955357706, 42.808328367048695, 42.31497264677479, 42.76347214175809, 39.43648246026809, 37.44857034375591, 36.98431468779041, 37.529026000730454, 40.47825613329488, 42.457072273377456, 45.923812081736905, 47.68063775954708, 49.98103726294733, 50.67174311607115, 50.32202459150746, 40.12032808796052, 23.915585241010113, 7.751256044833892, 1.025979268935419, 1.2263300149671494, 1.0339747753835495, 5.540125764185383, 0.34774002589045033, 0.08771028745198443, 0.03612486074768728, 0.057584071351635846, 0.15703135440426488, 0.0524751995239527, 0.49204120532639567, 5.441089349408304, 26.23582213155685, 34.43387193064536, 30.33720535616721, 37.09965590507754, 19.274430928691743, 0.9291562966762051, 0.06177927607730512, 0.05645381587166941, 0.03910817949461841, 0.0343267068326954, 0.02941896372865285, 0.02831577988071067, 0.012663244739204887, 0.01058151954860096, 0.018891936971715862, 0.0376665169343112, 0.03144094555248176, 0.0060907164457133945, 0.05881599436003355, 0.03949740961674721, 0.05585049098778156, 0.07519454815455022, 0.048007512645375346, 0.09080034905984517, 0.037899001636692596, 0.022020647715356563, 0.031661519502860405, 0.012135437930062895, 0.028393311809087475, 0.011062392938671815, 0.053185171507779634, 0.06825077317414746, 0.0347582824648388, 0.07788563883232494, 0.09397783662162482, 0.036510145517006036, 0.02633830201962302, 0.0403613614429149, 0.0085802718944427, 0.033537042552545186, 0.061621358543033564, 0.07531952007763809, 0.04904266980086123, 0.051941128988419814, 0.05383109088025747, 0.03481331822131911, 0.03736179397110978, 0.03152265074482608, 0.11164351772036284, 0.06534591332198152, 5.1362677447257505, 39.800399964855565, 50.379491236902055, 31.153228975111443, 34.56986050451956, 42.27285423586446, 10.71445324728566, 0.33341795085899295, 0.04824023100457365, 0.26465181501642354, 0.14802752303019648, 0.052252876977886886, 0.3012175900080512, 0.8908596839154921, 1.3795491932861268, 2.8601035860276993, 13.145621630453295, 41.18488288694813, 56.99348988071565, 59.0537501150562, 55.24087682847054, 55.02302838910011, 52.31553000788535, 49.907794844719675, 44.59428548812867, 47.429649214590754, 47.99477254190753, 45.76374015500469, 45.74223772172005, 43.57838769112864, 43.90619193353961, 41.856992783085, 43.39792728424073, 40.76524419169272, 41.39670264336371, 38.75441366626371, 37.893269062042236, 40.30105913839033, 40.85254830698813, 46.414390763928814, 49.08121808882683, 49.51021555931338, 50.01891951407156, 52.992895880053126, 52.14862138994279, 53.38765498130552, 52.63358716041812, 50.94759556554979, 44.93050321455925, 39.893673927553245, 38.30003846076227, 39.08041361839541, 39.42495853670182, 39.42510366439819, 38.834665359989295, 39.830900315315496, 41.77838456246161, 40.48883868801979, 45.62757115210257, 53.31818980555381, 52.11040181498374, 53.77534989387759, 52.90571728060323, 47.37977235547958, 43.0476321712617, 45.19799709320069, 53.75646760386806, 51.550389336001494, 52.01298190701393, 47.98314663671678, 46.44031370839765, 45.57708632561469, 42.080387453879084, 37.811750442751, 38.023272099033484, 37.13034060693557, 36.8046191430861, 36.70308466880552, 37.9572311524422, 38.29983057514314, 37.60866580470916, 37.33131893219487, 38.38685227978615, 36.960411763960316, 38.83178634028281, 38.64543061102591, 36.99835285063713, 37.75410729069864, 37.894767407448064, 41.74542488590364, 39.51366293814875, 37.612568563030614, 39.17493489480788, 38.29515510989774, 39.35884306507726, 41.47397333575834, 44.01471607146725, 43.68230304410381, 43.87613088853898, 44.068366250684186, 41.54193624373406, 38.82127046585083, 40.70867576906758, 40.08787439715478, 41.43296495560677, 44.25485141815678, 47.068143967659246, 51.359934729914514, 49.94847374577677, 50.724891231906035, 49.26209034458284, 43.7700778438199, 27.65262342268421, 12.775210642045545, 2.3665247809502388, 3.525427781766461, 4.4396768654546435, 8.438965697442333, 0.9029976422748259, 0.025268529181278525, 0.05922807305450401, 0.025159851948340094, 0.3688824897812259, 0.05958527687095827, 0.7770958723079774, 7.540271753265013, 28.275313415834983, 38.89131615238805, 32.89271189320472, 46.10561001685358, 25.78415728384449, 1.858261725114238, 0.06362761641221662, 0.12367273755972424, 0.01871326994601517, 0.07195368213879486, 0.03505277815425108, 0.10745167612068116, 0.024745903999334382, 0.014583714167407204, 0.05058005887774691, 0.0448209316199345, 0.0039473123193132665, 0.0071123736955585985, 0.023293868608532414, 0.05231012672846837, 0.009876749301779895, 0.05522270491647144, 0.03245489739422356, 0.1356677822167835, 0.030280471734342077, 0.07032727747554741, 0.08458115535998538, 0.1010596759677414, 0.07207752791263404, 0.11907594188326791, 0.16654340850730098, 0.2101272843297451, 0.10238617253039153, 0.25826984295441263, 0.23203090253856876, 0.20663081307805356, 0.2232511365605939, 0.11735299481980263, 0.14452293124650756, 0.2747786700004532, 0.12673447689702436, 0.17503400693737692, 0.10469812629443985, 0.1310113619171804, 0.10756131096352493, 0.21542194780082474, 0.1208916545334843, 0.17787876719188306, 0.16373310688762896, 0.1326155806741407, 5.2955223475733115, 45.53130049859324, 57.85064935684205, 43.75748311319659, 37.80321536525604, 49.383075852547925, 14.622068443605977, 0.40198052181832256, 0.19407680768880153, 1.6302168393327345, 2.7731289498267637, 0.5492532950255179, 2.0027130577833425, 6.39165222644806, 6.454878382144436, 4.326303697401478, 15.25526156348567, 40.533581164575395, 56.768773371173495, 60.43237693848149, 57.49908731829736, 56.65519329809374, 53.76134703236242, 50.403468685765425, 48.07298068077334, 49.48202940725511, 50.34615501280754, 47.4607418429467, 48.177429476091945, 46.885369362369666, 46.406702918391076, 44.731678270524554, 46.47238692929668, 42.21251641550372, 44.41281703210647, 41.13373517990112, 39.33872522846345, 41.51163985652309, 42.418923301081506, 49.49240799873106, 51.51996351057484, 49.8828838717553, 53.83854712209394, 55.21639339385494, 54.74193173070108, 55.082836689487586, 53.35777436533282, 53.20588450278006, 46.608697137525006, 42.1802862997978, 40.01064685083205, 41.051506611608694, 41.35441557053597, 42.47635856751473, 40.777587890625, 41.20545571850192, 44.104793302474484, 43.15221040479599, 49.14221094500635, 55.541538269289084, 53.92882439397997, 54.624386141377116, 55.08673552543887, 46.52518203181606, 43.93564108879336, 47.66813324343774, 56.24649017087875, 54.01640307518744, 53.36357947318785, 49.60941622334142, 48.55480855511081, 47.9912071074209, 44.72040145627914, 40.62941643499559, 40.7762856637278, 39.35657201274749, 39.663120931194676, 37.94138477694604, 39.52104483881305, 39.59893134332473, 39.08366918563843, 39.7893584928205, 39.93069717960973, 37.90989206683251, 40.62216397254698, 41.63836771442045, 39.98808145523071, 39.330468639250725, 40.32778616874449, 43.40963948157526, 40.853634803525864, 40.07786450847503, 40.67092295615904, 40.22418852775328, 40.669840381991484, 42.659090026732414, 46.55527445577806, 46.05212849955405, 45.50152186424502, 47.804306168710035, 43.015986488711455, 40.20924037502658, 42.68841758851082, 42.254423018424745, 44.13520736079062, 45.44420819128714, 48.32707182053597, 53.06511455966581, 52.134955852262436, 53.49815599380001, 51.72595854728453, 43.425124999015566, 27.163597999080537, 9.675448767600521, 1.681287324716968, 2.783477878378284, 3.837245178799476, 17.63676097316127, 2.40257675609281, 0.17406318967621173, 0.34519750264383137, 0.17909681634797206, 0.6411981871051173, 0.3240297272080376, 1.7337251238284574, 11.526083811636894, 33.505176267316266, 46.59472565497122, 40.07142789902226, 51.816439782419515, 28.584029443802375, 2.081640829001704, 0.1920888095252937, 0.1493073801600164, 0.11411506292079726, 0.2675788531139974, 0.15948936283107729, 0.1797467653429316, 0.10035724994996864, 0.09618534195807674, 0.12577913461192963, 0.1218480310372768, 0.11483096442515812, 0.10032348079426635, 0.18488214381279486, 0.16476161056949248, 0.09928396842893093, 0.18267052458418956, 0.12316574057143544, 0.22668575387327905, 0.09583119483244035], [0.04284660046499583, 0.05118397747977607, 0.08602591291550668, 0.027941825551792022, 0.028635512421568556, 0.02250245764791485, 0.056417874856701786, 0.024371306156559337, 0.021823297720402483, 0.016658036075832865, 0.0486275190938144, 0.0875802057224416, 0.06963184584052333, 0.012488590099007614, 0.04280315561880989, 0.06043271567191809, 0.041154614844990355, 0.053035102544292334, 0.02032774087462214, 0.02483479701162827, 0.06307913576282802, 0.04541050522558151, 0.02385256120995168, 0.04895776427621323, 0.11893963185890068, 0.23172652048449363, 14.374556099214862, 40.26293762268559, 35.4516093192562, 21.23436870113496, 34.576916848459554, 18.212084424111154, 1.2529684242702301, 0.0776461137819194, 0.1488820328226974, 0.1495050155227223, 0.14729183347475144, 0.0755632279681102, 1.143417115653715, 1.3907833517559114, 0.33570515232220777, 2.088756253642421, 12.622435304426379, 39.42421328636908, 54.85855556303456, 55.858720733273415, 54.56865318359868, 53.156454793868534, 49.95201564604237, 48.399247354076756, 46.2764213931176, 47.44691941045946, 43.73826742172242, 44.08622087970857, 44.10281642790764, 42.197250550793065, 43.077869722920084, 42.175873633353945, 41.34580204563756, 37.08580993836926, 37.26852570810626, 40.35638024730068, 38.24516450205157, 40.694425798231556, 45.45536733442738, 46.656942290644494, 47.59083509445191, 50.049776800217174, 51.4793905135124, 51.04094405328074, 50.770512319380245, 56.33719498111356, 52.52258408454157, 51.8477402963946, 42.08011288796702, 38.49783574381183, 37.77726888656616, 36.727917194366455, 36.61276817321777, 36.56301682995212, 38.403938124256754, 38.79454343549667, 43.31320801088887, 48.11804871405325, 49.17373503408125, 48.81715628408617, 53.132457733154304, 45.581067531339585, 52.50881264286657, 60.03892398649647, 40.74962531366656, 52.38501479548793, 50.76205568928873, 51.450298293944336, 50.03691142605197, 50.457934717978205, 46.78106961711761, 47.26975379451629, 43.55569285731162, 40.92694782441662, 37.230616000390825, 38.761571991828184, 36.445714427578835, 35.45882648037326, 34.28448454026253, 36.93073903360675, 35.863320904393355, 36.165896461855986, 36.83487238422517, 38.441945891226496, 35.01375121455039, 37.05257569589923, 38.95250120470601, 44.9879345586223, 45.66865013491723, 43.42374824708508, 38.44191843463529, 36.233216101123446, 36.78550935560657, 37.102409408938506, 35.762967063534646, 40.64805161568427, 45.35535473977366, 44.48173699840423, 44.299793935591175, 42.46674876059256, 42.351070219470614, 38.36618923371838, 38.403812608411236, 40.68258024031117, 42.87928796583607, 44.37090650681527, 49.674566791903594, 49.69371580308484, 50.689060380381925, 41.921394178944254, 29.27888320338342, 9.463386804826799, 3.6381792541473144, 0.5975503582627543, 5.099432276141259, 5.742187644204786, 5.631846468294821, 0.5254136194144526, 0.08367095097538926, 0.051527188700293346, 0.08133787616726854, 0.08902915377890872, 0.1461084727798739, 0.5143026478828923, 7.374013268178509, 30.591398477554325, 26.583803046134214, 30.208883054794807, 30.203142666047622, 8.326847687844309, 0.03394317640472324, 0.0545176703693165, 0.046516671070768956, 0.05140971294754455, 0.03643689218968634, 0.025875360832639763, 0.03957521733677676, 0.041159065815830426, 0.0666857551362726, 0.066107458344871, 0.03281568267172383, 0.051135936106044444, 0.09076142413241249, 0.04498716503862412, 0.025392005317694238, 0.09943588366431576, 0.05755796307517637, 0.04034697814213653, 0.0688279667989381, 0.07737278893229461, 0.029326351359486583, 0.009012567649234929, 0.17098104941748804, 0.02375674659326192, 0.04776059101606089, 0.018653785133914604, 0.047756373702037724, 0.02540075212656971, 0.06005364004522563, 0.023419099086294734, 0.07851573082828715, 0.04024268676256461, 0.033254681695853515, 0.06679235627093623, 0.03510171968129373, 0.030534157920027935, 0.08051623920759848, 0.045783678144817395, 0.007944386837358076, 0.03494010194234791, 0.03374061509666424, 0.015848455424871177, 0.027004561026490508, 0.0702421191418844, 0.027585631056178003, 0.6557924072107961, 19.77240327865847, 48.00274279809768, 37.147928514788234, 28.229096128094582, 40.27420266982048, 17.58105743315912, 1.6277809248816584, 0.15023889711066601, 0.11550658502646032, 0.22937314434637948, 0.03710643771374899, 0.0829115969639632, 0.7468748068617237, 0.18972293083225528, 0.36803323535188553, 3.7099897621139406, 17.067301465618996, 41.21790139905868, 58.56955312913465, 57.40912383602512, 56.85512435051703, 54.49929391184161, 51.75834163542717, 49.45527492030975, 47.84247083048667, 48.096008916055005, 46.49702725871917, 45.52089837289626, 44.614740648577296, 43.379484299690496, 44.69193681593865, 42.81692620246641, 41.38183686041063, 38.52226426524501, 38.2055877870129, 40.26618926755844, 40.421605340896114, 42.86098618661204, 47.19254193767425, 49.03379271107335, 49.94854042606969, 51.89980583806192, 53.45760260858844, 53.82803124766196, 53.948557838316894, 56.294562739710656, 54.1731959004556, 52.30490822945872, 42.15307681791244, 39.12726633010372, 41.30234218412831, 39.8276133691111, 38.90675067901611, 39.61169081349527, 39.751193831043864, 40.05065894895985, 43.79754620213663, 51.1601056591157, 51.529083021225475, 52.680569310342115, 53.159965315172755, 47.99250148957776, 49.72378077045564, 55.00428338204661, 44.99839551987187, 53.26333938106414, 52.934797733060776, 52.48069317110124, 52.513001734210604, 50.12793787064091, 48.726447551481186, 48.03619669329736, 44.90294464172856, 42.57339408320766, 39.56416345411731, 40.10321478689871, 37.25451500185075, 36.9792156065664, 35.29138049771709, 38.15386741392074, 37.929390168959095, 38.601256878145286, 38.62114329491892, 39.31839950623051, 36.76043756546513, 38.42259683916646, 41.53921804120464, 46.54608042009416, 47.16296334420481, 44.81040416225311, 40.08653686892602, 37.69567574224165, 39.407303948556226, 38.73657080434984, 38.53738500225929, 43.945725502506384, 46.9953251654102, 45.761363198680264, 46.722814575318374, 44.10349892031762, 42.51113822383266, 39.867951023963194, 39.22789081450432, 41.48851748435728, 44.213289983810924, 46.41443391000071, 51.34219384962513, 50.70758965707595, 51.6386152082874, 43.21960849146689, 31.97434775290951, 12.829043211475497, 4.755102597898053, 2.8210723255911185, 6.019284465620595, 9.21257084415805, 7.853960856314629, 1.5233492899325587, 0.1253207995285911, 0.027102951613825657, 0.07604220146012884, 0.01973589581827964, 0.12098480316419756, 1.019930728981572, 7.948343378882255, 37.39106055228941, 32.348404584392426, 35.15641958482804, 35.819464883496686, 12.182160039101879, 0.15516573112578164, 0.025862446505456202, 0.016778344438681682, 0.021922318415055354, 0.03376390033912274, 0.045470122187849016, 0.07387599592367489, 0.03526845488757376, 0.015143387361369548, 0.042014843483846036, 0.1388397845890253, 0.023767558009093328, 0.006781934118348986, 0.049199396068410534, 0.03151838363508784, 0.06844241006840622, 0.05787520774550015, 0.027977157526859836, 0.04068987526660485, 0.06120092565974882, 0.20176871349253964, 0.15129101162235584, 0.20824315236701121, 0.15098638442014495, 0.12090966526058414, 0.10153524802937623, 0.2453823594917213, 0.10260405559693614, 0.09906550313556388, 0.07115331944078207, 0.14570023984678332, 0.21734191735665645, 0.11358841577725065, 0.16727886823636873, 0.17841584079207914, 0.1219491852867988, 0.17189065625350322, 0.15912326473382213, 0.07298127417602847, 0.10647158919563217, 0.23626602044509304, 0.15674293762253177, 0.1395882524910473, 0.22103603929281238, 0.14128556625256616, 0.8333064399419293, 22.725836230862527, 53.05696779681791, 47.549148144260535, 32.65106643399885, 45.476481453064956, 24.16938416419491, 2.2377737154883723, 0.3004530342596193, 0.584112930922739, 0.7233749678538692, 0.3891600404054888, 0.1652569936648492, 3.7896229470929796, 4.51805954979312, 0.9144812389727562, 6.006337702274323, 16.34675520081674, 41.97679765762822, 56.710616388628566, 60.057068870913604, 59.0766881358239, 56.95261486114995, 56.24041441948184, 53.108499896141794, 50.830759925227014, 52.35860547711773, 48.11063543442757, 47.86503230371783, 48.367605593896684, 45.59041846183039, 45.91923467574581, 44.95751265556582, 45.32519171314855, 40.878949780617994, 40.601187136865434, 44.23390203906644, 41.90252365604524, 45.5694337814085, 49.938569761091664, 52.90278727008451, 51.601203641583844, 54.951139188581905, 57.247533952036214, 57.1888788284794, 55.644390659947554, 60.246688012153875, 55.770330121440274, 55.63192144516976, 45.93030752674226, 42.15718746185303, 43.299256140185946, 40.96629311961513, 39.927978977080315, 41.83302317896197, 41.26052579572124, 41.39506701500186, 46.43707383063532, 53.46278405958607, 52.99615536966632, 53.83631921583607, 55.00085130814583, 47.87708966962753, 47.98748477812737, 56.68291661047167, 48.3482918431682, 53.618988529328384, 53.8526362757529, 54.81710787742369, 54.71613430207776, 53.99260213298183, 50.621062171074655, 50.512149718499955, 47.24378378160539, 43.44017121099657, 41.85711437656034, 42.244993640530495, 39.12925104941092, 37.95081023247012, 36.45484570533999, 42.27217566582465, 38.82042715626378, 40.8395613393476, 40.761615999283336, 41.829473433956025, 38.067575270129794, 40.815356393014234, 45.22057817828271, 48.19998310458276, 49.65295453225413, 48.33409286314442, 43.08872292118688, 39.474643199674546, 41.0165661381137, 40.60453291862242, 39.72786357325893, 45.17826364886376, 50.67606556800104, 47.952203058427386, 48.449508605464814, 44.62745305030577, 45.45518690539945, 42.19665435052688, 42.33204280176471, 44.2487992009809, 46.59555719744775, 47.40972749648556, 52.646017151494185, 52.75931089155136, 52.447121604796386, 43.20591549719534, 33.56929917489329, 11.402664472979884, 4.8192426658445795, 1.5453774433943535, 10.27506051524993, 12.753927861490558, 10.812508579223387, 4.193151487458137, 0.27258784239811285, 0.3081762117724265, 0.3361774608492852, 0.287639478281621, 0.30735321883713046, 1.2368246840853845, 11.137825058352563, 41.812199315717145, 36.88682809952767, 40.856125508585286, 42.53604919679704, 13.452391182222675, 0.46455728010304514, 0.2318253764702428, 0.13590373729746189, 0.1705671474337578, 0.1177288681989716, 0.09737404994666578, 0.18930553548759033, 0.08878648776801364, 0.09277749175746595, 0.12408260226009354, 0.21933786751281834, 0.1748040426642664, 0.16823428713025587, 0.2296897991290016, 0.11951058186710843, 0.1441210874867055, 0.1774910500934047, 0.17128812810105665, 0.17888707679606256, 0.16398799966179556], [0.04951507408892916, 0.03663715906441212, 0.09316087279829288, 0.006481439960489591, 0.011063336184428585, 0.007811601775052447, 0.042399676261289466, 0.02930591787932621, 0.05815484132918139, 0.09328809701987813, 0.024683847047028043, 0.03907483934815373, 0.066692519692644, 0.051689921097169, 0.06968125851163942, 0.052879130873348446, 0.031015397117082632, 0.023270100730681614, 0.03464405875532858, 0.027608276615219734, 0.09265228234712156, 0.10853485549770056, 0.00854789031549327, 0.02967452299931357, 0.012066968821830327, 0.054243667531878724, 3.559979940614393, 30.842804754934004, 37.85120556431432, 22.958328839271303, 27.2302371071231, 30.188751489885394, 4.917434300145795, 0.6383233962039794, 0.02312448465325419, 0.17012459376165945, 0.0022174127685326726, 0.21277689134642003, 0.47555768982537333, 0.2389487071383384, 0.4040218397013603, 1.7013855494799155, 5.079096257686615, 15.625383277093212, 47.492061968772646, 55.54204817741148, 55.29957117572908, 52.948812361686464, 53.00054450188914, 50.43230595127229, 48.7792230421497, 46.746866549215014, 46.9569996864565, 44.88920457901494, 47.92285980716829, 45.45802277903403, 45.21313744206583, 43.3654422144736, 39.35901172699467, 38.77333910234513, 39.24562385005336, 38.37253170628702, 37.69378123744842, 40.44476301439347, 44.26088010111163, 46.614596382264175, 47.81832079733572, 47.870911936606134, 48.8107902772965, 49.73038996419599, 53.93920690782609, 52.95139720363002, 54.351047931178925, 51.366724352682795, 47.12984677283995, 39.853242135817005, 38.425350343027425, 37.8791916754938, 36.34654514251217, 37.92297317135719, 38.91757249832153, 40.33628202253773, 45.029856851024014, 47.57068980124689, 50.806794243474165, 52.38040208816529, 52.39570325420749, 47.60478696515484, 42.53039313900856, 41.5475256212296, 40.17456662270331, 49.92470026016236, 52.577611015688994, 50.85565913108088, 48.56607752461588, 49.686781052620184, 48.03352948158018, 46.71904909995295, 47.47009277343751, 45.95433988878804, 42.84737948448428, 35.29376922115203, 35.550955110980624, 36.07459937372516, 35.75791505075271, 35.168308288820334, 35.960466246451105, 38.101539073451875, 37.72643889150312, 35.48543191725208, 37.87492805911649, 43.33665593977898, 47.86738180345105, 48.76120367357808, 50.16121525918284, 46.07860057584701, 41.395341580913914, 37.077012062072754, 35.460619003542014, 37.61159189285771, 37.63050556182861, 40.14965564973893, 42.527141494135705, 44.552182766699026, 44.56260842661704, 42.76442135533979, 42.03392305681783, 42.38510854782597, 41.27267729851508, 41.02832540389031, 42.49979472929432, 44.37845706939698, 48.5896784259427, 49.41469407850697, 48.38535039655624, 32.442104124253795, 12.10051884574275, 1.7759277431234237, 1.7247514763186056, 4.816575454127404, 4.278680730250574, 7.759683747445384, 6.318745170870136, 0.5933966295373055, 0.10262600401596678, 0.0755670584077316, 0.019651919175239823, 0.0716889527956805, 0.14269856946362605, 0.9433576668943129, 15.453018642240956, 30.4223305948319, 23.082620905291652, 35.5182150871523, 21.334145953578336, 2.0286451953072704, 0.06368136131054451, 0.01812027384256644, 0.005371971318738596, 0.018726852684912663, 0.05333897131945818, 0.07122110290032241, 0.03421305002824914, 0.019098480021761313, 0.04932473954414168, 0.06316338628230077, 0.04453820304103917, 0.010129023970465266, 0.02257356018338713, 0.006011894616794082, 0.0400317482830536, 0.04711354166389473, 0.09897705062382645, 0.03596246925993793, 0.07329117206315841, 0.03298764642808707, 0.04072572435102156, 0.05079864291474224, 0.0825174983530756, 0.01599518807544824, 0.024009796925970626, 0.05261299958933265, 0.03362666717880676, 0.03703149133211663, 0.07503775293908774, 0.04532837676965902, 0.022732149959812244, 0.057051153778428995, 0.08042201039291198, 0.026556797956507054, 0.015192994427296425, 0.06166862233752205, 0.020092270344555862, 0.009324622073871715, 0.0597715205062301, 0.028993913250404502, 0.07012821718930237, 0.055271780508900845, 0.09463672586266073, 0.030384230682806625, 0.07777100909621486, 0.07404664200880835, 6.649538259352408, 38.23364450085548, 43.33307089344148, 24.32249192268618, 32.87027397463399, 30.524241616649014, 4.823224852162023, 0.9753168939102081, 0.08351348926343265, 0.15133293195357247, 0.015112886528274225, 0.4435867569859951, 0.20396620605982121, 0.07306180533862884, 0.45529552224663, 2.8570267317756532, 6.4071352924070055, 19.59392366870757, 48.20776508700464, 57.20712961689119, 55.24359895337013, 55.07901237856958, 54.42107008349512, 52.058638295819684, 50.10367801112514, 48.48189561597763, 48.407860878975164, 47.07901285540673, 48.70517653803672, 48.19808859978953, 46.65462809224283, 44.83293817889306, 42.34792055622224, 40.55237716244113, 40.38943013837261, 40.95715007474346, 39.49534546944403, 44.12225177211147, 46.418450417057166, 48.904617294188476, 50.4822063446045, 49.14418781957319, 52.205837003646366, 51.22845295936831, 55.35331549183015, 54.21642826449487, 56.74010868995421, 54.665637708479366, 48.61587985869377, 41.944073323280584, 39.880855621830115, 40.09866091512865, 37.954901264559844, 38.956219611629365, 41.09571564582087, 41.74769201586324, 45.75789974581811, 50.23481461309618, 52.19848255957327, 53.938489114084554, 53.37740582804526, 48.80374570046702, 43.53180562296222, 47.438686355467766, 42.71175961340628, 51.03775124396048, 55.56857908925703, 53.99254329742924, 51.014205255816066, 52.06189778543288, 48.65111843232186, 48.654244561349195, 49.39156778397099, 47.6815712836481, 42.95516621681952, 38.36618923371838, 36.44490641932334, 37.361548639112904, 36.88780476970058, 37.82716927989837, 37.16760704594274, 39.59361653174124, 38.89711341550274, 38.321215337322606, 39.435384196619836, 43.920320310900294, 50.01394594869306, 50.21248848207536, 51.250198579603634, 47.37803866786342, 42.86776011989963, 38.390743270997085, 38.6882903498988, 39.41047322365546, 38.502118972039995, 41.8835158501902, 45.12552738189698, 47.71902599642354, 46.07432519235919, 45.495614774765514, 43.77581234901182, 44.05608923204484, 43.935205705704234, 43.943638801574714, 44.06664825254872, 46.77069102564166, 49.075718925845244, 51.02452108936926, 49.45458066078925, 35.43855567132273, 15.406220843715055, 4.526420081815412, 3.4943204445223657, 5.109217118832373, 9.282939145641944, 12.428056366982, 8.000900687709931, 2.5298990982194103, 0.27991789423169633, 0.13894214925746765, 0.04068354738035029, 0.044373271971820824, 0.10032919581018149, 0.640288258512174, 16.27911686897278, 35.98641664751115, 26.49158420101289, 39.57222000245125, 27.760186579919633, 3.260123075977449, 0.05888779978117636, 0.06455859710131923, 0.03426266571266517, 0.019385320577590216, 0.028465115315010472, 0.07389283453625056, 0.007120847106806093, 0.08534956453067642, 0.04702715375911325, 0.012962957487381514, 0.08543901295671541, 0.027244524662232688, 0.05708029193262901, 0.011827395890929527, 0.00916711439663965, 0.03279973272114031, 0.0981422216301003, 0.02948252029807097, 0.04701981463679864, 0.009800031341822639, 0.16644436866045, 0.1560621459277407, 0.23607650561438454, 0.10360086622137217, 0.1511608532840206, 0.12770707148217386, 0.2358147486924164, 0.11102211316146197, 0.21252857160664376, 0.156843341105888, 0.16357777490010186, 0.15328454094067698, 0.1987055875360966, 0.2605902313465073, 0.18967357944817315, 0.23176281773034604, 0.12253181047497258, 0.1141745419872384, 0.1287281134676549, 0.13561217955523922, 0.14503047981810185, 0.14238455002346348, 0.18810506038848432, 0.1261929293433505, 0.17464055950122495, 0.21689449136535968, 7.240204551527578, 42.605012309166696, 50.848053655316754, 36.55179492888912, 37.74571734090006, 39.495769085422644, 8.654193012945115, 1.3713822057170253, 0.3466977173041913, 0.4710781898710036, 0.1345917657618561, 0.684186322314124, 1.4309154498961665, 0.8159239049400053, 0.7596651044103407, 7.505094956967139, 8.390723486100475, 19.630244816503218, 49.863507363104056, 58.193331149316606, 59.62445497512818, 57.31762278464533, 55.93794476601386, 56.31995616420623, 53.58011784092073, 51.36624974589194, 51.38499083057527, 49.28184340077062, 53.432668101403024, 50.3767220435604, 50.03648388770319, 48.74109368170462, 45.28245749012117, 43.14340468375914, 43.074319977914136, 43.26285262261668, 40.50493609520697, 45.92549477854083, 49.41086192284861, 52.41607996725267, 52.3409273547511, 50.68364358717396, 52.805116330423665, 54.21520448500111, 58.21821466568978, 55.13678496883762, 56.413457624373905, 57.38819014641547, 51.43071782204413, 44.74893277691257, 41.19013494060886, 41.78922599361789, 39.88311098467919, 41.52492100192655, 42.590609365893954, 44.92810664638397, 50.43367485846243, 51.81543173328523, 56.163543808844786, 55.026625202548125, 55.38536910087832, 49.30957848025907, 43.7818371095965, 51.73340320587159, 44.61398755350421, 52.61435577946325, 57.81427721823416, 56.02624516333304, 54.5127986323449, 54.261908146642874, 52.90878849644815, 51.12402377590057, 52.71443113203972, 49.83825906630486, 45.67597320002895, 38.870017682352376, 38.398034957147416, 39.47630628462761, 39.777826724513886, 39.15901007190828, 40.09487190554219, 42.158670117778165, 40.539268601325254, 39.290711495184134, 41.68298859750071, 47.10708918110017, 53.779425236486624, 52.90271666742141, 54.963780987647276, 48.73188003416985, 45.15924015352803, 40.72326306373843, 40.02453596361222, 41.49853914014755, 41.41091339049801, 43.28099358466364, 46.676958145633826, 50.382538918525945, 48.02088768251481, 46.96031408925211, 45.842905352192545, 46.98433468418737, 45.446961695148104, 45.13760435965754, 46.1804017712993, 49.14664714567123, 52.24422916289299, 51.49263243521414, 50.83152870978079, 35.97160185537031, 15.096922343777074, 3.508413520551497, 3.8611900229607863, 10.421007986991636, 10.349596335041909, 15.019580068126803, 13.75773593302696, 3.084451637921795, 0.5659348289332082, 0.3000143416706593, 0.1706064324225149, 0.1811971076794209, 0.3430053573702613, 1.3431054714225954, 19.788989020932107, 39.89035168001729, 32.76806485268378, 47.16112767496417, 30.878284554327692, 3.665973169188346, 0.11929288266166566, 0.24921641504812628, 0.14929351396858692, 0.23649482026455865, 0.1651246443150505, 0.1552823450296156, 0.17407651960609422, 0.2829985482798469, 0.1500045661363871, 0.16702461897605853, 0.1620165183539352, 0.14098404936732786, 0.1363785739146894, 0.09665801054647855, 0.1339896666186471, 0.13843152101241774, 0.24182260937748418, 0.1371794575524907, 0.23124109653215255, 0.13917727696318782], [0.016113399272604335, 0.07564486995820077, 0.04010322428638897, 0.025655110554409125, 0.02250696799056905, 0.051668673648589084, 0.019542625241522348, 0.062325561884790666, 0.05906198519252001, 0.0337950150001674, 0.04861276807083238, 0.050302754201355486, 0.053825655486434705, 0.10273631301618392, 0.037911021556224556, 0.09354770123477905, 0.04967087722052971, 0.06122014680576902, 0.09996263039929253, 0.007231964808588307, 0.053363911311833136, 0.02857452224669678, 0.02313222980216867, 0.017474611109543233, 0.03751044950237678, 0.03742478172024412, 0.25864871939824474, 13.192128192993904, 37.180907803197066, 31.56353831291199, 21.106148381387037, 34.594567514234974, 23.522069531102336, 2.929196381761182, 0.10862794284137989, 0.40663481239349614, 0.023855660035605394, 0.0350328445464613, 0.17950506460282112, 0.03263537238742555, 0.245844770162817, 1.7482516217616297, 0.6004749142354535, 2.737013481317028, 21.16445049162834, 46.4569406355581, 59.557664855833984, 54.580671325806655, 52.88411678806428, 52.64629956214659, 50.614182333792414, 49.460930978098226, 49.97887995935256, 47.82561640585623, 46.14597512829689, 45.66939538524997, 45.61975386834914, 43.54650666636806, 42.00252840595861, 40.44146822344872, 38.11291002458142, 37.12281357857489, 38.85657964214202, 40.502488536219445, 42.64862906548285, 43.55279814812445, 47.077165419055575, 46.867844212439756, 48.00009127586119, 49.59882582387617, 51.22130640091435, 51.32558653431555, 53.747991361925685, 52.542082186668154, 49.589149336661066, 40.179320535352154, 37.37995632233159, 37.21126302596062, 38.4465076077369, 35.76615202811457, 36.84125408049553, 39.53521243987545, 46.589642263227894, 50.91303948433169, 52.603655553633175, 51.2094686877343, 50.52170853460989, 50.09775915453511, 47.1704315370129, 44.21297619419713, 40.79761159035468, 48.655954714744325, 47.63884882773123, 50.776686130031464, 49.75608148882466, 49.84489963900659, 49.08616027524395, 49.83914944433397, 48.766224307398645, 46.95344209671021, 43.87037284912602, 38.70076740941694, 35.57772528740668, 35.86822778947892, 35.37394246747417, 38.241720661040276, 36.4786191909544, 35.77223562425183, 38.024397819272934, 42.72440141247165, 47.359172067334576, 48.34226316021335, 48.41986333170245, 52.47036164806735, 50.013549789305664, 47.359940851888354, 42.98734141934303, 38.383686927057084, 35.60337366596345, 36.375021549963186, 36.31479747833745, 41.48619544121527, 42.01053004111014, 45.04401660734608, 44.54852711769843, 43.35996658571305, 43.88991801969467, 43.10429865314115, 45.07000623210784, 44.329243090844926, 45.92690290943269, 46.861266397660785, 48.345350065538966, 50.834411651857444, 40.11712351152974, 17.692627291525564, 3.408835573542503, 1.345615420610674, 2.528284552597231, 4.920683003241017, 5.935010381283299, 11.883267587231053, 10.118587363150812, 2.426048464352085, 0.22937631595038602, 0.12689190030458475, 0.13326139279430912, 0.05516639745403683, 0.07483167528745628, 3.633856066773015, 24.213348050271314, 29.878188025566843, 24.66063553287137, 36.41911683544036, 12.517060829747109, 0.22086739269716127, 0.015189521176169719, 0.029741651453678648, 0.10219753870079595, 0.05654794509492575, 0.03253467396021851, 0.05226319618222695, 0.04119827036535548, 0.014961666517680692, 0.06154051328438425, 0.006300746153424224, 0.03717024517696231, 0.08126276124629282, 0.017429300839261665, 0.058667453741955186, 0.033236831847217777, 0.010171676873259488, 0.042653335633897976, 0.05412921782643084, 0.09892612875949952, 0.05566775220476332, 0.06331668430638891, 0.06707959327726595, 0.022954194799005505, 0.0837759969515666, 0.031711502909480084, 0.03345434336111911, 0.0041036533882781384, 0.05827784057586424, 0.023845494048850193, 0.022451237009297458, 0.045530692929582256, 0.07939728352451518, 0.0256524215857949, 0.06081146571124273, 0.03641349969491844, 0.0640553386221009, 0.04748255472570177, 0.07916695919008025, 0.05712222758560412, 0.06257125011254704, 0.039629475514013926, 0.08459853023410806, 0.017182549664510355, 0.005044609499764779, 0.07546407320807058, 0.058630329121144555, 0.6546107931963859, 19.408848593311927, 43.41600548836493, 32.5152269101912, 29.05883823671649, 40.448344138360795, 23.326721768225394, 3.435793043144288, 0.048048613262512994, 0.46286398064224954, 0.04292021768407957, 0.1835126390740756, 0.17947435979881596, 0.04500719440740444, 0.2763005189837948, 3.9641051715420144, 2.6177511195982657, 3.2988937439457064, 24.371080283195745, 48.257265398579264, 59.60516475862073, 55.752761825438476, 53.79445968135711, 54.37344858723303, 53.55866639844833, 51.71494845421084, 49.89834977734474, 49.56902757767708, 49.33580736960135, 47.07306261985533, 47.99589826214699, 46.8236037992662, 45.101487175110854, 41.527050848930116, 40.98881144677439, 39.22527459359939, 40.46597911465553, 42.49912400399485, 44.35775872199766, 46.25305583400112, 49.49233739606796, 48.164148330688484, 49.515683343333585, 51.546823901514855, 52.27043844038441, 52.06734203523206, 54.48421632089923, 53.74170772490963, 51.15065666937059, 42.58263126496346, 39.93754171556042, 38.030171548166585, 41.40447678104524, 38.73370747412405, 39.538558221632435, 41.29636449198569, 47.12142152170981, 52.778714856793805, 53.4213795200471, 52.15908627356253, 53.32773293218305, 51.55433916276502, 47.62876441401821, 43.81354162769933, 43.18912383048765, 47.845667562177105, 49.26624021222515, 51.52529401163901, 51.87187464006486, 51.42045297930318, 50.76600159368208, 52.01625316373764, 51.56881663107103, 49.654456800030125, 46.97690963745118, 40.49922120186591, 37.446515021785615, 37.659260457561864, 37.63617338672761, 39.05213332945301, 37.39501822379328, 36.584825208110196, 39.01254092493365, 42.49188723102693, 46.62982694564327, 50.45579310386412, 52.72420567850913, 52.88709386702507, 53.11353621944305, 49.00559871427475, 44.426353131571126, 38.65194959025229, 37.47187314494964, 38.07224681300502, 38.063292041901626, 42.47815893542382, 45.2672779175543, 45.18866185219058, 46.04886116520051, 47.299093123405214, 46.128481357328354, 45.18013461943596, 46.30259536927747, 47.11299234820951, 47.313264646837794, 48.48261733208933, 48.8113001854189, 51.7740507279673, 42.874239875424294, 22.511290427177183, 5.390263276715433, 2.6687595825041495, 4.215011346724726, 6.727995468724159, 12.021308541297914, 11.669761211641374, 6.5015565483800835, 2.2651579879945327, 1.0331998621263812, 0.28617845667946723, 0.39586784498345473, 0.015337563837097298, 0.06818404691594263, 3.396618616196417, 27.33394261329405, 36.210921349064, 27.42447287805619, 41.77262652304865, 17.579510058126143, 0.4543439797576397, 0.02902299586323, 0.04313349656219925, 0.04737177075097158, 0.020161995836984248, 0.03599546083639707, 0.07210847020389573, 0.03298013110554988, 0.020701882895082235, 0.1148735742355066, 0.01901175120785352, 0.026962246159992875, 0.024341447879710508, 0.03902481763713783, 0.038029140822829745, 0.047091371079366055, 0.03319298480487159, 0.04391621625531585, 0.05965920818609096, 0.06986973912365015, 0.053904815351650606, 0.11068943181946395, 0.16600742275195737, 0.09175328582885767, 0.16959642210314352, 0.060091630345390695, 0.2448426352273072, 0.23565201629554075, 0.1871340745879758, 0.14189698102493442, 0.12633327665107866, 0.13907203180415018, 0.15420914777824957, 0.15025049568183962, 0.17824504915024006, 0.11966389138251544, 0.15355647151027957, 0.3089897971480124, 0.1972903473482978, 0.2038930906283279, 0.08686460299237121, 0.06454281569007905, 0.186123987659812, 0.1470282532635235, 0.06861158526472508, 0.16372587501762376, 0.1853656831888422, 0.761362019806139, 21.4718250689968, 52.399472651943086, 42.84501429527037, 31.66616124491538, 44.95178991748441, 35.36510928984612, 6.495484719353338, 0.3629395167433447, 0.9626991806491729, 0.4425244994701878, 0.49350424940066956, 0.5960659863006684, 0.259627994270094, 0.7964984892356781, 4.344170093536377, 2.687940953239318, 4.803571326117362, 24.93768430525257, 48.896745097252634, 60.89934687460623, 59.71861931585497, 55.65762865927912, 56.4885788579141, 56.051846473447746, 54.026518867861846, 54.118498448402654, 51.57031889884703, 50.5456938282136, 49.91830679678148, 50.65207635202716, 50.103372066251694, 45.77304401705342, 43.07039368537165, 41.2004860754936, 40.279760668354655, 42.01716276907152, 45.124946871111476, 47.20822357362317, 47.25228748013897, 51.00883553105017, 49.375501755745184, 50.45869173542146, 53.16163232249599, 55.11616899121193, 54.982663277656805, 55.593752861022956, 55.392476435630556, 53.978791467605106, 44.30556374211466, 41.13089930626654, 39.478636172509965, 43.077532399085264, 40.47246279255037, 41.197179517438336, 43.38999232938213, 50.580661758299804, 56.444644389613984, 56.569458130867254, 54.20562997941048, 55.60920307713171, 54.622993699965946, 52.269489226802705, 47.39719160141484, 44.982396171938994, 49.372254033242505, 49.684780643832305, 54.25615795197026, 53.737852035030244, 52.85912736769646, 54.25270234384845, 53.699016647954146, 51.506709821762584, 51.01409542945124, 48.373610742630504, 41.556668666101274, 39.30420837094707, 40.111318403674716, 39.01787927073818, 42.34950519377186, 40.238187466898275, 38.50433118881718, 42.14386709274785, 46.54628830571329, 50.39612993117302, 53.10000404234856, 53.1526618619119, 57.9782989717299, 54.696895076382546, 50.825460803124216, 47.713185587236964, 40.78755463323286, 37.78700420933385, 40.168977245207756, 41.05331874662831, 45.34237561687347, 46.97346971881005, 48.21871242215557, 48.14716839021253, 48.919506611362586, 49.134103405860166, 45.99536003605012, 48.70274074615971, 49.322463466275124, 49.64746321401289, 50.31517221081642, 51.770422535557906, 54.33579775594897, 45.09558400800152, 21.50890127305062, 5.059868308805651, 2.8887503714330736, 5.683845329669214, 10.277556123272067, 17.226112350340813, 21.693995960297126, 17.482413745695546, 7.359609344313222, 1.2431660534874087, 0.50803289238003, 0.3947061492550758, 0.42964892101383984, 0.23837322188961893, 4.793714409874332, 31.147672937762355, 40.88917147728705, 34.85829199514082, 49.17850463621078, 19.38027216542152, 0.505562779764014, 0.07695167040031764, 0.14558414688273785, 0.15379339186174257, 0.15667182934140006, 0.1646644859424522, 0.14844101132644763, 0.09761016590580826, 0.11903555372789984, 0.14768894281118147, 0.11376882948341871, 0.0723416673680467, 0.20869028724489674, 0.06082623205598324, 0.1330460454787939, 0.15799593570972645, 0.09842528345724268, 0.19688194587586388, 0.1541099853573307, 0.32196793945566304, 0.09327327321854331], [0.0330427396411617, 0.05745271025525947, 0.07431957615359176, 0.018437838354598612, 0.018393512507299745, 0.006862785122657736, 0.040086002629851146, 0.05129464271087801, 0.03394323003087794, 0.04680263637114437, 0.021015289464905378, 0.06165828015054427, 0.0659669808021957, 0.0440320908843029, 0.05097986101323078, 0.0714748465426026, 0.0390845341908355, 0.018568647867669503, 0.03629082220516378, 0.07792147642542278, 0.04484425899722884, 0.034077663139830676, 0.09777718839505989, 0.04371986025944353, 0.03767697786491725, 0.06815348000776383, 0.04024725264659332, 3.4318201724560033, 29.64209664252497, 35.4401481536127, 21.017440057569935, 30.175586054402014, 26.189948051206528, 4.321374748983692, 0.2661678723750576, 0.40707338240838825, 0.021131361361532923, 0.03906210696685218, 0.12443972180687612, 0.014728364974050032, 0.601576364809467, 0.8913338004100708, 1.3977829439024771, 0.9840900102450002, 3.422550140850006, 21.298254305316558, 46.747611799547755, 57.29432390582178, 54.83622550964356, 54.08384430793024, 52.637674270137666, 51.45424027596751, 49.637818105759166, 49.4016404305735, 50.08754138023623, 50.16275282829039, 47.63490684570805, 44.799103813786665, 41.574319331876694, 41.18405526684177, 38.920349536403535, 37.84452969028104, 39.68179533558507, 38.89685846144153, 40.752880880909586, 43.598678112030036, 44.556073757909964, 45.92270205097814, 44.97404152347196, 47.338046181586485, 52.01321724922427, 53.60198897700156, 51.66824479256907, 53.14612719320482, 51.40691687983852, 46.22039033520607, 40.674366797170336, 38.32735384664228, 37.76786304289295, 37.51337966611309, 38.3156769506393, 38.4414202936234, 43.539207135477376, 48.02252723324684, 51.83300787402738, 50.17759115465226, 52.32158614743141, 49.93289016908216, 55.05895337750835, 49.32854706241239, 41.62811071641984, 47.275664806365974, 46.731067242160925, 49.05486368363904, 49.34550346866731, 51.32866559490081, 49.60823558991956, 49.88761817255328, 45.27444408785912, 46.48775869800199, 51.545109825749556, 40.727393319529874, 36.532681219039425, 34.56586753168414, 37.030320167541504, 36.48572260333646, 36.88994638381466, 37.82605140439926, 43.9750099182129, 47.48820627889326, 48.91697276023127, 48.41317569055865, 49.4973619522587, 48.55920553207398, 49.84262074193647, 47.05833411985829, 43.15966290812339, 36.75304782006049, 35.85466031105288, 35.5106213784987, 37.685944341844134, 38.90189870711296, 42.93346766502627, 43.93619022061748, 44.39211476233698, 44.530578351789906, 44.566071879479196, 45.10547230320592, 46.32323095875402, 47.2608264800041, 47.10306482930338, 49.18198377855363, 50.14831850605626, 46.18688152682397, 24.300871818296372, 6.293539529846561, 0.2825993551842628, 2.162641695430202, 3.87742250677078, 3.9174576488233384, 13.662414493099337, 11.804919223631583, 4.014267628231357, 1.3138906777866426, 1.572906108152482, 0.26581697346222016, 0.3695221119109662, 0.056998715060012, 0.0811603123081788, 7.4051421784585525, 32.53116938375658, 25.906917664312548, 30.89237370798665, 30.71477859250961, 4.1823919357792025, 0.04691640042790002, 0.018382296980088277, 0.02670195629639972, 0.017965173596636425, 0.027407492631145065, 0.0245841694319801, 0.05466173320347744, 0.015907502609245, 0.10946159205970266, 0.03381799380745619, 0.11196590284065855, 0.038008854814594796, 0.071689757188001, 0.06392776200007047, 0.05400703829382697, 0.04840586304424271, 0.02034583012573421, 0.032234103193566684, 0.027004463350280162, 0.049617948205841166, 0.02192820963119307, 0.03635429642013004, 0.04287499551390929, 0.11024726885220698, 0.018554502054147663, 0.008780612505131192, 0.044418057471874266, 0.01498108301612158, 0.09469825038385969, 0.013269835072869976, 0.02555449831209356, 0.043698068888437365, 0.002507451980847926, 0.03048222481964096, 0.01570083219708214, 0.04307099527889683, 0.06227185146041936, 0.06686036189597461, 0.051226514511771744, 0.019656843205373135, 0.05203580596454201, 0.040196143090724945, 0.010853037388334352, 0.10010301601141693, 0.05534071310032761, 0.08282758010130736, 0.07592654516620022, 0.04723338845876917, 5.936620514239035, 38.46700591425742, 39.4679908598623, 23.3538253461161, 39.98576725682905, 29.268145715036702, 5.986081111815668, 0.5973384889864153, 0.7727769750260538, 0.12659698709725373, 0.007732885283222723, 0.18486838487367477, 0.03730224212631583, 0.38023686276808866, 2.0595613170054654, 3.5800185943803484, 2.0131340598867786, 2.984633690887882, 23.960131599057107, 49.25331600250737, 57.83023734246531, 57.9071589439146, 54.97839573890933, 53.98917398145122, 54.63543545815253, 50.1346412012654, 49.4367495659859, 50.495852270433986, 50.90990551056401, 49.65257798471759, 46.85117021683724, 45.06384811093731, 44.0256045710656, 39.93640030584028, 38.36017231787405, 41.33495276974094, 39.760407478578635, 41.644792556762695, 46.05043403563961, 46.48384025019985, 47.57311382601338, 46.900242990063084, 49.772371092150294, 53.461081750931285, 54.668669700622566, 52.15724668195171, 53.20326043713478, 53.81411860066076, 48.04067996240432, 41.8451197685734, 39.68126581561181, 40.83784334121212, 38.59777381343227, 39.2185987195661, 39.57850363946731, 45.945883258696526, 49.871885545792125, 53.608025504696755, 51.197517225819254, 54.86334085464478, 51.363284434041674, 56.79723801151399, 51.79966772756269, 43.374797067334576, 46.88254133347542, 47.24567044165827, 51.13586148908062, 51.30978330489128, 52.96973820655577, 52.888729495386926, 52.82009978448191, 48.93647086235785, 46.93060605756698, 52.097677646144746, 42.58298427827897, 37.575945392731704, 36.4194933829769, 38.49843586644819, 38.087936293694284, 38.699049411281464, 39.46159739648142, 46.06702958383868, 49.207773362436605, 52.16500513015255, 50.698599584641, 51.204593181610115, 50.01723289489747, 51.67199850082398, 49.647039598034276, 45.43208414508451, 38.81276676731725, 37.615294610300374, 38.70630187373008, 38.85290830366073, 41.51871581231394, 44.868561144798036, 45.582703159701445, 45.538333308312204, 46.069998818059126, 45.00340438658192, 47.37934089476063, 49.002249010147594, 47.85250817575763, 49.45898156012259, 49.860157658976895, 52.525321898921845, 48.23049129978303, 27.989131404507546, 8.826591968536377, 1.7519281083537688, 3.9109553396701817, 4.95003802161063, 5.3835226835743075, 10.55056191259815, 13.029713630676271, 6.9136618414232816, 4.664257562929585, 2.3498985892341984, 0.34030241531229793, 1.596102882777491, 0.10283711486526075, 0.17345817939889047, 7.755477495731847, 35.683754797904726, 27.582789544136297, 32.151423154338715, 37.347012335254306, 6.778260152186117, 0.062426402038263704, 0.0575027741011112, 0.005280303152939004, 0.06338590801122689, 0.054920295538801345, 0.011080086696892978, 0.009819268767211226, 0.027616464179910483, 0.01218164069277625, 0.00855947164968858, 0.03374083343172266, 0.04223266143291708, 0.047626345598649596, 0.07936906084538468, 0.027216324965739926, 0.04448583710097498, 0.05239287954604915, 0.05174546247167934, 0.03975818594617229, 0.016529658891921564, 0.0378090322708651, 0.14926248740765358, 0.13328405367510934, 0.15717567004744085, 0.15862423505994583, 0.06072342688698442, 0.10146087621368709, 0.10007354460896985, 0.13901243016364115, 0.11138028990958007, 0.1075567220968585, 0.17334919573078234, 0.19690613893251266, 0.16822175393181463, 0.09772976755254692, 0.1120698226675872, 0.13318430902736803, 0.149042175842389, 0.11672292580647815, 0.09032776474111504, 0.13167791969833836, 0.09641451716062524, 0.14557294667728488, 0.18993859990469872, 0.15660179358336235, 0.24308826323718796, 0.16701000201846325, 0.16158194731800787, 7.834754480469612, 44.165813615245206, 46.91089222508092, 31.21827167849387, 43.447855134164136, 34.30210774944675, 8.718647360801697, 1.4669540644653383, 1.950020917480992, 0.6256700751762236, 0.19730726256966594, 0.6002213697760337, 0.18459012641781763, 1.7666832069235465, 1.9882355894773238, 4.302347821574058, 2.992305356648661, 4.427428283999044, 24.77435681127733, 50.96668574117845, 58.43558849826936, 60.23699975782826, 58.639551747229795, 57.383538215391106, 55.45015488901446, 51.77783189281341, 53.64612740855063, 53.02552215514645, 54.66603779023694, 53.02144681253741, 49.09388342211324, 47.77333121145926, 46.72448942738195, 42.36640668684437, 40.7489545883671, 43.17676836444486, 41.09331515527541, 44.3497060960339, 47.679115879920225, 48.292798149970274, 50.000480451891505, 47.88122777015933, 51.581964415888635, 55.43734050566151, 57.71690437870642, 53.22086011209796, 57.20753362101894, 57.39024154601559, 49.64976172293387, 43.86128079506659, 41.815584321175855, 43.538140250790505, 39.599833488464355, 41.080991068193995, 40.51153744420698, 47.4921953293585, 51.62420834264448, 55.63464357006935, 52.236364810697495, 57.17893954246276, 54.09513681165634, 58.4488029633799, 52.93624508765436, 45.56757850031699, 46.38497691000662, 47.55252922734907, 51.522383612971154, 54.13383491577641, 53.67008916793331, 55.22980397747409, 54.28537960975401, 50.89207833813083, 49.5745934209516, 55.12229965579126, 45.3135108947754, 40.23870129739085, 38.05671422712265, 40.66851854324341, 40.80544064121862, 40.770798267856726, 42.248755193525746, 49.63657079204437, 51.21954133433681, 53.96680078198833, 52.261232637589984, 51.5907113013729, 51.10679280373358, 53.64238938977642, 50.83791040605115, 46.80110900632797, 39.79404180280624, 40.02555185748685, 39.56275532322545, 40.55464821477091, 42.92443444651943, 46.602174235928445, 48.061903907406716, 48.905295864228286, 48.95591797367219, 47.49720419606855, 49.88222099119618, 51.389434875980506, 50.336451069001235, 50.44804642277379, 52.6234164545613, 53.33891560954433, 50.65748137812461, 28.171356877973004, 8.768172187189903, 1.3151218117244783, 4.759329932351267, 9.340823523459896, 8.981437337013984, 22.347994312163323, 24.1091836267902, 10.339869837607107, 8.6245830405143, 4.554392464699284, 0.553978341481378, 1.9960358354353138, 0.18818574476866953, 0.5545477593137372, 10.22700265530617, 43.31852282247236, 34.54481617096932, 41.82793586484848, 42.310544290850245, 7.535832610822494, 0.2142768915021612, 0.16904847005442267, 0.1404637837361905, 0.12883246996470038, 0.1320883283211339, 0.135178022206791, 0.12256355715855477, 0.08320373693300832, 0.31113625293777836, 0.08800510872876452, 0.29243451453024344, 0.13416959002854364, 0.19337674122183554, 0.1902049073889371, 0.13087843034055927, 0.21370139093168322, 0.16361805580316052, 0.17611497232029516, 0.11523768050415863, 0.14377860021927666, 0.1844301212939524], [0.021894346629720063, 0.011412842732463634, 0.03704400537835975, 0.04106854486669745, 0.0051864669583137, 0.05161982022165772, 0.09163546916698256, 0.05986674523521816, 0.020400737562487205, 0.027704803693679073, 0.112763699144125, 0.028017446090797746, 0.0357467312395813, 0.04762434993960685, 0.021635611924613198, 0.047035013821216366, 0.060868715461824215, 0.014766121617398195, 0.011527765497204759, 0.035797840795449676, 0.09734197384527615, 0.006627228886504928, 0.05904715373030594, 0.057406266174849965, 0.09358216753049244, 0.020323460358345223, 0.05902432431016238, 0.6308920369032891, 16.264407980826594, 35.451350442824825, 34.88705473561441, 24.867993593215946, 38.02637077146961, 11.918742483662022, 0.7117094712391977, 0.5673283122239575, 0.02457261299564233, 0.09704243346688249, 0.12859331263649848, 0.12711986508821288, 0.11396268037177863, 2.5574843921969017, 3.22449863918366, 3.1768928324022605, 0.20466153810341514, 3.28346461057663, 20.942642419568955, 44.57751343327184, 56.23317372414374, 55.24153578665949, 53.60551911015665, 53.15983587695707, 52.275635580862726, 51.44439904920517, 51.35063086786578, 48.08328474721601, 45.17154070638841, 46.59620831089635, 44.92389009844872, 40.89991092681885, 39.5336748707679, 40.68754988331949, 38.90072984080161, 39.62756464558263, 39.99785207932995, 40.91942079605595, 42.355420127991714, 42.677427107288, 40.82026720046997, 47.491618740943174, 51.9871570217994, 51.026439128383515, 50.27579161428636, 52.424842542217625, 52.603392754831624, 50.5508792015814, 46.59107785071097, 38.92429151842671, 38.22796883121614, 36.37146788258707, 37.30008509851272, 37.71709580575266, 38.163826311788256, 44.882948398590095, 46.31541367500059, 47.5706035091031, 49.828260944735625, 48.66803169250489, 49.392756262133204, 50.82309561391031, 43.297298877469956, 47.26504695030951, 48.014160817669286, 48.85754885212068, 47.59472608566285, 48.14113970725767, 50.5575668427252, 50.089467263990834, 46.05052425015358, 50.49402052356351, 49.26827199997441, 39.95914613046954, 34.13644644521898, 36.40507475022347, 35.43397434296147, 37.042138268870694, 34.32981144997382, 44.89537838966616, 50.0185311994245, 50.1405639802256, 49.76487152038082, 51.95329912247197, 46.615420080000355, 51.06680031745665, 48.67575876174435, 45.3064820074266, 41.44316704042497, 37.055827340772076, 34.75167412911692, 36.842622987685665, 36.493261398807654, 41.88686947668753, 42.338910871936434, 42.8410997698384, 43.35330247879029, 43.301252626603656, 44.604244385996175, 44.99597541747555, 46.58581010756954, 48.63811577520063, 49.23138995324412, 50.26870389138499, 48.23140521203318, 33.78189948297317, 11.380962979409004, 1.334178279484472, 1.4035935675905598, 3.6388840550376527, 3.1616607981343425, 4.834101094353584, 8.14833522804322, 7.181990204318878, 3.863215682006652, 2.0338766565245967, 1.5304172784090044, 0.6054163652081644, 1.0699286912718127, 0.23405064738565878, 1.0688352080122119, 14.723624490922498, 31.456602734904138, 30.981437006304343, 33.015276155164166, 18.314262167099987, 1.321102690792853, 0.08358128038385222, 0.045040569027825716, 0.13397229174452444, 0.019047929710077665, 0.04445072346096558, 0.05222688744505567, 0.027324848981093497, 0.09749765057236918, 0.06974348017284948, 0.06994865384073028, 0.016470863558952848, 0.05144158986607387, 0.028914739978649927, 0.03660288429067981, 0.0411522782768213, 0.017619501318662398, 0.061368239262411674, 0.06061645803011714, 0.0284507664881887, 0.02280326781704301, 0.08014866256064947, 0.0700586564057777, 0.008047822592479568, 0.008253375473882883, 0.04644039935702759, 0.04480992293646259, 0.0445659315934585, 0.03154765202423498, 0.04164464298575636, 0.04167600279493679, 0.03140501028317357, 0.05187344895074925, 0.057267282503627004, 0.018769278634159316, 0.029446424150298682, 0.032749737823201765, 0.0639772014842639, 0.02800934662621829, 0.03687502936490121, 0.0491163827809355, 0.07261772715156117, 0.03366455022666243, 0.018356253821102363, 0.008730341815539907, 0.057056244432685845, 0.0811501463214236, 0.020351935846490726, 0.033591859973967075, 0.9275858777184641, 20.71423495969465, 41.64352955356721, 34.05273914337158, 29.64959817547952, 41.399711101285874, 10.257090176305464, 2.3434882106319552, 1.246960088610649, 0.01609013701278356, 0.07009419522458507, 0.1121451903975779, 0.3292621077308732, 0.17473915501707987, 2.4190695872229915, 5.607597885593291, 5.161302272350558, 2.2853883476026597, 2.4451945337557026, 22.624499836275657, 47.80231752703267, 54.574575962558875, 57.039707168456054, 54.702205965595866, 54.05296740993377, 54.21918569072601, 52.49530792236329, 52.62018834390948, 50.64084660622382, 48.196186250255955, 48.59520504551549, 47.08551222278226, 43.13781922863376, 39.46790064534834, 42.71914151407058, 40.15941058435748, 41.32185989810575, 41.31421127626973, 42.440923875378026, 45.074144332639634, 45.89455904499177, 43.207139276689105, 49.30608364843553, 53.4040230320346, 54.01865059329618, 50.532385226218935, 53.481889924695416, 53.977120537911695, 51.8291796407392, 48.13435400685957, 40.495357667246175, 39.96821857267811, 38.517055357656176, 38.4020043957618, 38.389127254486084, 40.32617407460367, 46.12681435000512, 50.418036368585405, 48.39527007072203, 50.085435067453695, 50.77407383149671, 52.579682027139974, 51.864127958974535, 43.372659375590665, 47.88891169332689, 48.58108451289516, 48.89567036782542, 48.25659075090962, 50.319227941574596, 51.977496224064986, 51.418868341753566, 47.42471487291398, 52.235670551177, 49.87046564778974, 41.9510982882592, 35.83373838855375, 39.50685762589978, 36.84819275333036, 38.72390547106343, 36.82071262790311, 45.141777761520885, 52.137113155857215, 53.379912222585375, 52.074590575310495, 53.2169730432572, 50.13768496051912, 51.58860891096054, 50.928007248909246, 49.65870864929692, 44.06160408450712, 39.2806427709518, 37.959800304905066, 37.59018359645721, 39.447206220319195, 42.31900484331193, 45.08506028882919, 44.844870028957246, 44.93300176435902, 46.03740784429735, 46.77555476465533, 48.121359194478686, 48.69936358544135, 49.60714124864148, 50.52888254965506, 51.949753299836196, 50.55720990703952, 37.2112081127782, 14.316215745864378, 2.4500668529541265, 2.590431811348085, 5.808321747087664, 4.792238618096998, 8.023044428517743, 9.500904275525002, 11.55238526482736, 5.984969119871817, 5.529352484210845, 1.45721236784612, 0.6214974700443207, 0.3482300770138541, 0.12909494700931734, 1.064976453781128, 17.216657477040446, 38.23152642096243, 31.88950296371214, 37.823725438887074, 26.111818359744166, 1.6900133726096924, 0.07529405531503501, 0.05539947587455954, 0.04380747390490386, 0.006869372521196643, 0.08710068830799672, 0.07414653221325529, 0.01149099231922939, 0.0640287783537661, 0.03681083119684651, 0.06758355655737462, 0.046835325342873414, 0.014542532153427603, 0.03963335957979003, 0.024440807568269874, 0.024765738015694004, 0.027089181183386716, 0.03187094495872096, 0.08319634418453901, 0.007949796375713402, 0.0463843293818495, 0.025138962645864776, 0.13161447229644946, 0.15174999021955077, 0.10165176234178006, 0.08307374713401641, 0.1557035248486265, 0.2997960066122394, 0.32895775632031504, 0.11186998863253864, 0.09758481605639381, 0.1374170980266025, 0.237680004248696, 0.09620188179636195, 0.1606692608085371, 0.12784147394760964, 0.13034650485121435, 0.16109439364123732, 0.17765019719879474, 0.1026697476364432, 0.1272821225105755, 0.10043395833382684, 0.18822738930823343, 0.13309760319609798, 0.10847215120109821, 0.17645673946507517, 0.20037944368537397, 0.14582892729630395, 0.12645429556047724, 1.1985856198495435, 25.454962561207434, 47.930139726208104, 48.032239021793494, 34.72872041886853, 49.69881880667902, 16.117885881854644, 4.43956458760846, 2.7916626391872286, 0.14091566835920658, 0.23369207227182007, 0.4222793390433635, 0.5577848791595429, 0.7992918909557405, 10.506328363572399, 7.956031714716266, 6.030619134826045, 1.804686438652777, 4.487912702944971, 25.025806234728908, 47.56284898327243, 56.55099553446616, 59.27544639956567, 58.996805144894516, 56.0180748662641, 57.47299571191111, 54.92420819497878, 55.95674860861994, 52.88181827914331, 50.12396450965635, 52.010710854684156, 50.42437884115404, 45.18258610079366, 42.67594445136286, 44.695541474127005, 41.88879928281231, 43.95578638199837, 43.5660675264174, 45.013508412145804, 46.753158030971406, 47.47385824880293, 45.61677286701818, 52.123620202464444, 56.96228742599488, 55.685340204546534, 52.21408182574857, 55.41219419048679, 56.62479885162846, 54.93948974917012, 51.73570955953291, 43.24175811582997, 42.035158603422104, 40.171173772504254, 40.75992153536889, 40.26132945091494, 43.11827798043528, 48.70891063444076, 51.76611969547888, 50.82883796384258, 52.40606223383258, 54.57831005896292, 56.53300362248575, 56.70904744055964, 46.16663425199447, 47.08767737111738, 49.18751039812642, 50.18055254413236, 48.84859408101728, 50.51812741064256, 52.41614272517543, 53.9740453996966, 49.237897165359996, 53.0611058973497, 54.17826752508841, 43.71971068843719, 37.932669270423155, 40.59039277415122, 38.24585876157207, 41.087443367127456, 38.41670936153781, 49.5543186895309, 53.585009036525605, 53.788105441677956, 53.05491639721779, 54.26093539884014, 49.38173047957882, 54.062659586629565, 52.817844421632834, 50.85599253254553, 45.18552395605272, 41.81318775300057, 39.31942324484549, 39.86016119680097, 41.30269127507364, 44.9300992104315, 47.31912466787523, 47.533121339736454, 47.35722657172911, 47.61665213492609, 48.115867876237445, 48.77910144867436, 50.93623245916059, 52.9006064322687, 51.58311367034913, 52.75629066651868, 51.006309524659194, 38.95387403426632, 13.089677845278095, 2.604197859764099, 3.5626368561098656, 8.84436422778714, 8.234360160366181, 14.625706441940801, 15.851236293392798, 14.746529171543738, 10.532375843294206, 8.323981415840889, 2.6590073445150932, 2.0827753745740463, 4.744834323083201, 0.45223012866993106, 1.857359947696809, 21.109658902691258, 43.20023198281565, 41.161258451400265, 44.920179536265714, 27.371285538519583, 1.7688286208337354, 0.17201241826818836, 0.1291252534476019, 0.305502197194484, 0.13648984052481192, 0.14609843702806583, 0.1138527850590406, 0.10443338929044624, 0.23345625508696805, 0.16393423561126957, 0.19786970900191417, 0.17769216349528683, 0.24072249179645894, 0.0912514905775747, 0.06673372756209105, 0.1533040915045046, 0.16609262705089586, 0.1442870834181386, 0.25095143565727823, 0.11325409500709466, 0.09347657763188885, 0.20384188531146896], [0.0439354105882587, 0.029890086734667424, 0.018657696012768055, 0.015863352962168717, 0.06037790974181506, 0.03225302173485679, 0.030455654975207105, 0.08647038946829497, 0.08835527985807388, 0.03465567264826067, 0.04596588449672826, 0.025029613170772794, 0.033303397226958506, 0.07724836093163298, 0.06266907954047765, 0.040499487095662666, 0.013920375870751038, 0.03934243386010489, 0.020477376998432224, 0.05897365142441085, 0.048244011648479974, 0.0645888728960868, 0.07082688171536693, 0.02744165440690854, 0.022117387383214893, 0.08392539175768053, 0.07864603472332801, 0.08746701623162917, 4.16586208728052, 28.109897259742986, 37.16345325593026, 23.12484129782646, 27.73777219556993, 25.21061851132301, 2.049829058589474, 1.7108953359626955, 0.1006705722501201, 0.1797155855644134, 0.13713775172589288, 0.08096894354469354, 0.23074680128164832, 0.4966467114225511, 6.096567905718281, 5.038983648823154, 3.20061287572307, 0.3119212785555471, 1.903216990251695, 20.49750243463824, 50.10789063669021, 54.903203902706025, 52.791282130825905, 54.604064341514345, 52.470106694006155, 52.198764970225675, 49.38022821180282, 47.646262107356904, 46.78131672643846, 46.17222362949003, 40.67733603139078, 38.95943987754084, 41.000751141578924, 40.56070827668713, 38.57571832595333, 38.66947866255237, 38.27998730444139, 37.87909361623949, 40.003676799035844, 40.08111615334788, 39.872567653656006, 44.134952406729425, 51.70267143557149, 52.97234658272036, 52.77315685825964, 50.91922113972326, 52.22246785317698, 51.58791465144004, 48.486445565377515, 41.433153229375044, 39.20536072023454, 38.59854259798604, 37.673161337452555, 36.982628068616314, 37.47426579075475, 38.03050494963123, 39.594181353046054, 41.310104554699315, 46.6651165100836, 48.44731992290866, 52.32257066234466, 51.4706200938071, 43.5638709991209, 47.80002294048187, 48.03078382245956, 48.60841166588568, 48.29575169471003, 50.789786846407004, 50.54248925178282, 45.29540131168981, 48.267177228004705, 51.50626659393311, 46.83940702869047, 39.23509228614069, 34.410400467534224, 36.94698156849031, 35.24617518148115, 36.704061338978434, 39.61602895490585, 49.487493268905155, 50.62299589956961, 49.80070237190493, 48.276661519081365, 51.033209139300936, 51.44228881405246, 48.3475269809846, 44.58201631422966, 44.008353987047755, 38.753582123787176, 37.47248503469652, 36.21815419966175, 35.76724244702247, 38.5395226940032, 41.8311914320915, 40.93027791669292, 42.06060301872992, 42.66378510382868, 42.3350473373167, 43.057328270327666, 46.91650905916768, 46.37356673517535, 47.60591660776446, 48.859462968764774, 51.55801442361648, 41.81707874421151, 19.241730128565145, 3.817098414705646, 0.9749128897824596, 1.8695834014684924, 4.5998689147733876, 3.4243201103902634, 3.1267264533427457, 5.90996555743679, 13.186649622455722, 5.5442275827930825, 3.9472149552837497, 0.8112394305006151, 0.5572957473416482, 0.43581862543379113, 0.3344946108277767, 2.826889445704799, 19.094080348168653, 29.08108984270404, 23.82225048157477, 30.65868477667532, 7.3365664001434086, 0.16005881130695343, 0.052366411208265254, 0.008309615903624125, 0.053704253533073974, 0.08351211030516895, 0.036533679738039934, 0.019467713333846583, 0.022563717868779937, 0.09303206277470435, 0.0494751685689534, 0.04072164110238514, 0.03683360699083536, 0.05184699210428423, 0.023883225794340816, 0.009350814620002864, 0.01244706238785218, 0.03687306434937543, 0.01805079349827382, 0.0178296334906331, 0.07190863616884717, 0.034931077426599885, 0.016226088891046184, 0.023293675171331536, 0.03673546346685579, 0.0602694048786596, 0.010162897505647233, 0.0457229005593446, 0.07169637618766678, 0.045389644651403355, 0.03766513031516825, 0.0225032007532014, 0.08698085683488077, 0.04648309343704774, 0.028957813272192597, 0.010262735999159275, 0.016752569410469265, 0.014462751756993034, 0.06085442409159676, 0.08784884211396979, 0.016383788090259317, 0.043734668739019864, 0.035258281239939314, 0.07562462991524128, 0.08831178138573324, 0.08853780030603371, 0.04248407999834707, 0.034664750790163394, 0.08285695957320352, 0.014285401444912199, 0.03438624718617048, 6.787969979547686, 36.48779753715762, 43.15375189627371, 24.493340561466834, 36.387024002690474, 23.559687022239935, 2.4861551100207917, 3.1542281518059396, 0.2051255882026688, 0.19960990836543424, 0.521807061328042, 0.06522585968336751, 0.4111654257341739, 0.15561280471663322, 5.786963460906859, 5.486029415361343, 4.569679902445886, 1.6961659779471738, 1.89082266822938, 23.67716789245606, 51.87241200477847, 52.49977942435972, 53.5758150008417, 56.786157315777196, 54.80512111417709, 53.465023732954464, 51.29647470289662, 51.1536886615138, 47.71049876366892, 46.93451666062879, 44.261178201244725, 41.64210181082449, 42.19730546397548, 41.807457170178814, 40.37752182252946, 40.63180515843053, 40.055448162940245, 39.950261962029245, 41.81402321784727, 41.0784964407644, 42.66976279597129, 46.67913506107946, 53.87178528693415, 54.33709213810583, 54.41502571105958, 52.218820048916726, 55.439807676499896, 52.919304370880134, 49.41502747997161, 42.86816412402738, 39.82760552437075, 40.51413797563122, 38.76113660873906, 38.509018421173096, 38.937996279808786, 40.620904891721665, 42.57223306163665, 43.15234768775202, 47.706431265800234, 49.98592845855221, 54.15900476517216, 54.26674442906534, 46.38159190454791, 47.21339717988045, 48.188070866369436, 48.08701492124989, 48.240807133336226, 50.65761866108064, 49.256371528871604, 46.92118452441308, 51.089922689622455, 54.104644636954035, 48.13266738768547, 40.17784180179719, 35.48834623829011, 38.30963257820376, 36.591461858441754, 37.73831582838489, 41.387618434044626, 50.70809564282818, 52.32439064210462, 52.5964540819968, 49.53099235411614, 52.70236984375985, 52.33711481094361, 50.477546568839784, 46.91254354292347, 45.13265825087025, 41.55226776676793, 38.66194378945136, 39.45238767131683, 37.587947845458984, 40.51681695445892, 43.48006171564902, 41.71497160388578, 43.846011007985766, 44.55695629119874, 44.400092863267474, 43.9062782256834, 48.7679736844955, 48.24834200643724, 50.230860863962484, 49.136154805460286, 52.300632845970895, 44.686127785713445, 23.120301154352006, 5.852337114272579, 2.4308957784406604, 3.9830705667695696, 5.691831765636321, 5.9164688471824896, 6.839140730519449, 8.910341435863126, 12.22977271003108, 8.05011760803961, 6.702403964534883, 1.0994038322279531, 0.3719074645590398, 0.08201496765738533, 0.2353320213695688, 2.8894093296220227, 22.79052003737419, 34.72345659809728, 30.485549396084203, 35.552057296999045, 11.895158252408429, 0.2334234052367749, 0.05689315197448577, 0.007945757177132633, 0.05310987655614173, 0.04652211412547096, 0.039127224440416025, 0.025324467006289673, 0.018328389288076473, 0.006166313044471486, 0.11691286964642426, 0.0415486138644478, 0.0526713716587232, 0.02975971772215299, 0.07432789586844944, 0.06779553308602303, 0.027755526375145684, 0.025130782742053274, 0.022804677418823686, 0.047064220923329556, 0.08277525629607901, 0.05753748171452073, 0.03511802203232243, 0.10976336175395597, 0.23264132139663543, 0.1528741936049154, 0.0867013956209825, 0.17491100386025446, 0.16499586493497895, 0.07170906260369286, 0.1656999303809097, 0.1700965396218723, 0.20092574098417837, 0.140832701037007, 0.16077747838872095, 0.12305019152981621, 0.13251710773235367, 0.1970984116797486, 0.19865887149447398, 0.11180290231300939, 0.1730666625043077, 0.18361639802254018, 0.18820851290177917, 0.12457597054420941, 0.1571889233685309, 0.18541005500141652, 0.10452291432527766, 0.08973467479189558, 0.17503068211578554, 0.11732373026109512, 0.15148411174454998, 7.748479006751892, 45.89661828933224, 50.6079928336605, 32.58498038015058, 38.99546684757356, 30.78049594356168, 4.405982234785634, 8.094855671928775, 0.3650691492422935, 0.6708166171466151, 0.7944222683868101, 0.18866936075350932, 0.46032620714076106, 2.213540577119397, 14.332088597359197, 15.558193076041439, 5.094344471731494, 1.2132034354632901, 3.0309164331805323, 24.050683436855195, 52.73541189009144, 54.95038609350882, 55.83127590917773, 59.179956297720636, 56.66811358544135, 56.89012758193478, 53.97615955721948, 52.34778365781231, 50.87004246250276, 50.673759214339725, 45.64841070482808, 44.25452193906231, 45.558082442129816, 44.24376680004982, 40.96280221016177, 42.504819285485056, 42.06580015920824, 41.86489243661204, 43.783347222112845, 44.38441122731855, 44.591696723814934, 48.60183385110671, 56.77581010326263, 57.41612526678271, 55.60831269910259, 52.99123279510006, 55.53294827861171, 54.254008493115826, 51.457111450933645, 44.87682557875111, 41.786719599077784, 42.4729343383543, 40.61993214391893, 41.10750629055885, 41.18026233488514, 42.77002249994586, 44.32590123145811, 45.50640129273938, 50.00514022765621, 53.018556025720414, 54.86977746409755, 56.00699809289748, 48.30363173638621, 46.827196690344046, 48.18818853747461, 48.741854621518044, 49.33931789090557, 53.171179371495406, 49.87110107175766, 47.91277539345526, 50.7858056406821, 55.91536760330201, 51.46474438328897, 42.11977197277931, 37.766172501348684, 40.10840408263668, 39.015404255159446, 39.51780103868054, 42.61314730490408, 53.37416595028293, 55.73508762544202, 53.47842254946309, 50.52854130345006, 53.558533037862475, 54.186241703648726, 51.798396879626864, 48.33536763345042, 47.462930525502856, 43.08179993783274, 40.68231351913945, 41.421260603012584, 40.13844159341628, 42.39169028497512, 45.892378207175966, 44.82630937330185, 45.39703384522469, 47.24354451702487, 45.213231578949966, 45.37524507891747, 50.38946190188008, 51.19975689918765, 51.61748540016913, 52.28311161841116, 55.544013284867816, 46.64510849983462, 23.443914344233853, 4.736841513264564, 2.4724547613051633, 5.263802630286063, 10.144039623198971, 8.628291641512225, 10.887592550246946, 14.41388374374759, 20.678151115294426, 15.289622506787701, 11.642416407985072, 2.67056068585765, 2.0276015996932983, 1.4104509738183792, 0.6813912045571112, 4.441664526539465, 25.857435003403697, 40.082151659073375, 35.44842435467628, 41.97421281568466, 13.81313450874821, 0.2697178318856224, 0.14249935595979615, 0.2111418452113867, 0.1069473221357311, 0.19512928992269502, 0.08655576996745602, 0.21523206524791258, 0.17845253640365216, 0.24994384617574755, 0.1874518938242428, 0.12954971212292873, 0.10275083804322828, 0.16041792268233915, 0.13361239895945595, 0.2007216245176331, 0.1013293312562089, 0.10314188762417725, 0.09462277540155957, 0.21707657514320267, 0.15628153818749613, 0.26846291857861704, 0.09799658831569458], [0.011797965665708387, 0.043228993252400434, 0.01083404606869144, 0.052571833854721445, 0.07198847785231567, 0.033121255992521206, 0.02126898139625067, 0.03178924359681626, 0.0815380702636415, 0.07514738012105227, 0.025357927811602433, 0.06431866602431383, 0.000729004061741439, 0.01987553449467786, 0.06182752429477631, 0.033167807325240106, 0.01044336325233622, 0.026853183967872497, 0.017458006153784452, 0.042311254393069014, 0.06745622508347997, 0.015505119715066207, 0.044522230107817924, 0.001306584141979505, 0.034005332948459734, 0.028426345520382448, 0.09416884532378567, 0.04006373245389231, 0.9177293904846715, 9.313631692240316, 30.496139795549457, 26.323551824015958, 32.616984959571596, 45.767513475110455, 5.165611486281119, 1.4723871600243355, 0.039431997199332526, 0.15296554192900658, 0.5279057953626879, 0.029217754565780202, 0.1933868229389191, 0.658124317565272, 1.3229437532924837, 3.2797506163197183, 5.309571787234276, 2.650553901349345, 0.4498435502811786, 2.1787717073194446, 17.398602501038585, 44.826274071970296, 53.649939952358125, 55.71298506952102, 53.02787165487967, 53.63472115608954, 49.233229544854936, 51.657285690307624, 46.24910992960776, 42.3230331174789, 41.9824811720079, 42.92919620390862, 40.16806333295761, 44.60184781782089, 42.81050528249433, 45.253530010100334, 40.066630840301514, 38.42300084329421, 38.69980250635455, 38.100499645356216, 38.10534377251902, 44.551668936206454, 49.742062937828806, 52.928541552635934, 52.54356484259329, 51.44641122510357, 53.266171332328554, 52.94392901082193, 48.0671206597359, 42.5717584548458, 38.9795067233424, 39.160637855529785, 39.06449271786598, 36.85558642110517, 35.94987976935602, 39.104081200015166, 37.92515793154317, 39.99974658412319, 45.251423697317804, 49.02252766393846, 50.52274796270555, 50.60152876761652, 42.72152631513534, 49.32235756228047, 48.728942178910785, 50.5697105007787, 50.050274941229056, 51.640368507754424, 50.45820536152009, 49.44150740100492, 50.46856826351535, 48.68159917093093, 43.80227658056444, 36.19272155146445, 36.93843472388483, 36.6611349198126, 36.419936610806374, 37.176506903863725, 44.432613234366144, 51.664204751291585, 49.32223596880513, 49.568219569421586, 51.3315014685354, 51.207966419958304, 46.22048054972003, 44.45505311412197, 45.98308301741078, 43.74748499162736, 40.36024770429058, 37.36811076441119, 36.209458304989724, 37.13370207817324, 36.090716392763206, 39.33996077506773, 41.018860724664506, 39.21346825938071, 40.52624633235317, 41.63528080909483, 40.40239749416229, 43.64761360229985, 45.66517491494456, 47.83650882782475, 48.58036671915362, 43.468678997408965, 32.412309800424886, 9.710657923452317, 2.5665708078492075, 1.5778129932380494, 3.7597705231558893, 4.614750387207154, 4.860362343249783, 5.895030152413153, 8.065813462580405, 11.730433414059302, 3.3592183263071123, 5.755993406618796, 0.7237526185570226, 0.43685866639979426, 0.09445736169694893, 0.6027689492029529, 7.746807096465942, 29.05391566215023, 25.126209105214766, 25.466898333641794, 24.59210584240575, 2.3043895344580374, 0.021129997725027706, 0.04307530069303128, 0.0226039796196405, 0.021593940571971962, 0.01599582009798577, 0.10318236771009623, 0.011291767324080632, 0.04172225535336522, 0.016996982101831707, 0.005015837152548616, 0.017236145175693017, 0.008549178300815965, 0.04701557434013775, 0.07458011499576031, 0.0896840287192214, 0.0337701745992226, 0.01863217187835084, 0.019937428653300292, 0.025333294254397194, 0.06336738017477817, 0.03054247571966581, 0.04131171266518293, 0.012344757091223955, 0.012160461234499612, 0.02540580447643034, 0.04297786196994205, 0.04423084856581785, 0.022726478993952758, 0.0401581566209995, 0.03168767565981515, 0.044809696940524925, 0.052471403558287895, 0.04734394643756171, 0.05771157136487384, 0.010608439878260177, 0.06388136771537604, 0.04495273321686734, 0.041304691469356905, 0.05261352052912117, 0.017467180056677713, 0.02091494535336331, 0.06498808897430859, 0.07577613912402623, 0.03328411479390437, 0.07859553420735944, 0.028668687859129523, 0.04282605398686663, 0.058123523654836806, 0.11434901851199328, 0.05072813218219146, 1.5728078037500384, 16.129886373396843, 39.972282148176625, 26.54001174434539, 34.47461358962521, 49.39024594522292, 4.576190056339387, 2.452565402753892, 0.11113532563491214, 0.2674390573895747, 0.6141383068696146, 0.07216440228324744, 0.19956317700205312, 0.12322590911700843, 6.070577300363972, 7.961365647854344, 8.256157752006285, 3.3872821494456264, 1.0353608429431915, 3.1746011876290847, 21.763843567140643, 47.89707806802566, 54.64363321181267, 56.89946282294489, 53.96399236494496, 55.32068921673683, 52.41368732144756, 53.219601031272646, 48.08956053949172, 45.332295125530614, 44.38268930681291, 42.593813942324736, 41.38645741247362, 44.16724920272828, 43.556645993263494, 45.112395286560066, 40.43969923450101, 39.55129807995212, 41.02677606767224, 40.079551127649125, 39.87100655032743, 46.215122592064645, 51.20489520411338, 53.57970991442281, 52.10069787117743, 52.7605385934153, 53.82865098214919, 53.478748106187396, 50.99312643851004, 44.96196846808157, 39.598974489396625, 40.419922644092196, 40.36076545715332, 38.386059961011334, 39.43011645347842, 39.33020584044918, 38.980534384327555, 42.73599986107119, 46.538310204782796, 51.80679075179562, 51.46190458728422, 51.758871155400435, 45.65665944930046, 47.40218870101437, 48.06185291659448, 50.04785876120291, 50.411705663127286, 52.77604764507663, 51.034534900419175, 49.79508946018834, 51.93098083619149, 52.36102165714387, 47.217633339666556, 37.94663683060677, 38.57060355524863, 37.79186794834752, 37.94230653393654, 37.298021931802076, 44.82374022083898, 53.06263954408708, 51.80875585925195, 51.41133346865254, 52.53653203287433, 52.0122484237917, 49.05257301945841, 47.372221792897875, 46.81645724081224, 44.656427598768666, 42.06736126253682, 38.0650374966283, 38.57602427082677, 38.715715562143636, 38.6694041375191, 42.20232217542587, 42.83250585679085, 42.501108723302046, 42.94998476582189, 43.56524775105138, 42.7249466219256, 45.61569029285062, 48.399871010934156, 49.48483390192832, 51.346202511941236, 46.47349696005545, 34.96088158699774, 12.443933140846992, 3.033509365012569, 2.8934979102303906, 5.041150758343359, 4.822036864296083, 6.480211009902339, 8.123717942545492, 7.312497265877263, 10.823632421032077, 8.131964725832786, 3.6270171692294464, 0.5573054919800451, 0.3746353504398177, 0.05263290255360546, 0.6215892780211665, 8.26244236961488, 29.249792945000436, 29.657535091523204, 28.576780903723936, 31.143985909800378, 4.493076993573097, 0.023022943529330438, 0.047757948012722116, 0.07148459118099944, 0.0779358329131238, 0.09641427201248946, 0.02167301233707657, 0.04496048219622143, 0.015195086804939615, 0.035964097196777026, 0.037161075104508674, 0.03227601969434369, 0.011760497262941734, 0.038793175631473144, 0.0209034712714774, 0.010973230837994527, 0.020231985629746513, 0.0383765731878098, 0.02252807562810279, 0.023476948300676963, 0.05807445955372626, 0.04128429054793331, 0.06952227228471348, 0.09576718818636672, 0.09262302544929328, 0.17992253655627852, 0.10241917559816953, 0.16529419489445227, 0.13123957950982357, 0.15610935226563485, 0.14148128639546134, 0.09959503076970579, 0.1177627292852248, 0.10900796075621921, 0.16778926665504135, 0.1489173801195237, 0.15299784019589424, 0.171316473354255, 0.1777746098776979, 0.08397619104793957, 0.07602696397131489, 0.12862095308880653, 0.13511106612220888, 0.11657482568895626, 0.1382139367201636, 0.1487857049270984, 0.1965819918099911, 0.12169996922415112, 0.08704814233727033, 0.15547012850161523, 0.3216577964203973, 1.8102604943898417, 21.935719866906446, 49.85901232688658, 36.91474360804404, 41.14598474194927, 55.76151263329291, 8.98577743960965, 3.449571594115227, 0.23693689896214395, 0.5689438997257141, 1.4995761720403549, 0.3977110218857566, 0.8957885710462448, 0.9917776106346039, 6.605450328319304, 12.054414326144803, 12.240385663124824, 5.4638807715908175, 1.1358632435721736, 3.2598007061789116, 22.228728763518795, 46.82228980525848, 55.363988261069025, 58.74991939913843, 58.59455823898316, 55.865031826880674, 54.12638633481918, 54.483867229953894, 50.03238501087312, 45.27548351595479, 46.26939250576881, 45.83876332929058, 44.2422527651633, 47.4318535866276, 46.465452178832024, 49.21375497694939, 43.3871486110072, 40.73102151193927, 42.32086796914378, 41.98820391008931, 40.47154495793004, 47.649984436650435, 53.977426482785134, 54.85994800444573, 55.141280005055094, 52.570303640057965, 55.772291306526434, 56.87242200297695, 51.875216499451675, 46.92192585237565, 42.754862539229855, 43.45540961911602, 43.24938712581512, 40.63830060343589, 41.07844937232233, 41.72780952145977, 42.00963181834067, 44.31539712413665, 49.540802201917096, 53.030358437568914, 54.21622037887574, 53.65281504969443, 48.59777419797836, 48.17056532829039, 49.5077326989943, 50.94126878246185, 51.41847218236616, 54.37308772917717, 53.762433528900154, 51.83611046883368, 50.4091678896258, 54.32398749936012, 47.81299029627154, 39.78994684834635, 40.020276269605084, 40.422103481908, 39.892752170562744, 39.58622286396642, 48.11744466904671, 55.03181057591593, 53.976783214076875, 51.15479476990239, 53.88224232581354, 54.41891277990034, 50.995809339707904, 48.43238353729249, 49.875113656443936, 45.94508701755155, 44.77414969475039, 39.568560431080485, 40.056836681981245, 41.08107736033779, 41.25198679585611, 43.14906466391779, 45.708603397492446, 42.96270893466088, 44.31030196528281, 45.831675606389204, 45.37533529343144, 46.00920992512857, 49.7915828612543, 50.623737227532175, 53.64944965608659, 46.65260022686374, 36.51586994048088, 12.376612520986988, 4.048819051634881, 4.256216825977448, 8.179872555117454, 10.511948139436784, 12.380482919754522, 13.155564838840117, 17.25399059634055, 21.56586781624825, 11.564772109831534, 12.363534358239944, 2.661000644007037, 1.879096129728902, 0.1974461389885795, 1.277565607620824, 10.452833117977267, 35.32025306455551, 35.38477997626028, 36.21005450525592, 35.88090488987584, 5.3385605542890495, 0.13821395204192208, 0.12154009433523302, 0.1282466118854861, 0.10745375221895595, 0.12241378696935794, 0.15817184481889973, 0.08492433976742529, 0.1329971690692248, 0.17729211238122758, 0.14422005072476404, 0.12057898340806847, 0.14986227296533125, 0.09372450666682375, 0.19077270111489683, 0.31405731554954286, 0.18971730774689108, 0.19636967820265602, 0.1447975890891206, 0.10145768928792208, 0.13716660259712127, 0.1717925050686444, 0.14065847732126713], [0.04572777287854303, 0.017859819270069563, 0.009283420907694006, 0.016550908255721294, 0.027737234110733675, 0.03355397309567179, 0.041976167534988736, 0.05348536689134856, 0.0513955096774284, 0.0435814205106468, 0.09261688908501979, 0.0180201135921262, 0.042089697934927485, 0.008571224396056946, 0.07538592457891473, 0.036026541023485126, 0.04286761042631922, 0.023764014852443532, 0.04913891342678859, 0.029805359325461814, 0.046933514832128445, 0.10003945369633938, 0.021157701379589496, 0.023924238311367172, 0.02171239883248364, 0.058357597989661086, 0.12211561022746949, 0.08157924748957157, 0.014695928811335997, 3.2972242851411147, 23.14541412938026, 32.18528497603632, 25.851890733165128, 31.908708849260886, 23.851554509132143, 2.9491239834216336, 0.2994421659217727, 0.044963826170010913, 0.20870283576509646, 0.059559080494387504, 0.28067601484156424, 0.2886106326214729, 6.517378899358935, 2.014048094710996, 6.416552412894465, 3.7755686044692998, 1.188202247984948, 0.10954409206826841, 1.809811137856976, 15.876537542189322, 43.36374775055916, 52.700620466663, 54.47722273488199, 54.72088821472661, 54.05421472364857, 51.93762140889322, 50.36539816087293, 46.47383428389027, 44.840253399264434, 46.26747446675455, 47.24725507920789, 48.33029208644744, 49.93261560317009, 50.886649777812345, 52.11972136651316, 45.30017483618952, 38.96964980709938, 37.900968674690496, 38.73673946626725, 41.45908401858422, 48.73926193483415, 51.25439943805818, 53.374240475316206, 51.36389240141838, 50.49559339400261, 52.018469302884995, 49.99288282086773, 44.218820525753884, 39.14143000879596, 37.98631552726992, 36.1286888584014, 39.81447735140401, 39.55331025585052, 38.2356959004556, 40.21388053894043, 41.5308790822183, 46.74322266732493, 50.30979464131017, 53.60869230762605, 52.00567845375308, 41.88200181530368, 48.875827097123675, 50.651280110882176, 53.28810522633215, 49.74487527724236, 51.42683859794371, 49.79423046112061, 53.16731975924585, 51.538355504312825, 48.206600143063454, 37.62656750217561, 36.13427823589694, 35.745743936108006, 36.62879497774186, 36.59270917215655, 36.90425519020327, 44.93048752507856, 49.29252401474984, 49.403617305140344, 48.86282444000245, 51.9242069029039, 48.797724862252515, 46.67001555042882, 45.74917247218471, 42.65214350915725, 40.89236820897749, 38.62731318319998, 36.20269221644248, 36.0347794717358, 37.5288926401446, 36.888903033348825, 37.17831511651316, 38.418788217729144, 40.088964816062685, 38.114855520186886, 40.22185079513058, 42.56972666709654, 44.646857015548214, 48.12825864361179, 49.57901000976563, 50.17451209406699, 43.29780486322219, 21.768554333717596, 4.252184629440308, 1.248723439151241, 2.7337959120350503, 2.705652660900547, 3.7104915803478615, 4.629092043445957, 5.960172385938707, 5.510661409747216, 8.893470341159452, 9.139801071536157, 2.7704492355546644, 0.322048899627501, 0.08236911478302172, 0.14857457109516667, 2.4298431123456647, 9.527863706311873, 21.934827527692242, 21.89327197690164, 26.092661503822576, 13.529260812267182, 0.3763071075081826, 0.0294282793578121, 0.02934982812392616, 0.07696158357805784, 0.07856334319278117, 0.005603929814477001, 0.03056847674381589, 0.06458435297733353, 0.0366480911390916, 0.10666377001231718, 0.04260170130780147, 0.05063216434791685, 0.046630166996751106, 0.008894595854555168, 0.031727048748683546, 0.047541980165988214, 0.06354380256286071, 0.018933066317150672, 0.011021975097396683, 0.048423712892878445, 0.02600739417116969, 0.02513989918835221, 0.07553662173449993, 0.05999872303237358, 0.021138085698288296, 0.050384832861562895, 0.026738628925335024, 0.04608735156756255, 0.028316858149464094, 0.03580367072455345, 0.039844841981727275, 0.04457666065483805, 0.017194274640191468, 0.05380930333969094, 0.014438213003168424, 0.009437556840449331, 0.02319522138174263, 0.05131611998583521, 0.07175197884921106, 0.04362548205761179, 0.06000259560683082, 0.019264313159510493, 0.061845872100562825, 0.02176419020660462, 0.1096002692957559, 0.013848027484791895, 0.06561129383983151, 0.07255833235479171, 0.013717497593813367, 0.009114767608773566, 0.044939453082699934, 0.04765388645952748, 5.068665204509612, 33.565008101924775, 34.421222286839644, 33.428623368663175, 44.6608716441739, 19.845333868457427, 3.1480587538211577, 0.22250472177420894, 0.07487918806052016, 0.15152353462913346, 0.1586624781691259, 0.6641253600678136, 2.19344578443035, 7.932217044215049, 8.68499440531577, 8.184586263472035, 6.898429807155364, 2.2165232944873074, 0.6364681151124739, 2.6448931857462856, 20.5297835411564, 47.29298991541709, 53.03579876499792, 55.872178385334635, 55.54996744278939, 56.60484967693206, 54.60952428079421, 50.98986302652667, 47.37040181313792, 45.877049584542554, 46.62631642433905, 48.43005364941013, 49.95372972180767, 51.81793420545517, 54.05637987198369, 53.44884787836383, 46.61351773046678, 40.36807283278435, 39.470293291153446, 40.06290851100799, 41.76334227285078, 50.646628179857814, 54.39598260387298, 55.357535962135564, 52.77723612323884, 52.10759732031053, 54.39635915140952, 51.11490426524993, 45.56120857115715, 41.123580163525, 39.31762287693639, 38.235429179283884, 40.10059856599377, 39.697457359683135, 40.44892072677612, 41.75638398816509, 43.22955562222389, 48.9316894931178, 52.49132671663838, 53.725418121584006, 52.695399791963645, 44.96099964264901, 48.62866286308535, 51.709794459804414, 55.11023444514121, 52.6266602546938, 52.66991615295411, 50.75841572976882, 54.94969967872866, 52.62912350316202, 51.61153124224756, 40.482217727168916, 37.166398955929665, 37.08570011200444, 37.131242752075195, 38.08445322898127, 38.34167049777123, 46.69695831114247, 50.955267721606845, 51.713944327446725, 49.99093340289209, 53.1437502368804, 50.03579355055287, 49.23076237401655, 46.39350806513141, 44.79278487543906, 42.4633559103935, 40.14001446385538, 39.032270446900405, 37.87821108295072, 38.45650180693596, 38.07426683364376, 39.070513556080485, 40.973294550372714, 40.61490366535802, 39.47838121844877, 42.629703629401426, 44.34041792346586, 45.0854839048078, 49.257159925276234, 50.900181954906834, 52.721020713929214, 44.319939228796194, 25.031166153569377, 5.29994874231277, 1.576131031878533, 4.172484028723932, 5.44954696009236, 5.04541878738711, 7.368060090849477, 8.712456880077239, 8.239021897315979, 9.297004765079869, 4.762759064474414, 1.3453208751255468, 0.0680312889838411, 0.17676231661631217, 0.17043583996353612, 2.1623526657781293, 13.761379814917042, 28.157491299413866, 25.208353342548495, 31.407845712477165, 19.1328098312501, 0.6984413799739654, 0.01179870877099494, 0.04832914316906564, 0.034172297981117046, 0.021827369477720033, 0.02468634257844139, 0.04191681487305511, 0.03475330289333098, 0.05128636513085616, 0.026753437404911366, 0.040946530042997295, 0.025458187653472828, 0.048999297733028094, 0.03185852475824856, 0.06078166489098823, 0.062378548356073524, 0.015141542047081936, 0.015386465144523931, 0.036999273504461014, 0.013544683479854177, 0.009224400536397533, 0.051491783946872725, 0.09001395214469203, 0.14226286461757076, 0.10209829967108466, 0.10433679326407372, 0.09701622559899285, 0.1765550898327943, 0.1394348510450894, 0.19259081162031622, 0.15651349428920977, 0.17572452794880639, 0.11789838047397715, 0.17593886402826156, 0.08882450105081643, 0.10294043714360845, 0.3032548016598148, 0.283058088633322, 0.19211464201010045, 0.17623560052485238, 0.12296180796599197, 0.1123237501709692, 0.09946681063381896, 0.15017433122040766, 0.2530033408754295, 0.10959505223699155, 0.10571240372354947, 0.12457942560074792, 0.1716260954497322, 0.2647280867301649, 0.1151581222732221, 0.10888082846518486, 7.634557197170873, 41.97380488918674, 46.333515413345836, 35.869918331023186, 42.71934939968971, 30.398800296168176, 3.96908805254967, 0.7111100840472406, 0.27021395042538643, 1.243192284337936, 0.14834566402339167, 1.2855201743302809, 2.985644436651661, 18.7090761815348, 12.799570522000714, 11.569072008132936, 8.75747980610017, 2.410646297277943, 0.5427193004758127, 2.9180097820297366, 19.71146337447628, 48.086026483966464, 53.629986855291556, 55.38791079674998, 58.93231353452129, 58.14523504626367, 56.30277618285149, 54.567429404104914, 50.72331443909676, 47.97403889317667, 49.774461715452134, 50.51492283421178, 51.883327960968025, 55.958756862148164, 56.52601788120886, 57.32827986440351, 48.59512267574188, 43.3668032769234, 40.81315594334757, 41.31397593405939, 43.40433643710229, 52.98647496008104, 56.634793050827525, 57.8709593895943, 55.76516435992334, 52.34379852971723, 55.06327190706807, 54.444396418909875, 48.30406711947534, 43.628186102836366, 41.66793454077936, 40.469313129301995, 41.25923533593455, 41.6033644830027, 41.61693588379891, 44.094249971451305, 45.39116990181708, 52.025435432311035, 54.65416477572534, 55.71302037085257, 55.578106526405584, 46.648842596238666, 49.88929302461686, 53.63585079869917, 56.9347406202747, 53.39772762790803, 53.68704949655841, 54.0669192806367, 56.614294744307, 54.7463640089958, 54.16557473521079, 41.39860891526745, 39.491795724438084, 39.40368360088718, 39.10021374302526, 40.77371651126493, 40.94954459897934, 47.522546629751886, 52.32830908990676, 52.336161674991736, 51.30212683831492, 54.59572930489817, 52.87183976942494, 51.78036574394473, 49.607764905498875, 46.10571592084823, 44.162624728295114, 42.507780674965154, 40.73197857026131, 40.507960242609826, 41.06783151626587, 41.089569291760846, 42.26069488833028, 42.46319901558661, 44.342614450762355, 40.83219120579381, 43.874609008912124, 45.98648763472035, 48.39579566832512, 51.82329608548073, 53.25623989105225, 53.7843164320915, 45.086641004008634, 25.158256830707675, 5.48050916964008, 2.262693023489368, 7.173348242236722, 8.014640260127283, 9.829531235079612, 10.614344554562724, 13.675277906079447, 14.067871858996732, 17.738293486256755, 19.75377594271014, 8.98670409956286, 1.1888728507103459, 0.6241823324272711, 0.3304085736313174, 3.6561221365005743, 14.859710143458459, 32.51497391731509, 33.53139338954803, 38.27150321775867, 19.942245829489924, 0.8031705634728555, 0.11751372006631668, 0.11345833404770783, 0.1308349471899771, 0.19925289607096106, 0.13061213817807937, 0.12197629713843908, 0.17722952299781386, 0.1614147562894129, 0.12274672112037098, 0.11261082629883483, 0.1688645783090784, 0.13449801192168268, 0.1320357440460113, 0.24427137878392977, 0.1682279745657598, 0.16686672825486432, 0.10039681839125772, 0.1740493847718162, 0.1550797300954019, 0.1331805245530221, 0.10789961539088719, 0.2169022441751534], [0.09430315585867052, 0.08887353067797038, 0.054426126692804604, 0.07701556979408188, 0.005717225121183982, 0.08318775633890783, 0.05133295093753165, 0.025851958761772802, 0.041101099773039745, 0.02778722326301279, 0.05170394433662296, 0.03241765019934505, 0.06387702016640576, 0.011192262078815652, 0.03941381793288935, 0.05629649971641841, 0.038322280536616044, 0.06867108731380395, 0.04045176364841961, 0.020318224147382765, 0.02910053545248605, 0.015029241218261663, 0.04157664885203685, 0.0799871099391772, 0.08396961801354924, 0.0642188485982197, 0.0696106711702962, 0.1096262549981475, 0.08043223000582188, 0.36697162134993466, 14.858228468125867, 33.9431873444588, 29.246445202058364, 27.640685689064767, 34.90564284786102, 12.150120158349315, 0.9912064154782604, 0.03732634708285332, 0.08537406402249491, 0.12494650429054616, 0.2665405281849446, 1.1378718648226032, 6.43372651069395, 9.76676546758221, 7.7737851585111315, 4.818323360335443, 2.337037627735446, 0.4817257088518912, 0.1374030326523127, 2.5002285741990615, 15.642801542435924, 42.41205523090978, 54.378590814528934, 57.847409479079715, 54.91795201455393, 53.516265576885594, 51.58754202627367, 48.99655372865739, 53.0139825420995, 47.51915770192301, 48.02264882672218, 52.472499339811264, 51.31039911700834, 54.51118653820407, 53.46030904400734, 53.29381619730304, 45.5398355760882, 37.69197302479898, 39.6136559209516, 40.04727394350114, 46.29979871934461, 51.72368357258459, 51.77255238256147, 52.40525422557708, 53.430314679299634, 53.58890002773654, 48.78165098928636, 44.6235385248738, 40.75975287345148, 37.35320575775639, 37.20621493554885, 38.31357063785676, 39.47993055466683, 37.41242962498819, 38.08805396479946, 40.706887168269006, 48.70505886693155, 51.056711981373454, 51.819985605055294, 50.147333991143014, 39.3263070044979, 52.04018746652911, 52.71537642325125, 49.121516519977206, 49.94517111009168, 48.51624773394678, 49.04142172105851, 50.2409884237474, 47.218206005711714, 41.25304191343246, 35.80833711931783, 36.05501105708461, 36.78949840607182, 36.78212042777769, 36.55669789160452, 39.17051438362368, 47.40824484056043, 50.11071866558444, 50.36810459629182, 50.0921501651887, 51.99335828904183, 48.529928961107814, 46.802132744942945, 41.613342992721066, 39.63822564771099, 38.13118434721424, 35.73403958351382, 35.53618346491168, 38.79146045254123, 38.7841687663909, 36.44721277298466, 36.63120723539783, 38.242363929748535, 39.090854967794115, 37.43883894335839, 38.89702320098877, 41.35491763391803, 42.81776166731312, 49.10643108429448, 48.830974794203236, 48.87435228593888, 35.035418387382265, 13.069666893251481, 1.6604118577895628, 0.6212857233420496, 2.9294474134522104, 4.680664347064111, 3.6464723704322695, 4.851310493484621, 7.695307846992248, 4.907107189778359, 5.884394155394647, 2.7340861674278014, 0.4644315191093953, 0.1652485820194406, 0.21994874602363956, 0.8077832707954992, 7.331912507933955, 29.238645568970714, 38.3188501481087, 26.333185165159165, 25.652418598051995, 7.0373366244377635, 0.05012492604193188, 0.10279256685246384, 0.05629499052320758, 0.011793439043685796, 0.029868435174707445, 0.076118940487504, 0.014710522786293541, 0.0599170618900849, 0.07749357801531592, 0.01908366771174535, 0.032768392064158, 0.03261934965848923, 0.053776315593671416, 0.09696891200878928, 0.027071091932274645, 0.058116425850218346, 0.017702001327228163, 0.03720640069654873, 0.010905840956125288, 0.010655754426073645, 0.05113449203030718, 0.04753533435324508, 0.02331489006117467, 0.014490799193510847, 0.053111335953637484, 0.031350116252959255, 0.015808782604102407, 0.020077967483009544, 0.07918932129659, 0.03893325097798821, 0.02359818937557359, 0.04915805413357673, 0.0948828086256981, 0.02906647901381216, 0.04834495522382279, 0.025182231291828137, 0.013597743687099748, 0.02455417900496433, 0.010718083339593103, 0.035406565218563044, 0.07251502540443214, 0.031143174837193185, 0.02954130413972082, 0.031555050518363714, 0.04234578580625596, 0.05587695166468621, 0.07652612388013832, 0.031102024424340458, 0.04284497635859636, 0.02690296627641205, 0.038560867129314336, 0.0136805099112192, 0.9218658975535824, 20.308201005381925, 41.56778074079945, 28.49155564461985, 28.35523170809592, 41.90401807908089, 10.050638183470696, 1.1398156443911216, 0.07851877985822578, 0.21216926104839773, 0.14597253813858957, 0.44741842234807633, 4.646261728578999, 8.579831738625805, 7.505322454437134, 7.531569975037729, 8.509336940703854, 4.265549125209931, 1.663849570097462, 0.863296514557254, 3.449710838256344, 21.498377553878292, 45.925039783600845, 56.7518130425484, 59.861530873083304, 56.818301139339326, 56.95213240961875, 53.76126074021863, 51.48076334307271, 55.41117437424199, 49.59565654877694, 51.68235748044906, 55.33978723710584, 54.818767040006584, 56.92096525622953, 55.963514697167184, 55.51598402761645, 44.69673387465939, 38.59513798067647, 40.176570953861365, 42.01745694683444, 49.71117819509199, 53.62801782546505, 54.62995982939198, 53.969311098898615, 54.404015617985884, 55.403831697279415, 52.327336342104026, 47.099236596015196, 40.921342757440385, 39.362518325928725, 40.24072916276994, 40.81591729194888, 40.22200768993747, 40.553157714105424, 41.29430132527506, 41.37255261021276, 50.91795813652777, 53.10882937523627, 53.51889356490105, 51.697631189900065, 42.42043341359785, 52.7564710955466, 53.46865584773403, 51.149417200396144, 51.564490256770966, 51.12077605339789, 52.08050550953035, 52.674379810210205, 50.784487724304206, 43.45160492004887, 36.6126230455214, 37.36902467666134, 37.568920427753085, 38.088610941363925, 38.16148465679538, 40.96142545823128, 49.11210283156365, 51.11826573648761, 51.29658060689127, 51.677968348226244, 52.55691659065985, 50.37355669083134, 49.23282554072719, 44.80729372270646, 42.728865069727746, 40.50864665738998, 37.298025854172245, 37.39512805015811, 38.964652707499845, 41.03525230961461, 37.98336198253017, 38.124641833766816, 38.60348478440316, 39.640692818549375, 39.22873412409137, 40.74311025681035, 43.51515123921056, 46.34592187020087, 50.409901372848026, 49.260419414889434, 49.10440714128556, 36.361155971404045, 15.063515517019457, 2.703296542167664, 1.5501817339851012, 3.293480382811639, 4.149658776098683, 4.751783782436002, 7.170655535113427, 9.797509985585368, 9.867832199219736, 8.459050193909677, 3.7072301295495804, 1.0337987590220667, 0.10474360127362514, 0.07144270915417902, 0.8386148163868535, 6.039637644444743, 21.13177126453769, 31.341261517617014, 26.214170648205666, 29.602951388205256, 9.824954809681062, 0.048457914888257944, 0.04822331578320554, 0.011805949259489294, 0.012838493097543478, 0.007531314622610808, 0.006307021371133987, 0.01161233202794627, 0.03970971173276344, 0.03521254579085977, 0.030275455773657853, 0.015150463140960184, 0.05396693359099088, 0.03964702658835919, 0.1534667932578633, 0.03431284064126592, 0.019627346905068527, 0.07281753820397201, 0.03475923624430453, 0.020436220839920066, 0.025174514871210824, 0.03152520564805356, 0.018040529835308274, 0.026061813226870956, 0.30291294258448387, 0.18993538233541674, 0.1685418407883375, 0.2544166658434176, 0.15197145091670175, 0.17462280158314014, 0.1378958263704854, 0.14540610804913506, 0.2434153981026142, 0.23659851792598927, 0.11343083149122615, 0.1354710048725528, 0.18876210335762272, 0.16872131986723793, 0.20966481237161547, 0.17906264882654915, 0.12187888139798758, 0.19513679758435298, 0.10799942132566245, 0.14765598570867894, 0.12356142498432629, 0.08192201820953239, 0.11045067285698269, 0.20294539390071747, 0.20238519976696662, 0.10952182189230958, 0.14769663433394126, 0.21083891872436772, 0.2297122608269415, 1.0605104676177426, 27.378514466747163, 49.331320178124216, 38.62847028240081, 36.32376401655136, 45.01905856593963, 14.823309567666824, 1.582961104089214, 0.197919903082713, 0.7198000951640068, 0.5608382604775891, 0.8414505061603362, 5.725393035719472, 17.632067857250092, 18.48274365548165, 17.943033364511308, 10.55093747954215, 6.499357569602228, 2.086159399440212, 0.7891421452645333, 3.595309464200851, 19.812895867132372, 47.36597737958355, 56.84428291936075, 61.437856920303844, 59.41269013189501, 58.942001788846916, 55.92879387640185, 52.71678455414311, 58.47644782835438, 51.20185928960001, 54.39040107111777, 57.53480442108647, 55.532179494057935, 58.57889229251493, 56.52733187521658, 58.08717612297305, 48.70176799835698, 41.01549533105666, 43.47058134694254, 44.0914023307062, 50.73765462444675, 56.80012879833099, 56.24827877167733, 54.602401256561286, 55.89759142168107, 57.43917703628541, 53.29942518664945, 49.634860638649236, 44.144813245342625, 42.45589556232576, 41.95970004604709, 42.46723121212375, 41.91578911196801, 41.738101820791925, 42.738616081976126, 44.282460981799716, 54.197757782474646, 56.502479737804784, 55.26704688226023, 54.25735035250264, 45.45968194161692, 55.05637245793497, 56.194918847853145, 52.9850079936366, 53.46661621524442, 53.94334108598771, 52.43492695593065, 54.67379623843778, 51.9965510983621, 45.22845037521855, 39.652424627734774, 38.80168607158046, 40.065340380514826, 39.84717030679026, 40.06125327079527, 42.46295190626576, 51.300671638980994, 52.151288601659964, 52.37933128110824, 52.10783266252088, 54.80048879500359, 51.473605017508234, 51.76731601838143, 46.135325893279045, 43.53852072069722, 42.25573701243247, 38.559362042334776, 38.34398861854307, 42.622788490787634, 42.1899353304217, 40.37616860482001, 39.614946380738296, 41.21948995897847, 42.27803568686209, 40.78371855520433, 43.63494826901344, 46.376022138903224, 46.97714497966152, 52.781993958257864, 50.688307285308845, 51.045191980177364, 37.346369066546046, 15.10242444853629, 2.6425020108299875, 2.4209422738321367, 8.004564671747147, 10.005152417767434, 8.373506242229093, 11.311984177558653, 15.382564048613272, 13.56238522837239, 13.620798145571063, 8.43241435866202, 2.8795752121556193, 0.7042506553473011, 0.680335228962283, 1.6635656885562407, 9.100201802868998, 36.82274441565237, 45.765979828373084, 34.92226193028112, 37.502938316714385, 10.260934099074333, 0.06639206766962044, 0.21556865363832445, 0.12078090886315032, 0.09294495091683443, 0.1330131190198083, 0.15697041977076762, 0.15478765141339074, 0.13649595390644767, 0.13576705189001176, 0.15926083880326442, 0.10371497501769375, 0.24817376938318056, 0.1538918494817711, 0.23490840539095864, 0.1322169238401036, 0.13442117330287734, 0.12380818190473704, 0.0752285318148713, 0.1292720512156525, 0.11773817616725162, 0.1609684181429686, 0.10351881820468173, 0.11893722634281843], [0.04138010899506269, 0.07194212187201747, 0.042270532989453886, 0.07998819778402967, 0.04467496888772134, 0.03265338694496501, 0.004213530506427971, 0.07437543162415106, 0.03690147472004737, 0.06409312590896603, 0.026230572820490888, 0.05229574342769, 0.05774456677177261, 0.058082093619891716, 0.030983171628547773, 0.03674459906535284, 0.05326502851300663, 0.0741493973820921, 0.054693184943208774, 0.038423446277456905, 0.06409162054619481, 0.08303669912199821, 0.05471925491527204, 0.006289297927005758, 0.039435184125097535, 0.03527427332535867, 0.0219867923747628, 0.02299039053820795, 0.0772158788036435, 0.04604443915248398, 5.2572537429871105, 32.300565396585775, 33.56758509912799, 30.41811404689666, 26.179694975576094, 20.668702125549316, 4.433770266271407, 0.10085965041071178, 0.15040023522751947, 0.13168764901497673, 0.3462535701692105, 3.584999759351054, 5.893513666045282, 3.2083865231083286, 6.80949398586827, 6.721190156475191, 1.4968564986221253, 1.62740646110427, 0.594679244583653, 0.4896556994607372, 3.630870652775611, 17.22937183995401, 43.31515350649434, 56.20654867541406, 59.31007308344687, 58.539747038195216, 56.35687351226807, 50.851171939603745, 52.05157802950952, 56.01202657145839, 48.72612199475689, 53.74577130040815, 53.437814251069106, 53.56517361056421, 53.4579909232355, 53.85365216962753, 45.364521318866366, 37.814398042617306, 38.88624845012542, 38.6895376636136, 48.95681227407148, 49.487779601927734, 53.81237314593408, 53.265010310757546, 54.008142563604544, 53.071264836096, 51.83075643354847, 46.37406879855741, 40.07289878783688, 38.59254529399257, 38.129529107001524, 37.684395005626065, 38.888884282881214, 39.42255804615636, 40.801161335360625, 47.005821427991314, 51.30586877945931, 52.138772318440104, 52.32186071334347, 51.61595567580193, 38.09872673403832, 50.69330438490837, 49.8189413932062, 50.751637874111054, 49.26670697427566, 46.36578475275348, 45.34650979503509, 44.064655688501176, 39.718089026789514, 36.96471460403935, 36.08891210248394, 37.64063704398371, 38.18143775386196, 35.311525790922104, 37.07065390002343, 37.20919593687981, 45.689246500692065, 48.96666526794434, 50.86986987821518, 49.14098324314241, 51.161043105586884, 49.72811498949605, 47.491528526429214, 43.96158756748323, 39.256461358839466, 37.864639682154504, 36.216973566239886, 35.86646664527155, 39.658237580330145, 40.08306164895335, 41.45109415054321, 37.57959711936213, 38.543445064175515, 37.98997509864069, 38.67589173778411, 40.74221203404088, 43.41651147411716, 45.2425552183582, 48.509265915040054, 51.45040027556881, 46.28078699111939, 27.89814418362033, 6.474814809137776, 0.46900160129993196, 1.5965529747547644, 2.8209764726700324, 3.035123665486613, 5.014855679004423, 6.347471629419635, 7.113067786539755, 8.215916195223409, 8.767290634493675, 1.7689880896960537, 0.9085356612359324, 0.02829720607898649, 0.2608753999154414, 2.516423060048011, 20.43877474723324, 48.244498083668375, 46.86778537688717, 32.60606508101187, 17.91732026684669, 1.360187148374896, 0.06380692312133408, 0.02386388973513198, 0.03648126400226066, 0.03105321504746474, 0.048599599019414, 0.009877070101098189, 0.04977397350293975, 0.07147309986213524, 0.04450238076969982, 0.027175800829765298, 0.07111492311401714, 0.08566042002771171, 0.03344605045933877, 0.031235835086854718, 0.07229351874200568, 0.021753279199343056, 0.05116809647710574, 0.007474367476759419, 0.04309685074634129, 0.0999558964864381, 0.008904774290239139, 0.06148221782378613, 0.04545938929602985, 0.04963284095508918, 0.017052211295512897, 0.025177506444555138, 0.03295130704739883, 0.02990583750239063, 0.05561268963520566, 0.018640047262212443, 0.007909735722932965, 0.06795267304105145, 0.050325074173029394, 0.016479457150243463, 0.053359965959023085, 0.02801306023743124, 0.05933138767197248, 0.10986325195840291, 0.03547841277454169, 0.054006712706459147, 0.05133048413441547, 0.03817213113389669, 0.07556253848897834, 0.06232318318178577, 0.021641236925197226, 0.03859706478373658, 0.031222351939387383, 0.11264169198130408, 0.027541695913720517, 0.03382810233761707, 0.056336313305843266, 0.050242394133801424, 0.04853388399726922, 8.64451652573001, 38.08637911273588, 35.95973276322888, 31.619632128746282, 32.17373947943411, 23.09735921121413, 4.118488190635558, 0.29503283962126703, 0.17825194394155858, 0.213253382713564, 1.2649457493136007, 4.5910989853643605, 6.803741339714297, 8.002446101557824, 7.82689061857039, 8.684369767865828, 6.659835951943552, 2.739637056666036, 1.848163950827814, 0.9855152402193317, 5.424014781751941, 21.663266151182114, 49.10629772370862, 57.28428656055082, 61.24928505189958, 60.484854329016905, 58.695673019655295, 50.2963448339893, 53.18996360225063, 57.560182156101355, 50.316803916808105, 54.874802020288286, 55.489480572362105, 55.35101698290918, 56.51740827868062, 55.954277515411384, 48.50768519986061, 39.30435349864345, 39.45359183895973, 41.588647750116166, 51.56640829578523, 51.41456942404471, 54.429154088420255, 53.575203111094815, 54.67723223470873, 55.73832750320435, 52.82642656756986, 48.00556298225157, 41.03405990908223, 40.46516718402986, 39.17718633528679, 40.40544517578618, 41.0323497556871, 41.10146976286366, 42.065855072390654, 47.65801745076334, 51.90022553167036, 52.55388459851665, 54.22020158460064, 53.73006220786802, 40.21362166250906, 52.2166705900623, 51.83947586244153, 51.60278435676329, 51.85414160451582, 48.469469547271736, 47.09516125340616, 47.18122197735695, 42.55024425445065, 39.828707710389175, 38.71200499996063, 38.988041800837365, 39.16600758029569, 37.02661352772867, 37.005036569410755, 39.9928589021006, 48.93012446741904, 51.16070578175207, 51.85026630278557, 49.68137210415256, 52.54497689585532, 52.16714674426664, 47.54874806250296, 45.005875479790475, 42.12896208609305, 38.40273003424368, 37.73514655328567, 38.89268113720802, 40.520280407321074, 41.53836296450707, 43.6689159947057, 39.04063686247795, 39.122218239691954, 40.195629750528646, 40.901338669561575, 42.39400840574696, 45.695310484978464, 47.43687814281833, 49.90024820450814, 51.749316261660674, 49.90157396562638, 29.232926753259477, 8.743510284731466, 1.2144213314017942, 2.557993074578624, 4.741817039828147, 4.564719575066721, 5.865886451736574, 7.105711381281576, 7.915304274328294, 7.229991189895138, 6.819715682537326, 2.791909258211813, 0.8302801474928857, 0.18231628552800228, 0.19978751818979942, 2.2268050524496266, 19.842645083704305, 49.16127758641397, 50.14690253042406, 35.44137193310645, 25.44763949609572, 2.626292080648484, 0.036315114853242715, 0.012502709099452102, 0.03164223515458646, 0.0839312370085428, 0.012188839046434771, 0.041748034212017254, 0.0390077913330207, 0.021033711964264516, 0.0436532067795915, 0.028798210344487624, 0.044195436151517976, 0.027962764649982416, 0.07273935127041994, 0.033245074953283035, 0.0731029978863174, 0.05446395611450557, 0.004244248238166854, 0.015838163991218374, 0.0588514220960919, 0.049500859327494144, 0.01686959700178235, 0.025109397397646983, 0.07003120747545073, 0.16065206979551624, 0.14057477455466025, 0.11272501170394883, 0.20191474517266597, 0.15678171699325885, 0.19481078120729617, 0.09253848764684894, 0.15234651224267098, 0.17220230082110052, 0.21029631396935833, 0.09931775290639171, 0.08995535407936381, 0.11322994791572133, 0.12434933109269028, 0.18759815533074642, 0.16580836246571234, 0.2126274429141514, 0.1632213754759681, 0.18822227184089924, 0.14521349822321247, 0.18065566737805644, 0.19266457056566594, 0.14478753801555405, 0.1512697450215778, 0.23259958492652064, 0.13035670914236577, 0.2826769445692339, 0.14521193540384694, 0.13345555011783877, 0.1222508094243465, 9.98186432546185, 47.82447107376591, 44.97518685556228, 44.09774088090466, 35.312957456035, 27.820857801745017, 5.865315746876502, 0.4378914142087583, 0.3496446430442795, 1.0780307145849353, 1.030495878188841, 7.801790881541468, 14.780474343607503, 13.109747632857292, 17.196827934634303, 15.571902740386227, 8.316727972799733, 5.41521200249272, 2.193932893776125, 1.1117938641578922, 5.5958116535217535, 20.253615340878888, 48.20097154186618, 58.66916171966061, 63.61827896487329, 63.58087916528026, 61.76397454354071, 52.50814976230745, 54.039909839630134, 59.76134177177184, 53.0556224238488, 57.18569386389948, 56.89611704118791, 57.37005310673868, 57.807491517836056, 58.79393231484198, 50.87906391389909, 39.95548655909877, 42.80945016491798, 43.071829272854714, 55.68257101120488, 52.49623360172395, 57.636342817737216, 54.23829547820553, 56.980342095898045, 58.03695017291654, 55.171768588404504, 50.69181780661307, 44.24274698380501, 41.90910931556456, 41.966517125406575, 40.79814111032794, 43.175764237680745, 45.07409726419757, 44.382987406946, 49.62383093372468, 54.564181681602236, 55.404635783164736, 55.83577879013554, 54.36192858603693, 42.658125123670025, 50.905814478474284, 54.73487930913126, 54.685253481711115, 54.6935022261835, 50.080924341755534, 48.231220860635084, 49.30440487400178, 44.16557042829452, 40.563689278018096, 40.262647367292836, 41.256262179343935, 40.74618539502544, 38.980271585526005, 40.3261976088247, 42.054178176387666, 50.91569885130852, 52.53431981609714, 55.15868356150966, 49.224333609304125, 54.39553545367334, 55.00418924516248, 49.96490063205842, 46.45304964434716, 43.57283753733481, 40.64634930702948, 38.84709927343553, 40.509121264180834, 42.75203058796544, 44.01781082153321, 45.85591977642429, 40.87644730844806, 42.22332254532845, 42.796361215652965, 43.03479033131754, 46.37156632638747, 47.78647899627686, 49.8169292173078, 53.161463660578576, 53.58082386755175, 50.59859091235746, 30.063439607620243, 8.505405745198651, 1.3145969495657952, 4.070068492043403, 7.8964523826876, 7.362212327218826, 12.792860327228425, 14.343657628182443, 16.71473333912511, 15.951989235416537, 16.836246405878377, 6.762481927871705, 2.465034617531684, 0.44743785033783606, 0.5966016349773253, 3.729147843776211, 25.349195849510934, 56.9445308562248, 53.84663897175943, 42.203436128554806, 27.7852407193953, 2.8052693413149927, 0.18383376781017552, 0.15807024623838165, 0.16477867900844545, 0.22693013592112452, 0.1445487637313143, 0.15321364716416405, 0.11947783160834544, 0.17692261285358862, 0.18237539687223975, 0.11227985333290794, 0.1340516431317214, 0.12360503070897634, 0.16684955256360193, 0.07971187753062095, 0.253914725035429, 0.13461214370064198, 0.14259211388566803, 0.1232018156517898, 0.15058262544053216, 0.27353362390591257, 0.1768967497252649, 0.2272678581216643, 0.10480195419081759], [0.00513875643880437, 0.03819561172877589, 0.0455216990573512, 0.0361380374599849, 0.0039109681505754956, 0.07173016832600679, 0.03422365651556081, 0.037975089489332134, 0.02792841326745768, 0.097009131624814, 0.07745573327185647, 0.026058432863905065, 0.028266773236194448, 0.05584209083369183, 0.04929507278927392, 0.015414725170440733, 0.022829173080202554, 0.04065698328157587, 0.05106971929630926, 0.020257205244213827, 0.06187650029577556, 0.10092037053959024, 0.05246713644854965, 0.037392996732265725, 0.08945157466035697, 0.04649211412235614, 0.05805153054215255, 0.025880405521621148, 0.062485164812495636, 0.01758053042595425, 1.1303199539261481, 23.416598958353845, 31.99015686588903, 22.152097417462258, 22.900542520707656, 21.217490742283484, 14.469377436945516, 0.908465855304272, 0.10862438819341122, 0.10141766119387843, 2.6098651943668245, 3.7852867668674843, 4.833167079956302, 4.7412330969687435, 4.130942696525205, 8.986502097498986, 6.354873141934795, 2.7024976043931903, 1.9533975879030845, 0.3076860074314379, 0.9413643674023691, 6.867570069528396, 22.327670551115467, 45.67370999243952, 56.336979250754084, 56.58868558945195, 56.061887741088874, 56.893732240123136, 56.31885397818781, 53.719503187364154, 56.533599822751945, 53.71983266645863, 55.292977671469416, 51.36140561872914, 53.806238558984575, 53.043816089630134, 46.740943770254816, 39.50818338701802, 40.36190294450329, 41.72552670201948, 47.322486139112904, 49.67310767019949, 53.61201063279183, 51.563046824547556, 50.745307168652936, 53.036163545423946, 51.6715278164033, 46.88906815744216, 39.75572809096306, 38.663281317680116, 36.458160108135594, 37.61252541695872, 39.44630407517956, 40.11891995706866, 43.1069266411566, 45.28958835909444, 49.71529668377292, 52.17204578461186, 52.61739953871697, 49.67735951946628, 37.74456024169922, 55.258409823140795, 50.28905314783896, 50.47201994926699, 46.265858450243556, 42.667503510752034, 40.14056751804967, 38.581523433808364, 37.19411442356725, 35.94494542767925, 36.5584433463312, 38.08792844895394, 35.35912767533333, 35.59030825091947, 36.72706996240924, 38.15699354294808, 42.66153366334977, 50.4240728962806, 50.632562560419885, 47.79584953861852, 46.82994627183484, 51.13806978348763, 47.838105232484885, 49.034514427185066, 41.502630172237275, 38.144489026838734, 35.329733433262, 38.051046402223655, 40.34893166634345, 44.64378187733312, 42.9700751458445, 43.00015188032582, 41.17048778841573, 41.96071593992172, 40.806601662789625, 43.19939259559878, 45.7288702841728, 47.10438274568128, 47.937623608496885, 48.05128997372043, 39.094918543292636, 14.909511496943814, 2.5255408546616955, 1.2115891349892463, 1.6412438476277937, 2.1369957683547853, 2.8580556185014787, 3.088330371725944, 4.780703417716488, 7.249717279787987, 6.348727768467319, 4.984239618624411, 1.8796701440888068, 0.40711796872558137, 0.10531109622529439, 0.945647718204606, 8.05595507544856, 22.62321722122931, 30.3833108563577, 27.06301469956675, 29.46040265021786, 8.685976959043934, 0.22309467076293885, 0.08135410190950479, 0.034653581228227384, 0.07992677285426086, 0.016075361091944, 0.04198104368462678, 0.03997801487604457, 0.025754996928416436, 0.041441292607135354, 0.04528716890021198, 0.028618453558714643, 0.019875214652969472, 0.0462931955623771, 0.06785860510482904, 0.016358968756732442, 0.05597724789573301, 0.06768447331964009, 0.04731919030628858, 0.03310401901422489, 0.021975912011018204, 0.02421259189084653, 0.09148186087728509, 0.04496865252393388, 0.049651223234832294, 0.09227294625053484, 0.049672011030657645, 0.0385268375037178, 0.06745168984296822, 0.029027952452100096, 0.06304895955949061, 0.029089342907912312, 0.049725832537777966, 0.03056058412297599, 0.012444518975943569, 0.06250082748010755, 0.10282363937867266, 0.07389996681482562, 0.018995990864031257, 0.07323499483567092, 0.02907164244642181, 0.01478515602948685, 0.09302227217103205, 0.0401929485040807, 0.030746025281147133, 0.02283978722839346, 0.049671942082744454, 0.020604773589800444, 0.009367461710597479, 0.13942519833724346, 0.05007097813030405, 0.023937296280036532, 0.0627619217360212, 0.0661834312843219, 0.015446254476574401, 1.8723025845904506, 28.813492021253033, 37.69304383185602, 27.073328571934855, 28.7694614548837, 26.496185141225016, 13.937726636086742, 1.0072101760775813, 0.16175168175851146, 0.04276019340801624, 1.0099956104832313, 4.215424666481634, 8.20370585687699, 10.35420217821675, 6.447186123940253, 9.844116568565369, 7.9532340841908615, 5.806525791845014, 3.4398222979037993, 2.2059878082044664, 1.8473811928303012, 8.227046901179898, 27.013871323677805, 48.92655903293241, 57.86793916456161, 58.96733245541973, 57.116868034485854, 57.961440624729285, 58.58779215043592, 56.688815855210834, 56.10275099354406, 55.9366346943763, 57.26128185949018, 53.992288343368045, 56.61770720635691, 55.39569277917185, 48.987912747167776, 41.42503784548852, 41.073632701750725, 43.79338064501363, 48.76811096745153, 51.758871155400435, 56.3188696676685, 53.25490236282349, 50.97668778511786, 55.63822469403667, 54.184425646258944, 48.77473977304275, 42.03079300542032, 39.22319965977823, 39.23517857828448, 40.05469506786716, 39.52812471697408, 42.51173834646902, 44.070272522587935, 47.322140970537745, 52.95619818472093, 54.713722044421786, 54.60615496481619, 49.643831099233324, 40.43458838616648, 57.326777596627515, 53.51011922282558, 52.7536234548015, 48.99414147100141, 45.21477307042768, 43.77456503529703, 40.36864549882951, 38.42513461266795, 37.772518896287494, 38.044739230986565, 39.971258409561656, 35.32552080769693, 37.93493247801258, 37.60335491549584, 39.563535874889745, 44.75735410567253, 51.247919682533514, 52.81209814933039, 48.82429499779978, 47.473077697138635, 52.04672213523619, 50.18174886703492, 48.95162690070368, 41.33964000209686, 38.71435057732367, 37.07240327712029, 39.14662714927427, 42.50607836631037, 45.7694628930861, 44.85170672016759, 43.740028565929784, 42.51861426138109, 42.02551349516838, 42.29810645503383, 45.69279624569801, 46.71590335907475, 48.66742764749835, 49.066344461133404, 49.85388578907136, 41.22874675258514, 17.81889230974259, 3.7059975247229304, 2.310601833366579, 2.9760601251356067, 3.274068572828847, 6.233541484802, 5.684373869049934, 7.368409181794814, 6.758348240006355, 6.532286357495093, 3.295721036772574, 0.9596987513284531, 0.3291129350902573, 0.10019655534697157, 0.9582499871330877, 7.930516206449079, 27.970137326948105, 39.428198414464156, 33.68325187313941, 34.857527132957216, 12.378135381206391, 0.3596856042502388, 0.10438694904047637, 0.040883852559472286, 0.023240612091256246, 0.09936457620032373, 0.019140264372371377, 0.08335428853188792, 0.0038589409650153215, 0.03616078644089642, 0.015136177516392162, 0.017974799491405007, 0.02593847690150142, 0.012889113314750214, 0.0669367102185084, 0.06754539771786622, 0.048035968981322744, 0.030380540054231405, 0.07288175935466444, 0.025158003761222767, 0.03345188038844255, 0.03293770898674284, 0.041456422843639894, 0.043261176606099454, 0.03082279303681947, 0.27040507404073594, 0.12015408040174555, 0.11956221619320494, 0.28798326789852113, 0.1222230847023668, 0.22579255664060194, 0.14794506132602692, 0.1272759325201473, 0.1862646107591929, 0.1701233680209806, 0.11604138334552128, 0.14086840073427848, 0.1174251143369944, 0.13355132643013232, 0.1363190642047313, 0.16209983807657996, 0.08169142574432396, 0.19419996398350886, 0.0898391078977335, 0.15355510787377435, 0.1873955557182912, 0.18935169994590745, 0.1984593209119574, 0.09664785222060258, 0.22479261271655562, 0.1456665932651489, 0.1691414884501888, 0.21041407700507872, 0.1956818997859955, 0.1651130457438769, 2.601524764491666, 36.16636322390649, 44.70735565308602, 34.415232827586514, 34.07373951327416, 30.033386407359956, 17.68661625923649, 1.225568094561177, 0.41678728535771375, 0.19711531157935822, 6.028115682063564, 14.682081687834955, 12.311263872731118, 17.054053660361998, 11.398816627840842, 21.207433785161665, 13.203210849915783, 7.949203358542535, 5.024766527837323, 1.9358605482885916, 1.3318901893592652, 8.76711118605829, 26.912799689077563, 48.650106460817405, 56.96095382013629, 58.9834455520876, 57.551698069418634, 61.812407970428474, 59.8705562468498, 56.89878425290508, 58.31749769949145, 57.69574319162677, 57.8561955882657, 54.54582891156597, 58.07312619301581, 56.838889660373816, 50.428124704668605, 44.1514342061935, 44.600482833000925, 46.473881352332334, 51.387387398750555, 54.42478849041847, 57.2975363269929, 54.84845938221101, 50.56199912101992, 56.929135553298465, 55.37826176612608, 51.3784836184594, 44.548676167764974, 42.7499831107355, 39.88081247575822, 40.75878404801892, 42.24307952388641, 45.244790969356416, 46.2580450888603, 49.58757254385179, 53.48029352003529, 56.99490193397769, 56.93513677966211, 50.576794301309896, 44.62841403099799, 58.21201732081752, 56.23187149724653, 56.09466698861892, 51.08465494648103, 47.6461915046938, 43.55039373520882, 41.808951593214466, 40.740960797955914, 39.87675282262987, 39.70373707432901, 41.63169968512751, 37.630270219618275, 39.70568649230465, 39.577052362503544, 40.74655409782164, 45.46321207477201, 54.282959507357695, 55.09993430106871, 49.747464041556086, 47.683771733314764, 53.33875479236726, 52.33779730335359, 53.20954015178066, 44.89178157621815, 42.2897086604949, 38.47133621092766, 42.847120608052904, 43.78882677324357, 47.254095692788404, 46.980820240512976, 46.72423055095058, 44.137380353866085, 44.16656671031829, 44.24983470670639, 48.79929773269161, 50.45325533036263, 51.03360922105851, 51.144867250996256, 53.55250043253745, 40.54768600771504, 17.371877431869507, 3.9824018026551897, 3.05639541437549, 5.279349434760309, 6.265825042801519, 9.108370138752846, 8.516026543032739, 13.815530096330951, 17.513637773452267, 14.880364364193333, 11.555800668654904, 3.6162291803667626, 1.4539770253242985, 0.270600947401216, 1.6356998225373607, 10.539766569291393, 29.891198527428415, 42.01756677319927, 38.41440693024666, 40.84462511924006, 14.899486899375917, 0.46967284753918653, 0.24236172077155885, 0.1329217860174756, 0.20263974014068806, 0.15564802943939166, 0.10488039393338466, 0.19341783417809397, 0.11012805791030969, 0.20162969917779971, 0.07982226313963052, 0.11135323168409449, 0.12158750751686674, 0.1246077172277916, 0.18530546867799375, 0.12836834325665428, 0.11426024424332766, 0.18388046853003964, 0.14665611839342504, 0.11467750169216626, 0.17352164212253787, 0.15219163990789844, 0.1869804279938821, 0.25170800876953914, 0.10621324136492707], [0.02446070670210306, 0.025484935613349084, 0.05103074840360111, 0.05215587109447487, 0.012263934815212364, 0.02450391980669191, 0.1067430601124802, 0.013416129138110387, 0.05092295983265485, 0.11414058897043429, 0.021993671844322837, 0.0443035579707113, 0.034328740796134356, 0.02300167118289298, 0.08466487344835075, 0.05454130035134093, 0.0922034620758026, 0.0427260565301103, 0.006794152741936306, 0.04157752602271015, 0.05390092745543488, 0.03535666225117541, 0.02087475829607537, 0.03430756229546762, 0.08492442403709696, 0.14603399371187534, 0.05065633825236752, 0.08629161519028487, 0.024183988082973708, 0.038240780272791465, 0.5053429125297455, 10.446576937552422, 29.412579151891894, 24.449076614072247, 21.288685683281194, 22.338625731006747, 26.13761971073766, 7.084995873512761, 0.27415991610577034, 0.07189967294013308, 0.49824492405018506, 2.978357163167769, 6.12863818483968, 7.893452750098321, 4.081244795553146, 4.20778339908969, 7.896062597151726, 2.694097113224768, 2.8270826224357855, 1.1203027108023245, 1.023556960205878, 1.7845307266519916, 11.340544915968373, 30.814710778574792, 48.71469613044493, 56.41489321185697, 56.049732315924864, 54.79217337023828, 55.99104973577685, 55.6780759749874, 55.78702372889365, 54.69775799782046, 55.63594971933673, 53.036026262467914, 54.054689330439416, 50.77511718196254, 42.827579359854425, 41.332391462018414, 39.70143072066769, 42.336361331324426, 49.250684092121745, 51.84461024499709, 55.365521907806404, 49.79399904128044, 51.135955625964755, 53.0732064093313, 52.7740550810291, 48.42861806192706, 42.33806363997921, 40.11150275507281, 37.984742656830825, 37.51771780752367, 39.052474575658, 41.213602481349824, 43.86470110185685, 49.91004236282841, 53.50832669965683, 53.94267820542859, 52.26304085023942, 48.712166201683786, 37.014877796173096, 52.16523654999272, 50.64082307200278, 49.309911881723714, 47.389872458673295, 40.97533026049214, 39.523986616442286, 38.31111915649907, 36.517650696539114, 39.615268015092425, 39.741121184441354, 35.896500233680975, 36.89105249220325, 36.49444595459969, 36.70234726321313, 36.34540373279203, 42.67091205043178, 48.55580483713458, 51.80671622676235, 50.97206723305487, 47.630643229330744, 50.263361623210294, 49.72618910574144, 48.33619525355678, 44.80742708329232, 36.99231240057176, 33.93945717042492, 39.40382480621338, 46.007817483717396, 45.23267084552396, 47.26826329385081, 46.28712554131785, 44.22240164972121, 43.03240553025277, 45.423376483301965, 45.36380352512483, 46.57425088267173, 47.22696073593632, 49.79359503715269, 45.886886888934725, 24.84623032231485, 7.688529010741942, 1.3704354436166826, 1.1572493540663873, 2.036308280883297, 2.9028613432761166, 5.111641143598865, 4.513656198978424, 4.576324887814061, 3.283722261267324, 4.246450124248382, 2.5469606730245777, 0.1289005751811689, 0.11986459875779769, 0.2783866989756784, 3.814635901681839, 16.96309977962125, 35.70201735342703, 28.69302034378052, 32.28878063540305, 23.38552398066367, 3.4219076075861534, 0.05137010620185926, 0.028368793165070877, 0.020395020631352262, 0.011098253514407384, 0.03581980453623879, 0.0017296115496015598, 0.01982388293160306, 0.010425913684640922, 0.035401493716504306, 0.011151476515336864, 0.03921624768765704, 0.05673192877082094, 0.04278886807902206, 0.010501656797714533, 0.0326799625350583, 0.06067225987452173, 0.02679914604091356, 0.04431072855368257, 0.07999730656944937, 0.018559473964776245, 0.033887221342733795, 0.04199332024361338, 0.046531471889466054, 0.04161499921352633, 0.10604633378886408, 0.028525483043443774, 0.05573454741088133, 0.04841499481230013, 0.020205942470760598, 0.013063543874229635, 0.01769055214319979, 0.007651982089174131, 0.05500263466890301, 0.07545724736466523, 0.030441756225040847, 0.07737322560241146, 0.05299969396043209, 0.04802754584459528, 0.04441244204738929, 0.054383662439161734, 0.030000771117967465, 0.04615606965437051, 0.07601343485857211, 0.08569795833600145, 0.04511988211062647, 0.06270307852255722, 0.040890843111781344, 0.07365785238723602, 0.0808070385227761, 0.11268402599999983, 0.08141466115991916, 0.011777256393895276, 0.06187707486171877, 0.03421192770944007, 0.6009204096851811, 15.275808899633347, 34.983643101107695, 27.673523772147398, 25.748461754091327, 29.662194867287916, 26.448183175056215, 5.398689508438111, 0.27189919064121865, 0.06144141598093895, 0.25552027678537753, 2.694178992702115, 6.014831104586202, 7.737065399846724, 7.948564992796991, 6.170181478223493, 8.993177971532269, 6.472737423835262, 6.579129263277977, 2.740121714530453, 1.5195568482722006, 3.5142193638509323, 14.551880571150011, 33.44344208317418, 52.51626514619397, 57.23358208133329, 57.24538449318179, 55.638056032119266, 58.322851734776656, 55.119099001730646, 57.12425385752032, 55.17036045751264, 56.15247488021851, 53.42984399487896, 56.16251614785964, 53.087958443549375, 45.172533066042014, 42.22235764226606, 41.68441634024344, 43.25177977162023, 50.58027736602291, 54.81233043055381, 56.59371799038303, 51.71955331679314, 51.435044196344194, 56.07702808995401, 55.51479162708406, 49.73472026086623, 43.05367262132707, 41.812230694678526, 39.964794343517674, 38.11554585733722, 40.2033725092488, 42.568659782409675, 45.35659813111829, 52.01061671780002, 54.389236127176595, 56.08651630340084, 54.40177986698767, 48.87333639206425, 40.97326317141133, 52.540846640063876, 52.53127997921359, 50.88711653986285, 49.560108107905236, 43.1479585555292, 41.249111698519805, 39.569470420960464, 37.682680929860766, 40.770033405673125, 40.99115310176727, 37.35415104896792, 37.89577545658235, 37.573038916434015, 38.13568722817206, 38.27923813173848, 44.752984585300574, 51.201584723687944, 51.815078719969726, 52.7957889341539, 47.22716469918528, 51.325382571066584, 50.98586613132108, 49.51791909433181, 45.87659851197274, 38.42547193650277, 36.701421583852465, 40.39189338684082, 46.745991860666585, 47.811719448335715, 47.79906588215982, 47.85437130158948, 44.96442387180944, 44.31454989217943, 47.14821915472708, 46.772946388490745, 47.7780576675169, 49.59030251349173, 51.539226270491085, 47.55513760351366, 29.674146329202962, 10.064707725278794, 2.524535502156904, 2.4688704504120738, 4.712165882510524, 4.518147803121998, 6.127802719992976, 6.119298040866853, 6.778220928484394, 5.915485312861781, 2.4262948382285336, 0.8982474681350493, 0.24308867692466707, 0.06728995336039413, 0.29288996912298665, 3.7508777745308417, 17.95837179307015, 35.528083770505845, 31.44526904629123, 35.17555682889877, 28.405096800096576, 5.151826316310514, 0.037836385440201535, 0.021967737852866133, 0.012444872333998642, 0.0417596749180267, 0.02070604275251108, 0.052551425272418614, 0.02725457765101906, 0.05170905797351753, 0.09489474427555838, 0.038974106446990085, 0.018668997724871003, 0.030886529636899793, 0.05414401481468832, 0.051874502321645144, 0.06636164631814727, 0.0250984289337911, 0.06878927935876193, 0.04998001285017498, 0.051527594726893215, 0.07089788274418923, 0.07206764537841082, 0.014517283810663128, 0.06319056325141462, 0.03824414339877906, 0.19682802860775303, 0.14552230826548992, 0.24079458067013373, 0.1877996211330737, 0.053060594119972763, 0.10170767909937328, 0.1694581432328109, 0.13135331292306224, 0.17249493108641717, 0.14921266104905836, 0.1771967957216886, 0.13900434027516073, 0.15228213021351447, 0.12941045266005302, 0.20916331589462298, 0.16315878609255438, 0.19882659878461592, 0.26312478727871375, 0.21997440996910297, 0.1632444806877644, 0.10310630284009442, 0.1499806948366665, 0.09835447395040144, 0.2133269424760534, 0.19779215026046001, 0.2469917723248082, 0.22856136693829493, 0.17584051366054243, 0.177137270689972, 0.11147170718158446, 0.9057315955719641, 17.84161852252099, 44.88713356756395, 34.56124305725098, 33.42606206094065, 31.18656323802087, 33.28686106589533, 7.987385670984946, 0.515936192485594, 0.24200309969244466, 2.266126813427095, 7.565941214561463, 16.735998469014323, 19.21953735813018, 15.354735812833233, 13.57530551572, 17.306754319898545, 9.543894433206129, 9.32215892499493, 3.7070229793748553, 1.7355180147194094, 2.5427838390873325, 13.05400683033851, 35.013060877400065, 52.109048597274295, 58.14220305412047, 57.24425485057216, 55.92764854431153, 58.23779121521981, 55.30885542592695, 57.95079138971145, 57.99711850381667, 60.042336448546386, 55.197864117160925, 57.876007480006066, 54.322163597229995, 46.59618869904549, 45.441399774243756, 42.92074349618728, 44.74244909901773, 53.68901852638491, 57.46542161510837, 59.02253981559508, 49.67815183824109, 51.52470957848334, 57.86896290317659, 57.12233189613589, 52.30932089590257, 45.755259990692146, 43.39784491446711, 40.9275322575723, 41.368383130719586, 42.47954745446482, 46.67815054616621, 47.85954098547659, 54.424478623174856, 57.26982870409566, 59.13789672236289, 56.000275150422134, 49.45290973109584, 45.00144320149576, 52.02951469729024, 55.569653818684245, 53.11237519787204, 51.5783283787389, 46.13772638382451, 43.369274370131954, 42.37371014010522, 38.61014889132592, 42.968761151836766, 42.097426229907626, 39.627521499510735, 40.22023870098976, 39.1936485229, 40.72760120514901, 40.17745348715013, 47.01306212332941, 52.83641292202858, 54.86646306130194, 53.489197300326445, 47.60293168406333, 52.026435636704974, 53.913813483330514, 49.888143770156375, 48.60702706921486, 40.98326913772091, 37.338583161753995, 42.447576215190274, 49.48436713987782, 48.34275737885506, 49.17601393115137, 50.77218717144382, 48.23096198420371, 46.00931975149339, 49.788523412519886, 49.4834336157768, 50.26097682214553, 51.49515451923494, 54.29940600549021, 47.886652408107636, 29.245566591139767, 9.951805241646307, 2.4594903472931158, 3.983604499409276, 6.4510550518189715, 8.210134131293144, 10.798544941409942, 12.272880538817375, 12.197248416562235, 11.78184784227802, 8.58393257664096, 3.7679837211485836, 0.7387046936538912, 0.3977724314937669, 0.6595004566254155, 4.998044400445877, 22.020174380271666, 45.68337863491428, 38.06931288011613, 42.71719994083528, 33.374584874799176, 5.74121734788341, 0.1401529052565175, 0.14535398342676703, 0.13666741970566013, 0.09796172365426056, 0.16721450152897066, 0.17339175957585537, 0.26761507375105736, 0.13144628535355293, 0.16568191199293061, 0.11483500936939833, 0.09760869501699364, 0.19732227789298182, 0.13475121930241585, 0.1900118838755354, 0.23445668930728591, 0.14851850878086784, 0.1669545525745038, 0.11485947055682061, 0.14739425943022774, 0.13473235821772006, 0.13720302241704158, 0.10603818261334974, 0.14510693539294506, 0.11949898329593482], [0.019984780547900066, 0.09183555601104613, 0.03631546725368789, 0.0453598897964243, 0.035396920171596354, 0.04368734365749744, 0.02100775690538989, 0.06924351587170555, 0.049537853713357644, 0.019434041854354645, 0.0186266522148564, 0.07661026331686205, 0.02286620577046227, 0.04478847247458274, 0.04435649464627908, 0.009014212823052321, 0.028562054165729114, 0.004739671553139605, 0.0800283637738997, 0.03897684521131939, 0.027110313718777992, 0.08536695472655759, 0.12858039639409513, 0.003632473404474196, 0.00600714439285859, 0.13545998852820168, 0.04233375439540513, 0.034758244160442583, 0.06517021105654779, 0.040593068566053145, 0.04091258468707243, 2.978702576891069, 23.714514740051765, 31.294144045922067, 24.61281595691558, 32.188173801668235, 34.79739327584544, 17.945790790742446, 2.3011494115475686, 0.0942662304207202, 0.1331801874743354, 2.0566354740050534, 4.755908644968464, 7.550313511202413, 5.212898600486017, 5.094437628023086, 4.475175296106647, 6.3470494843298395, 3.574537572360808, 2.8026227220412228, 1.5766063741137906, 2.740697567501376, 7.804363466078236, 17.93092893015954, 41.85312532609509, 54.22492804065828, 55.878061940593106, 54.83929280311831, 56.42878232463714, 54.76297916904573, 54.9950187436996, 55.43851329434303, 54.305477834516964, 51.959778877996634, 49.026653997359745, 46.215091213103264, 40.26069010457685, 45.77702522277833, 40.75191205547702, 44.10132592724216, 51.48501911470967, 53.0847381776379, 52.98365477592715, 52.80577921098279, 52.77818141445037, 54.95395152799545, 51.818808894003595, 51.145031990543494, 44.05334357292422, 40.10633699355587, 39.46261329035605, 38.871178703923384, 37.74928277538669, 40.9541690734125, 43.25589433793099, 47.64393614184472, 50.83315257103213, 50.247440722680864, 52.340119346495605, 51.21716830038255, 37.28070074512113, 53.92778104351413, 50.21318666396603, 50.04322251965923, 47.06029530494444, 41.63622217793619, 39.54440647555936, 39.74216453490719, 35.381893111813454, 37.54892418461461, 35.3009000901253, 37.59208594599078, 37.30123043060303, 37.71000023811094, 36.612372013830374, 37.419556571591286, 37.14462195673297, 45.46353370912614, 49.37402694456039, 49.44976399021764, 49.772225964453916, 48.24342335424116, 50.55892398280483, 50.13853611484651, 46.800901120708836, 44.805344304730816, 35.69173289883521, 39.30677752340994, 48.255912180869814, 47.83301791837139, 47.538949981812515, 49.628071015880955, 46.64624990955476, 44.742676596487726, 46.55199927668418, 45.93883868186705, 45.74783886632612, 47.120382093614154, 47.59771885410432, 28.567830054990708, 10.637891523299679, 2.3796850683227664, 1.3455988731115096, 1.7871544245750675, 3.857675824434527, 2.8382682415746876, 4.006472162662014, 4.514198466654747, 5.408853350147124, 4.591536329638574, 1.241973285232821, 0.7289577876367878, 0.2710487411147164, 0.2338479098773772, 2.067262645690672, 12.460593408153905, 28.5691636608493, 30.55804264160895, 25.88633110446315, 30.472603613330474, 9.452776793510685, 0.12398320235191815, 0.044636415512931925, 0.05546517174450621, 0.05862841773177347, 0.06539891128458324, 0.01842097867460501, 0.04629438682909935, 0.02741242240693781, 0.06020820594482845, 0.040953306090687557, 0.180575764407554, 0.03867171239107847, 0.02529441912267958, 0.05877176427372521, 0.03474527812232414, 0.09005358187301506, 0.09747849071338292, 0.018803166533489863, 0.020852572389788205, 0.035637230462124275, 0.05088674685647411, 0.04048594649160101, 0.032169702012212045, 0.042181923429691986, 0.018244726741085612, 0.07056726217870751, 0.05092691284634414, 0.05783789543314807, 0.022345842463114572, 0.02536606175013848, 0.07106353393605641, 0.09767722158182053, 0.07490692044337911, 0.035835264190550775, 0.013490729822566914, 0.03625785744178199, 0.06605383985105061, 0.05232381288923564, 0.06898176661061664, 0.02080079825264552, 0.05907267977994296, 0.06328207245396991, 0.011583553935070674, 0.04725651282276358, 0.041463114621658484, 0.030108105781818592, 0.052511175012876915, 0.0824833308316527, 0.002829393248952505, 0.05240906315344957, 0.08535685002683632, 0.06563231529247376, 0.03976472833704564, 0.09967728563013578, 0.02372956196326883, 0.15891023100383822, 4.879805041897682, 30.494007987360803, 33.59644982122606, 27.17906390466998, 31.413872434246926, 41.82228372943017, 17.16213849283034, 2.0360338375453026, 0.1334651108951338, 0.11689912602906266, 0.7914772425447741, 2.7874252536604485, 6.387995596854918, 6.0254166010887396, 7.812730862248329, 5.909485557386953, 6.5530572687425925, 5.125616548522826, 4.316041796438156, 2.9906913013227525, 3.9693180015010223, 11.055865172416935, 20.684528889194613, 44.47991701864427, 53.629398499765706, 56.85364561696207, 55.76210098881876, 56.798261750128965, 56.62345347865936, 58.499119127950365, 56.65716232792024, 55.71166715314312, 52.52307830318328, 52.14204357516382, 47.40179254162697, 43.51306453827889, 46.43247289042319, 42.71771377132785, 45.1829626483302, 52.661349696497766, 55.568347669416866, 56.044327289827415, 51.41709935280585, 52.102917932694965, 55.62507690921907, 55.738488320381414, 53.29845243884672, 46.182264897131155, 41.47757407157652, 40.10228910753804, 39.93887139904884, 39.81509316352106, 43.2400950308769, 46.37831672545403, 48.404503330107666, 53.447537806726274, 53.54445957368421, 55.27576631115329, 49.80000026764409, 40.94087616089852, 55.075329272977775, 51.86230013447424, 52.15031585385723, 47.85171977935299, 43.18535835512223, 40.617512041522616, 40.61702958999142, 37.578428253050774, 38.57509859146611, 37.68331635382868, 38.94351897701141, 39.935411868556855, 39.047089161411414, 38.851084401530606, 38.730177340968964, 40.104226758403165, 48.468849812784505, 51.52823971163843, 50.709397869725386, 50.475153923034675, 50.510419953253965, 53.42305829448085, 52.16402845997965, 50.446116616649014, 45.65973850988573, 37.52606853362053, 41.382252631648896, 50.158222490741366, 48.94870865729548, 49.74752287710867, 50.550318302646765, 48.586571908766224, 46.51218721943517, 47.418913687429125, 48.17772365385487, 48.278763909493726, 50.25361845570226, 48.83756437609273, 34.056563454289595, 13.635806114442888, 4.281913253568834, 2.5381983432077595, 3.773014160894579, 5.359163293915411, 4.26156448741113, 6.233417930141573, 7.346529710677363, 7.0744113576027665, 4.725874566262768, 1.1704728896579435, 0.14205908522971217, 0.23277347156357384, 0.2114909668002398, 2.2971049576036395, 12.46548362316624, 30.943974448788552, 36.04715847199963, 31.116548930445028, 35.522984689281834, 14.906074520080322, 0.4844789369212043, 0.021837736562555356, 0.03452349566824494, 0.07174892981927242, 0.022362296116508307, 0.052185338666482325, 0.048129236355664275, 0.0791040940150138, 0.02609143210124345, 0.09777413936512125, 0.10868307818929035, 0.035700229702577475, 0.007898902760878687, 0.0409801957768298, 0.0712759547957009, 0.06953101334792954, 0.1045591809276131, 0.022199646074084506, 0.049600921901724035, 0.0540562441212035, 0.0449439576796947, 0.03525512495769128, 0.02795622608954868, 0.026455994192210418, 0.054651283764190255, 0.13695042790664783, 0.17867292457770917, 0.22289322028237007, 0.12151784714191191, 0.08999165132521622, 0.1870272666095726, 0.13059840988247626, 0.15136049579708807, 0.15760653321781468, 0.1317330473853696, 0.19386328366254607, 0.125246366425868, 0.12606656314024042, 0.15942924025077976, 0.11456080351866062, 0.146671578047737, 0.19016887061297896, 0.07828087125334048, 0.15997693182960634, 0.1336302334863332, 0.0836918804974806, 0.17123488499031914, 0.2659262788872565, 0.10112361366590185, 0.16492636543848824, 0.29177929485036486, 0.12224814343837001, 0.15814889282468828, 0.17750675489585246, 0.13554110191762447, 0.24584800305385746, 5.661657462196966, 34.57366128121653, 42.98250121455039, 35.757067818795484, 42.6973762819844, 43.439676992354855, 22.10795114117284, 2.9907246414692175, 0.37916332843803596, 0.5104853543302705, 4.189949852804984, 11.331217519698605, 16.58971759580797, 12.694522584638289, 14.007107480879753, 13.648865645931615, 13.702319706639937, 9.929783094313837, 6.991755250961551, 5.909775812779704, 5.318441737082697, 10.66716613308076, 20.70845142487557, 46.062907172787575, 53.31950772193171, 58.034000550546956, 55.825455111842004, 59.01051382864676, 58.220677914157996, 60.505231042062086, 59.600630498701534, 57.65523687485726, 54.74429691991499, 55.03969846233245, 49.03101567299136, 44.98295707087363, 48.051529238300944, 44.632301099838756, 47.43397166652065, 55.97587408558015, 56.58555946042461, 57.312798269333385, 51.734623062995176, 52.28319006581461, 58.114746462914255, 56.14632852615849, 58.16979300591254, 49.181407190138295, 42.61967020650064, 44.07397131766043, 42.6910416541561, 41.046101585511245, 45.20437878947104, 45.817162836751635, 52.081635152139974, 54.80872184999528, 55.098741900536325, 57.826805268564534, 55.20611286163331, 45.370581380782596, 56.99079913477744, 54.51390866310366, 55.51170864412862, 51.847226465902025, 45.51117089486892, 43.91855132195258, 43.790729122777144, 39.32027439917288, 40.22781672016267, 38.79937579554897, 41.522508744270574, 41.12799282996885, 40.94108012414748, 39.72399219389885, 40.00974470569242, 40.41498438004525, 49.43200742044757, 52.488349637677594, 52.30545736128285, 51.60136445876091, 49.521080524690696, 54.21255296276462, 54.222060788062315, 51.847618702919256, 48.63542110689225, 39.504002140414336, 42.8381109237671, 52.90422677993775, 50.907273600178385, 51.07901065580307, 52.68645286560059, 51.241941990390906, 48.22186600777411, 51.263479725007095, 50.657857925661155, 50.30950046354725, 51.61944658525529, 49.78491875433153, 32.13430004735147, 13.673042155081227, 3.3437663941614093, 2.075832534220911, 6.207070879397854, 8.844996709977428, 6.275732459560518, 11.222654158069242, 13.569565126972815, 10.5014754110767, 9.112949505929025, 3.6413519613204466, 1.9598018378019335, 0.700822442529663, 0.576439610412044, 3.017737759697822, 16.35791826632715, 37.61363937008766, 40.56157904286539, 36.6962165986338, 41.62965613026773, 15.72387791449024, 0.517445998566766, 0.17143503312141667, 0.1669973615677126, 0.1552851182679015, 0.10954684232391658, 0.1784101410979225, 0.1758253144761247, 0.18800336987741534, 0.11675284920080055, 0.2693779952824116, 0.2406963528764825, 0.1551995002814839, 0.0965999257600596, 0.196909494397621, 0.10900197760953058, 0.25238664009638373, 0.263967790430592, 0.11817964199449747, 0.12010169530948324, 0.11323100511705685, 0.16439964934702844, 0.08462622431257079, 0.11243150043751925, 0.132209048456242, 0.1083522737627068], [0.06571900580198535, 0.028059270661023837, 0.01113156684779472, 0.06292987502210083, 0.04656975330304235, 0.04787279991433025, 0.0598876019789567, 0.00999526214605618, 0.006770336025980332, 0.047217522777857325, 0.02478766345208691, 0.021100078161144932, 0.01003215215244, 0.03004259568819356, 0.00765017603689264, 0.04545485022507849, 0.05067814494513216, 0.04787362345884885, 0.020449280723809235, 0.024413902560369145, 0.047381630302557064, 0.09530654717837611, 0.06864840345036599, 0.041965538065039346, 0.0055432867731959115, 0.06777491765998064, 0.02160748883691286, 0.015337927728861332, 0.012256973948810371, 0.02201747228091042, 0.06423869793633781, 0.4019921050677377, 8.374019092129123, 33.64886053146855, 25.442432549691972, 35.79475002904093, 33.97827294565017, 27.997666482002508, 11.799101368073496, 1.0989531273803403, 0.04386326425798959, 1.0040576936256502, 1.1731646161886955, 3.3629450682670843, 4.632180419660384, 5.298483246757138, 4.159580411449555, 2.66279292202765, 3.3095723967398367, 2.128741385475282, 1.6398994552512325, 1.9995030880935731, 6.333128011995747, 12.970790805355197, 26.94691646483637, 46.67543234363679, 55.768208119177054, 57.657327498159106, 55.082777853935, 54.47704230585406, 52.78034656278549, 51.60927980176864, 52.10890346957792, 47.35498689836072, 45.17586315831831, 42.79589053123228, 42.188083971700365, 40.33139082693285, 41.637622464087706, 43.80070763249552, 52.74942651871712, 55.453606574766106, 54.51398318813693, 51.85973098201137, 52.79442787170411, 53.94296846082134, 52.76062488555909, 52.82846227768929, 48.94616696142381, 41.078288555145264, 39.25311165471231, 37.231294570430634, 37.36852653564946, 38.237206012971946, 43.46145399155156, 47.83637154486872, 50.965536486717966, 53.20839481969034, 54.72201785733623, 51.28571956388412, 39.34141989677183, 50.340000814007176, 52.975500168338904, 49.942594112888465, 48.919796866755334, 42.32355087034164, 40.31584255156979, 37.46325569768106, 37.29243255430652, 36.162193744413315, 37.431625704611506, 37.99658821475121, 37.034026807354344, 38.45857674075712, 37.26424247987809, 39.41949075268161, 37.970998671747026, 42.31487458752048, 49.63000866674608, 49.90686132061867, 51.768731994013635, 50.09275813256541, 50.70438508064517, 51.73007311359529, 48.7131703284479, 46.74068881619362, 39.07155690654632, 36.94493016889019, 46.804113541879964, 49.052576941828576, 49.005426129987164, 50.02455988237935, 49.3202002586857, 46.92957447421166, 46.947201605766054, 48.02448841833299, 49.26465165230536, 48.821490503126576, 32.11228966712952, 13.40265945080788, 3.2666886333496343, 1.1954402466935496, 3.1298398346670213, 2.649233043193817, 3.4892387688159947, 4.28480060831193, 3.2705318206740968, 6.081833522165976, 5.715050235871346, 4.44255147249468, 0.2957326149748218, 0.052630083350044106, 0.29607582236489943, 1.404194793393535, 9.979480504989624, 20.923667953860377, 28.364900350570682, 26.839976964458344, 30.103359530048987, 23.083676022868005, 2.966219388669537, 0.043378361245437015, 0.06199569974635398, 0.046825101899523894, 0.0688953135883616, 0.028054750742270585, 0.09342329621675516, 0.05459702175651347, 0.0011483991951418801, 0.0538347642718544, 0.035830882167623895, 0.06571005023415051, 0.012962786075208458, 0.02930793269056707, 0.026522760670031273, 0.00661180705778421, 0.06921581413236357, 0.06346961843871302, 0.01675072888423118, 0.06137207736291232, 0.05175455976578017, 0.033183198031638904, 0.013919479547879629, 0.0345915702411965, 0.04619587558291612, 0.013065734885693079, 0.020658508912029288, 0.029154496770652554, 0.02927908948021791, 0.05779254302803067, 0.03792482263018047, 0.026407364845996904, 0.07907361137650668, 0.03776371433970429, 0.04209995968267322, 0.09170939665167563, 0.03929120173016864, 0.01266190121250768, 0.02267202929473452, 0.01704407927219666, 0.017996774723512993, 0.06172263919706307, 0.018060595593264988, 0.015700849434060436, 0.03628911765953226, 0.07059296442856712, 0.051228184583446676, 0.10714013880539326, 0.015066000989698356, 0.028796680083858873, 0.044334469618456024, 0.04507780473138537, 0.06175280007864199, 0.03908430819489783, 0.07430096021703175, 0.04585071466863156, 0.04375799611631421, 0.8318926093559113, 13.511391474354653, 39.567850482079294, 27.53139472776844, 32.76803739609257, 42.85482414307133, 31.224514130623113, 9.798756318707621, 0.4803357495655937, 0.018197782788305514, 0.06656995328563838, 1.3213696571127063, 4.215522725735942, 8.101827194613795, 6.702765312887008, 6.700008376952141, 7.6209009751196835, 3.6836753160722795, 3.824412899632608, 3.650034372845004, 2.9146223250896703, 7.648816483636057, 15.574262046044874, 30.10790163470853, 47.92926503765968, 58.31652102931854, 59.01924502465033, 56.46200872236683, 55.96260862965738, 55.39155075626989, 54.684249354947, 54.1842334501205, 50.638297065611816, 47.534027407246256, 44.20602575425179, 43.57817588313934, 43.61269274065572, 44.43349969002509, 45.82867107083721, 52.8120118571866, 56.78886767356627, 55.17831110185193, 50.818957513378514, 53.66473121027793, 54.89775573053668, 53.800107894405244, 55.34417636932866, 50.61237804351315, 42.641772762421645, 40.4379577021445, 40.03669138877623, 39.547646353321696, 40.893580221360736, 45.7144477290492, 49.37950649569112, 53.73531426152876, 55.047323549947436, 57.133232162844756, 53.68749272438788, 41.54876901257423, 51.624573123070505, 52.8675369293459, 51.81035226391208, 51.466972289546845, 44.851804779421904, 42.24380123999811, 39.92366829226094, 40.16855755159932, 38.96167955090923, 38.796230054670765, 39.263878560835316, 38.04608460395567, 41.33063031781105, 39.31073911728398, 40.10104571619342, 39.376089726724935, 44.02907979103827, 51.12318046631352, 51.39663634761688, 53.45985797143752, 50.63619075282928, 51.464563954261045, 52.410918128105905, 49.26219232620732, 48.479510814912864, 39.7041489231971, 40.00327671727827, 49.29461856042185, 50.19120570152037, 51.8844929049092, 50.98143385302637, 50.88479449672084, 49.91416869624969, 49.70752254609139, 50.80093422243672, 50.228519208969615, 50.17133497422742, 37.482385097011445, 17.869828208800286, 4.906249661599436, 2.1843664780739815, 4.782535164586959, 4.707775769695159, 5.3516357752584645, 5.422598806119734, 4.832527243321942, 7.179564708663571, 5.172910526875527, 2.907588044481893, 0.9558007733956461, 0.02770741796872068, 0.25795056815108947, 1.2365888515787742, 9.040606291063371, 23.654239677613784, 32.790536111400975, 30.81004119688465, 33.51300924055038, 29.251422689807033, 4.531181839204604, 0.02964503819032783, 0.09593689964423258, 0.04424972880271174, 0.08803120934434476, 0.020541944803910393, 0.11224775424888057, 0.08084508244909587, 0.02283847913326275, 0.055801499665023825, 0.06230222301617746, 0.06921851076185703, 0.10863899749012725, 0.09287974917359891, 0.03847752442403186, 0.03811973838075515, 0.05341744170554223, 0.039126952479202906, 0.016257360600115314, 0.01221692861778842, 0.04885353035323563, 0.006802687440217743, 0.07547318965436951, 0.05009103048172209, 0.02528124815604139, 0.022122474207032113, 0.12780584319825136, 0.15115351416170597, 0.15333695667645625, 0.1724853396656052, 0.09507452978962853, 0.1748200385801254, 0.23076158677858694, 0.151521879879217, 0.15258059806881413, 0.14798328911344852, 0.05913885828528193, 0.12275257403211248, 0.1041021941590213, 0.13700802239679521, 0.08340498056983756, 0.16439922033779084, 0.14420057676972883, 0.09186909534037115, 0.1731364837577266, 0.16140956221328628, 0.13041670914859543, 0.30636986837752406, 0.2018660526241987, 0.16584487421618355, 0.14098835478146232, 0.14813912671900567, 0.18690844637251672, 0.16040067038228437, 0.2166834494639789, 0.14514536236322698, 0.1759956771087262, 0.8898005826819329, 15.821756739770214, 48.40979460747012, 36.23183542682279, 44.47601426032282, 42.26034187501477, 35.80738790573613, 13.989008684312145, 1.2106214127232953, 0.1478064760205246, 2.890209738285311, 5.573802253892345, 10.622744310286738, 15.328717750887717, 14.154458180550607, 11.425253402802253, 10.568225326076632, 11.104082868945214, 6.536498492763889, 4.233866180143049, 4.707057975953625, 7.8559122354753566, 14.783198429692177, 29.97779073253755, 47.35378273071782, 60.3919529914856, 59.33637649782243, 60.160074234008796, 57.96763796960154, 57.713182049412886, 55.296598019138465, 57.15662910092262, 51.752685577638694, 49.81975332383187, 45.595901935331284, 47.73992046233147, 45.08910425247685, 46.262473444784845, 47.981569843907515, 55.282830499833636, 60.29542346154491, 57.1858899824081, 52.115575421241026, 53.43848497636857, 55.82638079120267, 55.62189978937949, 57.13559342968849, 54.228085548646995, 45.42302346998646, 43.059991559674664, 41.233994883875695, 41.15590049374489, 41.80025569854244, 48.45301912676904, 51.01697837152789, 56.208882485666585, 56.34010930215159, 59.12478816124701, 54.692776587701616, 46.28175189418178, 52.13774073508478, 57.30639303884199, 54.6923961177949, 52.93589599670903, 47.307306566546046, 45.209454336474025, 41.59823402281731, 42.565008055779245, 40.16126586544899, 41.0787239382344, 41.424810348018525, 40.391724724923414, 43.02564728644587, 42.51727281078216, 41.31297572966545, 41.23110801942887, 46.71578568796958, 53.95159767520044, 53.60102407393917, 56.720708647081935, 53.67000287578952, 51.50324636890043, 55.19999788653467, 51.67423032945203, 50.74576216359293, 42.09816755787019, 41.28761760650143, 51.53879088740195, 51.347116424191384, 53.84369719413019, 53.46150536690989, 53.503282531615234, 52.7473045164539, 51.909070476408935, 52.12542449274371, 50.93134910829606, 51.725476095753336, 37.694538254891675, 17.43899703025818, 4.59662119227071, 2.9614698886871342, 6.626368328448265, 6.141942864464176, 8.019198544563787, 10.604086575969573, 9.24901064365141, 13.432198820575593, 14.91020183409414, 10.888779067224073, 1.9435204469388532, 0.16210124767836065, 0.6258069291230172, 1.9516109482895945, 12.006380981014622, 27.02042168186557, 38.528269413978826, 38.049159742170765, 41.27901977108371, 32.261679018697436, 4.823377824598744, 0.08987605631832155, 0.16505753501288353, 0.18351559617346336, 0.1299318674230768, 0.1310248144211308, 0.19782694597398082, 0.18191062665033728, 0.10721216639203411, 0.18791998886773664, 0.1840110558776125, 0.21840492563862957, 0.12932078972939523, 0.16483481793153673, 0.07459026566075702, 0.14364859509852626, 0.114428362238311, 0.12825815683050504, 0.11023794556216848, 0.1661624023390393, 0.2132745573837911, 0.10460737551892958, 0.14982861106193837, 0.17162796470426744, 0.24287018864866228, 0.09294461383814774], [0.04727970230423155, 0.017062689463097244, 0.05690604906469103, 0.06053039954314309, 0.032200146346322955, 0.04658607480626914, 0.054123334271172364, 0.032091524654759035, 0.0667523128551341, 0.031049878734554497, 0.040237377773249344, 0.08782962096794959, 0.04791202361605341, 0.05777695313877156, 0.04505582949927738, 0.03574555529461753, 0.06401769306150175, 0.05552392302741928, 0.05979313184657405, 0.056524039321248574, 0.02354115412961091, 0.02105079955541559, 0.0787817318773558, 0.04066090182130856, 0.06984120234847069, 0.02979243350695939, 0.025043847084405924, 0.03146992474343748, 0.02679452844594996, 0.0504961186238835, 0.042059977553905024, 0.08954729734649582, 3.6998014055913497, 20.79194691873366, 35.480446584763065, 30.46652001719321, 32.83633370553294, 36.10922213523619, 27.161648581104895, 7.839861896730239, 0.6318129358753082, 0.0627572869040793, 0.4112478567948265, 2.3807416567879343, 4.2039522240238805, 4.423084259033203, 4.15241914410745, 6.540655224554001, 2.2600797443620624, 3.707364715876118, 2.775499777447793, 1.9295656344582959, 4.554518961137341, 10.27141761395239, 19.411288307559108, 37.35099746334938, 53.37796280460974, 57.99938563377627, 53.98031334723196, 54.61157568039433, 53.95541021900793, 49.641956206290956, 48.275323990852606, 45.60399770736695, 43.593512350513095, 44.07879975534255, 43.25067366323164, 43.99036207506734, 39.26169380064934, 44.28490854078724, 49.03369857418922, 54.26311623665595, 55.56612760789933, 54.35713152731619, 48.30690691548009, 52.68256971913, 54.688316852815696, 53.973123642706106, 53.108782306794204, 47.30781255229827, 39.41945152897989, 40.91650647501792, 39.54386126610541, 37.73266369296659, 40.574118860306285, 45.318708035253714, 49.80840590692336, 52.62247900809012, 53.58509140629923, 52.993252815738806, 42.54250934047084, 53.525851849586736, 53.606256515749045, 50.21185698047761, 48.1289372136516, 46.73079267624886, 45.41033852484919, 42.09935211366223, 38.62963914871216, 38.029100741109545, 38.55510234832764, 38.74680426812942, 37.99237951155632, 38.730640180649296, 39.42530762764716, 38.77294294295773, 38.70620381447577, 37.719143282982614, 44.61432095496885, 48.20308177701889, 49.19349593500937, 51.03737469642393, 52.05290379062776, 49.84915148827338, 50.406230034366736, 47.09049755527128, 45.78299899255076, 37.64182552214592, 45.3233011307255, 48.428594527706025, 47.277928013955396, 49.298768428064164, 49.04011557179113, 48.5176754766895, 48.106156087690785, 50.679234843100275, 49.23784225217758, 37.03344237419867, 17.281358934217884, 4.94519095267019, 0.6215641503372501, 1.1042817898334996, 2.9253735417319886, 6.217813761003557, 4.132002226768002, 2.993333507930079, 4.259383159299051, 5.034853883327977, 3.4449767826064943, 0.9921894595026971, 0.5009267220814382, 0.16205770324074453, 1.2858046687418416, 8.24995550417131, 17.72755011435478, 26.899681322036255, 30.52501628475805, 25.9150428541245, 31.51367518209642, 10.043401410502772, 0.6575638476398684, 0.15632211020396602, 0.03821261505025529, 0.00702397385236597, 0.011019181749302774, 0.08520710282027723, 0.04083780301434379, 0.025182145106936657, 0.038216334407127676, 0.023355797241111437, 0.03644753315095459, 0.030929771469785806, 0.06217729705836504, 0.05490506954130627, 0.04330429203447796, 0.030750889939466314, 0.037265454584191886, 0.1335230424639679, 0.019202003398189144, 0.010368880353898052, 0.01775217242538929, 0.008980485802185873, 0.024873844513128844, 0.032900542231096376, 0.050374352778758735, 0.04076752593860992, 0.05642971857601116, 0.04023490330925392, 0.029659074836320458, 0.07106279083076986, 0.11254078287991787, 0.043172724094362035, 0.019091495215111685, 0.03354713959138721, 0.10341456895994564, 0.017378174046414997, 0.02105058122035717, 0.08829256790059228, 0.03697045710718921, 0.07161501765010819, 0.046704431560130856, 0.02168995245630222, 0.07557334798958994, 0.039626254114292325, 0.05100539855418667, 0.0342464208182308, 0.07336720628964324, 0.04947386621948212, 0.0018796726128071427, 0.06071401932727426, 0.07718298298817489, 0.05576679971249354, 0.022918263360136942, 0.0682402930913433, 0.07266710917916029, 0.11702426649149388, 0.03584058084074528, 0.06996527794868716, 5.442891188206212, 28.369067868878766, 37.12371180134435, 33.38970953418363, 33.03532731148505, 42.16400454121251, 29.746074753422892, 6.916816897930638, 0.34935190552665346, 0.14193235896527767, 0.3063658847203178, 1.7183347238648323, 5.257496439641522, 6.607534087473347, 7.2210525985687015, 4.888217545324757, 5.652780157904472, 5.655768023383233, 2.8570093262580136, 3.5961390454922957, 5.091852295783259, 11.212253012964803, 21.007206593790364, 39.23724958973546, 55.12156225019886, 59.70388297111758, 56.304262761146795, 56.228792436661266, 55.133576470036665, 52.32064477859005, 49.65170329616916, 47.26328580610214, 44.489216958322835, 45.18543766390893, 45.05296353370913, 45.48136480392949, 43.084090602013376, 44.99512818551833, 52.26268783692391, 55.998510083844586, 58.637394443635024, 55.22000589678365, 49.90129155497397, 52.36481066673033, 56.33856781067387, 56.39865067697341, 54.848667267830145, 48.08592450234198, 41.633774618948664, 41.20056452289705, 40.2082323258923, 40.601626442324736, 41.88173901650214, 47.193247964305264, 51.76444876578547, 53.74924652038082, 55.28907099077779, 53.9307895014363, 44.44374492091518, 55.5880222782012, 55.70403029841762, 52.90585848592943, 50.33022626753777, 47.16492845166115, 46.75750009475216, 44.8004295749049, 39.50983862723074, 39.48120140260266, 39.988469769877774, 40.202403683816236, 40.040366649627686, 40.444366855006066, 40.89252510378438, 41.21035868121732, 39.82093357270764, 39.98584178186233, 46.08562946319581, 50.536680221557624, 50.515322915969364, 52.13834478009132, 51.386034181041104, 51.34048761860017, 52.23510180750201, 50.161203492072325, 46.73738618050852, 39.106513069522, 47.601280366220784, 49.65514321481028, 48.97510228618499, 50.31302275196199, 50.57314649704964, 50.92804647261097, 48.28186650430003, 53.37362858556932, 50.86995617035897, 41.81830252370527, 22.12258550428575, 7.474101858754312, 1.6016569589414906, 2.5577177732221545, 6.514709726456673, 6.322594486897992, 5.976589956591207, 3.008755532003218, 5.435627448943354, 7.002875660696338, 3.2702712282057735, 0.7988592044961068, 0.12610016375659935, 0.11839662873817068, 1.2151466021614692, 8.113831118229898, 20.870666926906956, 29.590062479819025, 35.331172943115234, 30.62820599925134, 35.979364225941325, 13.940852765114078, 1.0290127319674338, 0.01870786136526975, 0.018677361489784335, 0.051015694775889, 0.040291455919824304, 0.02211569432890223, 0.02903397198796513, 0.04719031899566612, 0.0616326928138733, 0.021211116860109954, 0.06930710883030007, 0.017493460702920155, 0.030392067762272015, 0.018637611102613232, 0.039960168857848456, 0.04785204276202187, 0.027598792446717143, 0.07537159873473068, 0.02014472055429172, 0.004839106414076542, 0.028852321049799363, 0.0054872067431138176, 0.0396557446689375, 0.02727806782199731, 0.00775851188189981, 0.016224173671235482, 0.0940303979141097, 0.13521033579543715, 0.10731838448273559, 0.20106909135656975, 0.12305993616821305, 0.08871901074364301, 0.12855226564551556, 0.18229169410563287, 0.15993867339866777, 0.16778479270156355, 0.15976181434046838, 0.24135468287333367, 0.17118665209460646, 0.17519519183664553, 0.17902782246951135, 0.08873653883535056, 0.1240447421948756, 0.15488407123954068, 0.14996362639771355, 0.16289456236747005, 0.23570889066303932, 0.1266773956857862, 0.1404173741297376, 0.1550128659413707, 0.28767790525190295, 0.20285547050016545, 0.17736901228706684, 0.256550419895399, 0.151685317076983, 0.18138639268375215, 0.08869095660385587, 0.13843581110479372, 7.152074287014623, 35.49231175453433, 46.776778544149096, 42.16654623708418, 42.92371273040772, 43.701891360744355, 33.09836372252434, 9.445581205429571, 0.8015756297015375, 0.5612191593935413, 2.486166141686901, 7.732078106172624, 12.306406017272705, 13.033998820089526, 13.386657161097373, 15.371236243555623, 7.225948206840023, 8.475389807455002, 6.0233691238587905, 5.139415446789035, 5.871493479897899, 11.981151315473742, 22.556030942547707, 40.10979260167768, 57.02171133410547, 63.889585387322214, 58.814034461975105, 58.56990222007998, 58.84767270857289, 53.07720330453689, 51.82706548321632, 49.238469831405155, 47.38908406226866, 48.088179865191066, 48.27239398033389, 49.21835199479134, 43.89714694792225, 48.371845676052956, 52.044317722320564, 56.9353368205409, 60.53303280184346, 55.67441640361663, 48.47750648375481, 51.5238937254875, 58.82435421789847, 59.67970155900525, 56.807800954388036, 51.74069489202192, 44.27508692587576, 43.64458553252682, 42.38033894569644, 41.72131799882458, 44.80226916651572, 50.63817939450664, 55.412425610326956, 56.359387751548525, 58.660834527784786, 56.17236521936233, 49.42530016745291, 56.49659618254631, 57.172726508109804, 55.04684109841624, 50.97655050216183, 50.49142783687961, 49.389904699017926, 47.543425406179125, 42.10442766066521, 41.13450004208473, 41.65481813492314, 42.420492249150435, 40.681662405690844, 41.41550648596979, 42.154571240948094, 44.301166765151486, 41.03884912306263, 42.035048777057284, 47.857026746196134, 52.891620282203924, 52.52196435005435, 54.67704788331063, 54.31088286061441, 51.6955719455596, 52.07390416053034, 49.46484158116002, 50.15128381790654, 41.53879050285586, 48.814928377828295, 52.733964535497854, 49.812002720371375, 53.19889091676282, 50.795027132957216, 52.90635662694132, 50.82697091564056, 53.84021412941718, 52.510954256980654, 42.52864768428188, 21.456013994832194, 7.178175209030029, 1.5345355219418004, 3.8524443632172005, 7.779700092730984, 12.768634788451656, 11.162265346896264, 7.055814420023273, 9.865331688234884, 13.097508857327124, 10.106745727600591, 3.391561455303623, 0.8549220703782574, 0.4068075498986629, 1.9444517647066426, 10.671925929284866, 22.024224227474583, 36.95895656462639, 41.164517941013465, 35.95762645044635, 41.58117563493791, 14.636051693270284, 1.1875629016468603, 0.2886745856413918, 0.1727054214044925, 0.08621276176023869, 0.16048369899151788, 0.22443340941061898, 0.13711512148860963, 0.16356586989375854, 0.07417709912143408, 0.12650658872218865, 0.2187028878758992, 0.08709692681628851, 0.17355849095169576, 0.16342426620183453, 0.12287033706783287, 0.16571788748185481, 0.1812320412887681, 0.2671286079191393, 0.06739673069528035, 0.07537916002254333, 0.13816535142400574, 0.13828833917936972, 0.14215662354423156, 0.11099389814321073, 0.18312899756335443, 0.14537564839326567], [0.06154132533758398, 0.012708811648941089, 0.023908288360783653, 0.04807411632951229, 0.043983628162212914, 0.0370158976124179, 0.020579643990664233, 0.011278578162854238, 0.02827797727208705, 0.010204014402153272, 0.0341556815340394, 0.0385863280614778, 0.05792075933347787, 0.027813170661008167, 0.04521157134384398, 0.05078014189137086, 0.026477400604034626, 0.05534296539882499, 0.024676990560105732, 0.05963439842866314, 0.018457375511887576, 0.019612593966866695, 0.04539682289525386, 0.05647192235975977, 0.11737370217639594, 0.07484397865952024, 0.04176538993394183, 0.038247066024210186, 0.062114791944623, 0.06430624773906124, 0.023070243712995323, 0.06520905937518805, 0.7599559726734316, 12.58011293026709, 34.42420721054077, 30.964135431474258, 26.109174682248025, 34.32502615836359, 42.10482382005261, 22.876678820579286, 6.088080877257932, 0.2927986820859294, 0.29068357461402494, 1.236117431713689, 4.606128036975861, 3.0859301263286225, 5.547800862020062, 3.983820474916889, 1.8219931615937142, 4.248333352227365, 3.0839976235743496, 3.513806779538432, 2.1455006926290454, 7.282192053333406, 12.214919674781061, 27.275207081148704, 43.61240248526297, 55.121703455525065, 55.93895281514814, 55.349746134973344, 53.44506671351772, 50.71415570474441, 50.42720687004828, 48.92659433426396, 47.058036019725186, 49.41335655027821, 48.75818737091557, 50.562818896385934, 44.78163749940934, 40.519284125297304, 49.171793460845954, 54.453127614913456, 56.82301190591628, 54.41744189108572, 53.06607554035803, 49.591098754636704, 55.02475030960576, 56.14100586983466, 54.04147094295871, 51.828971755120065, 41.164557164715184, 40.05944505814583, 42.80768117597027, 41.635253352503625, 40.52666994833177, 44.52609116031278, 49.087627241688395, 49.09473065407046, 50.69868587678479, 52.42017884408274, 43.022780033849905, 41.84881856364589, 52.214932980075965, 55.21495388400171, 51.30296230316163, 50.67595181926605, 48.402742185900294, 47.50404873201924, 44.325214816677956, 39.64763933612455, 39.68732587752804, 38.62720727920532, 39.70816150788338, 41.66262757393622, 40.96059391575475, 39.52035842403289, 39.31523415350145, 37.41806999329598, 38.49818875712734, 42.97762178605603, 49.22383154592207, 49.74426338749547, 52.288544101099816, 50.26833911095896, 50.06294419688564, 49.08641915167532, 47.05483536566458, 38.932222550915135, 42.73197158690422, 47.44032982856997, 49.051098208273615, 48.66580770861719, 45.894661026616255, 48.53935049426172, 47.8380032508604, 46.7021672187313, 40.223690386741396, 23.24504625412726, 6.820950248549062, 2.675758561780376, 1.2142124651901185, 1.5583965254406777, 5.547076694426998, 2.4793365597724915, 5.09404686189467, 3.325004471886543, 5.698036464952654, 4.460537010623563, 1.287274699537985, 0.36513573760467194, 0.4404581151902676, 0.5822982831347374, 5.57758390903473, 15.610596922136123, 24.665599292324437, 25.434942783847934, 24.535153027503725, 25.312253006042976, 15.502626818995322, 2.6916358259416397, 0.04244047810413665, 0.030016094791672887, 0.025212892045777653, 0.01695224831271316, 0.01419289249761571, 0.015378382916922773, 0.038826695808600035, 0.0029653798405741977, 0.03254845205153669, 0.09559607478759943, 0.04511749957718196, 0.043148638290022655, 0.034966949493654316, 0.036505706037484834, 0.0780478502894121, 0.025912359048942887, 0.08256360918523804, 0.07410986724519923, 0.027731867664824092, 0.03467021682750314, 0.031542218545632016, 0.042190438496970364, 0.012192748010068411, 0.03264584097891085, 0.011504741682250415, 0.054536041157740744, 0.042728856581473545, 0.015163494296552194, 0.01798031915489945, 0.06232067041339413, 0.025275144350504684, 0.014313912364624202, 0.06143373594949804, 0.05463532232228787, 0.014984953675359009, 0.04907225228605732, 0.07965492655432994, 0.025689844980896003, 0.01073792693205178, 0.052596386972694635, 0.02515576103882444, 0.03225485651543544, 0.05225714791806475, 0.01629048815718101, 0.04985317550299149, 0.07580095271189367, 0.07066792613195796, 0.01829148300232426, 0.03396415955296928, 0.019674852017253157, 0.08579227142035963, 0.046716623849445776, 0.07297368224469886, 0.017109434233017026, 0.07683686446398497, 0.00671773020463485, 0.010192047151166105, 0.03614954793104722, 1.2828658328902338, 17.035869552243142, 39.37374414936189, 34.63616424991239, 29.080952559748006, 38.45395618869413, 43.99178589543989, 22.07972772659794, 5.092672071149273, 0.21599986920914344, 0.1936244327695139, 0.2477576304227114, 2.231370201033931, 5.120000695028613, 5.365962722609121, 5.409607916109024, 6.572971142107441, 4.830665098082635, 4.464489288868443, 4.504668087728562, 3.2265698957827786, 8.46145264564022, 15.053452676342381, 29.844567429634836, 46.20940769872358, 55.55350934305499, 57.1934130883986, 55.32761612246114, 55.48431481084516, 53.12226349307645, 51.25127723140102, 49.6910995821799, 49.16154038521552, 51.625228158889286, 50.96184161401565, 51.35005035708028, 46.74252840780443, 42.95555453146658, 51.30505292646347, 56.010987143362726, 57.36105911193356, 54.44768336511428, 51.48050838901151, 50.898361975146884, 56.17238090884302, 57.37928244375414, 55.443396645207564, 52.94512925609466, 41.62333719192013, 40.986003029731016, 45.68916020854827, 42.97447604517783, 42.43013343503399, 45.60392710470384, 51.38008002311953, 52.865159973021484, 53.67722395927676, 54.22413572188347, 44.96712246248799, 43.817169820108724, 54.37959101892287, 55.37915606652537, 53.44133261711367, 52.744892258797925, 48.86311077302503, 48.349186143567486, 45.22594005830827, 41.53043193201865, 41.10622759788267, 39.77461038097259, 41.7842092821675, 43.56056836343581, 44.26572030590427, 41.56801608300979, 41.67048408139137, 38.6806966412452, 39.74333340121854, 46.86218815465128, 51.302774029393355, 52.70648441007061, 53.58950799511325, 51.49646851324266, 50.58202674311977, 50.90126060670423, 48.29991332946285, 40.14193642523981, 43.45825725986112, 50.12932246731174, 50.528015705846975, 50.05515829209359, 48.040923149355, 50.61843810542938, 50.013102639106016, 48.82924110658708, 44.12821769714356, 26.834375819852276, 9.882634243657513, 4.496213909118406, 1.9255423858281107, 3.012446482335368, 7.149568382770785, 4.944997285642932, 4.08733059802363, 4.333681185399333, 7.21073333294161, 4.469995315997831, 1.189691768057885, 0.21960081953194835, 0.24740196644298493, 0.7014259359528942, 5.005284115191429, 17.21603774255322, 25.302539256311235, 31.11195191260307, 29.38722691228313, 31.092634239504417, 22.92725190039604, 4.288094418664133, 0.06455655930744064, 0.060441219247877605, 0.0643016052462401, 0.03126990493206728, 0.04455178194949704, 0.04044646231998359, 0.0051718418610342334, 0.02544229515948363, 0.012916813138872387, 0.10024662685370254, 0.03805524143840998, 0.02281586230251818, 0.06541189647489978, 0.04934734296834758, 0.04239153657709399, 0.06586802522501638, 0.09553523974553232, 0.028273139426845218, 0.03479522705498723, 0.05680816601060572, 0.039577687970332565, 0.03840046363972849, 0.011600769845949066, 0.03661646319913768, 0.04447743311644562, 0.011941277733703536, 0.08517968453346722, 0.09654786242472549, 0.14668282421846546, 0.1645904665272082, 0.10853935243381609, 0.1602577643408891, 0.21698358739095353, 0.18795348223178618, 0.17077489515706418, 0.11206351010309112, 0.2465099949509867, 0.11606335474718964, 0.13859889590211455, 0.10930685762075648, 0.13324625489692535, 0.08718239158512124, 0.13219225580894178, 0.17129152953144045, 0.24719285508317335, 0.16338337242843645, 0.18770735350347337, 0.0965724002209402, 0.103928713548568, 0.12227104946730599, 0.18166413019982078, 0.17634723485717851, 0.1373589672749081, 0.12625256162737647, 0.14701106225050267, 0.20951328018019277, 0.08822739680087374, 0.11785400100052358, 1.2156036808606119, 18.67198624918538, 46.19689533787389, 43.063764879780436, 37.745976217331425, 42.389383931313795, 51.46975324999902, 28.159885906404067, 8.018329739570618, 0.6748616839608839, 0.8339761233618184, 3.055351083317111, 10.764117317814982, 13.543177381638559, 14.168047232012595, 9.007374990370966, 8.28676204527578, 9.432281428767789, 7.3849429526636685, 6.8968868447888285, 3.8101205181690956, 8.856670664202783, 14.621797800064089, 30.893073851062407, 46.93798011349094, 58.05134527144894, 59.58283078285956, 58.107223356923754, 57.41031231418733, 55.203053412898896, 54.979827404022224, 53.6019693651507, 50.947583798439275, 54.31729201347598, 53.04749527285176, 54.89105239991219, 49.07839790467293, 44.75179610713836, 53.19362709599157, 58.45366278002339, 60.06816133376091, 57.02290765700802, 51.16317687496063, 52.207535389930975, 56.08044055200393, 59.21072336935229, 57.02726933263964, 55.27675082606655, 45.16942262649537, 43.733603723587535, 48.3253106763286, 45.19185073914067, 45.2204801190284, 48.90757083892823, 53.779170282425426, 53.09051582890173, 56.41517562250937, 54.79424830405943, 48.29943087793166, 45.8312794470018, 55.59024233971873, 58.772531863181825, 55.80232489493586, 55.81173073860907, 51.7905992077243, 51.50391709419989, 48.74475325307539, 44.420575480307306, 42.939327686063706, 42.4620379940156, 44.491319348735196, 46.377092945960264, 46.675875571466264, 45.044381387772106, 43.469965534825484, 40.740297917396795, 41.81787498535649, 47.242344271752145, 53.11913344167894, 53.74623414008848, 56.12407692017094, 51.59259796142579, 50.94052745449928, 52.648425486779985, 49.831669484415364, 40.99690329643988, 46.34583165568691, 51.74756296219365, 52.5062160338125, 52.33547918258175, 48.830441351859804, 51.539657731210035, 51.11513960746027, 52.1096997107229, 45.83236594353953, 26.837001846682643, 8.756055005135076, 5.517119592235935, 2.459682788579695, 5.180490507233528, 11.31052113348438, 6.782672328333701, 9.705121497954092, 9.790605633489548, 13.718254335464971, 11.61974608898163, 3.778563334095863, 0.9215920670859276, 0.779994503865319, 0.8498326112185756, 7.327555735265055, 20.349976208902177, 32.630732867025564, 33.71032799443891, 33.06263877499488, 36.8390614755692, 24.039096755366174, 4.42871384082302, 0.2545950111121901, 0.19544317146703122, 0.13695199072601336, 0.12484114421831986, 0.1497490298483641, 0.13175065208586956, 0.12957076421908795, 0.1292580011631212, 0.11496765749348749, 0.18650589781182428, 0.0626621809187195, 0.12489125402944705, 0.1706570248690344, 0.10784750609027763, 0.21283546642911053, 0.09259270368925027, 0.19433681793030233, 0.196770035751885, 0.1472451480766458, 0.15540179345876942, 0.11838635549910607, 0.145428539103558, 0.07281723942968153, 0.11988154462268276, 0.2239707842349045, 0.10636955394499725], [0.030797278478501305, 0.05158628472277234, 0.05363938120764591, 0.04812311914358889, 0.0727132506548397, 0.05131014833046545, 0.042916161248520504, 0.035123108856139645, 0.09786785490089848, 0.026333923827135758, 0.06778986403538335, 0.04822979688704495, 0.06423505518825785, 0.03016168214080315, 0.07746950753273503, 0.10811011336984173, 0.014809462084104458, 0.01425962258626016, 0.04643305640427336, 0.006886527623846046, 0.050782827029545466, 0.07725497993129878, 0.030493160724760066, 0.07938118801722605, 0.06384559907019138, 0.05418820276616081, 0.04705093695872253, 0.08545771316294709, 0.06063408954369445, 0.0355330195217844, 0.034603103694896546, 0.0943904362558838, 0.04871450837761645, 1.840551488341824, 15.796644745334504, 33.47553883829425, 27.054165832458008, 33.21937276471046, 48.81431256571124, 42.20636613907353, 20.46548608810671, 5.150400534752877, 0.3652103239249799, 0.2526691273575829, 1.3508303343288361, 4.118864738172101, 4.267183282682973, 3.311707391854256, 8.042920549069683, 3.204908851654299, 1.7533667601885337, 2.1525143807934177, 2.0169982073768495, 3.021586830577543, 6.568223603310124, 15.191720147286693, 31.14624715620472, 47.46067908502395, 54.89789693586288, 57.29624978957638, 57.04304510547269, 54.389769569520034, 51.19122574406286, 49.27053912993401, 52.74231526159471, 52.97730445861817, 56.44543278601862, 52.69766299955307, 53.96969156880533, 44.51996441810362, 46.841368213776626, 52.950789236253314, 54.62078148318876, 54.67309805654711, 50.717140628445534, 54.57586642234556, 51.17984694819297, 57.616574072068744, 55.33019704203452, 52.99841857725575, 42.8450103729002, 38.477498254468365, 39.54374359500024, 41.889862245129, 40.57926500997236, 44.1344464209772, 51.17884282142886, 52.026043399687744, 54.60185212473716, 53.31404778265184, 42.44262226166264, 46.05826700887373, 44.3479920202686, 55.19097251276816, 53.062055110931404, 53.47546900472334, 51.97040850116361, 52.32755991720384, 50.36330753757108, 42.93194186302924, 38.522566287748276, 39.086414844759055, 40.342816691244806, 42.81495325026974, 42.55387636923021, 42.873949620031546, 38.93808649432275, 39.419106360404726, 35.74241384383171, 39.286432189326135, 44.47071906059019, 49.6580457687378, 48.8101391638479, 51.58119170896469, 50.572962145651545, 51.819507075894265, 47.887778128347094, 47.193298955117505, 43.19652926537299, 45.462949275970466, 46.27223622414374, 50.37590226819439, 48.32520869470412, 48.7298325569399, 45.292126132595925, 40.77059038223759, 29.801876352679347, 10.790909067276987, 1.944060508281954, 4.231292615013738, 2.240132285702613, 2.108629922713003, 8.157594473131242, 4.383456553182294, 2.933173419967775, 1.3860861909004951, 4.098336768727149, 3.711883531462762, 1.3908823916027624, 0.06379266622506323, 0.41191269853903406, 4.93001236069587, 16.00921759682317, 25.378603819877874, 25.8068109327747, 20.845879508603005, 24.97808667921251, 20.101817654025172, 5.141980676881729, 0.48602404433392715, 0.07143489505735136, 0.008445755473428197, 0.040251833852380514, 0.03769952766296845, 0.03310408413169846, 0.021375168843435186, 0.01375022870037825, 0.06264518142767972, 0.02346279291105607, 0.0333677179690811, 0.01756605136418535, 0.02222295046874112, 0.01885352723841225, 0.03822235968865214, 0.03333040565672902, 0.02401647721267035, 0.026288525456742897, 0.05404013329215589, 0.09072433015511883, 0.020194137055847435, 0.010101314570244041, 0.03971469513471088, 0.02317350278908928, 0.01603193539795616, 0.02255419156544151, 0.0558188745391465, 0.03314973148066671, 0.028961687761869644, 0.02326421909064295, 0.028604288592994697, 0.022023926571672483, 0.04077776087327831, 0.027586584835643732, 0.04956709911986705, 0.10266988553226956, 0.039743048048788504, 0.041938092965151996, 0.062246145380120126, 0.02826394062609442, 0.05786825932802693, 0.052246970439990686, 0.020673336543803735, 0.028009804363753048, 0.051269112830801364, 0.04783997687721445, 0.015984606485994115, 0.032558173707295815, 0.05260402486929971, 0.032416535541415215, 0.041994411918905475, 0.06806036968144678, 0.0581421893871119, 0.04622812022364909, 0.05143181075372043, 0.06025898608288938, 0.057406235531333, 0.02709741662857273, 0.12962803695230715, 0.06437083661195732, 3.629143339010977, 24.425463945634906, 38.63176899571573, 28.09198379516602, 33.10669875914051, 52.51811258254513, 47.3170183550927, 20.603369166774137, 4.024919805026824, 0.2202657838502238, 0.10220525320619346, 0.847381191147912, 3.47160967607652, 3.070546590512799, 3.8481089184361124, 8.08180300458785, 6.445212681447306, 4.464864855812443, 4.581795123315627, 3.2382541462298366, 4.510929661412393, 9.026907413236557, 19.400380196109897, 34.73893427079724, 51.387744334436235, 56.26991064317765, 57.91665892447195, 59.111962010783536, 54.94712268152545, 54.61475672260408, 51.6623886939018, 54.33550750055621, 55.21644830703736, 56.95544681241436, 56.20941985038019, 55.58291142986667, 44.65823581141811, 49.21232331183649, 54.679405227784194, 56.71689610327444, 55.9982394403027, 50.80706880938623, 51.835388752721975, 52.907909885529556, 58.727428528570364, 55.89506149291993, 54.53077485484462, 44.103895079705026, 40.57764114872102, 41.7443815354378, 44.23274886223578, 42.81338037983064, 44.53739543114939, 52.03352335960635, 54.780723971705285, 56.54107978267055, 54.54334997361707, 43.987357539515344, 47.928511942586596, 45.17827149360411, 57.92375841448384, 55.80517645805113, 53.42594908129785, 53.013813880182084, 53.742429441021336, 51.79810662423411, 43.12813881904849, 39.22518437908542, 39.23031876164098, 42.38042523784023, 44.17084993854646, 44.345736657419515, 45.90006997508388, 41.80443302277596, 40.62467036708709, 39.258920684937515, 40.63586481155888, 47.85250817575763, 51.481108511647875, 51.750402758198405, 53.19634922089116, 51.92127297001501, 51.67182983890657, 48.6776924902393, 47.92775492514334, 45.15783202263617, 46.09165814615066, 47.91200660890149, 52.12498126491424, 49.33903548025316, 49.72862489761845, 46.367910677386874, 44.30229248539094, 32.881260533486646, 14.595697368344954, 5.010702379288213, 5.907550358003186, 4.480271435553028, 3.391969381801544, 6.568514348999147, 4.428607446532096, 4.547294445576207, 4.4795575641816665, 5.079219812347043, 2.0034317095433516, 0.32440878751297153, 0.12277874359560591, 0.3705077912778624, 4.205746218081444, 16.128218385481066, 28.84380409794469, 31.936643969628122, 24.310054086869766, 28.302871988665675, 25.66996728220294, 8.31947559310544, 0.7424543569645574, 0.11698386301436733, 0.0161052672492881, 0.05010376669346325, 0.03910839016879759, 0.10108985983195806, 0.036565142969090136, 0.03479592802543794, 0.07679449214089303, 0.03236033533129, 0.01751409911160027, 0.005746071204362858, 0.027215227544788393, 0.024155324903286757, 0.05433423061584754, 0.04915496679924188, 0.046596072253681, 0.026493496111323758, 0.021242783104460088, 0.04438806129919906, 0.019597498204318747, 0.05493175621414858, 0.03252322094575052, 0.021972499089315537, 0.009345949004073779, 0.042024561309165535, 0.04534506982552909, 0.13724774663006106, 0.14268761440630884, 0.14749124616144166, 0.17404472695723658, 0.205587983552006, 0.10415966607510083, 0.09972712731048947, 0.18363706707473726, 0.19949105748486137, 0.08921820129598342, 0.20551978640498655, 0.17818232187099997, 0.14484704772551216, 0.13585064740430924, 0.1963890602271403, 0.21234893931015847, 0.11334181973530401, 0.10192422917292965, 0.12964691335876144, 0.1422679361196295, 0.1276316731086662, 0.15600341762746536, 0.11158432210645369, 0.19778856496897437, 0.17934628521963475, 0.18382799150722642, 0.16618569141193745, 0.11803878140786003, 0.20186341728173918, 0.13774915117650263, 0.13230689320593111, 0.18196229161995073, 0.10609357077027522, 4.354917878104795, 27.114548760075724, 45.45396312590569, 38.072709652685354, 43.44203825919859, 58.76487147423529, 50.57602159438595, 24.76995198957382, 6.914741964109483, 0.6450156951623579, 0.7772303973474811, 5.306202961552528, 9.71246515550921, 14.004743272258391, 12.782960264913498, 12.694162707174979, 9.456203964448745, 5.148260391527607, 6.552628259504996, 4.9636751221072295, 4.312026760270519, 8.980945079557358, 19.896534527501753, 34.982878238924094, 50.87956205491097, 58.981335316934896, 60.96219108950708, 61.511005201647365, 57.83377532036074, 56.499749768164854, 54.382191550347116, 57.568042585926676, 58.3017768398408, 59.91004666974468, 58.32635441134053, 58.80646428754253, 48.17249905678534, 51.026811753549886, 56.08000909128497, 58.763620238150324, 57.13806060052688, 49.98120200249457, 53.52932706955941, 53.285528229128936, 59.322008855881236, 59.2121668015757, 56.02810044442454, 47.02262486180952, 41.63202916422198, 43.499112667575965, 46.717625279580396, 45.26441066495834, 47.00015752546249, 56.74619228609147, 56.256123512021965, 60.998072931843424, 56.018710290232015, 48.28977792493759, 49.42107185240715, 47.08341375474007, 59.489760783410844, 58.805067923761186, 56.38895457790744, 55.83961094579389, 56.727819904204345, 54.131493260783536, 46.22168079499276, 41.932255221951394, 43.34612061900478, 44.89913209792107, 47.26721994338497, 46.22335564705634, 48.307095189248365, 43.42682730767035, 43.300868234326764, 39.86018865339218, 43.01045202439831, 48.86870407289075, 53.553700677810184, 54.198224544525154, 55.05608612491239, 51.052416986034764, 54.83120879819317, 50.62362740116735, 52.273980340650006, 46.52377782329437, 47.77236630839687, 49.645611855291556, 53.65119903318344, 52.10735413335985, 50.61342139397898, 50.447489446209325, 44.67171307533018, 31.912931280751383, 14.0433011516448, 3.9325210211738466, 8.043857995540865, 5.51363064396766, 5.928171728887866, 15.156713974091316, 9.180664323991346, 8.094166315370991, 7.569262481504872, 10.686321027817266, 8.957837416279702, 3.500396441067419, 0.38711780321694195, 0.7703169134836044, 6.109643616983968, 20.417899893176173, 32.903159126158684, 35.44285458903159, 29.142492586566558, 34.07894449849283, 30.067944449763147, 8.994715540639817, 0.8955975393614463, 0.21633003778274984, 0.12406410889760142, 0.09245077057951882, 0.087883492270785, 0.1946019609608958, 0.11998886587999522, 0.1353592173226418, 0.26881504323213334, 0.14421939188914915, 0.16535820920140515, 0.11454768043251769, 0.12234149891282282, 0.20000842730364493, 0.11656587012112142, 0.1567432134141845, 0.0835738493309867, 0.19469707843757447, 0.15176928031348413, 0.22377543181421297, 0.10584164275637559, 0.1152376575215209, 0.10188855245829591, 0.1427613120646246, 0.16976154469434293, 0.12625521995247374, 0.21738812778024905], [0.04847397209115086, 0.055732559412717826, 0.042164334050950505, 0.026405170004093842, 0.05656217900855888, 0.03443068794665798, 0.03894379234782631, 0.1200440931584566, 0.020408281613321557, 0.03211764250731757, 0.05824316360597169, 0.008197849421131035, 0.06381259217197377, 0.08392289431104738, 0.08525632396941224, 0.033253735577267025, 0.033844289775457115, 0.059284127707923615, 0.04001489434871943, 0.02940121730188689, 0.017502870177850127, 0.038513840822082375, 0.08560967436360736, 0.028567880264393268, 0.016840184971149412, 0.04492857463417515, 0.032755050642956654, 0.11361079320551888, 0.005641585908785102, 0.1382799581774781, 0.048541303558815876, 0.07604250789529855, 0.040689733540338856, 0.5222984607661925, 2.61098159897712, 21.16072423996464, 34.93745719232867, 22.585258483886722, 22.48689916826064, 34.57646577588974, 37.40525168757285, 19.561666096410445, 4.264636683848597, 0.2881880891659568, 0.15282332536674317, 1.4542104063495513, 1.6368105887405335, 3.808437331068901, 6.727912608654269, 2.2502272407854758, 4.433377538957904, 3.0975641214078475, 1.6178497287534899, 2.3138613229797733, 3.359707641986109, 9.396903610998585, 19.61432783834396, 32.79457223030829, 46.905930426812944, 55.607147755161414, 58.9133410299978, 55.286093911817, 55.71870780760243, 54.8091297764932, 56.46612721104776, 55.66191188750729, 56.302835018404075, 57.3690019115325, 54.015610756412634, 49.906763261364354, 47.94011431355631, 53.46333711378036, 54.85115405051939, 57.87741561089793, 50.60545506015901, 53.42055189994074, 52.30585352067025, 55.58995600669615, 53.72468071599161, 52.30251558365361, 42.94803927021642, 40.03101571913689, 39.81040200879497, 41.81046170573081, 40.41955786366617, 48.23056974718648, 50.938632949706054, 56.06605329821187, 52.74828903136715, 55.90912318998768, 39.96515520157353, 57.201944243523386, 51.276141135923325, 48.26001498007005, 55.80673363900954, 52.0197009271191, 55.81913617349441, 52.032530999952755, 53.06620497857371, 48.35028832958591, 39.28310209704984, 37.26496811835997, 38.70716479516799, 39.36300469983009, 41.328308274669034, 39.496482956794004, 41.04881978804066, 39.21208366270989, 39.52134686131632, 39.149368886024725, 41.23473621183827, 46.66937228172056, 50.17985828461186, 52.45724524221113, 49.9797389584203, 52.61911753685244, 47.90571904951527, 48.80478905093286, 44.94971106129308, 47.91333237001973, 47.68808634050431, 49.43642793163177, 47.72454477125599, 47.55439627555109, 42.15275518355831, 31.82190287497736, 12.59406872334019, 4.131953197140848, 3.425216126826502, 2.366969479668525, 2.840365974172469, 3.0100893830099418, 2.8756484293168594, 3.0215012738781595, 2.248607792200581, 4.766087685861896, 4.026341173918017, 1.3407541330783599, 0.16547402637379785, 0.39223275778274386, 3.063474557092113, 15.433929447204838, 25.53446312104502, 23.801226577451153, 21.44716905009362, 25.146170047021684, 26.8969964596533, 12.242614549975242, 1.1819930134281036, 0.06524678154457962, 0.009907513477599189, 0.0379076469389181, 0.02575742159669678, 0.03244101205059598, 0.04956035754613338, 0.1051484480980904, 0.02105837041932729, 0.021644889249376232, 0.026706566230484077, 0.02504566271278647, 0.041174785940036665, 0.014114209522132673, 0.03778792654855117, 0.05149737638871997, 0.10114507178866095, 0.03052774959454133, 0.0877160101287788, 0.015094087688222289, 0.052141016649623076, 0.08020357574306189, 0.0017580221596759774, 0.03425529211639397, 0.036762847279709195, 0.036568774225851225, 0.018750978708868066, 0.06609465701565628, 0.01752330557323031, 0.021855025251786557, 0.03728836444356749, 0.05703601588104522, 0.04356706402294579, 0.02219522957720103, 0.04488647810273594, 0.02664872850742071, 0.021849289168453506, 0.010019544260426155, 0.05562607319124284, 0.08401435754832723, 0.024056892181115768, 0.06919964967716126, 0.034849469910465905, 0.07136720352836194, 0.020327187376096845, 0.04754694441573755, 0.03460931283752284, 0.06348546113698714, 0.027789751353162914, 0.0636524376609633, 0.010088052630664842, 0.03350816486823944, 0.03739984938874841, 0.026820067902125662, 0.017775731544280728, 0.02474743042952351, 0.02562336004038732, 0.0438700862709553, 0.013138505577620481, 0.04697540835026772, 0.01120266746804719, 0.8229500343722682, 4.791347749771611, 28.713920693243708, 36.481564890953806, 25.276730060577396, 29.088824756683845, 44.5687351688262, 44.75731880434098, 19.139597492833293, 3.853346508356833, 0.2649641950284281, 0.0948695093393326, 1.0152940584286567, 2.1621256586044066, 4.306586432841517, 7.3187759999305975, 6.149061476030658, 5.319476752511917, 2.41933508265403, 2.837285932994658, 4.032673595413085, 4.014876085904337, 11.34326998264559, 22.38291125143728, 35.46064253776304, 50.260984666885875, 56.56904235962899, 60.88157069298529, 58.8377530344071, 55.95691334816718, 55.31826911434051, 56.85723850803991, 57.1307179235643, 58.03706392165154, 57.5350123067056, 56.03644724815123, 50.92944283639231, 48.84770370298817, 55.71343221972066, 58.20202312161846, 57.62665064104142, 50.52640753407633, 53.5357754461227, 51.93913544377973, 56.64361446134506, 55.87716764019382, 55.52344829805436, 44.208798869963616, 41.94568149505123, 42.47681748482489, 44.84904343082059, 43.17199483994515, 50.41378844168879, 53.29378089597149, 57.331021601153964, 54.72913303682881, 56.40375368056759, 41.51643691524383, 58.69980327544674, 52.91282069298529, 49.521029533878455, 57.01904804475846, 52.670175029385476, 56.68511313776816, 54.34090468191332, 55.28198719024659, 50.4089129355646, 39.48821460047076, 38.38305150308917, 40.60559980330929, 40.938173647849794, 42.57482182595038, 42.58274501369846, 42.406356027049405, 42.238541341597035, 42.08988351206626, 40.725734156946984, 43.89349522129182, 49.90763794991278, 50.10592552923387, 54.18120538034747, 51.03694323570498, 51.77624333289362, 50.36916363623835, 52.73323889701597, 44.74411218397079, 48.991603697499926, 48.40235387125323, 51.18051375112226, 48.57700917028612, 49.684192288306456, 44.804202895010675, 36.743732190901234, 14.549223165358267, 7.5002611260260315, 3.9141358915836584, 4.0289551884897294, 3.3116184030809714, 4.518464044217141, 3.9450476006154096, 3.312028535912114, 3.4795625267490267, 5.649614314879141, 4.161696530157521, 0.11987692511249935, 0.21195854090394514, 0.23642852301559142, 2.7624743215499388, 15.64820754912592, 27.6571871003797, 29.66334608293349, 25.96273103067952, 27.07409147293337, 30.555357779225996, 16.373667563161543, 2.1999012702895753, 0.046013290017482736, 0.06335291260432813, 0.041910253329983646, 0.06076766080373238, 0.03792243243585672, 0.06294439621870557, 0.04813171848053894, 0.0578275915505665, 0.04323905198684624, 0.04033435301314439, 0.04553239747521378, 0.011168725942561944, 0.0318077925006829, 0.03800459153529617, 0.04462868568577594, 0.1761518977582455, 0.07912269462981532, 0.009133377799674148, 0.061366661121287656, 0.051961671636109395, 0.03881859059836115, 0.03331367429646273, 0.03599911124535626, 0.04037301747068282, 0.020352167588087822, 0.048153559647260175, 0.031939128699201735, 0.13093781747644948, 0.12417313087010577, 0.10133853963305874, 0.15093125673311372, 0.15416825400485148, 0.13387147457368914, 0.16300501692439281, 0.16950423108233562, 0.14614228790085163, 0.15378116509847103, 0.1645426626407331, 0.13000676017855445, 0.10533934954794184, 0.14405422333267429, 0.14529358505481674, 0.1583232544362545, 0.11552397522234148, 0.271416524605405, 0.10181218881400363, 0.15458423974773577, 0.0909526396783129, 0.16498823469925314, 0.2692485264232082, 0.10717612961607595, 0.05340950886508631, 0.1571770183621876, 0.1082042119495811, 0.24568205308769983, 0.12445715030715351, 0.1295847683063438, 0.11136829297268584, 0.13539407432319658, 0.13369725085794926, 0.820604702157359, 6.510407866970186, 34.97984232441072, 47.98079321461339, 32.86006208389036, 32.40498673531317, 44.83808825092931, 46.48508364154447, 24.692840153171172, 5.7394017807898985, 0.5361676552603322, 0.8005197153937432, 4.845862811611545, 6.9946999703684165, 9.914336800575256, 16.579786154531664, 10.111262336854013, 10.46966891134939, 8.109891097391806, 3.5497366709093896, 4.1466390413622705, 4.025776597761339, 11.402088865157097, 23.871670384560865, 34.55404550798478, 50.76209099062028, 57.5516745351976, 63.338190355608546, 60.81440010378438, 59.525677927078746, 57.84818218600366, 59.85440392648021, 60.37179985354024, 59.02477164422313, 60.57416277547037, 58.99216105861049, 54.03113549755466, 52.256294373543035, 57.45683946917134, 60.55899497001403, 58.34811964342671, 50.76326770167197, 52.122047332025346, 54.49842314566336, 58.04993714055708, 58.597315665214296, 57.53842476875552, 46.535780276021654, 42.63889766508534, 45.41302534841722, 46.72728215494464, 45.341524462546076, 53.274282793844904, 57.80195705352291, 60.901319826802904, 57.10888993355536, 56.14827009939379, 45.4228469633287, 58.45087789720105, 51.6699549459642, 52.68639403004801, 58.4711173272902, 54.4868560760252, 58.96281388498122, 55.751322315585234, 57.65001227778774, 53.863442405577636, 41.885665309044626, 39.70807129336942, 42.360734939575195, 43.77035240973196, 46.27518192414315, 44.239801283805605, 44.67000684430523, 43.0371751323823, 44.11921585759809, 42.326680921739154, 47.686909629452614, 51.815086564710064, 53.46357637836088, 56.24135186595302, 50.08922407704015, 52.79689112017232, 52.443277682027514, 52.742005394351104, 47.32320393285444, 51.299745959620324, 50.64986413524997, 53.24970914471535, 49.530886450121486, 49.36495450235183, 46.61985235829508, 36.858347769706484, 15.472867796497962, 6.877340693627635, 5.431045139989545, 4.645747898086425, 6.117111319495786, 7.264039814472199, 8.380655742460682, 7.8811992656800065, 8.07295217629402, 11.0380958549438, 10.435320715750418, 3.4685063458258107, 0.5457778911917441, 0.9862052096474556, 4.101179261361399, 18.1436586764551, 32.89636754220532, 31.047672110219157, 30.66714140676683, 33.81921299042241, 36.681366505161414, 16.706539507835142, 2.239308587966427, 0.1566510223933766, 0.2490029982741802, 0.17331625395003827, 0.1819581700669181, 0.137025305340367, 0.22087179004184662, 0.1827378943562508, 0.09038174329625984, 0.1836374654404579, 0.11673119189518115, 0.060397019805086244, 0.187451143058077, 0.23598937077387688, 0.20114566950548082, 0.1082232722171372, 0.24598462717427363, 0.16826283156631455, 0.18891751195394224, 0.17003623318047295, 0.10126118773534414, 0.2763039510576956, 0.08648343594564546, 0.07779902493160579, 0.10334329980034983, 0.11905255321893962, 0.13168410968876657, 0.126617725097364], [0.03273500595241785, 0.044718980638971256, 0.04758001260098912, 0.030973336974819823, 0.10754545294349233, 0.04357931376885503, 0.08594370402035215, 0.028328558227287668, 0.033374179920722405, 0.043190451368929884, 0.029585032438438748, 0.06905774721094678, 0.02520594937396386, 0.08576574945642103, 0.0498498660031586, 0.042208211736813675, 0.09984089136724511, 0.07547119782576639, 0.01745537081132493, 0.013773259218601931, 0.10257709696288071, 0.10737950297733469, 0.028567608303180145, 0.038635292571158185, 0.021755000981952877, 0.04047632825771167, 0.04047163213873583, 0.07585089398367752, 0.026987973307710023, 0.06422110472715671, 0.05708414918532776, 0.01692187101129563, 0.07402411136295527, 0.01110815520082871, 0.44717655306862253, 9.875944641328628, 32.021233804764286, 31.945426156443936, 27.874294211787564, 30.146011383302753, 36.55117127203172, 35.94481206709339, 18.512459531907115, 4.453713557412548, 0.22700728097509956, 1.045031078880833, 1.177015157957231, 1.4918920037246521, 3.8439085502778334, 6.466338076899129, 3.4950193618574454, 2.944757159679167, 1.6790117371466853, 1.5251682890999703, 0.7816755459193261, 2.988807828195634, 6.9744164136148274, 16.843795007275, 31.016861892515617, 49.55421670790642, 57.4662531575849, 59.25712108612061, 56.39808193329842, 59.44207260685583, 56.35128021240235, 56.27415857007427, 54.702566823651715, 57.46468813188615, 54.62247202473303, 52.775302394743896, 50.532432294661, 55.3260628638729, 54.420646467516505, 55.389322850012014, 48.39184191919143, 48.945837482329345, 54.3863021942877, 53.56116887061827, 57.35396746666201, 49.176304186544115, 42.20564050059165, 40.4806762356912, 41.275532784000525, 42.07323305068478, 47.65598958538425, 52.198294285805, 53.31583246108025, 54.6795738897016, 53.766783437421246, 53.920920818082756, 42.58787939625402, 48.39556817085513, 57.19177353766657, 47.82146261584374, 53.424254617383404, 51.972377530990116, 53.05068808217203, 53.20792805763983, 55.3326799023536, 51.49826888115176, 39.547258038674634, 36.5342148657768, 39.43112842498287, 40.02508117306618, 41.65106050429806, 40.10013180394327, 41.63935615170387, 41.333097488649436, 41.20094891517393, 44.25271764878304, 45.42500426692348, 47.534639296993134, 48.85541900511711, 50.09511939940914, 51.468917785152314, 50.594374364422215, 52.784347380361254, 48.68830250155542, 50.13765750392791, 45.66554754011093, 49.39167761033582, 50.69130005375032, 47.69950043770575, 40.10643505281018, 27.833782011462798, 15.84711584352678, 5.620564260790426, 2.8725237711783382, 2.0935881233984426, 3.730411582416104, 3.65655874533038, 4.154078796986611, 2.8436357600073663, 2.121035889271767, 2.2497612141793777, 2.6952463676852565, 2.9194593429565434, 0.15040035780158736, 0.2997901537004979, 1.3965660285565162, 12.667195431647762, 22.56614281285194, 32.86891291218419, 22.74302797932779, 21.783169084979644, 27.119500752418276, 19.83091719688908, 3.873759258177973, 0.11195104073492751, 0.030464576069085352, 0.008468148223454914, 0.05545391025201929, 0.03979158354923129, 0.008567086563655927, 0.06781051010494271, 0.05095419706776739, 0.08047002878400587, 0.05586735641343459, 0.06003685505880464, 0.11556958809735314, 0.04513828737300731, 0.11376887544869416, 0.05652017057723096, 0.09599982610633297, 0.04004663337142237, 0.03611071110372582, 0.066284999221323, 0.11463840056451098, 0.03875774789541479, 0.010607606757642522, 0.059721471982136856, 0.029665755123020183, 0.048804021921129, 0.036911575589329004, 0.0399312183951899, 0.0023685382151480525, 0.02305783117340217, 0.011777615497609781, 0.022335054029920892, 0.05663701047700259, 0.05660324515173993, 0.07194347784764345, 0.08039167331111047, 0.03515204399703972, 0.02160077024581692, 0.0661121468029676, 0.030260116778193947, 0.05698568773485961, 0.05592544503029316, 0.04301746105474811, 0.058458955252483014, 0.026297157352429726, 0.04501201310044816, 0.06808319910159034, 0.004895871135240962, 0.007615454538139485, 0.16820185096754184, 0.03255271533083531, 0.015166431286131904, 0.02409180855348466, 0.06484447047114372, 0.05866224434407008, 0.02492379153057212, 0.011615420319891025, 0.030275603245583274, 0.0637367303152719, 0.019979619030510227, 0.08969666916997203, 0.06655254776799871, 0.014296312452173762, 0.9235907598368583, 14.180786109739735, 38.911257482344105, 32.190164404530684, 25.675338968153923, 30.356423008826475, 46.02365601447321, 40.86625699074038, 16.48147979090291, 3.4789898607038685, 0.14983824844802582, 0.4238905138786762, 0.8374241931784538, 2.8918223227224047, 5.019560071729845, 5.448006449207183, 3.74429579223356, 4.17109158731276, 5.3222430040759425, 3.7860741826795765, 2.7501188555071434, 5.262791149077877, 10.267234406163617, 20.040469823345063, 34.765178849620206, 53.089597994281405, 58.316717147827156, 61.39455787597164, 58.39598040426932, 61.541831108831595, 58.57569556082449, 58.09476983162665, 56.44695074327531, 61.857958455239576, 57.27951695842128, 54.449013048602694, 52.38872535767094, 58.40171490946124, 57.076059695213075, 56.7005515867664, 47.88919018160912, 49.43777722697104, 53.19464691223637, 55.27030637187343, 57.59482060709308, 52.332741368201475, 44.61148900370444, 42.25798453054121, 44.038077708213564, 44.07621491339899, 48.12300658995106, 54.14284460006222, 55.47555223588021, 56.31398239443379, 55.09740829467774, 53.74735986032794, 45.821889292809274, 49.959860386387, 56.72838080313898, 51.49871210898123, 54.10805709900395, 52.64164370875205, 53.97253136481009, 55.163241355649895, 56.21073384438792, 52.53083282901395, 40.40204840321695, 39.89963200784499, 40.1071410794412, 40.63946946974724, 42.90042954106485, 43.495100082889685, 44.361641868468254, 43.76160944661787, 43.3585427653405, 44.89830840018488, 46.31776709710398, 50.38535910267984, 50.89354530457528, 50.38925009389078, 51.31143462273383, 52.51493546270555, 55.524052343060895, 50.65248035615491, 50.96013930536086, 48.26389812654065, 50.908520913893184, 52.29851868844802, 48.72642793963033, 43.26741041675691, 34.301205604307114, 20.581076375899777, 7.67991352465845, 4.164431893056439, 3.234800744441248, 3.6510764975701613, 5.827384466125119, 4.17656623548077, 3.6724203200109544, 3.8307389472761466, 5.494404165975509, 4.810899294191792, 0.808396692718229, 0.18440841036217828, 0.36514137601179464, 1.5974896857815406, 10.91613857976852, 26.863352329500263, 34.65020241275911, 21.36975911355788, 24.2784397832809, 30.533372894410167, 24.55780275406376, 6.363557269496303, 0.2725746963293322, 0.003541451625360717, 0.02116103960771955, 0.02957610942934069, 0.012247868993830298, 0.01717130923944135, 0.026981779486842217, 0.019752904885418473, 0.05955562926828862, 0.03212478053155205, 0.05152566035488441, 0.06729095693557494, 0.11232027979267221, 0.0865951392258848, 0.040761477674447724, 0.03138600938743161, 0.049942179598034396, 0.014699861715217272, 0.05957559351959537, 0.05331850911100065, 0.022890387335792187, 0.0571604706947842, 0.11197474349530474, 0.023227157672086073, 0.04388716237078752, 0.04389116134975226, 0.002883388083465698, 0.048566783643177444, 0.08578421983627543, 0.07849971959066969, 0.08948984075217478, 0.09221260150473926, 0.20399085876922454, 0.19302144496431275, 0.23245764415590997, 0.13310932434133946, 0.07662843492242598, 0.13214904845001238, 0.13539909985997986, 0.1658984850491247, 0.12297805669086596, 0.1370148405793213, 0.11926444547791636, 0.10691023581931669, 0.14656113881257274, 0.13481310388493922, 0.22438955853783318, 0.15624619089066982, 0.20699620637441837, 0.1757363103810818, 0.12753856278234912, 0.13250028444153647, 0.12685864442779174, 0.18398323156420263, 0.12207511481979202, 0.13773278753844, 0.11159219749031529, 0.1471018283477714, 0.10911154350446117, 0.2369802901821752, 0.1511295202879175, 0.15910140058446318, 1.166872521561961, 16.644507223559966, 45.028856646630075, 42.5459296472611, 38.00799054484214, 40.38919479616227, 44.902685765297186, 44.73560848543721, 21.779562465606197, 6.160161293322041, 0.47754078502616576, 2.0613371701009813, 5.003219477591976, 7.007383444616872, 14.547628721883221, 14.663704402985113, 7.2077033019834955, 9.062568622250712, 6.88399842669887, 3.98886856532866, 2.018389423047343, 4.715048824587177, 9.675039860510058, 20.42494054763548, 34.13688967304845, 53.66229541840092, 60.904422421609205, 63.725222387621486, 59.639175630384884, 63.558690317215465, 61.32745004469349, 59.453855406853464, 58.693374510734316, 62.800547153719016, 59.85773009638633, 57.916439271742306, 55.69068247272123, 59.6292834128103, 58.61089883312103, 57.492901740535615, 48.301168487918, 49.63559412187146, 54.98989612825456, 58.31779579962454, 60.489133634874904, 54.638098747499534, 47.04609632492066, 43.998210737782145, 45.349208385713645, 46.478286174035844, 51.23197524778305, 56.21336183240337, 58.42923425859021, 58.15482916370515, 57.555828325210086, 52.87607985158121, 48.53468287375666, 51.133763021038426, 54.612838683589814, 51.0189042552825, 55.50945720364971, 53.9777716513603, 56.443287249534364, 58.06531283163256, 58.87414870723602, 55.11939710186374, 42.12629879674604, 41.317094218346384, 41.87562011903332, 43.10785232051727, 45.190415151657604, 45.199613109711684, 46.23094935570994, 46.11913042683756, 44.12134570460166, 47.66759195635396, 48.497840050728094, 52.88724291709162, 53.57608172201342, 52.64635055295883, 52.19288925970755, 51.738902368853175, 56.592596192513746, 51.636108813747285, 53.226590694919715, 49.90573560037921, 53.30864275655439, 52.5029565441993, 48.27104468499461, 46.415955789627574, 35.087480006679414, 20.686462617689564, 6.402738315443839, 5.326645374298097, 4.61934152149385, 9.450040940315494, 10.043645578046, 9.253155608331005, 7.8540711729757255, 8.311346480923316, 8.508150423726729, 8.820476012845194, 5.219382278380856, 0.5019344341370368, 0.6928865070785246, 2.2125641520946258, 15.513847739465776, 27.904374868639056, 39.39525834975704, 30.295463492793424, 29.98239951749002, 37.64407304025466, 29.497067005403583, 6.146807584070391, 0.3264645997795367, 0.15783885704173198, 0.08473939848162475, 0.16882510945921944, 0.14060097476167066, 0.12255368228521078, 0.14070822707106992, 0.08652051460118064, 0.23540525937513, 0.1156073255885032, 0.19402088327032907, 0.18965110242847474, 0.2433036105527032, 0.30641629330573544, 0.1216365218222622, 0.1810007746661863, 0.17584420620433747, 0.10228455862811497, 0.16759932281509524, 0.15176330482767475, 0.11276349996126468, 0.15661785078625526, 0.30106887702018986, 0.11763364346998355, 0.10483825143666999, 0.10789489628927362, 0.13945607168059196, 0.10524882859880887], [0.053580974664298765, 0.010580811874880906, 0.06180095636556226, 0.04515060989726936, 0.025709399375163262, 0.07848263582995824, 0.07120985672959397, 0.01395714617589669, 0.055698989439875855, 0.04931326354703596, 0.09524237965383837, 0.058206253489779855, 0.07535467585248333, 0.0513772193282362, 0.036091187352975534, 0.043682321951153784, 0.030926084671650204, 0.03228075028727612, 0.08690908971813419, 0.06041207343279835, 0.05203905417734096, 0.03682176710196561, 0.008569187559788267, 0.07276151419406937, 0.047802293012219096, 0.019301815078623833, 0.010629556134283062, 0.016534609735132228, 0.05937608507191462, 0.060108373196975845, 0.01993393720758538, 0.05450426000020197, 0.07976489847586041, 0.020857406404590415, 0.03257849418948735, 1.6751368031386407, 11.331192024292486, 33.82375901745212, 32.12999720727244, 18.326894160239927, 29.53538267843185, 35.99962326788133, 34.81712672018236, 19.609609227026663, 4.178519575826583, 0.34211387617453454, 0.5246063466033628, 2.8730069581539404, 4.997141274713702, 2.374623004467257, 2.733937852805661, 0.8830323490884997, 3.736900653569929, 5.605590612657609, 2.5093083708517017, 1.249774266635218, 1.6421846035988101, 6.136637368509847, 15.304215685013803, 31.474016097284135, 45.57103018606863, 54.33928866540232, 55.10944604873658, 55.61241549830283, 56.319501169266246, 56.61292583711686, 56.964205465009144, 54.72439481366066, 55.469762817505874, 54.92528684677617, 54.57250102873772, 56.77781051205051, 55.478654830686516, 55.49540727369247, 52.77241945266724, 55.560581376475675, 53.50451807821951, 54.82982812389251, 53.68661019109911, 46.57554918719877, 40.797140905934, 41.9202253126329, 41.86829313155144, 47.505578456386445, 49.11113792850126, 53.49570059007215, 53.37731169116113, 57.0548749739124, 53.290576319540705, 55.29839054230721, 41.53926118727654, 50.00675624416721, 58.84347969485868, 52.111441243079405, 53.26125268013247, 54.946416654894435, 54.33445238297986, 50.86568863161149, 51.664436171131754, 49.211087765232215, 41.504199120306204, 38.98039710137152, 38.68772160622382, 39.17701767336938, 37.99490159557712, 40.3454093779287, 42.224350206313595, 42.65544222247216, 44.68905779623216, 44.898139738267474, 46.91715232787594, 49.287962298239435, 53.84757641823062, 52.35013315754553, 52.83486358581051, 51.01578989336568, 49.12238728615546, 49.59036919378465, 52.41356572797222, 51.21017079199515, 51.229429629541215, 44.086515057471495, 39.388245151888945, 29.23775911331177, 19.46330678078436, 9.09771207840212, 2.0736899395142836, 1.1597957077526277, 3.1954010263566053, 3.1496816344799536, 3.7816524457546974, 3.8062868916219283, 1.7905317078674994, 1.7884450069358273, 3.471567510597168, 3.527327189522405, 0.9652552789738102, 0.21531150856566048, 1.7044636294726403, 8.376604914665222, 24.909962954059726, 29.009030019083333, 34.31636948739329, 37.32505490702968, 20.4060798306619, 30.641418503176784, 8.401589432070333, 1.0138624546027954, 0.09004946798086168, 0.026941466025046767, 0.0807030191044173, 0.09762227775589113, 0.03841675066899869, 0.08805690393332513, 0.05385358705215397, 0.027906033923969637, 0.01484136964615074, 0.10575041700635227, 0.07644392264586303, 0.03800941788921914, 0.018638865571589242, 0.04236731670736786, 0.019931646604691784, 0.05721377509255564, 0.11539005539229802, 0.04957770560717872, 0.048618241769051364, 0.043127501924191756, 0.029696599738071525, 0.04879805026575924, 0.0366847446158288, 0.03072788431910017, 0.012946516282916551, 0.04158799461419544, 0.026038125788252202, 0.019445879828004588, 0.05847202854291086, 0.053704475698572014, 0.027157110199632666, 0.041660186909740014, 0.03275382873271743, 0.03799627948131773, 0.031305962775443355, 0.029778822039764737, 0.06185540989522011, 0.05483736652099798, 0.017581547407673735, 0.027307774796481096, 0.02488153412066881, 0.05538352975441564, 0.03383750223644799, 0.04075857037077508, 0.039229485686988606, 0.03748495792669635, 0.03839290618235546, 0.0599192988668238, 0.04747669798352065, 0.04702441882522357, 0.009522839663400045, 0.04083984846910162, 0.049841603744895234, 0.05349805330737464, 0.021284848992382328, 0.023519312962889675, 0.010424291493461258, 0.03248499698876854, 0.015762535791333406, 0.04919667262583972, 0.07336722927228098, 0.08242930631123244, 0.010265678734398417, 2.7325213868771834, 17.18381743277273, 40.19671624706638, 34.605491315164876, 21.810937504614554, 29.047971310154086, 45.00730714490337, 39.63022401255947, 18.03033551862163, 4.1891251744762545, 0.29883285023031697, 0.33826854380388416, 0.5039928817460614, 2.9378604071755565, 4.852866693850487, 4.448075640586115, 4.20615904754208, 4.064791433272823, 7.089527191654329, 5.117308968497861, 3.0267033173191935, 2.5823264785351294, 7.524647481979863, 17.97885441010998, 33.059167477392386, 48.59998249238538, 56.01902015747563, 57.33177469622705, 57.46400563947616, 56.25579795529766, 58.980868554884395, 58.39795335646599, 58.173880115632095, 57.4812013103116, 56.35473582052416, 57.12361843355241, 58.85717268913024, 57.07581258589222, 55.72592104634931, 51.795470791478316, 55.13183493768015, 55.498054873558786, 55.54877111988684, 55.31737481394122, 50.496032699461914, 41.46760732896867, 42.500022226764315, 44.77021163509738, 47.48012619633829, 51.45862940819033, 55.74781571665118, 54.98080015182496, 57.75207627204157, 55.05425437804192, 54.49464590318742, 43.68972416846983, 50.0298237031506, 57.56135886715305, 53.422791573309134, 53.54895460990168, 57.208647574147875, 55.47380678115353, 54.698554238965436, 54.41380585393598, 51.3541139325788, 42.52274451717254, 40.14628633376091, 40.51214541158369, 40.11351493097121, 39.21539022076515, 42.89959799858832, 44.14405622789937, 44.42096771732454, 45.53177118301392, 46.35912456820088, 48.51205079786239, 51.407316961596095, 54.30206929483722, 52.9105104169538, 52.643381318738385, 49.96982712899485, 50.51202028028427, 50.905688962628766, 52.634963912348596, 51.47034945026521, 52.710053766927416, 47.60875640376922, 42.818502995275686, 33.3939496163399, 22.978219178415117, 10.47998768668021, 3.7207605906071204, 2.4411495895155015, 3.906733398475955, 6.014208918617618, 3.686210392944275, 4.741111013197131, 3.9005085970124895, 4.639957989415815, 3.49835999550358, 3.3060562370284914, 0.5223525772171637, 0.03908651452811976, 1.221964049243158, 7.886999470572318, 28.043183626667147, 33.20887650212934, 36.01032349371141, 38.28262313719719, 22.376635459161577, 34.01179352114278, 12.971468394802464, 1.390964883950449, 0.03577160611448269, 0.05480850415845072, 0.03872422388784828, 0.03572694701893676, 0.026601349799743584, 0.05993228022670073, 0.05153658476868465, 0.009457003982407192, 0.01979602031379698, 0.061839402488042275, 0.06546845674634942, 0.03356012861214338, 0.0071849361073315875, 0.03736739024339664, 0.03493041093010576, 0.020923312948716265, 0.05545393706509664, 0.07166560243574843, 0.017094572127285986, 0.04855781658402374, 0.0360498377572625, 0.021908475206263607, 0.04533589209219621, 0.057777872444280697, 0.03192041700165118, 0.008138774466069957, 0.06545758595870388, 0.01230665858113958, 0.15422014880084223, 0.09881152200602716, 0.1892843608173632, 0.12264095502154482, 0.16379872997922285, 0.15238372879403253, 0.15022090936620391, 0.1678459418396796, 0.19275303839916186, 0.19909978573841436, 0.2392834722394905, 0.05950776026433995, 0.11858965991245163, 0.09264384771907523, 0.14880828919910616, 0.1647877954547444, 0.08445046076010312, 0.15841241174888226, 0.10952890820560918, 0.11078563714099508, 0.187154621066105, 0.13975349765631462, 0.08095430360446054, 0.13687311431332944, 0.11291484829158553, 0.13352786881789086, 0.14985537817401273, 0.1307474599490243, 0.168463040984446, 0.11330406692239547, 0.10241823331002267, 0.21014637524081817, 0.1636724940110599, 0.12411843219231214, 0.19716613385225498, 2.6548395810588716, 20.998340076015843, 47.459063068512954, 42.996645281391764, 28.44980593650572, 37.114235355008034, 44.85805703747658, 44.41415456033523, 22.66030127002347, 5.565040659519934, 0.5568555838638737, 1.3020684089391463, 6.704257774737574, 8.598619891751198, 7.085317507866891, 9.503058637342146, 6.347069586476972, 8.174828877372127, 11.075051446114818, 4.825642503076985, 2.9569596532852422, 2.466373126352987, 7.743225972498617, 18.27508749500398, 33.29157183247228, 46.52389157202936, 55.905463618616906, 57.539146484867224, 57.93426252180531, 57.97740859370078, 58.621599058951105, 59.969352906750096, 60.12191349460233, 58.310053040904386, 59.476954244798236, 60.97843362439064, 61.5950615944401, 60.278459210549634, 54.672113541633856, 53.357644927117136, 56.27899485249674, 56.88591495636971, 57.462825006054295, 56.68107309649068, 52.30563779031077, 44.34548170335832, 45.37173455761325, 47.64834880828858, 50.6090557959772, 54.222417723747995, 56.917478269146336, 56.406722914788034, 58.375234988427934, 56.53601992514826, 55.12527673475204, 45.997423202760764, 52.528687292529696, 57.1943897585715, 51.97219710196219, 54.44859335499426, 59.402044819247344, 57.29444942166729, 55.53747077142039, 56.34336879176479, 53.365595571456424, 44.81467954574093, 41.94286523326751, 41.83155229014736, 42.28315045756679, 41.75726259908369, 45.15183079627253, 47.05351352691651, 46.25708018579791, 47.97351721794375, 48.19715507568852, 50.52736851476854, 53.76249236445273, 57.198288594522786, 54.054865837097175, 53.24777149385022, 50.736407310731956, 50.23485775916807, 51.62413773998138, 53.98220785202519, 52.9246074153531, 52.231920765292266, 49.39105003110824, 47.73009100267964, 36.89568481137676, 24.31447655923905, 10.470703436482339, 3.415252571144412, 2.490267469998329, 6.103544331366017, 7.98887764253924, 9.37428722458501, 8.211979606459218, 6.42817831808521, 7.554569773135647, 6.635956562334492, 7.589062606134723, 2.4570989272286816, 0.4987812162406983, 2.7994681558301373, 10.59019354081923, 30.938624335873513, 36.72930179103729, 38.91315983187768, 43.57934474945069, 30.746991057549756, 40.331245699236476, 14.063781807499549, 1.54280461370945, 0.16718655464149293, 0.0927722210725469, 0.1429611537605524, 0.17835676009135862, 0.12202577875746835, 0.22041437426401725, 0.23180697503830158, 0.08585540472619957, 0.11339104854531827, 0.1820771128780419, 0.14871899399065203, 0.12402886119220527, 0.1563140509590026, 0.11132610451069572, 0.055090501123378356, 0.0956974741852572, 0.18389739907316624, 0.1688241135449179, 0.05519712907111934, 0.10877557564526798, 0.10420818242334551, 0.11055175049771225, 0.1294231390760791, 0.21231854094132302, 0.08815269556737716, 0.13027109115594818, 0.11858147043254107, 0.11177495542553165], [0.02149591196118103, 0.04167611004724618, 0.011641489334344383, 0.07763630785648862, 0.03455236186123183, 0.02372374352548392, 0.07123787256498491, 0.08808421496782573, 0.029085317115870216, 0.039956135404927116, 0.07660592725921063, 0.027150165612599062, 0.01685015752070373, 0.04840600860094832, 0.05358883472640188, 0.06955896023540728, 0.05704501741415551, 0.018093146669167667, 0.052187150464423245, 0.04963294437695896, 0.07983221462176693, 0.029063864738770553, 0.03399921956682398, 0.015204871662952488, 0.04066870059637774, 0.08272392074427298, 0.03151286780203302, 0.020286431498525125, 0.01646283495750639, 0.049059328382774714, 0.0721497546821352, 0.031997393516282883, 0.04435108223509404, 0.052354992667753855, 0.061835242630613435, 0.019289772176454147, 2.0146940600487495, 16.495529720860144, 34.71935772126721, 21.059309397974324, 20.02174638932751, 23.59620624972928, 26.334656053973784, 42.15191579634144, 16.719373503038963, 4.094420036961956, 0.5143773567772681, 0.25801430666638964, 1.888853025532538, 4.757633016955468, 3.448605710460294, 2.9140861861167418, 5.125888662953531, 4.406177372701706, 5.85132122039795, 3.3509082948007896, 0.7213001566067819, 0.40784881660534494, 3.6226684864490264, 14.362692890628693, 27.28145149446303, 42.3814058303833, 50.302636315745694, 54.25668747194352, 59.15490019705988, 57.111914080958215, 56.84983307315458, 54.58596652553928, 54.85426449006604, 56.04183266239782, 54.72175898090486, 57.61071797340148, 56.52916754445722, 53.32527752845518, 54.04192986026887, 58.34577406606367, 54.86010489925262, 56.51458809452673, 50.07722162431287, 42.13655187237648, 41.786135165922104, 45.331008588114095, 45.29140049411405, 49.79268112490254, 51.554115587665194, 56.13078809553578, 54.56772750423801, 57.17553492515319, 53.295887208754024, 55.799367427825935, 44.11423052510908, 46.646779429528024, 58.90116599298293, 58.065038265720496, 54.682809845093765, 52.26876358832083, 51.514860506980654, 50.579218326076386, 50.02145728757305, 44.498952281090524, 40.180924784752634, 39.548697548527876, 39.28316093260242, 37.79300935806767, 40.11371889422017, 43.614104793917754, 44.185601972764545, 45.98336150569301, 47.2016300693635, 49.53874295757663, 50.82245234520205, 51.89973915776899, 55.17900536137243, 52.766496673707046, 54.861928801382746, 51.52024592122724, 55.30864361793765, 50.616908381062174, 47.54094646823022, 44.21367437608781, 39.403867952285275, 36.48578928362939, 35.339833536455714, 22.331347773152014, 13.58260798838831, 3.186955918227473, 1.7384141947953933, 2.5142402610471173, 3.1158058393386106, 4.729159551282083, 2.9283028168063012, 2.2834038734436035, 2.687597255552969, 2.8349847274441875, 4.830769040892202, 2.2357357990357185, 0.1823993907460282, 1.3371953175913904, 7.55280960952082, 19.655304839534146, 23.634600370160996, 20.5121720990827, 29.544498266712313, 47.46070261924498, 30.169700537958455, 21.125444481449744, 1.7524924393623107, 0.13245968178154963, 0.1498000359823627, 0.011157438594607577, 0.06058597539161002, 0.02773986179231396, 0.031852415207052426, 0.0908794936033026, 0.09921883563360862, 0.03900495680770086, 0.012336818505108598, 0.11340926611615766, 0.05488200646434581, 0.0256488956661234, 0.03235029957948193, 0.08012675244601504, 0.0348224614806954, 0.05695215223597423, 0.054392568211281495, 0.03737831848763651, 0.02949588470191004, 0.0501143348763787, 0.05094508828234769, 0.09020836993811593, 0.05353002981733411, 0.030489058323925546, 0.05061820239549683, 0.020292615743293878, 0.04288384382943473, 0.05025592324654422, 0.020152888966784365, 0.08349647445063438, 0.029865974117250695, 0.04045787319961575, 0.036684373063185526, 0.033353503207646074, 0.05208220791011568, 0.05653782124300638, 0.026255790519738392, 0.02198754122570878, 0.012613766950615233, 0.061539858279208985, 0.040306153316651626, 0.13706527980825595, 0.054050406531220486, 0.04952013409966904, 0.02345826533142357, 0.019207982714438153, 0.01810359036279542, 0.0208285172289658, 0.055535280280896736, 0.07523787042666828, 0.051756946129664305, 0.07171401919256296, 0.031618710509651614, 0.01332024174306782, 0.03291329376459603, 0.02818109587796273, 0.053224046639497244, 0.0706003495161572, 0.004840445152724222, 0.08381570328868206, 0.06350185158812711, 0.03754352917894721, 0.03519085401128377, 0.026081833019552213, 3.75701260662848, 22.83717663057389, 39.54391617928782, 20.239987065715177, 18.596082502795806, 30.553726073234316, 40.362408930255526, 37.6996491032262, 16.861908512730754, 3.8094046856126482, 0.40151449521222426, 0.1582257314434936, 1.2349772477342238, 3.204869627952576, 3.7330792844295506, 6.130674385255383, 7.25508749485016, 9.730841459766511, 9.84531387206047, 6.482291336982481, 1.8707235854479576, 1.5952600634867147, 5.190015002604454, 18.18203318503595, 31.056775931389105, 44.87932412855087, 51.773776162055235, 56.47427789626583, 60.29444286900183, 58.978836767135135, 58.80982575878021, 56.739371284361816, 55.46833115239298, 58.567721382264175, 56.57716951062603, 60.8581070746145, 56.58373948066466, 53.456998563581905, 54.75698578742243, 60.37208226419265, 56.901698573943115, 57.719140129704634, 52.79172928102555, 45.39961476479807, 43.10743262690883, 45.796982242215066, 45.61873405210434, 51.98414464150706, 51.59792846248996, 57.38654667331327, 57.353747813932365, 57.54956430004489, 55.95738403258785, 55.163684583479366, 45.18140546737179, 47.20193209186677, 57.83389299146591, 60.341978073120124, 56.209949370353456, 54.761378842015425, 53.876782386533684, 52.513856810908166, 51.827579313708895, 47.41169652631206, 42.11681450566938, 39.90731985338273, 40.6668201569588, 39.81609729028518, 41.22498912196006, 43.900924190398186, 45.865553117567494, 48.500887732351984, 49.64939694250784, 50.26555422813662, 51.73917693476523, 52.21932995703913, 57.57249839844243, 53.554681270353264, 54.637561382785925, 51.44507761924498, 53.648210187112134, 52.101474500471554, 50.81063816624304, 47.840890115307225, 43.66246369577224, 42.341782046902566, 38.702685448431204, 27.216597064848873, 17.183438924051103, 6.18771594378256, 2.768707948346292, 2.6148546943741464, 4.316885596321476, 5.243988777360609, 4.180107155153829, 4.076000096336488, 5.46298647119153, 3.5810616996980484, 3.0264848903302224, 1.4678717765115923, 0.24246704253938892, 1.083418212590679, 8.416387554137938, 22.024689028340003, 31.76763688364337, 24.534346980433313, 34.59614038467407, 50.83212098767681, 33.23110849626603, 27.120663735174364, 3.150821573311283, 0.08837419456892437, 0.08881343108031059, 0.04437607968406332, 0.0443817678869011, 0.07103357989821704, 0.02657762980238805, 0.020343920651582942, 0.060864344930216197, 0.021763349425107725, 0.06223072019976474, 0.014245675955598634, 0.047995921735080986, 0.051765334792435176, 0.02384254461034171, 0.005486143317313926, 0.039818086360971776, 0.009531725325711794, 0.02143259479423925, 0.018419574818483764, 0.07150986442162145, 0.05684218797532301, 0.06533015489337907, 0.07784786303677867, 0.012715120382997538, 0.03330530861632959, 0.044599842475426775, 0.029485132657892765, 0.0718242745666254, 0.037902494997627316, 0.21476492015344484, 0.08553151041269304, 0.17878702571315153, 0.12912549859573766, 0.20781158439574704, 0.1339919495606615, 0.11611800745970781, 0.16985108505093283, 0.1677381073034579, 0.15032200232869194, 0.14898858033120632, 0.11011211562060541, 0.12001904974421186, 0.22516963522761102, 0.1373845086463036, 0.10653253149000869, 0.1271420433336208, 0.11993920806074336, 0.15476822342363097, 0.1515300923417653, 0.1606016305665816, 0.17351129993556008, 0.1767432410269976, 0.13097897171974182, 0.1348182673175489, 0.1682420092965326, 0.203988254070282, 0.13607895692750333, 0.20384905589444025, 0.1137228335644449, 0.11516212891306608, 0.2100389084268001, 0.1575600929678448, 0.14543166474228905, 0.15860332085961298, 0.08795054028591803, 4.340875792887903, 27.77679389522922, 47.191247555517386, 29.73708271980286, 30.559166400663315, 34.06690674443399, 37.89014293301491, 48.491874125696, 20.320228953515333, 5.153404089712328, 1.1368803631874824, 0.7315887174298688, 5.754114591306256, 12.623014834619338, 8.526534572724374, 10.069361617488246, 10.175572537606763, 9.888925725413907, 11.984734400626152, 6.764748567535031, 2.1414618770922385, 0.8391244793611189, 4.360155222877379, 18.87152506459144, 32.50312443702452, 46.142029223903535, 52.48953419346964, 56.77747711058586, 61.28263304310461, 60.361464408136186, 60.23090831695065, 58.600061324334916, 58.05623646705382, 61.881222032731586, 58.57536215935984, 63.02172176299557, 57.87724694898052, 54.06817836146201, 54.77356172377064, 61.79680085951283, 60.018610031374045, 61.42937675599129, 55.16378264273367, 45.623691928002145, 45.565091717627745, 48.49146227682791, 47.915728938195016, 55.28131646494712, 55.347388790499785, 59.93661288292178, 59.43812278009231, 58.37140283276958, 57.233444798377256, 55.603774516813225, 48.82495395598873, 49.24414157867432, 57.40025927943569, 60.99820629242928, 57.72403132530951, 56.85048810897335, 54.572971713158395, 52.49157774832941, 53.60059653559039, 49.0799903869629, 44.07326529102941, 41.999872961351954, 43.05455907698601, 42.86466536983367, 43.11026065580307, 48.01644755947975, 49.093938335295654, 49.70085451679845, 51.08410973702708, 53.60206742440501, 54.470052642206994, 56.31981495888003, 59.899483726870635, 53.376970444956136, 55.7512987813642, 51.63235510549238, 55.350385481311434, 51.34009930395311, 52.96789469257478, 50.514397236608694, 48.48357831278155, 44.968079520810036, 40.34751569071124, 25.438376818933797, 16.60883915039801, 4.493015216242883, 2.601499514233682, 5.2621238558523125, 7.445092989552406, 9.374610820124227, 7.287020000719256, 6.758697330951692, 9.102934714286558, 9.18276475321862, 10.192090618994929, 4.43469496503953, 0.5458597093820572, 2.3789584492483447, 10.440074628399266, 23.629262024356475, 32.524928892812426, 30.14383446785712, 37.88190595565304, 55.952300640844534, 39.95716533353252, 29.929327887873498, 3.46101388335228, 0.22573430331483965, 0.19174511183894452, 0.09689319953923264, 0.13855608690890575, 0.11983361816213978, 0.17940677552213594, 0.13850327280740585, 0.18843049453871866, 0.13293609653990116, 0.1905630841370552, 0.15431871367318017, 0.16411567587525616, 0.16542472095499117, 0.14121879402908588, 0.16090057339639435, 0.14595533180381023, 0.14942558752673288, 0.2341702949976729, 0.19910392261320548, 0.10531262074026371, 0.1902709135244931, 0.14652954534657542, 0.18355603029410686, 0.27686926265878065, 0.144592737178168, 0.11167036910210887, 0.09582513507695929, 0.16278128860698593, 0.16817416454995834], [0.02498612235931139, 0.05828968812561324, 0.041645435886757995, 0.11192135482786164, 0.049900416314842246, 0.021638687767629183, 0.03930245556177632, 0.03727940121485341, 0.055260174276848, 0.028845765252387332, 0.03733212338580239, 0.03459529725894813, 0.044647830223003705, 0.09618983889419226, 0.10369349391229692, 0.04564129687365025, 0.03953246963060191, 0.008355086094759887, 0.017578381549326644, 0.08936251693915936, 0.024977965438137614, 0.0773721607401967, 0.02646184518873211, 0.02462685776634082, 0.02586549170495522, 0.111287999297342, 0.012223623268636725, 0.006581310055128509, 0.013030958324370366, 0.023961046920909036, 0.04885249613453785, 0.020731944185231003, 0.09372606948618928, 0.02678073120243367, 0.07582188989486426, 0.04353607193596902, 0.01566441333477175, 3.976685928721582, 19.418056357291437, 38.814449464121175, 23.40994857972668, 19.091144454094675, 18.05860992400877, 37.8458397619186, 45.0357953194649, 15.97101959490007, 3.947573607006381, 0.30492855055678275, 0.45377643117981575, 2.8489888147000344, 2.82111105899657, 2.845176025744408, 4.4781352146979305, 8.34646051929843, 9.92611175583255, 5.4797129284951, 1.0362553884906154, 1.1244517204261597, 0.6907134527160276, 3.476717337485283, 11.948800586885023, 24.393949662485433, 39.430575370788574, 50.73985507411342, 56.993733067666334, 60.35185067884384, 55.60028752973003, 54.29804886541059, 56.01817292551841, 54.45657930066509, 57.24017558559295, 56.581350757229714, 55.15941312236171, 57.93420760862289, 57.81714839320029, 56.641280651092536, 54.748121230833, 54.08814714800928, 45.44260001951649, 41.99418160223192, 43.737922253147254, 46.548473065899266, 49.71314330254832, 51.22034542022213, 53.825595455784956, 53.442556396607436, 53.134952360583895, 55.45895276531097, 55.29820619090911, 56.93859631015409, 48.00677107226465, 47.523193820830315, 56.55058368559807, 56.44149864873579, 54.29936678178849, 49.43201918755808, 49.98260621101626, 48.296328283125355, 46.0374431456289, 41.93500872581236, 40.63579813126595, 40.562116407579, 40.196555429889315, 38.309683569015995, 40.68165063858032, 44.01911697080059, 47.53680444532826, 48.619676713020574, 50.75388931458997, 50.92193934225267, 52.85399690751107, 56.5273710989183, 50.55362093833185, 51.82972877256332, 52.63190054124402, 50.97171421973936, 49.61586459990471, 45.755158009067664, 45.10538208869196, 42.37771095768098, 44.26939164438556, 40.36900243451519, 27.359020286990752, 13.461444993172924, 3.752648969811778, 2.0586040135352843, 1.083365015445217, 1.3633730935473598, 2.190297346922659, 4.593611753756001, 2.9827188387993844, 2.8576035653391196, 3.4353206426866594, 2.6484385180857877, 3.0323932055504095, 1.47008043864081, 0.9056053442820426, 6.389441480559688, 19.173380867127452, 23.25715853321937, 22.96111764446382, 19.51293456938959, 21.29410836004442, 42.03320918544647, 22.120649814605716, 7.740284685165652, 0.25182359611555455, 0.01601976321844925, 0.02521157054410827, 0.016037002111965373, 0.014328956416237259, 0.03556649373363584, 0.059845670156421206, 0.021791669780448563, 0.019297057672614054, 0.06408608556094189, 0.03310833591967821, 0.03874447925256626, 0.14004487153743544, 0.009348423468069205, 0.020664402043386813, 0.03432050152050872, 0.008496794166163573, 0.048179438097342375, 0.0381342978817561, 0.018139791847657294, 0.03481731720028385, 0.004233482787610903, 0.018002451435031912, 0.01135220974608655, 0.06312399021079464, 0.06980229274279649, 0.0664646161960498, 0.020389598644068165, 0.03250580776723162, 0.06403928141920798, 0.04452435217136818, 0.040967206756073626, 0.08191444159996125, 0.12313466038434737, 0.034102741028032, 0.02246514725078258, 0.012645192834879122, 0.03010020358487964, 0.032060840918171796, 0.026427629786813935, 0.03984681848857192, 0.004158021690654419, 0.016094825470880154, 0.03104884643107653, 0.03404220092981573, 0.016127734692887436, 0.06275154890552645, 0.06810287990036511, 0.05185046631302084, 0.11398605371434843, 0.008625245086037585, 0.025817310520177408, 0.009485018860188224, 0.022227531674528317, 0.005625063307478183, 0.06359506916675357, 0.055355073418468244, 0.03965498624189247, 0.020258348630440813, 0.07109602372492514, 0.04044451645665592, 0.05229734072101213, 0.08806568330093738, 0.10140733432865913, 0.00931787762730833, 0.07399736723351864, 0.3289830372218163, 6.799163933723205, 27.422337147497363, 40.24441619073191, 22.808264840033747, 16.75312157600157, 26.335656258367724, 51.27110873499225, 39.92151491103634, 16.862361546485655, 4.586098943987201, 0.18621610207182748, 0.29765724234523316, 0.5748801618333786, 2.5660280498766133, 6.443477032646057, 6.528136489852783, 14.308893661345206, 13.49525680465083, 8.315179617174211, 3.1023177889085587, 1.9198782381511506, 1.9750528710503734, 5.599472695781339, 15.853807407040751, 29.135465660402854, 43.38330468823833, 53.53691293347267, 58.53718180810252, 63.2242258902519, 57.549968304172644, 55.78957326950566, 57.58659147447156, 57.704968606272054, 59.38579051725326, 58.18559231296663, 55.95825479876611, 57.361933800481985, 59.12538043914303, 59.053357878038966, 56.911131874207534, 56.73212274428337, 48.661249914476954, 43.82583433581937, 45.63271730176864, 47.79761068282589, 49.36309922126032, 53.81042765032861, 54.28255942560012, 55.33485289542906, 53.77081955632856, 56.69527599888464, 57.17190673274379, 56.99257204609533, 49.40781424122472, 49.42448431445707, 57.49440793068179, 58.5508002773408, 55.10870864314418, 52.789764173569225, 52.319907372997655, 49.53673862641858, 49.25286885230772, 44.46936976525092, 41.204506504920225, 41.62048170643468, 41.57278176276915, 40.212801887143044, 42.60386697707638, 45.46381611977854, 49.5057205230959, 50.13272316225114, 52.11351617690056, 54.0243850984881, 54.21178810058102, 56.81768924959245, 53.58819007873536, 50.54162240797474, 54.09283045799502, 50.955106904429776, 51.89237686895555, 47.57573789165866, 45.971790513684674, 47.09114866871988, 47.407327005940104, 44.05245711726528, 30.18117347071248, 16.956257204855643, 6.225336376697787, 3.5536602668223845, 2.4158105879060687, 3.3890442742455393, 4.232747324051396, 5.198515269064135, 4.137370480645088, 4.671303120351607, 6.404927488296263, 5.839518318253179, 3.648147222495848, 0.1259381284997348, 0.63354006577884, 5.20843445293365, 20.220412477370232, 26.132381385372533, 25.935050864373487, 22.11490550348836, 26.768446660810902, 49.364981958943034, 27.289470780280332, 10.756176479401129, 0.5036678459615477, 0.04654618077761224, 0.06900307917667013, 0.025893291120507547, 0.044805514100458355, 0.039646528631208405, 0.08623241957637572, 0.027213419577287092, 0.09343750714775055, 0.04946402198965511, 0.03502886855013428, 0.030781341934456464, 0.11299712613465325, 0.047346554966943885, 0.035176030209948944, 0.043009865292978865, 0.07857849641192345, 0.03189987052352198, 0.12561861620915513, 0.01251492341379485, 0.03959034374284168, 0.06415149797835658, 0.01948426274823085, 0.00580876209442654, 0.04862119886843909, 0.06602143433185355, 0.044218966542112256, 0.05132605614621313, 0.03332458721894411, 0.023448568573521993, 0.1292801411041329, 0.13295576967779668, 0.17097125881381575, 0.1780463412644402, 0.1537188208631931, 0.11609698600706556, 0.11246459543584816, 0.10637746763325508, 0.18502206211128544, 0.12524256662976357, 0.20795490412462145, 0.14985140983856496, 0.16474124795246511, 0.11270521599198542, 0.16246708530572154, 0.21836119733991163, 0.14416838575515056, 0.13469278211555175, 0.1241724567127324, 0.3345363779414085, 0.1260557306569911, 0.1338057289080274, 0.1548458128086021, 0.09941091685886345, 0.1216561183513653, 0.16813313288073387, 0.11590762439394191, 0.1565280499597711, 0.0957156228081834, 0.09891394030062423, 0.09719496157260672, 0.15536788640724075, 0.42606123933388346, 0.15300851946155872, 0.20858072134996616, 0.1892294169914338, 0.4541406906660526, 7.954063665482306, 31.57914738501272, 49.839902539407056, 32.042400875399196, 27.837812246814853, 28.333807722214733, 49.56974537141862, 51.42219451165969, 19.981967672224968, 5.306466740946616, 0.5009871204533886, 1.71051376288937, 7.124885887868944, 7.7651275069482875, 14.060958681568025, 10.447129011154175, 15.238273778269368, 17.244147408393122, 13.518442915331933, 4.99419165234412, 2.7187734794232155, 1.6504973317346268, 4.738766416426628, 15.563149971346702, 28.14251765128105, 43.57721098007695, 52.733270275977354, 61.300974046030355, 64.23088650549612, 59.12963228840982, 58.12307757716025, 59.37033637877434, 58.643956568933305, 61.37051766918552, 57.169376803982644, 57.6300121122791, 57.45002631218203, 59.96288491833595, 60.489843583876095, 59.10791020239554, 56.820615337740996, 50.76676645586568, 45.158094821437714, 47.72581561919182, 49.62868682799801, 52.961791484586655, 56.81565353947302, 58.00490833097889, 57.40804518422773, 55.66002914982458, 57.853238121155776, 59.2077462903915, 57.04034651479414, 52.62013343072707, 50.565595934467936, 58.1842077162958, 61.219357367484804, 56.483487621430434, 55.8355865939971, 55.22912932980446, 51.34482576001076, 50.858640132411836, 47.46570364121468, 44.162801234952866, 45.248356403843054, 44.30224541694888, 42.39609118430845, 44.50108212809409, 47.721120542095555, 51.28272679544265, 53.51859154239778, 54.984369508681766, 56.0750316035363, 57.242736893315474, 57.988218645895685, 53.470173804990715, 50.41664000480406, 54.26740338725429, 52.31716955861738, 52.0561711249813, 52.19636447968022, 50.1266081871525, 51.46188497543336, 49.40624137078562, 43.13823107750186, 28.353137162423906, 16.506273092762118, 4.963971751351511, 2.879458276494857, 2.2698246279070458, 4.8772143163988675, 7.922045357765691, 8.394159482371423, 6.039425836455438, 9.032013358608369, 9.175030819831356, 8.676008255250993, 7.323877532635966, 2.3546000401819907, 1.2785615219223885, 8.207828758224364, 22.240270337750836, 29.648160626811368, 30.95706339805357, 28.11839507472131, 32.2455325818831, 51.73538400280861, 31.709160227929395, 11.715653923250015, 0.6375166136891611, 0.09275682270526887, 0.2515650261193514, 0.16881061507569206, 0.12403866711763606, 0.26608084478685934, 0.20543802950170734, 0.14681906529491948, 0.18325163291827326, 0.1062681545473395, 0.13236595858489314, 0.18562881906907405, 0.23236009051963208, 0.14227717513999633, 0.10644417090882217, 0.16052492984360264, 0.18173657147394073, 0.17659622875432815, 0.19134345194024427, 0.10072744661761869, 0.11217304535450474, 0.1581063902666492, 0.06443340301273331, 0.09514199915311991, 0.14736393767018474, 0.18912182760334786, 0.18824887041363025, 0.2383895242406476, 0.1306804425774082, 0.09204757084409076], [0.02129110984594351, 0.0322083703001901, 0.0189789243402981, 0.045023902785032995, 0.10839131360332813, 0.0521512937191273, 0.04834558724636032, 0.02881994234367965, 0.017325999628331874, 0.06343268150944384, 0.026073865705139698, 0.02012278171136014, 0.020069266639409528, 0.05313774300438743, 0.00484192130839332, 0.06340943074094192, 0.0228406356707696, 0.06345245040832989, 0.11873288004989586, 0.0377236977369795, 0.0775963027450827, 0.05492784150485551, 0.05782803205112296, 0.037761013879771196, 0.06239567808206044, 0.08452269519048353, 0.0326865662129656, 0.05514976185476107, 0.017377452008546363, 0.024700658846526377, 0.06938755572322877, 0.09667063567547068, 0.1477752502767309, 0.024544346266456192, 0.10402573092329888, 0.04331505173937448, 0.03875748359508092, 0.3377209135120915, 6.570670672001378, 24.97785133700217, 35.5928538691613, 25.397882269274806, 19.22786258882092, 13.202033158271545, 50.63858339863439, 38.99052858352661, 13.432893080096092, 3.92626729223036, 0.7672885985624406, 0.48620851830609385, 1.7808267834686466, 3.8490787244612172, 5.148266765379137, 20.157976188967307, 12.868659150215889, 7.017099645829971, 2.1648833299836805, 2.2632225434626303, 1.1103961520618009, 0.8642331030099624, 2.3964835991782527, 13.437620516746277, 21.907429772038615, 36.31189100203976, 48.78740510632915, 55.44464395892236, 58.114158107388405, 60.094613798203014, 57.96104054297171, 58.93978564969955, 56.4688846372789, 57.13269479813115, 55.72068468216927, 57.48208384360037, 57.99125848277923, 57.46212290179346, 56.55753412554341, 49.218932505576845, 44.674882350429414, 46.39635570587651, 47.18255166084536, 51.387920841093994, 50.834803888874674, 53.380571180774325, 52.69585086453346, 55.38348636319561, 52.928984780465406, 58.48696762515653, 56.08959536398611, 60.22085135982883, 45.91505342914213, 46.61427082553987, 59.56095180203838, 54.556368320218986, 54.02704838783511, 49.35099478690855, 50.094276089822095, 47.697747138238725, 46.72894131752753, 44.160734145872055, 43.15187308096117, 43.95011855709938, 43.512464415642526, 41.124686271913596, 45.64545716008833, 48.69208366640153, 49.27770530023883, 49.636429586718165, 53.160683108914284, 53.70019728137601, 55.198130838332645, 51.16949581330823, 48.14703895199684, 52.80524969100953, 49.72127045354536, 51.69969043424053, 49.675013942103234, 49.52797212908345, 49.37273256240353, 47.02628443318029, 37.18650110306279, 24.7406969916436, 12.773361244509298, 4.328835587347708, 1.6948382556438448, 2.31343501037167, 2.215368646767832, 1.9139626910609586, 1.9029176643779202, 3.400444643151376, 4.770730791553374, 4.103394174768079, 9.033023368927742, 3.7973551644432932, 0.8099082148363514, 1.339010026666426, 4.72668061333318, 16.49113666626715, 23.98489744432511, 22.392521058359456, 19.018829676412768, 26.38202455735976, 26.601294855917654, 20.595032168972878, 12.010503392065726, 1.8160213530063631, 0.003682706507876696, 0.01709889669361855, 0.06731344161615258, 0.023824093382685416, 0.0339486998986573, 0.10245159643912509, 0.06421835830194816, 0.04690975461515689, 0.037976158181986505, 0.06618435058983103, 0.014409994154477553, 0.05681313409079468, 0.02738582957986622, 0.07864562869672814, 0.08658417650768835, 0.07184804627491582, 0.027177116585775252, 0.06373127959969063, 0.034121211407886404, 0.013068917023408557, 0.07486062575011485, 0.028877563646904407, 0.022603223107815273, 0.007883192212771504, 0.04864115162842697, 0.06605927141443377, 0.043937337299388264, 0.041506490519931244, 0.03302827590115128, 0.07306938960907922, 0.02099273583641456, 0.07460638415068388, 0.020972882667856834, 0.025677951465871547, 0.023401214763702407, 0.028866639233104167, 0.07238587064127769, 0.025000722079928366, 0.031016446657538898, 0.027145944468136278, 0.05141538582862385, 0.04090395087616579, 0.02986441129788516, 0.07021472383771213, 0.04575209233969931, 0.03644732630721504, 0.044764379009364114, 0.014631210661102689, 0.02066807735020355, 0.029885536172397198, 0.03931339146689542, 0.04074497614055872, 0.0666660130504639, 0.0417478809944324, 0.06197598447362262, 0.06346315648707171, 0.03225787490185711, 0.045073196712520816, 0.0632177823553643, 0.03828622460845978, 0.056131051537851175, 0.06263623735116375, 0.06655322958625133, 0.05394110110618415, 0.01731795762034674, 0.036287880427534544, 0.032091819598609884, 0.6571014982558067, 9.367581932775437, 32.80236597984068, 37.60209583467053, 23.87602617663722, 17.158837818330337, 25.104279133581347, 55.72631720573672, 35.25191753141342, 18.093522940912557, 5.478114562649881, 0.5771352795343245, 0.17855169882457103, 0.7971845975806637, 3.943498019249209, 8.152140907702908, 21.034637689590454, 17.343983496389082, 6.479444186533652, 4.78844617643664, 4.193474592701081, 2.2155863383123955, 2.0014927103634803, 4.109348822985926, 15.857594455442122, 25.44705310175496, 39.66771402666646, 51.717831396287494, 57.62613681054885, 60.31772213597452, 61.357769966125495, 60.93871570402577, 60.38112724981001, 58.36155768363707, 57.2349117648217, 55.57216021322436, 58.17303680604505, 59.49684066157187, 58.45067393395209, 58.73146856984785, 51.792281904528224, 45.19922871743479, 48.18863176530408, 48.603077242451334, 53.236698642853774, 54.959074143440496, 55.768098292812226, 54.65458446933378, 55.83864996510168, 55.96396184736683, 58.36589974741782, 57.79763067922285, 60.37129386778801, 47.642857490047334, 48.08597157078405, 57.89534868732576, 55.87981916243031, 55.60886183092671, 51.23090836309618, 50.926242182331706, 48.50428058255104, 48.97530232706378, 45.156329754860174, 45.1953455709642, 45.39798305880639, 42.595708447117964, 41.8769419577814, 47.73127163610151, 49.646251201629646, 50.262059396313084, 51.482442117506466, 53.48669875052668, 53.71926392278364, 55.57386644424931, 53.77809555299821, 48.66930646281089, 51.97975158691407, 51.778894855130105, 52.93433881575062, 51.076763137694336, 50.65731663857737, 51.446556352799945, 49.95769131568171, 40.28898608299994, 29.07319215036208, 14.43890650426188, 6.140364110469819, 3.1210571575549344, 2.7019465113839796, 4.159962352245085, 4.967444029546553, 4.395812509521361, 3.8549831173112317, 4.684447963391581, 4.912555852243978, 4.834608060698356, 1.7189669609069826, 0.24966312091677423, 0.39426476003662236, 4.210537393246928, 15.9974818652676, 27.26073745758303, 24.143339626250732, 23.182290292555287, 30.595362032613448, 29.02829081781449, 28.629691716163393, 16.31312676014439, 2.840905300071163, 0.021019230987275803, 0.014560726741629263, 0.012857164575478003, 0.015245978025749568, 0.04245624419361834, 0.07183265556851703, 0.019284612574284116, 0.02221175792416738, 0.03599063065203448, 0.01310498923093321, 0.018565160252394217, 0.005169036064011556, 0.06157367723062635, 0.05578047438194195, 0.008023058800327202, 0.07239114132619674, 0.02891002087703636, 0.08251075677934193, 0.06687500949708686, 0.02499423523042952, 0.03563097535422252, 0.024649807845332453, 0.02055103252191217, 0.03351274224358701, 0.04154871345587796, 0.029240107096190897, 0.06253056701332813, 0.05399313379800128, 0.09511903949802923, 0.03940531435692984, 0.16094100751703785, 0.11103899007843387, 0.11637915151133654, 0.10798010824909134, 0.15274883097698613, 0.15268979624154108, 0.12741673948063006, 0.08255738089041365, 0.18782876311771332, 0.3369098715484143, 0.24836046501032769, 0.1584146180821042, 0.10909609917190768, 0.1209219916152858, 0.1624710689629278, 0.18650796624921984, 0.1705486234277487, 0.18494358406432215, 0.18355682702554812, 0.1498141932872034, 0.12874073859664703, 0.10650656110937558, 0.13796235344582988, 0.19835402978764427, 0.17104474196751274, 0.2368549735195214, 0.20218114458745529, 0.12909545262734737, 0.12593504116539994, 0.08808248360911686, 0.1857578282755229, 0.3009539025445139, 0.23090286871358273, 0.2134436483104383, 0.15606317248555923, 0.11020219989962156, 0.12420289338596406, 0.7944789588932069, 10.83814715185473, 39.20273665458926, 45.94351806948262, 36.55180669599964, 26.807119269524854, 21.809182243962443, 60.656807115001065, 47.007135421999045, 18.629942363308324, 5.506420837294671, 1.3299368490134518, 0.8652160857473651, 5.520921839821724, 10.552314231472632, 12.15469462256278, 34.160537642817346, 18.789765219534598, 14.965843596766073, 7.764334697877207, 7.101432075423579, 2.4579042388546855, 1.3774490092069873, 3.5195849210985246, 16.743613750703876, 27.013824255235736, 38.42236934169647, 51.96028878611904, 60.54387815536992, 61.99966584482501, 63.820888996124275, 61.93569590968471, 63.11727854513354, 59.268617553095666, 58.53531868227067, 55.6615706413023, 58.1560411760884, 61.27967949836486, 60.88328869112077, 61.60275336234801, 51.60482398925289, 48.82084331204815, 50.66593016347578, 50.47965680399249, 55.35454319369409, 56.007782566931944, 59.06438758296352, 56.45332459480532, 60.398919120911636, 58.78713876970353, 60.68773108143961, 60.43438911437989, 60.917225037851644, 48.495965157785726, 50.7268798735834, 57.894803477871804, 57.51066223267586, 56.857826863565755, 53.773702498405214, 52.934962472608014, 51.7536622478116, 50.85695743560792, 47.36841709383073, 47.22663517921202, 46.29888872946463, 45.64678684357674, 44.929965849845644, 50.16097599460233, 52.860151106311434, 53.342292770262695, 53.444109655195675, 54.726912975311286, 56.10870907383581, 56.15770732202838, 54.23605972720731, 50.70363198557208, 53.44661604973578, 52.880794540528335, 53.26236663326141, 51.6696293892399, 51.82525727056688, 50.11174240419942, 48.29761874291205, 38.630800170283166, 27.817311979109242, 14.420390955863462, 5.799923952548735, 3.0504098774925357, 4.557376898104145, 7.62901782989502, 5.808331062716823, 7.286918999687319, 8.123024663617535, 9.339010407847743, 9.815952970135598, 15.747777896542704, 6.439516909660832, 1.622962293124968, 1.48142381060508, 6.303955874135418, 19.21051198436368, 31.142615041425152, 30.40598607832386, 27.21674611491542, 39.39446603098224, 37.16802673955118, 30.552839617575373, 16.955884579689272, 3.0500865271014557, 0.15358087907154716, 0.09071774945984926, 0.17211899642021428, 0.12274920324524566, 0.12256092947697449, 0.2910564449285307, 0.08782965161146657, 0.13265377781804533, 0.1703596142150702, 0.13789608684037963, 0.1517368594725286, 0.12426310023593327, 0.16383735613236505, 0.12495455587463034, 0.12170266585364459, 0.16767862823701676, 0.1258081387007429, 0.1360892071839302, 0.10591494204897074, 0.11265596419933344, 0.31266894972612785, 0.10845369614300229, 0.06961330651275574, 0.10275649943298872, 0.2292801565941303, 0.152244285470055, 0.15750176303329008, 0.15785137491841472, 0.32843537628650665, 0.19517049013126284], [0.08065059570775879, 0.044193639675335544, 0.0329976745190159, 0.057607850720805515, 0.07372173645924177, 0.03550357493241468, 0.03782367987197734, 0.05401310571018727, 0.050906006306890524, 0.044185680021802266, 0.023949816071939085, 0.09896830189973117, 0.04626882247506611, 0.05135761513825386, 0.03374805764084862, 0.0012403095165462864, 0.029497503062650084, 0.06380570504153449, 0.031915941132953575, 0.06964267066289341, 0.045937489447814804, 0.023731417811265396, 0.06138034728205493, 0.045081156366054094, 0.04535746512814395, 0.035786426085377895, 0.06674300488685408, 0.040767740443228714, 0.07157948649218006, 0.059520193871351025, 0.04115305585606445, 0.011821010548080648, 0.0543449443554686, 0.09036318864673377, 0.04353949251855093, 0.03790573937998664, 0.04362689548983209, 0.05207286163743946, 0.5888582020998001, 9.951904281493157, 29.3872171063577, 30.709769725799564, 27.450674310807262, 17.44368230142901, 26.555148170840358, 55.21616589638495, 28.78762006759644, 13.174777588536664, 4.134209540582472, 1.035069729531965, 0.650577554779668, 1.830384214558909, 8.140098740977626, 17.435594374133697, 21.24688498435482, 4.338306150128765, 2.6012310770250138, 2.2944183791837385, 1.5966324027507537, 2.028731732599197, 0.4682040118402051, 3.4018495871174723, 10.886306012830428, 18.585680377098825, 31.606876580945908, 46.574501914362756, 53.16501732795469, 57.786138134617964, 59.032718366192235, 57.34282793537263, 55.067504144484005, 58.32269091759959, 56.973423034914084, 59.664278799487704, 59.123423176427046, 55.15552997589112, 54.02969598770142, 49.31247318944624, 50.697705284241714, 52.16410690738309, 52.762095774373705, 53.88143039518788, 52.6191096921121, 53.795342214645885, 53.825826875625125, 53.54125107488325, 53.51328065318447, 58.52556767002229, 56.362129488298976, 59.15388430318525, 49.14362692063855, 46.530783176422126, 57.42023591072329, 53.12258904980075, 53.586915308429354, 50.32179317166729, 48.86813140684559, 47.83251585498933, 49.655276575396144, 48.93162281282487, 47.607716975673554, 44.910887441327496, 43.52841277276316, 42.96574484917426, 48.02140935774773, 50.38799885780581, 52.395585583102324, 51.76087940892866, 54.88583172521284, 52.372800534771336, 54.67597707625359, 48.446723722642474, 54.78418350219727, 52.05107204375729, 52.76083277117822, 53.277954132326194, 53.45746924800258, 50.31530557140228, 42.343099963280466, 29.5198755879556, 16.91166573955167, 7.829264142820913, 3.041414902094872, 1.0862510218735666, 1.1414811808255412, 2.570461799060145, 2.8864295540317415, 5.318863391876222, 4.628809142497278, 3.2772863872589606, 3.1051884735784228, 3.7931798013948628, 2.049609528433892, 2.414853039287752, 0.6853556176347118, 3.154607641120111, 15.023055288099474, 26.94348635212068, 28.04581553705277, 19.829050148687056, 22.931378233817316, 29.30687127574798, 20.72112460290232, 9.441187170244033, 1.3943573664272986, 0.2087926672350976, 0.02957375945463296, 0.05332744552663738, 0.05570117279046005, 0.033431988915488604, 0.0387548137786648, 0.03239181005365906, 0.02834794982787102, 0.04275287343789974, 0.013190725960979059, 0.05553426521439707, 0.06942284939390037, 0.03600383034696983, 0.04434700664733687, 0.008216681777529659, 0.027858013617655927, 0.020975353301412637, 0.019648916110576644, 0.013503386552685933, 0.029976890242147832, 0.01836422305073469, 0.0758509629315907, 0.06263360966958346, 0.04701563945761131, 0.01608076967268942, 0.07928207156158264, 0.010665735594117114, 0.015300618289338966, 0.03795775291960567, 0.01701499091371173, 0.056397504578795166, 0.10181194366586786, 0.04144942846089121, 0.06677726433882791, 0.07798097847450165, 0.07066228006395602, 0.08409570842500656, 0.020888892618278344, 0.05155539222722573, 0.04239696814047714, 0.039181969083485105, 0.06625228726695623, 0.07681986497294518, 0.03306413647688685, 0.03833923406238037, 0.05434472602041018, 0.036915497959501324, 0.059138291380217964, 0.023089279082693884, 0.03841978054673922, 0.037121548798055425, 0.056818243897249626, 0.046393277288805095, 0.04095943096364218, 0.03677724590224605, 0.02954209895594226, 0.03989111752279344, 0.048073882672695384, 0.019534698146725857, 0.014938764319184327, 0.06291108671575785, 0.0593281701026905, 0.02129987963745671, 0.03687285367519625, 0.03064413367199802, 0.0358011924301184, 0.10984939342785267, 0.03882972568634056, 0.010676698312313567, 1.155233010649681, 14.679416437302867, 36.523518562316895, 36.79298539315501, 19.798736110810314, 13.154284184978856, 41.19597534979544, 60.20470688419958, 27.646816353644095, 17.368737574546568, 5.2684104346459915, 0.5627991391285774, 0.1655410590671724, 0.9003847308697239, 4.515418814074609, 12.874937884269222, 9.697270874054203, 5.106472440304295, 4.805985054662151, 4.36133046304026, 4.261059972547716, 3.378267562197101, 1.2264239067031493, 5.871744021292656, 13.030823661435036, 22.86192874754629, 34.979689351973995, 50.3914426988171, 55.265415176268554, 60.39639703689083, 61.03682594914591, 59.63260958271643, 56.67546802951444, 58.164129103383715, 56.68698803071053, 59.84098157575054, 60.581893767080004, 58.833948335339954, 56.964170163677586, 51.12128596152029, 51.86427308667091, 52.35322006287114, 53.823030225692264, 55.203857498784224, 54.34479959549443, 55.44231799341018, 54.90680856089438, 55.21206701955488, 54.81465639606599, 59.312508875323886, 57.41872972057712, 60.532883751776914, 50.16928749699747, 49.26810726042717, 57.59118456994334, 56.16278286903135, 54.955634224799375, 53.36476795135006, 51.165141982416955, 49.81761955445813, 51.13136253049297, 50.94736414570963, 49.199320654715265, 46.693612529385476, 44.880308643464126, 43.63125731868129, 50.04640356186898, 52.19297947422151, 54.368914327313824, 53.81498544446884, 56.26203844624182, 54.06186726785476, 55.92114525456583, 49.02917608138054, 52.6188547380509, 53.10267517643591, 52.628405709420484, 53.44986377223846, 54.203127507240545, 52.670677092767534, 45.79410322250859, 33.05572363638109, 20.73205428738748, 10.191090414600989, 4.514710335962234, 1.6183642946904706, 1.7595850652264011, 2.66564816236496, 3.628570672965819, 5.578242376927407, 4.831497621151709, 4.323237874815542, 4.51736185819872, 2.754839673157661, 1.7238101074772498, 0.5551429789873862, 0.17650402241176175, 2.424132141374773, 14.431293183757415, 29.428480440570464, 29.064298175996353, 21.62268727056442, 26.49279032984088, 34.41780982478973, 27.282353639602665, 13.984453831949542, 3.5122155229891505, 0.18839435051045111, 0.03081904686686974, 0.018812807750016935, 0.007148485643894322, 0.02099185100486202, 0.04255800748304014, 0.029668706476748474, 0.043230579054403695, 0.02086741534332114, 0.026149189385074764, 0.08600045581378284, 0.029148820059133634, 0.02692333655431867, 0.008080649460034986, 0.047188319506183754, 0.05353209825472967, 0.05507975674024033, 0.0333848821690246, 0.04660969329697471, 0.022094377932409127, 0.03857803515969746, 0.047037660654994755, 0.07957181367542475, 0.07561516872937642, 0.0571645156390244, 0.016867231705316135, 0.006398494184512886, 0.019474929882093303, 0.06592094657882568, 0.018520935911745317, 0.027069038816637574, 0.23962045899562298, 0.1739328168332577, 0.120301598292445, 0.136614314490749, 0.16109845390723598, 0.1770556057172437, 0.09245355147868396, 0.3407774511123857, 0.18712547908146537, 0.1336605858898932, 0.24100462665721295, 0.1648319527626999, 0.27082645304260716, 0.12416950727422392, 0.16980634551615487, 0.1054104118637981, 0.2038353582423541, 0.1357133644482782, 0.16419479743607585, 0.1766883738098606, 0.21010623223358588, 0.2126843938904424, 0.1302831187363594, 0.1209997878439965, 0.12751387176854959, 0.08348342797328388, 0.15139035790437652, 0.1496061544504858, 0.14720069965527904, 0.21930244360719958, 0.15069619031442752, 0.1404716591200521, 0.1258952275759751, 0.19949084298024256, 0.1956300662770387, 0.16925856200677736, 0.23823212381572495, 0.11555886286641322, 1.1621129705059914, 15.870980524247694, 42.41701310680759, 44.17484683375205, 36.412444883777255, 27.63530811955852, 37.51398371111962, 63.95432410701629, 35.978795482266335, 17.21678299288596, 5.920400532983965, 1.323769657361892, 1.1646042884357515, 5.259073232450794, 17.971654899658695, 25.34935470550291, 32.492885089689686, 11.153859707616991, 7.606044998092036, 7.591286099726155, 5.476299976148914, 4.881847616164915, 1.4203814345021404, 4.042084342049015, 13.05429316336109, 23.75196553045704, 34.62248694512152, 48.542229513968195, 56.53294870930334, 62.09647778541812, 60.47275381703531, 59.51901774252615, 55.04069474435622, 57.16308139985608, 57.89258733872445, 60.95606042492775, 63.519062611364554, 59.12862816164571, 59.09736687137235, 53.73769906259353, 56.17458528087985, 57.25682604697443, 56.21801768579791, 58.91110527899958, 58.232092011359434, 58.09958257982808, 58.06938425187142, 57.27622216747653, 58.33216344156573, 62.12397752269622, 59.2921753083506, 60.940006163812455, 51.310579546036266, 51.53353098900088, 58.04554408596408, 57.30157244590021, 57.44008702616538, 56.21145556049963, 52.77804413149434, 52.92696083745649, 53.29846812832741, 52.88939629831622, 52.25169343333091, 48.37878827125796, 47.69756278684063, 46.945197274608, 51.76003609934161, 55.23072573446459, 57.523315798851755, 56.51386245604485, 58.700450466525176, 53.876601957505756, 55.28632925402734, 50.405194528641246, 55.861250662034564, 53.491927269966375, 53.734729828373084, 53.9748808645433, 53.74247650946341, 50.807880740011896, 44.25221950777116, 32.85406674108198, 19.544811671780003, 9.693171016631588, 4.2163425011019555, 1.672006261444861, 2.661618172161041, 6.091604636561486, 8.762455332663752, 11.229751686896048, 13.736418831732966, 11.694578047721617, 8.900652200944963, 8.339635595198601, 5.34662788914096, 4.530806762556876, 1.049586053817503, 4.59124852572718, 18.913559144543065, 33.379472148033884, 36.897587160910334, 27.8171197829708, 32.80819658310183, 39.58108848141086, 32.12984619602081, 15.097144938284352, 3.280520626614171, 0.3569578715870458, 0.10649963567454009, 0.09854269409251791, 0.13580504985105607, 0.05492624038109376, 0.17181705052573837, 0.1140177084673797, 0.1611054865943809, 0.12034516571269882, 0.09084288226140123, 0.11548479748589378, 0.10040509214083995, 0.16190215674859865, 0.141716965684487, 0.17821342504072576, 0.3010493570998792, 0.19644616442101617, 0.16356590053727552, 0.14318207819615641, 0.13945769578699144, 0.09633482103386233, 0.14973435160373488, 0.12202016333298338, 0.1748144921035536, 0.1942262407993117, 0.19863116975513198, 0.10139408866844832, 0.23110174513872594, 0.10038588631657824, 0.11578933275755375, 0.13847077535765787], [0.02692895963968289, 0.051546823533792654, 0.05752076184557331, 0.059984420170827266, 0.03571549017402915, 0.05853633013283534, 0.02730092980087765, 0.031608670927403916, 0.03834134080417214, 0.030094701158363494, 0.05136705717192062, 0.014084820474137463, 0.02865294666750537, 0.06847393458649036, 0.05590915800102296, 0.10682865511626007, 0.005847837366614371, 0.0685578978229915, 0.05985617322186309, 0.07165497679623865, 0.0763828347947809, 0.05089752188312912, 0.03149507732521142, 0.08793114293967524, 0.05931421198071011, 0.009749065427440069, 0.02907374152733434, 0.015326483332882486, 0.09291070678661908, 0.03006795511370705, 0.027937432037546273, 0.062032314918694965, 0.08964578561004131, 0.047644815978504, 0.04962812568391523, 0.06257211962234109, 0.0902734031420081, 0.04634190726304247, 0.019736625517027515, 1.3792058633219813, 11.623334077096755, 30.896623596068356, 34.279609034138346, 28.11085431806503, 9.07688723456475, 24.97525865031827, 65.12103703714186, 24.479702480377693, 18.561616636091664, 6.378520621407417, 0.9374470227668363, 1.567638977881401, 3.1362497229729933, 13.663233287872808, 10.93062291222234, 3.3355122564300417, 4.038310776795111, 2.163768151114064, 3.7943778403343695, 2.272078519867313, 0.6368486463062225, 0.4694876074790955, 1.7355029381090596, 11.300927016042895, 16.716114013425766, 24.495672410534276, 38.95342688406668, 49.68138779363325, 52.63639165509132, 56.8547321134998, 57.98408839010424, 58.38041251705539, 56.78427065572431, 58.506912877482755, 58.46906985006025, 58.321463215735655, 54.57985939518098, 53.2597464899863, 52.796024276364236, 53.50195284812681, 54.66721842365881, 55.005926855148815, 54.14492737862372, 52.61575998798494, 52.27747909484371, 54.6385851214009, 53.776907074836, 57.346797373987016, 56.9058092178837, 58.67928143470519, 51.44276342084331, 42.27811021189536, 60.85081931083434, 56.787757642807506, 54.74830165986092, 53.55570108659806, 52.188190260241115, 50.93375744358186, 50.2609807445157, 49.78001579161614, 48.19263258287984, 46.802505370109316, 46.549720379614065, 48.703646813669515, 51.439782419512355, 53.747775631566206, 53.10050218336044, 56.40872724594609, 52.028181091431655, 58.75099412856564, 51.45742524054743, 50.92562637021465, 49.639390976198264, 48.45596874913862, 52.55786188187138, 49.08585825274068, 41.32989683458882, 30.411800992104318, 21.902085542678837, 11.419138427703611, 4.964748870941901, 1.7983417597509201, 0.4152749971516671, 0.4970401435369446, 1.1218460408910629, 2.2727293881677815, 2.9064738462048196, 4.454897132612044, 2.2340474638246723, 2.469997886688479, 3.599439229696028, 2.3553146469977597, 0.7974285199757546, 0.11788475176980419, 2.2906774186318923, 11.149131290374264, 21.60984935299043, 28.44701909249829, 21.2692738732984, 23.46263973943649, 24.10226848817641, 19.983915129015525, 9.168514782382596, 2.0247719773361763, 0.040459359410188855, 0.05978245258090958, 0.079217528653962, 0.03505340251590937, 0.03706603806706206, 0.053585689935472705, 0.05604789652411015, 0.07497311044003695, 0.002076982866950153, 0.007606980169282085, 0.02283798309133178, 0.03764603557365556, 0.03557989644187112, 0.0051915992686014266, 0.0389186991378665, 0.017355685535397743, 0.0041612756491128, 0.0210623272634562, 0.016890758265470786, 0.022154071503469062, 0.03173446447979058, 0.04644125354506316, 0.06966206034825695, 0.01301254444350038, 0.02308631432242692, 0.05601020116779593, 0.07680252074233948, 0.024458075190083157, 0.020795422230636882, 0.03284512726109355, 0.0198502880671332, 0.07232694315814203, 0.04194494179119507, 0.0429745601309884, 0.02992916296446516, 0.0084483333592934, 0.013036456920446889, 0.02143486432971493, 0.04301282622280621, 0.10081802119290638, 0.02992593390386432, 0.08236000599760203, 0.03545597022879989, 0.028238517998327172, 0.03870552751205621, 0.06064687172071107, 0.027574844538204135, 0.0357349717899436, 0.02052251872937045, 0.03371712301046618, 0.03728952123633316, 0.06226920079620135, 0.03418379696086049, 0.07474251797482853, 0.061959846831497654, 0.04782688826502812, 0.06622971065582768, 0.03999538208928801, 0.03746764050916799, 0.04475562262438959, 0.05801288906725184, 0.10314512817609696, 0.0815749037710409, 0.03224599670859114, 0.024454629709643703, 0.1185439627677683, 0.010180958028462146, 0.02184159573047392, 0.06724561985221601, 0.02647350504693966, 0.06486537701059734, 2.6325306104075525, 17.285071457585982, 37.1644534603242, 37.59456096156951, 26.026889239588094, 15.023167075649386, 38.346389109088534, 55.09246218589045, 23.660472323817594, 23.76800802446181, 6.396517926646817, 0.794666129494867, 0.6137085621876102, 0.9523865953087808, 2.1787577338757056, 6.896481860068537, 4.441757192534785, 4.7919581686296775, 5.4528177265198, 5.972111100150693, 3.790252487505636, 2.2816885719376225, 1.4042408812430598, 3.414748056280998, 12.382094033302801, 18.802656089105916, 29.7267198178076, 42.630958787856564, 51.75793370892925, 53.36085734828826, 58.694570833636874, 56.712365765725416, 58.67295072924707, 57.73326458469514, 59.34461347518429, 59.13173860119235, 59.95249063737931, 55.78888293235533, 55.21283188173848, 54.428687326369754, 55.48110631204421, 57.29453963618125, 57.589866653565444, 55.96612307333178, 55.3996818296371, 54.69795803869925, 56.17838605757683, 55.03303435540969, 59.62486682399627, 58.92907757912913, 59.17260577601772, 51.603588442648615, 44.5726026258161, 58.164682157578014, 59.669468095225675, 55.99133214642925, 55.23962559238557, 54.560710383999734, 53.33948827558949, 51.614445563285585, 51.3520586106085, 50.6294717327241, 48.18196765838131, 48.114957886357466, 50.210601822022475, 52.61082956867834, 55.12315473248882, 53.7448299315668, 56.486303883214156, 53.168723967767534, 56.99266618297946, 55.17877001916209, 51.28840246508199, 51.1666795515245, 51.090365917451926, 52.857123036538404, 51.686452434908965, 44.22797533773607, 34.33413390190371, 25.519371801807036, 14.288275722534427, 8.35756867162643, 3.3431245963419642, 1.1578573214430963, 0.9646535628745634, 2.3186468597381347, 3.8839598721073525, 4.495582407520664, 4.24740816316297, 3.3359125833357535, 4.275717869881661, 2.5820705438813856, 2.2079752241411517, 0.495718366075908, 0.2998864662743384, 1.5730012256291606, 11.498632123393397, 24.529818604069373, 34.93564505730906, 27.3280414073698, 26.299562608042073, 27.378253629130704, 26.203390013787057, 13.485463626923101, 3.6333814599821648, 0.135489973209558, 0.02583998672273611, 0.05217694617327183, 0.024200060607625112, 0.04071093502364332, 0.01722277502619451, 0.04265074625671391, 0.03426990524354962, 0.036169010394763564, 0.047489415043063705, 0.06444114050076855, 0.027597379014496843, 0.01995362566723939, 0.020333197335862828, 0.06528383721747706, 0.08547803747557825, 0.015002611044403768, 0.021907241804705515, 0.044905760535790075, 0.023607865066057252, 0.013746533283753502, 0.02324048951718836, 0.1092019112360093, 0.03707593975348338, 0.004129670212991656, 0.04178871348079655, 0.03856386253309827, 0.03601984541502691, 0.09483251495346909, 0.005770636771264817, 0.040918939386404334, 0.0173034536607203, 0.13610808359038445, 0.10180015357271319, 0.18555527462834315, 0.13032467134537237, 0.13453835411177528, 0.14915368760064726, 0.12648271742246806, 0.16662306632966767, 0.16727326047276297, 0.230855738984481, 0.1251055288218683, 0.12477531428298644, 0.13950199099077334, 0.2085209511701138, 0.1699442719860423, 0.19618356480233132, 0.17129244883694958, 0.12134674140402388, 0.16986669792282968, 0.1588624424391216, 0.17646089166162476, 0.2596980147063732, 0.15760785088904444, 0.14747402450490385, 0.13182957446382892, 0.11137756263656963, 0.13622806828108527, 0.13364347148566477, 0.24412214485627992, 0.23442492730194525, 0.32702828727422223, 0.18203396680614642, 0.3470820176505274, 0.23846835468805608, 0.1599050114952749, 0.1649169119135026, 0.21541053309075295, 0.130056755076493, 0.1293523219083586, 3.0272482816250097, 19.199401870850597, 43.67343064277403, 47.33080156387822, 38.28447841828869, 16.816985607147217, 34.182608819776966, 73.45331622708228, 33.32706536016157, 22.78457372419296, 8.22195517439996, 1.2575377403728425, 3.085936009883881, 6.209397825502581, 24.316433821955037, 21.65976739698841, 12.692989918493456, 10.035215423953149, 8.784948164416898, 9.076439103772564, 5.688321244332099, 1.9771633513512152, 1.04019638992125, 2.388591790391553, 13.313275498728599, 20.640351233943818, 29.16495207817324, 40.98616384690808, 53.334699061609086, 53.913440858164144, 59.16208597921557, 56.964562400694824, 58.97565964729556, 56.36699714968282, 61.49163261536629, 62.095104955857806, 63.46595764160157, 58.98645793237994, 57.19717071902368, 59.07030251718337, 57.5489406431875, 59.37276432591101, 59.09575085486136, 58.614056341109745, 57.61855486900576, 57.31855238637617, 59.21334351262739, 58.38618624594904, 62.752160795273326, 62.166492092993956, 59.624039203889915, 54.23966830776584, 47.03424292225992, 57.216829638327326, 59.45904862496161, 58.449697263779186, 58.726498926839525, 56.90472272134597, 55.92356535696215, 54.77361663695305, 53.574147993518466, 53.216925974815126, 50.711610086502574, 51.07127181945309, 53.0219018074774, 56.191930001781834, 58.12468967130108, 57.50289201736451, 59.089227953264796, 54.90607900004233, 59.09528017044068, 53.61938861108596, 53.17777287575507, 51.50240698168355, 53.024651388968195, 55.251686880665446, 53.39266384801557, 46.823525351862756, 33.294039003310665, 25.149370701082294, 13.360496913233112, 6.727885642359334, 3.24820765083836, 1.0852824415891402, 1.787861922094899, 2.8524608477469418, 5.9767723468042195, 8.983418133951004, 10.875052732806052, 5.631757724669672, 7.822293110432164, 8.54676615807318, 5.088027984865251, 2.673298745386062, 0.43169373225781227, 3.647625792411066, 14.908687799207627, 29.159437225710963, 38.463644443019746, 30.734459084849206, 33.57810097355997, 34.686186236719934, 30.44621390681113, 14.06447998939022, 3.192120944300006, 0.2623752774971147, 0.15741865781526412, 0.17140527826643762, 0.16198097187424862, 0.17896458957224123, 0.1529653274243878, 0.3361022003716038, 0.1340900854237618, 0.14969649153851694, 0.13378895158248563, 0.13188746006738755, 0.1698311054778676, 0.14910758442936406, 0.17124406272365203, 0.20930369384586814, 0.11180103305847415, 0.11490155176650133, 0.18216564199857174, 0.12170432060356103, 0.14303816091870108, 0.13808488154843931, 0.19861310540187746, 0.11802142951637508, 0.14113875316275706, 0.14211435081256976, 0.18057564183348612, 0.1736479853430102, 0.11117782053207198, 0.12380999753311758, 0.11656899575985248, 0.11786804339217564, 0.18218073393068007], [0.07197825057852654, 0.07392796732845806, 0.07629164734915381, 0.03279535835909267, 0.031703550916826057, 0.012163438443695346, 0.025057730512813698, 0.06741268064586386, 0.045025243438900485, 0.010787542616467803, 0.006779460611963465, 0.04373821189566966, 0.027471045370123563, 0.03599296338976391, 0.014889642761479464, 0.11437930962851933, 0.033843393452585704, 0.021847044530835365, 0.02910619875746629, 0.01888540032650194, 0.017848643962474122, 0.035601664830239556, 0.04068288471429579, 0.05358786945561728, 0.02912323655290229, 0.12487456097357696, 0.10312198465990444, 0.0680114779501192, 0.023748802261487133, 0.04350042203441263, 0.03354625859027428, 0.0373201149575893, 0.04627403187295122, 0.02828628358040606, 0.06652036441429969, 0.042043273006716085, 0.04433711262179479, 0.0334448208882203, 0.03145875709672128, 0.10920114514808502, 1.5017326176166537, 11.01154140887722, 35.06742100561819, 31.13849263037405, 23.159699401547833, 14.282947182655336, 32.56848093002073, 43.939947851242565, 22.433084249496464, 20.455038855152747, 10.536882646622198, 0.8315895449730658, 1.1802074769812247, 0.7981961400758836, 3.5495827178801265, 2.485304936285942, 3.106940792452905, 3.924770172565214, 4.875096726802088, 3.150699979835941, 1.770801818178546, 2.2083728544173704, 0.5629021626326346, 2.17263491403672, 7.042987779263528, 14.65112045887978, 20.02140514312252, 31.052016135185, 40.38302883025139, 48.39350108177432, 52.09734032230993, 56.025468534038914, 57.86448355643981, 59.8317640058456, 58.9316035855201, 59.025207027312256, 54.886247496451105, 54.31165948990853, 55.22507752141645, 55.341544458943034, 56.46382085738644, 54.114446640014656, 52.85411850098641, 54.607770981327185, 53.607899988851244, 53.30440267439812, 54.19254495251564, 55.944969730992476, 56.44714293941375, 60.05306413096767, 55.189431021290446, 44.00875406880533, 54.52839397615003, 53.50823648514287, 59.54987895104193, 51.92786647427467, 55.56216993639546, 51.60879735023745, 53.00947181640133, 51.50226577635735, 51.55984617048695, 50.10379960460048, 52.496104163508264, 51.52435656516783, 51.712767616395034, 52.03518252218924, 56.16152378820605, 53.12368339107883, 59.69500664741763, 49.61287575383341, 42.915793465029815, 45.95548522087836, 49.77582277790193, 50.51307147549045, 43.21570965551561, 30.497343963192357, 17.35504261908993, 11.534437479511386, 5.248078828857792, 1.483873698499895, 1.2741332885719117, 1.2316807407525279, 1.4203706479841665, 1.3761819610672614, 1.8962854267128053, 2.4404425822919418, 1.7674309087376443, 1.8947704112337482, 1.9347371569564267, 2.3219573401635696, 0.8587092413536964, 0.8603560239557297, 0.7651956463533064, 2.4201141634295067, 9.78130667440353, 18.982783094529186, 27.431035003354474, 24.771883756883685, 22.830626272386123, 31.099000246294086, 24.452657738039573, 9.29534952486715, 1.710006919118666, 0.07781905046994649, 0.08890624263233717, 0.047458871117522644, 0.05634682403216439, 0.03344846363630026, 0.06555108698986231, 0.04058469522504076, 0.012217827813489544, 0.044022916981409636, 0.04993032821784577, 0.01939439871949294, 0.05132870681043114, 0.06690294872368537, 0.06130971397543627, 0.030654010460561806, 0.010287872301564823, 0.05504279299789379, 0.04116863808444431, 0.002584439986798492, 0.0752162361036866, 0.05474058280308401, 0.04196617774845612, 0.07306117714653093, 0.06576120192485471, 0.0221918415533559, 0.055245982498050704, 0.020314173457483133, 0.12420241075057177, 0.038927214205144875, 0.03437280234309935, 0.03303151645307099, 0.040423805269623, 0.021936642344019586, 0.04066274809320608, 0.05242776719012088, 0.03718310013233173, 0.011893899983636314, 0.05445650590944195, 0.022795917203409538, 0.003631388911256387, 0.01249619064882638, 0.011747369388749283, 0.018173331176982294, 0.07822688503731644, 0.07456870794656777, 0.03969818977038226, 0.043841959352815346, 0.047321350674235055, 0.05807672334354251, 0.018779132440085375, 0.024030668991467646, 0.016714107966230764, 0.053225249397538366, 0.03427350202635412, 0.05082145318268769, 0.06308421492576599, 0.11464224632589087, 0.032493025590215004, 0.0759857637627471, 0.021736281623523084, 0.04712841909138426, 0.09549478264225107, 0.0868068476237597, 0.0324404068411358, 0.012727550159568989, 0.03884363401260588, 0.04752230702809269, 0.06163181564319999, 0.03898646344520873, 0.09114584705281643, 0.05063566920017043, 0.030847183361108747, 0.17619274556636813, 2.833250549531752, 17.25783451910942, 39.21920668694281, 35.441795549085064, 18.256193437883933, 17.773981171269572, 55.01666630468061, 38.481169592949655, 25.38111609797324, 29.12578328963249, 8.903531220651443, 0.8375422932928609, 0.06653733326182251, 0.4724286803074422, 1.342518096489291, 2.6652976005308093, 5.31772296274862, 4.30041213189402, 4.815842461201453, 4.1614729550576985, 3.733574973960077, 5.550621046173958, 0.9983909718932645, 4.221094942861988, 9.11391931195413, 18.145753222127116, 23.75069860489138, 34.94070491483135, 42.39795038777013, 49.54559926063784, 53.73402772411224, 56.705505540294034, 57.184026856576246, 61.045137451541045, 60.98231677086123, 60.9687767490264, 56.173510551452644, 55.67039205181984, 55.89193536389259, 57.059122900809015, 58.14796893827377, 55.83630046536846, 55.35242511380104, 56.165414779416984, 56.50560194446195, 55.906299083463615, 55.74708223342896, 59.1841414666945, 59.237952463088504, 61.97775940741263, 54.6652925399042, 45.61666304065336, 57.25775564870527, 56.45112414513865, 59.507019212169034, 55.45144534880116, 56.060934605137, 53.146668480288604, 54.92165080962643, 52.524321694527906, 53.57523056768603, 51.08166610040973, 53.79271422663043, 53.543647643058534, 54.74607767597322, 54.58437012087915, 59.002068965665764, 54.19753420737482, 58.85019479259368, 55.6214879405114, 46.61783626002651, 47.99951860981603, 49.523131924290816, 51.008411915071555, 48.186615667035504, 34.824638059062345, 22.701140988257624, 15.739784106131523, 7.684448274873919, 3.2483853832367933, 2.4007180429274038, 2.1364873311211987, 1.9830608800534282, 2.259394065026314, 3.7328162404798695, 4.114086801005948, 4.179816899761077, 3.5193990988116113, 4.621152675920918, 4.35837495711542, 1.2323676458289547, 0.4015220028738822, 0.2686466571063765, 2.157456567210536, 9.744533473445523, 21.3983198519676, 31.17971281851492, 29.23647649826542, 23.5870651660427, 34.26690839952038, 29.276729822158817, 13.96794359530172, 3.444999581383121, 0.2488230748642837, 0.007518684226764187, 0.03838277083911723, 0.051004506061754884, 0.02502316654088997, 0.06730434049161212, 0.05694271020230748, 0.02365874288032853, 0.05593540034286919, 0.02385704282430872, 0.0175186324368922, 0.0772068772705332, 0.04169868665837473, 0.05028482774392732, 0.021773027030811198, 0.07334793917834759, 0.04590262095594118, 0.042330713026345744, 0.05717291962355376, 0.09550755332794883, 0.03145869389446753, 0.034981834582023086, 0.029558002941250324, 0.006568063916112747, 0.0355819687097063, 0.034712822807411996, 0.06684882461183494, 0.01435471420747138, 0.012635333283293634, 0.03337843170870216, 0.01681136474343798, 0.010814259932827084, 0.02126608558389689, 0.20438056769630603, 0.10782990138977767, 0.14446195064773484, 0.09084436847197433, 0.19532864132235128, 0.13012956407281662, 0.06967788006389333, 0.20201190044322323, 0.11376316043277902, 0.13149335379562072, 0.11033130869750055, 0.18748059147788634, 0.10337721451275772, 0.17480765859926903, 0.17175510465618105, 0.2507789739437642, 0.05784118961122248, 0.09135656719726902, 0.15268078704755153, 0.15758940349182776, 0.13497298643473657, 0.19624996930360797, 0.1458062817372622, 0.2748838079071814, 0.09955652719063145, 0.1979992697916685, 0.18116632626662332, 0.1208892720000398, 0.1724072906278795, 0.19177220070794707, 0.13037973774536965, 0.14273955516757506, 0.09898845767301899, 0.1959766138104662, 0.1622010689348944, 0.13510579543728984, 0.2442054186136492, 0.12062801303522241, 0.1772947170801701, 0.21832558957319106, 3.1290102533755766, 18.460535195565996, 46.76598418143488, 42.775894288093816, 32.42662252918367, 24.688729509230583, 40.47820906485281, 52.61316730130104, 31.826776419916463, 24.451024070862804, 13.699289675681824, 1.3145028126816596, 1.7595931551148816, 3.019394470799354, 7.146915879941757, 7.693599164485932, 8.533626217995922, 10.113897189017266, 8.969667284719407, 8.133468464497598, 6.465258934805471, 6.172528036179082, 1.6847332494874157, 3.0987545607551454, 7.893616018756744, 17.641269737674346, 26.0835616050228, 34.730901256684334, 42.08829495214647, 50.337431661544315, 53.14233033887802, 56.92793923039591, 59.019115586434644, 62.1783729522459, 63.21065448945569, 62.35280075380879, 57.7344609075977, 57.93047743458902, 59.29214392938922, 58.72625966225901, 60.933640157022786, 58.67266831859466, 58.03507920234435, 57.61362444969916, 57.79645396817116, 58.53348301303003, 58.73619502590549, 61.18908843686504, 61.369611601675714, 63.076262320241625, 57.339560601019095, 48.116934760924316, 60.72830800087222, 58.460448480421505, 61.6597257891009, 56.34401990521339, 59.14147000158987, 56.19244775464458, 58.500295839002064, 55.97468560741794, 55.22755645936536, 54.36055575647662, 56.49496055418446, 57.584143915484034, 56.502471893064445, 56.56833633299797, 59.76902177256923, 55.68125309482698, 59.81798079706008, 54.118855384088334, 51.302432783188365, 49.58725875423801, 53.36813726732808, 51.81395299973027, 45.658565721204205, 33.929749304248446, 18.458166083981915, 13.440042580327681, 6.6393847138650965, 2.653343196838133, 2.9373122559439753, 2.335644696028002, 3.0660655277390636, 3.1703836591013017, 6.167261273630205, 7.587512779620386, 7.385409714714174, 7.081708437012089, 8.109473855264726, 7.830342304322028, 4.842446427191458, 3.454151696735813, 1.193425496739726, 4.144506252581074, 12.331387592900185, 25.208076815451346, 37.28339149105934, 34.413930600689305, 31.475771357936246, 43.54225873947144, 34.181145775702696, 14.520396686369374, 3.1487971400060966, 0.22455975263109132, 0.15927919426993017, 0.11626695793482567, 0.1502025998648136, 0.12008573003714124, 0.2450112971447168, 0.2468538152114038, 0.1650491693327504, 0.09253348509270339, 0.19415629697182488, 0.11305397751951411, 0.16038495025807814, 0.18299621920431816, 0.14877303383283078, 0.15295377481848965, 0.19596395803795708, 0.18152917615107952, 0.15609421436825108, 0.141542864542815, 0.19769425954549544, 0.11146905651736645, 0.14568485680126375, 0.13164906882710997, 0.1245569792245665, 0.07891215068558532, 0.11638428430042921, 0.11765090343091758, 0.1594218245196727, 0.1899725835650198, 0.11780795145539508, 0.09154082666481696, 0.11419916405312477, 0.08735330580102821], [0.019303027412764007, 0.022736436221748594, 0.03920898517413486, 0.035251623935877316, 0.04416507225663912, 0.030985684396939415, 0.050952592113566016, 0.09842550562274072, 0.03175297507926101, 0.07761788344190967, 0.03917134344397534, 0.03569782418649524, 0.03741759581551437, 0.04420086771490113, 0.0667221213300382, 0.035775857902462446, 0.0549884045857095, 0.05070481629621598, 0.01484318240170157, 0.007724487044352799, 0.05633318383667258, 0.02328336171265091, 0.076876494192308, 0.0480882927865511, 0.026649140279680014, 0.018647717717554302, 0.019184389121590123, 0.05930137617753879, 0.06284539850669042, 0.05026738392189146, 0.053766118963399244, 0.012732118916427417, 0.03243735398075754, 0.02000966882934013, 0.143802716667133, 0.00028364866246251513, 0.08992894702861387, 0.062293876488242424, 0.021165509730757728, 0.05755030219593356, 0.0633024733753935, 1.407749073639993, 15.153121083013474, 28.594743397928056, 38.76916962285196, 25.128303650886785, 14.314380076623733, 32.61163092428638, 59.56023793066702, 21.359431512894172, 16.489128412738925, 12.990034934013122, 1.6462903445766819, 0.10308685952857619, 1.2266876860972376, 1.7248291882776445, 3.850171349702343, 4.280507574158331, 3.689723610877991, 2.500577174848126, 2.7288635315433627, 2.208319902420044, 1.2945739852805294, 0.6341989013937213, 0.5818478234352604, 3.9099249820555415, 7.6364149297437365, 15.121976483252743, 18.44071153671511, 28.95296758221042, 33.78175435527679, 46.97781570496098, 49.26524000783121, 57.96573954243814, 59.41740089847196, 58.390151762193256, 56.68593683550435, 57.835622756711906, 57.943527160152314, 58.97089788990637, 55.927338677067915, 57.745310183494325, 55.461670967840384, 55.588532186323604, 53.798660539811664, 53.44202687663417, 53.1134577720396, 58.50936435884046, 56.9430717345207, 60.65498321287094, 55.88643620091101, 41.08455650268063, 45.86025007309453, 58.003425675053755, 64.59603171194753, 53.8767235509811, 54.824026938407656, 55.06003202930574, 54.957293387382265, 54.69695391193513, 53.67881644156672, 54.478234706386445, 56.42957464341195, 53.176890342466294, 54.037678011002086, 54.54229093367054, 55.0390120475523, 58.59147525602772, 50.716458136035556, 39.405507503017304, 50.56747474978047, 53.69326645328153, 51.734768190691554, 40.1991638060539, 24.390743124869562, 11.069748401641847, 4.376836082627697, 1.866170571696374, 0.31413337275866543, 0.4274150699136719, 0.8434856034094288, 1.928415767127468, 1.6100820874975574, 1.7901476833128163, 3.420898577859325, 3.8089943076333697, 2.9023597701903316, 2.1216043877986173, 3.2438834828715173, 3.478289962776246, 0.6955661600635898, 1.1264895143047458, 2.803274080637963, 10.944337479529842, 19.153788628116732, 26.755357711545884, 17.620390961247107, 20.74623561674549, 33.73490556593865, 21.80281427598769, 9.61064434820606, 1.534471170556161, 0.0860389823754949, 0.04457145125695294, 0.07465325340989136, 0.0562219019047916, 0.03873907450226046, 0.0652911993224294, 0.040066176274370764, 0.02162876884422956, 0.03477391831937336, 0.02641133892710411, 0.007302989777658256, 0.009056582273314557, 0.0228309350824284, 0.030531838588837176, 0.006101082094133862, 0.034867530433280815, 0.021181319870295066, 0.04421635418229046, 0.013413237156196228, 0.1509071402852574, 0.04229649570920775, 0.02056614169099879, 0.048823174119236014, 0.009547328621509575, 0.053445499675769004, 0.027437697562779632, 0.05664101711684658, 0.03796975368693952, 0.03833053896443979, 0.065380257043627, 0.047165302394498745, 0.017472015986699733, 0.0367181230666897, 0.04056737014663316, 0.03912537433807889, 0.04629206175224916, 0.03043559687812963, 0.008985673175043157, 0.12794715577676413, 0.037644568515280565, 0.05517527641307923, 0.055257818556480834, 0.049697414506226785, 0.013735304350003362, 0.01771665658921965, 0.01771278018432279, 0.03239800387452687, 0.05670843668462289, 0.030383581423290798, 0.01893333444792417, 0.05357211485745446, 0.021623392822220925, 0.038807321444994984, 0.059383485481263175, 0.04297439542208468, 0.03542658309602449, 0.11143563976210934, 0.057494469708012, 0.03201016803242026, 0.0318949350020698, 0.027011800557374958, 0.0135513810035322, 0.07011647306142316, 0.030539432435386607, 0.031170526091309807, 0.018518128199502826, 0.09690525776316082, 0.07121141188808026, 0.035304066484733936, 0.0399148432658084, 0.06433096939637777, 0.017003857740952123, 0.034953136928379536, 0.05414647012648564, 0.06309313985008387, 2.379674772101064, 20.269608805256507, 35.44144645813973, 39.20596476524107, 23.145216049686557, 15.821552776521253, 43.02549823637932, 40.111055604873165, 27.23697573907914, 27.27685251543599, 13.586330317681837, 2.072034699301566, 0.05047603179850886, 0.13864660785803873, 0.5388310671814027, 1.7810355271062546, 3.666179338770528, 4.605777475141711, 4.603037699576348, 4.751841637396044, 5.912348397316472, 3.686058891396369, 2.1931896046284707, 2.609070178962523, 5.878869006710668, 10.907941806700922, 17.483168801953717, 22.534132349875666, 31.491419653738703, 37.01185364877024, 46.90312985450991, 52.37580899269351, 59.12561578135337, 61.89832748905305, 59.85020306802566, 59.28354217160133, 58.82615458580756, 58.395431272445194, 59.34655112604941, 58.05898212617444, 59.85670243540118, 56.897101556101155, 58.06743875626595, 55.59527081827964, 54.25298475450086, 54.993112471795854, 60.73172830766248, 57.965417908084014, 61.22869260849492, 56.07916970406809, 45.07263814249347, 49.28839375895839, 57.69491557152041, 64.83849302414926, 56.155091101123446, 57.45521560792, 57.031379976580226, 56.622884734984375, 55.294868253892474, 55.467283879556966, 54.49573632209532, 59.178850189332046, 54.828718093133745, 55.16726178507651, 56.86595009219263, 56.25613920150265, 56.94482111161756, 56.169619560241706, 43.751681927711736, 51.05167958044237, 54.225339889526374, 53.23025811103083, 43.063000017596835, 27.728903716610326, 14.186129358506973, 7.214438501865634, 3.43405322682473, 0.776165780280867, 1.1532679031933508, 2.0683182535632967, 2.780217653320682, 3.4142511410097924, 3.217448178798922, 4.8009953095066935, 4.294084858509803, 3.9916264818560694, 4.2970629180631335, 2.5820602476596832, 2.4278878108147652, 0.45313117064295283, 0.7713472710982446, 2.3084452652162124, 10.499878025824025, 21.688628196716312, 29.221300848068733, 24.912065344472087, 25.089395699962495, 36.15287811525407, 28.976409627545266, 14.450863849732185, 2.444992776839964, 0.16133883697611673, 0.07729522252996122, 0.03174240689634556, 0.14417597002560092, 0.029475098821304502, 0.06393998110246274, 0.039877714814558145, 0.04719131874040731, 0.03744070102731067, 0.05067172895876631, 0.016739591881031954, 0.020495161729594393, 0.01765102583674654, 0.0492262359588377, 0.07850508986701889, 0.031431170270567944, 0.029044206922633514, 0.04676202221983864, 0.013075443134913522, 0.06362146089574502, 0.10171340177616767, 0.06651774439359866, 0.04025140867358254, 0.08338514655347794, 0.05606338682193911, 0.010651583077325937, 0.008211288518542725, 0.05838095601047239, 0.027693320035694108, 0.0778238844847487, 0.029135379046502135, 0.03416818791940328, 0.051999340179346265, 0.06782704994322793, 0.14091441197501076, 0.3061448530324044, 0.11475212631687043, 0.15388878513007395, 0.32003696887723865, 0.16280327533041278, 0.16975196859528943, 0.2552687547980778, 0.1051320001903561, 0.14723408576701918, 0.1472530234605074, 0.11294844124706523, 0.0985012257531766, 0.14782331463310028, 0.20421071068173458, 0.18234821607268628, 0.12638641250950675, 0.13453856861639407, 0.10676297073763226, 0.14510506613840982, 0.2117349964476401, 0.21166352044430473, 0.17950218411222582, 0.28915731296423947, 0.17076216277576264, 0.10687666584647472, 0.12308648877566862, 0.16423248896195045, 0.16739390399907866, 0.10817372165019475, 0.13718048411030925, 0.13899933006013596, 0.1555354298362809, 0.177250130762977, 0.20333793735311878, 0.09965536785462212, 0.1868308569875456, 0.12967187250333448, 0.13496745527992327, 0.16684733090862153, 0.2026297809976724, 2.5584882738128787, 22.41438042732977, 40.81628599474507, 50.67236677292855, 34.860202189414736, 22.293689097127608, 40.700379956153135, 68.3918034645819, 28.119367822524044, 20.358595617355842, 15.703322733602217, 2.599883988018959, 0.3327296668243024, 3.5972885451009198, 5.214274862120229, 10.875072344656914, 12.271796984057273, 11.614111604229098, 7.681844801672044, 7.6481869432234, 6.546500046407023, 2.366262962741237, 1.481767753439565, 1.4842752511462858, 4.763064519051583, 9.495815000226422, 18.25506183408922, 23.81876349449158, 30.93747704259811, 34.997740099507, 47.80793043874925, 50.22289453014251, 59.58477235609486, 64.17637340484127, 62.2878384590149, 62.250709302963756, 61.92439163884809, 61.475778395129794, 63.52015303027246, 60.173912355976725, 61.1169207480646, 60.049082925242764, 59.99107107039421, 59.08279918855237, 57.73301747537429, 57.468920369302076, 63.188634303308305, 60.94729392759262, 62.39712745912614, 59.03584449521957, 48.873489364500976, 51.92484232687181, 64.89354348951771, 66.32923295420986, 58.21075823999221, 59.66569869749008, 60.19194349165886, 59.30406401234289, 59.27332047493228, 57.15468360531715, 57.58432434451196, 61.00228947977866, 57.527042050515455, 57.427915911520685, 59.43355321884156, 55.811934701858036, 59.31266969250095, 56.934113041047134, 49.99833099303707, 53.06744836991834, 55.32469003431259, 52.5846516701483, 42.70809219729516, 27.230852919240153, 14.044160150712537, 7.6113176441961725, 3.7500602054980496, 0.49363181836182074, 1.32286052550039, 2.897358257924357, 4.649926202912485, 4.478311231059413, 4.472850801483277, 7.87749360645971, 8.2112701477543, 9.115560823871244, 8.112970648273345, 10.41733370673272, 7.952412837936033, 1.6131738957858857, 1.4331276666733528, 4.436038376823548, 13.449039516910432, 24.42334390455677, 36.38080704596735, 26.51473991332516, 30.831547552539458, 45.65880106341454, 32.25073756710176, 13.68676947009179, 2.0091817816418986, 0.15709932172490707, 0.16346883719726918, 0.11011146444586978, 0.27620200007673235, 0.13925273662372945, 0.1330586246425106, 0.15040529140781972, 0.21670394997683265, 0.22134958375846187, 0.11646269339947932, 0.13978052523828324, 0.09801096012515408, 0.14310568390834716, 0.21710492039640106, 0.25016775835425625, 0.15210655818302787, 0.18471864532799492, 0.14438848281579633, 0.13446050425690992, 0.18637288962641071, 0.2202189452345333, 0.2335276391597525, 0.19622773743204533, 0.29474770169584985, 0.2322942682451779, 0.18200871654816214, 0.20041966330139868, 0.14073245077123567, 0.11833344180617603, 0.19427697114165754, 0.1423326705492312, 0.09463897816115811, 0.1611427337892594, 0.14678632269703573], [0.02404788298712623, 0.046807462725067334, 0.056821273774990154, 0.056981773025566534, 0.05680350436558647, 0.023925431493309238, 0.003160472509578892, 0.07323913171046204, 0.039263503821266275, 0.04326498406308313, 0.030679772082235546, 0.06066587453167285, 0.024132468670065847, 0.05507516404313426, 0.014073494821786882, 0.04927911517781116, 0.07952746484548816, 0.02450547113473858, 0.10488283009298387, 0.06424304165486848, 0.06881041572459283, 0.09252946313110091, 0.04675558708127468, 0.05249880269289978, 0.017631611253525463, 0.09629734401260653, 0.05216320255591024, 0.06169366575176678, 0.02383485883324137, 0.08498333619847413, 0.035869278494388826, 0.03911341570558087, 0.08868717979038916, 0.034580209157279426, 0.07235377921812958, 0.05237624394677339, 0.023701888952224005, 0.01320693925428655, 0.02259923562016939, 0.0717232428911713, 0.04405355666794124, 0.033144422491351445, 1.0490283418086268, 11.615377549202213, 29.46551742092256, 31.132410995421875, 28.87625974993552, 18.645684795994914, 28.431578682314967, 47.10337861891716, 27.43034858857432, 14.563133851174387, 10.07895867670736, 4.343795507184921, 0.15560422453188127, 0.3587568911813921, 1.6070113619489055, 2.214492487330591, 2.702713089604532, 2.6471490388916386, 3.236443727247177, 7.785580706211829, 2.9211883727581274, 3.1660388986910544, 1.851525299491421, 1.088786834189969, 1.3652863521729748, 4.004786769228597, 7.796894782973875, 11.343705365734717, 18.311473361907467, 26.537952500004923, 35.335220829133064, 42.662722141511985, 49.2034665999874, 59.46390059686477, 59.59715135635869, 60.92509331241731, 59.647553813072946, 56.906409340520064, 57.79046058654786, 59.36379778769709, 57.86600151369649, 58.650695200889345, 57.65753146140807, 56.800948573697, 56.43683887297108, 56.4447699054595, 60.083901805262414, 58.29963914809689, 55.996423382912916, 43.22969682755009, 54.25592653213009, 56.92657816794611, 59.03607591505974, 59.46614811497351, 57.19335817521619, 56.123770975297504, 55.449593990079826, 57.006386633842226, 56.07377644508116, 53.0594192781756, 54.87218579938335, 53.71578870281097, 56.32234488764117, 53.976049730854655, 57.07011730440202, 57.29979561221216, 46.71962961073845, 47.84662069812898, 52.71505871126729, 47.252793465891195, 30.826228818585797, 15.456313433185702, 5.041311085224152, 1.061561049953584, 0.12687237272339483, 0.4196021988266899, 0.5153437307284725, 1.2507596395669447, 1.1305856945053225, 1.6321059508669762, 2.302851475054218, 3.3036645718159217, 3.6869936412380593, 2.777025334296688, 1.6219156331592992, 2.732322326590938, 2.070103177139836, 3.4012533868512804, 1.4961363759733017, 2.5003756630805234, 7.461904268110953, 14.637351958982407, 21.08937240416004, 15.867408225613257, 17.89687098995332, 26.113938400822303, 22.39945188645394, 9.14419020375898, 0.9890091527373561, 0.10104502836662917, 0.06995120491351813, 0.023394555544420596, 0.05337117382535531, 0.06765402132464994, 0.08010763855230424, 0.06332870039548125, 0.033694910291101665, 0.010053715612288686, 0.022189187058698268, 0.0682651526444862, 0.05717090098187328, 0.018066103765440565, 0.053554207552224405, 0.054639374927407315, 0.05155596296272932, 0.011868727292054364, 0.08537213348092572, 0.013502756445368212, 0.02373838729615654, 0.07028277542802595, 0.05226808765362348, 0.030117373530482574, 0.024024053822241487, 0.06410040374424669, 0.028138405628382202, 0.03231174237425289, 0.03475994870607411, 0.024189379426740834, 0.01601981684460395, 0.04153169481264007, 0.021582857194927432, 0.006742222993184002, 0.035919296374965104, 0.03196046616311275, 0.03216705900887328, 0.019556600600481033, 0.01827878509497931, 0.060785050999613545, 0.024496666869268786, 0.05525869955759376, 0.030672586177505796, 0.013850890738408894, 0.05504530959672505, 0.049725587389642195, 0.04204975028011588, 0.05049260228031105, 0.025353813919449047, 0.026125015480624094, 0.040479128309074915, 0.02348065042057105, 0.13062119333734437, 0.023746178410346472, 0.030822130370764967, 0.008340712370080574, 0.05859848667657184, 0.03105723126340778, 0.05531350165725716, 0.04185312998390967, 0.004440174267191681, 0.06159962462862173, 0.05781376749397286, 0.04558740258817712, 0.024124238970539263, 0.007633331678657523, 0.028270214886194276, 0.023113054621423927, 0.03426810493692756, 0.04551507622724579, 0.07482815894388384, 0.019134869198164633, 0.044198829921022545, 0.03688750127630849, 0.03662503189257076, 0.02666386257436487, 0.006843321222526532, 0.053673472120276386, 2.1468291503767816, 15.672152638435366, 36.20221760965163, 35.65785931002709, 22.289590220297537, 21.102080883518344, 41.49953542217132, 30.5194975099256, 23.834956999747988, 23.25392650019738, 13.404273506133789, 4.731389909021316, 0.11975735410927765, 0.4020233920985653, 1.1682975676751908, 1.9861117486030826, 2.7544393462519494, 4.106559037200866, 4.990105032920837, 8.967032432556152, 10.547110226846511, 5.135722044975528, 2.1869371014256633, 1.6248719971026144, 3.248097579325399, 5.9526448672817605, 8.950796761820394, 14.145653440106301, 20.503886092093683, 28.889740936217773, 38.05538454363423, 46.41530859854914, 54.343560126519975, 61.49291130804247, 61.54807552214592, 60.69562289022631, 61.25995389876827, 60.29204630082654, 58.212107535331484, 59.74189073808732, 59.064454263256444, 59.00301033450712, 61.186209417158565, 59.16787931996008, 57.096008869909475, 59.006936627049605, 61.65943945607832, 59.51996303373768, 56.732989588091456, 45.35658636400777, 55.514262107110795, 60.586349579595755, 60.752434499802135, 59.469682170498764, 58.327170264336374, 57.99832267145957, 57.3632634839704, 58.746805037221606, 57.021060220656864, 56.17938626197077, 57.43647844560685, 56.170604075154955, 57.041138833568944, 56.4729089890757, 56.43164173249276, 60.98019476859801, 50.04079849489274, 49.979731113679954, 56.05159544175672, 50.53838645258258, 35.73300407778832, 18.634625673294067, 7.56923649580248, 2.838630815667491, 1.2720335947890438, 1.3990963250398638, 1.3003388888412908, 2.378181329657955, 2.978192178472396, 4.014590488326165, 2.8170158593885364, 5.3272861915249985, 5.35822682803677, 3.323256075382233, 4.386705746573787, 3.012319495601039, 1.2969476321051199, 0.5757853100376745, 0.5323171747788307, 3.1808833537563204, 8.81982195761896, 18.16762828057812, 27.05522487240453, 24.92095735765273, 19.520389033902077, 28.340697365422404, 29.971954245721143, 13.433360822739141, 2.3413958712931606, 0.184257552328129, 0.03794692426679596, 0.041203426137085886, 0.04958952251341074, 0.06365067565873747, 0.07445072274534933, 0.0345970094654589, 0.0407220816029416, 0.024445586041697574, 0.017376228183087324, 0.03558728152946119, 0.02803616736444735, 0.03861667663459817, 0.012295736082559152, 0.06928743569240456, 0.07753896106395029, 0.023725947943486037, 0.0415490964998401, 0.047951699309651895, 0.025275925760187452, 0.054888039406749516, 0.02564339898526669, 0.019978464152964375, 0.012514714654835482, 0.04285574372437212, 0.02449474207335903, 0.005195232440582327, 0.04930378703941261, 0.022984817248558807, 0.07427325081681052, 0.05148329186223207, 0.04716768875838288, 0.024969825753942135, 0.04110216463525449, 0.06301389188475667, 0.07870027374836706, 0.14733596013919, 0.14533434093238848, 0.22135174412640835, 0.16969293385984438, 0.11885306392345699, 0.12733085336343897, 0.08444107618303069, 0.20461724289963323, 0.1291585629505496, 0.147852900948736, 0.18031146407367724, 0.09093166419094609, 0.16979986441231545, 0.11958134540867423, 0.17987969691955275, 0.2740840121142326, 0.20469504678922318, 0.2319006675914411, 0.17307999243419017, 0.1887412504443238, 0.2666383422911167, 0.1081316021361178, 0.2162727803712891, 0.20439739098712323, 0.16196414858343142, 0.14379370747314346, 0.15580239615613417, 0.1881995190295481, 0.16339411298113485, 0.1352361529584854, 0.14315318135965255, 0.22615870070313254, 0.14290490758515176, 0.3641212839753397, 0.09142597476320882, 0.19110870727848625, 0.13043203090708103, 0.13947470293891046, 0.1316483793479781, 0.1686899562276179, 0.1309547326978176, 2.173024209276323, 18.783254085048554, 39.61187516489337, 44.12973173203007, 39.39694496893114, 27.27363617189469, 37.6168635583693, 58.988466185908166, 38.31173496861612, 19.83607707485076, 12.753395399739667, 5.475548842260915, 0.4825671798279209, 1.0938002361405281, 4.115745963588838, 8.986569758384459, 10.690697412337027, 9.625964145506583, 8.677963556781892, 13.844057494594207, 6.068081692341836, 5.831604936430532, 3.6519911452647182, 1.8802002769324089, 2.9883055196654413, 4.832004097200209, 8.908148830936803, 13.275400111752173, 20.924381825231738, 29.242407121965964, 38.656793717415106, 44.690563986378336, 53.67410567498977, 62.92774569603705, 63.127323735144834, 65.32019146027105, 63.681688001078946, 61.95197374589982, 60.38887393090033, 63.89127200649631, 61.99936774469192, 62.79659732695549, 63.44085447249874, 61.33592628663587, 58.45125836710776, 61.39707603762227, 63.638902787239324, 61.19025338080622, 57.784176949531805, 50.89119972721223, 56.3768462211855, 57.671538245293405, 61.54536516435685, 60.23847849138322, 60.28771992652648, 60.48365016137401, 58.54098650716967, 60.088910671972464, 59.5207396630318, 57.43964379833591, 61.244115368012466, 58.46977587669127, 59.6256003072185, 57.286518389178866, 56.20695660191198, 59.53116532294982, 53.78721114127867, 52.124581183156664, 55.914320330466, 48.98933264517015, 33.98064990197459, 17.666588637136645, 6.611816335108973, 1.7666520731103037, 0.6470382898565262, 1.4000417388254598, 1.557817117821786, 2.6631724113418214, 3.602063785637579, 5.326013382404081, 5.450548145078844, 7.446012785357814, 7.533788075370174, 8.090138531500294, 8.151971755489226, 7.958078211353672, 5.110144269081855, 5.639661300566889, 2.298642771859323, 4.456648470893983, 9.949172350668139, 19.803546897826656, 30.470075645754417, 25.976592686868486, 26.18073440367176, 37.90066272981706, 32.6495720109632, 14.346236586570742, 2.2825610541528274, 0.2238056463219466, 0.2266812033110088, 0.11925707571208478, 0.12466491335221838, 0.33269926845546693, 0.19865079692775206, 0.21176476662437763, 0.1020871913961826, 0.1222573058499444, 0.07671372349103613, 0.14959633320329652, 0.20622334623288727, 0.12674847332340095, 0.14675289062002014, 0.13374913033218155, 0.20645196219125103, 0.14924718097092646, 0.35917618642410926, 0.13442786891133557, 0.22994118322047497, 0.1721134193001255, 0.1201452320862201, 0.08200991147708508, 0.1152236074689896, 0.14326594950210664, 0.11951632752654054, 0.19044210353205282, 0.13550688843092612, 0.13757898772676147, 0.1795796049578536, 0.14629293143028213, 0.15259657866291462, 0.050677083913357034, 0.10829267978307702, 0.21672713179742137], [0.03964965426993947, 0.062215279697650866, 0.06361527090531684, 0.025370687005981326, 0.04636042743861195, 0.03582395290234878, 0.02271039306276268, 0.011827615183597852, 0.006696377897770295, 0.07635055951053098, 0.053212861755802754, 0.04622607476889126, 0.06013479556948428, 0.053089119403833346, 0.036502457824685884, 0.05147393026779737, 0.06060493606773596, 0.04065627848068553, 0.017850654943275358, 0.018293225852351998, 0.03672838098399582, 0.02916712381486451, 0.04036469392538552, 0.028978541696203813, 0.03349966129227992, 0.04438234628328393, 0.04277099141730897, 0.07155657280236483, 0.012133569633137557, 0.07726640230224979, 0.014591779158030067, 0.06900619715452194, 0.030266471477525852, 0.04848310002876867, 0.050670376813579956, 0.08453540458914735, 0.0074006516238554355, 0.07424286776973356, 0.041339544639472044, 0.06424576892787892, 0.05419179571852569, 0.06419796887184344, 0.009446147558910233, 0.5845010617086964, 11.178711845028786, 29.059126530924154, 32.953553738132605, 27.329663307436054, 15.600097717777377, 18.45224722739189, 50.07569189994566, 48.83572870685209, 16.984872856447776, 7.686772279201016, 4.369819452685695, 1.2820018082857132, 0.23384202632211873, 1.3159127821845393, 1.0771958626085714, 2.48503037037388, 3.837227773281836, 6.308917672403398, 21.510544746152817, 5.15494950356022, 3.1042877993276043, 0.5170540679847041, 0.15903390823833405, 0.2537723092903053, 0.5671360547984801, 2.324237462974364, 5.086982673214329, 8.930754430832403, 15.872602424313946, 28.067680789578347, 33.81098778017106, 45.03611695381903, 58.180712884472264, 61.020748153809585, 62.78028418940883, 60.381433194683446, 60.73306583589124, 60.431474793341856, 63.7201193840273, 59.09307972077401, 58.328664687372026, 58.55589151382447, 59.690750875780665, 58.91696530003702, 62.09080211577877, 56.35137434928649, 60.82672026849563, 52.21235206050258, 56.43414812703287, 69.71945516524777, 63.52438919005856, 60.53939880863313, 60.772760222035075, 59.49486378700503, 57.365589449482584, 56.32017189456571, 55.38809514814808, 57.17837079878777, 57.970246345766135, 58.62507035655361, 59.07351101598432, 59.63746939935992, 62.52137245670442, 50.17114670045915, 43.11093530347271, 46.73598589435701, 40.85718847090199, 22.072977327531387, 10.174302670263476, 3.2413479157032508, 0.7947432285835667, 0.9694983029077131, 1.9270998119346558, 0.9775595090562298, 0.7218259993580081, 2.7935630275357157, 3.3352347487403504, 4.424967487012187, 2.399426112251897, 3.402323948760187, 5.641437153662405, 3.202441925964048, 3.079558481131831, 1.7642601627495982, 0.8277442126024155, 0.5837010207676119, 2.732621897612849, 8.638253481157365, 15.74389769184974, 19.86234518789476, 15.41256723865386, 16.495208086506015, 24.492630612465646, 23.35396851262739, 10.919408855899688, 1.9961950591494961, 0.13433560128173522, 0.014400339531411809, 0.02814529084360167, 0.05108244018629194, 0.020304156857873165, 0.04298294113288003, 0.017032833101468223, 0.026591735396293864, 0.04970558100349961, 0.05549647792753193, 0.0412550987675786, 0.057869917908383, 0.09181183026803118, 0.04107828184421505, 0.06756455757685247, 0.00558697916154239, 0.06374295094921704, 0.06373953036663514, 0.008275050016480589, 0.07302302596790176, 0.017335977923545628, 0.02063977997750044, 0.05374338913468584, 0.012299380745858917, 0.02650395704192981, 0.02873993978174704, 0.06807924608790106, 0.013528112040442086, 0.012891965077048349, 0.03596567533790104, 0.017829782877778335, 0.09125219537846505, 0.06206963872236591, 0.015331970437640145, 0.03633603671445482, 0.033253241450555866, 0.11804728498381954, 0.019483688182287642, 0.04335247513447558, 0.04814936148543512, 0.07758715565526679, 0.036932374876473224, 0.022611320657174916, 0.027516388199141914, 0.014823048653441572, 0.049530533743241144, 0.06436232537511857, 0.05786170544583471, 0.017505034376236222, 0.0904577622009862, 0.07483303126308226, 0.04608866540835269, 0.0329725468350995, 0.07740621334843098, 0.06844584214230699, 0.008181036664022794, 0.06020748199174001, 0.04907832736329687, 0.040253063423498985, 0.036008457518032486, 0.025065207530954675, 0.03904830206245665, 0.050311096898850896, 0.05232388949802807, 0.004984324125783338, 0.018764157336385503, 0.08202730167296626, 0.04708270662494245, 0.023080032401447816, 0.02594760675433903, 0.06690939152312857, 0.041113759375988476, 0.008083977154456079, 0.013288424196352643, 0.025322287486145095, 0.0585674103199234, 0.06687582921116583, 0.006942320849761488, 0.030525181284775178, 1.4198206581415669, 15.880287328074056, 35.43484903150989, 36.740053007679606, 28.83388246259382, 18.021374863962976, 32.42055266134201, 43.51680647942328, 32.67145883652472, 17.74828572427073, 12.128195089678611, 6.352636900640304, 0.8041707678667961, 0.22786281732541902, 0.7227152742205128, 1.0907177434813593, 3.4360345140580213, 4.055267673346305, 12.556757177076033, 23.65747759419103, 6.745229872965044, 3.7973294238890376, 1.8508294465080386, 0.8011043936975542, 1.1988796750383994, 1.6680561895332031, 2.8570093262580136, 6.377982276101267, 11.329764281549762, 19.576071000868275, 30.014990491251794, 36.46859753516413, 48.88851204226094, 60.649974346160896, 64.28184593877485, 64.05906708009782, 61.34436722724669, 61.28226041793824, 62.47009923381191, 63.863619296781486, 60.33591016646355, 58.38045174075712, 59.94764258784633, 62.96744008218089, 62.44820064113986, 64.19331804398568, 60.09950499380789, 60.068659474772794, 52.68676665521438, 55.35223684003277, 65.86184332447668, 62.00931487544891, 62.335361896022675, 63.16462547548356, 61.83496159891929, 57.86791563034058, 58.25358659990373, 58.176590473421165, 58.89703573719148, 57.82529907841837, 60.20640527048419, 59.76312252783007, 58.407108168448175, 63.040286341021144, 55.6906863950914, 47.985547127262244, 49.88737890797277, 44.55514023380895, 28.68287317214474, 12.653061170731823, 5.041340993296716, 1.7337397101425356, 1.2212163474290603, 2.0674197856457006, 2.8266842567151595, 2.4168380037430794, 3.1850866636922284, 3.318167045231789, 4.058111146573098, 3.918764288386991, 5.463809188335173, 5.016758028537997, 2.806162415973602, 2.9036276763485325, 0.43239672518064903, 0.16728541062724206, 0.32042090150137104, 2.547579672067396, 9.500691486943154, 16.72383716029506, 22.609124145200177, 20.77845592652598, 18.841915092160626, 26.70746753292699, 29.180451323909146, 15.1291161775589, 3.645650879029305, 0.1863740847235726, 0.06438097195519556, 0.04000658229474099, 0.12916721974409398, 0.02264222847448001, 0.047936703138534105, 0.0412351421771511, 0.08993185050184689, 0.0719610289219887, 0.0972572751643677, 0.07362048261828961, 0.10546240625121903, 0.043079380111228076, 0.017813610761696776, 0.020708300796667897, 0.07653958404496794, 0.07478478304561108, 0.03973863921278427, 0.04491991401019116, 0.04826247053701551, 0.014118273618570982, 0.05273897125716171, 0.059037880235982526, 0.09333181765771682, 0.04616337430272852, 0.023627009603285024, 0.060499269560339956, 0.0332122978814427, 0.0164917413701093, 0.03704286390735257, 0.02808617758414438, 0.002731765637309441, 0.04883747698078233, 0.06667001202942864, 0.050303949298517364, 0.018701759474952857, 0.2038110885769129, 0.12150169034758884, 0.16760460882177278, 0.23457906419231048, 0.09953281676937496, 0.06833153416312511, 0.0939079081158965, 0.19058539261741025, 0.12751297544567816, 0.14590028072557143, 0.14762286006683303, 0.19715180800807094, 0.17112322001447602, 0.1359809129949539, 0.09109806614897906, 0.18075030988022206, 0.16003550691229684, 0.15958267234025464, 0.15002823825324738, 0.10091389709663007, 0.11940555887356882, 0.15573652791640452, 0.1706935366195056, 0.1664959110559956, 0.1156668506202198, 0.21120912305289702, 0.11868708331378237, 0.10032705076399351, 0.20717075184708644, 0.14359970336719868, 0.1664428824498769, 0.17333499246066617, 0.15687605306025476, 0.11918081165922266, 0.13153208720107235, 0.22422892522187005, 0.12973688272458891, 0.10490976574440157, 0.18551566788265783, 0.2705206307432344, 0.19016851821253378, 0.1540142703320711, 0.13647392121774538, 1.3399684333032178, 16.60470889460656, 40.03434188904301, 46.80203860805881, 40.64918910303424, 24.925693619635798, 29.36302981069011, 58.06234359741212, 58.11245187636345, 22.17142685767143, 11.570581140056735, 5.8308724338008515, 2.1229541734341653, 0.8585125099747413, 2.5044782171326303, 5.90923942865864, 9.933814310258436, 11.010749090102411, 15.588196266082027, 34.62592686376264, 11.822003106917105, 5.843606898861547, 2.1922818210817154, 0.7885812463298921, 0.9480377286672593, 1.1534729696089223, 3.1256884961358966, 6.380625463301136, 10.665567767235542, 17.48437689196679, 31.421081750623642, 35.156886346878544, 49.515271494465495, 60.11287243135514, 66.34830351798766, 65.66211231293218, 64.69291425520375, 65.05947935965754, 63.52145917953984, 65.54710057473952, 63.07032777417091, 60.88742679165256, 62.75488684254309, 65.85579502967097, 64.55328964417981, 65.37988993429369, 59.71208072477772, 62.08786426051971, 55.768419927166356, 58.20559247847527, 68.21516344624182, 63.20266854378485, 62.41914764527352, 65.11436900784894, 63.680189655673125, 60.736952904732, 60.28067534969699, 58.67635926892681, 60.734819135358265, 58.36277361839049, 61.44197933135494, 58.94603006301388, 58.389245694683446, 63.6464298156, 53.76654417284074, 53.39373857744279, 51.85575369865664, 43.97999525070191, 24.827485315261352, 12.494529754884782, 4.487996543607404, 1.6085212293171114, 1.870802890869879, 4.72388151191896, 3.295742609808522, 4.327641225630238, 6.111030665136153, 6.4033193165256135, 9.178225590336709, 7.448047514884704, 8.349984768898256, 12.947875338215983, 7.253997566238527, 8.308660637947822, 5.347565335612144, 2.4549019096359133, 1.1833125232688844, 4.059405038433691, 11.472621906188227, 21.67620016682533, 28.106875073525217, 23.713459622475412, 25.281666363439253, 34.507365380564046, 34.42553689402919, 15.441028937216728, 3.5019298426566587, 0.28610028506767365, 0.1323520464281882, 0.13202515671089773, 0.40791537432420644, 0.08788426601958853, 0.10193741354610651, 0.1416358063297887, 0.21760172841529693, 0.21197021608391117, 0.1430221803246006, 0.15633709488376496, 0.28319598445969246, 0.19205766039029246, 0.14958073565315816, 0.13945277750251756, 0.13765495300533312, 0.26906766838604407, 0.27780416571805555, 0.13675372717120957, 0.19544248198789937, 0.08932566044912224, 0.12936103998893692, 0.1692719379019353, 0.16561449625559393, 0.10737037887015652, 0.0980653906721742, 0.17267267880660875, 0.13109989103771028, 0.22964319033968836, 0.10203375676346403, 0.10836283045430338, 0.12564308505745667, 0.14211330893299273, 0.1094289567141283, 0.14840721152722836, 0.1561160172305761], [0.0514187221415341, 0.052329838170760104, 0.01216800815816368, 0.019014805983451587, 0.018628452521478458, 0.046981839658392054, 0.01611895341005537, 0.03207513228839925, 0.06786368426776702, 0.05685881974415914, 0.03368887351825833, 0.032589866764723294, 0.04764135709152587, 0.11103817802523414, 0.029783238536648216, 0.023469630245780273, 0.03705163561408559, 0.08068623411799632, 0.01645008342400674, 0.054111203268891385, 0.026211299963535804, 0.035148634905776674, 0.07696802637750104, 0.022318326500094226, 0.0776835908031752, 0.014546421964863136, 0.07721086092773946, 0.049437729852093805, 0.04338622896841938, 0.04972933355959193, 0.05352746725322739, 0.08649520305616241, 0.041165857185279174, 0.057360254934117685, 0.0923293150000034, 0.030097526107584278, 0.06821447592829505, 0.11097416371828127, 0.035347798613891486, 0.06926115121572249, 0.06136055540053114, 0.07749488802566644, 0.05725545027563649, 0.018698566803528417, 0.6622230718212744, 8.560774903143606, 24.601854893469042, 30.86699401178668, 29.310660285334436, 11.648467644568413, 6.976057925531942, 28.000384684531923, 45.67784024823097, 31.20593386311685, 10.135126036982383, 6.198780459742393, 2.7759030461311345, 0.9324958271557285, 0.43298131155390895, 2.445621091511942, 3.131071213752993, 13.439213979628779, 21.090700126463368, 4.043942810066285, 2.310498380853284, 1.9768251694979209, 1.6251693617913032, 0.7208534354163755, 0.22070905764497098, 0.04714876255621353, 0.40714039978000427, 1.3822144438182156, 4.022690673028269, 10.374696562367102, 18.173970753146758, 28.858481607129498, 38.641959313423406, 51.10041110746322, 60.02088892844416, 60.608973810749674, 64.09283476491129, 62.16452306316745, 64.07272085066765, 62.4034385527334, 65.18856848439863, 62.46492562755462, 63.85336622115105, 61.10200397429928, 59.616233687247004, 58.11331087543119, 61.623663517736624, 58.201266104175204, 53.394134736830196, 59.25753685735888, 61.89003559850878, 61.35532240713797, 60.64242770594936, 60.014260122852946, 60.063183846012244, 62.78576374053956, 60.795843370499156, 59.918134597039995, 57.68512533557031, 58.81351278674219, 59.75840391651277, 60.9489687796562, 56.28592175822104, 39.51222735066568, 39.946249377342966, 32.98396779644874, 13.178245944361533, 4.426808059215546, 1.0934099603083827, 0.4526688212588911, 1.1238229154579102, 1.405035038628886, 1.6304743674493607, 2.938572072213696, 2.6549028292779, 2.151285453188804, 2.791871015102633, 2.1325120089515566, 2.179897427558899, 4.656735437531625, 2.3761907267955045, 1.7159042026727431, 2.1408730312701194, 0.7126075101475562, 0.7650370355094633, 3.2380504281290117, 10.830050399226527, 16.981882049191384, 14.985510360810066, 11.499750979485052, 19.095774812083093, 28.291754030412246, 22.4034527040297, 12.135971188545229, 1.609265866779512, 0.012262062687847403, 0.014437205597547995, 0.008294000158897571, 0.04383852727891457, 0.0351385455278139, 0.026608903426676992, 0.04295971334701584, 0.024851989939868934, 0.024984636148738287, 0.0736498314466688, 0.055239509055090535, 0.05565548330665596, 0.06658697575931588, 0.07303856989188541, 0.07115274487483887, 0.005044477828402794, 0.047074566940746965, 0.06060514291147552, 0.0643659642927589, 0.049383475505296266, 0.01497083850535414, 0.0631478959844718, 0.10147095793077063, 0.07651215043639945, 0.084829360186573, 0.0772818313130448, 0.06645020608219408, 0.048713297958696083, 0.025480544014323144, 0.06080148741602898, 0.06227392372825454, 0.014313089777715506, 0.02110561123117805, 0.061362420824626764, 0.026689087934491616, 0.046924471164182316, 0.032189064884498235, 0.046621950703763196, 0.06731128890908535, 0.03940908733995692, 0.09442892451319965, 0.03952254496154286, 0.049381311306910175, 0.014001876134575616, 0.07262930274009705, 0.042901938826206236, 0.02549369965920285, 0.05310066434885225, 0.03391493840383426, 0.05259467093574424, 0.06563105124739871, 0.011500862404523839, 0.012841017357253981, 0.02127086980298402, 0.038181921737569, 0.07007299757172024, 0.11356125029945567, 0.07309061790546102, 0.014700942856800413, 0.029317093186921654, 0.05336563117922314, 0.03206991522963489, 0.06914666703631801, 0.07707711729791857, 0.04056080477312207, 0.08855303013396841, 0.06370048286513456, 0.030259618821043163, 0.037186773523928664, 0.06688394974316321, 0.09902352917819254, 0.023423823933567733, 0.02844954074750985, 0.04865797874968379, 0.04737845869855054, 0.041688110814580036, 0.0644974556240824, 0.04817424019077613, 0.06619469277680883, 0.030976041265192534, 0.06828968277982167, 1.256271305103456, 14.077779766052002, 30.250495479952907, 37.09682003144295, 31.40947545728376, 13.931077238052124, 17.93582993168985, 39.99965244723905, 39.81239849521268, 22.185070822315833, 12.460767953626572, 10.474957246934215, 2.3037595037491094, 0.31652160589733436, 0.17324496180780474, 0.6722940636738655, 2.352247108374873, 8.897986950412873, 11.599888109391737, 5.105433992801174, 4.199343929367681, 3.6972545616088377, 2.86119302434306, 1.4466262584732426, 0.7752211632267122, 0.3027691632028549, 0.5754187522876648, 2.00138263885052, 5.665412151044415, 12.20892825434285, 21.12556019136983, 32.04413652420044, 43.05473950601394, 55.089543942482244, 60.60236853937949, 62.336201283239554, 63.848306363628765, 63.59865534690119, 65.20035520676645, 64.89799537966329, 66.88959844650762, 63.11974571597192, 63.30257915681409, 63.025753959532715, 60.57482173365932, 59.6701741218567, 62.125879872229795, 56.21330691922096, 55.340344213670306, 60.58386279690651, 63.528005615357436, 62.530346839658684, 61.50956569179412, 61.947439485980624, 60.75545472483481, 62.92257993452011, 60.810787600855676, 59.01660526952436, 59.11432719999745, 59.92195890795801, 59.3167568022205, 62.76459863108974, 59.69513216326314, 45.29063170956027, 43.76576323663035, 37.89914477256037, 18.457212948030044, 7.255375789057824, 2.3452010606565783, 1.3252729057304322, 2.4771785207333106, 2.5010762964525535, 4.8774261243881725, 4.689292580850663, 4.054845773404645, 4.04266240135316, 4.029242256956716, 5.841112761728226, 5.068504877628819, 5.172878657617877, 3.0862037116481416, 1.6590836451899622, 1.0429893626320748, 0.24955815154938932, 0.6346805561934749, 3.8970171972628567, 13.272334779462508, 19.079757813484438, 23.401140897504746, 19.106480921468428, 20.21159302803778, 29.44355214795759, 26.622144214568603, 16.9088985073951, 3.5746682363171733, 0.15400642559172648, 0.040517348435617266, 0.03211746056143555, 0.05343377853052751, 0.03746971660744279, 0.015958985632976458, 0.07575321777333176, 0.0589137586704906, 0.015787613679534726, 0.05516205373550615, 0.01741377606747612, 0.049391155536737175, 0.06293648253044774, 0.04025688237180153, 0.04470830137330679, 0.03568535993596719, 0.030200731557523532, 0.028301871554445357, 0.12290412920617289, 0.02369149888475095, 0.04004712749813353, 0.0912625145828051, 0.07005286478107015, 0.04061540002904592, 0.04283680986132353, 0.018576132546689723, 0.0815666146997002, 0.04518441352692824, 0.019886313351772485, 0.025957044957566167, 0.03495562288369383, 0.022772331271440755, 0.050629168944132906, 0.05580288245372715, 0.03184656421053073, 0.04442299873898587, 0.029917951267693314, 0.1912137226111466, 0.12412856753555038, 0.11604425617523732, 0.18304820593085983, 0.10327373135594592, 0.20580748306407085, 0.16535751972227328, 0.16982557432305428, 0.12382846025209274, 0.10877219719752189, 0.13476336945689496, 0.1509691014765732, 0.1100773582114808, 0.23715187855545553, 0.14764515322542962, 0.10753595345323125, 0.09289312506875685, 0.17800812879877706, 0.15254042441806487, 0.18474674543305752, 0.147621848830773, 0.08408787900642042, 0.1286437978307086, 0.15982746807557924, 0.1625090822457306, 0.1836585175366171, 0.26714291844156485, 0.14044614839217356, 0.19958223726960922, 0.1910468839829968, 0.12436284488367459, 0.14212990239743264, 0.1618350014811562, 0.2133961355373744, 0.19922516368810209, 0.08789375784897036, 0.1657990315147946, 0.16138641103621454, 0.20742360682737446, 0.19384713452910224, 0.20791175805272596, 0.24183708843925308, 0.11233739419690064, 0.15881054764313085, 1.4194634773077504, 13.354898710404674, 34.3306782937819, 44.994053456091116, 42.159940965714, 21.756724465277888, 15.13785227652519, 35.08817818857009, 56.819140526556204, 39.118864613194624, 14.52533789219395, 8.615593948671895, 3.240342563198459, 1.7488347066025582, 1.7219065322029976, 4.848772719983132, 9.243310459198492, 22.017552275811475, 34.76047985015377, 10.100576819912082, 6.881587149635439, 8.284563556794199, 4.672201343121068, 2.879945630988767, 0.9133250590774321, 0.30813971534371376, 0.8379890144832673, 1.8368392101218625, 4.994784910832682, 11.786955748834918, 20.034372498912198, 31.891732831155103, 41.931659021685206, 54.33986133144748, 61.894773821676935, 63.44458464653262, 65.05140712184291, 63.979239002350845, 66.95956568564138, 65.05838894074964, 68.64876577931066, 65.41796045918619, 65.8726063082295, 64.45476362782141, 61.71501944142004, 61.346861854676284, 60.77531760738742, 57.65092226766772, 57.85116318733462, 60.05770037251135, 66.81923897035661, 63.94248247146607, 62.90081470243393, 62.87953192187894, 61.509326427213615, 65.1173774657711, 62.92326634930026, 61.15723486869567, 59.33093224802325, 58.610098669605875, 60.27099494011172, 62.745316259322635, 58.76735825692454, 51.11467676777994, 48.25637894292032, 34.10858192751485, 15.605051671305011, 6.0154081832978035, 1.9098113525298335, 1.0127209835956175, 3.203377656398281, 4.306853154013234, 5.384283623387737, 6.364711426919507, 7.817162650246774, 7.38995623204016, 7.7866662221570175, 7.842553623260991, 6.942952140685051, 10.615766413750189, 9.958352658056445, 6.4036654656933205, 5.4500975628053, 2.6950259795111995, 1.1744515213274187, 4.382805439733691, 14.529117095854975, 23.066611751433342, 23.67611473606479, 18.69003111316312, 26.867445322775072, 38.30516499857749, 31.860032235422445, 17.762574918808475, 3.122059568282097, 0.2938428292832067, 0.07280632267676054, 0.13366116811671566, 0.14641852388458867, 0.11296249896047578, 0.1568109355866909, 0.122920255356979, 0.17164236715724393, 0.15314070027201407, 0.19336302824799093, 0.13240556533057846, 0.1777059377561654, 0.15794851486721348, 0.1276517216296446, 0.2610925092331825, 0.06467717985111861, 0.061257397831087156, 0.19992555191199626, 0.2642256556259048, 0.20632935747984918, 0.17297065636563688, 0.16337454709554874, 0.2558769060358886, 0.1760153655683802, 0.1623375551594842, 0.26120647247279843, 0.22668293466971767, 0.14991504110155568, 0.11804133248064788, 0.17976524338366526, 0.13503744507268553, 0.1275519616601448, 0.0898101497741957, 0.18980710857337524, 0.12660828689413686, 0.224732045805262, 0.1809359483060337], [0.02131328617613162, 0.030730956331676537, 0.014585827612468313, 0.01928000455541957, 0.03647688197933378, 0.04358701678293367, 0.016856422204704537, 0.05919330798450017, 0.03830415106588795, 0.01956347049394202, 0.03697329546294866, 0.04239768826312596, 0.016225236618230422, 0.036625066366527355, 0.025082176378477487, 0.05844459110390275, 0.09197262446245841, 0.05778800778751893, 0.006449645875217093, 0.005712790429712304, 0.07449853429270369, 0.02041932668596987, 0.03749722299436408, 0.026876003811916998, 0.029922293071004174, 0.08898314253817644, 0.013173885433183563, 0.04116136024916365, 0.05109734825729843, 0.004356821985810154, 0.028620345795887615, 0.032708192875068036, 0.020596279589939984, 0.05494362291609568, 0.06321417408124094, 0.02787599178601898, 0.058856742576726025, 0.07389016855027407, 0.07713374651728139, 0.038512120954692364, 0.011949236429626904, 0.015406816270232443, 0.09181486397621133, 0.06902106692113223, 0.05344675989040444, 0.21440193237316227, 7.4146039159067225, 21.608178423297023, 28.557369093741144, 28.215030508656657, 15.307962529120909, 7.794704139232636, 12.49070446337423, 36.86031679953299, 50.18490245265346, 15.162526926686688, 5.623987019062043, 2.706258176795898, 0.20282560839287697, 0.9120757841775495, 1.5748503780172718, 9.276785927434123, 9.859495201418477, 4.097068372272676, 3.9077164425003916, 1.843533592839395, 1.2599441144735584, 0.9424294134782207, 0.6793282217075748, 0.3792188544907878, 0.08876735855254436, 0.12288712205425387, 1.1368596481700097, 1.52633543937437, 4.282617319014765, 9.783972905528161, 14.831561253916833, 21.565920768245576, 35.26803062808129, 45.5040321811553, 55.95079052832819, 62.33452643117597, 65.17614241569274, 64.47418328254454, 62.386038918649, 60.73296385426676, 61.287453636046386, 60.554201833663456, 62.96574169589628, 55.87143705737207, 58.8490729947244, 51.58121916555589, 36.86614151923887, 53.0016270760567, 59.23338290183776, 62.30106469123595, 59.65193117818525, 65.77417442875525, 61.264139067742136, 59.98327339849165, 59.66757751280262, 59.78468379666729, 59.49356156010782, 58.10190070059992, 58.145286037075905, 50.489313679356734, 35.28096268253942, 30.86946510499524, 21.298728912107407, 6.768721928519588, 0.7984929531812669, 0.7761770570951124, 0.25723829024261047, 1.0833952912399847, 2.391799063451829, 1.6793938005162825, 2.775019287101684, 4.368028890702033, 3.021476023620175, 2.429668321724861, 2.6888793803030446, 4.180916144001869, 4.451555763521503, 3.1685570603416813, 1.922964285458288, 0.8359733452239345, 0.9544408753994973, 0.7432898218112608, 4.938749440254704, 9.981247532752253, 17.120390745901293, 12.414032913023426, 11.097744318746752, 12.401732360163043, 27.302659749984745, 28.912325943669966, 11.801716608385886, 2.946278549009754, 0.07592364169296718, 0.040330610673634276, 0.05522088162721165, 0.08056899202206443, 0.030522540196656223, 0.027425662321489186, 0.02924905117270687, 0.007007629366501445, 0.054198985453695066, 0.13483947263129298, 0.09344361286850707, 0.048396256301672234, 0.031422103619984085, 0.055815867644043705, 0.017159800683598847, 0.035066016153582645, 0.01497121963409647, 0.020026840690162875, 0.06028063955806917, 0.026955776547472325, 0.00589792275868897, 0.024215861171063398, 0.08381889021444706, 0.1012728858979479, 0.09489219320277054, 0.06751620210707188, 0.009057614576792525, 0.044106225212735516, 0.08329597391909169, 0.02942688890822953, 0.03710406284118372, 0.025710343578529936, 0.051501612854941245, 0.04692252530085464, 0.0703193101611349, 0.017427387534670772, 0.04439719306725649, 0.04268517807847069, 0.020017770209139394, 0.04041386910924508, 0.04046951390562519, 0.054983218170462124, 0.0215267259327154, 0.09653920563118112, 0.07346610824066786, 0.06791164137182698, 0.012497726655114564, 0.039902919107266975, 0.07515083517759077, 0.027655774066525123, 0.07537920598781879, 0.03663628572417844, 0.05352718763113503, 0.08030087657032475, 0.07668912440778748, 0.0278097941284819, 0.03665740293781123, 0.04011276208104626, 0.06518098225276317, 0.05781312398011646, 0.047069694621548544, 0.08354938048268519, 0.060627386274357, 0.027866639767683325, 0.04162975789738759, 0.0434503581885609, 0.04159681611664353, 0.03060026747745372, 0.010460037156008186, 0.00424809160552198, 0.017852365234566313, 0.057750170704938715, 0.010156247862464478, 0.0012781452824128792, 0.008307649930488438, 0.027457822692550482, 0.04076228972764746, 0.022088806557979797, 0.050379749868185296, 0.02503481873821828, 0.027008293789901563, 0.021947346507541595, 0.029872891891206947, 0.6791393350689643, 11.755526777236692, 26.92228201896914, 37.81702995300293, 27.55321095066686, 12.912149410093985, 10.097275164819534, 24.68687815050925, 44.94438056022891, 35.780492213464555, 14.716023918121094, 12.934527512519592, 3.715743143712321, 0.09875706081549007, 0.5652559524582279, 1.5813667831882354, 2.600657920683584, 2.650350428396656, 3.4229901817537125, 4.892967045307159, 4.256034926060708, 3.505917177084954, 2.9811866629508237, 2.00958737923253, 1.6155837019605022, 0.32127150424545814, 0.46259597244281925, 1.3044136185799877, 3.0806937621485804, 4.86579776771607, 12.032138205343678, 18.304062043466878, 27.47821915534235, 39.20106572489585, 49.49645980711907, 56.92633498099543, 62.515904672684215, 63.47462215731221, 62.97623011373705, 60.64813475455008, 61.35104310127997, 61.99333906173707, 61.35102348942911, 64.57673757306992, 58.80143580898162, 59.98320671819872, 52.57601853339903, 44.214431393531065, 56.4730501944019, 60.08637289847098, 62.60507191381147, 60.719992576106904, 65.48984181496405, 60.52536456815658, 60.90453224797403, 59.86557875910113, 60.22716245343609, 58.60916514550486, 58.56403827667237, 62.464847180151175, 54.89009534159015, 43.329744723535356, 37.245269975354596, 27.801449914132398, 9.079918246115408, 2.696902833638653, 1.036032058538929, 0.9980187757361321, 1.7486236340576604, 3.266219174669635, 3.3649687661278636, 4.351156325109543, 5.886441142328325, 3.7598173464498217, 5.177566870566338, 3.673434497848634, 3.338860734816521, 3.5550041689026743, 2.864457662067106, 0.8115842313535753, 0.5619958499746939, 0.13596182208388083, 1.0227708927085324, 5.068239627345916, 12.77251107077445, 21.17749237245129, 18.175174920789658, 14.98425422176238, 11.57146857630822, 28.084405775993105, 34.48678862664008, 17.438406713547245, 5.409684402327384, 0.1216787409277693, 0.007532230576485276, 0.03669311412640157, 0.030750179392916542, 0.023025251369202332, 0.047214558017590356, 0.030763762131814035, 0.14286127121698472, 0.08911830343065724, 0.08201414794330636, 0.08388788409290776, 0.01429110209667875, 0.04193032100316017, 0.04404341749426338, 0.11023874229360973, 0.0559246827728085, 0.039559171625202706, 0.08174240123480558, 0.04394927294924856, 0.04260470054202503, 0.045143106066051035, 0.04942772091336308, 0.04743087826476944, 0.07882128499688641, 0.0641950462464123, 0.033817323480522445, 0.01526617401865341, 0.06575405432452118, 0.06430625539994048, 0.024927794339976488, 0.0817309328985791, 0.0892924198940877, 0.015040167547281713, 0.0760545278148305, 0.018258225210311434, 0.00953104829550871, 0.03324623557648832, 0.07026550014533343, 0.10437627743569114, 0.12996611155329213, 0.06401087104853603, 0.19889474996635992, 0.1029598651333682, 0.17916089194195886, 0.1474497854829796, 0.18291754197449456, 0.14424796696872483, 0.14906001036926625, 0.11724604894557308, 0.22201994133572425, 0.19321944804922228, 0.09047306863771332, 0.21296243784168076, 0.17607535025285137, 0.16761721862900644, 0.12843862416282778, 0.0719546550704587, 0.1313091709368652, 0.16621595188494653, 0.11910628662594866, 0.16302039996991236, 0.12439399401867583, 0.15386249299251264, 0.14083319133327854, 0.16338191686138032, 0.18979993799040396, 0.10503007219203057, 0.1335290792368112, 0.118571434680733, 0.16413651346679659, 0.12310269919614639, 0.19012659788131717, 0.18437948288215747, 0.059706969937730225, 0.13540657687812083, 0.11786398312617695, 0.12758415267472306, 0.1615789442533447, 0.15608685992417798, 0.10710031755508916, 0.21623484369727874, 0.2758599571402996, 0.222725584922779, 0.7525613243060728, 12.040017266427318, 31.71175683698347, 43.66360118312221, 38.716554949360514, 22.655635610703502, 15.693538381207375, 20.148762541432536, 43.640239546375895, 58.590522120075846, 19.870438998745335, 8.686750646560423, 4.263896336478572, 0.5193450386005064, 2.1942280521315913, 3.544939612188647, 15.291530739876533, 19.713793262358635, 10.842214649723424, 10.685941538503094, 5.121020511273415, 4.683671334097463, 4.029201562366178, 3.4171036847176093, 1.1368918851498635, 0.4278836399316788, 0.45282213077429806, 1.7365711711106764, 2.9124321716447032, 4.908776158286679, 11.356395213834702, 17.034906610365837, 24.760571641306726, 36.5439776451357, 46.65211385296237, 55.41349249501383, 61.97215434043639, 63.24085281741235, 64.96748016726586, 62.040909567186915, 63.287595702755844, 62.975657447691894, 62.079258580361646, 63.21729113978725, 59.49440879206504, 57.375771922449914, 55.50913164692541, 46.25582894971294, 61.115775415974284, 61.62461273131832, 64.38740868722239, 60.526764854308105, 67.35664290766563, 63.043816474176225, 62.621573325126406, 61.07984650519587, 59.50106505424746, 59.006285513601, 59.64798919616207, 59.988109680914114, 54.6894347283148, 45.62592767900037, 38.62530492967175, 23.25007865505834, 8.481686192174113, 1.5890970393534631, 1.0732335332901248, 1.2397994341388827, 3.0325226437660957, 4.348008132749989, 4.949129502619467, 6.271635543915534, 8.94632722100904, 7.6712975482786865, 7.83726038471345, 7.3775517363702106, 9.42182635107348, 10.725543748947883, 9.252989888191223, 6.249167717272236, 3.7160093745877667, 2.0575667917728424, 1.2210644781589508, 7.067820795120732, 13.473439601159866, 22.319723829146355, 19.693396937462595, 18.346345193924442, 18.833560443693592, 36.89286462722286, 39.21014208947459, 19.436787636049335, 5.145599553661962, 0.2128746594873167, 0.07900742137984884, 0.15672519502620544, 0.14951197160107477, 0.13829301231570784, 0.2091912014950668, 0.12737278135553484, 0.1606424324094288, 0.1809304171512204, 0.18857189904778235, 0.20064156832954577, 0.1365112603431748, 0.08345006484418147, 0.17143028337628613, 0.24128732842303094, 0.24516502034760293, 0.09790387635509815, 0.1951806178136218, 0.17228064097223744, 0.12375160631152893, 0.10491725808430104, 0.1667607936166948, 0.2625554307333885, 0.16068691147431252, 0.1838762550464561, 0.17007041602365433, 0.15148852441099384, 0.12080434349275405, 0.18353721517468655, 0.10058785773693554, 0.11822467264268668, 0.17504260244388736, 0.13660895187527905, 0.11701572461113816, 0.1557732848150115, 0.13371245004236698, 0.2657214269763039, 0.21201149290127141], [0.003867180958848387, 0.003907889913534746, 0.03432805514744213, 0.005876021262543697, 0.03841816410121899, 0.02662881596704885, 0.061068063031040856, 0.03214349414432242, 0.03830166511057365, 0.10808502399032155, 0.037174657843406164, 0.04452870738121771, 0.05621587279282751, 0.06248165229936281, 0.036883781919436115, 0.040597285880076314, 0.006505307908575501, 0.06848746369923316, 0.008042966552649536, 0.04567083339357088, 0.0019449585060130866, 0.02669092271507027, 0.06857767055231719, 0.05557176138785097, 0.029955370832354795, 0.028647501697583545, 0.037054531426439365, 0.039233316126610004, 0.1821308922503264, 0.024818268664661917, 0.07658451510172698, 0.03924591827296442, 0.08236277923588792, 0.024437634049043543, 0.05273295746695611, 0.025835989658991178, 0.04051934792509964, 0.03652405001283173, 0.08830418945440362, 0.022846593919600693, 0.020461838820108005, 0.03515136983966635, 0.06303657574819461, 0.01762677340828363, 0.053182107156082514, 0.03629570601568107, 0.0699554413797394, 3.6075357371760957, 17.25894847223836, 26.525491129967477, 34.20626463428621, 32.43031936307108, 16.017308465896114, 8.449986577033997, 26.56563658868113, 48.67941441074495, 30.58699365585081, 14.174521103982004, 6.700335404565258, 0.8012778360036112, 1.2458460129076436, 2.649399743926141, 1.278304238953898, 3.619456800722307, 3.2850078180913007, 2.9299026535403345, 3.2098963904765347, 1.5017306564315673, 1.684008714172148, 1.7614714801311495, 0.24178663388855998, 0.2709550638833354, 0.5246418317960155, 0.8896370688753744, 0.14525201712404529, 0.8464335097420601, 2.0812613396875324, 4.144829357824018, 8.113869361339077, 18.383811673810406, 29.756618084446078, 46.50627620758549, 60.70940609901183, 67.20029723259711, 66.71918715200117, 63.61145796314363, 60.18258079405754, 62.303429880449855, 57.51999355131581, 50.84535114226803, 49.07628766952023, 34.52265870186591, 35.63518408806094, 51.04464677072341, 47.91617216602449, 55.59011682387322, 58.89252501149332, 62.751125289547836, 63.75398905046525, 67.37786293029785, 64.43584603648033, 64.35649256552419, 58.169298787270826, 54.860202958506925, 44.244225717359974, 32.591232638205256, 22.93028389253924, 14.853126445124227, 2.5051477166914173, 0.17195853164359448, 0.7016352311738077, 0.5772595083521259, 2.2246448070772233, 1.4591497735631083, 3.885036807867789, 3.2823523734846427, 6.412999235814618, 5.058468512950405, 2.6711554152350274, 2.4068531201731775, 3.3618286636567887, 3.8283563525446005, 3.017016779030523, 1.9913851301516257, 0.39144074544310575, 0.6548222947505213, 2.304020341365568, 8.290922699436065, 14.056634268453045, 21.693931241189283, 13.073021500341355, 11.463905419072798, 16.435761624766936, 25.18942790646707, 29.808579683303837, 13.437099822105901, 2.7385356060920225, 0.1511906694260336, 0.04487679092093341, 0.0055887584007465315, 0.04991944210844175, 0.02965059232777886, 0.05234623245233971, 0.019356144118993994, 0.07460501285329943, 0.07465919059130453, 0.02270272260742082, 0.04070960203065507, 0.012806622882283503, 0.05423927018719335, 0.021146708017876072, 0.026731031248345975, 0.09221797178108847, 0.03727245279738019, 0.013694968863180088, 0.0146267740544112, 0.06980793114991919, 0.041018369938096697, 0.025901511243935076, 0.03748894924478185, 0.052703903582427776, 0.04289868295252804, 0.12666198965762893, 0.042734456684200034, 0.03088523494830776, 0.03350590490886281, 0.043063365043170994, 0.0865685100096368, 0.0692479974860626, 0.04511179222214607, 0.043652919496619896, 0.040078085111153704, 0.034739888693776824, 0.057373504424768115, 0.02212875038235178, 0.06813037479596754, 0.031363043986681494, 0.10456954609722861, 0.011656480717412647, 0.06927459605879362, 0.01184469224103997, 0.0030864174233659384, 0.04375627241848458, 0.036301325270605665, 0.02750200872880317, 0.07570036536743564, 0.04315867021139111, 0.010987468582067278, 0.03559599194916026, 0.013232171317682633, 0.03826951240039161, 0.027633036576932477, 0.05368018305049308, 0.04691662259339806, 0.02545075851582712, 0.028207516335251353, 0.08575122442937667, 0.016090374500040087, 0.09094015244514712, 0.02590021272490342, 0.05395730003534306, 0.026401010146665, 0.010386241821482057, 0.03236264891682133, 0.07735241099350876, 0.05615215342972548, 0.07740173939495318, 0.023194832592121056, 0.03426492950248142, 0.03404228902992702, 0.019591580175103682, 0.00923838834428499, 0.022874351200317184, 0.036740688186499386, 0.008761511060349163, 0.02608230990928508, 0.026137699981430368, 0.011822323431260886, 0.05942733635404899, 0.021019587218160593, 0.07138702988384232, 0.015653220790198014, 0.15478785059625103, 6.181790713341006, 22.85383885906589, 34.04553374936504, 37.505668286354314, 28.099104858213856, 12.91639929817569, 13.726963958432599, 38.81189207876883, 38.92735096716112, 20.910708442811046, 13.91326379391455, 5.716599572089411, 0.5316580940158137, 0.9116568260135189, 0.3440540398080503, 1.0235183493744944, 2.1112520271731965, 2.708100219888072, 2.617582702828992, 3.3489927072678847, 4.349625620149798, 4.3362238618635365, 3.964361841640165, 1.6104001672037187, 1.8293395157783263, 1.9754585912150724, 1.6980749464804128, 0.8680674037145031, 1.6875811353806527, 3.425211469011922, 5.792924973272509, 12.023761983840698, 22.28002944300252, 35.36950234443911, 50.77722349474507, 62.82536791216943, 66.92799060575425, 65.86754645070722, 62.85815892680999, 58.420499140216464, 61.65130053797076, 60.54683170010967, 53.45895974866806, 54.76122979194888, 38.75558645494523, 37.99388570170249, 55.56381340949766, 53.343328275988185, 57.16077112382459, 59.783707126494384, 64.72046890566426, 63.70477899428337, 65.16311622435047, 63.02156094581851, 64.46367525285291, 62.29690305648312, 58.02031932338592, 50.62502768731887, 38.11701674615183, 29.977853490460305, 19.23746455100275, 4.570912997568808, 0.8245926494559934, 1.6388274224535113, 1.749499425772698, 3.066997826099396, 3.2708279596221064, 5.033284935259051, 5.038372739668816, 7.132882620057753, 6.4395512303998395, 4.9333782445999885, 5.422415435314179, 3.6389455872197307, 2.8116596177701028, 2.2898784808574186, 0.6847444020452038, 0.1313701975009134, 0.46671534978574325, 2.106288758016402, 7.2930481933778335, 16.9615484822181, 24.5522859404164, 16.045483831436403, 13.679249305878917, 15.74040972417401, 25.10070585435437, 33.09313520308464, 19.13728133324654, 5.165218268671344, 0.47757866041314223, 0.08448055269376886, 0.023529444475688284, 0.02009827838910203, 0.0521600998998169, 0.04680455925183431, 0.026591354267551538, 0.12182355452809604, 0.04961753834880168, 0.042204461736424316, 0.03371090620696064, 0.03369774098598188, 0.050780884996657415, 0.03602176063483761, 0.0511970469397643, 0.07835984725745455, 0.1271273114628369, 0.06044603794092133, 0.03804505246901705, 0.04955163563511545, 0.040298442641693744, 0.06311935537885274, 0.09740057957148361, 0.013239159954771882, 0.03461694690368829, 0.05275876696912512, 0.05317311328385146, 0.016905819554062142, 0.03524092168757512, 0.05260243523685683, 0.04770376261383776, 0.08556540214246319, 0.037052229332226905, 0.0019318399685172125, 0.0388070916186177, 0.027177704558257135, 0.05232334940604145, 0.03852815517494756, 0.027627177919531544, 0.16343980246493894, 0.1777425414371875, 0.10799792745421011, 0.17811772533722464, 0.14697767613876253, 0.17826475293165256, 0.1709190422608968, 0.09361857202865424, 0.14436386074990998, 0.19240341119227872, 0.17189934369056456, 0.2324002028833474, 0.11169023376198546, 0.16933566109547693, 0.13197652544946442, 0.1122154176775967, 0.09322256585883518, 0.1462334676855995, 0.08208583845126052, 0.15292967369239177, 0.1727141394850708, 0.1440784623545985, 0.14445258905330013, 0.163255006735844, 0.0833885939491372, 0.1591494955843495, 0.14845251796707032, 0.10268965826159525, 0.25168335606013575, 0.16095380118537336, 0.13268884932321887, 0.16778690710423455, 0.19170794125285842, 0.13891768040916613, 0.136464191901107, 0.136753803780002, 0.18552008054910168, 0.15896554255197126, 0.2151548435851451, 0.08047863961227479, 0.1304912648253864, 0.08171767191660982, 0.24740421874148233, 0.1313600544967959, 0.22590713275055732, 0.11389146483833752, 0.2722349516566723, 6.08870747589296, 25.644634654445035, 39.836532838882945, 46.51804724047261, 41.907665883341146, 25.174009069319695, 16.46356044277068, 36.70354750848586, 55.73397367231308, 37.23080819652927, 17.02884066489435, 8.637120896770108, 1.3170373992573832, 2.6757536588176607, 6.575601091307979, 5.861966533045615, 11.397511459166004, 9.560746896651484, 10.02327867092625, 8.068780735615762, 6.857062039836761, 8.50438298717622, 5.022019397827887, 1.256304032379581, 2.288767714654246, 1.8287974932501394, 2.158733298701625, 0.6297823125796934, 1.3491548693949178, 2.5155081672053186, 4.998163542439861, 9.787272599435623, 20.930820395869596, 32.493347929370024, 50.53662530837521, 62.18343280976819, 66.3581015986781, 66.10339072442824, 63.26854082845873, 61.04836948456303, 62.74557905812418, 59.79678038627871, 55.62768136301349, 55.22915678639566, 42.71512500701412, 43.069417015198745, 59.13198571051321, 53.86887488826629, 57.950744321269376, 61.85902533992645, 64.64717941899454, 64.03601138822495, 67.59597809084, 64.83413919325798, 67.16484685097971, 62.168398364897705, 58.42034616777974, 52.65810981873543, 42.127471585427564, 30.5265107077937, 16.40723030413351, 3.9231078230565597, 0.4249345385018857, 1.4483546754044871, 1.75982911019556, 4.7645515876431626, 5.2626033656058775, 7.934770507197227, 9.782092129030536, 14.797783763177934, 12.893435782001866, 8.083451870949037, 9.992475317370507, 9.278398021574944, 10.568934294485278, 7.055107903095984, 4.731028560669192, 2.006342966229685, 1.2426719574197647, 3.267519440381758, 10.58586226355645, 18.839934295223607, 28.53998907150761, 20.643206719429266, 18.0974413887147, 23.348430125944077, 35.298040682269686, 40.26994689818352, 20.977822157644457, 5.759867727756501, 0.4711504166405048, 0.1406308368689591, 0.09270520370093085, 0.13352010068633866, 0.14891814620744798, 0.1848568629112936, 0.1143713040097106, 0.20578704383825103, 0.1842730732694749, 0.1541007156934469, 0.1467250203413348, 0.08479461043832764, 0.15476741137043123, 0.09771751780663768, 0.148538044022937, 0.20961710041569126, 0.24405241553341192, 0.10194903509991785, 0.1316824855823671, 0.21075106376121122, 0.16736283147286984, 0.14899146082180162, 0.21540998150744747, 0.19030759381430765, 0.17301698936329735, 0.22908759273348317, 0.23866148545376717, 0.10901422735543982, 0.1268767700680802, 0.1654605738698475, 0.13419819575163627, 0.2745074748752579, 0.1685265037080934, 0.29344161371550254, 0.1311252945132794, 0.1439248310822633, 0.15664296314841317, 0.07375582737187225, 0.1160157423826956], [0.012977551462339058, 0.05496264870969519, 0.05306238676571558, 0.01902767817579931, 0.03921714784096807, 0.0598336962021647, 0.0035222601652475857, 0.0666802239814593, 0.015225042757998793, 0.02264613552289384, 0.06556630149603852, 0.05589580125806313, 0.035523133157121564, 0.04191322575112985, 0.05349664753603359, 0.016420895474091653, 0.0465824167364307, 0.042754888249140595, 0.07771467099026327, 0.05629482964474348, 0.017983963818199212, 0.04565576061366066, 0.07355421601283936, 0.06274062066128658, 0.05776779072719717, 0.034839778898223754, 0.07328686664902395, 0.11657427410565077, 0.008447771242278959, 0.045619034358570655, 0.060163876267089966, 0.02312125559265335, 0.05541180222926121, 0.04375536077385468, 0.017966949005400943, 0.01775976052627929, 0.001898408849111518, 0.0092293341426299, 0.0028240289576652072, 0.05139449844136835, 0.018723231004250628, 0.029446947005307002, 0.05391206637385392, 0.08243509027506075, 0.037511759512727304, 0.015012101916175698, 0.05453393441594897, 0.052251413749951514, 2.0716338820995825, 9.337096291203654, 23.168881670121227, 33.14083514675018, 38.98118549777616, 30.941319004181896, 13.902751841852742, 25.53609286585162, 54.13232480326007, 25.729263713282926, 15.338844330080095, 7.822244571101281, 2.1600252293771316, 0.12063222651880597, 1.1300390141625558, 0.3063850982054588, 2.2191115685047644, 2.953144167700122, 3.4605181938217533, 3.254975945718827, 3.521752275766865, 5.068710311766594, 1.5130942531170384, 0.8808885286411933, 0.8909245255974032, 1.0968790515776605, 0.4214066116800232, 0.38612032609601177, 0.012191071235124144, 0.17878019220886693, 0.1365232726018275, 1.435522028515416, 6.2295499828553975, 13.974422370233844, 26.866188203134847, 42.88283771084201, 51.277121728466405, 62.366379999345355, 64.56247975749355, 66.42325216724028, 64.2936561953637, 58.51065874099732, 30.836266163856756, 40.69592806600755, 51.710272988965436, 51.33583960994598, 50.4284934074648, 55.82529821703511, 62.77585191111412, 65.55185840975854, 60.084807872772224, 60.68245157118767, 62.333918463799264, 57.112125888947524, 47.902808650847405, 34.73295265628446, 27.347723860894483, 17.327862554980864, 8.278267172075088, 0.8773756171426467, 0.4142944046085881, 0.29053918236205656, 1.8146693610375928, 1.7144355201913466, 1.3374191378393483, 3.2782309430260814, 2.4453374551188563, 3.4387306532552167, 3.8512897154977246, 3.7860432940144695, 3.8337724103081614, 4.753742516040802, 2.6094499134248306, 0.9129036494320439, 0.7153576432216553, 0.5002227179225415, 0.6365685032740717, 4.4862736425092145, 9.151922175961158, 18.011190429810558, 15.44900409636959, 10.432038672508734, 13.193078387168146, 14.598424396207257, 19.693308684133715, 24.750883386981105, 15.30405192605911, 3.5857776143858513, 0.19957142010811837, 0.02136551038992982, 0.04908782302311832, 0.010178176171687103, 0.06403183121414435, 0.05520945542582101, 0.008374372358253647, 0.03185761311361867, 0.032105658976962013, 0.07303110053462368, 0.07196884301881637, 0.020502045029594053, 0.018351504075971824, 0.09221961120924643, 0.050397159216264566, 0.05490235759005432, 0.04668065602140081, 0.06262830834114744, 0.0751250869624557, 0.017214432328699097, 0.03633718967678086, 0.049433543181587616, 0.015398396006334695, 0.027987917231756355, 0.05274091329004976, 0.02641994209449378, 0.08222923478892735, 0.022940642703624985, 0.06291695877969747, 0.04196548060844502, 0.020986293036971363, 0.013600807081186965, 0.0817026182888977, 0.05276824347674847, 0.09398309198478538, 0.08504990157821486, 0.03999930445946032, 0.06618477959906863, 0.0884290004990274, 0.029895391893543066, 0.014937484952350779, 0.06555693990160381, 0.010317146436371391, 0.06724797940302281, 0.04529491404912645, 0.06713108970753609, 0.018214161748126633, 0.06667906718869364, 0.011485343378397727, 0.0413270267627893, 0.06585477956480558, 0.05564932012930513, 0.020065162323355194, 0.11829342137301162, 0.04205959450994288, 0.04089910920048433, 0.037196602431997176, 0.021130566545311483, 0.03995472963358607, 0.04561012092557165, 0.0627186262769805, 0.04018527996395865, 0.07338969097022088, 0.029497298134130337, 0.08444691377301371, 0.03169199639570809, 0.08358817517517075, 0.053648202710093996, 0.08652354830936079, 0.048929361566420526, 0.0484431064086816, 0.022362278879530007, 0.03469020406144761, 0.035341497540714285, 0.012647610799890133, 0.006956331640286672, 0.06018565614677726, 0.04218111903737149, 0.03407978520338093, 0.024173770385283618, 0.027517431993938746, 0.024048762073019342, 0.02990692726246292, 0.011712309374894586, 0.09339951684758549, 0.036926656030118465, 0.049104485435471426, 0.1130717124549612, 4.139813136669898, 15.140204718036038, 29.500242164058072, 40.88786532801967, 35.80722708855906, 22.17714959575284, 15.907096728201836, 34.55004469040902, 46.950033557030466, 32.587555416168705, 25.356589517285748, 11.467980761681835, 2.2055548765966972, 0.5190120661450971, 0.48203848722961645, 0.7149919434901207, 0.6642603754035888, 3.206205440144385, 3.924535320651147, 5.397568691161371, 5.218006997339187, 5.608037191052591, 3.427788221066998, 2.176891911414362, 2.194127541395926, 2.3237334384072215, 1.5799776512768962, 0.7757205912663091, 0.8078493382180891, 0.6359646421286368, 0.8656210704676567, 3.089408042930788, 9.334802685245391, 19.940641580089448, 33.742287466602946, 48.54303752222369, 55.8904605527078, 63.89951682859852, 66.2959163419662, 65.77128756430842, 65.88496177427231, 60.8265398394677, 37.572003410708525, 42.154837962119814, 53.897163021949034, 57.90871612487301, 54.79709594480453, 58.90804583026517, 62.7056924758419, 65.96901816706504, 62.18861033839565, 60.852505930008434, 60.511883381874334, 59.24940578399166, 51.74386808949133, 42.84685780925136, 33.80897952664283, 22.574411169175182, 11.1878058602733, 1.812962517142296, 0.7843496217843026, 1.4312750822113407, 2.2130796986241497, 3.0688817895227865, 4.392963397887446, 4.077420239487003, 4.873296358892995, 6.933913038622949, 5.547070320575468, 4.691063530983464, 4.489312498800216, 4.033856925464446, 2.9755158962741977, 0.9291770729807116, 0.8270723841363384, 0.35519951593972027, 0.4848120932377154, 4.439151758147824, 9.669575998860022, 21.254688539812644, 23.262844008784143, 14.724587432799803, 12.411195078203756, 15.826788160108752, 22.288419392801103, 28.48344614428859, 20.606926756520426, 5.885908190281161, 0.46208205001969493, 0.11571382713173667, 0.038495941177731564, 0.047967346655505325, 0.04133835720318941, 0.020931308991425944, 0.01737848814246395, 0.021528650728625157, 0.04321454100370888, 0.01831915601336908, 0.035992009610298185, 0.05264369290201895, 0.03924243640334856, 0.03251189050535041, 0.07026426674377534, 0.04900225483241582, 0.04192845940950417, 0.05285862653005508, 0.058465279308297945, 0.021472504144654642, 0.03928704187273979, 0.05612561997446803, 0.05258933130291201, 0.0752691038313412, 0.08291114497208789, 0.038026631884877725, 0.033978290044732636, 0.029567217063759605, 0.0790814561168513, 0.022815596086964495, 0.09044734340521599, 0.03215382483998134, 0.05083915364417819, 0.059189477544878764, 0.04122576143051829, 0.06848926400585521, 0.021134090549763174, 0.061427358267528404, 0.05948840122249338, 0.04011407209139678, 0.08865538714153152, 0.18123699021675896, 0.11686096718955426, 0.15701011844700383, 0.14998325357033362, 0.18820918705915252, 0.19483934096511335, 0.13021194916819373, 0.14085202177445735, 0.16066854068588826, 0.13508566264663974, 0.11062031536693535, 0.1535509097119493, 0.22714828711844262, 0.1629178361186097, 0.08931357924255634, 0.13308517724996613, 0.14697448921299752, 0.1865313472526689, 0.15032606259469064, 0.1085535097386568, 0.18748875797515918, 0.19857486229269736, 0.12245388401131477, 0.1972677017892561, 0.12040836030557273, 0.20136196677002216, 0.2690758502050754, 0.19017714436256117, 0.1527413079935697, 0.2336403000498972, 0.13583328785194507, 0.1963176301890804, 0.11796022675210431, 0.10461638471291912, 0.15874690105838163, 0.1319574958254253, 0.14553430520238417, 0.06068080558531708, 0.11873995870231621, 0.12082777046147855, 0.18606991717411628, 0.2674369429869037, 0.2085777029635445, 0.18617609696042153, 0.211752156817144, 0.12029926938515519, 0.21908142724104468, 3.408562478519255, 15.412411324439512, 34.08634993337816, 46.19580491896599, 48.86797843440887, 41.47680136465257, 22.10999273484753, 35.572457544265255, 61.17697223540276, 31.37500959057962, 20.60218264979701, 11.171789842267192, 3.537178222210177, 0.38065042767313223, 2.217187155638972, 1.140091926340134, 5.411242073582065, 10.01204009979002, 11.831391299924544, 11.193588414499837, 10.872001128811991, 12.7273420364626, 4.036624893065422, 3.1830713008680656, 2.4474999068244814, 3.361987029352496, 1.1482324379105722, 1.0634502840618933, 0.6004464157646703, 0.4437633249307833, 0.29450224712491035, 1.9096816691660115, 7.593876334928698, 16.449241830456643, 31.749390017601755, 48.583198670418035, 57.34272203137798, 65.21270675043907, 68.45493793487549, 67.31959219901793, 63.350259488628765, 63.86880859251946, 41.131444515720496, 46.24878829525363, 58.440036466044766, 62.960215076323486, 59.896110488522446, 61.473585790203465, 65.82618897961032, 66.33128043143981, 63.89548855443155, 62.306563854217536, 63.98211802205732, 59.773438361383256, 54.901725169151064, 43.46631380819505, 36.320841850772986, 20.610439239009736, 9.560860645386482, 1.4284643362606726, 0.717335069371808, 1.3603222249977052, 4.110309558530008, 3.8893227327254514, 4.325251521602754, 7.547211406692383, 9.111474694744233, 9.196785265399564, 7.3016278878335035, 10.162027612809213, 9.108007319511907, 10.20407542105644, 8.052893665529067, 4.065897296513281, 2.8411685891689795, 1.2051145275754314, 1.1974154052234467, 6.07237276531035, 12.448957697037729, 23.972696911904123, 22.39375268259356, 17.718609071546986, 20.848819325047156, 23.09077943525007, 29.708472951765987, 35.07044515302105, 22.614572317369525, 5.758374775609663, 0.5795984054284712, 0.14274202197069122, 0.16378703947749831, 0.12915373659662663, 0.27142902716032924, 0.16513363818728155, 0.08673351768764757, 0.0908980559137079, 0.17930802678869617, 0.1422350403041609, 0.16274067062524059, 0.16477656460577444, 0.13455445727994367, 0.18602035128541533, 0.21352987916719532, 0.15098598605442434, 0.19347564317286017, 0.3543414055339752, 0.15188905049956616, 0.10278474509475694, 0.0958028725618797, 0.15987228421914965, 0.13871927895853597, 0.17575435941257786, 0.1892380584632197, 0.1469234830789989, 0.13807230238472262, 0.10685520006283637, 0.14561056159436703, 0.1997670942857381, 0.19368608752566, 0.11431846692557297, 0.17895113706829088, 0.0517673610949949, 0.12285454033483421, 0.20782374987198463, 0.13730888044641865, 0.15224394839136832, 0.28611523910395564, 0.17846703078717957], [0.06838283907141417, 0.07439009454702178, 0.016428678927402345, 0.01847334269944939, 0.03948635113756022, 0.05875809343471643, 0.04751049012186066, 0.07210997939710656, 0.0487467147139532, 0.028234009570892782, 0.10918774627028935, 0.11973170548557274, 0.030809558867927522, 0.09619019129463742, 0.0327750148942634, 0.017778485630368514, 0.0515554037185446, 0.054268994398655436, 0.08076383882472593, 0.0351992886393301, 0.09223343909627969, 0.08302277164353479, 0.025050213275056694, 0.015070156059077671, 0.05017343472929732, 0.038215978176242886, 0.04467698752940182, 0.004701340343848232, 0.01933214832998572, 0.037814134416440805, 0.05719748423284581, 0.07143140169641665, 0.02327128816696425, 0.06044383543813902, 0.008795537813115985, 0.05769492044383961, 0.04755308461045066, 0.04097492126147113, 0.029534168030706145, 0.15391054202712354, 0.020688376764977173, 0.07330566644668579, 0.01365780019231381, 0.05630282760267297, 0.02034197478825527, 0.023648385371592258, 0.014195390901858769, 0.0985732610006967, 0.03522816249319623, 0.8436974113987339, 7.475733564745996, 24.125685038105136, 35.518042502864716, 33.83896604661019, 27.483430024116274, 18.626639727623232, 11.246493343384037, 12.158903325757674, 18.73796836022408, 19.088000674401563, 10.593709945678711, 3.975311873420593, 0.577137976163818, 0.6206483381890482, 0.23982272152939152, 0.9285604028451828, 1.4270935904595161, 3.5776411477596533, 3.06289870412119, 2.858430450001071, 4.3890802514168525, 1.8387820090978377, 2.9836668266404063, 1.9448995277766261, 2.3547118277319017, 0.8247537117811942, 1.8354848892458024, 0.12570672398132662, 0.9564479031870443, 0.27159070235586935, 0.724947777005934, 2.3994844575082106, 7.690240144729615, 17.40059506508612, 26.6569277932567, 34.504443214785674, 41.38504535921159, 49.894458786133804, 50.481971002394154, 43.644232519211315, 26.151538241294126, 33.19566595938898, 62.64399751540154, 57.15873933607533, 54.03897631552912, 62.7413821220398, 62.886713781664454, 63.093838460983775, 58.06645816372287, 50.85137198048254, 45.2103211802821, 40.383950587241884, 25.785571298291607, 14.480075701590508, 6.9397460933654544, 1.6417043584008373, 0.16910591132698521, 0.3385181658931317, 1.1220910664527648, 1.7008521071364804, 2.6298729594676726, 2.7655994699847315, 5.018682441403789, 2.9443538909958256, 4.815391388631636, 5.363267073708196, 4.983900823900777, 3.087216663745142, 4.200094572959408, 2.6941392787041205, 1.2329639686692146, 0.5757204070687294, 1.2420589645062725, 1.8428551453736521, 6.291284166997479, 12.818778368734545, 20.741964155627837, 20.744323461286484, 10.801180774165738, 12.715650431571468, 17.724200410227624, 24.314056865630615, 27.712176769010483, 16.12846451420938, 3.2159432143934312, 0.20843890315342337, 0.034906784778520945, 0.014938588118961742, 0.04050158234613557, 0.09091984345427445, 0.17126228029449142, 0.054084620017918854, 0.028796275972478816, 0.01878303182761996, 0.03129513029219403, 0.013510150151447424, 0.0339028648581476, 0.06098896062241928, 0.026172899806331244, 0.0640868554793058, 0.038563625045841744, 0.022507331882333084, 0.06989130449871864, 0.020436381718384165, 0.0380261262668477, 0.06729705499545222, 0.05311692456504511, 0.02533844428046817, 0.03817704175749133, 0.04298870977494986, 0.026208678027614955, 0.030685726500627016, 0.0666353005855795, 0.017406883191377405, 0.059071492343660326, 0.021020960430764866, 0.02165353455160174, 0.042307634627626794, 0.066070732089781, 0.0596545618628302, 0.13596536141009102, 0.02212981332934672, 0.018135789038252928, 0.04322846082129306, 0.03383984646549629, 0.06830859749067215, 0.053234783361756036, 0.03540209126508525, 0.029736587612499154, 0.03550287779240358, 0.05016139948800687, 0.07979275343278724, 0.041167431495963566, 0.06246074192946958, 0.027566706769228465, 0.017106320085604827, 0.05389771371659252, 0.1248216626024054, 0.06338309263810515, 0.049895808295977694, 0.02306600150111462, 0.027823325156444506, 0.06142410622428983, 0.05714564689344937, 0.02584634716772745, 0.07450384328201895, 0.04987158842625157, 0.025039415265763962, 0.010462933925971871, 0.009464730936733466, 0.009219545454177405, 0.07958017935555789, 0.022152786390976082, 0.047830071360353506, 0.04882585925741061, 0.03419829134438788, 0.08323484010273412, 0.06443769310510929, 0.022038537783608324, 0.0059160043489218, 0.03991257181511291, 0.07953273553040721, 0.07724028636491106, 0.03846691410628058, 0.020664001762446378, 0.04615917997134309, 0.04588187912539129, 0.02358122818893002, 0.0675455739180888, 0.06142769534621508, 0.06267569470970381, 0.01866655581961236, 0.12984948232769966, 0.07129026531812645, 0.02502864598476839, 1.7732729113871053, 12.504532779416731, 30.654203468753447, 43.53863446943222, 40.6752218738679, 27.233688792874737, 22.410432561751335, 21.782290474061046, 15.280502015544524, 21.689571526742753, 25.00750837787505, 13.490147917501389, 3.5785749170088, 0.9165998091620784, 0.33150242461312207, 0.4510251642955888, 0.16962490525216828, 2.7478026959203907, 2.3266590362594974, 5.057768860170919, 6.082661142272334, 4.5335632081954715, 3.2146282397931625, 4.632575598455245, 3.8812389729484438, 3.7155200589087705, 2.878177867781732, 1.872208447706315, 1.225938635968393, 1.5818530345155348, 1.2527732863541574, 1.66753770122605, 4.037626078051906, 10.715400499682273, 22.582830536750055, 32.41371400894658, 39.26803627321797, 45.52147496131159, 53.8960490688201, 55.15207044539913, 50.852274125622166, 30.56118642130206, 39.94834000064481, 65.23093400462982, 61.84351628826511, 60.36317063916115, 65.47567029153147, 66.22464687593522, 68.34005171252836, 63.21438466348956, 56.11721669473956, 51.59277446808354, 46.12586121405325, 32.41239609256868, 20.315586828416397, 11.175998545462086, 3.2225850128358413, 0.5714755445238083, 1.3745265982804762, 2.052826362271463, 2.485914864847737, 3.2756828733028907, 3.1551001437248725, 6.368203807261683, 5.785773511855833, 3.617605196852838, 5.116414177802302, 4.075275928743424, 4.388888545574681, 2.440509507733007, 1.841667157507712, 1.2667722254991531, 0.05893386464806334, 0.5069034949185387, 2.0344851141975773, 8.341956657748069, 16.464856786112634, 27.507556523046187, 22.637680961239724, 11.523883361970226, 10.871160761002573, 17.550417838558076, 23.480941518660515, 30.014037355299923, 20.124371282515988, 5.293858282027706, 0.5134478163334631, 0.044719742896455916, 0.06286851904024521, 0.055476758824360956, 0.010330699489361817, 0.08267955659257789, 0.06887538764145106, 0.13442003949274942, 0.01989418107475485, 0.02521864153564938, 0.06793367406052929, 0.08388770023180593, 0.0651700348563252, 0.06969136321136067, 0.11716023943717442, 0.0840044367097078, 0.02715905989339996, 0.024967747740447525, 0.032695192362992995, 0.003297496671533032, 0.0169973919588712, 0.033388011638195284, 0.033659160798115116, 0.014199253900216953, 0.07792009746715908, 0.07273309999295781, 0.13297087693166348, 0.009813077819173135, 0.014876588623249724, 0.021594664525060404, 0.07390950460948291, 0.05163624897719391, 0.04688398341738409, 0.05416584449009069, 0.08388644384761011, 0.09209508361715464, 0.05126490317765744, 0.04212022270827044, 0.02752086598305933, 0.040427153073852105, 0.027276223465319605, 0.20165010776010253, 0.19637920833643407, 0.14976666519238105, 0.11216873227949105, 0.2302723783518999, 0.2100446387644737, 0.12193605453977663, 0.2054576873178444, 0.16288489433786563, 0.16084529249177826, 0.2228499669581652, 0.17816369061268147, 0.13042368054870637, 0.30106709969620554, 0.12431809002713812, 0.18582671490167418, 0.21552658008952297, 0.17978534553079836, 0.18687260877941886, 0.12632091965286002, 0.23497773634810604, 0.27390156061418597, 0.1296289409360578, 0.23179021303451833, 0.17264096276654353, 0.1307610656705595, 0.22790631579775966, 0.16804406749865702, 0.15662851473016126, 0.11367487646038495, 0.17785457413523428, 0.09653099316863284, 0.201624060770677, 0.10821559601613592, 0.1914078033258838, 0.18757713387810415, 0.21900333223804352, 0.1485617774268312, 0.1537201998214568, 0.19278251746248817, 0.09218034154224782, 0.1747963817850236, 0.13539280261724226, 0.15292110882939833, 0.1951012970699418, 0.18315817019151104, 0.1941777933989802, 0.16513707026118235, 0.12205540337750029, 1.681984893737301, 11.891121152908573, 33.10704392771567, 50.201458777150805, 50.31770606194773, 38.88160044147123, 30.721172055890484, 21.604450210448235, 19.358697168288693, 27.837759294817527, 26.913768514510128, 15.489788901421333, 5.857589167933311, 0.8201093190620024, 1.194915139386731, 2.48203024748833, 4.149761738315705, 5.999161235747799, 10.127561746105071, 13.89709480347172, 8.14381959938234, 11.387126003542255, 5.967515553197553, 7.32078327286628, 6.574449385366132, 5.485139527628499, 2.859926098777402, 3.1901820676942028, 0.897860317941635, 2.4862443439422117, 1.020718635089936, 1.4601453201424692, 2.897806388716544, 8.709795551915324, 19.036660771216116, 28.613733553117324, 36.56913180505076, 44.23617701376639, 52.91244806781892, 54.259409596843106, 55.69481272851267, 37.359673746170536, 44.647743471207164, 66.23598252573322, 66.49944813020768, 64.13541601550195, 67.41330546717491, 68.99161231133246, 67.68467856991676, 65.93800790848272, 58.76765243468746, 54.43438653023013, 49.355242713805175, 32.68860743891808, 18.581642297006425, 9.64203997965782, 2.784027990794951, 0.3128419630229473, 0.9871756285429002, 2.8566391525730013, 4.562411260220313, 6.415680666123667, 6.367461498706572, 11.831832566568929, 8.986322649063604, 10.13014070449337, 13.978811502456667, 11.504263666368301, 8.304022435219057, 11.924701544546313, 8.894478390293738, 3.9790062558266426, 1.8444272803683437, 1.8221919767318235, 2.874455293340068, 8.656772951925955, 16.993955104581772, 28.21178670852415, 28.230635658387218, 17.223121543084424, 20.43774316387792, 26.332477177343062, 34.4767120576674, 37.39006034789547, 21.8651819229126, 5.479019159270871, 0.6373553062158247, 0.31001705976743854, 0.13513214886188507, 0.11307127578484436, 0.241176521465663, 0.37086291899604185, 0.14413285459722244, 0.16619250959446355, 0.15341063901301355, 0.17653648921799275, 0.21447615097126654, 0.40088906103084165, 0.1797523118195034, 0.25503753414077146, 0.18856308903665314, 0.21961594210757365, 0.16686974664128598, 0.14808183866402796, 0.13105228633409546, 0.14689639420999637, 0.11145953404446764, 0.11852101077355685, 0.07600983424532799, 0.187014089897275, 0.17505729601027506, 0.2022120179308038, 0.24400747681577362, 0.16670866899432676, 0.1617881628654657, 0.16917027803438325, 0.12209602902012488, 0.11560528779462462, 0.14259551531605183, 0.17989143338655272, 0.12357369771287327, 0.3268246917474655, 0.16546497121453285, 0.1177757221364206, 0.20473679858109645, 0.1538449955443221, 0.14914763550604546], [0.01600252336732322, 0.020403495479014613, 0.11379884480829201, 0.09302959597158818, 0.03680409728399208, 0.0919042740978541, 0.07288861584158675, 0.06840536971726725, 0.0325830485821972, 0.04202312489430751, 0.008103227986383342, 0.08805886511841128, 0.05878425150689098, 0.026615842268051162, 0.023689319364606373, 0.06696373013959778, 0.01683977319889011, 0.03162941850361324, 0.013060658595584815, 0.03416724946169603, 0.007844942879127039, 0.08458647201017988, 0.060245610187731446, 0.13533678626821888, 0.045775151586220156, 0.07337150404289847, 0.055293847671559745, 0.06573434288222944, 0.01602541694733044, 0.044112495642395756, 0.024961611376174038, 0.05435619818707628, 0.010559678381879725, 0.022371939248255184, 0.012526112127928965, 0.051596818431731195, 0.027400283743777586, 0.009676883665604458, 0.01618379700718628, 0.038624640118571064, 0.05124750915133665, 0.017143166999542908, 0.0802013770707192, 0.024365368975146164, 0.061175173614174135, 0.02702724488992845, 0.06161525665271667, 0.05273719010273776, 0.023706828304115805, 0.03302872406258699, 0.1701252985625498, 3.5700528323650365, 15.628584911746366, 27.224743827696773, 33.49352290553431, 26.365099530066214, 24.791066108211396, 28.95138490584589, 29.040177560621693, 29.063649023732832, 22.45247840881348, 16.1879050923932, 6.330884416257182, 2.119661588822642, 0.6945913285017015, 1.037832794170226, 2.3662257002245997, 3.134220386705091, 2.87349897046243, 4.083798013387188, 1.9030171945210428, 1.7212669407167744, 3.0761276329717333, 3.1276945433309002, 2.89857100575201, 2.309428064092513, 1.454924277720913, 2.137247290342085, 1.2732907144292709, 1.1082979291677475, 0.19743087851712782, 1.0454930605426913, 0.47523988591086486, 2.20112259830198, 5.517452993700582, 11.85732993387407, 13.86631400354447, 14.925028393345496, 18.645951517166633, 25.14746835154872, 27.273226284211685, 22.71630879371397, 40.827617722172896, 46.39280988324074, 41.876416360178304, 36.268752774884625, 37.44354578756517, 32.98064947128296, 20.2441918465399, 14.37117599671887, 8.607581527002397, 5.273689944897929, 2.294267122783969, 0.5915153014563745, 0.12191948405797444, 0.06937554346457606, 0.5750195285485638, 1.8112640082836153, 1.7968993081200508, 1.4688338603704207, 2.0247403532266617, 2.508505020410784, 3.703183714420565, 3.939592319150125, 2.3467874142431446, 4.652460054043801, 3.2493824007049685, 3.953931769055705, 0.6152474796099048, 1.0216484206818766, 1.4633625217022435, 0.9994261711835862, 3.43416795615227, 9.12522848575346, 12.875144789295813, 15.36525070667267, 12.672303338204662, 16.8638285129301, 16.32601861030825, 21.278434568835845, 31.605182117031468, 24.507566998081824, 12.296725607687428, 3.4154163300991063, 0.1327109586207136, 0.06337419069642503, 0.051092108215896354, 0.07269249733297095, 0.08555240163038816, 0.027715599787751996, 0.050313349197348284, 0.034646690267348484, 0.025241461379693884, 0.0723741494960362, 0.056898108563355865, 0.02259562351560641, 0.04797995263229936, 0.04667474182262536, 0.09123839813494876, 0.06978512471241337, 0.05218378733843566, 0.05704161215333208, 0.09326252500496565, 0.06713782362039052, 0.06960971356039086, 0.020904421220503507, 0.012526858106045233, 0.16847451698155175, 0.01648561266671506, 0.11149920973806612, 0.02841976482511288, 0.03060502105302388, 0.04746812162920833, 0.023489810916925633, 0.009571537957526743, 0.008238791075024393, 0.022628090321837414, 0.027616688260628332, 0.023989185330367858, 0.045484528471265114, 0.0615143207382531, 0.028424966562118743, 0.06369554542846258, 0.014635805273428561, 0.10201948454543468, 0.030775211315842408, 0.036372774460863684, 0.018722508966381994, 0.013937755532923245, 0.09668278582994977, 0.05133939373697485, 0.11597936086717153, 0.06296614162443627, 0.0469366213186614, 0.018109387733162414, 0.0846491150197483, 0.0879623993269859, 0.0702012253684863, 0.060995100817132386, 0.029988691826621373, 0.025815548517951564, 0.016859990259211872, 0.025691141584707845, 0.027531097087288098, 0.08636129088699819, 0.06192839892220594, 0.008734654890553606, 0.04164640115754258, 0.04450461008555947, 0.11214941920291994, 0.06233620284605892, 0.060800330623263316, 0.052918101766056595, 0.06717038235717243, 0.023934737546369437, 0.023556328416171095, 0.1402209338641936, 0.03932556843445186, 0.04478621251520611, 0.05470475287086541, 0.05322697692580762, 0.03874406173464753, 0.029651402465758786, 0.03963514073421398, 0.061829156062055024, 0.01471594573118754, 0.02521184250532139, 0.04511911985314181, 0.04366467511581798, 0.021869883527077978, 0.02450720440866726, 0.03977239687716769, 0.03533143114538924, 0.051224472887453534, 0.021405823851725268, 0.020771604557071003, 0.6461220486990867, 6.280469702136132, 22.771751496099657, 33.507368872242594, 38.18529344374134, 31.646739629007158, 21.936168978291175, 22.21152524794302, 22.712855146777247, 25.915827328158965, 29.16109834947894, 18.092114810020693, 8.02489088427636, 3.5905092185543435, 0.5943154447501706, 0.3008815838444618, 0.9122337821510531, 0.297843677502486, 2.6394300595406563, 3.5108868200932783, 4.078952660483699, 4.961671771541719, 5.715268417712181, 4.6820562981790115, 5.782273286773313, 4.431770838076069, 3.839793983967074, 4.59315921029737, 4.543693709758021, 2.764397753823188, 2.49236814437374, 2.350833093927753, 1.654018884704959, 4.482828330609107, 8.837412807249255, 14.017766521823022, 19.079498937053067, 19.80570420142143, 23.480319822988204, 29.847883793615527, 31.920599514438262, 24.63826233340848, 46.73666838676699, 52.66543680621732, 48.49203886524324, 44.00109760222897, 46.493952120504076, 40.24857390311457, 28.166710830503895, 21.769146611613614, 14.405117246412463, 10.33932953111587, 4.743909134018806, 1.0680176389794196, 0.3091006960359312, 0.9159829551654478, 1.6622803768803998, 2.4032599839472004, 3.5087130915734077, 3.438731878995896, 5.283324756929952, 4.461702444861013, 6.113856732845307, 3.5192245533389435, 4.486436911167638, 3.1644184695136164, 2.9250999564124696, 2.429744072498814, 0.5131696344863984, 0.99751413829865, 0.4257041197871009, 0.7269875320696062, 4.4906255122153995, 11.188514828681948, 15.286639544271655, 20.721342294446885, 18.30645076690182, 19.668405555909683, 13.589236793979524, 21.636894095328547, 32.44343969129747, 29.335128030469342, 18.156300475520474, 5.179695736977362, 0.383822460688891, 0.06237370668039207, 0.026322363560358365, 0.021756690205825914, 0.022965523324185805, 0.06900409041273017, 0.026559255183524182, 0.039871379267424345, 0.011897562841524281, 0.07492948939362842, 0.11376988668475421, 0.08667072912137355, 0.013709261191017447, 0.06528179176271924, 0.02138222068277819, 0.0855215895740736, 0.0638062106595645, 0.024494067915985664, 0.01037263322711712, 0.006663991051966385, 0.010491543479504125, 0.00765736002640258, 0.020196462132697626, 0.010046702077341898, 0.05022644035277828, 0.009958428638656775, 0.04411501607166664, 0.007312100478297761, 0.045530620151229446, 0.007636372090107011, 0.01704454658583047, 0.005421428518715285, 0.0829321434420924, 0.06510671002850418, 0.05050369906389425, 0.056075471858944625, 0.014125395363437073, 0.019827255633689707, 0.06229651183070195, 0.01818604632130554, 0.057467242943183075, 0.10634009786430867, 0.24788317691174247, 0.1511410422502987, 0.21907454777148463, 0.17965557023642525, 0.23348443180082307, 0.22388380261198168, 0.20862777447027547, 0.16026858150237994, 0.18154956941162387, 0.18877397772044907, 0.1948110569989489, 0.14374654710052476, 0.17852091741177345, 0.1889592177805401, 0.14003164885986236, 0.1452772520602711, 0.149347186088562, 0.19128651628571172, 0.23117596373683025, 0.1193844531512549, 0.12954758239849923, 0.17461291904891693, 0.19849915748401997, 0.29342092934154695, 0.09769403721175848, 0.16263485856113896, 0.1500555416268687, 0.19221043364415247, 0.08202648961976652, 0.15333962266243276, 0.2734401305356334, 0.13366217935277572, 0.12717584313284006, 0.055667143164863514, 0.11821298214096217, 0.1333841966885713, 0.10043646344133925, 0.13988203188825038, 0.06201779755252985, 0.12202858263927123, 0.08019186991957888, 0.09331859498014373, 0.20925386748727293, 0.12484652215554831, 0.14557493850588799, 0.11347722577592058, 0.13080628017985052, 0.17725083556386734, 0.13272462562928278, 0.16735550767231375, 0.5079301446676254, 5.946442619446786, 22.78371668631031, 40.814697434825284, 49.57644870204311, 42.648260362686656, 35.586327045194565, 42.59573590370917, 41.23518336203791, 37.84887959880214, 30.84509934148481, 22.481115633441558, 9.536355637734937, 3.165546641234429, 1.1929459869861603, 1.5735939938214518, 5.36758658386046, 9.047076240662607, 7.846678485793452, 11.953030863115865, 8.970065405291896, 11.341546100954856, 8.404348819486557, 8.477581431788783, 7.960903298470282, 7.426847104103335, 6.081336852042906, 5.211223748422438, 4.582624704607071, 3.9841693207140896, 1.7588097842470294, 2.412467012482305, 0.7669035321281803, 3.2949637741811815, 6.961917781060742, 13.428168585223537, 16.608066443474062, 18.25200826891007, 22.41626904856774, 30.978701153109153, 37.062083521196925, 31.16670623902352, 48.51426693700975, 56.927127299770234, 50.1481576888792, 43.22647263926845, 44.476328049936605, 39.75653609921856, 23.785927372594035, 18.470768659345566, 11.081680251706032, 7.191896640485333, 3.766909727165776, 0.9880909503948305, 0.1270611291270583, 0.33556036170451875, 1.4131417197565879, 4.805132429445944, 4.626772451785303, 6.11810613063074, 7.146619740993747, 8.309660842341762, 11.585411621678261, 8.121241946374218, 7.909630565874039, 11.065358288826483, 9.696937472589555, 10.349296273723727, 3.881773395884422, 3.490735153036733, 2.717837013544575, 1.3649129915621974, 4.7518102584346655, 12.672940723357662, 17.897877077902518, 21.17772183110637, 20.78900710228951, 26.204401985291515, 22.865098022645522, 29.740504987778206, 41.49404410393008, 34.52865992822955, 18.370491304705222, 4.975663846538914, 0.4697673215020088, 0.36029234588626896, 0.185454273596406, 0.21432137056704492, 0.10625300898907647, 0.1632434234864289, 0.11566099770847829, 0.12958269986894824, 0.1256628654476616, 0.17915172953038447, 0.2456526046678905, 0.24541007655282177, 0.13926712375494743, 0.16988038025315733, 0.1580323861731637, 0.1864708569501677, 0.12663922918539855, 0.229759605060662, 0.1941554389533497, 0.13044320046901703, 0.1476363432143004, 0.09085297163936401, 0.07260775268678704, 0.3004750669483216, 0.13331995255524112, 0.16186688606056476, 0.21969848042053564, 0.06157574566802191, 0.1557383818491813, 0.1892421034074599, 0.10691238852638392, 0.10270083548441049, 0.25405274343586737, 0.11788179467041647, 0.10840430645452392, 0.1538301027950741, 0.17119098815225786, 0.10759645141661169, 0.14690391719341278, 0.11776084470893107, 0.28247754720430224, 0.19204924874488385], [0.05594059824943543, 0.031107471309482094, 0.01968269675759779, 0.1126232062796912, 0.12909827183090872, 0.0387034667355399, 0.09434143727224681, 0.06585144708233495, 0.07748988547152089, 0.060825688133557, 0.05614252370451728, 0.04814844601036561, 0.0941565725952387, 0.017947122649920565, 0.02714584296148631, 0.017728532867265806, 0.023684761141456907, 0.024128845074184002, 0.026444732699723496, 0.023945683027587594, 0.13139314949512482, 0.017401995550420497, 0.03921902858682218, 0.026807651532092885, 0.034736912442190994, 0.04445723137788234, 0.09020856912097625, 0.046568010453014605, 0.03584277568264835, 0.058880284458639166, 0.06352212993548283, 0.06205687569754739, 0.06573212122724903, 0.03766279757743882, 0.0419897081390504, 0.060310413565246336, 0.053624634015103506, 0.020573861942055727, 0.03199835878706748, 0.046993549312314684, 0.08334490395481549, 0.04723165326962068, 0.008369886913456985, 0.016654651882427356, 0.026444401366696246, 0.03444163534309595, 0.04011590304153581, 0.0666960973232504, 0.06998074526387839, 0.041824918796098044, 0.032459267925831585, 0.1120083824160599, 2.782202127479738, 9.952764261153437, 25.288924709443126, 30.5974801125065, 31.646572928274836, 27.98562284438841, 18.31410134992292, 17.395203767284272, 20.088987581191525, 24.667305523349395, 15.841713759206957, 11.39614647434604, 6.115984128367517, 1.9444059220052536, 0.7513564825057985, 0.17531934404565444, 3.3744336905017978, 4.175360596949055, 3.7086380152933063, 1.9465411622678082, 4.183492160612538, 2.4809579695424726, 5.363975061524299, 3.3713212897700653, 3.109672478129787, 3.006441578749688, 2.5805067439233107, 2.415548034252659, 4.044176436239674, 1.5018888995532067, 1.8260954704976853, 0.6191559989125498, 1.3854386320998593, 0.512824067545514, 1.2299284218780457, 1.497536171828547, 2.5442865971596014, 5.147174385286147, 10.20469613613621, 13.27599140905565, 16.025470918224705, 17.640085181882306, 11.583143511126119, 6.526304742982311, 4.718096996507337, 3.5314287629819687, 2.1799386124457083, 0.28221487097682496, 0.06402943718938098, 0.06721703711176111, 0.029311134938090563, 0.2569468397526972, 0.8670947171988026, 2.355279100518073, 1.954534094660513, 2.8833549061129173, 3.3251113564737382, 2.807905419218925, 3.321535380617265, 2.368902227570934, 3.1567507261230103, 2.322240976556655, 3.257610062437673, 0.38243124501839765, 1.2351788820758944, 1.5763146478322245, 0.469262408272874, 0.8581942464074782, 3.838122073681124, 8.908786216089803, 11.400036484964433, 15.572251831331561, 15.902011375273428, 15.445322951962872, 14.894247593418246, 15.047158252808357, 24.256660822899114, 31.283710541263705, 25.56111562636591, 8.635048904726583, 1.8048787573652885, 0.007150386020751491, 0.08786573435270018, 0.1051527611731041, 0.010207144828933862, 0.06472364308372622, 0.015318178939783286, 0.013930987146112227, 0.133196581755915, 0.04672758273720261, 0.037455846585573695, 0.07878687232732773, 0.0626003461319112, 0.06371877321432676, 0.0671537659100948, 0.05126347059323903, 0.09534900377113974, 0.026695659053662134, 0.039897211752231085, 0.06701828326068579, 0.011749168737761438, 0.07189895281748426, 0.054366486747899366, 0.019410325687438734, 0.0759615860278568, 0.0545458241005338, 0.05800821210047411, 0.04653622929547583, 0.019824622206449993, 0.05115993381027253, 0.02340466215936167, 0.07448263030739562, 0.001038758965742384, 0.030787558737962, 0.03252160833066991, 0.04747836422475596, 0.02305100532999683, 0.03942292288786942, 0.03854889700549745, 0.01986815898318685, 0.06246997711939677, 0.03374573256399843, 0.0394950807094574, 0.048682642950406, 0.04056260124930451, 0.0599682480547457, 0.03491475975381271, 0.039121061263065186, 0.04592252392021399, 0.06198420076661053, 0.1204722137340615, 0.0463470860174106, 0.029715399535733367, 0.019828603948436437, 0.05258986373401938, 0.12510870042587482, 0.06562424072575185, 0.015869350473005927, 0.020667516190799016, 0.023034164802201336, 0.05427969281651801, 0.029999535801189563, 0.03669579543413655, 0.03652108525256476, 0.09303730281610643, 0.03521561014255689, 0.029309012874540304, 0.05185384476076692, 0.0766976816099017, 0.023215861705642556, 0.06869271397590637, 0.10630710245740992, 0.0460615344045143, 0.049642524306452086, 0.021017679659229134, 0.03727862363561027, 0.010486402071922297, 0.011224148573444016, 0.047740948521682335, 0.044668288601021615, 0.03113753834529029, 0.03582973303573747, 0.06895155976376227, 0.003988710274326525, 0.004585901906173076, 0.07170880979467785, 0.05393641647852717, 0.037203773014968446, 0.08371617314555953, 0.04363907628782815, 0.05298981142620887, 0.06041598431165181, 0.06528979738152797, 0.127106427906021, 0.07484652207142885, 0.24145723140287786, 4.403324338697619, 16.412006770410848, 33.70475038405388, 37.36665164270709, 38.59637744965092, 33.939398334872344, 21.151085015266172, 16.892977606865667, 19.45404802599261, 31.959960499117454, 22.73734054257793, 12.237563517785842, 8.932428302303437, 3.1634023304908507, 0.610198408605591, 0.1754051918584493, 0.31319862291697537, 0.788422758060117, 1.6507817035721195, 1.9589555864372563, 1.8128715671839255, 5.215654065532069, 5.266754704137003, 7.618651005529589, 5.006764319635207, 8.99376436587303, 8.567719459533691, 1.8841277952155762, 5.303374442362017, 3.0654193172531747, 3.316175952073067, 2.5029955612074946, 1.93978046697955, 1.4334334889727256, 3.1801157949432253, 2.431974675386183, 3.5009038977084623, 8.349926913938216, 15.301071905320692, 17.190195206672914, 21.570435416313913, 23.83720647904181, 17.74499877806633, 10.51249138770565, 8.960022176465682, 6.6841629820485275, 4.004056718080275, 0.8816556584450507, 0.04210578578133737, 0.18251133151352408, 0.40402370895589557, 0.666871999780978, 1.3695755865304702, 5.388327096739124, 4.740908030540713, 3.4568333721929982, 4.633773392246616, 3.1584442094449074, 6.125789073205763, 5.062682609404288, 5.292730600603166, 3.6683317394025865, 2.346613604214884, 1.2890737191323312, 0.9672439819382084, 1.0459163087990977, 0.4901890498736213, 0.7874227988143122, 2.6662654453708283, 8.791020974036186, 18.209872207333966, 22.24460259560616, 22.8456195323698, 16.288665879157282, 14.467199540907338, 17.8365449367031, 24.52530787837121, 33.61717954758675, 33.26537824446155, 13.15999613654229, 2.8334018059315222, 0.3291843344848002, 0.0557213515463856, 0.0749115705970795, 0.047578993704049825, 0.049349683366956255, 0.04884132274216221, 0.01488439984724767, 0.09429927179289442, 0.027382968241469036, 0.053610649080045765, 0.04850775273817201, 0.06977754810284223, 0.030724285621075865, 0.023427847810390017, 0.032795132363155004, 0.06928421812312258, 0.02723269817990161, 0.06496885250652991, 0.03354133647536078, 0.022380188099979874, 0.03002523039016993, 0.05449937618968468, 0.030664670574028167, 0.02205385762687412, 0.04145097978893788, 0.018854421646063848, 0.05485443495995095, 0.042270850915942466, 0.07102316876332607, 0.03892956992551204, 0.025185556113419515, 0.08978846182505931, 0.09674364385465462, 0.02328432123777607, 0.03738873728340672, 0.0030918889669626355, 0.04685207585533781, 0.13353070334321068, 0.02280761153557368, 0.05322100910087747, 0.05763877385986909, 0.062088166558814634, 0.014481205857479045, 0.1095976186315379, 0.23184638260112655, 0.10698919650167228, 0.2936731561297371, 0.3541476465761662, 0.20313326930326803, 0.2038154399563228, 0.22605576912962624, 0.17008889406438799, 0.10669995234498095, 0.13325347144517208, 0.19891344251171236, 0.14504894253707704, 0.13695553005222352, 0.13627696001241285, 0.06443492752770263, 0.17536359328416087, 0.18181947750910638, 0.11615928427706804, 0.14446354411061735, 0.34277856470115725, 0.19071306883087083, 0.10161848348234931, 0.1854363777824948, 0.24190422838493703, 0.09205461885299414, 0.1903427878935491, 0.15252787589786515, 0.19610455049382103, 0.15653629306583636, 0.10889562928388197, 0.11984847260699158, 0.12073343439448266, 0.1107731652295878, 0.18740211343092306, 0.13237530485756938, 0.13430929382241544, 0.20390727857668556, 0.16990687157357895, 0.13656553001173083, 0.2450389835623003, 0.21571301524677586, 0.18550760863769442, 0.07223659840923163, 0.2920241978379988, 0.20209820790877267, 0.14451114881423213, 0.14687269144961912, 0.19500077101251773, 0.1268090785390908, 0.1459013685704239, 0.2232618005044999, 4.0624127609114495, 15.482875723992626, 38.20793336437595, 47.09067406192903, 48.50185263541437, 43.70107550774851, 29.248416193069954, 27.18962488635894, 28.909184125161943, 32.65234512667502, 24.196148457065707, 17.107017424798784, 8.490616448463934, 2.9205495167163114, 1.051853796647441, 0.5908369765646997, 5.713721532975474, 10.444914833191904, 12.21926664152453, 10.03946727321994, 11.421272197077352, 8.054978405275653, 12.075154839023469, 9.950991349835551, 8.830120140506375, 7.663947026575766, 7.25656867988648, 6.713804823736991, 12.367272377014162, 4.525257099059321, 5.572475021885288, 2.036492754855464, 2.7455573841448757, 1.1486196493910206, 2.2127776761208815, 2.5007686355421623, 3.276175621055788, 7.073225330921912, 13.554250232635008, 17.532592627309985, 22.023724125277614, 22.86718668476228, 16.024964932472475, 9.10186194604443, 7.15934734190664, 5.021520766519732, 3.013914429372357, 0.6938303886882721, 0.08690522097411656, 0.24763611355616202, 0.38620756818882884, 0.5789960764588848, 1.4267599438467335, 4.26830998351497, 5.655014438013877, 7.10119967499087, 9.16148393384872, 9.554494638596813, 9.069716161297215, 6.7141857839399774, 10.293062233155775, 7.877095485887221, 6.631418870341394, 4.699809435875186, 3.76250000249955, 4.0347519613081415, 0.995098264707673, 1.4026019433813712, 5.34240153528029, 11.292794962083141, 16.02063757757987, 21.296418636075913, 24.933385387543712, 22.374068267883796, 21.89138531684876, 23.40455532073975, 33.5413718992664, 42.666895543375325, 35.642966070482814, 14.192071749318032, 2.8846024649758495, 0.20913760598388412, 0.1741982356555039, 0.1466213073581457, 0.15673368328040646, 0.2160690316269475, 0.1564907874431341, 0.07901341218741671, 0.3061701032903887, 0.1865203615518347, 0.09504317381088773, 0.1685688990138231, 0.1477568335230312, 0.2605530607604212, 0.12118622300124939, 0.0883305658616366, 0.20511832568914662, 0.11066335418652143, 0.11798932277146848, 0.12309064097221821, 0.17559444621926354, 0.13349488107187132, 0.1631759158185413, 0.16210642643272877, 0.1705779033082147, 0.20499630320456722, 0.23669340557629065, 0.15529402020958163, 0.08465256241540756, 0.17377743888045513, 0.17307412420069018, 0.12984943636242421, 0.26162141633610575, 0.27109905776958315, 0.11117969744748647, 0.1052920206359798, 0.08704241199959671, 0.20009543957008472, 0.24524463220469414, 0.18327187296123276, 0.23037308827042582, 0.08766951625265422, 0.12784027885044777, 0.13384441634820354], [0.01919024969421087, 0.035469572119895494, 0.025914105729410247, 0.03815394803701389, 0.018507525542630784, 0.015793899430953447, 0.035194653807388204, 0.013787097639344154, 0.04218175872078827, 0.015711999843798338, 0.022209775671663306, 0.02202495312949102, 0.1387980481189105, 0.021140952782344916, 0.05402619049193398, 0.05471499163597342, 0.0604879850852153, 0.018466039966311187, 0.014212245793802845, 0.04613842281903471, 0.0072362984722149715, 0.03728968594523688, 0.05646749437155743, 0.05123187329680209, 0.03292070183482382, 0.05481126973585737, 0.05419702809904853, 0.0673082398791467, 0.026665276006585168, 0.02927143626185435, 0.025716688701762788, 0.05484226182283414, 0.025366372015747814, 0.0656538500240253, 0.02145922592570705, 0.10381536317929145, 0.10932028714206912, 0.0564983792062248, 0.07092309469777731, 0.05600339064614908, 0.017026336675870325, 0.05456941960860164, 0.08670968469232322, 0.03242389764636755, 0.04223350796007341, 0.0324207375336799, 0.08972620952033228, 0.02687212932223995, 0.03608912657645922, 0.04863416490655753, 0.11840926152804207, 0.009622131361656133, 0.0475284663750039, 0.5448257358324143, 5.823573393206443, 19.661002082209436, 30.79818779422391, 33.81346279574979, 26.650846158304525, 23.197530661859822, 22.519356781436553, 18.64298228294619, 23.187324654671457, 21.319490017429477, 16.55428094248618, 9.128192817011188, 5.158713017740558, 2.108134723478748, 0.6941097962760157, 0.16548006314664118, 2.048257536465122, 2.4339316929540327, 2.766160859215644, 5.651051373251024, 4.5176251472965365, 5.098920406833773, 3.987916900265602, 10.741673515688989, 15.345346639233252, 2.6418663417139365, 4.754021494619308, 3.4510182132644043, 1.6677265878646605, 1.6800450365389548, 1.8938766011307318, 0.4162690115551795, 0.4018601540836596, 0.19805755376094775, 0.1033674392308439, 1.342246717502994, 1.5160601778376488, 1.1266375837787506, 1.639291855596727, 1.2456217023634142, 0.33482004497801104, 0.11563767033118395, 0.13853544850022564, 0.2796299983897517, 0.2201102526798364, 0.11825199133806652, 0.05621141799154782, 0.04682311773180001, 0.30331382107350136, 0.3419753061907907, 1.6646195803919148, 9.90691371502415, 4.665521056421341, 1.1141942321292817, 2.5900483996637407, 1.77770997007047, 4.435580440105931, 4.49583932276695, 3.8196942883153118, 2.8495448106719605, 1.917810045903729, 0.8614994561479938, 0.6346127727339346, 0.8053138323368565, 3.098690086795438, 7.097082657198753, 22.149290961603967, 23.505107241292155, 14.113822425565413, 14.697039646487083, 9.225452888396479, 17.591779232025146, 23.54833176059108, 25.462436637570782, 30.62294806203535, 17.841451821788667, 7.132460474967957, 0.9821276607051973, 0.09701112345341714, 0.03830512399755178, 0.011282384662228006, 0.08285067765222442, 0.004985012168500332, 0.08774308367602288, 0.012481989293930032, 0.029161956551815235, 0.06528887041513959, 0.03508734021095499, 0.03394316491340438, 0.06956308178843991, 0.025183330627999483, 0.042783524615750204, 0.06674610754294742, 0.0460648630565453, 0.02314029670801134, 0.03669675687448152, 0.009684353980476098, 0.038498465437442064, 0.0614466521919014, 0.042825192137951815, 0.02071137089402445, 0.05675917468784798, 0.012970477597968233, 0.040438583105682366, 0.047066706878643845, 0.07463916505296385, 0.03958339149492883, 0.11097518261522056, 0.09732414697927814, 0.11572952427330518, 0.014864096602034426, 0.09515506861310813, 0.02853983187026555, 0.027123482770196376, 0.018935098365369826, 0.047751834631086364, 0.047157086101510835, 0.034565599860563394, 0.03991965812841251, 0.04582563678043024, 0.023546181581614, 0.02078953867537841, 0.014218507604973932, 0.0036171142992022782, 0.06924472629062592, 0.054784008497071844, 0.0362163010023294, 0.041277066338807344, 0.04175977067901723, 0.06795056629925966, 0.053772389393059485, 0.010344821362636022, 0.00830711845699097, 0.006358178807497626, 0.0724418027206294, 0.02498324952959534, 0.03968541908468451, 0.059483030946144176, 0.06372736489039756, 0.05108647363921327, 0.028315285753999508, 0.048711214199542045, 0.008001516886701388, 0.10797692898420558, 0.00786472135411215, 0.039484750013798475, 0.039661459684852636, 0.019056134511746706, 0.02661007937164076, 0.03065916240185259, 0.0930406429594563, 0.006220038311796324, 0.0138816750240362, 0.0427681147571533, 0.07327643253149525, 0.02307151924938925, 0.05419082661730148, 0.022285357906272816, 0.07879428805843477, 0.02057965356676329, 0.02801514016614566, 0.04100104485968909, 0.02485001917868372, 0.031966614018705104, 0.035067356807450135, 0.0049457894243870775, 0.07847118281549023, 0.044984502883087245, 0.014935224992974151, 0.05221784377710954, 0.019255700416021773, 0.08374505466030491, 0.10364669360100262, 0.01948909293259344, 0.1097446462259658, 1.3420608952160806, 9.216333377745844, 26.01584384518285, 35.971021344584805, 38.21581340605213, 27.287660606445808, 22.799312030115438, 17.515657794091013, 18.641085816967873, 23.312907180478497, 24.372323674540368, 20.983448797656646, 15.310970006450532, 8.157681255571305, 3.1113872893394965, 0.6795780276579242, 0.30693003186775797, 0.5451420995016252, 0.6115426784080844, 1.4202011280482816, 1.4790354548923432, 0.899001666374745, 5.3222322175579695, 4.9692365527153015, 8.62468796391641, 9.104181047408812, 3.594047196449772, 5.920394159132435, 4.343026232334876, 5.133156324586561, 3.968254303739917, 3.155353381749123, 0.5200299824918471, 1.1237915364965316, 0.6446810066699982, 0.38460411551979284, 3.935111991820797, 3.8718218524609846, 2.017902558849704, 3.1900438041456285, 2.1664402657939545, 0.8251224758644259, 0.4389644275990225, 0.4674112640561596, 0.4641835211265472, 0.8772720420552839, 0.5290210968063724, 0.8424516298597859, 0.3748387314619557, 1.8924909012932933, 3.330080754333927, 3.715651458309543, 6.631235009239567, 5.663314173298498, 4.502270048664463, 7.86460469807348, 4.928867028605554, 3.6469908587394224, 4.158338490993747, 3.372215835317489, 1.187989091680896, 1.1862453529911658, 0.7737941559283965, 0.3123539650151807, 0.45196693150266526, 2.9532253117330614, 7.7071504631350125, 18.0264719840019, 30.147484233302457, 21.519536779772853, 16.085993089983543, 9.97552969763356, 14.4952513517872, 21.670773567691928, 27.378792955029397, 33.89786435711768, 25.544471048539688, 11.666840026455542, 2.221834428848759, 0.11250828543016989, 0.03902130512400501, 0.029361074294654593, 0.03797092197102405, 0.02771681403711198, 0.06993794393154883, 0.03294979402374837, 0.0031781540582737616, 0.023400483149734717, 0.0708676835582141, 0.020331778157983097, 0.06371903368422101, 0.07022743323637594, 0.025723608390938853, 0.0509844996756123, 0.05519291941797542, 0.05292376698625665, 0.014908093989135758, 0.06778631704829394, 0.04924157303908179, 0.0160535448230803, 0.07946447709635382, 0.013008358730604092, 0.07291599582400053, 0.018255036369326617, 0.07700761780142784, 0.02232504892162979, 0.034674108554158485, 0.04302576161740769, 0.050353794809310674, 0.06458174827839099, 0.04374647798437265, 0.042960498587138234, 0.06638415398136263, 0.03853457882219265, 0.025442687779544823, 0.04622713197022677, 0.019978640353186958, 0.03369169655225931, 0.018235815223306417, 0.03046692795901289, 0.027056291113577546, 0.052866593844467596, 0.037440827431818174, 0.10958267225613517, 0.10350194128770983, 0.12142515050307398, 0.13817601536791171, 0.19977388182474723, 0.18166630588952573, 0.18593266486160218, 0.20531795288045562, 0.14691439727621694, 0.13271940090963918, 0.1172704105415652, 0.07142423877432462, 0.24494565873136445, 0.11903312522917987, 0.1761289917293095, 0.21882302578418486, 0.19824359055248, 0.1435322723081035, 0.142445208865308, 0.1852495136160043, 0.18074384409814112, 0.20716425542148853, 0.1292403198538288, 0.12351337594971543, 0.11172178892358658, 0.1623213753825234, 0.13950882449505791, 0.20575646160831376, 0.20637452602386477, 0.11610992523210666, 0.0992878448338278, 0.09530157526774753, 0.13982957018719566, 0.16193362764052807, 0.12121105191087532, 0.19977962748417932, 0.24529497950307785, 0.14003817592897724, 0.15224996984245318, 0.1182145985864824, 0.07825025071900699, 0.14809794183219635, 0.18293392093431565, 0.11114913053930768, 0.1940035850049988, 0.16344292810367, 0.12285942031491189, 0.11525882453086878, 0.1786662136474925, 0.2783026438086264, 0.29248872291176553, 0.12586849876829695, 0.1650374481875089, 1.1572856359904813, 9.537615699152793, 27.83690617930505, 44.63088512420655, 47.39904296013617, 39.00804981108635, 34.415303430249615, 32.91500468407908, 27.01976272367662, 31.333385398311002, 29.771546625321914, 23.621956609910537, 13.651764277488956, 8.067129417773216, 3.336640428150854, 0.9916915023519147, 0.4346483188771433, 4.443210430683629, 6.671518731501795, 10.753117030666722, 12.531997215363289, 10.40258167251464, 15.080305222542057, 9.519561029249623, 26.2566283441359, 32.45943707804526, 8.792478134555202, 11.511666159476004, 10.722126383935253, 5.417537477708632, 4.137311154796231, 2.8107506084826688, 1.6201832938578822, 1.6363946949282002, 0.6829467307656043, 0.2392799329132803, 2.8118961857211207, 3.49514830977686, 1.642290139871259, 2.5770231889140223, 2.4021852545199858, 0.7488489235120436, 0.3822682827951447, 0.29225944811778687, 0.5703479243863014, 0.7424386061968342, 0.5887270478471633, 0.4961727175020403, 0.24932440280193285, 1.1329257560353125, 1.6267033762508825, 4.44632871497062, 17.225294536159886, 10.382695255740996, 5.793115208225866, 7.894695160850403, 7.896530339794775, 11.490741295199241, 11.72549024704964, 11.83973712305869, 7.836446492902695, 6.39954109345713, 3.0669255073993438, 1.5550132360189193, 1.3575455546379092, 4.613375106165487, 9.177654885476636, 25.61211624453145, 31.22614387542971, 20.15993541286838, 20.0780677026318, 13.553782489991958, 27.11488412272546, 30.95940897541662, 36.365847126130134, 41.50163781258368, 29.43778822498937, 11.893988405504535, 2.0664293871771906, 0.16911933318741862, 0.11887918752167495, 0.09940053636748945, 0.1379507548746563, 0.1007454879882355, 0.15524670661937806, 0.0870318170036039, 0.13870513697545375, 0.09259159286176005, 0.12728645856822693, 0.1092626926519217, 0.19298395262129847, 0.0905765671162836, 0.10126795995259479, 0.19777359561093394, 0.11412000418790888, 0.1489511645969845, 0.18052488084762328, 0.1787557386823239, 0.11384089537445577, 0.11294369916281394, 0.15057971430641992, 0.12774230386581154, 0.14399270647235457, 0.061972173186199325, 0.10662600187765015, 0.2160749764692399, 0.19984063872646904, 0.18917867132732946, 0.17088766329951827, 0.14654923380622942, 0.1463202348039035, 0.14961864168365158, 0.19470455545571544, 0.1942674410078795, 0.1695287305741541, 0.11548801505517577, 0.09142075770444448, 0.16188637533735845, 0.21546613575229723, 0.1727964479716555, 0.15590569545184413, 0.22115147342124294, 0.1572619928347488], [0.07081458600418222, 0.10244427263856896, 0.08316431404842485, 0.026422226951727946, 0.03920656050585451, 0.034706288077417886, 0.14611768115672374, 0.018866039369435563, 0.007315352042731379, 0.033786277767390974, 0.04662301556597795, 0.011774012969145852, 0.025392782896937385, 0.06992638366477144, 0.02340644331378562, 0.0791763820715489, 0.019876633830849203, 0.06816056632106343, 0.0019124110211475543, 0.07430161139176739, 0.07154829905278261, 0.04264339181264082, 0.0252330708017032, 0.03340561633869525, 0.024772021851892916, 0.01898996366728698, 0.04004595538360938, 0.017662425225059834, 0.05714404960012725, 0.035422790960799304, 0.05193128475859281, 0.09493760689492188, 0.08366610163882857, 0.04522822992575746, 0.07556564114507168, 0.015193819887034837, 0.027223936049267653, 0.062496522065973094, 0.05173824592343262, 0.0334468242081423, 0.04694182688610689, 0.031265270100125385, 0.05031066022873406, 0.049002136088787555, 0.031854324681203694, 0.018379336050260934, 0.12186188956782704, 0.019598361968453375, 0.07615132302406334, 0.015942434303372378, 0.022741636043534647, 0.03884642257265026, 0.06270723454954644, 0.031388066333508303, 0.33220639812850183, 2.235992959430141, 12.17879366490149, 29.121517712070098, 38.58337087015952, 38.00865342540126, 28.85581047304215, 22.894400089017807, 22.182362425711847, 18.894412094546905, 23.768051170533706, 20.690367337196104, 15.646732737941129, 10.223164616092559, 6.07552586063262, 1.8405793126552337, 0.5691422245675518, 0.5079756809338447, 0.4762029503622363, 1.5502258606495396, 1.491241503146387, 4.914542042439984, 5.838293558166874, 7.880277508689512, 4.94054735668244, 1.7779285196335086, 2.054596454385788, 1.9513791607272242, 3.7206073730222644, 5.361976613921504, 3.979611526573858, 0.288260254648424, 1.1514504974888218, 0.595512809532304, 0.8083992667736546, 2.7424163010812577, 0.2255350438457343, 0.07064247669111337, 0.01654341208538221, 0.09793940751302628, 0.36571597259852195, 0.19297878918868883, 0.1528646787928958, 0.3750266681515402, 0.6065608392800055, 0.4901721652957701, 1.280961889893778, 0.3699432457647016, 3.3606271926433813, 5.213992941764094, 1.9147964398707114, 3.6533735356023236, 4.966064826134713, 4.169079411414362, 6.598448407265448, 1.6927461614531858, 2.7569805518273385, 3.1570071510730253, 1.8837756399185428, 0.2729573112822348, 0.3059879582255118, 1.0298888914046749, 4.183529423129174, 9.14422550509053, 14.722928270216912, 20.00373878786641, 52.776412425502656, 23.145074844360355, 18.878157792552827, 17.23156052251016, 22.533092921780003, 28.10704177425754, 34.18349527543591, 30.90318376018155, 14.853610857840508, 3.564309011543951, 0.9003763958331078, 0.16696348515970094, 0.03711576483422711, 0.03610480456582962, 0.05617402907040331, 0.0033839645367416166, 0.012901694393686712, 0.007276727326004016, 0.04527919392492022, 0.029269302706985228, 0.06303737631007549, 0.03067399577928647, 0.022792743684183207, 0.033713890119425716, 0.07359026044967674, 0.0725273517591338, 0.07514442302166455, 0.028554626943303213, 0.03228604012439328, 0.0217548975600831, 0.028164661376767104, 0.07431305674535614, 0.11760454745061936, 0.04010253480725712, 0.013227467537827551, 0.07625426991932815, 0.11356649800173699, 0.03612324047172743, 0.04104517535456727, 0.02255189521688848, 0.016876028309906685, 0.05180129112916128, 0.038612018820018544, 0.005127834897833847, 0.10377815428880915, 0.04611504564602529, 0.05935946862483698, 0.07163658302517668, 0.029330727636754036, 0.032566761552926995, 0.08942497608762595, 0.031179508472221996, 0.04922790603051263, 0.011827830645826556, 0.01466053554923424, 0.018576567301586754, 0.015793642791498815, 0.022486651338817134, 0.03374813041920143, 0.05672272805485034, 0.019699692418197953, 0.0052794173637765555, 0.02396626972533282, 0.027306414990415497, 0.07246421845329386, 0.009734479113361769, 0.031827431164621826, 0.04485346737407869, 0.04142490981687461, 0.044021047726874395, 0.035696563971859795, 0.01460924404748385, 0.04315962782129646, 0.04843694323133077, 0.02520002176864974, 0.018778019697375355, 0.027565835344214595, 0.061102609765986284, 0.07694320512875434, 0.015116587690558406, 0.04466355800808919, 0.020905673774259708, 0.0914601729281487, 0.03188973709550356, 0.029631861478030205, 0.02405326858523392, 0.08081342003518537, 0.07883698979933416, 0.03736520306237283, 0.018775282848265865, 0.12226675171405078, 0.07375936669808242, 0.03673521065784078, 0.01639343505244582, 0.002862163378121031, 0.052134324871604486, 0.05543864978056762, 0.043552673061288176, 0.08008971209487609, 0.035380790190350626, 0.017241814226332693, 0.07088292870790729, 0.07943216350770767, 0.037109249256431096, 0.05758183820533657, 0.05337231529636249, 0.014385036925124306, 0.058248154668798374, 0.07498542147298014, 0.01712823211545906, 0.6856686105170559, 5.031168326254814, 18.633572516902802, 37.261261478547134, 44.09880384322136, 38.78677322018532, 29.605257741866577, 16.17121148493982, 16.12586006041496, 22.22405722064357, 25.989154077345326, 21.687431873813754, 21.20499014854431, 15.419833429398077, 8.752030653338279, 2.6843779702340407, 0.7943620232324448, 0.1968822676327921, 0.08468001134573452, 0.2638585156490726, 0.6868056075707559, 1.4306495867429243, 0.7334004234402411, 1.661578640341759, 3.8553706965138836, 2.8580730240191183, 2.9447323997174544, 5.446286980182895, 7.0310775022352905, 4.865663426537668, 5.4491816893700635, 2.097711024745818, 2.225508709107676, 1.8179799640370955, 1.567053318985047, 3.2527875083108104, 0.6441689535014091, 0.11667247125578505, 0.2507309555526703, 0.25819786133304723, 1.0626792931748976, 0.6499122840262229, 0.9779785285072943, 1.6601515104693751, 1.555747086963346, 1.8829603997930404, 1.4073535271229283, 2.072787794374651, 3.326220896936232, 6.246655439176868, 5.4168035041901375, 5.336303720551153, 5.949081393980212, 3.6264714694792226, 4.8136523077564854, 3.38227843084643, 1.788832831286615, 1.4216406379015216, 0.22890256717801097, 0.19991536294260334, 0.18702452401480368, 0.9200253253502231, 3.2260290989952707, 9.021887760008536, 19.60110160612291, 24.009641716557166, 50.9081639782075, 29.550132751464847, 12.836333917033288, 12.002729254384196, 13.003273913937232, 27.568955344538537, 35.23679287202897, 35.20040504394039, 22.415145289513376, 5.938139942384535, 1.6766961904302722, 0.13441604051378467, 0.08150191857449471, 0.07205345743005315, 0.06609703954910079, 0.01455110659252011, 0.005617834310302692, 0.0188498308641776, 0.039832098109106866, 0.04971367472241964, 0.026322445914810224, 0.06489965178432965, 0.05166454060423759, 0.0341603355181794, 0.12539081996487034, 0.009816433284281483, 0.08772849736194457, 0.01651716974353598, 0.06945549240035397, 0.029055506719516653, 0.087630353837965, 0.02416080051672555, 0.05603434059829001, 0.025732680787182143, 0.025117630927613186, 0.10129657333656665, 0.05613007860618734, 0.07764963012549185, 0.026459422435671575, 0.035968640098168005, 0.0067307953553785, 0.015681610093452036, 0.04665958477304347, 0.06287285892833626, 0.034565864160897276, 0.06262428637954497, 0.09088880923246184, 0.05540942352625632, 0.07943357310948834, 0.04613033676099393, 0.04783220874566225, 0.018474645048920667, 0.01698559420483728, 0.0825736755805631, 0.026528222876931393, 0.021302151088152203, 0.10295257197632905, 0.16188812201782582, 0.1350845594800288, 0.14298637337501974, 0.1113436938894372, 0.09370693260984075, 0.14715896318516425, 0.17064161117999785, 0.12265278341909572, 0.12802857560135666, 0.1289327355522302, 0.1394071493057474, 0.2714474745575459, 0.18164168382363935, 0.11893033155149992, 0.13702896724064506, 0.13053614225599075, 0.19558601622139254, 0.2187211973772895, 0.1970727170907682, 0.13481437559089354, 0.22539071288079987, 0.19740051079180934, 0.14350331418456572, 0.13217584620560371, 0.117941128180152, 0.17801313901380186, 0.09095260903479592, 0.20449977097732408, 0.1280201716168273, 0.10964964366247577, 0.2030854807385514, 0.15186758471592782, 0.08447110682966248, 0.2689199666342428, 0.18773623501821873, 0.11503484340444689, 0.23668795103026977, 0.0956894915490862, 0.1301007285233467, 0.1424772466623014, 0.09675829145576685, 0.18480962592988245, 0.13457120396196842, 0.19194046425963604, 0.16009215145341812, 0.2051541019952105, 0.23680882438296275, 0.26652940458828406, 0.12925473762856377, 0.17039062545424508, 0.285161949934498, 0.3090811148285866, 0.09599867697444656, 0.5365367870657676, 4.104030089032266, 18.1707485260502, 41.3863475861088, 52.050326793424546, 50.371269949020885, 39.32521658559, 32.093915324057306, 32.73017867918938, 28.432227834578487, 31.964226076679846, 30.404893698230868, 21.608323550993397, 14.995730096294036, 8.42023245749935, 2.9991636208949553, 1.109037418519297, 0.8554730408133999, 0.6019881523905263, 4.091263264417648, 3.805285706635445, 13.708420953442975, 9.850806170894254, 19.110464088378414, 9.787984509621898, 5.9125410837511865, 8.036254971258103, 6.6709137059027155, 8.18742262740289, 13.062668404271527, 10.891704174780077, 2.7410030220785453, 3.7242858207994893, 2.6074737743023904, 1.9942943030788054, 5.954472201485788, 1.0970178054225062, 0.20056564901624957, 0.3116365696393675, 0.3408169812492786, 0.9203452436674027, 0.7557578721354086, 0.7827493560410316, 1.5118752540119234, 2.1315988321458144, 2.2645073648421996, 2.981302372870907, 1.8439192108569609, 5.938014426539022, 10.785968842044955, 7.867439591115522, 11.26260644005191, 13.664146219530414, 12.40952414851035, 15.2619590105549, 6.7639459525385215, 8.750340111794012, 7.16526129553395, 4.427562134881174, 1.5893882753387576, 1.2750834827461552, 1.9830611252015637, 5.89413732290268, 11.938065059723394, 18.013357539330762, 25.02622788952243, 58.52506952901041, 28.46434420154941, 26.74076061094961, 22.460238818199407, 30.07841129456797, 39.309660465486594, 46.14412769194573, 41.199191693336736, 25.3159616070409, 6.693020184193888, 1.3489017539447354, 0.27777220452985457, 0.16726409806118858, 0.1722648289174803, 0.18830955989899176, 0.06519414364330231, 0.11575121222244156, 0.09380460882018651, 0.116803472290837, 0.12228935130781705, 0.09533654718149094, 0.15856138520663784, 0.14837711959356262, 0.09245560459432103, 0.266471947993963, 0.15689246266359286, 0.32915629566677157, 0.06783731552141328, 0.12036794150668768, 0.08694860453326857, 0.2328702744336859, 0.19504259941318344, 0.22445366477533696, 0.17696640243934048, 0.15431606300896214, 0.27991602497716106, 0.21868506867078044, 0.27425258210109127, 0.14650003563973213, 0.15039206873024666, 0.08117608605853974, 0.21939722400519157, 0.21172408735559833, 0.17702125433471896, 0.1865658518527785, 0.0957560339461892, 0.19419688431005325, 0.2601317430455839, 0.1907546061181253, 0.13772961593443347, 0.2185666008341697, 0.10588898699009612, 0.1864635025060946, 0.3277801259631111, 0.15143901980932684, 0.10170019442035307], [0.020748250366699313, 0.08500631883620255, 0.02074024091745096, 0.013263936195853017, 0.019789420466329304, 0.05040609946234092, 0.04786420440781982, 0.0110287971103624, 0.04158466213172482, 0.0577093612012123, 0.017673813122054263, 0.023138166983581843, 0.06303468351102164, 0.007630453582086991, 0.01156269240328261, 0.04170871857974318, 0.02591012590264361, 0.04423010929097091, 0.03614056938057465, 0.025241193248920386, 0.07182700950051508, 0.09505865644783744, 0.017140296085046667, 0.05536130554373226, 0.01290606109485511, 0.016416827547213724, 0.08534092305889053, 0.035631461820054444, 0.014737906599146946, 0.016810307542102474, 0.04870706200299244, 0.05534174348858576, 0.003431537878632005, 0.050268782032353264, 0.0394537387746236, 0.03650629975562615, 0.028047597396277615, 0.005926142086184794, 0.06535633977863096, 0.09860110063586505, 0.013465813770439598, 0.035244415048509836, 0.030292616143161734, 0.03417856841077728, 0.06060203259450294, 0.018170197877371987, 0.011084594166717462, 0.043331231516335285, 0.03425772444555356, 0.04455558174560147, 0.03445149489468144, 0.04656297342491247, 0.047072138442027, 0.026666019111871723, 0.013268278956773781, 0.03724243364206726, 0.45582825978917463, 7.164922991106588, 18.115652953424764, 31.97535187967362, 40.34721366820797, 35.0468050279925, 26.948981592732093, 19.58127402490185, 21.37527592720524, 25.76029750608629, 19.58113281957565, 18.76349122293534, 13.576632257430786, 11.516273963835932, 5.500943737645303, 3.4475405418103744, 1.1637246969246096, 0.28531476915363346, 0.0858307826603132, 0.7477622431132102, 1.1785398567876508, 1.4544363103566633, 1.6214282786653889, 1.7104560305033962, 3.85779619216919, 5.127510563019784, 9.800366451663356, 4.610695637041523, 4.165614487663392, 0.43017424282527744, 1.9555569752570123, 1.0781083039699064, 1.0946598480786047, 2.402053609971077, 0.7127623211952948, 0.15518615502984295, 0.1880284209525393, 0.2818630527584784, 0.9369130901271298, 1.0873225643750162, 2.5608230646579497, 2.248299640993918, 0.7830698259415165, 1.6008446605936175, 1.2282647240546443, 3.1776934862136845, 2.655139642377054, 8.01952802365826, 6.85811274474667, 4.42189529057472, 3.402548994748823, 3.1349984868880245, 7.539039148438362, 4.8745976051976605, 0.2558201695642164, 1.0096494613155242, 0.7193227304566292, 2.7536350152184887, 5.091872888226663, 12.182776831811475, 17.79955698597816, 27.308192253112797, 19.60801870592179, 27.48573833896268, 46.46510308788669, 16.71014024365333, 23.09528231620789, 21.774918379322177, 32.56908497502727, 32.808710413594405, 25.33857014871413, 8.884053710968264, 1.7350604457239953, 0.22540615721335336, 0.08304573895950472, 0.02087751812782259, 0.028599649930613178, 0.05532564032041738, 0.008156943198804173, 0.039843133605656125, 0.021373943102756338, 0.04980668545730653, 0.03163973579273349, 0.08062947466368638, 0.1325892732148209, 0.05078250527261727, 0.03128887518429228, 0.017743594155857162, 0.052729172992610165, 0.062127298329986876, 0.014607484918087723, 0.03991524163152903, 0.009444213186901425, 0.03479986188692912, 0.04029193089433736, 0.054509220419511686, 0.02871707397242708, 0.08193557796579215, 0.01375839711287089, 0.043271028496805704, 0.0515404420213834, 0.028444656936992562, 0.014899768528618641, 0.08166745485317323, 0.07647687974836558, 0.038487514210564476, 0.0538437313310081, 0.034266323782503605, 0.04663996909174227, 0.04263976055587973, 0.04492709608448129, 0.04312672051450899, 0.063143169221979, 0.09840608529386022, 0.0627666638202725, 0.04872991823621335, 0.0684363579738044, 0.05293051622086956, 0.037249251824593356, 0.014200923014281979, 0.005658912902412516, 0.05817183698978155, 0.031161557116936293, 0.03894054030458774, 0.06371641366351997, 0.03501142472809842, 0.01487413043862269, 0.08693249370422095, 0.030342101592630632, 0.04939501278943593, 0.03254192881286144, 0.031108901978680686, 0.0161677647021509, 0.01765612798232225, 0.028167773608959494, 0.0060132400587111, 0.061115805630482016, 0.0642649172955463, 0.06195688973210993, 0.047868663039539135, 0.05337359083275642, 0.0818022327016919, 0.03530241173481749, 0.11319396476591788, 0.005571538659428517, 0.020056306346950513, 0.06462887800749272, 0.0184210667747163, 0.0417139126558698, 0.02054172646885197, 0.014525095034661073, 0.06384597828371391, 0.054857418872416026, 0.04748052842314205, 0.010563578727024217, 0.056232110026382634, 0.06008747814884109, 0.036292955760032906, 0.06214091171240134, 0.04906986592217319, 0.05871013633065647, 0.0593994009578901, 0.07092381482042613, 0.055236743477683876, 0.0742235470322832, 0.03962590554428678, 0.014610823146217774, 0.010113867878493284, 0.03460130338827449, 0.10466504661786942, 0.05305498635636703, 0.039090789298737244, 0.028372198425894304, 0.03790888417091581, 0.03717070482971688, 0.1700003036568242, 1.8720613588248531, 11.135326508552799, 26.977628623285604, 41.43102338237148, 43.936276512761275, 33.96702751036614, 22.73855059377609, 16.435948917942664, 17.545838471381895, 24.90458146218331, 23.894257353198146, 23.24651125938662, 22.82141262485135, 17.419087079263505, 9.381001341727472, 4.708458262105142, 1.4407118145496616, 0.36978840407344604, 0.04154855640785348, 0.199927972749837, 0.24133687898997339, 0.24480904993270677, 0.27910844573090154, 0.8173013310278616, 0.6830430739829618, 2.193005008082236, 3.102622508041321, 2.591224620419164, 2.274778581434681, 2.3055086356978265, 2.8377519596007565, 3.0392754943140092, 2.944646352721799, 3.537605025114552, 2.14604516663859, 0.8591187613144998, 0.7222110657922683, 0.9344606894639231, 1.8766659762590163, 1.8208108121348967, 2.231251794484354, 3.322454440978266, 2.9487346881820313, 1.9239858177400406, 3.777357205267876, 2.569384373003437, 3.8819601987638785, 2.901464734346636, 1.7652695601986301, 1.1297308629558933, 2.907778524583386, 1.6637868121747048, 1.775271604138036, 0.9011663244135919, 0.10349364455548987, 0.31379850040520396, 0.385000029759061, 1.4410600474765225, 5.263718299327358, 12.217650625013537, 20.208211944949245, 26.744537853425552, 22.93300013388357, 29.981142397849794, 57.93895759890157, 16.918855444077526, 14.898081710261685, 19.525272384766613, 31.571386975626794, 37.83437467390491, 31.008775926405388, 15.1620719317467, 3.477133844167956, 0.5316730480520956, 0.04228999928360985, 0.02369340644368241, 0.03763012775790788, 0.06327585182002475, 0.0141669575485491, 0.02287928672176936, 0.030278623547224753, 0.04306919880271439, 0.058825064841057026, 0.02398667830763565, 0.09473640156248886, 0.04159907990645978, 0.030124287473999208, 0.01960034230573764, 0.08007517940695248, 0.040409364512250315, 0.042949141333660776, 0.022946156621459993, 0.03282110274378811, 0.07656127199410431, 0.055208685507457105, 0.030244988456909216, 0.019788752054615368, 0.02152082705569844, 0.026892080167008024, 0.035270431394418406, 0.10557297572133043, 0.037286184923422915, 0.023486030273019307, 0.05202704957956749, 0.07506235968321562, 0.05790598915829774, 0.014552269130945207, 0.0581640956713067, 0.07834187483475094, 0.06683751715407257, 0.021087069988190647, 0.05903071348345088, 0.04089670368440209, 0.0484443589624378, 0.06952706033424025, 0.019372616924585837, 0.060966598515909534, 0.08442564717223568, 0.06129450329969968, 0.024275097004588575, 0.28239005996334937, 0.1475613891717888, 0.08772395446055359, 0.16382172793870972, 0.2001325182256199, 0.25064604236714305, 0.10955648737088328, 0.12184550294712668, 0.07955000315222048, 0.2531732285335179, 0.09603181793805092, 0.10289817207282591, 0.13698059644910598, 0.08637925564882257, 0.14154876341983197, 0.10653545794587944, 0.19037890127829968, 0.10615272041890891, 0.18771673041966655, 0.19918581741231106, 0.2084947356413449, 0.1791721381126873, 0.13563899263258905, 0.20722788668447928, 0.08747239416885762, 0.22915139253581726, 0.15007000536687914, 0.1434363734217421, 0.15111954582314338, 0.2203384089854456, 0.21351026731633374, 0.13690878336708392, 0.25729185511027614, 0.1631855991699042, 0.12191810509971074, 0.15285459707581228, 0.14878814108669758, 0.11396329324211806, 0.17789885401725772, 0.15299882078843732, 0.15086427000501465, 0.17024516067918272, 0.11497626066087716, 0.143253339694873, 0.25753436790358636, 0.15556475568202235, 0.07434674163138674, 0.1230412436228606, 0.07908137184717963, 0.19183508120477202, 0.12451949454243146, 0.10931769010400581, 0.28871062241735, 0.10447478102099512, 0.1120973482067066, 0.2075866456594198, 1.5118730476787015, 10.240557386029153, 30.116909357809252, 46.52052617842152, 54.547527297850586, 46.59843229478406, 36.223661207383685, 27.072736294038837, 30.917092484812585, 35.426121757876494, 30.235217848131736, 28.439798009011056, 19.34640642135374, 17.083842100635653, 8.551532818425088, 4.374314488903169, 1.7549197736286348, 0.47964109167937313, 0.17806701031663727, 1.2912707367250997, 2.098920095351435, 3.213574593105624, 4.485968678228317, 5.534734956679806, 9.18637921733241, 10.424214524607505, 21.7770266532898, 10.255322167950293, 9.00914692109631, 4.221514636470426, 5.476336258073007, 5.07548620623927, 5.627734843761691, 6.135991648320229, 3.229210141205019, 1.3058294716381258, 0.8003147715522397, 0.7947793266465588, 2.774409603688025, 2.9986723440308727, 6.3460728141569325, 5.625848674005078, 6.401609653426755, 7.090135159031038, 6.529553446077532, 9.774515090450164, 7.725528238281128, 17.13372092093191, 12.108585200002118, 13.304556069835542, 8.833763041803914, 8.189256335458449, 12.897747447413783, 8.899887338761362, 1.8447549208518, 2.3715334025121506, 1.272669018756959, 3.369584905524408, 7.0122427709641, 15.71555660616967, 22.372016868283673, 33.015131027467795, 24.692314555568082, 35.029001389780355, 53.79636595326086, 22.507911305273733, 29.53753409847137, 29.519051890219416, 42.90811738660259, 44.097693812462595, 36.879116719768895, 16.2564024233049, 4.310833379145592, 0.5046121872240498, 0.3492244897830871, 0.1322956470352027, 0.19212882995845812, 0.19804411657875587, 0.11967781886097886, 0.07618706102573103, 0.17462260240027982, 0.1343615716623683, 0.14267924872617568, 0.15209466849844303, 0.3636927650340142, 0.1973882074197454, 0.1685187355765412, 0.17201156024971317, 0.1471401633875024, 0.12371814359099635, 0.13861634738502965, 0.12639367502302895, 0.12263486462254679, 0.10969048380971917, 0.14963695118504186, 0.09840197140170683, 0.10398358076570496, 0.2343654635572626, 0.12198514545396452, 0.10609025360956308, 0.16281078299207075, 0.10531209980047519, 0.1106751979058308, 0.2399391209286067, 0.20301648686009072, 0.1901967255699058, 0.07852906075816962, 0.13461683215873857, 0.17785069773033743, 0.15109648657662256, 0.15569143598118138, 0.13126297583503108, 0.14680124608980072, 0.19350884542349847, 0.1298467856982062, 0.1542852203091306, 0.13757385493766877, 0.14130891661249823, 0.1388184873447303, 0.10869328248044176], [0.04681173749568482, 0.030186700657190337, 0.044909077696502216, 0.016761369845499436, 0.03528365407199149, 0.025632673754326762, 0.09382504038512708, 0.06443875030644479, 0.04209155952858348, 0.007164384362347905, 0.03348366154598133, 0.014624050611840382, 0.06417524287356965, 0.03834894422682063, 0.03927113788743173, 0.01750629076043204, 0.06763549731864084, 0.1053758153331376, 0.054495775576440565, 0.06694450133269833, 0.04587902161743372, 0.025856629982891104, 0.015281412465077256, 0.024358332457561648, 0.02779944236540506, 0.018976587772129044, 0.02267858126170693, 0.027972898078000838, 0.01827383042132903, 0.09395999443386832, 0.04233387696947302, 0.07476240561734285, 0.06599845169412513, 0.05747712930784591, 0.02876226166864076, 0.07567873104445397, 0.057740096648734425, 0.03207564748252832, 0.04661012613665193, 0.058065446529297106, 0.04040258080368081, 0.02050523387057887, 0.059699561867502436, 0.02781380651398532, 0.014197119387737928, 0.022594447570642637, 0.0746476916115611, 0.019278753916883183, 0.045481402832534046, 0.030889044320511243, 0.016323818727546645, 0.07655925718286345, 0.024546604310613007, 0.022553302903449344, 0.03386498564073155, 0.05005884329758344, 0.04313079610226616, 0.15812741171929146, 2.8353254833529076, 9.964979502462572, 29.459418135304606, 40.129557424975985, 41.23079030744491, 33.34380995842719, 32.11692983104337, 20.57295903082817, 25.30006031836233, 19.251271294009303, 16.832563300286573, 14.436245176099963, 19.75456630029986, 12.677470080314144, 8.48255499716728, 7.069314237563842, 4.347158939607682, 1.5458690879806396, 0.613807847182597, 0.5605362992613547, 0.9640865965235619, 0.6957286932776052, 0.44926438781042255, 4.0381185806566675, 3.886350556727379, 1.211577735600933, 1.535362038881548, 3.2093938367982067, 1.922701241508607, 1.5799747094992669, 1.9448466983533677, 3.263429634032711, 0.6155096042540766, 0.8235917096176456, 1.053533919395939, 1.7356894958403803, 2.744581939712648, 0.8333631304483261, 0.15813720232296377, 1.9926117288489498, 1.659012674804657, 1.6101951007881474, 2.2700278557115987, 2.1830674381025377, 2.498682424906762, 1.1535303342726924, 2.078244301580614, 1.8036826796108678, 2.5839635777858, 0.5838875172118987, 0.08118056001201754, 1.464173226587234, 1.0772121649596, 3.5058527031252464, 7.629431149651928, 15.01626076236848, 20.583470982889978, 25.716972966347974, 22.09518382626195, 48.81850950179562, 47.16879590865105, 26.47461210527728, 29.73204835768669, 26.41389381500983, 32.74896487112969, 31.935892835740123, 30.737455775660855, 19.768133778725904, 8.233666881438225, 1.1422120899923387, 0.07272309488466672, 0.08019429841829885, 0.05348334441922846, 0.007211057311524788, 0.011223979076490769, 0.10579934704207605, 0.0552663489455177, 0.0622196157553023, 0.028148391584475196, 0.03758007540337501, 0.04620399994535312, 0.06831223640831248, 0.007519057694627273, 0.038868665935531746, 0.06344941286971012, 0.04650185493031337, 0.01581560174423841, 0.037680318008267114, 0.04200941575090251, 0.022024828640203324, 0.034881331507236726, 0.08201723527764121, 0.03764012137488012, 0.008978468118115299, 0.016105073812087218, 0.04818255990563382, 0.06673036443610346, 0.03249337416022055, 0.06155179392906928, 0.03494791603917557, 0.06414621580211867, 0.03395551425074378, 0.031947040472239736, 0.026169716711005857, 0.007558475791161219, 0.008998614315304064, 0.060079809608719045, 0.021343994810576403, 0.06124313710437668, 0.07327754335898547, 0.01570877461363712, 0.04518696843015571, 0.01682895412217946, 0.06009723810899643, 0.03213302555283712, 0.08921992499381305, 0.02477845507523706, 0.03760033459853261, 0.03576329789094387, 0.01639523535906788, 0.06551089035647531, 0.03175186616699061, 0.029776200103843888, 0.03963252071351294, 0.05616104771052638, 0.03350339597091079, 0.06095114269203717, 0.06415758837735461, 0.0269138389792774, 0.05592711893240771, 0.05957448269210516, 0.04002764205177946, 0.027003440622901245, 0.0072384219721800865, 0.006920157926112053, 0.018686460699104977, 0.015058182104821167, 0.05603376986278642, 0.0760031079933528, 0.04879612738506929, 0.023492651187904903, 0.08668091042988724, 0.06592767283080087, 0.06459268035307046, 0.021974628813745036, 0.028277094355754318, 0.04641123055931061, 0.03468055135360168, 0.06569218506375629, 0.029829393418866302, 0.16062329553308027, 0.09096452170201848, 0.008653772285117978, 0.01580866864852367, 0.10362182638698048, 0.022437432104901924, 0.019374788783851172, 0.020237505293240952, 0.016151357014032624, 0.03743345000510735, 0.06272975370408067, 0.05172334934374498, 0.02628744527276966, 0.04375754412443888, 0.04306690053894155, 0.015902540274715472, 0.012428892697508057, 0.062342515410554994, 0.02924418076872826, 0.039397822017030376, 0.04213934426286048, 0.0557122236087678, 0.04437792595596083, 0.0859209665307595, 0.03461764404369939, 0.6283732010952888, 5.2090389882364585, 15.541042512462987, 38.39759957405829, 45.52516591164374, 43.8173855504682, 30.27556334772418, 27.95286320870923, 16.531756731771655, 18.67750306283274, 20.704344703305154, 16.762137143842637, 16.388244071314414, 22.83163824389058, 20.624077320098877, 14.087918112354895, 9.34825151197372, 3.4935425894875682, 1.6905080815476758, 0.7623057175547846, 0.26689841381965146, 0.20048882571920273, 0.19771898886369121, 0.08992956755983253, 0.2595329993674832, 0.8914371916363317, 0.320512494973598, 1.0245059286394427, 0.893405547305461, 0.6273318731015729, 1.301901708206823, 1.3909309309336448, 1.856246239716007, 1.328911394361527, 0.5332757652767244, 0.7423061649164846, 1.250252305499969, 1.8782236475136973, 2.148348088226011, 0.952185083541178, 0.828530463960863, 1.357477526030233, 0.5299622204995925, 1.2481193941447044, 2.2405706105693697, 2.321621487217565, 1.039128524641837, 0.8616755337965104, 0.9143928017827773, 0.22170278093507215, 0.18328298123613482, 0.11652653916708886, 0.4072497052050406, 0.4043816865211533, 3.5444623087683036, 6.585162358899271, 16.211160825144862, 23.910684239479806, 31.548466605524865, 27.474422301015547, 53.27355715536302, 35.317907487192464, 24.47979465607674, 35.14904945127426, 21.934388222232943, 30.91293477242993, 31.8967063965336, 36.76170841340096, 25.057032223670717, 12.082568118649146, 1.7585854737028, 0.27309719893720846, 0.11678925369896236, 0.03144689039477418, 0.05655551787405726, 0.03208177427070276, 0.029575383561032436, 0.10033235975330877, 0.07986026876155408, 0.028136643626156355, 0.023497385611276955, 0.018513732770037268, 0.10870019259351878, 0.05168925460067488, 0.06379666137358835, 0.022079161511013107, 0.014060802660101365, 0.037390732942449476, 0.04365878006924064, 0.034370741566583034, 0.08810493764617751, 0.03114280711498953, 0.011389194555851, 0.016214645452677243, 0.032287055190892956, 0.02099076890566897, 0.04300984231034114, 0.051060258110444394, 0.06588259621733619, 0.053987533695274786, 0.05963291987896927, 0.024796714780912287, 0.04873240802196726, 0.031587461783220215, 0.06236879605679743, 0.04192806487422317, 0.05549904815251789, 0.009165821623267427, 0.044477770195132306, 0.07911806745875267, 0.05906630592841295, 0.025133479371546738, 0.04248383868065092, 0.05710564178204345, 0.02336967683907959, 0.04232270357709739, 0.030117404173999548, 0.031395987682645364, 0.07297238755610681, 0.21889234141957378, 0.07787089930066178, 0.11614773167116989, 0.1327107747596118, 0.21336354615707553, 0.11972007627088217, 0.15938859162551744, 0.15928592052190535, 0.09871186162795752, 0.13102407897672347, 0.08366870633777111, 0.14924122080687555, 0.1254762923945823, 0.17098746923429353, 0.10366496479799671, 0.1256501790316355, 0.14397333976962876, 0.17818022279008744, 0.1138605148861966, 0.28542974362930945, 0.1180594657818156, 0.1435673284915186, 0.0819053941015755, 0.14945929539540123, 0.11150288696010267, 0.13731623489049175, 0.16523637057792756, 0.1677021164927752, 0.08028039137922949, 0.2394661535659144, 0.1534511497424495, 0.15065449980958817, 0.18596467201507863, 0.18069878280643495, 0.10760677062095174, 0.23184747044597906, 0.26447469548832986, 0.11266737890940522, 0.14413380454624855, 0.11707133493356167, 0.0840204019820498, 0.11495193736928125, 0.11688944267769975, 0.1945891826143188, 0.08826681202457798, 0.126109586638068, 0.12803665016807858, 0.11993066618038763, 0.12677412960798512, 0.18721950871329154, 0.08144970202157575, 0.218171299465241, 0.23336608653828023, 0.1333723682910204, 0.15525216116539894, 0.18666000405867256, 0.1678984495060098, 0.4595354205418018, 5.35640831916563, 17.911905434823808, 40.91365491190265, 53.25533774591262, 53.08334181385656, 45.70137839163504, 43.835193111050515, 28.60000525751422, 34.933193575951364, 29.40115720995011, 27.009176246581543, 24.460745665334887, 28.49797264222176, 19.638934827619984, 12.298657374997294, 9.956460114448301, 5.1506265613340565, 2.3448522148593782, 1.2397526108449506, 1.0083704009171457, 1.8642363529051504, 2.4780262429868025, 2.219448647191448, 7.2850318493381625, 6.466938199535494, 5.81101494450723, 5.201239355148808, 9.49152490785045, 6.397772594805687, 7.509779247545428, 7.198348939418794, 9.426056627304325, 5.032237662423042, 2.8181663395897036, 3.8066031327170715, 4.992922275297103, 8.330148362344312, 7.710551648370682, 4.463909268379211, 6.563295145188609, 7.096853688839944, 6.4881180178734565, 6.844121650342019, 5.784426177701643, 7.1094773469432715, 5.846166245398983, 5.575226564561167, 4.41959285928357, 5.9673444397987865, 1.5535992215717993, 0.4525742860090348, 1.7832891739183858, 1.7679650865254866, 5.250594539027061, 9.7963930906788, 19.186599254608154, 27.219140721905617, 33.42702696400304, 30.009410919681674, 56.812150862909135, 53.90509797680763, 34.2184788950028, 36.340441934524044, 33.983897624477265, 43.54791871963009, 43.52847160831575, 40.96783461109285, 27.305236747187955, 11.583091539721336, 1.835415144601176, 0.3003512364962409, 0.1822274499723027, 0.09953576620788344, 0.15355299347110335, 0.13052359373579103, 0.206630322781782, 0.10842321350449517, 0.16877505327424697, 0.26546794380391797, 0.11387741478580622, 0.12432562833231305, 0.20940832613456636, 0.14764640960962544, 0.25704848429849075, 0.21055335178971293, 0.13470364524231804, 0.18702308376950605, 0.15550032768759037, 0.10989774123675401, 0.1053120461743205, 0.09782001271002716, 0.2845608773491075, 0.15445952063366292, 0.12914037602322717, 0.11685728230663847, 0.16049917396758834, 0.22437031440917524, 0.17419245935255484, 0.25719143630516145, 0.11693758364286154, 0.17936287868407466, 0.1986709910054361, 0.08094697214302518, 0.11525297161912727, 0.1454757147979352, 0.10184693090136974, 0.19964888691902163, 0.1277044438005936, 0.11606608202020008, 0.16594058924144314, 0.114324021063024, 0.156987059200483, 0.09817481867127842, 0.12761781457811594, 0.11457042558298958, 0.21796136073047118, 0.1619245571595046, 0.1782792932804554], [0.08226032263689464, 0.04185935827873407, 0.038713238187014096, 0.014844296102021492, 0.039214432059276494, 0.005788998941199915, 0.021360963658099214, 0.04275344034296371, 0.04293894087294898, 0.03140516158553862, 0.05579987172818473, 0.056714998227694345, 0.03636338988379125, 0.0570775340161016, 0.07723347584326422, 0.03297229019564486, 0.014481327473937024, 0.08303467664987811, 0.08421272069456116, 0.037618820300145496, 0.09386832435284892, 0.021284900703317216, 0.02240333544661201, 0.06983148069271157, 0.06878935596755437, 0.015379667071805847, 0.010088271923333166, 0.03637810260237705, 0.04566068272857417, 0.04584860409640017, 0.10255981401930894, 0.054112348570338184, 0.07166583992300496, 0.004618370627623893, 0.029676256273242257, 0.039529922388253674, 0.03420710901639635, 0.04493489102911084, 0.0293166182124086, 0.0495644944209245, 0.012649080731094846, 0.041317760929345124, 0.005206208086512502, 0.013515090460949128, 0.10748602750320589, 0.045946418202572295, 0.023617370301977764, 0.01966684639844443, 0.07733476032773334, 0.0907290339349739, 0.06153957865711662, 0.047081863928225734, 0.12943882855676836, 0.022344898259747895, 0.029189286738513943, 0.08881679420629818, 0.0772068236443785, 0.06054683595955853, 0.04173745070734332, 1.5842552410979427, 6.099030663890224, 21.08935671467935, 30.14494645980097, 38.05862834376674, 38.87803108461442, 34.780264285302934, 28.637322687333633, 22.247467887017038, 30.405619336712746, 28.009472816221177, 19.998647551382742, 15.664274557944267, 15.833184565267256, 16.34062159445978, 14.334732274855337, 12.962105697201146, 8.672077059745789, 4.431117273146107, 2.6560807660702737, 1.54082847458701, 0.6633883834846559, 0.4360215468031745, 0.14456270653153622, 0.37379547292667054, 0.7906503578828228, 0.4988982131884944, 0.6975566403519723, 0.8997689187526704, 1.2302055618455334, 1.7434017336176288, 1.815116388663169, 0.37143849617531227, 0.6082047413914435, 0.9105193999505813, 1.3768950969942155, 1.1347159502967712, 0.7533188933326352, 0.9606659832981326, 0.5972865788686661, 0.29212115392569576, 1.5223858577589837, 1.436634633329607, 1.9386446956665286, 0.4902622572356655, 0.2833997025605171, 0.4522426618683723, 1.004830890845868, 1.5705297646983978, 3.1470073134668413, 6.047906491064257, 11.43608110566293, 17.754288911819458, 24.19925497424218, 33.519312489417295, 25.957598609309045, 21.847025271384947, 21.434444881254628, 12.867051959037783, 31.684949398040775, 27.575331157253636, 30.689171398839644, 36.00654625123547, 38.951081306703635, 26.578645129357618, 9.973747960982784, 2.4777970294798575, 0.29452280892479804, 0.02190952474671987, 0.03955462106293248, 0.04639063811590595, 0.04987224343142683, 0.06152933223112937, 0.04487215991943114, 0.02918161436795227, 0.059140233413106015, 0.008445540968809397, 0.02961967493437471, 0.023547503083283385, 0.04166662587874359, 0.06735055091520471, 0.08662509326372417, 0.04544062780276422, 0.10691770517657842, 0.047947566265300404, 0.06693717753214222, 0.08578956712998691, 0.028178188574290084, 0.07683201512742428, 0.08273987835573574, 0.009888799864828829, 0.05951051435042774, 0.05262973094959894, 0.03869426218912967, 0.03192971347861233, 0.10149150440889983, 0.07961632338382545, 0.030430397056343577, 0.061341430015501484, 0.033870405712795836, 0.021741579121519482, 0.03391360158040639, 0.0527957919985056, 0.041361343671357444, 0.02900953186796077, 0.06496738161771529, 0.04639220093527148, 0.010799875674438814, 0.042644923988489375, 0.020243802535978538, 0.023734357673674825, 0.03466460523345778, 0.028307238000354944, 0.04766726618512504, 0.10337023545176753, 0.04569578870770432, 0.04065773021730204, 0.03111379536529703, 0.010632008573250666, 0.03201369203687195, 0.03343672716930028, 0.01952621180774464, 0.02585490053940204, 0.03277807158508128, 0.021851863223879088, 0.03525565355835903, 0.028670488165751584, 0.046599377923074274, 0.008425613106679051, 0.010725094959320081, 0.028511802628335935, 0.04501108230362016, 0.018899697442388824, 0.07272436659062102, 0.025604608123220747, 0.025215766790713516, 0.006799737522904311, 0.047210539886427504, 0.09339221602966709, 0.04401420656171057, 0.0286258194941066, 0.07946425493085578, 0.04115986254727168, 0.0293307218910946, 0.05035708898738508, 0.021436517164411566, 0.08703429146759933, 0.0657282141788352, 0.021771468041885286, 0.08060093022762768, 0.047082783233734875, 0.006234459438165951, 0.01007179624491161, 0.038825466237481565, 0.08454128814440581, 0.05233070001967492, 0.016898595344936176, 0.1309971892905812, 0.045233167362429445, 0.01813090139729602, 0.01329897418467989, 0.054470437218344984, 0.0025728677498972827, 0.03611696238118795, 0.08259727874951017, 0.02646648385111363, 0.03241352481587279, 0.08432460017502309, 0.07996915283823207, 0.01715358962575274, 0.07043731068411181, 0.010782828302903762, 0.023272148100659255, 0.050375103544924534, 0.11538870707755128, 0.09322561488877382, 2.595065356262269, 11.43311579381266, 27.292946000253004, 40.35288541547714, 45.42753811805479, 43.84344970026324, 30.901824658916844, 21.990991946189634, 14.514402324153533, 18.284618854522705, 21.23014234727429, 26.973437570756484, 19.47710567905057, 24.670576780073105, 25.486514106873546, 22.216502735691687, 15.00892004659099, 9.76047202464073, 6.826375376793647, 3.049229979515076, 1.0918042400190908, 0.8608411721164181, 0.41427405731331923, 0.12216218837326574, 0.3468088613402459, 0.27454623892422647, 0.23686269568579815, 0.23413114790474218, 0.16835439439502456, 0.338258125008114, 0.15409365236278505, 0.5666067799733532, 0.31379773431727964, 0.7609919074081606, 0.6513380655838598, 0.5280038546169958, 0.19648030129892213, 0.6973882235826985, 0.5881543205149713, 0.012784137244095967, 0.22824930868321852, 0.45855118142020324, 0.39251722155078766, 0.1921890138257896, 0.17329437447892082, 0.14157340080747682, 0.15409095573329157, 0.5301750703684746, 1.9521994263895097, 4.024105422919797, 8.452094851001617, 14.43902123358942, 20.915672202264112, 30.356866236655947, 36.55700775884813, 30.100435403085527, 25.381016077533847, 21.38176941102551, 21.470460084176835, 35.538972270104196, 27.678589513224942, 31.873370255193404, 36.683170795440674, 41.99265580023489, 32.11896946353297, 15.17170919526008, 4.587729669386341, 0.8922739435107478, 0.07356029875095814, 0.021708403683958516, 0.03234176919044506, 0.08000907367996632, 0.013589272669877016, 0.011403752141632141, 0.03390750352052912, 0.06338896470204478, 0.03390174636977815, 0.027686396516078425, 0.05737063542549169, 0.07151072244009665, 0.09211899322127143, 0.08672442422398637, 0.036180436596154206, 0.05041975497959122, 0.053161549186634446, 0.062491416089957764, 0.047942314732579455, 0.045742454953611865, 0.07684832513933221, 0.04498113975709966, 0.015720725585255894, 0.06454241732435842, 0.026492534670978788, 0.03445607227002902, 0.07183970357742041, 0.03755588234672624, 0.05300976418619675, 0.04521821715658711, 0.038754878896138364, 0.06192370663366972, 0.037245812089813334, 0.05485597479667875, 0.04455189686268569, 0.08306657655104514, 0.051806094500446515, 0.037600541442272165, 0.06057274122271807, 0.06178234042900224, 0.02196281573795263, 0.035639394660510366, 0.06666916933271193, 0.024526684109361905, 0.057809734041051525, 0.03647541109051916, 0.015095500162832681, 0.05125042028544892, 0.04739114128413701, 0.12436018655857733, 0.13051752631943073, 0.20285259000957015, 0.15904398995541758, 0.0841608795247251, 0.0773060473523313, 0.19118612812411404, 0.1008004318141649, 0.19298913137566662, 0.17832148940332476, 0.12463361866051152, 0.14090750186193374, 0.13471168916552298, 0.21221381672207387, 0.22381370556691002, 0.14532064328030234, 0.1417849942921631, 0.22888563663488437, 0.12943087656411434, 0.17997161214870794, 0.1567841225093411, 0.1974957355207974, 0.11464030812344245, 0.1807672863886241, 0.1666608344643347, 0.13070884911764052, 0.07205555651096568, 0.16689136564250917, 0.19651108271171971, 0.1307069645413468, 0.25260158904617835, 0.18684746577374398, 0.1587130552938869, 0.08083991901648623, 0.13815497859351097, 0.19185783401612314, 0.16434776987279617, 0.13654132163332355, 0.18641468738355946, 0.19809152209951034, 0.14029083172640494, 0.1178741031476567, 0.11170056828808402, 0.09078714170403059, 0.1852652643837275, 0.13724990699800754, 0.06782900346743484, 0.17845809820198244, 0.20620597135876456, 0.21274292300785744, 0.15535446454680737, 0.1295500645233739, 0.20789853537515288, 0.13767096424295058, 0.11239783853412637, 0.2572822943329811, 0.24656987238314845, 0.23842790524565408, 0.14383594956128828, 2.4252228054308125, 11.083121722744359, 31.05606402120283, 45.310733856693396, 53.73660864368562, 52.65896881780317, 45.626794522808446, 38.29909709192092, 29.065906347767, 39.20826719653222, 38.61210615404191, 31.018307285924113, 26.324534377744122, 26.15133623923025, 25.566457894540605, 21.78943507132992, 18.100926414612804, 11.819845803322332, 6.567769098666407, 4.117191356997337, 2.398710769991721, 1.1973410027642404, 0.9010028718940674, 0.8874295099127678, 1.165137117908847, 2.273268468918339, 1.3646682111486312, 1.951440080038963, 2.4254476062713133, 2.8502390701924605, 4.394635308173395, 5.385426013700424, 1.5083647327077006, 2.740688987316624, 4.892631192361155, 3.9242163829265104, 5.714902656693613, 3.1516737082312187, 2.6100255212476178, 2.24585747526538, 2.307873089467326, 3.207419413712717, 4.3964714677103105, 3.8089246855628107, 1.6935161717476386, 1.2264041722782197, 0.9854657815829401, 1.502374292862031, 2.6961418938252235, 4.641698050883509, 8.910279658532913, 15.173324231178531, 22.756195375996253, 32.14341759681702, 44.11212421232655, 34.78255887185374, 30.15509755380692, 29.337497142053422, 21.49797158856546, 38.020706868940785, 37.458262520451704, 41.028345015741166, 47.13123529188095, 51.028823929448286, 35.80843910094231, 15.471253741172054, 3.90101678909794, 0.7497809154372063, 0.10174371587533144, 0.0843215434842052, 0.21150072676039514, 0.15253397395774243, 0.17305530908126987, 0.11817345966494854, 0.15626949528532644, 0.1572231981422632, 0.17867637197336844, 0.07084006608854379, 0.16205330589605918, 0.20132770731804833, 0.15780182435147225, 0.19714275284880595, 0.16328825495175778, 0.12129391198076549, 0.13700270574660073, 0.11282350762837356, 0.16298290762689807, 0.24604464250226177, 0.197506828473941, 0.13767568334456415, 0.10922629581463915, 0.14882362627935025, 0.11396417424323098, 0.16575479759804665, 0.1448052806118804, 0.2551625137247386, 0.13435804765791665, 0.160753499836691, 0.1379446721365375, 0.18211576967470108, 0.14427220599064905, 0.17148933343348965, 0.101230199478807, 0.19984137417087633, 0.09304538504370759, 0.23601511132813272, 0.09563525252404714, 0.11146377051068891, 0.0885163575050331, 0.10817944432698912, 0.2202947726172786, 0.1740780211384258, 0.16413467485577832, 0.15771718695759773, 0.18086551418227537, 0.16809939436854857, 0.17475639199537618], [0.054203884585970835, 0.029032989480202238, 0.011903388940188433, 0.03742822911590338, 0.044938223511581464, 0.02377872565580953, 0.024777708139510888, 0.03527025902463544, 0.0533286291324804, 0.04276532619710892, 0.008347372546972287, 0.06191431056527842, 0.11767469812184574, 0.023717804428850933, 0.06832688400942473, 0.08171882870937548, 0.0536868786589513, 0.06551428412597987, 0.053409455238931605, 0.055171740917308684, 0.021668107459141363, 0.014271557278510545, 0.06323096672854116, 0.07560901704334444, 0.13094417600622102, 0.04253235885933523, 0.021836905357157512, 0.017892849150924914, 0.05397083297852547, 0.034233734402204716, 0.024980508850046226, 0.037558084849508545, 0.007131109333356783, 0.014353005831400234, 0.030813034991883946, 0.05601908395727796, 0.05257497864565062, 0.07343407810455369, 0.05856867053455884, 0.009716971131462243, 0.03272968930222335, 0.06261641482612298, 0.06627592107942028, 0.032673366518030246, 0.0367335137730885, 0.014970888301069218, 0.06607118408165633, 0.08472718704011171, 0.04974920204990814, 0.0342848286363146, 0.03747900925396431, 0.04179317594295548, 0.03205575409435457, 0.0739790500712491, 0.05266613161732113, 0.026475318760100394, 0.055389872962428685, 0.017822305859637358, 0.015679105943549546, 0.00884161321371193, 0.20173557252893526, 1.8612841564801432, 7.752482766105284, 22.84788077877414, 35.01389634224677, 41.84518252649615, 46.919796005372085, 37.17189811891125, 35.41735918291154, 27.948438775154855, 24.067553550966327, 22.312608649653775, 21.44397427958827, 17.604538702195693, 12.331426816601908, 16.90062818988677, 30.691928825070782, 18.8437605673267, 17.47567315255442, 13.36310136702753, 10.25263044141954, 6.57811729177352, 4.345261983333096, 2.521312539615939, 1.3015138838560352, 1.6659006019753795, 1.0846050972900083, 0.5902689683341211, 0.33981683814237196, 0.28873146000889044, 0.3382840187799546, 0.22645981922265024, 0.4183732712220761, 0.3671014885748587, 0.5431986876553105, 0.2971517468892759, 0.42087687720214173, 0.5662165654282416, 0.37690272554755216, 0.26782452218955566, 0.34004035195516, 0.7451278199591945, 1.5098944570749038, 1.9974214126986845, 3.5536127080840454, 6.3503854601613945, 8.907926236429523, 10.401051948147437, 12.11679962373549, 17.63725911417315, 18.567664930897376, 19.71890607187825, 14.899460423377255, 18.800094781383393, 22.737675905227665, 19.596035865045366, 21.687400494852376, 23.275532876291585, 27.898801180624194, 35.67455291748047, 36.69171764004615, 30.75959755528358, 13.581232217050369, 2.4218113239734405, 0.4216135779936468, 0.17109199427068236, 0.013483422301379184, 0.03473479037864074, 0.026157388441084374, 0.05395360366110841, 0.01603565762765826, 0.012437348392972303, 0.06461224623865659, 0.030557048627205437, 0.024649432462249554, 0.023537806325381803, 0.07906188257038593, 0.01843160048367516, 0.0540680188925997, 0.06128449436096896, 0.04114227699896982, 0.01015966844504639, 0.05366214934075552, 0.022266314875695015, 0.04440571579541411, 0.07963896894286718, 0.025178952435512218, 0.04390534546767031, 0.09889797502828222, 0.030973013302671815, 0.02223633785521792, 0.06421938869020631, 0.051868450227043325, 0.0380818591633391, 0.048758355419962644, 0.03458000997441911, 0.07713443599641323, 0.023491731882395766, 0.04577748432394959, 0.0286669296873433, 0.01161104021218395, 0.08034258239692257, 0.04501567883116584, 0.024294546061766245, 0.023152789686836546, 0.005805104024588101, 0.03947831870567414, 0.029275747421648235, 0.06414572550584713, 0.056267916975963506, 0.07337435388997679, 0.010473703206967442, 0.056499030380960436, 0.019815314238169984, 0.08146690069547585, 0.08141669895379774, 0.05458428171433268, 0.06516081115771687, 0.052694457718321396, 0.044526474234918435, 0.02114569486659621, 0.02807418256246996, 0.032796384916911205, 0.01793585732699402, 0.05053458772900124, 0.03218687004259518, 0.0749181742749868, 0.028963384646621924, 0.03407376758273571, 0.06882278038369072, 0.06935099800748211, 0.04808023354158767, 0.03435291470058503, 0.0550120996852075, 0.05830811637063181, 0.024335631357145407, 0.04760170821100474, 0.03614198664323457, 0.05552914391662325, 0.01243907496363165, 0.03528528200883058, 0.09460664925075347, 0.036265943499822775, 0.08555743482805069, 0.012902668282960453, 0.009172448283812452, 0.014894627121036813, 0.09254103105875755, 0.01893331529572606, 0.022020676443653724, 0.012058692199418382, 0.0801069873775686, 0.007223710211204186, 0.005298954521065518, 0.0818211320907839, 0.06364530538238826, 0.06532922792699068, 0.1005664609012104, 0.05319696160093431, 0.04372050377329992, 0.061009162360982555, 0.08948274677799595, 0.02499278923947244, 0.0049027281009682245, 0.029330425032023943, 0.03652459393525797, 0.04494966503473059, 0.013858226987893784, 0.0642872870629353, 0.04023962241086749, 0.04140614066272974, 0.07818146368428584, 0.036458894234871676, 0.04447456794760881, 0.1369880275019715, 0.05483442091292912, 0.4822577722370625, 4.133447129880229, 13.014332056045534, 29.677115563423406, 41.2968312540362, 46.58805370330811, 47.50751610725157, 33.49747273229784, 28.389085685053182, 27.321371416891775, 16.641100645065308, 17.37023788113748, 16.8148204588121, 20.954111429952807, 22.76523251687327, 28.88882898515271, 30.74928564410056, 24.97226195950662, 25.98131718174104, 19.38799923466098, 10.90200431885258, 6.688434443166179, 4.992293225180719, 2.6829328219736777, 2.0910425051566093, 1.6588517350535241, 0.6908433812279856, 0.49577156322137006, 0.1571552767868965, 0.22027752031722378, 0.35156121116972744, 0.3114671416340336, 0.29497691520279457, 0.16032542522636153, 0.456254878832448, 0.3076210431754589, 0.3789516736663157, 0.12955987044880468, 0.25807026172837905, 0.25608814712012967, 0.3119182754908839, 0.727936377929103, 1.0485635409432075, 1.6688570884927627, 2.919431886365337, 6.499327661529665, 11.434146396575436, 17.412552410556426, 21.790370556616015, 27.28452074912287, 25.225552935754102, 26.674923627607285, 21.568754680695076, 26.341792806502312, 22.853644701742358, 18.366106094852572, 21.49682233410497, 18.758262703495642, 25.46732391080549, 38.00220504883797, 41.61985804957729, 36.97826247061453, 21.93199557642783, 6.559685584037535, 1.1827013689664103, 0.22550548817361557, 0.03721721785803957, 0.03641823794873011, 0.058171737398351395, 0.04873759443721464, 0.04406210620917621, 0.03506837187394981, 0.0007213300752130548, 0.03376038782598992, 0.03035242462741031, 0.04512179733043717, 0.015725911042893368, 0.010222006934664903, 0.101096042161507, 0.04453761315333747, 0.12186394268346411, 0.051085240237655184, 0.05587283011165358, 0.019591940236428095, 0.07723797277937974, 0.03841463243588805, 0.04128932374559584, 0.01504436570910677, 0.049317381269628965, 0.04309602337138307, 0.013530822076474228, 0.10455461504358439, 0.07380985955317175, 0.01171250472731528, 0.057362714076354626, 0.029601325213368383, 0.12931579483612893, 0.03509785093727612, 0.026338556743857842, 0.031086771613768036, 0.0298891521073998, 0.051623685135235714, 0.015709692961536348, 0.05630504925765338, 0.0254451890566176, 0.04116023026947533, 0.05145678138961235, 0.02966150908069986, 0.0613478230192296, 0.03498321354028679, 0.20199320789787079, 0.039735739569990866, 0.01942264438126116, 0.04582428463524388, 0.05086744144078224, 0.09800218841842107, 0.12375173654647605, 0.08411553478048694, 0.1694558143255211, 0.1270599493516549, 0.16258228960777485, 0.12849136165553524, 0.13131294008945266, 0.16558814283099868, 0.0669364420877349, 0.11463011149317028, 0.16539087519049644, 0.19569343707013517, 0.15153036813341803, 0.20289512321112618, 0.27371889460952054, 0.17396923665317798, 0.21041236096812835, 0.12103490531444551, 0.24844271220987846, 0.10749024098678943, 0.09406541579312856, 0.10557132097141397, 0.20477830522483398, 0.22881046808775396, 0.17387229588723954, 0.1689840267382322, 0.13425770546159438, 0.13923816563140962, 0.10622513871039115, 0.1144591972772633, 0.20395454620161366, 0.17824658132608862, 0.08160143339585874, 0.10628445689836818, 0.053705172838583115, 0.13661209283576858, 0.10331909142194257, 0.11138235834697563, 0.2002299492878299, 0.1351652285384555, 0.16987995124391972, 0.20358195167876061, 0.15031627199101835, 0.10805690856350046, 0.1592528714888519, 0.1671477139837319, 0.17491466576053252, 0.17778668342338455, 0.10081438227526604, 0.1596819573352414, 0.14819652202629274, 0.1151517867260883, 0.1269292241082557, 0.13852977944958594, 0.14967957631714884, 0.23690294594533984, 0.21534800499437318, 0.17744627991510978, 0.21542499683076338, 0.0901086942382878, 0.6869330233143223, 3.686843855727104, 13.032504397053874, 32.85727720106802, 49.35029268264771, 58.8119948294855, 61.26328791341474, 49.590467253038966, 45.39943825814032, 41.65135468206098, 33.519261498605054, 31.788017519058723, 29.81816399481989, 28.073480013878118, 22.764502956021218, 28.285074234008793, 40.05637776467108, 26.88630407856357, 24.56962085539295, 19.016631187931186, 14.01975614409293, 8.852651215368702, 5.480425328977647, 3.9243570979564426, 2.2356941238526375, 2.717233703982446, 1.9017386244189356, 1.1188506983941602, 0.5506941531935047, 0.7277587068177039, 0.7482421205889794, 0.8680799675564613, 1.0948240973295704, 0.6365208832486984, 1.2525566979762048, 1.10795239287038, 1.0212852337187337, 1.131879831514051, 0.7306385232556252, 0.7014264262491657, 0.8813121446198033, 0.9598448596173718, 2.166409867425119, 2.695051965213591, 4.936311687192609, 8.21803721689409, 11.966514991175744, 14.733300978137603, 19.417313068143784, 25.833371262396536, 27.877832189682994, 29.33401799971058, 23.486081784771336, 27.407975389111428, 30.848727533894202, 28.07622371181365, 31.122950238566247, 32.484340206269295, 38.20177524320541, 46.65274143218995, 47.90318519838395, 40.99059220283262, 22.664433487000007, 5.482190885851461, 1.2996438938763835, 0.3193287359129998, 0.16988019639205548, 0.13457694962140054, 0.17401370039630323, 0.1656306147455208, 0.11098626790748489, 0.10624455137839241, 0.13288055516539082, 0.2239806820908862, 0.08129082304695923, 0.09974707624003773, 0.14824365175539447, 0.1259506233937798, 0.1467778344428347, 0.17825248020310558, 0.13992001452753622, 0.12849045001090537, 0.16935416977972756, 0.12729742128642338, 0.10341209449595022, 0.20568942891493922, 0.20401511311290726, 0.1706299666435488, 0.1413353466458859, 0.11816530848943418, 0.09177624548394835, 0.20540108874199853, 0.1936095553420244, 0.11550633987832455, 0.105930095268113, 0.14152547434693383, 0.24247119473593853, 0.08939626311222393, 0.24405972401220954, 0.07758618272360294, 0.15746535853512827, 0.17258569718368594, 0.1209329083682068, 0.14581809481305463, 0.21955261727975262, 0.08860558376557405, 0.14258403931894612, 0.10997914573958806, 0.3525705779752424, 0.17989629038399269, 0.3066543934326018, 0.10253261789799699, 0.13148877258983352, 0.14314576562854553, 0.169820548786271, 0.2087692249446146], [0.026032830205475612, 0.09402625337843934, 0.032687604262103, 0.04868306812920398, 0.056753808241938396, 0.03647453008940624, 0.043703577060612946, 0.017163611971022143, 0.09592106460683769, 0.07949497505661943, 0.05953023345359872, 0.08515486328472054, 0.057090408123669126, 0.06354402472835875, 0.06120519659992668, 0.08666345128609289, 0.043024083884853515, 0.024320141059316458, 0.05534734359131225, 0.018411140190437436, 0.08749531551955209, 0.06509784639122025, 0.02191741545233996, 0.02281212187822788, 0.03465503679528352, 0.017812792962837606, 0.03638602778195374, 0.043932698637006745, 0.04063867761062519, 0.014131205182732835, 0.02923593383222338, 0.055309111973451036, 0.027355377584876075, 0.046465795171717485, 0.047305971459155126, 0.08772033852555099, 0.05643033144635059, 0.07350438199336491, 0.04540166840137494, 0.010576005630765953, 0.09265192228579715, 0.08076633627135908, 0.04621372926199148, 0.013804966640177996, 0.031137601547544042, 0.030960721421926737, 0.06036580555261143, 0.08094499563618053, 0.026515858217833504, 0.030040155698154724, 0.04843173766388528, 0.05293989696750238, 0.053960716787485354, 0.004495060636526755, 0.030946972058905713, 0.021144199079924056, 0.06977931010506808, 0.058526811490376154, 0.015173102954342483, 0.04223129779641186, 0.04830283187930623, 0.0528843134581562, 0.3263164690184978, 3.2568854045483375, 12.369968025915085, 21.59710361111549, 31.439265858742502, 39.940173625946045, 45.32884343977898, 38.91700375464655, 46.66053125935216, 29.690190784392822, 33.24359340052451, 26.886164834422452, 20.3068301370067, 18.56260507337509, 42.19957651630525, 46.01017875056113, 17.59763925306259, 18.581444217312722, 23.653221822554066, 21.010318994522095, 14.568973279768421, 15.205339597117517, 15.051010020317571, 11.498494840437367, 11.943797603730234, 10.075287338226072, 7.300388418859051, 7.096459490637626, 5.827792882919312, 5.14398745952114, 3.5936446632108385, 3.5076812630699528, 3.2846606883310505, 3.9165814893860973, 4.241381931689478, 4.225186955544257, 3.9744124249104535, 5.7021431865230685, 6.972653308222371, 9.185920300022248, 11.909672983231085, 13.657868466069623, 16.9759435807505, 19.60374528361905, 19.344009853178456, 15.298464509748644, 20.707119780202067, 16.51380208230788, 20.776528081586285, 22.953492556848836, 25.41021223991148, 23.65326496862596, 26.057362133456817, 28.701327923805486, 29.254219339739894, 38.68720385336107, 32.339834205565914, 26.39098325083333, 18.82236796040689, 10.306397311149105, 1.37886866206123, 0.2761889765820196, 0.021597144734715263, 0.0608349041712861, 0.03631266720232464, 0.08922574726203758, 0.05140169583741696, 0.05410035546388357, 0.06468219772702263, 0.10859666347143151, 0.02087043947540224, 0.01977397996421543, 0.07850043205243927, 0.017912593151953433, 0.027365537825971845, 0.030782169309414686, 0.0456785325772099, 0.03482656771196954, 0.06628780310312588, 0.03939671118954017, 0.03126062760730425, 0.03109596275363959, 0.029548696888190125, 0.03462309092884103, 0.09878621046100894, 0.06776160305185665, 0.11334735089011731, 0.034623845525446444, 0.007273480070814972, 0.007614824909626717, 0.04894367591928571, 0.0822335402030618, 0.033783565816139026, 0.04350284670269297, 0.0708371319717938, 0.02355363753233706, 0.024589482251734986, 0.11028040981581134, 0.03016389805012413, 0.06487716710375202, 0.03391808319476343, 0.022294175578281287, 0.04829009949800469, 0.06341200862680713, 0.03571305018399031, 0.027432273660275727, 0.10458525089967637, 0.04762279861156018, 0.06022212959285225, 0.018605146211602034, 0.028026572113195737, 0.03495469591730545, 0.028032587818621148, 0.017563691813378565, 0.047015260244088794, 0.03862168301918334, 0.05103846290899862, 0.07751014849711811, 0.02119075232786277, 0.028253133040702635, 0.11743664396025481, 0.0774579779094746, 0.03161527077487159, 0.04201421146130851, 0.04348371748722369, 0.05047386376968315, 0.08089336131008402, 0.06485245310731473, 0.046638927212165254, 0.03146615942128964, 0.03707068822076244, 0.052896662795495604, 0.03820112756183071, 0.07872240602849953, 0.0886592329029114, 0.03123652073554695, 0.02004217968562678, 0.001332028435670861, 0.02396643634945635, 0.03596589750339908, 0.016378774044794903, 0.005212585768482138, 0.05967524240634615, 0.02329868538635633, 0.05214011649631205, 0.01444516716630108, 0.06252929913781344, 0.07910411699765152, 0.03648516338979525, 0.021358090828383164, 0.03356252646734638, 0.032403615468572226, 0.061057288004385854, 0.04282872763372237, 0.03694121936155904, 0.05568944781477894, 0.026591787107228756, 0.0297894821532311, 0.00940812086956876, 0.047761380086622895, 0.05487526872105176, 0.07295819960774914, 0.007062354378567468, 0.0423556721709188, 0.04614395014340839, 0.019165018588424693, 0.06072834900189793, 0.041773004847909176, 0.009920169250108302, 0.059377532978091514, 0.026684508643924233, 0.017908601833867933, 0.10353106028971173, 0.024190909687369585, 0.035345228388905525, 0.0554453224063881, 0.8611299566203549, 6.061941712133347, 18.46059403111858, 30.521760717515026, 42.13582231152443, 48.841027828954886, 49.73672066965411, 41.29171256096133, 42.36068394876296, 24.222698980762114, 21.482358594094556, 17.129484761145807, 13.746043347543287, 17.930136611384732, 47.32594959197506, 34.591963060440555, 25.621765275155347, 31.36683144877034, 32.75274799716088, 29.91559566990022, 24.870894185958374, 24.41315947040435, 17.715378999710083, 15.8830653467486, 14.909260465252785, 10.529126159606442, 8.884879369889537, 7.927932345098066, 6.499945434831805, 4.690866431882305, 5.620711349671887, 5.43787790882972, 3.834398763795053, 5.328889460332933, 5.791098619661024, 5.480605267709302, 6.497148294602671, 5.65763311040017, 10.408625064357635, 12.377687250414203, 13.98323985838121, 20.670194587399884, 26.478185384504258, 29.57056045532227, 27.73209652593059, 19.736919556894613, 20.52229573649745, 16.87401294708252, 19.960198517768614, 17.9292344662451, 19.425302936184792, 21.28023885911511, 24.85471244781248, 28.948488235473636, 33.690394509223204, 42.02407398531514, 40.41367430840769, 33.922049691600186, 25.83351246772274, 15.19506298726605, 2.2494018270123393, 0.41814316905313925, 0.0764381540037932, 0.027694978616050178, 0.02009486738261917, 0.05005907312396073, 0.030208407758524826, 0.0638435612763128, 0.12042210392293431, 0.08507875244944327, 0.016445423694207303, 0.03744591042519577, 0.042986430663375125, 0.11394641632514615, 0.07127526531656904, 0.032864041971944036, 0.03357834618298277, 0.021714036345421787, 0.03980870178389934, 0.049361787556159886, 0.014015850535924397, 0.08928076003588016, 0.009393414854252291, 0.04760275009058176, 0.058591197349972306, 0.07935331773854072, 0.07566216056265178, 0.03496307308875746, 0.015257577554533079, 0.051300947614494836, 0.04046037447668853, 0.017600400831490275, 0.019027055729360833, 0.042449560076478994, 0.019814781807062608, 0.027162497712960167, 0.015562358931938728, 0.0387432343596893, 0.06545017022759685, 0.009252308161869165, 0.016042317804549972, 0.05797459233191706, 0.04670174642195625, 0.020062655300622987, 0.01957076173576136, 0.06314370548352599, 0.09611867698690585, 0.05592167204726608, 0.03480827353233772, 0.04150570911024848, 0.03852311814684541, 0.02364945980990606, 0.040630089764994, 0.07826617002607354, 0.09809099333060366, 0.18265382386744025, 0.15377302924471517, 0.27916902796395365, 0.06985659305486949, 0.18571541764803473, 0.16959738737392813, 0.15265424976185446, 0.14563069438501713, 0.08694967705636256, 0.1949089170703965, 0.10858228400109277, 0.2692822955789105, 0.16595221845613373, 0.18084705146330018, 0.17881837403101308, 0.10834725588680276, 0.15155189520409032, 0.10183629760098073, 0.18404398233659808, 0.17058911883542616, 0.13851836473951418, 0.11672916942306104, 0.13385831318315, 0.1514175540256885, 0.18857145471678627, 0.06785521899620373, 0.11166962599682231, 0.10281318993938547, 0.06278559768332109, 0.17753335346858348, 0.10288102702508051, 0.10724487068552165, 0.14372707314548955, 0.12378869262794334, 0.10667379810324601, 0.14528580160150606, 0.2339154175452648, 0.20244601182639602, 0.15253052656208316, 0.1944197852525019, 0.1060464793455697, 0.12900585098372352, 0.14827740558933827, 0.18223334884931966, 0.1710857429932202, 0.17450172904758685, 0.1273323932001668, 0.09707109281612981, 0.16100715154842024, 0.20753635964807005, 0.09787847287952901, 0.19035734356411044, 0.10555156356384678, 0.12665326391617138, 0.14781496427472562, 0.1850506371908611, 0.20178337641541036, 0.17946404825535514, 0.1831640843902865, 0.14710786512061474, 0.2754028477976399, 0.8060232910417742, 4.844247285396823, 17.49140185694541, 32.10389187259059, 48.53038003367763, 56.21219296609202, 58.225937812559074, 52.49416259027297, 60.360377911598455, 42.094096137631325, 43.957135677337654, 36.121918847483975, 28.24285580265907, 24.360527146247126, 53.20928519771945, 57.760395619177054, 26.952988293863115, 28.689154847975704, 32.877116549399595, 29.90464049000894, 21.902724889016923, 21.70844008845668, 20.0714369358555, 16.49506688117981, 15.91222228542451, 14.104223405161212, 10.789019465446474, 10.005728025590221, 7.913651485596934, 6.684624841136317, 5.506417405220771, 5.15772016779069, 4.4815212007491825, 5.205715269811693, 5.628171697739632, 5.177139332217555, 5.845025816271383, 8.76831143133102, 9.731599457802313, 12.674826402818004, 16.13288502539358, 19.651976708442934, 24.738959381657263, 31.074789416405466, 29.231814761315626, 23.16257449888414, 30.13932570334404, 23.73157116674608, 30.27435329652602, 30.076199077790786, 32.18526928655563, 33.32837150942895, 37.325729554699315, 42.682082960682536, 43.68493103211926, 51.99517042406144, 48.15609962709489, 38.184756079027736, 26.31941176229908, 14.332554378817159, 2.885949063685633, 0.374066484190764, 0.16702446575847366, 0.16623901113146738, 0.10718556015842384, 0.17220930286472844, 0.10383481415168894, 0.1736685471428979, 0.17559222456428314, 0.30991556843922985, 0.11320831359273965, 0.13037311874570387, 0.12324386621795355, 0.25812545070244425, 0.15150488804905646, 0.13488413555727852, 0.09865458123385908, 0.2539096994986457, 0.15052516884621114, 0.204287457369989, 0.15149060817014787, 0.19669515831816584, 0.09028936075347085, 0.09746327620720673, 0.1760997118488435, 0.20276571563895673, 0.21679477736113534, 0.11914289030697077, 0.08750436301793783, 0.12086047475496609, 0.1318837981671095, 0.22060773485610563, 0.11708181501636583, 0.18336674528977565, 0.1566989488539196, 0.1039490455220784, 0.1166638374448784, 0.15885678871024042, 0.10882979934854854, 0.15103703815369837, 0.08831219507321235, 0.17629383852885616, 0.11723396007812793, 0.1824067298683428, 0.16007969486376933, 0.17631017152340184, 0.25132620586983623, 0.14077705241018726, 0.16626329611866705, 0.1543650007055652, 0.16771419003846186, 0.13823354857102518, 0.11977706555156939, 0.18216242442928976], [0.046068023169232954, 0.07543704562610196, 0.052890656666169246, 0.043411808644211104, 0.12130409328927919, 0.029064280341469476, 0.03792808999517753, 0.07878087385888062, 0.05130398515311461, 0.05348243660503819, 0.09922905524651851, 0.04485310348231466, 0.012250352076314872, 0.04990010221879329, 0.015832696996268728, 0.05756690715169234, 0.019355395268048012, 0.020255734355399208, 0.09559389143701523, 0.054779503900077076, 0.06888798212692623, 0.06137203139763686, 0.07117470861562798, 0.0068689463847887615, 0.045500137512722326, 0.09967861862312402, 0.05875438556916291, 0.10854431668356543, 0.078063118421743, 0.0312901679576645, 0.02913983959344126, 0.03410400890354668, 0.017446288838982582, 0.033942617160538514, 0.017154269528785543, 0.005009379510151884, 0.0772193721645782, 0.009366701368332632, 0.014145902579560155, 0.106590754172254, 0.050064876239987156, 0.05780800651278227, 0.04130071547302989, 0.029914710715773608, 0.07782360103221671, 0.07370192542551987, 0.045687097440203356, 0.03610010844685378, 0.04007120947203329, 0.03494644898080057, 0.01071126228423729, 0.06199321762147931, 0.06709217244098264, 0.0554081135159058, 0.0340854695757791, 0.03537797098678928, 0.07977595312460777, 0.013805615899693823, 0.06615254261921491, 0.054017943555429104, 0.047809467425629984, 0.04995217704544625, 0.07625025561860493, 0.04693824542506088, 0.36803887375900823, 1.9975951001528773, 5.914805271933156, 14.645572266271039, 28.055180195839178, 38.25176977342175, 35.91226816177368, 44.17499196144843, 45.380355927252005, 34.271195550118726, 36.11763954162598, 32.61942271263369, 39.82704462543611, 85.71584563101493, 41.90664214472617, 24.221084925436205, 23.04490731608483, 22.042931972011445, 16.93145605825609, 19.00319903127609, 22.805607434242006, 28.52091850772981, 22.319796392994544, 28.79332515501207, 20.012552353643603, 18.260863019574074, 17.314157793598792, 16.60495012037216, 15.262038438550888, 13.018987909440073, 18.458509291371993, 15.125525247666145, 14.648108078587441, 14.50469739975468, 21.573067326699537, 24.284976413173062, 15.04831535200919, 19.949109977291478, 19.669154728612593, 12.978803227024695, 17.345481841794907, 14.27097414770434, 23.72211237107554, 27.387702618875814, 26.580810277692734, 30.63750005537464, 27.476954190961777, 34.94824763267271, 34.361068817877005, 38.255233226283906, 35.61622335064796, 29.455442813134965, 24.751199137779977, 16.360578613896525, 13.118314089313632, 8.087000635362442, 2.696625571097097, 0.5497106801598304, 0.03952192059988457, 0.062498686264359185, 0.06342114039486454, 0.025070016647899346, 0.038355195504282756, 0.08980298685210367, 0.06713217755238857, 0.03440564453241325, 0.04212509502746886, 0.04171033119482379, 0.01808039896610764, 0.03886193585311694, 0.023150520151360862, 0.09954577131617455, 0.021483217884275704, 0.038738136044553215, 0.0191691899371724, 0.08500764416831155, 0.04198953576926743, 0.04984937187644744, 0.00911916591106884, 0.03251801154786541, 0.01671311588236882, 0.013347546074299083, 0.10234310306728849, 0.030755972932843916, 0.032897048870161656, 0.04343625450987489, 0.0446408856359701, 0.009990419512764822, 0.0039026754881976355, 0.08947136271144114, 0.05341973996931507, 0.00328825956638602, 0.004023548840890609, 0.06875232327729464, 0.04834862861541971, 0.0479247828104323, 0.027766937254777843, 0.00886777894676573, 0.0924393328868093, 0.029505286515960773, 0.008835972891369415, 0.02266516131649335, 0.0016990884520759386, 0.039567008704668095, 0.08171848396980956, 0.04886091161038607, 0.015551809901221385, 0.0625545991915128, 0.03378707832927185, 0.04862043661095443, 0.023561112635258227, 0.0503275984327399, 0.024278791463603417, 0.005861195067184107, 0.07094443024646852, 0.024106762589766614, 0.025042399178229036, 0.03880929795183963, 0.015663675017534726, 0.06549392916983174, 0.034347341410935886, 0.07801853210454987, 0.05215226665079113, 0.04565668374960942, 0.0363970096523483, 0.09468257622492891, 0.05888024232380333, 0.041619090123041984, 0.019675579800781225, 0.03522267347321876, 0.06519891637107057, 0.060538822679870555, 0.009614543260766134, 0.04767115408134076, 0.0980302425582082, 0.0718163991827638, 0.03781682338505503, 0.0608649194961594, 0.032490600921934655, 0.07403994640035015, 0.029773388561161778, 0.04782986068617433, 0.010884793648015588, 0.015524143593445902, 0.037433055469826344, 0.03723066653155031, 0.027798195557308295, 0.038118413048646146, 0.037168885370896715, 0.072702816537311, 0.007985133617635696, 0.04980640200477454, 0.025835330823376298, 0.033522996330453504, 0.0015231977768933342, 0.022365463890075203, 0.036870658833293185, 0.0675332628851456, 0.029326351359486583, 0.024407946226757862, 0.028591418315866785, 0.0154453236797464, 0.015010113918012189, 0.042269770731969226, 0.0095123614958157, 0.006818143264090102, 0.029490974078315402, 0.00761224462973675, 0.09196778278677695, 0.04128168584899076, 0.06649860751725013, 0.05564170521533778, 0.05269453815755345, 0.020306175499553644, 0.0235639356692592, 0.03187911720165322, 0.8235997995061259, 3.701992294480724, 10.343256804250903, 22.684719985531224, 35.75641670534688, 47.019812522395966, 46.24058661922332, 47.69527604503017, 45.184209962044996, 32.50731548955364, 24.147573824851747, 22.787778300623742, 43.85156900651994, 76.83349717047908, 24.306486691198042, 18.69289444338891, 24.565102284954442, 27.32559777075245, 23.687622970150365, 26.010150524877734, 29.79943075487691, 30.46057958756724, 30.703007559622492, 33.967941422616285, 32.37564348405407, 28.37370214923736, 27.132966249219834, 28.972338207306404, 21.691795510630456, 20.21740205826298, 26.030197758828443, 24.62628145371714, 24.015635098180464, 24.277920069233065, 22.244616323901763, 24.596940163643133, 24.134302485373713, 29.177848831299816, 30.20564513821756, 21.88630976984578, 21.175962648084088, 20.854173360332368, 21.240356199203, 17.32753307588639, 18.84608849402397, 19.150266339701993, 24.72308162719973, 33.454758121121316, 32.05670379823254, 41.50415205186413, 38.54499047802341, 34.44458392358596, 32.33396830097322, 25.11891741906443, 18.09794149091167, 12.485161173728205, 5.323614362747439, 1.4129609230064577, 0.1366866178690426, 0.10657620616257192, 0.07392320992244829, 0.03998036676597211, 0.0432721201720978, 0.05994308206643309, 0.04025210964403326, 0.08795190392242325, 0.05637323874379358, 0.041043884496414856, 0.10503721979236412, 0.04425142951790364, 0.006480460325556417, 0.14410974938542614, 0.020606135311085853, 0.01575829453706261, 0.06530767787368068, 0.041474073509415316, 0.04855156147612199, 0.022783043095842007, 0.03757488515768801, 0.07252425676391971, 0.008744096924220363, 0.020373024331826358, 0.08786452393377982, 0.06059192023390244, 0.03613301958408087, 0.018087358874899727, 0.07617180055427937, 0.03023868355329239, 0.07072732858960668, 0.0488486044078825, 0.03322986810798607, 0.037229398656035625, 0.021570869834132252, 0.08052691847326295, 0.014246039847362668, 0.035412467926019625, 0.03293527282714363, 0.02098265411933103, 0.03747825848779852, 0.0943973463689608, 0.02807134803715012, 0.07327724458469499, 0.005240169243000809, 0.029555547629453005, 0.04946300309271582, 0.019640268893131328, 0.02520777649366327, 0.07573088631033897, 0.06504585200379934, 0.03330606321293501, 0.1850846974599746, 0.06616119175188004, 0.11954559208524805, 0.09343062001731127, 0.2931313787496859, 0.17875760793685916, 0.2406561945474917, 0.08900267778024559, 0.12653417554834198, 0.18882135259768656, 0.20940759069015905, 0.18581407445092357, 0.19879580205005987, 0.26179537958195137, 0.1640390824045866, 0.19035109228664832, 0.12488820499950841, 0.13162600958058912, 0.10706138496677722, 0.09012421517963372, 0.20230613949318088, 0.15755659960691007, 0.11315020582368297, 0.15467803955318468, 0.18631408471734295, 0.21951939970735582, 0.17945704621172723, 0.14435619987066717, 0.1639282448037017, 0.39670082770528337, 0.17365382293299322, 0.14249359497860556, 0.10721369856788267, 0.08503360688806542, 0.138297087903465, 0.12407036017506354, 0.12824989840268128, 0.12296377681195737, 0.17717537590332572, 0.14496084242578477, 0.11254011638342373, 0.1744305441576627, 0.16302775441398545, 0.13825614816479145, 0.07373112869719345, 0.1760392368681008, 0.22533494167991225, 0.1458992541677529, 0.11174373734261721, 0.12829413231942924, 0.09042596189124931, 0.12299347037990248, 0.14279889633818982, 0.18821620442453893, 0.11103003451059903, 0.16877784183429134, 0.17515697937098243, 0.11355954192338452, 0.20628446472748635, 0.09684760964685872, 0.17736254650498592, 0.2954054647876371, 0.09626962695150607, 0.09171279808205944, 0.23397622960469416, 0.19121566847447427, 0.5860703162127926, 3.1403419808033974, 10.158196437743403, 23.405210356558523, 39.83936479014736, 55.618146081124586, 55.0373685744501, 58.96135476327712, 58.60559578864806, 48.57140802568006, 47.779936482829434, 43.241730659238755, 47.41708586292882, 92.17871142971902, 54.49553628121653, 35.230352340206025, 33.13662252118511, 32.47067074621878, 26.485075027711932, 29.413626424727905, 32.68227084990471, 40.602344236066266, 32.569271287610455, 39.402440209542554, 28.90290637170115, 25.810952955676665, 25.163797178576072, 25.809997858539706, 23.288498270896174, 20.004097684737175, 26.228922682423747, 21.95168391350777, 22.452982433380622, 22.212813746544626, 28.524005413055423, 33.7119871570218, 23.76946322379574, 29.942044211972146, 30.230281545269875, 21.870533997012725, 25.163189211199363, 24.438237144101052, 33.00289323253016, 34.70988911967124, 33.32218985403738, 38.21500932016681, 37.57926764026765, 48.664956554289795, 47.20127313367782, 54.01289255388322, 49.01212161587131, 43.763703992289884, 37.662041418014034, 28.169442761328916, 18.870577812194824, 12.770482224802818, 5.068651966510281, 1.2299894637638524, 0.15183600657168897, 0.2638317332152398, 0.18267020282726135, 0.09429353379434156, 0.2045260631148854, 0.25001094015615605, 0.14198839063605956, 0.20468507232444905, 0.13237306788083048, 0.1924024765650111, 0.13309596376794, 0.14169940694926247, 0.16559224906227282, 0.339213130214522, 0.10592746758653272, 0.1540957054784221, 0.1483124311292364, 0.19282307415719957, 0.19619209902180781, 0.16545945538147805, 0.09830509958368155, 0.24714587857165646, 0.2355831603129064, 0.07985355783133738, 0.22012064083208963, 0.14043902377447776, 0.14866830961358163, 0.09336607710969064, 0.15364844802646868, 0.12917757725283024, 0.10788073132355368, 0.22250282187615672, 0.2976705722751156, 0.12092162389308216, 0.09404589587281789, 0.22579586614043484, 0.14493828879729395, 0.15798249852753457, 0.19799651187514106, 0.10922643371046552, 0.16673139116216093, 0.23702907466119338, 0.14905072538362396, 0.14221654694166877, 0.13426349708630195, 0.21005623733564732, 0.12155932314213246, 0.16471084958362966, 0.22951370615872646, 0.20792435253820113, 0.13838501947541393, 0.075329739690548, 0.23702466199474953, 0.1517430341411983], [0.0884628079591259, 0.060378541764352596, 0.03888239423113485, 0.012553624260509688, 0.05461746098233327, 0.033706240731501774, 0.03079379086322602, 0.04226690556313242, 0.08081094557118994, 0.03366369220818724, 0.05838318532633205, 0.0681990928827755, 0.051684899390825344, 0.029280255849082625, 0.04048643295743293, 0.03807631268676731, 0.06313592203021531, 0.0481784766569974, 0.047348033516637744, 0.044103478787526976, 0.10975156399992206, 0.04280671792765779, 0.08262037630042723, 0.014634947254953366, 0.04034922661019429, 0.0464252959336004, 0.10970378309608468, 0.04359307653841473, 0.05561882982991877, 0.060353938850664327, 0.05595583956868899, 0.03187037039277775, 0.04087960077149253, 0.0913283215355008, 0.09079395222567743, 0.01761594858591355, 0.05830154333624148, 0.047401667332216624, 0.02175905550229213, 0.09281443251717476, 0.02849247039956672, 0.017461060929382523, 0.059081888156792814, 0.01539529909590079, 0.041025245577217116, 0.057661032544509064, 0.04369951679461426, 0.04391170399744184, 0.04105092867487862, 0.039758706885960796, 0.04117495064894038, 0.02411908702924848, 0.030078048322109446, 0.03273476080428208, 0.042058280669152744, 0.011573333364550867, 0.062247780977838466, 0.022181445740223415, 0.033975470841171286, 0.036345536204715895, 0.013992640944648416, 0.05603357834080535, 0.07645149159455493, 0.023821638070888097, 0.04334070802395863, 0.05598447976573821, 0.05150237128198628, 0.5154351096960806, 2.821548648418919, 10.846254691000908, 21.376531085660382, 34.488330118117794, 39.12924320467057, 41.80422513715683, 45.97762307813091, 43.588589775946836, 36.29934726222869, 66.85298704331922, 72.11811788620489, 28.85224896092569, 35.51158628156109, 30.33982353825723, 30.88316986637731, 31.08093184809531, 28.251947856718495, 33.088887276188025, 31.657026044784057, 25.27648295125654, 20.73974605529539, 20.638331213305076, 20.33503786210091, 14.238441028902608, 22.48839359129629, 24.77534720974584, 17.868539710198682, 16.71857726189398, 23.942526040538667, 16.922652298404326, 42.03762185189032, 55.32378004443262, 25.65646452288474, 21.560427488819247, 20.970557928085327, 26.25392386990209, 28.123552991497903, 25.947143531614735, 36.67817761821132, 36.28447363453527, 38.85471651631017, 40.47918181265555, 38.65751543352681, 36.4127076825788, 31.412417234912997, 27.208454224371142, 18.72775450829537, 12.870282030874684, 7.132261414681712, 4.587275164742624, 1.5962120962719766, 0.6668978016222677, 0.041675757646801016, 0.06187273880406734, 0.0045797559658005355, 0.03194717262240668, 0.008038101894330353, 0.07944110375378402, 0.027829907766933885, 0.027263219122804945, 0.01390399116527049, 0.08491372944967401, 0.03872436178367465, 0.06691547426124735, 0.009289258497677023, 0.05214255265591126, 0.03618118353188038, 0.00867782648833048, 0.04661258527888887, 0.01689628175940485, 0.022889054342803937, 0.04522377512447777, 0.0296910647528186, 0.06151694458939376, 0.05677790936803626, 0.026996940366863727, 0.07299385333974516, 0.013301422793207871, 0.051081635793971444, 0.026285734981478705, 0.017255519539298072, 0.03814631397084844, 0.06333817307266497, 0.028752164629798745, 0.016883729408765515, 0.03379191617451368, 0.03789723580402713, 0.009576487843127502, 0.07422582231341832, 0.12100724187949974, 0.08593529237494354, 0.04571358109974573, 0.03333659181671758, 0.0646532855687603, 0.03651006890821361, 0.01732729623214372, 0.10943340768496837, 0.01168560163463436, 0.03368965109750148, 0.041232077825453975, 0.05063339774947494, 0.0345372507769254, 0.06018447637137386, 0.07609667797242442, 0.06323311177472915, 0.04834520037195856, 0.04831361073640086, 0.039253085025496064, 0.04839295446271858, 0.050322856348488605, 0.04384763989477389, 0.023275974709841035, 0.027477472847808274, 0.030195962660194888, 0.06850368178059017, 0.07857707914926353, 0.07328312813995347, 0.06987966762314882, 0.049750485247181314, 0.07208440738219409, 0.07881085087935771, 0.06686000949552943, 0.030983445504980705, 0.05922557560787086, 0.02877550158319214, 0.05121500404070943, 0.018820926366794496, 0.06047799529868269, 0.056256195830722014, 0.022668455494567755, 0.052739335148925745, 0.01571407785729295, 0.03886811052178664, 0.009741122053275186, 0.05819941998549527, 0.09807581712882366, 0.0707637560704062, 0.04599316871815151, 0.04104108444505161, 0.021283010381364056, 0.06416509986945218, 0.0837565076747729, 0.1265402812690985, 0.06319139062637283, 0.010595309131238009, 0.006460565979772758, 0.033331225370807994, 0.043965395269615036, 0.040798514195147066, 0.0489734729091006, 0.04724029091096694, 0.05471376206485495, 0.051906452018527255, 0.016191107401203726, 0.08508147972245371, 0.018905868280618902, 0.02344681423217539, 0.05516613698414257, 0.0535853490263464, 0.029970592999410246, 0.012027865778955241, 0.0200696554290311, 0.0575947659390588, 0.03941128984273922, 0.035976695512691816, 0.060474249128732956, 0.06310162044340564, 0.01282712339513725, 0.05379199741348144, 0.11376389587718634, 0.06889335240327543, 0.04079823840349432, 0.007349779076438638, 0.02388656593769068, 0.2627247055211375, 0.9244690030332535, 5.605969611675509, 15.877147470751117, 28.21674458442196, 42.24496226156912, 48.16613697236585, 48.762207800342196, 50.76148694561374, 43.1357442948126, 35.89405267469345, 75.12811337747883, 65.12947013301235, 22.791655563539077, 28.87163527550236, 25.35385954764582, 21.088813466410485, 19.412059053297966, 26.895162751597745, 35.34589752074211, 29.748014365473104, 32.16209592357759, 22.912680295205888, 23.842758594020722, 23.852937144617883, 21.050544861824285, 26.57367156397912, 27.24785835512223, 24.669770733002697, 21.977573517830145, 25.964101899054747, 20.748028139914236, 40.35995744889782, 57.51766758580362, 24.738871128328388, 18.953614388742757, 20.97389586510197, 17.10721158212231, 21.54804260500016, 19.584953208123487, 33.959492637265114, 32.286384067227765, 37.170085983891646, 42.32704962453535, 40.3690573476976, 41.79088123383061, 39.238736168030776, 33.68603675596176, 27.85511774401511, 19.67174545411141, 11.648500004122335, 7.136274489664263, 3.6775490641593938, 1.2445803130826643, 0.1571104759650846, 0.018191993078817765, 0.08390645406419232, 0.036146383987919944, 0.01962902272240289, 0.03736961572881668, 0.017104592557335575, 0.033814887320923234, 0.05093440135580398, 0.04553885559641546, 0.03128211254314069, 0.04324127364182665, 0.0239006906837946, 0.03639856098039496, 0.03015256186406459, 0.07606715294382266, 0.06359995680771048, 0.049126265315158714, 0.03620644911162315, 0.046205528290762056, 0.07431774520345273, 0.037880366547934474, 0.09037883216214758, 0.025818174284312035, 0.043033778727535284, 0.04886098438873888, 0.021549599402914607, 0.047803844340265765, 0.02103627261315142, 0.039581108552914475, 0.10252828184034556, 0.013401907673406025, 0.003882091184477172, 0.03377518098380777, 0.033260427355285616, 0.04122707910174805, 0.06382364682072113, 0.0985412078819448, 0.057635874217075694, 0.04300253766198312, 0.023684943087338924, 0.05829304359072159, 0.06975460376951002, 0.0511051623541261, 0.03567069701309647, 0.02242945329917054, 0.01654723103368475, 0.07964476822845398, 0.05644275356204279, 0.07877534270406732, 0.06821221596891842, 0.0516335446868212, 0.06831307144414994, 0.046084589820595524, 0.012684220226571686, 0.04612109391018749, 0.15904731477700895, 0.17834010533988479, 0.1562805269514361, 0.06792061226142031, 0.08846834677481845, 0.12124882004554234, 0.17749114202395563, 0.13846202663356258, 0.19408655232719838, 0.19675155771115135, 0.170078735738512, 0.14449006607455595, 0.19511710912469896, 0.11911983106044993, 0.15071618520925123, 0.1893925171105131, 0.30125620083943494, 0.23992413624880776, 0.11074326481790313, 0.14002306867511044, 0.22424542675575904, 0.12313222422474816, 0.1781680113485744, 0.09372687387850978, 0.15560561881190346, 0.15547693136238283, 0.16035343340087324, 0.17154014038462795, 0.19977489306080728, 0.19106098000080357, 0.1148797642259348, 0.1388977008361009, 0.1744152377209356, 0.1733356972615565, 0.2767587008495485, 0.17195912919217543, 0.0993863330973733, 0.19403471881824155, 0.16499299976614215, 0.18437105591499037, 0.12786506179479823, 0.14963345782410714, 0.1260146070572157, 0.18000844565610732, 0.1268431771126005, 0.1544922479097882, 0.24401631747041982, 0.1552328404279486, 0.08149942112786156, 0.16900598281814208, 0.14071817089232708, 0.06881573237478733, 0.2027522324914894, 0.12229737224838427, 0.1283741118987241, 0.08041048843053081, 0.20751716148468757, 0.18523436039686206, 0.1537360731632479, 0.11338248368232481, 0.26807791343139065, 0.16697923592742414, 0.15847172227598008, 0.15521002632956352, 0.15656197233305824, 0.09630657537209411, 0.2640998639887379, 0.9344614249083304, 4.962513610239952, 15.304452988409228, 29.97365655437593, 47.44318139168524, 56.51686306922667, 63.17773403659944, 60.155371312172186, 58.53746421875493, 47.399392051081506, 76.60149681952693, 87.18402801021453, 41.283789373213246, 45.98375766508041, 40.933592319488525, 42.11797944961056, 41.32824159437611, 41.92381428134057, 45.430170028440415, 43.35960965002737, 38.9428404069716, 29.687084267216346, 30.067156053358513, 31.03234152640066, 25.385509152566236, 34.7857948272459, 37.54058522562827, 27.36582559923972, 25.0763459743992, 33.794364775380785, 25.739548167874737, 53.993112041104226, 67.2408623849192, 32.877826498400786, 31.223209942540816, 30.050354580725397, 35.244849420362904, 35.26487312009258, 35.78505392997496, 46.49539555272749, 48.59622093939012, 53.41076558636081, 56.022448309006236, 54.3867846458189, 50.97563266754151, 46.05806696799494, 38.88193776530605, 28.742312769736017, 18.98679764040055, 12.85035344862169, 6.724810013847967, 3.056163259090916, 0.9938233718276025, 0.2910677523862931, 0.17766329730229993, 0.1578807926947071, 0.19622652701312499, 0.1172185080846952, 0.25895757540579767, 0.1047776002557047, 0.1568520591864663, 0.12733963273105123, 0.1852818884916844, 0.12440398380520845, 0.18189450816041042, 0.10163796509826377, 0.1568425750179637, 0.16613307649329787, 0.1863132879859017, 0.21023643653719656, 0.18936409524852232, 0.14928323306864308, 0.10149405548168768, 0.1594984945991347, 0.14095948858847543, 0.1915692180515297, 0.13183668375976626, 0.2133870190910755, 0.05774042223610225, 0.05792061760721188, 0.19698976509032712, 0.11700025729594693, 0.21907517596358256, 0.1840837576216267, 0.06219579808173641, 0.16391454715161555, 0.13459470753948535, 0.14514761466172435, 0.15757671707580168, 0.23536651064791989, 0.2783198961086812, 0.16084936807953543, 0.13360507515889983, 0.14213183293900183, 0.17010962440361901, 0.31801464997472306, 0.11802851582967466, 0.25582381614273597, 0.11849739228285129, 0.09361076559270583, 0.1962864504105622, 0.11402620438245997, 0.21160145200067954, 0.11851738717767502, 0.12570921376708055, 0.173858490982844, 0.162946778920389, 0.17792211244663886, 0.15040257945656776], [0.04472132486801955, 0.09445222124697701, 0.08129068515113286, 0.03061278343891665, 0.08255237067538886, 0.06308313857223238, 0.012292665027592693, 0.018625813348579313, 0.04737499215069318, 0.05288693347885724, 0.03535853533615028, 0.06709307642473329, 0.017378844373348742, 0.06613272392461378, 0.035980388056486845, 0.007232748133490884, 0.024804538453839002, 0.030264466242384047, 0.012795688892384211, 0.019634879464584015, 0.0384291727846909, 0.06426482536499539, 0.02876419412542976, 0.08147663767299346, 0.0283957862730829, 0.011103865108452739, 0.06974472123528681, 0.04203994435468509, 0.0017208974191641076, 0.064999365788554, 0.09431801796440156, 0.03038290726591743, 0.07001495875057674, 0.035700463359394384, 0.08818188351729224, 0.015264470430631793, 0.05447441704511162, 0.09021948587389723, 0.04171189784462895, 0.029130026007131226, 0.02831359078446704, 0.05503137062694277, 0.09431307669728996, 0.08571173259688002, 0.012410386886087157, 0.029116069800370646, 0.03313613725045035, 0.03321108746252233, 0.05888021551072598, 0.049847395369602795, 0.046534103401485956, 0.03812620033239646, 0.04620314958775717, 0.05878452346810411, 0.053554418226403576, 0.07031529586041166, 0.027534090575852224, 0.06880517568319075, 0.031204643817017638, 0.0470793703120322, 0.04676578754198648, 0.02855529918545677, 0.06855830384959137, 0.020730044287178787, 0.026106658098738522, 0.02798096115340389, 0.07857696423607488, 0.014775519601009307, 0.05501803686662067, 0.2884727674386194, 0.3217329956110447, 3.123087229267244, 9.581673722113333, 23.291861703318936, 35.44539236253308, 44.244704246521, 49.849904583346465, 49.80890797030542, 58.59396988345731, 45.82648238828106, 42.35398454050864, 48.47549038548624, 37.00975125835788, 37.64834057900214, 37.974528804902114, 32.147596882235625, 27.775130810276156, 25.176603717188684, 27.697203120877667, 26.055210713417303, 28.094609821996382, 29.91597417862185, 26.86448589448006, 28.330465862827918, 33.94686652768043, 31.645207943454867, 28.372217532127138, 34.005466738054835, 64.18008004465412, 79.57342963064872, 31.855195952999978, 34.20869258142287, 32.709211649433264, 40.09666442871094, 40.99180421521587, 48.374179486305486, 46.315296003895426, 46.89089598194246, 41.52675667116719, 30.71308412859517, 23.41298253305497, 13.707729635700105, 9.761545773475401, 5.098359998195402, 1.763218038024441, 0.7481878202769064, 0.39149737466246853, 0.0374128230877461, 0.062389668122294455, 0.05411282354485124, 0.029394203766940102, 0.09561113607619079, 0.014233965344066101, 0.008789328670489692, 0.01765263462138753, 0.027524424461467613, 0.05302075754791018, 0.030242987052207033, 0.02674255129550734, 0.031204337381847927, 0.047358084590204304, 0.020829545702004147, 0.03013290021748793, 0.05298971183477871, 0.037702791197525884, 0.05019661271944643, 0.0117528488326277, 0.036858504848374475, 0.020657304238768357, 0.12089222143854826, 0.015073224241214414, 0.029107300008857445, 0.01900446188125399, 0.05111334417315741, 0.049851126217794035, 0.011928783797268427, 0.02453007979408628, 0.06632307379115975, 0.039594518922029004, 0.05352273666029496, 0.06766020365419888, 0.014450850581089336, 0.03513687162569935, 0.029190093046054248, 0.04188730899665145, 0.0050438199503978175, 0.03248167599761679, 0.029237128929385257, 0.0021339134940306747, 0.058850096763982895, 0.04794868475366985, 0.060281030262910554, 0.07279136097959935, 0.12568390988294156, 0.012376518138954717, 0.019750365303949486, 0.019068033772430593, 0.1057439282416336, 0.009531257054468077, 0.027778972496068286, 0.042717732984812996, 0.027618856289454048, 0.02012575796294597, 0.022191039076255217, 0.031371357955879746, 0.05623482580807421, 0.04658418256909617, 0.051437916474476944, 0.05346475146530617, 0.047007545738691286, 0.03308987320070306, 0.07368920836597681, 0.027890484254326553, 0.07705818726530961, 0.0684138426497098, 0.0627790859359647, 0.04285454862721024, 0.02861874850256549, 0.06393620045855641, 0.09510895012006645, 0.06564508597817152, 0.05724978888587606, 0.05575253132490381, 0.03846969500544571, 0.03591798636461458, 0.049599347591039636, 0.0024668861888424167, 0.0333319952891719, 0.003036920721980653, 0.015186868596731897, 0.04425933554528221, 0.03991388565590305, 0.056249833470510865, 0.014303408341572411, 0.021088479589971326, 0.07336562048763999, 0.08498061658634294, 0.058298394714872685, 0.0772764993410918, 0.028585684147753546, 0.09188932772245138, 0.02028215481268783, 0.02652480229434948, 0.04016144696863429, 0.014112229184848408, 0.014865929467393266, 0.03785960173474685, 0.029141157264671022, 0.05545478742269259, 0.02108316485499663, 0.04422943513359755, 0.015873697064366313, 0.028738474638591853, 0.03438821220169625, 0.03561107238994972, 0.022380176608661012, 0.015132148851520352, 0.022023581832106558, 0.02207594968739056, 0.04300610763171027, 0.02883010449999523, 0.026437498914498477, 0.01597373186790895, 0.06271155528543938, 0.027469409772405223, 0.014044828769270212, 0.01293251506849042, 0.03916341060351941, 0.04689310752456227, 0.020346624941955653, 0.011584441639452932, 0.025720605326275674, 0.008539675937725172, 0.07129907532925568, 0.07047138627498381, 0.45668995548640534, 1.5894521364281256, 6.2755387925332595, 14.987549012707127, 30.72711640788663, 44.968295251169515, 53.781296207058816, 53.22797529159054, 56.52548051649525, 68.30016905261625, 45.332683440177675, 43.56280411443403, 45.72832899708902, 35.019426884189734, 35.163942690818544, 39.0371734096158, 33.66797424131824, 27.81924766878928, 26.986008767158758, 21.10147095495655, 18.392254575606316, 21.085259799034368, 22.15634338317379, 27.202098023506906, 25.630751425220122, 23.697087649376165, 18.966964175624234, 24.817850012933057, 20.569628938551872, 61.3925810014048, 84.28342742304649, 22.789982672660585, 25.11144922625634, 26.54527948748681, 34.95511178047427, 38.992980064884314, 46.88340425491334, 50.197893342664166, 52.051856517791755, 49.17155811863561, 39.63678613785775, 31.440189576918083, 21.73898946854376, 15.817371529917564, 9.141380806123058, 3.5464940965175633, 1.8447604366848547, 1.0074838839711682, 0.1564515177761355, 0.12072113868329795, 0.0350818818344945, 0.04384613453200267, 0.057529207964938496, 0.033100418400980776, 0.03532685377004166, 0.06320141871730167, 0.058709577086471745, 0.08333529721224502, 0.04479080138187255, 0.035573108902862, 0.030143623533208045, 0.014016135903676192, 0.08709053764300001, 0.006824430451923681, 0.08430452867140693, 0.004917992881664466, 0.03847626420939642, 0.0435020461408121, 0.0312964134894672, 0.03858068582391547, 0.0743890067021693, 0.033241175565748446, 0.04243091732684163, 0.036115483831494086, 0.03960169716587952, 0.05891818282825332, 0.07413747705399029, 0.02994975923830944, 0.009560720796035904, 0.047120241102792566, 0.03292632492018804, 0.08578848694601367, 0.01461699685727757, 0.008818026324133239, 0.014085028275486924, 0.03701729572287971, 0.06305927876383066, 0.02109015923774531, 0.023349049921718337, 0.018247168646344257, 0.056041702703242345, 0.058853482872608213, 0.019914271730569102, 0.04166414375386892, 0.06341405025112533, 0.019851105865992365, 0.017411730612718293, 0.0355227462827198, 0.052028348098599145, 0.023338395553911408, 0.0898285512061369, 0.05259581623719104, 0.023596867873904206, 0.04370941465059596, 0.04472944540001693, 0.045000950790821545, 0.03227005186941355, 0.1793687009522992, 0.2727598138153553, 0.12353994387892947, 0.12328616193225309, 0.21750314822120054, 0.20568762094743792, 0.18376126524902162, 0.20294819778252035, 0.13728480996383777, 0.23792945779860022, 0.11037532044875045, 0.140191761236037, 0.170873046341923, 0.17926454363811403, 0.15139524554533346, 0.14015474386753576, 0.155051936425509, 0.1383854484846515, 0.08205103507686047, 0.09507105941133154, 0.2223691088898528, 0.18084369599819186, 0.14655600602348007, 0.16325839284446933, 0.10042169326615911, 0.2840198967004976, 0.21199257052954168, 0.18063988596681627, 0.1283739663420185, 0.1622263804799126, 0.3300998095543154, 0.17219160623367757, 0.1814511730786293, 0.1842934358865023, 0.1849328894768992, 0.1428425633498738, 0.1781228581263173, 0.2880922362448708, 0.14608172098955802, 0.12800298826468567, 0.1125730045380131, 0.17539117244943497, 0.14649427465854153, 0.15076116989216498, 0.15934276424588698, 0.16852397561794327, 0.11045975865976465, 0.22265654507904287, 0.12279131509844335, 0.07449368495614299, 0.07891378245286404, 0.09775615162065915, 0.1161638041958213, 0.14177822207491245, 0.15492274335795833, 0.18561838495154537, 0.0967351939048498, 0.15113689005374908, 0.12051839351413712, 0.13289737845620803, 0.09377812516064414, 0.11054005999598773, 0.11980850579998187, 0.1625659259697122, 0.09876872067369762, 0.09427347761248389, 0.17372491589236647, 0.267746442508313, 0.22583155051594783, 0.5184890425974323, 1.1571313152390144, 5.581018924713136, 15.113584572269072, 35.09313998683807, 51.70421684941938, 63.84520376882246, 64.94536584423435, 65.3119937066109, 72.89837145036267, 60.69506983603201, 56.36886419788484, 63.90104263059555, 49.88771230943742, 51.3940122819716, 52.49960291770197, 47.47570960752426, 39.982511689586026, 37.65659324584469, 37.90982930890976, 36.49731320719565, 39.75774418923163, 41.20007422662551, 40.05021964350055, 40.10938859754994, 44.305108747174664, 41.92903103366975, 37.650823439321215, 43.309242494644664, 73.54310712506695, 86.19939542585804, 40.810680927768836, 44.74321003883116, 45.290702312223374, 50.875361196456424, 54.984055719067975, 61.17818032541583, 61.707060952340406, 62.23155244704216, 56.14530870991369, 44.488914935819565, 33.34193506548482, 21.565057846807665, 14.969744393902442, 7.83227946489088, 2.9917302391221448, 1.3392139899153865, 0.7742751365707767, 0.18321415589701745, 0.17231862361152328, 0.14127623530164843, 0.18736860474511502, 0.263290629992562, 0.06948429730630691, 0.07215390687868481, 0.15979389810273725, 0.1930405665189028, 0.19906212485605673, 0.13311808838719322, 0.1250811365823592, 0.090449174355355, 0.08182719950714419, 0.21858857223583808, 0.16052427100798777, 0.16193607912188576, 0.1636882447787831, 0.14512345224859255, 0.07853336617230408, 0.1328170311547095, 0.1808835938572884, 0.2055539232828925, 0.07856240856551355, 0.08917748372280791, 0.16718860775713, 0.12140360044976398, 0.16983424643835715, 0.19179562767667158, 0.06793612554188698, 0.1643856452597726, 0.16931658550616235, 0.18682075994870356, 0.14408446848392487, 0.12173812040278029, 0.11101387771627597, 0.12390684636850512, 0.1912245857379129, 0.11202823941505725, 0.1371577466207166, 0.08392297858071905, 0.06240304784789201, 0.1756209988267191, 0.145361460444908, 0.11904889131866156, 0.23705679172229385, 0.14936443838861682, 0.14750647598937636, 0.12475666770290945, 0.11208812450809826, 0.17441451759828677, 0.08813150557539157, 0.12531902220460678, 0.21978864896922345, 0.1647267535689377, 0.16855210636652287, 0.08877665885994512, 0.19546497432935625, 0.15177009236668387], [0.06347895322007037, 0.10544330767926671, 0.030284533915560574, 0.013618289207619046, 0.038802414651839964, 0.010222593949536883, 0.045369297356134465, 0.07506959921410007, 0.005631622456524882, 0.010171041020282335, 0.026612818135970065, 0.01562173170368037, 0.020074889724773747, 0.0027860657099799645, 0.08086174486144897, 0.03487920561324685, 0.03712191652025908, 0.028989366518573898, 0.039388353170286265, 0.06118422111255988, 0.05898542236536742, 0.1066640611257284, 0.09364156998814115, 0.035343064190519434, 0.020341419374510165, 0.05646866648608158, 0.04204400079024415, 0.047215936975854064, 0.010198014018486344, 0.07079482859661503, 0.02315121920659177, 0.08477448530855679, 0.035952931465280634, 0.040425295310635725, 0.0018876303511206063, 0.06967813287290835, 0.016214406050200907, 0.013085126486276428, 0.09785237992482801, 0.055249560128657095, 0.052449359378266724, 0.031349007340688864, 0.08735519037732194, 0.057996904642711726, 0.011020707221881998, 0.08661154882922288, 0.008814830779879084, 0.0634981437225736, 0.0440020066115164, 0.02762438169860792, 0.05314215950127091, 0.039142776025278915, 0.010633803134213292, 0.05534875702353255, 0.019294322738724373, 0.06166083505377174, 0.013888081434302995, 0.041222777518053214, 0.03153517053672864, 0.011662610378416796, 0.0787888181906554, 0.03046369889841205, 0.017977794895188946, 0.0301965736153145, 0.019909479850602728, 0.06585002981967504, 0.03729702506755148, 0.04961707869604711, 0.07231408054189337, 0.03826766612849409, 0.07280692022534148, 0.1054909123828815, 0.13950317076617672, 0.8458006598295704, 2.6956405658875746, 10.901565013393279, 22.832179530974358, 33.450745536435036, 33.75006944902482, 37.06559012013097, 44.04540861806562, 45.045110948624156, 48.19187164306641, 45.480101800734, 49.39274449502268, 45.547939192864206, 44.69574543737596, 48.36076105794599, 45.47606960419686, 48.84560915731615, 48.3731714371712, 46.15573398528561, 46.4818202295611, 47.86164337588895, 52.568142414093025, 49.06642290853685, 46.58720647135089, 45.0375525413021, 54.36886725887176, 52.51035805671446, 44.47576715100197, 48.19810036690005, 47.95314442726874, 46.77633139394945, 46.09106979062481, 30.655148759964977, 24.55908929148028, 17.39442321561998, 9.240864861396052, 6.37939727114093, 2.0863917998729216, 0.5797812246507215, 0.12573595023563794, 0.025857677608127558, 0.06416154522148353, 0.05684731693397607, 0.11221106629818679, 0.02353509437412985, 0.019209748547103618, 0.06094191133254959, 0.0685509877099145, 0.004178860239804753, 0.05893881357605419, 0.03126905457447133, 0.056131641425552874, 0.025715206321629307, 0.01936220004403543, 0.018076748557148442, 0.054434810299426324, 0.09094032098449047, 0.05356569121020937, 0.03120393327046787, 0.02202711158221768, 0.033452554545815916, 0.02315570273616862, 0.02264593250959391, 0.04133802395494234, 0.02090038010670293, 0.017342091305181384, 0.0622148200448963, 0.08463508794985472, 0.0336254222859298, 0.0678907041888564, 0.005389296875951151, 0.04781030629190707, 0.08053847874004035, 0.06315421620984712, 0.024497017354494142, 0.026560467517664357, 0.04734492703010479, 0.021924044028104796, 0.031702150891144434, 0.030904325859380827, 0.09442995873189743, 0.03420590625835523, 0.011803126225488321, 0.049424281178583065, 0.027769875201967456, 0.07999971974641085, 0.018644664857176044, 0.03737612747617307, 0.06599599255188819, 0.044783799338244626, 0.01865962655433724, 0.05209656822825632, 0.01996888805391087, 0.010422313071396804, 0.049970413768483754, 0.09727184615668752, 0.05858859648146938, 0.04296576161117804, 0.027014713606707035, 0.0743431716616596, 0.03970816806559602, 0.05375652371214763, 0.012659751378270167, 0.012103204780648793, 0.017793972097757845, 0.04374319912805673, 0.048065390588054736, 0.03015475479074784, 0.012986912099163861, 0.04053347458642337, 0.016944014782746954, 0.027621608460322026, 0.016499515247320937, 0.025995221034052874, 0.07961671408866683, 0.042519852473971345, 0.023088627907958244, 0.052975071894545714, 0.037667731183671185, 0.02545370220867617, 0.026631832438250704, 0.012208809043400952, 0.009565476286825875, 0.02797077792967039, 0.043550868924226493, 0.1439357095307881, 0.05352221572050645, 0.017723480517405178, 0.04455997909028684, 0.019431347140080987, 0.05792089722930424, 0.01079964393284172, 0.03646735567599535, 0.013085218416827341, 0.06530444498264021, 0.030865230477384986, 0.04096375169953512, 0.020506854146538724, 0.03643314985017623, 0.019582140056656736, 0.01732251775871602, 0.05620881329260527, 0.0035336518926816366, 0.04202187234055131, 0.01029056510061867, 0.031137764341227954, 0.040393694183759155, 0.03896229337119768, 0.007017173385623122, 0.040301786615483226, 0.08585849972141367, 0.01867961761872134, 0.09968462475245038, 0.01900411139602863, 0.033886838298771656, 0.04856573027228156, 0.03504068928680593, 0.017848151750982772, 0.044950683931669885, 0.04612219707679845, 0.07612922138744786, 0.01766334453056897, 0.011536055526155378, 0.06531339288959581, 0.02573266929586328, 0.06679512950922213, 0.10323289886958177, 0.08352222266576945, 0.07129880719848218, 0.06810050502779984, 0.0354366073565137, 0.014642364901280212, 0.02545182337804187, 0.031216318996983673, 0.026164455602185863, 0.1977102707831129, 1.6541312851252097, 4.977888320722888, 16.384489382466963, 29.308567700847505, 41.15253902250721, 43.36250435921454, 47.55675754239483, 51.97142831740841, 54.448707103729255, 54.7038729729191, 52.30858741268035, 54.738327072512725, 50.49857439533357, 44.2229978499874, 47.67344021028089, 42.91176126849267, 44.400218379112985, 47.08421391825522, 43.921551935134396, 46.97930620562646, 46.18393582682456, 53.21458824219243, 44.54454198960335, 42.349163947566865, 42.84850128235356, 62.472919417965805, 62.795114671030355, 42.24444450870637, 53.12928845805507, 50.95279270602811, 51.891086409168864, 54.46387098681543, 41.308767026470555, 33.906415124093336, 25.997055692057458, 15.86325639678586, 10.951519339315354, 4.919310173680706, 1.7210486363018713, 0.8131701559309037, 0.23053977368099077, 0.033080749093524875, 0.08554744504151807, 0.07272640438449961, 0.0700856456833501, 0.03292183181451213, 0.024986459437998074, 0.03308265282201671, 0.05180624388759175, 0.07132601098067338, 0.03186131331829294, 0.04184739581579643, 0.012393672762799167, 0.02592482904513036, 0.05389175738298124, 0.10151113924239913, 0.034487727023060286, 0.0314400396535113, 0.013612125072658304, 0.0218616902167278, 0.036888140959725264, 0.06710996100258443, 0.012327445419355026, 0.04042886911080249, 0.04215333685879746, 0.09418236677564921, 0.07774772768419597, 0.026396465330054204, 0.07403384067959363, 0.06653080619270764, 0.06899999184233528, 0.018124029588615222, 0.05839181147635945, 0.08631847423291014, 0.049560449476684296, 0.01575825144461687, 0.01940240050786205, 0.033420080078705665, 0.022727681751993876, 0.03470845993668322, 0.04949347040946445, 0.01503717310110768, 0.08010293477244916, 0.02289304949132906, 0.04169410162214791, 0.035924145711525794, 0.048016701870027094, 0.017120770419076566, 0.056324588330162156, 0.04359964957280506, 0.06998750982024977, 0.048687928957083536, 0.017595287194595705, 0.037565875963698474, 0.01675804693912787, 0.03354189954998513, 0.05307488932063984, 0.06644613815531616, 0.048846892201371735, 0.04856508675842516, 0.06876883247206289, 0.01598098480533208, 0.03640932834617073, 0.16687236666198701, 0.14992936694573972, 0.174694829169781, 0.1383656527726881, 0.137361740513194, 0.09932602665597394, 0.08302407399300607, 0.15408050629400438, 0.11472573458787896, 0.10778401272311326, 0.09717781652486134, 0.18151615265636675, 0.19757560784778289, 0.09772666489645358, 0.18238581566800996, 0.09846860572936074, 0.22262064619891106, 0.10369661955102798, 0.12252568943245758, 0.17583351161691452, 0.24164892192329132, 0.2816559332272699, 0.1963737537904132, 0.23853216981214864, 0.12992019224311077, 0.2255123829649341, 0.12091140428017225, 0.14588399369630123, 0.06286562322789142, 0.10320114452512034, 0.22037812298344028, 0.17747908380002747, 0.1065879426295719, 0.09220296411865181, 0.1039024750371614, 0.23125379826993714, 0.12574515861248778, 0.06354355741472495, 0.17233319460384308, 0.2205789452719112, 0.1268174059148277, 0.18528086193386586, 0.15599987830125517, 0.10399932387254893, 0.09257991002091477, 0.20582660461866087, 0.11686021642338847, 0.14236480027677553, 0.08047781223731656, 0.16046304526107927, 0.14406367685765992, 0.20092937224093946, 0.13534893642269796, 0.16248761646209225, 0.07112190983588658, 0.1729135674935195, 0.16034609427855862, 0.06480094901616536, 0.09881196633702326, 0.06446211598813534, 0.14304497910122718, 0.12663654021678433, 0.12680084309390477, 0.21658258632786814, 0.20601022057235244, 0.17051756622329836, 0.14192826805576203, 0.13777501430482636, 0.127148202680532, 0.23470909995657785, 0.18613321135842031, 0.19859795218273518, 0.30478167617993973, 1.4180071748072103, 5.389734247038442, 15.8436063028151, 30.674552725207423, 42.76176198836296, 48.515914332482126, 53.256718420213275, 59.59994408392138, 60.72087510939568, 65.20876084604572, 61.63974523544312, 66.28711454329952, 63.396920004198634, 59.25983536627985, 65.31943444282778, 58.63170308451499, 63.66409617085611, 62.86398756888605, 60.01665669102823, 60.709202135762865, 61.54360402014948, 68.66305889621859, 60.32812033930133, 60.83828733813379, 61.05436286618633, 69.41413787103468, 66.10870945838191, 60.48409731157365, 66.120115710843, 62.45626111184398, 62.55046467627249, 62.06683643402592, 44.885694057710715, 35.93166428227579, 25.769487619400028, 15.28018528415311, 9.37945298610195, 3.7229098043134137, 1.4153431500158002, 0.5376260415200265, 0.32699163762792466, 0.1147444424549899, 0.2622445216101985, 0.2764303555652019, 0.20525000088157194, 0.20812549658360022, 0.11998724177359574, 0.11915096487369269, 0.09459383259978026, 0.15912196238435086, 0.13385592298882623, 0.10317405565611779, 0.14793960678000606, 0.12795022012846125, 0.11647462904933961, 0.09933493625853332, 0.1583382697595704, 0.11651440433436826, 0.13164983491503424, 0.15733098671320947, 0.18018199521447384, 0.1279699162489945, 0.09072156457771217, 0.19204497397426637, 0.15013438739603566, 0.2187521779729474, 0.21030919956824473, 0.12692060561910753, 0.14170743555070894, 0.23108973288007323, 0.1434528596338726, 0.13922993784710286, 0.1590367427636539, 0.16097658464024145, 0.1733715961416883, 0.09301895501031991, 0.13682141870019898, 0.09089041801710283, 0.12992682656453503, 0.29092571968513153, 0.22892915042898349, 0.13186109132103382, 0.19930708913072465, 0.06924455775128258, 0.1664376424084748, 0.14894120545396883, 0.1512532588094473, 0.058744208091088844, 0.19531728789931346, 0.2535856749501921, 0.30740050178381706, 0.31536073754391364, 0.16969227502422948, 0.10304321549952992, 0.14789266091200615, 0.20580674761966353, 0.25268061867644714, 0.2173891543380676, 0.14624437677764124, 0.15035129753091644, 0.19230086266273455, 0.1767939866911019, 0.14119575010432353], [0.015512099733666308, 0.04320627491500589, 0.01747200641060068, 0.030545564969220472, 0.1024850131943822, 0.015932309493843107, 0.06724039513257242, 0.03192181511211299, 0.0465984164827293, 0.09091067338182081, 0.0389285969938482, 0.06580630918183634, 0.12099432563709638, 0.060900542584638444, 0.024684161143076998, 0.03805691534052453, 0.07294978796234054, 0.0899325323200995, 0.06985066353433556, 0.04302938904372915, 0.08897852302799303, 0.08154327200064737, 0.03944297906972709, 0.03613839752130932, 0.03445045684554404, 0.09984269933474642, 0.019761843216275016, 0.0385504445031045, 0.12105417242574117, 0.09279916438484385, 0.046465569175779826, 0.008329811896527968, 0.06734290535772039, 0.08337511080166987, 0.05043928256078113, 0.013085183942870749, 0.044404378971986236, 0.0292912223977187, 0.0717546371743083, 0.016085178508693655, 0.03527399370326631, 0.028101698525490302, 0.02979076152006465, 0.04687430006602118, 0.0711994992208577, 0.03816805937657914, 0.02235586097794435, 0.0201996069236268, 0.0043171410253571895, 0.04387308550517886, 0.03822270825865769, 0.050009656622405016, 0.048035471024171966, 0.014200169375286469, 0.01407874731211773, 0.03224366397086171, 0.05282787576077446, 0.07562223206003828, 0.027241504360591213, 0.04791057954031614, 0.011202005759602594, 0.05114880638317235, 0.018336078895616437, 0.016978278065160397, 0.01813226311858143, 0.034780740332339084, 0.010124549059377564, 0.06923972373648037, 0.0683462813556675, 0.016005614532097694, 0.03753326743120148, 0.052135864708332286, 0.025952827643543005, 0.043096931185573346, 0.007716026082034073, 0.05085788449392684, 0.7642004674961491, 2.7834089917521325, 5.816383688680588, 8.724500517691336, 9.982244795368565, 13.029500842094423, 14.366235771486837, 22.378524080399547, 24.277745523760398, 32.769902483109504, 34.82910171631844, 34.573884856316354, 40.795548423644036, 42.30415082746937, 36.173658832426995, 40.85645106530959, 39.668737765281435, 42.77558049848003, 42.32538653958229, 46.927927078739295, 43.63491296768189, 45.53727034599551, 42.72607626453523, 38.73672377678656, 40.27963515250914, 30.28906806822746, 27.577921882752452, 21.762759031787997, 9.495714979787028, 4.381626277200637, 1.6814154146179077, 0.37306113168597227, 0.025594254444924094, 0.04295834971051063, 0.03989998116007736, 0.014454733689255534, 0.027085555672285058, 0.08029280966448207, 0.04737000108786649, 0.02009693582001473, 0.019546578255211635, 0.05868096753293949, 0.06036662526669041, 0.012792501009009298, 0.023684069747105244, 0.02171453047213295, 0.09774701985260172, 0.012909056498639047, 0.018315584128422123, 0.027624425748663566, 0.06710026999034228, 0.04979620537450237, 0.03867124890788429, 0.02276710846701697, 0.029508799029093598, 0.05735429477006678, 0.025084959192862435, 0.03379479666510898, 0.06107511487038386, 0.11045133935347681, 0.035695430161731864, 0.05719361165838857, 0.0015680838259868326, 0.028611721561080026, 0.07551794451090597, 0.06444519310588799, 0.06698672809908468, 0.017756361011115294, 0.03683325459039019, 0.017185640829284827, 0.024005370852988095, 0.009989478182227863, 0.06526056346633742, 0.030606727513875213, 0.02717044204473496, 0.014927398447217721, 0.07614494151165409, 0.02215628358235042, 0.0469820618238901, 0.01789739779797533, 0.03019613886041747, 0.01496694582108889, 0.032115426597996585, 0.02054686117316446, 0.08760030020869548, 0.015027201509163266, 0.058957506121406635, 0.08740930682829312, 0.015305855457911329, 0.07299044424848211, 0.027641735505312685, 0.019126522670229597, 0.055214166866555336, 0.1219938405519051, 0.04404890651424085, 0.04510608486711018, 0.058838302840388594, 0.07142091395273324, 0.14473717539541184, 0.03176018205140868, 0.029125609510247747, 0.04134561205583234, 0.04946708634135224, 0.012650048874709155, 0.09853784475595721, 0.033819870722870675, 0.041412457057665435, 0.09162535680638206, 0.048019689612931786, 0.06377682735722873, 0.11845006337088924, 0.04165850534674622, 0.08325659699978367, 0.06992182544162197, 0.048716331666876236, 0.026187453561672763, 0.050985116376391346, 0.07194700951297438, 0.04158755028319936, 0.04793939210714833, 0.041949856245229324, 0.025685968575999144, 0.03273368062030885, 0.011444997357865496, 0.008503765566274524, 0.05327965696192077, 0.028748284394462264, 0.04894357249741593, 0.01812126209598876, 0.07276333748332917, 0.03323539543235975, 0.021872474819481857, 0.0696268662690155, 0.009515125158002541, 0.013151259026339939, 0.08538976882494266, 0.026626308944316644, 0.01962445492315437, 0.057220302161670504, 0.08912303019315006, 0.06932469054816232, 0.08309345857630815, 0.01657457845736175, 0.030319444542270035, 0.04228151485984845, 0.03992762927326464, 0.03135460935863516, 0.09493358493331941, 0.022583323973982085, 0.03933697165320477, 0.06153299796184706, 0.07411926714403015, 0.09864318184554578, 0.018374256887322953, 0.030903609567171628, 0.040682436552860086, 0.017585203562292363, 0.03774081980208716, 0.03881718099658047, 0.0307537685148418, 0.018862862019769607, 0.018049939310238246, 0.025684011221352606, 0.029179354408575647, 0.04001513183597596, 0.01633525258981653, 0.035944810933283264, 0.043390208795186014, 0.09629283941561177, 0.04085119806169983, 0.052340536588622685, 0.03489061649287901, 0.05702937006830208, 0.03349839341676524, 0.058534426404343504, 0.19682684883234963, 1.4094869287744647, 4.558628134189114, 9.19282171034044, 13.857005238533022, 16.617652716175204, 21.153534535438787, 24.427081923330984, 32.41258436633695, 33.79394508177234, 41.420154494623986, 43.56958197009179, 44.62937108932003, 51.542701490463756, 53.39494666745586, 50.40827358922651, 50.77088494454661, 52.42765095926101, 53.678655624389656, 51.8844929049092, 55.071661856866655, 55.81662193421395, 55.50972000245125, 50.73386169249012, 48.00399403418265, 48.701258090234575, 41.21378291037775, 37.53489778887841, 31.44229392851553, 16.016429854977517, 7.242086308617746, 3.5468400005371343, 0.8493218450776993, 0.14705062303091251, 0.07102679235920792, 0.03250343672510597, 0.057076335088500095, 0.0606334000645626, 0.019334174632545442, 0.022322172261474114, 0.04887715650482043, 0.045994750689715154, 0.029309518492570328, 0.04139559929289165, 0.03028662916603348, 0.025498797974338936, 0.012137549459904194, 0.07012598021256347, 0.015660701638778612, 0.024054839065478697, 0.01927883244089542, 0.03632181046170093, 0.08714895950810564, 0.022435214280361132, 0.0637686072338012, 0.025933330705870065, 0.12446531680442634, 0.041540995120040836, 0.0324278429991776, 0.02466550690212077, 0.03478089354992394, 0.0038280427238092793, 0.025134810449315176, 0.014406628155660246, 0.05748624192370523, 0.06238247838712508, 0.036774177720109304, 0.04264370973912939, 0.04692550921331971, 0.0069405689024396484, 0.024383228399880955, 0.004254635432810193, 0.11359819872004372, 0.030853229710051132, 0.08802572415480692, 0.021535853870333205, 0.02837157597945583, 0.0195418112731028, 0.04881719097254738, 0.021999618601835063, 0.04114356785712223, 0.04548262474277327, 0.10338471451353642, 0.019809681576706713, 0.023101413915414485, 0.04499844185286953, 0.06298283851074596, 0.014611981854203248, 0.10180517144861723, 0.05022009331432562, 0.0195650237372085, 0.0773178604281237, 0.034373717818168864, 0.0212883155402397, 0.02643985846530526, 0.07667161929871767, 0.10752883649641469, 0.030258559704487844, 0.060424169961122744, 0.15247175229653237, 0.023378237871633425, 0.13038560597886964, 0.12464853439239726, 0.10137227048436481, 0.08701836449965354, 0.1831915409814927, 0.12969634135163602, 0.19369256862949943, 0.1393230481734199, 0.1097834485793306, 0.16999472653673542, 0.2430480742646802, 0.22147074822456608, 0.20022676236206488, 0.2421486104327825, 0.13653347689297893, 0.18174173490655038, 0.09687747175414717, 0.2060828610293327, 0.2285691657133641, 0.10977684490142331, 0.15971817797230137, 0.1589497458189726, 0.1253145329293705, 0.14546423880082948, 0.2605989034618101, 0.2541063083035331, 0.2023419924080372, 0.14577824291923355, 0.1749347985511826, 0.3048773452399239, 0.09725787271294864, 0.1095941482532409, 0.19413576581545416, 0.1521004448013921, 0.13462997822751924, 0.14597200187704257, 0.09284405713720668, 0.0736529264418829, 0.2643989140708601, 0.27856194924923683, 0.15037075616419315, 0.25865227404621344, 0.09516265288355852, 0.10223659386317577, 0.2658277293366771, 0.18183001887894448, 0.09409977483653253, 0.19447316625906577, 0.14789563333315237, 0.13889932494250037, 0.20131165011515542, 0.18777041786140014, 0.22815463553753593, 0.10951522587528152, 0.19247657258904752, 0.16993317903289873, 0.09345028549432756, 0.1605213598738755, 0.18248304754735964, 0.1270296812177666, 0.11278509597985015, 0.14318886573516554, 0.142932333532841, 0.08948826261105076, 0.12187079917038642, 0.08514862732901689, 0.1212487051323537, 0.11532113812262974, 0.1776640787119827, 0.1712218308520894, 0.1869035434098013, 0.10664778941821669, 0.15228012306315286, 0.10519307271967973, 0.20849108906282535, 0.3943724719987762, 1.4149086249451486, 3.8424057922055646, 7.776314596976004, 12.749992743615183, 15.288868431122074, 19.427877972202918, 23.84956586745478, 33.31217604298746, 35.2142745448697, 44.971648877666844, 48.84428339619791, 51.38375920634116, 55.92878995403167, 57.35772117491692, 54.680919262670706, 55.82658867682181, 57.120986523166785, 59.495550201785186, 59.05247142238002, 63.27732301527455, 62.03905428609541, 64.98095350880777, 60.01127127678164, 58.26950357806299, 58.17946949312764, 46.03544273684102, 40.8337797657136, 29.97274656449595, 15.180595324885461, 5.984247894056383, 3.0245131638742264, 0.9188128839577399, 0.3184261311206126, 0.19482846251658856, 0.12256421599416964, 0.1819136756802759, 0.23064603007608847, 0.18391691899347692, 0.13921630148205066, 0.15038793185545554, 0.19196612820509942, 0.1073449983772251, 0.1638016564350936, 0.16839793883264068, 0.10401567218885308, 0.092099228152825, 0.18957392673098272, 0.07602455079435341, 0.1562447506453722, 0.1271776740829791, 0.10163039614957187, 0.146246766971965, 0.1447080334107722, 0.19331638881516075, 0.17095134052778446, 0.3327926086081613, 0.18434894661749565, 0.2008171097165154, 0.09631707077665676, 0.23744493783000978, 0.08972483056206858, 0.09838317160404499, 0.14950826373552123, 0.21176432229338155, 0.18820852822353765, 0.2283696457743645, 0.18994440685116476, 0.1261342853127468, 0.1366282726127294, 0.09535029079885253, 0.08308071853412737, 0.20347822337381302, 0.12866298067233256, 0.15307469413645808, 0.1704783425215752, 0.15712636462863416, 0.18131303210412303, 0.18131045804869744, 0.11288115574467568, 0.11758657502791575, 0.2023642549231168, 0.20155877475776982, 0.09505545420031394, 0.12369346023807604, 0.1854600192558381, 0.19485210398993186, 0.13699449328405244, 0.16813304095018297, 0.16354520084156146, 0.12649165000766516, 0.17786903787524472, 0.18685357915537973, 0.19009416171860313, 0.16404101294615578, 0.11612720817567841, 0.16669003773600827, 0.13996450891417844, 0.2215573774470437, 0.2874541462909791, 0.15694363733693478], [0.036842512762955124, 0.03204227477732686, 0.05136853572161448, 0.08040044501784348, 0.05176941421063197, 0.027362509863451127, 0.06078418532025911, 0.029364831955923192, 0.022754362679176757, 0.049608793455146016, 0.10973839494850367, 0.05662802043521116, 0.024295338962767875, 0.037121905028940215, 0.05120288836018694, 0.06178361213495655, 0.045821706749378674, 0.043477818610206734, 0.03620471392247466, 0.05674218285768744, 0.011921918691856968, 0.060398705198519656, 0.014607261794979775, 0.03345816997030089, 0.022346505129169074, 0.07092386078570159, 0.041105382204536474, 0.050727542294489766, 0.06537923048580847, 0.07053240517815275, 0.0338745694006643, 0.0775236776098609, 0.021168451508386962, 0.044267203268264575, 0.045356132135155706, 0.0340080295779532, 0.03621673001156699, 0.04303396641907673, 0.02125153182855537, 0.025786580818314708, 0.03541196613842922, 0.027808271528732394, 0.008495485113422957, 0.044724063632348855, 0.03424392720203727, 0.04293178178129658, 0.07085940214775263, 0.03703576227229449, 0.024396874341032198, 0.030558816375090714, 0.0070220940641217665, 0.06296096287006814, 0.02530571891956272, 0.014128168601722968, 0.029721463121654048, 0.05259534892355723, 0.031322766914062446, 0.038358187077627066, 0.01622859399855858, 0.04384050378575922, 0.026216511276640722, 0.03147991261475029, 0.037532424734484766, 0.05782818526870782, 0.03737888539270048, 0.049973206158967755, 0.04612697746544596, 0.04795956703263426, 0.03128149009670221, 0.07924393570471196, 0.04522314693237986, 0.007844050865500204, 0.0811959277357786, 0.08046972234883616, 0.1168604922150412, 0.04515064054078633, 0.052028325115961414, 0.015047996008257954, 0.05834800273840947, 0.018885137941387874, 0.12479795984202817, 0.2747170152443071, 1.163167475212005, 1.1439582801634267, 1.4210021495819094, 2.0033459076958318, 4.238790715894392, 5.363820127902493, 6.292121593029269, 5.942841883628599, 1.4915176625213316, 5.355946950374111, 9.438751378367025, 7.422196643967783, 10.669502885110917, 11.043929399982577, 11.497615248926225, 13.054090180704671, 15.57038772490717, 9.989458034115454, 9.78822083242478, 5.300724881310617, 1.750117811945177, 0.4719594054885449, 0.11896640663185429, 0.047592580273386934, 0.08610076736658813, 0.05065640336984108, 0.08036658393159028, 0.03733312313054358, 0.01492990930038955, 0.0699579464872518, 0.02004133315847045, 0.046579448145724116, 0.026360765632782734, 0.06906638868273267, 0.036024020594214244, 0.026214500295839487, 0.05600744708170814, 0.046191037737674294, 0.03215184450269707, 0.04100464930337283, 0.014567474061022363, 0.05838017843122925, 0.05179516242576703, 0.008061054846151702, 0.049621908880409696, 0.018440588610246778, 0.05534704098658216, 0.018338566766150536, 0.032959638253575375, 0.03987102686697918, 0.011639940879127432, 0.05365790521365501, 0.052085670627533436, 0.029147693909884944, 0.024357836415630676, 0.03617504333716728, 0.011884962610389677, 0.027089510601194158, 0.016046008433125192, 0.07414297756528662, 0.012511937586109967, 0.051658457866118807, 0.05088711457867777, 0.0200970200896864, 0.04117776219162249, 0.06264243883291079, 0.05050334283300946, 0.01469157647431618, 0.08032773561295002, 0.042303601174705455, 0.007499194471165539, 0.09881056439612182, 0.04248397274603767, 0.02730464149687079, 0.0190243476085485, 0.0420120089585262, 0.061771791398284905, 0.05461750694760873, 0.03289065586643354, 0.026205175090581182, 0.029912628871839375, 0.031050968494626786, 0.0524665005955725, 0.03502920945926059, 0.0634027504542422, 0.027348666654659376, 0.05775736044010809, 0.04418294125747296, 0.04759346127449986, 0.058586325030773885, 0.054778419885664224, 0.05904829520131311, 0.049710480135775385, 0.15485577195161773, 0.06545566307801394, 0.029052105289132848, 0.09911378199655203, 0.035296712040660844, 0.041077776226185025, 0.051824802367557446, 0.0657738347147261, 0.08466632901540688, 0.06379808629712751, 0.06145316010881817, 0.03413116672046242, 0.06150477528271656, 0.01273236119173347, 0.05227158484499782, 0.07241437677294016, 0.03429852628840074, 0.10208800344938233, 0.04695369358805399, 0.024666987367034442, 0.045126941610848716, 0.047345486274289514, 0.04412135161880044, 0.017697086873193903, 0.03897574970558767, 0.033748026997331655, 0.08075706660747528, 0.008288371327873922, 0.06972399855693502, 0.007474031355682641, 0.04525735275819898, 0.04806088599105997, 0.05689696709234869, 0.051907704572283456, 0.03213876355138998, 0.004319600646399082, 0.027372321534541347, 0.026621936497488813, 0.07994363444947428, 0.04041884485031328, 0.025920814744407134, 0.04030431470563335, 0.039241153206075394, 0.01741989519477131, 0.021928822501532493, 0.07631112130418902, 0.030065258484213587, 0.02784024037781262, 0.05074661788380435, 0.03692170710212762, 0.05401441572053779, 0.016611860126196858, 0.05848662634830802, 0.02245352952741087, 0.03187200599049609, 0.016668987302710454, 0.05735637086834158, 0.05554602849447439, 0.11627260400282761, 0.05757588953260453, 0.047207808782977444, 0.036271455502437974, 0.06380801479662619, 0.057042405054333715, 0.014018274246594839, 0.015964442094217147, 0.023080331175738288, 0.05054389569728125, 0.03938210189282414, 0.008394137426700083, 0.023135794026236382, 0.03796437574971107, 0.02171668892485961, 0.026408073477326866, 0.05006763032607494, 0.05667203218646108, 0.051119032375995195, 0.03548389796407954, 0.0195769613022886, 0.05898286363170032, 0.07677255138274162, 0.5044145671831024, 0.9622888639569284, 1.9083866741388076, 2.3997445596802622, 2.9118771562653207, 4.967672017312819, 7.188211083412171, 9.375155048985636, 11.001485432347945, 11.516544607377822, 4.187086032282922, 10.63803174803334, 15.356908805908697, 13.150155890372492, 17.58565641218616, 18.9383485240321, 18.432270596104285, 20.500863905875914, 22.18607298789486, 15.631783604621889, 14.493049921527987, 8.821804715741067, 3.8705201158600473, 1.3037229137074564, 0.4785585481553309, 0.11758757094221732, 0.056349957331774704, 0.008200104592458136, 0.01195273649383096, 0.035185426278340245, 0.03363780226678618, 0.016877391946411902, 0.048629717766157085, 0.07117271678702486, 0.0185474387234858, 0.08855693718238224, 0.020621763504741174, 0.02258344463283016, 0.07069234901498403, 0.044332857003375414, 0.040191378023835926, 0.028631492375185894, 0.00919719962703605, 0.06790161328089815, 0.009787493355331883, 0.022602621728794712, 0.06205189229559995, 0.08461660224824183, 0.005682044448481212, 0.025761847669679313, 0.06705258867793507, 0.020326126344321717, 0.0615767109388065, 0.018140605816076842, 0.03306620491428241, 0.016797667091351845, 0.031472355157377264, 0.036923729574247714, 0.0336556138110257, 0.03435253548706251, 0.023080522697719357, 0.05463432640798631, 0.04324023559268925, 0.03545045822618469, 0.007189926691353322, 0.02955819254801158, 0.020014190663313194, 0.0725503114142245, 0.08626091038627971, 0.045094183691206484, 0.06879891674484938, 0.02163255906423494, 0.09460197611441536, 0.08374392851105622, 0.02432973631056807, 0.01690248898681133, 0.011218143401727563, 0.044822525082817005, 0.019620321878802874, 0.03968786290516296, 0.059597055472794085, 0.08381149746597776, 0.04822030122722349, 0.02312620260542439, 0.06406168183011395, 0.1032531465734205, 0.10586913765197802, 0.0516374287525973, 0.021852453111580784, 0.035522876517666925, 0.05432988689731687, 0.034871575377521016, 0.06634394968709638, 0.04456211647559558, 0.03454995634514959, 0.06419987260033527, 0.1471228038351382, 0.11067545071484582, 0.23532333393250746, 0.1911647542710266, 0.16847920543964834, 0.17678467106194268, 0.1732357227874379, 0.15159406068344272, 0.16005668158252395, 0.1561071765759299, 0.20792735560286432, 0.20360254412216527, 0.09478457317116762, 0.1432465215123469, 0.12372353684998329, 0.10007277852104557, 0.2357765209049948, 0.16408160028438415, 0.2603809361255938, 0.13505690370596227, 0.09325791315566148, 0.09401220332590804, 0.12758325635185166, 0.1544065073493027, 0.1543214256244321, 0.20453634401482923, 0.09389232588751663, 0.1334248453138336, 0.13723718993846448, 0.25505158419330276, 0.08324881354647298, 0.20765999091729043, 0.14694983650359417, 0.16664565060167544, 0.07957093267431183, 0.1003138587299374, 0.0923277062153624, 0.19390957069493112, 0.22147045711115484, 0.1302911933030813, 0.07868027885354335, 0.12090699927460764, 0.11924769879589159, 0.2171616262245563, 0.15881221771480578, 0.15816101233565039, 0.0842789643173737, 0.12801554444576466, 0.17287449700938118, 0.248486838874317, 0.0652413193376795, 0.10250942841652902, 0.11934044906088423, 0.06391838891431689, 0.1540153428551651, 0.19451597525227457, 0.09706929250950776, 0.22621886924870555, 0.19829442814713527, 0.111422692876189, 0.1019638972056489, 0.2750498344821315, 0.1972103984125199, 0.1355380222441689, 0.20625371395820574, 0.11560416930625517, 0.11789992797158419, 0.1211972699891175, 0.08476368346882444, 0.17953049872190724, 0.10909555524948145, 0.1343412856541334, 0.16407145728026667, 0.11859471609275188, 0.16742833199039583, 0.11567551507464341, 0.15027542418289572, 0.09279207807154426, 0.1115693067831378, 0.13538341037929058, 0.4089079791259381, 0.6517223352866789, 1.4024905235536638, 1.697845732973468, 2.3150184221806067, 3.6909932330731428, 5.943680780549204, 8.1098602087267, 9.501044500258661, 11.086467504501345, 3.9620020456852454, 10.258468889421033, 14.13212420478944, 11.73049617198206, 15.644816660111951, 15.452818601362168, 18.596221746936923, 20.277153484282955, 21.63974565844382, 16.130987578822722, 13.305224833949922, 7.852150682480105, 2.79247211833154, 0.9655352994318932, 0.3967329421110692, 0.25602515937099535, 0.21494974652605675, 0.18318331319718592, 0.13162642326806823, 0.13215649482463637, 0.1719723518697485, 0.17116489519755687, 0.13741152090651376, 0.19377380459299012, 0.12861411958452196, 0.1386918989761222, 0.11238312198510093, 0.17940976326504063, 0.19864707374044005, 0.15287057766991277, 0.11478431733144868, 0.07854649691932625, 0.09121823470078169, 0.20838334645715453, 0.15390277389557133, 0.17453346040941056, 0.17370498228457668, 0.09207965460635963, 0.12038003803501207, 0.1775771890196108, 0.17089802080825453, 0.17877835359784866, 0.11606006056911523, 0.11453048941949684, 0.18946940169459392, 0.12314163944533757, 0.15804727892241172, 0.1020382460387003, 0.12259129720229296, 0.09704527565308156, 0.09837045454450193, 0.16708423593832603, 0.1303316580672418, 0.2531426309818222, 0.14144731805689875, 0.08015041690199606, 0.1080854989648346, 0.18141381863144138, 0.137809993879449, 0.1330608616192495, 0.12262970885081638, 0.05772918755669267, 0.21513616636155114, 0.2380643812038245, 0.11701574759377588, 0.1001751202068502, 0.1092329990839766, 0.20065001061847135, 0.18167436513448917, 0.1729017390959686, 0.21454641655568155, 0.2372585792815493, 0.10549604517197418, 0.21523489977323243, 0.21283883721597735, 0.25653974062973456, 0.284791377883765, 0.133031030155478, 0.13702522873157455, 0.13775788457883945, 0.3172165702187246, 0.14019790526118972, 0.14664854944473313, 0.14083371227306707, 0.14029797166585922, 0.23737228205127103], [0.04837102136544643, 0.002133210847762624, 0.050106693149334004, 0.03283297710661446, 0.03137582999413773, 0.03982072553387092, 0.056597591422858744, 0.018012512084697525, 0.06703747376318901, 0.02680397622527615, 0.05772607340928047, 0.052048178284519145, 0.04087278641940605, 0.006672739297256715, 0.061007760420081124, 0.05117217972574215, 0.05441740861222629, 0.04684978525244421, 0.0489790040639139, 0.02096191994966038, 0.02688081101364186, 0.016613430606441635, 0.03356149607908822, 0.05962844592549148, 0.015412098446470356, 0.06827961638449662, 0.05107293303515162, 0.023654391500918616, 0.06372331611571774, 0.022609441826540618, 0.03377271035025197, 0.08327836155771248, 0.028448596544143175, 0.020856559877434087, 0.0777114917253775, 0.011366815212362958, 0.021734979274051807, 0.03589477007006926, 0.05535323863788959, 0.04092221058184101, 0.07368881000025619, 0.02716495877041692, 0.013718241656709824, 0.026956180658852382, 0.0626107266232852, 0.04098966462357391, 0.057589510575898235, 0.03776530780258679, 0.004804749764697326, 0.02533357962214899, 0.022337256532703197, 0.0186030279784914, 0.052898072397276286, 0.051654524004627625, 0.03048727333906197, 0.0429673818871379, 0.007033679228756698, 0.05047969752922655, 0.006348727676536769, 0.04952906285442653, 0.04670903574855578, 0.03879403364994834, 0.008120431448332965, 0.05040451366033766, 0.07408249492366469, 0.044285485956577525, 0.07902643568212948, 0.028012338199562607, 0.07284121032083228, 0.03718500769126319, 0.01831912920029173, 0.04101154792513098, 0.04118052393858952, 0.06195727277607207, 0.03315176161366605, 0.08409561649445566, 0.028212903848578854, 0.10510388476353501, 0.030204751603906194, 0.04569439059724251, 0.01609933964397398, 0.04623123437106129, 0.03677546091738247, 0.06531395979465977, 0.024112492927440235, 0.05185422780472906, 0.006419548195891924, 0.026715337937217087, 0.05133310415511651, 0.035483242958904274, 0.04534251492230162, 0.07009765028112358, 0.1465813941772907, 0.03769278225879516, 0.03896335440297281, 0.10980381885723722, 0.2620550221012485, 0.15169826396290334, 0.13728998871820589, 0.0191253065056498, 0.09965995672128855, 0.09681221638475696, 0.04356309951793763, 0.06279685151492877, 0.022141595761622154, 0.053027548917358926, 0.021450860245573907, 0.05626360773138943, 0.03716036264273909, 0.06516261146433892, 0.025427494340786533, 0.058566176918365305, 0.025162150212112936, 0.05530380298413577, 0.012814823853512926, 0.0420459236709341, 0.035521447763688145, 0.04373558038364976, 0.04290979888830935, 0.028610564768314365, 0.04652713966225425, 0.04895463097660292, 0.047989846657841444, 0.012294519917979356, 0.01498795003675285, 0.02871746084682884, 0.012000839154596531, 0.018180681790615764, 0.02656935605280582, 0.02124175846186136, 0.05211948574851117, 0.047249644844522404, 0.03253439816856577, 0.009109987220126054, 0.03181228369113899, 0.023275367585161043, 0.030655220879482168, 0.04107926626719775, 0.027064043923371264, 0.053954948145415516, 0.0077269117126331464, 0.05732194287702442, 0.07693522249258335, 0.0663838475461929, 0.05805305505712187, 0.029170636327997334, 0.023923328581957087, 0.054394399161420526, 0.009462433630570529, 0.050954610755246495, 0.03905406304364724, 0.012850278402648628, 0.01701542949904838, 0.06759050497484785, 0.03426488353720596, 0.03490567012059112, 0.017596545494011333, 0.007844410926824617, 0.019244699393429102, 0.05149541903407343, 0.030275591754264412, 0.05574987299980656, 0.06506999909517265, 0.013720280408198315, 0.1060837418622067, 0.01583196729752085, 0.029191290058435935, 0.021123633449596745, 0.05800391051677927, 0.026357069258548083, 0.05741750468469917, 0.03822284615448406, 0.061407133546327396, 0.024336121653416948, 0.01130906271658117, 0.04103327417866357, 0.02392021443454489, 0.005413275906786082, 0.02236880786386469, 0.02709096425303048, 0.07927521507466033, 0.018175926299825795, 0.06055616308003665, 0.07423146838142027, 0.01638671071569045, 0.050710397246744365, 0.07260091152162322, 0.03193025357059894, 0.0476663813535725, 0.01646698523883618, 0.08119834857361932, 0.01807794939996975, 0.01314608697524114, 0.05894066367839133, 0.017669999919411157, 0.029534162285046715, 0.09409238974894248, 0.02276989128140192, 0.0472121141971119, 0.043178186301262154, 0.016175781812278495, 0.022964178839878693, 0.029961899816689473, 0.035205873165039286, 0.08610894152474019, 0.022477448707626715, 0.0397967393209617, 0.05782672587121206, 0.030079890763567343, 0.00985945582449917, 0.05573399965801547, 0.01995198432386162, 0.03711917009505053, 0.06354112891600498, 0.05642521014857677, 0.09079602066307299, 0.06657959833260506, 0.0787308483174251, 0.07331797747962898, 0.06651835726393808, 0.029040987438131726, 0.017992331413552165, 0.05794374580164591, 0.017124857498152603, 0.025199267172044324, 0.06173369767625005, 0.025099403780674743, 0.04443169766736608, 0.03303030603415063, 0.06841765010669347, 0.05175663969449459, 0.03658646702646248, 0.042683626750424024, 0.06313285001763894, 0.01837503063612648, 0.04540433438735143, 0.004050467255330014, 0.05315457012564425, 0.04086452033070307, 0.08661519540774246, 0.08706407696609536, 0.04494657386995612, 0.004643746811310731, 0.0470841660224382, 0.02198488481583134, 0.015551668174955395, 0.02939451403254944, 0.04972328146499011, 0.07173547731532205, 0.0273639903283648, 0.04102732167549191, 0.0764051509360152, 0.03195444854246753, 0.014831216108324307, 0.0204332924688295, 0.08561017232075815, 0.018174275380348968, 0.040052938275039196, 0.05754387471824885, 0.05140688225266434, 0.04402853623633424, 0.039906094541713115, 0.05011610070904417, 0.003283167236311842, 0.14644369753378053, 0.20543268220799588, 0.0811316759415692, 0.11122789969968219, 0.3528652766779546, 0.28678403386185247, 0.25769196751136936, 0.3141559876741902, 0.5613047773799589, 0.37620157123573367, 0.3281548655321521, 0.16098519546851037, 0.16586433284946028, 0.04335506451165965, 0.04776366302863725, 0.08724347177532413, 0.0056238653374865895, 0.04847011866889173, 0.010393916107263538, 0.03408369608223438, 0.036868885339748476, 0.015431591553703673, 0.04127939524609716, 0.10221045494319932, 0.041410354146313284, 0.033088291229139415, 0.03177324193529785, 0.03404748693649327, 0.04914453651215281, 0.02160943086980091, 0.07554035258269118, 0.04624704259537882, 0.03026777574221694, 0.0322887099408094, 0.03691704162666875, 0.03953581743483101, 0.05452024059430246, 0.06497055322172181, 0.00987539524137373, 0.026068472446152763, 0.0648016384952972, 0.030474184726875637, 0.03774375008839754, 0.06068400783284057, 0.058251142411703066, 0.06626410800362788, 0.01024408271581295, 0.007447821572573195, 0.052719121919043606, 0.0009903097100416951, 0.022707430217715523, 0.09425948884698654, 0.0744043974085681, 0.07837850149841079, 0.05347825376497162, 0.04290363188051889, 0.010795978202124037, 0.027174125012430935, 0.03222455773803015, 0.02645831543862099, 0.01428935158577177, 0.05211795740310223, 0.007747459627177207, 0.04438196323932179, 0.018994776614671274, 0.039983936735699256, 0.035996843625100396, 0.03624492970805976, 0.14473654720331394, 0.024197873426601294, 0.043765063277415694, 0.025866443569201137, 0.06270216687792732, 0.07916082282580676, 0.02022984441399815, 0.08674955190790277, 0.02742917483462201, 0.06499730501203768, 0.009639426754156669, 0.007391512673723722, 0.040959718246613784, 0.019995505778839993, 0.012742410350080221, 0.10324490346735525, 0.016242986875436, 0.055806506049608996, 0.04148456125309871, 0.05179328167991293, 0.12927568247241358, 0.06977303584496822, 0.14990802373616927, 0.14129786962463012, 0.12457147360809388, 0.18186060110888175, 0.2572226007619212, 0.12122914690764681, 0.14471852881533487, 0.17954016675151166, 0.11344385498593892, 0.17100833746935093, 0.08818582120922305, 0.10424347609401712, 0.1264127276297058, 0.22619927271960244, 0.14525767085292648, 0.1533824622991585, 0.1519234784908833, 0.10649558306942064, 0.13398347662821894, 0.08675876028475263, 0.1377653615969804, 0.22581866491706143, 0.09980712221154284, 0.20778556804983847, 0.15539048600100702, 0.15303032232388375, 0.18007431389583697, 0.0778089227875875, 0.08824828035768964, 0.2106761250404581, 0.12278900151291203, 0.1690267131573731, 0.23013937016648633, 0.06907536723320523, 0.16282644182924302, 0.11297409753164939, 0.11140635222076409, 0.24656342192282601, 0.17806213799743884, 0.1364380070158551, 0.09715018373343254, 0.18850281323877074, 0.11390890866037338, 0.09151820408841295, 0.11688506831565212, 0.15538418875826945, 0.1122782905135424, 0.11003087199623547, 0.05299879380712106, 0.15465131840638577, 0.11911136578888663, 0.15415659414664393, 0.10498242152314033, 0.0875093502503249, 0.12835109861747873, 0.14511553089945547, 0.0895743019458267, 0.16233147242136542, 0.09300361026919658, 0.08384446989023879, 0.14233826299107846, 0.23516270061654432, 0.20543772306653763, 0.12277253062254, 0.13873791021685447, 0.16178479207859886, 0.19874876425150903, 0.16856462424320562, 0.16690031354946477, 0.11377907973984558, 0.14497653190647403, 0.06595659264994246, 0.18138245499182135, 0.19007890124715146, 0.14706691006018272, 0.24069166441838588, 0.11138914588598475, 0.18783247098326686, 0.0714852806601313, 0.17336359818375882, 0.285569723214834, 0.1772518467999274, 0.1803620565201967, 0.19857818711428873, 0.0924255509650515, 0.1277882231759929, 0.14440049507444905, 0.16053927100954518, 0.10031008191647069, 0.1930583550805046, 0.3280802792118442, 0.3186466725122544, 0.33496213896620664, 0.2883536867316692, 0.42129025824608346, 0.43047019791218544, 0.25924623733566654, 0.2580031524262121, 0.35634855589559006, 0.16706618690682998, 0.14860264055671232, 0.18535380882601585, 0.09557807172137885, 0.13092323116237117, 0.07953448987175381, 0.16715224922424363, 0.09042652879631327, 0.14603716531588187, 0.14561420817288662, 0.2450873083885639, 0.11460989443284851, 0.13553941652419108, 0.08427553224347292, 0.11728358725386283, 0.16917720346921877, 0.11220098458110325, 0.1261331744852566, 0.0692737150576807, 0.09083725151515777, 0.08679505753060503, 0.14246261438294766, 0.14994297266727494, 0.162679536808883, 0.12397089897985421, 0.1024910269845878, 0.07696692321089006, 0.12416352412753529, 0.12809221452522662, 0.13792202657749578, 0.19279978508430143, 0.11798410571270412, 0.180193517176855, 0.25087381562879013, 0.12992495730999978, 0.09941565894311476, 0.09671706060368208, 0.1621978513656124, 0.19282531113393847, 0.19454701713496642, 0.1780312033670564, 0.1894433240616514, 0.09836306945691187, 0.11301178905752399, 0.10599448495814878, 0.21484644723034677, 0.15322526105709616, 0.08138100691740552, 0.20051542429193375, 0.11546123262134292, 0.11570039761042404, 0.0766041499352263, 0.13464019784042913, 0.17781597862560905, 0.09685749218108193, 0.22480942068561433, 0.23513984055288378, 0.17421001808777933, 0.14070032104369135, 0.22146265833608567, 0.1048777892344421, 0.17748248523041127, 0.114918673831609, 0.16431511920546332, 0.16914059978819665, 0.2750879243737267, 0.09894875899678278, 0.09748108775144625, 0.14482990267776674, 0.18355773100929876, 0.1571372737206759, 0.17684197443867886, 0.07828784265345143, 0.10766041209740985, 0.18647623488739615], [0.04769094979330417, 0.01827561732141241, 0.03747811676153252, 0.01874449185936922, 0.04999104834672424, 0.0769459553844025, 0.06451942702575077, 0.03681261618171008, 0.017945134651757056, 0.05884368077761704, 0.03296713825435408, 0.054770916054445895, 0.03160089321975266, 0.06605692718538546, 0.03057656280185667, 0.023876101176645008, 0.006306751803945631, 0.08442115023612015, 0.011932133516717342, 0.06866718026539011, 0.020546022306887374, 0.07241983131896104, 0.04210127735390298, 0.06416205850039279, 0.04953871939271208, 0.05631231177117556, 0.03728559886616084, 0.057228123919377406, 0.07225000494790655, 0.05146231637486527, 0.08217765408898554, 0.06445846940961576, 0.04101771110248181, 0.010566136503081408, 0.02122088448114453, 0.054734231934191725, 0.052180175233872673, 0.0737275970318625, 0.06686556363298048, 0.0799027789804724, 0.01673876067563411, 0.0587010850018311, 0.025124031592220552, 0.07028319677638431, 0.03013249419088806, 0.06809828337281942, 0.08266559080971826, 0.024178102612495426, 0.02603154509298263, 0.04783355706040898, 0.02009808495190115, 0.05494229758398668, 0.04143827039027407, 0.03412402678100813, 0.014965834035988779, 0.05173405159204718, 0.048065110965962374, 0.062270104779952, 0.02232638574505766, 0.036873106484211264, 0.0673144681739711, 0.03372098026316493, 0.010300042565851923, 0.04161018818136185, 0.02815067261126974, 0.05686824262562779, 0.0027762334502767776, 0.03532428737549532, 0.04065260125864898, 0.026879736575328057, 0.04254828582728102, 0.029308926689648823, 0.03204520889407685, 0.05882635186876982, 0.034130055892972216, 0.03949646732860035, 0.04163540396538954, 0.028279245147601734, 0.07914573855457768, 0.02622047003598944, 0.037186145331830754, 0.09247819652720805, 0.03941368769794222, 0.08849766495968066, 0.018554293295188297, 0.013219816234683799, 0.04257710988543207, 0.04063308133833832, 0.04245001206835432, 0.059552373394610426, 0.04639443791201038, 0.022752037602326563, 0.020096276984399846, 0.0163303438814417, 0.03657600992629605, 0.03613186662175483, 0.03419386335618554, 0.028630691813305024, 0.010555872840115861, 0.022513089033084053, 0.024657118239349896, 0.028933771517908866, 0.03190444981408937, 0.035402244482670105, 0.05839224814647629, 0.03447784448883707, 0.009272487875404618, 0.13698894680748064, 0.008654899391976577, 0.03696138662616572, 0.033472779267016924, 0.04048837499032098, 0.0444164180437163, 0.008847546564685482, 0.05758755705169132, 0.017652753365015792, 0.010782984393318335, 0.010143626563911958, 0.04719850847557668, 0.06817618685383951, 0.00908910749374979, 0.044988325661829406, 0.05514328075092166, 0.04633830664979835, 0.017020914688586228, 0.04103171518973766, 0.02523298461681172, 0.08715324193960236, 0.04792525778494535, 0.021209339536125624, 0.009310887074999271, 0.03819117224925468, 0.06127439349168732, 0.04052140104073671, 0.02693942631594837, 0.08365239632586319, 0.03840180046315636, 0.02576068896169384, 0.01828482569826226, 0.06339475249631271, 0.08516075450085825, 0.03613248715297349, 0.0542089599184692, 0.07356635084555996, 0.008018393803673286, 0.01717887627291343, 0.04717914560329049, 0.030161107574859937, 0.021214060552959, 0.03419473669641922, 0.04344594935255666, 0.04169145478836952, 0.07107428214963406, 0.05880068026242718, 0.02434716481084545, 0.040400175287598566, 0.045199214345625335, 0.006359472538479754, 0.050081239878049785, 0.022608800227904034, 0.036069342355814674, 0.06597412074164999, 0.020603457833790494, 0.060940777522421656, 0.01739973942148349, 0.05588439420887059, 0.04819621159244449, 0.03511267473861095, 0.06161737871626693, 0.02537368049454545, 0.05456879524694336, 0.06244565382780087, 0.04383464704357809, 0.06464988413837648, 0.06885062767973832, 0.05686705518934516, 0.01222329480843919, 0.04434906359341356, 0.017453103191069057, 0.05021747329362458, 0.03745449060994772, 0.08998513957785984, 0.02385841029125356, 0.027531439911634214, 0.050190932177487886, 0.04166144712437545, 0.03370902546110653, 0.04927728422767213, 0.04373443508220296, 0.015534355545476561, 0.039319351630946325, 0.0693799714527784, 0.03323767837437411, 0.0392186034080242, 0.05382966978715793, 0.05477797555466814, 0.08768437835838526, 0.1978983147250068, 0.05188244282298031, 0.019697478424096783, 0.02377452940920428, 0.03363063934469416, 0.022702870079346245, 0.037238576389368505, 0.058914264288520625, 0.04879069582168614, 0.04515683436165414, 0.006377962070532264, 0.02198767529109553, 0.055138649749419386, 0.022894700410805886, 0.06593035413853585, 0.025339114607401916, 0.02910928609180114, 0.06613218000218754, 0.021574269349296248, 0.0450220258696185, 0.054930630064899885, 0.031671817639782544, 0.04532081165140675, 0.04159206637151299, 0.011169065894078345, 0.05957135322293448, 0.025779027191381303, 0.022657015886638435, 0.017197245146117864, 0.044482791901475964, 0.05076893785547826, 0.024528765953296137, 0.049026938185336134, 0.054449300852514086, 0.03914841443240162, 0.04171021245119553, 0.06545177135135859, 0.09499536226353339, 0.05054653103974077, 0.027622929961991408, 0.06299079816427923, 0.06958484634636872, 0.033123447003984646, 0.06727712138766243, 0.0314100798700125, 0.04125661562166868, 0.02034688924228953, 0.06635609218069623, 0.021524224655642625, 0.021604108473946972, 0.04434429469608492, 0.020788975600754062, 0.03179450279041644, 0.06991552819888439, 0.046867627440200704, 0.07470317935991673, 0.039446303891318465, 0.008979813560032317, 0.03098091741483058, 0.04704599569161092, 0.02898953505791724, 0.00900018479554884, 0.03742933228251435, 0.03355015414736925, 0.07139044663598461, 0.04532794776042143, 0.02015657384970015, 0.03427571602045529, 0.14852050060947097, 0.056719092967649626, 0.012949749173957014, 0.03084986658406354, 0.04449914787865935, 0.0029479625922132044, 0.020990809125284997, 0.04313436224155369, 0.019318829891422105, 0.043758076555546255, 0.03631780382185694, 0.022838193765510956, 0.07367443052991744, 0.026585229394596913, 0.033801423325654, 0.04382448488726251, 0.09933102921011949, 0.022039587324064587, 0.09916195360523078, 0.07005998939876595, 0.033216067034030156, 0.03572044293245962, 0.05576437887465281, 0.07332481098391357, 0.018807238290807413, 0.03993435552523982, 0.03640604565941519, 0.018048079631802057, 0.033370096672085986, 0.03996378862329068, 0.08859899540942523, 0.025763655637180614, 0.08028439801907347, 0.10663894110269125, 0.0427119528514243, 0.04664474181951054, 0.02355979113358884, 0.034448043668582555, 0.03348050526373329, 0.07740253612639443, 0.014645391906191026, 0.05434568746075515, 0.0384936390835191, 0.023266498202217684, 0.05561983340509957, 0.03268460119743982, 0.08605214376603404, 0.06254184765801316, 0.06572529538384368, 0.1186093943373811, 0.06613417183079066, 0.043639892171467506, 0.06787057905908554, 0.08173101716825078, 0.06611502729356289, 0.01689915650434071, 0.016065771586351817, 0.010306317783561687, 0.04371634008543145, 0.037893455160120805, 0.024071984113224094, 0.07824816695985296, 0.056111979778976216, 0.060366280527124484, 0.06651222089966459, 0.015652843491895305, 0.01271215849556029, 0.08040576932891723, 0.028042087308882226, 0.043376304299360326, 0.024294636077097347, 0.05643043103778074, 0.014190673715465013, 0.022413217980835228, 0.018551554530858994, 0.031110725267940474, 0.0515200755739164, 0.06685498395874616, 0.01396419226958026, 0.017651914498738704, 0.005402053676305279, 0.028275064222754973, 0.025628778197231795, 0.05622052294652789, 0.07357479313448553, 0.035792650549762675, 0.054637678042655034, 0.11751434059753535, 0.13966924330640224, 0.19574744626879695, 0.1277768620920758, 0.0896250935752065, 0.1462478241733005, 0.2002734784036875, 0.18059372150849912, 0.08504109922796489, 0.18140157654641137, 0.08473630348641066, 0.12640647635224367, 0.09493613600610726, 0.1555424472016673, 0.08191405855599912, 0.11671585481493704, 0.06024261095350789, 0.12072008148196245, 0.11034450073155666, 0.12386356240078328, 0.19015033128521136, 0.24145392190304496, 0.18692254239032347, 0.11364563488431516, 0.07721400954910825, 0.19694631258326192, 0.12862853735925692, 0.19440227248255285, 0.2448229467676532, 0.1769770357397295, 0.24004766026571875, 0.11716616895770836, 0.10676631854186136, 0.08368149234522736, 0.13734113274803086, 0.16718917466219396, 0.17603054943103946, 0.27426281703575967, 0.21329259109352866, 0.12166670568647886, 0.11056339503416132, 0.17695932378692014, 0.1346192376748208, 0.11714543861847733, 0.11587550998815607, 0.1545322530211941, 0.18327623966240114, 0.19588554127802774, 0.1644678464940479, 0.12473419068321107, 0.19378972390005667, 0.1666837098497537, 0.08675638541218736, 0.12642351414767966, 0.09628406004799951, 0.091453998259479, 0.3362386253091597, 0.15012401456554092, 0.20328296288367242, 0.0893851624982011, 0.1354700549235267, 0.12638335581868887, 0.2229455594093569, 0.1345320415472792, 0.17396747465095214, 0.11925318398542943, 0.21733349038948938, 0.14518755848609632, 0.12381212725754707, 0.13465532041605444, 0.1944019966909001, 0.16406551243797426, 0.06720854885756009, 0.10881139791660732, 0.16173490443296973, 0.21745606445737425, 0.1996019716945387, 0.12751414756020232, 0.13562963103815434, 0.12318001278946478, 0.1946447546323461, 0.16877699913757463, 0.12446481118639632, 0.19451815094197952, 0.061384817405093106, 0.10325059550063265, 0.1126765566427381, 0.1821349065510496, 0.11408191429631365, 0.18122419654842348, 0.10511076423309504, 0.11899761705388946, 0.1671937099027057, 0.09620279344099184, 0.11519435823204056, 0.16401283623230073, 0.17739732689674825, 0.1588115435574324, 0.2226821477374723, 0.17838901239297084, 0.0821101923863734, 0.15106179811541112, 0.10986116053836961, 0.17565829198687308, 0.23751554049311147, 0.1409747337381686, 0.140851316973567, 0.20927324951175721, 0.07078894504135655, 0.1409087122808541, 0.21520771897367894, 0.12046200178203084, 0.21351035924688463, 0.12151146562950266, 0.20221782487726983, 0.11620616119715477, 0.10401944900231977, 0.09122149823533912, 0.13529878830717457, 0.19807946387558215, 0.1692726733463426, 0.09446060224886864, 0.17986621377208542, 0.1135603616374635, 0.12734360872737824, 0.11045546090650944, 0.09109353090846732, 0.16590055348652025, 0.14694831964950408, 0.10231802134864754, 0.16988361314419778, 0.2248389610359746, 0.12240997185149502, 0.07933844797193043, 0.12748086870077158, 0.15094187471174425, 0.2467955618856415, 0.0808180625280065, 0.24010344678836487, 0.17938823619436833, 0.16265588001378123, 0.0908815007536642, 0.18098647946551924, 0.21265652361175708, 0.14002377347600076, 0.08915553530377728, 0.12318699185045497, 0.10966014672791767, 0.10020186433628683, 0.12418213240321606, 0.21244902103658647, 0.1385996926335558, 0.12169181804863677, 0.14327914153616275, 0.11572703448755127, 0.09931936935191193, 0.22358345018038828, 0.08469766201150995, 0.12168775012175884, 0.10133850898954178, 0.19476535219338634, 0.16122326495185976, 0.16822305628128592, 0.2255287466029967, 0.10160378225508238, 0.14711954030058078, 0.17218999744903657, 0.1558599753245231, 0.17225113126539415, 0.07309042638347996, 0.16681654949582395, 0.08726271590398205, 0.13355106596023808, 0.14763435138569725, 0.151746021884103, 0.2051389947413437], [0.02889989127945756, 0.028882073989558606, 0.01655641259745725, 0.03570698276763001, 0.030268177938377185, 0.03938228192348634, 0.059901127261259866, 0.007241535161982381, 0.020691017853096128, 0.060973144737222505, 0.05543655069965509, 0.031032329575429042, 0.1057727408084658, 0.05606548590285163, 0.04786225088361291, 0.06216633434016859, 0.0634050065831792, 0.03829894932888208, 0.01634931987932613, 0.059176929024679054, 0.025542478392561598, 0.02583356499071083, 0.04147220808531969, 0.030404497538843465, 0.011652394595946516, 0.015831164820420168, 0.006487323515748065, 0.06337403747884017, 0.00934017748917423, 0.032284278122167435, 0.034251595742159316, 0.011249342332443884, 0.03890030536680453, 0.04791710277899139, 0.049113885334302346, 0.019206402658094323, 0.04694062029762615, 0.011862200222939495, 0.04895871805567895, 0.05085499634245231, 0.012894408897526804, 0.08596953650515887, 0.03959939124122743, 0.007877672070472111, 0.024497427211533633, 0.031770631490695866, 0.021913477760409156, 0.017269378069848303, 0.02155113540920279, 0.038536942203439055, 0.019915369151520635, 0.04067318221073478, 0.028913502746652213, 0.02376035295216547, 0.046690802855957905, 0.046941240828844814, 0.016335478585754192, 0.04507495871474666, 0.08249112960672186, 0.078784987751034, 0.0630743170697843, 0.030416107601335937, 0.014886104392879193, 0.05532557520294382, 0.0670865646773769, 0.09705618474512331, 0.03146153799588642, 0.10867016960776622, 0.017502805060376565, 0.018105319806284482, 0.07206438184385339, 0.03400213836181549, 0.02208831817692807, 0.09651602381059239, 0.03974484835541056, 0.03459836161064525, 0.013074910703806147, 0.019183226583165028, 0.012223023804835977, 0.044971253392436815, 0.022990852106182326, 0.07619595530653193, 0.04335925884304508, 0.05609879923623897, 0.06672278782653232, 0.059826134914352055, 0.027226592459145094, 0.05875928470143869, 0.011539347789009974, 0.031225330106193022, 0.04669415066018701, 0.027028315497802633, 0.07091447620862915, 0.031113050344790665, 0.060230296090125084, 0.032133715031968976, 0.025397371763603824, 0.026892331060803226, 0.05373364832672862, 0.08255188037911732, 0.0714962893436032, 0.045534718721624345, 0.08591502168846708, 0.07731650445249773, 0.016015564099014286, 0.019273983104334726, 0.014113440561378676, 0.02686609254939662, 0.03945788714073358, 0.06275694216451337, 0.055710825498305985, 0.027676651877681577, 0.011619012314645995, 0.03338571337442244, 0.06189559503728825, 0.03952909118285583, 0.03460585395054471, 0.059644736785201304, 0.021133077398483312, 0.03025270296230672, 0.026989313961577513, 0.024672960937624017, 0.025072452807498556, 0.026674137728649284, 0.06665416167027528, 0.028811413869862596, 0.06051136991910397, 0.057810561416009744, 0.09238165412699023, 0.07228784969136601, 0.03369742688993293, 0.04904536259991508, 0.0564484992214749, 0.05689404063647794, 0.0817622505729237, 0.021510668729822484, 0.05826360283179149, 0.01737523801444519, 0.004679626539244407, 0.018543357390069196, 0.01900896839346857, 0.07991099144302069, 0.01849461887632647, 0.06130384574193628, 0.09186449881282546, 0.015223349703686133, 0.06790946568212203, 0.04707670049561609, 0.018881267282150446, 0.05614052804547453, 0.07074493329010664, 0.023796699993732958, 0.049813840718519305, 0.01933885926020242, 0.0238147126360526, 0.06351606634956214, 0.023680501692597906, 0.02072630194766868, 0.035348572362695015, 0.02210733630964833, 0.047293484225989356, 0.017761369310920278, 0.025571365652966405, 0.07768785791291345, 0.040018629027350296, 0.043125582873941436, 0.050070660203815474, 0.07310216285047993, 0.07289866691515332, 0.08562110439543763, 0.04741546074529329, 0.01920937507924053, 0.03584301700034449, 0.025668871408749013, 0.0422995102651898, 0.06547964163004391, 0.021317806094884876, 0.054677499292959134, 0.04863541746031373, 0.046644500501814394, 0.037536952314117265, 0.044824727585599314, 0.07502007162979535, 0.07710543956847922, 0.062183257222415945, 0.03480980570818629, 0.03368618071920449, 0.041576989761163155, 0.0752773545982857, 0.014743779620696462, 0.032721247013297775, 0.0614523250729807, 0.03885406429969496, 0.13715956990997638, 0.018639702522646517, 0.014750618870640475, 0.02290415776623113, 0.018389155382230397, 0.050983059430314656, 0.007525632165432458, 0.023345198414679018, 0.01132395163538956, 0.022573226935140068, 0.054444489820349606, 0.007163988869456996, 0.044202499482179844, 0.007197935182991768, 0.02891049010588998, 0.023278135077787504, 0.0055777645602281545, 0.05127940139162445, 0.04126422670519641, 0.02098068718858544, 0.02363825577401346, 0.060720998388264454, 0.040894539486016, 0.012216474710693283, 0.042628376489324916, 0.01986682024453917, 0.01517985697700492, 0.08507781782217565, 0.039142760703520435, 0.057085118286551974, 0.0026113902417672498, 0.05893423620070662, 0.05363195015478039, 0.03649407682279426, 0.03813873353083769, 0.026725689700293927, 0.04585436890803037, 0.04651347265368508, 0.06719094415706012, 0.011090221082521303, 0.01355751449497597, 0.03734127430605792, 0.06346230229903614, 0.07426912160289866, 0.014814174482448688, 0.045284135192031824, 0.05906208861438979, 0.031171165774726582, 0.04124737277086224, 0.021780402542302207, 0.03009958113844116, 0.028093930393938097, 0.05090923153705174, 0.01863951483110507, 0.02389642548927617, 0.07362903982040382, 0.014599785734448704, 0.02845497997177224, 0.05505775852549461, 0.02343507010429617, 0.022730416685883558, 0.031111002974813024, 0.084069155817551, 0.02308270987874318, 0.020417524464128, 0.060079120129587195, 0.01155149411304944, 0.026857039305351438, 0.031619961148188, 0.02966599261027671, 0.04598177699071746, 0.023055094324292678, 0.020345759262601217, 0.050074168886508674, 0.037178775565999175, 0.12247724203212608, 0.02313226427612526, 0.05418764352197609, 0.010842700947015997, 0.05407392160005627, 0.09884716041626469, 0.053848576837129174, 0.041533246140686736, 0.041917439234713395, 0.00965463264184373, 0.02201231076352058, 0.09757259695400154, 0.04034705858136858, 0.09446502257619174, 0.08929874011946302, 0.034773937471571474, 0.036182118159148006, 0.05219358177254758, 0.018121432550551913, 0.03240177302711433, 0.033989838820191166, 0.02326208936621345, 0.059327748754332145, 0.044969368816143086, 0.02715075358508095, 0.04846885079337705, 0.04227388462412261, 0.06426864814373755, 0.11117802737581153, 0.03984900566959574, 0.033485323956777016, 0.044911295521043004, 0.023322692666683468, 0.0070399884416181, 0.03576081193562958, 0.036160522140562534, 0.036018703944019737, 0.02623392828559924, 0.01894210423943737, 0.03212545851936504, 0.008765974480118002, 0.05174897115437254, 0.08464208999348265, 0.05244098603725434, 0.034379965265191374, 0.04604618200251172, 0.02279641707578013, 0.06600288734320672, 0.050771239949690725, 0.07138474694182796, 0.03539867068250333, 0.06944459863007069, 0.07690909889436538, 0.007703407656311268, 0.005264891857927245, 0.028873679581128305, 0.07105642464011908, 0.015385404112748803, 0.03222925385700599, 0.04189244561618374, 0.08837987894132253, 0.01687737662465342, 0.058577518850084276, 0.03377845217924445, 0.06200209658052172, 0.02206979800135859, 0.07807765877054584, 0.013076220714156667, 0.03932156179460787, 0.06877943512893493, 0.010522623666592184, 0.018878413604632504, 0.020461842650547624, 0.09058280307198725, 0.027990738350537517, 0.02372011992960207, 0.014444350325051817, 0.03490187798536593, 0.11651539258779058, 0.06686766271389301, 0.04360886561053415, 0.03601110818225049, 0.04408654441396075, 0.06619719022344198, 0.12987529949074791, 0.16670678441803302, 0.16417650325644403, 0.14353339079647295, 0.19947723725870734, 0.17398834288600953, 0.23607285903586497, 0.2184834496508683, 0.29503673134792235, 0.12610998500378864, 0.11934147561870276, 0.08649022348465459, 0.1525771047078794, 0.1739884961035944, 0.10036845015542162, 0.16584484357266657, 0.18739563232708364, 0.23676747095681008, 0.10092076890531088, 0.07942217372117505, 0.0679561740628654, 0.08399607869045389, 0.14134129148817834, 0.0843682901693448, 0.14564356466214504, 0.082431374748628, 0.10020613910690432, 0.18772875800007777, 0.12251666491670955, 0.055302113760262735, 0.23371454929151844, 0.0703049766560716, 0.10229749019227682, 0.11239617612333068, 0.2799164233428817, 0.19970125668952543, 0.23524752187152065, 0.12040612332883383, 0.15759334118375856, 0.09653951972723009, 0.07374252042462749, 0.2206651608069097, 0.10694490129789037, 0.09551804107163223, 0.11326491982946474, 0.10792989118565476, 0.15893359668552876, 0.15960032300603005, 0.10588361671374691, 0.23608085699379447, 0.11577063255132207, 0.1316820259296125, 0.1263791346742261, 0.12973047822954195, 0.18893508601092524, 0.1504773036727021, 0.13736108167757913, 0.13844874266895557, 0.18652408473914672, 0.1656310284329999, 0.13360377280942856, 0.10924981471391455, 0.11297116341489939, 0.1446963429090477, 0.1893346008634375, 0.20371681379695095, 0.09917085554691092, 0.14058356924403098, 0.14097669492325476, 0.16775549749933905, 0.19044699117300973, 0.10404653787132233, 0.11738355406710219, 0.1715432507016005, 0.18211622932745566, 0.17237952760150357, 0.1143712503835559, 0.11842264508407925, 0.11957170036170753, 0.17378859312063263, 0.11472427902082283, 0.16236836721579875, 0.1469723748103265, 0.07273260969668627, 0.1252188715302656, 0.12508371829866402, 0.10397087902792039, 0.10885397708343883, 0.1358746565998562, 0.170068102438123, 0.131541479439024, 0.12794655822818318, 0.2719727350819496, 0.1072557261514087, 0.09345296680206254, 0.11187717453726839, 0.14893800320644535, 0.13924527492734695, 0.1767575975146986, 0.14875679276883602, 0.127886067925682, 0.19665968844727164, 0.11331275435945681, 0.15751553729416864, 0.12848288872309271, 0.20184801891446116, 0.10663202332873499, 0.1307523475899812, 0.10757841004599487, 0.18794594392661126, 0.12671067454521695, 0.10632476844494382, 0.13059041192454676, 0.12170550037896442, 0.10329535801804836, 0.12642870822380628, 0.21131519558689288, 0.10853860932852953, 0.1326834867077489, 0.11694368936361806, 0.20140511284191764, 0.14083012698158143, 0.15129724757805948, 0.13198861431690956, 0.20415794254551012, 0.1156975094589495, 0.09953605732129467, 0.12950690312971994, 0.18621824711801546, 0.16506200896636133, 0.06629248390034323, 0.16679975684852372, 0.10230243145938843, 0.15827771817003528, 0.14677352902870025, 0.18424765447214728, 0.23098033552448596, 0.1703627245320428, 0.10661153813763972, 0.10075517133959841, 0.10469050371959325, 0.15889228922465157, 0.16892964981736677, 0.15164079204682382, 0.1840916330054883, 0.13860625034618762, 0.12355246175561221, 0.1759158354252577, 0.18992428938227315, 0.13340805266653338, 0.11169105347606445, 0.12274830692237425, 0.24047654692924794, 0.08695706980483187, 0.12055068412014555, 0.1285660552281526, 0.17551394570018017, 0.13442298127037866, 0.15206198718759323, 0.06842808422422217, 0.15360369316993222, 0.12822837899288825, 0.1299936141097738, 0.13692811942629277, 0.09658269644264253, 0.18146324662431595, 0.20257249294269472, 0.19199142442835918, 0.17955574897989152, 0.14669825322926044, 0.2894036255536541, 0.184354952746822, 0.1848005401271005, 0.10851070840632725, 0.0560561013257792, 0.22876945174028798], [0.01620966588116942, 0.010234171453292572, 0.03402053596331708, 0.03864065135618852, 0.07194052074825572, 0.05746696332109071, 0.056398067653419516, 0.03665746422484517, 0.03742138412029993, 0.014666509119823817, 0.05158220913501517, 0.027327032331677697, 0.02865242955815648, 0.014546694883686161, 0.023706087114049063, 0.01588078050483619, 0.015927806812068148, 0.033595721057105454, 0.037004781676636594, 0.004592576926018322, 0.015373795007866238, 0.012493108102541058, 0.02991758546070947, 0.04241514357648069, 0.06375243511771964, 0.023081694812243505, 0.022418335448169423, 0.05049539084035543, 0.06993029837406452, 0.08412517216657439, 0.027588934810351462, 0.054583561591683864, 0.059042028602092504, 0.04333255684844429, 0.010813715052790942, 0.024497672359669403, 0.05926553092356171, 0.010492134324815727, 0.04660064196814934, 0.02603427619643269, 0.013185681271997672, 0.029656663574578784, 0.02590193450751324, 0.007007958784308886, 0.049361753082203294, 0.06367810926730595, 0.03042909087643268, 0.015459925315583186, 0.002425988106199751, 0.031314328455576496, 0.038559786945341096, 0.06828147031727337, 0.03370031504140746, 0.04119470039562833, 0.08762637018075875, 0.04577708212778934, 0.034453502045043057, 0.03005409849837663, 0.04993170334566986, 0.05851276909872409, 0.04976622835402528, 0.004687306570685319, 0.061859539109131986, 0.05940086035538585, 0.026005256785860947, 0.054847678064458796, 0.027315780415289828, 0.03511372810950683, 0.03750779883815877, 0.043807856948866, 0.018252065863400217, 0.047572179351963347, 0.005780257399178921, 0.016053826360392476, 0.05046526826317272, 0.050940610498430274, 0.06945405981593555, 0.0571155128249478, 0.06439333661429344, 0.05887690601089309, 0.018331729431426334, 0.050679830338565574, 0.008794200989688116, 0.019572908697169156, 0.0556677139003671, 0.029190119859131596, 0.010735687082483163, 0.04531904198830167, 0.024082998542355436, 0.033765286958265694, 0.028575905035400105, 0.04080674964033308, 0.10446701288944292, 0.036655181282830816, 0.07025861301489415, 0.058746065854305224, 0.03956887795920334, 0.018239184094953443, 0.017195306943669435, 0.04826853412293619, 0.04951114022743799, 0.04298803178713687, 0.044517618258513754, 0.00938188331577206, 0.05556819907900307, 0.03734405903566269, 0.07163737975661794, 0.037383217619912285, 0.06717436601437869, 0.036680500488728285, 0.05018580704927445, 0.04061307112175611, 0.07344053622575537, 0.03737295587216655, 0.02533584532718505, 0.052412024083276915, 0.014480722264476843, 0.0377328256745973, 0.03236860525043261, 0.02832416471304192, 0.1206304798383386, 0.032898807041947885, 0.02194003419830434, 0.01029330194972816, 0.04562559973208174, 0.09828020938702169, 0.03490752022292826, 0.04704249083935734, 0.029503373211369883, 0.07311732373050145, 0.03639670704761821, 0.10758289932123116, 0.005533303689932632, 0.050210517215272116, 0.08775410768125327, 0.05219800976074992, 0.04111664369702339, 0.07770513319560597, 0.012073473865917374, 0.04820623968337332, 0.039091095733906955, 0.021319219527105172, 0.057914791508547725, 0.029591634201126236, 0.050121884672872485, 0.05610234622332839, 0.06488675086368477, 0.03331930121226657, 0.038015278461839885, 0.03503049648697338, 0.018016223780690663, 0.015969486783198532, 0.028901785431850343, 0.028263904236918016, 0.035308789416787126, 0.018408129464895017, 0.04957713487167513, 0.04946202633061236, 0.06187209529021095, 0.0282173145998029, 0.023422791630089767, 0.02652395385197334, 0.04030430704475411, 0.020981459022169153, 0.011129757922683513, 0.025716558466815663, 0.0014426153821630345, 0.04846131248820213, 0.029703952266924807, 0.0285487721163419, 0.031615632751415816, 0.00792406683397149, 0.03180188787800651, 0.037270265616356366, 0.03384376883566861, 0.03499900644284583, 0.019489115915231166, 0.054346239044060635, 0.02441195861226128, 0.09441035454191508, 0.057350966118035786, 0.04635595348513415, 0.046791505113604574, 0.06919977991210838, 0.08467810378680307, 0.04288607697573401, 0.044621335072142464, 0.07443176206922339, 0.025948642888256622, 0.020357986025872733, 0.047216247241463394, 0.04900643767248239, 0.041280333703804406, 0.025896458894074447, 0.07828600404243316, 0.025083924974164656, 0.03684586439762385, 0.028849969159871824, 0.013730347761133266, 0.011248852036172345, 0.027873551795980143, 0.022979399091714335, 0.01747042252381723, 0.035986608690432006, 0.02110807803429423, 0.019172738839481628, 0.02515865876639803, 0.04328268452457363, 0.05258981010786468, 0.047635350962199514, 0.025133002481813875, 0.011517774753062236, 0.0179769636897911, 0.04698417239612149, 0.06731769340413232, 0.02689387472797065, 0.02271993851829921, 0.0787941501626084, 0.048933555897805965, 0.03671896959384603, 0.02975219856917618, 0.08363755720276987, 0.03113145177673188, 0.021358125302339756, 0.037173830468447945, 0.02339357686709733, 0.019676688713051622, 0.03289954248635519, 0.018901451783735427, 0.005960292370629407, 0.018157904081407095, 0.058871455295311834, 0.02520990430287296, 0.05268447559266802, 0.049276786270521344, 0.03933424821063396, 0.08487446744355463, 0.025892170716918288, 0.01781010590944319, 0.03660538173731297, 0.03635814218150993, 0.01746605773786864, 0.0635038166036529, 0.02892855062870489, 0.11748269350538332, 0.036166853857256716, 0.054839829493674545, 0.024469321360811595, 0.05129995553063289, 0.019830480863850926, 0.026797657915120645, 0.025606324160171133, 0.0655393811663793, 0.03796329556573783, 0.02739524288523582, 0.06332753211139672, 0.02391017293707738, 0.025412050008233038, 0.03290949013805197, 0.05451381694705737, 0.09744370266074136, 0.050542060916702596, 0.01972377630731752, 0.03428457965773921, 0.04273293216923072, 0.02337765564481097, 0.0735033784181841, 0.040714298149630915, 0.09406321712078587, 0.028080828375213092, 0.049387597058328896, 0.059959426552297614, 0.10762984518923106, 0.03375404078753726, 0.027344918569489837, 0.10621984504283437, 0.03191892313019883, 0.0835354223607048, 0.05802264519696755, 0.026152278634629426, 0.060118102513614206, 0.006979947736967476, 0.027959594961195707, 0.048330897510412245, 0.04654559088991054, 0.09734589621544847, 0.08905794336310319, 0.0106907895420708, 0.01353252279166613, 0.0583394531971745, 0.03684374616451321, 0.027781952578093738, 0.031043240582690607, 0.01747804509866382, 0.015723786106513395, 0.06899524209720474, 0.012697878616651701, 0.054157371557648146, 0.018162634674339526, 0.02078592848603524, 0.023751713395599398, 0.028713544222315954, 0.01825441966854757, 0.033464490195676204, 0.062415921955459544, 0.06460555063019838, 0.04371578467168635, 0.06835373539117075, 0.02297271497457499, 0.057846636496364116, 0.010436688711295926, 0.029641234563783776, 0.030569415201523134, 0.031317197454852924, 0.01750303297153404, 0.053370583937653614, 0.02370659656251871, 0.049849168863147504, 0.03267771789744016, 0.013078043045806549, 0.04140087763868994, 0.021713429220741796, 0.06672601305669354, 0.03622864267878956, 0.05432890247433417, 0.05580547566135084, 0.035787410508360595, 0.05854488733494955, 0.03243232078309501, 0.08119308554957952, 0.05751418881118298, 0.0888015337348465, 0.035463435755622004, 0.03431399743403158, 0.06043052466045465, 0.05373518816345642, 0.029549547245786078, 0.02261285857868291, 0.043015105334380944, 0.0528278106433009, 0.052707619108860536, 0.06703964179201473, 0.04875406915802629, 0.0901865134496362, 0.05035134332795298, 0.012329991704093353, 0.01970395186705695, 0.037068075860940644, 0.020556182547983144, 0.036877434880983447, 0.10031272491980946, 0.06576314012730314, 0.11372946022498993, 0.12098212185646258, 0.08412063692606266, 0.20405698747884846, 0.18591201113116357, 0.08465388774751656, 0.19937332509265793, 0.12838696685409354, 0.16993270405838568, 0.1625047155445622, 0.12458976778772571, 0.31657802061207835, 0.11869323499981435, 0.08072463044476125, 0.2290198552392183, 0.12688310561521401, 0.16827603892212914, 0.09461340614624562, 0.1797054425602959, 0.09302252498004707, 0.12457882805216698, 0.1381121542785437, 0.09422142959890828, 0.23020353769102406, 0.12872365483593556, 0.10916643370423587, 0.07157572500047184, 0.07980249041030485, 0.1226778727986159, 0.20967362238274467, 0.12429712986152981, 0.13446554511545167, 0.2324493857280862, 0.08939549702429965, 0.17903145372627244, 0.09671431034803392, 0.1128329611533592, 0.12319575589630874, 0.222261902545729, 0.09583903957278499, 0.06394282711910144, 0.1290639051266255, 0.14182864598208858, 0.147309897828006, 0.13251785849851946, 0.18778750162211158, 0.13033973263396373, 0.21905455287666092, 0.11724978745464357, 0.12041963711981812, 0.09888920332154921, 0.14613767605154745, 0.11790323747141708, 0.16050085936102176, 0.1722841036896552, 0.12484486740563186, 0.1339552999143639, 0.13792441677181952, 0.1100375522829352, 0.1411454947364907, 0.15496832558945303, 0.16022715146743483, 0.1837940691339393, 0.08259784565457413, 0.10920695209455107, 0.08707674039948372, 0.21313068607161123, 0.09053613299564009, 0.21848666722015028, 0.1987419767124999, 0.12762808781718055, 0.12430720391773409, 0.16917444555269134, 0.08363604800955904, 0.13502626018899103, 0.14632979558119852, 0.17992431388026286, 0.14624770159923262, 0.16229246322426105, 0.15781163027690304, 0.12115785476541328, 0.19158453981001533, 0.23737415130580627, 0.15091454069460594, 0.2819828076228019, 0.16346909766716344, 0.17578396104997204, 0.16287636011838913, 0.16374334182229736, 0.11300816546164213, 0.17305275034760276, 0.12992722493025566, 0.2749378937146356, 0.1261095100292756, 0.24227697612537494, 0.12036101607185219, 0.16946159062847016, 0.15444979131702455, 0.09801490547796411, 0.15554125210450542, 0.2005703374743462, 0.15282102710297032, 0.09743120776669634, 0.13682123483909717, 0.1839189567873555, 0.09880881771565446, 0.09347466241207816, 0.15461272289676053, 0.1370114697924545, 0.20052955095325747, 0.12315748214361169, 0.1362631857515343, 0.14693803874956024, 0.14641070978776102, 0.20928138536551308, 0.2605540413529642, 0.23523157192093713, 0.11936745366021512, 0.20172725281407758, 0.10796343051497975, 0.2406702599217815, 0.13655552490343972, 0.16252219767099427, 0.1258823266553302, 0.19804943322895036, 0.1665628671405777, 0.14687903465763216, 0.08455986577656963, 0.12348831721371221, 0.20496199778731794, 0.15629937271437339, 0.16917819938352033, 0.14662788039253605, 0.1337008514711934, 0.18897812483051132, 0.10527757987860711, 0.13190480429799328, 0.11633890125179484, 0.0923549636237083, 0.22534804178341744, 0.10116345789884368, 0.09007799709516187, 0.16093365307296478, 0.09805763020150124, 0.09896164459566917, 0.12586338130096275, 0.2014094029342936, 0.1010391294896122, 0.16922640163571606, 0.23294069323568578, 0.1194777703213115, 0.19106003005177746, 0.1292264843059163, 0.138241209450268, 0.2117954867501413, 0.18301944699018233, 0.14623054122972876, 0.1841680885803315, 0.2534838771868137, 0.16561684048464223, 0.10500047055463638, 0.10338138969194505, 0.1339096257523183, 0.15573547071506902, 0.11818655976845373, 0.1279585704868359, 0.11283267003994797, 0.1248104930404694, 0.1410092383382782, 0.12958004920473024, 0.1329436042015591, 0.09508468045462524, 0.121013087130362, 0.08399131362356486, 0.10777116542862308, 0.16680922569526782], [0.016206791136233557, 0.02590526890520367, 0.024324927193623398, 0.05231866094794485, 0.021785265285401575, 0.040972645980336016, 0.05550652517065887, 0.1586931676513726, 0.05342804436241427, 0.10410463031862052, 0.040019418097912304, 0.04828141206094334, 0.03478016193595625, 0.00724121819310371, 0.07702889972396436, 0.07033789545417794, 0.040759593098153996, 0.030799808483871243, 0.05632430104719055, 0.07592653750532097, 0.027929052950874455, 0.02931102002490192, 0.033621453950482036, 0.011239399468796629, 0.06031597536357661, 0.03081995468106001, 0.013804082766235357, 0.07376275280670774, 0.051995513570164485, 0.017246079420851126, 0.02310333488088462, 0.06334635872213591, 0.03138591937210051, 0.04316510534995506, 0.04753940228012301, 0.04785275905423107, 0.02731974108985836, 0.039685338645452456, 0.05040809895182329, 0.03205967071886746, 0.052276273303094416, 0.025234032242048173, 0.008768691219419481, 0.03245863590329405, 0.02428439731198934, 0.039654993902771704, 0.044784695661116036, 0.03671637638622234, 0.051169211135035565, 0.03778657440336482, 0.0743564862697836, 0.020157179059160334, 0.013163368003593098, 0.03299980807388502, 0.05058911786745152, 0.045343242705829685, 0.08667627559794534, 0.005429720462885716, 0.03232594181392943, 0.03336363472044468, 0.05070947411079561, 0.029521265194841453, 0.05757366021674487, 0.032504455622045264, 0.040544387508904746, 0.03631116566999305, 0.05090979461167609, 0.008316068279166377, 0.12175066126210075, 0.03944578295152995, 0.04887693816976202, 0.07279227262422924, 0.04673018360570554, 0.046616404227191405, 0.019570533824603886, 0.02782062852695104, 0.026192297152574026, 0.04139358831209041, 0.019473648600039944, 0.0784749519680777, 0.02550689169325896, 0.0383688586824123, 0.08892730238937563, 0.05326241998362446, 0.03145976641756152, 0.050837621468329625, 0.028360622837358428, 0.04354830252968016, 0.04111889216508116, 0.02513031351319965, 0.03313915563687202, 0.029564399775418065, 0.042436249298794616, 0.012570915822570604, 0.10129417548136366, 0.029153899222071615, 0.06510068091654009, 0.043195212605379285, 0.016962040831605275, 0.052053257447457126, 0.07139853652446501, 0.03929008324179919, 0.040726919448183435, 0.026559661210124052, 0.024504375629006855, 0.04476566603707691, 0.05577932525005552, 0.031268949237381743, 0.07059069680831126, 0.02841576967658776, 0.006837075690723836, 0.016403139471226645, 0.098753146106197, 0.06465821917499266, 0.04072688497422684, 0.07039236430559428, 0.040445029735565186, 0.018839553794673374, 0.03296123171645788, 0.06100311792725998, 0.0456293688846692, 0.025390436752669276, 0.047021078681873704, 0.05974218316916978, 0.014793579166214314, 0.04409721601874598, 0.044686778133074125, 0.07005010686454273, 0.018116353387613932, 0.0440351514055604, 0.038282616334336425, 0.009084604811974832, 0.03153059507660087, 0.04213474007443555, 0.050037507748892235, 0.004347156829035451, 0.017750349136129502, 0.032252895330349286, 0.03697828652577535, 0.05788050141305693, 0.11354452660006863, 0.008119442237300739, 0.014418091703837198, 0.05970718827278865, 0.021554816461678956, 0.01014245636460762, 0.031147221696653196, 0.031526090479606104, 0.05236530804165429, 0.05106360974511312, 0.0464403840352691, 0.04042212753706882, 0.06858029057301822, 0.012605526717379691, 0.03721536009482319, 0.029483939475950696, 0.08216056266739484, 0.017053255090309728, 0.03849246313855533, 0.01218730878580602, 0.045459569326692054, 0.058222529027731194, 0.02279040137035472, 0.10032242359293085, 0.008366006678120505, 0.055353460803387634, 0.030267768081337697, 0.03573395672344393, 0.03908767132088542, 0.09030145728179524, 0.020942681566661885, 0.05942523344269684, 0.030839924678026192, 0.01484640763186279, 0.04710553221464638, 0.009979917404932842, 0.04894497826875699, 0.04928741957091036, 0.032161998998133406, 0.026607059069999286, 0.010846902939280676, 0.049694970685748324, 0.07755986760340391, 0.11958573509248034, 0.03267412494507528, 0.1153332652944711, 0.06104280511217733, 0.015152367827061926, 0.04290624424034069, 0.05126678392351155, 0.08633261621599236, 0.03943366344056783, 0.045747093615993384, 0.06077342944580221, 0.033121110435815594, 0.05935771045305076, 0.038343351784973376, 0.053506564544213396, 0.028324865683492635, 0.018992867140520005, 0.013774695633459958, 0.04418656868379443, 0.04632552064234211, 0.03519323271428866, 0.05498963798726759, 0.025289230792212392, 0.014661543912464573, 0.02499112682867675, 0.0820134048380198, 0.02687584484867271, 0.013107226207672108, 0.08292271289974451, 0.04590921314252962, 0.02539304719727126, 0.05740163134290807, 0.11886603379201506, 0.020188454598669085, 0.027352144693835612, 0.018872959058611624, 0.03966936954267083, 0.022021825575540145, 0.05452229370993953, 0.08793888042771048, 0.08732879864833049, 0.04089616359241548, 0.014305232588442103, 0.047027942829675255, 0.00853046564565551, 0.01227760756944096, 0.06377849359846403, 0.047363397409959186, 0.004759732523046795, 0.011929319101205517, 0.011485559798236336, 0.05223563616915096, 0.07535271466739717, 0.05520014362710138, 0.03396463069704271, 0.07562569477745602, 0.05329710078395663, 0.041074799974599195, 0.08585290727956642, 0.03164618242261631, 0.04513548732164406, 0.08634643644214639, 0.03312528944544254, 0.04446538255339669, 0.04854891081190398, 0.03198877311191492, 0.004323567545431997, 0.08703878840371486, 0.024653619132755746, 0.05501665024747772, 0.08663866068086318, 0.027346946787269368, 0.05366954208922483, 0.030355312778884848, 0.05060075857346097, 0.03399649612425316, 0.017831112040326964, 0.03931411925042349, 0.07657009732699202, 0.042257873386505156, 0.0495521642357832, 0.03663805538728353, 0.011886001617136982, 0.05220869668729363, 0.03053102653563744, 0.07473730091606418, 0.012492414792969584, 0.011498082462968606, 0.030798722554238576, 0.039897579474434744, 0.13426191894517792, 0.052453442626903136, 0.056163625596391584, 0.03938011772510025, 0.004762295087153513, 0.02809134293197384, 0.006886940353715252, 0.014452073448938469, 0.07499186427242334, 0.08545686280535114, 0.03236405085772276, 0.006890783721070376, 0.012419485137797894, 0.027576884247302532, 0.05109632552991952, 0.02561013544759443, 0.055768952419560765, 0.008026198803206847, 0.038333829312074574, 0.03147038631141186, 0.0567691644743806, 0.02396608394901118, 0.005646998798775097, 0.042258440291569124, 0.02832564134751597, 0.012216526421628172, 0.04837849455314779, 0.03497855955614679, 0.07179091909840223, 0.0182691726067494, 0.04712423625131769, 0.024664104961219336, 0.030619703128092715, 0.03415804874572543, 0.015876141842454672, 0.08255792481283988, 0.01995193069770692, 0.054670401488340674, 0.04080874529937583, 0.018968172296280825, 0.033943597753081596, 0.044706976041197784, 0.027654659408595295, 0.05573037606213362, 0.042708310103344346, 0.03094259769685807, 0.028016823644359267, 0.006541447627598481, 0.012404621116847042, 0.08898475132281743, 0.02107082126331666, 0.025784924153178453, 0.06639155439071118, 0.0428889038401746, 0.04239718647553556, 0.03579209130557795, 0.035776474603241494, 0.005735518822010848, 0.07788045241707757, 0.05109690775674197, 0.008664297375587687, 0.05314869806170464, 0.020219067472123334, 0.03829428385342321, 0.018884423564398484, 0.0488490334171201, 0.10282733958334693, 0.013696629358755966, 0.022377024156852596, 0.016282631925517516, 0.02237526023940694, 0.04117633343764371, 0.03971487133493347, 0.005077839999895303, 0.02295901540726904, 0.042654151517537334, 0.018663058628238017, 0.017596593374506603, 0.0013399549319611623, 0.20532366789637074, 0.13130590740230777, 0.06977374064585856, 0.10533713555384068, 0.14494683833852892, 0.16638084464976866, 0.17194146320464151, 0.29371225725739236, 0.10672955398237514, 0.11279182989270457, 0.23165407921037368, 0.13560163818540114, 0.1476257712009453, 0.10617524340388276, 0.1812017042069666, 0.13630164336533318, 0.16183913835594732, 0.14935044962311947, 0.13225482987059703, 0.14724537790302308, 0.10306144073124855, 0.10087589913558576, 0.22863901761029998, 0.13447302213359263, 0.19362058700813403, 0.08970758592289302, 0.17529208663730853, 0.1433304234618141, 0.12009768866963925, 0.2493028297659851, 0.09908489282092742, 0.16368925601484316, 0.15056531185344343, 0.21905154981199773, 0.13529488125876074, 0.1933542335586202, 0.09880449697976151, 0.1656875810435703, 0.17931804721874578, 0.28858832414111785, 0.24156869719586066, 0.09327308935744148, 0.1633522079716767, 0.11981800529024295, 0.1269014304383628, 0.16542135016812434, 0.2014887236779736, 0.15344370336782548, 0.12422546999709261, 0.11565345940330338, 0.23202935504096173, 0.09123465196499903, 0.12171182826521898, 0.13913508084031845, 0.20118415776279666, 0.08674326232604443, 0.1127676368360558, 0.11797970836801876, 0.12338151689618827, 0.0958107479457413, 0.23465254734600746, 0.18920646499722235, 0.18217020788260047, 0.10309830488216493, 0.15962304517386422, 0.15362333566431077, 0.2406591976121549, 0.16123383696521484, 0.26902731087419296, 0.1359102337230598, 0.15010685419603703, 0.19064511683198715, 0.07675757436382194, 0.11569284398349063, 0.15026494410009156, 0.12450196645072392, 0.1733486135039599, 0.16184180434192383, 0.11972262734367002, 0.22457322045680017, 0.0829711219956798, 0.08933385758991204, 0.17909217385515092, 0.11782620733063068, 0.11355296122811495, 0.2532317116856575, 0.1357542275781593, 0.17872894092673258, 0.10056029389341993, 0.10463673966906725, 0.12722091974630473, 0.11147420462821761, 0.15474476581138952, 0.17291171356074272, 0.2528482233925212, 0.15538196710328903, 0.16099328535699076, 0.2753145025382119, 0.21333251959614216, 0.199488774542847, 0.13498130614959425, 0.21812516565044082, 0.11303724615924782, 0.1209540447340377, 0.24962847842083824, 0.17048629451422923, 0.3035621561350361, 0.17638123383925808, 0.2021589740029266, 0.08501885203464378, 0.15081228327847299, 0.13974157732821282, 0.1992988460246594, 0.11789062766418343, 0.10340358325911146, 0.12412104455213394, 0.12765287076153103, 0.13592509582879084, 0.08496582342852509, 0.1565908691695621, 0.0933383983529864, 0.11321878601466456, 0.1145410231284557, 0.1262901688835794, 0.11692190182305152, 0.1456095350365485, 0.14086610247050563, 0.19758532184266275, 0.11084537667733048, 0.17914115751702941, 0.0774890810792004, 0.14330339587984547, 0.12252536001465014, 0.10499791182096928, 0.1734250690788031, 0.12913032494966062, 0.07762437220662832, 0.13877521869876694, 0.18338896183957978, 0.10465708696433615, 0.18653321650720414, 0.1528876920741412, 0.11067071629147376, 0.1402824813680303, 0.09464761197206475, 0.24094073492432797, 0.11558785163346799, 0.09330159548910395, 0.11640362802051729, 0.27851564689509334, 0.17754447706524404, 0.13335312416236247, 0.13631272099671826, 0.10200374143859071, 0.2862428999956577, 0.12985928825313045, 0.15944748846513612, 0.12823063129138562, 0.13804043312707256, 0.051866676733498616, 0.10375566194735228, 0.17093693807480798, 0.16275340300654212, 0.19998984201060188, 0.10708036862554089, 0.14910314111940323, 0.14650824810228041, 0.11855111802898108, 0.11235371953056705, 0.18569568322310526, 0.19430280362646427, 0.1100733822151538, 0.09334322470690935, 0.06716536448126839, 0.09061102575111775, 0.10471212272081645], [0.08047822592479568, 0.024700237498168024, 0.03597174658470097, 0.01545809340783425, 0.03368677060690618, 0.04993113261016627, 0.032076342707319606, 0.03873783343982312, 0.027283047393505132, 0.06570472592307676, 0.0491150766010246, 0.03141219618790333, 0.03527444569514163, 0.06631093895843913, 0.040986569628359816, 0.04472044386690663, 0.06226210682202251, 0.03917985468081409, 0.057002805969527656, 0.048576696820917635, 0.016732528550370086, 0.015019136518540402, 0.06804376089524838, 0.05178056462036987, 0.045452716670209364, 0.007272709673646117, 0.007503334218786369, 0.03799918295455076, 0.023568202778997443, 0.077193524358013, 0.043944481069282185, 0.023565755128079367, 0.03248031236111157, 0.017066707594260093, 0.021444511291901433, 0.10673392068354354, 0.03995463387259553, 0.04813978538638161, 0.031747915068521135, 0.029846172659627856, 0.049207462974253206, 0.027448194882562085, 0.09400435092468416, 0.011150381009605144, 0.04789027437988309, 0.02309863876190878, 0.041904128457029025, 0.040729911021527745, 0.04867217818936033, 0.03666903215250181, 0.017126512248069048, 0.01993310791740735, 0.07508811555922994, 0.06308932090178132, 0.05149736106696148, 0.05266881292505611, 0.037631947216728044, 0.05423804827695412, 0.0497732303976532, 0.027246524151715062, 0.0414107869859905, 0.0755527402244268, 0.02157205343997527, 0.0604489682272317, 0.06356782708016616, 0.028056821094885952, 0.05923048240102588, 0.06665338792147175, 0.037253890486974875, 0.011765800506597566, 0.0277250858714744, 0.04483665557458036, 0.009583044598149437, 0.012863178365683604, 0.01916222619794069, 0.03352412631014182, 0.016952342158483884, 0.041554478267508174, 0.03455456819445376, 0.04464184707631508, 0.041221731808036566, 0.05659981307783916, 0.018441754979111494, 0.06583758855178472, 0.03939799055637371, 0.08458841787350756, 0.06096948283694445, 0.02473420583673062, 0.06406745813306301, 0.057464350961268916, 0.04654695835685538, 0.0469177219295694, 0.018109002773980462, 0.03247008508732242, 0.01712195210969977, 0.05149675968794092, 0.03739149519993413, 0.1496549236077455, 0.031512569027742555, 0.05485854502166471, 0.10163801106353922, 0.03333126367520421, 0.026543856816246148, 0.028283868488224766, 0.012148883730743923, 0.023616910649223194, 0.03324749579112376, 0.0685510260143107, 0.043683206782706326, 0.020076284004795938, 0.011322994983094114, 0.05114229846625559, 0.06508997100735865, 0.06062912912438474, 0.04267536066172104, 0.10144541655937511, 0.02443693882425226, 0.0189447759710733, 0.06623179441498173, 0.021819181913029284, 0.025876105853146123, 0.048236779778474764, 0.05839926934230232, 0.06733787982093711, 0.03340276266117731, 0.04944104318236632, 0.03381046316316051, 0.024282326959373973, 0.03907009343346281, 0.047299206902783726, 0.03215685088728224, 0.039748556220964085, 0.07037325807276272, 0.0391714085614489, 0.03162649970862173, 0.04566991791850136, 0.04964001919893969, 0.015254740156383525, 0.0154977805927516, 0.027779206152885195, 0.025043873897483273, 0.032801992680516937, 0.05531975293471929, 0.0259771490199191, 0.011330592660083166, 0.08049624431277476, 0.05242045488088362, 0.04257014997663998, 0.027681393961932872, 0.029991187358034715, 0.02397157296898865, 0.013976407541532912, 0.04392863454056844, 0.06843536205950283, 0.04707836290641178, 0.010379943621134567, 0.023651438231970516, 0.023180516324036067, 0.05469504653686478, 0.017760649188271454, 0.02249117891844963, 0.017814353866983327, 0.06491889591298758, 0.024557712585515073, 0.014043490030622531, 0.0983193871234694, 0.0488430732530692, 0.00844842816267403, 0.02530785438965165, 0.009515270714708155, 0.03744224086403847, 0.042763483755651026, 0.04022474881381758, 0.028077419283950043, 0.021860286360606555, 0.025113913485960617, 0.05510675367869197, 0.019676240551615917, 0.003794516801022955, 0.035476792498581836, 0.029089249062141585, 0.029646399911613237, 0.06273172255004607, 0.06995010174690716, 0.06604823208744488, 0.025907772097496257, 0.05082404639031138, 0.008988085394394735, 0.01064578666456885, 0.020899721271088047, 0.05370013964092059, 0.12422139440933544, 0.06250216813397504, 0.0356890294971245, 0.017104621285632733, 0.0435413847557239, 0.03239175259706474, 0.05897405362057109, 0.023049373562718113, 0.027115862110569596, 0.0387001189313108, 0.09147419233716304, 0.02161024675344027, 0.19917239555187766, 0.0402689942218844, 0.04081526853805108, 0.022739500573445714, 0.023365268003075354, 0.04429872778634872, 0.050406298645201235, 0.010789122672811633, 0.04726848677702008, 0.09189350290163871, 0.01195822742902824, 0.06646327554218232, 0.040760271085966984, 0.0382851712375639, 0.022928770256018447, 0.043032721526199774, 0.053075295347239704, 0.023469881139575474, 0.026352110754458175, 0.049428870045249505, 0.03368917229254881, 0.05233960579179468, 0.06759730017473621, 0.025972851266663884, 0.005373247333937475, 0.027920940079756325, 0.03097856935534266, 0.040492167125546166, 0.03154921484360051, 0.04246725670752987, 0.01752874096705308, 0.037921034325394905, 0.0570703940766473, 0.07199737979399581, 0.09842998723709777, 0.023116664810767098, 0.03631056046053287, 0.01760213410541896, 0.026585531999327006, 0.015261756564160029, 0.008395949224641007, 0.013786448379828325, 0.012133245003379643, 0.030444178978101383, 0.06576914625662951, 0.0269752983830028, 0.048091077516155864, 0.022383001557881796, 0.002661406685928664, 0.05625313913990414, 0.035873610721600634, 0.0806551615917875, 0.023625048418198864, 0.023495533593720006, 0.02403108076372695, 0.03422839093893286, 0.019502656519292824, 0.05769384409030599, 0.04203632841968248, 0.05705982206329223, 0.0577245029290357, 0.0463585390318786, 0.0041837316013932715, 0.008161609631872947, 0.057824707229531584, 0.04930519281075366, 0.01733180082913849, 0.015618735342286529, 0.02341414632786426, 0.0283712312398899, 0.025024158624751915, 0.05957598805487637, 0.030576846254388654, 0.05326133979965122, 0.03620805406582452, 0.0465431317476736, 0.03251283279349727, 0.07011730043638138, 0.06911973904577956, 0.06915826560749162, 0.07812011536330947, 0.02349158058003072, 0.05564080889246637, 0.020248362674347816, 0.0246627030203179, 0.058730575556476275, 0.021026233030903726, 0.006964113657182504, 0.06917894232056795, 0.04369167971514887, 0.03432524360476002, 0.05026404760898121, 0.03327484129958096, 0.07576447926581868, 0.04051165640233986, 0.05581381069796701, 0.08658244514897948, 0.030506048238866275, 0.06835470066195534, 0.01837299092702808, 0.018134770141313636, 0.008027372832950807, 0.0009840386220246495, 0.030922646852089997, 0.0247065155887075, 0.07496014057147889, 0.016880345215360006, 0.032316890485104055, 0.052690431926279306, 0.023852229876924428, 0.027359970281982136, 0.031228013329147816, 0.04489847503963017, 0.028511959676360412, 0.09090086745639002, 0.018407711946976282, 0.03658812177637893, 0.037364187995873155, 0.02640494400815618, 0.036048995060545784, 0.06977624575337095, 0.04112346954042873, 0.04140514474842818, 0.07770315668876134, 0.05330948459525263, 0.03303501747488495, 0.11223434771020567, 0.023918015762202205, 0.030601895414292816, 0.03677726888488378, 0.013995969596679413, 0.036737662139198476, 0.017082111707197565, 0.07012353639208502, 0.01723412844923235, 0.044205498716403405, 0.04087693095507641, 0.07719877206029431, 0.025506177316269567, 0.04428436746820808, 0.009289217320451093, 0.014528091396054914, 0.055920814028790886, 0.01848793284396731, 0.05297970672648761, 0.028427019677755815, 0.023513877569066904, 0.0214677180103477, 0.022081025019888918, 0.16634827059122825, 0.16964293896190583, 0.0740456460945068, 0.12431274273342664, 0.13170594319460854, 0.17740127991043753, 0.24598165475312742, 0.22680953836008427, 0.13254188301582492, 0.14829263541727297, 0.24142329370783222, 0.11509593891640825, 0.16327677895465206, 0.22498905298209962, 0.1720028268473764, 0.169990896097114, 0.12236863374710084, 0.18815307877957824, 0.08592849717505517, 0.13693455456485673, 0.12718541923189355, 0.10997592050942684, 0.19605662403327806, 0.11502282348491492, 0.10324283502995969, 0.21472586499106502, 0.14944305433140648, 0.29192236943110345, 0.1256348266296329, 0.18355348688219825, 0.1142347105328114, 0.12036789554141222, 0.11998886587999522, 0.13539349209637414, 0.1843576187327985, 0.1961102348662192, 0.1700266877249364, 0.10460530708153402, 0.14936880508978523, 0.11307947292563417, 0.1304228991390236, 0.1332257543840716, 0.14693342690025607, 0.13270109140824887, 0.0846409715051132, 0.10378917829403955, 0.18290336934789536, 0.09572208859026433, 0.16753604395254967, 0.10647096866441351, 0.164961222439043, 0.11056322649481798, 0.12516367489532118, 0.0740209857242242, 0.19350810997909118, 0.13987970298096059, 0.11951628922214431, 0.17412862890670378, 0.10472551393773287, 0.11770976196614005, 0.13199054485847875, 0.18434775152033378, 0.18523915610726804, 0.12502009469655254, 0.15572541964150247, 0.14861080705398513, 0.14939443839173164, 0.214326610608447, 0.11734564803660878, 0.10919854044914247, 0.1697052525536668, 0.10477884131814204, 0.10669740893307234, 0.10105695635561021, 0.1347562754827161, 0.11115067037603549, 0.09215922815905464, 0.2203061260403164, 0.13627665357724314, 0.11283689884529, 0.09965985712985839, 0.20727290201090998, 0.1341351313937095, 0.1822237421067492, 0.12356102661860567, 0.2006958226763433, 0.12566307995228038, 0.1363363318265446, 0.15036969896285765, 0.1250943975643285, 0.13644381396232114, 0.10774242947058332, 0.08051940315072575, 0.07766803155743307, 0.11029865036928847, 0.12399059510038746, 0.18845228207928522, 0.21839251501425622, 0.09392467778055899, 0.18771564257481407, 0.18125836406984638, 0.1348780681409182, 0.09599808708674486, 0.07668784504095394, 0.15977060902983914, 0.11868028811389401, 0.1686879031119808, 0.1629712784122075, 0.07346756380772398, 0.16248062974022282, 0.08935408231111304, 0.11229025680691966, 0.15142593502758012, 0.1442234061898724, 0.07582263300015081, 0.12255331456300714, 0.10396595308256727, 0.06176779241932016, 0.16131942430811544, 0.17972027402250998, 0.21076465416098797, 0.21986508922230816, 0.16912245882614968, 0.1064060350519515, 0.10157288592909614, 0.13058235267958335, 0.08646241449300321, 0.1060634098886963, 0.16376165132368767, 0.1423722772949165, 0.17850482956536357, 0.14881654762692992, 0.20006721689095422, 0.12583515096095302, 0.14338755829920694, 0.08361414555580386, 0.08958325751366154, 0.1392311635877817, 0.13432136736810207, 0.10392502100477297, 0.08291722771020667, 0.15306245205142807, 0.18318990155333476, 0.05591610641849618, 0.10179445387855654, 0.12370105216940566, 0.11710194014613667, 0.11875775492479725, 0.13751664349148351, 0.15108660404239932, 0.1409739829720028, 0.14570518877477417, 0.10802264911152663, 0.2008917420020988, 0.12604224750952375, 0.15059209428727627, 0.1444981099977609, 0.12544168820304255, 0.11239973077129935, 0.08852178906841625, 0.17599837373821967, 0.15482267695328883, 0.2074108897678314, 0.17498339916909897, 0.17290183102651951, 0.2223308811024312, 0.12428963752163034, 0.07401943822661716, 0.1020108430736488, 0.17412217844638134, 0.11943643987779656, 0.17857403794844307, 0.1303489256890551, 0.112424835472578, 0.08730113521338471, 0.1559004094451666], [0.02511055993607208, 0.017169005230009075, 0.006749020587097133, 0.024150270638206316, 0.07118979288685708, 0.028523090933900208, 0.015469244775182057, 0.028331662798600814, 0.06958935094336349, 0.07214905754212411, 0.0477973900495037, 0.06360426988272418, 0.019056956141045498, 0.04682006487142175, 0.029535045201379447, 0.016908458726961288, 0.03175101006373523, 0.07774983442598775, 0.0702232733789471, 0.04041212242877772, 0.03187421806937745, 0.041264445040254824, 0.012949821952309822, 0.043153227156689095, 0.14006655182569258, 0.019597320088876352, 0.025731426318206137, 0.06811168225061509, 0.07298508163301215, 0.044851188262503956, 0.031016448572758707, 0.023011067251284278, 0.061192740010277885, 0.03715552096705764, 0.04176805591991833, 0.06098645551490688, 0.00877587999697895, 0.043307662821344795, 0.039598146348350474, 0.07429221149293647, 0.02519005113431523, 0.04200010395218288, 0.05634041953711741, 0.0267999044679586, 0.04193034781623752, 0.0308042211503151, 0.033783504529105085, 0.05751447992459421, 0.03365150374931193, 0.032549785044524944, 0.05089832627544961, 0.04879595501528633, 0.06598139857693065, 0.052087991873944, 0.09245084718831124, 0.01392975278694423, 0.047748620892244006, 0.045479077755683855, 0.04930533453701966, 0.02143018927815701, 0.029500538686050043, 0.028743714679993933, 0.022127633809202144, 0.034161622545892195, 0.055067694685872526, 0.02743908035148296, 0.055893491502971425, 0.041662044672956394, 0.06730296919422765, 0.03405412508835716, 0.036326468276280555, 0.03225913511649255, 0.012007202472417586, 0.022876174489576972, 0.04950238767290308, 0.028821941833162022, 0.016395024684888702, 0.007142173079398251, 0.08190812137458595, 0.037852749078264164, 0.010780124012531053, 0.09253219806499059, 0.02612014507664548, 0.019529722405657656, 0.0190970819112995, 0.021349328697749206, 0.08530250374948786, 0.019782324576930656, 0.009968856052916137, 0.03583414953262095, 0.013019171104045405, 0.06488072941259992, 0.04076607420199341, 0.04264001719533436, 0.03972183507416518, 0.03967452148396162, 0.04936390961971014, 0.09240444524273758, 0.050929659271552685, 0.022897824134317138, 0.02857245572452103, 0.03419988480727038, 0.024916894824033784, 0.08200447991370194, 0.03696882150947087, 0.07096988734819236, 0.008500019396324793, 0.0548327699934523, 0.06371556330592403, 0.05891702986592728, 0.09236769600500984, 0.050760093370392445, 0.09520045932262175, 0.021765536606131543, 0.06930707818678311, 0.022877494076026544, 0.09888987747892257, 0.03517758153799561, 0.05739038900261926, 0.05110801986208366, 0.09140052532236423, 0.03267266937801915, 0.03991038846452871, 0.03924547777240796, 0.01912054143876078, 0.014994967402139259, 0.05572085358923482, 0.012507620680656646, 0.04042494674063018, 0.03553796078889601, 0.037367436208672104, 0.09386555111456303, 0.07893791422247887, 0.05480045640480615, 0.035442299389791106, 0.0843799576884316, 0.022492364439512455, 0.024939674448462266, 0.02912261027602419, 0.0128408775462078, 0.01311867539170048, 0.010171795616887752, 0.04250100288059443, 0.03212589135904226, 0.07308904742521626, 0.03229672322049737, 0.05620407120835397, 0.030131959844560876, 0.12146098043529258, 0.045021125716307474, 0.020576449404019984, 0.06345628467839091, 0.021703297707943187, 0.06706326794359954, 0.029228349561773004, 0.046720477271704905, 0.06161881513112496, 0.049152316135023875, 0.03047514042156118, 0.07274266843113207, 0.08973354098176764, 0.0408052136340449, 0.03552258923469532, 0.1167827266298475, 0.028863963671028618, 0.04261395105371072, 0.08972202668026572, 0.02229296515936092, 0.05329189138607152, 0.01838642236356053, 0.022611891392678506, 0.01702940677322688, 0.07120479288841448, 0.008355368589681965, 0.06692798447705085, 0.03968811571417798, 0.040306287382038376, 0.027150412675954645, 0.0549230074900533, 0.03729280009264908, 0.03032188453230887, 0.022900405850621964, 0.03150084979772087, 0.053800612072189974, 0.05119671369151724, 0.06571227955001016, 0.08129660701078754, 0.055307959011124994, 0.05018101133886845, 0.07756205861486735, 0.044290059501485485, 0.06880374309877235, 0.07166301305856436, 0.050512758053598866, 0.07891276355592475, 0.07025351853019769, 0.03328849298639163, 0.029289803219838973, 0.07652718874235308, 0.007608924596194899, 0.04307116764867979, 0.029752976148419326, 0.043899201442517584, 0.05428265757678498, 0.03198072727349016, 0.02599029508869975, 0.04745162392575895, 0.01953889056289148, 0.02250087567635121, 0.05803004177587648, 0.05793405861984338, 0.03937066803055425, 0.09646569949484642, 0.02685819801333691, 0.03090399644157339, 0.050805055070668466, 0.044427013039709105, 0.028544715680782835, 0.06427118389476692, 0.03267648832632169, 0.028906397281154513, 0.01907410310401071, 0.07526556450513101, 0.05467352712707174, 0.035350885948226336, 0.0681538860343637, 0.05092895064022272, 0.0777546761016692, 0.016990769128765792, 0.026529101962824504, 0.017121371798097126, 0.011049647150831598, 0.14067441195009217, 0.030074551130735108, 0.08288288398856118, 0.02874605699382242, 0.00985608791046205, 0.027756981942201817, 0.01949772674350008, 0.05150624768688314, 0.02973730965036779, 0.009539219580831067, 0.06410082126216543, 0.04896011233570115, 0.028621711347612645, 0.02926529606714124, 0.04104280814288124, 0.03398264142414255, 0.021192487517011263, 0.017839720953376065, 0.015786988360266534, 0.09154379908596316, 0.03008704027912069, 0.03789839259679279, 0.07274729560219473, 0.03781840918705829, 0.006653559807267401, 0.0344260914191123, 0.0495708491202564, 0.06671459068574252, 0.07471891480588144, 0.07980648172839035, 0.024260351727265986, 0.035023130551581426, 0.033501614816486835, 0.03719989277963196, 0.02983621543183202, 0.01381264379878919, 0.012149530117430035, 0.022379939121404485, 0.033966174364210136, 0.03494203248391709, 0.04627182553972929, 0.059612997762498364, 0.04645382887834022, 0.03927179672304661, 0.030524738868998907, 0.03533161883693069, 0.02632920472552219, 0.052536084361734896, 0.04376371879310858, 0.07438163693633772, 0.042401411450437965, 0.03482536495392842, 0.06628450892505146, 0.07951781213764222, 0.031916349074773254, 0.015561181071755147, 0.025474991792091922, 0.02275992064706741, 0.024642821123463013, 0.04487013744731103, 0.018583952389176817, 0.027160599730127764, 0.06633864069778113, 0.025359027147773775, 0.05600023819434066, 0.06184949952688429, 0.06998182544785161, 0.040748879358532934, 0.03344892328905483, 0.07327365929320936, 0.018875414370408943, 0.02885048052356128, 0.07342536002397537, 0.030387017327631195, 0.011999918891477489, 0.05152025560457861, 0.06025578000492627, 0.03104713613978557, 0.03374456811035353, 0.054993882114368106, 0.028234317921282306, 0.028134023605455315, 0.007727340721870743, 0.010846400194080367, 0.08170906874922015, 0.030016458683436918, 0.049153116696904746, 0.06189757154413289, 0.0247117766975275, 0.025780762380529797, 0.05402993283144409, 0.028586076767814737, 0.020196998394244624, 0.012470955712600582, 0.029329794924706224, 0.06523263190061816, 0.02291976680768834, 0.04238677917108421, 0.042423762065628846, 0.018366015696477507, 0.040217559078648206, 0.012662436516444772, 0.03295018855902938, 0.009081778905144142, 0.01623976739093421, 0.03290721868735648, 0.007005905668671814, 0.019324535331238183, 0.03370955406177429, 0.01728506563531776, 0.03739715275925495, 0.014290223968395544, 0.050851077802719614, 0.04120917945739724, 0.0206714864414666, 0.026492030968168573, 0.06492850265555805, 0.0292409842668642, 0.04052799705776476, 0.015929564026244465, 0.15637000602099205, 0.14404815591631398, 0.10176895847243649, 0.17843071821956866, 0.12073480569186712, 0.11840272679804795, 0.07938473500431546, 0.13747441672509716, 0.19222656745583783, 0.20239232438466243, 0.12563929292223147, 0.18956111774088877, 0.055565774410722725, 0.15021856513715562, 0.09740283953086024, 0.1449534573381947, 0.14038843132795828, 0.1744539864481457, 0.19934733939026633, 0.1658622950555817, 0.17204522215310605, 0.10261373128741981, 0.11139027969611269, 0.15751109398420782, 0.24008362043288448, 0.09114744817657817, 0.15596768728667693, 0.23563939116654858, 0.14161147537731356, 0.09039033114189103, 0.14970059776979108, 0.13514509574780542, 0.12025189450791768, 0.14835257413646868, 0.13186305250612, 0.12823972475504683, 0.17517783228428135, 0.203953136599833, 0.1708138277453761, 0.19011127612283155, 0.10647172709145855, 0.21592011945622586, 0.1965421858814455, 0.12067353397968317, 0.19613422874000766, 0.10291550098167312, 0.15910873970677777, 0.13599292525360662, 0.07495529889579743, 0.13934402366078671, 0.17099604941904548, 0.16702774461478959, 0.1393281656407541, 0.20329050118884734, 0.1910049176865047, 0.0721995274145757, 0.30383690590820006, 0.17179881763314048, 0.17134166232520537, 0.09044592614255606, 0.07709991607454515, 0.08448422991580541, 0.061832722201342546, 0.09813313582731832, 0.19571835024943277, 0.0876135841733025, 0.11129602789878847, 0.1640526881261218, 0.19612794681902856, 0.16843596743720193, 0.1198120374653128, 0.10612603757650622, 0.13642443193783685, 0.1276839356268606, 0.1300161677382646, 0.14504241546796215, 0.12485362379060638, 0.10860704396280552, 0.2092152566558892, 0.120177821466519, 0.12382566403116911, 0.23685483562369503, 0.13589684250614337, 0.13002413505267713, 0.2028902202484108, 0.18346066766929242, 0.16155421493514893, 0.07749911683100848, 0.14711837584693588, 0.17521892524053975, 0.12563431335072364, 0.21758390921017817, 0.10449256192171767, 0.1682254158320927, 0.09234488190662477, 0.2111311812674807, 0.16673094683116482, 0.20936583889828575, 0.10365009503138643, 0.15919929129942773, 0.15389106807208833, 0.16111250395976728, 0.13159190334620016, 0.13492469225198994, 0.09822593971846566, 0.15902221773660954, 0.12026072750168464, 0.18529699574555122, 0.1796360503161146, 0.14059023420897224, 0.22242720899803026, 0.13005989603698254, 0.1107447280458385, 0.13174190336177427, 0.2213962998000845, 0.22477185173380762, 0.19894771728544466, 0.10628462543771153, 0.1788797683172649, 0.18396642359514392, 0.1415299789439286, 0.1869655046011171, 0.1267855136745399, 0.11826441728419836, 0.07386322523797713, 0.24847913202979874, 0.10373047297640194, 0.0943230894664603, 0.11716580889638394, 0.09257348254323007, 0.06846710108220577, 0.25043031200766563, 0.11325898264805156, 0.11030494761202606, 0.06206515327756924, 0.1869671133857581, 0.08253344064277988, 0.10069840422440922, 0.09535438170836819, 0.12571407842539972, 0.16939843433999247, 0.11130160501887722, 0.18200116292122873, 0.0928409621419926, 0.11700648559077133, 0.1521019310119652, 0.10227705862733627, 0.13296195966822486, 0.14101863057622988, 0.1768600234701749, 0.11741672567422352, 0.11534959828901677, 0.08239146922865222, 0.14434000477194786, 0.1599714159965515, 0.2012191373374193, 0.11697970315693848, 0.09580599053973153, 0.053383756819511616, 0.11882620488083172, 0.1415651423796531, 0.16351446539403933, 0.08041696953437022, 0.15768622168369834, 0.15441167078191234, 0.09564613863345116, 0.2711200792222254, 0.07336349076321048, 0.18991627610258519, 0.10578998544764136, 0.17886581019528452, 0.0640071248785863, 0.18406318049998055, 0.14052219027953763, 0.15580782005863805, 0.12509520961752824], [0.009599096055382924, 0.010952081065624954, 0.0053052345268248076, 0.03347228130986614, 0.047957395173368916, 0.04642370630115752, 0.029478155512122378, 0.02607226649659776, 0.06941449137464648, 0.045659947284166856, 0.006411180600538971, 0.018476993108408588, 0.05223227687360299, 0.03383908803845125, 0.0019532159762269247, 0.02718006219384411, 0.03717193057039573, 0.032066724473430265, 0.06168533071515061, 0.025013611509254383, 0.04575544397436804, 0.028301017366409786, 0.08204023323712811, 0.041697755861546726, 0.010591993885745686, 0.05351205356419087, 0.02269254321412694, 0.012284224653886932, 0.05113456097822036, 0.073021708296672, 0.03436544406858664, 0.01461626141287026, 0.052573285591337955, 0.012243160425925688, 0.02272741170600057, 0.08241985278624682, 0.08005830248998058, 0.04751037903911164, 0.067828566797318, 0.008858799438683257, 0.03418858117994762, 0.020597800274469683, 0.026973973050893798, 0.10359476050061565, 0.027758477728873975, 0.06588252726942301, 0.057953689622903065, 0.04087486634812048, 0.0278935888256397, 0.011713405838236214, 0.0064391782413417056, 0.053324607170877926, 0.021174708531508525, 0.023910010143393473, 0.03788648376000985, 0.051206990761021455, 0.04296123020110592, 0.017982314813942198, 0.07657736750139345, 0.021742643983734232, 0.08502955428294598, 0.06446600005391144, 0.02041798411688257, 0.07521609054698099, 0.06708634251187887, 0.042290118027238116, 0.014630513521091593, 0.038532219271385865, 0.06318143531379682, 0.027920457444364027, 0.042486956658502745, 0.020877332351500952, 0.03032669364925354, 0.06201452252665355, 0.02670654516306616, 0.031633277671531804, 0.04122194631265537, 0.04594589343234416, 0.015955386934952152, 0.0277774537267584, 0.05408054443016168, 0.02354806615790773, 0.025428804351137053, 0.04616681020706893, 0.05272525062243785, 0.03883351782156576, 0.05314910408830451, 0.05989812802703631, 0.04158743920045034, 0.021261125164587173, 0.05327707907605556, 0.07382132022851899, 0.012593547975073659, 0.03548416609485303, 0.16605525728194945, 0.021887082200978073, 0.03195945875749233, 0.06142283834877515, 0.015574946714144562, 0.010168359712547353, 0.06291808875938577, 0.1000311569641194, 0.06361236743208382, 0.05729842014730938, 0.032982471504158554, 0.05103387404233218, 0.07594781942785749, 0.027057825204645915, 0.029541968720995133, 0.07785595292525907, 0.048302506291938406, 0.03308587422173831, 0.009197004274615358, 0.12793394076007028, 0.08594823159998463, 0.08192823884347755, 0.03247478503673788, 0.018840187732430718, 0.029678795854711247, 0.10977388014115634, 0.03869871315996974, 0.07669862389804856, 0.05388218511436736, 0.010343525716434083, 0.044176253309894, 0.054806565956002286, 0.07708535274310459, 0.07484590920108943, 0.017888256453818852, 0.05048665743801863, 0.047644846622020974, 0.029670428259358294, 0.013469297555275263, 0.06213323551140005, 0.009454037306920416, 0.020193809553259806, 0.04987117090833284, 0.02585484499802753, 0.06418819742036924, 0.03748386242096463, 0.000545422163052154, 0.013026636630867519, 0.06778113063304655, 0.04059212627790628, 0.014196361918302794, 0.03792041762461586, 0.05915129572273262, 0.09089927399350752, 0.01799646254268385, 0.07260099579129489, 0.029671531425969257, 0.07140936134683509, 0.02647987506803005, 0.026071670863236633, 0.0263375646599959, 0.03477117189416482, 0.04125779539707207, 0.0288975183221121, 0.02901081123479432, 0.02348483709107724, 0.032235711978207675, 0.11593375565303911, 0.04469800132116483, 0.02523268967296087, 0.07626864172878765, 0.08367577732931222, 0.03681850356740817, 0.12929906347586265, 0.020623356967623678, 0.020768743218673814, 0.03228579497625751, 0.030844775929806695, 0.03776855984582536, 0.08199245999416999, 0.011781367413218946, 0.00856443494182801, 0.056734433878333344, 0.041155560963576844, 0.028339363897459644, 0.04448735778550467, 0.0496257929461858, 0.025073126964871923, 0.040567910238619775, 0.06966408282037705, 0.02532913056652873, 0.01869160497951652, 0.04345673204009091, 0.03948997090300245, 0.03705427095654511, 0.05421628754946494, 0.030205623028920065, 0.04046325496728382, 0.04613999329927949, 0.02603749376571467, 0.05842358114257936, 0.10583689301124505, 0.07654864686511217, 0.03438917364204123, 0.06960462673657364, 0.13341736829569265, 0.003012850239399761, 0.01728305848495614, 0.004500903493364252, 0.040474822894940456, 0.030436234646326596, 0.07206206825832207, 0.024270487070504217, 0.04389722493567294, 0.04748455421518415, 0.046716807710547606, 0.02540296803589069, 0.0230600738958005, 0.06879318640717576, 0.05995915076064487, 0.06600529285928895, 0.10203415512918465, 0.1090217579997355, 0.02255227634563081, 0.0390065387792645, 0.00810730836219004, 0.0229004479854578, 0.019628128314751293, 0.06619212638226248, 0.0147773620424672, 0.08406592292651054, 0.056075372267514474, 0.013535614914050507, 0.08257007496731897, 0.03920833782983884, 0.026020101654613693, 0.035269017962198106, 0.01514381924343686, 0.014580948590000552, 0.038321736614189805, 0.05853983498508892, 0.02371244372860078, 0.029497533706167055, 0.03445140679457015, 0.0024120711614452907, 0.06198749111424531, 0.028897838163820487, 0.02878438628789398, 0.03639616312519197, 0.03953725001924942, 0.01683531839761042, 0.03833155786137908, 0.03469600717747404, 0.01892874558125773, 0.08690836959548535, 0.04110483445167061, 0.04194554317021563, 0.03138204105198383, 0.009409871380475741, 0.04190582151134168, 0.013816598727698288, 0.0452747697671575, 0.007854381082354174, 0.007194038189481945, 0.03038901681711357, 0.06743590843172804, 0.01863197844114996, 0.022830343279506893, 0.018719348853694338, 0.0303336842015626, 0.010768241031215557, 0.06273870544147588, 0.023287364522055275, 0.03313812141817424, 0.01747132459234807, 0.05807112324081602, 0.034046356956804955, 0.016117932597896265, 0.05531577310795265, 0.016346272764607303, 0.001678484996157368, 0.015830122940843145, 0.049178102654555154, 0.04319045902980913, 0.02368767227556917, 0.037329706378401294, 0.037076069988430514, 0.04531690843343254, 0.013738037368673232, 0.05643555616599418, 0.015616457188321699, 0.07023671056113898, 0.05552864595947247, 0.12347647349440283, 0.033119896186455604, 0.03382763885442288, 0.07176956056707329, 0.06939156236307276, 0.04190639990772452, 0.04385665674964267, 0.03119238257978953, 0.04515920540377979, 0.03392373692364462, 0.011265752893391878, 0.027195889570359743, 0.03588223304118841, 0.0657688934476145, 0.052040479100880124, 0.018155801170054945, 0.032327343754830866, 0.01582256356825031, 0.028974393330093835, 0.0182725012587804, 0.04215378502023317, 0.009492625155666424, 0.018544539080692396, 0.10649294772696112, 0.021657355415124088, 0.05098387148351439, 0.06408646094402479, 0.05661747523493344, 0.04063271744657428, 0.022786614980788964, 0.009347704303030287, 0.030600847789056362, 0.057135726054829944, 0.0299276307886166, 0.03340820571587932, 0.02725664991885424, 0.032958297599707885, 0.024216709613439538, 0.105394285712992, 0.021240379503597657, 0.0948146574439541, 0.03367638628509256, 0.037139938738677776, 0.049692396630322745, 0.010583968157128943, 0.06386974616156471, 0.11142882924046248, 0.019620976883978136, 0.03102436800667596, 0.023673442192375663, 0.016832619852897142, 0.057667429378676804, 0.0339397328395036, 0.030036336749852188, 0.050601405917756984, 0.05319939009965428, 0.06398413074953903, 0.017091695467130314, 0.037370473747291875, 0.04106063500887925, 0.01874738384128338, 0.06344049560627149, 0.042657801926496534, 0.06880335239393097, 0.046590606216341264, 0.1252850079007687, 0.1650346902709815, 0.1284433356035621, 0.1131839290141098, 0.19283695567038753, 0.11655215714727679, 0.0703209036240174, 0.12842422937073056, 0.20667788152012134, 0.1326775418654565, 0.10354724772755178, 0.16261117112252021, 0.14947158344570668, 0.12528796500015643, 0.10007026575265393, 0.16310321407452708, 0.17550436960112664, 0.13786095404817214, 0.15646313166906758, 0.1979843463989035, 0.1378332063435547, 0.14844522481003117, 0.19505782924111814, 0.26872789306986716, 0.15412832550223798, 0.22494032979011538, 0.10872368084927721, 0.20165645096811557, 0.1383501011878252, 0.15704805512101422, 0.18962042826798656, 0.11036121677006445, 0.1821082160477677, 0.14106784406448566, 0.07722559279852337, 0.2266659734830741, 0.13731016747413144, 0.16233666649749204, 0.17017800541174027, 0.2776971279132751, 0.17941301147783958, 0.08182845589134001, 0.09343779826116178, 0.19908786541031254, 0.16666350045031117, 0.15650221747496437, 0.13482747569439874, 0.1924460210026272, 0.2303945234105472, 0.20986224855146102, 0.1315892986472576, 0.1575864004271646, 0.13054548852866696, 0.10806959497952655, 0.2358899172395468, 0.10269489830299731, 0.1179462839518824, 0.1876441665714787, 0.2877212045413833, 0.16714454237972537, 0.2278678275404438, 0.10875447758383329, 0.07952651489646205, 0.20769253433231386, 0.16874384285221178, 0.09031566055191141, 0.08113911465531395, 0.1473901531989536, 0.08492142097243378, 0.09635725974916451, 0.11150726898302955, 0.1020292598273485, 0.26663641174954755, 0.1033970944943928, 0.07450614920667104, 0.11291199844450721, 0.14656976496260013, 0.1508372883883215, 0.12284021449065018, 0.14568605189842565, 0.07387441012167162, 0.17445158093206345, 0.10916258794285598, 0.23634840554047018, 0.08901442956900404, 0.20823605839283238, 0.17515910909541194, 0.10452199501976853, 0.13654132163332355, 0.13631425317256682, 0.14248761949279617, 0.13657666893014986, 0.15247348365524124, 0.09603940986938055, 0.31930284214115917, 0.1141037401412764, 0.12706932626784812, 0.1930101068630334, 0.1130930096992562, 0.05773856447288587, 0.14774466804679365, 0.19967833533883098, 0.17174627932329334, 0.17079865920447534, 0.09876310524921264, 0.10474841230578961, 0.18108004944459086, 0.2561834331361517, 0.10338461492210628, 0.16299686574887845, 0.11221470521582712, 0.1884792483742199, 0.09193237420291671, 0.23262822129313024, 0.13479905383240792, 0.25180444391744755, 0.1913503467315628, 0.09679899370718388, 0.12068276533917074, 0.18123410972616366, 0.10075300331077269, 0.14648356474936008, 0.20016446409206237, 0.12586869795115727, 0.20184213535920267, 0.17670751068620913, 0.1396965466800236, 0.19141007094613968, 0.0610958107356583, 0.1358208925493302, 0.10056592463966339, 0.20110578696814277, 0.11534240472340777, 0.11913479275761113, 0.19954843747038997, 0.051722529629666, 0.13910684283942948, 0.20590065467742183, 0.16436658499221649, 0.1421314345732812, 0.11843884784367778, 0.10981685767370848, 0.13200845599414843, 0.12109170307315166, 0.12832650719510932, 0.10118238793145265, 0.13333133662179594, 0.14995680821518745, 0.1141058698657059, 0.2093350268419712, 0.16376802517521769, 0.1416518022456477, 0.09040029794578591, 0.1748933991597545, 0.10531228366157702, 0.28316371683632174, 0.1796018827946917, 0.17162827113943716, 0.10573439044697631, 0.13151858873184652, 0.16029951613276236, 0.17531707642539857, 0.1550740763665207, 0.14952272747553166, 0.08386769767610297, 0.08605009065039697, 0.18571796105994334, 0.22474159126079854, 0.0974419023541193, 0.09886253580090501, 0.14235007606687086, 0.09870225488538704, 0.09086392669668121, 0.22437785271435018, 0.16621104892223112, 0.15874109411191556], [0.034230735167981155, 0.031776045817100716, 0.06143103165912533, 0.03329560611276858, 0.026613059453666214, 0.04444009782145581, 0.05187384348603026, 0.07785649684768531, 0.09422705268427249, 0.010306136795289574, 0.03512431927506001, 0.028575504754459666, 0.01005239219539949, 0.03819864160651642, 0.08914998882720548, 0.09569352883244715, 0.052948289460712866, 0.023924383868072784, 0.009246593145954033, 0.009414818393246783, 0.06712153659112031, 0.016167563604070775, 0.08628326483191022, 0.0450133269412383, 0.04744046202470218, 0.05245837240269589, 0.01831568180463247, 0.039559688734551596, 0.0061137766498441425, 0.06285347307341234, 0.01474078517452243, 0.07975399704469789, 0.04319839187026505, 0.016897446213049755, 0.03234877506451261, 0.012150389093515134, 0.01879736916312287, 0.027791576557642514, 0.026849420560944467, 0.03623079538585679, 0.015293284912683792, 0.028992247009169192, 0.03174642119706879, 0.04857010846476882, 0.022550738424122817, 0.018963918593081257, 0.04435717263409207, 0.0486901237989866, 0.02058596996169898, 0.06627450381676037, 0.055787959060962164, 0.028276027578319755, 0.038144984808299816, 0.03169482709058831, 0.030427905355369857, 0.05308218630811861, 0.02493034924320396, 0.02958758159600679, 0.009834282175307314, 0.03063373402842591, 0.04589746135377115, 0.04339639112473496, 0.03548521180486968, 0.03470715375677232, 0.021170648265509837, 0.028654731652368943, 0.024104598391380523, 0.035358378288125804, 0.053655365632186015, 0.017546694237558592, 0.06679369692480372, 0.05601822210836315, 0.03670158705884411, 0.05586441846624498, 0.037822461792177735, 0.037411390503327695, 0.03714488000578938, 0.029008336770798893, 0.031247703704021634, 0.06817728235957123, 0.021762922331089937, 0.04684425792807052, 0.09370962157845499, 0.024987413217463804, 0.020012468880703373, 0.05882183195001656, 0.008595619508395753, 0.05503915024981384, 0.020427663637805852, 0.024552585542081826, 0.05870830538051744, 0.10598419639732569, 0.05408721705598216, 0.02474089378430959, 0.044380071002148816, 0.03980175719686574, 0.03401413912914934, 0.08148297322012725, 0.04419625586559696, 0.0492037206347431, 0.10217951265193763, 0.013360314844777028, 0.02349167059536182, 0.04471615377453066, 0.04087713013793673, 0.06232049038273193, 0.037892704393955014, 0.07911980647834078, 0.030467669149079633, 0.03178814617586473, 0.0673753721639514, 0.006363685064453391, 0.030625303230819204, 0.021110640598400947, 0.024842385112518267, 0.03953952146994491, 0.029333106339758927, 0.044904416051482966, 0.04306697331729435, 0.06128675432034558, 0.03623372950260678, 0.007947202210479808, 0.03745062569636972, 0.016496088919079593, 0.12592983176751485, 0.02617501612422207, 0.05646264503499674, 0.06445172017500286, 0.023334672366599404, 0.013751715868561259, 0.03683101378321167, 0.05922129700681376, 0.008608787602204229, 0.042722264394885114, 0.058586830648803906, 0.043450791028238116, 0.022215394926587903, 0.0630142557765207, 0.04770987982591314, 0.022427057359187354, 0.06656563254974543, 0.03400979924105829, 0.03920817695137474, 0.017921991135564544, 0.05599880560992226, 0.04305874553298758, 0.041532583474632234, 0.02432045132492579, 0.06338316924689759, 0.07412095253746356, 0.04487012212555255, 0.06729579095037715, 0.026430196181360274, 0.02150609710013434, 0.05589016285094042, 0.033347757548213966, 0.026207346949846517, 0.017584966075035836, 0.06008753943587503, 0.05570663116692055, 0.10705421438380595, 0.10271992639548357, 0.028939390772833463, 0.020840470115804387, 0.03282720846454463, 0.012977850236629528, 0.032215793692176385, 0.02598269932693051, 0.03326489747832379, 0.05070260230211481, 0.058299919229842005, 0.10032878212270238, 0.1213734319073058, 0.07950295003191118, 0.02678294328131503, 0.05569095317755015, 0.03890624637865732, 0.07071675657625161, 0.004414863200978406, 0.026041933245235876, 0.054171371814464374, 0.022663290146738294, 0.04285795388803367, 0.04323557777810962, 0.0181159358696952, 0.03503857488413492, 0.022978261451146776, 0.020516606445814815, 0.03258746124864106, 0.030865033209744482, 0.09946228305418646, 0.013430277824461942, 0.09457676416082729, 0.02729841320204639, 0.05672517570576841, 0.014298294704677838, 0.06871933553127513, 0.029637917403071642, 0.031090764847073345, 0.0854923096936076, 0.0791597732853505, 0.05374195271982782, 0.045589068829412424, 0.0776876510691739, 0.054117293667889414, 0.05446371479680943, 0.03661798388366738, 0.009070142987184227, 0.015873120583203292, 0.07524543171448093, 0.011200783849363367, 0.018692187206338973, 0.007567654482104005, 0.02519564357616248, 0.04339955123742262, 0.02748182805765781, 0.028936950782794627, 0.032252933634745504, 0.06524532597752349, 0.05773189950794463, 0.043982570960877404, 0.0558785068231725, 0.021607473515154376, 0.05696853885667459, 0.06750940690718352, 0.08079752371075653, 0.04258553302215953, 0.025391670154227365, 0.015512584284278414, 0.01905000197791284, 0.009833774642057477, 0.018770090687359055, 0.025102161697202155, 0.02928318996583262, 0.030134304073609175, 0.022777213166738232, 0.12769047801773395, 0.0699891952136832, 0.039553464270166816, 0.02055450290020916, 0.06462866350287391, 0.03193645313712618, 0.030184479002209923, 0.020678683837515213, 0.03529535989547449, 0.05522251339449037, 0.08445250621486096, 0.06533711097173153, 0.07556757168664087, 0.022994718934980132, 0.05687836647754716, 0.03428549513280873, 0.05333665773392685, 0.03945831614997118, 0.024308419914074966, 0.04601617050807803, 0.053953251260663235, 0.04265861397969627, 0.015107341966922245, 0.09324266034508906, 0.018149272185720263, 0.027869043368545753, 0.04941589634625181, 0.03748566272758669, 0.03513256238112527, 0.03829219626382955, 0.020392431254168192, 0.061719927245811115, 0.030819044951649926, 0.06186318568765156, 0.03959615835018697, 0.02986694513369472, 0.018765806340642514, 0.06097786383883608, 0.0628941829857086, 0.04417405846799093, 0.02915623004458124, 0.04693005594515032, 0.027321995303575552, 0.02828327285486364, 0.04187506691162144, 0.01810987802943395, 0.06093271444701861, 0.08629757535433577, 0.008538499035151496, 0.03420089221289081, 0.0744039683993305, 0.04370578339383487, 0.031890512759526896, 0.04426913764027338, 0.026628800645290364, 0.03366991667257201, 0.039642207895315466, 0.08444048629532899, 0.12250855204559143, 0.028947289139332793, 0.057578953884301655, 0.0198990227504363, 0.020382558296044028, 0.02047356954144855, 0.10643464077504412, 0.06118489910037287, 0.02281433395710924, 0.043433603845656886, 0.021224490840048082, 0.046264428960820364, 0.029123577462028594, 0.055341322140227404, 0.020043537576472568, 0.066801909387352, 0.04511717782025376, 0.04149011156011013, 0.01766451856031293, 0.07080985924168941, 0.02228222652188232, 0.06633003753039145, 0.08535705687057588, 0.06307248611964526, 0.052682353529117765, 0.05878772188518798, 0.00824817565209683, 0.030858460175354156, 0.037933916093841676, 0.03109509132862572, 0.025884057845800154, 0.0366398939983018, 0.020191921146526452, 0.009120625308564594, 0.0671503491579525, 0.022189836318214095, 0.04726033943194536, 0.018301009305662686, 0.01253734680733854, 0.022105647085775292, 0.02450435264636913, 0.013286374911155193, 0.06659301253215921, 0.006612786213912431, 0.03462422090852934, 0.07035299504716551, 0.030320289154206554, 0.04844869118964961, 0.02138542867596111, 0.021129287178477934, 0.04513915305236175, 0.041717697130215746, 0.050051825932197036, 0.0213799319951044, 0.012986519479102666, 0.005359902561101462, 0.08629733786707924, 0.06665467494918455, 0.1553750723119705, 0.09802510976911553, 0.13663129099915106, 0.1204454236393494, 0.3734961164093787, 0.15457732963465876, 0.10799618843462198, 0.23997002491547217, 0.2202018155085464, 0.11685826289918154, 0.19758291632658054, 0.0782270382549013, 0.23251985049536153, 0.16957841903692292, 0.24223055119716355, 0.11263888043862198, 0.24549646062716363, 0.09836694586180872, 0.17522108560848623, 0.08145580008145302, 0.22044302595238532, 0.1690196957919867, 0.14016367645273287, 0.23119045812035763, 0.13264671448738347, 0.18129365007963874, 0.1533416757780698, 0.19100902391777885, 0.28064215375531104, 0.19613902445041365, 0.1269385857026904, 0.3397538963585131, 0.060095997046559095, 0.095599468557104, 0.12929379279094358, 0.1477503524191918, 0.09716542122224647, 0.11323716446396806, 0.21335104360215126, 0.1346399067270179, 0.11347070636768496, 0.1626719985037081, 0.11673440180358388, 0.14589176182785343, 0.14613781394737382, 0.2448708579064377, 0.10175018165741237, 0.17369094755380385, 0.14542984145302928, 0.1130837400353724, 0.09085900075132809, 0.10729439060894713, 0.1885775068113881, 0.15780138002047617, 0.06223697147722687, 0.14222463683014916, 0.11507836485942526, 0.10094611109384607, 0.1400881555051573, 0.17597804176470927, 0.17408205076090752, 0.15929788681528262, 0.074470526118192, 0.20290476059721363, 0.192774182425872, 0.15598604275334269, 0.10609312643927914, 0.08751624504164343, 0.13104589716080697, 0.16094037932493996, 0.1614112476067197, 0.1924570986340123, 0.14707254846730541, 0.12410557723694271, 0.12384865432977678, 0.11943305376917125, 0.2535648986456856, 0.17876598893875079, 0.12412385609481605, 0.1100364950815997, 0.22652740349933026, 0.09459141176193954, 0.1160758573021139, 0.14836622582327935, 0.10483589954674245, 0.11731961636894173, 0.09385503272736266, 0.16072906163190642, 0.1036346813423499, 0.05477983331788452, 0.16867518605243775, 0.18920096448592602, 0.15972683476584573, 0.1610742608505872, 0.10260844528074227, 0.08873388817113254, 0.15189226806884812, 0.1842863725558404, 0.15683030228941672, 0.1359229967478783, 0.2188222443745021, 0.10891629067519981, 0.1261288767320014, 0.12838936470929654, 0.1844758873865489, 0.163660665613509, 0.16970571220642136, 0.14322595971245922, 0.07305111075120588, 0.13423810893249127, 0.23276516717047463, 0.09716470876047689, 0.13356266453141166, 0.1475243258380121, 0.15695843815563187, 0.10408972990849327, 0.1466309447442332, 0.1584488009252856, 0.18908059675126307, 0.11354336980730297, 0.13411358900127873, 0.113907192623423, 0.12295739529954812, 0.12665864951427908, 0.20100051116558815, 0.1565198834624983, 0.11640132209586522, 0.11662305858466895, 0.07546496187006274, 0.11299755514389086, 0.11944073763105179, 0.11249672516339249, 0.11090022091182972, 0.21499358207708408, 0.20650787128796502, 0.11888696331410639, 0.06417653756216168, 0.1601371208145734, 0.08192754170346646, 0.14439764522737072, 0.19446152172261671, 0.08817145706064279, 0.09213662090440912, 0.19981292166536857, 0.14376208336362917, 0.1880061890809767, 0.1286795434932555, 0.10555791443273907, 0.14177384005198557, 0.14838245156551563, 0.12007815342757011, 0.17074959893380443, 0.21054898508854453, 0.13282263891831522, 0.16186092589651385, 0.14583211422206896, 0.08856784627442399, 0.14883160891552127, 0.1492797090641914, 0.115046173844847, 0.1799978276774768, 0.1699313863871559, 0.1251181999161359, 0.13104283280910986, 0.12119532412578984, 0.2193742107239462, 0.13573216424594003, 0.15836154351071005, 0.16096264184001954, 0.21437698855034767, 0.22267275549952062, 0.13337823652452038, 0.21967388899816623, 0.17607141256092057, 0.15264746222284534, 0.2207487409994487], [0.024252570189175107, 0.026983361458405856, 0.03047159726491138, 0.044287745915954156, 0.07957657108143454, 0.0489674054927403, 0.030939316925322338, 0.027322140860281167, 0.005297696221649888, 0.018311686656107346, 0.010473533710014197, 0.08214857339137986, 0.021933543518365874, 0.0509236493117867, 0.004460275935519848, 0.0194243872312889, 0.029126392835150325, 0.022617566188977613, 0.036840582221385934, 0.06641073723233516, 0.045099634406787735, 0.02003152531781985, 0.10288368535017776, 0.03859737504934592, 0.039955656599974444, 0.07642336084597534, 0.06296153360557172, 0.06120705436314307, 0.01285921864872498, 0.10617929600900221, 0.050739033613353975, 0.04318979636375462, 0.004153656904705831, 0.04713549008292537, 0.053643368695291786, 0.0814630089688205, 0.009944207173952413, 0.06889775740884005, 0.06590962379930482, 0.09676647327479818, 0.03934893411614242, 0.045372729430035244, 0.03688274387029871, 0.09593890679459419, 0.10832647192141703, 0.04793173888878477, 0.0341260071182924, 0.0431049597870198, 0.0684263528655133, 0.06698764740459381, 0.009776590966559466, 0.014551549008296383, 0.057608295051801595, 0.07359171601673288, 0.04103796646719979, 0.07231090893788684, 0.041441648838020144, 0.09233571183417114, 0.04105465952306986, 0.07081250990590743, 0.0455885632113824, 0.011831628526711177, 0.016228657200812333, 0.04192359475118499, 0.05368478340847839, 0.027825675131152236, 0.03003557832280715, 0.034892401477742585, 0.06999654199687705, 0.01579408616488499, 0.045188401014574116, 0.03249382998253549, 0.0414423919433067, 0.018273527816598936, 0.07811350402452293, 0.05131311309073241, 0.12854993673822573, 0.08518549914081251, 0.047976501406200474, 0.06435294845892538, 0.04698301560335583, 0.0285049595479523, 0.04290484229943926, 0.028741931610350168, 0.025706901928530108, 0.04868993993788477, 0.021531042838168722, 0.026656307032211658, 0.05742365254029151, 0.028795067468778263, 0.05288330605253578, 0.034458853169194156, 0.08547081326645228, 0.024218100063022108, 0.07126805642920156, 0.09562465752805434, 0.02433356291974985, 0.030977014196856372, 0.04583207957987343, 0.030033105774031534, 0.037179430571174434, 0.02826333350141443, 0.06100017998007037, 0.03607544807657119, 0.02367562554295986, 0.04178022905703514, 0.028625373247890707, 0.07021162884249803, 0.03894558499356912, 0.04330550628383795, 0.052337721215500954, 0.056891301872148636, 0.04933364148582182, 0.027494765367479097, 0.03194263355145532, 0.11993337813163958, 0.02593651188597564, 0.008687996305525303, 0.006875430840262844, 0.05661126609230715, 0.009836975931971064, 0.05176210573183433, 0.0270494461179741, 0.056006248154106646, 0.041207375320335554, 0.03539579402234766, 0.03714391856544441, 0.02303855257078765, 0.013001827831049601, 0.008157077264190923, 0.051949751308007594, 0.0342535799098832, 0.04625422466966895, 0.06779185586398648, 0.04137490725805683, 0.032551493420596087, 0.05879292745263346, 0.03382811765937555, 0.027675232699801846, 0.09529258905639572, 0.03282913517567419, 0.06657553806660638, 0.026625196201606628, 0.044861423197172345, 0.03676220759629242, 0.08211828993573304, 0.02828679877453514, 0.07827710976163227, 0.08857512410970465, 0.06142261235283748, 0.010893618023293394, 0.03311564439847585, 0.02166895207107788, 0.02093827081543784, 0.025517071086552837, 0.013608082043637913, 0.04039474755465504, 0.030310732207351157, 0.05635077704585368, 0.01829371614862354, 0.09344840857891307, 0.05887720861562318, 0.07286436915878328, 0.026179932493476138, 0.0451693024426218, 0.022522592353784752, 0.046199365113411224, 0.04148718510423938, 0.01775664446364728, 0.026361206133339195, 0.0154241154931726, 0.011780487369715929, 0.03357777161703956, 0.06879091112604065, 0.0522290209999248, 0.03365673612983477, 0.026468579101586537, 0.026830728015592022, 0.05394878113762506, 0.030348935096915212, 0.030072113055916085, 0.020691611571237445, 0.029198901141963662, 0.02065802436141718, 0.03216625078611317, 0.014903325091807113, 0.07265642991349583, 0.07112881228808435, 0.0677793303264245, 0.003321117795665839, 0.05523351824752266, 0.027077483020782955, 0.011649389616063526, 0.020725344337763327, 0.014581293329566479, 0.053617907763128324, 0.018173886590727398, 0.026481870727072802, 0.03293765153014853, 0.0787195715031797, 0.02661010235427849, 0.047426909929321664, 0.009279835616208373, 0.05867040318046367, 0.12244800045605629, 0.03462742698649245, 0.11585225155877492, 0.04548085507966819, 0.029476337968522025, 0.024972531959534656, 0.006634294611191558, 0.09052270347432745, 0.035799832624052806, 0.03084106997947299, 0.01536663304338412, 0.008000983497984107, 0.030917807091628353, 0.05736843292270938, 0.01708513775449847, 0.08541367076818021, 0.02603470903610991, 0.04124128237186421, 0.02137075809221114, 0.03574035355761167, 0.08246116024712402, 0.08784171749627398, 0.035479868341597824, 0.017576226927039605, 0.039349148620761214, 0.048618705252245556, 0.06207283713944978, 0.001878211419792816, 0.03226355927425527, 0.07858984983496128, 0.010695532583932002, 0.08427396942410739, 0.027751590598434694, 0.019949481131569035, 0.01958897547616113, 0.045102254427488775, 0.008270575105392886, 0.01643753681902684, 0.03795262013051299, 0.01225751978645642, 0.02820060047651491, 0.02998988692378325, 0.0489226276535661, 0.026951467302898248, 0.0542412122200814, 0.057334671427886334, 0.02468807393715026, 0.011786030015848097, 0.09876879728249005, 0.029116207696197015, 0.025869823932167024, 0.05929215630937008, 0.008748802619295256, 0.010951997753563187, 0.06424087362604276, 0.0410073459328663, 0.04675968182122996, 0.013263708284695544, 0.007543134880477503, 0.03198034614474783, 0.04366599278704774, 0.017754420893447056, 0.04717590505137079, 0.007168368498359117, 0.03587805020112184, 0.07584912432057243, 0.027499289116671974, 0.020046749400095116, 0.07054092407587075, 0.013757619533627747, 0.06463047913125446, 0.025632304116903294, 0.03759588362769254, 0.021178510242832765, 0.01885319015972557, 0.045957836743083694, 0.05463690812429113, 0.04440347498823558, 0.04179505285836997, 0.026534269225873777, 0.03443893488316286, 0.05498162853801924, 0.031014904905591282, 0.0550579538779153, 0.0765914788409587, 0.04678542237548579, 0.008462307760642182, 0.06505596436439984, 0.019391939577256, 0.029144669777803847, 0.026090897754916263, 0.03817622204341235, 0.0015160384458384568, 0.06592742002178585, 0.032530877994553696, 0.12694633085160487, 0.07587629745924666, 0.011658213033731426, 0.03347076445577606, 0.025751199047531814, 0.023186821227652893, 0.019917904902550004, 0.10032964014117757, 0.01919183358099432, 0.03783484177303411, 0.020094957397950274, 0.06018974705629292, 0.030795424545724547, 0.03553680782656997, 0.029357768625261325, 0.024692907951952472, 0.06947300517030301, 0.05571632984004194, 0.07146324031054974, 0.049729536572891864, 0.03562563572139029, 0.0021276964511226623, 0.09565120247463066, 0.026573322473033786, 0.03457112718493708, 0.0879757522395061, 0.031891139036404996, 0.03563444190207989, 0.0029385933368992543, 0.025455065845181386, 0.015832561015662168, 0.0482108706848756, 0.08354783298507815, 0.03361964598298073, 0.0646699862855096, 0.06986467528247065, 0.020546298098540115, 0.0834953866057819, 0.06362743255111479, 0.03975497603776955, 0.05632827704351756, 0.05865249204479399, 0.07355829160059653, 0.03762431698100221, 0.062199436999376745, 0.019673371552339485, 0.0248476347300194, 0.02583290807031576, 0.03050262191062493, 0.024948710455529155, 0.031237133605886373, 0.04947391218475757, 0.059997217669602365, 0.14179069398631974, 0.09229492531308243, 0.23783144450956778, 0.11711185332387687, 0.17636447183547482, 0.11414003738712881, 0.09270081401712472, 0.17917474281162987, 0.15240959192235626, 0.09839315372969835, 0.17097826085744366, 0.23251113241478322, 0.2918404593102394, 0.14402704253312082, 0.11078752937816805, 0.1301639920641338, 0.11558571424815925, 0.111477782258824, 0.08734706218444532, 0.16563151872927145, 0.17673954848320256, 0.21161993004141316, 0.18423870656519167, 0.13615927358548488, 0.18162559597722946, 0.13860519314485212, 0.17898037098348143, 0.14255334983669943, 0.15002111363555157, 0.18835008595018618, 0.2148587506024107, 0.16217872981102238, 0.09139674084801828, 0.13290819561769887, 0.20450891806713997, 0.2274455598765804, 0.1267475310352541, 0.12184581704317562, 0.18138725070222733, 0.19076962144144122, 0.17046672862864312, 0.163448260075623, 0.09157424342007407, 0.22037761736541028, 0.20097907602546677, 0.1749199977324855, 0.1479341215904682, 0.09103258095321157, 0.1842943858355284, 0.19060405451924572, 0.12683425984916188, 0.16572096715531043, 0.1547104910376572, 0.14076502482977607, 0.22102543663594032, 0.1427858115564431, 0.16803936371880193, 0.22116420580254448, 0.19060049987127706, 0.18275431928134736, 0.11804746884492137, 0.16775634019605576, 0.16644588551454007, 0.09635149110709468, 0.09163229756297604, 0.106108455858644, 0.10264540136220957, 0.06970428711464328, 0.08918863796298543, 0.11143447530846443, 0.21904620251828627, 0.1617755990235075, 0.12428523251606573, 0.16895906759365914, 0.14014643947443656, 0.14756770173628486, 0.3042512369011679, 0.21376600278721702, 0.1403845549230614, 0.17166328135757677, 0.11987983624661162, 0.13006145885634807, 0.173070615517997, 0.1034484070635611, 0.13163078996923663, 0.17779851182093545, 0.12919440054364745, 0.10038141236310044, 0.16973552834843436, 0.08927191172035472, 0.11006195218332353, 0.08804083140867372, 0.1680500583062249, 0.14533475461986758, 0.12911486529534863, 0.2672272800437866, 0.16753438920263322, 0.14561330418913596, 0.12514015599604578, 0.19211654190815267, 0.09060069888589845, 0.09456585506878554, 0.11981988986653667, 0.1468196781652589, 0.13232391567960863, 0.1622980556661083, 0.1527320383296859, 0.1763591705070388, 0.11793712920118725, 0.13944508597975777, 0.12756631814784583, 0.15285272782127704, 0.20586487837135795, 0.21089947031390285, 0.1270495458776432, 0.26133493009594183, 0.11972352366654143, 0.17404909365840499, 0.09290051781722615, 0.21812329639590558, 0.111584268480299, 0.1380317610117697, 0.08607714887588255, 0.3136293175480058, 0.1261225258631091, 0.09645986956574264, 0.12642621077717314, 0.07805765621484288, 0.10613966628067917, 0.09758790339072866, 0.2021506696098274, 0.07242665716236638, 0.14686147592240764, 0.25770925045494114, 0.16439520603706761, 0.10802345350384714, 0.18867391131577954, 0.11506921010873011, 0.07803931606993561, 0.23272735307053213, 0.18183487587638442, 0.13184511072693333, 0.1087352564378131, 0.1222538507934059, 0.09614843950276414, 0.12648620312252354, 0.10372454345586801, 0.2602120903470824, 0.15733130847013768, 0.14024143437704734, 0.18008116272188004, 0.2569636017564805, 0.11630542320950378, 0.10792152550552161, 0.1152191335155118, 0.12642690791718422, 0.12714869297680356, 0.181708088324916, 0.15150003105161652, 0.10373601179209449, 0.14798989279135583, 0.11960189188680342, 0.13730377830084295, 0.18297879836492, 0.18338729176790486, 0.1608845468370184, 0.13172937016333305, 0.18534731240041796, 0.13500263403740623, 0.0938901731804494, 0.15051167037698532, 0.1923256073026888, 0.2116660178909379, 0.12622198705831844, 0.2120532293713862, 0.15892780506082121], [0.03982276715818913, 0.06176947398231395, 0.011320190143681342, 0.06401567058938165, 0.04948813077663222, 0.04141542947881165, 0.036840026807640834, 0.02175382886742873, 0.03937819484441031, 0.01990817175547202, 0.01273544852606832, 0.025377943773844072, 0.018039499447050116, 0.04778888264310457, 0.02928944315851456, 0.027441575882896304, 0.020687122296001163, 0.0412442509625708, 0.0703165905490037, 0.064657851452789, 0.06088228670940284, 0.03490743978369621, 0.03183593857102096, 0.023154132255923845, 0.05021762651120944, 0.045236821601828264, 0.09136212133472005, 0.0728869074655156, 0.05625031227546354, 0.07900140758964323, 0.05125538836563787, 0.01314727153869406, 0.08206475571158432, 0.06484284636474426, 0.053935029859384226, 0.03705319843345112, 0.046282658022978616, 0.025548067003969225, 0.015760301687424223, 0.01669443291311543, 0.00579691406587259, 0.032818072866047585, 0.043271790754290364, 0.048655477472611015, 0.03407606967694817, 0.030105725163593892, 0.05353224381143528, 0.059890130069106824, 0.02048020769331244, 0.03605149633761856, 0.028470709672077533, 0.06952666962939887, 0.008938026336592533, 0.02077648070670905, 0.019249179092566335, 0.012652935110963883, 0.07219811015191578, 0.05986969467372664, 0.06482056086702694, 0.08485340002563693, 0.01947463876868208, 0.058155396742926496, 0.02260168518630728, 0.08697163313627244, 0.03483604421959289, 0.061267682561470624, 0.028204321748607104, 0.008749065004409322, 0.03511906774233907, 0.03290975060794623, 0.034107237964147524, 0.04428581920482459, 0.038720362804709904, 0.010827089032729068, 0.021741209484096018, 0.029761167543549693, 0.04628825046482586, 0.011839579561755303, 0.05499645233935407, 0.04616207195325725, 0.04368980279973438, 0.056487623331767906, 0.06502359714959899, 0.10230004892594392, 0.02155315213566346, 0.05176138177874589, 0.01768243927208166, 0.07081328365471094, 0.018069897815885565, 0.03914424308365391, 0.10330704851977288, 0.050199309348939895, 0.03506560629654316, 0.007991451448986248, 0.035315147946558656, 0.037200969133165576, 0.02154409123073903, 0.039861929572878346, 0.05267162829817784, 0.040138395382992686, 0.021877617184673587, 0.019580469984981804, 0.03510992448296278, 0.038386605109178254, 0.08166591501644543, 0.034600962479148185, 0.07470124881834754, 0.045944131430118315, 0.031943608398338964, 0.034257525262693246, 0.027580046275209998, 0.05416435061863834, 0.02309284522198141, 0.025208197842021624, 0.08060675249585221, 0.03438257762501317, 0.013679916193077882, 0.09858325844810856, 0.061103517580176556, 0.02130907460776789, 0.03415051044055051, 0.007958541748174017, 0.025755605968316237, 0.025727975092107253, 0.10726758519247656, 0.05363427523163058, 0.02230172537477507, 0.07769885893550613, 0.029867586732331305, 0.010962449108070184, 0.013713389447319412, 0.018950207534456448, 0.04198317340905628, 0.06801220573364727, 0.03143536651717319, 0.023997009003294573, 0.05656916956086794, 0.06710894210564514, 0.025102268949511553, 0.02130364304438474, 0.08553709519366104, 0.08585252423560427, 0.05623896651330495, 0.05967484404062552, 0.027296128344812223, 0.07040079127276136, 0.05669706793982656, 0.05746722379098496, 0.03771631264938943, 0.04380899458943356, 0.054075614654368935, 0.018970744436486595, 0.020461329371638356, 0.015899999735636577, 0.023355680412702987, 0.05056190642438108, 0.0217158998542976, 0.022679130929792603, 0.008144958710838712, 0.07527574581364471, 0.07091109010000383, 0.044849070029393326, 0.010471403027974792, 0.03096455186154814, 0.04045167554830832, 0.026514735899024436, 0.057365510297278245, 0.019019572965560422, 0.036757653203582576, 0.08009416306571615, 0.02641617102668651, 0.048286625289268074, 0.02947485175794892, 0.005509842247251542, 0.026462630428854498, 0.05629808934886129, 0.02660073309896454, 0.024822821142151955, 0.10397585859942822, 0.05382086743690795, 0.05985562163855761, 0.05013565510331143, 0.04530191609275438, 0.10068022495796604, 0.056580549796983126, 0.017538131289784948, 0.005969960400233827, 0.045525675053678216, 0.028238163682662194, 0.025948018526598334, 0.04669063431661456, 0.02295343828718028, 0.00848730808244117, 0.02613609119678938, 0.012923089314192053, 0.08002300115842974, 0.04807083747319637, 0.014748447968985045, 0.0198526150592032, 0.030245344687794006, 0.009860593465066726, 0.0486642261967063, 0.006112573891803022, 0.06992433054913437, 0.050255999855336644, 0.0641538460378445, 0.0314225536966396, 0.06627920759661544, 0.02783502714948789, 0.02044740380839475, 0.028099668392490958, 0.05907146553058298, 0.05136471677331194, 0.051233524216278914, 0.026666574525616826, 0.06471834941616943, 0.031185510771108732, 0.03387984774646259, 0.030176555737853054, 0.07213485427200794, 0.036139803292650374, 0.052315393582947796, 0.055634864050173954, 0.011567520672425387, 0.03030752421416823, 0.0022031819671317334, 0.028078874851006175, 0.0941494862819391, 0.007673448351617422, 0.012331519091892387, 0.04011708664737883, 0.08603197267098774, 0.04663875867282191, 0.1258035191905595, 0.09082011412829162, 0.018527771331249707, 0.0680826551791641, 0.15190040392260398, 0.01219395747137887, 0.06435268032815188, 0.015920426512527612, 0.04635210772375426, 0.07118731842286165, 0.04954491321357989, 0.03364534823284034, 0.01178733332292928, 0.01395737695988388, 0.04500918240556794, 0.01996193006033859, 0.010926713979232216, 0.023687823577934218, 0.10002066922043601, 0.04686545941137499, 0.0162989515135245, 0.01885734618671479, 0.06369109828806212, 0.022943680242244757, 0.08796079820322414, 0.06316427877473255, 0.062369554483842474, 0.0421822298648617, 0.14743257914820027, 0.015031606514727878, 0.04058255783973202, 0.05142963889445509, 0.022639907228069443, 0.06452389331834932, 0.05110590545941265, 0.035607487098464084, 0.05120468100592975, 0.03429579518495068, 0.026767207835350307, 0.012593041399433728, 0.03350737579767743, 0.021846215240657333, 0.014757645812125937, 0.05174628984663756, 0.07516068706829702, 0.032386566181817365, 0.03960848470488864, 0.034387691261907744, 0.02941708489801855, 0.061168715492972446, 0.0874389774136005, 0.03560419292038968, 0.02203199922317459, 0.03409165573576766, 0.05198710958563513, 0.022120509191506335, 0.06557072948424086, 0.0720169763230989, 0.023645202276266875, 0.019119183547914993, 0.05869564577756871, 0.05701693646129101, 0.06443681210399636, 0.07212340125753995, 0.01675987980448671, 0.04613240902882911, 0.0248270710149119, 0.02680386514252713, 0.011589839686489394, 0.027322073827587792, 0.026733538271078182, 0.018228997040780324, 0.0674834901527051, 0.07284258161821673, 0.025367000207845724, 0.024406314459479144, 0.013668701623476321, 0.023999301521407983, 0.035733048909253655, 0.02742531758192326, 0.045996903396782376, 0.022488514847692945, 0.02668620169823689, 0.05432433659030546, 0.057768143127642335, 0.0345760339780921, 0.11103367342823937, 0.016597653025641076, 0.02311552142454011, 0.030396541715749813, 0.03599349199043166, 0.0329615764560238, 0.04170930080656563, 0.04423872394967945, 0.1009853118129315, 0.03267073117557072, 0.03227985396440471, 0.053036098458593896, 0.025410330140843027, 0.009585549705661833, 0.04658142082212914, 0.017180885338494857, 0.07260820467866237, 0.04253734992216191, 0.04357872005071371, 0.025318575790151957, 0.08177770256635644, 0.03911975508315429, 0.06932785449128959, 0.024176876871816577, 0.058750317642284985, 0.04287286195904017, 0.049709089686192816, 0.05379942080546772, 0.03691770429272325, 0.044670353207977555, 0.044048726483578646, 0.03956579445530811, 0.009082710659582048, 0.227761157457867, 0.10393162468268026, 0.15141908620153705, 0.15840753942968386, 0.15868929124647574, 0.08914217473037782, 0.09751426701944682, 0.17802360377484755, 0.19451675666195734, 0.18149824152069707, 0.07907577940533239, 0.12086033685913972, 0.1318971127752335, 0.14127033642463147, 0.13248825686112528, 0.12728442077434834, 0.11940640157028554, 0.16649146774603477, 0.14683631759497429, 0.2913793663103735, 0.20495432158631666, 0.09220444266834567, 0.2123350577969705, 0.08102214835103481, 0.16629896517242157, 0.1108837883258539, 0.13526783835503364, 0.19119686867681243, 0.19218141423358073, 0.1806174702341518, 0.08159997016792336, 0.15817233511517126, 0.1112236402508232, 0.12179025268602757, 0.10476144346138162, 0.14065994821008176, 0.13972234852131338, 0.152494489786125, 0.07702002842580119, 0.1457974564043745, 0.1068660325460857, 0.10871231976536014, 0.2273383535324566, 0.18504980981590288, 0.044522180312102845, 0.12034581688743447, 0.147724611864936, 0.07101448898714396, 0.11359456746328263, 0.11567612794498283, 0.15542966373745473, 0.24446234918169438, 0.09833527578701896, 0.122682293125939, 0.12565993899179081, 0.22352436947966778, 0.1838246360421181, 0.23175716400146487, 0.1550841887271212, 0.15076014333434645, 0.11003202878900113, 0.2077341022630853, 0.10910169927463417, 0.26087218234615944, 0.08862087488054268, 0.10720988345001975, 0.11539823721132933, 0.19982232922507873, 0.11060013661100981, 0.12263051324313688, 0.09820543920561191, 0.1311285886913538, 0.25055135389970196, 0.14159819141270655, 0.20727763643428204, 0.2671562790149643, 0.11183221283699236, 0.11411692451445327, 0.1509589737942142, 0.10360456642604644, 0.09788173641408644, 0.18016884914569317, 0.26354993543317246, 0.1981049899252192, 0.18805269061798052, 0.37091240827595034, 0.07747408873852223, 0.1537230956338106, 0.18295756240765895, 0.20520706931429528, 0.2170228723797106, 0.16569101311747106, 0.13504607122271292, 0.12346811547514894, 0.20594686510101443, 0.12256696624981782, 0.14368967273302619, 0.17094141202828578, 0.11098068312651689, 0.10402178557048883, 0.1099448250005803, 0.18802803790857717, 0.183115100728408, 0.14313821200161211, 0.15062564893835975, 0.09110790271792682, 0.2157457578446596, 0.1123075167678537, 0.08503015183152692, 0.1409276806178593, 0.1244593489794962, 0.08814515726220223, 0.19548772714070736, 0.1452365727914918, 0.15211607299504742, 0.15540418365309316, 0.111447713307796, 0.34578883059082494, 0.13891481524032934, 0.1582123249048187, 0.16283709045139053, 0.07379393258522596, 0.13361026923502647, 0.10137113667423688, 0.14073467242621607, 0.10765200045200125, 0.06911465988284157, 0.25916089514090174, 0.0929477931030335, 0.13209084108952554, 0.1992940349924949, 0.07841682887726253, 0.12071985165558516, 0.2130151140473543, 0.1279577431118777, 0.09280409799107621, 0.17807840970495056, 0.1581156446087745, 0.06902251482730912, 0.1551613797463717, 0.09951556446932017, 0.25645156390964985, 0.13749871703405536, 0.1836475778010584, 0.13443340006614887, 0.1617171618366434, 0.21989375623243473, 0.21345477190709886, 0.1314622965911704, 0.10502272540883673, 0.11720565312932577, 0.19754358537254796, 0.14671319194378393, 0.16776234632538212, 0.16531089561120157, 0.22556308266376296, 0.08585207224372896, 0.14043883991337594, 0.0667045625948137, 0.12668086606408321, 0.13715615315783408, 0.1368601367838921, 0.15278350411643907, 0.1320365714209695, 0.11976993327299434, 0.12944521773005688, 0.17161388400821917, 0.12154499729794842, 0.17291373603286284, 0.16438471063250498, 0.1524569208343183, 0.11243816540246049, 0.10109254880057228, 0.24064925379089772, 0.08956131675551016, 0.20478949010852845], [0.05363836614114623, 0.09997206094164042, 0.05307260254818586, 0.04144611130017908, 0.014298041895662826, 0.016485097472585978, 0.018503923014166857, 0.018522573424683466, 0.13783430951016565, 0.0669335079709849, 0.055590369663531744, 0.011246247337229792, 0.04686955032089064, 0.03219433556941729, 0.0404864636009499, 0.03298486552892193, 0.013567014942846954, 0.004788584351885103, 0.06581331122546427, 0.014459924892552439, 0.027151623094875007, 0.02212038853265826, 0.023246777183826894, 0.05142429160074361, 0.10038485209788046, 0.046738162411436926, 0.031856781908220826, 0.03395072620121702, 0.025362221734418024, 0.03537467680871487, 0.04705758660190529, 0.0425832539105848, 0.03258924623350463, 0.020224037467532104, 0.02529348641063177, 0.026199015743669965, 0.04279926389215454, 0.04211622372930569, 0.08077405077675659, 0.039278350605238835, 0.05527958311440964, 0.010080618704969605, 0.09876076868104358, 0.032314810556389635, 0.024114496247362227, 0.014389917862811878, 0.006587883568323788, 0.08450591020406255, 0.03628865800677769, 0.03273166580906799, 0.1228779826253172, 0.022319061944501537, 0.04824515311948715, 0.028773245454255133, 0.023343562816960678, 0.07079259928075538, 0.007099967859234782, 0.028781088279379953, 0.10910330039839591, 0.04179562742431318, 0.022747071437357415, 0.017140694450767293, 0.05578289521978267, 0.03278668624378982, 0.049611712250137524, 0.019086720572123607, 0.04396510032576419, 0.06781879917628343, 0.032216398901636564, 0.05240533613569794, 0.009221245211759403, 0.03655300430592991, 0.05179007177151019, 0.004015442912444292, 0.028826373651803985, 0.04403797827000099, 0.10404921151817807, 0.0703889322316935, 0.08432227892861252, 0.09247719295202725, 0.03398113989181096, 0.028159672229160226, 0.0331733538018119, 0.04847938450233591, 0.06672245840872489, 0.035786230732957204, 0.05974329016622036, 0.022984505067729664, 0.04217759886335942, 0.04689242187587004, 0.05854062788609055, 0.019346935742144144, 0.03677449181615826, 0.03317601212690915, 0.025759530253708366, 0.06565599507021327, 0.021816912377553604, 0.027501951272208846, 0.03716680927262191, 0.043658791560559504, 0.01348892855833495, 0.06144232379512922, 0.01568325526726943, 0.03208462986344051, 0.05562782753258944, 0.02836776277681272, 0.03871942051656304, 0.0756026738353314, 0.04429219688679423, 0.024353222651106697, 0.06067442407290782, 0.007630116024595355, 0.05018468090002576, 0.05934987720402499, 0.043637103611423124, 0.030574061524783893, 0.03065370019495247, 0.0529879191890359, 0.053445668215112346, 0.031369772153876485, 0.06579454973219864, 0.0843266073253847, 0.013301240847325854, 0.05269138953618465, 0.0604583106694683, 0.049135316643984094, 0.0048550539706352985, 0.04101714802785747, 0.08226312651869752, 0.04143466594659033, 0.022163729956974427, 0.03699669561859581, 0.02560101517085587, 0.03727444462598332, 0.03158997455161185, 0.03760253710131492, 0.046264612821922194, 0.06933278809752196, 0.02576508822159902, 0.02090950804432073, 0.02402933791369921, 0.021538113829709833, 0.025604087183432236, 0.0344613314636292, 0.03850560537689636, 0.08079066722383423, 0.04359823231014513, 0.028503875533539443, 0.042718583342408946, 0.08329402039488477, 0.009762003694871261, 0.04723444566010468, 0.035810626802905914, 0.025094033504325538, 0.03261841120078199, 0.061569678251661604, 0.08358501889292272, 0.01988457624740418, 0.0202819345624096, 0.005820813136280425, 0.07715787828689621, 0.05712930623802447, 0.02121154012368812, 0.030993686185308525, 0.02377870650361142, 0.08849963380564606, 0.030418338832415404, 0.0525442470285681, 0.018567613648971724, 0.05546273175446738, 0.043787758632172505, 0.030579330294483134, 0.060751492518090436, 0.06629608451358734, 0.06961502254970613, 0.07600725252902316, 0.04886590267321275, 0.09293630944504853, 0.005029661209142257, 0.028122490151755275, 0.04587752008510213, 0.05329568352129671, 0.026360359606182864, 0.03052413940519816, 0.05189600257924007, 0.04877977523832552, 0.05276843116828992, 0.017808146639576843, 0.04132511920385784, 0.057245211510528485, 0.02145666336160033, 0.01753226114106515, 0.011390970922225426, 0.043902645007737225, 0.004920237040477655, 0.030906863525630008, 0.02507105852747637, 0.030357674244911443, 0.05619979643773648, 0.052499721998408924, 0.026095657076145855, 0.05254766761115002, 0.07652539609661026, 0.02553535377486579, 0.04432657125195669, 0.033544374013980555, 0.06521934793601114, 0.0495385968186442, 0.020714542498030973, 0.05397494304023924, 0.017393604972429814, 0.037637666063082796, 0.03756960681188972, 0.06441621199971245, 0.0550440302298915, 0.033130081325408914, 0.014431286610723024, 0.05127695374070637, 0.004566970437149247, 0.04119878747470437, 0.030452944939174963, 0.024910446278931155, 0.03498324418380376, 0.051221408535756414, 0.047061616224387, 0.010541205129195607, 0.041240788245153044, 0.06496597201593461, 0.036411745353571834, 0.045989732813811114, 0.043951027290595156, 0.057990235847330866, 0.041968920343225045, 0.022747239976700757, 0.024963520850325306, 0.03436368206636079, 0.030951832886785272, 0.031802742066042076, 0.008864276009731957, 0.036597916210490855, 0.022805797822412946, 0.04835164700184138, 0.026628588055891377, 0.015529194028086722, 0.01898124750192848, 0.030129370467376806, 0.03265661983600548, 0.04584958468894324, 0.04838669552437721, 0.05507746996778635, 0.020655569049619862, 0.03488448778948477, 0.06708431237887952, 0.09068313760743027, 0.11071497319085945, 0.02047728506788131, 0.050282165588390444, 0.06347034239180147, 0.015500667786616233, 0.06552582907099878, 0.0369308848354605, 0.03557243474548863, 0.03254681262337873, 0.04387734495403786, 0.061522425948491985, 0.04168003624785812, 0.07480804147499223, 0.06300467584702758, 0.047584360149959405, 0.04996893521878989, 0.03408491033159437, 0.040885158739383184, 0.07581454311167041, 0.019617971904095144, 0.08879720533807432, 0.07601961718812104, 0.03503169541457488, 0.03450733121304262, 0.03921031433668348, 0.0388487744625778, 0.037149694868393486, 0.03646559750420913, 0.01324684477426232, 0.0651831349598304, 0.013802918312590451, 0.03908094889934986, 0.018739573574895342, 0.007440668705385179, 0.05058443323979455, 0.057296290422879884, 0.04527734382258308, 0.01682791798826187, 0.027857329884183504, 0.03400741670761378, 0.028641428535563812, 0.006607124345347046, 0.013974459762985428, 0.018080341509513317, 0.01656952036184169, 0.04693672474053118, 0.03456899363006796, 0.049965039661694924, 0.016802547071429513, 0.02840764339893095, 0.05551652261807073, 0.03832523763600377, 0.025721080300788728, 0.01693012560867975, 0.023663425592765696, 0.05164067696539625, 0.03444009933680777, 0.023599428522791115, 0.05595960872127645, 0.0913644732246476, 0.05471649699874463, 0.015390152900269436, 0.09643415199412454, 0.07882347600834985, 0.06059897973412468, 0.024348714223672307, 0.01844413942777582, 0.04090399301100162, 0.02558730794267068, 0.04931996681637341, 0.02727648201999405, 0.04796140947409215, 0.03837294193104871, 0.08385697244516305, 0.04316403282686107, 0.029772586084061095, 0.04041267784252282, 0.05604101705455011, 0.0694057273287927, 0.02527613834958644, 0.040403745257325714, 0.012083161047719901, 0.04721579141914845, 0.01007846120985285, 0.1063904298409339, 0.030306899852509943, 0.06948915430374684, 0.0539083585083004, 0.012761780883245652, 0.04056662704134661, 0.05714728249116771, 0.031261998904688705, 0.06438228196554607, 0.027921970468014482, 0.051666877172406644, 0.01619494167126475, 0.043209086457688006, 0.04216804574694365, 0.12030874589277853, 0.2562346690965276, 0.0881832548146767, 0.08894185805993696, 0.08827604338406556, 0.07105831687729205, 0.22371615193063216, 0.09975711965272505, 0.24747986226312577, 0.16153074200114897, 0.1970102196379054, 0.060701279285093473, 0.18343128053651703, 0.13091295026242733, 0.12545068973615287, 0.10011865186595148, 0.1726299311004339, 0.1513163997761665, 0.07409838358721427, 0.13250964603597118, 0.12558166778856708, 0.2319247227522635, 0.13607783843913387, 0.16475024182469616, 0.13949698077574854, 0.2543276923918917, 0.1261581566124674, 0.1353468833070609, 0.1316906674013984, 0.11349890606417773, 0.1845730120135892, 0.2543306035260039, 0.185253037620456, 0.1680676170414494, 0.0794066297971914, 0.13374070336501445, 0.1712247113426847, 0.16983868974831798, 0.13603138286740551, 0.11943235662916016, 0.12024172086028323, 0.08576990165297063, 0.11451042557675993, 0.15262113944176706, 0.08934170233025666, 0.11675511682105642, 0.08805731762080424, 0.24003661327785064, 0.07867116240724441, 0.08202928584069014, 0.2327877667642409, 0.2809013059783367, 0.14547916219359444, 0.1275860372510168, 0.1040004117174014, 0.1089184203996293, 0.13948427903796398, 0.1250939685550909, 0.2249989661598398, 0.0866181371853717, 0.10780246778120918, 0.14244484114310435, 0.14834364155127158, 0.08768811686745576, 0.1214996065884348, 0.10880624980575616, 0.09809188965347507, 0.1324356572642442, 0.13197136201685475, 0.13404658695142116, 0.15532945943695886, 0.1445593204229109, 0.23768475399382655, 0.11370751946683853, 0.06989618447879631, 0.1651193429866145, 0.13992851810349574, 0.3384493711975313, 0.30853572151353287, 0.11238598715393774, 0.10783661231999436, 0.11416947048517967, 0.09893620281570381, 0.12699226548354473, 0.19745407565947504, 0.1884335435686573, 0.13435236328551847, 0.1687700124157052, 0.1891942841992263, 0.17077334765945712, 0.2724228577027398, 0.11800983094520147, 0.1372006475444763, 0.1735043898224831, 0.1691108296114591, 0.12038969840373724, 0.25205732954125254, 0.09748178489145734, 0.13710255764665144, 0.1664638579372437, 0.13849882949744502, 0.09336243819205031, 0.059471064652766914, 0.09487129432419616, 0.12461254358171456, 0.14271505567575657, 0.16655114599533621, 0.16555898552460058, 0.267419568112781, 0.12893687242702132, 0.11388355881095895, 0.08465424780884097, 0.12290841929854886, 0.1384170879159243, 0.14249316596936795, 0.10860222526976179, 0.14615986195783462, 0.09758287019306615, 0.20394005181808628, 0.1334681752468309, 0.10445952821042269, 0.19657949436335795, 0.11436082392690644, 0.1708753905709713, 0.15220481662019608, 0.14977881534686013, 0.14316580648864471, 0.08415408432483674, 0.18459069332288158, 0.1882394475321616, 0.18824407470322427, 0.07022317378751694, 0.10142001308380597, 0.12581394564720894, 0.12863347096548927, 0.10632977865996862, 0.148078590451229, 0.20233705880180483, 0.18001161726011386, 0.13342308331160777, 0.1624935306608677, 0.1870735996072331, 0.17287595257643731, 0.11816712411781473, 0.08821782836269948, 0.1030116756596873, 0.09679179248069564, 0.09558041595042714, 0.15007685419292222, 0.1583888622060899, 0.18715863536682822, 0.10150465047768048, 0.12168529864040115, 0.11018587456595515, 0.08649544054341894, 0.19354901907424774, 0.20547955146720334, 0.07815075121940145, 0.18389569835797434, 0.20270904045431845, 0.18782640356690655, 0.17596840437862182, 0.11373090813116682, 0.12245890188721881, 0.1079821766864869, 0.10998013399301038, 0.1540735808591689, 0.24581659344896195, 0.13007630564032063, 0.07445051590160978, 0.11443901852133775, 0.1193276477316695, 0.15182048563034306, 0.12954678566705796, 0.1547409200500096, 0.22171505366361913], [0.002593926309923371, 0.03721088997178501, 0.049005866936978795, 0.11696029814981646, 0.013190187784212251, 0.025187883105489518, 0.04109824992596142, 0.041378550006136786, 0.01601398404267046, 0.05052461326422711, 0.02327519521537808, 0.041458981577306986, 0.028710981658209237, 0.039905933663249016, 0.021429319768362952, 0.02976262885626526, 0.03708479572988806, 0.07262932572273478, 0.01049636600298747, 0.030552245255920197, 0.023606277348834182, 0.07827783754516034, 0.09798414704780425, 0.04813929125967045, 0.06413976534179623, 0.023660577660907182, 0.023207591786499948, 0.042468087912927714, 0.09241339314969317, 0.034073468808445244, 0.05190422653310722, 0.041529515292495496, 0.016593472100794315, 0.01560732254743456, 0.02151053083399611, 0.05766609255524893, 0.027994438555211793, 0.0180629781267095, 0.014603417948819699, 0.013984010964181396, 0.05985005984022733, 0.09150563258557551, 0.043695950655326735, 0.05289102821881252, 0.02083398901196497, 0.004678995474316781, 0.059996083859474435, 0.06430673037445353, 0.03184693193273439, 0.07089328621664355, 0.024665646713166952, 0.013558941333734942, 0.06468828046514143, 0.0073650630093329865, 0.027078070993264838, 0.043071018261534554, 0.036454098524465677, 0.022631566445793838, 0.051396509422169584, 0.08981401851821331, 0.027712393709788882, 0.027915621514342008, 0.08448695718881585, 0.024509807192390005, 0.0637221440011936, 0.020740556928719726, 0.09377236417945355, 0.01919049675756645, 0.03537250494944953, 0.05409398161235356, 0.029119295030531865, 0.046866325090729424, 0.02224447370897378, 0.029695690008661443, 0.011102054268121721, 0.03912658858743887, 0.03021590967452334, 0.04332648943208399, 0.04579417737981966, 0.029565922375167572, 0.020474969567130172, 0.04951623088169483, 0.04232060832662448, 0.035289166074606686, 0.02456250638070126, 0.022211710043672114, 0.054502593758966655, 0.032976001891638004, 0.026950565234367407, 0.014871924105400761, 0.067007941073708, 0.02223084308958102, 0.024089682659494783, 0.02475801967985688, 0.013745772941488654, 0.02117592852652794, 0.04444214327621364, 0.036148793334441806, 0.037542035307494864, 0.019072243425574516, 0.014553587759784875, 0.015891506693386022, 0.04316214442012772, 0.029880388061546033, 0.005711113175963082, 0.007820927937920656, 0.1526785960360881, 0.06029701851789029, 0.02479153794176396, 0.0705274026240072, 0.018022480803812226, 0.10484451803589061, 0.022844711258526773, 0.05270839668810368, 0.0564178059087886, 0.036607584240095276, 0.09288750198339263, 0.008502916166288479, 0.12807761288938985, 0.04057094777723955, 0.00784318566495072, 0.027099592318277688, 0.04579687400931313, 0.08283629818188568, 0.01826982186626523, 0.007736218244498296, 0.06687438130498895, 0.0783498498100427, 0.05961428479021115, 0.018252006491586086, 0.02479582420370031, 0.020634869353905804, 0.04609610795253708, 0.05594576168204508, 0.026065862001550776, 0.06473273654738743, 0.04201434935713488, 0.05033576876045235, 0.021890960521094745, 0.0986228728546731, 0.03493017344284923, 0.1316302843512066, 0.07040633774933315, 0.008343744163040914, 0.012667866164608108, 0.024914418444818547, 0.005260917298015087, 0.016903063552754543, 0.03770371050303502, 0.05746916965431264, 0.01630545560000164, 0.028299356870833906, 0.025337883121063633, 0.038129954163225434, 0.04440360905362233, 0.019500289307606798, 0.007061199979826569, 0.0242736874028079, 0.017281087723770933, 0.016961054493402763, 0.09014909771541435, 0.05866938045308475, 0.040151610399686524, 0.03228057025661392, 0.008062127369245695, 0.01860673967448454, 0.01455275846960684, 0.0391486251065808, 0.025437083846378713, 0.009963990436987051, 0.07025939442457692, 0.03880571266035399, 0.027337357281677188, 0.024746187451866367, 0.14463634290281804, 0.016053327445631788, 0.02575328855234529, 0.05598927930658383, 0.02452214312319073, 0.044086735935941826, 0.029025600562172554, 0.017040469082853487, 0.01992071069957268, 0.011715628450826533, 0.033361780787667925, 0.017309482772684386, 0.05854669530245085, 0.028550562846864906, 0.06074211560189725, 0.005136977199600229, 0.009812901618950551, 0.012157325062059588, 0.02568543997533139, 0.0629036863064093, 0.034743221176247445, 0.020840678874763752, 0.03496150260851268, 0.083317217537232, 0.09821205054439845, 0.06199762262704392, 0.09610527044823093, 0.02010928515735413, 0.07552291642153457, 0.046301381211848035, 0.06281522230335301, 0.03635607374411437, 0.02862237975932658, 0.09219257596639857, 0.058829443033544294, 0.010615513742631002, 0.034185842415618325, 0.017533948449718378, 0.029548064865652594, 0.050868238172223496, 0.0187085144552252, 0.007758029246507514, 0.04883568050459989, 0.050386039450043635, 0.04153105895966292, 0.04762512368841037, 0.06821782373252415, 0.02941658885608758, 0.08458654095809306, 0.056280576578912236, 0.058804840119856025, 0.044973272034117294, 0.039965163751114766, 0.026388216478329514, 0.006366154261594338, 0.12344736981415942, 0.03048183219957977, 0.07861179825399192, 0.044544224492124015, 0.03871732526609013, 0.03232610269239353, 0.042577251611698064, 0.05162560035504642, 0.038250314237009135, 0.04040042043573434, 0.01984281487943184, 0.033330669957062894, 0.051322467024287874, 0.029810856006318526, 0.03192986286575756, 0.015717737842351198, 0.062864615822271, 0.0039515954690174234, 0.030940722696663394, 0.013006133245184057, 0.046597531651176756, 0.05581340084092752, 0.028122524625711867, 0.1205947188540332, 0.008824300584233096, 0.049053008157399394, 0.04882680920643672, 0.018616997591790654, 0.06869356433350234, 0.03155738900175258, 0.06358293433403296, 0.06561333929458935, 0.04208906208195033, 0.03782806572534385, 0.03717163562654488, 0.0598268780196386, 0.04607487965615527, 0.01644830801524222, 0.051617767106020646, 0.04950932842949706, 0.02894116426637817, 0.027082529624984152, 0.02355800997916489, 0.02353066830114732, 0.0320971745532006, 0.03752784352869757, 0.018630637787282467, 0.047664776399371125, 0.019617920193160256, 0.0171253401335449, 0.025377162364161304, 0.016594287984433676, 0.02894310055360679, 0.07988438520941042, 0.07276790336735788, 0.011869380382009813, 0.0017062123515643182, 0.03656374868906794, 0.044658375423281424, 0.03011632399002631, 0.05488272275655501, 0.022558874277878675, 0.05256483181109352, 0.02568568895390678, 0.04762702741690221, 0.05390016519795022, 0.020723285476466822, 0.042626346356325576, 0.003268439674772503, 0.040420354043524113, 0.06350217717549493, 0.017321362881170168, 0.032148776320560325, 0.06143324182278687, 0.040881198064814654, 0.06108789704740048, 0.09664127918621225, 0.04878532554533693, 0.03328705657153361, 0.010288224702009992, 0.009873489597662082, 0.019910121449239312, 0.07241739515936182, 0.012732951079435166, 0.021013887524003946, 0.01733710598801413, 0.07512654252951184, 0.044120087573725375, 0.06965611550596452, 0.06551206247099946, 0.012503524983091461, 0.03207263292654628, 0.03185985775123681, 0.0673946469361263, 0.07897159144763025, 0.01345436362880132, 0.052027114697041056, 0.04532114106921419, 0.01713388775956006, 0.01833849207257792, 0.020660188559803273, 0.060863536707456076, 0.014900537489372638, 0.019914547522221843, 0.04779227641260913, 0.06991989490005278, 0.02843659003114989, 0.04366755177597365, 0.07323467307874272, 0.00860215136556015, 0.05402438252443268, 0.022306909874802636, 0.0423414612399234, 0.040897419976611296, 0.011960336086039823, 0.04922967569361772, 0.04513107465520021, 0.05438672679085886, 0.030144843528227463, 0.021044523380095922, 0.021936358891487606, 0.030066325261648146, 0.013944711611275713, 0.1465121857942112, 0.1457366596667036, 0.17312131521682586, 0.2583079634895248, 0.12881682644928658, 0.1392914393856641, 0.10375834325508726, 0.1148273255075178, 0.13417092302153188, 0.08567565751652564, 0.1181240546547117, 0.1277118365490629, 0.1015190452697777, 0.11347539482578156, 0.09365350563800143, 0.10342065935894366, 0.09130934553761637, 0.15058872350040944, 0.242964172315213, 0.10166080217928657, 0.14553580673471575, 0.32128526318457823, 0.237119993976047, 0.11300292542024006, 0.1424540648417127, 0.14697666490270248, 0.19705020942755286, 0.13574983023347395, 0.18611093352158226, 0.11158780780650916, 0.1343007749246974, 0.15444499560661856, 0.19796117990007325, 0.19277655729843726, 0.19749693061795928, 0.16717564554945116, 0.14404172077775002, 0.1346385277687542, 0.09351800766683395, 0.10809176556405523, 0.12891467119897568, 0.21463051768800906, 0.09424262725177313, 0.09069507325729055, 0.2017282793718961, 0.13528979443494352, 0.25060600661222016, 0.13606368113429318, 0.1407962965388452, 0.14690669043169868, 0.13747751172031128, 0.07994296795298016, 0.1247607739341836, 0.17283000262273898, 0.1209739093939143, 0.13291800154312966, 0.1373062910692346, 0.26772250992155844, 0.12513122341084865, 0.24047907501939805, 0.11672907749251013, 0.20001745181939296, 0.1501610778993176, 0.11853818646481923, 0.2090634180292968, 0.188133099206513, 0.13114060095000651, 0.11146318828386646, 0.16570636551947365, 0.09768888144002807, 0.1157911483859343, 0.1290157794832222, 0.08362981205385539, 0.15177908623891492, 0.14225203213432144, 0.09404522171544452, 0.249615439604367, 0.14640042888781718, 0.1740743132728723, 0.1870831603845281, 0.11245255253367847, 0.11628281595485827, 0.17349223966800398, 0.10209690539106246, 0.1428747237209351, 0.11711435077051002, 0.14089502995052647, 0.11406222583665965, 0.12530722445057285, 0.11653172558233624, 0.1980981717426931, 0.12082684349509017, 0.11599587772281901, 0.10540888734882879, 0.10054700992881291, 0.23852118411131445, 0.18611188347060836, 0.07366313839391356, 0.15179214037714467, 0.09350313790022366, 0.06604388070803496, 0.08358407660477585, 0.12589112134470096, 0.10313356790931956, 0.14295517827474302, 0.15507583836874655, 0.21180480237930052, 0.23511777722066451, 0.1035576512015635, 0.1862128845025455, 0.08514348687904497, 0.1915105816818053, 0.15790507768190679, 0.15870245263701485, 0.19631416747166267, 0.12728000044702523, 0.14285217009244427, 0.21895286236559192, 0.18825401852448143, 0.11054168410238721, 0.11577447831270196, 0.1557537955382178, 0.08485143117967152, 0.19886712483581037, 0.15914796340850093, 0.08051034033058152, 0.1604029839678157, 0.1704453394537972, 0.16388253999813912, 0.17233503321486135, 0.1565045463822542, 0.106262018183066, 0.1622590617907624, 0.11927512474358083, 0.16568816327039274, 0.1773867242398762, 0.10449197203401597, 0.10398302918239948, 0.11062766981100845, 0.1973955312203015, 0.08786418685509313, 0.1657433522444579, 0.19756224727438343, 0.1845766279485918, 0.17097974706801677, 0.11885917730509274, 0.25878820868749774, 0.158932815275846, 0.12303132278424118, 0.11836312005236266, 0.16139866844300302, 0.14329647044500998, 0.07575110337066074, 0.16806691224055906, 0.12065654981040186, 0.08113248033388969, 0.1318105448397898, 0.12005256609089913, 0.19011161320151823, 0.1301477663218975, 0.2884610616151364, 0.10426841225595244, 0.09816988506504605, 0.11564025204748878, 0.09048893431862516, 0.11983439957182254, 0.1308028940712252, 0.11647220821149888, 0.1889035231884449, 0.1469357558075459, 0.10910412777335414, 0.11083064480654656, 0.1518800413055766, 0.08202073629945517, 0.16755363333129114, 0.11556232558383096], [0.05981509175692355, 0.020918748979907364, 0.03772426081160384, 0.028157879583417412, 0.05567597998907009, 0.09837007916141903, 0.036268234102716373, 0.019804110202277382, 0.13604762393140024, 0.03297753406748657, 0.03322841254092994, 0.007508179724907443, 0.05772083719831802, 0.03271091631763885, 0.03634890316114311, 0.0380835943524876, 0.04898690626085286, 0.08960019571766739, 0.06594284137170162, 0.08625826738294094, 0.017377643530527433, 0.0592010454725354, 0.019411997674333475, 0.030094760530177626, 0.009131001969498974, 0.01281403861339054, 0.06682126842919858, 0.03228055876529506, 0.03364377775259557, 0.04219883482062048, 0.03355695317769724, 0.051351314065076654, 0.02758108815478702, 0.03325404967331598, 0.03567514032305729, 0.03681484166713011, 0.006220727312123224, 0.019956038844200875, 0.06256259331900267, 0.015242271117805956, 0.04863019657110976, 0.02454101378398557, 0.017083517478538618, 0.012632977562926471, 0.03358245624469654, 0.027244566797068524, 0.019664544304231965, 0.012402552679451484, 0.05131236998544586, 0.05369093126407074, 0.04349305226858105, 0.04174171781708156, 0.02204096628232829, 0.03892110082350912, 0.00629394089863185, 0.029489639170107343, 0.08437321611469792, 0.042215125680330305, 0.027032860314413428, 0.0354238634838933, 0.05237865329329526, 0.045080037877684644, 0.08421233765059903, 0.01078410192407788, 0.038486357417798815, 0.01530219738807289, 0.06640453958102772, 0.0782369897370377, 0.04726987339616303, 0.010794603074299953, 0.008782057538478365, 0.04016077281126092, 0.06037632010937218, 0.09203191200691847, 0.032792803455865195, 0.009647848933274228, 0.014935914472106003, 0.04928420200162838, 0.03740143136031205, 0.026533822979657885, 0.031249015629591963, 0.006732926516222858, 0.005746703705705342, 0.03633492971740423, 0.060623651595726136, 0.03026452752941799, 0.004117852827954677, 0.0530840287495765, 0.05275646870535228, 0.030636852006277734, 0.03106627876179353, 0.027066037667194204, 0.021144775561087077, 0.061359390946886236, 0.06592784137014421, 0.02850397129452998, 0.06026214236513742, 0.07177404218143033, 0.0847414286146241, 0.04695732484481508, 0.033348887527902285, 0.05257002971765976, 0.02693284179023918, 0.049335955071353146, 0.028694430328605157, 0.032630975042740186, 0.06849886308754645, 0.01899424992922333, 0.06443019310433058, 0.045267660471220175, 0.024973137168994835, 0.0645824147748851, 0.03747167396208933, 0.057865397989629745, 0.027084259068473216, 0.05154988022461053, 0.04955638538024599, 0.056744347056073535, 0.01654660858724627, 0.031187856915376844, 0.032120369780328006, 0.055957298966184746, 0.09205030577798044, 0.064585724274718, 0.0565037303303759, 0.021988201976543473, 0.05462534785751374, 0.08623821886196252, 0.0300247956352729, 0.09121441958291877, 0.04070295238747232, 0.011341146478850034, 0.05223036931467153, 0.05258067450936764, 0.05253654784492908, 0.03734140837144467, 0.017264084402291525, 0.028676049964081858, 0.08097821320857733, 0.03684878702305498, 0.058551180747247515, 0.11021732247524685, 0.06700945792779808, 0.021521957035386757, 0.027165418423171488, 0.023738858440229972, 0.09180896509919437, 0.05640542975837185, 0.02263307563900467, 0.03384037123572442, 0.022848656611336816, 0.062486283300865086, 0.013200379626434899, 0.02815236183514278, 0.036144924590424184, 0.042748958728606665, 0.01893787351887553, 0.05413316700968051, 0.040043676272034645, 0.050160916852614576, 0.05404885520317382, 0.029929559414965973, 0.01029732486894054, 0.05794252389140668, 0.10708427567395473, 0.01064906552088477, 0.005642226549811782, 0.022791816717794827, 0.002614867802138531, 0.014919597756928735, 0.03942964530940499, 0.02034789664790996, 0.07238086808713214, 0.05217548294533646, 0.01666668137805837, 0.0381787731162002, 0.05432858837828521, 0.07266457342813093, 0.05400365601564127, 0.0057741962072830055, 0.05646703854924249, 0.03358398075966585, 0.02135196595542854, 0.06657951406293339, 0.04553604022329373, 0.021373508347859307, 0.009823975419896025, 0.03597793274468953, 0.040726023125312025, 0.0653358699092942, 0.03086514046205388, 0.049655294992149844, 0.02745183763064204, 0.073360541324702, 0.006048697001871563, 0.060101742705991196, 0.019552864006630356, 0.014690688769933919, 0.02625141615769075, 0.02683639898145151, 0.01352202068383415, 0.054654800107762705, 0.01962628778851321, 0.03641408958262013, 0.06845662866028086, 0.035742054272803574, 0.034461182076483965, 0.05562503897254506, 0.046576249728640245, 0.05682090222234688, 0.02052782005780647, 0.07601491340826597, 0.02901024624495016, 0.04896364017059246, 0.03052346524782479, 0.011920164350510366, 0.017809334075859478, 0.07324644785013891, 0.0597459638130761, 0.02087724616660947, 0.07535140465704665, 0.033126622438430786, 0.040594700333331867, 0.01783033637630363, 0.04704274747881198, 0.024772190391236258, 0.03871843609358034, 0.045806388821332686, 0.024444712701463894, 0.03079591867243571, 0.0461310836967201, 0.018645005766302347, 0.03774154758561523, 0.016304145589651122, 0.039943035301421924, 0.034593619526393955, 0.04241332411766053, 0.08103224538987683, 0.08290410462406375, 0.055458001161534945, 0.07789805711757752, 0.02667817118157062, 0.03754921355134538, 0.07502439236568828, 0.030251584473937273, 0.028774342875206665, 0.04282850929866395, 0.05135178520915009, 0.031213072699404536, 0.04568389519267986, 0.030767973700177767, 0.029397078511875965, 0.035072324887639096, 0.017841007981088855, 0.05754716123544401, 0.031308081008553985, 0.048181583143530354, 0.010903942015682979, 0.05381299205304635, 0.03232966500124143, 0.02512471724091278, 0.06572655942891875, 0.019044413366505218, 0.03727048395141479, 0.057570308582076145, 0.02427300941499491, 0.05301374018252377, 0.021208042932313778, 0.0330742028722119, 0.03344371389116972, 0.11040607887891032, 0.053842647316595244, 0.07770399938547805, 0.016136196134011113, 0.03324049374749584, 0.054171210936000275, 0.03130161139603344, 0.01066166862484909, 0.02132279141205213, 0.04941021197385365, 0.09207727207291512, 0.02330677719005654, 0.045932896750708746, 0.03862331861690168, 0.03393667614868572, 0.016413316949300708, 0.011397353392244588, 0.011215866205372639, 0.0367498008023587, 0.08865263688588336, 0.022536615593238704, 0.021625964962426695, 0.058085192445545435, 0.03319535967743686, 0.04819359157174345, 0.027011706711604234, 0.010128846812632777, 0.018878695141944676, 0.003290836973446271, 0.047691555002764355, 0.03303392579959285, 0.007922337390482426, 0.04686667366073497, 0.012693924645352508, 0.04870395168601986, 0.06043771439562402, 0.011809615947816883, 0.011950756156546696, 0.02308897073230436, 0.052721864513812534, 0.0715937050840547, 0.045236798619190534, 0.028940622259171742, 0.0340265535839623, 0.04005281953141093, 0.07876528396962151, 0.021118334036380536, 0.04321094039046476, 0.07307664446172214, 0.022094703519776947, 0.04889398745651688, 0.04831901931714627, 0.03244984887480255, 0.056014357194785154, 0.015766478271313732, 0.09134633992347987, 0.015088148591589304, 0.027802644612928553, 0.052592169658671466, 0.01414173314603226, 0.006878639791055673, 0.017791932388659448, 0.041147873271256685, 0.07128966010866628, 0.06631458553695871, 0.009324413314912348, 0.024773764701920654, 0.07247126646219723, 0.015375464121931264, 0.03789523248410514, 0.03176119520268854, 0.04212950003303347, 0.02025527853308426, 0.06446653631545844, 0.02180980499683609, 0.014491629441298786, 0.04279326542370743, 0.018310717554883133, 0.0540625796683373, 0.04378985388264541, 0.06122888786898506, 0.05276511400757779, 0.17740840452813333, 0.17837730656948783, 0.08314585899032893, 0.12714676243523437, 0.12637516633877832, 0.19963100642686893, 0.1380579612187801, 0.13498380359622741, 0.3718792725234263, 0.10592847116171353, 0.11572321936968835, 0.11516352319308829, 0.14501486694620502, 0.1116943399932596, 0.09558452984258052, 0.11288402091351249, 0.14173211890362925, 0.14183293607446457, 0.10345907866834633, 0.219637407891212, 0.11665279811788952, 0.0880632701239759, 0.08019300372970682, 0.10952485560048973, 0.08756650807035547, 0.12853372631774795, 0.12544607022596946, 0.11324689378060641, 0.17175294428823457, 0.14010228216648102, 0.16077658972672879, 0.1203777704147562, 0.15415732959105125, 0.14769130236198827, 0.09562322494363594, 0.1675899918641775, 0.1439979924790321, 0.12791746220881903, 0.15017330466258913, 0.08469511859960134, 0.11066600485073944, 0.12692655812227918, 0.12212014546798122, 0.0579343305810565, 0.1270789713148148, 0.08391135702690772, 0.10505140007984255, 0.10600325666488179, 0.14608955040814417, 0.1420645857410085, 0.14568294158145306, 0.2042269517457293, 0.14580209889719564, 0.15281342751076146, 0.10082797267504277, 0.14803674672880482, 0.1427109647662409, 0.12268682070557149, 0.17620402238061353, 0.1633412529143595, 0.14318109760361333, 0.11040488378174844, 0.18354383417435233, 0.13362710784760215, 0.1751176177734329, 0.0711622367042207, 0.22479376184844205, 0.16604771897677453, 0.23412043799556073, 0.11702574504118775, 0.18898442207324892, 0.12306670072458445, 0.11410204708696374, 0.15612268219551734, 0.11516135516426257, 0.14334664920405035, 0.18786552001632031, 0.12986586128752078, 0.22721443114982498, 0.15141269702824856, 0.1685309623398127, 0.10721526904812745, 0.09793346267073386, 0.21141798926457284, 0.1558141632666511, 0.1497434986935508, 0.11279156176193107, 0.12903965078294277, 0.22437566170288673, 0.0589223311943633, 0.1195925456141272, 0.14764797242899097, 0.13894705222018305, 0.16007586442414792, 0.17051600340393283, 0.11746328849826129, 0.2973482944071293, 0.19724516348252374, 0.17738601943898588, 0.16321158487229578, 0.18152765929698947, 0.17098175421837838, 0.12538346552079724, 0.12761146370922366, 0.18059764387867144, 0.13206856325268745, 0.10229386659639497, 0.19342399352500517, 0.14582518878723347, 0.07224396051418397, 0.08455295566349261, 0.17055919544110376, 0.2005410422721217, 0.08907540250689754, 0.11524269071918343, 0.15572894364595413, 0.20034051109706202, 0.12815825896517885, 0.1782364842872466, 0.13461327751076993, 0.1923942794242213, 0.18637426858467443, 0.13751014706588563, 0.16597860252424596, 0.17938258246548716, 0.10381745459932475, 0.12631138185820273, 0.1598855068967227, 0.14746757404458138, 0.15215810057857346, 0.10933459766449467, 0.11648250443320121, 0.0995543898053227, 0.09129739456599759, 0.1645198945076235, 0.2234531233027097, 0.08063505178377514, 0.1704381841925844, 0.13229523334772358, 0.1480897753349235, 0.10185397891027313, 0.2280621380815583, 0.16371455223810288, 0.13541875767611689, 0.17823672943538238, 0.15792490403738715, 0.16664278543283864, 0.1285671124294881, 0.10555225304297863, 0.20601346878515137, 0.10433665536824735, 0.12748037074362079, 0.2100303895290821, 0.2023343162070359, 0.07847318996585186, 0.14084924853617145, 0.14292350819995328, 0.13502400789049365, 0.1440354695002879, 0.11733037224339864, 0.09756446110024568, 0.12375790355426651, 0.10591318770762413, 0.19964335576420833, 0.14840350366167485, 0.11830050002543196, 0.19152548975281178, 0.1608462117972874, 0.06257995287136686, 0.13043319536072592, 0.09505755328122648, 0.10696668883845692, 0.13807064763480617, 0.11577563510546762, 0.12668910917014847, 0.2413029106514108], [0.011413277487360663, 0.04474540301147969, 0.053708620234242374, 0.03813390717691472, 0.056539253827424786, 0.040310213582650314, 0.04856854564540329, 0.048783552051792224, 0.03851151957567181, 0.02481685523244162, 0.03477543134302382, 0.11992128926419443, 0.018449118999283642, 0.018803739184213263, 0.0629169281361805, 0.03649743228790261, 0.024503691895534436, 0.07919006440187655, 0.0836193626145682, 0.03665056177264741, 0.08029158392380323, 0.026275111257188746, 0.03408999332497197, 0.06733262445777655, 0.02074963124018283, 0.007600857690352226, 0.07466789335012436, 0.009008007510865649, 0.05821340875099263, 0.01887392432939622, 0.10617986291406617, 0.025197901620319294, 0.035409664044216756, 0.07480402717426901, 0.025616382894616936, 0.02677254172252311, 0.012767021882257635, 0.046313194287640434, 0.017632925094315605, 0.053501791816445134, 0.10353378756272216, 0.07195542115838298, 0.030610247687887282, 0.04169497879282121, 0.034095708340887106, 0.032789298603611614, 0.10009958393751614, 0.011293172137811782, 0.037140003856151335, 0.07814235489575133, 0.028642822815586003, 0.03699167008181253, 0.023254537654499856, 0.042948490158925136, 0.032042021968311844, 0.010835327350744798, 0.06431092087539934, 0.04073751444417623, 0.05128566799084506, 0.031587953994711565, 0.01608667429536581, 0.018770582898850405, 0.09441020898520948, 0.010035911728928407, 0.054373936952963, 0.03861766105758087, 0.039082841136522835, 0.0384887361208037, 0.04599100451976542, 0.026560647548326564, 0.010634168941197137, 0.05839097261008236, 0.03692568692889425, 0.02467126596809155, 0.05440246223682358, 0.06910607969808964, 0.011146821573586955, 0.06197030010122446, 0.06666069640026939, 0.06105126655330101, 0.056258176168006276, 0.05484960094514874, 0.021859589220595457, 0.03129616259567199, 0.06514479225922017, 0.03963664226654557, 0.07730241609557022, 0.049706324108786164, 0.025513026142312635, 0.0725275662637526, 0.035999318089095816, 0.031040965301555493, 0.036146200126818115, 0.024636431950174516, 0.04816097920880683, 0.020251790917808973, 0.044973735517311486, 0.016846315589763464, 0.01886603553899594, 0.0873148405263501, 0.03741299545752906, 0.08648658456701426, 0.04992608409074526, 0.0659549915261807, 0.020390180870890617, 0.0433542677802184, 0.00548528146839911, 0.06888047446526828, 0.05727893087051569, 0.016350949731385036, 0.044505732404368545, 0.03577488497079861, 0.01761745394868476, 0.052694457718321396, 0.0178713699607479, 0.058475636817034216, 0.024751488780302387, 0.046197495858875975, 0.009370435089353592, 0.009240088101866986, 0.05819160971910723, 0.0059053322653316205, 0.013970397581766932, 0.050592852546082395, 0.0247254322147778, 0.009560761973261833, 0.029048004803518136, 0.0986087155498324, 0.035410437793020284, 0.0033882038757926036, 0.04524882236916212, 0.02582195684343817, 0.027111918672979362, 0.027300491215541, 0.02158331301724238, 0.02684477998334314, 0.02134081363047083, 0.07096925149521521, 0.09354596987607018, 0.04916787155032639, 0.04024072557747845, 0.020788002669090228, 0.05373167565032359, 0.034124999712671966, 0.10352313127969542, 0.06250561169919468, 0.051450959121387814, 0.04267870846595015, 0.05730973909639063, 0.01566038275468013, 0.012203634119472437, 0.04904269278349896, 0.095489795409864, 0.007812770537941927, 0.008294607283577563, 0.13533574438864185, 0.036214646252412955, 0.025292963555623448, 0.03599511992727076, 0.026844245637015953, 0.07641943081492379, 0.043940374838008035, 0.02591889952459643, 0.02394310514172239, 0.03706528730089626, 0.03323692377776869, 0.0742148136299464, 0.03904719889584569, 0.016414751448938926, 0.038066686791998726, 0.08666617855910333, 0.025234589571013086, 0.0831109713462572, 0.05022340664459814, 0.03427790320147911, 0.009727214684619779, 0.037831260311988094, 0.016062291631955775, 0.0632888331799017, 0.01776049788590641, 0.04567560612133915, 0.04419947726531856, 0.04459860524342907, 0.010688253791041432, 0.051247486168698925, 0.022374746960497672, 0.026662807288249175, 0.03538271307104057, 0.0306928108987068, 0.03211366076533112, 0.021921902812356432, 0.03587320852544039, 0.023019381220482533, 0.06070858776389111, 0.014210006901844135, 0.07626665756106377, 0.1001370532978927, 0.03892844760670297, 0.03513935375057402, 0.035279452079726804, 0.04171898032748892, 0.025365854906398925, 0.025015586100879218, 0.03184618882744784, 0.10636418366864805, 0.03200437066205327, 0.15168579205149604, 0.01963820045573577, 0.02302464999018177, 0.037167088894714276, 0.049708783251023105, 0.033494145459225105, 0.020509050903661598, 0.03316029583314254, 0.037939684735911514, 0.050180501890398806, 0.04169496730150234, 0.038275407446968945, 0.06634843130145343, 0.021908042366586385, 0.03971214023148341, 0.026971280251839952, 0.08014860127361552, 0.015419493110159473, 0.05651238712392027, 0.03899197544782393, 0.03203766867368212, 0.01668028518437378, 0.02080840933617325, 0.028883219291005405, 0.03794212855638997, 0.040959802516285455, 0.05853706557724265, 0.03269320819526911, 0.060069846635263775, 0.06759453459732956, 0.01365380887422831, 0.03248926792894641, 0.05886453752135558, 0.0876997230995086, 0.09932716046610188, 0.04976593341017443, 0.10755034824532848, 0.013889001697422037, 0.011924073314144006, 0.03678583374787723, 0.11786287229868675, 0.025934250011379202, 0.03899540369128508, 0.035601925300133806, 0.036633715499192476, 0.046997755135018984, 0.05434960600048785, 0.04964494514429281, 0.07615893793803069, 0.04559622026018558, 0.07290694066473553, 0.019517976362558625, 0.015838962637879435, 0.09951914209992656, 0.03888172773464073, 0.03819910892015023, 0.019375267588803848, 0.017574696666410854, 0.04040562983361944, 0.04743646304573744, 0.03779576362801656, 0.058391999167900895, 0.037620310341158224, 0.03975267011311747, 0.03008643698488032, 0.09586105693972881, 0.04937110701575876, 0.05452538104427438, 0.03205282955370363, 0.10103312336028585, 0.05031701875850559, 0.016586523683321093, 0.04701359017241386, 0.07634518923418177, 0.007611286541026447, 0.0322397262789309, 0.029692798026747284, 0.024864203296601776, 0.06044842430480546, 0.008594196500076402, 0.07259082214366044, 0.045713240190619425, 0.026104062975895022, 0.04122987149223205, 0.04297013214278606, 0.040573495019587784, 0.02107324593159701, 0.04191242518924898, 0.021892711032001723, 0.02916607044396862, 0.017125543146844835, 0.028827804321002577, 0.05893511337137992, 0.03349679995388274, 0.0485405566230897, 0.036290144217350793, 0.004958956560585648, 0.06872332684936062, 0.020940676331520084, 0.029237565599502097, 0.04890079031728449, 0.047176533243468696, 0.029520240552242727, 0.0657354613705989, 0.02888975976665895, 0.06362805691277308, 0.01494847927167411, 0.08832620682134744, 0.05588111918299429, 0.05770511707411178, 0.011832417597273185, 0.04702601611854569, 0.025341439684252107, 0.07187370255949997, 0.01319615273631268, 0.04834021313957149, 0.061945222213023135, 0.004168902054399012, 0.013305018618402463, 0.02222623698593628, 0.04022857159255974, 0.02545575915475286, 0.0579421523387634, 0.05754632619960655, 0.028941800119355324, 0.03448062538800221, 0.07031500474700043, 0.046637303105765776, 0.06320756657289402, 0.05883835646654329, 0.10670841761654425, 0.07490007161733604, 0.04202430850015052, 0.037286943350467956, 0.037968815229232275, 0.030329108741434834, 0.029519531920912768, 0.059415852696064024, 0.06110065624177937, 0.01846386619182604, 0.03805631013106435, 0.03846966819236836, 0.07420673140234525, 0.03000545191518482, 0.035695997066795826, 0.024203147941959963, 0.12096188947438233, 0.16849069675851255, 0.2058956904276725, 0.17185593714877484, 0.09100114836567834, 0.09323365115109952, 0.0963455002995268, 0.1332064949336552, 0.10361310064552293, 0.09832513278290149, 0.13893513189208123, 0.19059129149442722, 0.15258770736475147, 0.09424368445310863, 0.17955478370910694, 0.22986595338631063, 0.09291961638917846, 0.10185720414043435, 0.100201144213638, 0.11864488719091301, 0.1384995036548184, 0.1197962177496764, 0.09033356402670184, 0.19283277283032096, 0.09361166957645647, 0.13119168369279754, 0.1327425980519864, 0.17363738268613818, 0.2347618527710438, 0.11824996886594642, 0.43842859506126375, 0.11023700327402162, 0.16984180006529057, 0.19390247672075228, 0.1876489929254017, 0.17206108017313868, 0.1346093398188391, 0.13876285403966904, 0.0796499086784259, 0.20578456171337636, 0.23493884972506957, 0.11355744284247199, 0.18012922707824938, 0.08360867568802449, 0.14584233383497885, 0.0934129080645019, 0.13899684793526126, 0.14196752240100216, 0.14415101088102789, 0.22821218406240787, 0.11501844146198804, 0.15972329543963557, 0.1532736471703937, 0.14617561272555782, 0.08706794571011298, 0.10284366491701334, 0.13107271023815678, 0.13150207187619903, 0.1937751988730123, 0.15201510260662726, 0.10206653766574399, 0.09407130700926628, 0.25660159456874093, 0.15721158424933113, 0.18878649559713181, 0.14497116929100407, 0.12489132297736023, 0.09572394252304109, 0.09953616457360406, 0.11226483034871279, 0.17582762806165605, 0.14100470309776647, 0.18082687270737466, 0.20254082286790495, 0.10768639779980145, 0.11183431957878413, 0.16076563466941157, 0.16279270331705772, 0.2031603428505121, 0.13956435054780977, 0.17672415011592452, 0.2276891758365016, 0.10838328500188167, 0.17144057959798845, 0.10537521778455666, 0.1589765895398394, 0.136298073395606, 0.17717885394250193, 0.10976937554416158, 0.15666704895275255, 0.1856668017083599, 0.18292785351795537, 0.16167092076953382, 0.12520104466426757, 0.17318280143362863, 0.17718391012280219, 0.13512945223239162, 0.18034998297451005, 0.13676056067549414, 0.1939433398506334, 0.18400730204678353, 0.1298019542328773, 0.13450973306692418, 0.16955296959607832, 0.1298599930540208, 0.12056323264034526, 0.17643463016758043, 0.1394660614671246, 0.22955320565210235, 0.12419215283326565, 0.15167696671860834, 0.13014931381950456, 0.12484043941742952, 0.15770621657852205, 0.14303132741441651, 0.1210518894837268, 0.09971915233519771, 0.1947828343198184, 0.1168677777112011, 0.10959954917310707, 0.16938965497238023, 0.10505855534105532, 0.0987326915586187, 0.1545844389305961, 0.11199097689842025, 0.09887789586378683, 0.09866834783385839, 0.15156629765706678, 0.09928783717294855, 0.10939440614874325, 0.14022372242423797, 0.13311601994979766, 0.159274582420626, 0.16795852612103188, 0.17856535051138173, 0.11586633991570243, 0.07501985712517655, 0.16946341391772995, 0.27474634109004853, 0.11176465154295007, 0.15355737549403023, 0.14044138332528455, 0.16123051214362347, 0.20484017448559885, 0.1767776996618317, 0.1463453624878199, 0.11972094195023661, 0.14512948902143588, 0.14707244121499602, 0.12143456572366339, 0.205279219475004, 0.11658997124721927, 0.19077893707060045, 0.13945302265065332, 0.19482835526427916, 0.16761516551336936, 0.1595967683580614, 0.10835023596882822, 0.15089889717919214, 0.3489809963972338, 0.1455244533116779, 0.30331887725380163, 0.10566928063429172, 0.08753799427781375, 0.07492418040431316, 0.1210577423954683, 0.1322493293593007, 0.12660921386052526, 0.1731034960117071, 0.13086839458875119, 0.29139545415678336, 0.1308688235979888, 0.4109073460342423, 0.13079442113878267, 0.1467163022607565, 0.0429543009358308], [0.025954627950165062, 0.032694920401779876, 0.03449615782066699, 0.019603333879081954, 0.02112867430813851, 0.03565732494837815, 0.01837252744383389, 0.028630883335286093, 0.04620064064980515, 0.0027738399043183534, 0.03728213231830347, 0.0702282146460587, 0.0444106187581295, 0.022454448832920002, 0.04332664648010846, 0.03976284376075191, 0.014977561884499608, 0.023921643188523672, 0.05185769435258643, 0.05465141399913738, 0.046488651404938394, 0.044604147889561234, 0.17655714294843136, 0.03244553196934923, 0.03373410717974748, 0.027222560921443567, 0.07826164244644104, 0.02377969092659412, 0.030598382901159987, 0.07022365642290923, 0.059484850404964346, 0.0550312863572711, 0.014046276675447101, 0.020878711309764656, 0.054306256915292436, 0.013868265612531575, 0.07002741534022555, 0.02159986243162665, 0.02142355495673274, 0.07954284023012846, 0.05132781431799935, 0.026317887691660758, 0.03343105811866061, 0.054432362648508245, 0.03247270893846308, 0.062380072871042844, 0.06962071458298354, 0.06895209602530926, 0.017552326899021864, 0.026436152514971556, 0.011922569866592606, 0.03889458269001015, 0.02239692137546597, 0.0692987737936839, 0.014625420951614938, 0.0626444957789875, 0.024779732526850798, 0.06793153667522055, 0.0035005281660555596, 0.023240522075925144, 0.06921773701305352, 0.05336847336542222, 0.0084428567882447, 0.1056238362986234, 0.03257616911263716, 0.05018210301416055, 0.01838143704639327, 0.08164580520843306, 0.022518834692516157, 0.07591457887282295, 0.056450805146126985, 0.04154994685743605, 0.07306867714730964, 0.05616604643423231, 0.054550531710828506, 0.04619889396933779, 0.11988710642101304, 0.08927646994350419, 0.03842411660439065, 0.041878813081571174, 0.002821901866662947, 0.11697813267669371, 0.02952054315697282, 0.011284233806955238, 0.07265746413219361, 0.02255935116761154, 0.06695966221271984, 0.024777041643016764, 0.03846973714028155, 0.006557568032745153, 0.07998747766138085, 0.007315219413759488, 0.012106374469435504, 0.039094117950768247, 0.03738829295241064, 0.049849896646675565, 0.03329144625533973, 0.022675099392091076, 0.0505096860410225, 0.04327200525890916, 0.04567140795951409, 0.04405762459481916, 0.01849407686912004, 0.032588177540850256, 0.029171243452677326, 0.046453579899764834, 0.03209543936405211, 0.02904589040084712, 0.008901675464585423, 0.035384245246889136, 0.030056703197319182, 0.05821394118210001, 0.12837849392165102, 0.014392467977989827, 0.008963427896941862, 0.02441905833209955, 0.018257650644368222, 0.02520575402154317, 0.037246279403447144, 0.06981786731029711, 0.03575190616350982, 0.04162861642638042, 0.04024348732444548, 0.015280067023160237, 0.06395297778409816, 0.008721916763592632, 0.014590107171135324, 0.03563589746913603, 0.026700083211424853, 0.0349797967881445, 0.05296114058564267, 0.01830524768710377, 0.01769290020268771, 0.036642697880104665, 0.03885245168461435, 0.03664337586791765, 0.08497964365467911, 0.04205106795134564, 0.04943492980073056, 0.03869533471222367, 0.05701800515394538, 0.052801713858160286, 0.03432599054048619, 0.012392019928102533, 0.04481154704286207, 0.03345461532233223, 0.03482668262515818, 0.04829209515704744, 0.035983705217198986, 0.1049936217285933, 0.04161242898854037, 0.0202256481673929, 0.060917526753919746, 0.014847984815376901, 0.01823328330271667, 0.07758994421531117, 0.06466967218946065, 0.03210357138736835, 0.03210915425311654, 0.055325046602276065, 0.038113839503738194, 0.03929126301720258, 0.029697972950675798, 0.07623994407514412, 0.07349916493460056, 0.044497711463801326, 0.02060164220540995, 0.009146404167216633, 0.042273095553560604, 0.06149670837687389, 0.06712830880837095, 0.031104094776955825, 0.06261542657270067, 0.03686827629984867, 0.03015297938198332, 0.06599229234721392, 0.03066312116120131, 0.014968346804380419, 0.031659600452610084, 0.0015658930539258667, 0.03316551672234651, 0.04015514589545708, 0.04516593165575497, 0.01945599027338528, 0.0047923530256676105, 0.03336595213641563, 0.05793924886553038, 0.056995206377318794, 0.023322648616627823, 0.01718974514533916, 0.030744483529199517, 0.06592445526151888, 0.05868846370327858, 0.03279015279164718, 0.018719015605447274, 0.07458092704896005, 0.010858625999741979, 0.04681760189874519, 0.0516213026017912, 0.04651108628980095, 0.034878811077965845, 0.07242983642725215, 0.11334061697726289, 0.009531714792002835, 0.013561293223662483, 0.039397174672734354, 0.03397166721462723, 0.07262950958383661, 0.022266113777614893, 0.04544843040827302, 0.00868938100944844, 0.04431583836013752, 0.04031967859895479, 0.020339448613324956, 0.041313597241476666, 0.022718327818438414, 0.07588417284310826, 0.023390830441888784, 0.05124973463675669, 0.02327170185444336, 0.031360929584010475, 0.05604159928137257, 0.024044539013336745, 0.015443183421607942, 0.01617745571439305, 0.0780176587643162, 0.05066904765103133, 0.02258199864187308, 0.01659501193752212, 0.0069764917228190655, 0.017476804036226486, 0.045629307597635255, 0.06096587839326071, 0.04941679266912322, 0.06699353095985229, 0.027602096200890602, 0.009803984355511925, 0.04439066982858124, 0.06050796465828054, 0.08750399529573419, 0.028521830719264767, 0.07207440993478222, 0.019856903236359358, 0.037219596561044455, 0.061512252300857544, 0.04185334448852847, 0.044048849057646534, 0.02583785699830661, 0.07264650141399714, 0.025138282742831978, 0.05327788729881568, 0.09927502818285458, 0.036929080698398814, 0.08658056823356498, 0.05194639967333886, 0.03333991663830896, 0.09970817429524276, 0.0765859859905416, 0.017329966048559835, 0.037098830460660884, 0.05052034232404925, 0.06357771727526862, 0.013010834152209423, 0.045790910014822606, 0.018778215049796047, 0.041227967763740214, 0.04609845984246462, 0.055831085980659535, 0.023779478337195133, 0.04073546515897878, 0.03694426839149768, 0.03205207495709821, 0.043951433317195025, 0.005221954066186182, 0.076160745905532, 0.013193569104788045, 0.049148623591228846, 0.014432831235500354, 0.01161212805703643, 0.027112263412545287, 0.03748694975529948, 0.04416558936598801, 0.020744098170149713, 0.015431597299363106, 0.018551661783168395, 0.0266084035543064, 0.0575665777338849, 0.04707042623551623, 0.09995893019461825, 0.03123548077118974, 0.03716717316438595, 0.04598570702176902, 0.07966348375644415, 0.04123663221816382, 0.02651985528157844, 0.03476253808325818, 0.026988197388427875, 0.10812424003116547, 0.01882953911028322, 0.048333789492326404, 0.054207293677233884, 0.04685386850108062, 0.030075345946956548, 0.07343909598045772, 0.037125796755595554, 0.03667391979345872, 0.03925910264614128, 0.02887821099120042, 0.06293985331731458, 0.057686137245787736, 0.008873040055585726, 0.07721764846674858, 0.018551774781137224, 0.028167032418892752, 0.04674815985884878, 0.04304165411139688, 0.08565501910784552, 0.011284463633332523, 0.07254869496870427, 0.02918168331586546, 0.04149099256122305, 0.020878073541567694, 0.023996319524162722, 0.03917246576278441, 0.07281729305583624, 0.07266489518505913, 0.08685181698491497, 0.02172455473262216, 0.03038577434997405, 0.02663477613109975, 0.010244281898673263, 0.07995509512482152, 0.05547743298173432, 0.023428721150623697, 0.03741369642797978, 0.10468177031725646, 0.08748800704075445, 0.04358388731376298, 0.0134439438754212, 0.14544269640839871, 0.00940504598416268, 0.058780961159256205, 0.03257523831580916, 0.09275345191840204, 0.018306375751572273, 0.02248991870381419, 0.038190183995832364, 0.04696826458037381, 0.07744251825516263, 0.04924309372361149, 0.02078943142306901, 0.009138822769595972, 0.07958728099061597, 0.07686625925763961, 0.26158942450438777, 0.08645737363446145, 0.196079055087701, 0.09878646327002395, 0.12770060570009295, 0.07956091224426225, 0.15409719168899522, 0.07450781927834596, 0.1131719014336986, 0.10298391263331137, 0.1366637271618651, 0.08210628533795958, 0.1098185813715381, 0.11019935005254324, 0.13743451886600064, 0.11088823163581472, 0.11984019119653011, 0.13033170403251726, 0.09199932262661958, 0.1364236045628786, 0.30737635469244373, 0.10324324105655956, 0.08913429934651622, 0.17998193901392723, 0.19590129204575094, 0.09560729797569015, 0.09524201959251397, 0.12955102979415847, 0.17036203505291095, 0.1490636569477858, 0.17916879796933743, 0.1494940298218881, 0.15150943861132668, 0.049222734937023734, 0.15388195162578938, 0.26254516515520315, 0.10940071871323932, 0.16340295363578106, 0.1822107492555534, 0.09874078910797836, 0.1492742851616875, 0.07899391524974378, 0.12799915016418503, 0.18934725663594662, 0.11735077316482222, 0.13397969215387298, 0.10093877197153146, 0.18289610683437318, 0.10560217133212475, 0.08686731494362317, 0.13547261365719382, 0.1960530693853094, 0.12968892562052897, 0.0825208997834594, 0.19345616921782496, 0.18009881338765546, 0.12511610083522337, 0.13972961103483555, 0.13206871647027232, 0.22044621287815033, 0.24412730828888957, 0.23548464140584394, 0.17201071755299646, 0.15778821862993703, 0.1688796855629452, 0.18920272648815187, 0.12720197439193726, 0.13630771078169346, 0.13924283876774773, 0.17937112179013992, 0.20772739133286863, 0.11534205998384184, 0.2844282522076561, 0.20402242159170492, 0.19196674107543885, 0.15860712065571742, 0.0939767947420478, 0.09700298759966128, 0.15404039393028907, 0.39786338145213745, 0.06406201124792138, 0.07098664169109638, 0.07989551646695023, 0.14133257340760003, 0.16387305582963652, 0.08549639294224401, 0.08415783049478646, 0.09812505359971717, 0.12081354420872466, 0.1740839046936843, 0.12673223225940622, 0.15455603239036378, 0.2099435151584687, 0.1838153510564758, 0.09710490027622831, 0.13719448819756508, 0.2586545416664693, 0.17716684168384922, 0.18723961086042468, 0.10864675029992096, 0.0751640655160431, 0.2076547202323714, 0.17000562030701868, 0.11222675577887606, 0.09427137853157136, 0.12231720626474389, 0.10150090430773075, 0.15844435761532477, 0.16232909754880015, 0.15238529161339806, 0.22720327690964748, 0.13181014647406916, 0.1642515798730235, 0.12155463468403586, 0.26628738209124536, 0.19069371744990352, 0.11512306608980703, 0.1770144208304344, 0.10116738792989524, 0.1341785839007747, 0.057098475029511805, 0.1405987684284487, 0.11488645983439301, 0.17070507390364525, 0.12296347037678766, 0.1403234517502208, 0.09129575513783963, 0.16383723355829716, 0.21522391407239824, 0.15629437782110708, 0.1109819012063165, 0.33012401793272267, 0.1631420547322881, 0.29141249195221935, 0.1322961832967497, 0.12878756189057905, 0.17190147341499407, 0.16142226395107087, 0.19317947358133333, 0.11139547377223931, 0.132976193581858, 0.18521494772886077, 0.08710851006570362, 0.1494477121459861, 0.12378910631542245, 0.10810249079499515, 0.14849361092332872, 0.2428652856859469, 0.2111380147717653, 0.0921808778037948, 0.16319630907908564, 0.08961538724120587, 0.07486912932607435, 0.1885787785173424, 0.20936223828504164, 0.09641616424966244, 0.11823845456444448, 0.19307628153793274, 0.1846887525771895, 0.13963637813445062, 0.14091307898202252, 0.2385744578655689, 0.12235068430703495, 0.16501417443636926, 0.070209797892359, 0.20040130783473292, 0.11344834426117521, 0.12280636872615545, 0.1993898725918224, 0.11560511925528127, 0.15640098661664995, 0.11070070863370934, 0.07510600371226188, 0.2226689710251747], [0.04239121098972617, 0.008050725108102686, 0.054877275871413375, 0.05757440715247105, 0.010309816890155837, 0.042067960190076026, 0.012436201176305693, 0.0577525302557455, 0.03956046248335512, 0.041300497137971466, 0.04225637951505281, 0.03172149652645233, 0.0417361406969928, 0.026241154409945015, 0.053286341079060114, 0.04924605082299921, 0.046734427732806054, 0.038234823939180186, 0.02081616597640659, 0.054725031218221115, 0.029017617926001552, 0.0668053261394943, 0.01944758054319649, 0.04640570706537655, 0.03328734002406559, 0.041204889365021265, 0.046038567088544376, 0.008711183871773463, 0.03862396979163732, 0.0267967903205464, 0.05279883336756499, 0.05526947075380914, 0.034541288060286356, 0.06435923037990447, 0.05524350037317603, 0.0253923385659413, 0.057158325648596214, 0.013187074594409957, 0.1183526935957132, 0.033490606133014925, 0.01808414322083756, 0.04308211887555738, 0.02516901052947487, 0.01854283070462125, 0.006899350978088596, 0.019427463074304888, 0.020610120883511922, 0.010270377726203973, 0.042991693687414935, 0.020481896917185476, 0.037403147397262436, 0.022081547874897238, 0.037269465054475495, 0.04040460710624053, 0.011980302252566383, 0.03900899792150144, 0.022896807152597655, 0.048208890347591335, 0.017472209423900615, 0.08222587166293975, 0.0187089798536392, 0.041841611851968115, 0.04744891963538624, 0.05628765140089297, 0.03192191087310353, 0.06883421041552099, 0.03529596127449505, 0.015839310250275077, 0.021459698985000292, 0.03893066160080414, 0.021337965698612314, 0.012553701826912022, 0.015689007629970872, 0.036222027509563395, 0.04232467242306279, 0.04567775882840638, 0.03444290704905026, 0.032075521078020815, 0.07174129192266734, 0.014336941925237977, 0.05999149882324761, 0.02655220142896137, 0.029787712490126014, 0.03535897200626712, 0.04217016014961466, 0.02869991934858263, 0.01821831202945642, 0.06890292850232894, 0.03780192297492777, 0.06427741985047056, 0.019072394727939562, 0.041393500211979115, 0.04876387125301746, 0.08852421756713622, 0.06364199971299499, 0.028755420503476938, 0.07587875660148359, 0.015323494632367887, 0.022434199213861458, 0.10083193334961131, 0.02925475469730314, 0.045729787689783884, 0.09783048513195208, 0.04497025747813525, 0.026656416199740865, 0.05732304221319576, 0.010944877923916905, 0.05631448363044089, 0.029613182339216435, 0.04019332771760322, 0.02946274565352548, 0.06838932783613283, 0.0028909338101173842, 0.06976220336171889, 0.04586515925644387, 0.03472947372844623, 0.06545183263839253, 0.051927829702054305, 0.07662939253233134, 0.05108596419074363, 0.10304614195540067, 0.04604652674207765, 0.027754938402663798, 0.08278972003608942, 0.0318590150545201, 0.05684545150988045, 0.026214532854576266, 0.022143729316491275, 0.09723505095368433, 0.04399099792804449, 0.030796209785846934, 0.08088357836729096, 0.06981479529772075, 0.05110303262969659, 0.013274125165245948, 0.040175079503246856, 0.07974620593050796, 0.08308746776874028, 0.06038183211198738, 0.08530168403540889, 0.013340332398882077, 0.07278625883402363, 0.022600989961515994, 0.030919996187871987, 0.0661496238242234, 0.019859787557394277, 0.09366578602742764, 0.022781344295869914, 0.03191321577516294, 0.0542136675287639, 0.04401715983065867, 0.011946036097323223, 0.03516390303810758, 0.09734898354978332, 0.0626994970615112, 0.01264719136675159, 0.026290101682647105, 0.05263103712950984, 0.05553884258974464, 0.04597174889978863, 0.03155328277047844, 0.030673698920215813, 0.004805890756899551, 0.01585245440383592, 0.08400647450358638, 0.020619448003990036, 0.006623408022982579, 0.05388198976194667, 0.03479774748425811, 0.09652216017486588, 0.07763946413873665, 0.02007312389210828, 0.034498701232575604, 0.09346644228865063, 0.019786869393541448, 0.008561469223951141, 0.07396305415539012, 0.05961223167457408, 0.08545359160991446, 0.0542584645201362, 0.0066933317406613745, 0.00811586652191416, 0.01512409439460645, 0.09125160549076335, 0.034580036787496465, 0.0505460522347881, 0.036799148356001225, 0.005217319234244285, 0.04882090649898014, 0.04788059102852018, 0.018241300412844268, 0.0384078219142412, 0.018948648545530536, 0.01826854441465149, 0.0292994904016415, 0.03260169133183456, 0.02844967672811641, 0.026226893683234533, 0.009596619676167687, 0.0442015954984292, 0.03125566527277472, 0.02624068518109139, 0.06790856935925062, 0.07358060774183081, 0.0372863074974908, 0.04308499170527343, 0.021278930963167263, 0.03709508046027153, 0.04742347019454164, 0.04296703331713234, 0.01890621110496502, 0.02673296370513497, 0.0278329529664329, 0.02282864830997442, 0.04917655898738773, 0.05026462600536404, 0.019928842722888918, 0.033453021859449726, 0.015583895578710063, 0.04454240886374347, 0.0065869230855887225, 0.030727786642889825, 0.052733788672353954, 0.10750295038545325, 0.02247016704190643, 0.040264784568740476, 0.03358131094324974, 0.03265607591357923, 0.05011667527498738, 0.04801904609907539, 0.023294054384854053, 0.05763601211290206, 0.012011175595914886, 0.013826486049971033, 0.04039341839210641, 0.013131235403219059, 0.07363707608272953, 0.01814985824298234, 0.059379314132515466, 0.027133122071503635, 0.051427486187387864, 0.02851017277627703, 0.05607184443262316, 0.08032454102630578, 0.038029205940303304, 0.06734437624653501, 0.03303864490120642, 0.025742563321405364, 0.059595098118147546, 0.01961695109193604, 0.027813873546678695, 0.023461350750538613, 0.12532377194973732, 0.021514550880378774, 0.039731583543001645, 0.032370229356832085, 0.038776344679776704, 0.03207428384602311, 0.05400898032671502, 0.015426114982654972, 0.0145292520192602, 0.03225476841532415, 0.08165310602635145, 0.01318331501792155, 0.02665528238961293, 0.04415033272497597, 0.07503750779095196, 0.036723481851720044, 0.027090778476708842, 0.013251233500458542, 0.04830205430006308, 0.024267656375624003, 0.023173054627653573, 0.06132319712290361, 0.03895012406452049, 0.04351414649957611, 0.03952644051863782, 0.04815861582756043, 0.04835212580679406, 0.04852302087050292, 0.007025825391117965, 0.02043093483324253, 0.02094287308864296, 0.0073372999829570615, 0.02036351909590585, 0.05706026256384869, 0.01794413107657625, 0.024162614229886283, 0.018347928360585245, 0.00931920008658762, 0.01549070577077087, 0.00786953238627663, 0.06759889363761871, 0.05356113681749952, 0.03805794955922231, 0.05664060725980709, 0.02936051696568968, 0.013199048548666461, 0.043995065854922424, 0.04651889272574936, 0.026411356164082408, 0.049810707418909, 0.05798311122963506, 0.013672280211692617, 0.06567841846375697, 0.05131622723814461, 0.01152025975076662, 0.0476485200136179, 0.04444071835267448, 0.08120145122971266, 0.024267288653420347, 0.030643687425782124, 0.0363612869724391, 0.09470172842303592, 0.03808996437357799, 0.024599770812558073, 0.028010664297448053, 0.0536801141025799, 0.05165289606778853, 0.06540420495214001, 0.05223613029586212, 0.01763662721420969, 0.07633663203206754, 0.011651301963044512, 0.01732645928108644, 0.053239310941388535, 0.01743223687123147, 0.04682492569930131, 0.09159562493404073, 0.08743225882250456, 0.019604643889432474, 0.07967817732283185, 0.05476982820959342, 0.05820036610408176, 0.054433504119515426, 0.02304171842913474, 0.015442746751491102, 0.042613119848312876, 0.012168877667957738, 0.044049982867774465, 0.08956287191399644, 0.045211751374506184, 0.03185704046289527, 0.03837815132893382, 0.03867041387204682, 0.09914742857818643, 0.04558554099452111, 0.04970830827651005, 0.05562659030059173, 0.038737572969928864, 0.04618654463199839, 0.05475453709462478, 0.16217002705220254, 0.14027301252128618, 0.20188019460728093, 0.15624168629367507, 0.1304043751330145, 0.1713181893912054, 0.06128770043893207, 0.12545662691756604, 0.1789745487152569, 0.18572730733261955, 0.14281309960830596, 0.11640833180037238, 0.14825724215517122, 0.17925053955085818, 0.14436504052531335, 0.10053741084712167, 0.1362096208838686, 0.22908517189564245, 0.09622467291210929, 0.13776485597895038, 0.1981555670499802, 0.13098350696025357, 0.1440575175107487, 0.18323589747230853, 0.16432362278142285, 0.15749903576027963, 0.12988640776565, 0.21978661117534484, 0.1499762208831887, 0.16304725901253764, 0.1317169442172012, 0.0999620711551078, 0.10087691803252506, 0.12668432878150096, 0.16147996569352766, 0.13140981956835718, 0.16122545596332322, 0.08610778473197453, 0.22690654041305666, 0.15254946425557137, 0.09996227033796812, 0.1956981714935072, 0.08764002952844867, 0.11098695738661675, 0.14015488176336213, 0.1126418375380097, 0.16022466934256016, 0.1789515660775285, 0.15100460199098434, 0.06483415892768292, 0.14180261431442154, 0.07124931025769442, 0.1325089105915639, 0.12546120812335324, 0.11122899520541392, 0.172593587889306, 0.1541380854623933, 0.11773673592195397, 0.15399131833785965, 0.20785405631026915, 0.13495525916016873, 0.14183394731052462, 0.16739277018895074, 0.1791892831604327, 0.0833878048785752, 0.11592261673462008, 0.10862544539474672, 0.2611998534731327, 0.15379202822523733, 0.17002002275999517, 0.2407126399057527, 0.129654850029657, 0.1022452429958409, 0.19261408537145586, 0.12208671339096562, 0.215617039751622, 0.19499680267706995, 0.12727413221352524, 0.14244692490225838, 0.0993087130688852, 0.11194662806848366, 0.10772094070430725, 0.23145950819936492, 0.11542036183058255, 0.16384802007627103, 0.16597756064466893, 0.09255334975257998, 0.12083880212758819, 0.11869836778890704, 0.1903905764582657, 0.18236016704430505, 0.11131979960707888, 0.12704740849233445, 0.15696591517377287, 0.10509450784734181, 0.13127469698027258, 0.1411763067928053, 0.14574327866636938, 0.09653932054436977, 0.1298258408543564, 0.11576520098793892, 0.17565602436661723, 0.30905699838073025, 0.08766395445432394, 0.0674421826918279, 0.18502223065062878, 0.10050476784066809, 0.13954095422260224, 0.1442591671741778, 0.17492604982708732, 0.14784632791434565, 0.24705520440493864, 0.09025075758296637, 0.13405361963856605, 0.10311027883642143, 0.06138201352329024, 0.19216082179017607, 0.10947050932314127, 0.14754527068186193, 0.10446089950780715, 0.16657846469071605, 0.1992509195641164, 0.19857351397795064, 0.1796236856570167, 0.10100161416396018, 0.2259827609504423, 0.17245008429932981, 0.15183925478448793, 0.1683120910198458, 0.1563710172570521, 0.1136145010710724, 0.12882655576592492, 0.13128644876903103, 0.12688232420553125, 0.1095176543740015, 0.12544898902096097, 0.17269592191423142, 0.19470775770323892, 0.1276354192786159, 0.1309618573155134, 0.16218766239621948, 0.12714398153606923, 0.10692270006984474, 0.1352449936131316, 0.1676617743026826, 0.1290378121719245, 0.2106066255439674, 0.1205761259001109, 0.09119051763968122, 0.16577843907138995, 0.22775355786565812, 0.13722882425833133, 0.12504880767195456, 0.36460419515928916, 0.10436755169423358, 0.21984834254028338, 0.16247876048568757, 0.24132348777305698, 0.13367881878249108, 0.09599173621785256, 0.18660605614704473, 0.09613638893971521, 0.08324636206511529, 0.15699519505423887, 0.17826455374879224, 0.12264610313239599, 0.1295983893496375, 0.15500843795316835, 0.12711796519016066, 0.11397804043466046, 0.1061582285910845, 0.1691366008092319, 0.09553537764135869, 0.25997877060886354, 0.09403999699580093, 0.1789522708784188], [0.04949961443461719, 0.022351758577109828, 0.046449213198596434, 0.02559352857661584, 0.03655005103698181, 0.08343343307534534, 0.04004600517932446, 0.05651363967767647, 0.04865806301935546, 0.028174737348191203, 0.019220201816830425, 0.03340304611370929, 0.06510356906801462, 0.030510727120863817, 0.04912135469156408, 0.09841217569285825, 0.08184882616924663, 0.046107901876131376, 0.060872358209904165, 0.03669031407503832, 0.060190402061468175, 0.1180219887605598, 0.007256732909985248, 0.021956298244936813, 0.06319936943210422, 0.07789288602408864, 0.028154014669839415, 0.05676711518918315, 0.056431147329989946, 0.013633464451789135, 0.054584546014666564, 0.094698196757705, 0.038836068894353606, 0.009650663348786052, 0.01729943935999707, 0.014204381901260107, 0.019033180602315455, 0.09060593126642127, 0.007474478559508439, 0.059831780982354, 0.006760227017014498, 0.041795171601998235, 0.04824691129127338, 0.034570996949989954, 0.04551013112969456, 0.011709784157574179, 0.068972343729148, 0.023592763557849873, 0.028719628875654553, 0.031497953985367096, 0.03508755471557379, 0.046425889651741714, 0.03449998442984877, 0.058282536694840084, 0.049653069506729805, 0.01778499354728528, 0.017857293095139247, 0.011024626719224597, 0.03931917543072374, 0.006704889134609051, 0.04272255933873596, 0.011804891100543882, 0.05821750349094791, 0.07668322553077052, 0.016531378759311575, 0.06857794634396992, 0.028326227404778043, 0.032372876190610474, 0.028369365815794276, 0.05821042866896718, 0.02136127583892836, 0.011309470658400848, 0.08148914788879695, 0.07573533728117905, 0.011614829474579424, 0.046921778365128466, 0.029607779504130446, 0.009174414256948137, 0.04737359787067098, 0.015059775567703671, 0.029202212557016365, 0.06446488156554199, 0.08132247013911124, 0.016228283732949246, 0.004082354707568283, 0.028147847662048957, 0.04939647601737131, 0.020319729510153976, 0.04884517233398172, 0.048331096693272554, 0.025908992092515674, 0.04428844305596525, 0.03429712051705968, 0.07391855976874791, 0.0332668318503326, 0.05212993135735874, 0.04868925045875292, 0.01229750766088405, 0.03142205956992844, 0.03300069290543756, 0.06330736484679003, 0.046185993048692905, 0.06249563723442055, 0.05574068377515482, 0.014097243547439577, 0.043745478239631465, 0.028621154018647732, 0.09356129163455579, 0.023754241485749523, 0.017683542438692624, 0.05443486775602064, 0.03466038791943462, 0.003999549700247665, 0.037034946388655135, 0.048300292297837236, 0.030451924127015858, 0.03826032317573986, 0.0328436678635978, 0.014298979395760164, 0.023195573782187798, 0.04373137456094546, 0.09801272978825916, 0.010085173097679452, 0.014372901134793798, 0.0277098196543633, 0.05312438243098798, 0.07595162688484115, 0.032756023574620485, 0.08355925535602916, 0.01941171422180149, 0.025127653272882588, 0.046256285446185263, 0.023488353434649688, 0.04764822506976705, 0.01590912767325438, 0.03061617146276178, 0.08771565772833363, 0.04971743238368823, 0.021451363948384122, 0.03288204503816462, 0.07569583778780314, 0.034785034255154675, 0.01608519191523233, 0.019441848290303064, 0.02536245347601512, 0.035114459723474524, 0.12924474784203116, 0.023057063170258078, 0.07476500265540616, 0.07066837046295404, 0.1108806397044851, 0.06531212884452074, 0.07930232692630061, 0.013630816660400842, 0.04389162483294645, 0.08815949076726552, 0.058558845456929944, 0.06950848270207644, 0.051175389634144884, 0.03957834680594745, 0.024925415636971596, 0.025940725369559183, 0.009717894267411003, 0.017834883108134233, 0.0941695654464345, 0.011300800458317804, 0.008783743889521687, 0.021528148941034754, 0.0673154334447557, 0.04536332953120432, 0.1146194858536605, 0.0050965459517864214, 0.01875918351053711, 0.029778628602563858, 0.017768074495477543, 0.028182367583917036, 0.052034733441448024, 0.03155038887334447, 0.06653779291457708, 0.11558425102022388, 0.011732350234993765, 0.048024918163015, 0.0329506405509047, 0.006962244881452212, 0.012458152468166044, 0.026468376088286602, 0.04096583545868916, 0.0011099239852609894, 0.03849283469119861, 0.03884634596385783, 0.061058471610228864, 0.038704589054348974, 0.026014970780740825, 0.017800422558080287, 0.03322481192768582, 0.042495640265124465, 0.019699755620451707, 0.03887125148227619, 0.04866567410288319, 0.03796385864036218, 0.03382204258213601, 0.012814815235023778, 0.10671129810713953, 0.021076078541697036, 0.03953687463616652, 0.029450501653275667, 0.010804142784177056, 0.018069482213186643, 0.049293502309029145, 0.01224614433839076, 0.03277509916393507, 0.04343408265060956, 0.0014228074606733338, 0.05562867789018539, 0.02493381962150095, 0.040798901069548824, 0.04046147764329949, 0.02534037865247698, 0.04033790766111305, 0.009179578647167693, 0.021239774294137474, 0.018707928397963126, 0.048916629185118986, 0.02623745229005093, 0.02558278993913724, 0.10739884669742278, 0.02544149651282257, 0.07690160655446591, 0.04621990010022156, 0.012553224937179157, 0.005308889245028578, 0.08757485842873013, 0.023566896599086545, 0.034701507688770374, 0.018813577668380835, 0.03052174346521497, 0.08573330563282774, 0.01964349603851236, 0.030496456818054282, 0.0346296907763087, 0.05456267803486797, 0.0434721572204463, 0.05076767764084282, 0.05656462665947695, 0.057644622941170974, 0.07293804383446133, 0.02175038913264871, 0.010389107947928772, 0.07076526526361704, 0.031431957425910144, 0.021530562117996237, 0.07007654455880966, 0.025227757981948318, 0.06631827041987451, 0.09628311775985265, 0.02545220833722382, 0.014507750804055364, 0.026446069523151365, 0.081454758201876, 0.014466585069444152, 0.07505191790480768, 0.03528731980270917, 0.02663852996192873, 0.049660213276623726, 0.06052598304625961, 0.042637565713976665, 0.012205189277958727, 0.03560671718010018, 0.0396870814954802, 0.02929820528914852, 0.01215752232970009, 0.04597264905309966, 0.07534497717936194, 0.03663914706257563, 0.02432733079448583, 0.015682964153858205, 0.04867320857761849, 0.13013336386892105, 0.010805417362961077, 0.04247535042644989, 0.04164940805264539, 0.05047928001130781, 0.05501083947057205, 0.051591566899010254, 0.03134431122171302, 0.015107977819899398, 0.023195407158064268, 0.016335943984168193, 0.04514477613772597, 0.05119778621461123, 0.07403781667592065, 0.021647842518324335, 0.030197575275275498, 0.025893463490290508, 0.023374472549485586, 0.07168067904609828, 0.045943553033735485, 0.05645966112253167, 0.034527866199852965, 0.05292328818130398, 0.041746287531549894, 0.11707699632332211, 0.0326896267342231, 0.06440930188663545, 0.024692892630193985, 0.01199031693695654, 0.03273912750545048, 0.04273074881864652, 0.007196753013563613, 0.0018959118812833164, 0.006859140938162925, 0.039631260498877496, 0.0568720922174473, 0.014553249723488286, 0.013007511245837856, 0.02041058945319345, 0.021659287871913086, 0.015087217794761304, 0.015570954438449155, 0.022913544258523374, 0.04902598823631003, 0.011040613058984522, 0.06307984056371836, 0.04283578713394461, 0.026734702724723086, 0.026463524836506096, 0.03882394938339149, 0.01675075378208872, 0.0525309668944007, 0.018601346415497603, 0.027974801806492672, 0.04995415738273052, 0.05809465746184992, 0.025459892199104352, 0.00757716067563442, 0.0632115540605399, 0.05612976834057801, 0.04316076163142439, 0.04152749665081502, 0.05837758139316594, 0.09443553585198619, 0.03457814071988387, 0.010037376872083593, 0.050519794571183385, 0.04393907248853676, 0.030365633898444717, 0.1012571351302247, 0.017006652046655937, 0.02759313105695671, 0.02842397830869642, 0.022840928699400638, 0.06406755389405355, 0.14907896338451296, 0.1862037220909711, 0.16497193234822444, 0.22786874684595296, 0.05111307221194429, 0.13351988618171987, 0.23634780799188923, 0.12384122327691126, 0.11541212638539654, 0.10181647124550036, 0.1475911899920433, 0.08519820087859709, 0.13632044316299502, 0.10287066951634423, 0.1135234208777547, 0.2747846454862626, 0.11301760366486927, 0.12404430552475876, 0.1604873915353129, 0.0816028583193979, 0.11581251457814248, 0.1940868740841266, 0.11604352839170926, 0.12221281146330219, 0.09437056393512795, 0.19924488279127306, 0.23227864005152257, 0.1168254666751431, 0.09042133472018665, 0.15474853496397697, 0.10704797076722307, 0.19930604725114762, 0.13883106650844698, 0.06651409015419983, 0.08601178625418295, 0.08429703633150748, 0.15199299330913252, 0.1987901176776617, 0.12536338635630187, 0.2599791996181011, 0.16186955204654127, 0.12513699205291848, 0.10861587695657246, 0.14431034184751973, 0.15448132349598795, 0.1318492935669999, 0.20888183986948383, 0.0464927691275314, 0.1681486538220798, 0.21870222904028433, 0.08783806325687517, 0.1981343617362361, 0.14399950933312217, 0.14294799237001327, 0.20112104743959444, 0.18460924797240766, 0.09974131525884714, 0.13936164368304516, 0.11317236108645318, 0.18127546315231632, 0.1395974302243802, 0.0888423738820899, 0.1128879969098395, 0.15563788643527418, 0.0851700165038628, 0.2608973100300758, 0.1001579751591048, 0.164791917007777, 0.1897236815984211, 0.1640085308181663, 0.06775357445041019, 0.06520079328648506, 0.18388770040004485, 0.1394088500209393, 0.0721335749051744, 0.21506544112438158, 0.15415519986662174, 0.2914904797029111, 0.21816610538911438, 0.08171037109869142, 0.07440249751051588, 0.1552275237777541, 0.14768007151301832, 0.08725344624009826, 0.15688363733070512, 0.11133188081364478, 0.08456207210979155, 0.18660475379757344, 0.17173468075211973, 0.18659666390909305, 0.07635630516996307, 0.19451151662055524, 0.12378988006422598, 0.13667992226058437, 0.06999084996359964, 0.06648009883299952, 0.11191093603209143, 0.10245627723634244, 0.13152816483090002, 0.07813768175941321, 0.1027677379428379, 0.21685960372128796, 0.13868894187673447, 0.16209945503261783, 0.15359940307755626, 0.12978741388407447, 0.13812029013229957, 0.11404894187205261, 0.12179971387189244, 0.09792328136222017, 0.1501686162044925, 0.1372388600101394, 0.15447711001240438, 0.11858306389542357, 0.14685816642257477, 0.10645577714087502, 0.10900707209422704, 0.180692853285901, 0.1036295638750157, 0.35420047599942456, 0.11468500169294496, 0.27658538111755926, 0.20620563428007788, 0.07760230887440905, 0.1588757417254871, 0.1957087281851038, 0.16393065031978393, 0.1813487624449115, 0.2099439288459478, 0.1220968027689284, 0.12512336334874555, 0.11978324788111834, 0.11231489419456452, 0.15703588964477663, 0.09075650584793861, 0.22468965049953232, 0.16161297387894125, 0.2575324067185002, 0.08258089978968905, 0.14061533124937167, 0.1825562242658869, 0.12348530648816979, 0.07479770694889369, 0.07735740588677507, 0.12483205075465864, 0.19888440777938213, 0.18544969239061881, 0.22624948212215978, 0.22856410953306386, 0.3070498786626324, 0.2679679951360149, 0.20479184965933525, 0.30316434199771575, 0.11123669438905294, 0.16871192762928625, 0.18033685222748788, 0.3203029852480658, 0.19426845224393954, 0.1681852728248604, 0.16733660062234249, 0.073404997406948, 0.1304793444972846, 0.09644334504921591, 0.15955541493190875, 0.19924906563133965, 0.11354271863256732, 0.11382718240061115, 0.13166086658114387, 0.1471118640995795, 0.18731433507655898, 0.25825746297355623, 0.1203709522322301, 0.14634626647157056, 0.13908341587070497, 0.1517245101351892, 0.13076365504774357], [0.050608967205569635, 0.06273133184520469, 0.041372880955497106, 0.03484850080924169, 0.04428457048150801, 0.018587311684724786, 0.03996589919552207, 0.058849468571884986, 0.03134107641545275, 0.08122028933177072, 0.025835951354594964, 0.0468500342310196, 0.019260634022254138, 0.05747613339354435, 0.08103881076338791, 0.059408138190666517, 0.03665538046569113, 0.07084720602799809, 0.03386055382208959, 0.013199710257111058, 0.008549731799341258, 0.12164350854413164, 0.014283566664333546, 0.018697858172198458, 0.06932544897520734, 0.0393657191025634, 0.036056104356483105, 0.07322051577390203, 0.027773912485328414, 0.042941786889587684, 0.03149372901046469, 0.0655239368338258, 0.033003063947563215, 0.009936526184901595, 0.056017961638468894, 0.03602460282103669, 0.04689645532879138, 0.04297317351184545, 0.07588198949252406, 0.06726382210129692, 0.07570894555218759, 0.013280761401890027, 0.05523134638825732, 0.09055641134299579, 0.050961375311617894, 0.019220889380742467, 0.013054522231311328, 0.07243480833788073, 0.026293087510331988, 0.032663280970507094, 0.020944068185804833, 0.011332344128600052, 0.029658136378613212, 0.018608423152698145, 0.0658997259433231, 0.007063685456335906, 0.016268761903648416, 0.05627885288108261, 0.08890815785214787, 0.015808558523384555, 0.07479333258684605, 0.01735302721030049, 0.06784588804528599, 0.0878946082065663, 0.04791629072579165, 0.024999507830568382, 0.037067692816978505, 0.020507106955553737, 0.052355770246997, 0.047511643084186705, 0.03240775617380296, 0.012256841798643432, 0.05437486008891175, 0.05749062394663211, 0.04671664300164388, 0.017335391866283554, 0.03298325674428094, 0.04644353265663789, 0.04126002471293173, 0.05330224123392856, 0.020812446619534207, 0.08341502398252489, 0.06900159296609702, 0.008483319637185384, 0.024259528182747386, 0.049025720105536526, 0.008354484715739326, 0.02078169585025359, 0.012292733017895973, 0.026108969769050038, 0.03292154836198015, 0.05376611130252, 0.03682264810307853, 0.08546270805621341, 0.049153878954389406, 0.02306665076063045, 0.021501416302916986, 0.03834725500294759, 0.06535515234234833, 0.03717767239938821, 0.05040174042205176, 0.019160414399999767, 0.01875847679442696, 0.03983770204227298, 0.01944080832594585, 0.037016629226385586, 0.06299250654035038, 0.014070297362312916, 0.029638112755492333, 0.06441850260260605, 0.0520681080618693, 0.07701844262379794, 0.0657966717957489, 0.022794662734433528, 0.06454834684489236, 0.05084723587177935, 0.038719167707548026, 0.04207889609519513, 0.021805118453959306, 0.04389413760133809, 0.01706540716000863, 0.0481226901343513, 0.006212744197147268, 0.03604412274134736, 0.05337446034255047, 0.047496378782295415, 0.032543602714976, 0.02020196072877415, 0.039646061317574595, 0.05581727724582438, 0.030912653235117757, 0.01489569677130109, 0.04463320560452919, 0.025796480589516224, 0.052551647437916654, 0.025727268375997103, 0.05478898040770043, 0.04630962431791329, 0.0793819311225126, 0.028057891702760133, 0.11677670517876265, 0.02821390359332004, 0.0018042819001787014, 0.03849945752130401, 0.04053189261485973, 0.02781153506328983, 0.061437152701640324, 0.028381510224613934, 0.026959798509074796, 0.06195171097774179, 0.04235028274237149, 0.023980737295782855, 0.04722742063383903, 0.0649438857010776, 0.05327540900438063, 0.025325139248443228, 0.03544966149474344, 0.04554711019379958, 0.031964505361693527, 0.02686488596091588, 0.043519570402080016, 0.08609457737615994, 0.019875046113626133, 0.04244998908571659, 0.01329866104624084, 0.025325535698944045, 0.030112189030455008, 0.02932187166034935, 0.007464314966778001, 0.03894155537108741, 0.046859334538420366, 0.037106786283754536, 0.03772522608238844, 0.04182649310678244, 0.03733911393811146, 0.008477878497703182, 0.058037894177100355, 0.05628124690584599, 0.10344245456038945, 0.0206852856002027, 0.008408991871551882, 0.03906625150252254, 0.025067915651767005, 0.038273859949361895, 0.045125884409513206, 0.038069651552265694, 0.040453295824268175, 0.05401488686461122, 0.08537538935460391, 0.029305538665803692, 0.10363425233311231, 0.0637695916567839, 0.07890699491385492, 0.07094309725348028, 0.02392491246874054, 0.06579625810826979, 0.015032766180323258, 0.03896387534276132, 0.024302471241342927, 0.026523833193125266, 0.02818821858043873, 0.03753122580688327, 0.027576520355538498, 0.038855087027073874, 0.03786633564760128, 0.030386086530803196, 0.07803519451690298, 0.04746870385603078, 0.04981408203621546, 0.0790817242476248, 0.04566819422067173, 0.025438727104976296, 0.041923330450851115, 0.058209585972250476, 0.007449384391938727, 0.08054952572790847, 0.009787212775629616, 0.04211975922507625, 0.013422073980402804, 0.04188759244918343, 0.04101332524911531, 0.011730706018786277, 0.04247080752505891, 0.03934537180729451, 0.05007144161349824, 0.01272041979621375, 0.025996270574509137, 0.014860384906041286, 0.12962201550122232, 0.02635447605092439, 0.016156796238295013, 0.06577145984216083, 0.0543253823003221, 0.034438877426568544, 0.018158091772948543, 0.08562495781769676, 0.056567710163372184, 0.03063630425341187, 0.03796089771053484, 0.028312635089781497, 0.03499419158024173, 0.03512348423922255, 0.009611982611879226, 0.015147727249460596, 0.02989414700066611, 0.02629200732635875, 0.022882301277751406, 0.019994643929925178, 0.07463083001634768, 0.02575000586558975, 0.02435339693610947, 0.0362126505933702, 0.07038021415111519, 0.017240695737963243, 0.01570031508773325, 0.021472707157954577, 0.024814380768446193, 0.059330663718884034, 0.08602409728712614, 0.014289649402452333, 0.03225788639317597, 0.050101315212105556, 0.02427723630511713, 0.03553749730570182, 0.07912998012597523, 0.02803141953453662, 0.05459329856920147, 0.01968506971494325, 0.026724395011701894, 0.051121085491632266, 0.04110635130576069, 0.01651076907892862, 0.025686956829421466, 0.07843496217843025, 0.009829145555775012, 0.022602541289562662, 0.05972014281958823, 0.05007109304349269, 0.02075192758873586, 0.02899101169239129, 0.02053521855193521, 0.04716696097485481, 0.04694414813251746, 0.08372377273776839, 0.016561702434574405, 0.04790591789529689, 0.018387753441328966, 0.005649964516651967, 0.026996971010380698, 0.05722162366333989, 0.03481892981536446, 0.04398918229966395, 0.046166948102895296, 0.018846705225446535, 0.008344600266296296, 0.03154190253436325, 0.027808897805610494, 0.009905635604574796, 0.02603434705956569, 0.08343313430105487, 0.0688312226726163, 0.030421901141263308, 0.0019311303795773477, 0.027880975187966422, 0.026335362157213594, 0.04857444452242025, 0.05249928149785246, 0.024941863544705897, 0.03239855545783236, 0.04970630495658806, 0.04856553875030049, 0.07639395073056221, 0.04861345754996423, 0.022540062988897967, 0.07988761043957165, 0.020477767703273607, 0.0172141105717709, 0.014393487832539026, 0.007103365937983918, 0.060293869896521496, 0.06730732823451681, 0.024899433765019623, 0.028664112399001757, 0.030890473074490027, 0.0195243789423858, 0.07108721371379591, 0.048570089312570716, 0.03545857875818207, 0.03516828506103447, 0.055693860481222796, 0.07671776843527633, 0.05598358344286681, 0.025821891725964607, 0.027591589305009094, 0.027856630828952598, 0.021082303006081812, 0.033140841030305436, 0.036921645815093676, 0.031139108825535066, 0.05436393184467189, 0.013113961078136439, 0.011819764697593788, 0.0365015653322541, 0.026576275741981886, 0.025415313542790474, 0.08281667867014486, 0.009929644800121746, 0.08985472076963033, 0.07657333021803249, 0.04780336936575271, 0.03760164843932275, 0.019248414919861866, 0.11859922068974665, 0.16080550188499113, 0.2682144915865314, 0.1119415335837872, 0.13200925272558967, 0.1778617140746886, 0.11405910019792857, 0.1084709331212986, 0.08545592051720427, 0.23787019323677788, 0.14701987226163188, 0.10247103975064333, 0.11536556356135877, 0.1481068131303595, 0.1438600047221107, 0.17521943085856978, 0.16566933282921392, 0.16645826549539644, 0.17001251509833723, 0.1173226194336049, 0.1699768766880997, 0.1171181429057352, 0.18351312937034717, 0.10927768499259988, 0.10124666270829978, 0.08960453177531881, 0.08621063969668843, 0.15302258483584852, 0.1628356502060929, 0.09920044186254663, 0.20211193620437579, 0.14783394793348928, 0.13096308305619225, 0.12700625424904208, 0.21319511406604322, 0.07319363374863902, 0.17200330182188944, 0.10836714352931708, 0.1698849921024615, 0.11184164337934026, 0.13149077974019513, 0.11206690387259569, 0.12374649650507397, 0.159361380182447, 0.17887609109522837, 0.1134846032026314, 0.09467178970695504, 0.09723332725585469, 0.11921625854747912, 0.17660255664058272, 0.0861237423434373, 0.12467568454843377, 0.31081357670407145, 0.061081519365430846, 0.18925950892509955, 0.2631422540833873, 0.10360488818297464, 0.14483007121711008, 0.12737481914941343, 0.1389592636616961, 0.22707958435339315, 0.12066447115953892, 0.10943959001451732, 0.1156936790193281, 0.19108099021738578, 0.1130633008095526, 0.09055488682802647, 0.06245662037643695, 0.24059512201816807, 0.20471337161237196, 0.10910729937736066, 0.11263234570862786, 0.14563887620404845, 0.16920487456504377, 0.18364555532893828, 0.07621403498154494, 0.17432660134809633, 0.2020896583675377, 0.12905330246975347, 0.10275143559180921, 0.12196342686131117, 0.15566646151484984, 0.15190751321854132, 0.05687422577231642, 0.10870249085729161, 0.17078820976518816, 0.11123055036390021, 0.1675789295545509, 0.22710976821760978, 0.08758393657063285, 0.1256894486986341, 0.1429441466086334, 0.1040131900639784, 0.17166086051973606, 0.10754667868417118, 0.11668975419935682, 0.08789021852276019, 0.13234490648873393, 0.17585565155792623, 0.12842851946310652, 0.12987716874528316, 0.08009757981785844, 0.12102168263687242, 0.06111709265819481, 0.1719909984498255, 0.19287230296721383, 0.18468093848036182, 0.1010371606436468, 0.15161865210581213, 0.22829944147698342, 0.12969477853227046, 0.2106015080766332, 0.11215645955094408, 0.1908933752847295, 0.13966561204964115, 0.13695146978622483, 0.1377430224731084, 0.1300583485393755, 0.10602809323538696, 0.12042336030713013, 0.11338531054676541, 0.10236207906517292, 0.149037380131983, 0.16193249383040015, 0.16822471103120237, 0.11627250441139746, 0.16104118117401678, 0.15327367781391069, 0.1445690190960323, 0.1829396206284723, 0.09802661130144712, 0.15797252406276044, 0.11175489924367397, 0.1286008662634319, 0.1643395420884894, 0.103403537293836, 0.1479765015744394, 0.09345361797679817, 0.12587075872767356, 0.12073450691757664, 0.17650285795811685, 0.15385064927320327, 0.17251445100672785, 0.17967812386491608, 0.16344246845091545, 0.08792345141691547, 0.09024677392576011, 0.10359282995904646, 0.15342991378518844, 0.18681096934503127, 0.196960071522382, 0.1432188197730049, 0.1670692665802856, 0.17354244907056132, 0.1646364777679405, 0.15971238634759383, 0.10958822639358622, 0.16311487393273463, 0.09432870489094528, 0.11020319581392313, 0.09972365693219247, 0.19006835987731335, 0.15336790662859717, 0.12344849596340811, 0.13446015185646473, 0.08093587152900235, 0.15212243152481897, 0.11590097475075915, 0.1695592974823329, 0.10838212820911601, 0.0843605603421888, 0.15254042441806487, 0.12803899439712688, 0.15618153306986057, 0.1166726780995246, 0.19382298743772894], [0.017208970121798978, 0.055691562217449954, 0.04578346747063822, 0.07887618285754035, 0.07003604149025294, 0.03064751786540353, 0.04780391328817895, 0.015936769083172323, 0.06886720582241974, 0.01617366357916786, 0.005993992099613553, 0.05832112071314647, 0.0506531858005591, 0.007631012826271716, 0.09519281376513744, 0.04892944200565258, 0.027191440514739484, 0.07106808449832663, 0.08368651788201063, 0.06720194517965279, 0.0394876534870315, 0.03616434108886508, 0.07142631487259943, 0.024703345899920792, 0.045062777916750604, 0.026633498679486015, 0.054895252124556614, 0.04677795684866367, 0.04655546576325451, 0.029619270822994655, 0.014533261531933904, 0.012121436715636764, 0.027373677510167324, 0.013716224930249156, 0.039985204611213944, 0.024910971049159288, 0.04303958950444095, 0.030782992853933287, 0.03264614358364094, 0.005579079837433153, 0.017245891729309674, 0.026347136928609786, 0.006666408538172443, 0.07464167016047625, 0.02069195439558356, 0.05950229805743983, 0.025067306611867204, 0.044294104445725686, 0.026332904930196466, 0.031221024692058567, 0.012282687689988844, 0.05038779379139024, 0.1058692602260459, 0.06755597739210052, 0.06647179443990031, 0.02163786613833039, 0.08302417358443623, 0.020180632840962182, 0.06598590317392541, 0.06610604108221109, 0.057365177049031185, 0.05355887302768327, 0.018866922285768296, 0.02238540898918385, 0.03555053612217307, 0.0336936462460266, 0.0043567262248196195, 0.05491530830641428, 0.01637242509112243, 0.020884087331773295, 0.026137368648403117, 0.07083650377969589, 0.02416260273856742, 0.0490622969734813, 0.06814291565528802, 0.04971599979926983, 0.033447230234742165, 0.04630831813800239, 0.005252824057900017, 0.03179891162642068, 0.038892433813382546, 0.042966696238445665, 0.02694958847226395, 0.03878818456864646, 0.057380257489820646, 0.17286677484310445, 0.027903419648928028, 0.06905132739414131, 0.050968584198985374, 0.08165918876447024, 0.0586695145184715, 0.03153173271716843, 0.05647694023566381, 0.02332580872931548, 0.030250123161221706, 0.039394106490597616, 0.029982626325480884, 0.0628298239391898, 0.03250122656144443, 0.06111812304645296, 0.03258022937863585, 0.015725864120008006, 0.018567232520229394, 0.07847352704453854, 0.006304288352464116, 0.04029627844330765, 0.02328975663159884, 0.073421782393369, 0.05121539474555081, 0.02076954952621412, 0.04571857599301204, 0.06319035257723543, 0.02829800281042774, 0.05598203594525976, 0.029662353692636378, 0.0668025529012084, 0.03919972317113031, 0.016112439747479175, 0.04328238958072278, 0.03937646348570143, 0.025150182003515865, 0.057551236823201186, 0.011930550587543798, 0.038920556901082884, 0.018034364742737626, 0.06850649332327229, 0.017778209838715774, 0.025644676436880426, 0.044022610546239925, 0.027332959936991818, 0.08534634696139444, 0.057411038902618235, 0.015138395340932954, 0.10333945403896994, 0.07529694346650954, 0.06004207211756899, 0.01867271133608395, 0.018025324905231115, 0.02706536734026046, 0.07469927997238214, 0.0924062225667219, 0.05947854550134751, 0.0427836854942143, 0.030481874334415605, 0.025725324427889242, 0.021033175702717517, 0.04079165770822475, 0.05387273925026098, 0.06746510404252237, 0.027751590598434694, 0.008709682339441874, 0.019355234389583913, 0.02428825264946828, 0.015259879648745542, 0.009448833654694741, 0.04127536179317583, 0.04621582834290401, 0.06647085981263269, 0.06208537033789101, 0.012523738212973602, 0.03508608765719879, 0.05503079223055994, 0.0737811082733735, 0.03817064875376321, 0.04648099435613521, 0.02010565198537323, 0.03794859816891052, 0.013260842158248829, 0.03555467299696419, 0.11250488399978607, 0.013645116649117443, 0.009889999750040231, 0.020028713775137742, 0.014212392308118363, 0.07403116703273789, 0.043633299984879075, 0.04813063063568646, 0.009547209877881312, 0.061772231898841366, 0.027531171780860716, 0.04471824136412433, 0.008967347394284463, 0.046060687877357974, 0.08553006250651614, 0.04928181180730463, 0.015492485009975012, 0.018563764057152213, 0.016680461384596366, 0.03306052820276349, 0.02598824963394192, 0.10505966616854553, 0.06811576549925151, 0.030365716252896576, 0.05694325795517333, 0.031966721271014506, 0.013190357281165499, 0.007891033601481467, 0.028553726789992184, 0.016555020232654868, 0.03817931320818682, 0.06324064624946445, 0.023268658570164157, 0.0868503537569796, 0.03227104012283587, 0.015955382146902623, 0.05883806918357169, 0.02105735726804743, 0.015618052566424014, 0.03801283464136143, 0.017065761475673607, 0.03293242298006531, 0.01166421820544788, 0.01308722460957905, 0.030084841606778004, 0.05130805691043216, 0.02907254068451303, 0.0076840601057835654, 0.0586571115549774, 0.0337293689259358, 0.033825528282191486, 0.05983779094211998, 0.06140051837710123, 0.02317503688015765, 0.011128256390351924, 0.010778039295767105, 0.02524849981249821, 0.01881167202466919, 0.021525143961151762, 0.042651466379362735, 0.027856801283515753, 0.03736899136715839, 0.1101821973439186, 0.0366617466563419, 0.025661041990162867, 0.10598749823627934, 0.04079164621690589, 0.0656389419530188, 0.043363771100919095, 0.039674919849682244, 0.055776640111880924, 0.037984351492336685, 0.03622532934851704, 0.012955463232262241, 0.05329689010977746, 0.05681625972952574, 0.045423157167651, 0.02260247808730891, 0.019696518898971623, 0.028105402560604197, 0.056353059987868034, 0.011278859700166411, 0.05244743266713716, 0.06443394693515955, 0.02469804457148477, 0.034905516903006265, 0.10203526595667486, 0.024490907803298007, 0.0620183797793523, 0.0046092527449100975, 0.019615376781251644, 0.03067057136626494, 0.016265760754205046, 0.0677186255193045, 0.028965813145341895, 0.07097081431458074, 0.04399766672342535, 0.021197647119181293, 0.017143651550155015, 0.007045774320666228, 0.06142543538683846, 0.07756968118971394, 0.05832242306261774, 0.04040319367402023, 0.0042326343452347625, 0.03571228792650565, 0.031205869557696487, 0.022321879232843077, 0.03295384279842819, 0.03672957991159732, 0.04785959255851565, 0.00865469063301721, 0.04525014004039188, 0.047485833582017696, 0.01135308117110042, 0.05060917404930919, 0.035097555993425275, 0.011638348373854834, 0.06525438113678848, 0.04293528280311054, 0.06338465928791032, 0.048536814283579595, 0.01902202444691812, 0.029886342479937503, 0.055339793794818466, 0.07230710148090318, 0.08317023590807954, 0.03939431716477679, 0.01663013706885038, 0.07107304108719673, 0.017737049849763993, 0.030636712195231553, 0.03376999073812077, 0.011050437179003513, 0.012259376592062896, 0.007423258878500953, 0.03025914767696973, 0.12800769970542, 0.050669262155650124, 0.045382497051069816, 0.07048418760419854, 0.04123044988861488, 0.05351927394287721, 0.03205406295526172, 0.05018386884682602, 0.08546085412343664, 0.08159806260899191, 0.0727913533187201, 0.00812566191363599, 0.0275125558443007, 0.03895130383992388, 0.019982398014455553, 0.04188896757700751, 0.010361483774989123, 0.03390761460327814, 0.04685478014571052, 0.04417374437194198, 0.0397885421801719, 0.044564338130575996, 0.008667048588845759, 0.13684512146057623, 0.017157695857026888, 0.03790900291454408, 0.015588074588337013, 0.09082303292328313, 0.028163816764830586, 0.0400749518115434, 0.036567383776268655, 0.051977047020749706, 0.020600592664953683, 0.030621911376534455, 0.007654920993973652, 0.006609980416889753, 0.016465636924089446, 0.029988695657060995, 0.056918616737088853, 0.038118256000621666, 0.022641161697045453, 0.047722811390075, 0.0787094591425792, 0.029038051406161922, 0.06331956862742383, 0.02010373868078234, 0.056906240586672104, 0.09751411380186197, 0.11767627626296975, 0.16117107904245778, 0.2074320491163, 0.13204452341362355, 0.1284997273356684, 0.1218566035611495, 0.18228156642327387, 0.05928681284609822, 0.14649373839699453, 0.1451130487745808, 0.11012269529483973, 0.10610922960744751, 0.28720948845148087, 0.24156650618439723, 0.07631679035482869, 0.09543386333051229, 0.21770318909998865, 0.07054722131860834, 0.11025761103918476, 0.10550871626624178, 0.265185778299647, 0.16840624322573985, 0.14562537773482262, 0.15133676239319388, 0.19640137892096274, 0.12731411434229345, 0.08578431942770559, 0.10152659889671112, 0.07783821798981198, 0.16646664649728807, 0.12106521941360929, 0.09005336736839625, 0.13335814969914575, 0.120499900151645, 0.14226142437227313, 0.1382785638974559, 0.18093836914387443, 0.10463582036355812, 0.1308181238991599, 0.09957087601745322, 0.0871561454128354, 0.19858192562335925, 0.12160848300423353, 0.17516805700236754, 0.07929589178773665, 0.1357857597571227, 0.19535962191800918, 0.1810596561840465, 0.12282438711413454, 0.09576513507072965, 0.18459800180167923, 0.1605377694772136, 0.20502685479098753, 0.1340358157552058, 0.19199697090493095, 0.098608861106538, 0.22504844011798983, 0.16575105908897617, 0.19679091930870088, 0.17707984473916794, 0.27888487063107953, 0.25694251901680426, 0.10422773298717315, 0.08711048657254827, 0.06263171743241049, 0.1842409128984136, 0.10328857047903924, 0.1560738517512237, 0.2301348196042161, 0.16377030811723203, 0.1269721939799286, 0.24193505576301008, 0.13775511134055354, 0.17482158607773243, 0.156327442175919, 0.11442489186001402, 0.14099469798947536, 0.18714927377239352, 0.092135418146368, 0.15506754929740585, 0.24449257901118648, 0.15231710978813712, 0.1612362271595386, 0.2962207968436903, 0.11526284649247125, 0.14617559740379935, 0.13684049428951356, 0.23838086744710324, 0.10769023590030209, 0.16202275430963886, 0.1794224650028252, 0.17594736760422108, 0.2191144149870642, 0.14168630684575728, 0.17831597357026993, 0.10200191814933093, 0.10273760004389672, 0.154392350044462, 0.13129204121087829, 0.11224316538221414, 0.10226631807463785, 0.1284831721756247, 0.059782464072228446, 0.14446345218006643, 0.08090319021815255, 0.14803515326592231, 0.20511132364551868, 0.09998738270012603, 0.19700899389722656, 0.18065836400754992, 0.13089290940232817, 0.14684508164082805, 0.1574306241086414, 0.1633916002127432, 0.08848955974944177, 0.10847009042458189, 0.1698446345906104, 0.1999882332259609, 0.06615491749178018, 0.18929094917351202, 0.24622606744448988, 0.12088341142741904, 0.11491884237095235, 0.14271263483791582, 0.0771934707318583, 0.10125049314792119, 0.14393679737564058, 0.17855395112306843, 0.24286747669741032, 0.19812504610707685, 0.12303854699336714, 0.16009513919632282, 0.2520683152420867, 0.2117487400650017, 0.13483354311075904, 0.11722210869793931, 0.13435617840338138, 0.18948565808034715, 0.2419531201162646, 0.1486949847951051, 0.11127789459762075, 0.11202958772980398, 0.0912795523782411, 0.07706925723581545, 0.14049727710024004, 0.1268948650648517, 0.15574556775391102, 0.15242258477355206, 0.07972003636701454, 0.0970675458290404, 0.14095968777133575, 0.24750695113212834, 0.1072576413712194, 0.188184181949304, 0.1540595308066376, 0.15510438280480524, 0.19994888695016985, 0.08517444449206514, 0.06554867381290083, 0.1142451446503401, 0.12538784754372415, 0.19012767040441114, 0.14084477458269368, 0.13971824229003924, 0.13813306847887655, 0.13037581537519732, 0.13356908434821715, 0.21709647810747548, 0.13000498285457013, 0.13936985614559344, 0.20654133400849758, 0.08713816532925253, 0.20093280431484023, 0.0827123987818918], [0.07268655249067853, 0.1556782133036083, 0.05738103123862417, 0.05222392651522833, 0.08468078509453805, 0.043660450140915574, 0.05102342843348461, 0.008915492817909728, 0.07449442806142954, 0.0606596194237711, 0.028286381256616408, 0.032334307494062575, 0.025655577868042935, 0.03864752699530894, 0.039958498786173524, 0.017314996690519394, 0.025829811159881855, 0.025179490612279025, 0.01233552477412647, 0.044888856805740826, 0.06956858996061549, 0.054422533740439726, 0.04265362291686958, 0.021423160421451735, 0.025876521455845045, 0.016407412326624318, 0.02946057187904033, 0.04236427916874809, 0.011308313865635184, 0.026047868511429238, 0.045192246775954, 0.04543519240894145, 0.03301469699269341, 0.040162040686775605, 0.0699945118638777, 0.055781179182832284, 0.01912630433517118, 0.023550937072403973, 0.04957197909994472, 0.023101829518113407, 0.05400566316600289, 0.03725576357194974, 0.02508753516350783, 0.051610634827445594, 0.0673280509128686, 0.054073684112799746, 0.044167523737996824, 0.025284814295328917, 0.016530346455833605, 0.011914773006743241, 0.022210193189582037, 0.013100922261665185, 0.019094279944716443, 0.05283342223734625, 0.007754805931566104, 0.04057394701146311, 0.157523657826166, 0.004107620766116006, 0.021897006870037126, 0.05493827945282383, 0.04526139770243918, 0.018447868360747254, 0.02809084497482306, 0.028959483343867526, 0.017513509223898573, 0.027109206721727407, 0.061323323527411114, 0.02541437700030304, 0.04548591125996844, 0.07603954313503158, 0.04081332267472341, 0.0289684446573618, 0.05337372106770354, 0.10485140516632989, 0.029316803988730235, 0.01829702564845643, 0.037143704060825615, 0.0466809586261309, 0.010092171310867754, 0.033507122988662416, 0.09297452191071165, 0.08550975351564347, 0.0981328983400618, 0.045203236307227807, 0.02713551226582739, 0.04348503132801383, 0.07912060320978204, 0.04422804085357536, 0.010107725768560364, 0.00831515088887705, 0.03891078161916906, 0.05358293967982454, 0.09330020120908177, 0.013048701878306607, 0.06630684804892348, 0.059076782180777485, 0.039557183627039194, 0.03488203630812707, 0.07074762991960011, 0.02007237695638211, 0.037965015433127844, 0.02877752214009243, 0.041032469786343076, 0.041648232107681614, 0.014149211121783143, 0.09719373583192788, 0.031742391574587074, 0.015900227646794052, 0.0012964805195693888, 0.07711609585150596, 0.047435631840339595, 0.037989457468352014, 0.02969239966102666, 0.008032328464210996, 0.030372124578383182, 0.02272277495883886, 0.0333781712388079, 0.08859805312127837, 0.1609203231430823, 0.030968045222482858, 0.06383468997814963, 0.022076367205309293, 0.019928836977229487, 0.026573314812154542, 0.09422706034515174, 0.0651703029870987, 0.030319737570901072, 0.018273045181206638, 0.053014659488032904, 0.012655563750154069, 0.028004252141521826, 0.01997495738549098, 0.01899935015957923, 0.04820795955076333, 0.04576006731499107, 0.045092119084250544, 0.03361040696261391, 0.009060043075512494, 0.01625560817398852, 0.07431042906377586, 0.030503137104754007, 0.059373989821441715, 0.037682321328189106, 0.02194855692646196, 0.013681343989446761, 0.0062680327626425895, 0.02621364036214448, 0.06300009081080075, 0.048459366624874455, 0.06939756849239911, 0.04385722365470664, 0.051194752506431074, 0.026568377375482555, 0.02997347157478573, 0.03495779091251954, 0.025679418524246544, 0.07830691824276602, 0.0427057245565999, 0.0236745051393706, 0.012507809329808, 0.03540664182735547, 0.05307350653193651, 0.047066312343362844, 0.0769311162613092, 0.031455156483477166, 0.005672346254164774, 0.04425485776136479, 0.03314485916146829, 0.028863685964156064, 0.025405877254783146, 0.032484537336013974, 0.03621819706994199, 0.029723497085093014, 0.01277439069047931, 0.012570008965990236, 0.06563313500655275, 0.008290163973616737, 0.06991332186566246, 0.027012953519701, 0.030242579110387354, 0.050562163063835715, 0.007675675273452315, 0.06408725767546604, 0.01526761809439068, 0.03644706966776041, 0.044520418309877, 0.030561407667494593, 0.05079283979871581, 0.014583486256249731, 0.01010988709411674, 0.02484070737996409, 0.02832165385987009, 0.021582269222445546, 0.021374375942433556, 0.07363867720649128, 0.02645963119463094, 0.022100596651134473, 0.01359449930474042, 0.04543774731216892, 0.034081367174944574, 0.020423632100104325, 0.07009991790137945, 0.018571875013050534, 0.042944441384245316, 0.056823066420732975, 0.021649476200822863, 0.05284995441475222, 0.02771142460856467, 0.044102793138834744, 0.026609690582019188, 0.046785636880104585, 0.04723507385220259, 0.07384554392868474, 0.05005835300131191, 0.032733803194376736, 0.022671113819665006, 0.08738789467080947, 0.022627678549578114, 0.0709798081868118, 0.04991452382396787, 0.02332947062959354, 0.005930090790629508, 0.012873087712984174, 0.05822422974292309, 0.011148658269385417, 0.04730723167379056, 0.03276020258424744, 0.02586101583625761, 0.05289770850551225, 0.038041222029395645, 0.10611997016014592, 0.03221071069879878, 0.12384727537151306, 0.06802104638829347, 0.03708963740556952, 0.02698566546783813, 0.05131223975049873, 0.053641782893288525, 0.02891264855861664, 0.03039636934596685, 0.08440674778314368, 0.013512593971925878, 0.0193111690121793, 0.055754519323067325, 0.02930465574947096, 0.02650198819596441, 0.024493937681038535, 0.003440516429104572, 0.053914058202457045, 0.015382684500617607, 0.018645231762240012, 0.002239637458021002, 0.05754377895725831, 0.017508160014967286, 0.035538684741984454, 0.0385800652926968, 0.025459313802721522, 0.056454202746071165, 0.0505720034632231, 0.026742673869575226, 0.03836184897790513, 0.07708677000576451, 0.041062707276714426, 0.06419300845253371, 0.03131877942641657, 0.05112810285701867, 0.04398501861179548, 0.012285534664237452, 0.0448747301444171, 0.05337075630743658, 0.04290647023627835, 0.02251507703124756, 0.039534223971948515, 0.050225674264854005, 0.04818265949706397, 0.03618203005903671, 0.03913523005922476, 0.06530425346065914, 0.02645124636229969, 0.011507183587509058, 0.019691114148665822, 0.012593923358156556, 0.036396883247840794, 0.002443130520517908, 0.027800032253106757, 0.07515242864047328, 0.03880375913614708, 0.06416762412916269, 0.005220063265428068, 0.03149364091035339, 0.09695530628725406, 0.04349990492506374, 0.03687052859834606, 0.022507092479856747, 0.024802630894907543, 0.04036972329260842, 0.030110654939386635, 0.04851000886710902, 0.017068153585217172, 0.08781219246767222, 0.037566856556241555, 0.013946998383729689, 0.02699905859997436, 0.044160314850629344, 0.006444655770000311, 0.08071200531576911, 0.006044159367335059, 0.08411780240074282, 0.04981934506025526, 0.02861314265417957, 0.04738480573700321, 0.014532431284145964, 0.03461277938538021, 0.07767416026082732, 0.04804237347636973, 0.03814535253050347, 0.04397208321719401, 0.010792505908607235, 0.010104114621607287, 0.04173512946093275, 0.047129763575691375, 0.08165967139986255, 0.035238385936545755, 0.02292910541948532, 0.04919320224754272, 0.06681447322931021, 0.028608502076578238, 0.024889733176678423, 0.04236859224376179, 0.024435759048848867, 0.027065284985808596, 0.05129485721549681, 0.11628781084812458, 0.0649188652694706, 0.023969177029005462, 0.1026054805204753, 0.04959421480194696, 0.07463227026164532, 0.0069749312974782965, 0.08251713063087195, 0.013203737006763057, 0.06467873500960489, 0.010199796130520203, 0.038666575771546176, 0.026783232479506446, 0.015562005573883654, 0.03656099077254053, 0.03011006888212456, 0.041096648802199674, 0.023903297297956965, 0.057790999360863245, 0.09152562748039923, 0.19737622580460965, 0.29980847852364667, 0.09069521881399617, 0.13332985041122283, 0.15157424964972083, 0.17474290884790883, 0.20736175288836803, 0.07987703842621657, 0.2083451646350084, 0.19908095529723555, 0.14085978990600956, 0.1012945585253258, 0.18349265950101037, 0.11309266495969027, 0.19101604128316527, 0.1273783967800198, 0.1740126431949677, 0.05802039672890979, 0.19443378933975775, 0.1330591609040576, 0.16007765706989074, 0.10001597310146017, 0.12267196626071969, 0.08865426865316207, 0.0552697312237034, 0.1900894119734726, 0.18219155109217092, 0.19391750736582666, 0.1063114308541821, 0.19867892767633163, 0.15137096055813376, 0.1424884315459959, 0.1450226810430327, 0.12947173969399545, 0.1745955748183112, 0.1352129251726212, 0.13244771548817236, 0.09267298970371486, 0.19142047442015142, 0.12826011035471194, 0.28770974386603604, 0.10905217935120869, 0.1758283175407879, 0.16758312771637596, 0.21887156511506728, 0.16906967536816675, 0.11569861262556046, 0.1820646562883931, 0.05941712440201833, 0.08674561421597198, 0.06761097484418462, 0.12123955038165855, 0.1695341391548995, 0.12703482166773852, 0.14105019339871022, 0.14838278864420232, 0.3603566053413576, 0.11042641085242072, 0.1048702892336634, 0.12399951236382609, 0.10518133625267975, 0.08120892824785364, 0.22913703604811625, 0.21001456215256648, 0.1449255870595094, 0.08729504481438669, 0.14453077598685218, 0.13645308362620492, 0.11220509847325665, 0.28599232795738405, 0.15875571106951084, 0.10126725515170444, 0.3420055206985243, 0.18066662243537365, 0.09017489189582487, 0.1283881389686177, 0.11130537417146469, 0.12798060317553822, 0.18044719953210125, 0.10830394893644318, 0.23603624003308438, 0.1774343136217325, 0.20795180912940733, 0.09380669257934056, 0.10061218102853145, 0.2141196136513064, 0.23289956963591038, 0.1541942090637261, 0.07783801880695167, 0.13976731788246863, 0.12428133312853114, 0.08738072408783822, 0.2234898648795582, 0.08847236873642092, 0.1103432749908778, 0.18296228150927252, 0.10803459242226617, 0.10502837913771791, 0.13796462106608576, 0.15317914256405446, 0.1877230736276796, 0.1339306012396851, 0.1227543666778553, 0.08716335430020287, 0.11930374578843195, 0.16226296883917626, 0.1507735958382968, 0.1754522603005171, 0.07026743834778186, 0.37296745445459123, 0.13424183211980328, 0.16688638607100134, 0.11879929221205174, 0.0906170472022026, 0.19637528596626175, 0.12183418782848505, 0.16375207522463414, 0.17746762312468023, 0.2764358407547397, 0.1385716844590441, 0.08526391590074187, 0.15503621630130276, 0.09648226231576935, 0.16275829064749903, 0.15087787572654987, 0.2300978635227488, 0.11058224079709862, 0.1214303982053553, 0.16021193696125863, 0.21832830152444302, 0.13819345152906834, 0.16999420559694692, 0.1465246577056185, 0.12419728562235834, 0.16719018589825402, 0.131505289445481, 0.10195800598951117, 0.14203590340912342, 0.17220908836010965, 0.14107968778379504, 0.06416215426138332, 0.18026857847167602, 0.14648051571942147, 0.11834233608697692, 0.09361352350923324, 0.1411448818661513, 0.13886089797221846, 0.12863679578708065, 0.11294574461757176, 0.2223519791638659, 0.14393108235972543, 0.148225526115106, 0.16985672345805555, 0.1020644079413145, 0.13916338012824137, 0.13744248618041316, 0.2381817918390997, 0.13415575448063113, 0.1611155989549814, 0.17149731606966065, 0.11145317551469612, 0.1105391406904786, 0.16616738191054714, 0.20485911217908706, 0.11582608965616073, 0.11100577250603708, 0.12104137109652643, 0.0926775785703813, 0.061944804695104404, 0.12020671830302286, 0.12168974961124121, 0.10376731414468059, 0.10198222968967692, 0.09063516518161183, 0.1391661227230103, 0.2144516055141726], [0.04884065241522847, 0.01005596791078607, 0.14444287505842027, 0.02268335781991482, 0.05896924258840661, 0.0049320601711740665, 0.03806659103100819, 0.035554370392234094, 0.0430644758706612, 0.05412573595681498, 0.010145478581468905, 0.06457504500905353, 0.03344588191999543, 0.038139216166229985, 0.047588102489469514, 0.0018638737251861924, 0.05471260144164967, 0.030035043976479964, 0.06415471937807818, 0.14275337539372907, 0.049023345232971256, 0.05993997174946051, 0.04882971651010937, 0.04929699183952424, 0.01443722762257582, 0.004791740155328186, 0.06572763195201274, 0.028253244123451655, 0.040659078532048774, 0.019848598843260158, 0.08396532026029403, 0.043537343641923326, 0.06294087987513312, 0.01332677743067184, 0.0444485784147776, 0.08984157470084968, 0.03314744087777311, 0.048053998860620686, 0.008178678070825916, 0.04654859778501334, 0.052437756976653496, 0.013603276757132864, 0.04677926685901419, 0.054930545795228214, 0.02027054283497555, 0.038110962843582515, 0.011008890315649972, 0.07003276263393703, 0.09655551564308906, 0.05226691170865971, 0.04673380720158739, 0.0305902413017447, 0.021044552108393084, 0.028213204538089134, 0.0430911242391073, 0.0564229961544756, 0.08272759796630952, 0.07045778055344859, 0.05894750867399478, 0.043852404961662914, 0.041126825005537083, 0.05068834923628358, 0.0262151476401355, 0.007584952268629305, 0.05425329725708693, 0.035561487349050666, 0.045745458018275044, 0.06189489789727715, 0.06138695862084147, 0.03144973449619307, 0.03728552225736841, 0.0435542167284556, 0.04394648055876455, 0.00415056957037098, 0.1306629757727346, 0.010460154942026543, 0.06551889597528404, 0.055716015743992986, 0.06465128607927792, 0.03356977365911007, 0.022749660814541484, 0.040295523846702236, 0.10586458708970778, 0.025923582237033595, 0.02624206988501453, 0.0660840313761465, 0.027064834909153082, 0.05449230519814357, 0.004549981479818423, 0.05325684669397531, 0.029213560234394767, 0.04116967613358171, 0.037941308842310985, 0.04809328384937779, 0.023462090025385542, 0.0348092885988374, 0.014023294995328592, 0.05711665046551535, 0.04432191343737706, 0.02683132173373334, 0.04830527186934506, 0.0437035502475356, 0.05165802502644159, 0.04987754092942323, 0.005780680662757087, 0.004633564545187138, 0.019800017377541914, 0.005941442298447533, 0.020157722981586572, 0.037920544029123364, 0.058625889641623345, 0.023246223685301604, 0.04926743233696588, 0.013658083644845794, 0.06984605934591064, 0.06900058939091622, 0.07136858248662564, 0.02637179155323294, 0.06620058399294654, 0.05252752715962068, 0.07349671345324287, 0.033070701850397934, 0.007252437550754797, 0.053563262711489396, 0.044641483184551044, 0.013582386497047641, 0.011300720019085754, 0.07305517867808381, 0.06405712743740409, 0.07100201707573668, 0.017778866759110844, 0.03258686753049974, 0.034534780143369595, 0.05694501995739918, 0.03454372805032519, 0.07600899920949052, 0.09904424419566508, 0.02797777039719926, 0.010917466340376245, 0.08116697727312004, 0.059897461530542186, 0.01931341173457763, 0.06321905789175822, 0.0076740229175606325, 0.04785606855406396, 0.020101712378222617, 0.025475464851385164, 0.05493279043284636, 0.06606912330514, 0.013952948014071632, 0.074420990873008, 0.06638012435888091, 0.0023867275364952345, 0.04705382127975745, 0.04573470214381815, 0.03981614815852335, 0.0293496749063413, 0.02006047769569822, 0.03669248976474328, 0.04684844459857672, 0.06956662877552933, 0.05270006165148751, 0.03270577586766693, 0.037380597599211245, 0.023986956014508204, 0.06355513300326082, 0.06664393439648614, 0.03547423376491474, 0.0793190965909631, 0.04204655952391125, 0.03839328156543836, 0.04688767596117912, 0.07457760988824791, 0.05710483355928333, 0.01034467772115022, 0.03589811021341913, 0.06960426667524923, 0.013623120349591539, 0.040760037429150076, 0.021756558055658976, 0.018198828498322158, 0.0958635084210865, 0.044748444380539085, 0.05217317319024475, 0.05214758585357378, 0.04287355526861164, 0.06695671277421136, 0.06377934778649962, 0.009725064850382267, 0.024512953898538987, 0.03044845374871887, 0.02366570661956024, 0.061248515041605125, 0.03102964443725444, 0.10622180622792053, 0.01521774385530021, 0.013899773851247325, 0.04571368835205513, 0.054637655060017304, 0.06989710378430544, 0.054643435193406004, 0.05062596669660942, 0.012182970812934782, 0.0253512283727046, 0.106228226044726, 0.026367903657017217, 0.07298482882399714, 0.02568800828509754, 0.07727192579618386, 0.017216219228782484, 0.05464341987164752, 0.056908220923956365, 0.059943951576227145, 0.05780374706392327, 0.010331094982252728, 0.03051638276496482, 0.027981303977750005, 0.019532175802235163, 0.0035349551997628185, 0.04600135436762245, 0.06487328303797592, 0.049707530697266904, 0.04971294693889157, 0.022676508993871754, 0.020465337926702156, 0.04762189845824915, 0.024818981126431498, 0.01868390005021807, 0.03996589153464283, 0.025215075396361853, 0.07577603187171683, 0.06351817309135391, 0.04184195276109442, 0.043209902341327364, 0.05329617381756825, 0.0668864548506756, 0.04878246420693975, 0.013186135179092808, 0.08350246525820225, 0.025484401267021898, 0.02310306675011112, 0.02248038473959652, 0.02686868575702031, 0.035062940310566656, 0.10083135112278885, 0.01992075858006795, 0.013388278969233076, 0.05886788149514507, 0.06390210571548631, 0.06434960065469628, 0.16432074229082755, 0.04926008555377203, 0.062440892591351466, 0.04758337955741633, 0.0735286133544099, 0.013078923089309566, 0.03079182776292005, 0.04936974720969316, 0.010827421323366223, 0.02555312892992891, 0.03244078988509794, 0.03589785740440411, 0.02749879115952119, 0.04821721389288864, 0.0259210235033665, 0.1060845845589234, 0.06324905789487305, 0.08628816013374636, 0.011887913006508063, 0.043896822739512696, 0.07119344712625589, 0.07889246222593131, 0.04397785952014308, 0.04592330916033638, 0.026483837657818393, 0.020089188755880442, 0.03248974290345946, 0.0210491907707746, 0.04859037149036604, 0.011573341983040015, 0.035774249117821455, 0.019737772733694123, 0.04475906618960923, 0.03310834741099708, 0.031652403056561466, 0.03769095896953537, 0.019634258933365345, 0.06487034126034667, 0.03867420217683239, 0.04596951575348935, 0.002572589324817302, 0.03155901693859168, 0.013407108452801984, 0.07098975966894819, 0.02559702768320999, 0.04708577863751881, 0.08756466179845795, 0.08046917076553069, 0.024979413344314503, 0.06229482643726853, 0.0186996374114026, 0.07797589165068443, 0.008368797153384696, 0.035721028989721695, 0.010056341378649157, 0.10833907406777145, 0.014322277087147438, 0.024042790417649576, 0.03128675312074202, 0.02674631853287499, 0.06499604096696263, 0.07825687737955202, 0.040005475297690406, 0.026510882476765304, 0.015828773668486507, 0.08214776899905936, 0.05175406563906901, 0.045773370431796204, 0.06170902198420898, 0.07076859008520842, 0.026427072457849022, 0.05033925063006821, 0.03033857950339875, 0.03367451703055732, 0.03129266157385803, 0.04039447559344192, 0.047733172729250886, 0.04169268435948799, 0.034712539354880015, 0.0024743064685965018, 0.01996222883462906, 0.024648674035204515, 0.021174245048314336, 0.023484785380142353, 0.014789426012054808, 0.043662660304577126, 0.014864783208336563, 0.008989061198888287, 0.07247360303036629, 0.05900861567727501, 0.04130203697469927, 0.015752803601865328, 0.03487865786038099, 0.07036315337304147, 0.020054653512253877, 0.06638555592226406, 0.04831100986789792, 0.023845072700491837, 0.03959097193493959, 0.027620409532720526, 0.03347446083001072, 0.049125572005587245, 0.27251576884619655, 0.08379211544149345, 0.3550610378865273, 0.1054125032838314, 0.13154334869355927, 0.19358965237775158, 0.10514909161194678, 0.154604219320801, 0.0993418770151273, 0.21702429730324976, 0.15171830482300253, 0.18347886991837334, 0.12235865928232671, 0.14750168027897037, 0.10573350178498415, 0.16056654373964957, 0.11348799697213596, 0.22536206119243177, 0.25433497022717233, 0.21482685070124366, 0.14037959067331207, 0.1800207183846543, 0.22456995692224274, 0.1438837381260049, 0.1207323695322679, 0.14121352334416684, 0.21904119230326147, 0.08739259845066456, 0.23469926338763009, 0.13737301732743942, 0.16167468992212128, 0.14821130752323136, 0.19022159278392795, 0.1219339018327094, 0.14270642952572915, 0.1565868548688389, 0.15635555760274011, 0.11098144921444117, 0.09185891403185745, 0.1188047084536764, 0.1178590341981861, 0.14378454506156907, 0.14277432023757888, 0.15663937785692755, 0.11270274918886924, 0.1536376615084948, 0.11098644410770749, 0.11532115344438823, 0.15824336678751055, 0.18104228130992384, 0.15221298311746892, 0.16141639571757088, 0.1667194861558176, 0.10125301357719207, 0.13233830281082662, 0.17246546734484935, 0.12368228301526078, 0.11562644714309324, 0.13120234763670352, 0.15217127729087107, 0.14528284450211834, 0.1741608658865575, 0.11544414119975221, 0.07126760443732624, 0.0842494163061342, 0.12797092748505454, 0.09880072016629482, 0.2396880585940615, 0.1389577314858475, 0.16035190122502466, 0.1397764036852506, 0.10408465840643454, 0.13681104586970422, 0.11107242981632871, 0.2987614201922571, 0.11514997109770776, 0.20716690608570654, 0.17304607006090303, 0.2563174832011423, 0.12200497947032414, 0.07476678764026973, 0.07118960902575525, 0.21006667145317603, 0.08419896941632034, 0.08868148009623252, 0.15397215081799417, 0.07177994871932654, 0.13709370167024676, 0.1926496012076255, 0.21121906687415418, 0.10734082319803777, 0.14942626168410625, 0.09064479490682002, 0.15132121080833097, 0.1824954428499745, 0.19664746168400013, 0.1178945423734765, 0.21112249383041937, 0.10383731925920134, 0.12925466101977134, 0.11433526723375244, 0.154497227481296, 0.15456436742697993, 0.14291406999672615, 0.12764691059748012, 0.08712769290732761, 0.1594566815202275, 0.13730710312243433, 0.15094904529471553, 0.14539218057067166, 0.1912709953443658, 0.0954081993850489, 0.20885685008139382, 0.14068242522978014, 0.17510134606592118, 0.1321377256704915, 0.15518548087246958, 0.16735080389245865, 0.11915398326011435, 0.17770514102472415, 0.2272916221690755, 0.29088916196938486, 0.10912215382221246, 0.19584582728003302, 0.22038489520069093, 0.18349868095209523, 0.09584205795920665, 0.16785554858225007, 0.1670386996721068, 0.2072508540004492, 0.06482223093870186, 0.18969005033854516, 0.12061226226749922, 0.14861241583862614, 0.15750746272744673, 0.23633427887914643, 0.20954015454457653, 0.15934546087538043, 0.16532922043435036, 0.20819449046206093, 0.18577026954341322, 0.1810883998029655, 0.13056574389338493, 0.14000282863215094, 0.15626872919740217, 0.18375757270522658, 0.11103424033330334, 0.11741798205841934, 0.12570477045711972, 0.0970890958823504, 0.1387317049046678, 0.11043964119087304, 0.167645380021103, 0.26770081431154286, 0.13513204160957568, 0.1579398733954276, 0.24506161379958355, 0.08775803771230482, 0.08966377335450343, 0.14291745610535145, 0.18524560656759048, 0.10107777096451291, 0.15885058339805375, 0.16061899011894581, 0.13128690842178561, 0.14985867235208714, 0.16649250962561177, 0.10178067195679873, 0.1479419969743298, 0.13036804724364512, 0.137582128687251, 0.1383567048657325, 0.14900327389759405, 0.11367830087340648, 0.10207341713530403, 0.11570658760085223], [0.029577867601126916, 0.056268817129274534, 0.03269832183216368, 0.039191503047702775, 0.023918211114622896, 0.06627855642187981, 0.06929277532523678, 0.016362873889926462, 0.03115116704946324, 0.03367079384324532, 0.06352279260153733, 0.01838672688351043, 0.013171505772568768, 0.011684444841868695, 0.054040198409629446, 0.023574649408880263, 0.06280540488660336, 0.10340310062371916, 0.015514516741067413, 0.0625869587454344, 0.021630800892448714, 0.07984931370423687, 0.011168366838847438, 0.02486670265845474, 0.05592857449946385, 0.05888416852441527, 0.06495130143218464, 0.058660444037448016, 0.10588936237317902, 0.02718486939556897, 0.028517333783149242, 0.045608833897858865, 0.044094343189029925, 0.04262435835816207, 0.038077193687880234, 0.07079804616589701, 0.014077084901322041, 0.030753370149121172, 0.030954217335449594, 0.06223136371362114, 0.03707842570879767, 0.030032019844398867, 0.04299691840705853, 0.07463492858674257, 0.04367715851854413, 0.015167804498736177, 0.05361679693563812, 0.0548629806707463, 0.02228433134845428, 0.035844602802347754, 0.05691871249807939, 0.07979988571136229, 0.046345645772112955, 0.023425737238158623, 0.048188370682539484, 0.04423785060944577, 0.02206379761769166, 0.026302918333620317, 0.04786953254933319, 0.08551993482415715, 0.03910748618504694, 0.05823622667981733, 0.03982881925279095, 0.04800412653675003, 0.05930124594259167, 0.015569734443429739, 0.02957474387761566, 0.020677818158160777, 0.036618117949054126, 0.04275795643127734, 0.030874480989070672, 0.04848389676020992, 0.05127318075767929, 0.02817025381861435, 0.04723716144179625, 0.04415637332825892, 0.042494793737968134, 0.04603277163339719, 0.013059710561778518, 0.006459494414288672, 0.030984705719616146, 0.028713791285671537, 0.04652236693448598, 0.02769872861643953, 0.048733802301989454, 0.04822468325015038, 0.0628256372686836, 0.017606977696320223, 0.03544280883826075, 0.050605623231780146, 0.057252286332509214, 0.08200031239539385, 0.037984374474974415, 0.025337540296717517, 0.022635958044819778, 0.08277134924766519, 0.04735775900283649, 0.03910878853451821, 0.04608057551987229, 0.05302171132737591, 0.04065228333216041, 0.08945286168806976, 0.06107891466648829, 0.022340114040660764, 0.06363216314404722, 0.04215637056697761, 0.0521193478526848, 0.02421477332621092, 0.018658954312183687, 0.016170980356213067, 0.08769737887046031, 0.005098965832017242, 0.020981547122280446, 0.03241147170023572, 0.038054827750930866, 0.04452542469446217, 0.07999165284056818, 0.06393487895688703, 0.024232921949137124, 0.06815731810826449, 0.040042772288284, 0.04093194755935862, 0.02304406265818304, 0.08577533321635378, 0.021587231556975076, 0.05554778283582099, 0.014713970181952803, 0.07581446650287799, 0.02917551439285519, 0.02336378370772206, 0.04064044344329065, 0.07593675711823088, 0.018284454145618988, 0.07954907618583211, 0.03943292799616053, 0.030582524881127383, 0.03523246024645144, 0.030363799117866064, 0.02663872531434942, 0.017621180966436382, 0.07309436407541076, 0.045612403867586006, 0.029361955295767517, 0.05057131015365163, 0.06369583271143418, 0.022595874409401612, 0.01921453659663037, 0.04995790738311987, 0.03286846229926713, 0.023889938639777324, 0.060952713172281944, 0.04833678872654996, 0.03845272998836252, 0.04682921579167728, 0.063978971147369, 0.017305956853012887, 0.028665546898639975, 0.07831679311610999, 0.015703479988470433, 0.04166010264006834, 0.05708362441509963, 0.015966322840071254, 0.040282795295840314, 0.03279480677578719, 0.04007574088210541, 0.0542762186077814, 0.08427796074219289, 0.013989478916740947, 0.029326720996910048, 0.034539924423781135, 0.013588675121296079, 0.026825240910834363, 0.08093295273401084, 0.07355701989464222, 0.0265848329440961, 0.021612612049906485, 0.029096586269236384, 0.048534983333440564, 0.05444773037226931, 0.06372970528900623, 0.05927471248733421, 0.04391863709315658, 0.024689226899476304, 0.0728763660956775, 0.010516261306381034, 0.06681156209519794, 0.020793817276435516, 0.021686750208778728, 0.013911428921405348, 0.10023001806750413, 0.026375522401424187, 0.023758966333022522, 0.008742261186031806, 0.0436792116341812, 0.05394623389527683, 0.022191178887301398, 0.029955024177569057, 0.0508271107420085, 0.05600783012567028, 0.03629238502452931, 0.060014807048343846, 0.0403884579727967, 0.03269373296549724, 0.03047877550876189, 0.04989600747883801, 0.0382020392064606, 0.08390681412551673, 0.027903406242389354, 0.09150864331111794, 0.024097852987207236, 0.06273369522645109, 0.047938671984499505, 0.017767348627169288, 0.03751839766459119, 0.017976674491599683, 0.06552231272742634, 0.04447723776402493, 0.024330414298381058, 0.03275057668947885, 0.044684269195122105, 0.04397275354412775, 0.04197980262218945, 0.06390858681932574, 0.00798148847553098, 0.042426542964793985, 0.061959551887646805, 0.045077318265553445, 0.03496627916672057, 0.03631670831612522, 0.042317007713380365, 0.06176400411453459, 0.027635064794712012, 0.05552433671489839, 0.034200015042217514, 0.0746935802782255, 0.04496692882610425, 0.0398379740034861, 0.05444855391678791, 0.015700214538693188, 0.037469406341833454, 0.020859478672425595, 0.033192486847720803, 0.052328443890737916, 0.14722625634843303, 0.06065223433618104, 0.03626030509270007, 0.06789572972563968, 0.026739726346286557, 0.036701299775872505, 0.05664817620849898, 0.030707023744922013, 0.058564280850752715, 0.01052697217317238, 0.027403131675636096, 0.07741400446262091, 0.021372112152617306, 0.04263854630651974, 0.04101850017304382, 0.10538041952156252, 0.007801808298550427, 0.006840710299119594, 0.050300540207254316, 0.049162405512986646, 0.024027566335374312, 0.07961093778571776, 0.03832721031240879, 0.03367034951224923, 0.0596448976636654, 0.024185560478438294, 0.00227491628573907, 0.02989526548903556, 0.09228970825431809, 0.029060329242999998, 0.10474463549232292, 0.040743122207781965, 0.020409944024117246, 0.06336597057299749, 0.012698881234222604, 0.011675566840436191, 0.04428869969541988, 0.04264393573506706, 0.06712641657119797, 0.019710574697162357, 0.09188030320670336, 0.024061038632005937, 0.043898772433279984, 0.0592680896572288, 0.016064363899790955, 0.09424357720079923, 0.015288061150650104, 0.06131284727504658, 0.012811523929779089, 0.027015238376935164, 0.02490524454192529, 0.04604301422894482, 0.059981938045952594, 0.07629950741125692, 0.034363777827351324, 0.08617490169502075, 0.04075727951262267, 0.005245216804811912, 0.09149509121573741, 0.03875459544360638, 0.016994337183273128, 0.040083838431465055, 0.04171386669059435, 0.017095684869996002, 0.03431857097893953, 0.03985023524071421, 0.05509115995899324, 0.011109356043650018, 0.05375430588760684, 0.06568104614533725, 0.06724544365199343, 0.009695168269137222, 0.04963387134334734, 0.08219292988219569, 0.04164757327206674, 0.025657724829450734, 0.0701237815402208, 0.04651135442057445, 0.04957858660829164, 0.036548380965306874, 0.021124146728506012, 0.07658548803339083, 0.05837318404848057, 0.03647873208167092, 0.0163241328235956, 0.04480044259839962, 0.03672456969657252, 0.04266263211085912, 0.03725079549176078, 0.045096876490260326, 0.043636636297789314, 0.06063127800101235, 0.014932126167320437, 0.0019023624613069962, 0.037601265395360614, 0.02192627334396445, 0.001959330674576303, 0.06740428432221375, 0.04014577280970351, 0.04205289890148467, 0.10807809855548606, 0.0752819894302276, 0.05926314455967757, 0.02809499717137266, 0.055911440943037315, 0.013737064437009396, 0.036290990744507125, 0.07326592946605337, 0.0614190538744292, 0.12325832229708472, 0.13998957531106088, 0.1283864382534258, 0.2040751284408954, 0.11629315048095681, 0.12020766059116972, 0.2278888336713276, 0.24108610776883943, 0.07583591696475783, 0.16918486434846156, 0.08684579553383012, 0.12958573357712838, 0.11228300961515597, 0.1423658727998695, 0.1646385002400606, 0.12910173454832646, 0.14970130257068143, 0.21499071690824725, 0.17392304155134386, 0.10908982491180783, 0.13639565767540088, 0.1256530442004723, 0.14332418750611045, 0.14857993371063663, 0.11821891166149609, 0.17858543733675636, 0.1353896769785112, 0.13370278201276256, 0.12993070296943188, 0.12954108597290132, 0.12055387104591056, 0.15141753870393002, 0.19042635276432962, 0.1704372495653168, 0.08992710075671635, 0.14034399822835, 0.12148099831275402, 0.14399783926144724, 0.15432222235587337, 0.1403598562483826, 0.18432551964877114, 0.1115584819607677, 0.11713601573700867, 0.25764971010146603, 0.12615367499811034, 0.10675436757024258, 0.16624346976318669, 0.09725113880009421, 0.10436365230669899, 0.26942043655341674, 0.21055215669255103, 0.16316650825883114, 0.1292876028005154, 0.13142756216468351, 0.1381260817570071, 0.13820719514642993, 0.13593402841398794, 0.08439845105092372, 0.29499873338687804, 0.14198008624296035, 0.15656096109699819, 0.18136296571502764, 0.13335736828946299, 0.1107808261088306, 0.1405813169455336, 0.11297648006509389, 0.10909602256311525, 0.167069373832595, 0.2718920813452813, 0.15284214048616349, 0.13314456438585637, 0.10812005719109889, 0.12487380254653194, 0.2081338162984579, 0.11930894752543782, 0.1386295853843612, 0.08659835679516678, 0.15174588398827663, 0.11954648074724021, 0.08843844636313378, 0.10122783226712097, 0.11492887046188117, 0.16001018004552012, 0.09242293860522971, 0.09262915415268752, 0.17675315420473778, 0.15280595049262047, 0.17105453257118503, 0.18385362480917286, 0.18506934505797204, 0.10133549826399935, 0.13804398777504123, 0.10765748564153911, 0.05314513958329636, 0.12659614440053701, 0.1835363877997283, 0.13310305774211884, 0.22084513018208168, 0.11305414605885745, 0.16963248952261864, 0.09537748692016448, 0.2080341635812675, 0.14871677233567163, 0.12066729802397952, 0.19293499960293695, 0.19752333000782998, 0.10542323617565055, 0.10474982956844954, 0.08570555792821032, 0.10702770774162586, 0.13429133672147028, 0.13458660232924646, 0.17088812295227282, 0.20331794245829507, 0.19058838036031495, 0.1058748450070139, 0.10963430658223168, 0.16198998106823814, 0.16470724897038552, 0.13521992721624915, 0.17216883810056796, 0.13221050402329815, 0.17356592200456128, 0.18130184722042855, 0.12223158827832631, 0.20338845319084584, 0.10113590937708655, 0.16277499136424836, 0.0916832960360954, 0.14367517834949878, 0.08660795587685802, 0.12085308966737603, 0.15461662994517436, 0.3324658261431802, 0.14851297762605453, 0.088830292675524, 0.11413834433281615, 0.19390865138942198, 0.09627037005679262, 0.1305486601326735, 0.1390031298562404, 0.12004019377092201, 0.17849355275111814, 0.20488860656417188, 0.10723250602642376, 0.08023048075096262, 0.07242506369948387, 0.09356071706861259, 0.17677419097913852, 0.23560194478880978, 0.14723670578772022, 0.18449510087168988, 0.22552372106621343, 0.09200106930708693, 0.1355311887398843, 0.11948185356994791, 0.11683272918866527, 0.3324440079590967, 0.09376620483254233, 0.20691613486457258, 0.12756086360182495, 0.13698055048383054, 0.13331333355557534, 0.2509891425049113, 0.14286249695766357, 0.1004938893921433, 0.196414417737434, 0.22996050395792533, 0.15021104215373918, 0.13149931395967163, 0.08431403582254726, 0.1353146463272072, 0.1032042318594552, 0.10760389779123569, 0.15024936187171167, 0.15790382129771097], [0.013217547656818023, 0.005028871180970343, 0.01663267090465994, 0.028316134196375648, 0.0303762978423507, 0.06552603591473834, 0.07155038281193665, 0.04633017462648211, 0.05553749044455829, 0.01689800545723448, 0.07257844216280407, 0.030598863621332476, 0.04182608324974295, 0.04574016435071827, 0.04837099072192946, 0.01873463039256392, 0.029893503486809712, 0.03606206452053401, 0.030356222508294933, 0.022206452765291738, 0.08191844823980525, 0.051387347010595184, 0.041836007918802, 0.04107831248773202, 0.05546519855758356, 0.00635687310639168, 0.037692077457904816, 0.052847158193828604, 0.10291719403598579, 0.05022915230403024, 0.06351878213125371, 0.06967427945064922, 0.016183860209440033, 0.03275043496321286, 0.04434093157009733, 0.05929274236663215, 0.05618625583367483, 0.010326093385717081, 0.041729383801500645, 0.046535999469098546, 0.009290267818517262, 0.02292563695640814, 0.025637440736435597, 0.02023290685047546, 0.03244665045771868, 0.023795872618774735, 0.018566631141208836, 0.040690185532214186, 0.08994932496739973, 0.05005139309251982, 0.01988965349512235, 0.026545513481382402, 0.015557990315550519, 0.04436983606748043, 0.01993578922514233, 0.056506829156029614, 0.10941620135018904, 0.024283370754170804, 0.02912413670621332, 0.048002368364963806, 0.09944229582024199, 0.10271824866292939, 0.05688054982813136, 0.03759867218773692, 0.044506889197134206, 0.049957742674216155, 0.003352605924573577, 0.050585348714864066, 0.026232455481564807, 0.03209932917548764, 0.0689936256516845, 0.034153601605324976, 0.06226816657750357, 0.026927067402509913, 0.050452325207692, 0.04910170070586666, 0.06178546606773331, 0.0772826357053653, 0.02724660650616692, 0.061235192772601886, 0.029773356002424995, 0.023137900768028154, 0.035878912050036654, 0.04240031211426662, 0.021732514386155435, 0.023278851369996707, 0.03669905130781474, 0.03663810135255899, 0.0863736249025791, 0.007532613620447416, 0.037833964602360805, 0.06068888398247862, 0.013418721388124171, 0.010595103245108359, 0.09509293888244899, 0.013877475904601236, 0.034432825331966725, 0.00997634647759579, 0.04238040914999382, 0.026612553835636186, 0.014744519853153297, 0.02153628096435099, 0.03720780646788978, 0.020883602781161185, 0.06536369422270406, 0.061004856946848096, 0.0239925216432781, 0.02769176679242763, 0.05926679113819715, 0.05093421749470215, 0.023482990819179726, 0.045730595912544, 0.03381189191713929, 0.061549625900243564, 0.023659717727212176, 0.05429052913020696, 0.023316412660924178, 0.03855588372736689, 0.03471784834419528, 0.06388267389528694, 0.059590474777524514, 0.06658087769943861, 0.0788385526186997, 0.021889514530137665, 0.03795819342016213, 0.07666857792965828, 0.04519133513132411, 0.02452456779147108, 0.06533539493478115, 0.123293700237428, 0.03781011628527795, 0.019554072510330908, 0.09388259657087827, 0.003344859099841767, 0.0035479140558069755, 0.01736906143055568, 0.1197706227521262, 0.036692899621782765, 0.02914677843481543, 0.016808422965808742, 0.08119249566187782, 0.06200281287273092, 0.08406096633764044, 0.08558885975470466, 0.0638626560178255, 0.0516592277844827, 0.007960548898535631, 0.0393623176721796, 0.028304206207394603, 0.019402479031874288, 0.09172922300715601, 0.08486775651333794, 0.0456633908493865, 0.026555710111654578, 0.07228080934334187, 0.025146353479114272, 0.04518308436437961, 0.04861864013477199, 0.047725791472100446, 0.043781534167787725, 0.07319792384101499, 0.033713537718980544, 0.027899169776168083, 0.023305524636300343, 0.03995158101221727, 0.016282631925517516, 0.017736710855857502, 0.0629541561788609, 0.014318153618895, 0.03352883392043653, 0.009397184964449657, 0.040702366330210245, 0.028190813703282226, 0.09989317686807725, 0.005922179975201406, 0.0706798694426975, 0.005163428300405823, 0.03356476344408528, 0.019572406909578753, 0.03460271682049479, 0.03971991219347523, 0.05766190971518236, 0.024010195291691253, 0.03505137238291002, 0.11338115835021581, 0.0454833448654221, 0.030685230458696044, 0.03394109647600882, 0.06235051336848448, 0.032713521016581405, 0.036043751188704086, 0.03909628981003358, 0.02892269771696339, 0.044777513586825905, 0.03291614361167435, 0.02134652864638596, 0.043161949067707026, 0.0073105410105668974, 0.06844734367463859, 0.019327379432657076, 0.042077141753848524, 0.02208856907072327, 0.02066730743183965, 0.07871928038976847, 0.09595974438613462, 0.025931262268474507, 0.03058235634178404, 0.013948235615727403, 0.04252598500780521, 0.04877396446141986, 0.04230199239006446, 0.015681929935160425, 0.03336348916373907, 0.011982555508673673, 0.019313722000186963, 0.022926406874772043, 0.04830834771236105, 0.015450956341209672, 0.04206259374416644, 0.021033824962233345, 0.053119184524421735, 0.05229756671694979, 0.03627587966020069, 0.04446283148060884, 0.025792638658575957, 0.036052806347969084, 0.01202530800289805, 0.019348144245844696, 0.07202854425075554, 0.0099726434000918, 0.043255170476773096, 0.022174213870218205, 0.04485935859021641, 0.027795847497820377, 0.05711010041376276, 0.06933110270408854, 0.0281146377505314, 0.016296729858544086, 0.007137909321294677, 0.05343289752941459, 0.0643463830854143, 0.020916726507787264, 0.020101484467065143, 0.0315900013646892, 0.020597260182483063, 0.0295777392813996, 0.043558296146652395, 0.016989227376818176, 0.021361249025851008, 0.019990947555690523, 0.02648181135525867, 0.059928537887190624, 0.06848504286139243, 0.04893697264994826, 0.03312623556402903, 0.0384348648179683, 0.06176144155042787, 0.03530028584082762, 0.023229262498658032, 0.06568679180476936, 0.04200210727210488, 0.037318031198435256, 0.051822109568503597, 0.044629390486666275, 0.043208573178778735, 0.06319305686760815, 0.08306680637742243, 0.05355521878828445, 0.03825671873205612, 0.05988960529887869, 0.048398803544020465, 0.011799952706261989, 0.021261219010357896, 0.0535072616842245, 0.046942374638972745, 0.04667887486697686, 0.03914532709806677, 0.12269103418915503, 0.005016098580052776, 0.021300136276911345, 0.03544867324132112, 0.028940656733128334, 0.015050097004390292, 0.07103862841763804, 0.0420595791881844, 0.0861192683899595, 0.023141541600888296, 0.07148259935239631, 0.04800156014220369, 0.034627656812869737, 0.024617852402790904, 0.03986915761244394, 0.019423937154633385, 0.03666378828066011, 0.057825281795474796, 0.04716704524452648, 0.01281565314369096, 0.07073698129745261, 0.06333843737299885, 0.03804628587057514, 0.028052054112777117, 0.04404482326560444, 0.009678198464004504, 0.020988809635802623, 0.07196598551085881, 0.04950256770356529, 0.07627422650975567, 0.03420326708545608, 0.03348764137274796, 0.012515847507353513, 0.07193390940946918, 0.028907954354860613, 0.056700974988240394, 0.10484592763767128, 0.059550136417871526, 0.0425153517074162, 0.06896131206303835, 0.03750402585513169, 0.013877474946991332, 0.031784620256193226, 0.050240314205087004, 0.02545325021680084, 0.019280265025313825, 0.055283034340508526, 0.07206527050584555, 0.10194862141243874, 0.07064786228922106, 0.028225050172618324, 0.0247354909492236, 0.025918656291680473, 0.08959950623853553, 0.06579950632106873, 0.06026489645122521, 0.019300589337944984, 0.06806729511628229, 0.03941510113016252, 0.048412102830385974, 0.032928933449570215, 0.05118486231132861, 0.02260117382261782, 0.037755429098803195, 0.025789819455014604, 0.016199484572655732, 0.01729443872107133, 0.023439145692053343, 0.05397340703395106, 0.03507116809487343, 0.025823716930444204, 0.012623990393964755, 0.02365420763981679, 0.01218804423021333, 0.049691979112404014, 0.16377245316342, 0.1700395733238228, 0.1261188716237103, 0.11321625792451444, 0.18594938090010998, 0.16405743787125235, 0.20725344337763327, 0.1679497773969366, 0.24247059718735758, 0.09135101305981798, 0.1910674151393675, 0.12367085298343052, 0.14998506153783492, 0.08421287391214602, 0.146437369647526, 0.17476762284434613, 0.12559047779969632, 0.13310603016326505, 0.12068354674885351, 0.13948927393123028, 0.1721133120478161, 0.11405419723521318, 0.13620847175198217, 0.15583241148100746, 0.19378180255091962, 0.07228272456315256, 0.11780708577604064, 0.16346974118101984, 0.2472910522333076, 0.16503790784026348, 0.21682151382969272, 0.22077512506756092, 0.1015257178955982, 0.07458356239141957, 0.09867073036730291, 0.11450622741493488, 0.12117307693246873, 0.05683033276469477, 0.12141337573167779, 0.05583716871877832, 0.09577687153772962, 0.11363950618092092, 0.21484457797581152, 0.16751747398126512, 0.10713233236944485, 0.11662583948383409, 0.10528483473125005, 0.14621017861270136, 0.15100375929426763, 0.13631177104769215, 0.12411975752442114, 0.11430140614749924, 0.14114642936375835, 0.15397866256535053, 0.11733856938418843, 0.1419686408893716, 0.14890352924985273, 0.11136441656778898, 0.12299398365881174, 0.28364187827514065, 0.2560474831731089, 0.17176521701678155, 0.1436726196158317, 0.15713401018611847, 0.1354359027238623, 0.2075881625135099, 0.07591780410298417, 0.12277462970345251, 0.0836876210486216, 0.0915232602687132, 0.18869012173625732, 0.15443233983410945, 0.17420542156023366, 0.07895356539877192, 0.16197657452956324, 0.17258971148440916, 0.15345554708713485, 0.16466227960923027, 0.11829958071992283, 0.21083225375942646, 0.13443470241562014, 0.12284729314307052, 0.10055991851033703, 0.1991977837056883, 0.07280361072550859, 0.11110249110647749, 0.12408748224017122, 0.127860511232528, 0.1623604458666617, 0.1322888288526766, 0.2298604375532558, 0.17518926231611162, 0.120448786765337, 0.1447884266775462, 0.20066537834223241, 0.15248400970332085, 0.0921569835214365, 0.20146517413518122, 0.1184896624556953, 0.18168234777066017, 0.1672676986744327, 0.2545043216237138, 0.12765192081250493, 0.1197405384793397, 0.24354836032275232, 0.186000494286418, 0.14278031104514677, 0.14731889170023704, 0.15686500607238663, 0.12945660179661167, 0.11101498854376617, 0.2645835106170947, 0.12269046728409107, 0.12855575900645028, 0.12537916010666278, 0.20329253898272592, 0.14090834455865045, 0.12946830762009467, 0.15690228391078212, 0.13986937611574127, 0.08297487582650878, 0.18685227680590846, 0.18215384424453784, 0.13615001924335957, 0.07025217021545095, 0.15532988844619644, 0.10541751349885618, 0.10004911406506455, 0.24157104142490896, 0.20030700241125401, 0.18440523875817177, 0.10857593313220049, 0.20632684471145754, 0.04314638982196489, 0.14135414644354774, 0.1176223436731004, 0.18954711365363291, 0.14062011163801919, 0.1750948343185648, 0.19036082160328666, 0.19474860551136156, 0.1704839962504564, 0.20820883162800344, 0.16569502741819428, 0.17267983406782153, 0.14880812065976282, 0.09010615082637918, 0.15781386725364194, 0.2945842798198423, 0.18643941670175523, 0.1769651000898692, 0.1566396383268218, 0.12465516871382153, 0.08864173545472084, 0.23962741507397545, 0.2622656962804256, 0.13677217456842625, 0.09281392689914474, 0.18274770028168158, 0.12436371056302903, 0.1182386537473048, 0.0922096367444723, 0.18319423761098616, 0.23646092853478848, 0.11051708501913857, 0.10622130827076974, 0.14882995416560482, 0.18643265980626308, 0.06872210876956102, 0.16432596701047114, 0.10722737323733107, 0.12484869018437401, 0.10316778905689718, 0.13826425337503034, 0.0937793892057192, 0.199800725545614], [0.02346910164511252, 0.011956386902790156, 0.04877810133621097, 0.022616920759901408, 0.013918284450717753, 0.047919604056064165, 0.05678618694805811, 0.07527425194219237, 0.030867500012860666, 0.021986621920199647, 0.054649782231858665, 0.08003408645069407, 0.03831766868731187, 0.056368607742291306, 0.033622614573687315, 0.07148097524599684, 0.03358184720479673, 0.00600034153209098, 0.026331870711498687, 0.039803090189853986, 0.05408159780105757, 0.0419776460846826, 0.06235291888456672, 0.04140328315477218, 0.048297867629556894, 0.05050398251642624, 0.034673568462171865, 0.023657285398052588, 0.02848706947970054, 0.03140790226508773, 0.056636769159306447, 0.03403192002987189, 0.048800969060750744, 0.056612216041333256, 0.03569502796557161, 0.021911478270926786, 0.05765013111334655, 0.06602311972528696, 0.022805851448567647, 0.0337087151954972, 0.011123333317828516, 0.018615978694851362, 0.031066970156145193, 0.054272303898488326, 0.05509074244107451, 0.103845386165044, 0.029990126326259588, 0.02617687388743845, 0.029184021799254323, 0.04517237062475855, 0.016603959844477715, 0.026927753051202145, 0.07546795727384668, 0.04110554308300057, 0.01857243425723526, 0.019491776155548233, 0.03907374001198238, 0.07667114432420462, 0.0511039098003699, 0.026355989074574846, 0.034896906074737354, 0.043528085469358394, 0.02018456287201374, 0.031075138568637833, 0.08418291987430665, 0.046881451496794346, 0.06823316081276826, 0.03703908709388587, 0.04980676206609896, 0.08509868605723304, 0.025655792372661735, 0.002990569290329492, 0.02706777094112289, 0.05318756170210339, 0.007065471398809384, 0.015174977954537159, 0.027978921444305492, 0.028125876260380593, 0.0537023421437029, 0.03618706325669924, 0.025433301287252578, 0.03750059761167054, 0.09282701934177069, 0.07925999290760487, 0.09133924594930104, 0.01680040585568115, 0.03864232525830308, 0.06385267389217211, 0.05661984244661947, 0.05631159164852673, 0.00582125794608146, 0.063909100098235, 0.03879569223030441, 0.05995386092352772, 0.1480687079170058, 0.012470215480143746, 0.03654723183342046, 0.04565038267643221, 0.05425132841112153, 0.02546793995274892, 0.031834419801711075, 0.02442249615165976, 0.050762196281744595, 0.04099377468528767, 0.020489134532850117, 0.06682909018690548, 0.05841280228548473, 0.03690243616039234, 0.049360967842080904, 0.0639207676173218, 0.0377791433504993, 0.07833584572278685, 0.024458475471023592, 0.04730166987546029, 0.05650100688780508, 0.01610843885329462, 0.026119488156250408, 0.07822274050164608, 0.07682114433977874, 0.0671090800014715, 0.02726315592055119, 0.06552881681390348, 0.02052456992978771, 0.08985700371164469, 0.026235828183651454, 0.05159507558170346, 0.04021397378716258, 0.05966377407011967, 0.015634242877093776, 0.010900156583727129, 0.01417612474817302, 0.012882903214514017, 0.014733036195168333, 0.04777117835117444, 0.04332731297660259, 0.04178828064111933, 0.055338736593482964, 0.054349575356970874, 0.06169000385148872, 0.024639530775828228, 0.042175660660910996, 0.11945540055392251, 0.03642641593732181, 0.029926855124593265, 0.0398067980554075, 0.059301387668857654, 0.04222762823525456, 0.04045844010467972, 0.00937932937015449, 0.047132126956937775, 0.045003042210854834, 0.033118578515225844, 0.05994193676498629, 0.03682857762361246, 0.04448919639652295, 0.011701260471806653, 0.028372790228815812, 0.02045060414069843, 0.011352225067845036, 0.07804690800126522, 0.04879947901973802, 0.00817773386745924, 0.02112168375582945, 0.010397086753660153, 0.027797159423390706, 0.038253784615306125, 0.03821109819616522, 0.006761832450020819, 0.04142892411759785, 0.06298475756099628, 0.04404312255041253, 0.05431059297294386, 0.07224563824673814, 0.08771935027212867, 0.03455484015566688, 0.00402881617417499, 0.044940188527107246, 0.03321905860737447, 0.006051027824381186, 0.027514074613610585, 0.0244313444671852, 0.02148410271582825, 0.019058695160633615, 0.07337103672926465, 0.013662668681072613, 0.02385089879915599, 0.08543479947313186, 0.09403091119301897, 0.05347448844282378, 0.03718604190996097, 0.01882520113741198, 0.03169548209576357, 0.051884097572896755, 0.023798584570026687, 0.06152063713318879, 0.016701457939381083, 0.10577764377118119, 0.0459498732591108, 0.005291419088720314, 0.0055819813954463655, 0.006993873779016037, 0.05466041553224768, 0.07455836575958999, 0.04055583669293312, 0.02321958297773475, 0.04124415520158026, 0.08859175587854079, 0.03698064224614251, 0.03566397076112128, 0.04312704610187681, 0.03516034072925968, 0.02174662572572068, 0.0543494183089464, 0.05927362847292136, 0.017168369377031922, 0.044425833264305714, 0.02550753903755498, 0.06678537720994604, 0.057950020061745766, 0.03147320743019302, 0.047748057817619656, 0.06230097046242126, 0.022393518029862357, 0.06711295640636837, 0.030563893622808883, 0.00815316255489785, 0.06559956503371078, 0.06338233421106013, 0.09012184030706845, 0.0774103502232221, 0.04844810130194791, 0.07162852378021325, 0.030084537086828105, 0.026580311110123035, 0.0217499582081913, 0.03672335544721254, 0.04896570477754839, 0.02928250240192058, 0.01943277014840034, 0.016513908124198357, 0.08634704931248581, 0.03300524729814741, 0.06313712861869605, 0.010252594910261613, 0.031810418267043374, 0.06542116613878358, 0.062153759006891525, 0.011092276113378185, 0.04936932586133481, 0.029638472816816745, 0.03916559778454323, 0.03599596262398747, 0.02700626557212203, 0.0656931350127824, 0.031585789796325474, 0.055086946475409695, 0.014049583302450278, 0.03851644552102493, 0.0116848930033044, 0.09769390697681135, 0.03302223912830795, 0.016416124661543196, 0.07020091127243734, 0.06366787816307719, 0.036216404424199176, 0.040466763649977026, 0.019791167146796664, 0.035032040154140805, 0.03289160198502002, 0.05357619427565125, 0.07827825889351868, 0.12793134372200698, 0.07498866202489984, 0.026757968814983487, 0.04503083971118735, 0.05090357397773093, 0.035575093070585886, 0.05956805904486007, 0.03383146163316504, 0.04474930239901428, 0.011324175716107412, 0.03675934242745561, 0.02042861167161215, 0.08104516929315944, 0.030512274618470864, 0.012330775028995931, 0.061894526344633875, 0.019316625473419988, 0.005793538490956229, 0.03327757240303102, 0.0352268869568023, 0.03208390591035207, 0.027131733537140875, 0.03437005208745118, 0.008005037060713456, 0.05255154401604688, 0.035231510297425335, 0.004630036710295826, 0.027001793533864043, 0.06263433745311153, 0.0632846120354389, 0.022082189473533825, 0.01828916941679293, 0.06460367371478389, 0.014962197033568256, 0.008454432376780579, 0.024266281247799917, 0.05251642271515824, 0.02893779730995096, 0.06780936863393554, 0.07907145866943945, 0.03922916393006041, 0.007124825975962825, 0.027235919579623208, 0.029962472467412873, 0.021961955804257624, 0.07863381562093574, 0.007832321101769565, 0.04423924871990758, 0.0616150651307356, 0.023199911755059036, 0.062486114761521744, 0.031942736973325093, 0.07084178978637343, 0.04271391786695008, 0.07774289366939376, 0.03868819860320899, 0.013459793276964657, 0.033360700603694685, 0.0801612876896416, 0.031851616560391365, 0.013012974410347882, 0.044421355480388294, 0.01190852651733064, 0.013737473336438981, 0.045722578802416404, 0.027280159242030595, 0.05020023631532827, 0.04182312615035523, 0.028428959795424057, 0.022002838086336855, 0.024181331673096267, 0.05932808583301883, 0.02226654661729211, 0.01950324449177471, 0.050538602029724475, 0.039455753585864464, 0.02205582647283952, 0.03790050699946381, 0.02016607333996123, 0.04146062483590457, 0.025211693118176153, 0.12602590685409884, 0.10674492936701545, 0.18370914062665356, 0.10151764332887628, 0.0986888789902291, 0.17817698989904698, 0.14638355963172453, 0.1538649904391458, 0.24337278829226572, 0.20787625753831482, 0.17525706109741043, 0.14670300297439098, 0.12231897592784897, 0.30642183978230725, 0.10288546267416208, 0.12971661203811247, 0.13776959040232245, 0.07948401999930221, 0.1243851303813919, 0.0985129852028143, 0.12835829984396696, 0.1514991117461074, 0.21588357706223765, 0.12781406332167888, 0.19791152208082138, 0.13601475875944863, 0.1524550975450585, 0.10837332585886603, 0.12232020166852783, 0.14805960679246535, 0.11545425356035272, 0.18704341574301644, 0.1824880884059014, 0.12858911447467344, 0.11620300491490673, 0.07240231088813275, 0.20866705945903258, 0.10766366797108805, 0.07810791924355492, 0.2473351482542292, 0.07827040649229482, 0.17217660623212017, 0.11508001960934171, 0.09345164913083277, 0.13108225569369333, 0.29790180825418044, 0.12630125417584373, 0.13478788427047192, 0.1045503019685707, 0.15203181864513507, 0.15622723787542314, 0.18206396680926124, 0.22724354249094764, 0.09728348303225734, 0.1256091550232903, 0.13785899286308598, 0.07701169338918502, 0.12341340913647607, 0.12762241110566164, 0.11392019313549805, 0.11180756778846826, 0.11237866335338163, 0.1319277716139632, 0.07350463480237993, 0.20133736002589428, 0.1580406752445044, 0.16564587521697247, 0.15931140060626692, 0.10636997529335561, 0.14074640889321605, 0.11611625311836121, 0.14472157784527348, 0.196746087843372, 0.14481782913208008, 0.12484750274809138, 0.15046040377309247, 0.18082710253375192, 0.09264878898618684, 0.1594687857094311, 0.1265684886264705, 0.175569471752932, 0.14332247146916005, 0.15762242188136424, 0.14695611842457326, 0.15042695637431838, 0.1269084631255077, 0.1911380178024692, 0.20941207996539532, 0.13983798183260426, 0.0881575525648171, 0.10824698263839369, 0.18301855832819017, 0.14892545468624563, 0.11874625594505381, 0.1972674566411203, 0.26641568649680386, 0.12344084274504455, 0.16867169269150303, 0.2988249135594214, 0.18444158196929963, 0.09460304097663011, 0.13184892584479627, 0.14857077129906224, 0.14121554581628692, 0.12434940004060346, 0.12290996679615591, 0.1365250805693288, 0.13628557084068177, 0.17764866502294618, 0.15310527636639534, 0.18073253664037875, 0.19568501010296807, 0.08881552250034387, 0.1272200923713465, 0.0917753951263524, 0.09506494602969578, 0.10172445642491502, 0.1519824825828114, 0.07779930838413777, 0.14525289046427897, 0.14457487200777377, 0.1593898939749887, 0.1298301922337663, 0.32610732701516926, 0.1744087412953377, 0.14587660860871116, 0.11935838317919163, 0.14754378447128882, 0.12171535226967066, 0.09593380464901848, 0.14130071947170844, 0.13676802237187663, 0.0814753046800052, 0.1373002083311158, 0.1725085521297109, 0.13279418641280744, 0.11861453478735302, 0.1215501837131958, 0.15449244709264848, 0.17602546260722224, 0.25347063918748214, 0.3425543767309958, 0.19016735375888888, 0.21035645187141436, 0.16247728959687296, 0.18377229691513125, 0.2114275193983509, 0.17918672442676561, 0.1566883002317721, 0.15254319765635077, 0.11017190112221627, 0.105281425639987, 0.19001808918772206, 0.12709346569834218, 0.08735762653692115, 0.06496596435505538, 0.13381605577324668, 0.12229098307509577, 0.10979079536252445, 0.18665523899178352, 0.16696612050216045, 0.172029287524281, 0.10392508995268615, 0.08910103580884396, 0.18732797144161117, 0.1102552897927742, 0.14364104147159285, 0.15532935218464944, 0.17021755087039164, 0.1785511012759901, 0.1953819610418812, 0.12831270995159305, 0.14894931066420772, 0.1763083941994175, 0.11432063495439869, 0.18221153066523615], [0.055348860445402326, 0.07649715043484204, 0.03435350841872635, 0.015739001570299508, 0.10321473492489708, 0.016044071188286668, 0.04206114966842917, 0.02005197411973871, 0.018234217929984295, 0.004906657174409878, 0.041369399085881255, 0.04874792896331318, 0.04469843416084205, 0.02238200181314061, 0.04173016138074379, 0.11580496095120908, 0.03013404168849511, 0.04632207707712247, 0.06903893209152645, 0.06149105847843232, 0.01470266751223995, 0.02786769505379902, 0.0447383358503782, 0.01133773451475727, 0.024750060026323604, 0.02843074669550744, 0.02860200373576053, 0.06822972873886747, 0.06382360851632492, 0.03874675453370137, 0.061427729820171674, 0.10026076117590552, 0.014870070172624003, 0.05408547803639405, 0.016586445159308853, 0.03382744733244181, 0.04625327855108246, 0.03500390940556123, 0.02407525722388058, 0.028331793033547943, 0.04037071537647036, 0.04133390240190972, 0.049309459920491905, 0.0966921167808675, 0.0209291179799625, 0.013475992206123569, 0.007493439714439334, 0.0066136040127716, 0.043802777785928025, 0.05382788097185474, 0.033525294594226346, 0.06222506647088355, 0.0638199542769261, 0.08032266411089128, 0.018529177102590763, 0.05584132857620717, 0.04179814402314444, 0.05664108606475977, 0.09306942488277152, 0.02068932862922309, 0.0703597749252954, 0.1429480843005642, 0.06407538714307932, 0.01641572246538295, 0.04471993824887661, 0.023897069003132564, 0.06338377445635777, 0.017342424553428448, 0.02198043192977146, 0.04616204897061952, 0.027603873524874933, 0.006333295792912043, 0.05140831483708275, 0.007593250916069074, 0.026998158446663333, 0.03431917618839972, 0.05909585777009207, 0.03128428248718622, 0.058113392142038194, 0.024029878005685828, 0.024402361445789857, 0.0626958619743105, 0.06130522086976036, 0.03645901297849994, 0.024292561894042358, 0.06696481032357102, 0.056870674954787384, 0.042969783572780515, 0.07936848627944147, 0.04404626351090209, 0.033564954966066346, 0.01465723179506078, 0.04525529581212229, 0.05365263835917558, 0.032132301599748676, 0.042863488873286594, 0.053230834178506374, 0.024777288706372344, 0.061385357497079726, 0.026240800094280033, 0.04915282941393314, 0.06278506908265334, 0.08871179419539629, 0.04177398544045226, 0.03208896209065232, 0.04926412666757261, 0.036973735963505124, 0.038947450417664745, 0.053667469821389646, 0.011363294080740983, 0.027558494306680177, 0.042810368336616986, 0.055848947320614135, 0.07747441049545042, 0.013686091819357489, 0.039968254915889234, 0.0054881140784991365, 0.04356463552422581, 0.038853574003423416, 0.05237759992239937, 0.007330421471006929, 0.03792124116913446, 0.03500892728146526, 0.05979226233677999, 0.03361045675832899, 0.02416273871917398, 0.05299607036455024, 0.032360683901295546, 0.025725134821127982, 0.05800607471516537, 0.035773532825612256, 0.037200934659208984, 0.047332715588591756, 0.019780430424537872, 0.06460306084444446, 0.05561918606080356, 0.10076956613169563, 0.01290958318408699, 0.03605884312081241, 0.006340200639134574, 0.03581657164519833, 0.0824423834320999, 0.017973943388149623, 0.03330732725801007, 0.009645577482578736, 0.013136163263791993, 0.04825177978003218, 0.014158707739214503, 0.05648223007278097, 0.04991993623515291, 0.029232668382446134, 0.05754819545414179, 0.031206279414735978, 0.07168010448015506, 0.054293501551353165, 0.0036064977569866086, 0.04268975545381827, 0.03623325452809373, 0.019775257415829167, 0.02108300589175234, 0.0282992840924811, 0.07359129466837452, 0.040496265695941065, 0.04735204781736097, 0.006989332314039911, 0.0458551426568339, 0.042705038907907666, 0.058666545927764914, 0.02222232610708283, 0.07999753639582666, 0.05432283888841349, 0.10635578734499794, 0.06460990200960828, 0.040649919950914, 0.068286128131853, 0.017571733821363702, 0.010432598759390174, 0.004478625177721223, 0.03126172119781616, 0.024595361976553837, 0.08785617357540516, 0.04323199248662399, 0.042910270032382784, 0.021387439656762347, 0.01375158180317451, 0.022916449646976207, 0.06644570148519932, 0.012386645821313704, 0.053882552836571014, 0.053425041297751094, 0.07858608834325306, 0.014793700782672293, 0.03795547380803093, 0.028753344405202136, 0.08514748585800971, 0.027298587487049164, 0.04600523843339855, 0.04495848270673906, 0.047080898657441146, 0.0239111248013233, 0.021260104352428068, 0.04749657796515573, 0.0718972061370169, 0.06857300507685832, 0.09052068100220735, 0.029451510974115906, 0.03717019538124723, 0.009082273989465208, 0.10239996977390782, 0.036219851819858435, 0.04457633506747023, 0.036022752718699556, 0.041269830638362516, 0.061984637436727365, 0.03444456945984595, 0.04404643588068505, 0.02347518821367093, 0.023593805437426896, 0.08793738655625813, 0.028868678942202564, 0.024456690486160018, 0.029564353810142607, 0.010242829204446847, 0.013888421385819394, 0.05265776976762761, 0.05750888748274696, 0.05710567625600004, 0.037869737077985084, 0.04565895520030491, 0.06086438706505203, 0.09821781152558905, 0.031184156710702567, 0.05244861244254055, 0.026165250418407303, 0.07930762059385739, 0.010988598561755592, 0.0635435497538457, 0.035663461312651634, 0.011635442985402, 0.025752558853597413, 0.04907465014126032, 0.015956458500436237, 0.024267449531884446, 0.03705823929199288, 0.0274575756291949, 0.08720666125056245, 0.06143588099568602, 0.02688280667268461, 0.032542836627051715, 0.028440516231761827, 0.015382019919343294, 0.008157417215707322, 0.07950514104337462, 0.03369631989288234, 0.01883705443282041, 0.061324752281389894, 0.07925381057805593, 0.0747362666973664, 0.05637871244201257, 0.0059235570182453005, 0.023056699278494044, 0.06009088724010414, 0.029129367171516343, 0.035618951604250944, 0.09577411362120221, 0.05469480521916863, 0.06484845412834998, 0.049429881281309554, 0.02466140641650606, 0.045050696710184704, 0.05334255278050419, 0.059818462543790384, 0.04977697656760293, 0.04066765488636109, 0.039151202992446, 0.016256611749169328, 0.06930583712434576, 0.03743566399920852, 0.08986141637808855, 0.05057642762098582, 0.02327201212005269, 0.050603210054818666, 0.0737476761963579, 0.03354290695560556, 0.056296928725656004, 0.020792670059768904, 0.05043590411303505, 0.07171175923318633, 0.05274788852060034, 0.04921264938950058, 0.01220810711534033, 0.03535323400771426, 0.06811345191372019, 0.05936342929940551, 0.04386973004007051, 0.08006844549409806, 0.041670521435838555, 0.007527599574983001, 0.021775558951400945, 0.06711310196307398, 0.06457099240393409, 0.07465688466665245, 0.02224136530722101, 0.04848031912960353, 0.026565878013629588, 0.03937896093233459, 0.03807717836612175, 0.035860533600733165, 0.017355582113527966, 0.012803605453471744, 0.03074079481584411, 0.01586428280138681, 0.0763246504169318, 0.03513178480188212, 0.020341869451165683, 0.019283859892898512, 0.034098883775333245, 0.029366107492317117, 0.014631455809238457, 0.08250143348930344, 0.04035046384219201, 0.0487973109909123, 0.01621053347574367, 0.03022191771906951, 0.023637093235588363, 0.05092250784077952, 0.028803052020169077, 0.04793075829624169, 0.04634464219693215, 0.06911807663498387, 0.03798613264676064, 0.014612378304704063, 0.09487010688791353, 0.06963013746445218, 0.07337422365502966, 0.020357825147408633, 0.0755925078485762, 0.027031377934279944, 0.029443367459480802, 0.07384420327481724, 0.019158995222120036, 0.016717752629530527, 0.025134448472770955, 0.0831457287553818, 0.04703606719211225, 0.07831584316708388, 0.023964676262450316, 0.016855853384420756, 0.03816619778292314, 0.07241426185975153, 0.009186934048850692, 0.055278445473842086, 0.07702535273687494, 0.12182166995180231, 0.12336688461683451, 0.09954458387989192, 0.19129618431531614, 0.08138059322992641, 0.15873197766561664, 0.09824491571635009, 0.09290700658194481, 0.11118197272862158, 0.15572865253254292, 0.14061667956411839, 0.18895561716729598, 0.1285835220328262, 0.2050004707228753, 0.15301262569283286, 0.13685140338155533, 0.13080745995525392, 0.25345530210723805, 0.19956333021963799, 0.09034223614200469, 0.11461367890719446, 0.146421373731667, 0.11248158726600871, 0.17515103452869002, 0.0774909962990111, 0.17230379214930922, 0.13471941133179974, 0.18614289470978324, 0.08825339782502382, 0.11268491466199199, 0.14324019362609233, 0.15496379034894128, 0.17655012558304495, 0.1782657335241956, 0.1010121402120398, 0.14864741073500726, 0.18847914112191047, 0.15918848945969538, 0.15565665558941905, 0.24440378942076238, 0.09456426926678228, 0.18060329760755264, 0.1438943714263939, 0.13644165359437466, 0.18989404423102257, 0.10033958396243473, 0.11670574245433654, 0.13868930959893813, 0.20803382650258082, 0.24516938704877134, 0.226844962265703, 0.2826187525305056, 0.2847706628662925, 0.19872320755835504, 0.07822358319836278, 0.19979335577978244, 0.1711661515817527, 0.22886406359893663, 0.11037017999877853, 0.15130487781378532, 0.27200822027460225, 0.1323516174189506, 0.1048815813696673, 0.12160240792699399, 0.14249328854343585, 0.12866097352197095, 0.09789657553717976, 0.13124186245183792, 0.23978838546862527, 0.14607669545277474, 0.10948334895675221, 0.11563505797136216, 0.09702313571206986, 0.12364731110151737, 0.09520179231561, 0.25630881108583947, 0.11271087738174586, 0.09594616930811636, 0.10108012285444046, 0.12394325852754617, 0.16039981236380918, 0.11182796870989185, 0.14642929508080407, 0.11334853066552071, 0.21803715746969948, 0.09871926969818531, 0.1139269500309902, 0.2410953008239308, 0.14269081665383232, 0.13445374736141774, 0.11919007366222721, 0.1067741479604475, 0.20773120645073154, 0.08629109425049636, 0.13091644362336205, 0.09596090117890028, 0.10857178093565088, 0.18333627031214778, 0.11380584685191994, 0.15521978628971886, 0.08916311957422765, 0.23001914032764975, 0.13463531019947222, 0.06415456999093294, 0.2890221444108794, 0.18650827268438955, 0.13092271022258267, 0.13430449811200942, 0.13633222559527045, 0.13640739414240086, 0.15559785068035126, 0.1809262802764293, 0.13076558558931275, 0.10772773590419563, 0.09907419823350445, 0.11245180176751268, 0.1252099619277062, 0.11684784410341133, 0.15744289683718837, 0.16729222880976816, 0.0999306615502123, 0.12769122878389974, 0.15644088447574647, 0.21205361241534834, 0.19390333473922747, 0.11166293038836411, 0.1214377909538246, 0.08443123961408293, 0.15188684416634424, 0.09200699116674163, 0.1526516450629119, 0.0922559007942196, 0.09235230529861105, 0.08339027934257062, 0.09706933081390397, 0.2170562278479338, 0.141689263945145, 0.10792298107257775, 0.11052579543883763, 0.10681378534964978, 0.16943935875690755, 0.09005857676628137, 0.10429605270826048, 0.07638373111765231, 0.1376450551493514, 0.17652542690836615, 0.08953392145133789, 0.13149926799439615, 0.17141494629604204, 0.1670407987530193, 0.14253082685172558, 0.15262846324232318, 0.1956554850743663, 0.1303574445867731, 0.06864022163133468, 0.22190371047585244, 0.13888061707538946, 0.09518645523536591, 0.17565259229271643, 0.15030349364444134, 0.10923800163812215, 0.12484335055154179, 0.15572859124550897, 0.07706724242457459, 0.17297693828661598, 0.15657971492938458, 0.20259729886968292, 0.17280369516341917, 0.19305104660170694, 0.15639746261219825, 0.19416077092530268, 0.1199476273670312, 0.1815737318247557, 0.18767980498171624, 0.1512063129414474], [0.07874528141391855, 0.03614472923800349, 0.07684054168602152, 0.014574293201158365, 0.09050660796703831, 0.04542624833242548, 0.006903701399888604, 0.03124037415780608, 0.05305697435453054, 0.024998149939722596, 0.035443184221343654, 0.07226849831039868, 0.038703508870375734, 0.02986412976057299, 0.05242968240993158, 0.02246752786900728, 0.03226533276779998, 0.040848363536379995, 0.03205702580030888, 0.029951710847296545, 0.02569871436383936, 0.025527443917047594, 0.0065198597486972095, 0.06898700665201872, 0.049703504905224814, 0.0488060980194038, 0.06202841170072075, 0.03436543257726777, 0.08878274925894315, 0.03538201210058985, 0.03683252680686213, 0.03846877186949696, 0.04366961255248997, 0.08444631622443277, 0.09420762469451274, 0.04816841026167235, 0.04237102457292138, 0.11079121426108385, 0.051211870741099126, 0.034710007434290265, 0.022547674072425694, 0.029060204753712304, 0.006361292954909826, 0.05734694798687293, 0.021925551306095817, 0.025353630058347218, 0.00868279839895906, 0.04193491370026623, 0.03225662234810091, 0.024830418819141005, 0.07132005081662247, 0.02503814547502947, 0.04595396416862646, 0.0540645485143027, 0.034405184879658685, 0.013376585594678839, 0.055858297423729976, 0.04380223386350178, 0.038610494305049224, 0.037415473751964114, 0.042910158949633764, 0.078047153149401, 0.02241501828745729, 0.062178561103440104, 0.07918260270549406, 0.05182739174474151, 0.03005010718029113, 0.060225450584004005, 0.038438882949131156, 0.03012853543153934, 0.04452135293714462, 0.040456766202565164, 0.08140942877939633, 0.0526520241081955, 0.02550822660146702, 0.00734354934519938, 0.06847556635376907, 0.070755198868292, 0.052508271539643894, 0.047430437764212977, 0.04193364965519117, 0.08782611994613564, 0.03547102768695162, 0.010323803740433388, 0.02978862988041534, 0.08851356894498871, 0.018586302363884546, 0.025143436599342574, 0.06407252197424251, 0.026758348028506004, 0.0869813624529108, 0.056718541384344144, 0.05630285824618994, 0.09205692477764622, 0.06633639606016298, 0.010664926413747092, 0.04083673432168942, 0.02647217205395141, 0.0046117722165710745, 0.07924207411105595, 0.03399173871824338, 0.017327039592689084, 0.09867364150141517, 0.05026456088789048, 0.030268855926190174, 0.06530378614702533, 0.0850089388569036, 0.026724912121050784, 0.032477722983927496, 0.012452874122367752, 0.05024483412384026, 0.027198463625785325, 0.07964446945416351, 0.021773626494611946, 0.04533776517717108, 0.02584384014499524, 0.013151378727578109, 0.03240517828793776, 0.02432545196385153, 0.16060141606196282, 0.009674933014227258, 0.028953482960200602, 0.048549841608731985, 0.04552074144744585, 0.02782282145363429, 0.06661498393382757, 0.03607604945559175, 0.042197057496636145, 0.07839358576963987, 0.04254845819706398, 0.03756376539146708, 0.054085872571675055, 0.009810173388330207, 0.107218410008617, 0.02618520700883481, 0.0775303349139229, 0.04856612097712294, 0.08491388266725887, 0.011572588344044503, 0.008379779023779257, 0.050920496859978286, 0.02683003087558093, 0.07509561556000864, 0.013386194252469128, 0.03939289990211687, 0.12980989090377285, 0.03052251338357887, 0.03300724295719016, 0.02702905094220994, 0.060549007818823865, 0.04383815189583167, 0.04681691625005296, 0.05014322788244294, 0.041053246090849566, 0.011142059379527646, 0.020383653801775748, 0.012614757119257365, 0.021036490948209842, 0.06230910631617712, 0.06974829120501395, 0.01124983550154514, 0.028427147997483134, 0.046702612101310687, 0.00399278634088865, 0.02803703878946122, 0.018079812908845565, 0.027075092826459198, 0.045837855882822506, 0.08797323947111446, 0.006670870521526423, 0.050532366074020826, 0.032651349151086424, 0.05409232686243711, 0.013631791507284488, 0.0055638576703777, 0.039963344292294596, 0.06290833646010968, 0.04962489279287477, 0.016061288056774967, 0.06621230513818803, 0.11098896453697836, 0.0068226229632273325, 0.045124616533998525, 0.03145496496149609, 0.13927031068071244, 0.029963211742259806, 0.040611109936669956, 0.03636813196804255, 0.06054289060674849, 0.03987747732730162, 0.05250017399028425, 0.03410490905685771, 0.062244793234933773, 0.0249224815202216, 0.01753960983947881, 0.05307297027038951, 0.04930386747864466, 0.04934060905549315, 0.04658533553142221, 0.06497574729784843, 0.04083177773281932, 0.021665734501795906, 0.04498932540657059, 0.02955365539228003, 0.08538483521871029, 0.045742098722727075, 0.07511695110869986, 0.06406267391397588, 0.034418913175261794, 0.024487025652741714, 0.04383978366311039, 0.020611421317763386, 0.0366228370506677, 0.0990967212184783, 0.041002439139711286, 0.07548578413984469, 0.02826970352250482, 0.059970519505441196, 0.022655870585191636, 0.07157869742161806, 0.07306915212182269, 0.020667249975245328, 0.04451229394744, 0.04215009247643813, 0.03655081712490609, 0.013756303777617794, 0.015971616507628034, 0.042523280717432506, 0.06724891403029043, 0.03045689795286425, 0.07153914430208745, 0.04461019998416305, 0.10981846645834947, 0.05792867685217531, 0.09392571966013602, 0.05608825020552163, 0.03922569355176341, 0.038647155442665664, 0.01817433283694329, 0.017557628227457885, 0.02145294783516757, 0.02283877982277303, 0.027357829066233772, 0.029697831224409804, 0.04219472092846709, 0.023124193539842967, 0.06718545896752227, 0.011264150812020226, 0.09737575832273691, 0.041974826881121245, 0.017181971268127524, 0.04072140361512861, 0.09162451410966535, 0.023115147956677025, 0.04959368237083958, 0.12145512752355107, 0.019775605985834714, 0.045637389825236414, 0.05090401830872701, 0.05458998906936857, 0.07158281131377144, 0.049019572249944174, 0.04986291631094871, 0.04500005446795014, 0.02415178749229639, 0.07522849351047509, 0.04620762737167459, 0.01758162018602654, 0.07387036517743142, 0.015376387257880021, 0.07994229379560679, 0.015620340296487897, 0.02005515146940466, 0.02578301084858756, 0.013172754495885345, 0.03820830963612084, 0.04514364998847727, 0.022068150912321383, 0.10155496713254722, 0.013108394491756636, 0.041086704980942516, 0.04963244258936855, 0.04512883384802169, 0.050372456711146145, 0.03232671173229333, 0.035000546279573636, 0.055842722856229356, 0.041857308993536624, 0.05066250909059759, 0.04478659172872863, 0.04305329864784595, 0.004924807233750941, 0.06732839565243452, 0.023231020670444257, 0.048615054843286355, 0.08023997258034446, 0.035513821358401934, 0.01977532061808292, 0.023680848347383644, 0.02446381701907564, 0.016634741257275307, 0.09589042108986648, 0.038697391658300356, 0.04892942668389409, 0.015196239767265658, 0.0014783339922301352, 0.013754130003132648, 0.017415310158544493, 0.07068430509177909, 0.025347170021925724, 0.03944679418759, 0.02325970683276894, 0.03801326365059903, 0.0947504056497447, 0.02950544356398525, 0.0623256576457812, 0.05105337481044474, 0.011953970852998957, 0.02297162904494232, 0.037650203091963645, 0.04991323296581546, 0.08206716122766657, 0.01213049379012157, 0.07510800320174425, 0.0356204837800995, 0.0596080833084641, 0.01555776336200295, 0.06444438871356749, 0.04310263471016961, 0.03595764290601496, 0.024305859265188058, 0.026415711373931942, 0.015001482979935265, 0.018341135075916688, 0.02586510674577327, 0.029724824332421827, 0.08329984266310932, 0.052732654862226024, 0.048274628352373845, 0.04456957051109883, 0.02375732115920513, 0.039901478861969326, 0.0704026758490551, 0.053530098765247294, 0.02580322599368951, 0.04653752781450749, 0.01862780900762206, 0.03441905490152779, 0.07666026587567984, 0.028858271637751214, 0.08647905392271858, 0.05640036208675273, 0.2354123993145843, 0.14696079156091138, 0.1816471843349357, 0.18247619872131657, 0.20472611931543197, 0.14159394728560604, 0.11228417406880087, 0.12677712501176905, 0.1964672165171754, 0.10345280440824647, 0.15314581773934827, 0.1418169248368471, 0.15700765164388766, 0.11296510365941834, 0.13371916097258368, 0.17277295971589704, 0.15189596061264315, 0.17109898099255177, 0.19715853426004612, 0.14137291559769263, 0.07569917793115301, 0.09293356685027962, 0.1261904089140796, 0.26704173354852584, 0.11545268308010795, 0.1168775683148734, 0.1389052391412758, 0.06960340099589479, 0.2353092225929422, 0.12233691770703563, 0.3146391440062754, 0.13644163827261618, 0.1232509448703739, 0.1780672094994976, 0.2655036435011895, 0.17061551822529686, 0.11434193985957293, 0.2704447880387306, 0.17416745424270633, 0.2184468306480877, 0.09568117949510775, 0.1377298304390523, 0.1461625585873281, 0.1813123273032327, 0.21410787718430643, 0.21475456264470855, 0.1279487262570089, 0.21302590056532816, 0.18338966664047013, 0.15868438828376033, 0.19629883039141857, 0.1508802965643906, 0.2477245047808655, 0.15950926579535007, 0.1907753824226318, 0.11159558359894062, 0.21621454236728532, 0.09635162900292105, 0.3310238954520995, 0.16723072727120694, 0.16861930759924074, 0.17583242377206204, 0.1571796690264056, 0.15489484243575605, 0.1338755501614463, 0.11450708543341007, 0.11877180497732856, 0.250750919803977, 0.14341734379770296, 0.12276982633216728, 0.17994509018476934, 0.12660432621956835, 0.16599965462040517, 0.1840290589438331, 0.1089498836306795, 0.11474241998286978, 0.23606607149685585, 0.14790499492758705, 0.11956447615258156, 0.16806056903254601, 0.08153854523815456, 0.23083664807340792, 0.10835708479487127, 0.17113327108804258, 0.17572831242315232, 0.15497908146390993, 0.11847309963477236, 0.0803537366371001, 0.1403909747398669, 0.10837159450015715, 0.22258606499000905, 0.18096518222122424, 0.17258293926715854, 0.13875686323210118, 0.21720596739361364, 0.07535032447307341, 0.091707136692299, 0.07582863146859793, 0.09590733631123459, 0.09515200426141102, 0.18587893145459314, 0.14912719628022564, 0.1997179114409993, 0.12533149411601405, 0.10151546763917131, 0.13084342012241965, 0.15529506208915866, 0.18366089240918237, 0.15878263139917007, 0.13052268975204037, 0.1571926618776014, 0.16567762190055463, 0.2046572020457637, 0.14559713973393365, 0.19700848827919654, 0.07966686220419023, 0.1496138306514871, 0.15304654806612, 0.08810498361145297, 0.1822273427199933, 0.12773838915651844, 0.12559522754482685, 0.09855548009997415, 0.16572911833082477, 0.10789979159110978, 0.14951702778137502, 0.08438577229577689, 0.15007331486671202, 0.10127095535637871, 0.15567767704206129, 0.12381984176294458, 0.2577218755839333, 0.17477863918869727, 0.19664252807776775, 0.06668866627038487, 0.1394175987450346, 0.18037190841090295, 0.19986403505167655, 0.1666484698052368, 0.13172757751759023, 0.10330748518988972, 0.07052094450280552, 0.24683357516844429, 0.10895129323246018, 0.1498213485484162, 0.24650377431704154, 0.10351899440490431, 0.13837432488799095, 0.1070063645320554, 0.11569050741532158, 0.09396863590565421, 0.1901249278096422, 0.2291609073478368, 0.15318802918397612, 0.11903717017342007, 0.1706706305905696, 0.1312589002472739, 0.17165330689280264, 0.19836408086121085, 0.0832766991469168, 0.1825980833100696, 0.12272749997435078, 0.21436860754845605, 0.1885794373529573, 0.1500639685940358, 0.21406918974413028, 0.12860210732586924, 0.15736250357041437, 0.1366100703636485, 0.21074686559938619, 0.2149439089360737, 0.17346682087067636, 0.23161497808271841, 0.12291485443711282, 0.22545992126387937, 0.12121475977642883], [0.04392308423355703, 0.09701073274857576, 0.062341442887461, 0.010012750975757597, 0.012523809076106597, 0.009735491307031725, 0.08728742990041934, 0.04580425143602394, 0.033676382454652945, 0.08055626730164213, 0.041339016038804285, 0.059181456604311546, 0.010763238477070006, 0.1032325464691366, 0.06943363591187424, 0.0659092101118257, 0.010548692681045543, 0.03520631749603537, 0.03439977629891327, 0.03659079925367429, 0.10001489291748694, 0.0354096180789413, 0.02901838401392583, 0.036444353886068835, 0.01129453960475662, 0.05371903519957297, 0.0567205025694303, 0.03480570330735176, 0.022102921727984663, 0.05968306416405305, 0.021073175068464012, 0.026660656496401758, 0.10960046847861622, 0.08538127290986239, 0.035945477429777384, 0.016106376161558494, 0.07369642491422354, 0.03457024235338454, 0.026371194004652, 0.02415561218625836, 0.05927260574554244, 0.03760617601895525, 0.07923959964706052, 0.06553851548702487, 0.05952944821347633, 0.008059811868494558, 0.021061279638219747, 0.05446431234539036, 0.059101825595022216, 0.02857712311519971, 0.030521460012682987, 0.02137798804699654, 0.05210360474584084, 0.034587567431792136, 0.05839939957724945, 0.004117555490079066, 0.021740634918152806, 0.07228909075380334, 0.05348714421533289, 0.01814735122025013, 0.05035670211298331, 0.0027286687268755373, 0.016660361152683056, 0.09904313336817488, 0.025691549526527527, 0.031246071936742916, 0.007101352084352966, 0.023555405280222336, 0.04507787750973817, 0.04191317595541478, 0.06603103341354478, 0.054019517866113496, 0.0059273668692537375, 0.015519096989244705, 0.06399156946328378, 0.01175118642183201, 0.012335049799613416, 0.07925388718684835, 0.008723795594226931, 0.06269218092183433, 0.07119070453148696, 0.050743894441233534, 0.02330682698577162, 0.04067016382431311, 0.05700319284392942, 0.016943168255590627, 0.09713254072853635, 0.05346760897326374, 0.059491948209582805, 0.03241096991264532, 0.03596489009777865, 0.028182317788201957, 0.021834779463167635, 0.03430666980303584, 0.09868736213613903, 0.03204093412345937, 0.03959507433577411, 0.033640299713419336, 0.03341686633986331, 0.04697896682867601, 0.038806731557293285, 0.016489870200354247, 0.04646119481373218, 0.05228520971873114, 0.040657086703445644, 0.037677291960966204, 0.016017943759629085, 0.04022124779200362, 0.055690612268423846, 0.0444593879153892, 0.05263428917274841, 0.030056846838804985, 0.06375259599618374, 0.035002009507509015, 0.023955925623135223, 0.08320095603384318, 0.08792808624885737, 0.03323949783319428, 0.1705841852291938, 0.040373691628056194, 0.05472239587576159, 0.03375757245286819, 0.09781731608053369, 0.06615013710313267, 0.011656697137251256, 0.051108257349340186, 0.05027679531204124, 0.05565428054861485, 0.04118497873986921, 0.05635859880356058, 0.10300377729318796, 0.04051694623945702, 0.06757444011107569, 0.00925561095843272, 0.01904761752924852, 0.09818566647628624, 0.055722267021455114, 0.03258723908314302, 0.019834715414852388, 0.03695778218248198, 0.06628245580941439, 0.04171639478074447, 0.07902213026799502, 0.06056685383701998, 0.021297045112136873, 0.043133975367151925, 0.0659475834559529, 0.006743682390679756, 0.03764616963904231, 0.05296956755280976, 0.05128694735767861, 0.036863932581318, 0.008502528334276812, 0.1115588726656091, 0.08955527232178757, 0.02460416624202363, 0.010836091523449267, 0.029376047483134656, 0.05997602767761677, 0.02249961163127615, 0.042761380844298875, 0.06386339912311205, 0.03770861729619004, 0.06606138581710477, 0.008918556211996944, 0.03847565899993624, 0.02661791645110615, 0.0002859285520952976, 0.04060298940467258, 0.03771706724599485, 0.03132364599995556, 0.01431784239567576, 0.03482584758932072, 0.041848732639224305, 0.05119926093386547, 0.09883319463340506, 0.060275947269532955, 0.06108908065324349, 0.08188968929912775, 0.020806212579050375, 0.01011487145367409, 0.004236698920478023, 0.01247818758260579, 0.05251313236752345, 0.002948584799249206, 0.04890041110376197, 0.03198466879586059, 0.061211367438156764, 0.04746997556198509, 0.07264950447866032, 0.020769741048195192, 0.016664729769071265, 0.03904656687330815, 0.05483610630636254, 0.041510784442746834, 0.015970752743493407, 0.06520994037630097, 0.009477188483992172, 0.044792176509696635, 0.025380952584166682, 0.026686849042532906, 0.05727349547669292, 0.0219729759790484, 0.08099505182115302, 0.02912096701742661, 0.0382275422734599, 0.05185118643566967, 0.02765251436240731, 0.043913029329550844, 0.029211032144244642, 0.060581336729228503, 0.02658287175900994, 0.02275874661732345, 0.013243845540038763, 0.050182788662852786, 0.04367955637374713, 0.025145212008107095, 0.060584657720380256, 0.0722445197583687, 0.04419153293354377, 0.044306595509331075, 0.0463555321367758, 0.038108365805519205, 0.018583952389176817, 0.033084047102038903, 0.02357335663550804, 0.04000511140592637, 0.03165385287795817, 0.02883411880071846, 0.05352820652807432, 0.007528703220398917, 0.033600064775636124, 0.061256256360079975, 0.02013712479252248, 0.062183123157029195, 0.11309346169113152, 0.07569513298691281, 0.05318093121111874, 0.05183104598414033, 0.06464211600682428, 0.032430079975916494, 0.0025959925926966414, 0.04504814946783647, 0.020925932969417305, 0.07541607013873516, 0.054907647427171476, 0.06808850809090561, 0.04255724139511586, 0.055063266697670185, 0.02215915449684666, 0.02726842277503062, 0.024436546204191063, 0.05902642339107491, 0.03638847543287181, 0.011389010694749173, 0.06312838372504039, 0.023150774875595685, 0.06301286149649851, 0.016830197099836606, 0.046093890127996286, 0.040762439114792694, 0.0472125432063495, 0.08722076492924845, 0.08166299622145393, 0.030656475348458178, 0.07569105739915565, 0.021088119528646913, 0.006932378464919185, 0.05640573619354156, 0.017804576669849696, 0.08142897934322396, 0.03020803620588155, 0.0373134040273726, 0.03326327720236394, 0.07788990594206319, 0.06635571679761333, 0.03540176950815705, 0.010325151097570217, 0.09688648860901596, 0.10319583553580508, 0.020473425899962747, 0.01509060869143615, 0.026103243261816043, 0.008442725595687667, 0.016688210363950462, 0.06676161316253486, 0.050896288481571024, 0.01736159973417319, 0.021891540832697384, 0.025824735827383496, 0.06294984693428682, 0.04540378280404595, 0.097918669512916, 0.046298132999049085, 0.07415315121292107, 0.029210825300505085, 0.05418166037528746, 0.05893959881617658, 0.04587143351654372, 0.02370085473352623, 0.0376335138665332, 0.016731067237654523, 0.05103878083548719, 0.09838574565947057, 0.033315145185277346, 0.07578474995229514, 0.03488944054791524, 0.010400115673790776, 0.05359214422623477, 0.02867053796146666, 0.04519515024918703, 0.03779175315773295, 0.03862511126264449, 0.031595312269224275, 0.025097413867291425, 0.016225158094218182, 0.024253269244406014, 0.026714340107695713, 0.03695642237641639, 0.007511476775811565, 0.028165203383973533, 0.012699670304784612, 0.017567156446016124, 0.0016920266775301688, 0.053892197883537704, 0.015659253732601724, 0.030293713564113266, 0.10654544007153281, 0.034705947168291576, 0.05420907866209746, 0.037872640551218105, 0.07539764572415622, 0.02932746218697679, 0.011004649061379174, 0.06365196651688988, 0.032077574193657886, 0.09188291556652516, 0.013951507768773986, 0.039380121555539875, 0.03754101641055557, 0.03305435736453341, 0.029123872405879443, 0.052856998593215986, 0.08785959032754745, 0.059848857082186215, 0.03542611195195106, 0.023271828258950866, 0.03989569106770139, 0.037782690337588715, 0.05324726676448219, 0.018465576483117, 0.047270126205178044, 0.28602110221982, 0.14366002513035653, 0.13486666875260492, 0.11870961395963547, 0.1290252330082078, 0.057660982748793985, 0.1368188446447734, 0.16093400547340994, 0.11092465911661425, 0.17779858842972787, 0.13510882914546998, 0.1692193229832957, 0.10126375412989048, 0.2727403551820786, 0.11769274715334178, 0.17330048786055657, 0.19473653196567492, 0.1281736573324569, 0.12655412447789025, 0.12925112169356118, 0.19685845762010545, 0.06686056873971416, 0.11244158215460279, 0.13058797576494757, 0.1451251989290599, 0.11733837020132812, 0.16271687593431244, 0.20112444886997824, 0.09150992267795148, 0.1425686256299096, 0.13156721999327983, 0.07583050838401241, 0.24921601668240564, 0.18975501459452415, 0.08886563231147106, 0.06178603297279728, 0.11705775985554343, 0.09089072445227254, 0.1267084299075988, 0.057432726851754615, 0.11277965675558775, 0.14887740565163476, 0.21954068162989235, 0.16408699354337108, 0.1772699417966989, 0.19561587832868102, 0.11885412112479249, 0.08906363539638058, 0.10541693893291297, 0.11704340336784241, 0.11530408500543526, 0.10837871145697371, 0.21949808714130234, 0.13536758300277496, 0.11112346659384428, 0.15303628248793466, 0.0898698203626179, 0.10534663504410176, 0.14434896800066196, 0.2780963822958931, 0.22387865450113054, 0.17742913486736436, 0.18464511620902246, 0.29985582275736716, 0.09377886060505145, 0.11646525213314642, 0.10326666036440481, 0.11586004267296485, 0.14263414146919406, 0.18384705177478253, 0.12108444055962948, 0.12782112665234074, 0.12132106979768123, 0.1560999447059247, 0.15283631821793897, 0.151535194487341, 0.1421122670534157, 0.1576926415005038, 0.1257753194940667, 0.1898062965201755, 0.10791967157274486, 0.13294325180111394, 0.09016501702248089, 0.08847534115756713, 0.2159671266112597, 0.10848776407299504, 0.2262526690479248, 0.1972537589890342, 0.11193422510498956, 0.20670153831522312, 0.07190122809861937, 0.18563594368676986, 0.12320515579513966, 0.1436780281965771, 0.2702373314288355, 0.246575158389826, 0.07888229623917611, 0.12320667264922974, 0.14555497425458125, 0.161393903376114, 0.21018163060709355, 0.09368845456910711, 0.2172357222485927, 0.17724582534884253, 0.12372497709528094, 0.12473008445193692, 0.093855990337268, 0.10818761082426195, 0.1444734879318745, 0.1480406078119432, 0.1492044179429931, 0.09654669031020134, 0.21465999675133537, 0.185978093875512, 0.10638473780765649, 0.18265019261067916, 0.17237287795832082, 0.14362921307404197, 0.3063671717480306, 0.12690629509668197, 0.21698228504148223, 0.1589265486766254, 0.20157835596511442, 0.17215685648543222, 0.0794330291870621, 0.13413166867629175, 0.15496426532345434, 0.18046638237372523, 0.27179356243821884, 0.22713363951733037, 0.20618861180640038, 0.11961429485029752, 0.15913987352002054, 0.07376452246981283, 0.1906943456420014, 0.18166966135463408, 0.12270447903222616, 0.1528684326237248, 0.1550379783035286, 0.1241198571158513, 0.10997096392055673, 0.07684595026676694, 0.1633308494403478, 0.1136765312103014, 0.14966214015599222, 0.13423492200672626, 0.08110519228202683, 0.07085431532393541, 0.14795240044834154, 0.2806649218884207, 0.15553207437117256, 0.22037528845812046, 0.10677050138192792, 0.24259085766971114, 0.18740032078518024, 0.15728238609529313, 0.1295657080387877, 0.14845633308493322, 0.1364949733139046, 0.09230541305676584, 0.2942580795816837, 0.1744391703076901, 0.0898964878832621, 0.1622688677161932, 0.09264635282658762, 0.09111466727429822, 0.2094215947774149, 0.0914841361584202, 0.14435908036126247, 0.12052295939816583, 0.12969899201585403, 0.09360518081173783, 0.14633454532632906, 0.2257490734900198, 0.0877269268816998, 0.16848783158967573], [0.012307198673126199, 0.01480403243594112, 0.0847434357649857, 0.05840190851520147, 0.03578389033434853, 0.052739714362448266, 0.03148911907638033, 0.010040577204387275, 0.05874562535374876, 0.011534331828325747, 0.010033133702592985, 0.03023537979911893, 0.023859524949183388, 0.023819667309702888, 0.06695676640036606, 0.017080255859200994, 0.04647586539748215, 0.05803916588305466, 0.026903558079333558, 0.039226057443527446, 0.059255571780546065, 0.04220016015272948, 0.015964514872569953, 0.09742212196391437, 0.024485422613760157, 0.04579610792138884, 0.02465979571664526, 0.06125440242730322, 0.041805211184245926, 0.017469420863856232, 0.02722512731598991, 0.0506089250707338, 0.06430431719749205, 0.01705139924231316, 0.06380109702266994, 0.07740901723023384, 0.013830432360390983, 0.037559858343053254, 0.07381137640726182, 0.05236282591677962, 0.02168222071392642, 0.08300493711665755, 0.0771373471305255, 0.033260944464634505, 0.014929848970965514, 0.04131095040769827, 0.034554499246540575, 0.024904543571474574, 0.03355961150279449, 0.027434805580865473, 0.05632638097590497, 0.06962669772967216, 0.05587341233847603, 0.024896880777011958, 0.026304753114198966, 0.03769399267771552, 0.015531777659611357, 0.01653301435702991, 0.06570043583070079, 0.033644497875244386, 0.025989733929295215, 0.058596816604896906, 0.05715434582182958, 0.04286564924123307, 0.050320776419774185, 0.030394067251754385, 0.009925917782370123, 0.04343825399935727, 0.03517261345780665, 0.006996458368150578, 0.027728330253833727, 0.05545960611573631, 0.026495183419976986, 0.08149801918696012, 0.06066522335693721, 0.1142075986811711, 0.024472665334601077, 0.028916228104442842, 0.011829697985141989, 0.01602735898021849, 0.03689959014375364, 0.030812025671043707, 0.04553307929346639, 0.03563816125895228, 0.07674390735525279, 0.04463685218304877, 0.03140203786202737, 0.04649312152797657, 0.021891014147249442, 0.03439137231438391, 0.03496901027017063, 0.05700383635778582, 0.040999868914725325, 0.06646277758503152, 0.060940225939116174, 0.015672041655277774, 0.03876822414777933, 0.02753465748091619, 0.01499152575213943, 0.019564738369456703, 0.020354996367748228, 0.02168729413120497, 0.024507656400542588, 0.02654586205138795, 0.1110165513631317, 0.0774447322492638, 0.018955491625914173, 0.03712154113717618, 0.0376647089668099, 0.0629524018375143, 0.05660375460020958, 0.05125984699735719, 0.0448183728862674, 0.05689716244476938, 0.04496782897941528, 0.041751883803836765, 0.0866147204332294, 0.07019203997427417, 0.012544444611956997, 0.034860884620537685, 0.06725249166089682, 0.026562980286055998, 0.03128907245193278, 0.026744167741027572, 0.06676217240671958, 0.0630420494464136, 0.005158018762050498, 0.07142158044922738, 0.030510937795042995, 0.04744947887957097, 0.03406557810282515, 0.03056638149334298, 0.03177615498462993, 0.047431104260707097, 0.0021113050423727762, 0.049419447163780855, 0.018396431302291252, 0.02763639970292007, 0.020872170834111112, 0.04468711521176081, 0.027496418202175733, 0.018856451779063192, 0.01790545704293876, 0.052956988389093074, 0.028607969645470865, 0.06514045620156873, 0.030458654209430662, 0.02192580986077026, 0.05291558516722533, 0.034190492569318706, 0.055427959023584286, 0.09141952430288638, 0.051300296439759197, 0.05109744401828897, 0.018986493288989992, 0.10764381863296994, 0.01995436494208632, 0.02279556480296437, 0.032142157320894545, 0.07910586367811888, 0.042867273347632545, 0.052121347342167175, 0.024643828529083443, 0.026810704392471144, 0.030948659367558938, 0.008410701205232933, 0.01754086430845482, 0.04160698976427798, 0.03548759050787457, 0.10593651508491848, 0.04615505458787084, 0.06382402986468327, 0.08405446991204255, 0.05737250468002693, 0.027632885274567434, 0.037685902789235115, 0.016580080883877895, 0.05745384023494779, 0.07257059742245944, 0.015535409873982352, 0.044600321280379454, 0.04414549487973413, 0.059381826900907105, 0.05615130307212953, 0.03914644941687584, 0.06467484328294955, 0.006028515851921252, 0.024225797331441316, 0.0025893750294457164, 0.07088271420328848, 0.03020692537839134, 0.0492566075145958, 0.06832094682801156, 0.05142621065099394, 0.0543773383833468, 0.06001885965346329, 0.017485056718390797, 0.036213906977566025, 0.009320421996826847, 0.09343619713740003, 0.02478503194006701, 0.0024390506235161618, 0.005524510915781702, 0.009735945214126861, 0.03753470767649912, 0.041593215503399415, 0.03070527323401503, 0.024072338428889072, 0.02034691797058669, 0.04418601710048895, 0.04459339201510434, 0.03514065226960567, 0.05456986777003735, 0.06661216473026622, 0.05270766124369637, 0.08226873428230325, 0.07943560324248769, 0.06012660992001334, 0.08274409183931929, 0.019013607055850087, 0.030227339706353606, 0.026910853151592518, 0.01862566396143408, 0.07872316445554457, 0.0039625016882294615, 0.018695866343595328, 0.0677314728137947, 0.0436049738838788, 0.089598479680717, 0.07031343426675567, 0.030880808875325228, 0.016949226095851873, 0.05810296568538874, 0.032458233707133806, 0.046432688682069706, 0.01810326286020779, 0.023310339498904445, 0.04035866481342143, 0.05123873744460364, 0.015807160412922742, 0.04695873827703538, 0.06714784405044011, 0.059219335821727594, 0.04256545002722452, 0.017436701248610215, 0.028922686225644527, 0.04515398834501544, 0.048472478219698516, 0.02781590942533747, 0.05235834430242258, 0.06925776510709716, 0.026899308206573613, 0.02483070801733242, 0.03585422486667672, 0.054377054930814815, 0.05360985617904414, 0.02533060528578297, 0.03290737190494134, 0.042180854737037615, 0.023189429757035068, 0.05188619282336966, 0.045607102539149985, 0.03798402973540849, 0.11425097457944386, 0.04873500122959095, 0.04946031029366198, 0.040452200318536455, 0.028528164351178754, 0.058890668780452786, 0.04792830681488399, 0.06483061960147274, 0.028175421081663623, 0.027493099126243786, 0.01158389005614745, 0.02614092904203121, 0.03236830647614214, 0.03550214234799628, 0.041590128169064565, 0.046168759900836215, 0.03361774991536814, 0.11471991998053367, 0.05998344723916343, 0.030166600425277027, 0.05404811209788727, 0.06946467779456608, 0.027870242296147252, 0.03985176741656277, 0.063883543405081, 0.03830880505002795, 0.05029918040118871, 0.07366900662741355, 0.04264695412148872, 0.06838341363735738, 0.05249864564487531, 0.09521501499318308, 0.07514417787352878, 0.024338170938614397, 0.04771562165490562, 0.05760974295797849, 0.04179345939548747, 0.042366707667468056, 0.02020693263940273, 0.03434149999051325, 0.03493844719243146, 0.07810727572969853, 0.04194746222046595, 0.03395909954222941, 0.027993383269096096, 0.07541073816678218, 0.03630677981662654, 0.04692481973418786, 0.046165561483752345, 0.032249735217661626, 0.05244582388249617, 0.02081661222262248, 0.018788440408365383, 0.030785421352653258, 0.06394378855944642, 0.04241984735633578, 0.04542858107015491, 0.005662192237533389, 0.028872559177539045, 0.04200778398362379, 0.029676545471433672, 0.045608822406539996, 0.03041531853077393, 0.037172168057652256, 0.03798913188098419, 0.027356172401097514, 0.03762841172095749, 0.07494334026329941, 0.038919342651722894, 0.02072272814750191, 0.05046300064291685, 0.047951833375038645, 0.0637461455358613, 0.03997683127020155, 0.04371421419144158, 0.023711687216775554, 0.032813150751134085, 0.05025993754726745, 0.039585965550354416, 0.019246457565215327, 0.02183769251249971, 0.029226966773069678, 0.0696198489036291, 0.055128131362219016, 0.04166988941330103, 0.06928752762295547, 0.03690748084937373, 0.025569856459755572, 0.10106537566189805, 0.14674582728935828, 0.14725490803680114, 0.15450439806426727, 0.09891766348793622, 0.1352265615376734, 0.156850220575448, 0.13780639326620486, 0.1326139718894997, 0.13569085678506282, 0.16098519546851037, 0.12145118983162027, 0.13060063153745669, 0.13208166335619267, 0.11316832380309222, 0.1450994583748041, 0.12321552862563442, 0.12967810845903813, 0.14722142999451007, 0.1264517981138441, 0.1767571838272195, 0.16338040000729023, 0.1542356390986712, 0.11854584734406202, 0.16802941989754477, 0.1500880543983752, 0.0899892304873755, 0.1004634986841871, 0.12445352671127166, 0.11262524407356979, 0.21823905228126436, 0.17374560026632202, 0.22302773000011522, 0.1101316585235538, 0.1076755806383106, 0.1541163898523777, 0.2350997741544439, 0.08228169648998207, 0.19487059735242399, 0.1498308173951603, 0.14950644044626146, 0.16064088491182174, 0.2060305831893798, 0.1479787385511783, 0.236836755948682, 0.08844612256413506, 0.14767043412693087, 0.129039405634807, 0.25576505719894366, 0.12016191748121094, 0.09823374615441408, 0.1743827402711876, 0.14547292623789082, 0.180120600928222, 0.14280246630791696, 0.09043130918496078, 0.11306638814388745, 0.19887172136335604, 0.11827735650923946, 0.1050727969155677, 0.10281089167561262, 0.13401791994129458, 0.135184932319868, 0.13000559572490955, 0.06971567118119809, 0.2081008132306799, 0.13626055040907475, 0.09028859466554658, 0.16219748364340875, 0.13325829779909504, 0.11520987917338649, 0.15818854553564904, 0.17747450259424027, 0.17217996169722852, 0.18224266447847892, 0.13068991142415232, 0.18620102546147763, 0.10237707140585108, 0.11697912859099528, 0.13102034046765298, 0.12876879273643418, 0.09656090890207598, 0.17337090666255645, 0.14884216560711785, 0.18128333853617792, 0.12811773291398443, 0.14152224145589337, 0.17702745964690564, 0.11884764002095308, 0.09935097813966776, 0.148390035835966, 0.13408299144958297, 0.11233085946690653, 0.19497415711802824, 0.16716472113565092, 0.14907311047277144, 0.15219163990789844, 0.21333282603131187, 0.06588198334699677, 0.1117942225368273, 0.10742136968239661, 0.13339001895679584, 0.1671399458521797, 0.10635829245251034, 0.18835431475552822, 0.2765642677343661, 0.19120380943340642, 0.22897410446838026, 0.12214194833030625, 0.2576665946793172, 0.12441105479674956, 0.25553360671526004, 0.1637526727732151, 0.19313364620170287, 0.20609703365593188, 0.14331845716843683, 0.12778796270609866, 0.1545482336152946, 0.22613729620652817, 0.22820148947498492, 0.13928221568705576, 0.14428640926076522, 0.13164134666083321, 0.14489897316501987, 0.14495865141432132, 0.132702546975305, 0.18523826744527588, 0.10704597893861995, 0.16266404651105404, 0.21078838756488216, 0.09790517104369018, 0.11683668220235456, 0.18735411036158764, 0.12514078418814367, 0.15247587384956499, 0.1288763055157277, 0.2240753245930518, 0.20376406610012057, 0.1796385171192308, 0.093631878975899, 0.14340338567572256, 0.08969683004843612, 0.24823537817405117, 0.12838957921391533, 0.13180688293951173, 0.07857409906723807, 0.1598794548021209, 0.08551361459878185, 0.10900132643479495, 0.10634850950971728, 0.12330719870665383, 0.17957497778679096, 0.18811224629321407, 0.18859244552591156, 0.15364703842468802, 0.11174105603488223, 0.14987886642977116, 0.1666662583668386, 0.2525348934314905, 0.12524131790644702, 0.1544758383064501, 0.11160720515275195, 0.21138507812734575, 0.0740927528409708, 0.12700600910090631, 0.1384309081420783, 0.14654618477629078, 0.05352989575194736, 0.11858908534650842, 0.10611450029236656, 0.2840373635051712, 0.20988555294611763, 0.17425670348588498, 0.13714990188037196, 0.12723857041208014, 0.12577099875817377, 0.17105321489995526], [0.08741328282462013, 0.06343006914962204, 0.025936008183165424, 0.007804819502897802, 0.05094372081540285, 0.030408349045882785, 0.07842189271844204, 0.00326773583149207, 0.011953376177247736, 0.03193565832090474, 0.025481693146209565, 0.041138684046604944, 0.06030905758962036, 0.04831770164591651, 0.04241789000168924, 0.05940397067235843, 0.03169173401059403, 0.07017719319030162, 0.03313655859880871, 0.025529847517910025, 0.0492942454143157, 0.02803983501038484, 0.09663665967602884, 0.020309971465218454, 0.038349955462880676, 0.03755130114093904, 0.009858221465331173, 0.054006379458212087, 0.012905309371079409, 0.03591330173695761, 0.06799261686542342, 0.005352726232470764, 0.007172513034029474, 0.07381551328205294, 0.041872875900158, 0.11117936802967904, 0.04790787524994343, 0.034337412911437215, 0.009430037687472519, 0.031205296906973087, 0.02915429758779224, 0.029203444043354645, 0.023475910251539563, 0.0793909173338644, 0.057271032504016356, 0.044814580751042214, 0.030658160741891594, 0.03434172215601129, 0.04331497513058205, 0.06419322295715252, 0.010544027205586675, 0.060061959760083314, 0.003785761852463287, 0.012159422227752306, 0.025111203449928475, 0.04133716593646715, 0.009294806889468625, 0.01737739646717185, 0.015595184841884241, 0.06611351810035206, 0.06944593928393818, 0.03746793162257921, 0.02841738612210799, 0.05090670344690162, 0.0517706361208712, 0.04147047672661082, 0.03272416580828928, 0.024189524983446446, 0.058196141129179355, 0.05244894569078761, 0.037120985723431074, 0.056773305179611336, 0.06849433550791395, 0.0393937464292732, 0.06447348473293167, 0.02522064485557137, 0.03890402089323729, 0.006975011257905394, 0.05383274946061354, 0.046884408596182064, 0.018536466429190292, 0.014404150818835103, 0.03653494761355462, 0.01912178250119811, 0.08527903847636716, 0.08572192922715219, 0.02587407380492697, 0.036279327055859956, 0.06429405928018593, 0.024952429812401537, 0.05726158663990998, 0.06315605482086539, 0.009412673347058797, 0.07226771690071591, 0.040497541232334996, 0.1404419502303485, 0.0367057201031956, 0.02389699430955995, 0.022103375635079803, 0.01800845947957808, 0.23310661255832643, 0.013144958910772638, 0.023027555378634604, 0.08331392335915759, 0.040395980956213134, 0.032597711505067926, 0.05111678007749781, 0.05234875288161059, 0.0641893005869802, 0.06677944002853287, 0.05463460603007867, 0.04077297282375155, 0.029111806521072026, 0.07369834779491348, 0.05334249149347025, 0.01750382970297529, 0.12716232934185576, 0.033502721813537424, 0.14780727275196584, 0.049552907341069756, 0.022579416925568255, 0.09993909617825862, 0.04262669875677075, 0.03891780664543471, 0.04412564171117641, 0.03873267000721347, 0.0797674035833728, 0.038594023414677193, 0.017052898859424938, 0.03967263690766789, 0.03508187417361525, 0.03288149345485914, 0.05710100695010155, 0.05055516485064741, 0.027875242935072993, 0.02021635743609119, 0.03605210920795798, 0.026739276269631043, 0.01429031111089693, 0.019099418479468555, 0.08788824201591554, 0.10595727606766647, 0.07091770909966962, 0.015577938287488878, 0.04110393429835958, 0.07443877177373057, 0.04040493269360835, 0.01814019595903735, 0.04124238936891479, 0.09243396261046011, 0.05244108562868449, 0.018414537790381623, 0.05235380906191084, 0.01783205815891345, 0.015679349176465504, 0.022108849333298784, 0.058403329608301004, 0.0739689377106486, 0.04897144277610126, 0.03845084924250841, 0.009063867769474465, 0.04964692165113745, 0.03821548404953173, 0.025314670656957937, 0.022654275207089323, 0.04501122786032577, 0.02221262934918125, 0.041343738970857476, 0.04675945199485268, 0.06916285447415806, 0.06660559935675514, 0.01653139216585025, 0.021481909789144996, 0.06965708077674912, 0.029841756162744378, 0.025397756722785776, 0.08433409200440492, 0.029053660447619138, 0.0646965618756029, 0.0975318563981883, 0.044379446640490525, 0.08543292255771738, 0.044850326413589145, 0.06743727972911251, 0.017163052726837418, 0.056499371290086746, 0.032289702024671345, 0.0902274455274305, 0.0021709720397578374, 0.027676692097297603, 0.0762904828955089, 0.04668139146580812, 0.05577515773174744, 0.059770865501054836, 0.04902897597921472, 0.08986657981069819, 0.07779099633015933, 0.062052394083190354, 0.024194418370062788, 0.05832182551403681, 0.06392537563618633, 0.0568954655600171, 0.012641194813524284, 0.07237518371473398, 0.03987407589691781, 0.08207409432338131, 0.06502831625121255, 0.05201401842397548, 0.06616326785015483, 0.009186063581446727, 0.06456608178033944, 0.04718911240718538, 0.04930269919456013, 0.051163810215169386, 0.04539613724656163, 0.05894509549703329, 0.04662999462696814, 0.02837756487180389, 0.06899665169898542, 0.04842766590656773, 0.04890493485295484, 0.010724188102739713, 0.04869370526003261, 0.09898857258620763, 0.03471486826216982, 0.06499358182472569, 0.021686388232234507, 0.07729989566629933, 0.07842810569150795, 0.008821502448089661, 0.004206846389288624, 0.016847244471371654, 0.010006192305515851, 0.059510522011306986, 0.02224090565446644, 0.021504880935554544, 0.06678745330822083, 0.0817999420987983, 0.03606545445959895, 0.04770964616909624, 0.02365688703233196, 0.05358164499123251, 0.03724331081274056, 0.039878254906544765, 0.0811626565372271, 0.02391109798824595, 0.058362631187323606, 0.014423129689549247, 0.05652910316242807, 0.13578344617159138, 0.03068388214394931, 0.05221945639219015, 0.025088404673301888, 0.017437645451976888, 0.034837377212581136, 0.01919831660005354, 0.053772695828229196, 0.022026874094961152, 0.025277316209770022, 0.041089757841320775, 0.018451853933173324, 0.04012881162305994, 0.024211622789622318, 0.028794638459540667, 0.056095681258387146, 0.08294541974582019, 0.023584455334311052, 0.06892429469453712, 0.024652224852733558, 0.03170938084592983, 0.0431337378798954, 0.0576124127743946, 0.030561499598045504, 0.04567675525322557, 0.06384245810970184, 0.041838968848629345, 0.024424235171247876, 0.12364000262271975, 0.06784637834155752, 0.01354727189942834, 0.04453270636018246, 0.08706949320772002, 0.01833335353782581, 0.053188925338608604, 0.006489165478401007, 0.10097008964587605, 0.03542230449496739, 0.12604468366912297, 0.07197431288659573, 0.03237260039895773, 0.005804441358533598, 0.041795838098492355, 0.10949171463688535, 0.08077038121559928, 0.06748762702749622, 0.0665858879144634, 0.05553009386564936, 0.08075174995728078, 0.0341920132538484, 0.03244794514631072, 0.022876664785848513, 0.013015897993388916, 0.045323140558696566, 0.036274443245342666, 0.007061142523232247, 0.015517420214300436, 0.06937543621226665, 0.026716375986354488, 0.04707001637847674, 0.03722073420161202, 0.031926371420042655, 0.0271570086929827, 0.06207460680255487, 0.013282822178406341, 0.033218970507263176, 0.07645026585387607, 0.09524687658995391, 0.07328819198113296, 0.0308930279777175, 0.021674485141110998, 0.0718306637399139, 0.05590735386396128, 0.04555707316725485, 0.03953034756705165, 0.031954596014392954, 0.006111930377946626, 0.04408164528168498, 0.015705701643450847, 0.024717978179274548, 0.024321544915437702, 0.02043380957817839, 0.03429975585951921, 0.007276326087453673, 0.04817607114091516, 0.07983533259961875, 0.043030507532098604, 0.018788520847597433, 0.01999025041567943, 0.03286499958184939, 0.013205723089706755, 0.02702079059916639, 0.018411136359997818, 0.03210016612654492, 0.07139462181517194, 0.03185567491117024, 0.022811752240804416, 0.06456948321072326, 0.03165170974699, 0.029689494272573825, 0.009048073909305518, 0.003007987735702867, 0.022574178799385988, 0.13375873707475203, 0.19103058163196812, 0.16500855135100503, 0.11989075299953261, 0.08791258829014917, 0.18902825762427625, 0.13994255283426854, 0.10671807798526942, 0.12939868554953607, 0.09365635548507975, 0.10485764878291277, 0.20459718671777558, 0.2220600383776811, 0.1613259666989888, 0.17597272511451476, 0.1570788212120533, 0.1499420533617658, 0.23129614761039136, 0.13123528941744758, 0.1464818793559267, 0.14627469853768427, 0.12837819514736054, 0.24994275833089508, 0.27644647405512873, 0.18474555033589565, 0.12217879715946414, 0.08491638011389202, 0.1365045494129581, 0.225465115340006, 0.14910085817738888, 0.1321014284246391, 0.07572377701440165, 0.1146671288616715, 0.17314670337063653, 0.12859069261579745, 0.24342118972732177, 0.13748071396783476, 0.11970035716771119, 0.05861788402281462, 0.15010930567739472, 0.12317531667048894, 0.11343432485216087, 0.16665329615915978, 0.2304739514065366, 0.11188541764333365, 0.12336847041883778, 0.11869188668506762, 0.13403272075999167, 0.09030754768079327, 0.11693629661514876, 0.10237550092560631, 0.1686915343687419, 0.2815602028802518, 0.13973229234257054, 0.06611178674164318, 0.11320556333709149, 0.11237074200424457, 0.08046498026458487, 0.19587990287090504, 0.15484630310487363, 0.16585501722030102, 0.10955995008830102, 0.10170355754634065, 0.1322667808422158, 0.1428823846001779, 0.11132712340763501, 0.18901828315950212, 0.10324085852311504, 0.14057780826284041, 0.1372516536784749, 0.2005642240927104, 0.11117598958193295, 0.17072932824732798, 0.17840603486664836, 0.11834660319671517, 0.12298538049142207, 0.2043250416435542, 0.14879108286432682, 0.13952668966545215, 0.08603326735957977, 0.09083734344570868, 0.1379362604911289, 0.0833298886314996, 0.07954878507242089, 0.15623094574097665, 0.15242218640783142, 0.14425008137139583, 0.1488873647946504, 0.1289431696697589, 0.20521681395269212, 0.07874849132232128, 0.1714132609026086, 0.13680107140493009, 0.164233484876252, 0.15555323371964117, 0.1769840684268744, 0.14901890209124935, 0.14633221641903923, 0.15502389760748034, 0.14368824780948702, 0.29892904023008965, 0.1845328536845984, 0.15537940836962194, 0.18536237368900932, 0.13965707783016468, 0.16234785138118654, 0.15942105843174845, 0.16624829611710965, 0.1057790227294449, 0.1453413429760164, 0.1450075584674074, 0.20773129838128246, 0.14512175153340065, 0.17347555427301317, 0.22308190773812034, 0.18661466697531362, 0.241714223257957, 0.16348068091657855, 0.18172613735641205, 0.15519082816618104, 0.10170146612630737, 0.15669562403232823, 0.12511545732136697, 0.09679142475849199, 0.11129196763278977, 0.09192869698088016, 0.11021798897174098, 0.09569357479772261, 0.13599073424214317, 0.08169595332395646, 0.1558670999422189, 0.2090434078127146, 0.08992332394324964, 0.12717023536923433, 0.1035915122878167, 0.09627479804499496, 0.13537110700722665, 0.1275773421530762, 0.11955300015547585, 0.13586622963268913, 0.22791748535969567, 0.19363711918554, 0.2003457664602226, 0.14680673127933858, 0.21137836719712905, 0.13513887511386027, 0.15492576174438, 0.09444146537252011, 0.12881733206731658, 0.1916037379733978, 0.1661066617816687, 0.10169731392975777, 0.1869233544435232, 0.06390999259066678, 0.0792917855564625, 0.11151159737980175, 0.13559546351673143, 0.1531464306096877, 0.22599992131994617, 0.10674301414720475, 0.15703979669319046, 0.10220735994798523, 0.1567754963593137, 0.20127277881387742, 0.12259390956211476, 0.15272039379323685, 0.16590962396754375, 0.17741333813436572, 0.09437106189227874, 0.31039820383152655, 0.2153260489144633, 0.18996418724136968, 0.11288991979052944, 0.12830452047168248, 0.15303893315215267, 0.08208793753217306], [0.013005641991302613, 0.05852743202159482, 0.09825580182575411, 0.02570819087146271, 0.02609678322539455, 0.022557158240928285, 0.05650001097350352, 0.020010235734404098, 0.04072945136877318, 0.014826768010313955, 0.024324814195654566, 0.034109072744726174, 0.10243723995142406, 0.009948494393498668, 0.05333357423003163, 0.07172796199278486, 0.026659662497320005, 0.06296290107251656, 0.05186730109515691, 0.03769903353625729, 0.010046728890419248, 0.06920621505067234, 0.06559257065096209, 0.026197891509641084, 0.03397650889030868, 0.016208721677802743, 0.06299613779711147, 0.02274271431228807, 0.0224494194656971, 0.006945109409805869, 0.0329425506624243, 0.0538362504824275, 0.05037323045994967, 0.0729271040989026, 0.056904417297412316, 0.05843228773183881, 0.0426127482956696, 0.03195266738804358, 0.0675068634952749, 0.03538997175412313, 0.07938157872206743, 0.02857769002026368, 0.04127491363174012, 0.05431350410705613, 0.017042583485524503, 0.036603393739149455, 0.027059217569448298, 0.027975895397004583, 0.00800363655622688, 0.10829895404317688, 0.02892649176740839, 0.04380015010434774, 0.051647315117260145, 0.06638204723957085, 0.01574986565467571, 0.03424782658957186, 0.0150611947455834, 0.0308731977917975, 0.0663961585791361, 0.07207319951586186, 0.09575429492660108, 0.02855289941503396, 0.02170727178905039, 0.020518517835185896, 0.039189040075026216, 0.027932312654992266, 0.012008247224824324, 0.08135447729258768, 0.02245889788854026, 0.06723266530541644, 0.03929539223111445, 0.025469749835470033, 0.007450662322357418, 0.06258371053263545, 0.009903346916901009, 0.034016965993589936, 0.03380538016978291, 0.016537520869244492, 0.05359213273491591, 0.06258852922567917, 0.010476900666441408, 0.08390769512662966, 0.014792020177288402, 0.09934808232731397, 0.02750416718152983, 0.030356921563525836, 0.04275324116010339, 0.06016127922902665, 0.02191111629438256, 0.029191426039042494, 0.04518177435402909, 0.028781553677793954, 0.03369399481603215, 0.015708285274975482, 0.014805309887554859, 0.06155016216179056, 0.017190327372161612, 0.08481708745802603, 0.0502029444361406, 0.06348429285290261, 0.008707810212076913, 0.029158532138793703, 0.03184836451715279, 0.011958663141535176, 0.07973630041364702, 0.004214999480022779, 0.044172836557751706, 0.023562640980667165, 0.025659180396506866, 0.03701422754074297, 0.06714538490820317, 0.06027210533859269, 0.051286411096131614, 0.02419226757821537, 0.06993517069326294, 0.055569796372325196, 0.031961555923185045, 0.001635198634410758, 0.04603634926400358, 0.0235148428398515, 0.036905335803185745, 0.03596974326477897, 0.024202772558877067, 0.050648332633558786, 0.0639534336064131, 0.022928812390854283, 0.07310400912237745, 0.065584679945342, 0.06748630935626646, 0.013919500615297547, 0.045685350759735996, 0.02011097821166679, 0.026689836785437602, 0.016284872732696035, 0.02320115090227656, 0.113669230392383, 0.037833830536974054, 0.030694852523025007, 0.04472021021008973, 0.03685785750407846, 0.05973083357657156, 0.01926422314417939, 0.08312591772165992, 0.047758932435704816, 0.049490195383588155, 0.04171633349371053, 0.070712604379702, 0.005749859030343472, 0.07611593742284083, 0.03194475369978576, 0.06604950379339919, 0.06722946305789294, 0.0521636966826214, 0.05309614826053862, 0.04001976283747823, 0.04857604181574238, 0.03943820634195882, 0.06099439601624205, 0.014685046532371593, 0.03761198679586092, 0.0050956917637508484, 0.09300704234309735, 0.06641061465826727, 0.03443005975456007, 0.02736355940390739, 0.05192772628018453, 0.05810196977108718, 0.08425011344614529, 0.06242008181288839, 0.07383962972990929, 0.032465886925497366, 0.05745177179755223, 0.035974726666726416, 0.04617739754218248, 0.022163333506473613, 0.02950797739979481, 0.06270467964631897, 0.03683532302778575, 0.08140131590827819, 0.06244899397115074, 0.04869092436086747, 0.05098716183114917, 0.0384523852487966, 0.051663272728722905, 0.030150458952712438, 0.05576866130614954, 0.03378906249699574, 0.024830734830409772, 0.035589782806533965, 0.05674808556514402, 0.04387950915242395, 0.03646313836197219, 0.017460109065136602, 0.027541337767615918, 0.009775087519008066, 0.015076070257853118, 0.02486249492053063, 0.03429131740103326, 0.03545366430414781, 0.04734629449704963, 0.03309776773676276, 0.0536922489353005, 0.043080621173665415, 0.03213179406649884, 0.03323441483981667, 0.03999847325406248, 0.055083437792716496, 0.11874990252357338, 0.11177772866381754, 0.061609300319105394, 0.00804632297536779, 0.03836583646555101, 0.01552897186258868, 0.04432595072073802, 0.07172337312611841, 0.032449281969738585, 0.08904386266705491, 0.06572894962324251, 0.03960135242631359, 0.03544952359891707, 0.025322174488176263, 0.0277492291324081, 0.013935087631726939, 0.04687791600102379, 0.015271738689813404, 0.02498278221596153, 0.07411871556072466, 0.0404268657908805, 0.01851543540044898, 0.03590930275799286, 0.03213221349963739, 0.07151299006035251, 0.02289422926673245, 0.027831922578174743, 0.043051517493421995, 0.02122629689232957, 0.0468021767183898, 0.03773475621616648, 0.01748900015598103, 0.06506472841025361, 0.0589290957507347, 0.011975518991089156, 0.008625497895052597, 0.005691790044487965, 0.02056160453526724, 0.040817631919297485, 0.04555364109335407, 0.04446245226708632, 0.0760785982974114, 0.021025430553803043, 0.00793060826723494, 0.01217548038825513, 0.029879899680494305, 0.03259291962510155, 0.03982476281723188, 0.05002448808461909, 0.025676369494307908, 0.05901459882396364, 0.03588313319449944, 0.040262486304967635, 0.07040832191705704, 0.04288676645486586, 0.05269843371464841, 0.048115695751602613, 0.12471548281610013, 0.030573626769886866, 0.04864971649142043, 0.03106865171913899, 0.03422497035635095, 0.010995429193210459, 0.055071640038682576, 0.05896692134199604, 0.01721031269088628, 0.033785867910351486, 0.015929265251953997, 0.06326208522002544, 0.05721333076155955, 0.0418250183875282, 0.028110150390514926, 0.018046821332386425, 0.07569435923810929, 0.02147525823074243, 0.058009514449945385, 0.04722617957140169, 0.04017888696023053, 0.033795784918531295, 0.0923963247107402, 0.06019735430938102, 0.04194187743949794, 0.010585333708853973, 0.05999328763855081, 0.003932918245423465, 0.030039994819690625, 0.052897815757821647, 0.05944168135043114, 0.05708148319935126, 0.024277109900609623, 0.00906788685824722, 0.026813732354991862, 0.02941439975984395, 0.023489567684009675, 0.029423468325647618, 0.06228416632380217, 0.029931685308955853, 0.0820333767502058, 0.030242236286041238, 0.027702490108147747, 0.023756654662711006, 0.020854179259209384, 0.04999412035930061, 0.010939665653202082, 0.08436793010802039, 0.06335332629180725, 0.03053747508074007, 0.012998666760752038, 0.04077652364128059, 0.02724596682275015, 0.06783700908624357, 0.035359094580335, 0.017309770055655992, 0.08775866590440275, 0.011735042076437704, 0.031053031186362913, 0.007774143427189801, 0.04003193597459505, 0.04270547940846413, 0.0655342253946489, 0.08839887026096545, 0.03326072612957608, 0.09286577572986003, 0.017392314114277403, 0.0170262428300996, 0.012689882573942024, 0.055988720062399105, 0.02142440339910888, 0.0510711403894088, 0.04070127465491814, 0.022987872024156877, 0.0332068586571803, 0.016690617795252514, 0.02387746481315023, 0.033679508093384006, 0.021956432310323563, 0.023711472712156755, 0.02545018394988391, 0.041668169545911016, 0.05763129301128849, 0.014409040375011823, 0.011243140850696835, 0.027520360365029306, 0.06371430309128857, 0.0321529246866703, 0.11927521667413174, 0.16483915398918814, 0.16431343381202992, 0.14317958074952328, 0.0995008402594155, 0.11067406409570288, 0.1914583038418524, 0.059953458727367466, 0.08465563442798392, 0.1959601122765772, 0.20507856572587646, 0.14179685333323094, 0.28170091791018365, 0.11325095404660511, 0.1121313701714239, 0.14196560718119144, 0.0932287788319011, 0.08420893622021522, 0.14064012185460137, 0.18912565804296927, 0.09493051292074305, 0.12247315878348967, 0.12503256660795983, 0.20336717126830933, 0.09275399584082827, 0.2031323346760004, 0.14757881001118692, 0.1098689056872841, 0.16635668223663685, 0.24266271671700865, 0.13590850236435092, 0.22004574807661198, 0.2117605531407941, 0.13095071839709438, 0.15714196217877252, 0.11911032390930962, 0.11449186326635462, 0.11084046605373583, 0.2288416325445137, 0.1329238084895957, 0.18819504507607032, 0.18489478426354547, 0.09937848835702866, 0.145541399176563, 0.10922599704034867, 0.12925628512617082, 0.14661478028903085, 0.19812912169483402, 0.05521646513032818, 0.221150370254632, 0.19292862575140693, 0.14721274255744873, 0.1284249571542586, 0.098758730887165, 0.09614343694861859, 0.1649734798458315, 0.07853686719411805, 0.13340952355534802, 0.26791740268949543, 0.09702184102347783, 0.1716833835047099, 0.15390712527498124, 0.13581684760509, 0.0916765851058787, 0.18668048924976782, 0.18743759862357573, 0.09749705302378825, 0.1330695643780693, 0.10470496745960367, 0.24179293113129757, 0.08570843075792636, 0.1900072107391973, 0.19778314106647046, 0.12794755414248477, 0.16303443470068518, 0.06513761401536965, 0.11885017577198245, 0.15629698252004964, 0.1160046264469143, 0.18026962035125305, 0.13363170437514782, 0.14811743110899003, 0.07379942543564305, 0.24325703240690694, 0.16668098257674327, 0.12746786818869654, 0.20054130274201595, 0.16130448559359198, 0.24696627691868814, 0.18878848742573492, 0.1299122708939737, 0.12494904770245477, 0.14792725744266666, 0.09509280864750186, 0.12401418294757606, 0.1505097704789331, 0.09045831378429167, 0.23095309343789858, 0.08235655094106352, 0.21300737655931906, 0.09478114109726683, 0.09328317873540426, 0.11665659025311471, 0.10737408673571003, 0.334033303323292, 0.17940839962853541, 0.1486416497538167, 0.08820451375457548, 0.21787563549174419, 0.1506081514901692, 0.20681934731621898, 0.1868363728206004, 0.25022872363127047, 0.15314805471608717, 0.13998857939675932, 0.12703714291414908, 0.1153280022704313, 0.1170285642447491, 0.16083093600407725, 0.17437685671592915, 0.1723602221858117, 0.13099841503126006, 0.1227390449193697, 0.18352805276311215, 0.13551376790048617, 0.0750424720407013, 0.21602369454358855, 0.21532482317378446, 0.16238837743238096, 0.1300293904158377, 0.16758364865616446, 0.10439238826473875, 0.14269643973919655, 0.08813481507522446, 0.14642606218976362, 0.21760919011167942, 0.13169186249856027, 0.11193921233737662, 0.11292113021256463, 0.13469687302506742, 0.25585971502286775, 0.11911159561526392, 0.12199614647655718, 0.20658107865000927, 0.1796938439891223, 0.15577493956492794, 0.2222835368687107, 0.16694393459587328, 0.21479947071882988, 0.14899325346754444, 0.17118656016405553, 0.17450908349165994, 0.16607485381105255, 0.17232227019004284, 0.207380966373509, 0.15012779903988685, 0.12382440764697329, 0.21008473580643056, 0.06982087803583953, 0.1810189003064748, 0.14329147555174368, 0.27108125388622284, 0.10610994206921709, 0.13172330274697275, 0.16463525202726165, 0.12943827697346288, 0.15942818304944426, 0.19191550511506297, 0.16146213116665042, 0.18554056574019695, 0.09897901180891261, 0.0833087522656687, 0.13005159164388336, 0.1505459911159931, 0.15640207446150242, 0.07658473726722502], [0.07104381483288542, 0.05604909162127203, 0.06513130145087358, 0.05707331287163881, 0.031531550771286415, 0.08484707980026161, 0.06088969477963063, 0.03042775979866424, 0.04233840837954514, 0.0582108615086444, 0.0216196121783146, 0.06115046344817646, 0.023587523516447797, 0.02532904629685706, 0.009167098117271259, 0.01381939111818229, 0.033185205182000514, 0.020902856485918168, 0.021772147944918083, 0.0316732770372783, 0.04667340116875787, 0.052825642614475185, 0.018490008942242113, 0.006616315964023553, 0.027943390286377365, 0.01148198982850919, 0.057290923976970304, 0.07172006362628552, 0.010108891179815177, 0.05857337814485354, 0.025135536317623434, 0.09015295879855272, 0.052867750637233264, 0.0441806927894152, 0.019756319722340956, 0.07906901484896099, 0.006725278564713776, 0.024727931576630762, 0.02007809388751705, 0.020897388533358614, 0.04257366248977281, 0.01804661831908649, 0.043712425376138384, 0.04941844358860005, 0.043716102598174926, 0.06778536709926783, 0.027448294473992243, 0.022573368661406062, 0.022938890277498195, 0.03663158577476298, 0.03798265843802402, 0.042384737546766, 0.032519068749200915, 0.003219106964083509, 0.025688575190161506, 0.05485224777892713, 0.027140143267329664, 0.046010447831283656, 0.025323112945883505, 0.050741419977238106, 0.01809307580603467, 0.053738635559115684, 0.014111420962088292, 0.03970250667583558, 0.04000771993530854, 0.04460431642890458, 0.037436054704049905, 0.038461608947404934, 0.034811912449978055, 0.03002042701888469, 0.012342059504120581, 0.027673968654726783, 0.039131334502129786, 0.04079427772892579, 0.044487231380997166, 0.052405776636254404, 0.014290490183949232, 0.04201595814177587, 0.09941618754378251, 0.0222251663780621, 0.01796142359624707, 0.016452548311903112, 0.10767598666491048, 0.01776849775905571, 0.03236344564826258, 0.03638222415540968, 0.03413898464772971, 0.10174684917494174, 0.017145664446176063, 0.051493925162621086, 0.011427179110356638, 0.02425909917350979, 0.016337424449081865, 0.0560053096963994, 0.012013691237136241, 0.023965164643502044, 0.06142563456969877, 0.03794457237686842, 0.01736463918801277, 0.013693985397807293, 0.05330505660705028, 0.061714936182984424, 0.06119040727254845, 0.06176331463540274, 0.04047878739994861, 0.013828520971019904, 0.03553038417932487, 0.03944821528068954, 0.0795500950827714, 0.02018611611528022, 0.07476654249213396, 0.05341911943809641, 0.0889280684772999, 0.02752768225036562, 0.02451145428142721, 0.05515447712593502, 0.018967136162363233, 0.012680264340052682, 0.0517826637012824, 0.02083321334794164, 0.04295962907734417, 0.028222629334777597, 0.01759017164248132, 0.035025666302610795, 0.017113249350879944, 0.06718980268605294, 0.05697759401593959, 0.02379534210288717, 0.03726996301162628, 0.037131971424265255, 0.07431991323227845, 0.056789017642938325, 0.04157018306995592, 0.04983547887194061, 0.03067447841467877, 0.11236552494548022, 0.032403125172300686, 0.047841735049000675, 0.0597677973189181, 0.03823148762626994, 0.04566277414860745, 0.035348683445444035, 0.013758357850864772, 0.04430890143398316, 0.04850044425937438, 0.04049641125264668, 0.029507962078036323, 0.05526070287751575, 0.03649359801784158, 0.05439197449314018, 0.05009332491505531, 0.06571088526998797, 0.07179379192811829, 0.023013495750004248, 0.008492124860265083, 0.04500432157768838, 0.033803422815136375, 0.03075150472502555, 0.06258559127848956, 0.034158175150232936, 0.05215103707967266, 0.05138723975828579, 0.01974835623836806, 0.03008373460972742, 0.021422848240622593, 0.04284253253811791, 0.07233599831740703, 0.032024248728468534, 0.029569917523692694, 0.021084386765235857, 0.08495507521494743, 0.013099394873866152, 0.01633449224755168, 0.037956021560896794, 0.02286240405913803, 0.03669617847809869, 0.027358872861030604, 0.02021029385017051, 0.043084126025918996, 0.04400135926722039, 0.03296138110360311, 0.04530905220176905, 0.06222097939180751, 0.01285906830396984, 0.030049519207809242, 0.01326855762125624, 0.028672958799307386, 0.039906768699086485, 0.02660542538750076, 0.01830571308551777, 0.04934825078253785, 0.04115426244454519, 0.023279600220942692, 0.05513488825771117, 0.011777124243728336, 0.04481929219177654, 0.032915722263315995, 0.020794817021176703, 0.022124998466742617, 0.038267018784198074, 0.034971994182635704, 0.024503345240748698, 0.02725883518465825, 0.01619966651853775, 0.0814547045757213, 0.05416366496994611, 0.04747082208914142, 0.03354728897853244, 0.03607303873004933, 0.02124880072510531, 0.029706329054709886, 0.08347687026065204, 0.032399976550931894, 0.005322584981894902, 0.009357172192164488, 0.04382953723712314, 0.06740220822393894, 0.008733157188661637, 0.011591564341928932, 0.011787785314804605, 0.026743654462118304, 0.00846527826656858, 0.018763927510008216, 0.013101373295930606, 0.09200758105444332, 0.04994561933281441, 0.03760951616230511, 0.04455300002929665, 0.02372510907720895, 0.02442416239289507, 0.07342516084111507, 0.0699318535325508, 0.09189878124743701, 0.012587755392756195, 0.047778996278441725, 0.06984867170573243, 0.02493353808418878, 0.03558003050725787, 0.039926981928968625, 0.05867888377378545, 0.03760187443526041, 0.039536453287808165, 0.025923141736477136, 0.028677348483113513, 0.010482448100623105, 0.025737859541550282, 0.05616992666956879, 0.042392750826453975, 0.06641786185003097, 0.04603850197107081, 0.03454851609985194, 0.05470309046006972, 0.036589021929689956, 0.044006116673230164, 0.06234419314310916, 0.018734538462013006, 0.015530434132914151, 0.07090981839404953, 0.005686395827891125, 0.07688147376381582, 0.0794727431850568, 0.0386085752547989, 0.0377099541196179, 0.01622539749669452, 0.023073024612160462, 0.06056045317241262, 0.04336451420620565, 0.03843569602336615, 0.06285771720051285, 0.022464021101533886, 0.03176789081114675, 0.033405623999574495, 0.07845032990219132, 0.009975756589894094, 0.0569525582625741, 0.053573053315161705, 0.03690720122728137, 0.027227350886190133, 0.059540491370904836, 0.0366020415939631, 0.04096031579519472, 0.015682444171679598, 0.03804848454291782, 0.044593579706645785, 0.05195387669147984, 0.08188850186284512, 0.07040980046675091, 0.054686661704533526, 0.07912217369002682, 0.02787209048326458, 0.013764997917948472, 0.05618543228915623, 0.049119803363517414, 0.04425946961066896, 0.022404660778721015, 0.032463695914033926, 0.03211507994321085, 0.050990938644615874, 0.021725931775666053, 0.04347932780341756, 0.013153646347833978, 0.014831722683964238, 0.06655151354930093, 0.023199218445487564, 0.02667084929623431, 0.021783687144277558, 0.14666163422647985, 0.02938947508922748, 0.02577580004600027, 0.05092655278501972, 0.05471544362784875, 0.0201788287039005, 0.004501978410483008, 0.029623396206466906, 0.026046468485747615, 0.044005760442345374, 0.013240646165344986, 0.0276042259253201, 0.07418808482226825, 0.01694457211171187, 0.04270776235047848, 0.05582417586758252, 0.04691172346112229, 0.013522973505689973, 0.03661678112562626, 0.04061322816978059, 0.04532630833226346, 0.06721863057464361, 0.024458396947011355, 0.021846661486873226, 0.07701114180587953, 0.045970921524830406, 0.029982802525703466, 0.014030027950573114, 0.035097816463319526, 0.04223087644805351, 0.005682628590523476, 0.032181415496574294, 0.00812434615762604, 0.03850611099492639, 0.0470795311904963, 0.08083441084431064, 0.06714513976006739, 0.04483602738248245, 0.03901166773791756, 0.04719683840390175, 0.02716225831048383, 0.007098525219912371, 0.07154589353670036, 0.020393233731268876, 0.05751393600216797, 0.06107273616737897, 0.11668491252367535, 0.09880772220992273, 0.2646151960136429, 0.13893799706091806, 0.12918914518048688, 0.20299589441668606, 0.22863432915220339, 0.13829353325549634, 0.11129396712227214, 0.12540107788217644, 0.09332840090557452, 0.14936655279128783, 0.13314850207778717, 0.08390496019273998, 0.08229281242576339, 0.19774906547559848, 0.11772008883135936, 0.16307358179361592, 0.13005661718066663, 0.10872480699852591, 0.10288888708718362, 0.17581210712031012, 0.1277140735258018, 0.057484943404673576, 0.10672724805772306, 0.08340945452331536, 0.10490837146437938, 0.12134461167959437, 0.1708694150851619, 0.2155688987864602, 0.2632316412223924, 0.2275454577419066, 0.14540866678280218, 0.07341433601874499, 0.12996883882630256, 0.20672248315907296, 0.10572613201915257, 0.058384874550205086, 0.08606296092752488, 0.12220372566052022, 0.11756089576069387, 0.14022625051438808, 0.10972925551956701, 0.1453535850610464, 0.09096139606328742, 0.14923003592318104, 0.12249940495577552, 0.1423443916944727, 0.1582634076476097, 0.15641759540284836, 0.12966637199203815, 0.1438855460935062, 0.13016161719156852, 0.09581124590289208, 0.10547415803997748, 0.2823238086796576, 0.28318127557154626, 0.11959501241724338, 0.09495939443548841, 0.2596051342064335, 0.08126808555736657, 0.10868001383759322, 0.06927326306580536, 0.1600747152922615, 0.14040868669267625, 0.1631659260320087, 0.10191128228700931, 0.1449622979928409, 0.17259735704189347, 0.13273464605933236, 0.09619301049819878, 0.15842076210725695, 0.16352276978713853, 0.1139635154076161, 0.09292392180331292, 0.1612788063263701, 0.08978425600235501, 0.15339044493532952, 0.15289935193234874, 0.1416796878460915, 0.1252496606039424, 0.20196014354305886, 0.20399200790111097, 0.1933923540937324, 0.1713753855156322, 0.1850590488362697, 0.16442719786878557, 0.19053340589086856, 0.12877512062268873, 0.0999058556232241, 0.08283647438210827, 0.1732534347402473, 0.11351153119316987, 0.1722019177771384, 0.13964687353901326, 0.10392881313999815, 0.14171966231398045, 0.188705382207709, 0.2127617074837608, 0.09522079129613216, 0.10837493464350702, 0.12662457392340706, 0.18710508582092103, 0.2936454850339121, 0.13597789460853224, 0.14466016823726316, 0.12377864921525603, 0.17803540152888145, 0.2599327134028558, 0.283415790406927, 0.25155152765012556, 0.23509868630959144, 0.272367301006471, 0.10077134345567997, 0.07826894326435943, 0.2143829333926401, 0.1915531608486368, 0.08374500103415021, 0.1329177410732354, 0.08111845326399611, 0.18097049887141875, 0.16171765213291492, 0.0985467926629128, 0.1944875993555592, 0.14036848239841002, 0.10432370082144776, 0.15383425499162368, 0.20589996519828999, 0.10405146381667546, 0.1241929495647069, 0.18266070333700027, 0.1640236227502746, 0.14583108766425043, 0.1322779504041518, 0.17307351133035076, 0.19338431017052746, 0.12666204328378364, 0.09217589823228699, 0.09271756069914949, 0.19826632804207264, 0.09842139939146657, 0.23662735347545918, 0.1557468701033823, 0.1153207014525129, 0.26116115071119805, 0.1420596981000516, 0.08559757017440374, 0.13098833331417653, 0.10756989880915611, 0.10749979410320522, 0.13800435038583894, 0.21429150845975647, 0.17193718843402403, 0.09678932567757946, 0.09976694856079356, 0.1530733764652283, 0.10390554704973776, 0.11087376023492507, 0.18251724571229952, 0.1351748199592675, 0.11339206744225756, 0.16389876574037537, 0.10185381037092979, 0.12585234963485312, 0.15855433719773449, 0.18660856891543637, 0.14435512734757316, 0.13481167896140006, 0.15653738091068883, 0.12538826123120325, 0.1034718340322856, 0.06557528770739032, 0.17592174962403315, 0.08182066477715008, 0.14520107227708065, 0.27652611655573694], [0.06634156715365187, 0.01982461454557075, 0.07908808277739633, 0.06335678134834574, 0.018899168841721072, 0.025078075892862775, 0.031410589318482146, 0.021487151745766885, 0.035080456910955335, 0.021200023906966372, 0.005969804309819255, 0.03982512670899591, 0.01744136863928889, 0.014687069004491694, 0.07722675725216828, 0.02420139168539355, 0.027182437066409378, 0.05284458413840302, 0.02482783901805599, 0.024896128095626354, 0.034495096788891864, 0.12620267398174734, 0.028542970915535287, 0.020098098358439825, 0.059525238560332414, 0.04099122744293944, 0.02615317112706121, 0.04320549733576275, 0.024200102742460948, 0.016019787158696883, 0.023677393290845138, 0.01954844750974688, 0.04757353915802894, 0.036749253049492836, 0.05158256919633958, 0.05259190152789797, 0.03862242229403027, 0.003724276832672918, 0.037653179343549475, 0.0124257862109751, 0.06479980754515817, 0.07094328877546134, 0.015655444360398237, 0.03430778446096567, 0.03876336331989977, 0.08674456467551571, 0.018390656914561987, 0.028765789503532074, 0.01158417063584972, 0.024695005117645188, 0.0868697357814639, 0.04801552592506332, 0.0395979548263694, 0.024081550636178544, 0.06970644748258976, 0.04873511231233997, 0.1098294061939082, 0.03353302825182196, 0.040715945238668116, 0.022654614200995817, 0.039651596302827524, 0.02987534911822408, 0.014656162144796503, 0.048826778562919754, 0.04934286901486978, 0.04075336097288997, 0.04328081527003839, 0.03521599318651903, 0.11422770082830422, 0.03131742728123021, 0.06353704566736856, 0.04125434417097319, 0.04945158838264404, 0.010172016824775887, 0.025227566459967245, 0.02566344942146492, 0.02267609147595302, 0.031217713277005864, 0.03955189378992204, 0.0520810472869104, 0.011692077950424245, 0.03141850683717959, 0.023975813265649543, 0.018373707219237284, 0.04333487809485486, 0.036086464420922344, 0.10146138183171712, 0.01448609828648548, 0.03698691267580275, 0.038464401337888934, 0.05310279024284213, 0.021831912379111015, 0.02316918971407558, 0.01871316460892558, 0.041401532643865195, 0.02774898972993176, 0.016945221371227698, 0.08279977877053522, 0.01817607951741065, 0.031669846878597335, 0.029052936494530692, 0.04576160332127925, 0.028665855249029495, 0.03540649627064986, 0.033226573929911664, 0.036410799234985344, 0.018924388456188383, 0.010976634183598143, 0.04880330945935942, 0.0353448300231849, 0.05233810808990271, 0.024873327403779955, 0.0037365203541177778, 0.033303558105422605, 0.03599474837462749, 0.1783664740862385, 0.09211890895159976, 0.03628204283755153, 0.042190438496970364, 0.0397950386057698, 0.05013369391822527, 0.01935061870984012, 0.034907447444575454, 0.08487454405234707, 0.03583596133056187, 0.05600219171854758, 0.018052614872313796, 0.04995201616698215, 0.06719496611866259, 0.08077328468883231, 0.07081562022288, 0.054151648880853775, 0.04842991820506511, 0.03545069571344122, 0.044429598586453546, 0.08641249620385709, 0.01628010766580701, 0.06978542348670383, 0.02067101912783279, 0.02993366564624012, 0.02409320283350685, 0.043844226973071214, 0.0523131221322523, 0.07851042183897189, 0.00906716386276868, 0.04682745761989106, 0.02239295878567763, 0.041920281420912475, 0.033933745862375346, 0.02284336294378004, 0.05013450214098539, 0.05475495078210389, 0.10703055758870418, 0.056391843189034736, 0.021921988997247913, 0.04085225909347496, 0.03356403183011759, 0.028763188635029142, 0.03383579386037684, 0.014927560283291726, 0.05153911285883477, 0.07929735501567203, 0.03547943167148098, 0.009688081955837627, 0.02935698721557856, 0.03765075850570875, 0.004541225573648849, 0.08293307040848079, 0.0507325601703938, 0.060060469719070586, 0.06315957882531709, 0.053405762695136576, 0.03297394877600093, 0.046862314620445815, 0.02160898845402464, 0.09119087770100563, 0.02165733817814579, 0.062147668607893496, 0.03991012033375521, 0.027455892150981293, 0.06355787942846937, 0.08261095341895858, 0.018927155948814847, 0.013719523896373088, 0.05538807265580662, 0.037010760992885604, 0.011796878778465815, 0.013144766431181662, 0.07480254862457514, 0.036963746176972505, 0.04914458630786789, 0.023892945534880125, 0.042165035021401225, 0.027963059593833266, 0.03145495538539704, 0.027084073292151577, 0.01045572120816477, 0.06246443064282499, 0.04114926755127888, 0.027263680690779325, 0.06835000454297951, 0.05531217249470854, 0.06648926890545315, 0.048900541338709094, 0.015708836858280967, 0.0504662297035177, 0.030357360148862488, 0.027012601119255828, 0.013091913067675648, 0.01601246431575067, 0.05275721564107845, 0.033773740738510125, 0.03892601527754338, 0.058832729550739454, 0.0357038303158216, 0.041151845437144084, 0.04047948070952008, 0.03404886206431735, 0.04002614051944787, 0.06453052763977359, 0.027323830084154205, 0.06757113061124279, 0.028171330172147964, 0.03718843210428473, 0.02451998084002445, 0.03904531814999158, 0.05667041191050122, 0.036336580636881055, 0.04002635119362705, 0.03361812529845103, 0.059657890514861193, 0.042267767412047234, 0.06214210680956322, 0.022143894025394996, 0.06115973694249988, 0.02894463081423554, 0.027750947084578297, 0.03723527838085448, 0.05193823317606604, 0.028511856254490636, 0.10215786300719747, 0.031888595624496384, 0.032098903996689666, 0.02858537579736402, 0.04829041742449326, 0.08127647422013745, 0.1024951791811374, 0.021282027873601166, 0.022839879158944375, 0.052077726295758645, 0.04769127155023237, 0.0350544826998826, 0.012284860506864085, 0.007523899849113678, 0.019193792850860668, 0.05166634091085965, 0.053837575814536506, 0.014384316802475483, 0.021258148913001342, 0.0256480721216048, 0.0556935387242946, 0.012611892908030461, 0.08896659503901198, 0.05138325227063991, 0.01377446867991239, 0.07130050791367408, 0.006661965228211616, 0.033405957247821555, 0.016856094702116905, 0.04359593404637229, 0.0850997509194478, 0.11707947078731754, 0.015147152683517386, 0.037589888989685044, 0.040469766714640205, 0.04182687615074458, 0.028107909583336407, 0.02874420497626547, 0.021874583476493438, 0.05874828750928564, 0.0415492573783042, 0.07206038286488864, 0.09180504272902205, 0.01991740503017941, 0.04621242308208058, 0.0345458960791509, 0.057737082092752384, 0.010954408057694955, 0.02416415981227352, 0.039479483159319054, 0.03561863750820199, 0.0936708422077279, 0.006942029736350261, 0.025869580699251066, 0.035041892044847055, 0.06498625036329031, 0.038096862995336135, 0.013893516828125764, 0.023022261711077827, 0.01394426728027963, 0.014688060130743731, 0.02050798987188647, 0.024150709223542965, 0.09020740466733133, 0.003429834769415339, 0.02723883837461472, 0.014725074626415249, 0.08305611178999947, 0.03319151008561735, 0.02391802916874088, 0.027239043303134463, 0.0468464374482151, 0.007232030883671777, 0.03500257258213336, 0.04127912711532366, 0.03817772357574394, 0.04157348873934919, 0.01590508464423399, 0.026862660475495844, 0.04844528209838656, 0.028626440025325266, 0.029118310607549165, 0.07656108813300248, 0.04617863094374057, 0.012092080226378336, 0.027150263288809408, 0.012066883594548751, 0.02703025178503125, 0.04835339368230874, 0.030200978620879115, 0.03723024135275233, 0.042111880010775024, 0.04366104385905689, 0.03213489097693274, 0.014695830177515747, 0.027856295665485725, 0.03777016480002673, 0.029814650056763526, 0.026672373811203628, 0.05738043752048285, 0.07942641018739632, 0.07257652694299337, 0.007879713215985367, 0.0521838677776677, 0.02490939482325508, 0.026186448071272145, 0.0065715812172951, 0.09449968805476543, 0.07331639933850496, 0.0066070036864989716, 0.03545630347704695, 0.09233860764652492, 0.17324326109261284, 0.15264121094538322, 0.15162150195289045, 0.16736782636613617, 0.20889441903320052, 0.17969531487793694, 0.06062213474163606, 0.13360153583268966, 0.15117157851496052, 0.08391630595489856, 0.1296578071290447, 0.16941059981623005, 0.11130597172004562, 0.09087560953752649, 0.13515067286789417, 0.10836112973911148, 0.14709871803079883, 0.12095461163910166, 0.15706294787026223, 0.09492264519776068, 0.0886387400509369, 0.19078561735730018, 0.09249124300455855, 0.11860479780983542, 0.11824917213450517, 0.085851221886133, 0.1366598660787267, 0.1256513588070389, 0.1487904853157459, 0.09070971319752355, 0.1372444984172621, 0.1532576818980517, 0.1532982539145216, 0.1321525264891886, 0.21078821902553882, 0.10157161422314183, 0.09710509945908863, 0.14937399916591185, 0.13959813502527055, 0.20172811083255276, 0.148910669189307, 0.09670576846767819, 0.16168774406035102, 0.12689470418638762, 0.09048146496136343, 0.27001804642138943, 0.15316570538186258, 0.1362276086283307, 0.08897007307818822, 0.15948567028728225, 0.19551757392623734, 0.1644781427157502, 0.2061824064942137, 0.18779499396201105, 0.17227382278971134, 0.17479959935430558, 0.15345415280711266, 0.17054992577721997, 0.09977950474187251, 0.12630977307356175, 0.1496211850955602, 0.15572560350260428, 0.19556876392133776, 0.12123984915594901, 0.16358725906860444, 0.09448795158776546, 0.10880055011159952, 0.11957156246588116, 0.2640038578500671, 0.23139149491344732, 0.14890575090483313, 0.13842361498503916, 0.183782133484079, 0.07042095470692843, 0.1720796807879402, 0.09225847484964518, 0.11439019573792336, 0.08819523642981246, 0.09556526273128488, 0.15190611893851913, 0.1702149308496906, 0.1788773168359072, 0.0649266487227813, 0.07559505126048481, 0.1647997004610877, 0.10353143567279463, 0.1599239645105216, 0.09459855936227307, 0.08656461828298147, 0.23167709249161908, 0.09710567402503184, 0.13944425860479956, 0.13255836922795544, 0.12223821493887133, 0.13197028949376077, 0.26772266313914334, 0.08227920670422816, 0.1957407966256142, 0.10146155037106046, 0.14622384562127053, 0.15116810047578427, 0.13278297088559599, 0.08919943214183854, 0.16656827572132313, 0.14427871773800544, 0.13514311924096079, 0.13714956480168528, 0.09356511441329796, 0.1551143266260624, 0.135982429849044, 0.22314710182047662, 0.16101577769844763, 0.12083337822508429, 0.14138169496530487, 0.15118446411384692, 0.24516158827370216, 0.2841186913992128, 0.18564809384124895, 0.12774989579714116, 0.17026656517578712, 0.12804015118989254, 0.10658425008577686, 0.14311743569710564, 0.2625045012081823, 0.07747053409055357, 0.18677009089339167, 0.13765365065586183, 0.2361027671084289, 0.15448198233160282, 0.14134201161082716, 0.1784437723577984, 0.16044925567844223, 0.11960916972208409, 0.1854117863601254, 0.16991816370958285, 0.23304154105003805, 0.07256871284616571, 0.13251418127648293, 0.1338304275827062, 0.11353717215599553, 0.1250024746742941, 0.1516019667108213, 0.14230038760410202, 0.22263230605711862, 0.06164804138543625, 0.1382022308966806, 0.2179720859614111, 0.1184636767533037, 0.1406273281862659, 0.1808781393112675, 0.23454981495536145, 0.1636402417094477, 0.1938084317671676, 0.1307665815036143, 0.16747719307820644, 0.176907291095103, 0.1362861683892627, 0.07614580719100852, 0.12668384614610864, 0.24392850847253877, 0.10357848879310394, 0.1471419866767622, 0.12011472646507526, 0.15727031254960647, 0.15776171198775693, 0.11036955180668062, 0.14260256332495522, 0.23405610193167967, 0.14051984605048934, 0.1535910527191816, 0.1590325752453458, 0.17998252124074968, 0.22944878786802295, 0.12436623865317915, 0.06607637815778294, 0.1240011977572595], [0.042241708931302836, 0.028454359440553575, 0.03546228662373559, 0.025842928500365347, 0.06944802304309222, 0.032437717872521574, 0.05958282538960057, 0.09783441516300363, 0.050510578533454295, 0.015805586102238346, 0.017599774554612178, 0.057057389734132644, 0.02405310579155001, 0.007727522188947807, 0.025045904030482617, 0.06250063212768686, 0.03022669619249721, 0.06044500755266317, 0.03126225362892353, 0.07772742635420254, 0.011579166166484358, 0.04759428864945808, 0.06163625129228158, 0.024527065238104235, 0.06937569668216091, 0.05199539865697584, 0.03847871569075412, 0.020995011117549676, 0.03145613133036081, 0.03268377765292122, 0.025835300179859324, 0.06467423041261013, 0.017976291447637543, 0.04910447777459218, 0.044196887888134494, 0.013088329691409826, 0.021748824398063367, 0.06118577244060655, 0.05843079386038646, 0.045471068306435505, 0.03171341046841154, 0.10173334304483668, 0.01774798383966329, 0.056184773453541344, 0.07493732647309381, 0.00397152261294034, 0.057911543295748776, 0.04108194374449311, 0.02171718688201039, 0.020002885120770624, 0.06318813475269465, 0.006156100134830923, 0.04756736448935924, 0.026446933287285992, 0.08195603251337044, 0.07134052068595925, 0.04446614864132097, 0.028395002948180325, 0.020607776654463623, 0.018637143788979422, 0.04146635517357819, 0.041727104689925916, 0.01824947840143596, 0.021022783720024654, 0.06957667218821664, 0.04961522476327035, 0.0678226602594218, 0.023688262163270867, 0.04547817377193321, 0.029664699836904486, 0.09555125864402902, 0.029488110824698405, 0.04044864184012817, 0.038786790288624265, 0.08975368143329698, 0.015394274453302065, 0.0704462202866712, 0.02592438279891447, 0.014965726783679379, 0.07445843725074684, 0.02922875558837287, 0.08498313701561383, 0.05392693231002458, 0.06134008936163399, 0.044819280700457674, 0.09347085495509448, 0.0209656642043903, 0.028700264088148554, 0.02163004246540368, 0.03812906550123327, 0.07073430765059686, 0.04659185877009746, 0.022095144020333406, 0.0555555509673732, 0.03683716546924364, 0.031421488834424846, 0.0354648300356442, 0.005330845324938456, 0.008972239823290899, 0.03987345536569915, 0.03105262324454323, 0.07163470610976219, 0.04451677556179705, 0.01067473712722741, 0.06334284237856347, 0.0925422031732817, 0.048555981803445086, 0.018879509110364224, 0.04012125416568691, 0.04150702678147824, 0.04620863860773464, 0.008627611340113707, 0.03429308706413835, 0.029984116366493608, 0.08834589528100145, 0.014774769792453417, 0.016064804400347413, 0.04278077436010203, 0.033713204470733484, 0.009177221969190625, 0.020454302430152893, 0.03295034177661423, 0.027011396445994897, 0.028115723680164066, 0.06761266023761804, 0.06886905209431726, 0.02916543650621128, 0.05000244390459792, 0.08390135191861661, 0.05292742888653471, 0.02976194703801265, 0.027297673927199458, 0.024187305243685845, 0.03436211158611602, 0.0804208152957501, 0.027634507465747096, 0.025668603277975516, 0.025256154946081584, 0.03509543776031464, 0.08737313981738784, 0.05320568351195224, 0.05386995835109584, 0.03889920603063318, 0.015735487141946874, 0.042106835321793636, 0.0363417785434473, 0.024383779983186436, 0.05613401246767852, 0.0572443726442514, 0.04729433075314568, 0.030685188323860208, 0.014682794233874209, 0.0022666748554911464, 0.07531655531737112, 0.01190254911630144, 0.0529019947674486, 0.05008529631360885, 0.0052744296525845365, 0.07461006903359968, 0.057371535578802715, 0.08455376005581311, 0.02892636153246126, 0.06932240760614795, 0.05098452265825003, 0.1044167192172139, 0.023777524812988216, 0.08323539934691884, 0.043369417168921044, 0.029931217995322043, 0.10300823592490728, 0.06856731304358091, 0.025759141464086793, 0.01793555855270355, 0.05802568273558732, 0.05310373636142862, 0.01847459908364521, 0.01687391773767529, 0.039470320747744654, 0.04724031389360467, 0.05812001114170398, 0.0438147287575468, 0.06125057964856106, 0.06734633743162118, 0.03149493368372562, 0.07709877460353798, 0.03409660466375851, 0.021092846291139725, 0.014982149793556141, 0.02189794915818399, 0.02443902832906573, 0.01721255732850442, 0.06391136388805124, 0.05082755124256496, 0.11689842122817233, 0.041333075026951493, 0.03984549698690253, 0.016005225742476124, 0.028784824873230634, 0.011894316543945143, 0.05133927882378621, 0.05682233097632566, 0.04785737856441448, 0.040255522565735925, 0.04361945677608733, 0.049498522759325085, 0.023456329044194955, 0.04038407594986981, 0.01056786020091104, 0.02837805325285562, 0.07197537008793124, 0.06173244512249386, 0.04395257095776258, 0.061958138455426505, 0.05620708959477563, 0.05546645494177938, 0.051307938166803894, 0.013338564650996799, 0.046089573222542965, 0.014677421084695287, 0.03746636880321368, 0.11795460366674008, 0.009426193841312443, 0.025903535631274986, 0.0068719753049193855, 0.06212861217077702, 0.020638584880338564, 0.036771370007866816, 0.023787865084746194, 0.07194962953367541, 0.012951858788578501, 0.012396115625667717, 0.03358122667357807, 0.006058484732714152, 0.013930046773185174, 0.04511606316232393, 0.02547578277787374, 0.05812092278633387, 0.015269240285570343, 0.018181670044038086, 0.02898784008838477, 0.07275215259963468, 0.08603269279363655, 0.004288870465731429, 0.026292890242691484, 0.030771779241941632, 0.025098425103351477, 0.048414044863274025, 0.06311240696137951, 0.06584348742880168, 0.033345961072031534, 0.032037927228356564, 0.03034403021898001, 0.069029294705439, 0.00896507019792954, 0.08248058823688377, 0.04820460408565499, 0.04827816767858402, 0.01803904170951536, 0.01943930296317464, 0.05135453163435863, 0.051681206847030314, 0.0449503468529832, 0.043257104848781903, 0.0858133694817943, 0.020314648431996186, 0.05724746380902587, 0.03441908937548438, 0.027513724128385226, 0.05249108818750228, 0.01689956253094058, 0.03603321747974523, 0.053216305321022395, 0.06712621738833767, 0.03862681963871564, 0.03924440907975359, 0.024084936744803866, 0.02876231337957565, 0.007581833333167578, 0.03700028857096069, 0.04758075187583605, 0.02886123831323799, 0.03962327020182725, 0.008388539239193403, 0.03339838446869004, 0.004750514091292938, 0.012308153410201833, 0.053719211399795554, 0.05766571334172642, 0.04158610237702247, 0.011985395779652942, 0.05328968888328922, 0.011083458441369718, 0.04874913938223355, 0.06813565314176583, 0.04217572194794494, 0.0640986149289435, 0.0943698361515999, 0.023164800030269453, 0.03588601368509474, 0.01071162904883104, 0.05020815000358609, 0.05713993187753424, 0.01893238066845844, 0.06522942199221542, 0.02171338325546634, 0.014651271631009878, 0.0915398154287569, 0.04088100271239396, 0.054515693862471855, 0.006687162338846153, 0.018938917313672362, 0.012582125604122639, 0.05515224014919612, 0.012488677241509, 0.056125746378975536, 0.014888736862509001, 0.018936301123410947, 0.020287611273928516, 0.07458478813209841, 0.07764721694853037, 0.020139446038933053, 0.06066207856600804, 0.06528055836116115, 0.0563019925668355, 0.02140497923978875, 0.004551524189375942, 0.009585426173984044, 0.028048771426021576, 0.021233321918595224, 0.022691863311094143, 0.02324693040141175, 0.04196278014851194, 0.07607046244365555, 0.02824910916388035, 0.03487080545915711, 0.1382186405000187, 0.10665101464837791, 0.029445012633298195, 0.014522338075743569, 0.03920870172160287, 0.05032444981137111, 0.0160393875182396, 0.041510094963614984, 0.06692846711244314, 0.0739181997074235, 0.037956144134964676, 0.04264861653228441, 0.052068276601212646, 0.04171362154245858, 0.05151029646156296, 0.0602977003361429, 0.013752488659754878, 0.09191525979868828, 0.16817571204756537, 0.10454971974174823, 0.06796082421656578, 0.15069453556451107, 0.13762331357406032, 0.22711234227303537, 0.24811651197171983, 0.17184004848522527, 0.1381712349792642, 0.14042909527497907, 0.18504948805897467, 0.16677130434301593, 0.08558693687401472, 0.04047727437629815, 0.17157597797772578, 0.1493398776097644, 0.20509356572743387, 0.13157284307864406, 0.173636494024146, 0.07700887418562367, 0.12119305650553397, 0.09304517819996803, 0.12774968129252234, 0.15247792696520207, 0.1358895646708627, 0.09851285496786719, 0.13282199540445883, 0.12550745685134204, 0.09613540834717213, 0.14444161867422445, 0.12618973475670622, 0.10754089472034287, 0.1371043809359112, 0.07572461205023913, 0.15227594022308627, 0.18938378370817632, 0.1958169917305631, 0.10781471752711844, 0.1983717877057291, 0.09226647280757466, 0.1660029487984796, 0.05835203619133081, 0.1694068153418841, 0.27430348098278046, 0.0910430763577742, 0.22955748042271984, 0.09148040531022895, 0.1341449373191403, 0.05662479137461032, 0.08961698836496762, 0.12721602444446858, 0.15102186961279762, 0.09969980095423038, 0.09647958866891362, 0.1313397531668025, 0.16631975679868655, 0.1576349550798055, 0.22196265328074657, 0.16961991035890195, 0.21129003725945952, 0.11200133440715652, 0.13518571372955077, 0.09341050254841966, 0.2495310167151113, 0.15944200327559827, 0.12271381764402314, 0.1319327971507465, 0.23903305341880168, 0.09850811288361588, 0.22009463980793956, 0.19828699709426975, 0.1020733405265116, 0.20185889736298593, 0.13084527405519641, 0.14591782413903745, 0.22709574880859545, 0.2644340008977921, 0.25226909156528216, 0.12244780127319599, 0.217909358682171, 0.15960907173012534, 0.1044715404690754, 0.1640113959870031, 0.10536476068439023, 0.1388352033832381, 0.1905227113034456, 0.1251500768346652, 0.16762446582077012, 0.13407546846616653, 0.2544684074218235, 0.15968655386278707, 0.10731543504422712, 0.18262451334345728, 0.137786045970936, 0.17320912421470688, 0.11269252957595934, 0.08239599680828472, 0.08332941365698654, 0.15769360677128838, 0.08140402019865091, 0.17070826082941026, 0.08393222526196512, 0.13598486600864318, 0.17398964523548083, 0.1935228801542713, 0.10573509524786666, 0.13348455420665203, 0.11511011920388668, 0.15095105244507714, 0.17317602921637798, 0.2787109073852339, 0.11102341551093325, 0.14945396342344824, 0.1209156713899105, 0.06932153426591428, 0.1758951816948191, 0.19694062821086378, 0.1594760175794363, 0.11173049168240641, 0.21535871490355463, 0.17269851129141547, 0.10232613421976568, 0.14203856939509993, 0.261876676832476, 0.21030219752461682, 0.10227220929077557, 0.208367963411635, 0.16175140596685872, 0.13705513680413847, 0.15608897432684898, 0.07739223224381286, 0.14185847744586008, 0.17644641259985586, 0.1899185896881165, 0.10037190521196013, 0.1697063097550023, 0.2052642041516881, 0.2169119428482748, 0.18007043749094012, 0.12307348826359357, 0.13095969694756693, 0.13352380855189216, 0.12926092761899197, 0.19675336567865265, 0.08063545781037501, 0.20604020525370875, 0.1331392017703864, 0.11040644660111397, 0.10705196974618782, 0.18819486121496848, 0.083990907596965, 0.10431748018750261, 0.12387581980757176, 0.09493047461634684, 0.11699179968526287, 0.1450110671501006, 0.11529951912140655, 0.15728417874103592, 0.23129023341161592, 0.2709742160814424, 0.15705567003498155, 0.14354080652758, 0.11960977493154427, 0.27076810778629395, 0.09134453195597857, 0.1847700038624387, 0.22758242914513235, 0.1927582018317715, 0.13767939121011766, 0.1673680255489965, 0.16298099240708738, 0.16951017592462803, 0.091877231194127, 0.25659234022661565, 0.07849656330842165], [0.03861985589948393, 0.03145842193325441, 0.034420893512546055, 0.03624212199581727, 0.09915132030484178, 0.03910468230324407, 0.03752608535691135, 0.048681214196427215, 0.01348271462765913, 0.04115814267988167, 0.019461709119740035, 0.03766674293024886, 0.04389140649788803, 0.05169419203734687, 0.027728853108842048, 0.061762318721101175, 0.037260988291593335, 0.007620684045832605, 0.03618455048830759, 0.023474558106353207, 0.046905908853777, 0.03781464386491045, 0.009538875798875046, 0.03357032141197593, 0.05108368507916889, 0.06473023910075426, 0.038094760083983985, 0.017429411922010685, 0.047196141263890656, 0.029875013954757206, 0.01892315313941048, 0.06081773997134259, 0.030523595482771917, 0.020167504009159825, 0.05581660308845102, 0.03802881906590155, 0.02948280183538314, 0.006309566698262409, 0.045821446279484424, 0.014279616523473976, 0.017320286527636553, 0.06439217982152778, 0.0423135066915664, 0.0360830744818574, 0.012571825551980687, 0.05026446512689994, 0.033189866827019764, 0.02136365645715306, 0.047236207662330526, 0.010185946218459117, 0.02408959838982311, 0.040898163081897844, 0.03604969986143612, 0.012094174519241338, 0.0532752251432788, 0.04156186335509823, 0.057227373153211615, 0.09336342644547263, 0.03790736731682574, 0.04327397027443494, 0.02559172443955416, 0.0180290806512799, 0.05212815786381403, 0.04838224838397676, 0.053801680764844345, 0.025927724857484142, 0.05793219319574776, 0.0790048549853025, 0.01926121624907659, 0.09157471839458713, 0.021955694950696443, 0.05257169595889507, 0.062243153806775815, 0.04821215771258839, 0.04249376334970997, 0.04547536605969072, 0.07737791406050806, 0.05605456531949102, 0.019833234949938713, 0.05606799101036403, 0.05036106881415171, 0.029363422354142514, 0.04217495586002066, 0.07482438213041714, 0.03202427937198551, 0.01386438825002481, 0.02988725795500702, 0.02059047264347394, 0.017324226134787166, 0.054931982210086244, 0.018499933611301166, 0.014545075565336213, 0.030499197497603395, 0.03413038914121928, 0.03162260798196639, 0.04190299464690109, 0.016801359635146878, 0.008938640164541862, 0.015847965128599636, 0.0429919924617054, 0.0740248851117588, 0.020009440918182655, 0.020488784047624758, 0.016394557371254892, 0.07799409389976533, 0.04892981355829586, 0.028883542963153416, 0.043456031069640196, 0.039286088093274066, 0.05228859965779609, 0.049436925459773316, 0.021335996852646914, 0.06666684042542212, 0.02301412777254178, 0.010103112004036385, 0.053992716280082544, 0.05271021231648423, 0.004004622878123736, 0.022390972702733936, 0.06497841328382492, 0.001270020321469694, 0.03301750087449628, 0.01377406265331252, 0.050059931142435926, 0.029555773625390667, 0.03701233147313038, 0.03197334984677934, 0.09565313301619985, 0.03438689453046649, 0.08031703336464782, 0.018928205489271113, 0.08369553473687942, 0.04040220542059791, 0.04737817907645818, 0.02899688184111109, 0.017761823218015414, 0.026356837516950987, 0.006292473840256853, 0.04406841877367228, 0.02588122523570013, 0.0627303512526616, 0.03881548411182819, 0.03977447297544249, 0.04641988735285498, 0.042885850979796344, 0.04745687162804027, 0.04564290182785161, 0.02618130570608041, 0.003053341098430176, 0.027794617926701907, 0.07267266331661133, 0.007635748686058628, 0.06815232321499817, 0.04729711931319006, 0.08998024427602369, 0.02188849563319837, 0.02217301877305633, 0.011848323497801058, 0.050440929649818333, 0.09441279836239354, 0.039434486985086434, 0.04837849455314779, 0.0378225269096513, 0.026699296056082653, 0.024619792520459143, 0.055819203956953944, 0.033906473132270964, 0.04612372925264701, 0.03225695942678759, 0.04640103009859881, 0.05023480603291143, 0.015352528407088211, 0.057090392801910646, 0.027567635650836655, 0.0072880783550170886, 0.053098726146403825, 0.04338032243052318, 0.02555316148866569, 0.04557060611043726, 0.011230510933655164, 0.027084621045017437, 0.019483623064814076, 0.023476109434399876, 0.004025384579079166, 0.030435288527740106, 0.06634139861430853, 0.06717821177575858, 0.05048156295332217, 0.05731217142555022, 0.08448662011012917, 0.03502471635358469, 0.09417272938956177, 0.010760262225484176, 0.06641694254452182, 0.03569217811849329, 0.02792767016217113, 0.09070356917237082, 0.06161238382300062, 0.05754360275703573, 0.0632066855717811, 0.02745588065966243, 0.024779862761797927, 0.050565817303234534, 0.04533098912948082, 0.07104881738703098, 0.08949583155974265, 0.03952477044696289, 0.050657805310742515, 0.006504689771381598, 0.028055953500311703, 0.03432992823241699, 0.025922051976404847, 0.040476481475296526, 0.036040579584697564, 0.0659836278927903, 0.024199254300084808, 0.02714988216006708, 0.0774051791297332, 0.019275712547823787, 0.045441853543443066, 0.02730663715591354, 0.01375996280506614, 0.06975445821280442, 0.08340774614724421, 0.006359384438368462, 0.035619897722837426, 0.06880468538691921, 0.10245203310924192, 0.035246322607441295, 0.020665706308077902, 0.00495010297820573, 0.05233150441199542, 0.053749667225225325, 0.025858133430442503, 0.019622235183393764, 0.03612832729554465, 0.11277352805219351, 0.022380465806852427, 0.05680815068884723, 0.0491158273671904, 0.023262296209953005, 0.014463364627332458, 0.07236760710516284, 0.013049157700621554, 0.024825826122034943, 0.06395356384136024, 0.0797874291217135, 0.07065349303546452, 0.042449092762845184, 0.09585714989131498, 0.01361301756509009, 0.05243416785472824, 0.03653772085184052, 0.02912629324372017, 0.053793437658779086, 0.06602510389301085, 0.018282897071912885, 0.03320372152713037, 0.12208162656714841, 0.04805372306896795, 0.07154698904243208, 0.01787574049235592, 0.09020224123472169, 0.028502916008414283, 0.061801561575022444, 0.010905329592435831, 0.02767259161168289, 0.011615729627890453, 0.07725779147398087, 0.058163613035914406, 0.09538473411192817, 0.014625005348916016, 0.030856577514280236, 0.04099427647287807, 0.04399774333221778, 0.0964651785550579, 0.06659933275753452, 0.09677939717808078, 0.03504581441501937, 0.014131479059165765, 0.029048788128420714, 0.040273027674805735, 0.039843428549506975, 0.034880603723708666, 0.032613052415751645, 0.06859737433372967, 0.04676266190325541, 0.04569084744059271, 0.1010631463460384, 0.04309358721178386, 0.0184571112115537, 0.031482726072652206, 0.03514044925630574, 0.02903241491425903, 0.027298480234739762, 0.021746282901374564, 0.007298233329258379, 0.024241818145157832, 0.04072888063326959, 0.0704711870921235, 0.041438017581259055, 0.024035001218679453, 0.047219123901619066, 0.0693082043360318, 0.019297222381517775, 0.024737852415250196, 0.02595009079443351, 0.016509863179958156, 0.010591462412248216, 0.05040185533524041, 0.04807045059879461, 0.024769262020145694, 0.017782620589939818, 0.028471347440274495, 0.07077853390646559, 0.019660152705206026, 0.04233361266913914, 0.12025824537680996, 0.03242896531798667, 0.04476040684347672, 0.049124897848213875, 0.07480513034087997, 0.03751386625451907, 0.035621793790450024, 0.01749662081560781, 0.008507415975233721, 0.027160354581991994, 0.02076588379549644, 0.02881265684751974, 0.03815634972265652, 0.12253805409155547, 0.040658293291926384, 0.03528069697260376, 0.03824630759716515, 0.0369513240612803, 0.02802365714864385, 0.05237396483519866, 0.046092154938847794, 0.0443620449532905, 0.035957865071513, 0.05576685716908786, 0.0525942151134293, 0.03505047222959899, 0.04464825540180168, 0.10384505674723657, 0.022384673544776537, 0.06332252955725116, 0.010972816192905509, 0.041556730566005555, 0.04147482810602073, 0.08101864732922086, 0.06233459023097831, 0.1804526540781221, 0.15453957682175024, 0.21033046616902276, 0.12253210924926305, 0.1580563494034352, 0.17893722491158595, 0.14200311484596423, 0.10707392582609769, 0.08085989858955145, 0.12727187991502786, 0.17034737213004023, 0.1372436710423039, 0.18002217395171044, 0.1156926064962341, 0.13960662327947157, 0.266178076666209, 0.08142428322424812, 0.1541224419469795, 0.12505023259549372, 0.10398962519942753, 0.19588247692633062, 0.22020932317020434, 0.12835942599321568, 0.13637417657000406, 0.20950021072020455, 0.10853767470126191, 0.09921112878909034, 0.15588206930025933, 0.17022329652982374, 0.14789304395596828, 0.1351714032071252, 0.22421567190077998, 0.11465263447814411, 0.17758448217664996, 0.18991220051482802, 0.13706929410897917, 0.15519703347836772, 0.07896883353110283, 0.18018113719599863, 0.10518318252457727, 0.11427101543954304, 0.14579987724221524, 0.10491915798235325, 0.24382453501945545, 0.11119455955321751, 0.0670145447516153, 0.1202386565085861, 0.1280419898009108, 0.09718975983560087, 0.09484095724239465, 0.2136392305575071, 0.1355818424734377, 0.1487551226971611, 0.10501747004567616, 0.2434440497909823, 0.13131836399195657, 0.18474774134735908, 0.17702375178135213, 0.08605679391973442, 0.11908972380502571, 0.1697310237514396, 0.09274602852641575, 0.1363231091489715, 0.2339666994709161, 0.1330046154438488, 0.0910869961784732, 0.19572682318187531, 0.13520071373110817, 0.07366915218411915, 0.24385295688144623, 0.2152860131595404, 0.16601591100615842, 0.2410812507713995, 0.1719695939532211, 0.1393193096643494, 0.11650737164722336, 0.16747604394632, 0.14233907504427817, 0.2890318277622423, 0.18859459057209954, 0.15981298901381033, 0.12426768144172047, 0.13499511105398979, 0.15531593032421606, 0.17343685151107852, 0.1218522904861358, 0.15101693600656527, 0.09145418978146008, 0.12075731335508248, 0.11114773625928549, 0.12007411614420915, 0.1246142672795442, 0.16718759652106993, 0.21099995040605146, 0.14642036249560697, 0.15488108349663599, 0.15833600213931454, 0.10918325699505307, 0.16398574736329818, 0.2238898853501005, 0.1223315627524449, 0.14222814551284238, 0.17250895049543152, 0.07663735984674386, 0.1507391372034627, 0.16365164109776098, 0.11909831931153614, 0.09152005802118972, 0.07454356494089288, 0.21984776031346093, 0.24163006083859553, 0.28177866051273964, 0.20701358124854105, 0.12085370253771545, 0.053950876388097965, 0.08960431727070002, 0.11620436855141195, 0.09540128161109264, 0.1541688668751909, 0.111616988095545, 0.11232793301103577, 0.13346100466385966, 0.10929938826349475, 0.17129074812175768, 0.08457285862776541, 0.08265386200359753, 0.09017329843294236, 0.18523147990626676, 0.11504411306833068, 0.10594418362504053, 0.1478191471147922, 0.10867246787153906, 0.1327147124515426, 0.15635439314909522, 0.14919297258940437, 0.13638110200483955, 0.1189986053073118, 0.20655173748250932, 0.12523043945792223, 0.07178112083385069, 0.22335167793977648, 0.1784822146498388, 0.1302488439626271, 0.2426712815800021, 0.10953605580594271, 0.13214098920504894, 0.09232657240523447, 0.07647723214881075, 0.13430641333182014, 0.10290927268684873, 0.1456142234946451, 0.0997179342553981, 0.1491036927027087, 0.08462480704991088, 0.26946229559759943, 0.12109792370709682, 0.08563626527545914, 0.14442093430026887, 0.18158741415508334, 0.17305219876429728, 0.14802968339814296, 0.17849867021845234, 0.31809187163749053, 0.18750935041856384, 0.14511500995966697, 0.20885062944744864, 0.1097957059861191, 0.10232576649756202, 0.15007303907505928, 0.10794583347535903, 0.18403740930220774, 0.1250892417925981, 0.20201032230209923, 0.16503741754399193, 0.20796212067286815, 0.12720621085815853], [0.04279303176689052, 0.10420386168745258, 0.003512501162702158, 0.005744170348700737, 0.06078397081564031, 0.03055503381596458, 0.019193425128657012, 0.02182867182719131, 0.047688751120961485, 0.01375083390983843, 0.0048774697032997446, 0.026269867385347045, 0.03625070601100883, 0.016340571155230847, 0.07242756880699627, 0.02379306873697187, 0.013346035923478345, 0.006509828784938661, 0.02751679422574178, 0.05176487897012023, 0.031182235745232434, 0.04849108266493967, 0.01805928941335409, 0.07048686125105427, 0.016694118817066474, 0.040533578008293145, 0.03383940213450021, 0.06010050930443311, 0.04943000768581706, 0.018383706581868955, 0.0314300173082419, 0.025002970547986128, 0.0373005184284862, 0.025154012443137266, 0.0728970887740293, 0.03804369266295145, 0.042763104542128505, 0.05458778656658627, 0.01325064265514694, 0.01792181685056177, 0.07630778882171839, 0.02184675533264395, 0.07542484950634741, 0.006299986289964328, 0.03270039793043848, 0.011239089203187296, 0.03478024620562792, 0.0387754138829487, 0.011430171641310858, 0.030900518402397156, 0.026497958573482694, 0.06434027736465778, 0.009716295058869067, 0.028977591747177706, 0.02405400594486104, 0.04217975540086628, 0.026539673976179574, 0.060789417700781945, 0.06721924344498305, 0.01972863521997727, 0.04770264795590793, 0.07421179524352474, 0.015616741598463588, 0.02159920359601177, 0.09723476750115234, 0.015241875624915045, 0.030670347285547087, 0.058307396247982986, 0.10173789360710692, 0.014138059754435335, 0.052567957449824586, 0.02404196112747154, 0.056959790132579305, 0.060877460355479876, 0.036549694806097016, 0.058621457822981386, 0.023165707844459725, 0.019443872677642974, 0.021736480806383397, 0.020382031610596086, 0.033276258562240875, 0.02830266828588661, 0.11415666915596494, 0.047931179644600044, 0.04833280889978332, 0.033777123016695824, 0.036778295442702315, 0.0176522534926452, 0.03212372716065617, 0.03452515807904063, 0.07312090136110783, 0.1649383317318655, 0.02194429556238315, 0.1502619870007038, 0.04259366504547577, 0.02728440528435092, 0.09054927140354149, 0.032677438275347796, 0.046478316878839854, 0.0532041360143452, 0.003829140384163287, 0.005357302171403482, 0.05297368910584239, 0.037624244202649405, 0.046962438481709654, 0.03363064317513378, 0.02632885040985721, 0.02455502361690085, 0.04643979797800703, 0.06024043526380293, 0.07790977826281902, 0.01745507586747408, 0.0585361079673373, 0.029929609210681052, 0.0551295064900431, 0.04224663487665596, 0.016340040639343283, 0.049402436181422205, 0.0603910711323542, 0.030329219824183854, 0.07400659093212697, 0.02745011776325203, 0.030774684630394466, 0.0327139308736209, 0.021247619034482107, 0.03550766201149072, 0.013539836058513293, 0.020857237865247076, 0.0269322729699554, 0.04786657544994547, 0.03173565957695246, 0.06583385004271423, 0.058038250407985145, 0.014816509135397933, 0.0732818640948784, 0.03486810882966365, 0.07997115998859368, 0.02175406060902582, 0.01996717776261991, 0.07571914218245976, 0.022779984489804315, 0.04236331772840312, 0.012944762899179854, 0.04065555069715746, 0.019961550846816074, 0.009704602641924735, 0.04781943805996449, 0.07659451254913885, 0.015999660113706224, 0.03561995900987137, 0.06664580365102138, 0.035167764121245955, 0.030923989421177297, 0.04890343715106288, 0.0710485186127405, 0.037438590455079274, 0.024458326083878358, 0.025085470556551893, 0.031229526352798267, 0.056443933337446184, 0.03266642193099664, 0.06501381420680592, 0.04585312401515342, 0.054222374118023345, 0.02022144617512822, 0.022110892872836803, 0.006974203992755183, 0.004272306687198579, 0.02277256109781804, 0.04681741803764336, 0.01326505181139275, 0.014726543600010055, 0.08941517016219516, 0.054626397397970004, 0.018452914964948452, 0.050250005217329155, 0.10379654805987112, 0.07067277546851866, 0.025473612833828218, 0.015195212251837216, 0.056675004607607285, 0.017264505750649882, 0.03741158202530877, 0.013597871049217159, 0.013209419463941408, 0.03673097802205913, 0.03632837200477239, 0.0557508459314704, 0.04315034283565418, 0.007755078371584176, 0.01415317849962101, 0.0402812363069144, 0.0434506263193344, 0.05198738537728787, 0.04142926502672415, 0.038336510619809555, 0.04038035276255781, 0.01037766067912021, 0.051142405718564994, 0.04419519100338221, 0.06387691291409635, 0.028824355010123506, 0.042780743716585065, 0.06302067559332618, 0.034641090164621996, 0.046493952733374415, 0.07587271982864027, 0.04141323463690858, 0.02133748880887945, 0.01373244588443589, 0.027941745112559972, 0.03565000497826165, 0.01716672228799472, 0.04433302554271875, 0.04051966585158821, 0.03288046306660099, 0.04263920897257425, 0.06852947596100069, 0.066651533988695, 0.031158473613041065, 0.04187734219275656, 0.03863554921061282, 0.04725875746038172, 0.010092427950322388, 0.030119133617488608, 0.046661231862080675, 0.030592801950631604, 0.024378229676175023, 0.08305859391487415, 0.07475103687254653, 0.03511392346192752, 0.037958453890056386, 0.021643847369799213, 0.07769133595208969, 0.028752279542987386, 0.02370903463733773, 0.10542130563408138, 0.04343749940275185, 0.05072666129337684, 0.09273615365307178, 0.07302690237279862, 0.07053732346262663, 0.004130391772055338, 0.02764898844273581, 0.031450521651535265, 0.017352450729137468, 0.017820739209832206, 0.026892807950536092, 0.03526285095440765, 0.02783991096000518, 0.0550149993280009, 0.06400907840279323, 0.07357241060104101, 0.04528266813365683, 0.04450163000353402, 0.027287820121273402, 0.062603889288561, 0.03484483507852401, 0.06563172540477206, 0.03882897492017477, 0.043172206985013145, 0.038710066583007574, 0.032447715319933436, 0.06475206494571702, 0.011043348950484108, 0.0491845531148776, 0.014531669026661306, 0.029461759315322966, 0.054558173437873204, 0.021520216100578828, 0.07110683322553674, 0.03220953092339539, 0.01097866335898758, 0.05009758436391431, 0.012492869657674625, 0.027339239942751108, 0.076609788342349, 0.029823551998443665, 0.02961253691014023, 0.011441544216546801, 0.06545510383382921, 0.03156527204649343, 0.041326873545204444, 0.08956484842084109, 0.03988545230259338, 0.0328970029048862, 0.08054028670754164, 0.06524739441491904, 0.06006625751333852, 0.053714722124559265, 0.01708043780508301, 0.029079814689354073, 0.057722062938996864, 0.047425063657424146, 0.022316168047367566, 0.028807962643763715, 0.050429817544476646, 0.03855219118357186, 0.04511556903561277, 0.06483243522985328, 0.030681302342864297, 0.06012732621222254, 0.04942362234296818, 0.07339365930566866, 0.0407950131733331, 0.047998407690395276, 0.030931979718227542, 0.07820590954994963, 0.014956739614717664, 0.022811687123330853, 0.048053408972918994, 0.03237717777430531, 0.10860147450359599, 0.07792943607895605, 0.0187245505907002, 0.040283013630898735, 0.06934719055049843, 0.029551418415541132, 0.07118689707450329, 0.09396274468951649, 0.019533164055657484, 0.031497327708488995, 0.035408239120677594, 0.011839933877420283, 0.036510045925575885, 0.038591192719796975, 0.030483398849384922, 0.010901687801965784, 0.04281571179988884, 0.018761384098099607, 0.056801366980277726, 0.042465195931013555, 0.04175915780867781, 0.015135264914152364, 0.0177858745483982, 0.024940214540448882, 0.028256432964436473, 0.024816998873927423, 0.06967103889872951, 0.009820145937884528, 0.07633906053078753, 0.014979954951653078, 0.04842927852164834, 0.058391531854267084, 0.022550931861323696, 0.05463591987086881, 0.020746976745525197, 0.02755320638478283, 0.022566826270532706, 0.030753259066372152, 0.031606261580882054, 0.028435019550905116, 0.15584351975590954, 0.14687607755824444, 0.09134249416209998, 0.11876205267805247, 0.1284942498070098, 0.11555115602189496, 0.14149455503830988, 0.09942338877027074, 0.16468792823293518, 0.1799517245061936, 0.09416165175817667, 0.13705406428104447, 0.10001869271359137, 0.10936302718736472, 0.1723510904177543, 0.20798404610926108, 0.18860750681450292, 0.20909582354849388, 0.12241421597859553, 0.13451783827716304, 0.18979262951160633, 0.18026404323116427, 0.1593543321735436, 0.1810151771191628, 0.14293654701642453, 0.07686785272052211, 0.13059617290573736, 0.1016804599954236, 0.07104998950155512, 0.12190697384217095, 0.13417997818079688, 0.16996296453139476, 0.12437312578361844, 0.1781280828459609, 0.10139536037440262, 0.19333675143218812, 0.08393220994020663, 0.113378829442926, 0.13531104571396305, 0.11106064738405329, 0.10304719915673619, 0.10903451336367477, 0.16128438344645887, 0.12191178487433542, 0.08871559399150072, 0.12173890947334229, 0.15882743222098197, 0.08524433469339725, 0.11167649014462387, 0.11932896540289926, 0.22727824627391754, 0.15519498036273066, 0.18831081628318758, 0.21090483292937282, 0.16222987384084733, 0.14641359027835632, 0.07833760006413346, 0.17784781723974213, 0.11678923071632463, 0.11338116601109506, 0.16232565015314088, 0.1245639429637982, 0.15481711515495855, 0.34250782922871653, 0.33192126020308466, 0.13156600957435946, 0.08896171505893431, 0.1631394040680701, 0.16444019071998137, 0.1778974597372355, 0.13972611767390083, 0.18213245506969192, 0.18755332386541754, 0.2164108907022784, 0.11359554805582571, 0.19475162389778322, 0.16721623288767953, 0.1638951191618558, 0.15194710464246813, 0.12329839635640384, 0.15315805982437827, 0.25447859639121645, 0.16593410813760373, 0.21872868971718898, 0.14705489780153, 0.1748006718773996, 0.11484602571374948, 0.19572049529562074, 0.13983749153633274, 0.12091259171645488, 0.18759153633108064, 0.20293883618808564, 0.16323113543612344, 0.26242099762443577, 0.155006691272701, 0.119531802502611, 0.15183930074976337, 0.13049111160780155, 0.17827773046108986, 0.11454012680558429, 0.17140406784751724, 0.1463581255126384, 0.17938920146515294, 0.11744125580955898, 0.14273431512617296, 0.1193233346566558, 0.15516671171832472, 0.15685458727661641, 0.17731748521327975, 0.1844612397854367, 0.2226262539625168, 0.12071460395330384, 0.1479676455980347, 0.16304148270958857, 0.2288404374473518, 0.13826252201632147, 0.11237256529350435, 0.11827866651958997, 0.14223638861890764, 0.08706144928451508, 0.19166291060466922, 0.12254129464347517, 0.07773827415921035, 0.08713376798456715, 0.09609911110131972, 0.16932669786676285, 0.0721261668349466, 0.1282069285310084, 0.1216834293858659, 0.16926015546965986, 0.0876909360710171, 0.16997725973206182, 0.2026443826335092, 0.135112552332782, 0.16062226897526174, 0.1295904067134665, 0.2645696597474237, 0.13130710249946964, 0.09270413117783685, 0.13275594330362736, 0.2059336117799244, 0.13675260868284012, 0.08734409742417835, 0.16025675310482904, 0.08577145681145691, 0.11890914922039356, 0.13119488594032105, 0.16418094656640486, 0.10591890272353927, 0.11774040548311127, 0.2335532724616989, 0.19155207300378432, 0.11323936313631074, 0.13893867121829143, 0.11878658281338793, 0.11424573453804178, 0.15671774865158145, 0.09777403211281185, 0.12287230591379827, 0.15422974022165423, 0.15799965889703843, 0.1864086812542331, 0.17917691850133483, 0.10919163033606545, 0.20663104290443085, 0.11914933310641397, 0.09995893019461825, 0.1581320542121126, 0.09753993862578947, 0.13995264987311057, 0.07228591148891757, 0.20765128815847061, 0.2637440008261512, 0.17927698490600433, 0.1361742889088008, 0.14736419814007898], [0.10022765085581811, 0.03835088625970868, 0.012303776175324476, 0.11091346657204051, 0.04678855567509609, 0.051570235180758664, 0.023080308193100557, 0.04169644968163583, 0.058183887552830486, 0.0623331576465599, 0.04101606401344461, 0.017887273946055965, 0.10331182890842039, 0.04686961160792459, 0.0892803923136765, 0.08061433676630259, 0.021341736766419584, 0.012069267085603168, 0.025732517993498235, 0.07122547726237005, 0.06982363595236694, 0.018319495007275574, 0.03340766945433232, 0.02885077929785175, 0.06710864333135468, 0.021592986792506232, 0.02351589238030776, 0.04741661753805895, 0.015260233964410522, 0.04499918112771646, 0.07254335533587203, 0.04367305611770961, 0.05180448954624515, 0.07784145088085244, 0.013514312881705983, 0.04515813288068579, 0.08865316548655111, 0.047017451255552234, 0.07137284193548464, 0.027906803842333537, 0.00933227050418575, 0.027492499662443038, 0.033476050462453597, 0.03715381259098649, 0.021863942515225183, 0.07262901162668582, 0.09048892665774592, 0.002832018297105547, 0.012007693726299031, 0.04203149057444065, 0.011605565556355063, 0.026591838818163644, 0.07267956576880909, 0.05032078408065343, 0.10669810607308343, 0.044218388145729426, 0.031277129141193245, 0.06048264928282269, 0.08524696237497753, 0.058411408005462545, 0.08056026628060688, 0.08131141549036389, 0.017577895083494725, 0.046278501995989395, 0.058078944998522924, 0.0764562490005647, 0.026177728075474024, 0.014328212353340803, 0.04797636734081372, 0.0815526182733236, 0.021091974866125855, 0.03320421948428116, 0.043479615086389166, 0.04935989148854729, 0.03459332075210349, 0.07704373884705767, 0.03516010324200315, 0.014543840248558312, 0.04020261653368512, 0.034692035011586644, 0.10753035335050476, 0.0474147636052822, 0.014140868424287727, 0.03571777694648312, 0.03740312058418509, 0.04877648872113036, 0.053489208822288824, 0.05936148726651746, 0.10392506697004843, 0.011428796513486775, 0.03197916445412463, 0.00895320253837253, 0.014947495806301314, 0.05475970818811367, 0.03350206297792254, 0.07731439004982672, 0.05427758990516586, 0.09444882747747245, 0.041071222343992804, 0.023579874128523855, 0.021422139609292633, 0.00831281336309809, 0.008762925450179366, 0.04490697095471044, 0.017990962031387517, 0.05581445804226303, 0.026432362294966177, 0.0380212233041323, 0.03125009964400482, 0.030934850632723783, 0.04487751870446148, 0.038731394470819545, 0.032085064618337544, 0.04591190594158346, 0.0276582753435979, 0.02335872178176238, 0.06055085026028176, 0.03165639628986678, 0.022284095776417566, 0.10805160723506443, 0.03894227166329661, 0.021205735092441884, 0.049730739330932985, 0.053712531113095825, 0.040054585364076405, 0.04869608013259788, 0.034637206098845894, 0.04487790174842362, 0.1141733775335935, 0.07737150956546107, 0.026064228319052248, 0.07012627898685395, 0.01872058800091186, 0.10308751070331182, 0.02110291077124496, 0.01352622650653845, 0.04997911652730358, 0.03680875126813208, 0.08340006994624292, 0.11499614830339148, 0.01247785816479835, 0.07613388686290673, 0.011214735268074419, 0.009189382657378672, 0.03022860758186829, 0.017600241868245988, 0.042878396944293094, 0.055747620701309175, 0.0237159370895355, 0.05109701500905137, 0.017273283203042323, 0.04364910054831736, 0.04472176919901564, 0.06433451638346718, 0.035943910779972235, 0.0634266792105571, 0.004961801140809493, 0.03972723216359173, 0.03644298258868437, 0.06053840899239145, 0.027412619674578313, 0.020526075292558923, 0.035205455647120555, 0.024078359879973917, 0.025672500750290293, 0.05237091580526002, 0.05455770995467902, 0.01389281106962552, 0.036135214425983934, 0.016913673870505828, 0.010105229279537116, 0.02819549450049958, 0.016439149434107448, 0.06807929205317652, 0.05571879281271851, 0.05313126956142726, 0.07438075593522481, 0.13698658725667384, 0.01757815363816917, 0.05017650674187368, 0.01311633978114133, 0.025732316895418113, 0.053402859221903555, 0.09340458068876498, 0.11080609168857337, 0.03448008529601559, 0.02031510425431113, 0.03095430926600051, 0.03923661796556365, 0.0015801814316223647, 0.017371288831195524, 0.08024225552235881, 0.023553294707990946, 0.03039265764997371, 0.005378529031370437, 0.037933299393062635, 0.01675564525348525, 0.014001594597263443, 0.06291415872833421, 0.09982638166195924, 0.0255244025479882, 0.007902598177503434, 0.03644710797215662, 0.034046958335825515, 0.07591839399068587, 0.026442158644297914, 0.06054227390596944, 0.05832833343095357, 0.06629748645448877, 0.016503983455139305, 0.02527740430988131, 0.05888434089419823, 0.026701454508809314, 0.014008857110785622, 0.06961140661470352, 0.03004885845697455, 0.048400056097776666, 0.023740946029823635, 0.07173529345422022, 0.06663504777656448, 0.04002359327709964, 0.06128474716998397, 0.03644999995407078, 0.01167146635482148, 0.03362737964057634, 0.016900525886505362, 0.008585002487375131, 0.01632820841135277, 0.04826735817797242, 0.07705406571227698, 0.027707281988114122, 0.03189175382196423, 0.03859602290415957, 0.033690309933116364, 0.06928293109540978, 0.018831659258613666, 0.05482104884821081, 0.03465324031910108, 0.0756538408477941, 0.035228691093863986, 0.04219351050954673, 0.030935101526518984, 0.054619460471815644, 0.030504994867970387, 0.009585136975792628, 0.06296378207362949, 0.03536063441706281, 0.025212549221431537, 0.06594734596869638, 0.07346814603454645, 0.05842621648503889, 0.024757655788092844, 0.0511536825328104, 0.010855382574992556, 0.023016824402035247, 0.043555407995177854, 0.0692260031017565, 0.09046545372374597, 0.028520181715007753, 0.06560171774077801, 0.04103061585356632, 0.010205641381382462, 0.13077592777629055, 0.11929767837207164, 0.026608591245847846, 0.04714288283139468, 0.0726280769994182, 0.059445634364120425, 0.07591938224410819, 0.027610389102670937, 0.009368924938532855, 0.07284686404971347, 0.029550569973164992, 0.12130854426011925, 0.0023130906864084425, 0.050355395933072415, 0.02549328788694355, 0.043592789255443125, 0.047609024350681615, 0.027085540350526575, 0.04551541330593248, 0.046230069917416385, 0.01705186655594697, 0.014250014886079777, 0.017181616952462543, 0.04533892963081599, 0.02779186958627355, 0.038237409485924634, 0.08563717692008904, 0.0458938186056912, 0.04112622362651652, 0.03591542763094749, 0.06870973644958389, 0.03716815758736865, 0.04112754129774628, 0.06599796905873284, 0.07612107787281275, 0.02420326860080804, 0.007710694588886033, 0.01858658581641653, 0.027351257947063255, 0.04217474518584148, 0.03036069837699254, 0.03246820434146831, 0.06782050755235457, 0.04813708875688815, 0.014496735417314116, 0.037278987527374303, 0.07729425725917663, 0.07067403185271448, 0.049865076678895184, 0.02160790443961178, 0.032284596048656015, 0.020697232741381855, 0.034869005152535056, 0.07582601910877614, 0.009563130142557765, 0.02439586118975234, 0.019821056067162467, 0.011353989942900596, 0.032459379008580605, 0.055758721315332, 0.012674962054006757, 0.0461715676130787, 0.03361813295933028, 0.032385179562674414, 0.019615702368619464, 0.042933225857033845, 0.01650594464022546, 0.1271747935923838, 0.027406646103988734, 0.014917865440609955, 0.05165738534302481, 0.02683337484937041, 0.022530103845882322, 0.045236392592590664, 0.026679718679177667, 0.03588729688236791, 0.006955760904783084, 0.03950303653255105, 0.031980868999756155, 0.043521454978373744, 0.03306674500626903, 0.07269011479952643, 0.034383251782386534, 0.053388150333757364, 0.0757443847795648, 0.0345184050139881, 0.05002265330404044, 0.07054556656869189, 0.10171211474845487, 0.018323147331454584, 0.28035088712649964, 0.17982113715862075, 0.08457740919003565, 0.23380899261082375, 0.16371033875451935, 0.09747749479908137, 0.13691868122306564, 0.18906349766879313, 0.23927982566097092, 0.13160178588042337, 0.09785489269321966, 0.08551222031875964, 0.15412173714608918, 0.11734820677027588, 0.1425818176639657, 0.2697744917485022, 0.15455165036743687, 0.1963387129287566, 0.11282297136682658, 0.33110476369338654, 0.11305054544561333, 0.10084263559791351, 0.24121268081568906, 0.16672195295893377, 0.1441108678737956, 0.08440382132727293, 0.16233055311585629, 0.14006039247878138, 0.09563536743723577, 0.14165410050942054, 0.09228229252321106, 0.17228594230067346, 0.1873671338563004, 0.15535421939867158, 0.10092567952890551, 0.13534311415447345, 0.17509129499235462, 0.11597299467652075, 0.19448779853841952, 0.17937216366971695, 0.19230542854676325, 0.08521559873535749, 0.15271896886969769, 0.11825687131814419, 0.0920237914749211, 0.3098077032594912, 0.10612945432864851, 0.053187052253633745, 0.07090625608520162, 0.1116414339612088, 0.08007422945792637, 0.15715535339568892, 0.2200107072149554, 0.1535216298314833, 0.13830386012071563, 0.10222142532227502, 0.1169341209254438, 0.1337827003050235, 0.1259663894832615, 0.11793805616757563, 0.17178277575200604, 0.14926834031939507, 0.1169888502467544, 0.06656616115041318, 0.15935876016174594, 0.1453081407253781, 0.14598468829306865, 0.06906583709942718, 0.09310837279284194, 0.24972742633713832, 0.09924769416571626, 0.13389199040830135, 0.11945271158530829, 0.13508201606812018, 0.1363903257034479, 0.22113697903771556, 0.14977680819649852, 0.14577231339869962, 0.22224714769230736, 0.14970125660540598, 0.1775085322198368, 0.21507031344358, 0.10635341247243267, 0.13768052502024558, 0.13020117797197836, 0.09695974193633565, 0.19220733864893838, 0.1955761643306863, 0.14418678718709177, 0.13062077964986527, 0.26883915967998967, 0.14770811033104697, 0.19035124550423316, 0.15616000599918828, 0.1130033620903569, 0.1204029517248273, 0.22562953313031506, 0.25314279952116553, 0.13615535121531258, 0.1506394538427553, 0.10381288105441679, 0.08986222843128829, 0.1128803896567514, 0.15811264154411134, 0.13034270505510992, 0.1682562891754412, 0.10436071818994899, 0.1352654328389514, 0.12798732176663416, 0.16135927620193652, 0.14804151179569383, 0.29938473997096865, 0.13769068334612156, 0.16077256010424706, 0.1305780472654489, 0.04807024375505505, 0.2877085181253572, 0.10187676236514123, 0.13935145471365223, 0.12902423709390626, 0.29762356512008176, 0.07690352943515585, 0.14322594439070072, 0.08909640097690207, 0.11488699609594, 0.11049505233043626, 0.12344873345066464, 0.12193478283382232, 0.23665131670573067, 0.13005772034727758, 0.08240084614484541, 0.11483481784741725, 0.13949072949828642, 0.2538319109308143, 0.10739925272402265, 0.13135354274943953, 0.18530551464326922, 0.09717530375646968, 0.19826983672476586, 0.18499699571440298, 0.09529965238705759, 0.13060611672699451, 0.131270544783723, 0.06866606177702066, 0.14364873299435263, 0.19831774786355036, 0.16294368392517491, 0.14128653152335074, 0.09206212651465209, 0.13420985560984383, 0.1406493455532097, 0.12255965011014093, 0.08159295280253695, 0.24655174674285998, 0.13681669959858542, 0.13394480450980126, 0.1946500712825406, 0.07946704349090015, 0.25229371363116854, 0.15733443410886874, 0.17232389429644232, 0.16038706466074915, 0.1378346006235769, 0.1410840851284804, 0.15759358633189433, 0.15071301360524472, 0.11988506096625522, 0.16875888881904466, 0.1467147241196325, 0.08687464640505853, 0.17955026379035366, 0.16243919970527773, 0.1373760357138611, 0.2538110426957569, 0.2062799448087331, 0.20916296349417782], [0.02614677046245385, 0.01110642288450993, 0.0203959226998831, 0.035816996823996305, 0.022552188245519515, 0.02623090223829833, 0.0337277218368986, 0.024832456613019593, 0.013687410448197157, 0.07901522781579726, 0.11349369666629261, 0.05565300501222092, 0.055544469505548484, 0.0391533327168755, 0.05222165889497246, 0.06546684030082918, 0.021764040819459388, 0.06728695795661019, 0.026765039806524595, 0.009805749230567488, 0.0077138992304342895, 0.04157907735075682, 0.035080089188751676, 0.031059994925594622, 0.021740029708692626, 0.044429747973598784, 0.054884818007027915, 0.027675518067553643, 0.013984447634298236, 0.03257271022565904, 0.04363968532772795, 0.06650312743600338, 0.017555624907535892, 0.0212596446996735, 0.07587381533437199, 0.00451701958926635, 0.029139127131671678, 0.032015339125909155, 0.12342866960792773, 0.008033048586859819, 0.054212866966883023, 0.004725999277715962, 0.08929607413348653, 0.01242675626980922, 0.018113976599828854, 0.006777037858902928, 0.019048289771402077, 0.03836482139905134, 0.054677460988562916, 0.027791036465655894, 0.0547876512451518, 0.004199086397420615, 0.10004628720062395, 0.01301503039881467, 0.04010878225427963, 0.024533737863924716, 0.056741581478666876, 0.055743399556846394, 0.025044672544144338, 0.016881580532137907, 0.01658900580819576, 0.053171799443061316, 0.07798337632970465, 0.02630628529004753, 0.020701766066673784, 0.0332321280673627, 0.03517325697166305, 0.07151685880437013, 0.024663371432031837, 0.013521822458583743, 0.06999533923883593, 0.007806774463519575, 0.03913477423690981, 0.04907578395138826, 0.04441074516263701, 0.03081099719800536, 0.03528122940371114, 0.027718438143511454, 0.02148197490661856, 0.06092750121869388, 0.06796323739352726, 0.03224058046696648, 0.06593888069713308, 0.023054431658238176, 0.027735889626426563, 0.06498897763630075, 0.04869744759954272, 0.03061346525716926, 0.05051270059700455, 0.025943483286086592, 0.04315642174333335, 0.055966944013151436, 0.06680930979670056, 0.04556517837749374, 0.007793843856967626, 0.0343245426343093, 0.049566490079967246, 0.06625682250746796, 0.021993233258986188, 0.04259235120468563, 0.017911432528748147, 0.03326721106385512, 0.05289516509360364, 0.05647101071512988, 0.021193529396588286, 0.030895157702147003, 0.0296338475609739, 0.01436045220602424, 0.009914448488533739, 0.050153585391179215, 0.043350127074987664, 0.05233272249179502, 0.04565679483235844, 0.0339165203753979, 0.021287976546333204, 0.04556864492535111, 0.024223537372064688, 0.03531681418779396, 0.03261954501090992, 0.058802649108392585, 0.033501147502853025, 0.056045012203075235, 0.03557548377542727, 0.025089299080953486, 0.05590440825589242, 0.03767265712902431, 0.09251896006565902, 0.04520443523482931, 0.05178033862443221, 0.047554478890472845, 0.015244332851932175, 0.03541494622045467, 0.030924694222067634, 0.06462845665913436, 0.02927628176797542, 0.06884619203065673, 0.014264015142896004, 0.008865637731017366, 0.017062670310899135, 0.02924498133060913, 0.08413015173808222, 0.03191229838487362, 0.0235681951181182, 0.01081111801472763, 0.05979639921157111, 0.10256712249810658, 0.05005343471683803, 0.023140555262685786, 0.02645391809393562, 0.07254958363069643, 0.011702409603693073, 0.05317179178218207, 0.011685355528888684, 0.009884897604464524, 0.02984861073444688, 0.053490905707041105, 0.05500746868370522, 0.035544480197131634, 0.03392819172492431, 0.07114916724423248, 0.027793309831571196, 0.08225010302398475, 0.011694814799533737, 0.047252548317755425, 0.02557006904915456, 0.04260119952021107, 0.06093747951390763, 0.016896348792098222, 0.011550205170116838, 0.008041599085704695, 0.031080169851080548, 0.06191819846149414, 0.02459810074088314, 0.049449401201620224, 0.061720348594169465, 0.06213126666543465, 0.06603656456835809, 0.05288485355014282, 0.02545657886883184, 0.03646568943476004, 0.019992751692752206, 0.029714702395722273, 0.007463439711324511, 0.03441172344009242, 0.023696761908790758, 0.054071320731553345, 0.09351717263099649, 0.04251660043073278, 0.05434709706253583, 0.03651307197287679, 0.0285343466807277, 0.04939993490434943, 0.012045398658712306, 0.09683166735715444, 0.0647380838410989, 0.021787607599230065, 0.03836336966243483, 0.06314117739337587, 0.04527513365892153, 0.07320415213583939, 0.07740856523835853, 0.0512651827997498, 0.006746214311269503, 0.03874664728139197, 0.01355449706616421, 0.03415575048195259, 0.04716280877830521, 0.009727614965560216, 0.011427910724324326, 0.027392088518207593, 0.07092710899850053, 0.004726384715702866, 0.026939661887985085, 0.03830601265954395, 0.04485028810919293, 0.046893670599186615, 0.024874727429461577, 0.057030534521946986, 0.11098591550703972, 0.04368226449455946, 0.03573498328126246, 0.014939766936755229, 0.016292650440347292, 0.03312736171327772, 0.0851027769667487, 0.0641257114588253, 0.022455686064917716, 0.06011966150254012, 0.031531476077713796, 0.04936117085538084, 0.07023639646509001, 0.03032500059494088, 0.1143505966531173, 0.041156495590844465, 0.061924235234337474, 0.05762943524807211, 0.009010226293016345, 0.05784393986687065, 0.03188187128774101, 0.024387526153136167, 0.048848711660191904, 0.02841785535096161, 0.048169674306747415, 0.04730820843589403, 0.015267897716483042, 0.032066182466223836, 0.04249349521893648, 0.07796721187450233, 0.043295447549392144, 0.027925203359054945, 0.03642926961483975, 0.028622674703177427, 0.051238086269868, 0.019315169906363856, 0.02414124229201867, 0.03605960154785745, 0.047200511795498674, 0.04079620827049498, 0.0470257671399703, 0.062111991893259756, 0.010906022902007305, 0.006935169897793282, 0.016772424494246804, 0.023780660027818337, 0.07862882838854868, 0.04977229193994596, 0.025594534067016457, 0.0390303066571153, 0.04249402381960423, 0.032898328236995206, 0.022988245492019964, 0.01164496258547109, 0.02140211024051232, 0.032836746259201924, 0.07995226059950168, 0.015748754827185504, 0.009590339670408397, 0.05694963563714297, 0.021658303448930386, 0.02339648034033035, 0.037711869339428605, 0.0609576621002728, 0.06331973333632754, 0.027207331093508872, 0.048156286920270616, 0.023995515131842227, 0.06843138606317582, 0.028718213528214444, 0.04124112149340011, 0.0259615074197251, 0.07199134302115248, 0.04728618340807096, 0.03962569870054722, 0.024388336291116093, 0.014771386556657813, 0.07703167296225026, 0.030044147016240225, 0.060165622947557326, 0.029755672777912794, 0.02740499518451191, 0.023421721022215583, 0.01880402646718487, 0.08196161729433844, 0.05295818348625495, 0.031420960233757095, 0.022796727341389465, 0.05928028577698335, 0.020732350211830872, 0.03281749063922513, 0.02912722404054817, 0.06887136567984858, 0.04514106061129321, 0.017298205958438978, 0.0801367498934269, 0.038804601832863786, 0.07545656554641263, 0.016665549483150244, 0.033393715162791555, 0.07239145542224569, 0.007915365032761568, 0.05097858930727647, 0.05099139446693082, 0.08109807532521025, 0.049871653543725136, 0.008979747484948848, 0.05543345187400138, 0.023466711450788765, 0.023404702378977692, 0.05069381910406294, 0.08627740425928947, 0.018037388874818722, 0.04323182394728065, 0.05694163001833424, 0.0430336216795108, 0.02832455158744368, 0.05362302906090214, 0.06837755306473664, 0.0511364838589103, 0.005310264851657614, 0.06540644192887891, 0.04485097758832478, 0.008599285239113436, 0.025537826323641405, 0.04113092357593198, 0.0035479296169679373, 0.023285022208226785, 0.022167744257697658, 0.028417349732931585, 0.03744393391835113, 0.09733717813487015, 0.04254731289561718, 0.03206466178169414, 0.11838279319025817, 0.09287808676280322, 0.10895975084314424, 0.23942544365361815, 0.14508338585015268, 0.09652622810174381, 0.09638971889451628, 0.11066315500366111, 0.11049682199354134, 0.21612472621904266, 0.17316688212656206, 0.19041345184368474, 0.16035439867165782, 0.14983328419827646, 0.17611265873476384, 0.18233114763373331, 0.15756162514369335, 0.14888639952386581, 0.08171335884159611, 0.0711395068755073, 0.13118895641978712, 0.121057796021623, 0.09783497440718836, 0.18692353830462505, 0.19308590360226172, 0.09365095456521358, 0.11161297379482178, 0.11653183283464563, 0.16258182995502027, 0.048668209853912556, 0.22702716861761388, 0.20876896447472035, 0.095428048723167, 0.1495019052057497, 0.1993079931144753, 0.09680555141981571, 0.10821275382993684, 0.12296995148062707, 0.21381530820602374, 0.09941080960655406, 0.07763689774419032, 0.11685342122350009, 0.27146230601975996, 0.12157058463461938, 0.16716374054310784, 0.07961689028888941, 0.12915954354309267, 0.10801009293044768, 0.1166762940345272, 0.2001538001481564, 0.1546854552842917, 0.13467229692445648, 0.1644067126776903, 0.10360684170718155, 0.30413267713400627, 0.10261588399448704, 0.1768530827135809, 0.10978483519847355, 0.2501881362930421, 0.16484077809558761, 0.19381908038931508, 0.12370416248637824, 0.1674862788809884, 0.1343539414266425, 0.1316707337936086, 0.13018248542662592, 0.10505202061106121, 0.21719533409322464, 0.09683673119833393, 0.0898755277176538, 0.12811503628449095, 0.1420442537674981, 0.21088100759492767, 0.1575393319850968, 0.14851469366300493, 0.18567547382366273, 0.12420489287544643, 0.21372814272199908, 0.09264729511473449, 0.10773538146167995, 0.2982612260647359, 0.1587890818594925, 0.16701530334689926, 0.16393346952334528, 0.09397583713214244, 0.11119488131014571, 0.07378407303364047, 0.2404938298728197, 0.2501721863424586, 0.1526115020556796, 0.1218087460485197, 0.1779242115275514, 0.0856264516891491, 0.16220739682114896, 0.13092169898652262, 0.08101784293690036, 0.12455022998995359, 0.12481551091637343, 0.12477424175989245, 0.12812279675516391, 0.09540208600341313, 0.1585428305571118, 0.08637424543379776, 0.1413047950594656, 0.12292638406037323, 0.11703362042504935, 0.10827830797361751, 0.07630130005699974, 0.1893502443788513, 0.10933912524412717, 0.19508136346215205, 0.22099730588736075, 0.1136566129242701, 0.13256524869751546, 0.0905163219619182, 0.1640305635068686, 0.07265036249713552, 0.14606586296952542, 0.09737158314354959, 0.22302091181758912, 0.17264071761840777, 0.16917393993466132, 0.0879399223072875, 0.08924791784656626, 0.224457893580679, 0.09555380205593764, 0.23490198557415318, 0.18461033581726013, 0.12581523267492173, 0.1762458967465547, 0.12633087879587568, 0.14013716981055277, 0.10987346391043357, 0.12751020986827152, 0.15053880521126334, 0.10852386979686637, 0.07778493657467828, 0.15194482170045376, 0.12493988529088036, 0.13522087716527526, 0.14837267628360182, 0.15292173702149622, 0.2658230408785805, 0.08442851234107249, 0.14451088834433787, 0.1947624104157571, 0.14249167975879487, 0.1684595629452698, 0.18564755757970197, 0.12829813895927322, 0.1246563101848287, 0.13088238335424854, 0.15665278439560246, 0.13670621439814568, 0.09510903438973813, 0.18370011611090553, 0.15684870372135795, 0.1056655727687382, 0.11141752944357934, 0.23652491219822439, 0.1096251824750535, 0.1298396457587519, 0.07481790868745697, 0.1478187027837961, 0.08822410262279934, 0.13289219970183988, 0.13767643411072994, 0.1822773835832073, 0.12454814623079954, 0.1412812761601902, 0.1271547144278884, 0.14974054159416308, 0.10922084126861827, 0.19104993301293544, 0.12198589622013031, 0.18184757761416898]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.07738886145694603, 0.04643281125613759, 0.030970249640484972, 0.06455472835730161, 0.023875955619939396, 0.018025533664190484, 0.03412295042747452, 0.0715772724980789, 0.03469669282616627, 0.03170545464531789, 0.0173165192902689, 0.05002760223203129, 0.010139548103325069, 0.022813795780342434, 0.025106426891720584, 0.028152595491959687, 0.022175680928593202, 0.08224332314585486, 0.028047804240017172, 0.042320317213213256, 0.025281652267421448, 0.05281495568793147, 0.026324171527859666, 0.0326577344939353, 0.05016380117364949, 0.033167232759296894, 0.053520047691680735, 0.07071831173473789, 0.05235354476157696, 0.026592714073617133, 0.025383911598774216, 0.03427813685829601, 0.004141585753043933, 0.06770960866443573, 0.053377850281615416, 0.06943317625911967, 0.0021664925800230837, 0.08435789435621231, 0.0768292265673799, 0.01699097597250535, 0.0633585625027697, 0.12219904486330287, 0.05277994930023148, 0.02467307776603247, 0.030752885598509066, 0.03616621800427956, 0.04759911500338105, 0.04948417010206369, 0.04033305066367311, 0.038408710576233365, 0.023948661194393234, 0.013966479042034238, 0.051815122846634164, 0.03474974441492269, 0.02278035412722778, 0.013519119125820938, 0.0033048855895627172, 0.04638818663454825, 0.023924083178562504, 0.029542600743532665, 0.031460819788457405, 0.007592009374826787, 0.018040790305202527, 0.03296117425986356, 0.05103447542135274, 0.10164093751940997, 0.036839299024112766, 0.05661662487733749, 0.02971288676734173, 0.047161429820041505, 0.09826377680104587, 0.028074774365391464, 0.011042322392665572, 0.05290155043645252, 0.03832708007746166, 0.014845025800769369, 0.06996998938942148, 0.03219691345528249, 0.07366162153982347, 0.049946573112280145, 0.013077636061596775, 0.05542609359948866, 0.01284201039872583, 0.03589910229728107, 0.05159218743022892, 0.06257651313658684, 0.10699241407095425, 0.010889353786384868, 0.027043068436004465, 0.012169822828934319, 0.06173233403974484, 0.044736068230122335, 0.005012119710896044, 0.01662393558710333, 0.046104864337511604, 0.021691388871160247, 0.010367255289888671, 0.03766495411494567, 0.012611414103077786, 0.038490674323252136, 0.06863152653339409, 0.010320403267659489, 0.026681984384213726, 0.036582602112884485, 0.019132469427741824, 0.05373183652878769, 0.07147795685957517, 0.05678762336291614, 0.02335208746033811, 0.027927001750457193, 0.07732924449467853, 0.04776251389675083, 0.05876055257695337, 0.05852822109215683, 0.04685383019668441, 0.0255950607524644, 0.04686120762339523, 0.0016251297253597108, 0.07908291934478669, 0.031090849116745017, 0.02620277148971875, 0.03035138657827291, 0.04295950267283667, 0.04985427866960245, 0.04787252795311713, 0.006410724778224024, 0.020847979692682143, 0.043649387831288966, 0.010879133215865061, 0.13463656658366804, 0.014745157621350261, 0.03611377928586256, 0.04406660697573135, 0.01453803617492198, 0.09258166436226138, 0.03327240130954212, 0.040220853256722616, 0.07509164722456087, 0.026718528693421718, 0.009356474094543486, 0.07810053415596485, 0.03281064564362168, 0.017939333450950442, 0.05933633659996333, 0.02952226493958264, 0.02927174461224387, 0.0539112045249391, 0.04307078077427803, 0.02582438725737795, 0.031480609754761385, 0.041727215772674936, 0.037450916809780944, 0.052344018458238536, 0.019799032954559214, 0.05795010433141744, 0.052757334384706714, 0.035567999096407045, 0.05076142636338069, 0.05823125476918875, 0.07826829975050303, 0.049802609869549354, 0.025403199777487787, 0.13892492760092984, 0.005441245776901563, 0.017708585852937355, 0.08281470982417946, 0.08223330271580527, 0.014557136662094104, 0.044617776593734185, 0.06843246624714906, 0.02429133998380313, 0.050317899759618506, 0.04639566365268923, 0.05519070542387425, 0.011705153156071903, 0.07522239545059782, 0.017648145346151247, 0.017320376542967655, 0.07195817907491038, 0.037749158669142954, 0.007937870301952166, 0.030545609019276117, 0.010226801687460995, 0.0575358307950439, 0.03363020650501694, 0.0717666647547195, 0.026392474011968703, 0.12425962219675704, 0.029545377812258182, 0.04737160987250748, 0.015190279603214755, 0.02268399175767216, 0.04714755979817241, 0.032799089207283916, 0.0223068677399668, 0.058864135325195334, 0.026378199878719547, 0.09600660598446285, 0.03006455942898268, 0.05063996312298602, 0.07949495207398169, 0.04246642167169241, 0.02300902754218588, 0.05023153483747475, 0.06687477200983033, 0.07158637362261934, 0.02870850144855438, 0.07303007397680514, 0.07035450424037634, 0.034386312303644036, 0.02925290076452638, 0.031098268678291675, 0.05568108979552504, 0.04719074034402448, 0.06038245264320605, 0.02064969315524063, 0.07466874370772032, 0.08140266422302493, 0.03175895631072983, 0.026519573744266268, 0.008954222392921728, 0.06630342363590194, 0.04416936617945472, 0.028442306962284832, 0.03432789426897803, 0.03671395554838162, 0.08501145162529523, 0.029022185725250074, 0.03980221301918069, 0.03439345607353795, 0.020827122948943608, 0.00858418947656549, 0.021163506410835732, 0.054970190845309734, 0.021697274341638532, 0.04772002666047023, 0.03051019277453663, 0.0505026150494814, 0.06029810636274277, 0.012860615801576887, 0.05656930362625469, 0.020403641035720226, 0.07020427439842494, 0.05692518594103956, 0.01489584520083642, 0.0925815954143482, 0.025138242523215955, 0.04565683313675466, 0.009644228210222096, 0.01051409136233551, 0.02737500092705652, 0.04082292941729388, 0.03281274089409459, 0.013981721318897702, 0.051467832207920096, 0.04792185252412193, 0.0424339548654614, 0.01626076777615855, 0.0036202717784626953, 0.08655504218392795, 0.065472892395431, 0.05433120456854663, 0.0272356495336299, 0.008312280931990714, 0.04486783535309857, 0.04937655390090039, 0.0445208664713127, 0.04972476767556322, 0.029460114141505574, 0.04409230156471172, 0.07621509218288046, 0.03065598888262626, 0.036460211906101436, 0.02380159912600873, 0.024931201516019724, 0.04692955798799953, 0.05129751937103368, 0.0186722191245926, 0.005203619188133387, 0.028165128690400915, 0.025353670277963244, 0.06377362894014486, 0.025587782917183735, 0.02053369212174608, 0.010483659477153373, 0.039547622849744175, 0.06196414841519249, 0.04690498571782824, 0.05797949146419283, 0.009302010031176672, 0.04867133932308324, 0.06874386566661059, 0.024429344977702827, 0.03705096145671222, 0.03120466679965537, 0.03882126807565651, 0.02350848622529978, 0.050722551231663075, 0.04300327310639043, 0.024706990563220555, 0.06963026769939931, 0.06490415638132442, 0.01762343709537339, 0.0720462025774102, 0.04044197304474731, 0.03954797141974972, 0.046496545940998106, 0.05219021864655999, 0.036242757848794424, 0.04581233749406473, 0.12164713214001349, 0.034355764547663356, 0.028389797380734837, 0.02491264878171346, 0.06092507655041353, 0.041039946804484057, 0.022016545314522042, 0.05073761252025443, 0.04194283121896367, 0.027358499393167517, 0.019551508031004382, 0.02315269392584601, 0.06569317331717861, 0.06249073427170516, 0.04909360698694664, 0.069074539858247, 0.04044109970451363, 0.07030193528701222, 0.03437523467225894, 0.0512291383629124, 0.018846659260171077, 0.05817251114715492, 0.07881640501680874, 0.09354250715865244, 0.034118813552683404, 0.02327276863187792, 0.04067300984095182, 0.04921295582467029, 0.052756947510304956, 0.030930229207320564, 0.09268016028668612, 0.0629069804844837, 0.057945592073543425, 0.021058768785047918, 0.02936727003074221, 0.05079016232142045, 0.08826020068579143, 0.045689460821449764, 0.0680422593629168, 0.043491979745487054, 0.06268331345411078, 0.05404871730734745, 0.1571083462406551, 0.10121580468670976, 0.12316057713882578, 0.12791416036986536, 0.1329622507816361, 0.12996286334049317, 0.09022975911296184, 0.15083420871486589, 0.14372045414582377, 0.19060164900316348, 0.1505294742603456, 0.2126309669186031, 0.14912572539141103, 0.14419786481847688, 0.16798965993427462, 0.1281333534467605, 0.25954730988990876, 0.19395912126187356, 0.12725548563344827, 0.1559654656316965, 0.16548222351458766, 0.25491221747811765, 0.15777257511452322, 0.12099142982474259, 0.20237876462840265, 0.09647182053736142, 0.13522836950517472, 0.13547091294200192, 0.15098500546188126, 0.14009477450482308, 0.13807953425472783, 0.12144162139344601, 0.1438993050326263, 0.13905943731867498, 0.06283923149889996, 0.22940012596307263, 0.08481383158434784, 0.14031010649857983, 0.16314628353763014, 0.1199849435098229, 0.14921921876169023, 0.26720322488296416, 0.14968466314096607, 0.09863501534827294, 0.12658772509424918, 0.16998873572916756, 0.172568061839669, 0.1143260588569026, 0.13296333862648857, 0.2717249516037203, 0.11337390349757288, 0.06754166686967497, 0.0978435545919403, 0.1274523625691091, 0.16743738714966083, 0.12427911913442997, 0.11295293818318075, 0.1077370208898379, 0.08269487835106351, 0.12070672090856299, 0.09477400115781254, 0.11222203667726248, 0.17620238295245558, 0.10701002643233347, 0.1895740799485676, 0.1724669229119055, 0.26375932258463675, 0.19818112374313418, 0.13073809835458958, 0.16763848522978445, 0.17306105474070196, 0.15566885170917358, 0.15657176293673056, 0.16814060989887486, 0.12103443800081169, 0.11555886286641322, 0.1784711370184537, 0.09359739735842713, 0.11197651315840984, 0.2238441958662964, 0.13120193394922441, 0.15726225330464302, 0.09755996416413015, 0.15601775879340787, 0.26902283692071516, 0.1935322264269475, 0.2504186368276996, 0.18837501445124227, 0.1518530290453665, 0.16047245282078945, 0.14695015826052235, 0.12162902948236275, 0.1044297656945644, 0.16506157995712373, 0.18697806844307532, 0.1700045477839247, 0.09299913631571878, 0.16920107476893934, 0.2351419702773133, 0.12856607054991107, 0.18137934467484876, 0.09132938639771554, 0.14860706854491465, 0.11500691183872762, 0.1575685812220458, 0.13914125550898815, 0.10320978599690622, 0.10832755976626951, 0.1425019606587387, 0.04903300943213606, 0.23612035648717036, 0.16826180500849602, 0.21558772922763902, 0.10340446426022439, 0.17802964054769088, 0.19275227231123757, 0.19267940202788, 0.0719365983780834, 0.10010715288620803, 0.08966862269106413, 0.12793875179223477, 0.15955562943652754, 0.18383136229409328, 0.10233459183044973, 0.15033361622162406, 0.1309954885753893, 0.13019279697008673, 0.1399365313831837, 0.12463026319540317, 0.25786093586394865, 0.10761296827225916, 0.1141863550630308, 0.27702661711842785, 0.12580767138710908, 0.2117076317869848, 0.14156515770141156, 0.21882984396671096, 0.10532993432735244, 0.16304808638749585, 0.12464228311493514, 0.14256111796825163, 0.11037567284919562, 0.15197525071280618, 0.19978911165268193, 0.08212430372593865, 0.12484680560808029, 0.2107619268879775, 0.12331201739969755, 0.1200278061291864, 0.232450136494252, 0.059006773235817114, 0.2375881503065748, 0.10084282711989458, 0.06045485944336942, 0.12202997691929342, 0.1726837870815108, 0.1872196619308764, 0.19347086278421266, 0.1666685872741284, 0.1255536059879007, 0.18467583633478613, 0.1388643760113947, 0.2999879269590301, 0.07591403495039671, 0.2100706397886238, 0.2835210815312401, 0.2219592058850873, 0.09594740270967446, 0.12960536074974846, 0.13990187356548925, 0.13649995288541242, 0.20102896367109593, 0.09510230813776294, 0.17413045219596357, 0.15917667638390295, 0.11077358657794614], [0.04070388701473994, 0.04165649053550536, 0.04160708552526851, 0.028231508293820005, 0.09086049462278044, 0.054744922691175056, 0.003622188913493207, 0.010746621072382457, 0.09523403695634297, 0.02936709766095925, 0.024625534349451625, 0.04613525504546781, 0.03658834394187697, 0.05970588209287775, 0.043336571149167516, 0.012938247321383848, 0.043022559369884195, 0.02921184419744438, 0.08213721230746278, 0.11101240682746134, 0.040773493763540065, 0.0713893511302529, 0.010107523712870336, 0.04149252856751123, 0.03182560596014223, 0.035668601762623556, 0.061178678466427716, 0.011632908191982538, 0.04794231090213984, 0.013669049235871963, 0.027644857313604127, 0.06737042323596056, 0.022005050165218212, 0.024515213857915615, 0.039519143531159054, 0.012160898862226356, 0.0161922297200128, 0.045504075204653126, 0.08562750889048462, 0.007367675369154783, 0.044667488039140744, 0.020642792618262674, 0.04555535329986484, 0.0455981737843925, 0.0701433627475654, 0.08592580820644095, 0.05072051343778449, 0.015928763464363595, 0.009014691628004995, 0.05764032518791576, 0.034198724184065096, 0.07417693058209074, 0.039734904534153404, 0.003121317037561488, 0.06603183014498604, 0.031081769059622483, 0.033494762160004146, 0.06710746355595128, 0.05828166718504602, 0.033578721566065665, 0.024622632791438413, 0.04968867344301074, 0.043585128376200315, 0.010438643193112747, 0.046744007662299185, 0.024837604723870758, 0.08219188034173944, 0.025392782896937385, 0.10904546076011275, 0.06712063260736965, 0.047016895841807134, 0.033751937876185106, 0.03836038191953013, 0.03455795047263946, 0.06528612015949142, 0.038368985086919806, 0.022713555090670145, 0.013078148382896138, 0.057661649245288105, 0.02703906945703972, 0.023172485807369796, 0.05223649035718653, 0.06722493547826044, 0.02814725968956707, 0.00737536162506008, 0.005078325986922269, 0.04800727515811882, 0.01810776937242237, 0.033893028289199836, 0.013017219495058302, 0.04507643726444052, 0.06832155203747173, 0.04986503454405935, 0.017150105840917078, 0.04809563573930533, 0.03748488897878317, 0.03583719856255958, 0.02349321617774906, 0.027972765927833897, 0.036191184809731866, 0.029581127305244728, 0.039819415523520404, 0.02034584736271251, 0.06106073540004511, 0.04048600777863495, 0.015403858213234815, 0.026420141277354092, 0.03858060921512304, 0.001127742950977277, 0.038776187631752224, 0.06301421364168487, 0.08474665333426769, 0.035648315754388614, 0.07796273026014529, 0.050513692680866494, 0.017794334074302066, 0.02310167438530874, 0.01672251386597993, 0.12983802165235245, 0.059859475060816736, 0.04164209574340813, 0.026088383071304812, 0.01602536715161536, 0.02254634874031669, 0.017736258863982175, 0.0666386483898086, 0.015320794172434798, 0.0683333421306264, 0.1255904011909039, 0.032740717137893366, 0.039318528086427725, 0.03417247801177925, 0.026251793455993457, 0.044249096780174205, 0.03229974543735866, 0.03561609409629338, 0.033223708761074854, 0.008015765643288052, 0.09324577832294088, 0.02305627793013569, 0.02908147901536957, 0.02452339184650731, 0.0037024667882736054, 0.02851837183228664, 0.012232689919220585, 0.032413655050819924, 0.11300610468512583, 0.00398063762282442, 0.008435693866152678, 0.014086105586630444, 0.031034244795239745, 0.0756955236917542, 0.03992617370620851, 0.008628046095010736, 0.03872516617599515, 0.019779890332551255, 0.02759105687390172, 0.03894524791488244, 0.056825268923515276, 0.02017214075632153, 0.036948956849594275, 0.042147529912331415, 0.07938859608745383, 0.05803280735328313, 0.05013503074165314, 0.0765612336897081, 0.030686871802073815, 0.03018334519208199, 0.03855785640377191, 0.026497060335391474, 0.034483237747824004, 0.0711625584611489, 0.032893222260979876, 0.012289299028775385, 0.0729733145224952, 0.038110740678084475, 0.054644208942209525, 0.01239044274458842, 0.03623687812397557, 0.026334519460496884, 0.0359647560323919, 0.027751927677121375, 0.062148495982851715, 0.017227235573133635, 0.07364339630810485, 0.04201007458651739, 0.01769955942196952, 0.10176432364049459, 0.042081002836986896, 0.0646432651387107, 0.018534727409602176, 0.043028404620746454, 0.07960753635533395, 0.06533843630384054, 0.026414512446330442, 0.020991808870026184, 0.043448305072923826, 0.040650145946851665, 0.03790848580519519, 0.025667218574052377, 0.11099001407743463, 0.02192276849171087, 0.09412073500214085, 0.01233587908979145, 0.10879979168455448, 0.011938775499020855, 0.007997915794652316, 0.06560432243972056, 0.012157920695420717, 0.07276403462334026, 0.04185273544862867, 0.05998846128462784, 0.020339176652111837, 0.04511590228385983, 0.06644782354874958, 0.08280193147760245, 0.04975570613638528, 0.06310117228196994, 0.02092266560442025, 0.043833099545971047, 0.10610218159854413, 0.0161592458044329, 0.033034147965090896, 0.033005182180673845, 0.026309707787849253, 0.02777545998293546, 0.0586465701851393, 0.018293413543893446, 0.030341325928607298, 0.04790954915205798, 0.022786099786659884, 0.012538261324798149, 0.039804124408551765, 0.06446810679570322, 0.00024099170478885138, 0.03751395818506999, 0.0374784346880211, 0.010060247469453082, 0.023143504701194265, 0.05863853775325322, 0.043681532880591775, 0.06937901384287304, 0.1220283987781694, 0.011607283508525261, 0.09635880724677155, 0.04677286236396721, 0.014687756568403735, 0.02953221259127942, 0.03723617470372589, 0.10230259999873177, 0.07767229866717132, 0.014996749514173117, 0.053706134278928085, 0.014622011860351891, 0.01228843717986057, 0.014718045769709975, 0.0546285807485542, 0.036623369481775074, 0.028170144651085142, 0.03713752556171629, 0.016660083445810502, 0.03839690899175983, 0.04221054447454311, 0.021230646356519674, 0.004525438416749239, 0.016828224423431584, 0.012551388241380695, 0.07791481912136078, 0.02950044484027932, 0.13733198565821494, 0.030255776890102896, 0.045328223552074165, 0.051373936641480655, 0.024183384788733338, 0.08025098892469561, 0.03673751275205324, 0.006008139828355202, 0.02301464871233029, 0.05944053221854472, 0.09786443048787695, 0.039581231126982364, 0.021103498743726842, 0.010958678040262914, 0.025046549459558823, 0.001247551202053024, 0.05155232787552861, 0.07420196633545623, 0.0065569125487649395, 0.031198118663122578, 0.041545928726273204, 0.02958397140666362, 0.015460367731359458, 0.08960804045801202, 0.04759251898635299, 0.0660410768262321, 0.04101867254282679, 0.04357610003001267, 0.030370136580219677, 0.06331799431673943, 0.023886249926421913, 0.03481221505470815, 0.1366475167413873, 0.039755102442277056, 0.04933852146589949, 0.09504637605841122, 0.014778382854626305, 0.0054176344682702856, 0.11500292052064212, 0.03901218484726645, 0.019907754237553286, 0.031108817709009015, 0.021803862069763487, 0.03830241970717907, 0.05491356928682616, 0.04638945451006294, 0.05087631656938503, 0.011883552050999096, 0.029239446345356204, 0.02968511033442713, 0.048740306388466596, 0.017739204472051035, 0.048640098257531086, 0.06138754467810355, 0.03485981975832293, 0.021602275608588132, 0.021937590377825885, 0.03673396959540345, 0.07413570739088521, 0.0502063075621282, 0.01756017738502593, 0.03876919324900355, 0.03238751613084347, 0.0363806153707687, 0.006395032903509996, 0.054594520479440696, 0.025990996059150468, 0.013638764822615251, 0.01414752668595963, 0.10807183195626545, 0.008686709277812512, 0.040425406393384745, 0.01629064903564511, 0.03564475344554071, 0.05183273137757375, 0.014618452424333702, 0.15714913276174378, 0.051269296691903186, 0.0362437729152941, 0.03919188609166492, 0.038856071450056574, 0.026816262360361796, 0.019496160093694925, 0.17330107008737905, 0.10939762371802524, 0.258036247424541, 0.12836340965042192, 0.09531238476835913, 0.16035582359519698, 0.2503295714456228, 0.14375892708138113, 0.1622287400307194, 0.12216346774009929, 0.10540041441638624, 0.14444586280132496, 0.12295388661685491, 0.15160893811093223, 0.10022507680039253, 0.1452904287725687, 0.22265332750976088, 0.2670946242588182, 0.13648392632603645, 0.16979998698638332, 0.20123110363079658, 0.1062169339087221, 0.1354093807599237, 0.11251817562527235, 0.2574448275469965, 0.1237418310296151, 0.25201442861749285, 0.08488326213292538, 0.16091557339795176, 0.11003490927959643, 0.09208948351442815, 0.11607879141886389, 0.11205325984666425, 0.14190251217974773, 0.15558668111841525, 0.16504641141622298, 0.07058744093463307, 0.11596598497201359, 0.1493348520729811, 0.11922065589216449, 0.22376726531694013, 0.09670624344219124, 0.11352958022466592, 0.12080873317656018, 0.1847841152020039, 0.1279568850934025, 0.15660069041675137, 0.08409539432895762, 0.13319788410538627, 0.1466131408608729, 0.14644420315181056, 0.11864350057177006, 0.11707164136873138, 0.11010303747870269, 0.14988642005670458, 0.1441945399968855, 0.1601152873087314, 0.13440917636598312, 0.0673690366168176, 0.08317003672521922, 0.1534105777259796, 0.20318553182146243, 0.1324307236580118, 0.13762158221535145, 0.10039100378391244, 0.17920901758536217, 0.23275217431927883, 0.12923682649289409, 0.27219211201994653, 0.15573671177750634, 0.16810210631980052, 0.08885580340340253, 0.19291436119425684, 0.14888088369081098, 0.15843749346752323, 0.11150900800261768, 0.10061565140682845, 0.11446581627692907, 0.0887870699948361, 0.1387625935697748, 0.130417138157833, 0.15743007252533592, 0.2428592029478281, 0.16525726945650193, 0.1117274120089508, 0.09634341654037276, 0.2298518114032284, 0.1681788683298134, 0.06788607701779374, 0.07592649920092476, 0.07609942056719335, 0.1630558085537726, 0.10628164535568607, 0.18829691944824112, 0.20724156901480692, 0.11194010099936878, 0.08530489394381162, 0.0980743385791298, 0.14510066879372444, 0.11061193436504373, 0.161193203661711, 0.06890363330321927, 0.15937331583230727, 0.15576280473220736, 0.11957394499932567, 0.14606859024253585, 0.12910928817525988, 0.19536639413525983, 0.09571624333940207, 0.15924331071155687, 0.12734122619393373, 0.12101232104243771, 0.11349264712583636, 0.14674475476626428, 0.11474585205677057, 0.13002125456208183, 0.1082401491341091, 0.19386354413244034, 0.2811280680039237, 0.14061404422165888, 0.22333767385252062, 0.09574234395498231, 0.1703015907156852, 0.07909763589381211, 0.12766199486870922, 0.21928557435110693, 0.12365835808938551, 0.14626147586011118, 0.23055396162934844, 0.09572731330990793, 0.10194747994143157, 0.25312885672094365, 0.10670847890357818, 0.24978134360524917, 0.17672237279194017, 0.11171924551167797, 0.1727615143623083, 0.16512260652117192, 0.1313568675710309, 0.13026048849907615, 0.16484201915802496, 0.22317440519409798, 0.17281244388751446, 0.1328358462741298, 0.11900880193758397, 0.14920078668623202, 0.1691793944806822, 0.13550662796103186, 0.0948555512173522, 0.1458633706093796, 0.10818619356160203, 0.23795994809798657, 0.14599640943831013, 0.08719823428339536, 0.11559483069445818, 0.12660858566842734, 0.08267746517254461, 0.11742472363215302, 0.18335373711682137, 0.12441849351049432, 0.12310515833838333, 0.13536065756793947, 0.28477155152828465, 0.09171412341416844, 0.14728176707942642, 0.21680894998773453, 0.20716319822015303, 0.18233925284397218, 0.08082004669573038, 0.3021172836663262, 0.16585256573894333, 0.19493078121975546, 0.0790270485524689, 0.11743089830082272, 0.08699149013526979, 0.15040058762796465], [0.0392152211298385, 0.019184207175708106, 0.013231361179702706, 0.07690568980310233, 0.05591701806312608, 0.045067489357484926, 0.036311556374834436, 0.008138237246913056, 0.12527623619403572, 0.042346988564297076, 0.018194482864571676, 0.05593882858633034, 0.05611402140329442, 0.08219417094463304, 0.07721490587197966, 0.05420126839570942, 0.04299772279937902, 0.017036803352135806, 0.04455006208210703, 0.0436835783353496, 0.040289375991109884, 0.04030275188626782, 0.04859853032675963, 0.015071504373824405, 0.028363700595594225, 0.021554494704750758, 0.07949152000008092, 0.011813785381344779, 0.009108079661194597, 0.030027758480320056, 0.027157820746182438, 0.030302755316839586, 0.007958414386056604, 0.03505689204640446, 0.0018474187550788386, 0.04843008291396884, 0.03186755885009564, 0.05737108741736701, 0.04399113582387086, 0.029359304631549506, 0.0704786870929022, 0.05603543227358211, 0.04555443016391608, 0.017083069317102913, 0.04659137613470516, 0.0389326227858903, 0.019598118735537417, 0.05157114682538856, 0.04430507482480138, 0.03046031470500654, 0.055800664629186356, 0.03622894528351965, 0.07763212501642204, 0.06134178241594665, 0.01410406843323501, 0.03728242726215432, 0.019533765434678045, 0.026594167725453456, 0.0425363808209377, 0.06623297419038511, 0.06898713688696585, 0.04144036181030735, 0.025224341229806026, 0.03798857646723909, 0.07018087041233817, 0.0966512919553826, 0.04924562947464086, 0.05091804154818097, 0.022384413074882283, 0.015822830741413902, 0.07539786788965426, 0.06880130693917313, 0.020089872489352862, 0.03980290249831254, 0.06336477164539599, 0.02581597561196935, 0.034289287268033916, 0.018463712974241184, 0.009122502223979081, 0.061486776046935594, 0.02962240220738515, 0.06266758949946492, 0.03648487993726327, 0.051317127391455636, 0.059393697433293834, 0.030620653077118823, 0.012242624164378692, 0.03687872573913586, 0.03058701798680329, 0.02247432306889565, 0.028165705171563936, 0.018447186542494644, 0.05787250345512744, 0.056178139132117076, 0.15400878514253324, 0.04040724244870005, 0.01876879408354721, 0.05508919494346746, 0.02158129054512228, 0.060316971277878176, 0.024159906109073953, 0.02328016329556704, 0.05172632559533081, 0.05656469943782976, 0.04252570921615247, 0.0170951294562509, 0.05228870307966586, 0.01131817245961077, 0.0330135670130051, 0.03193472560885693, 0.021348915010270093, 0.029922323714521144, 0.010316293205945723, 0.04034454964341656, 0.04390711130033578, 0.03191711707791734, 0.0681105561013664, 0.0392423176597203, 0.04550566100665639, 0.008275561380170045, 0.048839484131143945, 0.02274590698371251, 0.038021169677977605, 0.03639895934611559, 0.15151820265718047, 0.06186711571870312, 0.010965012629786807, 0.01307362080326364, 0.021155374387519497, 0.0480545198004092, 0.006386081644919731, 0.07689505650271332, 0.0061987027631051125, 0.06498176874893327, 0.026684933822722207, 0.012774323657785934, 0.015924541362290903, 0.11117003707876129, 0.08718879608016822, 0.020906491573118878, 0.01569927512337604, 0.03345202211470854, 0.019158748158764456, 0.03437741419240352, 0.0203755734893944, 0.0604211745573388, 0.050310595111260493, 0.045201750096654704, 0.055460015972775806, 0.033235000897078745, 0.0274758487414088, 0.022878928575664762, 0.0648595700641313, 0.07777355250812347, 0.030196422312949455, 0.050534162550203265, 0.03139078786085931, 0.06142187307799055, 0.01323962343796607, 0.045272643873167616, 0.05866279975781518, 0.06515862014625343, 0.03641297109425068, 0.02338246284653583, 0.0677997695522443, 0.051906007687531175, 0.012406602411741212, 0.05516836630000223, 0.013203367369339592, 0.05768456293510334, 0.031145681859925393, 0.03887133958238748, 0.05460530316697494, 0.010227396363212217, 0.02104514391131459, 0.028825509887669357, 0.029716278621626478, 0.0441384736839081, 0.038861683044101925, 0.05344672158600823, 0.05543285815586006, 0.02361604688508857, 0.02136310678906739, 0.019358321723918763, 0.06264629225516993, 0.047449038379014506, 0.03631351755992059, 0.018657282325288942, 0.09020799455503303, 0.06862285441809124, 0.03605529996416262, 0.03565223429412131, 0.04002283101961498, 0.054386232664147695, 0.010073529518840295, 0.07756862398837844, 0.01964587665673706, 0.06605227703168508, 0.03857597055274152, 0.020006301872912916, 0.026390453455068415, 0.08932169211367447, 0.061519890197462616, 0.03744289969965335, 0.010187325176722821, 0.023156350080464638, 0.04131370066334644, 0.05726873807068314, 0.04882436538595827, 0.05993950060538708, 0.03214793362384362, 0.03477907026066415, 0.059541832024772326, 0.04408115115497382, 0.05723770384887054, 0.033420838505750707, 0.023396263920491742, 0.0062690473503373085, 0.02408852395150931, 0.006173938970952746, 0.11971674378841154, 0.028665793961995555, 0.02392253951139508, 0.09455413392354405, 0.03982416143821132, 0.034786106778248664, 0.03577045315215665, 0.026761896930815234, 0.011979900056406135, 0.03116968722503272, 0.05681236800287039, 0.036523601851396026, 0.048332778256266355, 0.035353923486846114, 0.085605813280469, 0.03438219458105103, 0.030077259251547438, 0.020705676945527236, 0.022388862130502542, 0.031155627596402363, 0.0028930283423828623, 0.0588545362435041, 0.011173734242366928, 0.0411107563113253, 0.0425108241277837, 0.031182756685020945, 0.04440010420136875, 0.07886307509315592, 0.00473700748238292, 0.02320093256721814, 0.06148594867197737, 0.026303730386820053, 0.04600270268236918, 0.035553926061238014, 0.026364180469705213, 0.03302261451139085, 0.0303721456458011, 0.03502620256415779, 0.047336454097662246, 0.060861751722592505, 0.08613716420387069, 0.017497457766665087, 0.0193527982299847, 0.02485094997551172, 0.03651130614021132, 0.039114959372748295, 0.157297937680156, 0.03959830722681457, 0.019663510085534186, 0.021616316085020383, 0.04966701230695171, 0.02155321916835683, 0.01655548371584906, 0.06217493750755826, 0.06060727263590502, 0.06057886992611232, 0.0013757100509059045, 0.05313482420939592, 0.03841521849315013, 0.05549348635418762, 0.06005864259937118, 0.03437544534643812, 0.016805781877689788, 0.05292141509632911, 0.026110463640502384, 0.036319481554411115, 0.07042370496257659, 0.12071141702753883, 0.016366574094600735, 0.027568943745967363, 0.03539293651439009, 0.0686051654479196, 0.01662824866211703, 0.0199083651926729, 0.12154446103640142, 0.08108399462916198, 0.05988055780049294, 0.03961910268351917, 0.06183862107835951, 0.0856258234970512, 0.1172587047180822, 0.06922388869908548, 0.0329043228750027, 0.04254599522438742, 0.04194832023894114, 0.026914239260217836, 0.06529237143695354, 0.04667300663347687, 0.028892852846653234, 0.01975158338374909, 0.05519654301385726, 0.09528570958683569, 0.05835604666161442, 0.036102663350081256, 0.10935073147618002, 0.002497144507229208, 0.011623110885040895, 0.05773095338935814, 0.08378806283637401, 0.03820870417140184, 0.012923782623763527, 0.03368456044324464, 0.06023606856263453, 0.07174774238298978, 0.03992110220414977, 0.07338859546448916, 0.08993596439400027, 0.03946161415848521, 0.0559596891605085, 0.10198824347988253, 0.048267101538517786, 0.05960269387991679, 0.04437836262607767, 0.06886482328897522, 0.026791753292444254, 0.043270484574379466, 0.024234492429381898, 0.01934602409751425, 0.033904737943122466, 0.01105471961050024, 0.05491412853101089, 0.04869924790616478, 0.021923883149640697, 0.03791090664303592, 0.017446547393657027, 0.04304762193632703, 0.044883689542691556, 0.027243666643757495, 0.08135530466754591, 0.02642786727407046, 0.0362281485520784, 0.07477179785529453, 0.0986166445598487, 0.16060042014766127, 0.11598580366661472, 0.16562249421352343, 0.1589366610372259, 0.16202445502483076, 0.12387169825453913, 0.17396862378283856, 0.2904570577365737, 0.11605063768764658, 0.16543199879027184, 0.10773051680336077, 0.11286364297472662, 0.16080165612361125, 0.1394925374657877, 0.13634045337957723, 0.2431855564035716, 0.17231189735954808, 0.1666268508040136, 0.1381387834947917, 0.18028685732954935, 0.17216117722132515, 0.1580465587997629, 0.19902636387175132, 0.1962636363121771, 0.15920365800059613, 0.20160270223934806, 0.06794647538974401, 0.08775372463729113, 0.19517473425836335, 0.1943220477551222, 0.11620889613104445, 0.10035724994996864, 0.19195325792797152, 0.15973235059890056, 0.10917645413428546, 0.15142944371027334, 0.1289710705919612, 0.13481610694960242, 0.13242313938756145, 0.168179327982568, 0.17959891037354547, 0.18417867591544507, 0.11257845908403398, 0.21341732552936002, 0.14932247209212474, 0.1015774058478494, 0.26349891397741537, 0.166451278773527, 0.13622926337824715, 0.13121370105974137, 0.10368535805854107, 0.1595902719324635, 0.1734398239322247, 0.13283124974658414, 0.16238709040466817, 0.2076947253437773, 0.2055881061260739, 0.17232835292816165, 0.21852923106522332, 0.15667751371379823, 0.11806706537402446, 0.129952950162753, 0.17324644801837785, 0.2017320332027251, 0.21832762736706965, 0.13855354349699714, 0.13759674564484628, 0.17367623866565768, 0.11682906728838721, 0.18677326249739817, 0.21271120696779222, 0.09382652659570018, 0.0706506431883862, 0.2228438995418049, 0.0815341325717107, 0.20348041438527648, 0.11715114597351321, 0.1325149780079242, 0.14165500449317117, 0.08812867105007173, 0.17172455306976073, 0.09887696889739844, 0.1554594952012262, 0.24086193512043647, 0.09974123098917546, 0.171083306833621, 0.16590110506982575, 0.15186329462355183, 0.09647698396997106, 0.1980489582544373, 0.1521152762636062, 0.12130862852979092, 0.23357450841895996, 0.29746575100767997, 0.09940936170037716, 0.1478006997175755, 0.18105853769567706, 0.1233384780766022, 0.18773335452762344, 0.08504927338611695, 0.2572141737947541, 0.11061856102558876, 0.2513852099617643, 0.258398300577556, 0.1544086523954907, 0.0670052750877315, 0.1554098067384574, 0.15882876521397024, 0.13515793538141635, 0.2135849455671926, 0.19120299738020669, 0.0899050067809801, 0.13832118902956286, 0.09150698090032225, 0.18221830288248678, 0.11992285974443921, 0.17621433392407435, 0.2979265375723762, 0.1804414845161861, 0.13516047879332496, 0.12770088915262492, 0.11894900877509387, 0.15078419849516886, 0.20999637522524406, 0.17043018623465495, 0.142902517390828, 0.15642700296255851, 0.10405521764750443, 0.09571432045871213, 0.1293301666455884, 0.1464555412530899, 0.24383098547977788, 0.09256644219520593, 0.13227301679791945, 0.1607564416143202, 0.1904198716604902, 0.26603132486343384, 0.26791427705076437, 0.09144108201707564, 0.17129698407746133, 0.16110145697189918, 0.19324736429318307, 0.07296754588042537, 0.11136147479015975, 0.19509765049142225, 0.08382868081811937, 0.18288388007110168, 0.17599204585196512, 0.19631830434645378, 0.14344411090977732, 0.13480766466067684, 0.15176319757536536, 0.21204634990182616, 0.10995214114025717, 0.15074451514069112, 0.2074256905865285, 0.14967081227129506, 0.08203654069333308, 0.22756453333122117, 0.13989861003093182, 0.19843817688524726, 0.1769803145960454, 0.12322973189575058, 0.1743126891913914, 0.1249343234925501, 0.0945499740661152, 0.16946653955646102, 0.1433930281669863, 0.14202194528714304, 0.16125651316777354, 0.11676634000914714, 0.19778168549941433, 0.10723150245124295, 0.15914485309152834, 0.10518479130921826], [0.04807314722828808, 0.05668608223899238, 0.02509409287613967, 0.052707511856551134, 0.03705025282538226, 0.010351016141113736, 0.007864249252428812, 0.07305300298837886, 0.07370332736642131, 0.02741414610476744, 0.06195612364418565, 0.05360267410475401, 0.07199475977329478, 0.09357006334128881, 0.02824416215110931, 0.0701161053392195, 0.0455060210679808, 0.04947241065242598, 0.021224640227193316, 0.02645395448311202, 0.02841220162208042, 0.045335321356692625, 0.007663657747945118, 0.05605120602394304, 0.04705003297497188, 0.05233408229786062, 0.07630520710541357, 0.042314303423007654, 0.03251672452015262, 0.03252959096684091, 0.052071252852798476, 0.013502842630259694, 0.06765454992531769, 0.021671876611728823, 0.031216054696649797, 0.04217680213191817, 0.05184438357490206, 0.036491594697919585, 0.01890631835727442, 0.038490884997431314, 0.07023140923270295, 0.021315670624795943, 0.03690688713123241, 0.02757448256165991, 0.021467516912267576, 0.052134363176000696, 0.039327950967896375, 0.020377929209761565, 0.041935411657417015, 0.04802944191220788, 0.05341607423859739, 0.06728310453435106, 0.04403779823933879, 0.026794131995449146, 0.05254330857086086, 0.04255008613390308, 0.06777494830349762, 0.0348704990239874, 0.029346422863102732, 0.037038217584091815, 0.06430012669654624, 0.03224296300041099, 0.082409004981239, 0.018942985240550294, 0.025393441732552265, 0.04708138512327306, 0.0031912532041690526, 0.020644771040327126, 0.026608093288697066, 0.04614829386193906, 0.02533327510219909, 0.04432291318211825, 0.054464618780560074, 0.06884033145803599, 0.03874514191862076, 0.047202664502565904, 0.0911368378588269, 0.04552992684165797, 0.04612380586143944, 0.052338793738594944, 0.024841810546575055, 0.07073698895833186, 0.04310225166620747, 0.02537242411034963, 0.01624705671753374, 0.04863008548836074, 0.048228969512086724, 0.03578196745365858, 0.03784146460313951, 0.09096645224358767, 0.10017275299516418, 0.027759280205974658, 0.023131224311768048, 0.03936414862231862, 0.024345213201858347, 0.032952207200709856, 0.06351765598200503, 0.05405800229298973, 0.018494887007099968, 0.025600080543588248, 0.050500542781646215, 0.06117952499358405, 0.02861072373155865, 0.07416499493223044, 0.04095204970649174, 0.048289785401955734, 0.017048166351272695, 0.07289928744637197, 0.033534031827002764, 0.019573067660413442, 0.013943417880293584, 0.0595420963251062, 0.014092727459125943, 0.02463475613284015, 0.022745696309533332, 0.029104950034149715, 0.0353918639912961, 0.0733583043479631, 0.07662070509527, 0.035067540668551965, 0.030954293944242022, 0.052687704653268864, 0.03491347272609992, 0.09410445563374989, 0.07190800797674926, 0.06298721670323322, 0.020817443428020325, 0.05028834408749977, 0.027258413836299896, 0.014090195538536196, 0.011713735256043654, 0.02128570126519809, 0.009040320141901894, 0.03846622845758835, 0.04460299875767482, 0.017859005301650015, 0.06502296895750108, 0.03717043669894338, 0.049690822319638346, 0.04831914189121416, 0.023683276846103614, 0.056160932797337734, 0.05596002240875556, 0.009852185650097748, 0.027704236788615107, 0.024010700909721277, 0.04341362044215203, 0.028616766250061414, 0.047713687282896815, 0.04775931931010658, 0.07619431587837397, 0.011024466798370405, 0.038333978699219805, 0.021118826247871886, 0.03135627176943085, 0.04322641536653523, 0.09940317170994897, 0.03303729658645969, 0.06729383742617023, 0.011438047982782367, 0.01793031659608166, 0.05054499503345259, 0.049818295519799, 0.061707834547926346, 0.042589735014424215, 0.05842738093868379, 0.015146110803940365, 0.054554507707155524, 0.017708149182820515, 0.013387789630571441, 0.06515171003317641, 0.030896069346776897, 0.014010144138498413, 0.016195805435399377, 0.04605265927591151, 0.025327724795187675, 0.03038402383906707, 0.056931261018279104, 0.028473034748927723, 0.04579404331443291, 0.02496338870015837, 0.027369088643500884, 0.0378775971400882, 0.0711125559023311, 0.07735959689823851, 0.07006412627355707, 0.05056645315621169, 0.03081104890894025, 0.013073267445208566, 0.07959855014398214, 0.11331352044738109, 0.025183853483007803, 0.02470904942451706, 0.06079124482048135, 0.06742778789973067, 0.02546192999298294, 0.05442885396581504, 0.03158909546571874, 0.04440329112713376, 0.055892480266911376, 0.050640744532668786, 0.017192991442918297, 0.04070926878240801, 0.08117523570094379, 0.08751875781003507, 0.07961202563057024, 0.021604033780374357, 0.03371483240757258, 0.023989608593946023, 0.030868020952649178, 0.0181289651100674, 0.015599294903598007, 0.08237777157656609, 0.06956937903117749, 0.04756490151668268, 0.06529452414402077, 0.00989217927018481, 0.0515995571960605, 0.00355137892784701, 0.045743316802526676, 0.013943467676008662, 0.0252697242784404, 0.018059980807705753, 0.004011013966632046, 0.06332529513465782, 0.05425070787990286, 0.13695042790664783, 0.0315106078426564, 0.022806343660058997, 0.020405008502665068, 0.023215618472726598, 0.023648760754675157, 0.025419846868082404, 0.024441744110757307, 0.030076780446594762, 0.02486342380213882, 0.05829943659444971, 0.04172901224885737, 0.020384873796795166, 0.035279670414785226, 0.02462363828183903, 0.03817212730345707, 0.015831287394488053, 0.07057339088210175, 0.03820337219944885, 0.01696948529100947, 0.047011299569520264, 0.06248790740726456, 0.013757535263956075, 0.05841135054886822, 0.02921883474975344, 0.06359590803303065, 0.050401637000181986, 0.03698105593362162, 0.037271299835054145, 0.05526496232637475, 0.046079054835342595, 0.0931056455198315, 0.04571511327559429, 0.02614903999792953, 0.037218190789703405, 0.043401952923065236, 0.034750181085039536, 0.0457344263521654, 0.03562353664047776, 0.012369852216403571, 0.11185474348284545, 0.06761806115748421, 0.05942942394364265, 0.07601257684009691, 0.04300467887773149, 0.03298423733682402, 0.03597324428659293, 0.06863851325526353, 0.07438188974535273, 0.02746596429196577, 0.028570720535372535, 0.022253444598567103, 0.018546580705010605, 0.019509179757968075, 0.12714208163801702, 0.06907177428084035, 0.026323307763725042, 0.04840991564936215, 0.020595561382510973, 0.03639167768039531, 0.025621383533542676, 0.07379115934694007, 0.040665391096544844, 0.06546636532631613, 0.02848302262024053, 0.04461102735912127, 0.026634034941033013, 0.08188361422188821, 0.10860297603592758, 0.047588592785741055, 0.011360382946628717, 0.02590247268428005, 0.012851453390002493, 0.04144010517085272, 0.027267809904691194, 0.04659388507265718, 0.027493541542020057, 0.06382804799584613, 0.019400067770132617, 0.07089134801419512, 0.009565731968670603, 0.002854179066132694, 0.02586355924816622, 0.031185493534130436, 0.049733018442507715, 0.023631625283028812, 0.029366534586334904, 0.01980681449265009, 0.05298310815687141, 0.03497261854429399, 0.029495543792783737, 0.05614477217257504, 0.07409360319856675, 0.041676596513078104, 0.015727866482320094, 0.02633590224920021, 0.043199717202374054, 0.031441554592381564, 0.05825655865332773, 0.027212831604805206, 0.010668468612786985, 0.038953648068972176, 0.05188011774613012, 0.0047609041587659915, 0.07229639923260098, 0.03225230161220797, 0.05683107970042094, 0.015817555268445326, 0.06806819143915369, 0.05627696447434926, 0.05890790958918872, 0.024732893911160292, 0.03126950465112684, 0.026564412870474403, 0.02272686586835452, 0.058794199158587766, 0.04061126315425481, 0.08719518525345672, 0.04566250218739433, 0.026521540675011855, 0.031183708549266866, 0.013702926601493552, 0.0493830694786964, 0.014644644970464853, 0.03524690483426375, 0.025306479261827566, 0.17881682653340603, 0.21282725396656224, 0.10254422413004984, 0.15002578677188966, 0.13176048865481732, 0.12179204533177039, 0.10343039633646127, 0.20023935684754005, 0.23230159204573403, 0.20004953558166183, 0.10482879791168437, 0.18802494291336308, 0.16399333163374857, 0.11431203178700902, 0.2702522854651174, 0.2025006185736387, 0.18102061634342517, 0.13052409935382106, 0.12176701723928414, 0.10696806779672062, 0.09631265044933367, 0.11231389061938371, 0.1738734909844014, 0.20673815731800374, 0.14315439177857292, 0.07664933380100035, 0.15742887742817402, 0.161998116921994, 0.12574248496563206, 0.10233436200407245, 0.14613534714425766, 0.14399103640067962, 0.11644747123242387, 0.11065452119275448, 0.09309774715333216, 0.08730934001505376, 0.16856353639835314, 0.16981350077736765, 0.1350322509965589, 0.24230466254295843, 0.1346135073371472, 0.11897827333380138, 0.09675306673612326, 0.0949756431603624, 0.11308412307933455, 0.15069536293946928, 0.10856506234455494, 0.1286058764784567, 0.14043795125138375, 0.14421205276683455, 0.2530224317865026, 0.18832924835864576, 0.11267094121825312, 0.09029738935491732, 0.08385044537604817, 0.11786055871315541, 0.1838685022366624, 0.1063533818289157, 0.1109984563663602, 0.11078216676269809, 0.13253892591643718, 0.2159644453035247, 0.2771700900648871, 0.09873866704442809, 0.11233066794492545, 0.09456027794869677, 0.08543897465231919, 0.11175921231868768, 0.1336188494197784, 0.17506466577610663, 0.14613804377375111, 0.14359470847393238, 0.14474799255690268, 0.1893317203728422, 0.10311543460815184, 0.1511066449024985, 0.1906216592197457, 0.10843606079898535, 0.15296993927369196, 0.2072291277469166, 0.09592265040884096, 0.22023248966903458, 0.09584701454807674, 0.11439814773057738, 0.1554375697648333, 0.10434803177392292, 0.17710975281173186, 0.17423359827408869, 0.14709217563992547, 0.13079383891196023, 0.15591092017148772, 0.16338305067150824, 0.12367028607836655, 0.13662822664745394, 0.11655541302095498, 0.14437124583750002, 0.14278578091292612, 0.1408366234071793, 0.08794298665898462, 0.06754326799343671, 0.08598442925440689, 0.16140973075262963, 0.1290756109501085, 0.11762408269268852, 0.23288682193285037, 0.24954224756408125, 0.10702182418636738, 0.14702086817593346, 0.062313618574051134, 0.07882919102426499, 0.1962521603150714, 0.16549376079872732, 0.22874541190122405, 0.23182168392644775, 0.18203067262807202, 0.10875179627609831, 0.1807946663710379, 0.16655154436105685, 0.2556344851731293, 0.17007861316444414, 0.11651578329263196, 0.1391574812512244, 0.10096047524242632, 0.18500462595012881, 0.1085954607133904, 0.1914673436793589, 0.12326414456530926, 0.1318116020411253, 0.1940982275071644, 0.13923442712233913, 0.1252215221944836, 0.11708566843862496, 0.15520421938309747, 0.19531407033003148, 0.21215219260944476, 0.15732770785689354, 0.1677486333515375, 0.18825565795263938, 0.18018168877930413, 0.1479975843141156, 0.22648107050166977, 0.12571659119379136, 0.2474727989324639, 0.11748509902146556, 0.15046190530542405, 0.1662709416761514, 0.17013861317067377, 0.09330245350757915, 0.12820409400568855, 0.11281104337784553, 0.133710841257726, 0.0799574546756283, 0.10693970722176376, 0.06314257167339807, 0.14687266080610215, 0.1389867968616947, 0.18342902823801965, 0.10546488837609369, 0.13051193387758347, 0.13548441141122772, 0.14236870732518936, 0.12977367026671288, 0.1645213807181966, 0.12097174902596783, 0.10138764586900512, 0.1264457153757253, 0.14401466255226444, 0.14187827315782348, 0.17411494657637613, 0.09523677955111189, 0.17932575406326404, 0.059223748488171454, 0.10635980164572116, 0.03528698655446211, 0.11630469542597571, 0.11955470087066775], [0.03949881921852789, 0.04411480922792708, 0.05047676724291617, 0.021715147172911994, 0.015446807017489789, 0.07889011799688302, 0.010583428065142324, 0.011977304933562636, 0.06569449864928761, 0.022013377540955142, 0.048242575233621944, 0.03158059955063847, 0.015472064936353315, 0.07168814074248075, 0.048711608734823046, 0.06047826725989581, 0.05438151739297375, 0.04571920035467033, 0.0481612243569426, 0.032835034052691156, 0.010480103871574806, 0.04491825159939547, 0.020775869751589435, 0.0063222531142884935, 0.02277620193067818, 0.09564112075754712, 0.029379125241370454, 0.031150224761316375, 0.028361570871164723, 0.10658243445739632, 0.022235225112507903, 0.03056536068118388, 0.03174689808680165, 0.08423050159528371, 0.028735301119365522, 0.019789640716607534, 0.03537881751394561, 0.08937780805412801, 0.05709508509044686, 0.06817028031594331, 0.06439115326370924, 0.05195694104317696, 0.03931146092532624, 0.032385164240915934, 0.02475523686547193, 0.02442960544759708, 0.06718231034615348, 0.024999655302493803, 0.09046095678763044, 0.020027082007859024, 0.012737616554894035, 0.03899081482461864, 0.0224172399424377, 0.021460288872701988, 0.023393297245004968, 0.034261941759576725, 0.014253621244983328, 0.02422340330667794, 0.045967366876861745, 0.013717482272054882, 0.011160920464223432, 0.06685607946447789, 0.06408469894179894, 0.035464125234753854, 0.06880504544824362, 0.06154485700291492, 0.00903439349419768, 0.03555040971766557, 0.03728697782442455, 0.028370378967074138, 0.08883265988721002, 0.00776107827644615, 0.05178819102565608, 0.019661656152757428, 0.029108129299035477, 0.029297670942821333, 0.016226971807378917, 0.07104445068586258, 0.011497672605929116, 0.0267954841406355, 0.06124247060788255, 0.032668720194769484, 0.04292068116727375, 0.07372436414082205, 0.02918360236611578, 0.052687275644031265, 0.02818038724663277, 0.0734901327579733, 0.03596586685988211, 0.07118154978079182, 0.0151008905489899, 0.031038893033720316, 0.07076258395588206, 0.03246188794653262, 0.05044408593206637, 0.051998440026035236, 0.0624681921345332, 0.009407773257173117, 0.035926298418593024, 0.017421766364526366, 0.06798760665039863, 0.04883392999369291, 0.1001785369589925, 0.05416742646165433, 0.0749750869468816, 0.07315767358147329, 0.035906625280697504, 0.10646064946007346, 0.02095077720080172, 0.0818949599840468, 0.06213053122102734, 0.04310672945012489, 0.041242125068580916, 0.02718359194395523, 0.021231996586486217, 0.0701814679609191, 0.059736617540399876, 0.015566582949231229, 0.005973426948091196, 0.049911585876778256, 0.01564495182866531, 0.06068989521853867, 0.0587150814282077, 0.02811097776547315, 0.024458584638552803, 0.05388243792338237, 0.029667323688045148, 0.06321117101657776, 0.028248498208760738, 0.07638032202638927, 0.016544279679956458, 0.03411035594199935, 0.01789356735835393, 0.019345980047458605, 0.01480572549025378, 0.004558212136954911, 0.02698782966622422, 0.012649183195354718, 0.050240203122337984, 0.10627989101433948, 0.03312339337782995, 0.08350386719910369, 0.012075877466779805, 0.010142374967765665, 0.05413900843010314, 0.09805957606482892, 0.05947456567458088, 0.09806228035520162, 0.030544427328652916, 0.0323460363001833, 0.023906465071523865, 0.05454240734839151, 0.05765195057216672, 0.024944996844316204, 0.0033538173011038457, 0.04892709011572504, 0.08057577190019431, 0.07195575823706966, 0.03651677217755107, 0.05469307769089938, 0.04781365409613617, 0.02232570967246448, 0.03244342139711784, 0.041784607249522404, 0.03788285633368838, 0.048866155482227766, 0.029662200475051522, 0.03502093187923874, 0.027496931481085, 0.046318369211568955, 0.018817042301018393, 0.06540699351218439, 0.05146191034826541, 0.03214341753552998, 0.059470777369795315, 0.032976013382956866, 0.010588693962011848, 0.011882449841998037, 0.054133787540899175, 0.04090144193821377, 0.03863158087516504, 0.1094011630442354, 0.2065628304356529, 0.03222381846318322, 0.09725434870849695, 0.03230502378315695, 0.01779917574998352, 0.03770419696886693, 0.005353451143169115, 0.04515154069409736, 0.039568705589420376, 0.08372047089881475, 0.05730754808492719, 0.038122377553654295, 0.04115445013608664, 0.029551784222524975, 0.039718199986964464, 0.01669407859745045, 0.11439745825144554, 0.022133839121388815, 0.023314374867045594, 0.0514922091256707, 0.06496728968716438, 0.014376748811393497, 0.030838434637013464, 0.047091420875081134, 0.05685333838506092, 0.04006237647826633, 0.045722479210986246, 0.02969202810838338, 0.04088441180365701, 0.02841250805725013, 0.008751867928602284, 0.048301261399061456, 0.05005948298100022, 0.055933462140420755, 0.03535241429363528, 0.09230630937963726, 0.04915473314242498, 0.03313674245991054, 0.066921710216951, 0.036719578633745836, 0.07028266817571656, 0.04123842103346702, 0.060066314969932845, 0.04206692214093862, 0.055044761843859195, 0.06699291808951287, 0.08066542716997285, 0.04871220628340398, 0.0053239897956260515, 0.011556162461338025, 0.01679994237248696, 0.021650811109030922, 0.031738247038916714, 0.07208851361346823, 0.042118679041103016, 0.07359550815195808, 0.05091965033282196, 0.047378355276680766, 0.03638703901801379, 0.11807322472093568, 0.04469524340463742, 0.0746447574948111, 0.050497528225664175, 0.018463720635120428, 0.04758694569670385, 0.033001738615454204, 0.016730289658411376, 0.022135204673113845, 0.0639054496892758, 0.02781506481340095, 0.015397461379067072, 0.06313324455291995, 0.04192565169726168, 0.025030540137161172, 0.064813306014384, 0.05477732054949288, 0.07337436921173528, 0.0996880644872304, 0.0090060836725658, 0.06269810661192864, 0.10272872874573355, 0.012172181422131197, 0.030381013113524646, 0.04458401126847152, 0.08479107111211746, 0.05936216908477007, 0.02523038757874841, 0.04699951713724483, 0.0376838764866754, 0.018386276806854916, 0.01834924603181501, 0.024921395590588934, 0.07816705357043013, 0.025522058318939903, 0.047122861123493606, 0.08957465434627188, 0.02998904039662692, 0.05856427702031309, 0.03581589365738534, 0.04925899004804031, 0.044553685677988876, 0.014261595262665183, 0.0061097479849723324, 0.054434752842832, 0.055690233054901325, 0.03547327232456977, 0.07140099566670195, 0.03348998177135664, 0.004203257746168323, 0.002190036137753557, 0.03973024671957378, 0.014756727464226706, 0.053091149536832694, 0.04524005066242911, 0.05064588881308033, 0.061788289101734284, 0.026984761484087478, 0.020653619355852568, 0.06337853824539531, 0.02978606731630862, 0.044199458113120454, 0.04918468718026434, 0.03874102419602775, 0.02659448182150241, 0.040552619123651136, 0.030830021076385054, 0.030222783398423946, 0.007725319686165501, 0.03553656650887382, 0.036994052615257046, 0.03723928502069847, 0.041330022166573235, 0.0663106095406317, 0.04561399350002889, 0.04790660737442875, 0.03905266110274581, 0.03076604315860858, 0.029078343800539454, 0.023275764035661856, 0.02913470680434858, 0.04734205036994912, 0.04751105702692463, 0.07585972697744447, 0.049817184692308794, 0.019639713479386225, 0.0577141415898598, 0.0401109962483808, 0.030008882073865786, 0.03962805825135401, 0.030324424113777858, 0.06914755569831019, 0.05750499192565199, 0.030622062678899498, 0.10747026907460344, 0.03882666516508307, 0.05699467777665104, 0.031511366269701434, 0.039289225223323995, 0.020457328477453803, 0.017713977196704478, 0.04403223644100851, 0.037799728133024714, 0.0245504328350146, 0.038547387812286615, 0.032366418069408785, 0.04804979686835601, 0.07778663728987018, 0.04418839197305422, 0.03516208740972704, 0.021226283485790896, 0.14551907537444947, 0.18651372723041043, 0.13387338979349983, 0.1570149294791683, 0.21923487465227806, 0.18157017717678703, 0.2952105107326662, 0.09827594227728345, 0.17736420125490238, 0.14055920764803886, 0.17206383808966608, 0.10672284305215844, 0.060426728694789836, 0.17388706606241966, 0.12834109350918763, 0.2218056818650615, 0.15052466322818112, 0.0737197752741556, 0.17148297490371814, 0.12614979859321349, 0.14189885027946966, 0.12855051896504818, 0.19340603642406004, 0.0697595220539839, 0.0955864757059082, 0.12578712490897986, 0.19496018367428936, 0.1040416808738824, 0.21764965487583993, 0.23658115837362506, 0.1738210292833467, 0.14095820156076264, 0.10305220171088174, 0.2310387727113501, 0.06555238933933359, 0.14853044443072813, 0.10572199514436145, 0.12129562801771587, 0.1883644577596457, 0.1730787973370283, 0.14040966728521934, 0.21030163061955284, 0.1520437849385123, 0.11063307073087462, 0.08952077538255723, 0.10371681362871202, 0.1110901264473796, 0.1096932264044881, 0.12817686724085964, 0.12696002084281177, 0.1334086808586313, 0.2894593354675078, 0.11251178645198384, 0.11821917979226959, 0.0926604182008774, 0.19686694587430648, 0.0928550121945239, 0.12140988237074307, 0.13461589753147096, 0.12203844219085672, 0.09578364375498026, 0.22283795469951248, 0.1862752593813404, 0.18010671941503403, 0.15579616020043052, 0.1759127404300436, 0.1759526689326571, 0.10875443161855783, 0.11585673317313196, 0.07649935676806396, 0.15998068566043533, 0.10034124637323041, 0.14886130248346638, 0.12107946098812165, 0.21107714142530196, 0.13123268471850505, 0.08410221251148371, 0.20415325408741353, 0.1361688343627799, 0.12381193573556601, 0.20142556738949594, 0.14047041805761476, 0.165454184696559, 0.16533796915844565, 0.1551941989530479, 0.16132058876176036, 0.15905851498246193, 0.17213309243802102, 0.13832175593462684, 0.12484971674219256, 0.14231529567510853, 0.2818127054600947, 0.13696861483397024, 0.1477550408772884, 0.1225986056810906, 0.20228401487392766, 0.11484150579499622, 0.11939087296806036, 0.2255997935970945, 0.07061501243902792, 0.2303573375027026, 0.19101820165111175, 0.24250223661863038, 0.1420447747072866, 0.13906009615428988, 0.22334243891940964, 0.17462966573094169, 0.2762113157058916, 0.03983697425874491, 0.14044921274387068, 0.14580327867259904, 0.15485554212524047, 0.14831788567525728, 0.13915931986224267, 0.2031302202733294, 0.10735703361851555, 0.0975606153388658, 0.18076883388623116, 0.14287340604970533, 0.09821653981963474, 0.15876027695353956, 0.13453236330420743, 0.1717668564449395, 0.15334362164139748, 0.09317991774409048, 0.13974505536738904, 0.08539431938721288, 0.12022696600686159, 0.13632868626906028, 0.11452852823441068, 0.10586123162459944, 0.12499366466316486, 0.210212028975929, 0.10748095600114715, 0.137356408541241, 0.16259558889414036, 0.14978679798303113, 0.08750358926913432, 0.20176713535141563, 0.14703799790192038, 0.10152093750695068, 0.18300124474110144, 0.11516722339776256, 0.14917522999307803, 0.0929512634813305, 0.22197334786816952, 0.14661998968691597, 0.17285741324866974, 0.13763976914267387, 0.16389470547437668, 0.11218147998255108, 0.17534660145400033, 0.14984036285069682, 0.14294603118492713, 0.04756787010738927, 0.09259775986955052, 0.151111455934663, 0.254098923215943, 0.16733598775200306, 0.19928203805560069, 0.12203149377338349, 0.1424496828187858, 0.1910825377149928, 0.1475789172634963, 0.06113005869631326, 0.20264902512633032, 0.12100373319680653, 0.1639640057880071, 0.13299415068280313, 0.12607433893267186, 0.11876677177966603, 0.17239492596878161, 0.14394404456740426, 0.21241542042022754, 0.18318772586362977, 0.07869016904864581], [0.043131589003267794, 0.040926538978613196, 0.03332215488978452, 0.024504825705662373, 0.05642221474479284, 0.011116712402942921, 0.030581710912707834, 0.028434372206609097, 0.0024751958487960963, 0.009869664903700111, 0.04353618301871804, 0.0335064220182117, 0.05814808443368924, 0.02543082107759772, 0.0340791340286453, 0.03245971608726728, 0.03233524978220944, 0.029706733166089946, 0.05976635707362045, 0.04116173946268616, 0.026562039913128943, 0.04084107804022009, 0.05630077065659627, 0.036808015823724775, 0.018116136967775323, 0.0314140520358999, 0.009755519718202132, 0.06403408734308136, 0.0273600890256104, 0.009574419405731944, 0.018232697245454597, 0.022657743670166503, 0.021265802131364905, 0.0450782950276569, 0.07004036988702513, 0.039211785225498105, 0.009181404809257197, 0.09501369474756141, 0.0334385734411978, 0.018926253880284006, 0.02903843445012406, 0.04339585103274834, 0.045028526125656027, 0.04940178500668657, 0.07438473959243105, 0.04517568778547068, 0.05192295738285588, 0.021066734184240623, 0.01558865394232975, 0.05190448700300148, 0.10457983465805169, 0.0492446527125374, 0.05091639062870414, 0.10609495738941817, 0.10184821792908254, 0.05274980374041104, 0.049027198655230385, 0.08239054226226385, 0.058842504832653277, 0.05120693713486676, 0.05353966337298194, 0.036860113633015466, 0.015582088568818667, 0.03732548140349888, 0.04884188198634694, 0.04601861815899611, 0.021206321149703958, 0.0823615228516921, 0.04333045010665252, 0.03913276708654819, 0.03934790755832388, 0.046393338575839035, 0.03909287688833091, 0.06035688828917281, 0.03210093604490882, 0.004629646963064349, 0.054561873642547484, 0.07360624870465649, 0.03684190372305532, 0.05819006222150019, 0.09291927931049178, 0.020566407906552477, 0.04065603716298938, 0.018928973492415204, 0.014818128453747881, 0.052928631644575834, 0.0331562087540665, 0.025313793486284635, 0.022540932498692025, 0.08479389031567881, 0.11059371679420434, 0.022204545206360282, 0.05538539134807164, 0.03497808841207335, 0.05123166262262291, 0.054733029176150604, 0.04987887392241148, 0.08074149203997466, 0.018514908715001038, 0.03649427983609419, 0.02660068138802965, 0.027580661060769233, 0.035525140307483175, 0.043446412835750854, 0.06493712880558546, 0.07739434664648387, 0.028209330048412088, 0.028684051752450968, 0.06196732001919901, 0.06609803546340236, 0.0153417878543898, 0.04107089292618536, 0.05209109069959772, 0.04085520470154382, 0.04839277060161676, 0.03932304800518098, 0.045599253968365734, 0.0450063823542047, 0.02612473394331192, 0.05315758085118667, 0.06500312728026221, 0.06706769593180188, 0.016101789210111867, 0.030618283950212984, 0.004364687793572704, 0.05068603948119187, 0.022432027354596124, 0.06761264491585955, 0.055930393958284016, 0.04944802990423576, 0.060540730238802014, 0.03908417029907146, 0.06937905214726925, 0.033273259328017314, 0.038484832902829495, 0.07646808505899484, 0.02843967736548474, 0.031153312095651225, 0.009714504328346061, 0.024175229782779372, 0.010093582827868241, 0.02099423545352634, 0.06853248668654312, 0.012391702001613956, 0.02530089065041994, 0.01759710665341587, 0.10169432618685308, 0.031192237023083918, 0.019339464469662598, 0.04004936064443281, 0.007488884364119581, 0.027860549368685292, 0.02851577479422333, 0.026726505583933285, 0.06033556423180046, 0.017987077965611414, 0.061793000542468605, 0.05565328463431328, 0.0569485133183339, 0.02257539304874597, 0.07797690288674447, 0.021767942122213786, 0.04254717883023043, 0.018290132772357717, 0.016012097551156918, 0.057453181399332906, 0.027984734136430968, 0.06026517607331757, 0.03793454045549997, 0.0331138096178972, 0.05004329554316017, 0.04108735232523853, 0.02471098571174568, 0.03316751621182888, 0.05128909623430622, 0.015182060437397131, 0.06721632464999153, 0.04792955170776095, 0.05553265259931645, 0.0705927269413106, 0.04532556905741653, 0.021783767583509608, 0.019559391075745225, 0.04417126990794655, 0.03586854304998152, 0.04081226930382752, 0.06947917983897271, 0.03921767644163582, 0.09167512953882256, 0.05051915105732699, 0.07668271225186125, 0.06165894281659877, 0.02342242390788611, 0.0595108284464767, 0.042835844590538935, 0.03197970454611125, 0.051770946386480526, 0.021351653774599397, 0.020573909822550994, 0.03325634027620958, 0.016369328180688526, 0.03184043359191668, 0.030015953065406893, 0.041675478024708654, 0.06496758846145484, 0.04304392173165276, 0.0163597846403718, 0.04515367041852686, 0.042523652270075776, 0.03689004851865672, 0.045127412754922144, 0.01672642282961357, 0.01768303490544279, 0.049886714832316485, 0.14174872768982766, 0.03468162004625605, 0.028892768576981562, 0.04134401859294984, 0.042512360134071885, 0.033072115282618234, 0.046094188902286753, 0.018670451376707326, 0.07067330406918641, 0.040632123728432966, 0.06367177372017215, 0.0798639076791944, 0.020556701572551843, 0.011383621266201861, 0.07941972223981734, 0.10205403511081973, 0.01614539110432229, 0.04090744423710051, 0.0313500338985074, 0.08335565216839315, 0.04789767478923163, 0.03897533218766894, 0.048037217704639326, 0.0020520553235039716, 0.020946117471002286, 0.08774904384007377, 0.023883231540000247, 0.021362308142406326, 0.04091211737343862, 0.008043693378567696, 0.07205924139388147, 0.040535297875683156, 0.07163959375071911, 0.06694989459168527, 0.06907704496575941, 0.04427741138985561, 0.0719244252409666, 0.019410442515847184, 0.050333175552828666, 0.04850438961218442, 0.042337921913713224, 0.13014902270609333, 0.004491543335344402, 0.0447931724239982, 0.03305818014327557, 0.02989284082075521, 0.041177444265133915, 0.04172152756983715, 0.08634317290758894, 0.07459361346498614, 0.008342540447389888, 0.03159785376591308, 0.0661056656991282, 0.03487476996416527, 0.061047076052355195, 0.03629709646526364, 0.07722090434042678, 0.034943185446243134, 0.05837072490624363, 0.014819495920692722, 0.01888291054074803, 0.048257012160555016, 0.03207104712454302, 0.015220847469003452, 0.04583196083624517, 0.03240405596912869, 0.12419200727656005, 0.07440441273032658, 0.018145725198630846, 0.007731645178395294, 0.10535431890598229, 0.09693978534590814, 0.033987283916963686, 0.04022579452383422, 0.03323631473786889, 0.04599258266088944, 0.022361003343136083, 0.02629074328128369, 0.030100810709559632, 0.04665209626358363, 0.08849903625706512, 0.08004015386705438, 0.03822751162994293, 0.021216548423493103, 0.07279148355366723, 0.03855550834428399, 0.016659125835905154, 0.009044237724024682, 0.02952920952661624, 0.07058125094420488, 0.006085061280417347, 0.03214843924187365, 0.02747488730106383, 0.03261946840211749, 0.024104008503678827, 0.022150139557197693, 0.040902847709554824, 0.0879563702150218, 0.019873490955139843, 0.0452935619039401, 0.03698383683278676, 0.002677568986508695, 0.03042518382801885, 0.02041184392216946, 0.1300167193215701, 0.017340235457184817, 0.004535966380048664, 0.04004931084871773, 0.05724839460585387, 0.03233363716712883, 0.06333813476826876, 0.13928485102951527, 0.0427668085772424, 0.03087674669410673, 0.04632676936565869, 0.031002159117751067, 0.042593676536794634, 0.008941603967198923, 0.02491846338905875, 0.044617259484385295, 0.023790044604890773, 0.06413727555604232, 0.051353033932466666, 0.02458720314016025, 0.0581915331103148, 0.07557482653928381, 0.014060658061005657, 0.028380995030484857, 0.02131296633442323, 0.11845302047027696, 0.014787586443426629, 0.03639731608751801, 0.05546821694400522, 0.053507376597413135, 0.003558098237150379, 0.047856669933084524, 0.04622622798647612, 0.03934064121436208, 0.19677455567063826, 0.16204440395437902, 0.16839338827037043, 0.180136029939017, 0.10638676794065584, 0.1157855636049663, 0.1167102087469351, 0.22250378714694133, 0.1308753047018282, 0.09582777041941883, 0.2500828298469705, 0.2116646236109157, 0.19708992342554754, 0.1746361468347811, 0.10564301914024739, 0.1642728771173185, 0.19700931565415478, 0.16027792777505614, 0.1777385118147058, 0.1365961275634266, 0.12309700716286899, 0.1439988351757488, 0.15572900493298808, 0.127706412646559, 0.10587174235092056, 0.11634874548162184, 0.0932080714753078, 0.18980956005473293, 0.20869379592758996, 0.14306345714196084, 0.17663295500941817, 0.09680975724252001, 0.1204531534665054, 0.07909827174678927, 0.15419221723512297, 0.12251134826651505, 0.0766767980530858, 0.1723780107474135, 0.2498951536272803, 0.1434217717859053, 0.16002450588970416, 0.10184861629480317, 0.13540046349648507, 0.07865110622538675, 0.16347488929187098, 0.102391267015088, 0.15462862688206858, 0.12576019691844142, 0.0793905955769362, 0.1743432714213287, 0.1825492069005005, 0.08967095159835393, 0.18107343044492508, 0.25797474588597974, 0.18174392591801383, 0.17720879265858283, 0.10081520965022427, 0.243591291890029, 0.1551696075306785, 0.10498431376031331, 0.14668296211429183, 0.13155215870468848, 0.13441550425223767, 0.2183861411627262, 0.11704246107969554, 0.1174311664315962, 0.12664867504950494, 0.09184370718656049, 0.14153344166134635, 0.06839402395510866, 0.13854160784713684, 0.09506912120888311, 0.23679658229793274, 0.11504156965642207, 0.09727082725974823, 0.07967748018282075, 0.18728657205018306, 0.16060608919830094, 0.13313210779620757, 0.19730318698190874, 0.15515857586456885, 0.15581592526887694, 0.21993566124189287, 0.12141517603829985, 0.09248830122692932, 0.151634770595739, 0.15417225298381623, 0.18792191940930583, 0.16006805032732027, 0.1200707606791008, 0.22691695920882687, 0.14224231813944158, 0.13411931933895235, 0.16730588049657885, 0.21320999149353276, 0.1454483348155214, 0.13762872215480576, 0.14508507124358608, 0.12403322789337366, 0.12377622071653606, 0.09580399105024916, 0.08194021279773406, 0.11395072940015986, 0.1045690251574401, 0.23803651092513917, 0.1541970895543214, 0.1425360362496107, 0.16719188661344592, 0.15320578710206095, 0.21057141614296745, 0.14640799783650907, 0.1341166073877004, 0.20662747293470368, 0.14119156726425694, 0.25517297848578424, 0.2046173961172181, 0.14848572021770864, 0.20386483730568042, 0.25216954610040115, 0.20018461220447095, 0.1309961474110042, 0.2204906459777586, 0.1534165685335475, 0.1643117484185965, 0.07252361325006332, 0.18189159702629815, 0.131491974837357, 0.2705622752827983, 0.14713248718650113, 0.1696976069961825, 0.08257962042285551, 0.1606831116782081, 0.20278505169816557, 0.21202462364829358, 0.14577364639168786, 0.34037871766955624, 0.14631432060512806, 0.14942885106129034, 0.1555012469930995, 0.18097167864682215, 0.13516712843650772, 0.08921255522798147, 0.1808813262370325, 0.09337622011380811, 0.12589029396974272, 0.1215369227312265, 0.16475056358162435, 0.17646974763802944, 0.17655144325427471, 0.1952168384506818, 0.14296774211670124, 0.21592338299078329, 0.1130766154176766, 0.1659605381709914, 0.13656913062497494, 0.08109460494691327, 0.10248669858781562, 0.10860882894766909, 0.15352709969926268, 0.16033956720944376, 0.13400791483300348, 0.1387386456612618, 0.16103874501441756, 0.1647390109757262, 0.09108095940562988, 0.1170855688471948, 0.08558578008124906, 0.18477772602871542, 0.12631700494356696, 0.143458835119682, 0.11110278988076795, 0.11144512393061193, 0.1868558467756356, 0.12845569260178075, 0.15341062369125505, 0.11307623237371446], [0.015635955083604543, 0.013089639701760344, 0.015475422316681475, 0.011855617612450114, 0.02916530435604434, 0.053317133983176564, 0.08538413041781995, 0.09412481825077727, 0.0538578694836507, 0.05969291222431968, 0.0766471964156916, 0.05670244587705501, 0.03692599719450359, 0.03759181187037499, 0.06529889850606842, 0.04378035822282395, 0.020578475706579707, 0.046966866469911994, 0.05606690316551155, 0.034216413154236736, 0.03395163018496768, 0.022707037597654328, 0.044602397378654256, 0.009905869261391703, 0.03983773651622957, 0.021531052414267775, 0.01719040015051442, 0.07837858576808246, 0.059820894872949976, 0.010103099555107615, 0.06860462152549336, 0.012578688742172335, 0.02315966724117677, 0.038838244584058566, 0.05368487916946892, 0.04824449428387227, 0.03942332125359005, 0.01752554829562864, 0.03515159200516439, 0.026335668592383305, 0.0737351813023129, 0.025895371049221967, 0.01934624626301229, 0.025589962437328313, 0.03248152661047155, 0.02807213902293194, 0.02583134908138985, 0.04688117953558122, 0.04466677174693154, 0.03244514509494747, 0.02518837340176106, 0.041540455028054216, 0.02852088268545847, 0.05755798988825372, 0.030402988345632632, 0.04938244894747773, 0.031702903572530035, 0.04324734105818695, 0.05383457274987333, 0.09694452743015944, 0.027528134242240942, 0.07280612349390023, 0.058707719323255365, 0.05362513580269391, 0.11285388301457129, 0.05491173067580789, 0.02251562478411342, 0.016801723526910912, 0.04473227226445752, 0.025014163092559865, 0.07024180504583544, 0.03697385470713339, 0.010662356188761131, 0.05468936216446662, 0.008757170214648209, 0.05329690926197556, 0.011545726428589514, 0.032178481379824306, 0.02503369833462902, 0.046997027351490916, 0.014113276810084861, 0.058593729270562056, 0.034645472187548876, 0.043666797179368236, 0.01468001141948926, 0.028547326125384822, 0.07835526605166736, 0.02512375771578762, 0.07775672921730627, 0.011735754538207285, 0.02128408865011748, 0.009846202503409117, 0.06160694842917785, 0.011172486476660257, 0.015396572717074907, 0.018062840230883132, 0.049479297782865264, 0.039144361827282176, 0.05862720731285311, 0.04893426452913592, 0.05671800895323677, 0.051501999729343, 0.005708347119751477, 0.02106203040438554, 0.05633659675837525, 0.057106323600296056, 0.030031439532796224, 0.009915727855367287, 0.04719163666689589, 0.03823578920996478, 0.02076503918355992, 0.011961962107659109, 0.03938209806238452, 0.06550316052931933, 0.01929409291234709, 0.033622626065006184, 0.01496902000414388, 0.0477276798788338, 0.1007113587712088, 0.03476167623434336, 0.04472946838265465, 0.06930179218010557, 0.023223400010817477, 0.014462176233439919, 0.12620883332865854, 0.026446962015583154, 0.09529209876012418, 0.02261503809882749, 0.043723717512142275, 0.04564355683302687, 0.026808475076611486, 0.026542713430019158, 0.07125851097366503, 0.038294314496940186, 0.024582160366398674, 0.013565243364522054, 0.01923595449977344, 0.1061138108132347, 0.02946611260995269, 0.06137477399240579, 0.023974826927447034, 0.026456350423095208, 0.05068614290306165, 0.04356687633140434, 0.05537857699598517, 0.07662606004986071, 0.024187548476601803, 0.028330904371555776, 0.0062544873705314055, 0.04286562242815572, 0.022191014178397677, 0.018086397434554754, 0.006817709945607931, 0.030502148851331685, 0.06449210833037092, 0.0439948283676659, 0.03869915749096582, 0.0327211627436261, 0.05364112788811327, 0.06135882787226189, 0.01851641790821187, 0.04934286135399053, 0.030107841481484716, 0.051318747667415496, 0.035933346427496404, 0.07099295425559245, 0.022260636248956286, 0.0369819292738553, 0.05860045169209761, 0.02298395156920437, 0.027504868151980544, 0.028366489155638604, 0.02666726591996849, 0.051726563082587336, 0.0627533300599504, 0.019418202986520146, 0.02850564519664453, 0.01130794805865134, 0.012718294859833777, 0.009270368684684078, 0.0184491649645591, 0.038401758328320525, 0.029076078095503395, 0.06375987000102479, 0.057630166862039804, 0.026605559452887506, 0.07285074811548957, 0.03683414708282198, 0.029641293935597907, 0.08919390098702523, 0.07465169059052583, 0.0605102131263383, 0.024567275278029904, 0.0517147614981138, 0.0427819847790224, 0.04154392923679083, 0.032488609093331525, 0.01069748132008939, 0.011343489750288429, 0.034147748693583474, 0.06264476774020061, 0.03224422704548605, 0.1146404077148726, 0.0257764493055161, 0.04105475145362077, 0.04533092018156763, 0.0465247877723267, 0.026281789628668662, 0.015500103754381982, 0.06122108526347626, 0.04814648099483983, 0.028393993627340085, 0.02788738925911246, 0.02741280736611976, 0.0595679403012318, 0.018286765815930504, 0.018877187863953652, 0.00867702305361989, 0.044888684435957865, 0.022617600662934206, 0.027191406040782892, 0.02798560556144484, 0.009592501953574679, 0.055172407413802804, 0.03216358863057629, 0.0673705917753039, 0.024063545654738144, 0.025454102489616603, 0.03074634320763571, 0.05857581430445275, 0.0506622945859788, 0.05181352938375166, 0.027106881644877217, 0.08217350955331519, 0.035662055541310585, 0.0050679076699570065, 0.08802098207055561, 0.03131687186748511, 0.024456730705776045, 0.05099426729664688, 0.048269143162835995, 0.06300042405904782, 0.02684036731689928, 0.03915604466812746, 0.02902615980635728, 0.07112669022453409, 0.05713888999795722, 0.04418386822386135, 0.04895256636964698, 0.0738880081823276, 0.03620147337055495, 0.005751703865826131, 0.03854172259208657, 0.06628447062065525, 0.026224114699289206, 0.04096998382479914, 0.027599455112771645, 0.03656221268277976, 0.03423694814104707, 0.09509437146686739, 0.05695163895706496, 0.007628663809173891, 0.03204150868940257, 0.02133795229207364, 0.07566774534361978, 0.02343747178993879, 0.04148703188665452, 0.08616043029413109, 0.03952199337823738, 0.04584882243145858, 0.020461338947737412, 0.12146169289706216, 0.031781444821747086, 0.02521405649942256, 0.0476200636776705, 0.060172613499866384, 0.07727820771716296, 0.013856054171018544, 0.020257322072622277, 0.05574395880103112, 0.028464061944114587, 0.040371427838239944, 0.010767984391760924, 0.0753952631907117, 0.05533837653215855, 0.025851993235729398, 0.08257356066737445, 0.008107156102215091, 0.05292402745615091, 0.013517086119991879, 0.05063125270328695, 0.08372231717071227, 0.05971307948892636, 0.0653821339590415, 0.048957323775656765, 0.05766148070594477, 0.025196756318872495, 0.06394302247152214, 0.01936358474795857, 0.03146481302176272, 0.04370638477285543, 0.014757989594081958, 0.0144820571726849, 0.03904563607648015, 0.056754536025466464, 0.024713408464806217, 0.02479547563369476, 0.026412118421567064, 0.0629113816596087, 0.003196568417948701, 0.1150994552599807, 0.019213002505562, 0.06196992854858118, 0.016496203832268234, 0.038229361732280066, 0.029191336023711392, 0.050325832600074435, 0.08037878771222408, 0.020753088211941145, 0.029822757182222222, 0.028321803247015324, 0.05484482821738047, 0.052667085396786856, 0.037151173418087345, 0.007668829320238964, 0.056939561580938686, 0.052881873468117374, 0.009216567287371765, 0.04763839616169853, 0.05433341473220818, 0.017527543954671394, 0.04874370015797116, 0.059158428001307675, 0.028008168766034708, 0.029836098603423566, 0.026937331065475464, 0.030133792709919716, 0.030907394041517572, 0.023273268504248514, 0.008058426206961514, 0.06288023252460746, 0.05401042823289191, 0.05170762538909913, 0.039769642791079904, 0.013892338010332277, 0.030585723298211253, 0.013709473780416434, 0.0067349331877795205, 0.04489839843083774, 0.04274093395759983, 0.042873896177737944, 0.03308620363954575, 0.076284522731458, 0.18838515745535975, 0.11373670741675362, 0.10930962319816313, 0.11113365556323722, 0.16077734049289458, 0.1794744057640914, 0.17411821011093356, 0.1740557892668632, 0.1263753961651556, 0.2201761362413245, 0.20724464868826253, 0.16055178888622793, 0.14104697582942827, 0.17120342942014818, 0.10462830504102093, 0.11797394738682818, 0.18240875234046292, 0.16990140170579957, 0.14129538749975545, 0.14107210351334465, 0.0720671397603808, 0.12555526839869638, 0.083928877457736, 0.13844675084035243, 0.07169948650463935, 0.19477558712805473, 0.14619125624097165, 0.2605043682119539, 0.1361393552994536, 0.15656633903422665, 0.08153718160164934, 0.18808914108141778, 0.13094595333020534, 0.11018326986701259, 0.17875514113374297, 0.09610180006993395, 0.13520829800155856, 0.1293831033211562, 0.10526684698678794, 0.16834161604844755, 0.19787136375183062, 0.24592977527889515, 0.14260997905606224, 0.15234559293716185, 0.1186822186554632, 0.06746714949728021, 0.13910177133737073, 0.17198994124848999, 0.1480714811552917, 0.10661579758649874, 0.1437884674317414, 0.14218780332274977, 0.11938229278330842, 0.15298876971487077, 0.17921799613583475, 0.17763755674804413, 0.18933751199754978, 0.15424524584124166, 0.20504429095214416, 0.1720107788400304, 0.1509197960577665, 0.13370233768176648, 0.10694225063367237, 0.18631575478901788, 0.17783926769850716, 0.17581025318753335, 0.15664117050267037, 0.08709932467149151, 0.13526685776249056, 0.13923782855272293, 0.16566311219526877, 0.11523700634678526, 0.17231015067908073, 0.0964400125667453, 0.11469374275616101, 0.06847919761053017, 0.12425386121556645, 0.11002328006490586, 0.2371339367762689, 0.11647137317566142, 0.13508383935737994, 0.1165632194569034, 0.13035552936696237, 0.1519508584732971, 0.20060761531274166, 0.10241373637390715, 0.09076714680920686, 0.252003611456002, 0.09640274238922904, 0.10952020544678935, 0.23225705169381636, 0.101015396085718, 0.08150962541901297, 0.12161687932788365, 0.15367038878462008, 0.14116544366603898, 0.1031649851750943, 0.2013178554273421, 0.16937367437827974, 0.14451940724205586, 0.14512241036901552, 0.1268101740448225, 0.16541879143445723, 0.2502339177073971, 0.1458265064584632, 0.1328194673143087, 0.13142262855845113, 0.14418098024062573, 0.14153049988371713, 0.18734133201501063, 0.20614984775743178, 0.1293606263014578, 0.2378398101897009, 0.09975571005094437, 0.13429864520026794, 0.2565103841404761, 0.23588755768874, 0.18236583609494472, 0.13000047825757535, 0.1575500572160367, 0.14692003568333967, 0.1869923789655009, 0.110069444523223, 0.20125594020130175, 0.15204957656321988, 0.15464621626081007, 0.0974372522004189, 0.2255876587643739, 0.09722800294478094, 0.1939973950145706, 0.09627547986324757, 0.16830721870064738, 0.09336714963278464, 0.1787312545122639, 0.11830029318169241, 0.181889068936148, 0.11121120664381212, 0.08965827284320708, 0.09634721633647719, 0.10980798637554531, 0.2748467598951632, 0.18808537192883032, 0.13379567783446084, 0.09774885846362, 0.13963907476394408, 0.15266958684209855, 0.1203907096397973, 0.125477701996363, 0.16247398009704006, 0.2056810172695306, 0.1193139194360664, 0.08156284554711274, 0.18612732780316185, 0.1022738257362958, 0.1001357279657837, 0.1299611319817843, 0.09905209659688896, 0.1307019696480805, 0.197041001050703, 0.08275375220804446, 0.14293585753729268, 0.10585681895815557, 0.08718058361761993, 0.08688569339292665, 0.12350096532534208, 0.07199893495248211, 0.08360784831306628, 0.11928501493868329, 0.14535493337579314, 0.12282284727740674, 0.1285943545160755, 0.09400499443854056, 0.08827933756213996, 0.10331840960368996, 0.12660740589302394], [0.023680421253365856, 0.042256237788786816, 0.05981029604651755, 0.033334492735805056, 0.008319502268286963, 0.027634708563827222, 0.10414708691138415, 0.05835759415922146, 0.10512981683977189, 0.05869889015992803, 0.017087581574976925, 0.029606358411030907, 0.0842504888292282, 0.0435751922158224, 0.039347536005680604, 0.014051081961952152, 0.07358237740493591, 0.003064458470626344, 0.04462319666579847, 0.03839626930834305, 0.015972835545037544, 0.02774784442848496, 0.03210438727100771, 0.08769785384497336, 0.022255038061449607, 0.02755628988867806, 0.045994248902124744, 0.08121133376393588, 0.07915239585863967, 0.034800298557045965, 0.013655891675772447, 0.015455396778340784, 0.00838338059463328, 0.09961958388767897, 0.03510579526905091, 0.041939594497483586, 0.09610117953871528, 0.05447570790326404, 0.019340866410564032, 0.032034949061550924, 0.028173220494101127, 0.05355029667337095, 0.019393508142280965, 0.02264299073196467, 0.0407814993823488, 0.015745531512244094, 0.08148225309747843, 0.047527807539389025, 0.04315214697271586, 0.0592179951678601, 0.04343833443858931, 0.027886090740080804, 0.0771226152597416, 0.06430687593115915, 0.008689259392990461, 0.03335835637464639, 0.0654512887159663, 0.0455320795487252, 0.051954673422921094, 0.04148612407246425, 0.019643049792296464, 0.05185340809065008, 0.04706965631715233, 0.0759315707029835, 0.08671146201630754, 0.07867707660601986, 0.046152162605956684, 0.04156031968793081, 0.07257183848489678, 0.019801419318443345, 0.031959648364253586, 0.016099243882983442, 0.0212533091525397, 0.028442460179869688, 0.02033506659039807, 0.07849030437008028, 0.017584833924868898, 0.09521299252106298, 0.021125044966597232, 0.0551190187463597, 0.015062807360664012, 0.15583412751795786, 0.04157915012910963, 0.04522187905686517, 0.02429799728786513, 0.03224676662695504, 0.03619278593349361, 0.015544823179351948, 0.00999821158456466, 0.027997964474883293, 0.037544249301596035, 0.04407852730383316, 0.023910161445758516, 0.0911240441904914, 0.013756975062161446, 0.039744495954965396, 0.03255599035671161, 0.03788046613936463, 0.051166774975436355, 0.01076465861255964, 0.02162447492141397, 0.06369923031137836, 0.09039737148991517, 0.014553694054484369, 0.10830304495269254, 0.06322298409237016, 0.026872498959663416, 0.0843748938472521, 0.020426175512012937, 0.04173147139109431, 0.03625066770661262, 0.01592285118080796, 0.007324820410670533, 0.054281615697207956, 0.028355800313875083, 0.039455987242681366, 0.02487287924234425, 0.1300520512966379, 0.043291191930972764, 0.07089698642131782, 0.005804377198669939, 0.03135107577808442, 0.02990991500536761, 0.024902109327095173, 0.0547400810154936, 0.02026461906010105, 0.07743547790713849, 0.017178251911255143, 0.029303903068085353, 0.07233665715302191, 0.017572210711096565, 0.03677644534036517, 0.030963142259767464, 0.02915126004917247, 0.1405274609644567, 0.017868242406797026, 0.05695538895745432, 0.11954855684551502, 0.027555288228717063, 0.026018441159037814, 0.03474401407724908, 0.0496920480603172, 0.045178288653973615, 0.022651203194512956, 0.03814936300078708, 0.10773502140035553, 0.018176594711539727, 0.02784073450452378, 0.027684979253418507, 0.10848049389859361, 0.07464019927166163, 0.00368142307120105, 0.05387611386756744, 0.041875871303941936, 0.0312965743679313, 0.02527949764513441, 0.1276735551354866, 0.015774034771076854, 0.023461216685151862, 0.05862597774173464, 0.04219157613753792, 0.03251950541931776, 0.06936959862228363, 0.03367039930796431, 0.03776310146936486, 0.09320339833896968, 0.02171890866462021, 0.0837355858135608, 0.06860539527429689, 0.013408767033158051, 0.03480558839416312, 0.07945326156914234, 0.079681211031012, 0.034812012041408213, 0.02547406482570354, 0.02154920295241379, 0.10553205130441536, 0.07726673172005723, 0.04320044498590212, 0.05770967912770087, 0.05208747476459511, 0.03513453888796991, 0.06937180495550556, 0.06520081626912279, 0.007804853976854394, 0.035200671428033424, 0.018494155393132282, 0.02736413205463079, 0.08606656920164825, 0.03623436918602355, 0.050598287939905166, 0.017704410673750025, 0.04486268724224741, 0.04302164389481468, 0.05351804437175874, 0.008594047112931168, 0.0387407637261335, 0.035235670154854175, 0.06110289704895789, 0.01972213687915956, 0.06813697081299559, 0.07165366678588814, 0.015549596864730121, 0.05351141388077409, 0.016908723027295163, 0.054861249312037424, 0.033352013166633346, 0.0235935373066534, 0.046123143195384936, 0.034114040824915134, 0.06187162797657713, 0.012948581847482392, 0.050029597891074036, 0.02680678585273845, 0.03580089748626755, 0.027644533641456116, 0.03516768751245353, 0.08888789482655064, 0.03715576994563303, 0.08745797639412266, 0.0343185824702584, 0.05437179190677501, 0.0508364187102885, 0.05545549605402255, 0.03425547597749579, 0.02830999208644273, 0.030802342319680803, 0.026176408489024448, 0.1075164718373168, 0.04105151090170107, 0.03697377426790134, 0.030281279957102194, 0.0803092422504579, 0.041877740558477185, 0.03579388778176039, 0.11152543292771425, 0.006844294632995322, 0.04604399865192752, 0.02459157175654846, 0.02941590129217554, 0.05699342522289484, 0.01154918340034783, 0.03819865309783528, 0.023681150952113733, 0.06262216814643433, 0.035357627521960006, 0.03817084793662352, 0.029819047401448893, 0.05429069000867106, 0.0692864244563445, 0.0403144002531565, 0.04488524853161747, 0.03158360453052146, 0.010101598022776026, 0.041942180044228033, 0.1893282270119075, 0.01576603202509784, 0.07421517369127081, 0.04008292295639554, 0.09256307906921833, 0.026074101277176413, 0.0847208821364949, 0.05077895062464861, 0.033100284335594025, 0.04681630721015315, 0.028139788417085528, 0.04132400071548839, 0.020208403528217348, 0.054089588098107814, 0.05860729285726144, 0.05617505945866147, 0.03302425010910919, 0.05653308681963433, 0.010863469590643242, 0.020566147436658223, 0.07565145065347034, 0.03370720600228637, 0.028278534601051963, 0.061387291869088534, 0.03124157308540758, 0.2001574007614005, 0.07323750760406256, 0.07093467794719242, 0.09235206781135452, 0.06084550682815814, 0.02649238528383355, 0.06857357964280152, 0.04027956240479985, 0.02431499103324548, 0.060497526710312215, 0.038444433256142566, 0.0157254341531605, 0.03830453410985009, 0.038497201392367, 0.0736864657712079, 0.030237609114978584, 0.015760649299819865, 0.006648918272056167, 0.010613162810313366, 0.03743821507199638, 0.057509829770893826, 0.051746305168396046, 0.07773776088030108, 0.015447264755024545, 0.010394205305454953, 0.04917475101988643, 0.04577684464053281, 0.04949488384168475, 0.02299862598339396, 0.04299466227812152, 0.029882910406036727, 0.023432442422715888, 0.013107786409466738, 0.03411730435947257, 0.04183608452759443, 0.009192049600965074, 0.0487720569024884, 0.050733831876348105, 0.015826921650929558, 0.05050841050462858, 0.054013354688762664, 0.04318272920265313, 0.03265990252276102, 0.021593957808950258, 0.04599087811525791, 0.0028523258515633647, 0.05662767186520561, 0.03209467519134764, 0.008165967714552197, 0.05187088255620292, 0.0367991789995182, 0.03018891848173113, 0.06700260144087576, 0.05973426182003272, 0.03792008054592917, 0.004721944278571755, 0.020860384571396058, 0.05727646406739951, 0.018732121454611905, 0.06502727437163554, 0.030602468065016215, 0.021153489811225765, 0.0692287763400424, 0.03987364688768022, 0.009414162430461616, 0.05107279513932524, 0.02974911506528095, 0.04163599385309123, 0.005166239364282979, 0.042047145581173326, 0.025946691279269518, 0.03687001148899717, 0.14744943308253444, 0.1842205809249032, 0.1084160429215239, 0.16589620210711034, 0.11681667198577236, 0.08474191125001639, 0.24406153197971084, 0.1197415956806752, 0.17090673888883284, 0.230147153619797, 0.13542255747222132, 0.12730308267618382, 0.18152693917434062, 0.15032414737487995, 0.12747430332726048, 0.12210015823403675, 0.1605577796937958, 0.10969543273771003, 0.15573611422892542, 0.09277988961266895, 0.17494538588629616, 0.11698594677352137, 0.15422056248832136, 0.1291204270936789, 0.1702004517879217, 0.115264164163701, 0.18045744978852812, 0.17310534994448387, 0.17867494704982928, 0.17960807278511987, 0.10278305204044427, 0.11628068623042877, 0.1156747106823229, 0.17556199473479103, 0.15672830534317803, 0.1518967879876014, 0.21567334721405662, 0.14983351402465375, 0.11837320176944618, 0.1436576962230667, 0.14829147096362807, 0.14629987218687612, 0.1847687015129674, 0.1494781718018555, 0.19443118464081519, 0.10390353989937615, 0.1518073395615624, 0.16778201946327764, 0.1434162253093335, 0.1011153016119234, 0.17846588165529315, 0.09529638119162091, 0.21803922590709504, 0.18607241462074942, 0.17191939987242225, 0.09846036262329548, 0.15674252393505267, 0.20924763153156928, 0.16077947021732408, 0.22717997251499086, 0.07068675657313678, 0.15456055230911703, 0.18667393153713596, 0.16977136594153222, 0.1377822002095561, 0.1919370015422183, 0.11845731822353218, 0.16742301534020132, 0.11646567348150477, 0.1981921860527608, 0.125266085529039, 0.1238632636264928, 0.1328489616993935, 0.12619613159087398, 0.09731770417983494, 0.14620420312689197, 0.11987778313097455, 0.20092526600966532, 0.12379729579533301, 0.27995481966964664, 0.15489386184321297, 0.21729209099806127, 0.1569317936176254, 0.265766105224048, 0.14568176180604966, 0.15285542445077052, 0.12148873580078925, 0.10658005958483105, 0.19283861042030398, 0.14606465255060505, 0.08003643067974238, 0.14023355899318574, 0.13393758796155453, 0.2200225202907478, 0.07859353471787707, 0.1386909183835791, 0.13083350694467946, 0.13458013654716555, 0.2512367727655557, 0.23608615832223048, 0.10173175724283343, 0.14765813075486692, 0.24632869258282647, 0.06650872753872987, 0.3277760810188709, 0.21521754022086823, 0.12010094454331745, 0.23848681740703123, 0.14571936140137334, 0.1310551208594153, 0.2235126330126678, 0.11448202669740686, 0.0443688822880147, 0.13618312956344697, 0.14935097056290797, 0.1767388283605537, 0.09787494121419807, 0.16074832108232284, 0.20072517916560176, 0.16947395528756803, 0.15509223265032615, 0.10459829737702686, 0.209741405842285, 0.13687977927827066, 0.10291384623175669, 0.13985233832030528, 0.24456195593360933, 0.10452695926951786, 0.07858441061069889, 0.08407010576657711, 0.07734322559929664, 0.14171233851342432, 0.0839673197497764, 0.14575876896419834, 0.18478973828736814, 0.11636311729108134, 0.12568076126157277, 0.1953763532782755, 0.21532592634039543, 0.10266379513327153, 0.12313748724878797, 0.1090071716856572, 0.1871402492566455, 0.15337965841735565, 0.1296300287809103, 0.15256374413447996, 0.12163392478419889, 0.1272847195486388, 0.19398260951763202, 0.1884297131290359, 0.17676688250034087, 0.08089045017597177, 0.1244356692017567, 0.1036082819524792, 0.13997937101990948, 0.1959637282115798, 0.2630647566289671, 0.11068177094022114, 0.10943531524389984, 0.15413264623813092, 0.11701866638876739, 0.07400396325054669, 0.1571288620752673, 0.12869534022625417, 0.1056257132140379, 0.14971844761842681, 0.17692193869621525, 0.1319918931732255, 0.15433887710734723, 0.23245165334834209, 0.10089862896429916, 0.11615035935275017, 0.22207566657133643, 0.1279675720199462, 0.12947777646683878, 0.09512172846664345], [0.059962180638385404, 0.02577306894255021, 0.013364174970305495, 0.0440156621287667, 0.01784730713904625, 0.030775203654963165, 0.007683443883809472, 0.04106599379390959, 0.02470440501647611, 0.057887085938766125, 0.07401879471276077, 0.03286947353532718, 0.053479119444326054, 0.018906310696395177, 0.02927007645578875, 0.029917491614938747, 0.039895442089126, 0.05318278897433512, 0.03948532841018131, 0.04755165585647187, 0.050409669432068066, 0.013808301037868426, 0.04046353841981581, 0.01929309508282571, 0.018665651835861708, 0.039199523988269994, 0.10574749821136076, 0.023013809846053203, 0.1033001077631789, 0.03934978447373837, 0.06334685284884707, 0.06128163685301139, 0.12466868250480584, 0.01738045698842935, 0.05307217353894826, 0.03634359034138822, 0.08840105361154965, 0.13777458529558875, 0.03474197628337049, 0.027759021651300213, 0.016213810416839777, 0.05763653305269057, 0.013536292901863495, 0.07232116685519296, 0.030534617572782502, 0.06589047926207704, 0.05644609753583228, 0.039927004911606355, 0.01605291280054277, 0.02522615111252714, 0.06493263186946993, 0.008049587467535129, 0.05358684672823837, 0.03326995748906367, 0.036867778342697895, 0.021350811077882687, 0.052781849198283694, 0.03661238761138051, 0.035724032054384874, 0.03545671333408645, 0.04506492296293859, 0.02735675462791997, 0.07034551036814529, 0.04352217127058295, 0.029703013809217565, 0.012812518886470748, 0.030197219044390707, 0.038457533359647765, 0.044963060082086635, 0.06035848558249493, 0.017910915419399258, 0.03931734448058471, 0.11442259359624117, 0.03867186177822371, 0.0439101564998348, 0.05199034247667559, 0.04654251121645493, 0.033525612520714926, 0.07819093253102996, 0.015851046717275056, 0.01110828256294612, 0.02138473728160945, 0.02018852163136246, 0.03247675388270328, 0.03868634083999261, 0.022479438621010032, 0.041399724676363894, 0.026605207052442337, 0.03878014064544151, 0.06812851320231153, 0.02666243190516628, 0.02612369780939433, 0.035534612984666904, 0.0179181530350639, 0.04390784674474309, 0.013853483946032584, 0.021837759545193087, 0.05009502179980759, 0.0551449699747947, 0.08898380137379132, 0.056070331408972704, 0.05140361488766728, 0.029859876057373422, 0.011823501291444466, 0.07544436942665808, 0.01770595242569764, 0.0524762720470467, 0.007012315430573278, 0.04131187354364703, 0.016432233575371005, 0.03173975814734736, 0.0998157253789325, 0.05648081664056067, 0.044880946947922634, 0.0049500986689611556, 0.011067552540841843, 0.06907606437321633, 0.01543968048457417, 0.05013691148750725, 0.031614539160903905, 0.008372065475991657, 0.08001941586694411, 0.029823496457069155, 0.031739120379150394, 0.0582871217310669, 0.015151375743199982, 0.051459481849545435, 0.1107105452026571, 0.055622870943719344, 0.06371118894387638, 0.07645735216717567, 0.01692627027120081, 0.03995801232034161, 0.012095682754842265, 0.04912797752166948, 0.026254537965982195, 0.0864338317525483, 0.035210090479062456, 0.04235868289646122, 0.036047466715136846, 0.012030326836411993, 0.016209847827051437, 0.043425119421895475, 0.05622380946372306, 0.09223725421414261, 0.05727385553801733, 0.05703438028332688, 0.05463744821627775, 0.05623391033300469, 0.0202460146148599, 0.025338178064914483, 0.04407993307517421, 0.030693031148985032, 0.05112929795418055, 0.07084928978715213, 0.05355850913591924, 0.011375171316397047, 0.003879595413661352, 0.01887643326734824, 0.05276451262855723, 0.02238257446386401, 0.04126290903396664, 0.03992614689313116, 0.03123688271209117, 0.0333109661756504, 0.08913737901997182, 0.04688322115989943, 0.04020958410335645, 0.10352883097385207, 0.048749710117737134, 0.026444782495438576, 0.01870778284125751, 0.009187718331363172, 0.02629602162708198, 0.009635351166399497, 0.029998469023755, 0.06885064300149679, 0.05157872343495969, 0.04848110820016554, 0.06783593656314958, 0.027933379432426828, 0.00482286247725208, 0.04263905575498939, 0.0499200588092208, 0.029155937015950203, 0.08014673201908028, 0.027332927378255035, 0.0540867037770729, 0.018750262416658864, 0.03627313706543177, 0.08622069077025499, 0.017749196173803463, 0.06826328338995095, 0.018174240906392376, 0.02997953516070641, 0.03237805877541823, 0.03386998053399786, 0.01758612478302131, 0.0917088910336456, 0.014134601825067114, 0.02882458483650079, 0.02826293322047399, 0.074925406144992, 0.004895889329829164, 0.052255757468482184, 0.08412028452561748, 0.029067358099705273, 0.07051565849612798, 0.0043588645677382675, 0.031437863963806344, 0.016611908006692128, 0.03663695988155181, 0.11541184293286455, 0.04476897170647018, 0.0877024427116398, 0.08099244712221046, 0.022138418411956202, 0.03395183319826761, 0.02077924245367608, 0.0556490290158939, 0.022734524832377513, 0.018961922934038505, 0.02100204763513419, 0.08357374207867731, 0.07508657572250213, 0.026507580637811657, 0.049499036038234356, 0.0421693442659753, 0.04596344450668943, 0.027009036895188115, 0.0515810868162061, 0.06377108935867587, 0.04759278328668687, 0.020955925311652884, 0.06881222369209414, 0.018958241881562338, 0.052160088408498034, 0.05131196778928561, 0.03247354780474017, 0.16889433316405744, 0.06108751017299872, 0.039657759480178356, 0.023250456321083253, 0.027490142026856065, 0.05151536413318208, 0.05745455269671737, 0.006339925805091739, 0.07162374339156574, 0.08275105557855099, 0.02783368841084021, 0.013798603322356941, 0.0156868826935909, 0.05929639660603097, 0.034405736462964166, 0.08831541264249433, 0.03399942258012391, 0.012901122700573217, 0.013914418579529853, 0.010813644189657945, 0.021560328464294155, 0.030205050378196666, 0.06063944449828518, 0.016323941301614527, 0.057352287619705164, 0.012260274830154114, 0.059921926548404086, 0.026942257010828585, 0.03171090153045952, 0.012947053502073452, 0.07357595758813043, 0.043097157181511005, 0.01198052920611395, 0.04436096093887764, 0.06753779812565736, 0.03992438872134493, 0.01994324517586539, 0.031690058193259665, 0.0353510046918546, 0.027571841473540956, 0.026320387053513722, 0.03704336569494298, 0.05446574492980877, 0.016707646014589458, 0.0620878026670506, 0.08292155610697885, 0.016564299472637715, 0.01760822450441699, 0.0434596470046428, 0.07922055470126291, 0.08944101030788115, 0.014880295531193336, 0.08925875032981558, 0.03026319070599012, 0.018636034876709024, 0.02247448586257956, 0.05752639642225639, 0.06454948831589953, 0.04263659278231283, 0.04408185212542454, 0.07690310808679751, 0.08891103068186391, 0.06830528799083925, 0.08170637978060592, 0.011515048437661702, 0.045331889282791846, 0.031108630017467567, 0.043484744045042226, 0.013204028120174283, 0.046955903751715544, 0.03704784730930002, 0.11961837809893394, 0.014195931951455293, 0.003123899232671266, 0.07698461984194095, 0.029031941854965784, 0.06396149668181617, 0.024231474042960235, 0.019772076235723593, 0.08006066970166661, 0.009505652480818813, 0.06833256072094364, 0.06936009913202255, 0.01755400654679585, 0.02521487238306192, 0.10474530964969628, 0.030710247059863423, 0.03219175002267284, 0.08446005218091511, 0.0746883555585819, 0.01810905065447573, 0.038705477716341134, 0.031020761647772406, 0.05146692822416944, 0.01999098777530655, 0.05206977047266499, 0.03683920709356185, 0.030291773446445024, 0.045493740678554585, 0.06021577106308072, 0.05961585910089555, 0.025191223248839382, 0.0453053213535778, 0.01837479314886995, 0.08213353508542623, 0.04674165577237164, 0.04220968645606791, 0.0677381684222529, 0.04584698765087993, 0.05964154219855705, 0.04044903637540918, 0.016810907005903222, 0.003660127502723387, 0.19477439203089286, 0.0855428868183686, 0.10369363946900254, 0.12613855242248506, 0.07519447920663704, 0.14225100557650291, 0.16273864815312047, 0.2688489656054205, 0.07051712172406335, 0.16953156509947392, 0.15736656383641306, 0.09118714685281439, 0.12258542130791372, 0.07820371853848619, 0.17920828214095486, 0.09812509190411338, 0.09946837345318449, 0.192199754378488, 0.16473810699197555, 0.101747393097368, 0.13598780778627242, 0.10848348164149832, 0.1354184359191887, 0.13653013674962905, 0.10943579021841289, 0.10913497813406492, 0.1134337196427007, 0.07148233888250205, 0.12962694910745468, 0.15005549566159326, 0.15647721236511586, 0.17433193332004934, 0.22961688288036855, 0.1337826236962311, 0.12575369283196428, 0.19113193506435042, 0.18070754685228874, 0.12231108522222889, 0.14938801857492617, 0.21379100789706554, 0.2187046039128496, 0.08378835394978525, 0.08793277470695396, 0.1831941916457107, 0.09775334007797704, 0.24376257382813962, 0.11054772853610978, 0.20877950584455846, 0.17592269957305925, 0.16110220773806497, 0.2267078325272568, 0.1436466492351986, 0.10869584121410886, 0.1415594886507719, 0.2064984177629794, 0.12704196926807204, 0.10794488352633293, 0.141075458978453, 0.10350203321826074, 0.08191990380686137, 0.14965521472115673, 0.11486769068024813, 0.10731239367516772, 0.2476932330717964, 0.19223163895789655, 0.18248975847757634, 0.18918625559777985, 0.17022764790923367, 0.17767307258421378, 0.16504418976124258, 0.1019215018999192, 0.23552987123689345, 0.20637893869030863, 0.13897080094583575, 0.09298545398539113, 0.1504833557673039, 0.11735998154167207, 0.13645987116521405, 0.23119160725224405, 0.2232413459569216, 0.11059099718207314, 0.14287976457947685, 0.13730880383762623, 0.10796633398821277, 0.19598006120612546, 0.20857286128786304, 0.17892564166217081, 0.175924553505836, 0.22342051860065232, 0.16155101268762545, 0.13161194420629932, 0.19151044378597892, 0.15062695128783105, 0.18455084142906053, 0.20736359149938632, 0.11121037926885391, 0.09994016870135262, 0.15315979118308715, 0.19734673141952486, 0.14163746107970515, 0.15819642091951064, 0.10752987071511247, 0.09304815828199349, 0.1515041066393737, 0.1364851673884738, 0.1484138611704111, 0.10344191063796321, 0.15632284564837334, 0.13086392063527338, 0.1397421135897598, 0.1591544904776158, 0.18027164282337313, 0.1289394464824469, 0.21275321922955975, 0.08928810681907401, 0.13927228718755708, 0.28312467699570043, 0.12610898908948706, 0.22011060508028155, 0.1998564201377092, 0.21960872555932692, 0.16469874539442603, 0.09901314868681854, 0.10528145628350397, 0.2789758512329671, 0.11766156737482357, 0.11808571195410145, 0.1938222826368386, 0.15490636439813724, 0.17650357808076567, 0.18545549933708486, 0.08003631576655373, 0.1144964597939003, 0.10057931585657982, 0.18332816510190889, 0.09541261971237198, 0.22833028417681495, 0.17454792414942097, 0.11824160318581328, 0.12343906542106022, 0.1255791626810547, 0.11957366920767293, 0.14923014317549047, 0.18418390063508866, 0.18042858359554123, 0.17315726006223311, 0.288378477336899, 0.1744976228163127, 0.16736198877615316, 0.08236344573238204, 0.11197776188172641, 0.30624073659700735, 0.1731906921392487, 0.14113204223254036, 0.14164512195894796, 0.12627215815647957, 0.2563109714537859, 0.07456811039798683, 0.09616079650098279, 0.19580470368025765, 0.1569099601117834, 0.11222004484865936, 0.13043921681181078, 0.12185623583894585, 0.13208773077255295, 0.17775484480925147, 0.2038363081913802, 0.17785880294057632, 0.18466454419878223, 0.22792899200031835, 0.15061896865166005, 0.1415882322696909, 0.16034211062135237, 0.14120707288384438, 0.08334098158464318, 0.1265084579767239], [0.06734404682872758, 0.06762356166878054, 0.026352604881169337, 0.03206101328795476, 0.023055138374348322, 0.007602420988522711, 0.03762655012730149, 0.002897742177141951, 0.09840132022697119, 0.05103854717867029, 0.1010722015053034, 0.023211671204696742, 0.07431757666410939, 0.026648293752523682, 0.054042090646802425, 0.015244106855994512, 0.08696798655775287, 0.008404099442545445, 0.011338415375399974, 0.01145664572475418, 0.046306092652582356, 0.04214321683731772, 0.05705616399345379, 0.033533438108861446, 0.06156977018221252, 0.031338833693054416, 0.06531107930406448, 0.0427550146536481, 0.01685935440623472, 0.023913214306136774, 0.012880521638679409, 0.05936647832934415, 0.029005709089218613, 0.0038374498047144905, 0.04855118992347871, 0.08573964117996155, 0.07494684894599261, 0.12699005148944356, 0.016547365099071495, 0.027972371392552892, 0.07754263828598684, 0.07063761203279419, 0.015236557059500729, 0.030809315635011564, 0.06692969285312199, 0.009693202296001537, 0.06611718000063012, 0.0386631973238001, 0.050118502394686786, 0.03835103181641429, 0.03351505199867872, 0.02418648169916724, 0.019269616403166327, 0.0475836247055521, 0.00884452339021429, 0.055942773939140385, 0.019548460916285555, 0.0297152980290834, 0.034817106526104674, 0.06312816538998196, 0.028378436296817758, 0.05401171143016508, 0.027690173329545126, 0.019678556052367055, 0.07769934923177765, 0.019879322799463427, 0.043945997923372254, 0.06404866216584079, 0.04775614770610006, 0.033374352290505366, 0.005554560235806651, 0.05404664120907265, 0.018682984575148553, 0.02791915317967294, 0.044810397910975644, 0.017927847877745668, 0.031457558169119784, 0.03369675656299918, 0.035084505685635155, 0.036859845502241965, 0.08366509040276851, 0.043186172767872774, 0.06604202677525821, 0.04605706811191575, 0.05293549196193776, 0.12245877165227168, 0.03569510457436404, 0.029176920164196245, 0.04645641442508467, 0.04621770908875812, 0.016507974773224805, 0.056731139700258934, 0.09406332437309528, 0.019083054841405923, 0.023752498635721785, 0.011246362250418434, 0.007114317643666461, 0.020323190312351913, 0.04029451261064218, 0.03826137654663574, 0.06888624310733811, 0.01804140126032214, 0.05368166160018695, 0.028959069656388416, 0.03497107870756619, 0.058010705716667645, 0.03838432599760352, 0.057282485518484354, 0.06569806861901475, 0.02534026756972796, 0.0276152326935722, 0.05378170885265835, 0.02390825388682706, 0.030314710118897983, 0.009784921215126112, 0.06693797426358347, 0.024608691906436317, 0.049366426218541405, 0.022223239666932536, 0.07691930318551679, 0.02838242569968345, 0.004954173299108422, 0.020556435356998158, 0.003116497865712811, 0.030786016986014384, 0.11138887775521125, 0.06886584984679377, 0.018701504750718034, 0.04307868297121698, 0.03285703609787649, 0.028104548372568625, 0.036056426113411304, 0.04975035501223418, 0.032260560040031715, 0.04306169114105644, 0.08286317254626945, 0.02614532447149677, 0.049981460756351875, 0.07379165730409085, 0.009749318236455081, 0.028689268811215318, 0.030309031492159254, 0.036555413652451775, 0.1144286839952392, 0.046162880176017364, 0.04822846006361708, 0.03822072026049418, 0.025218202950312726, 0.020760921460966912, 0.04008560426413052, 0.026088503730152885, 0.051446822246596705, 0.08314689320902671, 0.048278186830782124, 0.07385043156964165, 0.022847139757246743, 0.07265961683926082, 0.09027703439876919, 0.03908770962528164, 0.06281270187408214, 0.056209705785037055, 0.035564478922394976, 0.033590469524384506, 0.027234215033991684, 0.05877060365051993, 0.05255242884759942, 0.024867043567581043, 0.04194149822597543, 0.022016742582162543, 0.027063473187867674, 0.03545839489708024, 0.015701198961675888, 0.020186470430945198, 0.03061676901134272, 0.05907912640982579, 0.043611294109254115, 0.09118222090746127, 0.02045467398279617, 0.07090452472649275, 0.016236316164835327, 0.030758518259972337, 0.08769554792032128, 0.046604717555906505, 0.06765317096705399, 0.027967602495224248, 0.06046492966913408, 0.04386136052949775, 0.07468102409714654, 0.07415176459377812, 0.04516039284006242, 0.05206574085018328, 0.020350869069056168, 0.04079340821913174, 0.03115013091554565, 0.03570581065310586, 0.0110169849921799, 0.06206832871201539, 0.05969217677991237, 0.02135846621146606, 0.07796885130266029, 0.07280525015366655, 0.09036840570549812, 0.016524005163040374, 0.03377732602999576, 0.06110326477116155, 0.0033025995353161692, 0.04155737791030158, 0.10534193126424667, 0.03832148380517479, 0.07543684644324165, 0.06618811974241849, 0.11502858446610552, 0.07373616955573521, 0.02496192164178337, 0.03122144412519711, 0.028549270073492682, 0.06764040794223547, 0.07947597607609727, 0.019207473265968503, 0.044086578887917345, 0.07268606219440699, 0.014116221460543815, 0.055264445217025865, 0.00783346209397179, 0.013632580577846498, 0.07111136846604847, 0.06110283576192395, 0.01114637149693144, 0.06748231037730171, 0.0785482052953974, 0.04833664700028397, 0.0293883508551986, 0.04047814005565259, 0.02108988727653219, 0.029303657919949586, 0.06239843216814822, 0.05076758187985228, 0.07583201757722324, 0.03069423390702615, 0.016157887913587115, 0.019542977641967517, 0.02003250591036293, 0.04531614617594788, 0.06999048990227523, 0.027159730220333706, 0.03109052735981682, 0.011690405963529504, 0.07472608538885271, 0.004103286144879437, 0.04760519008062059, 0.03439032660436726, 0.029265962563635364, 0.05701853375461313, 0.015275109476680237, 0.013709607845803183, 0.048166414602629604, 0.010234945202096096, 0.006182332421773144, 0.036744319443260474, 0.06893798468574401, 0.044871424475023826, 0.0762171069941213, 0.044139438954692696, 0.042098718620235884, 0.030150060586991812, 0.05213980240026309, 0.0075414892278551585, 0.03412832836470297, 0.07532767125315244, 0.07961125188176671, 0.022752866892504598, 0.020489260937357624, 0.06719349522984798, 0.0616026621672415, 0.05300977950795524, 0.07782293453572259, 0.016714559958106088, 0.0232878165139306, 0.14183563270395802, 0.10010136126150047, 0.059651244702118064, 0.038916006338812655, 0.03603877927807551, 0.06371000916847298, 0.014988872215091703, 0.04233676895138718, 0.03822926597128953, 0.013989559355972996, 0.04382891287546485, 0.028416803895285534, 0.11397871459203382, 0.03296247277889521, 0.021186927633900798, 0.00592622539824656, 0.09296651629190292, 0.04870508932658742, 0.05445876586881857, 0.031686099433910944, 0.03917711591648479, 0.013451639228620598, 0.03098960868233154, 0.03509379833215668, 0.03661365548689519, 0.007457193700716861, 0.03168268651220828, 0.04654436897967131, 0.015203697633208528, 0.009126010906672286, 0.04527726721379065, 0.04192288228941541, 0.015338501337194636, 0.0420934594266357, 0.030273086646752014, 0.050270685760845105, 0.012054145467587778, 0.02482985765973647, 0.02494144028112773, 0.02637564306027226, 0.05992380729425819, 0.016756367291353883, 0.04902437562122942, 0.0256883415333446, 0.021851009035843517, 0.03989910015896444, 0.06081374865325709, 0.017250967061808033, 0.0027765944692110947, 0.036851479822108825, 0.08402055519963465, 0.019629172109548124, 0.06019707468728866, 0.015840612599746357, 0.016177775556101434, 0.01152260397981492, 0.027972128159636934, 0.02889884939988054, 0.042780939069005756, 0.02788484584720385, 0.061947463020201654, 0.02412627676441785, 0.042136161167535095, 0.05688267955256086, 0.024205465357930913, 0.0646609464480031, 0.022714372889529315, 0.01951550381378301, 0.023340469736966397, 0.05788923481539373, 0.03619691131696586, 0.03343584616818736, 0.017458063610378775, 0.03177335493326668, 0.2262009274695189, 0.24185046433441101, 0.15112264081835747, 0.12987261818301293, 0.06662019333171268, 0.22162079420541564, 0.12491563860807689, 0.14583471892101152, 0.24803670093176827, 0.1674757375111503, 0.3196206154121507, 0.17670417054285928, 0.14726681304314446, 0.1312903558174449, 0.16186425071810523, 0.2125361865206111, 0.1949127628317764, 0.15075265099444699, 0.12662780681444755, 0.1790218316619435, 0.09457958336438864, 0.18278412010160186, 0.09783080688888028, 0.09072791544660445, 0.18370541743934157, 0.20691521555906345, 0.11409048682018635, 0.2057153226867799, 0.15730063430964947, 0.09842700715507231, 0.1579896997540228, 0.1823576542759134, 0.1233089836915174, 0.133793915832235, 0.09568329389777877, 0.25286956660209164, 0.20758390306465088, 0.20665529724811355, 0.11914482084853996, 0.11450252721026061, 0.1902504742986733, 0.2600850729692367, 0.2100255172098837, 0.21160224873212077, 0.17653065162800974, 0.1418811230049018, 0.14578846253214345, 0.23623191421070408, 0.12046993845292639, 0.1762124493477806, 0.2025459863005146, 0.18037141811463142, 0.18969699109513916, 0.15151732931694678, 0.12961420140439464, 0.17048699931511957, 0.18397529489330708, 0.0749461824494985, 0.14092784915720263, 0.2039418444638291, 0.2066649499559595, 0.11352349748654712, 0.13579452380297646, 0.06803025476514332, 0.13122723017248417, 0.08938706239625331, 0.23387550436440976, 0.31608977745617595, 0.14984344252415244, 0.15691722262530558, 0.10696458975754439, 0.19114788501493393, 0.0747180108221308, 0.12834195918854208, 0.1020170713684732, 0.13945107678732566, 0.13324602507054806, 0.10726926292503074, 0.11036798898731509, 0.23879191958375517, 0.15400239596924475, 0.08504857624610586, 0.14587820207159366, 0.16301635502567216, 0.17695181612526217, 0.2638263705997698, 0.14727286513774626, 0.13879294597333477, 0.14345799242296528, 0.1834160966738578, 0.08909046379548889, 0.09172394466135772, 0.20705605316306316, 0.13994970809548132, 0.1145921748191599, 0.16751511443045833, 0.22280789340936372, 0.15358501594633828, 0.16588530833682708, 0.18239520790596164, 0.15486177808094412, 0.10288503366492449, 0.29910376956385953, 0.16012728424562564, 0.10625256465808039, 0.16498120201210822, 0.16113384716933773, 0.24333557174090417, 0.18520175569480468, 0.1591558694358795, 0.11556080106886164, 0.0713220579669841, 0.19707152199360634, 0.12377088874458306, 0.17827244445441232, 0.2100950320281329, 0.14922939240932465, 0.14020173570081113, 0.28111893623586626, 0.2474616293705279, 0.15111600649693321, 0.07365018384711397, 0.12289849079905019, 0.10080479851533329, 0.1620067430720214, 0.2572447866682084, 0.15242621603031314, 0.09213596206879424, 0.1295479041554274, 0.16538165149188813, 0.12354758177553454, 0.13871037701685585, 0.15354773810794278, 0.1837212448158572, 0.17021701460884464, 0.133609181390174, 0.21183270330150283, 0.12135503047536458, 0.16648008367947995, 0.12160015562849662, 0.17170420577449186, 0.09882954039400625, 0.09037650325485776, 0.20702390811376034, 0.12015601094331473, 0.10280374407527909, 0.06934882231777714, 0.11014675045566213, 0.2138898792045732, 0.10574081026378179, 0.09388081924689394, 0.15212128239293254, 0.09947575854077455, 0.10459118042021029, 0.18280219977661488, 0.07268646056012762, 0.1607686070905578, 0.17932796039648596, 0.08696956469887689, 0.11135797376834577, 0.19434860036257776, 0.09719327617917331, 0.1611975703628794, 0.16086772354620119, 0.16625539009128848, 0.19632447901512348, 0.0685209417415242, 0.12095689458111603, 0.20404376480127537, 0.12007944811616214, 0.0673040876825971, 0.0778291475087885, 0.09381137337655791, 0.1653965748846531, 0.19747538822552851, 0.1569443574595836], [0.018334652056857463, 0.109271694185032, 0.03131889050916559, 0.03870164344628011, 0.024339973160456267, 0.004330244001692101, 0.04489557539683677, 0.027590692982137687, 0.02763442894173486, 0.027980760055323763, 0.06032034206474501, 0.004651356458423599, 0.08604743232529971, 0.08354200305597437, 0.008764455710808116, 0.056156968292329586, 0.04006222326068148, 0.07517213242188578, 0.04822868222911512, 0.03006377035842067, 0.07878534781235842, 0.03327756091171215, 0.06956312775371537, 0.06621061974475462, 0.053626296425899195, 0.04487796303545756, 0.005570274135548501, 0.0436020206149307, 0.022019588598801244, 0.06158363254320237, 0.0279298305301176, 0.028556346810693224, 0.039283851116535165, 0.025967136250748753, 0.04303971590894846, 0.023946910683486252, 0.04204657867610936, 0.008565410746321564, 0.021772174757995436, 0.04516857465909374, 0.031054362264131347, 0.019924225127925316, 0.03715434885253349, 0.022414301995248086, 0.03272267959771618, 0.0266882969487098, 0.05069138294446373, 0.04228543723002077, 0.0536210717062556, 0.10833014148257433, 0.025653281519489906, 0.01992272742603335, 0.07470232900232077, 0.05634938276583149, 0.08379400767866643, 0.04170262435030553, 0.025298929465333783, 0.011634711371434313, 0.03749069209480959, 0.003654088814660246, 0.054199345515019474, 0.04699048879105718, 0.048460829852809834, 0.006664213217464426, 0.06011800292218405, 0.013780675907318872, 0.04565802440347691, 0.0388810612381466, 0.03329261453942426, 0.0968440626597693, 0.11291292541089559, 0.03485042368993163, 0.04751460401401405, 0.04974643647250149, 0.02683280219864701, 0.0439970308704482, 0.013560697590301355, 0.014728592885207507, 0.03922514196845793, 0.0308698863767448, 0.07920636675290524, 0.027864651769519817, 0.030790351128446, 0.026299093639658346, 0.03220225691855435, 0.06743603100579593, 0.05675843924344067, 0.048507572707509806, 0.08903180444312674, 0.023864109985410206, 0.031176524559756925, 0.02928774818898209, 0.04242633995149405, 0.017521700619028944, 0.033696185827495596, 0.11068275153276422, 0.030936424943408182, 0.0705620527808224, 0.042888777435667096, 0.04801052720135739, 0.024048687379446723, 0.021959743725376266, 0.06764620722782227, 0.04732617702815802, 0.017252805672826308, 0.09128070151012752, 0.03370912122209707, 0.0344131866680278, 0.022860885289828145, 0.012880468970134616, 0.03500275644323519, 0.03433192006102012, 0.06051752926601518, 0.05654309958880467, 0.051544004330231305, 0.05847974687874798, 0.04052142785381406, 0.01206581490189438, 0.031315671024663795, 0.021258271487069227, 0.05712938667725652, 0.01968894995027973, 0.006503021614926477, 0.042003156812561136, 0.025469167608647578, 0.017587203051774733, 0.015609959805113895, 0.060670425093943076, 0.027381920616232583, 0.027940977109415878, 0.04586163142155256, 0.042718008776465734, 0.023733539874815655, 0.03399244734957334, 0.014044066511785552, 0.011386161805280756, 0.05122038197793788, 0.12238023231827444, 0.025213439798643513, 0.039694271230649565, 0.011933685802373917, 0.08099580258731881, 0.024738034361132213, 0.07242213724361313, 0.05907575179251933, 0.016663444656578284, 0.05480291554704309, 0.04032175852766922, 0.014932576243975952, 0.04995845130554611, 0.06791669755212723, 0.04853438578485962, 0.01254655135374877, 0.05852378161263563, 0.017670070782544154, 0.09531926423791917, 0.05192871453360685, 0.026538298848355492, 0.021070974480901516, 0.03536515050537644, 0.04745350467161306, 0.051038815309443784, 0.01650153963466085, 0.01222803210464096, 0.04897817668895568, 0.01927006264938222, 0.051081497898145076, 0.046842741073980454, 0.042388491377594976, 0.03720765708074455, 0.01888337210872241, 0.07759355248943453, 0.04809612603557687, 0.017600268681323337, 0.11495574482626493, 0.04312120851189379, 0.08295295039011587, 0.027039379722649054, 0.031343112294111526, 0.027678975039311958, 0.04383663121130198, 0.07209344721970058, 0.0449110273902695, 0.03986873626408558, 0.07172065351398722, 0.060388803512098334, 0.06606792054709888, 0.0366655579437652, 0.06528082649193465, 0.013928631425745065, 0.018830544600683837, 0.018783185045204816, 0.08189238592862122, 0.010750002392958249, 0.035406205157238635, 0.0063931866316124806, 0.05505629912799886, 0.0743372651237634, 0.03136507986534027, 0.046826710684164885, 0.03402129822080174, 0.09183397020904288, 0.006376311629860392, 0.06064396824747805, 0.020767521308434587, 0.03598180914958639, 0.0336405448615551, 0.03184182787193887, 0.00400246610121441, 0.04937680287947578, 0.015200707017474118, 0.048742719565428076, 0.0457571370286807, 0.07217412393900656, 0.0364735035315877, 0.013830154653518431, 0.034807890488375584, 0.01746764162465209, 0.017657319249044505, 0.03147473194516234, 0.09999814623546216, 0.05454622246625443, 0.026385025722124887, 0.018774865330347133, 0.06979575801280237, 0.05737348527257001, 0.033739649825879646, 0.05921178602523381, 0.07524671874219373, 0.05567142942679986, 0.06089298512726542, 0.012429843604144071, 0.02082207251430279, 0.03927260877624635, 0.04341094296485667, 0.03610601498474998, 0.09487520137260999, 0.0366689938481056, 0.09725454789135726, 0.04073641893844451, 0.02339879584108149, 0.051157045658797994, 0.054637455877156994, 0.03821984308982088, 0.07265330427476475, 0.029280525895075935, 0.025451235405559984, 0.04764963467154772, 0.07682505904907182, 0.028247460159623337, 0.020030971819294557, 0.021925951587036255, 0.03300754556192025, 0.01249958920638047, 0.09353495353171903, 0.01994389826582084, 0.06313024914913601, 0.032427617003239935, 0.035983908230498914, 0.03481802966205343, 0.02480374746805718, 0.0406114048805208, 0.04638992182369675, 0.026482043096855767, 0.10591874950595441, 0.04127403646106682, 0.004889606930045111, 0.04809696490185396, 0.10778820322405909, 0.0536604639473221, 0.05149528496868668, 0.053176767523250276, 0.03153495220167022, 0.042594768212086735, 0.027429590437320933, 0.010434509191151348, 0.024792727293266405, 0.053001049936058066, 0.06686279805557382, 0.01248459112004287, 0.038976776263406204, 0.03381552317390039, 0.012890749870078459, 0.05255053661042645, 0.028517525305130312, 0.032323532467407566, 0.026211522129033844, 0.04184696680655883, 0.011247474993128451, 0.12493173411536602, 0.036572708087342407, 0.061567709405696204, 0.048050532312763315, 0.012159067912087327, 0.011303365895254238, 0.021493820541147745, 0.049739376972279245, 0.05525868040539565, 0.06531914620990716, 0.024909117116382527, 0.03386484008402594, 0.020533431651851824, 0.0344939936222809, 0.10247187478648079, 0.05259270208977884, 0.04338486916235378, 0.03067251339915299, 0.05449880545418109, 0.07646835318976834, 0.04009170232400779, 0.00637551489841914, 0.04820870265604989, 0.02725637795764112, 0.019268030601163066, 0.013802682740553735, 0.02699280349207261, 0.01129431743925858, 0.019987262672774737, 0.01960649399176961, 0.10367679319554761, 0.0990506716733498, 0.019036622252315283, 0.03162504222634579, 0.024578059880783962, 0.0500851967221787, 0.039856789122906425, 0.046637594219177, 0.024016758749982523, 0.0064062115627401064, 0.0346132964947291, 0.031221103216070804, 0.03683715014748516, 0.011093326611444356, 0.04590950808638046, 0.01299124336876576, 0.02002368632313465, 0.08390685242991294, 0.051517321487828616, 0.06632198594630727, 0.022664134758674813, 0.05002239283414618, 0.045258620633713664, 0.009986936685539061, 0.06002197380087549, 0.020092752979948156, 0.029836910656623306, 0.04306773940521864, 0.03596327748269804, 0.050860044861873316, 0.013775575676962975, 0.039253280377916755, 0.02951620326888177, 0.14586755344944616, 0.1837920466618192, 0.10663435989690405, 0.1619195622662383, 0.0891632727918125, 0.17774496227502826, 0.11596574748475706, 0.12716472719705876, 0.21416867392197733, 0.20922945992600536, 0.2804192834563794, 0.09954943321645261, 0.16039379091272432, 0.1529078248647913, 0.1111435151148227, 0.07271058466886321, 0.1613586633315971, 0.1330120771402313, 0.15212613939037248, 0.10106071784731843, 0.19328834999713207, 0.18442500382661822, 0.11453190668215675, 0.13425035101752128, 0.16511456259796697, 0.19275709866516053, 0.0985153447536211, 0.20152765626628555, 0.180521464095481, 0.1829738034716537, 0.260314746128936, 0.13148043755321734, 0.17457679034240786, 0.18537875264883044, 0.15890039443489046, 0.14239855411071933, 0.21187859196816722, 0.20693617572467174, 0.11154837726104645, 0.16366805070109908, 0.08558931174658, 0.22376642262022342, 0.14016834958907098, 0.10315560059802187, 0.18420692923809254, 0.16553399573651054, 0.11195340794661354, 0.11282038965052175, 0.23531812453462234, 0.1839153408523529, 0.17745620841460844, 0.1935847494150362, 0.15921393890053998, 0.11187541253504255, 0.24961084307682133, 0.18986401358439078, 0.1651615850747593, 0.054212234944345496, 0.17320533974036095, 0.09650215761916292, 0.15298763590474285, 0.09706444317294706, 0.29914645598300044, 0.12347471915305623, 0.14040151610970497, 0.19152938147946713, 0.12774358323264506, 0.17928076938035029, 0.12127743342951422, 0.15025432612146103, 0.23319275148453253, 0.19206499951260705, 0.20032678280145894, 0.09243534156872381, 0.0911536458278856, 0.0863865105014655, 0.08482458745880474, 0.10508263348451546, 0.10124766628348059, 0.1971191726624966, 0.21384579850541008, 0.10348957662861194, 0.12902190818661644, 0.09929996434478991, 0.1431146011717858, 0.16225507813355616, 0.14329429475530503, 0.09157267293982929, 0.23935621994878017, 0.13664292021384164, 0.1820993447496045, 0.13928511149940953, 0.19077530581383936, 0.1937300762942722, 0.18165872161907537, 0.15807755471717927, 0.11200618374371722, 0.20628621140795372, 0.13503507020012026, 0.13526327247100492, 0.09740930531294116, 0.11827891166772574, 0.13234725071778222, 0.09675724191531059, 0.07204693036093827, 0.18984178171282817, 0.07885459449983413, 0.11410407721996309, 0.16045029755801926, 0.08920474879203305, 0.18342718962700139, 0.16574257083477514, 0.10667971230202145, 0.1852840182161139, 0.09397382232090158, 0.13363415585650554, 0.18878775198132763, 0.1227992900737351, 0.15699490394082763, 0.1382437528621766, 0.15162925476268416, 0.10321994432278218, 0.16463324487690004, 0.11489841080601178, 0.12316500512702812, 0.15354137957817124, 0.10166260248590862, 0.21148519049729073, 0.09697747687178274, 0.1441265113892094, 0.14953945883579794, 0.16037186547633142, 0.15728993972222652, 0.09676769135459777, 0.0900281400930497, 0.11327304802234135, 0.11445045621404726, 0.2002949748308428, 0.054264470649462555, 0.08652071378404096, 0.13333369617260274, 0.3640444913218099, 0.10731618581039291, 0.23009663778206996, 0.15912107372235867, 0.08322439066344693, 0.130297367971751, 0.13066944155481555, 0.15529371377441192, 0.09460232851486053, 0.23305419682254716, 0.2111039391808933, 0.08477191891401045, 0.17098340896829484, 0.12171019649794027, 0.1572566455410373, 0.2024920077453698, 0.1555159405594872, 0.08937063747115674, 0.11254960821280557, 0.15211624153439077, 0.12791144075773417, 0.08893883201263605, 0.08366724310983574, 0.1656445575457427, 0.1271951945138074, 0.1594172739574025, 0.12913455375500266, 0.11832254803589276, 0.12607508203795842, 0.23080890036879048, 0.151835975928172, 0.16788671303900982, 0.11319156691071489, 0.2969384067241223, 0.1063602919419927], [0.005107110783067202, 0.02291188950860693, 0.06695829091533538, 0.03946062207462327, 0.02485274645169416, 0.035233747274164236, 0.03012105458295874, 0.01690835722031132, 0.02520728236695211, 0.06445930444545324, 0.012790127094053935, 0.0795376921192773, 0.009871031413035048, 0.03453505976546196, 0.03193326812658099, 0.058569310217975616, 0.09792642232270972, 0.05165142134853429, 0.015582065586180938, 0.047927418152891824, 0.03830651061669473, 0.039675306724084, 0.007927004302356152, 0.043669773430954066, 0.07742112141943748, 0.046601787269596136, 0.027350572298371026, 0.029134367810442086, 0.044854325392553886, 0.021407229623066324, 0.02684445248075551, 0.024135406617255464, 0.04945580186622758, 0.043366364308542786, 0.014897673278145734, 0.026469291563356118, 0.02129474684836403, 0.028295451737639886, 0.026446427669255968, 0.050249626003806634, 0.027137134457007054, 0.0856271488291602, 0.048065428892450954, 0.06849341620240482, 0.010115037120187716, 0.053200140865820075, 0.03462039812978718, 0.048022175568246075, 0.03424218052156991, 0.05356066950386571, 0.08144787873231596, 0.011219599926393601, 0.034411409344043464, 0.07619913457141769, 0.01572368747269314, 0.036229098501104506, 0.036924304140190926, 0.03672281918566554, 0.03305834485217929, 0.01986610778276959, 0.09360612309988468, 0.07560085820695085, 0.054966954123829646, 0.045490530770151846, 0.026766458984404325, 0.0567419798443875, 0.002011359296551335, 0.07009142964717842, 0.016072727664704287, 0.015547306261836522, 0.03167240369704462, 0.024157975567504767, 0.03966006540483044, 0.03540438952885809, 0.029947148793707454, 0.02672599996590326, 0.05485739205933867, 0.06519914619744786, 0.07923255929903639, 0.04964002302937931, 0.0806046917193359, 0.018955688893554673, 0.06770018578296708, 0.03277241785620009, 0.02176055511940391, 0.047161908624994184, 0.031835208872273084, 0.04135512686785191, 0.04729808075353504, 0.012758211871128411, 0.031436963810495315, 0.04606208215738016, 0.03280589972893077, 0.019988540124388474, 0.044269911389076905, 0.03657036768873373, 0.05913087564911093, 0.044937794502343864, 0.10043302370655922, 0.0750021681550049, 0.0696153213239966, 0.018866345804605274, 0.09922655013900611, 0.07591145323409189, 0.04581142201899521, 0.011257129616194196, 0.050682163076295014, 0.049584462502670866, 0.05527288367551181, 0.04258254527925484, 0.041240899327902064, 0.05885410340382688, 0.028872515127483397, 0.013862123502598656, 0.08030171926704147, 0.022222883436047745, 0.020416522804167003, 0.053161809656528704, 0.009962125012891428, 0.056880442575821956, 0.006071033252913866, 0.03243989356222653, 0.07003892964172749, 0.04358260028605019, 0.08370743974322274, 0.06744087268147739, 0.010997701601515855, 0.05096615570026541, 0.02322010583274307, 0.04209228731211155, 0.009265340275071081, 0.029663424300510558, 0.09867372577108684, 0.019388101476755355, 0.01725557125023296, 0.05392594788704188, 0.02325263392600802, 0.006551523599022579, 0.14393750217653092, 0.01729244497724839, 0.0064946932815796434, 0.060724514731836904, 0.032407924713146304, 0.03214117672835146, 0.07560166259927135, 0.03761723832858186, 0.05259427640046324, 0.009536115967127825, 0.054647836368530996, 0.03465251636601264, 0.013858405103336179, 0.03597738882226329, 0.03740778989008358, 0.02022447222242913, 0.03027354246906696, 0.01924936103844835, 0.08342959497484469, 0.02340584768042449, 0.10456036070301648, 0.046930193840976686, 0.026673697228092822, 0.028028016188933004, 0.019555524246947422, 0.10596470712053199, 0.03755116324511267, 0.061481551327292, 0.025122357690105998, 0.018970495457911206, 0.030623840002883828, 0.01939480474609281, 0.043080303247176835, 0.04130792052995774, 0.06526637041280348, 0.04065522127935002, 0.046703462458906636, 0.03615003439687914, 0.07305703261086056, 0.08065539141816479, 0.04776686144572112, 0.059399132827116605, 0.0326704592143576, 0.017577517785192016, 0.05186715170801167, 0.01147738659769417, 0.0409349506240218, 0.019660227398778644, 0.09288363323937501, 0.04461692240569861, 0.03283425264300839, 0.04778160863826352, 0.041616098549697673, 0.03299233105574404, 0.01733660994608316, 0.0537064598662959, 0.028253403086695942, 0.015054559466549227, 0.018987561981644363, 0.01698424014443111, 0.0641734961931023, 0.013251587816123522, 0.01858163688842568, 0.041617783943131086, 0.015582855614352853, 0.033814013980689554, 0.04322761046369711, 0.024711020185702273, 0.05445786188506792, 0.03468527045521525, 0.041834452760315714, 0.05775351850916782, 0.04723538794825154, 0.01715123582060539, 0.026687289543089368, 0.019585750245999907, 0.02979303680119976, 0.02539487431697067, 0.02639495039118394, 0.07132968820270992, 0.11693063522538832, 0.05109391618339766, 0.05292936708898314, 0.05489663491325994, 0.06188511878492371, 0.025614877531845725, 0.05478023168360514, 0.016282524673208114, 0.051374633781491756, 0.02635143851230462, 0.05260596690218776, 0.024097496756322445, 0.07373123594950284, 0.11090084144304838, 0.03930764963790294, 0.02217363355861556, 0.03346624453702281, 0.015745764211451095, 0.030726560902210976, 0.05719132105549497, 0.055048492692050435, 0.01678811589015588, 0.03842599735024475, 0.017825008234790257, 0.039327744124156815, 0.0115175717397623, 0.03706030389894882, 0.027017565369005167, 0.04157623516455774, 0.08418638259172441, 0.022991696718118848, 0.031106898658758694, 0.058923035995253635, 0.002909893049828468, 0.0519827735279837, 0.045065915046800534, 0.0706349843512139, 0.011639498463351161, 0.04628009162843228, 0.08160984504126734, 0.06864918486004876, 0.01329602474617141, 0.021817854665700468, 0.045531298139042435, 0.04096873893192218, 0.014828128773989457, 0.05471451666146036, 0.023255075831266663, 0.03219630824582231, 0.13544342570727871, 0.053182612774112535, 0.06443315786459754, 0.040006831273316376, 0.009131934681546786, 0.03342702083529965, 0.012205300360707747, 0.04171340703783978, 0.059282649158229755, 0.038407481005114895, 0.013022424104893881, 0.07935954603336512, 0.023430521457245754, 0.029180141563917843, 0.03504503683577623, 0.050763307109234795, 0.034663199462116726, 0.05538495850839442, 0.05363836997158585, 0.013485318368991778, 0.036245243804108714, 0.026571045276678862, 0.012372951999667191, 0.08575319327534207, 0.054475244420069846, 0.029970732810456428, 0.024629736341716304, 0.010082283030985104, 0.021768976340911562, 0.050979248142891356, 0.025066827806914528, 0.06275791509617722, 0.01043926468194132, 0.032644385411854715, 0.06861788250746266, 0.042445093783880436, 0.035760850240025795, 0.018297132900765827, 0.03203112819802857, 0.11077180925396182, 0.0234276122383533, 0.03616501524623844, 0.06986777793856398, 0.029425504204306393, 0.054996479152431416, 0.01639302328018652, 0.04021134227514267, 0.04475818901893593, 0.08976550983084787, 0.035472092549166376, 0.09688570719933319, 0.04959196250344958, 0.02268051371849593, 0.022822184443113305, 0.027067343847105102, 0.021223747734761527, 0.028354298781543493, 0.08244397689498241, 0.031586343294850765, 0.035105615238388704, 0.04198489710688592, 0.023396053246312568, 0.02211036618738886, 0.020210883737872207, 0.028488461844502922, 0.02637020000557025, 0.001626269999354507, 0.055513446775054744, 0.023663567319031686, 0.001975085272739131, 0.008656224724085582, 0.05901989249152042, 0.08502273610041988, 0.04589628540880738, 0.03338657522333726, 0.024205766047441193, 0.059199490314049114, 0.02896613298705028, 0.02633261956244467, 0.022774625704773975, 0.057834348446058656, 0.007712658167996956, 0.012812020929319965, 0.029218003544355595, 0.02689715166906676, 0.10622500081456478, 0.11085419434933894, 0.1587674935017863, 0.11727687632364613, 0.11830092903466956, 0.11861426665657952, 0.1504196938607962, 0.12545943846024815, 0.20164102195732056, 0.2965629929977079, 0.1776607845339083, 0.25734964878328387, 0.0859618449823991, 0.14997056715430754, 0.1782316732550821, 0.1026504728642683, 0.1896064241807307, 0.13864260887907398, 0.12071872550633647, 0.2446666648311, 0.13690414087426278, 0.09633828375128009, 0.1434257094778361, 0.11972950681323007, 0.12887595311528252, 0.15869086938759974, 0.08763795343017386, 0.16019394921679653, 0.17958766420281705, 0.14260530591972415, 0.1078795362263918, 0.1097917146680336, 0.1767626996602743, 0.22105483909047421, 0.13881146997934388, 0.11365442191280666, 0.0636052964405427, 0.09384939432023995, 0.1174405969739441, 0.23997160305659618, 0.09788728289065823, 0.25994595140218735, 0.1991542545898307, 0.1541526717764716, 0.1186936716699312, 0.18984916680041822, 0.15666377009643664, 0.15822772327209675, 0.16533018570513497, 0.07229707338997433, 0.1286833739328769, 0.08503108645879454, 0.1849814441295401, 0.25603588460193527, 0.11654254274382708, 0.21948639663957784, 0.15746882125254602, 0.11311789223503683, 0.1729303754625782, 0.08996775704285792, 0.19161515268346957, 0.1923838299849341, 0.15759643617897265, 0.15472117030332166, 0.11525078060766382, 0.25944609435335286, 0.07908901740466395, 0.13553616831139212, 0.14104285427639562, 0.12824632843295414, 0.10276946930154678, 0.16477250433977575, 0.18421630615428572, 0.12614242116650268, 0.09615158812413294, 0.20122060822623394, 0.27974782271250603, 0.14659417252386772, 0.18248153069326956, 0.11892113849640855, 0.11835544385136136, 0.14464596496714702, 0.13174824656978731, 0.09956383566942908, 0.08311202088671346, 0.192985515440664, 0.15094264079966854, 0.13410117837690538, 0.17285997198233682, 0.12045290065749038, 0.19428682303236378, 0.22072920575737956, 0.11283532836504521, 0.1043791349436487, 0.09068931227609997, 0.20184110880138414, 0.15235627220282633, 0.16416260642149758, 0.19016657234920611, 0.1782123218741148, 0.18452188330552272, 0.10362895866555553, 0.19403957581568151, 0.15267384629095757, 0.09249326547667866, 0.18163367054395138, 0.25049284010404543, 0.1402650145633567, 0.12334738001828233, 0.14007966725095627, 0.14243246116224798, 0.16077311168755257, 0.12054135316922782, 0.14933564880442235, 0.21581098257053286, 0.11870065839180063, 0.18636541260826975, 0.17874292969222993, 0.10190540639263007, 0.1744365196434721, 0.17150480840956012, 0.14408341128258936, 0.15061778887625665, 0.13093361931462444, 0.09361259654284486, 0.21830009416707102, 0.1371914085241095, 0.0962377040677013, 0.1512678451235256, 0.2504620586912478, 0.18128588194808654, 0.11056302731195766, 0.1911677420139313, 0.12816469410374282, 0.08361330285908715, 0.28457160258004743, 0.13154167862188432, 0.13876049448886227, 0.2686059625158387, 0.1558546433525701, 0.1346761120423194, 0.2068298733642986, 0.11677450650641996, 0.1427794223831546, 0.1736311773739515, 0.08078166569072394, 0.09700335532186494, 0.0861107494922415, 0.21772067122642072, 0.10793653316795827, 0.1398097285099568, 0.1468210571235226, 0.09297908779474036, 0.08107238839710913, 0.11491652878542101, 0.16880001241882003, 0.2617181272756669, 0.1306736550383991, 0.25150974521473535, 0.13953389089194038, 0.0635562016959152, 0.12598397120112373, 0.18848589801740265, 0.21346404157098264, 0.16726189172796666, 0.1692232606752265, 0.09738341154110047, 0.08465722022998719, 0.12508315139360007, 0.13924231782795923, 0.10094506921426905, 0.15182603210691484, 0.20586123179283836, 0.07721152742423358, 0.10091385113135462, 0.08020422691779752], [0.031736103907948544, 0.0818035580338009, 0.02523631326884272, 0.07681284760755878, 0.02980579024991922, 0.06642374540528943, 0.04844741565325568, 0.06032142990959748, 0.045490530770151846, 0.03211488076035054, 0.0248848972466564, 0.05300750422682013, 0.03736058738262903, 0.06387440397614433, 0.012990148820643945, 0.13641065767695829, 0.014658623202253255, 0.029693466438461217, 0.04238881696496279, 0.11323522626151962, 0.04172676761123923, 0.04141654413674147, 0.14678258418796525, 0.017752729754354206, 0.04356517561621243, 0.012167165461446972, 0.014546671901048433, 0.04417341878457416, 0.026430119572567846, 0.0219222552128016, 0.015615817504904926, 0.04597134287318876, 0.06430987133494308, 0.05571160690798875, 0.042151957900533756, 0.0166086099981781, 0.017364457242130753, 0.0298287671419882, 0.05496530320435282, 0.048958898086341164, 0.05012840791154773, 0.01829167452430533, 0.03468064711459222, 0.07530274275209635, 0.058275638073081934, 0.0391097882792594, 0.0267635555111713, 0.029622994010306658, 0.026099590937637036, 0.012162081510459465, 0.041955402721801115, 0.059076276562747464, 0.046790087850944656, 0.09774976244737064, 0.014448923869959772, 0.0295257659613966, 0.0432521635816703, 0.05835459109455828, 0.01611715693387293, 0.01426216216772915, 0.029232798617393262, 0.01640714419585082, 0.04006802254626828, 0.06718600288994851, 0.042257850403867425, 0.019703245150946805, 0.04793983643814441, 0.04655784063581978, 0.07038079637793765, 0.0205784029282269, 0.01584970893623728, 0.051531459640471206, 0.07937734991672539, 0.04467679217698113, 0.038019350219157436, 0.08994735612143433, 0.02289963401703825, 0.042712358878024166, 0.03276792475052419, 0.013668117481434058, 0.04269281597507577, 0.08286904844064867, 0.023768839291146687, 0.10844697755190635, 0.03136187761781677, 0.027569282739873857, 0.03727356745531002, 0.04909975867297861, 0.06768240488224453, 0.059636110635173906, 0.024135222756153634, 0.05750134917757204, 0.019773455193987297, 0.03005396060255026, 0.02357144141569734, 0.07984937499127082, 0.06261928382539941, 0.029008430616569617, 0.048003540479487954, 0.049312129736908024, 0.044153205554692015, 0.05357644325422664, 0.03795730858860958, 0.03497550669576853, 0.0581792718730867, 0.00694863532947737, 0.029776491217255115, 0.01426758128218353, 0.01598601417255498, 0.10906990662577654, 0.15558640532676252, 0.03931978064018392, 0.06200423013539084, 0.10323399437531348, 0.04033524167513655, 0.008255721618150993, 0.0130703026849416, 0.026004101908315095, 0.025951938981550838, 0.04228062619785628, 0.03802489286528961, 0.021005163697766203, 0.03562134945945394, 0.06792566844172056, 0.041855780648127686, 0.01072983225552185, 0.016221184013110977, 0.05777231830682966, 0.08692480218146117, 0.033781635274569836, 0.030427801933500077, 0.05751978125303023, 0.0707257044832072, 0.08571927090205493, 0.06479081367292712, 0.043705055610306805, 0.06397012283184356, 0.01617246082112674, 0.023592598848946156, 0.0716279951795455, 0.02712758900147052, 0.02823806600645185, 0.017827327565981016, 0.031146783111316544, 0.06210956339453978, 0.02274777049258832, 0.04054540257540442, 0.07456079425830996, 0.048725892444171255, 0.042749180894104705, 0.04425801021317321, 0.014076577368072204, 0.005989339073083454, 0.06918389890943805, 0.06448163590844601, 0.021347796521900643, 0.07279748202211435, 0.05594432909762668, 0.0642879152550332, 0.03949686952476059, 0.01739061722952512, 0.0454164270852362, 0.05991525775302322, 0.023711660403698206, 0.03653611972807877, 0.009014232932860333, 0.01240267716873918, 0.012274344034883524, 0.01532055285473865, 0.0637833352741455, 0.018009424750362674, 0.04673371527103647, 0.08326287892076277, 0.016439848489338355, 0.016935773591901508, 0.01875860319893447, 0.030011720429625244, 0.018098804228488478, 0.06893469050766961, 0.06961248679867676, 0.051477971381597945, 0.035053617020528165, 0.022866648186238545, 0.024247320571673975, 0.03404470986776775, 0.0418800886179651, 0.016536731798682484, 0.04082317456542965, 0.014030355453160743, 0.046074442986038425, 0.017828392428195766, 0.08326897698064005, 0.03299488978941114, 0.06431560933349595, 0.0689396470965397, 0.08155438027554944, 0.035698889048709985, 0.007577007936854517, 0.1055176335296804, 0.012689872997842971, 0.09971837092551494, 0.04304499042430713, 0.05018248988856232, 0.044244419813396475, 0.02891835974409215, 0.014364147622648989, 0.02509931185012383, 0.01648730380580791, 0.04002764205177946, 0.008095144801172278, 0.08270806272424037, 0.06857044634319122, 0.023249081193259167, 0.007965186124502291, 0.041246307908647487, 0.04018893803379709, 0.026451962654508894, 0.04160363429916963, 0.07949627740609069, 0.030172621876361872, 0.06691321430187072, 0.022381490449451154, 0.0156507664360106, 0.027083581080660227, 0.06813294119051388, 0.04509950417184061, 0.015803914115343605, 0.035686807842144085, 0.08553296597974916, 0.037227023783470356, 0.023076020015944398, 0.013868393932258891, 0.19079415157677668, 0.010718715362130635, 0.04281950393511404, 0.041699820468502666, 0.03637491567661205, 0.02520223193231129, 0.017098076979539568, 0.067590351757263, 0.021043046745621873, 0.03919665881943318, 0.02699140346639099, 0.005991804918589732, 0.010532715917384673, 0.04651010952769749, 0.008021405486825613, 0.05463656721516483, 0.05768734000382885, 0.016916778441818974, 0.01754523867050246, 0.010352299338386906, 0.03506538413104511, 0.017176135593364318, 0.055821624794794675, 0.016109494139410315, 0.11790794891215141, 0.11759635030982957, 0.04317621362485713, 0.05320914239893037, 0.015589289795306903, 0.051057055862920905, 0.016542580879984364, 0.03823131525648698, 0.028468260105939645, 0.0008042183347448196, 0.03400519122219375, 0.035846851270405516, 0.029646449707328316, 0.023642856131998763, 0.055718268042490374, 0.046285929218415296, 0.03983932231823283, 0.04578355940118913, 0.00885291013776535, 0.06186946377819104, 0.012612865839694298, 0.03356682039016197, 0.08312920423885507, 0.03309860660303985, 0.05379173694358719, 0.02250421007404164, 0.03252015659405339, 0.030887954560438954, 0.02370601625091607, 0.027368224879366257, 0.1256656999729814, 0.04865394529676245, 0.03923671372655419, 0.06313324072248032, 0.0408138589362704, 0.022288550577697255, 0.040796166135659145, 0.05974659966605325, 0.043192152084121783, 0.021996734280800147, 0.027569083557013544, 0.04790002667915918, 0.03272948245848379, 0.06564779026854424, 0.02122556336314207, 0.07429230342348737, 0.03475699543712601, 0.03287214718218292, 0.039610139454805085, 0.07138473928094873, 0.026828628934679494, 0.04260744696723358, 0.008295830151426696, 0.012886623528996303, 0.04778704020164667, 0.029257280872233456, 0.02867829268648019, 0.07065029078794104, 0.01804698795650996, 0.046501295686128645, 0.0197751559091792, 0.05528871105202744, 0.02565968026887746, 0.06506803024920725, 0.06226204553498857, 0.01433358837534944, 0.039609461466992096, 0.05052229584825616, 0.054542755918397065, 0.036888324820827094, 0.02727080913891475, 0.007195239989913159, 0.03822243629744457, 0.045445124738879746, 0.09975186428956448, 0.08216088442432304, 0.06670308404511983, 0.045555690378551526, 0.026156381035463947, 0.04455285064215141, 0.0359349015859827, 0.049963239355072867, 0.014618680335491177, 0.039486902720865705, 0.010904859405972306, 0.15950172749017516, 0.04899718333035708, 0.04109619681032435, 0.02018158853564772, 0.01036916476403994, 0.051496633283433416, 0.04883394148501177, 0.041025371981724616, 0.03547908693191505, 0.053542654946326255, 0.0017399526592682027, 0.08254601980649656, 0.15759176304263456, 0.10885870384593165, 0.1647862786006543, 0.09880150157597758, 0.16462874027990526, 0.19615972414612773, 0.17453722956199802, 0.12054709116778067, 0.1392855558304056, 0.09644651665322243, 0.12306607253248654, 0.09005726675593084, 0.16644231554481292, 0.09285672823147428, 0.15612211529045336, 0.1539708331467644, 0.16286967983168943, 0.1657878619528586, 0.19424318666419677, 0.11190479966781794, 0.0993372038787892, 0.21386262179622728, 0.11767426911260813, 0.2745749518996285, 0.15759327989672461, 0.07615667031777483, 0.1390165210731568, 0.10058499256809873, 0.05308239698229779, 0.0882495444027647, 0.13792596426942658, 0.23012532011395503, 0.1748752888412245, 0.20405505693727927, 0.21538987936031437, 0.11251695754547274, 0.1069593114117461, 0.20696069053824873, 0.2173757324776342, 0.096047974732374, 0.09223387576639654, 0.1785768724737629, 0.21876483374545652, 0.20278606293422563, 0.10687032263846168, 0.14135696564710912, 0.12456441027743202, 0.16716651378139374, 0.10598093286276826, 0.1866952134596725, 0.2524682284603196, 0.1631393887463116, 0.1656042153556501, 0.09306490496401826, 0.14040625053307704, 0.19835303387334272, 0.1098888086515569, 0.11756659545485051, 0.18322270543825242, 0.13088357845141044, 0.1412004692059371, 0.1579860531755032, 0.1747945738175223, 0.12445288319741526, 0.10822781511852819, 0.1681918611810092, 0.11719852085075072, 0.09524213450570261, 0.13067932408903876, 0.15616397433463605, 0.17130467560022108, 0.1975781512596915, 0.27821187771135764, 0.13774484576236817, 0.1312282720520612, 0.08561432451730774, 0.12751674459826562, 0.16308010886273078, 0.1314029554205556, 0.2157771674495551, 0.17217597804002224, 0.24458470874496047, 0.19027526490390304, 0.18424690370598149, 0.14853583768971507, 0.11568416420730854, 0.22219660121106335, 0.11847914406849493, 0.12503139449343567, 0.18820413087885227, 0.14124019852569028, 0.08533759057641992, 0.08361619867144093, 0.19324809973759038, 0.19504511218157508, 0.11667233335995868, 0.15558225313021293, 0.11075706972229866, 0.3053745363027819, 0.1413059595131105, 0.14789511239336384, 0.13448583112368662, 0.10361984221925659, 0.26784404210986634, 0.09008681476717034, 0.14527599567607527, 0.10797949537875191, 0.12655508974867483, 0.2361554586358609, 0.21659462923003783, 0.15815842295846633, 0.10574730668937969, 0.2611104050470937, 0.14895853436281606, 0.14399753282627753, 0.10258167050778867, 0.1406335181766941, 0.13773551481145044, 0.08691733282419943, 0.16463971065898098, 0.1554923144079024, 0.13078418620411428, 0.17436430819572943, 0.16101537933272703, 0.18764674062690428, 0.12047196092504649, 0.1410434211814596, 0.17730885906325233, 0.17622104485429105, 0.08332097902894021, 0.12567408097487304, 0.12532453037678234, 0.1723491598761851, 0.16382275449652828, 0.14571507130899738, 0.2114989647581693, 0.12096641705401483, 0.1771889969466194, 0.10686139005326456, 0.15414865747574838, 0.12216897591227487, 0.18927769585242196, 0.07668235985141608, 0.09994459668955497, 0.09067577550247793, 0.1503621913011997, 0.1432539678869709, 0.20477510297731047, 0.16107924042209504, 0.10430188263736426, 0.07953632082189284, 0.17243840911936376, 0.1408423997101284, 0.14406554611219516, 0.12296953779314795, 0.1771286598617031, 0.08871780798560189, 0.10746602494750293, 0.10782322110307795, 0.21396353089761352, 0.12917342505628063, 0.1755526484621148, 0.23108878293104712, 0.12918332291226234, 0.2589602107482572, 0.08428083357190894, 0.08102973262148519, 0.09826251275597081, 0.16487638586230818, 0.14980067949621909, 0.18304495771806087, 0.11721847744117822, 0.0928373998331447, 0.1892147234250461, 0.06126975099886618], [0.023395116703825134, 0.01050130727009908, 0.051874958143960086, 0.026970608009686394, 0.015138940220969099, 0.03365624966400285, 0.015643332510315362, 0.016228965551201856, 0.05229355241622656, 0.03255739612805267, 0.03374818021491651, 0.10151058765909365, 0.05931963588321402, 0.029864007186505104, 0.013340322822783024, 0.025301880819062074, 0.03155233665189195, 0.04311176264778741, 0.03213641932234168, 0.061243006869429545, 0.05037977285082302, 0.005435697863914914, 0.032920828239331325, 0.05794168502512959, 0.019620917512164004, 0.03197381332997353, 0.09804529618592032, 0.028183373074317654, 0.053444599522457975, 0.026492479129604278, 0.04708135447975609, 0.13288184219310362, 0.08915221814306513, 0.02396194707422007, 0.03881191414210104, 0.06511682238910468, 0.008361414938624348, 0.026594050897045002, 0.10016673920495857, 0.05272450368671168, 0.0989762538923852, 0.017414739423040903, 0.04495001743517576, 0.05014398630948798, 0.04308889109280802, 0.030794821251484177, 0.07936627994621955, 0.09045862788034063, 0.034943737029548616, 0.1116297817638805, 0.02453704353331799, 0.04314023047505368, 0.0698196905995569, 0.006665976177300177, 0.07591026579780925, 0.06521112015170437, 0.03146328084591416, 0.0383419421831927, 0.07744164491492896, 0.02301052715929766, 0.07999307010322809, 0.040541644914135824, 0.00645586459394244, 0.022710906341671947, 0.010066827207112746, 0.03391594963989431, 0.03839770572320108, 0.05093858802631017, 0.05665068131601138, 0.016874605301587332, 0.02065862957087736, 0.026896253430975542, 0.035289054991857666, 0.024743306961271073, 0.0358581051020132, 0.03650445348372863, 0.04173544355698171, 0.056709313855296185, 0.04202854113593217, 0.03347010562016118, 0.02984695215409081, 0.03825599094852805, 0.06054194065772238, 0.00903064062097861, 0.010944697893254701, 0.058326563767848484, 0.00812761256501319, 0.09976330198227398, 0.04135421139278239, 0.057433374196050636, 0.048351666154039484, 0.08966443985099755, 0.04699302071164693, 0.024088868691075235, 0.03477927327396409, 0.07487659102245685, 0.010283225020694156, 0.03316366662000937, 0.058799381743395523, 0.02373600859315165, 0.03500934862982362, 0.08837795606063259, 0.040995858444441716, 0.03331668885244477, 0.036691532154837926, 0.06695472094560824, 0.024576035493444053, 0.05044999630040219, 0.026103277735772635, 0.032507259503848134, 0.07206742321291278, 0.0884940030594026, 0.07504254098861449, 0.048849646287459525, 0.02999190748068354, 0.0861271437738211, 0.07814593252635772, 0.02738366346626032, 0.030587862598739808, 0.017380006911773837, 0.041859741322696216, 0.020666363228472973, 0.01980232521741381, 0.023707956368584308, 0.061893714291434136, 0.05292111632203864, 0.042829976357038946, 0.04888998847755213, 0.02631041258873959, 0.11457722078287795, 0.021160501430952744, 0.020808376777436466, 0.05413677528380387, 0.06649949617924229, 0.04706139788932858, 0.03277926668224316, 0.012217935065798944, 0.02714202209796396, 0.04347899072473088, 0.035292513878835786, 0.030746908197479866, 0.02471272856177342, 0.025423537496657624, 0.046639348560523604, 0.03274900237879446, 0.06282995417413693, 0.03399459622620094, 0.020441056769942085, 0.021524276366577517, 0.03174348133465937, 0.04318947460682642, 0.024587986465062828, 0.04647148720499489, 0.0555662532156754, 0.03491073779221024, 0.03146365431377725, 0.06244248605423397, 0.023207174268581217, 0.04521740127294775, 0.09915260733255457, 0.08215346103233677, 0.05557386429920312, 0.024214114490596038, 0.0045068085948455966, 0.05484180600051919, 0.07300239522010088, 0.020176195276660785, 0.04572704509501496, 0.03248431134007631, 0.04189319638234954, 0.041016699866421764, 0.045761143668524684, 0.028481503850930644, 0.003764713586743681, 0.01190923897910022, 0.050484933740189, 0.008040607001842752, 0.03740973575341125, 0.03456342800129806, 0.019559249349479235, 0.008715511310935743, 0.031112064006588155, 0.06138750637370733, 0.05848037890128552, 0.04213169104449692, 0.024260068274734002, 0.010588842391547178, 0.06445470791790756, 0.016997849696405956, 0.03618219859838005, 0.055629781056796355, 0.0033971496281259123, 0.03806762524970597, 0.07452682591974735, 0.06624787460051237, 0.01959578025214855, 0.05711385041415211, 0.05306142149493099, 0.015407516283073254, 0.022071724712488153, 0.0637375730119886, 0.04593165951871103, 0.013506529428395293, 0.009794240674724983, 0.0577002332635945, 0.047944528726680626, 0.02381074047016521, 0.08169407640854198, 0.05580938270976467, 0.04573588191922154, 0.019946401458113425, 0.006740786578325976, 0.02284315226960086, 0.044883716355768905, 0.008678910502743338, 0.060752553549865564, 0.029633587091079647, 0.048978115401921735, 0.08569208244162221, 0.06628267031403319, 0.009074538416649786, 0.03542090255406595, 0.04651213199981759, 0.022970085377774896, 0.057098969156222965, 0.10301536054260309, 0.02696535839218526, 0.021437363691567894, 0.012743305715341723, 0.028537303780115424, 0.021570253133353208, 0.02405149509168921, 0.0206318260696266, 0.053300820140829014, 0.05753193523794894, 0.02177035721439508, 0.010579578473322816, 0.08554558344786206, 0.03787693064359408, 0.010083710827353981, 0.037541629280894995, 0.02468238573431248, 0.13465198027270456, 0.02154788719640384, 0.053501309181052836, 0.042414277897126255, 0.026532057146992416, 0.05930188179556882, 0.02776903442047056, 0.026973367841433615, 0.04857468967055602, 0.0597036910814143, 0.09440565842293924, 0.05144928904971288, 0.05639054467000308, 0.03943706870139126, 0.07352741825724803, 0.05467540404248623, 0.04214992393709479, 0.043626114080149325, 0.03086849209672261, 0.05617796293189449, 0.11646075519703089, 0.07666231899131691, 0.02121274479694905, 0.005855171222074499, 0.02658582119751842, 0.01416614166490974, 0.13748403878942614, 0.054668972734361894, 0.08403517215722993, 0.023980616636934782, 0.016349584179660006, 0.054815621115267284, 0.01745813255829196, 0.02410794236517001, 0.06235717833342572, 0.028568428017259128, 0.07762900703857023, 0.022398568464503176, 0.018585972946077105, 0.13741918178575654, 0.015648400181934478, 0.048472144971451456, 0.03209410254062424, 0.06615120962622666, 0.03045471843271967, 0.05218477176141836, 0.07062877137814799, 0.06897374567004942, 0.03970489303971972, 0.02994672361490948, 0.05123956098912224, 0.03494335398558648, 0.00948985574782015, 0.012621683511702765, 0.030751175307218107, 0.01877193695925657, 0.053014322409346226, 0.01729590960988595, 0.08849247088355404, 0.05015361220425656, 0.056744373869150884, 0.06228079170649571, 0.057098735499406056, 0.00278948413793959, 0.046208282376849846, 0.026795137485849763, 0.007984823352026363, 0.0775546735272773, 0.006844083001206239, 0.020550779712897156, 0.06338165622324714, 0.06054431169984802, 0.014706850352306521, 0.025665983257274476, 0.007923821685835719, 0.013510748657638268, 0.07190622299188568, 0.03796723708810826, 0.02469383683356066, 0.050889297929261966, 0.00593706937281475, 0.0030484290384206803, 0.00466453795877075, 0.0642937834885332, 0.12132483895026869, 0.07429791118709311, 0.026112212236189557, 0.04423076046570655, 0.05101286408100879, 0.054012048508851766, 0.01081480864330285, 0.025263279563777392, 0.0405116104370644, 0.029807874009073265, 0.03511205420739228, 0.10227512808576708, 0.056752184135538924, 0.06696106415362128, 0.01349816374826215, 0.034627354208139643, 0.04936635727062822, 0.1185747288588074, 0.0384917774898631, 0.06822949125161094, 0.061392137375209606, 0.02076588762593606, 0.03566033184348095, 0.007594598752010855, 0.07767717098636974, 0.022782305736214887, 0.22926955393725829, 0.09005211098420043, 0.10275335847249917, 0.10165026080944847, 0.11844757358513533, 0.19441243080842882, 0.1082103866182508, 0.10213548557892924, 0.23308047363835, 0.09590064836365562, 0.13858587240740178, 0.14431722131707977, 0.09104427911581532, 0.13253010058354947, 0.22291813346166767, 0.09388443518189654, 0.16610345953414518, 0.23436360962448582, 0.12255362865905609, 0.1410878083157924, 0.20169984218814682, 0.13065185217607406, 0.06174213996517563, 0.12851833561134915, 0.14370055118155095, 0.14069785424057515, 0.15605589465027855, 0.09004928411975985, 0.14969571012883418, 0.12213657039307779, 0.1122273916318532, 0.2597338063341956, 0.2250300693295656, 0.12757069250989345, 0.15001337614751634, 0.19515322250944955, 0.17077947636285137, 0.2032819210040954, 0.20768593065440658, 0.1816237573662112, 0.1257808123444838, 0.24836916776914753, 0.1800511627187652, 0.14590415713046828, 0.10320334319746303, 0.12397255372977066, 0.1760128221564716, 0.15334523042603848, 0.1715232711285353, 0.22405948189477767, 0.1422707246796739, 0.15965522086668402, 0.2763960961132281, 0.09926724472954389, 0.13803972832618222, 0.20310998023036989, 0.1009517188574518, 0.19134913631264241, 0.12031471371770867, 0.1955061285726486, 0.2061064105721251, 0.09500874581957057, 0.09240735637684984, 0.07296803617669691, 0.11967334490750106, 0.13828817064002638, 0.37742038647974696, 0.09085593639963097, 0.10803753419989541, 0.12109331185779265, 0.10836251635825443, 0.12960949762453958, 0.1092244418818624, 0.07209856468703478, 0.10245581758358788, 0.14253859498327778, 0.10197979353007772, 0.2546465228642187, 0.11471719270752323, 0.1908332067391565, 0.21947962442232719, 0.26465114085905017, 0.22623837384725773, 0.13334400771606353, 0.10817422726822477, 0.1970907201569888, 0.13527816522025293, 0.19488841655754274, 0.12877014105118093, 0.10101630006946864, 0.11541486898016547, 0.17924159164390258, 0.3337167251494623, 0.14109911577355477, 0.14451949917260679, 0.10719364238602501, 0.11844520637344931, 0.1514541883502276, 0.1631317278670688, 0.08129698239387044, 0.14849696638843707, 0.19152961130584442, 0.1470461797209517, 0.11533265242413168, 0.13788199082257288, 0.22105756636348464, 0.08985281321069888, 0.1532184122310531, 0.13549228679508935, 0.2189031585810646, 0.22073709646299963, 0.10307765115172633, 0.18820074477022697, 0.17153129972998174, 0.08001219165781814, 0.1103917223912093, 0.1861592123825704, 0.10939187805859313, 0.10664562905027021, 0.14718470373942008, 0.1077062547987988, 0.10379311598597035, 0.15441966873984184, 0.05704836521838462, 0.22136242339207282, 0.1983127989355595, 0.1216603241740696, 0.1617122435521695, 0.17537727561448851, 0.12711265620084541, 0.1268614483095946, 0.13909122996753262, 0.14347689947293651, 0.1586654812337891, 0.1591122330677125, 0.1206987918985467, 0.1519218850280008, 0.14268848774654252, 0.17285971151244256, 0.18273464614345183, 0.11005805279578894, 0.054854764377758394, 0.14033944766607978, 0.11471372232922625, 0.10269440034584654, 0.24659778862710924, 0.11071979954478242, 0.12156041098698495, 0.08746503206390528, 0.12940899709299689, 0.16201757555527074, 0.1941757556051016, 0.09122559680573403, 0.16247974107823066, 0.13415593834173295, 0.09370023700138254, 0.15139916791550576, 0.09180831392445872, 0.20222062875907268, 0.13495412535004078, 0.133625682924063, 0.1721761619011241, 0.1425024969202857, 0.1327339565802005, 0.14021489709135027, 0.1550535298883915, 0.20756548631095117, 0.30141095060013956, 0.14678949430104227, 0.19166131714178672, 0.1921401374162205, 0.18358224582287574, 0.19175549999119776, 0.197541409682843, 0.12475761765193556, 0.12668313368433906], [0.03389362583778078, 0.07254104941121994, 0.048680352347512404, 0.016299434148916797, 0.0962455258254082, 0.010865060180696029, 0.006292244971489475, 0.04892669558044403, 0.028513804033038118, 0.02490693759623795, 0.04086974505034666, 0.04274957925982533, 0.01750006629604726, 0.06951857208003921, 0.03445304239228849, 0.07586181839747776, 0.009753172616324118, 0.08949466710609776, 0.04311935074867741, 0.04074583798947354, 0.06750630425109018, 0.028123671842378475, 0.017490955595407757, 0.05601403160741734, 0.01823150214829272, 0.0200782815790585, 0.054571874920398965, 0.03573230197352748, 0.05302054304329138, 0.031781632513288534, 0.020632871779643243, 0.016495928040615494, 0.01259186928490958, 0.038301255253534165, 0.026949676572375243, 0.05663073621690274, 0.014013820402925054, 0.028606881800618385, 0.0472232109806951, 0.036383216239271626, 0.01266625929518693, 0.026075223595985485, 0.013205101600878183, 0.011299975956189296, 0.049467362133004976, 0.041248782372642914, 0.042913468449466655, 0.031925341031784495, 0.04923883427475249, 0.045502573672321536, 0.037261654788087455, 0.07480593473320046, 0.07912635653009338, 0.03060929007798193, 0.009890487173482055, 0.03594515184240957, 0.020846206199137435, 0.030986287691179785, 0.03741652329242037, 0.038541174839220704, 0.012659624973762662, 0.005445081483377445, 0.04835883290657113, 0.032612539136842374, 0.0325159162973925, 0.02569230220791313, 0.03739716425057381, 0.03230289022828783, 0.018525222173681664, 0.012497110911945422, 0.01199377295110495, 0.03198319216138654, 0.015148507701533457, 0.022538933009209654, 0.04052048173522757, 0.01912418035640111, 0.04011094645266572, 0.08521011354581964, 0.06631190422922373, 0.08994066051297611, 0.05441885268796356, 0.027537869304538738, 0.07676200235202428, 0.06466512162719043, 0.06800299735679742, 0.022713409533964533, 0.037966796587551796, 0.05062392124185159, 0.032791918624312646, 0.03848096032837226, 0.03174086897483757, 0.018656359189340187, 0.011419586221417113, 0.023930861141472578, 0.021204451895168713, 0.03776162675011062, 0.000690474687050277, 0.015828107171992383, 0.025168478098367492, 0.03278016683555419, 0.034720931848090504, 0.060779699875462445, 0.046430218048513903, 0.022457955600393396, 0.07889287591341042, 0.012146791353100731, 0.023380208632818634, 0.048561409536388614, 0.046007421783982747, 0.0076003219076101825, 0.04440386952351659, 0.0225493039244846, 0.015098553023210939, 0.06538125295792857, 0.04625812022676391, 0.029890686198468172, 0.03734865939364799, 0.0409394973558524, 0.036842980076588934, 0.044717950250713095, 0.03114269986268013, 0.03673201990163615, 0.008287096749089898, 0.02299085785184176, 0.05129897876852944, 0.004029961475621789, 0.06329735590805931, 0.05769328867656089, 0.08352507251284777, 0.13099184199686975, 0.05414055592771019, 0.11531226682446657, 0.04350701422100106, 0.024197932798415426, 0.07495658592351022, 0.05001453660248269, 0.006781902517222109, 0.059399377975252375, 0.04472043620602739, 0.0522450398984215, 0.0373682942271473, 0.048184666647425586, 0.05309648150878568, 0.033542665637909405, 0.027724335105308605, 0.017736638077504693, 0.011099583634565915, 0.06644914888085858, 0.007277437872553786, 0.011211904573194202, 0.03210028487017318, 0.09115100282454684, 0.020483310349405776, 0.06787161327778332, 0.0438992052729572, 0.05139158347681646, 0.022037292890731367, 0.01607967799739732, 0.06935272936619098, 0.05171673800495844, 0.08620949822568125, 0.008003837654307004, 0.07446278096927751, 0.022458501438039447, 0.024570190242581794, 0.010683801862591458, 0.0691196394543494, 0.0019689327487984916, 0.023273023356112744, 0.029853885249805548, 0.06059998713974511, 0.09342221603278192, 0.0550331479509271, 0.05537885661807753, 0.024276207832078782, 0.051220719056624564, 0.08551911511007818, 0.03756779884438842, 0.07228258666732619, 0.023596343103676073, 0.08763603821036317, 0.02413201476297071, 0.04567167992072721, 0.027338293824164618, 0.024172764894883, 0.028441211456553112, 0.06622473108431985, 0.014051842304216999, 0.022591852447799137, 0.08165121378917849, 0.025000331375086983, 0.1006295865461711, 0.021481588032216798, 0.07508323557915227, 0.022368574207047784, 0.05105563860026099, 0.019525520413392977, 0.04637460389565076, 0.03467626126122571, 0.029017332558249755, 0.07078223411113986, 0.0314390552305286, 0.09029183521746628, 0.060570450619824474, 0.04921872446674013, 0.044586976028738484, 0.028865733334133704, 0.0410897808239585, 0.02558722367299901, 0.034358817408041614, 0.03075035942357875, 0.040878895970602194, 0.04244450772661836, 0.059703798333723704, 0.030621422995482723, 0.05156448569088694, 0.008756181961225887, 0.03066014299439567, 0.05745410836572128, 0.04979241706971681, 0.06474467985812696, 0.03377139650946183, 0.0034696426131807633, 0.03549622814922083, 0.019394898591863535, 0.03161816084156594, 0.05725884787558068, 0.01419707150724266, 0.09375949390232564, 0.010562083897961965, 0.030679490544923374, 0.019408322367516738, 0.01734314276085746, 0.05385352576512003, 0.055911954221946586, 0.04336413499268313, 0.03628237608579859, 0.019845287428207455, 0.03777202639368273, 0.08142786085485451, 0.030081049471552816, 0.01493166842978568, 0.04993340406086176, 0.047934351248606566, 0.01074216148305324, 0.023670555956120935, 0.06719557132812277, 0.027022148490012176, 0.019172765652558977, 0.040526081837954066, 0.10108835063874723, 0.014500182812973378, 0.06152162921705073, 0.04971069464039418, 0.03745643264283577, 0.025547000226534666, 0.02695335954007122, 0.082872687358289, 0.09499136328456864, 0.05538039645480533, 0.012648193026712586, 0.010811683962181693, 0.03893789730124897, 0.045939860489940455, 0.04571119090542198, 0.0334425647592833, 0.052679327481816855, 0.05837578874742312, 0.0807414613964577, 0.050202251126569127, 0.051136020375716115, 0.10330325638454768, 0.036084667944739905, 0.029649830070294203, 0.02311543332442882, 0.04068553154807418, 0.014757745403556094, 0.03262123806522258, 0.04618498181263286, 0.03429606331572418, 0.06856882989767098, 0.03797466814097378, 0.02923927014513362, 0.07756717608220155, 0.013963062289891946, 0.04302590334367368, 0.040940255782897436, 0.026334295379779032, 0.03939880260957345, 0.053090877575619574, 0.044810102967124794, 0.014914510933111512, 0.025717464365786123, 0.05333198459758874, 0.03584087578459613, 0.07390210420013436, 0.013877072750831084, 0.04932031538637896, 0.013065743504182227, 0.046218567107233315, 0.03443532277859988, 0.021255823836151152, 0.013419789123168636, 0.049651667565828374, 0.09416160579290121, 0.007825963529607943, 0.0369629034802558, 0.04063483567968492, 0.01564500832764973, 0.05322755532219045, 0.03204405593175081, 0.0328433461066696, 0.039868805211998766, 0.053199650569548534, 0.023560695117339495, 0.014535358697626621, 0.06337667282129969, 0.11400134482931708, 0.03960404139492781, 0.031023797271172368, 0.065461722833495, 0.0030732048006968634, 0.010709244600166718, 0.00584156071248975, 0.020793102899446123, 0.04070361505352682, 0.060497166648987806, 0.09231426137229128, 0.03763148756397348, 0.014094856225945538, 0.04400507096321352, 0.017100986198432023, 0.01312220801464132, 0.05363357426117986, 0.11453199095182842, 0.03027987227054133, 0.0077949297866002935, 0.01896116833743309, 0.02459179009160688, 0.02694249066764549, 0.03148106940751595, 0.02761069745306046, 0.04842380865386898, 0.007399074919146276, 0.057665115793145476, 0.04562922332796358, 0.02301989066895218, 0.062198372137162, 0.0033418253916616164, 0.06619320656623572, 0.03207701111903354, 0.031543630062632506, 0.149810362847582, 0.16943106968556682, 0.12254268126261812, 0.10728109898346086, 0.22713288875116458, 0.12789738304432363, 0.17562829198375826, 0.15214821804435025, 0.08675094618792496, 0.1249243030625005, 0.10711799886438156, 0.09584110801018055, 0.1267155851688116, 0.1805083486702173, 0.12233697133319033, 0.20560411736369136, 0.08636627811938526, 0.2178978826850653, 0.07011842658563007, 0.15374803945662516, 0.19270950928330424, 0.18685817568292543, 0.16722643717883096, 0.17343479839544143, 0.17883987045816838, 0.10429333309612929, 0.17158725479197118, 0.11689189415905746, 0.0723810059829585, 0.11207114033881696, 0.07920603733509779, 0.16639674863507672, 0.13890626569909437, 0.17392399150036997, 0.09886679524976401, 0.10450299603924637, 0.10959646183877222, 0.09429886576629455, 0.11013812430563474, 0.08188621892083077, 0.12018029593051442, 0.10395466860744262, 0.13479457987893012, 0.1321729810367669, 0.16900153950818125, 0.22280945622872925, 0.1345235532930782, 0.17911462023133234, 0.17880423204793086, 0.18081055503458748, 0.18185995759502535, 0.21588248921738518, 0.23462349729191875, 0.14220441210894816, 0.10193905297426448, 0.11008003185833655, 0.21917652939596485, 0.16420979743763325, 0.217334930634787, 0.11154142118269399, 0.10082452527938351, 0.11576883224470001, 0.12225553618683932, 0.19387523463416487, 0.11437146488817469, 0.08360124463515897, 0.18744100005395953, 0.1475047139871505, 0.19246823755243134, 0.16295005777670493, 0.19454173112828888, 0.12487174943089487, 0.1845363930108086, 0.08532524123908052, 0.18244302711419522, 0.11191621437788972, 0.16907139140511715, 0.1449351631585629, 0.07802204844812233, 0.18168653061072673, 0.11296212357739288, 0.14586876386836653, 0.17993464074548216, 0.309213801257072, 0.10713220979537695, 0.10275146623532619, 0.1476128856020589, 0.09751603668255192, 0.14430606707690224, 0.1282015812372969, 0.2162534136685633, 0.1257243823079813, 0.11956747921724474, 0.17807488570049887, 0.17286150415818538, 0.22223846025524602, 0.11922118449283224, 0.12048229545114503, 0.09822039324189387, 0.1436521650682534, 0.18248834887579565, 0.25163549088662673, 0.15502881589195422, 0.15640215107029484, 0.2358100449125613, 0.12412878204016917, 0.10325071041382129, 0.22935969184242913, 0.160385072832146, 0.16179110464309493, 0.13562713359152118, 0.07399726764208849, 0.12462648638193646, 0.18543253202111493, 0.1474623646466963, 0.10048357784868249, 0.12973896648374297, 0.12609883842449035, 0.15616120109635015, 0.18767669466474365, 0.1515903221743722, 0.1414343864927369, 0.08842068078416972, 0.12074739251646305, 0.258134184104781, 0.05626135543289204, 0.12692128743736014, 0.21078098715553362, 0.1128256603354408, 0.18968986647744335, 0.16666769861213623, 0.20725963336806144, 0.19758169058590166, 0.19395788019943624, 0.1619000883112031, 0.16674240750651206, 0.15577736040276868, 0.16923633013521472, 0.1271185780605001, 0.16367819370521655, 0.19330816103085396, 0.18091573890659118, 0.13247892591020755, 0.24212432544558282, 0.20769173760087262, 0.11521410797872852, 0.07241835276926718, 0.15447435209587698, 0.09192223119879923, 0.18450768003540655, 0.18775474370246936, 0.3530099447215757, 0.10356787081447341, 0.14898438216938129, 0.14809584275128382, 0.1252826943152374, 0.06701381696808724, 0.18371764420261308, 0.23814823718801623, 0.15273600666513368, 0.1941579670434998, 0.11962707319687452, 0.13750984063071592, 0.0947061104459628, 0.2151454666689519, 0.10940654098146385, 0.205757258339755, 0.07305180023033774, 0.10269772516743791, 0.09269463168757577, 0.18516685272897446, 0.28689983571248673, 0.16351967479192442, 0.16375746848362108, 0.17446184651024882, 0.12064040067695803], [0.045165364750691, 0.02242255850785202, 0.03004568493774822, 0.0509766970701035, 0.07637425461002896, 0.031519322092795087, 0.003509407843305399, 0.042895990153474194, 0.008822110530379559, 0.055502962861810966, 0.038139415349090294, 0.052196117523576946, 0.01637373510147295, 0.018832231909337065, 0.022353365446531007, 0.055805916161907304, 0.061994106283471476, 0.0309042492505884, 0.06352416772936141, 0.03258669516071677, 0.023792342868663614, 0.10089821527682005, 0.03355963831587184, 0.020450694156029535, 0.048345755785703666, 0.042748280740793676, 0.06145719739217913, 0.007368744540614106, 0.034728765097116275, 0.05098882424194486, 0.036856041875697916, 0.031603124450832125, 0.04600840237652583, 0.04178615857756907, 0.04286482186627485, 0.04917550944693146, 0.041024820398419135, 0.09362152912804196, 0.032790489870333867, 0.02414258486110597, 0.026605306643872496, 0.02139828746177016, 0.06028413291900389, 0.06610222596434817, 0.034344951216612137, 0.059409823584099936, 0.013077181196891734, 0.024213166456789743, 0.08382942392340592, 0.056904516888842474, 0.030306882615531647, 0.04773701466019115, 0.05396821678826406, 0.035464381874208493, 0.033127890313945474, 0.040231521031068224, 0.09908096278987585, 0.04924909985293785, 0.06661763459804558, 0.06060230455571606, 0.04444613459429914, 0.004934313427281356, 0.02955501902878525, 0.08250521030277014, 0.020730421585481495, 0.040741103566101486, 0.03909319481481949, 0.015127127145176694, 0.025442333463879845, 0.04023399932550327, 0.029168156118342475, 0.007165681444964702, 0.015305305789825658, 0.024950780808144522, 0.02978752096814494, 0.0543259721880238, 0.040657381647296494, 0.0286882633208147, 0.012751065228404778, 0.022992920543577884, 0.015540985078851302, 0.05556620725039994, 0.02386488564943354, 0.052884397727827874, 0.061976934422648726, 0.04272920515147909, 0.04571194167158777, 0.030473608245712616, 0.08564521318241473, 0.0341037254510147, 0.04259452689439059, 0.030410124454647306, 0.020385858219777866, 0.04145089168882659, 0.009115989519012793, 0.015349510978276451, 0.035989205728495316, 0.01204964470103263, 0.029950977318109046, 0.05154093997853418, 0.013074887721168419, 0.03174888800018497, 0.042529003394226876, 0.018153694428263173, 0.08380460267465922, 0.008587517170986582, 0.03181761949353161, 0.02714377069365113, 0.014353773834544324, 0.006063727646945946, 0.02065875406016506, 0.10216452797213871, 0.012305841739890317, 0.019499902433205037, 0.01828124040677663, 0.10174202282101878, 0.06916734374939434, 0.038442096687973513, 0.03437457966708368, 0.008839397304390949, 0.030445849049776316, 0.04502010298892856, 0.024408993851994316, 0.04818590770986292, 0.03028001591202713, 0.028235242972450874, 0.0587861858788998, 0.08259178589909308, 0.02504039011264761, 0.07613321270553336, 0.03932944866978834, 0.015615785903778049, 0.034880887176240646, 0.07084404974575005, 0.016624389494198467, 0.04138966211147847, 0.010927290460395237, 0.040468510330444386, 0.09285777777193055, 0.03847558622158343, 0.023814396624783837, 0.0426319885938879, 0.05982295947990591, 0.07952273808299534, 0.09610031385936084, 0.025766631888766444, 0.03621631249364826, 0.04170254008063386, 0.06960220589873291, 0.03385038783533439, 0.005274964956521628, 0.02327483706927348, 0.02831211989565242, 0.010790356074369723, 0.04429524208629324, 0.03576662654297487, 0.039909254654400775, 0.05352473998021695, 0.063971130237464, 0.08632583633786248, 0.030404828871870716, 0.0361259371012209, 0.023864236389917713, 0.04326642430838078, 0.053422394463972706, 0.02912832337671951, 0.010145270780119444, 0.006131076351589253, 0.03475288154497262, 0.06325356632230744, 0.06767142684228959, 0.020577855175361037, 0.04408778164595847, 0.02425342054677106, 0.035732309634406725, 0.04369831020613352, 0.01896297247449477, 0.035565267992956985, 0.021834578365087513, 0.0734866087535216, 0.0555506288524597, 0.03492672221675035, 0.03544584637688052, 0.03264743827223297, 0.05325687350705267, 0.027829905851714076, 0.0553429500770665, 0.061842784766227975, 0.04110231019196011, 0.0548014676408662, 0.1541919720869872, 0.0767655493391137, 0.04649198771784863, 0.018677727296768178, 0.016349944240984418, 0.025874186802895802, 0.011467227314208305, 0.01176090616237132, 0.06049831578087422, 0.0377221770524498, 0.043755751478696064, 0.0075415361507405205, 0.0388420635323611, 0.07159899109073224, 0.05278296385621352, 0.06453108688395831, 0.043519815550215786, 0.03183137460221206, 0.04816074938242955, 0.04936115553362235, 0.044723841466850815, 0.03591719729405257, 0.01827744252589201, 0.06447857921762813, 0.05596277266440373, 0.04348433035756311, 0.053880867443137595, 0.01210718460741543, 0.015415921225212516, 0.05859837942426244, 0.039715602948901155, 0.025135710602626208, 0.048220477427446076, 0.020701404090129563, 0.060374879864074533, 0.02013113781539423, 0.03308486681611788, 0.04456145380954108, 0.03440186388850693, 0.021362945910603292, 0.03792298784960182, 0.03297546946053063, 0.024963271871749914, 0.014607041544701545, 0.05675172448278435, 0.03757581978495564, 0.04608200044341145, 0.020416614734717918, 0.025736089878445192, 0.03318456549858374, 1.4099808969413355e-05, 0.023858864198348696, 0.02972797103857081, 0.0462077729283802, 0.028294655006198634, 0.031950606611527266, 0.0263701195663382, 0.05859415444936003, 0.05465424852445722, 0.006560695107891075, 0.03588908186723148, 0.0387278245010924, 0.026038573949687907, 0.019472470739856362, 0.04022669467714526, 0.0857082928621, 0.010876590761566355, 0.023022208084923126, 0.022337342717594678, 0.019685992850892006, 0.0441359494241976, 0.029533350231846976, 0.0267906156518767, 0.02611146338524357, 0.0783927124294062, 0.03197573429544366, 0.06719601565911885, 0.05271203943618363, 0.04427677936731808, 0.024552855588075136, 0.06315244271630241, 0.009262912733961017, 0.02345790910053878, 0.001974179373768669, 0.007639595883853374, 0.05829025503067721, 0.05626269225631991, 0.03127213807836656, 0.019300602744483662, 0.02023217906694739, 0.029325784454422615, 0.011985809467132054, 0.012251069326133979, 0.07402604956540369, 0.02948037142144336, 0.03937762410890672, 0.030915648638901692, 0.054809002115601496, 0.05176476788737121, 0.010899220041239695, 0.04161824359588566, 0.018348330556745493, 0.1114370646856485, 0.06199627048185757, 0.04493643852671789, 0.010091820825642396, 0.011760178378843253, 0.023818579464850408, 0.03353199020268456, 0.02651578735470051, 0.05961573652682766, 0.013603298782160687, 0.0986268105466039, 0.055533629361419916, 0.07055550272906981, 0.042960460282742016, 0.02540910631538399, 0.009116191574702821, 0.05928321989373334, 0.05534722101724437, 0.09992493887341793, 0.040637145434776624, 0.022786515389358806, 0.05784315079630864, 0.028103862723876393, 0.006703391432717082, 0.01735551125039497, 0.08081060849250325, 0.05579568505767853, 0.02029281492615419, 0.06981220592053668, 0.031350125829058315, 0.02699919266536111, 0.057746095117181546, 0.12080341652636567, 0.047262710474071004, 0.03981206490988693, 0.03564210661176232, 0.03979873114956483, 0.03771299931911692, 0.03406888760265804, 0.021616697213762713, 0.009355465731313153, 0.022361039732312484, 0.05045303766946158, 0.02300585019251993, 0.039048282910258546, 0.017170995143392397, 0.10904870897291169, 0.04235562620564334, 0.05964088719338179, 0.055758430201920776, 0.017324362115393725, 0.01708229173785977, 0.021468853735695445, 0.011874408791622808, 0.008290954959398557, 0.018070204251055277, 0.04731589229777456, 0.01331406132873869, 0.07639722192599889, 0.03955372474006107, 0.1434441415532943, 0.10292658627393747, 0.13332401282123982, 0.1649792255052636, 0.23872199107802686, 0.15035695125979764, 0.0963126581102129, 0.20044341202705138, 0.172480758459818, 0.20802667124136803, 0.18461773622660868, 0.11866960884822954, 0.12326326356419634, 0.07570524534751331, 0.19445076584815982, 0.20141904032038105, 0.12579971939445506, 0.15861946999305682, 0.15551718162192454, 0.22847063148454314, 0.1282992421258842, 0.1568276669469572, 0.1546365941964811, 0.13516738890640198, 0.18117548867819772, 0.19220079625806502, 0.19165767056326713, 0.2261629141867161, 0.17053491045390406, 0.12372166759544805, 0.1956077884402006, 0.19703899390034138, 0.11767710363792798, 0.16696282632408604, 0.12599753861826274, 0.16111768271413543, 0.11432238929574529, 0.258771936979986, 0.1311582975810574, 0.14843086832233016, 0.14006273670782968, 0.10098270711398895, 0.13305159195536567, 0.18217106590107565, 0.16550687622399102, 0.15033798292279243, 0.14498405488989047, 0.06555336993187666, 0.13770526966019986, 0.23056989625817348, 0.1931541467145566, 0.1864455147616325, 0.09860224210687223, 0.08736077515828995, 0.21272625293462508, 0.21437001715023674, 0.20176197191880596, 0.09053733575368121, 0.18856469782129412, 0.21230870437237526, 0.12783756689919581, 0.07312665468141918, 0.09131210345414378, 0.12045488482521427, 0.12954422693339088, 0.13688554025946126, 0.16640497641938348, 0.08254127006136602, 0.1249592213500892, 0.17046082975162616, 0.07902920125953614, 0.14835720130753133, 0.13932589802049822, 0.05811626497175425, 0.12991433933136926, 0.22943312903085064, 0.07592069225445872, 0.15657763117023055, 0.1045038234142046, 0.16733278550447958, 0.13141769495221878, 0.11077803754878622, 0.07764340183066745, 0.25079038865383596, 0.10990614522128336, 0.1319727869403939, 0.09376462669141832, 0.1392717356042516, 0.22565358829113746, 0.09464941993956605, 0.10352595048325677, 0.1718661107964093, 0.15964222801548822, 0.16280157461522088, 0.15028880007805365, 0.10148608816727515, 0.1018113614390454, 0.15005572548797055, 0.08627166626073661, 0.17141735181212428, 0.10684295797780638, 0.06298743503829164, 0.1367719907073244, 0.09750224709991487, 0.18288136730271, 0.08715436042797181, 0.10218233951637823, 0.07821855000070027, 0.05348518686068635, 0.24038230279280295, 0.09313230537959645, 0.2954312053418929, 0.1067596688986786, 0.1065949063688036, 0.11587256821052683, 0.12183120008558036, 0.18342967175187605, 0.1549627025040888, 0.164634884305058, 0.08751465923964016, 0.13775609193309662, 0.16446822953801002, 0.08322459750718648, 0.1928620986760624, 0.21092674304400721, 0.08863441165416472, 0.25746073153230453, 0.11936268093244684, 0.13219826193826814, 0.1879702748790864, 0.2031743929030434, 0.13881877845814153, 0.16675317870272746, 0.15689034826092182, 0.13294666855325624, 0.0965715958286197, 0.09012896492476426, 0.09972401699351688, 0.1623797206388366, 0.11961008902759322, 0.10258122617679258, 0.1601649144844663, 0.16974014019773853, 0.19493006109710664, 0.1517915734720807, 0.21424405697372653, 0.13518245019499334, 0.13866364565347472, 0.24961292683597536, 0.12227664190915324, 0.1402935436776569, 0.1777166783088638, 0.18339254713106543, 0.07716233691861553, 0.1969314351557724, 0.15810314205385026, 0.1350342887904375, 0.09293493814766408, 0.15945179387927055, 0.27384367501062734, 0.20163210469388193, 0.11878556391644864, 0.1532473550328324, 0.20125623131471299, 0.22949721994659594, 0.22386679546006266, 0.09709203765997965, 0.09816735697489593, 0.12123415712267162, 0.1189398693461572, 0.1901998052433614, 0.1346415001899004, 0.139692394483474, 0.10384180853443761, 0.30208728366321136, 0.15324897913923188], [0.025388747528796236, 0.07427229320690518, 0.03772298527520992, 0.013937078502720163, 0.014341300007917229, 0.037770425269920985, 0.05754421945781477, 0.04306365615658222, 0.021481668471448848, 0.01725431678125695, 0.05940261852717208, 0.0213280123012561, 0.034506929016882376, 0.04053237908069165, 0.03451569689317577, 0.04507697735642714, 0.016525539254108747, 0.037328143559035756, 0.051169011952175256, 0.04637843050483254, 0.034548680808755665, 0.07893080492654155, 0.008155451242571637, 0.05302933007178288, 0.02167345283763303, 0.06879971347629063, 0.024427845360591047, 0.02090535393255132, 0.011065430477291588, 0.06094260464212107, 0.0525647207283445, 0.0877167991993408, 0.028465383445783973, 0.018148155612570625, 0.021132506662979725, 0.00688861521343971, 0.010862852889864195, 0.0370031537397975, 0.044411526572319775, 0.05101007169052478, 0.019123366387981563, 0.051260724168030486, 0.01130781016282497, 0.04342117406908543, 0.019875674305724043, 0.053693647045762315, 0.027877899344950437, 0.03131035820490891, 0.01337380086507408, 0.038495106141894095, 0.06348436563125541, 0.06643051762254008, 0.045072422963717294, 0.0395822576848009, 0.05221430445089937, 0.055270401550637144, 0.04073391383093211, 0.020064417302848834, 0.01281727629248053, 0.03130341361787531, 0.06309104843005058, 0.028231560004754897, 0.0787394744674525, 0.024231587040929065, 0.04881755486431141, 0.04304179583766288, 0.022042282038338242, 0.011124348384328188, 0.03957084680516874, 0.02601954624086859, 0.027744084851996555, 0.04789944828277634, 0.06624350789934397, 0.036655181282830816, 0.054293524533990896, 0.03340363983185061, 0.03959660651162267, 0.041606104932725436, 0.029913529025150404, 0.01224857283711073, 0.015764176177101272, 0.045699806838867166, 0.019997336728979024, 0.01733792953253273, 0.055042973028556, 0.017995981822511362, 0.03112071313925328, 0.0332610861909005, 0.04118682884220635, 0.06566007065797044, 0.053985086044356714, 0.04705906515159915, 0.038272726139233965, 0.06724866122127542, 0.017291150288656354, 0.0414746978710736, 0.04418854136019946, 0.07045837810202953, 0.04076404023855444, 0.016085864157385884, 0.027243118890891635, 0.07913844539753853, 0.10370923701914088, 0.03114054140995347, 0.059766127247243166, 0.027149154376539014, 0.024529917000402367, 0.059217684902250774, 0.04660829135607328, 0.02329912588691279, 0.04771477512774929, 0.03621158190071583, 0.031214300355303193, 0.03942661926210408, 0.02985143376844785, 0.06421141754535419, 0.04868119121378949, 0.02488301458558248, 0.05615438274558514, 0.0564235324160226, 0.012935210740373982, 0.02692063034872615, 0.02732822168318014, 0.012914451672845792, 0.054769368556838845, 0.03574273609105618, 0.04567899606040409, 0.04800316126596543, 0.041082280823179794, 0.06683638334394464, 0.06711591350575609, 0.05040416509033211, 0.05323591334144435, 0.04574224427943269, 0.06748001211352887, 0.009524769247359326, 0.05549422179859492, 0.056916954326293165, 0.052728395413367025, 0.03118142943769213, 0.02247154408495032, 0.012395411782387285, 0.04446028806870023, 0.060790168466947736, 0.014992064886516141, 0.05310870061117796, 0.053856938686822696, 0.05219780674744999, 0.0842923172298939, 0.07326806685136211, 0.031330692093639124, 0.027848228759643052, 0.048168333652879924, 0.020676473673853665, 0.034103089598037546, 0.04542148709597607, 0.009534278313719459, 0.06066609669717089, 0.06003962446665091, 0.07641102683039443, 0.05379569761815572, 0.08544257526556331, 0.04955088486894966, 0.08159461521333264, 0.027764673464961594, 0.01472827495871893, 0.017752925106774897, 0.029046700538827047, 0.01582365045549288, 0.036026161809962605, 0.04435926788456498, 0.020324889112324006, 0.011626265252069121, 0.0758890834667029, 0.009003529726948229, 0.03643317666325358, 0.028091166731751258, 0.036212443749630646, 0.019370410591363907, 0.029347401540425998, 0.030778656796281858, 0.04207390120192882, 0.0406776063684975, 0.025911020310295206, 0.07671268161145911, 0.013695320306015352, 0.04797909078338454, 0.03527106341695593, 0.06874564299059492, 0.009526717983516715, 0.06396963253557202, 0.036584187914887746, 0.009854406347468255, 0.02448151939578595, 0.06197536394240395, 0.022513313113801905, 0.06721787214759858, 0.030627047996066754, 0.022965498426328265, 0.031945824307659944, 0.01452552212867886, 0.06233009329486278, 0.06615782862589245, 0.08925126565079536, 0.04729035858725829, 0.040916759866259755, 0.07727636144526544, 0.04828573662727591, 0.020875154746576183, 0.0050222368595460734, 0.031309136294669686, 0.037156880773123235, 0.025919698171257496, 0.08216323631425058, 0.04998101259491617, 0.10809116035459504, 0.04371107706139165, 0.02881330993747519, 0.034132231582677176, 0.04823940362961543, 0.01016598579759199, 0.0286684331348947, 0.030415075297857967, 0.010273769580488725, 0.0038423697650057055, 0.11681939925878279, 0.04676027553937128, 0.031253005032457655, 0.021345149688122254, 0.061510494129071315, 0.055833457022785186, 0.05852537507551813, 0.04465646786434997, 0.04593277417664086, 0.03453155491320837, 0.043333227175378033, 0.06356054158400624, 0.027130643777068586, 0.03704484807507646, 0.016144393274800915, 0.022859711260084185, 0.0352815818041563, 0.061428787021507184, 0.03195131332763741, 0.032119521337951866, 0.04639380588947285, 0.04864474458079185, 0.05022905271260008, 0.022357896856603124, 0.08595244508356818, 0.05123591441060266, 0.040073109370085506, 0.04355967127447648, 0.02641901321288559, 0.02719798290561284, 0.07275306424426456, 0.01792861971132938, 0.06568470804561531, 0.04401255564223375, 0.07885100920834849, 0.1471723237585637, 0.04730947631140871, 0.1049854782139582, 0.01634175476107386, 0.04019264206891099, 0.05622532631781313, 0.03578910356267326, 0.03082474081536695, 0.06765589057918518, 0.02434836565366676, 0.09354836007039394, 0.03936841573205687, 0.051509683591223536, 0.06122485441606372, 0.05470051257420452, 0.03147729259404925, 0.02718080529913066, 0.09750133545528497, 0.024089012332561038, 0.0457229541854993, 0.0963913889661912, 0.051683405519373, 0.017772977458192937, 0.03517492704333798, 0.059642534282418995, 0.020821074684781414, 0.04278123018241698, 0.04372331914642165, 0.05611679847201994, 0.04327153794527535, 0.03259526768458947, 0.011585089941358855, 0.06220943061634899, 0.04176707915781487, 0.027197471541923382, 0.026154571152742834, 0.07034274479073864, 0.02160789677873254, 0.011020158511406232, 0.043873909049697464, 0.0554756939621462, 0.037248022253474886, 0.03751156799074623, 0.029427467304612362, 0.10795607607090667, 0.051546279611366416, 0.046307927433161006, 0.039758572820574045, 0.014459695066175154, 0.1637421160816185, 0.015794950886629522, 0.01796589946494468, 0.013059171427401805, 0.04975942166281804, 0.007164701331226576, 0.043353486370535634, 0.025535288657392227, 0.04758889539047115, 0.05800193400993463, 0.02722419843438172, 0.011425158553456348, 0.05464042446786358, 0.049528576388594606, 0.022332478059275497, 0.04006678531427057, 0.04037410148509568, 0.036431809196308736, 0.03858769169798301, 0.022958538517536178, 0.034567024784102555, 0.015258278524983796, 0.03657382657571185, 0.027562389863775145, 0.05259381291726905, 0.0598593792998262, 0.07650913204997778, 0.02310492068288788, 0.03571752413746811, 0.09665124599010715, 0.044140166738220764, 0.02911676119472231, 0.02555679466064659, 0.026715663524584907, 0.05972422606822464, 0.03758825722240633, 0.049217295712761344, 0.02236001125927414, 0.04135160669383984, 0.022482962625461723, 0.057840909989130114, 0.030218893586988413, 0.04117729104754906, 0.0847698504766149, 0.16616031857988528, 0.13560191397705387, 0.10555143332889966, 0.11221637528750206, 0.1377378896840157, 0.12024012739740073, 0.1469557660241281, 0.10980306043019218, 0.10781256482005121, 0.1966819816058682, 0.16518801510814698, 0.1375789570832445, 0.0977757941150377, 0.16483167697104717, 0.11133567294886998, 0.07148426942407124, 0.10037130766337919, 0.09703124092230875, 0.15900101242286546, 0.13926720036373985, 0.1632826012228766, 0.1455651325804572, 0.1387308468861926, 0.17133237733956308, 0.13599169951292778, 0.25579016956110157, 0.16172615570887444, 0.10338446170452142, 0.28693397259039266, 0.4244735987196046, 0.24690960173404988, 0.1005013510885258, 0.11627682514729039, 0.08429683714864716, 0.11394960325091116, 0.16527249928443663, 0.20516165562214392, 0.14566115404088653, 0.1865152747280175, 0.10323700510085591, 0.11940029584952902, 0.15555338693722603, 0.13287787385765584, 0.08682659737044766, 0.1473842236784197, 0.3176669379876506, 0.061777108048479405, 0.08303733497497537, 0.22250631523709144, 0.10657807541710716, 0.1510759860637688, 0.09240580121836356, 0.11762481813709583, 0.15706184470365125, 0.14321615378702843, 0.1722870607890429, 0.17884184696501304, 0.13722384468682353, 0.16130825474617944, 0.1511801280561955, 0.12522552883432758, 0.14183540287758076, 0.13025569278867016, 0.14932386637214692, 0.11129942932917226, 0.11872369465568375, 0.098388472932481, 0.10604972755836864, 0.09320614859461786, 0.10922385965503993, 0.19638739015546539, 0.1305143700371827, 0.11330987386886152, 0.1130687247120565, 0.09648698907826217, 0.1559703685944119, 0.10620125208891208, 0.08601594611161179, 0.18203298621360334, 0.14492069941855248, 0.1414708829214496, 0.21074562453694884, 0.1405201065203836, 0.16991906769333348, 0.10121842470741081, 0.28911045902679045, 0.12404645823182599, 0.17003430263890376, 0.11493303798018925, 0.24372154215891517, 0.07973376466261764, 0.14043150079106131, 0.18944519331618664, 0.16344377080038672, 0.10115654778576667, 0.12385047761903656, 0.20931516984297385, 0.09665128429450336, 0.039506598841398954, 0.1825615409160814, 0.19245504551837522, 0.17965037616029864, 0.10355050360122997, 0.29850380014508004, 0.1368833645697563, 0.17089118730396996, 0.19493409071958837, 0.16873607472065957, 0.10297559291845369, 0.11772281610436978, 0.13107082566186307, 0.1535682692643135, 0.09992453284681806, 0.19330299759824432, 0.17220683606161227, 0.14422970343260996, 0.2546108538104642, 0.07711476285851772, 0.19437156767854769, 0.08858302247620399, 0.15734601735828385, 0.1286234352136812, 0.11784669252172594, 0.15434917332904954, 0.11940735918019088, 0.15732079774381655, 0.17878935462044132, 0.12495817947051219, 0.12584167803006788, 0.21040312194776153, 0.08706987625168217, 0.17588588138741834, 0.1985098980367184, 0.12003207323892463, 0.08008241127695769, 0.14061179192316148, 0.19642365675780082, 0.16604539006948474, 0.11820364352916518, 0.2119598585751749, 0.14399284436818094, 0.1721122548464806, 0.13147256216935574, 0.0959824895366065, 0.11935433057407219, 0.2114786174629004, 0.09413345972256315, 0.24949133336063356, 0.1798461116249523, 0.1099833975275678, 0.12477670090212939, 0.08110023569315672, 0.08541296596728987, 0.1209009778235228, 0.14645212450094763, 0.11674993806668829, 0.19129305867658508, 0.16880372028437354, 0.15140491357493788, 0.14708163427008739, 0.13926522385689521, 0.3373832832421026, 0.1464851735340011, 0.1116106678701697, 0.1995831106098429, 0.08402245509768687, 0.17773953837252435, 0.14029787973530833, 0.18141734263589307, 0.13231588707816216, 0.12929340974698145, 0.16071850494030984, 0.20019280934526076, 0.09268004537349747, 0.13139120363179715], [0.07700228582947485, 0.023399925820769805, 0.05737209865342706, 0.0204679770996013, 0.02337844471537298, 0.0392916958568798, 0.1478466037059984, 0.10140564127434647, 0.04735539179115046, 0.012657890742224072, 0.07345825583944399, 0.015786498063994993, 0.041268424867021467, 0.03217767698750381, 0.051310826318278435, 0.05442365988968842, 0.06750687115615414, 0.10107470661281578, 0.06451620945646878, 0.054123579419308135, 0.05589963552812415, 0.07711869288956927, 0.03939796374329636, 0.0624870187452724, 0.0366940334319107, 0.034765832261332584, 0.06794799990471333, 0.04325201802496468, 0.12389832747078712, 0.04570464851454862, 0.03813078153818365, 0.038568102829759164, 0.050196605058567184, 0.02964370711255939, 0.07671377711719082, 0.05281240461514362, 0.02885547924726721, 0.016747268082033244, 0.05114253595351212, 0.06282459155866696, 0.061014808428984504, 0.05633572341814157, 0.05415898800316838, 0.005766165211811783, 0.0765372321550404, 0.031784128044701876, 0.03608566002860185, 0.02660813159309328, 0.05517869699566115, 0.05211036547177261, 0.043224565264198093, 0.03491790071430226, 0.012113093060531445, 0.032828641048963034, 0.01874666946429399, 0.018317248454437624, 0.06256895184877419, 0.005866033870035843, 0.05191574466504878, 0.05386737663479102, 0.027231156427953995, 0.026754356710420504, 0.030059242778788173, 0.03701991191314113, 0.16230400050840071, 0.031277462389440305, 0.010285229298226055, 0.07891487029771652, 0.028600128735565854, 0.019123107833307118, 0.03429700560387104, 0.018023225824318586, 0.023278627289278854, 0.02864343568592543, 0.07217972404173306, 0.0577579350060513, 0.051794308237731464, 0.003214764921370173, 0.1092623325905973, 0.021010072406141028, 0.026143179425308784, 0.02227684092377463, 0.011467663026715239, 0.018401025914617123, 0.049371815647088715, 0.04103955993008229, 0.01855211569026353, 0.022636526865103555, 0.031162727316240632, 0.0548008049748117, 0.04885578265173301, 0.04107687224243437, 0.06551239954968614, 0.056046831661895405, 0.04615077598681373, 0.03259760808319815, 0.03204440258653655, 0.12301935649086392, 0.014708764614507317, 0.018609212223260153, 0.042224108061242493, 0.06489233564465277, 0.0893250092743866, 0.03230151893090337, 0.015601379620361955, 0.041868578146902785, 0.08176003657882253, 0.03235178579005503, 0.016039320485546224, 0.05911497549424249, 0.0440971662230309, 0.018786258973000992, 0.02990190172567964, 0.03650068050070155, 0.013250839922787442, 0.020162198850284183, 0.03322731320475859, 0.030238626096698067, 0.06095740546081817, 0.06544365848024046, 0.09172745334405093, 0.04353501090419389, 0.0016211247613330583, 0.019674825204175808, 0.007529142763345473, 0.014213255114643084, 0.03702143642811045, 0.009974772166911392, 0.022358142004738894, 0.029540055416404244, 0.062006298572786396, 0.042799371144463944, 0.043415190922396804, 0.010283286307728099, 0.05813768095967751, 0.05133768919134333, 0.04021950494197588, 0.055261089751917514, 0.06464410017454816, 0.03429688302980315, 0.03560420441170854, 0.008654213743284345, 0.05077939112520507, 0.02473734871243998, 0.050850047414461454, 0.02889945269412091, 0.02762017013024419, 0.011756395819717118, 0.09688208360345134, 0.02881368915099771, 0.05602000709322672, 0.08087487560847113, 0.0027368943565600225, 0.05113041644255, 0.04788998326647186, 0.03671945222923833, 0.04939972039973063, 0.07088621522510244, 0.06220907821590382, 0.024539855076000098, 0.031084057747296272, 0.035018545515354604, 0.04208970942624635, 0.04122989447486978, 0.06297767507813631, 0.019080867660382105, 0.056663919315342946, 0.02320647138291069, 0.010359520674683154, 0.043893505578800555, 0.04432633376470016, 0.043141712855187156, 0.02229058262591641, 0.031781101997400966, 0.016060905970422732, 0.09993010230602757, 0.034741141247533025, 0.0421373792473347, 0.03465465375132138, 0.02757595919613396, 0.045850182237524184, 0.05119220526408284, 0.12815213792266386, 0.06470240712646516, 0.013088339267508879, 0.017633924839056788, 0.04368068252299582, 0.03748070230827697, 0.08945722072835892, 0.05229404654293772, 0.035594567025621096, 0.08313687277897712, 0.06799331400543451, 0.04641067897600513, 0.03833349989426713, 0.049233498472359874, 0.014038377351337865, 0.0638643031068627, 0.0594233833403597, 0.02842075116331539, 0.08315094581414616, 0.025343594306539145, 0.054643768441653064, 0.05822121901738067, 0.02031537621552425, 0.11150038951346952, 0.03501492191947276, 0.0028226674757822747, 0.03735700975202265, 0.05838896162928112, 0.050444089762505986, 0.07401824312945528, 0.08400179370636902, 0.08162673727999772, 0.025854802863191695, 0.08345680641791514, 0.0795192753655776, 0.03412994097978358, 0.025628542625195077, 0.03225855672010972, 0.03586083237502364, 0.012378363453242327, 0.06787607190950264, 0.010322460213736182, 0.010268074674381605, 0.013540457547341865, 0.056258310233393026, 0.02621074071935108, 0.04148996217296489, 0.04632987968263127, 0.039683358308168194, 0.013683956349268557, 0.048706357202102105, 0.0460001822530983, 0.047035235986714406, 0.04478624315872308, 0.018109498815911434, 0.01655198460925491, 0.038946649855783874, 0.018828181219437433, 0.09124287208842655, 0.033855436354755394, 0.011442327541449379, 0.08201934968031223, 0.05900809856792612, 0.05921234143897892, 0.0469063570152127, 0.0381656002343422, 0.052925398753535365, 0.05037397739567584, 0.08585093843360102, 0.043551998903914806, 0.08428510068164718, 0.024734259462885322, 0.0644415618491269, 0.022137937691783714, 0.06139503318756338, 0.1216727807637184, 0.04452454369334925, 0.004210611711436462, 0.0621675179460116, 0.027436584820069616, 0.07257374604382823, 0.026483081145993164, 0.030378693782333887, 0.0672239778683551, 0.020592207832622434, 0.03898894940052302, 0.015297076090299075, 0.03498992830094311, 0.059070029115724954, 0.045933057629172845, 0.02596658658266308, 0.07726272508021324, 0.03971687465485546, 0.01036737882156646, 0.08123114479765778, 0.04491365124141017, 0.06001874090983503, 0.03744453529737169, 0.02083100126906028, 0.030123611401406028, 0.06338683114717565, 0.024147842139486345, 0.028815204089867975, 0.056876899419172164, 0.03923681331798434, 0.03368125094341175, 0.020884931943709814, 0.04451928066930944, 0.04440242927821894, 0.046397103897986874, 0.015222845043266013, 0.060547345408028176, 0.0053757845213817015, 0.03326950932762796, 0.014451188617385926, 0.051039217505604036, 0.05305536173944993, 0.01833387447761432, 0.017317009586540442, 0.04008671509162073, 0.015480054275793655, 0.08097053700757605, 0.04912149258739045, 0.010307251453219403, 0.07066283930814074, 0.009008394385267411, 0.06579380662691209, 0.0035212568294692545, 0.03845512018268628, 0.05092586713632749, 0.03973702276726404, 0.06304173918080426, 0.008523200259303615, 0.022410205340072997, 0.017373566027550448, 0.00682735642898948, 0.07171016577030383, 0.009773518953983103, 0.0247029360428813, 0.015990739977437884, 0.016924810873705055, 0.019370900887635448, 0.058190188626007694, 0.03937001302537899, 0.03911645707464026, 0.024303097518221028, 0.01851824502791128, 0.062439574920121706, 0.034278462445663835, 0.007533882932376958, 0.0409949965955269, 0.03789170464921383, 0.04991191146414607, 0.029215427573710203, 0.022906411979948322, 0.032215770709538655, 0.012036039937107314, 0.026180874781623006, 0.018034755447579008, 0.01813339884392917, 0.02529291375990837, 0.030035974773307963, 0.02315305207195061, 0.010606857906696538, 0.0015636940224794673, 0.040759014701771165, 0.0417678720588165, 0.01395356663007049, 0.040023915034027836, 0.06725626847436351, 0.17155022210171147, 0.14954566414798462, 0.1129933033559111, 0.09572827091981327, 0.11117639560853282, 0.10211210457548019, 0.3195637410446521, 0.13444849199825717, 0.1713495989961009, 0.12220258418951305, 0.10248924966060347, 0.10559706918654904, 0.16397931222473422, 0.12279543665147598, 0.10972325705111989, 0.34962561342024034, 0.19343943785755865, 0.2320453662785792, 0.1477820837810155, 0.11195381397321341, 0.18249464611853325, 0.17229398622387843, 0.10032207119248568, 0.09535779846051047, 0.16286142140386567, 0.13676172512913906, 0.14291803833217392, 0.18053310863193006, 0.17920618306004232, 0.21637971092376018, 0.14703062813608878, 0.1654936841899349, 0.13216889012725125, 0.11596297424647117, 0.1846783337814193, 0.16355339798235125, 0.22874700536410655, 0.15422526626817643, 0.15098350392954965, 0.14738129722254892, 0.18722913077762052, 0.17300494646112766, 0.1431127932042845, 0.10882884939952243, 0.19351004052066034, 0.12024067898070621, 0.14566644004756404, 0.10473295265147764, 0.1440980588837016, 0.10595456411641453, 0.15998053244285046, 0.1775286803322454, 0.10966593835262523, 0.07481539591906533, 0.17385197923548762, 0.10213389211604673, 0.15615010814320657, 0.12284307965948699, 0.20812450066929866, 0.18524949829424583, 0.11755794632218539, 0.1043453274835502, 0.11054955182536957, 0.15679132373582932, 0.20939309630663167, 0.08910445256098624, 0.11144598960996636, 0.21724133001219845, 0.15617630835021698, 0.16150949072212945, 0.2334180732648219, 0.15050056210208326, 0.1244508300817782, 0.14673635844261418, 0.20771380093309189, 0.17798752103361393, 0.20427613459046812, 0.12748250812892953, 0.23489360457226155, 0.158383943921616, 0.19374441746021473, 0.19434017339541068, 0.15239120581217352, 0.15671656887617805, 0.17461097318558924, 0.09952315640064979, 0.14661649632598125, 0.10296298311122003, 0.09245435587100445, 0.12259586308632167, 0.2226210598863902, 0.2001964865672973, 0.16935568663381761, 0.11107832869334568, 0.1472931664677397, 0.1435897901894585, 0.07683085067377937, 0.24674025033750843, 0.19410283935646858, 0.08847373237292613, 0.14582914180092274, 0.24029837019981878, 0.16450081891830892, 0.08423287646784898, 0.12472668302155311, 0.11387623501040282, 0.23795974891512628, 0.13648821641841244, 0.1155637811508871, 0.14639425421914748, 0.14779863128017995, 0.11791822215121602, 0.17224429776110958, 0.1297225262368879, 0.08229304225214067, 0.16418496086712808, 0.13591803249812898, 0.09353410317412308, 0.08320886206122176, 0.2752120919044941, 0.2040151897216997, 0.12769483705802312, 0.13761113277606427, 0.16746142698872477, 0.18962854879998392, 0.20461552686268286, 0.12199462962246711, 0.13078536597951768, 0.14137532111377488, 0.1134330378244481, 0.1621965796596581, 0.09734225729780813, 0.15967006765065656, 0.09175942219313114, 0.1542413541145863, 0.09592479545502894, 0.13620519289566627, 0.1474544739410762, 0.15174055201632364, 0.2051004451969939, 0.16825668754116183, 0.08947141633759584, 0.23745080606350977, 0.13676485076787012, 0.09610493336954425, 0.06265193066229263, 0.08686233537211534, 0.10916304759561055, 0.186982128709074, 0.14338029578568476, 0.17071028330153035, 0.1891114547728531, 0.16583575776988463, 0.1717291802408234, 0.1232541471178974, 0.11407221562319225, 0.15184037327285738, 0.10529364474237927, 0.11866252253492994, 0.10874121660186399, 0.18613721033738506, 0.11899603891276544, 0.0929983702277945, 0.11254985336094134, 0.1665393635630608, 0.14450060744439402, 0.15127714543092638, 0.09159451410655053, 0.11875878148261579, 0.0987335112726977, 0.09081543333107427, 0.13753317566888948, 0.13893951391500814, 0.15634287118671403, 0.0972568461551301, 0.29530005108925605], [0.02840278257105139, 0.04521285837155677, 0.022150398111872138, 0.018353455684958928, 0.038789678440098806, 0.10265448716499152, 0.057381736039514505, 0.04334051267153794, 0.008976459052533874, 0.06715025722740159, 0.01758700386891442, 0.019541717427332076, 0.021868973797667893, 0.08438781008965547, 0.0786857640430812, 0.06273544190691845, 0.01658059033234754, 0.045632406423288974, 0.012739328761404801, 0.02407019912836052, 0.032582508490210584, 0.02648391618183063, 0.043553029292172966, 0.04989277458779755, 0.13507732761002358, 0.059900905095761826, 0.06724299217063574, 0.013946734083395813, 0.03897714781604948, 0.02649324713274837, 0.03058596078546778, 0.04220400208366975, 0.051637735187767014, 0.02102596873056985, 0.007003204729933773, 0.04137453570541355, 0.058379891148257645, 0.04235196430536528, 0.035411755464250044, 0.03483648472014935, 0.0395972385341602, 0.05171756154947704, 0.05428262310282839, 0.014863358284797401, 0.07514253078449158, 0.04518713696949905, 0.040864834426752025, 0.0030200634360118142, 0.016271494922318285, 0.00990575051776344, 0.0282033545626027, 0.02415874740108848, 0.07856066188504619, 0.06093209008536032, 0.061468481867303776, 0.0744748238714472, 0.03210461518216518, 0.04682155108199485, 0.036529604150282766, 0.066638219380571, 0.07083661869288453, 0.01167566164381682, 0.05041272995332557, 0.03928657838954561, 0.07217272965898437, 0.03183891482260679, 0.061305841400979035, 0.051260245363077814, 0.06819861790826244, 0.04448903551805885, 0.025164528915117827, 0.03128157628159369, 0.03135176717243608, 0.09859052862250998, 0.05133225379752056, 0.01650661688237902, 0.025733531144778096, 0.018175321090365612, 0.029095423730811285, 0.04146806354964933, 0.04829073918142146, 0.04426097114300055, 0.019465913027224523, 0.02744020841595146, 0.01419039217815284, 0.05763387855803294, 0.03794264183529923, 0.03313275114182503, 0.035421350715501655, 0.05511442221881402, 0.014086222415038896, 0.01228451768251797, 0.03583139544653316, 0.05930029982400518, 0.02205846181529905, 0.048720552811339024, 0.043566355391615824, 0.00693559555539621, 0.058849939715958414, 0.03512803097105315, 0.06364195757815916, 0.02328852323004075, 0.05987257133388232, 0.12370927229283318, 0.026007840417385585, 0.04250636166562477, 0.039400262007069205, 0.007585861519234436, 0.02511301333264959, 0.04082026343131739, 0.020064216204768708, 0.03610180150116644, 0.014359479274360404, 0.0250271980785915, 0.01726769650685451, 0.055924146511261506, 0.044791609604632666, 0.005662210910926543, 0.017087194700575164, 0.03621585667133331, 0.03613770421173784, 0.0039096064292900865, 0.016479415015407627, 0.06275914849773531, 0.009398116718887562, 0.05435428296726558, 0.0443633702853995, 0.07221784457684526, 0.06250810148494859, 0.051603556175025246, 0.013206250732764603, 0.05140263046468458, 0.07267776546218703, 0.04241726947047057, 0.019446820200931643, 0.09059086997782992, 0.03939935802331856, 0.042335340197408394, 0.011067766087850737, 0.025100821043334665, 0.11107861214587766, 0.02411393125751807, 0.020591227240079356, 0.021673826305496118, 0.04092324097009917, 0.05232531825200685, 0.03867748869402755, 0.019883745042006337, 0.04464061750519661, 0.047609407394643755, 0.04271156980746216, 0.02667668880143714, 0.07818026858712397, 0.02680234445799743, 0.02123203297566262, 0.015291406082049494, 0.006250876702383282, 0.027346720791331706, 0.02981433213027495, 0.05333536304533482, 0.03935812334079416, 0.04087191307917237, 0.036667657024677724, 0.03135476449143983, 0.050379232758836406, 0.08834300712952692, 0.04787056676803097, 0.03229209604943472, 0.012188652312503228, 0.07698751565429472, 0.060052820331146645, 0.03812232009705998, 0.04244768699150413, 0.028493228826611757, 0.04386911333929147, 0.025466034309037273, 0.03655551707432155, 0.06895435598468588, 0.0530539789507466, 0.006339223877031116, 0.017178943305606806, 0.14615601619645474, 0.01387322411662148, 0.013239092922078506, 0.05370739832400315, 0.04794521437537286, 0.024774117102365822, 0.012289478101827686, 0.07966525341954925, 0.0641992520691166, 0.01915916376146338, 0.04746876897350435, 0.04291902641735731, 0.004624993457729298, 0.11866290557889209, 0.03632323155480047, 0.028973855153327028, 0.0441746789992096, 0.031764016321469704, 0.020278395236199422, 0.029331846125123483, 0.029595351642778808, 0.048944997420955094, 0.05062797001653141, 0.030104815434183807, 0.026436761554871357, 0.053072020321363406, 0.06183404753345156, 0.07505288317559228, 0.006871062702679586, 0.01968438598147083, 0.012993196892972677, 0.02173583154686757, 0.025265076039959828, 0.02226315859344698, 0.011290918881704491, 0.036246262701048006, 0.080551877617836, 0.04426117032586087, 0.020826864394269163, 0.06787979509681463, 0.06888065066549086, 0.04465352225628111, 0.04238259250057801, 0.03768325212501711, 0.029451127930153764, 0.08513523611210047, 0.043717539013032956, 0.030847259969901175, 0.06818103619040021, 0.12345486981493813, 0.07763043962298863, 0.051069003004100055, 0.029766468871985714, 0.03708146324741744, 0.0671742587620693, 0.03284291326699238, 0.022979542733200138, 0.03173518651765922, 0.048493354115635164, 0.021385371219366792, 0.0068238065690703455, 0.007013115992454151, 0.037305360104167656, 0.049096407038309885, 0.06280307980975317, 0.033947068131378585, 0.0490748608154395, 0.0330560734014838, 0.020508763620689995, 0.05272943346250442, 0.026223111124108398, 0.01276325177206027, 0.03664425686903058, 0.051110065316841494, 0.023408946506078207, 0.06368483168884151, 0.04605798741742488, 0.03260549112793899, 0.03914136642349824, 0.022455084685897155, 0.05241331877186895, 0.0138043231263216, 0.015316823921767215, 0.04067127465180332, 0.04584671952010644, 0.04107797157860572, 0.04539949271166998, 0.03512588209442554, 0.029372843320391355, 0.05653982456292837, 0.03587906526762151, 0.04405075278613837, 0.03857625400527351, 0.043152231242387526, 0.10404594032274139, 0.06160366191198269, 0.02606100500411084, 0.03468930773857621, 0.024121027146916718, 0.05585941974253905, 0.06644323468208313, 0.015623346233980791, 0.009286957361074466, 0.01611614186737326, 0.022000846257733724, 0.008880866601342156, 0.042643150494944666, 0.023268574300492485, 0.011623147274217299, 0.043121894160586025, 0.05804730173681052, 0.06258652973619681, 0.000899626984685329, 0.02859596313247758, 0.026763561256830732, 0.020299460738897324, 0.0872740386835029, 0.031380709974215396, 0.009820075074751532, 0.029919720930798404, 0.08387659195690386, 0.016937332580827417, 0.042340396377708645, 0.02113154713785456, 0.03172677104181099, 0.022036023099996874, 0.0143965617603352, 0.032291621074921666, 0.015208002089733079, 0.014105020297480928, 0.07430449954324192, 0.03837286532225628, 0.012061336160367055, 0.03637943559536531, 0.02174809852975511, 0.05433582024829042, 0.04345859746418653, 0.12429180555045606, 0.022147190118689212, 0.020471652406418038, 0.018905217105883266, 0.055378102021472114, 0.016892349813133478, 0.13120878277526749, 0.027086833123898795, 0.03945156308491865, 0.047979676840646614, 0.033328455962961724, 0.007553822764631121, 0.09192514999379074, 0.03135295843915834, 0.012138238939036046, 0.03402695961056217, 0.056111382230395274, 0.03191720517802864, 0.011245322286061222, 0.04586504817369484, 0.01731211045426467, 0.06592448590503586, 0.07307836815955178, 0.022686042958089424, 0.01428208715702978, 0.017499087618723992, 0.037196453044851946, 0.05363139474103528, 0.0559076258251744, 0.0344548158858332, 0.03793276696195526, 0.06560809925318727, 0.04653324155257114, 0.03194862052858357, 0.18272759813454845, 0.2033742499207297, 0.09703595236304308, 0.09650508407503368, 0.13539079546688065, 0.20332981682112142, 0.11719366385331077, 0.1159208317497565, 0.17846683160431925, 0.13368324677069343, 0.1302176335405919, 0.10361043465954643, 0.1621419882341739, 0.14196914650740164, 0.1274254499003291, 0.17028260705692155, 0.1271060525229381, 0.23970433030157323, 0.14260499948455443, 0.2527430088770005, 0.1525622119586314, 0.18193906383408656, 0.18821583670233527, 0.11541610238172355, 0.21429768312842618, 0.17617183136603526, 0.17651623385327478, 0.10057602167850542, 0.15578580269169423, 0.08606052476792567, 0.12391746434713564, 0.10788326707458305, 0.25109627224024267, 0.15146803921989857, 0.140005954270882, 0.16604240232658002, 0.12047899361219137, 0.12177876136716335, 0.1718633222363649, 0.10257581759604717, 0.08831303010904983, 0.1010578833219986, 0.1363352439816921, 0.24885739560329148, 0.12856366503382885, 0.18411829286525327, 0.072950622998178, 0.16488908760009274, 0.1069132465448591, 0.13642262397033555, 0.18559693448966552, 0.15845224832094487, 0.14859524014736378, 0.30965666136434006, 0.21380004773457206, 0.18482911520667616, 0.1804090330317136, 0.14924857525094865, 0.19508056673071078, 0.2026550312556567, 0.16653130431809735, 0.08415189331337329, 0.16350216202197537, 0.19053032621741298, 0.21976318420662036, 0.09604864122886812, 0.1460864094476546, 0.13230508523842982, 0.11229866079144901, 0.12630166786332286, 0.10949769012269475, 0.19860696137672473, 0.07354557454105347, 0.2961158121545469, 0.1427728340270058, 0.1627695061747105, 0.13776266496748696, 0.12181580937918156, 0.10128107537785846, 0.11285224358641333, 0.20464545025700526, 0.19441002529234658, 0.07772569499549367, 0.14766036773160582, 0.17431730104069557, 0.19445954521577205, 0.11859643979058151, 0.1744191907346249, 0.15836486833230143, 0.15642910204347105, 0.0943829745595013, 0.1282407513128654, 0.19549860558923216, 0.13161608108109044, 0.11133131390858082, 0.08847462869579754, 0.151028917621701, 0.13982498898140847, 0.1354413266263662, 0.14194354384897218, 0.19556799783341347, 0.11849533916721422, 0.11582795124981674, 0.22119393001400658, 0.18674871704030424, 0.18328618348365833, 0.09853876406146635, 0.07414097807580426, 0.13162971744614263, 0.13276692900446155, 0.13641128586905618, 0.14315028554729878, 0.1920594223925183, 0.09806173643277538, 0.15814138516303033, 0.15540366271330466, 0.10776655357931891, 0.1753406872552249, 0.0909579027023527, 0.09572587306461028, 0.09855342698433707, 0.12400479070962438, 0.09684295183227909, 0.15311154296561597, 0.08561622441535996, 0.20402046040661875, 0.09703433591752283, 0.14509029596322967, 0.1475469867188123, 0.21307171262320013, 0.13165663777580186, 0.09402397809730423, 0.1069176821939407, 0.1520754243697851, 0.08815792794789999, 0.22280542660624753, 0.15076195130184775, 0.15270442852089483, 0.1051709097960303, 0.12129338338009774, 0.19348471365388364, 0.1294686293770229, 0.1806844416404924, 0.12667759486864652, 0.12427926469113558, 0.1263240146480741, 0.16380256041884422, 0.07976004913929971, 0.20731744236282765, 0.10351915528336841, 0.10348764608704275, 0.1411090902383289, 0.17235944077612894, 0.12237982629167458, 0.20063168579532256, 0.16078863262889848, 0.0951007453183974, 0.11806245352472029, 0.09098432507486114, 0.2004595764822537, 0.09606384041328585, 0.2576342657689126, 0.0930237660424844, 0.10433713800363964, 0.09408039281204825, 0.11988769630871474, 0.10255897898347148, 0.15725120631677492, 0.10140245434858146, 0.11326750154576956, 0.17599723992809174, 0.10611803195769749, 0.15907046595408073, 0.1545404654837424, 0.10414398425529081, 0.14894445366676778], [0.02351121732874984, 0.08260798865869161, 0.06455934786748502, 0.08816190394422702, 0.017974336008210818, 0.049109480328737735, 0.05180638178341812, 0.06420090681903305, 0.11133096150813565, 0.0958181023898144, 0.026261396368124315, 0.02584525549243535, 0.032232057738808856, 0.047255168338456464, 0.03522089231879481, 0.01304327606058289, 0.021584697721165516, 0.04907144023285759, 0.067538702109408, 0.01504629146262643, 0.020339906350859714, 0.04500152918720438, 0.04328657242078935, 0.05819083597030371, 0.06917172577232122, 0.04126217358955934, 0.034963544232830886, 0.064113381273684, 0.022263032188939474, 0.05674579496225042, 0.012139887943293058, 0.020703859401926882, 0.025869283840180408, 0.019930792416656212, 0.023771158622337446, 0.02901179757299683, 0.028272940243984905, 0.01801878442957757, 0.03621669170717078, 0.00976397732888619, 0.05623381457201416, 0.023798755024589842, 0.034028989743561514, 0.01074043108195427, 0.036402897038046396, 0.02134827915729294, 0.02240196606444736, 0.01434385969919423, 0.05853485158314148, 0.047572673478674506, 0.03527050417277121, 0.04169618921174158, 0.009043521431815481, 0.0593484292978481, 0.14730801325171225, 0.052297444142881906, 0.022023283057816086, 0.031934455562863624, 0.01297471885223903, 0.033114774888681794, 0.049766822072166594, 0.011326840744474003, 0.0560090137315133, 0.014051037911896505, 0.028938860256945895, 0.039230313061946825, 0.05634713812821335, 0.04913157047403436, 0.048714205772886356, 0.025693681166176836, 0.05507460479894954, 0.016983920302722725, 0.03029334009625018, 0.043273388047612486, 0.0442294083205202, 0.03133011752769592, 0.038685291299536344, 0.05448623395134365, 0.05239862520548125, 0.008732062640539821, 0.024963438495873444, 0.04408448363744444, 0.05802187144816403, 0.024498750628422827, 0.0464882760218555, 0.015075197875229342, 0.02573206217118329, 0.05603825147714346, 0.009378478054948633, 0.03864645447221495, 0.05979187163193861, 0.0121274390145235, 0.0809129731609456, 0.024861686697770512, 0.021754367044195536, 0.06439266245692007, 0.039390973190987305, 0.03744035245730512, 0.037331085336664994, 0.02340629967229982, 0.07334365674685087, 0.02532069019282297, 0.04455146402300847, 0.019212339839507497, 0.021124583398622852, 0.0611692977197949, 0.0816846841705903, 0.047763410219622236, 0.018439971909467733, 0.017584257443705877, 0.05084915875246929, 0.039415307973902074, 0.06682612542663852, 0.03537612088445214, 0.05806787502801707, 0.061424753568585844, 0.08065820296084689, 0.09981762527698472, 0.04056765742960476, 0.013497683028089664, 0.06315137402364804, 0.019142712023289456, 0.015599849359733204, 0.07497233669123343, 0.016123846796671712, 0.02318238749379112, 0.06742339821592455, 0.040681992221864006, 0.06105999995563781, 0.02682217464391743, 0.037430037083404685, 0.03942235981324508, 0.09987099862266934, 0.0555258957038243, 0.08727931702930121, 0.09429663645043489, 0.019525311654433608, 0.08024766410310423, 0.05339466208111375, 0.013031969560430417, 0.009676271752874938, 0.018526200851004933, 0.03515768623460205, 0.03056374998132308, 0.042487079232570626, 0.029999953319108295, 0.038948385044932365, 0.06320669706309996, 0.0549050580499874, 0.033206644152561506, 0.048437628880023, 0.09952357774900814, 0.06078326601474997, 0.05835976218804718, 0.04837723050807272, 0.011913126875315944, 0.05201833149898918, 0.02426066199287532, 0.028981035312397346, 0.029187812019259702, 0.022929038386791948, 0.02687698631967989, 0.12728934671970146, 0.020545690973860123, 0.01802902510990539, 0.03687083503351577, 0.026099158097959818, 0.018399443943053484, 0.029097815840354854, 0.024005692609916293, 0.04231587390325243, 0.07164167750987314, 0.05165617492410445, 0.05255797532417121, 0.12138375877252511, 0.02706589019526878, 0.0110903101402425, 0.020583800017653454, 0.031243522779174873, 0.028984136053270874, 0.05129764577554119, 0.061530814611262856, 0.009417126233118677, 0.02054903877808923, 0.0600322125659835, 0.055132095867227164, 0.028872097609564665, 0.02224789429155569, 0.021229315278751236, 0.06045631884086517, 0.032405388962116935, 0.01854331717045317, 0.07497030655823408, 0.014888973392155624, 0.13007318000158957, 0.014954129170115679, 0.014846145246748724, 0.07845479619478987, 0.09802007657145301, 0.05893001505624383, 0.021758772049760147, 0.05731853378576137, 0.0137136556628731, 0.012971461063341029, 0.03396429744879565, 0.08514974581738634, 0.048709689684572725, 0.03426456944115701, 0.03686905387909182, 0.03350199019956974, 0.007742072113849704, 0.01055341178265911, 0.026214961863813863, 0.02630735589792171, 0.0353172853318674, 0.03874280152001208, 0.024950935940949187, 0.057961281554232684, 0.02915691377805366, 0.024451308718491948, 0.00741297654214225, 0.01593674131248507, 0.04577697104504032, 0.006116833819466974, 0.04960572527300927, 0.08965736885945644, 0.023978218781731786, 0.06186927608664959, 0.07536293428030706, 0.03312918883297713, 0.028421990310532913, 0.03164929657002851, 0.054019885588317156, 0.045444596138211994, 0.033494589790221185, 0.029136915052790317, 0.05111857272324063, 0.037299273535609245, 0.024865733557230523, 0.049393354209079865, 0.040307754440413374, 0.05006798272652011, 0.0564578608159096, 0.04702436902950849, 0.05755011450439211, 0.018123594833718195, 0.026745291975056453, 0.019165108603755796, 0.025317106816557147, 0.02373156528319082, 0.010331494305583258, 0.010165485925221396, 0.03813682597190623, 0.06189401306572461, 0.11541617899051598, 0.061629892762510054, 0.005375390943710603, 0.031108635763126998, 0.009036008982108006, 0.020352948997770588, 0.08095470963106041, 0.015872006882883368, 0.05591637071883006, 0.01799801961638995, 0.021407258351363485, 0.024399735679429387, 0.01283848830949395, 0.0317983600431152, 0.057935678895803235, 0.04386327191886883, 0.03758314358551176, 0.07357724461584322, 0.006928775457650304, 0.04423817619681359, 0.041857749494093086, 0.07397772473914009, 0.018158068790310816, 0.0035407224054177927, 0.030250730285901698, 0.02846783875758129, 0.009560860607082085, 0.10781252651565498, 0.07602915498277835, 0.048528781851693514, 0.005809131253045053, 0.009479272243146215, 0.11174269546304019, 0.043993763505451144, 0.04921302094214386, 0.051965203301440326, 0.04730721635203208, 0.09086023415288619, 0.10452525855432596, 0.07672508457495321, 0.06795802799564216, 0.06082605968620028, 0.03398108626565626, 0.02170791913334641, 0.024036420396559184, 0.028273723568887483, 0.03768325978589635, 0.014829863005528047, 0.05164502068392692, 0.023353539196954622, 0.039798378749119664, 0.049623705356592135, 0.01088408884712525, 0.0726870657695878, 0.02039982783307712, 0.07128308707427594, 0.021372590957569982, 0.04416878012219264, 0.06598755792384187, 0.06645432763522671, 0.04769053227538544, 0.026462657241931847, 0.01693408628324828, 0.008907529333936832, 0.08634836698371558, 0.059857827971779534, 0.010744263436795484, 0.026381254654317617, 0.027251597568993608, 0.04588387478443404, 0.04342069909457238, 0.029775629368340297, 0.028958908777924317, 0.07295352647141104, 0.0508732675394464, 0.00972651850221859, 0.02019644489571933, 0.028090440863443, 0.14338817116954636, 0.07244705042291073, 0.011767694658990349, 0.0435737251574474, 0.07127397062797701, 0.07233674142269358, 0.055376010601438826, 0.002906892379190052, 0.025327805234419725, 0.057808182713004856, 0.058617684839954304, 0.05915441370058445, 0.029538724338635806, 0.0345845720280082, 0.05077977416916721, 0.07173305647748132, 0.04497433306589242, 0.03178328917842479, 0.059537587897671815, 0.022352289092997392, 0.10140453044685627, 0.1474229570838713, 0.18700022370584551, 0.33520036166714084, 0.22303837862226272, 0.1824785889156403, 0.13711763425700127, 0.1484824566831512, 0.16147313218924308, 0.182707327448072, 0.08468688315441532, 0.09160364587460795, 0.13613100494107894, 0.2855310510964163, 0.1293496712441406, 0.10554600942639575, 0.1585312932729721, 0.13927869168260407, 0.2544621408226029, 0.1698124895413076, 0.12760124409631377, 0.1382687886155421, 0.17202449181387502, 0.15738160980324592, 0.14103056622609017, 0.14779391217856638, 0.11884992296296744, 0.170929997318214, 0.06602252983758528, 0.22024911377699147, 0.16212213123517652, 0.22437150950633714, 0.17420362891449084, 0.1453852244923192, 0.11938640667546181, 0.09288929462913545, 0.10276842742196976, 0.18034742424084296, 0.12465288577180718, 0.13889218500304606, 0.1673646854056466, 0.09960282188389571, 0.10844389787845074, 0.08426841528665635, 0.08485331575596526, 0.14667119500377487, 0.16812295923309942, 0.07383820480637013, 0.10335030950485699, 0.1946135595320694, 0.15176704333674523, 0.13172498814040615, 0.14197581147234287, 0.14957690521353675, 0.23627764965978362, 0.13312767980800522, 0.13262714860179733, 0.14447161867733926, 0.08725002948795596, 0.08662212084257796, 0.16288636522668024, 0.10192511017404257, 0.12831985755192657, 0.10921842043077755, 0.1329791813247627, 0.08320758269438822, 0.1651375452356954, 0.1655165595753539, 0.13798668439830505, 0.13471982501927884, 0.18552331344014217, 0.10235011277179565, 0.11164592323644508, 0.18247642854769386, 0.14465137354789243, 0.1013775488301631, 0.1128256067092861, 0.12124322760369509, 0.2779648603210526, 0.12629140994601673, 0.12329676458912513, 0.1530403887192088, 0.10840427581100695, 0.08154124186764802, 0.11387432745147137, 0.07224086551896988, 0.30817008306903226, 0.0842819367385199, 0.2687992311773762, 0.13714225632288765, 0.13554088741300568, 0.14482139910180725, 0.1917963477993204, 0.13311882383160054, 0.19016300237947897, 0.1659448027250267, 0.1359656065582268, 0.08476720747327612, 0.13940105124587013, 0.1741028423871725, 0.1644074634438561, 0.10428178815111037, 0.12882502359007636, 0.09873405519512393, 0.15076927510240387, 0.17000154471926152, 0.1683358091019815, 0.10512369579725689, 0.12207950450359814, 0.12755823592024465, 0.19741620027249862, 0.16466468512531252, 0.07400528092177645, 0.18103196976646302, 0.1380487068766548, 0.19959371326671493, 0.15591715612719137, 0.2365662043373431, 0.15093381546678084, 0.11988524482735705, 0.21810051294103747, 0.0860974348841175, 0.1605921617198375, 0.09680470872309901, 0.08865240705950607, 0.09345839070456644, 0.1636351242421135, 0.1762509069615795, 0.11808575791937691, 0.13772526455502357, 0.17248918542698508, 0.18526247582368313, 0.23212195974924874, 0.18049359381679567, 0.2059577588712977, 0.23690686831551216, 0.10676455653963551, 0.29547879472374916, 0.11891143216240792, 0.15390180862478672, 0.11726936100110893, 0.07873906844085263, 0.19547128689385232, 0.13185923738825706, 0.09528528823847733, 0.10577418871464268, 0.12785471960782044, 0.13135872150380767, 0.11895004299379165, 0.0691274229076601, 0.2622416717631202, 0.1996635958071678, 0.11212447538010537, 0.10636714076803577, 0.10352372116739712, 0.09655892473435211, 0.19148755307880141, 0.15781903068625158, 0.14882353434879936, 0.10839004955825307, 0.15609721743291424, 0.17393209671060886, 0.21256934280597398, 0.09909896585609644, 0.19386308447968578, 0.11655413365412144, 0.10294147136230623, 0.1495730441303984, 0.05885814068718784, 0.08393885192251013, 0.15064587365956078, 0.16330467987685435, 0.19528423886625998, 0.15667028184379303, 0.219290845036026, 0.1244626967837253], [0.053022691919918985, 0.037981107109977354, 0.09569562791335968, 0.009856216230189369, 0.05602297185349369, 0.017987514635728254, 0.022407807484869997, 0.026137960451324622, 0.018913063761447708, 0.007448317614504167, 0.019666432710965315, 0.026665126619439934, 0.015370376340504137, 0.02181706559513846, 0.01999850501306355, 0.03921893282583164, 0.05869631993494207, 0.08425634940184894, 0.06018983132596459, 0.022583452293709404, 0.022842853495310393, 0.06313255124334848, 0.07544170344068159, 0.009333323875081637, 0.032504723752818765, 0.021228221688239325, 0.06988005066711096, 0.019458290452377933, 0.00805285004448266, 0.026698150754635854, 0.028502136513951327, 0.0695195373508238, 0.051036463419516245, 0.053191763694368066, 0.0269537674818909, 0.03255889382994464, 0.017555433385554823, 0.03174717962411383, 0.03426139400671086, 0.025003263576617165, 0.017861634898450107, 0.028644106012859175, 0.022330989933482582, 0.038394365579851215, 0.03395772824484495, 0.043342450873986374, 0.03150370347523882, 0.020188535037901134, 0.058429407241243514, 0.032358826138079166, 0.07561236484757355, 0.036624277295965346, 0.0365871335229566, 0.10696911733717689, 0.05034691150931101, 0.06004417885936076, 0.04031886654575506, 0.09822908067895521, 0.026705110663427945, 0.04927392493212416, 0.023942375442974513, 0.12696755914798669, 0.07747140743078725, 0.04286061221313092, 0.030485204901666414, 0.026449233466278643, 0.011449794983491303, 0.06934976460592401, 0.01859917264101246, 0.008629292903107502, 0.04715935755220633, 0.0658497387062638, 0.02583919573695429, 0.09688287267401334, 0.039255295189157616, 0.0446044466638517, 0.04639035083293434, 0.03831604841135202, 0.06131198159569214, 0.02729671823251392, 0.028334527967437625, 0.07745830732728205, 0.08999818605521033, 0.03280136448841903, 0.0590542515349244, 0.028018430513780446, 0.04810010203190389, 0.04625612073728154, 0.08067470449473589, 0.027537373262607766, 0.06515042300546361, 0.029060922961141315, 0.04088528131345107, 0.01471901487093419, 0.060972688914907563, 0.021827840621793465, 0.016122431449231603, 0.03500510067228348, 0.026173428406999, 0.09974008951816829, 0.08606695990648963, 0.07228850852698088, 0.12099908304310615, 0.04038748504113286, 0.043993813301166224, 0.06364123745551033, 0.07649156565387404, 0.0616216688086429, 0.024465232366515745, 0.06135542261143846, 0.042663153050647634, 0.05757068396515905, 0.03915249768103804, 0.05778741406937761, 0.023186545436000152, 0.08715210046859519, 0.08527163806701861, 0.03164238262651188, 0.041046381943048015, 0.00734156278345073, 0.010718520009709943, 0.0329258882500712, 0.04134248641710128, 0.03276807413766942, 0.07448731876549221, 0.0031595184907106865, 0.006887612595868808, 0.013770006217753455, 0.023628959297052315, 0.031068419977541895, 0.07152924644610575, 0.017722237539748033, 0.03140623985429204, 0.07154870507938248, 0.057343021786260995, 0.02154805382052737, 0.053522196568308346, 0.01769074366518086, 0.0701311053407769, 0.0006879489909249148, 0.0172499232670112, 0.03509534966020334, 0.08669264689688722, 0.03732531669459516, 0.05374313249523121, 0.010444983528296073, 0.0213660619732353, 0.004171814624926135, 0.018955089429753925, 0.015312734927471369, 0.05520506191157526, 0.013229689192807963, 0.06554119679475985, 0.011559554315622778, 0.022188658458030513, 0.07239600598451591, 0.03166752946262639, 0.009982651381212617, 0.020898937946185473, 0.04781612472969198, 0.016414531198660695, 0.008674758306193736, 0.050920385777229266, 0.05578684440303234, 0.01914876220267146, 0.014684793723356581, 0.01608164109770329, 0.00556266927648516, 0.050527853816146814, 0.009414804986708108, 0.005132360562246534, 0.01283522381732661, 0.035172559831651955, 0.09200165919478863, 0.026079908223642458, 0.06733689922839403, 0.03201328792549189, 0.05207801357873025, 0.06275638675076828, 0.039772101933316845, 0.062135809566825635, 0.05982005217623326, 0.06948317115705821, 0.018684572292371623, 0.040798579312620625, 0.05364240342450719, 0.02797200941600867, 0.029649452771991495, 0.07812091209475072, 0.03187679212480303, 0.04143101553763113, 0.03504541604929874, 0.05796203232039848, 0.06336500147177328, 0.03947914991107199, 0.04400903163778205, 0.03751355598890974, 0.010692023901238797, 0.05991420055168772, 0.012986231238521155, 0.036707474444542205, 0.03267875977701718, 0.04024486628270919, 0.050621182477522286, 0.032000344870011174, 0.0047842511670633915, 0.08094167847546839, 0.054187252817134705, 0.050369124228675524, 0.012951425948901283, 0.06227204681284005, 0.052716279732844526, 0.04748170819854544, 0.01931423527909623, 0.040649762902889526, 0.044541987515385115, 0.02154114370745036, 0.02222587500939206, 0.024262808954283118, 0.02928788416958865, 0.03032857631032746, 0.051363035210318146, 0.017268698166815505, 0.04367902011220013, 0.08596695478885405, 0.023770147386277397, 0.024083814425994794, 0.06711339307648521, 0.042385369569303534, 0.0394205748283815, 0.011589235434639118, 0.0364219956099987, 0.007096763217686526, 0.07830441313525362, 0.03631141847900806, 0.026729717407555833, 0.018377755993917104, 0.020272643831107887, 0.05188461851268526, 0.027552093642072815, 0.046446236947010604, 0.034238235168759866, 0.039538322542343414, 0.0138032314510295, 0.04953352531658546, 0.0405792789834161, 0.02455100740095781, 0.02108704892077273, 0.023067983753618695, 0.022310428133594896, 0.06636589810612702, 0.06012433846931785, 0.0418450094519123, 0.08683955191724724, 0.08074881584053079, 0.01972931895344969, 0.06325046749665372, 0.049872185974832506, 0.09753392483558386, 0.021568874175089504, 0.10667556010547186, 0.032389546263842814, 0.07540392764513532, 0.1473427783217161, 0.030125591738690293, 0.056725811558745565, 0.01164266815213787, 0.012476231185569158, 0.023026680123181115, 0.04818735561603981, 0.06971589334669613, 0.03334548609751848, 0.022289971670796795, 0.03516097658223683, 0.02501106043646653, 0.10215950243535543, 0.028651065921651262, 0.04083942329030364, 0.09990996951537748, 0.061677930305802056, 0.08842063481889426, 0.027046810775514574, 0.024625388792746013, 0.03312377642179209, 0.04766384560254313, 0.03706356743350625, 0.07321338349532697, 0.06186005238804126, 0.001806566278607915, 0.00851896283547244, 0.02803595477504836, 0.06925000463642421, 0.05047389441320012, 0.033329095646378495, 0.052126426505105156, 0.05468961114304201, 0.022615277501303824, 0.1240449183950982, 0.038641727709722136, 0.017816968142024932, 0.06413310803773423, 0.028173329661630338, 0.018275626897511464, 0.026876049777192455, 0.030740978676945935, 0.025938949960794662, 0.04703431668120527, 0.09557652422377179, 0.03582026418899337, 0.004005978853749713, 0.038005139288162036, 0.059629706140126915, 0.03778120029657599, 0.08669227151380432, 0.0487130681323188, 0.07394609296874655, 0.04885444199786552, 0.07917642803682436, 0.04149709445153994, 0.04192231155391182, 0.022128053242340687, 0.04921790092222152, 0.016802254042798476, 0.03191760545896907, 0.026276398284901536, 0.0429836689164081, 0.017303011244944027, 0.08453376516098939, 0.031426556506043965, 0.009530425849070233, 0.029737190906739527, 0.012731666924552092, 0.03266842908135826, 0.02339538483459863, 0.030676361075752688, 0.03377669400745823, 0.05006985581149498, 0.01779735437594354, 0.08295907909351011, 0.09395365122585528, 0.02818527488758968, 0.016173973844777194, 0.06677770100894474, 0.029175502901536324, 0.027820816218492486, 0.03318474169880633, 0.0273678743941409, 0.0054077217693350495, 0.0356469176439268, 0.041418566608861576, 0.04308041816036548, 0.015295659785249062, 0.13281304749750322, 0.12288035749788247, 0.2730015298772243, 0.1306204119276616, 0.1323710913739858, 0.13850189384914216, 0.20376205894975893, 0.13084398702748362, 0.11584786187496879, 0.1024785167687843, 0.12718472209188247, 0.18940564785753528, 0.13298799133589193, 0.11307918947310218, 0.1371217864535509, 0.12203678744094026, 0.17300496178288616, 0.1899786663031386, 0.09723616944205377, 0.2822007443155012, 0.149375960350998, 0.19100893198722796, 0.148931430172055, 0.11106626280853826, 0.08864335956112032, 0.19536807952869326, 0.16680783141524563, 0.11312294075445783, 0.09349057405826547, 0.12143489514147082, 0.14780377939103112, 0.18358088218637053, 0.24175294134165012, 0.09158368928418045, 0.16824917987950389, 0.11100029497737847, 0.1295692320432394, 0.11834439686349324, 0.18054440076793396, 0.11418359714650339, 0.1817764080460033, 0.11478298433846044, 0.09564526529321749, 0.16117870927818362, 0.0896307473040877, 0.11009241183919292, 0.19927191037324168, 0.21394589555359658, 0.2636734594500834, 0.10400240354600454, 0.263470568724217, 0.1691276529022763, 0.159005762167996, 0.19752734430855323, 0.08160105801277584, 0.1623104050034477, 0.11876775237220911, 0.23177351231776902, 0.171742356953121, 0.12611005395170183, 0.1315440534944496, 0.23578415114072063, 0.14757358529154332, 0.07378368998967832, 0.19315377899235298, 0.1283307053569344, 0.09835575331723499, 0.15056929551064968, 0.13600139818604917, 0.10120768415471239, 0.14027164888478097, 0.12859289894901937, 0.15084635886934497, 0.08951009611689276, 0.17797877230951864, 0.11500884238029681, 0.07496731115445014, 0.14648878946900368, 0.1716780668545154, 0.09720199425975162, 0.19153220068302848, 0.18964799211150218, 0.19544280374482756, 0.14746339120451482, 0.18469797627579781, 0.15376431116413686, 0.15185146622600096, 0.15662779460751242, 0.10831538662915269, 0.1297572453416163, 0.2094704558652255, 0.12986313401451036, 0.11507029795358259, 0.18359264929688748, 0.11372330087807872, 0.0929991209939603, 0.1422904897481203, 0.14146158261404884, 0.1303530472420877, 0.2788422454989726, 0.13461326218901143, 0.1734477146378448, 0.4032189182696804, 0.20487595079166276, 0.1676106455946161, 0.19043599015041707, 0.12427456857215975, 0.1801212597638369, 0.14901318707533423, 0.21805987963753365, 0.05113899279686232, 0.20724814204919725, 0.11581827555933308, 0.1325888442055833, 0.09796707860885129, 0.25600110421017297, 0.1496025385154832, 0.20835752929410628, 0.11971412376771051, 0.15164016385472592, 0.16743519613819738, 0.31979047242672215, 0.2266762084177425, 0.06415918184023711, 0.16703713685274127, 0.1750092469756642, 0.07457009456571072, 0.10359084579132258, 0.11860386318256778, 0.26146534890417134, 0.11877592653036119, 0.2154736280921967, 0.18898307375850218, 0.14665270164128275, 0.1805306111852969, 0.1458946576402072, 0.11125815251181204, 0.18423470758622695, 0.15849167120552834, 0.11430158234772184, 0.09635588079090081, 0.17896915545626996, 0.14585839103787177, 0.12498847058703824, 0.10943631115820139, 0.2047808333149841, 0.10534608346079627, 0.0728758298341305, 0.12075181284378614, 0.1083928457791767, 0.10025586587406936, 0.14508291087563963, 0.1695689501901788, 0.08824826503593115, 0.19935188995253658, 0.12138469339979273, 0.1376439826262574, 0.2352683288195441, 0.09419598781894292, 0.12296293411524066, 0.09487582190382866, 0.11305192440387704, 0.2346548456097803, 0.11558383733274476, 0.1099075471621848, 0.0792656006712106, 0.1464095759776331, 0.12555298545668203, 0.17428466569512122, 0.1792777816374456, 0.09720885074667393, 0.19537094469753005, 0.13141732723001512, 0.16349344394139706, 0.2074045925250938, 0.1358101519966318], [0.008726917402518374, 0.038111771066342635, 0.035377346625130986, 0.05443741499836888, 0.023096840370506532, 0.11726930737495424, 0.10829841778162988, 0.05764682544395328, 0.039118812795007424, 0.025255143710021532, 0.022577802395267833, 0.011363981644653026, 0.022239802487855478, 0.07485422125506787, 0.011930289160039638, 0.022430895459688, 0.005075115599714581, 0.04781527820253565, 0.04935551712649965, 0.006065601689530718, 0.016482655567327337, 0.047226321297667684, 0.031028211852836034, 0.04068613675753436, 0.026805251761670076, 0.02707370237687663, 0.036213589051077445, 0.08399785601443822, 0.016941988480187232, 0.01387355544964873, 0.05219360475518531, 0.0477536847334235, 0.07817559545078585, 0.04478471864375376, 0.02711825230489335, 0.028452302494476882, 0.04272031853155744, 0.03263656365414781, 0.06631904416867802, 0.011211113587412383, 0.030237800636959654, 0.0540276077545939, 0.046432665699431976, 0.00826586366465856, 0.03098561736424604, 0.01695228087144994, 0.015729078816460268, 0.032585224271902156, 0.060363733284776254, 0.06606724638972553, 0.037751797842042106, 0.03239207435399294, 0.06066057703367645, 0.018541581981304674, 0.042000437200429945, 0.012694323011073134, 0.06038270928266068, 0.0292555533439642, 0.013143892133338077, 0.04380350173901647, 0.03817600370835393, 0.11545839043514383, 0.05886464477366498, 0.031064122224286683, 0.05253069493318758, 0.031512705008349115, 0.03590699683334078, 0.04359344043017876, 0.012078651662675605, 0.031398939036373655, 0.046509354931092074, 0.05147462357736884, 0.0507993170721156, 0.007955638274940993, 0.019419110800710418, 0.019416372036381115, 0.02633390275971784, 0.028671836480498317, 0.0900327212988369, 0.06417934527440418, 0.04561481704454749, 0.045903831374861544, 0.03691122701932346, 0.050221935755783514, 0.04936953270507436, 0.09054609979953497, 0.03282622404156193, 0.0359249347820878, 0.01457689981532073, 0.020739515049142704, 0.07526365694619956, 0.08211214591058032, 0.015417598000156785, 0.02322764030747837, 0.03004563514203314, 0.010415067794852921, 0.06632089044057554, 0.03930134856472573, 0.10338732687335822, 0.04601304869978659, 0.018968666422991984, 0.017734311085434693, 0.0468394392350268, 0.008810577076679517, 0.009709303548950101, 0.03274762342053075, 0.03875633446319449, 0.050872443994927796, 0.08884107153261862, 0.04495501615888169, 0.03360902417391058, 0.004808640054937813, 0.042432905325005134, 0.0628529291509861, 0.05159376940179256, 0.04760339360443815, 0.016504372244760875, 0.045510211568926616, 0.019730293800333337, 0.036742251005864916, 0.02692077207499214, 0.02256795433500121, 0.07672562849737945, 0.010594140847153481, 0.010818484907729492, 0.023696798297967163, 0.015287254843109799, 0.02259210142637453, 0.039854425741660024, 0.07265359538817599, 0.08111135162893804, 0.04241677917419903, 0.022428018799532327, 0.011407987650243506, 0.003266668575252557, 0.04191958045046176, 0.021991973044350747, 0.022393098596723813, 0.06540386787345333, 0.0077896021238918756, 0.05097322669180651, 0.011531152563439983, 0.07557442051268394, 0.04111303925333966, 0.0025280875166983257, 0.10659368062812476, 0.05039887525321496, 0.042555023570575064, 0.05507024958910001, 0.03663958756313209, 0.025146989332091425, 0.04795588598015809, 0.07832362662039458, 0.029301976356955788, 0.012204111009205302, 0.03595712962710569, 0.042875826719307134, 0.0448211461245533, 0.04437385419864328, 0.06486985096407515, 0.0848273377144529, 0.029357251515912435, 0.016279983176519314, 0.007905705621646298, 0.06464302765145417, 0.03132397733298281, 0.047863373202421976, 0.026759910847871538, 0.006849859304155314, 0.017966872396608515, 0.03535468574433077, 0.1539629577629028, 0.05462383100342366, 0.05373161436328965, 0.06272486989356338, 0.045171623689032374, 0.03613201217846044, 0.05151298543017718, 0.035849398512753754, 0.0549656211308414, 0.05753385045775964, 0.1190922442342966, 0.01731208172596751, 0.026484038755898515, 0.10187352947410076, 0.04307281473771699, 0.022134722037721547, 0.042685725831336556, 0.012090524110282141, 0.027395097328530207, 0.0613986146486094, 0.02982264035381377, 0.06635419228264401, 0.006324503497566067, 0.05189047525486639, 0.012515383066549417, 0.01810766403533278, 0.052112196421911644, 0.03988329959552615, 0.01461879716389963, 0.014318558687884963, 0.030392536991125638, 0.01030881331497503, 0.04369158778459795, 0.04511843420444958, 0.03753135221139078, 0.04127258089401069, 0.03334001239929949, 0.03184456089060874, 0.0767671428019962, 0.04672408937626789, 0.06765985891463296, 0.04050916661658595, 0.030632912399127122, 0.06787894473921868, 0.022142882789334944, 0.08006436224546164, 0.06336997721284147, 0.0628642021347919, 0.04650484650365768, 0.052287063651507905, 0.07052531120397391, 0.038306962608570055, 0.023956975163591486, 0.057271561104684114, 0.017188291493502837, 0.07120074028329504, 0.04097956375429227, 0.0733832711534154, 0.030202702318708745, 0.02263208930080216, 0.07834499281260275, 0.014617423951295356, 0.037533458953182545, 0.06129009063325583, 0.03158471535801167, 0.016338868524819132, 0.052384847114163066, 0.10461204099438845, 0.025469646413600253, 0.0531340504605924, 0.034810499017757755, 0.04004882438288581, 0.05761459229453918, 0.05017693192067166, 0.005553196120496479, 0.03236742930546884, 0.03449912641137358, 0.04389829362832731, 0.02049715164297771, 0.07054025757937663, 0.039233450191996755, 0.08147458455735639, 0.05947362721687364, 0.08950878610654224, 0.055480294320131504, 0.06894207559525967, 0.05005525034521857, 0.040307448005243655, 0.06715857694225927, 0.014930260743224814, 0.025034374407222195, 0.04229310960058243, 0.06509458285666282, 0.013724501552661101, 0.05545633108986001, 0.097956215482085, 0.09659603403340425, 0.08260393605357216, 0.05041602413139997, 0.02377591411312742, 0.024184415176991495, 0.07072600325749767, 0.032039327254038186, 0.09780631505794103, 0.038069134442916805, 0.028163839747468312, 0.019325864493786808, 0.07004043883493832, 0.03073569075504859, 0.03424223031728499, 0.06681322450599363, 0.03663401427348295, 0.010805558131617165, 0.08017687757890071, 0.02554108602775922, 0.049621391771060806, 0.014210261626078958, 0.0214330870057306, 0.0013318822804590567, 0.025796327371931365, 0.02424069391112895, 0.03120749366409596, 0.034160906253682996, 0.032772911982911254, 0.02834981908240626, 0.07223570208636022, 0.09178673322763174, 0.050107478389456395, 0.011985023269399762, 0.020576524097592603, 0.03793820618621765, 0.06675456515363147, 0.03979578554149597, 0.03279536218953229, 0.05158456102494271, 0.03990731645195235, 0.017305866837681785, 0.04381747518275534, 0.03569742582077461, 0.042205028641488285, 0.03800891227118912, 0.045743500663628506, 0.01843662410523863, 0.01813546728132473, 0.044931478107408176, 0.02424427537217496, 0.04197867264250114, 0.03857638424022063, 0.036727220360790534, 0.09942636119141694, 0.03968654140349358, 0.026264267282620556, 0.029376319444347775, 0.08076141032600596, 0.045168509541620175, 0.07341953775575084, 0.07927212774032548, 0.09069993791560974, 0.05101197541901662, 0.05236731136157628, 0.04049148913773318, 0.035536194956230546, 0.046594923121794585, 0.057456184463996085, 0.051179101330138026, 0.09557043382477376, 0.043077212082402366, 0.0710240880688352, 0.052571293762734825, 0.007016752994874673, 0.015502586836866556, 0.03221147295628344, 0.020911038304949482, 0.04104026090053301, 0.002331785386383173, 0.03916579696740355, 0.03816668424875506, 0.024325750738142, 0.050939637566766435, 0.021690561496202024, 0.00630030517406281, 0.13010999818723049, 0.1684403801036458, 0.10688059587752628, 0.1911082323039732, 0.08855357405639465, 0.2845860050330239, 0.18725959043348991, 0.12982809315285376, 0.15333067475547715, 0.14132975420403865, 0.07074429743712948, 0.1323412139449389, 0.1683494454670337, 0.2019231414963161, 0.1899574609893945, 0.1450898516322336, 0.15097619545075203, 0.18389102522163622, 0.08697866582341733, 0.12100777048016749, 0.10577285572165444, 0.17372275552442, 0.12392765331652858, 0.1293242371250545, 0.20848013400550813, 0.10743580277889006, 0.0531915376984304, 0.20995142118584728, 0.11139637775598996, 0.11636846458479283, 0.15485931127782793, 0.09482994855892274, 0.1059168879122984, 0.15252023034038084, 0.1363047077170303, 0.13049334858454045, 0.10756863476408106, 0.15024770712179525, 0.17595740335602916, 0.08811777727978845, 0.15216088913861783, 0.09137069385859276, 0.16042772860776994, 0.1280323983800988, 0.16160658470565276, 0.1384112503259413, 0.12366434889695338, 0.08705099218434866, 0.17894819529066164, 0.1588597764531451, 0.12796940297008524, 0.15956060900803537, 0.1704937868541287, 0.1468324718335944, 0.168323046077163, 0.16534546149834511, 0.1524403273698784, 0.12698670368521445, 0.11156444212481861, 0.08148080519130153, 0.12035770657201929, 0.29208962174673236, 0.2825593653946154, 0.11543284140286908, 0.14881572025197168, 0.17483644818346347, 0.22317429794178856, 0.19859900938407068, 0.08580163301479432, 0.0955767770327868, 0.24128890656415494, 0.10798229159967554, 0.21544119192948266, 0.10190339924226846, 0.12620203812877018, 0.12541747216375607, 0.20707165071320152, 0.1436937942860588, 0.19249056135454487, 0.20051200753979145, 0.16172972567860158, 0.16179528748316152, 0.15697921446013838, 0.1903009441711249, 0.10311174972523605, 0.17314645822250074, 0.17583026340411556, 0.12919470697881716, 0.07434624367423597, 0.11349014967920319, 0.18182235799970167, 0.1716716623594684, 0.19985953045468177, 0.1527674928788216, 0.09334489477858429, 0.14971523004914486, 0.17323472687313635, 0.0966195605935589, 0.16289615583035255, 0.16179153365233254, 0.20195493414517374, 0.1340892427270451, 0.1448642540602915, 0.09398585756219204, 0.10004542918214876, 0.1806408052723254, 0.08551225862315587, 0.10544795017208784, 0.1794283179145667, 0.15015917800126538, 0.11819162360963323, 0.09795580945548513, 0.09005805582649286, 0.1702684957173563, 0.11926742555994181, 0.17788295003194965, 0.09990770189512162, 0.10746393352746965, 0.1453686923149132, 0.12839448983750998, 0.2182451809846586, 0.18032461014245788, 0.1910103722325256, 0.11564653396846787, 0.1592246641314799, 0.1292149776652936, 0.12035841903378887, 0.11826810982799339, 0.19118692485555527, 0.21454998652540871, 0.23932448858695649, 0.18651795603575247, 0.14121919239480651, 0.09366966243232451, 0.12519851657411746, 0.09566768102588193, 0.10293774051411499, 0.16110605349944485, 0.34386852395630657, 0.13073118824151256, 0.1785562034215658, 0.20264482696450528, 0.19600405507991392, 0.1316183487013463, 0.13692038193825753, 0.17823712780110298, 0.08521448024698804, 0.12838628503584093, 0.14224182784317002, 0.17117768886589235, 0.13353511600965454, 0.13775883452786555, 0.21669897040532482, 0.09882312057720077, 0.15354919367499892, 0.1940030487434518, 0.16149922514394408, 0.08338092540901515, 0.12155252028136485, 0.18133684211680967, 0.20976233536437636, 0.12023038275900388, 0.18547439106529762, 0.06892036466348557, 0.21016197279095652, 0.10710760305124907, 0.07392691012712256, 0.08000843016610992, 0.13841872734408225, 0.12323235191645161, 0.08693067041496116, 0.21555682524077355, 0.07793453056365252, 0.15638748814742412, 0.09082448082946001, 0.09770534466952087], [0.05356733063836733, 0.01078799652356294, 0.030116795134099743, 0.05654470454300604, 0.05438881821089214, 0.03632429641701522, 0.014394817952697557, 0.06936124826390898, 0.07330589627306308, 0.03532367833559552, 0.017246460549593452, 0.05003068573592652, 0.08014320801462858, 0.07388824566958413, 0.017815987549481854, 0.0011847661071149032, 0.054524327673378496, 0.06670290784489724, 0.08060332808283069, 0.0641614877648892, 0.03201378396742287, 0.11424568857276633, 0.018299425418879238, 0.035068551904612014, 0.022421102940795884, 0.0509448393037723, 0.059883698760982484, 0.033842815056202874, 0.06826769605639481, 0.06500061451187057, 0.08499788420815622, 0.031051654143319018, 0.057590261342064034, 0.05446154676798371, 0.04970636241318238, 0.04190474898824769, 0.08861879112138864, 0.0721027551879806, 0.0795856568842165, 0.022710718650130496, 0.07359294175741173, 0.040615859681800495, 0.01540549476856306, 0.051937562849132285, 0.04402599665486524, 0.03875909621016153, 0.03707135471725657, 0.015046016628583594, 0.01912620474374102, 0.009950839580156872, 0.016966608630853797, 0.02198240077573686, 0.0248025159817189, 0.02947937742236161, 0.02029980739368306, 0.0720234727486968, 0.032919705920522256, 0.010411433665262116, 0.04255963158943961, 0.059848757490756056, 0.04123289753953296, 0.017803688007857532, 0.0498694816844598, 0.019256941478459105, 0.05098026703983065, 0.08592825202691941, 0.03167471536735614, 0.024546098692582983, 0.037286158110345566, 0.07251052080743736, 0.04620470091580384, 0.03273306008909018, 0.01220943340505924, 0.049374102419542695, 0.05621912100562646, 0.026557757481632215, 0.07675870051307064, 0.03205348838931851, 0.03194464644747636, 0.03413363735401823, 0.031185271368632396, 0.033714434041851954, 0.04541107979152472, 0.04641344455341178, 0.02802268038654039, 0.012596110539180378, 0.15623082316690878, 0.07372945862551851, 0.04406215217445166, 0.027563851176490708, 0.029347878430158864, 0.04665892210698897, 0.03210012782214871, 0.00987029979906736, 0.07005942249370199, 0.05347196035267365, 0.037937876768410206, 0.0601108170174543, 0.06281923660407625, 0.0433869299388701, 0.011633412852402658, 0.010418665535267322, 0.031068475518916405, 0.023474052488323183, 0.04953617981124309, 0.020873622570727623, 0.026218981910196525, 0.049320185151431835, 0.0171578414137325, 0.04609362965810203, 0.05451202430131455, 0.07620864172255801, 0.03311198249819779, 0.043920862578576615, 0.09522465237927052, 0.1108164415364304, 0.03236398957068882, 0.032676492156761314, 0.01973410508775663, 0.057744179897370844, 0.044305205059748505, 0.06034667633714215, 0.028816209580268592, 0.00648495486764718, 0.02929881241382851, 0.013620077065312335, 0.034995673960375215, 0.06646483836154785, 0.010433355271215401, 0.05338158496024628, 0.059700883369171814, 0.020970534608368913, 0.038068889294781035, 0.03016395359149864, 0.06298727032938792, 0.0601402577763844, 0.0749079929664731, 0.032153732909430424, 0.019061313266114845, 0.027065489914328344, 0.049298635098121824, 0.09063508091194016, 0.056261631224544785, 0.09075885773786614, 0.041930343985797904, 0.050782068602500424, 0.06723959074025193, 0.07001775497150037, 0.014181077506603494, 0.019962826383209998, 0.03754469746303174, 0.02374133481944521, 0.05128759470197463, 0.048809748428363, 0.0637931450300159, 0.08023852467416756, 0.06949332182205493, 0.10161528889570506, 0.030901468351423263, 0.03200497778673326, 0.02258180328945239, 0.037367079977787314, 0.03545308207732535, 0.026996767997080763, 0.03362816488069873, 0.02115229471406389, 0.04551226085412406, 0.1040932615738242, 0.04750669032575623, 0.04884888019953524, 0.04302453204628922, 0.08628054521977903, 0.025710967940188227, 0.03515128556999468, 0.021439485755118153, 0.035544610432078766, 0.05829771289662008, 0.0907368710144393, 0.025239140133283315, 0.11139525160674127, 0.04943818950484838, 0.07451419312987598, 0.03222804343808563, 0.05026221665884218, 0.059682328719645746, 0.03422482096920571, 0.01459248108609069, 0.055379285627315124, 0.01899424609878371, 0.047750394385788715, 0.06097555408374437, 0.10768161741115394, 0.13764743002191668, 0.09540338069200517, 0.038778106682002544, 0.020733660222181392, 0.04932840527485936, 0.03399149357010761, 0.01567402773822147, 0.042924231984802795, 0.04531794265213032, 0.030805209403737422, 0.035725644669465484, 0.026765373054771658, 0.0320335126466929, 0.01398815166941213, 0.04602129946673109, 0.0860522969836189, 0.03965416269737386, 0.03883342589101484, 0.04368816720201604, 0.014064289317766746, 0.0778139713070085, 0.03850147999342411, 0.0695252447058597, 0.014764955248533478, 0.03057667005416607, 0.03682198543702403, 0.018487992215781443, 0.07010384793243102, 0.027043120146939353, 0.03509046968012568, 0.03737706593388031, 0.0487555208946428, 0.09836691521829176, 0.042758071344465985, 0.005815035875721445, 0.03319372407971852, 0.06857604644591771, 0.05095860973421124, 0.031180994682795102, 0.013720817627355218, 0.011643499357535714, 0.044040299516411564, 0.049138392487000075, 0.041322617926785064, 0.08863487896779854, 0.027896488468433102, 0.036109282349747036, 0.05765326441295686, 0.05067447921441448, 0.020189904420065786, 0.013010110199120978, 0.05045281550396354, 0.061111588316458854, 0.07765569754185216, 0.015957418025561398, 0.04662425279797566, 0.0169487300539209, 0.06727693752656061, 0.04916450076345955, 0.017482260497467175, 0.047241650717032534, 0.028814439917163506, 0.003941745254128511, 0.02789528379517217, 0.07783881553839292, 0.0884208033582376, 0.09412880956886277, 0.023218696230962392, 0.03370715237613167, 0.006954072159714998, 0.03285610913148811, 0.03658183219452058, 0.03873856122335119, 0.07998731678291675, 0.0720614860314996, 0.008187254425138235, 0.03162471472375816, 0.01730239071372536, 0.014172111405059697, 0.003913459851549218, 0.04955504089593888, 0.013625955832521281, 0.08600401812263074, 0.013048291063657212, 0.024396106337888107, 0.03158442232938063, 0.0536784861657408, 0.06045561020953521, 0.04614567767167765, 0.07194838847123808, 0.05528535175647947, 0.040671378073673096, 0.040224128282598914, 0.04621683574852444, 0.016653780457413486, 0.049426250024548465, 0.05819319169067087, 0.08689125519125693, 0.08444401029978069, 0.043169698047061125, 0.02850665260226496, 0.028850878889281905, 0.06946814051198383, 0.0477805667586865, 0.014615431165082321, 0.025889543035338004, 0.028481561307524963, 0.03569344216356835, 0.01843665857919522, 0.03077729507499645, 0.06860069915532105, 0.049958458966425354, 0.0857668373012735, 0.04725008151463924, 0.06430188103789283, 0.04747168393805624, 0.06566538730816496, 0.05577382090831957, 0.001132650941144675, 0.013328420689269422, 0.07579689244589499, 0.11369230496066232, 0.015125790321748826, 0.039268717049591007, 0.03273602867979677, 0.04253325518220664, 0.09232592123049883, 0.04131953442288984, 0.05692484120147363, 0.07495481626040514, 0.07735920619339713, 0.041668954786033406, 0.02623556962897701, 0.03185180425193281, 0.040292857860725735, 0.017134906656499353, 0.06589712124438056, 0.06028645799585408, 0.04658915064928513, 0.13905364569396744, 0.01877690503944553, 0.046635498968704094, 0.03872731888306238, 0.08631793797136315, 0.036854973183043545, 0.036101728722813635, 0.048090682980874856, 0.009646186522478539, 0.031775557436048985, 0.07512477286640676, 0.02466029175857623, 0.07971988314942968, 0.04494572734279979, 0.02481372384805112, 0.03830666000383996, 0.06177030135727218, 0.038890556897968054, 0.06791185587644577, 0.03354505966267279, 0.022034308978266293, 0.17670135133929793, 0.12394918038720086, 0.0941591849550605, 0.19097410563019016, 0.13477158191944325, 0.17354874631329892, 0.11479266768982334, 0.19973775311823816, 0.11128391604870559, 0.12115223168004906, 0.08393191116591615, 0.1261341397560412, 0.15834491940275316, 0.1921820883909541, 0.2040567270089542, 0.14364507109407457, 0.28853203200044175, 0.27505976298163015, 0.13708244017775983, 0.23007293502169274, 0.05887938047488851, 0.2592229789062854, 0.08365198263838407, 0.15392837655400077, 0.1452616851536497, 0.1543581825230391, 0.16324037445649026, 0.170464169894976, 0.12203675679742329, 0.11615619694273319, 0.1412788246788325, 0.1617306756276277, 0.12689628998839086, 0.1169271035600574, 0.11528882453398359, 0.10542572596140447, 0.2501329932842524, 0.1599281167070712, 0.15434051653550518, 0.08144220202079705, 0.1365968476860754, 0.11514703698095777, 0.24828734957883436, 0.21776666714539453, 0.15045234452812903, 0.15643719193195144, 0.11749589320031867, 0.09834810775975067, 0.18686447292566302, 0.13404344599093163, 0.12055904980027869, 0.08313133396328458, 0.1711403803839799, 0.15003350893816642, 0.08192266172338879, 0.12494569223734642, 0.08787794579421321, 0.10295318484666849, 0.1502990809779975, 0.1304378225317886, 0.17943890524968026, 0.09380781872858925, 0.17849741383425652, 0.08712742477655412, 0.2018557564024964, 0.13065444155325814, 0.211244271166863, 0.13054899721136018, 0.2438923797660297, 0.18838121976342895, 0.2147571826654096, 0.12326605978511995, 0.1758965606530828, 0.16423576781826635, 0.14554231848207214, 0.2130826830022758, 0.1203021728583882, 0.0859615768516256, 0.1276057410324293, 0.1124001367978992, 0.16274850004382674, 0.19441600077815596, 0.1529039944251699, 0.15782773344507142, 0.1358009895850574, 0.13692461074359957, 0.2590444191328941, 0.1317447532088526, 0.14966900430379376, 0.20339614471360562, 0.14579463720081315, 0.12399344494746578, 0.12190149631351234, 0.17463671373984507, 0.1398959900102308, 0.16739116140430974, 0.09037791285663845, 0.12647034510249092, 0.1492307407240714, 0.09100175357513851, 0.09710218832497636, 0.14048705748733015, 0.10755117562028671, 0.1688775711602742, 0.0722390958558648, 0.21319109976532, 0.13270571857931154, 0.15973745274447626, 0.11757888350515597, 0.1406699073530974, 0.22163562566762973, 0.14389093935249314, 0.17545178532600406, 0.1314692833130398, 0.15833172736869705, 0.13248847136574407, 0.096376174460015, 0.1004715349465128, 0.13697963117832138, 0.20710810117663878, 0.2984100003396311, 0.14506155234431067, 0.10767237072990787, 0.07924488565373806, 0.09892201486734614, 0.11933037500467994, 0.11702295648114336, 0.15423991386928868, 0.08778250656060635, 0.1251527045162455, 0.17289841427437722, 0.13545951355368863, 0.16104450599560816, 0.13145710251504375, 0.15404646134664937, 0.16220882174468812, 0.23196135707680257, 0.29715162431520803, 0.1321702231202395, 0.09741916486452665, 0.1434726706675945, 0.23263079534855582, 0.22329826628969562, 0.18644545347459857, 0.21808347514560147, 0.14412338575047834, 0.1719892977346336, 0.10374466858563886, 0.11574571937202446, 0.11475965696116609, 0.11069486338284709, 0.11397627843243462, 0.10061281688150861, 0.18322100472306052, 0.1320440484391105, 0.1918326450451728, 0.1331324908401697, 0.17621326140098034, 0.1577260735775194, 0.1842318730609071, 0.09294670525818102, 0.2140715186514201, 0.09345851327863433, 0.07594601146035618, 0.14251204237582224, 0.11118839254542706, 0.1870498508815804, 0.17574029403828806, 0.16380591588395257, 0.15774318798174783, 0.19227820178193433, 0.21054362247307457, 0.12882767425429437, 0.16657791310741057, 0.09055618151661851, 0.17063704529596915], [0.09002487655849227, 0.03507229424412212, 0.05422282227945905, 0.03272407770817799, 0.044339181059190345, 0.04438251482262727, 0.04312436479414183, 0.05506141276489343, 0.014100111589106101, 0.0509653321557468, 0.07900768951062234, 0.02124648139391455, 0.050142722264412916, 0.02101348341262389, 0.08063787098733649, 0.03997384352729686, 0.09856226763898328, 0.013402809741936866, 0.029424856860010378, 0.02128795930935491, 0.06759454225820881, 0.07468403482268895, 0.08711417145546406, 0.1335609331727028, 0.026733273970744303, 0.024054839065478697, 0.023653129371063366, 0.022244732263648224, 0.05711408407096902, 0.04777739132424036, 0.055026693660165035, 0.027091061929240826, 0.04837131247885766, 0.04301607826604478, 0.006499728873266929, 0.0336983883302779, 0.03531625494360924, 0.04877822774071847, 0.027571485242656166, 0.015594745298937686, 0.02032679284081584, 0.009515543633531178, 0.083571145040614, 0.05125856380008402, 0.04383777268230916, 0.06060405123618342, 0.019602925937262275, 0.03081570480830006, 0.06107553238830259, 0.03274990253210549, 0.09812134573416365, 0.01759725029490167, 0.04903926070959819, 0.09439392195593926, 0.028446763678784334, 0.04659906382702532, 0.011343185230338526, 0.0254478378056158, 0.011129392115699669, 0.02074611489661038, 0.05347917690092037, 0.02883965953163082, 0.04586841896056168, 0.08205036858036634, 0.03853100502202588, 0.023639470023373445, 0.012028234458768801, 0.03061453586504344, 0.0853442632022404, 0.03167136756312703, 0.017359757292715293, 0.01316887904859839, 0.03513093061384655, 0.000788661004222494, 0.013502991059795024, 0.03269509660200246, 0.013663718221528877, 0.019402741416988355, 0.08941590560660248, 0.08749693962595156, 0.021619378521497694, 0.02725706169111354, 0.04851126908174446, 0.05078454306649585, 0.05026774781365549, 0.04101745063258756, 0.16723227476881397, 0.04508707439526916, 0.038273944219033566, 0.044555884350331566, 0.021867332454290123, 0.019227295791009263, 0.036942881772354726, 0.04223551894087465, 0.04837455303077737, 0.06551262171518418, 0.024423166478593505, 0.04639570961796469, 0.03628636740388409, 0.028551078040993987, 0.049489517395775166, 0.03480122169299472, 0.051636122572686405, 0.03098105148021733, 0.016124348584262115, 0.023573714781612642, 0.024134037235090812, 0.0443891070092157, 0.04795977770681343, 0.06711507846991863, 0.04636174127940209, 0.08216482211625384, 0.07514099094776377, 0.03243797068153659, 0.01731836939260604, 0.03250840863573455, 0.09564289042065222, 0.04848649762871285, 0.029966492513795535, 0.04508193777573686, 0.07351430283198435, 0.008172804091666496, 0.03672146704047918, 0.018746935679847677, 0.05243963772250761, 0.022645815681185455, 0.04273558666388835, 0.07481842196636623, 0.02908623259093973, 0.03482423497424011, 0.02711750728438699, 0.019773183232774178, 0.013390389541464468, 0.050131012610490286, 0.048806653433148904, 0.0209516505410354, 0.030537823650745616, 0.0313110361927219, 0.05644821576894291, 0.009122094282159402, 0.09323462408276335, 0.052619032531736366, 0.07254058975846538, 0.03753405650176349, 0.11008836689495272, 0.019676841930636478, 0.013343368979891943, 0.06775835483905769, 0.08544354819722715, 0.04307124808791184, 0.032558323094441045, 0.028888647023948933, 0.040064341493792115, 0.02692476339307764, 0.04810638778332261, 0.03948160905330893, 0.018102427824370323, 0.11604362798313941, 0.08684307592169893, 0.05755536603711306, 0.03683762129155859, 0.0924230994836938, 0.020898426582496014, 0.03474972526272459, 0.03624632015764233, 0.040429255985204256, 0.02436898491014877, 0.027219270573808785, 0.028678681476101763, 0.05842926551497752, 0.031214110748541933, 0.09034230508991788, 0.04012398143869735, 0.024488634437382705, 0.061200531124467814, 0.04109781325584458, 0.01467784051783383, 0.009073187229073337, 0.04345212402122636, 0.05461718519068053, 0.0413671889222197, 0.05363457017548142, 0.04008777229295623, 0.04864286000449811, 0.06521188623962865, 0.004600064956673211, 0.04817111838248469, 0.029214157782975706, 0.017460109065136602, 0.11799594177113426, 0.04941213868498322, 0.02335538738407195, 0.024187063925989696, 0.04873600863521138, 0.04279411578130338, 0.08308184468337605, 0.049544932365778, 0.0937142793930346, 0.07832600149295985, 0.038720937370653116, 0.05375239066779614, 0.03409987202875557, 0.033138604053566535, 0.042922040973339355, 0.057436959487536264, 0.018932654544891372, 0.015257597664341092, 0.04466404830436072, 0.02088066291875176, 0.027991094581422307, 0.03744956466459459, 0.05496072582900525, 0.03831335561229818, 0.05608160056233887, 0.05164539989744944, 0.0346171614083071, 0.012741196100720236, 0.01846588866394614, 0.05352800734521401, 0.10262094017478729, 0.0815996024457197, 0.050769160020976305, 0.025951408465663274, 0.03815282571820482, 0.026777559598427148, 0.037247620057314634, 0.04243926768521628, 0.017822357570572246, 0.02432229951204312, 0.04279804964279456, 0.010927674461967282, 0.11161213875898432, 0.022191106108948592, 0.03778260989835666, 0.022897682408051147, 0.03276264257428627, 0.02104585637308417, 0.03442972650631301, 0.06803649838172621, 0.07025111301411545, 0.0342051669835083, 0.012482582054461443, 0.05952362977569142, 0.07936172938394932, 0.08869732279450664, 0.0028187767067368356, 0.022611259370140975, 0.05862589347206297, 0.014363742553659025, 0.057706978667767785, 0.03133378517363341, 0.08345877526388054, 0.020644711668512995, 0.0296386796605563, 0.04797670824994003, 0.08142646657483232, 0.08084352729060958, 0.02878067267668103, 0.03310173224177092, 0.06494288978677604, 0.03116493173424275, 0.02739800271698304, 0.06718293087737215, 0.06271110712400367, 0.056852901714944074, 0.07091948642365395, 0.04831418530234406, 0.04448791319924978, 0.050345279742032296, 0.03430046449084917, 0.04802589492511846, 0.043339489944159024, 0.03550382774142969, 0.03347494729584263, 0.006889006875890999, 0.011219893912634542, 0.07174709886913339, 0.04922236338438046, 0.028051282279193405, 0.042043763302987626, 0.022993299757100405, 0.008744667659723952, 0.055909265253332355, 0.01742992137048033, 0.028854812750773087, 0.011088263727874767, 0.050271854044929634, 0.04727313310028084, 0.046535175924579945, 0.052172633098258134, 0.08362303217572552, 0.05207900949303181, 0.05617451553623523, 0.07505826111282073, 0.04186131180294099, 0.03134692358153482, 0.03696078524714516, 0.02591941471872551, 0.06507800471398138, 0.04207207025178979, 0.04916317543135055, 0.001563669842829357, 0.02034875083594553, 0.13181799121441382, 0.03971567189681434, 0.03822607138464528, 0.037180204319977955, 0.05339147515534874, 0.0612146309727142, 0.09675294416205538, 0.09217085737374522, 0.04524290050950743, 0.013823930189133653, 0.023214988365408876, 0.026951057445858757, 0.011847454945616906, 0.052716084380423835, 0.052282769728692315, 0.03959574083226823, 0.027691751470669147, 0.07131302579035682, 0.05204687593504787, 0.017980194665611755, 0.05071043172070096, 0.018772904145260973, 0.07974167835087546, 0.03441847650514495, 0.08855418692673407, 0.006977278878161263, 0.023942053686046315, 0.0814445385889661, 0.05989401413488293, 0.11189910763454054, 0.00870841446392719, 0.11839669002520463, 0.016436742002805396, 0.04264627230323611, 0.012465089394320405, 0.04012442193925381, 0.07623640474893394, 0.028442565516959277, 0.01618360931564483, 0.05433257586593109, 0.0704065599148312, 0.03108132855906602, 0.049909456152348756, 0.02768655547932271, 0.07399427223830454, 0.03144399841286002, 0.025982063473953355, 0.07198147580868776, 0.05533067734851953, 0.22546631043716786, 0.13244207708104966, 0.15276968389028503, 0.20457435729763201, 0.1274478349894766, 0.10695676033895825, 0.11505567333510808, 0.11571599516056238, 0.15690085898724296, 0.1596085814338538, 0.18618247081195155, 0.12095796710421002, 0.11328294587832306, 0.17634037070937697, 0.20798758543547124, 0.09732134309747527, 0.21703624827486856, 0.148666869368284, 0.15876352516633851, 0.1670321879247504, 0.12913179583847523, 0.23486976391605793, 0.13302641830617382, 0.2587967582287327, 0.16021539967867637, 0.09892989791208699, 0.12573867750864837, 0.11184581089764835, 0.19555240028327514, 0.1261446274997246, 0.11218586200547796, 0.16533393953596393, 0.16945394507098585, 0.13419500882587126, 0.1118366025207985, 0.09733972154677877, 0.11387245819693613, 0.09147429958947244, 0.1099786324606788, 0.16934270910438032, 0.12123462443630542, 0.08965875547859939, 0.1127605505227562, 0.17795335351219102, 0.26125547145643546, 0.16389387809941847, 0.12855914511507557, 0.0885008059201702, 0.09959670850225996, 0.12879370591573178, 0.20196515375808363, 0.07061020140686343, 0.14954400939806817, 0.18322983005594823, 0.10222275831526327, 0.20053767148525486, 0.08445976872838314, 0.08283242177698882, 0.11812230031336508, 0.16898957321480398, 0.16861152414593006, 0.1224924412165438, 0.14540944819248494, 0.12957330763099656, 0.09002453181892635, 0.13848004502154168, 0.1422678288673201, 0.1959437026732391, 0.270902234460077, 0.06826193507520423, 0.12189772716092488, 0.1530554806513171, 0.21374542566557087, 0.09283089574666754, 0.1483887641300117, 0.12944451292916653, 0.07886084577729625, 0.15633721745783286, 0.15298771251353527, 0.1392949480683573, 0.1508299339442484, 0.14209213426276562, 0.1476795505732298, 0.21808082448138347, 0.17325197917319116, 0.10069429799313508, 0.21599986920914344, 0.10817212818731224, 0.12453474735300388, 0.22113089629959679, 0.10005275298270488, 0.1336667758803214, 0.13995318613465757, 0.13289802197006442, 0.15305463795460042, 0.12394957875292148, 0.14285681258526542, 0.1222500739799392, 0.11551738686619267, 0.12498130766494621, 0.2978681310290291, 0.15990697268036105, 0.10978301957009301, 0.13186150500851293, 0.09910499496806054, 0.06338911408919, 0.10624874954021747, 0.10834291982915133, 0.09648940225522365, 0.19332457063419206, 0.09247320929482099, 0.2060309202680665, 0.11595108456188634, 0.10993654359011881, 0.10201955349334788, 0.0712251631663211, 0.1656212225075691, 0.1966795301245105, 0.15197872875198243, 0.1658290621614264, 0.10629919643003134, 0.08699389565135203, 0.15710765676152322, 0.1320343497659891, 0.13187523330411605, 0.0940323131339204, 0.15834622175222443, 0.22671403783944347, 0.16601195799246912, 0.11332311186819308, 0.17961366522696712, 0.13551971274277858, 0.1510051995395653, 0.2561472737861257, 0.2216255286287877, 0.18865347208995975, 0.10270616745636349, 0.07896024568547165, 0.18603640848830824, 0.1389521084004833, 0.26445094676267716, 0.07148765553269656, 0.11782043868856085, 0.15019561314294416, 0.2683340319462361, 0.20348438272072425, 0.14928349353853734, 0.13463002419279468, 0.13603873731147859, 0.1769240071336108, 0.1060013797494673, 0.28512211336243537, 0.130601336338347, 0.14748537792794167, 0.1143017738697029, 0.1403963986423708, 0.12582637925422, 0.1788645384893302, 0.26776479797497876, 0.19280277282720615, 0.11188715666292176, 0.16564366888375054, 0.11878832949385529, 0.14722611845260666, 0.15317224777273594, 0.16715375075657524, 0.2146196392394843, 0.11681386044309025, 0.09743716793074723, 0.1422056531713855, 0.26501058931312255, 0.24910262034785366, 0.17953774591367092, 0.10703797331981121, 0.17087880732311359, 0.2817926339564785], [0.03865007040721755, 0.07446607514735192, 0.04036606139233036, 0.03642539320994289, 0.05669282764316567, 0.03642687942051599, 0.03419913404110459, 0.033019841273104956, 0.06871634778837044, 0.03359324659311003, 0.041478639393444025, 0.025735335281839775, 0.024822390217694546, 0.051762603688985116, 0.03737487492241687, 0.0439961000736202, 0.032921295552965135, 0.029772103448668798, 0.007428477852485113, 0.04023081623017788, 0.023934195539163008, 0.058105267779601205, 0.028125368727130756, 0.053647551535358357, 0.050447678884431246, 0.011674117976649395, 0.049105546467246554, 0.019925385751130602, 0.030118141533626668, 0.05019919060531163, 0.03949085956499462, 0.013886826965326985, 0.044534690527906345, 0.026411712394967198, 0.04339768198288737, 0.025527899739362543, 0.023241619496876677, 0.05200011392814979, 0.03581140055170944, 0.05878551938240567, 0.03796719495327242, 0.05199393159860084, 0.001668087028402595, 0.010711315910391992, 0.01522203203245637, 0.035416677579163544, 0.02152922912500799, 0.09429036219033504, 0.030206166951346303, 0.02475649324966775, 0.017251905519515276, 0.034739256671239296, 0.03757449828328625, 0.04573908416674503, 0.09142861776654759, 0.0615867696732523, 0.019376026015848886, 0.07255103919775256, 0.057702378309782476, 0.02356164889680522, 0.05161694739194167, 0.014794329932380109, 0.03540080040693283, 0.0026099023553768116, 0.011328626686947481, 0.013850756673022144, 0.03928346041169378, 0.037551910180838845, 0.06066148484786672, 0.03554594342506701, 0.028041311644858895, 0.037110911667226784, 0.014177022028654335, 0.03385512225870644, 0.018002154575961254, 0.017139610436354435, 0.012494410452012335, 0.050470044821380615, 0.09196936858878021, 0.05590727342472923, 0.02631650873339705, 0.10747096621461454, 0.024505478795617822, 0.058815530876839356, 0.058507988710076585, 0.06716381698366135, 0.04388549995999183, 0.015397242086398748, 0.03724526433694748, 0.008919329960800467, 0.014173121683509841, 0.0663837019894873, 0.05402323722298588, 0.0191127062745152, 0.035765500393726175, 0.013627465025732114, 0.012522425329793366, 0.03219672959418066, 0.03526445973904864, 0.0052571898014585105, 0.02235999019185622, 0.04230435577131087, 0.0328672748629845, 0.028030630463974613, 0.05050639952382734, 0.025096862283985943, 0.04099327289769727, 0.06432362261318392, 0.021175202658219684, 0.0434409084940149, 0.08641154625483098, 0.06748522917229323, 0.03347446083001072, 0.038154656668343855, 0.05431533888763478, 0.08407808074186887, 0.033094377797697826, 0.053170213641058055, 0.03988902227232053, 0.044356303124298016, 0.07074232093028485, 0.024247875985419078, 0.018029189818809112, 0.03055320861148498, 0.016244180057378068, 0.03418594966792772, 0.046382448635995395, 0.029488382785911524, 0.0638787821686316, 0.022553004129158876, 0.06143172113825718, 0.026230885001320033, 0.05086946008246272, 0.1449026657088149, 0.0187429845813782, 0.04423547956732012, 0.014626728089135742, 0.0523122985877337, 0.091487284779789, 0.03445671195344579, 0.026171618524277886, 0.042840667114022284, 0.057294861668901104, 0.008335629376702973, 0.02332034652241536, 0.07688344260978122, 0.029755316547028003, 0.006128271033371529, 0.05239592857598778, 0.052614581560896295, 0.03362043505354274, 0.07449415993065604, 0.03493092803945465, 0.02445062881545915, 0.06203969234540578, 0.025031313885964697, 0.07161529344176093, 0.030101752997706496, 0.08804219504517895, 0.08268688039313402, 0.031113812602275324, 0.04850310641491125, 0.109138356581811, 0.018475868874379707, 0.00024568815294309567, 0.019136652267808398, 0.02568404378008939, 0.05265136527258062, 0.040845904394143054, 0.04929521068510029, 0.081069607497944, 0.013831295166915704, 0.031502498801977884, 0.034644453290609584, 0.030606160608811245, 0.018885009621660558, 0.07037176420131037, 0.07009014261946564, 0.049116754333578774, 0.018292599575473897, 0.017453260239093535, 0.08329081814736129, 0.06461178658590203, 0.026267193738491307, 0.026000549175566243, 0.01451790338427189, 0.072088475309072, 0.0516341882006776, 0.09072324231026635, 0.06724787981159265, 0.007348809017604518, 0.07009643986220322, 0.03054331841638252, 0.031200842105693398, 0.04106886662362565, 0.025753719476802696, 0.04956845509549303, 0.04928874490301936, 0.02318837255569956, 0.0647079995683124, 0.03310597636887143, 0.04715234018681992, 0.026769079005105362, 0.0327512661686107, 0.034487998984273405, 0.005090905150638954, 0.07882540654991904, 0.03746031670861187, 0.02132259414441163, 0.029184194169037288, 0.04381436103534314, 0.031061982923758127, 0.053141496835216406, 0.0757674363652064, 0.030515176176484075, 0.06620438378905097, 0.03871592715562832, 0.059248339910540855, 0.023560417410466942, 0.047452290422253074, 0.042288003624567104, 0.01454511961539186, 0.0412515364587307, 0.024845319229268262, 0.03796989924364513, 0.02551420783293584, 0.03964845151189835, 0.02839152299378428, 0.029935981146991256, 0.03395166848936389, 0.050100690850447265, 0.050768619928989685, 0.04658319814611347, 0.03276784048085252, 0.024708660634895487, 0.02053262917475114, 0.08603711312095966, 0.026680475191002893, 0.034473320739644195, 0.0479110736670273, 0.0743941777956582, 0.05008216684443816, 0.07036313039040373, 0.021879496015307885, 0.08354468436370935, 0.05019513416975256, 0.02956318361083827, 0.02190780487932986, 0.053409746352342836, 0.018867351295005892, 0.01015888990819334, 0.03629102138802409, 0.07842576912333889, 0.08640452122856533, 0.08731884716619408, 0.039304137124770114, 0.044227653979173595, 0.06863744073216954, 0.025959542404199322, 0.03673749743029475, 0.031248826022830703, 0.03779912675400415, 0.09055551502012438, 0.01638493530692593, 0.03133826104233102, 0.018971215580560027, 0.06057137758621286, 0.03055959203911405, 0.081814635665186, 0.06499767273424134, 0.04144065292371858, 0.020378561232299097, 0.02454311669533772, 0.018499793800254984, 0.05130080588822884, 0.0152980825383096, 0.0735533120290887, 0.027370375671213674, 0.07929036063292334, 0.05586480151020712, 0.08989104099812047, 0.022425038717506875, 0.018622373613799294, 0.019015137316478838, 0.008469363430424804, 0.019206536723481073, 0.04699858634041683, 0.011895245425553333, 0.01253026336686866, 0.02237982229299603, 0.0162287587074623, 0.07439602406755572, 0.02526180484452315, 0.001664775972453607, 0.005815110569294062, 0.051855936180800206, 0.027157983539866346, 0.06763294624585299, 0.03971577914912374, 0.030992782201557875, 0.013935069437138738, 0.017893783778192538, 0.0072502527637557405, 0.00788114388518396, 0.07254347024906067, 0.05562844423336848, 0.03143880625195321, 0.05237876437604428, 0.10082610342050753, 0.05014454938411232, 0.08378051687031986, 0.03582326342321692, 0.02738265606063989, 0.03746575976331388, 0.08380450308322908, 0.006384180310452658, 0.045929158241638256, 0.041525569939685446, 0.08080473259812401, 0.034628307987605376, 0.054350935163036476, 0.06165130491999369, 0.0329714551598074, 0.03821634589844654, 0.04745789052497956, 0.011348509541412276, 0.06956616146189552, 0.04294261809498553, 0.03545463340537202, 0.04641474690288306, 0.049064028332190174, 0.055806961871923945, 0.03359697744130127, 0.05121937457231745, 0.0457408155254539, 0.06981048222270704, 0.03950469894334674, 0.035169867032598105, 0.09529518609445903, 0.010783493841787981, 0.09442822737318855, 0.016582218269186638, 0.0432069912072151, 0.07557894043143719, 0.10651956928232986, 0.015549191795740158, 0.011598614266052121, 0.03549787140781841, 0.04645934088095542, 0.06083566259833113, 0.032859407140002135, 0.012840311598753738, 0.17225497702677406, 0.12252749739995888, 0.12495785005270474, 0.11287222315947856, 0.14260590346830507, 0.14876249246299267, 0.18847567840449272, 0.07334108269142528, 0.12751209444456524, 0.1499114251665531, 0.17410969121321557, 0.09004520087112343, 0.17982691346156984, 0.1530089637925548, 0.0989734806540993, 0.11630176897010497, 0.10991235053347004, 0.1564029324799776, 0.11446243016830376, 0.16752944027464237, 0.14386746641849318, 0.13594994772105448, 0.17763222477609114, 0.12010409316468625, 0.09132165657055956, 0.10306936974126486, 0.15586530729647607, 0.1450142693976241, 0.1340293959384003, 0.1433996165231351, 0.22547475272609344, 0.11519993535212933, 0.13501815497875214, 0.09809572775397571, 0.1317651771129139, 0.14432318148113069, 0.15560952586031732, 0.18945478473699864, 0.16169577266179747, 0.17535617755305383, 0.09950621053576471, 0.17384862377037927, 0.10807036872833006, 0.11761249178239416, 0.07105572750010798, 0.12422168552274666, 0.17395840416992867, 0.17182152447921617, 0.15890944959415546, 0.09859291115595449, 0.12108227253080377, 0.09749490797760026, 0.22048418019567767, 0.1221075050172306, 0.14717089883502454, 0.17526787825890128, 0.11406128354851278, 0.18229791473957802, 0.12326694078623288, 0.16410243787592457, 0.24337179237796416, 0.09994984439183628, 0.21036327005394045, 0.15219943868296762, 0.11144864793506362, 0.16736194281087768, 0.14979291136466688, 0.10880589740531099, 0.14341161346002934, 0.16678766798107855, 0.08614906154933476, 0.09424261959089388, 0.0916718430216274, 0.08160383891194098, 0.1935643867980088, 0.17970530466446955, 0.22225310785635827, 0.13542208249770826, 0.1658748588975399, 0.11466990976083664, 0.16349367376777435, 0.27965325681913283, 0.10673676286974262, 0.23053755202601034, 0.21905554879096248, 0.1932767361042, 0.1245181079232885, 0.17802668344830314, 0.07109177193694538, 0.04266980269383039, 0.12751754132970688, 0.18692007558720727, 0.25118907613139, 0.14181301778843328, 0.15901953642887456, 0.1672614167534536, 0.19635922876336884, 0.1063150467891847, 0.11091326738918021, 0.12592931848860558, 0.1220799794781112, 0.10633958458539941, 0.15466084854016382, 0.1508711341528162, 0.256387549602697, 0.09206092375661097, 0.07072276270557797, 0.10663017705683747, 0.10321786056362814, 0.26358732052387734, 0.1452414757542072, 0.11320526456280101, 0.12393104708603314, 0.16435961359210555, 0.14399498941436892, 0.18787221562477852, 0.1590990257118979, 0.1453513480843075, 0.061177881734986464, 0.19639570987032307, 0.13031838942439328, 0.11781167464270709, 0.09580461158146782, 0.09368703730644719, 0.15078965304118974, 0.09399295153637087, 0.1669747926174633, 0.08435640048475997, 0.17325928765198878, 0.1429145296494807, 0.11084477912874953, 0.19589220624296896, 0.1769206976337779, 0.1802506826577648, 0.14572466272980938, 0.1907752904920809, 0.10721613472748188, 0.1204380845170348, 0.24928755397277497, 0.11183756013070384, 0.10586821068558963, 0.2451730336272909, 0.15397366767208423, 0.07236612855546898, 0.12843328452999556, 0.18972244053598375, 0.13540956462102552, 0.1307462648518624, 0.17297652459913687, 0.14259992798249568, 0.11587319640262474, 0.1882483954391172, 0.13507722035771416, 0.1464661285882035, 0.10596741907178395, 0.14946534749000304, 0.1724945020771796, 0.09043066567110439, 0.20662931154572195, 0.15146198712529677, 0.12007264525539453, 0.22681997247761299, 0.18797459561497937, 0.09546980051504028, 0.20990266735034607, 0.1130083569836232, 0.1461096372335188, 0.20587785590079524, 0.2609502620274021, 0.10194135123803731, 0.1861247997130117, 0.11884351846792045, 0.18631826755740952, 0.17026799009932628, 0.12998769991099834, 0.06317842458825439], [0.038109840524773446, 0.08337852755381216, 0.08116595837618075, 0.029564765582401908, 0.022858454875888366, 0.08897041781775414, 0.002607030483270665, 0.009960172446294418, 0.035615607630461454, 0.07184567906322979, 0.01425955459595688, 0.016856527541794123, 0.021395184805676825, 0.025944879481328592, 0.04356452827191642, 0.006773821726035808, 0.11498102572776618, 0.0764143516519858, 0.03329652541827771, 0.04999051208517725, 0.015306624418665326, 0.025455416330406745, 0.007979229473764258, 0.016553078199766817, 0.025932039847717653, 0.029460389933158315, 0.08722236605301019, 0.06832671547008139, 0.021018503203747735, 0.04750959379898925, 0.015925512378734928, 0.021823856964587204, 0.055019718429614464, 0.06203386241630201, 0.03147027331344303, 0.0730895913476425, 0.04163663353650801, 0.050703839534112526, 0.07405392750496827, 0.0027328211628276137, 0.026504554590510748, 0.018232002020663312, 0.06739542834580907, 0.03682177476284485, 0.046170058419867877, 0.014601827358766912, 0.019619209136092858, 0.04606380585520979, 0.023325961946900335, 0.09694526287456674, 0.03744619387772776, 0.0494508644295556, 0.07616390984865927, 0.05415823723700258, 0.05469213923319213, 0.04825668657318719, 0.0825453992752779, 0.026120587492421753, 0.09402415429752681, 0.05224113668044729, 0.027643627742485657, 0.022929679985428532, 0.07678326895280231, 0.03625527572547717, 0.04915765193741649, 0.024605658198256167, 0.02462904686258445, 0.053037021594542655, 0.025474790694011797, 0.038621774949734254, 0.08275482473113845, 0.09165354884199559, 0.022061372949411313, 0.06316075860072048, 0.09268680226898963, 0.007162317840172159, 0.056644878199984955, 0.013580510539243059, 0.11710567865520717, 0.07307831453339708, 0.07984196692104302, 0.023216327104056557, 0.031085114948631778, 0.03283491147862327, 0.03467952862622277, 0.033428418945761464, 0.01854687181842183, 0.013055193515854978, 0.02210113099746166, 0.05192370048814243, 0.04890956968489674, 0.037679245485173124, 0.0734802885281463, 0.07893690298641882, 0.0071215973941669355, 0.11779973899284679, 0.03558090001705193, 0.03845910383989254, 0.016332816430217317, 0.019130144350891633, 0.03922074845421218, 0.12799165016340633, 0.02451341738173318, 0.02556693000388482, 0.02895651092272132, 0.0037337286818412046, 0.05722076181442507, 0.0864375549398603, 0.06279560662205182, 0.10212892020541815, 0.033553674321381316, 0.06949916707291719, 0.03232088180318956, 0.03421065217304615, 0.02783880013251497, 0.06364812458594961, 0.03325457827398374, 0.03228030595628004, 0.07475984688367575, 0.055560511386682915, 0.12458277340497702, 0.03532059483170029, 0.07092208346171726, 0.06707190941538542, 0.019398344072302984, 0.059528230133676724, 0.07026647307699727, 0.014148423008831039, 0.024601032942413323, 0.03335723405583732, 0.040843173290692994, 0.016379404152112625, 0.01649154793290842, 0.04641307683120813, 0.07341916237266795, 0.029354715764883067, 0.06054281782839568, 0.03571806805989435, 0.03418706815629717, 0.013869061386362921, 0.018754575491672563, 0.07128410597121523, 0.059418189264233076, 0.011176843601729602, 0.03744467319319806, 0.03376401142187176, 0.026889377791855126, 0.02283407412769814, 0.056630448933931134, 0.04241659914353683, 0.06428412311980802, 0.038493026213179675, 0.04578934336501745, 0.023211429887000593, 0.03858140977700392, 0.04719490403189294, 0.03627304513488085, 0.025406631851388563, 0.03988997222134664, 0.06883669254039565, 0.05924931667264431, 0.009350354967248297, 0.05681452070993762, 0.004080259935900329, 0.1119714952825058, 0.03969301867689337, 0.049165898873921365, 0.03379541719632764, 0.037049693581197536, 0.06461773142819444, 0.03699276558754425, 0.02161917550819776, 0.03620045830405528, 0.02493056566304257, 0.03431144253080411, 0.01585777679968986, 0.025096052146006017, 0.0644388422369957, 0.05280183643222817, 0.047447245733271685, 0.025851545074293693, 0.03199914211197005, 0.09768265314520368, 0.008021108148950002, 0.025478140413460713, 0.03673770810447393, 0.04131240214431479, 0.06761060712198097, 0.02432572200984484, 0.050324223815433444, 0.021725171433401205, 0.05046736351364563, 0.04570376368299608, 0.0406245777623788, 0.09828641469920836, 0.012627620693115939, 0.03788039336101182, 0.01287109875721076, 0.042880722021143285, 0.05468593009056584, 0.028692051625600266, 0.05433111646843534, 0.0827832006278538, 0.07348287790533035, 0.06029347153080087, 0.018275377918936072, 0.05700776255839775, 0.04787376518511484, 0.0606663303539878, 0.033510643162674485, 0.03592168656928885, 0.020564642073887012, 0.02232022639814644, 0.04851842051251762, 0.06691876077844251, 0.015923679513376088, 0.03556224194565608, 0.047972464122839516, 0.05887757633782684, 0.021443567088534756, 0.01489714659269779, 0.015238715512227389, 0.027111610322589838, 0.05281461477880517, 0.03682155642778643, 0.05753128789365292, 0.02018647426138482, 0.01386233896482736, 0.015869220238058798, 0.0824047991585347, 0.014461070193999238, 0.023868965067630334, 0.017492562464828935, 0.061230837562752355, 0.05270292682032432, 0.11155608410556471, 0.09781245142221452, 0.03443202093964623, 0.039640127966601046, 0.036753941507589434, 0.01387105513018586, 0.047883743480328596, 0.05923392596624552, 0.06006057314094036, 0.012612989371372087, 0.04205865988267526, 0.0723062664450657, 0.05553161838061868, 0.03274601846632939, 0.048141623997399886, 0.05948698779027309, 0.01758634311807973, 0.04657554492774991, 0.046345201441116875, 0.07256515819819705, 0.05827269246501308, 0.08548857118453711, 0.03597630480785043, 0.0490890717464349, 0.02735539099141475, 0.007262928167267913, 0.06913686111088722, 0.05720594950440911, 0.018281393624361486, 0.0853990461497057, 0.06784251725841915, 0.08433983000295778, 0.06455413846959991, 0.039373789838845694, 0.021194940913588773, 0.05276059408882453, 0.037823630076262264, 0.044142304123529506, 0.021248996077526002, 0.05857288401814238, 0.021528646898185535, 0.021469522147409378, 0.016148880634817387, 0.03878860208656519, 0.009166819452788801, 0.04115218251583077, 0.03091424478278045, 0.0575380486195847, 0.04575188549595975, 0.025079244176947305, 0.022862051658692862, 0.018126703235470963, 0.035065636940060124, 0.04650218434812081, 0.05080544194507022, 0.015250276736614686, 0.05533184946304368, 0.03087671222015014, 0.026669855297152555, 0.030891997589459343, 0.0763860370423044, 0.020324429459569436, 0.04384786206027193, 0.05636262459560268, 0.033341299427012284, 0.052377124947886315, 0.004800239422043125, 0.0378346081162172, 0.04016305575327527, 0.0776321173555428, 0.015286870841537754, 0.03436304621338364, 0.08347722266109721, 0.08219479913673094, 0.028166886862187136, 0.07793165773393647, 0.010982750438063616, 0.0755714787350547, 0.013744194800364635, 0.02205130846930608, 0.009746068108436323, 0.02399306365048453, 0.03821464901369426, 0.045224062407449375, 0.04594187530118131, 0.02188303342629825, 0.016834351211606015, 0.029181378795915557, 0.021835773462249387, 0.05267733565321373, 0.033759502994437376, 0.05789306908545475, 0.03277302689609989, 0.09445915434269175, 0.04913497573485778, 0.04510518854423877, 0.04728162518492149, 0.04609630330495777, 0.0031773805488727147, 0.026522186104088064, 0.05761240128307574, 0.004506333620332543, 0.08357100714478763, 0.007385213036961373, 0.02094370812448042, 0.049431513048588276, 0.030483306918834007, 0.02539717258074351, 0.039345471398724664, 0.05636062893655993, 0.020074692457133246, 0.04602724430902351, 0.031111583286415667, 0.04175601301774864, 0.036881249998846365, 0.010340134819759237, 0.06395594637480474, 0.12600365966077776, 0.1630546287783692, 0.10774570066602, 0.14080613310779297, 0.10361107051252358, 0.14134285430754387, 0.15455764117500476, 0.1218738405394458, 0.13209652546192371, 0.1786636395920669, 0.1541246789237184, 0.1372887016904931, 0.12382917271386232, 0.24094802808136712, 0.13695804282061516, 0.137587996920751, 0.2798627971881821, 0.1783603300610858, 0.14925721672273454, 0.1294529552180921, 0.07152900895884923, 0.13630908973995717, 0.14598991301271225, 0.1563563236906644, 0.09528500478594534, 0.13388411502443975, 0.20248451540547036, 0.18880212379078712, 0.12414053382892763, 0.13039910444809547, 0.23174502916874426, 0.23191580548882487, 0.15065108305744587, 0.1469467108648631, 0.15097207389771938, 0.19609250759165134, 0.09439042859500456, 0.18122073383100573, 0.18101854790602961, 0.051783594498110395, 0.10474521771914537, 0.19803346795660837, 0.27443383850397607, 0.16041164076136005, 0.23503284871337876, 0.08636252428855627, 0.106432648946441, 0.14702973947409662, 0.12957877749877592, 0.1989192647799369, 0.20273249806655994, 0.12019878929300655, 0.12763630794060807, 0.18436167899879718, 0.11522888581478789, 0.11910195822917646, 0.10068946397833287, 0.22801851703514978, 0.20903749361393914, 0.1341447228145215, 0.18447662283095623, 0.10849707204127505, 0.23337284343377238, 0.1099998071309059, 0.11267324714290519, 0.1709440320489868, 0.14155869191933063, 0.14968167539806138, 0.11816736160507126, 0.10707847638836793, 0.14642552592821662, 0.19616540851852587, 0.1710672343089696, 0.13627843090122746, 0.24869599619940405, 0.08600127552786181, 0.14000793077772664, 0.1387275527081182, 0.1799756724147066, 0.12816436468593537, 0.26862732104716763, 0.06815663629001187, 0.11331473086630145, 0.1559683461222918, 0.19290604147939913, 0.2001063180186095, 0.10517951296341997, 0.1422619759555786, 0.1270853758098618, 0.13799862004816532, 0.13225032527360225, 0.12449189239451963, 0.21739272430779474, 0.17184960926252027, 0.0997221937042571, 0.10822884933722597, 0.10356178807635462, 0.11036339245976941, 0.12952358852471077, 0.13587097937781967, 0.19146997902181842, 0.28655295110037254, 0.14510685878415264, 0.14323259403388347, 0.10594898699632577, 0.1414742996735919, 0.19440408045005417, 0.14921615440999308, 0.1326676286877163, 0.210991952448122, 0.09986839392372679, 0.12143491046322931, 0.16853756601772002, 0.2512756134233167, 0.1282727584663418, 0.15186543966973984, 0.1682394812063825, 0.22325047772497902, 0.15826913798528333, 0.1378640643651447, 0.24239005070299874, 0.16831253535084187, 0.16717506332262871, 0.1774807385499439, 0.2141547617652724, 0.17700849130990046, 0.36979149906866016, 0.2559485046132918, 0.10324502604142313, 0.1338437115473132, 0.10467662986728454, 0.15501314173302344, 0.18857505533003038, 0.14650375882704414, 0.2806627155551987, 0.1772474647770005, 0.19458827863056816, 0.07087594198603785, 0.10369287338107826, 0.0685252011903832, 0.17308373094326066, 0.12366460936684763, 0.25248811610283395, 0.07884126456995165, 0.13874111246437798, 0.11302352552452397, 0.15743250868493514, 0.10134131287134464, 0.2649107833783473, 0.17646240851571485, 0.10969533314627987, 0.10541540675706441, 0.18132199533283713, 0.12919296029834978, 0.1774905444753747, 0.11966948382436268, 0.20313504662725235, 0.09565759164791915, 0.18526491198328235, 0.16501209067721523, 0.12815326407191255, 0.19340361558621932, 0.18170897698690816, 0.0909307525463162, 0.26624895512096347, 0.15291959197530824, 0.10564810596406461, 0.10001539087463772, 0.126202505442404, 0.11415990970788464, 0.1768457282695078, 0.09162532616286509, 0.18389945218880333, 0.10901405881609648, 0.23644007562148958, 0.11235247080725048], [0.07243667759241597, 0.023870585343590187, 0.0693889576641302, 0.061559933613264756, 0.039872965069427606, 0.0471533399315611, 0.0582823068684628, 0.028190070597995675, 0.07341366186137162, 0.0074034622089276395, 0.05669323366976554, 0.02473501980515017, 0.03695995404174732, 0.06872968537913215, 0.03880354463152828, 0.025039648922580867, 0.035394813429804585, 0.03241940837113127, 0.05041550702205108, 0.016759975565477245, 0.08587261872185815, 0.051239086014609185, 0.026495838425152247, 0.02292082400902385, 0.035459103528410196, 0.01576714859824748, 0.029321195587756175, 0.1173764524320441, 0.026369399443689375, 0.034659372852934946, 0.04323914391739715, 0.06781085484450863, 0.02585408082532306, 0.05624122647268157, 0.05827564190352156, 0.05596300249078101, 0.05288348225275836, 0.06631024947930729, 0.10576573110395864, 0.05899666470565623, 0.06457859199614295, 0.051765223709686156, 0.023729960328989455, 0.014920789981260897, 0.03962993516676849, 0.032473417569793044, 0.02456755873056189, 0.04747523475558527, 0.041704524248357744, 0.056520055664042314, 0.05814561380013343, 0.06062833239294349, 0.05584125196741474, 0.011547361068697947, 0.00783599449336649, 0.04115287199496262, 0.033699817084256685, 0.03221543363085197, 0.022897985012781237, 0.00633850327557734, 0.0625580006218966, 0.04879357248184182, 0.09186250698422233, 0.025810588098641847, 0.03165006265795279, 0.024638425693997455, 0.014108919685015516, 0.037362280436941696, 0.08408650770903596, 0.046343205782074126, 0.053447096969091126, 0.02709121131638606, 0.03623849073905618, 0.01754807894148173, 0.028856007847934965, 0.01670846955910806, 0.041215361786946174, 0.0641707765809711, 0.013777618258891088, 0.06231462597967156, 0.07084309979672394, 0.019666762128772757, 0.06008541737232478, 0.059453521239300894, 0.061254854419178544, 0.053383561467090924, 0.05565308545145297, 0.02851640107110143, 0.027195046873643037, 0.020354029181743824, 0.024392848548990105, 0.02990990925970818, 0.019660780897303935, 0.022585534137643637, 0.035019859356144746, 0.049515583537398815, 0.03797109434080701, 0.016616129151154912, 0.03771933486625072, 0.045939098232455795, 0.031567204503282424, 0.007773610996082426, 0.08117502119632498, 0.02548061296223633, 0.031814796459530635, 0.024139187261161786, 0.022183165607613423, 0.018613280150138082, 0.031017174441066962, 0.051464116681487336, 0.004035073197296551, 0.03721475105492338, 0.008954882186146514, 0.02412283702963783, 0.0626304648786543, 0.031214162459476825, 0.013983744748627708, 0.04265197582783238, 0.030830792909968766, 0.010946433082403196, 0.03962779012058051, 0.0171934568413323, 0.08926176871623724, 0.065469169208119, 0.022653637438892357, 0.03168654568012684, 0.012228089561235281, 0.01161001269675551, 0.022979180756655913, 0.05013549805528695, 0.021844338325242844, 0.015480566597093019, 0.06956590099200126, 0.08220497278436538, 0.05563457293676273, 0.005931099153859842, 0.04179251327690098, 0.11706286966199837, 0.04118488297887868, 0.011581710536002873, 0.03530181035579693, 0.024629552480614474, 0.029254103522567503, 0.013069490631741863, 0.04930577886801574, 0.08473925292491914, 0.026022612507785522, 0.15937429642485035, 0.03733798778886276, 0.024454411374585285, 0.03287505831629519, 0.06502081625043385, 0.009213098824294585, 0.016628518708110336, 0.10970915337243389, 0.051591677981759274, 0.0323089155098123, 0.03566726493919569, 0.015870264990465538, 0.026799111566956968, 0.039023055634911985, 0.038212867859270305, 0.034259432821624705, 0.03670608016452001, 0.02481778985970924, 0.0767768951012723, 0.031414463808159196, 0.049038057951557065, 0.06862515268186409, 0.06349877574511113, 0.016785639510940642, 0.029560442931289156, 0.026554313916412574, 0.010534446318483642, 0.027800329112177415, 0.011113571442453372, 0.045489201607603225, 0.0249728977665185, 0.04404133373510934, 0.06570991999920338, 0.12877542705785844, 0.035903365576579686, 0.07792094782475503, 0.03414706304489124, 0.011185485073515486, 0.03732822399826781, 0.03575295570396608, 0.009348792147882765, 0.027098029498912157, 0.06069711176678539, 0.028222439728016337, 0.01579761687260602, 0.020247343777408524, 0.0035105524265447692, 0.04594910717118652, 0.05497173834291678, 0.09932014310071546, 0.030409936763105855, 0.07066205789845798, 0.021632788890612223, 0.024703100751785022, 0.04356694527931752, 0.019513548374356284, 0.0818686142203308, 0.02363084770378567, 0.04339074505673301, 0.013070724033299955, 0.01562454133114267, 0.04015567449612483, 0.05334921008456619, 0.04310902388345811, 0.03123239918251432, 0.015064357731100774, 0.0852615946543313, 0.038123005745752205, 0.08705673784378075, 0.013116577268397857, 0.014632146245980216, 0.01623580288592606, 0.03723652710417106, 0.05526917964039792, 0.035239542729311416, 0.044994825917866924, 0.01860674925058359, 0.03438848033246975, 0.0565571534717756, 0.043427360229073994, 0.03877453288183578, 0.04570991919946767, 0.020514040051268476, 0.0689642002145129, 0.08943376311611745, 0.043339191169868556, 0.025058797290248257, 0.03849237120800442, 0.047078148401792974, 0.027090531413353262, 0.004261959233366314, 0.06073900145448505, 0.04839368224624665, 0.10303567719435501, 0.0036585979603020657, 0.03601619500606772, 0.018581979712771795, 0.04896935135606797, 0.024955304557337396, 0.017916772161580382, 0.05416094152737529, 0.015943864014961066, 0.03579498711793173, 0.030491929238421783, 0.008570440113544464, 0.030069814792143244, 0.012553301545971585, 0.03628086306214814, 0.09542610285983932, 0.05426992519548344, 0.031166121085745194, 0.08450687547484714, 0.032622835358544704, 0.024683349089877262, 0.038398291780463153, 0.03328631346624705, 0.03305983489319202, 0.007546300260019639, 0.03987198830732415, 0.0344564629748704, 0.033795183539510734, 0.04690993464581909, 0.03960102683894577, 0.03526081699096868, 0.07453005114990859, 0.033687663099337975, 0.09121536953194488, 0.020469647171276233, 0.01599266860378726, 0.014602776350183113, 0.03214653934382143, 0.004225841539371158, 0.04808077363357429, 0.10286696165079072, 0.02904982043189868, 0.03276410197178203, 0.03318518602980241, 0.03719792010322694, 0.004781092490790593, 0.01563108276440612, 0.07115675151468286, 0.04750903455480453, 0.028389617350072633, 0.06223822020054345, 0.013046034934720206, 0.014049858136493114, 0.07453159864751563, 0.006919066250819954, 0.06250188851188268, 0.05606178569817736, 0.0596220069564879, 0.07659745432676808, 0.011298226402892221, 0.02360517801266284, 0.04495805752794108, 0.025898249624597452, 0.028925409668215343, 0.042301582533024976, 0.021355660414443384, 0.029565121813286698, 0.06421171248920503, 0.04812663165672172, 0.05719596354831612, 0.03998780164927725, 0.03111424161151292, 0.05523709587812905, 0.022680073217939467, 0.04074984845975715, 0.04981275287366683, 0.030186838553016706, 0.04652943792602709, 0.056797038583505544, 0.12346220893725274, 0.010531919185943421, 0.002797628131379644, 0.032833781498934955, 0.0910600069009008, 0.030366016942406857, 0.001076007956139473, 0.05961192523940437, 0.04985517882291348, 0.08020203590633408, 0.015472993817961505, 0.03579450065209981, 0.0524604868053669, 0.04134105383268288, 0.013160771923139693, 0.01833321947243906, 0.05190198955636832, 0.06501704709784639, 0.004335204421001817, 0.006260617510340507, 0.01982449005628305, 0.023424101640440287, 0.07003702974367527, 0.015852395989631694, 0.046329665178012465, 0.04310646131935139, 0.04079734208062291, 0.02383822387444877, 0.02488991703778025, 0.033244768518113324, 0.06858235134953453, 0.034041875342447916, 0.01627357485103271, 0.25198874935027094, 0.1031525285854455, 0.13173145392248709, 0.08948106904544177, 0.19562209896262617, 0.09336477476021937, 0.17179225992050864, 0.09720473685452054, 0.11743128134478485, 0.2756403963412008, 0.18451383938231777, 0.0881244269229712, 0.1473596016125333, 0.11070761874678636, 0.1378080939813968, 0.05626369966194034, 0.14149509129985688, 0.10901773603813303, 0.19084719550465384, 0.11375880139248987, 0.14929144553119136, 0.1781757028713342, 0.18596333902209036, 0.11058412537339235, 0.13895665896275353, 0.17281477279480428, 0.20810894908443575, 0.2243951509796804, 0.09967281167665798, 0.17477664736009416, 0.10383439280333058, 0.16766224927719564, 0.20898221270932307, 0.11022106864519658, 0.14343802817165852, 0.18680836464608871, 0.1721630464758604, 0.16002136492921462, 0.18293142348768252, 0.30689528211951256, 0.13920491741549584, 0.10822683452598511, 0.09124405952470918, 0.12183425677639824, 0.11903645005077125, 0.08012319779804639, 0.1758273675917618, 0.18993924341855511, 0.1299075671141186, 0.20911469995494814, 0.1672602522998087, 0.17380540108969136, 0.20056259998631096, 0.1203532862446962, 0.15065313617308296, 0.19135872773345441, 0.12155062038331263, 0.1597199706180442, 0.10234538600930285, 0.10505616514673156, 0.19376487200779302, 0.1499510165904799, 0.2351005402423682, 0.07405821759734424, 0.2079055527405393, 0.13686425833692475, 0.08871059143735517, 0.18501467702369537, 0.2211183171358801, 0.15557647682726383, 0.1395713679131962, 0.07426807972332163, 0.07892489838864535, 0.1082069468834708, 0.07812158625212409, 0.10487407370800934, 0.12274476759616407, 0.10368243926354956, 0.08979717224475839, 0.22928237824911074, 0.11896099039022962, 0.13665355351423064, 0.2326809741075962, 0.1276122757624234, 0.14747120530134247, 0.1818823580059313, 0.2385959696144827, 0.12339097042117389, 0.11159677869610249, 0.11288182990204905, 0.09348769356767017, 0.05520549475125248, 0.14269693003546807, 0.14430490262325735, 0.09904123347012267, 0.12457383315890067, 0.09570191749521802, 0.13425733773939072, 0.13553324185552137, 0.10574559831330854, 0.10379865480166289, 0.11351805826228474, 0.1348956421979012, 0.16084137012160596, 0.2279236293848484, 0.1084424959375493, 0.13654840028574391, 0.12471730610535992, 0.1439772161745256, 0.2813912651711895, 0.17690381305592676, 0.20181619562208655, 0.12403996180622809, 0.13643434511557703, 0.2736473726409097, 0.12098385321517145, 0.15540384657440648, 0.18639204182451774, 0.11613263207818232, 0.09330962409055041, 0.12952188780951884, 0.1448726503839416, 0.18854284899369364, 0.09891272222082462, 0.2281223219488898, 0.12053643488475393, 0.07484813085606984, 0.09951336579697748, 0.11445411045344607, 0.1586285404740803, 0.0742486747161996, 0.11075253448178692, 0.1573859918261728, 0.10929076211346735, 0.14289114864603167, 0.10103468617965138, 0.10589760547924428, 0.21388309166556407, 0.1762871888856734, 0.08785973588425307, 0.1497357305619986, 0.17574337371174367, 0.13277688814747718, 0.11873910834472026, 0.11847558175964702, 0.10573635163206248, 0.09188555856986393, 0.21347685056107663, 0.1307512750668872, 0.08464916098502376, 0.20301261045519384, 0.12003316108377711, 0.24321177193234045, 0.08063706659501599, 0.15504209985656126, 0.17756598881415783, 0.125816535024393, 0.10051074332647747, 0.06791771644906652, 0.1001640962016198, 0.1470918232394803, 0.17558468625910822, 0.15546000081925623, 0.15472653291879163, 0.07555996443355277, 0.20505693140289477, 0.11218085179045317, 0.1159919553526467, 0.1580659255024887, 0.11917615384464303, 0.10201822816123886, 0.08377741421422652, 0.18649514193736738, 0.15781031260567327, 0.12003762737637567, 0.11270946011908593], [0.05597642052077478, 0.060846104376739076, 0.09533731326941522, 0.07834648668405511, 0.030823767883703116, 0.009977080964393193, 0.0879563165888671, 0.02545657886883184, 0.0404785345909336, 0.01329082205155564, 0.008681177165389301, 0.045000211515974615, 0.03054211182790178, 0.06778610254367513, 0.046929067691728, 0.04036701900223571, 0.04984435783098302, 0.0563534468622698, 0.0813026667662686, 0.05311089928352064, 0.027015479694631313, 0.03153679655834792, 0.06468474113893125, 0.031380514621794704, 0.026812738355910106, 0.07724606266786015, 0.017360442941407525, 0.06222695870805652, 0.06174179139517008, 0.11029646701870427, 0.008028261973747924, 0.040844670992584965, 0.029081465608830896, 0.07909046531084084, 0.03797386757909291, 0.024071924741409963, 0.05222945000916239, 0.048975100845939694, 0.011699404623810084, 0.04444876993675867, 0.027887249448066278, 0.062034777891371524, 0.04924024770697279, 0.05968520154936179, 0.043796618439016805, 0.02460593782034853, 0.029606509713395953, 0.038617764479450645, 0.03446615398711255, 0.045985810443638794, 0.022112978547210657, 0.0037090800422799565, 0.032454483706744454, 0.03187474858526501, 0.01914655778466934, 0.028224690111293912, 0.011345725769417421, 0.054206577385024685, 0.016149367100649303, 0.03487008150606867, 0.01903122516288873, 0.08049327189162855, 0.0870557802338754, 0.03920255769645015, 0.03369640416255401, 0.03243821199923273, 0.015750853908098033, 0.042754321344076626, 0.06862500712515847, 0.04220369564850004, 0.10952596642797995, 0.03562357111443435, 0.02112334425140533, 0.12741968125825928, 0.011569988433151476, 0.030556259556643428, 0.04254336754280714, 0.02555015267834308, 0.026219690541526484, 0.07176837313079065, 0.05835769758109124, 0.022717268701883096, 0.04447409680353538, 0.025122135524607958, 0.05749062011619249, 0.05380081891592953, 0.011680310839907298, 0.008860098915324818, 0.06785793094745568, 0.05657763100199162, 0.11883568138845506, 0.05431299465858648, 0.04159474384880835, 0.09333062256055494, 0.010020888744733267, 0.020196316575992013, 0.0439616835736219, 0.017046624599325082, 0.02318453637041873, 0.07077102624480763, 0.02684675457496797, 0.026898603405683275, 0.02731753284141662, 0.027548958427242698, 0.02355625563781829, 0.03456839608148702, 0.08602074948289702, 0.03442296961082086, 0.06978208334335397, 0.009532767205288815, 0.058123083154280344, 0.008721858349388406, 0.022354847826664487, 0.03281546050622579, 0.03629760208329366, 0.03142725364605506, 0.010900260005596905, 0.009319537165274304, 0.04162534140050412, 0.015450110771663248, 0.04826038294742185, 0.0407064036135712, 0.07713180831483296, 0.027755436359814582, 0.033209624234586954, 0.053190495818853385, 0.016979634040786375, 0.02677298030785976, 0.022467705984449676, 0.07931807769402381, 0.023294379972221873, 0.054612136671259526, 0.02927720681914399, 0.059631192350700024, 0.06235611347121097, 0.05098159237193966, 0.0271228430867796, 0.07983410685893991, 0.05904012487360066, 0.039642123625643795, 0.04150536437068255, 0.01504659406735652, 0.01234596080687498, 0.04051539108097073, 0.046558449675719586, 0.08598534855991603, 0.050379025915096846, 0.059367420617491014, 0.03537132134360652, 0.005411663291705472, 0.04516453737573278, 0.017195525278727856, 0.01972014313533662, 0.05480439792717657, 0.014519724758311868, 0.06223036396887995, 0.03763349471433509, 0.07059474175255145, 0.04860139166515681, 0.030647293784685677, 0.02237260574474931, 0.005866997704405579, 0.04018729860563913, 0.06294196388954598, 0.007334012986956946, 0.03791963621493309, 0.07499505885906758, 0.06744001466300219, 0.021478255549746177, 0.0593889668403614, 0.021196948063950387, 0.045190726091424306, 0.0846453228845231, 0.006400527669146898, 0.03438368845250338, 0.022033240285611922, 0.027125532055393826, 0.023329759827784957, 0.06293120801508909, 0.018370979946226846, 0.03196657379908908, 0.0605681102212158, 0.0788990275994424, 0.02332321360647198, 0.015404315950769572, 0.03147533140896309, 0.052035602951242085, 0.03755842958907447, 0.025951852796659357, 0.018685363278153445, 0.03427322623470137, 0.04099921007911044, 0.04433599796386496, 0.0038115476537871388, 0.05698325540570002, 0.049806505426644325, 0.014342173348150909, 0.031076153635137507, 0.02359501777156707, 0.01876480659590133, 0.03711105339349278, 0.06772321438597095, 0.06510822688259425, 0.0876278640522111, 0.03808658209539229, 0.06254340281649944, 0.02656506787564966, 0.0327010989008892, 0.06589555076413578, 0.024117654444830074, 0.03886341823325042, 0.023097673491124186, 0.03824102159048762, 0.012034310493618252, 0.041417130194003546, 0.06679835473938335, 0.03206851520395327, 0.04754652689781882, 0.07117516826838255, 0.03556228025005229, 0.022525610740206415, 0.03337206168761177, 0.052538164290449316, 0.017226873596589413, 0.06480282593157984, 0.02070880641469792, 0.022133291368522955, 0.07226359534768328, 0.043528794100688356, 0.04070757572809535, 0.0013950537709939866, 0.017568202156032768, 0.02687917541592352, 0.044048688179182435, 0.030224470707077174, 0.04176275459148231, 0.04425776506503744, 0.07848344022227872, 0.07991728102487904, 0.01852879214340881, 0.04413647036398611, 0.04153289757068119, 0.10834552452809389, 0.03135162353095028, 0.05962163923428424, 0.018077880452056567, 0.08382239889714026, 0.02956862091988085, 0.07428786011352655, 0.07287169295933939, 0.02264669668229838, 0.08440513133762345, 0.05779832316141936, 0.07608585315005434, 0.004357654148817904, 0.051689350361665415, 0.021536572077762217, 0.09749113116413356, 0.04305357443949869, 0.05031110455973014, 0.04469949136217756, 0.0658980405498897, 0.08717702130877203, 0.08608509320765735, 0.03450175792339348, 0.07279192022378407, 0.04279920643556022, 0.006848451138789496, 0.07256220875968857, 0.019031868676745126, 0.07581075097644523, 0.003307715087430552, 0.06407123877696934, 0.02821671130556253, 0.03289230295547074, 0.03150930549318512, 0.052685831568294, 0.05999687676047606, 0.04290956140105282, 0.014362133769018036, 0.04823096517112948, 0.043904514262272466, 0.040292547595116406, 0.029978567974702008, 0.07563304922152912, 0.05384812867569347, 0.04025507440430023, 0.036895028090164546, 0.06059415721064133, 0.04509295028964839, 0.016564824242865848, 0.012601679998389896, 0.03699397983690424, 0.016344746334418174, 0.07727337370236075, 0.06294710816995752, 0.030839606751537615, 0.08081155844152936, 0.07007696590716801, 0.021615925380179, 0.015318587839212871, 0.09844888662618977, 0.012514714654835482, 0.024288729539201147, 0.03162458065837141, 0.1012376994795857, 0.014322791323666612, 0.0714969328574596, 0.06959774726701361, 0.035980411039124575, 0.134021183475852, 0.03736684249053079, 0.05962553479137921, 0.06268080834659838, 0.04088019448963385, 0.021128028879062306, 0.013552026432608406, 0.009811674920661796, 0.017272522860777476, 0.04093962376035991, 0.010523041184510916, 0.061187339090411706, 0.0614043066818868, 0.016742960752678976, 0.012293396641560381, 0.08629240426084689, 0.04440945047404497, 0.023420539331592383, 0.04714402813284148, 0.0181291623777079, 0.024543101373579235, 0.04317364723031079, 0.048493660550804875, 0.044167845494925015, 0.014135958758302996, 0.008848125918678219, 0.058250862789610704, 0.006203197784000828, 0.018346319575944257, 0.047277124418366345, 0.06189019028698245, 0.02246585779733235, 0.08981318348237584, 0.03822976392844031, 0.019866105867549777, 0.044477325864136226, 0.032824921692090656, 0.0459930767876006, 0.012357145690569475, 0.09228564032744016, 0.02048536921070228, 0.0240006823948915, 0.1541771559465316, 0.1805559533738321, 0.1986017673005981, 0.1599561248815829, 0.1999089124822809, 0.17296247454660554, 0.20878247826570467, 0.10724628794818156, 0.19058720058491155, 0.09829245913293093, 0.14124853356230643, 0.21984198401051186, 0.14523534705081295, 0.22017109538278273, 0.14450433063170603, 0.10544452575906631, 0.10878168902690373, 0.1598207877888795, 0.20921007790152105, 0.19041538238525393, 0.13934383979968487, 0.11454574989094851, 0.10979749097098267, 0.1297223423757861, 0.10877114765706564, 0.13451868097387976, 0.16806151898157212, 0.1697869175263951, 0.1218636362482944, 0.20052334564107083, 0.13523961567590315, 0.15367072586330677, 0.19424683324271635, 0.20860523616354312, 0.16865771924776418, 0.09273168736047323, 0.07979905833640406, 0.1009244614491059, 0.1944173490929027, 0.15681399993838804, 0.07385138151866776, 0.09525089855155638, 0.19882177243069296, 0.09055545373309044, 0.08146161468879831, 0.10426078202022661, 0.1553728506569901, 0.10138020715526036, 0.17004865912660477, 0.19883606763136005, 0.07758186198771, 0.13348879833375255, 0.15596027155556988, 0.12995959980593574, 0.16680738708424955, 0.13444927340793994, 0.12092425157466244, 0.09836400408417949, 0.1464392695455782, 0.08058107322863034, 0.1272340351715684, 0.22766412476137762, 0.14295534681408636, 0.10136291655080934, 0.09250520112653894, 0.1407159032720712, 0.15791232487367046, 0.2532196074964539, 0.15282357051487894, 0.16657072720268082, 0.14811009198667544, 0.08895304294363146, 0.13194583596721773, 0.21504325521809442, 0.12244717308109808, 0.09166791299057585, 0.17939822598090097, 0.19125627113446114, 0.12329088869474589, 0.15141023022513236, 0.16742692238861517, 0.16326226924936618, 0.1320080576284278, 0.1040408228554072, 0.1647955635862966, 0.1815158002559216, 0.12332253578689792, 0.185563916100129, 0.21303115592848873, 0.17725435956831903, 0.14334206799826316, 0.18915630155994048, 0.155598157115521, 0.1729862539157752, 0.12644658871595899, 0.06455702662107445, 0.22768689289448724, 0.09949609051428496, 0.13444760333626501, 0.11486904665587411, 0.14836359048081985, 0.11982844706865088, 0.1632436073475307, 0.11489314012109272, 0.09948237754044034, 0.1609613088470313, 0.18951268566231574, 0.11498464166276878, 0.14941682348087912, 0.15487726837877305, 0.13419554508741827, 0.1409858113695537, 0.20518941864851983, 0.12473605993774631, 0.1003972780440123, 0.17191025278260633, 0.1105063904317156, 0.16270506285852002, 0.2301560249179602, 0.13528553498608453, 0.10983065491722477, 0.15229287076621287, 0.17240280135264321, 0.06250073554955664, 0.07526535000051222, 0.20121152242345197, 0.1302284813455997, 0.08970803025388911, 0.1560013338683113, 0.279023869624061, 0.1252902479421708, 0.15723662000269661, 0.2026718392247154, 0.08774758827301764, 0.18171829261606742, 0.15125423940199037, 0.12425845774311213, 0.14681719604038423, 0.13817244539818457, 0.11609906210534035, 0.12660676237916754, 0.15485310596564125, 0.10043348335931379, 0.10370949748903514, 0.13609320616289494, 0.19956455596031683, 0.16048812697972023, 0.17887155585471662, 0.13586140327876614, 0.16034906669970483, 0.14732823797291325, 0.1421879871838516, 0.10348329470763284, 0.12858226564863037, 0.09505926931817686, 0.15398970955321867, 0.0799969005428495, 0.14999005643110122, 0.12973207169242446, 0.1990499134145437, 0.1424535285801657, 0.1307826693500242, 0.1322945745121087, 0.17747431873313843, 0.1281241527307899, 0.10338715067313564, 0.15042847322840847, 0.13841187851803918, 0.18967665912162876, 0.25277193635702133, 0.07223162649860305, 0.12982409417388902, 0.15414825911002775, 0.26046094634840566, 0.09903685144719579, 0.06202402201691463], [0.06107527957928758, 0.03009219796607091, 0.006354337355362312, 0.016924575301668337, 0.09793715521452889, 0.01999847436954658, 0.07319339626138249, 0.02705835572053348, 0.06087675555458954, 0.06972575289828163, 0.04331500960453864, 0.04404418358218767, 0.024638075208772096, 0.06305878846755912, 0.0330789104825066, 0.040037880816887465, 0.038268424555539124, 0.07302837326161324, 0.043959894758318706, 0.0783886521634075, 0.08971925344197981, 0.02834232291206718, 0.05906295812418384, 0.04943192673606738, 0.08194265661821251, 0.06424213001023858, 0.03863099864834259, 0.07525046491214345, 0.008554265124633188, 0.03275504681251703, 0.040219627516043764, 0.02417820220392558, 0.03588761480885648, 0.03552866048149524, 0.023182737979016477, 0.0541755469936517, 0.034567675958838195, 0.021875186770733808, 0.078230278806821, 0.044408305172598174, 0.0436585387515445, 0.03152690444802565, 0.09107095429733877, 0.07433942549170987, 0.025544539169077913, 0.09141881950199605, 0.0004609113831623202, 0.014032995583669794, 0.092481981001554, 0.04318929457616422, 0.03793094367269547, 0.017284657693498077, 0.005800289161983998, 0.021453332794349522, 0.07872919356750865, 0.06668098240850434, 0.023619584296078935, 0.09041362021478916, 0.036497167987568725, 0.031189007962483074, 0.025092060827920516, 0.05161990066088977, 0.04445581794566205, 0.007946176131466224, 0.013409633670122394, 0.030264010420069102, 0.044607530167746934, 0.03754480471534114, 0.07756483185315326, 0.043928917993100426, 0.027180406933410034, 0.03003536190296854, 0.03277953481301665, 0.026933617454262513, 0.038153779497670556, 0.03346499198326661, 0.023807982553637797, 0.056220729790267446, 0.06677064533916212, 0.04901860697915958, 0.015062891630335681, 0.023405284605800145, 0.028352454424865788, 0.04793838087108828, 0.02021949839658074, 0.04052936452470961, 0.03467221631698551, 0.03162695936137631, 0.047486745226647586, 0.03148916312643597, 0.01849267492821861, 0.046292057921809536, 0.025618681158389778, 0.08055527138734057, 0.07104638122743176, 0.045204615265491514, 0.05014806189724515, 0.08325442131007872, 0.06848131967408043, 0.01911997070325719, 0.040474788420983863, 0.06430365836187717, 0.019156153035920956, 0.059118878712216695, 0.03885959545450826, 0.011003207858471621, 0.0185201276889852, 0.01353635801933706, 0.02112036608459969, 0.029661859565925215, 0.030911260870315378, 0.02190414872471123, 0.006486030742375842, 0.04330966614126679, 0.023612373493491642, 0.05304380913355178, 0.0271667265183022, 0.08787920217840903, 0.0865381346234391, 0.009292530650723605, 0.09220905451764984, 0.015445015329356878, 0.023354276556581743, 0.05615183550323691, 0.03196336963634578, 0.02152530483961586, 0.008128900550335886, 0.012942969295827132, 0.032995717164369366, 0.012410803446395984, 0.08451698017456839, 0.04196088408089934, 0.05074615440061016, 0.024618963230281107, 0.04850118353422131, 0.02849758020602167, 0.045273612974391836, 0.0051595743993417395, 0.04057783107723921, 0.04129831378738727, 0.028785073851806023, 0.03130085105376859, 0.04670450433848366, 0.014626129582944899, 0.05508019724079678, 0.0372840513685538, 0.03069840334055405, 0.07876484729950467, 0.046138016792434844, 0.005038763770097566, 0.01933031546462688, 0.07712154273664759, 0.04314901367310555, 0.008790129232370566, 0.0444845692254603, 0.017747148803825823, 0.04491464715571173, 0.007027565368315987, 0.04592672974291829, 0.05629935722437598, 0.020681832458884008, 0.06961011958699073, 0.024879153502444108, 0.028751285543905634, 0.06451637799581213, 0.0822505243723431, 0.02855619359310837, 0.03737960934578892, 0.037221017654144, 0.07052882754754636, 0.03931099361169242, 0.026055039094400503, 0.016840365001811616, 0.021395675101948362, 0.0169532940227298, 0.035680889812929016, 0.019982281186047102, 0.05004220003742845, 0.005975515495294766, 0.047126894576414946, 0.025142262569598617, 0.030727315498816393, 0.08427845103846443, 0.09039655943671543, 0.08658291246261328, 0.04215286188428441, 0.033967032382685336, 0.054829533271972215, 0.03389593942331211, 0.06377181331176432, 0.038217207747361356, 0.0070037175300380885, 0.026141426999181993, 0.05743541198992922, 0.07158767597209062, 0.03883607655523285, 0.023773479868748018, 0.09185397276474584, 0.0661844884856574, 0.028322931311483827, 0.08427223806539852, 0.02135127647629669, 0.08617533836513759, 0.025337337283417586, 0.006784156252134352, 0.048346851291435386, 0.05172441803639935, 0.029811535909351324, 0.021181478833539352, 0.027162949704835494, 0.02826098735714632, 0.024189580524820956, 0.01698448146212726, 0.021884500484673247, 0.09285135795512507, 0.06436586470132874, 0.0222109382100884, 0.027305832763593045, 0.03496103529487887, 0.061934098616362586, 0.05455297170086734, 0.022951264512695135, 0.08539054257374618, 0.03183907378585108, 0.019907089656278975, 0.01325641800048611, 0.05572549991249558, 0.024429341147263205, 0.05412278268786688, 0.024817253598162246, 0.035030293473673445, 0.005648680361768892, 0.0326926336293259, 0.08457035352025302, 0.024069392820820216, 0.026002110079711965, 0.04469809708215537, 0.05804228003046686, 0.052132800356635166, 0.019061533516393076, 0.010795327984998304, 0.05622967769722304, 0.0755509858830802, 0.017082504327258757, 0.09931625903493936, 0.022103297111067562, 0.002212429366585228, 0.010601474223808657, 0.014990540371546823, 0.023288636228009578, 0.019883250915295175, 0.06053427594803995, 0.022133908069302, 0.028355513030903477, 0.0171919897829573, 0.048630591106390765, 0.0515678066820387, 0.0549756262391325, 0.035423549387844346, 0.0993651431053877, 0.025179274192440416, 0.016791118954819058, 0.03654363888105558, 0.01235485413006597, 0.00957528125464676, 0.011956003858828017, 0.027011501783084486, 0.0032450555590912704, 0.019768318574454997, 0.04573580531042911, 0.060285102020228104, 0.013176503538664792, 0.003428590594745812, 0.01589273339167478, 0.09200742783685846, 0.07074228262588864, 0.0554322031506848, 0.025646312034598766, 0.020767779863109032, 0.037375775075727896, 0.04797877285689597, 0.03732619769570809, 0.03293793115224088, 0.008403459759128672, 0.06637983324546969, 0.05789753920849293, 0.031464138864389354, 0.04087741742090833, 0.06633212128954549, 0.01411049878374944, 0.015237779927349862, 0.032939133910282005, 0.0341944111090514, 0.029621890843695695, 0.02043096164631988, 0.012473990378390639, 0.04058367632810147, 0.055933718779875394, 0.030424898460267052, 0.040028369835307526, 0.011749187889959545, 0.007575383830455042, 0.03916775049161046, 0.011321837232718545, 0.015965254147416882, 0.024694775291267904, 0.09620010447237762, 0.03812298276311448, 0.051357143994180426, 0.04259797045961023, 0.024857959680018887, 0.05883145401434553, 0.04679480695255822, 0.03488604677841067, 0.05836112965499202, 0.037080344759048, 0.03530337317516247, 0.06189539585442794, 0.0573707809821973, 0.05622998413239276, 0.0552382143664985, 0.06725808410274406, 0.0231503477815779, 0.024362099694929296, 0.030297570816812017, 0.043052770047178196, 0.019789179148633155, 0.0508958901158504, 0.04648769379503304, 0.050762418447242635, 0.026957084642603036, 0.04387272927429407, 0.05590183037002722, 0.0533786699956944, 0.00978836094990613, 0.05667209730393464, 0.0372546833879765, 0.035280953612058394, 0.03153524906074088, 0.049165148107755574, 0.01455099359455128, 0.07732346819172944, 0.026805908682065147, 0.051899744918750185, 0.048280868138517105, 0.05831523715788799, 0.030515170430824645, 0.01986116268521836, 0.04927269536100569, 0.0838306036988093, 0.02398844414030112, 0.06434715683421781, 0.12734659647028293, 0.12483522235866516, 0.06494529530285828, 0.10426501848644788, 0.13855339027941227, 0.08738732776574551, 0.1571250469574044, 0.24300543381081474, 0.15713255461906234, 0.09734078640899352, 0.14397706295694077, 0.17414666261644135, 0.09889249749962362, 0.13592892626841224, 0.11620520358724941, 0.10755394119769336, 0.1190801630277307, 0.14571721635518536, 0.13995525457205313, 0.1878730736432537, 0.12735022006616478, 0.15164074608154837, 0.11239572413145535, 0.1456934369860157, 0.1544329220609319, 0.17268648371100428, 0.17252453272381138, 0.0942526476818227, 0.120397420570014, 0.09401824775963061, 0.09367879420038193, 0.1715361414056632, 0.10919539948865291, 0.10343484730730135, 0.07360428751957032, 0.1663807067539423, 0.08840509855578985, 0.17135520675970664, 0.1996452863057775, 0.15756928602293616, 0.0946976988005542, 0.16870684080546902, 0.16722898059073957, 0.1166717664548947, 0.08709062957355092, 0.23588893664700372, 0.1154743480466066, 0.14722942795243957, 0.2414206430436142, 0.1789620921256081, 0.21148181971042387, 0.10487451803900542, 0.07223528073800188, 0.09004190669304903, 0.1327441915148689, 0.2854592226926358, 0.133545795275319, 0.2305630321103719, 0.07932651232207015, 0.20999220770693597, 0.14221881456192464, 0.11052309114846492, 0.10608356566198411, 0.2242894308461297, 0.112367095425725, 0.15415080252193636, 0.15961089501938514, 0.13029614223107217, 0.15750966906066866, 0.11640324497655516, 0.10499262581429175, 0.2465140245734684, 0.12102801818400623, 0.14518443284736526, 0.19865101143237085, 0.11889393471421734, 0.18252752661224336, 0.101758562659304, 0.12208952493364773, 0.09339675893105807, 0.17562109075727003, 0.13099558050594023, 0.17055763262173823, 0.19356199660368506, 0.14930865186597073, 0.16452727959521357, 0.11663561476574791, 0.11824560982565727, 0.15978829033913153, 0.08531223306612623, 0.12521419073304824, 0.17321712217263638, 0.09193258870753551, 0.11087630364683368, 0.18884635770753508, 0.15257528141861962, 0.15912038424322683, 0.1558514564268051, 0.14930217076213131, 0.14714808473663946, 0.07276304636991794, 0.10415902256124443, 0.1314787981250594, 0.18050220464506458, 0.25114684936500364, 0.09915082234769099, 0.13577221532262143, 0.10158554170160525, 0.16507965963213675, 0.17212999744280694, 0.0997946426392563, 0.14807773243275382, 0.16975794408109882, 0.12327329165512517, 0.12054204264835966, 0.1331365357844099, 0.06787039519798371, 0.17301544186569032, 0.20486026131097348, 0.10913593574397026, 0.20993876541333817, 0.1234955261010797, 0.1782428581387766, 0.1602572127575836, 0.10579861159766875, 0.22433504372114138, 0.20879772341539785, 0.09699298249137017, 0.14631841151464373, 0.08316737073924273, 0.23874414634079705, 0.11491109722203786, 0.19787007672411783, 0.09893388156929324, 0.15858465895777749, 0.20457095586724822, 0.21747141685937682, 0.1355022306163465, 0.1799346867107576, 0.16425698845376893, 0.21844061001414256, 0.1224820607251698, 0.17202705054754214, 0.11824415425860113, 0.20680054751855714, 0.1873258263954232, 0.14953625658827444, 0.13986058142637053, 0.12324470891467026, 0.12851396891018077, 0.10757165315050272, 0.2414797697096102, 0.1894820727888615, 0.08385955416146787, 0.21297513957946532, 0.14498958604470377, 0.1609034998522651, 0.18207665322528732, 0.10091867748527758, 0.12685809284448624, 0.19618096010338879, 0.1601813087660459, 0.11352587235911239, 0.1616765898201735, 0.15339036832653707, 0.2862653616935976, 0.09075411565361485, 0.16647934823507266, 0.07326701731090585, 0.17233048265259113, 0.12398104964485093, 0.08719637268973936, 0.15238861643498944, 0.15917687556676327, 0.10412066453887571, 0.12842209964630105], [0.015020597831255969, 0.02152761842514719, 0.029081706926527045, 0.03423912383075203, 0.009421562839810167, 0.03877222695718369, 0.034326921337314194, 0.03581666740618887, 0.0772921045521094, 0.03410332325485445, 0.07328498207273022, 0.06343485719914879, 0.03331749324476527, 0.03425340370966062, 0.0568991351211744, 0.06602865854097952, 0.05658976966515184, 0.04568528564226243, 0.02330661056593301, 0.03996394184087554, 0.014566745319884392, 0.012173686784902408, 0.09448428202660815, 0.03579558849695229, 0.057201517685767145, 0.04296545134556871, 0.055025548358718236, 0.05927411493875327, 0.06653218515097134, 0.035551355836252053, 0.05381908245204438, 0.04667505974911394, 0.04802017990920333, 0.023350325458112265, 0.007408019953272156, 0.10164482924606531, 0.03485168007412746, 0.0462997647663278, 0.07195653964675243, 0.016444845297824473, 0.06558050476615468, 0.06709748143029791, 0.035408346372986996, 0.027727832296682943, 0.015378038177356846, 0.02378968645878617, 0.026368252227022767, 0.032537359098393115, 0.03832349095553641, 0.0462615906050609, 0.024933698962652878, 0.01667686651701168, 0.007164847845542095, 0.005601285374723376, 0.03048808730748152, 0.07843547545733952, 0.03451199285806187, 0.019310446974310665, 0.05146490958248896, 0.07896046019009045, 0.02070509280348497, 0.007107181055846835, 0.10884142856323913, 0.05787131218840519, 0.04577313294453968, 0.05218236624533611, 0.02739360345707786, 0.018851345803047863, 0.10342687999288883, 0.049363829180478096, 0.025227821184202068, 0.0017180567890811233, 0.013844740009986827, 0.04644630206448417, 0.045861413086494135, 0.03451238739334288, 0.04132809928588329, 0.028291334015046878, 0.024873459553946892, 0.035679598954776605, 0.07925165021010945, 0.024763206095104257, 0.04065882572303376, 0.02556749690894879, 0.04371167077953297, 0.027980139524105097, 0.015000957252097227, 0.01851845570209046, 0.02316484216510529, 0.0043764534676747945, 0.03761064614199343, 0.07061183317414216, 0.07618925203719447, 0.03635328135363037, 0.08498167378767844, 0.05268244545966868, 0.04753939078880414, 0.02200003995019342, 0.02462300817452131, 0.044295893261028875, 0.05439775462652888, 0.0380461364834299, 0.059809579754308353, 0.01744384310328432, 0.07020417480699478, 0.00726327482205365, 0.03988066042262701, 0.06684891654238587, 0.03433337562807626, 0.051608145041691686, 0.04798050804604446, 0.029774531947388768, 0.04647916340599618, 0.047254429063609535, 0.023714743907593434, 0.06324520830305354, 0.02105975129281081, 0.026224323458248572, 0.008048588680403848, 0.025866935780692487, 0.041459192251486164, 0.03859925579520003, 0.05007162930503969, 0.02694172649494102, 0.04553757622958191, 0.039829638966869925, 0.021547502237221888, 0.017084151416295962, 0.04768030500159629, 0.057931113011774525, 0.014944592333068291, 0.057932875014000365, 0.033984407256808014, 0.07035389137003692, 0.035924256794274814, 0.00733612020755367, 0.04159058016093989, 0.030192476960139412, 0.04151803546495015, 0.03614127035102537, 0.05326990083220506, 0.06106923897600463, 0.026351009503067024, 0.05817356068761118, 0.024248439060043425, 0.061700319225389155, 0.04836547105843502, 0.0064818287501111635, 0.04310201034851132, 0.09259818887878811, 0.0725773926223478, 0.03196928575034103, 0.05359873258238358, 0.03875600121494743, 0.025206998914420128, 0.007929857022264192, 0.12191529355702863, 0.055251705174845074, 0.002439744890697541, 0.08063432400024707, 0.06326284364707048, 0.04064282214629554, 0.026767799638271816, 0.07461489538752264, 0.045582534099418315, 0.011376208407924542, 0.005445016844708834, 0.05343385513931994, 0.0199653142537441, 0.024055112941911625, 0.015398689992575636, 0.023241232622474916, 0.02996521697740161, 0.09556545425326594, 0.07345914450143615, 0.0365144164571839, 0.01988351330040924, 0.013941090888223581, 0.07700946407332536, 0.019587062171570236, 0.017467632048553037, 0.008067734175241523, 0.02355814404455164, 0.04825601624625345, 0.07593676477911011, 0.058281563763176246, 0.04312229252630665, 0.08117123672197904, 0.007555451659080122, 0.05775791585385319, 0.04385186870011591, 0.03827552619059721, 0.05653807022158177, 0.006376793786447736, 0.05190195125197211, 0.08765514444319472, 0.009164248270192936, 0.022977435991408366, 0.05162834294981534, 0.011275654579813202, 0.03579730453390268, 0.062057622633273565, 0.04206110370315371, 0.017103389799294454, 0.06871545146549903, 0.010211582393235257, 0.0438994006253779, 0.027499292947111592, 0.08938682490899678, 0.09286067358428433, 0.03193295977619146, 0.092690663352128, 0.021323034644968087, 0.0383466306412893, 0.03360536227363252, 0.030312168622209184, 0.03342098789289594, 0.0417059300196988, 0.031888854179170825, 0.0179014197595778, 0.0325847492973891, 0.04826471134419403, 0.01686107044318511, 0.12083192265802815, 0.04520291838073923, 0.08253707956042021, 0.018823571285353075, 0.05023164208978415, 0.07301901166717853, 0.005520467886761312, 0.025740073535651452, 0.04698587311131339, 0.06165521196840752, 0.045584073936146115, 0.044913842763391235, 0.006870169252637895, 0.05723666963017276, 0.024804147748997616, 0.08973134230942496, 0.018191033553692604, 0.07036186634532868, 0.04650313812758654, 0.010124273267724823, 0.041802085545514865, 0.04566247537431698, 0.028084708610549573, 0.014784070099854182, 0.049834283774778734, 0.014227507222864418, 0.02655719823744749, 0.052372880820785804, 0.018628015851361618, 0.015840779223869887, 0.04782025011316423, 0.008248576890647171, 0.03886977293258233, 0.05510812114563681, 0.02967057573128372, 0.0686021930267734, 0.04170305335954313, 0.020824552723957647, 0.027806584220079165, 0.03123769093485129, 0.04953428757407012, 0.042491522542531454, 0.05578755686480192, 0.03937773902209536, 0.032012224978496956, 0.012552070059633304, 0.02290119109074435, 0.020093810181283665, 0.048215781308470235, 0.03860381018790988, 0.039039220090114304, 0.010019878466283123, 0.035719121430790236, 0.04744641452787384, 0.07444015073199427, 0.04093763193175678, 0.053120843104777805, 0.03971645713693673, 0.010187588519446794, 0.007894080716200293, 0.11431751697654687, 0.01161524220444863, 0.06066912657491142, 0.08325286615159243, 0.020874059240844463, 0.04708672858654492, 0.054429692832092126, 0.04476284300307593, 0.03483143237028872, 0.04892890191366596, 0.06447245817511313, 0.05411471195158459, 0.019679946501949624, 0.0329312393742223, 0.10910121663924187, 0.0016178546432075243, 0.004441191727716115, 0.04052527744563357, 0.05720436753284547, 0.03831181194513075, 0.05699551664292813, 0.05687170534304554, 0.011661494762877063, 0.03633577624456056, 0.09236474656650136, 0.04380795654029616, 0.059838426795097134, 0.10320958681404592, 0.05435003117928582, 0.05701693263085139, 0.029447682449714314, 0.05753749320583959, 0.056340323776126876, 0.07082004821108234, 0.030134476443392136, 0.02611166831376332, 0.08978204200825385, 0.07197188438787576, 0.03617836049787941, 0.04147309674731186, 0.06760536708057889, 0.06564067331172767, 0.039487193834276936, 0.045824016504470384, 0.01975529316452242, 0.017513695000220212, 0.04625264652854493, 0.058241685056277824, 0.10162965304428533, 0.025280736792351932, 0.06095275530711778, 0.04115634237325961, 0.03193731307082119, 0.04263106162749952, 0.06862469302910952, 0.03422803470804807, 0.06305572411586201, 0.028576719003819653, 0.019174179084779277, 0.029410519524507468, 0.02012340798823824, 0.029936174584192135, 0.019050475037206086, 0.0876043145094187, 0.007354400023036907, 0.027274275686772122, 0.02110091894264183, 0.007768392022098265, 0.04115164625428377, 0.08971156958009928, 0.07770287323622935, 0.2059660632643969, 0.1273661317123521, 0.11096785881466444, 0.14296306898036312, 0.1183189397617694, 0.13956893175359697, 0.16036428120588103, 0.13715845142160693, 0.15280696172868052, 0.20103840187432306, 0.20696616040602808, 0.15107957135525443, 0.14577718571789805, 0.1227596450236536, 0.20535582826743204, 0.2520189332144876, 0.11264559902971792, 0.1632595879416312, 0.20404279953049076, 0.0789216501758464, 0.2048631111580518, 0.1464156280722349, 0.26574618693801666, 0.13827652610357732, 0.16653354129483625, 0.23241166355869464, 0.11853889126570956, 0.1466723288139028, 0.10494017177411627, 0.14609272201215068, 0.1899886714114297, 0.19998303914983429, 0.18548565255778451, 0.24230061759871824, 0.11856306900059986, 0.12014096497648186, 0.12942085613406476, 0.13880071410488698, 0.16497533377860824, 0.1146271467329033, 0.1736885420377216, 0.11765320935556967, 0.11190695237488517, 0.10279163222519622, 0.1473867517685698, 0.2133379281768876, 0.1491934628856759, 0.18395788937566743, 0.13526774642448272, 0.1565095412755205, 0.07621996450207888, 0.07789919858858471, 0.06478666147637753, 0.18237371147880632, 0.1297147581053357, 0.1495087233882758, 0.19700424415209603, 0.17322363391999276, 0.11877235656063403, 0.23156389533992738, 0.2983709604990098, 0.1536626972618603, 0.126468675030816, 0.1526924469057591, 0.10168581495001432, 0.16640382728749709, 0.13172466638347796, 0.22146173903057653, 0.12056418258937136, 0.18760771610804144, 0.12198513013220603, 0.10730929101907438, 0.13920427390163945, 0.13697702647937884, 0.07220534968280024, 0.18856203183531764, 0.08983614313746653, 0.09440370489873233, 0.300780184446804, 0.15913967433716023, 0.1556856443564738, 0.09559054363278613, 0.12256903468721336, 0.14122149065857934, 0.13828136777925876, 0.1423614141681502, 0.14858816149494342, 0.1028361572553554, 0.1933519965818813, 0.1232089938956403, 0.12930362935989134, 0.1685603801161051, 0.14334130191033886, 0.06330430049509292, 0.10144767651875174, 0.20867806048162524, 0.1024513129865931, 0.10162039104128077, 0.12100027814026802, 0.14200021903361046, 0.09389722885023202, 0.09613217545613166, 0.2039589588680575, 0.09532655739495832, 0.14842913696362128, 0.28033893615488087, 0.12663132315801998, 0.14007640371639885, 0.15489855030130956, 0.11608355648575291, 0.174460590126053, 0.2500790913379, 0.14655776802570591, 0.11339916141643641, 0.13553826739230465, 0.12754288351824208, 0.13375934994509145, 0.13431586685680574, 0.09272174353921607, 0.22590734725517614, 0.12313570992480363, 0.10496617279826634, 0.14929711458183106, 0.14433991284139697, 0.11900533155928697, 0.1659646137587486, 0.12845426001736235, 0.14368608744154054, 0.15596678330292627, 0.14966528111648175, 0.14671038806198106, 0.17323229071353713, 0.14214353876248484, 0.1341646411005528, 0.1404155508404778, 0.06412964148987686, 0.20041138955181648, 0.29566017370070186, 0.18448572395549667, 0.16797945564312322, 0.11547121474699629, 0.19598686406689306, 0.12223335794143139, 0.11889250979067818, 0.12470448179350746, 0.1699371473683465, 0.1219028676108968, 0.1959936516059022, 0.10614944922347223, 0.196539519895469, 0.1374565975199784, 0.1317060044816425, 0.25322262588287553, 0.1468165831700448, 0.18592160255197557, 0.25857578782785323, 0.10639154066842411, 0.1924105664534915, 0.17201539068933458, 0.1124773431389082, 0.2037460477121415, 0.18866644961939705, 0.12372735962872544, 0.13854482541641883, 0.1464005208183681, 0.11363689382109912, 0.10794993970663318, 0.08740664084231661, 0.1697788429596732, 0.06221439869653794, 0.123654903032847, 0.2548244391237536, 0.13067474288325157, 0.1574277436180461], [0.047925230971868, 0.031597328995684945, 0.07315000504135125, 0.07843918332289304, 0.08110768972865998, 0.040828284371884606, 0.057828395942886995, 0.022218348195536003, 0.03672593333307774, 0.03192208132766668, 0.02985281847237099, 0.044713346062288176, 0.03307428331144395, 0.04767884560410054, 0.06729389871320418, 0.05561458570281825, 0.009417913388460875, 0.023451504605491797, 0.022447889205068353, 0.06013520925696339, 0.0010126808539949238, 0.04833498075904866, 0.04894606228316984, 0.05781589721840236, 0.11644785427638601, 0.12000785719963813, 0.03316242938801166, 0.03269852867590324, 0.05921416855867832, 0.031058196534192374, 0.09665076335471484, 0.0090357216991364, 0.01450936629196569, 0.035926872984536236, 0.012939889622371525, 0.024525425809946273, 0.03988493136280487, 0.03128319081189412, 0.07329347032693125, 0.02996087708931056, 0.027582762056901574, 0.05839219835076121, 0.011084304968526047, 0.029817145588176868, 0.05744747021385739, 0.06059072513674056, 0.028053879317256714, 0.0640017009760824, 0.03988238412045664, 0.04351862428349353, 0.036918991320436044, 0.08501736582407067, 0.03144902969530273, 0.021363198719618302, 0.02281900326300773, 0.039221319189715775, 0.03268208459860856, 0.021724524089105187, 0.00559367620641546, 0.029461663554332433, 0.06609562994732011, 0.05109485081066528, 0.028278749105670763, 0.023549774533978874, 0.04694708224926745, 0.02529575211566783, 0.029550096913871747, 0.0441647275170732, 0.05241306213241431, 0.02285595742925521, 0.041797205565437194, 0.026651394493397207, 0.04329161327933112, 0.04506772684474145, 0.014173205953181512, 0.011274065904980226, 0.028283238380907044, 0.02140866795314416, 0.062144585103998264, 0.06027436529796931, 0.021949729040986108, 0.018663263556757764, 0.06526918961636483, 0.03931835571664476, 0.044397602924295974, 0.02751147182988784, 0.057034027882881706, 0.013736739807251482, 0.020605260055632364, 0.026275906073410186, 0.04084894576320245, 0.0473998746864738, 0.03019067090785792, 0.059069056184061115, 0.022322710438240922, 0.030560850338529677, 0.04941582356789901, 0.03617371417461865, 0.010843562795930814, 0.018249399877423723, 0.04251892167714335, 0.026342988562499805, 0.09147617650488693, 0.03179214515482947, 0.03447165449840888, 0.028302359935497085, 0.02082258770843187, 0.09079523159251099, 0.022993525753038067, 0.02569403931228144, 0.025055685058055867, 0.07485468090782244, 0.06980251490829453, 0.09789474458704073, 0.046362583976118796, 0.015945557069273728, 0.02506770880802745, 0.02049299370076868, 0.043252144429472186, 0.0845130424826376, 0.01951108731689953, 0.015226943613660913, 0.03859275170872289, 0.019674505362467423, 0.055831403907148115, 0.06340362379447588, 0.0566823284081634, 0.023755394448075565, 0.01707275585842229, 0.049588162707345146, 0.043822719054597045, 0.06191735193433781, 0.07030489238639993, 0.04448393720292276, 0.07521134080185045, 0.13683143913024856, 0.035100708445233685, 0.05418877350166441, 0.03880193584688729, 0.019178237435558153, 0.07843144583485781, 0.13303553475247276, 0.10870909453519892, 0.022225120412786643, 0.043580478222499934, 0.09966529635412079, 0.04095868019747638, 0.013967333230069809, 0.045531321121680166, 0.034535090408978925, 0.0553770792940932, 0.008169586522384517, 0.0453420284564697, 0.01962167976964866, 0.03498639663561218, 0.022688498269886743, 0.022529535025598544, 0.027423659001567194, 0.07849251836418145, 0.01916640520756764, 0.055719179687120264, 0.04297084843499526, 0.015507373928783402, 0.008522214878711009, 0.05402464299432693, 0.07535698177713542, 0.022571085719391707, 0.01286182430527744, 0.004506858390560675, 0.01633069628188687, 0.03797584791637717, 0.053357391903597506, 0.019783205578043576, 0.07582565138657248, 0.056139451691940914, 0.017138264036827514, 0.06387024411871549, 0.02465070416820386, 0.031053498499996723, 0.09492332701601329, 0.0857712729503551, 0.023555169708185622, 0.02354966919688929, 0.026576109117858356, 0.042791411490930666, 0.023771279281185522, 0.012966605023510996, 0.04341062886880771, 0.018392587456131176, 0.05206654907294339, 0.05193462490194267, 0.024348356077567707, 0.08612121425328717, 0.052800461304404085, 0.03766099344037714, 0.039673858817907116, 0.03443948646646834, 0.04673647701800351, 0.04605699533356294, 0.04493883255148127, 0.022449515226687637, 0.1481577120120487, 0.04034784765193059, 0.1046052304727416, 0.04353193123073828, 0.048991767088732416, 0.03835029637200698, 0.04234544106669003, 0.02954957597408324, 0.04208247372580152, 0.02078320312824461, 0.059343246713040344, 0.08571937815436433, 0.022696454092980396, 0.010376010717253291, 0.028992333194060676, 0.011284266365692021, 0.043632920771356554, 0.04158259752476889, 0.022937578351927862, 0.03548980067153612, 0.07494107264304355, 0.037054998740073175, 0.04744436141223677, 0.030806906288489703, 0.019751200339786952, 0.058016907198414694, 0.003658306607488363, 0.014229037483493167, 0.07644910906111041, 0.022513473992266005, 0.015353009127260698, 0.029457854182128946, 0.016396863295906977, 0.06600680971337904, 0.010516764051581343, 0.013408787142966064, 0.06648940680127952, 0.01969217326522114, 0.05391862408648576, 0.0831749013835384, 0.01137665561175034, 0.027956735538018328, 0.026197020084627216, 0.030850858667925484, 0.003975681752161754, 0.061789273524716984, 0.02134601536747669, 0.06554347207589496, 0.058363776488770405, 0.020343734875261303, 0.028626124014056502, 0.05897529851344805, 0.044919814418761, 0.05676232713965639, 0.042189454073987664, 0.04514060861941788, 0.00895861494955757, 0.04538705910465891, 0.02729947423382152, 0.045346931419185096, 0.030176557653072863, 0.060674286177081455, 0.012053003038970694, 0.028761947572591807, 0.029833890354981827, 0.0458965918439771, 0.045839146740974925, 0.02216573519211623, 0.05501518701954235, 0.03195611478370284, 0.05928937157976532, 0.06253915868939892, 0.036862070987662005, 0.01781872439859135, 0.007429951135324495, 0.11741342383526987, 0.10156712494790555, 0.07471791889157987, 0.04796932316234997, 0.04919743488332437, 0.06662181743811216, 0.010304864131725364, 0.15574729911261992, 0.010504809249522946, 0.0925526372908104, 0.04611161357212452, 0.0698605690511965, 0.068399524466405, 0.014464634418066953, 0.05004868114126786, 0.038312964907456795, 0.05314923049281201, 0.024520425171020533, 0.04420311618295889, 0.023699096561740005, 0.0255108542830473, 0.025628203631288586, 0.04857554768903121, 0.0038496547823606603, 0.007755724279465335, 0.0233315218300108, 0.026658252895539327, 0.03340139902467209, 0.03578706193835505, 0.05036510609751267, 0.04380638606005138, 0.03290824907561464, 0.0699549587443471, 0.016674886179727413, 0.051118860006212234, 0.02779044849317401, 0.031648564956060825, 0.015148354483948601, 0.06656451406137598, 0.043686428182427926, 0.03642162788779505, 0.07763417047117988, 0.07595189501561465, 0.023072105306651325, 0.08434074164758767, 0.0517431642079065, 0.05971373832454124, 0.005157059236925336, 0.06806276753664979, 0.0703174332457204, 0.01713596194261505, 0.048549684560707504, 0.04742364639476423, 0.024420647964542432, 0.013324216781784932, 0.04264361397813886, 0.02661270130756161, 0.034313284972262, 0.03764102152819115, 0.046331814054640076, 0.019366850197735815, 0.03188211069021735, 0.058136639080100486, 0.03194155336748208, 0.06340434008668508, 0.04552803077404538, 0.042657223530113704, 0.02752078554382728, 0.033184894916391185, 0.022402645967480157, 0.016888266564497066, 0.1348561427045253, 0.0491683388639602, 0.018394962328696446, 0.05569851829580242, 0.00926338387803445, 0.16634077825132879, 0.13096305241267528, 0.32871554996217456, 0.22673698983365492, 0.16686787738675074, 0.12473481887530898, 0.18777415637047062, 0.10634919132796988, 0.17525661676641435, 0.05220611497098881, 0.10842194179854087, 0.2169632554174431, 0.2023419924080372, 0.14138621488405814, 0.2347810202909093, 0.08288209491799917, 0.20583967407864912, 0.11298242490738632, 0.16306547658337703, 0.14551003553694294, 0.17985864482339353, 0.21219809659786765, 0.14695388144783436, 0.154360955761325, 0.2097326877617067, 0.21954107999561295, 0.11932235406411272, 0.20350171162957148, 0.14056786444158326, 0.1433301017048859, 0.25388444924066145, 0.053495406473596255, 0.11530640625184584, 0.10867161751394311, 0.07136420046369876, 0.10413060836013287, 0.19426636848478548, 0.11988344452073497, 0.15164045496813713, 0.16246055823660668, 0.11823252504391056, 0.14030204725361642, 0.06472080089752713, 0.10851721249280438, 0.15712628801984174, 0.23969873785972598, 0.10369664253366571, 0.18571996821030495, 0.09380037235396524, 0.11986492051472587, 0.12654441814388961, 0.17997997782884106, 0.09290778033074834, 0.1817349014022658, 0.07954453328444112, 0.11706191205209303, 0.12880224013520827, 0.09259694015547153, 0.1368149069528426, 0.06732291046289668, 0.19909495938449137, 0.13945887556239484, 0.139016842830085, 0.12563809016419034, 0.13835535655098577, 0.13712907961059, 0.1578515894230335, 0.10223444115610854, 0.1986718183803943, 0.09200795643752621, 0.19140613325420888, 0.09482846234834964, 0.20277994955258988, 0.20625379056699816, 0.13831810935610725, 0.061560833766575784, 0.20254233972199503, 0.1635541027832416, 0.10632239357237855, 0.1207647980341027, 0.28107955931655826, 0.09956938980688011, 0.1630158800511591, 0.1291123678487155, 0.09918570999176272, 0.11262344376694773, 0.15346501593387898, 0.12665739313008326, 0.1569881164018185, 0.09548250225282486, 0.14294941729355243, 0.12269941519104666, 0.09562965242132064, 0.1753266372026936, 0.11529463148044965, 0.23586748618512388, 0.12130694313635751, 0.15830260070581592, 0.1095378790952025, 0.11870413643097687, 0.22556675988579952, 0.11428202412301496, 0.12671235993865038, 0.17486356769598302, 0.09327500457725219, 0.0963050508571248, 0.11303149283893647, 0.22105007402358517, 0.1309682464888019, 0.21447748396425478, 0.10272166541507168, 0.1852523941065996, 0.22062232117018393, 0.13455266463420085, 0.14583182310865772, 0.10849717163270521, 0.11157748094128986, 0.09686068676772619, 0.1338776952076343, 0.2136295625279027, 0.14780192545825435, 0.09532648844704514, 0.17562648401625697, 0.12899670389390763, 0.13139763877036112, 0.13241970731366065, 0.12095204524455533, 0.2080515078118732, 0.15508314684754418, 0.17234154496221774, 0.15265838663664558, 0.11521032350438258, 0.19317219574605266, 0.11980770140766137, 0.12524272750822768, 0.19300460635173708, 0.10646051156424707, 0.13796016243436646, 0.13453959517421263, 0.08649435269856647, 0.17990654064041955, 0.23685259864695613, 0.17100682061526085, 0.11482269833645514, 0.1634065389272667, 0.16406859211142988, 0.14000480513899557, 0.0773877123250596, 0.23736144956802172, 0.11759428953331326, 0.09940864157772834, 0.15997991957251104, 0.11110313462033389, 0.14245786463781712, 0.1405605712845441, 0.1521742497120173, 0.09198347226746621, 0.06994339847756971, 0.17673446165938533, 0.12479011510168353, 0.15448565955363935, 0.1182193406707337, 0.09190461883742003, 0.08828742745062036, 0.16320069110201252, 0.13212582066414819, 0.20765188570705154, 0.10748836407137495, 0.1183951118840806, 0.09639073013057632, 0.11589785677290733, 0.2936141367160505, 0.17854495725083738, 0.14294688920340232, 0.13616898758036478, 0.09449369724719756], [0.022819750198733904, 0.047808647711551, 0.035811465669183, 0.018758545742340146, 0.06471319364443903, 0.05430985369809693, 0.05504845821809384, 0.05611073488609926, 0.017898177292438287, 0.03111776178552499, 0.06575090570315238, 0.026449944012828415, 0.048597595699492006, 0.044629608821724696, 0.06612139348421367, 0.052022590947848175, 0.056061015779813456, 0.07746319496823896, 0.027877324779007225, 0.021426194129631888, 0.024444902308225155, 0.018755799317131602, 0.054705338928127484, 0.03128033330393655, 0.0104541516855299, 0.1210565779418234, 0.054154357001666105, 0.03186124245515995, 0.05268714157864452, 0.017141902954467846, 0.028658238419842337, 0.06556208035157574, 0.041049457786063996, 0.03843437452169676, 0.052768082598284374, 0.12444088626052104, 0.05601964320146269, 0.020747051439097813, 0.055020342791272756, 0.0202468917855332, 0.03475647832777712, 0.04584828616991159, 0.0736527119372641, 0.02328030310661322, 0.059864186501551064, 0.07949575646630219, 0.08825538199274771, 0.04409640396554624, 0.0329536474460075, 0.026282084572519508, 0.04855615800366767, 0.03246388743601499, 0.05028657059395506, 0.05402663482293006, 0.019429075689385497, 0.03392395908914266, 0.07122767593471274, 0.0330236257474509, 0.006885624118900348, 0.074706343303044, 0.030154521133930936, 0.03777770693564127, 0.006307683079578584, 0.03213185152309316, 0.03008013208126349, 0.03605474455041751, 0.036210884760704734, 0.01682931801394349, 0.09441043881158676, 0.08555140571608659, 0.04161210340117255, 0.044526841957122094, 0.07937210987532332, 0.014112074052043741, 0.03173761118593956, 0.05517992656677962, 0.032542721713863076, 0.03058741060686448, 0.020527103765597268, 0.03999425594003932, 0.026713826828786445, 0.05470427406591274, 0.018653923029740973, 0.05696404958143831, 0.021526840845904043, 0.012546783095345864, 0.06850866135209799, 0.01640804243394204, 0.0068190118162742555, 0.03688350229734375, 0.017458563482749368, 0.038601810698427504, 0.03359585129205258, 0.029484232504581733, 0.0488588048685943, 0.06252279505133629, 0.0017418725474271925, 0.07754564135065002, 0.03244810985521444, 0.034743849368345354, 0.04761850468874459, 0.056357315606287414, 0.05165616726322521, 0.08426696738047947, 0.011737075082266764, 0.08266084106458772, 0.00958485256565074, 0.04374155969989877, 0.012733579271533077, 0.03836269167462184, 0.031032212747020588, 0.07400377938944487, 0.02428642552976887, 0.040179017195177656, 0.03081952567182241, 0.06394984831492748, 0.03667709905834448, 0.033416548413374735, 0.061956414757596875, 0.018408774893971223, 0.054421974496255, 0.017143356606304165, 0.018080192122368083, 0.09326964196178222, 0.0312677962750557, 0.014004625432613878, 0.0075843963760792495, 0.04637469582620167, 0.0466039821114992, 0.023101626504813472, 0.040130497016493356, 0.01632509426394057, 0.04726656389633014, 0.049259710170689135, 0.05984797608107329, 0.05949768620813566, 0.04994369262168485, 0.04327380556553122, 0.09374110013126366, 0.013419408952036213, 0.020947013793873693, 0.08280937785222646, 0.022598291416802717, 0.017193560263202075, 0.023985875830534967, 0.0450198769929909, 0.04578606450870153, 0.04193779802130115, 0.06631539759015845, 0.013250351541735714, 0.03517884175263105, 0.0272745936132607, 0.059277953039253914, 0.02953792569197474, 0.038748053052733024, 0.11406122992235808, 0.020535042351712624, 0.027697127492677782, 0.008083122966420508, 0.038588377346675244, 0.05141014195678215, 0.028823809172477455, 0.011465297730249024, 0.0120509997190487, 0.07248404480877423, 0.039199914693111376, 0.058996289322573336, 0.07614803650686819, 0.025661066888020407, 0.038096100737851475, 0.057095720943424015, 0.039559803647740234, 0.05545787475702744, 0.028041838330306837, 0.013410938892423386, 0.05236530421121467, 0.01613662705846852, 0.034844241360382694, 0.033771867653535265, 0.006943900906105316, 0.022617648543429472, 0.06652208811212933, 0.053227624270103635, 0.039722072561421705, 0.032768116272505254, 0.03097187949254388, 0.0017599451600671598, 0.0532162363731092, 0.07223037777528649, 0.026548932148744504, 0.04085458033988553, 0.05422227069615357, 0.031761430774725256, 0.039719502336435744, 0.04419508758151243, 0.03380929870951561, 0.0743301405060676, 0.024584598441217697, 0.05161991598264826, 0.02816478395083499, 0.0036222918565580325, 0.05476135144671125, 0.05914792110542617, 0.03732542777734418, 0.013935751255391347, 0.02098775626490674, 0.02066780347377062, 0.05558848891767764, 0.03595169423328292, 0.05590684058505201, 0.021829070192911935, 0.07864644841080712, 0.06610797928465952, 0.055657743266032594, 0.05748396664257011, 0.020395143205420147, 0.05956317140390316, 0.053313280560917435, 0.026377728734646114, 0.026473972360573472, 0.07114984906248509, 0.039638875412844846, 0.029244605947526234, 0.003156284402657841, 0.01957294508634556, 0.010828524489977188, 0.015001900497853998, 0.019318391306085453, 0.069954797865883, 0.032168223462518186, 0.01389538608266101, 0.025585429112036383, 0.05267918192511124, 0.027432474758355852, 0.03094353040890588, 0.012294543858226991, 0.013281566751820427, 0.06945300261460005, 0.011676337716409997, 0.043991277550136855, 0.022922802431088303, 0.06078511611708711, 0.019947393541975368, 0.026985516080692894, 0.07222202741691182, 0.023261897844232382, 0.04553079252101241, 0.0258710362663072, 0.04273368676583614, 0.054204558743344206, 0.03106602595277852, 0.06490618651432377, 0.04394582938402892, 0.03553380476190679, 0.08352152552575835, 0.032281458918606086, 0.07738939771849303, 0.04057670875843014, 0.012014111627884691, 0.04039369801419877, 0.03913169839389382, 0.02142603708160741, 0.031254406973359086, 0.04037252717441128, 0.024126755569370526, 0.02718311888466199, 0.06298340541580993, 0.05401774820300841, 0.02808454581686566, 0.01587341935749376, 0.04076598610188212, 0.08714974857866765, 0.032547670641853925, 0.04054277106338451, 0.020775705042685715, 0.04678308580731673, 0.043941125604173834, 0.015159043325712124, 0.03448694561337752, 0.06628247879205212, 0.025032983957639626, 0.037575406097476526, 0.032866612196929997, 0.03778901056296403, 0.01224312499435919, 0.019129198232305147, 0.04145893944247116, 0.03588694065148312, 0.017887113067591866, 0.024947509612707842, 0.05302351163399797, 0.011261455140136665, 0.08418219975165783, 0.027611317984279127, 0.02974612732237626, 0.029980033117857192, 0.012736830357161742, 0.02119111430440699, 0.01940076491014371, 0.08438707464524815, 0.02959506627502701, 0.014788500003276334, 0.014656048189217766, 0.036667162897966565, 0.06298793299544243, 0.01792031340301037, 0.051410888892508326, 0.04454035957854602, 0.005051580421070779, 0.046198196829326695, 0.060716447825994224, 0.04138226170212992, 0.053305087250567255, 0.012540568207060138, 0.0371370084523674, 0.02306488301274517, 0.07199004067168122, 0.09631889406591655, 0.04501761703361427, 0.06802673076069163, 0.027750786206114198, 0.028920692481821584, 0.051722024011635975, 0.05163461337947557, 0.04100043965022891, 0.06298102288236541, 0.031927578008523395, 0.04270154554697295, 0.023267266205361774, 0.03413365650621634, 0.033178509573542306, 0.06897481819314343, 0.032526679832728646, 0.005024865019931308, 0.01872979637776171, 0.02172225838406913, 0.04512304605375375, 0.011745432143910758, 0.05288626698236312, 0.07276163676813727, 0.03180884012591935, 0.04155555845148141, 0.01744690745498144, 0.03307591124828304, 0.029947694631353505, 0.04425246373660142, 0.029473080179624023, 0.03394012737478461, 0.04784618218940112, 0.0726082276613001, 0.03812553000546271, 0.047963470250608466, 0.18139914038681215, 0.10047816926793707, 0.10043583524924132, 0.06184979064029552, 0.11180677871790626, 0.16090118626673378, 0.2257387159812835, 0.1521183406153033, 0.11199109947248814, 0.18620220523688102, 0.18352900271213826, 0.13921728207459375, 0.12239771444470653, 0.13997451402246952, 0.13044185215427032, 0.20945478170629472, 0.17379712734010913, 0.10890711294186693, 0.10590508249738526, 0.1268232741483277, 0.13770707762770115, 0.14677815619976292, 0.23083795042287922, 0.14975123618158603, 0.06719728736507316, 0.1803554681640479, 0.17719661186058677, 0.13618502946149919, 0.07909483967288848, 0.08365404341490039, 0.06272272867781502, 0.12105522962707667, 0.1363474094579297, 0.18003688283985664, 0.1177138145712595, 0.24621972423647684, 0.12620380779187526, 0.15577132362992535, 0.17732228092368574, 0.10394316196681992, 0.11152520310133697, 0.16686478239153663, 0.11336346938004417, 0.12736866746338146, 0.17055003302952937, 0.16035746302335493, 0.17714221961796286, 0.16043891349146444, 0.23450884457317092, 0.09954478306275222, 0.1437334316752611, 0.18426217949919163, 0.12700584056156297, 0.2300158001842999, 0.12290029110567224, 0.1457391264698198, 0.08808420730694648, 0.18282386474311355, 0.08558399509638549, 0.2402554539543006, 0.1268767700680802, 0.16196200353724344, 0.08050388987025908, 0.17401445116246902, 0.12102777303587045, 0.11821168745237014, 0.06645914632827044, 0.09595796706215029, 0.2594962884341517, 0.2356793043474036, 0.19169884012831798, 0.16221229978386434, 0.1282225567246637, 0.17382081477872788, 0.07152695584321214, 0.13759207250850816, 0.307677396603169, 0.11333811953062974, 0.17633859338539262, 0.14865908591497332, 0.15629489876089558, 0.14521890680395788, 0.07690271738195613, 0.12000519121366164, 0.11167376287161343, 0.11791862817781588, 0.10711600703577842, 0.08723596411366617, 0.07585100889686616, 0.16849987449184542, 0.14817343213625495, 0.21103661537410753, 0.13518575969482624, 0.08500950576196756, 0.16571018063733656, 0.22021675422306985, 0.15924320345924747, 0.1192739373072982, 0.10734038652792093, 0.13184393095152994, 0.14629152182850147, 0.15112598096170735, 0.1559599344768832, 0.14759892748007852, 0.09603887360783354, 0.15722538915372666, 0.056553135340612744, 0.12116230573625335, 0.13030832302906822, 0.08048915799947516, 0.07380988253580947, 0.17757786317698418, 0.11690582163752088, 0.07068733113907999, 0.13484169428627338, 0.1693677448577458, 0.20263002614580816, 0.1613618349356036, 0.14375030093135374, 0.20706795816940649, 0.10764486051254696, 0.08100629799188146, 0.12105139152657603, 0.18575681703946284, 0.12612808000056014, 0.08217723274062719, 0.07643417800746619, 0.20060113420890224, 0.1608516510215498, 0.11035462841391565, 0.24162281364683183, 0.09958926978851519, 0.10989388781449488, 0.17054920565457116, 0.1106364491786207, 0.20247270232967793, 0.1056766350783648, 0.15508029700046586, 0.17311628968004258, 0.15876905632115182, 0.1351752336467466, 0.16454290778886888, 0.06155125766752228, 0.12560856513558857, 0.16126812706070562, 0.09629132256152169, 0.1367830989822265, 0.12378599599844987, 0.138549437265723, 0.13300820073533443, 0.15864282035298888, 0.13544776176493015, 0.16147506273081227, 0.12796601686145992, 0.09825008680983897, 0.1277629192918539, 0.06938090608004602, 0.1291817754146553, 0.11987396801311163, 0.13675587221739754, 0.16841966508617326, 0.12833317216005058, 0.19739761497945557, 0.16852040564821613, 0.17337605477340762, 0.1261773471149706, 0.11433096948049723, 0.15947854566958644, 0.11543177654065433, 0.08343152551641388, 0.07854527883952664, 0.13045391037819848, 0.13877264464334135, 0.1829212958053235, 0.10813046832598987, 0.17575584562315097], [0.07668738538819937, 0.019790548530797807, 0.036734000238920414, 0.0394737298390077, 0.01641732933480413, 0.038272592073847214, 0.04387544888642527, 0.08455992706360356, 0.03690858784642431, 0.052334890520620736, 0.019918425842338515, 0.09093581638749569, 0.06792408263971729, 0.013435098432725476, 0.05047814620117988, 0.029689986484065175, 0.007418960646440786, 0.10488925757066858, 0.02069276836400311, 0.013043769229684147, 0.09796768381831147, 0.07273719856335271, 0.037395988305610035, 0.05185852938842389, 0.01255587943183679, 0.09263825527722798, 0.03665439221226881, 0.004966708891574414, 0.05156802501709712, 0.08024751854639861, 0.008868391817105154, 0.04547001493553962, 0.02998592816443453, 0.05963701461892455, 0.04155652755270562, 0.020805320086618586, 0.06690468774327347, 0.06862820937268196, 0.020748606597584103, 0.0629105236411335, 0.010720886263786065, 0.04849668659810578, 0.02552598643477165, 0.04852975095291773, 0.03278851719392884, 0.016424911690034693, 0.05607311613857747, 0.012782922994735981, 0.022310487505409028, 0.020925772090953206, 0.0347627027921619, 0.04225010908539257, 0.03626281403065209, 0.028669812093158404, 0.051991958922195824, 0.017016155367356636, 0.008874778117563938, 0.03579546209244478, 0.01765314981551661, 0.046031005800731724, 0.005206514042877262, 0.013370612981699169, 0.02103697549882195, 0.07259613879385494, 0.05289470927128869, 0.03575884308966418, 0.019075767430026206, 0.004811133671131346, 0.021461334582718632, 0.01127542858387554, 0.08624468464404346, 0.0794838208164419, 0.025766386740630674, 0.0747927503600236, 0.03248845970618629, 0.04859864140950865, 0.027407132569820653, 0.04445274593308569, 0.017152813961729407, 0.02440937689595646, 0.01696995068942347, 0.03385390417890684, 0.02215146871974632, 0.060489957761620326, 0.02382560449111606, 0.021524398940645402, 0.054492420111332214, 0.05825203873457448, 0.03386694682581771, 0.020191072704150312, 0.051006375316290126, 0.07309708368754195, 0.09910126411986929, 0.01799006762373592, 0.08072565700257979, 0.03988686190437406, 0.04233557002378568, 0.031796960017433575, 0.01740089046858972, 0.027539537460993857, 0.014575091847819428, 0.07733010251315371, 0.08470627283977886, 0.02854917622772196, 0.01610830478790787, 0.0446756775190513, 0.07036150628400427, 0.10112234195994754, 0.07838467616708049, 0.037012729838851004, 0.036821020166239435, 0.02533073935116972, 0.01570801235615246, 0.023480066278528784, 0.024224667351753004, 0.035803624759277994, 0.05931697372767714, 0.10390142549670513, 0.03708393771141287, 0.04413198108874983, 0.08740151571410318, 0.0848207876627003, 0.04779877283820703, 0.03202382163445075, 0.025239203335537065, 0.00038635959666158496, 0.019842087095903776, 0.047744625743718884, 0.05036134460580446, 0.03296855168657438, 0.05638158910216824, 0.0843307748436928, 0.02895476041181434, 0.03624924278307346, 0.030318590354234464, 0.07125078880738828, 0.05127372084966591, 0.04506478889755184, 0.03158458703828435, 0.010320494240600496, 0.057060871603748495, 0.030847143141492724, 0.07440574572331483, 0.07342063326148257, 0.018310878433347232, 0.05526732953806078, 0.02227206053512712, 0.03260954373305844, 0.08106840473990287, 0.030819751667760076, 0.02799999843832226, 0.022657314660928907, 0.04358403670090822, 0.03561731983697222, 0.008520764099704403, 0.0758164200270849, 0.13230834877298725, 0.02610129548326856, 0.03992656441104989, 0.05627314552604672, 0.058252804822498755, 0.1037091680712277, 0.07178781644230889, 0.023167240020308285, 0.03696462717808543, 0.042654063417426044, 0.13411631627428916, 0.039543918814630284, 0.039624013307113806, 0.015320500186193856, 0.033207188074987744, 0.04516970463878205, 0.033806081140233625, 0.04670546960926825, 0.05296290641830814, 0.06237897736531112, 0.04391536972815952, 0.0274933519352588, 0.007267690840132175, 0.04291364464968924, 0.05194154267589893, 0.029212786485591245, 0.035542756499302004, 0.01820531343260119, 0.016759529319261352, 0.036354284928811174, 0.007048406311491084, 0.12657016635902468, 0.040210878791948484, 0.03883361741299591, 0.026843341653265303, 0.026737527673943873, 0.0436801960571639, 0.01966729455988013, 0.019517738875302098, 0.03454239888777656, 0.0810597479463585, 0.011066453204670501, 0.035469005214831525, 0.0527059298849875, 0.012176778907286785, 0.13169645902610597, 0.034469287286722855, 0.023785873256143064, 0.016471815423198765, 0.049941800384511875, 0.019734336829353726, 0.007939350288060885, 0.07303475477402249, 0.037985063954106266, 0.02613295981239888, 0.025906427613189145, 0.014048132523443672, 0.0135278822140648, 0.13404476366216136, 0.015612446718038091, 0.024685817808213256, 0.07687205088234718, 0.03597209132426689, 0.012772322253083751, 0.05996901414266998, 0.04648723031183885, 0.018844956629759362, 0.01234522344724786, 0.04869976118507405, 0.03390589090544851, 0.015072549126231143, 0.02699548096936797, 0.09213642938242805, 0.04554539032640957, 0.025368112950555743, 0.026541250202083783, 0.043777301532006076, 0.03522344339158266, 0.03436512614209806, 0.09533229539351118, 0.05162951889477911, 0.027030039195632263, 0.03567945722851061, 0.02487388664796468, 0.025853602020370386, 0.013572839126291295, 0.041825458888084664, 0.031194278647402124, 0.01737873520581953, 0.003519807965682459, 0.09834185648228853, 0.021228545360387336, 0.022996385176215443, 0.06024080681644621, 0.03022907681072191, 0.05567458953948752, 0.04998743241172164, 0.019689601125015367, 0.016998439584107652, 0.018455197906962807, 0.007104030998063184, 0.054180721917580214, 0.03992848729173984, 0.010506634454002545, 0.021070522489026192, 0.027815378909449906, 0.02898737277475096, 0.033539980499734806, 0.018135377265993628, 0.0037041612790011235, 0.05558325270671518, 0.0882391639113907, 0.07615391240124741, 0.01039279091562475, 0.012890456841447422, 0.03648024127488175, 0.06218200849909937, 0.016823526389235934, 0.08432731212627503, 0.08111007226210448, 0.013990289054720873, 0.08024142814740058, 0.015479068895201049, 0.03710404751942523, 0.07235116685830778, 0.04727261982137158, 0.05267620567352541, 0.02746112453150413, 0.029118509790409478, 0.07749361631971213, 0.04790855706819604, 0.042656028432951826, 0.05946753681787561, 0.018291766454856244, 0.028623885122097792, 0.06265435533057298, 0.08024632344923674, 0.05169264453973982, 0.02189969009299192, 0.1033456210467604, 0.05216767267894842, 0.029396883159455274, 0.02948820658568894, 0.14260921296813797, 0.028545309398924152, 0.04147925992466269, 0.04761579656793226, 0.02550803124904633, 0.07826436971945148, 0.03700833249416563, 0.04054031192114757, 0.10924435250701443, 0.01437483263397289, 0.006960829055207151, 0.029926904920308344, 0.07152482611878265, 0.014062698727713959, 0.057601553478067925, 0.05303089289114841, 0.03522035988768743, 0.05034727157063542, 0.06822796673664162, 0.05538685457600702, 0.009876533839551192, 0.10436659408432823, 0.00917610443843108, 0.018060047840399128, 0.041682169802727244, 0.04178085724913305, 0.0119898448352732, 0.056872678274709376, 0.012952268645617993, 0.03494914944073366, 0.015663727686079522, 0.01669203122747281, 0.06580926628122408, 0.12742853723466396, 0.03150234941483265, 0.058274971576587814, 0.021102163835518786, 0.03946822932771137, 0.06764458312142281, 0.0625866906146609, 0.0456293152585145, 0.03518183332597537, 0.03467079139344635, 0.05337878490888304, 0.06802188142413093, 0.06353626808812542, 0.027494179310217023, 0.0390611608482657, 0.026882157413168784, 0.04776105449925508, 0.039153539560615055, 0.01935659611086932, 0.01597207903321232, 0.20721212059499758, 0.14654402440834433, 0.12238356480074507, 0.07068624329422751, 0.13823071404570533, 0.09687680525765305, 0.18553819086763168, 0.1372384616444188, 0.1377063881485693, 0.18516311421990397, 0.07168618721827384, 0.17119635076772782, 0.16071737113018192, 0.10592479393967699, 0.1347871641478231, 0.11284337994912941, 0.2073289796469673, 0.1321881036123922, 0.10642784557515576, 0.14057946301275684, 0.26326577810029833, 0.10164600136058946, 0.11724968020233417, 0.10632587927243403, 0.07010436121134028, 0.22155258173663772, 0.1537450976789959, 0.10036578416944512, 0.18206991165155367, 0.2823183847771537, 0.10392545767488981, 0.10332248519144713, 0.17325050828437652, 0.09873185652278124, 0.09506771926798167, 0.11325522115634334, 0.1434919301180109, 0.08823598464650494, 0.17004332715465179, 0.2195984140158661, 0.15811818802068311, 0.16229417926121145, 0.10921412267752233, 0.11152666632927234, 0.1223876863537777, 0.1637305175104449, 0.15146364187521322, 0.06613082402656156, 0.10193797279029124, 0.10788356584887351, 0.15118987269459233, 0.14530090885537286, 0.17890805228342935, 0.12269014552716287, 0.10596394869348696, 0.23518569857603122, 0.19230414151905045, 0.15678524099771055, 0.17455921628542487, 0.159606252526564, 0.20353558803758315, 0.122681220602845, 0.10002630762755872, 0.20198186979659144, 0.13144207186996937, 0.1370316945136555, 0.06599698846618976, 0.16058902075934797, 0.16736932789846776, 0.14320965736143051, 0.1966437538184466, 0.10618885678629722, 0.08674320869988973, 0.1594124782469965, 0.11632612290521784, 0.08455668651168385, 0.1160136816061793, 0.11677941713001459, 0.1908069912103876, 0.14331499445101908, 0.13550439098429296, 0.11279982018975482, 0.11667116890631377, 0.1799014691383608, 0.08622793796201868, 0.14166292584230825, 0.09384948625079087, 0.06831482578549655, 0.24441757900339944, 0.08347118588825388, 0.10181326133709762, 0.22586999280798822, 0.16545236140729921, 0.05099283854266809, 0.1417727522071331, 0.11599171020451093, 0.13411970238291449, 0.11582129394575474, 0.16968561005928826, 0.13924735868650098, 0.13567521326964901, 0.13543875257094062, 0.10294167054516655, 0.17108221898876852, 0.07831951272824118, 0.13860283359404535, 0.20683416345667457, 0.12336256388094156, 0.09900778607134858, 0.1290131288190042, 0.19600282933923507, 0.13358615278717012, 0.13754246065453177, 0.11311751685195393, 0.08211485020095304, 0.16071635989412186, 0.2049935759315568, 0.26423524704671675, 0.10074918819290977, 0.18305741430770966, 0.18319285865272247, 0.2260044872039749, 0.13635401313583698, 0.22792968147945022, 0.13519018768302857, 0.1273139304811916, 0.1245325486806612, 0.10867677328567352, 0.20478428071064336, 0.1269937057288424, 0.17541751055227173, 0.24703254352413842, 0.09256807396248465, 0.12230736203491689, 0.11495405177195227, 0.16136808621306575, 0.19206418745940734, 0.11356689636745762, 0.1899514088947927, 0.09265088040622012, 0.11002128057542349, 0.15895749862876632, 0.1555289487324415, 0.1252144741855802, 0.24634130239006014, 0.1072665356520203, 0.1869232471912138, 0.13632948300050152, 0.16716272930704779, 0.170107510000948, 0.09265508622892442, 0.10998008802773492, 0.11093693950604047, 0.10517562889764387, 0.13757393154646122, 0.1908766286027047, 0.2754897834552873, 0.2286250748100781, 0.11363951384180015, 0.09364468796599297, 0.12495677752961075, 0.18577242991135967, 0.197176736509127, 0.14105901873159793, 0.16053410757693554, 0.10674872150224064, 0.22966108615359954, 0.11957757625608675, 0.21756872534751895, 0.07940839179941724, 0.17578906319554777, 0.13049075920735637, 0.13549677607032562, 0.14265614351437939, 0.15137083798406586, 0.16436673820980136], [0.024859650819111737, 0.07447441784484733, 0.05250706112072353, 0.022162952377731283, 0.039261113626942526, 0.0336293408256625, 0.06909048980883054, 0.05023938723869863, 0.02058469059486543, 0.011712476956628023, 0.008225271538380654, 0.11778719813352632, 0.038948679988783215, 0.02823153893733698, 0.04048585073061047, 0.03335618834582067, 0.02880322247473223, 0.05420852707879198, 0.010338165973793837, 0.06525327797017752, 0.06764160303939735, 0.011216605480219568, 0.052404187003811525, 0.10703615769143067, 0.08737998098255166, 0.024247100321395744, 0.006033890437515032, 0.02818543768127359, 0.04138309673796739, 0.02742488091180642, 0.03851313602119204, 0.032609804202952695, 0.049099134311320326, 0.020485662239333315, 0.059026025025354284, 0.06939248932946114, 0.033740634248862346, 0.026627387213070067, 0.0295734798325406, 0.032597872383532026, 0.050523621180365165, 0.052513833337974165, 0.011224713563288172, 0.06425139967412238, 0.00959886814422545, 0.03743572528624246, 0.05572924225200569, 0.03771912036163192, 0.039096285979593956, 0.05019446767325844, 0.04413119201818782, 0.06047964621815951, 0.04110483062123099, 0.023093188046327522, 0.006684053458288433, 0.005320564424994612, 0.02673484062054946, 0.022096287406560396, 0.06546385255792449, 0.05278128612365934, 0.07779470419571285, 0.07741146871159155, 0.040452066253149704, 0.14429733367456546, 0.017219563202571966, 0.017082534970775727, 0.019606999609799638, 0.029535579547706633, 0.018386688579114217, 0.05706068391220705, 0.0781068237378232, 0.035566003437364296, 0.03865301601528641, 0.02708039223967541, 0.031423335106322364, 0.019600899634702552, 0.07125683324111086, 0.059761185980131554, 0.01302363356620434, 0.00760226872854776, 0.022675018952859026, 0.08285355814281972, 0.06314738653600216, 0.11419356395039829, 0.032029793289820516, 0.04569630964749283, 0.05059344626422371, 0.03921106510284928, 0.058710006095709345, 0.039415997453033924, 0.033681304569566445, 0.02324698211234664, 0.03446272574365139, 0.03704013280390251, 0.09577029084246005, 0.016103265844585917, 0.019133066976322763, 0.01730427529001909, 0.007521163000004187, 0.05033019164036359, 0.03925652092983646, 0.09813644532715121, 0.03118739343218265, 0.03298284305680183, 0.039012353386609785, 0.04178683273494244, 0.12850972478308026, 0.04182979494573609, 0.07295264547029812, 0.01729539824619649, 0.02741488346439456, 0.03763922122156909, 0.04787860686079629, 0.04884358653197846, 0.04176696041418661, 0.02819978076243593, 0.01343324641516853, 0.057492374457539096, 0.062049429322923386, 0.04027990714436577, 0.008264145712488362, 0.02703159052367893, 0.03174746690708543, 0.04622489882392749, 0.052454193393068935, 0.04056039874652221, 0.007572383159816626, 0.01769582091289903, 0.046160482320814364, 0.010902564972639086, 0.09399733355929775, 0.018178525253108913, 0.037340297543954466, 0.04476435985716601, 0.036888631255996805, 0.012759741174147255, 0.038172050694664644, 0.07081083983423249, 0.027013106737285856, 0.023238472790727695, 0.02185563429168636, 0.024791051475932042, 0.03046941391432718, 0.06527712628726037, 0.030629748455999844, 0.047651392843333945, 0.03125935590134994, 0.01937847175154715, 0.05544737552202517, 0.058747073259925654, 0.015378839696847625, 0.04122857297320039, 0.04113269323903707, 0.03419083347844501, 0.07473736220309812, 0.047760399494079814, 0.04158093894441282, 0.023391481616624424, 0.033730659784088214, 0.03437867823747858, 0.03968079574406147, 0.02566577066787549, 0.01131821746727632, 0.056126569923494136, 0.021155313100485552, 0.009079185697520453, 0.040563210289204316, 0.048303230245026856, 0.021101202395173813, 0.03708027964157443, 0.0621853792859662, 0.04286906982381498, 0.015832783181160208, 0.02710901903018596, 0.01901680738815377, 0.05707636956245669, 0.02704759601563696, 0.08832957760821428, 0.05653715857695188, 0.020280885021953333, 0.011693241446459246, 0.0875216459615096, 0.055467646208501635, 0.010539166377707115, 0.04132362916284511, 0.03207903167593383, 0.014940748486908214, 0.06875409294039973, 0.006044030089997837, 0.014558899621929855, 0.1265936009886284, 0.0227664151574455, 0.06435061955163557, 0.029461638656474894, 0.029191567765308485, 0.012276482377802173, 0.01775588220616262, 0.09032518302481021, 0.07754610100340459, 0.06320378592898769, 0.05999170566698717, 0.06334146342029975, 0.09666998450073505, 0.011319661543013589, 0.05899556153904527, 0.04613256224641397, 0.029668114673826965, 0.05459807512740936, 0.12487788579516834, 0.01482193686834146, 0.13058580007524262, 0.025708815233120998, 0.01773200899122223, 0.032508845305851394, 0.03046233526190683, 0.05861393867000457, 0.04235538105750757, 0.05421180976554752, 0.060761616370009805, 0.03323446080509213, 0.020742225085174846, 0.054969685227279706, 0.11431483566881188, 0.07280118988766786, 0.06865457811903569, 0.02588849157966193, 0.04228582793486215, 0.030793482512836496, 0.016273488666141228, 0.02616251548451762, 0.02237304433008596, 0.049131972670194604, 0.01819355972862292, 0.048973266065361044, 0.07737987524559421, 0.026810168130924145, 0.07782498765135966, 0.045175595854919766, 0.027485470805737763, 0.06416597704012549, 0.04715902047351964, 0.04478798983919044, 0.014526262361135696, 0.04843000630517641, 0.03726862235775879, 0.03492194948898208, 0.04169200254123538, 0.011584377479589274, 0.03395603519053229, 0.024029757346837752, 0.04434967263331337, 0.039163441247036385, 0.0556844107866768, 0.048277531825606866, 0.031657359645431565, 0.01808891786382564, 0.026734942127199426, 0.0009223192272099456, 0.06207909607779115, 0.036498470337040005, 0.021576659543620005, 0.04550668756447492, 0.03761013669352378, 0.029585534226029154, 0.037503765385237434, 0.036096266515913515, 0.009581533489718793, 0.00827711749626624, 0.004184517799125564, 0.07495945109234703, 0.04616346240283982, 0.01572850520812696, 0.003790613822451222, 0.06554911814389691, 0.05445395100621447, 0.04283588672537477, 0.03856236100076668, 0.038450351285357634, 0.03447779469312199, 0.09177457541227342, 0.01264641666033816, 0.0647111481896812, 0.02441380871459842, 0.059476082528670954, 0.027832851459782933, 0.02226706755708062, 0.027146400290451227, 0.023491429277665676, 0.1170502215503685, 0.04593146799672996, 0.03384606326900182, 0.048694130438830585, 0.06842766287586383, 0.1009592724843852, 0.052230170131811214, 0.04594495497463692, 0.04229911956034842, 0.06501564515694495, 0.029203227623516036, 0.038960722890952905, 0.009169631953080817, 0.007573238305462105, 0.02868039559783234, 0.044411319728580215, 0.027457784388154268, 0.09206485378766253, 0.0447503442785913, 0.0479995223483251, 0.036181853858814124, 0.013507881573581649, 0.03790449831754931, 0.05053154635994185, 0.0616431460836001, 0.027938203871129986, 0.020775626518673474, 0.021718387724831704, 0.010418079478005248, 0.013019692043833917, 0.03935914223773345, 0.006169290253667222, 0.048002594360901464, 0.01208825457480646, 0.07021572741289293, 0.03545084510058646, 0.056599617725418466, 0.012639676044214398, 0.039725542939718694, 0.0026881192142384188, 0.0021668308557221488, 0.022089564985024835, 0.004793005158013154, 0.006878863392968572, 0.01319686328286245, 0.022229661398957816, 0.042171604225351926, 0.025598998444395202, 0.07635730874514388, 0.05262664361526409, 0.025757775912361763, 0.06430302250890002, 0.03117930545892206, 0.019519755601762764, 0.04361536203613205, 0.031670722134050824, 0.0233894553140647, 0.057543093308566086, 0.012501687329683094, 0.01427399056528004, 0.08285334363820092, 0.02294500365913395, 0.020046368271352786, 0.05244276336123867, 0.09734771184382901, 0.25244314674167867, 0.13367557056969212, 0.08610039198350522, 0.09952064363225814, 0.16956469074131983, 0.16080282057725614, 0.1525518850934121, 0.15554322861135006, 0.11397213389676426, 0.17321583514492359, 0.2007501383101748, 0.08462525904178621, 0.1458949947188939, 0.21350341849029067, 0.15847000623902968, 0.16887844450050787, 0.18728880902692197, 0.1472637793349643, 0.11915365384230692, 0.154935353165192, 0.17613197947221418, 0.2207030668374031, 0.27333943593886595, 0.19701303884146676, 0.10416388721956361, 0.09619093439992397, 0.14761031154663334, 0.0975789784664108, 0.11490106147022978, 0.15557843801235, 0.13755064247356308, 0.1546352152382174, 0.08713631905735501, 0.21505281599538945, 0.20596555764636687, 0.09287276245172947, 0.06675724646136647, 0.15827117577916192, 0.10003658852750257, 0.17774392039545123, 0.1637904868731576, 0.12149016072432842, 0.10318904799679596, 0.07390233402651164, 0.1496303015418591, 0.12842324111730824, 0.13890491738434763, 0.1320926950223023, 0.1786517039422066, 0.10412406596925952, 0.12143199932911705, 0.14824751283853285, 0.10443527386673998, 0.17323189234781652, 0.18340688829700794, 0.13750872214234647, 0.13133508003046437, 0.1753486852131544, 0.17556188748248164, 0.19231615377770317, 0.15838274882445413, 0.18307337958005168, 0.27810159169377824, 0.16685244837595573, 0.07886694383717353, 0.11172384970010289, 0.1461084574581154, 0.15384859615756621, 0.18725634222069096, 0.1774575260858382, 0.12325342699524858, 0.11308442185362501, 0.08469105833360265, 0.11665519597309253, 0.11534733066876089, 0.19729146583666726, 0.11152560912793684, 0.08645489150958677, 0.07292636099361605, 0.09554974178993896, 0.15262912207793805, 0.11914132748760524, 0.17389630508278647, 0.2027850210546486, 0.11584626075120703, 0.10871192906051876, 0.13560097934978624, 0.11132821125248749, 0.13596519287074768, 0.15482627756653294, 0.11412433258468106, 0.17078946614938398, 0.21499889872727856, 0.20132899434576113, 0.12928979381197883, 0.1215930846369555, 0.17470596808820002, 0.18126911994430328, 0.15196876960896677, 0.08945718242396271, 0.15675464344601478, 0.18106337937135852, 0.205218009049854, 0.13179346107907836, 0.12100471378934961, 0.16433502216973614, 0.1712057430056795, 0.18398942155463083, 0.16012043541958257, 0.1478462819490702, 0.1405125682152087, 0.2653951041640774, 0.07896312617606695, 0.15634348405705345, 0.1046728453929386, 0.1671739141907423, 0.2486070380696366, 0.1422795500125616, 0.1772846047195696, 0.11041432964585482, 0.09569841647340406, 0.12840928299532783, 0.10933544802209062, 0.12516369021707965, 0.17716834321618083, 0.07769767916010273, 0.15182397899127778, 0.18637733293637154, 0.14321854398135217, 0.18137447235565032, 0.1613510177741128, 0.10429402257526114, 0.13550077504929037, 0.09917984941914197, 0.15371388725696072, 0.15445477088853238, 0.15954213096730172, 0.14551270152291945, 0.08359115525719621, 0.15510602223296321, 0.12087263257032442, 0.09888132027680836, 0.19774384075595489, 0.15702741671233408, 0.141238896176219, 0.15507691089184056, 0.1188563964059276, 0.09826298773048386, 0.1727444765668723, 0.21237978200999, 0.08049191591600258, 0.12032768358626675, 0.0854556753690685, 0.10425607824037153, 0.13958845167390763, 0.08651423268020154, 0.11006031275516558, 0.11877489231166341, 0.12577920355984282, 0.13739917156917436, 0.14247252756068784, 0.17450761260284534, 0.14012187869558412, 0.10323049335349953, 0.12574836852089052, 0.12260931559027204, 0.09982899402178104, 0.11698571694714409, 0.21680265274499694, 0.13543686799464688, 0.09642145025633997, 0.10307276351076942, 0.1744969180154224, 0.11065623722970487, 0.1367631806961952], [0.05803120622952139, 0.023460642119208654, 0.0712616749167923, 0.04885405895390338, 0.009782250441100088, 0.022242060532012296, 0.08349678854668334, 0.015152429114095868, 0.06366821141132424, 0.03381149738185829, 0.009236882023903872, 0.027375541019043135, 0.01938901886704468, 0.041496060232842163, 0.061024648828371886, 0.0809967295537072, 0.10461085355810582, 0.044459123615055315, 0.04354134262088807, 0.007375929966538905, 0.0442940891239672, 0.0160156024034105, 0.03709164838637075, 0.06895537488162518, 0.041577997166783585, 0.021856273975103133, 0.030845321767452746, 0.013928820074896419, 0.03740493238212601, 0.062109352720360604, 0.060453595398294355, 0.02930359663291564, 0.07540052621475152, 0.06375648772283908, 0.021699275746340715, 0.03572503179912606, 0.01881678757678357, 0.10241919858080727, 0.05515191839226792, 0.07031474427710618, 0.052789387503458615, 0.015431265008725948, 0.03468012234436409, 0.03925632557741577, 0.08362089479041677, 0.05546129150916973, 0.14529646554541203, 0.03846069347233542, 0.025976013294571353, 0.06464433000092545, 0.022535403259098533, 0.08730554021894933, 0.05705195434030987, 0.041773177217692144, 0.021028954558254733, 0.03463798367808904, 0.045139972766440724, 0.06671917955240896, 0.053073866593260924, 0.05499096714981622, 0.03403937789581476, 0.014169437758203958, 0.04447804981722467, 0.07598848337487829, 0.024403627406084732, 0.02383808214818278, 0.08034844296954333, 0.03084175371294541, 0.033104072640379595, 0.004995079521435283, 0.08118449004306909, 0.02109630326289804, 0.05559917584422135, 0.05751664029254068, 0.07986252106005147, 0.056611381005495794, 0.0574793279801886, 0.027621600799442782, 0.047952905898132635, 0.02142852878258113, 0.030430297464913422, 0.04210369053086446, 0.015055670294039434, 0.03747433994806582, 0.007936379303329535, 0.04064207138012975, 0.045529968976493806, 0.035752461577254924, 0.04914716036329347, 0.04948764048036068, 0.047552670922971545, 0.03923632302171281, 0.006565581312433126, 0.04315363701372858, 0.03888264320971024, 0.0424465723335743, 0.03996597963475412, 0.026280971829809492, 0.020510372405330983, 0.05059449197424035, 0.04425822088735239, 0.013972986001341094, 0.055983108468353755, 0.09220376851097231, 0.07630776583908067, 0.01807663172873999, 0.01861184373528006, 0.00602193276262692, 0.07191602891731648, 0.03332082955767551, 0.027357591578977245, 0.04461943900452987, 0.05662613202847781, 0.021312407090238506, 0.05266592477358157, 0.02179663211497809, 0.055582873493192665, 0.016332734075765458, 0.029086642447979223, 0.03376723665203299, 0.08285175017531841, 0.06265128714843624, 0.0028353325849879655, 0.02881797158249444, 0.0553665915504098, 0.03779701618177276, 0.024944089030125932, 0.043741567360778014, 0.0846234510742849, 0.07638874899355635, 0.08445743216021408, 0.08277177825690278, 0.07085945577390733, 0.03100946185088927, 0.0539767433468613, 0.021171782075637774, 0.05787041586553378, 0.03575322000429996, 0.023614618131109787, 0.04680693029395996, 0.0503558402640685, 0.028816730520057104, 0.06681632716208696, 0.06635875816667272, 0.043348307616167495, 0.059074453273487676, 0.0183526091578026, 0.01444620138499886, 0.06313870292938044, 0.0030036219921443733, 0.02628325860226347, 0.05992284968435284, 0.008098566341364096, 0.0286135065459436, 0.06310840032153553, 0.04640598668746891, 0.02516871367040421, 0.05428480645341258, 0.035806034105799855, 0.03205264186216218, 0.008092855155888585, 0.03966466576281575, 0.0366541049292972, 0.013643110456365733, 0.05933449415850544, 0.01356467167140856, 0.0235257423557942, 0.054588349641210614, 0.05216285781634431, 0.03116777775088145, 0.03178407058810755, 0.06890096731724278, 0.05078088882709703, 0.01797944964510539, 0.011981543315003717, 0.08430551692482927, 0.03513413286137004, 0.026172265868573904, 0.06856528291058156, 0.06568145217193712, 0.038590085722746394, 0.01663655880087566, 0.053226934790971785, 0.032153732909430424, 0.02650264511635948, 0.010300778010259233, 0.026963376139681187, 0.012848774955097227, 0.022170136367241224, 0.028792707917971477, 0.028968590214067412, 0.0182971635442828, 0.042792713840401946, 0.04368449764085874, 0.020058418834401716, 0.09195864335784028, 0.025208527259829066, 0.048049927103303136, 0.060173314470317096, 0.07219949677105873, 0.04947588103072298, 0.059918766435716427, 0.012042688622680164, 0.018964744052819667, 0.018084238981828094, 0.09106058146684401, 0.004783765658841379, 0.039153662134682944, 0.032204597317163026, 0.04337414393141385, 0.03430831306163342, 0.06586136792095439, 0.04620630970044483, 0.007516849924990487, 0.04553880580070038, 0.007948979534464138, 0.05377216722756144, 0.034810188752148426, 0.051549382267459753, 0.04035217221826315, 0.04912340014632191, 0.027009774254815235, 0.05277629889127228, 0.025462971872559963, 0.042254897134919325, 0.08702765714617507, 0.07769127466505574, 0.009989646721571203, 0.0393427211430765, 0.01667888324347235, 0.05341070013180856, 0.044562089662518234, 0.028525348978057027, 0.10760222005868152, 0.06212903734957499, 0.0241079232129719, 0.041349408021497155, 0.015393513153427312, 0.04071437475842334, 0.014822308420984736, 0.03548019392896564, 0.011241014956706956, 0.06332064881139705, 0.043790367161554676, 0.04185542824768251, 0.050100579767698245, 0.02710008644498885, 0.005850739403432536, 0.040121346096237825, 0.012978775287798096, 0.03835077900739928, 0.09567472137390606, 0.0436854399290056, 0.05945888768521048, 0.06604659265928692, 0.011182075024642532, 0.06738965970373924, 0.0038596522297725203, 0.037361456892423095, 0.025969390464465947, 0.03396665699960243, 0.02973644397101335, 0.05042021463234579, 0.03451157917058276, 0.017527829322423187, 0.03858763041094907, 0.0496796987229778, 0.04171028905998796, 0.05161445377574814, 0.08712225368306523, 0.05037605349395064, 0.025018669604774446, 0.023650373369755767, 0.007509966624990827, 0.06827571699696203, 0.0601440882160058, 0.07689999010894569, 0.023831371217966083, 0.026324914633146217, 0.02726422078276594, 0.030965727806511908, 0.053524992789231965, 0.04530545541896455, 0.04767600724834108, 0.02080317312521079, 0.0494081626886562, 0.04739191503294053, 0.02070574397822061, 0.04887956202090268, 0.013595332425358075, 0.02593325792751726, 0.048738180494476716, 0.06908695048262035, 0.03766102025345449, 0.09785321496066549, 0.023989811607245958, 0.028400139567712625, 0.06732880933991364, 0.022500258975572163, 0.023655285908570214, 0.014791932077177111, 0.1014553297371153, 0.04083200755919661, 0.022457831111105702, 0.12090350591367292, 0.007120303663184807, 0.011752540482238177, 0.02114989302842127, 0.10519371623353613, 0.05639497648864504, 0.11542900330236844, 0.05610502370062375, 0.060925337020307786, 0.04038299576589658, 0.04027306597920195, 0.014284427555638456, 0.05430837897884269, 0.058915627925025846, 0.017371748483950095, 0.05052786530746568, 0.028867052920583277, 0.05494074625594001, 0.02029693647918682, 0.09406780598745232, 0.054168636880574696, 0.07046194807175668, 0.07310589369867118, 0.04408439936777277, 0.0900127647084094, 0.0605289861109228, 0.024396837951855797, 0.024466655374835097, 0.032818517197043665, 0.09297412354499103, 0.024574507148035114, 0.007440861663781107, 0.04696614634726317, 0.043637233846370256, 0.054599469407431545, 0.024585580948980588, 0.03445479290319547, 0.04454032893502905, 0.03826644421825486, 0.05798486174054204, 0.026387731927717407, 0.08139543235301971, 0.015411135090905574, 0.004423431415606531, 0.030075020359588728, 0.02045333907458811, 0.07510241842077625, 0.08591085417015899, 0.16414274942250023, 0.20064182879944004, 0.13132326695467197, 0.15277821810976153, 0.09222441458053167, 0.12535980872569547, 0.13921467737565119, 0.13076367036950204, 0.19215115376057165, 0.12106007896363737, 0.13529667390450356, 0.15556231952242314, 0.07038650373297353, 0.1315606469588895, 0.11127603300396474, 0.1681918765027677, 0.20419211006693302, 0.16500302019619173, 0.11408370694205647, 0.2331222101084648, 0.1848161989642728, 0.1418635642696773, 0.11694735126389612, 0.22320180049827024, 0.18488191398641757, 0.14243342643303258, 0.09640622808928452, 0.10205421897192156, 0.12243002037247344, 0.18423340523675566, 0.12421843730994772, 0.13210528950777747, 0.1523823958010443, 0.09055608192518835, 0.13120852230537322, 0.15610875471705393, 0.13586075976490974, 0.26600193773065844, 0.15885835152960595, 0.17313525801704777, 0.3365582678346865, 0.08193498807809046, 0.19985816681817656, 0.11005173257041363, 0.1556564717283172, 0.23302975861776262, 0.23429812442871834, 0.15206793202988564, 0.13910279789518926, 0.1864711940288544, 0.2027876870406251, 0.21418842366866528, 0.23658757819043053, 0.09617176688005848, 0.15760956692599482, 0.18156939576710426, 0.11804884014230584, 0.20247057260524845, 0.1886380737226817, 0.1925408014006192, 0.1396895139928787, 0.06928709095283862, 0.19289686374606627, 0.16553157489866982, 0.09570610799616384, 0.2174915649717854, 0.1524000464668197, 0.1519635295675647, 0.15939806047226154, 0.16811934329809683, 0.1918287992837929, 0.14632299272043092, 0.08648302225816636, 0.17654839422433607, 0.24127461136348788, 0.13762464656704856, 0.108438290114845, 0.15971330565310296, 0.1251748291354987, 0.1646685462084509, 0.12419795977973169, 0.13539197524228405, 0.09589576838357795, 0.17896317997046057, 0.08722762907705, 0.1793053608027197, 0.13494556048704734, 0.15637225831948942, 0.10311531969496321, 0.08472373198357322, 0.15159899428967508, 0.09635362849240342, 0.18444279238822, 0.23549892128475253, 0.10986715900681673, 0.1496760982779726, 0.10954813701250862, 0.07973292962678018, 0.24180791581109648, 0.11858703223087134, 0.1282345996268334, 0.15687666593059418, 0.1337415307399727, 0.1119988599431611, 0.16884991538620767, 0.13417283824134257, 0.1944421550198909, 0.08372597907099032, 0.11914077590429976, 0.1830239669089356, 0.12604542677440952, 0.08619680414877592, 0.17256982384189484, 0.09374195814973886, 0.11137867346405984, 0.13780518284728452, 0.18761033612874248, 0.1762140428106631, 0.209756865496597, 0.18480015708313835, 0.1353991611470138, 0.2028455879659422, 0.12317612872368867, 0.09701375879587666, 0.10280775837600233, 0.17936790422085794, 0.16471734600922755, 0.13000263862552183, 0.2659890061664966, 0.15187754385894345, 0.14092803301830448, 0.14644231857551684, 0.3196656307385814, 0.16115165105269802, 0.1768197885323917, 0.12927670903023214, 0.13404151544936244, 0.12370236217975618, 0.095259026744433, 0.1208739885459504, 0.11178141354673332, 0.07658499007624003, 0.17707100408452173, 0.20528873428702357, 0.10856712312107125, 0.08615904367498814, 0.09767581198003986, 0.11706974147067917, 0.2954829928855742, 0.15652778948987686, 0.17270427227260607, 0.17298708129073345, 0.15734822369150578, 0.10008656044280338, 0.17605737783014777, 0.18358999863266948, 0.17209538559038795, 0.1774094923729858, 0.13161139262299384, 0.11079964888913017, 0.1282217829758602, 0.15921757015730106, 0.13432971772647676, 0.1095934664349883, 0.16462437357873688, 0.13252498311621527, 0.1553735861013974, 0.14737378956089098, 0.10373459452943457, 0.18752597452652073, 0.12101735424010024, 0.17699133094039657, 0.15302463795148558, 0.08766007804942709, 0.1691623566852462, 0.11964892968535425], [0.03168835173240833, 0.06023710661177194, 0.04207307765741022, 0.057816709271602096, 0.0688648539324922, 0.04033709943835293, 0.02494219679295296, 0.06292611736083223, 0.022140339377426335, 0.0043887807799863725, 0.032385041666848045, 0.011976264969205425, 0.03320253792128736, 0.029392424527735963, 0.054856204623056036, 0.007892413038550126, 0.017908475429360426, 0.04083740464862316, 0.019909935672917677, 0.06001339361612355, 0.02146960641708105, 0.021723267704909368, 0.08052992153792612, 0.06126243868962892, 0.02151948257139133, 0.015058038463335366, 0.12387192808091642, 0.05809502901449319, 0.009775058790710906, 0.023644417036144484, 0.022005191891484206, 0.03029669939179815, 0.06680755545535395, 0.058358869695615385, 0.010279162839475659, 0.1460360621492709, 0.0038571586135789874, 0.07556526576198878, 0.04889410236970552, 0.021428185958235015, 0.014931655023247005, 0.07599780666491679, 0.00883401745194269, 0.10156062852230766, 0.0674457986268305, 0.015022647116453418, 0.025509580661873185, 0.05072588754457332, 0.04807010585922868, 0.017809374295475505, 0.06881747905525469, 0.021944150005677537, 0.019491188183066346, 0.04504947479994548, 0.06090940239148275, 0.01727504712048798, 0.07441524521357591, 0.04376570679127209, 0.04014257439261964, 0.04679189581844596, 0.05022147610302895, 0.04715383405827227, 0.04495294389104651, 0.03576357368259661, 0.02002094947402516, 0.012007437086844397, 0.031022401075930368, 0.049232625132126194, 0.029796116474655368, 0.055504020063146475, 0.08022923968852529, 0.039684281444116946, 0.0960044302947579, 0.052877483784311244, 0.023832872750297673, 0.010166207005480125, 0.052888699311522715, 0.057962361738205924, 0.03569869752672892, 0.0041599393044898835, 0.08009684437345113, 0.049438296757157774, 0.058522801020092545, 0.015413067547694571, 0.037964287649599776, 0.035495282030634345, 0.06100728544556807, 0.033053782798590205, 0.025180498017899455, 0.06399646476511994, 0.060270040731636755, 0.037147580465722474, 0.0057374148896234415, 0.007280780409928412, 0.09317021907096909, 0.028342834275756634, 0.021936515939512083, 0.036505985659577196, 0.05518338545375774, 0.021500050751191956, 0.028292797242982254, 0.04032389591297796, 0.03798227539406188, 0.06421206872008982, 0.04785179378344648, 0.03627172363321147, 0.037876022829403805, 0.03745950848585175, 0.017711424208696813, 0.05277965435638063, 0.045237645146346865, 0.05986046331423906, 0.02876436649521272, 0.03867200733492932, 0.08658616833629147, 0.02014886317474227, 0.09182163619346197, 0.07328790852860098, 0.07911150208524159, 0.04543845211305926, 0.007990587206046668, 0.06500472074314471, 0.04575182037848619, 0.06777767557650805, 0.01677208741556012, 0.06722740994225587, 0.059856571587583715, 0.08263581297210149, 0.050971070154299664, 0.02708634857328669, 0.042645808820041924, 0.09746648611560946, 0.07772643810078021, 0.03171176529459415, 0.06894922319559321, 0.01628931412743705, 0.04965931312331269, 0.020552315719185338, 0.025450854276817654, 0.06911629931099954, 0.07914555469347585, 0.051109609494526545, 0.04143539373011839, 0.03722082996260255, 0.00928476922244074, 0.08355720990127133, 0.021153713891943617, 0.03762515201683968, 0.06930975949451809, 0.03422841775201021, 0.09594239249464967, 0.04795374476440972, 0.017761382717458953, 0.027372917167902477, 0.03362967024346994, 0.03714320610367483, 0.04905751275439416, 0.041794803879794576, 0.018251232742782564, 0.02574604902146084, 0.04223176511004568, 0.07076502011548128, 0.03172998478065335, 0.08290634926168189, 0.033161770552396774, 0.027594741756817507, 0.024731423022345673, 0.04374483855621469, 0.014118264042471927, 0.056672874883177786, 0.025555852372499726, 0.09123966218002381, 0.020593762991108724, 0.035098195676842046, 0.010008640914043833, 0.022277344626584844, 0.014254389248127419, 0.04942588996322406, 0.033565629123439716, 0.014418210447465461, 0.06108751783387796, 0.03411356201996246, 0.003746856795436132, 0.016418135642344435, 0.05734669900829754, 0.04980436804133558, 0.09085156203758332, 0.016287929423513915, 0.062070807006450436, 0.04283538110734474, 0.03682570479389641, 0.05114674177621642, 0.06333556837372242, 0.02000016359341962, 0.03094617724268427, 0.038296915365443114, 0.03061389235118705, 0.03459237080307738, 0.08749942175082623, 0.03152524969810921, 0.02488939801321155, 0.07075503032894866, 0.06571413348278692, 0.04141054566829436, 0.016077481240274447, 0.022821044887325937, 0.014657145610169299, 0.024930711219748183, 0.03265965737462525, 0.06432396735274984, 0.06350697671634055, 0.04174469406866739, 0.024585850994973898, 0.049516410912357034, 0.024517021825416915, 0.036603428213106054, 0.035923774158882524, 0.03936884857173409, 0.034404713735585256, 0.1074712266845088, 0.03493934351530287, 0.053915644004460306, 0.03596817661497382, 0.05588897924509741, 0.06207052355391845, 0.0015324960493730503, 0.09392047195785469, 0.014880446833558382, 0.0451266160234809, 0.05368050097698166, 0.07502581728922744, 0.01716753625641427, 0.08505225346814241, 0.03253970332744141, 0.03283978762826131, 0.06568044859675631, 0.05012098068912184, 0.0582088390365243, 0.013599989282327795, 0.027601579091541713, 0.018007890659294302, 0.012564541013430686, 0.04643232862074529, 0.030778089891217893, 0.024708250777856, 0.03772118879902748, 0.07841011794704585, 0.04005408740692562, 0.0591915421518347, 0.032000762387929906, 0.015461653801462343, 0.023156836546296557, 0.05352187481138015, 0.06384481766050862, 0.017071744622362238, 0.0017502431353111003, 0.016465200253972606, 0.054843384141643206, 0.03776102537109006, 0.02751899672852409, 0.041833613894038627, 0.030031027760536923, 0.0559064805237276, 0.012491035834705878, 0.06545370189292778, 0.028721708804368976, 0.0739285112508843, 0.05006877562752174, 0.02901843380964091, 0.02511536330735732, 0.053254173047119574, 0.02406602203395338, 0.017320466558298758, 0.058415284410359404, 0.08133547065118629, 0.004541663201375595, 0.03522089997967405, 0.01919436933202369, 0.05791816612585418, 0.05664568259230545, 0.02885405432372805, 0.02749026460092395, 0.024976946541198322, 0.03225670661777258, 0.025386091118918794, 0.02667222250883858, 0.06047450576818759, 0.05375646625555331, 0.015951468395219458, 0.03048598822656899, 0.05684643593286315, 0.030280839456545732, 0.040344453882426023, 0.03680145045021369, 0.09368539021740999, 0.06342706225451923, 0.026071563610927235, 0.012539396092535989, 0.024030713041523294, 0.037408364456026785, 0.08011754406916519, 0.08610839760231395, 0.020394626096071258, 0.024472192275307836, 0.056054657250041925, 0.02124533800768756, 0.022319651832203233, 0.0646680174395442, 0.055036028441522396, 0.02242562668998876, 0.04836555532810669, 0.02985459005069589, 0.006840633690327167, 0.05296550345637145, 0.022570254513993863, 0.07507954303535723, 0.02234457841803951, 0.025762699942495075, 0.04084185178902361, 0.048316207774464166, 0.020797036760937304, 0.0961069481807851, 0.03673568180191421, 0.015518410382942568, 0.018512830701506427, 0.03340832445950758, 0.08079835874659401, 0.07238579403248525, 0.029455473563904246, 0.03004154231729767, 0.04606610794942226, 0.04635159061440537, 0.03237867164575765, 0.04260494185972118, 0.030446017589119655, 0.047236468132224776, 0.03720108404635422, 0.017053766453999187, 0.03395776654924116, 0.06216554143916696, 0.03608564470684336, 0.030759043030200467, 0.04101633597465773, 0.07249928229758817, 0.030110434689108404, 0.06570189139775692, 0.01767612479236578, 0.019005892550452583, 0.01577058162975816, 0.08060307527381567, 0.04368491898921709, 0.059595419875075745, 0.08403526408778084, 0.15008155797277728, 0.14486612331482673, 0.1481928448042562, 0.10159161677884479, 0.08986605887090968, 0.08127639761134502, 0.1958895096134755, 0.07043348790536966, 0.10697267198514555, 0.1336775164330198, 0.09834733401094714, 0.10529894607081529, 0.0805184608625789, 0.16220931204095965, 0.14814882539212704, 0.19702765579906203, 0.15487639503853937, 0.12274852908787229, 0.24940927002218463, 0.11829584987173158, 0.1481963688087079, 0.13443150016809666, 0.09191482312857144, 0.10855852761456083, 0.1368881756019208, 0.21118938862796754, 0.1600544905710605, 0.07705553660109159, 0.11372262672070535, 0.11936980555014265, 0.09266333699586893, 0.124151052216128, 0.14114241506303513, 0.21326363296999087, 0.21293989953494843, 0.15112288596649326, 0.18954303806587575, 0.13619134202599525, 0.2466784117202605, 0.06117950201094632, 0.2672028878042775, 0.12084212694917956, 0.23035099429468955, 0.15663637479226436, 0.11288605870739107, 0.11233672003952727, 0.13860450366572027, 0.2223466625136714, 0.10249237529933454, 0.27807514633863206, 0.1061124854811257, 0.1288972810030945, 0.11512183268824894, 0.15366649705796473, 0.17240949696110142, 0.15410791691993514, 0.10251613934674572, 0.197044187976468, 0.09066948592061959, 0.1527455674424287, 0.21760897560706063, 0.13180060101853264, 0.08821597442992272, 0.08724124245946446, 0.1981634271120833, 0.1295731697351702, 0.23453584151162257, 0.10886417371371102, 0.12783705362028655, 0.25495825936236693, 0.20659502145023118, 0.13935099506089765, 0.1656497822653863, 0.09141968518135049, 0.12138749728159559, 0.17585350651173823, 0.26451232572717054, 0.17269264305791548, 0.07173655749929529, 0.14023578064816614, 0.11990894758773428, 0.20132799843145957, 0.1744000078930009, 0.13694345650653686, 0.12336247961126989, 0.12299911644790443, 0.0817016147137169, 0.17761676512177915, 0.21473492015033, 0.23831282351766866, 0.0764405518589962, 0.2001168287449306, 0.09608716012970095, 0.1173542588648777, 0.11290696524684468, 0.09690608513811905, 0.21192691679443085, 0.10984496543965033, 0.10166264845118408, 0.15658710001697465, 0.10174283487421852, 0.05332264598579176, 0.15492612946658366, 0.12903572841277047, 0.10334851685911418, 0.1497069869430796, 0.1135291665371868, 0.09075316570458875, 0.11475998637897354, 0.2846818885976269, 0.17918752115820685, 0.13032552936384756, 0.14413369729393913, 0.15928530765156593, 0.17115637629983887, 0.2051701898416204, 0.1419997440590974, 0.18521025927076418, 0.167964241136947, 0.14722526043413148, 0.09502685613810055, 0.17877135155422075, 0.19700848827919654, 0.13253351733569177, 0.24362830925853024, 0.08787063731541557, 0.18407117845791002, 0.13984293076059512, 0.2061774116009474, 0.1842854226068143, 0.17158696367855997, 0.12667876698317068, 0.08132455389826529, 0.12654643295513046, 0.147224708850826, 0.11288201376315087, 0.10981823663197218, 0.1389136967519599, 0.14296107715175999, 0.11462057369851297, 0.15457483218802562, 0.19227666960608578, 0.1512967879253049, 0.13875816558157245, 0.23493137270692857, 0.17110987476283507, 0.14048970815154815, 0.11909949142606029, 0.17989416065956318, 0.2092595518596711, 0.13342280751995503, 0.14802934631945627, 0.10232726036901436, 0.14234711896748314, 0.07940679833653473, 0.13599928378337814, 0.10111588383874587, 0.09107312998704373, 0.09249318120700699, 0.14757933095097542, 0.16967323007843188, 0.11407789233471118, 0.19604450452231592, 0.13894723608128487, 0.09824599590032332, 0.18805128101619983, 0.1561098272401479, 0.13552095380521592, 0.14232579107967117, 0.1712642108360606, 0.18529748604182275, 0.15309727840846585, 0.19389866160288935, 0.11312666394176984, 0.12442760995679325], [0.01674728723423135, 0.04445927300220055, 0.01784801960081583, 0.06262014950475385, 0.03315241278840169, 0.049412176989379435, 0.03713666371280148, 0.0029005336100160475, 0.018498338233198852, 0.043241024663251255, 0.05173858683255892, 0.023707069621811953, 0.037928771813430136, 0.035450538665416746, 0.025129357818514112, 0.010992508482999139, 0.04944018133345151, 0.05930536366518467, 0.062033471711460626, 0.040155682157004075, 0.03222468797297728, 0.0046446254183988905, 0.02324583489568003, 0.020531150625057278, 0.027025320094018698, 0.06751210353667698, 0.005843083312239258, 0.022698062877621383, 0.06342322415401859, 0.03188470198262123, 0.034666704314370314, 0.025531272441449187, 0.026129064255303917, 0.023443292142943512, 0.08243830018346349, 0.02582905847849625, 0.044654901214544816, 0.02399074814973339, 0.010460289007413292, 0.030359807799780564, 0.023192034455977624, 0.02801876950768694, 0.057227729384096405, 0.01834468972388535, 0.08318903570574138, 0.07638234449850936, 0.03822014569455097, 0.04903474079084493, 0.015383498469037155, 0.02430684177295095, 0.04389326426110441, 0.020534885303688147, 0.06317753592626223, 0.054407449469210646, 0.057437978384475556, 0.08070401501871886, 0.06937923600837108, 0.07183476997118804, 0.08219256215999204, 0.04242174342394837, 0.01910909991561165, 0.029887962755897356, 0.07972929070913985, 0.04806072511259587, 0.01021991934507124, 0.013155501238220643, 0.02395136548476594, 0.06623465192293929, 0.038187154118091836, 0.031036600515606905, 0.027971059466982563, 0.045001824131055225, 0.060233666876991915, 0.05802585893580991, 0.04526576057316796, 0.022881839709777026, 0.028603562724686442, 0.017947383119814822, 0.05285762295487428, 0.037389051379455675, 0.05810661609434794, 0.03609704792559628, 0.02969361391038664, 0.03526832465262663, 0.016922956940928296, 0.02143563233285902, 0.01133843931564761, 0.03680193691604561, 0.00837623778234927, 0.04417229263532547, 0.013180033288775914, 0.046096609740127484, 0.03537748835139698, 0.049003832973539836, 0.10893380344514886, 0.010151987455995574, 0.0648745853874472, 0.006235768969711518, 0.0126290274220669, 0.06292733161019222, 0.014437533100135626, 0.04413489605330172, 0.010702268412006239, 0.04083681859136109, 0.047241846069453225, 0.06556555072987272, 0.030857939235565644, 0.03757526437121053, 0.002621301743690105, 0.03876430943848626, 0.027819494716823105, 0.03169322405160675, 0.04828122053896228, 0.06329639829815396, 0.037097734954929164, 0.011967180124033364, 0.050375643636911153, 0.03331305759568368, 0.02247052327279122, 0.03000296595987053, 0.05169658989254987, 0.03323205911944951, 0.06675755289653618, 0.007961074147568716, 0.026785628419489633, 0.043663820927782405, 0.05573640134365809, 0.01828938392141173, 0.06451895971211695, 0.02779487839659616, 0.0688520755859152, 0.06544853846031813, 0.00341331671675547, 0.05804545163447338, 0.02575434766890061, 0.05534762704384424, 0.030877384462303696, 0.03620961305475043, 0.08051836127114874, 0.018468625513055635, 0.10960097409664624, 0.017477395839147994, 0.01825160238020603, 0.029193574915670102, 0.02875998638750565, 0.051376828623394814, 0.03956981258647096, 0.04749576208151637, 0.04678958989379387, 0.04134520602923247, 0.02850604930802459, 0.05722681773946651, 0.019258330012821866, 0.04005617882695891, 0.045069285833667365, 0.06880068640795446, 0.014415047461948088, 0.02069907901327937, 0.02316946742094813, 0.01946205385930596, 0.05937514278376776, 0.07539402978915362, 0.020028503100958564, 0.016556763082682606, 0.003796544300595058, 0.02491886941565862, 0.010572712410301452, 0.04382001093378471, 0.05799065719568922, 0.033776199880747065, 0.04699051560413453, 0.0329734776319275, 0.03827203282966249, 0.02892791860616736, 0.06210269924673823, 0.015871904418623496, 0.01752942661574531, 0.03364571978548362, 0.017285900671155225, 0.015117562537442054, 0.0354368218611325, 0.03950314761530008, 0.033655050736401355, 0.011317856448342004, 0.05280627591174938, 0.05087182346370913, 0.03813014185476688, 0.03208641484830409, 0.022813378262423703, 0.016830425010994077, 0.056633976768822446, 0.005043412008578139, 0.03616274379554295, 0.05616463683245163, 0.03324961019379478, 0.013738912624126721, 0.0394282701815809, 0.05027718601688262, 0.031972208375772165, 0.056510226755973794, 0.0813357387819598, 0.024548431430312417, 0.03364796059266214, 0.0449136397500913, 0.023890777506054412, 0.029291249210796053, 0.05118063350598659, 0.05897712563314746, 0.011530515752852926, 0.029738041264335477, 0.08733888036541401, 0.02669198566206521, 0.029055839967763716, 0.025279260157877882, 0.039774354231814225, 0.00941044020075952, 0.03440362589073277, 0.029217245117310556, 0.07529608544803436, 0.03876099610821374, 0.05074084924173452, 0.020868223566081257, 0.03419827219218977, 0.0412211112768179, 0.05167500919572288, 0.0436843827276701, 0.05584771391905605, 0.06123852142463289, 0.03333295672951687, 0.04894117847265256, 0.05997703891367682, 0.14730355461999295, 0.035343642586902264, 0.04051015103956865, 0.016764775106322863, 0.010834218438474402, 0.028364560529289227, 0.033358471287835034, 0.07761827414675106, 0.02908087380590939, 0.08553853543895869, 0.04976145945669663, 0.03407818407961919, 0.07049324276346354, 0.0241043972933004, 0.05682008633870752, 0.06220069721401219, 0.07530483417212963, 0.019796667658092997, 0.01926918739392873, 0.06495025189172837, 0.05342809798856897, 0.06440908738201664, 0.02574048147747113, 0.01587859140859256, 0.02493381770628114, 0.08087765650763627, 0.045639963880662, 0.06760968015559259, 0.039627039354414716, 0.06277268527135735, 0.08560077242192723, 0.01637240976936394, 0.006887093092495155, 0.014196621430587145, 0.015089225902732824, 0.024983454458115083, 0.04235581389718479, 0.05526758234707579, 0.03929757558169865, 0.0501281512720931, 0.03059696946893969, 0.09721592939909428, 0.02591220200091841, 0.02911395348247982, 0.022539189648664287, 0.011603453068903858, 0.055219226877295205, 0.03362314700479469, 0.05669726329224725, 0.023701249268807234, 0.036659620762352026, 0.020561211915206046, 0.009568249525111771, 0.04422697216092099, 0.05780712168122973, 0.05592837148616391, 0.04397909292170117, 0.05454094795089576, 0.03192137078111691, 0.013471529743964634, 0.03822939237579703, 0.028672740464248968, 0.035109012838332884, 0.020383284164352283, 0.05629393332187207, 0.042450678564848444, 0.007266989869681458, 0.06335418814072205, 0.03278628787806919, 0.028347200976925033, 0.06544387298485925, 0.007458655013432427, 0.017033966911596157, 0.06051329663023353, 0.030803230981672966, 0.03602705047195477, 0.007146364059149018, 0.024886088513378656, 0.014971613211767569, 0.0696544454342896, 0.02322983514938143, 0.05472459071766465, 0.06813887837192706, 0.10942547101407282, 0.033602684796337164, 0.030591645157865943, 0.06228278353509884, 0.010168506226862871, 0.03022877229077201, 0.04229947196079358, 0.05807248687732124, 0.010457538751765125, 0.011256331927143039, 0.10090163968984159, 0.05841665953818349, 0.054505163983952616, 0.0541417203813551, 0.010638586395690519, 0.03027075007858296, 0.03905974358560578, 0.0672308496770359, 0.014299484056180284, 0.0012038676715981696, 0.06877877629332005, 0.02602310088883725, 0.05081305685903757, 0.04520703993377186, 0.08401000616891731, 0.012881390190863562, 0.014605450954648757, 0.033775449114581274, 0.02917306291149749, 0.021215056467260567, 0.04720997298136354, 0.03125769732099387, 0.006253789272910405, 0.010583920276633674, 0.033376102801412344, 0.06757647024407502, 0.049185974207977136, 0.02313272967453926, 0.20238518444520814, 0.09322259650235215, 0.1096167172034902, 0.13948954972288302, 0.13036878268805244, 0.324594609799885, 0.15897254459559917, 0.11527176375590986, 0.10619713819675869, 0.13420795571179162, 0.0909969195603363, 0.09191845438533253, 0.12597917549071774, 0.21179530288903944, 0.17058136602563245, 0.12857638209337188, 0.10076316929752789, 0.14297174109566596, 0.16628307650887197, 0.11952263243015736, 0.09252428437673277, 0.1657313246640467, 0.08052532501038044, 0.09287634008233586, 0.16197942437664156, 0.13713310923307173, 0.16077992987007866, 0.12596115710273867, 0.17795180601458396, 0.14213436102915195, 0.17194995145884254, 0.1404587735211657, 0.10085692313770134, 0.07653139456505738, 0.1071488798686093, 0.12071808199248008, 0.18348438575142817, 0.17700489069665634, 0.12386868752899671, 0.13154155604781645, 0.09799553877523831, 0.2177232606036048, 0.22220280652325, 0.12283159600150202, 0.11924525497541313, 0.14961763044759152, 0.14022248136180063, 0.16648743812355304, 0.08582520554022444, 0.08547630611686938, 0.09135361775876054, 0.14618642988704866, 0.0882033339791721, 0.14804298268450847, 0.15530744207001504, 0.22695604501472366, 0.1379784412922398, 0.15823556801244137, 0.1919365725329807, 0.0546181274788274, 0.08925612264823529, 0.16575617655631036, 0.17771021252678287, 0.11075998085641092, 0.1373194831032907, 0.1900636407756998, 0.08307715622527946, 0.2601019881906048, 0.12999471727638476, 0.17871194909657204, 0.10726080531434667, 0.19015353353273487, 0.08128271017584109, 0.09335321449344197, 0.18296556036558845, 0.10413502102657672, 0.14624249220134752, 0.11046131381825094, 0.09307245859095166, 0.13348148985495492, 0.2765745945995854, 0.13367000877136184, 0.10458528920407258, 0.145760714827526, 0.19331741537297928, 0.24421418265950298, 0.07166515810475235, 0.1018063665457791, 0.12311878704255629, 0.12764924716564918, 0.11577558147931293, 0.17515926231299678, 0.17774120844419927, 0.10160099369503799, 0.1731064990763703, 0.10050623106860346, 0.196363840612673, 0.09671313823350976, 0.15451175250834034, 0.1325411322496591, 0.10363102710295109, 0.29045914149572777, 0.07224422098407823, 0.16016145176704855, 0.11081712335468301, 0.1732613867329013, 0.09553894761108583, 0.1164558905387117, 0.14923291641377634, 0.12969680100439057, 0.16044867345161978, 0.12386643523049932, 0.20290089951407528, 0.11153919952771357, 0.12091482869319378, 0.06783886301902033, 0.10749741923063995, 0.18514034608679433, 0.07159881489050966, 0.13368888517781613, 0.18383966668719248, 0.12869325646710011, 0.19171184830127225, 0.06857149588364748, 0.14698021955067112, 0.13847135758448031, 0.08823121957961591, 0.11169796358914146, 0.24399134300408826, 0.1044843877635656, 0.13023749053958925, 0.21335769324533402, 0.07358013276731776, 0.12104403708250293, 0.14426978515280833, 0.12361895818743976, 0.16651757602249423, 0.2438477934488366, 0.11841121505224898, 0.12333613384755389, 0.2262447936640632, 0.13661744012948007, 0.09632845484321156, 0.12512461973294137, 0.16077937828677316, 0.1439734010566627, 0.14387612321203755, 0.16004016472687646, 0.15382755938316547, 0.11463670751019833, 0.14241674103804175, 0.1012728858979479, 0.14645232368380795, 0.1095825343603088, 0.14221221088401734, 0.17034202483632874, 0.15093335581402625, 0.22090119249638052, 0.14418781374491033, 0.14295065835598977, 0.13029808809439983, 0.23906260909092045, 0.16978645787364052, 0.10496077187840017, 0.12350169310887014, 0.09175880166191248, 0.1691981329913101, 0.12403691277628946, 0.12257869505593855, 0.14585266070019814, 0.1346138137723169, 0.12027332964803904, 0.14030028525139057, 0.2179207427487258, 0.11947043119899689, 0.14554838589843244], [0.06534941434379547, 0.01778208241317301, 0.03256706415765709, 0.04414941341946683, 0.04789145032484685, 0.062471045812051144, 0.010202545428558463, 0.05329107167199255, 0.03205847370648577, 0.0825519493270305, 0.018605496696827394, 0.014410039162143104, 0.030678350989136006, 0.05746971357673888, 0.04260081647624893, 0.05145570886651835, 0.03407574025914073, 0.0221950093269228, 0.030057611011509455, 0.047833085916335547, 0.07405244895527441, 0.08626346145906756, 0.057540117056980256, 0.02272389919286774, 0.06771042071763547, 0.03754135348924226, 0.06223669951601375, 0.08258814698145275, 0.006623069507881038, 0.01791766082357255, 0.05710538514258881, 0.029637712474551894, 0.021821175656852224, 0.017345538700840647, 0.052742533566009615, 0.05185813485314289, 0.03504554245380625, 0.04544531626086082, 0.012472508955867061, 0.02407175811728643, 0.014134090461377657, 0.03810323301642653, 0.10590957943350078, 0.02719551801771647, 0.06893708070199336, 0.07087473156711749, 0.02945417504487259, 0.025819218079108867, 0.06877480795787227, 0.05020412804198362, 0.046987642774418484, 0.03667811795528378, 0.019975784760449204, 0.05277426875827294, 0.019881573182741002, 0.048667803827312686, 0.07225249473366045, 0.022683047554305485, 0.06349062073915716, 0.038305759850528934, 0.042468811866016164, 0.03068254532052144, 0.04253469542750428, 0.030045219539334218, 0.018407397850927328, 0.05495476949539396, 0.05631833705270002, 0.06811575783837227, 0.04408462536371043, 0.010183740842847094, 0.02997780380199754, 0.009832506766542792, 0.01826269533334961, 0.028022561642912128, 0.06091727777534436, 0.0707460364567176, 0.06011242580209529, 0.04573784693474731, 0.06383700739412058, 0.05901913406447538, 0.1138219117156921, 0.07291133034854166, 0.022743555093784968, 0.02270723295007502, 0.07960611143179479, 0.02534740367874263, 0.012916510534142295, 0.10072617491166438, 0.039260267099786195, 0.045434472286292625, 0.05560277645746547, 0.057468916845297625, 0.0578091747968668, 0.025020377980845592, 0.03432265039713633, 0.04458337541549437, 0.0028681996721594085, 0.042429151494176164, 0.03353569423779845, 0.036264825011453325, 0.046295221864936814, 0.051230069159740405, 0.08624890578850623, 0.0463014999554763, 0.053737517070746234, 0.06644259116822673, 0.03856745931590277, 0.048399247875016545, 0.03370054869822437, 0.013209293059433901, 0.043836102610634226, 0.06137910238917797, 0.04182530950093943, 0.01500290694586452, 0.05401124411653127, 0.041455905734291004, 0.06863171805537517, 0.0589173209793385, 0.026988411893046675, 0.008062613835077613, 0.012538726723212148, 0.0722464886043341, 0.01569087975733583, 0.018329565233040242, 0.015301755929906524, 0.047503859630876014, 0.04152257070546189, 0.053703958589223125, 0.012636938237495, 0.04991416759308308, 0.018327799400374777, 0.03607917509432282, 0.002195481586480333, 0.035075638217911605, 0.07677286547879059, 0.009441834483896534, 0.04185191190411006, 0.06978238211764444, 0.05690454370191982, 0.09778641975454747, 0.01930401375096652, 0.02901332783362558, 0.056787431840935064, 0.04969847936844153, 0.06733840842160486, 0.07480028866519851, 0.02425288045478444, 0.014655257203435947, 0.05449931490265074, 0.03932848722944337, 0.06473454451488872, 0.03326004048088386, 0.0194313490553008, 0.04692532918265751, 0.04176082404991312, 0.037492886936712655, 0.021482053430630796, 0.0640410932171489, 0.04488426027819515, 0.054359672395812894, 0.014396233300137666, 0.001476048656191016, 0.014252727794941637, 0.0022211395468818207, 0.03367177443578839, 0.05205587363771854, 0.007322717499318383, 0.034596572795342055, 0.09775688706506645, 0.057316917340241136, 0.03052292132539855, 0.02668202077339013, 0.02205161490447579, 0.03769070999095998, 0.019297329633827173, 0.0443477267699857, 0.018689168819917307, 0.0220992770646849, 0.012550003537457558, 0.04452157127220304, 0.09523514778383317, 0.044554007434917074, 0.03887188350481372, 0.08497012884265955, 0.024322190344513907, 0.09518054103659046, 0.022696459838639826, 0.03968004497789568, 0.05054307981364189, 0.020706579014058077, 0.039746223483234644, 0.01610406449124698, 0.06367504874604844, 0.02330892606668415, 0.035893709038294135, 0.03237514764130597, 0.024163229015445518, 0.0201719205060433, 0.09602425665023828, 0.03801976773707617, 0.10458522025615939, 0.038966847763907526, 0.05637581279921917, 0.07061750222478183, 0.052274932649226925, 0.016369249656676285, 0.05431476432169157, 0.0703238760451636, 0.01009770246568106, 0.04783840639696968, 0.03689009065349256, 0.03367509925737977, 0.031164238424671274, 0.061123236683347536, 0.03569261861904975, 0.03138613962237874, 0.09707631753577341, 0.049727663487917, 0.10162808256404054, 0.05130575098578007, 0.027740587660622214, 0.025941778740455067, 0.03427218052468473, 0.04762117067472108, 0.024612805798589706, 0.054981816229560686, 0.016109333260946216, 0.08501260075718166, 0.04025473349517392, 0.07059037505138306, 0.03869849482491132, 0.00144716989457412, 0.012249424152316587, 0.0594199819099759, 0.004722656261536383, 0.005583919119089843, 0.019105585487259012, 0.049062982622173526, 0.013520532558041235, 0.04091226293014423, 0.030669600349820914, 0.06281968859595156, 0.05271243780190426, 0.0408713270219103, 0.03714159348859422, 0.044129376389807275, 0.05979035860828816, 0.02130930060370555, 0.026157217986521222, 0.017835333184789748, 0.010879440608644679, 0.06871921295720725, 0.027068743872786724, 0.05006381903865165, 0.029305130723984014, 0.027741771266465227, 0.012959441143809067, 0.005701986195955185, 0.023985465973495476, 0.051588203773022666, 0.050409669432068066, 0.038541213143616915, 0.017727602070437807, 0.10802506994936736, 0.01782840966517406, 0.012196982561069871, 0.04626439448686377, 0.0432368801275809, 0.03682586184192089, 0.04823180403740657, 0.04162738685526195, 0.1057906213006185, 0.061825206878805355, 0.03848104076760431, 0.053578285695684534, 0.03231699390697383, 0.008873099427399857, 0.05296810432487438, 0.05357913605328049, 0.008207236871033186, 0.06774359998563606, 0.019401069430093613, 0.039364585292435465, 0.05571257600921297, 0.016357725779075297, 0.03508377790210709, 0.007232465159763853, 0.10375184682948936, 0.022559125171673876, 0.006686964113595746, 0.03427193920698858, 0.0637850742937336, 0.02752749838926379, 0.019360623818131226, 0.05973090252448475, 0.025886986216890718, 0.03288337803115288, 0.04313567608234383, 0.05314500168746999, 0.04533403049854021, 0.0022814735195659584, 0.06074453643973797, 0.024348350331908273, 0.013860356712323284, 0.0437682502031807, 0.023745519574731592, 0.01464104914527026, 0.04779930909975402, 0.015848023542803864, 0.008135096286423504, 0.034854365212302056, 0.02557610390677808, 0.050514972047700044, 0.0034980182704936356, 0.008030988289148458, 0.06563356401579035, 0.03905024792578432, 0.049726472221194744, 0.037914047603525465, 0.04838367713795555, 0.059790868056757804, 0.061026805365878734, 0.03504480317895932, 0.06205573805697984, 0.017444578547691627, 0.032975017468655304, 0.05902335137849855, 0.05604227343874593, 0.013419446298822522, 0.01091639669011197, 0.015963075584882212, 0.07943391018817503, 0.05987814462353146, 0.06136167005846097, 0.0099974311324918, 0.014759592633063515, 0.030057162850073753, 0.05410508222637638, 0.06041071745717238, 0.08290523077331244, 0.010337023545176753, 0.06551345675102165, 0.0250174266271173, 0.015572616849244844, 0.036357617411281795, 0.061666320243309584, 0.049328711710029075, 0.05617839194113209, 0.06000315485101554, 0.020782481090375976, 0.03319091636747603, 0.04973457743143363, 0.21490154427386102, 0.08547513400234523, 0.09988744653040364, 0.11811918233551326, 0.15607952080186338, 0.17813306241746873, 0.11057746040845111, 0.16002655900534124, 0.09171365610053463, 0.23386490170753774, 0.13518735315770875, 0.06289732777663777, 0.20066344780066322, 0.13616132670112197, 0.11849127890121554, 0.09757260461488078, 0.14583183843041622, 0.06748097738431347, 0.14940979079373423, 0.2023980087570606, 0.10626562645718937, 0.2004782230623307, 0.2465444689075793, 0.0747790756905752, 0.19537296716965016, 0.15474185467727725, 0.13804787950169656, 0.38474455475807195, 0.09561806917190553, 0.17532686702907088, 0.1304817959786423, 0.16740993055845463, 0.07914782231373173, 0.10805909191408467, 0.10187696920888079, 0.13520060647879878, 0.17360916000700768, 0.16622588038444522, 0.1213034344536643, 0.14800018901305814, 0.17680169353562017, 0.19394006099431746, 0.2335268883935867, 0.18417147468895684, 0.2054613798616394, 0.12993172952725043, 0.07582795731122456, 0.1589149194619348, 0.14545040325291697, 0.12764576912647294, 0.19606057704696733, 0.24571661897484334, 0.10954823660393877, 0.27472470676706684, 0.15167791666763444, 0.17599595290037895, 0.22459684660838497, 0.17619380276770363, 0.08285428592634779, 0.1412534978120558, 0.08578937560800584, 0.15774271300723477, 0.11310416393943372, 0.11574112284447878, 0.12186657802592363, 0.09750090644604738, 0.1545215890772881, 0.1638508392798324, 0.14581025007270998, 0.15962560390753133, 0.14512716011414606, 0.1351378945213172, 0.0992665475895328, 0.1975477069255806, 0.098944254399788, 0.25873626792623156, 0.12178757903917183, 0.13237426297799235, 0.20026943345944728, 0.22296293428347957, 0.132754227266677, 0.19618600096193053, 0.07772047793672932, 0.09560204261252958, 0.1725500740952069, 0.1482074311183345, 0.10373406592876681, 0.2192499512626279, 0.142991965816867, 0.12450537554198697, 0.23330208755308585, 0.16603648812780458, 0.10026060029744141, 0.1711247368685661, 0.12570010498166084, 0.19031458053617709, 0.17730303679502782, 0.1584066507676917, 0.10603325666799661, 0.10074724999046135, 0.10346700767836264, 0.1189663913100958, 0.15704537381327924, 0.1559929375446612, 0.16080657440808513, 0.16050619133297475, 0.14412421312543655, 0.11842480545202572, 0.09532738476991655, 0.10820392849704913, 0.12515345528241129, 0.2525083561457934, 0.10107842213924854, 0.10558232965488588, 0.16139456221172888, 0.1353653307042776, 0.16144824965346247, 0.07426260219466302, 0.1343135839147914, 0.11549939146085132, 0.16286148269089962, 0.10712192889543311, 0.12899126466964522, 0.10327600663708103, 0.13779355363259393, 0.14817620537454082, 0.11621571431357054, 0.11806067620073596, 0.16145739674327836, 0.19107696059490406, 0.16635177927392145, 0.09476768093243723, 0.11017952369706285, 0.15069255905766643, 0.19441816114610244, 0.07941251335244986, 0.08350759804729493, 0.10386427023237753, 0.1820140791636321, 0.15784801945330637, 0.11320606129424227, 0.13615351260429429, 0.11454669217909537, 0.15026523521350277, 0.13571382410103275, 0.2072429632948291, 0.14925231376001913, 0.12221328643781525, 0.13698661790019082, 0.10805087179065713, 0.18631511127516148, 0.18075274603982128, 0.08848492491749987, 0.15245653779035614, 0.1460351122002448, 0.13134436501610663, 0.11965653693844235, 0.12171183592609822, 0.12552516114327217, 0.07087777293617688, 0.0685221215169276, 0.2396448359133736, 0.11623232309976894, 0.1890420165633963, 0.18053428840733346, 0.1383025271277274, 0.13112215355278986, 0.15859806549645242, 0.16577254019437299, 0.13672669958924094, 0.1671745577045987, 0.15437112940895945, 0.13152442632182954, 0.08792365059977578, 0.08464602768541345, 0.1327963774242709], [0.012621697875851346, 0.02967760267276918, 0.07131736184800826, 0.01217430827373098, 0.04633469071479575, 0.06444929933716213, 0.02146900312284068, 0.0326402485370636, 0.04140643177614097, 0.04269209202198733, 0.08310201577842237, 0.042562182662227464, 0.05554140898429098, 0.020766619239903746, 0.06076561151853493, 0.052512921693344275, 0.03424390038895992, 0.04193773290382759, 0.04586211788738447, 0.014438231197756626, 0.05627778035798862, 0.0327217526313278, 0.05771419138557488, 0.04084470163610193, 0.011045891404782814, 0.013646964836234768, 0.011429643040643105, 0.031903384951874614, 0.043249980231086095, 0.04793293015550702, 0.029159903436178164, 0.018326520033541228, 0.037145217084476066, 0.020970019414239836, 0.014400018732093517, 0.02614478437951015, 0.04666249590715574, 0.00889889169259057, 0.04122227573046281, 0.02618782128387642, 0.01997572155819545, 0.04387897289087696, 0.012688931667306011, 0.04698002403001151, 0.05175604597635327, 0.03404553724272597, 0.05462092369975102, 0.037496307519294565, 0.019880709418606375, 0.03791716558137729, 0.021352848871761275, 0.02648912941015536, 0.04941688076923451, 0.0640896133958332, 0.027279375917128017, 0.025014597847456896, 0.010280166414656467, 0.05172058759677795, 0.006415291141057688, 0.036616528316611247, 0.009514250860158956, 0.016415550095599987, 0.06390665244731693, 0.03107487618352377, 0.048040331852051525, 0.06039419677108527, 0.014394884027781026, 0.0956953980869824, 0.03990661931194125, 0.013126393727537607, 0.011761651182877681, 0.017946624692769784, 0.09233569651241265, 0.058399315307577776, 0.07569952267071894, 0.049375826117372325, 0.014323571775739473, 0.04246542192695122, 0.03864751550399008, 0.025916614667362264, 0.025826683605930982, 0.04965818314362438, 0.03381605177456814, 0.013544383747953803, 0.010052475507461257, 0.05865746778586219, 0.0052776256756436445, 0.03419506611422666, 0.044225991568377906, 0.07014334742580691, 0.014682047298148036, 0.06751335225999355, 0.07312984160718418, 0.07595287560815774, 0.06600697059184313, 0.010591111927022858, 0.042833113487088875, 0.040613841040120016, 0.018887099126474034, 0.042762748311243715, 0.04368943890797035, 0.03796030782283314, 0.045034432663552226, 0.10734885179948424, 0.06135885851577886, 0.0315713337171943, 0.0543189931270336, 0.0319002497370445, 0.03838948943021317, 0.03628907935513604, 0.038403972322421695, 0.056821921119286176, 0.031008481258346193, 0.06695971583887454, 0.02346246349324863, 0.052632040704690644, 0.04986753965157175, 0.058856482106831774, 0.024229916969254136, 0.03757584276759336, 0.03898422646846983, 0.05438064022230045, 0.035641846141868064, 0.012668694497176237, 0.02742569488022597, 0.05744227230729115, 0.04330518069647012, 0.04736424393711552, 0.06733777256862772, 0.07047365389523969, 0.02858899556280625, 0.046533440735431454, 0.02296816249708495, 0.03676479697347649, 0.02760373371382875, 0.03452010572918, 0.07615844764175915, 0.0347996435518707, 0.021405318233695243, 0.04612998436054876, 0.03209658658071872, 0.06140070606864268, 0.0317928671926981, 0.06439265479604084, 0.041081369178549904, 0.061636354714151353, 0.006303832051344217, 0.06939756083151988, 0.07845688761482317, 0.022627849004141266, 0.02117417418518134, 0.021678704370353973, 0.03885582247148118, 0.061656537300516526, 0.03373719451408233, 0.01583528350062308, 0.0619286593921002, 0.06099992717105535, 0.054791998794122096, 0.06458047657243668, 0.0555679003047126, 0.03535514539708534, 0.03924553522900228, 0.07275806679841011, 0.0055534905855423745, 0.07508285253519013, 0.05840633267296418, 0.05924369358728009, 0.06749149577151384, 0.01683395093066558, 0.0543244706556922, 0.07604243894738537, 0.03379932041430185, 0.0023070024420326998, 0.022417002455181172, 0.08225098402509767, 0.057874307592189124, 0.039095768870245066, 0.07361710417054354, 0.032899358625253367, 0.029772415629497943, 0.01690436781744563, 0.034076816612674345, 0.022416217215058785, 0.0963078240954107, 0.06914349543231149, 0.04169320912971612, 0.03065825650288213, 0.04501801922977452, 0.02342296783031235, 0.049235356235576254, 0.02651362890197385, 0.027463679434731606, 0.01844512576597833, 0.022449653122514006, 0.0360766661563708, 0.03034237546906356, 0.06747050496238856, 0.015419653988623572, 0.02424658895770629, 0.010414731673776143, 0.023695291019976143, 0.013387206446139083, 0.03740056568095761, 0.015472317745368329, 0.033488189125613826, 0.016478641266604106, 0.018514784225713343, 0.0026753494861505686, 0.03446256103474767, 0.08654894412405069, 0.04077434795157563, 0.05387414119116241, 0.04503155217295693, 0.015113485992074975, 0.02816560749535359, 0.031769329141224587, 0.027026459649806062, 0.055755235615276524, 0.03281370999531881, 0.004804541484542913, 0.03932346935353933, 0.06085196877979945, 0.004513154675688354, 0.029063452966511253, 0.008476991750930828, 0.030439911868363142, 0.042637408665952184, 0.002192202490761936, 0.08662816527630053, 0.014355486041055092, 0.013741112254079313, 0.042276608066693436, 0.027909387473858176, 0.02589726137117513, 0.023428431952432282, 0.018232231847040595, 0.12586255392600454, 0.03913490830229656, 0.05014329683035613, 0.048039914334132794, 0.03981678784194012, 0.041725878949247064, 0.016844725957320585, 0.07737497228287882, 0.0454078354091654, 0.004413127054220005, 0.0537948893953956, 0.00622434899278526, 0.024541519402015596, 0.01861012578310986, 0.05060480734814079, 0.012474069860012782, 0.05372863811170382, 0.040542728928548676, 0.027503123386732997, 0.06582729233008239, 0.09988209923669215, 0.010866900706934112, 0.04298938393232323, 0.03679716035783772, 0.029710115444275643, 0.052329616005262064, 0.07883315935971276, 0.03964016627099726, 0.06792690184327864, 0.011840293938744695, 0.023627645456262177, 0.060852539515303034, 0.02309463020684498, 0.021900228269758727, 0.02999042893098968, 0.021313606017840006, 0.03293873554456138, 0.03490823268469784, 0.02629806325140019, 0.0615127272753706, 0.04821942788698981, 0.023504849222879258, 0.08916564000349853, 0.05776271539469881, 0.028937979255832975, 0.05942745126723763, 0.046585044418010986, 0.037744397432693554, 0.05125835695634446, 0.00647084640091165, 0.035221459223858775, 0.04753291734584397, 0.07899520227745657, 0.03804986350118153, 0.050927066063928994, 0.08326831814502517, 0.02830783171849626, 0.029694860718483408, 0.031559392321674574, 0.08947396741038369, 0.038126656154711405, 0.033862124302334366, 0.02767215685678586, 0.046004679189213825, 0.06195506644285014, 0.048699481562981685, 0.023333151682069706, 0.04718358891325132, 0.036304374300544305, 0.018716642648101817, 0.022748762576450265, 0.041599796198668985, 0.033648584954320424, 0.04380889116756378, 0.046215307403115496, 0.02003201944453101, 0.02375448280344567, 0.05271467477864316, 0.03427100457972096, 0.06425456361724965, 0.02556793740950525, 0.01872784859921423, 0.05162378472666587, 0.03724937056822162, 0.07055214726396146, 0.047535188796539465, 0.01970486925734628, 0.04480280981008564, 0.059543310574466185, 0.018183062408840465, 0.03297194928651856, 0.0754302504262136, 0.03557983132439756, 0.024852798162629048, 0.07367905004010086, 0.03696240935354464, 0.060827155191932, 0.032056230984087435, 0.05447965325607408, 0.029293666218197154, 0.014519396298114332, 0.0872263573710957, 0.04916145173352092, 0.04406824257344969, 0.01934643012411412, 0.05263492119528594, 0.048028116580098874, 0.02261537134707455, 0.04934572652282734, 0.07886925742270486, 0.12005340878761585, 0.013481580817531194, 0.017030276283020937, 0.022899664660555222, 0.04536258642591777, 0.08681765712437131, 0.1126682369278804, 0.1731439454541091, 0.12176144011919537, 0.11796068640485888, 0.1503755212310822, 0.09836958886514749, 0.06399719254864801, 0.19939281436945164, 0.14333768597533628, 0.14819629219991548, 0.10734518223832692, 0.1781353147159661, 0.09517806657259503, 0.16157644680671154, 0.1225862027175965, 0.0923008241900994, 0.09803976503110702, 0.12156251006789746, 0.13534924285786767, 0.10840872678184703, 0.11168998095297045, 0.12127246917976488, 0.1364459896520261, 0.10119326637997743, 0.1043264817206129, 0.13401773608019277, 0.14832006136496223, 0.22224123349353192, 0.1611498737287137, 0.09088238941565638, 0.19100712401972664, 0.15509892825878438, 0.12127637622817872, 0.2597433058244567, 0.08508406143875853, 0.09594131231067643, 0.20348087403803103, 0.0927893124941376, 0.14808824315907496, 0.10463683159961816, 0.10463449503144912, 0.15115788086287438, 0.09544851093162453, 0.18011741400245698, 0.191961286529418, 0.187338282985072, 0.1316733078490342, 0.10545708194014528, 0.1345596513560703, 0.17125468070228256, 0.12976079998958495, 0.08008043477011305, 0.12957502366794696, 0.07071976730179402, 0.18084487577359523, 0.1487086211601573, 0.21094558880694453, 0.06209897222898661, 0.11091788689936362, 0.11294929926554043, 0.20731085400667884, 0.12158740792543658, 0.13479857885789487, 0.12176772970105372, 0.11299374768690718, 0.11371076001875824, 0.20301067991362465, 0.20963347937551238, 0.20579370880319228, 0.0741245914551039, 0.12228807194098351, 0.19019402894041232, 0.1878840746658464, 0.21793931272001038, 0.14115738442107556, 0.1852273889967511, 0.15546806006421968, 0.1524728861066603, 0.1594862678358632, 0.18423141340815252, 0.184835136657761, 0.07643087616851253, 0.1510171045459086, 0.06764807648235752, 0.12071880977600814, 0.1747857484846346, 0.16822875597544257, 0.1823505143364591, 0.15673910718291037, 0.11769909036135483, 0.19294315077845128, 0.20389506713517253, 0.1402819144629663, 0.14378885047570353, 0.10832100971451691, 0.11318654903481085, 0.15717282020036252, 0.13545191396147976, 0.12739433906972408, 0.14780521963632878, 0.13518012128770351, 0.1486546426050125, 0.348229127064828, 0.1873104893151791, 0.15642753922410552, 0.1126979994437387, 0.14528209373595255, 0.16790209608452936, 0.14473342156458288, 0.1824925776811377, 0.1767700387825889, 0.07641432100846883, 0.21572842893581237, 0.10862349187053981, 0.21355283116140675, 0.1725108657152422, 0.10748041973960017, 0.10797931151765008, 0.1428958983911622, 0.11790341367163967, 0.32911523335403015, 0.11776069149134621, 0.11845654447472866, 0.11448928921092903, 0.21003875520921525, 0.20937040478231447, 0.11439797919123404, 0.18980972859407627, 0.1894632423476827, 0.13742904899822128, 0.2049067934914943, 0.13860540764947094, 0.10125551102382523, 0.20057090437941014, 0.1536798423096057, 0.14282783913996913, 0.1877059132581757, 0.24966641509484863, 0.21155655924831668, 0.09283960616636662, 0.14277182279094575, 0.14411805377852532, 0.15231900968618933, 0.1275053528708316, 0.1343664899468422, 0.10938898224623934, 0.1773644923683136, 0.20847493992938151, 0.15038108302941247, 0.07110286489008896, 0.09254123024161785, 0.10503708955741699, 0.16750262719729256, 0.09612515042986601, 0.1344531651345953, 0.15111907084863033, 0.15381478103658847, 0.09343470326594769, 0.18096286863569291, 0.15736702348916762, 0.13511066775648825, 0.25391055751712094, 0.276041642552422, 0.14637110304207573, 0.13249767974259394, 0.176133772117957, 0.09134811724746421, 0.11347305059673325, 0.15583953609870327, 0.2251731439103042, 0.1873196517267535, 0.13378705168443342, 0.07661196403205395, 0.09448861808425958, 0.16608623787760737], [0.0707941621001209, 0.03466989890101456, 0.03713377939176656, 0.07543897616767115, 0.020458289917798776, 0.03663216800158543, 0.029074448243444486, 0.07617907072868078, 0.052165328449900114, 0.0911820830116349, 0.02774866605778375, 0.0725784115192871, 0.02529529246291326, 0.03153511499535413, 0.024711215538122965, 0.0070724997767097056, 0.043623432772414344, 0.05412180209532381, 0.036171025206004424, 0.019609497056432793, 0.028860734610427773, 0.05549216485251823, 0.04416859626109081, 0.030315068265002583, 0.03347951701031097, 0.017158404488356847, 0.01647761279356576, 0.00909205884747808, 0.044686578950213815, 0.031165230508533218, 0.07924714561311469, 0.04683439454604541, 0.05074877825175082, 0.054043297235283165, 0.04049649552231835, 0.052204467881951606, 0.025276699508990974, 0.02126404012913906, 0.040041757221784324, 0.019076968272847515, 0.027703579868220037, 0.03984600643537218, 0.04708292879044049, 0.04392954235475871, 0.041253654691841335, 0.02610596478916705, 0.009763031210299703, 0.05243723220642536, 0.03615845370316698, 0.06726021382717357, 0.061483148620614124, 0.07307726499294082, 0.019325860663347186, 0.019569842430252223, 0.032521294234620954, 0.026119507308448517, 0.04181248518908697, 0.07265092174132025, 0.046958217337246866, 0.042942805786526976, 0.05925750998299449, 0.019618115545580947, 0.039360057712802966, 0.030441612583555044, 0.022964604018676667, 0.034561340411704396, 0.05471154807075378, 0.01498965745521409, 0.017204919431899345, 0.040956964160525994, 0.06986524218753462, 0.05054635483951819, 0.045350156649346315, 0.03331970340842682, 0.006660678200498825, 0.015017987386653981, 0.022726660939834775, 0.02203527233383108, 0.02654441414521106, 0.019494809863728382, 0.038304698818753806, 0.052956739410517685, 0.02484676713544515, 0.038389397499662255, 0.040939359460026026, 0.024142182664945725, 0.06672593644790112, 0.006140631383224841, 0.08001346336377245, 0.0061282897067646835, 0.04768696230565829, 0.013261819877962192, 0.029468265317019918, 0.09139563768140732, 0.008457740919003564, 0.04452413383630976, 0.058218602827119256, 0.03141005114171534, 0.03853714904717861, 0.03680219355550024, 0.04429593539586471, 0.044452933624627135, 0.02453448863009051, 0.026980270293631384, 0.06234502434850701, 0.08052964574627339, 0.029311201970783934, 0.04247570665733468, 0.022065172745515744, 0.09230061734635985, 0.02542522289009104, 0.020522072483154557, 0.04146874153746232, 0.028974236282069358, 0.04727764918859448, 0.015361894789572447, 0.05395147010623928, 0.06146143768884002, 0.05727871636589689, 0.06894360777110824, 0.02360499415156101, 0.03355080532210489, 0.04011108051805247, 0.08770113270128928, 0.08177319796936167, 0.023952874677976774, 0.03620291744629222, 0.03808663572154699, 0.02426585798422175, 0.021026840155583718, 0.020128205613864046, 0.08729739670431422, 0.02335760520861274, 0.04488407641709332, 0.010889665009604107, 0.013976397007823953, 0.020940628451024814, 0.011050616252055813, 0.019144182912104072, 0.015901485946209683, 0.008931827727675198, 0.013366574740728304, 0.03366335895994017, 0.06901757356019751, 0.013331688054266476, 0.04249013592338851, 0.017961124821956602, 0.010712576125027433, 0.04121707782389657, 0.03693468080112531, 0.03503303606844237, 0.028785251967248418, 0.03879949585684846, 0.008970373441585371, 0.03292781879164038, 0.02098185930310959, 0.006560882799432523, 0.03284464079526163, 0.02009871314399906, 0.006205217383291212, 0.0315886396434038, 0.006556367189923843, 0.020333519092791026, 0.07535997718091934, 0.03052136233647264, 0.00844080941826706, 0.019498446866148905, 0.0990720761699542, 0.07924340710404419, 0.028904298200241985, 0.02960257776712458, 0.015088813172863617, 0.039392892241237626, 0.09923725238730831, 0.05245040125784375, 0.03392148462514724, 0.027470865339461355, 0.0422458189930166, 0.06725913364320033, 0.016103940001959284, 0.05542865233315576, 0.037911676561399814, 0.026989633803285902, 0.041672118729160684, 0.047717058069763646, 0.04392645118998424, 0.06595378876813958, 0.02271881236905052, 0.042236407602866816, 0.013220456875710478, 0.017238278730562138, 0.09954891993754333, 0.0073135742399420955, 0.03259315711235808, 0.061199811001818996, 0.03871744784015802, 0.02379425042759507, 0.005041884620779104, 0.027978136204183105, 0.020925909986779578, 0.0016937206894527342, 0.07452702510260767, 0.060904844168333284, 0.06664234859448287, 0.05106259084817383, 0.039843179570931586, 0.05349850529924997, 0.022661767546988787, 0.02736260370922185, 0.029345172224566344, 0.00810964014230957, 0.05098182219831694, 0.010673532453966478, 0.031064624011877085, 0.028338823805473028, 0.05590877878750044, 0.04559876750253382, 0.05015625903803495, 0.03976688104411287, 0.04267460989555524, 0.020837463220701586, 0.014999111937809617, 0.024253430122870113, 0.03211729776775164, 0.04555796565968664, 0.04518740893071217, 0.0448114819253885, 0.010755869668848332, 0.07345535236621097, 0.04440518336430673, 0.01185232918003514, 0.019585545317480163, 0.041832300053248485, 0.04776699168066825, 0.05531818628491414, 0.05044679788331832, 0.03793176338677445, 0.02827382507553745, 0.029218580025518616, 0.017767231798760833, 0.03839798534529344, 0.03620066897823446, 0.06112797493715921, 0.0063354322206108805, 0.04890419940854754, 0.09334799743467763, 0.030010406588835102, 0.11007843839545405, 0.17838836887911444, 0.06775408772931946, 0.024916230242759473, 0.004830180532148769, 0.016344721436560634, 0.020630895272798596, 0.00851690493178584, 0.0618587538690096, 0.017699877348458095, 0.06282945238654652, 0.07129058707505465, 0.0468501951094837, 0.079807385712141, 0.0663230125041258, 0.07394500512389407, 0.003888103777670392, 0.014603408372720644, 0.07415872067213058, 0.07831968892846378, 0.009166227649867294, 0.0907079128909015, 0.07191124852866897, 0.014436662632731662, 0.04236348626774646, 0.08666585680217513, 0.056208920544914664, 0.04961932716410487, 0.010955630925544088, 0.022392696400563565, 0.0365033732997554, 0.08867421758271034, 0.01900740365888323, 0.0683219044379169, 0.03916900304536666, 0.01477726340864695, 0.10728721236509663, 0.02327415908146049, 0.09664205293501578, 0.03468486059817576, 0.07535372590345722, 0.025376886572508563, 0.026703528691864303, 0.06214149010878417, 0.09183992271221454, 0.0566576642074412, 0.04459285575355734, 0.036310257855802774, 0.0603175841482176, 0.01528963354611469, 0.023973808030507738, 0.03306135557772171, 0.09060848233920914, 0.04304851825919844, 0.052757062423493595, 0.038895034681885474, 0.0778039661987174, 0.10235475526461679, 0.044405118246833165, 0.043425709309597174, 0.05514641022009235, 0.06029131499329402, 0.010825460138280067, 0.030659384567350633, 0.027291173671161937, 0.022494718244659807, 0.053974173121875337, 0.03189872139163556, 0.021395397395075812, 0.04317878001940347, 0.016821015536064104, 0.025517848665795984, 0.02495074824940774, 0.019046648428024306, 0.019377585004774794, 0.03089829483219693, 0.01653500043997361, 0.024157274597054048, 0.05592137710341523, 0.037368742388583, 0.03439691496051608, 0.09589591394028357, 0.02744162376339157, 0.0227743441674618, 0.03653810389580266, 0.028887911579541625, 0.02988687682626469, 0.0536084542381427, 0.02879760513502744, 0.02305166416561171, 0.04781493729340935, 0.03732462338502369, 0.07798083291779603, 0.04400111028864499, 0.05065308620912894, 0.061528734682548436, 0.09032232551685265, 0.0673459314050213, 0.03046560645734351, 0.027296185801406542, 0.05389418588170121, 0.015864887053237086, 0.033411526707031076, 0.05812645011070756, 0.02094017645914949, 0.17320461961771214, 0.22547911942726184, 0.15967478675227012, 0.20741608384395802, 0.10222794473051064, 0.14756001021352508, 0.06698351819068193, 0.20925281028593742, 0.1831069189093767, 0.24474388649386747, 0.186501408536588, 0.151223243484574, 0.12158833489182497, 0.18556341048209898, 0.10903013134074789, 0.1554915483199781, 0.10881363489334622, 0.12388593982905151, 0.2122643632033179, 0.12315889174539237, 0.08690547378313157, 0.16804008384145078, 0.11903628151142791, 0.06820714446685969, 0.1414112659591821, 0.10999455176774534, 0.13142797585216262, 0.26329415399701367, 0.12613299828503402, 0.11172689106916228, 0.1664989907294512, 0.14007669482981006, 0.1213912740950623, 0.14219321190349518, 0.101289548310301, 0.1014551688586512, 0.10840597652619886, 0.07652079956906457, 0.1712188431091847, 0.10853879318963136, 0.09602601099158488, 0.13385929377569308, 0.06530636786333015, 0.16917796955714304, 0.1276401613628672, 0.12572622091899957, 0.16034263156114087, 0.13736783857307128, 0.17831401238518377, 0.19240765531937923, 0.11288007556070244, 0.1685135415004146, 0.07531987247808326, 0.09805157044602018, 0.1179687073454261, 0.12304557968051204, 0.08787383956293907, 0.22415574850334277, 0.09392201945546175, 0.16860443017175122, 0.2884664548741233, 0.14681924915602132, 0.1703047010326578, 0.08355791470216167, 0.0907795727553387, 0.1258204880380823, 0.13987323719887965, 0.2197906254760681, 0.18692615832532608, 0.17542389972556025, 0.15245676761673344, 0.21201346940811605, 0.2585800166331953, 0.1160793123586524, 0.20459249825967898, 0.17542903251465292, 0.15675963833928108, 0.14790648113816016, 0.10393948474478337, 0.09852323545924119, 0.11733322209047696, 0.18650444224476817, 0.14263731307320057, 0.16491560956403134, 0.11640566581439589, 0.12814805467402743, 0.24670511754530094, 0.1634976574249806, 0.1830974500626326, 0.13060695942371123, 0.15328084839688194, 0.10752810871288662, 0.21089631403165482, 0.2499101383070792, 0.15606180884905402, 0.12360031926824201, 0.18557258821543188, 0.25428990893546616, 0.14116763467750243, 0.08881109451214153, 0.0665741820909804, 0.115465936401198, 0.1776129959691917, 0.07487610072618531, 0.1721185520892182, 0.15962097673646866, 0.06810019859263013, 0.17522160654827473, 0.13214298103365207, 0.2634284951754155, 0.0619810636365606, 0.153000230390218, 0.15466227346370298, 0.08412793774398104, 0.20796245775155484, 0.2459929928544068, 0.2294076183029721, 0.14518435623857284, 0.22470846561895264, 0.24289205279802126, 0.07677570766498966, 0.10837118847355728, 0.14407489238487137, 0.1862856168900767, 0.08646574697547382, 0.1331745490672127, 0.17678978852927688, 0.2379346978400023, 0.19235496379194722, 0.12212738499886568, 0.12269158577246052, 0.25624545561450146, 0.09859252811199236, 0.16077354069679015, 0.06763107699131773, 0.14966866722510708, 0.24592700204060924, 0.11766569658873544, 0.15007936696131385, 0.12168627923294423, 0.16313338261698523, 0.11107242215544948, 0.14690892740843758, 0.09038821673922001, 0.08252860662797767, 0.08962835710976394, 0.06519552260156601, 0.06015744878940525, 0.19456978526807603, 0.16430967998120094, 0.07646826125921742, 0.1654558700899924, 0.19076382981673365, 0.184994850668215, 0.18045057031896808, 0.06080498460740332, 0.08348986311184783, 0.15352090970883447, 0.12091775514906454, 0.10630112697160053, 0.17044241299792645, 0.1565103686504787, 0.21051786659706026, 0.13013632096830877, 0.07582886895585446, 0.09664989001448117, 0.17860949249757876, 0.16082866838382137, 0.1786196508234547, 0.12468848587764848, 0.10194586349591132, 0.19749613388651804, 0.1272506439577668, 0.13629658718503293, 0.16669890903417142, 0.18504559633231935], [0.024576742209554202, 0.030292901510913527, 0.019449905620046684, 0.023352763532931288, 0.025868320484615626, 0.04493671431837063, 0.04210127735390298, 0.02397716924127552, 0.03302133131411768, 0.02358922614685951, 0.03944671757879757, 0.027947059847534667, 0.06057939086590083, 0.066635821525368, 0.054642450770423304, 0.013457272847693776, 0.013521348441680594, 0.024898263565715284, 0.008392423304969506, 0.022776245980733828, 0.06933042088583594, 0.05736480549638791, 0.018252638514123617, 0.010472115489744372, 0.04336048841416355, 0.005386270349845291, 0.003078641870336968, 0.05092057346877071, 0.05178498877813259, 0.0838887497722622, 0.08995714672510663, 0.06360392514315825, 0.029623444086962172, 0.06765227464418258, 0.059356419594898346, 0.07063962684403505, 0.032041479961105415, 0.027437948456574834, 0.0757770277860184, 0.012923771132444663, 0.06691935066614421, 0.08282640798678322, 0.004013408230797899, 0.052835371931113546, 0.05574195548110912, 0.023707500546269362, 0.03211092774666125, 0.08695147736298461, 0.006341088822321787, 0.03192335111840117, 0.04776583871834221, 0.04077046388579954, 0.05380538479995824, 0.12461869526774653, 0.06186608916088458, 0.026175194239664464, 0.03727610320633939, 0.005078161756823501, 0.11366371455932818, 0.0421770932453294, 0.029892358185362913, 0.02267656262002645, 0.03147398883987579, 0.05483542448810993, 0.02236181731155563, 0.0633957177670973, 0.09823461183376851, 0.03553274756057128, 0.023311381378481467, 0.1023053962196554, 0.06709319133792194, 0.10395234736103205, 0.022372414222768238, 0.08628992213597221, 0.08507751904788517, 0.013017234816816787, 0.05211768544188911, 0.029144443781866185, 0.02298004452079054, 0.009829010532778359, 0.019171626096771612, 0.07252258669224478, 0.08490694957154413, 0.01891153541603877, 0.020027191175388235, 0.08943344135918925, 0.0648004204154976, 0.03342494473702485, 0.03832483927028314, 0.08095922954981366, 0.04487059710006561, 0.10656168113552755, 0.20693727889128272, 0.08162919642223466, 0.08051310590798817, 0.018917407479978377, 0.038862422318948854, 0.07571793942441864, 0.04393197851435792, 0.0510362757279748, 0.0399227531236266, 0.011621729053947474, 0.03692237742906136, 0.020058363293027206, 0.047928980972257354, 0.049535183896941525, 0.06826434825216571, 0.10327090449150532, 0.02974376202591004, 0.0171697253526579, 0.030025783888695222, 0.07358069967238173, 0.029191883776577252, 0.056898893803478255, 0.024731486224599426, 0.050140569557345686, 0.06425674696783386, 0.007015736013155191, 0.06693189152546468, 0.04380706787830399, 0.017102901418242725, 0.023587197929079977, 0.052201824878612836, 0.01824297623017863, 0.030389777159378416, 0.0034472793096586344, 0.0611093053744445, 0.05076997590461566, 0.023866316318632137, 0.02822357162292446, 0.016419307756868583, 0.005529624552676274, 0.0813909200951457, 0.048479809681133884, 0.006847031960909766, 0.05962924265693273, 0.09149863054194758, 0.010835806155697474, 0.03623096392520013, 0.07429470127869038, 0.0404095943386276, 0.07121226224567621, 0.11590688894953459, 0.027452921645054897, 0.015176752405691774, 0.035146455385632096, 0.011001740800096624, 0.03227964712066516, 0.02817251569321079, 0.030673501652575312, 0.00577859977643276, 0.01738214238186277, 0.0452429847791791, 0.007485336419420258, 0.015134711415627071, 0.023555150555987513, 0.03616670447011148, 0.04267267935398606, 0.0268322984958368, 0.03790112370024285, 0.06080547873411448, 0.05780118066937693, 0.05447281592134988, 0.07601284497087041, 0.03492872553667234, 0.012966808036810929, 0.06876872521975348, 0.038318415623038046, 0.017318516864531466, 0.02095058950926027, 0.042830370892319954, 0.02985449620492516, 0.08935508588629384, 0.08952870439257353, 0.07262380988967997, 0.01118615540044923, 0.011031128890481929, 0.02426838798959169, 0.026021708524034872, 0.05919655619729912, 0.031145005787332213, 0.03859596927800486, 0.05068010613021832, 0.02602938664025597, 0.02656252446374105, 0.013722606442658412, 0.040093249821614836, 0.07149078117142763, 0.05839782143612543, 0.08423364255577327, 0.03514179757105247, 0.05229607284549744, 0.01141324109818426, 0.016166730483453122, 0.017016798881213033, 0.03243126741219913, 0.016747172321042707, 0.01927008946245957, 0.021664200410727533, 0.01678855256027272, 0.05579260155378331, 0.00960124110157091, 0.017935953087984555, 0.03906606381098109, 0.06675258864678683, 0.06062039189160832, 0.04953815631808774, 0.01093133731985525, 0.06301734694129517, 0.05274241865282098, 0.0857857366903655, 0.04891156534393949, 0.02582433171600344, 0.030033247500297525, 0.03636351245785913, 0.0837022609888546, 0.041960064366820364, 0.05233757182835572, 0.09878160627258402, 0.0453460542485118, 0.02048674050808674, 0.02096429673744546, 0.05762638238769385, 0.03629710029570326, 0.03789185786679868, 0.059723685976238026, 0.05201306464450975, 0.009781584902215871, 0.015056657589851849, 0.058043145709821296, 0.04953717955598428, 0.10369852710995944, 0.06478885248784097, 0.0551813553207584, 0.11227081349540143, 0.027729879666660583, 0.05688337286213233, 0.029286074286867535, 0.009021361380995763, 0.04708686265193167, 0.011051418729156498, 0.07155215247504174, 0.026510836511489846, 0.026585639251636404, 0.008498737156661528, 0.0994729929633679, 0.040563478419977816, 0.06907607203409558, 0.022386768795249444, 0.057480446468558044, 0.09506179740832699, 0.061854019445637544, 0.06433155162320023, 0.015480705450529294, 0.09905932846689418, 0.05787160330181641, 0.03609940364596344, 0.06190537031920207, 0.03786903227709475, 0.011872898640802071, 0.0018881438694323504, 0.08600689095234679, 0.01653374788621741, 0.10140691298030077, 0.08633846146685463, 0.040012599915386214, 0.048949180261021664, 0.03553902948155038, 0.1236217390866049, 0.04016968624425992, 0.08589673516971451, 0.07012912883393227, 0.042501347620160355, 0.049028673374484626, 0.01481203422431023, 0.10520490877810987, 0.08691121944256368, 0.03453684475032553, 0.04140817845660833, 0.007479863200006226, 0.0207271293226269, 0.06117544940582687, 0.030422096493684, 0.04493971355259419, 0.023599449590209032, 0.07044317125673256, 0.0432862046985857, 0.13849521356244243, 0.06960153174135955, 0.02330814082656176, 0.10101323571777153, 0.05058839008392346, 0.0612943462516752, 0.03762888669547054, 0.025561617184129935, 0.06161038433351825, 0.01714467810797355, 0.030960313480107055, 0.04885493229413706, 0.030307750210105896, 0.03660167387175945, 0.046934549050826224, 0.04082408621005955, 0.03676072521615894, 0.10903138006406446, 0.017900435336595102, 0.07160296708705925, 0.05980892091869347, 0.06900211390588554, 0.040023022541596044, 0.07256277566475254, 0.0319212252244113, 0.03770661397626804, 0.08296286356785605, 0.06004637753170344, 0.060843963160990715, 0.020033658872688972, 0.060112261093191566, 0.05052256014859004, 0.10055554414828939, 0.008520691321351597, 0.03994294337087101, 0.07905862669670775, 0.041173655960348346, 0.03265876871263308, 0.04915211695216356, 0.042103031695249586, 0.0405189304071809, 0.024232918118697502, 0.01521327660509175, 0.006570477093074231, 0.022060172106590004, 0.03723185396783295, 0.039238701724717696, 0.016815417348557425, 0.07777313115976511, 0.05349338017103653, 0.1084286220852406, 0.040141681900187846, 0.012500158984274154, 0.03740818059492496, 0.06695207028139023, 0.038326976655591885, 0.008787004551249407, 0.03247976843868533, 0.054297155790751984, 0.05204120688440819, 0.07738581242700739, 0.06189980852087179, 0.03914254619890163, 0.07371550050353812, 0.037375939784631614, 0.1310007132950329, 0.15302852967814093, 0.09698217299075858, 0.13621179657357355, 0.1536982743850639, 0.15060816681192768, 0.13329310883437434, 0.0730987920636131, 0.10368165785386678, 0.11957176164874148, 0.09903312059900454, 0.14042785421254175, 0.18555651569078047, 0.14224466236848987, 0.11577605645382598, 0.15700182937566312, 0.08115082047879696, 0.09799913938848243, 0.0969517133348892, 0.1309236295280918, 0.11272794582069882, 0.2072222023120811, 0.10629331287477287, 0.12086651152780942, 0.16070105345739474, 0.10594114991686038, 0.07688160399876295, 0.1243455925836198, 0.13553301202914408, 0.1899809798886699, 0.16765987440463037, 0.18859210844722488, 0.1898615621030331, 0.08117514377039287, 0.2428534419666375, 0.18204080031043102, 0.11287060671395834, 0.146233452363841, 0.20412705388040314, 0.18784963135277072, 0.12285601122364884, 0.15463152269442237, 0.135207302087257, 0.19301572994839764, 0.18566139312761445, 0.11315425076792318, 0.10913235045248464, 0.14954688988866346, 0.16660858726789876, 0.1376100602529703, 0.2102484487958493, 0.1585211196253377, 0.11710243044240821, 0.19049447330255664, 0.14627238495215295, 0.21495685582199406, 0.16348025190734095, 0.15228491877355885, 0.18862278260771306, 0.13980320144084193, 0.12384978047902546, 0.12917678052138898, 0.07280850602734475, 0.17407104973831486, 0.06678139355273978, 0.12055005592804764, 0.21964520666628118, 0.15450283524490174, 0.1832399883818242, 0.12113620512067311, 0.18891101552834436, 0.21267910788376487, 0.13347782795467686, 0.1516334682462677, 0.23843559676841383, 0.11422805322874939, 0.18746450363147646, 0.08299677061938471, 0.16916226475469529, 0.1538395563200597, 0.08842678650492623, 0.2650443891123418, 0.14990393282665362, 0.12569876432779337, 0.10335097600135112, 0.17271260730922225, 0.12183650907489563, 0.1283025209822001, 0.11029305792744122, 0.29094082693899836, 0.17551446663996867, 0.19338780353146215, 0.3301869597165816, 0.16535701410424325, 0.2103500167328504, 0.13134286348377505, 0.22625236261275508, 0.1971724923820265, 0.09950039592841942, 0.18730566296125614, 0.2888832373484489, 0.0926486204468435, 0.13271026914158177, 0.17091507392544902, 0.0826418114405486, 0.1571186577841159, 0.14682261994288814, 0.1376861481056098, 0.18347281782377153, 0.16588195287171872, 0.07150561263364169, 0.19678583248488365, 0.2166118049213002, 0.18518572913542872, 0.14908705327299335, 0.13834316043123124, 0.14401519881381145, 0.12602497988771047, 0.1265898394969202, 0.241712078211769, 0.12816287847536226, 0.10142902993867475, 0.15913831070065498, 0.11831334731992214, 0.09291351066842195, 0.11888774472378916, 0.13602102535866922, 0.12545563100326446, 0.33439094380986306, 0.12950550884969775, 0.147579254342183, 0.16544955752549634, 0.1378016741645913, 0.11209912553069093, 0.14524633275164714, 0.15751613484274957, 0.1615537093171189, 0.2762477202040534, 0.1347070007074264, 0.16990362336078, 0.09457765282281945, 0.19091929970008714, 0.1499622934047253, 0.1331570822625391, 0.09475419778496989, 0.10405298833164478, 0.12300865424256172, 0.18552064745416566, 0.15125618526531806, 0.18857493275596252, 0.10179815408323081, 0.13919279790453373, 0.1040689765866245, 0.16141273381729282, 0.10835479419197767, 0.13611416632850326, 0.18823661300684177, 0.11647336500426454, 0.12532521985591422, 0.13856828302866028, 0.2806000495629926, 0.23187661243061866, 0.1490582330452819, 0.14371590358355354, 0.14480051554499135, 0.13719833395894498, 0.1286962595317633, 0.210440399786157, 0.06468087239491363, 0.23271842048533503, 0.15234410672658874, 0.12177437934423647, 0.16623358722896348, 0.1666805229239887, 0.1526815684572343, 0.23938991249569003], [0.016521306618327097, 0.03305895389207909, 0.03890642640931953, 0.038388328807007883, 0.02526633816981508, 0.05952007895816238, 0.03560545313502512, 0.004842181299482623, 0.046362974680960185, 0.02309326465511995, 0.0850269802275204, 0.013687711137707436, 0.04017044467130496, 0.08791216694179081, 0.016651470702321782, 0.02187019379268731, 0.01870080761070694, 0.024159553708628784, 0.02512567102037851, 0.06421042546149223, 0.04519721102570334, 0.030023395609591278, 0.028559786545473243, 0.018696751175147873, 0.07252615666197193, 0.010336760202452782, 0.028433351394449993, 0.021495159279795426, 0.0588265089167943, 0.0371460636116324, 0.0660628030797647, 0.0075167508123652835, 0.016339383718948212, 0.03630466158351591, 0.05410512436121222, 0.026758727242028522, 0.03185832366016844, 0.048563546921697356, 0.023625301227213878, 0.012383254924638858, 0.026229483060418602, 0.07505475243012752, 0.039018026267689083, 0.042448303692283175, 0.041289626350325924, 0.0697743918205942, 0.024764611866445314, 0.0298406146917372, 0.04178175740244408, 0.08386189839051617, 0.018012347375793804, 0.1078534432716908, 0.026599555238780957, 0.025187492400648135, 0.016307359328493476, 0.030069958433629047, 0.013468971967907443, 0.041179056880214525, 0.04024614181910311, 0.037647200027300466, 0.024761242994798288, 0.03813277336678678, 0.06263160251922185, 0.09438243063707506, 0.017337776314947876, 0.08817482018663038, 0.022891076814924038, 0.035499169926850066, 0.03908670221966121, 0.07977720950880358, 0.05063752696338681, 0.04147227320279326, 0.05942473931598568, 0.03260656748147261, 0.034513452255557624, 0.09072868919540798, 0.03988005521316682, 0.07146759168995966, 0.4693932560903411, 1.2602743290124403, 0.8691760861585218, 0.7094354771317974, 2.295956438587558, 1.584240041913525, 2.57168312707255, 2.149634135346259, 1.0384338973991334, 1.3399413444342152, 1.3345526206877925, 0.43931072998431425, 0.6184081132373502, 0.35821128336171953, 1.8081486657742531, 1.8449766573406037, 1.4055080519568537, 1.1529389143951478, 1.0894014205663436, 0.9126539660557624, 0.17803897149860862, 0.14707067921277017, 0.016600357316013788, 0.14376980552990593, 0.04481006083228896, 0.06884636057000007, 0.044469580715221745, 0.03585751138387188, 0.07049249199729773, 0.025286363708155773, 0.05359249662667994, 0.038141935778361176, 0.11815362564858892, 0.030526619614853017, 0.016441440037001046, 0.0354724372887323, 0.04226699366324371, 0.040080651505700046, 0.07211276795715094, 0.06197896072520845, 0.01095382391565269, 0.03207815833570015, 0.023555489549894008, 0.031061481136167725, 0.08021187247528185, 0.034106521671938325, 0.037305321799771446, 0.027426309665785204, 0.050329230200018615, 0.04942122448776518, 0.026809308197229143, 0.015283170636863479, 0.05004689232596467, 0.05007174038778871, 0.07159076330642547, 0.024226726213049506, 0.0320729048877594, 0.06959036217942353, 0.022205548781541087, 0.0416082653006719, 0.03505332590711694, 0.09017271620611991, 0.028550288970431978, 0.022181834529844985, 0.08795130637384231, 0.009568561705940915, 0.05301287067272971, 0.0578782759276369, 0.02018054474085089, 0.03166619838485795, 0.017574694751191045, 0.1379402135048182, 0.09121959067640767, 0.017788318368876656, 0.023042111049195933, 0.04761980320777624, 0.01667200760435193, 0.07369530642585409, 0.010539930550411586, 0.03334954253307754, 0.03154724791285492, 0.024332482735776616, 0.08641293287397393, 0.008820035389714665, 0.05072442431663794, 0.04070423175430587, 0.09030344144951913, 0.0155351139725216, 0.019797510354809707, 0.05707333968471616, 0.055649503990406954, 0.03573072000196384, 0.018891425608026407, 0.08931780804789836, 0.03883305050793194, 0.024562052473606124, 0.0273513192340972, 0.05500486781520229, 0.08134569026409619, 0.08122018974034056, 0.08086339195048617, 0.025095615475889177, 0.028613922148642522, 0.047903401296465635, 0.05476539639095145, 0.0365034805520648, 0.030236542337544026, 0.022429821021374197, 0.06853075532783424, 0.033647179182979374, 0.04806159462238993, 0.030088989972887985, 0.017289700467259656, 0.03488849442932875, 0.04023807491326044, 0.06017309613525868, 0.020667129316397255, 0.006494050725333152, 0.08700125775630436, 0.04541438546091799, 0.10683687523968759, 0.01758547743872529, 0.031011763945101734, 0.02738513435507494, 0.00865719286769989, 0.036349205765873194, 0.02039002190764633, 0.05722594439923283, 0.1005858812300909, 0.012115967805467307, 0.055784105638703035, 0.04625291082887881, 0.08557810388024777, 0.04255741376489882, 0.04112341208383441, 0.027777700790113984, 0.041978898638438795, 0.03621352010316426, 0.03451092033496788, 0.0589398707773897, 0.023743895468332117, 0.012575517138165813, 0.05373867769395152, 0.021167773520573977, 0.08642009579606595, 0.042993356098210624, 0.013696999953789337, 0.035052988828430255, 0.007609378982094989, 0.06140375509858132, 0.020879036897132476, 0.036112346701444156, 0.013902511657966722, 0.05015126414476864, 0.019964942701100823, 0.03586561659411077, 0.00960456305033257, 0.1368914544582367, 0.020727550670985254, 0.018546486859239878, 0.02365278846193706, 0.01823136616768616, 0.0391894307798676, 0.05654175893493718, 0.0382433811412944, 0.03615061279326197, 0.007038301611769825, 0.07805382577522148, 0.028092685501061143, 0.1484563637284502, 0.08198129809311322, 0.018235231081264156, 0.035303890284511356, 0.035910957507909305, 0.1103243756017858, 0.21270722331058597, 0.22953158665087917, 1.0226567762513314, 1.3105149879570932, 0.9823783859610559, 2.4890598702815274, 1.9949555901750444, 2.7136457158673197, 2.3647160780045295, 1.4035120558354164, 1.5139048354279612, 1.471997987358801, 0.5742433895507167, 0.845267707782407, 0.4665555132012214, 1.6316113645030608, 2.2381943896893532, 1.6847521258938698, 1.8823281627508903, 1.5289704141116913, 1.2055337308875977, 0.3281233639967057, 0.3955031871314972, 0.03482618849844702, 0.07620284243697122, 0.01527852814404234, 0.053206292551852045, 0.058443591359161565, 0.11066920709826293, 0.02219334117046768, 0.027496860617952004, 0.09435800009316976, 0.021413084450027636, 0.0630335841748503, 0.12329100360793453, 0.08271489622852496, 0.04125527879824081, 0.009732265119260598, 0.05754111680172144, 0.0581507082848299, 0.009697058591090385, 0.05464747630720658, 0.051917311314853935, 0.050314846899240255, 0.04236697579824156, 0.09085290269145081, 0.031073062470363035, 0.040906268292136734, 0.0429266489922039, 0.019682825077325106, 0.07164718568204873, 0.05864067130812234, 0.02436970311757778, 0.04475304856896401, 0.053001704941233324, 0.09163136293570842, 0.06408922652143144, 0.048289072940186153, 0.027845011190361077, 0.07023019881378259, 0.0271013485748441, 0.06489938365355616, 0.10917823911914903, 0.03380809212103486, 0.03004279104061425, 0.03613541743928387, 0.026210756041109565, 0.0363477923336529, 0.07947890253196802, 0.027766150099435644, 0.06580105381867578, 0.0759776738742667, 0.09010779791541638, 0.07077648845170775, 0.015228405883986385, 0.016087760224998478, 0.03836598202225663, 0.06693350031010567, 0.05690898701188065, 0.02505290224367092, 0.04319569524077158, 0.05184570890701106, 0.07604140472868759, 0.03142064996814776, 0.011552434485976495, 0.003797761422784759, 0.03237129421904683, 0.004103785059640124, 0.01529486305380781, 0.07218248961913971, 0.048673672060812675, 0.022440680317700874, 0.045821641631905115, 0.047437845834440766, 0.03759665737649606, 0.044593173680045915, 0.0392997857453602, 0.05489157873295969, 0.04664651531305525, 0.19721845765748333, 0.21026734052406204, 0.12551769944688967, 0.18114980941097583, 0.217046421922503, 0.16959075305250385, 0.13337895664716923, 0.1082474499520275, 0.16883490006289176, 0.06664591090333077, 0.1492091217228482, 0.11660208309730215, 0.11382976411691598, 0.13188053463255206, 0.09018576268347041, 0.03575837194559074, 0.14807060781505801, 0.11895801796908341, 0.09330708067864181, 0.12882670898350979, 0.27442170367125546, 0.11901772686190183, 0.13525377298074384, 0.08061525607181173, 0.07911855009414497, 0.09862992852445572, 0.0952659904836647, 0.21307048688252128, 0.1600042352032277, 0.11613199622520518, 0.13264414043195788, 0.1219308221592538, 0.09663303608014699, 0.1169265519767519, 0.2529158383127182, 0.1170725223698443, 0.1844985789108661, 0.11748422568123187, 0.150353902229859, 0.13368022838427177, 0.06544682242336773, 0.2950317058111391, 0.1300053505767738, 0.12295430030433402, 0.2000104957410405, 0.14606456062005413, 0.2107879125903691, 0.16157270829764106, 0.11804198365538351, 0.165605916070842, 0.13037575408816338, 0.21228919977382307, 0.11493942715347776, 0.11501903901056898, 0.059942779461703, 0.18935104111029258, 0.15640844831303244, 0.14161093911576655, 0.14056452429823338, 0.19260309967062167, 0.0965110135955676, 0.11252403619789308, 0.128833373948451, 0.1817635530906339, 0.19258800773851334, 0.16358768807784205, 0.09303860516557771, 0.16268709043581642, 0.11668552539401478, 0.15426507219672203, 0.17241885855553613, 0.23109137230823118, 0.28049190859160117, 0.12687200500119117, 0.1581785557491164, 0.16110200855520465, 0.23114849182386554, 0.344049044914784, 0.7481166660304993, 1.5769178348202861, 1.5645926445722582, 1.4420289954831524, 3.34678269682392, 2.9933661126321365, 3.7438155470355867, 3.7025911913764094, 2.0467757385584617, 2.3674830650129626, 2.9198861458609184, 1.503189900709737, 1.3842583664001957, 0.945744674292303, 2.917270415252255, 3.606006257957028, 2.7614451896759773, 2.95445571022649, 3.0583953328670996, 2.4383355340650006, 0.9420941121155216, 0.8449177588185958, 0.2721603040493304, 0.3901592029198524, 0.14410294652465852, 0.15803656901323027, 0.1384388141694569, 0.2110051291604196, 0.23111918129988257, 0.09997177748910843, 0.16520076281120702, 0.13526013151051539, 0.20095302903604126, 0.2212549106127793, 0.19290846231723988, 0.11934167480156307, 0.23930700646052439, 0.2140759772831394, 0.28424825218896715, 0.22096090138919894, 0.12032063557736336, 0.1939111794795721, 0.14352488722051346, 0.14880361606276807, 0.2538715176764996, 0.10499423459893274, 0.13471394146402038, 0.1287609786396065, 0.15206449995598487, 0.18102437017425416, 0.11638602332001734, 0.09287324508712178, 0.14051319640730658, 0.14577096508395287, 0.19135506583317635, 0.1630611405257256, 0.1362491203772445, 0.13154247535332558, 0.11216780531310266, 0.13390885966439403, 0.13956013706422624, 0.14564269132191135, 0.14894108287990093, 0.1625748738766678, 0.3121412070768495, 0.11707835229894809, 0.1316430473760251, 0.19134771138910325, 0.12369992602015696, 0.1890731197331221, 0.12328832996107879, 0.21048101776790237, 0.14604407542895886, 0.07455752306287328, 0.1407286816186482, 0.14574436651122186, 0.11693766791253321, 0.17895289907051673, 0.10686164286227957, 0.17220144280262534, 0.13075453860144462, 0.20749820846944086, 0.1479314556044917, 0.13447513653626367, 0.15366490359508223, 0.14779366703043062, 0.22187827635676632, 0.1104689670366145, 0.1751261366711509, 0.21546409795841864, 0.1501692750401074, 0.13420867583444043, 0.19264872786739182, 0.18971523930949552, 0.18122998817313105, 0.16779053836099564, 0.1399831554942554, 0.11497845167234061], [0.046836937957954024, 0.02396045128754791, 0.004641671670645837, 0.039763184669878215, 0.07693336089892734, 0.06578004002691278, 0.060040555263478915, 0.036729066632688046, 0.04363620728855172, 0.07075728262744604, 0.024648336956517834, 0.054734346847380363, 0.03394003544423369, 0.020900973824844248, 0.05474783382528732, 0.0798287365825907, 0.06977597762259745, 0.06790103871495494, 0.044598141760234876, 0.021957772964191054, 0.037483908386240085, 0.026888071611944227, 0.0883018758688723, 0.0050355083752243275, 0.05635536591252012, 0.029481223694259123, 0.03808351774369517, 0.029543129344200416, 0.0620786402554762, 0.029395456320696303, 0.003743054605306938, 0.05433446044222482, 0.05110764447900076, 0.03966966065608206, 0.01336155016155493, 0.0620428639494123, 0.05985737981034383, 0.03161447404343034, 0.04663113609797532, 0.024795019811379816, 0.03446859014671176, 0.02769228390177652, 0.08858137538716679, 0.03694470889205414, 0.0644003999449553, 0.022396199337597338, 0.05929804369506817, 0.051383018613823, 0.013580941463700466, 0.02719896541337573, 0.034207189455628395, 0.07195441758320217, 0.02591630248653312, 0.03541876899919683, 0.10332174208616057, 0.0428256900951026, 0.027077764558095126, 0.029350086678600604, 0.09138508865068998, 0.12310892749097078, 0.0750555185180518, 0.10051890216287106, 0.002224955861757119, 0.027277451121218266, 0.03139883369928406, 0.015561715418082333, 0.05154378599517288, 0.07069527547085477, 0.06862048720640522, 0.18866743021194013, 0.06645756818714642, 0.17084486962806794, 0.1377991460744412, 0.9049506761854695, 1.0551849920903484, 2.484630043468168, 2.943726311768255, 5.493808456005589, 10.8928838276094, 9.833324167036242, 16.501144593761815, 23.652309871489003, 24.309440235937796, 25.082529590975856, 25.77073101074465, 24.621582454250706, 21.966918399257047, 27.57188339387217, 21.20975386711859, 20.86147681359322, 19.272448170569636, 19.58807541478065, 18.184321888031498, 17.591918476166263, 23.447224824659287, 22.704494614754957, 26.656980745254028, 16.138867620498903, 20.054127516285067, 13.781741819074078, 8.124428872139223, 2.681395007717994, 1.032297104116409, 0.34124580662577386, 0.11280083908669411, 0.03251420409088174, 0.02177249651492363, 0.027542310699279753, 0.09432017067146879, 0.07525304662844828, 0.045383780248342984, 0.04575508774348325, 0.032873035844175086, 0.04694556539517738, 0.03328318016663675, 0.03925514580201238, 0.08758916895115569, 0.06952725185622131, 0.04479676154592345, 0.0646870777071003, 0.05614930358264716, 0.03270307923817346, 0.044770059551322655, 0.04536458208496052, 0.04928091548443322, 0.012963113577796087, 0.11527639092697252, 0.022027366306452502, 0.03243412108971708, 0.04761499983649101, 0.049023824037923935, 0.044378975496417096, 0.04095973356837227, 0.04987146585218368, 0.022305431325108777, 0.04296067861780044, 0.08169357079051195, 0.02628965926687083, 0.04239563131704927, 0.022863080131731207, 0.04179301506449138, 0.01611758402789072, 0.04001679807721127, 0.0200220124210201, 0.039447709662659515, 0.060809531339233926, 0.03472702990796778, 0.026781510696896625, 0.01097487601181192, 0.08169340991204785, 0.03127848894725884, 0.02153803147525797, 0.021439581516108686, 0.01608483568434754, 0.022439630777244608, 0.024502157804466063, 0.056107034681424986, 0.025534518739028324, 0.030080300620606834, 0.04708315861681777, 0.04682011466713683, 0.009489329062372206, 0.036428821453404044, 0.06071252928626153, 0.018702678780461994, 0.06115795578807593, 0.05921802581137708, 0.07771837885581678, 0.05074633826171199, 0.005955649399003315, 0.08800270321268229, 0.09325468792550026, 0.0638422359442038, 0.03682636362951129, 0.03925694227819482, 0.057927313215670094, 0.012120121917236718, 0.08126085368736137, 0.05230568341850754, 0.030965768026127934, 0.10049531431568247, 0.03618452367523024, 0.02149421890686837, 0.016498050104165753, 0.07978045006072329, 0.024505961431010116, 0.025421493957119606, 0.06618308654475598, 0.07820237022373946, 0.024452503815653826, 0.026766305766819466, 0.08827861743949114, 0.05515760276466609, 0.04806491944398131, 0.025863700974432212, 0.03610901038853392, 0.07937692856836705, 0.06269487372088818, 0.05215446915357344, 0.04255347607296802, 0.08069289908293756, 0.028763410800527182, 0.05210291143626936, 0.09742457344527207, 0.0254975205227252, 0.09000982293078015, 0.008782062326527892, 0.062386642074993545, 0.07070781633017525, 0.018316059102935177, 0.03736032691273478, 0.05414149438541743, 0.03242883125259992, 0.0320652267715383, 0.03724537158925687, 0.04221433277932867, 0.07865209447880907, 0.03621409849954709, 0.10111204573824521, 0.03036612994037569, 0.04719142982315633, 0.06517972586856735, 0.010896098232948253, 0.017040369491423332, 0.03277124574167594, 0.051470808459505926, 0.026884727638154745, 0.05953611700885719, 0.033818392173176816, 0.008848804864101112, 0.05923745763157645, 0.05043647867897826, 0.07928400976403106, 0.023336723567016666, 0.0703110057680357, 0.10129242114001706, 0.03286887215630662, 0.0839247405829449, 0.03940403499009629, 0.015294156337697661, 0.06088139421697106, 0.05206897757166336, 0.0783927124294062, 0.01220503606037387, 0.032322919597068143, 0.15912072132191352, 0.0988926200736915, 0.1395687785360121, 0.24213874322031778, 1.2373023552279319, 1.4071701563173726, 4.060833271472685, 4.639311778929926, 8.133843050849054, 16.526769438097556, 16.525798651479906, 24.278157372628492, 30.273582550787157, 31.580096598594423, 32.841940733694265, 32.98360301602271, 27.887173314248365, 27.87041694887223, 32.97658197341427, 25.868323503002046, 25.798962270059896, 24.42375183105469, 22.220960509392526, 21.2802682768914, 20.59390840991851, 27.275087448858446, 27.531677138420847, 31.154319394019346, 20.240555809390163, 25.696294230799523, 19.46647213351342, 13.833554367865286, 4.468571005329009, 1.5604693755026788, 0.30334523067839686, 0.04566926674376573, 0.056437915716800964, 0.005554537731973876, 0.0525045866567281, 0.04272951924752805, 0.018880219656913992, 0.010288569441575919, 0.020107609340019768, 0.026914041992577336, 0.03248425771392161, 0.03597443555331519, 0.04093807243231324, 0.040710869906169754, 0.09690980832543104, 0.018642464269613548, 0.032475558785541404, 0.03177652079161377, 0.10071253854661219, 0.055123764661050616, 0.009045666478003466, 0.03582533952149172, 0.044799534784209345, 0.03736258304167179, 0.07273428742924044, 0.06486517016685779, 0.011488407730094848, 0.021078133572553916, 0.05805106705895836, 0.02515961254586376, 0.027255933626645037, 0.05390990217546782, 0.07815409136275131, 0.04513590867000242, 0.027272645834713217, 0.025456651647184646, 0.02322360493933722, 0.019887293944315567, 0.02187491863996031, 0.0507122281968834, 0.09478518604150704, 0.06140444074727355, 0.07957127741387776, 0.05747367425130741, 0.08768203412933696, 0.07019671311061229, 0.07960138466930197, 0.06057705812817139, 0.07459232643727334, 0.05250567450158058, 0.018964265247866995, 0.024159639893520265, 0.0181372695031666, 0.044825823091331034, 0.015144372741962153, 0.023607049182417895, 0.020814802339901368, 0.02817393870153014, 0.02030873231800093, 0.06338010489520046, 0.044430621313832463, 0.05612792206868049, 0.03271828225303081, 0.01619401470487637, 0.12519783475586485, 0.07004749450472093, 0.096019767375002, 0.02775697045088295, 0.05424916038229581, 0.09221195799088286, 0.013563058098718045, 0.10817654851463535, 0.05452464559986707, 0.13824243519094684, 0.23084181150601757, 0.16017473573165555, 0.1472940244862149, 0.19981316681350433, 0.15639470469567085, 0.13323425796003113, 0.168486483274929, 0.14379649603318784, 0.17321954301047712, 0.20293545007946032, 0.1299541299381564, 0.17179143254555043, 0.14938006658227215, 0.1812899728576022, 0.3008170179542034, 0.18637532578600993, 0.1348699935741963, 0.1307425416645504, 0.10964657931077866, 0.11982963450493352, 0.13706016234092175, 0.1767744208055158, 0.14348007107694305, 0.16164275937743727, 0.1107587244722151, 0.18482759835258608, 0.14851308487836393, 0.1919168381080512, 0.20318934693932536, 0.08306957195482909, 0.1408075886748491, 0.1690637918129083, 0.1122235075660771, 0.14746581204235554, 0.181853951465699, 0.2909698157060531, 0.11551047675311567, 0.1083088212556416, 0.11403717476153567, 0.15389246235211052, 0.24251864622196845, 0.1817015918993181, 0.125469972169207, 0.08969875292912607, 0.10121970407424435, 0.12012857733474624, 0.13926716972022288, 0.0993132406485177, 0.13417695979437522, 0.13572533074165546, 0.2634910692370707, 0.11990573767933155, 0.1260279523088567, 0.18842099504845758, 0.15163446416056928, 0.1379870674422672, 0.13964367129148977, 0.280725289616854, 0.16870731577998208, 0.09048643687199201, 0.2360304484083768, 0.07211452995937678, 0.14793436673860397, 0.22981065715993607, 0.09050155944761731, 0.1838234562667147, 0.14203014242793285, 0.07001014005753302, 0.507905016983709, 0.20682221248505578, 0.49346533213411614, 0.7116589707232291, 1.853850652133265, 2.3404226331941547, 4.811616107340782, 6.173823398928489, 11.83673749046941, 19.85244316439475, 21.560833454132084, 29.375249954961962, 35.87707665658767, 40.28979801362561, 42.55233880012266, 40.942413730006066, 33.919284420628706, 34.762594007676654, 41.315540959758145, 33.90045704380159, 35.534088919239665, 33.90726235605056, 30.50468860134002, 28.26531529426575, 32.21347505046476, 38.664191307560095, 37.57143074466337, 40.8906384437315, 29.27341934173338, 34.158184220713956, 27.762202678188203, 19.06294849611098, 7.189776109110925, 1.8997427508715663, 0.5397124360165289, 0.19666439222712673, 0.18215267979089292, 0.20994184508679375, 0.14874738520912587, 0.18824830350856628, 0.15779925029604666, 0.20370207426528777, 0.16046794822379468, 0.18143839473205228, 0.17302201490008062, 0.34232252788159157, 0.0935965853052274, 0.24145297195401885, 0.11944430760077893, 0.24133717010338462, 0.13190730174462642, 0.15992701354046024, 0.12881112675512993, 0.1965264197919638, 0.1457194380101658, 0.09978536531449327, 0.09792703519304914, 0.17901326679895002, 0.17482304164478857, 0.17179651936936766, 0.13392470236266815, 0.11152875774930562, 0.12034890422176932, 0.09085609727809507, 0.19954502071824767, 0.09617300794249582, 0.08602117083125538, 0.19400571472942832, 0.09414448372779355, 0.1939875278021059, 0.11511445526153812, 0.12022832198248756, 0.10648015405862563, 0.12458879485606186, 0.09967175447532248, 0.1923040802320165, 0.193472073203133, 0.15857137499317048, 0.22492152999245354, 0.10078601403942994, 0.2047855064513222, 0.1602469931446737, 0.24835338635790735, 0.22609655565071493, 0.14017291547309968, 0.06022359665122725, 0.21853108499800006, 0.10378927022459046, 0.1307952638354994, 0.1595978408811554, 0.1308613465798478, 0.12650469648501567, 0.12689612144904752, 0.11052563456037354, 0.13119997276413825, 0.16932171829525502, 0.17620261277883284, 0.21478793343469021, 0.24501380991310845, 0.2064407160205226, 0.18586409999237907, 0.2567717120532067, 0.2694149820073959, 0.22112015574689836, 0.13072156617718358, 0.11304833145151216, 0.13206036611189767], [0.05856500480384116, 0.03521806162391459, 0.12292592440761867, 0.06849644224970572, 0.05811468683063023, 0.0493302017510418, 0.05784338445312554, 0.05092326626782456, 0.04557902924716473, 0.021203367880755858, 0.03968219768496291, 0.0340670183481228, 0.022927343417259476, 0.045535837209993796, 0.03996023397532202, 0.04610205662526912, 0.027784700918522094, 0.06110614143131722, 0.05509446945882613, 0.05153868384959717, 0.03011975989436671, 0.06916178961194332, 0.05125549944838689, 0.07745126697925792, 0.054197916761040694, 0.04090545240849738, 0.020092172668345516, 0.09320985646017137, 0.0026900085785816754, 0.04868572262386161, 0.04202791294383426, 0.06581380152173581, 0.024478776801017024, 0.005252890132983486, 0.03480222526817553, 0.044229151681065566, 0.10104405543496532, 0.01740940936630772, 0.012651648083251091, 0.04748208741206796, 0.04755870003493563, 0.043836746124490615, 0.033965952198712096, 0.052174429574440566, 0.058782818922472585, 0.010137850260962884, 0.04108254512351367, 0.016783025235899033, 0.0806265635295741, 0.010988350540790106, 0.052916454677019394, 0.04683956180909469, 0.04084221568078764, 0.026897360428026127, 0.04615956301530523, 0.03734384836148351, 0.005552018260312898, 0.044231618484181744, 0.014840852536801851, 0.05320815797594767, 0.08047518455573628, 0.03829450601892125, 0.045692732016886436, 0.0849828995283573, 0.2117905684656674, 0.23806692461573312, 0.8899299596105853, 0.9883196123184698, 1.5618323991375587, 3.225648629088556, 6.724055938182339, 6.757974634247442, 13.478523973495731, 18.550082906599968, 29.455223160405314, 39.87828254699707, 49.79473644687284, 55.26803139717349, 66.79107635251938, 70.48683551050001, 78.26732743170955, 71.38527008794969, 68.63743012951267, 50.8983031395943, 67.3028358336418, 63.61203847392913, 75.85042568945116, 76.80272225410708, 74.05856932363203, 66.53449058532715, 62.88761200443391, 61.06849908828736, 48.6826660556178, 50.53592712648454, 58.02743058050833, 69.40124896264845, 64.72559544347948, 63.658228305078325, 62.02619283430038, 64.00101600154754, 58.137511899394376, 35.4204107869056, 21.572298542145763, 6.362872325604962, 1.1396462470293045, 0.20099904027677354, 0.21994588085480277, 0.10310969660959898, 0.053187584684741114, 0.00792232542035861, 0.06877569661986443, 0.04085482931846092, 0.14326478504846174, 0.002983193060631053, 0.040367911494667494, 0.007694973028264941, 0.019603906529805353, 0.02044916198018097, 0.058500105665335735, 0.03818048149227135, 0.032624616512968656, 0.027351416910307545, 0.016792120614780054, 0.0745583504378315, 0.037110172392379855, 0.023766910664797313, 0.03217750844816047, 0.04230514101143326, 0.04573148840497579, 0.030280567495332613, 0.03207281870286792, 0.04623038018302572, 0.024336472138642304, 0.009387020892914264, 0.0424713246344078, 0.0632755721979324, 0.06214709787238991, 0.041453324017986175, 0.006811876186064535, 0.024590568181367654, 0.08367815220187749, 0.07869459703684815, 0.025121742904546763, 0.05559054586375433, 0.009533345601671647, 0.031499269741377046, 0.02440528024078137, 0.00814913389002604, 0.029894744549247048, 0.008956770592879866, 0.012409051020269193, 0.08902451128608758, 0.041700008160044114, 0.10425546537003211, 0.03561427463747321, 0.02499572910188187, 0.0860658644007579, 0.05274879633479061, 0.023586322673626488, 0.024951146615128365, 0.047917317283610185, 0.09197606419723842, 0.056207667991158464, 0.02649661217395577, 0.1287321277683781, 0.08711804019948167, 0.050487944465731426, 0.023655718748247432, 0.02680466187396838, 0.0752092570426964, 0.05097637914361493, 0.03533168012396463, 0.02924473235203374, 0.052666395917655005, 0.044670196159953074, 0.012862313643939072, 0.03747250516748717, 0.009387330200913693, 0.08746450346323752, 0.022392060547586412, 0.04953894155821012, 0.017222428371408777, 0.0386039212706589, 0.0326892321989421, 0.003549201322922243, 0.038682901105212594, 0.008849791202303624, 0.045653761124178294, 0.08627360446318504, 0.03718313460628833, 0.055766723103701114, 0.05172268667769048, 0.022472944110631946, 0.03479816500217684, 0.035219122655689716, 0.06489107159957772, 0.03503343826460262, 0.043088584657638304, 0.05097037684472819, 0.01889935844848233, 0.07481552615401245, 0.0922775044736843, 0.07531486226305847, 0.032788348654585506, 0.026830542239270387, 0.015007088828321188, 0.05195877199331599, 0.12858343010227527, 0.038029251905578765, 0.05375271625516396, 0.059227904515160676, 0.06160020302500456, 0.12536641240360277, 0.026812401277223424, 0.01823196180104729, 0.046948449716212294, 0.051069543096086675, 0.028446526191527807, 0.02891084633677477, 0.05530904685597747, 0.013256226478505039, 0.004705443702292659, 0.005411468896894686, 0.010945605707444973, 0.0810881315039531, 0.06305014316533362, 0.08283849685422837, 0.014633921654744735, 0.054134699185529066, 0.020883809624900742, 0.05620500200518197, 0.02248699799360287, 0.06574441693843373, 0.03811674680741083, 0.06460109965935831, 0.011877664665301001, 0.055917332159175034, 0.03061240231017432, 0.05000785248534334, 0.07136738738946377, 0.17076354173402633, 0.3372396877215755, 0.8036490313468442, 1.3552148087370781, 2.0842271418340745, 3.3668497877736248, 7.344026748211154, 7.806342792126441, 15.810183786576795, 21.76746979836495, 35.53417128901328, 46.50610754566808, 60.08100709607525, 69.19445376242362, 81.25922510700842, 84.63697418089836, 93.1694236878426, 83.04609221796836, 82.43013889558854, 66.98315481985769, 82.10630016942179, 77.70931536151518, 86.59006349502071, 86.69959175971248, 85.30722095120339, 79.36457910845357, 72.5580430799915, 71.29215302005892, 56.77403719194474, 60.405622451536125, 67.73824245698991, 78.88165689283802, 75.85492857040899, 74.87268078711726, 75.50033846209126, 74.22450127140169, 68.8356980969829, 46.27785698060067, 29.51715346305601, 10.181300178650888, 2.2606578036662075, 0.5789249222124777, 0.08148108098295428, 0.12066311518391296, 0.06527500422371012, 0.024876717342844894, 0.05510200010312181, 0.0334336168523277, 0.12112812289307195, 0.058881808973608486, 0.031929941389769796, 0.020025992247786735, 0.04925383810674952, 0.0508118809140738, 0.019670280387565013, 0.04565407905066687, 0.05797844192373657, 0.0374003128719426, 0.04719402303078002, 0.02874368595169677, 0.03804940384842696, 0.024046775990075642, 0.1630915848598365, 0.023567450097611835, 0.06733493038242863, 0.016349118781246005, 0.01701124282854219, 0.015046302953945294, 0.007935972319119761, 0.037833914806645726, 0.014165171606075621, 0.024228903817974275, 0.07857431357185687, 0.05867229924807626, 0.011751205574030118, 0.0614295416181126, 0.07360503828573613, 0.058565426152199514, 0.05995561909531394, 0.07272433594710405, 0.040215712806750695, 0.009920481430937447, 0.037829571088115056, 0.02382514292314168, 0.04699330799461854, 0.009803935517406753, 0.04808165080424759, 0.10170946408423687, 0.05632549614435243, 0.06640887563867916, 0.08565983780088925, 0.07041121006853159, 0.07271593196257468, 0.03556342555149909, 0.04274056240495655, 0.03453132891727071, 0.04513972761830495, 0.11451807879512349, 0.016578416557862394, 0.05106695754934223, 0.11475085461091612, 0.04568186505968052, 0.04609059211948226, 0.07545965288074748, 0.038289369399388956, 0.039454386118919625, 0.023008263369481412, 0.023150629318890073, 0.07973111399839963, 0.029587154501989007, 0.0233954863412486, 0.053422237415948225, 0.11247885999299827, 0.14720164960430515, 0.2929152500244879, 0.18775379375344325, 0.16508189660887565, 0.14209976449849146, 0.13233107094082142, 0.1680499510539155, 0.09876848318644109, 0.08190180114921063, 0.16051238132340295, 0.1695725967686984, 0.13805186315890283, 0.15490333068995707, 0.09601519383009403, 0.1819198503489456, 0.09622110294238215, 0.13696328286201725, 0.11937290820623599, 0.18424748593280393, 0.11101956208867413, 0.14526493336644866, 0.14016873263303312, 0.12489048794152276, 0.1470193206783264, 0.1329897226946008, 0.12702514597725484, 0.12813338409027747, 0.0952163786296883, 0.13099397172129926, 0.08899130903544927, 0.2868690696214476, 0.14570013259447392, 0.0992172038663299, 0.11053429901479714, 0.23380278729863707, 0.17941676530866854, 0.08419422733206904, 0.1783004679506825, 0.09401024980170113, 0.12272621294663799, 0.10542976324476543, 0.2069301542735869, 0.12315534475830295, 0.10439664771359775, 0.06594374535545226, 0.19868583778940863, 0.08786818583405788, 0.23177486063251573, 0.17376803132074495, 0.3306000956123875, 0.21551496619659088, 0.10277527624801283, 0.1447161539427696, 0.17372191282770327, 0.10829490909893667, 0.17908842002432193, 0.16179634468449702, 0.10108490324308796, 0.1501459706454508, 0.13707514702072068, 0.12896457416636328, 0.08820374000577197, 0.18168968689297477, 0.5280250599307399, 0.8152137720777143, 2.07544372927758, 3.23412781280856, 3.7859415575381252, 6.0970047596962225, 11.292329180625178, 11.898824687927, 20.530597432967156, 27.823317127843058, 42.31778890855851, 57.873442249913374, 70.97338984089514, 82.84585522067162, 95.51698577019476, 99.80864709423435, 110.23564846284928, 97.18899019302862, 98.71201515197755, 83.22086518810642, 96.60605538275935, 91.55699222318589, 100.69304743120748, 99.88323488543111, 97.41696619218396, 92.53022639982163, 87.07319751862558, 86.0234300551876, 71.1648956421883, 75.39747822669246, 80.184385853429, 93.3327982502599, 88.33974653674711, 87.88193533497473, 87.05138914046749, 87.11272716522218, 79.86863505455756, 57.57156095197124, 35.76845053703555, 12.153748350758708, 2.705624959161205, 0.7586378111473976, 0.2431911948106943, 0.23788036688441233, 0.13410408951101765, 0.08097694916350227, 0.12462942049868646, 0.1658584646159603, 0.2744345433048664, 0.11483457269928149, 0.1444306942604242, 0.1417799840771383, 0.09451920031419686, 0.10125877455838266, 0.14356015790854731, 0.14499952986596093, 0.1897979768053178, 0.08594001913743635, 0.15067559787102286, 0.14191388092454404, 0.2285701309841487, 0.10783116543485273, 0.23058215366496196, 0.17549042680090474, 0.13886932493938556, 0.09028936075347085, 0.18335073405215818, 0.1075912113752096, 0.11122200082266524, 0.17941129544088918, 0.11041297367022884, 0.1300015967459448, 0.14296418746873257, 0.20197886673192825, 0.09419584226223732, 0.10414668088478428, 0.22429223472793258, 0.1322991250743789, 0.13845824215921665, 0.14545988742141955, 0.20016141506212376, 0.09110366625170555, 0.1282676716425246, 0.09406713183007895, 0.3520651744498361, 0.09203447840146481, 0.15204949995442746, 0.29639598583021476, 0.18810342096032637, 0.15982098697173983, 0.16927178468435042, 0.1687546906572196, 0.14178013729472316, 0.21183299441491404, 0.1589336732943212, 0.14274727733385179, 0.14432587811062414, 0.3071191330109873, 0.12282170580639956, 0.22693655573792998, 0.20092286049358307, 0.17416104974765934, 0.11866796942007159, 0.22354868511038445, 0.07573748232736703, 0.3039022685298997, 0.11505831633844685, 0.11727166692576102, 0.11555751455166649, 0.10562284038432183, 0.23158744488271976, 0.20278045517061988], [0.01400576594601115, 0.05176482534396553, 0.03807709026601046, 0.0329521803876325, 0.02403999036628633, 0.05169538330406912, 0.02809898274379873, 0.06315486355414314, 0.08517196236719048, 0.12459395062779227, 0.040691150802998774, 0.06481256290909744, 0.04508337419059488, 0.0978474003533202, 0.05370565164353579, 0.11410957773125942, 0.03564061657074959, 0.06624969022889292, 0.029127940332757372, 0.023586184777800116, 0.02239361379085289, 0.016197841314058152, 0.021712714843752406, 0.03623878185246741, 0.015352169303373705, 0.023166728656618826, 0.03013249036044844, 0.026229243657942262, 0.025315049870480454, 0.06656993796387989, 0.013874047661140082, 0.04901643895033387, 0.06854614603423304, 0.046202942744017615, 0.026939301826660673, 0.04773591915445943, 0.023625057994297916, 0.047881851243155624, 0.026432325905789773, 0.07235771691006038, 0.04059432878068859, 0.052515024604696425, 0.03384795167573518, 0.02223431921353744, 0.05424472856365385, 0.022773675755747867, 0.035604300172699076, 0.049590652493099054, 0.05030394546807774, 0.04145243918643363, 0.015044862708647647, 0.03711250129966967, 0.09016446543917542, 0.03745240685079367, 0.024416085910953345, 0.06938300516095854, 0.01920191529807785, 0.07484597048812336, 0.15582813671038998, 0.0748117416796665, 0.7320337225833248, 0.8467452768837253, 4.6294901640184465, 5.434610574476181, 7.799796356308845, 8.333595145133234, 14.793769217306568, 14.180765517296331, 23.971373111970966, 30.33728772594083, 32.32758856588794, 47.67825688085249, 57.58401447726835, 64.5844489528287, 81.37333470006143, 83.14691282087757, 86.04668186556908, 91.50121611933555, 85.87595678144886, 87.35292526983446, 83.46092993213286, 82.61994238822692, 76.76790729645761, 63.67413351612707, 77.23850542499174, 70.2549449859127, 75.708906573634, 71.47932852468183, 66.23914395609211, 66.16538770737188, 66.2352058964391, 61.91582518239176, 67.26947999769642, 67.90079332167103, 72.94799727778282, 67.64765924023044, 69.042430539285, 67.93174082233061, 70.97595507098784, 72.31815092025265, 72.62996365947109, 71.10017653434508, 67.3783100804975, 50.0929150273723, 22.37016550956234, 10.398335706803108, 1.4534741039237669, 0.06484823196285194, 0.04010138950581032, 0.10001536023112075, 0.06199907053322081, 0.02975626266561449, 0.040325244227724696, 0.03956104087973795, 0.024419872300519098, 0.030543335653360815, 0.05389363812883535, 0.07051819424715734, 0.07327300045759448, 0.03960853450060372, 0.01968157252356891, 0.010043737317074933, 0.009897583062880704, 0.06615977448922011, 0.042819258786978266, 0.03609643505525685, 0.010394993418407057, 0.1188940343056475, 0.049180021704805475, 0.03803376033301315, 0.0842421308099743, 0.011737602725324613, 0.08148434451751171, 0.003397271244583892, 0.03790178636629735, 0.028763629135585604, 0.06854436104936946, 0.07300061789611656, 0.03899479465138528, 0.03802855859600729, 0.01714123837319353, 0.01387498516123742, 0.01987673150705955, 0.028995144736742782, 0.05869600583889312, 0.01656568226134104, 0.06771213675458586, 0.015722232863246914, 0.03540773733308719, 0.050954572450850284, 0.03772867730848732, 0.04972404372247477, 0.07211418521981086, 0.025789920961664572, 0.09027489701346045, 0.03659834521972845, 0.025188444264894052, 0.03661611845957176, 0.033018994745948625, 0.022168981489695372, 0.09550468049823277, 0.015251510138172778, 0.051138016034758864, 0.02738000348120207, 0.04201925231985027, 0.049455430313584306, 0.052512220722893556, 0.004245324112895516, 0.038462482287638614, 0.002299048534158858, 0.04327554841555896, 0.03474998190217922, 0.037083255893160263, 0.08093999308203498, 0.040262509287605365, 0.04127560311087197, 0.009563902933751384, 0.04501376361135514, 0.03004167829790423, 0.07301625375065111, 0.07109101350990034, 0.06130594482284881, 0.043665640386602575, 0.027679980529712576, 0.007457686391013164, 0.06050318810007265, 0.024121911978469263, 0.019875323820498683, 0.05355765877832329, 0.06700331390264534, 0.0191101111516717, 0.04365774968098249, 0.011976706427371791, 0.033288699830131184, 0.04224869182273265, 0.019909504748460267, 0.07963100162845466, 0.023910370204717885, 0.030828036908661167, 0.04033033488198154, 0.013280360163339685, 0.05804271287014408, 0.006997272815375079, 0.03303248172385558, 0.032355884360449935, 0.02321720810516948, 0.047503116525589466, 0.02331349578115248, 0.01825499423449078, 0.05431214047055091, 0.02278190928571407, 0.0306925063787569, 0.04094454587527341, 0.029907572691539125, 0.05782625089669901, 0.05542428563198736, 0.016513297169078744, 0.05303909386237783, 0.0254400524370853, 0.020456480035077662, 0.031984337462833336, 0.03620532296237446, 0.06416668950189507, 0.07337436155085603, 0.060046178348843134, 0.004899407588621421, 0.048053347685885046, 0.07210519134757981, 0.05131171881071022, 0.04116032986090549, 0.011763494581945482, 0.007896579120443354, 0.05410407099031633, 0.08969617121282125, 0.10760992690319977, 0.1320838696894146, 0.8988170085414764, 0.911469471550757, 5.236401932854807, 5.5891622554871345, 8.431566146112258, 9.2766898293649, 17.251690126234486, 16.264016724401905, 24.860531283963113, 35.8044304386262, 38.825934163985714, 55.11096400599326, 67.12093983927082, 73.82288978945824, 89.96108178169497, 93.89890609248992, 99.05196697481217, 100.7011902716852, 97.51768481346869, 99.64971265485211, 93.67124388294836, 96.31811418840962, 85.21593955255325, 75.40323626610541, 86.95504788429507, 78.72094954213789, 85.61624096285912, 83.19110224323889, 76.53800149117747, 75.48855566209363, 76.10777239645682, 71.95471194482619, 74.908139013475, 78.23588571240826, 84.34901729706796, 76.57553857372653, 79.31197227970247, 80.17195193998276, 79.11431620197912, 84.87668591160929, 82.41316287748276, 82.44617354485297, 81.69375311943793, 65.56042878858506, 33.045980468873054, 13.161850437041252, 2.260291797499503, 0.18239186776261176, 0.04843079154529879, 0.01666763898796372, 0.0564412520297112, 0.008889300271778578, 0.0504835011557706, 0.06601008090881572, 0.05742011321408134, 0.023605358043325045, 0.03444507124743635, 0.03811182852293696, 0.059688779179968184, 0.008977583286562755, 0.013533821310697785, 0.039087897316823085, 0.041991408854242296, 0.030479591392401247, 0.06029883414627083, 0.06462854092880603, 0.08392998828522621, 0.03283004682030409, 0.032505279166563865, 0.01731230389146555, 0.06276133950919875, 0.022622271884052504, 0.01973358797840774, 0.02456603613081238, 0.005377764379861014, 0.036420183812057784, 0.04148428163100635, 0.019440756615010962, 0.012159513200693315, 0.009512369156694941, 0.008997917175292969, 0.0629046898815901, 0.03406450557973116, 0.0973601301290816, 0.018300277691695, 0.04213385907332263, 0.0587900354707193, 0.05887158553025896, 0.022400382177663908, 0.005244677191630247, 0.05179108300757024, 0.027818717137579958, 0.05948940862811381, 0.0661731963496535, 0.04105362147393246, 0.042665382366507285, 0.04739292243856096, 0.01725565551990463, 0.02390734990307641, 0.03268868827651585, 0.030416211023205714, 0.025987194347826224, 0.014165964507077251, 0.08392915324938875, 0.09368880696955229, 0.03286756597639572, 0.0382133313424645, 0.02389347988120731, 0.06278128843874702, 0.04642390931445745, 0.04727191885092086, 0.03834142890428344, 0.06500034638109707, 0.04515916709938357, 0.01893172374806337, 0.042925338981853384, 0.12376667526099952, 0.1296640890500238, 0.15893770291680293, 0.11356577021820892, 0.16168949074081837, 0.16257951636948895, 0.09910638158720347, 0.1575386884712404, 0.14091507081062565, 0.22319222439921674, 0.1389843607020955, 0.171911662384387, 0.14902691537093732, 0.1938327014326088, 0.12319077632480091, 0.20799975091170883, 0.11358129115955484, 0.19834264572108948, 0.10753646673214053, 0.14543324288341308, 0.1293065711375206, 0.0656861559517922, 0.11468272641180985, 0.09400006083230819, 0.09079762178683475, 0.14350142960827197, 0.11619246354506862, 0.15053220153335603, 0.15760270277819327, 0.1542020691258292, 0.11308226148567854, 0.07783107805035769, 0.14816065378967794, 0.1934291569576148, 0.21384985877140877, 0.09708303612686935, 0.13768394177238788, 0.16351889338224165, 0.1907103415578604, 0.246213135880328, 0.1090541328754156, 0.17673132069889577, 0.13027941087080588, 0.13241503417732256, 0.15896598688296734, 0.11082060139385924, 0.14341302306181, 0.15509546554136663, 0.13192098407495406, 0.15526832562060128, 0.19680061798182227, 0.1838610252185214, 0.24058790546992134, 0.13451543276108083, 0.09516187913475499, 0.15411560844269492, 0.13907626060949219, 0.22121427730927545, 0.27045211183928675, 0.2274577100310595, 1.0312011693754504, 1.9705689890730766, 7.257869926191146, 10.095006073674849, 12.375933950947179, 14.269952370274453, 24.417887887647076, 24.073550854959798, 37.11894612158499, 47.41676030620452, 51.29951453978016, 68.28158486273982, 78.62735394508609, 86.79070841881537, 104.22784820679696, 106.08139561068629, 109.22290032909764, 115.94484652242353, 110.20871746924617, 113.44491604835757, 106.1551675488872, 106.79200357006442, 98.91717864621071, 87.72213012941423, 101.7619795953074, 95.51514225621378, 100.50630338730352, 94.93665541371992, 88.7556040671564, 88.50889482805806, 86.74640917008924, 83.48571146688154, 87.69803108707552, 89.29558107929846, 95.97540886171403, 87.22639745281589, 92.31031479374056, 91.23576579555389, 92.20470889922112, 96.50576037745323, 94.43554908998551, 94.93980899933847, 92.35269208108225, 76.80549929218908, 39.192012894538145, 16.375445377442144, 3.0114460327932915, 0.3693495889104182, 0.19625851884484294, 0.17293530906881058, 0.25024623640121957, 0.19598206835648707, 0.14887614926743895, 0.18896836487035598, 0.07881301890818343, 0.14658274249203745, 0.1388631962359913, 0.2360798304359759, 0.17557791404185757, 0.1571576363377033, 0.060917159031716094, 0.0952536411463253, 0.12793734985133334, 0.13210585641284145, 0.09147624545280011, 0.1941270017696004, 0.19688018387363804, 0.1770183432006067, 0.12084119998279119, 0.09029035666777242, 0.17332429787324322, 0.13182692379961092, 0.19776218090086214, 0.1302130370130462, 0.24877631285738563, 0.14351506597332417, 0.1676817691975063, 0.13477191899812993, 0.07276589621699626, 0.11461662834570294, 0.10121228834313732, 0.22234968090009308, 0.13791888561700621, 0.20115254897504084, 0.24750767125477716, 0.11889840100681591, 0.16983810752149553, 0.12135227255883718, 0.07777772002643155, 0.09076140114977475, 0.1853799477459923, 0.1298214281879125, 0.1789487928392426, 0.17564001312899977, 0.18750559658773486, 0.13889987652580585, 0.1541689741275003, 0.13657518271957675, 0.1500149849321573, 0.12713179307719394, 0.16165109441405343, 0.0825605601552994, 0.14733295707452684, 0.215491937593587, 0.24921472965469285, 0.08408591782133426, 0.1903147950407959, 0.0806308229784331, 0.17194624359328903, 0.08777046365843666, 0.14358608232390496, 0.11492526218775781, 0.30374941866724725, 0.13233317002173395, 0.11905032390307997, 0.11300557608445806], [0.03585659973924199, 0.021203913718401905, 0.05928898087492394, 0.04664244738617732, 0.11377226155731948, 0.03563040844915855, 0.06229076617126984, 0.012402524908764229, 0.06143558222139555, 0.10201619036736027, 0.012920859040722493, 0.013231558447343209, 0.057284894865006215, 0.051408651915769425, 0.09091671015466414, 0.04059753868909132, 0.08305542231086763, 0.0455157388933003, 0.09677807950685102, 0.04599507627708297, 0.018122761713100538, 0.06862423337635494, 0.04666284830760091, 0.03245216246033388, 0.03954858045964953, 0.18498872196482075, 0.0263157656281105, 0.0278035830706358, 0.02486197398074212, 0.008474483770588714, 0.01907651245053257, 0.07423283967880473, 0.014622634306790368, 0.014254127820623259, 0.07121906510644382, 0.047042138438912175, 0.015191175926086164, 0.057610103019302895, 0.0556561344813916, 0.05846734008481426, 0.060271737616389036, 0.024960785916435625, 0.03600977135882263, 0.0057242827061864164, 0.0188828339319556, 0.008024128929396432, 0.05911520532061977, 0.019087015515974453, 0.03893912687236744, 0.0385972103404422, 0.01452734062988912, 0.013619665293053035, 0.02480451547120127, 0.07540074071937031, 0.020779972152423956, 0.026706608365319913, 0.02472830504449385, 0.18485310908046462, 1.1580127453611744, 4.238746589229954, 5.613536354034178, 19.04147351941755, 29.630921809904038, 25.380023717880253, 37.70464228045556, 42.01901412779286, 47.45010829740956, 49.18116400318761, 60.10980906025056, 59.36176599994783, 67.49088994918331, 75.91817286706741, 80.86168504530384, 74.80008555996802, 75.17521319850799, 71.17276391675396, 70.80912882281889, 44.994892843307994, 57.048834523847034, 61.640310056747936, 45.814793725167554, 39.885993926755845, 40.120806617121545, 29.492783777175415, 44.38883566087292, 38.80424737930298, 43.81334550919072, 42.12829920553392, 44.636764757094845, 50.81150893242129, 42.6084130041061, 49.74384369388704, 53.22582583273611, 47.443608930034024, 47.38207478677073, 55.0580826113301, 50.866429959574056, 41.90872884565785, 54.38798096872146, 52.980046195368615, 62.80974118940292, 63.587790381523874, 75.55558896833851, 79.19688993884672, 70.97895960653983, 40.70867969143776, 22.972486634408277, 12.365150374750938, 1.3110172964872853, 0.6952618086530317, 0.17934780207372483, 0.06578328057883248, 0.0327613938509697, 0.026012346929600163, 0.012626064577019744, 0.06971317373456494, 0.06424011902943735, 0.06469191172190251, 0.014711447837462109, 0.055887673065186515, 0.03728886240071828, 0.012152089808707037, 0.05761034050655942, 0.0416823766464668, 0.024620922500147455, 0.03375649609933457, 0.023581967463776953, 0.0649872692602296, 0.08371504699631084, 0.037616200279444456, 0.03898211972667806, 0.0075056607320514186, 0.05506715076344629, 0.05576708699546515, 0.034707433378864685, 0.028853780447295117, 0.04894680921889601, 0.03457655108744099, 0.06885643462620436, 0.021069930686104684, 0.03448614888193627, 0.03649462457566011, 0.0353780284433836, 0.05276080859344333, 0.07551763041485703, 0.030005739198156425, 0.09701524500644977, 0.06483388313603017, 0.03923762154074446, 0.05395042822666226, 0.059265132557841084, 0.08432546585437753, 0.06471858690342595, 0.07585338376943143, 0.04912074565166428, 0.009729047549978621, 0.02643398448614584, 0.05012745030164238, 0.057991587992517225, 0.04951278731647519, 0.010280643304389332, 0.06740097482238086, 0.013840988094377664, 0.007730158010212285, 0.0710047749922641, 0.0069303885515358665, 0.06318369144273382, 0.07308403721019145, 0.02928258858681206, 0.05563156987209955, 0.04358343915232728, 0.04145296012622215, 0.07099303086438487, 0.04891853291361083, 0.055500565006607966, 0.026278135389269843, 0.08236190589565424, 0.030583568675924214, 0.06022153204427131, 0.014436485474899173, 0.03955327274818574, 0.05136252193140888, 0.04173796781669221, 0.013757037306805293, 0.009967161083383667, 0.06466878352746849, 0.05433589685708285, 0.04235546915761886, 0.06173726381553758, 0.1019189048618559, 0.14857660888904525, 0.02990435703747696, 0.02148451831852717, 0.04711320075476843, 0.011219019614790958, 0.04582623432901117, 0.05705755061259674, 0.032928366544506246, 0.05094000528897009, 0.03739213488335091, 0.02518469234928489, 0.0748459245228479, 0.10240575373773614, 0.03439838967977032, 0.04245432897380764, 0.053258133721688104, 0.05521740741847504, 0.025463337679543806, 0.06570762173543054, 0.01701878496415673, 0.030294964202649655, 0.015542653235306424, 0.028643418448947133, 0.03872976270354083, 0.037159734450641184, 0.037781705914606015, 0.02366523739070662, 0.05388533756617577, 0.04621544529894187, 0.024618871299730196, 0.031759871785799344, 0.06110951221818405, 0.007946841670350443, 0.05740902409137738, 0.049169909344204975, 0.023946324626224178, 0.03208542467966195, 0.04296954225508436, 0.013783838892836246, 0.04216308149719431, 0.040447232238347494, 0.059117695106373686, 0.04409163123777798, 0.2544078251887714, 1.5240616904151056, 5.557629341079343, 8.211375561452682, 22.67846968866164, 33.708256982987926, 30.414256395832187, 42.76338977198447, 45.790741751270915, 54.74019412071475, 54.3881731648599, 70.1799649576987, 67.53932337607107, 78.36795191611014, 86.27232013210174, 88.54909127758395, 86.90152322092365, 84.41594077694802, 83.09589062967609, 79.90550533417733, 58.320396331048784, 73.42109003374654, 76.86756687779581, 57.451285393007346, 48.81632474160964, 52.023909630314, 38.17378520965576, 57.217398382002315, 50.22908403027443, 55.24665447973437, 53.18810439878895, 52.705221406875125, 58.85193240258002, 50.328343529855054, 62.24109165130123, 62.85579373759609, 56.72630194694766, 56.564374739123934, 62.960058181516594, 64.54390341235747, 49.295022564549605, 62.25485132586572, 64.74198310605942, 71.8364917078326, 71.96059550008466, 84.8751954109438, 88.5803133441556, 86.50959214856549, 54.054246102609945, 30.498759938824563, 16.923783902199037, 2.7350027763074447, 0.9309582580481807, 0.2843742583307528, 0.07421266858375843, 0.05098225503799416, 0.05560357318890672, 0.05038515844893071, 0.05997896562480639, 0.0396416601424496, 0.05753804478914507, 0.016731565194805304, 0.022607089936613076, 0.008848975318664265, 0.011670629403764203, 0.05468524061143399, 0.10167783231384332, 0.010396108076336884, 0.04705203246445425, 0.02786171956798963, 0.032218524795626445, 0.03968655289481244, 0.030520109782716444, 0.018247356337885705, 0.06624933016756851, 0.011549344278811928, 0.012411680617069286, 0.00352585383581989, 0.01354936044663191, 0.023060470346301314, 0.05088256018596792, 0.054569427269480886, 0.021329850912274375, 0.03264428965086418, 0.023384393388105017, 0.0028871072009356035, 0.028850597351969733, 0.05174029903906969, 0.14776843209420482, 0.060741648288263436, 0.028019271295277343, 0.010483550309624163, 0.026235046773968686, 0.029415018375842806, 0.06874557404268174, 0.11550597981700014, 0.0726147623912942, 0.033042957976220116, 0.011020650722897582, 0.01989159169757078, 0.036491839846055356, 0.03824631142760477, 0.1108355554301412, 0.037381965066156084, 0.02599296298989606, 0.02455844228426295, 0.03487038794123838, 0.061807751565450625, 0.09733023737827617, 0.021572597362401507, 0.033478191678201964, 0.0956218766288892, 0.06617529543056604, 0.07001875854668117, 0.03449450307075055, 0.06152820225144106, 0.009721366560927803, 0.05651606434595682, 0.04692419537252957, 0.2257222450909115, 0.11611747885904006, 0.1689673106997244, 0.2014324008937805, 0.22047498714058633, 0.1497632944055142, 0.13696282320926267, 0.17565758718598276, 0.19877153238461864, 0.20180039888908788, 0.0939271675663129, 0.0888399224007322, 0.124699387308811, 0.2636934390231486, 0.1799720718014625, 0.2743112031490572, 0.17318024269996152, 0.21044966945004082, 0.20181077171958264, 0.15735151786958018, 0.13177702083222328, 0.1746172244630514, 0.11275547135981823, 0.15288387695627828, 0.15349572073788414, 0.29088395257149974, 0.18781862011359585, 0.08733145697342773, 0.04800153715956596, 0.17615863933197914, 0.17619188754789292, 0.1282580112737994, 0.13420144396443523, 0.06067324812794405, 0.10358736009126711, 0.1279074877440449, 0.1318304478040626, 0.139000846914226, 0.13082463564651628, 0.27416298045746745, 0.20470336650408086, 0.179409901160867, 0.10459079737624816, 0.1043585348393648, 0.09558865139561315, 0.139004600745055, 0.16898198894435362, 0.10387324878285009, 0.17674579976066468, 0.19355695574514328, 0.08871509603434995, 0.1317003660745198, 0.11771904695178233, 0.15573671177750634, 0.09886728554603555, 0.12698114954776343, 0.19881110848678699, 0.3397681455939047, 2.2946399930984747, 7.573124054939517, 13.266552225235971, 30.347176021145238, 41.52812557835733, 39.971038756832, 54.181464256778845, 58.36867286312965, 68.34382503263413, 68.7508572301557, 82.00584042456843, 84.09256489046159, 91.16791663631317, 100.92823274673955, 104.02513227155133, 99.47435917392855, 94.81241041614165, 96.30466830345893, 93.22956146732454, 72.13379167741346, 81.82352865895918, 89.01710064180436, 67.89156790702575, 62.02265877877513, 60.05458208822436, 47.24893385364164, 67.41154040059736, 59.72283586379021, 64.59168572579661, 60.39267470759731, 62.27480442293229, 70.94135192132765, 61.310866263604936, 69.65996065447408, 74.20823912466727, 68.3165410257155, 66.69060876292568, 77.65244883875694, 72.4532530384679, 59.766287880559126, 76.23707725155738, 74.36219215393066, 84.59243958996188, 85.73912097561745, 95.35765909379529, 99.99985479539441, 98.3102075515255, 62.712301669582246, 37.0571844808517, 20.341386218224805, 4.506927372947816, 1.351261795047791, 0.3767472096989232, 0.19945158863500242, 0.11652540535696092, 0.09755742841310079, 0.13175466638659278, 0.14538833480929175, 0.12540235724901, 0.15073446406712457, 0.14987529646004402, 0.17129077876527465, 0.08419903836423352, 0.13375240918849746, 0.21333274942251945, 0.23915001972308084, 0.0910990237588844, 0.11131017754274992, 0.08340561642281472, 0.18384605586048097, 0.12466256146229084, 0.09863084016908562, 0.20873755486982487, 0.12134050544832023, 0.08196201566005908, 0.11093186800398173, 0.12218685640442757, 0.10998502163396728, 0.13193670419916032, 0.09342813023155735, 0.1516836316835496, 0.1254779701271365, 0.21174464915548602, 0.16714920019430501, 0.142617164960792, 0.18171129057243948, 0.1417328390262781, 0.2914681099355221, 0.20335692101188246, 0.12909355272929515, 0.2312175163458432, 0.18937748646543873, 0.1893251473384519, 0.21008732518361461, 0.19768661398801113, 0.18361947769599576, 0.19151133244797108, 0.11338177122055523, 0.12944949250067436, 0.19944276330211472, 0.13622030014953307, 0.2170748437844938, 0.11714842636138202, 0.13746350763305543, 0.0952813275639088, 0.10153663464851918, 0.25691377539788524, 0.1568431112795107, 0.16686545654891, 0.10206140487665132, 0.1511738308134579, 0.12419755375313184, 0.14653993349882866, 0.1671998692496169, 0.18695549949282603, 0.16063510860887267, 0.17425682605995288, 0.16200925584041304], [0.03951055185508825, 0.028611355754096183, 0.058506081151145126, 0.025359674492069793, 0.05919693924126126, 0.022415579446861823, 0.035532104046714884, 0.03276600570027386, 0.05710660705282804, 0.06295240949839354, 0.020989049038278963, 0.051179312004317204, 0.06345343866175221, 0.052146011542889385, 0.015567214971768762, 0.0449779260182573, 0.022689873397710825, 0.04223422808272224, 0.057485992945129835, 0.030243199641606024, 0.0380821809202673, 0.11977336534689512, 0.07398717826412571, 0.03432962179724728, 0.029344597658623132, 0.0718988149216579, 0.05041157316055991, 0.04267174472671844, 0.012499841057785578, 0.011013097095964177, 0.07414679268314954, 0.01947262587266103, 0.04367973257396971, 0.02643130126319105, 0.003353760323314477, 0.057914186299087546, 0.04854771188430248, 0.02545081405720163, 0.0419117663536341, 0.003087974736474515, 0.06668013205090839, 0.0964294558751487, 0.011148726259688697, 0.056518960158310594, 0.03402633907934351, 0.04884130742040373, 0.08490727898935158, 0.05021104198550025, 0.04257040661609462, 0.018737353835134737, 0.0325314142561007, 0.10621715607422014, 0.07221042118485897, 0.08193045283757872, 0.044795413231176716, 0.2611710485671797, 3.489235091593958, 11.636989808851673, 26.06170419723757, 33.34116235856087, 46.483114611717966, 57.947178886782744, 67.06689742303664, 63.74153944753832, 70.4697653555101, 63.670438643424745, 70.89938256048387, 71.92585898983863, 73.6975622177124, 69.78003225018902, 71.82395581276187, 68.6487893135317, 58.52544215417678, 50.6440511826546, 46.05756098224271, 43.07057411439958, 40.140594974640884, 28.458115477715772, 39.0632846278529, 45.49774854413925, 66.03473355693203, 44.205178522294574, 16.833255598621985, 15.644442073760496, 11.350093926152876, 16.598515472104474, 20.556577251803493, 18.68412010131344, 16.142921390071994, 23.818326150217366, 20.961410960843487, 18.300296568101455, 26.204148992415398, 29.995780683332878, 30.85410510340045, 28.16867789914531, 25.87491112370645, 32.579057601190385, 36.10523700714111, 29.640892474882065, 35.680440395109116, 45.428389272382184, 52.39939028216947, 59.96910579742924, 70.07945814440328, 76.06206893920898, 64.73103184853831, 54.72072347517937, 36.71368291301113, 21.597562528425648, 11.290908302030257, 3.861387122061945, 1.0910575187975362, 0.31282759121348785, 0.0638282050438706, 0.045011258503842744, 0.01575133654349033, 0.034836637937734206, 0.04847782551341, 0.06166889429873517, 0.1010610012998504, 0.06215183229576196, 0.03067811158665967, 0.028173879329716007, 0.04219366372713158, 0.0818420922563922, 0.038208033844468095, 0.08270767968027823, 0.009957577323450918, 0.08303896674225408, 0.10987445216385588, 0.03609042126505125, 0.06279688215844574, 0.013428214175115912, 0.011120946953944381, 0.050421624234126466, 0.07337373335875812, 0.051496790331457896, 0.08347002909548822, 0.015410225361495491, 0.03735491067111012, 0.04251858076801704, 0.08413829525271732, 0.07011249706509613, 0.07414920586011103, 0.04092262426932012, 0.027814836902243477, 0.031864532802794734, 0.1223490295571185, 0.039655556977396055, 0.026733270140304684, 0.21451768825852105, 0.017666092870997328, 0.0758765196247447, 0.06089583114390412, 0.0416991654633274, 0.029675781298729203, 0.1011083378726917, 0.03993095792529564, 0.046716914962857, 0.017621269066547676, 0.04106344272112174, 0.05792034181555914, 0.02098920991674306, 0.03296286731417621, 0.06414145456566926, 0.03459291472550362, 0.028005347647253546, 0.02522342766995632, 0.04052822305370243, 0.07247051569603144, 0.017092252796095227, 0.030354190460075776, 0.05199962363187825, 0.014473159061444384, 0.04301283005324583, 0.04774246920621203, 0.07285409591971867, 0.015819533690509778, 0.049152676196348284, 0.021373667311103597, 0.023642942316890247, 0.06154731614515186, 0.06018844470682164, 0.035609812175314275, 0.03827692813149864, 0.016356461734000235, 0.1048709863736745, 0.020225330240904324, 0.051364659316717624, 0.027657861656118787, 0.07228120004818325, 0.009270555418615621, 0.036746311271863605, 0.06473705728328036, 0.033117076982894254, 0.021676145636686878, 0.048321608694330345, 0.046354620492145907, 0.08400573905917906, 0.04514176924262316, 0.05441844666136369, 0.050568854841854305, 0.033732046403231165, 0.00553528642124166, 0.016406826269362244, 0.0506329266054015, 0.025457927183578574, 0.04149630921141755, 0.011486556670147807, 0.018402119505129034, 0.010001825604347453, 0.031041319617220474, 0.03135657628938075, 0.03739071762069099, 0.07836696421427113, 0.03391701833254868, 0.04802427081871898, 0.01234036070414849, 0.0686530382823079, 0.048738019616012616, 0.09985547002044418, 0.024759839138677044, 0.04300046922458757, 0.04402512714507119, 0.017510615326764605, 0.01810855844298438, 0.10510337914550498, 0.029843828430579557, 0.05205930571161932, 0.017244857510611895, 0.7151329649552223, 5.377032141531668, 16.937308234553186, 33.06818108404837, 42.60118799824869, 53.30528913005706, 68.33328954635128, 74.89845860388972, 71.52611455609723, 77.87141907599666, 75.11218855457922, 80.93681412358438, 82.68449675652289, 83.43014717102051, 82.33113827243929, 84.05887957542174, 79.91675469183153, 70.17444226049608, 62.97698320881013, 59.47063530645063, 57.021934909205285, 50.008203598760794, 35.591939956911155, 43.795592861790816, 57.600225633190526, 73.16043284631544, 55.21056082940871, 25.03862846282221, 27.294864039267264, 27.31517799438969, 30.737102762345348, 31.156406094951016, 35.41955571020804, 30.075893132917344, 34.3463913086922, 32.180348673174464, 26.864201522642567, 37.67896644530758, 35.422234689035726, 36.72911351726901, 39.01343522533294, 38.500463731827274, 42.0529975429658, 48.74406683829523, 40.5162246765629, 48.843012548262074, 56.0601265968815, 63.11955744220365, 69.04761591265279, 79.06660449120307, 88.5955713641259, 78.9682863604638, 66.92999101454213, 47.1426336996017, 28.11276451233895, 14.203070075281206, 5.539260391266116, 1.4823444644289634, 0.2911781916214574, 0.13331708738640433, 0.027200895954944918, 0.01802642615662227, 0.06797045394177399, 0.06917489737632775, 0.02901507642931275, 0.02867069500949114, 0.08529409976495851, 0.048195663839578635, 0.04327503130621007, 0.02079006536082635, 0.036982687700900345, 0.03582343196256026, 0.06789018324906788, 0.01694888710194538, 0.022662311469415025, 0.09049576782290975, 0.03815610074408112, 0.027617176641680063, 0.06573631938907408, 0.04697625487742405, 0.05953379576244663, 0.04054698071652844, 0.08357834626710223, 0.06748640128681738, 0.019926425715487812, 0.026516570679603085, 0.03457304240474778, 0.06013067018601203, 0.042331624670975634, 0.10489889495675603, 0.014460839410012048, 0.04915035494993772, 0.06067786380768784, 0.04214803936080106, 0.0805725849744293, 0.019803108542316386, 0.14077902891703192, 0.016964748952417605, 0.0494636619283307, 0.07234461680655518, 0.018752263821361047, 0.024911951641702366, 0.05182811569782996, 0.006898520730300657, 0.019858014063849565, 0.023350545708390496, 0.022762776239805167, 0.017526597836084904, 0.04298419368663623, 0.03329834487709788, 0.045871636529843655, 0.025858976127159213, 0.05161154647207549, 0.0462196204781292, 0.10561899462294196, 0.03456971375271678, 0.021214610221044674, 0.018132966004251953, 0.07880194127679833, 0.035703585167685827, 0.08593356101623467, 0.12737596062042061, 0.117210992762158, 0.24056141414949972, 0.18933320658341532, 0.10320615474014513, 0.10845679113821638, 0.16530845945160236, 0.214315977308058, 0.1622578207283251, 0.11073980976136462, 0.047221598365614494, 0.20855734034651713, 0.12418708133120691, 0.09195670515539185, 0.21850413402482388, 0.23834424844432264, 0.06324872081618636, 0.11164557083599991, 0.15705714092379616, 0.17667489066239328, 0.14866725241224613, 0.20753910224283897, 0.15445222747662377, 0.19453175666351474, 0.17912670909877748, 0.15914313705457797, 0.16467815295102137, 0.1714750229110641, 0.13411473813316516, 0.12383766862894259, 0.20274569010061605, 0.08135247780310531, 0.1057708638930513, 0.0789448090137974, 0.11948821209971944, 0.2063134688162996, 0.1734206717341177, 0.24061242028349833, 0.10134127456694843, 0.23007155606342902, 0.19273206291179504, 0.18147620883199478, 0.0928159417103856, 0.1773102839867915, 0.17861727595088944, 0.17763910424565116, 0.15088737521681095, 0.15887594090834742, 0.1667850786038945, 0.16729448110826556, 0.18015922708136423, 0.23702697558028085, 0.13723509085755195, 0.17644857296780234, 0.13845664869633414, 1.1708081297336088, 7.970631266793898, 25.416362516341675, 47.46391896278628, 57.99434538810485, 71.25194088105233, 81.61044197697794, 86.91579280361053, 86.1955907267909, 92.94351870013823, 85.12809415017405, 92.65090988528345, 92.60058587597263, 93.94045968209544, 89.36273205664851, 94.62072418582056, 89.27548285453551, 78.5130403887841, 69.4086543975338, 65.48109100710961, 63.73318872144146, 61.08714995845672, 48.27850895543253, 58.816391806448664, 64.8137624802128, 81.32734098742085, 63.65338417791552, 30.294320121888195, 29.544572791745587, 27.29438747129133, 32.54065367483324, 35.765496992295795, 34.395550374061834, 30.571578741073612, 39.21653555285546, 36.65406680876209, 33.3994330898408, 42.46396780014038, 45.857704454852694, 47.23511142115439, 47.8496644573827, 42.30262502547234, 50.80657851311469, 54.087476422709805, 48.82680923708024, 53.592300722675944, 67.25881115082773, 73.57068923211867, 81.33791569740542, 90.799817885122, 101.2937270441363, 89.6409849966726, 77.99587588156425, 56.54328415470739, 36.31125165570167, 19.275866516174812, 8.160176373297169, 2.418901905898125, 0.6406111186069827, 0.2385013577558341, 0.15748965884408644, 0.1261934885875352, 0.13888478459369752, 0.19373842665264684, 0.16097448555932892, 0.15808805012174193, 0.2571438162797882, 0.19668032685595174, 0.20177668080695216, 0.12615145334312994, 0.11678497892834487, 0.11274438606755388, 0.19844326370906448, 0.11345441167753552, 0.2338256473622976, 0.17433519685460677, 0.11888278047403983, 0.10869318288901161, 0.19119483088293385, 0.12934142813807534, 0.13921561200291882, 0.12596099622427456, 0.1587416150517041, 0.1538590455968534, 0.08668834148275276, 0.14688828899975748, 0.14749804902220928, 0.1302511422263999, 0.1749374492154006, 0.24139974416503984, 0.09953772739296961, 0.2458460418687713, 0.28035349182544217, 0.2384335130092598, 0.11801654187541817, 0.13003104516575414, 0.30982912307785404, 0.08171129040420055, 0.26887381749768413, 0.26352873011942834, 0.18575458006272394, 0.09360465987194931, 0.16215419967568692, 0.1921334264860038, 0.09632961929685648, 0.15857258541209085, 0.13218068788128515, 0.12489553646094377, 0.1725832763458452, 0.11866036982786272, 0.171974481594178, 0.18254362978041175, 0.12002733881555258, 0.17620327161444774, 0.22543817968858829, 0.14964784495532513, 0.1668655791229779, 0.09922483410205572, 0.19597250757919205, 0.13630479964758122, 0.24249515796621002], [0.04183240347511826, 0.06358581482462826, 0.003404462416168122, 0.1002432177624395, 0.02266364063196365, 0.08747303768271401, 0.05604138094631415, 0.07310417000084155, 0.02128739623473056, 0.027961590620238456, 0.03516338592875869, 0.04788827872084034, 0.036516197611607855, 0.04284950393822886, 0.02105940080758545, 0.021051385612677664, 0.06324549941646476, 0.03375242817245665, 0.09161470052335532, 0.0578863658161173, 0.04278446690389707, 0.04648092923866165, 0.05814309337086255, 0.04631162380739566, 0.017043678991256223, 0.058533993564666285, 0.033989559198098804, 0.07722605245127794, 0.024489818043225718, 0.04763267348490415, 0.06305675067368054, 0.041232345956227476, 0.0038956085664986245, 0.023556841695080363, 0.05496754018109172, 0.009652801691704701, 0.03422036616792602, 0.00884553462627434, 0.0706501605529939, 0.02562267056125547, 0.03379116540834789, 0.025301348387954697, 0.06883721348018416, 0.05107605484344306, 0.0387057573384335, 0.021207163846420667, 0.03328922460035932, 0.0702435517263028, 0.12405015077562102, 0.09308503009378911, 0.04189675486075782, 0.03471902811959867, 0.08830431968935075, 0.21238301490103045, 2.78251959431556, 19.681184637931086, 39.97569461022654, 56.77173868302376, 69.79660818653723, 68.86895979604414, 72.90955020535377, 67.52127262853807, 73.41332374080535, 64.55729046175557, 62.53033507254816, 68.27961583291331, 59.88555146801857, 56.361792164464156, 55.46111006890574, 38.3297033463755, 32.91564010804699, 33.54618464746783, 20.52627301985218, 21.662775854910574, 22.73034303419052, 17.544628420183738, 22.46241573364504, 31.21903850186256, 52.50366257083032, 42.64495772700156, 84.48605706614833, 44.01636738930979, 12.133693272067655, 19.97679602715277, 17.140410523260794, 15.319878689704405, 18.39606123585855, 14.463715495601779, 19.276488211847123, 17.34018271969211, 16.751540860822125, 25.157905778577252, 20.51164650147961, 25.25471771917036, 20.97058734586162, 19.031096889126687, 18.14831256866455, 20.506096347685784, 16.16210864436242, 21.24915015312933, 18.64443552109503, 29.19057692250898, 30.55126870832136, 31.980888305171845, 44.1185059085969, 56.791115191675004, 59.731029695080174, 65.27323284456807, 67.14707066935878, 56.53316443966281, 42.55536686989569, 31.036348227531683, 11.390285472716055, 4.303535809439998, 3.0689872032211674, 0.6571728976503496, 0.1100685328785931, 0.024495086812924956, 0.030032745712707122, 0.0958520171022223, 0.05679400104488577, 0.05160685801397889, 0.05059624248514733, 0.03262774981257897, 0.014371501109112176, 0.04255867014909464, 0.007652794621178821, 0.03169032057837373, 0.022832589832344846, 0.03013294618276339, 0.045584736602200616, 0.037516681627640804, 0.016513431234465494, 0.043583071430123625, 0.03291895515435646, 0.041375412876086856, 0.06909048214795128, 0.03989666782980485, 0.03023409468662595, 0.027511100277244568, 0.044460337864415306, 0.05259558258037414, 0.06858075022577279, 0.03322835125389599, 0.04976827763922272, 0.005884885378632575, 0.06301283851386079, 0.035040551390979564, 0.04018364053580069, 0.06850838556044525, 0.04376677165348684, 0.02234296963339852, 0.07064084492383466, 0.06157072396167825, 0.08951312982507291, 0.07155582203619903, 0.022751639236605937, 0.06650675103188523, 0.06594362278138438, 0.04597572489611564, 0.03477204906483812, 0.037678406618896036, 0.007077009161754001, 0.050343475604970614, 0.06097220244907564, 0.008025505972440325, 0.08135440068379526, 0.018134281760261908, 0.029487321754136396, 0.028227742971672166, 0.056445070978013746, 0.04871563452686514, 0.07385730337832244, 0.029021597752768188, 0.05673547575791037, 0.07036277798995857, 0.07329345500517277, 0.10257394834151191, 0.04729774750528797, 0.05128022876658267, 0.038804295397694075, 0.09122945022799316, 0.07347807453404512, 0.08874183250290733, 0.04321584718361978, 0.02310956892136845, 0.02281504833409863, 0.04303446054578789, 0.07292922616245286, 0.023511376291994127, 0.013244466071257429, 0.036243497123641354, 0.0026090709105764907, 0.07418260729360966, 0.005509266244893473, 0.061584758692451065, 0.02644488208686873, 0.06636060443857024, 0.04092532089881359, 0.12024704517135698, 0.037943139792450016, 0.028748987280132792, 0.035867811436013836, 0.08756221031710025, 0.07782614444412532, 0.04684304367871054, 0.095584039546309, 0.033239145432749105, 0.03674767490836882, 0.05143207122361468, 0.04255433792188283, 0.02607674428051518, 0.03416904210743885, 0.07313278338481342, 0.017097896948877363, 0.0172690907868767, 0.048645782629929246, 0.0275553839897076, 0.013863655678447218, 0.032049405140682094, 0.04676415194426814, 0.0079053838647181, 0.03302837549258144, 0.05433219282196895, 0.11774696319574311, 0.08709963110666122, 0.03485576715320349, 0.09531908803769658, 0.12233404487731958, 0.44439075094076896, 5.206742930796839, 26.394746765013664, 48.75475137464462, 66.31070367751583, 79.86190426734187, 78.03192246344783, 83.87876433710899, 78.13439046182941, 82.1102382290748, 76.0728083887408, 73.00274572064801, 75.48484509991061, 68.78429935824487, 64.08684530565816, 65.76381937150033, 50.22355348833146, 46.215765860772905, 46.052924740699034, 32.32536654318533, 34.07470441633655, 35.72819917432724, 26.617260863704068, 34.86485019806893, 37.96000426815402, 54.98946074516543, 48.55070575591057, 83.91785467824629, 45.45832087916713, 17.275985287081813, 24.771416994833178, 17.767783826397313, 22.661942781940585, 28.571399411847516, 22.567472496340354, 26.37118704857365, 30.249301118235437, 26.523347554668305, 27.454133841299242, 27.265914986210486, 35.90455285964474, 29.72596476154943, 31.586160582880822, 23.607853727955973, 29.270656031946984, 30.500515199476677, 33.368450287849676, 32.0518361368487, 42.18991571857084, 41.82055004181401, 42.369501436910326, 54.1338231486659, 65.1052769537895, 69.43430669846074, 75.32303948556223, 77.49967252054523, 67.23151929916875, 52.97593162905786, 39.152757813853604, 15.331523226153466, 4.716072072905879, 3.5078023662490234, 0.7262886760215606, 0.22634792442042984, 0.04749683843504998, 0.12091673625212525, 0.07610498236552363, 0.040278329003241756, 0.09602585011312077, 0.05370074101994115, 0.02898172287630939, 0.05698669897091966, 0.03521433460616297, 0.08253314186848941, 0.028586348729027856, 0.02929782416040619, 0.02386457921426383, 0.027981851730615865, 0.030511475971809802, 0.01381400935051422, 0.07303660870679925, 0.01631214546280042, 0.04265804324419268, 0.041186955246713855, 0.042046076888518955, 0.03857349991918572, 0.009756671722918268, 0.04489285961514519, 0.05780248684928783, 0.06558387555302152, 0.11358257818726764, 0.03383957067384355, 0.08558234800734828, 0.08167492421043497, 0.016104066406466788, 0.05576545139774681, 0.06730982568114996, 0.06123598567360352, 0.029786201381695368, 0.04899238761995108, 0.0494475357775246, 0.022960470974325173, 0.01775523294664679, 0.06810725426241275, 0.009308064998608203, 0.03982731772045936, 0.010402171662257565, 0.040899465431369124, 0.07217491300956858, 0.041929838367767876, 0.03202491714018247, 0.06510611247992323, 0.022376311695083015, 0.03898117360809157, 0.04248073985499721, 0.08048391795807308, 0.05171902477741242, 0.03039978801332895, 0.021174607024858558, 0.03582419422004492, 0.04768862471645398, 0.05136152601710731, 0.07101186130556368, 0.1845075268178217, 0.1860575218715014, 0.2357735331620901, 0.21139966444142405, 0.1400611126014302, 0.25774501143924655, 0.16424868406066973, 0.18442722548159862, 0.15137063880120555, 0.09934790612709138, 0.15084744671419745, 0.1037580981069515, 0.14568274239859275, 0.12183094727656535, 0.11533499665317998, 0.2143619732270318, 0.19494509174218103, 0.20498240636962078, 0.1197977729081627, 0.12670740334978028, 0.11055375764807386, 0.11221067559334541, 0.20392223261296752, 0.1770832002042763, 0.17303658589240045, 0.17427642258905596, 0.12108894515662424, 0.19701463230434926, 0.13720519810674653, 0.12140045182839518, 0.3210825869633306, 0.0896737554801568, 0.11491373256449738, 0.22587472723136026, 0.22956416070941957, 0.131643169950093, 0.1438568024745872, 0.1445170323694906, 0.18184333348706846, 0.1120267072392087, 0.16355137551023116, 0.1382431093483202, 0.2282788030683033, 0.12753267922709066, 0.14712975991349067, 0.11695458313390134, 0.10678142579572816, 0.2113119933393694, 0.31820488492808036, 0.16366585968963562, 0.21191576255425332, 0.1361360304778622, 0.22471752077821763, 0.8450513645525902, 7.775395781763139, 33.77657682664933, 61.47098525877922, 79.4487767065725, 91.66807374646588, 89.48300761561241, 93.65026704726681, 87.77017131928476, 91.55717265221381, 83.88397324469783, 83.2268742592104, 86.66152123481997, 78.15221371189241, 75.77362568147721, 75.90711178318148, 57.06540653782507, 50.90331985104469, 50.905222200578265, 35.797338793354655, 36.41263315754552, 36.5018121657833, 30.401138028790875, 39.73015815980973, 48.53091739839124, 73.88003872286889, 60.58192122367121, 97.57362565686627, 54.47596757642685, 29.802996189363544, 37.263901233673096, 28.56453722523105, 26.978491544723514, 29.29256835291463, 23.625518122027, 31.963941704842355, 28.934844270829235, 26.90284275239514, 39.52134686131632, 35.68021289763912, 38.868507569836034, 36.78871785440753, 32.040714256225094, 29.315959407437234, 33.85563611984253, 26.61650972981607, 36.77420900714013, 32.20365539673836, 45.517827157051336, 46.28936521468624, 50.72453037385018, 64.56735526361774, 77.61222885501, 80.73952674865723, 88.30404512343868, 87.37724396490282, 78.11545325863746, 61.55922682054582, 46.06321311766102, 20.935552735482496, 7.64907536006743, 4.67158111833757, 1.4314915480152255, 0.5038929532372183, 0.22295308239277334, 0.24059846216151792, 0.19598983648803928, 0.20354188528032074, 0.20533333592597516, 0.13864913594818887, 0.11845764764133962, 0.16494786186564356, 0.1324765203941253, 0.20196961238980296, 0.22775654560856282, 0.15417819782610864, 0.14006912588111817, 0.11470107421759637, 0.12213359031105235, 0.11782259139562808, 0.16150241206970908, 0.11711619704240754, 0.1798050339904524, 0.15653754945003218, 0.1246041549189437, 0.1170469273722941, 0.10856369104717048, 0.13555521325718972, 0.15813403071895724, 0.1626943376275801, 0.15309741630429222, 0.23435090788670127, 0.11222805812834732, 0.25792176324513655, 0.1680502728108437, 0.18458133172844687, 0.13399507519939255, 0.13425050423510615, 0.06740606164619808, 0.3073605426376866, 0.2308623273406298, 0.164049822957285, 0.14948903492862178, 0.17379755634934674, 0.1736446911649358, 0.17222825587997515, 0.11199566535651685, 0.16556600288998696, 0.18257893111196258, 0.1952109702171818, 0.11835060983655915, 0.16169054794215387, 0.07656651203550639, 0.14979461207985878, 0.1076821996379764, 0.2088127693822307, 0.31156440415690023, 0.18003444668025742, 0.20863972544189424, 0.15330510274056466, 0.12082887362808951, 0.23533422770279072, 0.14186362555671123], [0.03077910112727794, 0.019523699039353, 0.04820595623084134, 0.011249409365137259, 0.02613328348454689, 0.0029322175701494303, 0.0161441940919406, 0.024454329020133423, 0.12599622094703297, 0.06797138090816236, 0.060921525732884486, 0.07524121823089738, 0.09098864581075408, 0.05921356717965776, 0.02650347440653751, 0.03664826350887457, 0.07633681589316937, 0.046318434329042514, 0.018777464283630252, 0.08082164781949214, 0.04086923560187702, 0.05912829010236648, 0.013470652573291334, 0.1389418887875734, 0.09207188647480742, 0.036966722428558335, 0.057367858356766166, 0.046431597006777604, 0.09642441501660694, 0.05109903748117147, 0.013025205961668925, 0.06854909547274152, 0.06386656306623932, 0.07698177765574186, 0.021106614806358854, 0.06387150816379056, 0.057672041227980975, 0.054655512569532286, 0.0186398423336927, 0.07472252308000481, 0.025323080387146726, 0.07254345492730219, 0.025413438542595795, 0.06881331919782585, 0.013818532142097191, 0.06704793852423468, 0.018903654286517732, 0.021843306021764878, 0.047471871629597685, 0.03204162551781103, 0.08545900785153912, 1.2181125268820794, 5.06188097500032, 21.345658110034083, 44.92722411309519, 71.08003124114006, 72.75222393774217, 74.7805521565099, 67.9728158827751, 63.307101649622766, 64.03177915080902, 56.77501778448782, 58.225977036260794, 54.193694206976126, 49.224741535802046, 42.56900887335501, 39.68876930975145, 40.97038022933468, 36.73733480515019, 23.38257435829409, 15.912453705264678, 18.635355234146118, 17.476355644964404, 12.754734889153513, 17.02365529152655, 19.27789242036881, 22.799343409076815, 36.486220744348344, 31.300694404109834, 30.428019992766846, 57.30526731860254, 65.27807697173088, 40.28605215011105, 52.8437202976596, 49.57887664917977, 45.096427317588564, 35.94951498893, 54.745583457331506, 59.28047487812658, 59.00494406300207, 41.89214898693947, 27.416120190774244, 29.340782127072735, 25.567832685286, 29.96114811589641, 16.97844997529061, 29.24204626391011, 20.46129111320742, 24.15655409136126, 22.01980567747547, 19.62563014799549, 15.807010589107392, 22.24588913302268, 24.073848955092895, 36.5974905413966, 50.41415322211481, 43.780028896947066, 57.26327834590789, 57.36832334149269, 67.27417899716285, 66.65056920820668, 68.54945136654761, 54.60758270755891, 30.728804988245813, 16.260949430927155, 10.184223325021806, 6.550920067294952, 2.1031714543219535, 0.4608587301786869, 0.03336455402595382, 0.08443359916488971, 0.06230075212736284, 0.05495812879094193, 0.021425037336866223, 0.0343933564821078, 0.027145051975704493, 0.02822346820105468, 0.07617296500792427, 0.06216335042770352, 0.07622703549361999, 0.010141077406343915, 0.05820859771882815, 0.051149603114613605, 0.08156660703882095, 0.027803546681459394, 0.03341603896490509, 0.04770881879413801, 0.03069619509211231, 0.04155775712382409, 0.03705719358197624, 0.0678968788575261, 0.016156556835818677, 0.040177270514710296, 0.032070865178661, 0.08156972501667277, 0.055305917386806784, 0.02752178720378828, 0.0415387160084661, 0.06865349027418322, 0.030329080013137673, 0.02732114686119941, 0.029796940019173972, 0.012374384584085596, 0.062348533031200214, 0.021814426422239314, 0.09563935109444203, 0.03556114260948474, 0.04567807292445533, 0.042034256151847305, 0.0007429794207001256, 0.04272692603990436, 0.12092344718234194, 0.03673314605088484, 0.0339897200765629, 0.05401495964296403, 0.03708443949900327, 0.020448619972974546, 0.06578816055891014, 0.012558257177231774, 0.025750802597031, 0.04065174707061341, 0.09636968569529634, 0.01693922290278058, 0.025947578026041872, 0.06158272089857248, 0.08984632444598022, 0.03775569722957669, 0.02974108646383449, 0.06766583440044234, 0.06351281430632358, 0.06266508439195252, 0.019939786288887262, 0.00639552032695182, 0.04044796002187556, 0.08581432709169966, 0.08455303227228504, 0.02432512063082428, 0.049439116471236756, 0.07774991103478017, 0.024951958668328104, 0.04843984670456379, 0.019464250616428834, 0.017501424186893048, 0.03035807261063207, 0.08302972772188726, 0.09096370964881875, 0.009493094384520045, 0.05191869793399688, 0.025650094593724897, 0.06893793105958931, 0.030348743574934143, 0.009986647487347646, 0.08524880864687505, 0.043707848000790805, 0.05621838173077953, 0.07390321502762456, 0.03790452896106628, 0.0558220231605153, 0.06592373513887007, 0.02674905346676467, 0.04277141659610695, 0.016085992477113203, 0.038018503692001104, 0.047020193850321156, 0.07420688461993011, 0.02434093460080124, 0.09182724395706769, 0.06998953995324912, 0.017705444892447804, 0.01967957877974597, 0.024603877043832215, 0.016708381458996766, 0.015281031336334926, 0.02122113154450011, 0.08735405656719401, 0.010877079142618084, 0.058083372986725265, 1.8761167218608243, 9.063137365925698, 31.852287515517208, 57.18382289332729, 79.83601662420458, 82.55574103324645, 83.32127001977737, 78.09212300085252, 74.44346366390106, 71.60471100961009, 63.478571984075735, 69.36467678316178, 58.758642750401656, 54.23456922654183, 50.37106598577192, 50.73333609488703, 50.23204149738435, 44.90742006609517, 30.496808559663837, 26.453690182778146, 25.279895413306452, 19.32270549958752, 19.463457792035996, 22.073967725999896, 24.57059556438077, 28.89372214194267, 39.60007667541504, 42.6001524925232, 38.01105391594672, 63.41135432643276, 57.24476083632439, 31.349029771743286, 36.73818595947758, 33.88024114793347, 32.54602143841405, 36.73733872752036, 38.323568759425996, 60.339985509072584, 48.97565926274946, 37.55944398141677, 37.884302523828325, 35.2286696434021, 30.672301284728515, 43.45939866958126, 24.878948773107222, 29.23143429140891, 24.922418440541914, 25.832514224513886, 33.98818085270543, 24.732832639448105, 26.73230201967301, 32.384178561549035, 35.592704819094756, 47.422871358932994, 61.07607710746027, 55.60860295449534, 63.96014882672218, 65.34857373083791, 76.2537237905687, 76.067168020433, 78.29860441146359, 64.72412455466487, 38.3644437789917, 21.979722976684574, 14.332186656613505, 8.38571265820534, 3.0306693238596765, 0.6935819923397034, 0.14057069896690308, 0.08209284049488845, 0.042423160686608286, 0.03473381361653728, 0.0358300777753034, 0.05664024719848268, 0.0598728547864143, 0.029996565295263167, 0.05564541691133092, 0.03300836910643885, 0.006795928629505779, 0.011569838088396336, 0.05231388438973696, 0.009301595386087654, 0.011809374630120734, 0.08413654857224996, 0.03090200269775045, 0.06542907216616216, 0.030063188131598216, 0.02341095365643982, 0.02877645536265787, 0.061330026796748566, 0.044636220160511234, 0.060387451366911975, 0.02444442350327248, 0.07210211933500345, 0.018706267902387247, 0.04787027948505936, 0.018365678617790825, 0.062206040677284045, 0.05236728837893856, 0.024908343367579005, 0.04955558481836512, 0.024173078990931955, 0.015512830390024091, 0.03901773515427786, 0.013122164922195577, 0.031711462689864064, 0.049531219391933376, 0.07957292450291496, 0.0338103712326096, 0.030073811855888175, 0.0822008052660573, 0.018718356769832394, 0.02979682893642495, 0.04841502162537748, 0.04407424870277605, 0.03535851618395217, 0.05442341474155265, 0.02372024824932939, 0.012521810544234131, 0.08260133135462962, 0.06423964788536392, 0.07092732350311934, 0.010158070194114362, 0.043932599045576594, 0.04410998287400411, 0.16885452723551184, 0.2402485131977066, 0.27466911942728106, 0.1367877567968061, 0.1711274028545426, 0.1261789175952154, 0.13289747038675895, 0.10830312922236421, 0.2392134058379358, 0.2107153027769058, 0.12635122609114455, 0.11442970289217849, 0.1553838057143073, 0.08950337752579682, 0.20122879004526525, 0.12793833810475566, 0.18705234832821355, 0.13393640818615116, 0.266641253425229, 0.1673839601778215, 0.12387653993022059, 0.15285165529818306, 0.08732707495050085, 0.18345469218348304, 0.13474942665667305, 0.1389208060478972, 0.1709022189700796, 0.21877888379798782, 0.23039201064215553, 0.14521639403556624, 0.10019392000451204, 0.12290409856265593, 0.16091581854608752, 0.18905807376628925, 0.12310793923754847, 0.09497131476359022, 0.1325911118258392, 0.11146724854986514, 0.2099785406983668, 0.16336598223255527, 0.1717736899492241, 0.16888247412298957, 0.08416921456134127, 0.15782131362826596, 0.08462023350500292, 0.19696716549656085, 0.10244063372092863, 0.17006136086438933, 0.1727094357052157, 0.09764870778927881, 0.3776668216432295, 2.923690599779929, 12.309403688676896, 39.9235466987856, 70.51001671821841, 94.54045680261429, 93.75781843739172, 95.21752849701913, 86.85509804756411, 83.08054631756198, 79.85697777040544, 74.09218403600877, 78.51054576135452, 71.23287031727453, 67.01420430214175, 60.7340346613238, 58.67007563191076, 58.7892686167071, 53.35972770567864, 36.73396941154234, 26.15049881319846, 30.28925830318082, 28.951516305246663, 24.6558423965208, 28.60503177489004, 34.831717937223374, 37.895175333945986, 55.77848472902852, 51.63254337926065, 50.54043000744235, 72.74972146557224, 82.00908030233076, 59.54088103386664, 74.70923562203684, 69.26993585401966, 65.90876271647792, 51.88051954392464, 75.07208624193746, 79.22817476334112, 73.31007126838931, 58.90942650456583, 41.71125711933259, 44.779797907798525, 37.42418104602445, 45.08897873663133, 25.64162031296761, 43.172273328227384, 31.653970518419822, 34.128052573050226, 34.685574346973056, 29.33062711069661, 26.850783094283077, 32.32955171215919, 37.67153355383104, 55.40780898063414, 68.79941617288898, 64.76841595865065, 76.72309813960906, 75.72891850625315, 85.19127568890973, 86.24622068097516, 87.18695409836309, 74.34793041598412, 48.898737661300174, 30.04102522327054, 18.36612766788852, 10.695496432242855, 4.258407469718687, 0.9911813490813779, 0.2700999871857705, 0.1684597468063716, 0.121968122980287, 0.12717424966995755, 0.11567546144848871, 0.14938584288522122, 0.1401840850350357, 0.11553473875767763, 0.16327181470490273, 0.11829820176165913, 0.1667832553146347, 0.11958953488858477, 0.16717170785752036, 0.10540314168939668, 0.1028144310018228, 0.1810530678278977, 0.12386000009193537, 0.1575419826493148, 0.1445058781293131, 0.07675876946098383, 0.1445279874268078, 0.18468219486455764, 0.0998421783949579, 0.16161542536029894, 0.14514908555053896, 0.26098905671988765, 0.1385048203050129, 0.1239082023441311, 0.19664576096880823, 0.14696540341021555, 0.2467841471755697, 0.18894720552188737, 0.19083231807716433, 0.07846954338733228, 0.1684879694855021, 0.11996970602100897, 0.1556529477238655, 0.24316337049728443, 0.1367480581205699, 0.20371161972082433, 0.11215583135884617, 0.09141070663087791, 0.19884901451728038, 0.19957037822854137, 0.14115655704611732, 0.13614010606561938, 0.11457618656418017, 0.15472694660627073, 0.11655317604421608, 0.055227370391930306, 0.10318838916118107, 0.13699637786034616, 0.18360637759249057, 0.13879492248017944, 0.18883002471298943, 0.11913750470886308, 0.17947671934962275], [0.008039360193745985, 0.14124851824054796, 0.019557364773185506, 0.004637367214121286, 0.024862023776457198, 0.03663940370203026, 0.013923192201482673, 0.07142937922429654, 0.05197310549837928, 0.044474142768810836, 0.046940045731682936, 0.017982774466696768, 0.07398693311598993, 0.06522314007123632, 0.025548938428983096, 0.034374169810044194, 0.02788782401400949, 0.05294709053311137, 0.03269223526360528, 0.01097637945936332, 0.07929973754911654, 0.05307499274250962, 0.08706369392213323, 0.08143510038573896, 0.1008926228349728, 0.06077366693305874, 0.0434934008385866, 0.04449406488528175, 0.013788653755440347, 0.014297916448765225, 0.031001071272898587, 0.06555207524328463, 0.011326562079991545, 0.05854152803940158, 0.039285425427219564, 0.06737406981448013, 0.012524617298866713, 0.022274264953129237, 0.02090217849810518, 0.05470576410692546, 0.04432685087404905, 0.03691789964514394, 0.07545078158258431, 0.04841508674285105, 0.03243577583963352, 0.033346083646099416, 0.029277329393211874, 0.02129798931550355, 0.026385544746693586, 1.4765159449269696, 7.7735959041503175, 18.57090480865971, 48.309393698169345, 69.2448797533589, 76.46196242301696, 63.79832752289311, 67.18874193006947, 55.58158566874843, 57.46418606850409, 42.66205533858269, 44.0087579911755, 32.049918097834436, 24.91609165745397, 31.63625317235147, 21.108950914875155, 31.493404373045895, 20.054751173142467, 14.362480102046845, 22.472235387371434, 33.87609128029116, 26.776297284710793, 25.93167370365512, 29.59704233754066, 31.95331600404555, 53.149465130221465, 45.59328571442635, 53.41187169474941, 42.84399055665539, 31.94472405218309, 50.22363193573491, 37.63981334624752, 45.694349504286244, 50.53262056842927, 46.58980700277513, 36.62375080970026, 46.17531053481564, 56.11521628595168, 66.15514247648179, 51.2651506547005, 80.13716051655432, 60.991777527716856, 49.00740692692418, 49.05203957711497, 51.757302207331506, 44.66659438225531, 53.277204959623276, 45.974175314749445, 41.1565084611216, 54.32370116633754, 36.20593993894516, 30.226551371236003, 24.913567612248084, 20.765192431788293, 17.99166879346294, 19.012028286533972, 14.078007263521995, 21.658443597055253, 39.99145469357891, 34.413624655815866, 36.65459632873535, 46.532712982546904, 51.53138545251662, 56.97650209549935, 62.42661191571144, 59.44090374054448, 49.19481777375745, 37.84412176378312, 18.9069519119878, 9.636627108820024, 3.9481813292349544, 1.3270280438084758, 0.607215078367341, 0.011579708173690785, 0.06298116077819178, 0.0394450934723981, 0.057689546337050784, 0.0635529649744351, 0.06140516086992237, 0.027403667937183095, 0.08044067995562669, 0.05459809427960746, 0.06906390655785799, 0.03354801293162089, 0.04643402550549758, 0.03652154490531933, 0.036839287532793905, 0.040694284102609085, 0.07301489777502514, 0.0022208206627833387, 0.012752816696921665, 0.030708450583680987, 0.04331846083063753, 0.03385666975631349, 0.0380089275929476, 0.023876398035715667, 0.07538016359772413, 0.053939419543190356, 0.06834974407308525, 0.06635464427451934, 0.03018782297599941, 0.05739145769527363, 0.04980178632503075, 0.03637406914945572, 0.027808893975170872, 0.029627600113951394, 0.05690522168973281, 0.07741168321621034, 0.036601604923846266, 0.08368267978150999, 0.022275216817375154, 0.046103339822542284, 0.05473358842033533, 0.0470406407370202, 0.028342951104165088, 0.025798531789933483, 0.08097861157429796, 0.07259440743514607, 0.05812961022339522, 0.09041214932597454, 0.051567048254993655, 0.050911345939722755, 0.1179714116357988, 0.03933709805771228, 0.09256261941646377, 0.0597735429783502, 0.07479206854177099, 0.01904851385211993, 0.08735627056129518, 0.013120797455250738, 0.07411994130140351, 0.0251014185919156, 0.11460645469806849, 0.04623745500500645, 0.05804592277854682, 0.04395520246978249, 0.05564986788217099, 0.11172008820839467, 0.03453097651682554, 0.015980341291475682, 0.0473342975601554, 0.023457154503933365, 0.03901069863669334, 0.014551852570636379, 0.040132113462013584, 0.09439465740034658, 0.0994719740664286, 0.026899871281197956, 0.06255091813903663, 0.0872905019129957, 0.06120588990949816, 0.01855186479646833, 0.043805302045638525, 0.02178961474959168, 0.039716583541444236, 0.13646757800973233, 0.013031712920975783, 0.01323107198151129, 0.12416147867277746, 0.07530910894274712, 0.005713397554392296, 0.06780127108457588, 0.020531893730343833, 0.03289864233304416, 0.014863119839930968, 0.040681295081852906, 0.03993189255256326, 0.02268048690541858, 0.017137183852854277, 0.004173432506861225, 0.11406847711412177, 0.06501070388983335, 0.05723151002800273, 0.041627363872624217, 0.024674025799838767, 0.13466721010063926, 2.3350619789092772, 9.904351426709084, 28.903069150063303, 64.19686386662146, 79.82667353845413, 88.1078952358615, 74.55678093817927, 74.36081932437035, 66.33674037071967, 64.54583321848224, 51.83678511650332, 54.21121543453586, 42.310638427734375, 37.9364033668272, 38.96993221775178, 29.593174880550755, 40.14796118582449, 25.941269782281694, 25.472313165664676, 31.46630471752536, 38.66899621102118, 30.852367493414114, 30.868645329629224, 35.64714339471633, 28.927319203653646, 43.77590648589596, 40.15029891844719, 41.19860726018106, 43.98159165536204, 38.14055881192608, 44.70371569356611, 39.85504642609627, 51.16219628241755, 52.43496225726221, 49.020574323592655, 34.43292663943383, 37.400799797427275, 35.63110482308173, 46.24412067474858, 37.25570740238313, 55.51203027848275, 43.767410632102724, 31.02291999324676, 38.00483303685343, 39.51654980259557, 38.20647816504202, 37.50045153402513, 42.346861516275716, 38.544766902923584, 48.30588709923529, 36.84346629727271, 20.919651446803925, 27.96061577335481, 23.87308636019307, 24.181396422847627, 30.904225149462302, 27.466099031509895, 31.432872395361628, 49.37359940621161, 46.85128788794241, 44.648935871739546, 55.61849124969975, 60.277725727327415, 66.40569563834899, 73.2951113485521, 68.97687988896524, 60.09796350233017, 47.06185640827302, 26.209858002201205, 14.129466798997695, 5.430383730319239, 1.6620040949313872, 0.577773645279869, 0.006754651812145547, 0.081650409396858, 0.038347029007009925, 0.030956871830107226, 0.026098692699545817, 0.00821052338822835, 0.028662788982112563, 0.051643009703125686, 0.04611927445136732, 0.04528017834790292, 0.04091992763982665, 0.03910572035238147, 0.041605396301395474, 0.06951254296807513, 0.018824768297734763, 0.1308580524017734, 0.05904214351528114, 0.02417872122849428, 0.038883393975876035, 0.0434432182491066, 0.038027122181149266, 0.019280644238836343, 0.08135223265496955, 0.03168641544517971, 0.0277147053801004, 0.03679156025511123, 0.004810861231113274, 0.01996241652617051, 0.013851895271199606, 0.016340234076544162, 0.014836751093577235, 0.046611815360524965, 0.044819265378699194, 0.02930979236900326, 0.010269465123964174, 0.0623822485607478, 0.007762538631551809, 0.023456558870572238, 0.061209115139659376, 0.05293740718174846, 0.026959524632641868, 0.041714609795880896, 0.029775026074099927, 0.029343460018055576, 0.0021063829274592743, 0.017153752419436653, 0.01183005230080697, 0.045005328983308814, 0.011531325890832852, 0.026413612293019414, 0.018452108657408147, 0.04140223744475553, 0.09595425153571753, 0.019458139150012887, 0.126383486053636, 0.3003316859324133, 0.0989673059854296, 0.12360696891142477, 0.10162301106198181, 0.21420694767467438, 0.0778607716183028, 0.13009366519268484, 0.13139154071048384, 0.19242964204280608, 0.13718060668437712, 0.11067899770193523, 0.16011678884106298, 0.10789059853601841, 0.13624003457446254, 0.18131868583300423, 0.1340162958348951, 0.09007206757462795, 0.28375093855204125, 0.2303520055307496, 0.13702170472712288, 0.14843836066222962, 0.25713244753499187, 0.1648926269263029, 0.12079319691345577, 0.20714910220234625, 0.18169233755719277, 0.08082143331487333, 0.25260350426598904, 0.11336760625483529, 0.12274109803500677, 0.31250816319257985, 0.14235373796714892, 0.1347933388164928, 0.19101705251922532, 0.2864337478193545, 0.14757416751836577, 0.22251419062095307, 0.07098600583811922, 0.236607848876907, 0.08272374454405039, 0.13808972322412078, 0.18572189875187414, 0.183376505249931, 0.13440519270877685, 0.14988278879994346, 0.15629983236712797, 0.13445789955796736, 0.23480558106976174, 3.1476204289544016, 13.073082297079026, 39.08686591732887, 79.4835053720782, 94.61254996638145, 99.41835557260822, 83.60493583063926, 84.9151094498173, 74.55444320555657, 74.20335185143256, 61.750897361386215, 63.20766172101421, 47.84618923741002, 41.58330548194147, 49.699418929315385, 36.91632824559366, 48.13416965546147, 32.398656029855054, 26.26809343214958, 37.84257242756505, 47.000110457020426, 38.06794005055582, 39.526649905789284, 45.38749464096562, 45.07734498670025, 72.630826580909, 64.53607828386369, 72.08575833228328, 59.65910127086025, 50.882939215629335, 67.75098231530959, 52.90129284704886, 60.5371081444525, 68.30180075860792, 62.347250600014966, 52.02931857878163, 61.20101244218888, 71.9862634904923, 80.42030857455346, 64.45258671237578, 95.80623703618204, 76.14346596502489, 62.08551083841632, 65.6778214054723, 67.81721545803931, 56.74898109128399, 68.8703404703448, 64.17536535570699, 59.67875234542355, 72.86806721841135, 53.32244557719077, 45.270517795316636, 35.55221811417611, 30.178382704334876, 28.47312834955031, 33.17820356738183, 25.883463851867187, 35.625903760233236, 58.71009949714907, 52.497935910378736, 55.46228677995744, 66.52007979731407, 69.56631014423986, 77.402538945598, 82.86616525342389, 79.08788727175805, 70.39183570492652, 54.579176902771, 32.95636215517598, 18.893651154733476, 7.22416352841162, 2.1988478687501725, 1.0636283841825303, 0.2008375336205767, 0.3171953955484975, 0.12678789620798442, 0.11148126795887948, 0.16321631929566785, 0.08966862269106413, 0.16663648819010105, 0.2452103880744788, 0.13998897776247995, 0.16803256085803434, 0.18618824711490065, 0.15985202885443167, 0.12327575079736211, 0.1479215424267515, 0.14019407482156832, 0.1703274691657674, 0.12330387388506245, 0.0900426191548186, 0.07595785517966555, 0.1617259871695311, 0.201248218035025, 0.10221497486195258, 0.29034220583496556, 0.18903167437641852, 0.08599347675279265, 0.19076304840705088, 0.1037959888156864, 0.10274886153638364, 0.16904287761257542, 0.1323062803355917, 0.21684843415935195, 0.11582804318036764, 0.20309916306887904, 0.1344850037487284, 0.13126846102456893, 0.1708888737184386, 0.15460516926982712, 0.16488665144049353, 0.20133029669523242, 0.1768785321544255, 0.16905873563260804, 0.1742000436230052, 0.14327137340461055, 0.11852396021206534, 0.09802449689877611, 0.1587486324170905, 0.11573923826818505, 0.12868893573120718, 0.22139934883002313, 0.21359315802974088, 0.1796211269233496, 0.1473259703526574, 0.2294116785689708, 0.2502657563215302], [0.02101113918357559, 0.019781462728015838, 0.06883666955775793, 0.005771298000904462, 0.02423353481947655, 0.011408632121709807, 0.02893280241668465, 0.04916377681037111, 0.07181707334013716, 0.056901402741430275, 0.04453859374588055, 0.03993371201138343, 0.024578034982926423, 0.030756465144335266, 0.026144253863622586, 0.04879718841684442, 0.016020250641891075, 0.09469852617551243, 0.04263401872688725, 0.010355856859185284, 0.11799198875744497, 0.0627727312366328, 0.08261061634027189, 0.03524258026793119, 0.013261444494879294, 0.033927927424590436, 0.043166894165258256, 0.09490476470560798, 0.0720661898113547, 0.052163244690746076, 0.031269010524415684, 0.012405113328338392, 0.01143441002275194, 0.00968946953259048, 0.023707477563631632, 0.07749736248966187, 0.059290463255057414, 0.0500596936551794, 0.022402203551703886, 0.055148022835172957, 0.13202930890744732, 0.01685422161714204, 0.060254347420507864, 0.018030484507401145, 0.018253848933043982, 0.04982442422319324, 0.1256497883267941, 1.2034982659163014, 8.6653668649735, 29.633267387267086, 45.234910518892356, 57.52533974186067, 72.35622928988549, 66.45193253794025, 58.557236886793575, 63.79016114819435, 56.17227108247819, 39.795194979636904, 30.294555464098533, 27.539390479364705, 19.418223058023763, 21.772100156353368, 12.700139418725046, 19.75456630029986, 9.574266326042915, 13.935671314116448, 29.469628064863144, 21.239701163384225, 26.36603109298214, 27.57932805245923, 67.34933160966443, 50.99273027912263, 39.144089375772786, 62.328462446889574, 54.94676574583977, 54.47677950705252, 49.21191930770875, 36.883482317770685, 30.843832415919152, 29.70003789471042, 18.549141537758615, 11.445379084156407, 10.253514935893397, 9.876943865130025, 9.844974587040564, 12.651642253321986, 19.79637484396658, 15.870917766324936, 29.049287265346898, 15.373883843421938, 20.661165291263213, 31.259833112839733, 29.26931654253314, 30.195574452800138, 48.62153591648225, 59.607922184851866, 42.47697830200195, 51.37896214762042, 55.86432187787948, 74.68821171791323, 48.04276274096582, 46.84949536477366, 38.70811008637951, 30.7754203965587, 21.474354997757946, 17.80691339123634, 29.360876429465513, 30.429516376987582, 29.09457495135646, 57.01794978111022, 61.58198048991542, 52.53724198187552, 62.250124869808076, 51.00047303784279, 54.521106212369865, 61.43232245599071, 63.81908862821518, 61.01833981852378, 52.599289955631384, 21.858613914059056, 15.507446431344556, 3.432447751683574, 1.8739439739334969, 0.19179404953554754, 0.061535365173533085, 0.0815792857939678, 0.008871063548741082, 0.032998425285181696, 0.039759174199594606, 0.04493655343990653, 0.07364959395941227, 0.06833095193630265, 0.05974230191279804, 0.06148086567859977, 0.03969645458123377, 0.001900177195502986, 0.04357129282828781, 0.1475383758905434, 0.009523532972971519, 0.06753272662359862, 0.0864827081621174, 0.03193042594038191, 0.031740715757252715, 0.019897643792172594, 0.014070239905718596, 0.031638330021392436, 0.03063127488618897, 0.04933128959589428, 0.04004094899902421, 0.016586046793588227, 0.053457224651450114, 0.10000743888198368, 0.09853751533814976, 0.004840380992860564, 0.026793990269183155, 0.028623343114891363, 0.04784800164822129, 0.028589020460663785, 0.04134378493613294, 0.01594806121917622, 0.012157161310765774, 0.05945951587730839, 0.04004404016379868, 0.049241469617212014, 0.05893014912163058, 0.012877447710883234, 0.001942583513746579, 0.03576801699255744, 0.045391368349232984, 0.06250087727582262, 0.043577892675755486, 0.06514702923595905, 0.05946516577574996, 0.056861029907820694, 0.1144844322134891, 0.032662775352477066, 0.1066433001429804, 0.04782247176814464, 0.070365505262969, 0.004988050185925057, 0.022541993530467156, 0.04316469932335519, 0.03421702219413654, 0.09253059694122884, 0.022192481236772674, 0.03191123160743906, 0.0016392851149806033, 0.02332627987338891, 0.09228553307513077, 0.05345009237287506, 0.010401672747496878, 0.055043336920320034, 0.01962921424438396, 0.03769522990971323, 0.04893808730787808, 0.012231351180572905, 0.06296080199160403, 0.007504066790363962, 0.020874917259319656, 0.03269195947195253, 0.030324443265975966, 0.03431434983447675, 0.019333065720275044, 0.024712385737427303, 0.09081639860185886, 0.09355314811992069, 0.0953378648527207, 0.010628167599920305, 0.035340428848059914, 0.038124036134010365, 0.025032932246704737, 0.021050355224419507, 0.0439121253458002, 0.030525742444179715, 0.026935806550506144, 0.04715583737819426, 0.008676918674140208, 0.05028952769334278, 0.014893306576977334, 0.06990052819732698, 0.034376985183165926, 0.0537305839750315, 0.32326832774185366, 2.9578804296831933, 14.272949061086102, 40.01511835282849, 57.36096497504943, 72.67082691192627, 82.5189099773284, 76.83034358486053, 68.45394949759206, 72.6946278541319, 64.19117642987159, 48.457741660456506, 42.67240255109726, 38.49685122889858, 33.016221446375695, 30.750534919000444, 19.508200268591604, 32.42392001613494, 15.60593028222361, 28.55952443615083, 37.51252066704535, 23.58155227476551, 35.7953344621966, 38.083049020459576, 52.779001189816384, 45.06966890827302, 37.997117734724476, 45.55851390284877, 49.981798202760764, 45.27238092114849, 46.33102078591624, 32.19596559001554, 31.646578811830093, 29.797049876182314, 18.269541263580322, 11.622927131191378, 11.068267706901798, 8.666031706717707, 7.326441782136118, 8.468567825132801, 12.436756184024196, 11.093784686057798, 14.25329210296754, 11.983247822330846, 12.493450122494853, 18.518195998284128, 19.547488689422607, 20.970738357113255, 27.952002248456402, 38.1536046151192, 29.360495959558797, 37.25382858707059, 44.29977824611049, 49.60082231029388, 37.590975915232015, 43.70297393491192, 32.82623164115414, 25.590682452724828, 26.658120193789085, 20.053515626538186, 30.30694034791762, 35.51450452496929, 33.22755090651974, 58.400385225972826, 64.43245318628126, 54.23578908366542, 72.44389426323676, 59.74103958375993, 64.48928833007812, 72.67138388849074, 73.97795677185059, 72.74626193508026, 65.98841036519697, 31.583383544798824, 21.994975113099624, 5.433625569266658, 2.5680358131085677, 0.09429225442750801, 0.03688895684336463, 0.00648541116876708, 0.07379316649730168, 0.021504955629127163, 0.026102383328121037, 0.052370923466139266, 0.08008548328953405, 0.028967287864596136, 0.04225470944337788, 0.0403268032166506, 0.05079204689771418, 0.02249325693194424, 0.040028151500249104, 0.062396742944275184, 0.05804257880475733, 0.055040644121266184, 0.051304272436086214, 0.04551795671784109, 0.10137294464173818, 0.08110282507034079, 0.023332061921997417, 0.05942299263551832, 0.018262226104495988, 0.015528931642972655, 0.059734035824095054, 0.02653485145269623, 0.01755042891618946, 0.016078630372160868, 0.016427667691342292, 0.05784231193003155, 0.09593731333171168, 0.08274479664020962, 0.08384991677538042, 0.03183239732959098, 0.017947831281250524, 0.04090174454294386, 0.05881988991712851, 0.05683734246920194, 0.01556036901855541, 0.08709154887906007, 0.045452923513948924, 0.030390656245271527, 0.11978196851428478, 0.025272991643437458, 0.13152920671047705, 0.03465108378159423, 0.037217382566943284, 0.025278195295663133, 0.0139403602318658, 0.052456985783552935, 0.1128509488978213, 0.04703035600663674, 0.2464703882053014, 0.11202848456319302, 0.1534178095959848, 0.08067811358599894, 0.08504264672557194, 0.1333793856564068, 0.16753509400352357, 0.20631780487395104, 0.17565907339655584, 0.1480676353939118, 0.11816296426038589, 0.22256441534526888, 0.12286759447306396, 0.1192741364901585, 0.2046706392279556, 0.18059914541100303, 0.08374192902157385, 0.13711659237742424, 0.22884394613004502, 0.1265142419405522, 0.23566903876921824, 0.2068099550782673, 0.1200748592494957, 0.12128704783296394, 0.07615932098199284, 0.1336152334847758, 0.1795683281436082, 0.10711732470700819, 0.21581852087570777, 0.268406565150907, 0.20204675744377798, 0.09016738423416693, 0.09364746120427886, 0.15324943879198644, 0.16247399541879856, 0.33276463107716653, 0.14305637848954048, 0.151119407927317, 0.18030783281691615, 0.11398043828986346, 0.28589592345299264, 0.14396129686745907, 0.13786104597872303, 0.188097951092547, 0.1680045986487981, 0.21930884810224657, 0.6156297268406038, 4.476767288100335, 22.048811604899747, 49.448697105530776, 67.93118384576613, 88.6039181678526, 93.65206349280574, 87.42227277448102, 76.53171785416143, 83.4678803720782, 74.21909624530424, 59.50237512588502, 48.80461646664528, 41.83304671318301, 35.09256732079291, 33.23636054992676, 22.9417097568512, 36.451397941958525, 22.300268873091667, 27.4451006227924, 44.31851933079381, 32.93534217342254, 40.884064551322695, 41.77289324422037, 82.05352860112345, 65.37816409141787, 51.62877005915488, 81.6863476845526, 72.35324828855454, 70.98785554209064, 64.20475959777832, 48.93725533639231, 44.39457016606485, 40.81750192949849, 26.738783736382764, 17.755265581992365, 15.762842739782027, 12.657744480717568, 13.613422128462023, 16.45276019650121, 24.615167417833884, 20.770246405755323, 37.33641016867853, 19.831209413466915, 26.35021609644736, 40.37194028977425, 36.38765942665839, 37.7157582775239, 61.482352287538596, 74.4548777611025, 56.39038232065017, 67.69230365753174, 71.84923156615227, 95.1792932325794, 66.86300477673932, 63.22257849477953, 53.23929917427802, 44.036579362807736, 33.6808317707431, 28.414453614142637, 41.887681407313195, 45.28336748000115, 43.02024618271859, 70.21816884317707, 74.16958808898926, 66.82884877727878, 82.56950855255127, 70.94587833650651, 77.11964976403021, 83.38311795265444, 86.59565679488644, 84.9090454655309, 76.7715629454582, 39.72248600375268, 26.034092672409553, 8.634033991444497, 3.4509189282694175, 0.4891131253492448, 0.13210738858869, 0.16861437399300838, 0.18096623942255977, 0.13586290481109775, 0.16111921488998399, 0.1792811983895879, 0.20521457697595322, 0.20335702826419186, 0.10340980389305662, 0.13325339483637966, 0.20972948551418322, 0.18159003417578437, 0.1578725649104003, 0.22405716830924635, 0.13086281746866243, 0.1701822495388408, 0.20974883689515053, 0.1840523633384897, 0.3154325353041772, 0.21535834718135097, 0.11040660747957808, 0.2088959205655321, 0.1297544567815719, 0.0972954876300308, 0.20517705398942196, 0.10785741160713858, 0.12433263037594096, 0.24719847816853757, 0.3030083664963323, 0.14183287478743062, 0.16914205535525279, 0.2384957959575038, 0.21835450173145343, 0.07245153203726777, 0.12434540106163872, 0.04642436896721202, 0.2883178338168129, 0.137817440254073, 0.10338170378799401, 0.2189322239569118, 0.15353771767789318, 0.09474168756916639, 0.15783632895158184, 0.13123600954009643, 0.18778356393018078, 0.3071740461933998, 0.14389064823908193, 0.13933573458944598, 0.12263930027162838, 0.19734077125547395, 0.3731801511058885, 0.2713581793490918], [0.06435292547628765, 0.037735859382777445, 0.05609268585460321, 0.04535270772213417, 0.07476016864060395, 0.01486832636498636, 0.036375394481564724, 0.08577017744462337, 0.0740042160595617, 0.019991635119602568, 0.03885966057198183, 0.046511162898593375, 0.07843490089139632, 0.040391457207020254, 0.025089555720408118, 0.016701879287739436, 0.056875214025738745, 0.10760778951789103, 0.051011776236156305, 0.03990136394878069, 0.05065331603550623, 0.016734166063308235, 0.05849286613445129, 0.08005915284757653, 0.004094187414363748, 0.019041295388653394, 0.07348573541328793, 0.05346647133269618, 0.0390328653907824, 0.022768041179064783, 0.04945808097780232, 0.018031769619894125, 0.03413224690443566, 0.030650727773806265, 0.0498032801964831, 0.009942199065980893, 0.05298246847345464, 0.05210014585886271, 0.00790560219977652, 0.06264412422634422, 0.03908226657057962, 0.018158733371585127, 0.009423157260302574, 0.09093934805282662, 0.1330755245421202, 3.0722278164279078, 17.38077925097558, 34.590409801852324, 58.531227650180945, 74.90926081134428, 72.70149200193345, 67.39971837689801, 61.92022215935492, 42.58564756762597, 61.61167675449003, 61.12162759227138, 28.172663027240386, 26.72439452140562, 19.697217326010428, 22.587859015310965, 19.507162801681027, 20.17010415754011, 23.575178423235496, 14.211917961797408, 21.915480436817294, 23.899378007458104, 18.901507662188624, 38.43859226472917, 31.69854433305802, 39.10373603144, 80.13356762547647, 69.19399876748362, 60.756250965979795, 49.123246285223196, 30.90841227962125, 24.69770193099976, 12.674876413037701, 13.948485697469405, 5.568426155274914, 2.8545416651233553, 0.7344628341736332, 2.2049846620328966, 1.6438899766052923, 1.3208584006755584, 0.8982383976540259, 1.248456227683252, 0.3879303467129508, 0.6278153665123448, 0.2016237236919903, 1.5334947455313899, 2.1930824748931395, 2.1301416716267987, 3.5154948696013424, 4.079932272434235, 6.5479527942595945, 10.38926326459454, 18.30485043987151, 21.835556261001095, 33.869105539014264, 37.352095726997625, 36.07541130435082, 58.446222043806515, 53.86998099665488, 45.55823149219636, 39.52497897609588, 39.949493177475475, 30.516622412589292, 35.358072557756984, 60.48466605524863, 73.13790275204566, 54.08831973229685, 38.32401590962564, 31.687646027534242, 33.35653804963635, 46.288949443447976, 41.20540472768968, 53.37243226266677, 60.77063037503151, 65.21549555563158, 68.2114528840588, 60.2181213901889, 42.368414940372595, 17.988438721626036, 4.817544769856238, 1.2716653822891175, 0.12787797037632237, 0.010189742184123926, 0.06622519839795367, 0.019437696093753464, 0.043678445546256925, 0.05049221157546967, 0.03079489019939736, 0.01803115291911508, 0.013327876766843182, 0.027064919178824753, 0.034192710393859495, 0.036079807116860346, 0.050338407933351495, 0.009464539414752395, 0.11948928462281344, 0.03727554013171504, 0.02996027187985038, 0.010212687475066031, 0.012736939524690951, 0.05878900125202152, 0.022518250550473892, 0.07386774515673038, 0.014311871697915899, 0.059370373886439114, 0.048748832947063836, 0.06410921375537593, 0.0562303671763549, 0.032725180874788956, 0.06870864860473141, 0.031557850569726965, 0.012628645335714664, 0.029722166007324576, 0.036303439673276684, 0.0331050762155604, 0.032592977081695874, 0.060399210816549684, 0.05008513160470513, 0.047689835135374344, 0.04185175485608559, 0.015372899642604736, 0.0236089471652503, 0.053852265550484585, 0.012850709327106035, 0.047354231167945175, 0.06129742592513081, 0.05722679092638916, 0.04322523559113184, 0.06408792800239979, 0.04660294023192218, 0.08308411230363193, 0.04015865457815029, 0.025757569068622206, 0.029171042354597203, 0.08103440575782331, 0.050963076026809793, 0.04266780703478763, 0.06350577395829944, 0.020311185714578437, 0.04500133766522331, 0.022691876717632817, 0.035371574152621536, 0.04296155578847374, 0.05871573643338296, 0.027386863798564, 0.015359576415991592, 0.018906222596283884, 0.06485832134081472, 0.04064084180901128, 0.10978067534104471, 0.044687429307809765, 0.036411339326971964, 0.026459016409071705, 0.023966290792750738, 0.07831909137988284, 0.04410143333276914, 0.019691368872900645, 0.030006511031740138, 0.030763001789549188, 0.062114899196932395, 0.03211632866652743, 0.015722486629871833, 0.026533560594543818, 0.04667106460058882, 0.061829895336901954, 0.07115705794985257, 0.05177983300640218, 0.03356589342377359, 0.06008061017059992, 0.07804750554984616, 0.07977413749622722, 0.08070705638777825, 0.042874899752918756, 0.06360603954582926, 0.05406858196722404, 0.06677072960883379, 0.23048931913029766, 4.80344335879049, 22.79246945534983, 41.550035938139885, 69.52437216235747, 84.16644665502733, 82.22863105035599, 76.54916455668788, 73.42629109659504, 54.6628842046184, 68.48432433220648, 73.67419273622575, 38.20763134187268, 36.9550028154927, 27.878510759722804, 31.624595888199348, 31.10161058364376, 27.509229413924682, 26.042790528266664, 26.35365209271831, 31.64615519585148, 22.913976638547837, 27.683831760960242, 32.0349052259999, 32.576100134080455, 31.857117914384414, 62.5901629847865, 50.803550443341656, 41.32605291181996, 40.64316434244956, 24.968017954980176, 20.275863024496264, 11.731369879937942, 11.673910098691142, 5.523134546895181, 2.689271862468412, 1.055436636651716, 1.7983568363612699, 1.1437150932127431, 0.5497036934379609, 0.6161517697957255, 0.31448479261129136, 0.11992783165506779, 0.33815635788825255, 0.4316628742362223, 0.9009760894602346, 0.9315438556575006, 0.7855324615393916, 1.8634571495556065, 1.8177257454203022, 4.223346383340897, 5.452443140168344, 12.6376207605485, 16.812516066335863, 24.420276611082016, 28.587453672962805, 30.133793200215987, 40.76972353842951, 42.81580440459713, 38.74231315428211, 32.94432440111714, 36.1220718199207, 36.45665391798943, 39.226208117700395, 60.128095149993904, 81.8832035987608, 63.53730163266582, 48.084402622715125, 40.563281351520175, 40.36485648924305, 57.69650805381037, 51.496990188475586, 61.02575702051963, 70.20171057793402, 72.00637740473594, 80.71181128101965, 71.58429115049302, 54.78433647463399, 25.180377037294452, 7.245394827858095, 2.0172290143466767, 0.14213289014033734, 0.03931548288692871, 0.04585114750830878, 0.060237554773207636, 0.09098835469734284, 0.05972638643617111, 0.054050433344297835, 0.05536804711746593, 0.023429567677780025, 0.037812548614437544, 0.04398175124679843, 0.05190361749320742, 0.024132415043911146, 0.04086047921690249, 0.06397530158621169, 0.032960094075890324, 0.02199622100189088, 0.0015281847698779237, 0.011742980662553061, 0.07783487018558287, 0.013969894836566622, 0.10610724543972362, 0.018522496815891038, 0.04344062121104329, 0.05699308814420816, 0.10034693074562859, 0.018750287314516403, 0.013587650478697352, 0.02301112087743898, 0.02839823966966041, 0.04208967112185013, 0.062322991659804705, 0.05960875746583747, 0.05801431782123062, 0.04246879271381805, 0.0972118691330956, 0.03338219320041037, 0.02314267349579642, 0.1174838732807867, 0.02446988252021613, 0.024920008971445987, 0.07110695579960462, 0.13096533535468963, 0.026147456111146078, 0.0390408480269534, 0.0206709501799196, 0.05291489185765386, 0.05355493150531285, 0.010427742719560141, 0.011707173712972191, 0.013817586023510705, 0.14574464230287462, 0.13853247607907943, 0.10932022585503517, 0.16732831155100178, 0.22978381343906928, 0.2766311318883973, 0.18518373730682558, 0.20746682950806236, 0.26001679921342485, 0.1007801917712054, 0.10914414054563931, 0.1650457525806081, 0.13444694450065015, 0.12033951198381763, 0.133808272319936, 0.1762770765250729, 0.1746328526567067, 0.26965648356464605, 0.13822527482144295, 0.11433057877565585, 0.10919991174652692, 0.130164819439092, 0.1726827145584168, 0.1598320646031249, 0.0874322664833838, 0.14553217547795466, 0.2429693051043057, 0.13179917609499348, 0.06152320352773513, 0.07582084035440799, 0.15202460209688834, 0.16547370461686967, 0.18167617310199047, 0.16030403605151564, 0.16927598284617548, 0.12030846244024655, 0.15245256945490837, 0.1884393964803988, 0.14332014256187026, 0.1914845806576552, 0.1544433408567021, 0.14258791572384297, 0.1294917958758531, 0.2289049726940932, 0.5320529050884709, 6.429016234413271, 30.350009933594738, 54.581746055233864, 82.43141758826472, 96.51125954043482, 93.41999253919049, 84.78651846608808, 82.6035390361663, 61.75884016098515, 76.98857984235211, 77.11462128546931, 44.0408351344447, 41.318176792513945, 33.074076406417355, 34.418154993364894, 30.66765915962958, 32.09541366946313, 36.249337042531664, 25.014317612494192, 34.29068972987514, 36.67451804684055, 29.218039397270452, 56.24907109045214, 44.32057465276411, 54.495010683613444, 98.02911481549664, 84.22990275967507, 77.32762167530676, 61.509361728545166, 40.24136458673785, 30.669759588856852, 17.37356601222869, 18.94317892289931, 7.544300027431981, 4.029816639038825, 1.5448160541634408, 3.512053725219542, 2.390275222639884, 2.084234496278148, 1.6100497279436359, 1.9600511534560112, 0.8120552834964568, 0.9319334573322727, 0.6015109715442504, 2.09965750094383, 2.9730006764012002, 2.3559142793378522, 4.584883009233783, 5.1910392315157, 8.33579461420736, 13.894197152506921, 25.730448269074966, 28.598995247194846, 41.07880630800801, 50.37147783464002, 47.76210931039626, 70.76737911470475, 70.56791874670213, 62.473276353651485, 51.60142721668367, 53.84460718401017, 41.36163273165303, 46.730643626182314, 66.77616350112423, 81.6666260073262, 65.93165366880356, 53.575736553438254, 47.75626497883951, 49.24801688040457, 65.00845324608588, 61.310544629250806, 74.09443547648769, 82.8283614497031, 83.75564113739999, 91.6306229560606, 82.85075033864668, 63.138765288937485, 30.379362990779263, 10.503233613506442, 2.8367586193546175, 0.4719190479766938, 0.18762389588500225, 0.23188366043952205, 0.10824443156560583, 0.19851316157127583, 0.1633701344291049, 0.09180752485389672, 0.22971523324808768, 0.08071620347759417, 0.11052217184295578, 0.17136669807857083, 0.15186891770891606, 0.11538339042735678, 0.17726274057021066, 0.16978463458438076, 0.14764550562587478, 0.07226982364250768, 0.1241748009417807, 0.07639057228281614, 0.1518480954391341, 0.14420066870027973, 0.207122243159721, 0.14061330877725156, 0.15341007210794957, 0.16247758071028418, 0.19985799827883322, 0.16400793326958535, 0.19878441798350505, 0.13066463052265107, 0.1831447176875607, 0.09275248664761744, 0.13830621967152243, 0.20552871899018366, 0.16972330158516286, 0.14358599039335407, 0.25699577744930024, 0.1865661582879482, 0.1771989254461181, 0.23352003956754364, 0.1841428536441057, 0.1628482906568435, 0.19022009125159633, 0.25084566955845206, 0.18260272580289072, 0.22343729592619405, 0.17417791900375199, 0.1205804389751246, 0.1961653931967674, 0.1426346317654656, 0.16619356679579905, 0.1705241392576887], [0.07818068227460308, 0.02756136713639623, 0.032881547081013845, 0.03045813326964215, 0.07611232914871748, 0.043638850291890484, 0.06582028262557522, 0.04453559834209662, 0.09836262512591579, 0.07053285717002808, 0.1368256628272995, 0.08810553519475846, 0.0661645318952299, 0.06527506551074405, 0.0456713734855575, 0.04449681897136954, 0.023849876071777076, 0.039748065924692544, 0.022033079407147823, 0.03376552827596184, 0.020231644720620206, 0.04533946206192336, 0.019204167596575235, 0.04418273441373341, 0.01917976003530766, 0.03804194598248409, 0.04570526521532767, 0.040502945982640794, 0.016756702454820756, 0.0574973157246507, 0.04877857631072403, 0.04315487807616592, 0.02439490741028661, 0.046172360514080336, 0.016694863837572838, 0.09840683606002601, 0.03722104829766097, 0.05027664592489601, 0.04046356140245353, 0.08615199566608475, 0.08993558901091737, 0.014175440057090694, 0.16892891437295945, 0.6505885864457777, 8.014009739122084, 30.717206539646273, 54.504851910375784, 68.13566484758931, 70.12346713773667, 61.73832616498394, 63.71345135473437, 51.98701189410303, 43.883171542998284, 51.71793337791197, 81.48666766382034, 59.20298453300231, 19.700002208832775, 18.72408316981408, 17.830698643961263, 26.674245057567475, 24.145236092229045, 29.890176749998528, 37.529681036549235, 40.41624738324074, 38.99282709244759, 54.80385418861143, 53.25911891075873, 59.348649594091604, 63.1085983399422, 63.62220525741578, 33.18138853196175, 23.80499989755692, 16.607913471037342, 8.19884260815959, 7.251214154304997, 1.425034468693118, 1.3937155686078535, 0.4061923812954657, 0.4166578471420273, 0.26240426626416946, 0.31241660036386987, 0.04668989121132801, 0.040017989343933524, 0.11619715200316523, 0.035192098904160724, 0.02745992943434225, 0.11645743803631876, 0.02863619807026079, 0.009474240960703503, 0.11711716231319214, 0.04766631240565931, 0.1616371822573485, 0.04009694619584949, 0.011109050566090212, 0.15361941329413845, 0.20230402509050988, 0.23803450377477756, 0.9807379159235186, 2.1007898401829506, 2.8975364806190615, 7.430962651006638, 20.1992356008099, 31.434382507877967, 36.31830015490132, 52.32479856860254, 50.26989629191738, 38.06696338038291, 34.01547270436441, 28.70500122347186, 24.38291995756088, 16.47202883997271, 30.6358055914602, 20.231075440683675, 25.274553145131758, 24.768510518535493, 24.674448159433183, 33.3726550686744, 39.39626247652116, 39.12629358230099, 51.245276005037375, 61.70693151412472, 68.01324767451133, 58.49527128281132, 33.706633121736594, 21.973386387671194, 7.279520919246059, 1.3191150297080318, 0.035643382148156245, 0.05389129389978705, 0.05742772812804869, 0.09687817655503751, 0.07534614929388608, 0.03390031761579937, 0.06702135527326215, 0.014665282421535062, 0.015010444293429535, 0.03757067933498371, 0.03873425197877711, 0.03147704744591348, 0.036368836768932884, 0.08870132177347138, 0.05628205129816648, 0.009065646051068701, 0.05333409133938052, 0.03786028355299946, 0.05086030916220719, 0.0827543344348669, 0.04407177423878063, 0.026645792475450906, 0.012896369125003056, 0.06258910379162239, 0.05780356703326107, 0.07421996940167681, 0.005671171745615862, 0.0652020879750771, 0.08423188055354743, 0.06502283106167471, 0.027772227091895, 0.08829288199664125, 0.03501855317623385, 0.06404275945838421, 0.04221516781516614, 0.06178269665988703, 0.09522245370692785, 0.09515269374054286, 0.018544077512718016, 0.06351111359113167, 0.012745951591510207, 0.019954975897205934, 0.048596982829152584, 0.02126726535930028, 0.02673791263312582, 0.07165402684721255, 0.06496375802183343, 0.05546450524801209, 0.04150880027502295, 0.016537557258420897, 0.05719907386528869, 0.08872828806840605, 0.020046735993556438, 0.035064943630488656, 0.05058082113523157, 0.04527699525257753, 0.007836215701254626, 0.06651069638469527, 0.11659821435328453, 0.13342905879741715, 0.065290555808573, 0.04599810998526312, 0.034114285973050905, 0.004690774554957546, 0.04233181619295671, 0.010400385719784086, 0.015096168574546615, 0.03995230879574534, 0.012878484802410729, 0.0033118337676334647, 0.006838763478182017, 0.07523136634019113, 0.02381345242141716, 0.0229147125426079, 0.005336269706247314, 0.05570514878678707, 0.007629325038813536, 0.08053527649251685, 0.028974389499654214, 0.010361595815348049, 0.026297599768206, 0.006411364461640798, 0.022874674872465195, 0.03554346513063197, 0.07129660852613949, 0.0420936203050998, 0.017542921254531513, 0.06812852086319078, 0.1327218217474799, 0.07846407351955291, 0.03241348651147658, 0.29545584272953773, 0.8763008264283981, 12.259881804066321, 38.0381888727988, 65.90085521821054, 74.52530783991661, 79.40883913347798, 70.66980623429822, 70.23800034676829, 57.434458424968106, 55.3563553287137, 52.98691818791052, 84.46901829011979, 64.23130619910457, 32.230264755987356, 27.398981394306308, 28.601774246461932, 32.092134567999075, 22.260005743272846, 27.664674905038652, 33.75529796846452, 31.84369948602492, 32.43276299968843, 48.15724103681503, 37.69618565036405, 48.23187197408369, 43.59621486356182, 47.79424528921805, 29.4344973564148, 20.74536288938215, 12.358382325018606, 7.048792396822284, 5.218729694043437, 1.4180090134182286, 1.1662288851314977, 0.48141850759425475, 0.20865311665881067, 0.15501053703408088, 0.032068135990430756, 0.019345357601020127, 0.1256739660616844, 0.042438202823001536, 0.074809895407769, 0.018686112129099427, 0.11318746067944074, 0.042315287845990354, 0.016148037938100678, 0.10362554957429249, 0.08549420959165982, 0.15521255441971366, 0.08638611979662411, 0.1133271951168295, 0.09445186884653184, 0.2962054750852047, 0.32406061587314455, 0.6068233316463809, 1.3961927905198068, 2.5016041003888656, 5.788013675520498, 13.253839823507494, 20.24859078468815, 28.78769067025954, 38.42666041466498, 41.04326178950649, 33.65070404544954, 40.03638544390279, 37.95590146895378, 38.37261015369047, 23.421566640177083, 39.23413522781865, 30.067542406820483, 35.873075839011904, 36.55483476577267, 30.36554055829202, 40.77816055667016, 48.543476827682994, 47.69649982452393, 59.17495527575093, 70.3218763105331, 77.9030647585469, 70.75194851044687, 44.15753349181145, 29.36587549025013, 10.308998823165894, 2.25199917151082, 0.3627724176453006, 0.14141684307927085, 0.024416032284798644, 0.013948199226551, 0.019693828015137586, 0.02491881387428411, 0.05745993063394582, 0.03734401690082685, 0.01543262002674202, 0.016512136545873458, 0.017986857715333184, 0.07427629218586991, 0.00899818913650609, 0.03701186032905694, 0.031417489855460105, 0.007319241854166913, 0.015524100501000162, 0.03989244285490244, 0.03575726877897978, 0.07560350887116886, 0.040424521561832204, 0.07225041863538566, 0.04573686634220424, 0.07897601943583259, 0.06304687963077618, 0.07983900216077605, 0.05236727688761969, 0.13885005016721066, 0.041277767309258064, 0.04469180366985741, 0.012024246013513016, 0.029565759581483664, 0.0686378620805279, 0.050659800969785264, 0.015957711054192438, 0.06533951648781378, 0.09447083718353703, 0.03306897049168906, 0.05358741746374196, 0.048124302749431906, 0.0666951320524658, 0.03299521920721858, 0.049858702827365174, 0.013321135193109514, 0.02526941592805088, 0.04210996862140395, 0.029752851659131628, 0.023280216921721737, 0.0696893100957236, 0.15546200796961784, 0.129817184060812, 0.17729675487404872, 0.15050368774081432, 0.21623089068358947, 0.1472530387822659, 0.21085923537611964, 0.18767841070169405, 0.1368138497515071, 0.27474569757619216, 0.2744439815080935, 0.15474081279770022, 0.14044798700319183, 0.13353674011605401, 0.10059910390766398, 0.19267491275264373, 0.11908498938165366, 0.21735494085136922, 0.07951029681510503, 0.1353011018927059, 0.15774933200690056, 0.12066084756365708, 0.11347856642978807, 0.09504090619063187, 0.12945470189855945, 0.08336306789950018, 0.18274229170093614, 0.09424358486167847, 0.14748945351569884, 0.10995479946535443, 0.1625089749934212, 0.12666379762513022, 0.15289880034904327, 0.11461701905054432, 0.0923666311427951, 0.21543536966125812, 0.07784070011468665, 0.09479811760566889, 0.14141342632712858, 0.2848937885174828, 0.3055757722787319, 0.1696519175123784, 0.6459618443923613, 1.467524156455071, 16.638637396597094, 48.88146746543146, 78.39373757762294, 86.74203180497693, 87.34805368608045, 80.27972298283731, 81.50296118951614, 69.98707063736455, 60.339483445690526, 65.00185581945604, 93.12150016907724, 71.37720569487541, 33.33174082540697, 28.825263054140155, 30.394893615476548, 39.84801361637731, 34.164852250006895, 45.09953775713521, 51.10640448908652, 55.30438392393051, 50.987129134516564, 72.91709684556531, 71.47430004612093, 76.63776305414017, 78.81609055303758, 80.69746325092932, 44.12312253828972, 30.550790179160337, 21.639908436805975, 10.630785169139987, 9.213399444856952, 2.2813514932509396, 2.539436096145261, 0.903871656665879, 1.0356672781129037, 0.780971909482633, 0.6377284216784662, 0.1425441414598496, 0.3021471917388901, 0.23796148027383515, 0.15085306979956167, 0.1192095782607794, 0.2742394666758276, 0.14749827884858654, 0.35299183440304577, 0.27247424688070054, 0.2611617942250544, 0.41536312790647634, 0.23399456974960145, 0.18628077521439523, 0.35092499047037096, 0.7817284366296184, 0.5779867402968869, 1.8186566954658878, 3.678629431993731, 3.9326636973888647, 10.982732580554101, 26.398120003361857, 39.12895687164799, 45.30512486734698, 66.8222435059086, 62.90802794118082, 50.318247349031516, 46.70981191819715, 43.21605874646095, 38.024519412748276, 26.704188431462935, 46.191341261709894, 33.384947776794434, 40.73322980634628, 39.02600642173521, 39.10582665474185, 52.23783569951212, 58.70404727997319, 58.38779441771969, 70.93346795728131, 80.70885381390973, 88.9782299533967, 80.71805569433397, 53.23126616016511, 35.30690131648895, 12.694046016662353, 3.252403606330195, 0.5238249369205967, 0.2671568918853037, 0.08833250406408504, 0.15968902066590326, 0.16202018025421328, 0.0967897623476963, 0.18235806796339252, 0.12683992889980156, 0.2599389953238349, 0.19129892691008507, 0.12103086803108455, 0.3132626372239282, 0.11060389044183878, 0.15263371860548375, 0.17768534531276073, 0.27749828213164884, 0.17407533983069082, 0.15155788601165818, 0.13584050440019177, 0.1640544041630722, 0.21921308711171153, 0.11143938593205907, 0.1522637747468487, 0.19228095969846173, 0.1509317010641098, 0.2540987546765997, 0.1783935169899656, 0.15840950061477002, 0.17899416056611847, 0.14492725713118432, 0.14710712967620743, 0.145655868034209, 0.19099298203664442, 0.1733395736664534, 0.14241729262134722, 0.2282140686387016, 0.2360816690469942, 0.2288219287631012, 0.1849831295229735, 0.14989863149821758, 0.17166895040821645, 0.19092150603330907, 0.18738965684127423, 0.08580259062469968, 0.16995793899461148, 0.1710748032576615, 0.1277690556561274, 0.1858561020344496, 0.1535660476093331], [0.03603962197479221, 0.04973719745213467, 0.04112796647654426, 0.01885969807664233, 0.04087651343715768, 0.01667405305910976, 0.02472322396633606, 0.02405145870251281, 0.057655991685967294, 0.040119637720166676, 0.026458629534669945, 0.011855527597119012, 0.03752482897271553, 0.03177054339058457, 0.039937435198695435, 0.010803418831088612, 0.04530719826899229, 0.07159806412434386, 0.006661160835891121, 0.05642932787116978, 0.1051378531020976, 0.06312479077267551, 0.042995654361983465, 0.026206714927308986, 0.006085045958658861, 0.03746268008985827, 0.0311743009895567, 0.06391217594125098, 0.026838875360666748, 0.08300492179489906, 0.07753928282087849, 0.042722191616532304, 0.016541581135243177, 0.0368877349331254, 0.04584392329918281, 0.024873656821587396, 0.008259766562391193, 0.01886808290897358, 0.007476136182254602, 0.030088721842114485, 0.021554887324811953, 0.2802134815964007, 0.4299145083754294, 17.20828910027781, 50.03283216107277, 67.93317640981367, 66.67433092671057, 72.40992653754451, 61.08889149081323, 59.170279810505534, 46.1743103304217, 41.238062381744385, 39.1613870282327, 51.43425972230973, 27.11116179343193, 34.98741642121346, 15.523843899849924, 21.46699074775942, 31.39889878611411, 39.88245594886042, 82.90505163131222, 56.01687462099137, 55.47631317569364, 64.90755027340305, 64.1910195350647, 45.13188946631647, 56.53743982315064, 33.98770624591459, 25.45748660641332, 11.075719229636654, 5.1552181859170245, 1.080378743429338, 0.46201399076850186, 0.15443718150979088, 0.04836031911714424, 0.07270268630236387, 0.07313554130134083, 0.07342445604022473, 0.02966051125117848, 0.10296974000671219, 0.03761765584650059, 0.06539217737172881, 0.08259497282485809, 0.07081861562666393, 0.12284789835253071, 0.1883548816605922, 0.07918936726186546, 0.030669259440694607, 0.0641365056376784, 0.057746566261254975, 0.06830807655088364, 0.04680401915984769, 0.06038413037576022, 0.04469826945193833, 0.06059960026534335, 0.09946234434122041, 0.1558943420288063, 0.17805401746544147, 0.16806472122909563, 0.18048556521534923, 0.1474975893694547, 0.23562794581295984, 2.381943863245749, 3.3314305399694755, 10.319954003057173, 23.612895934812485, 42.58578092821183, 35.40616473843975, 46.16274718315371, 36.864482356655984, 76.18913804331135, 50.75759987677298, 28.019892592583936, 27.862221156397176, 19.951420253322972, 27.900693724232337, 13.917092027202731, 24.970396872489687, 31.049435215611613, 31.6627017144234, 48.637558798636164, 58.94962687646189, 63.815181947523556, 73.61028948137837, 58.31883130535003, 41.727225088304095, 21.964162934210993, 6.506495793019572, 3.4595003387620373, 0.8326673387519775, 0.0027691823291412045, 0.04394679082437389, 0.06366028623174756, 0.024733832368867534, 0.02457143705067856, 0.0790932845144022, 0.040400225083313646, 0.017697550356388092, 0.08565859673845191, 0.041318768334965554, 0.011047271320656424, 0.07130169534995671, 0.04125357425260929, 0.07047626625506148, 0.021813212172879327, 0.053055744783412066, 0.020629332453433066, 0.01314697276440359, 0.05127049561950469, 0.023441233281647007, 0.05851435107028773, 0.02144857347311993, 0.06129491315673917, 0.04862040979787708, 0.004178705585805039, 0.07445815379821485, 0.039908576666587786, 0.07016256091094787, 0.09217468015248738, 0.054572859343381665, 0.10438992146162257, 0.04399200916410454, 0.06519749144753141, 0.056316647828826984, 0.06383158349161668, 0.06673037975786195, 0.04725738616299726, 0.02058675711704118, 0.09181134763263887, 0.01377270955051626, 0.03422631484065806, 0.03075669688593236, 0.04110248256174307, 0.04889440880487523, 0.08903157461674945, 0.03750924291389604, 0.04422573875936289, 0.03041999358233185, 0.04042508463645655, 0.025696488878419323, 0.014488960582492574, 0.036278541815737565, 0.08597588737405117, 0.05576672693414073, 0.018742685807087732, 0.027679465335583495, 0.04533286604489531, 0.04126822185372153, 0.025484127390588966, 0.035506723553783474, 0.019717457997162017, 0.030967983935448914, 0.06117863633159188, 0.008994180581442291, 0.054232942300938794, 0.029326686522953456, 0.06671800743788481, 0.04331918478372597, 0.033051089999536355, 0.030852695363723946, 0.05717240251420487, 0.07950290406663572, 0.0023674525249178613, 0.04428795275969371, 0.026540309829156727, 0.08086027397263436, 0.01574014208369678, 0.061177008394752784, 0.07359006892769568, 0.0460650239350094, 0.021600482962845315, 0.05145874640513813, 0.02346454150674324, 0.10802012868225576, 0.06482721817108893, 0.0938962022924135, 0.05641452705247268, 0.1944446065012486, 2.1901948750019073, 27.000523497981412, 61.49868895930629, 77.75259479399651, 77.24594223883845, 80.49587695829331, 70.13907817102248, 68.15283698420372, 57.40508379474763, 54.770510119776574, 46.08208364056003, 53.18286018986856, 40.234904443064046, 49.32083176028345, 21.11079639004123, 27.754948254554506, 27.210609566780832, 36.61099526189989, 55.911076530333496, 43.53904239593014, 41.916691257107644, 49.5634852686236, 45.400038380776685, 37.65343966022615, 44.21709860524824, 31.692898081194972, 22.769043099495676, 9.425575156365673, 4.625118682461401, 1.4270640501091558, 0.48815208336999344, 0.12795598110965184, 0.028818151613156644, 0.09080692975511474, 0.11112034095511322, 0.06985241021480292, 0.05637339962225768, 0.041699996668725245, 0.050456454421603875, 0.15521698240791598, 0.040565723057595954, 0.05226798806219332, 0.06869909548831564, 0.14404202721291973, 0.03757802228773794, 0.023933716734210332, 0.07116811259859993, 0.10885520282411769, 0.08630153602890431, 0.01938194021462433, 0.03172626542378097, 0.06474158486291286, 0.10330333299334012, 0.08160714841177387, 0.11757689933743208, 0.23446742985998434, 0.13292023851986856, 0.09548939704414337, 0.05120803264059848, 0.23542189880484538, 1.197077591092356, 2.3722190818478985, 8.38858481376402, 17.181983724717174, 29.58100768827623, 30.681791459360433, 40.44003263596566, 36.16365286611742, 61.27767908957697, 53.52420837648454, 33.26345236070695, 29.760779719198908, 28.70096314337946, 33.13541050880186, 26.20159749061831, 37.0872494482225, 39.64692938712336, 41.37747910714919, 56.82822473587529, 68.61716716520249, 73.1043743318127, 85.76070970104587, 69.16356117494645, 54.57043786202708, 28.32847329878038, 10.61472894683961, 6.4628251041135485, 1.6366242761573486, 0.13978553545330802, 0.0262000423014885, 0.04638142590861648, 0.012995822659333148, 0.04609520779922605, 0.0709253316745162, 0.023210642731658394, 0.055742258085839214, 0.057459651011853456, 0.046402098791253184, 0.012079313371120202, 0.027324866218071793, 0.03599613499377043, 0.043847027024434465, 0.008452266263174675, 0.016877016563329007, 0.019495528071157394, 0.04819058850708027, 0.04666779340515214, 0.12180425677328341, 0.05898294024049275, 0.03468775641052954, 0.03440964734181762, 0.03967341065647141, 0.07235984663448988, 0.1093132850984412, 0.017927704236259865, 0.045657105097967776, 0.03147603620985343, 0.008115756396775045, 0.0518229867391769, 0.01572044787838334, 0.07731314898738939, 0.09092522905238214, 0.010141533228658862, 0.03451164428805632, 0.06370619022017045, 0.022940713566757982, 0.013183530480150255, 0.053493069905427196, 0.04484433560602127, 0.056302325815082564, 0.05605288375649722, 0.06529145213144441, 0.07168598037453429, 0.06138455693519885, 0.08529637504609362, 0.20206353476931974, 0.13512476377429503, 0.13466200070275416, 0.1615236020616947, 0.12319314353648694, 0.13230750607627054, 0.1520402915775776, 0.12470095778905577, 0.12469436177202772, 0.19272564309498957, 0.11387431212971288, 0.0918276729663053, 0.20810850475343967, 0.13475871164231532, 0.11386676616365872, 0.19379922339031774, 0.09735847537916514, 0.15244803421439665, 0.11259286919788969, 0.1639234337715372, 0.16995387872861278, 0.11739568889982278, 0.14141377872757374, 0.14450860540232352, 0.1686330818601193, 0.10039144045402927, 0.11614171788096429, 0.1420904488693322, 0.2528864358581843, 0.16451698337351123, 0.16736551278060482, 0.2040748373274842, 0.1262893261868627, 0.13051423214135632, 0.13577673524137468, 0.08358914044595535, 0.1715735264963681, 0.14978926478614732, 0.18519185783882297, 0.1967151072477141, 0.5558851649684291, 3.952206171328022, 35.73460048244846, 72.2346358145437, 88.8128157584898, 84.86370286633893, 90.60999870300294, 80.7774325340025, 79.85357315309587, 64.15114864226311, 58.02190396093554, 54.73346333349905, 65.05103449667654, 37.0765531447626, 45.6346078841917, 24.15499887158794, 33.7965730697878, 42.77267794455252, 57.23345656548777, 104.17894409548853, 73.82201117853965, 74.03956936251733, 82.38668687881963, 83.7570845696234, 56.56654380982923, 71.58183574676514, 44.88488997182539, 34.46724345607143, 15.14780725202253, 7.201579991848239, 2.2180944488894556, 1.0682223376727875, 0.4009619619577162, 0.26964775016230924, 0.23254001392952858, 0.42732267971000365, 0.25114070533985094, 0.2354314595821404, 0.21586626347514892, 0.21341108957365637, 0.42855936012441115, 0.28472693456757453, 0.1708870963944543, 0.3906330742662953, 0.3527834278441245, 0.2290648858874075, 0.1105785865576998, 0.15497258503831204, 0.5125560899896007, 0.23193062162928044, 0.11031512892053974, 0.22928176537877132, 0.19664786004972076, 0.2580583414002772, 0.24099186363239444, 0.4219301561674764, 0.5320018529891968, 0.2781011933280576, 0.5460912517962918, 0.3930371807467553, 0.70301896982616, 3.197481108288611, 4.460799809425108, 14.196040207339873, 30.86943960958912, 54.47437509413689, 48.05271379409298, 60.345794539297785, 49.28566771168863, 92.5264766139369, 62.25880115262924, 42.88854475944273, 40.53667591464135, 33.06072858072097, 42.388062092565725, 28.701853521408577, 40.04439884616483, 45.64251538245909, 49.38804157318608, 67.66838504422095, 79.36823475745418, 85.85261083418324, 94.8190627559539, 78.31596482184626, 61.70190303556381, 35.3801162781254, 13.839521273489922, 8.242770702608171, 1.9532291711338106, 0.19763902460615482, 0.2012783559339662, 0.1586337345502069, 0.11665634510497894, 0.15693246777499878, 0.16812675902920385, 0.12499426987262503, 0.18436503446390554, 0.19653499997671575, 0.1550827178383066, 0.20623571089198514, 0.17801252614346244, 0.11025691389917366, 0.16588066584400593, 0.1063687035874013, 0.14996089912470312, 0.20891752424499682, 0.1228491164323303, 0.12330564354816753, 0.3923526045776183, 0.15274933659501616, 0.21460709071928458, 0.21112774919357993, 0.12197588345095997, 0.1540221457159327, 0.17636899175422807, 0.1619383773856586, 0.17082075318021162, 0.13432685255763993, 0.17686601427774276, 0.2662848693228537, 0.11781602602211699, 0.13261709752823078, 0.1634307013403985, 0.16922301552709074, 0.17584170875770433, 0.12974356301128864, 0.13378147456434467, 0.27484927266355486, 0.18606535129008756, 0.11189315513136888, 0.11290327270304966, 0.14879325855403178, 0.17914981431057378, 0.22598959445472688, 0.08072125965789442], [0.06571837760988744, 0.050050573378440835, 0.09103562232227096, 0.09944094750549524, 0.07111067132603738, 0.023996654687629595, 0.05161429289728404, 0.009253081910672688, 0.053921523729279164, 0.03461755977402772, 0.03297165434266771, 0.00740864527254035, 0.008555021636458415, 0.005344606179278345, 0.06543184540444805, 0.08106668104207324, 0.015588558181339215, 0.024264327723593004, 0.10844495507978624, 0.036960926973411155, 0.0893582804729381, 0.034228371786734754, 0.005556437630026091, 0.04196040144550704, 0.03807340921353429, 0.01777297937341275, 0.013758490958641616, 0.0202680281513641, 0.03140931378208822, 0.023886339941753015, 0.0440075722402863, 0.0592700393509961, 0.058624671561823744, 0.027912608873579773, 0.03360327085359924, 0.010360226433183397, 0.015805873385209952, 0.018368191386182463, 0.03145640520679374, 0.02963226750463007, 1.2684551674512126, 6.453428576069494, 35.8139657205151, 59.12883996963502, 63.30954920861029, 64.06979084014893, 65.00376601372996, 47.22952204365885, 44.09121405693793, 43.250642284270256, 28.37569275209981, 13.88594840803454, 24.18748982491032, 30.299297609636863, 15.702584347417279, 29.20213418622171, 47.518451675291985, 51.238553062562026, 62.74983875213131, 47.20275186723279, 44.38357184010167, 37.22113563168434, 38.978808541451734, 32.764538641898866, 19.59036215659111, 22.311106381877778, 12.354961037635805, 7.165149017687767, 1.645970793981706, 0.46960733169990204, 0.09964774527977552, 0.12994118305223604, 0.022042088601137363, 0.047452903292592497, 0.09639004065144448, 0.04581117687085944, 0.05974780242409437, 0.0354790409666396, 0.032144206606092, 0.13453368097543716, 0.07722037573975903, 0.07534907574975684, 0.02829128613455161, 0.09813596269175892, 0.08875946018604502, 0.044375064617563645, 0.041482921824940754, 0.0973838099068211, 0.21413632968981422, 0.05443378374160779, 0.06885554596421219, 0.04725218059555177, 0.05186173929682663, 0.052332592256847894, 0.05937281770691757, 0.06391093487881365, 0.06124804006709207, 0.01643320459181503, 0.09283473384716819, 0.06927242036908865, 0.03214196579891347, 0.06905464455485344, 0.009378330583023209, 0.022860808681035717, 0.06374257556613415, 0.6756518576895038, 2.2889905543096605, 6.194325627819185, 14.125918034584293, 28.96155953407288, 42.15638337596771, 48.15465619487148, 49.80466788814914, 45.530841581283084, 36.045381638311575, 22.83829842844317, 16.13025213441541, 27.272724220829627, 23.393996300235873, 26.5274287808326, 32.594219523091475, 37.34758892366963, 41.78622930280624, 52.94776901122063, 62.9629332788529, 69.23931783245456, 59.89729504431448, 53.94891869637274, 43.0980856187882, 24.163598668190744, 7.381274065663738, 0.06229319466998982, 0.08149876995312591, 0.10612869590160348, 0.07389858019568267, 0.030065063131792896, 0.059291221682102456, 0.07622541904809975, 0.11429846436987001, 0.04413773057862155, 0.04014190789612551, 0.036923469104353464, 0.044930447719150016, 0.01596735322832941, 0.036945080444697416, 0.03649113504516502, 0.011768247199905737, 0.09497035715368488, 0.021572974660704215, 0.047243826406737494, 0.09709680272686867, 0.08822286922124126, 0.08460162522932214, 0.01279587466870585, 0.014794069462485853, 0.10335973238632565, 0.03290431521412346, 0.013701305367923794, 0.040582672752920664, 0.038007307316987746, 0.05093230993577069, 0.01973928384212477, 0.026000528108148326, 0.028903886427982684, 0.011476914496010831, 0.053176756031931414, 0.06204367983305167, 0.04402859369292856, 0.05134688990731394, 0.016518604243174195, 0.072814351278207, 0.07032472640275955, 0.02035559774676879, 0.06489066557297785, 0.0962338736280799, 0.0161512095421072, 0.04426783912124173, 0.13012620860770827, 0.04038298044413809, 0.04678604673714407, 0.022591046140258832, 0.010458344101695525, 0.04990050824539316, 0.07934659148656553, 0.10209430835299915, 0.06230631775613274, 0.04119692971148799, 0.05672317621628604, 0.038623831895810944, 0.025522301551855864, 0.034830378999392834, 0.04446283531104846, 0.025606075181595744, 0.10488024837667904, 0.049587626445798144, 0.030107923835936575, 0.06417268030946294, 0.03908454568215436, 0.030383349681693702, 0.021713417729422934, 0.026854493978223013, 0.04580438933185032, 0.05073384719810659, 0.0747804929532351, 0.06357843356747782, 0.03771569977905001, 0.053973104429220965, 0.020186614072431, 0.02364691831321726, 0.028499244532037168, 0.01880689929690092, 0.05275893933890809, 0.005327758469408559, 0.021310271620149576, 0.03587834131453307, 0.04526626619119798, 1.4836355370859948, 11.612270051433194, 51.53778676063784, 71.89960264390515, 72.17768299964168, 73.94500101766279, 72.04681704121252, 56.39413995127524, 55.81680628561205, 55.27273431901009, 39.717787004286244, 22.64955005338115, 26.51740908622742, 33.66240839804373, 20.088320778262233, 39.904550660041075, 41.23012350451562, 39.94226032687772, 49.416466989824855, 39.6723267339891, 44.41220121998941, 31.45703615680818, 29.93050263774011, 22.988603653446322, 17.795132552423787, 18.099139774999312, 11.567339301109316, 6.048436501333791, 1.769602063202089, 0.6200484607008196, 0.05063484565565183, 0.17013121276132523, 0.09044143686731977, 0.022359201121294213, 0.08971496334960384, 0.05676379036759177, 0.21301312221875116, 0.1721268411605589, 0.08993103078776792, 0.04851038425019191, 0.1870290898988324, 0.1308908256431741, 0.09438410836962924, 0.08676638285959921, 0.1261559196357285, 0.1285187876032245, 0.1951010978870815, 0.3303646308279807, 0.46400661610307237, 0.20769043525140132, 0.19659982633686837, 0.09583974437367532, 0.23737574476868878, 0.1656616872717296, 0.027848665429759892, 0.043367670488453684, 0.11793007353140463, 0.043875544647415804, 0.07605375406602699, 0.21380931739845585, 0.12824221454080076, 0.026792000355799834, 0.009307602473023919, 0.09770060258526957, 0.013989196421818869, 0.5224104934642392, 1.9439239607703303, 4.730865782307041, 11.714260501246299, 19.368591347048362, 38.291299420018355, 39.28660085124355, 41.9801434393852, 47.093000027441214, 33.509082948007894, 29.144161555074877, 21.76632642745972, 29.28959519632401, 28.741504761480517, 35.20544921198199, 42.922975324815326, 47.605681265554125, 51.652418028923776, 61.17837644392445, 70.78133490777785, 78.95189085314351, 74.23708423491448, 68.92333953611313, 54.074563980102546, 33.47036915440714, 10.642074731088455, 0.740932354763631, 0.13957100019099253, 0.08851366087553963, 0.1367160816106104, 0.023907637186048013, 0.04313926137382946, 0.0935164601692269, 0.050449184247202454, 0.11887946331332769, 0.05835788144219307, 0.049156426196737636, 0.020717876895721403, 0.0583832657655641, 0.030367654455345006, 0.0038286982077894915, 0.11049066264663013, 0.06086770039532454, 0.06898758887884117, 0.009697117962904516, 0.0419525720269209, 0.1137884260125218, 0.07272671081966932, 0.08249480682875841, 0.02243507063887533, 0.10060255896420249, 0.023763043835999507, 0.0620136721690576, 0.03295305372786618, 0.035736775927005276, 0.043302801993465236, 0.050141542489009525, 0.02762940915061101, 0.023053452980914907, 0.029031415169517842, 0.03796382799684521, 0.08914614306582559, 0.009750793913319226, 0.06546559157751261, 0.007676137320231647, 0.041673769648637504, 0.04359326422995618, 0.031135964034605893, 0.04201492775351771, 0.07255343705295556, 0.05237076641811479, 0.11819795915676702, 0.18087161224215262, 0.12545308759135584, 0.17858880812362318, 0.15185733445950095, 0.13521457992253766, 0.086167968599306, 0.1510473496971592, 0.23504170468978344, 0.12375374369683767, 0.2405412966806081, 0.23633479981893496, 0.1431309954533654, 0.16455093639031534, 0.19354244603985743, 0.17915067232904897, 0.07294079409010949, 0.1669347721842989, 0.1584807467917281, 0.15889205939827428, 0.26036990445948416, 0.15570637469570484, 0.22052507396907578, 0.15583199779352835, 0.1082636297289883, 0.10421407363948323, 0.12008733882178223, 0.2328467555344105, 0.18911458041158416, 0.12647338647155032, 0.22436605496031625, 0.12045717542810787, 0.19593631758564906, 0.10686139005326456, 0.17871789393886445, 0.11460062476896471, 0.10836378806420874, 0.18164704643910934, 0.1564233870275559, 0.13431712324100156, 2.1508069240277816, 16.862387041891775, 65.72169311584966, 83.58145652278778, 80.97477482211205, 82.06789232069447, 84.10514000923403, 65.183614530871, 62.061576535624845, 58.777576031223425, 42.20586407569147, 27.383795938184186, 37.437277840029815, 40.202238944269, 25.084682972200458, 41.985038557360255, 64.11789086557204, 69.55603353438839, 82.62029540154242, 63.51732500137822, 57.61349501148347, 48.55680111915835, 49.24185483686386, 41.04053181986655, 25.2026992459451, 29.47089106805863, 16.961934835680072, 9.282649870841734, 2.8903499630189713, 1.0003007984449788, 0.4850060054131093, 0.39198892731820384, 0.24098579621603414, 0.1877102033505517, 0.2964040144316612, 0.2625468505486365, 0.519885222517675, 0.3150246088062564, 0.2473102350749316, 0.38137894664560595, 0.5077995419982941, 0.22258444088360957, 0.20168023033728524, 0.29637576110901376, 0.22548845037817958, 0.2752818671926376, 0.3120450477205938, 0.375439957264931, 0.6186065606532559, 0.5548547460667549, 0.3796249117341734, 0.5289163572653648, 0.3640427446413425, 0.24962201263875733, 0.16485536440966592, 0.20796300933486034, 0.20389261565381483, 0.11995515035044764, 0.25441914796829224, 0.21460879143447648, 0.13225320576419755, 0.19515355958813624, 0.12642637931651649, 0.2409986358496451, 0.18476681693667368, 0.9809114195166097, 4.002512039676789, 7.943838046443078, 18.74566012813199, 38.61483612368184, 50.589969542718705, 58.58869429557555, 65.62656779443064, 62.075406812852435, 52.19814131336828, 38.81373167037964, 28.921353278621552, 38.527186839811264, 35.716914515341486, 40.07993944229619, 46.491461415444654, 54.40031682291339, 62.23816948552286, 70.49118934139129, 82.93393596526116, 89.60883725074031, 84.95356436698668, 77.49931950722971, 63.575340778596946, 38.37170016381049, 13.61673358948, 1.464507608644424, 0.22091573284518337, 0.17506759223197738, 0.17964047830431693, 0.2128730507026757, 0.18063936502702777, 0.25063850406196814, 0.17600062603671707, 0.1408006325964966, 0.12826639227569103, 0.16879981323595972, 0.17441851657725152, 0.2021000005545155, 0.10258893302131085, 0.0947549332293772, 0.18354486073217086, 0.17265259198123412, 0.15094955091274556, 0.1368638906147211, 0.19683985700530393, 0.27455561584041965, 0.24502988243775986, 0.26403128379775637, 0.08632740681810726, 0.22253928766135248, 0.16777805112782987, 0.11023763146611953, 0.22544725016961176, 0.10390051385207523, 0.10760240391978335, 0.15877647205225884, 0.0517870304024508, 0.10883055777559358, 0.18269412009225738, 0.0757335752789532, 0.177317745683174, 0.19753042398200882, 0.22051188193501967, 0.09616986698200626, 0.2150017485743569, 0.13165144369967524, 0.11307526710292987, 0.20208015887727662, 0.14786099083721638, 0.1180985362659539], [0.024214792478409027, 0.01152558406184037, 0.03083331716967927, 0.037584020756185055, 0.07568717333337954, 0.01952648376895776, 0.036631195069921595, 0.041541780360163226, 0.03565774629673651, 0.035735864282375386, 0.010171707516776459, 0.0222600482764744, 0.08043614471511495, 0.04757121408117875, 0.01903792268656675, 0.033169718714611184, 0.013168371515348555, 0.013517712396869977, 0.03348310613223622, 0.05459478861021419, 0.046348694802051595, 0.03668539196012482, 0.020722695588765126, 0.02713152860862113, 0.03494363360767884, 0.006413313197798186, 0.040182989361065055, 0.03286060223716401, 0.03378453874780286, 0.05946208993273397, 0.07268580938539199, 0.033463651329399116, 0.013036319982230425, 0.026614752507978873, 0.02683514259725569, 0.036499983360690456, 0.048432756560824575, 0.011120945996334477, 0.11748140647767052, 2.4084056433170073, 15.880399115623968, 43.64797053798553, 68.12323877888342, 67.13853559186383, 67.38162840566328, 60.33998943144276, 53.315608885980424, 41.834211657124186, 26.13175968970022, 18.899897529232888, 31.055754153959214, 39.375018919667895, 31.841875583894794, 21.336728834336807, 49.043378983774495, 79.49156192041214, 50.33122254956154, 61.99220941912744, 38.81554380539925, 28.463420483373827, 14.291561688146285, 9.010816870197173, 4.614199294197944, 3.579222108087232, 1.842279537550865, 0.6321153873878141, 0.49930301404768423, 0.07464788313354216, 0.007454847556448752, 0.0422127086729292, 0.05522024194379488, 0.13339498320654516, 0.030846727538793802, 0.05626307913072168, 0.04778752666747859, 0.030862405528164202, 0.07651738281692229, 0.07427758687446195, 0.11104131898572368, 0.09196228993635985, 0.06701403913358528, 0.14028910036769607, 0.07830064398266616, 0.1720907430975668, 0.016455017030239105, 0.05709049622378042, 0.0488770071176752, 0.16614375575896234, 0.05521395619237616, 0.025633527942362334, 0.22478110607593293, 0.18837853845569397, 0.07443157054724232, 0.0969118231366719, 0.0999628065995151, 0.053466536450169744, 0.0509579585594756, 0.11245249124664454, 0.03919771985120831, 0.2665949204275685, 0.2540257771409327, 0.07328583243032617, 0.009663053863351385, 0.04317148686236432, 0.02975913932577016, 0.03659320093931691, 0.015594347890826966, 0.14329380445903347, 0.6399068080129162, 3.175099083492833, 3.922498629939172, 15.50063817731796, 29.726798265211045, 31.706147847637055, 52.69219913790303, 44.96163114424675, 58.3504730655301, 41.93987638719621, 27.73034126527848, 20.876911340221284, 17.82517202438847, 22.30461289805751, 27.40669865762034, 40.24129398407475, 42.747445337234005, 48.84912752336072, 63.88363122940064, 66.73807728675105, 72.1581417514432, 71.291517596091, 45.52031393974058, 25.12675235348363, 7.294441615381549, 1.1130989102586624, 0.24557018892899637, 0.18438440116663135, 0.022130014427426844, 0.054627282229522546, 0.06844699127419342, 0.043762232582535476, 0.04811221005154714, 0.05947919667608315, 0.025775183345221227, 0.09779605714063491, 0.05197702020767236, 0.01647209313007132, 0.03690790219773208, 0.058953725477500316, 0.04285848631914105, 0.0936385209582025, 0.015021751751191916, 0.06537339289582546, 0.043273993257072665, 0.027350137543473995, 0.018240810116572727, 0.035672723315656185, 0.017267436036960255, 0.035622054260344274, 0.03260385936066028, 0.02736372028237149, 0.05931315094893498, 0.045658916895908695, 0.09230482316906415, 0.0773088742167719, 0.026001535513768756, 0.03922125024180259, 0.046243047446853695, 0.04085777109609016, 0.018430658195528294, 0.055020208725886005, 0.10855822884027036, 0.09215391916973938, 0.01649714995085472, 0.03555390690903991, 0.026811116164730444, 0.04074595290266218, 0.04743210783588791, 0.02800822622262903, 0.04287093141747098, 0.07842098873469137, 0.02038387596727379, 0.02569595261687233, 0.049894287611448, 0.018445939734397877, 0.03002940748457707, 0.03169580576791158, 0.039004409054835, 0.03769136116569562, 0.019708437311853615, 0.07539643530523585, 0.0018026470206677916, 0.037854606841480544, 0.022910089201984868, 0.07995846591168836, 0.02808304045409445, 0.02597112182317482, 0.012549254686511573, 0.03750831211706804, 0.0381262616194304, 0.04034728074686662, 0.0029553967573109174, 0.015757710395020344, 0.02417328583467151, 0.09054812227165507, 0.07344042131256673, 0.05366267411098365, 0.049577349376293926, 0.07040229280509296, 0.061190414933427695, 0.08417555776935431, 0.04513168369510001, 0.07040402416380183, 0.06457610221038904, 0.00894846524217076, 0.18144358880817893, 4.0923220592160385, 22.60620786297706, 54.92649493678924, 79.21198321926978, 73.46169440977036, 76.96901505993259, 68.69430449701125, 63.28991382352768, 49.08107296113045, 38.687156784919004, 32.314474121216804, 37.00937863319151, 37.049602539308616, 35.56590326370732, 32.49592296538815, 52.558336488662235, 64.21625606475338, 48.85722721776655, 46.17973496837001, 33.065557018403084, 21.393140362155055, 10.230971113328012, 7.400942300596546, 4.306861979346122, 2.988187603412136, 1.6678990495781747, 1.1136033025480088, 0.6500198427707918, 0.1628086685893997, 0.04925927350057229, 0.05850858625865752, 0.12845437493055098, 0.10782535082750744, 0.08548177598464875, 0.114219427078722, 0.18057201057672503, 0.15000582252058292, 0.2803659330933325, 0.11766958831539077, 0.4543323658647076, 0.06603081124804674, 0.043474669988837936, 0.05937277557208173, 0.022024727133553357, 0.07885119306945032, 0.11621571431357054, 0.08932304808930044, 0.1931479873676454, 0.6572165953055505, 1.6656374354516308, 1.0868618084538368, 0.5623929286676069, 0.744515010906804, 0.6758303255323441, 0.47175599382288996, 0.2453016291462606, 0.35488290712237364, 0.38533664879298984, 0.3397905766483276, 0.2294434865395869, 0.5467712927249171, 0.6186746505479659, 0.3462705773211295, 0.14694323282568686, 0.032781499828542435, 0.17649760259495628, 0.06457961089308224, 0.1187502472631393, 0.047270811853870276, 0.2176456405751167, 2.1234096586704254, 3.1002813433447196, 12.960147453892617, 21.80432046613386, 30.025194537255075, 43.11650899148757, 43.15484231518161, 43.73709463304089, 41.31362292074388, 30.225223648932676, 32.3349057474444, 25.64047301969221, 30.28447497275568, 38.0768399084768, 49.69746558896957, 54.84730228301018, 56.36833075554141, 73.29018485161566, 77.11301311369866, 82.07886711243661, 82.33817500452842, 58.54503831555767, 30.413815129187803, 9.8498079276854, 1.3705811841833977, 0.201620337583365, 0.2547511857964339, 0.09904557718865334, 0.02148712110224991, 0.05195550462831894, 0.10107699721570938, 0.04226501332595945, 0.04131138324737549, 0.0255861300824871, 0.12587533993346076, 0.06382030284693165, 0.02232770724672704, 0.02003304791756936, 0.025662407541887897, 0.011339476407175104, 0.08040720957421488, 0.018692497471948306, 0.06279451111632009, 0.05105259723120159, 0.015653790568091696, 0.02319713851677314, 0.06799351318829483, 0.02744484133267355, 0.08475722534762276, 0.03872165749330194, 0.02793805256876494, 0.023351836566542907, 0.0498250792283685, 0.038970061502749884, 0.038769936354290095, 0.036358846982400266, 0.018564097305399277, 0.03700969230023123, 0.01465941706086479, 0.08458530755653497, 0.00219641525613805, 0.026353028144747503, 0.08034186227427376, 0.05405394585743066, 0.014938149533625093, 0.05039155528309846, 0.036006649550531185, 0.17129897590606444, 0.14932781938583622, 0.11746037736414902, 0.18419753700014085, 0.1614902465934715, 0.13791425844594357, 0.20186642034640237, 0.08832583143826454, 0.09870023241326695, 0.11743863578885795, 0.1529361394744727, 0.10219714799595457, 0.21502722865871846, 0.11399001438891697, 0.11744504028390493, 0.11597992011135626, 0.06668958557589401, 0.2802861986621734, 0.0978136465193764, 0.1656247311902623, 0.1316760810873201, 0.20397236540673241, 0.08674115558425266, 0.08749783594882296, 0.14422454000000032, 0.17266624366804478, 0.11158005499671544, 0.21213524674455966, 0.1929495399517398, 0.18340386991058627, 0.13372217935900535, 0.2088881524339799, 0.15575995488512903, 0.13536686288012614, 0.10626278427099028, 0.17923918612782033, 0.13836788974942701, 0.1806068369337628, 0.5062926470512344, 5.123031216282999, 28.865906653865693, 67.19571590423584, 91.23615018783077, 81.57400315807712, 89.64002793835056, 78.79530983586466, 71.51027602534141, 57.85081017401911, 42.580481806109034, 30.528668011388472, 44.812581077698745, 50.997554794434585, 44.3005274188134, 34.67560368199503, 65.27650410129179, 95.69335122262278, 65.5718271963058, 76.5688705444336, 47.8338808398093, 35.82245372956799, 18.73692697094333, 11.351886449321626, 6.51486466007848, 5.133425987535908, 3.3252302533195865, 1.671379049939494, 1.1250815059869521, 0.44950950530267536, 0.1398809440433979, 0.18122732218715454, 0.18057928841200568, 0.26812158044307466, 0.23446588236237728, 0.30602344341816445, 0.18127557040462572, 0.12844617012888193, 0.4026566710202925, 0.26026623744157057, 0.41105691704057884, 0.24316303341859774, 0.21032971540285697, 0.40814277986364983, 0.3872830943474847, 0.233256122277629, 0.4632843484080607, 0.36366659547052077, 0.3300638340653912, 0.5253968267671524, 1.2040472751663578, 0.732119647004912, 0.6017555068096807, 0.4732182718092396, 0.4557648277090442, 0.40877998115554937, 0.34146417232771076, 0.304496017314734, 0.2686519584348125, 0.3165731482928799, 0.29814732411215383, 1.084218130957696, 0.5758704377278205, 0.1885134158956428, 0.18702755772298385, 0.2859235026182667, 0.39307242079127225, 0.2856291103507242, 0.1999936571284648, 0.3032262725455146, 1.0003807167372396, 4.431263381435025, 5.58073994613463, 19.40655989031638, 38.071458416600386, 42.307520143447384, 68.69963107570526, 61.05011493928971, 76.05177663987683, 59.14905586550313, 44.643252357359856, 34.14186323842695, 28.373288339184178, 32.760841808011456, 41.82515490439631, 57.666474465400945, 64.27372663251816, 68.48475579292544, 85.2939005820982, 89.95619450846027, 94.21141701359903, 93.39799588726413, 69.5406735327936, 40.620618558699086, 13.527277073552533, 2.781566458363687, 0.5717086804009254, 0.36458657513703074, 0.36573987454175955, 0.14592346254616015, 0.15344993932352913, 0.2924023694809406, 0.20927344869461753, 0.15242106791946197, 0.16072872455321974, 0.16103810150056116, 0.1911079871558374, 0.09356706793750487, 0.1385182268436878, 0.17208038558883054, 0.20391060339827694, 0.22456759737143595, 0.17234281666817206, 0.23693381928868834, 0.29071191986722333, 0.1954470325501696, 0.10921800674329843, 0.20497741147635445, 0.11603280316076933, 0.21823215748994582, 0.08954114566046385, 0.08614666369413176, 0.15773820841024, 0.2027176359608289, 0.24521310002573077, 0.16146243760182014, 0.13526048391096054, 0.19891646089813403, 0.12555228831667092, 0.10807734012844102, 0.14440627137739814, 0.1555654451611542, 0.19037756828531144, 0.26098194742395037, 0.19973047528295748, 0.1396228796652248, 0.11107839764125886, 0.14592131749997217], [0.06415020712020417, 0.012358288119186558, 0.011577744115774911, 0.03328838190364261, 0.06386814886824259, 0.07095523208620087, 0.03161927358427596, 0.07552721417478978, 0.0400145304569554, 0.04468405469050331, 0.06687897017165538, 0.07766715055632015, 0.046246073494154605, 0.049272247199569984, 0.02450678497552872, 0.036395849029143015, 0.003671344466349711, 0.05317243529603847, 0.014410218235195405, 0.03968805442714403, 0.037009631013197285, 0.016685678443360715, 0.046478144509056886, 0.05018013033775553, 0.0392571184784174, 0.022173064738331784, 0.011848187517194499, 0.017261824442914898, 0.036668036238200245, 0.028063639277412046, 0.07546304665025204, 0.009644096060055158, 0.052474552179656686, 0.07210287776204848, 0.05103801091712329, 0.07755281193362129, 0.027794654315878308, 0.5044519216302903, 3.1055912519654925, 28.623851306976814, 58.37436814461985, 66.81168448540473, 64.77315810418898, 64.8979522335914, 46.87256282375705, 46.20485774932369, 39.4546155775747, 20.049336341119584, 17.570039495345085, 15.196737839329629, 14.501254539335928, 22.08456204783532, 20.062486087122274, 33.71616055888514, 44.02984465322187, 51.37536141180223, 29.263232946395878, 15.038822235599643, 7.424420137559214, 3.1340473121212375, 1.998547255512207, 0.07731505654632084, 0.013910598673617408, 0.13581922247765527, 0.023060119861075958, 0.06779129661980175, 0.03899982401860818, 0.025484759413126497, 0.07594247213414601, 0.04644067131824071, 0.05601785438615949, 0.11802219560429936, 0.13765878344495452, 0.05006442041767221, 0.01416123582936463, 0.19264730294385266, 0.09243816077228516, 0.20374627753851876, 0.21115785644900417, 0.06923381719858417, 0.022557148664829232, 0.09503092406497848, 0.027479910922627297, 0.09594054622275215, 0.10875645409067793, 0.1633048484161977, 0.3228162439359773, 0.4854031760365733, 1.2906083464622498, 1.096028632694675, 0.2512042906375662, 0.13265503420224115, 0.48078191917269464, 0.24396281388978808, 0.29371906011815996, 0.3168894813185738, 0.24003019346104515, 0.12980806761451308, 0.12765251836108585, 0.27483094784040607, 0.6299066639715626, 0.42189172919719453, 0.03662380615189191, 0.07584651196075064, 0.05559441843821157, 0.005742628596753123, 0.12317672627226961, 0.08498156653536905, 0.06457735093370562, 0.02029417473221979, 0.19163094941646824, 0.05753970719994076, 1.607151464108498, 7.2627346457973605, 17.495400713336085, 29.628050634937903, 42.28165211216096, 41.24678573300762, 34.826116792617306, 32.42849546094095, 29.59191187735527, 20.971063913837558, 18.826602159007905, 26.626429403981856, 31.316564313827026, 38.504754804795795, 38.20504257755895, 48.43081851159373, 67.17611189811461, 62.358951030238984, 76.44557476043701, 63.6763810342358, 48.22598841882522, 19.928643049732333, 3.7714506060846396, 1.0123386137908505, 0.26839394002191486, 0.017059776413765167, 0.061945356278409885, 0.04348634133836435, 0.1008658480620192, 0.03256389255365057, 0.011007827368655033, 0.059243927244097, 0.027240012404358676, 0.03839390975753627, 0.02972780441444728, 0.038900937389342055, 0.07273792634688078, 0.04177836363293952, 0.061399595241152474, 0.02113555186247874, 0.01177257368145811, 0.03361824021163968, 0.09010340823161025, 0.10923522839983625, 0.02018145447026097, 0.0538302903183766, 0.045057920919310664, 0.05195341320828565, 0.05412592364835644, 0.050140374204924995, 0.05343389344371615, 0.006866521716508414, 0.05676805747733001, 0.0479991814391988, 0.12021432555611096, 0.04049416661502854, 0.006544110261940308, 0.05154590805872314, 0.026546532378321695, 0.02528884583303044, 0.027428334053125114, 0.08828781815546174, 0.03250313028993626, 0.03739112364729086, 0.03259901002409958, 0.05889667874021877, 0.024772944987841675, 0.031677929106198495, 0.04297534154067117, 0.02935671142392582, 0.01939955640644316, 0.05112282834166, 0.021728163006745523, 0.10213215309645861, 0.055920162854055246, 0.016413880023925055, 0.011264443840651263, 0.12128071994670939, 0.03472694180785649, 0.03615561534740752, 0.017749487287214687, 0.0579574357928528, 0.03215042340959753, 0.023752307113740715, 0.010117353578548758, 0.005455949876998221, 0.0020656378229989883, 0.03243673727997849, 0.03141327254143694, 0.03820019293456309, 0.046228836515858296, 0.05117214525178556, 0.017237767366872683, 0.009808074307417678, 0.044333925696029786, 0.08810410261034005, 0.038239573684310725, 0.05932980953084846, 0.0776684299231537, 0.029987987025731036, 0.05852626373751029, 0.6080938118600077, 6.069739384035911, 38.442840191625784, 69.71259101744621, 76.36143992024084, 73.41666560019218, 74.37533209400793, 55.52082031003891, 57.68250126992503, 48.61524051235568, 33.256082227153165, 27.20217058735509, 19.873414116521037, 27.383801821739446, 37.717166408415764, 32.91846421457107, 38.28951866396012, 42.32871663185858, 45.83601767016996, 23.73018264770508, 12.394923125543903, 7.180390367584844, 2.636095799746052, 1.5372703945444477, 0.11254812966311172, 0.08203367552449627, 0.1259896172691257, 0.05524674092509574, 0.14828411651955498, 0.16095522610891252, 0.12592616220635752, 0.4505229476959475, 0.4269216173598844, 0.4243200746995788, 0.3329436505033124, 0.6347387175886863, 0.19193278805863476, 0.5993416556908239, 1.112736091017723, 1.023369605743116, 1.319055213562904, 2.2861804212293317, 0.7060433623771514, 0.13689427366179807, 0.049623973487365636, 0.22610299078927887, 0.21576242791789196, 0.19687880491537435, 0.2974533710268236, 0.909813741041768, 2.888557439850223, 3.484789820448045, 2.796771036040399, 1.9221876561641695, 1.6400996187040884, 2.2096866032769604, 1.836633163113748, 2.0897383170743145, 1.2693953105518896, 0.8064603901678516, 0.4694200998112079, 1.1119381338357925, 1.3591578939268667, 3.938191297554201, 3.0929021393099143, 0.359512958675623, 0.39710618014777865, 0.33349520316527737, 0.12173255860445001, 0.14515170557124002, 0.08595324947588867, 0.0713189093456153, 0.032656983727769505, 0.060724794353929266, 0.03904301222533949, 1.3759286004689433, 5.992745218738433, 13.950976402528825, 24.42400678511589, 41.2777606902584, 42.560050179881436, 38.18527383189048, 29.934819206114742, 26.465278825452252, 30.75767363271406, 30.514286641151678, 37.99133223872031, 41.22425563873784, 47.252079594519834, 50.984701187379905, 56.919706175404215, 74.08826166583647, 68.71692872816517, 86.13485674704276, 72.67623978276407, 55.78128530133156, 22.5640227717738, 5.241491208153387, 1.392315895326676, 0.22330169836359642, 0.023114450816665928, 0.03633554258774366, 0.00953053980464897, 0.12454858290091639, 0.09654992320124181, 0.012780794227916389, 0.04983181697166255, 0.07018408798162015, 0.009180437623252793, 0.03988207002440768, 0.03558285354125885, 0.0617910661704598, 0.03610150655731559, 0.08209229657246221, 0.009481192251006442, 0.025792956585064534, 0.02336000689425536, 0.14441244604606784, 0.10459271259605886, 0.012195362285110018, 0.019496952994696556, 0.03394938554734953, 0.042763265420592604, 0.028164504328742627, 0.002967206002663701, 0.05115554029602678, 0.03842633059849182, 0.09661524751854521, 0.031807035988857674, 0.028967289779815945, 0.08137208965396689, 0.03334968425934354, 0.046613807189128095, 0.06032785355684258, 0.11100804778717219, 0.011269633128728357, 0.12717307755543342, 0.047752129574937206, 0.03814137270373683, 0.1709899360374097, 0.1245247269229543, 0.12027567387708735, 0.22431556976610617, 0.13390150522032093, 0.20775019010949522, 0.12628879758619493, 0.2783442270611563, 0.13910558645523366, 0.17633146876769681, 0.21607984878843833, 0.25906118113667737, 0.2038018342347876, 0.235267915132065, 0.09280811229179944, 0.1476028958155263, 0.0680310208530676, 0.14730620528421096, 0.08690094620349907, 0.1117792072135114, 0.16322283104302424, 0.10627340224962081, 0.09383440964044103, 0.17458543181419375, 0.19709732383489612, 0.14881216560400304, 0.17784150467524606, 0.08536295574759284, 0.10483947717734884, 0.122526302302797, 0.11013193431520656, 0.16423385259845566, 0.14161619447892712, 0.20856541491323904, 0.14830929016874683, 0.13934025450819923, 0.09097452681030958, 1.1511652676328537, 9.978621505921888, 45.789957277236454, 82.73176916183965, 85.6057603897587, 81.86380355588852, 84.6926090794225, 64.28310109722999, 64.60551600302419, 55.58027559711088, 34.7767694534794, 29.192218434426096, 23.776723530984697, 23.58779472689475, 31.50441054374941, 30.69934210469646, 47.13276501624815, 58.12413269473661, 60.78848108168572, 37.03337177153557, 19.535490159065493, 9.923537700406968, 4.306989946672994, 3.0960991161484874, 0.3812015819693766, 0.24067084214860396, 0.20853316261162683, 0.1734627452829192, 0.20405798339315, 0.22985786349783022, 0.2946154442766021, 0.3409148259989677, 0.45915164113525425, 0.2593506397979875, 0.18072110660854848, 0.3175552423682905, 0.20087787581066932, 0.39813430078568, 0.7411404242438655, 0.44083469337032694, 1.4002486438520494, 1.5534190376920085, 0.43383286424702217, 0.3091092455771662, 0.2030170384433962, 0.3742054218967115, 0.6917515324969447, 0.5105158752731739, 0.6127458041714084, 1.2498746547968158, 3.943382799625397, 4.220333022456016, 3.4412490600539796, 1.3457522132704336, 0.8939255677884625, 1.1697345034730051, 1.040711691302638, 0.6315264189916273, 0.5991835351432524, 0.462248076594645, 0.28542882432380035, 0.8509422129681035, 0.8144212081547707, 2.430773449520911, 1.9742204705553672, 0.3748453198181045, 0.2936181203732568, 0.3723484860552896, 0.14974686948041763, 0.2727975666282639, 0.18870668455718026, 0.093730888179233, 0.09568158552170762, 0.45681047643865313, 0.1998128757000931, 2.343450212670911, 10.048535793058335, 22.997266207971883, 37.11880491625878, 55.98596242166335, 57.67778265860773, 51.88907815564064, 46.10662983309838, 41.1654475427443, 29.85320644993936, 29.534698224836784, 37.938050762299575, 44.58642505830334, 56.60140583592077, 57.71704166166244, 65.29680628930369, 84.40657415697652, 79.3663755539925, 96.1117426041634, 83.70829812942013, 66.13243195318407, 31.84263260133805, 8.85690208404295, 2.2664531055958044, 0.42063755133459646, 0.15084340176995725, 0.18670803777152495, 0.14798633814338716, 0.2010305724557369, 0.1507746530396323, 0.1618659973985726, 0.19650228802234898, 0.17885237301309265, 0.1603052311486775, 0.1538362774637438, 0.14611924397608927, 0.2658598743859799, 0.14209650096393403, 0.2977487745304262, 0.0965880054319578, 0.054827813404582204, 0.17500679549430648, 0.15370665538695552, 0.1703783680474566, 0.12452334796469058, 0.10902684482355272, 0.13223647440393127, 0.1450780385564412, 0.231352960690856, 0.24313871778788107, 0.15958339246290346, 0.11498409007946331, 0.2362668171765343, 0.17245334783388724, 0.21156498621548378, 0.27374947683945783, 0.11480125553545453, 0.09406339332100846, 0.2132854358323159, 0.14786912669097224, 0.15096073579644004, 0.31500184067314674, 0.12827390759822824, 0.10790016697419268], [0.007501949514863232, 0.0359273326372908, 0.0717177500407542, 0.06330961714528742, 0.07924499290604746, 0.02862079587254313, 0.03424250227849811, 0.020850674406955802, 0.023758472206311363, 0.021068591947457003, 0.022629856154502883, 0.043061147218630205, 0.02230530109016165, 0.07991977081063294, 0.07900185192063933, 0.03162424166446492, 0.03320130451972927, 0.03822747332554671, 0.0348151951367336, 0.017584807111791546, 0.07447247198151966, 0.009950762013754538, 0.052796573408188364, 0.04972937952486738, 0.04599428720652096, 0.05045447791475923, 0.043759773440298536, 0.0446450186803216, 0.06993584485063631, 0.013589835744501363, 0.017276646329029914, 0.03989630776848044, 0.1106887270185736, 0.02417030575264606, 0.029740362510746046, 0.040281600198678436, 0.5034475190745247, 6.370662643063453, 35.54854677569482, 61.90470526295324, 67.22262336361793, 64.27921010601905, 65.66594446859052, 52.53183695577806, 48.437313956599084, 29.07938361167908, 22.80216947678597, 17.411105055962842, 18.27829599380493, 31.100945741899555, 22.363701443518362, 28.208627239350353, 36.14784963669316, 39.384593425258515, 41.09246400094802, 11.921723484992983, 6.926285989822881, 1.358778649760831, 0.09706496411273557, 0.015168008469646017, 0.061790786548367435, 0.056027089576086694, 0.10860919666987275, 0.03787123094943743, 0.24953152233314133, 0.12286040090745497, 0.031046822043736617, 0.16974527298683123, 0.1828345593305365, 0.05427177912826019, 0.714591248862205, 0.32732577453697886, 0.4100400119298889, 0.010047646280708573, 0.8103701352111755, 0.897804975749985, 0.7739951773997277, 0.8881143925170746, 1.1530166263541868, 0.544318279191371, 0.08030597871590046, 0.05486662724926587, 0.143227752358202, 0.14148491765222243, 0.1417585949022924, 0.18974013716703464, 0.51120774459935, 2.102797358266769, 2.6997269401627206, 2.4598526762377833, 1.9019791147401257, 3.4574464876805586, 3.796933754797905, 1.6071370003684875, 3.2207736132606386, 1.3745989169805282, 1.9931156308420244, 1.853022419156567, 0.7021748022206369, 0.9129187260423938, 2.992824825548357, 3.273679767885516, 0.3451040399170691, 0.17305362368783644, 0.13593540737225165, 0.07403679777898135, 0.15403699249990527, 0.1158579052876561, 0.15712919915395399, 0.1445055257288679, 0.036208115352858464, 0.34065211912797344, 0.03671194456758038, 0.09076693996546731, 1.0860957205295563, 4.11632941615197, 10.983324858450121, 30.39950828398428, 39.32543231594948, 58.53457343193793, 51.31645133418422, 33.11217831027123, 21.443786005819998, 19.953465769367835, 18.29839814093805, 25.62986300837609, 30.92726907422466, 36.94901335623957, 43.41654677544871, 50.17335107249599, 62.87072620084209, 63.63236419616207, 68.14601990484422, 51.54425082668182, 27.964900962768066, 14.655825341901473, 2.460302523066921, 0.1425251578010859, 0.0848072202455613, 0.0792368570522916, 0.04442468413241929, 0.060888028538395325, 0.05465067089385083, 0.1359935840892215, 0.022465001694076968, 0.005580802577652879, 0.037333433396152915, 0.09304730792439754, 0.025080119432400794, 0.00889456233820848, 0.12773213787905632, 0.05930732485027083, 0.019303720722335483, 0.041387409812981085, 0.04780578254271419, 0.09011008085743075, 0.03442286618895108, 0.04050600267345867, 0.07606945886847473, 0.08178951564214884, 0.07706372608100215, 0.010712245749610086, 0.07942055727565482, 0.062324788135987144, 0.011701107254221795, 0.03574443680624809, 0.01412618922204861, 0.038983196080211675, 0.051135074257129626, 0.020458454626702496, 0.011853861355883701, 0.05429577300204866, 0.023896651485213832, 0.03840522104573827, 0.03165854516649439, 0.021865729415308566, 0.0573959622922684, 0.02789511908626845, 0.061810727817036455, 0.07663939764062244, 0.07598069226068836, 0.05142738276551809, 0.01751267993372054, 0.056576137130539265, 0.06415342085904653, 0.016758341882978717, 0.07000908285619752, 0.06664827045413756, 0.05197713129042138, 0.039558214015297355, 0.025329007992460847, 0.02911072059143936, 0.05223190532095971, 0.01775862288571173, 0.039811846574828516, 0.01566999332769023, 0.04008632821721896, 0.0628987833436939, 0.002944173090415256, 0.024988319116434263, 0.04486557539372195, 0.030569591401745717, 0.022096850481184743, 0.048692544636827324, 0.0511918030679226, 0.0953711360512722, 0.012790473748839671, 0.014273324068785917, 0.022291444474831227, 0.03503775133961632, 0.037999837959726016, 0.06058522845588385, 0.7741544624009441, 9.363119256111885, 48.09423992710729, 74.58156247292796, 77.93161961340135, 74.05681210179483, 72.97816030440792, 61.03762219029089, 56.903534243183756, 40.18701622563024, 35.87699820918422, 25.319201484803234, 23.17131942318332, 31.18199367677012, 19.55656505400135, 24.824221903277984, 30.87215388974836, 33.3009345300736, 28.448450757611184, 11.464997799165788, 4.990613960450696, 1.4516354929054938, 0.12514462994952358, 0.027038127168892857, 0.04597450681631604, 0.07288024250057436, 0.16534653402143912, 0.22624772011993394, 0.2263856465898214, 0.27734849662069355, 0.5598493328978938, 0.9767864956971138, 0.7428435296300919, 1.1581486800024587, 3.730686148328166, 2.351407721157997, 2.8258642362010096, 2.0380967591078054, 3.053460010597783, 2.6819002580258156, 4.593232264441829, 3.9318419608377644, 5.191204951655481, 2.558094811054968, 0.469783102913249, 0.062090912984023174, 0.1683788479215676, 0.29662136889753804, 0.13347104041566774, 0.23710105628255876, 1.5492913559559853, 3.285709186907738, 6.487289417174555, 6.672766535512864, 4.621523830198473, 5.94286737903472, 6.586446935130704, 5.130034608225669, 7.988112780355639, 4.191205011260125, 6.793361277349534, 4.723682451632715, 4.769460433913816, 2.392690912369759, 6.420553720766499, 3.361419756566325, 1.1188248352658365, 1.5048051817763237, 0.7282245495627004, 0.8693882618700305, 0.38094914067656765, 0.6986072226878136, 0.4471660423423014, 0.32177059520636836, 0.15801760067622508, 0.2984200514131977, 0.028475078288465742, 0.039169026028004386, 0.45838316301665, 3.081554232105132, 8.295683476232714, 24.921071106387725, 33.17699155499859, 48.64920431567777, 46.030814340037686, 28.79839481845979, 19.920500209254605, 26.950462287472142, 25.341747268553704, 35.925361033408876, 42.6663895576231, 49.52772894213277, 53.41602548476189, 59.27536795216223, 71.29938587065666, 71.38916107916063, 78.18910752573322, 58.07334192337529, 33.117877514131614, 17.287617075827814, 2.8826613820368245, 0.24097995862605112, 0.06707348755650944, 0.04959834018541921, 0.029516701226032553, 0.006689767037788707, 0.014547355634520852, 0.013392397649435988, 0.08758248100357671, 0.01811279299398584, 0.06078846009087659, 0.011220091180275045, 0.025875249749890743, 0.047942253445545514, 0.00509017976113565, 0.04954636111975678, 0.048088446004135955, 0.03436171322039539, 0.04446332560732, 0.038105006509971236, 0.03994456747727048, 0.09579672087584773, 0.04104209185067204, 0.12278363889744207, 0.016125792659999385, 0.05298457521524641, 0.059480449229839354, 0.06524218501703394, 0.03597339367373817, 0.01997594180847368, 0.02444877105224277, 0.021987225214440017, 0.07542853438926321, 0.029459510847265204, 0.02950997114361775, 0.02312947571608088, 0.021010250521583423, 0.026027898514463056, 0.030280320431977033, 0.02653539729034228, 0.0910231733935014, 0.13243761844933033, 0.22311322541246492, 0.19215657766307556, 0.15348908641645986, 0.12060925154195679, 0.1972012360009455, 0.2341945953066311, 0.14107536704790208, 0.11554011669490608, 0.1462936055876555, 0.24570074563305228, 0.11459412834336681, 0.12907410941777692, 0.20493333077719136, 0.13503108654291401, 0.15303520996484066, 0.11205044830398214, 0.12278614400495445, 0.09693393243416663, 0.17253902710733876, 0.14355482593659433, 0.13857215943355716, 0.14733888659506075, 0.12761166289208398, 0.226505876428658, 0.1432608013912555, 0.14309408533717358, 0.20387504159683184, 0.17975942111544072, 0.07406032433913601, 0.11702705505153826, 0.1978901022624585, 0.10282641261695855, 0.13848542295877012, 0.12295903472770607, 1.1762219811639478, 12.302279683851427, 56.95800812013688, 85.84234206907212, 85.9002519422962, 84.7564652658278, 83.52805737526187, 68.83044996569234, 64.71418134627804, 44.242029190063484, 36.93374356915874, 27.563791544206683, 27.13781822112299, 44.126538922709805, 30.611200563369263, 39.790982354071836, 49.74687960840041, 53.305497015676195, 51.5223208550484, 16.395642642051943, 9.349294862439557, 2.312563508749008, 0.2699565142393112, 0.23728954455544873, 0.1824391200657814, 0.16372979738779608, 0.2546452664800229, 0.39735218630202357, 0.3926173952077666, 0.15667221238536222, 0.2594471668764468, 0.3440270122260817, 0.29839421892839096, 0.6033951801157768, 3.38134368100474, 1.682828938768756, 2.243308670097782, 1.275443360209465, 2.281982014256139, 2.1393987103816, 5.017871491370663, 3.463291554681717, 4.817226567576009, 2.0225791272617157, 0.3202199106735568, 0.29258141955060346, 0.6203371839177224, 0.520332372717319, 0.5667533785585435, 0.905888245230721, 2.2439014382900733, 9.710121539331253, 11.192183225385605, 10.433417385624303, 6.56106920011582, 7.702387234857006, 9.32181179523468, 7.376227936437053, 6.025532311008823, 3.6207901614327587, 7.520276490719088, 5.260832415473077, 4.675214213709678, 4.961120188236237, 8.224116890661179, 12.299664443539037, 0.6134582046539553, 1.300971983901916, 0.4682428678197246, 0.6385161439257284, 0.25573396935097636, 0.7474255934357644, 0.5583794246758185, 0.4838495497261325, 0.201451032152099, 0.8174402687338091, 0.22781331272375202, 0.16025416372764498, 1.773607416018363, 5.698232093164998, 14.112118155725542, 38.86723279953003, 50.37001479056574, 74.66401853869039, 67.77802313527754, 45.15385866165162, 32.435290967264486, 29.28536492009317, 27.56938876644258, 39.231640600389056, 46.2824147747409, 51.385285008338194, 62.738330518045736, 71.44622372042748, 81.57117905155306, 83.70755287908739, 89.2880658180483, 67.97227459569132, 47.16368506031652, 23.77615478730971, 5.184291283930502, 0.3542781573149466, 0.22538116742526332, 0.17828408899086137, 0.130146709120562, 0.12715050094430486, 0.1627433212894586, 0.1724539300607097, 0.16571060964657416, 0.12012087815110722, 0.23720950368911992, 0.224642597379223, 0.12708025068164835, 0.1477917824541369, 0.17929105028029413, 0.18838581629097464, 0.08453571102431706, 0.13920919218611333, 0.2133107626990926, 0.18947274183794377, 0.10063988276787343, 0.21305557881151477, 0.17668887942789063, 0.3063333106617774, 0.1798441964051416, 0.13819550464470542, 0.16474261158897033, 0.13544658198952675, 0.14852828406278165, 0.14327452968685858, 0.15440402522442803, 0.11318459551060393, 0.14418638882137116, 0.22011912397799954, 0.08254286352424853, 0.08632815758427305, 0.09256528540244026, 0.09001986634346748, 0.08252920417655861, 0.07164027556897172], [0.07140678729140951, 0.03434123185973975, 0.03923916903835151, 0.0395640745879181, 0.025277722236369888, 0.03407913785908492, 0.016774205648670756, 0.028905884002245245, 0.035638188072029627, 0.0098623784499303, 0.07379795454682843, 0.04788875752579301, 0.07310315110390225, 0.03151779566260596, 0.020216072068339395, 0.10353838409026785, 0.02538021139409994, 0.07860304952989663, 0.01830672815201744, 0.0894040082611384, 0.028666889467727275, 0.010468392302432369, 0.03546617451995131, 0.028668249273792874, 0.034869483957487735, 0.085517437377524, 0.03231009528521569, 0.0778300055272637, 0.06841309188354401, 0.07848616749528917, 0.04767016582791844, 0.0776559733335049, 0.049712659655919963, 0.02931246218541938, 0.06235044059013167, 0.48760491273095535, 10.986729475759692, 34.650080819283765, 63.40802815652663, 72.76259468447778, 66.52236261675435, 49.88968133926392, 41.18414155898556, 42.36053097632624, 31.509611606597904, 22.552245855331424, 15.562369419682412, 18.656787064767656, 25.814192833438998, 30.667355175941225, 60.129605262510246, 69.11559843247937, 38.7878518719827, 16.92759056245127, 4.430798580569606, 0.5865292948099875, 0.15057825873936379, 0.055743276982778506, 0.08405096122934934, 0.15985521578019665, 0.06186336954875339, 0.03366326702938926, 0.05583595063897872, 0.1473408784236639, 0.07245946104728407, 0.7599301708321419, 1.0928288366525405, 1.0549750227120616, 1.0258586560526202, 1.4334805574147933, 2.200683047694545, 2.6539972520643667, 3.886127717071964, 1.7177082478038728, 1.9591117457997416, 2.094081606595747, 4.846998337776431, 2.013280535897901, 5.343742985879222, 2.9426912963390355, 0.35810832114469626, 0.1342275522408947, 0.12665195390582085, 0.03365998434263372, 0.11546105642112033, 0.20734074675748426, 1.2042080923434229, 2.504664774863951, 4.853764916619947, 4.495270088795693, 5.248397031138021, 4.412064850330353, 5.756845051242459, 4.3048390169297495, 18.65733619659178, 5.469182835471246, 2.754368253292576, 2.691621607349765, 2.9594574676406, 2.8020561846994587, 10.90049812870641, 7.089846864823373, 1.364832582973665, 2.116639892901144, 0.8953408079762614, 0.19410853905062522, 0.33589986122904286, 0.1411852393780024, 0.1732381895905541, 0.11538961872218118, 0.12410722432597993, 0.07069344452071576, 0.05579653924571411, 0.0038233961611460416, 0.06008022329619816, 0.055520161535711064, 0.6853763939392182, 3.024613674609892, 14.120394356789129, 26.76978615022475, 35.604134605776885, 63.02429091545844, 65.80456887522053, 29.78716354216299, 27.259154781218502, 31.593034536607806, 19.053679935393795, 15.589298452100447, 17.222662625774262, 27.30831188540305, 44.44507068203342, 58.315701253952525, 66.92287583504954, 64.62567306333973, 52.062748939760276, 37.761928496822236, 21.047348130133845, 7.455180835339331, 0.5746218982723452, 0.05180145966850462, 0.05370864704731972, 0.04489420409945231, 0.023595416137287696, 0.045214210516743125, 0.0517253028679519, 0.04372160693991088, 0.09461187397039707, 0.028161206320228598, 0.09515984900175564, 0.013925182114865993, 0.05246121458889497, 0.07750025830201565, 0.018914722341803775, 0.0383209666958259, 0.08465221767584163, 0.02660663580642112, 0.004715931445976059, 0.02247831438698115, 0.06269203536512871, 0.028581688999228423, 0.047837234282445525, 0.012545269114085504, 0.09002263958175337, 0.0055081731331865155, 0.05685983098021919, 0.05409859729209735, 0.040723464391644926, 0.02330254455427489, 0.034551247203302, 0.03071946884325195, 0.043896849552590045, 0.006708487353828406, 0.06706513719813478, 0.05681953092496242, 0.051910841702333385, 0.048259636011695674, 0.06528555325442745, 0.022978305501202424, 0.0478882365860045, 0.0749212003222877, 0.02209706690102335, 0.0176979276546908, 0.02957724323946863, 0.021362649051532633, 0.03815585559594535, 0.05087313347405965, 0.03832264059794046, 0.030124990359669736, 0.07219532925275064, 0.029299783430272536, 0.02427882593756001, 0.0854551008031253, 0.046225232072174556, 0.031017806463604494, 0.027682472230686296, 0.049725526102608254, 0.031333507466760856, 0.0703145144507289, 0.06981114871920117, 0.029038530211114598, 0.055167607872957186, 0.027337604345032768, 0.02550599345516774, 0.08286327979857884, 0.037804673230575944, 0.05119769811449994, 0.01231681499179573, 0.02948902629976792, 0.07190201716918139, 0.013183116792671144, 0.034851300860604936, 0.8628974133922208, 15.93955041900758, 48.40793540400844, 77.4627394830027, 80.95415099974602, 75.77461411876064, 59.084117104930264, 52.0811213216474, 51.27852985935827, 45.40940892311835, 32.64291378759569, 26.22587892317003, 24.838844499280377, 25.197827662191084, 33.960794864162324, 43.27274484019126, 53.928714567615145, 33.11890125274658, 14.45419688378611, 3.675129697207482, 0.45569238643492427, 0.14879561810483857, 0.03245526511642722, 0.08076006201125922, 0.08881769052916959, 0.25026891260377826, 0.3570441637308367, 0.3090460892886885, 0.6168207790582412, 0.4482233968953933, 2.303300586438948, 3.083633333444596, 3.0971672265760364, 4.641386712751081, 4.951067153484591, 7.388767263581676, 9.086744150807782, 7.108635508245038, 5.961293693511717, 5.218132513184702, 7.286826333691997, 10.040642023086548, 7.934411120030188, 9.135809079293283, 7.786620624603764, 2.982946091121243, 0.5153845478930782, 0.25382438794739787, 0.2983753425219367, 0.5807784259799988, 0.07380552349552032, 1.0993524736935094, 2.700883549067282, 1.6063044772994135, 5.412976741790772, 6.15415467369941, 6.607569388804897, 7.625154295275289, 6.802123852314488, 12.333175213106218, 6.551206400317531, 7.576533084915531, 6.5607946342037575, 6.632022915347931, 8.113820331711924, 6.06900982318386, 7.245913561313384, 5.265245572213204, 3.9013729893392135, 2.411192487324438, 1.548020630594223, 1.902806244550213, 1.07805130702834, 0.8646377812950843, 0.724445223327606, 0.8483891789951633, 0.38299585181859236, 0.3100694601814593, 0.19725346787562295, 0.03058099079005901, 0.10402958434555801, 0.6591202318668365, 2.3857377757949214, 12.072586667153145, 23.46647189509484, 35.74792869629399, 46.058200328580796, 52.67114385481804, 25.017779104171264, 22.052849684992147, 32.14858531951904, 25.852771305268814, 29.4164603371774, 27.9356381200975, 39.03822068245181, 52.81244724027572, 67.85318359251946, 76.0962563176309, 73.67921337004631, 61.14522064885786, 44.91216613400368, 24.305429612436605, 9.533178517895362, 0.7354342949486549, 0.038773456528302164, 0.04904417516363244, 0.021287465182643746, 0.028112132643019, 0.009401527725370422, 0.0579902588299686, 0.045759703423227036, 0.07277561021187613, 0.048432668460713285, 0.02507248345101553, 0.08038666309608568, 0.03858453541573498, 0.05540214952141528, 0.02211833350180138, 0.057661584127814546, 0.02764273141961425, 0.036395603881007245, 0.040484050423988414, 0.04869701092942588, 0.10042599868029357, 0.02562431190463324, 0.0371384946629405, 0.05456140249847405, 0.036605496650501605, 0.021481003890174533, 0.020146199103985584, 0.08947340816619898, 0.039587329186859636, 0.043849417218758215, 0.047461935469219764, 0.007095258333720268, 0.08557062686210679, 0.07196567141480985, 0.045022784296663544, 0.06265361988616568, 0.03539624984466261, 0.03867838118645934, 0.17618038090727023, 0.08397284324371046, 0.11003680151676941, 0.20416986287361194, 0.13991895732620072, 0.09172366886970498, 0.1487196681480254, 0.15660688040717957, 0.10130910653500788, 0.11038774639488229, 0.10003760742444186, 0.12728436714819363, 0.23395317035817334, 0.13425733773939072, 0.13622471281597692, 0.3124756504210734, 0.20630888761051241, 0.12190406270805867, 0.1435167513667576, 0.15274339175272375, 0.06866555615899063, 0.1571820898642463, 0.14581742065568126, 0.12401218345809369, 0.13580025414065008, 0.11309733809602839, 0.15017805440771967, 0.21376235620869746, 0.2719545021893517, 0.1745367086222095, 0.23414083125610508, 0.26685689185415545, 0.2363069601837666, 0.12684175218906135, 0.1132647512901214, 1.075920724580365, 18.83830455041701, 55.56958713839131, 88.71575278620567, 90.6180944750386, 87.36651236011137, 70.44570553687312, 60.293736842370805, 59.154555028484715, 44.94347057034893, 33.13067228563371, 25.387044760488696, 28.590426829553422, 41.02760761014877, 44.37633506713375, 75.43193232628607, 87.8328743288594, 49.84100472542548, 22.255008643673314, 5.799356189466292, 1.003100757877673, 0.4471034376371292, 0.13712779258287724, 0.33233841039961387, 0.32411365980102175, 0.1872327620343816, 0.38751046924341115, 0.21115448566213732, 0.38229460557622297, 0.22984876237328977, 2.6609628911941283, 2.948356669756674, 4.207810365384625, 5.758744458998404, 6.654751089311416, 8.868268132209778, 12.110782707891158, 12.506997989070031, 6.8035756195745165, 6.169096452574577, 10.09304783036632, 14.03672137568074, 12.311510982051974, 15.866356049814533, 15.469222934015336, 5.979191468607995, 1.7046592576849846, 0.522671637515868, 0.6910040145439487, 0.8385309144373864, 0.6757379046851589, 5.661852600113039, 11.218805332337658, 12.473527423797115, 12.707063382671727, 18.25576982190532, 13.301824139010522, 15.45448462809286, 15.46637333208515, 34.43251871293591, 18.33555083121023, 12.933505735089703, 14.912826880331963, 8.926224093283377, 12.576758323177216, 23.58102079360716, 19.608873782619355, 6.734601720686882, 4.751392526011314, 3.253254270361316, 1.9297991380576167, 2.19639957431824, 0.6803020726769202, 0.44994445938256483, 0.3928178650957923, 0.546091006648156, 0.181107567322831, 0.2582766764586972, 0.4001815328674932, 0.11837314048241224, 0.3443002298233971, 1.6850195825099947, 4.762062353472556, 18.917136346140218, 34.51468844567576, 47.57144289631998, 80.18771202333512, 83.94614281192904, 40.82771970379738, 39.124355931435865, 44.068738875850556, 31.600271309575728, 26.67454904125583, 29.131115751881755, 42.684063757619555, 63.21331385643252, 78.2809066772461, 84.78822077474287, 85.24923263057586, 71.61407762958159, 56.96107149124146, 33.192473150068714, 14.984494466935436, 1.6168125069910482, 0.14599369748705818, 0.16274581873609176, 0.23763120444791935, 0.13015030973380612, 0.15205653264157235, 0.33070526416263274, 0.19495537264212487, 0.17450175969110382, 0.1250477045053436, 0.23084659189466508, 0.13037693386356677, 0.14324229270700486, 0.14707092436090594, 0.1129271210201325, 0.18942276226176372, 0.19888506661499702, 0.1564679120577151, 0.14663296721635327, 0.20216171659769552, 0.16224498109471414, 0.21877549768936252, 0.13105383383170252, 0.18426000380948668, 0.19563251775839638, 0.17049044671077884, 0.14389021922984432, 0.1671863554586326, 0.20713974060791157, 0.15813197760332018, 0.1092334280932142, 0.21678348522513144, 0.10613171428802515, 0.15678703364345337, 0.14500493844670637, 0.0985795429216758, 0.1876734464519447, 0.11792995095733674], [0.011079572460373804, 0.03824721924179504, 0.07892284527300827, 0.10888982999829516, 0.08662888539894935, 0.07288636354308936, 0.017253376408329895, 0.04801784334103427, 0.06423839916204734, 0.04683366676251735, 0.030147844677670833, 0.046016032612251664, 0.019618741822459047, 0.03433829391255014, 0.025551361182043632, 0.07081757374708691, 0.01430638076271862, 0.058733467538390434, 0.05437631948640751, 0.05917366165968199, 0.032611995214416135, 0.009440551286623364, 0.02664001234206221, 0.09883958380669357, 0.03356876242305002, 0.07414153731998897, 0.019275488467105938, 0.05835952470079065, 0.0772261367209496, 0.016000691459574286, 0.02178128928907456, 0.0643249785888099, 0.03284447608635791, 0.03804230987424812, 0.48268230752118174, 11.602339590749434, 48.088858435230875, 67.56153183598673, 63.232509936055834, 57.30028983085387, 54.18350781163862, 45.91368844432216, 34.22645699593329, 31.995404997179588, 22.596225430888516, 20.994882506708947, 32.84188189814168, 34.54242744753438, 42.01670777413153, 46.22839197035759, 39.50687331538047, 20.487812219127534, 5.631496887053213, 0.7787014700232014, 0.26829912898040587, 0.1709952526876042, 0.14500006612750793, 0.07672069489114708, 0.12299196118669165, 0.10205464798115915, 0.11300012153843719, 0.3325108414696109, 0.8297676040280251, 0.39275522974710314, 0.3572684436315491, 1.6755334528223162, 2.565203126399748, 3.5579064776820526, 2.152503103979172, 4.163022291275763, 7.260909763074691, 5.434252658197957, 5.898431337648823, 6.623677092213785, 8.71469263107546, 5.748697307802016, 5.582355472349352, 5.381847341214457, 7.057224021803949, 3.2058977792339944, 1.8676287128079323, 0.1524404346221878, 0.4823365567191955, 0.2299098502243719, 0.08881528501308734, 0.3449027426540852, 3.55099305510521, 6.8880448418278855, 5.776873163638577, 3.339494933043757, 3.08770646972041, 8.169066915588996, 6.862190538837064, 5.302689008174404, 7.874144882925096, 3.2488384169916955, 7.5159810050841305, 4.150224087699767, 8.4085790957174, 2.6046258884091533, 4.673078483150852, 2.0716860986525014, 2.824934389322035, 3.348220735788346, 2.4728163548054236, 1.7617280276552325, 1.5088815049779032, 0.9418644083123054, 1.1499316822136603, 0.47346081524606676, 0.6923189278571837, 0.16016154369759947, 0.1863721541820034, 0.06699679449440972, 0.11196119906080347, 0.09277158521956975, 0.05651234881952406, 0.15901677851234713, 0.4930799286211691, 4.77024196617065, 14.22195432647582, 33.29947148599933, 38.48358969534598, 54.57112819917741, 46.68253967838903, 54.82997717395906, 59.90733631195561, 24.89056879474271, 20.51970304981355, 18.396184790518976, 39.53665979446904, 45.559725915232015, 55.414869246944306, 55.84571807615219, 68.45153331756592, 68.67673227863928, 48.65876705415788, 27.328574849713235, 7.3985486741988895, 0.12520385620694968, 0.08358885699342336, 0.04299422560800468, 0.10636892575289934, 0.03657713607554475, 0.08107059575136631, 0.04290202309587791, 0.049372788578752554, 0.049779198222583344, 0.04712279217558042, 0.0713816213030969, 0.07088691236511355, 0.021728343037407727, 0.09829763022641982, 0.06597595935266826, 0.009831665985045895, 0.0367590896184406, 0.019095053693519968, 0.040057155589062365, 0.04912064989067374, 0.04529507492759055, 0.08238151008563657, 0.0503919574792587, 0.058752236692535306, 0.07214881239398833, 0.07517354202366645, 0.031433495347418135, 0.029451836561483723, 0.046639739265364986, 0.021164059909361026, 0.0228172259390234, 0.049033714233026396, 0.021202019566009124, 0.01806032171683206, 0.015183489191375915, 0.0979483247764649, 0.07234996410026666, 0.020940973190590743, 0.013387109727538643, 0.04006297019640765, 0.09953704557471699, 0.06569822949747886, 0.05479066580113384, 0.006355971516665793, 0.055051223795500495, 0.011574763076139555, 0.07085559469076895, 0.06433885244111862, 0.0697598438109121, 0.05324228336253474, 0.006386205176597522, 0.031476714197666414, 0.015782102634529435, 0.04854380866632827, 0.04907202629011966, 0.0469849078405288, 0.07099123821864206, 0.022740272407029426, 0.05176614301519529, 0.01134068395326575, 0.0516565962724628, 0.05831711407330248, 0.06861027525437456, 0.041424944290831205, 0.0032842289862943996, 0.0347014770452534, 0.026487334849192735, 0.017288819466146733, 0.0440920296034986, 0.06294948687296241, 0.0455569391018681, 0.6195984912976142, 19.211780871114424, 63.14671593327677, 81.49433981987738, 74.60177052405574, 67.92460995335733, 62.08841731471401, 55.24661133366247, 42.22100442455661, 41.71955685461722, 30.14509943223769, 30.60703108387609, 32.11578253776797, 26.762110071797526, 32.958401787665586, 35.274565296788374, 36.49578740519863, 19.781783626925563, 4.7497573879457295, 0.9129034655709422, 0.055340962078902996, 0.04019264589935061, 0.056483444322140954, 0.16311233052082602, 0.12908823607910064, 0.31693578367271735, 0.6918368440481925, 1.24302631905002, 2.5393235731509427, 3.1048668392242926, 4.341764209731933, 5.77212562484126, 7.321729544670352, 7.588379133132197, 7.669823227390167, 8.410201976376197, 9.508851978086657, 9.290708380360758, 7.079758038443904, 8.956785240480977, 6.810954088164914, 11.88903739375453, 8.708442334205873, 9.872778308007026, 12.046276388629792, 5.476256339780746, 6.1837170873918845, 2.6165006189577045, 0.8707061782479287, 0.14708079157337067, 0.2790634916915048, 0.3641705587506295, 3.3496791220480397, 6.29395628167737, 6.027799931264693, 5.561304601930804, 2.0669910215562393, 3.592843273955007, 5.028167222776721, 5.767236880717739, 8.796947675366557, 6.862468046526756, 11.778641304662152, 8.051054564214523, 8.480470257420695, 7.7677996216281775, 6.370020845244008, 4.796109016864531, 5.0679199541768725, 4.352922372279629, 5.524603474524714, 4.8379195217163335, 5.670177340507508, 3.585717307944452, 5.444045345629416, 2.3928362852142704, 1.9650308475379024, 1.3742347494248421, 0.7014748430059803, 0.3820602746019441, 0.24171733357492955, 0.11468936839411337, 0.09486171822514265, 0.03548412779045682, 0.2599490157538845, 2.391311218661647, 11.632897796169406, 30.61234981782975, 44.299115365551366, 43.36651302153065, 38.4583806222485, 51.59878353918753, 43.80937214820616, 21.543775066252678, 23.587298547067952, 23.51860215587001, 48.203552461439564, 54.59980856987738, 62.89609609111663, 64.44735034819573, 77.86714369250883, 78.30730422850579, 58.524026178544574, 33.38936044323829, 9.48453426361084, 0.18156299127205727, 0.12915434946696605, 0.04114363680503542, 0.0210066307561412, 0.014971233040635145, 0.028132389922956788, 0.03157024778756163, 0.017051876132046024, 0.034893290139734745, 0.07073478262510992, 0.0443668061897399, 0.060838918472009326, 0.030072319899655642, 0.041107852838092276, 0.034409547750387466, 0.038480512166936556, 0.041754036510903994, 0.03411553469636748, 0.0459156712637313, 0.00486634562783424, 0.0633711991230807, 0.048333134487151146, 0.03373412250150596, 0.06228603174789779, 0.014538979420678751, 0.02004370228537629, 0.02715708721699494, 0.03125187122232972, 0.03483025642532495, 0.015274576087962958, 0.01654728657505926, 0.011195303447875045, 0.01821066455675229, 0.051477998194675294, 0.037624738329360564, 0.04636371012536749, 0.009491838000324226, 0.10958063446225659, 0.14023331384504997, 0.16805407260694813, 0.37940734276367777, 0.14219854387544817, 0.2099228614280301, 0.06338167154500562, 0.17775196431865617, 0.17666957401219877, 0.13421166357734512, 0.1864494830970803, 0.15540208457218063, 0.29940015366000516, 0.09173470053581462, 0.13477656149095105, 0.09917167526098991, 0.11330542289802145, 0.1889896467928925, 0.1187892794428814, 0.12310949439603476, 0.08768249378209153, 0.16416890366423517, 0.1264485269184074, 0.14700723181088127, 0.2921567923359333, 0.16533124290647047, 0.0792951640042086, 0.12185140948502288, 0.1775609019903406, 0.09728859283871229, 0.1689436692263811, 0.1913068942244976, 0.2114230148013561, 0.20846997567963219, 1.206634200869068, 23.069726113350164, 74.41494803274833, 95.56832175101005, 86.86925780388617, 78.68044714773856, 71.14656248400289, 63.17005011343188, 49.29519514883719, 44.12489152723744, 30.647492293388616, 30.613322565632483, 44.31999806434878, 50.436342070179606, 59.75723897257159, 61.23794155736124, 51.50156759446668, 25.390508213350852, 7.734383969537674, 1.401092198587233, 0.5397449181445184, 0.3032178149348305, 0.5000065891973434, 0.21414281079365363, 0.27525793460588305, 0.28705142919094334, 0.4208773062113793, 0.7349756840736635, 3.0537107971406754, 2.7582175693204327, 5.451459115551365, 7.336227605419775, 11.780195543842932, 14.645074125259155, 14.535396810500854, 13.059613858499835, 18.353307400980306, 17.195406075446837, 15.860523485368299, 16.836924975918187, 22.829639796287786, 15.724523144383586, 16.32268753743941, 17.40856924364644, 19.143194306281305, 12.437199411853669, 7.520239228202452, 2.554927742288959, 1.2703272411900184, 0.3752831543885893, 1.0579315092294448, 1.3480667793943037, 5.189688465287609, 5.070644040261546, 4.939701105317762, 10.871604969424586, 11.550965366824983, 19.13263136340726, 15.034562541592507, 14.9626164667068, 23.785725370530162, 11.686041009041572, 17.063667389654345, 13.69873466030244, 17.49073309283103, 9.364325384939871, 14.672265956478736, 9.506726053453262, 9.86170643760312, 9.590474540187467, 9.863673506244536, 8.752997517585754, 8.788593026899523, 5.663756910831698, 5.383915410887811, 1.9009585630509163, 1.595678041058202, 1.1600923369969092, 0.3823573328554631, 0.29425826344278555, 0.312626171376436, 0.46007998648189735, 0.14962826374798052, 0.35969384735630405, 0.8095963864076523, 6.309804618358613, 18.154303989102765, 43.39787629342849, 50.94225721974527, 68.71945473455614, 61.375675585962114, 66.86641723878923, 72.65716137424593, 37.8094833127914, 32.99920620456819, 31.144484050812263, 55.78610197190316, 62.08152963269142, 71.14008272847822, 73.2361973485639, 86.87278009230091, 85.72602810398226, 69.7301632358182, 42.36879933264948, 13.774453074701372, 0.8514899964774809, 0.2760921430683905, 0.163267815725938, 0.18628503466325422, 0.188027149246585, 0.24728929023108176, 0.19103793607604122, 0.07115250738758234, 0.1691628776250347, 0.2900208472724884, 0.13492881380502256, 0.18223684221025438, 0.097196263922078, 0.14990345785214057, 0.15788443927322665, 0.14155136811877453, 0.2010589023871768, 0.10528206149296415, 0.2003962363326742, 0.18194575944254476, 0.21848870501402887, 0.23357041750944432, 0.1516474110464896, 0.11547331382790882, 0.09490065847433383, 0.11220916640013458, 0.1824445439682853, 0.07861854748860483, 0.114204250876942, 0.09789151169600026, 0.08417769515466306, 0.12914051391905354, 0.11969394501178496, 0.13053899210306907, 0.19757914717399305, 0.20766146180610504, 0.17941707174383825], [0.08538845881459214, 0.020763581701283975, 0.01218909664349931, 0.015722363098194043, 0.13202537121551652, 0.05358399688116005, 0.022412225896973285, 0.03964953552631121, 0.1307811831394511, 0.011282488084097785, 0.018441251276301283, 0.0809883562126948, 0.020805551828215682, 0.13193802187039008, 0.024602367850621382, 0.054617909143768975, 0.06972622021191544, 0.09306576298249346, 0.1280542855120955, 0.04125483063680511, 0.14347881469274723, 0.05120729336575155, 0.13016462025623168, 0.19703934630078657, 0.23144587183431273, 0.12817731923273495, 0.14523303346528163, 0.034979019208901355, 0.018947279163365884, 0.08031539393648987, 0.11312913074488602, 0.14120649065702193, 0.09133049722520575, 0.6524039083911527, 17.236237948940648, 58.89421555303759, 73.47479512614589, 64.32249738324073, 64.48840579678937, 60.29055580016106, 45.023369250759, 37.00512678392472, 22.37778275243698, 14.854741481042678, 20.495064681576146, 26.881758051533854, 42.96370913905483, 60.8532041118991, 46.38694201746295, 43.48782408622004, 15.024100599750398, 4.012904604596477, 0.410663852648389, 0.18235417623673716, 0.04197806360260133, 0.053270915898704724, 0.02709607022904581, 0.14263838559629458, 0.14783066907717338, 0.23241610686865546, 0.8403496071696283, 1.7638467204186226, 3.173444823872659, 4.094746819426937, 2.270762319526365, 3.1893304230705386, 4.717811644077301, 4.412440907570624, 5.3220365893456245, 5.4593509243380645, 7.825454540791051, 7.356980375705227, 5.021540378370593, 6.629014457425764, 3.6775010151247827, 10.498581682482074, 9.43140575962682, 7.105526049290934, 9.18286967662073, 3.322773623851038, 2.262922727292584, 0.35956578809888134, 0.22643233198792706, 0.617878225541884, 1.3912731577311794, 8.216863937916296, 27.757105558149277, 35.64255029924455, 38.55474149027179, 22.03455771169355, 8.02112295742958, 3.5407377731415535, 4.404569691227329, 4.95754151575027, 4.577574653010215, 3.916358649730683, 5.009938987993426, 3.1029703732459777, 5.418072881237154, 10.790730599434147, 1.2226024149887025, 4.209531305297729, 5.894472195256141, 2.691045754378842, 2.7773967337223793, 2.4443669136493438, 3.321208598152284, 2.7618614512105144, 1.1056705540226353, 1.8418338582400353, 2.5829074796169036, 1.5486102118607492, 1.1156531086852475, 0.36539553334155395, 0.1260885192201503, 0.10381710985975881, 0.03998465685834808, 0.014278145634659357, 0.04859944963226876, 0.25733233519619514, 1.5253081461114268, 6.6003404605773195, 20.755584586051203, 42.75898102791079, 54.11336798821726, 86.84827312346428, 101.27537819647021, 91.56430352118709, 50.108361321110884, 28.718451030792732, 24.61698151403858, 26.87340536425191, 44.40368575434531, 54.45979172183622, 56.63097266227969, 65.06517464114775, 71.69636111105643, 53.40070470686882, 22.48053120028588, 4.29761940433133, 0.3815227566707519, 0.15025795737822212, 0.10622196710638462, 0.06394537053101006, 0.17740521760236833, 0.12530298798435158, 0.0354250624114948, 0.06893572472636739, 0.07738830987364054, 0.13667515719369536, 0.07513466306150922, 0.18041880831362742, 0.12288040346315793, 0.2854901726447767, 0.09124796657312302, 0.05233792805924051, 0.026812544918709227, 0.11493953440578715, 0.15591516429858823, 0.06098219606604788, 0.009894507219864717, 0.06538632445998731, 0.10441094291426482, 0.034226242062305255, 0.05963256747852411, 0.0509620571298705, 0.041548472138181816, 0.025819377042353157, 0.04585904587480811, 0.0133480143455428, 0.0021200999711459925, 0.013309740592845747, 0.04110767280743007, 0.03583605709155241, 0.06944606951888531, 0.10956741944556275, 0.03594433978920983, 0.04771517732390954, 0.08279952596152022, 0.08785228184874981, 0.13219532016063892, 0.021865016953538985, 0.14664277314178406, 0.04560260560303446, 0.04669654085451076, 0.043356045104202726, 0.021837428212165836, 0.03128829295746982, 0.055231185509793224, 0.07733497483235213, 0.05221646098840622, 0.019324983492673888, 0.004241233203379859, 0.05150201505110149, 0.07144370506848059, 0.0422399316073185, 0.00798229382546138, 0.024632057588126872, 0.09538861051682504, 0.11068944714122242, 0.15380184947242662, 0.044827458689049374, 0.0469643613623996, 0.056015625070299835, 0.011540531394852987, 0.08866560675444142, 0.1476112002086255, 0.14590984150286646, 0.1277972783352579, 1.4058203706818244, 26.391024435720137, 72.24722662279683, 84.9323521890948, 75.64516021359351, 75.12241809598862, 69.86174306561871, 57.390547490889034, 48.730279707139545, 34.14545220713462, 27.9086188731655, 23.87273334687756, 25.984566865428803, 39.54714428993964, 52.51823809839065, 41.766162457004675, 35.912421134210405, 13.20934739805037, 3.1179246546760684, 0.4773715102384168, 0.19520393753003693, 0.08320660976272437, 0.15751751380101328, 0.5124233116305644, 0.5340942536150256, 0.8540578006256012, 2.26572084811426, 2.09403159637605, 4.807074492977512, 6.082122796966184, 6.173717004637565, 7.012926734262898, 6.559523786267927, 7.123921475102825, 7.093065169549758, 8.668192932682654, 6.787961154214798, 8.113772282677314, 9.697727830179277, 8.765953106264915, 10.214246126913256, 9.141666158553093, 10.069863680870304, 9.389271659235801, 7.045485838767021, 6.638670842493735, 7.6382393221701355, 5.746602271833728, 2.294550759177054, 1.164423981981893, 0.2229940068096884, 1.8751879781484606, 8.806847737681482, 28.98186564445496, 38.65650346202236, 41.94481465124315, 26.34152412414551, 10.731679316489927, 3.021544174801919, 3.0893403820453154, 5.102899161077315, 5.377041947457099, 4.594561947930244, 9.598888024207085, 6.136916347088353, 4.014692469950646, 5.234051942825317, 4.765426276191588, 4.433519724876651, 5.966232447854935, 5.993512532403392, 4.671868431952692, 4.002791998847838, 4.175694979006245, 5.805711409737987, 4.818051245904738, 5.922549991838395, 6.037037113020498, 3.8319313478085304, 2.0467991502054277, 1.5818264359428038, 0.5760932773832352, 0.2889698972144435, 0.2909771701501262, 0.13548228168679824, 0.08625455185650818, 0.025045999791473154, 0.8000375090106842, 4.505009824229825, 13.970645127757905, 41.18119193661598, 57.826852337006606, 86.71608924865724, 93.76288613965436, 73.54303652240385, 44.918590976345925, 30.784055494493057, 33.79951092504686, 32.058058977127075, 51.433134002070275, 62.04382388822494, 65.35710880833288, 73.52758238392492, 82.29452686925089, 61.3749695593311, 28.000882825543805, 5.24594751096541, 0.3133387250765678, 0.1179856378885527, 0.11877380446681093, 0.02038750913925469, 0.1108311887289728, 0.06257608029690963, 0.012715129001486688, 0.11297702398752013, 0.05807726343552913, 0.058342716731731935, 0.10396595308256727, 0.111880507019739, 0.1257398802666895, 0.07468686934800879, 0.08009106040962281, 0.031976441011553815, 0.02148976027514906, 0.09014093887902076, 0.07234425674523078, 0.0052180005736919425, 0.003780339865179192, 0.028137164565944867, 0.0964352168563393, 0.03404922595608138, 0.025481771670221805, 0.034485536011596846, 0.03421622546269529, 0.07116613609175529, 0.050937017546065395, 0.015104627142840577, 0.0617871476307271, 0.06273300574731923, 0.025843143004984147, 0.02314035224938585, 0.11082092315078744, 0.16988906769021866, 0.1560279784063178, 0.2284036907217195, 0.23960412600107733, 0.15167186457303264, 0.16562330626672314, 0.14894030147021817, 0.1482365118159402, 0.41911536527256815, 0.2100796796261303, 0.08887140861442012, 0.1079066327562736, 0.18469382407924823, 0.05836494094241531, 0.1878175016252264, 0.16547339818169995, 0.13345838464315862, 0.16515320407286768, 0.18487428375069173, 0.2271928887573942, 0.2267811777851274, 0.2519676053235608, 0.17944915550610713, 0.282233961887898, 0.22559173435213106, 0.30668408700054695, 0.16639057396640702, 0.1954043308092702, 0.1401286202693178, 0.10249397642309628, 0.1844391764532174, 0.18967472858005957, 0.2319190690233823, 0.28139892605043226, 1.5576288440535146, 32.14915210200895, 85.94589264162126, 97.63796037243259, 86.53595047612345, 84.49099925256546, 78.85460038338938, 62.77709530245874, 52.30193899523828, 32.95370671056932, 24.429282372997655, 30.64728048539931, 38.22763150738132, 60.45121608241912, 80.01304103482155, 60.28053806674097, 54.10671564840502, 19.457276136644428, 5.6866243289363005, 0.8614165960781036, 0.3101254765304827, 0.19014953455377012, 0.14875818704885824, 0.37428589177227795, 0.5049364569206392, 0.5741461270278501, 2.005849115310177, 3.6122460134567755, 5.6891513159198155, 8.300635468575264, 11.49091584067191, 12.325776642368687, 12.240462149343184, 16.2312953318319, 10.910798272778912, 14.224611732267565, 16.965680699194632, 18.733836143247544, 18.326374446192098, 16.670965571557325, 19.851709681172526, 17.145790053952126, 24.22215377130816, 20.906370301400464, 17.917914505927794, 20.462848294165827, 16.25641517100796, 8.309228401030264, 2.5528900709844407, 0.8133871733180938, 1.0786775379411637, 2.446973328628848, 8.326086748030878, 19.43562073092307, 25.148937279178252, 26.37344829497799, 15.650078519698113, 9.492407441139221, 12.148156031485527, 12.138024549330435, 16.00438033380816, 14.080950021743776, 17.082922304830245, 20.31860116989382, 11.853513467696406, 16.47623558198252, 23.322581706508515, 7.411292945185016, 13.04509912767718, 16.92970471997415, 11.659264949060256, 9.659157203089807, 9.2969576966378, 10.166253966669883, 10.1778837942308, 9.032440896957151, 9.938031838786218, 8.116957247257233, 3.299351190367053, 2.6722458341429314, 1.555252010303159, 0.30471971498862394, 0.2537152050964294, 0.5047575907120782, 0.16530265250513632, 0.1789267295070233, 0.5748258002342717, 2.6434502438191445, 8.028539178832885, 26.444811897893107, 52.21967120324412, 62.38946314780944, 91.61636121811406, 106.20667611399006, 102.57587925080331, 64.5090296191554, 41.13692406685122, 36.70091559810024, 39.903158218629905, 60.43241223981304, 71.68802215207008, 74.46122415604131, 85.43886353892665, 91.6734552383423, 70.00934185520296, 36.52557388428719, 9.152174188244729, 0.8057226781402865, 0.22560851167767282, 0.2802278227623432, 0.1902826193479761, 0.24379240529191112, 0.2676023873350313, 0.12991766415296063, 0.14120203202530263, 0.2189328827925267, 0.1640967688252849, 0.3105709106931764, 0.2366060255876472, 0.18359298637557417, 0.3579660126518819, 0.1810781035812632, 0.13632841047740754, 0.09179584201305144, 0.1708047879078696, 0.24385156260142404, 0.27617356289298306, 0.14048137311493197, 0.18094342532417468, 0.16283356644693883, 0.12109388642373586, 0.13135447737670716, 0.21650429214200667, 0.1845571386717981, 0.16380989954115885, 0.2490907459850273, 0.1619433876006834, 0.1814186909506398, 0.2012418288617365, 0.2673456865933634, 0.0903323765904192, 0.1625050219797319, 0.30817743751310533], [0.1822844315921107, 0.10441305731693584, 0.06737523426812503, 0.015097836731001736, 0.17153551321356528, 0.10279550863009307, 0.05092819987405693, 0.04149193101893029, 0.0878578819514763, 0.020550752899819807, 0.037572529437320853, 0.0350996014481831, 0.06332709161084026, 0.05725361932549746, 0.039174649113368605, 0.0011627265954420212, 0.10048429031045207, 0.2199011259982663, 0.19682813586006243, 0.13998514732285855, 0.07984055731926235, 0.22879176022064304, 0.07771711481074173, 0.39971967377970297, 0.4184273876730473, 0.3397847543801031, 0.15535015913267292, 0.17114532931197077, 0.08038975809129977, 0.043393859204145215, 0.19445269638972898, 0.08628992979685146, 1.1481227341198152, 16.635834863108975, 63.115717441804954, 75.46424481176561, 71.4481064581102, 59.924551594641905, 32.30254423233771, 32.27407174725687, 21.72887367586936, 22.740462749235093, 17.445186530390096, 15.51074710584456, 22.85113242364699, 55.27017301128757, 55.040510392958126, 43.437158830704234, 27.94818970464891, 9.176056519631418, 0.9869849032932713, 0.07438221150228093, 0.009878413627795395, 0.05315406450761422, 0.1275811496100599, 0.10872611700887642, 0.34918431613233786, 0.30590427078066335, 0.9211861017730929, 2.274978132017197, 4.127569458177013, 5.520492830584127, 4.533606354267367, 5.163788074447263, 4.912250397666808, 4.792640661039661, 6.525671770495753, 7.381891838965878, 6.363372427801933, 4.570593814696036, 4.731003065263072, 5.630799685755084, 3.3289560146870154, 6.964525666929061, 8.02133721690024, 10.893191733667928, 8.854853626220457, 6.532445213487072, 9.864857081444034, 4.199230670928955, 7.835923346780962, 4.032296557580271, 1.1914473964321999, 0.8300774099846041, 17.111912542773833, 38.36401624064292, 66.63712332325598, 66.32003891852595, 72.50892716069376, 59.9180914509681, 41.145992586689616, 13.329701404417715, 3.2059607823048872, 3.9598896041993177, 4.332913381438102, 2.1779232496215455, 6.709695160388947, 6.335092138859534, 3.5558651291554977, 2.9590032081450186, 2.779000737974721, 1.9032594008791832, 1.1766481711979837, 2.5634799801534225, 4.65096268923052, 3.93367812037468, 3.847390634398307, 2.9396406729375166, 6.986613513961916, 5.833977970384783, 4.289899689535941, 3.3755640685558324, 1.5298019565882222, 1.6507540018327775, 0.6533093630306183, 0.2540879988021428, 0.3546074219048024, 0.2625774634220908, 0.14172012196673503, 0.07556962480227794, 0.17831923710482736, 0.8061720346731525, 5.501130050228489, 14.111390556058577, 32.37317042966043, 46.11507861844955, 51.84424546457107, 62.936241549830285, 55.63417680801884, 41.49691527889621, 24.386106883325887, 29.230088918439805, 44.86051244120444, 32.20352988089285, 44.86479566943261, 53.595419006962935, 57.571219705766254, 61.34579496998941, 61.1760034099702, 29.439196355881233, 5.847329718451347, 0.4880514807037769, 0.3222191856513101, 0.11591933021742491, 0.22591246472251034, 0.013031930298424296, 0.1322184560159522, 0.12250383294397786, 0.2531068699975168, 0.03090348507788393, 0.1353157035285427, 0.2480702096175763, 0.29105108231306076, 0.37726557543200834, 0.04592964470747017, 0.061043804856918515, 0.06220846917600401, 0.17019495127662537, 0.1422420576695473, 0.04176284652203322, 0.11562424847075056, 0.07544312836422075, 0.1478686670382177, 0.06901515272235678, 0.1027867599059978, 0.06634136030991232, 0.08827343868512301, 0.030722358909946297, 0.06370560416290838, 0.08101706918809684, 0.084693341275617, 0.01256608659581792, 0.045140892071949865, 0.14483848286251869, 0.09432100570730625, 0.16577142170600354, 0.15432426014975195, 0.02919832274558083, 0.04354768965934073, 0.04429926021745609, 0.11314733299396693, 0.07343152703176584, 0.039761288602265625, 0.07039392712495982, 0.08541697260713385, 0.0386464812852923, 0.08356477118908398, 0.0261335535305402, 0.03491949034674514, 0.038381472320085576, 0.03037126464468818, 0.05954973422171128, 0.061319090891629464, 0.05817214725539089, 0.09186043088594753, 0.09075178674632504, 0.012262066518287025, 0.18232426816417327, 0.10901412776400966, 0.12978664779615018, 0.19072338037433165, 0.13679357906503065, 0.09691729300445127, 0.11709525219855771, 0.09135004012815415, 0.022834348004131068, 0.13155249578337516, 0.19886355486608323, 1.8840752109404535, 23.638175610573064, 74.31288796086466, 83.00834332743, 78.48871384897541, 69.20928816641532, 50.29232832693285, 49.37583515720983, 35.4415641292449, 34.3362323699459, 27.39007761401515, 17.714272891321492, 16.764453303429388, 34.35965676461497, 45.96371827587005, 39.08463016633065, 27.30877668626847, 8.658089887711311, 0.917358358781184, 0.096562234234185, 0.03672557710219295, 0.13718696521414867, 0.27378300084702434, 0.7857056586973129, 1.3259495145851568, 1.591571564635923, 2.644657598387811, 4.5028137872295995, 4.3864473604386855, 8.71651751379813, 8.085711646464564, 7.471402777779487, 6.918982046265756, 7.03809020980712, 8.821380119169913, 6.723309707257056, 11.72308877591164, 5.869968658493412, 8.029357483310084, 8.92787148875575, 7.8988156107164205, 9.390495438729564, 8.760711839122157, 7.269159978435886, 9.15645545528781, 9.569443771916053, 6.923146132499942, 4.340060430188333, 2.9595449855250697, 2.322872233006262, 0.939251987203475, 1.9152437126444233, 17.35822170011459, 46.04123215521536, 78.22852734596499, 77.64083077830654, 83.63142751878308, 67.80664074805476, 45.73010190840691, 13.795406376161884, 1.8433854007913222, 2.352169151267698, 1.7754701741280097, 3.434360887735121, 1.4042636800196864, 2.2625547599407936, 2.4230132852831194, 1.752065146161664, 2.8099727534478713, 3.194573896546518, 3.436604973769957, 3.4387257502925013, 5.993907220901982, 7.794140298520365, 6.479842307106142, 4.575771833619764, 6.825597276610713, 10.301437474066212, 6.84063466325883, 6.832563406036747, 3.965039185939297, 4.574986869289029, 2.6583554956220814, 1.2407642146272044, 0.9655888030125249, 0.44424939239698075, 0.3142278467214877, 0.051184184323515625, 0.10229012808732449, 0.3790702027899604, 3.3926175534725194, 13.434384561354115, 38.41140239469467, 54.378143664329286, 61.26889298039099, 63.44733422802341, 56.131917738145404, 45.20145662369267, 26.781196325056015, 33.94794910184799, 53.36170458024549, 40.06962753111317, 53.50695387009652, 60.87474969125564, 67.25213527679443, 73.13824792062083, 71.77825235551404, 36.85556288688414, 7.059242081257605, 0.3651978826570896, 0.14725818689311707, 0.1145110461079786, 0.08451519518970482, 0.07737203050524959, 0.08758741460980908, 0.09823129467305639, 0.1642897157298942, 0.05367192079222972, 0.09398256338411763, 0.1852713777653633, 0.1749144512559137, 0.2720532968880669, 0.07597684649930847, 0.05169637155749145, 0.05502636807279722, 0.13206764394717832, 0.08558205689393705, 0.06232200340638238, 0.200697232278124, 0.04489241528414911, 0.13161139262299384, 0.033589174835792476, 0.0630562067512543, 0.02158787315561166, 0.0776064534100794, 0.04965262900617334, 0.033211148749556274, 0.10502614216097902, 0.033979412363541704, 0.07852103215672317, 0.03159807784663093, 0.07659114176227201, 0.052184687491746685, 0.09434247149094459, 0.28249872187452935, 0.1941808577506773, 0.11158467450689886, 0.1480868182355358, 0.3758220819215621, 0.22122740805629762, 0.18777101540998106, 0.2358244167220208, 0.2895048104466931, 0.17828356805107287, 0.14434542867445177, 0.1309443139020474, 0.17307194851098523, 0.17769895103429595, 0.1216523951640533, 0.1641007218389742, 0.22200357769766163, 0.20669910215562393, 0.3124403797330395, 0.315780890805106, 0.18833608186293035, 0.31160828567320303, 0.2454712716562133, 0.45550230469915176, 0.5910731767935138, 0.6768047893720289, 0.3862131759524346, 0.3586844805507891, 0.21213072682580641, 0.17602054432274836, 0.34469838103940414, 0.3866435028612614, 2.919560834284752, 31.12847685813904, 89.60648382863691, 96.02789801935997, 87.62931900639688, 79.57508487086143, 52.42761565792946, 52.93031446395382, 34.90357575878021, 33.82123693343132, 26.247559824297507, 25.617948808977683, 36.299912083533506, 75.65922583303144, 73.26828233657345, 54.93308059630856, 36.28086505397674, 11.761717257961152, 1.8232951433427873, 0.15623523583335264, 0.10007263296433996, 0.24393472910648395, 0.4816240336625807, 0.45683247848383846, 1.4424174327042796, 2.090376437671723, 2.1736233513201437, 5.669787554971634, 10.92634850932706, 15.843186609206663, 14.249440335458326, 18.136386602155625, 13.42545234387921, 15.503945715965765, 15.32714488044862, 18.20839543496409, 14.019425684405913, 11.028291890698096, 18.217040338823875, 16.34761518047702, 16.76577514217746, 25.225605887751428, 17.138300288108088, 24.63263765458138, 20.365214617021625, 19.969723993732085, 19.51179708203962, 12.055605746084645, 17.81334803950402, 10.84555454792515, 4.592174205087847, 2.6183796794183793, 22.623693789205245, 40.869877338409424, 62.63281876041044, 65.31906181766142, 69.31720825933641, 55.754158189219815, 40.35311291294713, 19.196850369053504, 9.436943165717587, 11.390146228574938, 12.075758884030005, 11.74318111711933, 16.90869454414614, 14.461795495402429, 13.301037703790973, 11.338317009710497, 9.885701537132263, 8.935013144246994, 9.999734643966923, 9.756980134594826, 11.398255728906202, 12.559162570584206, 10.795038342475893, 8.228157912531207, 15.880373620217847, 16.19537916875655, 10.337942973259958, 10.231692829439718, 5.931487112276017, 3.436792266945685, 2.608693386277845, 0.9097886746448856, 0.9588302527704547, 0.3331776443989046, 0.5977686013906234, 0.28327072399758524, 0.4661431740368567, 1.0225492787937964, 7.818995377709789, 18.1879343909602, 45.08540153503419, 59.2365364874563, 63.72372404221566, 71.7022289768342, 63.945184984514796, 53.24467282141409, 34.89765297982001, 41.46432430513444, 58.84066735544513, 47.23363268759943, 63.74140608695246, 71.05920345552506, 78.32975587537213, 83.3343707361529, 79.2614992203251, 44.581890798384144, 9.711125666095365, 0.825805826292884, 0.3558404557406903, 0.18695807354825159, 0.3188931383192539, 0.14587276284733128, 0.4509215585647091, 0.248582124890339, 0.4287400649439904, 0.16684219811952886, 0.2666276477036938, 0.42953909464901496, 0.5105515136834115, 0.7060111253972977, 0.24709807468518136, 0.20367354515098757, 0.19442856462011415, 0.2621921824832117, 0.25362004165447527, 0.24286945320425496, 0.3414231713020033, 0.22524408365209259, 0.24258388626960017, 0.11471176880501932, 0.17871358852473, 0.16497639097994374, 0.21032924042834392, 0.1933512458157155, 0.1820531649695289, 0.22180277073094923, 0.2191777704584022, 0.15749735036684623, 0.2512120894126354, 0.19040387574463122, 0.18112458979650853, 0.3343500960017404], [0.18874970805500785, 0.15929341286180482, 0.041135864843043594, 0.027228936688193393, 0.0761132101498304, 0.16067612495633865, 0.07623927757864998, 0.11822550767852415, 0.05171787181508638, 0.14449961153009247, 0.06127687561656199, 0.04928733913167831, 0.04039367503156105, 0.052222762061583425, 0.0452147429478505, 0.05118254106491805, 0.034587935153995795, 0.24061986665812232, 0.24887273268353557, 0.10491604766538067, 0.27280835314623775, 0.2034504603474371, 0.2039184021733461, 0.27586001842733354, 0.5333885334191785, 0.35539162014761283, 0.2539235963335922, 0.22465865458211592, 0.1336628381883906, 0.06683499672480168, 0.44176904484629637, 0.8930596432858898, 22.635719776153568, 66.0604956842238, 71.58405580828267, 63.51703866835564, 54.76775661591561, 35.98463196908274, 38.72214040448589, 66.82023525238037, 42.54345855405254, 16.369116633169114, 25.652210712432865, 42.38402205128824, 42.01230687479819, 49.54966675850653, 43.92168529572026, 24.304290163901545, 6.485911194355258, 1.1928253741033616, 0.22096660108335558, 0.04809025397163726, 0.14906554152407955, 0.06737611526923795, 0.12301257661273404, 0.47074828176729144, 0.9410464715573096, 2.4127003935075577, 2.7691717686191684, 4.986795042791675, 1.8362107728758168, 9.043879508972168, 6.5416157149499465, 4.881511763218911, 4.5221491109940315, 5.088724695867108, 5.456683712620889, 6.219682770390665, 13.530226695922114, 5.209351797257701, 7.51958272149486, 7.1369677685922195, 5.441679666119238, 5.723763781209146, 7.9270429476614925, 5.859176747260555, 7.230471680241247, 4.642141769009252, 3.2040206799584054, 4.618923298774227, 2.8552665681608262, 3.4428900816748222, 6.055669842227814, 15.979496817434988, 47.00776692359678, 55.600424812686065, 54.59106560676329, 55.919619452568796, 66.86224383692588, 71.67741606312414, 62.13468951563682, 36.682150979195875, 10.700829875084663, 5.404839294572031, 5.447083221327874, 4.343231666472651, 4.149114056941002, 3.066193740214071, 0.5378857759698745, 2.066245526075363, 2.828111754309747, 0.5532345007504187, 1.3923226369004096, 3.8636515553920505, 3.1996933250657977, 1.4868641380340823, 2.2055041309325927, 6.884031766845334, 5.367989607395665, 5.23544438423649, 7.452632765616141, 6.8112129645962876, 1.8590171490946126, 3.9036621826310314, 2.3066005254945448, 1.2058927503324326, 0.5175318004142854, 0.23850734856340194, 0.18419926835884973, 0.24574254339020102, 0.1717428166058756, 0.04659154850448813, 0.014899568388148423, 0.8487350217277004, 6.117417264369227, 20.97901063580667, 22.745306876397905, 20.72244644165039, 22.45361001260819, 24.788157670728623, 31.99262795909759, 29.803853227246194, 37.68597179843534, 24.424173485848215, 34.51234679068289, 47.171192476826334, 59.06813344647808, 53.383583561066665, 59.14474125831359, 51.9129575452497, 10.35002681516832, 3.1412343200175994, 0.203455378631911, 0.19968832512536358, 0.16931011972408141, 0.1406040084698508, 0.15524382612878276, 0.19508413670043792, 0.14240851325373496, 0.045689916643764705, 0.21521763215141915, 0.28125450315494693, 0.27145302103411767, 0.18953494817739536, 0.0914310692479053, 0.13021139758488826, 0.051253109254063144, 0.05584857193753124, 0.1553364308370698, 0.1823334918627816, 0.16829133003709779, 0.2888139523565769, 0.17187116697670954, 0.07179576077408369, 0.025636531007025513, 0.023063228262828726, 0.10308144328695151, 0.020444940835718187, 0.10953137500872535, 0.007766065030028263, 0.077148784823235, 0.061191732604657455, 0.02931047610247568, 0.15591908666876056, 0.010717305760349958, 0.1338894010311173, 0.1100658285882204, 0.10360664252432124, 0.04905249870892975, 0.04228102839401653, 0.02924435313851122, 0.08303669146111897, 0.08841838252039687, 0.06916265529129775, 0.08325571599867075, 0.13753617873355267, 0.038803088809213335, 0.02814250036833748, 0.03138120793136618, 0.045474381636708014, 0.04019061193591164, 0.075021764684108, 0.060900772411015734, 0.1554074625094091, 0.053760652926059506, 0.11040714374112506, 0.11926204762271336, 0.1370732164791515, 0.08040073613125472, 0.31749738740824884, 0.32560207670734775, 0.19136739984875728, 0.16800551795430724, 0.17890961510279488, 0.03743248090388314, 0.015237457212811757, 0.3061818704009056, 1.917388391110205, 30.841390740486887, 77.8769103942379, 79.23059094336726, 72.62547646799396, 63.419932549999615, 48.55478502088978, 47.46128705240066, 68.88137802000969, 34.6576000029041, 21.54565780393539, 28.841333004736132, 30.226519992274625, 38.845165544940585, 49.75690910893102, 40.93350602734474, 24.192224125708304, 6.237731556738577, 0.7594485773194222, 0.09230915156583633, 0.07978575138915932, 0.6889441573331434, 0.5596217741408657, 1.179254341029352, 1.8961791549959492, 4.018134349776853, 2.7396694162199577, 5.628610022606389, 7.593425752655153, 7.981240787813741, 8.02042281435382, 9.526430080013892, 7.808601096753152, 8.321607401294093, 6.8706564845577365, 5.445621648142415, 6.7213039052101875, 14.249327567315872, 11.566177298945766, 9.859659940965715, 7.666244064607929, 9.134849079193609, 6.705146681877875, 7.580110776808954, 5.260755438958445, 4.132200306461704, 2.3212128252752366, 2.393740881835261, 2.573173382589894, 1.4894644243101922, 2.9749709319683815, 6.074649210899107, 20.40065911508376, 51.427948628702474, 67.62625878857028, 66.65831981166717, 66.1320161819458, 77.98515996625348, 83.31886168449157, 72.17803601295718, 41.667648207756784, 13.48803670175614, 6.70723436340209, 5.780958802469316, 3.508736625794442, 3.3982794948162574, 2.7371039409791273, 2.205724028810378, 2.926281325278744, 3.4982124163258463, 1.384246354141543, 2.4967577668928334, 4.466932435189524, 3.496748636807165, 5.469332375834066, 4.555573098121151, 6.564168362848221, 7.329611057235349, 6.88701423906511, 5.1634409446870135, 7.527297533327534, 6.4748741349866314, 6.519823026272559, 5.996077272199816, 5.199947424473302, 2.8083768390840103, 2.9674767534579, 0.937518667309515, 0.4709205902632206, 0.32668023820846315, 0.018188543767938693, 0.03125321187619721, 0.6685175566423325, 6.498084760481312, 19.339506972220637, 29.15609928869432, 27.684304406566007, 28.827800827641642, 32.51588390719506, 37.151191926771595, 36.10495851885888, 40.648318336855986, 29.862482855396888, 38.768361614596465, 56.00300512006206, 68.6349041231217, 63.88651024910712, 69.26540159410047, 68.48690525177987, 21.46120721294034, 3.4185130413501494, 0.6905770890655056, 0.06953292090686099, 0.19337461149740606, 0.07592138173359056, 0.13696616335261252, 0.0416731950826943, 0.1579320746203584, 0.058522394993492675, 0.19017328327942282, 0.2320581139816392, 0.20600697235955348, 0.09003840567123506, 0.014039146312091862, 0.04913865295689433, 0.049611356019252734, 0.08106314171586307, 0.06993383770027468, 0.09577446602164738, 0.12151455296383751, 0.16223891367835386, 0.09643981338388498, 0.052034304432210424, 0.05821306784186633, 0.06337070882680916, 0.07644394562850076, 0.004272115644022462, 0.1311103711205144, 0.0072004699764112315, 0.08408894386863516, 0.0812262801393386, 0.05044158465499359, 0.07643338127602493, 0.07978225036734536, 0.09121842622276276, 0.3900064143442339, 0.25849648240593176, 0.16488462896837344, 0.09723003307778029, 0.23679889588346406, 0.3534418344497681, 0.14095103097779138, 0.3801709179195666, 0.301572350004027, 0.3812688138456114, 0.16901165186878175, 0.19133439678097927, 0.11570753754987834, 0.17009577353394803, 0.21810949149151004, 0.24706856497833807, 0.24401625618338588, 0.4084024836699809, 0.45243580795584193, 0.29813892778850376, 0.4140452728156121, 0.336783467040908, 0.3725140223339681, 0.5892153829336166, 0.6513278306491914, 0.5440548062324524, 0.4847628184624257, 0.4148739041580308, 0.2436128036389428, 0.17535433894203556, 0.5376943765628723, 3.854170451241155, 39.39123007559007, 90.30826645512735, 88.76980304718019, 83.10190754552042, 77.02909792623213, 52.836918907780806, 52.68347970900997, 79.76695937495079, 56.02117353870023, 23.51051030620452, 35.95714399891515, 59.97877051753383, 57.36842924548734, 66.58357512566351, 58.19590814651982, 30.23117780685425, 8.316929974863607, 1.7957753039175466, 0.6138595734392444, 0.14744428497168327, 0.774619753562635, 0.2590778512099097, 0.9383695764887718, 1.1254540085792542, 5.273885573110273, 5.4084812152770265, 10.277078574703587, 14.72299789228747, 8.900824785232544, 18.98719576097304, 18.003320194059803, 14.519793621955381, 14.739236504800859, 14.663916210974417, 15.566470257697569, 18.445467410549043, 26.24708325632157, 16.65370714279913, 14.448309406157463, 17.64979304805879, 17.817211574123753, 15.41109242746907, 20.44168906827127, 16.211183378773352, 19.286329438609464, 14.473809715240234, 8.938275575637817, 11.254464580166726, 10.050605823916774, 8.932747975472482, 10.229558079473435, 21.131504543365974, 63.030284297081735, 65.43163776397705, 66.90472310589206, 65.48990457288681, 79.05929319320187, 84.78338841469058, 72.22645375036424, 45.00289447845952, 19.38737753898867, 12.745293744148748, 13.391559143220226, 11.205243737466875, 11.481977739641744, 8.447558629897333, 2.8092414765588702, 5.038818909275917, 6.223331064947191, 2.1570601626749966, 5.146983169740246, 9.671245947960886, 8.30348801228308, 8.610581159591675, 8.273110235891036, 14.87474556892149, 9.11906938399038, 14.162813809610183, 14.47633081866849, 16.35217591639488, 10.773297625203288, 9.407086083965918, 7.860459733393885, 3.755211993571251, 2.816187013541499, 2.145437199261881, 0.9511356656589817, 1.0632544107014135, 0.6155569791313141, 0.1376428181726125, 0.1880828131951632, 1.3898315641187853, 9.574752699944282, 29.83741890999579, 37.65749931335449, 33.81803627937071, 33.313560639658284, 37.52711972882671, 47.41287715973393, 43.546467442666334, 46.862443108712476, 37.50177337277321, 48.14189280233076, 65.26236003445041, 78.6648125802317, 75.19498194417646, 79.48333278779062, 75.42779030338411, 29.64593860410875, 5.369689954865364, 0.9506853285335726, 0.3680679851001309, 0.3465455415989122, 0.17263593722976026, 0.37826813937675574, 0.35567905633680286, 0.28225130611850374, 0.31114918450194023, 0.389226965846554, 0.5740567705323619, 0.5730318061767087, 0.3599907523922382, 0.17862590210091683, 0.23015565719575654, 0.25675623707713624, 0.2987403374525809, 0.3951597039497668, 0.24689847813738933, 0.23089220476967676, 0.40480873457366423, 0.3118233112317901, 0.1819213518812772, 0.22783693887533682, 0.2539335861201248, 0.16857367940247062, 0.1416205918236125, 0.2942316955135715, 0.0664230406043991, 0.1669709621778419, 0.13633389566694537, 0.30528217674263064, 0.3123553439734444, 0.27959766947934706, 0.27726649456927854], [0.12409891993288072, 0.057110249800907995, 0.08642890580719517, 0.022792090594227758, 0.05765450547539419, 0.0410341207058199, 0.021489689412016063, 0.0818433256579503, 0.01698999921040189, 0.029929691565132914, 0.07437366962192521, 0.08580715650872839, 0.05650999692959651, 0.02483861787515062, 0.04637252779737596, 0.0221807275327944, 0.04203108454784078, 0.2155132195161235, 0.036789307956613844, 0.08835249895890875, 0.09631317138912217, 0.09206703713824672, 0.06011957723286845, 0.31438161588964925, 0.2361986659947903, 0.17697508987640181, 0.14953910643535276, 0.1310630115650354, 0.03402229030466369, 0.20196562873259669, 2.445905953645706, 19.45588957878851, 62.1106493088507, 73.2078464569584, 69.40975266118204, 55.185438048455026, 43.79296095140519, 30.446861097889563, 40.20590636038011, 121.20342700712143, 85.04770909586261, 28.54598637550108, 42.61539874538299, 46.68675622632427, 38.115996929907034, 24.258812242938628, 12.067369914823963, 2.6620265889552335, 0.2542305371213344, 0.20140043970557953, 0.0330941403104413, 0.10304380538723162, 0.0539570931916035, 0.5234623628277932, 1.079174330638301, 3.5591231478798777, 1.165897322277869, 1.8464463204145434, 4.617363176038189, 5.139089890064732, 6.094135055618902, 5.635819829279377, 5.444897970845623, 3.7147598545397487, 3.971708686121049, 5.336672913643622, 4.595770528239589, 3.1079856138075552, 12.130085672101668, 7.897790891508903, 6.264801794482816, 8.451931092046923, 6.1775192522233535, 6.879756873653782, 5.02821478151506, 4.078567042466133, 5.323253504691586, 6.825882629040749, 5.801318355144994, 10.540022503945137, 12.048489585999521, 16.451013761181986, 26.344401182666903, 48.255767053173436, 56.778920542809274, 48.299748589915616, 41.4852423052634, 53.99748548384636, 54.1810171065792, 50.77931411804692, 56.93443467540126, 52.817381581952496, 31.663578364156912, 26.798189993827577, 21.58797429453942, 26.54078249008425, 17.108268660883752, 22.64377240211733, 17.38590971116097, 21.150863401351437, 13.807522577624168, 14.182075588933884, 8.197646775553304, 5.845389125808593, 7.755676556018091, 10.676038534410539, 4.5991824999932325, 3.4389598667621617, 6.2378560919915484, 5.047340258475273, 6.168433081719184, 5.465416869809551, 3.1262506208112164, 8.856805985973729, 4.42443355437248, 4.2234552291131795, 2.3379069230248852, 0.5274506778486314, 0.45274579777352275, 0.12581643543296284, 0.06659298188864224, 0.043009493740335594, 0.08626765196001338, 0.20604235029989676, 0.9820831663185551, 4.231303401531712, 18.048798115022723, 35.19719654513944, 34.57629711397233, 24.26231295831742, 26.092747795966368, 55.203877110635084, 32.734591345633234, 21.681881720019927, 29.908931562977454, 33.37032910316221, 38.30733014691261, 47.451740003401234, 61.4700674241589, 64.36146220853253, 54.25769159870764, 20.152981050552864, 1.5223172162809682, 0.4262143037011547, 0.1225632047581096, 0.11950605428747593, 0.11737722618084763, 0.1422458115003763, 0.05412377094128921, 0.05470451538360888, 0.09977251035912384, 0.026126363795370828, 0.1777322452154852, 0.018332141203685634, 0.14764130746404971, 0.07653717086800645, 0.03777684125628683, 0.0962666085650844, 0.04892317923687158, 0.023701829580409874, 0.050296824680821556, 0.07077934595966531, 0.08393392597715701, 0.060145141586901686, 0.11346124518182009, 0.048011572911374034, 0.022808519349763953, 0.0366838674451555, 0.049297244648539254, 0.025905856877685558, 0.03829186684602211, 0.05373381686607196, 0.08810194990327282, 0.13490198540591425, 0.10484279433806097, 0.0887133876582788, 0.11244483802828098, 0.05987545565491723, 0.04334601318283428, 0.13697552494704723, 0.1406881402456953, 0.03632710412925771, 0.05075146338992542, 0.029105742935151346, 0.08358242951573865, 0.11237783597842341, 0.05354641643803447, 0.059717771777462576, 0.06819687888867433, 0.02738565721008326, 0.0351469571732225, 0.04963634580734277, 0.02679296562658443, 0.057442199528938344, 0.015440941656819515, 0.014764983019220733, 0.051031989466038444, 0.13319739380911474, 0.18495420204295268, 0.17093817913724532, 0.15954997570764634, 0.08720463877844234, 0.07040138116046306, 0.019418631995757742, 0.10947492965046438, 0.13175472767362673, 2.966194138411553, 25.102155170133038, 74.48697843859273, 78.68882533042662, 77.08996526656613, 61.829466358307876, 54.48953505485289, 37.57328602575487, 52.74186811139507, 134.80621460945378, 98.2933335150442, 26.64580002907784, 33.21458355073006, 47.03322702838529, 41.227181726886386, 29.540719063051288, 13.476695168402888, 3.1947065216879693, 0.21892177451762462, 0.24483908057933856, 0.1102551672187063, 0.3760562596782562, 0.7806074967788112, 1.293899337610891, 2.9224881481739784, 5.854827819332, 4.383761027166921, 4.797952530845519, 5.599820806134132, 9.182717684776552, 4.915333380622249, 7.496422106219877, 9.644668948265815, 7.040056788152264, 7.169548936428563, 7.5449168201415775, 9.149062768105539, 6.615239583676861, 8.918020456067978, 8.198920074970491, 4.608916351872106, 5.559913141112174, 5.299774687136374, 5.062186919873761, 1.9511637980899506, 1.8284079528624013, 0.8603833579728681, 3.0101055627869022, 3.874586633136196, 11.801981368372518, 15.990987400854788, 20.38487941988053, 29.571313550395352, 52.82781900898103, 62.168578793925626, 56.21033768500052, 49.32974338531495, 60.67996086612825, 59.317678559211, 59.94087649929909, 64.2545658542264, 60.222977284462225, 38.73357019116802, 32.486322964391405, 24.658350752245997, 28.12549848710337, 20.626244429619085, 26.8835231181114, 22.53347143050163, 26.57440700838643, 19.80532373151472, 19.332330995990386, 10.980286982751663, 7.270988783528728, 8.056847414662762, 11.330756641203358, 4.300589619144317, 4.491561487797768, 6.178692040904877, 7.11262651989537, 7.885165762516761, 7.629500281426215, 11.699007384238705, 12.23912952407714, 7.530567809458702, 6.176044441038563, 4.540740165018267, 4.038866772767037, 2.3615318488690162, 0.7405635906803993, 0.3583352670313851, 0.3667410288847262, 0.21831668763151094, 0.09812939731824784, 0.3862696825977295, 4.2306346374173325, 14.755357446209079, 31.119639758140814, 31.923957063305764, 29.398168363878806, 30.135705355674993, 47.40899009089316, 37.50801386371736, 26.60592717509116, 36.74853709436233, 40.7922810892905, 44.8569626961985, 56.81869729872673, 72.1986049221408, 72.71568313721689, 71.89944574909826, 39.126262203339614, 3.3266484352850147, 0.4950161392409956, 0.0882572052820075, 0.07372457864544085, 0.07495988010158462, 0.08147395636525848, 0.06480608946613728, 0.04088461098651733, 0.07898518184740698, 0.036428009400204305, 0.03301851594099595, 0.01305760094715703, 0.08097166315682473, 0.03437396679674426, 0.03823918680990896, 0.05880841008958317, 0.04606970090178713, 0.047261660933614745, 0.06960189180268396, 0.028063058965809407, 0.06344839014233121, 0.05254485223802829, 0.09820138660049248, 0.04840600860094832, 0.05912051047949542, 0.07225372047433931, 0.010801318792566177, 0.01894302929060594, 0.00818838632004636, 0.029148607469734647, 0.04101453949847529, 0.055168002408238194, 0.013920577926441066, 0.015935181365949253, 0.3216833837570683, 0.14814177738322368, 0.2744251357451562, 0.2487405825165972, 0.26117156950696824, 0.1333087063845127, 0.08467159970032592, 0.23670491221691334, 0.1651614012136575, 0.29325199163248467, 0.16243129367789916, 0.20722511344619338, 0.15315403020189655, 0.1596305068702467, 0.1365702337915859, 0.19423328880821505, 0.19417632251016556, 0.3632674330184537, 0.2349962143888397, 0.2161880357251052, 0.18090063165272438, 0.3654149613313137, 0.23294873715889072, 0.479368701457016, 0.35528746283342766, 0.42263734725213825, 0.19059795645936844, 0.22471079452624246, 0.2221295685176888, 0.34451727785410424, 4.511665105819702, 35.16478992277576, 86.9918397165114, 91.26541106931626, 88.35238441344231, 73.02209085033786, 60.17707770870578, 46.9956507221345, 53.07797208909066, 125.047710634047, 87.2399845430928, 39.24623181743007, 56.52193469385947, 60.85746772827641, 52.68396216054117, 35.540097990343654, 16.908992644279234, 4.060716580960059, 0.7465053686211187, 0.46696362356024407, 0.24513134312245155, 0.269557505004829, 0.5103344350091873, 1.384735302098336, 3.416279986981423, 9.191625387437883, 6.284768619844991, 8.723573857738126, 12.119654128628394, 16.035941685399703, 15.618125911681885, 15.63229351274429, 15.642500500525198, 13.795955507986008, 15.387274815190224, 14.812327911776883, 16.785334041041715, 13.584150460458572, 26.644468384404338, 18.894798448008878, 18.902607887021958, 20.82855636073697, 17.31973344279874, 16.80366131567186, 15.16178854050175, 11.982059344168633, 13.396918081468153, 15.252192308825833, 12.280529160653392, 15.32992878267842, 16.87882177291378, 22.339116027278287, 33.901386645532426, 56.568740337125725, 72.84507428446125, 59.174076664832334, 54.13860451790595, 65.11976618920603, 65.05688667297363, 67.92035810409054, 71.20386046748008, 67.40949292336741, 44.890079267563365, 39.24828321703019, 28.096100322661865, 28.06486648897971, 20.93547428807905, 27.560402616377804, 26.41121875855231, 29.939455447658418, 19.690682657303352, 21.19375255800063, 14.991527276654399, 10.738793515389967, 17.48023290787974, 18.877077179570353, 11.227028581403918, 11.269013631728388, 16.84157494575747, 14.687203322687457, 18.357469035733132, 13.93214020036882, 11.366468841029752, 16.10164530815617, 14.054656413293655, 12.11694279024678, 8.095638184778153, 4.413843645203499, 1.6453623363087255, 0.9568848184520199, 0.5072496440862456, 0.4553302413513584, 0.42892934994832166, 0.4901173440439086, 1.331912742987756, 6.151972364994788, 23.11768493344707, 47.266109912626206, 47.11878961132419, 35.969295501708984, 38.980726580466, 69.94605833484282, 43.19922393368137, 33.91885688227992, 43.10693840826712, 48.11565214587797, 54.73658946252639, 67.82091033074164, 81.5779882861722, 84.00792798688336, 83.86178047426286, 47.27151493872366, 5.304752665181314, 0.7088330868751772, 0.2806449729588724, 0.30251086899830454, 0.2698951046313009, 0.27984533038350845, 0.2599104968530517, 0.17667521241932146, 0.42462206655933016, 0.22470722455651532, 0.30718495528544154, 0.12761432121718122, 0.2576545211336305, 0.2835947791895559, 0.13379789948944124, 0.2400349585279342, 0.41097188128098366, 0.14824912162317386, 0.30360524091989766, 0.19373330918531265, 0.190491960534165, 0.15688251884233567, 0.24540048513200977, 0.1634248331068985, 0.14422139903951076, 0.1692317795729445, 0.13373163288399098, 0.09028596698396629, 0.17575242887100867, 0.13449917637532757, 0.18370020804145645, 0.2684147776134553, 0.16420916924553533, 0.2591623660297163], [0.11808011185137496, 0.11302020070293259, 0.12142424651932333, 0.08331574664841737, 0.020552549376002243, 0.03596489009777865, 0.021298960331947576, 0.050868310950576305, 0.010645327969424186, 0.023809302140087373, 0.024801430052086234, 0.061259895277720314, 0.03350701956679264, 0.20223498524677372, 0.02683336718849117, 0.05134087228666871, 0.06748124551508697, 0.10090979086535593, 0.07188968315360046, 0.03126610896640247, 0.02409524062738544, 0.05232378990659791, 0.06764197076160101, 0.13579453912473496, 0.08769229970752232, 0.1965594535032588, 0.06367413327097893, 0.1313054477495532, 0.0385358045628715, 0.4608285156709533, 13.987739797561401, 52.849741135874105, 66.21344458672309, 74.69116134028282, 54.88815769072502, 51.46773715173045, 44.076085475183305, 33.08487076913157, 18.61418620232613, 13.521333702148931, 13.161679813938758, 32.95649159339167, 46.21313787275746, 32.242579037143344, 29.484080037763043, 11.220147763529132, 2.0467376180233496, 0.1812978482414638, 0.20245322837464272, 0.07470339386453552, 0.11970538270449448, 0.13099239358017523, 1.3628574244437681, 2.374354567258589, 3.002169627335764, 5.7123516451927925, 5.347590340721992, 2.4268324480902765, 5.294228455712719, 5.181846176424335, 7.382021767477836, 3.4272959636103724, 5.713384209140655, 6.8406920279226, 7.504419819001229, 4.677817196615281, 3.9460335864174754, 3.229049324027954, 6.670011560763083, 8.615313499204575, 8.652818222199718, 6.521465518782216, 7.9887741900259455, 9.184097378484665, 6.779399600721176, 4.068378195647271, 6.400253003643406, 13.056343582368667, 31.64829680996557, 43.32600670476114, 33.18371057510376, 33.98458403925742, 58.393987840221776, 65.34230970567273, 50.67426520009195, 39.14576030546619, 40.616413777874364, 49.29599138998216, 51.09132297577397, 48.24853812494586, 45.32704307186989, 47.39672091699416, 48.1330321681115, 35.125079847151234, 51.051412859270656, 52.20219312175628, 54.490711765904585, 52.79525156944029, 43.04514538857245, 41.83903617243613, 38.639770630867254, 24.548528309791322, 26.510521404204834, 28.112648802418864, 19.243179444343813, 19.819326593029885, 13.795823127992692, 12.922884937255615, 17.233590349074333, 5.626818480030184, 4.047224853307971, 4.782088014387316, 7.783340542547165, 5.604585995597224, 6.279481264852709, 8.022210924856125, 4.585085011297657, 6.068472458470253, 1.7317275342441376, 1.2097926894503257, 0.4106986636836683, 0.35701621684335894, 0.13572479448010846, 0.07232868217773016, 0.05769697355947668, 0.06475739691767, 1.6025589815070553, 11.711373636799475, 41.83425872556625, 47.83825428255143, 42.17842317396595, 38.25702967182283, 29.11801895787639, 23.2028042885565, 14.954706026661782, 26.08114934736683, 40.57313042302286, 44.190881483016476, 51.11824612463675, 56.62644232473066, 63.67802058496783, 61.97347225681428, 28.200615798273397, 1.73150543003313, 0.40938359715284844, 0.11298134472341308, 0.07692082770048611, 0.017699955872470335, 0.05403102450673619, 0.02901133600502245, 0.06894992799648354, 0.02945988048468867, 0.06936951435261196, 0.031988928244719585, 0.06752715716438909, 0.0674975402052364, 0.029292463460156036, 0.07420737491620165, 0.02499043926476471, 0.03367308061569929, 0.10126275821558892, 0.02310052716864213, 0.038505693477007656, 0.08681556570433802, 0.10142043443216432, 0.0577110619164042, 0.02515991898103347, 0.047893553236199, 0.06248553253469929, 0.03147002625008745, 0.07776163218002166, 0.0718952372910515, 0.04908287792556709, 0.09290456276146636, 0.06869479773506042, 0.05217293570298822, 0.08128746758185088, 0.018587512782804908, 0.04589166589862397, 0.03306904327004187, 0.045696007042762735, 0.031052334046351816, 0.0236883751612397, 0.028405090410923286, 0.025253699634284265, 0.05443662592780687, 0.03933585316483532, 0.09360842136365753, 0.025300980665751045, 0.11830925641040649, 0.06046828130380281, 0.06898435598780071, 0.08586514936459642, 0.026574253269861785, 0.05699080903263343, 0.09162793086180765, 0.08013003130233096, 0.05618396906122085, 0.029527771196538405, 0.08199396918738082, 0.12050835776232904, 0.08857117109601537, 0.030358614617838498, 0.11284448311574037, 0.05316926752247157, 0.6624571882909345, 19.790575619666807, 64.07664714321014, 74.97179123663133, 80.78705018566501, 65.60801106114542, 63.391946438820135, 58.425096158058416, 47.67409524609966, 27.523491151871223, 28.503005043152843, 29.414101031518754, 32.06858073511432, 44.47691248309228, 36.96700526821998, 29.21487012217122, 10.788488964880667, 1.6538109990858263, 0.15263476048506078, 0.12729639472860482, 0.3100405327014385, 0.4108477137502163, 0.9316069200154274, 3.9288469860630655, 5.980114206191033, 5.181190650309286, 8.908354755370848, 6.07267871018379, 3.4067694650542353, 6.047279402132958, 8.599220994980104, 9.519903256047158, 7.626970352665071, 8.700971199620156, 9.41663117178025, 9.48407534630068, 6.568775676911877, 6.562578822335889, 4.2964495574274375, 7.851710886724534, 2.0533045237102816, 3.864150186700206, 4.697976218115899, 6.122372688785677, 7.215524017810822, 5.051957868760632, 4.356501535061867, 7.420941975808914, 15.449814065810173, 34.31121941535704, 45.31391489890314, 37.683092778728856, 36.5933406737543, 61.936315644171934, 67.46135450178578, 56.674412911938084, 44.23292144652336, 48.62838829717329, 57.04704200067828, 58.29824670668572, 56.04597468529978, 52.14083156278057, 54.44777357962824, 52.36873303690265, 39.21240137469384, 55.69877040001654, 56.125838064378314, 58.18555308926491, 56.320803396163456, 50.57660602754163, 44.32083352919548, 41.291469374010646, 28.84596532390964, 31.446910558208344, 33.230994747531035, 25.26050909872978, 19.53687475573632, 14.83455990591357, 14.556801184531182, 12.445681537351302, 6.885739959055378, 7.012683547312214, 2.7917947740324083, 7.772656496494048, 7.71769428445447, 9.975481648598949, 9.068477672915305, 5.407734984351743, 5.196774717300169, 4.4132513673074785, 3.385344498580502, 2.4954768678834363, 0.384326056246796, 0.20268000572198824, 0.12560897116218844, 0.08041996493815415, 0.10163219645619394, 1.4306064406710288, 11.983876382150958, 35.45565328290386, 39.71385678937359, 36.408400920129594, 45.31202823885026, 33.285390177080714, 23.680541130804247, 25.692542483729703, 34.09670891300325, 51.34578674070297, 53.60613099990353, 60.401221552202784, 67.47192921177034, 73.03704292543473, 75.44406813959922, 45.70164511280675, 5.450992353500859, 0.3822180887143458, 0.13546363510672124, 0.18064704122802905, 0.05301784641379791, 0.13104696968390098, 0.04693420048082068, 0.07532449964914592, 0.010092426035102579, 0.044026854673340436, 0.06895413381918784, 0.053599207556896636, 0.0750257023760388, 0.09154417446904606, 0.060147470494191495, 0.16078975111726793, 0.03687113380780624, 0.025149944516259338, 0.00018402881822464313, 0.07001206293822297, 0.09709402948858277, 0.0905906861167281, 0.0285544813865976, 0.044299325334929654, 0.023031157907098535, 0.07154652938967751, 0.055429242220857454, 0.008250308249356046, 0.05421369817228087, 0.04834228157696705, 0.027055387129826892, 0.040981551752455776, 0.12892243933052788, 0.3665776070087187, 0.1929986308659277, 0.24733965285122397, 0.24174129680520107, 0.1132237119600177, 0.11425678152590991, 0.13343057565150723, 0.17105634053868635, 0.16317623757546948, 0.19538553101160835, 0.08694174038546701, 0.20105914753531257, 0.174795447157756, 0.31877359795954924, 0.14244576044861348, 0.1125287629603859, 0.12850122120712074, 0.2973596937954426, 0.17087407289974152, 0.20245682898788683, 0.16282285653775738, 0.2577091891679072, 0.18202763891989188, 0.3203426686025435, 0.20236699751788573, 0.2604846644305414, 0.29597338108766463, 0.237004452595307, 0.35005661448644054, 1.4269615781884042, 24.509894924779093, 78.83920900283321, 86.63291931152345, 94.46215844923451, 74.33365298855689, 69.85084672128, 59.55503686781853, 46.817983042809274, 28.009478699776437, 20.089079756890577, 19.399344690384407, 44.890938266631096, 62.97067603757305, 45.604044775809015, 38.14410463456185, 15.091605571008499, 3.3029708025916933, 0.8094090319448902, 0.42044799053861254, 0.3607879434862445, 0.412554772150132, 0.848506604952197, 3.5225230215057253, 8.111520351902131, 9.062074403609, 12.081078598576209, 12.147884407351095, 7.029979728883313, 15.317403674125673, 14.758247252433533, 16.90494083589123, 13.472280540773946, 18.736479820743686, 20.029377360497755, 19.727745133061564, 15.077128102702481, 11.4266634948792, 10.90479802700781, 14.236673020547437, 17.052984814490042, 16.336581553182295, 15.868270166458624, 16.837799664466612, 18.15270954562772, 12.036784252812787, 9.234835197848659, 10.205722816528814, 16.67251883014556, 35.907973166435, 46.794519424438484, 40.64581586468605, 42.73159896173785, 71.8908400689402, 69.48531320018154, 63.952943432715635, 47.37946641060614, 52.54720087974302, 61.67560354355843, 63.82012805631084, 64.68552843216928, 59.3516541296436, 58.37976924834713, 59.11707678148824, 44.749560356140144, 57.375536580239576, 54.11938882643177, 57.709079250212646, 60.892102256897964, 52.99659859749579, 47.07596125141267, 48.756716482100956, 36.09174797611852, 35.66010682813583, 38.38112954170474, 26.91151119047596, 27.238970264311764, 20.79299419156967, 19.905150013585246, 28.832203688160067, 12.067245379570993, 10.234554198480422, 13.997903639270415, 17.61488591471026, 16.10325740229699, 14.492736131914201, 16.66840034146463, 15.234925054734754, 13.134308534283793, 9.161278009414673, 4.057072944218113, 2.407254917967704, 0.5865675379191676, 0.2644974636214395, 0.15697883141617622, 0.11666473376774981, 0.19639741058551496, 2.3863305439872127, 16.67821999519102, 56.11062711285007, 61.904183587720325, 56.910115980332904, 48.71601404682283, 39.60131614438949, 34.571205877488666, 26.34559358319929, 37.6028371626331, 55.88258443340179, 59.818098468165246, 70.17664663253292, 76.52570093831709, 80.57101388131419, 89.16584476347893, 56.72808270300589, 7.176043891137646, 0.5529340717100328, 0.2063359305142395, 0.3535056036085852, 0.1683847161550676, 0.2704830005043938, 0.0925361740613176, 0.21564469552568852, 0.10803794788737452, 0.2854835842886279, 0.47518776128849677, 0.19370626628158555, 0.157898458682241, 0.3416233347548593, 0.22109401682692192, 0.2843779661963063, 0.23299706198515432, 0.2813903765091973, 0.22055416998843994, 0.21891334755045755, 0.2549477333142873, 0.21005899525217472, 0.09638693799535114, 0.08184419899818399, 0.12430798532741687, 0.14401841638309343, 0.18247342548303067, 0.19007219031693476, 0.1695015650963591, 0.2065890306426633, 0.17873445675978739, 0.14485172086185025, 0.2596802414665299], [0.05552927415157038, 0.10744112708996381, 0.030236760672602444, 0.020207465070510106, 0.024614418413670316, 0.014701078837406973, 0.04183091726454516, 0.04442454623659292, 0.014103445029186626, 0.05063549683038747, 0.05135578035767521, 0.025435195439645363, 0.05862663657734952, 0.042418928050826636, 0.05248051234370759, 0.03912502576807334, 0.08419372937491826, 0.0417205699599318, 0.0758708275914673, 0.09745027569513168, 0.050730372989369985, 0.057664560379400376, 0.1292440736846578, 0.12889130551728512, 0.0944087304355156, 0.02056501937218972, 0.06021829532279123, 0.10440617018649656, 0.050533070874911164, 8.143012081423114, 53.455025611385224, 69.41085876957064, 71.59843521733438, 61.740146144743896, 50.643313777062204, 29.457364774519398, 19.896622780830633, 15.970406724560647, 24.347687267488052, 28.797443643693004, 27.669585712494392, 36.8391752243042, 31.797360604809178, 29.927266682347945, 8.350490754650485, 1.6852121463706418, 0.3062810021783075, 0.08091154823740644, 0.158710818317148, 0.18973751714633358, 0.32310325111592975, 1.7750347910388824, 2.5331676583136282, 2.4257113856654016, 3.6347768431709664, 6.88292222638284, 4.892238955343924, 4.447251452553657, 4.397835471937734, 8.836667556916515, 2.961526272758361, 5.432278235112467, 7.0204169904032065, 5.577822683318969, 3.200741333346213, 3.122165717424885, 7.124780474170563, 5.23191572197022, 6.829748124845567, 9.878752077779463, 12.062457146183139, 13.52642591922514, 14.459740173432136, 37.683771348768666, 39.478192944680494, 41.237956477749734, 45.724492919060495, 63.2129059299346, 61.50481962388562, 65.32951101180046, 48.41574484302152, 43.43677836079752, 58.86407606063351, 69.36800295306791, 51.49066732775781, 33.969298562695904, 43.81774248615388, 44.58148287188622, 43.267649681337424, 45.17647897043536, 37.18660308468727, 66.36348309055452, 45.527888036543324, 38.149352765852406, 63.36892212590864, 61.78697532223117, 61.9757942999563, 65.03600397417623, 70.69090074108493, 53.45053449753792, 51.91389499172088, 48.60739577201105, 45.913488403443374, 44.954853288588986, 48.71867341379966, 41.13207993968841, 36.02059225882254, 33.613696482873735, 22.476455857676847, 17.507911113000688, 12.881408814461002, 6.991733187629331, 17.292184675893477, 10.168268103753368, 5.850836317385397, 4.636899521273952, 2.8711989906526383, 5.109047476322421, 3.870739523441561, 0.7569939090359596, 0.6162798596966652, 0.8726698761024784, 0.13428569831434758, 0.1395439726090239, 0.06859329108509325, 0.14674887631929692, 0.14799861087193414, 0.4569684744121567, 8.167007180952258, 42.373125706949544, 53.98733831221058, 22.651668133274203, 21.93146997882474, 28.38805410169786, 18.049557093651064, 15.961176406952644, 15.19098666406447, 25.935245021697014, 39.91903989545761, 54.9414195552949, 62.201989543053415, 67.04805435672884, 64.13600044865763, 42.04785139329972, 3.700699383212674, 0.060732056867451444, 0.07862844534458653, 0.01595235993004134, 0.037965612981708786, 0.08562049918597744, 0.15836275392963042, 0.024164389638650804, 0.054575096320120565, 0.12284219099749481, 0.11821496630868605, 0.11272518024329217, 0.0284976932039905, 0.09603824541573563, 0.11934663139043317, 0.05129948055611984, 0.010025569541950621, 0.024294187915661646, 0.03309607085201048, 0.05659310214762246, 0.022135920965323047, 0.05770619725808502, 0.0637799874699164, 0.061152344194030574, 0.02992466411312982, 0.06664841601084318, 0.07093476987774334, 0.10865922221132826, 0.04161938506689283, 0.02458137895671591, 0.032985532025416056, 0.05055495800690786, 0.053605680999856804, 0.1099973020233935, 0.056763074075382565, 0.00885298004328844, 0.021045708901158745, 0.030176147796033375, 0.027474935181559097, 0.15472487816887517, 0.011581192469044078, 0.0497911453637625, 0.034961674978295644, 0.020278318627406994, 0.0493317415877696, 0.04986994516765399, 0.06000220107154981, 0.022372188226830576, 0.07918984989725775, 0.08000886683622677, 0.05910311645317463, 0.12788195403352862, 0.04595647310657848, 0.152719673670588, 0.07645361365810519, 0.044274906282343214, 0.010354194448389595, 0.05524556114969235, 0.06167126917130044, 0.09148525464678965, 0.04845261739026155, 11.37432829026253, 62.01036214828492, 80.792831759299, 78.8302581541, 73.28023772085868, 62.77091756943734, 41.440982280238984, 34.02001088665378, 27.25894689559937, 27.474296785170033, 27.897740179492583, 20.106159717805927, 30.262692090003725, 34.27842055597613, 25.907511903393655, 8.936527179133508, 1.154569884942424, 0.18326936019284112, 0.14395706806211703, 0.18648444734994443, 0.5015354861895884, 1.209018266489429, 4.0758179512716115, 6.286055157261511, 7.241914704922707, 8.068089908169162, 7.539094551917046, 9.539769080377395, 9.645805455023243, 10.519437905280821, 13.087295985990956, 7.218372148852195, 11.004026147627062, 7.981814924747714, 10.26038790902784, 7.961497047255117, 5.49423256228047, 3.562680002181761, 5.4317987253589015, 8.617798320708737, 8.923635328969649, 11.640516019636586, 15.407371078768085, 19.927129014845818, 40.843809266244214, 43.98548656894315, 45.27917446628694, 48.5301721480585, 65.74563526338147, 63.14984598467427, 68.43791484832764, 55.00570328004899, 46.70585816906345, 63.41852834147792, 68.28925701879686, 56.55166625976563, 39.50921497037334, 49.07071398150537, 52.20463675837363, 48.441338308395885, 53.119710030094275, 44.919214633203325, 69.26419350408739, 49.77974514807425, 42.048690780516594, 66.15333818620252, 60.70386378995834, 64.66930943150675, 68.25978432932209, 70.72831230778849, 56.96337392253261, 55.55618439951251, 52.26759079963931, 46.94411077807027, 48.883295289931766, 52.080701628038966, 44.81417748235887, 37.31967341515326, 32.66745605776387, 24.919592372832764, 16.553243475575602, 11.122089489813774, 6.987254821485089, 5.838066060696879, 4.317641633172189, 3.239890264887964, 6.6814290900384234, 6.643802283271667, 6.75385614556651, 6.914970932468292, 5.394052776598162, 3.4471522271633153, 3.4452383556673607, 1.6315492194506431, 0.7528128462933725, 0.2194806969454212, 0.08082850430641444, 0.08277148714349156, 0.4491043060777649, 8.187280931780416, 33.49579788023426, 48.228208480342744, 25.864010856997584, 24.710398643247544, 30.486341714859012, 23.427487457952193, 20.723281906497096, 24.22002196311951, 36.88623582163165, 47.88786049812071, 60.63167648930704, 72.29268689309397, 73.19513013285976, 78.05983404959403, 57.678931913068226, 6.83682260974761, 0.03453347013301907, 0.0776125897743529, 0.03294843038724315, 0.05971659966293843, 0.09296753518884221, 0.1143132651885671, 0.03273040559443255, 0.03636408319336273, 0.11599220050078247, 0.03701296732610753, 0.09879897348582746, 0.05179023264997429, 0.11205320622050956, 0.05555787221378377, 0.0722046985080646, 0.041972624378338944, 0.17839229124928677, 0.09069645221555427, 0.08392462566975625, 0.04505026004006786, 0.004085490401203354, 0.042295679825568394, 0.009906373921811823, 0.03623535743944588, 0.02408120398139281, 0.023023972002368782, 0.09248581910205465, 0.033280529502418735, 0.018414876784288117, 0.011815436300821604, 0.029811895970675736, 0.16629309693892158, 0.27357836344069053, 0.15522608353245645, 0.112915683327423, 0.11795380693529883, 0.07934304449947611, 0.16706686106420335, 0.2694385775154637, 0.12229934109434967, 0.18964074491973848, 0.18485146965230667, 0.17316306700869916, 0.1580750725923046, 0.17637495191827898, 0.18058117298829943, 0.1561194186609599, 0.16905272950328168, 0.18984351307153705, 0.25545407146696125, 0.21692490505595363, 0.1734293132059036, 0.25920931189771623, 0.24194947353774504, 0.2646285872305593, 0.11171705450021452, 0.11790420274220167, 0.1603429073527936, 0.28643193985185317, 0.12007919530714713, 15.852278663266091, 77.28732324415638, 91.1199382043654, 91.89569673230572, 81.3335697112545, 70.57508099463679, 44.733157004079516, 31.098961022592363, 24.382945452967, 37.13725574554936, 39.67897515143118, 40.35137922533097, 51.78205628548899, 41.70462831374138, 40.000786012218846, 11.619193034787333, 2.5494861891192775, 0.4023553839614315, 0.27625375697689675, 0.2557010122484738, 0.5979245768920068, 0.7215690228246874, 3.8563380510576315, 7.398976212547672, 9.282006602133475, 13.160227556382457, 14.73053276538849, 12.030335876249499, 13.688184465131453, 12.952999914846114, 17.66154446909505, 11.432104802900746, 18.15919518470764, 11.953534887683007, 14.800628462145406, 11.506781828018928, 10.660558900525494, 16.227691654236086, 11.864630445357292, 15.082636091016955, 14.905629331065764, 16.49048359163346, 18.60423711038405, 24.137671801351733, 44.22444128221081, 44.210332516700994, 47.53810274985529, 51.725962469654704, 64.5826328954389, 62.0183127926242, 65.42333802869244, 56.58057020556543, 51.438927342814786, 72.25212958551222, 68.12681598048057, 60.97096935395272, 43.48407037796513, 53.210422685069425, 58.98760718684043, 54.81060458767799, 59.69478699468798, 50.060724135368105, 71.6239070892334, 57.38051799035842, 44.36187328830842, 65.59624787299865, 58.33101026473507, 65.14275127841582, 68.33973007817423, 70.86150030935966, 64.11637683068552, 62.04926813802412, 54.662040895031346, 49.21715567188878, 51.30044806388117, 52.12042739314418, 47.88211422581827, 39.47556103429487, 40.67681827852803, 29.276319934475808, 24.75332506241337, 23.00375576942198, 13.65994732226095, 27.32102232594644, 20.794098338773175, 16.89148122264493, 11.402150642487312, 10.803758751961494, 16.233770347410633, 12.686600377482753, 5.934373976722841, 4.242820460950175, 3.4116785564730248, 2.0637499180532273, 0.7121692465678339, 0.39931150213364636, 0.3472012822185794, 0.3080086530216279, 0.9942261502146722, 10.943850125035933, 55.91097847107918, 68.7317866663779, 34.393232253289995, 33.15908201279179, 43.606742505104314, 29.627613290663692, 25.729946205692908, 26.444904073592156, 39.68594912559756, 54.89364116422592, 70.90883547259916, 84.48673171381797, 81.74995283926688, 91.06610759612053, 68.1417445213564, 8.473074628460793, 0.17415806200475464, 0.307940348622299, 0.2529695104326933, 0.17504583533492782, 0.20089958674244343, 0.2687310187085983, 0.17310686679857393, 0.23081957963445496, 0.35072580761005806, 0.14279223137324856, 0.21445664637271436, 0.2819949424555225, 0.3515956238392861, 0.2526138004876914, 0.2758768723616677, 0.13083264892620425, 0.3890046164874108, 0.1609497102758577, 0.25750577750225223, 0.14709344734587979, 0.1310076540516269, 0.19820804407279338, 0.16447109470684684, 0.09710365921379098, 0.2115520699730804, 0.1791157233979433, 0.25480085893744425, 0.13757676607178104, 0.10267915519615335, 0.12036902169066092, 0.2189954721759404], [0.043030997828370145, 0.025901610835365234, 0.048332264977357084, 0.023807268176648407, 0.005208219546118691, 0.05035695109155871, 0.029621758693528753, 0.07795705354862636, 0.029710238018343528, 0.021217065532841993, 0.050327801446039835, 0.04722363615949308, 0.019235985143290415, 0.02629251485960859, 0.06347387788757201, 0.053008458006285855, 0.13678912043331132, 0.04279850163466988, 0.019116814421009154, 0.052735937548981565, 0.02607565260522308, 0.06705140890253168, 0.2029064000253716, 0.042916383414018544, 0.05328323459252716, 0.047452458961596417, 0.09389342139324836, 0.042910699041620384, 2.385581861580572, 40.44867361745527, 76.31119435833347, 62.90283472307267, 62.085181359321844, 46.684340046298125, 35.66317804398076, 29.21680973422143, 22.22694408509039, 20.683946417224025, 22.79488563537598, 29.42549159449916, 45.27324776495657, 50.57045182874126, 33.53704160259616, 9.134847118008523, 0.8426351845264436, 0.14972479082643986, 0.03117645369662393, 0.04409340090088306, 0.03274308051913977, 0.2924323081970215, 0.6386554493538795, 3.533522818357714, 6.054832416196024, 7.199559480913225, 4.363888828985153, 7.431282814471953, 5.234012719123594, 3.436125218868256, 5.161073303991749, 9.231409988095685, 8.673391053753516, 4.440747182215414, 7.246429843287315, 7.743856493503817, 9.122344563084265, 5.527102514620751, 9.275941637254531, 16.373270423181598, 25.058430548637148, 27.43505935515127, 38.16229266505088, 52.035245280111994, 58.03571854868243, 64.29659797299293, 66.70756124681043, 68.0971863961989, 63.587021596970104, 66.04315880806216, 70.58920937199747, 65.52306821269374, 65.992826954011, 66.1897534708823, 65.76663171091388, 66.73372345585977, 61.069558128233886, 41.001108077264604, 37.71743705195766, 39.998899352165964, 40.369508420267415, 36.72728569276872, 55.68299462718349, 66.71028337171002, 54.71422803017401, 57.72608272490963, 65.4957724386646, 57.02219378563666, 64.28044565262334, 66.8962743205409, 61.84878010903636, 66.32798564049506, 71.36417558116298, 61.836240291595466, 56.96241294184039, 63.49417517262121, 61.5869854342553, 61.017021902145885, 59.89063485976189, 59.94573631594258, 48.474521560053674, 35.29140403193813, 29.44621151493442, 12.067542499111546, 11.454865336418154, 6.61302883778849, 8.004517603305079, 5.6438038137651265, 2.773597182766084, 2.4968425881478096, 3.243618722884886, 5.0010680575524615, 3.0560678964661014, 1.1158818318959207, 0.7717279248660611, 0.24516226243107553, 0.06589619427799218, 0.03023478225053799, 0.031631368197380536, 0.183465892388936, 0.4485498116381707, 8.34925030508349, 30.302049152312744, 62.01240962551486, 55.827910515569876, 30.39531723145516, 27.69698346814802, 29.223397354925837, 26.61844934186628, 21.511764603276408, 23.937558358715428, 40.441605506404755, 44.79659349687638, 51.221267177212624, 61.97102862019693, 65.4612006679658, 33.79174855447585, 3.074427285502034, 0.13319590759854164, 0.07226445336615847, 0.04537973913454241, 0.09296368942746232, 0.050534568576803135, 0.05387571550184681, 0.07814795499847782, 0.06192983533706396, 0.11553481536647005, 0.09786548768921245, 0.03865943583209188, 0.09535085770391649, 0.07885673188514288, 0.03370934338759511, 0.049941739097477934, 0.1285868162109006, 0.06355282707860874, 0.006749726824402329, 0.02445639171186955, 0.0838010173831736, 0.04819728411553849, 0.0213076094646127, 0.03525897071907117, 0.014769308543163202, 0.00969233470142729, 0.10819860418597538, 0.057924616586176626, 0.03218714966468754, 0.036374298975833004, 0.034773592732005545, 0.044555432358456236, 0.05938664942439045, 0.047809072890348976, 0.021436434809959704, 0.031461606943799604, 0.022073279870974443, 0.011228498037634118, 0.05286245313923686, 0.040172532260898626, 0.018711745431045854, 0.010817858630851393, 0.06767703460589533, 0.0655906401093929, 0.015742097523123506, 0.0673725606212693, 0.028525864172186104, 0.01962025293088969, 0.054463496461751006, 0.021806771288655942, 0.08749598967692546, 0.05498999038771276, 0.0327088134062867, 0.07257460406230343, 0.07730679045761786, 0.028306343592703346, 0.09363163382776322, 0.1252310982935371, 0.030895257293577158, 3.5825747539920196, 48.41277168643091, 85.09495012221798, 70.34461036805185, 72.34931807364188, 58.353301094424346, 48.22940088087513, 41.101261877244525, 27.006785561961514, 26.622752181945312, 22.47642447871547, 24.536090473974905, 35.752396275920255, 44.86562328953897, 24.92995135245785, 7.621897257143452, 0.4655058808144062, 0.22261375140759254, 0.2410887737548159, 0.30343204376197636, 0.7214145182121185, 1.5921803900311071, 4.922527007518276, 8.977084486715256, 10.323697905386648, 8.710177983007124, 11.438309011920808, 14.768415997105262, 11.288881417243712, 10.00130065025822, 9.049133523817986, 11.204845616894385, 10.413891826906513, 6.833155193636495, 9.179550370862408, 10.639562452993086, 7.064095033753303, 5.855290168716062, 7.5251186566968125, 17.280731354990316, 26.39007326095335, 30.48822053017155, 40.98340249830677, 54.44082706205307, 63.143546658177534, 66.72634939993581, 65.98128734096404, 67.18330552501064, 64.68276708356797, 66.57342403165757, 71.0795448672387, 64.32290530973866, 69.93811945761405, 68.90823056620937, 69.98754132178523, 67.00040540387555, 62.28137047060075, 46.481867298003166, 43.80904659148186, 47.02766902985112, 46.94521296408869, 44.960752533328154, 58.433799897470784, 66.68874171472365, 58.462162556186804, 59.73283790772962, 65.37727763575893, 58.33758415714387, 64.51739603473295, 66.88018475809406, 63.37444874548144, 68.8104772567749, 74.27877902984619, 61.88551702807027, 56.56182127614176, 62.56489115376627, 63.18928541675691, 64.78501935159007, 61.23501939158286, 59.99201636160574, 48.35872142545639, 35.97584585989676, 28.762099166070264, 13.56681554548202, 11.795234891676134, 7.57292744613463, 7.10489405739692, 5.8481828339638255, 3.0838451414339008, 5.820444322401478, 5.460490863169394, 6.491302492157106, 3.294523488129339, 4.862172026788035, 3.972530177524013, 2.1118675941421143, 0.5077409209503282, 0.48385095932791317, 0.04284966481669296, 0.07336827881273723, 0.3699121732384928, 6.96521306230176, 27.02095904657918, 54.559208116223736, 41.97855880183559, 32.051959691509126, 26.997634672349502, 21.754267100364935, 28.93819397495639, 30.293647435403642, 39.31346516455374, 53.73495732584308, 55.31832010515275, 60.00357558650356, 69.29747873736967, 73.69538922463694, 47.84883683727634, 5.757480965506646, 0.18024401769282358, 0.042827858123928315, 0.010699274923442113, 0.016903871775514657, 0.02499950591534857, 0.06624266520262727, 0.10512760284567073, 0.09127843388987165, 0.08617919944827596, 0.0627161939478209, 0.043792787999395406, 0.22304688219822225, 0.05044649144814861, 0.04673031001021305, 0.04581118070129906, 0.025996475503028884, 0.057671807571164066, 0.03787402333992143, 0.0354925356054258, 0.018996316451399077, 0.02812958412593411, 0.05412733325013711, 0.057284377755657326, 0.0626582623789868, 0.027931215234040737, 0.04504161473784236, 0.03387053594774297, 0.05805612323925861, 0.042352450771197196, 0.026886367066312703, 0.13469385463864575, 0.16486440424717244, 0.12240725990024307, 0.2036052713951757, 0.09753195598961846, 0.1314819850508244, 0.08376191625551832, 0.13301475844796629, 0.20573039929712975, 0.19738135859370234, 0.15489367798211115, 0.11424081625356791, 0.19038979504858294, 0.1411637123073301, 0.1330655041120706, 0.08027890516865639, 0.2244909885790079, 0.1020123446059804, 0.07106374077979596, 0.18175835901450726, 0.17214891981453667, 0.17431374639272693, 0.3529213849575289, 0.12812492647959342, 0.20300939288591185, 0.14991505642331418, 0.19828837605253344, 0.14506755847363703, 6.445067553750931, 60.54692583699381, 96.26417375379994, 81.63116778096845, 82.12277412414551, 66.08589695345971, 51.11212722716793, 42.0002338194078, 33.055123513744725, 30.747265623461818, 36.484934206931825, 41.22183945871169, 60.60548682366649, 62.75370228675104, 41.74809994236116, 11.22854849984569, 1.2667616841293152, 0.3246980316696629, 0.3125831785221254, 0.2294450187154355, 0.5383513735667352, 1.424151812830279, 5.814256293158378, 12.813756754321437, 20.23985762749949, 18.5099962834389, 9.764013924906331, 17.890599120047785, 12.10029625123547, 9.906272407500975, 14.008409707776963, 19.371962624211466, 23.892425606327674, 10.81395495322443, 19.869842798479144, 17.88531372624059, 17.79422256254381, 12.08714258286261, 13.660094411142412, 24.507057089959424, 31.574489570433098, 32.08084598664315, 41.72418525142055, 57.25787331981044, 63.718766166317856, 72.24902306833576, 66.00515104109242, 67.36225189701204, 64.11201123268374, 65.07876565379482, 67.95402772964971, 63.30370487705354, 69.67530496658819, 69.48563483453566, 72.22109579270887, 68.63082485814249, 65.07947560279601, 51.18945283274497, 48.56786220304428, 51.17431640625001, 50.66093306387625, 49.60099489458146, 61.9023596855902, 67.64603537897911, 61.025882536365145, 59.99303617785054, 68.28348328990322, 62.4535232974637, 67.90853608039119, 70.81563995730492, 70.5299658929148, 71.29527522671607, 77.84679443605485, 66.36351446951589, 59.07568793142996, 63.40973046518142, 64.69551086425781, 65.10488471677228, 62.926219894040024, 66.59709945801767, 54.797652921369, 41.5000335631832, 38.24580777075983, 17.608898416642223, 19.83859915887156, 13.085017088920841, 15.874695008800877, 13.622931914944804, 8.93878842553785, 9.24678469857862, 11.104737904763992, 12.447183805127299, 7.692571503500785, 5.375900047440683, 3.927914687702733, 2.092572229523813, 0.24408704270758938, 0.5892899079668907, 0.13517783834568917, 0.32493953322691305, 1.0164614538511922, 11.543146121886469, 41.024246138911096, 81.90202313084757, 69.74100466697448, 41.452565039357836, 39.773653322650546, 44.524785011045395, 39.69166009656845, 34.2995503640944, 39.78054884941348, 58.41843205113565, 62.98912294449345, 71.65669810387396, 79.72881040265484, 85.72653801210465, 60.702459581436656, 9.132676086118146, 0.36285383746989314, 0.12490617742221202, 0.08517219219356777, 0.174167255059846, 0.1524608432044906, 0.3022996432358219, 0.31804422096860024, 0.22687433407671992, 0.3108918402464159, 0.14418168504151607, 0.1067467832997922, 0.34107175144937735, 0.3091442098300303, 0.1670235770964815, 0.19528042374839708, 0.1742599976639594, 0.18091033032584578, 0.1256944589136589, 0.16445850022137165, 0.14432868199242702, 0.2017888769267067, 0.15091087879432788, 0.07231568166565511, 0.2020481517238002, 0.15016987258868833, 0.18863390620437362, 0.19821477032476859, 0.16324363799104769, 0.12484789345293276, 0.08988661300991813], [0.05875214093154477, 0.04412602475513855, 0.06566503490771979, 0.023538292791213722, 0.05164053140869064, 0.03542382900993671, 0.03042816199482449, 0.059029752043105906, 0.056427753560485384, 0.046516491040106744, 0.02039201373624946, 0.02259827609504423, 0.03015436791634608, 0.011545191124652424, 0.04257909405315596, 0.056145603377972884, 0.06445882947094018, 0.10380612415892464, 0.034385538554840514, 0.004466821678027872, 0.046738288815944426, 0.11160589514240143, 0.08995920750162295, 0.032794504171057094, 0.04043818473996174, 0.06420425462326215, 0.031362243424800616, 0.469647842429338, 15.406709178801506, 60.67275939449188, 71.0028782198506, 68.61037362006404, 53.20725340997019, 37.0571844808517, 19.64805433827062, 14.434395778563715, 29.20322068275944, 21.61211648295003, 41.407602910072576, 48.62932574364447, 42.620933209696126, 25.538591415651386, 8.421000261460582, 0.43511734854790474, 0.052399621119782816, 0.04437859245245496, 0.16097325981865007, 0.02822905872768212, 0.6852688964816832, 1.6290650108168203, 4.559360636818794, 6.577040110864948, 6.729917430108594, 6.657454092656413, 13.15325358221608, 6.4369575631233955, 11.142114170135992, 9.83776625125639, 10.573888248012913, 11.676941110241799, 3.8805417716503148, 7.715053548735957, 11.926364629499375, 19.161378414400165, 16.406315411290816, 22.36413094305223, 22.9857305172951, 39.20487826870334, 51.18924886949601, 59.384927595815356, 61.62479708271643, 63.35360134801557, 65.67201629761728, 69.66553826485911, 61.69514479175691, 65.04144822397541, 60.3159962930987, 66.59267502446329, 66.80425551629835, 71.06802878841278, 67.06669345978769, 72.79570733347248, 68.7779608080464, 69.35697324814336, 67.37200290926042, 54.81575073734407, 29.60510280824477, 39.44631976466025, 38.90050234333162, 33.90153569559897, 67.58414037765996, 59.989549190767356, 58.91405882373933, 57.481954405384684, 58.78835470445695, 58.84695099246118, 60.00580349276143, 60.95862173265027, 60.63652453884002, 62.056010692350334, 59.10378779134443, 60.63157058531239, 63.106841118105, 63.4144647659794, 62.31679339562694, 64.47148861423616, 63.7971665013221, 63.367890542553326, 61.07954056032243, 62.979062065001465, 48.1848035320159, 41.97365583912019, 30.26986610504889, 25.118578134044526, 16.803780947962117, 18.473073051821803, 13.828562171228471, 9.195939014034888, 5.368486767815006, 5.808190837983163, 2.440552898953038, 5.097774584447184, 2.88137803154607, 1.3792410420794643, 0.6130392464899248, 0.216779685429027, 0.0444281047150012, 0.06477704707292781, 0.06254016609501935, 0.3262455292767094, 5.172972794502012, 18.823028879780924, 52.19718817741641, 55.78195602663102, 47.48285616597822, 30.364575655229633, 30.81325361805578, 21.788493702488562, 10.726681236297855, 17.425982606026437, 30.35247906561821, 47.30830284856981, 53.524463330545736, 59.87540821875296, 65.18119442847468, 39.781160739160356, 3.1431636358461077, 0.15545266169694164, 0.03260087927863483, 0.08658966935810544, 0.028197057319865115, 0.04589445062822873, 0.02587975051644589, 0.05727288643679312, 0.08618454674198743, 0.10083346552545987, 0.008207821970685356, 0.06588409774966779, 0.022830793356162407, 0.06784027262080101, 0.05757239617166981, 0.004476310155775038, 0.012532155604041632, 0.01189699880929003, 0.041789379977290673, 0.03807522867235445, 0.056721628718678994, 0.0032222148870313244, 0.02724888944818128, 0.017052824165852323, 0.037050103438237024, 0.007431799801246774, 0.0332795029446002, 0.08822123745396253, 0.008396353336021064, 0.031516838052700606, 0.038510175091364694, 0.02352195596622844, 0.010490188461488054, 0.08205443650724427, 0.053843493843751575, 0.026875685885428425, 0.004422616010772124, 0.012737777433358135, 0.013639882353374795, 0.04629389653282781, 0.039129798495841604, 0.02007377698206373, 0.01648323779414979, 0.047403318251693444, 0.02224584309113843, 0.0268251221672061, 0.0698247544407364, 0.061835441813473745, 0.05551998150504886, 0.010885712953524725, 0.022521751572287852, 0.04832240159533197, 0.07888706896694438, 0.044126645286357215, 0.054479660916953325, 0.035863410260888844, 0.04092178923348266, 0.6014682544815926, 19.99298364885392, 69.40669321244764, 79.44487002588089, 76.84178121628301, 61.39359297290925, 46.920513799113614, 27.618416432411443, 25.053421681927098, 38.6637363126201, 21.18141866499378, 34.76246456946097, 33.96979670370779, 44.36625065342073, 27.01521473546182, 6.147589606623496, 0.20732726361001694, 0.018766811831043135, 0.1275003120122898, 0.4126962532679881, 0.748885695732409, 2.3400485371389697, 4.632789857925908, 9.05945327974135, 10.01467397136073, 9.516054430315572, 10.703509834504898, 15.747631788253786, 14.433151406626548, 12.450028504094771, 13.504505753517153, 11.367201343659433, 10.135349612082205, 8.037803326883624, 6.045548656294423, 10.264444620378557, 12.623901290278281, 13.462908037247198, 19.15747565607871, 27.719046800367295, 39.58860766503119, 53.944549176000784, 59.29852954802975, 63.140906903051565, 62.49965429306031, 68.82111472468223, 71.8244892551053, 64.65185096186977, 65.41160621950704, 61.91514268998177, 66.73795177090552, 68.47210222674956, 69.42952140685051, 68.62870677824944, 75.03932660625827, 69.8668735258041, 69.21783893339096, 67.99667173816313, 56.31154660255679, 36.7370641616083, 45.43668508529664, 43.06690669828846, 41.52815695731871, 67.74799346923828, 59.42601834574054, 60.940272884984175, 61.621164967936856, 62.55349274604552, 60.96934157033121, 61.603514302161436, 64.5846019252654, 65.97596860701039, 67.58021800748764, 62.87278152281239, 62.7765618601153, 62.37977097111364, 62.522933560033, 63.64561788497433, 68.86280167487361, 67.70128588522634, 66.20221091854957, 65.11646747589111, 64.66896426293158, 52.01018917945124, 41.80278954967376, 31.5690766995953, 26.243992428625784, 18.322210850254184, 15.333359875986654, 8.997856378555298, 7.547641886818794, 3.3928269099804664, 5.303032705860754, 5.395417761418128, 6.577865279489949, 6.315131687348889, 4.216178742147261, 2.709050904358587, 0.6368908117855749, 0.3446677375224329, 0.046653540339320905, 0.05730285579639097, 0.18512471789313903, 4.780615654683882, 18.068535481729818, 48.91199919485277, 45.84769456617294, 36.21303158421671, 31.654417668619466, 24.83536143456736, 19.573443012852824, 19.60843839953023, 31.334793529202862, 45.18817940065938, 56.36613422824491, 63.9027645511012, 69.28842590701196, 74.53593746308358, 48.67666875162433, 4.390873264881873, 0.13472557067871094, 0.05307471695085687, 0.024763311432193846, 0.043606371994340615, 0.04881790343431696, 0.05833024098988503, 0.07132634805936007, 0.11897501746012319, 0.050008859890963764, 0.06224342193754931, 0.04629193151730203, 0.05272749526005599, 0.03774907822991091, 0.020483944287163117, 0.045111187012685884, 0.06273942173368509, 0.05953746149316431, 0.022202917269521186, 0.0419811547673758, 0.012340402838984325, 0.04802153971526892, 0.03710828398564651, 0.0509085075839633, 0.05690512592874228, 0.035119197977286194, 0.082638448314561, 0.16641321952544874, 0.01111778588364682, 0.014905400232472008, 0.14689735948078095, 0.07193951717307491, 0.22419678017256722, 0.11938576316160542, 0.2364776598950548, 0.17380183111996422, 0.0941718943537243, 0.10826592799276115, 0.1354896514526298, 0.2155742307584132, 0.11158640586560774, 0.0752678168036284, 0.2755519897947388, 0.162881845307927, 0.10835616548936214, 0.10772784315650502, 0.23923019848523602, 0.1878183443219431, 0.15679342281674186, 0.08334615267813207, 0.13667364033960527, 0.22438684658658123, 0.1433478902664877, 0.25367639508218537, 0.11120534607119138, 0.10906362470479743, 0.19020218011592666, 1.0132897272706032, 26.807638983572684, 80.57319471913, 89.12018837467318, 86.11218544744676, 69.24118488065659, 53.892632684400006, 31.240517400926162, 24.415183413413263, 39.95219961289437, 32.68522243345938, 56.56549261462305, 64.66381026852515, 56.30689074916225, 33.60380818766932, 10.678851854416633, 0.640868524149541, 0.2297064845239924, 0.21197654397016574, 0.5845514396505972, 0.7294320879924683, 1.8640713682097776, 5.492145861348798, 16.550260513059555, 16.36152586629314, 16.4635016072181, 16.136912318968005, 26.1783907874938, 17.98085678008295, 23.08104411248238, 22.28900774832695, 22.947340319233557, 23.514773922581828, 12.542597420753973, 16.516867414597545, 24.82974656166569, 27.426792960013113, 25.085155617806222, 31.946130221889867, 29.911524249661355, 45.54100052002938, 56.04039707491475, 64.54670790703067, 66.61366754962553, 67.1280393292827, 66.19099293985676, 71.42454085811492, 64.4029648073258, 65.84171372075235, 61.108373903459125, 67.41523527329969, 67.10559552715671, 70.40440297895863, 67.74797777975759, 73.71200438468688, 70.93611947951779, 73.36490600339829, 71.65381123942714, 60.92011190229847, 42.10976208409956, 50.57803377028435, 48.05416899342691, 46.50817071237872, 69.29076363963466, 62.53087635963195, 62.82311647169052, 58.46146045192596, 62.195658837595296, 62.71533366172545, 64.08961057662964, 66.15554255823936, 66.1896122655561, 66.97923244968538, 62.94462365488853, 64.67404373230474, 64.21886836328815, 63.866192371614524, 65.62893690601473, 70.85738966541906, 69.64156473836591, 69.32132674801734, 66.08054684054467, 70.3203308966852, 54.741304151473514, 46.55553725457961, 34.310152530670166, 31.09239301373882, 23.117535883380523, 28.39066836141771, 19.750969486851847, 16.29432389813085, 11.395572827708337, 14.483782341403348, 8.681091646994314, 10.445177631993449, 8.526904256113115, 5.490265084851173, 2.506740689277649, 0.5736940125784566, 0.17176350097983115, 0.23478555553142103, 0.23167605061204205, 0.6167147524895207, 6.880616853314062, 26.069415576996345, 66.58945083618164, 69.38317468089443, 62.833279332806995, 47.85960374339935, 42.158238657059215, 33.06912245288972, 20.63070220331992, 29.961273631741925, 46.28996925969278, 62.940289435848115, 72.8980419712682, 79.66355785246819, 83.83033091022124, 57.761168326101, 5.667838627292264, 0.27835265402832343, 0.14794746684210916, 0.1231985061519569, 0.11019047109350083, 0.16826240255707697, 0.19245555113640525, 0.20133400456078593, 0.25892558357407974, 0.21377064528003817, 0.2031149751236362, 0.13244944684688123, 0.17071550802117394, 0.17067865919201605, 0.14603782415149674, 0.13362963593775226, 0.10317079978243959, 0.20047292173389467, 0.14222368688112305, 0.10956706704511758, 0.11632444517266367, 0.13396464618704013, 0.20928376023807835, 0.15574512342291494, 0.1794002178095041, 0.082319303746185, 0.13281764402504892, 0.1690260543217582, 0.13590813464214727, 0.10605551918307621], [0.014840448425421792, 0.029938539880658352, 0.06335334927444497, 0.02311833871288165, 0.0628324554512097, 0.029985886029598695, 0.03783127180330696, 0.03277241785620009, 0.043488666415214546, 0.051780369267949176, 0.03576519778899608, 0.010877922796944698, 0.02026950861627777, 0.013804376752476298, 0.03144714703422881, 0.0405920037038384, 0.028324679907170996, 0.00894801612312515, 0.049683578958314274, 0.06002701465941726, 0.02423357120865295, 0.07446752305352881, 0.017611708289252657, 0.05732422964947839, 0.042876550672395576, 0.01394593543673475, 0.05683076560437199, 6.660426758950757, 46.32457633172312, 71.11460301183885, 66.0327253034038, 55.26839225522934, 39.046642011211766, 28.525007578634447, 28.110448352752197, 27.43040938531199, 22.722535556362523, 47.43758416944935, 66.45189331423852, 49.4473752667827, 26.066891531790457, 7.233683611116103, 0.2938409293851545, 0.08201209482766929, 0.0287398612577348, 0.171598638858526, 0.2629100681552964, 1.082660337128947, 2.824872611991821, 3.529165065096271, 5.813303157206505, 6.106824413422616, 7.740606809816054, 7.137003069923771, 13.05527767827434, 16.52840506645941, 11.53807940021638, 12.49057992812126, 6.59580865213948, 8.811673233585974, 10.144555414876631, 10.821326067370753, 17.464666981850904, 32.51036317117753, 34.45321706033523, 39.75036228856733, 51.1778583065156, 56.00548798038114, 60.347916541561005, 55.67811127631895, 52.09093116944837, 53.98928380781605, 57.87736462008569, 62.87666466928298, 65.13131364699333, 68.28399319802561, 68.21375923772013, 66.11301622083111, 68.00024893976027, 67.70410214701008, 67.20639259584489, 64.79157755451818, 68.07099280818817, 67.50921526262837, 66.57304748412102, 62.44672975232525, 36.27540903706705, 32.35126791461822, 30.285918404979093, 41.17359822796237, 63.88712998359435, 58.66276825627973, 63.181503434335035, 65.25242074843376, 64.47419897202523, 62.261833144772446, 68.50174750051191, 65.19866858759235, 64.2492941887148, 59.941574681189756, 62.72917178369338, 59.33849850008565, 57.1130358788275, 58.350594659005445, 63.085715232356904, 61.53656336569018, 59.66664398870161, 58.54695635457193, 60.01243622072282, 63.730647025569795, 70.13766611776045, 60.318534066600186, 56.42532671651533, 54.69701274748772, 50.28362066515031, 36.478160273644235, 26.940309232281102, 27.84215627178069, 15.295121669769289, 7.803761872553057, 2.464919888204144, 6.514339552771661, 4.175723416189994, 2.355007231235504, 3.6354483039148393, 1.0809465065117807, 0.10430097099273436, 0.056874965047163356, 0.02736323381653957, 0.09376690197255343, 0.07965738569656688, 2.894744243352644, 17.711540960496475, 45.44328251192647, 56.27602561827629, 35.52324748808338, 60.69772528063867, 50.1473222240325, 32.28584278014399, 22.44126239130574, 17.66014418294353, 30.372198781659527, 38.447621560865834, 57.40773923935429, 61.35718945533999, 58.775814887016054, 19.13445722672247, 0.6765913879198413, 0.04629617564440255, 0.08048828465924149, 0.03734286393850081, 0.012162322828155613, 0.08944069621183219, 0.04589967917831195, 0.029513158069382754, 0.02659901323157453, 0.020424292850939017, 0.07915480903560117, 0.09037394452119067, 0.039356863126158714, 0.030811665609719294, 0.012997572212630223, 0.04359660437330604, 0.01559313172624717, 0.03153932464849805, 0.08418209249934844, 0.022434105368090734, 0.02808213072468437, 0.026319354750035752, 0.05036471156223167, 0.02153089919668292, 0.06706622504298726, 0.062264079498427535, 0.022759089441669565, 0.031112230630711685, 0.044291867468986786, 0.05048050575198666, 0.012833808469886502, 0.041143441452614726, 0.010226352568415385, 0.0558741401220041, 0.031166990595539252, 0.03000198345210764, 0.03828682981791996, 0.015287635014242223, 0.04100941437026186, 0.01848901685838017, 0.05092276448023416, 0.040737575731210174, 0.03339556526512869, 0.037273429559483644, 0.02439766915725364, 0.09512324532073352, 0.04023136781348337, 0.06161198928771962, 0.0369557635408015, 0.055558764706215555, 0.020354988706868984, 0.01967010993300186, 0.0867130631400693, 0.03335757879540324, 0.024259028310376792, 0.08498644651544672, 9.546597926847397, 54.1993934108365, 80.07736006090718, 73.08542928388043, 64.10063243681385, 48.501064239009736, 38.87703088022048, 35.9811959728118, 27.69236291608503, 18.438852333253433, 35.98768357307681, 62.51550459092664, 57.62765476780554, 28.834986609797326, 6.555488647953157, 0.2672361973072252, 0.08017055735352539, 0.036700108509150245, 0.5216379091143608, 1.307364711838384, 3.751694117822955, 5.562600945272754, 6.943717493164924, 9.260238428269664, 7.636144286201847, 7.942931978933274, 13.096185057393967, 19.41530481461556, 10.24732445516894, 12.284599600299714, 8.649329273931443, 11.119372267876903, 8.482474588578748, 8.585718235661908, 9.697595450185961, 15.827356903783738, 25.032837083262784, 36.135043098080544, 40.98658354051652, 51.952216548304406, 59.585246962885705, 62.92808301987187, 60.098477332822746, 58.03253358410251, 56.39011559947845, 61.75256436870944, 63.85475866256222, 67.90309967533236, 70.03748093881916, 70.00266598116967, 67.18005780250796, 69.37338444494432, 68.27622690508443, 68.25346931334465, 66.15358921789354, 68.85087766954976, 69.54061077487084, 68.28251838684082, 62.960470030384684, 41.54451716330744, 38.73340545162078, 35.21838126644012, 45.902203744457616, 63.39283289447908, 59.356725754276404, 65.46300495824507, 62.693599808600645, 63.52828802600984, 62.3909693379556, 70.0561357313587, 65.7782340818836, 66.23838301627868, 61.03332327258203, 64.48691921849405, 58.41532553395918, 58.681497573852546, 58.30768785169048, 65.20529347081339, 62.97287256486955, 61.55346485876269, 61.97472741526943, 63.2126941219453, 64.9728891157335, 72.47819931276383, 62.27512605728642, 57.077397223441835, 54.21945241189773, 49.457365543611594, 37.890750900391616, 29.452712843495032, 25.350949148977957, 13.17259478953577, 8.358302154848653, 5.641586203728953, 4.936807376723136, 5.8258630767945325, 10.609506310955172, 5.644213701448133, 3.139032644610251, 1.418876224948514, 0.6894864862965, 0.11707334974480253, 0.00886951700874394, 0.06390603957697749, 3.0148170648082613, 17.373593468819898, 44.120306276506, 49.69214293264574, 38.56825797788559, 57.12758787216679, 41.9098114198254, 21.98577323267537, 24.56777930259705, 30.260777973359634, 42.49819440226401, 46.31830053944742, 63.16705342262023, 70.159348980073, 68.49294570184523, 25.163977607603996, 0.7448187494470228, 0.06478077792111905, 0.08303575683385135, 0.025954928639675343, 0.03945543948981551, 0.027066604572258172, 0.029063970075860143, 0.04070145468558035, 0.019694289583111965, 0.06120355717176872, 0.023001221106237462, 0.05817715363997606, 0.02436704670770034, 0.0610316853459564, 0.061627628972693804, 0.03256332181814698, 0.03333465744470877, 0.058626943012519236, 0.07167675667592595, 0.05247025442640147, 0.0692522033087669, 0.026922288929082216, 0.04756885453037197, 0.003970610489505494, 0.08071749050530695, 0.05404832277206644, 0.0204924785066396, 0.08324752651876019, 0.05616954362560665, 0.1181185081781399, 0.10356657612588137, 0.2076750215623648, 0.09392567369486056, 0.22762133108992733, 0.12359398372110822, 0.13925091333446965, 0.13053995737385365, 0.15482491393002773, 0.14470374331839625, 0.15408340210635818, 0.11519439653643679, 0.17298896586702717, 0.1308176795681638, 0.11828437387462586, 0.15468513352736352, 0.24082525483062192, 0.10816857353934359, 0.11895833206513237, 0.22334960950238092, 0.07889538868180207, 0.19420540320777124, 0.12094382512112781, 0.20714229934157866, 0.12212216027922208, 0.1345829404289684, 0.2288767806584797, 13.438158862052427, 66.18259906768799, 90.91026398443407, 82.9618553961477, 72.91102501653856, 55.58026775237053, 43.997285058421475, 39.545724391937256, 37.387859898228804, 32.78895147385136, 63.735385248737956, 81.4118915988553, 64.54920645683043, 35.52234534294375, 9.50277622668974, 0.4088226982182072, 0.31431882732337524, 0.10243278131970476, 0.4697609170069618, 0.6910604599022097, 3.844803586121529, 8.053634993491634, 13.239695756666123, 18.66922293939898, 15.32444727036261, 19.560420743880734, 14.405435938988964, 26.738507209285615, 27.308478586135376, 21.211985695746638, 24.27707479846093, 14.943600816111411, 17.885192132765248, 17.71867379065483, 18.55959661545292, 25.23951069001229, 39.85843927629533, 44.21357239446333, 44.96211751814812, 56.19280861270044, 62.791329583814075, 67.16703553353587, 62.64873181619952, 63.40794578675301, 59.72670724315029, 62.4057331392842, 61.30820689662811, 65.76379191490912, 69.42508128381544, 71.62395415767547, 68.40186042170372, 72.1851041240077, 70.30833628869826, 70.4554565491215, 68.53431886242282, 71.43361722269367, 71.44004206503593, 69.88173146401682, 68.17051902894052, 46.04205585295155, 42.437503568587765, 40.27892912587812, 50.146137668240456, 63.066742727833415, 61.549656237325365, 64.33151883463707, 64.00515802444951, 65.32109752778085, 63.646068957544145, 70.73352906011766, 65.95259912552373, 67.1960767622917, 64.02472672923919, 65.63408697805097, 58.78371846291327, 59.01984906965687, 58.68281549023044, 66.69464880420317, 66.47308195790937, 65.66509331426313, 65.06726526444959, 65.45392074892598, 69.79637284432688, 75.52639868951614, 63.700582058199, 58.34011408590502, 56.76983633349019, 53.65496058617869, 44.90027350764121, 33.653955690322384, 31.868898753196966, 20.58922706111785, 12.099201909957394, 9.453661287984541, 14.397190136294212, 13.587221676303496, 11.46514488804725, 11.691512715431953, 3.8494135968146788, 0.8570993535460965, 0.48433028522037697, 0.19817681832899972, 0.18103811379161575, 0.24597894280187546, 4.507693215723961, 23.891356760455718, 61.31465135082122, 73.5548585461032, 48.97551413505308, 77.06218704100579, 65.70008870094054, 46.63885624177995, 34.07597134190221, 28.552022903196274, 43.861363164840206, 52.83631878514444, 75.27243306559902, 79.884214708882, 80.67072837583481, 33.209445245804325, 1.31715580580696, 0.2394131556033127, 0.2064148222486819, 0.1723198646739606, 0.14513790066684448, 0.24674213491380217, 0.1359535483342986, 0.08760822155783254, 0.1416665877425863, 0.1480548417255763, 0.18675550457931336, 0.24533729820001512, 0.08521392866368256, 0.16753411341098048, 0.1077838595055284, 0.23822587253826283, 0.12639424958897214, 0.251410031210511, 0.15318744695715367, 0.1513166142807853, 0.2128199608095231, 0.08204373425894207, 0.18215747550129893, 0.07133298238078434, 0.121685451857986, 0.2300866939608128, 0.1330495694832456, 0.2103916612724143, 0.13503361463306413], [0.050571497845193075, 0.06041197001092857, 0.05194144308446877, 0.042474936738970785, 0.04234274060675695, 0.040216992173584244, 0.02494580315185651, 0.045058633381080244, 0.02581187704157445, 0.03050773363229969, 0.016465684804584713, 0.023996168221797676, 0.0642688013613224, 0.006682091794397322, 0.022002483770671873, 0.04360049993040101, 0.024219128536060456, 0.07283990031048175, 0.05256299320007524, 0.08098418869438671, 0.025022789242587266, 0.04679864505305887, 0.027983037251678687, 0.016878548739177567, 0.01849639045465137, 0.04279960097084123, 1.2742590495655615, 28.940372851587114, 64.19753459192091, 67.96891704682382, 65.98163250953921, 53.22925790663689, 37.12829312970562, 23.505785811331965, 14.200554855408209, 31.136688340094786, 44.02068199649934, 47.896921173218765, 43.780228937825854, 25.4356703835149, 10.488462948030042, 0.6800864648915107, 0.012113865851725062, 0.06388504876785221, 0.0443138120575778, 0.2579311708048467, 0.9501211200990985, 1.9385137865620277, 5.057430555743556, 3.919990274213976, 6.635530985170796, 7.767981031248647, 6.026120666534671, 13.134040832519533, 14.444764564114234, 14.112984999533623, 17.477932437773674, 19.45270069183842, 22.170701219189553, 17.273259239812052, 20.29012280125772, 25.95727893614, 33.30488435683712, 44.00640064670194, 53.38461122205181, 48.77693237796907, 54.5610555525749, 54.44894636830976, 54.04169844042871, 52.23102646489298, 59.56487809458087, 65.45411294506442, 67.40195412789622, 66.4475316386069, 67.53047450896233, 64.04260881485479, 62.165782143992764, 63.39396645945888, 60.44046878814698, 64.7459956907457, 63.32650561486522, 64.72319103056385, 62.561117833660504, 67.06123352050781, 65.84351016629127, 66.70538040899461, 49.476318436284224, 30.434319319263583, 27.37266032926498, 53.66052250708304, 62.98409838830272, 57.92721794497583, 60.84170372255387, 59.21421820117582, 61.39655828475953, 63.62648848564395, 61.74903031318419, 61.837601354045255, 64.27177329217234, 67.90218968545237, 61.8194878485895, 60.59316273658507, 57.14243012089884, 57.95727506760628, 62.61081034137357, 61.0294597379623, 57.03074455261231, 55.30250510861797, 55.894037754304954, 61.31092509915752, 61.11730906271166, 66.99248221612746, 60.8046922376079, 61.21665877680625, 56.55238405350716, 54.042730023784024, 56.9935251820472, 51.34289987625615, 33.84161756884667, 24.67850781256153, 17.948257961580833, 5.353986255584225, 5.1269236783827505, 5.639408307690775, 3.696877523776024, 1.1621834505950253, 3.2557560070868465, 0.44572659377609536, 0.04101294220515317, 0.04401950405970697, 0.04202482177905979, 0.022687835603832238, 2.5655218189762485, 15.332600897358311, 36.840783396074855, 45.12865351092431, 33.96232066615936, 40.5668193294156, 70.12363972202425, 45.23336510504446, 21.27721078934208, 20.770891635648667, 37.903180891467684, 57.827071989736254, 59.31599586240707, 60.32368413863644, 40.114456299812566, 6.637341159005319, 0.1607876673581139, 0.10964160740015008, 0.13652659742341888, 0.03439755081349323, 0.04855839498040657, 0.021291226674351963, 0.013465874099863634, 0.08491988879658523, 0.06778846975536117, 0.03615356223177045, 0.05358797287748707, 0.04589391053624211, 0.016071773885238557, 0.04060400447117225, 0.06405791267752647, 0.015494275740498017, 0.02786526272463943, 0.012039697049335848, 0.015419643454914613, 0.020422440833382068, 0.07188681798476367, 0.02106024733474178, 0.021497530321921074, 0.09291281352841085, 0.032548126464168874, 0.03608834899721607, 0.038419363028820486, 0.020138582274798426, 0.039633807741225734, 0.028618553150144797, 0.05630682658163771, 0.08009903538491457, 0.03221815324298317, 0.06907584986859752, 0.03137596022908486, 0.00832180340488952, 0.03763618751338894, 0.03836222819142765, 0.02034457374153839, 0.028225352777348413, 0.017034545307978988, 0.04476727099127827, 0.03842772104807439, 0.017646182245845278, 0.028006211411388173, 0.05913081819251661, 0.028163382009933555, 0.05941314074481207, 0.05657344816192504, 0.04163246601819993, 0.042054641751512405, 0.08611739913542425, 0.060927489727375016, 0.04147203954597635, 1.9474906209976444, 35.35364027946226, 73.9528928264495, 77.00605792383995, 73.1684737051687, 63.2154554705466, 46.227281939598825, 31.505977530633253, 19.15969571759624, 31.59402885744649, 38.55922868174892, 47.82653424047655, 47.15464399706933, 27.75554641600578, 8.392650350447624, 0.6902667928126551, 0.1176576526655305, 0.17456263303756717, 0.3277474906175368, 0.7268288599387293, 4.6205927575788195, 4.338194852875126, 10.658999758381999, 9.323873981352776, 9.63085239933383, 11.2328189803708, 11.092707014852955, 14.259307057626787, 8.913050813059654, 11.931144037554342, 11.334008286076209, 11.885183665060229, 17.55978249734448, 14.367737058670292, 16.308010028254603, 21.96822258733934, 31.894078408518148, 43.414856233904445, 52.99635933291528, 55.41594397637152, 59.28754691154727, 61.138862486808534, 59.58038322387203, 57.974313843634825, 60.14814238394461, 64.33502935594129, 67.10572104300222, 66.75444141510995, 69.43701313387963, 66.96810076313635, 63.88747122979934, 64.9341517879117, 61.34273944362518, 67.02938387470861, 65.15068231090423, 66.6269330055483, 65.47211662415536, 65.73239334167974, 66.4767768306117, 66.93871436580535, 52.392734019987046, 36.6944593767966, 32.955499233738074, 55.36276055920509, 63.067154576701505, 57.997561731646144, 59.81049299240113, 60.00136336972637, 62.958826557282485, 65.39260233602216, 64.41992513595089, 64.95600723451184, 67.25575954683366, 68.40109163714995, 62.273639478991115, 60.8038136266893, 56.65063550395351, 58.31856458417831, 62.92068935209706, 64.65226281073787, 61.19186547494704, 57.16889435245145, 60.30169533145044, 64.24068458618657, 64.79248362202799, 68.51874705283873, 62.003968684904045, 61.35991550260975, 59.30487202059839, 58.21373139658282, 62.30699139256632, 50.33029687020087, 37.98707646708335, 24.419533321934363, 13.608883946172654, 4.904804758487209, 5.946779943281605, 8.007917807948205, 8.459231603530146, 5.314251174849849, 6.2065271408327165, 1.5910793071792972, 0.7402777479540917, 0.11149570871625217, 0.0687370857884807, 0.017972133505428513, 2.085446753809529, 16.321322552619442, 37.798959593619074, 50.14546302057082, 37.813633180433705, 42.24402481509794, 59.57628826941214, 39.6215477297383, 23.62321569073585, 29.156526827043105, 47.51430180764968, 66.88432678099602, 65.4890847975208, 72.36156371331984, 48.05658125108289, 8.384808551880623, 0.0668515365630869, 0.08602235826753801, 0.022469075366614327, 0.07017723149469784, 0.016086701108443163, 0.07472975495001001, 0.025822056434868325, 0.018081843041844906, 0.07641661927224168, 0.05065020954897327, 0.04024965050179632, 0.04567380581471709, 0.018648573820809686, 0.041892886116740205, 0.017005232868776206, 0.015093579197362548, 0.05277451390640871, 0.03549959510564804, 0.05279708668709763, 0.06010226747621933, 0.011986860922808129, 0.036198692471389814, 0.019837218607144973, 0.028494127064702973, 0.0041719841218793826, 0.023216489897740465, 0.06449088258969207, 0.059030747957407474, 0.09891145051487031, 0.17012788793973385, 0.2735626433164843, 0.23870230261837286, 0.13139855807587025, 0.1790214792614983, 0.14467694556280492, 0.1423885796459452, 0.15501818259156522, 0.15046818722640315, 0.1442885543069532, 0.1301116069718715, 0.10832787386231846, 0.14392950421860143, 0.10442711503034639, 0.13903081627382388, 0.15809044031606567, 0.1538249393624644, 0.11615563769854846, 0.3105463652360824, 0.13004869583152956, 0.1799812188912784, 0.17723889991400704, 0.16525854116245625, 0.14662179765441727, 0.1069955014052891, 3.5782464185068688, 48.26770674797797, 86.13812800376647, 84.45690601102768, 85.67359385951873, 71.0564499516641, 53.73751471119543, 35.4977128582616, 23.148654007142593, 43.52800876863542, 58.85018302548317, 59.7244518803012, 57.16927482235817, 33.22950816923572, 13.465967485981604, 1.0616675668185758, 0.20510488850695474, 0.25645603786312765, 0.4111377239948319, 0.43092994259730466, 3.5834894016865766, 7.980704893988948, 13.955126270171135, 16.502527229247555, 15.965021310314057, 17.926455466978013, 14.554460510130852, 23.56229735958961, 23.310932267096735, 23.362968390987767, 23.71154158346115, 25.23169928981412, 30.650665490858017, 23.941543486810502, 28.542615098337976, 31.068174339109856, 39.340592276665475, 53.04085077777986, 61.796487069899044, 61.26336636081819, 65.73228743768507, 65.44972773521178, 62.413770075767275, 59.695261601478826, 63.08484838854883, 65.02700213463076, 68.16080724039386, 68.14735351070281, 71.48016791189872, 69.17313960290724, 67.6298281454271, 67.76008221410936, 64.73336958116101, 68.36262103049987, 68.32777469388901, 69.40031543854745, 69.10019136244252, 70.61202187691966, 69.02863164101878, 69.58379607046805, 55.76812967177361, 40.295697258364775, 38.323784489785474, 58.45322739693427, 64.40601641131987, 58.96013098378336, 60.32285259615991, 60.68510309342415, 63.687963793354655, 67.74156862689604, 66.95189352958434, 68.00661102417978, 70.20422089484431, 72.54076111701228, 63.93687740448983, 61.47855151084162, 57.54940348286783, 59.93306313791583, 65.7829919169026, 66.66841599249071, 62.192097325478834, 61.338797461602, 61.47830440152077, 67.36863751565257, 66.72795757170647, 70.94000262598838, 60.87887602467691, 63.042157311593336, 59.05346770440379, 59.039472687628965, 62.43325641078334, 58.65164833684122, 40.198928463843565, 31.31436778653053, 26.56570326897406, 12.018562882177292, 16.562566949475197, 13.7671241260344, 12.93430393741977, 8.461572277930475, 7.997177377823861, 0.912320135581878, 0.3915506637384815, 0.21386013967135262, 0.29785572040465574, 0.13545629598440664, 3.9453709510064896, 21.784459544766335, 50.711735602348085, 59.630138489507864, 48.02703403657483, 54.4511232837554, 88.16229851015153, 62.67146587371827, 31.348259026004424, 31.223447245936242, 52.96130118831512, 75.7992152244814, 75.85792526122063, 80.39424050238826, 60.4934560868048, 11.372985859071056, 0.2629358393530692, 0.23107079518658502, 0.22257527847203518, 0.13716614294436671, 0.11607145229654929, 0.21685661597838327, 0.1691817387097305, 0.16271183507577067, 0.19201829879274293, 0.18140994222654452, 0.17982847628093537, 0.13294723545832018, 0.09418892448828106, 0.13174925780584737, 0.06791073738807632, 0.08680933740951362, 0.1901222771454242, 0.17070361833658912, 0.0796395818132066, 0.2935713277228417, 0.14525990782966539, 0.16766565070757944, 0.09393017063097608, 0.17754360372501035, 0.14748548518025106, 0.152766021990007, 0.15913988884177901, 0.14324094439225812], [0.03811181320117847, 0.019520431674355944, 0.020703809606211803, 0.041136787978992354, 0.06310037938096831, 0.01984187833694441, 0.053328793841384114, 0.03298854275095848, 0.01700985429417943, 0.020675627146697333, 0.08574221523538714, 0.01216921283142461, 0.024624551841688734, 0.051107456787459316, 0.09219484358665445, 0.0375644663619178, 0.04829106476878928, 0.03945337488285957, 0.05611832298698926, 0.0170416526886965, 0.04170694125575885, 0.061918907092824105, 0.013601826935736163, 0.02482177734735512, 0.029389607239394423, 0.0760941881866705, 13.050666932136783, 55.77481339054724, 73.11832228014546, 65.18363022035169, 61.69410928603142, 43.389647160806966, 24.717117663352724, 28.9703123031124, 27.686459748975693, 31.97010570956815, 25.162559670786706, 37.23775863647461, 34.098477901950965, 13.261674757926697, 1.181827661010527, 0.03576719344803884, 0.09366762463844593, 0.05425490604172792, 0.6630173517811684, 1.4286526100289438, 3.848514638600811, 5.496957138661416, 6.626556111920265, 4.899510049050854, 4.141230583190918, 5.6691075140430085, 8.336053490638733, 19.44553844390377, 18.221982525240993, 14.411006685226196, 23.72212217700097, 15.780651280956885, 31.522167113519487, 27.535113134691795, 31.136252957005656, 33.98515670530258, 44.841002571967344, 49.550890538000296, 53.385329015793346, 52.43759416764783, 57.69112263956378, 59.75382651052168, 67.20639259584489, 61.66951994742117, 64.8527116160239, 60.79623168514621, 60.80928533307968, 63.29059239356749, 63.71594598216396, 59.78731178468274, 62.50132914512389, 57.51297250870736, 58.45663985898418, 57.83531288946829, 60.65983910714427, 60.138469819099676, 65.4379370904738, 60.67239069169568, 66.13975894066596, 62.032299964658684, 64.01987083496587, 28.625810530877885, 29.782321376185266, 61.23176382433984, 57.99423163936984, 57.23080504325129, 59.90748143965199, 61.86890971276068, 64.31721002824845, 61.74620620666012, 61.83201197654971, 61.624695101091945, 60.80391560831378, 61.75705940492692, 65.2100081597605, 61.66529555474559, 60.007062573586744, 57.30043103618007, 61.43001217995921, 60.66324764682401, 56.58862283152919, 51.19743485604563, 52.51199760744649, 58.29666599150627, 63.2959464288527, 64.58005197586553, 61.608099552892874, 61.62021575435516, 66.2930843907018, 68.4533219183645, 73.24091203751104, 63.655749367129424, 59.15533558014901, 46.0927289532077, 30.571329670567668, 12.500075005715894, 4.204875942199461, 9.706555124252073, 3.9785198819252754, 3.6305909387526976, 4.818759233720841, 3.420242071151734, 1.146781528669019, 0.020197436979581273, 0.033423102295566956, 0.22108981866509686, 0.03737022093827686, 2.823045768084065, 15.401164908562938, 36.96954304172147, 60.04277183163551, 68.1871263442501, 72.94420042345601, 72.90142305435674, 45.87659066723239, 19.53304063889288, 21.14374037711851, 33.6498019003099, 48.87322264332926, 55.51517601936094, 61.51263298526887, 20.02444694119115, 0.2764139306401053, 0.024367111825173902, 0.05290767530940714, 0.024095489605960828, 0.05082287427578723, 0.017728825895896843, 0.03663546984053908, 0.06691064790732439, 0.017192719481705178, 0.03237260039895773, 0.04133045883669008, 0.12712764854152359, 0.04032687599500341, 0.01741077108759313, 0.050506901311417746, 0.02361945597635162, 0.03834387272476189, 0.03055621550658778, 0.0384745060376102, 0.049142253570138454, 0.04033104734375112, 0.026235964164258014, 0.06157049030486134, 0.028710037454842564, 0.06197576230812458, 0.02410718585334478, 0.05744504554557705, 0.0533637082985332, 0.051217493826463345, 0.0711327423191359, 0.02749816488264309, 0.036261871742505225, 0.047223678294328914, 0.06566557116926679, 0.10686830782722082, 0.0297872988026469, 0.11112466169100617, 0.053894794921601014, 0.029879683260655696, 0.014515425089836843, 0.061904994936119166, 0.043074557587744734, 0.06808326038862429, 0.05863233244106655, 0.05979716146905577, 0.14596702230553474, 0.043362369160017664, 0.03650973949040617, 0.0340126644098951, 0.033528948833625165, 0.04603397439143831, 0.04419615244372718, 0.06965253787535815, 0.0850520006591274, 15.978064171729551, 63.75914696724185, 82.0752820660991, 73.6230371844384, 71.79400459412606, 50.247452489791385, 34.999210988321614, 36.66280192713584, 32.692686703897294, 29.49942631106223, 28.86933284421121, 40.43326262504824, 34.24197389233497, 11.212928641226984, 1.0801073644430408, 0.056301892975405346, 0.15308528147157163, 0.5756444111466408, 1.3454552163039486, 3.904629292026643, 6.852957279451433, 7.7126618835233876, 10.523460295892532, 8.82367176394309, 12.670758904949313, 12.443108462518262, 9.117809322572525, 10.414908701373685, 11.020508927683677, 14.231026768684389, 17.584650324236964, 18.44678532692694, 23.913980991609638, 24.58200573921204, 32.12156607258704, 37.442145501413655, 46.094548932967655, 55.46007064081008, 59.66083103610624, 59.161007327418176, 62.26193512639692, 63.33259705574282, 65.93088488424978, 63.16236619026431, 63.962302207946784, 62.06234139780845, 62.01362163789811, 64.32203846593058, 64.03729792564147, 64.15114471989294, 65.8629180539039, 61.07930914048226, 61.145601118764574, 60.699129489160356, 61.99021293270973, 62.46195247096401, 66.02978352577456, 63.61603144676455, 66.14016686716388, 64.73365983655377, 63.964455589171386, 34.0039134794666, 34.2255352389428, 61.56119977274249, 58.12467005945022, 58.871708992988836, 59.97715842339301, 60.20788400403915, 63.5370074549029, 63.33670377731324, 62.96907178817257, 62.71141913629348, 63.033222152340805, 64.1454533607729, 66.26185447938981, 62.45740252156412, 59.342887632308475, 57.77705392529888, 62.758244391410585, 63.24017032500237, 60.08312909833847, 53.371192793692316, 54.30746255382415, 62.23007763585737, 65.34341581406133, 65.6456462029488, 61.937115807687086, 63.136541305049775, 64.66477909395772, 70.50911457307878, 74.15539695370582, 67.41962832789268, 62.263264809885335, 48.48019330732284, 32.17795602736935, 12.838314713970309, 4.710366004897702, 11.606137425668779, 6.743310363061967, 7.926375164139656, 6.591332737476596, 5.978045155925136, 3.089169023498412, 0.5507260224511547, 0.046987654265737346, 0.04711495892655465, 0.014726584777235987, 2.642541724827982, 16.90956727150948, 32.85665158302554, 58.181352230810354, 67.1359468275501, 71.67524307004868, 73.07106556430941, 46.120334594480454, 25.840635491955666, 31.28182976476608, 43.07364925261467, 55.625453456755615, 63.435978966374556, 69.57465694796655, 25.9118127822876, 0.40918202409821175, 0.06347185924589153, 0.032959416088077335, 0.06825308675967878, 0.041484840875191074, 0.016089328790023442, 0.02474179202240081, 0.09813639936187575, 0.06677990734216667, 0.02448832034133375, 0.02022132551628015, 0.03631499227917483, 0.07360467056353247, 0.0202226948984448, 0.059778637463046666, 0.06642414377101007, 0.08555903595181243, 0.059895519497654134, 0.050153439834473595, 0.048808618448674686, 0.009533982412258704, 0.06212689613382663, 0.04295916559414999, 0.030641465770801714, 0.028700285155566472, 0.06458634480593667, 0.05057389186995645, 0.024357646808869416, 0.11117392114453739, 0.14370399857721022, 0.08555457732009311, 0.14658376904985598, 0.26698449145882364, 0.15079985733234114, 0.27313433887977756, 0.14373370746691383, 0.213234736133487, 0.17893650478893713, 0.16591336247661423, 0.0893907626009276, 0.17782088158832443, 0.12874107567533372, 0.17887851193306908, 0.17192781151783082, 0.21286920494129583, 0.21665349542613954, 0.1657638987225871, 0.13036273059345063, 0.23823287458189074, 0.2457354187725052, 0.13832943213562812, 0.10669429861609975, 0.1838214337945946, 0.290734688000333, 21.391898931995517, 75.91847881194084, 90.3937662801435, 81.476485190853, 77.85078740889027, 58.696441804209066, 37.885334107183645, 38.36091364583662, 38.93809041669292, 45.10743348829208, 37.443463417791556, 50.15874024360411, 42.6562306188768, 16.75060537553603, 1.8639213375506865, 0.12788455107159194, 0.24329702219655439, 0.6649401098970444, 1.347273234878817, 4.837310573747081, 11.408469580834913, 16.80807202093063, 16.1658731391353, 11.439704395109608, 13.205904537631621, 16.364152873716048, 15.309637381184487, 28.692008372276064, 26.571363249132713, 21.9994132749496, 29.64565423227126, 23.27207530698469, 39.97961698039886, 35.6433504627597, 42.570338556843424, 45.49177477436681, 55.36052480820687, 58.93755774344168, 64.16258235131541, 61.65606621773013, 64.69023527637606, 63.592830627195305, 65.9509595747917, 64.40725980266448, 64.91837209270847, 61.12994301703669, 64.59958930169383, 66.81568530298048, 68.59060487439557, 67.12974948267784, 69.50778838126891, 63.33753924215994, 63.85655510810114, 62.67232095041583, 65.1485171625691, 65.18603463326731, 68.6971599824967, 64.54046349371633, 70.14889194119361, 66.55902893312516, 67.61941817498976, 39.244074513835294, 39.97908353805542, 63.95085280941379, 59.585031232526234, 60.74189116877895, 62.80266131124189, 60.87352983413204, 66.83008040151289, 66.24080704104516, 66.49606704711914, 65.20079843459591, 65.37768948462703, 66.41674103275423, 70.41715068201866, 65.67982965900053, 64.65523988969865, 57.36829196253131, 64.41120570705783, 65.59267067140149, 62.25389426754367, 55.84665944499355, 57.54601455503895, 63.99496770674183, 69.56636505742227, 66.9872340848369, 61.741773928365404, 62.99659898204189, 66.20016344131963, 69.7085980446108, 78.13286858220255, 68.49939407840853, 64.85495521176246, 50.77840805053712, 38.28822428180326, 19.061214808494814, 10.84825509978879, 19.4953643122027, 12.870435003311405, 13.440979046206321, 10.225940673582016, 9.239320428140703, 2.514159852458585, 0.4010829425627186, 0.13936388065978406, 0.3452208223602464, 0.08444832337479438, 4.0262222770721685, 21.95859512975139, 48.350790392967966, 68.65172324642059, 72.88059526874174, 75.94577066359982, 83.4521673571679, 59.575739137588016, 30.525759573905702, 32.14450997691001, 49.102159623176824, 67.1663922648276, 74.13618518460181, 80.21606291494062, 35.341649593845496, 0.7259056320594204, 0.13141898197993157, 0.09933973962981855, 0.23829639859257207, 0.21981582976877692, 0.13456463092757812, 0.1142364112480033, 0.16060711575611947, 0.174916289866932, 0.09702575573277089, 0.1747527607386151, 0.17699764350489264, 0.23162772578577842, 0.1223018691844998, 0.18269727637450542, 0.18643793049118212, 0.18535181699741274, 0.1288958714013138, 0.17127622309471333, 0.12157128177463047, 0.1618025346749252, 0.1781852789703877, 0.2248988997551703, 0.13489187304531375, 0.3280848757393899, 0.13801043312395775, 0.13628275163712042, 0.09446336016539605], [0.03997539868578315, 0.12484044707830876, 0.033774142934670376, 0.0371452592193119, 0.02869395152365248, 0.02687272687082089, 0.11254820627190414, 0.036378998925248464, 0.02470413114004318, 0.07363389681784377, 0.07958879018382681, 0.030638851495760105, 0.01928430039345497, 0.047481765655139764, 0.04958567292159123, 0.055080120632004355, 0.0117008036918818, 0.03099906029209735, 0.05519124551586086, 0.02908207081829108, 0.04496545410685001, 0.005557380396977909, 0.02274596252508702, 0.022377997088516434, 0.10646215099240504, 1.6572414795237205, 25.897374537683305, 69.58202315915015, 71.0972112224948, 64.24541888698455, 54.59640787493799, 43.03815964729556, 27.428228547496182, 19.029418114692934, 25.512701811329013, 41.02696434144051, 54.32874141200897, 41.123780204403786, 12.372770559403206, 1.0765782118804994, 0.019568829278972362, 0.06314469373694832, 0.024011658519626628, 0.3432796781341876, 0.2471429674375442, 2.3149598317761577, 8.490256571000623, 3.5787624553326642, 13.477183503489341, 10.960396643607847, 15.376556938694371, 14.974608132916114, 16.85616224042831, 10.734704444485327, 15.041368834434019, 27.517644859129383, 28.102427105749808, 37.64243348952263, 41.19701085552093, 44.935778802441014, 47.48144411271619, 52.68327182339084, 52.62238879357615, 54.42758121798116, 59.79043791371008, 62.61969450981387, 63.84947915231029, 63.99839978064261, 59.47465181350709, 55.84293319332985, 60.08569432843117, 58.812700856116514, 61.20324034844676, 62.995445805211226, 60.953287309215916, 59.381899526042325, 57.0754478054662, 56.139938985147786, 56.006801974388864, 56.111360596072295, 59.39652212204472, 59.05251849082209, 61.08320797643354, 59.048937366854766, 62.83195749405892, 61.7307520681812, 66.08938786291307, 36.01370457679995, 34.23881246197608, 62.35575822091872, 56.92962584957, 60.184769476613695, 57.961526916873076, 59.844092015297186, 60.74712753295899, 62.16515848713537, 57.87497589665075, 56.29979125915035, 54.53798024885116, 59.48484605358493, 58.81402661723476, 60.574723674405014, 62.05801502350838, 60.43092566151773, 58.75636777570171, 62.971664474856475, 61.5399601382594, 48.88758636290028, 47.81828941837434, 57.5596094900562, 61.03354684768185, 66.15132993267429, 59.51249484092959, 59.67007998497256, 62.40796104554207, 66.93884772639122, 65.59792272506222, 64.613819660679, 62.98823648883451, 61.78319023501489, 47.36769537771902, 24.485664483039614, 11.160148247595757, 9.41243129391824, 8.606551904832164, 3.8187151666610473, 6.586847997480824, 4.128095055780103, 2.609898534513289, 0.6469548782033305, 0.1690892106102359, 0.0666255099819072, 0.02686115128228501, 0.16862802567981905, 2.330580180691135, 16.678269024818174, 34.242675996595814, 60.47289502236151, 85.40110680364793, 75.73011875152588, 54.56740194751371, 28.418946689175023, 18.17334709628936, 30.563885011980613, 42.383053225855676, 56.11094482483403, 52.9269451479758, 39.67204040096652, 6.504836140140411, 0.08346756995325127, 0.034545026569356846, 0.015821865470629307, 0.02534076552687874, 0.036542007113776864, 0.04128509494025381, 0.06191918288447684, 0.05934662899122604, 0.027352317063618573, 0.04224978349802475, 0.012019989437483733, 0.05089551856320712, 0.02458244573415047, 0.05666946579191474, 0.0063488406745055995, 0.03219166192256155, 0.035068218656364954, 0.09250445036037315, 0.049519226285478765, 0.021583238323669762, 0.09818917515897944, 0.009492686442700366, 0.03069112167483376, 0.07467460428034106, 0.04673733886691832, 0.022298143913729057, 0.02092395837779247, 0.04581452850552817, 0.09391633508306357, 0.05131401707448306, 0.041790437178626176, 0.021583276628065976, 0.024605786517983484, 0.01348277208425345, 0.04743883408786309, 0.03236905341186831, 0.024989332267714125, 0.029758853958018368, 0.030846520695054246, 0.05207768799136243, 0.045134188802612406, 0.07496083005061073, 0.040252592279425556, 0.01391035735592126, 0.05840247158982581, 0.021219721942719434, 0.039518530660819624, 0.029737102806628234, 0.030788610193638072, 0.0557038119633592, 0.03541237599546871, 0.04597601983996649, 2.433077596849011, 31.728032712013494, 80.31969193489321, 80.8393902932444, 70.71394074347712, 62.04826008888983, 51.13275497190414, 34.22120494227256, 25.21338966584975, 27.926293073161958, 39.323404450570386, 42.65157084311209, 37.757084369659424, 11.1449961316201, 1.0908560070299333, 0.0218514533668396, 0.0413377290110915, 0.1647421059709403, 1.6093685838483995, 2.520294684556223, 5.904261450613699, 11.68574094772339, 8.990672557584702, 14.731729088291047, 10.50262172375956, 11.451103783422901, 10.398506329905603, 11.283655839581645, 12.77118040669349, 15.979688032980889, 27.466542259339366, 32.39340985974958, 39.67036554890294, 44.41140497884443, 47.94384056522001, 51.623125768476925, 56.95069682213568, 57.5466735132279, 58.697081150547156, 59.36845364109163, 63.313448044561575, 62.334844143159934, 61.244083989051084, 59.67907005740751, 56.34535743344215, 60.01335013297297, 59.525897579808394, 63.64068746566773, 65.27084019876295, 63.32612122258833, 61.3807785895563, 60.38758739348381, 58.76093341458229, 58.89165032294489, 57.89609001528833, 61.52793022894091, 61.394726537889056, 63.41849696251654, 61.516210186866026, 64.17332180084722, 63.33965339968282, 64.59407444923156, 39.20446641983525, 38.25087547302246, 61.48450174639302, 58.13691177675801, 61.59855250389346, 59.74633086112238, 59.44378276025096, 61.93302085322719, 65.00831988550001, 59.530992738662235, 57.635326923862586, 56.11461616331532, 61.84155118080878, 60.72396201472129, 62.652293328315984, 63.35214222631147, 62.756126311517534, 58.98123725768059, 66.15812347781274, 64.66437508982997, 51.19774472328925, 51.58453749072168, 60.689907996885246, 64.23048250136837, 67.75731302076771, 59.16415699066655, 58.739391757595925, 61.441885194470814, 68.4927103596349, 68.45132150957662, 67.85010060956402, 66.35333199654856, 63.89641423379222, 50.337839588042236, 31.477942389826623, 15.329062919462881, 9.171860564139582, 6.522904048042913, 9.086187174243312, 10.189000771891687, 7.170537864008258, 8.296622883888984, 2.405193712442152, 0.7243538443599978, 0.07088849050623756, 0.033807211119921944, 0.20179618540550434, 1.9638133193216019, 16.49639460348314, 39.395772180249615, 66.95479608351185, 91.62684179121449, 80.49561808186193, 54.40131310493716, 31.060021692706695, 20.35028607614579, 40.28178461136357, 53.65693353837537, 64.13401572935044, 61.64925306074081, 47.92547602807322, 7.511099615404683, 0.08037259006091664, 0.05751402410227926, 0.06348253468111639, 0.03773861729930486, 0.04866686153916582, 0.049727027634939844, 0.037062379997223616, 0.036757358259731726, 0.0317781544741123, 0.046880988013600154, 0.02807252015167427, 0.031804044415513356, 0.03532550545529493, 0.01997142763537986, 0.0712807888105031, 0.05037591559812427, 0.03231298343669022, 0.012579877136064874, 0.16126947537545236, 0.03442216138806074, 0.10829636466599281, 0.009741786634549499, 0.021880888380110267, 0.05394233450774224, 0.05479363056140081, 0.010979171849847322, 0.043101585169713345, 0.1051888975404924, 0.22375395070881615, 0.1697430666536093, 0.11123621175366064, 0.10390933918496294, 0.12465133061332088, 0.23624921247603434, 0.112070573433753, 0.13498150533245457, 0.275087617938557, 0.22289749505298756, 0.17323907825254625, 0.09468347254780032, 0.11364341322933474, 0.13288852247980334, 0.17442602423890946, 0.09409220588784065, 0.1454561948776245, 0.10865160729736091, 0.12199377926487116, 0.10600779190539353, 0.10295649434650138, 0.18503744515680498, 0.09473365896771993, 0.1974112207009908, 3.7232934611458934, 44.10811947238061, 92.49155967466294, 87.8516467925041, 83.00661748455417, 72.47146852554815, 58.472749033281886, 37.44458521566084, 26.39463889983393, 35.71635361640684, 54.47236291823849, 68.77675271803334, 52.65207329104024, 15.672896908175563, 1.7804936271521354, 0.12479449712461042, 0.2051342143526962, 0.23661786930695658, 1.2993737406307653, 3.3620845983105325, 8.002869717536434, 18.138571362341604, 11.879446218090674, 25.169702306870494, 20.309538533610684, 25.632418432543357, 27.937807190802793, 29.920114240338727, 20.67918465983483, 22.9821886170295, 35.393550395965576, 35.94967580610706, 44.79164346571892, 47.00299339909708, 51.62256879191245, 54.365878412800456, 58.74999000180153, 57.30725988265007, 59.309194472528276, 60.870654736795736, 63.82349737228886, 63.9297543802569, 62.659369284106845, 59.88245671795261, 57.36031778397099, 61.912565692778564, 61.09938383102418, 64.62890901873189, 68.80560567302089, 64.97068866606682, 65.56401383492255, 62.62206362139795, 62.18789254465411, 60.94907468365085, 61.1564072485893, 64.25026693651753, 64.06087529274726, 65.3722099334963, 64.37864218988727, 65.84311008453369, 66.2072943102929, 66.9496734680668, 45.048146863137525, 43.46223062084567, 62.99800711293375, 59.986752540834495, 63.123562182149584, 61.562851090585035, 60.37049762664303, 62.64581357279132, 67.39010072523548, 62.61348539783109, 61.25199540968865, 60.13361000245618, 65.0214715926878, 65.56950123079362, 64.73664868262507, 67.56658384876867, 65.29642581939697, 60.35002677671371, 67.50624210603776, 69.0839292157081, 54.4847732974637, 54.01640699755762, 62.65189324655841, 67.14170486696305, 68.4348475548529, 58.76034898142661, 57.24819683259534, 60.87467124385219, 72.37356616604713, 73.15821278479793, 69.6436357498169, 69.78073827682003, 66.14623085145028, 52.67774912618822, 30.98271962135069, 19.166340212668143, 20.070105291181996, 19.975752676686934, 12.748840547377064, 17.7490407805289, 14.986940064737874, 10.368871842661212, 1.876548305153847, 0.4470829984113094, 0.1748414430767298, 0.12736050862698786, 0.4551306294818079, 3.8549353134247566, 22.367753251906365, 44.371800807214555, 71.64666468097319, 91.01097476097846, 81.69403553009033, 65.62799945954355, 40.29596005716632, 30.288061980278265, 45.70434762585548, 59.080692875769834, 74.86621672107329, 71.581969107351, 57.861745742059526, 10.041430419491185, 0.2238869895377467, 0.21056116588654059, 0.11181456217121695, 0.11189880886025007, 0.10836163535714151, 0.17333862371742728, 0.2046543215551684, 0.15297323345176636, 0.07742515104191919, 0.20312278922046387, 0.11778921294476717, 0.17699738303499837, 0.16332865842888433, 0.16741149337782016, 0.1279613973512765, 0.14524841651080117, 0.1758343849571482, 0.1797471790304107, 0.25762467434810055, 0.0732261848245417, 0.26185776978250475, 0.08686925314607159, 0.18283491173098165, 0.1562747659702455, 0.09669840636272585, 0.1590268449076722, 0.23105055514362552], [0.020363488452388875, 0.031059933638560678, 0.01110021086905392, 0.015575510746378814, 0.04454587541160084, 0.02289100403657123, 0.026274755026303956, 0.07239934612786578, 0.03673192797108524, 0.050227777176206155, 0.04546908796915124, 0.047005630518880584, 0.008399168709142795, 0.01925820743875398, 0.086733058034893, 0.07361090651923612, 0.0643239060657159, 0.06258682468004766, 0.03365844067546629, 0.07878490348136233, 0.041506712685429284, 0.03481935116372282, 0.03111058354167448, 0.030488761464854887, 0.07260555401444435, 10.632315874099733, 52.466184323833836, 67.59417380056074, 63.320810333375015, 49.14046156790949, 40.14050083775675, 23.938487960446267, 19.70963162760581, 32.45818780314538, 45.003129820669855, 47.043672300154164, 47.594769231734745, 16.022801745322443, 1.8258255624002027, 0.0734571143684368, 0.04011766121332203, 0.10766785847203386, 0.25586216650422544, 0.8735375779290354, 2.5187367681534063, 4.716669744060886, 4.92634984754747, 4.940347315803652, 7.876899857674876, 7.359888813187999, 18.52345197431503, 11.761275991316765, 15.652892820296751, 24.04096184238311, 37.44767212098645, 52.02636895641204, 58.18993829911756, 63.46011331004482, 58.93339218631868, 61.548907064622455, 66.25092675608974, 63.163833156708755, 59.881209404237815, 59.070832037156634, 61.381111991020944, 60.550852129536295, 58.26118030855733, 58.387531618918146, 58.49263545005553, 58.535220623016365, 59.6249335042892, 57.49336065784578, 62.036559658665816, 62.246881069675574, 59.452160942939024, 55.69577763157507, 56.38906440427227, 51.690253211605935, 56.30000698950983, 55.56081671868601, 59.09578615619291, 57.05548294128911, 60.023658121785815, 58.28498125076295, 62.85655075503934, 58.75268467010991, 65.34988772484564, 34.24671211550313, 45.15915778375442, 66.5949970676053, 57.440749906724506, 64.97444237432173, 58.399659587490945, 59.55269913519583, 58.384036787094615, 64.52283243979177, 58.29630121108025, 56.420290393214074, 49.20929524206346, 51.33597689290201, 55.31238948145221, 56.57076820250481, 59.09256981265161, 61.36347309235604, 60.113225444670654, 57.943221215278875, 59.84236617242137, 50.04877659582323, 46.88470255944037, 57.14736446257561, 64.03097898729386, 61.3302113932948, 57.210020403708185, 57.07034087950184, 64.99332466433125, 68.34764542118197, 62.41067924807149, 64.52516232767414, 64.1772755499809, 63.83266002901139, 65.3298326461546, 52.9662198405112, 31.63772406116609, 33.077712443567094, 8.864766436238444, 7.081126945634042, 5.460509494427712, 3.3982069309680694, 6.827043650611755, 1.92160346815663, 0.36439018083676217, 0.1197626784203514, 0.0732934779878105, 0.026891264283368667, 0.09789324305470913, 1.0844133914478364, 11.833166172427516, 33.87802893115629, 38.28332524145804, 65.78524727975169, 70.54326272779896, 51.41591479701381, 58.163525058377175, 28.650501851112615, 38.162045555730025, 51.63423784317509, 52.68641756426904, 48.990587803625296, 15.247465852768192, 0.170865063705752, 0.10052734445179663, 0.050399545580148704, 0.009914070232621124, 0.012825031017494059, 0.06678926893660138, 0.010496115109192268, 0.14420813039666222, 0.032013676715113466, 0.022664962133633035, 0.007345918472105217, 0.0443854910742131, 0.008131187322789864, 0.08548281786422576, 0.017402388170481693, 0.0687845679180276, 0.04637459623477152, 0.11064790219308869, 0.02424389424343263, 0.026179151083793373, 0.04924005618499172, 0.040714053001495144, 0.026731353005274173, 0.05555460101834709, 0.020221836879969608, 0.03334108109195386, 0.0036554141467692513, 0.036839999994563485, 0.10440276109523351, 0.05762510685129993, 0.03548114770843137, 0.020163081766616915, 0.06720366121660318, 0.05403690423155504, 0.02402563004814569, 0.020020579836601694, 0.07738079455110335, 0.06317662045119271, 0.07557763042108667, 0.00463099479900613, 0.08103188532855242, 0.0666798102939802, 0.03585225985115094, 0.058616156494545366, 0.10061223465468615, 0.04935238382688934, 0.06650367901930887, 0.033444142900407314, 0.04844940365141919, 0.06148788304398618, 0.013462897848277805, 0.07718715050648298, 13.402906560128736, 61.77176044833276, 78.62037997091971, 70.82998014265492, 59.490058883543945, 48.873489364500976, 32.10072455867645, 26.224666910786784, 27.05815684410834, 37.58482956117199, 46.96787641894433, 46.29605677820022, 14.556795300975924, 1.6401046442408718, 0.0303141049094378, 0.028613246076049346, 0.13362395156535412, 0.9579598543144042, 2.8409376596250846, 4.87915785081925, 9.441652951701995, 12.361527085304262, 11.206774442426621, 16.943531074831565, 11.312607834416053, 8.030720506944965, 8.138347402695688, 15.434254023336596, 26.22294499028114, 41.17302948428739, 52.40033165101082, 60.68983347185197, 64.70952941525367, 61.73666308003088, 64.28657631720266, 65.27132265029415, 62.84729003906251, 59.76238904460784, 59.77544269254131, 60.87747966089557, 59.20072132541288, 57.53434550377631, 59.037295772183334, 58.83278339139877, 60.0252898277775, 60.25900817686512, 59.208589599978545, 64.28189692958709, 63.64663377884896, 61.76473940572431, 57.10037054554109, 57.04403354275612, 55.23971972926971, 58.08326944228142, 56.66223787492322, 62.372408682300204, 57.48296637688914, 61.80755207615515, 61.16281640145087, 64.8618075924535, 60.6762267697242, 64.99324621692782, 38.41214764502741, 48.220093096456225, 66.06817568502119, 58.70919735200944, 66.35161399841309, 60.62101548717868, 60.14819337475685, 59.27758016893941, 65.04532744807582, 60.33023449682421, 57.506339780745975, 51.84732060278616, 52.87107098487116, 57.38162409874701, 58.95943280189269, 62.49786569226173, 63.68417870613837, 60.798185025492025, 59.1397088573825, 63.107303957785334, 50.814442865310184, 47.906836925014375, 58.40457431731686, 65.28725139556393, 62.72677129314792, 58.303577207749896, 57.37993747957292, 65.33797156426215, 70.02288972177814, 64.54295027640559, 66.2905034711284, 64.30271294809157, 67.37521925280171, 66.83478724571967, 53.85239701117239, 34.24326435212166, 22.564989636021277, 7.304631933089226, 8.15759104105734, 9.698988872189677, 9.656591972997113, 7.507914160528491, 6.135218941396283, 2.591605825770286, 0.5477105778071188, 0.15597370873776176, 0.04234276358939467, 0.22420278630189358, 1.67781418850345, 13.441056513017225, 41.12445485207343, 48.6950489782518, 67.05687968961655, 72.32079459774879, 48.15980626690773, 47.95847492833292, 34.293109832271455, 45.33156556467856, 58.34627612944573, 60.3277281022841, 57.57008614078645, 18.92510267996019, 0.1705839554028165, 0.024434177077285225, 0.04854255611257208, 0.03641550301484043, 0.05009536653937352, 0.07187532666589945, 0.04396042335898646, 0.09643349315850966, 0.029035877631676775, 0.05245475263725366, 0.05817165695911935, 0.005591554621670155, 0.03296487063409821, 0.08687107643533139, 0.04275465842276331, 0.029830841325043194, 0.019770000137448795, 0.07608207633658763, 0.03498165455136088, 0.03567704788198875, 0.02073336144789092, 0.020120971828639027, 0.07655551867379297, 0.04766631623609893, 0.012397730155968139, 0.05605145117207881, 0.0058739413338292756, 0.14844225238888495, 0.15583058819174767, 0.10739880839302655, 0.1493668898699745, 0.15388293221833246, 0.12539298799369605, 0.15747006231498334, 0.14587408051856104, 0.09516372540665251, 0.13030150484654213, 0.1904808829027799, 0.1551469160063613, 0.09539319172261224, 0.2900035949724336, 0.14130568372145777, 0.16951998185005882, 0.2250630723973436, 0.21726291836990466, 0.21923211673575066, 0.1419708778661105, 0.18319762371961149, 0.13368192909946366, 0.212761492979142, 0.12443487247031544, 0.21493154427697583, 19.287404168036677, 73.93448122086065, 86.80675091282015, 80.46531384991061, 68.99885300667056, 54.14142862443001, 35.47287248796032, 28.636365629011586, 44.339637371801565, 60.156563712704575, 61.742774132759344, 59.71390462690785, 20.482452300287065, 2.4322781687782657, 0.2936324308956823, 0.20225974520848644, 0.24815329951384377, 0.8477691380727677, 2.8600844644731094, 8.8495486205624, 14.692816234404042, 14.167332380048691, 14.36911283000823, 19.243287309523552, 14.248036126936636, 30.19442127596948, 23.060324192047123, 24.147779749285792, 31.65980112168097, 42.40532836606426, 56.03558432671332, 62.95018949816304, 66.44049490651777, 65.30277613670596, 66.35778780906432, 68.64835785281274, 64.50840203992783, 61.12675020771643, 61.12275331251083, 61.838883969091604, 61.708539685895374, 59.057088052072835, 59.4666305665047, 60.21496780457036, 60.457487952324655, 60.6484014757218, 60.8544514256139, 65.96391124110069, 67.08451670985069, 63.97633644842333, 59.514483482606956, 60.276396043839, 58.157586589936294, 61.416036775035245, 59.818239673491455, 64.98224789096464, 61.18775875337663, 64.19785622627505, 63.23033694298037, 65.6554638954901, 63.75547170639039, 66.85064931069651, 43.60184738712926, 50.14587486943891, 68.99655449774959, 61.02512551892189, 70.38762307936146, 61.91200087147375, 61.79024265658472, 61.84747003739881, 67.58110446314659, 63.41671228408814, 60.498315903448294, 53.95157021860923, 55.49000224759502, 61.23396427400651, 61.9217558060923, 64.64264908144551, 66.66978882205102, 62.328121200684585, 61.271819068539536, 64.80433310231855, 54.29247517739573, 51.61315902586907, 61.344473131241344, 68.50679166855352, 64.23648765010219, 57.151526097328436, 58.047454280238, 65.92013758997764, 73.2521378609442, 67.01986820467057, 68.84220923146894, 67.00195866246378, 69.99751198676326, 69.30468020900604, 56.59877784790532, 36.1623663287009, 41.194414246466856, 16.086220587453536, 15.49641868760509, 12.579179406166078, 12.782498405825708, 12.837946011174111, 7.873658018727457, 1.721512211426612, 0.421107561597901, 0.2444539375362858, 0.12618516887267753, 0.3145283676924244, 2.2288400271246513, 16.702648516624205, 46.7027908755887, 51.180702024890536, 72.90310182879048, 78.33825172916536, 64.1703917903285, 71.76555172089608, 40.07058851180538, 52.0218974544156, 67.38694713961694, 68.18363543479674, 67.60710977738904, 23.670148811032696, 0.45625444982321034, 0.20298451035013124, 0.1474838763956101, 0.14474748693887265, 0.13106112698874167, 0.20140287586517874, 0.12651358310493732, 0.3550002105053394, 0.14724882529868236, 0.15454487815018625, 0.15009956103899788, 0.1772355444488987, 0.10269718124501168, 0.29348316632451554, 0.06687143186648047, 0.13738817054658167, 0.10271806480182756, 0.2147927444668547, 0.20207300361606384, 0.15153974504961124, 0.14206096980600588, 0.07462736729892992, 0.14205951423894975, 0.1366752184807293, 0.09709280374790392, 0.15953909725912158, 0.06731330372032619], [0.05479453837559108, 0.02049864168399044, 0.012940276496773286, 0.05018369647704306, 0.02095500792136356, 0.041970042662034114, 0.010590890719134723, 0.017946500203482086, 0.04225989968906488, 0.02719110152083299, 0.009903257859179811, 0.023462888672046607, 0.01817020745347104, 0.047244868286314516, 0.042122976794358225, 0.03549581829218134, 0.0852209690117067, 0.03077087717341079, 0.01694807887918526, 0.07713458155311885, 0.023147580288951437, 0.03931303523601063, 0.10017493634574837, 0.016472430208758, 0.4027485709276892, 16.60762517682968, 61.85848797521284, 63.777672321565696, 62.458124237675825, 45.453060980766054, 28.03560756867932, 23.126482809743575, 26.862828693082257, 39.06659903064851, 49.1074626676498, 49.46322164227886, 21.27072318907707, 2.389974916173566, 0.025418318522673462, 0.02644031811805983, 0.05014969366452387, 0.23644055059600264, 0.19390741032698464, 3.5345463118245526, 2.8189307114770337, 6.024087407896596, 10.857155938302318, 8.665292339940226, 12.173696544862564, 11.057324294121036, 9.67043205615013, 19.886993362057595, 36.54388350825156, 53.146880288277906, 61.33365523430609, 63.671721258471095, 60.15609695065407, 57.65592721200759, 62.702993885163345, 62.489879746590894, 61.01171493530274, 62.80597963640767, 62.65883584176341, 60.3762831226472, 58.86606470231087, 59.042610583766816, 61.70713547737368, 60.27777279576948, 58.81182224519792, 58.82920226743145, 58.36500936938871, 58.00892483803534, 61.93281296760806, 58.83465828434114, 57.44794353362053, 52.39409508243684, 52.64074156361242, 52.39527571585871, 53.43095010326755, 55.828302752587106, 60.6914298765121, 57.064135689889234, 62.215141250241196, 60.735199605264974, 63.475183056246856, 58.18119925837363, 65.31961094948554, 35.517258028830256, 47.48981052829374, 63.54434228712513, 55.6563421218626, 59.83032449599236, 58.287428809750466, 58.820863308445105, 54.55337162940733, 63.188967704772956, 58.432140734887895, 55.74779610480032, 53.18759841303672, 52.138489907787694, 47.30663976361675, 49.78609546538323, 55.81643758281585, 59.8940904678837, 60.80631609885924, 60.70946101219424, 62.031801823646795, 47.37789746253721, 46.8002264730392, 57.24383515696372, 59.70270626006588, 62.747956014448604, 56.17760550591254, 57.121720006389005, 61.974252808478575, 64.15782843866657, 60.34576708270658, 57.372273168256214, 57.77940734740227, 64.73277338089483, 65.14425746856197, 67.94834029289984, 53.97057017972393, 27.06572701854091, 13.748793909626624, 12.308263259549296, 10.711740928311503, 6.147771996836509, 8.16778184906129, 5.284222979699412, 4.525528723193753, 0.21587070678510975, 0.17345951239187873, 0.05389733450307001, 0.053331364066370075, 0.07077922338559743, 1.682429837603723, 17.05999605117306, 41.97749583951889, 50.3432563812502, 45.42001108969412, 67.02223731625465, 93.27462950060445, 45.20630859559582, 29.847471944747436, 53.78036268295781, 53.904666516088675, 59.83815746922647, 29.275851211240216, 1.636055042186091, 0.11880290814705434, 0.07966002869990566, 0.08823340293020011, 0.03019689920268232, 0.07994611657434895, 0.0871883440882929, 0.04952314865565108, 0.020632276146282113, 0.05678589966508651, 0.07855247240513563, 0.0761268311931241, 0.04988117984706356, 0.052287741639320894, 0.0226673006170219, 0.03620606606766101, 0.04745203761323806, 0.01862702951315911, 0.05095505508624258, 0.018811829072693666, 0.044570861369251244, 0.06640237155220201, 0.0438207961739071, 0.12348568187125268, 0.026308110494527127, 0.09059748897749571, 0.028063298368285743, 0.06297772104341177, 0.04046448070796267, 0.05171389964919898, 0.062042208944237044, 0.17071192272968833, 0.10457282495354453, 0.08045076167271023, 0.05439364073437549, 0.04929403857057614, 0.04698481974041751, 0.026689294778231173, 0.03856464011234142, 0.047588642581456134, 0.02335776800229665, 0.0796916451485407, 0.04560187781950639, 0.034071438675445896, 0.06892565833104235, 0.025400369082607573, 0.02181373502788765, 0.011447130912734617, 0.02493414329364896, 0.05108652726536797, 0.007966182996413761, 0.3099611047054491, 24.353109944251276, 72.6007027779856, 72.12938293333977, 68.25234751547536, 52.86884307861329, 41.74160841972598, 31.671870254701187, 27.815274307804724, 38.21843354932724, 47.98197384803526, 47.19085139612998, 21.976290902783795, 2.834898190152261, 0.06904541319536586, 0.05113798539124189, 0.17324390460646924, 0.6767639722074232, 2.11309235422842, 5.405500704242337, 7.303422372187338, 8.404310576377377, 16.468985080718994, 12.232062393619168, 13.838597555314342, 8.29276817460214, 13.168163491833596, 21.96258221903155, 35.22678690571939, 51.767692565917976, 61.03346447790823, 64.51730189784881, 64.4509393169034, 61.73847913742066, 66.27925411347421, 65.86982142540717, 64.9393371612795, 64.61742824123752, 64.6515057932946, 61.43737054640248, 58.47864827802105, 57.2777440471034, 60.88922323719148, 59.77457192636306, 59.84791240384502, 59.74187112623646, 59.290186666673236, 58.787597687013694, 63.118639607583326, 61.22806502926735, 59.478558494198715, 55.778206240746286, 54.545016980940304, 55.9884492043526, 56.210929962896536, 57.79972914726504, 63.838453369755904, 62.35738208217006, 64.84502377048616, 62.10699758222027, 65.4381488984631, 58.733468978635734, 67.28141969250095, 37.797104312527566, 48.31198246248307, 64.86391390523603, 57.041491846884455, 61.84921941449566, 61.43069074999902, 60.03892790886664, 54.225233985531716, 65.20904717906829, 60.30363298231556, 58.70528674894764, 55.134164825562515, 54.06653881072999, 50.694798807944025, 50.99607213850945, 57.77922691837434, 60.3137997658022, 62.71603968835647, 62.94811848671206, 65.04020091026061, 49.252005930869814, 47.90338523926274, 59.45685994240546, 62.81737412175825, 62.42895357070431, 56.86176100084859, 57.48524135158908, 61.937076583985366, 65.7394536079899, 62.29349059443321, 59.84444110624252, 60.4342596761642, 64.67799748143842, 67.4347137635754, 70.74628460791804, 57.78256485539099, 33.33742433978666, 16.31903875258661, 7.048101079079413, 6.629263527931706, 6.402414229608352, 10.53211892804792, 7.821212007153419, 6.5074420648236435, 2.2741909613532405, 0.4667205898271453, 0.048561543601775364, 0.05656915423910945, 0.10996819068227084, 1.6389199658747644, 17.367745214892974, 38.86553833561559, 50.11146783828736, 48.25577097554361, 57.92937132620043, 85.54621881054294, 45.40898138476957, 33.83613017297561, 58.03298073430216, 61.02500784781672, 66.89769421854328, 35.01213912040957, 2.3727463954879395, 0.10964830300860828, 0.02233669345807885, 0.03719734936772335, 0.0760661953339173, 0.01645762555962128, 0.051315587554727836, 0.04622685234813441, 0.03557322764649026, 0.036378995094808846, 0.02841342544753946, 0.10523962788283826, 0.00720700566401525, 0.0381847869064058, 0.06793129918796402, 0.06661152121640983, 0.06684972859558559, 0.002239707363544092, 0.02183774996909403, 0.04261907235148453, 0.050309583875200445, 0.04673511721193791, 0.07422304907513243, 0.04763320591601153, 0.02117914992624954, 0.0659846467897296, 0.01808430984496109, 0.2491908430332138, 0.2271172145922338, 0.17180975736869922, 0.09842811798256251, 0.1741586442315771, 0.22044238243852893, 0.1803605703096236, 0.1301141503837801, 0.08240273072113914, 0.11889332950475717, 0.11808511440552051, 0.10704137475019503, 0.10654566223703085, 0.0967535034062401, 0.22155630492394973, 0.09853921605334168, 0.2061817936238743, 0.1223282685743705, 0.11674914899612628, 0.15693047594639564, 0.07709087623703866, 0.16184476144131155, 0.1884309082261978, 0.10172627971417482, 0.6080055585311306, 31.60334448660574, 82.25070614968577, 81.13721586042836, 80.23104636899888, 61.470196862374586, 43.565235983940866, 36.10839451512983, 38.30521598938973, 54.79688413681523, 63.42589063029136, 60.781514952259684, 27.680656602305753, 3.616992326513414, 0.1333849321329786, 0.2903509698808193, 0.18080045799574546, 0.6866722469848971, 2.177005905297495, 8.959326936352639, 13.999451014303393, 16.430010449501776, 21.603242120435162, 15.169150829315187, 21.683021168554983, 20.459757466470045, 17.81744691633409, 27.693635725205947, 40.18777716544367, 57.87643894072502, 65.2094707950469, 70.25275630335655, 66.62529345481627, 64.64075065428212, 68.538374593181, 68.52282631781794, 65.28756518517771, 66.64786277278778, 67.3247540381647, 63.03537161119523, 58.47880125045777, 59.113942807720555, 61.19658016389417, 61.404873709524836, 59.213351357367735, 60.29110493198518, 59.40460220459969, 60.573280242181596, 64.84728305570542, 63.279523464941214, 60.812854689936486, 57.32567933297927, 57.31852885215514, 59.464335979953894, 58.688828483704604, 60.84078588793355, 65.14565383234333, 62.96509450481784, 65.39352409301266, 65.81032691463348, 66.51781266735446, 61.019516529575476, 66.5862266479, 42.269630047582815, 51.98723939157302, 66.60188474962789, 59.933694639513575, 64.5560392256706, 64.32474490134948, 60.85184304944931, 55.44058822816419, 66.25226820668867, 62.672364096487726, 60.96738430761523, 58.530462787997344, 56.417952660591375, 52.00348192645658, 53.257895131264966, 59.346241258805804, 64.2123846853933, 66.48608853740078, 65.69733519707957, 68.64754984455725, 52.99669273437993, 49.8035970810921, 62.71298023962206, 64.30715307112663, 63.21245485736478, 55.99479167692123, 58.49829543021418, 63.035991345682454, 69.7165761455413, 65.74618831757577, 65.14052337215793, 62.065334166249926, 68.84712003892469, 71.36128871671616, 73.76869047841718, 58.15727280032251, 33.681439738119806, 18.887520490154145, 22.682331262096284, 20.271350337613015, 14.201742352977877, 17.18346049708705, 17.121630214875747, 10.582255644183006, 1.436961415794588, 0.23392384451243187, 0.194674693348427, 0.16328871460451236, 0.27066701482380595, 2.641623645059524, 24.207841042549383, 56.68234394442651, 61.25609428651872, 55.363399905543176, 74.38610292250111, 100.48928030075567, 54.06939429621543, 41.31724326841293, 69.42095495039418, 69.7502379263601, 75.68559200532975, 43.68601360628682, 3.5445993465761987, 0.3582049095101895, 0.17602104994077838, 0.20245060835394169, 0.2173903187917125, 0.1728222038476698, 0.16606103358489854, 0.2252281030579921, 0.14143493807604238, 0.11182856625847279, 0.14180632217997505, 0.1657019375312713, 0.11394214155452867, 0.1564973757992829, 0.12183319957506274, 0.18949851303571658, 0.11648752230910525, 0.13929883979501265, 0.128416292699835, 0.33634875810915427, 0.25161603225335, 0.18956591345129475, 0.1532296890452985, 0.18870809415896095, 0.09642987722350706, 0.1568954810500145, 0.10044708908084901], [0.03316706421995356, 0.07011933823025997, 0.030186074380312237, 0.03203697536411065, 0.05050356116806788, 0.11199439365056255, 0.10642468929290773, 0.06044098942150032, 0.04654081816214227, 0.04550067377426932, 0.014029477324877537, 0.021689778171299447, 0.02356475346811837, 0.028381067808837663, 0.005413334799795262, 0.03290651388646614, 0.08122592007801419, 0.05628559062437666, 0.03382126500289287, 0.04508140534462948, 0.10465779942610573, 0.04646767974801121, 0.07110779083544208, 0.036595139141765334, 4.6350628714407645, 47.699210182313, 63.29537768517772, 62.46931475977745, 47.18412453128446, 42.381358761941236, 20.421318238781346, 16.892942305534117, 24.921190738677982, 36.73088250621673, 53.90957732354441, 31.442623407610004, 4.427183135863274, 0.33123058597407035, 0.048998336292683124, 0.06034340514170547, 0.09838946118590333, 0.1697139859560036, 2.3103400151575766, 4.266428226424802, 3.5307827976442154, 9.239817588560044, 15.657940910708522, 13.32460722615642, 22.488503417661114, 17.02229815144693, 25.074039620737878, 32.04838837346723, 52.18326376330469, 59.76906099627095, 62.201581616555494, 59.375494295550936, 60.45149457070136, 62.978187376453036, 57.68937326246693, 56.96003990788614, 62.94912261347618, 59.48568151843164, 61.18080046869094, 60.532593496384166, 62.87251480164067, 61.05043657364384, 56.7429994767712, 56.272315056093284, 58.524438027412664, 60.30271514769524, 59.671441047422356, 58.77454011671005, 59.532993147450114, 60.26076147633215, 55.53172057674777, 51.854980991732695, 51.291936520607244, 46.376092741566325, 57.63578191880257, 60.63279828717632, 61.716972781765854, 58.29503036314442, 62.44089718787902, 58.06176308662661, 61.04890684927664, 57.03230173357072, 67.39191286025509, 34.87851965811945, 51.20420878933322, 64.76554086131435, 54.4070162311677, 58.12741571857084, 59.18592222275273, 59.881515349111254, 53.822853719034505, 60.40993705872567, 59.77523088455201, 56.77769284094534, 54.67658112126013, 52.535680878546934, 50.7458366886262, 46.48267530625867, 49.09329506658739, 53.40132836372622, 57.852222227281146, 58.83996525118428, 54.73081573363274, 45.19669486630348, 46.96234979937154, 56.964334903224824, 63.073630409856, 60.58474925256545, 57.798434765108176, 57.54550072454638, 65.14328472075924, 64.93420277872394, 58.732629591418856, 54.75047857530656, 56.74046562563989, 56.79051506903864, 63.48651478367468, 62.583867580659934, 65.8798626930483, 54.23583222973732, 33.05048334983088, 14.705887533003285, 12.790023473001296, 11.624572565478664, 6.842058483631381, 6.149571874449331, 5.577251488162625, 1.9918152425558338, 0.6492638672071119, 0.13354964103669892, 0.04974225746287454, 0.08191929093652195, 0.20436769741917812, 3.1671758957447547, 32.53843753568588, 50.42395130280526, 56.46050253222066, 94.1195551041634, 90.19354497232746, 44.62230690063969, 30.244590351658484, 41.979300129798155, 49.72704026006883, 57.42256972097582, 40.380275326390425, 7.811169268623476, 0.19702376407240668, 0.05901290576965098, 0.027527977194216464, 0.05434510140349308, 0.05101968992441412, 0.0750339148385871, 0.06510724629005117, 0.02489866767709534, 0.015826302077320796, 0.043502237662793174, 0.07053690211426827, 0.023120933835725152, 0.04335479638088615, 0.015241614197410885, 0.03892360593102152, 0.020295230018335487, 0.05770430502091205, 0.07854863430463499, 0.07064187148165318, 0.012902653918811872, 0.05599702828593793, 0.028372669569967736, 0.027901115639495756, 0.05848901271219215, 0.03678856102088767, 0.027212469628260984, 0.023911166936159137, 0.021671298215345993, 0.053054591821086024, 0.10606632102280857, 0.06847673846829323, 0.02836784513126458, 0.05103796112140821, 0.02444350228254353, 0.009436902792883978, 0.06771936096371182, 0.04504879298169286, 0.05427911442013518, 0.05347939140553917, 0.016784281620094856, 0.0656565006882433, 0.021220819363670967, 0.053702663900631095, 0.03957904394595854, 0.037313469144846165, 0.023149731080798853, 0.030292564432226846, 0.009728445213348156, 0.09951346538840763, 0.028491748361698085, 6.246269576011166, 56.14674037502658, 70.309081539031, 70.2547331779234, 57.10439489733789, 50.17984259513117, 25.105679419732866, 22.82361895807328, 27.65826771336217, 33.7324893859125, 46.66040574350665, 29.80289616892415, 4.978923336152108, 0.2599060841866078, 0.07057324532539615, 0.012923628448568767, 0.4115793583614211, 2.9701596546557645, 6.25912465395466, 7.245044756320215, 8.119295470176205, 9.877858757972717, 15.184293139365414, 16.002225971991017, 11.011737527385836, 10.260945866184851, 24.353688493851696, 37.83277042450444, 53.82803909240231, 63.97705031979469, 66.00759075533959, 63.478054231212994, 63.00018010600921, 63.777884129555, 59.138896926756836, 60.08203475706039, 62.882924772078, 62.11292820592081, 62.85422478952716, 61.66018470641106, 63.34466618876304, 62.580478652831054, 57.78382785858647, 57.0179654705909, 59.12441161371047, 60.760283162516934, 60.44981187389743, 59.24259262700235, 60.79894204293529, 61.656909527317175, 58.659073383577415, 54.56834723872524, 53.57085712494389, 49.29949014417587, 59.44095865372689, 62.55779950849472, 64.08714732816144, 61.28928146054668, 62.673274086367705, 59.87056801396032, 62.536818750443004, 58.00826980221657, 68.20843265902612, 38.241932469029585, 51.68189464076873, 67.08277517749418, 57.91015955709643, 60.53130303659747, 60.91513049217963, 62.23456874970467, 55.56102852667532, 61.09356303368846, 61.907894149903335, 60.15611656250493, 56.74116772990073, 55.08968122543828, 52.562470666823856, 49.32747625535535, 50.66074479010798, 56.25012228565832, 60.26852384690316, 60.45663679799726, 57.37399508876186, 46.53029680252076, 48.53785214885589, 58.73901913242956, 65.9149992850519, 61.00094410680956, 57.29084476347893, 58.02517914002942, 65.52891254425049, 69.38471225000197, 61.37118839448499, 57.73047185713246, 58.53276914165866, 60.36690473556519, 65.77679849440052, 65.64144534449424, 67.16234437880978, 55.444910680094075, 34.88724300938268, 16.12245544310539, 7.455423531993744, 11.220384086332015, 9.176349716801798, 9.395302303375738, 9.81954291943581, 6.483381265594113, 1.7144054895447147, 0.24904363157768405, 0.2563656088445456, 0.012124882196076216, 0.19514813568563233, 3.18336425289031, 33.641827721749586, 51.793776327563876, 49.04137073024627, 81.90295665494858, 91.20869359662457, 50.96515601681125, 32.9421200290803, 49.83216762542725, 56.38183547604469, 66.25774383544922, 48.57663262274958, 8.257483513124528, 0.07476335556636896, 0.03382564319538013, 0.013631379735025187, 0.0984186644575769, 0.03308174500782644, 0.030194752241274526, 0.03198998161561547, 0.03510457335881168, 0.03866759083804585, 0.08830487893353547, 0.07829394837420794, 0.06760263980756845, 0.05593468788109961, 0.05703397808716663, 0.006391250823188814, 0.029911426113798257, 0.048798594188185475, 0.1034073294290612, 0.09040015238908031, 0.03256594183884802, 0.01535921443944737, 0.005850048009080873, 0.037183203554201516, 0.03603385333272238, 0.011458261212664507, 0.059715569274680275, 0.10790920681169919, 0.24193933053362757, 0.12785822829051366, 0.22337165751284171, 0.22908236801383958, 0.13888734332736463, 0.19101671544053864, 0.1779493392114678, 0.08625243745383718, 0.16858256602239224, 0.1487209704974967, 0.17336994139177186, 0.21004208003080663, 0.14269081665383232, 0.10750439829163014, 0.1482219408236204, 0.2966473239564127, 0.23837682250286304, 0.11164477410455866, 0.1293661574562711, 0.1634822284141856, 0.1468992287353162, 0.3039999907055209, 0.18081173480999085, 9.512913592400091, 69.73849435006419, 81.69364329307311, 80.28196657857588, 64.6317998055489, 58.01254518570439, 31.52343600027023, 24.245476184352754, 36.90971512948313, 49.2731043600267, 67.47807948820054, 38.79933264947707, 5.837207551925413, 0.6081398997095324, 0.2514026920881964, 0.1672627191029249, 0.23391771580903764, 2.6965892891730032, 8.882013097886118, 14.861204566494113, 12.806058122265725, 19.742952162219634, 25.447868954750803, 24.321340707040605, 34.53838348388672, 25.342339546449725, 32.912643417235344, 40.81697240952523, 57.03422369495515, 66.89995350376253, 68.40834802196872, 65.62919970481627, 65.56923843199208, 67.93172513284992, 61.92783547985939, 63.22731279557752, 68.51336556096231, 65.77395085365542, 65.62284938750729, 64.47035504925636, 67.15078907628214, 63.08005525219826, 58.2157043487795, 57.155432778020064, 59.474012467169, 61.87295759877851, 61.517583016426336, 61.298942258281095, 63.31988857638452, 65.32991109355804, 59.75198691891086, 57.48615526383924, 56.66313217532251, 51.050612695755504, 61.686684239295225, 66.518644209831, 66.71076974561139, 65.08234677776214, 65.3907980457429, 62.016983109135786, 64.57443514177876, 60.679074410469305, 68.71350842137491, 39.95898531329247, 54.518489991464925, 70.57115862446447, 60.88431635210591, 63.38431350646481, 65.65579337458458, 63.949150500759, 56.15478515625001, 62.80522654133459, 63.32952976226807, 62.22717508192986, 59.021735729709754, 58.004751436172, 56.48171863248272, 51.13338255113172, 53.83669184100244, 58.420981591747655, 62.530562570018155, 63.25946054150982, 59.28882168185327, 50.09773169794391, 51.80766151797388, 61.70403680493755, 69.77987535538213, 62.598839267607666, 59.269311812616166, 59.065497613722286, 69.59595541800223, 72.32045727391397, 63.44804025465443, 59.93467130968648, 62.72530432670348, 60.43588745978571, 69.00519155686902, 65.84882890024494, 70.42997683248213, 58.443872544073294, 38.0620055044851, 21.316909097856094, 20.371635536993704, 22.514147873847715, 13.976347273395909, 14.217395551743047, 14.584738266083503, 7.737844970918472, 1.6074491965193904, 0.15394279432873573, 0.23492712857982806, 0.18818260380818, 0.39674124650416837, 4.550167581727428, 41.163804069642104, 65.82791482248615, 66.92187955302578, 99.29042354706796, 92.0054054260254, 54.36773761626213, 44.13860021098968, 58.13171071390952, 64.85570830683555, 74.11375707195651, 56.07623184880903, 10.887357208036608, 0.2808597533693237, 0.1872498151515761, 0.11459496337920429, 0.16696339322915002, 0.15270623648839612, 0.12088435371556591, 0.13354265431482948, 0.12146772966990549, 0.08533793531598584, 0.17621447181990071, 0.2001146377334672, 0.15687029207906417, 0.1749712030493444, 0.10863458482368339, 0.10215828435555582, 0.08450695974451881, 0.07863213788838157, 0.20139697698816178, 0.20166352962053594, 0.09156774699447617, 0.2554647660543842, 0.07142269893759681, 0.15128485227544464, 0.12720685437201493, 0.14631963725532257, 0.1501553322398855], [0.0274338441405205, 0.04090696160170821, 0.043594436344480327, 0.07654029650673752, 0.0223778477013712, 0.022719321817520167, 0.05694261061087732, 0.017414547901059833, 0.017582263699882937, 0.07697322045362766, 0.011999487009410177, 0.014283410573918975, 0.03182026249687037, 0.008044301460857594, 0.022538281834474014, 0.022309219629894343, 0.02612951241673962, 0.05874934471062115, 0.0070680622124083105, 0.06671738690666615, 0.06973666199032338, 0.06575455228167196, 0.07343809240527692, 0.0629701903991161, 14.944917751896767, 60.981775483777454, 67.99536166652557, 54.60357012287263, 41.12601987777218, 30.848260771843698, 31.010354680399743, 32.715375654159054, 39.09378497831283, 54.18146033440867, 39.531709763311575, 9.518863827951494, 0.7221070616956681, 0.03523247939864955, 0.026597741525620226, 0.11723422820890143, 0.7034301445368798, 1.2270269711171429, 2.9692464778500223, 4.5977047470308126, 4.839530144968341, 5.213910571990475, 22.77777821786942, 13.643710670932649, 12.002945965336217, 22.298193939270515, 49.59053393333189, 62.30711690841183, 65.46923368207871, 64.89155092547017, 59.52470517927601, 58.44952860186177, 56.26682766022221, 51.72062412385018, 52.980669852226015, 54.63757314989644, 54.384866606804636, 57.252954667614354, 58.63044792605985, 55.291177303560325, 55.026181974718654, 59.660944784841234, 59.780267207853264, 56.287933934119444, 57.10245724647277, 57.16077504619476, 57.28797358851279, 56.891625927340606, 60.632649237109774, 58.389920342353086, 56.115463395272535, 51.80375483728225, 48.19721391124111, 49.08752526006391, 56.158982092334384, 60.73916512150919, 62.15977699525895, 55.31602551860195, 61.95275821993428, 57.39134373203401, 62.396150788953236, 56.87209252388247, 62.72093480633151, 36.386521939308416, 49.41598453829366, 62.76993305452409, 53.54455371056834, 53.34978841966199, 57.296861679323264, 60.04432509022375, 55.75219700413366, 56.51955773753505, 55.369852204476636, 57.08988212770032, 56.13655397968908, 55.1185812488679, 51.42465383775773, 48.29797567859773, 47.046625844893924, 48.98865407513034, 50.975271809485655, 52.96793391627651, 50.237654409100934, 43.775984933299405, 47.75446068856024, 56.5143370628357, 60.79872631257581, 62.93043251960509, 56.45727442156885, 54.96888399124146, 60.96472886300857, 60.55211121036161, 56.66502275774556, 49.539335235472656, 56.69074173896544, 60.01599381046911, 64.3235211218557, 65.47820414266279, 64.09111676677581, 59.157049655914314, 51.8812059587048, 31.02174524338015, 13.987074955817192, 7.6925234544661745, 8.147796392440796, 5.955650873722569, 7.173262930685475, 6.403224199048935, 2.2886713714368883, 0.3362385027350918, 0.060174226114946994, 0.0658114189882913, 0.02405865418334161, 0.0428195154264329, 6.2022488155672635, 35.11168103064261, 51.2270095271449, 56.605736132591005, 45.73118840494464, 17.597625524766986, 20.869854996281287, 40.524740142206994, 45.411523080641224, 56.578667856031856, 51.8599820137024, 8.22782451106656, 0.3082954763404785, 0.01979064812222796, 0.03378500223099705, 0.05711783790179799, 0.02993460027350774, 0.00583947743214066, 0.08125543744573671, 0.10528837405746022, 0.0990777835249901, 0.025500946850966544, 0.017208790091136773, 0.019828136634802627, 0.04866126526687895, 0.015159286558628084, 0.061657498740861495, 0.018691394305337342, 0.07651740579956001, 0.013950138386609334, 0.024986541792449933, 0.009006343184850149, 0.04728528325475993, 0.039222935635236, 0.003417032482590707, 0.03756044440031533, 0.028656380656625957, 0.019466435882232843, 0.06224621049759369, 0.027405313111000487, 0.024634376919317632, 0.05606416057074263, 0.04166635391753047, 0.07142858249285529, 0.02509663437282847, 0.019482192395615484, 0.009675793905532169, 0.04784188060570629, 0.011621338349106091, 0.06131231101349958, 0.03388875351858235, 0.014493047661568611, 0.02517813272143324, 0.018877685821104436, 0.006148796444082814, 0.06097976373688829, 0.01357011759894029, 0.050980887571049315, 0.05043668935315744, 0.012525337421515537, 0.026065994151717713, 0.1561760785238397, 21.31547154918794, 71.62023575075212, 75.92354651420348, 63.39340948289441, 48.53705590771091, 38.089324812735285, 36.47723851665374, 30.889696690344046, 30.38961018285444, 51.78140909441056, 40.333265719875214, 9.220340078876866, 0.5042824323379225, 0.03819658466043972, 0.0793999188669747, 0.37309753618413405, 1.892404976871706, 5.9969549025258715, 7.396087386915761, 8.183752759810417, 10.335570919898249, 10.768621179365343, 15.280226469039919, 9.613707719310638, 13.251615839619792, 24.1290484705279, 49.83487406084615, 61.94989096733832, 68.33604305021225, 65.90794686348208, 63.04548348149946, 60.56080318266346, 60.30839081733458, 55.6525452675358, 55.69500100228095, 57.51569463360695, 56.54662993646438, 59.5706832024359, 61.03236621425998, 57.48083652988557, 58.1865454489185, 61.005576425983065, 60.983289518663966, 56.68497585481214, 57.478028112842196, 58.26101556901009, 58.8031106610452, 58.183187900050996, 63.20573975962978, 61.81778161756454, 58.010289822855306, 53.56899399911204, 50.44171963968585, 49.883425158839074, 57.29704995309153, 63.45987796783448, 62.32481464262932, 60.02254809102705, 62.32055102625201, 59.001531600952156, 63.392122945477894, 58.50705016043879, 65.0001770450223, 39.42786893536968, 51.66089427086615, 65.02425647551014, 54.04591106599378, 55.93251620569537, 58.949654333053104, 61.66793923224173, 57.93403110196514, 55.73846086379021, 56.944723052363244, 60.05659818649293, 59.455365519369806, 56.72856515453708, 53.275016277067124, 50.5191001584453, 50.30823746035176, 52.499469557116115, 54.723174956537065, 54.901725169151064, 50.65612423804499, 46.04805707931519, 48.84169855425435, 59.716426710928644, 63.33588007957705, 60.6203761408406, 55.99656458823912, 54.778154819242424, 61.61053142239971, 64.26317153438445, 59.66298833970101, 52.29270573585264, 58.535969795719275, 61.6107589198697, 67.36630762777021, 67.45900892442273, 67.54539520509782, 63.39140907410653, 53.169932057780606, 33.11622619628906, 15.498538728683227, 6.114604434659404, 9.212989557173945, 5.813355128611288, 10.152218745600793, 10.687718372191153, 7.771251797676087, 1.8823813598963524, 0.35486252918358774, 0.04361001857286019, 0.04025178788710506, 0.04793845364944108, 7.354811795296208, 39.492238952267556, 47.83881518148607, 61.58082731308476, 57.48595130059027, 27.140014748419485, 30.412032411944484, 46.39963088497039, 52.662922566936864, 61.95243658558015, 61.68146748696605, 11.824617366636954, 0.29222120500860677, 0.03880732910587423, 0.0708433602666182, 0.046919993380264896, 0.037371592235661326, 0.04254155957530584, 0.03661527959329467, 0.10707713573450044, 0.041082254010102445, 0.05148799181164754, 0.06430217981218331, 0.02007134656812395, 0.021258369163279573, 0.046564256622185635, 0.030848489541019646, 0.035678480466407154, 0.0421985705202866, 0.07949443879507243, 0.021738650750428922, 0.024135741780722336, 0.05478856288978169, 0.013610428187906021, 0.009133859477456539, 0.021255668703346484, 0.0486187665392795, 0.057017491875036116, 0.09784993610434956, 0.17680959956299874, 0.10716415566181946, 0.13103336396236576, 0.13831596430991927, 0.16107688087128824, 0.23460531036459634, 0.11774190701544286, 0.10732069806826693, 0.15893892865748177, 0.08723589516575299, 0.20076991870037972, 0.12042003548553876, 0.16138907702219102, 0.12190500499620555, 0.0978144892160931, 0.13328566245975035, 0.2035432029515505, 0.16769330648164596, 0.16119070621507783, 0.14244717005039417, 0.145031935385158, 0.12028222392883994, 0.4241834352574041, 27.221168587284705, 81.75668362648257, 83.54908127938548, 73.70218276977539, 56.53345469505557, 43.60424003293438, 43.264103858701645, 44.57701136988979, 54.694718160936915, 69.92338703524682, 51.84224897815336, 12.111806446506131, 1.0258180840361504, 0.12729496980506566, 0.11166643907105732, 0.3631674432225766, 1.7004901459140165, 5.371700169578676, 11.292672388015255, 12.876727465660343, 15.757953505362234, 12.95718704500506, 31.792100706408103, 22.62887327901779, 21.786385428520944, 27.36457044078458, 54.51869787708406, 66.61242023591073, 69.6144925394366, 67.979005382907, 64.35304087977256, 63.53095916009719, 62.04881314308413, 58.536291430073405, 56.953230673267, 59.77240677802794, 58.67220547891433, 61.88162603685933, 64.26760381267917, 60.98903971333658, 61.069507137421645, 64.6540984799785, 62.73224692190848, 57.718155614791385, 57.04028375687138, 58.05934298423029, 59.362872108336425, 59.33565085934055, 63.68402573370165, 64.21308678965416, 61.653846156212595, 57.69324856419718, 53.43370752949869, 53.80767806883782, 60.96090847446073, 65.23740983778431, 64.7945350216281, 61.16045905697731, 65.4885317433265, 59.48772115092124, 66.3021372210595, 59.66272946326964, 64.74194780472787, 42.49300510652604, 54.135501923099646, 67.95771475761168, 56.65728784376576, 58.72166264441706, 62.78340247369582, 64.39074662423903, 58.34771956166914, 56.925499516148726, 58.49331794246551, 60.419515486686464, 61.53095045397359, 60.052895469050256, 56.35518689309397, 53.06504003463253, 51.763919245812204, 53.03336297312091, 55.88930737587714, 58.06280251472228, 53.39054576812252, 48.07114893390287, 50.81393687955795, 62.63598803550967, 64.23307518805227, 63.87965786841608, 57.18381112621677, 55.06912408336517, 64.91026063119212, 65.60977220535278, 62.511488083870184, 54.786070162250155, 61.64361661480319, 65.39141778023013, 69.30074999409338, 69.08461170811808, 68.9964525161251, 62.82634458234234, 55.1454024161062, 35.94532197521579, 19.002451819758264, 15.731492215587249, 21.970807429282896, 14.933606616912352, 16.09023807510253, 16.50885989589076, 7.365667935340636, 2.129555522434173, 0.2936276505070348, 0.24814822801178504, 0.15592356062223836, 0.2287696509231483, 9.76738618266198, 47.91324215550577, 66.76621637036725, 64.47432841024091, 53.56185528539843, 27.293991311903927, 35.39939472752233, 54.75860964867377, 62.15833748540571, 70.43653503541024, 71.460234426683, 15.437653737683451, 0.6040061505571489, 0.19118025989061405, 0.1564139335025703, 0.14462914167632981, 0.1729590271509463, 0.11516807375535851, 0.12972005943377174, 0.2174352575093508, 0.19621168022915242, 0.13589843596902587, 0.11122977661509668, 0.12053104928664624, 0.1342234000443451, 0.06678884758824302, 0.1616182292421018, 0.08289490390809313, 0.18096236301766289, 0.15975973058131435, 0.14369347252913062, 0.10557586387280496, 0.11446210841137557, 0.17880698996445826, 0.0815140151028191, 0.13344732233353201, 0.1495162770152092, 0.14917991845117462], [0.04711032026417313, 0.04201920252413519, 0.023969211502962058, 0.04465822986657581, 0.06909121759235859, 0.030176369961531415, 0.03206117991207829, 0.03389967410194297, 0.020749951081891215, 0.06345132808952082, 0.023359399769575368, 0.015373920454763839, 0.029764095914640257, 0.062358323634872516, 0.05470735756980796, 0.037483870081843874, 0.03656981610542825, 0.044314673906492616, 0.0759356692733784, 0.057044913992285735, 0.028862054196877346, 0.032666084852309964, 0.05445255672619228, 1.3404204864655773, 34.87017285439276, 70.99295462331465, 61.91708426321707, 51.96781189210954, 28.787829914400657, 22.245967580426125, 20.951793309180967, 29.852235663321714, 44.11083767491002, 45.110065398677705, 15.876718951809792, 1.1625484761691864, 0.03799508821459548, 0.09172729246558682, 0.07637695890040168, 0.26023951629477166, 2.215725337305377, 6.768874410660037, 7.719813344940063, 3.445061358713335, 8.606338135657772, 10.733183545451011, 12.029425886369522, 16.62251057163362, 34.072880514206425, 44.29218845982706, 59.53470722321541, 59.79316788335001, 62.79327900178971, 60.2341599618235, 63.54263605610017, 58.795261998330396, 58.015192785570704, 52.13284561710974, 47.45420325186945, 47.06074245514409, 52.83472238048431, 51.81229383714738, 56.29230737686158, 55.681845372723, 58.91273306262109, 57.29142135189426, 59.867767441657286, 55.68979209469211, 58.65553540568198, 59.25165722447058, 58.88959892334477, 57.51523179392661, 62.29956634583012, 58.21106026249548, 56.04547262191773, 48.81113936824184, 49.51569118807393, 46.62102122460642, 55.888707253240774, 58.05487148223385, 61.293450940039854, 56.45978473847913, 56.13324742163382, 55.70467356712588, 58.40859474674348, 58.44487274846723, 60.99156179735738, 36.80145771272721, 51.086270962992025, 62.521003753908225, 51.31843605349141, 48.90542922481414, 55.2179584195537, 61.408439144011474, 57.465656957318714, 55.69356541479788, 55.33500194549561, 57.71821837271414, 57.93225426827708, 54.232827694185325, 52.753376345480646, 49.79901183036066, 48.46799473608694, 48.05478480554397, 50.014942230716834, 48.13369897104079, 45.742339703344534, 45.644264759555945, 48.04772846160397, 53.91255832487538, 61.56988782267417, 57.621869271801366, 52.28859116954189, 56.928123581794004, 60.884437945581254, 64.30896520614624, 56.34719702505297, 52.25300350496846, 60.50290899892008, 63.44723224639893, 64.55587056375319, 63.85406048067155, 64.70825856731784, 65.28632571620327, 63.59733350815312, 56.939278802564075, 40.21235081457323, 24.90777623268866, 7.998998338176359, 6.371758945526616, 8.148282276045892, 5.479346186883989, 3.98558505119816, 2.4716580298639115, 0.18377461050066257, 0.08308313171108885, 0.05675588050977357, 0.06969823502004147, 0.6156312590164523, 18.133978266869825, 48.68874572938489, 33.262816936739036, 18.024126406638853, 24.135385059541274, 27.733253625131425, 34.94590597767984, 48.82128261750745, 55.92274950396631, 59.54423466036397, 28.850887898475897, 0.8654051562470775, 0.025618447501572873, 0.01558054298643143, 0.06740137318810148, 0.014295164277897248, 0.08094610646367073, 0.0451936602081743, 0.027132911397324457, 0.019326979151716637, 0.040840932483514475, 0.017185343970214168, 0.08749940642906774, 0.026116195893395814, 0.03587567149811695, 0.007834217648187113, 0.014444938297533702, 0.10687151773562355, 0.022187561037078984, 0.03137957041842803, 0.07763001061375104, 0.06940427176173657, 0.11468935307235488, 0.07197458867824848, 0.015186233701364649, 0.04812150269806866, 0.02832034001907995, 0.07825273284388166, 0.010285975276342323, 0.02212623761396014, 0.04339177161455155, 0.04386994071424969, 0.015772230634015175, 0.0034965248778462414, 0.04352583317086101, 0.0402116870147086, 0.01290445231021412, 0.060829568368893486, 0.0503089135482667, 0.0700136257575885, 0.019600652571346973, 0.03119170076153692, 0.03958663970772778, 0.05114675326753528, 0.03644733013765466, 0.031987072396723014, 0.06323803005920303, 0.014624724769213749, 0.102133869133409, 0.06150009065505959, 1.9974170000322404, 43.555649711239724, 78.77808278606784, 69.0454193853563, 60.174230067960686, 37.323376132595925, 28.307516074949696, 28.56015789893366, 38.14291223402947, 47.85183745045816, 45.675663332785334, 16.357954548251247, 1.1804674565792084, 0.0712399639850182, 0.08429581059082862, 0.1719744969159365, 0.435336419050732, 3.7457066197549147, 7.942339701037254, 10.142047059151436, 10.735332023712898, 12.945478770040697, 9.085381127172901, 10.90476566745389, 19.17981355421005, 34.06110555894914, 50.6299816408465, 61.783166700793856, 64.35986972624256, 64.54407599664503, 63.556729132129306, 65.99884386985534, 61.458308158382295, 58.78138465266074, 53.74721081026139, 49.23274317095357, 50.602681944447184, 53.17289736963088, 53.69469027365408, 58.71452785307362, 57.335783358543154, 61.264374409952474, 61.07817557550246, 61.4382452349509, 55.50675076823081, 57.17354628347582, 56.76603555679322, 58.76356924733808, 59.469435061177904, 63.114521118902395, 60.63850533577704, 57.0453671486147, 51.398460249747004, 51.01431900455106, 49.274379130332704, 58.15132256477111, 60.42410858215825, 63.70402197684012, 58.46255871557421, 60.64805630714663, 57.5612804197496, 61.00929483290642, 58.15318569060295, 61.77385891637495, 38.639609813690186, 53.020226955413825, 64.4796589113051, 52.763060677436094, 52.2913525181432, 56.76047755825905, 64.58281724683701, 58.675692465997514, 55.695820777646965, 56.701430197685, 58.09844509247811, 58.7732300450725, 57.02632404142811, 55.98435817226287, 52.27035607061079, 51.95173017440304, 50.752187005935184, 51.944014872274096, 50.76532302364227, 47.49960860898418, 46.457391708127915, 49.657822193637976, 57.56985472094629, 64.01619949648457, 59.29836873085269, 53.85247153620566, 56.59141555909188, 61.93715895375898, 65.53151307567474, 58.3330891209264, 55.31186388384912, 62.56542067373953, 65.02786505606868, 66.06672440805744, 64.66521447704685, 64.24369304410874, 64.2226848294658, 65.5647159391834, 60.54515684804609, 40.71439458477882, 18.874619814657397, 6.699594566898962, 5.832775273630697, 8.324020639542612, 12.52316011536506, 10.977633499330091, 7.650221672750289, 2.857327283390107, 0.158382902042039, 0.1414456633069823, 0.030090231035325318, 0.7065147209552027, 18.2053477533402, 48.19903389100106, 42.01273441314697, 25.76748132705689, 26.47934836726035, 28.451823995959376, 42.84865033242011, 54.10004761911208, 62.886090124807055, 66.67632349075811, 37.32653364058464, 0.9314606278654068, 0.023199666606923266, 0.025719766459998586, 0.06092671597857149, 0.026656954376507672, 0.019881603826257973, 0.03339304866629743, 0.06638793079482933, 0.03970071019965314, 0.041479562529392784, 0.01607448966693013, 0.02013993633520459, 0.020159287716171915, 0.01217702692825227, 0.048001165606922684, 0.03742566655179666, 0.06684634248696028, 0.07657264839977988, 0.025526185617631963, 0.023454511500594598, 0.06453628096008493, 0.05364497364949315, 0.02844424133429364, 0.04194011926771172, 0.061063374572944265, 0.03171639246565681, 0.25750553235411644, 0.1510722628764568, 0.1376845546427273, 0.15644911226005326, 0.1825393090445188, 0.13425560638068185, 0.25195997508783496, 0.14684051575679935, 0.06052755735694401, 0.2974670073918758, 0.1432908013943703, 0.08213476848698432, 0.15509958709439925, 0.16340126824234763, 0.16444242769672027, 0.12570801100903942, 0.19458112336935537, 0.161788362048326, 0.19816353436439268, 0.09352241267239855, 0.1421686051593673, 0.1574425444367432, 0.2085921820253134, 3.390249177332848, 53.365081740963845, 88.60049001632198, 78.34172694913804, 68.82029102694604, 42.7071233718626, 34.04021109304121, 29.178307748609974, 39.86299707043556, 58.29403408112065, 57.759038479097434, 20.59071363941316, 1.9134156429959883, 0.21740643728163936, 0.26320957789017313, 0.37020013036747135, 0.6646772498084653, 4.572486848600449, 13.255998107694811, 18.49711129742284, 14.135061079455962, 17.105815218340968, 21.843850112730458, 23.709629428002145, 26.31285159818588, 38.169180347073464, 47.85847410078972, 63.94068602592715, 63.26383398425195, 65.39938411405011, 66.17471510364165, 68.03583268196353, 63.88258003419446, 61.83560486762755, 56.62189629770095, 51.07557073716195, 54.10307176651494, 56.61817004603725, 57.333174982378566, 62.18891236089892, 60.40575581212198, 64.42455353275423, 63.171803412898896, 63.05752908029864, 56.50310731703236, 58.22598095863097, 58.8700851317375, 59.58300336714714, 60.54993821728615, 64.866212414157, 62.15356003853583, 60.60911109370571, 53.78127267283779, 53.9701073400436, 52.114520303664676, 60.570075665750814, 63.865549102906265, 66.49775366629324, 61.360876483301965, 62.47225261503651, 60.29245814969463, 61.69849841825424, 60.911372861554554, 62.56798590383222, 41.530027927890906, 55.738931548210886, 67.16206196815737, 56.28001859111171, 53.38244215134652, 59.08867097670033, 67.95138405215356, 61.74671219241235, 57.601865183922556, 57.107097410386615, 59.671746992295795, 61.579023022805494, 57.53565949778403, 58.69756360207835, 56.47696864220404, 54.45986624686949, 53.43316624241491, 54.678710968263694, 53.547358205241544, 50.72768003709855, 49.17770055032546, 52.298275501497336, 59.09881814833611, 66.37491287723665, 63.06283996951196, 54.459623059918805, 56.666634851886386, 65.0514934139867, 68.87717323918497, 61.20577812194825, 58.430159937950876, 65.7327816563268, 67.3514183105961, 68.55570362460229, 65.47068888141264, 67.20993841848066, 66.72598854187997, 68.2021882457118, 62.08186695652624, 45.04339295048868, 31.135611649482485, 20.049536381998372, 16.48032073051699, 14.297662934949322, 18.669593603380267, 13.532640914763174, 6.196281419646356, 1.8136707501065348, 0.2643351755555599, 0.26886505345183037, 0.1425968329872816, 0.8953715740673004, 25.050340660156746, 63.68402573370165, 45.18331173927554, 25.398745190712717, 33.973950493720274, 37.51292859354327, 49.59568400536814, 64.68064115893456, 70.67202629581575, 76.10931781030472, 44.77581670207363, 1.7075659791308067, 0.2511848626478065, 0.09688376899688475, 0.13634272099983308, 0.10258384619749362, 0.22500849629361785, 0.1733806513009533, 0.13530991190383512, 0.13297973290806817, 0.1575322839761934, 0.0805269797602969, 0.1889989011350178, 0.14413250219677726, 0.12226846009012192, 0.10200023275589752, 0.13678726650053455, 0.196777482126509, 0.1439770323134238, 0.1036639612228159, 0.25936856625541566, 0.18419764425245025, 0.21324739190599612, 0.27395601414384385, 0.20137391774164093, 0.11247572669338797, 0.11270036665542472], [0.0029461974777551673, 0.07219238747512141, 0.011208730096357965, 0.03209829304157005, 0.02844697626818332, 0.05579177800926471, 0.03960795610422089, 0.08761281042449898, 0.08030893581528818, 0.10042242871056642, 0.01927940892205844, 0.01878778540319012, 0.01659325759617552, 0.062234064173554225, 0.017604757956559622, 0.013766929417127564, 0.09468379430472852, 0.042350114203028144, 0.09477099809314936, 0.014587128046719779, 0.05417625179454204, 0.041724266334166454, 0.02087176097707162, 5.85168109786126, 56.04243278503419, 69.3819038329586, 63.452417619766734, 46.69270646187567, 28.8774815682442, 20.173179295755205, 35.09725063077865, 49.25112339758104, 41.174806317975445, 32.565072390340994, 4.25036366908781, 0.06719632209428857, 0.06577725146686839, 0.06525191433367229, 0.133555922957678, 0.718371126680605, 4.512114217204433, 8.7120940608363, 7.219305182656935, 7.732913080723056, 15.592240229729684, 9.661676345332976, 15.706814623648121, 46.193141629618985, 54.654054949360514, 59.82081274832449, 64.32119515634352, 61.6194312803207, 61.29053661900183, 61.77157217456449, 62.72866187557098, 62.409953609589614, 58.664905948023645, 53.99215498278218, 47.49039888381959, 43.67169695515787, 47.87645816802979, 47.029904780849336, 48.78798561711466, 52.527173257643184, 55.24976491928101, 56.909135387789824, 60.58179963019587, 58.88672382600846, 56.117067644673014, 55.051622467656294, 54.764461824970866, 56.67189082791729, 60.380860528638294, 57.8047223244944, 56.21725282361431, 49.20018357615317, 47.31229189903506, 44.725261272922644, 47.593431703505985, 56.56184873273296, 60.47782544166812, 59.038727437296224, 59.043195016922496, 53.67034804436469, 58.562359502238614, 54.31427571081347, 63.79108682755501, 36.32342669271654, 47.21140461583292, 61.606546294304636, 52.86174751097157, 45.64815967313705, 52.127985800466234, 59.50998060164913, 55.82378810451877, 57.89946717600669, 52.05644176852319, 56.118530688747285, 58.71089181592388, 58.46173894020819, 51.97180094257478, 52.031267996757265, 50.71687782964399, 50.149722714577955, 50.51595833993728, 51.643577006555375, 49.53269858514109, 47.011646147697206, 47.12859161438481, 54.97776423731158, 57.922236534856985, 58.761533537218654, 55.49036702802105, 55.93464605269894, 61.41282043149395, 61.00980081865865, 53.54295730590821, 49.03729146526706, 62.56778194058327, 61.171700569891165, 59.87043073100429, 61.34167648130848, 61.774521796934074, 61.75090520612655, 64.98838640028431, 65.80645161290323, 61.08055645419706, 38.73735135601413, 18.01210630324579, 5.1497454989341005, 8.471495874466436, 12.241014222944937, 12.944121629961076, 2.778849236426815, 1.382846313138162, 0.31038116603609056, 0.04291224653922743, 0.06003783948178734, 0.05187360982921335, 2.399859779304074, 27.779139472592263, 34.53868158401982, 25.0317015570979, 27.398659759952178, 32.03510134450851, 39.27378254552042, 34.75742824615971, 47.78988361358643, 54.97203365448983, 49.06081784156061, 5.329462616674362, 0.20441459732190256, 0.048979356464359074, 0.02853074606748358, 0.023791011790895177, 0.012831999544775295, 0.06980938671697533, 0.030889469499309218, 0.029808720536229592, 0.04382934954558169, 0.014045379394965788, 0.05813635179712888, 0.02018180495548633, 0.038855604136422764, 0.02988237414448973, 0.03833783212147894, 0.056788171115781994, 0.01798346586104843, 0.022166208251409476, 0.02641341885581853, 0.03538020796352818, 0.039845198212612065, 0.06541541281847224, 0.024859059016190233, 0.02263017982665089, 0.028244717564854412, 0.026637237188556505, 0.03224677811827391, 0.07121733374773495, 0.025003964547067884, 0.03775187062039491, 0.029386119624119134, 0.0711820477379426, 0.05962665711018828, 0.07188278070140271, 0.04555305120565238, 0.03141857195465315, 0.02118412183687812, 0.040405959251426884, 0.026984236713859345, 0.016239688866921974, 0.05544430350944881, 0.04988879476103091, 0.01989350691738148, 0.02876397579037134, 0.039211712447145296, 0.03180086898106722, 0.03444402553741971, 0.018524266478996125, 9.436750969579144, 67.9012090929093, 76.59229493910267, 70.80097029286047, 52.65843929782991, 34.44858866353189, 23.81031470914041, 29.008527955701275, 29.26620806417158, 37.59438445491176, 34.591460997058505, 4.723721675334438, 0.19114770115383212, 0.031664570448018854, 0.1385935179648861, 0.3347478182085099, 3.3393287226077053, 6.272607801421997, 7.65386212256647, 5.958624030313184, 10.503554267268028, 14.376018162696594, 17.915949398471465, 24.25042425432513, 45.6015383812689, 59.194704409568544, 64.01537187637823, 66.96536294875607, 62.202252341854965, 63.91408843378868, 63.22608117134341, 62.66229144988522, 65.12876802875151, 60.445112874431, 56.64287705575266, 49.73439078177176, 47.34533394536665, 50.40571228150399, 48.993910051161244, 50.7796004510695, 54.72626186186268, 57.03346275514173, 59.26163181181877, 61.70763754075574, 57.50478259978756, 56.081036752270116, 56.730514572512725, 56.63410663604737, 57.70246613410212, 63.337229374916326, 59.99023952791768, 58.60792175416024, 50.75104951858521, 49.92930120037448, 46.61697333858859, 49.74372994515204, 58.46553579453499, 61.40383428142917, 60.99722177751603, 60.71709002217939, 56.708659125912575, 59.28082396907192, 57.25720651688115, 62.94352146887011, 36.477748424776145, 48.86241259113435, 63.19917371196132, 54.802332308984575, 47.982479833787494, 54.01990967412149, 62.02857763536515, 58.04363781406034, 59.27131222140405, 52.9230070883228, 56.63352220289169, 58.550623770683046, 60.08591790353099, 54.91601436368881, 53.21423915124709, 52.64889224883049, 51.58960911535448, 52.72486463669808, 53.91512355496807, 52.309148311615, 51.067086650479226, 50.28718217726677, 56.593149246708045, 60.91660922573459, 60.29174820069344, 54.933492445176654, 56.51467438667052, 61.66382466593097, 63.60487230362431, 55.79971259640109, 51.49409547928841, 63.65837735514488, 63.43939535079464, 60.781232541607274, 62.63577622752037, 64.22286525849374, 64.59055216081681, 67.3680805390881, 67.02600279162007, 65.07520414167836, 42.15793271218577, 17.79592094882842, 4.222122603847135, 3.207292672126524, 6.410055006704023, 9.896517472882426, 8.160516638909618, 3.2157451346997297, 1.0252289317788617, 0.0814247965031574, 0.05292524170551089, 0.028323553757922306, 3.020112264540888, 32.59513343534162, 42.34434335462509, 29.887727229825913, 30.64973588912718, 36.742622160142474, 45.87186813354493, 42.022406977991906, 55.32500774629655, 62.10838610126127, 57.73305277670584, 7.6304289025645105, 0.15488420913536705, 0.020895699309485576, 0.03437456817576482, 0.038057892102627985, 0.036095393175679835, 0.057179519471021435, 0.034297419291350155, 0.0185199668105211, 0.07521944601208934, 0.062189431891085646, 0.07862754136083588, 0.0526089814581698, 0.030760707356215968, 0.05462443621288385, 0.04994870666714926, 0.0072428293717694625, 0.0966903777612794, 0.061854299067729906, 0.012481950989533818, 0.035574430404531385, 0.10340345302416433, 0.05816985665249729, 0.01479818335463924, 0.09930108283315936, 0.04354177163012567, 0.08619373213619956, 0.10847444180399181, 0.18792331368932802, 0.07210881494346165, 0.16763543619984583, 0.09053604106508917, 0.19655128700598595, 0.22565017153899516, 0.2717280159554174, 0.16366872485847245, 0.11480524685354003, 0.08285061636519048, 0.09965267888600789, 0.10915541735988472, 0.13168387986238927, 0.1266907256156687, 0.16187036409974098, 0.2993065683591751, 0.10332571042160835, 0.21570339318244688, 0.1606587041169405, 0.18857902366547816, 0.09407319158556, 13.204902372052594, 80.59856460940453, 84.30339228722357, 78.60817355494346, 62.1699712353368, 41.38451191686815, 30.063610230722738, 45.74363800787157, 63.49043715384699, 54.38973819055865, 43.54422384692777, 6.282976096676243, 0.43314467214288255, 0.14356587292446246, 0.25613164559247037, 0.20276424475014213, 3.4918858783860363, 11.85596396846156, 18.20509672164917, 15.86767984974769, 18.238611413586526, 25.759309068802867, 17.490044716865786, 26.9273595271572, 49.02668145395095, 57.09309062650127, 65.0167529813705, 68.00527741832119, 66.70749848888767, 65.82377279958418, 63.03051179455173, 64.60280172286495, 67.00350407631167, 62.64537034496185, 58.37376017724314, 51.76318184021981, 47.77273501119306, 52.62552276734383, 51.61689704464328, 52.53796762035739, 58.162364036806174, 60.24814321148781, 61.427141004993075, 64.3351274151956, 60.195858017090835, 57.44431926358131, 55.14791665538665, 56.69182039076283, 58.716285074910815, 64.38512979015228, 62.31068234289847, 62.56818202234084, 52.24334270723405, 51.78119728642126, 50.02573659343105, 52.87142792055684, 61.10863670226067, 65.57525927020659, 63.018587789227894, 65.14997628427321, 60.04058707144953, 62.772113892339895, 58.50998017095751, 65.52901844824514, 39.98055442687004, 52.071844916189875, 65.38436143629013, 57.31601853524485, 48.946978892049486, 58.068034956532145, 65.24491725429412, 59.536821380738296, 59.61068353345318, 53.471193621235514, 57.851798611302534, 61.18014151050199, 62.161895075152, 57.671875569128225, 57.52466117182086, 54.18140149885609, 55.25031012873496, 55.28961227786157, 58.51181191782798, 54.63323500848586, 52.748579286759906, 51.351838957878854, 60.029063147883264, 62.719985592749815, 61.788430521565104, 54.95485759550526, 56.986684568466686, 64.54047526082685, 66.44371125005907, 58.64321916334091, 53.77326711531609, 66.90609593545237, 66.64659976959229, 63.236271489051084, 65.2354133513666, 66.26392549084079, 65.91319499477264, 69.24851971287882, 71.02441987683697, 67.44323315158968, 42.78562176612116, 24.400529438449492, 11.709533064596116, 18.533797225644513, 22.30768999745769, 22.726893309623968, 9.823510396865107, 2.5038400965352214, 0.6485732236216146, 0.16156166130977292, 0.20456698753180044, 0.16179714141593826, 3.8186874649217053, 38.948798487263346, 50.43150186538697, 36.546107492139264, 39.45097561805479, 42.340232710684504, 53.98303547213155, 51.13071141704437, 62.875660542518865, 69.77696495671427, 66.04575541711623, 10.642368908851378, 0.3496212313973135, 0.17569124908937564, 0.14241022929068536, 0.11227975374147778, 0.16250286161178545, 0.1121860305448213, 0.15829720744682899, 0.14417308953500566, 0.24490969856419872, 0.07566104973516158, 0.12036625611325426, 0.10250016641352447, 0.1317772200150836, 0.07686746967655998, 0.12679280683157906, 0.12306083249108446, 0.18464453398220002, 0.13557274134889727, 0.12106356466369284, 0.11048763659932923, 0.15866597153006062, 0.15285421403185015, 0.12335500259312893, 0.1239357815094052, 0.10136938999376952], [0.008251600065118363, 0.03790598069768279, 0.014840268394759586, 0.05176150435281377, 0.03396769504873984, 0.03812744139483379, 0.058912996413005944, 0.045505021323239615, 0.024161968800810077, 0.02888502917372652, 0.04849837965241844, 0.027190023252079566, 0.03317321973642515, 0.01681239896213576, 0.010174881993612696, 0.03416467923671007, 0.06800302033943516, 0.01610470034422413, 0.05070793044362819, 0.01865232765163866, 0.024835084294599873, 0.050667599744854436, 0.24385062797415644, 18.158965726052564, 61.96552553484517, 64.92443607699487, 50.04861185627599, 36.590155709174375, 24.560016932026034, 21.9288400296242, 38.78537685640397, 80.26416686273392, 62.36204185793477, 13.119919319306652, 0.6789022768216749, 0.005231923264105835, 0.02018092778481303, 0.01806035236034903, 0.506163208835548, 1.342413908531589, 3.305791722189996, 4.657807225181211, 6.964174124502367, 18.5082959359692, 35.1586788700473, 23.04196946082577, 44.827152682888894, 62.60779796108123, 60.19160616782404, 65.30589442099294, 57.92299747467042, 58.1770807696927, 57.60367731894217, 60.55979905589935, 59.38850871978268, 57.1190998631139, 60.47046315285468, 58.82637816090738, 53.39526830180999, 43.70071072732249, 45.176294619037265, 46.04902982711793, 47.8456401055859, 52.86388912508565, 54.624280237382465, 56.87182580271075, 58.62577638318462, 57.892230403038766, 56.97565486354213, 56.38958215713502, 55.66424177538965, 56.85266502441899, 59.72200824368385, 56.23905335703204, 54.636851433784734, 47.526825935609885, 46.18894861590478, 44.9995957651446, 46.62736761954523, 45.32359530848842, 53.073143651408536, 55.79825739706717, 61.752713418776, 53.85952788014566, 57.192314824750355, 53.317962308083814, 63.63882041746571, 32.81089909615056, 44.77525580313898, 64.19908785050916, 53.58140830070742, 49.90530021729008, 46.02342851700322, 58.49323949506206, 57.97288217852193, 59.64694976806641, 54.66282144669564, 56.176020868362926, 58.53489506629206, 59.242698530997004, 56.96107149124146, 51.4610848119182, 52.35749936872914, 50.43955056898056, 53.64641766394339, 54.37121675860498, 52.405924950876546, 51.03826115208288, 49.86966156190442, 52.08922886079358, 57.68122257724885, 59.05484445633427, 55.77942609786988, 55.335464785175944, 59.36789666452716, 61.34033503070955, 54.34374447791807, 48.04681847172399, 60.90792902054326, 62.38500341292351, 59.99577006986065, 63.577447091379476, 59.63825779576456, 61.73723574607604, 60.02713726412866, 62.72799507264168, 65.4904301704899, 63.54964140922793, 48.102088589822095, 22.101271344769387, 8.23278925111217, 7.238874868039162, 10.40630792417834, 15.552808642387392, 11.195238751749839, 1.373341674766233, 0.09884574315360478, 0.06361797902612917, 0.08242381346081534, 0.08364197753009298, 8.10824223103062, 40.14980469980548, 39.62141044678227, 30.339509748643447, 17.529048765859297, 28.42043915102559, 40.10229695227839, 54.90658106342439, 56.15631488061721, 58.80886870045816, 22.79854520674675, 0.6534179636547643, 0.023482333898784655, 0.03723053629660318, 0.03282928839325905, 0.12861793470238486, 0.01436438606751542, 0.03091526176449993, 0.004381561358909934, 0.07179596761782324, 0.036689762491732836, 0.0522009591992584, 0.054861739608308965, 0.031444615113639066, 0.01048902975350258, 0.0619043016265477, 0.013086581095722655, 0.03472279727218613, 0.025748603924688314, 0.05075661533121621, 0.06268861095210718, 0.08034881835262622, 0.059828846865604, 0.08285833087058798, 0.03613048766349112, 0.018989369949145664, 0.05658732201423376, 0.03890480613335967, 0.06668415401251086, 0.06067912402232328, 0.017519143800581657, 0.031576972124317, 0.018847017406275677, 0.05941865274742727, 0.017260811291635036, 0.024638858533674673, 0.02624873676517558, 0.00658861039424195, 0.03969615963738292, 0.016544748908810077, 0.009434289475452275, 0.031575556776876894, 0.031692593944289034, 0.05900926685201065, 0.05481092499629144, 0.052248004658688466, 0.022508456116361965, 0.038687440176163955, 0.22969447226533968, 24.013293443187592, 71.38359131351595, 74.42068253794025, 56.41037856378863, 47.955611598107126, 30.36504633965031, 26.356221245181178, 42.83004260832264, 72.62421346479847, 63.06828421931114, 13.762020141847673, 0.5482426718358071, 0.029730035645526745, 0.09671170564909136, 0.24476666994873555, 2.573760267226927, 5.508793380952651, 10.369262118493358, 9.793756277330461, 9.528707996491464, 9.46205614074584, 23.66415935177957, 26.132312743894516, 45.92861698519799, 61.7608601816239, 61.13455572435933, 65.96010654203354, 60.716650716720096, 61.86682693419918, 61.63647397871941, 63.825313429678644, 61.99780664136333, 60.294285974194935, 62.51202544858379, 61.58669125649237, 54.84312888114683, 45.48353387463478, 47.866491425421934, 48.1835562183011, 49.43427847277734, 56.0780635956795, 57.19413872688048, 59.174413988667155, 60.31035984716108, 59.007932909073375, 56.91986699258128, 56.44368340892177, 56.04838694295576, 57.70917730946695, 60.401025433694166, 58.0362049225838, 55.71091405807003, 49.67113079563264, 47.200680855781805, 47.744027183901885, 48.23031871549545, 47.99089331780711, 55.47437552482852, 58.76027445639334, 63.01543812597952, 56.33240576713317, 58.51289449199554, 54.27925678991503, 64.09794169087564, 34.20122831098495, 47.08760284608411, 65.3388148738492, 55.90406725483557, 51.437338782895, 49.598829746246345, 61.372569068785644, 58.92680652679936, 60.309316496695246, 55.57794178685835, 56.978596641171364, 59.87672221276068, 59.4934085876711, 58.28531072985742, 54.32190864316879, 53.62386403545257, 54.40463535247311, 57.26499634404337, 56.4985102991904, 55.550022355971805, 54.348337573389855, 51.49024763414937, 53.666284468866166, 58.888131956900324, 59.49804875158495, 55.86785201103457, 55.97212037732525, 60.71739988942301, 63.24279831301782, 55.96706444217313, 52.1397646780937, 61.87424413619503, 64.47714467202464, 61.956335421531435, 63.566142820542865, 61.92956524510538, 64.4230277307572, 61.69570176832138, 63.93471617852489, 66.66487016985494, 65.24410532366845, 47.62573242187501, 19.99736297515131, 6.508031400942034, 6.416927979838464, 8.438351846510365, 14.166150766034281, 6.936882272843392, 3.090178788669648, 0.6332916081432374, 0.10841074925396713, 0.01417845652829255, 0.05328030430621678, 9.35342021526829, 40.34229109364171, 31.491682452540246, 24.713573801902033, 23.091797290309785, 36.63972270104193, 47.63499313785184, 61.15484614526073, 61.412945947339466, 68.14390966969152, 29.84292199534755, 0.9034232194385222, 0.024408302457642653, 0.01512147628912522, 0.024267221620726972, 0.04262774446678739, 0.0370265462345654, 0.017371972564667944, 0.024070896268371614, 0.05130855869802256, 0.016003711761215764, 0.030160312758638497, 0.023125344586949197, 0.031548268725014025, 0.07104753802019743, 0.10575320556639664, 0.008656015965126215, 0.05096106887644818, 0.051872299818862835, 0.11166063978547051, 0.026917506625214895, 0.056009557653939536, 0.04583844194008459, 0.040240105046259786, 0.05702163641070647, 0.057455472002226504, 0.12164078893200045, 0.1408869094185291, 0.3688751659806698, 0.14892873354256153, 0.14312164918068918, 0.15317808536271896, 0.12488306454953649, 0.2649570244454569, 0.11659472865322906, 0.16352486886805104, 0.163761819863031, 0.1100216406367479, 0.18649097441905932, 0.09430645003674493, 0.1514857971379834, 0.13806569870681534, 0.1994354548233171, 0.19240236931270172, 0.17977112693892372, 0.12776310315295575, 0.17306690765244348, 0.10289283243999367, 0.4168858349082932, 32.77448185028569, 82.55717662072952, 81.46612228885775, 68.91270991294616, 52.69361511353524, 37.65848382826775, 33.95899057388306, 50.80426039234285, 88.44779214551373, 76.3964117726972, 18.897126374706147, 0.8909753325485414, 0.11998595474588296, 0.2182002269452618, 0.2900550147939113, 2.326891681840343, 5.1153428804489876, 12.724296316023796, 12.535037052246834, 14.440158720939392, 26.348143123811294, 38.09707149382561, 32.24388518641072, 49.19270361623457, 61.33472604136313, 63.53678780217325, 67.18955778306531, 64.26958460961619, 63.43738317489625, 63.21482789131903, 64.86823635716593, 63.17131311662736, 62.312969084708925, 64.04339721125942, 65.08903834127611, 58.53551087840911, 47.47677256984096, 48.67540967079901, 49.520531392866566, 52.86741925824074, 60.15461429472893, 60.25567023984848, 62.08803292243712, 61.65737236699751, 60.336612270724395, 58.72257655666721, 58.33877655767626, 56.66932167545442, 58.30182783065304, 64.29492312092935, 61.0590853998738, 58.49899753447502, 51.83648309400005, 49.50804648860809, 50.82680617609332, 52.31176453251993, 49.16795738281743, 58.20395292774324, 60.42027250412972, 66.47655717788204, 59.15638677535519, 62.06784448316021, 55.85521413433937, 64.18450055583831, 37.45102574748378, 49.9356750519045, 67.89030490383026, 58.379369166589555, 54.79214591364707, 52.37946071932393, 62.153779691265484, 62.66608045947168, 63.466322422027595, 56.85799552548317, 58.1724053044473, 61.13967441743421, 63.34645871193179, 61.803974874557994, 56.031136358937914, 57.91833377653553, 55.90873879771079, 60.392984574840916, 59.2529006158152, 58.89229359165315, 56.2902638220018, 55.913700595978774, 56.67545234003375, 62.34217897538216, 61.176764349783625, 56.96799055222542, 55.541910894455455, 62.60281262859222, 66.54901904444542, 59.17216254818825, 54.01398297279112, 66.27449235608502, 67.3316260307066, 64.60109549184, 67.96215488064674, 64.78072043388121, 68.76881384080457, 65.05340753063079, 66.19714321628695, 69.41188643055578, 72.80150459658715, 53.82014728361561, 27.284756091333207, 14.390013179471417, 18.436614621070124, 22.140108693030573, 28.767963109477876, 21.067495384523948, 3.787517124606717, 0.7151773367677966, 0.23529411533907538, 0.225421448328322, 0.2313278483286981, 12.201605189231135, 55.238707757765255, 54.658204817002826, 42.21905892895114, 26.484635722252634, 42.307194586723085, 54.62671602925947, 70.62895082658338, 68.22097639883718, 76.70058373481997, 35.45704572431503, 1.2422176979241835, 0.14432664419854843, 0.14592344722440168, 0.14140365104521477, 0.24209679224558417, 0.11769555869602388, 0.1714278778602039, 0.3549219776065119, 0.12117181288739368, 0.1859123022445748, 0.1138231987434049, 0.10750405355206422, 0.16031984810627278, 0.1354801059970933, 0.16178479207859886, 0.16063765202078129, 0.16051446508255698, 0.17523072299457368, 0.24279687403430864, 0.21591337788249218, 0.1659184952657069, 0.21776534947416476, 0.20243625186624067, 0.2285307234213237, 0.15631441868120627], [0.021864846498975833, 0.03642324050287566, 0.0741832967727415, 0.05446125182413286, 0.04656970350732727, 0.034197494612946626, 0.06968983103551211, 0.051015920771826664, 0.09475383772364548, 0.05855023845910065, 0.021853686513138876, 0.05182351533984465, 0.024025312121657115, 0.011147263989363228, 0.06579659518695648, 0.02126698382198811, 0.03024721011188963, 0.09487159309848663, 0.01189877421805455, 0.019674344484003323, 0.04329426394354913, 0.04089388831128036, 1.1640538082968805, 37.30857310756561, 66.33188447644635, 61.20473869385258, 52.319868149295935, 34.63004927481375, 27.967264190796886, 28.597510630084624, 33.45159276839226, 32.31563318160273, 25.383751930729037, 3.0733704518887306, 0.0769573547727158, 0.10343535292533138, 0.02579314236138617, 0.2201619942582423, 2.039460885909296, 7.449937116715216, 6.8533465746910345, 5.654727614695027, 6.9988282649747795, 26.090029593436952, 30.114928560872233, 54.091077158527995, 66.88984947819864, 61.140521649391424, 63.65885980667607, 60.87152158060382, 61.59346126740979, 54.624974496902965, 57.251260203699914, 59.380044244950824, 61.619344988176906, 57.12655628881147, 58.62139901807232, 59.67230396886026, 56.42187110839352, 46.39908567551644, 42.269955604307114, 43.31602427267259, 45.79653116964525, 53.50443178607572, 57.32324354110226, 57.652244106415786, 57.07281981745074, 54.39850861026395, 56.55269392075078, 53.942658593577725, 55.57432928392964, 53.995787097561745, 58.69996017025363, 57.35655623097574, 52.03035408450712, 43.97140526002453, 44.10096899155648, 43.15185739148048, 43.905234875217566, 45.23273360344672, 51.28391527360486, 56.67730762112526, 59.316627364004816, 56.8598468842045, 58.28590300775344, 53.95496699117846, 61.29652607825495, 37.51177541671261, 45.194498339006984, 64.2900711490262, 53.95356670502694, 49.3957607976852, 42.916828970755304, 51.3717959773156, 53.90714937640775, 58.82723323760494, 55.62730089310677, 54.26381049617645, 54.96926446114817, 58.83083397342313, 55.56641394092191, 55.33288386560256, 52.24324072560957, 56.38874669228831, 56.53374887281849, 58.5826224665488, 55.240331619016594, 54.00838575055523, 51.58008167820593, 52.93250706888015, 58.36914354755033, 58.48928574592837, 55.05214022051904, 52.75746737757037, 58.07218482417446, 57.92349953805247, 54.59612546428558, 45.452115689554525, 46.97453660349692, 56.44967286817489, 59.865986685599054, 56.56666932567474, 57.33626973244452, 54.8834430017779, 58.36892389482068, 56.6807867634681, 61.82342983061268, 59.7945720918717, 62.105252127493586, 38.82249816771477, 18.99630742688333, 3.5791193910183448, 3.691869392510384, 7.203991759207941, 4.59380591107953, 3.541918896859692, 1.0429077283028634, 0.1439181201520466, 0.11806425383134235, 0.0924067052021142, 0.8963730042019199, 23.89277077490284, 59.22000369717998, 45.837437568172334, 35.078078085376376, 37.88567927575881, 24.962983592864006, 45.519647136811294, 47.76396851385794, 53.87154994472381, 46.41438291918847, 4.135864290498918, 0.20737211039710432, 0.019122996750558098, 0.02366466857042284, 0.038585458551683736, 0.08761664086412038, 0.04755246407923199, 0.05353670627359421, 0.10459695672315937, 0.04210717623091994, 0.07332804387495404, 0.07323892486672248, 0.06939612824710147, 0.06527185560234132, 0.04544536222613627, 0.0785625771048569, 0.04397666825342082, 0.02812439579546692, 0.06873425126316086, 0.03449913790269244, 0.04993249624667149, 0.04549546820682384, 0.00972536075184302, 0.05968225211085332, 0.05605048973173384, 0.05649029697862364, 0.03610065236928002, 0.028943305482126536, 0.036080596187422355, 0.02905028008465325, 0.07537896850056226, 0.03595021568358906, 0.030198525224301605, 0.047827700318227855, 0.031133344013904853, 0.008857120748519177, 0.09559603648320322, 0.059455819503073735, 0.02731578807616907, 0.03140141541558889, 0.04292465716360077, 0.02669106444133626, 0.04547010303565091, 0.04761701081729224, 0.07376816138745317, 0.040688626543288274, 0.05207423676526354, 2.1697264765539477, 47.37892120115219, 76.16292876581993, 67.24175668531849, 61.50054816276797, 42.20458146064512, 31.15102264188951, 31.93430231463525, 33.63529305304251, 43.07238232704901, 30.418924016337243, 3.5186354623686884, 0.11340799441020336, 0.034101273969657, 0.15000737001818998, 0.9975143834467858, 5.394318026881065, 8.9142696895907, 8.72382979239187, 9.970203118939555, 9.011577810010603, 21.600759260116085, 30.417288387975386, 51.47043966477918, 67.43034424320345, 61.78023276790496, 62.13088481656967, 62.691834742023104, 63.46288642575664, 57.25169558678904, 60.35105443769886, 62.23005410163634, 62.84701155078027, 59.26382833911527, 61.21246576309205, 60.8538277687565, 58.35348936819262, 47.823235527161636, 44.83614275532384, 46.87322570431618, 48.65778253924463, 54.92739708192887, 59.60741227672946, 58.815799528552645, 59.49768004878875, 54.94501636874292, 57.184560298919685, 55.22015886922037, 55.47990998914165, 54.703186558138945, 60.48262642275903, 60.70253018409976, 54.249846858363, 47.255252791989236, 46.69629935295352, 44.659977343774614, 46.441721839289514, 47.23311885710686, 54.03965096319876, 59.41686353375835, 61.31439247438985, 58.32538950827814, 60.61461025668729, 54.90534943919028, 60.28237765835178, 38.29970113692745, 46.60011499158798, 64.97428547951483, 54.56288729944537, 52.73113650660361, 44.41871235447545, 53.28084491914319, 55.79044795805409, 60.49247549426172, 56.69420911419777, 55.28516431008616, 55.95526987506498, 60.64048221034389, 56.83057031323833, 56.387158132368526, 55.54026349898308, 57.8624439239502, 58.229397343051055, 59.9073951475082, 58.8366469260185, 54.9072596334642, 55.3073884594825, 56.52806928080898, 60.3047037893726, 59.56274432520713, 55.53927898406983, 53.69230939495949, 60.28061651414441, 60.55340559251847, 57.372751697417236, 47.21275783354237, 49.783514545809844, 58.65245634509672, 62.005674915929, 60.04324251605619, 59.50739968207575, 58.98160596047679, 60.48332068227953, 58.44965411770729, 65.85867404937744, 63.55053570962722, 65.6908985876268, 43.34595587945754, 22.56189488595532, 7.373313125102752, 9.328456290306585, 11.548020647418115, 8.276979654066025, 7.442911171144055, 1.8011740787375359, 0.3775994059058928, 0.033538371715093815, 0.09486640668323926, 0.7693821636419144, 24.458762907212783, 51.987302149495775, 39.10999613423502, 37.508323730960974, 42.138328706064534, 38.037298494769686, 51.67715641760057, 54.9383169604886, 61.04729867750599, 56.65091399223574, 6.725010054726755, 0.24046419759190854, 0.026318247752985167, 0.04653375483148041, 0.012663181536951134, 0.022490504761076262, 0.05036568832433513, 0.031060881672366977, 0.02263829269776902, 0.035883462612306884, 0.05809121389663028, 0.056739455584677, 0.013257468498552279, 0.061710075355104865, 0.024096818768509456, 0.0138140773408175, 0.01594337084585981, 0.03288938799091885, 0.0522818542536228, 0.03664405768617027, 0.027497379642520702, 0.032262034759285955, 0.016924874075958808, 0.031795927713955605, 0.0483352565507014, 0.15863374987196538, 0.15560350440923246, 0.2111918707528422, 0.20085190543003623, 0.1731606614926169, 0.14481318663925896, 0.2065762369743278, 0.13828259351993763, 0.13858817067117463, 0.1507160932787003, 0.12503776068408645, 0.14474449919596796, 0.12216784976302617, 0.15389145111605046, 0.1536682284166736, 0.1112755963338479, 0.13152600446295354, 0.2975244946297138, 0.11799263993218062, 0.18136958471469342, 0.10832685496537917, 0.24290647057275622, 4.295485634957591, 60.02727454708469, 84.25573548962994, 77.04128080798735, 69.57185637566351, 49.67109941667127, 40.394717493364894, 39.28321192341466, 45.0612554242534, 44.34256738232028, 36.35067539830362, 4.878900935572963, 0.3901685798360456, 0.2819374552176845, 0.35657409218049824, 0.8087060696655705, 4.619309161939929, 15.098738401166855, 15.345381940564803, 13.781650623967572, 14.887242240290488, 31.433596072658418, 37.1218918215844, 61.850682458569935, 69.60522005634924, 62.90201494770666, 60.52078716216549, 65.07287033142583, 66.8486959703507, 61.13931748174853, 63.86785937893776, 65.04674342370802, 65.51837313559749, 60.69984728290189, 62.75625182736305, 66.06765793215844, 61.28422552539457, 51.30562167013846, 45.42583973177018, 48.1503455100521, 49.08852938682803, 59.1237840344829, 61.22829252673734, 62.340331539031006, 60.17586569632254, 56.00026338331161, 58.20031296822333, 56.4819618194334, 56.749714574506214, 55.54273851456181, 61.51682207661291, 63.6871361732483, 55.470331561180856, 48.02413540501749, 48.467386768710234, 48.064504438830966, 47.86660909652711, 49.82553097509569, 56.577726487190496, 62.51581445817025, 63.25637755855438, 61.20406404618294, 62.20397818473078, 58.14063018368137, 60.86825816862045, 42.23969844079787, 48.930442179403, 67.4123719430739, 59.75392456977599, 53.05469674448813, 47.08022879016015, 56.2077332312061, 58.74445553748839, 62.816452364767756, 58.067980043349735, 54.46217652290098, 57.217382692521625, 61.076281070709236, 59.883276493318625, 59.041418183234434, 56.922043908026914, 61.31337265814505, 60.87465163200133, 64.11414107968731, 61.248288769875806, 57.753115700137236, 58.168243669694476, 58.44349207416658, 62.53426136509065, 60.80548063401253, 55.12799493728146, 52.58196484658026, 60.168048412569114, 62.82689371416646, 60.04576852244716, 51.47972783734722, 51.16627946976693, 61.21538400650025, 65.18357922953945, 63.01645401985415, 61.56844439045076, 60.65223363138015, 62.62042799303609, 61.657964644893525, 67.88961456667992, 64.58891653245496, 68.38918332130679, 44.081023739230254, 25.22963220073331, 9.733436107635498, 12.255842743381379, 13.397824148977957, 12.090450121510415, 9.775222097673725, 1.8608263423365934, 0.34927140500757003, 0.20445506208606307, 0.22355205589725127, 1.4627125114202502, 31.453356973586548, 77.8982323984946, 60.91924898086056, 46.58374694085891, 46.491241762715006, 37.58616708940075, 60.081815104330744, 64.04031422830397, 68.94132752572337, 65.8748185250067, 8.807632211715944, 0.4078504100682274, 0.12149651159322071, 0.17544358818521424, 0.14885895825441808, 0.2048107260657895, 0.12993660184644884, 0.10434770235611547, 0.2622659107850444, 0.10423676516380041, 0.20297171668179576, 0.14893490821123123, 0.17019701971402093, 0.22379162691293225, 0.1509308890109101, 0.20352850938516281, 0.20081802902202453, 0.17261641730944957, 0.1686493688893895, 0.16694428699631847, 0.1526693263722043, 0.09381488205925112, 0.09752540593786586, 0.23529446773952056, 0.16225671756171411], [0.03364660844747578, 0.06937892957320137, 0.06779873533354652, 0.012872652958087143, 0.038224692426381573, 0.022015922868083564, 0.0038664538935277494, 0.03605905379499159, 0.016929248438006448, 0.019146052166639317, 0.0348661131706209, 0.053881863357439164, 0.00578954765167568, 0.030546175924340085, 0.017943680999920737, 0.04221107690565048, 0.036641675152725754, 0.04160947188915264, 0.056527751017241716, 0.032643856811186964, 0.004764546906845945, 0.11468734592199327, 3.589388156129468, 51.3427508261896, 58.467438144068566, 64.73657807996197, 34.12917044854934, 27.06645461820787, 22.140261665467296, 30.29105082634957, 40.308515564087905, 47.834453505854455, 16.39453947544098, 0.1033098447406965, 0.06475938874627314, 0.031552832693822926, 0.13373325699039046, 1.519469330387731, 5.396308139447243, 7.288755159224234, 11.191696851484238, 17.978981887140584, 32.92880358234529, 30.157313692954283, 45.457909030299035, 65.20559549331665, 58.25698337247295, 65.64828988044493, 62.42807495978571, 62.62972793271465, 59.630244393502515, 53.894507577342374, 49.56318324612033, 56.539805012364546, 60.2471665413149, 58.398000424908055, 55.03558389602169, 60.08816149926955, 57.59780945316438, 50.37015207352177, 41.730009971126435, 41.47025492883498, 49.6979009720587, 56.45149677030502, 57.56634419964206, 55.617773455958215, 57.04813634195636, 53.6929879649993, 54.88151319565312, 55.49610153321297, 54.187559620026626, 55.00545617072813, 57.36303598650041, 53.079062507998565, 50.254979518152055, 44.898124048786784, 44.092222106072214, 44.05781507492066, 43.70579804143598, 45.523800926823775, 49.30000005229827, 54.332683394032145, 59.95714649077385, 55.94549925096574, 56.73684135560067, 49.99373005282495, 60.22585238179853, 39.840031593076645, 43.516708420168975, 62.506475294789965, 52.449804505994244, 50.704251720059304, 43.1825146367473, 46.215499139601185, 51.797435898934644, 57.019495194958104, 57.051282082834554, 53.62915531281502, 53.82581903088478, 57.652177426122854, 57.85900400530908, 57.31137052659066, 56.983707489505896, 58.42763785393008, 55.766046893212106, 57.77411214766964, 57.50444919832292, 56.50145207681964, 53.841163342998875, 52.38714856486167, 58.06381056385656, 56.97931051254273, 54.65440011793568, 53.325516793035696, 57.539232777011016, 59.75886283382293, 54.948844602031095, 49.781569050204375, 43.71418014649422, 43.86618768015216, 48.358140914670884, 50.69390450754474, 49.803820656191924, 49.28465966255435, 50.94921550443096, 53.95107992233769, 57.837230928482555, 60.617920737112726, 64.89587729977023, 58.890591282998365, 35.61327765064855, 12.500896742266994, 4.707080039285845, 10.784844102398043, 1.6764581515904398, 2.398529850667523, 1.4004973466357877, 0.4944242903542134, 0.06809970063547935, 0.023955768575110746, 0.11396235861485043, 2.8589587442336546, 35.15542330280427, 34.13482258396764, 37.00429131907802, 39.300944958963704, 23.349326387528453, 38.493168123306766, 43.006874822801166, 55.280037772270944, 55.81346834859541, 24.016841227008452, 0.21731265279794895, 0.031922226884372296, 0.05528253255291812, 0.03921797904636591, 0.05353816184065035, 0.04010687852578779, 0.04327120852746791, 0.024679321382615357, 0.027478696673267314, 0.04479155980891759, 0.03397345219949081, 0.0372443909967138, 0.03105253131399232, 0.04183236517072205, 0.020788391458711798, 0.07779480378714301, 0.024997686456528403, 0.00429597401600932, 0.0643330148511356, 0.0575185057166363, 0.02006410320679988, 0.05149626556122976, 0.024962394701076612, 0.061036672578343464, 0.09271360002458097, 0.02527619772140057, 0.009355796106730499, 0.009361996630867644, 0.034870912711466515, 0.014595310823361, 0.048911856457350716, 0.0505112603517069, 0.03270159685803998, 0.058248411308253006, 0.035191654573164644, 0.006261965825087241, 0.00507228586244427, 0.04460105289434714, 0.06150959780619991, 0.032706361924929005, 0.027149646588030363, 0.04152114961236235, 0.05117879106452869, 0.01877245981426489, 0.024771012531052676, 0.1596043219849948, 6.908817714260471, 61.43950823814639, 66.94895959669545, 71.63778443490305, 44.054724247224875, 30.84276553123228, 31.475761552010816, 38.29012663133683, 37.86438080572313, 44.4785245772331, 16.292777503690413, 0.17878593786829905, 0.07035450424037634, 0.03636645040504875, 0.6782647078075718, 3.1320405294818268, 8.102281699257514, 9.41244992517656, 11.56085072025176, 11.01902234938837, 24.71422099298047, 31.65917746482357, 49.454427688352524, 65.89597578971618, 62.69276434375394, 67.36565651432161, 62.489165875219534, 63.90425897413685, 62.03870911752025, 56.70859636798982, 52.320868353689875, 59.28663299929712, 61.49136589419458, 61.8739225018409, 58.0196564428268, 61.564776974339644, 61.18023172501595, 53.23466293273434, 43.24904587961013, 44.31463618432322, 51.76192668176467, 57.86885307681177, 60.450357083351385, 57.08521058482509, 57.942181787183216, 53.62515057286909, 55.24299883073377, 57.26429423978252, 55.326729666802194, 56.29827330189367, 59.798004165772475, 57.2283378724129, 52.54490629319222, 46.18761108767602, 45.46540860206851, 45.321218352163996, 45.16828121677522, 46.213071192464525, 50.84845373707434, 56.279924454227576, 59.913404218612186, 57.581217827335486, 58.47567119906026, 51.83653408481229, 59.95876642965502, 41.69296710721908, 46.01073180475543, 64.1735924443891, 54.3143267016257, 52.13929791604319, 44.90285834958477, 48.20984786556613, 52.68018491806523, 61.20930825510333, 58.15249143108245, 54.81574289260372, 54.790067057455744, 59.01282802704842, 59.82846137016051, 58.76564025878907, 59.34789257664835, 59.8980991301998, 58.442283984153505, 59.247848603033255, 58.55945302594093, 57.51131334612447, 57.143112613308816, 56.82304720724783, 59.980723857879646, 56.67211832538728, 54.901368233465384, 54.08466408329626, 58.33952573037917, 62.72470028169694, 57.10610505073302, 51.08603954315186, 45.08275393516787, 45.81362878122638, 50.84042072296143, 52.94696884770548, 51.64000764969857, 52.06611041099795, 53.01952485115298, 57.22769068133447, 59.166267225819254, 63.016716818655695, 66.04959149514475, 61.319781811006614, 35.98467511515464, 13.540080670387516, 5.646589186883742, 13.271776822305496, 9.705090118992715, 6.627463650318885, 4.800038251184649, 2.3177741323747942, 0.37423707664974276, 0.10660892577781793, 0.10385390506276201, 3.511205267521643, 40.04732493431338, 34.57102152609056, 37.431237389964444, 48.70712595601236, 25.03280962667158, 43.04887556260632, 49.977518896902765, 61.08414150053456, 62.63983588064871, 33.86324551797683, 0.40044604770598874, 0.026147389078452706, 0.013019671934025904, 0.08812459546231455, 0.014812068698266822, 0.0100621837566817, 0.07758224503167215, 0.0039987070035309566, 0.06978112573344862, 0.045229968945345575, 0.039164069439134294, 0.07286829152895559, 0.02660900684854677, 0.06812592382512747, 0.028166712577184363, 0.11511701399520521, 0.025532747160703428, 0.046915998231739774, 0.0097066902315184, 0.032690297061156844, 0.039593423416297284, 0.02875160538561402, 0.03489237083422561, 0.02495348318329742, 0.16016378067433834, 0.1688823362271632, 0.16139589520471712, 0.0821650289599934, 0.18721209298218452, 0.1414270167269053, 0.1533785246072277, 0.13013956918110772, 0.09792473692927631, 0.24661651181597866, 0.09501711149970371, 0.11138259583423216, 0.13759202654323271, 0.18851044347449658, 0.1725238738881965, 0.10548587152433973, 0.12658022509347047, 0.1294067447944995, 0.16852711657843283, 0.1508547398712366, 0.18143686255620373, 0.20420574643198522, 10.011816524690198, 76.49188226269138, 73.78428582222232, 83.43679166609242, 49.48115471870669, 41.276819321417044, 31.533287032958004, 41.13007953090053, 50.790218307125954, 63.80420715578141, 21.929828466907626, 0.26670922074587117, 0.30412326957429614, 0.2409989422848148, 0.4208941295021965, 4.3144233284458045, 14.721545634731172, 13.76917846741215, 18.19011130640584, 27.449872186107022, 39.23450393061484, 38.23579788208008, 53.36164966706307, 68.53704883206275, 62.15339137661842, 70.4081606095837, 64.34536872371551, 66.39907467749812, 64.44931937802222, 58.83312463760377, 53.68592769868913, 62.381018284828436, 64.96409908417733, 62.87924951122653, 58.66030500781152, 64.21565201974684, 63.51626596143169, 56.76424303362447, 46.21384782175864, 46.577529984135786, 54.18125244878954, 61.48150505558137, 61.84715624778502, 59.90240981501918, 59.5333069370639, 54.219691676478234, 56.23422491934992, 58.64210521021197, 56.79804209739932, 58.7039609878294, 62.01326470221243, 58.88324860603579, 55.3450628249876, 48.32891925688713, 48.26048174212056, 47.707482461006414, 46.74635664109261, 49.3247345186049, 54.19067005957327, 59.94740332326582, 62.80637187342491, 59.61615131747339, 61.26291528824837, 54.224363219353464, 59.50824691403297, 43.31190186162149, 48.715147203014745, 65.5576595952434, 55.58057761961415, 54.13617657076929, 47.651337654359885, 50.72814679914906, 55.16629688201412, 63.07462669187977, 59.491506238137525, 54.45171556165142, 56.082480184493534, 60.70796266678841, 62.52099198679771, 61.32275104522706, 61.130715723960634, 62.2122504634242, 59.80915938654254, 61.73263872823408, 61.47672760871149, 61.515406100980705, 61.06123093635806, 58.04652467850716, 63.27239259596794, 59.430442779294914, 56.40517750094014, 53.597360580198234, 59.16380397735104, 66.34316521306192, 61.41856278142622, 54.605131226201216, 47.82504373981107, 48.48871661770729, 51.96652927706319, 54.53685845098188, 54.716059777044485, 54.179091222824596, 56.34975048803515, 59.056946846746634, 61.61279462998914, 66.32590678430373, 68.95204344103414, 64.88419255902691, 42.35741269203925, 17.66652587921389, 11.767457646708335, 24.726703936053863, 13.449255247269909, 9.83866153224822, 7.211506530161827, 2.0037010047704946, 0.2778394670496064, 0.2438832633197308, 0.28723501450111794, 5.454608778799734, 47.726039194291644, 46.998278710149954, 48.49993067402994, 44.613407042718705, 35.08598558364376, 52.74823411818474, 58.615974380124, 70.64672700820431, 72.37810827070668, 43.873593115037494, 0.7798658010940399, 0.23417055546756715, 0.13771590296058886, 0.23450449319376102, 0.1526394182996404, 0.12989085107561082, 0.1385603157142478, 0.14411492813979426, 0.10282789882753166, 0.15753562411954328, 0.15327052153166265, 0.15414447463568182, 0.08745825984665463, 0.18052256726209195, 0.11443128869418176, 0.21274994037324385, 0.09142093390466706, 0.12321016601016446, 0.16382215694794733, 0.15849259051103748, 0.07979742656912535, 0.08850570122200636, 0.2035656493277319, 0.1384573534972245], [0.07929451282947295, 0.06376230233018437, 0.003421584720678267, 0.04367261944759277, 0.023088061002894275, 0.003788918374113799, 0.03717088102993946, 0.018017913004563704, 0.02674137152010395, 0.028951791821107752, 0.03081713930793828, 0.08261734259224708, 0.041003557628080736, 0.027628382592792475, 0.03012610501759956, 0.03997425338433635, 0.012450098968862046, 0.05574858214165415, 0.04569711403981332, 0.02152593303171377, 0.02315785544323585, 0.32909981966499363, 16.79027230508866, 54.54208697042158, 67.81613288387176, 47.93903958412909, 52.819982113376746, 45.456465598075624, 20.925538924432573, 32.478929296616585, 37.63090172121602, 38.50201699041551, 1.70521991147149, 0.029215678467505404, 0.07693917550627263, 0.12928709718248538, 0.7561910488913137, 2.530337913382438, 7.146297126047074, 9.971781872933912, 6.327910769370295, 18.06943370449928, 30.82766636725395, 37.940886635934156, 62.530166410630756, 60.10266642416678, 61.90567016601563, 58.930258212550996, 64.49728996522965, 60.14644792003017, 61.654167790566724, 55.90959387440836, 46.69678180448471, 53.79068243888117, 61.442704969836825, 57.42013000672864, 55.71861367071829, 56.84430253121161, 59.073864029299834, 50.24899790363927, 40.514667495604485, 41.40013079489432, 50.79462312882947, 56.94116546261696, 57.470183372497566, 56.80312156677247, 57.16533284033499, 54.82177549792875, 54.52131017561882, 55.97767445348925, 56.77291931644563, 55.70123757085493, 57.89087326295915, 53.480717136013894, 51.5973557964448, 43.24437825910507, 42.2808676381265, 42.28463311349192, 43.56130184665803, 47.4841623152456, 54.9082519931178, 54.679134584242306, 56.842992459574056, 56.32891093530963, 58.715834002341, 49.979303575331166, 59.118590816374756, 38.58987023753505, 42.337628256890085, 60.41779356618082, 53.03478679349346, 49.76743675047352, 42.38921526939639, 42.50041054141137, 47.135644035954634, 57.76264313728579, 56.888617469418435, 53.33932353604225, 51.47761760219451, 56.39232389388546, 52.87291449885215, 57.275304332856216, 55.090002859792406, 55.598855864617136, 55.83640636936311, 56.492599287340724, 55.215016641924464, 57.44131472802932, 55.83438634872437, 57.77840714300833, 57.73837935539984, 56.87184933693179, 54.15318789020662, 55.87911705816946, 56.70589777731127, 58.52598344126056, 56.63598545135991, 57.899522089189105, 52.49801828015236, 48.121112085157826, 42.334207950099824, 45.81134596178609, 46.28090466222456, 45.57474467062181, 49.404005619787405, 53.43700232044343, 54.74360658276466, 57.30948778890795, 59.959868615673436, 60.763723081158055, 55.96127502379879, 26.90760058741416, 17.094489374468406, 10.785747228130218, 9.030843511704477, 8.205203711986542, 3.3602224530712252, 1.0306216391824907, 0.0657700425795009, 0.04963130877924062, 0.07876164505198117, 0.5048856806130179, 15.354786803645474, 42.24914743054298, 29.736090360149262, 12.056887380538448, 27.158640123182728, 27.1262413455594, 39.41066149742373, 43.95353101914929, 52.39637397950696, 38.9178470642336, 6.125593444993419, 0.06215446763822149, 0.08143812643303987, 0.0755529011028909, 0.06808267050092259, 0.10754446469007001, 0.039107754315820434, 0.014940025491429674, 0.017308134457937652, 0.04041886783295101, 0.044860687752765034, 0.03275080268541652, 0.02637699712067843, 0.04752272454601142, 0.06411311697335013, 0.03395790061462791, 0.019666924922456665, 0.03307393857187802, 0.04516457951056861, 0.02315930334941274, 0.014132137894780647, 0.036901076354326746, 0.018658839398995042, 0.04311925498768688, 0.06758488188948363, 0.15991238126110646, 0.04939016345287523, 0.06694178938144638, 0.02206996462548212, 0.029543117852881554, 0.09156456006871116, 0.03490663922181533, 0.052525213574089354, 0.0297920236499199, 0.06485031572200599, 0.04683140680314072, 0.03928354851180508, 0.06670954982720076, 0.05289042683979196, 0.06439026460171708, 0.05723839332800239, 0.08005899962999168, 0.033110051956628604, 0.04888151171466997, 0.05176803525236826, 0.4013557005072794, 20.8067185648026, 66.02738303522911, 71.52241183865455, 58.03868386053271, 54.08085153948877, 49.93650267201085, 29.311544779808294, 32.80919678749577, 39.30685989318356, 38.35925448325373, 2.495182444972377, 0.08737144676307518, 0.08924785655953231, 0.31950846014003603, 1.5977539554719002, 6.532484927485067, 8.727902193223278, 7.832000976608646, 7.994668531802393, 16.142565434978856, 30.510385844015307, 44.37620955128824, 63.688854171383774, 64.26775286274572, 62.37660561838458, 61.740134377633375, 66.8886649224066, 60.72662922643847, 64.21804074318179, 57.0521685384935, 50.11359768529093, 55.73059651159472, 63.13978902755245, 58.49060366230627, 58.37982808389972, 58.78404401963758, 61.69865923543131, 53.253937459761104, 44.57514039931759, 43.57791700670796, 53.00787933411137, 58.436204310386415, 59.75230463089482, 58.59559766707882, 57.61148675795525, 56.8443182206923, 55.45406941444644, 57.59272998379123, 57.84444808959962, 56.98721801081012, 58.54665433206866, 57.772711861518125, 52.389148973649554, 44.24130747395177, 45.79100455007246, 43.685417406020626, 45.50335753348566, 49.07800174528553, 56.68882369995118, 57.38343231139645, 59.23037836628576, 57.90788066002631, 60.51030658906507, 53.04095275940434, 59.34960665241365, 40.48020947364069, 45.00421239483742, 62.043514020981334, 54.864250844524754, 52.19494065930767, 44.19674150405392, 45.25580498480028, 48.57889583033901, 61.010318571521395, 57.57329856195758, 55.422486489818944, 51.803958800531205, 56.095067070376494, 54.3657450522146, 57.405291680366766, 57.007025980180316, 56.32122701214206, 56.6899964886327, 56.946131183255105, 54.79003960086454, 58.69144862697971, 56.56582209371752, 59.38210348929129, 58.62419566800518, 57.77723435432681, 53.90727881462344, 55.41426520193777, 58.208412662629165, 62.48905212648454, 58.28595399856568, 59.12357222649359, 53.12842553661716, 49.27287686255671, 44.642734604497115, 49.6283769607544, 48.07606758609895, 49.97508310502576, 50.28806078818537, 56.1130315257657, 56.933905155428, 60.49425625031995, 61.82653634778915, 67.51239238246795, 55.642676584182254, 30.62691357827956, 7.102946110310094, 13.236069525441817, 12.865989977313628, 8.34372760788087, 8.283760451501417, 3.176088256220664, 1.0215156116793234, 0.21083646724301003, 0.03666288812734908, 0.3159272135986436, 18.01384391323213, 41.14429027803483, 28.420927486112042, 18.104095689712032, 33.444234401949, 36.886820254787324, 48.28700873159593, 50.7805771212424, 58.605646779460294, 48.50321762023434, 9.462525844573975, 0.022332077778335062, 0.07245395287510849, 0.04532104147778404, 0.0398106629689855, 0.02736236430674551, 0.02321786694078436, 0.061426634314439954, 0.01185563676464822, 0.07721044724026034, 0.05349423435907211, 0.008688754732570341, 0.03922193972093444, 0.08200616530713536, 0.04710200054931545, 0.036910219613703034, 0.05508382466711825, 0.0495180158665584, 0.04667203753225265, 0.038883099032025185, 0.049533322303285526, 0.015896124288349623, 0.016316425979077336, 0.022585344530882377, 0.10653409430937422, 0.26292738174238517, 0.17344031422849626, 0.1882335180116277, 0.10019946648108383, 0.0824561270494615, 0.14466001501967832, 0.14740441775610372, 0.12315017366481405, 0.1030908738292994, 0.12206987477838994, 0.12585570509996147, 0.14839818701148033, 0.1865653155912315, 0.08285250860236346, 0.12083383787783886, 0.08590733782658655, 0.1910395295389237, 0.11261256531842294, 0.2127738116729644, 0.21304721313138164, 0.8663188233490914, 30.30204522994257, 73.15959345909857, 82.40846387801632, 65.59554184636762, 66.18807469644855, 56.51535295671033, 30.39466415682147, 41.46514015813028, 50.27262233918714, 48.98740283904537, 2.8275810085958053, 0.36628241800973493, 0.1702049257413995, 0.3543838774484973, 1.7387093531508602, 7.577780398630328, 16.182703048952167, 21.445811910014, 13.849576269426654, 24.036435427204257, 36.34630980030183, 48.440765642350726, 69.85259609837686, 66.23155809217884, 68.1499501197569, 62.91943027127174, 68.19705778552641, 61.72260922770347, 67.83881987294843, 60.678093817926225, 52.7832922627849, 57.5586877330657, 68.01580505986368, 62.94088171374414, 59.608279120537546, 61.73210136352047, 65.38706394933885, 55.54380932161885, 45.94838573086647, 45.27395379158759, 57.297595162545484, 62.123130290739006, 61.181435892658854, 59.9765504560163, 58.454439409317516, 58.58184975962485, 57.73156227604036, 60.28364066154727, 60.58784400263141, 57.8729009628296, 60.80717902029715, 60.94136722626225, 55.74849820906117, 46.43662668043568, 46.96984544877083, 46.3306010923078, 46.42619709814749, 50.76984551645095, 60.85554576689198, 59.639587479252974, 61.62729563251619, 60.21372049085556, 62.906396235189135, 53.882093275746996, 59.44638721404537, 42.01022801860687, 47.94426025882844, 63.34377973310409, 56.778273351730846, 53.73639291332614, 45.75040801878899, 46.422443389892585, 50.95488332932996, 64.48642499985235, 60.20262802800825, 56.11975054587088, 53.37035340647544, 58.95434941014936, 54.826752985677416, 58.34634673210883, 58.49594985285113, 57.44698255292831, 57.262721369343424, 58.183705652913744, 56.52899103779947, 59.825692176818855, 59.735893434093846, 61.221471525007686, 61.164891335272024, 59.6517115254556, 53.60362460536342, 56.23215390789894, 60.01172234935146, 65.28245825921336, 61.54844030257195, 62.64659804682579, 58.02097828157487, 52.84153161510345, 48.26703210030833, 50.986109318271765, 51.596830198841715, 51.05625698643347, 53.50492600471743, 57.03021111026887, 60.637658103819824, 61.15416757522091, 66.39841571930917, 67.50794441469255, 63.71072138509443, 35.86717659427274, 26.700911291183967, 22.954326060510454, 14.275947713082838, 21.337356413564375, 8.982167878458577, 4.189068300108756, 0.47473849668618173, 0.2958489377652445, 0.1461167465294561, 0.7443614868867783, 22.41362144870143, 57.677602229579804, 41.078374847289055, 20.15777614808852, 37.593772565164876, 41.67453588977937, 53.999207404352006, 61.382531889023326, 66.42983390438941, 59.672923703347486, 14.652033390537387, 0.2003829370463087, 0.23278326216724612, 0.2623137453150365, 0.10532404311121472, 0.170797448785555, 0.19082439672802726, 0.10467765642510307, 0.1172034391352246, 0.09886507921281362, 0.21362867386591053, 0.13428784336053556, 0.11156507797779576, 0.09731527568111498, 0.14399998430763522, 0.0927091337319824, 0.13450441641672967, 0.14640953001235762, 0.1914365622665613, 0.21966425161207878, 0.1595635661074231, 0.06622532097202155, 0.06028241305161388, 0.08916110476298679], [0.027101831210236398, 0.008563322199117995, 0.04200590706820931, 0.047872378565971895, 0.025837652069786866, 0.09046107170081909, 0.0031219162619597614, 0.03873386510437535, 0.03869470268968613, 0.03550933591360527, 0.022920262849619313, 0.028810379651164817, 0.07217315100734273, 0.05727324266767791, 0.011878514065287046, 0.03140429399096437, 0.07083688682365803, 0.037184498242793546, 0.0114046934721691, 0.003070501467934059, 0.03183745350989123, 0.6430966755555523, 30.10191805901066, 62.2378517735389, 54.318421656085604, 37.16381803635628, 36.54632322249874, 22.185517972515477, 25.20950455819407, 46.879379903116536, 49.5367778501203, 19.5059625564083, 0.16667569657006573, 0.10444745466473604, 0.030158608213006973, 0.3201105133179696, 1.993094793250484, 4.099250680977299, 4.609968037374558, 6.376749671274617, 16.117386760250216, 28.564044967774425, 33.767355334374216, 54.753106563322014, 63.40258390672746, 58.822169457712484, 57.74041506551928, 60.70333426998508, 61.3214841196614, 62.80085702096263, 60.23866676515149, 56.75883016278667, 44.01673216973582, 50.672868836310606, 57.63723319576633, 61.571923532793605, 56.68881193284066, 57.17574281077231, 59.6531431905685, 52.37197291466498, 43.08185092864498, 40.72777378943659, 49.716975458206676, 57.48137389459918, 58.45018363768055, 55.66610882359167, 55.66359066194104, 54.51146894885648, 54.402819295083326, 54.444015949003166, 54.792757803393954, 53.623283524667066, 57.609231395106164, 55.30815724403628, 49.952878567480276, 41.9298743432568, 42.45944138496153, 39.57794274053266, 46.042295117532056, 52.39913532810827, 55.75079671798214, 56.65170631101055, 59.471270730418546, 57.15526411610266, 56.80172912536129, 49.03605199629261, 58.43824394287602, 41.15067589667536, 44.034457360544515, 62.3495844102675, 53.95894427453318, 54.450330964980594, 45.19358050438666, 45.26959211595597, 42.59355898826353, 55.06179709588328, 58.819062940536014, 57.984441403419744, 53.42844370872744, 54.655568984247026, 53.21428621968916, 53.97967400089387, 52.5131154829456, 54.106013544144176, 53.82581903088478, 52.07879535613522, 52.25644342360958, 53.6605695755251, 54.05677210900092, 57.09530284327846, 57.467190604056086, 53.45982659247614, 51.766092238887666, 52.23918891722157, 51.99830439782912, 58.724427915388546, 58.037550295552904, 61.74199750346523, 59.530977049181544, 61.24764550116755, 49.832861884947754, 45.42200757611183, 44.14353455266645, 46.132611613119806, 51.49008681697231, 57.91213643166327, 57.711507197349306, 56.98015382212978, 57.068481676040165, 65.16625019811815, 59.09450354114656, 51.16220412715789, 11.456538227296646, 16.626544729355846, 15.201135796885337, 3.776275366544724, 7.561950693207403, 3.9477827183661924, 1.792847009435777, 0.10434142809601561, 0.12578419845310912, 0.12995829745646448, 3.927795545708749, 28.356869297642863, 47.83262568135416, 35.27662454112884, 13.913469718348596, 17.183283990429295, 30.096609130982433, 44.51824641996815, 54.2638732540992, 50.43871902650403, 17.732092219014323, 0.50751538466542, 0.03064925113933221, 0.07592601656553245, 0.06844916696389837, 0.041639100339624195, 0.07803834313827177, 0.030715050431148663, 0.029773827146498427, 0.04434123417482742, 0.031755258021275365, 0.01569633813379633, 0.022047744245238362, 0.0029323269770811164, 0.037087400428830616, 0.054084620017918854, 0.0537242484278977, 0.04365889115198966, 0.04156492770679536, 0.051789914723485715, 0.06954107208237534, 0.04425017313370782, 0.11467961609483728, 0.014017819381889798, 0.042419985252162146, 0.0266218981930926, 0.05194011392192014, 0.012908931051741445, 0.03925698824347027, 0.06508306855516088, 0.12069496911980453, 0.014809126920637586, 0.06264673658616601, 0.05222306466631351, 0.06355307222674451, 0.062276628018627246, 0.14976056713250377, 0.047437049102999514, 0.040752116080013015, 0.05103930177527571, 0.08175616017392567, 0.027572843133501952, 0.056905757951279806, 0.02655137213878334, 0.018732764968468298, 1.1263152139802133, 38.73101672818584, 68.76104754786338, 61.620239288576194, 42.4909419398154, 44.54729549346432, 31.95727759791959, 23.435795037977158, 38.17027861072172, 45.437799038425574, 19.756219579327492, 0.18726601025029538, 0.12642152231907652, 0.02539135031251898, 0.40617764176380255, 3.0354178432495367, 7.939562662955254, 6.637807430759554, 9.444709458658773, 10.86425248653658, 25.79765219842234, 37.724811107881614, 57.73820284874209, 65.54431961428735, 62.86292852893953, 59.471125602722175, 63.26205715056389, 62.56326729251493, 65.06788499893682, 61.57006432933193, 59.33024975561327, 46.96174183199483, 52.11341027290591, 59.8356314628355, 62.755588946803925, 57.786102833286414, 58.390900934896166, 60.52098720304428, 56.56686152181318, 44.91697495983493, 44.06403203164378, 53.157239267902995, 59.99267924216486, 58.47327463088497, 57.69180120960359, 55.64366894383585, 56.32384715541717, 56.62423403032365, 56.1683447899357, 57.085846008793006, 54.91837955290272, 58.8291669660999, 56.39834473209997, 51.52938112135857, 44.673289868139456, 44.35934335954728, 42.42177486419678, 49.25039383672899, 53.825183606916866, 58.46153105458906, 57.84652302342077, 60.19815652601181, 59.22624811049431, 60.07193857623685, 51.62988008991365, 58.304667626657796, 41.76997107844199, 45.28072380250501, 63.594721209618356, 54.05549733869491, 57.14645839506581, 47.074278554608746, 46.19514203840687, 44.732105808873335, 56.49399565112207, 59.888661907565215, 59.705098905871, 53.18620597162555, 55.10064032769973, 55.53459959645426, 53.92760061448621, 52.35346324982182, 53.6051151060289, 54.15285448874197, 52.532397854712706, 52.60238470569734, 55.0261192167959, 56.91004930003997, 58.756607040282226, 59.43074872416835, 53.84807063687233, 53.15411313887566, 52.72606095960064, 52.26152289298273, 61.49605312655049, 59.84081291383313, 63.912280221139234, 62.160035871690326, 62.63730202951739, 52.76724192403978, 46.61239985496768, 46.12266055999264, 46.45500690706315, 53.372851956275206, 60.25908662426857, 61.25001461275163, 58.046661961463194, 58.782569208452784, 63.895606225536724, 62.61017491740566, 49.5992886635565, 15.3061641223969, 5.66134024050928, 10.568755826642438, 10.38266093500199, 8.831949926191761, 6.941312099656751, 4.231046486285425, 0.18747525950593336, 0.050823054306449435, 0.08250193144645422, 3.582971158527559, 30.797419009670136, 41.247472147787775, 30.492807742088075, 20.200110289358324, 26.27380636430556, 36.75311842272359, 51.54490586250059, 58.669236244693884, 59.849763762566354, 25.468996801683982, 0.8540199865256587, 0.036516469572820974, 0.03047470566666415, 0.08065602727114193, 0.03652220757137384, 0.06555107166810382, 0.044684204077648546, 0.01745902888116337, 0.023007744344912713, 0.015291315109108486, 0.043168284614840825, 0.04366357577964664, 0.03330954508255086, 0.05431749542514163, 0.042411757467855374, 0.006111360600052943, 0.03924835060212401, 0.03159857580378171, 0.08964917171866664, 0.06078243480935212, 0.025436436502082695, 0.03388417614323478, 0.06192007537690863, 0.2635829691444674, 0.19902777347353198, 0.18107854791225927, 0.11822232075275914, 0.09946141737483202, 0.21079296877066936, 0.1461636157886636, 0.10543677294927259, 0.1150047438099019, 0.203834408293328, 0.11963834235024069, 0.09893005112967185, 0.1490428193562454, 0.23294766463579672, 0.09831914963621287, 0.10377641526922103, 0.173941029295806, 0.09087818359295208, 0.11156042782409538, 0.15198353978414691, 0.15712478648751013, 2.713459158135999, 49.950046616215865, 77.10918488041048, 70.40324195738762, 51.404253590491514, 50.9658855776633, 32.177455925172374, 36.238887848392615, 60.233885395911436, 62.42117943302278, 25.719789228131695, 0.4686997933012824, 0.37011003842757595, 0.20490248807735983, 0.7745526442604681, 5.624327284674491, 12.202075873651813, 14.768412074735089, 14.994090545562008, 23.81202486253554, 33.42821544216525, 42.40300632292225, 62.387403903468964, 67.25456714630127, 66.08047623788157, 63.58500157633136, 65.79696732182657, 65.58676750429215, 66.91796502759381, 65.44822938980596, 61.02672192358202, 48.7891270268348, 56.41357529547907, 62.028765909133426, 65.69333830187398, 59.38097384668166, 60.55582177254462, 64.89595574717369, 58.50696779066517, 47.429468785562825, 46.095047073979536, 55.173514043131185, 62.43361334646902, 60.19504216409499, 59.04321070640319, 55.98629974549817, 58.91205841495145, 57.93716899810299, 57.732350672444994, 58.25024474051691, 56.35536339975173, 61.03611207777455, 60.72780593749016, 53.909463574809415, 47.96553911701326, 45.530359129751886, 43.844340078292355, 51.18379285258632, 56.49728259732647, 60.03858666266165, 60.47115349000501, 64.18518697061847, 61.81690692901612, 61.01514700920352, 53.811086608517556, 58.226796811626805, 44.62154203845609, 48.98166441148328, 65.7321423099887, 58.30504809656451, 58.40004397976784, 50.58576868426416, 48.23813992161905, 47.129313330496515, 59.833948766031575, 62.624875960811494, 60.717188081433704, 55.00784881653325, 55.801779685481904, 54.50227491317257, 53.240923035529356, 53.269018973073656, 53.412397292352495, 54.99327721134309, 51.16760915325534, 53.302786657887125, 55.873143288397024, 57.764459194675574, 59.90371988665674, 60.185746146786606, 53.484725798330004, 55.53334443799911, 54.70495946945683, 52.586848197444795, 63.619322315339126, 61.69710597684307, 67.14942409146217, 64.92725626114877, 68.83021462348201, 56.27824567979383, 48.79823477037492, 48.21617857102425, 50.07483290087793, 55.07649421691895, 63.42526305106379, 63.50312994372461, 60.23773324105048, 62.687143587297015, 69.85909938812256, 64.2504708997665, 58.58882373379123, 17.346397715230143, 29.993242909831388, 32.246742633081254, 14.767003943843228, 18.967250508646814, 8.634337975132851, 4.88330771846156, 0.1349590895997901, 0.3176733118391806, 0.18822627081986398, 5.280402591151576, 38.188627458387806, 65.98803381766042, 48.212997528814505, 21.872687378237327, 28.28316992329013, 43.520901433883175, 59.71651692544261, 68.06083386944186, 68.53638202913346, 34.10913105933897, 1.5254459193637295, 0.14934162429023176, 0.13151569291949272, 0.16222651837573898, 0.11037766467779876, 0.1624788524162385, 0.17639555968344214, 0.16764040044959516, 0.10017367996155255, 0.11309100254889458, 0.17312781164242377, 0.1689905231638301, 0.1464227526899307, 0.30859820364463714, 0.11968875093565834, 0.10018317179093439, 0.1798431238820476, 0.12652128994945558, 0.21617873541770444, 0.17800838926867132, 0.09637291092545756, 0.18236655621759354, 0.11546306357148195], [0.04539078612241053, 0.04338557396324412, 0.013016022482676613, 0.03541081317610318, 0.02837436645472002, 0.025891709148943908, 0.05276838520301446, 0.03518288286643163, 0.1000940451218236, 0.1073521229949209, 0.07241996921478741, 0.0696262763813138, 0.022646112540256114, 0.04896164834198933, 0.09320988710368834, 0.03254185603450864, 0.05428145481874386, 0.07110246652436834, 0.08011329228118544, 0.09656995640046175, 0.04825035102605339, 4.342275588743148, 49.14554103728264, 62.93168375569006, 54.661346635510846, 37.46428335866621, 20.210686960527976, 20.36524207361283, 37.62646159818096, 37.11349010467529, 43.39388332059307, 4.817066730991487, 0.033804380425041726, 0.0010516925648252871, 0.2360410204217319, 0.12972205126237485, 2.900266940555265, 5.156219861199779, 6.481638262348791, 4.453870942515712, 22.002559015827796, 32.92056660498343, 43.75581610587336, 63.04800948789043, 59.88783036508868, 58.025237975582, 54.73806427371118, 56.48986539533062, 60.71562697810512, 63.81341295857584, 60.22354210576704, 55.32068921673683, 45.64672016328382, 49.18591007109612, 58.643187784379535, 58.031878548283736, 57.96362146254509, 59.08342676777994, 57.80821715631793, 54.71218839768441, 44.28735609977476, 39.54780324812859, 47.83757571251162, 54.509217508377574, 56.72442313163512, 53.88329352101972, 57.16225377974972, 56.789150084218676, 57.27679875589187, 53.97886991500855, 57.443177853861165, 55.11188576298376, 55.25864516535113, 52.179435530016505, 46.29576652280746, 41.911250929678644, 41.90234714938749, 39.83906276764409, 47.32906395389188, 54.27203962879797, 59.11854767030286, 58.08036688835391, 57.518534429611705, 57.4414873123169, 54.46094489866688, 50.308998400165194, 57.76774614087997, 36.637938022613525, 39.05855424942509, 63.05199069361534, 51.361535056944824, 58.16085784666, 48.22999315877115, 46.365274844631074, 39.17624496644543, 45.60161682867235, 52.8437202976596, 58.77810162882651, 57.206203937530525, 56.16800354373071, 51.42383406239172, 53.47458647143457, 51.56321548646497, 55.007766446759625, 51.96700780622421, 53.59493263306157, 52.019822520594445, 53.3229947090149, 53.30859176574215, 56.29915191281227, 52.92845918286232, 52.08957010699857, 47.69186750535042, 49.129843711853034, 55.402945241620465, 55.08872024474606, 54.7887412963375, 57.10632862583284, 57.97833427306145, 60.06536076145788, 56.946609712416134, 48.37586218310941, 43.53069951457363, 44.37943766194005, 54.202397946388494, 61.28062086720621, 58.12953772083406, 59.12589034726543, 53.01048771027596, 57.47641994107155, 62.1162582981971, 59.597457301232126, 29.38393408252347, 11.618759612883292, 8.300162822969499, 5.250960300045629, 7.434945327620353, 4.2196951470067425, 5.359364315386742, 1.2970043838985506, 0.13500067285232006, 0.0920552547059713, 0.2840978844511894, 12.203211399816698, 44.494280738215295, 29.484788025579146, 26.01923865656699, 26.117484223458078, 19.54384284634744, 32.021439729198335, 42.38153526859899, 54.31072988817769, 36.854421477163996, 5.3162854140804665, 0.09076496345862266, 0.017998563538816188, 0.06239078278022428, 0.028319388154834032, 0.037064739548030405, 0.04115209441571947, 0.026670211528037346, 0.08113218922047846, 0.07984041942343598, 0.017257247067567323, 0.009183287470331116, 0.04292142044212069, 0.0523317878645274, 0.048520454475956584, 0.036260385531932116, 0.014690642804658462, 0.03241858482661267, 0.03089256066408369, 0.024751693708822135, 0.05087242484272969, 0.07792014343243453, 0.06865354390033791, 0.0967394533537088, 0.03973295100994649, 0.008007577599792351, 0.06051110178833047, 0.07569072032046896, 0.026585754164825046, 0.04801896182940372, 0.04914904877002682, 0.03217749312640198, 0.05614635031369906, 0.048168517513981754, 0.03543909331182799, 0.043605337775642836, 0.05593976321359796, 0.03521811525006929, 0.056252051295051654, 0.0723207072024384, 0.07272926189245717, 0.04779469725044985, 0.0499804456898522, 0.051460355189779115, 5.64220642851245, 59.78967305152648, 70.4050305581862, 63.01510864688505, 42.27044982294883, 25.347275849311586, 22.116931407682358, 31.927361680615334, 38.552623410378736, 43.273533236595895, 5.63872532498452, 0.034360035487841216, 0.04601198000713222, 0.38987146029549263, 2.389623618895008, 5.70336990779446, 7.457171438201782, 9.373234068193744, 5.7528682581840025, 22.323416740663593, 35.29496554405459, 49.03546756313693, 64.47694070877569, 61.9162291865195, 59.519782604709754, 56.07549836558681, 58.13168717968849, 62.65602350234986, 66.096965882086, 62.345418853144494, 56.7119146931556, 46.23325178700109, 52.00544311154274, 60.27344249909925, 59.49729173414169, 57.16875706949542, 60.44428133195447, 59.65736758324408, 56.06804978462958, 46.21146302069388, 41.903512093328665, 50.962665311751834, 57.16818832582044, 57.98229194456532, 53.423607426304976, 55.9213335283341, 58.927438028397106, 57.88820605124197, 56.79289202536307, 60.37037603316769, 56.43258310133412, 56.42865680879163, 53.06579705207579, 49.35839629942372, 43.136811179499475, 44.34897261281168, 41.029149101626494, 49.87774164445939, 56.41539527523903, 61.370662796881895, 59.85361945244574, 59.72342421931606, 58.86838674545289, 56.9166624161505, 51.544862716428696, 57.90406419384865, 37.67666009164626, 40.53955101197766, 65.51527446316135, 53.11928641411566, 58.433227231425626, 50.971851502695394, 48.17813550272296, 42.076727882508315, 48.38700955913913, 54.19420019272835, 60.853341394855136, 58.82339323720625, 57.79798761490853, 50.73720747424711, 54.72141773469987, 52.84618354612782, 54.97505387952251, 53.2421781939845, 53.75791495846164, 53.049291718390684, 53.9360886235391, 53.84736461024131, 57.64118694490003, 53.49855607555759, 52.12355744454169, 50.6120171854573, 50.47430669107745, 54.5774902835969, 55.33718278331142, 55.971610469202844, 59.448540595269975, 59.42636743668587, 61.49983429139661, 58.82647622016169, 49.506924690738806, 45.40182698157526, 46.02597021287488, 57.765133842345215, 62.453688037010934, 60.80920296330606, 61.769512930224025, 55.132580188012895, 59.844735284005445, 63.21154878985498, 62.22925786049136, 30.917988746396958, 12.301493248631878, 12.070524481035049, 9.98803029137273, 10.752548286991736, 10.33884806017722, 5.3414332001439995, 2.9059146633071284, 0.2253211367755167, 0.07650729343895951, 0.2648673308712821, 14.408751322377114, 42.76713171312886, 29.56145271178215, 22.755030432055076, 29.621080583141698, 27.89061519407457, 40.06886659129974, 51.29602755269697, 60.414792952998994, 45.43623401272682, 6.688008375706212, 0.05265843626412173, 0.012624286295425509, 0.03749311676308994, 0.03800884332327593, 0.033085016203263116, 0.024731620289986173, 0.012413409102948443, 0.028080556413999973, 0.06514602566077825, 0.011021266466066723, 0.016549594414931153, 0.04537064950132082, 0.14514076583568128, 0.05322935562881251, 0.04852674405781492, 0.015122134167130197, 0.016704143077555685, 0.0447393011211628, 0.04933301329372391, 0.03050603674754741, 0.03778750520019281, 0.04011874139729527, 0.16301134481064736, 0.0712402321157917, 0.25680112982949904, 0.08956557620436915, 0.09997642764280881, 0.08970861248071156, 0.14362026516708637, 0.18954950384795669, 0.15938804004221194, 0.1759392623939822, 0.21753625854128794, 0.08337158679721818, 0.09147090581996788, 0.17185575328767302, 0.21128456739168014, 0.10272714294373028, 0.15874912271336203, 0.15449682911557538, 0.1512385652430596, 0.17079928739657327, 0.19624431557472677, 8.379843811835013, 70.38534025992118, 78.60122311499812, 71.75907196537142, 52.443434576834406, 30.93544525484885, 31.56583878301805, 50.096005855068086, 52.87631911616172, 57.74509837550502, 7.230948248217183, 0.12741359085926127, 0.1968471041970676, 0.682808528504064, 1.9908011872922222, 8.898161495885542, 14.588279185756562, 18.1052763231339, 12.214061656305867, 29.766626011940744, 40.60280315337643, 52.69283063950078, 66.51837748865928, 66.32249432225382, 63.13132063035042, 61.03717111772107, 60.469953244732274, 65.88324377613684, 68.76813919313493, 64.64423764136531, 60.911070839051284, 48.961028822006725, 54.289988394706484, 63.373601513524214, 62.54391039571455, 58.23840310496669, 62.807999657046416, 62.64194219343124, 58.367088225580034, 49.57566422800864, 44.71361183351086, 53.1980711413968, 59.561120463955795, 58.77386154667024, 54.890244391656694, 57.99791082259148, 61.781511460581136, 61.45011040472216, 59.09442509374311, 62.432648443406634, 59.627530113343276, 58.92591614877024, 55.87962304392169, 50.37691816206902, 46.40061539988364, 46.70266143737301, 43.568766117095954, 52.39163183396863, 58.17524902282223, 63.032814225842884, 62.04751483855709, 60.38445734208631, 60.198552685399214, 58.52130405364498, 52.45877888894851, 58.88092656289378, 40.14263460713048, 43.17316762862667, 66.37841163143035, 56.014838910871944, 61.41764886917607, 54.07730963922317, 51.11584955646146, 45.5300453401381, 49.93283525589974, 55.906726621812396, 63.23658527866487, 61.94794154936268, 58.111318311383656, 52.44711376005604, 55.00312628284578, 53.50421605571624, 56.055255013127486, 53.46316452949278, 53.40146172431208, 55.453626186616965, 54.58659018239668, 55.98045933631159, 57.435258588483265, 53.98779330715057, 51.91598561502273, 50.23612860710391, 51.00089665382139, 57.13720552382931, 56.486299960843986, 57.53359240870322, 59.96227302858907, 61.24090686921151, 63.222613796111084, 62.96028567898659, 54.37556666712607, 48.53236083061465, 48.933254518816554, 59.99773125494681, 65.84729917587774, 63.133811335409845, 63.95008010248985, 57.03782443077334, 62.01229979915004, 67.76387906843617, 65.16636394685315, 36.93475161829303, 17.78074137626156, 19.669490091262325, 15.370484129075082, 17.682487964630127, 13.673769754748191, 11.51201525042134, 2.6241090364994544, 0.3404476655827415, 0.29047437132366244, 0.5043365181453767, 18.96506770964592, 61.48509010191887, 44.08408711033483, 36.33469173985143, 36.24617953454295, 29.896089723033292, 47.4853664828885, 58.61226774031117, 69.9793121891637, 56.94970838485226, 9.952158254961814, 0.18276688312330555, 0.12647482671684798, 0.1655831019724569, 0.12107236701394282, 0.13158473276322888, 0.17296835810186403, 0.09054230766430979, 0.23448356367166967, 0.22774192865096757, 0.09308163632428454, 0.16342149296354863, 0.14245311489268658, 0.24848618003870213, 0.16922903697817557, 0.12050588329833363, 0.12034200943045079, 0.1460669354926194, 0.14758526047150936, 0.17806491123572474, 0.09161030317866996, 0.15849666609879465, 0.16851121259312477], [0.024269041079547138, 0.058717686127150254, 0.054965146156328346, 0.033724496606737375, 0.024923605754250483, 0.058818434350072384, 0.06349247467193393, 0.016548659787663532, 0.040374859912140716, 0.04554921310515173, 0.02072475061962201, 0.017912192871012998, 0.025798619890044776, 0.03904506534097656, 0.01459688226121568, 0.0343951644496091, 0.021417868669114767, 0.048779231315899285, 0.0589125061167344, 0.028968653416321166, 0.0899990210910478, 9.498668524526781, 60.91953531388314, 57.13735457389586, 53.27109782926498, 48.26762437820435, 31.389530204957534, 32.55212072403201, 43.27323905883297, 47.666705500695016, 28.91734265512036, 0.5708363820468226, 0.09875568951810561, 0.043254615063027996, 0.0709638275927113, 1.2989147007465363, 2.37852061467786, 5.580642377176593, 3.599243111187412, 15.199562926446239, 30.341604294315463, 37.0929878757846, 57.311103805418945, 62.9468947072183, 60.3204168042829, 56.05381942564442, 48.13105137117448, 54.639149942705714, 59.89407085603284, 58.938314760884936, 56.988684977254565, 50.75774108209918, 44.899873425883634, 50.89590657141901, 56.83493983361029, 59.348575069058334, 57.861745742059526, 56.31743015781526, 59.457593425627685, 54.26110798312772, 43.65761564623925, 38.846306954660726, 46.19429480644965, 55.25382065003919, 56.975850982050744, 53.859955418494444, 58.4287400399485, 57.15757831450432, 55.37691639315698, 54.9839537374435, 56.159441009644546, 53.0460165392968, 54.45943870852071, 48.426170502939534, 45.290502271344586, 41.087360997353834, 42.907878122022076, 40.2996039390564, 52.29703995489305, 55.76345028415803, 58.92963847806377, 53.24177026748658, 57.555012472214244, 49.9802057204708, 55.28405820169757, 50.36805360547958, 59.63153485328921, 37.04765704370315, 30.76273741260652, 63.82305022208922, 54.47146469546903, 58.12167729100874, 52.1585802878103, 54.582095146179206, 42.98212858938402, 40.9656733851279, 44.25287454358993, 51.29360352793048, 56.64935288890716, 56.882482882468935, 54.646441628856046, 55.54245218153923, 54.60070679264685, 55.41441425200432, 52.876801567692915, 51.63787388032483, 51.82434335831673, 53.91067950956283, 52.22096950777116, 51.413804561861106, 50.731633786232244, 51.26903380117109, 55.47836457529376, 58.03468304295694, 58.41130902690273, 57.77767758215628, 57.92465663725331, 53.268163896376095, 59.85439215936969, 59.06602713369555, 57.75758720213368, 47.90457763979512, 42.936542803241366, 43.94530973126812, 55.04023974941623, 59.59347609550723, 61.7070766418211, 60.92653282227055, 58.875631363161155, 55.80194442502914, 58.81374028421218, 61.65425016034035, 53.13466210519114, 20.89051215879379, 12.727930391988448, 9.81409670845155, 7.082961143985872, 9.282009543911103, 5.470222263566909, 2.9269138074690297, 0.2317562600177142, 0.13287370633934775, 0.03046045260083291, 2.530663960403012, 33.01206373399304, 43.77285880427207, 43.18264015259282, 36.04724476414342, 20.01900073020689, 45.056830990699034, 47.45287356838104, 54.79591923375284, 49.94863064058366, 18.939527196268884, 0.6679179243022396, 0.08562621420189258, 0.11312390602524243, 0.03414140548557043, 0.007386691586655235, 0.041677531140345725, 0.029902392021951177, 0.011779922379871771, 0.022115046984606215, 0.022336459801261945, 0.03105283966438184, 0.04789181804705051, 0.027720460615631555, 0.032672837917362495, 0.015828607044362977, 0.028561454701928363, 0.045390897205159556, 0.046366445059257175, 0.06268087729451156, 0.00933331046854296, 0.038411564253751314, 0.033629241234232346, 0.03540095745495731, 0.04861217052225144, 0.08641998854375656, 0.04699351866879771, 0.03396316746910734, 0.01428372658518774, 0.05035543806790825, 0.06684583686893025, 0.016144776318763054, 0.09332309191625926, 0.02883147196694007, 0.035741131136854815, 0.02984009183672888, 0.026488686994379087, 0.022515488803506862, 0.01375160861625186, 0.046158482831332, 0.06162194076985602, 0.029265510571760037, 0.05064126930289692, 0.05258789488805398, 14.547518895518396, 73.32772977890508, 63.71801699361494, 61.784755260713645, 55.83323709426388, 35.64333085090884, 36.20818353468372, 47.7651216906886, 45.672611728791274, 30.575340294068862, 0.592348498682822, 0.22864068768197493, 0.035669007789223425, 0.5944503987989118, 4.066346162749875, 6.772157924790537, 6.43711494822656, 6.16305306073158, 12.818354752755935, 28.186640393349435, 39.01713009803526, 60.7776161163084, 64.4525827900056, 63.299649146295366, 59.07353455020536, 51.44699565825924, 55.91986263951948, 62.469640316501746, 62.649226034841234, 60.27274431720857, 53.44882042177262, 48.10115898809126, 53.549723394455455, 60.321087529582364, 61.73636105752761, 56.93852570749099, 58.14794932642291, 60.889231081931825, 56.32620057752056, 45.94323173646004, 41.91964087947723, 49.393501512465946, 56.973689756085804, 60.747409943611395, 53.330564883447465, 58.25956821441651, 58.629071174129365, 57.254017629931056, 56.913822620145744, 57.94682587346723, 57.15401288001769, 56.52324084312686, 50.378012503347094, 47.587783490457845, 42.558959760973536, 44.17001839606993, 41.582819108040106, 54.6823234711924, 58.05180026638893, 59.47674243680893, 55.189611450318374, 57.54122141868838, 52.50765946603591, 55.56291910909838, 49.222643067759854, 58.27458304743613, 38.77291548636652, 32.48922944068909, 65.04521369934082, 55.62978375342585, 60.977496177919456, 54.622675987981985, 57.268247988916215, 46.30982037513487, 43.81128626485025, 46.62189983552503, 53.695345309472856, 58.62446631154707, 59.52962775384227, 56.38659331106371, 56.849499671689934, 55.68523037818171, 55.201982605841856, 51.7656764676494, 51.60944454131588, 52.012440619930146, 54.50427139959028, 53.63805124836584, 52.02907146946077, 52.81421622922344, 50.59614335336993, 55.678009294694476, 59.483088831747736, 59.090494878830455, 59.00381049802227, 58.127274513244636, 53.186672733676055, 61.133473150191776, 61.98944807052613, 61.58353767087383, 49.53506769672517, 44.880343944795676, 44.838951172367224, 56.41303793076546, 61.256239414215095, 59.86954035297517, 63.272247468271566, 61.73153654221566, 57.47993438474594, 60.878766198312086, 62.82538752402029, 56.551238721416844, 23.352383875077773, 7.065975810250929, 4.948446519913213, 6.240488002377172, 9.25804582334334, 8.204635458607829, 5.1900223570485275, 0.37271415514330714, 0.18011528427802748, 0.031730503805222056, 2.6694732087273754, 37.0039971413151, 35.40413295069049, 42.22505231057444, 34.517049712519494, 22.82366994888552, 50.759125678770005, 53.806344462979226, 60.990283104681204, 58.242517671277454, 23.47077669635896, 0.8664515097775768, 0.060830173578353665, 0.06195458763789746, 0.05545957164177972, 0.048943656767087604, 0.05497379911943309, 0.04607526270011741, 0.0546690991388694, 0.04553563036625424, 0.03716582101919959, 0.04140189653562923, 0.014700666107537766, 0.07348302346203597, 0.027180943194957032, 0.05299228972064392, 0.07535017125548855, 0.07884399950384133, 0.07933241885996635, 0.10054116467795066, 0.018512543418534824, 0.10954696489798446, 0.024398222655778932, 0.10227820009834344, 0.16502779547966298, 0.15435559314585504, 0.1393163372432032, 0.2002373803406954, 0.13273604033935454, 0.16650617663418094, 0.18166670425524636, 0.15956710543363326, 0.16953988481433163, 0.08431049649633708, 0.0831917399961141, 0.17300303124131697, 0.07180378937553014, 0.08566930664763336, 0.10786366288460071, 0.12924177542088494, 0.1896069757640362, 0.1396985691521437, 0.20895858655773827, 0.3091145775491192, 20.438219731853856, 84.90016521946077, 72.41466476071265, 71.85682527480587, 61.4919581720906, 43.49809285133116, 44.52420842263007, 54.147967215507265, 59.87660454165552, 38.89372056530368, 1.14501106883249, 0.36987533973109343, 0.16967019637025174, 0.4762835734553876, 3.05393192075914, 11.159213742902203, 13.237542375441521, 11.740957133231625, 26.91931082356361, 35.14355421066284, 45.510998310581336, 61.42191640792355, 69.2773962020874, 65.09473754513648, 61.24331912686748, 52.40572098762759, 59.35368199502269, 64.79446049659484, 65.08064446910736, 61.97162482046313, 55.61079555942167, 48.87033577888243, 56.220253436796135, 61.85875077401439, 63.79756658307968, 58.96814830841557, 60.64167461087627, 64.98558582798128, 60.64135689889232, 47.93501130996212, 43.05436295847739, 51.47174581404656, 58.964645631851695, 61.146903345661784, 53.33879401606899, 60.70407952031782, 61.85032552288425, 60.535998113693736, 60.32331543584024, 59.75655648016161, 58.885578493918146, 59.93397705016598, 53.09063742237707, 49.76187482956917, 44.95928556688371, 46.638075690115656, 44.64187560542938, 57.01641613437284, 60.54661989212037, 62.24823036501485, 56.18758401563091, 59.529266895786414, 53.409114268518266, 56.564766976141165, 51.729508292290475, 58.813983471162864, 42.27615294917938, 34.625707211032996, 65.59746380775206, 59.327398192497995, 61.066785012522054, 56.67755080807594, 59.17157811503257, 48.62867463019587, 45.26603452620968, 50.40632809362104, 55.70747021705874, 62.278703258883574, 61.6340381868424, 59.15432360864455, 59.01318104036393, 58.424331295874815, 57.08197462943293, 54.42815780639649, 52.816208793270974, 52.3917063590019, 56.38205512877434, 53.74994862464167, 51.96486226973995, 52.95003614118023, 51.52860841443462, 58.7468913293654, 62.26672434037732, 63.65044632265645, 61.86821153087001, 59.72691512876942, 53.33751532339281, 61.370250948013805, 64.50637025217857, 63.31381674735778, 52.049522707539225, 48.28415716848066, 47.70474072425596, 60.329089164733894, 64.27011020721929, 64.22290840456563, 65.39724249993601, 64.65831502791374, 60.515052656973566, 64.97204188377627, 65.90576602566627, 62.20076968592983, 30.71686137107111, 21.595077706921487, 19.336053325283913, 16.381617226908286, 19.491851829713394, 14.213234897582764, 7.175022113707758, 0.48627464701571776, 0.2903999075774224, 0.15700455664867358, 3.8956926618852927, 46.15865615106399, 57.0784366515375, 54.09403462563792, 41.03285181906916, 29.275613907844793, 58.396607983496885, 62.360233645285334, 67.8118496556436, 66.19357385943013, 28.07670420215976, 0.8319040700312584, 0.2996800821875372, 0.2561063187256936, 0.17533196917464658, 0.11158544059482314, 0.11181808617566863, 0.09591983886615885, 0.14149084717275637, 0.14807978554839088, 0.12258450200240459, 0.15626301418148703, 0.1634790414884206, 0.1263649237432307, 0.1266293389902961, 0.0940232043485007, 0.1013970917331115, 0.1725959474401128, 0.2419703570945609, 0.1589128969898147, 0.11104342572751547, 0.13730949331675807, 0.1529519055639544], [0.030011197574616923, 0.017854427926302437, 0.022038970623285543, 0.051008554836434704, 0.008796030024607337, 0.048187941673301884, 0.055981683544814594, 0.08078616262683946, 0.07957771255244171, 0.04158424078336647, 0.008125908019381666, 0.08241230682019265, 0.0332041735190057, 0.010795490778682214, 0.02985563959115215, 0.03188155336125243, 0.018338785101208958, 0.026163442450906002, 0.049306479838466456, 0.059436590696174296, 0.12542553140871948, 26.60991426437132, 62.232332998706454, 54.50076480065623, 48.004939325394176, 29.737216080388716, 18.058555010826357, 29.57165675778543, 39.81102566565237, 43.88586621130667, 10.17702381457052, 0.05686859119563334, 0.05060857650072825, 0.04345651753547211, 0.8358108120099191, 6.390507874950287, 3.053882400835714, 5.146973854111088, 7.797704752414458, 19.05067736102689, 35.60532700630927, 46.15701660033196, 61.023886049947436, 60.348575499749955, 59.26248688851634, 55.789188877228774, 49.021001861941436, 47.46236962656821, 56.875422616158765, 57.169655292264885, 54.36713749362577, 45.07787450667351, 46.775299810594134, 53.038556191229056, 58.760603935487815, 59.66733824822211, 56.956274432520715, 55.46596596317907, 58.03994294135802, 55.38783627171671, 43.88823532289074, 39.6411988043016, 43.704083965670684, 52.461673598135675, 57.648804187774665, 54.958266135185, 58.9708782780555, 53.687771212670114, 52.540866251914736, 49.81782351770709, 55.11247804087978, 50.33124608378257, 51.19668176097255, 47.46045943229429, 42.33589064690375, 39.71490798457977, 43.04923249829201, 40.1020263087365, 52.89624475663709, 57.11541283515192, 59.066070279767445, 54.64779092419533, 58.439879571237874, 53.33162392339399, 59.584886104829856, 51.69980026060536, 62.00986400727303, 33.6897433957746, 26.883836907725183, 60.47614274486419, 50.80821806384672, 60.886861970347745, 51.63026840456071, 57.21404475550498, 50.54248532941265, 42.99164425942206, 38.99098750083677, 45.502459310716205, 47.30040711741294, 55.646779383382494, 55.09178361585064, 55.88587922434653, 56.28648265715569, 57.33264154003513, 55.868812991726784, 55.026589901216575, 52.84075498580933, 53.89684923233525, 53.45475889021351, 50.436220476704264, 49.118739481895204, 54.49951356457126, 56.11860129141039, 54.44758922823014, 52.38116695034889, 53.41593134787775, 54.4059258122598, 55.33222882978378, 52.25777702946817, 59.652099840102665, 58.045430337229085, 51.87404371077015, 41.43509088024017, 43.78821096112652, 53.30692083604875, 60.31702787645402, 56.55511010077692, 60.24616633692096, 58.29376343757876, 56.5517133282077, 54.62072264763617, 60.36844622704291, 57.29694012672671, 54.53960803247268, 32.00539527400848, 11.095161437988283, 6.928134406766584, 9.757744016185883, 2.925423797099821, 4.309418384105929, 0.7735960149476606, 0.18149050403266184, 0.049081678997965596, 0.20475343801081183, 12.224605967921596, 43.00254060376076, 29.82020558849458, 25.101535435645815, 23.986662510902654, 23.734185426465928, 38.7737548735834, 43.106946253007465, 57.70331336605934, 32.83335270420198, 2.1149537640233196, 0.04970245153432892, 0.05607968534252817, 0.040629220255199945, 0.0659042535229556, 0.04547032137070933, 0.028827691323033748, 0.020390822469527205, 0.04340127493525225, 0.04696908429445279, 0.04752689206431951, 0.040180947736746846, 0.022308432474552144, 0.02035224994253968, 0.0332171663702015, 0.016330320898803975, 0.07714220412796544, 0.04683121911159927, 0.08794725376872287, 0.05875821217834469, 0.03692682073902219, 0.017016523089560292, 0.06711719287258965, 0.010363106923778693, 0.08838973083202878, 0.037003234179029544, 0.03943082508480838, 0.025416665687976826, 0.041724488499664494, 0.02849643298935506, 0.03324464211360582, 0.007338478321945596, 0.001978687322398107, 0.05813891053079598, 0.0912936024307724, 0.055283712328321515, 0.0351412306659885, 0.056832466319563894, 0.0286764157710657, 0.03212395315659383, 0.028150735813523495, 0.05703214330658798, 0.11993343175779428, 36.40794984755978, 69.37197239168229, 61.733407512787856, 54.95736791241554, 37.541255950927734, 24.598220817504394, 34.02986388052664, 39.852104648467034, 43.07495932425223, 12.849801375019936, 0.08356210520310749, 0.031516581413245974, 0.14840236985154692, 1.2983463247937541, 6.820867878775443, 7.062649150048533, 6.647062753477405, 6.16071826988651, 17.521811992891376, 36.22137446557322, 49.25574394964403, 63.64615132731777, 63.10014955459103, 61.687574617324344, 58.39094800333823, 50.62026592992967, 51.12126634966943, 59.166620239134765, 59.473177002322295, 57.04830500387377, 47.742477847683816, 48.92076961455807, 55.40027802990329, 61.70147549721503, 61.645699393364694, 57.00670042345601, 57.22571772913779, 60.57724575842581, 57.62230857726067, 46.516117434347834, 41.231888571093165, 45.546068222292014, 55.07193642277872, 57.91465067094373, 55.25854318372665, 60.99119701693135, 55.979239479188, 54.056670127376435, 52.411985012792776, 55.91874868639054, 53.24283715217344, 54.282210334654785, 49.48976432123492, 44.69614551913354, 41.98651729091522, 43.621255274741884, 42.99624127726401, 54.90706351495559, 58.61174998744842, 59.61899895821849, 56.709816225113414, 61.14692687988282, 55.40276873496271, 60.15581846237183, 52.88458355011479, 61.75551006870886, 35.83050635553176, 28.76658243517722, 60.04514486558976, 53.95456298705071, 61.90402277054326, 53.17103032142886, 58.77306138315509, 52.64816661034861, 44.401983445690526, 40.698544286912494, 46.68822319276872, 50.06695285920174, 58.1850157245513, 58.523080887333045, 58.60245004776986, 57.86599759132632, 58.401691375240205, 56.10652431364983, 57.05752649614888, 53.540988276081706, 53.62441708964687, 54.359422191496826, 52.17627017728744, 49.38447613869944, 54.100949764251716, 59.29952583005352, 56.14121375545379, 55.351118964533654, 56.96791994956232, 57.77492015592514, 55.08815542344124, 52.64991990981564, 61.31640072791808, 60.35283127138692, 53.8490237728242, 43.90790600930491, 46.36446291400541, 54.75982558342719, 61.41421287290512, 58.85051642694781, 63.480160543995524, 59.662741230380156, 59.69671680081276, 57.740481745812204, 64.37945804288312, 59.663988544094956, 55.877493196918124, 26.261590142403882, 7.222180770289514, 3.912257076271119, 8.127149035853725, 8.900356061996954, 7.115493282195061, 2.500500688629766, 0.17887278159539546, 0.04426499310460302, 0.2656268917264477, 15.652176007147759, 42.39118037685272, 34.28959931096723, 32.34576286808137, 26.578517652327015, 33.45999056293119, 45.03934898684102, 50.243569343320786, 63.81761773940056, 40.945088786463586, 2.1880738533312276, 0.052912329293547146, 0.05965765685804429, 0.06403869919238553, 0.03620334645552981, 0.04065920493655628, 0.04572442890475354, 0.0413674570529932, 0.07346037024211499, 0.05684601458450479, 0.010674830015388229, 0.04587018862366677, 0.002923940229530056, 0.03399777549108671, 0.059050015068703124, 0.014097052983068412, 0.048986576843045415, 0.041572450690211794, 0.1054135604851669, 0.03352002773974692, 0.034692858556105245, 0.024015042713032137, 0.1554284073532589, 0.10313083297542988, 0.22109898107667125, 0.18972043338562214, 0.11837887082008586, 0.09147428426771395, 0.17250708124089628, 0.14612670567247177, 0.17079067656830435, 0.15257396374738988, 0.0992291241944317, 0.13611343088409594, 0.15345346332798082, 0.1426341108256771, 0.16118684513193948, 0.16974406256791086, 0.156960996889299, 0.14242495350059003, 0.13300464608736579, 0.1169755892647851, 0.5332147233909177, 44.12176932058027, 78.25917674649146, 71.49818728047033, 63.668638275515654, 42.376510712408255, 26.275814617833785, 39.4970360109883, 50.5190295557822, 57.514486543593875, 15.497944489602121, 0.387312604054328, 0.2741679140636998, 0.23922521891372822, 2.3270059208716116, 11.24270139201995, 13.726673703039847, 14.719277524179029, 14.091523751135796, 23.652068645723407, 44.27644798832555, 55.07039100893083, 64.78494874892696, 65.24512906228343, 65.19533457294588, 61.82525765511298, 53.657333620132945, 53.67713374476279, 61.77250177629533, 63.04036871079476, 59.62945207472771, 50.32655100668631, 51.82785780199113, 56.63811922073365, 63.744904841146166, 65.06870477430283, 57.83834488161149, 58.11838642243416, 63.33824134642079, 61.0095105632659, 48.94595123106434, 43.83826824926561, 48.00566104150588, 57.51225079259565, 61.54895413306452, 55.44386340725807, 61.534610025344364, 57.99994261034074, 56.50058915538173, 54.83291110684795, 59.293610895833666, 55.08885360533192, 56.30378815435595, 52.5494287860009, 46.22593264425955, 44.02864048557897, 45.874323537272794, 44.75827586266303, 57.745596516516905, 62.426321660318685, 61.76632012090376, 58.171938542396795, 63.14212676017516, 58.038597568388916, 62.7396249002026, 54.24301408952283, 60.669001763866795, 38.89835680684736, 31.0804376294536, 60.69688589342179, 55.50059264706027, 63.801328136074936, 55.88935444431921, 61.2167372242097, 55.030739768858886, 47.682661702556, 41.07307180281609, 50.89800111709103, 51.74009869175573, 60.55742209957492, 60.88595198046777, 59.551408675409135, 59.9695372581482, 60.852203907505164, 59.79075562569403, 59.0336871916248, 54.366647197354226, 57.21968512381277, 57.98449631660216, 52.87633088327224, 49.56352449232533, 56.44680953794911, 61.385563881166526, 60.11835590485604, 57.463774219636, 60.782907393670854, 59.30207144829535, 57.09838974860407, 52.45938293395504, 62.714953191818736, 62.2363220491717, 57.32938989516228, 46.71741739396126, 47.821223351263235, 59.22029003020256, 66.07141556278353, 59.2037219385947, 65.09017975099626, 61.68379345247823, 63.30119063777309, 60.769194787548436, 69.09242506950133, 63.09322657123689, 66.47737303087789, 39.70615717672533, 18.823242648955315, 17.71603991908412, 21.058721042448475, 11.339539808611717, 11.234320267554253, 2.566969663866105, 0.35705893390601684, 0.20760259561000333, 0.4720247374667276, 19.153551324721306, 60.81327046117475, 42.62036054365097, 34.86643483561855, 36.227854221097886, 35.06569516274237, 53.582832121079974, 58.17504898194344, 71.56033331348051, 46.79898308169457, 3.039973431056546, 0.19107473893992363, 0.16880436379822994, 0.14607197635116118, 0.1399371748970401, 0.16828368447961348, 0.07572172389876458, 0.057960270318172635, 0.24931606776531667, 0.12979679080026765, 0.17855839443302926, 0.17512498753926448, 0.11415276210755111, 0.14807641476152406, 0.16944124333320126, 0.09997643530368806, 0.22886164276109588, 0.14587665457398663, 0.2089234078002553, 0.15040130775061347, 0.09222908005599054, 0.18840994806058947], [0.021151787180814053, 0.0545517651123866, 0.01895794310727187, 0.04390870093277866, 0.05426945788184962, 0.020259124294464147, 0.1129692864994849, 0.03219783276079163, 0.03385910974635232, 0.031910478926053455, 0.04461124952461931, 0.01762043786114983, 0.03038640062685215, 0.021750590230728832, 0.06978672583617511, 0.015936017359396624, 0.0010964076805506805, 0.0584926707820306, 0.0883882292996972, 0.08212934458448042, 2.410397471920137, 45.794158135691, 67.24102712446644, 44.10148282204905, 38.919027697655466, 21.236223982226466, 22.882946768114646, 37.499553311255674, 45.29664470303444, 35.92275657961446, 2.376348847343076, 0.0788564867370071, 0.13278468692254636, 0.04195235369186248, 0.8958608897462969, 5.346460698112365, 6.409211206820704, 4.364401678885184, 11.066906644452004, 22.587835481089932, 39.55535773308047, 54.422733168448175, 61.96096381833477, 62.32101386593234, 60.73551339487876, 58.21990128486388, 48.2600934274735, 45.868314466168805, 47.706497946093165, 48.09221990646855, 44.09488931778939, 43.72644539802305, 49.7249770933582, 54.14673166890299, 58.7564266112543, 59.054966049809615, 55.9691942891767, 56.20701543746456, 57.27043667147237, 53.146437060448434, 47.689741580717026, 39.591878921754905, 43.70790435421852, 49.773084963521654, 57.17533880664457, 55.79106377017114, 55.49063374919277, 53.60016899724161, 50.641784052695, 48.97017186687839, 50.489384282019834, 48.1244029537324, 46.531002829151774, 41.96872541981359, 43.22421335404919, 40.190032528292754, 43.02129737792477, 40.44878736619027, 51.59938366182389, 54.91086429165256, 59.26356554031373, 55.814735274161066, 58.533231981339, 53.20331142794702, 59.098269016511985, 53.58076895436933, 62.01902274162539, 32.13061694175967, 26.752315913477254, 58.73485357530656, 44.37355802905175, 56.620637216875636, 51.68505999349779, 57.984100157214755, 53.47451586877146, 50.73009229475453, 39.172989399202415, 45.047860530114946, 41.71641895847936, 48.34260048404817, 49.75111184581634, 54.715738142690356, 52.95290339377619, 53.425556844280614, 53.842818583211596, 55.52712355890582, 55.97417569929554, 55.972606751226614, 55.2302001368615, 53.12318132769678, 49.91814205723424, 52.516245534343106, 55.24852152793638, 53.62019269697128, 49.41972255706788, 52.75719673402848, 55.23726824791201, 58.28298476434524, 55.303532769603116, 56.91170454025269, 57.39991803323069, 51.315325613944765, 43.568926934273016, 43.55997608553979, 49.74083523596487, 56.601335233257664, 58.36811196419501, 55.24503061848303, 61.18102012142059, 58.315952285643554, 57.07108612983458, 57.44895942749516, 61.10151760039791, 60.63422602991904, 39.79192372291319, 19.533581925976662, 4.244804689961096, 6.607986630931978, 7.170052470699434, 5.66410796296212, 0.770670784817588, 0.07937309046786639, 0.03417519762391045, 0.039240413931228464, 3.11139464378357, 26.628116023155954, 40.179744151330766, 17.883085819982714, 11.719781237263835, 26.583348051194225, 45.674094384716405, 52.06295682537941, 55.716232792023696, 42.623521974009854, 4.724193830643931, 0.031969454289684375, 0.03740578657016158, 0.024879576766022274, 0.03127006198009176, 0.04754509431340041, 0.03631986842881288, 0.04308077439125027, 0.02262504320711859, 0.06527609972944183, 0.027266363913734114, 0.028299552223254597, 0.009429809776315046, 0.051684738512361245, 0.07594491595462446, 0.057863605343886924, 0.061220384293025544, 0.014447113029628754, 0.023482368372741248, 0.04812668528287642, 0.026245969272549116, 0.034848263321985165, 0.063112564009404, 0.05604517691197896, 0.05788945698089177, 0.030196033523327885, 0.05438442852708602, 0.02875192522732241, 0.10708065973895212, 0.021706796814537337, 0.02726572806075696, 0.03209689301588843, 0.03156497327220296, 0.028429630122357802, 0.052370222495688554, 0.02397036829572772, 0.06326689242175029, 0.03676227654420561, 0.01356327739138637, 0.051741409866559895, 0.055375436035495613, 0.05580419246407767, 3.1878068274067295, 55.66944676060831, 73.66331992610809, 52.28748506115329, 45.43528872151529, 27.069927876995457, 25.53268824854205, 39.56852120737876, 40.52460678162114, 36.57268155005671, 2.5508587735314525, 0.040105185471475124, 0.08094632862916878, 0.3093103589790483, 2.2622544534744757, 8.067485372866354, 9.888201067524573, 5.806418907257819, 8.804253089812494, 24.474815207142985, 42.416816988298976, 58.15780624266594, 61.72195419188469, 65.05919694900513, 64.30545076247185, 60.87681285796627, 50.371269949020885, 48.167070496466856, 48.75853253949074, 51.324041120467655, 46.20638355132073, 44.9113267467868, 51.66529909256966, 58.255496794177645, 60.32803404715754, 60.27324638059063, 55.332452404883604, 56.849997812701815, 59.594927372470984, 55.08896343169674, 48.746502630172245, 41.76048286499516, 45.902007625949004, 52.06663600860104, 60.158975970360544, 56.29210733598279, 57.43208931338403, 56.32505132306007, 52.41598583036854, 50.3425189756578, 55.240139422878144, 50.928203367417865, 48.32799357752646, 43.452240344016786, 45.08284807205201, 41.58402327568301, 44.07561479076263, 42.1407997992731, 53.48214487875662, 57.018742099885024, 60.94270867686118, 55.92120016774824, 60.923304711618734, 55.794554679624504, 60.77533329686811, 55.2528126009049, 62.30459482439103, 32.503183272577104, 28.527264902668616, 56.46707250225929, 46.881199882876494, 59.595978567677165, 53.58712711641866, 59.33646671233639, 55.618000953428215, 51.68258105554889, 40.87852224226921, 45.46704030806019, 42.547855531015706, 50.61537081195463, 52.71831820088049, 56.47861211530624, 56.123555244938025, 56.02492724695514, 55.929335163485625, 57.471520900726325, 56.64523440022623, 57.889025826607984, 56.31056208764353, 55.21896646868799, 48.77311983416158, 54.45076634806972, 57.91593328599007, 56.92927283625449, 51.390431158004276, 54.03369288290701, 57.8709868461855, 59.18277255950436, 57.238355605833, 58.807958710578184, 60.35095637844455, 53.17092049506403, 44.830321957988126, 46.29861808592274, 51.15361021411035, 59.31133216427219, 58.09595438741869, 57.38780575413858, 61.39717409687658, 60.27887890415808, 58.002001854681204, 58.922107527332926, 63.66266058337305, 63.53015507421186, 39.83852540293048, 16.916288252799742, 3.7813352240670115, 2.4547425633476627, 7.21692136218471, 10.361296765265926, 5.1083914599111, 0.7276684310167068, 0.07262161887821651, 0.08608172242079051, 3.269712045308083, 31.27941554592502, 34.28306464226016, 17.476396829851215, 15.932579386618832, 31.758587975655836, 50.278976578866285, 56.979267366470836, 63.16107965284779, 51.53409581030569, 6.873805657509835, 0.07720024294910893, 0.08106626735459413, 0.0241810328988058, 0.03820677362983266, 0.04511427817746036, 0.010688978701739783, 0.008609381320345546, 0.11531608194232949, 0.043807611800730235, 0.05482640380280153, 0.1027516654181865, 0.0632397958918685, 0.08068028927570389, 0.06124885595073143, 0.051767613904009906, 0.04643934981657132, 0.022898797065980976, 0.04352027903340998, 0.023443895437183882, 0.029808381542323098, 0.0783927124294062, 0.1163546443586388, 0.17065310249886206, 0.142297736939884, 0.14651822256705455, 0.13829895715800025, 0.07558693072848743, 0.24425878429845457, 0.07566958395463806, 0.08952386271689208, 0.10363260524407511, 0.12164497177206701, 0.24450171077924393, 0.14057596965182212, 0.1065945846118754, 0.17075214234571304, 0.11450130146958175, 0.11010004207491876, 0.19729593979014506, 0.18602787426883177, 0.2523823346822493, 5.0961085577164935, 65.46292258847144, 79.0409129665744, 60.130272065439534, 55.13198006537653, 32.613162609838675, 32.00324385396896, 49.86301314446234, 57.14465802715671, 46.83029144041, 3.430486811745552, 0.41959619269736353, 0.29082061242192025, 0.29309822246432304, 3.489803590120808, 16.304517157616154, 13.602666989449533, 11.463594571236642, 15.898668535294073, 30.636462588464063, 44.84905519793111, 57.60422645076629, 64.17161949219243, 65.83656757108628, 65.98880260221421, 63.500498033338985, 52.11377113096176, 50.587616120615316, 51.23352066163094, 53.52678929605792, 47.78409027284192, 47.931508633398245, 54.853476093661406, 59.91265504590927, 62.366450602008456, 60.01842175760577, 56.8991647228118, 57.71679062997141, 61.883865710227724, 58.03019192910964, 52.591194183595725, 44.22195842189174, 48.39417965181413, 53.92887146242204, 61.6598669944271, 58.96521437552668, 60.35825198696506, 60.243675631861535, 56.326510444764175, 53.90276808892527, 57.12570513448408, 53.283155195174686, 50.59988137214415, 46.46763301664784, 47.63427534411031, 44.62461717667119, 46.9900691893793, 43.60014115610431, 55.62813635795347, 60.17772097741405, 62.72617509288173, 58.79554048661263, 63.363826967054806, 58.13589196051321, 62.97926602825042, 56.93153604384392, 63.3769041492093, 35.91510011303809, 31.06334786261282, 55.171101785475216, 48.16716855572116, 61.524054927210656, 56.39956851159373, 61.09326493355536, 57.584304732661096, 54.26901548139511, 44.83673111084969, 49.06311242811142, 44.0701783857038, 53.43723766265377, 54.84926346809634, 59.05822161705264, 58.861224497518236, 56.88458135051113, 58.41410175446541, 60.29647073438091, 60.32037758058118, 61.11661480319116, 58.32771547379033, 57.179053291197754, 51.151001837945756, 54.86610220324609, 60.912318152766076, 59.76772346804219, 54.041404262665786, 57.972564466537975, 61.27147389996437, 61.67222638284007, 57.57910759218278, 61.142922139936886, 64.29930440841183, 56.10967789926837, 47.97300730982135, 48.2187084997854, 54.24654422267791, 61.724872435292895, 61.58519683345672, 58.24117622067852, 64.58065209850189, 61.41418541631391, 59.71662675180743, 64.5103043894614, 67.60917294409968, 65.20217910889657, 45.158024218774614, 22.559051167580392, 9.423410008030555, 14.850529836070153, 17.6734527849382, 17.627278643269694, 5.243409737463921, 0.4642287816011137, 0.2506782640252383, 0.22595116748444496, 4.378406991881709, 38.25183253134451, 56.0317051026129, 28.035956659624656, 18.977689896860433, 38.2901030971158, 57.452571930423865, 64.82344288979807, 68.3959690217049, 59.94149623378631, 9.640787762980308, 0.1993831616616057, 0.22376600893274431, 0.08464738366103942, 0.20103892281411156, 0.16888164674803136, 0.22806518711149695, 0.20749653839776594, 0.2768270358923943, 0.1416119656735851, 0.190321613223322, 0.2327861733013584, 0.23541731759905818, 0.14217857962414143, 0.16249287182525282, 0.246943018489307, 0.12535595530343632, 0.10995319068071344, 0.11206483543520013, 0.17548900187736557, 0.179154901134391, 0.1461176351914483], [0.035404875994690006, 0.08076842769139236, 0.03891673412234072, 0.056886655548887874, 0.05015723963057803, 0.03491893110256042, 0.06143890704298693, 0.031000192187005476, 0.07154141192234333, 0.037140360087036126, 0.011072848123618433, 0.04332507983030331, 0.05951488871247538, 0.04286571052826701, 0.017488653501195293, 0.020356645372005242, 0.028181599580772945, 0.06419668950500988, 0.02236427453857276, 0.10232534514920366, 3.450340378669001, 53.91016175670009, 58.69406484788465, 50.708417277182306, 29.83864268948955, 18.156673100686845, 27.35175213506145, 30.876627352929887, 47.983887964679354, 17.960648728955178, 0.4519972379409498, 0.06524992250506917, 0.09315580895711338, 0.09386661597677777, 1.8877032807757779, 6.965036555644005, 6.311399552129931, 6.170187361778752, 17.227887222843787, 40.58925920917142, 61.353726002477835, 62.53776404165453, 60.42418702956169, 62.330780567661414, 58.63845348358155, 56.83425341883014, 52.95742588658487, 43.78997210533389, 43.05068377525576, 40.26861329232493, 44.57952168680007, 48.85394027156215, 55.37150352231918, 56.182155455312426, 59.05989254674604, 55.92218076029132, 56.6839325043463, 55.34183079196561, 57.17597423061248, 53.808713574563306, 47.48748456278155, 41.17853649200932, 40.06750552884994, 47.84875446750272, 55.9572781285932, 57.35228084748792, 57.15190264486498, 52.47349954420521, 45.851554178422504, 45.8210067595205, 47.159107654325425, 42.74724529635522, 42.13788940060524, 40.14090876425467, 41.226632595062256, 39.94731233965966, 40.326774197240034, 41.686577566208385, 46.81595909980036, 50.92181774877733, 53.68437444010089, 51.18520490584835, 55.21540103420135, 52.05029933683334, 56.05479609581732, 48.88171849712249, 65.29469213178082, 36.85889297916044, 26.91388422443021, 59.00055885314942, 51.59362562241093, 58.11001216211627, 53.20464895617578, 56.382988652875355, 51.67965496740034, 49.63428405023391, 40.79789400100708, 42.740957736969, 41.29476808732556, 41.38701831140826, 42.27490563546458, 46.18999196637062, 48.11185136918099, 50.46618346245059, 49.80714682609805, 51.7594006753737, 53.09513245859454, 53.439708755862334, 53.7902392110517, 54.52587973686957, 51.054358559270064, 55.768027690149125, 52.50461570678219, 52.554578858037154, 44.762986629239975, 45.00636969843219, 53.63135184011152, 58.138955331617794, 54.930942904564645, 55.95455208132344, 57.08665009467833, 52.0303423173966, 43.975245260423236, 42.93320094385455, 47.21646055098503, 56.34325504302979, 55.52925732827956, 57.05068196019819, 56.792413496202045, 60.29228164303688, 54.849738074887185, 55.89197850996449, 58.14776105265464, 63.67301956299813, 60.34408830827283, 41.00158268405546, 13.733094623011928, 4.145317692910472, 7.4302791780041115, 6.977398395538331, 6.337725520133973, 0.8063608600247292, 0.11751346725730166, 0.03657450073308522, 0.19859096546086574, 13.886792698214132, 44.72728521593156, 41.426143953877116, 24.838548360332368, 25.577130663779478, 35.8062582631265, 44.24540242841167, 50.728633173050426, 47.452787276237245, 12.627699125197626, 0.4122451806981718, 0.08300789421604526, 0.04688978653341051, 0.0177374980111997, 0.05471421022629065, 0.05007906035790521, 0.03339786735934115, 0.022303269041942495, 0.04308739339091605, 0.01507596875120315, 0.021178069742276304, 0.04708351484770256, 0.07823361128929161, 0.04962887645008103, 0.021859581559716214, 0.014007658183184123, 0.08936925851289304, 0.05384928163801951, 0.04426985393248258, 0.030002025586943475, 0.03401110925140881, 0.013808367112951895, 0.05532826417155805, 0.003938372791444342, 0.041929750267656586, 0.048925856714166945, 0.03988757819658326, 0.0031219059676532786, 0.021682617164427237, 0.1006777658157291, 0.02986579025614887, 0.022606641775177374, 0.05282482673083583, 0.03548649117170322, 0.029051829497480107, 0.07218691760734205, 0.013326797540479851, 0.018282433588718696, 0.008274004306463946, 0.04042017401286191, 0.07672988028535921, 7.321062741741058, 62.64694713777112, 65.31259382924726, 55.83286446909751, 37.881607855519945, 22.718164074805475, 30.563537882220363, 29.62932932761408, 42.321401411487216, 21.673964415827108, 0.2960048519795941, 0.05156748875555012, 0.013940831375939232, 0.8828301631635236, 3.648653453396213, 7.846194563373444, 9.92552241971416, 5.9888213776773025, 19.054723285859634, 44.59486992128434, 62.208045682599476, 65.1856541633606, 62.47944231956237, 63.82765508467152, 61.41836274054743, 60.80029918301491, 54.499964637141076, 45.80602722783243, 44.99518309870074, 44.37685674236667, 46.29918682959772, 51.00623892199609, 57.16336773287866, 58.31870578950452, 59.19736769891555, 57.47480000219038, 57.494894304583156, 56.78560033921273, 58.65428024722684, 56.658382185043834, 49.462284195807676, 42.09111513630037, 41.68234925116263, 51.19985888081213, 57.238794911292295, 59.21143724072365, 57.8964626404547, 54.759955021642874, 48.77321397104571, 47.47829444946782, 48.28862082573676, 45.62496277593797, 43.24005580717518, 43.24017347828035, 43.2465983206226, 42.745370403412856, 43.131798390419256, 43.080756587366906, 48.02761062499016, 51.79026188388948, 54.22770507874028, 54.24570875783121, 57.81925470598283, 54.46413770798714, 59.075715388021166, 51.31840075215986, 65.91261448398714, 37.66379079511089, 28.436654229317945, 59.0887455017336, 54.147163129621944, 59.7995299677695, 55.6984369985519, 57.007618258076334, 54.76354791272072, 51.30326040329472, 43.7997466518033, 43.787555925307736, 43.22791607149186, 43.12688366059334, 45.322524501431374, 50.06777263456776, 50.54186167255525, 53.69065807711694, 51.56147003173829, 54.28051194837017, 55.29061640462568, 56.14136280552034, 56.03565492937642, 56.20446589685256, 52.237251266356445, 56.00140479303176, 55.45028824960032, 56.78045026717648, 47.085900537429325, 47.14820738761656, 56.25905352254068, 59.27978454097625, 55.81413122915453, 56.1066851308269, 60.348752006407715, 54.66647317332607, 45.892221312369074, 44.69018743884179, 50.16543572948825, 57.175829102916104, 59.87356470477197, 57.31455156880041, 58.56325772500808, 62.474759009576616, 58.86105583560083, 59.93167461887483, 61.08230190892374, 65.70561532051333, 62.360978895618075, 39.532439324163626, 13.549167821484229, 3.3361641053230535, 8.888533057705049, 6.8018350678105515, 6.981862052794426, 2.905313805226357, 0.35079800373604225, 0.03719537669131833, 0.12284650407250851, 16.740469971010764, 45.213898381879254, 35.61825513839722, 25.296392902251213, 34.08564782911731, 42.803496006996404, 51.082897724643836, 56.35634399229481, 55.38013665906845, 16.947165150796216, 0.7221480014343417, 0.03861748485735828, 0.008802077331159626, 0.02007773382619264, 0.03182033719044299, 0.02514467191612048, 0.040759451371888, 0.008204981699706087, 0.025624319565512484, 0.03381719324557531, 0.05692618951622037, 0.05758649985035581, 0.016082820873106682, 0.0996595736773264, 0.04958472297256512, 0.02617056898382162, 0.01997470840691559, 0.043089025158194766, 0.020700726102316575, 0.031467063405040296, 0.052479941608204, 0.11279536921891475, 0.25040999535591374, 0.15076650186411797, 0.19386758907668053, 0.07917122629981849, 0.12957027392281642, 0.2073230501264334, 0.09324866647441542, 0.2747550132053514, 0.13647674042130672, 0.08655029243879742, 0.1214034625539376, 0.12997325149274644, 0.09087589299005848, 0.13306484527645573, 0.07891804956260227, 0.2041971509254748, 0.13324551945251803, 0.11294329313621407, 0.16065352536257238, 13.032504397053874, 75.19091836867794, 72.37727672823014, 68.91400429510301, 45.55983574159684, 31.085999550357943, 36.93054291509813, 42.266707881804436, 61.70856714248658, 26.524318341285955, 0.757371559739113, 0.14301499441987084, 0.16543720818815694, 0.9314631406337985, 5.76571794286851, 14.498376500221992, 14.942419202097001, 13.638606686745922, 23.545256622375984, 49.46806576944167, 65.70009654568088, 68.21240994238084, 65.05931854248047, 65.35837965626871, 63.18814400703677, 62.23709867846582, 56.29229560975106, 48.74118389621858, 47.05502363943285, 45.83120099959835, 48.789542798073064, 54.24457911522158, 59.877502764424975, 61.77558475925077, 61.622392669800796, 58.28513422319966, 57.45512931577621, 57.68215610134987, 60.9701652680674, 58.79527768781109, 52.857170104980476, 46.573042792658654, 43.56478098900088, 53.17292090385191, 60.458127298662745, 61.68128705793812, 62.36734098003757, 57.58123351681618, 50.57143634365451, 50.417526460463, 52.181757573158514, 47.50066372656053, 46.505362295335345, 45.03484218351303, 46.00673883192001, 44.627186329134055, 43.47726114334599, 45.62698671894689, 51.62682064117924, 55.12313904300813, 56.89257906329248, 54.88798118406727, 60.20111399312174, 56.55288219451905, 58.96280604024088, 52.4111456255759, 66.5640260327247, 41.01807232825987, 31.83318361159294, 60.475330814238525, 55.20889382208548, 61.13163748095113, 57.98990526506978, 59.29741559490081, 56.44593484940068, 55.272906903297674, 46.66823087200042, 47.69611150987687, 45.96853102407148, 45.368514291701786, 47.180406124361106, 52.33696183850689, 53.22806550610451, 55.57627477953511, 54.285583573002974, 57.547705096583215, 58.043680960132235, 58.76050979860368, 58.708836493953584, 58.546987733533314, 52.89966898579752, 58.00411601220408, 56.37209623090683, 58.77972156770768, 50.5857765290045, 48.92566473253312, 57.82436555431735, 63.079278622904134, 55.72350878869334, 58.490544826753684, 64.24284581215151, 59.029345127844046, 48.57485186669135, 47.32728712020382, 53.45167590725807, 61.494033105911754, 60.5334956415238, 60.11109952003726, 60.15446916703255, 65.22871394311228, 61.676521378178755, 62.628966992901226, 62.5888882144805, 70.95135396526706, 65.9833897313764, 47.6448029856528, 17.0380856913905, 9.810168454723975, 17.3411613510501, 17.070037318814187, 13.156470906349922, 2.104784038759047, 0.2655987609778681, 0.3698761977495686, 0.3902745144742151, 21.133836392433416, 60.494444524088216, 54.795162216309585, 35.13720389335386, 36.19275293042583, 48.678951571064616, 59.87869516495736, 65.81690080704229, 63.50373398873114, 22.546809450272594, 0.8682322658358083, 0.1123389799989039, 0.0703873923949657, 0.1735010650008917, 0.20771576211817805, 0.13357397198917406, 0.1430658166927676, 0.13365819569556944, 0.1615010024679284, 0.11970674634099969, 0.16645772923384944, 0.12194174657305404, 0.11330099490981911, 0.14708408575144508, 0.14103646510310713, 0.09521298486018374, 0.14959238018960724, 0.18765001948322022, 0.11156984304468479, 0.2173343177644476, 0.21687012976936756], [0.10060556202886567, 0.041110748650446054, 0.034470244896628206, 0.05414648927868374, 0.025840302734004877, 0.025779475352817008, 0.02185519953678933, 0.057842223829920256, 0.10138061318186023, 0.0258427771980003, 0.05247171765433685, 0.03917482531359119, 0.04256333562455351, 0.03430135315284133, 0.06377967337386743, 0.031116840564796043, 0.0333149038675812, 0.016341580476071087, 0.05357006174181739, 0.2496532537043095, 17.577933265316872, 64.11143856663858, 56.989375314404896, 45.891652568694084, 28.981075286865238, 21.38832957513871, 25.622961598057902, 41.65639492773241, 39.85217917350031, 7.364147036306321, 0.018185224692006747, 0.018358147973495147, 0.05809493708394228, 1.0504779027354334, 2.659893309877765, 4.07548945276968, 10.981632355720768, 6.439498278402514, 26.065534391710838, 58.492627605315185, 60.81889514000186, 58.7495977647843, 61.2541134895817, 59.75516011638027, 61.350305695687574, 57.12762317349834, 54.311255485780784, 47.29694758692096, 42.76819859781573, 43.96754172540481, 47.8675308535176, 56.043719322450706, 57.33281020195254, 57.93223073405605, 55.79525286151517, 59.39072878130021, 55.23128663339923, 53.67541574662732, 55.759841703599506, 52.94117158459079, 47.97659235615885, 40.0814103311108, 40.08690557172222, 43.10467127830752, 51.2390237469827, 55.03331676606209, 55.379889549747595, 46.63935046042166, 40.441319173382176, 40.91198398220924, 41.65415917673419, 40.11108306146438, 39.938812563496256, 40.41056779123122, 39.86691159586753, 41.49428729088076, 45.021992498828524, 41.120465801608184, 43.287885189056404, 43.552080354382916, 45.9042472993174, 45.430115115258005, 48.45720037337273, 46.41888972251646, 55.023557909073375, 52.444932922240234, 63.99984321286602, 37.79375460840041, 29.479959587897028, 64.53607436149352, 51.96892976760865, 55.13089749120898, 49.87789853926628, 53.973429587579545, 46.97364622546781, 46.740088693557254, 39.72007766846688, 42.99631580229729, 41.984081499038204, 41.32112641488352, 40.09338140487671, 41.89087813900363, 42.3591189230642, 42.647911271741314, 44.04906426706622, 47.27983036348897, 48.24488247594526, 50.075911552675315, 52.814137781819994, 54.93580664357832, 54.40722019441667, 53.653842710679584, 53.886337280273445, 54.07854910819761, 46.315194022270944, 43.12149824634675, 51.11309213023032, 57.189984936867994, 57.65617432132844, 57.260791563218646, 57.250205086123565, 50.35934202132687, 44.64341709690709, 44.145111345475726, 43.84151204939812, 53.388039373582416, 54.89736741588962, 57.42094585972448, 54.626370860684304, 52.18065146476992, 60.014868090229655, 60.56765164098432, 55.73228313076881, 58.38764536765314, 56.76942840699227, 51.2855822809281, 24.974215299852435, 6.025799522476812, 5.752115163110918, 5.604082461326353, 6.473681734454248, 2.699101322120236, 0.15307791170574006, 0.05570113831650346, 0.03905288326824385, 4.788404991549831, 26.039317269479078, 37.842301784023164, 22.959509472693167, 23.89745016251841, 37.032685356755415, 35.373389413279874, 46.805466759589414, 50.58208165630218, 31.426329881914203, 1.6895583776697036, 0.04489716502927965, 0.008841318269861082, 0.07798308521629342, 0.014188839892496266, 0.012400903675194471, 0.033545592093780156, 0.038551061203883547, 0.05174874515843488, 0.03824170723917984, 0.035387236820233446, 0.02772678850188611, 0.014611519328618964, 0.08874141115454898, 0.06201913820639734, 0.10619560602091013, 0.01883631707319329, 0.05887056663331967, 0.0502515527149362, 0.056010775733739145, 0.01013317329418515, 0.04198966600421456, 0.031988499235481985, 0.058682254560652285, 0.04438797702952739, 0.04826827748348156, 0.015681402292102575, 0.02232519639355521, 0.044969372646582705, 0.02172731264914957, 0.04220942598617366, 0.03990923550220267, 0.03280363593911452, 0.020564161353714524, 0.03677402450252445, 0.11184263163276258, 0.0678860157307598, 0.007451944562020682, 0.03399690215085303, 0.039309511231558944, 0.2369587631115029, 25.665125116225212, 72.41523742675781, 62.95874418750886, 53.47225266118204, 38.27560601695892, 29.180931814255256, 26.83218517611104, 38.63250640130813, 41.74301262824766, 8.947522563319053, 0.14052963665416165, 0.02655080331849956, 0.2987537286694973, 2.1405195276583395, 4.527048151339255, 9.641517323832359, 7.151871794654477, 8.277239511089942, 27.56836698901269, 60.71857267810453, 63.78310088188418, 62.946702511079856, 63.30908636892996, 61.872734023678696, 63.11139106750489, 61.00105393317438, 56.16811729246571, 50.284699316947695, 44.6869279492286, 46.32573735329413, 50.41711068922474, 59.81709041903096, 59.27607397879324, 60.16619705384778, 58.44994437310004, 60.21970995010869, 55.977042951891505, 55.261783061488984, 57.117240659652225, 55.71065910400883, 50.08900050194033, 42.14427109687559, 41.38252719756096, 45.16869306564332, 54.73224347637546, 57.51001111922726, 57.981495703420336, 48.69217780328567, 43.50820079926522, 43.17705469746744, 42.52469001277801, 41.61704571016374, 41.335239102763516, 42.19386554533436, 41.776988198680264, 42.889231174222886, 45.94448689491519, 44.22570820777647, 44.54718174472932, 45.638153706827474, 47.94713535616475, 47.74129721426195, 50.48319085951775, 49.74962134515086, 56.03076373377154, 54.205426016161525, 65.43468544560095, 38.36424373811291, 30.322680819419126, 63.32518377611714, 53.17097148587627, 57.446598160651426, 53.213505668024865, 57.1852663255507, 49.29612082819785, 48.99236855968353, 42.76267982298329, 44.61400716535507, 43.60761719365274, 44.276059673678496, 42.52383885845062, 43.84225729973086, 42.906705333340554, 45.54005522881785, 46.285560515619096, 50.58841628413047, 50.76160461671891, 53.54226304638771, 54.15015197569325, 57.467206293536776, 54.4512370324904, 54.32418754023891, 56.712561884234034, 57.30638911647182, 48.08629712750835, 44.990205610952074, 54.74102566319128, 59.10863191850724, 59.18046620584304, 58.37315613223661, 59.05714296525525, 51.83582805818128, 48.4231149765753, 46.30969485928936, 45.113415102804865, 55.23010207760719, 57.795767553391, 60.432098450199256, 56.312248706817634, 55.08209928389519, 61.44317173188733, 60.91359292307208, 60.563282120612364, 60.45533849347023, 60.46736055804838, 53.44434499740601, 27.53121429874051, 6.777709549473179, 2.8578151281802886, 3.7169242674304597, 8.555613063996839, 7.948978312553899, 0.6402322421631506, 0.28210182704271813, 0.06338419963515575, 6.305734669008563, 31.969278089461792, 42.483493358858176, 25.289011001586918, 26.42255048598013, 44.3079093194777, 39.71339002732308, 51.74559393236714, 57.350029407009, 38.76949910194644, 2.353915341438786, 0.14214789014189474, 0.016891104920256524, 0.022554136024067, 0.03560522713908746, 0.039522135104503364, 0.03943619153071796, 0.03687651557547431, 0.035650342056948336, 0.01654898729025116, 0.008163778618308566, 0.050548162807019494, 0.0765761953868693, 0.051868607275067806, 0.056729167023853916, 0.01478995078228294, 0.08905736879715997, 0.028762767286670786, 0.00961703591934976, 0.06837445806952254, 0.042509468152157726, 0.22911826689397136, 0.15526801918543157, 0.16777720843111316, 0.21009529249802714, 0.13426512119270143, 0.10194947943091394, 0.12785779928127605, 0.09130906208508438, 0.184361862859899, 0.13738536666477882, 0.12210431809146559, 0.16505327556402455, 0.12411884587979126, 0.09981432343803107, 0.20432729394205157, 0.13427826726148206, 0.13645990180873102, 0.12588978069083345, 0.11648318625145382, 0.39943790664115264, 32.83871262304245, 78.93689170960458, 72.27336529762515, 60.660509832443736, 43.04217223198184, 33.73101065235753, 37.2077799612476, 54.90842065503521, 54.72385744894705, 10.365773170225083, 0.39140452480604576, 0.14897662935958755, 0.516935906583263, 2.0342740416526794, 9.995095460645615, 12.227160411496317, 20.35120979432137, 11.116935495407352, 31.985012677408037, 63.40765553136026, 65.85869758359848, 66.57305532886137, 66.20964773239629, 63.28930585615097, 65.62273956114247, 62.80303393640826, 58.56419909384943, 52.41206738256639, 48.4922859745641, 48.3627575443637, 52.1720967754241, 61.26553543152348, 62.00889518184047, 61.581639243710434, 57.66785906207178, 61.301150552688114, 57.44717474906676, 55.79376236084969, 59.86363718586584, 57.41319525626398, 53.92543938852126, 44.869792769032145, 44.555869794661, 48.41252065473988, 56.788365610184215, 59.17773623620311, 60.012891215662805, 51.15965850891606, 45.159020500798384, 44.57332041955764, 45.570100584337794, 45.12042830067296, 44.81267913695305, 44.972554945176654, 43.12177281225882, 44.61876500037409, 48.75595161991735, 46.107763398078184, 46.790863775437884, 48.61255761115782, 49.799184414648245, 51.27414464950562, 52.642008489178075, 52.07433169887912, 57.94387232872748, 57.25672406534995, 66.2563866953696, 39.88474661304105, 33.403896747096894, 66.33636382318312, 57.37650932804231, 58.69484539954894, 55.027499891096554, 59.46117454959501, 50.14920103934504, 51.564972708302165, 44.783151534295854, 46.56544516163488, 46.41456727058657, 45.5962118025749, 44.377217600422526, 46.573376194123306, 45.65725957193683, 47.59948784305204, 47.76871065939627, 52.79058002656507, 52.993135144633634, 54.923368807761904, 58.00496716653147, 60.09330372656546, 56.69517793963033, 55.64698726900163, 57.97343523271623, 61.224774160692775, 51.39438098476779, 47.18788608427971, 55.90422022727228, 62.49412767348751, 61.4514636224316, 61.5849732583569, 63.087739175365826, 55.48774688474594, 49.606031217882716, 48.51312944965978, 47.85894086284023, 58.53662483153805, 59.945924589710856, 62.224025418681485, 58.782286797800374, 58.107003704194106, 63.782363476291785, 64.86483173985636, 61.11442219826483, 62.756910785552, 63.1871751816042, 56.4277821202432, 28.150958591891875, 9.73807332977172, 10.163633823394775, 12.581810335959158, 15.927545024502663, 7.89368466023476, 0.515949001475688, 0.20504620617195485, 0.17063753559224068, 7.425173232632299, 40.637178805566606, 52.33070173571187, 30.74305299789675, 31.948615043394028, 49.45274106917843, 48.245604192056966, 61.41074549767279, 65.8822867178148, 46.30873387859714, 3.062923218934767, 0.2014215530887727, 0.07584624382997714, 0.15089918829260335, 0.1532992191853062, 0.11075909219441876, 0.11204193706714338, 0.12903244955645454, 0.23822614832991557, 0.14076407488074996, 0.19550709384343318, 0.18050123937428, 0.1560562623724822, 0.2406876194741457, 0.14224070935480057, 0.20564821338461292, 0.2106840157460782, 0.18496036138986388, 0.1176511945443288, 0.27112629985617054, 0.15940814218934507], [0.029996325892786828, 0.04423706153888376, 0.0036944022764556954, 0.02556673465146413, 0.06985373554691192, 0.05045720135733005, 0.02280739128529545, 0.0369791177311732, 0.03839661021746936, 0.031020945508874236, 0.033547917170630354, 0.05863165062281394, 0.014793749620777466, 0.05962592166578097, 0.11885141683441978, 0.09130515503667055, 0.05418211619760241, 0.04723414688581421, 0.05551015642741996, 0.6174844563488038, 27.894794479493175, 62.45558646417434, 52.790442743609034, 33.46082602777789, 18.087866883124075, 19.341158290063184, 30.5593527132465, 41.661388104961766, 25.31115278120964, 1.6654663220528634, 0.06635864325348409, 0.16331493013328122, 0.15601026645350843, 1.9553631856556863, 2.9799964687516614, 5.379909200053062, 8.133180170289933, 13.349628025485625, 46.03139092845302, 60.29758468750985, 59.34409179995137, 59.237273893048695, 54.38403898669828, 56.81841096570415, 57.186325365497225, 57.07253348442816, 57.3467856068765, 45.80199895366546, 44.14455829128143, 48.84757034240231, 53.951676122603885, 57.71376648256856, 57.59720933052802, 56.307365355953095, 55.116196447803134, 55.343486032178326, 54.49159822156353, 58.22397270510274, 56.9727679990953, 52.495405981617594, 45.273334057100364, 41.2450598901318, 39.99544374404415, 40.920899529610914, 43.56784828247563, 46.13121132696829, 45.421878137896144, 41.64973474317982, 42.380593899757635, 40.137637507530954, 40.622917067620065, 39.42606856746059, 41.94530886988486, 40.46164489561512, 40.53143562809114, 41.821950327965524, 42.73241089236352, 40.60063800504131, 41.3702658684023, 39.19482131158152, 41.345507867874645, 40.278532966490715, 44.35196145888298, 42.34540631694179, 53.220577701445556, 51.33443932379446, 61.400739531363214, 40.706887168269006, 30.64478389678463, 61.91034563126103, 51.18693467109434, 52.37043142318726, 44.71120349822506, 47.910453350313254, 43.368309467069565, 43.284339366420625, 39.488034171442834, 40.475384958328746, 42.86347689167146, 40.09321666532948, 40.518550642075084, 42.20654656810146, 40.44848142131683, 41.680270394971295, 39.61222817820888, 41.07102824795631, 43.93244827947309, 47.440467111526004, 47.67444825941517, 55.39866985813264, 55.16027212142945, 55.25654669730894, 55.90753855243806, 52.224334901379, 43.64567202906455, 39.938443860700055, 47.16327321144843, 54.443035356460086, 56.1197466235007, 55.54980270324215, 54.89855197168166, 50.607835938853604, 47.184030394400324, 42.82710475306357, 43.57401424838651, 46.685465766537575, 52.5733591664222, 54.52851949199554, 54.80360707929058, 50.47790742689564, 57.02244481732769, 57.32617355162098, 60.0685025799659, 60.6965171906256, 64.5100494354002, 59.73952554887342, 46.57739662354993, 16.429561338117047, 10.418669273776393, 3.6913913536456326, 4.570812977129414, 7.358469895778164, 1.3546961978558572, 0.052963059635893, 0.1004767060400017, 0.7684133382093522, 17.877225798945275, 42.62618918572703, 26.719885756892545, 24.677652735863965, 44.30586576461793, 37.2154168159731, 41.595923746785815, 48.824804905922186, 38.97771812254383, 7.833861160662867, 0.1118666714718265, 0.0211438677468968, 0.026587154190506668, 0.04505287239988966, 0.06261836451989028, 0.10198400701366125, 0.04659989120198354, 0.07000088571540772, 0.018447577247336026, 0.05826879307747849, 0.07651319997685571, 0.034192377145612435, 0.03941200613494843, 0.030918019681027344, 0.06257211196146185, 0.013223789358181099, 0.020362668738309896, 0.06385201888699686, 0.031369032879029556, 0.04509980294613108, 0.025249748535814787, 0.05624027269321585, 0.02011966756394794, 0.061135869473218925, 0.03962446146854951, 0.06703048704131957, 0.034017375850629424, 0.026428750190403194, 0.055820628880493106, 0.05400387435069969, 0.03073074948793698, 0.01759879970772853, 0.03849286150427596, 0.08243954124590082, 0.040811445759308916, 0.047247538102730635, 0.039503113141343485, 0.022729598887024388, 0.039352270429052656, 0.897268285193751, 34.119819518058534, 71.4222345044536, 59.45860147476197, 41.26088665377709, 26.037999353101178, 24.539961853334983, 30.50387667071435, 41.427497171586566, 29.746733711611842, 1.9256533153595465, 0.09541913912060762, 0.09242586506110045, 0.35961656440650264, 2.835059007329326, 6.8744837372533745, 8.360531041699073, 8.67246929676302, 13.404307826872795, 46.35253890868157, 63.57539176940919, 62.670242094224506, 60.694316740958925, 57.3457657906317, 59.644345314271995, 59.82224049106721, 61.09064479028026, 58.685212058405725, 47.958231741382235, 46.51442689280356, 50.60257604045253, 55.26476798519012, 59.975271763340125, 60.535288164692545, 58.06226515000867, 54.75385181365475, 56.29206026754072, 55.442451353996034, 58.99808383757069, 58.410763817448775, 56.095455385023556, 46.91051567754438, 43.0586265748547, 41.894423961639404, 42.92457565184563, 45.91000141636018, 48.3556031411694, 47.564727798584975, 42.575155227415024, 43.10711883729504, 41.7353993077432, 42.881225616701194, 40.94459456782187, 43.08887981599377, 42.40252779376122, 42.489824064316295, 43.7710270574016, 45.342830611813454, 42.460818136892016, 42.98187363532282, 40.75026858237482, 43.861543593868134, 41.79801602517405, 47.65407939111033, 45.09709804288803, 55.59934616088868, 53.59534448192966, 62.84910609645229, 41.644149288054436, 32.31634116941883, 64.65494571193572, 52.85893517155802, 54.563165787727606, 46.45071583409464, 50.2210823951229, 45.16636317776096, 46.49139473515172, 41.35518435508975, 42.323405742645264, 44.52658145658432, 42.70165558784239, 42.50393675219628, 43.622039748776345, 42.33054445635888, 42.592464646985455, 41.94323785843388, 45.24749348240514, 47.90371079598704, 50.23369673759707, 50.50763114806145, 56.99504313930389, 56.34324719828945, 57.44029883415469, 58.365515355140936, 54.991061072195734, 46.586288636730565, 41.80546460613128, 48.30593024530719, 56.566834065221975, 57.324977228718424, 57.41925531818021, 57.083763230231504, 53.29854657573085, 48.981640877262244, 45.959666467482045, 45.208583570295765, 49.73984679868145, 54.513818448589696, 56.524954918892156, 57.00889695075251, 53.46112881937335, 57.70105800321026, 61.09775212503249, 60.94048077060331, 62.7439042060606, 65.38840147756761, 61.4377078702373, 45.70338664516326, 19.472944044297744, 6.4986785092661465, 3.420617392947597, 5.892714483122672, 8.866406967563014, 2.204496572094579, 0.3128384696620126, 0.03362083724970299, 0.4338679510739542, 22.87832425486657, 42.45975909694549, 24.850270363592333, 26.180353933765044, 47.119009264053844, 41.95085117893834, 48.02345683497768, 54.71012523097377, 45.779582608130674, 9.470085232488572, 0.12730056990779218, 0.016657545779561325, 0.012367840277992431, 0.11094001917949609, 0.053813677701738574, 0.030593037522668322, 0.01822205628418634, 0.08133144102870457, 0.010031859123808964, 0.044626460200355905, 0.09174156468361618, 0.012167618410932201, 0.019706771070618304, 0.014609290970369213, 0.026337604879611926, 0.013222622031706476, 0.03689683222722623, 0.05025513417598221, 0.08820981508301151, 0.007769022129415985, 0.16624532369596345, 0.14644322255926748, 0.0767404216551973, 0.07783062605848236, 0.12242022210792189, 0.1444912918152348, 0.1517141526264529, 0.10065984701918018, 0.12109423882418102, 0.10247852442966354, 0.10173020974522638, 0.14531327351447076, 0.06229665355696794, 0.16682391926165552, 0.20728891324852744, 0.23939489206719786, 0.09145543850477665, 0.20228942345467307, 0.18915132198843265, 1.2551476686231553, 42.539230239006784, 78.09520598380797, 68.2080247325282, 48.476443521438114, 30.247887103788315, 29.983376187662927, 44.21936181283767, 54.934649544377486, 36.50517755939115, 2.6880108204580124, 0.27800340986540245, 0.2340290283844356, 0.7094102881608472, 5.258915847347629, 13.394960818752168, 14.529917259370128, 19.530685255604407, 18.010209837267478, 51.061556108536266, 66.40481702743038, 65.70179885433566, 64.99018284582323, 59.94762297599547, 62.26865806887227, 60.86736779059134, 62.23474525636243, 61.555359363555915, 50.29922385369578, 48.197774810175744, 52.98326646128009, 59.25142188226024, 62.06231001884707, 61.77978561770532, 59.02069630161409, 54.276809230927505, 55.459690170903365, 55.957842949898016, 62.32098248697097, 61.400504189152876, 56.95880828365203, 48.72822046279908, 44.3018884812632, 43.4336208528088, 46.91426546342912, 48.31301012346822, 50.107733741883315, 50.09196973616078, 45.42949930314095, 45.449118998742875, 44.38729809176537, 46.578800832071614, 42.551334673358554, 44.99364160722302, 45.675553506420506, 45.794879851802705, 45.72138640188402, 46.59809497094924, 43.7410326926939, 45.26701511875276, 43.1930422782898, 45.89142899359427, 45.071818367127456, 49.726338155807994, 47.61797789604434, 56.40929991199125, 56.46606445312501, 63.93759912060153, 43.87693105205413, 35.14863760240617, 66.38129065113684, 55.56742983479654, 55.29713538385207, 49.29616789663992, 51.85470250345046, 47.600331152639086, 47.92784121728713, 43.9166921184909, 43.45596267331032, 45.840877486813454, 43.93188738053845, 44.985318337717366, 44.91799869844991, 45.0351716626075, 45.23774639252694, 45.409134357206284, 47.53278009353146, 49.48256677196872, 53.10682896644839, 53.14347174859817, 58.82322457528884, 59.94508128012381, 60.04747083110195, 60.20957062321325, 58.35921995101437, 49.172793665239894, 44.26758735410629, 51.79737706338206, 58.48907786030924, 61.02917732730989, 58.0515923807698, 60.27231677885979, 56.362082419856904, 52.10641668688867, 48.23808893080681, 47.98161691234958, 52.334718242768325, 58.13482899819651, 59.12386248188635, 60.81145832615515, 54.13200316890594, 59.407285105797556, 60.71844323988884, 63.799547380016705, 63.905945593310946, 67.55356942453693, 63.07308520040205, 53.15411313887566, 21.461436671595422, 14.080095925638753, 10.626982431257925, 13.065936719217609, 16.695890272817305, 2.7422851468286207, 0.3473820483251926, 0.1297523577006594, 1.223050178058686, 27.951974791865197, 57.8468446577749, 37.953312704640055, 32.36060119444324, 53.835581810243674, 48.720901320057536, 57.384432515790394, 61.16169460358159, 54.46912696284633, 13.220424171416992, 0.23899945280244275, 0.12942209719650208, 0.16669480280289728, 0.23431482514546764, 0.1520489024058465, 0.15205386665559587, 0.11335266754031183, 0.1972935495958213, 0.09691546205431224, 0.16154577264622336, 0.3172830053635182, 0.14510780873317874, 0.07789408878212975, 0.09333298977224097, 0.1689169634013407, 0.12962699507273015, 0.14761164453962158, 0.17628663730236793, 0.247051619113453, 0.12499921880061589], [0.07598535007526798, 0.020134675226384596, 0.009451152028275595, 0.018284695463315136, 0.02918333040490266, 0.0032532084104229487, 0.058689685613517804, 0.030468766570031166, 0.021491328840174025, 0.0541433674703923, 0.016926708856537458, 0.05677502121656172, 0.021809847131671927, 0.017949202578634988, 0.025998660768832893, 0.05475809940347268, 0.04730571098926087, 0.047000076381429556, 0.0878498610109091, 2.069986241479074, 33.33621232740341, 62.50493380331225, 51.5292203041815, 37.26121441010506, 20.988069349719634, 26.162546373182728, 42.55918333607335, 45.888279330345895, 16.016820130809663, 0.19022775213083915, 0.06024250753163811, 0.14697828900910195, 0.3527760734000514, 3.173998123215091, 2.776924088116615, 10.378363978478218, 8.165883912194161, 31.78961196253377, 54.99493637392598, 61.179164840329086, 54.204068876081905, 55.22319478373374, 51.15992523008778, 53.976085032186205, 56.98619034982497, 55.423839707528394, 51.853239459376184, 43.25211709545505, 41.93354568173809, 49.63916347872827, 55.66942322638727, 58.63453895814958, 55.286450847502685, 52.76383338436004, 53.99342190834784, 53.96336086334721, 58.565724895846465, 54.45192736964072, 56.27353883558705, 48.24868717501241, 42.85315321337792, 39.601041578477435, 41.01808801774056, 39.35990602739396, 41.12880083822435, 40.406088444494436, 43.246080567759854, 40.416251305610906, 40.48359840146957, 39.36705258584792, 39.08362996193671, 39.79450856485675, 40.48539484700849, 39.38262047306184, 41.94095896136376, 41.33226202380273, 41.00670922187067, 39.275147530340384, 44.5705629933265, 46.34840080814977, 47.27725728865593, 43.10171381119759, 46.60000124285298, 42.48503877270607, 50.914443692853375, 49.73503405048002, 60.09184852723153, 43.228943732477006, 32.19926430333045, 59.881244705569365, 50.29966708152525, 53.27145476495066, 47.1660110258287, 47.63403215715962, 43.68440935688634, 45.53983949845838, 41.85703200678672, 42.45478553156699, 41.65333155662783, 42.52994598880891, 40.408284971790934, 41.01537765995149, 37.81000106565414, 38.855759866776005, 40.073702873722205, 39.91419969066497, 40.16311722417032, 43.76282145900112, 44.649210437651604, 49.608729808561264, 53.518242451452444, 54.30869810042843, 53.26574379397977, 47.46106347730083, 42.07114634975311, 39.86112217749319, 40.42860284928353, 51.53344469685709, 54.98359287938764, 53.42891047077795, 53.53190014439245, 48.71292321912704, 47.43550139088785, 43.43297366173037, 41.5730014154988, 42.09408829289098, 50.04331273417319, 52.89697431748914, 57.6046932128168, 52.2145878115008, 53.31109816028226, 55.44896248848208, 58.007061712203495, 56.54313118227067, 55.16055453208185, 51.618885686320645, 53.92737311701621, 32.38398636541059, 16.668718053448586, 3.3385351780922186, 4.904313481623127, 9.02212506340396, 1.17620911088682, 0.22716668855038383, 0.0670767204475499, 0.12738617257245127, 6.025898562323663, 31.78645641573014, 34.7923412630635, 22.022315994385753, 21.647323677616736, 41.682015849697976, 40.64442734564505, 49.11211067630399, 46.41239427751111, 19.53824954648172, 0.9742421644829935, 0.0418388884093973, 0.05159207251704028, 0.05454459835985496, 0.053966661629777764, 0.02072062332092995, 0.028620862905236504, 0.03548977768889839, 0.0390428704990735, 0.06365642131816956, 0.03641797747883586, 0.003385304951206631, 0.11961195062124923, 0.053917712441855864, 0.015135542621024916, 0.07924555215023218, 0.04841105712036933, 0.02079030476330269, 0.03913521473746627, 0.010160602114704109, 0.032586346590711225, 0.09120402376978629, 0.0259363797358087, 0.04334864469485418, 0.01622422155173075, 0.0254219938294902, 0.04054726416906042, 0.03488987338759246, 0.022810963170242407, 0.03544768115745918, 0.03007477712667277, 0.04460145509050739, 0.030435361306092916, 0.030853961324018818, 0.01018573554427994, 0.04736949163939684, 0.03985811062457581, 0.0514303207127077, 0.048457171782971396, 3.5189877402397896, 42.0843804267145, 70.52021488066643, 57.953325240842766, 46.98589578751595, 23.17772073130454, 29.83534593735972, 41.99492685256466, 42.892780919228834, 19.78893606893478, 0.253032099816107, 0.03752603556119627, 0.20037841712755544, 1.3492327039280247, 6.0428157448768625, 6.329573854323357, 9.241755239425167, 7.546544603763088, 30.262956849990356, 57.19702166895713, 64.95325765302105, 56.08615544534499, 58.14288162416028, 52.834439969831905, 56.84068218354256, 57.686941392960094, 56.77578264667142, 55.70762318949546, 46.75189502777592, 43.19865911237655, 50.40981115833406, 56.77056589434224, 59.31437592352591, 55.97075931487545, 54.37203653397099, 54.57376795430338, 55.555466605770974, 60.74938289580807, 56.74220323562623, 57.898400291319824, 50.89380810337683, 44.19358791843538, 43.01995592732584, 42.627460033662864, 40.754453751348684, 42.36346490921513, 42.346594795104, 44.93241733120334, 41.63395897034676, 42.22242824492916, 41.12188177724039, 41.5194296836853, 40.34199299350862, 43.41577799089494, 42.65652479663972, 43.59459100231048, 42.266652968622026, 42.57668102941206, 41.00496768951416, 47.20255967109434, 47.83317873554845, 50.13559825958745, 45.62234263266287, 48.39556817085513, 45.15068154181204, 52.45663727483442, 50.927211007764264, 63.25346715988652, 43.05462575727894, 33.937523441929976, 61.016990523184504, 52.41577402237923, 55.015842606944425, 48.11694652803483, 49.82608402928999, 46.48995914766866, 46.80723574853713, 43.70139714210264, 43.7234212506202, 43.094877119987245, 44.31040394690729, 42.31078747780093, 44.38390131919615, 40.73340631300404, 42.41811529282601, 41.99066715855753, 42.29591777247768, 43.5254749175041, 44.365968242768325, 46.97332851348385, 52.591853141784675, 55.35282127318844, 57.8679980001142, 55.45042945492653, 49.342871558281686, 44.54309855737994, 40.74851136053763, 42.266586288329094, 52.76969340539748, 58.27766603039157, 55.018902055678836, 55.57343890590053, 49.607388357962336, 49.71333549868677, 45.81502514500772, 42.69592892739081, 44.59164965537287, 50.28741359710694, 54.65119161913472, 59.85975403939525, 53.670795194564334, 52.62053351248465, 55.21515000251032, 57.76209792783184, 58.45627900092833, 55.35041686027281, 54.304281511614406, 55.65310616647044, 36.47706200999599, 17.795485565739295, 5.046884773239013, 6.031989512904999, 7.068211070952877, 3.0798256925998198, 1.0764031761115598, 0.0963261872229557, 0.0982787614808448, 7.705985028897563, 36.60104028640255, 37.49212434214931, 20.93407400192753, 26.60951026024357, 46.99273640109647, 46.32719255262806, 54.677283225520966, 53.45078552922895, 25.55182941498295, 1.2663734920563237, 0.13392519265893968, 0.04188806359325686, 0.047302501080858136, 0.02404734289513961, 0.007175653515714071, 0.035581961048827056, 0.021688644361171513, 0.04601517459377647, 0.03568817913952855, 0.12181752541613196, 0.023674733050528075, 0.13980468765141504, 0.026825597141719153, 0.03875034365562662, 0.02414373207777258, 0.04267144212198835, 0.050039564694968924, 0.04899049155233849, 0.05503921153684778, 0.14244321703670487, 0.2736955442495885, 0.1617626214940702, 0.12783717619435442, 0.09473755069437528, 0.1983032075147475, 0.10883032028833706, 0.17632730124938875, 0.1468451582496205, 0.09705377156816183, 0.12357836318833214, 0.10509945677533265, 0.17240084016755705, 0.13663574963087036, 0.15030784502385125, 0.12573482408638925, 0.1262292802153576, 0.19141255307101435, 0.1966317262380354, 4.8895369325914695, 51.94718022500315, 74.86645990802397, 66.0979700088501, 51.97485254656885, 31.547395798467825, 39.36488351514263, 55.37875990713797, 59.71355945833268, 23.32532540444405, 0.6599058090679107, 0.12612634098097203, 0.3689789555726513, 1.1891472940483403, 7.8914690113836725, 12.288088548567988, 20.29162899140389, 16.16490529429528, 36.50411067470428, 59.02534038789811, 67.15430351995653, 57.556475516288515, 59.7709672681747, 55.75427586032499, 60.2536972876518, 60.35447082211895, 60.54290932993735, 57.44157752683086, 47.29007951674923, 46.356304384046986, 54.82308949193647, 59.921127365481475, 61.517743833603404, 57.51407469472578, 54.67747149928924, 55.78697273808142, 56.70467007544733, 63.58657836914063, 58.88639042454382, 62.538321018219, 53.52412992908109, 45.812471682025546, 44.82636036411409, 45.24196294046218, 42.59834820224393, 45.45603805972684, 44.394762362203295, 47.36560475441718, 44.93462562561036, 43.695129194567286, 43.43684896346062, 43.577356107773326, 43.36689349143736, 45.09595663316789, 44.717345929914906, 46.87980351909515, 44.579474618358, 45.78969840080508, 43.44390922977079, 48.58228083579771, 49.919985571215236, 52.2437035652899, 49.00487699816304, 52.185817226286865, 46.56616295537641, 53.821088652456964, 53.975371160814845, 64.67405157704508, 45.86083058388003, 35.97016234551707, 61.46341508434665, 54.81840225958056, 58.039652685965265, 50.6410897931745, 52.57550862527663, 48.190012439604736, 49.91329008533109, 46.111269997012236, 47.77602587976764, 45.67360016607469, 46.69912345947758, 45.0253539700662, 45.752177007736705, 42.289955769815755, 43.58022336036929, 45.001117644771455, 44.169112328560125, 44.96906795809346, 48.46462542010892, 50.27932566981162, 53.734282678173436, 58.562783118217226, 59.24696999211466, 57.34644828304168, 53.88356808693179, 47.27768482700471, 41.54915732722129, 44.22348422388877, 56.565818171347345, 59.86766938240298, 56.82613019020327, 59.077013692548206, 53.78613248948128, 52.561850932336625, 48.10091972351075, 46.03674496373823, 46.861411525357155, 53.68211123251147, 57.03458063064083, 63.93386110182732, 57.09694239401049, 57.03049352092128, 57.115263785085375, 59.80164020292221, 58.53151006083335, 57.878215774413086, 53.509946638538, 58.07496578462663, 37.82702807457217, 20.710632262691377, 6.0062984785725995, 16.434439786018864, 19.566725953932732, 3.590561680255398, 1.0402608638809574, 0.15086885121080185, 0.26460064034308156, 9.810702877659953, 46.91133937528057, 48.93962837034657, 31.448277504213397, 31.793559828112205, 53.9299540365896, 52.38475984142673, 62.18698647714431, 61.103023790544086, 33.003403140652566, 1.7133208316180015, 0.24648898882010292, 0.15172371340374793, 0.14063054575554787, 0.19228347246685337, 0.09435917986857315, 0.11491688118586618, 0.21961776539683345, 0.1966945454478264, 0.11026105077396478, 0.21936906261309502, 0.12988610133048029, 0.25371410192981847, 0.07949415534254044, 0.057282952832118164, 0.1271180264771946, 0.1254951534792781, 0.13056693899054683, 0.12615016631541714, 0.13924803284387435], [0.0882822793397692, 0.03382491541185206, 0.029810063105316895, 0.03902090675828438, 0.05529656345325132, 0.05013476261087964, 0.022250851390943415, 0.04237022401104051, 0.06832863835077133, 0.03803133949517243, 0.03064045453474166, 0.06263118500130312, 0.012225338347977208, 0.03712023495726528, 0.02264056031802489, 0.024143684197277315, 0.040364268746587544, 0.02945403714904622, 0.03187874947944957, 7.121927440166474, 54.06221635880009, 57.419286697141594, 52.75709867477418, 29.922195057715143, 25.932687636344667, 26.26471431024613, 41.385963193831905, 37.768565147153794, 6.508143188491945, 0.12788707150086281, 0.08197086397558451, 0.05157818334297307, 0.8876583556975088, 3.110524367901587, 5.374862580530105, 8.029198627318106, 13.709135805406879, 47.19306361290717, 59.82586083873626, 57.34252983523954, 57.87460327148438, 52.78113103681996, 47.58911317394626, 50.47289856018559, 47.305208098503854, 49.0072774887085, 44.802029901935214, 40.87212485651816, 40.8542819946043, 49.06242209096109, 56.92300096634896, 58.64475281007829, 54.01852899982084, 52.53921101170202, 52.08356103589458, 55.10236617057554, 54.72289254588466, 52.00217969955937, 49.00237844836328, 42.51064400519095, 42.62595384351669, 39.90778269306306, 40.252323688999304, 40.433133186832556, 39.48472761338757, 39.74419632265645, 41.054373864204656, 40.21705373640984, 40.260968592859086, 38.66614857027608, 40.08684673616963, 41.22194928507651, 40.10054365281136, 39.47096793882309, 39.900914622891335, 38.72918890368554, 40.06328505854453, 48.01619652778872, 51.904010618886645, 53.20431163234096, 55.08494692464029, 53.63532520109608, 52.27585915596255, 47.22221859039799, 53.77527536884431, 51.228684379208474, 60.78948913082, 40.909791377282914, 27.095268349493704, 60.984913379915305, 53.88757282687772, 57.74978953023111, 52.914707353038175, 52.53242923367409, 45.01231993398359, 50.51857456084221, 46.07119121859151, 44.87475456730012, 40.753935998485936, 42.73194805268319, 40.05764469023674, 40.68140352925947, 40.71161754669682, 39.64546634304909, 39.060919438639, 40.318949068746264, 40.72541644496303, 41.7235262932316, 40.924782676081506, 44.751501929375436, 45.50381252842565, 46.252757733868016, 40.70274514536704, 42.323527336120605, 41.63411978752383, 40.006296942310954, 39.55120786543816, 42.03150687679168, 45.25043133766421, 45.36598436294064, 45.674396407219675, 45.53343426796698, 43.89619773434055, 43.056904654349054, 42.7761374750445, 43.7753338198508, 49.65429990522323, 52.64558569077523, 55.30405836720621, 56.18406957195651, 51.461496660786295, 50.43421614554621, 51.84306875351937, 56.003479726852916, 54.6713565241906, 59.307343113806944, 54.290733645039225, 46.17612246544131, 24.33310977874264, 11.972468168504777, 3.888132048230018, 4.403166953594455, 2.6230848075882083, 0.9270065313866063, 0.02530427484382545, 0.0369148314630072, 2.3397026331193986, 24.18935687311234, 35.64018118766047, 25.2576869533908, 18.0363328226151, 37.40327089063583, 48.50886583328248, 48.430857735295454, 46.060789092894524, 34.38182992319907, 3.977500555976745, 0.10380614714156236, 0.007277513523736308, 0.03351725833190065, 0.020223497375545484, 0.013798328488314105, 0.07208178736149304, 0.08013027645046673, 0.04053823199243315, 0.019359200809811874, 0.018172191621194926, 0.019020927025966586, 0.012997776183540062, 0.04562393349084643, 0.051339045166969306, 0.02813051683798192, 0.0412979613869421, 0.041806440755364396, 0.045265312411732254, 0.031194468254163384, 0.06884302808752946, 0.046668846776048024, 0.05635512842526359, 0.045664746825012474, 0.019853342842731266, 0.008403559350558828, 0.021935330418449257, 0.04303156856387373, 0.05734430881397379, 0.04708128936228253, 0.07091488989610827, 0.03401531507411311, 0.04336860894616093, 0.07273904483525023, 0.09162934046358832, 0.028504737382454258, 0.013398102131642163, 0.07393295456084513, 0.029753297905347524, 10.63962717210093, 63.79207526483844, 62.437657310116684, 58.24382382054483, 36.09569780288204, 30.64361110810311, 31.497222800408643, 43.88223409652711, 42.64007437613703, 8.287922086254243, 0.050133916083723314, 0.05042890589984675, 0.1441047851356768, 1.6827078355896858, 6.4524102307135065, 9.438786679698575, 5.570040210600823, 13.634140087712197, 46.24266939778482, 63.48642849153089, 59.695846034634506, 61.19017885577295, 54.201080030010594, 52.279059810023156, 50.55902988679948, 49.48103312523135, 52.0652396448197, 47.780971988554924, 43.172630263913064, 44.496390973368, 50.946803246774984, 59.54877284265334, 59.62757325941517, 55.544872283935554, 52.67855713444372, 51.1679974679024, 55.403529674776145, 56.312848829454, 55.291338120737386, 51.672649614272586, 43.950773592918154, 44.328870465678555, 41.115884473246915, 43.27596118373256, 42.85857392895607, 41.458609411793375, 41.43754236159786, 42.58473365537582, 40.78355773802727, 43.44679609421761, 40.36725697978851, 42.23598787861486, 42.75124219156081, 43.10379658975909, 41.3650804950345, 42.20904119553105, 40.613020927675315, 42.067302426984234, 48.720779726582194, 55.76470544261318, 55.35391953683669, 56.950481091776204, 53.51737168527419, 54.53814106602823, 50.684796764004616, 55.982145955485684, 52.79015248821628, 62.45135422675841, 42.01111447426581, 29.266688554517685, 61.63607389696183, 55.65630289816088, 60.14402781763385, 54.55893355031168, 54.44231756271855, 47.78163486911405, 51.25871012287756, 47.84040374140586, 45.99527374390633, 42.89482447408861, 43.69715705994637, 42.557167237804784, 42.97324049857355, 42.06512943390877, 41.63341376089281, 42.84436710419194, 40.52859583208638, 41.79752965127268, 43.798628776304184, 43.4058661614695, 46.24801166595952, 47.82240790705527, 49.20316065511396, 43.87641722156156, 42.897950603115945, 43.07373554475846, 41.41854632285334, 40.46215480373752, 44.02711468358194, 49.10967488442698, 47.33970926653954, 48.469493081492764, 47.0414993070787, 45.046860325721006, 45.43049950753489, 44.29604414970645, 46.48605246697703, 50.25647786355788, 56.4315083719069, 58.59410324404317, 57.449186924965154, 54.81808846996677, 54.13058719327373, 53.31537746614026, 57.88627232274702, 55.80164632489605, 58.639477222196525, 55.92137275203582, 47.09959745407105, 26.363542349107806, 11.671329179117757, 6.472651131691472, 8.686639839603055, 5.487723879275784, 1.6795905318952378, 0.031956892362945986, 0.059854407389197624, 2.2119784931982718, 29.85499701192302, 39.012788034254505, 30.373418638783118, 25.60739371084398, 43.07650866047029, 51.47794315891882, 54.06748410194151, 53.61266959098078, 41.225577477485906, 5.730441616427514, 0.007531504229372068, 0.05496269467497065, 0.03984728963264535, 0.021312158111663117, 0.03791240434492788, 0.03522903200299029, 0.027502215572542725, 0.0697105000877092, 0.020001984967459596, 0.017726968132680463, 0.023117534320561156, 0.015453318764846173, 0.036366484879005345, 0.025816073288179697, 0.05441933149291624, 0.04899685774298926, 0.026128690787440827, 0.05943322373974708, 0.04373490622627639, 0.37310565671613144, 0.2052143777930929, 0.11783808169345703, 0.17738240350398327, 0.12551701762863707, 0.14107158257355615, 0.06262784868839287, 0.1766062951496532, 0.1216570146742367, 0.18536254222835266, 0.17011713206527695, 0.3151182247506034, 0.21856059470484335, 0.1330986297539165, 0.20213370842318382, 0.17350792914869326, 0.14136744572991325, 0.16417264217330566, 0.11645667194839447, 15.106707676764458, 73.49879218686011, 69.69301054554602, 68.0776059242987, 42.95203224305184, 37.23189077069683, 35.40851423817296, 54.20236656742712, 51.91660142713978, 10.381293008404395, 0.2448323390056049, 0.24587188967533652, 0.26439615615433265, 2.4279490978487077, 9.973308655523486, 16.150348397993273, 18.433833660617953, 17.463480464873776, 50.40107603996031, 64.3717231289033, 63.953441573727524, 63.576305681659335, 57.94295841647733, 54.32145757059897, 54.365180230909786, 51.411721783299605, 55.30899663125315, 49.24418080237604, 46.013132295300885, 45.303602987720126, 52.742432932699884, 60.92578757193781, 61.81559293500839, 54.70583808037543, 53.21507069372362, 51.74823760986329, 58.017648189298576, 58.308982233847345, 57.651855791768725, 53.41902609794371, 46.29476239604335, 47.347299052822976, 43.27874214418473, 45.71184327525478, 45.957681748174856, 43.09825820307578, 43.94139912820632, 45.75480499575215, 43.37737014216762, 44.92717312228295, 43.816255907858576, 44.35296558564709, 45.382834865200905, 45.347502154688684, 43.305312279732, 44.4197831615325, 42.81436097237372, 44.692227071331395, 52.392914449014974, 58.78026285479146, 58.07736235280191, 58.200783652644006, 58.36957108589911, 57.40395022976784, 52.63838421913886, 59.43209409713746, 57.58409684704196, 63.87463723459552, 44.880096835474816, 31.47524379914807, 63.20433555110809, 59.691092121985655, 61.709771310129476, 57.97876181141023, 56.791095579824145, 48.96910105982135, 55.45641891417965, 50.349712602553836, 49.06009612544891, 45.16336256457914, 46.821011112582305, 44.57427355550951, 44.50658913581602, 44.85302071417532, 44.90233667435185, 44.646551070674775, 44.37289122612246, 44.35251451307728, 46.51189304167225, 45.52167107982021, 48.98831675129552, 51.25887094005462, 51.00119867632466, 45.27862141209264, 45.29808813525785, 46.14860311631234, 42.75900063976165, 43.671402777394945, 45.667010584185206, 51.474997458919404, 49.672338885645715, 50.422441190288914, 48.97925999856765, 47.79468851704752, 47.39494800567628, 48.51407081850114, 48.657311854823945, 53.852934375886, 57.88722938106906, 59.820055730881236, 60.81778118687292, 57.05140759868007, 58.497695307577814, 54.334252342101074, 57.34512644429361, 56.03852610434256, 61.3408802401635, 57.433583736419685, 46.53205010198778, 29.76142102672208, 18.981584810441543, 9.6757351006231, 12.570027535961522, 9.441228355130843, 1.9696895201360027, 0.14420685869070793, 0.23759392660952386, 2.8808056106490474, 36.582169763503536, 49.316093537115286, 37.391817569732666, 27.23055285792197, 48.65340909650249, 61.748245839149725, 61.431545826696585, 63.82813361383254, 51.66287506780317, 8.78332136138793, 0.2679094353750829, 0.23302939089555896, 0.1205303981119106, 0.12143612088214968, 0.13922368656964074, 0.1912546929933371, 0.1547922632626949, 0.19120250708393513, 0.0980977119216996, 0.0971691673921962, 0.1866686914957339, 0.17148944068579905, 0.12308312564968102, 0.22298695880078503, 0.13033833835394154, 0.1386689776254277, 0.16390091078656335, 0.18842064264801242, 0.11241588756562242], [0.05043450983301286, 0.0769380953222994, 0.04799421335900984, 0.016514476944482135, 0.013559325335306988, 0.11812811492071038, 0.035681368617881695, 0.10057164731645778, 0.034529111092729915, 0.01780701474466872, 0.014900423533793901, 0.00975508975135463, 0.06673233328206886, 0.018523550186786922, 0.028548433122435407, 0.05676580134839301, 0.046654474966588526, 0.030932037174821864, 0.41798560008887325, 19.756923644773423, 56.74760433935351, 54.7477093819649, 49.03702474409535, 25.912795336015765, 18.808688694430938, 26.889159564049017, 40.11116150886782, 27.08733927819037, 2.95814837659559, 0.11368125031191496, 0.03173848644139306, 0.3038138006964038, 2.3901195535736703, 6.370584195660007, 2.7583715223496963, 8.901466092755719, 25.909869247867217, 59.438699368507635, 57.66794535421557, 57.48607681643579, 52.81034092749319, 49.954471049770234, 47.582378464360396, 43.75061896539504, 45.61708273426179, 44.04075276467108, 41.66473388671875, 40.10180665600685, 40.0932833456224, 46.464146029564645, 55.76908673009565, 54.94933489830264, 54.03726616213399, 55.846094623688735, 53.02813053131104, 52.786359556259654, 57.252895832061775, 51.58541610164028, 46.75577032950617, 41.685777402693226, 44.884748766499186, 39.60267328446911, 41.89686759825676, 39.112267186564786, 40.69140949556905, 39.220163745264855, 39.62667818992369, 40.54708196270851, 42.08440003856536, 39.03287056953677, 42.19472846677227, 37.781144188296416, 40.128667046946866, 39.97278813392886, 40.67247621474728, 38.254719395791334, 45.998474397966945, 53.34192798983667, 57.04405315460698, 53.93533160609584, 57.29690482539516, 53.06354168922671, 56.90753898312969, 53.75347091305641, 57.02682610481017, 51.03877890494562, 61.51841848127304, 36.190630928162605, 26.917934071633127, 58.225263164889434, 48.9598991793971, 57.235084349109286, 51.894581240992395, 54.83797096437024, 50.84595910964474, 52.35521654928885, 47.50247978395032, 47.532281952519575, 41.20394168361541, 42.24001615278183, 40.10240285627304, 40.51711897696219, 39.12990608522969, 40.076201423521965, 38.17444416784471, 39.448257415525376, 38.40711524409633, 40.184686337747884, 40.01636958891346, 39.096365897886216, 38.3038039361277, 39.89121852382537, 41.106419794021114, 40.95163129991101, 39.042539212011526, 39.801019699342795, 37.977450970680486, 44.47501797829905, 39.01365095569242, 39.850853412382065, 40.35725101347893, 39.802110118250695, 40.42248395181472, 42.379558394032145, 40.46065253596152, 46.79539803535708, 54.2390093495769, 57.339258578515825, 54.798213820303644, 54.250709779800914, 50.12111294654108, 46.258123536263746, 52.82181778261739, 55.365039456275206, 58.02118224482383, 57.10266905446207, 58.479758308779815, 50.985803373398326, 29.343400309162757, 10.1680366839132, 4.295409639035502, 5.038259971526362, 3.3879192894504917, 1.0720240949623048, 0.06752120466121743, 0.071518590163079, 0.1881210563043433, 11.200440795190874, 40.31587785290134, 30.115152135972057, 12.662686667134686, 34.86864705239573, 42.70058478078535, 42.55395873900383, 49.51506360884636, 37.95867458466561, 11.802521674863755, 0.18772930958338324, 0.07062083470725244, 0.06733964182316296, 0.03241135678704708, 0.02986872437289886, 0.023089882376934254, 0.06448119923832916, 0.045427841795307976, 0.009440983168690676, 0.04923712972912097, 0.01996110651581999, 0.00942402964292635, 0.0521523509204628, 0.06035716791126517, 0.02492550948274232, 0.11973159057238411, 0.01414855037094845, 0.06555903898251635, 0.052464217653558146, 0.06249399014538335, 0.041339065834519365, 0.05103283216275516, 0.016650043863562808, 0.009055391964202207, 0.06383835570886731, 0.06812207040286834, 0.04835744245698856, 0.09571820452448823, 0.009112261543651263, 0.05207127200499658, 0.01726725792151786, 0.0720097444530937, 0.013823234006732464, 0.016643618301097906, 0.05157457889928933, 0.05899144764689188, 0.09521554359385083, 0.7119122700345132, 27.113207309476792, 65.6909848797706, 61.818793589069, 54.83431531536964, 33.46353638556696, 25.61086108607631, 31.641981793988137, 39.68718074983166, 35.217443819968935, 3.19000605133272, 0.14560519897889707, 0.04291448351596633, 0.9850739735749461, 6.06387593092457, 8.73398578936054, 8.807435112614787, 4.1334515425466725, 28.410825421733243, 61.90380311781361, 62.54449482887023, 59.691645176179954, 57.184430860704, 51.60545941322081, 50.85857345211891, 46.344741236779, 47.822902125696984, 46.08533920780305, 43.01893218871086, 42.6572935811935, 42.27455654451924, 49.644792079925544, 56.54331553366877, 57.861227989196784, 55.549002539727, 56.665497364536414, 53.692458445026034, 54.39559036685575, 58.552498663625414, 53.99651273604363, 49.43843618515999, 44.29205902161137, 45.14404096911031, 42.082917382640225, 43.53885804453204, 41.88177039546352, 42.94303040350638, 40.07736244509297, 41.617351655037176, 42.921280860900886, 44.59603094285534, 42.11530439315304, 42.23995731722924, 40.03074899796517, 42.55435882076141, 41.37013250781644, 41.78423673875871, 40.93430619085989, 47.70444262412287, 55.84839313260971, 58.483590464438166, 55.42259631618377, 58.92149563758605, 55.61514546794277, 59.56894167007939, 55.25757043592392, 59.04290083915957, 53.43564125799364, 63.60432709417036, 37.592992013500584, 28.287000117763398, 58.87526266036495, 49.53527950471448, 56.56341768080189, 54.64442945295765, 58.744330021642874, 51.916558281067886, 54.47691679000855, 50.16677718008719, 50.27247328912058, 43.094539796152425, 43.60939010497063, 42.85962904653242, 42.71727054349838, 42.57466100877331, 41.57248366263605, 40.64883216734856, 41.808131817848455, 40.70121542099984, 42.18814672962312, 41.326680491047526, 41.08370927072341, 39.97084263832339, 41.081924592295, 40.471682240886075, 42.45971202850342, 40.94661066609044, 40.878839954253166, 41.26757429492089, 45.92961718959194, 40.74792300501178, 41.01265161268173, 42.14277275146977, 41.21018609692974, 42.91214958313973, 44.333930323200846, 43.1868645452684, 48.55114898374004, 55.404047427638886, 59.36741029062579, 56.98717486473822, 56.03810248836395, 51.77258376152285, 48.26695365290488, 53.27942502114081, 55.40234119661393, 57.68516063690186, 57.85091607801376, 58.27561855316163, 52.00931449090281, 30.352257451703473, 10.465192506390235, 7.486414669021484, 11.384712765293738, 7.873955628564281, 2.7977052955858173, 0.134426842353517, 0.10012494910868908, 0.1298378531130091, 13.175997445660254, 39.64223823239727, 29.820825322981808, 14.967338019801726, 39.74333340121854, 48.94583355995917, 49.16434880225889, 55.49031603720881, 46.76892988143429, 16.55482615194013, 0.19082482573726486, 0.037829302957341555, 0.06409229087312857, 0.020290993552114216, 0.05668159679419572, 0.04694813945060296, 0.004030124748110651, 0.038303346673567454, 0.02754839726783816, 0.0378942595524413, 0.043998819685751395, 0.016161065263253067, 0.053168018799155, 0.01992611736509829, 0.040383781006018964, 0.1110901800735343, 0.018294566506219488, 0.06841589576534687, 0.01661651219511705, 0.22810300121143942, 0.200335209768626, 0.11765172314499656, 0.13903104610020114, 0.07626564632500372, 0.21807149353046573, 0.13228280740159173, 0.21445183534054987, 0.15062993903073574, 0.12852622631696925, 0.13871511144022788, 0.09769566131815796, 0.16405422030197037, 0.12925464569801284, 0.10724560612992895, 0.16470904161612834, 0.23256803742579876, 0.15401678310046274, 0.7622539912981372, 34.723374228323664, 74.33122896379041, 68.93460458324802, 61.83421634858655, 39.361255322733236, 28.045195802565548, 39.38898255748134, 51.819432550860995, 41.14107001212336, 4.991507770553713, 0.19690050052538996, 0.1561528507379755, 0.9638078018061577, 7.827898667704675, 14.01651724692314, 12.275561478830154, 17.290619650194724, 29.51517462730408, 62.06894274680846, 63.543463676206535, 61.76927366564351, 59.26179655136601, 55.52220490670974, 53.86987117029006, 48.8300451924724, 49.89302712102091, 48.83985504027336, 45.990151128461285, 44.880332177685155, 44.24854032454952, 52.476256970436346, 58.590239709423436, 58.85419953253962, 55.7891418087867, 57.492740923358554, 53.17787877974972, 55.59622003186134, 62.13943166117515, 56.25736298099641, 51.57743800070978, 46.84210954173919, 48.457651445942545, 42.74245216000465, 46.646599000500096, 43.293819735127116, 45.18057784726543, 43.254207718756895, 42.45449919854441, 44.814381445607836, 47.32235277852705, 43.880100327153365, 45.1148271560669, 40.368845539708296, 44.65160308345672, 44.72710086453346, 45.09627434515184, 42.07970103909893, 50.88804221922352, 58.91696530003702, 59.85973050517421, 57.21994007787397, 61.851325727278194, 57.65509174716089, 62.106554354390795, 58.168553536938084, 62.463901888939645, 56.78377251471243, 64.05356791711623, 38.89452857355918, 31.147892590492006, 59.8706268495129, 52.24051075596964, 57.755971185622684, 57.34032938557287, 61.179761040595274, 56.35028000800841, 56.679759102482954, 52.29902467420025, 52.35904086020685, 44.79037654015326, 45.730219579512074, 44.32524227326916, 45.42729100873394, 44.47817156391759, 45.11099892277872, 43.15680350026777, 44.17560777356548, 42.17975285745437, 44.37708031746649, 43.71221896140806, 42.291132480867454, 41.94281816482544, 42.64602068931826, 44.29645599857454, 44.006145692640736, 43.46776116278864, 42.118395220848825, 43.83939789187524, 49.25693635017642, 43.58751504651962, 42.839185653194306, 45.26261421941942, 44.1599065257657, 44.87584498620803, 47.69005929270099, 45.18469633594636, 51.071597376177394, 58.83032014293056, 64.03992983602708, 61.02337221945486, 57.81908996643559, 53.4702600971345, 48.00078161301152, 52.93668047074349, 55.944244092510594, 59.439021002861764, 58.05615017491003, 61.17684279718707, 54.60854368825113, 31.587858969165435, 12.94379803442186, 8.83410232682382, 10.361193803048904, 11.131630655257933, 5.3124640449400875, 0.1351196769504778, 0.32789559073505864, 0.207105205364285, 15.96148137123354, 51.583243108564815, 41.52806282043457, 21.367366467752767, 45.86515303580992, 54.978062337444676, 56.284595997102805, 62.422807216644294, 52.671371352288034, 21.879635856997584, 0.5387128444929277, 0.23331475864735343, 0.19375250734869512, 0.15420986790089838, 0.17140681044228617, 0.16829925138623486, 0.11669763724409765, 0.2926030845171021, 0.1566417680512513, 0.14654676700311323, 0.08187173219818263, 0.09479647051663169, 0.1400467254702122, 0.21156595148626836, 0.11390376054952223, 0.2242730365645501, 0.1500109706314341, 0.18436072904977108, 0.14767182840695306], [0.042304769458789984, 0.06217293418763627, 0.027682292200024092, 0.08407647195722788, 0.01973431959237543, 0.03546950317198231, 0.034433614402528734, 0.09649316374693187, 0.03749347682441435, 0.009083176057996049, 0.057634732746068514, 0.07252843194310704, 0.019355129052494324, 0.035513231470700235, 0.06355347059246513, 0.045249285852356304, 0.06638166419560872, 0.06467956238456311, 2.076382891785714, 34.10574605388026, 61.8243045191611, 49.911854497848026, 31.733973141639467, 19.080414810488303, 22.219152296743086, 23.45689738950422, 32.95675831456339, 19.347834164096465, 0.4109967638167643, 0.0497246221188576, 0.037697796304259575, 0.670084237091003, 2.1514293551445007, 6.581700867222202, 9.5845615671527, 6.27899440065507, 46.1710939868804, 59.789524001459924, 59.7159089580659, 51.56909904172344, 51.82906981437437, 44.231654520957704, 43.751324992026056, 44.2626843913909, 45.581404855174405, 46.847769521897845, 45.920172122217, 41.801699130765854, 41.22323974486321, 42.75562347904329, 52.21891026343069, 54.768525400469386, 58.57683697054463, 51.39499287451468, 52.99982278577743, 52.149037161181056, 56.2609637168146, 52.89313823946061, 52.36205324049919, 49.046230546889774, 51.16644813168434, 49.345813335910925, 44.42527840214391, 39.3066559299346, 42.07459803550474, 40.25124111483174, 41.50830976424679, 41.9910397837239, 43.72903808470696, 41.62071704864502, 43.20314238148351, 39.18197947163736, 39.703556645301084, 40.361769583917436, 40.32336565756029, 39.061386200689505, 51.22350685058102, 55.69300451586324, 51.509631987540956, 46.71710360434748, 54.92383556981241, 52.812196208584695, 55.56654730150777, 53.45399795040008, 57.67830041147048, 49.790747396407596, 60.910447182193884, 31.611987429280436, 26.054785136253606, 59.7223416451485, 50.3491360141385, 58.050780450144124, 52.382477021986446, 55.00282033797234, 51.64122750682216, 53.24531609012235, 45.57851406835741, 43.78994464874268, 40.82662928488947, 43.49161701817667, 42.08713000820529, 41.62387455663374, 38.27637087914252, 39.25082491290185, 37.50626448662051, 41.945763864824855, 39.173954302264804, 40.69374330582158, 39.28498091236238, 40.37750613304877, 39.432265912332845, 40.76173759275868, 38.73617072259226, 38.94249523839643, 38.145500998343195, 40.096130986367505, 40.373913241970925, 41.87589860731556, 44.543859497193374, 47.55591423280778, 46.90068229552239, 47.92151051182901, 46.74989069661787, 44.28669321921564, 45.692294182315955, 50.2671153314652, 53.102145656462646, 56.4361132344892, 52.832125771430235, 52.71264645361131, 52.66578981953283, 53.34685056440292, 52.92310906994728, 56.248172867682676, 60.536319748047866, 60.17611672801357, 60.3060217057505, 59.66544766579906, 41.184361211715206, 17.272633621769568, 9.219879200381618, 11.757385000105828, 4.224458375284749, 2.0763113085300695, 0.260056022915148, 0.10217646362199899, 0.08654953401175239, 5.398922399167092, 31.63267989312449, 52.4828661641767, 29.160988523114113, 19.603698215176983, 38.63356936362482, 42.40887026632986, 46.85198606983308, 48.60109252314414, 25.401837979593587, 2.1727484176235814, 0.03282420156944183, 0.01952608348801732, 0.07690619542113236, 0.03733791884094958, 0.025529353391198863, 0.014812078274365877, 0.02187333858361648, 0.03543991685634659, 0.0522862209547912, 0.021268854991743164, 0.017609467482074134, 0.05064744397156662, 0.030232020503570958, 0.05128225506914239, 0.0670074737600742, 0.06105227778936106, 0.031234187997817516, 0.02963816638164703, 0.04544594445295873, 0.04811433594553702, 0.0725211770904641, 0.10961366817355157, 0.013500929325668803, 0.02722294779584533, 0.029206450938457446, 0.08845650305550906, 0.03424124206386266, 0.035553098686279795, 0.007494791380820737, 0.008565577370445094, 0.004514051477364715, 0.09140840070622583, 0.034406031406815016, 0.04722041092933186, 0.0490491968699761, 0.031382441332924275, 2.9405783645568357, 41.96774482727051, 67.39956932683145, 56.23718630883002, 38.3768973042888, 27.0578783558261, 27.189311096745154, 23.876469404466693, 36.18666148954822, 23.569026185620217, 0.3879028594782276, 0.12843145357985652, 0.05183612514707831, 2.2587753111316315, 9.777804978432195, 7.900208542423864, 5.917287151659689, 8.024901180498063, 48.01796943910661, 62.39286776511901, 61.857621131404755, 55.27676651554724, 53.64298951241278, 46.62634388093026, 45.843854565774244, 45.647724290047925, 48.94025202720396, 48.70265053164575, 48.277948056497884, 43.74940303064162, 43.435982119652536, 45.409471681041104, 54.8850864748801, 57.640716260479344, 59.76022389627273, 54.219617151444965, 53.268716950570386, 53.3454228216602, 58.86982625530612, 55.68328096020607, 54.01557153271091, 50.95055695502989, 53.04655782638058, 49.76847225619901, 46.186705020166215, 40.926406537332845, 42.895503044128425, 42.235077888734885, 43.5981015236147, 44.166064646936235, 45.390820810871745, 43.04167409096995, 44.70493162831953, 40.204792407251176, 41.549643701122655, 41.254034273086056, 43.81760520319785, 42.34339414104339, 53.407972858798125, 57.84356555631084, 54.1581496884746, 50.02671326360395, 55.05049674741684, 54.06789202843943, 57.82428318454374, 55.40096052231328, 59.14062276963265, 53.64617055462253, 60.05572742031467, 33.46840012458063, 27.47716796013617, 61.80833655018961, 53.19270926137125, 59.14374497628982, 54.00730709875784, 56.220881016023704, 55.30058314723354, 53.80332031557637, 48.270813265154445, 46.53637647628785, 42.25229709379135, 45.6139644499748, 43.17966307363203, 43.02991874756352, 41.311547986922726, 41.92472034885038, 39.63787263439548, 42.628970146179206, 41.454294804603826, 42.52757295485466, 40.90193094745759, 41.82776720293107, 40.65462943046324, 43.5578070148345, 41.50761550472629, 41.506619222702525, 41.490078587685865, 42.2544151736844, 41.828653658590014, 44.005004282920595, 47.55984052535027, 48.25563369258758, 47.55578871696226, 50.68855047225953, 48.04683416120468, 46.19961746277348, 47.3499309632086, 52.54488275897119, 55.407079419782086, 59.277693917674405, 53.25911891075873, 52.71107750554239, 52.985251180587284, 52.554308214495265, 52.990471855286636, 58.76191008475519, 61.542399852506584, 62.20931260816513, 61.218176734062936, 58.95107030868531, 41.54758053441202, 19.5706836254366, 11.027263249120406, 14.22783297877158, 6.879400428264373, 4.659393823915913, 0.8826803163655343, 0.09570373312359857, 0.10740649225490709, 6.138029809921019, 35.32588951049313, 49.15348383688158, 31.455563306808475, 26.46355886613169, 42.674528475730654, 47.070179677778675, 52.50740843434488, 56.06240941632179, 30.48802048929276, 2.6804122088416933, 0.09502150884438908, 0.02008863717257496, 0.0823344263218103, 0.02748311700059041, 0.04563712169446292, 0.04992211958573711, 0.032053450084922296, 0.03453805516924589, 0.009123880224632881, 0.03450021042578644, 0.03580599963184326, 0.12804924465355375, 0.011948379368761615, 0.003340662374431568, 0.010946188891877331, 0.015188185310351755, 0.020344656095990253, 0.02320822189381767, 0.1800506571007352, 0.15604665562991174, 0.1345117402172858, 0.21582938400247406, 0.12878840458729576, 0.12165646309093123, 0.0976347266846607, 0.12839963794836115, 0.11865391170666104, 0.14757300306472088, 0.14553994360950687, 0.25857450080014044, 0.1260685473079643, 0.14495480565294144, 0.14709626654944113, 0.15223048056565947, 0.14959100123134353, 0.1004195788634881, 3.9271255558536904, 50.97574641627651, 74.21766850256151, 65.05085799001878, 44.52349847362888, 30.814571534433675, 31.97144912135217, 34.52392562743157, 44.09994133057133, 28.844823914189494, 0.8013212885106764, 0.18564784869311318, 0.15645286609088221, 1.960962981947007, 7.26432026393952, 14.47040705911575, 19.34449230470965, 9.069513178640797, 49.78161611864644, 65.07260753262427, 64.49913740158081, 56.406718992417865, 57.43228935426282, 47.70750599522745, 47.87617967974755, 47.43284202391102, 51.26863764178369, 51.85333359626032, 51.64264740482454, 47.11727557643768, 45.3395240537582, 49.284236046575735, 56.67887264682401, 61.00813773370559, 62.26548879377304, 54.288721469140825, 54.292392807622115, 53.07427721638834, 60.85460439805062, 57.85020612901258, 55.9912262424346, 53.891138261364354, 56.182637906843624, 52.87406375331264, 48.95875384730678, 43.337056021536554, 45.27006280037665, 45.36848683511057, 46.27618605090726, 45.676765518803755, 48.39123787418489, 46.02570741407333, 46.98651944437335, 42.90888224878619, 44.2544944824711, 44.470260143280036, 44.64661775096771, 44.375421154883604, 56.718445439492505, 60.56234075177101, 57.72358417510987, 51.09140926791776, 54.969786136381096, 55.5164154883354, 58.8135245538527, 57.395434764123735, 60.301471756350615, 54.237714967420025, 59.7460170715086, 35.49146844494727, 29.89909621977037, 62.71245464201897, 55.15045050651797, 60.289987056486076, 55.73221252810571, 58.28003121960548, 57.499581536939075, 56.65813899809315, 50.47644830519154, 47.78083862796907, 45.4225214066044, 46.5822603625636, 45.4409408569336, 45.13902425765992, 43.65974157087265, 44.690391402090754, 40.875325510578776, 46.28323062773674, 42.77106977278187, 45.101883334498254, 43.295871134727236, 43.92052819651943, 42.65393995469616, 46.24035519938315, 43.738420394159135, 42.920268889396425, 42.75037142538255, 44.27301983679495, 44.37518189030309, 46.9919244704708, 49.77990204288114, 52.4672943545926, 50.28850793838502, 53.966585051628854, 52.19748235517933, 49.14542336617747, 50.79894165838919, 56.460847700795824, 57.67456239269626, 60.99025172571982, 54.78255179620559, 53.34666621300482, 54.12923397556428, 54.27052167154128, 53.22419412674443, 59.04113577258203, 65.38720123229488, 64.43481837549518, 63.88323899238341, 63.62679835288756, 42.59620266575968, 20.0533861883225, 13.500643199489964, 22.68326674738238, 11.724586140724922, 5.206423257627796, 0.6032018808107222, 0.24430333997213075, 0.183439293816205, 8.378510205976426, 43.57740317621539, 64.99566239695396, 40.421872062067834, 28.720198446704497, 50.82259747289842, 55.15480041503907, 59.7986239002597, 62.70632397743964, 39.046979335046586, 4.680342712709981, 0.21503564030412706, 0.23645317572499477, 0.1711092006054617, 0.12692798304581834, 0.12727293711636337, 0.13903083159558235, 0.08691445233360415, 0.12778201020292698, 0.08131468668580055, 0.12341106490742777, 0.11900514769818514, 0.2506571506420451, 0.13751983041724852, 0.21958791861130347, 0.19266544390589962, 0.14536610293772914, 0.10368007971274276, 0.09622192265646112], [0.0369833235538775, 0.04661185366492118, 0.011683135789128081, 0.045909577034293644, 0.034852484466447946, 0.03641383677360512, 0.028439991461533694, 0.051982869288974234, 0.01596687921142626, 0.05529899195197129, 0.03159942424615785, 0.026126928785214984, 0.08868948571504125, 0.024426556417658448, 0.01664419861270055, 0.1385259030446891, 0.036585088068198775, 0.06654348494785448, 4.884900691047792, 48.43266594794489, 52.227500254108065, 52.83679339193529, 39.265510266827, 23.16431014768539, 23.90454573016013, 33.84224514807425, 33.06164249297112, 10.43219066435291, 0.16260666652552544, 0.0840628892183304, 0.10823310878608497, 3.5273514591878463, 11.90435032690725, 5.522518244481856, 7.62214191498295, 13.960364595536264, 54.29753895728819, 59.7623105972044, 56.850354748387495, 50.53360116097235, 46.58739474511916, 46.282355939188314, 49.89079137002268, 53.2593503305989, 59.64889526367188, 54.308956976859804, 53.905074442586596, 52.24277396355906, 44.55593255258376, 38.32338833039807, 46.03015930421891, 52.41094558469711, 56.272013033590014, 53.12993957150368, 52.42823539241668, 50.273681379133656, 54.150728564108576, 54.463400302394746, 52.42144184727823, 55.6706940743231, 56.43792536950881, 53.95129565269717, 53.27801296787878, 43.76935612770819, 40.98881536914457, 40.26420454825125, 43.67842382000339, 41.67843864810082, 44.18004397423037, 42.231481075286865, 41.13831650826239, 40.92213115384502, 42.05559807439005, 39.350594320604884, 42.30657485223586, 40.215810345065215, 50.00149242339596, 51.92158283725862, 53.8908205493804, 51.35833440288421, 52.50518445045718, 49.926437870148696, 53.265080913420654, 50.043147994625954, 54.19348239898682, 46.84490226930188, 57.878270687595496, 28.64755418992812, 29.571082130555187, 63.230176125803304, 49.705408388568515, 55.575768793782885, 49.70083490494759, 53.527208989666356, 49.140128166444846, 49.50075480245775, 43.32711281314973, 44.345807260082616, 41.18515353049002, 43.29382757986746, 41.92002527175411, 41.911215628347094, 39.10772900427542, 39.46319380114156, 37.841603602132494, 40.38793179296678, 39.053580684046594, 39.41772960847424, 39.74874627205634, 38.18343031790949, 38.43119075221401, 40.952145130403586, 42.53256613208402, 43.383355679050574, 39.905954868562766, 39.951246476942494, 41.810112614785474, 45.10258151638893, 50.13047172177223, 54.18911680098503, 52.5823845401887, 55.966989917139855, 56.587979562820934, 50.137528065712225, 50.89635764398883, 53.67807511360415, 53.54515383320471, 55.327208195963216, 54.62014605922084, 54.044334273184504, 55.9570663206039, 57.10383007603308, 56.975446977923, 55.37920705733761, 57.15353435085666, 54.09672537157613, 58.52438703660042, 59.55594685769851, 49.47716566824144, 23.070371343243508, 18.400077742915002, 16.517189048951675, 6.64645282491561, 2.75463693564938, 1.5282623037215204, 0.20082336099397755, 0.03479561775982861, 0.9000487553496516, 22.314965994127338, 37.746580262337964, 25.118040769330918, 22.618749641603042, 54.49143348201629, 45.2172363188959, 42.03025171833654, 52.2141916521134, 37.44300450048139, 6.415223219702321, 0.059117967067586805, 0.09060765496425091, 0.07621983426713175, 0.059475542436684334, 0.058394580884205724, 0.04873434239397607, 0.04007459558065861, 0.015272657037712635, 0.02592236224201418, 0.04935310011909855, 0.027017797110602263, 0.04105154537565766, 0.027999533039908257, 0.061050362569550355, 0.04112663348355601, 0.018922892669516227, 0.05439893057149264, 0.03856853183899676, 0.03699396451514575, 0.02984142674493694, 0.05669660062619275, 0.04618087941179833, 0.038110568308301514, 0.059754160953865904, 0.007520017698557387, 0.024180308945717353, 0.042389897148936026, 0.036096366107343666, 0.09020129128569558, 0.012538942185440853, 0.021585887072667963, 0.013667831156072358, 0.03139245793253424, 0.10394413489848377, 0.04712452736472891, 0.0755408582007212, 6.795359234656058, 56.77525704906833, 59.619759898031916, 59.13600613993984, 45.83940267562867, 24.856108811593828, 23.59492559586802, 26.517089413058375, 36.90215279979091, 12.377294032804429, 0.2817606114812436, 0.0733463457154651, 0.19074516791489818, 3.7479352614571972, 16.320137996827405, 10.376153722886118, 6.058551313415651, 15.14006547389492, 55.25752336748185, 62.631932304751494, 58.810292520830714, 52.75844404774328, 49.73700308030652, 46.753409062662435, 51.002955898161865, 54.873962633071415, 61.304555169997684, 57.90111849384924, 55.975081766805346, 53.735153444351695, 44.65308966175203, 39.71369597219652, 48.259332487660075, 55.20681104352398, 57.70547851439446, 54.4855656162385, 52.681797012206054, 50.157940080088956, 55.777049141545454, 57.013799913467906, 54.851142283408876, 57.40640171112553, 58.57640550982568, 57.79610487722582, 54.2394761116274, 44.796036520311915, 41.9808102423145, 43.60009801003241, 46.446852299474905, 44.25569080537365, 46.39377086393295, 43.83984896444505, 44.42196399934831, 42.82297057490195, 42.73552917665051, 41.664596603762725, 43.70873197432488, 42.82698315958823, 50.58154821395875, 54.859795032009, 57.154161930084236, 52.78520637942899, 53.09458724914059, 50.915173253705426, 54.60092252300632, 51.71744308164043, 54.692454953347486, 46.80076776012298, 56.67278120594641, 29.434405180715746, 30.77477712785044, 65.1998649104949, 51.33323515615156, 58.70448658543249, 51.49882193534605, 56.19836661123461, 51.63965855875323, 53.44673372084095, 46.45388510919387, 44.56865279905258, 42.37594589110344, 44.1467861975393, 44.27185881522394, 43.63271251801522, 40.042947569201075, 41.30375815976051, 40.599896677078746, 42.78171900779971, 40.858926080888324, 41.09023609469014, 41.262216337265514, 40.748883985704, 41.182560843806115, 43.4875181413466, 43.72050692958217, 43.94038323433169, 39.89541153753958, 42.59433953992782, 43.40431290288126, 46.962463548106534, 50.001198245633034, 56.07389019381616, 56.593466958692005, 58.59492301940919, 57.355803135902654, 52.01271126347204, 52.80054284680275, 56.06302130606867, 55.92576580662882, 57.37249282098586, 54.86081877062398, 55.612980319607644, 57.163289285475216, 59.314328855083836, 57.94742207373343, 57.51699293813398, 58.55402446562245, 57.02055031253446, 59.96640720675069, 61.05415105819703, 47.96378189517606, 28.01951212267722, 12.463599904890984, 10.099210854499571, 6.921528645100133, 6.070782244205476, 1.9325533773629897, 0.17815621359454048, 0.07235885838106756, 0.985124106368711, 24.984185964830463, 36.54288330385762, 26.456992818463235, 24.363125716486287, 58.406684552469564, 51.46236350459438, 49.643705583387806, 57.7003441318389, 46.73467974508963, 8.89401751179849, 0.02244898088036045, 0.03671351121738553, 0.09445639642616434, 0.08953870950086464, 0.0876179508744709, 0.029318414688591036, 0.021810302953986872, 0.026241914752209862, 0.030910789726241946, 0.03189618947104581, 0.005873942770244133, 0.015458928443671716, 0.022338420986348105, 0.008197252830160002, 0.03646499995562819, 0.039766666539494074, 0.0718932684450861, 0.02766349048714244, 0.15054922400703355, 0.13548644920510633, 0.2233231028602008, 0.13638119393539044, 0.15402763090547056, 0.1339830935842568, 0.1345883796532308, 0.08223203867073021, 0.09144679703299077, 0.26496076295452736, 0.09700264286009536, 0.08689451106493512, 0.08951869162340319, 0.13641183745236168, 0.10898952101988178, 0.273205217334532, 0.1139724633145717, 0.2665361768055347, 9.814942959816227, 65.48677452148931, 65.48797476676204, 66.48411950757428, 50.38354304529006, 35.21077971304617, 34.84049620166902, 47.64519914504021, 46.62234698572467, 15.045045075878022, 0.471999793643913, 0.23900460091329392, 0.19491596507929987, 7.304418654211107, 21.688024151709772, 12.69790464831937, 14.272551921106155, 17.083534194577126, 58.382412925843276, 65.19789195829823, 60.752222691812825, 55.72070821639031, 52.3918907104, 51.22813524738435, 54.9991843008226, 59.41786373815229, 64.33144430960378, 60.94481106727355, 58.44797926564371, 55.91102161715108, 48.34354969762987, 42.44217903383317, 50.25104538086922, 58.165074394595244, 60.150966490468676, 54.650791537377145, 53.42134421871555, 50.74269487011818, 56.59119198399206, 60.46598772848807, 56.3890604819021, 59.85825177161925, 61.9402027130127, 57.89927890223842, 57.530999722019324, 47.512372001524895, 44.52900548135081, 44.718648156812115, 48.11504417850126, 46.318563338248964, 49.06779966046734, 47.12930548575617, 46.9451266719449, 44.629900609293294, 44.61645080197243, 43.478269192480276, 45.55991418900029, 43.514727623231956, 52.89188700337564, 55.75811978309385, 57.9414326144803, 54.80388948994299, 54.42420013489262, 52.349231012405895, 54.11472905066706, 52.25878507860246, 55.78638830492574, 47.78563568668981, 56.9132617212111, 31.72974482659371, 34.12677780274422, 65.06215441611506, 54.00942125628072, 61.648029281247055, 54.480262571765536, 57.13372245911629, 53.68775552318942, 55.369746300481985, 46.624904371077015, 47.282834899040964, 44.03416318278159, 46.49172813661637, 47.42995123709402, 46.25109464891496, 42.83227835932086, 43.106628541023504, 43.02450195435555, 44.685680635513805, 43.6454523763349, 42.98203053012971, 43.85941374686457, 41.398420641499186, 42.58646342062181, 46.17744822655955, 46.94612687633884, 47.13192562903128, 42.65697586920954, 44.32390082267023, 45.267466191322576, 50.926281406033425, 52.52226245018744, 59.28147508252052, 58.80220851590557, 60.69577194029286, 61.56458870057137, 54.459960383753625, 54.439187511321045, 58.63553131780317, 59.22297293140043, 60.1587837742221, 56.144626217503706, 57.57565198406097, 58.43382735406199, 61.527926306570734, 60.32957553863526, 58.51390254112982, 62.08834671205091, 57.75801474048246, 64.5865317313902, 64.19461242614254, 52.287069289915024, 26.48619290321104, 23.92877224952944, 29.17296744162037, 18.143476286242088, 10.569208860397339, 2.6828448137929364, 0.7519890259831183, 0.12811166549762412, 1.4472725915331996, 32.30371702101923, 51.68505607112762, 34.207143245204804, 31.51200817477319, 64.18444172028573, 57.282011585850874, 54.4006698362289, 65.74624715312835, 54.648508717936856, 12.41014486359012, 0.18496478937806624, 0.16169310667582099, 0.1663764319833248, 0.1618621669589512, 0.15727051173246678, 0.12467222949189526, 0.08256855045234965, 0.19016343138871655, 0.08178894873708487, 0.1872238294491845, 0.11543566060643043, 0.07706592475334484, 0.21174153883851346, 0.13681270061962067, 0.09668400390974938, 0.14836296228872192, 0.20923010343986176, 0.06711032872478809], [0.06468622734950435, 0.02158386268532805, 0.021108742615568544, 0.04924587845321625, 0.02412497249972676, 0.09448200674547304, 0.0800025542717307, 0.00950751694730453, 0.08445971510222844, 0.06569320396069558, 0.026773922596006628, 0.015279647590021695, 0.05061248354914208, 0.016483335470360135, 0.14586127152846706, 0.019674756256262624, 0.04483010935326738, 0.09290841618372549, 11.380489353210697, 54.18163291869625, 55.0475981158595, 42.12104674308531, 21.5263871992788, 24.62251009479646, 36.04691528504895, 37.439117431640625, 31.76235345102126, 5.537545825204542, 0.07934307514299309, 0.05077502442403667, 0.07090164423589745, 1.5089164385872504, 18.940180270902573, 6.161709158651291, 4.477479198286611, 22.062743863751813, 61.69363467924057, 58.45737726457658, 55.222076908234634, 48.956592621341834, 50.819008504190755, 52.65433257625949, 56.19579353640157, 57.06844245233844, 50.39764396605953, 55.073120978570756, 57.951313064944365, 54.05683486692367, 53.18881827016031, 41.37074439756332, 42.82475525333036, 49.07287912984049, 54.35966537844751, 56.10667728608655, 55.3308520778533, 50.650264217007546, 52.208515982474054, 52.23200313506588, 56.68674876613002, 53.52079591443462, 54.32585062519197, 52.538850153646166, 53.489805267703154, 47.92238912274761, 42.6826830833189, 39.33439493179321, 44.84787456450924, 44.31988039324361, 45.591795213760875, 40.27799167940694, 41.68108232559697, 41.58411741256714, 40.171099247470984, 40.31246539085142, 40.185647318440104, 39.029689527327015, 45.45358657836915, 49.95410626934421, 57.17706857189056, 54.14864970791725, 55.21164340357627, 52.76551215879379, 61.1340222820159, 53.92754570130379, 55.59144650736163, 49.83589387709095, 58.856019512299575, 30.031656642113965, 33.93058476909515, 61.951593275993105, 51.37645183071014, 53.828325425424886, 45.31440127280451, 47.81413562836186, 43.621659278869636, 42.31683577260664, 40.299125409895375, 42.25099094452397, 39.59321252761349, 43.063607984973544, 40.79202221285912, 42.26265215104626, 40.09142021979056, 40.47470246591876, 38.720049781184045, 41.55408774652789, 40.015188955491595, 40.16149336291898, 38.81430041405463, 38.66566219637471, 45.02766424609769, 50.41453369202153, 49.37047719955445, 45.17572979773245, 41.15703798109486, 41.827947631959, 45.556658621757265, 52.46385443595148, 53.556054099913574, 55.91061369065316, 55.36119945587651, 55.014826713069795, 55.94485990462765, 53.32947054216939, 52.59188059837588, 53.38856104881533, 53.97717545109411, 53.19163453194403, 52.99121710561937, 55.44743276411488, 56.76181116411763, 55.37835590301022, 55.205210716493674, 55.45757209101031, 54.44270587736561, 55.270922183990486, 56.33044850441718, 60.9790062904358, 58.70297255054597, 35.11208503477035, 19.96797461663523, 11.499637230750054, 6.262932785095708, 7.107772096510857, 2.0411388023245722, 0.18753362008400504, 0.13101503913921694, 0.13693423280792852, 13.609573302730439, 43.212528613305864, 47.30696532034105, 21.980211311771026, 44.61507405004194, 43.09291201253092, 38.91857662508565, 51.25193226721979, 46.48637017896099, 15.712796238160903, 0.14023705235412046, 0.04331905837921847, 0.0491141994303513, 0.09789836052204333, 0.047459089452581066, 0.0038999103895959357, 0.014459400122324306, 0.03832973840255891, 0.08411205674131071, 0.051835504615859646, 0.03590835663940638, 0.027803958453718695, 0.05055824452410302, 0.06682047935863657, 0.018216766447069186, 0.055870623778431654, 0.03999763055734577, 0.05338143557310105, 0.07502954047653945, 0.1088337293796001, 0.05306552772620513, 0.012582818913694113, 0.029112404069652962, 0.009395327201233277, 0.12293369253917087, 0.035481320078214335, 0.08395418134187499, 0.0595011106211572, 0.03971387159019228, 0.0581794519037489, 0.0565064690947052, 0.06598349765784318, 0.09887454805955773, 0.05517168346071436, 0.02929845618294372, 0.04919718973518861, 15.622142418738335, 60.78668855851697, 61.27474123431791, 48.72407843989711, 32.233798811512614, 31.922594039670884, 38.84032926251812, 41.68890745409074, 35.96764418386644, 6.182794349808847, 0.11189325472279904, 0.0776838589339487, 0.390704718808974, 6.333794324628769, 15.552351686262316, 7.530733529598483, 5.242696846685102, 22.44415121693765, 63.04081586099441, 60.43908026910598, 57.14991008081744, 51.47796669313985, 52.309011028658965, 54.20780297248594, 58.865225315094, 58.42171899734005, 53.45802622456705, 57.166152615701, 58.19890483733147, 56.27171493345692, 54.0071855052825, 43.201063525292184, 45.346784360947154, 50.93561272467337, 57.698171138763435, 58.65932049289827, 55.61200364943474, 50.18205088953818, 52.91174204118791, 54.97161003851122, 57.965202177724535, 56.253840692581676, 56.8324883522526, 55.16542611583587, 57.43211284760506, 49.218877592394435, 44.75276493257092, 41.40734795601138, 46.83694378022225, 45.47863091191938, 47.3810588928961, 44.74292370580858, 44.716557533510276, 42.06330160940848, 42.21916875531597, 41.90099000930786, 41.8522741717677, 40.85894177036901, 46.80120706558228, 51.259612268017186, 58.597139158556544, 56.22261470363986, 57.360666874916326, 54.64045609197309, 63.10653517323156, 55.278519815014256, 56.733707381832986, 51.473585405657374, 59.27700358052408, 30.186572613254672, 35.62885338260282, 63.155525576683786, 53.801068875097464, 57.41147333575834, 47.33279805029593, 49.794673688950084, 45.98771533658428, 44.81225159860427, 41.550232056648504, 44.575116865096554, 42.415836395755896, 45.18546904287031, 42.3250727499685, 43.20823754033735, 41.9334593895943, 42.03019288278396, 40.200748443603516, 42.99502926488077, 42.81612996132144, 42.323723454629224, 40.51781323648269, 40.735838182510875, 46.55429778560516, 52.396295532103515, 51.49341298687843, 47.93508975736557, 42.839079749199655, 42.23765488593809, 46.877293202184866, 54.22114687581217, 56.327847972992934, 57.59461272147394, 57.43560375705842, 56.14508905718404, 57.41969070126934, 57.068626803736535, 56.886973996316236, 56.08528467916674, 57.05778929495043, 53.47376669606855, 53.52252567968061, 57.78211770519134, 59.164961076551876, 56.370221337964466, 56.16378699579547, 57.10733275259695, 56.71298157784247, 57.286079083719564, 59.17550832994523, 62.35395000826929, 61.427513630159446, 36.44176460081531, 19.313693854116625, 3.836922073556531, 4.529525618399344, 8.002219584680374, 3.9203023477908108, 0.18865281325434485, 0.04500835886104934, 0.20666358631945428, 15.211979189226705, 42.20595429020543, 35.56551887143043, 25.575538181489517, 48.160975133219075, 48.373089067397586, 45.103985724910615, 57.80430655325613, 52.891008392457046, 19.904771504863618, 0.14873783975358934, 0.05799028181260633, 0.04529458463131901, 0.06097396062086187, 0.04531249576698869, 0.028627414872208913, 0.08727891866358058, 0.015559895959262167, 0.049097180787113406, 0.03612680278057533, 0.041267555357227405, 0.05919843694315322, 0.07732094776245856, 0.08187636703012452, 0.060679893940687187, 0.05482790533513312, 0.03382910591279788, 0.04257301514547679, 0.11011947772555775, 0.2641403440746569, 0.10539917335394891, 0.15691570577121552, 0.11623060706281856, 0.18227841014102583, 0.2755665454653002, 0.1468605566168985, 0.14137317606758687, 0.17525202023886866, 0.11934089339188031, 0.19385212942236857, 0.15938168151244042, 0.1297611677117886, 0.16112333644301663, 0.13677824198478652, 0.17242575334685464, 0.19868142512296477, 19.480853503750218, 72.00873867157968, 67.94823046653502, 56.5032995131708, 34.509593286821925, 38.23528797395768, 48.49105827270016, 51.71679981293217, 43.99600244337513, 8.17839038948859, 0.2685296601585804, 0.22244767886736702, 0.38311097951185324, 6.582396107335245, 32.8223406499432, 17.54400476332634, 8.171566445981304, 24.53251719474793, 65.96129894256592, 63.638918476720015, 59.25617187253891, 54.342814876187234, 55.396434107134425, 57.26898539450861, 62.150178955447295, 62.358382286564, 54.6274769690729, 58.79498743241834, 61.36311223430019, 58.42992459574054, 57.53906019272343, 44.24061713680145, 46.69410282565702, 53.06277290467293, 58.94780689670194, 60.63289634643063, 56.37224920334355, 52.18447185331776, 53.38761967997397, 55.16672834273308, 60.070777554665845, 58.098966767711026, 58.804248148395175, 58.311370957282286, 58.48515549013692, 51.76843389388054, 47.83931332249796, 42.929557061964466, 49.75465374608194, 47.692702970197125, 50.251908302307136, 46.28146948352937, 46.35735950162334, 44.20416655079011, 44.025702630319905, 45.35250709902856, 43.54745587994976, 44.14928866970924, 49.67833618963919, 53.72144868296962, 61.16582878174321, 59.72680922477477, 58.104669893941576, 57.22014011875276, 66.42439749933058, 58.35851000201318, 59.62385093012164, 53.46842050552369, 61.555002427870235, 32.21262585732245, 37.85168017110517, 65.71608804887342, 58.01485938410605, 58.473427603321696, 50.46949394287602, 51.902382835265136, 48.4373688697815, 46.059463331776286, 44.49648903262231, 47.61665997966644, 43.70130300521851, 47.22223820224885, 43.38575224722586, 45.45438281951412, 44.81489527610041, 45.86432149333339, 42.56180347934846, 45.33638615762034, 45.25369474964757, 43.4294984417577, 42.39634613836966, 43.0436509655368, 49.79211238122756, 54.556497758434666, 52.63463051088395, 49.99986856214462, 44.663056404359885, 46.42054104035901, 50.626926114482266, 57.026214215063284, 58.15194229925833, 61.50228185038413, 60.55159345749886, 58.02761100953626, 59.02782717058736, 58.21557491056381, 58.421158098405414, 59.48136691124209, 57.95546293258668, 53.02704403477331, 54.84954980111892, 58.55590720330515, 62.88593323000016, 59.74055713222873, 59.974836380251, 59.13096981663858, 58.12975737356371, 60.78558637249855, 61.82781504046533, 65.40803294028005, 61.9944961609379, 36.91957596809634, 25.994627744920795, 20.17167506679412, 16.213658394352084, 14.867351901146675, 5.9083461088518945, 0.23658742497284568, 0.3164927090608305, 0.3960807867828877, 19.26425433927967, 57.30400039303688, 59.9507922510947, 33.53548834400792, 52.02005001806444, 52.570244804505386, 52.30370406181582, 64.620534758414, 61.235827399838364, 25.27627702682249, 0.3371719655490691, 0.17779311856194852, 0.15590463825050863, 0.12849327687534595, 0.1333125215023756, 0.09646289561304355, 0.1525736113469447, 0.11999043636024, 0.1873301777748331, 0.10373575898307948, 0.1540430139509901, 0.12148403968181341, 0.14819843724610346, 0.25631136981950653, 0.13214388501740273, 0.14505292619428328, 0.14867679786778268, 0.09193813518410729], [0.031057763694515152, 0.026667715996624004, 0.04713250234002068, 0.12325981616853707, 0.0856962499599303, 0.016734819153263684, 0.020137594021376104, 0.012623969326546837, 0.028853713414601745, 0.04189729112230482, 0.017654377471415267, 0.0398478718594678, 0.009461486554374138, 0.07267814084526993, 0.006833454488866753, 0.012010690087692873, 0.01823499742444725, 0.1020418236693067, 18.931333364978915, 55.77304832396969, 54.1496342228305, 41.89390620877666, 24.58186257270075, 20.528271467454974, 35.342261483592374, 37.73544465341876, 29.030575598439864, 3.9362286415792282, 0.018382555534762722, 0.10973478667438032, 0.5140054364117884, 2.5939168372461876, 13.424404090450658, 9.77963770589521, 3.674557766606731, 24.321044568092596, 59.638069521996286, 60.46346956683744, 55.95375191780829, 55.42039978888727, 54.617847550299864, 56.39923903249926, 57.182971738999896, 55.90346320982903, 44.531774674692464, 46.95134755103819, 55.24847053712415, 54.75701716638381, 53.87589985324491, 45.06648786606328, 42.450388554603826, 48.575334318222545, 52.13489701670986, 54.312357671799205, 53.95924237466628, 50.20248251576578, 50.85700450404998, 49.735202712397424, 52.98367831014818, 48.86969251017417, 49.77109632184429, 53.14666063554826, 54.891950622681655, 49.178626229686124, 44.17397214520363, 39.123626370583814, 41.79673733249788, 43.83132957643078, 46.536066609044234, 42.37446715754848, 41.507015382089925, 38.59497324112923, 40.03595398318383, 39.17530359760408, 41.23592861237065, 40.44250765154439, 42.83243133175758, 43.48403507663358, 46.735883912732525, 45.249784146585775, 49.97336118452011, 50.457919028497514, 53.55287305770382, 51.30679445881998, 57.273919736185384, 49.61393087140976, 62.6324422128739, 33.88603056630781, 37.5017027701101, 60.071456124705655, 48.34678173065186, 51.27802387360604, 42.50143820239652, 44.55026865005494, 43.140215796809045, 47.144892984820956, 47.99586296081544, 49.070082479907626, 42.43136113689792, 40.962845356233665, 38.21024364040744, 39.349649029393355, 39.43625104042792, 40.68309407080374, 40.430728773916925, 40.681215255491196, 39.02417075249457, 40.391434469530665, 39.09508720521004, 45.27220441449074, 54.53945898240613, 53.21330170477591, 54.07435217211324, 49.95966034550821, 45.049056853017504, 46.977992211618734, 51.08983247510849, 51.90070406083138, 55.30043409716699, 52.35276899030132, 49.9787034526948, 51.763523086424804, 53.16040462063205, 53.86156751263527, 53.5691705057698, 55.451880731890284, 53.32947054216939, 48.96600630975539, 56.62484199770036, 55.305407662545484, 53.45320563162527, 53.120714156858384, 53.5363991029801, 51.58511015676683, 53.35133775588005, 55.33237395748016, 60.699376598481216, 52.59406143619169, 50.18816194226665, 42.82639480406239, 26.72355709537383, 8.537117127449282, 3.945001267617749, 3.493836031806085, 1.9687952197367147, 0.07230315612809313, 0.04995893011049879, 0.09059536691394546, 5.69862776225613, 25.58250431091555, 63.626527709345666, 29.248092597530736, 33.879029135550226, 43.19749809080555, 38.482401217183764, 46.88605969951999, 46.57785946323026, 25.56065670905575, 0.46671878185964405, 0.05152712358281978, 0.070017617075674, 0.06376380003207634, 0.03560667121482473, 0.06594941440609194, 0.04785843193531037, 0.033935837282408635, 0.02711858746836022, 0.0418663066962073, 0.03699403729349856, 0.007539900074217229, 0.045861907213205294, 0.04580649990408171, 0.006953818871895032, 0.031321820795475956, 0.04467321837681436, 0.03053869890619911, 0.03246905852950389, 0.011093960549201698, 0.06912833455228998, 0.1817551261234668, 0.054381348853630405, 0.01436675040637173, 0.046118826289931615, 0.04277278023261217, 0.04936198290858058, 0.115778959927059, 0.024971334947152965, 0.01205808315951858, 0.03981880265318098, 0.006164104317224795, 0.016792390660773364, 0.04965334912882217, 0.0562594861783568, 0.41584030875275213, 24.861013735494307, 62.22592776821506, 58.94392375023135, 48.96581803598712, 28.685928698508974, 30.44984994396087, 38.380011666205625, 37.86285892609627, 34.7669360714574, 3.4131161051411785, 0.06599898029479288, 0.1218981791528002, 1.1683044318229923, 9.37828706156823, 16.027869447585076, 10.980628228956654, 7.25655593218342, 26.30248281263536, 62.17729037807834, 62.665801971189445, 58.26916233185799, 56.479777059247425, 56.89727414038874, 59.65171544782577, 60.852235286466545, 58.4742630681684, 46.597126145516675, 49.43986392790272, 57.12386554287326, 56.290605068206794, 56.548595043920706, 46.922973125211655, 45.98098062699842, 51.30933223232147, 55.940800251499304, 56.89111994158838, 55.06003202930574, 51.420245093684045, 50.721270884236986, 50.806417695937625, 52.288755909089126, 48.823400697400494, 52.32349241933515, 56.178393902317175, 54.62288779597129, 51.79672987230363, 46.30443496088828, 41.22403206363801, 44.59888642834079, 45.29460507054483, 49.52159827755344, 43.83571086391326, 43.89388353593888, 41.25810569332492, 42.682887046567856, 41.066568513070386, 42.198497864507864, 41.9681292195474, 45.38400765388243, 45.1448921234377, 49.39867119635306, 48.795355750668435, 51.90636011861986, 53.38955340846893, 55.96336172473047, 52.943109235455914, 58.374501505205714, 52.56631066722255, 62.45813208241617, 34.635885761630156, 37.87719911144626, 63.195357245783654, 51.16773859147103, 52.566396959366344, 44.2399581786125, 45.61091284598074, 45.457858039486794, 47.66022574517035, 50.29027692733273, 51.08276436405798, 43.99706148332165, 42.419174332772535, 39.873477643535985, 42.29485481016098, 42.17408895492554, 43.38189655734647, 42.48974169454267, 42.33166233185799, 41.58291716729441, 42.65929398998138, 41.66165090376332, 47.62252000070388, 56.99282700015653, 56.37199424928235, 55.45898806664252, 49.604623086990856, 46.597789026075795, 48.23156210684007, 53.63015551720896, 53.978477677991314, 57.21247188506588, 53.91235436162641, 51.5945513017716, 53.44374879713982, 54.76215547130954, 56.15616583055066, 55.78716885659003, 58.044269315658084, 54.77103179500949, 49.00054670149281, 58.210695482069454, 57.56780724371634, 55.30322290235951, 56.78249382203626, 56.57946017480666, 52.68773155827677, 54.926773425071474, 57.161257497725956, 62.66331126613002, 54.312381206020234, 53.60835498379123, 45.08154192278462, 25.340807860897435, 7.456198200102776, 3.0108441941199766, 7.04345356072149, 5.611603606131769, 0.69274450502088, 0.0536054473430399, 0.07719852691215855, 5.469535848786754, 32.78225991033739, 61.094433799866714, 28.41750914050687, 37.66301416581677, 43.078936607606956, 40.24584001110446, 52.75111706026139, 53.93986978838521, 32.14277825047893, 1.137160812654803, 0.053792035717877655, 0.07453980344918466, 0.017410840035506317, 0.09812105462075242, 0.04550628153787506, 0.05098378721384272, 0.01764780060658532, 0.026786790957914728, 0.011607095816983812, 0.03901753980185717, 0.031057438107147336, 0.02022112824863965, 0.02814162511288399, 0.09620129190866025, 0.049640532477848956, 0.04176953063917257, 0.01579747897677965, 0.1650976014113234, 0.16619931245523115, 0.20015375418288095, 0.402165332869176, 0.17795283257240252, 0.16493252478539944, 0.19429344203202956, 0.08599009830504657, 0.14944964268755528, 0.2486180390922293, 0.12027339859595222, 0.2060503789013432, 0.18304359408155566, 0.2550252920557415, 0.11679976442528349, 0.17677635134708497, 0.2060152461091357, 0.6986957211648265, 31.468034482771355, 71.65966341572424, 66.892179366081, 55.1448925079838, 35.07770153783983, 32.91445555225496, 45.42831866971908, 51.42617179501442, 40.14229336092549, 5.413235618222145, 0.1783613719406628, 0.42773581560580964, 1.3320692700724448, 9.62950800695727, 24.93721950438715, 16.820656945628507, 7.509596367036143, 26.822624398816018, 64.4111978623175, 64.18504184292209, 60.412863146874216, 59.55930440656601, 59.539214026543405, 64.27513868578019, 61.838613325549716, 60.3435823225206, 47.047806478315785, 51.10539251758207, 58.116617433486454, 58.17440179086501, 59.785829128757605, 50.695387163469874, 47.052423108008604, 54.42205067603819, 59.319227895429066, 59.779015971768295, 56.10877183175857, 51.896577727410104, 51.52220318394323, 51.62004670789165, 53.09893715766169, 49.37253252152474, 50.90341006555865, 57.87086525271016, 58.14179512762255, 54.61680027746386, 49.498762238410215, 43.14996288668725, 45.552967671425115, 48.85608188567623, 51.675544323459754, 47.04979119762298, 46.00216927066926, 42.26188728886266, 44.69278404789586, 43.17080243941277, 44.904435142394036, 43.660259323735396, 46.60007969025643, 48.36452261094124, 52.17907467196065, 50.51846865684756, 53.63618027779364, 55.82938532675467, 57.700618697750954, 55.70888619269095, 60.28501349110758, 55.187344320358775, 64.43615590372394, 37.04537814663303, 40.3941212930987, 63.88130134151828, 51.54961662907755, 54.968523133185606, 47.204336504782404, 49.13377000439552, 47.198005799324285, 52.01390758637459, 52.966439493240856, 52.62709171541276, 47.285168709293494, 45.73140413530412, 41.86494342742428, 44.71402368237896, 44.73214895494523, 46.223288966763405, 45.47793665239888, 45.35492720142488, 44.77331422990368, 44.597611658034786, 44.263602226011216, 51.214720741395034, 60.92411664224441, 56.97767880655105, 58.73532818209741, 53.275008432326786, 47.832437407585886, 50.92937223372921, 55.31236986960135, 57.20032038227205, 59.623093912678385, 54.025400992362734, 52.02220732165922, 54.00060769050352, 54.95316705396099, 58.903888117882516, 57.23716712767079, 59.78070651331256, 57.08188441491897, 50.32144015835178, 58.444959040611025, 60.65822309063327, 56.55283512607698, 58.943343239445845, 57.9390242791945, 58.04957628250123, 56.63949205029396, 61.13908213953818, 64.11951080445321, 59.71085302291378, 55.96060037612916, 47.36640099556216, 29.25213459999331, 12.605947621407049, 10.92460697697055, 12.948156768275847, 6.739349259484199, 1.1298921704292297, 0.2882670268656746, 0.14195229257306746, 7.733289628259598, 39.56832116649997, 73.70260638575401, 35.54952344586773, 41.029270695101836, 50.53394632954752, 50.17597121577109, 60.888842767284764, 61.47218158168178, 38.50436649014873, 2.1263207927826913, 0.19138436103540082, 0.1595886937913395, 0.267367382203379, 0.21886831690226832, 0.11098112745751297, 0.23254727644305076, 0.1292132922718602, 0.1121473354437659, 0.09640074289974668, 0.2141466565550335, 0.15748282533980187, 0.15031962745612668, 0.13649788444801686, 0.21452135015879908, 0.20270603738965529, 0.10334237283396144, 0.11350284375610853], [0.027126236856284163, 0.028065575564640666, 0.04568266562156139, 0.03365148076667421, 0.0876872665098598, 0.04615593558898376, 0.06167162540218523, 0.025158530446670713, 0.06723609737931721, 0.037897143873476216, 0.009097555528334793, 0.03759038311639621, 0.0232027328738402, 0.06936962160492136, 0.018854703183376023, 0.04606950937980606, 0.10760927572846414, 1.7661916849113282, 38.50067161744641, 52.32224902799053, 51.17175117615731, 32.17719900992609, 19.66662087748128, 18.848587043823738, 36.51550123768468, 45.71350636020784, 23.982849967095163, 1.2663439517059636, 0.03087766983005549, 0.056318099565443494, 0.5939504191760094, 7.4118087368626755, 12.406701022578824, 5.343101678356048, 5.00251050918333, 23.925420584217196, 63.261319744971495, 59.888446177205736, 56.60017028931649, 55.512838286738244, 58.35954943010884, 56.40368307790449, 58.64084612938666, 56.02721791113577, 58.50116268281014, 52.15484619140626, 56.93539173372331, 55.24927462300947, 52.7743374916815, 46.83281744680097, 46.22281828234273, 53.23205455656975, 53.26487695017169, 54.56823348999024, 53.02855022491948, 51.90120220184327, 52.8007624995324, 52.27079929844026, 52.31394537033574, 49.690111144896484, 50.84868123454433, 51.49835517329555, 53.669316461009366, 49.92919921875001, 43.69314055288992, 40.87378794147123, 42.11414337158203, 44.153289487285, 46.603523531267726, 40.973345541184955, 40.49843672783145, 39.21277792223039, 40.25006440378005, 39.507214561585464, 40.05389098198184, 39.262274311434844, 42.17694836278116, 39.72905989616148, 39.647043135858354, 39.02311563491821, 41.4503881239122, 39.54342196064611, 43.616638645049065, 42.79992272776943, 49.545438443460775, 49.5151852023217, 60.62680882792319, 37.26679986523044, 40.51684441105012, 58.79021390791863, 49.08690552557669, 53.34550126906365, 46.78361523535944, 53.11376371691304, 52.23494099032495, 52.59312006735033, 52.858154619893725, 54.175423806713475, 51.0128402709961, 46.644174975733605, 40.75199050288047, 40.873054458249, 40.207683194068174, 39.4659512273727, 40.81260288915327, 40.58268923913279, 38.980302964487386, 38.48987333236202, 40.1685183278976, 48.413579694686405, 56.025056685170824, 55.251608433262, 57.1228967174407, 50.079069060664025, 51.921214134462424, 50.394149134236, 51.31591004710044, 55.59385092027726, 50.88235478247366, 48.797226721240634, 49.07664852757608, 48.55358869798722, 50.01331444709532, 51.17566962395945, 52.781099657858576, 53.60885312480312, 49.87910270690919, 52.9726956736657, 57.112090587615974, 53.78875263275639, 52.044796251481586, 46.874229831080285, 47.23427987867787, 48.14828626571163, 56.9688299394423, 54.90702036888369, 61.79915428161622, 28.45115915421517, 35.50612634228122, 50.03868433736986, 36.49793686405305, 11.662593080151467, 2.253834350455192, 6.887260367793422, 3.9302725224725665, 0.7435895766942733, 0.0460055333772494, 0.05440193363615582, 1.7723246783979478, 21.46266241227427, 39.32350250982469, 64.3911349388861, 23.969274643928777, 31.31706637720908, 44.42664730933405, 45.74350464728571, 45.48259250579342, 36.332075518946496, 3.2807988697482697, 0.2277085425392274, 0.057196974784376166, 0.060045278195532105, 0.028292657431936073, 0.06949986421292828, 0.0535964266577315, 0.048029361472975825, 0.04475692880430049, 0.05185979726393858, 0.03587161123211827, 0.03636674917933922, 0.0385751431777833, 0.03199704303105753, 0.09191308410898333, 0.03165083257631669, 0.06457260884945432, 0.034609688220605735, 0.05544563650243706, 0.029005747393614827, 0.012834892484299358, 0.08804971802859538, 0.09878126153301808, 0.08680530778703191, 0.06629549462588565, 0.03261654960712598, 0.03389454514328991, 0.015308766592023595, 0.05479321304348208, 0.027946671057913094, 0.018268684225697673, 0.025407202586892153, 0.05745295540339524, 0.03966584936865876, 0.05993713722414067, 2.694624426864809, 46.762912965589955, 56.98054998151718, 58.67183285374796, 41.40397079529301, 28.839495374310403, 21.494027645357196, 33.397938666805146, 49.01336892958611, 26.458400949355095, 1.4551040938785, 0.1385074709692309, 0.04084535281083757, 3.0721189706556262, 12.3158638323507, 10.990932295399329, 8.283212300269835, 3.9507990210287036, 25.642083152647942, 64.43467717016897, 61.402163351735766, 58.37676079042497, 55.93942349956882, 59.77674884180869, 56.47603119573286, 58.17644142335462, 56.743705503402225, 59.56390926914831, 53.619808304694395, 57.30744423404817, 57.648129540105025, 55.61756164796891, 48.44362897257651, 49.180693318766934, 55.88868371901974, 55.59151318765456, 57.0743416970776, 53.5424630872665, 52.09670882071219, 52.09943486798195, 51.12290982277163, 51.99994787093132, 49.28766419810634, 50.65823839556787, 54.043047735767985, 55.73053767604213, 51.074252820784054, 44.90150513187532, 42.31799287180747, 43.42003768490207, 46.23651127661429, 47.38282003710347, 42.712908867866766, 42.757478760134795, 40.67031106641216, 41.9970606219384, 41.75256752198742, 41.79590971239152, 41.61524534225464, 43.55993686183807, 40.40900276553246, 41.307606004899554, 40.553812749924205, 43.57269240963844, 42.919594241726784, 46.54205214592719, 43.74894411333146, 52.55996819465391, 50.9501451061618, 61.261605216610825, 37.4167638440286, 41.405814309274, 59.70388689348775, 51.190260841000466, 53.391432223781464, 48.745486736297615, 54.02941357704901, 54.76563853602256, 54.52473048240908, 55.73156925939745, 56.8293426113744, 53.388310017124304, 49.26802489065355, 42.056174662805375, 40.66150142300514, 41.5449760806176, 42.022297151627086, 42.69447372805688, 43.626138625606416, 41.25914119905041, 41.04763130987845, 43.98714573152604, 50.209676142661806, 58.11515046704201, 57.80427909666493, 58.8046129288212, 52.39072576645882, 53.18282881090718, 52.110088025369954, 53.791298250998224, 56.48695499666276, 53.144417039809696, 48.18888671936528, 49.403687907803445, 49.189157793598795, 51.074825486829205, 52.34219820268693, 55.248015542184156, 53.97704209050825, 50.49121210652013, 54.730517633499645, 59.60511376780849, 56.101538981160815, 55.31930069769583, 48.17351495065997, 48.42134598762759, 51.17206496577109, 59.26452259863577, 57.0676540559338, 62.887906182196836, 31.468624799482285, 38.30669080057452, 52.33247856939993, 36.90982103347778, 13.335683999523042, 3.3717510344520694, 3.707470374722635, 4.020977332707375, 1.7862530148798421, 0.2754029703717078, 0.045101944161879445, 2.0040600242153292, 24.161335460601318, 56.27959889750327, 58.1662707174978, 25.96343117375528, 39.650177109626036, 48.10344965227189, 53.02492595488026, 50.711182548153786, 45.15778103182393, 5.1927327148375975, 0.08132225563449245, 0.045526379854568554, 0.033563035915816025, 0.021219854092886372, 0.06966872531319819, 0.04931768387435906, 0.01744436787351245, 0.015361269470304252, 0.11915972891954646, 0.05391808399449914, 0.05515818882192816, 0.04371525990145822, 0.0294198140862488, 0.0646692891454985, 0.050028058054346236, 0.035563900526012146, 0.07663533737462375, 0.13024225560647826, 0.09623362081906489, 0.18151603008229888, 0.12359561548838693, 0.21151048672055045, 0.2085774884589257, 0.19214766039963693, 0.16817666199659148, 0.14851466301948796, 0.15832040458917618, 0.22290311813835176, 0.1166622976081506, 0.17497809784066293, 0.2155717026682631, 0.1480779622591311, 0.1460805718576716, 0.14783305927149712, 4.137818611437275, 53.72785783583119, 64.64612037904801, 65.42151804893248, 46.66423397679483, 30.45467838164299, 28.948711810573457, 48.742239013794936, 59.17770485724173, 32.29889250570728, 1.7548214692261912, 0.459739659582415, 0.3373718225667554, 2.54268259290726, 19.99206385304851, 25.066589078595563, 16.217353267054406, 9.878332384171026, 28.228437169905636, 65.41565802789503, 65.22130458585679, 62.309489942366085, 60.119803259449625, 61.07818342024281, 59.452462965442294, 60.11684971470987, 58.206824102709376, 59.63265272878832, 55.551359884200565, 60.439229319172526, 60.54015974844656, 59.33063807026033, 51.712230251681426, 51.0102475843122, 58.647216058546505, 57.748769713986306, 56.972869980719786, 54.284049926265595, 53.33638175841301, 54.758884214585834, 53.68771237711753, 53.788195656191924, 49.61720212813347, 49.945657483993045, 55.074081959262976, 57.95614150262649, 53.63526244317332, 46.84525920498756, 45.52470307196341, 45.69280801280853, 48.66254037426364, 50.474514576696585, 45.669293403625495, 44.13102219181676, 43.88534453607375, 43.89465624286283, 43.32481430422875, 43.29269401488766, 44.16068315505982, 46.88178431603217, 41.9290663350013, 43.45509190713206, 43.02632585648568, 46.87075853347779, 45.886463272956114, 47.53099541510306, 45.83878294114144, 55.234000913558475, 54.2123999903279, 64.9656758769866, 40.77548550021264, 43.51021689753379, 62.183142554375436, 53.039540706142304, 56.57937388266287, 51.77041469081756, 57.6960648259809, 57.16921990917575, 56.335763316000666, 59.4314076823573, 57.458027947333555, 55.67678551520071, 51.94885115469656, 44.84732935505529, 43.76545729175691, 42.65543830010199, 42.98415253239293, 44.68111107426305, 46.22830960058397, 43.50284676398001, 42.42048440441009, 46.00168681913807, 51.95860608931511, 59.52595641536098, 59.14607878654235, 59.7539794829584, 55.01303026753088, 56.80410608168572, 54.86302314266082, 56.95187745555755, 60.646930586907175, 54.133011218040224, 48.132075109789454, 50.01790362019693, 49.7767053111907, 52.850294190068404, 53.05080967564737, 55.677550377384314, 53.82527382143083, 50.62392157893027, 55.084405637556515, 62.48997780584521, 57.00473531599968, 57.339238966664965, 51.78070699014972, 51.72955143836237, 53.07771321265928, 63.003612179909986, 60.679250917127064, 66.8251617493168, 35.03763060415945, 41.73013156460178, 52.384818676979314, 41.07823364196285, 15.973431852556045, 5.529801105299304, 15.339997506910755, 11.627411380890878, 1.2362162264124041, 0.16646200400446692, 0.22640392544769475, 2.7898671742408507, 30.978226546318304, 52.82998415731615, 70.56086632513231, 31.595742933211792, 42.46951010919387, 56.29469610029652, 60.44530507056945, 58.21184865890011, 56.847220774619814, 7.695215671293198, 0.4254628020909525, 0.11276651834768635, 0.15105179300712002, 0.10773728135973216, 0.16758708073006523, 0.14411318145932692, 0.09867168797720825, 0.1306916427828612, 0.46898416513877533, 0.16357045109954574, 0.15305998524831188, 0.2817246053488024, 0.11434503485478702, 0.24623322270570264, 0.1304415303973421, 0.17206227527030055, 0.19552742581694357], [0.052749681166343154, 0.059780682917804494, 0.05320083800583117, 0.020072637426276362, 0.052721052460612795, 0.02520580956291768, 0.044076799775563905, 0.019368526015070178, 0.017613161941088976, 0.06472012674015376, 0.014555903260536013, 0.033465064761619416, 0.03350061124130603, 0.012562073252704597, 0.07022604661723299, 0.06311038448925942, 0.13620370668509316, 11.980758097863967, 50.80988507116995, 51.65321034769858, 49.03469485621299, 33.28025579452515, 20.1719613998167, 32.28468764212824, 41.57584513387373, 36.98877050030616, 22.60964385924801, 0.09506891436514356, 0.49141803876526896, 0.4236067242680058, 2.931350988726462, 11.830618593000597, 11.257578942083544, 9.540498641229446, 4.414935044703945, 20.226562753800426, 59.31557224642847, 56.415238380432136, 59.49005496117377, 57.916474573073856, 59.92796405669182, 54.63040697959162, 58.9236843201422, 57.64647822226248, 57.950724709418516, 55.851731069626354, 56.17576591430172, 53.86214802342077, 54.117121696472175, 48.15272638874669, 50.613911690250525, 51.42470482856997, 54.07327352031585, 51.596794897510165, 50.066823420986054, 52.3844656636638, 54.531641698652706, 53.67820847419001, 53.99133912978634, 52.640243422600534, 49.916631944717906, 52.05783420993436, 57.14419126510621, 50.575382248047866, 44.64109897613526, 40.97154517327586, 42.07321736120409, 43.340213529525265, 44.489197346471975, 40.228522746793686, 40.886810210443315, 38.59911918640137, 38.78383536492625, 38.77035025627383, 41.579061477415024, 38.725682304751494, 41.15248803169497, 39.977914671744074, 43.66953965156309, 42.32383720336422, 46.68208076107887, 43.51512770498953, 48.16591731963619, 46.27212639777891, 51.98072041234663, 48.47557667763003, 60.209751052241174, 34.07599487612325, 36.5879984055796, 59.895741785726244, 50.43640875047254, 53.79956660732147, 50.30674303731611, 54.17991492056078, 53.3730088510821, 54.524640267895116, 54.90866384198589, 54.2661835301307, 51.511793213505904, 51.780801127033854, 44.687496692903586, 42.263977912164506, 38.33415131415091, 40.0492351285873, 40.3382981208063, 42.825994722304806, 36.91695582482123, 42.41862912331858, 40.776081700478834, 49.828335469768895, 55.54870051722373, 54.52071005298246, 52.839629265569876, 52.32458283824306, 52.12212185705862, 55.31231495641894, 55.08238561691777, 50.68921335281865, 48.06706182418331, 52.41368732144756, 52.23989494385258, 50.94278281734836, 48.66763945548765, 51.021732284176736, 48.14699188355477, 50.745522899012414, 51.31931074203984, 55.56549218393142, 55.5041737710276, 54.03262207584997, 49.11868849108296, 50.36170721054078, 46.54664524139897, 49.494718274762555, 51.15297479014243, 54.49027246044528, 53.36604664402624, 58.64277593551144, 58.00402187531995, 51.58392952334497, 47.10151157071514, 23.47382437798285, 4.026192614147741, 2.360816751756976, 6.10552954096948, 2.7607234735642714, 3.250826813520924, 0.04756926821785108, 0.2231431947720628, 14.919287024005769, 27.73717599530374, 43.563796474087624, 39.065179132646136, 17.8962218376898, 32.994256173410726, 40.21282149899391, 49.496036191140455, 40.74713068623697, 8.063654688096817, 0.2028177176872569, 0.057044979109759295, 0.022261726009028576, 0.013438905889709151, 0.04290505680405805, 0.044278828652515534, 0.09194652384687817, 0.046612382265588934, 0.15691982732424814, 0.0496831537795163, 0.06717416683151838, 0.028163110048720436, 0.018064918244377743, 0.020627717923132644, 0.01649914752511728, 0.05433852070822351, 0.020977201488529964, 0.0031766221218276773, 0.018367948153266506, 0.042246726807206876, 0.0063854117967909385, 0.02662889449106109, 0.0159908864917534, 0.03203345710531839, 0.056864128733474406, 0.0320335126466929, 0.018344825704491908, 0.01904930866834137, 0.023715563621672413, 0.04731061395197626, 0.03200003077396222, 0.08626042775088742, 0.03657814348116517, 0.11864206032647241, 15.135885207883774, 59.35776910474224, 56.5940200128863, 54.374758658870576, 41.54926323121594, 23.93409686703836, 27.160118856737693, 42.488902307325795, 41.00207690269717, 24.523803649410127, 0.12931014110724773, 0.701384689779051, 1.9126285949060995, 4.506588087927911, 15.606829485585614, 11.947203201632346, 11.492606382216177, 5.753016817954279, 21.983727716630508, 61.83185115937264, 57.393414743484996, 61.05864217204433, 58.775548165844334, 61.03559040254163, 57.06702255433606, 61.279542215408824, 59.50853716942572, 58.20130532787692, 56.72601953629525, 58.02327679049585, 56.22887872880506, 55.51339526330271, 50.52934146696522, 52.54820108413697, 54.74081385520197, 55.726650607201364, 52.32119783278435, 49.870869651917495, 53.37897869848436, 56.03071666532948, 55.93261426494968, 55.39700285080941, 53.2696936207433, 49.15781413355182, 51.63905843611687, 57.97041893005372, 51.423826217651374, 48.788597506861535, 42.160984316179835, 44.05558716866278, 45.796539014385594, 46.953300891384, 43.211987326222086, 41.49791156091998, 39.992215633392334, 41.19330421570809, 39.06466922452373, 43.13219454980666, 40.98670905636203, 43.578803462366906, 41.324060347772416, 44.1923523718311, 44.27176467833981, 48.455352937021566, 44.56107477987967, 48.995580980854655, 46.82284285945278, 54.30938843757876, 50.7571291923523, 61.32888955454673, 34.73111698704381, 38.38640905195667, 60.821425068763, 51.72057313303794, 56.55168979398666, 51.792548625699936, 57.18182640690958, 53.921979858029275, 55.35226429662397, 55.706093465128255, 55.86929936562815, 53.496418383813676, 53.81385187948904, 47.75773586765413, 43.32852878878194, 40.69981905721849, 41.260239462698664, 41.98483851648147, 45.69520850335398, 39.739054095360544, 44.49549667296871, 43.2578908243487, 50.662584381718794, 57.92259739291284, 56.53325857654695, 54.473421958185014, 56.55065821063135, 53.91503726282428, 56.53748689159271, 56.286969031057055, 51.867246243261526, 48.16517599167363, 53.37631540913736, 52.00163449010542, 50.37823607844692, 49.78729963302613, 51.32115033365066, 48.922734722014404, 51.84110364606304, 51.488882649329405, 56.77841063468688, 57.91606272420576, 57.16772156376993, 52.39265165021343, 50.70591480501237, 48.64852966800813, 50.32091456074869, 53.064443834366344, 57.36659749861687, 56.07865587357552, 61.59417121641098, 58.52912918213875, 54.41906575233706, 47.15872326204854, 23.83278989022778, 5.692042102736812, 6.834011250926602, 8.011888227155133, 3.5068259412242524, 4.401061131108192, 0.047939851759902896, 0.26542537995884496, 15.405045113255902, 33.026670640514745, 43.59988227967293, 41.571656042529696, 23.478235083241618, 41.29406990543489, 47.716092063534646, 55.98605655854749, 49.743027840891195, 12.176854052851278, 0.36968780140722957, 0.055032611689380104, 0.02559317809139048, 0.03947459168792252, 0.04004456493402681, 0.032199250023451545, 0.00512245025733606, 0.06506861247602971, 0.07188333994558743, 0.04984443827021507, 0.018952231921796358, 0.09765139675789303, 0.04704581566094872, 0.060194523614500804, 0.05955655240423738, 0.013468282488775591, 0.04703821223830024, 0.17163472159975962, 0.146862716984845, 0.18570679149800734, 0.1680010593225879, 0.16906786740066546, 0.15899819321930408, 0.15363871870983034, 0.12377497965409873, 0.13246584112846083, 0.1606391382313544, 0.08933237904021818, 0.15498096604020367, 0.17407276577526526, 0.16742755058071307, 0.17238326611057406, 0.13295578499955515, 0.1854001724671933, 19.48851389269675, 67.9235666028915, 65.83921124858242, 62.977528418264086, 45.26927440397201, 30.292274605843332, 44.48309021611368, 51.900727595052416, 50.312740341309585, 29.411888814741566, 0.40977083927681374, 0.8577739399287009, 1.8217395558472604, 5.137841595757393, 19.028490474147183, 21.604924817239088, 17.6783969325404, 7.925258269233089, 24.643143723087928, 60.401864820911044, 59.069478819447184, 61.25991075269638, 61.20146743712887, 61.9425129890442, 58.74387502670289, 63.717020711591175, 61.98570612938174, 62.031499801143525, 58.909826586323405, 59.650872138238725, 58.111031978361076, 58.48702253833894, 52.55711270916847, 54.38736907897457, 56.63582463418284, 58.23443366635231, 53.22033843686504, 48.83207305785149, 55.243900975873395, 58.5747306577621, 58.08226923788748, 58.6119931743991, 55.937732958024554, 49.840122192136704, 53.815613023696415, 61.38766627157889, 53.72484545553885, 50.14868328648229, 45.08833546792307, 46.55237190185055, 47.32090542393346, 50.08929860207343, 46.08343685826948, 43.28552784458284, 40.83326201285086, 42.59728916229741, 42.18356932363203, 46.49583485818679, 42.34791663385207, 45.57531733666697, 43.35936646307669, 47.15105502836166, 47.662233998698575, 52.10274927077755, 48.69331529063564, 52.69112833084599, 50.962367211618734, 56.21466013693041, 53.29789938465242, 62.87358560869771, 36.65863637001284, 39.17942993102535, 63.71706385766307, 53.60062791455177, 58.412473970843905, 53.93095816335371, 57.812504306916274, 57.741187772443226, 58.873046521217596, 58.12329330751973, 57.42785315359793, 55.55260327554519, 55.051049801611136, 49.733241527311264, 47.744368430106874, 43.24378990357922, 43.57965069432413, 42.5623369216919, 47.254429094253055, 40.147227702602265, 47.4035732976852, 46.16594391484415, 53.006694778319336, 60.42272006311725, 57.931689446972264, 56.097577387286776, 58.38933983156758, 55.7970767636453, 60.72791576385499, 57.21635895390665, 52.37156498816706, 49.3081860388479, 54.5578823551055, 53.84739598920269, 51.34391577013078, 50.55708439119401, 52.02508634136569, 48.516898847395375, 54.26170418339392, 51.61042121148879, 58.05974698835804, 60.0945588850206, 60.45295369240546, 54.82564295491865, 54.77614264334402, 52.47833974899785, 53.95579068891464, 55.58021283918812, 59.322530531114154, 58.19426859578779, 62.89273461987896, 59.47334958660988, 55.680633360339755, 50.15309987529632, 26.030509587257143, 6.943094326603798, 7.5611779862834565, 13.149445941371303, 5.920266191805563, 6.207031655696131, 0.23715740971026883, 0.2791643088623401, 20.775023852625203, 39.1240107628607, 55.861874318891964, 44.613069718883885, 28.798055533439886, 46.817590805792044, 55.091038365517896, 63.01982333583217, 60.52192072714529, 18.689187803576072, 0.7808873333757924, 0.2341317607750816, 0.20552350959229856, 0.07811561842719394, 0.10717212297623196, 0.09232379150606933, 0.15916691642374764, 0.1786277713554521, 0.2812468116321872, 0.217173638483209, 0.1503762566754895, 0.1836433030304409, 0.08970272126457385, 0.1670523973241929, 0.11011275147358257, 0.10336959193791113, 0.12038981331692589], [0.09042300479186159, 0.0825789386046029, 0.013116580141227574, 0.010567469496069657, 0.06939841884999506, 0.026249372618152734, 0.040050391032690966, 0.014750242529947673, 0.05511175623283752, 0.06624303292483091, 0.031120454584578836, 0.0669959671194515, 0.030052206261203657, 0.013187960383572407, 0.025176839948061015, 0.05133957376763706, 0.31446757095475353, 19.181145198883552, 51.454401093144575, 44.79235733709028, 34.71644340022918, 14.844288364533456, 28.353327397377264, 48.41855718243507, 40.87915374386696, 43.80415931824715, 11.693564115032075, 0.14367183820614893, 2.0671886109536697, 12.264137575703284, 8.447163451102472, 14.80649926970082, 5.523451768582867, 8.302407399300607, 0.6426289329125036, 10.612163716746915, 61.568879773539884, 52.52370980478103, 60.54692975936398, 54.75525994454661, 59.028254708936146, 51.50101454027238, 54.34745896247126, 51.44225351272091, 56.78383527263519, 57.845020755644775, 57.05590263489754, 55.04189498962895, 53.31240038717947, 52.52273313460812, 54.01117847811792, 53.22629259478662, 53.880316442058934, 51.585706357033025, 52.95918310842207, 51.697470372723, 49.705765324254195, 50.50113962542627, 53.30356328718124, 53.65175993211808, 51.39994290567214, 46.89881916969053, 55.10186802956366, 51.84381008148194, 46.89866227488364, 43.552221559709125, 46.31832015129828, 44.81045907543552, 44.30174727593699, 39.095263711867794, 38.38449885768276, 37.66479099950483, 41.26222418200585, 38.155020590751406, 40.57411493793611, 45.57075562015657, 52.24688852986982, 48.18318359313473, 52.63304195096416, 50.632829281591604, 54.43421002357237, 51.58432568273237, 56.64447738278297, 51.03042425647859, 57.0909333229065, 50.926991355034616, 62.77436925518898, 27.569675099465158, 30.626338951049316, 59.082705051668235, 50.887575457173014, 58.221340794717115, 52.11228455266645, 54.43342554953791, 53.61946313611923, 50.76278525014078, 47.15749556018461, 50.48210044060984, 53.58455011921545, 54.37038521612845, 49.943613929133264, 45.25888404538555, 38.095137765330655, 38.011489299035844, 37.94849603406845, 41.40308826200424, 39.553690725757235, 38.60350047388385, 42.39737772172497, 48.71670830634333, 55.04415819721838, 53.18804164086619, 48.99742449483564, 53.70931679202665, 54.5839229706795, 51.41146682923841, 48.24408231243011, 48.880482950518214, 50.32369944357103, 56.398658521713756, 54.24576367101362, 54.611128530194684, 55.50619771403652, 50.977409501229566, 49.73675989335584, 51.37209799981887, 50.26223982534101, 51.783134937286384, 54.30069646527691, 52.660651514607096, 53.00512583025041, 51.906340506769, 52.23010863027265, 49.91600044312016, 48.16751372429633, 53.206727812367106, 56.12509281404557, 57.243411540985115, 58.32757034609395, 60.03105963430097, 53.251372229668405, 29.31813043932761, 10.142476558685303, 1.5642525015338775, 3.1160431427340356, 5.32735973596573, 60.002677363734094, 6.690613319796901, 0.10299934930498562, 6.683496669415505, 45.658047968341464, 27.43087810854758, 20.331252774884625, 28.647999378942675, 24.55014824867249, 41.64398062613703, 47.121594105997396, 46.98529174250942, 19.268670928093698, 1.2112621073761296, 0.07159767341950247, 0.03986261139113096, 0.015803462123468278, 0.029868961860155387, 0.025153646636153423, 0.06629090575921921, 0.02900515367547351, 0.022715793982628855, 0.031525033278270595, 0.03508104679865703, 0.04945991575838097, 0.0680583318875682, 0.04861591286176155, 0.046383827594259096, 0.10313133859345991, 0.022011222918668104, 0.028542233555908167, 0.11065609167299925, 0.03678853803824994, 0.018176782403081175, 0.05171041777958313, 0.05832705406412002, 0.00684402410819706, 0.04215576152707781, 0.0195404687040155, 0.037659392316615393, 0.027871504426002506, 0.04006667040108193, 0.06443082129642849, 0.06873877884279336, 0.06895410317567087, 0.06109259699681594, 0.37145823060024175, 25.571570704060218, 58.44542580266153, 53.4092790080655, 43.244617523685584, 28.51644700573337, 31.282433809772616, 43.73691420401297, 45.76629754035704, 47.91121429012668, 14.627642131620838, 0.29295514788358445, 2.4383323471392355, 16.789213265142134, 10.486142866073116, 10.268686663719917, 10.071355162128325, 11.84753381436871, 3.4092079535607374, 13.70325028896332, 60.20216518832792, 54.474167208517756, 61.75348612569994, 57.12863906737297, 61.95284451207807, 54.51492063460812, 56.914681619213475, 54.491833563773866, 57.939847976930686, 57.86786463952834, 56.83380234626032, 56.938372735054266, 56.01805525441324, 53.91182091928298, 55.071606943684245, 55.185336066830544, 54.71266692684543, 52.51826555498185, 52.847313188737445, 54.422466447276456, 52.683887635507894, 53.890793092789195, 56.606446081592196, 56.36845234901675, 51.41066666572325, 47.25377798080445, 56.55010123406687, 53.04637347498248, 50.052240048685384, 45.36534893897272, 47.90852354418847, 46.743548224049235, 46.00866863804479, 41.123533095082934, 40.059958888638405, 39.91799654499177, 42.78955982577416, 39.94935981688961, 42.386300948358354, 47.2283374878668, 52.3347496217297, 51.103882405065725, 55.25123580809563, 54.04190240367767, 57.02167995514409, 53.83238507855324, 57.290801617407034, 52.91408761855095, 60.19261029458816, 52.870902322953754, 62.312023793497396, 29.299336402646958, 32.7406886700661, 59.77281078215569, 52.08893860540083, 59.78027897496378, 54.62327611061835, 55.979721930719194, 54.62155026774253, 52.201165460771136, 48.11602084867416, 51.7715992466096, 55.68785052145682, 56.15900170418524, 51.73021039655132, 45.366129490637014, 41.19952509480138, 40.71930539223456, 40.54250455671742, 43.20766487429219, 41.03965713131813, 40.76354972777828, 44.41347599029542, 52.19400713520666, 57.3224590670678, 53.18284450038787, 50.60347034085182, 53.94484335376371, 54.340261413205056, 54.48806416603827, 50.135817912317094, 50.43307473582607, 51.85228240105414, 57.21571960756856, 56.65245548371346, 56.85776018327283, 56.495466539936686, 52.5721981448512, 49.379973257741625, 50.7653191012721, 51.18932339452928, 54.059949228840495, 56.70144980953586, 54.87247997714628, 55.18045271596601, 54.41577488376249, 54.315370052091545, 51.95541327999484, 50.06711367637881, 55.475305126559356, 58.90905387939946, 59.65773236367011, 60.21771346369098, 61.16204369452692, 55.48095333960749, 32.7253012118801, 10.639837999497692, 5.337440717604853, 6.493457344270523, 9.225635278609492, 62.43223267216837, 8.662186803356294, 0.11330521605428188, 8.95226667004247, 42.26778261123165, 32.78869455860507, 30.331719921481227, 29.164291158799205, 28.09299968904065, 47.89231631063646, 51.6335710402458, 54.31248711001489, 26.561023881358487, 1.3708399380407026, 0.03083424222084784, 0.06981246639043093, 0.03165626030926022, 0.05013984943469686, 0.07399997959334044, 0.06631069381030337, 0.0650416385202158, 0.03295792604706461, 0.08731737627737945, 0.06700683790709704, 0.05095120549442307, 0.05501330244324862, 0.0062107581142035705, 0.03596386353996012, 0.025462462424090313, 0.012656693729842383, 0.24209309970178913, 0.2744496199152162, 0.09605765808373691, 0.08838722572451638, 0.24044277777354564, 0.17498755136564856, 0.10732502646503911, 0.15933893380626557, 0.11825838051135502, 0.14571200695730027, 0.1551747249980127, 0.16902973154379478, 0.19896188991204386, 0.12529154263076284, 0.14327938668429852, 0.19205713945050396, 0.5853593866190603, 33.78036975860596, 67.26764432845577, 60.38737558549451, 50.442994409991854, 25.832549525845437, 41.073503263535045, 62.42549011784216, 51.29661198585264, 57.59661313026183, 15.418528260723239, 0.4093207166560235, 2.423442049372581, 18.228705467716342, 16.287995153857818, 26.740637056289184, 12.25319710470015, 24.499077027843846, 6.306283800832688, 12.032591239098581, 65.5776793726029, 53.8832974433899, 61.82044490691155, 58.708138312062914, 64.41274719853556, 56.27458218605288, 59.553511065821496, 56.214550310565585, 61.86423032514511, 59.801444084413596, 58.631330459348625, 60.127612698462706, 58.58749797267299, 56.79982677582772, 59.07882974993799, 57.11612278415311, 55.27473472779798, 52.72306034641882, 54.770239476234686, 57.24885579078429, 54.76479130406534, 55.3255529557505, 59.5711931105583, 59.09043996564804, 53.42501947956701, 47.84003111623949, 59.148134108512636, 55.693079040896514, 52.12201987543414, 48.129082341347974, 52.21320713720014, 50.46008809920281, 49.70976614182996, 42.88913311496858, 42.02628227972215, 41.27219484698388, 45.53770180671446, 42.20467559752926, 45.18466103461481, 49.19718688534152, 56.52939111955705, 52.035366873587336, 58.18362328314013, 55.30471732539516, 59.70750331878663, 56.658794033911924, 62.61349324257144, 55.93971767733174, 62.20146394545033, 57.78176469187583, 62.93084436847318, 30.676908108495898, 34.525784830893244, 59.47751906610305, 55.00461678351126, 61.780566169369614, 56.56049551502351, 56.62250818744783, 56.75979114347889, 52.416982112392304, 48.305455638516335, 52.440261379365005, 56.05475294974543, 57.517557759438795, 55.07001053902411, 49.280082256563254, 43.98727516974173, 42.60630276895339, 42.647977952034246, 45.05128083690521, 44.14963776065458, 41.91860145138156, 48.09186297078287, 53.98597332739062, 61.34040563337265, 54.34337577512188, 49.34714301939934, 54.21451414785078, 56.97788669217018, 54.053261587696696, 49.6922762932316, 50.078315965590946, 52.61243381807881, 60.88560288952243, 59.15256246443718, 58.57145940103839, 57.919506565217056, 53.957187052695986, 52.5562576324709, 52.48391343701271, 51.80350772796139, 54.90891879604709, 58.92461392187304, 57.90746881115822, 57.550289938526774, 57.070317345280806, 57.03847162185177, 54.93150772586946, 53.12058864101287, 59.63781064556491, 61.46153626903411, 60.45002368188674, 61.98016774269843, 62.743409987418886, 56.32115640947896, 35.91351155311831, 13.717854253707396, 4.920731052275627, 7.6424176269961945, 12.836017185641875, 69.0573198564591, 8.369158294893081, 0.21684716245339763, 9.42679403289672, 61.0379320575345, 35.69198393052624, 30.497075280835553, 36.90117220724783, 37.01730182093959, 55.23872344724594, 60.919700053430375, 62.33640524648852, 34.163463730965894, 2.174512258460445, 0.15367302412707962, 0.22614814401153596, 0.07145688178077822, 0.19281003534072833, 0.1287893238928049, 0.1812163977733543, 0.13852263951013166, 0.14428498433722606, 0.12998555486481037, 0.22846735262822723, 0.12148759432978208, 0.2309116327594365, 0.09949056702035089, 0.15761404087947262, 0.17091185635616704, 0.11081663305841147], [0.01904647031258191, 0.023868693106417215, 0.03710800819399376, 0.05351725913163635, 0.025604271044534062, 0.05731283792204434, 0.07858922930374261, 0.028169491561129693, 0.06014560123965625, 0.07981351441553525, 0.03139108471992997, 0.02748242752145856, 0.05517718397201069, 0.04545976850955237, 0.05331432244049446, 0.019218261699162183, 2.1236065126234487, 32.61710263067676, 51.03487614662417, 49.506909001258116, 35.58198498141381, 25.619421658977387, 40.53332228814402, 49.23912094485376, 46.514509262577185, 36.51494426112021, 6.136513813849419, 0.05816154459851885, 5.149420432506069, 18.145947379450647, 6.588816046714784, 12.52810916592998, 9.938421134025822, 8.295645233123533, 4.752441760032408, 9.869939492594812, 50.78771583495602, 53.649390820534, 60.558696869880926, 54.169665767300515, 56.788722545869895, 52.13526571950605, 53.06824853343349, 50.273304831597116, 55.58839882573774, 55.60942272986136, 50.42204110853134, 50.58300733566285, 55.25499343872071, 52.12080394068072, 54.960984337714414, 52.744072483431914, 51.7547958127914, 46.946625017350726, 53.53878390404486, 53.887427699181345, 48.48957561677503, 48.63448758279124, 51.94240670050345, 51.29180708239156, 54.001490223792295, 49.691056436108006, 55.321807092235936, 52.24813584358462, 51.5002182991274, 45.79205574527864, 45.29699379397977, 43.89610359745641, 43.13801534714238, 38.357979712947724, 40.033392675461315, 38.655868038054436, 39.86535441490912, 37.59159564971924, 49.86909281822943, 52.61664252127371, 54.107354994743105, 52.333847476590066, 56.98362904210245, 51.961183086518325, 55.300987151361284, 52.74610819355134, 55.24230064884309, 52.97441367180117, 57.15704094979071, 49.71099776606406, 56.58293147240916, 26.726012499101703, 25.914944794870195, 53.790137229427216, 46.787867084626235, 51.04478013130927, 48.17905725971345, 50.38031885700841, 47.555945611769154, 49.88000877441899, 47.39583838370539, 47.73006354608844, 46.769898706866854, 53.78688558455437, 52.72299758849606, 49.533169269561775, 39.54913685398717, 36.76810579915201, 38.658880418346776, 38.37558723265125, 37.80814970693281, 42.28203258206768, 40.95586745969711, 51.346328027786754, 53.48156044560095, 51.53891640324747, 46.662072750829886, 51.39159610194545, 46.508076575494584, 47.89000995697514, 47.07835389721779, 52.08882877903601, 54.30331660855202, 52.854267551052956, 50.87392168660318, 52.487078789741766, 51.54865564838533, 56.5897407070283, 52.67358749143539, 51.585584763557684, 48.26751062946935, 53.639773168871486, 53.478344102059644, 54.13050090112994, 52.78568883096018, 55.15505929147044, 55.07400351185953, 54.944043620940185, 49.71516724555723, 48.583233971749586, 50.203117939733694, 55.22287314937961, 57.39932967770485, 57.93848299211072, 63.336676320722034, 47.044146906945016, 17.702248865558257, 14.784831116276404, 9.37984130074901, 3.5334853106929414, 11.532558664198845, 8.908924479638378, 0.040364563690438386, 1.6307740610453392, 29.797855923252722, 36.010527456960375, 24.108554086377545, 24.243432629492975, 31.292037733139534, 35.69196039630521, 46.10746529794509, 50.005705048961026, 40.303510619748025, 3.1653821468353276, 0.03782991199724136, 0.047142361891606165, 0.014131076863005519, 0.014343507298749062, 0.011376332897212238, 0.0660541233035826, 0.03330591382578977, 0.029910638958456057, 0.04396398566783436, 0.026072875536497564, 0.033683690933450576, 0.04478069668215129, 0.021022682213374687, 0.035029014106839895, 0.00411553206034906, 0.02650803262968698, 0.08408843825060515, 0.031273103349151156, 0.032957558324860955, 0.06352341696319562, 0.02897588145588675, 0.08149912235357108, 0.06330720396832594, 0.0628119089730805, 0.06980090612365354, 0.06348813095340325, 0.03331218808588963, 0.04780090256263653, 0.06334170090755628, 0.030690786511366887, 0.04945862106978894, 0.12028499716712583, 3.126789701561774, 38.44810401239703, 59.642435119998076, 56.45119867017193, 41.50864708808161, 22.815189784572972, 39.418145379712506, 52.31547509470294, 51.900551088394664, 44.36815692532448, 6.770779211674967, 0.20102809033086225, 6.774673634959806, 22.435298427458733, 7.362484931945802, 11.904678825409183, 15.854585997519957, 11.216447007271553, 2.4344594968903452, 10.747708082199098, 54.004447690902225, 57.0394169130633, 61.70337392437843, 56.662590888238725, 57.563123933730594, 55.49750966410483, 54.27100412307247, 53.193250548455026, 55.75548395033806, 57.676958960871545, 52.170633731349824, 53.75860921798214, 58.184988267960094, 55.09356437190887, 58.079907971043745, 53.09665041585123, 51.98144997319868, 47.144536049135276, 53.60200074411208, 55.331487501821215, 50.752987169450336, 51.398636756404755, 53.3120003054219, 54.60710025602772, 54.36335240640948, 49.76633848682527, 54.13041853135633, 54.006534391833895, 53.348501882245465, 48.731064181174006, 48.09167861938477, 46.96184773598948, 44.35744101001371, 41.314187742048695, 42.50498402503229, 39.336081550967315, 40.934180675014375, 40.33246947873024, 50.40336670414094, 53.88669029358895, 56.58167631395402, 54.644892292637984, 58.11713910871937, 55.19545185950495, 57.206611864028446, 53.90483125563591, 57.086759921043154, 54.4844751973306, 58.80231049753005, 52.66077310808244, 58.136315576491825, 28.470068900815903, 27.796448892162694, 52.66670765415315, 48.44147166898174, 53.0593486755125, 50.180101471562544, 52.570142822880904, 48.340168614541334, 49.46738719940186, 46.72179475907357, 46.38515733903455, 48.45738080240066, 56.398395722912205, 54.50882134899017, 51.08853809295162, 41.517531256521906, 38.86193367742723, 40.61943792527722, 40.61060082527899, 40.05809576280656, 43.72364874809019, 43.33032523432086, 52.78471608315745, 56.31417066820207, 51.56012465876918, 47.899811960035755, 49.50837989007273, 47.71037324782341, 49.1742096408721, 47.374233968796275, 52.82113136783723, 55.481777037343676, 54.140177388345045, 53.58289095663256, 53.6370078979, 53.619416067677165, 56.81428070991271, 52.09700692084528, 51.297392537516934, 51.28058910369874, 54.85181693107852, 55.95295567666331, 55.52306390577748, 55.750981069380245, 58.13470740472117, 57.341537475585945, 57.4859199216289, 52.30310001680928, 52.05399028716549, 53.63930248445081, 56.36958983636672, 58.919718803897986, 58.74534983788767, 61.579128926800145, 50.381162166595466, 19.92743495971926, 5.9807050131982376, 9.152780194436351, 7.099607682997181, 20.65073374778994, 12.794499877960453, 0.05633162101730705, 2.1914664583821453, 34.51793616817844, 37.498855129365005, 26.266532328821, 30.57378311311045, 34.58127852409117, 42.20039629167126, 53.058434763262355, 55.56024405264086, 45.76347343383297, 4.855980075174763, 0.11850077839147662, 0.03831573814574269, 0.021551859362291235, 0.06532584181836536, 0.017797210734457742, 0.07057096238338179, 0.05425455747172237, 0.051579631249149965, 0.028387763417295875, 0.030800105342941902, 0.014131269342596493, 0.02606677364618067, 0.03531810504594638, 0.053483635532639684, 0.027656457799997543, 0.07397613127625759, 0.1763293543650258, 0.09510519628923747, 0.11299766239620025, 0.14499042874142049, 0.1666384493751872, 0.151422334414336, 0.2266279755220298, 0.09281774967788689, 0.17653425224125388, 0.1960576505910966, 0.15528272807357774, 0.16366700882152205, 0.09954882800699243, 0.1704303088087228, 0.19319148583998605, 0.25624596123253146, 3.823296249874177, 49.76310253143311, 67.52896047407582, 62.7949381643726, 48.53935833900206, 39.57377718340966, 52.61470879277876, 57.678527908940474, 56.452038057388805, 48.01727125721593, 8.075003575894142, 0.47985198036316906, 8.119525909423828, 30.253780464972223, 14.826652407646181, 25.720830617412446, 21.066926640848962, 19.526633447216405, 13.854022276016975, 14.339547964834399, 57.23409198945569, 57.095620555262414, 64.87943864637806, 58.42289178602157, 61.21196762208016, 56.5751338005066, 57.7480479978746, 54.08427184627902, 59.81882018427695, 60.101458334153705, 52.92664312547254, 54.65438050608481, 59.74485212756742, 57.79634414180633, 59.34589609023064, 53.67632965887747, 51.726672418655895, 47.149815559387214, 56.238939608297045, 59.005905043694284, 52.659937643235736, 55.202645486400975, 55.82023443714265, 56.6752052307129, 55.450884449866514, 51.05650409575432, 57.00310753237817, 57.297269605821185, 55.4293937836924, 51.497382425492816, 49.394560552412464, 47.805949641812234, 47.19094161064395, 43.9407637042384, 43.7856065073321, 40.96071943160027, 42.57608875151604, 43.411486917926425, 55.23693484644736, 56.772248591146166, 58.60931027320124, 57.62388537006994, 60.88617163319742, 57.93452532060685, 58.9833043467614, 56.92930813758605, 58.68504731885849, 55.806109982152144, 59.54522702001757, 54.867012193126065, 57.2541392234064, 30.677914196445098, 29.701040060289447, 52.89007094598586, 49.2841419096916, 54.1712974732922, 53.37076133297336, 53.51013883467644, 49.224313997453265, 50.364425413070194, 48.71708485387987, 46.79724547170824, 49.99647963431574, 59.65705771600047, 55.68792896886026, 55.16081340851323, 44.60165169931228, 40.26910751096664, 43.192340174028956, 43.814526142612586, 42.21962767262613, 47.40323597385038, 45.3038618641515, 55.836323999589496, 58.93906785595802, 54.68631252165764, 49.72590669508904, 49.39462331033523, 47.914556149513494, 48.963774481127345, 47.091697800544004, 53.04879749974897, 58.88782208965671, 57.12386554287326, 56.29537074796615, 56.98865359829318, 55.789667406389796, 61.31809911420269, 54.9732417445029, 53.63270898019114, 52.573261107167895, 56.74218362377536, 55.43406532656763, 58.35579572185394, 56.62311223245437, 60.2891476692692, 60.325931656745176, 60.488098129149414, 53.815452206519346, 55.33210723630844, 54.43820299640779, 59.61308010162846, 60.90783096128895, 61.65626233623874, 61.49689251376737, 49.757560222379624, 23.352021055836833, 20.876566171646118, 20.493283925517915, 10.654687112377538, 14.89565670490265, 11.866920128945383, 0.12286689733305287, 2.9600843114237634, 39.789523232367735, 47.639303822671216, 33.854282902133086, 36.84033624587521, 41.884955360043435, 47.75281329308787, 61.40297920473161, 63.41625336677798, 55.79728072689426, 6.582856005237949, 0.29942092996451164, 0.16837507876898014, 0.11455838268081989, 0.2764720920353167, 0.1538060169907347, 0.20926663051209143, 0.13539517748980753, 0.152067533664165, 0.15872725856400308, 0.12453286277671015, 0.11057511617940281, 0.11083908709547213, 0.24103168488269855, 0.1167720243815453, 0.16285599750136176, 0.16494197831038507], [0.0352877373206279, 0.06124275406041454, 0.020358786587753606, 0.02066501682894605, 0.06192618492810477, 0.03326970468004865, 0.051406522191339926, 0.03736461317467113, 0.06205969873154837, 0.041668625368225964, 0.015096809215573295, 0.07055760947086158, 0.03263841375648495, 0.07603014323620066, 0.04730417498297269, 0.004739482903988251, 4.3306903781429416, 44.04877793404364, 50.4848264878796, 46.61011311315721, 36.33249129018476, 54.16066785012522, 64.92208657726165, 54.488303430618785, 44.77931545626733, 27.920435013309604, 3.911356156872165, 0.3882531148772086, 1.6029395739878378, 4.977162682241009, 7.2942195111705415, 6.332455815807466, 6.532990422941024, 5.743234917040795, 1.8716246274209793, 20.699590790656305, 52.47670019826582, 59.09048703409011, 57.1672587240896, 54.44451801238522, 51.79610621544623, 49.406037407536665, 46.562624977480986, 51.795451179627456, 53.30369272539693, 54.51919209572577, 54.075905430701475, 44.18045974546864, 51.524701733742994, 53.072465081368726, 51.5366022048458, 51.31185431634226, 52.22269535064698, 51.78032259787283, 51.73877685300766, 51.61187641082272, 49.72897006619362, 43.10580092091715, 46.94504430217128, 53.591692755299235, 54.59737277800038, 46.6784486462993, 49.673782317869126, 51.95209887719924, 50.621081782925515, 47.36023895202145, 46.91444197008687, 45.01041366207985, 40.68087400928621, 36.75067086373606, 39.72155640202184, 38.832025604863325, 39.4531133097987, 44.338974491242446, 54.00159612778695, 49.964398568676366, 51.84816391237321, 51.139666188147764, 58.71983481991676, 55.49972188088202, 51.509545695397165, 51.884096745521795, 54.967350344504084, 49.939491518082164, 53.25457680609919, 42.21262624186855, 51.15107636297903, 26.144315196621804, 24.100419090640163, 52.54895417921005, 42.59903461702409, 47.74632177045269, 41.7967765561996, 46.75326785733623, 43.04325872851957, 45.25088241023403, 43.630076685259425, 47.743725161398615, 46.31988517699703, 50.23949400071175, 52.347968009210405, 52.87672704265964, 44.27851899977654, 38.859874433086766, 39.298195377472915, 38.25129124426073, 38.01827107706378, 40.38973608324605, 41.76122027058756, 45.89780676749445, 54.97939594330327, 48.24591798167075, 43.45466044641311, 52.2110027651633, 50.061743951612904, 49.703058888835294, 49.5032141285558, 55.88072130756994, 53.54898991123323, 51.293556459488414, 47.86655026097452, 48.21455863214309, 50.62154070023568, 51.46457179900139, 53.44145028821884, 51.87433004379273, 46.7818933148538, 49.79317142117409, 54.09611740419942, 54.592156025671194, 55.86475726096861, 52.95584124903525, 55.46312224480414, 56.00607633590699, 55.040600607472086, 54.88190935504053, 53.327493667602546, 53.66604128191548, 60.760189025632805, 62.2745337793904, 49.789092156194876, 49.43268599048738, 22.252855262448712, 9.072010747848019, 6.3529511805503605, 8.113379065067537, 9.071447887728292, 7.008330697013486, 0.6488385964785853, 0.8099687051388526, 25.67789439232119, 42.287194421214444, 37.009719879396506, 22.49304944469083, 24.508306364859305, 33.45240077664776, 44.841320283951305, 45.86870670318604, 37.87235498428345, 7.398398153243527, 0.062480824924404585, 0.02616081668454553, 0.029727411794386087, 0.017372713754734686, 0.023663898652058937, 0.014691638718960027, 0.014340052242210556, 0.019116303057319695, 0.09670039053044974, 0.03713425053583999, 0.01780657998977169, 0.05071104459104039, 0.03788207492400562, 0.057288342260665474, 0.08969926620803534, 0.06886295403443998, 0.04630251885241559, 0.023773581375397985, 0.08354050918452202, 0.014152747575163603, 0.06157156282795533, 0.03444075051154341, 0.023456614411946748, 0.03669891724242799, 0.02582116777287616, 0.038287561431887655, 0.037671519488456755, 0.053563580637977976, 0.048901142717729655, 0.021893827605151364, 0.1118207291790074, 0.10280440291089397, 6.727784151031125, 50.57418200277513, 58.45960909320463, 52.97527659323908, 46.39496326446534, 53.26673615363337, 63.99190041326708, 59.9084424203442, 53.17314840132191, 34.09586952578637, 3.953596406405972, 0.44864961757294597, 3.1192935618662068, 6.691321307613004, 5.402037251380182, 14.499624794529332, 13.540369945187724, 8.718055082905678, 2.730363592986138, 21.15507406573142, 53.29880152979205, 60.20956670084308, 59.23732096149076, 55.691651298153786, 54.499450806648504, 52.241157947048066, 50.04235175348098, 52.24348783493043, 57.205529289860884, 57.22404287707422, 53.043353249949796, 45.958340706363806, 53.27973096601425, 53.83460906244094, 52.00122264123733, 51.91439705510294, 54.940015346773215, 53.809298007718986, 54.08527205067297, 52.90017889391992, 50.13746923015964, 45.10346012730753, 47.64854492679719, 54.92016030896095, 55.745599577503825, 47.11815810972645, 51.407014939092825, 54.367808218925234, 53.39604100873394, 49.71263339442592, 48.60548950010731, 46.50683710652013, 42.985501827732215, 39.50348830992176, 41.6931632257277, 40.60983988546556, 41.17865808548466, 47.28608654391381, 54.82815719419911, 53.0018114274548, 54.365611691628736, 52.87711143493653, 58.959260217605106, 54.397257374178984, 51.882743527812345, 53.11421086711269, 55.22107278147052, 50.809508523633404, 53.558015284999726, 43.24568048600228, 51.557681022151826, 26.919236298530336, 26.143356177114672, 53.072374866854766, 44.08433421965569, 49.04791324369369, 42.55428037335796, 48.25707712481099, 45.03786633091588, 46.581934805839296, 45.748293861266106, 48.10198660819761, 46.77477421299104, 51.63423392080492, 53.645429226659964, 55.104907866447206, 45.722849445958296, 41.80876724181637, 41.514091337880785, 40.277850474080736, 39.226992591734856, 42.3413231295924, 43.65323435875678, 50.0350090765184, 55.75157334727626, 52.488043692804155, 47.511281582616995, 51.28653933925014, 49.722415785635675, 50.554079855642016, 49.637731813615375, 56.237868801240005, 54.811761686878825, 53.32662290142429, 49.90225253566619, 51.083325262992616, 51.86557531356812, 53.05213543676561, 53.72919144168977, 51.732516750212646, 48.548932844592684, 51.55225638420352, 55.989633760144635, 56.679276650951756, 57.31442605295489, 55.915057736058394, 57.65161652718821, 57.50279003574003, 58.01848365414528, 57.84020408507317, 54.87176218340474, 56.873331992856926, 59.27955312113608, 63.579035651299264, 52.60178066069081, 50.1572968113807, 23.393470702632783, 11.745749288989652, 9.223540732937476, 9.028087066065881, 5.6109515120906215, 5.980846708820713, 0.7776275373274281, 0.49377075606776827, 27.56600768335404, 45.05601906007336, 30.64984767667709, 27.03211818971942, 30.827813456135413, 37.56537068274714, 50.53436994552613, 53.75176468203145, 46.32373694450625, 9.430052541917371, 0.05033199577742527, 0.059273214785442244, 0.03766006647398876, 0.03566987346857786, 0.07612997215361365, 0.050330965389167114, 0.0417521940694461, 0.022754605912092715, 0.03822417914747231, 0.035664514683547525, 0.0687600301218129, 0.040959312220013915, 0.039491575857203816, 0.050997676387909925, 0.08376854291606335, 0.020890759957593777, 0.14990742618758834, 0.150227191287183, 0.12905454353219079, 0.13336637748345254, 0.35958696276910845, 0.09413544389028704, 0.18523766989669493, 0.1549864512297415, 0.2037325032776402, 0.09099361772138266, 0.10913517731692522, 0.21735405218937706, 0.15610080272439988, 0.24525313578065366, 0.21820477750753203, 0.2773291605614847, 9.110902028699076, 61.63344590894638, 66.82393796982305, 60.89176101069297, 49.60327771402175, 64.52131840490526, 74.76789859033401, 59.9301919629497, 54.10711965253277, 38.05432158131754, 5.324919531422277, 0.5847956071938238, 6.146299637133076, 12.943479341845359, 16.482589821661673, 18.072208781396192, 16.545075139691754, 13.864659743924296, 7.5331016605900185, 25.59736224912828, 52.93569987820041, 62.04314531818513, 60.31611396420387, 59.405057199539684, 55.23059237387873, 55.052046083634906, 51.12582022143949, 55.0447073290425, 59.915490919543856, 58.0597666002089, 53.700354176182906, 47.852672915304865, 54.10898277836462, 54.785787751597745, 52.34672461786578, 53.71443548510152, 55.72078666379375, 55.336833692366085, 54.873782204043486, 54.207834351447325, 54.30077883505053, 47.95772575563001, 50.79990656145158, 57.67093420028687, 55.84459235591274, 45.708254306547104, 50.366296383642386, 54.81461717236427, 55.30930649849677, 52.37313393623599, 50.681533352021255, 50.28780975649434, 46.095262804339015, 40.10045736066757, 43.08487115367767, 41.70881348271524, 43.22981449865526, 48.83301050432267, 57.15565243074971, 54.2086031360011, 57.40751566425447, 52.944462453165364, 61.05127596086072, 54.060270863194624, 52.49218179333595, 54.21516526129938, 55.9922029126075, 51.95663313711844, 53.23752626296013, 43.88880406656573, 50.34742586074337, 28.825988692622033, 28.6099680777519, 52.06341966505974, 44.320005909089126, 49.374889865998306, 42.85021143574869, 48.952634949837964, 45.62878316448581, 46.770773395415276, 48.1761037149737, 51.4645561095207, 47.41086498383553, 52.786324254928104, 56.257912112820534, 56.84407895611179, 47.849731137675626, 44.17356421870571, 42.904120491397, 42.7921760466791, 43.02763200575306, 45.937218742985884, 46.69769179436469, 52.701926615930375, 58.69776364295714, 54.56371099718156, 50.48112769280711, 52.53388051063784, 50.420017165522424, 51.719470947019516, 52.28259778791859, 58.830080878350046, 59.3322854657327, 55.506040819229625, 52.920441858230106, 53.82492865285566, 55.511143822823804, 53.94674962566745, 57.417109781695956, 53.23332540450558, 49.67473937619118, 52.33911914210166, 57.32416922046293, 57.26186629264586, 59.13429206417453, 58.35303045088246, 60.965321140904585, 59.87137602221582, 60.70388732417938, 60.020967375847604, 56.876136487530125, 58.0774211883545, 64.88191366195679, 66.61329884682932, 57.05438467764086, 50.38187211559665, 25.758191193303755, 13.711652986464964, 13.88580131915308, 13.811874447330354, 14.273265792477517, 9.191888186239428, 0.9497613039228224, 1.4097562240016077, 32.71400674696892, 55.56237389964443, 47.950406612888465, 34.92302287009455, 35.35323235296434, 45.33431514616936, 58.22865209271831, 61.71038712224653, 55.324321331516394, 12.670562786440696, 0.28046448264391194, 0.1742831948063066, 0.16127733543755549, 0.11785474410581014, 0.11281185543104527, 0.11875364103264387, 0.12039396551347549, 0.15603517963280603, 0.18218620379845943, 0.08407442650247006, 0.10812710520000228, 0.12686899427564877, 0.08185746764103252, 0.14442467280933935, 0.2491665580460141, 0.17595593246721453], [0.08778504997251496, 0.013597704425093629, 0.015466636245799883, 0.019647169430109284, 0.06732458819545085, 0.02001281553548911, 0.03629328134740072, 0.04540632238551494, 0.007448032725557325, 0.05056459922343493, 0.02755141756947964, 0.08739928639824353, 0.04529884791061763, 0.0641033761653929, 0.027068504470310388, 0.1278279908001423, 6.459012070009786, 40.385625439305464, 46.25351867368145, 37.11732618270382, 16.556979533164732, 33.30303299811579, 49.94143701368763, 40.28559715517106, 35.26166069892145, 26.314973600449104, 0.8607406613807526, 0.1421907604221375, 14.879501442755423, 8.754213452339172, 2.6486368429276252, 11.165862160344279, 15.400382395713562, 11.154589268469042, 6.997358847048975, 35.41818288064773, 56.05831053949172, 57.80345539892874, 58.18083840031778, 55.24805868825605, 54.93997612307149, 49.50584996131159, 43.57930944811913, 49.07056100906865, 52.8349930240262, 55.32418797093054, 54.83964189406365, 58.158010205914906, 46.75730789861372, 47.61098823239727, 53.343955855215754, 54.40995408642677, 53.589335410825676, 52.85270644772438, 52.31989952825731, 49.86749249119913, 46.2084977088436, 38.104355335235596, 47.7912760549976, 51.01224014835974, 54.45769325379403, 50.44730509481123, 50.521206471227835, 50.323848493637584, 52.431918498008486, 47.91850597627702, 47.787012438620295, 44.22675940298265, 39.33443415549494, 37.35329989464053, 38.66177512753395, 37.6570600078952, 42.26865729978008, 48.29706568871775, 53.44708673415646, 52.65187717253163, 53.700322797221524, 51.718580568990404, 46.67907622552688, 49.89152877561508, 54.59663537240798, 49.55331848513696, 56.25759440083658, 51.015935021062056, 54.97446552399666, 47.08730474595101, 57.06351595540201, 25.838533101543305, 22.518895902941306, 50.28802548685382, 45.083965947551114, 56.08694384174963, 51.35241162392401, 53.544020268224905, 51.15821899906282, 53.719624780839496, 50.950635402433335, 51.916895604902706, 51.42826241831626, 53.138662922766905, 52.56037612115183, 52.78681847356981, 45.26450087947231, 40.41373314396028, 38.96218553666146, 39.03315690255935, 37.21400868508124, 39.95446674285397, 43.025490391638975, 43.521536857851096, 52.60837416495047, 52.80997222469699, 52.83470669100362, 53.26639490742838, 54.022114046158336, 54.91616733612553, 53.33133366800124, 54.07290089514948, 50.38631223863172, 44.60318534604965, 42.922994936666186, 47.91925122660976, 50.3755610219894, 52.91347572880407, 53.230356170285134, 49.58503869272048, 49.76505587177892, 50.903884672349506, 49.94247251941312, 50.79783555000059, 48.985869192308, 49.336187839508064, 52.321950927857436, 56.81674395838092, 56.25237372613723, 56.70976523430117, 56.906173998309725, 59.37735742138278, 58.456067192939024, 56.79987384426979, 46.52600180718207, 39.994349402766076, 28.479792456473078, 6.755393224377786, 5.855304387307936, 8.219507615412436, 11.490830529120661, 17.957644193403183, 1.2933992354139205, 0.4074221975620716, 16.26490710243102, 37.63093702254757, 48.95347825942501, 38.180908233888694, 23.03435221795113, 23.734142280394032, 39.666847182858376, 48.64079475402833, 43.901975385604366, 13.173677363703328, 0.1462042797356844, 0.16403039496752525, 0.0225622259125474, 0.07431477278230653, 0.01147491692174827, 0.10408557005106442, 0.0037547419947992653, 0.03548874730064023, 0.025069229492557146, 0.03716410881268882, 0.05231168571739428, 0.0038178188016548035, 0.10865531516291442, 0.009313276311713121, 0.12269036769266091, 0.034795870568843625, 0.07109559471568755, 0.015306659850231824, 0.019572029611276045, 0.013943226358312515, 0.011360614688225813, 0.031212164885214264, 0.03809629992071179, 0.05333520599731034, 0.10730401267327609, 0.01588377782383994, 0.05006938466742154, 0.10678855041342397, 0.08522312937965316, 0.02414328583155669, 0.026034881405892874, 0.1280036164567836, 10.2593308302664, 50.60026576442104, 52.77038766491798, 44.04909956839777, 24.1003288761262, 42.533593793069166, 56.381780562862275, 47.372684632578206, 39.07005856114049, 28.217721254594867, 1.3376444289761207, 0.29097340099753877, 20.373333923278317, 9.480756040542357, 6.715083026116894, 18.06539366322179, 10.432449540784283, 5.457322568662706, 7.228247696353543, 36.32124585490073, 56.16472836463682, 57.879180677475475, 59.200391846318404, 56.578938499573745, 57.73337048868979, 51.87223549812071, 45.59741989258797, 51.65813684463502, 55.45957249979819, 56.97332497565978, 57.5907374197437, 55.89452412820632, 48.39645462651407, 48.21757101243543, 54.99297518883982, 56.65608759849303, 56.10994854281026, 54.34604690920923, 56.34112519602622, 53.44039517064249, 48.8988043415931, 41.354552853492, 49.084936495750185, 54.06049443829445, 55.18466534153108, 50.25647394118771, 50.6294717327241, 53.58365974118633, 54.74506178209859, 51.29493713378907, 48.66148917905746, 46.466428849004934, 41.80504099015267, 39.61847651389338, 41.40897181726272, 38.58619889905376, 43.94766315337151, 50.81527048541654, 55.83783411210584, 55.1487168189018, 52.507224082946784, 51.150448783751465, 47.73833190241168, 50.73079832138554, 54.51179842795096, 50.14376463428621, 56.89509722494311, 51.61538693212694, 56.405754089355476, 47.633314363418094, 54.78736062203684, 26.50873084222117, 24.173592867389804, 50.17177035731655, 44.67683176840506, 57.86637021649269, 53.98440830169186, 56.2648743198764, 51.595139657297445, 57.22036369385258, 53.104181366582075, 53.35438151513377, 52.58211389664681, 54.70440641526253, 55.44876244760329, 54.129500696736, 47.11022315486785, 40.75923904295891, 39.579492076750725, 40.55467567136211, 40.0878861642653, 41.469521445612756, 43.93005171129781, 45.793507022242395, 54.241562812559074, 54.24186091269217, 54.79435813042426, 54.936610729463645, 56.10971320059992, 55.104817651933246, 53.40925547384447, 56.15629526876635, 53.87023202834591, 47.12377886618338, 46.52813557655581, 51.032444277117335, 51.516782468365086, 54.528150789199344, 54.53255953327302, 50.499276499594416, 52.14727993934385, 51.72220091665945, 51.66203175821612, 52.02788691366873, 50.61080125070388, 49.919114805036976, 51.40824264095676, 57.34289853803573, 58.75126477210753, 59.23014694644559, 59.70217674009262, 62.391592994813, 62.403964150336485, 57.02578275434433, 47.71302084768973, 39.73937965208484, 30.155301517055882, 9.730138374913125, 8.986622710381786, 2.617926645663477, 5.527900226654546, 20.686374364360688, 1.4046657229623487, 0.29032106180825545, 18.184329732771843, 43.67800804876512, 46.356853515871116, 40.942362739193825, 30.905517570434082, 29.88528947676382, 46.459011647009085, 55.37955614828295, 53.248752086393296, 16.965700311045495, 0.2727205594701152, 0.0981196373580925, 0.04508501361875285, 0.07052128924237144, 0.04856636995569833, 0.033223348699750445, 0.02915511155621179, 0.05788397945223316, 0.027683389620975624, 0.01309589385205219, 0.02514803887254769, 0.06882147803421944, 0.03428780871834006, 0.09531294401254385, 0.03901800711549098, 0.088990006685978, 0.16564216735141893, 0.13446618862930806, 0.15191734978748908, 0.11141535375387439, 0.24702672125591388, 0.128675835627702, 0.18917378368637255, 0.12273221907596435, 0.29916337120436853, 0.09552232350312895, 0.1688937356154765, 0.2822284154113262, 0.2069317477364694, 0.13786198060599067, 0.1328971792733477, 0.19650838608222623, 15.777622230591314, 59.768358892010106, 62.98809528350831, 51.43545604521229, 26.70371578585717, 41.83370174900178, 60.30808879483131, 47.99179154057657, 47.01026939576673, 35.53303380166331, 1.4630218883675914, 0.310527611403696, 21.85404239162322, 13.322850004319223, 6.392576925216183, 20.23998902690026, 22.36957715403649, 21.264584679757398, 11.759065735724665, 39.54996055172336, 58.55155729478406, 59.82127558800482, 60.507957089331846, 58.594232682258856, 61.6522301397016, 53.64518996207945, 47.63178856142106, 54.812530471432595, 58.60375619703724, 60.251410545841345, 58.028489620454856, 58.26536939990137, 48.97733411481304, 48.36014524582894, 55.31571565135833, 60.17860743307299, 58.69250766692623, 56.62845842299923, 59.56008103586013, 54.510947273623565, 50.44499874114991, 43.333988728061804, 51.51722177382439, 56.326047605083836, 57.89607432580764, 50.630169914614775, 51.06106581226472, 53.71890698709796, 56.65027856826783, 53.595097372608805, 51.82831671930129, 48.83328507023473, 43.63465409125052, 41.45316123962402, 42.73940055601059, 40.7184777721282, 48.43127742890389, 53.909389049776145, 58.52976460610667, 57.613400874599336, 51.785202026367195, 52.075637848146506, 48.41722749894666, 51.7549095615264, 53.907090540855165, 52.665950636709894, 58.67019330301593, 54.52847634592364, 58.50027230478103, 49.2760226034349, 56.40929991199125, 29.091437055218606, 26.627661028215964, 49.72087037178778, 46.00055325415827, 58.94843447592951, 54.8543978506519, 57.65835123677408, 54.42144663103166, 59.126721889741965, 54.223770941457445, 56.130666502060436, 54.49615601570376, 55.13369806351201, 56.28570995023174, 55.93082958652128, 49.40848496652419, 43.791242953269716, 42.13790509008592, 42.56849112049226, 41.24040011436709, 43.86358322635774, 46.449260634760705, 48.73009927811162, 56.31726149589785, 57.53387481935563, 54.87659454345704, 57.46292306530861, 57.37463051272977, 59.5177351274798, 55.89591656961749, 59.673068831043864, 55.86966806842435, 49.522155254117905, 48.394112971521196, 54.611250123670025, 54.69279619955248, 56.162778946661184, 57.87012000237742, 54.58325224538004, 53.823532289074315, 52.704154522188254, 52.835636292734456, 54.34625871719853, 49.90251925683791, 50.193006069429465, 51.50902794253442, 58.395862733164144, 59.26666813512003, 60.49583304312922, 61.47739833401096, 64.11965200977941, 62.18588821349606, 57.796759913044596, 50.17306866184358, 46.39295501093711, 32.908964234013716, 9.930225341550766, 12.984516159180673, 16.219375248878233, 19.556751366584532, 23.645339819692797, 1.7615694168113896, 0.44572754372512147, 21.01436491935484, 50.61446866681499, 61.63344590894638, 44.79196902244322, 33.962571697850386, 33.65717595623386, 56.35174697445285, 63.14309166323755, 63.016446175113806, 22.42417850802022, 0.5370940700654061, 0.20035751824898107, 0.08215179862154108, 0.2016664254328897, 0.1268682511703622, 0.15446652267729083, 0.2127512733662321, 0.1512647501283115, 0.09889552354692452, 0.08806074969470502, 0.14749084779572103, 0.14708525020508997, 0.20854941899738005, 0.21906124848511913, 0.2797115714319291, 0.17242644282598651], [0.026727060997678388, 0.04499881723595243, 0.027740449764795845, 0.02146077916897353, 0.03425857863358913, 0.03166072468663896, 0.039093309728008126, 0.039442002307623625, 0.0186908676198894, 0.03388548998402492, 0.0708981432140835, 0.02984905506544296, 0.06573896239241285, 0.017027606466604818, 0.07994940309154411, 0.47072591199990244, 11.74654160776446, 33.52482734187957, 46.57348209811796, 27.84502744674683, 27.86753792916575, 34.767430290099114, 48.14761554041217, 30.21156007243741, 38.42913543024371, 20.813247349954423, 0.29404636352292957, 0.21293570137312337, 15.738618181597804, 10.570991577640658, 1.7870759771716211, 19.262608904992383, 11.260865888287945, 4.9156050047566815, 24.1617767272457, 60.11163296238069, 57.12705442982336, 61.06530235659692, 56.69901794002902, 54.410840542085715, 54.383117229707786, 52.903760017887244, 41.83301533422163, 43.567785524552875, 49.94843452207504, 53.3374604102104, 53.08402038389637, 55.0951333199778, 53.752141229568, 52.44012801877914, 53.90321523912492, 52.02266623896938, 49.84807675884616, 47.96188346801266, 46.62097023379418, 43.31142725483064, 39.72412163211454, 37.34709078265775, 40.60638035497358, 51.663879194567286, 53.747332403736735, 51.837455841802786, 49.83898078241656, 51.94520335043631, 51.39414956492763, 49.56691342015421, 45.79053386565178, 41.57715912788145, 38.69932397719353, 37.32785940170288, 37.81330370133923, 40.9381305017779, 44.71449828916981, 54.86486665664181, 52.288830434122396, 48.16631740139377, 51.27429369957217, 50.10661978875437, 50.447199190816576, 45.2980096878544, 53.80918818135416, 52.410918128105905, 55.46409891497705, 53.514606414302705, 57.759340501600704, 49.35303049702799, 55.912770994247936, 30.80768777478126, 23.495542541626964, 56.978361298961026, 48.33359472213253, 56.88106690683673, 50.58296811196112, 53.74785015659948, 50.240823684200166, 55.29627246241416, 52.81225896650746, 56.391778684431515, 51.69453643983411, 55.11561201464746, 51.00209689909413, 53.13323828481859, 43.99446095189741, 40.48816011797997, 39.67002430269795, 39.774316203209665, 38.80837763509443, 38.37363781467561, 38.8134257255062, 44.82870594147713, 48.70201118530766, 53.69565909908664, 51.929470723675145, 53.125522982689645, 52.006470772527884, 52.389329402677475, 54.536066132207075, 52.76675555013841, 46.08935571485951, 41.5041285176431, 42.66624442992672, 49.54247313161051, 50.983610768472, 51.98818076041437, 49.30864887852823, 48.7907273538651, 48.28230580975933, 49.97808371820758, 51.37710294415874, 50.389367764995946, 51.31372920928463, 51.528157341864805, 53.3348677235265, 52.78897577716459, 50.88968569232572, 52.81915841564056, 54.9679151658089, 53.38542707504765, 51.23600352195002, 44.81305176211942, 33.78795954488939, 23.128732289037398, 16.11655031481097, 15.352997222254354, 8.96030164534046, 4.625888937903989, 6.217074394226075, 13.398031054004548, 0.9110048545464393, 0.08558289192977452, 7.90810525417328, 39.70789478671166, 49.90025604924848, 57.67544492598503, 24.438231260545795, 20.920969363181822, 30.297801225416123, 46.44337315713206, 45.07638008363786, 22.11019669809649, 0.33575016764863846, 0.05225376563987905, 0.005066185887347186, 0.08435112979984091, 0.08436412265103671, 0.0636435395497228, 0.03448860802417321, 0.04978000644534346, 0.05173298672983243, 0.026407632976770404, 0.026004117230073582, 0.013740419902117744, 0.05747051413861975, 0.029096457949509064, 0.01917386307351051, 0.08292498052000039, 0.021921307178995302, 0.04014952281009286, 0.10384593774834949, 0.03476515044307998, 0.03323387474783006, 0.05099878721540013, 0.10458089952026645, 0.05789286990259444, 0.09913454297930004, 0.07421357256750907, 0.03265018852788114, 0.04255572071058616, 0.017990747526768717, 0.052673999340303486, 0.09358243566126594, 0.4377902599592363, 17.142738449958063, 43.85182788295131, 54.551755612896336, 35.9016110820155, 29.884797219307195, 38.518608616244414, 52.325696791371996, 34.01106396029073, 39.02911293891169, 23.72686040016913, 0.15069867243930218, 0.3105006144652444, 20.32103107821557, 15.209061926411046, 6.760270691687062, 12.761565696808601, 9.082808052339862, 4.888529864049727, 24.033950605700095, 63.617576860612445, 58.90242115143807, 61.643824500422326, 58.0680271117918, 57.199159360701046, 55.621499707621915, 54.57373265297183, 43.94026556322652, 46.15497696784235, 51.1984742841413, 53.68657881213773, 54.19240374718943, 55.917803395179014, 54.715436120187086, 52.37419689855268, 56.53851455257785, 54.13959295518937, 51.9262190788023, 51.15339448375087, 48.989556220269975, 45.90711062954318, 41.62399615010908, 40.59538202901041, 43.811874620376095, 54.18129559486143, 54.97006462466333, 53.412966036027484, 51.5976264399867, 55.23671911608789, 53.362653793827185, 51.44499132710119, 48.653224745104396, 42.97081647380706, 40.2674561931241, 39.2362533077117, 39.754347416662405, 42.35391786021572, 45.79433464234876, 57.034663000414454, 52.735443269052816, 50.24751917008431, 49.73741492917461, 51.26992417920021, 51.12999754567301, 47.34421999223771, 53.81615823315036, 54.07594857677337, 56.62414773817986, 54.071802631501235, 58.70630656519244, 52.13191993774907, 56.61797000515846, 31.674009907630186, 24.600464413242957, 58.14233641470633, 51.080297193219586, 58.023378772120324, 51.622290303630216, 57.001699401486306, 53.18187175258514, 57.90730407161098, 54.299931603093306, 57.453827088879, 53.111292623704486, 55.92938223192769, 51.33601219423356, 55.58273492320892, 45.36539208504462, 42.92494435464182, 40.24175682375508, 40.76279271033503, 41.392556698091575, 40.80791173442718, 41.58664734132829, 45.60155799311977, 50.678917131116314, 55.05255991412748, 50.907971782069055, 55.00398920428369, 52.33103513717652, 53.51207648554156, 56.325212140237134, 54.16214658368019, 48.876595881677446, 43.845010803591826, 44.69200349623158, 51.71666645234632, 53.63146558884652, 52.78325696145335, 52.19927487834808, 51.32695936387586, 50.286750716547814, 52.54141538373886, 50.26940991801601, 50.3463589760565, 51.752720878970244, 52.44279915286649, 51.89180812528057, 52.06254889888149, 51.27221092101067, 54.70217850900466, 55.979125730453006, 56.664230438970755, 55.43623047490274, 48.532996254582564, 36.56254614553144, 24.673585237995272, 16.87428947417967, 15.664117663137375, 11.3429356005884, 6.702964863469524, 8.014615255017436, 19.763426934519124, 1.5509931743144991, 0.03781698426351913, 8.365671307809892, 46.0734034353687, 50.642956841376524, 53.996340151756044, 30.104300898890344, 25.12905674595987, 36.78829423842892, 53.302041407554384, 52.542293994657456, 28.31641201050051, 0.38753164391363826, 0.027186956985162634, 0.024402845996401967, 0.027221921238026796, 0.025056384113286773, 0.017942116265335394, 0.060123648990186, 0.027802828474030383, 0.037027113139629364, 0.06211793290511255, 0.03576696745210117, 0.06536602312999387, 0.024689581215141282, 0.016799429093577692, 0.029148544267480894, 0.055828270607537804, 0.2479525538341653, 0.10412242654110156, 0.18716264966755145, 0.14659818682459094, 0.07724604734610166, 0.2279306620719933, 0.19022540790179085, 0.13678015720459724, 0.17314158590330234, 0.12937122895832986, 0.15731276914237008, 0.10260685947873902, 0.13976167947534593, 0.16722496629001635, 0.16509557893920332, 0.5058081117608856, 25.86234384967435, 54.360783253946614, 63.850608794919914, 41.024869795768495, 40.411081621723795, 45.28316743912236, 56.992909369930146, 39.60535618566698, 50.51848826869842, 26.66765939804816, 0.3402420475838646, 0.7193956007399868, 22.598135625162435, 15.17862335328133, 9.70459884212863, 29.423667692369033, 22.297101559177523, 12.388387476244281, 28.294558525085453, 65.63183553757207, 60.481375186674065, 62.42599218122421, 60.780463757053504, 58.70525536998626, 57.68492921706169, 57.37347341352894, 45.88780864592522, 48.15364814573719, 53.408314105003114, 57.21281313127088, 57.65132627179546, 56.94622924250942, 53.981042908084014, 52.113488720309356, 56.52488823859923, 56.58495933778825, 54.60198548532302, 52.53523765071746, 51.83963667961859, 48.68361919156967, 43.71692580561484, 42.3361102996334, 45.088708093089444, 57.52196650351248, 57.194974191727184, 54.45105660346247, 52.77980135333154, 56.72902407184724, 54.335393751821215, 54.84765529632569, 48.95857341827885, 45.62083252014653, 41.52306572083504, 40.402401416532456, 40.34418167606477, 44.99590481481245, 48.39998475966915, 60.61304915335871, 56.09213705985777, 51.623608220008116, 51.76801027790193, 54.917124394447576, 52.559371994387725, 49.78484422929826, 54.63394887985722, 55.557223827608176, 57.85275566962458, 58.06070012430991, 60.050432220582046, 54.71722472098566, 57.909414306763686, 35.14892785779892, 27.1967714448129, 58.52608150051486, 53.42720423975299, 60.539618461362785, 55.02934732744771, 57.641159488308816, 55.507758817365094, 60.78257791457638, 56.643657607416955, 60.804621634944795, 54.956881538514175, 58.97305911587131, 53.849133599189024, 56.165524605781805, 47.72216781493157, 45.850110746199086, 43.710289155283284, 42.48045352197463, 43.66828057073778, 42.622839481599875, 42.84113899354012, 48.228149644790165, 52.852663301652484, 57.449524248799975, 56.89898429378387, 57.043609926777506, 54.814809368502715, 55.81433911477366, 60.68826452378304, 56.29498635568927, 49.955890947772616, 46.23493840617519, 47.34547122832268, 54.62596293418638, 56.521393406775694, 54.42566710133707, 54.50987254419635, 52.93236194118377, 51.94585446388491, 56.2876005326548, 51.52108923081429, 51.37876995148198, 52.086981342684844, 53.76205305899344, 54.81328356650568, 53.842085099989376, 51.46688991977323, 54.70088020447762, 56.81625758447955, 56.75690820140224, 56.335641722525324, 49.41396059528474, 36.26492846396662, 25.678816149311682, 18.386580867152063, 19.801707306215842, 16.497008454415106, 9.126589548203254, 12.148655153089955, 22.22767560712753, 2.0742537802265537, 0.2938963022203215, 10.194513663168877, 51.20005499932074, 60.992044248888575, 62.73531421538323, 34.57251987149639, 30.831292598478257, 44.30277493692214, 60.338432250484345, 62.09270838768252, 35.66257792134439, 0.6905320430955579, 0.15770289175693067, 0.13617620412861148, 0.21317095165291142, 0.20481300900780386, 0.14095240993605507, 0.17276836318835137, 0.11460812476974343, 0.09943033718774397, 0.11518986129592504, 0.13196048356832998, 0.19204800768244654, 0.16292198831515928, 0.15178781964125174, 0.17122970623595102, 0.1375924861959873], [0.039801554183565804, 0.03890032451900263, 0.052986796870226824, 0.035036138724535704, 0.030909452902814074, 0.03450450051816241, 0.025221970187680378, 0.07129796450176547, 0.04749903710739267, 0.029756555694245526, 0.056809031689960154, 0.04872295832742126, 0.02807110480423416, 0.0496006461100713, 0.04252731417035384, 0.46264797449111944, 17.11942388165382, 39.82551490106891, 44.720001374521566, 29.39455193857993, 22.815144677315992, 21.137225320262296, 37.09387825381371, 26.45139559622734, 39.73511603570754, 12.433574161221905, 0.09385697859069032, 0.10173123630304491, 3.0164735307616577, 6.00521884618267, 8.869785108873922, 18.17576719868568, 10.577811598777771, 11.84865463164545, 43.84443813754667, 60.28601761787169, 54.00201974376556, 56.41832136338758, 52.86989427381947, 59.05477385367117, 55.40169008316533, 47.47789436771024, 39.79133144501717, 45.59820436662244, 45.07988668257191, 50.12923617516795, 51.63820728178948, 55.543856390060924, 54.793059825897224, 53.560207889926055, 51.626212673802534, 52.77574170020319, 47.596232275809015, 46.95576806222239, 41.59399001829086, 38.79229591738793, 39.12561893463135, 38.43980035474224, 37.437066032040505, 42.215540562906575, 52.53417861077094, 52.64344407666115, 53.64528017659342, 53.41851618982131, 52.53442179772162, 45.526209262109575, 39.74919342225598, 38.47206969414988, 39.373791217803955, 38.0603620313829, 39.720830763539965, 39.65253837646977, 46.90030182561567, 53.875264429276996, 50.1684755663718, 50.294234598836596, 53.282500159355905, 50.650817271201845, 50.85330178660732, 48.46328396950999, 49.467081254528416, 52.85889594785629, 53.42939292230914, 50.492141708250976, 56.433748045275294, 49.641752243042, 59.82161683420981, 34.27563959552396, 25.569066270705193, 55.58636311561831, 49.22072895111577, 55.37909330860261, 49.5459169726218, 51.695854356212, 47.806283043276885, 50.85451379899056, 50.1309580956736, 50.43167837204472, 50.299314068209746, 52.87502473400485, 50.86686926503336, 47.98058140662409, 38.31786563319545, 39.09940965713994, 38.664783585456114, 40.610024236863666, 39.45616883616294, 39.720866064871515, 38.74938911007297, 39.26036019479075, 41.54255597822128, 45.10536639921127, 47.445405375572946, 48.506947794268214, 48.63032594803841, 50.63903839357438, 51.31109337652884, 46.51254415512086, 41.59075798526887, 41.593962561699655, 43.9626544521701, 50.410226929572325, 52.153422371033706, 50.81779256943734, 50.90471621482603, 52.502285818899836, 52.70521356213478, 48.25958744172127, 48.997346047432195, 50.3890343635313, 54.572489261627204, 52.332435423328036, 52.56392586615778, 56.19279684558992, 54.02971952192245, 51.40474388676306, 48.816677754925145, 52.61300648412397, 54.948150342510594, 52.407262479105306, 47.28824776987876, 35.835315181363015, 33.3757576634807, 17.374134755903675, 11.159220607050004, 0.49844950016948486, 10.239679755703097, 11.91652242214449, 0.3693935623572719, 0.14576433076252862, 1.2449580863598855, 29.341011585727816, 56.698068726447325, 80.67381135879025, 45.816056728363044, 26.371392973007698, 36.1105518187246, 45.45378269687776, 47.74641198496665, 28.798214389431863, 0.8793362506454991, 0.006545901950073219, 0.09504142713042037, 0.021088722822887283, 0.05124870041805891, 0.057163355015819116, 0.05547723379887401, 0.048224844128614476, 0.0041067723237398655, 0.035864762406075196, 0.008825918944973138, 0.05266508973774411, 0.037897894639642014, 0.0671209083990224, 0.0259500888792137, 0.012730343507662898, 0.022837349153574438, 0.02295076655554435, 0.04802037143118439, 0.01751715963285777, 0.0689307145113426, 0.05466275593085636, 0.02181523847543905, 0.046187689933445186, 0.009195065114557022, 0.008462420758611013, 0.05003088491878683, 0.057963384465584834, 0.09260100808234946, 0.05470223244159453, 0.060011792492361805, 0.6732693855320254, 25.255174675295432, 49.449203091283, 51.313682140842566, 34.57171970798124, 25.674385832202052, 29.007851346846554, 43.73002652199038, 28.6827084325975, 42.60894644644953, 14.361386741361311, 0.06993062013099272, 0.17329397611320022, 4.482658688099154, 10.55332031942183, 8.433218444547347, 12.328595845930039, 6.690629009277591, 10.057984782803445, 45.77363237257927, 61.649531549023045, 56.61704824816797, 59.08463878016318, 56.792488021235314, 60.21319881562264, 58.013231600484545, 50.221961006041504, 42.61258640596944, 47.087740129040135, 48.213919285805, 52.81316111164709, 53.62453868312221, 55.5249309539795, 54.42310187124438, 53.26213129105107, 53.5694529164222, 54.33310701001076, 49.71689308843305, 47.76263098562918, 41.96291638958839, 41.72706034875686, 39.73863047938193, 41.14719675433251, 40.18061491750902, 46.91493226635841, 55.0221223215903, 53.7681641117219, 54.728983986762266, 55.44834667636503, 55.06307186618928, 47.6985865254556, 42.41695819362518, 40.7592978785115, 41.28244400024414, 40.23522999978835, 42.17037447037236, 41.09538616672639, 48.832167194735625, 56.189537355976725, 53.88594896562638, 52.20461714652277, 55.01248113570675, 53.36166535654376, 51.484320932819, 49.4690110606532, 52.39354595061272, 53.16835134260116, 56.265949049303615, 52.19952591003911, 57.81275141623713, 52.4532679588564, 60.506050817428104, 35.58092986383746, 27.12347019103266, 56.56869326868365, 50.339820384979255, 57.47204649832941, 51.32260161061441, 53.20277406323341, 49.55792727008943, 53.124789499467425, 53.719256078043294, 53.49582218354749, 51.241161438726614, 54.42588675406672, 53.90334075497043, 50.806331403793834, 40.138649479035415, 42.029361340307425, 40.731523575321326, 42.25486232388405, 42.07284081366755, 42.26955160017937, 40.81823541272072, 42.49354639360982, 44.76108820207658, 48.07947220340852, 50.91532230377198, 51.74316598523048, 50.843825340271, 53.65335241440804, 52.95884970695742, 50.198748419361735, 43.063984532510084, 43.23113241503316, 46.97902771734422, 52.46378775565855, 54.29973156221452, 52.78100159860427, 52.010012672793486, 54.05169263962777, 54.70282177771292, 51.04690213357249, 48.57746808759628, 50.82122072096794, 55.2706083943767, 54.18632407342234, 55.85275480824133, 56.75423706731489, 54.91851291348858, 52.407760620117195, 51.3352277201991, 53.52026247209119, 56.3544612546121, 54.6272220150117, 49.12704706192017, 41.2755641629619, 35.03224911228303, 16.952932996134606, 8.57049257524552, 5.190743582863962, 13.22929657274677, 15.327627331979814, 0.40793032836048837, 0.06479548680926524, 1.6505783531934985, 34.58702087402344, 59.10792589187623, 67.01469852078345, 42.9893300610204, 32.70972155755566, 41.962881088256836, 50.93955862906672, 54.93922302799841, 36.99056302347491, 1.3943367739838939, 0.018136953491897836, 0.06093529616332343, 0.03214642060019317, 0.020143914246751417, 0.049867731173552816, 0.00728392998890711, 0.05334943991094347, 0.021156665245671908, 0.06550293070294204, 0.015621588062194568, 0.01613706564380517, 0.12772021755095453, 0.06546156195503089, 0.021574075912095366, 0.028148251773429014, 0.14751879468319878, 0.11829428705236605, 0.1403454078301307, 0.13206110155630496, 0.14011829340409848, 0.1363638037395093, 0.11148424038002569, 0.1597262372172648, 0.21715439435455108, 0.08743395953769646, 0.18115442126028, 0.13659742991289786, 0.17517387927059205, 0.10350150461759298, 0.18427177092000363, 1.088975965976715, 34.19625866797663, 57.98525333404542, 61.025827623182735, 41.637124323075824, 34.1100057478874, 29.808864055141328, 46.55846334272816, 36.76461488969865, 53.42559606798234, 15.969488889940324, 0.2762722963046643, 0.42001377190313033, 7.266672215154094, 10.550110840028333, 18.077462796242006, 25.500762116524484, 19.706327030735633, 19.111423107885546, 45.95002528159849, 64.47847827788323, 57.203568104774725, 63.82171269386046, 58.23962296209028, 63.19702425310689, 60.48360701530211, 52.99488844410066, 44.5381171472611, 52.15639552762432, 49.662603562878026, 55.04139292624689, 55.4653383839515, 58.29845459230485, 55.91140993179814, 53.79159242876115, 54.0285231990199, 58.26473789830362, 52.653199011279696, 51.04472129575668, 45.33400920129592, 42.90052760031916, 43.01339380202755, 44.434040977108864, 42.0634114357733, 48.90460944944813, 57.601492558756185, 56.72961634974326, 57.0872502173147, 57.81717977216167, 57.33020182578795, 49.60041830616613, 43.24146393806704, 43.12009011545489, 43.47403695506435, 41.9735695469764, 44.21858126117338, 43.64907272400395, 51.37543593683551, 57.38938254694785, 54.784999355193115, 54.314212952890706, 56.38464389308807, 54.6210874280622, 53.81121604673324, 51.133033460186375, 51.86351214685748, 55.27339719956922, 58.024049497419796, 54.90093285037626, 60.16431431616507, 52.455507632224794, 62.40932210799187, 38.07353727279171, 29.661773212494392, 57.57926840935984, 54.080843694748424, 60.46348525631813, 53.203946851914935, 55.364309895423155, 51.53903799672281, 56.550646443520826, 55.94276928132581, 55.25503266242243, 53.54283179006269, 57.11377328441989, 55.760751693479484, 52.84202583374516, 41.97880983352661, 43.84565014992991, 43.27167011076405, 44.25166253120669, 45.735561847686775, 44.720071977184666, 42.81551414920438, 43.54471414319931, 47.100931059929636, 50.2215923032453, 53.56139636808827, 54.158200679286836, 53.39103214202389, 54.762700680763494, 55.55507829112392, 52.976872997899214, 46.26607025823286, 45.98593065815587, 48.23520991110033, 54.94622838112616, 57.65167928511097, 54.74703473429526, 54.938234590714984, 57.368727345620435, 56.21063970750379, 53.00617702545659, 49.83096345778435, 51.566376916823856, 56.58316289224933, 56.82856598208028, 57.217331701709384, 59.447913016042406, 56.118122762249364, 53.64209913438367, 54.41271151265791, 55.08271901838241, 58.21970908872543, 55.89523407720751, 53.817986057650664, 42.58414922222015, 38.455729100012014, 18.905335895476803, 15.370695937064388, 5.923685027707008, 13.313351004354416, 15.984600801621715, 0.3218436187073108, 0.2120957319294253, 1.78640439385368, 40.00946229504001, 66.26249774809807, 85.84591927066927, 55.176487199721805, 35.949091372951386, 49.58133205290764, 60.06905955653037, 63.92639290901923, 44.69255655042587, 2.7096010167752547, 0.0847544597702161, 0.213188449101102, 0.09617192775852258, 0.11895205014415326, 0.19501552586593937, 0.2845852083015827, 0.17888801142333016, 0.06162753704214289, 0.10824689070784277, 0.24283214472234252, 0.1332385480524071, 0.25421035836540884, 0.1820626491380315, 0.08356025893120997, 0.21141829569974255], [0.05645375075419584, 0.038959244341259046, 0.03936598340289728, 0.02841397320040532, 0.04976826614790386, 0.08842380642290078, 0.029047378526640036, 0.029961225659316106, 0.04982918162920302, 0.03409185491862797, 0.041857921863876046, 0.025165469288044882, 0.044766516394672856, 0.024968261019356792, 0.03181541507552949, 1.4271440909754847, 19.99936534512428, 40.583038330078125, 43.46275229607859, 37.43604229342553, 28.118483328050186, 30.114644189034742, 39.06594399482974, 27.036419068613363, 39.81624241798155, 7.390872105475395, 0.08985053026868452, 0.1765344361023557, 3.074947980142409, 5.5336950382878705, 5.521639143266986, 4.384485194759985, 6.422578154071686, 18.242420035023844, 57.650212318666526, 56.93692145809051, 53.951770259488015, 48.83636020844983, 50.062238170254616, 45.484632138283025, 45.68672049430109, 40.901640692064845, 44.91611596076719, 47.56415121016964, 50.35384678071546, 49.92186830889795, 51.98885148571384, 54.72499885866719, 54.90659283053491, 48.556781507307484, 50.72017654295891, 53.12456200199743, 53.01191153064851, 49.35111638038389, 46.098279107001524, 41.60868713932653, 38.789491422714725, 36.46954282637566, 39.412850179979884, 35.805771889225134, 43.43119682804231, 45.619542060359834, 48.72813809302546, 44.56914309532412, 42.62991543739073, 37.730659361808534, 38.61501263033959, 37.44950386785692, 39.29295116855253, 37.09574137964557, 41.77819628869334, 38.1545812852921, 46.19033713494578, 53.742037204004106, 52.17014735744846, 52.875107103778475, 51.35403940754553, 50.97140827486592, 52.87797827874461, 50.51779400917792, 49.93059950490152, 55.08267979468069, 54.30819603704638, 49.11145956285539, 55.48793515851421, 49.66241528910976, 55.306027397032715, 34.91752762948313, 26.47753623224074, 55.15945234606343, 49.83769816737021, 55.006444608011556, 48.80450271791028, 47.2918838070285, 43.444630945882494, 46.80181503295899, 44.70994441739975, 47.01380345129198, 45.275259940854966, 48.10341435094034, 45.10621755353866, 40.92568482122114, 39.17699413914835, 39.99687933152722, 38.95232077567808, 39.234637291200706, 39.15094175646382, 40.3949999040173, 40.19401765638783, 40.36691965595369, 38.51726324327531, 42.392306097092174, 38.59263550850653, 39.404487686772505, 41.28628792301301, 40.78729967917166, 39.01145442839592, 38.571380184542754, 39.25653980624291, 41.38203297891925, 45.333397311549035, 49.87687087828114, 47.31610444284255, 49.92356669518256, 50.577790583333666, 50.981920226927734, 53.41573522936914, 51.17775632489113, 47.846181392669685, 52.60578540063674, 55.151799801857244, 53.94077585589502, 53.45023247503465, 52.94636088032877, 56.49201485418505, 56.74014399128576, 52.51897942635321, 60.848830669156975, 57.309821190372595, 60.01284806959091, 56.675726905945815, 65.22415222660189, 45.762712494019546, 28.420764707749893, 10.551926897418115, 6.897134444405956, 3.893713826133359, 2.229835818852148, 0.2835756269914489, 0.10438758489345351, 1.2712493659027162, 19.05468406215791, 53.75438090293638, 53.04100375021658, 30.60342642568773, 18.22459286259067, 31.683933504166145, 46.7139696305798, 51.892831863895545, 33.79247419295773, 2.838482746193486, 0.09782307706172429, 0.05474876462211532, 0.03812610840184554, 0.02772132246454637, 0.01964224539997597, 0.04592493326673585, 0.049082774503697316, 0.028321860703609647, 0.07042001241878157, 0.019215647424120578, 0.02320442592815286, 0.03253379678954521, 0.06533090565954486, 0.05169159882972318, 0.09066476681900602, 0.023347885468073433, 0.08999023406255631, 0.02361468324858335, 0.023614587487592816, 0.031032850515217553, 0.06661211110411153, 0.015935790405849058, 0.03297221741729206, 0.04421993181289685, 0.06334397235825177, 0.06532912833556052, 0.014555038538791481, 0.012255272276008563, 0.07034629177782806, 0.04109289880181032, 2.040064563193629, 27.283393067698327, 49.28094125563099, 51.6487310009618, 42.77434887424592, 28.464212802148637, 28.236870265776112, 38.147819119115034, 27.990465010366133, 45.01091180309173, 8.374006344426064, 0.18747122988345163, 0.4307018629004879, 5.053295887285664, 7.4000161309396075, 6.029429185775019, 9.430155504134394, 4.718110724802941, 17.969189690005397, 61.42728613268945, 58.495051630081676, 56.33605357139342, 51.26285214577952, 51.86735214725618, 48.92364078952421, 48.44188744022001, 43.23605498959942, 46.400176094424346, 49.28964499504336, 52.69492126280262, 53.07529311026297, 53.71675360587336, 55.6964248226535, 55.528810178079915, 48.59950004085418, 52.00952237652194, 53.43265633429251, 54.983031980453006, 51.224934593323745, 47.54632011536629, 42.96950247979934, 40.3962746743233, 38.191141697668264, 40.854344752527055, 38.017314018741736, 45.57768644825105, 48.777881591550766, 51.036601989499985, 47.82001918362033, 44.67726322912401, 40.85845931883782, 40.53542860092656, 39.90801411290323, 41.32198933632144, 38.197221371435354, 42.72624884882281, 40.00081346881005, 47.862066991867565, 56.034827309270064, 53.426906139619895, 55.12721830798734, 53.800245177361276, 53.33413424030427, 54.61027737586729, 50.66204309463502, 52.01855951739896, 56.30164261787169, 55.15472589000579, 49.672636985778816, 58.24824040935886, 53.228371450977946, 57.794728125295336, 37.92890379505773, 28.338598897380216, 56.785082586349986, 52.19552117009317, 57.67465260721023, 49.137743365380075, 49.85748652488955, 46.461329767780924, 49.927747941786244, 48.137138889681914, 48.534973129149414, 47.23754329066123, 49.49299243188674, 47.225713422221524, 42.94233614398588, 40.63204050064087, 41.387579210342906, 40.9787231106912, 41.99405608638641, 40.45327063529722, 42.547000454318145, 42.605012309166696, 41.290763347379624, 39.999981926333525, 41.99380113232521, 41.35074423205468, 42.01236571035078, 43.345842130722545, 44.4610268838944, 42.44441478483139, 39.29537127094884, 41.0065484046936, 43.339052507954264, 48.0064376708, 50.624678596373535, 50.13224463309012, 52.76089552910098, 53.60173794531054, 53.66904189509731, 54.513743923556426, 54.438971780961566, 48.92977537647371, 53.33167099183606, 56.90996300789618, 55.03860804342455, 56.190212003646366, 54.69827182831303, 58.30621304050569, 57.19020066722747, 53.9551591873169, 61.45488785159204, 59.12180715991605, 60.486882194395996, 60.924905038649044, 65.61015659762968, 49.039562517596835, 26.540949190816573, 11.770648494843515, 12.292475719605724, 7.558109221919891, 4.488928106523329, 1.07280207257117, 0.1698233373463154, 0.7149140476699799, 23.17973682957311, 58.55801743845786, 59.445084987148164, 38.100432965063284, 24.179886310331284, 36.4562616809722, 53.11033948775261, 57.1471958006582, 41.654829902033654, 3.8526676931688866, 0.05304192455725805, 0.06174247321342269, 0.02631871698183879, 0.04983144924945889, 0.01989536276537805, 0.02720937271782708, 0.084379528679194, 0.01789004335390224, 0.08141846095602359, 0.06214150160010304, 0.03437685877865842, 0.016130582624745947, 0.031089280551720052, 0.032540446432727965, 0.04525164923360271, 0.08558070857919033, 0.15531380059978656, 0.10188741864816797, 0.10409255677293386, 0.08811002446999473, 0.18647769045445228, 0.12067841395976082, 0.16669172312944167, 0.1355151008934744, 0.22830509520586462, 0.15834004708355473, 0.10777628289595728, 0.15107914234601683, 0.1543834021375064, 0.13722563733256635, 3.3171957683178688, 37.17086653555594, 57.39200269022296, 58.759627265314904, 50.959437201100016, 40.61263653539842, 41.52494061377741, 49.71139392545147, 38.898188144929954, 54.670317096094934, 9.344254616768131, 0.40898612009421476, 0.4475115173526349, 5.828644527542976, 14.014226582742507, 13.962273809217638, 12.647327646132439, 14.593114487586485, 22.68118985237614, 62.06995864068309, 63.07495617097425, 58.640179326457364, 52.6997418557444, 52.586275531399636, 49.951258628599106, 50.850046219364295, 45.99006875868767, 49.68456099110265, 52.704578138166866, 55.221096315691554, 55.43332792097523, 56.74589418595838, 58.59395419397662, 57.54180585184405, 48.328723138378514, 53.280750782259055, 56.50810441663189, 55.28771385069817, 53.60028274597661, 49.59228723279892, 45.6152549097615, 42.519794894802956, 41.47090996465376, 43.93818278466502, 40.51548334860033, 46.84353336211174, 49.26595780157274, 51.97968098425096, 48.95982465436382, 46.30841224424301, 43.72595510175152, 41.12305456592191, 41.28920224405105, 42.878781980083836, 40.91494537168934, 44.20536287369267, 43.16701735219648, 50.180529009911325, 58.76845652057279, 54.51330461809712, 56.40625223036736, 56.646293440172755, 54.4845183434025, 56.89983544811126, 53.379249342026256, 51.732450069919715, 57.86387166669292, 58.28098827792753, 51.86488497641779, 60.48521910944293, 55.118279226364635, 58.78209852403211, 39.30806798319663, 31.261398138538485, 58.18984416223342, 53.9729549807887, 59.02093948856477, 53.732588214258996, 51.57169957314768, 46.909009487398215, 52.88181827914331, 49.560963184602805, 50.1564182004621, 50.1444039806243, 52.66140853205035, 48.82938231191328, 45.1182984536694, 43.20459365844727, 42.695136608616004, 45.12907712690292, 42.78580611751926, 41.893404145394605, 45.88614556097215, 44.67747111474314, 43.987055517012074, 41.93343585537326, 46.12246444148403, 43.807395273639315, 43.8568445944017, 45.58886520324215, 44.612387226473906, 42.8747497835467, 42.52282296457599, 43.843571293738584, 45.319147340713016, 50.268817640119984, 54.138624129756806, 51.90725441901915, 55.441078524435724, 55.698586048618445, 57.073259122910045, 57.41324624707622, 56.25278557500532, 49.996456100094704, 56.284223371936434, 59.48688960844471, 57.520244583006836, 57.45718071537634, 57.32098817825318, 60.702820439492505, 62.29292185075822, 57.6269095174728, 64.33050294076243, 61.40260657956524, 63.60526061827137, 61.01616290307815, 69.74370325765302, 49.76040394075456, 39.118189965524984, 18.130793302289902, 11.731138460097775, 9.071975446516468, 5.137726866429852, 0.8364907303644765, 0.35495654349365546, 1.4561170459755006, 26.745290948498635, 64.86898160749867, 62.61377173085367, 42.22315780578121, 28.353362698708814, 42.306465025871034, 60.31055988803987, 65.76655326351043, 50.365653114934126, 5.829930084366953, 0.18373013143577885, 0.1534659658829051, 0.18313803740086096, 0.20638453113215588, 0.18493834402292006, 0.14913920853887835, 0.24661376922120973, 0.10939545568919952, 0.2835476188169372, 0.1566300622277683, 0.10107993133245938, 0.12839637441380372, 0.12973919631012026, 0.1630112222365795, 0.17134250502192205], [0.019786681702, 0.08362676302391676, 0.0783147170178352, 0.01573970637118985, 0.027831246505581567, 0.006760901653192818, 0.04015243011376551, 0.030652698534991474, 0.03724010856521707, 0.07608786030041595, 0.027143902843818072, 0.01192562559980058, 0.006431963129509842, 0.043734737686933055, 0.030332770641712897, 2.562006149561175, 28.332652584198986, 39.41190096639818, 42.93185949325562, 29.03853212633441, 14.980117101823131, 20.818917136038504, 28.769230035043535, 29.69930833385837, 39.49430996371854, 3.5756434356012656, 0.1028483457142307, 0.49781104249338953, 2.2083073998651197, 8.877234670423693, 5.523413035177416, 8.408864448147437, 6.866241366632524, 38.30939331362325, 60.20487554611699, 54.30334406514322, 51.761648193482436, 44.83140845452586, 44.34591316407727, 44.97379049178093, 49.78982956178727, 49.877988753780244, 51.624200497904134, 52.0179162486907, 53.33622094123594, 54.28903525875461, 54.40760066432338, 52.4012416408908, 52.856711187670314, 49.90458242354855, 51.1103464711097, 51.38180194362518, 50.691735436839444, 50.48439894953082, 46.78771018981934, 41.783048260596495, 41.27764301915323, 37.13007780813402, 37.60599467062181, 37.595019878879675, 36.18871681151852, 37.045433059815444, 38.270067630275605, 38.66589753858505, 40.72281199116861, 39.273488367757494, 40.55528363873882, 38.33714800496256, 39.64761187953334, 37.1575814677823, 39.16801191145374, 38.211808666106194, 39.73117797605453, 48.28189396089124, 48.34857817619078, 48.04903461087135, 50.5377745628357, 50.6809881425673, 54.26090401987876, 47.3221331257974, 47.51809866197648, 51.885787287066066, 49.076150386564194, 49.74048222264936, 54.36201487818072, 51.64786023478354, 55.3223366122092, 36.93137837994483, 27.95859379153098, 55.3336291159353, 49.67817145009195, 54.64285266014838, 47.09450229521721, 46.168356172500125, 43.884485537006015, 46.40669507365073, 43.56163524812268, 44.11137111725346, 42.22585247408959, 41.5182686621143, 40.19751248821136, 39.87634489613195, 38.73653158064812, 38.700351638178674, 39.33629335895662, 39.50910906637869, 37.618981638262355, 43.78950534328338, 38.40512660241897, 39.252574289998705, 39.9869792692123, 40.70287458358273, 38.158370294878566, 38.46324436126217, 38.32011707367436, 39.06697165581488, 39.313567146178215, 38.308981464755156, 37.80877336379021, 41.27355983180385, 44.064922409672896, 45.41168389781829, 47.05758494715537, 45.47945460965557, 45.93988987707323, 50.97411471028482, 52.54475724312567, 49.46514752603347, 48.87222243893532, 53.05355925713816, 52.19776868820191, 52.392714408136186, 49.38482915201495, 52.21272860803912, 50.08768258556243, 53.78863103928105, 54.36570975088305, 55.17132143820486, 56.06904606665335, 58.65699060501591, 58.17849282295474, 59.49669161150533, 52.284959054762325, 26.40893397792693, 7.726830465178336, 9.198924918328563, 5.79221845634522, 4.112428373867466, 1.2566380467145675, 0.21577401116730707, 0.3026224114000797, 14.698951801946087, 38.70579196560768, 34.65058680503599, 27.114880200355287, 25.347387636861495, 32.21820935126274, 46.698617473725356, 48.227494608971384, 37.071622725455995, 3.9666613311536856, 0.04710831694425114, 0.016263029650754986, 0.05843474304363613, 0.055483688089636066, 0.050227826971921234, 0.03261086906516745, 0.017865317866146084, 0.05799534565378582, 0.12316584016286558, 0.02520056377585617, 0.08301281250051915, 0.038506543834603606, 0.03517187801339934, 0.01971347817039538, 0.07044245113408373, 0.01720482367090881, 0.07231644009270015, 0.07534816410512694, 0.034869323079023636, 0.09377114609965394, 0.015747078052241237, 0.05395254262933328, 0.05216113411851468, 0.06338399279141618, 0.027433985866786494, 0.023679978837589585, 0.017885854768176234, 0.0053990266713944655, 0.0434033242204497, 0.06086209263171881, 3.201122783845471, 34.48034809481713, 47.80959352370232, 50.676202850957075, 37.7169349885756, 28.35854218852136, 33.7499870792512, 34.13943529129028, 32.63166442994149, 44.68171511926959, 3.696291619731534, 0.14080400338336346, 1.580820960863944, 5.416986384699422, 10.973395378358903, 7.700672178499161, 10.070649135497309, 5.553737369275862, 42.808257764385594, 60.96786283677625, 57.76097220759238, 54.18558666782995, 48.196166638405096, 46.09319963762837, 47.346820523661954, 50.99771168924148, 52.249536129736136, 52.97847724729969, 54.12293072669737, 55.12522966630998, 56.32880895368515, 57.3133905472294, 54.476253909449426, 54.63267018718105, 51.57194668246854, 51.120728984955825, 53.949914978396514, 52.59418302966703, 51.94463068439115, 49.03339262931578, 44.591339788129254, 43.07595168390582, 39.568560431080485, 40.18660437676215, 39.00169949377737, 39.55142359579764, 40.91470218473866, 40.67276254776986, 40.744294812602384, 41.85489823741298, 40.303028168216834, 41.20032918068671, 40.58925136443108, 41.59218572801159, 38.62943910783337, 40.13140486132714, 40.13493499448223, 41.64787946208831, 50.65290789450369, 51.52679627941501, 50.66058005056074, 52.249767549576305, 54.097509845610595, 55.40513784654679, 48.08691293962541, 50.52645460251839, 54.52811156549762, 52.46578424207626, 51.62199220349712, 55.28570167479977, 52.93759438299364, 55.27493084630659, 38.00440157613447, 29.780256248289543, 55.153207932749105, 51.54684743573589, 55.64545362226425, 47.7472121484818, 48.04307260820943, 45.576803914962284, 46.99413668724799, 45.79640565379974, 47.830723331820586, 43.499536283554576, 45.50368701258014, 41.81856924487699, 42.088585207539225, 41.39449827132687, 40.7764974717171, 40.623615249510735, 40.26473014585434, 40.14704335120417, 44.74496726066836, 41.29242643233269, 41.93908799079157, 41.228931103983236, 43.43673913709579, 39.856431022767104, 40.436098498682824, 39.846358376164595, 39.97998960556523, 40.92445711935721, 40.04423018424742, 40.22742448314544, 44.016488982785134, 46.28867487753592, 47.38024303990026, 49.23189593899635, 48.326683505888916, 47.098632551008656, 53.85788048467329, 55.7343384527391, 50.347704349025605, 51.30743772752824, 54.853138769826586, 53.461442608987134, 56.360352654610914, 50.531153601984826, 53.762935592282204, 51.05231108204011, 55.804792065774244, 56.32400797259424, 58.19043251775927, 57.07230990932834, 62.852271449181345, 58.895188300840324, 61.11173145232662, 53.27720103725311, 31.943631672090103, 8.533416371191702, 12.379173828709511, 10.174381117666922, 4.324200326396573, 1.946424349181114, 0.18363243990367462, 0.3458423035279397, 15.539221552110488, 49.01397297459264, 40.94135861242972, 36.308062768751576, 30.1052991420992, 37.85461410399407, 53.299350661616174, 57.37428534415461, 45.75498934715025, 6.074572234384476, 0.005560889558476066, 0.034037535454356865, 0.05155664478098193, 0.05382737152338509, 0.03353283289940127, 0.014573358573890744, 0.030226742157772667, 0.019550397203514175, 0.0673072899301206, 0.03828065131881064, 0.054787141796682155, 0.04797986836262769, 0.01464439599188946, 0.029011081280787627, 0.05045481116300629, 0.1653187403515462, 0.10702002387974532, 0.16323921000284536, 0.09148367650566563, 0.14404726725432182, 0.1584343371852752, 0.21012489413542135, 0.10648722505016674, 0.19516249217333334, 0.12393776567712908, 0.08994048431275353, 0.20971621687133468, 0.1789780267544331, 0.16797616146504882, 0.18915761923117025, 4.830943096068598, 41.933373097450506, 56.006033189835094, 58.535616782403764, 43.60900963506391, 28.134608191828576, 32.978707898047666, 41.76800204861549, 41.584478270622995, 50.67774434243479, 4.460972884008962, 0.3347353462971026, 1.3761282736255278, 3.980741169183485, 13.809320003755632, 17.071472906297256, 18.366125706703432, 12.850915328148874, 43.916331260435044, 63.247077618875814, 58.83566633347542, 57.9356235842551, 50.46457921305011, 48.522299951122655, 49.66120327672651, 55.319453670132546, 55.363662704344726, 55.54702174278998, 57.081794200405, 57.20505468307003, 57.87688609092467, 57.920969609291326, 55.78260321770945, 55.4623338483995, 51.71891397045505, 50.82107951564174, 53.91744167573991, 55.67050187818466, 54.874727495255016, 51.23765091742239, 46.81782614800238, 45.713761314269036, 41.780479108133626, 43.34709336680751, 41.499472664248565, 41.29812955856323, 41.50492475878808, 42.199266649061634, 42.91958247461627, 43.222742465234575, 43.21726291410385, 44.515818472831484, 42.48665871158723, 42.76654335760301, 40.59528789212627, 42.39934282918131, 42.18270640219412, 43.63534442840084, 52.283696051566835, 52.46995764393961, 51.53283672948038, 54.29680939643614, 56.598177725268954, 58.61727268465104, 48.892752124417214, 50.60259957467356, 55.18415151103851, 53.6749372174663, 53.95780678718321, 57.76104281025549, 55.03659978989632, 56.150101846264256, 41.02881570016184, 32.0645308879114, 55.546351017490515, 54.098223716981956, 59.88426493060205, 49.75394379708075, 50.57773174778108, 47.39448124362577, 48.79723456598098, 47.149909696271344, 47.93032407760621, 46.157146038547644, 45.017050312411406, 44.06203554522607, 43.58838973506805, 43.59950180976622, 42.889870520560976, 44.01651251700617, 42.62377300570088, 41.45450269022296, 47.375234173190215, 42.581179987999704, 45.17533756071522, 44.65005374723866, 46.51448180598598, 41.86355490838328, 42.692261511279696, 42.87724048860612, 42.92926680657172, 42.993699581392356, 43.216572576953524, 43.013868408818404, 47.126179356728834, 49.29549324897028, 50.22022339605516, 53.51336302295808, 50.64260775043119, 49.540606083408484, 55.10406455686016, 57.88268335403935, 53.50660085678101, 52.34129213517713, 56.1506627451989, 56.613384754427024, 58.70828736212946, 53.85846491782896, 57.30684803378198, 52.98714960775068, 58.35791772411716, 59.23257489358226, 59.29242241767145, 59.49462060005435, 64.98307158870082, 63.18708496709024, 64.20307297860423, 57.090411647673584, 33.74290720109017, 10.906719988392247, 20.234617340949274, 13.939406391113037, 10.265450708327755, 3.5035233055391624, 0.45671768786926425, 0.9206923121406186, 20.41661923931491, 51.903281058034594, 45.62109531894807, 41.41855416759368, 33.90381067029892, 45.765140441156205, 60.84855610324491, 63.07619563994869, 53.102078976169715, 8.61408285556301, 0.12319950206625847, 0.09810373337278444, 0.1705744712343139, 0.16560917960539942, 0.10376320791340644, 0.07262752541611273, 0.11964710639609445, 0.18524160758862573, 0.2488564150107484, 0.20956183483283367, 0.15166781962879244, 0.1351344777691749, 0.07406967061181223, 0.07938343265484418, 0.29002302296219334], [0.02202476352272976, 0.05850395142671563, 0.11081893132218432, 0.031428012073100094, 0.0313190724550476, 0.02842927006103339, 0.05518220184791473, 0.006445902099292125, 0.04773488876620128, 0.01316640171177325, 0.034008933561703855, 0.03861565390721925, 0.014341558562591674, 0.03641958626347684, 0.058319550232901696, 3.9281304180622105, 28.41294938518155, 38.53944424659976, 41.671656870072894, 17.64210912489122, 10.965021118041008, 14.364228498551155, 23.835537510533488, 32.21221204726927, 34.10753465467884, 1.850789609935976, 0.1092745746756273, 2.4538453211707454, 2.356327844242896, 3.403813468833124, 3.6680552123054384, 12.379150294488477, 17.046897295982607, 43.98429809078094, 58.1051758796938, 55.14080539826424, 50.88912087102091, 47.14840742849535, 52.55284517042099, 54.27229066048899, 54.64721433577999, 51.72463278616629, 52.506012070563536, 52.97183667459796, 53.688339956345104, 50.61848125150127, 50.506387756716826, 51.477954926029334, 50.215634222953554, 50.24573056928573, 51.706417299086056, 47.59844057021603, 50.50513259826168, 51.066196272450114, 45.44374927397698, 40.72884459649363, 37.602174282073975, 38.28560413852815, 37.67570303332421, 38.7482790793142, 38.88365968581169, 38.789471810863866, 37.01225373052782, 38.33681068112774, 38.7290673102102, 38.29011094185614, 38.074780664136334, 37.633619923745435, 38.18774492509904, 37.78056367751091, 38.01751013725035, 38.45183026406073, 37.59478453666934, 38.144716524308734, 44.63523111035747, 48.255323825343964, 50.79968690872193, 53.87881417428294, 51.38214711220034, 47.52419402522426, 49.34874334642964, 51.88472824711954, 50.53154191663189, 52.042407528046645, 55.8757673540423, 52.5338295198256, 50.05716262325164, 36.816841248543035, 28.68304183406215, 55.96768025429019, 51.61092719724102, 54.01321026586718, 48.09528327757313, 49.40888504828177, 47.15081968615132, 49.8512734905366, 45.92629494205598, 51.2107160014491, 44.38379149283133, 44.947879314422615, 40.959868277272875, 37.41058218863703, 39.42867694362518, 39.182493302129934, 38.42766061905892, 40.58343056709536, 38.68087314790295, 46.25042392361549, 43.78546137963572, 37.91821925870834, 39.738677547824004, 39.78589896232852, 39.1181585865636, 39.52763834307271, 40.663458685721125, 39.60700358113935, 38.34281582986155, 38.504884243011475, 37.67980583252446, 40.40751618723716, 40.50791317416776, 40.95262365956461, 41.87241554260254, 44.39284040081886, 48.84373034200361, 51.720788863397416, 51.56063064452141, 49.98335538371917, 49.815034712514574, 52.975304049830285, 51.832199865771884, 52.96625906421293, 48.58705828266759, 48.155146491143014, 48.664085788111535, 52.112814072639715, 53.56169054585119, 52.470055703193914, 51.85787570091986, 54.40737708922356, 58.3265858311807, 60.89326720083914, 59.3576749678581, 38.779148132570334, 16.69932430790317, 15.34384927441997, 10.112848935588714, 3.7249185481379112, 1.9657525636496085, 0.16352522126849622, 0.06760437882715656, 16.891147821180283, 32.847783104065925, 40.86493907436248, 36.75065517425537, 18.383945034396266, 26.50867396785367, 41.92557542554794, 53.05792877751013, 39.51437288714994, 4.822877232105502, 0.05183416779243177, 0.004570545673730874, 0.03505166732676087, 0.02945100727130569, 0.07882968898141578, 0.07875124923884869, 0.04405212408352283, 0.040392476103959546, 0.03454678474114307, 0.0702374153620293, 0.01479246163545477, 0.04490017958526169, 0.07235728023994355, 0.007711540637237411, 0.00951509834492519, 0.025045076655524395, 0.04239961114381591, 0.008628078653747517, 0.05096846545535711, 0.02619181260196192, 0.00610654765266865, 0.016943271677460403, 0.03180292018148447, 0.021375798950752905, 0.08431764409667061, 0.02229484398999522, 0.06795101063025576, 0.025854528986758767, 0.023439344874913656, 0.11454221056473833, 5.739439043306536, 36.16907750406573, 46.27849240456858, 49.05415765700802, 22.427371317340484, 13.715732251444171, 18.88577699661255, 28.898558424365138, 37.44379289688603, 40.65497852140858, 2.1227806085540406, 0.17567943601358324, 1.9180377885218591, 6.733624560217704, 6.3179018612830875, 6.8847260263658345, 8.741026443819846, 17.849200464064076, 48.920526427607385, 58.87754155743507, 57.39970230287122, 53.38748239701795, 49.48654013295328, 52.69461924029935, 57.151773206649295, 56.708266888895345, 54.90905607900312, 56.99262695927774, 55.932728013684674, 53.965635838047156, 52.61250834311209, 51.244193430869814, 52.56339634618452, 52.26280550802908, 50.211531423753314, 52.181220208444905, 49.60510946089222, 51.999834122196326, 53.34816848078082, 46.815590397004165, 44.299276182728434, 41.80868879441292, 40.481272435957386, 38.9932507084262, 39.90628434765724, 39.81789765819427, 39.99225877946423, 38.76385873363864, 40.74282784615794, 40.76309081046812, 41.68282385795347, 39.84973553688296, 39.07682072731757, 39.273876682404556, 39.41359150794245, 38.58692845990581, 40.207094838542325, 39.98392766521823, 40.71345713830764, 46.331879784983975, 50.609063640717544, 51.22690362315024, 55.33406057665425, 52.96288582586473, 48.10331236931586, 51.71775294888405, 54.67887570781093, 52.17213599912582, 53.82317927575881, 59.3466805642651, 53.93348416974468, 52.53488855977213, 38.10787370128017, 31.030839258624663, 57.03415309229205, 52.50655728001749, 55.25378142633746, 49.54690540990522, 50.97515021601031, 48.351096337841405, 51.22914721888881, 48.39271268536968, 50.98830192319809, 45.62544914983934, 47.86270633820565, 43.00125798871441, 41.3633232731973, 40.04012738504718, 41.61351165463848, 40.941633178341775, 41.5880907735517, 40.90409609579271, 47.61132163386191, 45.23016052861368, 39.329272316348174, 41.02810967353083, 41.570749975019886, 40.66739674537413, 41.81361529134935, 42.288920264090265, 42.075394276649725, 41.73169659030053, 39.88210293554491, 39.64646262507285, 42.43822528469948, 43.35038423538209, 44.85938672096499, 43.83032937203684, 45.885459146192, 49.2008464567123, 53.36183401846117, 53.280554663750436, 51.43329089687717, 50.76038083722515, 53.58307923040083, 55.366427975316206, 55.641499873130556, 49.89919700930196, 50.69486156586678, 49.12118704088273, 54.30251252266669, 55.78705510785503, 53.64818273052093, 54.19347455424648, 57.177147019294004, 59.6362966106784, 62.528742590258204, 60.195697199913766, 37.810577654069476, 11.159881526424039, 15.388127930702703, 8.99540783897523, 4.791370793696373, 3.5816368172245645, 0.2580983311899247, 0.025789193178136504, 17.567113407196537, 37.566872950523134, 48.3338967446358, 41.700184268336145, 19.047815991986184, 33.77437637698266, 49.56557196955527, 59.18574963846515, 47.91941204378682, 6.644150883920732, 0.07639536799322214, 0.03833085689092836, 0.04087626828902191, 0.02720090744626378, 0.099783526703475, 0.06955340609795625, 0.06071188577240514, 0.05914781385311677, 0.07280069193051708, 0.1043317064402565, 0.016040327891166654, 0.0358985890183718, 0.011417639400479535, 0.08947576005612651, 0.014656669678046338, 0.07564361357400495, 0.11811767314230243, 0.13124576950025174, 0.2126913040035194, 0.18252277686711282, 0.12537577399803748, 0.1855480887236134, 0.13170880836344537, 0.088391347277549, 0.20097498511595113, 0.18386240417678512, 0.12178010202103084, 0.24479913675496656, 0.15743260061548603, 0.26666907773863885, 7.311350953194403, 44.32365763571955, 55.34111299822408, 59.07558594980548, 28.47497774708656, 19.808471433578, 21.355787631004088, 34.98517674784507, 44.50917397775958, 46.33207982586276, 2.0653796628598244, 0.2240657484939983, 3.041144748849254, 6.544145643711091, 8.246468517088122, 9.957391677364226, 20.608821261313654, 21.89543712523676, 51.1664677435352, 61.672901030509706, 58.83556042948077, 56.29761042133455, 52.953197571539114, 56.63394974124048, 59.78102422529652, 59.11193455419233, 57.005284447823804, 57.99721656307098, 57.2146801794729, 54.99739177765385, 53.668159361808534, 50.93542837327527, 53.699357894159135, 51.363778652683386, 52.61388509504257, 52.40697222371256, 52.308728618006555, 55.32014792965305, 55.50286369939005, 51.12017200839136, 46.36066605967861, 42.453702957399436, 44.34890985488892, 41.49785664773757, 42.68373427852508, 40.7729555714515, 42.81927570219963, 40.74330245294879, 43.29976997067852, 42.5604659511197, 43.49428422989384, 40.84283259607131, 40.50256306125272, 40.644364587722286, 41.578916349718654, 40.85696097343199, 42.530157796798214, 40.83204607809744, 41.96028840157294, 47.73478607977591, 53.05284146339663, 53.78439095712478, 57.74415700666366, 54.67401589116743, 48.89614497461627, 52.00296417359383, 57.24616896721625, 55.208368224482385, 57.85366565950456, 59.69367304155904, 57.745008160991055, 54.96734249976374, 40.83721968435472, 34.587789658577215, 57.747734208260816, 54.98861351320821, 57.16032397362494, 53.58412258086666, 54.28732510535948, 51.942273339917584, 53.55102169898249, 50.808096470371375, 54.523800880678245, 48.51123494486655, 49.14891035326066, 45.27644449664701, 41.9850464021006, 43.34510080275997, 42.989906649435724, 42.710449541768725, 45.06493852984521, 43.52083475359025, 47.92036125736852, 47.18352048627792, 41.749370790296986, 42.909501983273415, 42.723056039502545, 43.81202367044265, 44.112885152139974, 45.71989590121854, 43.06873060041859, 43.72527653171171, 41.866606512377345, 42.93555828832811, 45.674270891374164, 45.28252024804392, 45.781967409195445, 46.90263955823837, 48.81723865385979, 52.719451765860285, 57.01568657352079, 55.05878079322077, 53.7816962888164, 52.196035000585745, 56.7563747590588, 56.87782310670423, 55.87896016336257, 52.59674825975972, 51.69647409069923, 51.53502541203653, 57.383240115258005, 59.19435139625304, 55.79091079773442, 58.05461260580248, 60.227613526005904, 63.294032312208614, 64.17753050404211, 64.15598492468557, 43.01118158525036, 21.85883160560362, 26.87559404680806, 18.729345029400243, 11.455835142443258, 5.061088656225513, 0.36287207036249103, 0.19540373326068927, 20.52138770780256, 44.15578411471459, 51.68152201560236, 51.13111934354229, 27.42008766820354, 40.45768330174108, 57.833151663503344, 66.09559305252569, 56.23873956741826, 11.288627443775054, 0.253815179570548, 0.1495913689535472, 0.09504852876547845, 0.1604356346351485, 0.26321251966780235, 0.2045440508593475, 0.285151316634109, 0.0745234857763975, 0.19793208388070907, 0.20653555770554852, 0.09550063555399257, 0.10631837161077608, 0.1774187773586281, 0.18048818523605026, 0.11011833625455057], [0.03653154618317082, 0.06073918531558687, 0.025735354434037884, 0.029335268622925206, 0.06505365843974775, 0.06744780577719212, 0.06241642757348957, 0.03433554748734159, 0.09886263539233515, 0.05261422149957188, 0.016558184175782146, 0.006891192141695009, 0.05126643918394562, 0.03996300721360792, 0.020794749988483328, 5.774782540336733, 31.806809594554288, 41.01298893651655, 39.448900684233635, 29.522268233760713, 15.577281290485015, 24.961030252518196, 27.78806482591937, 35.90170914126981, 30.811882749680553, 0.48699326813220983, 0.58039384984201, 2.140201080229975, 11.66994458244693, 10.970847798931985, 8.403519238195113, 10.54172775437755, 23.558788799470474, 55.862266555909194, 58.75363780606178, 54.9228588996395, 50.521547717432824, 50.07667249248874, 50.39091317884384, 55.68446159362794, 51.41745236612136, 52.53880700757427, 55.715416939027854, 52.67642336506998, 51.23028078386861, 51.57713990057669, 50.655308385049146, 50.73081008849606, 51.27932217813308, 51.823194103856245, 51.129197382157855, 50.47652283022481, 51.43750744481241, 47.429096160396455, 44.38212840787826, 38.80200770593459, 39.816214961390344, 36.19940527023808, 35.14949267910373, 38.11931133270264, 38.484146671910445, 40.09081617478402, 38.353967128261445, 37.85944254167619, 38.98380956342144, 39.18133228055893, 39.3086955624242, 36.939391782206876, 39.62628595290646, 37.30056362767374, 37.48440511765019, 38.80463177157987, 38.7819722390944, 38.2737664253481, 44.57369696709418, 47.63050986874489, 51.25914158359651, 50.96604639484037, 50.52348536829795, 49.00498682452787, 49.5372603016515, 47.90566413633285, 51.37691467039047, 50.24001567594467, 55.51431702029321, 45.759076456869806, 47.23975550743842, 40.1917113027265, 32.46170813037504, 55.60656332200574, 49.83103798281763, 51.1152062877532, 47.12523798788748, 47.79959147976291, 48.25484137381277, 49.47270201098535, 45.68364143371583, 48.7169671827747, 47.01214036633892, 44.96593398432578, 40.73194326892976, 40.26549500803794, 38.139758648410925, 38.340058403630415, 37.38557315641834, 37.947895911432084, 38.68097512952743, 40.082834151483354, 40.07803317039244, 38.69047511008478, 38.02194241554507, 40.12165777144894, 38.21299322189824, 38.19978267915788, 39.81920380746165, 37.92206318147721, 38.62637181435862, 38.09015635521182, 37.42090978930074, 38.476054822244954, 37.98238531235726, 39.5610765487917, 39.63901012174545, 44.004666959085775, 47.26888695070821, 53.712568436899495, 52.212257923618445, 49.017346212940836, 50.77867084933866, 54.16941473560949, 51.20355767588462, 55.108865537951075, 51.48806679633356, 51.64546366660826, 45.59807885077692, 46.30632554331134, 44.18211498568135, 46.47878039267756, 47.64101005369618, 52.99812047712265, 52.22523312414847, 59.640277816403305, 57.405240689554525, 44.34723892519551, 9.979806061713926, 10.710201398018869, 8.478251176495707, 1.8198624565716714, 0.7443643673773735, 0.0501830414718678, 0.06631643946973548, 6.798024485188146, 48.422565844751176, 36.34157549950385, 49.400651993290076, 38.64907057054582, 33.64229448380009, 42.219141298724765, 54.24399468206591, 44.236141712434836, 7.3953352724352195, 0.11867288770454547, 0.07587286538534588, 0.018298732109307762, 0.031475950024961945, 0.05347954845356365, 0.02130906120122921, 0.030006290781461907, 0.05477110374598734, 0.06572311203325949, 0.03904578929406501, 0.08810073948435246, 0.030521969461152633, 0.04310374553765982, 0.009770886484353293, 0.07838960977331286, 0.07950074369868926, 0.07965173196768568, 0.07554391489153908, 0.021188032715731574, 0.02166572875613647, 0.04925220250903119, 0.06840320934932079, 0.06173821759500331, 0.030788723191606904, 0.02354249095303878, 0.028929161583824508, 0.04006460579412599, 0.04230172808973059, 0.0817388772303539, 0.034512663184995615, 7.687491053535093, 38.37893693677841, 49.36328357265842, 45.68717548924108, 35.40296800674931, 20.247782776432654, 26.05365549364398, 35.145809573511926, 42.35075250748665, 34.06284709130564, 0.42593526383561475, 1.0690239720767545, 2.565415179537189, 8.910977840423584, 14.96033953082177, 8.236022264726701, 14.897668880801048, 24.49088711892405, 55.1627863607099, 60.51782185031522, 55.38569073523245, 52.5967796387211, 51.524023163703184, 52.92664312547254, 56.880180451177786, 54.27161993518953, 53.7209701538086, 57.08700310799384, 55.3259922612098, 52.406160293086884, 51.06050099095991, 50.84275061084379, 51.45120436145414, 52.87301255810646, 54.23932313919068, 53.369933712867, 51.91230250943092, 52.82807004067206, 50.44200597270843, 46.56846930903774, 40.959370136260986, 42.79778503602551, 38.72250518491192, 37.11278407804428, 39.457706405270486, 40.948834649978146, 43.223668144595244, 40.78571896399222, 39.109898074980705, 40.38663348843975, 40.09489543976323, 40.58730979119578, 38.7300596698638, 40.37197951347598, 38.53318414380474, 39.48519829780825, 39.64253633253036, 40.21091522709016, 40.607121682936146, 46.10201712577574, 48.292582419610795, 53.833302913173554, 54.37374668736612, 51.91037270330614, 48.761548842153246, 51.37037215694305, 49.65798301081504, 53.758315040219216, 51.05924975487494, 56.67649961286976, 47.09357661585654, 49.4167297886264, 41.834521524367794, 34.268524416031376, 57.994600342166045, 52.11720712723271, 52.990405174993704, 48.92739057540894, 50.163909927491225, 49.36787274576003, 51.84759516869822, 47.75737893196845, 49.416576816189675, 49.276430529932824, 47.04708476220408, 42.94563093493062, 40.95489863426455, 38.91070050577964, 39.699916685781176, 38.58579881729619, 38.98784175995858, 41.49939813921529, 41.42522219688662, 42.70268324882754, 40.3435972429091, 39.44325639355568, 40.820577067713586, 41.389348199290616, 40.556617244597405, 41.875220037275746, 39.50209979088076, 41.523273606454175, 40.406162969527706, 39.38581328238211, 40.40954797498642, 41.116417915590354, 42.12435722351074, 42.174124256257095, 46.14020532177341, 50.187977590868556, 55.89464964405183, 53.683633112138324, 50.36741818151167, 50.71737989302605, 55.53510950457666, 55.448095644674, 55.96882166401033, 54.740374549742675, 53.479250169569454, 48.00539039796399, 47.97690614577263, 47.20729397189233, 48.27686548233033, 48.49412556617491, 54.41869704954086, 55.23733100583477, 60.365135746617476, 61.00059109349405, 42.49598218548683, 13.045753182903415, 13.550201366024634, 9.436118487388859, 5.102708926123958, 4.447027387157563, 0.1215895759542623, 0.11706626343150293, 9.312383397932976, 47.246678490792554, 42.91132588540354, 51.64010570895288, 38.32081525556503, 38.57815804020051, 48.67684525828208, 59.43403959274293, 52.77770680765952, 11.27087381578261, 0.10491711252759542, 0.07763135892849776, 0.0064175008259142845, 0.02523462404496968, 0.029150193271737908, 0.006755882340873922, 0.054782035820666826, 0.024727887526575117, 0.0403147756362394, 0.034980003631884055, 0.07755239058526293, 0.024648603172071522, 0.10852452097160202, 0.05459339049975238, 0.04442970583876295, 0.19149083193511734, 0.11728692739721268, 0.12327099339135232, 0.1672732451510045, 0.1498610319028939, 0.1534942498490695, 0.08009070800917764, 0.14491688430068955, 0.11090514685718283, 0.1115063803210374, 0.12226759441076748, 0.14632550548882256, 0.1368594319830018, 0.17068507900882154, 0.19281126108140717, 9.570257663726807, 47.6547932624817, 57.5938674711412, 53.774361456594164, 41.406590938568115, 25.925403794934674, 32.706324784986435, 39.391226153219904, 48.56017435750654, 40.8431738422763, 0.5335831810389796, 1.12433000437675, 4.87095421360385, 19.57666523994938, 18.306427232680782, 18.483643839436194, 17.845603650616063, 25.35166302034932, 60.60627522007112, 63.388467296477295, 59.59466849603961, 55.80609821504163, 55.974603237644324, 53.8969551363299, 60.0838900381519, 53.67416058817218, 54.787070366644095, 59.17468463220904, 54.841532476486705, 52.65866287292973, 53.196494348587535, 51.640439110417525, 51.47285584480532, 52.65532885828326, 56.51086968760337, 54.05519531619165, 53.40999680180704, 53.84632125977547, 53.96101528598417, 49.505147857050744, 43.4300789525432, 45.771557438758116, 41.54980844066989, 38.591454875084665, 43.637533110956994, 43.11921934927664, 44.42058332504765, 42.45079648110175, 40.99366341867755, 42.64666788039669, 43.68742565954886, 42.43260452824254, 39.53407103015531, 41.913012073886016, 40.60365038533365, 41.841381749799176, 43.65410120256486, 43.16170646298317, 42.60379637441328, 48.00660633271741, 51.11200563369259, 55.80196795925018, 56.31252327272969, 53.02326679229737, 50.13942649287563, 52.533096036603375, 51.72738236765708, 55.9401491380507, 52.873200831874726, 58.10940027236939, 49.38449967292048, 49.962900223270545, 44.13066525613108, 36.817825763456284, 59.14775363860592, 54.3780142261136, 54.06277333536456, 51.92513258226457, 51.07896750973117, 51.76799066605107, 53.84565837921635, 48.57866048812867, 53.18016159919001, 51.053323053544574, 49.90497466056578, 44.81824890259774, 44.648261224069905, 42.437429043554495, 41.84402934966549, 40.926441838664395, 41.25440689825243, 44.1693712049915, 43.8730675174344, 43.80626563102969, 42.04912616360573, 41.80460952943371, 43.7798249336981, 41.974950221277055, 41.013706730258086, 43.83287891264885, 41.56503115930865, 44.297977878201394, 43.088424821053785, 42.06918124229678, 43.88167711996263, 42.04732579569663, 44.254349354774725, 44.41067149562221, 48.603736200640284, 53.75191765446817, 58.14894560844668, 56.5162629465903, 52.71842410487514, 53.30139029410578, 58.17681797089116, 55.30156373977662, 58.33439919256396, 55.91178647933468, 56.864459591527144, 49.82045935046289, 49.864472266166445, 48.63551524377639, 51.265621339121175, 51.16559305498677, 58.74525962337371, 56.990501034644346, 64.72102195985856, 62.87675096142677, 47.92791181995023, 12.285902807789466, 19.960312266503614, 17.8984183649863, 8.098097510876196, 4.9439554060659106, 0.2557995924425702, 0.18307743984605038, 9.857006457544143, 60.838008849851555, 44.54382811823199, 57.2046624460528, 50.80176184254309, 46.21395764812347, 55.215495171085486, 68.750363011514, 60.79604733374811, 17.875260691488943, 0.14116933539269433, 0.1393855609480412, 0.0822355090490272, 0.13827447298794024, 0.13731465674936771, 0.14737688455610506, 0.14167368171676514, 0.10136697681680804, 0.18628371699202448, 0.10771993712912645, 0.2563223861638577, 0.09364903934540288, 0.17599399171529279, 0.17676392540095315, 0.2348512858753243], [0.0817065023546738, 0.028912075907893242, 0.0032278836982685233, 0.06823527521543926, 0.009509060614471956, 0.05894704519080059, 0.06289403359856337, 0.038350805820476626, 0.016995618465326486, 0.04219780826280194, 0.06609104108065367, 0.1351567096407375, 0.043378790254674615, 0.020247916428131923, 0.12581687210307968, 6.3556066251570185, 33.79152497937603, 45.40824397917717, 38.53140338774651, 21.666768827745994, 13.454086626729659, 20.347030508902765, 34.40379911853422, 39.41679608437323, 26.379531891115253, 0.22491511017564805, 0.629673099085208, 4.702927720162177, 17.210338538692845, 13.766336710222307, 3.882380382668588, 13.941139098136658, 33.32096999691379, 56.880878633068455, 55.716232792023696, 53.02010928430865, 48.66620779037476, 51.4775352324209, 52.975500168338904, 54.69742459635581, 51.45962961258427, 50.15941096890358, 52.271807347574544, 50.368665495226466, 48.665670425661155, 47.42961783562937, 51.78588844114735, 51.925693481199204, 51.02625085461525, 49.164737116905954, 48.446488380432136, 49.971121511151715, 48.76045842324534, 44.95342946821644, 37.90723662222586, 38.37609321840348, 39.01534541960686, 38.420929831843225, 37.685159867809666, 40.333226496173495, 39.51322755505962, 40.30674265277001, 40.676327982256495, 38.6071482781441, 38.45247745513916, 39.51091335665795, 38.25901831350019, 38.06659859995688, 36.02645620223015, 37.02119281215053, 36.1714623051305, 36.36215617579799, 37.70959231161302, 38.073847140035326, 43.46911830286826, 47.83674417003509, 50.19419846996185, 52.40426971066383, 49.91134851209579, 48.65204411168253, 49.848837698659594, 48.777006903002345, 51.81429424593526, 51.45896280965498, 55.20309655897079, 49.40979111579157, 45.35911237039874, 40.89305070138747, 33.651704249843476, 56.26882806901009, 50.064823012198175, 52.12888402323569, 46.64099001115369, 48.43546652024793, 47.351327326989946, 50.277854780997004, 49.152985695869695, 47.5270220541185, 45.65988755995228, 43.8261559701735, 39.02764597246724, 38.77332341286444, 39.18161469121134, 39.48980708276072, 39.7855890950849, 37.7447328259868, 38.3144727829964, 39.80087849401659, 38.43936104928294, 39.62027688180247, 39.14043372677219, 39.9876303826609, 36.583668108909364, 39.17362090080015, 39.37107301527454, 38.61636192567887, 37.93013934166201, 37.42353777731619, 37.54015376490932, 38.18973748914657, 37.92248287508565, 38.979824435326364, 40.87038332416166, 45.66484935822026, 51.176583536209606, 53.55137863466817, 50.00004899117255, 49.65528442013649, 49.287542604631, 50.74855881352579, 54.96892321494318, 54.88210547354914, 54.78050431897564, 52.13790547463202, 47.810150500266786, 44.71847165015436, 43.393000787304295, 49.37490555547899, 54.17113273374496, 53.47828526650706, 56.19598181016984, 58.15829261656731, 61.7217266944147, 47.932504915422015, 20.32151549093185, 12.852806891164473, 4.7478378780426524, 1.819869320719473, 5.171472487911101, 0.39504767125172, 0.0992840526986026, 5.406799989361917, 37.619448400312855, 39.20386237482871, 24.567157606924734, 25.85629947723881, 38.730604879317745, 49.10716064514653, 52.314737689110544, 50.013898880251, 9.922224686991784, 0.25547140037580846, 0.05547388982508452, 0.052332458191461144, 0.04643892846821297, 0.06096160745308284, 0.02410953582805251, 0.022798518071912473, 0.06836442997859371, 0.03208325282039662, 0.05859955919966583, 0.05456103094583077, 0.06347483549747737, 0.02326994751309676, 0.060751002221818895, 0.012413978880842128, 0.03661589629407372, 0.009048117959361163, 0.028590250031782255, 0.05133781176541121, 0.0510160165328172, 0.0956172417969473, 0.017578634358341658, 0.04345126600275117, 0.009072229619167987, 0.06692321941016183, 0.04309162219625808, 0.03342988983457608, 0.019626193942742485, 0.022032642737030986, 0.04907800560636867, 8.576124118220422, 41.18289424527077, 52.214274021887014, 46.44809176844936, 28.75359742872177, 14.779971299632905, 21.356938846649665, 34.115524522719845, 43.68872396407589, 30.659216257833666, 0.169441519124854, 0.8378485446014713, 6.9403658278526805, 16.172648053015433, 18.40341567993164, 11.717845547583796, 12.666078536741196, 32.8292263707807, 59.52414428034137, 55.03056326220113, 57.18439555937245, 50.48001766204835, 53.83492677442489, 55.9181877874559, 58.177535764632694, 53.911103125541445, 52.287979279795, 50.73588955786921, 50.41023477431267, 50.639010936983176, 49.84164799413374, 51.87511451782719, 51.27586264764109, 54.04731919688564, 51.55972457701161, 51.49888861563898, 52.20473873999811, 50.97547185036444, 48.054043477581395, 39.50552402004119, 40.46787361944876, 41.80683351332142, 39.493823589817175, 39.163469806794204, 42.500681184953265, 41.609185280338416, 42.39160399283133, 41.8868733990577, 39.73514349229875, 40.5830422524483, 41.60572182747626, 39.47178379181893, 40.910179691929976, 39.242089794528106, 38.779877693422385, 37.9926658445789, 37.96252242980465, 39.67953212799565, 39.989485663752404, 44.84465822096794, 50.10531756185716, 53.07861143542875, 52.87218101562993, 49.67746150109076, 51.42377130446896, 52.754254956399244, 49.788774444210915, 52.69224228397493, 52.96712590802101, 56.561683993185724, 50.75359121445687, 47.67194186487506, 40.509905738215295, 36.05026498917611, 59.206753930737904, 53.335675731782, 53.880383122351866, 50.81381136371244, 50.852203522959066, 49.06208868949644, 53.744747561793176, 50.67646172738845, 49.85825530944332, 48.49752233874414, 45.93055855843329, 41.75931399868381, 40.34964553771481, 40.882511292734456, 41.05827662252611, 39.53045852722661, 39.73403738391015, 40.963539615754165, 41.54107724466632, 40.1999012116463, 41.37101111873504, 41.19670491064749, 41.75631730787216, 38.17677405572707, 41.4801981372218, 41.640634844380045, 40.304451988589385, 39.76929949175927, 39.55391822322723, 39.921467842594275, 41.24286728520548, 39.85594072649556, 41.518229438412575, 42.28666490124118, 47.88367925151702, 53.2896702520309, 55.536439188065074, 51.15039387056905, 51.11622218162783, 50.65865024443596, 53.437837785290135, 56.34850709669052, 56.63111386760589, 56.76562370792512, 54.00524785441738, 49.61406815436579, 46.61178012048045, 44.810035459456905, 51.00930229310067, 56.200308184469904, 55.43858389700613, 58.729138681965495, 60.877036433066095, 63.981933670659224, 49.61837883918516, 17.67764775983749, 10.236255526542664, 9.702717085038463, 5.252129166356979, 3.220132305737465, 0.07223773221935957, 0.08482821871556583, 5.544008910655976, 42.131519471445394, 41.27702720703618, 32.98410900177495, 37.04196568458311, 46.44935084927467, 51.81461195791922, 59.52116327901041, 58.161042198058105, 14.974959185046536, 0.17356936940022055, 0.02774308893769499, 0.02576647867118159, 0.053044475630045905, 0.018656581354838227, 0.03572405886746222, 0.023418070613256386, 0.04665063303564826, 0.03475612592733195, 0.04529947993315516, 0.03873807092707965, 0.03213489097693274, 0.01328837535824747, 0.07674914739665485, 0.0346151044622304, 0.11978988220254261, 0.13941294093045498, 0.09938230347489158, 0.16176891873680777, 0.07368334013247684, 0.17050229043008822, 0.1822948503878809, 0.11117994259562224, 0.13337511088578932, 0.0856238546510858, 0.16258570635991712, 0.19582497436673413, 0.17498385882185352, 0.062464154851172245, 0.20001507694682769, 10.81451585215907, 51.866159746723795, 61.056653530366965, 52.378507583372055, 33.53937541284869, 23.535366365986487, 28.891556993607555, 45.28911767467376, 52.27306250602969, 33.94796871369885, 0.5085582754785015, 0.8094414527858458, 10.80562383897843, 26.910261915576076, 22.902972429029404, 12.502414699523682, 16.40205767846877, 37.35772040582473, 60.73457594840758, 58.76953909474035, 58.346903708673295, 54.64163280302479, 56.19887259698684, 58.5281172106343, 59.612005372201246, 54.29258108139039, 52.6949800983552, 53.56548740017799, 51.714889618658255, 50.69113923657326, 48.67472325601886, 52.74247215640161, 52.8343262210969, 56.21622124025899, 52.86980013693533, 51.88991362048734, 54.17276051736648, 53.717828335300574, 50.38983452704645, 41.536142902989546, 43.10847205500449, 44.30714837966427, 42.43312620347546, 41.49479719900316, 45.19981707296064, 43.589735108037154, 45.166971145137666, 44.63990657560287, 42.28892810883061, 42.65337121102118, 42.40322989802207, 42.46797646245649, 42.30289174664406, 40.472270596411924, 41.13061297324396, 39.09297304768717, 39.90274636976181, 41.585549077680035, 41.94771328280049, 46.900882336401175, 52.23300726183, 53.725312217589355, 55.40938185107324, 49.30854689690375, 52.00583534855997, 54.31026704849736, 52.72025585174561, 53.938646008891446, 55.639126839176306, 58.00562612472042, 52.54710282048872, 48.51184291224326, 42.0334876737287, 40.13715897836993, 60.437821188280665, 55.124664845005164, 55.76309334847235, 51.63793663824759, 52.27040706142303, 51.40796415267452, 54.799049285150346, 54.82717267928585, 51.6564384583504, 51.834086525824766, 48.3555599950975, 43.704527193500155, 41.87551813740885, 43.81612646964289, 43.4359585854315, 43.67321099004438, 41.35429397706063, 42.645946164284986, 44.042910068265854, 40.96644609205185, 43.61482258765928, 42.516711911847516, 44.13401103788807, 40.09459733963013, 44.549797965634255, 44.80427742004395, 42.0085649336538, 40.77187691965411, 43.13047655167119, 42.52290141197943, 42.90872143160912, 42.59204103100685, 43.04729092505671, 45.189344344600556, 50.725197176779474, 56.69995930887038, 55.90713454831032, 54.072893050409135, 52.279487348371944, 53.74107622331189, 55.12914419174195, 58.34695862185571, 59.065717266451934, 59.207891418087875, 54.44549468255813, 53.47020518395209, 49.40470772404825, 47.93693327134656, 54.59366613818754, 60.034797653075195, 57.315202682249016, 61.78533969386932, 63.91315490968766, 68.10077144253638, 52.184946460108605, 23.719982524071973, 22.3512283063704, 16.563410259062245, 13.432741088251914, 7.1607829293897085, 1.5294974826035963, 0.2322333642551976, 7.389008979643545, 46.7913854506708, 51.266194005166334, 36.60691207455051, 36.4262516267838, 51.098194968315866, 60.89664043918733, 66.19976335956206, 65.89178669837214, 22.400193214416507, 0.27647350163709733, 0.14072109734819782, 0.17341880247958247, 0.15910769782720074, 0.13486921216451353, 0.1557835044279214, 0.18378248588452417, 0.20880941391712238, 0.15146137425495734, 0.1449806074942312, 0.16035642114377793, 0.15787155367434025, 0.12473334798649435, 0.14590057183898267, 0.10533271522651758], [0.035469143110657894, 0.0789344821485781, 0.08419154602433405, 0.021442304958679506, 0.048122678643032435, 0.023981503383707137, 0.09042431480221211, 0.010127563615359608, 0.06757867657729695, 0.017954055745635304, 0.022835778673329664, 0.029211637353704824, 0.03147334341079958, 0.08253713318657491, 0.05021753841109815, 5.862989781364318, 28.713414707491477, 45.34574493285149, 38.42437367285452, 27.075338786648167, 23.621297651721587, 28.78424486806316, 32.801363814261656, 43.89137714139877, 18.164437432442945, 0.03244667344035641, 0.043474876832577496, 2.8741353750228886, 27.331899058434274, 15.619112387780222, 11.885700437330431, 21.422138444838986, 46.076957102744814, 59.92134309584095, 54.47427311251241, 50.66759717079901, 50.11157766465218, 49.33954146600539, 51.86201380145166, 52.106071518313506, 52.918645412691184, 46.60946984444895, 50.668754269999845, 48.52652826616841, 47.86288284486341, 47.9613108019675, 49.545489434273016, 51.99200114896221, 50.79936919673797, 49.42111499847905, 47.48184027210359, 44.92687502214986, 41.34259354683661, 38.38791524210284, 37.04726480668591, 37.51219903269122, 38.15278483975319, 39.32593437933153, 38.89129654053719, 40.75173554881927, 41.37725945441954, 38.608819207837506, 40.3328146473054, 38.454768119319795, 37.942636013031006, 38.12497131286129, 36.55147721690517, 37.32094034071892, 36.48615014168524, 36.18703411471459, 37.00759003239293, 36.27074141656199, 36.3592928455722, 37.3629803042258, 45.54036901843163, 50.729099935100926, 52.4118398850964, 48.068320905008626, 49.83416803421513, 49.43964819754324, 52.099709433894006, 52.97837918804538, 51.35305881500245, 52.99274682998658, 53.202275922221524, 47.41406171552597, 47.41221427917481, 42.71892970608127, 35.03957609976492, 55.494920899791104, 50.24843308233446, 50.47634632356706, 47.02223654716246, 46.1342982322939, 44.847172460248395, 43.90898858347247, 43.2104693689654, 42.35786768697923, 41.437965977576475, 41.95390670530258, 40.24555367808188, 38.541676075227805, 37.20455969533613, 38.74867916107178, 38.07166630221952, 38.15287505426715, 38.770930767059326, 38.21828449926069, 39.25377061290126, 38.65956683312693, 39.98990143499067, 38.036639536580736, 39.4470924715842, 41.728064475520966, 39.60987475610549, 37.45959220394012, 38.195668112847116, 38.83456730073498, 40.593040374017534, 37.70776056474255, 37.4983177646514, 39.12215155939902, 41.400738762271025, 44.3319809052252, 51.11202524554346, 52.67779619463029, 52.99750858737577, 53.5330690107038, 52.542898039663996, 49.33805096533991, 51.273717111156834, 51.714285573651715, 52.730057854806226, 52.29573772799585, 47.60321017234556, 40.21193504333496, 44.81116902443671, 55.81857527455976, 58.21478651415918, 57.09114905326598, 57.68670212837958, 58.95735002333119, 62.14342855638074, 52.755317918715946, 26.335636646516864, 13.114523118542088, 6.219485180993234, 2.441744073744743, 4.285110965851815, 0.17054715253893407, 0.05148516111676732, 2.042626361212423, 37.70003349550309, 48.05251767558437, 32.792452189230154, 18.899048336090583, 32.862884229229344, 43.35051759596794, 52.489753846199285, 50.56875736482682, 16.906105779832412, 0.1673192257482198, 0.04616049764257285, 0.02017240888709503, 0.04049326646171751, 0.015943356481711232, 0.022385069995277354, 0.059334130266741406, 0.062091709715464426, 0.03951733939409737, 0.0647465491126622, 0.022875630567150734, 0.03868881530398804, 0.06309254996238217, 0.04513544135636861, 0.02386143442333466, 0.02578226774330101, 0.08729337474271175, 0.024495760970298323, 0.036423527785847266, 0.040545578775627, 0.07070896546206168, 0.04600104410201312, 0.07234267860410676, 0.05886421576442738, 0.13508808348448048, 0.05928844844381656, 0.061408106477991234, 0.02085534371285429, 0.09644727508026747, 0.07956727077403376, 8.108248114585876, 37.74614095687866, 52.10916626837946, 45.22428089572538, 28.310014624749464, 24.770195176524503, 24.678021438660164, 34.84712108489006, 49.271382439521055, 20.587979747403054, 0.049653437228933464, 0.08771396467402097, 4.81086056078634, 27.971816101381858, 14.778691626364186, 17.125064249961607, 16.892775604801795, 47.7934725822941, 61.159490231544744, 56.444212928895034, 53.03602234009774, 51.85973490438154, 51.12218026191958, 54.967350344504084, 55.01428542598602, 52.347485557679214, 48.75147619555074, 51.67468140202185, 48.51363151304184, 48.346475785778416, 48.301388140647646, 51.29062644896969, 52.68031435628092, 51.5569632284103, 51.766002024373705, 49.6540920196041, 49.3618832865069, 44.29461248459355, 40.58331289599019, 39.17325219800396, 39.61944926169611, 39.09541276193435, 40.88249952562394, 41.96223781954858, 42.91257319911834, 43.520842598330596, 41.3944237462936, 42.77058732125067, 38.70931817639259, 39.333355503697554, 38.62011563393378, 39.357262349897816, 37.546296196599165, 39.600135510967625, 37.86567911025017, 38.37538326940229, 37.93442256989018, 36.61902435364262, 39.617656738527366, 47.927550961894376, 52.773580474238244, 55.073301407598684, 48.20909084812288, 49.494090695534986, 51.51986152895036, 52.36161785741007, 55.08058524900868, 52.23961645557035, 53.35138090195195, 54.48717378800916, 47.83280611038209, 48.853171487008375, 44.27456917301301, 38.15636988609068, 57.42506042603524, 52.26279766328874, 51.838259927688114, 51.070416742755526, 47.23981826536117, 46.2903065835276, 46.565288266827984, 45.317150854295306, 44.35169866008144, 43.35093336720621, 42.530185253389426, 40.78853130340576, 40.619496760829804, 40.805958394081365, 40.02960366587485, 40.19503747263263, 39.30476926988171, 40.94917589618314, 39.9120423870702, 39.31269637999996, 40.72110183777348, 40.70454551327614, 40.55173781610305, 41.91773068520331, 42.144408379831624, 41.08913390867172, 38.2799010122976, 40.77162981033325, 41.77989075260778, 41.17411598082512, 40.58105361077094, 40.62024985590289, 41.47165129261632, 42.99002432054089, 46.92981373879218, 52.84440279006959, 54.20907382042178, 55.275397608357096, 54.45838359094436, 55.17117238813832, 51.428960600206935, 51.10622798242877, 54.00331020355225, 54.80479947982296, 54.776625094875214, 49.25790909797915, 43.04747919882498, 47.09286666685536, 57.66794143184539, 60.11692423974315, 59.154551106114546, 59.33912215694305, 61.30102111447243, 62.69348213749548, 54.36441144635601, 26.792953629647535, 8.540124604778907, 9.325697883482903, 6.914093792438508, 5.161189504208104, 0.384042879506465, 0.044307564610555294, 1.9330239392095998, 41.44384561046478, 49.55722908819876, 35.29577747468026, 19.918266419441473, 33.99064802354382, 48.991195771002005, 57.2379163003737, 59.8457904015818, 20.941330386746316, 0.1658138323334917, 0.030600234918716936, 0.008555490865312036, 0.0332927830787676, 0.034871874151811484, 0.06659583173572056, 0.029403789442092664, 0.033787775469282945, 0.04103165390270372, 0.1020684375637962, 0.05295323838870372, 0.032966218948844946, 0.027035949563968088, 0.06021620007231832, 0.04343950655311347, 0.14090178684601862, 0.26406250954155003, 0.12282765830957121, 0.11878965482596429, 0.110964848089122, 0.12700142789511912, 0.18752093366797895, 0.11417946793259152, 0.3108621773219878, 0.22755667326911805, 0.1860099478114036, 0.2346634564380492, 0.14318696583711332, 0.16254490451706996, 0.1013239456581012, 10.696553511004295, 44.69180345535279, 63.66419030774025, 53.01728125541441, 38.723474010344475, 34.79737366399458, 39.00953638938166, 45.232435503313624, 57.931669835121404, 22.3998539293966, 0.19114520370719895, 0.16453847980066655, 7.808045591077498, 37.617291096718084, 22.353983771416452, 21.726824237454323, 25.552219690815097, 49.17932833394697, 63.14770829293036, 59.22954290143905, 55.26747442060902, 54.57815316415603, 53.774824296274495, 57.809562529287035, 56.267337568344615, 52.76504931911346, 48.148713804060414, 54.4845183434025, 51.393800473982296, 49.841138086011334, 49.56502283773115, 51.99100486693844, 56.018027797822036, 54.66809703457741, 53.715741634368904, 50.76346382018059, 50.1208972161816, 45.24123337961013, 43.251120813431285, 41.2357795623041, 42.55338999532884, 43.02223874676613, 44.781166814988666, 44.37858650761266, 44.946255453171275, 45.67982104516799, 43.19854536364156, 46.29855140562981, 40.90024825065367, 40.87507055651757, 42.38368472745342, 40.32401284863872, 40.51422426777501, 40.0340594783906, 38.46704121558897, 40.804083501139, 39.148776608128706, 38.02844962766094, 41.56352104679231, 51.10687125113703, 54.77778219407605, 56.49872210717971, 49.7274128852352, 49.792120225967906, 52.08705979008829, 54.949197615346606, 56.13865244773127, 53.98062713684575, 54.92735001348681, 56.26266210309921, 49.36662150967506, 51.20440490784184, 44.674199858019435, 40.11043194801577, 59.89225479864306, 54.706983412465746, 53.64298166767244, 51.93322443193006, 48.9739961777964, 49.12125764354583, 49.34140066946707, 47.49422711710776, 45.95113138998709, 45.82950261331374, 44.76200211432673, 42.72455830727854, 42.982528671141594, 42.376294982048776, 42.682816443904755, 42.15000560206752, 41.13756733555948, 44.63051249904018, 42.21558763134865, 41.97242421488608, 43.14184358043056, 44.27913481189359, 42.07868906759447, 44.727669608208444, 46.54313864246492, 43.29465912234399, 42.16717773868192, 43.65573683092671, 44.21441962642055, 45.85195426018008, 43.402006549219934, 42.529102679221864, 43.77418848776048, 45.96256117666922, 49.396196180774325, 54.93498294584213, 56.12395924906577, 56.882020042788604, 57.4536858835528, 57.73162503396311, 53.1660371441995, 52.33535366673624, 53.98376111061343, 57.48831648980418, 58.05303581299321, 51.926795667217625, 44.43621397018433, 50.248774328539454, 60.15282961630053, 64.35439409748201, 62.790423516304266, 61.43289119966569, 63.514191027610536, 66.65843748277234, 57.59600516288512, 34.19766679886849, 18.543609034630563, 14.522743244324962, 10.747734558197761, 10.11007974224706, 0.6544938575356238, 0.14230817105741272, 2.670025282329129, 47.715021256477606, 59.14611801024407, 45.31824519557338, 29.880772867510398, 42.18779371630761, 57.734449140487186, 64.09555688981088, 69.81480798413678, 27.90174884180869, 0.5080555992261057, 0.2446674155972658, 0.1423388298961424, 0.17995360908248734, 0.09404759658800979, 0.1148800323567083, 0.10974483008706763, 0.14633128179177163, 0.16434214678743195, 0.22240977283687363, 0.11245257551631621, 0.06934703733291357, 0.18368592816254786, 0.14648092940690058, 0.17363813345230397], [0.012657440665568556, 0.03362021671848432, 0.011236855099278112, 0.04017702153613491, 0.019975403631706874, 0.06122056049324813, 0.04620552062988282, 0.08217390791903581, 0.014803594808214375, 0.030423596110795776, 0.02347434934739384, 0.04357600809946176, 0.05763863596404272, 0.04070322434868544, 0.03552252794766138, 6.643420342476138, 27.72895666860765, 41.96986290716356, 39.54294735385526, 25.594228275360603, 10.995087066004354, 27.243849692806123, 30.884042593740652, 41.313830806363015, 14.312073722962412, 0.04438980031878718, 0.0891811686057237, 1.3304428347656805, 8.232331314394552, 8.729417208702333, 19.766606015543786, 19.24334418389105, 51.97065953285464, 54.928534569278845, 54.21175279924947, 53.583934307098396, 50.40732829801498, 51.21332829998386, 53.003792224391816, 56.664618753617816, 53.02343153184461, 50.635927954027736, 48.145050310319476, 44.32011181308378, 49.34660957705591, 49.072651632370494, 48.21073824359525, 48.32305531347952, 51.193485029282115, 48.22208173813359, 48.59029816042993, 41.80417022397442, 40.85414863401844, 37.89200605884675, 36.331542076603064, 35.650791198976584, 37.3779990596156, 39.79475175180743, 40.97149810483379, 42.63693647999918, 39.57851932894799, 39.482307510991255, 38.87519128860966, 37.13734596006332, 39.989607257227746, 42.657124919276086, 37.708352842638575, 35.94707527468282, 37.435210750949004, 37.635887053705034, 36.65386284551313, 36.64272723659393, 38.01299548918201, 38.07141527052849, 48.74349809462025, 49.41469407850697, 49.70374530361545, 51.734266127309496, 45.93911717014928, 47.82281975592337, 53.54418500777214, 52.31791873132029, 53.19068139599216, 50.554421101847005, 50.08488593562957, 44.14387972124162, 47.80474155179916, 43.06857762798187, 33.82842663795718, 56.83266093654018, 49.269903705966094, 50.70200812432074, 45.25058038773076, 46.08730039288921, 41.8774087198319, 39.254876721289854, 39.68520387526482, 38.53044240705429, 38.92384829059724, 38.94321695450814, 36.904412085010165, 38.08487684495988, 38.86938618075463, 38.9577022675545, 37.379391501026774, 36.77024349089592, 38.01347009597286, 39.409194530979285, 38.91978079272855, 39.284773026743245, 40.24717753933322, 42.84802667556271, 42.39668738457465, 43.364332183714836, 40.632813207564816, 41.72069434196719, 41.85242714420442, 43.92059879918253, 43.45326408263176, 40.39164627751997, 37.230255142334975, 38.185756283421675, 40.93064269711895, 44.84860020299112, 47.47948292763003, 50.711037420457416, 49.72391805341167, 53.161926500258915, 54.01450857039421, 52.23606278819423, 50.66770699716384, 54.4140451185165, 55.392119499944876, 49.03836227232411, 46.54306019506147, 40.787617391155614, 45.625704103900546, 54.264453764884706, 58.30085900522048, 57.79641082209926, 56.12872100645497, 59.55075756196053, 57.898612099309126, 58.327523277651885, 42.81384321951097, 17.043982974944576, 8.581300666255336, 4.03835024564497, 1.261392449659686, 0.0948417003476812, 0.056469493861039805, 0.5168831997340726, 28.62911512774806, 48.1143303071299, 39.786812874578665, 28.16560668330039, 39.430567526048236, 48.608839204234464, 52.035547302615264, 51.6488447496968, 12.261541947241753, 0.12385986985698824, 0.020037981523801724, 0.036716744108426, 0.05150458910652707, 0.09768762505583226, 0.03924396474875751, 0.027422958031116475, 0.01627006042268007, 0.011233021786826993, 0.018966982944778377, 0.030336595335674864, 0.05359736511543874, 0.09675198655215003, 0.017335131396389297, 0.05126349357587676, 0.010872699992520916, 0.12741732936833175, 0.04492580139588925, 0.013562347552168274, 0.00555615465629906, 0.13224379820448737, 0.0833913135612684, 0.057574675283244545, 0.07126600331356449, 0.04648823771745928, 0.02959339237291246, 0.033612046390771866, 0.053878040578697, 0.10650663005728876, 0.06513811197252044, 9.207812028546488, 34.988812784994806, 50.759106066919145, 45.358680909679784, 31.847408087022846, 18.303528601123443, 30.959830630210142, 34.87880599114203, 47.26610206788587, 17.203950958867228, 0.008894335384660912, 0.20588718685171298, 2.0513593958270167, 13.408377285926575, 8.177526487458138, 10.978587615874506, 19.877520838091453, 53.30017043698219, 57.82429102928408, 55.78807100172966, 55.87819922354914, 52.46469382316836, 53.909549866953206, 54.98129437046667, 56.55397261342695, 52.828787834413596, 51.57138186116373, 49.88932832594841, 46.186599116171564, 48.343906633315555, 49.656665094437145, 48.62276754071636, 50.127682916579715, 51.79521583741712, 49.49098417835851, 49.88263676243444, 45.35042039809689, 43.04940508257958, 40.609118169353856, 38.11083901313044, 38.80048582630773, 39.017137942775605, 42.207731123893495, 43.501395487016254, 43.95204051848381, 42.03493502832229, 41.48869791338521, 40.400938372458185, 39.8652014424724, 40.99785251002158, 43.5343159398725, 39.55453403534428, 37.190109683621316, 39.052007813607496, 38.82932701418477, 38.75521775214903, 39.25952865231422, 38.91091231376895, 39.192369830223825, 51.24836683273316, 53.16519383461245, 50.936671764619895, 49.637378800299864, 47.61800927500571, 49.346138892635224, 55.670913727052756, 54.64038156693982, 54.298099856222834, 51.73063401252993, 50.67939173790717, 46.6249632066296, 48.394505208538426, 44.119000127238614, 35.907125934477776, 57.81173159999233, 51.14664408468431, 52.696686329380164, 48.50294305432228, 48.4541723035997, 44.44138757644161, 41.9386016168902, 41.091048025315814, 41.66914655316261, 39.51807952696277, 40.22756961084182, 38.375642145833666, 38.8870878373423, 41.196344052591634, 39.739109008542954, 39.3908574504237, 39.256288774551884, 40.43725167551349, 41.82609627323766, 40.922876404177764, 40.782318269052816, 43.369984319133145, 43.879158958312004, 44.887337530812914, 45.97301429317844, 41.93174923619917, 43.91660582634711, 44.6794754459012, 45.31575449051396, 44.91979514398883, 42.56720066070557, 39.34204747599941, 41.374105868800996, 43.28409617946994, 47.397572071321555, 50.85269774160078, 53.19825157042473, 52.94933795928956, 54.476771662312174, 55.18227661809614, 53.793828179759366, 52.63326552606399, 54.774518782092684, 56.90985710390153, 51.98067726627473, 48.892712900715495, 42.93706840084445, 47.72574109415854, 55.498305905249815, 59.63647311733615, 60.26462893332205, 58.64745924549719, 60.665844255878085, 61.86048053926038, 59.559092598576704, 42.83060350725728, 13.452382356889787, 3.8366668743471948, 6.950338454015794, 4.434021297962436, 0.5768895185282154, 0.15090016888514643, 0.5534168909634314, 31.77531296207059, 50.99515430388912, 41.26461682781097, 28.492497013461207, 40.39130895368515, 54.992786915071555, 57.610816032655784, 59.96955686999906, 16.808201459146318, 0.0984152630271931, 0.02647886383197, 0.06975830397418431, 0.04198207024244532, 0.10352679317997349, 0.04599830150724419, 0.026929057315893234, 0.03310988724772488, 0.10542167335628502, 0.06419326126154873, 0.014785122513140162, 0.013933923178082033, 0.07456405779286739, 0.03434287894877695, 0.0846804020505759, 0.1563121357391919, 0.17711263330232713, 0.1954951428718144, 0.12632416786565898, 0.08144701305296152, 0.197154933646802, 0.17069681547582152, 0.17952289912969838, 0.13944609721581783, 0.10807582327435095, 0.15304627227446727, 0.16947993077337745, 0.12846362161179706, 0.17380828158028666, 0.20421346859826198, 11.105805770043405, 43.19905919413413, 58.08532084188154, 51.664738193635024, 37.504295456794004, 19.624957461510938, 39.50071911658011, 42.83282749114498, 56.06277027437764, 19.002061543926118, 0.17309759713469014, 0.3923061796494069, 2.7345217956650645, 14.877340216790477, 13.339523999921738, 26.32355574638613, 22.286197370098485, 56.429504040748846, 59.21213542261432, 59.12464695592081, 58.971082241304465, 55.30517624270532, 56.73643735147292, 57.84369499452653, 58.27385348658408, 53.15878468175089, 51.06182282970798, 49.81345399733513, 46.48961005672332, 49.925029739256836, 50.65842274696597, 50.0987946602606, 51.59360601056007, 53.38769812737742, 53.160628195731874, 52.67581539769327, 46.941510246646025, 45.73054513623638, 43.560407546258745, 41.04924732638944, 40.53548351410897, 41.04878840907928, 45.453790541618105, 47.09607516565631, 47.91138295204409, 44.47605348402455, 43.607421075144124, 43.426713558935354, 41.13778306591896, 43.82644230319608, 44.83202818901309, 40.86392710285802, 39.47960499794253, 41.83256426165181, 40.224439559444306, 40.72459274722684, 40.67206436587919, 41.35628261873799, 41.203529834747314, 53.165958696796054, 54.381105053809385, 53.51803848820349, 50.17254306424049, 47.88092182528588, 51.008078513606904, 54.540753364562995, 56.66143378903789, 55.379567915393466, 53.153207071365856, 52.60465183565694, 48.47103065060031, 50.79953785865538, 44.65876925376154, 38.677994128196474, 58.97000358950708, 53.53618729499079, 54.83876720551522, 50.70747983071112, 50.20138032974736, 45.78988275220318, 43.622326081798924, 42.88050390058949, 43.433875806870006, 41.63062103333012, 43.03067576500678, 40.3899125899038, 41.52572901018205, 42.57767338906565, 41.65968579630698, 41.08676479708764, 41.18349436790713, 42.105522001943285, 44.016288941906346, 43.5372773293526, 43.61992559125347, 44.907945663698264, 48.0255788372409, 46.32692583145634, 48.535843895327666, 44.50093700039772, 45.913362887597856, 47.51374875345538, 48.462432815182595, 49.3899792240512, 45.87814392582063, 41.7843936335656, 43.18420910066174, 46.88277275331559, 49.95156849584272, 51.586969360228515, 54.83765325238628, 54.9909943919028, 57.1794847519167, 56.61993511261479, 57.22885954764582, 54.144990136546475, 57.77563010492633, 59.54005733613045, 54.52980210704189, 51.63961933505151, 43.79453382184429, 51.71400316299931, 56.69254995161488, 63.128727943666526, 62.97785789735856, 60.82373534479449, 63.22094286641767, 64.14478263547345, 62.177282533338, 48.58401452341388, 23.453730075590073, 18.85721233583266, 12.638669994569595, 5.351425928454246, 0.8928879170167832, 0.18858066309363614, 1.2102992880728938, 36.55819231464017, 61.890639643515314, 51.75828672224476, 39.283490411696896, 50.995260207883774, 63.372550318318034, 64.68712875919958, 67.32096502857824, 23.110289304487168, 0.3269992372201335, 0.12638065152831618, 0.22063943557441237, 0.1795556570493406, 0.17666090189689593, 0.17499797016141877, 0.10148234965820467, 0.2601493937113593, 0.14417788524541164, 0.12668068220298137, 0.08263398202196245, 0.10812605565954601, 0.2251086239853213, 0.08562914065776334, 0.21608594684831559], [0.032382739572635585, 0.08595910238763017, 0.01110982144206402, 0.05060720903378341, 0.017374230608824762, 0.04477638360713759, 0.03971253093632479, 0.09309285951237525, 0.12460983163046262, 0.02192498823147147, 0.023265933212373528, 0.07010826059887487, 0.05121808371416504, 0.08174366527988065, 0.27380993649844204, 5.568560006157045, 28.544372320175174, 44.103079226709184, 41.161289830361646, 30.473576361133208, 14.37909330091169, 28.036568549371538, 35.66983822853335, 42.65779172220538, 11.004035953552494, 0.0388298750734858, 0.17304724983630643, 1.7362762579033453, 3.1273050029431624, 6.149023232921478, 17.183023152812837, 22.928905179423673, 53.2908038170107, 54.44253329307803, 53.72558678350141, 49.44252329487955, 49.79947467004099, 48.85445017968455, 54.13392905266055, 53.91205626149332, 51.68571110694639, 48.93169733785814, 52.22802192934098, 51.24261271569037, 52.53199385058496, 51.93025912007978, 51.80856758548368, 51.50199513281546, 50.831199230686316, 48.66725506321077, 45.60633936235982, 43.52560043334962, 42.56707906723023, 38.9545996727482, 36.26168466383411, 35.560941465439335, 38.26672184851862, 39.072278622658025, 40.01339250995267, 38.38934298484556, 37.64370433745846, 37.82083465207008, 41.259541280807994, 37.03371301774056, 38.21446803308303, 39.10257500986899, 39.60107295743881, 36.798535546948834, 36.67103498212753, 37.84198799440938, 36.56290308121712, 36.55136739054034, 36.776550662133005, 41.61698687461115, 50.29496023731847, 53.072092456202355, 57.22181104844617, 46.913861459301366, 41.5930643389302, 49.281278579465805, 48.9674928880507, 46.711067076652284, 49.35948279596145, 46.647862003695586, 47.188160650191776, 44.27215299298687, 46.965868165416104, 43.48387425945651, 34.290058228277395, 53.95280576521351, 51.887179728477236, 50.22936251855666, 45.999831538046564, 46.12066015120476, 43.04313321267405, 44.12141630726476, 44.30231994198215, 41.98283810769358, 38.819438718980365, 38.347726637317294, 37.422145335905014, 37.84212527736541, 37.76215599429223, 37.224928563640965, 36.720303873861994, 35.39351117226386, 38.29804981908491, 39.08130399642452, 38.104551453744214, 39.218092733813876, 41.32372694630777, 43.36535592232981, 45.747258355540616, 46.23219666942474, 44.00997000355875, 45.687995264607096, 45.82963989626977, 45.440293665855165, 44.072218018193404, 39.204172242072325, 37.82665152703562, 37.478678457198605, 39.80356139521445, 43.910957613298976, 45.37191106427101, 47.52557077715474, 46.50171841344526, 49.636790444774014, 51.81087786151517, 52.472836663646085, 52.782135163584066, 59.460017450394176, 52.86712508047781, 53.36640357971192, 49.85849065165366, 46.4852209245005, 44.74044084548951, 48.49473353355162, 52.25640419990786, 58.11280488967896, 57.491148441068596, 55.43483803349157, 59.41505139873874, 57.751280030896595, 45.63702014184768, 29.018826138588693, 5.397395616577518, 5.580282009417012, 5.066210781374286, 0.6825270984442003, 0.10449063138014848, 0.034517964513431636, 22.636317937604844, 50.70292203657089, 43.538473652255156, 23.89581649534164, 28.02600952886766, 49.53792710458079, 54.380854022118356, 51.826971346332186, 11.904606261560994, 0.4136978672637094, 0.01682457784491201, 0.04315577822947695, 0.015135728397346554, 0.02516967128030956, 0.07379855209540936, 0.04494640533061278, 0.004981172631584829, 0.032448515881814306, 0.0990692493055136, 0.04904337460175157, 0.044798217112979585, 0.014302185473723278, 0.08068572083908705, 0.050450904114592465, 0.017130294807195183, 0.06575955483581751, 0.039365914454984094, 0.0477314030661458, 0.05345828951366487, 0.031072905422338558, 0.07025456040977471, 0.07713202281945175, 0.11596652123356059, 0.045746181971363487, 0.06333868635157425, 0.022933186752901926, 0.040858303527197534, 0.07939487034755369, 0.11244446264519808, 7.235721772716892, 36.74865084309732, 51.165695036611254, 47.54041694825696, 34.929322196591286, 18.36063438846219, 31.872175893475934, 41.09992042664559, 47.29384106974448, 12.499218948425787, 0.039232626647478154, 0.22225059508796663, 2.326676686925273, 4.851404630368756, 7.864253155646786, 6.05161460176591, 22.2352457815601, 55.949586360685295, 56.572552880933216, 54.93186073918497, 50.90348459059193, 51.96207738691761, 51.03833959948633, 53.9115071296692, 55.535764540395434, 50.428124704668605, 49.081586791623025, 52.0321701418969, 51.68870779775804, 54.165402150923214, 53.08782900533369, 52.138846843473374, 53.00687520734726, 51.680784610009965, 50.705248002083074, 48.22612962415142, 43.92133228240475, 44.13874533868606, 40.554491319964015, 38.18454034866826, 38.72273660475208, 40.882758402055316, 40.770370729507945, 41.55742568354453, 40.15593928675498, 40.17335853269024, 39.80453806538736, 41.954091056700676, 39.234605912239324, 40.63116973446262, 40.81965138835292, 38.867919214310184, 37.70428142239971, 38.0604051774548, 39.26313331050258, 38.40437350734588, 37.37967391167918, 38.437082152212824, 42.55506484739242, 50.74804498303322, 53.811047384815836, 53.95336666414815, 49.05938617644772, 43.979583401833814, 48.783090499139604, 50.819024193671446, 47.83870143275107, 50.17885808021792, 48.44076171998055, 47.485892080491595, 44.57738007268598, 46.40247460334532, 44.10779391565631, 37.301285343785445, 55.31608435415453, 52.485937380021625, 52.38424208856399, 47.964260424337084, 45.43694788409818, 46.68591683910739, 44.360567139041045, 46.342234842238895, 42.70422866267543, 40.81195569807484, 40.88257797302739, 39.90192267202562, 38.665673963485226, 38.82769138582292, 38.74526669902187, 39.027995063412575, 38.399639206547896, 39.97143883858958, 39.75722251399871, 39.74470230840868, 40.87503525518602, 43.13341440693025, 45.21959366336946, 47.84223548827633, 48.613879449905895, 46.67176492752568, 47.1617042633795, 48.18339147875386, 47.90882164432157, 46.92449500483852, 41.519241409917036, 40.099394398350874, 39.804710649674945, 42.891902308310236, 46.58034624591951, 48.59178081635506, 48.99888361653974, 49.136103814648045, 50.80434276211647, 54.504596956314586, 54.41997574221704, 52.12132561591364, 61.377432807799316, 57.79190009640109, 54.652435010479344, 50.39681634595318, 47.686180068600564, 45.690635019733065, 51.87058810264834, 55.98598595588438, 60.30764948937201, 59.19490052807716, 57.31674025135656, 60.499010162968794, 57.267161492378484, 51.498508145732266, 30.840588615786647, 7.161596330904192, 7.79819897105617, 4.19118098674282, 1.0788743918941868, 0.04446245992796556, 0.06098992972364349, 24.048024069878366, 56.17796244159822, 46.77998704295005, 29.545637715247373, 35.70478654676868, 56.42684075140185, 60.62118022672592, 59.677610935703406, 17.211199498945668, 0.5212556005966279, 0.007988201320967487, 0.0796326717001296, 0.021530136939198263, 0.028660728205596248, 0.08074831788338001, 0.0471827270643365, 0.0768920994033256, 0.02341995901998974, 0.03786027972255984, 0.04295826544083896, 0.047584321845563195, 0.018281355319965272, 0.015362363060816162, 0.03567286504192218, 0.08587598950872499, 0.18397693432146506, 0.0712737714451167, 0.21068842841252206, 0.13944661815560636, 0.10880218953975748, 0.11232273893490916, 0.14930062326452426, 0.19597514292165158, 0.07776668069944268, 0.1579755271274236, 0.15340026618251879, 0.28453388041065586, 0.16831468039702985, 0.44438621570025727, 11.186384001085836, 46.37020918630785, 58.52526172514885, 52.716153052545366, 44.164083849999216, 23.999586720620435, 37.14018183369791, 47.06557089282621, 54.113752380494155, 14.307246265872834, 0.23091685747908008, 0.4420817619369876, 4.321893972735252, 5.075620547417672, 14.033997289596067, 28.894430129758774, 25.122196520528487, 57.24222698519307, 57.5839360298649, 57.62715270442348, 54.657086941503714, 54.46792279520343, 53.85984166975945, 56.87815650816887, 57.91356809677617, 51.96894545708933, 50.39339211679275, 54.75612678835469, 53.12319309480729, 56.25260122360722, 55.148465787210775, 56.119201414046756, 54.94856219137869, 52.84195915345223, 52.917468701639486, 50.74649564681515, 47.19236150864632, 46.895551835336995, 44.17808278914421, 41.53171846943517, 40.1516011453444, 43.09237857018748, 41.7713439080023, 44.28877992014731, 43.65135946581441, 43.09199810028077, 40.78488349914551, 45.178793168837025, 41.67369650256249, 41.66940542959398, 41.4934596707744, 41.66964861654466, 40.03314948851063, 40.48864256951117, 41.42017018410468, 39.419106360404726, 40.348810072868105, 39.69069519350606, 44.82219872936126, 54.34365034103394, 55.54014190550774, 55.593454760889855, 48.18316398128387, 45.5263622345463, 49.242658922749186, 51.44470891644878, 47.467923702732215, 51.70236549069805, 49.01067426127773, 48.53434554992184, 46.02595452339419, 48.75722246785318, 45.50055696118263, 40.0043200677441, 57.56691294331705, 56.13975463374969, 54.90489052188013, 49.76862522863573, 48.17496230525356, 49.44400202843451, 47.297363358159224, 49.19775955138668, 46.664763496768096, 42.7014555469636, 43.119995978570756, 42.09182508530156, 41.69529307273127, 41.378738187974506, 41.21998809999035, 39.40579775841006, 39.28091341449369, 41.445006632035785, 41.99315786361694, 42.18640127489644, 43.66109086621193, 44.81886471471479, 47.697445115735455, 50.22428697155368, 51.6328061780622, 47.6711142447687, 49.38053807904644, 50.20667160710981, 50.98603479323849, 47.887134859638834, 44.00207819477205, 42.85197650232623, 42.67270457360053, 45.781237848343395, 48.98430416660924, 49.54242998553861, 51.38033889955091, 51.6801570307824, 54.57857678013464, 56.10502204587383, 55.84472963886877, 50.71836048556913, 61.69985163596369, 58.797081978090354, 57.76974262729768, 52.70114998663626, 50.238399659433675, 49.62764739990235, 53.297381631789676, 57.57582064597838, 63.45693226783507, 61.94003405109529, 60.37277652371315, 60.743346368112874, 59.36999513256935, 53.08226708442935, 35.24455524259998, 8.887349482505552, 17.17929886233422, 12.43065199544353, 1.23776029194555, 0.4055090308670075, 0.21767754047628374, 27.8240055038083, 64.84232125743743, 54.71065082857686, 33.78069139296009, 38.77762625294347, 64.20725030283775, 67.45256054785945, 68.28720169682657, 25.9630879663652, 0.987413177086461, 0.11887200927782444, 0.1992383557221582, 0.06346175071573065, 0.15242362665312906, 0.2465074362173196, 0.12026255845182365, 0.1258393031575026, 0.10093165501471489, 0.24206358999494584, 0.13385023861642809, 0.3079921055224634, 0.07835797800291931, 0.20319829484628094, 0.09636587823831266], [0.07273953513152177, 0.013164075677313153, 0.034887965828661, 0.03387862966666299, 0.024069099792189175, 0.04353381197659239, 0.06415925844902955, 0.027328499390052694, 0.017456255642877474, 0.0747413841647006, 0.10702757750667873, 0.08332896166511121, 0.12487482910435047, 0.07405097806645979, 0.6549094449127875, 7.925198943384233, 30.482997894287113, 50.60132088199739, 33.95445239159369, 22.22274518782093, 11.776616381060693, 24.271110834613925, 30.87596251118568, 40.78311843256797, 7.1253869706584565, 0.05176697805103275, 0.14894365693532652, 2.981554630302614, 6.505894689790665, 3.2666131277238173, 4.055859215797917, 22.654398102914136, 54.81102035891626, 56.45851781291347, 53.15797667349539, 51.961877346038825, 48.29546536168745, 49.600308479801306, 53.64979090229158, 53.19665124339443, 50.6091263986403, 52.02267800607989, 54.917646069680494, 52.25177580310453, 51.14058010039791, 49.8813816039793, 50.306911699233524, 51.98295616334485, 51.86047623234411, 48.379745329580004, 46.105802212992025, 43.337126624199655, 38.25235420657743, 37.61077603986187, 35.891436453788515, 37.30589020636774, 38.397430912140884, 35.564561813108384, 36.67395322553573, 37.400874322460545, 37.83469630825905, 38.14630900659869, 37.363325472800966, 36.60622173740018, 38.44056521692584, 37.24153195658038, 36.861469976363644, 36.1740981378863, 37.74537609469506, 37.627112711629565, 36.50669159427766, 37.03111248631632, 36.592524820758456, 44.4636627166502, 52.067083158800685, 50.62367054723924, 44.23261157927975, 45.929177884132635, 52.30404530802081, 50.061402705407914, 48.42668825580228, 46.93802718193301, 48.86904531909574, 47.17254177216561, 47.81850907110399, 44.63754138638897, 44.68393910315729, 45.565413351981874, 34.20937507383285, 54.515705108642585, 50.08048111392606, 51.953095159223004, 49.800361125699936, 51.0469295901637, 49.94114675829488, 48.81845458861321, 51.56443142121839, 52.08043098449708, 45.50792709473641, 40.89509817861742, 36.9336651217553, 37.428472118992964, 36.408220491101666, 36.3720013249305, 36.50678180879162, 36.22757181044548, 37.034364131189164, 38.59891522315241, 38.38570694769583, 40.65166411861297, 40.16991076930877, 43.27939718000351, 47.08126037351547, 47.68775293903966, 47.86338490824546, 49.721380279910186, 48.11544426025883, 46.5721014238173, 44.45863423808929, 40.97869173172982, 38.54395104992775, 37.666638435855994, 38.891178869432025, 40.043018171864176, 42.0793362586729, 44.14364437903128, 41.95192590836556, 48.348240852355964, 53.27285897347235, 53.317691664541925, 53.61080646514893, 50.12717693082748, 55.41277077890212, 53.407584544151064, 52.39033745181177, 53.778872182292325, 53.50544767995035, 48.31685404623709, 51.04101857831402, 53.91232690503521, 58.669255856544744, 60.78364087689308, 59.140289368168006, 65.34343542591219, 47.69750395128804, 25.677676700776626, 4.707424227268466, 5.33404492562817, 3.6332316744712094, 1.0040187763590966, 0.07295279868788297, 0.04784712830798761, 14.50466896257093, 52.95030286235195, 37.12748512145012, 30.366372100768555, 31.568476576958936, 54.07787838289815, 51.28431143299226, 59.308088364139685, 19.94587794426949, 0.5519461860099147, 0.010128982793239337, 0.09798965521997983, 0.08808300454890536, 0.06774950652353226, 0.023344305922247233, 0.02400308791097374, 0.06985670796805812, 0.015873771757938932, 0.08648961061431516, 0.01680049204057263, 0.05768258642825869, 0.04836568556305382, 0.028584071532672936, 0.04616350836811527, 0.002889331010538304, 0.04294085226232006, 0.05068361864335114, 0.05369777242923456, 0.01643552966866522, 0.040170678328121864, 0.05780077464277706, 0.016734382483146844, 0.05020581343541703, 0.03755565635078857, 0.05137411667214287, 0.15668319808619638, 0.06464920232012387, 0.05226592345523739, 0.593765700055707, 11.372383775249606, 38.4784710022711, 55.59745557846562, 40.370861637976866, 29.44930822618546, 14.130019853191992, 26.822598903409897, 37.27367970251268, 46.36171725488479, 7.578299622381888, 0.132608333482377, 0.9424785656794425, 6.037757848539661, 6.892047130292462, 7.458718322938489, 5.887592357973899, 21.67606092268421, 56.43357938335788, 57.57318873559275, 56.455874135417325, 54.273439914949485, 50.74602888476465, 51.37149003244216, 56.58497502726894, 53.701460284571496, 52.081560627106704, 51.282966060023156, 55.53632543933008, 54.54814703233781, 54.312573402158684, 52.38333994342435, 52.84887036969585, 53.726508540491906, 54.4388109637845, 52.01995195881013, 49.914372659498646, 45.66798333198794, 40.775454121251265, 40.26467523267193, 39.45943224814631, 39.49771850339828, 40.52734851837158, 38.81013093456146, 38.5114267564589, 39.97337256708453, 40.00167246787779, 38.62537160996468, 40.645847243647424, 38.452665728907434, 39.86181251464352, 38.718551435778224, 38.784965007535874, 38.23406419446392, 39.596287665828584, 38.81891704374744, 37.23531499985726, 38.524099934485655, 38.77557093097318, 46.15597717223629, 53.854530780546135, 51.34708896760018, 46.80759660659298, 46.87300212921635, 49.908457725278794, 53.263421750837765, 48.75308828969156, 49.50209233068651, 49.570663206038944, 48.30875827420143, 48.726859400349284, 45.28093561049431, 45.977650534722116, 43.58613829458914, 37.2464309969256, 55.53186962681433, 51.35168598544214, 54.093414891150694, 51.76550780573199, 52.36632077924667, 52.157046641072924, 50.32312677752588, 53.23980908240042, 53.71997387178483, 45.83264835419194, 42.392004074588904, 39.43745913044099, 39.248157701184674, 37.76336800667548, 38.10967406918926, 38.200751504590436, 38.92900620737384, 40.642560297443026, 40.817866709924516, 41.55259724586241, 43.82746211944088, 42.025333066140455, 45.27911955310453, 47.75615515247468, 49.61584891042402, 51.237878414892386, 50.6980896765186, 50.702231699420565, 48.296987241314305, 47.16510103594872, 42.93424037195022, 41.050828041568884, 41.30342083592569, 41.24744469119657, 42.47681748482489, 44.59969051422612, 45.70745414303195, 42.45961789161929, 51.076712146882095, 54.806678295135505, 54.59815725203484, 52.5792387993105, 52.407497821315644, 58.20602001682405, 56.16176697515673, 54.810388857318515, 56.343964992030976, 55.69504414835284, 49.546081712169034, 52.97273881973759, 55.720268910931004, 59.78062806590911, 60.594766985985544, 61.557736319880334, 63.359465291423184, 46.08872813563193, 28.68432248792341, 11.232525783200419, 10.509011264770262, 4.723193626249991, 1.601008051826108, 0.11625554322475389, 0.08437103276411373, 16.94162480292782, 59.858855816625784, 43.24221311076995, 32.051863593439904, 35.87688446044922, 58.67795175121677, 58.45541215712025, 65.68726647284724, 23.795523451220607, 0.6542352262523867, 0.0680666899068221, 0.05175486620094988, 0.08990776469750751, 0.03505411880811857, 0.018809747228759433, 0.01881864150956033, 0.10176610096447891, 0.016877612196690133, 0.10597166319888447, 0.040681061425036004, 0.0616494816307339, 0.02624199136100229, 0.0682954514218915, 0.03489832716783689, 0.22437520205013214, 0.14461415699653088, 0.1243583019822836, 0.207100409653879, 0.10658880830892634, 0.18125329256778766, 0.15296249289906796, 0.10900608384080472, 0.13454819068072305, 0.23404036648571494, 0.13312251637539557, 0.22363853190214406, 0.2812146972264013, 0.18595331859204078, 1.0209669701514705, 17.337801840997514, 47.68309708564512, 65.25189515083068, 46.04526827412267, 32.615088493593284, 18.216224485828032, 33.31413722807361, 44.089401921918316, 51.50221478554511, 9.394068717956543, 0.37134414478655786, 0.7803927470118769, 5.226615619274878, 10.271098921375891, 9.64494743654805, 7.904056387562906, 26.03003498046629, 59.156174967365885, 60.305570633180686, 58.100108177431174, 57.020926860071, 53.07188064821305, 52.891545757170654, 59.31028096906601, 55.15864826017811, 52.07716365014353, 52.724746965592914, 57.08896037070983, 56.83674412388956, 56.35968192931145, 55.25280083379438, 55.92377324258128, 56.17869200245027, 57.36574242191931, 53.63313651853993, 52.065729941091234, 47.95697658292709, 43.29773818292926, 41.844378440610825, 40.50860743368826, 41.715869826655236, 42.55954419412921, 40.248420930677845, 40.94075456742318, 41.30479758785617, 41.70481266513948, 41.68817397086851, 40.72305125574912, 40.081994764266476, 42.68575037679365, 42.48963971291819, 41.11056573929326, 40.60361900637227, 41.96228096562047, 41.309853523008286, 39.35075906015212, 39.84162799773678, 39.97582404844223, 47.841066621964984, 55.796943403059444, 51.64543621001705, 48.14121030992078, 49.632687645573775, 53.70183290973787, 52.746939736027876, 49.42959908516177, 49.812057633553785, 53.040572289497625, 49.50021743774415, 50.69826226080618, 46.32479598445278, 46.95319498738935, 44.47583775366507, 38.179288295007524, 57.33446936453543, 52.691959873322524, 57.63141632080079, 52.90660373626217, 55.83772036337084, 55.48407162389448, 52.007165032048384, 53.34491683590797, 57.19970849252517, 49.066391529575476, 45.730533369125865, 41.60428231762302, 40.92208016303278, 39.63267549391716, 40.41757706672915, 40.548117468434, 40.33002584211288, 43.179008037813254, 43.15221432716616, 42.1625336523979, 45.49594033148981, 44.13336384680964, 48.88776286955803, 50.70442038197672, 52.88139074079452, 53.2604407495068, 54.032924098353234, 52.263319338521654, 50.85342338008266, 48.07616172298309, 46.26039458859352, 43.134669565385394, 42.7028872120765, 43.81772287430302, 44.12769994428081, 46.513795391205825, 48.22644733613538, 45.34425835455618, 51.664130226258315, 57.366585731506355, 57.16348148161366, 53.334059715271, 53.05257866459509, 59.35157960461032, 58.77890571471184, 58.24780502626973, 58.32312630068872, 60.019378815927816, 52.329619161544315, 56.62464195682157, 58.557562443517874, 63.0563170679154, 62.20087951229465, 63.928001080789876, 61.824029953249045, 48.74838144548478, 29.233352330423173, 10.337668407347895, 9.632771418940637, 10.419901878603044, 2.6662769673332094, 0.2872676498466923, 0.24640114917870493, 19.106751565010317, 67.80273406736313, 47.66057875848586, 43.27392155124296, 43.339534959485455, 66.4230089802896, 65.05960095313289, 74.96237754821777, 30.655370373879713, 1.2788370684269936, 0.15297099647502746, 0.2095531933610478, 0.1672960286058726, 0.13231070832379405, 0.14595421331544078, 0.12539656562430243, 0.09915012520767989, 0.12666221182312698, 0.30614761094893184, 0.10098685931053855, 0.11690785177052022, 0.223560314325075, 0.15832029733686678, 0.2164763912198044], [0.049722706899046905, 0.04287087396087666, 0.08090236284319433, 0.09389699902385475, 0.04474131210196403, 0.05632370349860961, 0.049621169605562766, 0.028328251792117957, 0.05463406210765243, 0.013466611459490754, 0.06619711361464954, 0.0521336468837915, 0.06307135613995694, 0.0788234300430744, 0.5648645121724375, 8.44244876215535, 35.937438011169434, 53.48004248834426, 33.32383332713958, 21.04381407460859, 18.817429696359945, 25.92833576663848, 39.905943101452245, 40.6718643250004, 4.626462094245419, 0.09234024707468287, 1.235930996556436, 4.968301067429205, 5.510315260579509, 6.827493252292757, 3.691137625325111, 22.799145329383112, 52.300868188181234, 55.628987512280865, 53.5424199411946, 50.66471030635219, 49.41636500820037, 48.8474016804849, 52.81058411444388, 53.88510173366916, 50.08994579315186, 49.93552207946778, 51.21455207947762, 50.60714560170328, 50.32002810508975, 48.26100341735348, 47.151882648468025, 49.240234897982695, 48.58445382887318, 48.40191456579393, 45.30069651142244, 40.75185714229461, 37.772644412133005, 37.5921251696925, 37.06220119230209, 36.984836363023334, 36.81822584521386, 35.971076257767216, 36.74910191566714, 36.804560307533514, 35.79266332810925, 36.15731823828913, 36.62311930810252, 37.20608941970333, 36.31808834691202, 37.81549630626556, 36.256860148522165, 37.66954883452385, 38.12304542910668, 35.93056209625737, 36.37954404277187, 37.13078775713521, 38.194314895137666, 45.00085484596991, 50.25357530963037, 46.28211275223763, 48.23085608020906, 53.7835515699079, 50.092828735228515, 51.03365236713041, 49.622885642513154, 48.638037327797186, 48.44814362064485, 47.803003941812825, 48.94611597061158, 47.594843756768014, 44.522784602257516, 44.95632025503343, 34.185840852798954, 52.651061319535785, 54.09517211298789, 51.20137291569864, 52.298153908021995, 51.530848087803015, 50.428909178703066, 53.812384913044596, 54.11559197210497, 53.30900361461025, 50.63037780023391, 44.624872130732385, 38.34944463545276, 36.7626380151318, 36.97268486022949, 36.83900264001662, 37.444816635501006, 39.80445177324357, 40.836054740413545, 38.20619575438961, 37.73004747206165, 39.756700838765795, 39.86849231104697, 41.636163342383604, 44.590571003575484, 47.519840194332986, 49.70705970641106, 50.41510243569651, 51.1988429869375, 49.396231482105875, 46.06958696919103, 42.534629298794655, 39.094247817993164, 39.04491616833595, 40.11933180593675, 38.606948237265314, 39.880247654453406, 39.73655162319061, 40.98198652267456, 48.61517775443293, 51.4181976164541, 55.16311976217455, 44.449977567118985, 50.314795663279874, 53.79214548295545, 57.87932972754202, 59.188640425282145, 55.24603474524714, 53.56524029085713, 52.590554837257635, 48.833453732152144, 52.87684863613498, 53.25510240370228, 56.457568599331765, 52.33533797725555, 49.24773446975216, 59.691480436632716, 34.442026538233605, 14.622346931888213, 6.615188592864621, 1.9623084774901791, 1.6387584132532922, 0.1581875189778305, 0.0403570138939446, 11.481863010314203, 52.20062025131718, 47.53056003201393, 36.91246471097393, 31.669346209495302, 52.27889114810575, 52.656842893169774, 52.574865356568374, 22.230262410256174, 0.8242842531011951, 0.024215640920785167, 0.011466686264611782, 0.11979725196837418, 0.03979142650120682, 0.054242572026147004, 0.06974078354335601, 0.03171732326248481, 0.04684461798939494, 0.05589235386240387, 0.034764575877136765, 0.03059934434150496, 0.07012107724984808, 0.017570423811013182, 0.08033013346815303, 0.05196735217806794, 0.008174470332901805, 0.04964198804490509, 0.01685946357376393, 0.03611565237083743, 0.020969990685942675, 0.05695242802762697, 0.03174189361743629, 0.09087395478761004, 0.06554975399687406, 0.02959287334834376, 0.02815343052779715, 0.03537808973041754, 0.042802175026266806, 0.6467921611282134, 12.651586359547032, 42.65413999557496, 60.75903584880214, 37.03454456021709, 23.65987220118123, 17.45199772619432, 25.075720356356715, 39.51030146691107, 44.89084412974697, 5.183901498394628, 0.115938137675966, 0.6550185971202389, 7.800332740429909, 8.462088069608136, 11.059782639626535, 5.652570311100253, 24.65234560351218, 53.7979898145122, 55.91909385496571, 56.7474631340273, 53.033402196822635, 51.728225677244126, 50.723592927378995, 53.157862924760394, 54.06831172204787, 51.42519512484151, 50.97815082919214, 52.108499465450166, 53.665146981516195, 52.73419987770819, 50.396714364328695, 49.06699165221184, 52.14251033721432, 50.30929257792812, 50.09362105400332, 47.74877717418056, 43.80544585566367, 38.36333767060311, 37.58999924505911, 39.259458049651116, 38.65973157267417, 37.76945160281274, 37.4097781027517, 37.544746860381096, 38.48031059388192, 37.86016818015806, 38.803859064655924, 38.12256297757549, 38.05345081513928, 38.645850304634344, 39.625485789391306, 37.11463151439544, 39.22398805618286, 39.55552247262771, 38.290071718154415, 38.68902383312103, 39.34110218478788, 40.4556122902901, 47.02215809975901, 51.77728276098929, 47.81071139920143, 49.61500952320714, 54.69252555601059, 50.325311537711855, 52.94621183026222, 52.4726640793585, 49.93791080290272, 50.76058087810394, 49.80006694793702, 50.0020533223306, 48.99536132812501, 45.95885845922655, 46.14656740619291, 35.41129912099531, 54.56161252913937, 56.03128933137464, 54.55380701249646, 54.38826730174404, 53.00533763823971, 51.9144166669538, 54.681915544694476, 54.90271360643449, 54.80720781510877, 52.399076492555686, 46.592132968287316, 40.62672961142756, 38.52736726883919, 37.55797309260215, 40.60782378719699, 38.59637744965092, 40.9692152853935, 42.14970750193442, 39.64756873346145, 39.06763845874418, 43.075853624651515, 41.438946570119555, 44.30368492680211, 47.95281887054444, 50.39700854209162, 50.32760612426266, 52.3235002640755, 52.43387576072447, 51.368363903414824, 47.267710239656516, 44.95132707780407, 40.82994368768508, 40.96911330376902, 41.775309424246515, 41.44752479368641, 40.65613562060941, 43.1209530368928, 43.50259965465915, 51.05092648536929, 53.86988685977075, 55.220774681337424, 46.68916848398025, 50.070314330439416, 53.41704530100669, 58.495035940600985, 58.217634154904275, 58.47131344579882, 56.00486824589392, 54.10988492350425, 51.63048021255001, 53.53247673280778, 54.591477455631384, 60.77727487010341, 53.9125544025052, 55.995281973192775, 61.110797928225615, 30.780641071258056, 13.61803581637721, 10.85350715344952, 5.46128612372183, 2.7802659475034286, 0.15619294777993234, 0.18987663871338292, 13.077984279201878, 57.90067526601977, 44.56932352435204, 42.21015907103016, 37.84895412383541, 57.495596408844, 58.817599896461736, 60.59157025429511, 27.732988865144794, 1.0768625837179924, 0.036036542301336606, 0.07872053677396429, 0.0675642434808035, 0.03787794954053337, 0.04514677945764796, 0.14066975413551255, 0.07797251320293835, 0.07307223945615754, 0.012521122022712184, 0.05578284542406759, 0.02368395866435622, 0.04743528327033405, 0.03355950042004547, 0.0435684621334076, 0.1277131235767757, 0.1479203932948651, 0.14758758937879918, 0.1327005551467019, 0.22784816972430677, 0.13339170435022923, 0.13371120897992966, 0.16482528779775868, 0.23299807322121438, 0.12912905324370633, 0.1529732947388003, 0.12875184687154909, 0.17124446108937266, 0.24828420861834483, 0.8523146748062104, 16.854087306607155, 51.1872249264871, 67.09289489253875, 46.273813016953014, 31.76888615854325, 27.519156932830814, 36.04314196494318, 51.36687732511952, 50.87087792734946, 5.889668272387597, 0.3071686529344128, 1.9828083774735852, 10.339314822227726, 12.286198946737475, 12.835953447126574, 7.291878346473941, 25.296286998256562, 53.449424466779156, 55.48836269686299, 58.72818554601362, 54.91378253506076, 54.82911425252115, 53.83052979746173, 55.78269735459359, 56.74382317450739, 51.48193220938406, 52.97914405022898, 54.77395788315804, 55.4317589729063, 55.44803288675124, 53.34457951207315, 50.681462749358154, 54.907283167685236, 53.24115053299935, 52.90304222414571, 52.269453925471154, 45.52850384866038, 40.9760166752723, 40.56962774645898, 41.35859289476949, 40.938832606038744, 39.755665333040305, 38.725913724591656, 40.32615838512298, 40.28704843213482, 39.71812825049124, 40.23097815052156, 39.72558467618881, 41.0789357462237, 39.70870279496716, 41.1849574119814, 39.19424864553636, 40.584999515164284, 42.05789658331102, 39.85284205405943, 40.16211701977638, 39.97307054458126, 42.58568286895753, 48.4729879133163, 55.882980592789195, 50.54665480890582, 51.83376096910047, 55.92357320170249, 53.334753974791504, 54.25917425463277, 54.10114196039016, 52.111421631228545, 51.58197226062898, 51.319000874796224, 51.28047927733391, 50.31899259936426, 46.375896623057706, 46.18835241563859, 40.22357271563622, 55.84587889332926, 60.161611803116344, 56.757880949204974, 57.88757454964423, 53.739252321181766, 53.039964322120916, 58.57774696042461, 60.05809653189875, 56.10402968622024, 53.959273753627656, 49.24977802461194, 43.35616973138625, 40.106007514461396, 38.769793279709354, 41.71005295168969, 39.939471521685206, 43.46353677011306, 45.332899170537154, 41.141929011191095, 40.95581646888487, 44.05725025361584, 43.12963324208414, 45.604044775809015, 50.587827928604625, 51.758765251405784, 53.196513960438395, 54.303928498298895, 54.911903719748224, 52.239930245184134, 50.52052005644768, 47.847377715572236, 42.41723668190741, 43.55620668780419, 44.45722610719743, 42.97615089724141, 43.69150492452806, 45.094199411330685, 46.256432994719475, 53.067970045151256, 56.15298478834091, 57.168302074555434, 49.561249517625384, 52.55216660038118, 56.221932211229884, 60.480449507313395, 60.59653597493326, 60.06784754414713, 57.75995239134758, 57.309538779720185, 54.39442934528474, 57.65439748764039, 57.30892688997331, 62.53235509318691, 58.0482622884935, 58.655437346427675, 58.423335013851045, 37.52947707330027, 19.518802435167377, 11.021900388502306, 8.272976875305176, 3.8518991537632483, 0.35468908687753065, 0.2058040050248946, 15.104034581492025, 65.13355332036173, 57.896191996912805, 48.63081232193978, 43.46334457397462, 66.01016383017263, 65.92661734550231, 69.87187847014397, 34.944191901914536, 1.7758261292211472, 0.18065883898206297, 0.15827923502412536, 0.19416772700365514, 0.08870788714698247, 0.23147415580047717, 0.21845643739065818, 0.30292798855131675, 0.18103737834720843, 0.2403777675522912, 0.08991097460591024, 0.08681828531646922, 0.2276027151533673, 0.18813409512081455, 0.15762082841848174], [0.06616807888231932, 0.034212885319345424, 0.033028823654017145, 0.03774127179396249, 0.03450153575789544, 0.011514273731248274, 0.033059394392635555, 0.043778002502456795, 0.08655347936456242, 0.06293041511408745, 0.06508648530730317, 0.03046675750444974, 0.047601926546063156, 0.012767372367482994, 0.3912973337836804, 7.797087959704861, 38.824588791016616, 54.823960258114724, 44.43444105886644, 28.69086107900066, 13.07646926372282, 24.798377406212595, 34.953997827345326, 36.24762296676636, 3.503986635515767, 0.0874724631167708, 6.362620313321391, 12.270087811254687, 7.124648094177247, 8.940269120277899, 4.925223146715473, 23.85176435593636, 49.29106097067557, 53.90943611821821, 54.87057370524253, 53.98091346986833, 50.661176250826934, 49.99664437386298, 53.191108934340946, 53.89923403340002, 51.883771188797496, 49.55883333759923, 50.21517922801357, 50.2477898136262, 47.731620727046845, 44.676337549763346, 38.59709132102228, 39.885260443533625, 42.15776405026836, 42.70317746746925, 40.043630061611054, 37.471084748545, 36.8484280955407, 39.10931364182503, 35.20038150971936, 36.49601882503879, 36.37667286780573, 37.08858305408109, 35.446894630309075, 36.283889201379594, 36.461866747948434, 37.69174552732898, 36.586076444195164, 38.17142002044186, 35.929071595591886, 37.70535222945675, 37.203124107853064, 37.53455262030325, 35.62675491456063, 37.74474851546749, 34.868046929759366, 35.49348062084567, 36.329584813887074, 43.10215311665689, 48.300960602298865, 54.48271013075306, 52.16476194320187, 47.93954164751115, 49.40961853150399, 50.609687297574936, 49.872297394660215, 49.93301568492767, 50.58510972607521, 51.7157329282453, 48.85520719712781, 48.7740808148538, 47.45793342590333, 47.11707945792906, 32.21126283368757, 44.636639241249334, 54.696746026316, 53.8128242185039, 56.03359960740613, 54.56773534897835, 53.53346124772103, 52.43813153236143, 50.35529021293887, 51.20305169013239, 52.876805490063084, 48.42353859255391, 38.312425305766446, 37.19046269693683, 37.13368638869255, 36.75711139555901, 37.68455190043296, 38.61165115910192, 38.01903986161755, 40.79222617610809, 38.65351069358088, 37.156914664853005, 38.373951604289395, 39.61738609498547, 39.65645290190174, 44.86319534240231, 47.18324199799569, 49.96917993791642, 50.38224081839285, 50.16969542349539, 47.655813078726496, 45.24483803779849, 40.437604688829, 39.61160452135148, 36.548119668037664, 38.43135156939107, 38.814323948275664, 39.33234353219309, 38.768420450149044, 46.36523954329952, 51.82539455352291, 54.17887549246512, 48.89188920297931, 48.87433267408802, 55.12477467136999, 49.958283593577725, 50.53251074206445, 53.890816627010224, 57.856164209304325, 53.10891174500989, 51.947458713285386, 50.75574459568147, 57.92993222513507, 54.74181013722574, 63.72241397057811, 50.16331372722503, 46.23296545397851, 47.32336867240168, 17.513778978778472, 20.5201207822369, 3.0173114470897184, 1.1026092666772105, 0.09698726747545505, 0.07260153205284188, 7.725738575381618, 51.19333205684539, 50.18947201390421, 28.808704768457723, 26.932525288674142, 40.82916705839096, 52.36461454822172, 53.36811373310705, 27.32265599312321, 1.6821154351195984, 0.017843740999758724, 0.030156053309779496, 0.08591120657060416, 0.028635441558435563, 0.023457173656131473, 0.037747113214385127, 0.04064527362765324, 0.048594941204834374, 0.07101559215375493, 0.04045378229010009, 0.020815470751615304, 0.023126081946576317, 0.01725289760337722, 0.05935460013607818, 0.10188017911728352, 0.038098736080311, 0.008036075591770633, 0.04739799777105932, 0.01702176121574256, 0.02945963916699252, 0.020236390635311123, 0.05042252055699787, 0.03951619409265057, 0.00956312726972805, 0.044130422099823916, 0.06524176366867558, 0.08388611442980268, 0.039362566650754986, 0.4173169891920782, 11.764646287887327, 46.32041077460013, 59.14751829639558, 47.75217002437961, 31.6069628730897, 17.714214055768906, 26.07031576095089, 40.28333002521146, 41.45776217983615, 3.8099650942510177, 0.08690605600995403, 6.421375457317599, 7.803449553828086, 8.466424249833631, 10.945698541979636, 8.096205457564324, 26.528360343748524, 49.89279177881057, 55.20959984871649, 55.635941874596384, 56.05244659608411, 52.7303167312376, 52.1479820436047, 54.58218536069317, 54.46781689120878, 50.3402949917701, 51.50001825824861, 51.85465151263822, 51.88000571343207, 48.92128736742082, 46.53781990851126, 41.09690412398308, 42.31376455676171, 45.44870322750461, 46.994246513612815, 42.78362920207363, 40.29994910763156, 38.87266528221869, 40.91405891603039, 37.31655513086627, 38.13444383682744, 37.68174740575975, 37.46055318463234, 37.19098829453991, 37.60321763253982, 37.54329558341734, 39.36613082885742, 38.61494987241684, 40.48293552091045, 37.22437550944667, 38.340807576333326, 39.29856800263928, 38.09783635600921, 37.003589214817175, 38.83292775000296, 36.50562078722062, 37.06567248990459, 38.460259437561035, 44.872075588472434, 49.82300889107489, 56.29405283158826, 53.64775911454232, 50.33643145715037, 49.405715773182536, 50.77558786638322, 53.025416251151796, 52.32717160255679, 51.57177802055113, 52.94491352573518, 48.79879959167973, 50.28997098245929, 47.57691460271036, 46.893445522554465, 33.06171309563422, 45.78988275220318, 57.430300712585456, 55.53600772734612, 55.77026344114735, 55.281320387317294, 55.0057581932314, 54.0349127400306, 52.25279561934933, 54.40800074608096, 54.82081451723653, 50.9464188544981, 41.23363010344967, 38.86270638435118, 38.692542199165594, 38.977647519880726, 40.53594243141913, 41.597794717358006, 41.11567658762778, 42.391309815068404, 40.240929203648726, 39.58874494798722, 39.323588801968484, 41.52385803960985, 42.670511968674205, 46.58493541902112, 48.420016304139175, 51.234815043787805, 53.49306475731635, 50.71058242551742, 50.838475227355964, 47.41403425893476, 45.04899017272457, 41.034334474994296, 38.36019977446526, 40.55570333234726, 39.78999391678841, 41.00332813878214, 42.00057506561279, 49.569788517490515, 54.38873798616471, 56.81654783987231, 51.39354551992109, 51.41975871978268, 56.64965098904025, 53.44394099327826, 54.89539838606312, 56.73665700420257, 60.321138520394605, 56.75884977463753, 53.37838249821817, 52.125275442677165, 58.921683911354314, 58.67099346653108, 65.66906275287752, 51.047655228645574, 52.94448206501623, 46.267195978472316, 15.668126325453482, 9.40144669625067, 4.588027769519437, 1.3170090846477018, 0.21325203439881726, 0.14859226772621756, 9.590007778136961, 55.97981214523316, 49.00964267792241, 32.41788741080992, 33.83324330852878, 49.048674183507124, 57.87477193340179, 60.86366899551884, 31.036358033457113, 2.254713941966334, 0.07772070010222736, 0.07336156788252055, 0.08084697468626885, 0.03797211706818592, 0.0846733846851895, 0.009665262111793122, 0.09859854956307719, 0.03233567113056779, 0.013701871315377855, 0.015980975229233023, 0.0013681005234942743, 0.043450890619668274, 0.05240415636029455, 0.046231770632608284, 0.21755040052437016, 0.0846576185957078, 0.15444009264390315, 0.14748458119650043, 0.10948833618913928, 0.1754376586646803, 0.07011566866910265, 0.13547589251350972, 0.14690327367955638, 0.11364935041074792, 0.16562204988252732, 0.17886193379038767, 0.16511021121855707, 0.2435113276324926, 0.7826712150727549, 17.45554747120027, 53.21379984578779, 65.81379428986581, 57.34750340061804, 39.1472900298334, 21.789854764938358, 33.960881156306115, 47.53272125797887, 45.37923412938272, 4.541529542015446, 0.20643660978924847, 7.708729707425641, 18.428554150366015, 13.440985910354124, 14.28006325998614, 9.002784836676813, 26.603442353587, 53.40469767970424, 55.97375208331693, 57.609227472735995, 58.139422093668294, 54.78178301165181, 53.8531893299472, 57.51023077195691, 55.1358671342173, 51.61497116088868, 51.96697250489266, 53.64979874703192, 54.08696651458741, 52.219282888597064, 49.254818270283366, 43.32003685735887, 43.803904364185954, 46.59183094578405, 48.10022154162007, 44.7446495486844, 43.33085083192395, 40.300831640920336, 42.587722501447125, 38.35231973278908, 39.97720864511306, 39.31397899504631, 40.4477910841665, 39.436011775847405, 39.64378756861533, 40.07156910434846, 41.08813370427778, 40.0678663869058, 43.24896350983651, 39.453356496749386, 40.91030128540532, 41.04159478218325, 40.50501846498059, 38.37303376966907, 41.83438424141177, 38.16560706784649, 38.88286344466671, 40.14490173709008, 45.78284602011404, 50.04487775987195, 58.30089430655203, 56.55110143846082, 53.99829349210186, 51.73909456499162, 52.63797237027077, 54.62297408811508, 54.095529048673576, 53.950373895706676, 55.1754242374051, 51.65859576194517, 51.8815315154291, 51.25361496402372, 47.84199230132565, 35.92742027774934, 46.19013317169682, 58.75771314867082, 56.8118723746269, 57.365875782505164, 56.93011222347137, 55.27618600476173, 54.27260445010278, 53.43296227916595, 56.83877983400899, 56.89095912441131, 54.15899692043182, 43.388203728583555, 40.992063091647246, 41.758376552212624, 40.75881150461013, 41.810395025437884, 43.29571423992034, 42.91264380178144, 45.47941538595384, 41.29465041622039, 41.29566631009502, 41.96217506162582, 43.0110207680733, 44.18388005225889, 48.67313469609907, 50.827225869701756, 53.65919674596479, 55.15477295844786, 54.409071553138, 52.0768851618613, 50.01259665335379, 46.90798574878324, 43.07298244968538, 41.11655127617621, 42.07375864828787, 43.30825013499106, 44.38523100268456, 43.59922724385416, 52.59518323406097, 57.98328822658908, 59.39934230619862, 53.182001190800825, 53.43827709074944, 58.11489943535098, 52.96186993199011, 55.202249327013575, 57.43286202030798, 61.798001104785556, 60.015170112732925, 55.91015869571317, 54.58552722007998, 61.91508385442919, 61.40174365812733, 67.42458620379048, 56.89276733706075, 59.28037681887227, 45.85332708974039, 19.609622955322266, 29.38923908818153, 7.025780831613849, 3.1471722981622143, 0.4462388920928202, 0.3721225514046608, 10.657666152523412, 64.15543579286145, 59.18128598120905, 39.8817499222294, 37.19666788654943, 54.97854871134604, 65.59460439989644, 70.90127314290693, 39.52917591218026, 3.2684122698922313, 0.17793882848514667, 0.14339460630811032, 0.24024950911200818, 0.1788241962992376, 0.14647299273600503, 0.10957340259225139, 0.21090392894562215, 0.15016283990154344, 0.2781939512539295, 0.1626920087202903, 0.11897543880848155, 0.171861085259626, 0.1310368266797835, 0.19387488223371968], [0.07879729878397719, 0.0777046352384552, 0.025169826413114226, 0.044949921674185225, 0.07990085609978245, 0.007171871914197841, 0.03569937168410228, 0.030662958367517403, 0.034216512745666894, 0.034887965828661, 0.029282389403951746, 0.05159984830947173, 0.04268382210284472, 0.09570805385949151, 0.267033122720257, 7.16499702584359, 38.83152354148127, 49.59660968472881, 37.262312673753314, 19.836345757207564, 11.94922028049346, 27.510806206733953, 39.536491132551625, 33.765935436371834, 3.3941928753929758, 0.04090248764823041, 15.969796795998851, 8.26270418782388, 6.9637612950417305, 17.282423857719667, 4.554123292046209, 21.29681871783349, 27.223710283156368, 35.86480748268866, 51.085662995615316, 52.187566603383715, 51.29983617413429, 51.25230881475633, 53.71434527058756, 52.373781127314416, 50.98567785755281, 48.504696353789306, 52.28746152693226, 50.337788597229995, 49.268032735393895, 44.90852617448376, 39.32270234630954, 36.77875111179967, 35.13936511931881, 36.28706632121917, 34.79521243802963, 35.6661472782012, 36.56594291810067, 37.05960458324802, 37.044813325328214, 35.98593027360978, 36.85527263149139, 35.76771313144315, 37.16002902676983, 40.41547859868696, 40.80135745386924, 41.59100509458973, 40.35244218764767, 38.964240858631754, 36.9766935225456, 37.825023743414114, 37.11445893010786, 36.410197365668516, 36.57508204060216, 36.136090370916556, 35.70704975435811, 37.285368365626184, 38.13554994521603, 39.41107726866199, 42.125239756799516, 45.43970138795915, 44.16504090832126, 45.176702545535186, 46.0006199344512, 46.82779289061024, 49.04650903517201, 51.99226394776375, 50.19866212721794, 50.46745823275659, 48.097954411660474, 49.36851993683846, 46.54999494552613, 47.518804688607496, 35.26847385591076, 43.243723223286295, 48.281795901636926, 49.12463088189402, 49.42742216971613, 45.76501100294052, 45.64102880416378, 48.6253680721406, 49.01334539536507, 48.52542608014999, 51.69483061759703, 46.90952724026096, 38.68767453778175, 36.78609378876225, 38.167285842280236, 37.72679974955898, 37.72344612306164, 38.04692399117255, 37.08195424848987, 38.72787098730765, 39.71657891427317, 36.338657256095644, 37.40429070688064, 37.43939199755269, 40.267405202311856, 38.880749287143836, 41.15893248588809, 42.87096077396024, 44.97183715143512, 47.556726163433446, 45.943757334063136, 45.74580707857686, 43.062964716265284, 42.41354180920509, 39.56420660018921, 38.32366289631013, 38.322533253700506, 37.646775553303385, 38.24037528807117, 42.05861045468239, 45.74117083703318, 49.77567765020555, 50.57154617001934, 49.86046360385034, 54.871322877945445, 50.13731625772292, 40.160689277033654, 49.756222694150864, 51.96780404736919, 58.79544634972849, 53.64479772506222, 52.91501329791162, 49.565458220820275, 57.52090354119578, 54.74234750193935, 62.14210671763267, 44.47303325899186, 43.063874706145256, 25.032968482663556, 10.295352897336407, 3.424655227891861, 3.128059814053197, 0.16822452717010053, 0.18292593829814466, 6.455877605945834, 44.92678088526572, 40.67854804377402, 32.97644076808807, 27.155639510000906, 30.910461718036284, 50.89328250577373, 52.88913742188485, 29.03307414823963, 1.4270769203862836, 0.004626052574284616, 0.02707714977253589, 0.07107410594941148, 0.08450824677223161, 0.01937115369665046, 0.015207769390526078, 0.07418414713033746, 0.07954230396858147, 0.07784245445603326, 0.010040898961315473, 0.007338585574254995, 0.05474451283413557, 0.06034874094409808, 0.023974476442221674, 0.03792075853374216, 0.04295060073115653, 0.018666306841036966, 0.018108309464408986, 0.09815935901696644, 0.062500478910102, 0.06472144441138353, 0.060292257281440886, 0.07453063337673103, 0.03778557465862363, 0.03179718601337123, 0.056155493573075345, 0.0273742099412747, 0.08537633930363002, 0.5124716058133111, 10.738041400909426, 46.47311649014873, 55.71230257711103, 45.10850037297895, 25.3495547463817, 12.430233282427634, 25.221540351067823, 44.39012219828945, 38.7020343349826, 3.500792845602959, 0.014462622479655811, 18.054605184062837, 8.382431595556199, 7.71215932984506, 7.6309868597215225, 4.879202958076231, 21.7810215873103, 29.22684119593713, 38.834469241480676, 53.09785066112396, 54.95720709523847, 53.560670729606386, 52.623408609820956, 55.347714347224084, 55.07278757710611, 51.40919969927881, 49.91811460064304, 52.02089332765149, 51.56824788739605, 50.27344603692332, 46.722351735638036, 40.343055955825314, 38.57818549679172, 36.53653690891881, 37.15585170253631, 37.62257452934019, 37.90782105538153, 36.7601590771829, 38.43633297950991, 38.776543678775916, 37.9414475348688, 38.39891749043619, 38.013913323802335, 38.67790783605268, 42.390686158211004, 41.65725784917032, 44.56112969306208, 42.326469113749845, 40.02896431953677, 38.36657754836544, 39.79348482624177, 39.13067094741329, 37.91629729732391, 37.22329685764928, 37.51463090219806, 37.58924222761585, 39.27618695843605, 39.61860202973889, 41.12687887683992, 43.603726202441806, 46.51635277655817, 47.64557569257675, 47.34160377133278, 48.372379118396395, 50.46488515792355, 50.187640267033736, 53.20493528919836, 50.6077378795993, 52.53927376962478, 49.23213520357686, 50.87028564945344, 47.819085659519324, 48.480240375764915, 36.8449136518663, 44.61595266096054, 47.29054235642957, 49.84738642169584, 49.655096146368216, 46.538878948457786, 47.40587965134652, 50.004206703555205, 49.77265742517287, 52.528369580545736, 54.4504290242349, 49.567129150513686, 40.45004644701558, 38.55681250172277, 39.3767604520244, 40.61608429877989, 38.17772326930877, 39.0210210892462, 38.634138107299805, 40.3164073728746, 41.30785311422041, 39.930885453378, 38.61493810530632, 38.09268628397296, 41.341303087049916, 39.81012352051274, 42.03787680595152, 45.23065082488522, 48.304012206292924, 51.07109139042517, 49.6257136714074, 47.12404558735509, 45.23010953780144, 44.166472573434156, 41.05326383344589, 39.51873064041138, 39.42584106999059, 39.742850949687345, 40.205259169301684, 43.86918044859364, 48.725290452280355, 52.59667765709662, 55.42035272044521, 51.813372488944765, 58.18240734838671, 52.25106585410334, 39.58330069818805, 51.1884996967931, 54.97707390016126, 61.31563586573447, 56.59563995176747, 51.7262174237159, 52.396903499480224, 58.29510488817769, 58.92775181801089, 62.920179443974654, 47.13389858122795, 45.26499509811402, 22.195825961328325, 5.35714376357294, 4.392367197621254, 2.672894496110178, 0.17841170391728803, 0.10582672702448984, 6.821183139278043, 49.95601254124796, 45.33727653564946, 34.97426079165551, 29.971993469422866, 36.97308494198707, 57.462060143870694, 61.085800663117446, 34.321849038524014, 2.5638629015414947, 0.009974098967147932, 0.014753289644666498, 0.03018083625412997, 0.024566206585375533, 0.0060022797345394095, 0.03427870376335998, 0.042739313681639975, 0.05729591120935737, 0.07998234487228817, 0.014242716940991102, 0.044319534734372175, 0.04976544311390289, 0.11849396020895052, 0.05719715864547799, 0.16061051718650327, 0.16804840355630846, 0.07656228323016437, 0.11097213358528192, 0.1348781907149861, 0.12206679510493433, 0.12297213483121126, 0.1378384157414398, 0.10852256744739511, 0.11331258582011347, 0.1308568879481285, 0.13493949307068703, 0.17624775067933146, 0.3077501749559757, 0.705451881212573, 15.15010674153605, 53.1757567774865, 61.24692770742602, 52.36495187205654, 31.150818678640555, 18.93388486677601, 37.5213969907453, 53.0478443637971, 43.359409609148585, 4.476694724252147, 0.18761310936702838, 19.659660631610503, 14.244808996877364, 17.099174645639238, 27.588404417037967, 6.954111774121562, 23.919878275163715, 30.180840069247832, 41.92452423034176, 54.16813212056314, 55.53744331482918, 55.595412023605846, 55.00247516939717, 57.4581769974001, 54.80094771231375, 51.67840373131537, 50.547270621022875, 53.830000277488466, 53.89401728107084, 53.93507272966447, 49.76225922184606, 42.560964092131584, 41.667044162750244, 39.149757200671786, 40.12552522843884, 38.84704436025312, 39.456870940423784, 39.80298088442895, 40.569506152983635, 40.515251928760165, 38.59822096363191, 40.40519414409515, 39.68643157712875, 41.57673551190285, 44.070982471589126, 43.83641296817411, 46.01339117173226, 44.15512123415547, 43.19955341277584, 40.72462020381805, 42.07207202911377, 41.06299523384341, 40.335634831459295, 38.976007969148704, 40.13004772124752, 39.66475655955654, 41.25668187295237, 41.71961961253997, 43.24766912767964, 46.083852629507746, 49.76620904860958, 49.530906061972345, 48.72503549821916, 49.11453862344065, 52.183569708178126, 54.24532044318415, 55.3451765737226, 53.20784176549604, 54.61308971528084, 50.25437547314552, 52.709328128445534, 49.90166810251052, 49.88124432102327, 40.42843418736612, 44.912185745854536, 48.87394435944096, 50.351752235043435, 50.011729809545706, 47.29650043672132, 47.0689715877656, 49.81130061611053, 52.12191397143949, 54.569782826208304, 57.402597012058386, 50.4222450717803, 42.306818039186545, 41.09543715753863, 41.607475126943285, 42.54299963674238, 40.996291406693004, 41.79259530959591, 40.6571436697437, 41.977358556562855, 44.027750107549856, 41.66745601161834, 40.23679110311693, 39.83121802729946, 44.91861058819679, 42.932694958102324, 45.46528308622299, 48.23614735757151, 50.36892829402801, 53.75574196538618, 51.3427508261896, 49.823930648065385, 46.86327857355918, 46.44795448549333, 43.24775934219361, 42.369913285778416, 42.460676931565814, 41.08397599189512, 42.17772499207528, 45.781735989355276, 50.940366637322214, 54.97664636181247, 59.05558578429684, 54.81136160512125, 59.51864119498961, 53.719307068855535, 44.06496947811496, 52.46923200545773, 56.26975374837076, 62.00410989023025, 59.38104837171493, 56.46706073514877, 55.70039818363806, 61.36735623882663, 62.84484640244515, 65.84227854205717, 52.621270918077045, 50.50390097402757, 23.327543504776497, 15.769656877363882, 11.464583989112608, 5.803676189914827, 0.5008738620146629, 0.23080177575109467, 8.601470474273928, 55.747313653269124, 52.906827311361994, 45.67481610082811, 37.18109215459516, 42.95119677820514, 64.08846132216915, 68.70375740912654, 41.3427504416435, 3.9058940112590794, 0.15683817767327832, 0.07334774765636652, 0.1448499741813829, 0.1268213053023623, 0.06474451897966285, 0.1828785327773902, 0.12676703563380626, 0.175250074375541, 0.22461009992947503, 0.125492341936596, 0.10471491894174008, 0.15603948504694048, 0.14518412641219555, 0.13311051943850133], [0.08790764702303756, 0.020981928251022776, 0.05898786235540625, 0.06825218277592814, 0.021966876003951318, 0.10303661182162263, 0.008443903455871248, 0.045874528511757814, 0.05655670147990027, 0.05713140914937662, 0.09899405011486623, 0.05678761953247651, 0.07261607240164474, 0.09094467236390037, 0.16480357686598457, 10.849966233776463, 42.439496132635306, 49.3438482284546, 42.83785204733572, 24.849038739358228, 25.98696735597426, 31.811200687962195, 41.43072528223838, 31.2059691644484, 2.8310111213114957, 0.21870037510750756, 14.999221005747396, 11.95358685908779, 3.1025619564517855, 5.197378272010434, 3.494537400622522, 16.373204723481212, 18.27683294973066, 22.012968986265122, 42.63155498812276, 56.281352196970296, 51.43508342004592, 55.29612733471779, 53.65549402852213, 52.76280180100472, 50.64216452260172, 50.036640782510084, 48.00889699689804, 50.09833182058027, 50.766840980898955, 46.222500570358775, 41.06964365128548, 39.31501842314197, 37.93079045511062, 39.931042348184896, 39.49847552084154, 40.33949052133868, 37.95562298067155, 37.850479925832445, 36.09201861966041, 36.62780654045844, 35.567429065704346, 37.15028193689162, 41.339573321803925, 47.10962695460166, 48.19847691443659, 44.64738653552148, 41.13633571132537, 38.82452995546403, 37.19629133901289, 37.92704459159605, 36.90370998074932, 38.02822213019095, 36.94129020937028, 36.019760716346006, 37.03220290522422, 38.1835989798269, 36.34956144517468, 36.27367927182105, 37.69238879603725, 38.64893720995995, 39.83337533089423, 43.43205582711005, 46.71456975321616, 47.98473519663657, 47.72508605833977, 49.299890225933446, 48.85421483747421, 49.85674519692698, 48.94544132294194, 50.100818603269516, 44.86155186930011, 49.2393837436553, 33.71760791347873, 41.687295359949914, 45.32215972100535, 42.82030336318478, 47.20816081570041, 49.623113139983154, 53.1821463184972, 52.8601981747535, 51.52670606490105, 51.661921931851296, 50.62367839197959, 44.47835199294552, 38.23753941443659, 36.94702863693237, 36.817896366119385, 37.51309725546068, 35.76315141493274, 37.52544095439296, 36.69048993818222, 39.52857971191406, 37.6435435202814, 37.930300158839074, 37.82975412184192, 37.62881109791417, 39.002448666480284, 38.3387993228051, 38.40508737871724, 36.56153417402698, 39.86295000199349, 40.54767424060453, 44.48398059414279, 44.48797356697821, 42.38787774116763, 39.52410820991763, 40.56270476310484, 39.03340008951003, 38.698045284517356, 38.91497196689729, 39.87018285259124, 40.88907734040291, 44.21728687901651, 43.61446957434378, 43.93185992394724, 46.58267613380186, 52.23007725131128, 52.93138919338104, 60.81180741710048, 48.313100337982185, 51.83287059107135, 57.18487801090364, 55.60601026781144, 50.97874310708816, 49.26567146855016, 54.721535405805035, 61.2259038033024, 55.78740419880037, 61.6371133250575, 37.71656236340923, 22.48698546040443, 7.223119687649512, 4.72370598585375, 0.35468908687753065, 0.013370861960274559, 0.02826967479420766, 2.421792692715122, 39.98687336521764, 42.67218682073778, 26.974367172487323, 24.436071995765936, 43.04922857592183, 51.664702892303474, 56.948449304026944, 32.2324691280242, 2.489572720181558, 0.0850851109792148, 0.052972202895269285, 0.03733286649108895, 0.052247621614726326, 0.07406623087703221, 0.09636161112857443, 0.06385214146106474, 0.11436411044410161, 0.011119961573351777, 0.07120225713738511, 0.012998589194349706, 0.05365775582650977, 0.024674872326995098, 0.028037686133757237, 0.05040658975861246, 0.015603055437696318, 0.042112998499144474, 0.05716690200290853, 0.05875640421084339, 0.055424726132543824, 0.01128348974405878, 0.04207506948601335, 0.05531282366944417, 0.0872122383706512, 0.07656754625420417, 0.040205834102967096, 0.09055746088345205, 0.033481907204634724, 0.19988085834249375, 13.144826369900859, 49.19355477056196, 53.61689006128619, 48.37142206007435, 26.710932946974232, 26.657312185533588, 34.613179160702614, 46.80137180512952, 36.55424641024682, 3.6224333893868232, 0.2514730649249208, 12.967844124763245, 8.887483823683954, 6.5761742476494085, 6.261694296713799, 5.528697938688341, 18.082824676267563, 17.56181820746391, 24.45223019969079, 46.67935471380911, 57.72886368536181, 53.425619602203376, 55.67067446247224, 54.84070485638034, 52.06516904215659, 50.63989739264212, 49.91878140357233, 49.174503818635024, 51.85194115484915, 51.29365844111289, 47.58039766742338, 44.153207117511386, 40.82001224640877, 39.66268554810555, 41.722129929450254, 40.60515657547982, 42.81174475146879, 39.16050057257376, 39.90851617628529, 38.08022099156534, 37.32110900263633, 37.10937553836454, 38.89749388540945, 43.22358185245145, 49.92985425456878, 50.41463959601618, 46.02745679117019, 43.85107086550805, 40.7338220842423, 40.86222087183307, 38.63220830117503, 38.959126087927054, 40.935310317624, 38.52983443967758, 38.39761526353898, 38.428754960336995, 39.54889366703649, 38.682395027529815, 37.394080777322095, 40.16185029860466, 41.000531488849276, 42.35643209949617, 45.67360801081504, 48.62892173951673, 48.41981626326039, 50.129400914715184, 52.02543150994086, 49.60785119764267, 52.093433641618304, 51.29182277187225, 51.21809397974322, 47.8622317314148, 48.64595267080492, 35.26399058680381, 42.56389802502048, 44.63741587054345, 42.8260104117855, 47.44969644854146, 49.86988121463407, 54.54397755284464, 53.449671576100016, 54.47532823008876, 52.150449214443086, 53.37336578676778, 47.159735233553, 39.57289857249106, 38.23180098687449, 38.81285698183122, 39.2648160073065, 37.54326028208579, 38.756649417261926, 39.50502980139948, 40.863079870900805, 38.98097368978685, 40.92990529152655, 38.98482937966624, 38.71998310089111, 41.38465312219436, 40.80853539128458, 39.637268589388945, 38.556887026756044, 41.46398305892944, 43.38035114349858, 46.65522429250902, 47.274005643783084, 45.32938080449259, 42.51653932755993, 41.89328647428944, 40.625823543917754, 40.707193113142445, 40.79969829128635, 41.695885350627286, 42.38197065168812, 45.621071784727036, 46.84017973561441, 47.22727060317994, 49.5703847177567, 54.38479992651171, 56.47928284060571, 59.141269960711085, 51.01444452039657, 53.778817269109915, 60.3886228992093, 57.83781536163823, 52.47029496777443, 51.22660160064698, 57.38337347584387, 60.78626102016818, 60.39181963089974, 61.95242874083981, 41.08964773916429, 24.966186208109704, 8.209447226216717, 4.054513842828812, 1.806144089468064, 0.16258645712608294, 0.026016206097518726, 3.353087171431511, 45.478430871040594, 50.09947715267059, 34.91102826210761, 29.397393695769775, 46.13057590300038, 56.94291483971381, 62.68310354601953, 37.0522540615451, 2.7553515424651485, 0.011756089384547405, 0.039422045717196125, 0.013481405574918516, 0.03288807798056834, 0.16429233575059524, 0.03507128683850169, 0.07658318976961798, 0.057409610148639455, 0.051725651437957446, 0.006192854160608183, 0.027994970986319166, 0.030266335496919292, 0.03299015153559946, 0.0883725168363702, 0.14824199700547805, 0.08771732013912932, 0.2152367383842507, 0.14726270681187031, 0.34195428473814843, 0.15499483223163313, 0.10435670388922577, 0.14090449879727057, 0.16533776997558533, 0.16829938928206123, 0.14412720086834124, 0.18552476900719828, 0.17540810299256157, 0.1319221332068405, 0.39110026532603853, 16.896982346811605, 58.338470612802816, 62.07334756851197, 55.89669319891161, 36.36201889284196, 36.716950247364665, 42.500112441278276, 53.047985569123306, 41.58336431749406, 4.289204449422898, 0.24050516797409904, 16.547305007134717, 18.965299129486084, 11.637094732253782, 13.548647126843854, 8.656209111213684, 19.673690949716878, 19.405704813618815, 25.916992272100142, 46.80912633096018, 60.30242881467266, 56.08507679354761, 58.594142467744895, 55.53189708340553, 54.41873627324259, 51.89434982115223, 50.156049497665904, 50.26320865077358, 53.58304000669911, 54.500211746461936, 50.23457534851567, 45.414143223916334, 43.98459619091403, 43.28311166455669, 44.76111958103795, 43.44596455174108, 44.58220066562776, 40.92793233932988, 40.563426479216545, 39.34004314484135, 38.8355714274991, 37.98427981715049, 40.67268802273659, 45.8549548733619, 51.63568519776868, 51.97328359849992, 49.369779017663774, 45.610477462891616, 42.995825506025746, 43.05308426580122, 40.59957112035444, 41.101332479907626, 41.18733436830583, 41.15057391505088, 39.74923656832787, 41.9884745536312, 41.62474532281199, 40.443637294154016, 39.0646456903027, 41.74483653037779, 42.781993573711766, 44.72894437851445, 48.3676605070791, 50.78298545652821, 51.93759395230202, 51.398777961730964, 54.364560496422556, 52.10341999607702, 53.669955807347456, 53.33682498624248, 51.6457421548905, 49.11060056378765, 49.97287088824857, 38.40592284356394, 43.07100165274836, 45.162464341809674, 45.467232504198634, 49.20859706017279, 51.83747937602382, 56.643994931251775, 58.45467867389802, 57.60180634836997, 55.42474185266803, 54.71945262724354, 49.2635690781378, 41.864970884015484, 40.87733768647717, 40.83629792736423, 41.51765677236742, 40.992671059023955, 41.09881824062717, 40.042559254554014, 44.495135814912864, 41.698580018935665, 41.45682473336497, 39.432920948151626, 41.35011665282711, 43.110033158333074, 41.70447141893449, 42.304166516950055, 40.49727962863061, 43.79205096152521, 43.92993796256281, 49.26437316402313, 48.812900512449204, 48.19000459486439, 43.812870902399865, 45.61743966994747, 43.387470245361335, 42.657038627132295, 43.36448515615156, 44.28445354584725, 45.24563820131364, 49.15674332649478, 47.178307656318914, 49.03088623477567, 52.02498435974122, 57.070693892817346, 58.789347064110544, 61.25950674856863, 53.35952766479985, 56.010492924721014, 61.19989848905995, 60.786916055986964, 55.628932599098455, 54.73698169954362, 59.78745691237911, 65.62923500614782, 63.75732698748189, 64.08481744027907, 47.30062677014259, 26.68593764305115, 9.215095869956478, 10.355101381578754, 3.677435070276261, 0.49475527098101957, 0.13537335930572403, 3.74750453618265, 50.70749159782164, 56.57786377014653, 39.293884692653535, 38.156750355997396, 56.64017062033377, 65.15688750051683, 71.01255862943589, 46.04824535308346, 4.142162636403115, 0.14812406543041431, 0.1272814253705644, 0.15899417891858086, 0.12837876205242452, 0.24443783436811742, 0.25608351994906703, 0.16627449632412003, 0.17124700450128125, 0.16517303042834805, 0.1702178113402859, 0.07908461239909934, 0.12895741890515053, 0.16251320379876322, 0.17201411898338026], [0.061068296687857765, 0.06264153484916014, 0.026949883416114796, 0.03550026926302141, 0.04881729822485678, 0.019862872976509315, 0.02505571187113322, 0.03176559829303334, 0.0029854283615526173, 0.07330408064468254, 0.02191542170851702, 0.07282081706028792, 0.011154774523850892, 0.06982596485965675, 0.07778007957723834, 9.661621432150564, 43.9599048706793, 54.55465424445368, 47.432108540688795, 24.20159859042014, 18.7906575587488, 26.465594576251124, 43.10414568070443, 28.89145697316816, 2.3579137075331906, 0.22065811279800632, 7.639787677795657, 10.881758024615626, 5.370826951919064, 4.804022398687178, 1.6792806646516247, 13.84107159030053, 39.8323162909477, 47.116087098275464, 52.759722740419456, 54.53933738893079, 52.47191882902577, 53.389365134700654, 51.57399808206866, 50.28907275968983, 48.41962014475177, 48.21616288154356, 50.372093646757065, 49.60723538552561, 47.98102463445356, 48.518824731149984, 44.75640096972066, 41.062097011073945, 35.94702036150041, 37.56999907955047, 37.11161521173293, 38.79508472258045, 36.50116497470487, 36.783685453476444, 34.81178837437784, 36.73653464163504, 33.96951821542556, 38.560009233413204, 41.775666359932195, 49.11896305699503, 48.03880899183212, 47.338473719935266, 40.52566189919749, 38.23364842322565, 36.48883696525328, 38.35138228631789, 36.99181425955988, 36.40794200281943, 35.24219397575625, 37.10531588523619, 37.13891883050242, 36.21484764160649, 35.456288706871774, 36.36769064011113, 35.4625331201861, 38.02487242606379, 39.43054791419737, 44.77213359648182, 44.57521492435087, 48.15627221138247, 47.22347374885313, 48.09941745573475, 48.265125828404585, 47.796516341547814, 48.1479371747663, 49.54603072135679, 47.91720767174998, 48.310554719740345, 34.221048047465665, 40.48222557190926, 48.268746176073634, 49.86538617841659, 53.466165142674605, 51.024191610274784, 51.2637189895876, 49.79334400546167, 49.657986933185214, 48.75705380593577, 45.834119243006555, 40.744024169060495, 38.89590140311949, 37.08029116353681, 37.63837383639428, 37.359120691976244, 37.463326300344164, 36.13902430380545, 38.195993669571415, 38.115514478375836, 39.530089824430405, 37.82173679720971, 37.12650845127721, 38.782340941890595, 39.020201313880186, 36.62129540597239, 39.05285112319454, 36.85459406145158, 37.21054523221908, 37.35276645229709, 38.92489556343325, 39.73069552452334, 40.33152810988888, 39.642371592983125, 39.37529740795013, 37.6732829309279, 38.7250861044853, 41.08391323397237, 41.75365401852516, 44.1833269980646, 45.62733580989223, 45.05922755887432, 44.3450306307885, 46.24144954066123, 51.43729955919328, 52.701977606742616, 52.17229681630289, 51.48733331311134, 54.16599442881923, 58.11789612616263, 55.79111083861321, 51.51955558407692, 45.93805813020276, 51.533864390465524, 55.713863680439616, 58.01878567664855, 63.16076194086383, 49.818509932487245, 15.621710958019381, 7.385825976248711, 0.434278114548614, 1.3038593386450124, 0.18447584142127346, 0.028611658358826276, 1.676600582657322, 34.31301586089596, 46.40877000747189, 38.085296538568315, 24.162233683370776, 37.09523931626351, 57.660304577119895, 53.295443980924546, 36.41530429163287, 2.5342838177757883, 0.028891163622780196, 0.036226922811399546, 0.02054488849675944, 0.026580443260289972, 0.023648661163245, 0.028769595045295936, 0.07263355452807681, 0.03665918409223518, 0.01954661464438804, 0.01905941336806263, 0.018649996829129035, 0.004803564722439455, 0.026009667537084995, 0.03186153931423061, 0.07389959909262196, 0.025480352492342075, 0.017878098127942894, 0.020563941103436296, 0.03395124331056591, 0.038399889073785276, 0.06966278047090577, 0.017415317819423733, 0.028561483430225524, 0.028902388726090713, 0.11394306852091705, 0.03585026802254781, 0.058446184566785256, 0.007624210923114011, 0.15138084309235697, 12.61358153435492, 51.10960122077696, 58.877451342921105, 53.66803776833319, 27.98426570430879, 22.66775377335087, 25.910022220303937, 45.55607811097176, 32.78308556925866, 2.7400251261649595, 0.22066459390184573, 7.4326781976607545, 9.90835028309976, 3.201367931981241, 5.914269868404635, 4.0020308138862735, 18.375878680136896, 41.94140611156341, 52.106397075037805, 53.40816897730674, 57.111231588548236, 53.57388519471692, 55.11378026777699, 51.08319190240676, 50.06317953909598, 48.600331583330714, 50.07612336066462, 50.52616042475547, 53.77542049654069, 49.46126437956288, 48.422816876442205, 45.49300247623075, 42.94614476542319, 38.28964810217581, 40.2308879360076, 39.504574806459495, 39.416341089433246, 38.53176032343219, 38.09598499728788, 36.72364965561898, 37.12902269055767, 37.01785879750406, 40.68703997519709, 44.84355995731969, 52.63728987786078, 48.5287836290175, 49.63207575582689, 42.85916228448191, 40.53953924486714, 38.38089027712422, 40.739725251351636, 39.031991958618164, 38.76894997012231, 36.75117684948829, 38.79128786825365, 38.39872921666792, 38.13713066039547, 37.47565430979575, 37.523385632422666, 37.784733157004084, 39.92351531982422, 40.72323560714722, 45.994838360817205, 48.66843961900281, 50.28670757047592, 49.15549601277998, 48.72757719409082, 51.35611826373685, 49.26267870010869, 49.5177072863425, 48.925303874477265, 48.588223226608775, 49.860047832612075, 35.06538137312859, 41.97989240769417, 46.6399388159475, 50.52187327415713, 56.171012001652876, 53.28357488878312, 53.55781524412094, 52.588609341652166, 52.33667550548431, 51.1479776905429, 49.27529696495303, 43.3819632376394, 39.85720765206122, 39.20272488747874, 39.1139381162582, 38.87783104373563, 38.44954744462044, 37.81514721532022, 40.716869600357555, 40.05258483271445, 40.48737564394551, 39.31981548186272, 40.26063519139444, 39.698845878724136, 39.581453261836884, 38.75612381965884, 41.11875172584288, 38.209380718969534, 38.452465688028646, 39.14824316578527, 41.846335703326815, 42.622168756300404, 41.866375092537176, 40.25927412894465, 41.53505248408164, 41.380044337241884, 40.449967999612134, 41.88337464486399, 44.25421991655904, 45.91123696296446, 47.84551066737021, 45.98278883964785, 45.802344122240626, 48.56553623753209, 53.13709005232781, 55.9861114717299, 56.03710620634018, 53.23785181968443, 54.173905849456794, 59.29388546174573, 58.17273478354178, 54.2550753778027, 49.478361991144, 54.441289901733406, 57.941867997569425, 60.7872220008604, 66.03568277051373, 49.269080008229906, 18.80639018550996, 9.073676774578711, 3.456105527377898, 3.128668516874314, 0.4418531306568654, 0.0586186501107389, 1.64551101865307, 39.20123830918343, 49.63593144570628, 38.42255761546474, 28.433345710077596, 43.81530669427688, 65.60948194996004, 59.49693087608584, 42.32772427220499, 3.8879025895749373, 0.0836051670053313, 0.0190203926796394, 0.044315792394862066, 0.036579599048221306, 0.025759647082116817, 0.033870949635222074, 0.021068842841252204, 0.006542377466816576, 0.050563848457269134, 0.04631201451223704, 0.019826240567190033, 0.02204552259025795, 0.07900821045041084, 0.04112223996931026, 0.12183425677639824, 0.12006119990180578, 0.08499625244087751, 0.11948418247723773, 0.11445225652066932, 0.12924304712683926, 0.13923301752055847, 0.11137681187040384, 0.1438101783635155, 0.19571263523351765, 0.1866367456292914, 0.1512616704548559, 0.18375219476799812, 0.18766704195689773, 0.36200102839258413, 15.784561884018684, 58.91311745489798, 67.6520993632655, 60.73197149461316, 34.00739262180944, 27.93084498374693, 35.32750160463395, 55.90873095297045, 36.94587938247189, 3.3629450682670843, 0.30884142123883773, 10.922701685659348, 16.698433929874053, 13.225628176043111, 12.130114109285417, 3.9159416527517386, 16.830203994627922, 44.62467993459394, 54.98588746593845, 56.036215828311065, 57.683783884971376, 55.16012699373307, 54.27635423598751, 51.70184381546513, 51.90705437814036, 48.088360294218994, 50.980512096035866, 52.92740014291579, 53.39708828156995, 52.03120131646433, 51.82397073315036, 49.68286652718821, 45.21150181370397, 39.10973333543347, 41.00909010056527, 41.597618210700254, 40.26798571309736, 40.57612319146433, 40.0539380504239, 37.70465404756608, 40.611349997981904, 37.98067123659196, 43.091507804009225, 47.298041928199034, 54.480799936479144, 51.21742717681393, 52.78750488834997, 44.51979575618621, 41.57438208979946, 39.29392783872543, 42.40420656819498, 41.18605959799982, 41.215771552055116, 40.36158523251934, 41.625694536393695, 41.49307920086769, 39.708722406818026, 39.0587229113425, 39.73508465674616, 39.566207008977095, 42.131907786092455, 42.64336132234143, 50.05176936426471, 49.41815753136912, 51.99056948384931, 51.071667978840495, 50.91861709471672, 53.955441597969305, 51.945266108359064, 50.945587312021566, 51.66839384263562, 52.590535225406775, 49.23450039279077, 38.302854722545995, 42.78203671978366, 49.03475761413575, 51.96146157480056, 57.13165144766531, 56.17176117435579, 56.929064950635365, 56.04511960860222, 54.87151507408389, 52.738651767853774, 49.83596055738388, 46.3956065331736, 42.76101673803022, 40.85458401710757, 41.745267991096746, 40.85690998261975, 41.847888961915054, 38.842937638682706, 43.40456785694246, 41.8164707768348, 42.106518283967056, 41.57588043520528, 40.50524204008041, 41.99682920209823, 42.31037955130301, 40.46862671452184, 43.25186606376402, 40.40877526806247, 40.56208110624745, 41.500257138283025, 43.435825224845644, 43.53466895318801, 43.57379851802703, 41.98471300063595, 43.12050588669316, 43.564596637602776, 42.565667013968195, 46.14718714068013, 45.35283657812303, 47.466550873171904, 51.556288580740656, 50.018970504883804, 50.091224485828036, 50.6424783122155, 55.19577349385908, 60.0095062102041, 57.83866259359545, 56.29282512972432, 56.47626261557303, 61.35642459315639, 58.63856330994637, 56.89051589658184, 51.075425609465576, 56.88531091136318, 60.702679234166304, 64.29653129270001, 68.84918320563533, 52.90877672933763, 21.187990596217496, 11.395101162695116, 6.889308335319643, 5.160610464311415, 0.5434894946313674, 0.14081382463055273, 2.2319252164133134, 44.65306220516082, 59.77570941371303, 49.864844891332815, 36.267823173153786, 48.87268527861565, 71.82408132860738, 66.71245636478548, 50.70493029009912, 6.069241243024027, 0.16150497080337617, 0.09980740566407481, 0.20512246256393774, 0.09319220579439595, 0.11950292098786562, 0.10649368317136843, 0.18479281796082375, 0.13027179595683852, 0.11729652647890391, 0.13473911511321224, 0.14601234406713517, 0.13295684220089068, 0.19829035255937807, 0.19966639968897068], [0.027974483880004095, 0.10400063388289944, 0.056571927477395346, 0.024443613365292553, 0.0584340037687892, 0.03028701029477581, 0.03660779108383483, 0.05421397396393361, 0.03593174147329504, 0.03951671120199946, 0.016344437984028654, 0.017698431357501015, 0.06532308390183796, 0.12290387639715789, 0.20157408119449693, 10.107600804298155, 45.25097654711816, 54.007836618731105, 40.649675476935606, 27.45773457711743, 32.11992652185502, 49.38182461646296, 48.01709475055818, 28.273775846727435, 2.867724260976238, 0.3092376419132756, 3.448806977079761, 10.301851284119392, 3.6776990948184847, 3.6092007833142437, 2.774828071555784, 9.674411300689945, 39.72560428803967, 55.54953598207044, 50.50964332395985, 52.9977164729949, 52.713332868391475, 52.63841559810024, 50.540692806243904, 50.63515524710379, 48.37754487991334, 51.200635510106245, 49.82881399892992, 49.9031860597672, 47.99128163245417, 46.26356386369275, 44.99146861414756, 41.81894579241353, 36.26132380577826, 38.81444161938083, 37.40692653963643, 36.96385952734178, 34.86104942137195, 34.53367271730977, 34.00239159983973, 35.45757524428829, 34.7849593623992, 40.00832480769004, 43.10522433250181, 49.5811398567692, 48.6135656602921, 46.33417044916461, 42.044050616602746, 37.33604538825251, 36.783269682238185, 35.82155158442836, 35.44856163763231, 36.405423841168805, 37.01599567167221, 37.682661318009906, 35.4356844963566, 38.058965667601555, 35.790925718122914, 36.182715585154874, 34.85731140259774, 37.7637327871015, 38.08482193177746, 43.682616833717596, 46.75120861299577, 49.22259207694761, 49.383915239764804, 48.43083420107442, 48.195276260375984, 50.81600396863876, 49.11589576352028, 49.77937252290788, 50.14643184600338, 51.48641547849102, 34.647711707699685, 40.55773904246669, 53.780158719708844, 49.001892074461914, 50.1145508212428, 49.14967521544426, 48.5430924354061, 43.85183180532148, 42.11286075653569, 39.601418126013975, 38.45133604541902, 36.67798542207287, 38.50667284381005, 38.460832103606194, 38.138385818850615, 37.6618335323949, 38.43147708523659, 36.74559923910326, 39.03638501321116, 38.47219913236557, 37.575662982079294, 36.5960314196925, 37.935128596521196, 39.21678658454649, 37.48888446438698, 38.960444004304954, 38.120758687296224, 37.694773597102014, 36.114427120454856, 35.73839341440509, 36.830977470644065, 38.0988012590716, 39.441197149215206, 40.20697324506698, 38.34250596261794, 37.24808231476815, 39.633612940388346, 41.38691240741361, 41.45817010633407, 47.76557668562859, 48.596801450175626, 45.12282094647808, 47.05827920667587, 50.973918591776204, 50.97781350535732, 55.583664524939756, 57.16036319732667, 57.89642733912314, 55.7000804716541, 57.093922168977805, 58.67841066852693, 53.96496903511786, 47.352504038041644, 48.74201936106528, 56.070516955467966, 59.15668879785846, 60.98005748564198, 52.454738847671024, 25.8907163143158, 8.489261269569397, 1.498025855229747, 2.028383499672336, 0.15649208979260537, 0.02743945956500548, 1.420211424269984, 32.64962692414561, 56.12163720592376, 47.54354307728429, 34.09323369303058, 40.04213171620523, 50.64460031447872, 57.910328219013834, 37.30829461928337, 3.362677366502824, 0.08422641068576806, 0.01949089898487493, 0.04861530382186175, 0.07159114635038762, 0.05718846737797703, 0.037576945934204325, 0.0379466446447036, 0.03936676481258004, 0.043055455185352795, 0.008131959156373577, 0.02644611740364663, 0.05947765300891573, 0.036031340564330744, 0.029294947500250516, 0.016525587134604013, 0.08121215347801486, 0.01570342348948602, 0.024413010067937356, 0.06445388820382857, 0.046600224450230605, 0.09614162132023804, 0.04726593953467185, 0.00826156112335382, 0.09666574803451378, 0.01811579797386883, 0.03799352539522994, 0.05479706646574121, 0.13977016772954695, 0.15703746778590066, 13.576173340120624, 52.05422562937583, 60.02897685573947, 47.38130992458713, 32.377771369872555, 25.515625938292473, 38.56495141983032, 50.444367239552165, 32.68649328139521, 3.0934875530581323, 0.40502805022462723, 4.499635686797481, 7.773989121760092, 4.88844455249848, 9.08087726562254, 5.399245994706308, 11.669160108412466, 41.958084029536096, 55.630964386847715, 51.63428098924699, 52.54440030743999, 53.111296546074655, 53.62771188059161, 51.71001019016389, 50.246114961562625, 49.45177224374587, 51.792960474568034, 50.440691978700706, 52.57187651049707, 49.24029765590545, 50.38017765168221, 45.33108311314737, 43.14334584820656, 39.108788044221946, 40.736603044694476, 38.45234801692348, 39.85053570039811, 36.47526164208689, 37.467801724710775, 37.14854824927546, 37.47341463642736, 36.70622256494338, 41.62378434211978, 43.63999635942521, 50.908744488993, 50.62740072127312, 49.748817259265536, 43.38729766107375, 39.8833933953316, 38.44366781173214, 38.8525592127154, 37.642480557964696, 37.868789549796816, 36.440219186967425, 38.991395427334695, 37.963565780270486, 39.17362482317033, 37.96538968240061, 38.108187490893954, 36.705257661880985, 39.38667228144985, 41.445092924179576, 45.53512873188142, 47.57684007767708, 50.50955310944588, 51.02392881147323, 51.92756052940123, 50.296568409089126, 51.63807784357379, 52.55708525257727, 51.36679887771607, 50.49746828694498, 53.20085210184897, 37.08277402385589, 41.09530379695278, 54.68485339995354, 52.16597003321494, 52.95910073864845, 52.04040319688859, 50.7714811448128, 45.77711935966246, 44.89644135198286, 42.3256258041628, 39.5336474141767, 38.074494331113755, 39.676849226797785, 39.75051918337422, 39.094475315463164, 39.50279797277143, 39.43016744429065, 38.80058388556204, 39.75688126779372, 40.2872210164224, 39.65972023625528, 38.82393767756801, 39.18571749041158, 40.67343327306932, 40.33963564903506, 38.93590173413677, 38.24426627928211, 36.68484956987443, 38.374183024129565, 37.30894965510215, 38.32668704371299, 40.02412019237396, 40.75055883776757, 41.30236179597917, 39.72817344050254, 40.43190156259845, 42.48334038642145, 42.5441018227608, 44.30770143385857, 50.53064369386243, 48.56412810664023, 47.171976950860795, 49.76559323649253, 52.13630906997189, 55.43304551032282, 58.92794009177916, 58.299427340107584, 58.24020739524596, 57.664960430514434, 58.26078414916993, 61.178148946454456, 57.49421181217317, 50.11421741977815, 51.14036829240861, 60.12554953175207, 58.83313640471428, 63.72130001744917, 54.31955129869523, 29.145989379575177, 8.354724953251502, 3.597470690165797, 3.466320359899152, 0.5304980530373512, 0.05329847974222034, 1.5113050394481229, 37.11486685660578, 56.100664292612386, 46.3581871217297, 36.66948172353929, 44.24651245917044, 58.59668808598673, 64.30135580801195, 44.39600967591809, 4.0781493100427815, 0.08662566782966738, 0.06761435329193069, 0.02842164365574718, 0.029447684364934123, 0.06594763708210762, 0.04517818906254346, 0.030292242675298647, 0.011978252009759027, 0.01656212569815257, 0.060677756555378444, 0.0780341602982052, 0.06966703225888553, 0.078965999005783, 0.040143095332408146, 0.1338345644574973, 0.1398842535432308, 0.13873928917511819, 0.10258794476788852, 0.1731852835585033, 0.3316821181966413, 0.167518669078427, 0.13147253152583877, 0.13502691902460592, 0.19445317136424203, 0.15374892811861732, 0.14852966302104537, 0.20989730473487608, 0.23039196467688008, 0.23963250189779267, 19.128597205685033, 59.64965228111514, 66.76606732030069, 55.08808089840797, 39.093941873119725, 42.76457040540634, 60.03582923643051, 58.863879942124896, 39.0012994120198, 4.061439277664308, 0.6805933086622147, 4.338386558717297, 16.22477243023534, 12.645635143403085, 10.48414343787778, 8.057742205358322, 13.116150902163598, 44.065318569060295, 55.08637858975319, 51.57362153453212, 53.28085276388353, 55.116996611318285, 54.74685430526734, 53.66889284503076, 52.467361034885535, 51.157881675228, 53.156898021698005, 52.91817865064068, 54.20465330923758, 50.69497923697195, 50.98324598804597, 47.28933426641649, 46.888440578214585, 40.34619385196317, 42.78306830313898, 40.530137323564105, 41.62224677301223, 38.59982913540256, 39.75418659948534, 38.68231265775619, 40.191530873698575, 39.91846722941245, 44.29848386395363, 47.281936676271506, 53.570386440523215, 51.470965262382265, 51.97258541660925, 46.16268050286078, 41.332352238316695, 39.81600315340104, 40.23628903973488, 38.21340114839616, 41.19393179493566, 40.319321693912634, 41.26479333446872, 39.56475573201334, 41.75654480534215, 39.88268736870059, 39.92188361383254, 38.48128726405483, 40.3272605711414, 43.111421677374075, 48.251581884199574, 51.40192762497933, 52.74461769288587, 55.84721642155802, 52.40159073183614, 53.58413827034735, 54.92407091202275, 56.09366678422498, 54.089523899939756, 54.09365807810138, 52.71808678104032, 40.32373043798631, 43.13262208815544, 56.5575223584329, 54.69820122564993, 55.264493419278054, 56.32302738005116, 51.95902970529372, 48.32760526287941, 45.44552610766503, 44.114881638557684, 43.30343346441946, 39.965468991187315, 42.27083813759589, 41.238670349121094, 42.19668180711808, 41.600630590992594, 42.39093326753186, 40.780125664126494, 42.74541747185492, 42.617850226740686, 40.90899513613793, 40.7729124253796, 41.27661535816808, 43.51484137196695, 41.65302561175439, 41.30799039717644, 41.308676811956595, 40.579312078414425, 40.07368326187134, 39.71196228458036, 39.83465010120023, 41.72946868404266, 43.04100728804066, 43.65955721947455, 41.777341211995775, 41.1182810414222, 45.34934959103985, 44.622181384794175, 45.930032960830204, 51.948278488651404, 53.35875103550573, 48.841902517503314, 51.50506634866038, 56.833759200188425, 57.70094817684543, 61.46002615651777, 60.63933687825357, 62.120741567304066, 60.72753529394827, 61.00715714116251, 63.48500074878816, 59.9727104556176, 50.70508718490601, 54.29675448325373, 63.23589101914437, 63.79886096523654, 67.34103971912016, 55.54896331602528, 30.131437816927512, 12.172626718398064, 7.323044519270621, 9.929185913455102, 1.1985766719425879, 0.15744960776740508, 2.1679432690143585, 41.30182443126556, 68.03549535812871, 58.06417926665276, 45.68912882958689, 51.33987965122346, 65.53825563000095, 71.83096116588962, 52.86798407954555, 6.49704582268192, 0.21911709629479917, 0.11375975900239522, 0.12512331738347007, 0.25039038350505216, 0.2411833396481891, 0.2554715535933933, 0.08127676533354868, 0.1377203156270327, 0.12594481644731376, 0.11051199819532134, 0.14790033711300743, 0.23436990686722342, 0.1979686875617312, 0.13173719958191918], [0.06358825864510671, 0.10004915236946076, 0.027201234948851412, 0.047734501891799515, 0.03340015413179513, 0.006823222905833035, 0.058327659273580204, 0.12648886144762078, 0.03647911512563306, 0.03333980938599956, 0.018311924143363873, 0.04132220806974558, 0.021674098266709237, 0.08115863457562462, 0.22108830181100678, 11.29171827147084, 39.630839824676514, 52.14413419846566, 49.21123289292859, 29.247533659781183, 40.8935566871397, 63.18775177001954, 44.521968749261674, 34.25376453707295, 2.077094556823854, 0.13834912059528215, 1.2748763325714296, 11.89182423776196, 1.231135653872644, 7.037703366048875, 4.401137617326552, 5.515501124243583, 33.980724427007864, 56.53412542035503, 51.45942564933531, 56.66379113351145, 52.84271224852532, 53.36021800195017, 52.985396308283654, 56.34813054915398, 52.1088917024674, 51.715960425715295, 51.163643637011134, 50.27490515862742, 44.43004800427345, 45.126676636357466, 39.65410732453869, 35.5428671836853, 33.90669753474574, 36.77334216333205, 35.821155425040956, 36.824027030698716, 39.592004437600416, 40.917596893925825, 40.006544051631806, 40.27962338539862, 36.7446304136707, 39.37661140195785, 40.78680546052995, 48.59241231795281, 48.7991722168461, 48.00198578065442, 43.340515552028535, 36.716377581319506, 36.51453633462229, 37.97983577174526, 35.57569742202759, 37.746992111206055, 35.079972590169604, 35.212952706121634, 34.75198007399036, 36.79164786492625, 35.94445120903754, 37.15735004794213, 36.25526766623221, 35.51917999021469, 36.7919812663909, 41.54298351657006, 40.26557737781156, 45.51256725865026, 42.713140287706935, 46.86296870631557, 44.14013385772706, 46.395900710936516, 44.554481275620006, 49.33330489743141, 46.615702490652765, 54.663574541768725, 35.550315764642534, 42.20198485159105, 52.27773797127509, 48.67373874110561, 49.93415317227764, 42.33240365982056, 40.714822123127604, 35.785128455008234, 36.65465124191777, 36.7575232444271, 38.083904097157145, 35.982451131266934, 37.08890468843522, 37.57487066330449, 38.44206748470184, 37.40751489516228, 37.587940000718646, 37.244434510507894, 37.24081808520902, 37.57553746623378, 40.5914439693574, 36.28710162255072, 37.702312392573205, 36.18666148954822, 36.424372811471265, 38.3879780000256, 40.40167577805058, 41.48479907743393, 43.72498235394878, 39.032007648098855, 39.04987796660393, 36.39589248165008, 35.789333235832956, 36.646331894782286, 39.076330431046024, 39.71894410348708, 38.621241354173236, 37.66488121401879, 43.56710695451306, 49.69507294316446, 49.320070820470015, 46.507735329289595, 45.98191807346959, 49.88320158373926, 51.69760765567903, 53.72007585340931, 50.96411658871559, 50.04110051739601, 53.50377675025694, 56.16897236916327, 56.99300350681428, 55.56843396156065, 46.08488029049289, 45.68233920681862, 55.95687412446546, 57.3941364595967, 62.586362208089525, 51.93902561741491, 32.781383260603874, 8.270647968015364, 2.3895611061203867, 1.2129872148075413, 0.543222712172616, 0.11942311760879333, 0.7390879214771333, 31.239381874761275, 48.68553723058393, 39.10795650174541, 23.47740746313526, 32.865329827031786, 51.12888751491424, 56.36076842584918, 37.039800536247995, 4.443034414322146, 0.023038269118255666, 0.01958698747799762, 0.03603886354774718, 0.028547471682090434, 0.071408664206824, 0.0738470224783786, 0.06969047454936851, 0.037559613194917484, 0.02696997215670924, 0.03934318462627069, 0.029795392521566925, 0.002345393023138205, 0.0512203321822228, 0.018889897262617465, 0.007909194673336442, 0.06023468194349159, 0.0693859699212255, 0.06488247609306728, 0.0753071554185402, 0.03438707839156832, 0.061061252509394, 0.07210180523895449, 0.03429462690086615, 0.09408357973781326, 0.033094442915171385, 0.05258410658326842, 0.03558516329635055, 0.07180622553512936, 0.42964984031934894, 14.731853623544017, 46.47705062743157, 59.43478484307567, 51.90171603233584, 37.40404359755978, 45.97009997214041, 69.29594116826212, 52.31926802665957, 39.855219010383856, 1.9464378323285811, 0.040302391824943405, 0.7223354171841376, 12.44907634873544, 5.145136713981628, 9.608013418412979, 6.322801391924582, 6.063527330275505, 40.03420460608698, 55.38753424921344, 54.35074983104583, 56.09853444560882, 56.19948840910389, 54.2385268980457, 55.89106852008451, 56.385557805338216, 54.79229104134345, 52.951554098436915, 52.979261721334154, 51.99597843231694, 47.64316343492078, 45.09039471226354, 41.89253337921635, 38.15924890579716, 37.50574673375776, 38.53936972156648, 36.29855494345389, 37.49588981751473, 40.13339742537468, 41.25816845124768, 41.038778520399525, 41.377545787442116, 40.05892730528309, 40.09708412231938, 43.724299861538796, 50.06021030487553, 50.61546494883876, 50.69513220940867, 46.26654878739388, 38.49541956378568, 38.70690591873662, 39.304008330068285, 37.61922090284286, 38.59492617268717, 36.688285566145375, 38.152667168648016, 37.2751231347361, 38.765976813531694, 37.508715967978205, 39.172063719841745, 38.324851374472345, 37.599797325749556, 37.71966103584536, 44.8699967322811, 43.70917520215435, 47.032187600289625, 45.4046981565414, 48.55200798280778, 45.4935908317566, 48.23835565197853, 48.08386525800152, 51.27693345469814, 49.880000929678644, 55.16612429772654, 36.91060550751225, 43.56135675984044, 54.66675950634865, 50.7691159555989, 51.77121877670289, 44.24892079445624, 42.01413077692832, 38.20593687795824, 38.13616575733308, 38.981942515219416, 39.17491920532719, 37.837073264583466, 38.92142426583075, 40.31672508485856, 41.02739187978929, 39.33994508558704, 39.02439432759439, 38.11079586705854, 39.2718723512465, 39.314865450705256, 41.93451058480048, 39.437612102877715, 40.24527518979965, 37.585880756378174, 39.8292136961414, 39.252040847655266, 42.25359147594821, 43.9828585809277, 45.98890381474649, 40.9468577754113, 41.31185393179617, 38.87854491510699, 38.36994294197329, 38.8190935504052, 40.811041785824685, 41.68075676887266, 41.196732367238695, 39.733829498291016, 46.085421577576675, 51.50434855491885, 51.51265613494381, 49.62787881974251, 48.71673968530471, 52.55199793846377, 53.226641685731956, 55.5103789606402, 54.33250688737439, 52.89068283573274, 55.41273547757057, 57.333445625920454, 58.866574610433275, 57.612204551696784, 48.8402747338818, 47.618072032928474, 58.34883743716825, 58.778556623766505, 63.20149575510333, 55.38072109222413, 31.629632211500603, 11.542989227079577, 4.312608251648565, 3.7807848665022084, 0.707852800767268, 0.02770324278953335, 0.8298847235498891, 32.87542012430007, 56.508304457510675, 43.04161133304719, 33.5338487932759, 43.22701000398205, 57.15864912156136, 62.93191125316005, 44.35953947805589, 5.595939130552354, 0.07241266839686902, 0.05950578758793493, 0.05473026359874395, 0.04005753097214526, 0.016617144217654582, 0.07208514282660139, 0.009092980068207029, 0.05801127645217123, 0.027628261933944402, 0.01795016784941958, 0.02019835628509041, 0.02996696748830859, 0.034795725012138005, 0.024838014580910246, 0.08206251873484544, 0.28210158189458234, 0.11457303794281137, 0.19517144008028894, 0.17319711195605417, 0.08234116789554397, 0.19614274763772566, 0.148920796871666, 0.11724908265375322, 0.23283904868989225, 0.11640856162674966, 0.1228205336918754, 0.13985382453087838, 0.19579927977775374, 0.5305231194342337, 19.118877572398034, 57.896850955101755, 66.0242529838316, 60.38243732144756, 41.58881641203358, 51.836671367768325, 69.70120829920616, 54.3421402285176, 45.14513923275856, 2.6609736777121022, 0.3677731025363169, 1.6457868103058109, 14.96378533301815, 5.937826643067022, 13.722016869052766, 10.676193468032345, 7.836578872896011, 40.61481737321423, 58.40147172251056, 53.38219896439583, 58.57207521315544, 57.99212532658731, 57.89082619451708, 58.07663279194986, 58.60640379690356, 56.359693696421964, 55.48305573001985, 54.94122343678629, 54.91296668206492, 49.190283513838246, 48.58096291941982, 44.10664858356599, 39.93503139865014, 39.43361520767212, 40.40615904715754, 38.517643713182025, 40.60472903713104, 43.19322270731772, 43.69281891853579, 45.23140784232847, 45.09675287431286, 41.976072019146336, 43.165479783088934, 44.154956494608236, 53.30359466614262, 54.84182665424963, 51.69353623544016, 48.55393386656239, 41.38237422512424, 39.57693469139838, 41.506980080758375, 39.014698228528424, 41.61246438180247, 39.07616176912862, 39.3959016184653, 37.901647244730306, 39.904605573223485, 40.07766838996641, 41.727295690967196, 39.72407456367247, 38.62637181435862, 39.47472164707799, 46.05315223816903, 45.81646073249079, 50.41230578576365, 46.63770698731946, 51.74518600586922, 47.40047462524907, 50.54075164179648, 50.53877476722964, 55.27291082566785, 50.6580069757277, 57.71089138523225, 41.00574824117845, 45.84747099107312, 55.823101689738614, 53.564381291789395, 53.28749725895544, 47.3290757210024, 44.42260334568639, 40.6484438527015, 41.45450661259313, 41.132389806932025, 42.03284832739061, 40.212193919766335, 41.17748921917331, 41.89669893633935, 41.91482028653545, 41.23152379066714, 40.45326279055688, 41.538017795931914, 40.139331971445394, 40.72589105175388, 46.07556073896347, 40.6293301428518, 40.752476876781834, 39.260721052846606, 41.05990048377745, 41.97132202886766, 44.434076278440415, 45.617596564754365, 49.83251671637259, 44.94651432960264, 44.184323280088364, 41.177195041410386, 39.13926486046084, 41.34937140249437, 42.905791421090406, 44.172834657853656, 42.54003824726228, 40.99045099750642, 49.89581984858359, 55.158609036476385, 54.9176029236086, 50.52847462315714, 51.13646161171698, 55.1512820489945, 54.94799737007388, 57.92054991568289, 56.52512750317974, 53.29354163139097, 58.05747593602827, 59.26465203685146, 60.94703505116125, 60.05362895227248, 51.16003113408243, 50.616014080662886, 62.13471697222803, 62.08529903042702, 67.45120340777983, 55.194675230210834, 36.04484035122779, 12.98723534230263, 5.088208413893177, 6.0236593792515425, 1.8398199663046868, 0.23779113296299215, 1.2600650950785608, 38.05471774070494, 63.56090645636282, 49.99044702899072, 35.55987458075247, 44.73804819968439, 64.47847827788323, 70.75497658021989, 54.46950743275305, 8.354147384243628, 0.1778461471680672, 0.19743437187806254, 0.1866846414463174, 0.20703881618476686, 0.10817302451018365, 0.13114516683403524, 0.16819397558368024, 0.12824999799411144, 0.09024233827667852, 0.10819039172342709, 0.043579133738192825, 0.21189414355303013, 0.29741895835726495, 0.25250329996549314], [0.036610280869588736, 0.03088463931494663, 0.0334141084233359, 0.043131512394475366, 0.04695691498777559, 0.028761472598078753, 0.021720165048816034, 0.04835763397896963, 0.011242061624333504, 0.03630060131751722, 0.049173697648990544, 0.0293070612655532, 0.04905799538978646, 0.03409447110888939, 0.14436994348802876, 10.103332284958134, 41.960080515953806, 51.19957647015972, 40.29907834145331, 25.690789184262677, 41.010713961816606, 45.2861798194147, 31.679932686590384, 40.14684723269555, 2.998874346094747, 0.09207056880357767, 1.560282940345426, 8.938607996509923, 4.273090372162481, 9.915463501407254, 7.662696280787069, 2.8573491015741905, 28.089110659014796, 53.40579202098232, 56.44514253062587, 53.51705789566041, 51.03745314382738, 50.78186365865892, 51.17879575298679, 50.103097500339636, 50.79741193402199, 50.235744214827015, 46.54711984818982, 43.8709847388729, 39.7747358968181, 38.104014089030606, 36.15303501006096, 36.15710643029983, 36.376202183385054, 34.857742863316695, 36.02161207506734, 42.20690350378714, 47.70392487126012, 49.74663249907955, 47.75929697098271, 47.6867566570159, 45.692580515338534, 46.851546764373786, 46.69447937319356, 46.73800591499575, 48.189377015636815, 49.53781727821597, 44.938646055036976, 37.71834704183763, 35.00400020230201, 36.98398913106611, 35.56953145611671, 37.45645038543209, 35.62289922468124, 36.34607838046166, 34.42860810987411, 36.25338885091966, 36.93177061696207, 35.67957747367121, 35.83430320985856, 35.743233619197724, 35.868133652594786, 37.26529759745444, 35.51555572017547, 37.94864900650517, 37.24909036390243, 39.34412240982056, 39.32715423645512, 41.632860706698516, 40.77839982125067, 45.73655420734037, 45.59316412095101, 54.564432713293264, 40.1161664532077, 40.6354372732101, 55.28369734364172, 47.59536935437111, 48.43855342557354, 43.41368736759309, 45.024502815738806, 43.08039572931106, 44.823426431225194, 41.04287347485943, 41.05368352705433, 40.18920490818639, 38.571541001719815, 37.38396106227752, 37.80939309827743, 37.63273739045666, 36.31897872494113, 36.43754020813973, 37.8726452396762, 38.631423827140566, 38.314029555166925, 37.72753715515137, 37.82749483662267, 37.16362976258801, 39.36529144164055, 42.34029546860726, 42.45355390733288, 46.753801299679665, 49.25329639065651, 47.167144590808505, 46.74578789741763, 41.5147267618487, 38.84401629048009, 36.61975391449467, 36.72348883844192, 38.029618493972286, 39.23786540185252, 37.36592600422521, 41.716136547826956, 52.62286732273718, 50.64381976281443, 49.37339152059248, 45.92363165270898, 44.46521205286826, 42.06078737012802, 42.93539354878087, 43.41096524269351, 44.50295309866629, 49.191636731547696, 55.503318694330034, 58.586262426068714, 56.61223157759636, 44.89781418154317, 49.344016890372004, 57.34611095920686, 57.97423539623138, 60.166157830146055, 56.70436413057389, 32.87260386251634, 9.749271696613683, 3.316389721247458, 1.9810064161016097, 0.19691694077224503, 0.08894030290145068, 0.6904419511556626, 30.241548553589855, 50.16302347183228, 39.07108622212564, 22.354842770484186, 21.555655925504624, 48.97819311388078, 53.14054566044962, 39.69388015808598, 4.131235403399314, 0.015317498079140582, 0.018169205793510043, 0.01845031409644552, 0.016781713310328704, 0.024920462878541123, 0.02123259605028697, 0.06315178388068754, 0.05591443251638163, 0.07193777049260755, 0.03486894769594073, 0.05951435628136801, 0.03283788389976948, 0.04341575782746077, 0.04982939613382182, 0.06096945985430672, 0.01957622968832091, 0.01741052976989698, 0.024131093542241765, 0.053110772879013134, 0.036724056417663256, 0.020735276667701624, 0.09100750689544986, 0.012805963089058717, 0.0411385155072616, 0.03267156238096856, 0.060948174101330584, 0.049842021262813965, 0.05985053481474038, 0.11740043864495332, 13.290449265510807, 50.36641013237738, 57.76270197283838, 47.76452156805223, 32.58230140132289, 44.56540899892008, 56.22891403013661, 42.38124893557641, 42.25158322241999, 3.9080839195559105, 0.1554920845815251, 1.874309122081726, 10.434952993546764, 6.26016604323541, 12.898891798911556, 7.3304685854142715, 3.2505220943881623, 31.117478532175866, 55.253934398774184, 58.24249021468624, 56.63491464430287, 53.44060697863179, 53.036167467794115, 54.23745216861848, 52.35827599802325, 52.964231198833836, 53.55247689831642, 47.25839461049726, 47.29068748412594, 43.07452786353327, 40.54353221770256, 38.437454777379195, 37.27558597441643, 37.95439527880761, 36.50220048043036, 38.678131411152506, 42.690806311945764, 50.287084118012466, 50.708134866529896, 50.688628919662975, 49.477067608987134, 48.40699403516708, 48.95072083319388, 49.334281567604314, 49.38579797744752, 50.245012775544204, 50.848869508312596, 46.483789259387606, 38.651318088654556, 36.1774556867538, 39.25375884579074, 38.584269092928984, 39.940761981471894, 36.86028542057161, 39.24162695484777, 37.096706282707956, 37.828463662055235, 38.9438602232164, 39.0020642742034, 38.02907328451834, 37.45328111033286, 36.46037232491278, 39.37118676400954, 38.89244579499768, 39.68212873704972, 38.945346801511704, 41.2228435854758, 40.908116525219334, 44.25616933453468, 43.421273231506355, 48.273629526938166, 48.206886476086034, 55.94298108931511, 41.5562960409349, 43.23008121982698, 57.52384139645485, 50.604392097842315, 48.97982481987246, 45.24048028453704, 46.03527015255344, 43.09407303410192, 44.6544821031632, 42.88365748620803, 43.53354323294855, 40.94955244371968, 40.25514779552337, 37.838355879629816, 40.89470986397036, 39.2053097294223, 38.915964326550885, 37.646763786192864, 38.613471138861875, 40.93568294279037, 39.837552655127745, 38.97127366835071, 38.972854383530155, 40.42847733343802, 40.629373288923695, 43.64320485822616, 44.52705998574534, 49.59642925570088, 52.42691355366861, 49.36697452299057, 48.189675115769916, 42.60657341249528, 39.60507769738474, 39.11343605287614, 39.955914097447554, 39.54579107223019, 40.341000633855025, 40.58639195657546, 44.61425427467593, 54.33904547845164, 52.67863950421734, 52.39166713530018, 48.517130267235544, 46.531053819964015, 45.74562664954893, 47.61667174677695, 46.37942283384262, 46.879254387271025, 51.9350601011707, 58.248405148906095, 59.52251649671986, 58.73229618995421, 46.54066754925636, 51.21506198760002, 59.11938313514956, 60.72582514055314, 61.018308439562404, 58.45206637536326, 33.48368560114215, 11.099765319978038, 2.2459783332963146, 4.070814722968686, 0.32769404832393895, 0.04402054210884437, 0.9162583790959851, 32.18079778455919, 53.959756205158854, 43.60050593653033, 24.596414566040043, 26.088576355288108, 55.136592772699174, 59.722004321313676, 47.61305532147808, 5.7664244597957985, 0.014974422839229867, 0.06412778755710011, 0.027088271453976635, 0.03318163138183375, 0.020043807622465878, 0.021531651878068526, 0.04827784975209544, 0.02423902383945402, 0.028727741746772683, 0.017457500535754428, 0.009573932939900026, 0.11136398755855138, 0.030028135778622764, 0.017204327628977837, 0.20679204394259762, 0.14963342718059017, 0.14110650086114485, 0.13837159761498052, 0.13381205679428193, 0.13000194914638996, 0.1128847410361613, 0.1597630707246642, 0.05834890672216012, 0.11060359166754831, 0.1467035239141795, 0.2529588464887873, 0.1681711001982612, 0.15889509310645444, 0.23832886539880307, 16.87913948489774, 59.2243928294028, 65.3152100501522, 52.70169127372004, 37.10521782598188, 52.11116667716734, 54.23687950257332, 43.53331965784873, 50.264067649841316, 4.113435197261072, 0.32899612200356304, 3.0352687931829885, 11.122291491877649, 7.9641789678604376, 19.310852096926784, 16.871769351343957, 4.809469590263983, 35.0444241492979, 54.91209591588667, 61.215999818617306, 57.62123777020363, 56.88097276995259, 54.416939827703665, 56.88217301522532, 55.008813719595636, 56.51850654232887, 56.05847920140913, 50.38842639615459, 49.001946987644324, 44.37129089909215, 42.11827754974365, 40.85622749020977, 38.98250733652423, 40.707495135645715, 37.408915181313795, 40.294308739323775, 45.90010527641543, 54.40732217604115, 53.60774701641452, 53.33189456693588, 51.28541361901068, 51.1017329462113, 51.30979114963163, 52.57077040210847, 49.74645991479197, 51.86972125884026, 54.236377439191266, 48.684662542035504, 41.01668380921887, 38.29085226981871, 40.893533152918664, 39.88044377296202, 42.3166710330594, 37.96698608706075, 40.47150573422832, 38.6707926565601, 38.73240916959701, 40.8321794386833, 40.17956372230284, 39.10814085314351, 37.73185568471109, 38.63476960889755, 41.04284601826822, 39.16408954128143, 40.96663828819029, 40.85238748981107, 43.37982946826566, 43.67025352293446, 45.928110999445764, 44.76718356532436, 49.5844542595648, 50.961508212550996, 57.468881145600356, 45.83907711890436, 44.25048189778482, 59.39691435906195, 53.21393320637365, 51.236117270685014, 49.53629539858911, 50.283730491515136, 47.43639961365731, 48.07812290806925, 45.1004595141257, 45.914594511831964, 43.91319728666737, 43.43704508196923, 39.91632561529837, 41.48329680965793, 41.72473438324467, 40.33577995915567, 41.035656313742365, 41.93953906336139, 42.82908555000059, 41.70711117406046, 41.400864278116536, 42.155190975435325, 42.198894023895264, 43.19718430119176, 46.74982793869511, 46.45003334168465, 51.92764682154502, 54.56596636003064, 51.47480134041079, 51.19272801183885, 44.287866007897165, 41.504646270505845, 39.05506333997173, 42.07709658530451, 41.79698051944856, 42.06106193604008, 42.12063489421722, 46.772946388490745, 57.39710177144697, 54.91075446528774, 54.59801212433846, 50.98523855209351, 48.657311854823945, 47.675832856086, 48.90540176822294, 48.34309078031971, 49.13409163874965, 53.70483352291969, 60.00488958051128, 63.06910399467715, 61.79254116550569, 49.21970521250079, 54.55372856509302, 61.749312723836596, 62.81184357981529, 64.50349907721242, 61.246488401966715, 36.70119800875264, 12.94941879087879, 8.301248338914688, 6.840295868535196, 0.9656467192596005, 0.26747111050832656, 1.341680302735298, 37.926911231010195, 62.66329165427916, 51.015597697227236, 33.28507246509675, 32.034309025733705, 64.69897039474981, 67.67801838536417, 57.815963837408255, 9.689939964202143, 0.11117272604737552, 0.13031301148716481, 0.12010295169367907, 0.14330658280561048, 0.11078881640588084, 0.12753308525369053, 0.22534439520489788, 0.2049360733719603, 0.16306138567386136, 0.1875397334656408, 0.12009262482845977, 0.15177096570691756, 0.09699765562770829, 0.13994048439687298], [0.009694916417732114, 0.033334914084163406, 0.05989713977361399, 0.021083804538413402, 0.07820202548417353, 0.08265483493526136, 0.02566290741425849, 0.029159978129750783, 0.039818208935039665, 0.05455930724800114, 0.04947525666906469, 0.0300648313901958, 0.0615700000085898, 0.026057174564489437, 0.08133467391974504, 10.720071061964958, 40.27133933959469, 48.75849723815919, 33.0183316815284, 29.632465262566846, 38.95173634252241, 30.209443953729448, 31.072981203756026, 42.752061966926824, 4.3582254167526004, 0.054439012291691, 0.5500809764189105, 10.15466042103306, 7.486618632270445, 9.0215386690632, 5.009387894984215, 3.0048010474251163, 26.213476388685166, 52.00638840275427, 55.745866298675544, 50.09589210633309, 49.66905978418166, 44.37658609882478, 43.89580157495315, 41.80424474900769, 42.379205380716634, 41.76148699175927, 40.093138217926025, 37.35302925109863, 36.60680224818569, 35.161000913189305, 36.593936874020486, 35.166417706397276, 35.281766768424745, 36.10057330900623, 43.858786167637, 50.11342117863317, 49.0156086029545, 48.77522222457394, 48.59600913140082, 49.38697076612904, 47.84922907429357, 48.28056819977299, 47.87621890344928, 47.89384211263349, 47.046057101218935, 49.32359703125493, 46.33201706794001, 38.408342945960264, 34.27502378340691, 36.6141253132974, 36.284995309768185, 37.56239752615652, 35.63543119738179, 36.714326181719386, 35.500250631763095, 36.364380159685695, 36.154152885560066, 36.08493874149938, 34.977885061694735, 34.94539999192761, 35.91324483194659, 36.75387936253702, 35.29254151928809, 35.503678783293694, 36.629053854173236, 37.36341568731493, 36.283532265693914, 37.73025143531061, 37.74069670707949, 42.91293405717419, 44.07413213483749, 51.55886557794387, 41.178124643141224, 40.95307080976425, 52.84183363760672, 50.25131994678129, 51.67556393531061, 49.282631797175256, 50.25102969138853, 48.475639435552786, 48.379223654347086, 50.215936245456824, 48.13473447676628, 45.15761236990652, 41.5038735635819, 37.14481023050124, 37.36628293991089, 36.15074042351016, 35.98896226575298, 36.38783593331614, 37.25060832115912, 38.22459559286795, 37.41182557998165, 36.678369814349765, 38.84847602536602, 38.71141272206461, 41.28055734019126, 41.14837346538421, 42.97873573918497, 45.945330204502234, 48.96946976261754, 51.16460069533318, 51.89504015830256, 48.98039748591762, 43.90438372089017, 38.90427958580756, 38.375606844502116, 37.23341657269386, 37.78290925487396, 36.04796255788496, 38.61139228267055, 51.8423705716287, 53.47875987329791, 53.19194439918765, 51.02860819908881, 50.16176046863679, 45.65718112453338, 44.55431261370259, 42.121062432566, 42.10981699728197, 41.44147257651053, 47.035215670062655, 49.267660110227524, 46.46292225007088, 43.031522996964, 51.0830585418209, 56.06863421778525, 58.93641633372153, 58.75615204534223, 59.2214314399227, 34.26550026862852, 13.74991080453319, 2.9079685143886076, 2.61655013888113, 0.1725096246528049, 0.043143359944224365, 0.6826131454398555, 29.563219739544778, 48.04887771606446, 40.007795287716775, 32.2497824699648, 38.117848288628366, 57.601010107224994, 53.15954562156431, 41.04357950149044, 5.847103691870167, 0.06295830454497088, 0.05381742770212793, 0.06622627858192691, 0.012811071937903764, 0.05017900418850684, 0.08092474793234179, 0.02366561851944895, 0.08419559096857425, 0.0268586251073547, 0.02538059252284227, 0.00533420174765671, 0.04280748018514245, 0.05541513854217145, 0.06694814025033867, 0.03387573002386959, 0.01408225695242084, 0.04526161220705798, 0.050444591550096396, 0.03224110140675499, 0.060050640811002066, 0.05782766432891931, 0.042689575423156066, 0.04010458409245457, 0.049770721459701184, 0.027157544954529694, 0.003125726591773151, 0.09805101120183546, 0.024624335421850125, 0.26309101812301144, 13.623406521735655, 49.56281454332414, 53.58902946595223, 40.96493990190568, 32.2698022473243, 48.96391568645355, 41.119304780037176, 37.93816843340474, 46.54611572142571, 5.042091146592171, 0.0834417298075653, 1.1485550528572452, 9.237818160364705, 10.280288054097085, 9.649619960015821, 5.462450577366737, 6.079519814060581, 29.557722537748276, 54.063338156669374, 56.661610295695645, 52.4199435018724, 53.06886042318037, 46.08666104655112, 45.58680988127186, 45.38205823590679, 44.78985486492034, 44.40680011626213, 42.07772416453208, 40.254496682074766, 37.69711132972471, 37.51028099367696, 37.29065179824829, 38.41673681812902, 37.49180663016535, 38.45658025433941, 45.07046122704783, 52.76226835866129, 50.235081334267896, 49.27296707707067, 49.38188737438571, 50.9605589989693, 50.145906248400294, 50.001484578655614, 48.90855927621165, 49.476071326963364, 50.07198133776265, 52.85632679539343, 47.611764861691384, 39.82925291984312, 36.36632565529116, 38.33959164157991, 39.44265627091931, 39.364448132053504, 37.25475818880143, 39.431626565994755, 37.011029951034054, 38.066398559078095, 38.5764596539159, 37.607520472618845, 36.01030388186055, 38.372292441706506, 37.92959413220806, 39.28105461981989, 37.28994184924711, 37.475948487558675, 37.60340590630808, 37.65755030416673, 38.559809192534416, 39.99683226308515, 38.76971483230591, 44.740629119257775, 46.38772256912724, 54.9662716927067, 43.95338589145292, 42.79928338143134, 55.525491852914136, 52.26052268858879, 52.80967020219373, 49.953753256028705, 52.1004193828952, 49.13542132223807, 49.67322141893449, 50.72902148769748, 48.92026755117601, 46.36953453863821, 43.35893500235773, 38.9271979947244, 38.47285024581417, 38.08193506733064, 37.913861505446896, 38.08942287198959, 39.08292785767586, 40.16315252550187, 38.62785054791359, 38.53617691224621, 41.041163321464296, 40.92755579179333, 44.2813156497094, 44.51945450998122, 45.46474572150938, 48.480244298135084, 51.867571799985825, 52.74937160553471, 52.99037379603232, 50.6298404355203, 45.28598370090608, 38.90135349765901, 39.710095236378336, 40.19840678861065, 39.548505352389434, 38.391386539705344, 41.811057905997004, 54.12831221857379, 55.819371515704745, 55.53370529605497, 52.427709794813595, 50.85153672002977, 47.264807685729, 45.777641034895375, 43.135152016916585, 42.946921394717315, 43.37106297093053, 48.84689569473267, 53.328105557349424, 50.1952535875382, 45.000454764212336, 53.32198273751044, 58.05040782497775, 59.942610186915246, 62.731431068912634, 58.71263334828039, 35.72029167605985, 12.192239549852188, 2.7770773057014715, 3.9298788145665204, 0.9994592661819152, 0.01582436100204265, 0.6971522072149862, 34.069879901024606, 53.83345588561028, 46.63422392260644, 33.12152924076204, 40.61411526895339, 64.19753459192091, 60.634822230185236, 48.15335396797427, 7.109650421527125, 0.011430635124505048, 0.008461105960210966, 0.0720005973632778, 0.06859538250512655, 0.032436879006244486, 0.05009604452718651, 0.018404618866982, 0.08408482997648178, 0.09139258865146868, 0.0897274659045281, 0.005444923477743062, 0.02732341065101566, 0.03284954375797703, 0.0753518413271635, 0.19295579122920192, 0.07081435617780493, 0.16912653441390685, 0.13747884471329952, 0.22847296039183296, 0.17153994120176763, 0.17682640753205747, 0.13670861991422792, 0.19728095511034613, 0.10062360339948248, 0.1591013546191877, 0.07435507666800292, 0.19127369197385927, 0.17096169803652073, 0.575053297704266, 18.53353246565788, 58.66583947212466, 62.17158332947762, 47.59360036542339, 41.33721205496019, 47.98142863858131, 39.210930485879224, 42.42861155540713, 53.61600752799742, 5.605236128453286, 0.14931246698383363, 0.902333045678754, 15.50756214126464, 18.82736113763625, 20.49880858390562, 10.936962443013346, 5.478350395156491, 33.40770144616404, 55.04972796286307, 60.69833324801538, 54.778778476099816, 54.89085628140358, 47.69877479922387, 47.66855293704618, 45.06291066446612, 45.696004744498964, 45.55695672189036, 44.55951759892125, 42.05617858517555, 40.6765397902458, 39.226906299591064, 41.05986126007573, 38.935874277545565, 39.492007532427394, 40.06925882831697, 48.050352527249245, 54.10378956025647, 52.640902380789484, 50.726958320986846, 51.88225323154081, 52.73929111419186, 51.055425443956935, 50.708672231243504, 50.722271088630926, 50.44212756618377, 50.500276703988355, 54.27205531827865, 49.76949599481399, 42.143086541083555, 37.3397873293969, 40.175927685153106, 39.65505261575022, 41.25616412008963, 40.47176068828952, 41.3613110972989, 40.126325391954, 39.20856921903549, 40.16085401658089, 38.636864154569565, 37.681398314814416, 38.59520858333957, 40.29078252853886, 40.74781317864695, 39.17491136058685, 39.65954372959752, 41.14485902170981, 40.13864163429507, 41.63564951189103, 40.59461716682681, 42.15215506092195, 45.68257062665878, 49.69711257565407, 55.69746817311933, 48.715123668793716, 44.130782927236254, 56.70149687797793, 54.25094904438142, 55.585147180864894, 54.015677436705566, 54.35988110880698, 52.70252673856674, 52.98896174277029, 53.37567606279927, 51.56585916396111, 50.5404378521827, 46.31169134570707, 40.688165695436545, 40.466332127971036, 39.95033648706252, 38.83457514547533, 40.686741875063994, 41.27527782993932, 41.01378517766153, 40.629996945781095, 41.135119776571955, 43.44491727890507, 43.0530450420995, 47.36057627585627, 46.858967888739805, 49.19332335072179, 50.798988726831254, 55.557388567155414, 55.55028123240317, 55.94231036401565, 53.91800257467455, 48.75075055706886, 41.99750777213804, 42.64447919784054, 42.119819041221376, 41.895988987338164, 41.090816605475645, 42.75146576666063, 55.993214884111964, 58.3635933937565, 57.21763764658282, 56.903463640520656, 55.457391661982385, 50.11580205732777, 49.03110196513515, 46.921921930005475, 45.43384528929188, 45.71398488936886, 51.61391604331232, 55.53867493906329, 52.39562872917422, 47.58515158007222, 57.15218113314722, 60.26692744224303, 62.31905660321636, 65.48198922987908, 62.344077402545565, 38.53276837256647, 18.553597350274366, 6.7462624369129065, 8.800632742143447, 1.1383146023558033, 0.13053897678131057, 1.06399059055313, 37.07279159176735, 61.599395813480506, 55.051387125445956, 45.20433564339915, 51.133268802396714, 72.6655238674533, 69.576829941042, 56.40961762397521, 11.198099140198002, 0.15417209976623136, 0.10770803978366238, 0.13735849230039504, 0.12981839447973237, 0.08795510616994674, 0.25263450018340544, 0.1987794843772727, 0.24785532195481563, 0.15018756921973922, 0.14823102662640233, 0.103949727340331, 0.2285362698978955, 0.1332728381478979, 0.13373943165906016], [0.0053114762281878825, 0.03751217320020642, 0.010533313465965612, 0.02091045990856665, 0.08034810589085664, 0.022168027710229642, 0.05251252332762365, 0.055850977453613476, 0.035207003144727606, 0.05653932277533797, 0.05383624282154826, 0.047173940035845005, 0.007999750575230969, 0.09761835538571882, 0.12275883297045385, 11.371446328778422, 43.67995746674077, 50.57453893846082, 39.57238081962832, 30.717200656091016, 18.152129034842215, 29.56550452017015, 46.26975336382466, 38.97978128925447, 6.671117669151676, 0.16662953211174858, 0.8925552509965435, 3.0738977655287716, 6.484239774365579, 7.973681399899145, 3.214277432810876, 9.22514105996778, 23.20083525873, 45.82000263275639, 51.40983904561689, 51.54710238979709, 46.23009427901238, 43.86197505458709, 37.497501911655554, 37.69668379137593, 36.764783551616055, 37.15524765752977, 35.75314937099334, 38.63302415417087, 35.889957720233554, 36.78281076492802, 35.93661039106308, 36.233310238007576, 34.99160943492767, 44.780437254136615, 48.95640434757356, 52.29673008764944, 47.80610261424896, 50.105117520978375, 48.129772678498306, 49.33646240542012, 50.604870627003336, 49.61868870642878, 49.02564594822545, 48.31565772333453, 47.95329739970546, 48.55451045497772, 45.68822276207709, 39.097879932772734, 36.40485509749382, 37.135624039557676, 39.20372901424285, 38.91779215105119, 33.66595814304967, 34.84259859208138, 34.75938943124587, 36.895967222029164, 36.08247157066099, 36.14404493762601, 36.22620290325534, 37.68416750815607, 33.85742079827094, 35.82500719255017, 34.371533701496745, 37.546441324295536, 34.83596194174982, 36.95077842281711, 36.84744358062744, 40.487638442747055, 40.54630533341439, 46.018101938309215, 44.71481992352394, 51.46470123721708, 41.479523489552165, 36.53175553967876, 51.652990694968935, 49.77813305393342, 51.337949845098684, 50.81128535732147, 50.58416835723385, 52.86297129046533, 52.78522206890968, 50.9509805710085, 51.23190464511995, 49.388708376115375, 42.73875728730233, 39.64462695583221, 35.55016671457599, 36.44968386619322, 37.87752074580039, 37.296864832601244, 36.746332722325484, 37.462078986629365, 37.441113918058335, 38.79397469182169, 37.2748956372661, 39.44976752804172, 41.19728149906282, 40.42268007032333, 39.03191351121472, 45.448138406199796, 48.71350765228272, 50.8871243846032, 49.37508206213675, 51.9948370225968, 47.69961026407058, 40.952200043586, 38.086222217928984, 36.451841169788, 36.37073047699467, 38.197809726961204, 36.09508199076499, 45.01167666527533, 52.13387720046505, 55.478376342404275, 54.53340676523025, 55.49177123654274, 54.53839602008943, 52.89215372454736, 51.11301760519705, 47.84526748041953, 43.06393354169784, 42.26843372468026, 40.558629420495805, 44.2383853081734, 45.846349193203835, 54.74550108755789, 57.27529648811587, 58.746769735890055, 59.693371019055775, 56.904444233063735, 38.376932605620354, 14.828060538538042, 1.0407048271548365, 2.885775253657372, 0.3427874513210789, 0.017190296728644642, 0.6665001713460492, 30.07602257113303, 50.38786549721995, 38.144810661192864, 29.768928443231893, 32.86387658888294, 49.646643438646876, 54.83378971776655, 38.83284930259951, 6.001820112428358, 0.04576215490458473, 0.04131860362606184, 0.03570269267525404, 0.11451070136841267, 0.03947650690773322, 0.008217381790370471, 0.06834348513474388, 0.014202751091591293, 0.04330652901121686, 0.0004862315167443857, 0.1036619387506958, 0.10395939536993543, 0.01615413408275814, 0.04891359930737846, 0.034182732098645745, 0.019449855824331605, 0.03415563939920357, 0.038847020121231195, 0.08164975056124311, 0.01862734169398825, 0.04192225792775712, 0.07755625932928055, 0.026621700925452095, 0.06334121444172437, 0.0397550373248035, 0.031240916165012508, 0.05201246709592881, 0.10399832795824736, 0.26490569655453006, 14.857005669224648, 49.230754529276204, 55.773679825567434, 44.668245700097856, 35.29102748440158, 22.956044058645926, 27.837733799411406, 45.84789068468156, 45.90884039478917, 7.075761633534586, 0.24502668019023635, 0.7424815684076279, 6.031153067465752, 6.403543381921708, 10.005752540403797, 5.093985574860727, 9.175136723826009, 27.213878862319458, 47.106991121845866, 54.03644638676798, 54.598180786255874, 48.540942976551676, 43.85106302076771, 40.55402848028368, 41.28626046642181, 39.04906211360809, 39.182532525831654, 38.79080149435228, 39.36908829596735, 38.52288007736206, 38.35237072360131, 38.58599101343463, 36.598247558839866, 36.36838097726145, 45.87051491583548, 52.91460144904352, 52.45859453755041, 48.86993177475468, 51.18986468161307, 50.714340056142504, 51.47179288248862, 51.67111988990538, 51.24410321635585, 51.47930029899844, 48.461554204264, 48.33220228072136, 51.329477525526485, 48.855646502587106, 39.696445388178674, 38.318183345179406, 38.66024932553692, 41.17010731850901, 39.85966697815926, 36.26703477674915, 37.72134765501946, 36.10340918264082, 36.897406731882405, 37.24770184486143, 36.77436197957685, 36.743120301154356, 39.138456852205344, 37.33297025003741, 37.35910892486572, 37.47096315506966, 39.509673887683505, 36.76759196865943, 38.401263067799235, 38.90739787009455, 40.19979138528147, 42.77117567677652, 47.205866229149606, 47.60918786448818, 53.23002669119066, 44.962905914552756, 38.87560705984793, 51.426662091285955, 50.662741276525686, 52.38952944355627, 54.36333279455862, 52.112794460788855, 55.56048331722137, 54.78424233774985, 52.198384500318966, 54.33387187219436, 51.87447909385928, 45.01392810575424, 40.596441068956935, 38.29266832720849, 39.455054883034, 40.87946753348074, 37.78373687498031, 38.77375879595357, 39.027583214544485, 38.28078746795654, 41.24082765271587, 40.93771080816946, 40.51080396098476, 42.9645485262717, 42.660392253629624, 42.066266921258745, 47.13620885725945, 50.78539379181401, 52.9133580576989, 51.055515658470895, 52.9330522783341, 50.61830474484352, 43.44383862710769, 39.82317324607603, 38.75877534189532, 38.10982704162598, 39.56455961350472, 38.14162961898312, 49.33543474443498, 55.146783090406856, 57.345263727249645, 55.84840097735005, 56.17291042881628, 56.98240526260869, 55.210827550580426, 52.473083772966945, 49.200085516898866, 43.83644434713548, 44.521235266039454, 42.808681380364206, 43.991166160952666, 48.18339147875386, 55.67418498377646, 59.93090975669123, 61.30729690674813, 61.377758364523615, 57.67471536513298, 39.65529972507108, 13.928720874171104, 2.501688921643842, 4.622657395178273, 0.7954344850394034, 0.06390623875983781, 0.5237228327220487, 33.854914403730824, 53.90216796628891, 45.71609904689174, 38.235248750255955, 38.95283852854083, 57.314543724060066, 60.23289303625784, 46.08008715414232, 8.028147922408197, 0.06233665100749462, 0.05149838762478002, 0.02637376039919834, 0.1363517455155811, 0.07222709125809132, 0.058714422592592824, 0.07059732346885628, 0.09998588882867368, 0.013705084096610308, 0.02676052371821096, 0.05604296291787779, 0.03209004227462555, 0.05124411155139247, 0.03787055679206406, 0.14695072516558633, 0.1103796948107981, 0.1489729674593095, 0.13556543287009964, 0.2089894139358113, 0.19635561282836622, 0.13941016769216907, 0.19701553628809992, 0.09699050036649551, 0.2612961660469732, 0.1341140486540333, 0.14974395834630536, 0.11646026490075935, 0.19415913149714473, 0.5971678658839196, 18.818726039701893, 57.640731949960035, 64.54431133885538, 52.119497791413345, 43.42743527504706, 27.48425960540772, 39.91907519678916, 58.166568817630896, 52.97654744117491, 9.169481646630073, 0.34461031157162886, 2.1544922359528083, 6.50253959240452, 12.857301927381947, 15.40135024055358, 10.379598544489953, 15.199965949981445, 30.88400140885384, 50.945230376335886, 55.59025410682925, 57.175146610506125, 50.504912945532034, 46.945311023342995, 41.60333310404132, 43.355734348297126, 40.92681838620094, 40.93578100204468, 40.4200638494184, 43.06684001799553, 40.91143485038511, 39.77075076872303, 40.89622782122704, 39.057820766202866, 38.52835570612262, 50.30688032027214, 55.204889082139545, 53.06608730746854, 50.32125580695368, 53.38613702404884, 51.32459417466195, 53.694188210272024, 54.91939936914752, 52.91315017207977, 50.828492795267415, 50.195324190201305, 48.941597400173066, 53.26997210902553, 50.12687490832422, 42.921731933470696, 40.301086594981534, 39.94761436216293, 43.004721441576564, 42.309853953699914, 36.52769980892059, 38.689882832188765, 36.994783493780325, 40.350590828926336, 39.69838696141397, 38.29977566196073, 38.9601106028403, 41.48734077330559, 38.27091486223283, 40.477530494813, 38.23668041536885, 41.31395632220853, 38.500153864583666, 40.82717057197325, 41.56871426490046, 42.71711364869149, 46.07453700034849, 49.774085167915594, 50.37657691586403, 54.092787311923125, 48.50372752835674, 40.49587934247909, 52.931730439586026, 54.50638555711316, 54.62445282167005, 55.559192857434674, 52.519418731812515, 56.96391128724622, 57.02581805567588, 55.05523889295517, 55.51942786862774, 54.817519726291785, 46.79507640100295, 43.842339669504476, 39.14329705699798, 40.25377888833323, 43.154085297738355, 40.62251698586249, 39.34853899863459, 41.47218473495976, 40.37098715382238, 43.710610789637414, 41.693531928523896, 42.50126561810894, 45.40471776839226, 45.11189714554818, 43.19497208441458, 50.8017736096536, 54.023828121923636, 55.263493214884114, 50.42763048602689, 55.768168895475334, 52.7587382255062, 46.76312869594943, 42.96345418499362, 40.774010689027854, 39.65163230895996, 42.09850880407518, 40.49892702410298, 51.539371398187455, 58.29861933185209, 59.38701037437686, 58.793049781553215, 59.156084752851925, 59.61686518884475, 57.973223424726925, 54.77870395106655, 52.90031617687595, 47.46457792097523, 47.99798888544883, 45.808819955395116, 48.18774530964513, 51.540332378879675, 59.63522972599153, 62.21507064757809, 64.60642599290418, 63.590838063147764, 59.520778886733524, 41.20451434966057, 19.505984129444247, 3.958135814436021, 5.88051297010914, 1.4592206213743457, 0.2040325492740639, 1.1029353136977842, 37.184920387883345, 63.140569579216745, 52.1233574036629, 44.59358338386782, 43.89870412888066, 65.32272923377253, 66.98966595434374, 54.49699148055046, 10.212374175748518, 0.16527587007130348, 0.1234819969883369, 0.1536136063476724, 0.2586483516760411, 0.18046904835970173, 0.12044893232204261, 0.1308333690488531, 0.19814484181904024, 0.14631070467012544, 0.1201692489426463, 0.16202584930485295, 0.18423449308160814, 0.14926636381255043, 0.19968789611612597], [0.06477808129162559, 0.07454707362358609, 0.024464498837328246, 0.05956368468281242, 0.04680185113102198, 0.0648567431996907, 0.036894254341361024, 0.06712540533513793, 0.005719040270759574, 0.05886040064656447, 0.03876264702769057, 0.026559063661543113, 0.12152720873634662, 0.06705129398934304, 0.08663994770857596, 9.322857106885603, 46.51032409360332, 47.69688029443064, 44.680424659482895, 34.582192436341316, 23.925328408518148, 27.054713003097046, 37.85673610625729, 41.25237903287334, 7.847764492034913, 0.04234224264960616, 0.292029315305333, 2.148067883906826, 5.162278942523464, 7.54355134502534, 3.1521027174688157, 9.213876993425432, 25.43441522505976, 46.54873194233064, 52.9721700760626, 50.49489913448211, 50.990569053157685, 48.01905985801451, 42.288990866753366, 39.427770876115375, 36.22927411910027, 37.80731424208611, 36.784948456671934, 37.32689057627032, 35.10324401240195, 38.091623321656265, 38.30945214917583, 36.75742910754296, 42.1150690509427, 48.822290666641734, 48.514094352722175, 48.803765312317886, 50.45862505512853, 45.87237019692698, 44.147806013784106, 46.29960260083599, 46.33741424929711, 48.22590997142177, 49.24037218093873, 50.847355473426084, 51.19257111703196, 48.64856496933968, 47.229204331674886, 37.23511495897847, 37.46181618782782, 36.994497160757746, 38.643461581199404, 37.2852389274105, 37.04093802359797, 37.25930421583114, 37.71525229177168, 36.8431289734379, 36.23117646863384, 36.26670529765468, 36.14076975853213, 36.53775284367223, 35.49235490060622, 37.93428920930432, 34.13986282963907, 34.31668719937725, 36.398736200025006, 37.73690769749303, 39.17538988974787, 40.87122271137853, 43.79775801012593, 47.60898390123921, 46.2130319687628, 54.35282476486699, 41.988533389183786, 38.015905887849875, 46.025268108614036, 42.44487762451172, 49.462146912851644, 49.03813477485411, 48.9075041586353, 48.98222923278809, 49.754081080036784, 50.122317114183986, 54.284759875266786, 48.01757720208938, 46.818002654660134, 36.86101498142366, 36.71049402606103, 34.63680751862065, 36.68518689370925, 35.90239163367979, 36.872197658784934, 37.55045783135199, 36.44957011745822, 38.30710264944261, 38.57747162542036, 39.33951362486809, 38.04540211154569, 38.6999515564211, 38.822309893946496, 40.63025974458264, 48.09052936492428, 50.34884183637558, 53.03487308563725, 50.65756374789823, 47.85865452981765, 40.374054447297134, 37.309381115821104, 35.928216518894324, 36.47666192823841, 35.42898508810228, 37.722512598960634, 38.85340644467262, 47.23162443407121, 51.81891479799825, 55.02976702105615, 54.202288120023674, 53.298472050697576, 55.330824621262096, 53.65459580575266, 51.69015515235163, 47.51307018341557, 44.61427388652679, 43.74359792278659, 44.01824228225216, 45.463616078899754, 54.86347813760081, 58.38964577644103, 61.26122474670411, 59.34097743803456, 55.98698616027833, 39.46309574188725, 11.514691287471402, 4.07488736894823, 4.223076720391551, 0.8993206040993814, 0.02388520038596565, 0.49879993942956774, 28.162666866856238, 53.408635739357244, 40.79696439927624, 34.24460580272059, 30.328356489058468, 46.12875984561059, 57.06200976525584, 38.817210812722486, 6.722106520206698, 0.016378852568807143, 0.05102096929124767, 0.0508809820448439, 0.13988374792520078, 0.032312780423390294, 0.04912569457965513, 0.01201700552501866, 0.05011711960598346, 0.04769684867032113, 0.02091761516977943, 0.04614699534290741, 0.04429220454767347, 0.0229571825419102, 0.04417506204317174, 0.06247732773303025, 0.007065515448865031, 0.026774054746173566, 0.03534263901172146, 0.02580449578442401, 0.07289720368721793, 0.05150067822767362, 0.045993827553766395, 0.0160230114312482, 0.08703763927182845, 0.014762188713516922, 0.051090959084009936, 0.09070930717092368, 0.05982741045074598, 0.08975414874693079, 12.112480113583228, 52.52818915151781, 55.67303572931598, 50.11784168981737, 39.3824282769234, 28.811117026113696, 36.90262348421159, 44.54489108054869, 46.14451600659279, 9.261831891152168, 0.07654038843728843, 0.18095859386507543, 3.070888327014062, 6.2996442087235, 5.3347386948523985, 7.1912798477757365, 13.755673746908865, 26.871212759325584, 47.97978124310894, 56.00048303604127, 52.36635608057822, 54.077560670914195, 49.65893222439674, 43.992809634054865, 39.39650958584201, 38.1053476948892, 39.26321175790603, 38.88629944093766, 39.19171479440505, 37.81038545793103, 39.68572162812756, 40.55973945125457, 37.94640148839643, 44.250356381939305, 51.03484084529262, 50.33248163038685, 49.13972808468727, 50.57690805004489, 49.22276073886503, 47.57882479698428, 48.70719655867546, 47.72025762065765, 50.06735686332949, 51.90717204924553, 52.12379278675203, 52.01720237731934, 49.247993346183534, 48.41257949029246, 39.00777132280412, 37.742532376320135, 38.82582825999106, 40.0680781948951, 40.451305527840894, 37.38538488265007, 38.21955534719652, 38.390335344499164, 38.19604858275383, 38.297112372613725, 37.707839012145996, 37.74489756553404, 39.048105055286044, 38.011591280660326, 38.94671178633167, 35.14424847018334, 35.80359105140933, 37.4748110002087, 39.82727604527628, 41.11859875340616, 43.20396215684953, 46.54883784632529, 49.20294884712466, 47.84438494713076, 55.88402394325503, 45.46989579354563, 39.6565862624876, 49.15479390851913, 44.88623142242432, 49.548929352914136, 50.458895698670425, 51.03990854755525, 50.50011980918146, 50.929187882331114, 50.85688683294481, 52.71536073377056, 49.111032024506606, 48.182830579819225, 37.46615040686823, 39.47874992124496, 37.858877720371375, 39.456651287694136, 37.2739464236844, 40.23885426982757, 39.131255380568966, 37.50686460925687, 40.04189245162472, 41.019558906555176, 41.453533864790394, 40.585101496788766, 39.95016782514511, 39.7331666177319, 44.26894449418591, 50.09579404707878, 51.99237769649875, 52.8269168638414, 52.32938381933397, 49.86029101956276, 43.13264562237648, 40.24821696742889, 37.93003736003753, 37.643088525341405, 36.87413923202023, 38.951846168887236, 41.476193397275864, 51.057441542225504, 54.36991845407794, 56.609658502763324, 55.917215039653165, 56.7184885855644, 58.186341485669544, 56.18323018473964, 54.569159169350904, 49.61868478405861, 46.35599843917355, 46.98443274344168, 46.182994457983206, 47.459420004198634, 58.3056168402395, 59.28833138558173, 63.97222580448274, 62.00079548743464, 57.50686537834906, 38.47396419894311, 12.610904516712313, 3.5606840060603235, 4.503404594236805, 1.1079721272953096, 0.017637021749490694, 0.5105554360535838, 31.92795591969644, 59.235297018481845, 43.33729136374689, 37.73112612385904, 37.33176608239451, 52.98629060868294, 68.71537546957694, 45.36154423990558, 8.465330889148097, 0.053321251705769575, 0.09417097504821517, 0.04782802590559568, 0.022586168075400977, 0.015604586655934973, 0.01567159157862226, 0.046117757597277244, 0.06908336519113473, 0.04481494081236663, 0.04660319304093719, 0.026063094508924314, 0.057489064957706205, 0.07578003085068158, 0.01953817044024266, 0.24527446366846564, 0.15162019960341916, 0.13094757743660482, 0.1937685032645541, 0.1373671644156979, 0.22724368038677403, 0.10564286592266253, 0.181670289546732, 0.10417254401310798, 0.1907020371647612, 0.09893572784119076, 0.12382397097685646, 0.18872660284321155, 0.20710192650796908, 0.21166384220123294, 14.950402205990208, 60.24067109630954, 62.51042904392366, 57.409661200738725, 47.290299169478885, 34.398668658348825, 38.195828930024184, 48.4797893031951, 51.098194968315866, 11.318417845233796, 0.20872224843309772, 1.0354899134366744, 6.613352923623978, 12.707756661599683, 14.934241060287723, 10.898962520783948, 11.706331429942963, 28.061224568274717, 48.60271638439548, 56.44153395006734, 54.221076273149066, 56.870378448117165, 53.42078724215108, 47.91212428000666, 42.71397183018346, 39.99644394843809, 41.56441142482143, 41.62049739591537, 41.82064025632797, 39.426864808605565, 42.554970710508286, 42.710108295563735, 40.572494999054946, 45.94695798812374, 52.71341916053526, 50.93949979351413, 51.01322074090281, 54.32391689669702, 50.82347608381703, 49.54424996529856, 51.22749197867609, 50.63672811754289, 52.99138184516661, 54.86032847435244, 54.7000761185923, 53.20333496216805, 52.03200147997949, 52.56209411928731, 41.27445805457331, 40.678791230724705, 40.63799465856245, 41.43578906213084, 42.053397624723374, 40.13436232843707, 39.74132122532014, 39.334728333257864, 40.81946703695482, 40.41786339975173, 39.83690154167914, 40.018558271469615, 41.21891337056314, 40.039260541239095, 41.63378246368901, 38.03745931194675, 38.28558844904746, 39.421977535370864, 40.94282950124433, 42.4110746383667, 45.64914811042048, 48.234645089795514, 51.79556885073262, 51.26481333086568, 57.43382692337037, 47.62396343292729, 41.00577177539949, 52.040360050816695, 48.38816273596979, 51.546765065962276, 52.452385425567634, 51.7364195085341, 52.73502749781455, 53.23790673286685, 53.005718108146425, 57.77147631491385, 52.84088442402502, 51.08401167777277, 39.87152038082, 41.26320085217876, 39.31016645123882, 40.77333211898804, 39.459436170516476, 40.79988656505462, 41.657552026933246, 39.083833925185665, 42.65121390742641, 42.612696232334265, 45.42594563576483, 42.56345479719101, 42.123117754536295, 42.37907986487112, 46.30593330629411, 52.67085752179546, 53.992915922595614, 56.00008687665386, 54.586343073075824, 52.294768902563284, 45.036340528918856, 41.122332849810206, 39.553016078087595, 39.76341985887097, 38.536078852991906, 41.26841368213777, 44.13304221245551, 52.581411792385964, 56.80102702110045, 59.543312903373476, 57.84301642448672, 60.90549322866625, 60.61046431141516, 58.240344678201986, 57.15095343128328, 52.17184574373307, 50.45437320586174, 48.32901339377127, 47.77188777923585, 49.892564281340576, 60.51378180903774, 62.714529575840125, 65.71706079667615, 64.29844933171427, 59.29907083511353, 42.565062968961655, 13.887853699345744, 7.480913544854811, 12.404165210262423, 1.186137487811427, 0.14389051034325553, 1.0007049251467952, 35.29995872128394, 66.54949757360643, 52.847654434942434, 45.75768009308846, 42.74586854442474, 61.34091554149505, 74.36916612809705, 55.371401540694706, 12.017227315133619, 0.15102738544585245, 0.1636186227082245, 0.1424455306222362, 0.21558733086191842, 0.14719797238226862, 0.13396515180507015, 0.1577532084117974, 0.17393218864115978, 0.21795987451989807, 0.10715676291335015, 0.1825077921873139, 0.15506393336240323, 0.1461554339696323, 0.11106665351337965], [0.065683436339661, 0.08014156858647063, 0.016258563358156432, 0.03798445491420646, 0.08949831368461733, 0.020101672158606594, 0.07791252085758794, 0.033355016231296525, 0.042119529398698966, 0.037953803736356, 0.06881239223143748, 0.11085505236781414, 0.04204058403810186, 0.0031362813681499254, 0.06903082688128756, 6.426097991005068, 36.4735044202497, 45.59772191509124, 43.733015368061686, 23.833144864728375, 11.608328069410017, 17.195682602543986, 34.62915889678463, 43.94780043632754, 10.546305160368643, 0.0828198349523929, 0.0076461981253458135, 0.6030017173578662, 3.413941028618044, 6.454253254398224, 3.8652815453467833, 8.766094311591118, 26.257422624095796, 44.39184411879509, 52.603730078666445, 52.34230410668158, 49.26656184657928, 49.232484294522195, 46.711384788636245, 44.16644903921312, 41.802052144081365, 36.40129750774753, 34.20037715665756, 37.11372544688564, 36.9621846752782, 39.3218433472418, 36.5531442242284, 37.487519479567005, 48.14549353814895, 48.60427356535389, 48.82926464080811, 49.72764822744554, 45.63676518778647, 43.83549905592396, 43.67667836527671, 39.42754730101555, 42.07759080394622, 43.16789596311508, 47.78342346991263, 49.39121477065548, 49.90694369039228, 47.92654291276009, 47.131937396141794, 37.61714204665154, 36.41068373956988, 36.564362202921224, 35.29985673965947, 34.62309491249823, 37.38990345308858, 34.85878229141235, 36.54203214953023, 37.4135043544154, 37.73096530668197, 36.33766097407187, 36.39963834516464, 36.06624472525812, 36.685269263482866, 37.38981716094479, 38.04180529809768, 36.73803298704086, 36.05104946321057, 36.49025686325566, 40.04536767159739, 41.356133568671446, 48.18104197902065, 47.55843239445841, 48.58577566762125, 52.88130837102091, 40.40235434809039, 35.16113035140499, 45.4982937535932, 47.77018547058106, 49.428002680501635, 49.69479053251205, 50.84122480884675, 50.989302127592026, 51.23801962021859, 49.75668945620137, 51.73874939641645, 50.637289016477524, 43.79266677364227, 36.951068678209865, 35.63315622268185, 36.13367419089041, 36.18770091764389, 36.71257288225236, 36.616792525014574, 37.112909593889796, 37.32320747067852, 35.83144380200294, 37.61954253719699, 39.35210051075105, 38.39582274037023, 39.73049940601472, 38.16666218542284, 42.387744380581765, 49.186451358179895, 49.8910580911944, 51.21248106802664, 49.7497429386262, 43.185479948597575, 38.54088375645299, 38.14962733176447, 39.87792561131139, 40.66977762406872, 38.59821704126174, 38.45234801692348, 36.62216224978047, 36.58860245058614, 45.11870245779715, 53.76108423356087, 53.70132692398564, 52.532970520757864, 53.31170612765897, 57.54857978513164, 56.43072782024261, 53.686555277916696, 47.80764802809685, 44.2658575888603, 42.69300676161244, 45.03566195887905, 54.48868782289567, 58.89254070097401, 61.4872827068452, 60.26466031228343, 56.750071510191894, 34.99365691215762, 10.619066107657648, 1.687085936146398, 2.369833790486859, 0.7871768539471011, 0.05292813751786467, 1.0501912019906505, 28.930157038473315, 51.42166106931625, 45.34115968212005, 39.30447509211879, 38.38089812186457, 51.235579905971406, 54.53673685750654, 39.05030550495271, 7.552133490962367, 0.07894624925909505, 0.018602681323705662, 0.045038286085811355, 0.04407162485163539, 0.018471607510300896, 0.08424263642800432, 0.012135081699178105, 0.05534910942397772, 0.0986194714242893, 0.05744904069410217, 0.03656195604332513, 0.0062851763739731285, 0.02334416611120105, 0.03569168782222175, 0.05186758454768889, 0.02840045557898139, 0.06997368959409576, 0.019815335305587902, 0.04701563179673207, 0.03953409373700138, 0.035211741398539276, 0.04750625365563939, 0.027341005775416573, 0.035879268280921445, 0.06573079589514003, 0.08742756270352872, 0.05640304722492734, 0.016283570383224758, 0.11211195750342262, 8.242486330770678, 44.334699107754616, 53.72757542517878, 51.37739319955149, 33.37650291381344, 18.205283034232355, 23.39447286821181, 41.6793486379808, 48.45498423422537, 11.943685816180322, 0.04127445780942517, 0.053772316614706675, 1.2174855605248482, 6.863454032328821, 7.728428831023555, 6.871261019860545, 14.241412224308139, 28.552544578429195, 45.478521085554554, 54.495367619299124, 54.04616209768481, 51.485152475295536, 52.4825406074524, 46.97687433611962, 45.03341051840013, 42.45176530653431, 38.250808792729536, 37.308557418084916, 38.60219824698664, 38.04931271460749, 40.889269536541356, 37.66612460536342, 40.09852363217262, 48.918439726675714, 51.37491818397276, 49.316324956955455, 52.4411399902836, 48.78414561671596, 46.78602749301542, 45.797535296409364, 41.591291427612305, 44.37785302439044, 46.69092570581744, 48.0908666887591, 51.0458940844382, 52.4013553896258, 49.67230750668434, 48.57892328693021, 41.21779157269386, 36.9316529458569, 37.67966462719826, 37.828820597740915, 37.48489149155156, 38.59341213780065, 36.0216316869182, 37.08184442212505, 38.843223971705285, 39.98429244564426, 38.200751504590436, 38.39831344542965, 37.968664861494496, 39.45918906119562, 38.67461696747811, 39.75910132931125, 37.97001415683378, 37.64833273426179, 38.501279584823116, 42.35475332506242, 43.69958108471286, 49.66414505435575, 49.28725627160842, 50.73701135573849, 56.268443676733206, 42.93255767514629, 37.68855664037889, 47.58817964984525, 47.723187631176366, 50.63713212167063, 51.49637437635853, 52.9825565122789, 52.76233111658404, 53.14993581464214, 50.055358332972375, 52.98201914756529, 50.349575319597804, 44.941195595648985, 38.809989729235255, 37.841070159789055, 37.60243315850535, 38.424389362335205, 38.91619966876122, 38.222344152389034, 38.67358146175262, 39.1542600816296, 38.42413048590384, 40.168851729362245, 39.67327202520063, 39.623222581801876, 40.81837269567674, 38.98974410949215, 44.097729113794145, 51.37083107425321, 51.5407677619688, 51.82071124353717, 51.98341115828484, 46.41140191785751, 39.8944309449965, 39.98995242580291, 42.10233703736336, 41.564313365567116, 39.19273068827968, 38.76755752871114, 37.65225510443411, 39.64077911069317, 49.30664062500001, 55.92242786961218, 55.60477864357733, 54.671666391434215, 55.47105327729256, 60.571585778267156, 60.020163289962284, 53.86194013780164, 50.092189388890425, 45.18521801117928, 44.19440377143122, 46.85059755079208, 57.55944082813879, 61.707931718518665, 62.49140162621776, 62.302002137707134, 59.755485673104566, 36.42700079948672, 10.768985959791369, 2.94646829366684, 3.133745779914241, 0.35842676857306116, 0.06437727175052128, 0.675716515510313, 32.45840353350486, 57.03219582957607, 50.06862771126532, 43.099834995885054, 41.87674583927278, 55.173368915434814, 61.31620853177963, 45.6275946863236, 9.8043486379808, 0.08260461787182478, 0.06816957551505297, 0.050619535388485085, 0.04529412497856444, 0.07092930767084323, 0.040090641292232665, 0.08258416332424649, 0.005340272994456633, 0.05776891687644586, 0.014795945420290434, 0.005825643320643013, 0.0765959527944365, 0.04075007445569481, 0.05254606648738827, 0.1443876860843551, 0.1300839052325295, 0.15387934692684682, 0.1904358522545907, 0.17988545790074334, 0.12134366939144751, 0.1844013929967919, 0.09597475970945052, 0.12608632820868684, 0.09205373785188121, 0.15029361111021813, 0.1805009942261442, 0.13801092342022928, 0.1386113984570388, 0.3497642140475012, 11.24616974784482, 51.67379886873307, 61.949898812078665, 57.21620205909976, 35.997944493447584, 20.528944153939527, 24.573494195938114, 45.928824870817124, 54.12353084933374, 14.97835889939339, 0.27763510543492537, 0.2945701838020356, 3.2079420695381784, 12.275928220441266, 13.115000667110568, 7.61493455979132, 11.70093228740077, 29.96732584891781, 47.695691816268436, 55.613921688449004, 58.447277161382864, 54.53684668387137, 54.357625745957904, 50.60221910476685, 49.416204191023304, 46.059122085571296, 40.58072805404663, 39.80267101718534, 39.215080353521536, 39.598029198185095, 43.709983210409845, 39.89260704286637, 41.38640249929121, 52.188708013103856, 52.74625724361789, 48.833845969169374, 52.8661209537137, 49.968340550699544, 49.132181444475734, 49.0393977780496, 43.55783447142571, 46.127477230564246, 49.01855038058374, 51.28891237320439, 55.17856605591313, 53.17834161943006, 51.89924101675711, 52.037057415131606, 42.95999857687181, 39.61319308127127, 39.94713583300191, 39.10284565341088, 38.66105341142224, 40.41621208190918, 37.97645076628655, 39.47600033975417, 42.36708525688418, 42.05895954562772, 41.29571730090726, 41.593036882338986, 39.51776573734899, 40.282510249845444, 40.86441347675939, 41.064626939835094, 41.05696655088856, 39.72613773038311, 40.35892978791268, 44.736600845090805, 46.11248200939548, 51.567020185532115, 53.60976703705327, 52.41821765899659, 57.08992135140204, 46.8355474164409, 41.672194234786495, 46.24782339219124, 49.086685872847035, 51.74359744594943, 53.71623193064044, 56.24285413372902, 54.38767110147784, 56.18869404638968, 51.86201380145166, 55.94329095655873, 53.61737251281739, 46.88392200777608, 41.88331580931141, 39.961099470815356, 40.48302573542441, 39.521939139212336, 41.937703394120746, 40.00499079304357, 40.092655766394834, 42.39935459629182, 39.60971393892842, 41.959955000108295, 44.24939932361726, 41.5021869444078, 41.558414120827955, 40.857894497533, 46.92477741549092, 54.153991976091945, 54.47196283648091, 53.12284400386196, 54.27633070176648, 49.05912730001634, 42.80156227850145, 42.641882588786466, 43.98251341235253, 44.05174324589391, 41.93750335324196, 41.511075035218276, 39.57570306716427, 40.68973464350547, 49.81227728628343, 58.700348484900694, 58.47680868641023, 56.29597479297269, 56.781666201929895, 62.128143079819225, 62.69510992111699, 56.97128534317017, 53.4670868996651, 48.809903821637555, 46.66795630608836, 48.67951246999925, 59.096021498403246, 63.327478362667954, 65.39603048755278, 63.82328556429956, 62.18067146116688, 40.69559466454291, 15.39784658339716, 4.60379961998232, 9.115458842246763, 1.6471259319974532, 0.3063112779730751, 1.587428561141414, 37.03210484596991, 64.26592503824543, 57.240665881864494, 51.6177168200093, 50.28247533305999, 64.81450773054554, 68.02276334454938, 52.872000586602, 11.905554494550152, 0.16971049259506887, 0.22655165784301298, 0.18687099999477788, 0.13544040732085705, 0.14908680812485758, 0.15367149195123106, 0.14631265053345313, 0.10599430109704695, 0.1511881873011589, 0.170152218892209, 0.11679120722316927, 0.21915025258016205, 0.10764075428127282, 0.1947797699681213], [0.010815009741382975, 0.011008711242597672, 0.14107817092970495, 0.034338703769589626, 0.0215735626331861, 0.053658207818385095, 0.035538006754171465, 0.04648099052569559, 0.018226495763707547, 0.061846550088375814, 0.0695679464467591, 0.0332503839425983, 0.05851663784274171, 0.036357199893363064, 0.02890549712784348, 4.385429015082698, 26.912925204923077, 46.8151746257659, 47.03116386167465, 30.127535058606057, 26.33860588073731, 37.62470045397359, 36.13052845001221, 44.263084473148474, 14.271328141612393, 0.11388185809576705, 0.07865742645076207, 0.9964566305279733, 5.791773757626934, 3.41732848555811, 7.825103488660629, 27.085882117671353, 31.464012092159642, 48.625932893445416, 50.3736900514172, 54.35218149615873, 54.475187024762555, 51.18836241383707, 50.76900612923407, 46.49728221278037, 44.22158971909554, 44.1741878755631, 39.074063301086426, 35.81150247204688, 38.23942607448947, 37.647779680067494, 37.158585594546416, 43.84616398042248, 48.929708696180775, 47.71029087804979, 46.68690919876099, 47.69645275608186, 42.88795248154671, 42.8429275943387, 35.911189509976296, 36.178914808457904, 34.94070491483135, 37.258013756044456, 40.30119642134636, 44.81756641018776, 46.177236418570246, 47.443283373309725, 41.24573846017161, 36.81869652963454, 37.235142415569676, 37.518525815779164, 38.796798798345755, 36.860465849599535, 36.9241572964576, 37.20020586444486, 39.02579461374591, 37.125449411330685, 35.87280127309984, 36.88156427875642, 36.362222856090916, 37.17457709773895, 40.1105692309718, 42.186926872499534, 42.01669992939119, 40.82577813056208, 40.26821321056735, 38.61061173100626, 37.47266154135428, 40.92593193054199, 45.65349017420123, 47.19801364406463, 51.287763118743904, 50.150432663579146, 38.8578857914094, 39.11215343782979, 55.115639471238666, 52.66044755135813, 51.14805613794635, 50.35054022266019, 49.28236507600354, 52.430565280299035, 50.653723747499534, 51.4709887966033, 50.46600695579283, 48.005229580786924, 40.917600816295995, 37.2755898967866, 36.48597755739766, 36.51219075725925, 37.933096808771936, 36.66583391927904, 37.2296981657705, 37.58715160431401, 38.696570473332564, 36.566519506515995, 38.897701771028586, 38.161582716049686, 38.14597168276387, 36.477360110129084, 37.152439240486395, 43.575489059571304, 49.71131940041819, 49.045748095358576, 49.40828884801557, 48.25077387594408, 43.8188878182442, 42.42333988989554, 45.33187543192218, 47.92698221821939, 49.45527492030975, 50.1295264305607, 46.3306442383797, 38.1373110894234, 36.86738883295367, 37.482687119514715, 45.465557652135054, 52.62702111274966, 53.57487363200034, 54.97827022306381, 53.28564982260428, 56.21254597940753, 56.027888636435236, 51.95242051155337, 50.02024919755998, 43.639611967148326, 45.979294007824315, 46.87405332442253, 53.24441002261255, 57.749656169645256, 60.74384058675459, 55.658683776855476, 35.0983920404988, 10.628646496803531, 2.540833195371013, 2.176168969561977, 1.2320902607133313, 0.036802729817047235, 0.8079304822510289, 28.790216676650513, 51.79476868721747, 38.96776314704649, 33.32827737254481, 32.35940487154069, 47.44036512990152, 59.97742514456473, 40.09320489821896, 2.97998960460386, 0.13585361982545546, 0.11056218461524095, 0.016496383862930442, 0.03667808348132718, 0.053426048703371525, 0.035344699788237774, 0.01877844296095352, 0.03516804757377794, 0.03147492346714341, 0.045537794564640334, 0.02353672997184819, 0.04832618990011754, 0.05534963419420585, 0.04034016379005006, 0.07583538070321083, 0.04575051802901491, 0.009278812888829459, 0.046881505122949044, 0.049727897144733905, 0.023314635336939848, 0.032860108110452854, 0.011698329227886373, 0.04863259825675238, 0.038922318903308724, 0.024222129685503822, 0.056478671594372684, 0.029722110465950066, 0.04532266558418351, 0.030797900924939784, 5.73051368997943, 33.08172502825337, 55.42940162843274, 51.59155068858978, 31.788864751015943, 21.79451846307324, 27.387333916079616, 38.414885459407685, 50.67553604802778, 15.173982208774937, 0.054837102220664104, 0.04899582352429148, 2.046405074577178, 7.505568583165446, 5.051385202715474, 12.26398068089639, 20.30308231230705, 30.000218845182854, 50.049262969724595, 50.902939381137976, 56.00299335295155, 55.73602899428337, 54.580420294115626, 52.6415652613486, 49.26578913965533, 47.952399176936, 46.21744855757683, 40.78582094561669, 36.79643315653647, 39.292578543386156, 39.300050658564416, 38.06511594403175, 46.39334724795434, 51.08410973702708, 48.2392381852673, 47.79403348122874, 49.59455828512869, 45.11702368336339, 45.66342553784771, 40.55674276044292, 38.59884069811913, 38.101233128578436, 41.065144692697835, 43.312686335655954, 47.90625641422887, 47.75395078043784, 49.99197283098775, 43.386834821393414, 40.22414538168138, 37.77516257378363, 39.54953693574475, 38.64391265376922, 38.78370200434039, 38.18395591551258, 39.29870136322514, 40.33298723159298, 38.29080520137664, 37.235040433945194, 38.35240994730304, 37.358512724599535, 37.99665881741432, 39.950332564692346, 43.5789603571738, 44.50395330306023, 42.22613880711217, 40.93295297315044, 40.21957974280081, 40.522437710915845, 44.98873864450763, 47.02642171613632, 48.90134995983493, 54.16026384599748, 51.383186540296, 41.48947454267933, 40.79082981232674, 55.49597993973763, 53.727045905205514, 53.7167339940225, 51.72117717804448, 52.960685376198064, 54.122648316044966, 53.2100147585715, 52.47999106684039, 52.29655750336186, 50.18758143148115, 43.61192395610195, 38.47556060360324, 38.9110182177636, 37.792970134365945, 39.44528425893476, 38.37005669070829, 38.12069200700329, 39.148709927835775, 41.438377826444565, 38.59678929851901, 39.05113704742924, 39.4598440970144, 38.6087917512463, 38.320022936790224, 38.30362742946994, 44.566985791729344, 51.597081230532744, 51.02356010867704, 51.92981981462049, 50.65473571900399, 45.80942007803148, 44.277134403105705, 47.595859650642645, 48.13751935958863, 50.11300540739491, 52.3058888220018, 47.494360477693625, 41.313724902368364, 39.47431764295025, 39.624007055836344, 48.78174120380033, 54.71753851059945, 55.60942665223153, 56.12689710432484, 54.364866441295995, 57.66217947006226, 57.646062451024214, 54.96323577819332, 51.12053678881738, 45.64009528006277, 46.649309358289166, 49.188553748592255, 56.84238449219735, 61.588287661152506, 62.74370024281164, 58.97056056607155, 36.397077037442116, 13.300631738478138, 2.0319627850286426, 5.1063783034201595, 0.47949587205244654, 0.032448270733678536, 0.7039155991327378, 31.653478260963197, 58.137637415239894, 45.13856141797958, 40.763957654276204, 42.3973737993548, 53.85234602036015, 65.00642145833662, 46.711098455613666, 5.153939493240849, 0.22258244905500646, 0.09053337507911267, 0.03254218545231608, 0.035755119902352174, 0.04341944654081618, 0.03771316785846026, 0.029461904872028582, 0.01884879856069963, 0.08043030712513194, 0.032634234746858, 0.0564853672028309, 0.035753273630454656, 0.04665409192262639, 0.027962153694862803, 0.208569705005615, 0.10959082343164953, 0.1901739267932792, 0.1171206480132476, 0.14415292610083857, 0.17369863907656363, 0.13861227179727248, 0.15530770253990928, 0.11582822704146947, 0.1366088905882451, 0.25267111918618607, 0.10934096385514545, 0.09884666245911392, 0.10015066668030717, 0.06828833446507493, 7.254570232283685, 38.89748211829893, 64.06890438448998, 58.08902355932421, 40.68158003591722, 34.6011806303455, 51.14482410492436, 47.271722824342795, 56.04815160074542, 17.273310230624293, 0.21078412811602318, 0.3409340088405917, 5.510073544517641, 13.905007204701825, 11.184322795560284, 14.07312979621272, 29.825885180504095, 34.16215365932834, 51.40892121099657, 53.27789137440344, 56.894638307632945, 61.08886011185185, 55.495042493266446, 55.803580053391, 51.94670169584213, 50.5400416927953, 49.3554231428331, 44.59239490570561, 39.57524414985411, 42.05393498943698, 41.16509845179897, 39.9407462919912, 48.80306713042721, 52.44864740679341, 49.595072115621264, 48.455337247540875, 51.99649226280951, 47.55218798114408, 47.59517715823266, 42.910588479811146, 40.964696714955, 40.273363282603604, 41.712665250224454, 44.53837994606265, 50.85765169512842, 50.438660190951445, 51.750708703071844, 46.02645266440607, 42.09744191938832, 40.34120851947416, 41.0832150520817, 42.21365390285369, 40.37135585661858, 40.122461857334265, 42.13318647876863, 41.64554565183578, 39.39563881966376, 38.69214603977819, 41.291022223811, 40.110675134966456, 40.17497454920123, 43.08781293130691, 46.10567277477634, 47.19993560544906, 44.30393988086332, 44.3087879303963, 42.73909461113715, 41.71397532186201, 45.94751496468821, 50.82379379580098, 50.6285225191424, 57.1543227472613, 51.77439589654246, 42.66150620675857, 42.34153493758171, 56.46082416657479, 58.21384514531782, 54.44964455020044, 54.415049245280606, 54.38226607538039, 58.57828432513822, 53.94956980982135, 54.703845516327895, 54.2313999514426, 52.344151543032744, 45.21930340797671, 41.026203401627086, 41.3948905083441, 40.67344504017984, 41.428964138031006, 40.11345609541863, 40.06577968597412, 41.67116265143118, 43.2961457006393, 40.557382106781006, 41.67291202852803, 41.14233693768902, 41.31088510636361, 39.35609348358647, 41.640046488854196, 48.444797838887865, 54.88087384931503, 54.536764314097745, 52.590570526738325, 53.44519222936323, 48.651145888913064, 48.150153313913655, 51.33787532006541, 52.50322326537102, 54.99399108271445, 56.040314705141135, 51.6257498341222, 43.46822792483915, 42.999159520672215, 42.73429363004623, 50.41671060746717, 58.29051571507608, 57.80249441823652, 58.217206616555494, 55.40247455719979, 59.27092390675699, 61.64957861746512, 56.39444589614869, 54.74521475453531, 47.92945331142795, 51.11318234474429, 52.07681063682803, 58.184470515097345, 64.8370848932574, 65.58828546154884, 61.32219799103276, 38.07935807012743, 13.21575164794922, 6.0302254269199995, 6.152914224132416, 2.8807982562049745, 0.16933746906297822, 1.1235821799885843, 35.728787529853086, 64.60153087492913, 51.679015621062256, 44.552775044595045, 43.93548811635664, 62.88873380230319, 74.13407494944911, 57.01718099655644, 7.5768385394927, 0.25244282498475046, 0.29750092976516296, 0.12380857260957842, 0.1837596717861391, 0.1495304496418084, 0.15085447940134233, 0.1464680284862557, 0.10951563956276064, 0.19238145511236884, 0.12940432395665877, 0.1726559168028255, 0.15346170643404608, 0.18383571367350318, 0.09927329682414571], [0.0881438625736102, 0.05878458858557767, 0.0684725096629512, 0.032307957899906946, 0.009290825147482177, 0.06799919756069299, 0.03427450943197455, 0.08314067257508155, 0.062463909703036474, 0.037367248517130656, 0.028749263071785533, 0.02481939672913042, 0.06485793063597334, 0.048689863329092344, 0.0752060164907767, 1.6089932620525362, 23.567206205860263, 47.32373737519788, 51.801319045405236, 40.575456388535045, 21.029866126275834, 36.516670103996034, 45.25136486176522, 43.15781547177223, 17.040029225810883, 0.1271745637660065, 0.1696066417160534, 1.7049969492420074, 6.341417941354937, 4.947706172543188, 12.171967760209116, 21.735088671407393, 32.83970498269604, 47.483271937216486, 53.57906272334438, 52.0862360923521, 52.62489126574609, 53.57534823879119, 50.66196464723157, 50.72061584841821, 48.661642151494185, 45.3362214180731, 42.487878568710826, 35.82011991931547, 36.41357844875705, 37.167732561788256, 37.74624686087332, 46.4009762579395, 48.83445393654608, 47.55841278260755, 48.80899775412775, 47.08305681905439, 45.017571987644324, 41.63086029791063, 36.17517286731351, 35.020536914948494, 33.136096923582016, 34.58897813673943, 37.10133075714111, 37.25209489945443, 41.391203480382124, 38.78887953296785, 37.51193623388968, 36.052481128323464, 35.608253094457815, 37.96735086748677, 37.35369605402793, 36.404392257813484, 36.187238077963556, 38.385004843434984, 38.52097380545832, 36.26451269272835, 36.723798705685525, 36.93381024945167, 36.950927472883656, 37.46183187730851, 43.38423821233934, 42.3560594743298, 48.2033210415994, 45.76812928722751, 44.486455609721524, 44.93601022228118, 41.657552026933246, 41.66571447926183, 45.20431210917812, 47.27146787028159, 49.25368862767374, 53.79160811824184, 39.612149730805434, 43.130762884693766, 53.48895411337576, 48.37246148817001, 49.02191969656175, 45.736993512799664, 47.63500098259219, 46.61665954897481, 49.48295508661578, 48.770695809395086, 50.522222365102465, 46.8548023316168, 38.058126280384684, 37.97183413659373, 39.49431388608871, 37.34955795349614, 37.848126503729056, 37.422176714866396, 37.412104068263886, 35.55965100565265, 35.934064772821245, 38.10195876706032, 37.53562342736029, 36.3474472876518, 38.77291156399635, 36.84883602203862, 38.23306791244015, 45.072159613332445, 48.83745847209808, 50.03147894336332, 50.39275669282483, 49.88004015338037, 50.662619683050345, 50.27080628179735, 47.552301729879076, 47.16498728721373, 51.37188226945939, 50.312489309618556, 48.73421776679255, 49.448626502867675, 38.511262016911665, 36.70265320808657, 37.622409789792954, 42.59919543420115, 50.060720212997936, 55.990363320996686, 56.08404128782211, 55.1918315118359, 58.88590405064245, 54.115129132424634, 51.03806111120409, 48.026245640170195, 52.94532537460328, 51.81364705485683, 54.285618874334524, 58.53346340117916, 59.138453698927364, 57.30218825801727, 33.287994630875126, 8.929870916951089, 0.5068985306687894, 3.006791650287567, 0.16635686609773867, 0.0988083963672961, 1.0273041107481526, 29.547816591878092, 53.28015065962269, 43.9836234431113, 33.34080934524536, 33.12156061972342, 51.13314720892137, 54.34969863583965, 42.70749599702897, 4.997109895752323, 0.029387107877541455, 0.02659182924206459, 0.030628041995148507, 0.018757858178428104, 0.014667265631649044, 0.02165998501192418, 0.02523675376939918, 0.05524545772782257, 0.012550318591116418, 0.012941494576572891, 0.017425476145299695, 0.019873142385134296, 0.02604243503282628, 0.02108123048298782, 0.06112085798034265, 0.07617748492667753, 0.057955838499530676, 0.02237531386556164, 0.033914926912515395, 0.03329025498861748, 0.06341901450087467, 0.08765378846756874, 0.030912394680443312, 0.005102877189675647, 0.025747493097198107, 0.014573817269035406, 0.04219776229752649, 0.07581107273337341, 0.08704929146915676, 2.7214853081011006, 28.126114299220426, 54.65228988278297, 56.3628198254493, 44.09040212631226, 28.272510882346864, 41.29139484897737, 44.320398146106356, 47.445268092616914, 19.75756299111151, 0.11960071211140003, 0.09585908043288416, 3.115149332631019, 6.681385453670256, 7.933254511125627, 9.00789862678897, 17.671775971689534, 33.2177096797574, 48.84964135385329, 53.14033385246031, 53.14533487443001, 53.0549281643283, 53.98650284736387, 51.450196312319854, 51.9471449236716, 49.79423438349078, 47.57037601163311, 44.91779081283077, 36.71116082899032, 37.873621909849106, 37.88951927615751, 40.34742547619728, 47.347204915938846, 50.50914126057779, 47.718017947289255, 48.08449675959926, 49.036710954481556, 47.937211759628795, 43.82472038269044, 38.43971798496862, 36.92192939019973, 34.65507007414295, 36.996642697242, 38.797481290755734, 40.71887785388578, 43.431510617656095, 40.35207740722164, 40.92732437195317, 36.01501072606733, 36.9338769297446, 39.370363066273356, 38.67313431155297, 37.214318552324855, 37.486072124973425, 39.6783201156124, 41.07917108843404, 38.02040876880769, 37.77209528030888, 38.961283391521825, 38.379588050227014, 39.26420411755962, 44.32381845289662, 46.11334493083339, 49.718869962999904, 48.44421340573219, 46.75556636625721, 46.75226373057212, 42.617120665888635, 43.55450830151958, 46.772393334296446, 49.52924297701929, 51.49347182243101, 54.01716793737104, 39.73868931493452, 44.188386855586884, 55.11637687683106, 49.07065122358261, 51.05206397271926, 48.014039224193944, 50.116437481295684, 48.84068266037972, 52.852380891000074, 50.34604126407255, 53.14745687669324, 48.298179641846694, 40.33609374876946, 38.97634137061335, 39.345279509021395, 39.165305476034845, 38.807353896479455, 38.707215785980225, 39.46254661006313, 37.098239929445334, 39.35147685389365, 39.431450059337, 39.70548252905569, 37.71801756274316, 39.678610371005156, 38.151474768115634, 41.33282292273737, 46.69198082339379, 52.57140190370622, 50.81653348861202, 50.27473649671001, 52.51161713753977, 52.457915967510594, 53.30772884430424, 51.754093708530554, 51.08756142277872, 52.96300741934007, 51.97753937013688, 53.83458945059008, 51.80166813635057, 39.65027516888034, 38.72021452073128, 39.861620318505075, 46.19649917848649, 52.35478901094007, 57.01012465261645, 56.378372023182536, 55.65063507326188, 60.72686064627863, 56.318328380584724, 51.86323365857525, 50.49331841930267, 54.86666310218073, 54.357123682575846, 56.9387218259996, 61.04185050533664, 60.662761272922644, 59.349932209137954, 37.16831307257376, 10.151789246066924, 2.5352202836544286, 2.3456013875622905, 0.4675029801024545, 0.07249591917160057, 0.8900998472686737, 33.77696906366656, 57.68278368057744, 49.428677328171275, 33.00282655223724, 34.182055765582675, 56.7804894908782, 62.15737258234332, 49.25624993539626, 6.419020074029123, 0.07492511503158078, 0.022599465446546677, 0.019612191770706448, 0.04602809849705908, 0.03777583002022678, 0.04292990869632171, 0.02872535155244893, 0.04090698458434593, 0.05726195819255325, 0.0070175947339814766, 0.06451823958946813, 0.014143679966969837, 0.01309328819549973, 0.05473570282300634, 0.10551250074058773, 0.1722371578216553, 0.20754950571685069, 0.1313901004651862, 0.18114916589711944, 0.13720328288693584, 0.17119265822393281, 0.15970395938042672, 0.11087113255334478, 0.15338819263683212, 0.1266830340929089, 0.11194054533036486, 0.23587346167093326, 0.1903742281419616, 0.16158078286436298, 3.1640289291258785, 33.792603631173414, 63.90405108851772, 62.13555243707473, 53.976975410215324, 33.072056385778616, 44.87270709007017, 53.93563362859911, 55.995281973192775, 22.129108405882313, 0.368023184278319, 0.3064418806424064, 3.931939284647665, 14.5828898491398, 13.460327117673813, 18.109551706621726, 25.85792922204541, 36.29131032574561, 50.088427835895175, 55.04919059814946, 55.10078153302593, 57.10288870719172, 55.45397135519213, 52.89292643147131, 54.268164327067716, 52.71010083536948, 50.66477306427495, 47.509532205520145, 38.72910261154175, 39.91933407322053, 40.46047602930377, 42.97069880270189, 50.72154545014905, 52.52033656643283, 48.09234149994389, 51.180011687740205, 51.35945620075349, 51.39733060713738, 46.32855753744803, 40.33878057233749, 39.21767696257561, 36.5976042901316, 37.4241457446929, 41.56977722721715, 41.208640683081846, 46.23525219578897, 43.17146531997189, 43.67403468778057, 38.77034633390365, 38.47377984754501, 42.0071058119497, 40.74786416945919, 39.40799036333638, 39.623524604305146, 41.68115292826007, 42.23252442575271, 40.43520812065371, 39.537683533084014, 41.498139058389974, 39.21519410225653, 40.96854848246421, 45.65262333039315, 47.46823356997582, 52.363508439833126, 49.429763824709006, 49.28065100023824, 49.20707125817576, 46.2864665831289, 46.203355481547696, 49.9214643047702, 52.21673727035523, 55.59205447473834, 54.54426388586722, 42.96979273519209, 47.403777260934156, 56.361294023452274, 51.9997517524227, 54.633815519271366, 50.41244306871968, 52.34508114476358, 51.5636783261453, 55.039890658470895, 53.06546757298132, 54.817182402456964, 50.91157644025741, 41.82356634447652, 41.784170058465776, 41.87895805604997, 41.576045174752515, 41.38235069090321, 40.53925683421474, 42.401504055146255, 39.15465624101701, 39.99817371368408, 40.939632769553896, 40.543995057382894, 39.24783998920072, 42.276851131070046, 39.98588492793422, 43.33535371288177, 50.00981569290162, 54.576748955634336, 53.28898383725075, 52.301562447701734, 53.74375127976941, 55.10060894873835, 57.207219831405155, 54.843976113104056, 55.068916197746034, 55.65065076274257, 51.733465963794345, 54.250533273143155, 55.2511259817308, 42.43521682677731, 40.23719902961485, 41.53424447582614, 47.48312288714994, 53.83578185112246, 60.00315981526529, 58.809735544266246, 56.80771466224425, 63.320559301683986, 59.34545286240117, 54.72225712191675, 53.82905890864711, 57.63445223531416, 58.226224145581654, 60.15885829925538, 66.04487680619764, 63.13143045671525, 62.83339700391216, 37.249196267897084, 11.540309267659342, 3.824178538014812, 8.216439831641413, 0.7494741738323243, 0.21303780557167148, 1.7817833514944201, 36.38489023331673, 67.10761947016563, 57.735790591086115, 47.69702149975685, 44.20497455904561, 64.97224584702523, 69.38111151418379, 58.63695121580555, 9.693955490666053, 0.22767031475180582, 0.15185667562388605, 0.14596369748394336, 0.1435145143900187, 0.1643019424931657, 0.13143286349311953, 0.14074005036344453, 0.1518078758231094, 0.11060488635614035, 0.05072392635948716, 0.19386544403049255, 0.12019313556412536, 0.12436595520064717, 0.2002423599122032], [0.0023312618131674226, 0.013629170528973543, 0.02343500498682261, 0.03974259605691318, 0.0986103626388696, 0.022947451310052026, 0.055139683968117165, 0.014048032932013515, 0.08732707495050085, 0.05806220980781702, 0.027256203672638344, 0.03226940069467791, 0.036603183064970284, 0.015238704020908524, 0.01979729968063053, 0.6183883175253868, 17.472821589439146, 47.85931741037677, 50.5430736849385, 34.7540863867729, 19.528186705804643, 30.156999903340495, 45.07561522145426, 43.627189820812596, 25.02034825663413, 0.4127415750295885, 0.07854534012656059, 1.6251816191980917, 4.60124223462997, 3.844911451301267, 11.08231665626649, 18.451788310081728, 37.11253304635325, 55.09285050053751, 51.92778410450105, 53.594850263287945, 54.16215050605036, 51.00105354862829, 52.86988642907912, 51.788343844875214, 50.18807957249303, 49.45699684081539, 47.699139579649895, 38.85389674094416, 36.21231771284534, 35.87332687070293, 43.301185946310724, 50.90063302747665, 47.98530394031156, 46.345662993769494, 47.27772797307661, 47.120507609459665, 44.272392257567375, 41.487619261587824, 36.633803844451904, 37.196028540211344, 33.37463194324125, 35.909047895862216, 36.64816364165276, 34.88067303934405, 35.32967852007958, 36.39565713943974, 36.683327690247566, 37.2313847849446, 37.1768363829582, 37.68714850948703, 35.53966260725452, 35.8973043195663, 36.983016383263376, 38.52435488854685, 36.27320466503021, 37.43374378450456, 36.629504926743046, 37.361191703427224, 36.31778632440875, 39.22863606483706, 44.52044686963482, 50.936048107762495, 49.64169732985958, 43.61107672414472, 48.28513776102374, 46.30749440962269, 44.25116831256498, 44.06610304309476, 46.934061665688795, 49.59675873479536, 50.37687109362695, 47.35808949316702, 42.30478232906711, 45.74213574009557, 53.12564457616499, 47.44034551805066, 46.73972391313123, 44.67479213591545, 43.83204737017232, 43.743374347686775, 45.93109200077672, 47.64352429297663, 46.43841135886408, 39.01162309031333, 37.70642695888397, 39.06465353504304, 38.067430142433416, 37.261406606243504, 36.992108437322806, 38.486001953001946, 38.57765989918863, 36.617310277877316, 38.65912360529746, 36.682276495041386, 37.129426694685414, 37.30829461928337, 38.450684931970414, 36.04824104616719, 37.968433441654334, 43.83958616564351, 48.89425046982304, 50.01536192432527, 50.08422305507045, 48.402189131705995, 48.41922006299419, 48.3501196676685, 47.23825323966242, 48.479942275631814, 48.92978322121405, 44.39074193277667, 47.04450776500087, 53.21849100051388, 50.24744856742121, 39.52849341977028, 37.201178612247595, 38.49181098322715, 45.10113023942517, 50.61702605216734, 53.61234795662665, 55.03874140401041, 58.5260344320728, 55.13469434553578, 54.48044692316363, 55.576514044115626, 56.27216208365656, 57.395324937758915, 57.23238968080091, 59.64542788843955, 60.530314599314046, 57.22856929225307, 28.773362252020068, 8.08484088028631, 1.1693219191605047, 4.994744706538416, 0.5981527485193745, 0.039056648590391686, 0.8595032148784207, 28.76531747079665, 53.857668676683986, 38.3264870028342, 36.731976847494806, 43.692834608016476, 51.050326362732925, 59.08638423488986, 40.37883581653718, 3.30459711532439, 0.09936187190995102, 0.046896240824172576, 0.05297956500022162, 0.04774785480431972, 0.09985357012239196, 0.006068661731983265, 0.04698073266134147, 0.006560802839005427, 0.022717490867381136, 0.05284916917462984, 0.05930502275605837, 0.07168432562461785, 0.05973223168703337, 0.06584505024816721, 0.053611549233356794, 0.026159204069464922, 0.08805604591484993, 0.041782228546517516, 0.10482443887139521, 0.11085820098918293, 0.01258729478239172, 0.054323022749515316, 0.05192545099904941, 0.027647477334305167, 0.028639689515975696, 0.07999493935776335, 0.032683796805119326, 0.0976912639734726, 0.055761211101085915, 0.7870867620072057, 22.52986481112819, 54.03038632485175, 55.21993137175038, 40.66299584604079, 20.44487403285119, 31.16753189794479, 52.05084846865747, 48.59211029544954, 25.89272652902911, 0.5872231866082838, 0.09810802346516041, 1.5492218564594946, 5.090801590873349, 4.691549904884831, 7.811514927494911, 16.155665170761846, 38.02016558185701, 55.119244129427024, 54.43735576445057, 53.50866402349165, 54.83676679672734, 53.530182146256976, 53.425215598075624, 52.380127522253225, 52.45511931757773, 50.411548768320394, 50.27283806954661, 40.06473241313812, 38.15010193855532, 37.573144820428666, 44.04571064056889, 51.92086896588726, 49.613342515883915, 46.06499779608942, 48.731762363064675, 49.40701407770957, 44.82190455159834, 42.61673235124157, 37.911311964834894, 37.76010067232194, 35.69517673984651, 38.49051660107028, 39.0518940648725, 36.02383605895504, 36.989668723075624, 38.36792292133455, 38.14768575852917, 39.614216819886245, 39.38438946200956, 39.14141431931527, 37.78873789695002, 36.89785780445222, 37.85408066165063, 40.54070026643815, 37.81472752171178, 39.45019114402033, 38.79545342537665, 38.23820229499571, 37.05861614596459, 39.440695085833156, 46.16754816424462, 51.39322388556696, 52.56385134112451, 45.02930379682972, 49.78555810066962, 48.189318180084236, 47.27617471448837, 47.00411519696636, 50.232496492324344, 49.9086695332681, 53.840092535941835, 49.460503439749445, 44.471350562187936, 46.96838632706673, 53.92320363752304, 49.59944948073357, 49.353501181448664, 47.430323862260394, 46.5536819734881, 46.15347862243653, 47.65855481547695, 48.397443063797496, 49.278391715018984, 41.08160295794087, 39.13406379761235, 40.80680954840876, 39.47464712204472, 38.301124957300004, 39.4264058912954, 38.92941413387176, 40.346240920405236, 37.560844267568285, 40.63288381022792, 38.619052671617084, 39.295132006368334, 38.65261639318159, 39.257104627547726, 38.804733753204346, 39.835305137019006, 46.17045464054231, 51.74879066405758, 51.96754124856765, 50.77099084854127, 50.28083185995779, 50.8750670186935, 50.76492294188469, 51.021194919463134, 50.50081406870196, 49.978981940977036, 44.84223419620145, 49.26680111115979, 55.23704075044202, 51.47630360818679, 40.69747740222562, 39.61382458286901, 40.42275067298643, 49.01570666220881, 53.13887865312638, 55.127179084285615, 55.49865499619515, 59.494036166898674, 57.4182080453442, 56.313641148228804, 57.673785763402144, 57.93394480982135, 58.98641870867822, 59.59721803665162, 61.399111747741706, 62.57095513805267, 59.17982685950495, 33.16229835633309, 10.511807914703123, 4.033148692500207, 6.467194134189237, 0.3362733137703711, 0.03733016603115586, 0.9526435105550675, 32.82416062970316, 58.75515576331847, 46.125696474506015, 37.84589075273083, 45.98566393698416, 59.042488990291474, 62.54349070210611, 48.67846127479307, 5.52383468997094, 0.06008640179530748, 0.047702923747560674, 0.10364186724707966, 0.027286552245758718, 0.0608554506494153, 0.022621911822728092, 0.04705822628532206, 0.00568199034352156, 0.02859978974165936, 0.0908330686750912, 0.01935858793947245, 0.010144746009891313, 0.0648096364532267, 0.02340185444711918, 0.18992966731950162, 0.06152892620452951, 0.20272836119176882, 0.14979645069087708, 0.28856472863305, 0.2398813885426329, 0.15547417344585543, 0.11153552230567702, 0.18050529964027867, 0.18125411994274587, 0.1340864848105177, 0.1442769557357796, 0.17608976802758633, 0.18334426827007727, 0.14526730823901393, 1.0735523484406935, 25.83889788196933, 61.06136821931409, 62.077513125634965, 47.72490955168202, 28.693002693114746, 39.89972222235895, 54.45460242609824, 54.004537905416186, 31.910169932150076, 0.9146057129386933, 0.26149887291173785, 4.361790851239236, 11.945161607957656, 8.988906510414617, 16.479953988905876, 21.78461055601797, 38.094035579312234, 57.51349810631045, 55.68862715075093, 56.50052639745898, 56.79575535558886, 55.82832628680814, 57.11339673688335, 54.70392788610151, 52.97798302865798, 53.88146177414925, 52.59947822939966, 42.31044230922576, 40.315360100038596, 39.5622964059153, 45.47469677463655, 53.70939916180026, 50.85545909020209, 47.10764615766464, 50.803319023501494, 52.15328508807767, 47.223360000118134, 45.29162799158404, 40.19979530765165, 40.27796030044556, 38.625630486396055, 41.06123801200621, 40.72738155241936, 38.345392827064764, 39.101786613464355, 39.08330048284223, 40.38552345768098, 40.955679185928844, 40.01594597293485, 42.05464493843817, 38.371990419203236, 39.15488766085717, 41.02725459683327, 42.38869751653364, 38.70324634736584, 40.68427470422561, 40.81901988675518, 41.20450258255005, 40.49160395899127, 42.07866161100326, 47.701136066067605, 53.06291410999914, 52.419025667252086, 46.09382721685594, 52.75287428209859, 51.73167736299577, 50.321177359550234, 48.92065586582307, 53.16153034087151, 53.29236492033928, 54.73984895213958, 50.82502934240526, 44.92046979165847, 50.41138010640299, 56.64575607545915, 51.35428259449621, 51.291379544042776, 50.31539578591624, 47.407393686233036, 48.76346688116751, 49.39934192165252, 50.654492532053304, 52.1686254778216, 42.65060986241987, 41.14828717324042, 43.868050805984005, 41.96528942354264, 40.566544763503536, 39.83290856884372, 40.74611871473251, 42.79731042923466, 40.138598488223174, 42.47827660652899, 40.15839469048285, 41.20082732169859, 40.81840799700829, 42.69575634310323, 40.36107140202677, 41.64004256648403, 48.152789146669456, 53.61746272733135, 55.320755897029755, 52.0071061964958, 52.298475542376124, 54.3287374896388, 53.63826697872531, 53.62058101161834, 52.73763979634931, 51.01464063890519, 46.69882928171466, 49.61156960456602, 58.28464000455795, 54.98632677139775, 44.14502113096176, 41.51782543428483, 42.98157553518973, 49.56619562641267, 56.04948912897418, 56.87421060377552, 56.38795045114333, 61.67694107178719, 60.08378413415725, 60.44074335405904, 60.41975867363715, 62.32436749242968, 64.22181798565772, 62.65836123497256, 63.53157104984407, 63.92860120342624, 63.5725127497027, 33.11714010853922, 10.794897137149688, 4.056796417120965, 13.385250010798055, 0.8726217044937996, 0.12421144292719903, 1.0012946902744233, 35.44085418024371, 65.3931632349568, 52.29574165036602, 49.968697486385224, 55.847326247922844, 66.6468115775816, 72.22356688591742, 57.492199636274776, 7.124408829596735, 0.11688314543496217, 0.14138992274961165, 0.11592723624480349, 0.1577385301671682, 0.18166054490833514, 0.10909465126573079, 0.1606737347620149, 0.10007074072716698, 0.11111916884058907, 0.17639925222723715, 0.11585537719750598, 0.125989280190439, 0.1694722086071007, 0.09605272447750454], [0.041642896305289, 0.037692755445717804, 0.1597284741940037, 0.03859142254617426, 0.03774799038505843, 0.04052874782393056, 0.01912139371157654, 0.07572458140672216, 0.01769874545354997, 0.026412499550309394, 0.02842894255844576, 0.04033187088826972, 0.029071111930534247, 0.07952553430391897, 0.027275212229259556, 0.07567423410833844, 10.966838156023334, 45.183817725027765, 53.309897915009536, 41.19861902729158, 28.832431185630064, 23.2279957109882, 23.633696263836278, 48.161618401927335, 28.97917489851675, 1.9725413283994122, 0.06605184802244748, 3.277841647786479, 2.203279656748618, 5.044893680080291, 3.031905851056499, 17.115868253092614, 39.7631609824396, 52.113578934823316, 54.27068248871834, 52.27714177100889, 53.65041063677881, 50.77039857064524, 50.135245246271936, 49.37949865095077, 52.069758215258204, 50.5752214308708, 48.57621685151131, 40.676296603295114, 34.596544388801824, 37.21890380305629, 42.886461980881236, 48.13968058555357, 49.27498709770941, 47.08614764675018, 47.677335123861994, 46.878203192064845, 46.32272889537197, 44.35808035635179, 40.22674591310563, 38.12939182404549, 34.46239540653844, 36.369585144904356, 34.810458690889426, 35.044259409750666, 35.36957686947238, 35.71278818192021, 37.823148850471746, 38.141880650674146, 34.355130349436116, 36.47943896632041, 36.206069377160844, 37.66918013172765, 36.48597755739766, 38.081640889567716, 35.73048983850787, 38.813037410859145, 37.19131385126422, 36.860520762781945, 35.72459451613888, 39.73000126500284, 43.60809180044359, 52.10547531804731, 38.39494020708146, 44.883650502850934, 47.58795607474543, 49.1742802435352, 48.88400523893295, 46.76359545799994, 45.36666685535062, 47.144469368842344, 46.53966342249225, 46.36312146340647, 43.608825283665816, 46.13504740499681, 52.20637829073014, 46.522287322628884, 44.57277128773351, 38.51743582756289, 38.549132500925374, 38.788134282635106, 40.64951465975854, 38.48211096179101, 39.3282485777332, 36.788404064793745, 37.63556934172107, 35.82030034834339, 37.791593382435465, 36.928056132408884, 36.50050601651592, 37.19836235046387, 38.08434732498662, 37.68462250309606, 37.99669804111604, 36.63266243473176, 38.1303684942184, 39.26420411755962, 36.697338396503085, 38.09580456825995, 35.62331107354934, 42.9438619459829, 49.27260229664464, 52.71641192897674, 48.80810737609864, 46.4537674380887, 48.38478557525143, 49.42611994281892, 53.36882760447841, 54.014685077051965, 51.30356242579799, 51.40487332497874, 53.00257236726823, 51.16152947948825, 53.29106269344207, 48.11262799847511, 37.605629890195786, 37.519910412449995, 40.9347298068385, 48.112569162922526, 56.500816652851725, 55.01415206540016, 58.163756478217344, 54.88699274678385, 55.94537373512022, 54.671525186108006, 57.06893274860998, 59.00250434875489, 61.44154002589565, 56.74968319554483, 58.46034257642685, 45.58403284318986, 25.72233092400336, 3.5843251116814154, 3.2737503705486177, 0.544732456966754, 0.6046879688097585, 0.25212586376695867, 0.42055867492191257, 32.38329210589009, 52.602482764951645, 50.36238185821041, 30.88900439200863, 26.098686264407252, 43.33055665416103, 53.0310409299789, 37.92675825857347, 2.716758606895324, 0.14120298197432873, 0.15253333044388603, 0.024862502581409873, 0.01577060844283551, 0.06313312580929169, 0.09800503826549939, 0.06738207543328886, 0.026243646110918735, 0.025025225402186477, 0.036994791890103976, 0.06324135871123403, 0.053085610721140146, 0.056086469051097675, 0.06200056823511278, 0.024623218848700487, 0.02329324616209394, 0.08121848902514867, 0.0541811662485763, 0.037650827453621936, 0.06156417007948603, 0.040469188318257375, 0.029343371917944283, 0.017920393842242418, 0.04504875084685703, 0.03445416471109756, 0.041180960608706366, 0.09204513468449155, 0.05745564820244909, 0.08735923532156215, 0.12060996400372637, 14.256994820410206, 51.93774692473873, 59.178603080011186, 47.91044550557291, 29.842214007531446, 25.79737763251028, 36.16252714587797, 52.249908754902506, 33.672579103900546, 1.95200759797327, 0.12461312580853702, 1.462913778039717, 2.346137281387083, 6.288859161638445, 5.927674568468525, 13.673671695493884, 40.07156125960812, 53.53436339286066, 55.80434883794477, 53.85233033087946, 52.435856557661495, 53.604585586055634, 52.19527406077231, 51.80338221211588, 52.87162403906546, 52.128519242809666, 51.14129789413945, 42.384069119730306, 36.52598965552546, 38.925731028279955, 46.070238082639634, 50.99182028924265, 50.486493495202836, 46.66315140262727, 47.42036496439288, 49.803534323169345, 48.08528123363372, 46.16936814400458, 42.90819583400604, 40.74589513963269, 35.5960702127026, 37.31964203619188, 37.40910737745224, 37.232788993466286, 36.96796232654203, 37.86146256231493, 38.27545696689237, 39.77664216872185, 38.09334916453208, 39.128137096281975, 38.69493876734088, 39.57265538554038, 38.77637109448833, 37.78874966406053, 37.5400282490638, 40.13346410566761, 38.49952236298592, 38.6850740063575, 36.26094725824172, 42.54251326284101, 46.92226317621047, 53.10759382863199, 42.803907855864495, 46.93527367807204, 49.9403505171499, 49.43934617503997, 48.89294824292583, 49.44701833109702, 48.300638967944735, 50.850399232679806, 48.29839929457634, 47.960373355496316, 46.037517670662176, 48.63264406881025, 54.041443486367505, 48.31065670136483, 47.38599323457288, 39.377101698229396, 40.31827442107662, 40.363750380854455, 42.0403871228618, 40.557240901454804, 41.20252178561303, 39.467390737225934, 40.48117829907326, 37.40647938943679, 38.968041635328724, 38.080911328715665, 39.03441990575483, 38.933187453977524, 40.32999054078133, 39.00347240509526, 39.03924049869661, 38.452198966856926, 39.00811256900911, 40.02112742393248, 39.662018745176255, 38.13345147717384, 38.701755846700365, 44.72402180394819, 51.04622356353268, 53.30455564683484, 50.37274476020567, 48.54806207841443, 50.8754631780809, 50.71586193576936, 53.590390528402025, 56.21921400870047, 54.514367580413825, 53.8530755812122, 53.4159666492093, 52.357754322790335, 54.86734559459072, 50.280455312421246, 38.09147034921954, 39.25121322754891, 42.53660225099133, 51.01537804449759, 57.14909030545143, 57.331213797292406, 57.85845095111478, 57.16091625152096, 57.294237613677986, 57.76652236138621, 61.014974424915934, 61.17528953859883, 63.24427704657278, 59.12806726271107, 62.388933627836174, 48.58100998786188, 26.617402069030273, 4.603661846730017, 3.1260194461191855, 4.1778841518586685, 0.6419013945325729, 0.02769393099081372, 0.4926172728019376, 33.49749626651887, 57.29361003445041, 52.72016955960182, 39.063221869930146, 36.309004137592936, 49.15420947536346, 60.89382417740361, 45.78281856352284, 4.134495873605052, 0.15060861114292376, 0.018021663004953056, 0.01900236471556127, 0.036111684035389655, 0.0312068022697443, 0.05621334470267739, 0.02663807222439397, 0.01841049093092161, 0.07676953299631996, 0.027907970211198254, 0.053648647041090076, 0.04856162021056779, 0.028308145814545216, 0.008928046126158969, 0.08819956482658464, 0.09981119013842076, 0.2588193118572235, 0.136777751688515, 0.1140924480052725, 0.12120267856986293, 0.09213597739055272, 0.26166480755613697, 0.13660697536843439, 0.10648147939073463, 0.12335080443130386, 0.09619664175495987, 0.2801587216315731, 0.31036042037510103, 0.2291536907995901, 0.186807521949372, 17.29070986470869, 59.326468590767156, 67.72256866578134, 55.448578096205196, 39.315849965618504, 31.539003887484153, 35.596470294460175, 59.56337974917505, 38.2534916939274, 2.902890761052409, 0.3397061537590719, 5.404739764428908, 8.418498769883188, 12.304962585049292, 6.886187599551294, 20.68336786762361, 41.49532671897642, 54.64713981074672, 57.19232659186087, 56.803611863044004, 56.068555770381806, 55.160711426888746, 53.73894245393815, 53.232937089858524, 55.37847749648556, 54.455520260718565, 52.84001758021694, 44.9840945582236, 38.44598593250398, 42.4136398684594, 48.42951236232635, 51.44814099034956, 51.58799702121366, 47.644955958089525, 48.56300238640078, 50.96327720149871, 51.61420629870508, 47.97558822939473, 44.99149214836859, 41.667503080060406, 39.383683435378536, 40.25125288194226, 40.027065892373365, 38.86054515838623, 37.96713513712729, 38.49596085086946, 40.74385158477291, 41.368226235912694, 38.36477718045635, 40.1974222736974, 40.11586050833426, 41.43075273882958, 39.81036278509325, 41.97524832141015, 38.459776986029844, 43.09141366712509, 41.351889564145, 39.888700362174745, 38.34553795476114, 42.46111623702511, 48.755433867054606, 54.3620188005509, 42.75440754428987, 50.08975359701341, 51.481092822167184, 52.372608338632894, 52.10249039434618, 52.11921930313111, 48.26376476595479, 52.14637779420423, 52.312078322133715, 49.32759784883069, 45.37043625308622, 51.450980786354314, 56.628964408751465, 49.99629920528781, 48.93557656195856, 41.99845698571975, 40.77727017864105, 42.23248912442116, 44.41409964715281, 42.602145056570734, 43.165526851531, 41.39534942565426, 41.74873928869925, 39.376478041371996, 42.15694819727252, 41.38495514469762, 39.96469628426337, 41.0310318393092, 41.47199253882132, 41.07715891253564, 41.23111978653939, 40.02346907892535, 40.52911358494913, 40.945335895784446, 40.743651543894124, 41.35093642819313, 39.40515841207197, 46.888993632408884, 54.48271013075306, 56.785678786616174, 53.35948451872795, 52.47751605126166, 52.10968009887203, 53.54292200457666, 55.18914468826787, 58.08592488688808, 57.90090276348976, 56.12439855452507, 56.412033804001354, 54.08928071298907, 57.341596311138524, 54.67419632019536, 40.922291971022084, 40.86732779779742, 44.50112135179582, 51.412769056135616, 60.054193773577296, 59.963877277989546, 61.35134904615341, 59.52472871349704, 61.4667098752914, 60.34477080068281, 63.151709110506125, 62.98566733637164, 66.18955735237368, 60.34173488616944, 63.768548888544885, 49.09200068443052, 29.148593833369596, 5.365342007529351, 6.583920928739733, 5.09311382808993, 1.5190388502613192, 0.5755796920387977, 0.5643187511351802, 39.375787704221665, 65.3953872188445, 63.38619624414752, 43.34542635948428, 38.02955573604953, 58.71912879328574, 67.86644120370188, 53.94516106574766, 7.138646052729699, 0.27442093758333114, 0.1679368917980502, 0.1140590159282569, 0.1501256386719404, 0.17368262783894617, 0.23051086152272843, 0.12678600397081147, 0.1298608357507375, 0.15949143126847284, 0.12229350350436666, 0.20536145135279626, 0.1278529729273531, 0.12707412963913334, 0.16695348005140984], [0.05698150872523266, 0.013946082908660175, 0.06583850785729385, 0.026472516793517337, 0.051989266123141975, 0.03808502310646638, 0.02165758524150137, 0.0231144278340282, 0.04557062143219575, 0.04479828606089277, 0.02433541876774642, 0.0789348422099025, 0.02949097024787578, 0.007463992252239898, 0.013990463339723648, 0.04573998815049568, 7.9666667311422295, 40.990462764616936, 51.64936642492972, 42.16656977130521, 24.77610814955927, 23.787111928386075, 38.08055831540016, 43.13000586725051, 35.34981204617408, 4.173328318903524, 0.03358968811470174, 0.4402543970894429, 2.266420991190018, 2.4044202700737984, 3.927214299478839, 9.017794766733724, 34.83265146132439, 53.78654826071955, 55.70964713250437, 49.86800239932153, 51.720612356739665, 51.595869218149495, 52.265708061956595, 51.09621809374902, 50.925563612291896, 49.889540133937714, 50.31971823784613, 39.31321413286271, 34.5997646547133, 37.646187197777536, 40.76107863456973, 45.30475224218061, 49.9753184472361, 50.40818729708272, 48.054702435770345, 48.09116478889219, 47.61555387127785, 46.20581088527557, 44.402301157674486, 38.84269445173202, 38.436438883504565, 36.93398283373925, 36.3918092943007, 34.83533044015208, 35.85975154753655, 35.734565181116906, 37.762567843160326, 36.324677928801506, 35.32130425976169, 38.5009422609883, 37.69343999124343, 38.27225631283176, 36.71407122765818, 35.52831126797584, 38.15817025399978, 36.4760539608617, 37.92608361090384, 37.06159322492538, 36.151583733097205, 39.38948462086339, 49.55564445064914, 45.494045826696585, 42.11442578223444, 50.398852056072606, 44.81414218102732, 49.04898012838056, 46.196099096728915, 48.21084806996007, 45.905165133937714, 47.10184889454996, 45.20055447855304, 47.92633502714096, 42.20753500538488, 45.671007479390795, 54.11923977636523, 49.434745234827844, 44.82563080326204, 37.97716463765791, 37.712169308816236, 36.978878282731586, 33.45257728330551, 35.78067656486265, 37.96687233832575, 38.34932304197742, 38.685175987981985, 37.27949265510806, 37.1435825286373, 35.99947814018496, 38.174581450800744, 36.802630501408736, 37.68961960269559, 37.05783951667048, 38.471775516386955, 38.45498384967927, 37.28525461689119, 37.49842366864605, 37.4537439500132, 36.550504469102435, 36.692082420472175, 40.06992955361643, 48.479938353261645, 50.20780909445978, 50.81776119047596, 52.86577578513853, 52.8430260381391, 49.97023505549277, 47.33929741767145, 48.51393745791528, 49.67919126633675, 48.926912046247914, 48.85998464399769, 50.575025312362186, 52.184181597925004, 52.47311515192832, 48.53252557016189, 37.41313172924904, 39.44621778303577, 42.61146460810016, 53.53153144159625, 54.02291420967349, 54.868365410835516, 58.52592460570797, 56.14370446051321, 56.560789692786436, 58.44886572130265, 57.69309559176045, 60.28644907859064, 55.082715096012244, 56.47884745751658, 45.64611611827728, 18.483224145827755, 3.1063671458152036, 4.591360803573362, 6.298000735621299, 0.05607514244113719, 0.09359964199604527, 0.5478511702629828, 30.538487665114868, 56.729463377306544, 39.75970145194761, 25.30646162648355, 24.7754942986273, 47.68911007911929, 55.70079434302546, 41.183164888812655, 3.27206791889283, 0.09674076336405932, 0.03683884320179782, 0.04414105923065255, 0.07727683641977849, 0.04684143106362993, 0.024642750260330016, 0.04651004824066355, 0.04827237605387646, 0.026703503794006767, 0.0880009182278187, 0.010731641180633057, 0.0321538899574549, 0.03429181918862366, 0.013837941937268743, 0.01376283180434257, 0.03370300017958207, 0.09393855163286771, 0.047997990172476544, 0.036215960093203096, 0.009567502589385596, 0.04197930849547829, 0.023946539130842975, 0.021390358451753858, 0.06980189437707586, 0.07095096497646264, 0.10835699286432036, 0.027762995732407418, 0.027932772307746837, 0.06984330142938322, 0.05424573213883466, 10.106824175004038, 46.75289523216986, 58.62827493298439, 47.092945114258804, 32.203571065779656, 27.444959417466197, 36.98080024411602, 50.50547384446668, 37.99716088079637, 4.024099049068266, 0.11186036656820968, 0.7612754212271783, 2.045571448341493, 4.981410118841357, 6.24587586810512, 14.859859193525008, 35.76575586872716, 56.28618063465242, 56.41724663396036, 52.512644798524924, 53.340653219530665, 54.0067030537513, 54.56422482767413, 51.93024343059909, 52.594955736590975, 52.43606052091045, 52.314843593105195, 42.32367246381698, 36.906514475422526, 39.38657814456571, 43.87093374806066, 47.463946419377486, 51.1266831428774, 51.19604241463446, 48.84014137329594, 49.19084049040272, 50.44233152943273, 46.65915450742168, 45.563789490730535, 39.86189880678731, 39.14849811984647, 37.402906110209805, 38.00806899224558, 36.32637631508612, 37.38833058264948, 38.63808008932298, 37.707995906952895, 39.395038697027395, 36.59123436097176, 39.79717577657392, 39.529717199264034, 39.851441767907914, 38.247427709640995, 37.70348518125473, 38.330625103365996, 39.247243788934526, 38.13244735040973, 37.59647115584343, 36.87739479926325, 41.466720873309725, 50.299298378729056, 48.627341024337284, 45.041714176054924, 51.728068782437234, 48.04873258836808, 51.59309610243767, 48.336258011479536, 51.84812468867148, 48.24921669498567, 49.55179268313993, 48.048607072522564, 48.332873006020826, 44.1514342061935, 46.63076046974429, 55.187850306111, 50.58042249371929, 44.99162550895445, 40.26947621376284, 38.7940296050041, 38.41065322199176, 36.55040640984812, 36.77696643337127, 39.680650003494755, 39.96834408852362, 39.985669197574744, 39.66559594677341, 39.22567075298679, 38.38752692745578, 39.424813409005445, 39.76816984914964, 39.204870423962994, 39.82627191851216, 39.821757270443825, 40.182740842142415, 40.91811464678857, 39.367515425528254, 38.05090911926762, 39.147443002270116, 38.80373747118058, 43.34565777932444, 49.85219916989727, 52.891008392457046, 51.09609650027368, 54.90032880536972, 53.15288151464155, 52.49780254979288, 50.39521994129304, 51.80509236551101, 51.50282667529199, 50.979068663812455, 51.18990782768496, 52.959736162616366, 53.19003028254355, 54.6529370738614, 49.76054514608076, 38.51687885099842, 40.136582389954604, 44.77729935799876, 54.36030864715577, 56.13843671737179, 55.52432298660279, 60.559159709561264, 59.30609580009215, 59.90780699637629, 61.888070491052446, 60.47483659559681, 61.400508111523045, 56.497859185741795, 58.27165695928759, 47.845647950326246, 17.706528171416252, 4.292384511040104, 5.814056742575861, 4.932354015688743, 0.5058330862272171, 0.13331661241189127, 0.5745050851856509, 33.839742675904304, 63.210921210627404, 49.31637594776769, 32.409111107549364, 29.32234698726285, 53.28569296867617, 59.28564063964352, 46.76685494761313, 4.617663237356371, 0.17123159081224473, 0.10164816172853594, 0.022260172765762098, 0.04822065362766866, 0.052490333590896866, 0.03183754161000252, 0.06776538752620259, 0.029819133586340377, 0.02856466844077072, 0.08885817061508856, 0.030524442009928248, 0.06278464007341573, 0.013551543797216108, 0.04307957163320915, 0.15939740163664665, 0.08674870921118606, 0.19171646015057642, 0.10512248537833653, 0.19951281438191093, 0.06947317370964635, 0.10280572824300298, 0.07199796968169751, 0.179258200430101, 0.13692395190798468, 0.2516537237792246, 0.29575504602924474, 0.12058189454218074, 0.10013986484057481, 0.13881983565947703, 0.2435581815699416, 11.713283831073392, 54.23308264824652, 65.83070755004883, 53.108425371108524, 35.513892635222405, 32.56783962249756, 49.56426974265806, 55.45859582962529, 43.19843161490656, 6.1145607982912376, 0.19900128215311036, 1.2242364498876757, 5.772430098825886, 10.74394750979639, 8.14268309262491, 11.476596247765327, 38.95233646515877, 56.72939669701361, 57.91593328599007, 53.65285819576633, 56.75071085652998, 55.70768594741822, 56.57908754964029, 54.81724516037972, 54.23772281216037, 54.12264047130462, 55.60872454797068, 42.450031618918146, 38.24752576889531, 41.138151768715154, 44.40070475301435, 48.90307188034058, 53.29473795429353, 53.17067338574318, 50.81266603162212, 49.12976918681976, 52.11837599354406, 50.65751275708599, 48.277038066617905, 42.316929909490774, 42.41394581333284, 40.373913241970925, 41.45631874761274, 37.670435290182795, 40.34227540416103, 40.29918424544796, 40.64202293272942, 40.121359671315844, 38.22503882069742, 41.06630963663901, 41.49530318475539, 41.4995668011327, 40.7159556881074, 39.76742852118708, 40.37632157725673, 40.29378314172068, 41.21471643447876, 40.34331090988652, 38.61829565417382, 42.77933812910511, 52.19834527661724, 48.48215841477918, 46.91543825211064, 53.4856750119117, 48.91034003226988, 53.37576235494306, 49.34200863684378, 54.55114372314946, 51.51297776929794, 52.521556423556426, 49.923590229403594, 49.21949732688166, 46.46159256658247, 49.76694253183181, 56.92373052720101, 53.079137033031834, 46.44862521079279, 40.33740774277718, 40.665168839116255, 40.50098234607328, 37.483024443349535, 39.003248829995435, 41.984524726867676, 41.9946954327245, 43.63779198738837, 41.247523138600016, 40.98912915875835, 39.4595459968813, 41.53582911337576, 41.8980521540488, 41.81799657883183, 42.647162099038404, 42.046082404352006, 40.7223177725269, 42.02724718278454, 41.094491866327104, 41.76218125127977, 40.77395577584544, 40.56193597855107, 44.19758873601114, 53.27889550116755, 54.44311380386353, 56.66378721114128, 56.53134838227303, 56.62362214057677, 55.466197383019235, 53.048789655008626, 55.65280806633734, 55.29742171687465, 53.69862048856674, 54.24371619378367, 56.02500569435858, 53.24502191235943, 55.506503658909956, 54.37047150827224, 41.800236086691584, 42.78918327823762, 47.89967467707973, 56.86255724199357, 59.22255323779199, 57.251523002501465, 61.47307195971089, 61.270862010217485, 61.112119766973684, 64.07412898155951, 61.930181057222434, 63.322881344825994, 59.25878417107367, 60.20162390124414, 51.073699766589755, 22.189371701209776, 6.085942695217748, 12.208570338064625, 13.553968802575143, 0.9019546595311935, 0.39305866185215216, 0.8743697945629397, 37.055717514407256, 69.23756845535772, 50.780659491016024, 38.22943187529041, 35.751380382045625, 61.15876459306287, 68.4025429141137, 55.6836731972233, 6.420224241672024, 0.23190624471152985, 0.16448298439143166, 0.163707519550958, 0.16796558945169374, 0.11807640398582143, 0.12329006131978766, 0.10768781506246138, 0.1393182371412554, 0.09051854361689861, 0.13715918686601425, 0.10890414052072073, 0.12135028073023404, 0.15495864223809014, 0.12486090162588705], [0.049264471407138535, 0.04561737577821459, 0.11023694198698768, 0.0642815950296579, 0.029420154995375106, 0.0235115505769969, 0.03238810218810555, 0.030289563282783476, 0.0638799466222765, 0.015350427410955873, 0.04757035223226394, 0.09149412594495282, 0.038166649774798465, 0.03691717952249512, 0.04335833953753595, 0.01128074044602052, 3.631764953174899, 32.88848161697388, 53.778566237418886, 45.83501746577602, 23.417316752095378, 22.36446434451688, 35.699605095771055, 40.77064529542, 42.02933780608639, 7.23759372388163, 0.09033008598752561, 0.24390322757103752, 0.7020552312174152, 3.7613512383353327, 5.5205747100614735, 4.035400378127252, 26.033737697908958, 56.98135014503234, 55.00238887725338, 50.93759352161039, 48.245121740525775, 52.027486831911155, 51.60151350882746, 52.373337899484945, 51.85711083873626, 50.026834857079294, 46.97616438711844, 38.359674176862164, 35.29632268413421, 37.25563287734985, 37.49344618089738, 42.33415695928758, 44.10869998316611, 50.77550157423943, 49.76769170453472, 45.59307782880722, 49.050992304278964, 47.30666329783779, 46.43418304381832, 41.170013181624874, 37.945507187997144, 35.680330568744296, 35.752627695760424, 36.73688765495054, 37.022910810286, 36.3643370136138, 36.65975032314178, 37.15401211092549, 35.75764048484064, 36.86575320459182, 37.13230179202172, 38.07705563883628, 36.03178278092415, 35.15658824674545, 36.96826827141547, 36.323167816285164, 38.44181253064064, 37.12362158683039, 35.904007650190785, 41.475369699539684, 46.51842378800916, 41.60286241962064, 46.95173978805543, 48.91249733586466, 50.46584613861577, 50.418914979504, 50.51808426457067, 49.64848695262786, 48.411312564726806, 49.14599603222263, 46.88933880098405, 46.94579347487419, 44.748081622585175, 47.91093972421462, 51.29884773685087, 49.29753288145989, 44.08930778503419, 39.460836456668, 37.94045125284503, 35.83807260759416, 37.15317664607879, 36.22674419033912, 38.302478175009455, 38.131984510729396, 38.959177078739295, 38.264937170090214, 36.66276270343412, 36.011562962685865, 36.61287407721243, 36.84020288528935, 37.563201612041844, 41.21601081663563, 37.89352401610344, 38.379034996032715, 37.47152013163413, 37.37356678132088, 36.32722354704334, 36.445306501080914, 36.17072489953811, 37.10940691732591, 44.498967970571215, 51.10935018908594, 50.09557047197896, 50.90312765490625, 47.528022258512436, 47.366714785175944, 45.18819509014007, 43.525929912444084, 44.66705722193564, 43.46756112190985, 44.386544996692294, 46.639750542179236, 52.90912582028297, 53.273745429131296, 53.59530918059811, 46.24232815157983, 38.895689595130186, 38.982746601104736, 43.70892024809315, 54.26232784025131, 54.29379309377363, 56.77159355532739, 57.81745826044391, 56.455764309052505, 57.80295333554668, 52.48243078108757, 53.817754637810495, 60.57124453206217, 58.83961223786878, 39.70686320335635, 8.693320616599053, 0.925195622107675, 1.9170609957748845, 1.7036931288819162, 0.42158667298574604, 0.006288747301310182, 0.79840439341722, 32.14133677944061, 56.48178139040547, 51.45276546478272, 42.33345093265657, 34.418974768730905, 46.43202574022355, 59.83302308667091, 41.21584215471822, 5.206055535424141, 0.047037549572245735, 0.0204054260205838, 0.03947880134106644, 0.03889450991165735, 0.01398182474076748, 0.10250719910066936, 0.03596446108854106, 0.023614780924793695, 0.031392421543357835, 0.009327659612491487, 0.027234213118771874, 0.03695529622716769, 0.026870013004349127, 0.014251080705904433, 0.0699538479168569, 0.013984332721109593, 0.05402497241213437, 0.04332192354805527, 0.007870883095048128, 0.05747607210651041, 0.036979110070293954, 0.12345658585188851, 0.020620227498452992, 0.008163192561046492, 0.039628540886746305, 0.06962088312232687, 0.010106000155510922, 0.026263742512392423, 0.020789946617198088, 0.1058622658432972, 4.962140004481039, 39.38711550927932, 59.52568577181909, 50.01107477372693, 27.831650203274144, 24.793852952218828, 40.76047458956319, 46.341701399895456, 46.16508491577641, 7.286589520592844, 0.05260349243819233, 0.21863308194423878, 2.677328980738117, 4.100657340980345, 3.378285703159148, 7.567659212696937, 29.76031491833349, 56.728894633631555, 56.89065710190804, 53.6144660365197, 51.12419636018815, 53.10850774088214, 53.850506428749334, 54.99495206340667, 53.25330988053353, 52.29465123145811, 50.30316583571896, 41.483681201934814, 38.25471155105099, 40.065556110874304, 39.71289973105154, 44.18314656903667, 47.40573452365014, 51.65080593478296, 49.2112172034479, 46.61883646442045, 51.1712138114437, 48.35014320188954, 48.645403538980794, 42.87416927276119, 38.75751233869983, 37.465126668253255, 37.232753692134736, 37.26701167321975, 37.486217252669796, 39.45591388210174, 38.7834313607985, 38.524045021303245, 37.038819943704915, 37.55660810778218, 39.40148707359068, 38.93110467541603, 37.27048689319242, 36.91887778620566, 38.87476767263105, 37.96003172474523, 38.74197190807712, 38.31459437647174, 37.52539388595089, 42.47105944541193, 50.28044354531073, 44.83538181551042, 48.749307124845444, 50.84877537142847, 51.58236842001639, 52.34184126700125, 52.80888965052944, 50.73901568689654, 51.08385086059571, 51.450141399137436, 48.18471723987211, 48.785188967181796, 45.17252129893149, 48.99924839696577, 54.988476230252175, 51.11183304940501, 45.83866527003627, 41.64706753146264, 39.463005527373284, 37.63127042401222, 39.050332961543916, 37.80815362930298, 41.42114685427758, 38.573588478949766, 39.835214922505045, 39.330037178531775, 38.52700248841317, 39.13543662717266, 38.68379531368133, 38.49891439560921, 39.338882123270345, 41.17219401944069, 38.66297537280668, 40.783851915790194, 38.01180308864963, 39.101123732905236, 37.350063939248365, 38.74043826133975, 38.673961931659335, 39.24441968241046, 46.62941901914535, 52.47163249600319, 50.924120180068485, 52.34558713051581, 49.10752934794272, 48.65362874923214, 48.176197851857836, 46.52810811996461, 47.38979401126985, 46.57692986149942, 47.19831958893807, 49.78417742636896, 55.0005728198636, 54.998211553019864, 56.209557133336226, 47.32492977573026, 40.09094953536987, 41.619920807500044, 46.97666252813032, 56.824486717101074, 56.608740668143, 58.248401226535925, 58.795866043336936, 58.27059007460072, 58.24477303412653, 56.3835338623293, 55.43827402976252, 59.318251225256155, 61.201757692521625, 44.25984851775631, 13.232505071547724, 3.0782974391214313, 5.6983502545664395, 5.405495801279622, 0.8579941442416561, 0.00620975406021781, 0.8340267464518548, 35.43898320967151, 61.34115088370539, 52.57792872767295, 38.961193177007864, 34.55872489560035, 54.01242186946254, 66.41135954087781, 46.87300605158652, 6.432563037641588, 0.08473287907338913, 0.02131489687599242, 0.005817645362713525, 0.015139445838999125, 0.0154039807873027, 0.052401835113883986, 0.043902078102673256, 0.031691511845095985, 0.052832924280195474, 0.04063038087840523, 0.01858770622000579, 0.061503495915883014, 0.018567588751114184, 0.05291111121374754, 0.16728735649056975, 0.13870225648485845, 0.19811896336895807, 0.16479265245218433, 0.09287801781489004, 0.17931527398045988, 0.11224257549451244, 0.24649781415299063, 0.08918774930099327, 0.14287380441542596, 0.22559438501634907, 0.17251294947439627, 0.12316518898812995, 0.09538228263057048, 0.1712609013362277, 0.2121922896514016, 5.417212411280602, 44.288862289920935, 68.41238806324621, 57.8073150111783, 34.277098717228064, 33.82492788376347, 49.21129172848117, 51.61579485862486, 50.8210716709014, 9.771572332228384, 0.19666498977570765, 0.9746761992573739, 4.081629432978169, 9.273333261089942, 10.88810638073952, 7.409027286114232, 30.05392589876729, 57.848766619159335, 59.47813095584993, 55.49077887688914, 52.384034202944854, 56.01334841020646, 55.10955195273123, 57.85371272794662, 56.28680821387999, 54.685892828049205, 53.485808372497566, 44.15749426810972, 39.76567914409023, 41.59231516622728, 42.208817620431226, 46.08843395786901, 49.55430300005021, 54.08858645346857, 51.77266613129647, 47.578369802044286, 52.255957049708215, 51.47241653934602, 50.33316412279683, 44.82058663522044, 41.606066996051425, 40.34153015382829, 38.09869143270677, 40.26687960470877, 41.4938715196425, 40.68142314111033, 41.01682501454508, 41.22676595564812, 39.543225842137495, 39.74556915221676, 41.900448722224084, 40.83873371924124, 38.91636048593829, 38.06474331886538, 41.39030525761266, 38.93114782148792, 42.56106999612624, 41.33399571141889, 38.068018497959265, 44.65199532047395, 51.71605848496961, 48.0601074618678, 50.258811673810406, 53.214380356573294, 53.73840901159472, 53.85370316043977, 55.17442795538134, 53.22539044964699, 52.21898871083414, 51.79415679747059, 49.30519719277659, 49.8342151026572, 47.62041761029152, 53.50428273600917, 55.618875641976636, 53.98773839396816, 48.76904056918237, 43.6463309872535, 41.47740933202928, 38.78156823496665, 41.47364777903403, 39.49571417224023, 45.61365850510136, 41.02384605715352, 42.18154538062311, 42.221231922026604, 40.33826674184492, 40.921664391794515, 41.06362281307098, 38.76628668077531, 41.43981341392764, 44.752411919255415, 41.357094549363666, 43.02567474303707, 40.48832093515704, 41.56143434586064, 39.391994937773674, 40.97900159897343, 39.64859639444659, 40.47446712370842, 48.62967091221964, 56.502507194395996, 52.73214063336773, 55.42086655093778, 51.906183611962106, 51.13208816897485, 51.42984705586588, 49.15144420439198, 49.83060652209867, 48.292209794444425, 48.630549523138235, 52.408172468985285, 57.358564484503965, 56.57205081755116, 57.960118785981216, 51.09244869601343, 43.010228449298495, 43.75707518669867, 49.03919381480063, 58.800286554521136, 59.255191279995834, 60.746323447073664, 58.97969576620287, 58.6804267667955, 59.761765387750444, 56.954207343439904, 56.00281684629379, 62.3051518009555, 61.62056484530049, 45.25332996922155, 11.519579541298652, 3.1614257010721394, 6.186347036592423, 8.743322991555738, 1.830879413793164, 0.144956874090337, 1.207964252079687, 40.17050304720479, 68.2710023080149, 65.25603325136247, 55.489782594865375, 45.34164213365125, 61.03382533596408, 74.62452027105516, 55.39719504694785, 9.582855336127743, 0.19689830951392653, 0.11697987935716107, 0.09199018319768291, 0.2598397103288482, 0.09832394534661885, 0.28340221532890875, 0.10547642566023335, 0.11077131129681103, 0.13501397213868557, 0.16875337298598983, 0.08713359178434457, 0.17952646909942552, 0.10098991600135643, 0.13208328746259212], [0.02924756879257339, 0.066755338902435, 0.02675153367641953, 0.0408923025092771, 0.030736724973746368, 0.06986105168658881, 0.02957025460237938, 0.06319590671468647, 0.0351820363392753, 0.06885389121429575, 0.004296089886807867, 0.0803089587979259, 0.09631707077665676, 0.04421940321222909, 0.0573713363959424, 0.039995071823678674, 1.0431951644920534, 25.311315559571792, 53.170536102787146, 43.742413366994555, 36.82968701085737, 22.703800355234456, 33.13979571865451, 41.51609959140901, 46.54536262635262, 13.400121677306391, 0.0560083702176569, 0.027842161343282754, 1.960863942100156, 3.270028776699497, 2.8724700837366046, 7.5746944738972575, 24.891459172771825, 52.65983958398142, 54.656867288774066, 51.25871404524773, 48.00250745588734, 46.61032884351669, 47.36289439662811, 49.652334797766905, 49.743094521184126, 47.39836831246653, 42.83759709327452, 36.70142942859281, 33.1287032558072, 36.271463132673695, 37.377234197431996, 41.615500296315844, 44.99792875782136, 49.625949013617735, 48.36300857605473, 44.015845714076875, 46.544589919428674, 47.436368234695934, 46.77932416239093, 43.686660797365256, 38.115977318056174, 36.59805144033125, 36.12351917451428, 36.116231410734116, 37.074387996427475, 35.01656355396394, 36.653713795446585, 36.803881737493704, 36.21054872389763, 38.996580800702496, 37.52198926864132, 37.42264739928707, 37.99248541555097, 35.590571049721014, 35.58647609526111, 37.67669931534798, 36.74840373377646, 35.77409875008368, 36.29533075517224, 43.567679620558216, 45.221343040466316, 40.46264902237923, 48.504394331286036, 51.43332619820872, 50.230252896585775, 48.12721529314595, 47.975898096638346, 49.93747541981359, 48.34098838990735, 50.010694303820216, 51.10378826818159, 49.69607706992857, 44.88764347568635, 45.75245549601894, 52.62631508611864, 46.51632531996697, 47.81413955073203, 39.7375439828442, 38.724827228053925, 35.98654216335666, 36.58251885444888, 36.891487875292384, 37.42236891100484, 37.522962016444055, 37.60116231056952, 37.87066052036901, 37.14449644088745, 37.384274851891306, 36.81882596785022, 36.71228654922978, 36.495665811723285, 39.88579780824723, 38.58173131942749, 37.58100132788382, 37.27772366616034, 36.699021093307, 37.426561924719046, 37.21050600851736, 37.75383272478658, 36.0569251737287, 38.91839619605772, 43.09062919309063, 46.502973571900405, 45.9793959894488, 43.21310127935102, 42.60408662980603, 41.791104808930434, 39.075326304281916, 39.812559312389745, 42.598489407570135, 46.324784217342255, 47.61538520936043, 51.243299130470525, 52.97794772732643, 53.8346992769549, 50.490753189209975, 42.21974142136113, 37.3123856513731, 39.05750697658908, 45.97213175988967, 54.18539839406168, 54.0564622417573, 56.18346944932015, 54.09215581032538, 53.39466817917363, 56.43802735113329, 61.5030937810098, 60.918578255561094, 56.889095998579464, 37.00907661068824, 8.40423507075156, 3.9604093182471494, 6.147416532039643, 3.298015133027108, 0.12931980913685215, 0.03101167584499044, 1.184438243508339, 34.56823664326822, 55.52270304772162, 49.103940379235056, 34.888886482484885, 30.99816591508927, 46.648917121271936, 54.77578570765834, 34.92983210471369, 6.448341752252271, 0.059156531933695085, 0.03798230220713923, 0.07138488483765433, 0.010712246707219993, 0.020620916977584846, 0.03089124682329355, 0.07132097012213162, 0.010442571308944496, 0.014862637204538672, 0.0336097251443613, 0.09100456511782062, 0.0236424156314423, 0.01299662513643383, 0.03363525119399832, 0.010485426267428745, 0.016128305428391023, 0.006701013208517144, 0.011687787858048275, 0.039765176498481346, 0.0352341877747207, 0.07793052392380853, 0.05714120741392817, 0.11050334140177696, 0.04175640755302964, 0.04699565988454608, 0.07766112144435607, 0.07411119257730824, 0.004500154642418268, 0.03129748409734138, 0.06870202194418638, 1.588863045457871, 31.248193479353386, 60.25880421361616, 49.68663984729398, 38.127207063859515, 27.340208599644324, 35.66104819697719, 44.43313883196923, 50.673370899692664, 14.101739564249593, 0.02930424589243147, 0.034174994610610514, 1.162727556882366, 2.7098309657266064, 4.103513561910199, 6.3684205182137035, 25.989512974216094, 55.643814071532226, 55.6668266173332, 52.66602516174317, 50.69184918557444, 50.58371728466403, 50.35017151986399, 51.93746451408633, 52.25736910297025, 49.424915775176025, 43.55410429739183, 38.5402600995956, 35.307458293053415, 38.034984296368016, 38.93620375664004, 43.11961550866404, 46.49135551145, 50.8236918141765, 49.17172678055302, 45.2265441033148, 48.52266080917851, 51.6112135302636, 48.31899958272135, 44.52696192649103, 39.2652278561746, 37.94968058986049, 37.25335005790957, 36.845851098337484, 37.63987218180011, 37.243520598257746, 37.16554780160227, 39.42113422578381, 37.143045163923695, 40.963194447179, 38.889664834545506, 38.07175651673348, 39.9438214302063, 37.54171094586773, 36.96673462467809, 39.36906083937615, 38.07585147119338, 37.25472680984005, 36.93954083227342, 44.50097622409944, 47.13512236072172, 43.59464199312272, 51.66373406687091, 52.78487297796434, 52.78158995413011, 50.48708969546903, 49.55840187688028, 49.91847545869889, 49.513380912042436, 50.087341339357444, 52.20513882175569, 51.157795383084206, 46.38003080121933, 49.24596548080445, 54.24805041282408, 48.59536978506273, 48.66083414323869, 40.444351165525376, 40.07647598943403, 39.845805321970296, 39.0534237892397, 38.228721926289225, 39.00037373265913, 39.96018163619503, 39.94823801902033, 38.70156757293209, 40.0836774610704, 38.54985029466691, 38.76520018423758, 37.95483850663708, 38.321144734659505, 40.50535186644524, 39.460432452540246, 39.042417618536184, 38.33182927100889, 38.13456935267295, 39.34513045895485, 38.10179794988325, 39.940671766957934, 38.04539034443517, 41.11672386046379, 45.07648206526234, 49.29213177773261, 49.74822498136952, 45.63267023332658, 44.497242127695394, 42.95156940337151, 41.48502265253375, 42.37912693331319, 45.44019952897103, 49.398055384236, 50.612185847374704, 53.51905045970794, 53.76625783981816, 53.24332744844499, 52.940948009490974, 43.68943391307708, 39.46245639554916, 41.635606365819136, 49.30975106454665, 56.24528992560602, 56.21276563213718, 58.08009624481202, 57.37633282138456, 53.24562203499579, 57.376834884766616, 60.63575575428625, 63.619608648361705, 57.82340849599531, 38.57517311649938, 9.156829061046723, 5.536396570744054, 7.436659893681926, 2.216726031995589, 0.7660113154880462, 0.03073942926411908, 1.133329882737129, 37.33063251741471, 61.48930272748394, 57.096722741280836, 48.74763619515204, 40.36038890961678, 52.52373333900206, 62.272784402293546, 44.58321655950239, 7.617195806195659, 0.06742493805265234, 0.017873865492161245, 0.11367899801341758, 0.044523877196855126, 0.01574515517155129, 0.029987964043093306, 0.06728022404375576, 0.013041079303460016, 0.0238474820470137, 0.020714992574686487, 0.08558966414702517, 0.013798114941305211, 0.012556118834313127, 0.04168380157000596, 0.14151363062762445, 0.2002459911689643, 0.1368890182986375, 0.0827689360707037, 0.15503834602573227, 0.16682385797462157, 0.24186077587787183, 0.1281481542654576, 0.20899937307882696, 0.17010887363745322, 0.13901526468896097, 0.1787319899566712, 0.2729110395716083, 0.14373983617030806, 0.17683219915676504, 0.14904861098095296, 1.9552673327346004, 35.54510293468353, 67.09351462702598, 56.584304301969475, 48.258406808299405, 33.44022181726272, 45.86652586537023, 52.450851778830256, 56.146732530286236, 17.573720639751805, 0.17870811865695063, 0.35453853527865103, 5.820577682987337, 7.16817218449808, 7.7201982275132215, 12.421825681963275, 30.72249781700873, 56.37210407564717, 58.398694684428555, 54.25731112880092, 54.0821929900877, 52.147664331620746, 52.7534822494753, 53.80063349200834, 55.61952675542524, 51.253054065089074, 47.720190940364716, 41.21953702742054, 36.53551709267401, 39.401369402485514, 40.384409504552046, 46.55792597801455, 49.76989607657156, 53.82927856137676, 50.19428083973546, 45.1427387422131, 50.36508437125914, 53.1757842340777, 51.56894606928672, 47.76143074035645, 42.1026429822368, 38.80953473429526, 40.624944932999156, 39.3125787088948, 41.036048550759595, 37.60460615158081, 39.43546264402328, 41.413560990364324, 39.15545640453216, 41.91180006150277, 40.48741879001741, 39.51598890366093, 43.10038412770918, 37.45266922058598, 38.02206793139058, 40.46626937004828, 38.727196339638006, 39.763796406407515, 38.7377945838436, 48.25237028060421, 49.66405876221196, 46.33524125622165, 52.98515312133297, 56.373202339295425, 55.23252218000351, 52.503517443133944, 51.542599508839274, 52.25726712134577, 50.69015472166, 51.81798127389724, 55.31864173950688, 51.90737601249449, 46.76754136239329, 51.54925577102169, 57.476874936011534, 51.59697532653809, 51.09037376219227, 43.47607658755395, 42.04524301713513, 41.38581022139519, 40.09210663457071, 40.70842473737655, 40.87039509127217, 41.961151323010846, 41.94910180184149, 40.49021543995027, 41.54492901217553, 40.82101637317289, 41.08588618616904, 39.670432229195875, 38.43124566539642, 42.4794376281, 42.250284917892955, 41.59378213267173, 41.70270242998677, 40.33052790549494, 42.34815197606241, 40.27498714385494, 42.8623237148408, 40.167408297138834, 42.34005620402675, 47.74192087111935, 52.23965567927207, 51.76355446538618, 47.48692366384691, 47.468229647605654, 46.88855824931976, 43.16853138708299, 44.03351991407333, 46.53995760025517, 51.52845151962773, 52.91688819085398, 56.00589982924923, 55.729408033432506, 56.79882264906361, 55.44737392856229, 46.40584391932334, 41.04541517073109, 44.027989372130364, 50.55182449279293, 58.28405949377245, 58.66248584562733, 60.92849400735671, 58.065359900074625, 54.957983724532596, 60.30342117432625, 63.67667521199873, 63.80707833074755, 61.01379379149407, 40.37974580641716, 10.518390632444813, 8.64148453358681, 15.48469864553021, 8.451253502599656, 1.5659560359293416, 0.29977927525197307, 1.375409376717383, 42.16820932203724, 68.74439316411173, 60.742789391548406, 46.23006682242117, 43.29052886655254, 60.46337150758313, 70.4043794447376, 53.988632694367446, 9.696137309074402, 0.152439147594475, 0.11338266754342664, 0.15792770791919003, 0.14722840139462104, 0.09626874595039314, 0.09575865396689023, 0.11295993256592944, 0.1613631372850749, 0.0618690271080742, 0.13131244979318113, 0.24486708875385024, 0.11780199129134418, 0.08212609637168147, 0.09529943022155955], [0.08148653552897515, 0.04952787158770427, 0.06262779889267779, 0.042519768204299674, 0.0472103062296106, 0.05059359565136894, 0.05644452322514788, 0.06399086083195384, 0.044852701286154414, 0.027780791954888452, 0.07363218078089338, 0.03077928881881939, 0.04516318906098605, 0.07156958863619836, 0.049419067950258334, 0.08339982479810716, 0.10038499765458608, 21.63831203214584, 53.727489133034986, 53.14742549773186, 40.735249826985026, 25.05946997673281, 31.973971205372965, 36.39123662825554, 51.98689814536802, 20.676635119222826, 0.5228601564322749, 0.13671677108974228, 1.178435301107745, 2.4475776187835203, 0.8290834568681256, 0.2003700208039053, 15.061598458597738, 46.63709117520241, 51.73003781226374, 49.309143097169944, 45.74853704821679, 46.67483222100043, 44.604511107167895, 47.19233012968495, 44.62950052753572, 42.745801864131806, 40.003064909288966, 37.28024182781097, 39.09367907431818, 38.80580063789122, 38.51703182343514, 44.17332887649537, 46.92869978566324, 50.14452949646981, 49.14450945392732, 48.88270301203574, 49.68845982705393, 48.133946080361646, 44.86961234000422, 42.63260618332894, 37.614667031072806, 35.23766363820722, 35.94468655124788, 36.08802172445482, 37.8688915314213, 36.77187127451743, 37.229957042201875, 36.46262768776187, 36.20751673175443, 37.615255386598655, 36.7722438996838, 35.05792494743101, 37.94731540064658, 37.17737767004198, 37.94109452155329, 37.023573690845126, 38.12740318236813, 35.69461976328204, 35.23363536404025, 38.892661525357155, 45.485914753329375, 43.60828399658204, 48.47452548242385, 50.30602916594475, 48.042507786904615, 49.23997209918115, 48.21545293254238, 50.181278182614236, 49.15327595126245, 51.66963723398025, 49.11319717284172, 47.71616658856792, 44.808552803531775, 44.91879886196506, 52.593563295179806, 48.126995640416304, 47.79232725020378, 43.16117302063973, 43.06181938417497, 40.54918827549104, 40.6172453203509, 38.00460161701326, 37.82563171079082, 37.64928587021367, 37.52079686810894, 37.90575396630072, 37.39666954163582, 36.96397327607678, 37.170674339417495, 37.161033153533936, 38.74788684229697, 35.61610567954279, 37.59164271816131, 38.86812709992932, 37.659076106163766, 37.08220920255108, 38.25796319592384, 36.66023277467297, 36.31143992946994, 36.98260061202511, 37.132737175110854, 37.55527842429377, 37.70490507925711, 37.13983274275257, 37.36895407399824, 37.11430988004131, 38.459851511063114, 38.52396265152962, 37.24643884166595, 37.862019538879395, 44.75762474921442, 46.720637659872736, 49.823212854323856, 53.00043859789449, 53.5250634531821, 55.68654829455961, 47.9909796099509, 41.269155010100334, 40.18738885079661, 40.112644164792954, 44.05305723990164, 55.060090864858324, 53.00365494143579, 56.869966599249075, 57.06889744727843, 59.190621222219164, 60.752006961453354, 58.78821349913075, 57.690899064463956, 41.14411769374725, 11.16472565358685, 3.0224468102378235, 4.572402517641745, 2.6034109342482785, 0.5740285172097145, 0.12590443595282494, 0.8479319164349187, 30.162581436095703, 49.8963572132972, 41.76859432651151, 30.90920459839606, 20.859943166855846, 52.88132013813142, 53.93471579397879, 29.8730085357543, 6.919685621415415, 0.08361306537183062, 0.09487211403827514, 0.008195864295797243, 0.08551251143217088, 0.053298939394974904, 0.04811942276935424, 0.006089389677189532, 0.018091145264465484, 0.044429786277995, 0.041671685889483466, 0.06280533593869017, 0.00462455008434312, 0.03466899491726391, 0.03189461516036141, 0.023845382966101173, 0.027573310447135763, 0.09682075826511269, 0.07176682563318361, 0.035154441852242715, 0.015453949829773798, 0.09825278343933244, 0.08187291963446526, 0.009355450409554667, 0.06659677402386743, 0.03672300304676737, 0.046128923328773636, 0.042228658623512716, 0.0613503817528967, 0.0261084258466238, 0.06519195263183887, 0.34911022010830145, 25.593071176159768, 60.95161637952251, 56.62462234497071, 46.27474654105402, 24.086245606022498, 36.67384732154108, 44.665127415810865, 57.37011978703161, 21.192467981769195, 0.46960990575532763, 0.03420507505295738, 1.6891666309487436, 3.4577730249974037, 2.801525684133653, 2.077102646712334, 19.05753758645827, 50.58807111555531, 55.618965856490604, 52.57988206801876, 47.559699320024066, 47.91133588360202, 46.55221108467349, 48.52883461982974, 47.426134770916356, 44.476661451401256, 41.16442380412933, 38.46788060280585, 41.45005080007738, 40.40584917991392, 39.53946036677207, 46.775731271313084, 49.350841814471835, 52.050177743358, 49.61124797021189, 48.41453675300845, 50.59166792900332, 50.610456082128714, 47.759340117054606, 45.71156086460237, 38.25677471776163, 37.1222879809718, 36.183107822172104, 36.954437994187884, 38.85485772163638, 37.1018720442249, 38.77354306559409, 37.58670837648454, 38.04624542113274, 39.73591619922269, 39.44731212431385, 37.18217080639255, 40.33710964264409, 38.02038915695683, 39.01666333598476, 38.08856779529203, 38.27393900963568, 38.60151575457665, 37.19551470971877, 40.94144098220333, 46.49768621690812, 44.583169491060325, 50.7395608963505, 52.076590984098374, 49.33885505122524, 51.556665128277196, 49.950434930862926, 52.41974738336379, 51.67901169869208, 51.928686249640684, 49.73852495993338, 48.8703828473245, 45.31971216201783, 46.66184917573006, 55.08896343169674, 50.566278426877915, 50.01450292525753, 44.8508124197683, 44.16013010086552, 41.67171570562547, 41.241145364699825, 39.50582604254446, 39.245196311704575, 39.30396910636656, 38.86701314680038, 38.38209444476713, 41.05440132079586, 40.425845423052394, 38.49139128961871, 38.42061996459961, 38.97660416941489, 36.72290048291607, 40.38713555182181, 40.22767551483647, 40.57644482581846, 39.494360954530784, 40.60153622781077, 38.81324529647827, 39.23137387921734, 38.60342594885057, 39.16768635472944, 38.66279886614892, 39.64346985663138, 41.39973071313674, 40.43754977564658, 39.626540906967655, 40.094032518325314, 39.86508377136723, 38.84797788435413, 40.689220813012895, 45.87564537602086, 48.030619082912324, 52.49599041477327, 54.960556799365634, 54.44316871704594, 58.6707071335085, 49.539229331478, 43.37740544349917, 41.21318671011156, 42.91805667261924, 47.57114479618688, 58.06166502737231, 54.89224480044458, 59.11406832356607, 59.05790390506868, 61.71655701052759, 61.30184873457878, 63.28706618278258, 60.91889204517488, 42.84853658368511, 9.450199796307473, 5.023305935244407, 7.3156939975677, 5.0618339065582525, 0.40077852986512646, 0.10450053689700943, 1.035048401644153, 33.496617655600275, 56.78607102363341, 48.5874818986462, 32.63977393027275, 24.65936076256537, 60.26450341747653, 60.70150644548478, 38.321803692848455, 8.082383025077082, 0.03914925329867871, 0.08678470002186876, 0.02536865304254236, 0.030407741921202793, 0.006648090418292991, 0.03467975079172081, 0.0469494532913931, 0.01179638943980418, 0.09494904458763138, 0.023965614720157558, 0.018125351090284608, 0.022312260998953736, 0.048614020624588576, 0.07178475209061178, 0.15211123131936596, 0.13697603056507726, 0.302349561524968, 0.21716879680752757, 0.13194635690700623, 0.19563296208939246, 0.23193074420334833, 0.1708309727931215, 0.13368335402300283, 0.1435101476888503, 0.11120335424258826, 0.11578872754809358, 0.1468891163747157, 0.08832483552396299, 0.18497209785686386, 0.2808178330381071, 0.5757937676483585, 30.608662789867772, 67.55208676861179, 65.44498558967345, 51.67833705102244, 34.602690742861846, 43.23722777828094, 48.42011436339348, 64.37360194421584, 25.235888381158155, 1.2788299591310563, 0.22261768909952334, 4.037522135242339, 10.329270612808967, 5.9537720584100295, 1.681220276701835, 18.239315479032456, 51.36116635414862, 57.95101496481127, 54.1524818635756, 51.38968198530136, 50.02873720661287, 49.038652527716856, 52.71936547371649, 49.45938948662051, 46.39543002651584, 45.209168003451445, 40.12356404335269, 43.51055029899844, 44.00001502806141, 42.485525146607436, 50.66585956081268, 50.832109220566295, 54.10515062270626, 49.928865817285356, 47.67525626767067, 50.232147401379, 52.18732341643303, 50.23106090484127, 46.612423389188706, 41.186020374298096, 39.132855707599276, 37.986507723408366, 39.41891808663645, 41.61680644558322, 39.86886493621334, 40.108988515792355, 40.45077600786763, 40.44268415820214, 42.01414646640901, 40.507179690945534, 38.730534276654645, 42.27043021109797, 40.52872919267224, 42.94141830936555, 39.10471662398308, 42.05415071979646, 40.68863637985722, 39.54947025545182, 42.99576274810299, 49.54452453121063, 48.8106059258984, 52.830446996996486, 53.03049572052495, 51.78337027949672, 51.73844737391318, 51.15511640425652, 53.7748517528657, 51.58685561149351, 53.18140106816446, 51.264173984527595, 49.81256361930601, 45.51630919979465, 49.872866138335205, 56.20099459925006, 53.851592925287065, 52.92006531069356, 48.02542194243401, 47.48317780033235, 44.07355946879233, 45.513653755187995, 43.381571000622166, 40.66087776614774, 41.380703295430834, 41.69293180588753, 39.762533403212025, 42.586632082539225, 40.75663458916449, 39.907394378416, 41.15564946205386, 42.129252341485795, 38.94796694478681, 41.053004957014515, 43.09661472997358, 43.091758835700254, 42.49099685299782, 42.36779912825554, 40.12393274614888, 40.77852925946636, 40.48686573582311, 40.823236434690415, 40.442225240891986, 41.36240151620681, 41.98547786281955, 41.57315046556535, 41.6560850604888, 42.50397989826818, 42.4577312315664, 42.554456880015714, 42.81441588555613, 48.15864132296655, 52.16868039100401, 54.814181789275146, 54.658244040704545, 55.547849362896336, 60.3264376424974, 52.97759079164075, 44.569421583606356, 44.288328847577496, 45.8747196966602, 47.8692449292829, 60.65279060794462, 59.17373149625717, 61.95879082525931, 62.214792159295854, 63.08356185113231, 64.61657708691013, 64.85471986955213, 63.49483805318033, 44.22574350910802, 14.601609360787178, 6.901442677743974, 11.305573063512004, 10.546200236966534, 1.5946745271644287, 0.3166513505481905, 1.0444680961870378, 37.25748423607119, 61.462960089406664, 54.21420428060717, 41.730704230646936, 34.235254872229795, 67.54550503146264, 73.10252297309138, 51.43633857850106, 10.254461207697469, 0.1955920223507189, 0.2059181521256124, 0.11678865615038142, 0.17505804677644085, 0.11685123021203665, 0.1362240999456375, 0.2037519772326754, 0.11177239669186455, 0.13098557539764913, 0.13897438623732136, 0.17015802583867506, 0.07419586061469971, 0.10846162515301859, 0.16845139644799695], [0.016865797205677917, 0.029022210623107614, 0.029066249187434876, 0.0405931681574833, 0.06005988749224813, 0.059712504922983155, 0.04077891766604397, 0.021288620060189598, 0.09982462732061263, 0.050478077253266695, 0.06584790009524553, 0.03645083115946862, 0.06064279996339352, 0.01374128558147218, 0.0411359376213964, 0.05702069795299923, 0.14388625089439655, 11.553780648016161, 44.20981084146808, 49.68126227778774, 42.35255679776592, 37.06061655475248, 30.30617352454893, 32.78889852185404, 47.85025281290854, 29.14967248516698, 1.3608979553945604, 0.06213535374451069, 0.2789200493885625, 2.2408348802597295, 4.819417211317248, 4.1960309974608885, 10.234382594785384, 46.07735718450239, 53.315177425261474, 50.029007850154755, 46.59694179411858, 44.41346814555507, 42.09188784322431, 41.79742374727803, 40.01425543139058, 38.636044379203554, 37.9300412824077, 38.33222150802612, 37.83298615486392, 40.253735742261334, 44.197086672629084, 46.68852129290181, 50.504732516504106, 46.373809922126036, 48.65535459210796, 43.71620408950314, 46.60068373526297, 51.824782663776034, 45.4596858639871, 43.7974089191806, 34.486682722645426, 36.95084510311004, 35.168524019179806, 35.47141336625622, 35.907682911042244, 37.070465626255164, 36.78567017278364, 38.12446924947923, 34.821233441752774, 37.23619361077586, 34.71683955961658, 36.91702642748433, 36.65996605350126, 37.32929106681578, 36.47771312344459, 38.1218530285743, 37.95146134591872, 35.346772209290535, 35.800994442355254, 37.499929858792214, 43.18293825272591, 46.9816243263983, 47.49180701471145, 50.2050438234883, 47.08990135500508, 47.27622178293044, 49.24081933113837, 48.474929486551595, 48.17047119140626, 49.699720951818655, 49.38482522964478, 50.873831472089215, 46.47030022836501, 44.29374564078547, 51.32695151913551, 49.39327009262578, 49.25672061981694, 47.88969224499118, 45.789298319047504, 44.938810794584214, 45.330243725930494, 45.06253019455941, 39.923287822354226, 36.483208364056004, 40.548215527688306, 41.97877845456524, 37.30468211635467, 36.961929721217004, 37.808796898011245, 37.27818650584067, 37.039392609750074, 38.02660219130978, 37.3723743807885, 37.51139886917607, 38.83310033429054, 36.17574553335867, 36.65422370356899, 37.3420113132846, 37.568547802586714, 36.25859383613833, 36.911150716966205, 37.34934222313666, 36.640950402905865, 36.65186635909542, 36.85642973069222, 35.611638099916526, 37.25299704459406, 36.69171764004615, 37.33860669597503, 40.894725553451046, 44.58088274924986, 47.07571021972164, 50.23077849418887, 53.11110042756604, 50.426183131433305, 53.1719873797509, 53.09770553342758, 48.753657033366544, 37.960816198779696, 39.3001800967801, 38.74683172472062, 44.45793997856879, 51.22802542101953, 56.99531378284578, 52.86228487568518, 53.655768594434186, 53.22622591449369, 57.506735940133375, 57.5657009309338, 42.00620758918024, 6.371293164068653, 4.904106576596537, 5.447125386807227, 2.4113898315737328, 0.5937905213044536, 0.022230500265234904, 1.6061864384720403, 28.272059809777048, 54.87140524771906, 47.502028711380504, 42.480041673106534, 44.29459679511286, 47.80554563768449, 61.16242808680381, 31.981782605571134, 3.717754339018176, 0.1540899751407485, 0.12703035537513996, 0.01366049011853794, 0.03826359437117654, 0.03045687305500671, 0.045706965930519566, 0.058811263767101114, 0.07620304161983152, 0.040406920691771854, 0.058060122218223355, 0.017620799837694053, 0.051061487681562864, 0.031041434530409116, 0.03781049549880047, 0.03628657041718403, 0.029434639802803437, 0.016830164541099823, 0.04446208071444304, 0.03634609927934024, 0.09694746920778867, 0.011294367234973658, 0.07700256162112759, 0.02869752340859944, 0.017645356786106865, 0.011913878599091644, 0.05978350212136584, 0.03237427047063266, 0.0324265023453101, 0.010463939416372489, 0.07973705884069204, 0.21204576767500372, 15.406587585326164, 51.479790595269975, 58.20731047661074, 44.97317075729371, 38.60512041276501, 35.827788153002345, 41.83059915419548, 56.028747635502974, 31.4093283684023, 1.6173854181843421, 0.0796120026479325, 0.5979676616768683, 3.4095845010972794, 3.010956962262431, 1.5270390145240293, 13.09170865243481, 47.02046363584457, 55.43464583735312, 52.24617858086863, 49.5896827790045, 46.80283484920379, 44.241491825349875, 44.19734947143063, 42.704444393034905, 40.901268066898474, 40.11701760753509, 39.36143182939099, 39.939051828076764, 40.815462297008885, 45.66914435355894, 47.855775510111165, 54.2185345772774, 48.792264922972656, 48.25579843213482, 44.183625098197695, 48.723913700349875, 54.00675796693372, 46.62407675097066, 45.12091075220416, 35.65283083146618, 38.95303464704944, 36.78860410567253, 37.42130202631797, 37.23106315059047, 38.091105568793516, 39.978408890385786, 39.822663337953635, 37.33636310023647, 38.42953158963112, 36.95474393906132, 39.511513479294315, 38.93538398127402, 38.624936226875555, 37.18534400386196, 40.13756690486785, 38.63016866868542, 36.79234996918709, 36.08346785268476, 39.18905934979839, 44.47260572064308, 49.10400705952799, 48.926535498711374, 52.64085531234742, 46.85981119832685, 47.44534654002036, 49.13267174074727, 49.035338124921246, 49.862793491732695, 51.74413088829287, 51.844731838472434, 51.15082140891783, 45.377594578650694, 46.70124938411098, 53.69365869029876, 50.548733665097146, 50.959476424801736, 49.471737107922955, 47.520338335344874, 46.194141834012925, 47.2230109091728, 45.67726365981564, 40.11513094748221, 38.593043435004454, 41.93752296509282, 43.39582881619854, 38.18492866331531, 38.869284199130156, 38.439200232105875, 38.648038987190496, 37.73589572598858, 39.826766137153875, 40.056660175323486, 39.8970236316804, 40.48240600093719, 38.822400108460464, 40.39028521507017, 38.932881509104085, 39.465264812592544, 37.902937704517, 38.70638816587387, 39.84799008215628, 36.968060385796335, 38.5354983422064, 38.83147255066903, 37.383972829388036, 37.54244835146012, 38.34535752573321, 39.02454730003111, 43.627687961824485, 46.147038090613584, 48.42130284155569, 52.67670185335221, 53.99790125508463, 51.55570806995515, 55.443643754528416, 56.3097736912389, 51.3492541159353, 39.32890753592215, 41.26482863580027, 40.77521485667075, 47.920365179738695, 54.01050775281845, 58.429465678430375, 56.27046369737195, 56.7974498195033, 55.3449922223245, 58.8603929550417, 60.884437945581254, 41.58644337807932, 7.685473484377708, 3.0958480844574594, 5.788118108626335, 3.4934080031610306, 0.6087984901762779, 0.03544471256675259, 1.5788693365550812, 32.31142447840783, 57.429218138417895, 51.22141622727918, 41.22434193088163, 42.124671013124534, 54.23554981908491, 69.05451928415607, 43.2757572204836, 4.321687558004934, 0.06455125797900461, 0.05379000558487831, 0.02750072936196962, 0.004640284093892983, 0.052936507028437434, 0.051106460873157754, 0.057598109912848285, 0.05846211153473105, 0.014785935523949805, 0.03862989931217125, 0.12021870757903784, 0.05450481541394707, 0.04792868602840651, 0.02617004038315387, 0.16377269831155578, 0.16781065582988725, 0.14601975979824222, 0.10705855810233664, 0.11255182986778599, 0.25491039418885786, 0.11502436332164273, 0.0906955099274074, 0.14278653167909192, 0.11580205747797606, 0.12198359029547823, 0.1476241777380628, 0.26236017024324787, 0.1308451821246455, 0.077995786954078, 0.19971872349419903, 0.3589057880303552, 18.727354426537794, 57.305345766005985, 63.648151736105646, 53.38692542045347, 47.45535250632994, 41.712982962208415, 45.14816730253158, 59.48787804572814, 36.32608605969337, 2.327123837124917, 0.14815236471833723, 1.287570593337859, 5.320224454326015, 13.436982151000732, 11.156123895798961, 13.05666619731534, 51.26352679344916, 57.08087636578468, 55.0003884684655, 50.645255350297504, 49.74945268323345, 46.23977468859765, 46.724261929911954, 44.521753018902196, 43.3436377586857, 41.879805288007184, 42.24420132175569, 41.55784537715297, 43.46926735293481, 48.7559163185858, 51.93796657746839, 55.07354851691954, 49.311194496770064, 48.976294686717374, 44.861006659846154, 49.27317104031963, 56.561291756168494, 49.13584886058685, 47.63302018565517, 37.381831215273955, 41.76495044462143, 39.413599352682795, 39.94622192075176, 39.37436780621929, 40.94443767301498, 41.34313483392039, 42.52090492556172, 37.719876766204834, 40.63010677214592, 37.97347368732576, 41.39226252032865, 39.811912121311316, 41.352481842041016, 38.89678393640826, 44.30965869657455, 42.51739832662767, 37.83675947496968, 38.627309260829804, 39.342482859088534, 47.03530980694679, 51.08351353676089, 50.561481368157175, 53.834581605849735, 48.756434071448545, 47.89841167388424, 50.73583072231662, 48.29368068325905, 51.00352071946668, 53.8814696188896, 53.44788689767161, 51.669194006150775, 46.035132869597405, 48.686333471728915, 54.89734388166859, 55.61295286301644, 52.155748336545884, 52.14694261550904, 49.43984823842203, 48.82889593801191, 49.92055431489022, 49.534255766099506, 42.59900716043288, 40.841079296604285, 44.23234093573786, 45.33857484017649, 41.299655360560266, 40.700772193170366, 41.12141109281971, 41.13637493502709, 40.81218319554483, 41.94657187308035, 41.86616720691804, 42.02261094124087, 43.02869496806976, 40.21250770938012, 40.39805543038153, 41.08513309109596, 41.749727725982666, 40.71418669915969, 41.03347939829673, 41.09774351119995, 39.354375485450994, 40.674904161883944, 41.4989431442753, 38.62777602288031, 39.60452856556062, 39.3832637417701, 41.964701068016794, 46.78666291698333, 50.210692036536436, 52.70374659569033, 54.495136199458955, 57.35662683363884, 51.69583866673132, 56.23532710536834, 58.698795226312455, 55.35449220288185, 42.20351849832843, 44.651685453230336, 43.12212190320415, 48.66120676840506, 56.87827810164421, 61.16899805684244, 57.209969412895944, 59.98808614669308, 57.36267512844455, 59.26765265003328, 61.899229634192686, 46.27071826688705, 9.659125824128429, 12.451158146704397, 15.80522689127153, 5.977324420405973, 2.1872592260760646, 0.16504978220308983, 2.3032616078853607, 36.2753737357355, 68.3612403561992, 59.464834120965776, 54.86095213120984, 56.63067063977642, 60.92904706155101, 78.52179511900871, 55.17642051942887, 5.822110349132169, 0.19476639407296337, 0.24494106220381878, 0.1289245384114404, 0.12767427525813543, 0.1063971407711506, 0.11295044839742685, 0.18079757750515016, 0.17323500266478908, 0.23853586235594368, 0.14136879404466, 0.1827096716771203, 0.25418867807715173, 0.14028274183792455, 0.10824329009459865], [0.0518251164636064, 0.013477861460658812, 0.04041478841475422, 0.056612104958584236, 0.010270002343121075, 0.008979138445049044, 0.047007200999125365, 0.026933217173322078, 0.0249946431722492, 0.02106511390828077, 0.05279285022087636, 0.03398939448919508, 0.05583710360130476, 0.04357625707803715, 0.05453364713297737, 0.020235375568811453, 0.12349331976785777, 6.921436469401083, 41.66986434690414, 50.03044343763783, 45.05138674089986, 23.629615037671982, 20.195744691356538, 31.95085471676242, 48.02638292312623, 36.2753737357355, 3.055488121125006, 0.04810209386050702, 0.3215546503422722, 4.223955821606421, 6.465253051250212, 3.921619283576166, 10.803227270803145, 38.86868407649379, 54.16192300858037, 50.95198077540244, 47.4966589866146, 43.236255030478205, 42.14944470313288, 39.674299686185776, 39.88431907469227, 39.59973542921005, 39.444656679707194, 42.72545653004801, 44.989578031724506, 46.38071329362931, 46.6606253962363, 51.465599459986535, 48.32440853118897, 47.588316932801284, 50.06153998836395, 48.989732726927734, 47.770911109062936, 48.078805400479226, 45.166312186948716, 39.30378083259829, 34.895428995932306, 35.39923391034527, 34.98043852467691, 36.70126861141574, 36.8892325124433, 37.6363028249433, 36.890974044799805, 36.6626803336605, 36.123558398216005, 37.24914135471467, 36.96144726968581, 37.8899311250256, 37.635545807500044, 36.74678771726547, 37.922988860837876, 37.313530983463416, 37.1172869590021, 35.78494410361014, 35.6686968188132, 36.66604572726835, 39.770287929042695, 45.331577331789084, 47.50978715958134, 49.57480915131108, 51.94911003112794, 48.981978201097064, 47.819779919039824, 46.08464102591238, 51.25011620983001, 49.32915110741892, 52.12458510552683, 51.4257638685165, 43.76736356366066, 46.11415293908889, 52.71855354309083, 50.881480093925234, 50.33999689163701, 48.07958595214352, 49.94179394937331, 50.72871554282404, 50.548200222753714, 50.72372236559468, 47.187058464173354, 38.19094950152982, 37.43364964762042, 42.95855906701858, 38.130686206202355, 36.46948399082307, 36.9788900498421, 37.23470703248055, 36.46539295873335, 37.93472851476362, 37.16530461465159, 38.15797021312099, 37.86744417682771, 38.121449024446555, 38.40212598923714, 38.94831603573215, 37.56466465611612, 37.699939358618956, 36.49460284940658, 36.028888071736986, 36.95915660550518, 35.93559449718845, 36.98637785450105, 37.23456974952452, 35.14177345460461, 38.26176397262081, 37.229886439538774, 39.51056034334245, 42.70966899010443, 48.87993381869409, 49.52587366104127, 54.621358071604085, 49.958248292246175, 49.829065030620946, 53.058521055406146, 50.46068822183917, 47.06337828789988, 39.17850425166469, 38.58713634552495, 37.9920147311303, 40.28663266089655, 46.460188358060776, 47.399603859070815, 53.67447830015614, 53.563969442921305, 56.593204159890455, 60.73534473296135, 42.2990164449138, 8.959860378696073, 3.0940004029581627, 3.5116264320188955, 4.611979232680413, 0.6662423980812873, 0.08813464653588111, 2.073451900674451, 31.829159259796146, 49.357509843764774, 42.92176331243208, 34.24749266716742, 36.99625830496512, 51.10635742064446, 59.07190676658385, 30.59288113347946, 2.4641258533923858, 0.05888480820783204, 0.014241128266158124, 0.04017053660185587, 0.045062126742014964, 0.022336475123020432, 0.06447414356854654, 0.05154186311448294, 0.07537849352604921, 0.06516308643885198, 0.039895082027801586, 0.025556852117240913, 0.0467950904050902, 0.021383927143629522, 0.05455415147627073, 0.08219620107763237, 0.07368593717054014, 0.040041102216609066, 0.05169070250685177, 0.07030055632874851, 0.07443628964885589, 0.006528421260055996, 0.02577473709900533, 0.10913608896155512, 0.03147079616845135, 0.030876099349810716, 0.011307612895184468, 0.03540843064265867, 0.03577009692127186, 0.061960804441403, 0.0926945474179041, 0.1329158105316662, 8.894681372950155, 48.48022076391405, 54.3464901370387, 51.58500033040201, 31.759435207613055, 30.234358849063998, 39.68019500855477, 53.9007951367286, 39.98861881994432, 2.9744247419218866, 0.04958090402426259, 0.22977010046522464, 5.07004342732891, 6.942667278551287, 4.934051911677084, 10.459496244307488, 42.37540852638983, 57.927229712086344, 54.33323252585627, 48.89787473986226, 45.01474003637991, 44.64198935416437, 42.5747198443259, 40.826907773171705, 40.486959872707246, 40.65179355682866, 43.63410495942639, 46.133541214850645, 50.06369729195872, 49.650287320536954, 52.6737286967616, 50.11242097423923, 48.22642380191434, 52.3613864375699, 51.04408979415894, 49.346154582115915, 50.91756982188071, 46.50320499174057, 40.2560930867349, 36.43372766433224, 37.9484881893281, 37.24845493993452, 37.20577563008955, 38.28050897967431, 39.96909718359671, 39.48845386505127, 38.90225564279864, 37.24159863687331, 39.21899880132368, 38.33041329537669, 38.96408396382486, 38.61857806482623, 37.992214772009085, 38.45250491173037, 38.834347648005334, 39.42094987438571, 38.80650666452224, 37.950602346850985, 38.66711347333847, 41.63809707087856, 46.20696406210623, 48.99214890695388, 50.412290096282966, 52.549585680807795, 48.98025235822124, 49.461625237618726, 48.75851292763987, 50.655288773198286, 50.17184095997965, 50.9538988144167, 52.23323475929999, 44.70087589756135, 47.04906163677093, 54.209826915494865, 53.655054723062825, 52.19511324359525, 49.81581134180869, 52.4381079981404, 51.78610024913665, 51.870478276283514, 52.146240511248195, 48.2268552626333, 41.03358137992121, 39.3467386307255, 45.712423786040276, 40.60317185617263, 38.01415258838285, 38.5761340971916, 39.048783625325854, 38.49015182064426, 40.10125752418272, 39.94775948985931, 39.7281224496903, 40.05866058411137, 40.003461068676366, 39.490489575170706, 39.94738294232277, 37.70237907286614, 40.572906847923036, 39.58040598900088, 38.78140349541941, 36.64726934125347, 37.8994232608426, 38.828232672906694, 37.24291263088104, 37.606077040395434, 39.61369122228315, 38.652122174539876, 41.554719248125636, 45.67060739763322, 51.32732414430188, 52.25519610989479, 54.868420324017926, 51.94892175735966, 50.767574464121175, 55.78770622130364, 54.02539314762239, 47.63354186088809, 41.364817696232954, 40.49755811691284, 40.49190598149454, 43.866870172562145, 49.779109724106334, 50.956303227332334, 54.96802891454389, 56.19097686582997, 60.5083885500508, 61.568573828666445, 44.99147253651773, 9.696080434706904, 4.916981756687164, 6.426017582416535, 4.964485091547813, 1.334310291755584, 0.10691951314407973, 2.017692834619553, 32.07180100102579, 56.79945415066135, 47.56932481642693, 41.33336420982115, 43.940143969751176, 54.94665984184512, 67.18493723100232, 37.35569254044564, 3.572263823401544, 0.03586018503072762, 0.059035018897585334, 0.06521609972321218, 0.011157923145219685, 0.025639486191193425, 0.01864744192590156, 0.03789605985906336, 0.023454044186960787, 0.0467124218571811, 0.042351611904920115, 0.04728987212142637, 0.09668149114135774, 0.050368829284824675, 0.03057879977859557, 0.16348300982386837, 0.16917561000633627, 0.122449915675867, 0.13279122931341972, 0.12490676730991372, 0.1574253993889978, 0.11306207506887375, 0.07733131293207407, 0.18084911990069574, 0.08095261821102712, 0.16137626803209706, 0.14687293659775488, 0.15131070008200986, 0.16217807097540748, 0.13787103576525567, 0.0944581431066317, 0.18842554561072783, 11.017396526951945, 54.989111654220096, 64.06198532350602, 58.82626048980221, 34.71957345162669, 30.5687467898092, 43.202204935012325, 59.89079567693896, 44.1953137613112, 4.413620560399948, 0.18728070381668308, 1.6659325938070975, 9.204781997588373, 9.98429717556123, 6.4479622629381, 14.519342549385565, 43.05613194742511, 59.430262350266986, 55.51123795970794, 53.271054683193086, 48.79291603642125, 46.80833008981521, 44.15969079540622, 44.182413085814446, 43.56181959952078, 43.896146743528305, 47.80475724127985, 48.91892610057708, 51.35193701713316, 53.39760211206252, 55.304387846300685, 50.90489664385396, 49.27308474817584, 53.248320625674346, 52.63483055176274, 52.60846045709426, 52.207213755576845, 47.767310373244754, 41.51667617982434, 38.838128812851444, 38.90675852375646, 39.06253545514999, 39.88606845178912, 40.315046310424805, 41.75203800201416, 41.816494311055834, 40.23268045917634, 39.882958012242476, 39.906707963635846, 39.51407086464667, 40.873685959846746, 40.26841717381632, 40.207412550526286, 40.26511453813122, 41.21276701650312, 41.32211092979678, 40.67708499969975, 40.44819508829425, 40.83670585386215, 43.84814085498933, 50.95130220536263, 51.04170499309417, 51.17975281130884, 55.93048049557594, 50.34841822039697, 51.46230859141196, 50.05629577944356, 50.89043094265846, 51.175932422761, 52.47758273155459, 51.81922466524186, 46.29110282467258, 49.260238985861506, 56.71712752311461, 55.7361388206482, 54.50705628241263, 50.58873007374425, 54.79363641431255, 53.60314999857257, 53.16305614286854, 54.269819567280436, 51.94703509730678, 43.589538989528535, 39.76676564062796, 46.97949447939473, 43.60185523186961, 40.14710610912692, 39.64127332933488, 40.78018449967907, 40.81287353269516, 42.188656637745524, 41.36604539809689, 42.523642739942, 41.41016814016527, 40.96473986102689, 41.43143523123957, 42.586938027412664, 40.86869670498756, 42.20424805918048, 42.02359545615412, 40.72218048957087, 38.717817952556, 41.39282734163346, 40.22482787409137, 40.21838341989825, 38.37059013305172, 41.57945763680243, 41.604745157303356, 43.204091595065215, 48.61700557893323, 53.81407545458887, 55.9448952059592, 57.47106590578633, 52.87851956582839, 52.9151858821992, 57.29120169916461, 54.66796759636172, 50.83680429766255, 43.256918076545965, 44.03612044549758, 42.900351093661406, 45.20021323234805, 51.885042036733324, 52.9631172457049, 59.96636406067879, 58.79471286650627, 62.0780897140503, 64.07883974813646, 47.31837157280215, 12.588385208960503, 11.5655703121616, 13.40885973745777, 13.369717424915684, 2.0321885664616866, 0.2953524515032768, 2.537667597493818, 37.934806962167066, 64.244336312817, 55.142135081752656, 47.38836234615695, 49.56600343027423, 66.76475724866314, 74.01487411991243, 45.07843932797832, 5.71592737590113, 0.2667586793822627, 0.09701371283060121, 0.12264115420440513, 0.19762488262307262, 0.16860916459512326, 0.1378355352508445, 0.1675768764389138, 0.11907277027926139, 0.12104649622473987, 0.323653424819631, 0.1886833341972482, 0.1505795151235596, 0.1421365520406154, 0.097088988630041], [0.03082011747474392, 0.09281999431550504, 0.02936160481054216, 0.026973703004900488, 0.008113637206054503, 0.01650243978797188, 0.021019866840252956, 0.044501315907485066, 0.020046705350039468, 0.04484879806818021, 0.017066517987498836, 0.07249485430938583, 0.028628299703761458, 0.07565195627150036, 0.04813785484481243, 0.014355018727421282, 0.06632490474129878, 3.343762226643101, 34.57284542822069, 52.70300526772776, 45.891966358307876, 22.521141459864957, 21.83851568929611, 36.5965844738868, 46.157577499266594, 43.89151834672497, 8.51614127236028, 0.0085802364628762, 0.23754770086417276, 3.3478005518836365, 9.112694551867824, 5.5167705012905985, 5.916193300677884, 31.378080806424542, 53.26615564284786, 52.01412331673407, 50.343836892035704, 49.30101986854307, 45.842921041673236, 42.142784518580285, 41.112158221583215, 41.11256222571097, 44.59703506961946, 46.48251056671143, 47.53519235118743, 48.48626513634959, 50.69771312898206, 49.069427444088845, 50.36881846766318, 51.47667623335316, 47.544033373555834, 48.17282069113947, 48.19011834359939, 43.345936267606675, 37.53943204879761, 35.03998402626284, 36.30409333013719, 36.125876518987845, 40.13814349328318, 40.94069180950042, 43.01547658058905, 42.81769498702019, 41.457860239090465, 39.5301329705023, 37.486609489687034, 35.98408283725862, 36.5468958885439, 38.98071089098531, 36.58838672022666, 34.932911165298954, 36.24013908447758, 37.455909098348315, 37.526296031090524, 36.25599330471408, 35.18298972037531, 35.22572002103252, 40.94982308726157, 42.45285180307204, 45.21976232528687, 50.16561223614601, 49.038350505213586, 52.82783862083189, 50.06003379821778, 50.442300150471354, 46.695844358013524, 50.320334049963186, 54.85713958740235, 39.646168447309925, 47.70064184742589, 42.44368130160917, 54.26565793252761, 52.65376383258451, 51.15720310518819, 50.40422178083851, 50.95512651628064, 51.5983913021703, 51.365347600752315, 51.09979529534617, 50.56283066349645, 40.861153987146196, 35.93166428227579, 38.64990603539252, 38.35688537166965, 36.855425603928104, 36.95277490923482, 37.281944136465754, 36.2603118342738, 37.155502611590975, 37.26402282714844, 38.356928517741544, 36.41982286207138, 38.24578031416863, 36.82692958462623, 37.63281583786011, 38.005868542578916, 37.18446931531353, 35.87711195791922, 38.29432356742121, 36.65966403099799, 37.203194710516165, 36.171536830163774, 37.397418714338734, 35.954512088529526, 37.406393097293, 37.257676432209635, 40.519672439944365, 43.10982135034377, 46.055258550951564, 47.79203699481103, 50.942469027734575, 52.28082095423053, 50.756752644815755, 51.810003172966745, 53.145385865242254, 47.85954098547659, 44.27899360656739, 36.98439705756403, 40.02202956907211, 41.397742071459376, 40.591718535269464, 41.83272900119905, 47.28881259118357, 52.29983660482591, 60.119822871300485, 59.88280188652777, 37.79706116645567, 6.9979692659070425, 1.6657776601852912, 3.6054071159132066, 2.748905372235083, 0.6237691352444311, 0.06897380695708337, 2.4865694103702425, 32.5783613804848, 47.323086261749275, 45.12932815859395, 27.555601635286887, 32.28091628320756, 53.40576848676128, 57.84511881489908, 31.944098434140606, 1.734284429300216, 0.025794607504541357, 0.08073633626824425, 0.09057754770882669, 0.01566179810212024, 0.0227714445246684, 0.021417966345325116, 0.14277168489511938, 0.059225261511821906, 0.06317889956276744, 0.05219650056753909, 0.009945188724105398, 0.042827206949192675, 0.02606780594965864, 0.039420831467836134, 0.03700395813211799, 0.029525603167712692, 0.010287800480821922, 0.03707179904825265, 0.06396115194225023, 0.045449529744444356, 0.03175003138641196, 0.04722347145058936, 0.03020905318760103, 0.03982901843565126, 0.04418405208496317, 0.10439406599729292, 0.02288714295343286, 0.09259722360800351, 0.0433093635365367, 0.04022622353307182, 0.08689328532425628, 4.791985134924612, 42.845245715110536, 58.48862286536925, 51.9373978337934, 24.777441755417858, 20.18385010380899, 41.06937300774359, 52.29964833105765, 47.48797093668292, 8.214809596538544, 0.06907796427126854, 0.22721890510330278, 6.212485711420737, 7.045004858124641, 6.124988909690611, 7.368597945859356, 33.12092911812567, 55.89683048186764, 53.96090938198952, 54.14904978967483, 49.63795538871519, 47.80876982596613, 44.49060155499367, 43.449494684896166, 43.08112136779293, 46.85268425172376, 46.94449517034715, 49.22048968653525, 51.33428635135774, 52.85804087115873, 49.78979818282589, 51.3443942992918, 53.10704469680787, 49.76048631052817, 48.927869104569965, 49.73472810560658, 45.83239732250091, 40.84943786744149, 36.85293097649851, 38.905107205913914, 37.52378963655041, 41.07531932092483, 43.54098396916544, 43.83566771784137, 42.32062870456327, 43.76999939641645, 40.690483816208385, 38.65627204218219, 38.61888400969967, 38.66561120556247, 38.899133436141476, 37.02116535555932, 36.79387184881395, 38.416556389101096, 39.291515581069454, 40.46847766445529, 37.33491574564288, 38.544409967237904, 37.58993648713635, 42.03001245375603, 42.55380184419694, 49.446951650804095, 52.28777139417587, 50.693018051885794, 53.66557451986498, 52.814530018837225, 51.03660983424033, 47.1006525716474, 47.99472155109529, 55.79379766218124, 43.44763155906431, 45.57141850071569, 45.12358580866168, 52.63425396334741, 54.874390171420195, 53.14533487443001, 50.844770631482525, 52.805077106721946, 53.449585283956225, 54.14806919713175, 53.26944258905227, 51.91086299957768, 41.76866885154478, 37.64255508299797, 40.531918079622336, 39.75828547631541, 37.428542721656065, 38.74518825161842, 37.88820920451995, 38.33626939404396, 39.00946578671856, 39.98504161834717, 40.20557295891547, 38.026304091176684, 39.39688613337856, 38.94292669911539, 38.54614757722424, 40.87377617436071, 38.92918271403159, 38.58434754033243, 40.010199700632405, 37.80695338403025, 39.246318109573856, 38.350189885785504, 38.25957529006466, 37.65445163173061, 37.798300635430124, 37.77441732345089, 42.1039608986147, 45.83635891637495, 47.446601698475504, 50.79864355825609, 54.09610171471873, 55.17467898707236, 50.392968500814135, 54.1768515494562, 54.898089132001324, 50.07540948929326, 46.87208037222586, 39.384452219932314, 40.746252075318374, 41.98812938505604, 42.55430782994917, 44.540953020895685, 50.94907429910476, 54.58926916122437, 63.47321010405018, 62.36692913116948, 40.35819630469046, 7.9218546325160615, 4.463755315349949, 7.193302810192109, 3.5843944886038384, 0.6979177435559611, 0.05304183645714676, 2.467921236830373, 35.707787159950506, 52.942407131195075, 48.784530008992846, 32.20841519294247, 36.2696353081734, 60.059457594348544, 66.50391963220412, 38.62009209971274, 2.9918329561910326, 0.07629614428526933, 0.0668486024463369, 0.09005597206733881, 0.041307683042701215, 0.06176372832288185, 0.02490403986866436, 0.029899076776458856, 0.022841622008972114, 0.01414903875200018, 0.06994614107233864, 0.029868653509765867, 0.048413010644576246, 0.03844780787344902, 0.023342928879203338, 0.155469301126657, 0.20018271230641874, 0.08826423796915239, 0.1596112627415888, 0.2902233396326342, 0.20832359159906066, 0.13887146998557354, 0.22073495141681165, 0.1405118021272844, 0.12717107806595104, 0.10716636965592062, 0.14896443323983302, 0.20509750341936467, 0.15433693124401957, 0.1211855105394798, 0.13999905947956348, 0.21259632442266713, 4.970766277082506, 47.94226377241073, 65.6848346033404, 58.62998508637952, 33.20009431531353, 31.71445738884711, 47.65750362027077, 57.34351042778262, 54.8249839967297, 11.2935019693067, 0.12502020960974117, 1.1794684779259468, 8.053777669706653, 12.214349950513533, 8.12700734023125, 7.950376147224058, 35.291290283203125, 57.03664771972164, 57.34044705667804, 56.2783202048271, 53.5804904660871, 49.06713677990822, 46.52453484073762, 46.05767473097771, 47.097506830769206, 48.58151205124394, 50.32319738018898, 53.73254114581693, 53.552457286465554, 52.389227421053, 50.48135519027711, 52.60999410383163, 56.98277396540488, 51.3964480738486, 52.10119208981914, 52.38775260986821, 46.52015747562532, 39.48425692896689, 39.26342356589533, 41.20391422702421, 39.07340042052731, 43.80274726498512, 47.1050024801685, 46.20679540018882, 46.25045530257687, 46.68249260994696, 43.19754515924762, 40.102281262797696, 40.163078000468595, 41.04723907286122, 42.308496813620295, 39.82729565712714, 38.69924160741991, 39.104461669921875, 40.668506776132894, 42.15133136318576, 39.102982936366914, 39.217743642868534, 39.05246280854748, 43.99639468039236, 45.792400913853804, 50.733198811931, 54.71105483270461, 53.22086011209796, 56.31259779776297, 53.036273371788766, 53.28140581807783, 49.734469229175204, 50.008807643767334, 56.047104327909416, 45.927095105571134, 48.424864353672156, 47.30412160196612, 56.35559874196207, 56.58218229970625, 55.36472566666142, 53.180287115035526, 54.340261413205056, 54.42041112530617, 56.049500896084695, 55.83474328441005, 55.567586729603434, 44.38115173770536, 39.34027848705169, 41.59869686249764, 42.02406221820463, 40.61666480956539, 39.882628533148, 40.848943648799775, 41.116916056602236, 40.94675187141665, 42.22001990964336, 41.92527340304467, 40.3389923803268, 41.466061915120775, 41.76626836099933, 41.63279794877575, 43.12799761372228, 40.99125900576192, 38.94011828207201, 42.4196332500827, 39.900039934342914, 41.35261912499705, 39.84928054194297, 41.50520324707031, 40.44802642637684, 39.7950263177195, 40.143854464254076, 43.67818847779305, 47.23133810104863, 49.32939037199944, 53.243582402506185, 55.49787052216069, 58.585352436188735, 53.49395121297529, 54.07838436865038, 56.76308201205347, 52.60375753525765, 48.88232254212903, 41.29204988479614, 43.06523576859505, 46.880023171824796, 44.01211161767283, 45.938646485728604, 53.42935762097759, 58.53169833460162, 66.83348501882246, 64.27431106567383, 41.96957265177081, 10.771174642347521, 5.724528643392748, 9.041506475017918, 9.522293940667184, 1.9479805495469802, 0.16659015519244058, 3.4927142339368022, 39.780395876976755, 60.65585005667902, 57.23721027374268, 40.41804775114983, 47.28956176388649, 69.11348035258632, 72.99021767031762, 45.76841562025009, 4.1161416326799705, 0.08828252448790497, 0.26766195833202333, 0.19995231902407062, 0.0932647543208253, 0.14913430557616297, 0.09533657016412866, 0.15809820844761788, 0.09991759209022408, 0.1002196145934924, 0.14985416775509236, 0.20178602707962837, 0.2026220128661202, 0.21217091579831418, 0.11252645703573382], [0.042065987513671, 0.0436817167416936, 0.012025908424308705, 0.021924838844326236, 0.04605795294346829, 0.032533275849756696, 0.022655621606616244, 0.027121709276651664, 0.010846807178290141, 0.05816216896017713, 0.02798904912666448, 0.04279540280901617, 0.10704479916321655, 0.04599323000518545, 0.018956194511584697, 0.00979374080235439, 0.0731134703082423, 1.1691581602058103, 25.134265653548706, 49.45239590060327, 51.21642305004982, 44.844089477292954, 32.06324631167997, 31.93613406150572, 42.548714530083444, 48.73854806346279, 15.432686055860213, 0.06578934033431354, 0.1186073029173478, 2.881818072449777, 6.3429216800197485, 5.461135602766468, 3.329145023899694, 21.792398421995102, 45.86965983913791, 56.125320311515566, 51.01416603211434, 49.82603696084792, 49.162415073763945, 48.4728035619182, 46.35408432252946, 45.31491902566726, 48.783890662654755, 49.22002684685492, 51.40910948476484, 53.114222634223204, 49.104528734760905, 49.06628170321065, 49.010270257149976, 45.60771219192013, 45.40154064855268, 43.81070183169457, 41.36286435588714, 37.5259312506645, 36.474022173112445, 34.64242043033723, 36.27808409352457, 41.69900363491428, 44.87433095132151, 46.53840434166693, 49.252700190390314, 49.63205222160586, 49.42870478476248, 45.604240894317634, 45.77688009508195, 45.50666016917075, 43.734141088301136, 38.342400058623284, 37.17204324660763, 37.17937023408952, 35.98834645363593, 35.729113086577385, 36.83666490739392, 36.05646625641854, 35.271297962434836, 36.793899305405155, 38.50098932943037, 38.68250877626481, 39.0080576558267, 45.460795894745864, 48.83576008581346, 50.893792413896136, 50.192582453450854, 50.207342332409276, 51.50965944413216, 56.12200983109013, 38.12479088383336, 44.68110322952271, 46.5664061423271, 41.908630786403535, 52.12860553495346, 49.428379228038175, 52.51717905844412, 49.5271013629052, 50.89118011536137, 50.63802642206992, 48.6389708518982, 50.25161804691438, 51.80042474500595, 44.44490202011601, 37.71664473318285, 38.41228885035361, 37.70295958365164, 37.954775748714326, 37.73622520508305, 36.88179962096676, 37.721955622396166, 37.631639126808416, 39.63660570882982, 37.767612011201926, 37.60335491549584, 39.87572908401489, 43.53588488794143, 45.31736658465478, 47.121307772974816, 46.54717476137223, 41.900837036871145, 39.781215652342766, 35.87674325512302, 36.611481635801255, 36.48034111146004, 33.96469370011361, 35.329117621144945, 35.42697291220389, 37.11100724435622, 36.99126512773576, 38.8778075095146, 42.903387008174775, 45.29482472327448, 49.56168882308468, 50.912443284065496, 53.56458133266818, 48.55318469385947, 54.66614761660176, 52.33097237925376, 49.676363237442516, 45.395508043227665, 40.98508519511069, 38.924679833073775, 41.3217108480392, 41.42821888769827, 49.73086064861667, 53.50708723068238, 60.64292192459107, 59.35041858303932, 37.65951148925289, 6.003739622331435, 3.7214982413476516, 4.124917935940528, 3.472494660846649, 0.6618818869033168, 0.025133488947645794, 2.7550215730744028, 35.579478586873705, 50.029937451885594, 45.48113338408932, 35.66671994424636, 35.72051525115967, 47.94302078985399, 56.318163641037486, 26.035459618414603, 0.9604831640758823, 0.053818496394782304, 0.06835194274542794, 0.04264021637819467, 0.025808962077022563, 0.033884662609066696, 0.08743860969139684, 0.005257100743737313, 0.012733963273105123, 0.04273330755231362, 0.020463859377008294, 0.07265030121010158, 0.024387225463625886, 0.004930008970756805, 0.03407556788935777, 0.03383066873216341, 0.006134197681075744, 0.023610883452478918, 0.023671643800973415, 0.017845506832424193, 0.04978701614985063, 0.024564488633205334, 0.009903800823996145, 0.04755265943165268, 0.022899678067093896, 0.02841588650499621, 0.024400679882796063, 0.03252494464358015, 0.021638505821747166, 0.05800021797298424, 0.024575020426944382, 0.03891789474554601, 1.5286286776104283, 30.991860705037272, 55.52760993280719, 57.2592108480392, 42.683012562413374, 34.15253600766582, 40.795120885295255, 47.85356721570415, 53.02889539349464, 15.637746587876352, 0.07812851168695958, 0.22571533497783447, 1.9056086554642648, 10.06077947155122, 6.50816083915772, 3.0991161542554058, 23.282091079219697, 50.753332338025494, 57.29756378358411, 52.30700669750091, 51.64191392160232, 51.7157329282453, 50.04266554309476, 47.31493165416103, 49.18693773208126, 49.11222834740916, 51.71810596219955, 52.74789287197975, 53.48271754480178, 49.648624235583895, 51.31037166041713, 51.57297042108352, 47.944397541784475, 47.066716224916526, 45.756550450478834, 44.19359968554589, 40.83069286038799, 36.49950973449215, 37.21299279120661, 38.44373841439524, 42.703691297961825, 47.2466157328698, 47.97476453165854, 50.80152257796257, 50.23796427634455, 50.94341824131628, 46.87791293667209, 46.29846511348602, 45.69586746154293, 43.602855436263546, 40.16060690726004, 38.89862745038925, 39.144716955000355, 37.91249259825676, 37.83448450026974, 39.067626691633656, 37.52460548954625, 36.61237593620054, 38.15285544241629, 38.54497478854272, 40.133981858530355, 40.570788768029985, 47.63350263718636, 49.697100808543546, 51.84336293128229, 53.04882495634018, 52.40053169188961, 50.72784869901596, 54.81236573188536, 42.51814357696041, 44.743213961201334, 46.27273044278545, 44.85101638301727, 53.26031523366129, 51.8668814628355, 54.97814078484812, 51.69794497951385, 52.21647054918351, 52.67481519329933, 51.488435499129764, 53.821112186678, 52.74903428169989, 45.85537456697034, 38.2336837245572, 39.454215495817124, 39.79564605220672, 38.95556849818076, 39.02820294903171, 39.12680741279356, 38.59970361955705, 39.03499257179999, 41.85779294660015, 39.763557141827, 39.35361454563756, 39.73918353357623, 44.4622310515373, 47.004017137712054, 49.888559541394635, 46.66632460009667, 42.5597010889361, 40.28273382494527, 37.70659954317155, 39.20132460132722, 37.94746445071313, 36.10317776280065, 38.22971820831299, 37.44748776958835, 38.188556855724705, 39.18189710186374, 40.95430243399836, 46.21225533946868, 49.76244749561433, 52.95557845023371, 53.965267135250954, 55.6663167092108, 49.517730820563536, 56.24706283692391, 55.4020195622598, 50.747374257733746, 45.99160240542504, 42.270398832136586, 41.39416094749205, 42.656446349236276, 44.03764624749461, 49.883778172154585, 56.41273198589202, 61.7375377685793, 60.89336526009345, 37.387946190372595, 9.446884412919323, 6.575296127027081, 9.295697635219945, 4.563010402264134, 0.8305522006365561, 0.05463043851177058, 2.8212694246922774, 39.5168714369497, 56.499051586274184, 49.72150971812587, 37.09268193091116, 42.570640579346694, 56.07256051032774, 64.86288232188072, 30.750572181517082, 1.5517099874634899, 0.07714390484315735, 0.04107628235473268, 0.03682942798120841, 0.01768448281161968, 0.030332272684562112, 0.012858267742088966, 0.008715757416681418, 0.007120198804900171, 0.006453169400863831, 0.022384493514114333, 0.0645454740151763, 0.051518688954773455, 0.018906253239800854, 0.07904002608190622, 0.13184265924557564, 0.11145974854908644, 0.14155446311398862, 0.12762503112636267, 0.09698244112153208, 0.14018403906976024, 0.12750631048073693, 0.0728358477053623, 0.10709982725881761, 0.11180369904445064, 0.1482074311183345, 0.16564265764769048, 0.24053904438211074, 0.15067132310040537, 0.18648355868795227, 0.1359205759100376, 0.19644999486063758, 2.065186486128838, 35.21858130731891, 64.80537645278439, 63.87716716335666, 54.52060022661763, 42.50360335073164, 42.59111142927601, 52.83662865238806, 59.329641788236565, 19.399901666948875, 0.19560869242395126, 0.4292073785778015, 6.629463568810494, 8.913265562826588, 7.761585606682686, 5.868475706346574, 25.183791460529452, 50.78813552856446, 60.775380365310184, 55.76341106045631, 54.87525701522828, 54.06988851485714, 54.40946379015523, 49.97433785469302, 50.47831927576373, 51.57059346475909, 53.21191710810508, 53.62032605755714, 55.30687855136011, 51.03575867991294, 52.937916017347774, 54.123954465312345, 49.3880101942247, 48.84445990285566, 47.74101088123937, 45.9599567228748, 40.83892199300951, 40.184721639079434, 38.60436731769193, 39.62797649445073, 45.86655724433161, 49.87733371796147, 50.643937433919604, 51.61837185582807, 54.072139955336056, 54.039701954011, 48.197700285142474, 49.39563528183968, 48.95245059843987, 46.21045889392976, 41.584388056109034, 41.80372307377477, 41.356780759749874, 39.41248539955386, 39.0795506969575, 42.02104591554211, 39.318607391849646, 37.749878975652884, 38.966398162226525, 40.32359315503029, 42.24248724599039, 42.75629812671293, 50.347280733047, 52.53581816150297, 54.63452546827255, 55.217154333668375, 53.98555755615235, 53.6209418696742, 54.4616783818891, 45.066154464598625, 47.13680505752564, 45.85284071583902, 46.6039667590972, 53.24638297480922, 53.75244325207126, 57.09550288415725, 53.01107214343164, 54.993469407481534, 54.98482058125158, 53.200244134472264, 55.430982343612186, 54.303571562613214, 49.23095064778482, 41.38971297971664, 41.213245545664144, 41.24249073766893, 40.42852832425026, 42.187746647865545, 40.274716500313055, 41.40127220461446, 41.07209513264318, 43.45244822963592, 41.490396299669825, 40.42431569868519, 42.93424037195022, 48.2777048695472, 49.91323909451885, 52.14086294174195, 49.891924935002486, 47.191871212374785, 42.51313863262054, 39.848460766576956, 40.94006815264302, 39.4887754994054, 37.43336723696801, 39.70666708484773, 39.411547953082675, 40.81088096864762, 41.512185065977036, 42.526462924095895, 49.39568627265192, 52.932212891117224, 55.010453270327666, 56.24623521681755, 56.43935311225153, 49.022590421861224, 57.33270822032806, 57.846895648587136, 54.48914674020583, 50.05121238770024, 45.46970359740719, 44.205288348659394, 45.47116664148147, 45.23886034565587, 54.51785064512684, 58.362538276180146, 65.85963110769949, 63.89653974963773, 40.19502962789228, 9.57431241389244, 9.447015812320094, 11.611522839915368, 10.092778167416974, 1.8925635877155491, 0.11390542296031791, 3.872134416334091, 43.42156740926927, 63.92425913964549, 57.51225471496583, 48.9614995064274, 49.02652455914406, 65.30399599382955, 70.55593982819589, 36.41876382212485, 2.179114669561386, 0.21539346465179998, 0.18667918690029653, 0.1772887722378777, 0.1273021327271577, 0.16422882706167238, 0.27810431896678867, 0.1360484206628415, 0.09387517317889199, 0.13135055500653484, 0.1332476032116721, 0.20944485320679604, 0.1230035137925898, 0.058843171329147397, 0.20940968977107158], [0.028759752730688745, 0.06684048957521878, 0.08856324208599907, 0.0812670513386688, 0.03048273618333042, 0.021372523924876607, 0.06586653135356403, 0.04357287863029107, 0.07502039338672355, 0.04553599425801828, 0.043379085198525465, 0.03108019857937771, 0.04276870464485499, 0.051989377205890995, 0.10745972770476535, 0.023253725601300117, 0.039823215319624836, 0.38839456535154776, 20.174993391959898, 46.01394422592656, 52.60010188625705, 37.676499274469194, 16.530995791958226, 34.80117051832138, 44.03222945428664, 49.68963653810563, 26.53672872051116, 0.4443238867867378, 0.041532740522656715, 2.027990894932901, 2.8265702628320266, 3.1661318098345115, 2.1960392065586585, 9.371203261037028, 31.6302695966536, 49.24900139531782, 56.329558126388065, 53.25863645922754, 51.27612544644264, 49.51395750045777, 51.09654365047332, 50.793673915247766, 51.817416452592425, 52.25121882654006, 51.72116148856379, 45.31189095589423, 50.23783483812886, 49.44519442896689, 46.086206051611136, 44.1044795128607, 40.614056433400805, 37.257731345392045, 36.00149423845353, 36.20193912136939, 35.973021753372684, 37.597855752514256, 40.73353575121972, 46.6716904024924, 49.34452679849441, 48.34202389563284, 50.18235291204145, 50.004563639240885, 50.61472754324637, 48.71425682498563, 49.26638533992153, 48.0557575533467, 50.29937290376233, 48.88153022335422, 39.61333820896764, 36.76753705547702, 37.66082156089045, 36.60955575204665, 38.50709645978866, 36.58207170424923, 37.95275180570541, 36.15415680793024, 35.86263841198337, 36.838857512320246, 37.78537250334217, 37.680068631326, 47.07736545993436, 47.0725566341031, 49.1353311077241, 48.20594118487451, 49.88851639532274, 38.118099320319395, 44.48298431211903, 50.619681496774, 46.7694672461479, 42.39006642372378, 49.569168783003285, 47.19679770931121, 50.38259775407853, 49.78966089986986, 49.799823760986335, 50.31347774690198, 51.05740231852378, 51.88701106655983, 49.72893084249189, 44.31269068871775, 35.5932500285487, 35.327407467749815, 37.555086228155325, 37.04243636900379, 36.54839423394973, 38.57911902089273, 37.898615252587106, 39.0076458069586, 41.420421215795706, 40.04561478091825, 40.505948066711426, 43.492425026432166, 49.87856926456575, 49.05333788164201, 52.231854084999334, 51.67340663171584, 48.91831028846003, 46.577832006639056, 44.98990751081898, 40.79580730007541, 37.97463078652659, 38.28061488366897, 36.10526054136215, 36.39503740495251, 35.854444580693404, 37.56783785358552, 36.36728271361321, 37.62745788020473, 39.55294939779466, 47.44099663149926, 48.0121329522902, 52.03479420754218, 53.541682535602206, 52.254768571546, 53.17837692076161, 55.961875146435155, 52.47034988095684, 48.58778392114947, 42.0715581986212, 40.93228617022115, 40.94795603905955, 49.24268637934039, 56.154345850790705, 62.67818489382344, 56.81062506091211, 30.93355663361088, 3.0476441162247814, 4.621743973224394, 10.228874606470908, 0.6092179999236138, 0.5488204859918164, 0.10320538099134162, 2.9293746044558864, 41.09348773956299, 49.707118541963645, 44.79679746012534, 23.237483924435033, 35.09543457338887, 51.74257370733446, 51.982595305288996, 24.411249276130434, 0.6480623349066704, 0.053668147809202635, 0.04891852525273158, 0.02878730316766568, 0.05485237418343464, 0.02899199420015418, 0.08114342773032766, 0.0502030325362519, 0.026244241744279865, 0.09275952699564158, 0.031041300465022365, 0.02886801436092825, 0.018001204626935146, 0.04741532284946692, 0.11203437577933074, 0.03640036894789627, 0.08189127510113102, 0.043981831686030474, 0.019469875617012865, 0.037594945169985294, 0.014463229604335803, 0.07824865725612448, 0.024540916107775226, 0.06088839626059898, 0.01967750459669098, 0.018359069194224094, 0.03214126482846276, 0.08349226096705084, 0.03642176578362142, 0.15883926061853287, 0.04466654575099388, 0.02895563375204802, 0.6216184506493231, 23.71855282014416, 53.60165165316675, 57.03023464448991, 46.6198915819968, 20.854671501344253, 33.462014505940104, 47.562315540929, 55.57556090816375, 26.572465435151134, 0.5047901954141356, 0.03663237101488537, 0.7390407304609976, 5.13788229034793, 5.476276932224151, 3.1890222718638763, 14.240361029101958, 33.43904902858119, 53.70042870121618, 56.727306073711766, 55.03270095394504, 52.352419899355986, 51.64609909057618, 53.125146435153106, 52.37766427378501, 53.42752587410712, 53.056383363662235, 52.01342905721357, 47.992372051362075, 50.58140308626237, 53.216890673483576, 48.57149039545367, 46.53264630225397, 43.25725147801061, 40.137135444148896, 37.65084697354225, 37.8699388042573, 37.580973871292606, 38.810472180766446, 44.16671576038484, 47.937070554302586, 51.426858209794574, 50.848477271295366, 50.80704919753536, 51.886144222751746, 51.236419293188284, 52.01065201913157, 50.82624919952885, 51.19429303753761, 52.03961480048395, 49.59558202374367, 41.675881262748476, 37.66295925263436, 38.68138697839553, 39.52164888381958, 40.41783202079035, 39.237779109708725, 38.80643998422931, 37.77058124542236, 37.62790503040437, 37.82310178202968, 39.427060927114184, 40.23652045957504, 47.132400235822125, 49.459860171041186, 50.20403577435402, 50.98855687725929, 51.36840704948672, 41.54179111603768, 45.57694119791831, 53.223256680273245, 46.893516125217566, 44.345062009749874, 52.23115198073849, 49.79385783595424, 52.82291212389546, 51.40657563363352, 49.648926258087165, 51.18589916536885, 52.58325922873713, 54.03930971699377, 52.35120396460257, 46.882003968761815, 37.71158487566056, 37.49519555799423, 39.150133748208326, 40.11158120247626, 37.896391268699404, 39.8386783753672, 38.33888953731906, 41.1390656809653, 44.19498428221672, 42.93423644958004, 43.766853655538256, 46.62726563792075, 51.31771825974988, 51.32385284669938, 53.50391403321297, 54.250584263955396, 51.22387947574739, 48.17820610538606, 44.95051514717841, 41.824480256726666, 40.280851087262555, 39.08514399682322, 38.464232798545595, 37.94205157987533, 38.972799470347745, 40.17244462044009, 37.94865292887534, 38.24578031416863, 43.15259871944305, 50.13480986318281, 49.978107252428615, 55.3272670315158, 56.34413757631856, 52.27058749045096, 56.11438866584532, 57.63855111214423, 55.450045062649636, 50.34071468537854, 44.84837270552113, 42.614551513425766, 44.08828796878938, 51.05116967231997, 57.99993868797057, 63.06631126711446, 59.55728046355709, 35.13505835686961, 8.903040924379903, 4.267099442020539, 7.558260233171525, 3.7623222701011168, 0.6693972094405083, 0.0784616373599537, 2.6638759864914805, 43.697023699360514, 57.814606697328635, 54.40732217604115, 34.538763953793435, 43.11535189228673, 58.81452083587647, 59.10253655525946, 30.3465719761387, 1.1062014223106447, 0.04473596480825255, 0.038811527267699285, 0.03166942553023898, 0.09135074492904449, 0.013363242258257685, 0.06893233095686283, 0.018562260609600815, 0.0668261943745517, 0.02408221904789248, 0.03775778864960998, 0.013144537562414283, 0.07032510178584246, 0.056895745182109464, 0.13690302238589333, 0.10697424246539032, 0.09742177722434844, 0.21544031858924897, 0.193505643175975, 0.0999779828012951, 0.1177457068115473, 0.25789786130189896, 0.14884876928502513, 0.26551145759801714, 0.17175240802668756, 0.13818484070079942, 0.10227979356122595, 0.14262114861799827, 0.18490535627690055, 0.22304602417974706, 0.12567299313002056, 0.09824167516443039, 0.8259986965887008, 26.739819242108254, 59.42720682390275, 63.51787805557252, 50.36719852878202, 25.153795134636667, 45.484973384488015, 54.97165710695329, 61.38326144987538, 32.03730179417518, 1.0016603287189239, 0.1477642952194137, 5.386672837118949, 6.630317664915516, 6.8520467992751835, 4.78625504239913, 11.24266314891077, 33.53356638262349, 53.78604619733749, 60.79168958048667, 57.57409480310256, 54.39783788496449, 53.28533995536066, 56.93612521694553, 55.637314704156694, 54.49042151051184, 53.91765348372921, 52.70885744402486, 49.95898962020875, 55.64949758591191, 54.8384298816804, 51.48686262869066, 48.87222243893532, 45.17389805086198, 41.173629606923754, 40.506748230226584, 39.98439442726874, 39.841596618775405, 40.52428906963718, 45.246783533403956, 52.0996113746397, 54.02500091060516, 52.36666202545167, 52.27682798139511, 54.083338322178015, 55.0261192167959, 54.30863926487585, 52.98348219163957, 50.99952774663126, 55.867651970155784, 54.06767629807996, 44.23716545104981, 38.64778011075912, 40.1547468862226, 40.31891376741471, 41.58900860817202, 40.51315738308815, 40.73697566986084, 39.60645052694505, 38.74843989649127, 39.60976885211083, 41.694069293237504, 42.210210061842396, 49.49456922469601, 50.82997545119255, 53.358645131511075, 52.89258518526631, 51.932851806763686, 44.862324576224054, 49.85941633101433, 54.11679613974787, 48.204795852784194, 46.25098090017996, 53.232368346183534, 51.53490381856119, 54.17157596157443, 52.93888876515051, 52.47509594886534, 53.288881855626265, 54.277774133989894, 57.1720753946612, 54.639522567872085, 48.20792982655187, 38.91360305970715, 37.92810363154258, 42.403680970591886, 41.02632107273225, 38.98950092254147, 42.72689603990124, 41.52172819260628, 42.33658882879442, 45.494077205657966, 45.00505178205429, 47.409766720187285, 49.30622485376174, 55.72902756352579, 53.75258053502729, 57.12996875086139, 55.858434400250836, 52.902065553972804, 50.49466771464194, 48.80936253455378, 43.657572500167355, 42.004795535918205, 42.52472531410956, 40.505269496671616, 40.21184875119118, 39.628549160495886, 40.910160080079116, 39.3650717889109, 40.563677510907574, 43.93049493912728, 53.48796567609234, 53.130476936217285, 57.389264875842684, 57.246957363620886, 54.716044087563795, 58.0677721577306, 60.006168273187455, 58.61537425748764, 53.791298250998224, 46.71045126453523, 44.99588128059141, 45.10936329441686, 54.346541127850934, 60.43593845059795, 67.40449582376789, 60.224758040520456, 35.4643177986145, 5.301629477931607, 9.599001772942083, 20.112182517205518, 4.874400506096502, 0.9343066138605919, 0.3055615843303742, 3.686470985412598, 49.66011285781861, 63.704547574443204, 58.981213723459554, 36.16184857583816, 49.43487859541371, 67.11413060465168, 65.27747292672434, 39.0928122305101, 1.5875517480796384, 0.18946747115302473, 0.13101077969035796, 0.1370269907338004, 0.18055875725563497, 0.07786305456031715, 0.17832515130360282, 0.10123497220657526, 0.09779840903056246, 0.15676489370244165, 0.10598844818530545, 0.11571936594742922, 0.17127222411574858, 0.10922690102409933, 0.3391140290806371], [0.03075798199842534, 0.030896167022987243, 0.07202542627290373, 0.04692460139912944, 0.05492883741915707, 0.0662575426301168, 0.032195802627792286, 0.028562711086124185, 0.007378787474496471, 0.07503852668789125, 0.03615632014829786, 0.0612481703020392, 0.013774507941918509, 0.02460828204939683, 0.023300951091392387, 0.07802007960215693, 0.042773695707681685, 0.1359102184013013, 13.146038382284104, 44.89974006529778, 49.222282209704005, 37.21496574340328, 31.273043655580093, 37.64492419458205, 51.93641724125032, 48.07716977211737, 33.89873904566611, 1.9868612890281987, 0.03230176407903914, 0.7541110282463412, 6.984192430973054, 3.827858701828988, 2.6341588843253354, 2.620683091302072, 13.698538541793825, 36.83835937130836, 50.40023273037326, 54.911703678869436, 51.15361021411035, 53.185284214635054, 53.378680598351266, 51.20984915764102, 49.14725903541812, 50.826155062644716, 49.346899832448656, 52.84182971523654, 48.90188732454854, 44.77280039941111, 43.60750344491775, 38.24152062016149, 36.34335625556208, 36.62315460943407, 36.58120878281132, 35.68125624810496, 38.64714860916138, 43.294196282663655, 45.884572690533055, 49.30364001181818, 48.99382768138763, 48.634260085321245, 48.825781576095096, 51.62479277580015, 49.748444634099165, 50.38181328004407, 49.99669928704539, 52.29496109870173, 50.19221767302483, 48.94094628672446, 46.11716531938123, 38.906742834275775, 35.84156351704752, 37.629862293120354, 39.571055058510076, 37.22605428388042, 35.78239064062796, 36.666139864152484, 34.94292497634888, 36.78137517744495, 35.12150264555408, 37.95005713739703, 41.862562548729684, 46.71615831313595, 47.5791621208191, 49.538735112836285, 46.13064650566348, 47.20325393061484, 50.22070584758636, 49.506481462909335, 48.90584891842258, 44.01031517213391, 44.93366072254796, 46.045829173057314, 50.25037465556976, 50.18836198314544, 50.464045770706676, 49.648377126263036, 53.59774889484529, 50.96228091947494, 50.2043221073766, 43.22786900304979, 37.5786792847418, 37.94832737215104, 37.89648932795371, 37.557106248794064, 37.54725325492121, 38.1328905782392, 39.54470457569246, 43.645464143445416, 45.28279089158582, 45.701829464204856, 45.06997877551664, 48.19968500444966, 50.41012887031802, 51.730504574314246, 52.82544597502678, 53.21525504512172, 50.42934456179219, 48.103496720713956, 50.03311457172517, 48.92686497780585, 47.529324485409646, 47.37540283510762, 44.068185821656265, 43.88779209506127, 40.86916738940824, 35.257789319561375, 36.22419464972712, 37.57777713960217, 37.956395687595496, 41.14971099361297, 49.14572146631057, 49.85586266363821, 53.58436184544718, 53.71394911120015, 55.37565338996149, 45.91917191782306, 52.06334906239664, 56.91636823838758, 47.55750279272757, 46.504028689476755, 41.61852836608887, 48.50586129773048, 53.57801545050837, 61.00530578244118, 56.41403421278923, 27.252102359648678, 10.522410081278894, 3.4923582788436645, 6.130864620208741, 2.862237845697711, 0.36909647346023594, 0.06511738163328941, 3.432699028522738, 41.74128678537185, 48.22167773400584, 37.724846409213164, 14.591621045143375, 36.10417404482442, 53.65331711307649, 54.62896354736821, 20.801242936042048, 0.1334736297928518, 0.013048917340535312, 0.08649570101331319, 0.009579691048260898, 0.001515701845956726, 0.04451191473391749, 0.06306333902982936, 0.05693006209067761, 0.020872843076264667, 0.033448199335966385, 0.06859287739761415, 0.042290252092624867, 0.07090211154953127, 0.03026613822927879, 0.06640327553595267, 0.00914521002766466, 0.028173952108068813, 0.07635419076729207, 0.03848665619208928, 0.0608249718413478, 0.05756508386243255, 0.027788609882155736, 0.05287143552014905, 0.012305756512608741, 0.016928792615691503, 0.027051043411296223, 0.03364588066394772, 0.03213426661527446, 0.023364775791584004, 0.03826180555587334, 0.01447578578541476, 0.06058709387997947, 0.11148056315798914, 15.27533527343504, 50.15059740312638, 56.02569210913874, 40.62109708786011, 26.859628039021647, 39.41362288690383, 56.89274772520989, 54.984012572996086, 36.776193726447325, 2.278157703338131, 0.07342073285291273, 0.06535785663272105, 4.185256246597537, 7.477911951080446, 2.4031499124342397, 4.715113053398748, 17.492904124721406, 40.7071852684021, 51.75226980640043, 56.74508617770288, 52.4199160452812, 54.400089325443396, 52.946564843577725, 53.07826234448341, 50.98292435369184, 51.80446478628343, 49.935996686258626, 53.99631269516484, 52.022336759874904, 48.07445156958796, 45.38298391526746, 42.2558742953885, 39.5986803116337, 39.859619909717196, 38.02421739024501, 37.95034739278978, 40.39899287685272, 44.01656350781841, 46.60207617667414, 50.75147313456382, 51.443292940816576, 51.102172251670595, 52.36228466033936, 53.871738218492084, 52.4362801736401, 52.51191523767287, 51.94976506694671, 54.01046460674655, 52.76696735812772, 53.03942695740731, 47.11579292051254, 39.555063555317545, 37.77520571985553, 39.61041604318927, 42.06876939342868, 37.98149493432815, 36.915339808310236, 38.645579661092455, 36.444290607206284, 39.510172028695386, 37.852499946471184, 39.42282868969826, 42.991189264482074, 49.380004636703006, 49.24749128280148, 51.739274994019546, 47.47630580779045, 47.92054953113679, 51.278349430330344, 51.77184635593046, 49.46161739287838, 45.23018406283471, 47.94726479438044, 48.086136310331284, 51.58081516142815, 50.75576420753233, 50.94923119391165, 50.30568791973976, 54.60918695695939, 52.21504672881096, 51.6858523122726, 45.6169258394549, 39.08892516166934, 39.25173098041166, 39.520746738679954, 38.70048107639436, 38.986774875271706, 39.44780242058539, 42.18420866997012, 45.90747148759904, 46.80397625892393, 48.34903317113077, 47.48226781045237, 50.87847163600307, 50.60177979930755, 53.97912879143992, 54.31424433185209, 54.88452557594546, 52.51069538054928, 50.69931345601236, 50.84499028421218, 49.35974167239282, 48.14663102549892, 50.25510895636774, 46.914465504307906, 44.945365075142156, 42.10032878383514, 39.063382687107215, 39.60430106809063, 39.349703942575765, 41.235759950453236, 44.70254682725476, 49.84981829120267, 52.08574187371039, 54.9461381666122, 54.52017661063902, 55.661394134644546, 48.490713104125, 54.380124461266306, 57.09882905406337, 48.66729036454232, 46.788867289020175, 43.23378785963982, 50.95277309417725, 56.547579150046076, 62.51618316096645, 57.934784197038226, 29.11189613803741, 8.540236392328817, 8.307500596969358, 8.526011916898913, 4.446026692467352, 0.7651175666720637, 0.11888872531633224, 3.9280039216241533, 46.47298312956288, 54.03055890913933, 48.94731621588431, 18.00307700710912, 42.332533098036244, 61.63072770641696, 60.23446982906711, 26.558503758522775, 0.2836092429295663, 0.05826888883846903, 0.06155578141671516, 0.06906730032736255, 0.0382144230177566, 0.03390766439899322, 0.04029482287625152, 0.029011696066346862, 0.053872624337072336, 0.05205085193137488, 0.051285855682386514, 0.08731735329474173, 0.0740054494611198, 0.05353742256580342, 0.059887437270052975, 0.09344875331847899, 0.1993112106837573, 0.28212508547209925, 0.11343575743657928, 0.16072423527798346, 0.09658163924130703, 0.08469530246070317, 0.1383499173267234, 0.11384085707005956, 0.14795587848751776, 0.10990717943998114, 0.08124674234779612, 0.08118498800021988, 0.11161923273316315, 0.11474484082071051, 0.09932520694189495, 0.14270664403034797, 0.23870573469227363, 17.665058912769442, 57.97432168837517, 62.64121263257919, 49.74866428682881, 44.56766828413933, 47.23262463846515, 60.57427652420537, 59.1354020949333, 43.21524289346511, 2.8470634212416988, 0.13126021791850367, 2.0319011302724963, 13.42687322247413, 9.915798864056988, 6.075595482703179, 4.1722947743631185, 15.687824468458853, 39.94379789598527, 50.31847092413133, 57.02181723810012, 53.45149547823014, 56.49727083021595, 55.811546387210974, 53.81872346324306, 51.494726980886156, 53.562023947315836, 51.825531836478945, 56.50444092289094, 52.324912317337535, 49.17323297069919, 46.758186509532315, 43.44119494961154, 39.89087727762038, 42.54764764539657, 40.40540595208445, 39.574067438802416, 42.44167304808094, 47.789365860723684, 50.005869788508264, 53.61622718072707, 52.10178044534499, 52.92507025503343, 52.80429263268748, 56.23468383666008, 56.31661430481942, 54.98018826207807, 54.579761335926676, 56.76045402403801, 54.25139227221089, 54.835809738405295, 49.52638749153384, 42.93233410004647, 40.411116923055346, 42.6277659785363, 42.463763836891424, 39.72927170415079, 37.72274009643063, 40.33847070509388, 36.29559747634396, 40.879326328154534, 38.9080568282835, 41.11100504475255, 45.19251361969979, 51.27613329118299, 51.547467170223115, 54.587394268282004, 52.14248680299329, 51.265264403435495, 52.81496932429653, 54.37813189721877, 50.65248035615491, 48.79310431018953, 50.33158732998756, 50.48743094167402, 53.21891853886267, 53.64567241361065, 54.22304922534574, 51.20959420357981, 58.1684672447943, 54.5609418038399, 55.00043553690757, 47.14088040013468, 39.72118377685547, 41.64404730642996, 42.215273841734856, 41.02245753811252, 40.472250984561065, 42.4982806944078, 43.610433455436464, 47.24744727534633, 49.240540842856134, 50.59448419078704, 48.83809389606599, 52.959704783654985, 54.466428372167776, 54.915022004035215, 57.64623111294162, 59.20667548333446, 54.90515724305184, 53.59059449165098, 54.62648853178948, 52.77681250726023, 52.364171320392245, 53.954959146438114, 49.27020180609919, 48.36198091506959, 44.85291481018067, 40.3006669013731, 40.55603281144173, 42.143164988487, 43.36430080475346, 45.92274911942021, 53.53881136063607, 55.17030554433023, 57.30949171127812, 58.77025688848188, 56.43644271358367, 49.38773562831264, 56.407115151805264, 61.46658435944588, 52.6577175817182, 52.190939841731904, 46.111630855068086, 52.26187590629824, 59.60287017206992, 64.59440000595586, 60.13310009433378, 29.628174189598333, 14.067312921247176, 9.512554695529323, 15.24562135819466, 11.174765940635435, 1.938683919368252, 0.28742868152837603, 4.94935650979319, 51.21663093566895, 60.73769423269457, 50.25723488100114, 23.595306065774736, 51.98339154643398, 68.62996978144493, 69.14559671955725, 32.87588492516549, 1.0405030702390978, 0.11289660007722917, 0.22102108525653041, 0.13628494264858385, 0.18750179679163043, 0.24254630199603497, 0.09814609037411791, 0.126547742965481, 0.10584070046822872, 0.2191924487030314, 0.2078211911383175, 0.13499907938943756, 0.14269696067898505, 0.16174892384198405, 0.10488675246315618], [0.11636542321573343, 0.0367387767971283, 0.018379952751039978, 0.02679220719953939, 0.06764220824885754, 0.016114713113394477, 0.03349596108760565, 0.07137733121072093, 0.0386839583065481, 0.030187432271158023, 0.08080530716406722, 0.025665416352210507, 0.06759998914335044, 0.06654621222086492, 0.062419216133533954, 0.030693948539274356, 0.025074063507359357, 0.027848502636075984, 5.156463048150463, 35.755122323190015, 48.92269942068285, 43.76226056006647, 14.163384514470255, 22.33719602707894, 40.04725825402045, 38.718269025125814, 41.15573967656782, 4.949495263638036, 0.014800776562262929, 0.23410507027179966, 2.002033139428785, 4.460803731795281, 2.672319623731798, 2.8751061616405367, 4.086087942123413, 18.545929116587487, 39.84685651717648, 50.95322416674707, 51.46616035892118, 53.51842288048037, 51.719918097219164, 54.32229303544568, 53.047663934769176, 53.82421870385447, 53.23544348439863, 52.39520511319561, 47.93336783685992, 46.14171151191958, 39.30207852394351, 36.320575129601266, 35.927643852849165, 35.183911477365804, 36.51822728495444, 40.07467562152494, 43.50964423148863, 45.68822668444726, 50.55542915098129, 49.99697777532762, 48.49132499387188, 51.063144668456054, 50.84750060112246, 50.738819568387925, 51.07998732597598, 49.8799224822752, 48.52646550824566, 50.34812404263405, 53.95759497919391, 50.85605136809811, 48.220861881009995, 41.43681672311599, 37.25928852635045, 37.28581551582583, 36.75195740115258, 37.77311901892386, 37.977027354701875, 36.247536674622566, 35.67050110909247, 36.12881437424691, 37.22111994220365, 37.67001951894453, 40.32526408472369, 43.33212167985978, 46.268302086860906, 47.53720060471566, 50.83740834266909, 49.60973001295521, 51.24339718972483, 49.130577195075254, 51.68296544782577, 42.994044749967514, 42.85468293774513, 46.18759147582516, 47.99473331820581, 49.8421069114439, 49.19640633367723, 50.51482869732765, 50.85330963134766, 50.73242218263688, 47.661575040509625, 42.592692144455455, 36.82946735812772, 38.23520560418406, 38.50237000373102, 37.81630039215088, 38.94947313493298, 39.4365373734505, 42.17087261138424, 47.22900036842593, 47.964648738984145, 49.08791749708114, 50.90883862587714, 49.11726074834024, 51.12735779054704, 52.02877336932767, 48.88902979512369, 49.54227701310189, 54.11081844760526, 52.004584112475, 50.679517253752685, 51.680035437307055, 50.85097582109513, 50.080300684898134, 52.30925421560965, 49.18260351304085, 48.42638623329901, 44.66948516907231, 38.53464718787901, 36.151285632964104, 36.79966911192864, 36.89863051137617, 42.169491937083585, 48.43987526432161, 53.60792352307228, 53.47653981178038, 53.36235961606426, 48.580774645651545, 54.18173882269091, 58.408720262589, 55.109920655527425, 50.12705533735214, 45.37537059476299, 46.70529727012881, 54.23308264824652, 59.40376281738282, 53.5431848033782, 22.932445118504187, 9.534392491463693, 4.218723870092823, 4.274870637924441, 3.916342469953722, 0.7940250058327952, 0.045824460835466464, 3.9578558552649716, 36.4367086656632, 46.60093084458382, 42.211135741203066, 35.011397792447, 40.90056204026745, 53.25639286348897, 51.80129551118421, 18.34132848247405, 0.4006010119713122, 0.09336881970445957, 0.05634853623867516, 0.05542364977901021, 0.017723695022023974, 0.03264905471775321, 0.045105203865997257, 0.02152130777587093, 0.015000533030909157, 0.03049150597484362, 0.04554660457576956, 0.018818384870105696, 0.015582231252694563, 0.038199606877301014, 0.057127877484045686, 0.05928796580842426, 0.04832574939956108, 0.08198240125972418, 0.09087950892506108, 0.09455959613044417, 0.02534620858158075, 0.020807062936646324, 0.1396482065320015, 0.029844178915804917, 0.024572770043666807, 0.05829676294759397, 0.05795773456714327, 0.037054136891158364, 0.04062448583182789, 0.10454399706495386, 0.03933793692398937, 0.028121643624598944, 0.033889891159149914, 6.926086929536636, 43.462207086624645, 55.449617524300855, 49.365801734309045, 22.618502532282186, 28.494770026976063, 47.46205583695443, 45.96991954311248, 44.88625495664535, 5.288660160956844, 0.0426612684743539, 0.027088503195573727, 2.9035877172024023, 7.131710811968773, 4.351687315971621, 3.3774664180894054, 5.276589557047814, 24.44356176160997, 41.92260226895733, 52.10372986332063, 51.109252129831624, 53.91328396335725, 53.449997132824315, 55.23832728785854, 53.76319054634341, 55.066150926774554, 56.47293252329673, 53.56627579658262, 49.03222376300443, 48.92280140230733, 41.439307428175404, 39.695837420801965, 37.11429419056062, 37.30305825510333, 37.85736760785503, 40.725396833112164, 44.77285139022335, 46.32379185768866, 50.32717466354371, 52.69649805561189, 50.6539120212678, 52.04533753856536, 52.27625531534995, 53.052084445953376, 52.64907267785842, 50.37391362651702, 51.12285883195939, 52.64495811154766, 53.26464553033152, 52.6601690630759, 51.347116424191384, 42.52852216843636, 37.92308692009219, 38.619531200778106, 38.59276102435204, 39.04533586194439, 39.24691430984005, 38.36793468844506, 38.06100530009116, 38.35930155169579, 39.36168678345219, 39.6240698137591, 42.87120003854075, 46.86466709260018, 47.56218610271331, 50.053648179577245, 50.96798012333532, 50.87465124745523, 51.052036516128055, 52.10746788209485, 51.83127810878139, 44.26566147035168, 46.63798155323152, 48.22872623320549, 49.49756983787783, 51.67581104463147, 51.24715874272009, 52.15209660991546, 50.53410322435441, 53.26537509118357, 49.17298193900816, 44.580227713431086, 38.710298768935665, 39.3959016184653, 39.33359476827806, 38.14565397077991, 40.52292800718739, 40.18290950405983, 43.168292122502486, 49.871571756178334, 50.69548130035401, 50.952573053298465, 51.32753202992102, 52.44977312703287, 54.02944887838056, 52.97944607273225, 51.24780201142835, 51.03311892478697, 54.61119913285779, 53.75191765446817, 52.391682824780865, 53.882932662963874, 53.849612128350046, 53.44869882829728, 54.3501457860393, 52.589680148709206, 50.44621467590333, 45.998905858685895, 40.05313788690875, 37.530179177561116, 39.178751360985544, 38.73248761700046, 45.04087086646788, 51.641207894971295, 54.10318943762011, 54.615243096505445, 55.60802636608001, 49.16945572822325, 55.57738088792371, 58.38086751199538, 57.39071223043627, 53.82498748840825, 46.674859677591634, 47.73242873530234, 56.44579756644465, 63.33670377731324, 57.81607758614325, 23.542622750805272, 6.6550148687055035, 6.291844575635849, 6.096238426623806, 7.51152519256838, 0.2944052297501795, 0.01010120157227521, 4.359275631366238, 41.085646921588534, 54.95564206953972, 44.5679703066426, 31.254726186875377, 44.97399445502989, 58.963610126126206, 61.20549178892567, 22.23383568948315, 0.48359128616509905, 0.037065651192660296, 0.09401044132368219, 0.051392671321668935, 0.013278416215231823, 0.03335713446440716, 0.03909877576534787, 0.06245939744516246, 0.05235769312768694, 0.06397979086144798, 0.0318393821362406, 0.028988123540916753, 0.029174459106739492, 0.07064135820274392, 0.039373000768283685, 0.14932873869134536, 0.12214125119029515, 0.10333916292555871, 0.21922963461087597, 0.1970743105536507, 0.19715937695676283, 0.1004292085886963, 0.2503362823758395, 0.12156393499143663, 0.11572839812405648, 0.1688611768786946, 0.1185210720605908, 0.18291487598851805, 0.22919283789252082, 0.19845535257650962, 0.14127929965334554, 0.10969959259513887, 0.141877721574518, 7.35497163188073, 48.38058471679688, 63.01259048523442, 56.479388744600364, 24.51128932737535, 33.159737048610566, 53.025541766997314, 49.94993678985104, 50.16678502482753, 6.973275494190955, 0.20320008749202376, 0.7181920459674251, 6.929664131133788, 11.10315424780692, 6.9453300776020175, 6.3534316708964695, 4.969523866330424, 22.50858791412846, 42.18036866957142, 52.10350628822081, 52.79551044587166, 57.769715170706476, 55.82173670491865, 57.49754190444947, 55.70284574262558, 59.3240406436305, 59.207322674412886, 56.200327796320764, 52.32117822093349, 52.475507797733435, 42.809269735890055, 40.343016732123594, 37.939800139396425, 38.75404496346751, 40.072031944028794, 44.18634330072711, 46.93993737620693, 50.631652570539906, 54.00843281899729, 54.0055420321803, 52.212026503778276, 55.47902353348271, 55.27489554497504, 54.01138636373705, 54.647049596232755, 53.37220476519678, 51.47685274001091, 53.42618442350819, 55.69391058337305, 53.994747669466086, 53.882932662963874, 45.44090947797222, 40.84547235119728, 40.104458178243334, 40.56865892102642, 41.056213455815474, 40.49955068096038, 40.45441596738754, 39.79044498935823, 40.218324584345666, 41.96546985257057, 41.75879232345089, 43.78490440307125, 48.50699094034011, 49.197700715834095, 54.05633672591179, 54.23435741855253, 55.21310252528037, 55.84587889332926, 53.23039931635703, 55.10207983755297, 47.63179248379123, 49.26105876122752, 49.393379918990604, 51.356345761206846, 53.684292070327274, 53.90488224644815, 53.57524625716671, 53.575167809763265, 55.0397769097359, 51.489667123363866, 47.530481584610484, 40.740960797955914, 40.559966948724565, 42.9508476872598, 40.72968398371051, 42.69248508637951, 42.645879483992054, 47.658684253692634, 51.43673081551829, 52.53641436176916, 52.92545072494015, 54.35975559296147, 56.09521219807287, 57.955631594504084, 55.05790218230217, 53.41551165426932, 51.38484570287889, 56.52060108800089, 55.47268106091408, 55.598338111754394, 56.390143056069654, 55.398148182899725, 56.02184034162953, 56.63423607426306, 54.98461269563245, 51.59539853372882, 48.938369289521255, 43.69996155461958, 39.80047841225901, 40.054698990237334, 40.32863732307188, 46.06248747917914, 53.728430501876346, 57.70640419375513, 57.150149345397956, 57.438149375300256, 50.10288176998016, 55.4160185014048, 61.98725938796998, 59.19344532874323, 56.17273392215852, 50.03416968930153, 51.39909175134475, 58.922731184190326, 65.20746254151868, 58.108631487815614, 27.44019569889192, 15.34469944815482, 12.82667802226159, 11.482337617105054, 6.7041950168148166, 2.252939069463361, 0.1425808370714226, 5.257679320150807, 46.557765160837484, 61.21605080942954, 55.23999821755194, 46.78996555266842, 55.13539644979662, 67.00459449521958, 68.99154170866936, 26.902234785018432, 0.8462073605868125, 0.20874860185769298, 0.20732507259855348, 0.10273230637633994, 0.10069646602196079, 0.09850222166747817, 0.15436703849944378, 0.1267435243954101, 0.22743127999767182, 0.08993111505743959, 0.0989496936240504, 0.14789477531467715, 0.101598312387303, 0.2316692783947914, 0.17179831201511045], [0.037800616795016874, 0.003373485650949841, 0.03254187135626713, 0.013461202878745334, 0.033725710856097366, 0.026461582803618044, 0.025109041166762193, 0.04738915711641312, 0.03196925127638444, 0.07435369004885997, 0.033654621727163755, 0.048171712100626006, 0.0344668434662444, 0.019164934318753022, 0.043931741027101394, 0.004443017411000666, 0.056281572493213805, 0.04301370722391913, 1.4906195623259393, 28.35886774524566, 48.60030020436933, 38.096581197554066, 22.778496011610954, 35.81583276871712, 42.52967926763719, 43.67396408511747, 45.426941917788604, 9.542884422886758, 0.10181766634266223, 0.14816128198177586, 1.6316298731873113, 4.113433726372258, 3.9290041260180937, 1.0542037866769298, 1.688422116060411, 9.29729796225025, 28.440568754749915, 47.95690205789382, 52.22663733267015, 53.87026732967746, 53.743319819050456, 50.36408808923537, 49.165753010780584, 48.769283756133056, 49.157688617706306, 48.32087055329354, 46.172478583551225, 39.5981704035113, 36.84099520406416, 36.44533395767212, 35.37939063964352, 39.02065238645, 42.18700924227315, 44.97158219737392, 47.14043324993503, 47.9008827670928, 49.64654930176274, 48.86925320471487, 46.2082152981912, 47.02586473957185, 50.24727206076346, 52.8955622642271, 51.74279336006411, 50.53316577788323, 48.62901979877103, 49.04516758457307, 51.59042496835032, 51.797647706923954, 49.323389145635794, 46.82696919287405, 39.62091622814056, 37.87496336044804, 37.74769813783708, 35.764928248620805, 36.46920158017066, 37.562432827488074, 37.46762129568285, 37.1041666307757, 36.28454423719837, 37.23489530624882, 38.40676615315099, 41.28793139611521, 42.33410596847534, 44.420273457804036, 47.75874783915859, 46.147034168243415, 48.958730313085745, 48.275806442383804, 50.10829071844778, 41.21450462648946, 41.83352524234403, 46.324003665677964, 45.38492941087293, 49.13948097536641, 49.99842512992121, 50.43592629894134, 51.53305245983986, 49.04555197684996, 47.787993031163374, 40.82704505612774, 37.44365953630017, 38.39964705128824, 38.34142338845038, 38.26645904971708, 38.2198691368103, 38.68689398611746, 42.646765939651, 48.158833519104995, 53.228410674679665, 52.02959706706386, 51.89072555111301, 52.33640486194242, 52.205130977015344, 51.20948829958516, 52.21727855743901, 52.099995766916585, 50.20579691856138, 50.988623557552216, 52.961324722536155, 50.47230628228957, 49.79201039960308, 50.86647702801613, 52.21277959885136, 54.44687143448861, 53.17132842156195, 50.4540398043971, 47.81708132836127, 42.18647579992972, 37.04429557246547, 35.16695114874071, 37.93121014871905, 42.87692277662216, 48.75382177291378, 51.28670407879738, 55.81846937056511, 55.84876183540591, 55.4445812009996, 53.366011342694684, 51.91749964990924, 53.51000547409058, 50.68188636533676, 49.259772223811, 54.584201458961736, 57.93527057093959, 51.89057650104646, 16.11850953871204, 3.040153124640065, 6.093371174027843, 5.552632731776084, 7.624920914250036, 0.05504512956606285, 0.0773786188613984, 5.66503462291533, 38.343835646106356, 45.34911032645933, 41.29151644245271, 28.305221488398892, 37.852480334620324, 57.571592330932624, 41.66107039297781, 11.091983337556163, 0.12031368715989015, 0.07428130240089471, 0.07771115464669082, 0.03872348461300135, 0.05373195910285558, 0.10955180657366592, 0.011008278402920452, 0.05196891499743347, 0.017601435050188054, 0.054235953026481216, 0.04459244589651785, 0.012014946663722157, 0.028827377226984793, 0.03051964055386282, 0.019175088814189358, 0.00982296514144588, 0.04987882795713602, 0.04327760153119603, 0.08388622934299131, 0.032102606116583755, 0.036402138611001354, 0.030352024346469875, 0.06271023378377, 0.0843617937437469, 0.10153493393332728, 0.02371626650734294, 0.00821167060489496, 0.043061078270717014, 0.04279086373806481, 0.04569573125111, 0.03484526791820123, 0.09531219324637806, 0.006924760199317168, 2.083249000772353, 33.802123223581624, 55.33798686919674, 44.960270081796956, 21.198382915989047, 33.16746411785003, 45.09081440587198, 47.74458808283652, 47.56060930990404, 9.819299732485126, 0.0959420937203592, 0.0970962894479594, 1.1247251831716107, 7.85898345132028, 6.280332909476373, 5.3728734485564695, 4.890109598636627, 13.163757689537542, 31.250974439805557, 47.87972550238333, 54.63397633644843, 56.37721100161153, 55.116714200665875, 53.05422606006746, 53.02804423916725, 51.64876630229335, 50.4452693846918, 50.22653056729225, 49.07526000853508, 42.092703696220156, 38.72552933231477, 37.930743386668546, 36.590281225019886, 39.575640309241514, 43.19744709999331, 46.60855985456898, 49.63098533691899, 50.117288635623076, 51.34569260381883, 50.00740343524564, 49.26773071289063, 49.189871664970156, 52.27227018725488, 52.54070935710784, 52.56768741915303, 52.32757952905471, 51.531495278881444, 51.765041043681485, 52.531381960838075, 52.381127726647165, 51.78129534567557, 49.759929333963704, 40.42472754755328, 39.06256683411137, 37.93523057814568, 36.84167377410397, 38.15879783322735, 38.725666615270804, 39.573039777817264, 39.93130514698644, 38.56217045937815, 38.4074447231908, 40.464547449542636, 44.10376171911917, 43.78871694687874, 46.70817236746512, 49.29384193112774, 48.07372985347625, 51.779157653931655, 50.084074005003906, 52.31789911946943, 43.23403889133085, 44.71674188490837, 48.37071603344333, 47.836399001459924, 49.93538087414157, 52.527585106511275, 52.814902644003595, 52.45740213701802, 52.18808827861663, 49.27886239943966, 42.035209594234345, 38.00670400742562, 39.78421626552459, 39.55530281989805, 39.35952163511707, 40.731135260674264, 39.179108296671224, 44.71973857572002, 50.32070667512956, 54.98123945728425, 54.159287175824566, 54.3195552210654, 54.436618358858176, 54.79574664946526, 52.52829113314229, 52.40903146805302, 52.354079061938876, 51.14594198042347, 52.47553133195447, 53.54514598846436, 51.85756975604642, 52.10826412323983, 52.7643354477421, 54.11795716131888, 56.68128882685016, 54.21446315703854, 50.97627593624977, 48.61513853073121, 42.55431567468951, 38.527630067640736, 37.71904914609848, 39.64653715010613, 44.88843187209099, 50.85097582109513, 53.427176783161784, 56.79017382283365, 58.82126339020268, 55.35495112019201, 55.8584971581736, 53.589731570213075, 55.58686517900037, 53.96841287612916, 50.21311213893276, 59.0169543604697, 59.73587774461316, 53.16935546936528, 16.495253193762995, 4.709118200886635, 6.021284384112205, 7.320279248299138, 5.417643871999556, 0.14101787981006408, 0.04738945589070359, 6.724106438698308, 41.36942255881525, 52.27435296581638, 44.05820731193789, 30.21250536364894, 47.38862122258833, 63.43313524799963, 51.15195105152746, 15.917872459657731, 0.189259018628828, 0.067135441086946, 0.0395808978787353, 0.012164607685389779, 0.05503587522393754, 0.07255915206887069, 0.018811287065487237, 0.07196734914736402, 0.05457773549301971, 0.0567184609451121, 0.0684601066994571, 0.07379721144154187, 0.030973308246522665, 0.08017077951902345, 0.029764342977995836, 0.1601980094827952, 0.1711488839599394, 0.10981927851154921, 0.20492105804864438, 0.20246824369795863, 0.15458370348618877, 0.22745599399410912, 0.18411450839090734, 0.21851089092031603, 0.25139147656098493, 0.20108687991817153, 0.11365989944146526, 0.09176123016063245, 0.2558680807030009, 0.2098455325129532, 0.09934343983449283, 0.18612179664834855, 0.14013887052574467, 2.385215855413868, 38.243148403783, 63.7010919663214, 50.883311840795706, 32.2515671483932, 48.011038611012125, 52.394675593222345, 55.39908170700074, 54.28855280722342, 13.069986566420525, 0.27456361379834915, 0.45400420444146283, 3.8479743321095747, 9.684420208777151, 12.269865216747409, 5.2849682300321525, 4.178786787294572, 11.995515035044763, 30.686129600771014, 49.854058373358946, 56.5090379407329, 59.45842496810421, 57.82127864899174, 55.232239769351104, 55.911064763222974, 53.85580555085213, 53.29903294963222, 52.31788342998874, 50.83757308221633, 42.99055776288433, 40.70887580994637, 39.559805700855875, 39.094012475782826, 41.998178497437515, 46.08466848250359, 50.528462856046616, 52.04568270714053, 53.115987700800744, 54.35497422372141, 52.87464034172797, 50.60930290529805, 51.365406436304895, 55.40895823509463, 55.84224677854969, 54.009837027518984, 54.41390391319029, 54.03670526319935, 53.0134294879052, 54.62195819424045, 54.99439900921237, 53.838005835010165, 52.05347645667292, 42.945285766355454, 41.071797032510084, 42.276262775544204, 38.55718120451897, 38.4384589041433, 40.1834939372155, 40.644529327269524, 41.18381600226126, 40.569129605447095, 39.151063349939164, 43.00635706993842, 46.992897218273534, 46.66665015682098, 48.11195727317564, 51.015491793232584, 50.68421233084894, 52.3784448254493, 54.51191609905612, 53.38395226386286, 46.353986263275154, 46.76350916585615, 51.03404460414764, 49.58888261548935, 53.002701805483916, 54.40792229867751, 53.73734212690785, 56.263258303365404, 53.954335489580714, 51.846461603718424, 44.463505821843306, 40.65177002260762, 42.15985859594038, 41.92245714126095, 40.45778136099539, 43.199757376024806, 41.93868398666382, 47.21670373793572, 53.134885680290964, 56.6603276806493, 57.39456007557531, 55.3803563117981, 56.64156306174494, 55.11026190173242, 53.28179413272489, 53.20784961023639, 54.30376768112183, 51.852596190667924, 53.505133890336566, 54.672541079982636, 53.34112390395134, 53.46208980006557, 55.1288107902773, 54.52167103367468, 59.7830952367475, 58.29714844303747, 54.51968631436748, 51.35785195135301, 45.576949042658654, 41.896718548190215, 39.766451851014175, 42.84533200725433, 46.32968325768748, 51.019378862073346, 57.19398575444376, 59.215257629271484, 58.44240949999902, 58.55450299478347, 56.73797492058047, 55.64695196767008, 58.61504085602299, 54.600961746708045, 52.92327380949452, 61.70986152464344, 60.624145538576194, 55.73520137417702, 18.351807094389393, 5.73930666331322, 10.18942536846284, 18.14064629616276, 16.408483501403563, 0.2727357280110159, 0.2622570854521567, 7.919716450475878, 47.61382018366168, 57.64939254330051, 56.64950978371405, 39.00780270176549, 51.401347114193825, 72.90163486234604, 57.850135526349476, 18.78800407532723, 0.39581912179147044, 0.14864243116349946, 0.1536093622205719, 0.09451223657496514, 0.09341642440807435, 0.14796303374873054, 0.10539276885890192, 0.18241871148347857, 0.16419735616974293, 0.13233582068595195, 0.17060407287170812, 0.25229077185353926, 0.15936185515696005, 0.17114566639065745, 0.15711574665000363], [0.029531781666822014, 0.01383475022345421, 0.028988839833125956, 0.07386742339980218, 0.07638799822739056, 0.0675769835229843, 0.10918537905860333, 0.053001210814522165, 0.039884724519065315, 0.04364792843379321, 0.038416704703723235, 0.07533579944602906, 0.026369834198586406, 0.03092506768993072, 0.03860931836008545, 0.03840279637745792, 0.053428952176604545, 0.012403582110099736, 0.3905794174680787, 17.012290223952263, 44.94510227634061, 43.64927276488274, 28.59899916956502, 35.689744257157855, 37.98864541515228, 39.226510140203665, 50.37005009189729, 16.636999807050152, 0.23791310948229608, 0.019331012604637973, 0.5408637129491376, 3.6763534767012445, 8.90998940314016, 2.4309999663983626, 3.4710524543639156, 6.323094589094962, 23.034677774675433, 43.548212897393014, 53.75452995300294, 50.484061625696, 49.32195355815273, 48.09232973283338, 47.15019602929392, 46.64302964364329, 44.709485500089585, 42.121533116986676, 37.16931719933787, 36.838398595010084, 36.3976614705978, 39.057785464871316, 41.35173659170828, 44.28797975663216, 46.77249139355075, 47.474681946539114, 49.11633899134975, 49.585352482334265, 46.456693526237245, 46.47461875792473, 43.37886456520327, 44.61448177214592, 45.71191387791788, 47.42443246226157, 47.46371892190749, 46.48082394753733, 46.8856478506519, 48.66452901594101, 51.34681440168812, 50.9899297068196, 50.88858742867747, 47.65726827806043, 43.15554834181263, 38.45584284874701, 36.30300683359946, 36.182786187817975, 36.888275454121256, 36.380018649562714, 37.39309626240885, 37.28332088839623, 35.514798702732215, 35.77028228390601, 36.43728525407853, 37.87296687403033, 40.500794072305005, 41.70801724157026, 46.69697792299333, 44.33395385742188, 47.295111917680316, 47.03144627232706, 51.855302626086825, 40.636143299841116, 41.14445109521189, 46.26867078965711, 47.748381014793154, 47.55999742015716, 50.32943787113313, 48.220253913633286, 51.203255653381355, 49.198002738337365, 46.55331719306208, 40.83792178861557, 37.28893380011282, 37.236927093998084, 37.89684234126922, 38.712577666005785, 36.72157079942765, 36.11461539422312, 41.622701767952215, 49.79621910279798, 50.60930682766823, 53.919944147909845, 54.22729715224236, 55.924934264152284, 53.698859753147254, 50.606208155232096, 51.80121706378076, 51.90593258027108, 52.94165403612199, 51.702177216929776, 52.235862747315444, 52.5492875806747, 53.342096651754076, 52.37502451865904, 53.75769530573199, 54.271780752366595, 54.35303265048612, 54.678173603550086, 49.64958129390594, 49.45089755519744, 45.05043360494798, 40.979464438653764, 38.850888283021995, 39.92216994685512, 46.352723260079664, 48.04374725587907, 51.37201170767508, 51.489325877158876, 54.41293508775773, 52.56592235257549, 55.202163034869784, 54.45562224234305, 54.52737023753505, 51.03467218337521, 54.76988646291918, 59.44128813282136, 44.829925798600726, 8.862009990599848, 2.1872602066686078, 7.953279681744115, 2.9214318048569465, 5.662666491923794, 0.19771238518578393, 0.11238134466111661, 5.050870881926629, 42.805100256396884, 46.7915698020689, 43.33880932100358, 33.666413137989665, 41.38332343870594, 53.128147048334924, 35.25162727602067, 7.39792795911912, 0.05102359314238833, 0.0631053168176403, 0.02101491025138286, 0.0679525045017081, 0.028919817226368095, 0.011427289235495753, 0.06855160058025392, 0.14704737481811356, 0.0950630537925228, 0.02598349605837176, 0.04025548043090009, 0.05886176811350931, 0.04413146397940094, 0.060514338509810556, 0.04153947443551114, 0.019134493815081737, 0.04677105056602628, 0.015492970518197025, 0.04923941650157494, 0.08924772632458518, 0.07833743152479011, 0.034030594697762886, 0.03904959292060906, 0.040281784059780265, 0.037983229173527616, 0.06321968608385613, 0.020909793412072525, 0.004605124009803179, 0.038413494795320496, 0.03429746908706523, 0.05300925856816673, 0.10981659720381422, 0.05295638701007251, 0.6200817395602504, 21.370957397645522, 50.35967542279152, 48.66589400076097, 36.00283176668229, 41.83131302556684, 47.329970021401685, 47.95162254764188, 53.79687193901309, 17.95016815585475, 0.23834110748383308, 0.019117572848054192, 0.4036488774563036, 5.560136716211996, 9.184549431647024, 7.703878716115029, 4.619005668547846, 7.673057711893513, 28.07252883911133, 43.98693784590691, 56.17317322761782, 52.60326723898611, 51.746374484031435, 50.42459849388369, 50.497550656718595, 47.785996544745664, 46.41432800600606, 43.51016982909172, 40.92761070497575, 38.066100458945, 39.01121124144524, 39.34074917147237, 42.02319537439654, 45.3774808299157, 48.86174186583489, 48.992564678192146, 50.873917764233006, 51.34790089822585, 50.8961772149609, 49.25557528772662, 46.97951016887542, 46.2877413534349, 48.40644098097279, 48.66126168158747, 50.18538490418465, 48.16317950525592, 48.89603907062162, 50.764381654800914, 53.969009076395345, 51.9042145821356, 51.83817363554432, 48.86257340831142, 45.31060049610753, 40.890163836940644, 38.509999013716175, 36.59488608760219, 37.65211782147808, 37.85353937456685, 39.65783357620239, 37.46999825200727, 38.51583550053258, 38.06084840528427, 38.59743256722727, 39.291892128606, 42.24382869658932, 43.36924691354075, 48.31232763105824, 47.08688505234257, 50.18536529233379, 50.106349145212484, 53.617094024535156, 43.54090552176199, 44.72394727891491, 49.763635973776545, 49.558272438664595, 51.34772439156809, 53.92182688559256, 52.3060731733999, 53.55463420191119, 50.424363151673354, 48.81115505772252, 41.537429440406065, 38.74614138757029, 37.5475945011262, 39.37463060502083, 39.698457564077074, 38.925464307108236, 37.33538250769339, 44.25342759778423, 51.34866968277962, 53.090507984161384, 56.22648608299994, 54.73046272031723, 55.43751701231926, 55.42132939061811, 52.965796224532596, 53.37715479635423, 54.26430471481816, 53.52654218673707, 52.374726418525945, 52.94497236128777, 53.63370133984474, 54.45675188495267, 54.70323362658101, 53.70940700654061, 54.271517953565045, 54.799033595669655, 56.77362926544682, 52.939347682460664, 51.490094661712654, 47.03390952079527, 41.11910473915839, 39.30847198732438, 42.49643718042682, 48.68642760861305, 51.19948625564576, 53.47692028168709, 54.523518470025834, 55.035379932772734, 54.5972982529671, 57.33350446147304, 57.03199971106745, 57.29588500915035, 54.97394777113392, 56.58431214670981, 61.85840952780939, 47.28499612500591, 11.577864000874182, 3.271194456085082, 6.868842878649312, 5.373506421043027, 5.147454344457196, 0.06833306633897367, 0.08951954964187839, 6.808629103245274, 46.49186149720223, 53.149233710381296, 45.6495560369184, 34.01575903738699, 43.939379107567575, 60.1993489265442, 43.55207250964257, 9.701330527182549, 0.11250541260045384, 0.042477840212203806, 0.038550992255970355, 0.03275860912136493, 0.027272257045091643, 0.04604889395376367, 0.015614964274479257, 0.05620947595865977, 0.03930016878932234, 0.028696854996885506, 0.03837470393327456, 0.03079608912699886, 0.094716276432718, 0.017352912297111847, 0.024144433048223297, 0.13299543771051592, 0.0884423534115476, 0.0994853423007073, 0.15302223243540333, 0.21461309684861093, 0.1587178663260514, 0.1554520335048437, 0.17143875630872865, 0.175490151009252, 0.14295067367774827, 0.22920815965100644, 0.10914057057591216, 0.05946093313996831, 0.18542056572773766, 0.14204428441101505, 0.21772540564979279, 0.2772691605552551, 0.19920953549444678, 0.9778599380966156, 24.244689749133205, 56.80580054560016, 57.88810014724732, 39.78184323157034, 45.806968596673784, 48.75465723776048, 51.46026895892236, 60.60099570981918, 21.07441052313774, 0.4098421773843227, 0.19400568408591135, 2.7098473906517033, 11.870248260036593, 16.67482714499197, 9.2829450291972, 6.762328955434985, 8.132480517510446, 25.464692000419866, 46.984907350232525, 57.10495579627253, 54.038395804743615, 53.946561351899184, 53.43285245280112, 52.253352595913796, 49.84880239732804, 47.98218173365439, 45.55647427035917, 40.99001169204712, 39.43791020301081, 41.22072158321258, 43.2991776927825, 46.61159576908235, 47.36041153630903, 51.19268878813713, 51.128216789614775, 53.65362305794993, 53.27630281448365, 51.52870255131876, 51.592770545713364, 48.88309917142315, 48.60379895856304, 50.06400715920233, 51.91606798479634, 53.12600935659101, 50.473177048467825, 50.94814469737392, 52.999497229053134, 55.773307200401064, 54.262637707494925, 54.286187618009514, 52.79296090525966, 48.777752153335086, 42.65328491887739, 39.979766030465406, 38.21515052549301, 39.62390115184169, 39.953595976675714, 40.89571791310465, 39.35383419836722, 38.70669018837714, 39.43605884428948, 39.52197051817371, 42.55402149692659, 45.373813413804584, 45.80474853515626, 50.13698677862845, 49.59158905090825, 50.74735856825306, 50.40845794062461, 55.81454700039279, 46.091787584366344, 46.8622548349442, 49.93154871848322, 53.229567773880504, 52.748296876107496, 56.968469081386445, 53.18246403048116, 55.57244654624693, 52.42805888575893, 50.98670944090813, 44.128731527636134, 41.09570780108052, 40.26141182068856, 40.77323405973373, 42.807951819512155, 40.09118487758022, 39.23986188827023, 45.883588175619806, 53.33200439330071, 55.51942002388739, 57.49485115851126, 58.650620675856075, 58.523488813830966, 59.04093573170324, 55.741281047944106, 55.714914875645796, 57.471489521764944, 56.90768018845589, 54.90173301389141, 55.40090168676069, 54.54595050504131, 55.53740016875729, 55.34595320301672, 55.92595408039709, 56.33386096646709, 54.494740040071555, 59.374376420051824, 55.43792493881718, 54.65704379543182, 50.49134938947616, 45.31453855576054, 42.64408696082331, 43.58219631256596, 51.54318394199495, 53.482976421233154, 57.67286400641165, 56.10000141205327, 56.76899694627332, 55.131313262447236, 59.58721207034204, 58.80378138634467, 58.47221951330862, 56.21908457048478, 59.89825994737687, 63.320508310871745, 50.7071856529482, 11.626560226563486, 7.505900513741278, 20.23474677916496, 10.108243092413872, 14.14846872129748, 0.7045316563979273, 0.27961437019609636, 7.178919478770226, 54.7649521212424, 60.443759656721554, 56.63416154922978, 45.4047687592045, 55.52637438620291, 67.86116169344994, 50.89934256768996, 11.248153486559469, 0.22554595293777607, 0.10854840759308108, 0.16461741750038442, 0.19868344759508488, 0.11569567850881046, 0.10743005711945797, 0.19230993314375802, 0.22282341435070963, 0.11753134008857513, 0.10717095852258707, 0.14335838567105033, 0.13514529493066574, 0.2837639007597201, 0.17560860352410426, 0.1318264335033394], [0.018337697256356478, 0.03994091706831129, 0.04563730938600437, 0.08171919643157914, 0.08387979420442736, 0.05741388874969656, 0.010794437407786328, 0.0777938002119622, 0.05531942734735147, 0.014829003071833043, 0.03981467343926911, 0.05645041827172522, 0.0589220094374351, 0.015388495277523275, 0.09046205229336217, 0.014995297777556605, 0.03713822270172738, 0.04091236252157439, 0.08035899200026067, 10.246985170149035, 42.314611788718935, 44.08336147185295, 28.620805586538008, 25.77901701773367, 31.461372337033673, 39.26357653833205, 44.24875997727917, 27.546821409656157, 1.5685271495772948, 0.12999154567237825, 0.1937804235926559, 3.036327833129514, 2.815943581442679, 9.841408171961385, 5.174292672064997, 7.164770508966139, 23.009913890592514, 43.621576909096014, 54.515371707177934, 49.3927994082051, 50.07480936665689, 45.90842070118074, 43.562757045991965, 39.49117991232103, 38.743689906212595, 37.64195103799143, 38.32370212001186, 38.21141642908896, 40.56787444699196, 42.036437296098285, 45.10837485713344, 46.66209628505092, 48.09773475893083, 49.036318717464326, 48.076985420719275, 47.00736291946904, 45.26553246282762, 41.86973656377485, 38.972850461159986, 38.85456746624362, 42.850756645202644, 43.303735486922726, 43.752340885900686, 41.385978883312596, 42.43189850161153, 46.636243943245184, 48.51451796870078, 51.56357634452082, 51.2167093830724, 49.90524922647784, 44.98272957340364, 39.44099318596625, 35.72011909177227, 36.8206145686488, 37.22297130092498, 37.54992046663838, 37.509214108990086, 37.53119899380592, 36.17196829088273, 37.02389140282908, 38.701010596367624, 37.55924786290815, 41.442708123114805, 39.20099904460292, 42.51680212636148, 42.970655656629994, 48.09321618849232, 47.25618631609025, 52.23542736422632, 44.15155579966884, 43.095896936232045, 47.680951549160866, 47.72108916313418, 49.904421606371486, 49.221948808239354, 51.19176703114664, 50.587616120615316, 49.49924861231158, 45.73788781319895, 39.62905514624811, 36.1162196436236, 38.640088342851215, 37.897564057380926, 38.60744245590703, 37.271596923951186, 36.914629859309045, 41.617618376208895, 49.86834756789669, 50.375498264066636, 52.25583937860305, 51.97113021727532, 51.26870039970645, 48.478691039546845, 50.5977632922511, 48.583249661230276, 47.82915830612183, 49.90183676442793, 51.13503779134443, 51.31440385695427, 50.34064800508561, 48.796759959190126, 48.89603907062162, 50.83596883281585, 55.17302766922982, 51.52040673840431, 52.40363820906609, 54.39084429894724, 50.23235920936831, 50.3952826992158, 48.6609596590842, 46.51636846603886, 44.80656808422458, 46.10760650327129, 46.96600152600197, 50.62931091554704, 54.52124741769607, 54.24205310883061, 54.91164092094668, 56.5006362238238, 53.84739206683252, 57.44464482030561, 57.696978738231046, 58.80369901657105, 56.2224970325347, 34.63357940796883, 6.631458584339389, 3.0610956395826037, 3.993794817116953, 4.6071542270721935, 2.641532204804882, 0.17266938462853434, 0.12218984414733226, 4.736042820638226, 33.72591941587387, 45.41473550181235, 38.36174518831315, 34.990546472610966, 42.52391730585406, 49.40364083936138, 32.69088829717329, 3.8595379696738337, 0.056517259443118695, 0.0666948102955376, 0.05677344690587732, 0.05964196354691541, 0.046648694833199826, 0.07375944330687485, 0.09192771638833708, 0.024449801440500928, 0.03312083081372323, 0.007787223420886984, 0.0165544705645692, 0.05262048043791325, 0.036078811202558785, 0.007234627921735087, 0.0276755640328291, 0.034512931315769116, 0.010329005477439252, 0.05077229715102623, 0.04427956409692284, 0.05275022891920902, 0.07391069970664478, 0.09645636088304943, 0.05296472970756793, 0.0513116077279612, 0.025445591252777847, 0.019162456024317973, 0.06480299447092318, 0.03495450439532438, 0.039866912974825794, 0.06926717266680733, 0.03402560746537582, 0.041953184897260326, 0.031172621341782714, 0.07634882815182209, 13.313426509980234, 48.89522321762578, 51.71909832185315, 30.773865176785378, 31.251964838274066, 38.33343744277954, 44.44559627963651, 49.83666266164472, 26.48276867405061, 1.4466569019902138, 0.06175065120201438, 0.41849655009085135, 5.579570589527007, 6.474601530259656, 11.696947159305697, 7.313446479458963, 7.14864956755792, 22.265426458850985, 46.460419777900945, 54.41360973542737, 52.27612979950444, 52.06496507890763, 50.004206703555205, 45.3576297144736, 42.9305298097672, 39.74776567951326, 38.68335600822203, 38.542107535946755, 40.490992069244385, 41.01659359470491, 44.04802876134073, 46.86893070897749, 50.21938793120846, 49.453031324571185, 50.050969200749556, 51.116037830229736, 48.65873175282633, 46.70625040608068, 44.40594896193474, 41.877020405184844, 41.09075776992306, 44.13289316238896, 46.828553830423665, 45.851448274427845, 43.086961776979514, 44.46312535193659, 48.47527073275659, 51.20178084219656, 52.557285293456054, 53.70473154129521, 51.25117132740637, 46.89306505264775, 41.192578577226215, 37.04691963811075, 37.62894445850004, 38.239582969296364, 38.17692310579362, 38.94189119338989, 38.32705182413901, 38.49886732716715, 38.53146614566926, 40.649196947774584, 40.26339261762558, 42.22509153427617, 40.70604385868196, 43.944089874144524, 45.2630849038401, 50.36733973410822, 48.61819013472527, 53.80877633248606, 46.58552769691714, 47.03012443357899, 48.12017071631647, 48.8707790067119, 50.64370993644961, 49.45963659594136, 53.84600354779152, 52.26046777540638, 51.865802811038115, 45.82904761837375, 41.60257216422789, 37.857614717175885, 39.71659852612404, 38.78773420087753, 40.42274675061626, 39.426813817793324, 38.11664804335564, 44.39124007378855, 51.26965745802849, 51.2702654254052, 53.46198781844109, 53.433734986089895, 52.06969153496527, 51.05741800800447, 51.12844428708477, 48.84049046424128, 51.11213114953811, 50.510188533413796, 51.92284584045411, 52.714776300614886, 52.86670538686937, 50.909019054905066, 51.51548416383805, 53.07455962704074, 55.23891172101421, 52.77050533602315, 55.998725814204064, 54.93188035103583, 51.83557310412007, 51.47455423108993, 50.762867619914395, 46.67782106707173, 45.921776371617476, 48.68812599489766, 49.81157910439276, 53.82624656923356, 56.215919217755726, 56.61565972912697, 54.80234015372492, 57.776493026364236, 55.85368048760199, 59.746538746741514, 57.69511169002902, 61.4794889573128, 59.04860396539012, 37.898885896128995, 7.347214164272432, 2.855383013525317, 5.0335511661344965, 5.926600819633854, 3.1262442469596867, 0.08311696981470432, 0.18400624484544803, 5.043435048672461, 39.08597946166992, 49.965896914082194, 44.271874504704634, 40.02645008025631, 47.769538279502626, 55.995654598359145, 40.243604260106245, 5.57113504217517, 0.06002610684522699, 0.08115245990695492, 0.046189363835559744, 0.05580694271972584, 0.043388163340428186, 0.026573044766161232, 0.036222766784410325, 0.027485505279694355, 0.04336931374705127, 0.03326947485367137, 0.056163054860888, 0.1203230410934456, 0.030830630116284858, 0.03139521010340222, 0.04956530264368461, 0.10204965308789285, 0.09009924837418141, 0.17411185158116205, 0.13546737361579173, 0.2853933697746646, 0.1667214013756283, 0.14944755892840125, 0.12836747757729985, 0.10965207982207499, 0.12836536317462885, 0.0814324956867964, 0.1847265513553735, 0.33384107654133155, 0.09745944576758532, 0.18782658742800837, 0.15773741167879876, 0.22363116213631248, 0.1478838968661524, 0.2647052879535383, 15.45824912286574, 54.3364018009555, 56.974156518136304, 40.29274763599519, 38.579099409041866, 41.691288332785334, 50.811108850663715, 55.55538815836753, 33.50111661418792, 2.4104693003239173, 0.27619813899359397, 1.1213617507488498, 9.061477222750264, 8.087322269716571, 17.38192654425098, 11.339024016934058, 10.585534745647061, 25.761484023063417, 47.00961828231812, 59.490415819229625, 55.33877134323121, 54.65049735961422, 51.506086164905184, 47.10478674980902, 45.41070722764539, 42.57050721876083, 39.637629447444795, 42.07178177372102, 42.73133224056613, 44.09814880740258, 48.41789430187595, 49.65817128458331, 51.82419823062036, 52.20636652361963, 51.346076996095725, 53.03241375953921, 51.14728735339258, 48.952952661821925, 46.47350088242562, 43.300256344579886, 42.46931399068525, 47.34212152419552, 49.01472606966573, 46.48431485699069, 44.59960422208233, 46.751447877576275, 49.38975564895138, 54.187171305379565, 54.32370508870771, 55.55550190710253, 55.28895331967262, 48.93292503972208, 43.01096585489089, 37.76495656659527, 39.3003644481782, 39.47395286252422, 40.916173073553274, 39.77339444621917, 40.28105897288169, 39.62152419551727, 40.679077563747285, 41.79043408363096, 42.95074962800549, 45.951198070280014, 43.3803472211284, 46.31380942560012, 47.628929153565444, 52.23518025490546, 50.39614954302388, 55.798410369503884, 49.0194486033532, 47.70610178670576, 48.81313193228937, 51.13756772010557, 52.683542466932735, 52.66793927838726, 55.62317848205567, 55.075796035028276, 52.53244492315477, 49.9805038206039, 44.09297912351547, 39.814516575105735, 42.283750580203154, 41.69953315488754, 43.02603560109293, 42.43792326219621, 41.25192403793335, 46.13306660805979, 53.83105931743499, 53.65883981027911, 55.53775710444297, 54.845650965167636, 54.31850010348905, 53.00671046780002, 54.374358577113, 52.12931156158448, 53.2148471186238, 53.248253945381414, 55.44766026158487, 56.15575790405274, 54.02973128903297, 52.91172242933705, 53.7980604171753, 55.21808785776938, 59.2345243115579, 54.089367005132864, 56.566069203038374, 57.32717767838509, 54.54907663406865, 54.19283128553822, 53.962231220737586, 51.32879895548667, 49.889304791727376, 51.465528857323434, 51.152586475495376, 56.44514253062587, 60.28299347046883, 59.175982936736084, 56.22575652214789, 58.38407993316651, 56.30258006434287, 62.57317912194037, 60.39755413609167, 62.72244099647769, 60.99719039855465, 38.72967919995708, 8.78011090140189, 5.715724883540984, 9.824136995500135, 10.915964034295852, 5.977534267210192, 0.6586409059743727, 0.5064405326641376, 6.529350463421115, 44.28546551735171, 59.20669117281514, 53.31473811980217, 48.27194683013424, 55.263779547906694, 64.45656007336032, 48.55424765617617, 6.41671960392306, 0.11655456266335903, 0.1077517834041388, 0.11654976695295304, 0.16693239731173362, 0.11877341376196955, 0.16774137083801532, 0.23718339541266042, 0.13742198566755942, 0.12934758748498656, 0.07801437990800028, 0.11285543817305758, 0.3749886089034619, 0.1354582418477343, 0.17595577924962968, 0.07553531938502867], [0.0603687703128784, 0.03062294559523223, 0.07598721932980322, 0.028361342960007252, 0.032926953112285946, 0.06200615684652041, 0.032936303215401794, 0.014071228159140917, 0.07639764327435725, 0.06275470518777448, 0.028880786961845817, 0.08974117121749348, 0.07515871822233162, 0.11883529834449293, 0.13537731231941333, 0.09300940955478339, 0.00816145258384847, 0.03136426781214053, 0.10295925992390803, 5.937094630733614, 32.125374694024366, 49.499389817637784, 39.958408724877145, 22.674147236731745, 31.305828786665398, 44.247128271287494, 46.36895010548253, 36.64302141435685, 3.8984608746344045, 0.04398815191140579, 0.1667028926913777, 2.5031279412008103, 6.333453568720049, 12.424045743480807, 4.669561587995099, 5.402185811150459, 20.39022953279557, 42.6154536585654, 52.90788635130852, 49.44771259061752, 48.389049191628736, 45.446071317118985, 42.594602338729366, 41.483014399005526, 39.07438885781073, 40.86637466184555, 42.9032850265503, 42.852608003923976, 44.28856811215801, 46.39324526632986, 46.90363976263231, 48.67557833271642, 47.11210197018039, 45.02144728937457, 43.74846950654061, 42.84554381524363, 38.53230553288614, 37.21080018628029, 35.493849323641875, 36.5585570950662, 39.500495541480284, 38.36666384050923, 38.666925199570194, 36.226481391537575, 37.41254337372319, 43.350905910615005, 47.912253718222345, 50.06992601579236, 49.20895399585847, 49.56392849645307, 45.73294954915201, 41.183219801995065, 35.648261270215436, 38.297167285796135, 37.08025978457543, 36.44052120947069, 35.96604385683614, 37.53857304972988, 37.11889513077275, 36.99342243133053, 36.90684787688717, 36.140153946415076, 37.588908826151204, 38.10024469129501, 40.224996536008774, 42.94753720683437, 46.88021144559307, 48.06857585906983, 49.21062492555188, 44.66531176720896, 44.0869543629308, 47.49388587090277, 44.99946632692891, 48.53649893114644, 49.181669988939845, 50.34867317445817, 52.18804905491491, 50.559731991060325, 44.35490715888239, 40.70916214296895, 36.39832042878674, 37.20746224926364, 37.298076844984486, 37.58991687528549, 35.87859461384435, 37.90658158640708, 42.332533098036244, 51.181325681747936, 52.00530190621653, 53.99381806773525, 51.96745495642386, 49.83130078161917, 48.13155343455654, 46.03858455534905, 43.67936126647457, 44.41519791080106, 45.651983984055065, 47.93779619278447, 48.95121505183559, 48.67379757665819, 47.105190753936775, 48.745471046816924, 47.468974897938395, 48.631122189183394, 50.751402531900716, 51.09941482543946, 50.79509381325015, 54.680813358676055, 50.89635372161866, 49.58662333027009, 50.68965265827794, 51.157316853923184, 49.09790385153986, 50.7803653132531, 50.47857030745476, 52.607491631661695, 53.32579135894776, 54.66183300941221, 56.92274208991759, 56.89636022813859, 56.301623006020826, 57.32295720807968, 58.5060146547133, 46.4776546724381, 23.796039242898267, 2.9972914245820816, 0.22295571773523287, 2.0402518563693572, 3.5322480480517116, 2.0325550629246623, 0.05054742736261218, 0.016713475943693233, 9.083576836893636, 40.56198696936331, 45.88321162808327, 34.27625148527084, 35.56953145611671, 50.174284596597, 46.90414182601437, 25.23042255832303, 2.3872900537906157, 0.007393009896810738, 0.058019611488787405, 0.03713221274196141, 0.03690321373963549, 0.014169344870043139, 0.007386636524085677, 0.02192435620893394, 0.09807378699582431, 0.036388077067151185, 0.057589215632047386, 0.06101761997166661, 0.010224744741384302, 0.10300484981628195, 0.019614541745414178, 0.014434694744376166, 0.03690674540496642, 0.028952454487162254, 0.057478071595992775, 0.04757157414250317, 0.036647876634472804, 0.03371217408247533, 0.019064569139793035, 0.06897021400471849, 0.047025284504578005, 0.0478540537428231, 0.009548552446968613, 0.08227490895097295, 0.10455505937458047, 0.02533644670620561, 0.06345054284939844, 0.026647127383658965, 0.03323951698539238, 0.019541993218984817, 0.11752272159942698, 8.170757947429534, 40.67812442779541, 55.84434524659188, 43.329799636717766, 26.89418019786958, 34.54759713142149, 50.22450270191316, 51.342370356282885, 38.27830460763747, 4.183109729520736, 0.07438470128803484, 0.2659115699991103, 2.6663840970685406, 6.43437272117984, 7.64787462449843, 7.4569110908815945, 5.713669561570691, 20.495331402747862, 43.469408558261016, 55.12595530479185, 51.94648204311248, 50.95719752773162, 46.39093106792819, 44.46603182823428, 42.76113048676522, 40.76947642910866, 42.52223068667997, 43.86142200039279, 44.50043493701566, 45.69491432559106, 49.04142172105851, 48.42888478309878, 50.13963830086493, 49.79159462836481, 47.598338588591545, 45.712243357012355, 44.77092158409857, 41.60849886555826, 38.22902002642232, 37.76851415634155, 38.57381205404959, 41.407893165465325, 40.745040062935125, 41.6428941295993, 39.15425615925943, 37.89679135045698, 45.93783455510294, 50.22496161922332, 53.109562858458496, 52.4322989679152, 51.8254102430036, 47.54357837861585, 42.351823314543694, 38.393579144631666, 38.11520068876205, 38.68896891993862, 37.369016831920995, 37.76781989682106, 39.084155559539795, 38.65156127560524, 37.04351894317135, 38.4384314475521, 38.1705217976724, 39.25918348373906, 39.39813344709335, 43.12189440573416, 44.90754165957051, 48.21147957155782, 48.79443399367794, 53.12513859041276, 47.89544636203397, 48.24643965690367, 50.148471478492986, 47.661720168206, 49.6634154935037, 50.842362296196725, 50.74210651459233, 53.133689357388405, 51.93387946774883, 45.87536296536846, 41.02687804929672, 38.53948739267165, 39.08519498763546, 38.119758482902284, 39.05757365688201, 38.69987310901765, 38.721528514739006, 43.46877705666327, 51.99036159823018, 52.899174767155806, 55.066009721448346, 54.20159778287334, 52.61484999810496, 50.64986413524997, 48.799689969708844, 46.319900866477724, 47.040318673656834, 47.7062939828442, 51.27693737706831, 51.13681854740266, 49.52973719566099, 50.36209944755801, 52.5138803451292, 50.85775367675289, 51.301762057888894, 52.93796700816001, 51.462587079694195, 53.87185196722708, 56.52047557215537, 53.29888389956567, 52.06003073723086, 52.13388112283523, 52.14921366783881, 50.76283624095302, 52.404767851675714, 53.346324966799834, 54.258589821477095, 56.09924439461001, 57.01010896313576, 57.74254099015267, 57.544673104440015, 56.51709841143701, 59.34892023763349, 61.52051302694506, 48.30836603718419, 28.35606913412771, 3.9626516882450353, 5.1238166709100055, 8.748010223911656, 4.244043259851394, 2.424433183285498, 0.2661965240634257, 0.05323244296314736, 7.825427574496116, 45.51000595092774, 50.681784383712284, 43.396224975585945, 41.527729418969926, 55.63143507126839, 55.78372893794891, 31.754955860876272, 3.182036775735117, 0.09888577890852768, 0.06718151361471222, 0.03882689499146035, 0.050521468473297935, 0.01733866306172023, 0.02557645822244306, 0.025388787748412262, 0.06614977704180826, 0.024632588104014436, 0.05882358246092355, 0.020324283902863824, 0.07555340672092092, 0.13152870109244702, 0.012385090662827416, 0.09325568383980183, 0.12483974227741843, 0.1145596390650157, 0.15637834105760823, 0.13511144916617102, 0.16088583386473118, 0.13534138279576458, 0.19446826329635036, 0.1876862094767632, 0.19021475927964335, 0.1417960412800312, 0.07458168547600508, 0.18073414542501975, 0.1812318267841493, 0.1496406590505954, 0.19443837054554494, 0.17447488532672006, 0.10503545779013827, 0.16360771361618273, 0.19196995864472083, 9.07339338333376, 44.77067839714789, 63.11271290625296, 52.54718911263251, 35.43151109449325, 45.060019877649125, 56.75874387064288, 56.19162797927857, 45.27968437440934, 5.751383150777509, 0.18520494262056966, 0.9067198489942859, 7.33347753363271, 13.937828617711222, 23.852431158865652, 8.06319135812021, 8.504515367169535, 23.760935991041123, 46.09166991326117, 57.00288787964852, 54.698483636302335, 53.65538027978713, 47.936588102771395, 46.18179421271048, 45.810620323304214, 42.93489148539882, 45.43625362457768, 47.65544829830047, 47.317418436850275, 47.889147035537235, 52.18843736956197, 51.443206648672785, 52.71074802644792, 51.03006732079291, 49.565065983803045, 46.80665523775163, 46.35993257645638, 43.18493081677345, 39.8450679163779, 38.550591622629476, 39.740568130247055, 42.94348539844636, 42.481198772307366, 42.43452648962698, 39.89698833034885, 40.22726366596837, 47.1795706595144, 53.27906808545513, 55.04109874848397, 54.553877615159564, 54.09850220526419, 49.196359265235166, 44.68708484403549, 38.702540320734826, 39.384644416070756, 40.686455542041415, 39.35229270688949, 39.299976133531146, 40.72308655708067, 41.73137103357623, 40.443617682303156, 39.53144696451003, 40.63082848825763, 40.57096527468774, 40.55824895058909, 44.35936689376832, 47.67661733012046, 51.40039790061213, 50.54270105977213, 54.54127111742574, 52.06716160620413, 49.1811796926683, 50.14543164160944, 49.447132079832016, 53.39772762790803, 53.990648792636016, 52.209159251182314, 55.712851708935155, 54.03364581446494, 46.82870288049021, 43.92526249731741, 40.65218579384589, 40.68713018971105, 39.84677414740286, 40.77639156772245, 38.420035531443936, 42.80715557836717, 46.672518022598766, 54.613544710220836, 56.408805693349535, 56.08724194188272, 56.48435838760869, 52.56004271968719, 54.00041157199491, 49.587262676608184, 47.22846300371232, 47.8041414291628, 50.22583630777175, 53.65356030002717, 54.36735714635542, 52.459033843009706, 52.15755262682515, 53.96828343791347, 52.58500076109364, 52.135756015777595, 54.707681594356416, 53.73693420040993, 54.272831947572776, 58.96125278165264, 56.86628349365727, 54.83626473334528, 55.49369712029734, 56.210518114028446, 52.419814063656716, 56.84453395105178, 55.0906422061305, 55.85347260198286, 57.21617460250855, 58.812289007248424, 60.49233428893551, 59.943143629258685, 58.74465557836718, 58.539680357902284, 61.671116352081306, 49.9219742128926, 28.883980935619725, 5.598055249260319, 5.530737080881673, 13.202355773218217, 12.539033947452424, 4.850718215588601, 0.7193275721323106, 0.21691882231783485, 11.413254872445139, 52.109464368512555, 59.78712351091447, 47.173008534216116, 47.46026331378568, 63.90563572606733, 63.193196019818714, 37.56151107049758, 4.091181384940302, 0.12417563597761816, 0.20335584848878846, 0.16487926635290348, 0.15654663525281415, 0.1059887086551997, 0.08372060879464112, 0.15890785613127295, 0.11481897514914313, 0.1435058882399913, 0.1267930826232318, 0.15948350991933577, 0.11067441649614804, 0.3069913189017004, 0.11021978927836304, 0.17766533509617854], [0.045955212891943036, 0.03231857970897709, 0.12000332195912639, 0.10426071307231342, 0.056336968311018525, 0.04376509775137229, 0.08365431920655313, 0.08298599942316932, 0.012479573244138831, 0.014523071604931067, 0.04157326657385115, 0.036541352108601606, 0.012762833296531632, 0.03814387781124923, 0.07404985957809034, 0.0328521522873592, 0.017713507967850855, 0.05002954426491934, 0.03707798137780159, 2.231556513617116, 24.33591623460093, 49.23329230277769, 41.55214617329259, 34.21315623867896, 35.3347344552317, 35.94650260863766, 46.575749228077555, 46.37526119908979, 9.569933087595048, 0.06151310265845349, 0.15901441896154037, 2.1979013517979653, 8.696581086804791, 5.939338226472178, 6.916196182850869, 4.2294853829568435, 13.786032892042591, 44.48060343342443, 52.89525239698349, 51.70568381586383, 50.22129420311221, 46.47672899307744, 42.70197722219652, 41.79498795540103, 41.76863747258341, 43.6555407124181, 44.893844742928785, 48.41949462890626, 46.886942232808764, 49.31119841914023, 46.54339751889629, 44.72932092605099, 44.186209940141254, 41.07431519416071, 38.737625921926195, 39.36066304483722, 37.21400476271106, 36.55718818787606, 37.25086327522032, 36.602868110902854, 38.05691819037161, 38.21330701151202, 36.837488605130105, 37.39541046081051, 36.81057722337785, 38.119883998747795, 42.07618267305436, 45.95445363752304, 47.42080034748201, 47.21524069386144, 45.24517536163331, 40.18649455039732, 37.25346380664457, 36.53744689879879, 36.805344781567975, 36.80588214628158, 37.34170536841116, 36.11019488303892, 37.12217030986663, 40.79825093669277, 42.35514163970947, 42.39062732265842, 39.96669669305125, 39.08395551866101, 39.37456784709808, 41.85217219014322, 45.713439679914906, 47.14922328149119, 49.54387734013219, 43.15929812769736, 41.59409984465569, 48.42888478309878, 44.370679009345274, 46.38497691000662, 50.42641847364364, 52.02676119342927, 50.701557051750925, 49.776454279499674, 47.79491601451751, 39.44057741472798, 37.94240067082067, 37.01992980895504, 37.1310858572683, 37.87924658867621, 38.11491827810965, 37.37421789476949, 44.11130443696053, 51.706476134638635, 51.30607666507844, 52.2047975755507, 51.06814569042575, 49.26386325590072, 45.004216317207586, 38.913273580612675, 38.52894406164847, 37.748415931578606, 39.28743631609025, 41.18898960851854, 40.464174824376265, 41.67555570602417, 42.362621599628085, 42.884183083811116, 43.64210267220774, 47.46595075053554, 48.94429599085162, 50.164000142005186, 53.025784953948, 52.754015691818736, 54.07501113030219, 51.97392294483801, 51.41763279514929, 52.426533083761896, 54.196149610704, 51.85116060318486, 55.24545815683181, 56.36725994848437, 56.648752766270796, 52.57246486602291, 55.902717959496286, 54.526754425418, 57.995259300354995, 58.403021058728626, 55.908997674142164, 35.31056873260006, 10.754570268815565, 0.6278700345466215, 2.7348527456483533, 4.5600186144152, 2.4102123850776307, 2.162080796495561, 0.10519438273003025, 0.1277712926328663, 11.916944076938014, 43.857848721165816, 40.728887742565526, 36.23134120818108, 38.786031892222745, 51.033534696025235, 45.536313287673465, 23.685479394851193, 0.6352486257110873, 0.019118155074876644, 0.00535713698369481, 0.02997772910842492, 0.02717121196309886, 0.045847818856277776, 0.03458983505204801, 0.013374970106768512, 0.06295661532109784, 0.05923818541510452, 0.005609847364887115, 0.02519103172685831, 0.09668889921158554, 0.03350367559300315, 0.10497845318769256, 0.007295818715882038, 0.04509193905358834, 0.052054720675392505, 0.04367707807931208, 0.0716636106071453, 0.05564385792240501, 0.05162760750540803, 0.032374435179536386, 0.037604452321125616, 0.044729954848486575, 0.014834861729233978, 0.026890277945166154, 0.04069110483772332, 0.05122172263180537, 0.01919312635436654, 0.08153694411439281, 0.01818020873132252, 0.04122375811059629, 0.06378193333324406, 0.0171180201634284, 3.303440751567964, 30.371367239182998, 57.70382327418174, 47.71797480121736, 35.266630341929776, 38.434528689230646, 45.007730760881984, 50.8336389449335, 51.30681407067084, 9.55454464881651, 0.19885947927832606, 0.08382377019452472, 2.647454003172536, 11.0766831521065, 9.715190222186427, 10.1339405005978, 5.729635079060832, 15.994522436972588, 46.61642812913465, 56.12508104693506, 53.54906051389633, 51.765358755665446, 47.39227294921876, 45.31092213046166, 41.91514584325975, 43.72813593956732, 47.126034229032456, 46.95646232174289, 50.24273780084426, 48.718567509805005, 50.52559952582083, 49.07659753676384, 48.29914846727925, 46.65614604949952, 44.68850866440804, 41.91759340224728, 39.140257220114435, 39.1844819438073, 37.90376140225319, 37.089861746757265, 38.85788186903923, 40.042614167736424, 38.7904445586666, 38.55256457482615, 38.95594504571731, 38.81484562350858, 39.19296603049002, 44.76688546519126, 46.67449489716561, 48.49091314500379, 49.21211542621736, 46.848095078622144, 40.98836429657475, 37.75975942611694, 38.92305204945226, 38.784196222982104, 38.414085295892534, 38.81572815679735, 38.64259081502115, 39.07537729509416, 42.06852228410783, 43.05162122172695, 44.02452199689804, 41.32383285030242, 40.02823475868472, 42.10092498410133, 41.82055396418418, 47.870429485074936, 48.36306741160732, 52.83567943880635, 46.79477437849968, 46.07209336373114, 50.176390909379535, 45.96827214764011, 48.85986305052235, 53.265633967614946, 52.87151029033046, 50.709115459072976, 50.585223474810206, 48.94742604224913, 41.646683139185754, 38.69551927812638, 37.98564087960028, 38.245407689002256, 39.911273602516424, 38.4020749984249, 39.29686569398449, 44.64262477813229, 52.73101491312827, 52.56644402780841, 55.153596247396166, 52.84612471057523, 52.568515039259395, 46.04520943857009, 41.37532572592459, 40.2969406497094, 39.32262782127627, 43.088832747551706, 43.8854935861403, 43.54107026130923, 45.14001661731351, 46.15424348462013, 45.724438005878085, 47.03766322905018, 50.84421365491806, 51.5861770414537, 53.0150729610074, 54.06424814654935, 53.7981741659103, 55.496717345330026, 53.75657350786271, 53.687504491498395, 53.62367183931413, 56.1085404119184, 53.82694475112423, 56.70943183283652, 57.56427318819108, 58.17570794013239, 54.56573886256064, 57.849017650850364, 56.44003560466152, 60.15327284413, 59.46211984080654, 57.04225278669789, 38.410449258742794, 13.329500382946385, 2.188282229246632, 4.917628947765597, 4.634614250352306, 4.605759334179663, 2.7128556034257336, 0.1688790573708473, 0.049848985002045675, 12.417856243348892, 48.23641015637306, 50.57473113459926, 37.71524836940151, 43.27132101981871, 59.21598326775336, 51.61406509337887, 29.140003842692224, 1.3759645146708335, 0.06918540044176964, 0.0218408047446921, 0.05749107593850744, 0.03421809088679091, 0.057563256742733146, 0.08222844571836534, 0.036250211884297674, 0.009503398267101617, 0.01339381012404638, 0.052734079785765185, 0.027449832395500237, 0.03842607395903718, 0.02181422532415919, 0.019376029846288504, 0.015238569955521775, 0.13504021831097143, 0.08962979735506159, 0.1929484521068873, 0.22445688234461894, 0.1410720422263107, 0.11823856947763313, 0.15708602243854156, 0.19222048471771902, 0.16726990500765462, 0.09640655750709196, 0.11294795095079369, 0.09566978010679446, 0.13245134674493345, 0.13172178589288266, 0.2528817627218462, 0.13238330281549884, 0.17643479870692377, 0.17233357764780524, 0.20924110446245442, 3.3060809969902043, 36.00194531102335, 64.7734405148414, 53.0515706154608, 46.62839920290055, 47.074827686432876, 48.15870408088931, 57.03123484888385, 56.988469246895086, 12.633963150362815, 0.22708470182072735, 0.7853185697909325, 6.60002225829709, 19.831568310337683, 13.235021272013265, 17.019713309503373, 7.786266140399441, 16.215006709098816, 47.77167204887637, 58.09357350872409, 56.717390321916156, 53.5981725108239, 50.39764788842971, 47.98652771980532, 44.77900558902372, 46.23960994905042, 47.5997624089641, 49.30918232087166, 52.589931180400235, 52.17523074919178, 52.745464924843084, 51.62606362373599, 50.14769877156904, 48.863977616833104, 46.20429292801888, 42.811658459324995, 43.16066311251733, 42.09764588263727, 40.40183659522764, 40.514608660051906, 40.11325213216966, 41.53245979739774, 42.65315155829153, 39.61763320430633, 40.94545748925979, 41.58402327568301, 42.42296726472917, 46.84264298408262, 51.28275817440402, 52.279224549570394, 51.72299715780443, 48.699595005281516, 43.29846382141114, 38.928849312566946, 40.88169936210879, 40.86066761324483, 40.818494289152085, 40.52468915139475, 40.57878648081134, 41.539374936011534, 44.56902150184878, 45.71435359216506, 46.95113574304889, 45.114591813856556, 43.0875579772457, 43.00512544570431, 45.0022315979004, 50.949168435988895, 51.049471286035356, 55.21702881782286, 47.856399166968565, 46.07363093283869, 50.41809128176782, 47.49286997702814, 50.59103250503541, 55.070912684163744, 54.51679944992066, 52.544184577080514, 53.107409477233894, 52.51381366483627, 42.80445306531845, 41.78995555446994, 40.03463998917611, 41.05163997219455, 41.97682903658959, 41.28282839252103, 41.76392670600645, 47.720355679911954, 56.59843660170033, 53.65604316034625, 56.52353894325995, 54.377982847152225, 55.002577151021654, 48.19023601470455, 43.62754283412811, 41.2102763114437, 42.48557613741967, 45.44377280819801, 45.66154672253517, 44.90103836982481, 46.23986490311162, 47.687317555950536, 46.733565791960686, 49.490666466374556, 52.864873639998905, 55.26305783179499, 54.69610275760774, 57.05741666978406, 54.77162015053534, 59.03821752917383, 55.85902667814686, 57.39496407970306, 56.88401260683614, 59.04013949055826, 55.999063138038885, 59.693727954741455, 59.30093396094538, 61.001563841296786, 57.15486795671525, 60.569161753500666, 58.95914254649993, 63.256004933388006, 61.732054295078406, 57.16453659919001, 40.26795433413598, 13.450334879659838, 2.9687848639103676, 8.189166611240756, 11.018201593429813, 9.878379452613093, 9.099125112256697, 0.4780477820144546, 0.31288051256729715, 15.091114294144417, 53.42900460766208, 54.49432034646311, 48.132808593011674, 50.519763039004424, 63.1202870030557, 61.334239667461766, 35.32257903006769, 1.8165833551076151, 0.14304193007128854, 0.09399658279313196, 0.16187048667380888, 0.10203279149267944, 0.12787199489051296, 0.16684152396215549, 0.168817080857773, 0.1421697849347707, 0.11027976630195496, 0.1355042530884666, 0.13738029516272007, 0.19931000026483692, 0.08608941394355028, 0.1386166078549239, 0.10577041190117599], [0.03342282650391421, 0.05009666122796555, 0.013721080012469283, 0.07087197365059007, 0.09633865147348374, 0.06045299784971341, 0.01499064187819679, 0.039336829926938786, 0.07996405069265636, 0.06026635584872096, 0.025910003328575723, 0.03433937409652337, 0.01788464817969549, 0.021313954587845553, 0.009287921674249154, 0.0581903686566699, 0.06109427472937012, 0.03128904563885543, 0.06822613578650259, 1.0474484846476586, 15.758972341014495, 47.841152914108775, 46.44939791771674, 32.78248152425213, 26.062859335253318, 37.24730568547403, 47.30200744444325, 49.480684034286014, 16.21586080520384, 0.11537835722969425, 0.04911913686702329, 1.537783367018546, 2.0911540475583847, 2.0675744741193713, 5.843744181817578, 2.2898667137469015, 14.64658227659041, 39.71382933278238, 56.00062816373764, 52.271446489518695, 51.228464726478826, 47.8423963054534, 45.07885117684641, 43.86958837509156, 44.27577334065592, 46.00267133405132, 49.1893264555162, 47.63474995090116, 47.87106098667268, 47.405275606339984, 44.78808195360246, 40.88690434732745, 39.023751058886134, 36.820606723908455, 37.36407072313371, 35.776177606275006, 36.82135981898154, 36.88876182802262, 37.85945038641653, 37.48550730366861, 36.90587120671427, 36.06291463298183, 37.61382764385593, 37.45725447131742, 37.33066389637609, 38.59156862381966, 37.60522980843821, 39.66523508871756, 43.29438063406175, 42.93031407940773, 42.94083779858005, 39.397109708478375, 36.69713443325412, 36.351189228796194, 37.454536268788004, 37.13810689987675, 35.937343874285304, 41.44947028929188, 46.370797541833696, 48.41462304515224, 47.822223555657175, 47.69919449283231, 46.61843638266287, 46.125425830964126, 42.967407934127316, 43.645232723605254, 45.6885757753926, 48.33761122918899, 49.69052691613474, 47.02125595461938, 41.376349464539565, 45.19685568348054, 51.160038978822776, 43.862167250725534, 46.224340161969586, 48.212389561437796, 52.32146455395607, 49.79916088042721, 47.34201562020087, 42.45830389761156, 37.894802708779615, 36.043977429789884, 37.39694802991806, 37.24734883154593, 37.75322475740987, 37.52405243535196, 41.922284556973366, 51.0571159855012, 50.071420438828014, 52.677341199690304, 52.46541161690989, 50.758698140421224, 44.62132630809661, 39.82167882304038, 38.011450075334125, 36.7169306355138, 36.87607688288535, 38.819532855864495, 36.658455940984915, 35.39765319516582, 35.863446420238866, 37.715573926125806, 38.22195583774198, 40.26194134066182, 43.37815853857225, 47.11041142863613, 48.6048815327306, 49.61972813452444, 51.74263646525722, 52.2522896335971, 53.59155939471338, 52.73645524055728, 53.0172969448951, 53.78549706551337, 56.70341099462202, 53.80625817083544, 52.55149979745188, 52.2943139076233, 51.381594058006044, 54.76787428702078, 57.568062197777536, 59.92624998092652, 48.426201881900916, 23.194500630901707, 4.0303866084544895, 1.7245620993837234, 5.390012735320676, 6.830389922665012, 1.4655049938348033, 0.7382644688890827, 0.328962046412691, 0.1043702023584516, 11.732092576642192, 41.49183580952306, 40.60138325537405, 40.39738470508207, 50.82109520512243, 50.81144225212836, 46.4137553399609, 17.54188079987803, 0.2383222463991373, 0.04691122933441112, 0.015044864623867458, 0.056691341432592565, 0.057258434188101566, 0.05389559931392151, 0.018144514779710484, 0.018992355776830547, 0.03670972291259997, 0.01951691916122312, 0.0625519140533382, 0.04347193122450863, 0.07740406830224299, 0.0372757469754546, 0.00489926586235543, 0.058882881496702476, 0.04659475075201162, 0.01789086689842084, 0.013999082786481709, 0.028261458501219753, 0.04958133303350018, 0.042025645323578394, 0.04212908251511474, 0.022480120439262643, 0.04455381591293601, 0.04016372608020902, 0.03925796883601335, 0.0190788988144167, 0.02898568355087792, 0.02016369846739596, 0.027178206345847538, 0.06748015767023449, 0.0501991676226739, 0.05154484702694801, 0.07423317675749141, 1.1096390120444761, 21.89849069041591, 54.67663603444254, 54.00971151167347, 39.881267470698205, 34.038649989712624, 40.133911255867254, 52.0714448344323, 54.08852369554582, 17.196182704740956, 0.23287983521098093, 0.13620350750223284, 2.1176038153709906, 3.965198777375683, 2.8537672421624585, 9.30243822836107, 4.851677235095732, 16.05666748939022, 43.002097375931285, 57.03728706605973, 55.01660354675786, 52.13192778248941, 50.46048425859021, 45.486306990346606, 45.53974928394441, 46.253683413228686, 48.11273390246976, 50.59419785776446, 49.80908447696317, 50.726605307671335, 47.703109018264286, 46.250569051311864, 45.0172072072183, 42.653363366280836, 39.2155392708317, 39.702285797365256, 37.60822257687969, 38.88452652961978, 38.908864836538996, 39.219857800391416, 38.74692193923458, 38.193248010450795, 38.57192931636688, 39.21058531730406, 39.59471087301932, 38.81108407051333, 40.1305890083313, 40.293414438924486, 41.72879403637302, 45.780386694016, 46.115392408063336, 44.302339553833015, 41.176139923834036, 37.85416695379442, 38.830778291148526, 38.92590361256754, 37.96854719038933, 37.42994300780758, 43.19126544460174, 47.335422115941206, 50.44240997683618, 50.32981834103985, 48.98943462679463, 48.607638958961736, 47.10063295979654, 44.05548126466813, 45.56374242228847, 47.10854045806393, 50.05580940554219, 52.05204479156002, 50.11711605133549, 41.984418822873025, 49.209538429014145, 50.486262075362674, 46.73799414788523, 48.5295484912011, 49.036232425320534, 52.97862629736624, 51.562995833735314, 50.759745413257235, 44.667853463080625, 39.844989468974454, 37.794005640091434, 39.061386200689505, 39.32853883312595, 38.62400270277454, 38.507182751932454, 43.20881412875268, 55.59604744757376, 52.88831372414866, 54.632211269870886, 52.47600986111549, 52.53296267601752, 45.22564195817517, 41.77753340813422, 39.81764270413307, 38.856093268240656, 39.393987501821215, 40.60818464525285, 37.509021912851644, 37.489908203001946, 38.85548137849377, 37.46660932417839, 40.305491416685044, 44.0938812686551, 46.89799154958418, 50.22024300790603, 50.722930046819876, 51.64703261467719, 53.58314983306393, 54.613544710220836, 55.08260134727725, 55.500624026021654, 54.63744763405093, 55.275397608357096, 58.21448841402608, 54.54044349731938, 54.29267521827452, 54.08155364374961, 53.62124389217746, 57.432305043743504, 59.74959035073558, 60.98485062199255, 50.08911032830515, 27.077809879856726, 5.921811115357184, 3.124682898482969, 8.00811981001208, 7.539880987136596, 5.586853940640727, 2.6406361883686436, 0.07597332249485678, 0.14019946808055525, 12.664268362906672, 48.0683679734507, 44.88241103387649, 43.976978948039395, 54.0831696602606, 57.66344639562792, 55.448546717243815, 22.068031218744096, 0.25436472508215136, 0.043977399867388516, 0.023298673895037463, 0.05905379188216983, 0.058335814279534166, 0.044865632850316264, 0.026652126107364896, 0.06297182599683443, 0.026548549104782364, 0.04090821798590403, 0.013840154016150102, 0.07441537544852303, 0.052743418397562164, 0.06419540247729709, 0.03472910217580295, 0.022404013434425, 0.16556623271636425, 0.11650573987994464, 0.09702322764262077, 0.14693203262023388, 0.15662512862153594, 0.19421038277927907, 0.08777954180033938, 0.1100639516728059, 0.13996309931239775, 0.14108771638524148, 0.12379287546800992, 0.12501051859749904, 0.12501866977301337, 0.10999556300380539, 0.12621633332943724, 0.1288475618968087, 0.1511568083397804, 0.1971877222099612, 0.17003888384469096, 1.5445818151197128, 23.955726777353597, 63.499074212966434, 62.47928934712564, 48.40942982704409, 37.500263260256865, 49.21969344539028, 57.81265727935299, 60.11756358608123, 20.026865082402384, 0.40584656920644546, 0.5008516761083757, 3.176014711779933, 8.846528395529717, 10.38813558317, 15.827781500354892, 5.519450460710834, 17.846986286101803, 43.733282089233406, 57.763851227298865, 57.8365445137024, 55.898901493318625, 52.383908687099336, 48.7206228317753, 48.391363390030406, 49.39903597677908, 50.69558720434866, 52.966867031589636, 51.73525848696309, 52.95390359817013, 51.26677059358167, 50.47038432090513, 46.31224047753119, 43.40084160527876, 41.503987312316895, 40.499350640081595, 38.90577400884321, 41.27506209957985, 40.1490359152517, 41.05093002319336, 42.033495518469046, 39.448182890492106, 39.214707728355165, 40.95528302654144, 42.002728446837395, 41.25644653074203, 42.223546120428274, 41.03080434183921, 43.70890848098263, 46.815131479694, 46.23214960098267, 44.53308082395985, 43.28850100117345, 40.70580459410145, 39.282082280805035, 40.082975356809555, 39.638535514954604, 38.852904381290564, 45.21773053753761, 50.684710471860825, 52.133794830691436, 52.30805397033692, 51.87325139199534, 50.631844766678356, 49.37540369649088, 48.19127544280022, 47.414136240559245, 49.349417994099284, 51.96449748931393, 53.94784396694553, 53.04682846992247, 44.536528587341316, 50.51459727748748, 50.05203608543643, 49.100751492284964, 51.41650707490983, 51.58845593852382, 54.63293298598259, 54.34129299656038, 52.295749495106364, 47.312287976664884, 41.831999440347, 39.630890815488755, 41.33317593605288, 40.81192824148363, 39.8412279159792, 41.77747849495181, 43.94755724937686, 55.65043503238309, 54.14794368128623, 58.21853237767374, 55.390621154539055, 54.14548043281802, 47.604257445181574, 44.183334842804946, 39.595252160103094, 41.24430679505871, 40.98658354051652, 42.603925812628965, 40.456365385363185, 38.77793219781692, 40.17563742976035, 41.9869722858552, 42.48646259307861, 44.80709760419784, 46.85259403720979, 53.182001190800825, 53.11119848682035, 55.379964074780865, 55.05881217218215, 55.960890631521906, 56.661625985176336, 57.71838703463155, 56.04002444974838, 55.519216060638435, 60.396961858195645, 56.97768665129139, 57.40344816638578, 55.01055917432232, 56.172620173423525, 60.88986650589974, 61.20601346415859, 62.79517350658294, 51.480771187813055, 28.684208739188414, 6.995585445434817, 4.354179982216128, 10.480872181154067, 16.19443093576739, 9.235537302109504, 4.90401489119376, 1.2671864032745361, 0.3635273206858866, 14.276333085952269, 53.56797810523741, 55.29452308531731, 52.92393276768347, 61.52238007514708, 64.19166672614314, 63.26432428052349, 25.322425673084876, 0.39571052116732447, 0.1019748522629661, 0.11892427179601886, 0.18020790430807299, 0.16330896996923033, 0.15880702363867916, 0.2397080994541607, 0.1808607950806618, 0.17464526328108004, 0.14877292658052138, 0.13281913023562203, 0.18871146494582777, 0.13908484079424413, 0.15198914754775264, 0.09973340923146856, 0.12759772009186207], [0.03428689707371016, 0.07040726471572153, 0.03867344374978735, 0.1463502501287768, 0.033647822696835764, 0.06389473594965474, 0.06160525920530481, 0.03758454552641319, 0.08121890271262777, 0.006791756801953119, 0.0336530550773586, 0.014119436156996077, 0.005752830493879775, 0.04601245498164527, 0.138869907166208, 0.038679848244834336, 0.04574371899868693, 0.028028088967285814, 0.02203369227748725, 0.14053049467263684, 8.536451305112532, 40.477459892149895, 49.373505269327474, 34.7014364119499, 29.190906401603456, 39.002107420275294, 41.56673346796344, 51.56720453693021, 25.06121543145949, 0.3371010564507977, 0.031893061917094935, 2.111583467452757, 8.702636245758303, 29.651165162363363, 8.911293591222456, 3.5033345414746195, 11.948945714581399, 43.42634485613915, 52.192720597790135, 55.35476676879391, 50.47576973515172, 46.74730585467431, 44.06511460581134, 45.36435657931913, 44.20146011537121, 46.86161941097629, 46.241476997252434, 48.43293266911661, 43.985408121539706, 41.73814496686382, 38.38689150348787, 37.32499214910692, 35.72714013438071, 36.027570155359086, 35.64537048339844, 36.34845141441592, 35.7835320503481, 36.531806530491004, 37.28163426922214, 37.72199876846806, 36.04337730715352, 37.91308879852295, 38.615200904107866, 34.53584963275541, 37.44056478623421, 37.752393214933335, 37.088328100019886, 36.42734596806188, 41.44395151445943, 41.96855675789618, 39.71702214210264, 38.37082155289189, 35.558427226158884, 36.699072084119244, 36.24419089286558, 36.58718255258376, 38.14898798542638, 44.974033678731615, 50.623023356160815, 50.41900519401797, 52.58915455110612, 52.03417055068478, 49.7939480504682, 47.003750416540335, 48.13220847037531, 43.4836781409479, 48.13816262829689, 48.96795965010121, 52.337679632248424, 42.05597462192659, 44.924239189394065, 40.863095560381495, 47.1263401739059, 51.12541229494157, 45.98956669530561, 49.87742393247543, 50.88067993041008, 50.86770865225023, 46.3822743969579, 43.8017862842929, 38.04610029343636, 36.323913066617905, 37.35609654457339, 38.039047871866536, 36.72108050315611, 37.304658582133634, 42.362088157284646, 49.41370956359371, 51.41650707490983, 54.11777673229095, 51.08534528363136, 50.71857229355843, 44.382854046360144, 38.20949446770453, 37.09603947977866, 36.17420011951078, 36.18403742390294, 38.46891610853134, 37.578032093663374, 36.71284744816442, 37.74916118191135, 35.6574200045678, 35.996677567881925, 36.57817286829795, 38.59292576389928, 38.296021953705825, 44.6784556296564, 47.01764737406085, 49.24583996495893, 50.25849396182645, 51.19988241503316, 50.963822410952666, 52.86542277182303, 53.73432582424533, 53.13596433208835, 52.34927808084796, 47.56299803333898, 44.58125145204606, 48.00808898864254, 52.833886915637606, 56.6220728043587, 57.69923017870996, 44.67334870369204, 14.461979846800528, 1.660464809786889, 1.6623558825062168, 5.911184433967837, 2.4675439538494235, 3.185310729088322, 1.327202344133008, 0.011366883202666237, 0.2851439315465189, 13.505987428849744, 44.86223828408026, 37.32105016708374, 28.288369024953536, 44.546067791600386, 47.89744677082185, 43.050503346227835, 9.418557055534857, 0.11010624738710542, 0.1215196704311717, 0.0795317855813811, 0.021351425863441922, 0.045083014129270474, 0.09342720326516898, 0.023011680121623704, 0.02075930501544668, 0.05228717856469655, 0.05107633829597504, 0.07220348808914423, 0.030613359920079672, 0.05273758463801877, 0.028329942931210803, 0.03324112577003337, 0.09419125339557087, 0.02364363371124191, 0.010881604807030772, 0.08043406861684016, 0.02313931036980883, 0.010636657769341144, 0.04631714730132972, 0.026660652665962136, 0.03910508449940432, 0.02139375796691785, 0.03389753288619461, 0.025161186856548154, 0.03267959864329427, 0.027632352843460058, 0.040808714655858856, 0.065219501153596, 0.008868772945847482, 0.038022326470743266, 0.04282902257757322, 0.07136004826714916, 0.13826915633774575, 12.311915966772265, 48.90170297315044, 52.84735633480934, 41.594998067425145, 30.928292812839633, 45.09915728722849, 50.14000700366113, 55.96533467692714, 24.8554184744435, 0.14846209406612382, 0.26162377588691255, 2.2640835037154536, 5.692600550190096, 19.374975004503806, 6.898063555840523, 3.8501941484789697, 13.008410257677879, 44.796985733893614, 54.658761793567294, 57.53316487035444, 51.957496058556345, 48.04683023883451, 45.93548113299955, 45.72840352212229, 45.32132817852882, 49.46964256225094, 49.65627285741991, 51.869462382408884, 46.00012571580949, 46.37159378297868, 40.406574818395804, 38.694609288246404, 38.235535083278535, 39.077667959274784, 38.544013807850504, 37.667571959957, 38.062260458546305, 38.41635242585213, 38.41093563264416, 38.211930259581536, 37.74811390907534, 40.69681059929633, 39.5686428008541, 36.790773176377826, 39.43170109102803, 39.67742189284294, 39.009328503762525, 39.62627418579594, 42.5573358997222, 43.57581069392543, 41.50914522909349, 39.61820979272166, 35.766261854479396, 37.15153709534676, 38.973352524542044, 39.3262364018348, 38.89519929885864, 47.846946254853286, 51.23771367534515, 51.37550653949861, 53.964533652028734, 53.43017347397343, 51.58749103546143, 49.774226373241795, 47.9027105915931, 45.93068015190863, 50.45160793489026, 50.656912634449625, 53.802120070303644, 45.412162426979314, 45.948844648176625, 43.977049550702496, 50.73423824002666, 49.9827278044916, 48.3888413060096, 53.12030230799029, 51.46944338275541, 53.93954815403108, 50.08331698756064, 45.537313492067405, 40.612667914359804, 37.22219074926069, 38.54161723967522, 36.98043546368999, 38.18858431231591, 38.42726445967151, 43.889725823556226, 50.77574868356028, 53.08263186485537, 55.55398394984584, 52.95577456874233, 52.83973124719436, 46.45343795899422, 39.239065647125244, 39.79603436685378, 38.671290797571984, 38.47556452597342, 39.7115308238614, 39.097236664064475, 37.89882706057641, 37.549716503389426, 36.73702886027675, 37.085562829048406, 38.75162878344136, 39.998954265348374, 40.583054019558816, 48.01598864216959, 49.622575775269546, 51.850489877885394, 53.41177755786527, 53.484792478622936, 52.94940856195266, 54.24715219005462, 55.706038551945845, 55.3641333887654, 54.508754668697236, 49.84786495085686, 47.46817473442324, 51.09703394674486, 55.29853174763342, 59.05106721385833, 59.8937217650875, 45.38429790927518, 17.8336541498861, 4.441750328386984, 4.007768260855829, 8.782269185589207, 5.619510123806616, 5.474788883040029, 2.300487021284719, 0.27480220422148705, 0.37259265359851623, 14.135912233783355, 49.06945490068006, 45.53171234746134, 36.15157588835686, 49.14365045485958, 56.47084974473523, 49.88834773340533, 12.582736015319826, 0.14102235376354189, 0.01739380990094956, 0.04103635385211918, 0.007856045887174626, 0.034941032739175905, 0.05834901397446952, 0.042301088406313817, 0.03709326100145136, 0.036750961425563985, 0.02106325422984458, 0.06848854388320638, 0.05529397407606725, 0.03531200315562948, 0.03112245981972064, 0.09718075830249057, 0.04685564965550457, 0.07140327860871631, 0.14841894799422833, 0.10430465587565016, 0.13967754769950144, 0.12739880536232265, 0.2565109510455401, 0.24393053094465889, 0.10565382864085898, 0.12057133785058415, 0.23102260825614776, 0.19315509666358271, 0.07682101410483161, 0.12731024559827583, 0.13402562678581284, 0.3497341834008694, 0.19322353895873795, 0.17650541669178396, 0.26669613596412445, 0.1916377063119604, 0.28013429874854706, 14.712555562296222, 55.68863107312111, 61.224146581465206, 46.915516699514086, 38.84467132629887, 49.47624783362112, 53.00640452292658, 60.16682463307535, 31.13535277305111, 0.5533063291541992, 0.43558211876980724, 5.932274528088109, 15.080734722075926, 39.55719340232111, 19.658046576284594, 6.564092857222404, 13.281983810086405, 47.25358970703618, 55.42128232217605, 60.747139300069506, 53.38721567584623, 50.60014024857552, 48.963743102165964, 48.69085204216742, 48.548560219426314, 51.82322548281763, 50.40875604075771, 53.712886148883456, 48.104104688090665, 47.504935187678186, 40.91997777262042, 41.42617533283849, 39.54195107183149, 40.57753524472637, 39.84499339134463, 39.656931431062766, 39.5974761439908, 40.7439810229886, 40.597566789196385, 40.68543572579661, 39.52724610605548, 43.398276375186065, 42.21778415864514, 37.89512826550392, 40.52090798654864, 42.34557105648903, 41.162231199203, 40.5740168786818, 46.28464660336895, 45.106982415722264, 43.53975234493133, 42.71069272871941, 37.30194037960422, 40.04468910155758, 41.607479049313454, 41.06224606114049, 41.968137064287745, 49.874242890265684, 53.26521819637668, 54.378610426379794, 55.63440038311867, 55.9356148781315, 53.63235204450546, 52.56929559092368, 51.81086609440466, 47.85390453953897, 52.28080134237967, 55.32343879822762, 55.628877685916045, 49.31949423205469, 47.1430024023979, 45.51395185532109, 48.85344213055026, 49.98246500569005, 50.442053041150494, 55.41091549781061, 55.73404035260601, 55.955081601296705, 50.99645653078633, 48.714056784106845, 42.108200980770974, 38.87621502722464, 41.00737602479997, 39.02713214197467, 39.96460214737923, 41.08079494968538, 45.99561499011132, 51.810320884950706, 55.66428884383171, 57.08453593715545, 55.76468975313249, 56.470653626226614, 49.05127863730154, 42.042218869732274, 41.897361816898474, 39.74483566899454, 39.55489881577031, 41.73080621227142, 42.22059257568852, 39.88358951384022, 41.35046182140228, 39.99520055709347, 39.5217743996651, 40.68221938225531, 41.42360225800545, 40.63772793739073, 50.473267262981786, 52.29953458232265, 54.24947031082646, 56.682238040431855, 54.99921175741381, 54.61846728478709, 57.11509120079779, 57.95583948012322, 57.56382996036161, 57.20039490730532, 51.9167112535046, 48.59083552514353, 53.62746477127076, 58.00184888224448, 61.88838035829606, 61.78825401490735, 46.05711775441324, 19.298788847461825, 3.986408748934346, 5.386004073004569, 12.412815997677466, 9.676536244730796, 13.700574251913256, 4.0933450623866054, 0.5102417996573834, 0.8409719769993137, 17.532975058401785, 55.391166363993, 50.74385196931901, 42.04584706214167, 57.97581611141082, 63.4717196033847, 56.890308010962706, 16.085338054164765, 0.2616047462628734, 0.16532028784915326, 0.1674915189223905, 0.09079346959028514, 0.19252941733406437, 0.2378442841431787, 0.1138547002788513, 0.10523316976163657, 0.12166827616672363, 0.1285211318322728, 0.17051345999202422, 0.22668641270889392, 0.14303803834463322, 0.21629778548113762, 0.16321536934664174, 0.1798253353204458], [0.04155398797123663, 0.09688563825141999, 0.03168633500594766, 0.018973230391800888, 0.03493863488397291, 0.09262557652208114, 0.07041758392006159, 0.07125067389419965, 0.04874027191451, 0.033650461869734916, 0.06822402138383159, 0.07571564882152504, 0.021576259262679566, 0.013951621724352723, 0.04203929701038907, 0.09979294958494364, 0.06076016846383291, 0.01732897013425827, 0.04979063208485323, 0.03169434828563564, 4.030677354143513, 37.64128031269197, 50.828351589941214, 41.6288245877912, 35.28624611516153, 38.64726628026655, 41.69888988617928, 48.16233619566887, 30.47149750494188, 1.9287921920899425, 0.03742973064823497, 0.20598046571737338, 9.92774542300932, 34.147166282899924, 13.178568559308207, 3.915132909051834, 10.931487794845335, 38.993176183392926, 55.370817107539025, 53.43726511924498, 50.784809358658336, 48.57378890437465, 45.52271835265621, 43.94585886309224, 45.14176599441036, 44.14163220313288, 43.55485347009475, 42.45422071026218, 39.45340356519146, 38.71417014829574, 34.974127431069654, 35.584593357578406, 35.73228628404679, 36.53379517216837, 37.84888744354248, 40.18324290552447, 39.48246048342797, 37.869985872699374, 38.11420440673828, 37.43949790154734, 37.86733827283306, 38.176342595008116, 37.81271534581339, 37.30174426109561, 39.75486909189532, 40.69483372472948, 40.58204597042453, 40.37017522319671, 42.39611471852949, 41.69296710721908, 39.963790216753566, 38.37209240082772, 36.631823047514885, 34.62190251196585, 37.78928702877414, 36.69861708917926, 39.797634693884085, 49.18262704726189, 49.401244271186094, 50.98943156580771, 49.972153094507036, 51.85860918414209, 50.887681361167665, 51.573225375144716, 49.57476992760935, 48.61447172780191, 49.08284587244834, 50.04235567585115, 51.58341177048222, 42.599234657902876, 45.435445616322184, 47.12959574114892, 39.59121604119578, 45.873982291067804, 48.34909200668336, 47.69347567712107, 52.74808114574802, 53.43247198289441, 47.987614216343054, 45.24522243007537, 35.78690136632612, 36.22882304653045, 37.73531913757324, 37.09173663969963, 37.211612116905954, 39.429229997819476, 42.20110624067245, 45.77170256645449, 49.35481517545639, 51.709770925583385, 53.95926198651714, 50.95175327793245, 45.48717775652486, 38.14740727024694, 38.14151979261829, 37.39225687519197, 36.83627659274686, 36.844188013384425, 39.06066840694797, 37.239833570295765, 37.552948536411414, 36.33579784824003, 37.432696511668546, 38.78675360833445, 37.11602787817679, 36.00393003033054, 38.13256502151489, 38.95598426941903, 42.85860530791744, 44.514857492139264, 48.208478958376, 49.226118287732525, 52.88561513347011, 49.23953671609202, 48.860337657313195, 45.12402511412098, 41.97904125336678, 42.11243321818691, 50.2184191057759, 53.84392076923002, 53.76851320266724, 57.00694753277687, 33.64718960177514, 10.035860653846495, 3.193124335619711, 3.3708567340527815, 9.270532688786908, 4.708249886189738, 4.003027341058178, 1.1237601575351532, 0.42536728624855324, 0.4672995071497656, 16.33399475005365, 45.54602115384994, 33.77966373197494, 36.36379964890019, 44.7013661938329, 43.956923869348344, 41.66450246687859, 7.0464242658307485, 0.01441543242113004, 0.036210463412346384, 0.042233519451392275, 0.11392705728329959, 0.03073519854355724, 0.017984027020452965, 0.02638651193269799, 0.024926857797489054, 0.08228307544824578, 0.015551291834262591, 0.043753755819653316, 0.05531423710166447, 0.04352482576524058, 0.03919591188370701, 0.03256680368776283, 0.07034344959162897, 0.044650427261067015, 0.043547754776814294, 0.03997727943163726, 0.060253336184447816, 0.05627110773216813, 0.11358819361175261, 0.024265731579714248, 0.10085878473135734, 0.061381940744937434, 0.0649023637355816, 0.03725566015007996, 0.0769066167694907, 0.032760413258426616, 0.03612311789765954, 0.07268272205105714, 0.05016454044849642, 0.038676603862475005, 0.02779432489807087, 0.01589850873701395, 0.02823908490339114, 5.891775565762674, 43.482015055994836, 58.41456851651592, 46.72172415641047, 36.93654414146177, 43.236270719958895, 47.314511960552586, 54.15971079180318, 32.786658848485644, 1.8278785554632064, 0.08907270587740407, 0.33046973809119196, 13.174453992997448, 38.85938021444505, 12.033484558905325, 8.171757171230933, 13.35115873044537, 40.798129343217425, 56.01400736839541, 54.47127249933059, 52.891777177010816, 49.84255406164354, 48.39415611759309, 45.84133248175345, 46.824239223234116, 46.460400166050086, 46.611693828336655, 45.50061187436504, 42.06772996533302, 39.36680155415689, 36.59579999985234, 37.70794099377048, 37.20038629347278, 38.34101546195246, 40.400918760607325, 41.14854604967179, 40.629408590255245, 38.39234752039756, 39.215441211577385, 39.50859523588611, 39.30176865669989, 39.237473164835286, 38.539965921832675, 39.14308524900867, 40.889948106581166, 42.92006884851764, 41.574707646523755, 41.73651326087214, 44.04374161074239, 44.43502549202212, 42.294803819348736, 39.220108832082445, 38.576600859242106, 36.6610368605583, 39.43777684242495, 37.80901655074089, 41.41011322698286, 51.0498478335719, 51.945281797839755, 52.5929553278031, 51.39972717531266, 52.66549564176991, 53.19211698347523, 52.97532366168115, 51.7816875826928, 49.07611900760282, 50.36904988750335, 51.09506491691836, 54.476183306786325, 45.43826972284625, 47.02393493344707, 46.21602865957445, 41.87428651317474, 48.84433438701015, 48.851708442934104, 49.771496403601866, 54.65840093551144, 54.41145635420277, 49.87104615857525, 45.49727785971857, 39.33188069251276, 38.68907090156309, 39.196076470036665, 38.602472812898704, 38.23892793347759, 40.36976729669879, 43.273850948579856, 47.98884584057716, 51.7200828367664, 54.24209233253233, 53.941336754829656, 52.690818463602376, 48.148117603794226, 39.57615021736392, 40.10767059941446, 38.66400303379182, 38.245411611372425, 38.28041484279018, 41.49210253069478, 39.2882796256773, 39.144250192949855, 39.60093175211261, 38.79694392604213, 39.58051189299553, 39.8804751519234, 37.57561591363723, 40.611385299313454, 40.67583768598495, 45.611159955301595, 47.66807440788516, 51.57402553865987, 51.952216548304406, 53.97991326547439, 51.68048650987687, 52.542486190795906, 46.4061184852354, 44.31437338552168, 44.71325882019536, 52.82683841643795, 55.76516043755316, 56.57862470995996, 56.74698460486628, 36.7774998757147, 10.69801067152331, 3.765902658624034, 4.859707797727277, 7.5840444237955165, 6.198999622175771, 5.065665571920333, 2.5543411028000618, 0.15890496031891915, 0.4223504626462537, 18.663755155378773, 51.08094438429802, 40.01183532899426, 39.429826198085664, 49.81117510026502, 49.08413633223503, 48.34441261906778, 9.436637220844146, 0.08913604602698358, 0.027479987531419725, 0.019097173841850414, 0.023165472272423007, 0.08018378003109848, 0.00845386738693642, 0.035566708238254634, 0.053994056933950034, 0.02176150889886964, 0.0749643846985794, 0.02428317157131049, 0.04116812480553504, 0.01881769156053422, 0.11876891682585401, 0.007641220469057801, 0.045280331565487775, 0.177810171679143, 0.18788356904781636, 0.1614452312670408, 0.13964040775693234, 0.13279781766956852, 0.2564028713611826, 0.14384745620191097, 0.16362985355719445, 0.1467147241196325, 0.17423608039896335, 0.09062391135000414, 0.23259861965573606, 0.11829781105681775, 0.10925749857579509, 0.15491670658511503, 0.12444140720030955, 0.1801607132919373, 0.09295780587220386, 0.27615487034763064, 0.18648961078255408, 7.660791970068409, 50.11085987091065, 64.56970084098079, 52.873667593925234, 47.58049180430751, 50.275536660225164, 53.22581406562559, 57.93060687280471, 37.84587114087997, 2.365263738939839, 0.400693892471252, 1.4498558400138732, 16.13746831493993, 41.729225497091974, 21.665645068691624, 10.24981123785819, 14.105189288816145, 41.24797028879966, 57.69826527564757, 56.32166239523119, 55.51352077914823, 53.234666855104514, 49.676755474459746, 47.656421046103205, 48.71048742725004, 48.67668444110502, 48.017792932448856, 48.50285283980831, 44.27014081708847, 41.6661577070913, 37.49342656904651, 38.965900021214644, 39.19111467176868, 41.83137186111943, 42.12465924601401, 44.10022766359391, 42.944964132001324, 39.73456298151324, 41.96427745203818, 41.13759086978051, 41.8637784834831, 41.745499410936915, 40.15689242270685, 40.84747668235533, 44.04958986466931, 44.61473280383695, 45.01921938311669, 44.066173645757864, 47.47745113988077, 45.863995936609086, 43.63172408073179, 41.14805183103008, 40.41515696433283, 38.59036053380659, 41.007434860352554, 39.73788522904919, 42.5716878521827, 53.55463812428137, 54.893574483932994, 55.00780567046135, 52.8326552914035, 52.740008907933394, 54.25052542840281, 55.83355088387766, 54.71138431179909, 51.45293020432996, 53.709426618391475, 53.06565976911976, 56.290428561549035, 48.743349044553696, 48.902216803643014, 47.96616277387066, 47.47759234520697, 52.54593395417737, 51.03452313330866, 51.739600550743845, 54.33688817485687, 56.446778158987726, 51.705707350084865, 48.564159485601614, 39.74776175714309, 40.59948090584048, 41.01191812945951, 41.74139661173667, 41.04268520109115, 42.307841777801514, 44.40896134222708, 49.50096268807688, 52.785116164915024, 56.27410365689186, 56.99226217885172, 55.53421912654754, 50.29269310735887, 41.37235256933397, 42.38615189829181, 40.0297095698695, 39.69479014796596, 40.17477843069261, 43.7257589832429, 41.15047585579657, 40.98945863785283, 40.22544760857859, 40.522437710915845, 42.99921443385463, 41.0360760073508, 40.981778637055434, 42.02523500688615, 42.816510431228146, 47.024287946762584, 49.147333560451386, 52.76110341472011, 53.45848514187721, 58.187800607373646, 53.834208980683364, 54.180801376219726, 49.822287174963186, 47.49020276531097, 47.9599222829265, 54.85163257968042, 57.67156570188461, 58.90355863878804, 59.77704694194179, 37.96264402327999, 12.793210398766304, 5.518959183846751, 9.042706720290646, 15.345796731210525, 12.886526526943332, 13.314698338508608, 5.788878558143493, 0.860386728759735, 0.6677226025250651, 20.794604324525405, 57.32272186586934, 47.593455237727014, 48.159798422167384, 55.44738177330264, 58.760603935487815, 56.203446080607755, 11.417555751339084, 0.23219116813232824, 0.0683488937154893, 0.1391689878918471, 0.25686862217562817, 0.3598262273496197, 0.12598900439878627, 0.14237972366954052, 0.09771459901164617, 0.17446040626495116, 0.09139821939771214, 0.12331056183264141, 0.1725152477381691, 0.12305348570789061, 0.19838375399910635, 0.09548460899461662, 0.15020840681127964], [0.006065615574874345, 0.059267469126010136, 0.028630103840823137, 0.034129661357691216, 0.004732292690013926, 0.017551593369834365, 0.057632024625256184, 0.021194672782815272, 0.022421355749810898, 0.060817973628159494, 0.03646970373548327, 0.006899373003116419, 0.14154620468616486, 0.013614369710276445, 0.01714172675424526, 0.09625712439658181, 0.03300639259959421, 0.02627308303940921, 0.04279067987696298, 0.0157397868104219, 2.1142212613936393, 28.285199749854307, 48.337897562211566, 46.92294174625028, 34.794647616724816, 36.05892166014641, 36.51400289227886, 45.02229059896162, 33.97791993233466, 4.894800753362717, 0.037904735804805835, 0.1722896348444685, 2.1546900704983742, 25.694503668815862, 20.101615651961296, 3.203186195704245, 5.866719955398191, 30.137480228177964, 56.75065202097739, 53.46970312057003, 54.418975537823094, 46.4684174906823, 47.74938906392744, 44.262602021617276, 44.0664521340401, 40.56212032994917, 38.9879947323953, 38.605002741659845, 36.18095051857733, 36.56872387855284, 35.12791572078582, 36.475092980169485, 39.13370293955649, 41.240305977482954, 46.28124198605938, 47.05504717365388, 47.655726786582704, 42.673634175331365, 38.43016701359903, 37.63647933160105, 38.6843522902458, 36.776480059469904, 39.142343921046105, 37.51860034081244, 42.513162166841575, 45.197953947128795, 45.97905474324381, 45.78320687816989, 41.11074224595101, 38.73971654522804, 41.31698831435173, 36.91925041137203, 35.66331140456661, 35.7832496396957, 37.77233454488939, 35.931036703048214, 44.59932573380009, 52.39527179348854, 50.83823596277545, 51.78131103515626, 50.213163129745, 48.592043615156605, 51.010431935710294, 51.149774136081824, 52.03846554602347, 49.72489864595475, 52.42509749627883, 47.1178247082618, 47.950838073607414, 43.469122225238436, 45.87345277109454, 46.07131281206685, 51.158258222764545, 50.598743884794175, 44.742303971321356, 44.10221630527128, 40.844181891410585, 48.53260401756533, 50.111942445078206, 46.937144648644235, 40.787593856934585, 35.545785427093506, 36.886086771565104, 37.020957469940186, 36.76594065081689, 36.22581066623811, 37.47297533096806, 43.01563739776612, 48.64535254816855, 52.56034081982028, 51.13945830252863, 50.199709400053955, 45.75924904115739, 37.80100314847885, 36.63802039238715, 36.941050944789765, 35.767262058873335, 37.04576253890991, 38.288769491257206, 37.927232865364324, 38.398733139038086, 36.377931948631044, 34.72479412632604, 36.87280562616164, 37.26859631076936, 36.652682212091264, 37.11976981932117, 35.873232733818796, 37.56766134692777, 37.29622940863333, 38.756865147621404, 39.200532282552416, 41.155374896141794, 39.29688922820553, 39.68223856341454, 39.57301232122606, 43.8865840050482, 44.479803269909276, 53.46212510139712, 52.67540747119535, 57.955733576128566, 51.960881064015055, 32.199070146006925, 5.995048630622126, 3.3226383020800934, 3.789401088030108, 6.135991158023958, 3.126262142773598, 2.5461835534341875, 1.1421831625123178, 0.16468144712909577, 0.9272625273273838, 15.072547754933758, 47.58789331682267, 38.09764023750059, 33.58818538727299, 43.998481381324034, 52.197356839333814, 31.762473083311516, 2.451141582381341, 0.09262491002558701, 0.013296312029143015, 0.05649457941012037, 0.06775657751507337, 0.04538357340460343, 0.02433520426312762, 0.04303414261929932, 0.0904480099017101, 0.025884356620090625, 0.04516048477061334, 0.03646962712669084, 0.04589434337591933, 0.048378728209964694, 0.0197671732730082, 0.037483058028644135, 0.0493669088539337, 0.02302715509769417, 0.05560248151361462, 0.044812535296284386, 0.03311827208005613, 0.031260215835044944, 0.10166158358896933, 0.08883672781408795, 0.005547909635013991, 0.07061110539061409, 0.06981193012888394, 0.053560163885835683, 0.026835018107967994, 0.1052067397282489, 0.03310935864705713, 0.04407719431084491, 0.10296056993425855, 0.06824921801566117, 0.02175440726381156, 0.045312403836437774, 0.009686451146168815, 3.0310772503575976, 35.06928413145004, 53.76087634794174, 49.00646163571266, 37.9577410605646, 37.227281985744355, 43.022811412811286, 50.45983314514161, 37.635330077140566, 5.160076531671709, 0.024863546376206705, 0.180004017667905, 3.876359054157811, 30.43864961593382, 19.601068265976448, 6.136655999768165, 8.327241886046625, 33.161000051806056, 58.87881632774108, 55.92595408039709, 56.693965927247085, 48.96795180536086, 49.18234071423931, 46.20705819899037, 46.58883033260223, 44.29442028845511, 43.03730064822782, 39.20050482596121, 38.97975383266326, 37.8551750029287, 37.02349916581185, 37.20593252489644, 40.861087306853264, 42.4400923329015, 46.74134385201239, 48.54406126083867, 47.799905269376694, 42.56767134512625, 40.30234567580685, 38.952728702176, 39.906904082144464, 38.75032655654415, 40.60774926216372, 39.36340478158767, 44.814526573304214, 46.74911798969392, 47.245266437530525, 46.56008328160932, 43.91399745018252, 41.49397742363715, 41.79507424754482, 38.27599825397615, 35.92658481290264, 37.5696970570472, 38.30435699032199, 37.97540741582071, 47.235640941127656, 53.32212394283664, 52.701071539232814, 54.51657587482084, 51.28464875682708, 50.40865405913323, 51.68063163757325, 51.728241366724816, 52.78548094534105, 51.387528604076756, 53.838684405049975, 48.33667770508797, 50.47172577150407, 44.57230452568301, 47.02813186953145, 47.60560674052085, 48.694409631913715, 50.39428249482186, 46.83212318728047, 45.6986484219951, 42.623235640987275, 51.99035767586001, 52.758138102869836, 47.6004135224127, 41.668071823735396, 37.56268778154927, 38.00197755136798, 38.54029932329732, 39.45481169608332, 39.0099129369182, 39.40404053657286, 45.555552513368674, 52.13002543295584, 54.70584984748594, 52.28858724717171, 52.780138677166356, 48.50371183887605, 40.42142491186819, 39.844687446471184, 38.53641225445656, 37.79631591612293, 40.065571800354995, 40.38823381547005, 38.92445233560378, 39.49813427463655, 39.16905526191958, 37.09673766166934, 38.50745731784452, 39.27629678480087, 38.77819499661846, 38.70274820635396, 37.27581347188642, 39.16224994967061, 39.782106030371885, 41.13983446551908, 42.3196324225395, 43.6739170166754, 43.65227730043473, 42.78948922311106, 41.582160149851155, 44.81330671618062, 47.23258149239325, 54.021459010339555, 55.726376041289306, 60.62087428185248, 55.312534609148585, 32.893741515374955, 7.7126226598216645, 3.721659793969124, 6.324993506554635, 7.226974887232627, 6.386095208506431, 6.641642037899264, 2.1985956113184653, 0.11931641688269955, 0.6220583076919279, 16.934231135153002, 51.93712719025151, 41.85977766590734, 37.94388724911598, 48.56779944512152, 59.93929970648981, 41.20410250079247, 4.18422858561239, 0.11851033916877163, 0.008198121382344154, 0.010812835009287923, 0.04414109370460914, 0.05440918848879876, 0.04485177048932641, 0.02797339986559124, 0.053281790516789884, 0.011116079422795485, 0.04735017856282573, 0.021503511553389892, 0.07868567977340953, 0.05840837429728239, 0.02755759415336915, 0.01649733572717636, 0.05270287702460924, 0.11493664625431262, 0.15714626759290695, 0.13422217430366626, 0.11310368130404143, 0.10747989879981165, 0.14242107709569318, 0.18858979486169355, 0.07711990330848964, 0.18659444225411262, 0.12658289107944698, 0.12156307697296144, 0.08087064680312911, 0.28989888607494296, 0.1058094287591596, 0.12762481662174388, 0.28004681150759425, 0.09795402447062154, 0.16341187089921969, 0.12414654761913324, 0.07888387438030013, 4.244662013746077, 38.63833896575436, 61.5694014487728, 57.529968138664, 47.10129191798549, 46.466126826501664, 48.81326529287523, 56.665815076520374, 42.099567844021706, 6.670945575160365, 0.21024444981688456, 1.8717269767676632, 4.7416738733168575, 34.247629950123454, 25.660153512031805, 8.741638333566728, 8.925187606965343, 33.24674306377288, 61.39957458742204, 57.78334540705527, 59.21751691449074, 50.63063667666528, 52.276314150902536, 49.22728323167371, 47.52721425025694, 44.240389639331454, 44.04043505268712, 41.3710307305859, 40.59731967987553, 39.78434962611045, 38.61561667534613, 39.76780506872362, 43.48539613908337, 45.555376006710915, 49.884029203845614, 52.36118247432094, 50.14110526730938, 44.94516503426337, 42.592213615294426, 43.26415092714372, 41.684906636514974, 40.85585878741357, 43.63701143572408, 40.71128806760235, 45.79231462171001, 48.49968356470908, 49.97843673152309, 50.0874040972802, 46.536815781747144, 42.17577557409964, 43.58292979578818, 39.971634957098196, 37.37660269583426, 38.8829222802193, 41.82593153369042, 40.056303239637806, 49.519621402986594, 56.778846017776004, 55.521318451050796, 55.7301454390249, 53.82953351543796, 52.01663363364435, 53.858060913701216, 55.06386026259392, 56.21866095450617, 54.86439597222113, 55.87901115417481, 52.06602411885416, 52.726833666524584, 48.46204450053554, 47.79603389001662, 49.996256059215916, 52.644895353624904, 51.147118691475164, 49.78346747736777, 48.40191064342376, 47.13374168642106, 52.381876899350075, 54.144558675827525, 50.39695755127938, 44.44037560493716, 38.88599349606422, 40.411775881244296, 39.11284377498012, 40.38555875901253, 39.742133155945815, 40.85408195372551, 47.484487871969904, 52.85951568234352, 57.78134499826739, 54.52675050304782, 53.96406296760806, 50.22975867794406, 42.450443467786236, 41.119806843419234, 40.657767326601096, 39.5709805334768, 41.8870146043839, 42.69098674097369, 41.11770445300687, 43.94680415430377, 40.168228072504846, 38.512281833156464, 40.046320807549264, 41.13124447484171, 40.70061922073364, 40.56122210717971, 38.948692583268695, 41.97747622766803, 40.286907226808616, 42.147758083958784, 42.69849023511333, 44.859382798594815, 44.41563721626036, 43.93522923992526, 43.0895426965529, 48.101982685827444, 48.87567804705713, 56.93417187659972, 57.25546890689481, 64.017529179973, 56.60623819597306, 38.170674770109116, 7.921890914440156, 7.199711963053673, 10.063794793621188, 13.897966550242517, 7.907121229556299, 8.444659998339992, 5.237456560134888, 0.27605748525069607, 1.4176951012303753, 19.639613397659797, 59.948332924996656, 51.419907769849225, 45.54933555664555, 55.254291334459865, 66.81081371922647, 48.39135946766023, 5.577259332902971, 0.22640717366049368, 0.11189592070877553, 0.11912658029506284, 0.15391391281399036, 0.24584127680188228, 0.13594853811927382, 0.15268273291087922, 0.268701509001755, 0.08101126990251004, 0.12891744443726155, 0.13416998839426425, 0.14176553565888636, 0.21816020651209742, 0.15300925490596604, 0.18176937535885843, 0.2020586624501213], [0.08079609878721737, 0.019035551644441102, 0.03959415119982535, 0.028874664004111004, 0.037628269994691495, 0.03904725635244001, 0.053254038981732824, 0.028670777363943, 0.019454358506106564, 0.013378235556545758, 0.04386600685275851, 0.00486958330692423, 0.07312509186205364, 0.03123912160404988, 0.06256031420742793, 0.011537790715303874, 0.053607607710986376, 0.053650286469248035, 0.04995339512524586, 0.04500472377384863, 0.8385468490662114, 16.231041358363246, 48.48133471704299, 47.14741506884175, 26.751182348497455, 27.832991653873076, 33.52393696385045, 36.733388900756836, 42.12466316838419, 11.525408183374713, 0.017673355384519505, 0.0264516600497788, 2.5026251423743466, 35.0107741355896, 18.277411499331077, 7.137088381475018, 4.152313730409069, 19.52654323270244, 51.650350939842966, 52.33067820149084, 52.880955357705396, 49.53868804439422, 48.16510146664035, 42.53715138281546, 44.092359389028246, 38.30715364025485, 39.16951025685957, 35.878888791607274, 38.0881324122029, 36.50323206378568, 39.96332345470306, 40.17706909487325, 45.059894361803615, 46.41496342997397, 50.25818017221267, 51.04587839495752, 51.047153165263516, 48.03906002352315, 38.2063526491965, 36.2659796591728, 37.867754044071326, 37.63541244691418, 37.75148322505336, 38.32377664504513, 47.453124600072066, 46.89503800484442, 48.84618574573148, 44.608825714357444, 41.266405428609545, 37.44305156892346, 36.9991216351909, 34.151465200608776, 36.90795790764594, 36.06661342805432, 36.92695394639046, 36.334393639718336, 46.18742281390775, 48.8398785744944, 50.74671137717463, 52.350690134109996, 52.50367041557066, 52.40257524674939, 52.2916780748675, 50.74442071299399, 50.31181858431909, 52.3331061486275, 50.63504149836879, 45.41086804482245, 45.756440624114006, 44.5213137134429, 42.22931200458158, 46.809851969442065, 50.610079534592174, 49.15029887230166, 49.35412091593589, 50.06095947757844, 48.55090187441919, 44.96869925529727, 47.88605620784145, 45.88174858400899, 41.513306863846324, 36.31436601761849, 36.779959201812744, 37.10197794821955, 36.29782146023166, 37.450190282637074, 37.144347390820904, 38.46665290094192, 43.8997749359377, 47.63232200376449, 51.85743247309039, 51.2433461989126, 48.203387721892334, 39.896776522359545, 36.950213601512296, 35.834585620510964, 37.697499644371774, 36.76240659529163, 40.57780196589809, 45.223112029414025, 46.35632399589785, 45.17688689693328, 42.56695747375489, 38.2616816028472, 37.02633503944644, 37.54219339739892, 37.042887441573605, 36.123503485033595, 37.404494670129594, 36.70820728425057, 38.82334147730182, 39.11024324355587, 38.13964097730575, 39.36666427120086, 40.26315335304507, 41.75114762398505, 42.45833527657294, 45.48050972723192, 51.01941024103473, 53.07439880986368, 55.4818868637085, 54.5988711234062, 24.39047444251276, 6.002353554771793, 2.2472359432328135, 4.436090348228332, 4.663850617024207, 9.884740556440047, 4.781499658861469, 1.5963024333600075, 0.12075252530555572, 1.0565453190957348, 19.845467229043287, 39.97649085137152, 38.169443145875015, 41.28811182514314, 50.80898292603032, 44.69130139197073, 24.172010191025276, 0.5127162942963263, 0.020060630913283077, 0.0664978873946013, 0.024005784540467208, 0.0461127205691751, 0.04890473950053415, 0.07723636399473875, 0.06347575863342612, 0.036911387897787556, 0.023416806568181323, 0.02430584011298995, 0.0463773847948159, 0.01005006903376911, 0.04107743914749834, 0.001211997659993358, 0.05229456365228661, 0.07870678549572345, 0.024997272769049294, 0.032490440043470556, 0.030149593273358002, 0.04111970421828089, 0.025995776447797977, 0.047099614185431314, 0.09252131961646581, 0.05520753254513106, 0.00582018398657261, 0.028989653801545504, 0.015854137882049528, 0.005072347628283165, 0.04611362072248613, 0.024738831092573466, 0.02520552802560551, 0.012026076963652047, 0.011401932682811974, 0.03212059003060624, 0.12392188467445875, 0.041377948627116225, 1.2139578788511216, 22.036338467751783, 56.16692489193332, 52.660157295965384, 34.849023434423636, 32.453227966062485, 41.24242013500583, 44.37692734502977, 43.95198952767157, 10.32850378944028, 0.050486063719877315, 0.28115855830331005, 4.280789984810737, 34.48295254861155, 23.035785844249112, 8.073969050761193, 5.057990964381926, 23.710007936723773, 53.576199393118586, 54.58011042687201, 55.33716317146055, 50.42971326458839, 49.38850833523659, 45.82006539067915, 45.75313406605875, 41.70846046939973, 41.17283336577877, 37.63259618513046, 39.08184920587848, 38.24137157009494, 39.892944366701194, 41.646804732661096, 48.06339048570203, 49.701411493362926, 51.92210843486171, 52.51479033500918, 50.90341006555865, 48.51938563008463, 40.535667865507065, 37.77825732384959, 39.63680574970861, 39.666811881526826, 39.49152115852603, 39.405950730846776, 48.63563683725173, 49.11821388429212, 51.212084908639234, 46.43082157258065, 43.29657716135825, 40.309535380332704, 39.552357119898645, 37.02007885902159, 38.58831305657664, 38.84543618848247, 38.11958982098488, 37.505115232160016, 46.74493282072006, 52.71790635201239, 51.3398325827814, 52.70517826080323, 52.47337402835969, 54.23991933945687, 54.76771346984371, 52.30221356115034, 53.19989112115676, 54.305975975528845, 51.76999107483895, 47.423565618453495, 47.0035425309212, 46.18914865678357, 45.575909614562995, 48.90190301402923, 50.80010267996019, 52.350890174988784, 50.33216391840289, 52.984451017072125, 49.56039051855765, 46.041138018331225, 50.975362023999615, 48.2318131385311, 41.613892124545195, 38.30608283319781, 38.41028059682539, 39.02589659537039, 37.69677008351972, 38.55667914113691, 38.29790861375871, 39.16845906165339, 46.664712505955855, 49.75643842451034, 53.74790899215206, 53.559674447582616, 49.68968752891787, 41.39495326626686, 38.70078309889763, 37.81371162783715, 39.56796030844412, 38.735288189303496, 40.650675681329545, 45.98931566361458, 47.39332414442494, 45.63633372706752, 43.42246170966856, 39.26153298347227, 39.90295817775112, 39.27644583486742, 39.10141398829799, 39.43386231699298, 39.2373437266196, 39.044151306152344, 39.532639365042414, 40.07446381353563, 40.3396866398473, 41.60998544385357, 40.986273673272905, 42.41498131905833, 44.483372626766084, 47.629482207759736, 53.43616293322656, 53.915864882930634, 57.62708602413055, 55.88692649718254, 26.732631498767486, 7.7572724703819524, 3.746208683136971, 5.570083356672718, 6.952796799521293, 8.18923770420013, 5.316889949383275, 1.476995699828671, 0.08652181695065192, 1.0570087716464074, 21.049691746311805, 45.92016819984683, 44.699589360144834, 42.705828989705736, 55.37741845653903, 53.46292918728244, 30.549519331224506, 0.7918230239902774, 0.014799326740866228, 0.12017733117024745, 0.03375392587434861, 0.006547880372137673, 0.07846998771832836, 0.06302317303995933, 0.02412584583996044, 0.09268214445441, 0.019408262995702606, 0.03480509426745196, 0.053994704278246056, 0.014881376672776477, 0.04852766719376368, 0.03397514908424309, 0.047457281485079765, 0.04298736529064275, 0.25580601225937566, 0.17630718378049715, 0.1434925736318673, 0.1577502666341682, 0.09458672330384293, 0.2092981933345718, 0.2312840893864632, 0.10704395646649985, 0.13453004971867608, 0.13505613761803797, 0.18396363503509955, 0.10979798892813344, 0.14522189454686257, 0.13543303755502548, 0.10883231211694018, 0.08997700372410398, 0.08471319827461436, 0.13232236818200158, 0.3222012591938819, 0.2042177127253625, 1.1948778768700938, 25.217417940016716, 62.950052215207016, 59.97360867838706, 39.24831851836174, 38.58208825511318, 45.76040221798805, 48.62254004324637, 52.00033226320821, 13.938862162251628, 0.33157740929915064, 1.1292611591277586, 7.4833581620647065, 40.75767793963033, 24.127836458144653, 9.723115371119592, 6.5779147994133735, 23.95437748201432, 55.11022660040087, 55.332628911541356, 57.6857921384996, 53.472978299663914, 52.23472918233564, 47.91105739531979, 48.34275737885506, 42.88925470844392, 43.33355726734285, 39.58363802202287, 42.159348687817975, 41.18674209040981, 43.16992382849417, 44.594136438062115, 50.521437891068004, 52.55708133020709, 53.88245413380285, 55.93375175229965, 53.165084008247625, 50.66010152139972, 42.454993417186124, 40.265644058104485, 40.38467230335359, 42.06685919915476, 41.78663330693399, 41.59666115237821, 52.11397509421072, 50.185839899124645, 53.05972914541922, 47.93497600863057, 45.0746738526129, 40.924766986600815, 41.392615533644154, 38.07223896826468, 40.61565676043111, 39.75945434262676, 39.331802245109316, 40.1218617346979, 49.8704146569775, 53.13910222822621, 54.17526691190658, 55.847471375619214, 56.144594838542325, 56.22386986209501, 55.872519631539625, 54.89579454545052, 53.59995326688213, 58.23004453412948, 52.83884086916524, 49.89415284126036, 49.371273440699426, 49.1899501123736, 45.45039376904888, 52.29068963758407, 51.96374047187067, 52.47952822716006, 51.03675103956654, 53.58506394970802, 50.69628538623933, 48.00501777279762, 53.7041235739185, 50.58101477161531, 44.05291995694561, 40.10245384708528, 41.38402946533696, 40.93709891842258, 39.221426748460345, 40.09122017891177, 40.139755587424006, 40.764883333636874, 48.06691669648694, 52.34298267672139, 57.75312746724775, 55.59658088991719, 52.576540208631954, 44.02118798225157, 40.41154446140413, 40.15768474148166, 42.923638205374445, 39.80141978110037, 44.50924458042268, 50.51628389666158, 50.11051077996531, 48.7081967630694, 46.51132429799726, 40.91534153107674, 41.203365095200084, 41.07800614449286, 40.918738303645966, 41.125027518118586, 42.78291140833209, 41.39846378757108, 42.58849913074125, 42.257188289396225, 42.65251613432362, 44.01149972792595, 44.3445913253292, 45.98418520342919, 46.41529290906845, 49.76325550386983, 56.0867634127217, 57.855254219424346, 59.291759537112334, 58.7670091659792, 28.86693431485084, 9.27866768452429, 5.3965483846202975, 11.019262594561424, 11.39048747477993, 20.560472165384603, 14.923485921275232, 4.881203366864113, 0.45701624765511484, 1.2971218098555843, 26.22811467416825, 53.000352305750695, 49.89885968546714, 54.019101665865996, 62.606225090642134, 61.5856949744686, 36.43253134142968, 1.5944210439920428, 0.16411461867392063, 0.18490846659387314, 0.18522411014043516, 0.13460026933781563, 0.15897665082687334, 0.13449989649797642, 0.16386182498066656, 0.16795829629465459, 0.15104299831774928, 0.08740159232289561, 0.17155340902747648, 0.14752169049555255, 0.17562767911341884, 0.13332261854121763, 0.19355979027046313, 0.20268549091152607], [0.019914172139138948, 0.09396328861194272, 0.014602021753577697, 0.04833321492638319, 0.012402779632999052, 0.07916636930237855, 0.052491934714658614, 0.06205042140678533, 0.039300210924158176, 0.03946417672259193, 0.03684725867764604, 0.04478103759127759, 0.02663635235700396, 0.03516216018807984, 0.032047187316141305, 0.004285272246512074, 0.02633157768286765, 0.0147304889528201, 0.0464655653453402, 0.06311305813611516, 0.18311465639741192, 8.424638259795405, 37.92972357042375, 46.296205828266764, 26.443960743565714, 20.21215000460225, 30.971793859235703, 40.813752143613755, 47.80124671997563, 15.978712343400526, 0.5053778767826096, 0.26744252010699243, 2.9704094606061138, 28.789710690898282, 25.096446160347234, 5.936520493799641, 1.0805941060666115, 16.128816546932345, 46.08685716505974, 58.42301730186709, 55.72967083223405, 51.80717514407251, 50.27938842773438, 41.9918752485706, 41.85927168015511, 39.37330092153242, 40.019719293040616, 39.67098136102, 42.47123987443986, 42.28200904784664, 47.067061393491684, 48.750228881835945, 47.532070144530266, 51.702679280311834, 50.82636294826385, 48.8104215745003, 52.26555901189005, 49.37002220461446, 42.12954259687855, 35.38679999689902, 38.34638518671836, 36.12500967517976, 38.70750996374315, 41.48452451152187, 47.03873403610722, 48.88601741483135, 50.05668409409062, 47.89411275617538, 41.79017128482942, 36.6902232170105, 37.33648861608198, 37.29434667095062, 36.80146947983773, 37.407609032046416, 36.23683252642232, 37.229509892002234, 44.331918147302446, 48.36366753424368, 48.67091855695171, 47.24931040117818, 50.858922543064246, 49.73381419335642, 51.72402481878958, 49.70887576380084, 50.36947350348196, 47.36331409023654, 50.84158958927278, 46.80886353215864, 46.88548311110466, 41.79268552410988, 44.62943384724279, 48.22166596689532, 49.85254041610226, 50.14691429753458, 48.42392690720097, 49.53531480604603, 50.041877146690126, 51.77399189241471, 47.84770327229654, 46.628167783060384, 39.49814604174706, 36.22614799007293, 36.503177150603264, 36.011990501034646, 36.185151377031886, 38.30091707168087, 37.129599278973, 40.471556725040564, 45.39646117917953, 48.49829112329791, 49.9231783805355, 49.77182196032617, 44.84194001843853, 39.47285459887597, 36.49463815073813, 37.30481155457036, 37.196330562714614, 37.70043357726067, 47.85694437642252, 50.924139791919345, 50.598241821412124, 48.0562243153972, 49.23126051502843, 48.304114187917406, 45.749882421185895, 43.80582240320022, 40.9596094008415, 40.060837499557, 38.153773277036606, 37.86592621957102, 38.05209367505966, 38.24126958847046, 38.03265833085583, 41.27942377521146, 41.93186690730434, 41.53808447622484, 42.75684725853705, 48.082386524446555, 51.290955928064164, 53.76806997483777, 58.22081127474385, 51.628989711884536, 22.330749611700735, 6.539984499254535, 1.8873451193494184, 5.1320786533817175, 4.871023345378138, 7.032161056995393, 7.832249066522045, 0.95997448169416, 0.0750701584582848, 2.448477557589931, 27.177085068918046, 41.65218230216734, 24.87936454434549, 34.74065226893271, 51.08341547750658, 49.31110820462627, 15.932909846305849, 0.13857963645169813, 0.015430978683364249, 0.03805694981448112, 0.05063161276461137, 0.08239359129220247, 0.01770877162925899, 0.03853839777049519, 0.09522318915133515, 0.11157817042042172, 0.057716930149904186, 0.0846992631352717, 0.03178365690062844, 0.07408794946968555, 0.1446720426000895, 0.010107342724598223, 0.0668473307403826, 0.03843965286749505, 0.047883770293405944, 0.08528390313468634, 0.016721922063058423, 0.0468717260105956, 0.027971833215786085, 0.013340924201803583, 0.04432904954639174, 0.0506316204254906, 0.035775946002573736, 0.022666509631240082, 0.09068596447187086, 0.07182910092054837, 0.08046241387003854, 0.012560584169301777, 0.04152744302466031, 0.04059268169165139, 0.027188065897433028, 0.027242791388304006, 0.047687326197422324, 0.0312929067219938, 0.11741302546954925, 11.996174973826255, 45.43371977344636, 53.416174534828436, 32.176275291750514, 27.108657360076908, 41.07187155754336, 46.842388030021425, 51.67032757113057, 16.94734165745397, 0.26547192746112425, 0.16681074254935788, 1.5500788943421457, 30.825526714324955, 25.006206150977846, 6.965088036752517, 3.744313688047471, 17.399847853568293, 49.39474882618074, 56.23331492946994, 57.812735726756436, 53.93172302553731, 52.75189368955551, 44.65608243019351, 44.221915275819846, 40.382346337841405, 41.743145988833525, 40.91676535144929, 44.542702397992535, 43.1735324090527, 48.43993409987419, 50.081955925110854, 49.69177030747937, 53.150394731952304, 52.044549142160726, 52.14741329992972, 53.037238274851155, 52.19392868780321, 42.39682466753068, 37.34059141528222, 39.614734572748986, 39.06772082851779, 39.04795208284932, 42.34901489750032, 49.026371586707334, 50.0715498770437, 52.83939000098936, 48.557134520622995, 43.290273912491344, 37.96722535164126, 38.55443162302817, 38.327687248106926, 37.81618272104571, 38.073992267731704, 38.54972477882139, 38.42169077165666, 47.41677991805538, 50.858279274355986, 50.760392604335664, 48.18626657609017, 52.506329782547496, 51.54657286982383, 53.572528054637296, 51.06311328949467, 52.15599152349657, 50.24195332680979, 51.76775532384073, 47.75706906472483, 47.716625505878085, 44.735620252547726, 45.400999361468905, 49.28611486188827, 51.711249659138346, 51.16440065445439, 52.197388218295195, 50.34107946580457, 52.82739539300242, 51.27383085989183, 51.09397842038063, 48.92334268939111, 42.341852649565666, 37.558447699393, 38.02987344803349, 37.304670349244155, 37.65887998765515, 38.847307159054665, 38.45941612797399, 41.15092300599621, 46.810299119641705, 50.74319693350023, 51.43438916052542, 52.72200130647229, 48.436400044348936, 41.09706101878997, 38.511638564448205, 38.35866612772788, 39.19155789959816, 39.83319097949613, 50.57231103220294, 52.614873532325994, 54.027107223387695, 49.918667654837336, 51.55879889765094, 49.182866311842396, 47.55650258833363, 44.6304105174157, 42.37525555395311, 40.8758746424029, 39.12417942477811, 39.79276703250024, 39.61482086489278, 40.72021145974436, 38.403993037439164, 43.98681233006139, 44.69843618331417, 43.763739293621434, 45.43291568756104, 50.5401122954584, 54.224021973148474, 54.723888827908425, 58.965787041571836, 53.496328169299716, 24.812129236036732, 5.280276094713519, 3.3235951152540024, 8.57205662035173, 6.292885474620327, 9.657441166139419, 6.3597569830956004, 1.1944682343352226, 0.10962666868562661, 2.8055934271504803, 30.663607351241577, 48.490367935549834, 32.38252528252141, 43.54267843307988, 55.46428718874532, 55.14298623608005, 21.568693883957405, 0.1653875350471466, 0.04470504933006821, 0.010857783303025269, 0.07363255616397628, 0.02666437010761471, 0.02382085283076571, 0.07827588402095341, 0.057171831778701276, 0.03544108514043112, 0.017493489431217313, 0.030585185121444446, 0.012814007969873567, 0.008561131187654551, 0.06108600481022751, 0.028058332203316595, 0.03505562417088978, 0.03403905613888656, 0.21645471093154725, 0.18218467162261087, 0.18005172962382918, 0.11163609432837657, 0.14055824237725428, 0.10251559542431947, 0.24413945844336865, 0.13231887482106686, 0.12321349083175584, 0.06841361282333251, 0.21133158986847247, 0.1455045656691636, 0.128842429107716, 0.06522422025520956, 0.1626926522341467, 0.1348335890760345, 0.09068769583057973, 0.1738711773988701, 0.15169570522923626, 0.20248161959311656, 0.2771181493036209, 12.715992658369004, 51.45279292137393, 59.53580156449349, 39.21868108933972, 31.763177148757446, 43.014292024797015, 53.05153531412925, 57.68297195434571, 20.0660240650177, 0.6415560420963072, 0.8709321435420745, 4.775141006515873, 33.3353494059655, 29.347652158429547, 11.625557080391916, 2.576732688373135, 19.028706204506662, 50.53429934286302, 61.072162582028305, 59.115900070436545, 55.83164853434409, 55.58218186901462, 46.7937663293654, 46.023381448561146, 42.54520400877922, 43.593014209501206, 42.82668505945514, 47.17091791091427, 46.23325963174143, 50.06843943749705, 54.095179957728234, 51.42307704494846, 54.65040714510026, 53.98385132512739, 55.71365971719065, 56.952116720138065, 54.91444541561989, 45.00667564330563, 39.02799898578275, 42.374545604951926, 40.627627834197014, 40.80673110100531, 45.21279227349066, 51.021300823457786, 51.59393941202472, 54.67689883324408, 52.99597886300857, 44.273674872613725, 39.7024348474318, 41.40401786373508, 40.48204514288133, 38.69709214856548, 40.36963001374276, 39.35616800861974, 40.33551716035412, 47.94583705163772, 52.19993383653703, 53.07170806392547, 49.32419323152112, 54.779264850001184, 55.10087174753989, 55.06214618682862, 53.305194993172925, 53.33542077772079, 51.30240532659715, 54.96225910802042, 50.13634350992019, 49.808292158188365, 47.42316553669591, 47.80159973329114, 47.46878662417012, 52.88165746196624, 53.01302940614762, 54.14116974799864, 52.869996255443944, 54.61462336201822, 54.345909626253196, 53.69208581985966, 50.58862024737943, 43.68262860082811, 39.33842320596018, 42.20488348314839, 38.9724660688831, 39.8510612980012, 42.56041888267764, 39.673676029328384, 43.395852350419574, 50.28926887819844, 52.47301709267401, 54.07375204947687, 55.34147385627993, 49.45591426664784, 43.23003022901474, 41.27192812581217, 40.830775230161606, 39.965931830867646, 40.830382993144376, 53.0593918215844, 55.748306012922725, 54.4960226551179, 51.18292600877824, 54.822705099659586, 52.32162144876296, 51.121356564183394, 47.89395193899832, 44.26610077581098, 43.425823180906235, 41.93180807175175, 40.458703117985884, 41.76086725727205, 41.48909015040244, 42.261824530939904, 45.48245522283739, 46.7136009277836, 46.82749086810697, 48.028634363605136, 53.20889296070222, 56.33308433717298, 56.8352222442627, 60.61868167692616, 54.878065432271654, 27.137475013732914, 8.634952806657362, 5.770590507215069, 12.693798907341497, 11.989090192702509, 12.126686938347357, 16.41451120376587, 3.2184402933043823, 0.2887959952556318, 3.5117200786067597, 34.46059896099952, 56.8105976043209, 35.99830927387361, 46.77133037197975, 62.61914145561957, 65.07015997363676, 26.31186119971737, 0.4256827612557719, 0.24613496426853443, 0.14602440229106337, 0.1220695453605825, 0.19333056144175992, 0.1381231246576194, 0.20823982754541984, 0.19652703266230323, 0.24178399854610044, 0.10183783743770854, 0.18393954923076017, 0.13701497847514768, 0.15711815216608588, 0.16823900623186944, 0.07330159851980787, 0.15476715090053697, 0.10341148162561078], [0.02798232670512892, 0.05296110228124646, 0.0295215601386923, 0.04914025408065608, 0.03811426851297579, 0.021873426683727774, 0.035713490684546774, 0.02746694105406923, 0.02486724849610079, 0.028587838770040584, 0.028459438603491555, 0.05582255559162267, 0.04370451934875981, 0.08070327957431156, 0.04509341377284258, 0.036485849038487485, 0.017064591276369268, 0.0247348646723455, 0.014870607391780904, 0.05989573017183331, 0.026393245845552415, 2.9776528525737027, 26.919875644868423, 42.13319824587914, 40.1984420899422, 24.192428088957264, 26.211171996208932, 34.96292514185752, 47.610529315087106, 26.72033290709219, 1.792647949149532, 0.07292941768443392, 9.901994082235522, 36.317778479668405, 30.601386793198127, 9.659245456418684, 2.9694832909491757, 11.105191919111437, 40.96533213892291, 59.31440730248729, 48.926229553837935, 52.60385559451196, 47.561750719624186, 48.295951735588815, 43.5052707887465, 44.23219188567131, 43.16688006924045, 47.98746124390633, 46.543679929548695, 48.99511421880415, 47.727039398685584, 49.66086595289169, 50.65455528997606, 51.70017288577173, 48.98021705688969, 48.412869745685214, 49.05313784076322, 49.39353289142732, 40.24638129818825, 36.82770621392035, 38.00298952287243, 38.9333757277458, 38.99503930922478, 41.92157853034235, 47.823914097201445, 50.27838430097027, 52.2211617039096, 48.936710126938365, 43.248233948984456, 37.333574295043945, 36.8144799816993, 35.589610069028794, 37.87466918268512, 38.81962699274863, 36.0142497862539, 36.15161118968841, 42.00507402420044, 43.05429235581429, 45.62202884304909, 46.1429980493361, 47.2542800441865, 49.12416411984352, 50.463677067910474, 49.63387220136581, 52.827450306184836, 51.014923049557595, 51.31331736041654, 46.81067958954842, 48.71570417957921, 45.08481710187851, 45.77030228030297, 47.60741887554046, 47.79555928322577, 52.71236404295891, 50.0267211083443, 51.4146557161885, 49.1461843059909, 48.94670040376725, 49.27948213392689, 45.02310645195746, 41.4019468522841, 36.22764241310858, 35.49539081511959, 36.3044463434527, 35.379606370002996, 36.14460975893083, 38.27963821349606, 41.690323429722945, 45.67760490602063, 48.884421010171216, 49.24305900450676, 46.476576020640714, 41.969494204367365, 37.27746478972897, 37.059035839573035, 37.99065759105068, 36.30828242148123, 40.864201668770086, 49.153252417041415, 51.97586844044348, 49.98094704843337, 51.29142661248484, 51.76691985899403, 47.987653440044774, 51.680055049157914, 48.92875163785873, 49.29212393299226, 47.12339447390649, 45.37498228011593, 41.06499172026112, 39.68805151600992, 39.38947285375288, 40.30720941482052, 41.080120302015736, 40.50822304141137, 42.55463338667347, 46.0338737887721, 50.71504608277352, 53.656000014274355, 53.53786606942454, 59.16623976922805, 44.46981691545056, 23.013493053374752, 3.8884691269167013, 2.905076256682796, 3.6562687350857646, 6.083312255720939, 3.4940196477597762, 2.95660394334024, 1.1223579101985501, 0.11960330914946334, 1.6907459978134403, 24.082301662814235, 36.16042083309543, 33.016829413752404, 29.788528526982955, 53.57770558326475, 43.50924807210123, 9.913733736161264, 0.047616367303435846, 0.09152041808251413, 0.06607958806618568, 0.03115687631971894, 0.08104440320523516, 0.1387844117538583, 0.07124498186092224, 0.026162653380343993, 0.020943449569805976, 0.11204947537231831, 0.01369941121553101, 0.038011145417488394, 0.019083380428773743, 0.01796428301942445, 0.04582545674976803, 0.028282531664796898, 0.013658405401773993, 0.04899153726235513, 0.08962531574070455, 0.012797762117829296, 0.04495669389143587, 0.02913028647702548, 0.136596234815736, 0.07820682885545878, 0.01779447197012844, 0.044082951461595875, 0.018703615322949427, 0.08558826986700298, 0.03412765037688998, 0.07155428986035048, 0.05021358922784848, 0.05726188541420045, 0.01347998543942888, 0.056366232869726036, 0.10172307746665132, 0.038192765712137186, 0.05062715413289205, 0.08320171446088823, 4.473585265298044, 34.4629680725836, 49.45386286704771, 43.60060007341447, 25.58906839739892, 30.19797690453068, 42.60826395403954, 51.900927635931204, 26.593710953189483, 1.6709482020908788, 0.18850842100237647, 7.91440801274392, 37.96545244032337, 28.237227201461796, 5.694400918099189, 4.471041117945026, 11.233230829238893, 41.74862946233442, 58.46752443621236, 53.493551131217714, 54.33110660122287, 50.11196597929924, 47.81687736511231, 45.196726245264855, 44.98178428219211, 44.40685502944454, 49.16774165245795, 48.325404813212735, 49.88799864246, 50.632860660552986, 50.34009495089131, 53.41515079621346, 53.059113333302165, 51.46043762083977, 49.86102450278498, 52.14191413694813, 50.777035220976806, 42.74491540847286, 37.70859995195943, 40.56889034086659, 38.92282847435244, 41.8385733327558, 43.05163298883746, 50.52308920891055, 50.92987429711127, 52.45990460918796, 51.76234245300294, 45.198828635677216, 39.399125806746945, 37.48991604774229, 35.51669320752544, 38.64860380849531, 39.46661410793182, 38.4431500588694, 37.636848034397254, 42.82536714307724, 45.91601048746417, 47.94005547800372, 50.481861176029334, 49.90261339372205, 51.36179001100602, 51.552844739729366, 51.62066644237888, 54.95858776953913, 52.340943044231786, 52.44151653782014, 49.148561262315326, 49.914160851509344, 45.586754968089444, 47.14088824487502, 49.14026544940088, 50.033679393029985, 53.306905146568056, 52.85666804159842, 53.22948540410688, 50.40333140280939, 51.15448490265877, 51.50522716583745, 48.021597631516, 42.147401148273104, 37.68796436248287, 37.50819037037511, 37.5881165073764, 38.42492672704881, 39.27195079864995, 38.9011848357416, 43.62282814518098, 48.68967533111573, 49.830939923563314, 50.57457031742219, 48.59880578133368, 43.57879169525639, 38.9343523979187, 38.69168712246803, 37.289757497849, 37.794609685097974, 42.41297698790028, 52.20143218194285, 53.97665377586119, 50.67453192126367, 52.91698232773812, 54.40591796751946, 50.777309786888864, 53.94357642819805, 50.00610120834843, 51.35127413657404, 47.30073659650741, 46.102644705003314, 41.89749517748433, 41.557072670229026, 40.096130986367505, 41.35587469224007, 42.38015851666851, 42.993295577264604, 44.0629376903657, 47.50753179673226, 52.59537935256959, 55.94424801488077, 54.290717955558534, 60.15173135265228, 46.7078350436303, 24.58448663834603, 4.503123654473213, 3.8537536994103467, 5.920386804688362, 8.982522852959173, 3.854379562600967, 5.625057335822813, 1.9985052126069225, 0.04306417709637073, 2.4010144270235494, 29.950090954380652, 42.665436421671224, 32.95200832428471, 33.809238403074204, 58.94199786647674, 52.08122722564205, 13.851850263534056, 0.14894575601623905, 0.042547002630007845, 0.06910127632680439, 0.08293814191053953, 0.020712797732783422, 0.050775890103391105, 0.03688483912077162, 0.037546041947338855, 0.04102740977560321, 0.04400328214791033, 0.03129726767750277, 0.020273176262215264, 0.023024027543743292, 0.002132274544677667, 0.07484852922179046, 0.03834589136644237, 0.05125275685361797, 0.18324060125216363, 0.24089955003751864, 0.12229813067542931, 0.13677442686692362, 0.1020598267355273, 0.1359333389348561, 0.22023978282607373, 0.10292901477265744, 0.27230610590307947, 0.18530123987265174, 0.2752336036534079, 0.1346959077542828, 0.10476879024457549, 0.16827991532702602, 0.21390302527335384, 0.18016429858342295, 0.07512412169167111, 0.15326283000890287, 0.20620911231925412, 0.22172671352182666, 0.1874020368221306, 4.626813636672113, 38.30760471282467, 56.88501673360025, 53.99931330834666, 33.92012380784558, 38.53149360226047, 45.31222435735887, 58.29963522572672, 31.698530604762418, 2.4326856049799153, 0.31667142205180665, 15.764616631692457, 44.32453232426798, 37.404922208478375, 16.318128762706635, 6.762705993267798, 14.296519564044091, 41.82105994993641, 61.333243385438, 54.765493408326186, 55.914159513288936, 52.253689919748616, 52.70874761766004, 48.648914060285016, 48.86426394985568, 47.94784922753611, 52.55614780610608, 50.45359657656763, 52.78706558289067, 52.582996429935584, 52.8599432206923, 55.53987518433602, 54.34368564236549, 52.325006454221665, 52.76323326172368, 53.94815775655932, 53.90531762953728, 44.85547611790319, 40.689275726195305, 42.5295929754934, 42.408156394958496, 42.70963368877288, 45.08481710187851, 50.79446623402258, 53.02791087858139, 54.7574290152519, 53.4020814587993, 46.90007432814568, 42.19558354346983, 39.5619551597103, 38.14642667770386, 40.10109670700566, 41.222478805049775, 39.63278139791181, 40.06352824549521, 46.26948664265294, 46.846114281685125, 49.26657361368979, 52.22439373693159, 51.46674479207685, 52.60983720902474, 53.6177098366522, 53.6847274534164, 57.21698653313422, 54.84547838088005, 53.34139062512306, 50.255920886993415, 50.53725680997295, 50.14791842429869, 49.25890930237309, 49.65353504303963, 52.42965529041906, 54.48218453314997, 55.5359959602356, 54.76215547130954, 54.74580311006116, 52.59173154830933, 53.407294288758315, 50.42181753343152, 43.66522896674372, 38.48941833742204, 39.346742553095666, 40.38843385634884, 38.40216521293887, 39.809472407064135, 40.74578531326787, 43.9500440320661, 49.46951704640543, 52.17513661230765, 52.47555094380533, 50.25103753612888, 45.52227120245657, 40.611295084799494, 41.36883812565958, 39.97273322074644, 39.06295122638826, 45.47927025825747, 54.85421742162397, 55.633031475928526, 51.779483210655954, 57.036996810666984, 56.54256636096586, 53.432577886889064, 56.72617250873197, 51.81666727988951, 54.37610010946951, 49.556079833738266, 50.4501135118546, 44.36539557672317, 44.21278007568852, 43.16904913994574, 44.44541585060858, 45.60409184425108, 45.1446097127853, 45.57924362920946, 50.267601705366566, 54.84201100564773, 58.97163137312859, 56.09267442457138, 61.655195451551876, 48.198912297525716, 26.81281258982997, 6.48359013180579, 7.722178043857698, 11.578182693450682, 15.948326722268137, 9.298253059387207, 8.058502164579208, 3.726682143826639, 0.19352009159422692, 2.5218347051451286, 33.47719407850696, 49.295359888384425, 45.93383373752717, 42.929360943455855, 66.60193181806996, 57.48574341497114, 17.478142284577896, 0.4800026851796335, 0.1289983126785486, 0.22592288351828055, 0.12910524323101968, 0.15171989828588503, 0.2703141547258823, 0.1624829739692711, 0.19994902484599622, 0.18833438114773846, 0.2675867897848929, 0.12550302886313972, 0.17266317931634767, 0.09748114137760094, 0.06028407546240957, 0.1403332423538931, 0.11273841824262373, 0.11288222826776967], [0.010389766783543654, 0.02814394444407475, 0.056171474167175835, 0.06865257096867408, 0.0873973481957951, 0.0160437724139962, 0.019567703129723668, 0.06212105471340399, 0.11733764241780005, 0.04560859258016271, 0.04896752040592894, 0.11648526234972863, 0.030642976879232356, 0.06047880735188242, 0.06023168653970765, 0.06418556973878896, 0.05488379911008862, 0.041953652210894136, 0.06022597535423214, 0.051891685673786755, 0.08049261305601367, 0.2025228810887183, 15.941765577562395, 40.773775346817516, 47.04722988990046, 31.924004131747832, 29.320968274147283, 38.183759797003965, 48.39668996872441, 36.006907109291326, 5.603421541952319, 0.30331418879570504, 11.162215336676567, 42.935515142256214, 41.87609864819435, 17.969450527621856, 2.5702715641067875, 6.876365494343543, 34.3980489238616, 47.25051456882108, 54.50172185897828, 52.789513141878196, 49.27570881382112, 51.195912976418775, 47.144555660986136, 46.42877801772087, 47.204069783610684, 50.730045226312455, 51.56549830590525, 52.344261369397564, 51.44941968302573, 50.009239104486284, 49.232111669355824, 51.61113508286015, 51.83541228694301, 50.64421984457201, 49.65005982306696, 46.45964314860683, 40.626517803438254, 36.90156444426506, 38.10348849142752, 39.04720291014641, 39.0295365548903, 44.74848170434275, 49.422119125243164, 51.10421580653037, 50.3402949917701, 52.016916044296764, 43.94826327600787, 37.82310962677002, 35.56085909566572, 36.916536131212794, 37.49566232004474, 37.548669230553415, 37.112937050481, 36.639863906368134, 41.46326918755808, 45.47914866478213, 48.58319082567769, 47.137405180162006, 49.53338892229142, 47.36059196533696, 51.15191967256608, 51.1255927239695, 52.32236277672553, 50.78769622310516, 52.79542415372787, 47.69371101933141, 49.159975359516764, 42.66333795362904, 44.11233994268602, 46.81113066211824, 49.34403650222286, 51.17395554819415, 50.16546318607946, 47.96633535815824, 47.70891412611931, 50.80190697023946, 47.42493060327346, 44.641377464417495, 41.18172537895941, 37.19730723288752, 36.16013450007285, 36.0880531034162, 35.25788737881568, 36.75081599143244, 38.13480077251312, 43.37306337971842, 46.176934396066976, 49.109200277636134, 45.39236230234946, 42.523878082152336, 38.19079260672293, 38.822953162654755, 38.255429344792525, 36.93903092415103, 36.875064911380896, 39.273182422884055, 51.04150887458555, 49.78242804927211, 47.39237493084323, 49.07973151053152, 51.44894115386471, 52.90649783226752, 51.269598622475904, 50.74906087690785, 51.12940919014716, 48.30220007127332, 50.57018510756954, 49.50916828647737, 46.28769820736301, 41.664706430127545, 39.496769289816584, 39.988077532860544, 40.94246472081831, 42.6499116805292, 46.84889131976713, 51.09177012597361, 53.77732284607426, 59.25774866534818, 56.24424265277002, 42.65789762620003, 20.909472896206765, 2.240354880209892, 3.0406613167255157, 7.179864279685482, 4.377074856911936, 4.120639120378803, 3.217903664035182, 0.655974613562707, 0.14619903969428233, 2.321297891678349, 25.429214162211267, 40.95432989058956, 38.43927867950932, 44.4711426765688, 55.5080843740894, 40.219677802055116, 6.134473200767271, 0.030140777516569343, 0.058721470601496205, 0.06543606654891083, 0.007848227959907344, 0.02997945089103474, 0.04931286135087571, 0.02791281571731933, 0.05082216564445727, 0.012504906814184882, 0.05682577071110568, 0.026399202179163698, 0.00495724962092936, 0.02309252346505321, 0.05330953056052808, 0.04130741874236734, 0.037780943657121355, 0.04220156975451016, 0.011077613190507457, 0.07059856453129361, 0.052826588733061675, 0.01903219043367332, 0.04819773993785343, 0.04760320974333633, 0.05004479707549176, 0.026080687718105414, 0.09528953236557784, 0.02257926562320321, 0.004515628660878828, 0.053336332146559036, 0.024160126359352184, 0.05426443617550596, 0.05168207252638475, 0.08024225552235881, 0.05118585439519056, 0.051374499716105006, 0.04813786250569167, 0.03409955410226699, 0.021219585962112875, 0.8266776956377492, 20.290283618434785, 46.70561890448294, 53.041462667526744, 35.024627947038226, 30.567013102193034, 40.55729973700739, 55.21299269891555, 37.714365836112734, 5.637364752830998, 0.27938785331864513, 14.525780139430879, 47.07587103689871, 43.1927441781567, 13.71620980001265, 4.096465798154954, 9.977954702992594, 37.161158669379454, 52.91659009072089, 53.95437863565261, 55.98602125721594, 50.71433221140216, 53.71194085767193, 48.3158185405116, 47.14159427150604, 49.64887134490475, 52.00500772845361, 52.11024884254702, 53.0387052412956, 52.839201727221095, 52.22462515677176, 51.39538903390208, 52.15565812203192, 53.23170154325424, 51.335631724326845, 50.66898961221018, 48.85380298860612, 42.96382681015999, 38.9602243515753, 38.35587732253536, 40.487175603066724, 40.516605146469615, 45.814723122504454, 50.86688887688422, 53.67826338737242, 51.50265016863423, 53.191838495193, 45.79460136352047, 38.996423905895604, 37.55486657542568, 38.07122307439005, 37.618448195918916, 39.20455271197904, 39.147639120778734, 37.08189541293729, 42.21132793734151, 45.854033116371404, 48.8384900554534, 49.63548037313646, 51.01276966833299, 49.44726544041788, 52.520807250853515, 53.17147354925833, 53.6926898648662, 53.04528305607458, 53.47956003681306, 49.58754508726059, 48.419392647281775, 43.03193876820226, 44.82091611431491, 49.483127670903365, 49.851081294398156, 51.80675937283424, 51.432526034693566, 50.8787932703572, 49.877000316496826, 52.21548603427026, 50.37503934675648, 46.00318516454389, 41.90328459585867, 39.574334159974136, 37.909280177085634, 38.14475574801045, 37.50111049221408, 37.974760224742276, 38.154789170911236, 45.10956725766582, 46.85302549792875, 50.7562505814337, 48.77903084601126, 43.98960897999425, 39.5994451738173, 39.6364252798019, 39.4721564169853, 37.876277354455766, 38.0823939846408, 42.183749752659956, 53.88586267348259, 52.1907711798145, 47.86097265058949, 50.54061828121063, 52.60045097720239, 53.235008101309504, 53.376538984237186, 51.891510025147475, 53.81724865205827, 51.25434060250559, 51.60497303931944, 50.62088958678707, 47.60795624025407, 42.3143333004367, 42.188766464110344, 42.86032722842309, 43.96828305336737, 44.578588162699056, 48.67286013018701, 52.643577437247004, 55.67994302318942, 59.84545307774698, 58.91384701575003, 43.13664643995224, 24.187609457200576, 3.729229723253558, 2.5471045749802745, 5.741665478675596, 8.755563728270992, 7.4613791608041335, 4.155953199632706, 1.1600060448531182, 0.022821146393975904, 2.7810996963131815, 26.338143041056973, 45.338245361082016, 39.38915906413909, 45.589551618022305, 62.70186816492389, 47.64430484464092, 7.550387055643144, 0.09785108523623598, 0.05329339291840311, 0.026526838173008254, 0.1401383036206807, 0.10636449010381777, 0.03899160389518065, 0.04121299457526015, 0.0198703691468484, 0.01263017846917313, 0.026543088813102054, 0.03607157167167433, 0.029845050340818784, 0.08359790449180911, 0.006882680904856253, 0.033909771140784986, 0.04097492892235037, 0.04299145620015841, 0.09613084246314342, 0.12562197933514274, 0.18043442118552425, 0.1215338966839256, 0.17337950216906686, 0.12745461486760648, 0.16211814757797027, 0.14615088340736207, 0.24557435644730446, 0.14283867162321845, 0.08556871930317533, 0.19946433633806246, 0.09632132256463652, 0.17154449176403785, 0.12166046973077521, 0.14659651675291602, 0.1681956916206306, 0.13848025952616047, 0.1291704832786514, 0.17638000809857923, 0.18639063222273705, 0.8883602760972515, 23.29857876223903, 54.519537264300936, 61.07508474780668, 42.85525952616046, 41.55757865598125, 49.363358097691695, 59.18880516482938, 43.5315389017905, 7.419470596698023, 0.5196677148342133, 16.936659082289665, 48.72949523310508, 47.7333701041437, 23.07306601155189, 6.538488605330068, 9.461859041644681, 41.56268950431578, 53.77208255952405, 56.348279599220525, 57.95084630289386, 53.52885638513873, 56.98769653997114, 51.58582795050837, 49.288013289051676, 50.45332201065556, 55.391660582634714, 55.46889597369779, 55.652643326790106, 53.08715435766405, 53.53445360737463, 52.61028043685421, 54.26088048565773, 54.459171987348995, 55.08292298163138, 55.15182725844845, 49.83828652289606, 43.57339843626946, 40.15850843921785, 41.06899646020705, 44.06984890660932, 43.70081270894697, 48.313049347169944, 53.992609977722175, 55.079400693216634, 53.70346461572955, 56.680916201683786, 46.96475421228717, 41.618010613226126, 38.87557568088655, 39.834030366713, 39.70094434676632, 40.26911535570699, 40.295379546380815, 40.54273597655758, 43.9298124467173, 48.98669289004419, 50.41568686885219, 51.916271948045306, 53.75828366125784, 50.981724108419115, 55.65862886367306, 54.96621285715411, 54.88766739445349, 55.724614897081935, 55.86802067295198, 51.8359653411373, 48.490705259384654, 46.78634520499937, 46.68186110834922, 49.87653355444632, 52.741091482100956, 52.24507247248004, 52.53909726296702, 53.14940629466888, 51.672637847162065, 54.82989088181527, 52.44394448495681, 48.46313099707327, 44.37819427059543, 40.256163689398, 39.58357918647028, 39.55000762016543, 39.28196853207004, 40.22414538168138, 40.37002225075999, 47.725180195223906, 49.01445150375367, 52.73256032697616, 50.70563239435996, 46.99154792293426, 40.163611442812034, 41.17025636857556, 40.347598060484856, 40.61852401302707, 40.15621777503721, 43.84676410305885, 56.4458603243674, 54.72483804149013, 47.562947042526744, 52.09162542896887, 55.43706986211962, 57.16364229879072, 55.56800642321187, 55.170376146993334, 56.61169421288275, 51.80761837190198, 55.89210402581, 53.18723755498087, 50.70551080088462, 45.17969139160649, 43.01135809190812, 45.36357210528466, 46.52066738374772, 46.42436142890684, 52.44264618042977, 55.85213115138393, 57.17689990997315, 61.31664391486876, 60.35367850334414, 45.50890376490932, 24.65506184485651, 4.475884754811564, 7.759968609579149, 14.802803416405956, 11.428559960857516, 12.828425438173356, 7.983496150662822, 1.8480035013729528, 0.2875054741819059, 3.9393096633495825, 34.15179467970325, 53.34115528291272, 50.33193249856272, 57.416007595677534, 67.48048782348633, 54.39377038709579, 10.224092256638313, 0.1469140295540133, 0.17419900174342817, 0.12706158877981286, 0.263792080504279, 0.22844775609912413, 0.22222152971211942, 0.16366828052747637, 0.10900442143000903, 0.09527772695066468, 0.21764962423232295, 0.12399989540778822, 0.1513442853766103, 0.1929585797892463, 0.19303011707961562, 0.15702010823353646, 0.13507424793656797, 0.09651003300302452], [0.02435871933196341, 0.05803116026424593, 0.05643714579843706, 0.01868220699590541, 0.03376648588586719, 0.08047446443308746, 0.03802484306957453, 0.056585770686187094, 0.023078632375766194, 0.03126929780738729, 0.04503569287818767, 0.13010710237487672, 0.06057110562499973, 0.006764234135663438, 0.024504159209168246, 0.07892115221869561, 0.09891157308893819, 0.019026477332978, 0.06017535992507493, 0.046079855397223465, 0.06747096461514313, 0.1203429976838731, 9.390299320220947, 34.886607585414765, 46.05863178929975, 32.60983055637729, 28.893088679159845, 30.947051548188735, 43.511036672899806, 41.78049087524414, 9.81392510475651, 0.36692574800502875, 17.803991225457963, 40.65781439504316, 33.86144122769756, 18.914982964915616, 2.9627738316212935, 5.140997632857292, 22.40839881281699, 49.44908542017783, 54.925078961157034, 53.423999663322206, 52.01313880182082, 51.384998675315614, 50.28499349471062, 51.58521213839131, 49.319180442440896, 51.38015062578263, 53.73065840813422, 53.21400773140692, 49.2225371637652, 48.257332078872196, 50.6120877881204, 53.4457492059277, 51.04385052957843, 48.97396479883502, 48.30816991867558, 42.37403177445935, 37.60257436383156, 37.66088824118338, 38.06507279795986, 38.24943204079905, 37.90771907375705, 43.698482821064616, 46.29402106808078, 51.869901687868186, 52.25308979711225, 51.73227748563213, 43.7270062969577, 37.945824899981105, 36.403976486575225, 36.30302644545032, 37.60881485477571, 36.55717249839537, 36.05070037226523, 36.43877575474401, 39.448171123381584, 47.27881446961434, 48.706015925253595, 49.93552600183795, 49.83265792169879, 52.18577800258514, 50.79282276092037, 51.88894087268461, 48.780682163853804, 46.561577704644975, 47.17192988241873, 46.19322792176278, 47.944825080133256, 44.19593349579842, 43.77034848736179, 48.43854950320337, 49.38673934628887, 50.336541283515196, 49.25496732034991, 50.09882603922198, 48.10528924388271, 48.45477242623606, 46.03719211393788, 42.27479580909976, 40.65263294404553, 37.15972308189639, 35.94823237388365, 35.50686767024379, 35.53734448648269, 35.6997972919095, 38.38410269829535, 43.29155260516752, 46.365467040769516, 48.37159072199176, 47.2001003449963, 43.21821605005572, 38.96669626235962, 37.71128677552746, 37.14699106831705, 38.14491656518752, 36.64318615390409, 37.14211948456303, 46.177738481952304, 48.34136885981406, 47.88091005817537, 46.74295594615322, 47.286965154832416, 48.205560714967795, 51.48257547809232, 53.91966173725744, 52.21169310231363, 52.949114384189734, 50.559214238197576, 51.08468632544241, 50.314756439578154, 48.63116533525529, 43.72437830894224, 39.16109677283995, 39.4053388410999, 42.34222527473204, 47.92087901023127, 50.80709234360726, 53.044851595355624, 55.770059477898386, 52.713462306607155, 38.66242624098255, 19.414167327265588, 3.357383392510876, 1.4535346555133022, 2.7577490912329767, 7.319147644504425, 3.6008061757010803, 1.5954111973124168, 0.792051195617645, 0.14719357503758324, 3.747356711856781, 34.912173594197924, 34.23647865172356, 32.91329060831378, 41.64582021774785, 51.92827047840242, 31.01183145276962, 2.313595582400599, 0.06512717223696171, 0.055558565523355245, 0.02776124713672025, 0.04275453584869543, 0.05180035267145403, 0.03057579479871258, 0.04273910683790042, 0.0045748027285651095, 0.03674791622606497, 0.023407188334291982, 0.020589237326696035, 0.043575050489556406, 0.03359307039288744, 0.0674861025125269, 0.07306433342877897, 0.08066550377876529, 0.02972622627332326, 0.014838872199517586, 0.05729635937079307, 0.02986317215066764, 0.007558681198485917, 0.014468083728946026, 0.05113800071300038, 0.06901207304890118, 0.03164666888844823, 0.0411646084619626, 0.03588942277635779, 0.04115675606073872, 0.10350599389282927, 0.029846856393100276, 0.013756602551908264, 0.005035224443887391, 0.022049883545766917, 0.03829162552832596, 0.02528245091408251, 0.04014584941849594, 0.05962135961219188, 0.05255779146306938, 0.056674376415509375, 12.05102735950101, 41.711433625990345, 51.82046021184614, 36.8527780040618, 31.489782064191758, 38.78646727531187, 49.59382872427664, 43.70241303597727, 10.338929449358295, 0.20403172189910568, 19.02476030011331, 41.89565558587351, 40.44513171718967, 20.129064398427165, 5.380784869194032, 6.206097151002576, 25.29843253474082, 52.338177773260306, 55.41304534481418, 54.776193634156265, 53.156670524228005, 53.415641092485004, 51.88423010610765, 53.44938524307744, 50.35681993730607, 54.4381873069271, 55.78046160359537, 55.07177952797183, 50.11209149514475, 49.795654281493164, 51.72562906819006, 54.956877616144, 52.761703537356475, 50.62126613432362, 50.869156006843816, 46.53047723154868, 39.82452254141531, 39.43967134721818, 40.39656492971605, 41.17709698215608, 40.03711500475484, 45.65733801934027, 49.43331356971495, 52.80110766810756, 53.51106843640728, 53.04977416992188, 45.982639789581306, 39.518161896736395, 38.23073410218762, 38.18014729407526, 38.01717281341553, 38.274025301779474, 37.424816469992365, 38.059946260144635, 40.84498205492574, 48.2474124047064, 49.75660316405758, 50.90459069898052, 52.25698471069337, 52.82867016330842, 53.174838942866174, 53.41675112324377, 51.849940746061264, 50.03175743164555, 48.783337608460464, 49.54170434705673, 49.290668733658336, 46.31484493132561, 45.63844396222023, 49.015942004419145, 51.474687591675796, 53.28772083405526, 51.12268624767181, 52.10255315226894, 50.72437347904329, 50.62142302913051, 47.62173552666941, 45.58071451802408, 42.38310029429775, 37.88481243195073, 37.20499115605509, 36.98920196102512, 36.66802652420537, 39.136903593617106, 39.6442307964448, 44.00795390529018, 49.31723494683543, 50.63083671754407, 48.01999730448569, 44.81156126145394, 40.252088346788966, 40.38313865661621, 39.532439324163626, 39.76452204488939, 37.80998929854363, 39.267494986134196, 48.15800197662846, 49.803196999334524, 49.34545247785507, 48.343534008149184, 48.65161265096357, 51.0502439929593, 52.89594665650399, 54.80456413761262, 53.921313055099986, 54.22359443479969, 52.37322022837978, 52.33125086753599, 52.35258856127339, 49.70767944089828, 44.514198533950314, 41.455636255202755, 41.20426331796954, 43.70441736713533, 49.902068184268096, 53.59138288805562, 55.5693910198827, 57.22403503233387, 53.04735014515539, 42.55058157828547, 21.51774229541902, 3.9347773646154716, 2.1277026928240255, 6.550762191895516, 11.195036749685965, 5.959968422689746, 4.034074862157145, 0.8446303226294056, 0.13834634735699625, 3.8653239559742714, 38.352735504027336, 43.14482458176152, 38.95895742600964, 48.105261787291504, 57.24210146934756, 37.35418635029947, 3.556700839150337, 0.01109735431870626, 0.13456087709674913, 0.02823427770166628, 0.005893159607019757, 0.10534704873158086, 0.06439408738045924, 0.049609777878128716, 0.037810418890008045, 0.04376953340045387, 0.043768311490214644, 0.04015486244292509, 0.08113658656516383, 0.00867621387324987, 0.06639579085693245, 0.0711761412000464, 0.014282188663679748, 0.03966176228958272, 0.32315712241876515, 0.16118954176143294, 0.09312621498059842, 0.11695331142794703, 0.0802178786046082, 0.23970353357013197, 0.18590914596232677, 0.12736043201819544, 0.136296495254482, 0.14221441721723926, 0.12697046262121972, 0.2899526041601935, 0.1081280398272699, 0.10899663797669834, 0.08249682163999927, 0.17528646355194433, 0.20855634443221555, 0.09254096211084435, 0.09199238953090484, 0.24322550022794356, 0.11182472815797215, 0.202883631892262, 13.913910004400439, 48.66371708531534, 59.87802836202807, 44.55629733300979, 41.47675821858068, 42.55598268201275, 55.47697605625276, 49.48447304387247, 13.043113427777445, 0.5256607900223425, 24.55066796272032, 48.86233806610108, 41.046427142235544, 23.551575560723585, 7.362521213869895, 7.849527107131097, 28.539510542346587, 53.19152862794938, 55.53227755331225, 57.8268954830785, 57.03970324608588, 55.02975133157546, 54.106782328697946, 56.30542770508797, 54.217926609900694, 58.4605622291565, 57.34619725135065, 55.31910850155739, 49.84593514473208, 51.48550156624087, 53.376115368258574, 57.96509235135971, 53.401983399544996, 53.83156138081705, 52.12370257223807, 47.64749765396119, 41.92741893952893, 42.1852598651763, 43.26757123393398, 44.141620436022365, 40.726797119263686, 47.958926000902736, 51.212473223286295, 53.7641554494058, 54.8946492133602, 56.00336990048809, 47.104300375907656, 42.82506904294414, 39.56496754000264, 39.88149104579803, 40.18893818701468, 40.58302264059744, 39.03147812812559, 39.55858192136211, 43.37317712845341, 51.18013720358572, 52.809038700595984, 53.31830747665898, 53.52129797781668, 56.44600152969361, 53.90590598506313, 54.49881146031042, 53.20214256163567, 50.903515969553304, 48.21359765145087, 50.47560891797466, 47.37073913697274, 48.07574595174482, 46.66156676507766, 50.12837325373004, 53.48497683002103, 55.04246373330393, 53.22477463752993, 54.030178439232614, 52.29325486767677, 53.76706192570349, 49.52017837955106, 45.65055624131234, 45.435802552007864, 40.04591288105134, 39.341980795706476, 39.65136558778825, 38.886530860777825, 40.069384344162486, 41.33351718225787, 46.97090448871736, 51.27293655949255, 53.01396685261881, 50.51407167988439, 47.669953223197695, 43.44793750393776, 42.098446046152425, 40.231178191400346, 41.92774449625323, 39.42231093683551, 41.843684181090325, 50.62660448012814, 51.05155014222669, 50.43599297923427, 50.75676441192628, 51.09078953343054, 51.104207961790024, 54.53112002341978, 58.8625894823382, 56.321054427854484, 57.576777704300426, 55.85309605444632, 57.03814606512747, 55.904875263091064, 51.502756072628884, 47.82551442423175, 42.78424501419068, 43.355349956020234, 47.62225327953216, 51.56294484292307, 54.35282084249682, 57.53667539165866, 59.323012982645345, 55.20482632421679, 44.91249953546832, 24.580230866709066, 5.264714091054855, 5.557142476881705, 9.95759956298336, 16.857180095488026, 10.95695476378164, 9.1483243819206, 2.776040329087165, 0.2714781487180341, 5.325617223016677, 45.30359514297978, 46.037105821794086, 46.074082005408506, 55.28568206294891, 63.045722746079974, 42.58750284871748, 4.851874334196891, 0.14617282416551344, 0.22364853701043516, 0.1651495728161066, 0.09390169514283057, 0.1861900857259189, 0.1552935145915516, 0.10965902057866897, 0.18987201154232028, 0.09630679753759215, 0.059563948983146306, 0.09508720088389613, 0.14244464196024403, 0.1446568280939133, 0.2179128673648642, 0.1982349490806941, 0.08977161555160439, 0.15546029193266747], [0.03803158081286857, 0.08530425809083447, 0.03590455301286232, 0.01998265465391019, 0.11453371464965806, 0.030122393321606423, 0.028579352431059368, 0.03022159213170169, 0.038504280044787356, 0.003867864452918331, 0.04561988854660623, 0.0254269695705584, 0.020090044859135826, 0.03111368811298763, 0.030531009298659144, 0.031213656841446797, 0.06142843462106201, 0.026391715584923665, 0.15518292213880247, 0.06736756572800298, 0.03419410467388169, 0.08936470795062282, 2.0394349002069045, 25.521093722312685, 47.07912268177156, 35.51858771231867, 21.48845591852742, 27.841873861128285, 42.323809746773016, 40.07019235241798, 16.593732141679336, 0.36235030319902206, 6.019472739388866, 36.92596158673687, 35.24101726470455, 11.437127397906396, 3.6190197015962298, 4.759644212261324, 23.668513182670843, 52.37127865514448, 49.96322970236502, 52.93518604770784, 54.43184875672864, 54.061910413926654, 51.234830733268495, 53.04130969509002, 52.44929067550167, 52.835561767701186, 49.5418651642338, 49.819259105190156, 49.79141812170706, 51.995448912343676, 52.70958700487691, 50.624808034589215, 49.91245854285456, 46.39150765634353, 43.58560092987553, 41.148953976169715, 37.02141246488018, 36.471794266854566, 36.85373506238384, 37.17057235779301, 37.74024563450968, 46.008044981187396, 50.08727465906451, 53.07565396831882, 50.77155566984608, 50.90508099525206, 46.60018167188091, 38.780540573981504, 37.613917858369895, 36.69301202220302, 37.52867298741495, 38.2608735945917, 35.451291607272246, 38.50986173076015, 40.47725200653076, 47.366036215136134, 52.223777924814534, 50.68414565055601, 51.84427684353244, 48.960726799503455, 53.16514676617038, 47.74810252651092, 44.41274250707319, 49.170871703855454, 48.30081547460249, 46.56715139265984, 46.74843549728394, 44.04318855654809, 43.85931960998043, 49.78278106258762, 50.57847699811382, 51.86007222821636, 48.12697995093561, 48.29714805849137, 46.57229754232591, 45.46590282071022, 44.17935363708004, 39.403220761206846, 39.17437399587324, 38.00462515123429, 35.64457816462363, 35.649175182465584, 36.59097548454039, 36.9426473494499, 38.296402423612534, 41.03314207446191, 47.02702576114286, 49.83863169147123, 49.41221121818789, 46.4989923661755, 44.28355924544796, 39.4116146333756, 38.39845072838568, 36.61341928666638, 38.92475828047722, 37.18022138841691, 42.03646867505966, 49.668039967936856, 51.3587462517523, 50.23216309085969, 50.840314818966775, 49.47978188914638, 48.77148812816989, 49.40027152338336, 49.19044825338548, 53.330635486110566, 50.95998633292414, 51.9303846359253, 49.43794588888846, 51.10189376338836, 50.29848252573321, 46.0561881526824, 40.92681838620094, 41.761757635301166, 47.40015299089494, 51.69051208803731, 54.08256561525407, 57.095957879097234, 49.6350646018982, 34.496833816651375, 14.213045643221948, 3.0755086339289144, 2.439423256343411, 6.823577746268242, 9.183024610242537, 5.3897038486696065, 3.6662004215102044, 0.41196157494860314, 0.12806796018154393, 3.054678151684423, 23.057739350103564, 33.90596405152352, 35.53893304640247, 42.07079725880777, 47.722720869125865, 20.795596684179, 1.525575357579416, 0.035272461527417746, 0.05032585175227254, 0.026412106930248203, 0.02001511188404214, 0.09605306155619123, 0.02722728768393638, 0.10588377759221101, 0.07664485984752256, 0.02664754873201732, 0.02738914674057836, 0.047350799094044396, 0.03690534346406499, 0.028884500573058764, 0.017169924535518213, 0.024479805274055372, 0.06042754457842919, 0.03301628279469667, 0.07238546461467782, 0.0372991930963772, 0.05023687063986736, 0.028462960692723433, 0.023832219660342224, 0.03167071064273196, 0.005469104564268022, 0.002538790483207953, 0.026415891404594147, 0.03761987367104139, 0.04504082949771997, 0.01686558461627893, 0.048650915419021924, 0.03520611831317506, 0.10463716867830485, 0.032598523558267666, 0.051364142207368735, 0.04718288028192136, 0.04956442930345094, 0.049485583534283985, 0.06642614326049244, 0.019528048503543102, 3.782102292583835, 31.597890430881133, 53.8857763813388, 40.47252555047312, 26.871981543879357, 31.8880497255633, 49.566760447717485, 45.79135364101779, 16.117732909417924, 0.3821647996383329, 9.584410555901067, 49.716712659405125, 38.73285631979666, 13.398100676075106, 2.8347427662341826, 4.967597492279546, 25.726700444375318, 52.68425241593392, 49.936553662823094, 53.84032003341183, 54.88616512667749, 56.49930654033538, 54.0808319276379, 55.932276941114864, 53.46544734893307, 52.896327126410704, 49.57265969245665, 49.8759412765503, 49.03359659256474, 53.404034799145116, 54.728560370783654, 52.62363610729095, 51.96067317839592, 49.40317799968105, 46.28731773745629, 42.83812269087761, 38.865099030156294, 38.28105026675809, 39.16886306578113, 39.42319739249445, 40.89580028287826, 48.07143526692545, 51.60330603199621, 54.714600655340384, 50.93160406235726, 51.86351214685748, 48.76516526745212, 39.981229074539684, 39.19787291557559, 39.30555374391618, 39.147764636624245, 38.731530558678415, 36.59245029572518, 40.25762673347227, 41.229111533011164, 49.67891277805452, 53.53337103320707, 52.34115092985092, 53.35310282245759, 51.93464825230261, 52.438088386289536, 51.045584217194595, 47.255590115824056, 51.037668874186856, 49.29303392287224, 48.23063642747941, 46.70647005881033, 45.966507081062566, 46.065935242560606, 50.13601010845554, 52.651504547365256, 53.08119235500213, 50.768535444813395, 50.56739630237703, 48.21044014346216, 47.56360207834552, 46.02811182698896, 41.369348033781975, 40.61218938519878, 38.32929541987758, 37.02977103571738, 38.631086503305745, 38.08572799928727, 38.40340860428349, 39.21776717708957, 43.80892107563634, 49.640206829194106, 50.86244875384916, 50.668056088109175, 49.120233904930856, 46.000329679058446, 40.10168506253151, 39.74500433091195, 39.005943498303814, 41.01837435076314, 37.747647147024836, 43.37455388038389, 52.126005003529215, 52.409615901208696, 52.65989449716384, 52.55217444512152, 51.57974435437111, 50.8900426280114, 51.90409298866026, 51.803527339812256, 54.44411400825747, 54.15774176197668, 54.28651317473381, 51.94642712993007, 53.075622589357444, 52.6962980147331, 47.66362644010975, 43.78665770253828, 44.96471412720219, 50.618924479330744, 53.47346075119511, 57.35616791632868, 58.53567561795635, 52.87795474452358, 35.97655973126812, 16.4274001121521, 3.546992237529447, 2.4443120004669314, 7.158218679889557, 10.95257249570662, 7.409769594669343, 4.509984370200865, 0.4595695267761908, 0.10359238562805038, 3.341634831120891, 30.232268225762155, 38.932877586733916, 40.66776152580015, 48.32641286234702, 55.24645443885557, 26.242599987214614, 2.2333995373018327, 0.048562367146293965, 0.07556230866260107, 0.03986368391422495, 0.04828844857852786, 0.07143979035918752, 0.018918652372855334, 0.03447861057676135, 0.04637447366070363, 0.04153947443551114, 0.035186192366264524, 0.013749097763080032, 0.12603502330039779, 0.03928218104486023, 0.027281526708975438, 0.020952872451274626, 0.040178538390224984, 0.08830421243704135, 0.17601409386242592, 0.19715721658881635, 0.20090237530248783, 0.21277315283734954, 0.18504475363560263, 0.1282784811431362, 0.14110492272002084, 0.15597979147588054, 0.16475543590082278, 0.09248404943894956, 0.123826322866784, 0.05721217779923351, 0.27989494223748485, 0.0929196929979709, 0.1628340260996934, 0.11394067066571406, 0.15368773301522579, 0.16234605873544372, 0.37274608568799117, 0.14593665458021626, 0.17659846573106705, 0.16180362251977767, 3.662996825671965, 36.2056653730331, 62.7336315185793, 49.979911542707875, 35.71738912213233, 38.815430056664255, 55.596808387387185, 48.77666565679735, 20.84656592338316, 0.522456458739696, 9.387148676380034, 49.445986747741706, 38.70221084164035, 16.170607439933285, 7.474476445105768, 7.525380474905814, 26.548682143611295, 54.92424349631033, 50.04915706572994, 54.51330461809712, 57.60729374424104, 59.18969946522867, 55.373884401013775, 56.219296378474084, 56.84293362402148, 53.51695199166575, 49.65865373611451, 50.06878852844239, 50.56587442275017, 55.133882414910104, 58.088788217113866, 55.33987352924963, 54.33989663277903, 50.88232340351228, 48.720258051349276, 44.76415549555133, 41.1349432699142, 40.180689442542295, 40.33880410655853, 42.40307300321518, 42.80539051178963, 49.3215613211355, 54.85266808540591, 56.870378448117165, 51.86221384233045, 55.57178366568781, 50.76906888715683, 42.4875137882848, 40.540029541138686, 40.46495537604056, 41.232618131945216, 41.22233759972357, 38.318438299240604, 42.87189429806125, 41.76879044502012, 52.94396823452365, 56.16148456450432, 54.109775097139426, 54.64087186321136, 52.676144876787745, 52.98128566434307, 52.273144875803304, 48.65637048598259, 52.74916764228575, 49.993475098763746, 48.63271859384353, 45.487271893408995, 49.243051159766416, 46.59992279544954, 51.112386103599306, 53.89162463526572, 55.96289496267996, 52.17763908447758, 52.13788586278116, 50.928827024275265, 49.20120339239798, 49.30504422033987, 43.08414159282562, 43.688716119335545, 42.51748461877146, 39.40693524576003, 38.87077077742546, 41.01412642386652, 41.2337673864057, 42.135669339087706, 43.94676885297222, 52.59206887214415, 53.17124212941816, 53.89090684152419, 49.8138697685734, 49.291276701035045, 42.61828560982981, 41.71617969389885, 41.24942156576341, 43.79165872450798, 40.914231500317975, 46.1697760705025, 54.21979758047289, 56.060977751208895, 55.70501481333087, 54.836166674090975, 51.84645375897808, 51.711771334371264, 51.64504397299982, 50.55995948853032, 54.68724604575865, 54.3742173717868, 56.09389428169497, 52.75524731605284, 54.36976548164122, 54.63678867586198, 50.4430022547322, 45.4914649071232, 47.047378939967004, 54.060557196217204, 57.57479690736341, 59.77465821850685, 60.71984744841053, 56.553729426476266, 39.681932618541104, 18.273969619504868, 4.781945338172298, 5.544056469394315, 13.935937054695623, 18.598573207855225, 13.0818134930826, 6.321559471468772, 0.9598199770815912, 0.3722963920764385, 4.86828209892396, 34.249893157712876, 45.77194575340518, 45.25266708866243, 55.60364507859754, 62.012260575448316, 31.483729847015876, 3.1598922994828995, 0.15173244680608475, 0.16916658549058824, 0.15373651749424397, 0.11230042279367486, 0.1895638450138992, 0.09466816611107319, 0.1791515916345581, 0.21528497127996338, 0.13973272135180814, 0.11647341863041925, 0.18475745534223897, 0.20215670638267072, 0.08081932657308157, 0.09582664427017012, 0.11880965738166725, 0.10831076711896928, 0.18161514653794228], [0.027590518697134914, 0.04376328212299174, 0.035239592525026495, 0.010106026968588273, 0.008426698078701814, 0.03381230943505803, 0.055047875991271394, 0.04110328695406357, 0.049852773306831244, 0.024353151787973704, 0.028216673001166315, 0.03300715485707887, 0.028362607005082315, 0.07402761238476924, 0.011417175917285345, 0.022712572582907254, 0.07569624381440301, 0.05690964201705591, 0.024574710161335046, 0.008875010816770936, 0.06060869755944418, 0.07690045742257949, 0.4128342410249095, 12.604743453764147, 40.521441428892075, 39.574392995526715, 26.42107371361025, 27.68685002480784, 35.45555130127938, 44.04056449090281, 18.474188966135827, 0.8342250712936925, 0.07823918074850114, 0.8926202152525226, 9.678377797526698, 14.441447219540997, 3.624685810458276, 2.648635126890675, 23.80566473930113, 48.93878506075952, 54.43502979893839, 53.57688188552857, 52.191704703915505, 53.16543309919296, 52.417692061393495, 52.28510026008853, 52.44986334154683, 51.7022164406315, 50.4337925295676, 49.710954619992165, 51.666165936377745, 50.110891249872026, 49.843985726756436, 50.071651858668176, 45.977630922871256, 43.24086773780085, 38.84398098914854, 36.32239903173139, 37.463432204338815, 37.41952519262991, 36.08400913976854, 38.07699288091352, 41.46953713509345, 44.51243738974295, 51.197960453648726, 52.03408033617082, 53.400379150144516, 50.7695121149863, 48.0572598211227, 38.19957087116857, 37.2102588991965, 38.91614867794899, 38.38886445568454, 37.81064041199223, 37.83116225273379, 34.52733808948148, 37.48617802896808, 46.949892351704264, 51.502112803920625, 50.3425189756578, 52.3591899102734, 49.512525835344874, 49.10653698828913, 44.079862717659246, 50.201368562636844, 49.79397550705941, 50.715159831508515, 46.39797956712785, 46.32241902812835, 43.645389618412146, 45.75384401505994, 50.3549881904356, 49.46924640286354, 51.91031386775356, 47.80686355406239, 47.611407926005704, 45.96105890889322, 42.89814672162456, 42.471820385225364, 40.05371055295391, 36.285917066758685, 35.902968222095126, 36.52710360865439, 36.35777096594534, 36.552379362044796, 37.459902071183734, 37.00944531348444, 40.60402693287019, 45.63424310376568, 48.279332653168716, 50.69031946120724, 49.07886074435327, 47.599032848112046, 46.12114652510613, 40.063324282246256, 38.32223515356741, 36.98442843652541, 36.47835246978268, 36.254079188069994, 40.57634676656416, 47.07727916779057, 48.305114392311346, 50.54052414432649, 50.66623610834922, 52.060701462530325, 50.87503563973212, 48.168568841872684, 46.71111022272418, 49.59391501642043, 49.617531607227946, 54.47293950665382, 52.44658816245295, 50.441158740751206, 50.73588955786921, 47.29439020156861, 43.32875628625193, 48.82249070752052, 53.14081238162134, 53.62622137992613, 55.413351289687625, 45.947593412091656, 35.77575791266657, 13.37442917208518, 2.841504196966848, 0.43566130161766087, 4.173910790874112, 10.367314661702803, 5.004885994618939, 1.6396874021137915, 0.3940867824900535, 0.11491820651797519, 5.723246518642672, 30.58592284879377, 38.37885064463462, 32.39635555974899, 37.85779906857399, 45.042922266068004, 14.02340296776064, 0.45381948532116034, 0.07900238052130708, 0.013072606694373875, 0.02258617765150003, 0.042285444890900005, 0.036954863387490475, 0.03517902561373288, 0.053588823235083016, 0.03577545953674182, 0.03079165539313709, 0.025101951023022977, 0.023533661789711446, 0.05669321834800705, 0.07899120329849182, 0.056722207115061825, 0.13423492200672626, 0.043365736116444877, 0.05530716611012336, 0.03347712298554759, 0.04818120776044746, 0.063288637827481, 0.052964384968002, 0.025997712735026598, 0.028610334941937078, 0.03188608860176417, 0.04352867535706009, 0.03168480091487929, 0.05013639820859798, 0.016744818515895356, 0.018494356491212404, 0.0971354135582524, 0.05278492121086006, 0.038254523890153054, 0.023590005641322465, 0.05222875669959092, 0.016550578837913853, 0.025354183556872512, 0.038381606385472326, 0.04250127101136793, 0.07105711411925093, 0.7386541931379227, 19.15715206053949, 49.84401710571782, 45.24809360504151, 31.349676962821718, 34.635870072149466, 42.01501723258726, 49.24471424471948, 22.139822360007994, 1.2194879304978157, 0.006038479304181473, 4.300925472090322, 15.750225455530229, 14.857453800016835, 3.4372891822168907, 3.4720595229056577, 26.624807503915605, 51.027364807744185, 53.902721020483206, 53.63680785702121, 53.92553744777557, 54.37779849575412, 52.34565773317891, 51.85888767242432, 51.33362347079862, 51.3740199612033, 51.86376317854851, 50.7265111707872, 52.205142744125865, 52.09400238529329, 52.127895585952274, 52.4380373954773, 48.97196831241731, 45.05516006100563, 41.37222705348846, 39.93547462647961, 40.30949615663098, 38.61065879944832, 38.50906548961517, 39.2804152734818, 41.24259664166359, 47.3201915525621, 52.77670268089541, 52.263460543847856, 53.64678636673958, 53.99782673005135, 50.13919899540563, 40.489203468445815, 38.17619354494157, 40.2520255888662, 39.11710346898725, 40.32762535156743, 39.110855133302756, 35.81774688536121, 38.960659734664425, 48.65206372353339, 52.642326201162035, 51.72340116193218, 53.37436206879155, 53.89684530996508, 50.58297595670147, 47.01410547379525, 50.94472046821348, 50.96149644544048, 51.160290010513805, 47.68561132492558, 46.62689301275438, 45.07299900054932, 47.123323871243386, 52.0145586998232, 51.92375975270426, 52.26708481388708, 49.33545827865601, 48.41075166579216, 48.40737842744397, 44.857653033348825, 43.09109203277096, 40.204023622697406, 38.38469497619137, 37.62336292574483, 37.81728098469396, 37.17013697470389, 37.51808651031987, 38.13827991485596, 38.300587592586396, 43.27576898759411, 46.59772234578287, 50.91753844291934, 53.2163493863998, 51.15943885618641, 50.205863598854314, 47.338065793437345, 42.05129915668119, 38.95879660883258, 38.37655998045398, 36.84903214054723, 37.87329635312481, 43.84621497123472, 48.84487175172376, 50.697760197424124, 50.440158536357266, 52.01174243803948, 52.76958750140283, 50.84522954879269, 49.35678812765306, 48.37041401094007, 50.79312478342364, 50.991498654888524, 55.55599612574424, 55.46823701550884, 52.8986648590334, 53.26097026948006, 49.354909312340524, 46.53575281943045, 49.64606685023154, 55.52254223054456, 55.45819967023788, 56.908903967949655, 47.9520736202117, 38.97945965490034, 13.346092989367824, 2.0348565136232684, 2.880004221393216, 8.64747497343248, 8.984970411946698, 5.552998492794653, 4.922735873729953, 0.5300028538030963, 0.15944614015038938, 6.152279290460772, 32.091118674124445, 41.42864642604705, 35.903399682814076, 46.06369949156239, 50.975962146635986, 18.15816948490758, 0.7584656558690533, 0.03320643730882195, 0.029613979070657687, 0.07269546975411716, 0.027618463669392853, 0.04968215403477511, 0.06202284990239048, 0.03196588240473742, 0.02955340832892445, 0.08716003713949073, 0.021636284166766752, 0.014655327108959037, 0.06504551492511265, 0.021723208333095236, 0.02467817991160818, 0.042905593065605055, 0.012777117005879841, 0.13503497826956934, 0.1350001059472561, 0.16755148828510316, 0.12168088597395729, 0.10275265367160882, 0.16831566098957293, 0.12015145272016527, 0.08185958970458278, 0.13395393627785868, 0.11328754240586875, 0.1245133811607957, 0.09620737464677903, 0.16272092087855264, 0.20813502671737827, 0.2938738405223816, 0.13652181703477137, 0.07027663906375248, 0.15860983260696934, 0.11935335764240836, 0.12577001050475145, 0.08043717893381273, 0.1208492898712716, 0.15254829980192647, 1.0014615748678486, 20.57965255552723, 54.99265747685587, 53.18011060837777, 38.135695072912405, 39.410516369727354, 47.67552298884238, 54.69690292112289, 25.11862128011642, 1.0686924092231258, 0.2009022680501784, 4.048182647074423, 12.987022553720783, 18.982834085341423, 8.804935582222479, 5.169413733866907, 29.96795735051555, 52.22963010111163, 55.46993147942328, 55.499376712306855, 52.23347794625067, 55.20668160530829, 53.05592444635207, 52.427851000139796, 50.78653520153415, 52.22323663773076, 52.97695536767283, 54.42678889920635, 55.2468192192816, 53.54260037022253, 54.64025997346448, 54.05545419262302, 50.993899145433986, 48.437666969914595, 42.547196572826756, 39.930046066161125, 41.58711018100862, 41.39975424735777, 40.64671408745551, 40.1012889031441, 44.25263135663925, 49.924033457233065, 55.44533037370252, 54.22847386329405, 56.9929446712617, 55.54030272268481, 52.711446208338586, 42.34467675608974, 40.35323842879265, 42.62466730610017, 41.710558937441924, 42.397491470459975, 41.5688358583758, 37.77355047964281, 42.20964524053758, 50.521916420229026, 54.77897067223826, 53.55745046369491, 54.94349841148623, 55.249659015286355, 52.484654764975275, 50.46288867150584, 52.874020607240745, 53.019924932910556, 52.60944497200751, 49.12438377257317, 46.469252955529, 46.86660866583548, 50.05967686253209, 53.65390154623217, 54.27311435822518, 54.69065066306822, 50.637845993042, 51.31192884137554, 49.548721467295, 45.66440220802061, 45.52140435864849, 42.64539703246086, 40.55959824592837, 39.33290443112774, 40.276340361564394, 40.02420256214757, 38.9168272479888, 40.63826530210434, 40.73796802951444, 45.462564883693574, 48.34623652119791, 52.00292494989211, 55.15301573661066, 53.50021523814048, 52.94616476182015, 50.3099750703381, 43.222067817564934, 41.86759494966076, 40.55837446643461, 38.596267623286096, 39.94499029651765, 44.969307222673976, 50.49354591677266, 53.13742345379245, 52.34950165594778, 55.079667414388354, 55.55350934305499, 53.511303778617616, 50.043163684106645, 49.195629704383116, 51.801585766576956, 50.349269374724365, 58.08623083176152, 57.760285792812226, 54.01788965348275, 56.03643155867054, 51.83757743527813, 47.28609831102433, 52.05056998037523, 58.55766050277218, 57.653907191368845, 59.01693867098901, 51.82410801610639, 43.30541426135648, 17.10899429936563, 4.572787400214903, 2.1816649456177992, 10.705062112500592, 21.08105305702456, 15.219746462760435, 7.702279369677267, 1.4530946146095953, 0.3781292936013591, 8.253438568884327, 43.051499628251605, 50.055323031640825, 41.995291632990686, 53.3624812095396, 59.58316810669438, 21.200181322713053, 1.0496429281850015, 0.12752872621340136, 0.09778954539327853, 0.10263383343455293, 0.11584314277335522, 0.16212795350340106, 0.18602723075497538, 0.1340247074803037, 0.12425153996915587, 0.14285485140017926, 0.08099770248537103, 0.152056364102229, 0.1738574337815085, 0.18275378301980036, 0.15469659420271076, 0.14053800233429478, 0.12977785310677944, 0.1997583762051598], [0.030069809046483813, 0.04079287578802436, 0.06742692988125548, 0.020038291789411057, 0.07255084767577148, 0.06854125073239689, 0.004880987004482098, 0.025067582403519945, 0.03998528122000637, 0.04741693546454753, 0.0453496701835144, 0.05643753650327844, 0.05031662805366421, 0.04710174774030044, 0.05179872856505456, 0.022992252131863948, 0.0252079067286104, 0.09640213717976887, 0.058069150564411, 0.005347895090498271, 0.045451743738545526, 0.043348464664191975, 0.24379758404627924, 8.519567462705798, 34.98412947500906, 50.94726608645532, 37.19895462835989, 33.52655710712556, 41.77794133463214, 42.28410359351866, 23.63506320984133, 2.079497253702533, 0.20811627288499188, 1.1567555031468792, 6.904388377743383, 29.143781085168165, 4.524316220514236, 3.2108438880212846, 31.270041081213186, 47.28782023152998, 59.14821255591608, 56.58200187067832, 50.21687369192801, 53.27159597027687, 51.007290117202274, 55.048237462197584, 56.905142414954405, 53.35602891060614, 54.699032768126465, 50.41316086246122, 49.53280448913575, 47.894304952313824, 48.44907322237569, 43.56107434918804, 40.633754576406176, 38.560326945397165, 36.58205601476854, 36.566197872161865, 37.37635166414323, 36.58801017269012, 37.60711646849109, 37.49204197237569, 39.07897410854217, 46.96421292520339, 50.92539495037448, 52.2743647329269, 51.02500354090045, 51.15224130692021, 49.3800477827749, 43.95644141781715, 38.860482400463475, 37.16615184660881, 36.479764523044715, 38.012520882391165, 36.01116288092829, 35.97984275510235, 35.31515006096133, 40.07491488610545, 46.60292733100153, 49.94324914870724, 49.27273173486033, 49.20007767215852, 49.99969205548687, 46.99180287699546, 51.43189453309583, 49.49891128847676, 51.66698178937359, 48.13576213775143, 49.573942307502996, 40.86708068847656, 44.28979973639212, 49.80382457856209, 49.44490025120397, 49.79356365819132, 46.35326062479327, 44.46460408549155, 44.69112488531297, 41.3001182002406, 38.96194627208095, 37.232969422494214, 37.2941074063701, 35.83391097284133, 35.669159658493534, 36.78779217504686, 36.920050574887185, 34.87384419287405, 35.91171902994956, 37.76661180680798, 40.65481378186134, 45.17622009400399, 50.17091528061898, 51.28240516108852, 49.634523314814416, 49.24593802421324, 46.823525351862756, 40.471309615719704, 37.9964352423145, 35.625586048249275, 36.004718426735174, 37.60351965504308, 38.82352975107009, 41.35328985029652, 45.61832220323625, 46.954956131596724, 48.48836752676195, 49.2454202713505, 52.18811181283767, 50.57011058253627, 48.937443610160585, 47.97129715642622, 50.994954263010335, 54.11902404600575, 54.862481855577045, 51.6221373311935, 51.34401775175526, 49.09942573116672, 49.34597807545816, 51.2095824364693, 55.93316339677381, 51.48577613215293, 41.63078577287736, 26.373587539119107, 9.717156310235302, 1.4583220308826816, 2.7318278628010906, 7.596198378070709, 4.654031453594085, 3.6712671431802937, 3.8919382181859787, 0.4608473614338906, 0.06776036965029855, 9.68377007592109, 38.81539083296253, 25.706062893713675, 30.046367491445235, 40.364142617871686, 36.87217804693407, 8.768530103468127, 0.04527109254512095, 0.05662266931106007, 0.012589887032405505, 0.04533600700538486, 0.057067858325617934, 0.04445782126558404, 0.04629865393883759, 0.015236360749470131, 0.04840018250228417, 0.04765421587733492, 0.03193009843779428, 0.037622769483395165, 0.03358046441609341, 0.07218631239788187, 0.022008959128851854, 0.03687467696445604, 0.03421581560565579, 0.07537935920540365, 0.046164465978020625, 0.03733694207884612, 0.0317934934695762, 0.03555857238449878, 0.06964205779255399, 0.019357000222249378, 0.0685884494094118, 0.04094792815345911, 0.026194746718711914, 0.0022882038413832386, 0.025325020504814964, 0.016736623290325367, 0.015150223738483846, 0.038638012183289376, 0.02025396852273374, 0.07890397652743325, 0.02477022729093029, 0.09441084483818662, 0.08362199029614849, 0.033470932995119405, 0.04709737720869241, 0.037754655349999666, 0.3385580024651943, 11.017290622957292, 42.50397989826818, 55.83692019985568, 39.788550484565, 32.851138691748346, 44.891797265698834, 47.388001488101104, 25.560035013383438, 1.3043278167324683, 0.34775041404270357, 2.041569282450984, 10.060441167123857, 34.076673446163056, 3.2712827094139594, 3.399647911710124, 34.54994663115471, 48.18678432895292, 57.2720762222044, 55.790259684285815, 49.37841215441304, 52.85204748953543, 52.65845890968077, 54.85799858647009, 56.500691137006214, 54.63219165802003, 55.55063424571868, 53.11190843582154, 52.160592463708696, 49.8900382749496, 51.0495928795107, 46.28125375316989, 44.1269507715779, 40.171114936951675, 37.8904841792199, 38.749769579979684, 40.1421364661186, 38.29132687660956, 40.2545633623677, 40.1940921814211, 41.006505258621715, 47.74787110667075, 52.3953620080025, 53.1391453742981, 52.30734402133573, 51.97955154603528, 52.11705415479599, 44.68321346467541, 39.23983443167902, 39.23312325631419, 39.41516045601138, 40.36482511028167, 37.83921880106772, 39.18318363928026, 37.346016053230535, 42.804374617915, 48.63504848172588, 51.77863205632856, 52.51557873141382, 51.9536482134173, 52.59697967959989, 49.090392512659875, 53.27562816681401, 51.1076831817627, 50.603140861757346, 50.20394555984005, 49.10079071598668, 44.01225674536921, 44.76437122591081, 49.412564231503396, 51.70697427565052, 51.590876040920136, 49.245926257102724, 47.429645292220584, 45.789121812389745, 42.74186772684897, 41.38456683005057, 40.5227985689717, 37.90054898108206, 37.30713752008254, 38.36157652639574, 38.384436099759995, 37.10737512957665, 38.347142204161614, 38.125959750144716, 40.521735606655, 42.375192796030355, 47.58309625810193, 52.94456051241968, 52.99103275422127, 51.92963938559256, 51.3576989789163, 48.33211991094774, 41.6178301841982, 38.65441676109068, 36.83626090326617, 36.681578313150716, 39.57307900151899, 40.981562906695956, 45.46592635493125, 48.35375570481824, 48.48472756724204, 50.41531424368582, 52.45400928681897, 54.557760761630156, 52.23508219565115, 49.08931386086249, 49.573534381005075, 50.969152912016845, 53.638278745835834, 57.45747097076909, 52.501505267235544, 53.47718308048864, 51.198568421025435, 51.81092100758707, 52.8630183589074, 56.67737822378836, 55.93223771741314, 44.52593426550589, 32.2969921173588, 10.566297481136939, 1.0004210436055738, 3.2631918403410145, 9.484371485248689, 8.604214172209463, 5.617539623091298, 3.6823630381015042, 0.1287639817042697, 0.13277492696239104, 10.116989977898138, 45.44445922297817, 31.940405522623372, 34.20555860765519, 44.68275062499508, 45.295048298374304, 11.685013348056424, 0.19405753291662664, 0.025647030242027778, 0.049641884623035315, 0.014484812216382596, 0.008598119827858623, 0.02971000244630681, 0.030575235554527853, 0.04343504409095453, 0.03352267074308569, 0.04382593662387902, 0.050015792986678506, 0.07390257151376817, 0.04028199856439906, 0.02606797448900198, 0.03586493860629778, 0.040063517949273514, 0.1037871481610402, 0.05110080714427656, 0.11501327036849915, 0.10006815901086216, 0.10313095554949776, 0.11136625517880726, 0.17571888954168366, 0.12473447413574304, 0.206490327874499, 0.12195527568579682, 0.12616126692943996, 0.14939005636880476, 0.2359318835360389, 0.11523231022780943, 0.145434912955088, 0.20776623199062966, 0.19385353902414923, 0.17157061536225582, 0.18405009571823383, 0.2606981271697629, 0.19266715994285, 0.1184613861504101, 0.12852528402882238, 0.08292296570875952, 0.49752118546635876, 13.811288052989593, 52.497598586543916, 63.18339793912826, 48.82420086091565, 44.07102561766102, 53.55501074944773, 54.07755674854402, 31.38394867220233, 2.804276981661397, 0.5297320264001046, 3.4090383110507845, 11.567759975310295, 44.782578868250695, 8.991873783449973, 4.9337351802856695, 39.18629800119708, 48.516843934212964, 58.41417627949869, 56.31641426394063, 51.35571033723893, 53.182483642332016, 53.42729445426695, 55.43735619514219, 60.61385323924404, 56.14803083481328, 58.11998674946447, 54.59822393232777, 55.04567615447506, 50.52481897415654, 53.14200478215372, 47.12912897909842, 45.384850963469475, 41.54889845078991, 40.455078847946666, 40.370524314142045, 42.608542442321784, 39.931077649516446, 42.50934570066391, 43.16088668761715, 42.72172243364396, 51.26191862167851, 55.147089035280295, 55.915469584926484, 53.04047423024332, 54.94156468299128, 53.59707032480548, 48.598813626074026, 41.92142163553546, 40.60067722874303, 39.666847182858376, 42.208358703121064, 39.733347046759825, 40.33461109284432, 39.12931380733367, 44.735816371056345, 49.44983459288075, 54.47139409280593, 55.68212778337541, 54.275150068344615, 56.19586413906467, 50.95638559710596, 55.042903038763235, 53.10964522823211, 52.72726512724354, 51.97255796001804, 49.92227623539586, 43.657854910819765, 48.50868540425455, 49.99997446613927, 54.15154441710442, 52.81804446251162, 50.85456086743263, 49.18363509639617, 49.6610071582179, 44.11440703176683, 44.02214111820344, 41.90847781396682, 40.42954029575471, 39.631192837992025, 39.54038212376256, 40.12667448289933, 40.24472605797553, 40.545795425291985, 39.53355719966274, 41.21499884513117, 44.311125663019, 49.135460545939786, 55.340669770394605, 54.79072209327452, 53.75825228229646, 53.905376465089866, 50.41387081146241, 43.686982431719386, 40.9159141971219, 39.079680135173184, 39.3136965843939, 40.6795286363171, 42.45351468363116, 45.72567355248236, 49.741270619054, 49.69373933730587, 52.82657954000658, 53.508969968365086, 56.86935078713202, 55.04131055647328, 50.64669486015074, 48.23517068739861, 50.00262991074593, 56.32693013837261, 58.79052377516224, 55.592434944645056, 55.16981132568852, 52.7554944253737, 53.565734509498846, 56.37088029615341, 57.98258612232824, 56.14326123268374, 47.50306813947616, 33.05903411680652, 12.599644372540137, 1.9507264538157372, 4.231450000116903, 18.638308778885875, 12.43170613242734, 13.45260299021198, 10.570225734864513, 0.9356463484225735, 0.2409391874267209, 12.674403767431937, 50.55246776150119, 39.31159027161137, 43.307367601702296, 52.843943872759425, 52.16762919579783, 13.803047153257555, 0.5020046384344178, 0.16319407210234674, 0.1169644733290038, 0.09656529858588211, 0.06688595689352482, 0.2345050447770665, 0.06790666180031915, 0.0944004413641749, 0.23433264435058643, 0.1258478373769791, 0.1855562705426447, 0.2577649603687948, 0.14918934133264328, 0.25629017982752095, 0.16069507797158536, 0.1389912708151725, 0.1941403163777244, 0.17067300546313488], [0.05752875597306317, 0.07799057755619287, 0.017768706518015074, 0.062261953604437655, 0.04702434987731038, 0.016236657073961634, 0.07637270711242192, 0.06094494121029012, 0.11019030255415749, 0.029022882865261168, 0.02509734108893862, 0.023380723826947714, 0.11450318604587548, 0.0643122002422329, 0.05038912295393887, 0.013157785137844904, 0.013410026290183587, 0.09061016773264255, 0.043252171242549535, 0.040782870679733255, 0.033833166178796566, 0.028127471638482907, 0.08470742963254453, 4.25134769370479, 29.656611373347623, 48.102998579702074, 37.93352042475055, 29.45956914655624, 44.870526252254365, 47.99470193924443, 31.676208396111768, 5.316727661317395, 0.17120088600823957, 0.8954059560933422, 5.9300912387909435, 8.728737658069981, 5.4985957088009005, 5.182500231650568, 23.14538863397414, 47.838034629821784, 55.16525353154829, 49.56175550337761, 54.06153778876028, 54.41776352543985, 57.24654159238262, 51.65335155302479, 51.8797742935919, 51.314698034717196, 50.16746751723751, 50.21517138327322, 46.643798428197066, 44.73164689156317, 43.143942048472745, 39.13298514581496, 39.09587560161468, 36.220707662643925, 35.53400262709587, 38.05300366493964, 38.95479971362699, 36.54704101624028, 37.43730921899119, 38.00828472260506, 39.506465388882546, 43.334027951763524, 52.70103231553109, 50.06401892631285, 50.252551571015395, 52.72009895693872, 50.84476278674219, 45.665912320536954, 42.80342148196313, 37.10335077777986, 38.54353920105965, 37.20591683541575, 37.610834875414454, 34.53726953075778, 36.606327641394834, 37.227623231949345, 40.443943239027455, 44.28909763213127, 46.033450172793486, 48.75018965813422, 48.34540890109155, 50.568898570153024, 50.93561272467337, 50.29945919590612, 50.385139449950195, 50.95142379883797, 52.792313714181226, 42.88963517835064, 42.2322694716915, 49.22514946229997, 48.41053985780286, 50.46086080612675, 47.787404675637525, 47.63161989950365, 45.635812051834606, 41.472086675705455, 39.83577582143968, 39.37796854203747, 37.1800801830907, 35.43335460847424, 34.47033428376721, 36.139604814590946, 36.1975892128483, 35.4162020837107, 37.16282959907286, 37.44535792258478, 35.90511375857938, 39.47298795946183, 45.21545948520784, 49.36363658597393, 49.31261047240227, 49.778238957928075, 47.459098369844504, 46.94416569125268, 38.780505272649954, 36.66135457254226, 35.672615266615345, 36.81153820407006, 36.41300578271189, 36.884819845999445, 38.3924691138729, 40.58394047521776, 45.45791687503938, 47.94351108612553, 48.324047673133116, 50.26800178712415, 51.433275207396484, 50.27734879524478, 51.616708770875015, 51.20209070944017, 52.83043915225614, 53.81692309533396, 54.23180003320017, 51.71521909775273, 51.384924150282345, 52.82987040858115, 56.07971491352205, 49.12267361917804, 39.06148033757364, 13.982272013541191, 2.3504310509850903, 0.07971978355799952, 2.3913614740294795, 8.868286763468097, 7.93172674794351, 3.1919052139405286, 2.9957636613999648, 0.10445797305193641, 0.22099614143371585, 10.084898125740791, 28.39879551241475, 25.14041396879381, 30.83341656192657, 40.87856538834111, 28.113756871992543, 4.452221095561981, 0.04471742931092459, 0.01024996531346152, 0.03860524277232828, 0.03434731842829816, 0.034274873323738575, 0.1224715346770902, 0.03277707567077971, 0.021721342908999613, 0.10729143350955941, 0.035153185468046896, 0.06373283858861654, 0.04985870665780479, 0.06000761731317448, 0.01845679136984531, 0.037235067706675305, 0.11442620953124379, 0.08195045539328168, 0.01810074626137653, 0.051853515342959476, 0.02529133178834473, 0.047321101695659666, 0.05554329356058471, 0.021417029802837682, 0.007232139093591081, 0.029377411119639877, 0.03534435121823223, 0.08407154601187476, 0.02824905362250584, 0.049710012822141575, 0.07352830691924019, 0.06447479474328219, 0.019836896850216775, 0.021357192590291944, 0.06115478801450903, 0.013531125638814223, 0.07250131243058751, 0.02220017084431264, 0.03509822632035902, 0.04288290537172749, 0.07002674118285218, 0.05558631322797268, 6.537942415283573, 37.62814037261471, 56.70094382378363, 43.76233116272957, 37.38440429010699, 45.984620586518325, 50.731343530839496, 33.53703768022599, 4.341825987062147, 0.1779665608680056, 0.3479691168233272, 8.721825461233816, 20.843647679974957, 9.831446332316245, 6.931283089422411, 26.321145449915242, 49.21343334259526, 56.26317593359179, 53.81196521943616, 55.78244240053239, 56.01725901326826, 58.623626924330196, 55.951351427262836, 54.315393586312574, 53.66676299802719, 51.783668379629816, 51.698698074586936, 48.713107570525146, 45.94634217600669, 44.705739636575025, 42.117720573179184, 40.576899820758456, 37.0068016359883, 38.25017729113179, 39.75350410707536, 39.504433601133286, 39.87256373128584, 39.14860794621129, 39.34675824257636, 41.83606693821569, 45.81950841411468, 53.67452929096838, 52.02965982498662, 52.099230904732984, 54.55316766615837, 52.27207799111643, 47.518020214573035, 43.1573800886831, 39.57283973693848, 39.23148762795233, 40.14742774348105, 39.529395564909905, 38.270585383138354, 36.98354198086646, 39.05628319709532, 42.47580551332043, 45.862568193866366, 48.839690300726126, 50.33445066021335, 52.020391264269435, 50.64519651474492, 52.48774559267106, 52.19268921882876, 53.594509017082956, 52.65925122845558, 53.93204073752127, 44.2623862912578, 43.39072581260435, 47.91491700756935, 50.34867709682834, 53.454754967843336, 50.23914098739625, 49.186412134478175, 47.49817302150112, 43.14586008748701, 41.632166447178015, 39.25048366669686, 39.449810674113614, 36.780829967991004, 36.139138052540446, 37.3504130301937, 37.56806927342569, 37.31335055443549, 38.97841238206433, 38.386197243967366, 38.24784740324944, 41.17344525552566, 49.450022866649014, 51.873914272554465, 51.47551128941198, 53.10272616724814, 49.03386331373646, 47.07836958669847, 40.58493675724153, 38.094694537501184, 36.912900094063055, 38.85582262469877, 38.162131847873816, 38.21236956504084, 40.582944193193995, 43.75517675953527, 47.17139644007529, 49.88491565950456, 50.29201453731906, 53.89688845603697, 54.39671608709521, 49.65779865941694, 50.470823626364435, 50.80189912549911, 53.57742317261235, 55.76019471691501, 55.016803587636645, 54.74088445786507, 52.21204219325897, 54.35460944329539, 58.46044455805133, 50.868351920958496, 41.15206441571636, 16.486998565735355, 2.9626745466263067, 0.8010809207635542, 4.637906099519422, 10.559975601011708, 8.956736210853823, 4.71569013211035, 2.3105304952590697, 0.19952470406649575, 0.35929355109410904, 12.39596353423211, 37.88424368827574, 30.354442211889452, 36.77295777105516, 48.806157958122995, 34.76850109715616, 5.965406788933662, 0.04215814789096194, 0.03503588208508107, 0.03683068436540423, 0.04229582921271363, 0.014825452254304003, 0.05883205922380571, 0.012347768774376282, 0.0664846953605452, 0.03249869081041506, 0.06509311962872744, 0.029047922449066278, 0.05577380558656109, 0.06882923084401316, 0.06455548678434665, 0.05413983580506137, 0.022823979004075932, 0.014252734498210974, 0.11291630385864167, 0.12144089360991794, 0.23139285854995253, 0.14549361061184637, 0.16904270907323207, 0.1429243355749115, 0.06836983855933913, 0.1836877974170831, 0.1760791653707143, 0.21286021106906478, 0.13198406375463934, 0.12231829410959637, 0.22708301642729392, 0.1991502862543829, 0.12131052076696389, 0.14401253282783494, 0.25468288139710504, 0.16316764206895906, 0.19089191971767336, 0.1148683648376215, 0.17009304626093757, 0.14993267644557262, 0.2466265782113037, 0.16861484896752144, 7.019702138439302, 46.63696173698672, 63.43807743441675, 49.76652676059354, 41.63259006315663, 57.58978036142165, 58.213460753040934, 39.49433742030975, 6.311981533804248, 0.4412466954560049, 1.5957895834599773, 11.929052433659955, 17.799251041104718, 10.09892059910682, 7.2096223215903015, 28.702741938252604, 52.716404084236395, 58.461185886013894, 54.30113969310638, 54.796946894737985, 57.243411540985115, 60.84832468340474, 57.21556663513184, 55.5989460791311, 54.981521867936664, 52.83401243148312, 54.577090201839326, 50.51550726736746, 47.36865243604107, 46.627147966815585, 43.547565706314586, 42.471694869379846, 40.117935442155414, 39.38998668424545, 42.33037971681164, 41.46144136305779, 42.56750660557901, 40.78762523589596, 41.290418178804465, 43.397260481311434, 47.760967900676114, 56.551238721416844, 54.04027462005616, 55.13893442769205, 55.184402542729536, 53.630167284319484, 48.67273853671167, 44.63737664684173, 40.75014698889948, 42.14800127090947, 43.29172911182527, 41.232033698789536, 38.78757338370047, 38.685301503827496, 41.86709288627871, 43.75196433836415, 47.76700050600114, 48.77339440007364, 52.43205185859434, 52.38337916712607, 55.376645749615086, 54.95107250828897, 53.88614900650517, 55.04050254821778, 55.19058419812111, 54.9741635014934, 47.061103313199936, 44.4967596761642, 48.326652126927534, 52.69070471486738, 54.42861672370665, 52.33218439163701, 52.0741512698512, 50.76227534201838, 45.29354210822813, 43.92129305870303, 42.32743793918241, 42.28697084611462, 38.560221041402514, 38.36548712945754, 39.232695717965406, 40.529144963910504, 38.478749490553334, 40.90111901683193, 40.56439138227894, 39.806726747943515, 42.36851692199707, 50.54476814885294, 54.23372199458461, 53.028287426117934, 55.67030183730587, 50.826868934016076, 49.600579123343195, 41.17837959720243, 39.787205111595895, 38.63592670809838, 41.140544414520264, 40.721776485443115, 41.07817872878044, 43.197372574960035, 43.97055018332697, 49.645902110684304, 53.13681156404557, 51.348822655216345, 54.70810128796486, 54.745905091685636, 52.13621493308775, 52.795526135352354, 52.38790558230493, 53.46783214999784, 57.185278092661214, 57.01594544995216, 57.211004918621434, 54.67882471699869, 55.58677888685658, 61.68879055207776, 55.35623765760853, 41.770175041690955, 18.258666492277577, 3.5730424138807484, 0.46253401125150345, 6.393828651597423, 19.059094767416678, 17.99844272675053, 9.898699291290777, 5.2295622998668305, 0.7144527401654952, 0.43207533597465486, 14.067424708797088, 39.79160208855906, 36.44866012757824, 44.684523536312966, 56.651396443766934, 39.79101373303322, 7.0979411659702185, 0.20648643614784365, 0.10372660423238432, 0.147666557722034, 0.1053805574173889, 0.08867994025950471, 0.17217617722288256, 0.16435904668704157, 0.15756741676840091, 0.1761522961239661, 0.1393024863735322, 0.13759974870950947, 0.160664051410652, 0.14235804338128338, 0.11200946260003314, 0.10183130270771443, 0.15615272816390763, 0.1015282613075068, 0.20473094566935496], [0.03957095022703852, 0.07544469118358628, 0.07877084576795179, 0.03444799387286748, 0.06507319368181691, 0.01626511149468922, 0.023231018755224445, 0.019717676332220435, 0.09282878900487578, 0.05681336008673234, 0.06072319706060714, 0.023039383776185494, 0.02643602611046405, 0.02023175771858904, 0.024057459086179737, 0.022753127362398852, 0.025448418117218444, 0.017255519539298072, 0.01982817493919884, 0.008307695895763896, 0.02454549922878223, 0.0442150901372154, 0.04933511620507606, 1.9305719675556308, 27.17118582417888, 43.336412752828295, 34.871577062914454, 38.297398705636304, 61.933209126995465, 53.448887102065555, 34.94295243294009, 8.100869645995479, 0.2748259223036228, 0.9367888613093285, 5.289545636023245, 8.16095349288756, 13.889996294052372, 4.848192209197629, 28.460164916130807, 35.44527469142791, 38.65247126548521, 55.76921224594117, 52.949949849036436, 57.57693852147749, 55.3273807802508, 52.85208671323715, 50.481323811315725, 48.4622484637845, 46.391711619592485, 42.657250435121604, 43.45715899621287, 41.61237808965868, 39.562782779816665, 38.85932922363281, 37.83680262104158, 37.536921731887325, 37.68949800922025, 37.93530118080878, 36.23080776583764, 37.03200286434543, 37.056039148761386, 39.97723217933409, 40.415255023587136, 46.270318185129476, 52.17224974786082, 49.835717370433194, 51.051004932772734, 54.37054211093534, 52.18620161856375, 47.38380062964655, 43.574936005377005, 38.13049793243408, 38.79450813416512, 37.20091973581622, 37.4957093884868, 37.121632945153024, 35.36061425362864, 36.07315201913157, 37.17886817070746, 41.12334482131466, 44.723625644560784, 47.17097282409669, 49.970713584653794, 48.30687553651872, 49.030239043697236, 48.17753145771642, 49.996777734448834, 47.805604473237075, 51.64882121547576, 44.198918419499556, 41.541140002589074, 47.10994858895579, 46.45009609960741, 53.20679057028986, 48.706176742430664, 50.00322218864195, 46.56074616216844, 49.40972443549864, 45.0588196323764, 38.6992572969006, 35.624530930672925, 36.497124933427386, 34.53652820279522, 36.041745601161836, 34.81427123469692, 37.78649037884128, 37.73999460281865, 36.52178095233056, 37.11767919601933, 36.026773914214104, 38.10517903297178, 45.986279749101215, 48.60670543486073, 51.34751650594896, 52.709037873052786, 50.72752314229166, 42.115990807933194, 38.95595681282782, 35.48973867970128, 36.36601971041772, 35.80189658749488, 36.47008019108927, 35.59241064133183, 35.35693899277718, 37.01945127979402, 42.03661380275604, 45.2188797919981, 46.42653442198231, 48.681701152555405, 52.369913670324514, 50.67898773377942, 49.59739415876327, 48.71911271925896, 51.597830403235655, 53.500430968499955, 54.88698097967333, 52.69239917878182, 56.81600655278852, 51.18154533447758, 50.74879023336595, 29.200324012387185, 10.23207918290169, 0.7256743347933217, 0.697204485054939, 4.710799426801743, 6.466314052381824, 6.1721696296045865, 2.88524107586953, 1.6470213763175474, 0.10497044756888382, 0.4168236592123586, 11.452134386185678, 36.1721134185791, 31.70032705030134, 29.249783139075006, 38.993960657427394, 19.207387816521432, 1.6554885477788988, 0.10758397950520439, 0.0502300945921771, 0.037341293458256035, 0.08573513658296678, 0.04636327345525065, 0.08568301962147798, 0.04149714807769464, 0.0378425716001901, 0.02095542352406248, 0.035389446983895, 0.01663166732947913, 0.03353776267519401, 0.049887392820129474, 0.07015833210560583, 0.0702367335437767, 0.03455711543680199, 0.059376747737969124, 0.03137212787424365, 0.03434958221811441, 0.020059462629198548, 0.05836605943078476, 0.05383480257625061, 0.029414803871224006, 0.016052392818364167, 0.01610253231539842, 0.019945972448875828, 0.055579851276331374, 0.039016091895680276, 0.02264544221332237, 0.014453176615549432, 0.08115452834435048, 0.048802236936265425, 0.01798568177036941, 0.05120820501038144, 0.033793888850918705, 0.053516860765915726, 0.027759010159981348, 0.04577718938009874, 0.035788774144865816, 0.04415142440026806, 0.0740225945088652, 2.5125193211340138, 33.546090510583696, 51.46289302456764, 42.437397664593114, 37.31028326096074, 59.21422996828633, 55.90796609078684, 38.009971341779156, 9.26303311701744, 0.2671827243701104, 0.3232872654353419, 4.570059882056329, 13.091811614651835, 21.20079125127485, 6.281690539852266, 31.616200054845503, 38.027712222068544, 45.003506368206395, 56.359795678046446, 54.215961502444365, 57.17524859213061, 58.26697364930184, 53.52481634386125, 53.00526703557661, 49.57416980497299, 48.92911249591459, 45.032171049425685, 44.81383231378371, 44.10167894055767, 41.98704681088848, 40.005865481592, 38.84098037596672, 38.30304299631427, 40.53814680345597, 40.236524381945216, 37.67233763971637, 39.102716215195194, 39.21033036324286, 42.02083410755281, 41.92119021569529, 48.255253222680864, 52.85370665211832, 51.6496096118804, 52.28058561202019, 56.398234905735144, 53.693207617728945, 49.282165035124756, 45.00696982106855, 39.642069570479855, 40.59354243739959, 38.532889966041814, 37.833245031295284, 40.01660885349397, 37.90470669346471, 37.79109916379375, 39.62533281695458, 41.840652188947125, 45.21727554259762, 48.942970229733376, 52.57906621502292, 49.64888703438544, 50.740867045617875, 51.27634509917229, 50.82127955652053, 49.59960245317029, 53.32293195109214, 46.48708012796218, 43.54060349925872, 47.37507727838332, 48.42672355713383, 54.24704236368979, 51.88845842115341, 51.470910349199855, 47.97522737133888, 50.344013398693455, 45.82413681091801, 40.936906722284135, 37.04032221148091, 37.10053451599614, 37.0883555566111, 38.24121467528805, 37.236962395329634, 39.850245445005356, 39.40767265135242, 39.21606879080496, 39.41220298890145, 38.76848320807181, 39.80131779947589, 47.41937260473929, 51.61731673825172, 52.9429837196104, 52.74491971538913, 51.92352441049392, 43.5453534895374, 39.46473921498945, 37.04951232479465, 37.91155907415575, 38.18219477130521, 38.10032706106863, 37.00675848991641, 36.14425282324515, 39.341039426865116, 45.49963128182196, 47.65152200575798, 48.04313928850236, 49.973859325532, 53.72997591572424, 52.996516227722175, 50.82713173281763, 49.85218348041658, 53.17598819732667, 55.065119343419234, 55.902988603038175, 55.49199088927239, 57.24216814964049, 53.855872231145064, 50.864523687670314, 33.61319441949168, 11.710828427345524, 1.5460126222141328, 2.105998012327379, 7.007079460928518, 7.195173290468032, 8.668354730452261, 5.121694668646782, 1.2684316332301786, 0.13176916077012016, 0.4390534776593409, 12.830685703985154, 35.56094538780951, 36.08253432858375, 35.624224985799486, 46.449652871777936, 24.79371370807771, 2.821323847578418, 0.12020425916078592, 0.04827275526739898, 0.040245923484044696, 0.04724851869527371, 0.023596546116976008, 0.07200161626021709, 0.031246667570104043, 0.06570530048901997, 0.019632177089431116, 0.03804240563523866, 0.020422059704639742, 0.006471828429869587, 0.0426806504988382, 0.11990278057994382, 0.008094243690251343, 0.04168508093683951, 0.05275613545710522, 0.022948408919957378, 0.18320873199451357, 0.2239932612546029, 0.14144063777019902, 0.10254530431402308, 0.17644814395856473, 0.1406652188950008, 0.10626568008334407, 0.11106748088833787, 0.1823990843108585, 0.12488233676600842, 0.11429418959925253, 0.143511526647114, 0.1391447182264059, 0.173656213127317, 0.12589951000747182, 0.07791003107183403, 0.09871057460024472, 0.13196635180182997, 0.14261803830102568, 0.11670087779601736, 0.14865268141992632, 0.1512832894560791, 0.17901391031280642, 4.034491613987954, 38.32638894357989, 59.333799500619214, 46.91728176609163, 50.7994790231028, 67.89638457759735, 60.806272952787346, 44.26719119471889, 10.541261972919589, 0.48168001936808713, 2.0751667118841604, 11.1140594174785, 17.56069640959463, 22.013074890259777, 7.528896389469025, 37.5239465313573, 42.52430169813095, 46.980463304827296, 56.648631172795454, 53.552720085267104, 59.02937650680543, 60.74320908515685, 56.725823417786636, 54.94268648086056, 53.2833787702745, 51.53768085664319, 46.24003356502902, 47.24898484445388, 45.451468498476096, 44.165084054393155, 43.18801379972889, 40.43429813077373, 40.74794261686264, 41.99167913006198, 41.86273121064709, 40.258634782606556, 41.24129833713655, 41.653833620009884, 44.03964665628249, 44.01762254776494, 51.02203822905018, 55.60074252467002, 53.185637227950565, 53.338425313272786, 58.64264257492558, 56.68061810155069, 51.20652691010506, 47.2143110921306, 40.08676044402584, 42.565043357110795, 40.32376966168804, 40.73094698690599, 42.116790971448346, 39.364000981853856, 40.241341052516816, 41.54503883854036, 44.32321440789008, 47.19088277509136, 50.93693064105127, 55.137463538877434, 52.150590419769294, 54.15723577622445, 51.94742733432401, 54.01404573071388, 51.40850151738813, 53.74995646938201, 49.437879208595525, 44.52744437802223, 47.56413159831878, 50.07335808969314, 56.30665932932208, 54.32939644782774, 53.63580765262727, 50.856176883943625, 53.01353146952968, 50.19497902162614, 44.36938462718841, 39.60359504145961, 38.67413451594692, 38.80079569355134, 39.06967416886361, 39.74845209429341, 42.22824904226488, 41.918719122486735, 41.134802064587994, 42.416122728778475, 40.56840788933539, 42.57999150983749, 49.815372036349395, 53.16587240465226, 55.27700970249792, 54.797943176761756, 55.343019270127826, 46.39999566539642, 42.54040695005848, 38.951512767422585, 39.97880112740302, 40.263216110967825, 39.694158646368216, 38.98416257673694, 37.76194026393276, 41.32546847866428, 45.78580740959414, 49.062810405608154, 50.45719731238581, 52.23514495357391, 56.712597185565585, 54.082698975839925, 50.54235196882679, 48.624132525536325, 51.87996648973035, 56.770307017910866, 59.753312680029104, 56.488300369631865, 61.365865738161155, 54.93453187327231, 53.085122569914795, 34.23713760991251, 14.065308590089122, 1.0250137530026897, 1.3066573368926204, 8.581445793951712, 15.513465308373975, 14.334027228816865, 9.329784012609913, 5.548326949919424, 0.4144335568191544, 0.9810933807203848, 15.76470390442879, 47.622296425604056, 44.60330693952499, 43.16156525765696, 55.05845523649647, 29.30560042781215, 3.4511444645543254, 0.2063378457340502, 0.17214433860874948, 0.13556927863147952, 0.16928301553332037, 0.2113305173453785, 0.16955373568400262, 0.11725541820088703, 0.12002629693597557, 0.13515378318486676, 0.20059195647556938, 0.07669035780934558, 0.10955831066014306, 0.15516076687603228, 0.24107423340601308, 0.1521869054845264, 0.10970987349508271, 0.20620909699749565, 0.11610945791847284], [0.04912533834877034, 0.05141297648210199, 0.03769756647788229, 0.031082655806394837, 0.012098146685128732, 0.09556785976934819, 0.04096059924772671, 0.013922369614573977, 0.101731144372494, 0.01684260580899014, 0.018827254253049052, 0.01917531481012702, 0.03602868223923349, 0.07545658086817111, 0.05398133221352774, 0.04226407869869182, 0.028410426213315902, 0.04120275581015214, 0.038381583402834596, 0.03500510067228348, 0.12582464789551112, 0.07632001558498991, 0.0422305700128838, 2.8721305535685633, 22.347378500046272, 43.55517510444888, 39.73215856859761, 57.02681041532948, 74.3904959770941, 53.60689586208713, 31.79569163630086, 12.735078911627493, 0.22226591684645225, 0.28386346154635955, 1.79067364863811, 12.107335925102236, 5.303134687485234, 4.324614136449752, 15.136494155853027, 27.16991105387288, 55.40603606931625, 55.018482362070394, 60.13658315904679, 56.100644680761526, 54.67927186719833, 47.72771796872539, 45.71640891413535, 39.972705764155236, 42.038578910212365, 39.788550484565, 39.10157480547505, 37.078843808943226, 39.676531514813824, 36.42006212665189, 38.80753040313721, 38.15969997836698, 39.69274659310618, 38.2541859534479, 38.86673073614798, 39.40595465321695, 40.83616848914854, 39.85496013395248, 39.704945164342085, 44.196710125092544, 47.610352808429354, 50.14583172336702, 52.184448319096724, 50.14385092643, 48.24434903360183, 47.16764665419056, 43.2102850175673, 39.15462486205563, 37.64549686062721, 38.049532367337136, 35.7202995208002, 37.968539345648985, 39.991478227799945, 35.22288806976811, 36.36367805542485, 36.379751928390995, 42.5231759778915, 43.49588063455398, 49.795367948470584, 46.420697935165904, 47.85740721610285, 45.55046519925518, 48.22011663067726, 47.68080249909432, 53.03720689588978, 45.081628214928415, 40.017256044572406, 46.828961756921586, 45.53418344066989, 48.15063184307468, 48.40800600667154, 51.054389938231445, 50.817937697133715, 49.58173213466522, 47.1326159661816, 44.60239302727484, 35.820037549541844, 36.79674694615026, 35.98158820982903, 34.998214706297844, 36.237052179151966, 37.27751578054121, 36.73810358970396, 37.51838461045296, 42.24799425371232, 39.07451437365624, 40.90682606543265, 46.2550836993802, 48.910700890325735, 51.893988963096376, 50.078406180104906, 48.40474651705835, 43.23403496896067, 39.204815510780584, 37.400533076255556, 36.712600338843565, 38.43963953756517, 36.445694815727975, 37.152490231298636, 34.74097390328684, 36.232776795664144, 34.40158297938686, 38.81094286518712, 45.83815536191387, 45.80528589986986, 49.79152794807188, 49.902056417157574, 53.03125666033838, 49.945681018214074, 49.98191195149576, 53.99308066214285, 51.44026879341372, 55.45903905745476, 55.97199093910956, 54.76443829074983, 41.376796614739206, 20.137536717999367, 6.033341259725633, 3.9292801628189706, 2.081976927095844, 5.744527338012572, 6.636363998536141, 6.267679343300482, 4.3498575302862355, 1.3907026980192432, 0.05604087532828412, 0.7782577518974582, 18.892419530499367, 39.48476291471912, 31.91203501916701, 41.69625797579366, 41.75816474422332, 13.536055337998176, 0.49785716098643124, 0.0805800466708118, 0.09116712897535294, 0.013094191221640477, 0.004194923667162056, 0.04221218007226144, 0.08006788624991333, 0.02349874350212274, 0.054436706367038915, 0.004452502537113164, 0.07344186155786438, 0.04012750544314904, 0.07330011230923476, 0.0385930045177379, 0.008902327596930968, 0.04538436247516544, 0.032910470730595054, 0.030722579160224528, 0.01659998193293089, 0.03787786144042208, 0.06756236656538903, 0.05738172837863526, 0.04330874683575765, 0.04539647815568794, 0.06206200848664008, 0.07316331964947524, 0.019438494740414525, 0.03095753832660135, 0.01815433219646014, 0.061703674690497506, 0.03278370999220399, 0.04024018931593146, 0.10897859660608154, 0.017000337566940055, 0.12195098559342085, 0.02483439290024821, 0.039173243342027556, 0.0399808302491663, 0.006769252011567475, 0.042293190039814486, 0.020753287394801458, 0.04210707663948979, 4.118465637007068, 27.69479870796204, 52.23396039778187, 44.28262964371712, 58.569482526471546, 74.92939825980895, 59.13327224792973, 38.31209582667197, 14.32657962845218, 0.3604645318081302, 0.588525045783289, 3.5588137709325363, 16.031879090493728, 13.35670986483174, 6.245784182702342, 19.34891477707894, 31.58625864213513, 55.383192185432684, 54.57244611555531, 59.76114173089305, 57.33533620834351, 57.16219886656731, 50.82057352988951, 48.29388856887818, 43.370019620464696, 42.336643741976836, 42.09248012112033, 40.576899820758456, 37.970857466420824, 40.22422382908483, 38.13604024148757, 40.39358392838509, 39.39041030022406, 40.19135828941099, 38.982232770612164, 40.03981751780356, 41.868622610645915, 41.806723686956595, 39.80470672730477, 41.49124745399722, 46.84595738687823, 49.87591381995909, 52.71812600474204, 54.45442591944049, 53.742001902672556, 51.56845577301518, 47.93500738759195, 45.492939718307994, 41.05976320082142, 39.05486722146311, 39.78842889108966, 38.44514262291693, 39.65531933692194, 40.731421593696844, 37.43583833017657, 37.65320431801581, 39.253037129679036, 45.69823265075684, 45.515316840141054, 51.187017040867964, 48.74858148636357, 49.75048818895894, 47.89106899692167, 51.513715174890336, 49.52978818647323, 52.80797966064946, 47.41499523962698, 42.20791155292142, 46.603970681467366, 44.94314501362462, 49.30473043072609, 49.8577767802823, 52.749869746546594, 53.074708677107296, 52.231265729473485, 49.262894430468165, 45.79608794181578, 37.871182195601925, 38.114800607004476, 37.43694443856516, 36.24647763467605, 38.473685710660874, 37.725599504286244, 37.903541749523534, 37.7606733383671, 43.94803577853788, 41.95509518346479, 42.4855016123864, 48.689742011408654, 50.64498078438544, 51.8530668750886, 53.23492180916571, 49.618084661422245, 43.67900040841872, 39.711989741171564, 37.97771376948203, 38.409680474189024, 40.3318222876518, 36.85694748355497, 38.976702228669204, 37.22873718507829, 38.22730202828684, 37.6728710820598, 42.467470476704264, 48.09100397171513, 48.464460680561686, 53.62911216674313, 51.932373277602665, 52.7135132974194, 51.2954705761325, 50.16002678102063, 53.757224621311316, 54.07801566585418, 55.80280342409688, 57.289519002360684, 56.15913114240093, 42.811638847474136, 23.79139123424407, 7.583562462560593, 4.37409826824742, 5.477010905742646, 7.498932423130159, 8.186382709010955, 4.6642389316712665, 1.521807308158567, 0.4901626351619921, 0.04103520855067238, 0.9082517184076772, 19.859403410265525, 40.97462423386113, 35.55130420192596, 45.94604799824376, 48.9182004620952, 17.797170223728305, 0.7624097829384189, 0.04690264531921956, 0.04840133163417059, 0.03488528835136564, 0.10934092555074923, 0.07773461225893229, 0.03065099398935995, 0.029100297965229522, 0.09759878950013269, 0.0433406850413209, 0.07571113656365103, 0.0544340901767775, 0.028833745332855373, 0.04955425182537687, 0.02797107095830143, 0.049030370259236906, 0.015192693737786145, 0.05325973867588947, 0.03421503036553341, 0.15304415787179626, 0.16926332707366637, 0.20854656915030173, 0.11149840534574564, 0.15333792194724083, 0.28646083668835703, 0.2301892271685985, 0.15356128254244406, 0.12810769716217635, 0.08178645895133096, 0.20618384673951135, 0.2484211698174477, 0.21150993513724498, 0.24957299833336186, 0.15752223290262685, 0.31045752968038287, 0.15001394305258028, 0.1547738311872367, 0.11414069622274368, 0.15015315655018055, 0.1670987303218534, 0.18118710257112983, 0.1339971283150296, 4.555364722205747, 32.41289423358056, 59.76614275286275, 52.628762645106164, 66.92474288325157, 80.1613615405175, 62.02625951459331, 42.10174083709717, 16.944160615244222, 0.7156988894266467, 0.7810874355416145, 6.633170698919605, 20.23088912810049, 13.56589476908407, 8.415838422313813, 20.17281451532918, 33.38073907359954, 59.09319739187918, 55.52580564252792, 61.15325366297076, 61.17594457441761, 58.69623391858993, 52.33565568923951, 49.41877334348617, 43.4740016537328, 45.14360558602118, 43.64718606395107, 41.42216274815221, 39.57416549805672, 43.54969555331815, 39.135209129702666, 41.918719122486735, 41.90649309465962, 42.11893258556243, 41.49764483974826, 43.19049273767779, 43.513343026561124, 44.032209842435776, 41.93456549798289, 43.38850182871665, 47.212604861105646, 52.191041823356386, 54.575003500907656, 55.29604888731434, 55.19203155271469, 53.743927786427165, 51.05950078656597, 47.230255526881066, 43.26080122301656, 41.25166516150198, 41.27277535776938, 39.82115322543729, 41.93465179012668, 42.995719602031095, 38.57527509812386, 40.56542688800443, 39.65490748805385, 46.11969917051254, 46.52138909985943, 53.420508753868845, 50.52474444912326, 51.25775306455551, 48.7660321112602, 53.02831880507931, 52.5650280521762, 55.3586499152645, 49.371183226185465, 43.60849972694151, 46.19202767649005, 46.35750462931972, 48.42197356685516, 50.54473284752139, 53.96858546041674, 54.9765012341161, 54.047448635101325, 51.721322305740856, 48.651851915544086, 40.114977975045484, 41.14684374101701, 38.998632200302616, 38.19089851071758, 40.07232219942155, 40.13078512683992, 40.137135444148896, 39.65027516888034, 46.2654269895246, 44.57724278972995, 46.27542118872366, 50.626337758956424, 54.632838849098455, 53.16685299719534, 53.978815001826135, 52.680459483977295, 44.6191611597615, 43.73352527618409, 39.53363956943635, 40.90586116237026, 42.1075459449522, 39.79041753276702, 41.876483040471236, 38.839423195008315, 40.638320215286754, 38.63153365350539, 45.42184283656459, 49.36734714815694, 50.64381584044426, 55.20577161542831, 54.32840016580398, 56.68035138037897, 50.78387583455732, 50.23418311149844, 54.25104318126556, 53.693741060072384, 55.68693660920667, 57.00377825767764, 55.09140314594392, 45.17874610039496, 24.85199816765324, 8.381598091894581, 7.773324770312156, 9.061767478143016, 15.113910128993375, 15.282776990244466, 16.704797975478634, 11.947033559122394, 3.453832023566769, 0.27838188794351393, 1.4872227897567134, 24.228757081493256, 48.86531906743204, 43.65130063026182, 54.17897355171942, 57.39210467184744, 22.238611175167946, 1.205832566465101, 0.20368707426373037, 0.25597226866070305, 0.0986454418049224, 0.23530294067196308, 0.1540424930112016, 0.20295216611796812, 0.10342308785766365, 0.11309568334611193, 0.10986789445122404, 0.28268007020796504, 0.12543639453548577, 0.11729397540611607, 0.11285212101234544, 0.10434613953674994, 0.16305418444737313, 0.09455408795826858, 0.18836481016009085, 0.17838459972652698], [0.06621131688476571, 0.06892015015886677, 0.04144387049300056, 0.02385950196654566, 0.042022274536711555, 0.04041876824152085, 0.03342899351170467, 0.04099992637131964, 0.014327305496760435, 0.00543412211681566, 0.025722028334595026, 0.012536771283785423, 0.018337214620964184, 0.08023350679826352, 0.03244941986556495, 0.09185488440937574, 0.06059441385009597, 0.040203643091503656, 0.05264767655922521, 0.04197593004773221, 0.02001513486667987, 0.0799005956298882, 0.03653035108600894, 1.4736448925349022, 18.498774382375903, 46.541589306246856, 43.499253872902166, 41.71286136873307, 57.598354662618334, 40.5643403914667, 33.360891880527625, 19.72918660409989, 0.9488005070917068, 0.5667009168574887, 2.7001292282535188, 2.8954252648738126, 3.2696225662385268, 0.8933349446423593, 7.099762126322716, 24.055786440449378, 42.54445483607631, 53.55135117807696, 57.87601140237624, 58.19617094532136, 51.239592490657685, 50.3132620165425, 46.61368247001402, 42.63364168905443, 40.649283239918375, 39.5738007176307, 37.19965281025056, 39.48917950353315, 38.27540205370995, 38.29801844012353, 40.36480549843081, 42.828967878895426, 42.63039788892193, 43.64800583931708, 40.041684566005586, 39.907402223156346, 37.7675727875002, 39.35406561820738, 40.124372051608184, 43.60794275037704, 45.526636800458355, 45.30511310023647, 46.4153556669912, 45.796484101203184, 45.68563792013353, 43.7788757201164, 40.75329272977768, 40.40241318364298, 38.43932182558122, 38.613435837530325, 39.05613414702877, 37.19260038868074, 36.55666259027297, 36.462702212795136, 36.450154550613895, 36.21702455705212, 40.0710395843752, 43.67997315622146, 44.11616033123386, 44.237451784072384, 44.428031906004875, 43.514123578225416, 44.94717328779159, 46.15662436331473, 54.352601189767164, 46.16855229100874, 39.993870873605054, 47.03404288138113, 47.48435843375422, 51.41911152870425, 47.25586468173612, 51.708527534238755, 50.77339918382707, 53.05634413996051, 48.44867706298829, 45.43186449235486, 37.2301806173017, 37.327796643780125, 35.847458839416504, 37.74343059908959, 37.25242830091907, 36.79777852950558, 37.36117993631671, 42.518743699596776, 44.51266880958311, 47.53899312788441, 47.45110457943332, 50.62794593072707, 51.205609075484745, 51.18809177029518, 47.41633669022591, 47.26114811435823, 40.827319622039795, 36.992143738654356, 36.23141181084418, 36.79631156306113, 37.70280268884475, 37.79064416885376, 35.71636146114719, 34.32476335956205, 34.58974299892303, 35.96753435750162, 36.34698837034164, 36.04377346654093, 43.78381790653352, 47.23315808080858, 49.91811852301321, 51.85507512861683, 55.348620414733894, 48.46021667603524, 55.49377164533062, 53.85065940118606, 52.237859233733154, 57.67571164715675, 54.75106300846223, 36.273420395389685, 19.364284584599158, 9.098616184726838, 11.390880692389704, 11.227490440491708, 5.8092111445242365, 4.739259654475797, 3.2672527192100405, 1.7071198095237057, 0.05670784679692119, 0.5431014251324439, 1.1188292479322803, 19.823360750752112, 41.7939995181176, 35.08443232505552, 37.32174442660424, 33.87987244513727, 8.733177781105042, 0.08598669687466276, 0.061772434912141294, 0.02783111818585425, 0.06099797747728806, 0.09854325333670264, 0.02723534884411962, 0.05311936455508394, 0.021275039236511917, 0.057624769772613244, 0.039235775268846945, 0.0321295858180571, 0.07494683362423413, 0.03775732899685541, 0.029475183090976173, 0.044894418604071104, 0.0113326390724509, 0.05665699388050745, 0.035493868598414045, 0.04777694699324427, 0.03422350712841557, 0.023089403571981578, 0.04098167815696328, 0.010243787771962103, 0.04901862613135769, 0.03047744060055383, 0.05511368677440671, 0.04168660545180883, 0.0532630366844035, 0.058833353912397746, 0.024721672638289394, 0.015221397137089122, 0.04889998975540361, 0.011064397216203713, 0.021321498638679905, 0.05663391931222812, 0.04629493841240483, 0.08813990189904168, 0.03589958110223374, 0.05205271352503089, 0.01529023109469563, 0.0447936014332358, 0.04785080553002415, 2.038809159590352, 22.413868558022287, 52.398009607868815, 48.530395723158314, 48.88446415624311, 66.22164234038323, 48.729299114596465, 39.18139503848168, 21.223346840950754, 1.145350476426463, 0.12343826102873973, 1.4045517290792158, 5.998069836247352, 6.909246723498068, 1.9966941807539234, 11.60407720073577, 27.863456703001454, 46.9566741297322, 52.98977367339596, 58.54614050157609, 58.83975344319498, 53.96413357027116, 51.9008570332681, 48.16242641018283, 44.31758972906297, 42.83249408968034, 41.215579355916674, 40.52358696537633, 40.26318865437662, 40.375227235978656, 39.548450439207016, 41.83192099294355, 43.5234627416057, 44.9271809670233, 44.04010557359265, 42.61797966495637, 40.5614221480585, 40.89479223374398, 41.40295882378855, 42.01961425042922, 45.61463909764444, 47.29041291821388, 46.603417627273075, 49.42619839022237, 48.48259772023847, 47.38396929156396, 46.743885547884055, 42.78766924335111, 42.99768470948742, 41.068941547024636, 40.31752917074388, 40.61959482008412, 39.05781292146252, 38.8088640089958, 37.65197661615188, 39.20776121077999, 37.50731175945651, 40.89704759659306, 45.42276459355509, 47.124571184958185, 47.45816484574349, 45.65803227886077, 44.62557031262306, 47.57678908686484, 49.766326719714755, 54.72796417051747, 49.522508267433416, 43.89194588507376, 47.21640171543245, 47.503154431619954, 49.988058305555775, 48.646576327662316, 51.05095394196049, 53.23725561941824, 54.583185565087106, 50.181113443067, 47.052168153947406, 39.40943771792997, 37.74825119203137, 38.57984465937461, 37.90215715285271, 37.96116528972503, 37.07746705701275, 37.75959860893988, 42.70034551620484, 44.33774678937851, 49.35108500142252, 49.608337571544034, 50.419016961128484, 51.20540903460596, 52.37318100467805, 50.276226997375495, 49.74591862770819, 41.93528721409459, 38.4599809492788, 39.89956532755206, 38.02255430529195, 38.66910211501583, 38.50576677630025, 37.67442041827787, 36.90516910245342, 37.184171215180434, 38.17721336118637, 37.42680118929955, 37.73234205861246, 45.94951145110592, 48.805193055060606, 51.64310239976453, 54.089688639486994, 55.57332123479536, 48.549717318627145, 56.90337342600669, 53.777832754196666, 54.717754240958925, 56.39330056405837, 53.688532152483546, 37.781073585633315, 21.63378953933716, 11.20342081592929, 12.689525485038759, 13.037390689696036, 3.0833237113491183, 4.60966601487129, 2.3332900481839336, 0.13376241429678856, 0.13482723054626297, 0.5752466582963544, 1.431756185427789, 23.392805860888576, 45.655196405226185, 39.30454177241172, 46.93690538406373, 42.03106757133238, 12.009742452252297, 0.34838023024701303, 0.04638501120010211, 0.02457354187725052, 0.027788303446986025, 0.03910868128220882, 0.07307832985515557, 0.03017258740240528, 0.009080993665021755, 0.03573217173858035, 0.02584622076321994, 0.017376302876659942, 0.07396310778154482, 0.0554644899262536, 0.023919588157666788, 0.01007916984118281, 0.07213430268870247, 0.020565166844115145, 0.04839519143945748, 0.007938456838019192, 0.13645026442264357, 0.19101107703341594, 0.0915048435150135, 0.13796356386475025, 0.17812806752420243, 0.1278997196124927, 0.13121765407343067, 0.15484889248205772, 0.11242311943562762, 0.12377476514947992, 0.08553503441714472, 0.0762772755396943, 0.13626134714051602, 0.16751782638171028, 0.087790067848419, 0.1796837469502803, 0.13533050434723978, 0.14323464714952056, 0.22335025301623732, 0.17268850618312437, 0.0838444545684803, 0.1974563279579724, 0.20770603280153968, 2.3174846124264503, 25.028385193117206, 60.638477879185835, 56.94433866008636, 53.84872959506128, 64.03264991698727, 50.127953560121604, 44.8022730888859, 25.74422363312014, 1.801992628362871, 1.1019163554714573, 5.569044418873326, 12.444981394275544, 8.964041625299762, 1.4776231564821736, 13.657229119731536, 31.442072314600793, 48.52647727535617, 54.539439370555264, 60.352015418391076, 63.90399225296513, 56.29064821427869, 56.11831103601764, 51.64026260375977, 47.88529134565785, 44.29654229071833, 43.688998529987956, 41.5952177201548, 42.27245023173671, 42.079759874651515, 42.61131555803361, 44.58939821489396, 46.44437728389617, 45.547139029349054, 48.14996111777521, 44.82128089474094, 44.16725704746862, 41.84715547869283, 42.77629044748122, 43.87156917202858, 48.2849730214765, 48.671451999295144, 49.1239680013349, 50.55521342062181, 49.71502604023103, 49.18093258334745, 49.17257401251024, 44.59220663193734, 45.994571639645486, 42.89244359539401, 43.40897660101614, 44.665198018473966, 41.499594257723906, 39.6814227104187, 39.74446304382817, 41.485014807793405, 39.156801777501265, 43.55162535944293, 46.940851288457075, 48.43079105500252, 47.830032994670255, 48.0685091787769, 47.36543609249977, 49.03668742026053, 52.14899793747933, 57.794088778957246, 51.513664184078095, 45.74364977498209, 46.22046093786917, 48.23444112654656, 52.389984438496256, 49.20498063487392, 52.77168989181519, 54.74696413163216, 56.46993191011491, 53.9225721359253, 48.875901622156945, 42.068439914334206, 38.82068603269516, 39.62265776049706, 41.001355186585464, 40.23194305358395, 39.90939478720389, 39.54089595425514, 46.39871305035007, 48.22581191216746, 50.57036553659747, 52.630543401164395, 52.955688276598536, 54.03697590674124, 53.9568732630822, 51.99374268131872, 49.98508122659499, 44.87039289166851, 40.19492372389763, 42.57165255085115, 40.12290116279356, 40.50992927243633, 41.77308544035881, 40.31415593239569, 38.39102960401966, 38.56462978547619, 39.85401484274095, 40.158924210456114, 39.298250290655325, 48.14898836997248, 50.13054232443533, 53.47421776863837, 54.81255792802381, 56.5635863427193, 47.97807501208398, 57.39537200620098, 54.810086834815245, 54.60995181914299, 57.25386465749433, 57.44397017263598, 40.55402063554333, 27.551243882025442, 15.470497704321339, 16.270688676065017, 21.874391648077196, 13.966760020102225, 13.180678794460913, 13.163956749823786, 7.439834562040145, 0.5566519270500829, 1.4462049714019223, 1.7518264944514923, 27.84499999015562, 52.62622879397485, 48.20047732322447, 53.3152009594825, 48.0531648666628, 14.326612968598644, 0.46838811809016817, 0.17247642240216657, 0.10264334058569324, 0.17445937970713263, 0.22910368057989308, 0.23310416107696874, 0.14006658246920956, 0.19237304346696024, 0.16488207023470633, 0.17178585542546165, 0.10063644303309341, 0.1359809129949539, 0.16193932733468472, 0.12477230355744401, 0.26700707573083143, 0.14251904441945015, 0.10543543995628435, 0.11027196752688578, 0.12198080173543385], [0.05836251244369534, 0.04547485661122107, 0.01707280756935718, 0.1141747028657025, 0.06064837325304266, 0.04520433947383877, 0.027818358991475358, 0.004079237687326367, 0.01893959338626554, 0.03863896979319473, 0.008666130240946528, 0.04323710612351856, 0.05689207179051253, 0.004492668048178237, 0.029464270168494795, 0.02066040114920226, 0.03167326363073963, 0.06674140376309234, 0.02532967448895497, 0.042221633597247066, 0.09804213990367229, 0.03413419659820295, 0.0461918076560382, 0.9107818923169567, 11.318807140473398, 34.745512085576216, 47.86088243607552, 39.603485215094786, 32.41269223151669, 29.715803861618046, 39.76769131998862, 28.359677714686242, 2.5107630798893594, 0.2839979559423462, 0.9020014828251255, 2.635863889609614, 4.519168109663071, 1.3052891651468894, 1.3285414658246504, 9.286245703697205, 26.54453423715407, 44.88965172921458, 55.78481151211647, 58.90846160150344, 53.58884511455413, 50.47342415778868, 47.47086940273162, 45.1171648886896, 42.23193214785668, 42.84828162962391, 39.49169766518378, 40.11275399115778, 42.511848172833844, 45.1806955183706, 47.43484635506907, 46.900686217892556, 45.76497570160897, 45.197687225957075, 41.85012863528344, 41.5900598033782, 38.999879514017415, 38.49015182064426, 38.86899002136723, 39.755080899884625, 39.84716638442009, 38.441843909602014, 40.71644990674911, 40.65762612127489, 40.39598441893055, 40.09430316186721, 40.45090544608332, 38.584747622090006, 37.93623862727996, 39.361090583186, 37.05652552266275, 37.96749991755332, 37.08817904995334, 35.58043564519575, 37.08802215514645, 35.746924569529874, 38.20490529460292, 38.083582462803015, 41.443778930171845, 41.694994972598174, 42.79166221618653, 42.1993568635756, 45.352601235912694, 46.18685407023276, 54.01122946893015, 47.3925357480203, 43.18657821224582, 49.361502816600186, 50.4027352025432, 53.26896013752107, 50.53493868920111, 52.132190581290956, 51.14470643381919, 51.3505288862413, 48.18601946676932, 46.16755993135514, 37.09837329003119, 36.38764765954787, 35.782794644755704, 36.496438518647224, 37.09820855048395, 39.85081026631017, 42.368720885246034, 45.589426102176795, 47.0397146286503, 50.3099750703381, 51.65890170681862, 51.83208219466671, 51.09178973782448, 49.04536370308169, 50.06058685241207, 44.7759892863612, 38.9783182451802, 36.83243266997799, 35.858296348202614, 36.02044713112616, 36.93308068859962, 36.92494961523241, 39.210197002657004, 36.0055225126205, 35.05936837965442, 34.474652813326934, 36.63946382461056, 37.83646137483659, 40.87176007609214, 43.36239845521989, 47.561680116961085, 50.1720880693005, 49.958868026733406, 50.54642338906565, 39.97387463046659, 51.453922563983554, 47.34767952272969, 52.279169636387984, 43.715709870861424, 27.71419678964923, 15.187021147820259, 3.5742294211541457, 1.8839344959105215, 6.888314014480961, 5.494396321235165, 5.293774931661544, 1.3326329882106474, 0.18895480511409624, 0.11508517538107212, 0.5161218921984396, 3.4426868538702693, 22.011351008569044, 41.6951322555542, 50.99619373198479, 46.02304412472633, 26.439903051622455, 4.429017824511375, 0.1775551869744255, 0.06120235058328798, 0.05399450126494612, 0.005483909213404742, 0.02644835246516572, 0.025594223801407124, 0.025518266183714715, 0.06892169765647381, 0.06776014748480051, 0.03817944727357357, 0.07900336111385016, 0.028548425461556164, 0.04714544156506177, 0.05139810288505209, 0.0653061073934359, 0.07055580916423952, 0.0713380768654808, 0.16061630881121083, 0.05891126888473669, 0.040302732734069716, 0.05756200801941657, 0.03301410327455209, 0.030923773001338688, 0.04181872497523024, 0.04331571057498936, 0.02092820825055242, 0.083373632251976, 0.008667568571024365, 0.022976413264029452, 0.009040589230285298, 0.05144255896729808, 0.10684675011303156, 0.017808717375080434, 0.007440428345298936, 0.05368203315283022, 0.015906285487055298, 0.05468841604588013, 0.02664260746490571, 0.0434696521129339, 0.05729607591826109, 0.03435325177927171, 0.02180128035345866, 0.9905230037627683, 15.941004637748966, 42.57595146856001, 56.52983434738652, 46.30127353052939, 43.23059897268973, 41.720541369530466, 43.84261423541654, 31.158890916455178, 2.7278469022243255, 0.22235337344388809, 1.9474316628709918, 7.140640577962322, 9.53445230760882, 4.82157108283812, 3.258990246442057, 16.226232532531984, 33.18884495765933, 49.43360774747787, 56.14652856703728, 59.51776258407101, 54.70513989848476, 52.84678759113435, 49.63826525595881, 47.4631227216413, 42.997359152763124, 44.01249993231989, 41.37267028131793, 42.40006846766318, 44.006428103293146, 46.348443954221665, 48.098738885694935, 49.91303120889972, 47.95540371248799, 45.31430713592037, 42.94126533692883, 42.44483840081, 40.95499277114868, 40.36958294530069, 40.157014016182195, 41.980869077867084, 41.038386283382295, 40.207808709913685, 43.045443488705544, 41.655665366880356, 42.54597671570317, 42.82612416052049, 42.54181508095034, 40.57471506057247, 39.09246706193493, 40.55822541636806, 38.12336314109064, 38.49004199427944, 38.09155664136333, 37.290165424346924, 38.54053074313749, 38.948802409633515, 39.540570397530836, 41.184447503859, 42.96345418499362, 43.31855812380391, 44.34303022200062, 44.255953604175204, 47.552894007775095, 49.71015837884719, 55.006068060475016, 48.437349257930634, 44.55399097934846, 48.70487843790362, 51.88805833939583, 55.11599248455417, 50.374141123987016, 52.71362704615439, 52.44799629334481, 53.82645053248252, 50.53731956789571, 48.30204317646642, 38.9780201450471, 37.76302283810031, 37.832899862720126, 38.018333834986535, 39.2161903842803, 41.8090888761705, 45.04257709749284, 48.811712034287, 50.34828093744094, 50.85695743560792, 53.166849074825166, 53.232419336995775, 53.540898061567745, 50.48990595725275, 51.832717618634625, 48.85090827941895, 39.894121077752885, 37.607449869955744, 37.513387510853434, 36.102256005810155, 37.357794930858, 38.97696110510057, 40.061704343365086, 37.86279616817352, 36.20577519939792, 37.63621261042934, 38.64694464591242, 40.758980166527536, 42.75265032245267, 45.25990386163035, 48.94151503039945, 51.51201286623555, 53.63418771374611, 50.32491145595428, 43.0207404013603, 53.09946275526478, 48.3980941772461, 54.29200841534523, 46.799030150136645, 32.045256360884636, 19.822852803814797, 4.73077654838562, 4.344735405137462, 6.048163896606815, 2.409190607647742, 0.7900251075625421, 0.3536206393712952, 0.09763021442678668, 0.3972168338875617, 1.2288820070605124, 3.4224385984482306, 25.17135362471304, 47.55203108633719, 52.38345761452952, 47.404777465328095, 33.32060521648776, 6.50197918376615, 0.05146569482261135, 0.02571040103512426, 0.03531535479029821, 0.059808445944180416, 0.05942675795766616, 0.04991383051439639, 0.07188245128359526, 0.035374504438931906, 0.040963839799646413, 0.005489223948379438, 0.020243356289762645, 0.04007618138266187, 0.08927498373293108, 0.03998777866663952, 0.10484510792359229, 0.01161886292750076, 0.08771996314246809, 0.05691571709429545, 0.02785922786701591, 0.16970413406529736, 0.12288744381118206, 0.0893269244941973, 0.17367846032063808, 0.12346414713970116, 0.13674808876408687, 0.0946450992036731, 0.22031436914638167, 0.07497497203369295, 0.12171388138085605, 0.12239576092049961, 0.1218100713806287, 0.18762869159540824, 0.12068094204991095, 0.138231618029456, 0.23299658701064127, 0.09811451222987906, 0.1424588299086017, 0.16628853105489286, 0.1465642644513038, 0.19806146080936157, 0.17840741382491204, 0.14412015285943786, 1.1511889244279554, 17.6512933546497, 48.60994531262306, 62.33613068057645, 50.80088323162448, 48.02545724376556, 43.60114136049825, 51.52180310218565, 36.67426701514952, 4.285532620645339, 0.65077361200125, 4.9297799602631605, 9.586613947345365, 14.110519789880323, 4.525261511725764, 2.759688703283187, 17.724751503236835, 39.01063857540008, 53.84561523314446, 59.04595244315363, 62.74145664707307, 58.51140006895989, 55.776676516379084, 53.272333375869266, 49.700932964201904, 45.45484958156463, 45.93483394192111, 42.616355803705034, 44.643715197040194, 46.8543787156382, 49.39770237092049, 52.43817075606316, 52.527620407842825, 49.90562969638456, 48.604002921812, 44.680781595168575, 45.138212327034246, 42.52590202516125, 42.612343219018754, 41.5626581253544, 42.65312017933015, 42.30510004105107, 40.52530104114164, 45.409165736167665, 43.91553109691989, 44.91487256942257, 43.897499961237756, 44.99631666368054, 41.54014764293548, 41.576970854113185, 42.53033822582614, 40.543336099193944, 40.7912612730457, 41.09473505327779, 39.12719964981079, 40.17205630579303, 40.64616103326121, 41.20609898721018, 41.91382400451168, 44.296691340784875, 45.91480631982127, 47.212267537270826, 46.35023255502024, 48.54632446842809, 51.21428143593573, 57.854505046721435, 51.54663170537641, 46.61633399225051, 50.32471141507549, 54.50304762009652, 57.20596075057984, 53.219867752444365, 56.24965944597798, 55.0258211166628, 53.99656372685587, 52.37877822691395, 51.549240081541, 41.31701184857277, 38.584378919293805, 40.63002048000213, 39.18949473288752, 41.7186939331793, 44.63891421594928, 47.062283946621804, 48.75264506186209, 52.20269518513834, 53.591339741983724, 54.43975625499603, 54.00596172578874, 56.195958275948804, 52.90494849604946, 54.458893499066754, 50.08555273855887, 41.96930200822892, 39.98972492833292, 39.830119763651204, 38.455015228640654, 40.211727157715835, 40.80773522776943, 44.11809798209898, 40.474067041950846, 38.023072058154696, 38.81341003602551, 41.39199579915693, 42.65687388758506, 45.22780710651029, 47.307628200900176, 50.81446639953121, 53.956732057756, 53.5774584739439, 51.06420763077275, 42.94130063826039, 56.68957679502426, 49.40310347464777, 57.19478984032908, 48.68546662792083, 38.79757542763987, 21.450142206684237, 5.394433246504876, 3.5219204473880033, 11.699663400650026, 11.987292766571047, 14.049255309566377, 4.8358995010775905, 1.2139594723140041, 0.9829089478138955, 2.479068122563824, 5.072385572618054, 30.32039211642358, 51.18192188201412, 59.78098500159479, 56.52104431583036, 39.42264433830015, 7.580429959681727, 0.31520660065354844, 0.15089739564686053, 0.20332966360353655, 0.1903649431563193, 0.1682220910105013, 0.12691789366785558, 0.16000661007579298, 0.2314978738826129, 0.20315977594544812, 0.1502606233641986, 0.1833696717456464, 0.2321614898861416, 0.1931852652060409, 0.16235442441557685, 0.1905316745321597, 0.14880148633833856, 0.16096461834686418, 0.2267865250788389, 0.19736162416877287], [0.04286516660584077, 0.04166399436672369, 0.0695791696348498, 0.06773655963761192, 0.02947362027161064, 0.07836114960692583, 0.05970601615826449, 0.005919671037249388, 0.03285692884556709, 0.018260274495508884, 0.09499555378551446, 0.02010262593807232, 0.010626005316754023, 0.14810051588762194, 0.04792855579345938, 0.03895275557654039, 0.040555005487535274, 0.017625032473475705, 0.01636735358906369, 0.04286678688180062, 0.0958256177123516, 0.04437445174722422, 0.04450708837999452, 0.10106915247536476, 4.950484191217731, 27.784564110540575, 38.55622022382675, 42.61297079824632, 36.27056490990424, 18.117457243704028, 37.03344237419867, 29.961875715563377, 4.35371567164698, 0.1081108411533698, 0.6483579835584087, 5.400387404426452, 7.154198740759204, 4.7744080135899205, 1.3956543226395886, 1.1639914180963271, 11.797693237181633, 29.90966896856985, 47.41741141965313, 57.45918112416422, 54.905733831467174, 52.469051576429806, 51.06876934728315, 46.409840814528934, 45.70191575634865, 42.78717110233922, 44.33586405169579, 45.149336168842936, 48.075396860799486, 50.56703936669135, 50.63794012992613, 49.582045924279, 50.27409715037192, 45.30231645030361, 41.79787874221802, 39.28139194365471, 39.27243325018114, 38.52449609387306, 37.39268441354075, 39.84156131744385, 38.105598726580226, 35.591618322557025, 37.61822462081909, 37.10336646726055, 37.9185801167642, 38.73872026320427, 38.47016734461631, 38.2359508545168, 38.75448819129698, 37.214032219302275, 37.52839057676254, 35.15700009561355, 37.25688019106465, 37.096227753546934, 37.80811048323108, 36.59489393234253, 37.62551238459926, 37.81392735819663, 39.66958107486848, 37.74746671799691, 40.03884084763066, 39.847946936084384, 46.34989130881525, 46.818763594473566, 52.75490214747768, 46.09356049568423, 40.51474594300793, 53.77607945472964, 49.091071082699685, 49.733151312797304, 48.230467765562, 51.2221497105014, 52.129413543208955, 50.90329239445349, 48.5538750310098, 43.79406313742361, 38.69654301674136, 36.889722808714836, 35.6662178808643, 37.03233626581008, 38.93238729046237, 42.03350336320939, 44.87358570098878, 47.18750953674317, 49.65088352080315, 49.022661024524325, 49.7814945251711, 48.013380266004994, 49.13392297683224, 48.81802312789425, 44.92030505211123, 41.91467908120925, 36.11504685494208, 35.52734636491345, 36.919462219361336, 36.66031514444659, 37.118706857004476, 41.1116365463503, 42.13773250579834, 42.88838001989549, 37.9217533142336, 36.85020492922875, 36.974124370082734, 36.40319201254076, 40.47376109707741, 44.1013337719825, 49.12527022823211, 50.50766252702283, 51.99161283431515, 50.95194155170072, 50.035695491298554, 47.03415270774595, 54.87304872082126, 38.23397790232013, 34.940359746256185, 10.847198021027351, 1.9538990384148014, 1.233960250692983, 3.6942715990927915, 3.9736137322841154, 1.7079314950012392, 0.17514234709162868, 0.061104601594589414, 0.1232167620271925, 0.6200045791845168, 0.7511189339622375, 6.240843467174038, 23.940749206850608, 32.82905967004838, 43.247021936601215, 51.26410338186449, 23.230462881826586, 2.2703144338823136, 0.03443210137887828, 0.0635059999542371, 0.04472078860647256, 0.0502442327448197, 0.023652070254508047, 0.019082870980304097, 0.012927918540944737, 0.016991556284107992, 0.022998648966031692, 0.06810875579474435, 0.0263507547788322, 0.017045785733047995, 0.06914167214305171, 0.051496790331457896, 0.02351330300312369, 0.028960858471691612, 0.0796404398316818, 0.03389642971958365, 0.017367006399698796, 0.034974901486308344, 0.024570579032203364, 0.028232335668778228, 0.04672178728205543, 0.04831713857129217, 0.05033109562411424, 0.06563806861278511, 0.04149789884386044, 0.05172891114207526, 0.022107949179987756, 0.07866349386712236, 0.02917788926542046, 0.06642455745848917, 0.06447827278245842, 0.0725427424655326, 0.04621917997757274, 0.057041780692675424, 0.02981763971488803, 0.01743647525267255, 0.03177522801824155, 0.006574935724793543, 0.015773632574916607, 0.04224360882935505, 0.05392830743784866, 7.103451605766051, 33.53686901830858, 46.49662325459142, 47.94821008559197, 40.29981182467553, 24.97599017235541, 44.05033511500205, 34.51698695459674, 4.996710304291018, 0.05682754803509001, 0.7120526173422415, 5.877037259840197, 5.780651877003332, 4.377089565800083, 2.3814611665664183, 2.1146279621508817, 17.105958384852258, 35.15103809295162, 50.91534191562284, 59.384268637626406, 55.92509508132935, 53.824799214639974, 52.38592870773808, 48.813253525764715, 46.15221954161122, 43.43414252804172, 46.23805669046218, 48.37284980281707, 49.26154905749906, 52.247822053970836, 52.95051074797108, 51.50590181350709, 51.498335561444684, 47.54770863440729, 44.90920866689375, 41.076519566197554, 41.488784205529, 40.45261559947845, 38.66212029610911, 42.2555918847361, 38.70704320169265, 38.61729937215006, 39.89106162901848, 39.578813506710915, 40.5307178343496, 39.368656835248395, 40.276195233868016, 41.295179936193655, 41.27031210930117, 40.02482621900497, 39.16419544527608, 38.280920828542406, 38.96549209471672, 38.72540773883943, 39.38558578491211, 37.57035993760632, 38.78241938929404, 39.20103826830464, 40.5497609415362, 40.86733564253777, 42.606957804772165, 42.55939514406266, 47.33475923538209, 47.68095547153104, 53.576611241986676, 49.065520763397224, 42.442116275910415, 53.68665725954118, 52.40840781119562, 50.55691180690643, 50.926367698177216, 52.33998990827992, 54.08735875160464, 52.52613382954752, 51.39686384508687, 46.66696394643476, 40.124140631768014, 38.010830340846894, 37.3384968696102, 37.72129274183704, 40.00990944523966, 43.1567995778976, 47.02144815075783, 47.9574001989057, 52.271430800038004, 50.83712593201668, 51.76961452730241, 51.01168709416544, 50.180882023226836, 50.0928012786373, 47.470994918577134, 42.12296478209957, 38.13916244814473, 38.1944521780937, 37.73584081280617, 38.48016546618554, 38.49725523302632, 43.0733903761833, 44.52585581810244, 43.781939091220984, 41.80761406498571, 37.944346166426136, 38.63384392953689, 38.253181826683786, 42.12674594694569, 44.85537805864888, 51.61351988392492, 52.28863823798395, 53.313577098231164, 50.902888390325735, 49.540747288734686, 48.33609719430247, 54.341402822925204, 44.07035489236155, 41.04157909270256, 17.445588573332756, 3.792464213986551, 2.056062195089556, 3.0714033832473144, 3.13377887491257, 0.8770438704279162, 0.203149801480674, 0.14131409536686637, 0.24544036766934782, 1.2384914462604832, 1.1261083089536237, 7.8885066413110305, 28.691588678667625, 38.741195278783, 49.043555490432254, 59.11637467722739, 28.713267618610015, 3.068520441170662, 0.12542205336954326, 0.06537821924974842, 0.03527901157917034, 0.013361323208007361, 0.039964382341432, 0.047391983980853716, 0.01070834827729531, 0.06439591066971903, 0.02152682935458518, 0.015086999459702884, 0.02236921389046456, 0.016110639440857114, 0.10883826462011184, 0.044511650433583606, 0.04331563013575731, 0.026244278133456266, 0.03264286855776464, 0.017846686607827584, 0.015824747876444414, 0.1431662508196408, 0.1873997998453917, 0.2107518298491355, 0.15165073586808098, 0.12330374365011532, 0.1477825127902531, 0.12131155498566167, 0.19254279322922233, 0.13497150022416346, 0.10397487800688514, 0.217467509810963, 0.12415580196125854, 0.08378667621723107, 0.19237151129111169, 0.13203012096064706, 0.07661757179565969, 0.16415646239634485, 0.12520966315341572, 0.08157950795946584, 0.18041016684184152, 0.14078845179850055, 0.13913659769440853, 0.13582371175289154, 0.20405125714117484, 7.037950475369731, 37.984244515818936, 53.476037748398326, 56.1764915527836, 49.44655156904652, 32.292006784869784, 50.30449551920737, 40.79465804561492, 6.231861729775706, 0.255156722100031, 2.523325205810609, 10.77936553185986, 11.88235955853616, 9.678541556481393, 3.2205117950516366, 2.576976855916362, 17.535987438694125, 36.919391616698235, 54.34110472279211, 61.99332337225638, 58.020644880110225, 55.78242278868153, 56.51993036270142, 51.54597666955764, 49.32496201607489, 45.68342178098617, 48.12584638595582, 49.46443365466211, 51.97595865495744, 53.963784479325824, 55.55003412308232, 53.39000840340891, 54.233557255037375, 49.58913756955055, 45.65661238085839, 42.78280942670761, 43.93058123127107, 41.20375340984714, 40.56739591783093, 44.21849104665941, 41.354796040442686, 40.13276592377694, 41.995915289848085, 41.34234643751576, 43.17661539200814, 41.62530229937646, 41.26447562248477, 42.05783774775844, 43.38707016360375, 41.63246062494094, 40.50672077363537, 39.39278725654849, 40.17803792030581, 41.502928272370376, 40.95242361868582, 40.44036995980048, 41.78704515580208, 41.172558799866714, 42.94882766662106, 40.83669016438146, 45.23770716882522, 45.52556991577149, 49.056467933039514, 49.59460143120059, 55.91114321062642, 51.73534477910688, 44.87136563947124, 55.04904547045308, 55.02934340507754, 53.23314497547766, 53.184068279881636, 55.01103378111317, 56.64276330701767, 54.985671735578975, 53.27177247693462, 47.744741055273245, 42.70240083817513, 40.446955619319795, 39.19143630612282, 40.18328605159637, 42.76499794375512, 45.33946914057578, 48.76086634974326, 48.77282565639865, 53.374758228178955, 52.46366616218321, 54.22112334159113, 51.63175890522619, 53.343469481314386, 52.36644629509219, 48.123606712587424, 43.743519475383145, 39.384573813407656, 39.76200388323876, 40.15374275945848, 39.46253876532278, 41.36002063751221, 45.31424437799762, 47.64234365955476, 47.7844472085276, 42.850509535881784, 40.377588502822384, 41.893353154582364, 39.907280629681004, 44.88090484373031, 48.166858688477554, 54.7573584125888, 54.55201056695754, 54.84536070977488, 50.958476220407796, 49.07373420653805, 48.64898466294812, 55.847804777083866, 46.316849262483665, 47.30265463552168, 18.735050116815877, 3.812466585828412, 2.130977136473502, 7.30030506849289, 13.234991854236974, 5.992917803026015, 3.7543029842838167, 0.8618611722223221, 0.5448355417578452, 3.0678808496844385, 2.4146667267045667, 11.41114071492226, 33.93231061197097, 45.009923365808305, 51.690194376053356, 62.81149448886995, 33.749743892300515, 3.709692397425252, 0.253637922146628, 0.1650508547261838, 0.1684781788818298, 0.1975055261244697, 0.17544786295583173, 0.17240857765559228, 0.12754015624523163, 0.18105982472338986, 0.1499299491725622, 0.1694687918549584, 0.14307926919671798, 0.13163606065415567, 0.23016766945440925, 0.12038746908787759, 0.1432923795354943, 0.12211863627477039, 0.1294444209986156, 0.18906006559489236, 0.14153249171232024], [0.0696074995662897, 0.02774677573583059, 0.02577658911656228, 0.07541760997546297, 0.050586482524992, 0.045207334877622705, 0.013077548919095388, 0.004483391681025106, 0.020093042178139574, 0.049351836074023485, 0.021350918330192085, 0.020993827511706663, 0.05082108929092365, 0.08993322946011059, 0.05820050783034775, 0.06870963685815373, 0.05710506721610024, 0.026700021924390912, 0.06184644283606641, 0.0018402044811556418, 0.05039088112572509, 0.050200921964020505, 0.05004013543047252, 0.02273973806070224, 0.5153817899765507, 13.824861414970892, 30.11529726366843, 38.66999641541512, 43.58917420910251, 25.78308059323219, 21.471330850355088, 26.661842523082612, 6.68021805824772, 0.2158097415080955, 0.8748755351670328, 6.363457249056909, 4.4320566808023765, 1.9473067598958171, 1.127545367325506, 0.4688265655309924, 4.20912730116998, 18.90895232077568, 39.76926419042772, 55.880254545519435, 56.56055827294627, 54.157039657715835, 50.84201712762156, 49.03247479469546, 47.9460096359253, 47.334657253757605, 51.042838558073974, 50.92739143679219, 52.511715196794086, 50.89258824625323, 53.205088261635076, 54.42705562037807, 50.55377391076858, 46.78970275386688, 41.68567542106875, 38.20684294546805, 40.41447839429302, 38.862941726561516, 38.346118465546645, 36.39926571999827, 39.77515559042654, 37.9088604834772, 36.8208420661188, 38.099950513532086, 37.413688705813506, 38.94988498380108, 37.799155712127686, 37.92750350890621, 38.776935915793146, 37.64544586981497, 36.87035806717412, 37.26638801636235, 39.421138148153986, 36.430221065398186, 37.55679245918028, 36.94016448913082, 38.77051499582107, 39.106434622118556, 39.50636340725807, 38.60779546922253, 42.100442532570135, 42.19800756823632, 46.21310257142591, 49.3419341118105, 53.47521012829196, 45.59938107767413, 40.92435121536255, 55.510500554115545, 48.524402341535016, 49.53511476516724, 45.56622136023737, 47.30962076494771, 47.52641408674179, 47.01627454450054, 42.8581581577178, 38.31488855423466, 35.18718273408952, 36.302767569018954, 36.54903750265799, 35.9277811358052, 38.496627653798754, 45.69562427459225, 47.45630171991164, 48.044539574653875, 48.97946003944644, 48.67763757705689, 50.16948361550608, 48.80495771285027, 46.87482995371665, 45.58144407887613, 39.9070688216917, 36.9050867326798, 36.71651486427554, 37.115910207071614, 36.62491575364144, 37.379481715540734, 39.31927811714911, 47.04513534422844, 45.14237788415725, 46.73031022471767, 44.073178998885616, 42.82018961444978, 39.06164507712088, 38.41909808497275, 38.2658314704895, 42.73792966719597, 46.985013254227184, 49.78990016445037, 50.358792889502745, 49.58663117501044, 48.704858826052764, 50.071192941358014, 46.47174758295859, 36.69442407546505, 14.280577090478713, 4.577484438496252, 2.5473377108573914, 0.8301325683151523, 1.7738933813187385, 0.705537008902719, 0.3409540803442079, 0.1044214613014652, 0.035613010592398145, 0.06653511926772133, 0.24440103150423498, 2.296072393655777, 12.11653780552649, 24.855777371314264, 34.234937160245835, 38.54081707616007, 37.04940249842983, 9.610269761854603, 0.35970938361940846, 0.030848654249923366, 0.033329980477931044, 0.07316158062988713, 0.023998989340578838, 0.015117215882656316, 0.0507425461264868, 0.08589596908179023, 0.0036086631523850827, 0.021157563483763128, 0.0470075304169328, 0.061354939976046165, 0.04577497921643719, 0.03330122536769317, 0.024204697354786822, 0.03783133692078052, 0.034697926227724364, 0.031675039039504145, 0.05068386379148691, 0.00574591224111857, 0.029094383766454075, 0.06679109988674041, 0.06649717493283172, 0.01813079606020643, 0.030872414466894926, 0.052261993424185825, 0.02839834500675, 0.02643007360729239, 0.030454279847383022, 0.025358749440901225, 0.0144433448346512, 0.06179270176817814, 0.021924067010742523, 0.03664700712467875, 0.020862539193683097, 0.008012590687646861, 0.06751915154558036, 0.013172292927910965, 0.06695338795261999, 0.0061164052890343296, 0.04332544755250697, 0.022253909996981104, 0.05232652101004797, 0.026160065918379737, 1.3225254079987927, 20.150035350553452, 40.93395317754438, 49.88771623180759, 48.21044406583233, 27.43441216407284, 34.472766153274044, 33.403877135246034, 7.421088574394104, 0.13513973313233546, 0.8519270343165245, 3.3848147334591037, 2.3138122933526195, 1.7830553025968614, 2.340310110199836, 1.6089621282392934, 5.396529753361979, 23.934806816039547, 42.36007598138625, 59.19419057907597, 58.35730583437028, 55.66428099909137, 53.14009851024997, 51.45587590432937, 49.75358686139507, 49.57263223586544, 52.266406243847264, 52.78482198715211, 53.555414753575484, 54.482816034747714, 55.64270796314363, 56.27690422919489, 53.49439051843459, 49.59452298379714, 43.991883954694195, 41.114617547681256, 41.55347977915118, 39.70048542945616, 40.1804344884811, 40.20623583947459, 40.18829884067659, 39.93062657694663, 39.22429007868613, 40.837729592477125, 37.920494233408284, 40.86084411990258, 38.29351555916571, 40.27123343560004, 41.03031404556767, 39.47272123829011, 38.91245380524666, 38.61969201795517, 40.99495780083441, 38.44905322597873, 39.029830732653224, 38.80329424335111, 40.11868853722849, 39.94706915270898, 40.38720223211473, 40.52433221570907, 43.46210510500016, 43.91701375284503, 47.87056676803097, 49.61083219897363, 54.79196548461915, 47.45558000379994, 43.87263997908562, 56.46611936630742, 51.013444316002634, 52.25701608965474, 47.988022142840975, 48.97977775143039, 49.51822503920525, 48.56142167122134, 44.792133761990456, 40.92495918273926, 37.754778015998106, 38.65065128572526, 37.17658927363735, 38.125143897148874, 39.33377127493582, 47.05658082039126, 49.68664376966415, 49.0619670960211, 50.436608791351325, 50.93525578898769, 51.214151997720045, 51.50844350937874, 49.37768651593117, 46.40192154915103, 42.57649667801396, 38.400266785775464, 37.86705193981048, 40.04917629303471, 37.90904091250512, 38.82371018009801, 40.90131121297037, 47.70663130667902, 46.09314472444596, 48.101370796080566, 46.02606827212919, 44.85386402376237, 40.67830485682334, 39.877737337543124, 40.10335599222491, 43.20093800944667, 48.88067514665666, 52.0025719365766, 52.58587544964206, 51.07635128882624, 48.564869434602805, 49.0808258518096, 47.96689233472271, 39.96563373073455, 20.086716528861754, 6.325057245069935, 3.2409360668351574, 1.2990928008671732, 2.7350218978620346, 1.37822772226026, 0.5319391563534737, 0.03976079447555446, 0.042097328170653314, 0.4799881295090722, 0.5874468842821737, 3.1058464511748287, 13.594441779198187, 32.046809619472874, 38.77834012431484, 43.42456017771075, 44.843744308717795, 15.203677492756999, 0.813557428698386, 0.013634792656727858, 0.013441137120788618, 0.06639448084658192, 0.022472038211661483, 0.026347903016534065, 0.011321649541177098, 0.0376378805677016, 0.03251302048503872, 0.007318340743245978, 0.040415654094108654, 0.02184151337602206, 0.01883656796698849, 0.009278451869895142, 0.04646182683626971, 0.006419664545495424, 0.05104440392085141, 0.008394886277646067, 0.04308406090844543, 0.06375833016429698, 0.1783465864437242, 0.12927434947942534, 0.19738102151501566, 0.12840269463917903, 0.16402454205578373, 0.15926963349263515, 0.2682834394997166, 0.13071408915904262, 0.2123285766931311, 0.1394888296002342, 0.1557402817472335, 0.1271678681575483, 0.1516527123749256, 0.18552098453285235, 0.09611670814094045, 0.17218325587530292, 0.12278427475041921, 0.13913048431277275, 0.16130185025113244, 0.08452653329098418, 0.19524924396987886, 0.15432136433739818, 0.12654494674455735, 0.1106371463186318, 1.1873856595446988, 20.0166335798079, 45.788066694813395, 57.15697426949778, 55.08538623009959, 39.056950000024614, 34.061038878656205, 36.68006820063437, 10.157000114840846, 0.41596156514940724, 2.153333911011296, 11.68005939452879, 15.717112806535537, 8.673568541003812, 3.7405889072725853, 1.2549471374480956, 6.43206685781479, 24.22364034960347, 44.016736092105994, 60.28741398165303, 58.69798329568679, 58.74384364774151, 54.65605535814839, 53.99958002951838, 52.876338728012584, 52.52298024392898, 53.86750598107615, 56.98903014582973, 55.78131275792276, 54.87673574878324, 56.726521599677305, 57.6791476434277, 55.31750032978674, 52.409294266854566, 45.94251394271851, 42.18322023268669, 45.401003283839074, 42.29280733293103, 40.75492051339919, 41.50283021311606, 44.371373268865774, 43.441936277574115, 39.90747282581945, 41.950592302506976, 39.44666101086525, 42.25559580710627, 40.22042305238786, 42.11567701831941, 43.83697778947892, 40.66525120888987, 39.544277037343676, 39.666152923337876, 43.0027327998992, 39.8695788075847, 40.3989811097422, 40.68529452047041, 42.354514060481904, 41.57396631856119, 43.32683040249733, 43.48037942763298, 46.17425149486911, 46.41876420667095, 49.43059144481536, 52.8407589081795, 54.60158932593561, 49.80350294420796, 46.635012319011075, 59.17870506163567, 55.01604264782321, 53.43650810180172, 49.94905425656227, 50.10383490593203, 51.69914522478658, 50.71585801339919, 46.539094678817264, 42.32296643718597, 39.21322115005986, 41.188911161115094, 39.77490848110568, 38.21750002522623, 41.06279519296462, 50.487277969237304, 51.054499764596265, 51.87607549851941, 53.08367129295103, 52.506369006249216, 53.653093537976666, 53.85480926882837, 51.2605889381901, 48.38494247005832, 43.70810831746748, 40.06236722392421, 40.83345813135947, 40.5316395913401, 39.747714688701016, 40.973961353302, 42.444936460064305, 50.13982265226303, 47.91077890703755, 51.402947441224136, 47.20523864992204, 47.62699542507049, 42.51102447509766, 42.34354319110994, 41.594978455574285, 45.46151761085757, 51.50921621630269, 54.39777120467156, 53.33275356600362, 50.664737762943396, 49.72394551000288, 48.27734401149135, 48.44793965739589, 42.523528991207, 21.372857785994007, 8.42456961831739, 5.070639627595102, 2.534157076189595, 8.865596017529889, 2.6039409445178126, 1.9040756215972288, 0.6064774889138438, 0.193213349989345, 1.5086815866731829, 0.6781389468139218, 6.346293937775397, 17.79007661727167, 36.02043536401565, 44.14166750446443, 51.168989827556, 50.81343873854607, 16.1018531937753, 1.092219275812949, 0.14277045915444053, 0.09310385287408868, 0.21659272933198562, 0.0837222329010406, 0.1249421988764117, 0.13704183751777296, 0.20621036870344994, 0.13596053505616804, 0.13073575412554125, 0.14045414635010306, 0.1920643253552337, 0.12160780118598093, 0.11680207801081481, 0.14023564275233977, 0.1540464153813739, 0.13732815521859354, 0.10719212553193493, 0.1318512394303276, 0.16898273971051941], [0.022042176701248656, 0.01388405181182128, 0.03506901155736658, 0.02124497794636315, 0.052521582317328265, 0.024799330971173705, 0.04609104411135759, 0.03687680285844592, 0.012587742943827425, 0.03735578018090418, 0.06437013181106699, 0.029360748707286777, 0.045137781754977284, 0.03814069854636346, 0.06021438444393778, 0.022171325718743667, 0.02112411225454942, 0.040259889266904325, 0.056580013535436124, 0.052071919349292596, 0.044052430518692544, 0.04704052965427118, 0.028642363162831436, 0.03852817432714566, 0.061985043463327234, 4.314798895389804, 21.624685718167214, 33.19146510093443, 47.74549415034633, 33.906324909579375, 26.219224622172696, 28.525337057728922, 9.157412513609856, 0.22885180619214812, 0.44351805422094565, 1.7715258631975421, 1.6961619330029336, 1.9869530970050444, 1.4062533022895938, 0.9988481118794411, 0.6321764292736208, 6.628471209156898, 27.61476862815119, 48.076295083568944, 56.16735243028211, 54.3985870576674, 53.224001930605986, 51.23090836309618, 52.14986870365759, 51.44362634228122, 51.19382235311693, 53.085071579102554, 52.79323154880155, 52.55564182035385, 53.35011005401612, 51.31109337652884, 47.90436583180582, 43.074163083107244, 41.389905175855084, 38.62911355110907, 39.736343737571474, 38.98555109577794, 41.77954166166244, 41.70305544330228, 41.880162223692864, 39.946622002509336, 38.789079573846635, 38.600315509303925, 37.979055220080966, 38.48718258642381, 38.445691754741055, 36.540686776561124, 37.45736037531207, 37.59606322934551, 38.10039374136156, 36.84236018888412, 38.502507286687056, 37.72112407991963, 36.51376755006852, 36.59683158320766, 38.07546315654632, 38.436827198151626, 39.95428631382604, 42.71234404656195, 43.98584350462883, 44.97937594690631, 49.15303276431177, 48.05092911566458, 55.65347486926664, 44.813345939882346, 40.76069816466301, 54.2940951162769, 46.454520533161784, 46.623260897974816, 41.569486971824404, 40.14074402470743, 39.030046463012695, 39.71226430708362, 36.761731947621996, 36.33602926808019, 35.12899829495338, 35.29193747428156, 35.361940014746885, 38.92059272335422, 40.70735000794934, 42.90221814186343, 45.69457307938607, 46.380564243562766, 45.5240951045867, 44.73205874043126, 41.90799536243562, 41.8494265310226, 40.48092334501205, 37.679241011219645, 36.31565255503501, 35.90208961117652, 36.64238991275911, 36.277809527612504, 37.976792012491536, 37.01090835755871, 41.42014664988364, 48.37401474675825, 51.08346646831882, 47.36001537692162, 44.764218253474084, 44.01271958504954, 42.27272872001895, 40.121696995150664, 41.03558178870909, 41.81874575153474, 46.279731873543035, 47.913199009433875, 49.591718489123934, 53.80113163302022, 49.875721623820645, 47.24134014498803, 40.870567675559755, 25.040470015618112, 6.277557832579459, 1.8595011940886899, 1.7132211789008112, 0.2379358622936472, 0.501491206307565, 0.16699815829915388, 0.09884867727035478, 0.11368826001642213, 0.07882644842949607, 0.06324633445230222, 0.5178594408977417, 4.02587392157124, 18.97570125518307, 18.22327886858294, 34.06436504856233, 41.635555375006895, 27.993818636863466, 1.2879829325022236, 0.3642025505823474, 0.005076800035538092, 0.0452799600128445, 0.06239448298489856, 0.06106671854673375, 0.10515315953882472, 0.028986378775669203, 0.08936152868573705, 0.029687887403152646, 0.009162130994692205, 0.043834221864780115, 0.03264318265381359, 0.01967687640459307, 0.04521848145692099, 0.07319342690489947, 0.05515088800400977, 0.004208325417787438, 0.03932973978319957, 0.030734865295310176, 0.02726686761654433, 0.044583589920113166, 0.022854047955103943, 0.011855315007720024, 0.04737138770700944, 0.0387752338522865, 0.04105615722496183, 0.03247968799945328, 0.00931616829362728, 0.017761612543836236, 0.04570728002656852, 0.03671487485389075, 0.05769535711395645, 0.008012351763975478, 0.07439153479231943, 0.02348881883306369, 0.09868116448483161, 0.08261876751578624, 0.012048871909839012, 0.04794624476363102, 0.06057753310268445, 0.042132127714613755, 0.021323676243604674, 0.04649603649252846, 0.04326331782184782, 0.07286038550157702, 6.708175241947175, 28.327547619419715, 40.19075816677463, 54.11464275852327, 39.132855707599276, 26.61783156856414, 32.34807118292778, 10.461832996337645, 0.39586478063175756, 0.23721357927687708, 0.9255777467643062, 1.9246309250593188, 1.0122184299172894, 2.5027254079618766, 1.5840708896998437, 1.6815034227986492, 7.87746467897969, 31.640432457770075, 51.05845351372996, 58.528889917558246, 55.67921738470755, 56.061279773712165, 52.60108247880013, 53.76080574527864, 55.11440392463438, 54.24286111708611, 55.27147523818478, 53.28819544084611, 52.624463727397305, 55.04658222198487, 53.02476906007337, 50.28119271801364, 46.231039570223906, 42.325755242378484, 40.022300212614, 41.691962980454974, 40.04058630235734, 44.49744609094436, 43.24116191556377, 42.55706525618031, 41.81502734461139, 40.2398701637022, 39.93955389145882, 39.694801915076475, 40.62576470836517, 40.39424288657404, 39.618033286063906, 38.74120312352335, 39.1284312740449, 39.47117190207205, 37.72050826780258, 41.51661734427176, 40.22448662788638, 37.9708456993103, 39.19477032076928, 40.38183250734883, 40.62959686402352, 41.894773052584746, 43.13899201731528, 44.859378876224646, 46.80971860885621, 50.763118651605424, 49.98373193125571, 55.86798537162043, 45.00811123078869, 44.583832371619444, 54.78701937583185, 49.434525582098196, 48.72108959382581, 43.85389104966195, 41.64010924677695, 42.2089352915364, 42.5498833963948, 40.09344416279947, 38.736986575588105, 36.93255509099653, 37.01704294450822, 37.47091216425742, 40.46911308842321, 42.12163509861116, 45.234683021422356, 46.602154624077585, 49.71094285288165, 48.07510660540674, 46.78434871858167, 45.32800797493228, 44.93036593160322, 42.60531040929979, 39.163222697473344, 38.70789435602004, 38.172279019509595, 38.560272032214755, 37.66274352227488, 39.30864064924179, 38.937533440128455, 42.88150410498343, 50.174061021497174, 53.06071366033247, 49.559182428544574, 46.80122667743314, 46.16917594786614, 43.05242530761227, 42.04314062672277, 42.70833538424584, 44.15772961032006, 48.5872700906569, 49.25517128359888, 53.14662141184653, 54.23036444571711, 49.958977853098226, 49.603646416817945, 40.84506050232918, 29.939690789868756, 7.906721638094995, 2.952933830599631, 2.22397800414793, 0.9610327861962781, 0.5994232287330012, 0.11529529031606452, 0.09586305642921118, 0.09491047206064386, 0.09792079157646626, 0.2486448368478206, 0.40419712061843566, 5.373345603865962, 22.224167047008393, 24.79108964243243, 36.33375821575042, 45.883627399321526, 35.67032852480489, 3.6771563368458904, 0.29422789571746705, 0.03896936819317841, 0.05082921365336065, 0.1163476652976486, 0.07228912139732031, 0.09571557684290795, 0.08452689335230859, 0.057082632331237684, 0.024401093570275173, 0.016914051168808536, 0.013293981206633393, 0.059962146164428805, 0.040171463568244255, 0.03232710626757434, 0.039192648349149574, 0.026898367833646557, 0.05027355476012153, 0.03965898139041759, 0.04684616548700198, 0.044007553088088194, 0.18461609679845073, 0.11466210332488823, 0.1250496350469128, 0.1310552434334832, 0.06394572293145523, 0.09454726977574249, 0.14388934588961064, 0.13716448819445026, 0.07355665217243856, 0.0878665081015037, 0.09963629226530753, 0.04745885579576416, 0.11592484605047973, 0.11407267527594683, 0.25791116058826447, 0.2123122743421024, 0.15886398993672865, 0.12984845576988113, 0.1225371271251671, 0.22571649943147937, 0.17366209668257546, 0.1488037846021114, 0.11101167904393328, 0.32991080034163695, 0.25883417396295455, 6.53601800241778, 31.89850284207252, 48.99354134836505, 59.77459153821392, 44.96686358605662, 37.68954115529215, 38.87175136996854, 14.251338762621726, 0.6925693466778725, 1.1183049986439368, 4.862754498758624, 8.378171901549063, 9.98135441733945, 7.5249965729251995, 2.8454858929880205, 1.2958557423084014, 9.531644871157985, 32.21331423328769, 51.59992494890767, 58.36730395593951, 58.4809507093122, 57.87806672434653, 55.607681197504846, 56.02824949449109, 56.57097608812394, 55.7113572858995, 56.501067684542754, 54.93474760363179, 53.52302774306267, 56.36176470787295, 54.58280509518039, 52.6082839504365, 46.86888756290559, 45.51491675838348, 42.05507639915713, 43.396581911271625, 42.222545916034335, 45.771216192553126, 45.137804400536325, 45.39637488703574, 45.17794593687981, 43.741464153412856, 42.11624183962422, 40.274520381804436, 41.99105547320458, 42.3959146776507, 40.61369557534495, 39.856587917574, 41.472431844280614, 41.351622842973285, 39.03818145875008, 42.16042733961537, 41.43503204468758, 39.18610188268846, 40.70949946680377, 42.04092448757541, 42.13597920633132, 45.03130812798777, 46.33947741600775, 47.93501130996212, 48.428092464323974, 52.0469613998167, 52.45737075805665, 58.59931999637235, 48.10161006066107, 46.90058815863825, 56.45154383874709, 51.53000085584579, 50.087678663192264, 46.11875780167119, 42.96775702507266, 43.91628811436315, 43.586809019888605, 40.92071125584264, 40.236065464635054, 38.34430240815686, 38.32600847367318, 38.94850823187059, 43.06726363397414, 44.49433957376788, 46.500588770835634, 48.49611813022245, 50.93540091668406, 50.544132724885024, 48.02356273897233, 45.84284651663996, 46.18111564267067, 44.591120135399606, 41.702145453422304, 39.95104251369354, 39.08230420081846, 40.20710268328267, 39.50472385652604, 40.020201744571814, 39.77843861426077, 43.99615541581185, 51.53408796556535, 54.84576079153246, 51.97020453791465, 48.24434903360183, 47.64166116714478, 45.690584028920824, 44.95493173599244, 46.120205156264774, 46.323682031323834, 50.72821347944198, 50.62980513418875, 54.96767590122839, 55.094297855131096, 50.12083053588868, 48.84051007609214, 43.26044428733088, 30.955614082274902, 8.416250271181907, 4.473439647305397, 3.5059598328605777, 2.416930179442129, 1.969599795918311, 0.5510061041962716, 0.5129413709284798, 0.24658571508142257, 0.3479748471610008, 0.6494932032881245, 1.1445522740963967, 9.06931019598438, 29.023403544579786, 31.040874642710534, 45.211878361240515, 53.40670201086229, 41.39301561540173, 5.822609961032868, 0.4069421668687175, 0.18781215433151494, 0.1395223689295592, 0.15516833582472417, 0.15061020460580626, 0.14328418239470453, 0.11618564536254253, 0.13067518721424765, 0.12451643785161358, 0.11020884188192506, 0.11014377037363668, 0.169795022736634, 0.11155600749677229, 0.17395586075802005, 0.2109198635744472, 0.2176945016629273, 0.14594048501983767, 0.10129124136461366, 0.15027966830999623, 0.09260388857294476], [0.0423544196171626, 0.01374444090611031, 0.026245057627919222, 0.12144739769639508, 0.11147765968475612, 0.04567610790892955, 0.007882063669498049, 0.04597485155588196, 0.030512203755337867, 0.052318557526075074, 0.05721973908704616, 0.02245320777048267, 0.0359845134399591, 0.03463689583323656, 0.071909609100511, 0.034512084788612785, 0.034362655508542256, 0.010824300472684687, 0.03783368881070807, 0.053486722866974534, 0.01254963198481428, 0.01607137168907831, 0.09828995402541854, 0.03337468170831281, 0.010461350039188421, 0.42181588649269075, 10.990376299427403, 27.765621023793376, 37.29053020477295, 41.28569172274682, 29.788146095891154, 28.907093501860096, 12.432279779065041, 1.24495551230446, 0.290133063831637, 0.8739467301676351, 0.674398476558347, 0.3567599451109287, 1.8238432945743686, 1.1955135459861448, 1.49509278035933, 1.5752862514026704, 12.901128530502321, 37.38531820235714, 56.4834209411375, 55.81178957416166, 53.220546322484175, 52.998677453687115, 53.412573799010254, 55.8860400415236, 54.18162899632608, 52.00050876986597, 53.25136046255789, 54.27313004770587, 52.28198982054188, 48.81632474160964, 43.75895400201121, 39.32393397054365, 38.27013038819836, 40.34267156354843, 38.77354306559409, 40.67816365149714, 46.29858670696136, 50.37675734489195, 47.70839245088639, 48.80864866318242, 44.69677702073128, 40.15992441485005, 39.61130249884821, 39.35832138984434, 38.41298310987411, 40.200230690740774, 39.6482982943135, 35.89444098934051, 38.363396506155695, 37.4446048275117, 37.99046539491223, 41.27638001595774, 40.69419045602122, 42.4543736826989, 42.48064964048324, 40.28935870816631, 44.63702363352622, 45.5337715918018, 46.79150312177597, 47.29533549278013, 50.75483460580149, 49.53186312029439, 54.75815465373378, 44.4102478796436, 40.23490052069388, 54.52918237255466, 46.196687452254764, 47.48414270339474, 40.049086078520745, 38.419949239300145, 36.40113276820029, 35.6059310513158, 34.76671641872775, 36.35240516354961, 34.91630384998937, 36.5824874754875, 36.13014405773532, 38.88739770458591, 41.78726480853173, 43.56038401203771, 44.540384277220696, 45.43324124428534, 39.73484146979548, 38.92728036449802, 37.216781800793065, 37.384722002090946, 38.081515373722205, 37.03068494796753, 35.19594923142464, 35.33307137027864, 37.10958342398367, 35.73608706074376, 35.49815608609107, 36.543448125162435, 42.27600389911283, 49.973416097702525, 49.12488191358505, 50.42057021971672, 49.53686806463426, 47.50236995758549, 44.32870180376115, 42.01995941900438, 44.36109665901431, 44.29144713186449, 46.045130991166644, 47.64781144357497, 49.113283464985514, 51.39117248596684, 50.15208005905152, 42.859581978090354, 28.390503621870472, 7.962168753147126, 0.5530498429171501, 0.24516048510709118, 0.9565200380259945, 0.35055503128997745, 0.10828114249893736, 0.06287089008237086, 0.138063921382831, 0.06556860742069061, 0.06792874045429692, 0.2726284757016167, 0.4621817333804023, 11.387620222183967, 34.381429841441495, 28.045786119276478, 34.678553304364605, 37.83619465366487, 19.15327479762416, 1.5788956899796764, 0.11024184494970307, 0.0041013417179666225, 0.0848377182058269, 0.04368807144102551, 0.014102381124581783, 0.02066146601141701, 0.014543478272014089, 0.023856744050018253, 0.03908632300613869, 0.039853380031643376, 0.04479753146428735, 0.0337022187698993, 0.04292644214846435, 0.0947159546757898, 0.019645240803759907, 0.033110852518509475, 0.029037091881036762, 0.030049277890113094, 0.011336567188282649, 0.06837565316668442, 0.029746228829026226, 0.022030465132106217, 0.05336854614377503, 0.046560403199926506, 0.06349144428367577, 0.024686220004373503, 0.0020810991531283025, 0.036488997659856276, 0.04911561669301122, 0.011098560907187001, 0.05711588054715146, 0.05014836067153562, 0.030082325007946744, 0.03199695684616605, 0.017165320347093286, 0.025038314014372808, 0.025865533839791052, 0.017862222870931994, 0.05110983549046421, 0.039879545764697176, 0.02051710631818541, 0.03830283722509781, 0.04682446604654674, 0.07817878237655086, 0.07135183580460087, 0.8404029268891582, 16.08305621531702, 38.88013739739695, 48.361863243964414, 47.01075184729792, 33.155206711061545, 33.34957584258049, 15.268756478063523, 0.9617388741143289, 0.19810914212176878, 0.35961785143421543, 0.061544948933465835, 0.2597214263533392, 1.2972863042546858, 2.458931164395425, 2.4988552543424793, 2.999493345137566, 14.824334286874342, 41.50144561644524, 58.362004833836714, 58.8664294827369, 54.33923767459009, 55.25565239690966, 53.80250054021036, 55.96370297093546, 55.7276233550041, 54.96050973092356, 53.35467569289669, 56.04491956772343, 54.01968609902167, 51.82566127469463, 47.094172816122736, 42.64360058692194, 41.378808790637606, 41.76906501093219, 40.317686065550774, 42.016527345103604, 48.46993238695207, 50.40297054475354, 49.47563202150407, 50.271881011224565, 46.64119005203248, 40.566846786006806, 40.371399002690474, 40.656916172273704, 39.428841683172415, 41.29461511488884, 39.584944171290246, 38.32702044517764, 40.506748230226584, 39.3715319325847, 39.40862970967447, 42.81876579407723, 42.23556818500642, 43.759008915193625, 43.322221617544855, 41.79225406339092, 46.798677136821134, 45.048837200287856, 50.23771324465352, 49.2492877283404, 52.5169829399355, 52.085730106599875, 55.92853892234064, 45.53422266437162, 44.72079761566655, 55.693326150217366, 49.275446015019575, 48.315222340245406, 43.13555209867416, 40.610314492256414, 38.39434792918544, 37.955791642588956, 37.0602164729949, 38.55664383980536, 36.33056932880033, 38.052725176657404, 37.54548034360332, 39.696143365675404, 43.722162169794885, 44.23497284612348, 46.041189009143466, 46.02233809809531, 42.995731369141616, 40.716571500224454, 39.54032721058015, 38.66639567959694, 39.48390783802156, 38.42242817724905, 37.147038136759114, 37.47975318662582, 39.39465430475051, 38.254801765564956, 37.71153780721849, 37.44269071086761, 44.63445840343353, 51.49903374333536, 51.85638127788421, 52.13051965159755, 50.688789736840036, 48.61502870436638, 46.24101807994228, 44.297405212156235, 45.117247258463216, 45.55503083813576, 48.13440892004198, 50.193402228816865, 52.29751848405408, 52.64461294297249, 50.285024873672, 44.142797147074056, 31.51288090213653, 9.391427982238032, 0.7020538829026685, 1.3314321300675793, 1.5510120507209533, 0.406722299634449, 0.15166187478650003, 0.07817690546113638, 0.06533697307590516, 0.021783727363893585, 0.09642119744732496, 0.19899489297982187, 1.4029252937724515, 13.780380756624284, 35.73565167765464, 31.10296968490847, 42.49886120519331, 44.66139331940682, 24.00812964285574, 2.105352537285897, 0.19277678712481455, 0.0125243462952635, 0.06419679675731929, 0.0127654226737157, 0.017811172686877753, 0.1527054091134379, 0.04747270283499553, 0.024561671344863794, 0.07087848539794646, 0.047396622643235235, 0.041727820982135115, 0.02923765944527282, 0.0721711591787396, 0.12086363869809336, 0.046389929484575994, 0.09352352349988877, 0.023277558596624483, 0.0211094684838768, 0.05579137198266484, 0.08294190340224775, 0.20200040912435901, 0.11532199614110494, 0.17573214286277372, 0.18734526970694143, 0.23966149066484746, 0.11466705225287907, 0.0806044772147171, 0.13702630125466855, 0.1345239669805573, 0.1878072820123165, 0.15639547078359514, 0.1756502787071851, 0.13640000905481078, 0.13227434979090769, 0.14491996397414517, 0.1445548464694331, 0.1182721930766298, 0.15093530167735394, 0.20975521074668055, 0.17356172384273622, 0.10434571052751235, 0.09909545717340323, 0.11229970267102604, 0.19655548516781102, 0.21064895956266314, 0.7328718227724875, 16.53341197198437, 45.959611554299634, 54.8870280481154, 54.29907260402557, 43.250818790928015, 41.45343188316592, 19.256619445739254, 1.890997336276116, 0.585816465318203, 2.3834471116142892, 1.972255363099037, 1.8746686318228323, 9.499705010844815, 5.183794123511161, 2.546779018255972, 2.513746777849813, 15.41586301019115, 40.85518021737376, 59.71934103196668, 59.54822763319939, 58.10073967902892, 57.02981887325164, 56.234252375941125, 58.98416726819931, 57.60127290602654, 55.54188343786425, 56.78716928728166, 58.175986428414625, 56.31992870761503, 53.01799904915595, 48.330609798431404, 43.44576451086229, 43.98739676321707, 43.336718697701734, 42.171719843341464, 43.623965632530954, 51.81142307096913, 54.23324738779376, 51.92212020197223, 52.38317128150694, 48.99173313571561, 45.19373347682338, 42.00987108292119, 42.56769487934728, 41.38200552232804, 42.89147084759128, 42.708151032847745, 39.727428190169796, 41.42006035773985, 40.82606838595483, 41.55353861470377, 46.06168731566399, 44.290933301371915, 46.113325318982525, 44.19989116730229, 43.157423234754994, 48.79072343149493, 48.094298762659875, 51.208515551782426, 51.49701764506679, 54.15569428474673, 54.526154302781634, 56.25702957953177, 47.63773487460229, 47.66441483651438, 56.924377718279445, 51.88454389572144, 50.92447319338399, 44.39380530388125, 42.46357164075298, 40.452337111196215, 39.487834130564046, 37.54569999633297, 40.33959642533333, 38.69229508984474, 40.48604203808693, 39.24196427868259, 42.574186401982466, 46.60444136588804, 45.517862458382886, 49.301192452830655, 49.470023032157656, 44.63294044617684, 40.99105896488313, 41.8770831631076, 40.72575769116802, 40.72993109303136, 40.40630025248374, 37.804839226507376, 38.478690655000754, 40.75614037052278, 40.04347316680416, 38.979161554767245, 39.46106787650816, 45.59712179245488, 53.779193816646455, 53.34775663191273, 53.914527354701875, 53.22545712993991, 52.01282108983686, 47.95783165962466, 45.19784804313414, 48.93021860430318, 47.97360743245771, 50.812462068373165, 52.06636536505915, 53.3992769641261, 53.78094319374331, 50.08114791685536, 44.20670040192143, 31.050109863281254, 10.080524682998657, 1.2439108135238772, 1.071058088733304, 1.753330110542236, 1.4738521652836956, 0.254193672970418, 0.16678874050417256, 0.1959061337214324, 0.23202422225186903, 0.6341552037385203, 0.7989767530272085, 2.8285240934741114, 24.674197127742154, 45.97496371115408, 39.659002442513746, 46.818022266511, 49.89805559958182, 28.177356143151563, 3.297557931753897, 0.2692845325556494, 0.15646006731737047, 0.26937100856054214, 0.11921751493167494, 0.0728954799893883, 0.25939881140666626, 0.23035652544950289, 0.12401891737094811, 0.1309685682457301, 0.12591431848704815, 0.20085645599230645, 0.1570286884182884, 0.12206248202992064, 0.22493637677642608, 0.147336496400737, 0.15480145631778627, 0.11450160790475146, 0.12466329690669814, 0.300959081298882, 0.22872189300194865], [0.04206889098690402, 0.046541205036544034, 0.04563990642406768, 0.01968176213033017, 0.04870722671189616, 0.12701218376957601, 0.04688863357108447, 0.060152400269984245, 0.013612777205003847, 0.06252610455116918, 0.06362439884293465, 0.04006449088093735, 0.028498122213228096, 0.03663354695984914, 0.06009721129591908, 0.04808678359334027, 0.03870018787922398, 0.01719734665276783, 0.03992951001911875, 0.04279647533211016, 0.026443392045856006, 0.057609612723031355, 0.03775798783247029, 0.006251817554115288, 0.02923336169201761, 0.15784167624529333, 2.255128977760192, 11.912476497311747, 21.94212313621275, 41.01283596407983, 29.10835816014198, 24.725215396573468, 18.440058462081417, 2.064751348187847, 0.16676718278998331, 0.17505790888061448, 0.055667104860467304, 0.26099098726145686, 1.3662788344006385, 1.0521704054647878, 4.009978271299794, 0.5463764203652259, 4.057175170990729, 18.31837477222566, 41.88478669812603, 57.43348959953555, 55.24166130250501, 53.133885475897024, 56.147214981817434, 53.822818417702955, 52.52868337015952, 53.96670272273403, 52.15833317848944, 52.071252638293856, 49.49804052229851, 43.67152044850011, 38.969343862225934, 39.682218951563684, 39.24159557588639, 37.85163310266311, 39.110219709334835, 46.205371579816266, 49.08970609787972, 51.30208369224302, 54.02219641593195, 52.89960622787476, 51.209441231143096, 50.09864953256423, 47.01650988671088, 45.180452331419914, 48.36034136433756, 46.84336470019433, 45.330702643240656, 37.895481278819425, 38.114035744820875, 35.91875576203869, 37.4138730572116, 41.26117298679967, 41.951223804104714, 43.40994150407853, 42.916389665296, 40.33717632293701, 46.19313378487864, 47.6110549126902, 49.50818769393429, 47.91773326935307, 52.84990587542134, 49.3146030364498, 57.02698299961706, 50.230143070220954, 41.20507132622504, 53.26912487706831, 48.06599493949644, 49.05795451133482, 42.10061903922789, 39.648094331064534, 36.42582408843502, 38.15636988609068, 35.81482864195301, 36.631324906503, 35.788176136632124, 35.33581310702909, 35.654038921479255, 37.30076366855253, 39.77743840986683, 42.53611979946014, 43.41162027851228, 39.14428157191123, 39.02847751494377, 37.56282114213513, 36.26904303027738, 36.434163047421364, 36.7023237289921, 36.44981722677908, 36.70679915335871, 35.52086660938878, 34.68684911727905, 37.002934178998395, 36.68648912060645, 35.55743878887546, 44.029017033115515, 51.19756429426132, 49.387727783572295, 51.08996975806452, 50.67640289183586, 48.612616446710405, 47.91797253393358, 45.86819287269346, 44.71929927026072, 45.42795388929306, 45.29598182247531, 49.219897408639234, 51.06308975527364, 54.738076040821696, 46.9352932899229, 35.656992466219016, 11.589087863122264, 0.9044186434438153, 0.8819798055675723, 2.0793305529702097, 1.429533059558561, 0.24790524024396177, 0.1591371462470101, 0.06729874038888563, 0.08606166623893284, 0.05617376477006943, 0.2715439709924883, 0.1308004425898675, 3.625212878950181, 16.35428026799233, 28.89368684061112, 26.86763751891352, 30.675527434195246, 29.205762378631103, 12.031274303313225, 0.6171432714308462, 0.035722151308530764, 0.03546658054655118, 0.05397092490907639, 0.02693480872098477, 0.03213724669729991, 0.043643707289330425, 0.07726460199562774, 0.008354865844481656, 0.03141654565209343, 0.10484896134585144, 0.014558127788346142, 0.06665911825914538, 0.04460446964648943, 0.06626672036344967, 0.038602615090748, 0.03567011861671363, 0.03273631979320799, 0.030876400039320996, 0.014317520638747562, 0.0527193364236624, 0.02552953533708088, 0.033629984339518894, 0.08458920694406956, 0.008370682687288331, 0.021902875103537115, 0.10050230869843114, 0.06350503851389212, 0.0401228629503279, 0.05220602304043789, 0.017283589000843706, 0.05038421233034423, 0.051340562021059376, 0.06982403431808756, 0.022453881927856037, 0.047877568811658895, 0.037395114965376355, 0.029029398443057176, 0.018128488220334537, 0.028579268161387696, 0.045996508861501376, 0.020744540585925984, 0.018957772652708718, 0.0562633702441329, 0.0626769434330204, 0.05197125156560252, 0.05243640100102752, 4.765760658248778, 20.951934514507172, 33.23827858894102, 51.51807685052195, 33.515566625902736, 32.01517178166297, 21.222807515052057, 2.8234855638396357, 0.07096483116789211, 0.12262387892171261, 0.11025954158075395, 0.14259933043391476, 0.5085217790497888, 0.9224401570616231, 3.5479301742969023, 1.8872553951317266, 5.549213895874639, 22.621922839072443, 45.19727145471881, 58.913556760357274, 58.05527940873177, 56.12736778874552, 58.11389923095704, 56.38653055314095, 52.66178115721672, 55.98049071527297, 54.18140149885609, 53.888141570552705, 52.282162404829464, 46.300340006428385, 41.10757689322195, 40.121112561994984, 40.952505988459436, 39.3585684991652, 40.76203961526194, 46.7266349638662, 50.60303103539252, 52.12448312390236, 54.91985044171734, 54.647367308216715, 52.09513202790291, 50.54007699412685, 47.90225167428294, 47.23270308586859, 47.98657478824739, 47.568010822419204, 45.37421349556216, 39.881871515704745, 39.81363011944679, 38.16267313495759, 40.03567157253143, 42.28071074331961, 43.41507980900426, 44.6965338337806, 45.094250402142926, 41.2027532054532, 47.37489292698522, 50.837192612309615, 51.53595893613754, 50.6151197802636, 54.197710714032574, 52.455146774168945, 55.350687503814704, 47.49893788368472, 45.68302954396894, 53.64296205582158, 49.56045719885057, 50.349053644364886, 43.5100874593181, 42.30095017340876, 38.499906755262806, 38.63950783206571, 37.62463377368066, 38.703469922465665, 37.76457217431838, 37.816339615852606, 37.94521301023422, 40.49156865765972, 42.656787595441266, 45.71167853570754, 45.43673999847905, 41.37013250781644, 39.44687281885455, 38.654636413820334, 39.661371554097826, 39.558134771162464, 38.656095535524436, 38.127532620583814, 37.823384192682084, 37.73213417299333, 36.05512480581961, 39.07586759136569, 37.680296128795995, 37.49167719194966, 45.30925120076826, 53.81924513847598, 51.348108783844985, 51.03726879242928, 52.42868254261633, 49.95806001847791, 48.02586124789331, 46.15127425039969, 45.763661707601244, 45.80975347949613, 47.1606844471347, 49.989321308751265, 52.145224617373565, 54.617235660552986, 48.04182137212446, 36.95298279485395, 15.212555777642036, 1.8426546141985927, 2.900834213341436, 4.090875440066861, 2.776996897112939, 0.927884100425628, 0.4576502007342154, 0.07829571037643379, 0.0821088134281097, 0.030216599153655193, 0.20975332617038683, 0.13178601470445434, 3.462048408485228, 22.79294013977051, 38.94275019245763, 32.61859117015716, 35.666461067814986, 37.954363899846236, 16.003415430745772, 1.023974570055162, 0.08277255966658555, 0.06500673555438558, 0.14901153232541778, 0.04911508809234347, 0.03378448129120854, 0.019340594449350913, 0.025937622713465846, 0.052073738808112766, 0.04024199728343276, 0.0787361266632234, 0.08235223786604982, 0.043337321915333314, 0.02389334007016113, 0.05538802669053117, 0.06000697379931808, 0.040349824158775235, 0.0637563651487712, 0.05169736747179301, 0.01325652908323513, 0.09466794394557515, 0.12392421358174856, 0.16763529830401944, 0.19640609802257633, 0.14235815063359278, 0.09858187948984486, 0.21088180432636894, 0.19178796679742877, 0.17214737231692961, 0.10551348899401004, 0.11436764210943254, 0.21523116126416192, 0.12366626411676408, 0.14730557709211303, 0.10665458461810505, 0.13347623449179435, 0.12116819695239106, 0.08589054517928632, 0.11087912285039503, 0.1598131269096367, 0.12862516657239007, 0.0791621021926403, 0.13352126513998355, 0.18459093847101737, 0.14835016862038644, 0.23029810358439726, 0.2666490368785397, 4.662407675097066, 23.184920241755826, 38.794425764391505, 58.16691398620606, 41.843448838879986, 39.72409025315316, 25.902663853860673, 3.8603864273717328, 0.8447167373472645, 0.6454173703828167, 0.2558056598589305, 0.8358239274351829, 2.6343790273512564, 6.194086363238673, 8.634834154959648, 1.2934216664683436, 5.862153826221343, 20.908486420108428, 46.39128800361387, 60.65344956613357, 59.07153414141748, 56.83687356210525, 59.46526558168473, 56.545759170286125, 54.28496776088592, 55.92351828852008, 56.61515766574491, 57.62631723957678, 54.40762419854441, 47.839215263243645, 42.922763516826016, 43.426693947084495, 43.49917934786889, 41.76117712451566, 42.63647756268902, 50.745146351475874, 53.702338895490094, 54.96786025262649, 56.12968198714718, 57.84356163394067, 54.705504678910785, 53.77916636005525, 50.54008091649702, 50.156445657053304, 51.79968341704338, 49.950846779731016, 49.358545349490264, 42.00010830356229, 41.71989417845204, 40.00865036441434, 40.805675983428955, 44.17001839606993, 43.89546425111833, 47.309769815014256, 46.173490555055686, 43.45023209048856, 48.68597261367306, 53.94514929863715, 53.25732246521981, 52.467110003194506, 55.16446513514365, 55.523640494192804, 55.675695096292806, 48.3167246080214, 48.776685268648215, 55.116388643941576, 54.323575650492025, 52.94152852027647, 46.11474913935508, 43.82837603169103, 40.205294470633234, 41.65220191401821, 39.80807212091262, 40.840847876764116, 39.13372647377753, 38.68976516108359, 39.326597259890654, 42.07321343883392, 44.36244987672375, 46.73530340194703, 48.14324209767003, 42.4153107981528, 42.0236268351155, 41.52499160458965, 40.812410693014826, 39.8132457271699, 40.37296402838923, 40.19473545012936, 40.05571880648213, 39.74471799788937, 38.633726258431714, 41.4056025012847, 40.35302269843317, 38.96226790643508, 48.21853199312764, 57.52711657554873, 52.44330121624855, 53.65661974876158, 54.31767640575286, 52.79941320419312, 50.82885757569344, 50.21879173094227, 48.033329440701394, 47.480243867443455, 48.067195184769176, 53.32558347332863, 54.995446282048384, 56.54098956815658, 49.06315165181314, 39.108329126911784, 15.156837528751744, 1.8259717932631894, 3.048871327792445, 8.555945484868943, 3.684286960671025, 1.2881453431421712, 0.8359411082440807, 0.32469953320199446, 0.26814955797406936, 0.22343355741712356, 0.5121540164034213, 0.2410584519947729, 8.807898932887662, 28.957529298720825, 38.92636645224787, 39.69386839097546, 41.31544290050384, 43.96905576029132, 17.621096987878126, 1.190000409560819, 0.2944368538596938, 0.14025013713586715, 0.18245963590039363, 0.22286398636717952, 0.11256492997129118, 0.14148127107370284, 0.1763755801103769, 0.08906961854306922, 0.1798183332768179, 0.24810381023393524, 0.19371731326945368, 0.157559342201679, 0.08990626316517593, 0.2732506616702003, 0.10985371416374562, 0.13392589745983002, 0.16253935804049816, 0.13196209235297096, 0.12571818465667386, 0.15097830985342303], [0.018761993137999408, 0.09782106225048343, 0.08832304287822017, 0.09880645816484768, 0.022647568107312246, 0.03401787380778021, 0.059962364499487227, 0.026324709704626473, 0.05159886771692865, 0.04309664390260174, 0.06815514241855952, 0.015423239280109205, 0.06859207300529366, 0.04053917811101964, 0.04200406079631179, 0.032651460233835444, 0.0075573376717887105, 0.016154827392329613, 0.025931386757762204, 0.01927615496360006, 0.08703485071178406, 0.023176800797603304, 0.06452100516687478, 0.038789126856793324, 0.026588150104808233, 0.08996718247691471, 0.5591528057571381, 12.60411391335149, 15.971745233381949, 33.0569552606152, 41.30518590250323, 17.485414358877367, 18.16407069083183, 5.783969221576568, 0.4512020080320297, 0.0703302652184521, 0.1531089382666734, 0.07027653181144307, 0.06479416147715623, 0.42951047360416383, 6.221374782823748, 2.7098427328371235, 0.4258204425775236, 5.695808558694779, 21.77910747066621, 43.944152632067286, 53.66561766593687, 55.335908013005415, 53.93373912380588, 53.18959097708426, 55.22404986043131, 53.76254727763515, 50.09875543655888, 46.15569868395406, 44.768191614458644, 41.574644888601, 40.621473635396654, 38.87219852016818, 37.87821500532089, 38.501707123171904, 40.213421621630275, 44.13602713615664, 48.918722137328125, 52.15861558914185, 51.378491463199744, 53.661487410145426, 50.95481272666685, 51.45806458688552, 50.86397455584619, 49.843554266037486, 52.202451998187655, 53.23642407694171, 50.916032252773164, 47.282226931664255, 38.85635214467203, 37.172459017845895, 39.67029102386967, 40.36353465049498, 43.53119765558551, 42.24815507088938, 40.810394594746256, 38.5777344242219, 46.48894325379403, 48.66849453218522, 52.13486171537831, 50.02877250794442, 52.96151299630442, 47.28382725869456, 53.01868154156593, 58.93711843798238, 41.092209046886815, 55.62672430469144, 48.34331435541953, 48.83686619420206, 42.57526897615002, 42.61097431182862, 37.26187336829401, 36.242296388072354, 35.48970337836973, 37.31100889944261, 34.39444034330307, 35.38038692166729, 34.852071116047526, 37.97527013286468, 41.305413399973226, 40.886916114437966, 38.84175308289067, 38.12234332484584, 37.8840789487285, 39.05275306394024, 37.05324642119869, 37.97345015310472, 36.78801967251685, 42.282130641321984, 45.53690948793965, 44.87094202349263, 40.16559616211922, 35.49386109075239, 36.518184138882546, 35.64705710257254, 41.70345552505986, 48.9540470031, 48.558201405309866, 51.12637327563379, 50.65340603551557, 51.567824271417436, 46.32354474836781, 48.5512117416628, 46.04712355521418, 45.96859770436441, 45.87511193367743, 49.407269031770774, 53.077764203471524, 49.448669648939564, 38.64159453299738, 16.223785954137004, 1.7919285619451155, 0.6048771005965049, 2.572237897303797, 2.6031765726304825, 2.169972114985989, 0.5597994452522648, 0.32657917588949203, 0.06762716994290391, 0.02218006869717952, 0.023771093504863883, 0.03559018500269421, 0.23587333909686536, 3.977783947221695, 16.14359603774163, 29.96961847428353, 26.932729251923103, 37.3968852719953, 26.532863224706343, 1.8900813402668124, 0.01682903647663132, 0.09829359294305887, 0.05427180977177717, 0.07052317381866517, 0.022952473016395684, 0.010679733935713528, 0.04420056127973142, 0.04150534138804482, 0.02759452916741852, 0.047952706715272325, 0.015289109733496464, 0.0867902005331651, 0.03959423929993664, 0.01499560995838575, 0.03750838106498122, 0.0993571987736129, 0.06012644904154924, 0.01144876555284305, 0.06805934312362825, 0.029679659618845874, 0.05820423101765975, 0.012799256946891548, 0.023370165220131318, 0.03571178613891525, 0.0209183793424839, 0.06445104601762949, 0.08118238330127732, 0.03809670594731166, 0.03678892874309132, 0.05285842351675515, 0.008807342270419242, 0.03161186742926798, 0.09903918801536483, 0.011386509417676398, 0.039076999716100194, 0.14033180210859547, 0.038780906733365796, 0.05469713029601882, 0.05793447613776211, 0.01402065103437992, 0.021706886829868443, 0.05701639636930439, 0.010928944252701777, 0.011719141921569264, 0.011710603871653158, 0.02804062216572704, 0.06287465157407908, 0.5081754153774631, 13.783215649666326, 24.511206957601733, 44.11936098529447, 45.1359804984062, 24.899192125566547, 25.71657092340531, 6.380368548054849, 0.5391830386173341, 0.1160026039747942, 0.0923838834428499, 0.1138942533983819, 0.08229255195586913, 0.2718584654071639, 5.145465702779832, 1.2072328526166178, 0.8948814616568628, 6.983278518722904, 26.3373742565032, 46.77354258875693, 56.63038430675384, 56.910096368482044, 55.45959603401923, 55.062389373779304, 56.87111977607974, 55.6849911136012, 52.07062505906629, 48.733350922984464, 47.197633174157914, 44.230313070358775, 42.80501788662326, 40.58716074112923, 38.821988259592366, 39.4053388410999, 41.44318665227583, 45.433770764258604, 52.52006592289094, 52.97803794184039, 53.434754802334695, 54.61129326974192, 51.22782145777057, 52.91249513626099, 55.32077550888062, 52.97302907513034, 54.40234468829248, 54.756691609659505, 53.12060825286373, 48.26003851429109, 39.567246437072754, 39.419141661736276, 41.75909434595416, 41.99080836388373, 45.45226866199125, 44.784167428170484, 41.396388853749926, 40.83746679367558, 48.25038948366719, 50.11173848182925, 52.73305846798805, 51.284107469743304, 54.430507306129705, 48.047300923255186, 52.48628647096696, 56.923663846908084, 44.28192361708611, 54.876437648650146, 51.03614307218983, 51.07635128882624, 45.22069977175805, 44.08450680394327, 39.58883908487136, 37.10474321919103, 37.62090752201696, 38.57980935804306, 36.031653342708466, 37.4461345518789, 37.55422330671741, 39.21537453128446, 42.734266173455026, 42.25831793200585, 40.64569034884053, 39.823039885490175, 38.683826692642704, 39.458345751608576, 38.35991344144268, 38.178378305127545, 38.427150710936516, 43.65865899670509, 45.79748430559712, 44.95785390177081, 39.93524320663945, 36.591461858441754, 38.554247271630075, 37.68919990908715, 44.01457486614105, 50.186859715369444, 51.131586105592795, 52.21184607475035, 51.30147964723649, 52.168613710711085, 48.95836553265972, 48.45473712490451, 47.23425634445683, 46.33739855981643, 47.52004023521177, 51.198603722356985, 54.53107687734789, 49.58788633346558, 40.65118951182212, 18.86993258230148, 3.7409728092532006, 1.9685246987688927, 6.132369339466096, 9.52788233757019, 3.726528681093647, 0.6388916495826937, 0.4440746937067278, 0.06875895759871892, 0.11122604576690544, 0.1956891469777592, 0.04401170528463779, 0.42245143303467386, 5.780758271294256, 21.75958191194842, 33.20219278335571, 30.845748493748328, 40.320066944245376, 30.050487941311253, 4.630815434840418, 0.05452372246391831, 0.06766308414479417, 0.08010579228040673, 0.060778466473904356, 0.04378380178804359, 0.049143938963571866, 0.021892613355791377, 0.03853399276493057, 0.04499138235264728, 0.0811535477518074, 0.014246921806085496, 0.012183608581131745, 0.011561329724387297, 0.009379382996309188, 0.034688430567902905, 0.0925404871363313, 0.06969724676661915, 0.07138600332602378, 0.09399437645991003, 0.009903938719822515, 0.057808899005214055, 0.1979250358718057, 0.17547060044542437, 0.2831014798533532, 0.18365482499282207, 0.13459308343308587, 0.19762787036597732, 0.11165663314562653, 0.09314573490090909, 0.14365424882740746, 0.0841692911701337, 0.17970640783108052, 0.2508172783399782, 0.2154898078691575, 0.17733279165000687, 0.1253601687870199, 0.17813393575770242, 0.21400333682615913, 0.15198634366594976, 0.15727481714660124, 0.11493400325097385, 0.17747059554582645, 0.08334669660055831, 0.14771698162921015, 0.15155060817637753, 0.10336424464419966, 0.14028738433074567, 0.5152927399162324, 15.944316098766944, 33.49073017797163, 50.84548450285389, 51.90449699278801, 29.593947587474702, 27.008805582600257, 8.235934011397823, 1.0085909729523044, 0.4301016483335726, 0.2611826931036288, 0.2145087863168409, 0.3987462518195952, 1.907513333905128, 12.635906684783198, 6.9195909942350085, 1.6063025161143274, 7.711771015198001, 24.95366600251967, 47.490049792874245, 54.889530520285334, 59.866645643788004, 55.27040443112774, 56.314708032915675, 57.68971058630175, 57.30995847332863, 53.508848374889745, 49.94112714644402, 48.995298570202245, 44.56070999945364, 43.670426107222035, 43.16943353222263, 40.56741160731162, 41.70152964130525, 43.99169568092593, 48.332178746500325, 53.29024684044623, 55.697213219058135, 54.32684298484556, 55.9136260709455, 52.95954788884809, 54.16753592029695, 58.17508820564517, 55.52607628606982, 56.34471808710406, 56.76805557743196, 56.19467958327263, 52.44401900999008, 41.80560973382766, 42.35546719643378, 44.52769540971325, 42.787233860261985, 47.838787724894864, 45.753922462463386, 43.88388933673982, 42.84830124147477, 51.99599019942745, 52.36933708190919, 54.4164103077304, 52.58292582727248, 55.39637919395201, 48.68916542299333, 52.84163359672793, 58.44381370852071, 46.830640531355336, 57.81988620758057, 53.66472336553759, 52.51343319492956, 48.824416591275124, 47.52399398434547, 42.455687676706624, 39.28657731702251, 39.37367746906896, 40.942480410299, 37.61847173013995, 38.33350804544265, 38.89561507009691, 43.131300249407374, 45.86398809186874, 43.39742522085867, 42.74477812551683, 42.25772957648001, 41.088780895356216, 41.549161249591464, 39.87284221956807, 40.65348017600275, 39.97003070769772, 47.20847852768437, 47.66331265049596, 48.565673520488126, 42.63654424298195, 38.561946884278335, 40.115083879040135, 39.67862606048584, 46.309863521206765, 51.25496425936299, 51.73962800733505, 53.75171369121921, 52.58517726775139, 56.58549278013168, 48.99242739523611, 51.78648071904337, 49.70559666233678, 48.722254537766986, 48.91345831655687, 54.01315927505494, 56.2482120913844, 50.8448451565158, 40.41260350135065, 18.906610665782807, 2.3649077838467014, 1.8527831545760556, 3.965227704855704, 6.439554172177469, 4.3867650724226435, 1.0953998277264259, 1.4095474803639998, 0.2809596205911329, 0.3367358470155347, 0.232966004780704, 0.19917486235499385, 0.7470731929905954, 7.991208511014139, 24.680423890390706, 42.449588391088675, 38.255927485804406, 50.25295557514314, 35.203558629558934, 5.2047488958604875, 0.15657698765637415, 0.19110657755405674, 0.15138989825162197, 0.20691945968616396, 0.09044278518206651, 0.11482011662015032, 0.11635446049753698, 0.14382147049951938, 0.15395109872183493, 0.13424878819815575, 0.16562119186405214, 0.16758257613307045, 0.07792748255474914, 0.15869543527162847, 0.16274067062524059, 0.21390342363907447, 0.15889041997011633, 0.12175650651296302, 0.1539663591932866, 0.10594707177651506, 0.16611095187404465], [0.01931635734264649, 0.044379331727301886, 0.035496844849999876, 0.025071709702212005, 0.057876138542328155, 0.004670503389676132, 0.03833043554257001, 0.058401494827722354, 0.042825705416861086, 0.031470374820092996, 0.02822179621415994, 0.0751797626576116, 0.012372393713092372, 0.055268359926318934, 0.024409786752995946, 0.012517465868093556, 0.15845925036457278, 0.0819429936968992, 0.037680429091016134, 0.04048010507117837, 0.01516025757507211, 0.027769181892395984, 0.05048341305565931, 0.02121465427110032, 0.04347473893675112, 0.049230985703968236, 0.11755420015223565, 3.3279058000733777, 17.64713760345213, 25.95937152062693, 38.790448481036776, 28.723808988448116, 18.626263180086692, 10.19964216216918, 1.38466898952761, 0.053984277821596593, 0.01637688755328136, 0.07049530353997985, 0.06093782042303394, 0.1676280204687388, 0.6197619438171387, 3.7486631062722977, 0.23636322168092574, 0.4857993354239772, 7.837442774926463, 28.80842628017549, 48.04876004495929, 57.46575893894319, 53.722193933302364, 56.56289600556897, 54.87315070244574, 53.77638147723291, 51.64863294170749, 46.29682556275399, 41.073060035705566, 41.5537896463948, 39.93265444232572, 40.037264054821385, 40.32845689404396, 38.5417898239628, 38.5842377139676, 44.64229922140799, 47.115906669247536, 52.44148908122894, 50.763083350273874, 50.33852992519256, 51.97215395589029, 53.83943750012306, 51.36505734535956, 52.732328907136, 51.05651978523501, 51.33544737292875, 52.019089037372225, 52.16065914400163, 46.016893848296135, 38.322195929865686, 37.762501162867395, 38.99767906435075, 39.21348002649123, 38.99448233266031, 38.330181875536525, 39.05245496380714, 42.10383538276919, 50.17829718128328, 49.344048269333385, 51.51254630857899, 50.052185135502974, 50.587745558831, 45.532630182081654, 36.184994482224994, 45.583703364095385, 51.32554338824365, 49.52457535651423, 49.37984774189611, 43.54098789153561, 42.188833144403276, 38.79559070833268, 37.032665744904556, 36.98860183838875, 36.99732126728181, 37.09072859056535, 36.319492555433705, 36.21062717130108, 37.201229603059836, 37.498984567580685, 38.2722367009809, 38.55315685272217, 35.86594497003863, 35.87705312236663, 39.00584936141968, 38.46910830466978, 37.64060174265216, 41.8785422848117, 47.841137224628085, 48.82646799087525, 50.168420653189386, 48.10532062284408, 38.677350859488214, 36.42991904289492, 35.979505431267526, 38.679402259088334, 47.87863508347542, 49.84397788201609, 48.40982206406132, 48.54858375364735, 50.10784749061831, 49.179371480018865, 48.0061395706669, 47.71385239016625, 47.595165391122144, 49.37249329782302, 48.47230934327649, 52.28408044384372, 42.606028203041326, 24.601103759581044, 3.6352291414814615, 1.471360111909528, 1.711075764990622, 7.142238453511269, 10.824619877722956, 3.3889741618787093, 1.1055445478808497, 0.3957778449741102, 0.18262442141290636, 0.08191369849467471, 0.06559760384862462, 0.03884669453386338, 0.217048536325174, 8.114052241848361, 22.584625021103893, 30.064367248165993, 30.776610835906002, 34.88236750325849, 16.42479860013531, 0.42030562075876426, 0.05138853444687782, 0.03793144546028587, 0.07030337553230986, 0.041711422870115894, 0.030058107053440426, 0.09482112322603503, 0.04896364017059246, 0.07521119524514483, 0.028976902268045855, 0.11381795870200281, 0.02974720750634949, 0.022999100957907016, 0.022956573502010396, 0.03196887014764211, 0.062150127750130436, 0.07835252345689843, 0.11118256261632328, 0.10523670908784676, 0.0037925999053949194, 0.032480611135402036, 0.08696807848830378, 0.032201931331186526, 0.03472951969372169, 0.020045600268208695, 0.01696237982551177, 0.012851319324615742, 0.029063156107440594, 0.08668002176789508, 0.07384471655372651, 0.05938860677903699, 0.03853762402169166, 0.04631052447122432, 0.045122046309012565, 0.058048052502976316, 0.018620933368501645, 0.009497971491767995, 0.02209736376009401, 0.03857605482241319, 0.02818412767092307, 0.029523950333016056, 0.058638962932051196, 0.05781193271339421, 0.042633015151706435, 0.035376128545331384, 0.015886944639796934, 0.014842351196303725, 0.05668631589580929, 0.05979692398179924, 5.849874846396908, 23.545719462056315, 36.827768971843106, 51.247260724344564, 28.370252424670806, 22.451391912275746, 13.479543789740532, 1.546738628418215, 0.09107795634096669, 0.22510505401559416, 0.14284653168532158, 0.06762870211875247, 0.07905812873955696, 1.7539173629014724, 3.139573931694031, 0.4785842887095867, 1.5747984066124887, 9.924173124374883, 30.327673996648482, 51.109248207461455, 57.202920913696296, 56.45773726124918, 56.53390968999555, 56.97911439403411, 55.24162600117346, 54.22049968473373, 49.65721030389109, 42.937240985132036, 43.36031959902856, 42.2965100503737, 41.83146207563339, 41.63679092161117, 40.71006821047875, 40.40041277485509, 46.0213771174031, 49.58290884571691, 53.880308597318596, 51.14875431983702, 52.87347932015696, 53.816754433416556, 55.13816564313827, 55.28028880396197, 56.374861501878314, 52.40512870973157, 54.34468584675943, 54.49954102116247, 53.08597372424219, 46.85947387449203, 40.70154882246449, 39.53467899753202, 40.97472621548561, 41.722839878451445, 40.20938942509313, 40.00574781048683, 39.608725501645, 44.0200504949016, 51.93683693485876, 52.4025595572687, 53.30247679064351, 51.249982849244155, 51.662047447696814, 46.83278606783959, 40.162717142412745, 48.62761951261952, 53.13035926511211, 51.136755789479906, 51.559661819088845, 46.50779808721235, 44.48286664101386, 40.742062983974336, 39.2790267544408, 38.00761007493542, 37.797139613859116, 38.22987118074971, 38.46365228776009, 37.98882192181003, 39.56575985877745, 39.07101561946254, 39.742207680979085, 39.815536391350534, 37.52042424294257, 38.57206267695273, 40.72323952951739, 39.258371553113385, 37.90393790891094, 43.36082950715096, 49.224282618491884, 51.57886966582268, 52.3696038030809, 48.88932005051644, 39.93267405417658, 37.4842050767714, 37.870821337546076, 41.76303632797734, 48.920969655436856, 51.32224075255856, 50.66112918238486, 50.912925735596694, 52.94232476142145, 50.22100394771945, 49.556185737732925, 49.07893134701637, 49.17409981450727, 50.49201227003529, 50.380079592427904, 53.02647529109832, 46.13487089833906, 27.599620434545702, 6.206556068312738, 2.6675277131219066, 4.357819941736037, 8.46897182926055, 9.651303637412287, 4.2080079547820555, 1.056729180197562, 0.20906642109395998, 0.2592009155740661, 0.07083268100095373, 0.05508100929399652, 0.07426441782304356, 0.3841941359062349, 8.492070667205319, 25.54614393941818, 34.7237507758602, 36.596557017295595, 40.49282381611486, 22.105054470800585, 0.6757660967207725, 0.023139668515913432, 0.07510008951348644, 0.0236188622582103, 0.01602541886255025, 0.07247046206987674, 0.091138860330947, 0.028520130004072865, 0.037051995675409996, 0.021337894835479317, 0.02017530469944881, 0.02803846945865981, 0.05160414606272694, 0.01033210143026325, 0.017502203681356004, 0.04044135251352864, 0.014455931659247127, 0.07527144806038949, 0.03467043899300118, 0.0847728228977611, 0.019759979707399206, 0.03397530613226756, 0.1459748517241209, 0.14630563316806672, 0.11951730045820437, 0.04786662524566055, 0.12483313859951113, 0.0899455251712953, 0.11696448865076227, 0.218656279086586, 0.17621827161600515, 0.11406369672547426, 0.20928331590708227, 0.23298702623334624, 0.18300398733587037, 0.21658606436704436, 0.1738354777015986, 0.11261387532877346, 0.15117689516515503, 0.20254704350185013, 0.13202633648630113, 0.14885793169659955, 0.1804658920774537, 0.11818246885893807, 0.1727050843258058, 0.13848997352104034, 0.15920724329208175, 0.22983056012420888, 0.18016481952321145, 4.937731094898717, 31.24537329519949, 42.70901003191548, 57.451277548267, 40.326491786587624, 29.209667098137643, 14.823223275523032, 2.1049634871944307, 0.3812945850433842, 0.5941185907971475, 0.41342792852270993, 0.21039811173273673, 0.2595631525881829, 2.788720126113584, 11.164917849725294, 0.3862160870865468, 1.4884036683267163, 10.782118055128283, 31.312598797582815, 51.47459737716183, 58.9891565230585, 55.81209944140527, 56.976258908548665, 59.382130945882494, 56.99605903317852, 56.27762202293643, 52.01871248983568, 45.170948428492395, 44.977991350235484, 44.549331203583755, 44.15268151990829, 44.99331997286889, 42.55710447988203, 42.783939069317235, 48.686353083579775, 51.53034210205079, 56.27551178778372, 53.39176170287594, 52.955370564614576, 55.18985855963923, 57.57887224997244, 55.37238997797812, 57.75595157377182, 54.54210265990227, 56.261242205096835, 54.75202791152462, 56.7228816401574, 50.46521071464785, 42.752179638032, 39.743168661671305, 42.64540095483103, 42.43450295540595, 42.28474293985675, 42.228021544794885, 42.78498241978307, 45.47291601857832, 55.40050944974346, 53.821476967104026, 55.087920081230905, 53.01581821134014, 51.156814790541134, 48.62558772487026, 45.38036377199235, 50.50547776683685, 53.00691443104898, 53.57121406062957, 53.400147730304354, 49.18092081623693, 47.407146576912176, 43.44247756465789, 41.831454230893044, 40.84573514999882, 39.70949511374197, 41.367312323662546, 39.01680454131096, 39.948175261097575, 39.10144928962954, 39.81782313316099, 41.94369285337387, 42.81853045186689, 39.19496251690773, 39.410908606744584, 42.371462621996486, 42.06141887172576, 41.12535699721306, 44.29532635596491, 52.4140638689841, 51.583905989123934, 53.65479192426128, 51.17381042049777, 42.92209671389672, 39.98817559211485, 38.62519510330693, 44.04917017106087, 51.59696355942757, 53.1630051520563, 50.26511100030715, 51.345739672260905, 53.104251969245176, 50.80398582643079, 53.39969665773454, 52.629452982256495, 50.8161255621141, 53.07321817644181, 51.388434671586566, 55.053407146084695, 44.487930420906316, 29.131417774385024, 5.368179352052751, 2.3810029847006646, 7.156926258917778, 13.295215925862713, 20.456195954353582, 10.38879159958132, 1.994300064059996, 1.2054101762271698, 0.5113755484982845, 0.11112848446974832, 0.15910195216776865, 0.18214690348794385, 0.6509246232528841, 11.80717360588812, 33.5399127775623, 40.735963698356386, 42.28396238819246, 49.10514846924813, 22.722431613552956, 0.8539187403455858, 0.12107887110041997, 0.19426206307065105, 0.18189567261405531, 0.11563284397726098, 0.16147743760337754, 0.2564848887343561, 0.1466313584317123, 0.10660028430603205, 0.16465933783160103, 0.25386604780872024, 0.0736946629119977, 0.16419482807959282, 0.11971081426787762, 0.14575228786035893, 0.1330289004310485, 0.18488982001379614, 0.22508747995861117, 0.3657919685206106, 0.19271638875286426, 0.1257287336873912, 0.1426105459611262], [0.02585904124463278, 0.01940158079378307, 0.019404346371189724, 0.0046632289060301365, 0.022152037540030096, 0.004049944400321692, 0.0498286223850183, 0.03446523468160341, 0.023737661427848285, 0.03801147100485621, 0.043947472642626495, 0.02617315644578588, 0.038547682756137465, 0.046624781398643414, 0.012488162047379922, 0.01309891319608376, 0.022045838601526715, 0.04902272853219221, 0.0890697947432918, 0.10501069782842552, 0.06060597794731298, 0.08064584596262825, 0.03051565115099713, 0.0329410299778946, 0.05040334154581351, 0.07711933640342566, 0.021795069295612556, 0.6944035450297018, 12.5616571980138, 19.165677332109023, 29.058187123267885, 41.92075875497634, 23.047556877136234, 18.62724377262977, 4.8586428742254935, 0.20912640577843114, 0.2667793331127013, 0.08954796384298995, 0.04082554943799492, 0.09281922056670151, 0.09716638649303107, 0.34866558267704906, 1.4206628645620039, 0.14544096504968984, 1.4423354306528646, 10.073490892687152, 32.72957463418284, 49.330323896100445, 56.92504452120874, 57.931434492911066, 55.81857135218959, 51.31137186481107, 50.942453338253884, 45.872429032479566, 43.55308448114703, 41.52126927529612, 42.37986826127575, 41.36020891128048, 42.260608596186486, 38.61117655231107, 41.6397209321299, 40.77983540873374, 48.42814345513621, 50.454941949536725, 54.027785793427505, 51.29148152566726, 49.359290599823005, 50.26794295157156, 50.27596812094412, 49.79985513994771, 50.09246787717266, 47.980306840712025, 53.19907134579074, 50.48226518015708, 49.78421665007069, 42.2160896947307, 38.256394247854914, 38.54947766950054, 37.71530720495409, 37.19965281025056, 36.73111392605689, 36.56328355112384, 38.75436659782164, 42.480983041947894, 49.796383842345215, 51.87505175990444, 52.86792916636313, 52.49662976111136, 50.76428751791678, 35.420520613270426, 37.376841960414765, 52.03441373763546, 51.0550763530116, 49.02992525408345, 45.06253803929975, 45.287666397710005, 41.89222351197274, 38.04586887359619, 38.2356684438644, 39.6132872181554, 36.36203458232265, 35.29551859824888, 37.948892193455855, 35.231744781617195, 36.31475433226555, 36.92727165837442, 36.45904264142437, 37.14858747297718, 37.67200031588155, 36.873664625229374, 38.24221487968199, 40.48788162969774, 45.186528082816835, 48.18433284759522, 48.68019104003907, 50.09794350593321, 47.63999023745137, 43.78727351465533, 36.73263188331358, 37.27705294086088, 37.046805889375754, 44.09250843909479, 50.285719133192494, 48.86727633014802, 50.93828778113089, 49.77534032637074, 50.40536319055865, 48.5829201821358, 47.681755635046194, 48.209220286338564, 49.89751039012786, 51.58420016688686, 45.76543461891913, 30.152412691423972, 8.886203169822693, 0.36489540050106667, 1.911846449778926, 3.4146313657683716, 11.263588993780075, 12.998557263805022, 2.5713374682011145, 0.4359765314767438, 0.10624651256347857, 0.0792862007754945, 0.047917968458345825, 0.08729354328205509, 0.04286573351090474, 1.1307572982003613, 13.448958127729355, 30.971544788729762, 27.51900592157918, 32.635439711232344, 27.15603174701814, 6.748295695550981, 0.029856497609627344, 0.02854021299900788, 0.051398723416270754, 0.09018389342893517, 0.044029325306896246, 0.023592382429107547, 0.054238622842897335, 0.04965668927217203, 0.02231634424759015, 0.011088776049174128, 0.07696610349681109, 0.06625443997402346, 0.011934198123673278, 0.03300468422352307, 0.06181184247496629, 0.0384054776851929, 0.07342990292536636, 0.05226533739797531, 0.07373594739023717, 0.030107437370104656, 0.08631878066807987, 0.00903078905051394, 0.025435415689923593, 0.025448879685192823, 0.029280142851113796, 0.013589385667845849, 0.04167149436750239, 0.054609788611771605, 0.033705501456654845, 0.036733812547378966, 0.022235374499653137, 0.036662685114049146, 0.06458202407004372, 0.06081420830601166, 0.05524141278358237, 0.034168969329086044, 0.03541355194043248, 0.0583730997788089, 0.03687357762828469, 0.048442964682415615, 0.03277584993010087, 0.04870431174734428, 0.06294536148949016, 0.05184796120550844, 0.09021007831418708, 0.028154152565665787, 0.06008488494121741, 0.08705981751723636, 0.05251361883335537, 0.7889009194989359, 17.59525445199782, 28.269896622627016, 41.81812993941769, 47.32021116441297, 23.523285465855754, 20.441604737312566, 5.069742385418185, 0.36550155991027433, 0.34316945340364213, 0.2614463805671661, 0.15511208964932352, 0.060862356932052684, 0.01713180591562583, 0.7443791375525537, 0.6963130038592124, 1.1830611238556525, 3.1486395097547963, 12.840461231047108, 34.38796843251875, 55.32883597958473, 58.4918745102421, 57.830205963503936, 57.08490463995165, 53.58638578845609, 52.11787000779183, 47.7055997233237, 45.94860538359612, 42.97240895609702, 44.022298013010335, 43.0755437574079, 43.020391310414965, 41.297199956832394, 43.049895378851126, 43.39238889755742, 48.54370040278281, 53.655949023462114, 54.52333019625757, 50.89738530497397, 51.06791819295576, 51.02732166167229, 52.15836847982099, 50.35259162226031, 49.97257671048565, 49.11204007364089, 54.41017766152659, 51.91280457281297, 51.27989484417824, 43.137144580964126, 40.3041381989756, 40.67835192526541, 38.63152188639487, 38.674334556825706, 39.65872395423151, 40.05088644642984, 39.76167440414429, 45.10087528536397, 51.67692107539023, 53.538277918292636, 53.40872987624138, 54.57205387853808, 52.42884335979339, 36.187277301665276, 42.99049500496157, 53.438371227633574, 53.91908122647194, 50.45202370612852, 48.571965002244525, 45.6501365477039, 42.77340750540457, 40.313242020145545, 38.29918730643488, 40.62679236935031, 38.106316520321755, 37.06211097778813, 39.471948531366166, 37.69971186114896, 38.266965035469305, 39.38052200501965, 37.981432176405384, 38.025460781589636, 38.02182082206973, 39.047175453555205, 39.874936765240086, 40.59994766789098, 47.434140328438055, 48.17958285731655, 51.3365024905051, 51.5587753634299, 49.87797698666973, 45.603938871814364, 37.814323517584036, 39.09425174036334, 38.63704458359749, 47.24017520104685, 50.367245597224084, 50.524987636073945, 51.67211617192915, 50.912964959298414, 52.14467940791961, 50.02197111806562, 49.476338048135084, 49.44075430593183, 50.835764869566894, 53.34406568158058, 47.976490374534364, 33.005952681264574, 11.990028619766237, 1.7470446349151674, 2.8198992917614603, 7.7468522037229235, 13.68090944905435, 12.420834302902223, 4.860112292151298, 1.1113133738117835, 0.42306831767482145, 0.1889427009248926, 0.17861438013853567, 0.06028831575907046, 0.07192437161481188, 1.121655438215502, 15.009794735139417, 32.925140088604344, 31.165915881433797, 36.94047827874461, 33.644718508566584, 10.004866084744855, 0.11364848473139348, 0.0043668486403241275, 0.05971049777262154, 0.035817536915982925, 0.030193022797785463, 0.03428849436703228, 0.036988912165285125, 0.09037118660466326, 0.10794371907268802, 0.018531557720815463, 0.0462763186454052, 0.057981724610492114, 0.03418789170081577, 0.04187416675831041, 0.005893224245688368, 0.04608896418264316, 0.03695965526745685, 0.09546430000374395, 0.04610557296884157, 0.006635618985690658, 0.04625018738630799, 0.05594573869940735, 0.18102386455622413, 0.13760704186654862, 0.0998718872846615, 0.07873657099421948, 0.09553651911236587, 0.213226784140833, 0.08100953088292191, 0.16319897506506215, 0.1627869576576256, 0.13900921259435917, 0.12785475791221665, 0.2974963945246512, 0.17079867452623385, 0.15219016901908383, 0.09152833177077194, 0.2477684782277192, 0.14425461661190758, 0.16558104885681985, 0.11753630433832446, 0.15525341754959476, 0.22168307715365965, 0.24474606218357242, 0.19428689964115622, 0.14336080650889105, 0.17124455301992356, 0.15312786063840314, 0.19192575537148984, 0.7519494958462254, 19.102691911881973, 36.55727448001985, 48.452234652734575, 56.27468024530719, 35.83366778589065, 27.065711329060218, 7.059423490878075, 0.7579137048413678, 1.2013966109483474, 0.6214388183528378, 0.3406712713260805, 0.32509394590893104, 0.28285164325948686, 1.8904587458218298, 3.453129919305925, 1.0691020517579972, 3.0590709611292812, 12.062508136995378, 35.630504700445364, 53.11415987630045, 59.744397132627434, 60.9204766827245, 58.83722743680401, 56.20234781695951, 53.754588788555516, 49.97241197093841, 48.159814111648075, 45.30708997480331, 45.966150145376886, 46.50118104873165, 46.23857444332492, 42.197481970633234, 45.711945256879254, 45.33561345069639, 51.889105612231845, 55.74316770799699, 56.732562049742675, 53.00406286793371, 50.721808248950595, 50.672033371463904, 53.65640009603193, 51.02903181506742, 51.618030609623084, 49.95315705576251, 55.87647338067332, 55.512159716698434, 52.66115750035932, 46.51070848588021, 42.43362434448735, 41.847724222367816, 40.16362320992255, 39.70126205875028, 40.716320468533425, 42.56781255045245, 42.13106839887558, 46.127512531895796, 53.289948740313136, 55.63099184343892, 56.45598396178215, 56.367836536899695, 55.970998579455966, 41.96463438772386, 47.857822987341116, 57.070944924508375, 56.264415402566236, 53.1387060688388, 50.72101200780561, 49.91463153593002, 45.59416040297478, 43.469694891283595, 41.201262704787716, 42.030714558016875, 39.37283808185209, 37.881541175227014, 40.01860926228185, 39.6966258172066, 39.95546302487774, 40.474353374973425, 40.533294831552816, 40.4532314115955, 40.13074198076802, 40.844397621770064, 42.133617939487586, 44.04377691207394, 49.01413379176971, 51.16636576191072, 53.15869054486675, 52.79533393921391, 52.80149990512479, 48.16143405052924, 40.32565239937075, 41.64658900230162, 39.98667332433885, 48.34334965675108, 53.82598769280219, 52.157705599261874, 54.004698722593254, 51.91125915896509, 52.62489126574609, 51.499398523761386, 50.21337886010447, 49.55303607448455, 51.73496823157034, 54.66945025228686, 47.78551801558464, 32.67254533306245, 10.699110896356645, 0.9501168300067225, 4.512774155985925, 9.461934547270499, 23.45240431447183, 27.035646361689416, 9.616231764516524, 1.4273725690380221, 0.48047643395200856, 0.4265854273351931, 0.3357908009521423, 0.40293693662651126, 0.2748148293504792, 1.7494505187196119, 17.736130299106723, 42.487184309190326, 39.15604476005801, 44.296722719746256, 37.75261286766299, 10.926414209027445, 0.20688961290063398, 0.1484594434019058, 0.1174677624517391, 0.18083176034833157, 0.14508235929233415, 0.16633707038577528, 0.23388904879891106, 0.2072535965952181, 0.12952199506182827, 0.09558029337635926, 0.22793184184739668, 0.12021218817080222, 0.08986232802271844, 0.09381802301974067, 0.15776543517506894, 0.11677537984665363, 0.1797724139666365, 0.21713449139027827, 0.13789656181489268, 0.09318209343379544, 0.26679033413529396, 0.08354142849003116], [0.06515856652009873, 0.01867360957417517, 0.04725354423205699, 0.08809503212931656, 0.036783953002023126, 0.03484956567145644, 0.07524167788365195, 0.02765060105781642, 0.05011551848222172, 0.020244727587147106, 0.00488214188202795, 0.019618986970594814, 0.007393939257223881, 0.06695972349975379, 0.03783927742211569, 0.04308823225719314, 0.046368502005333864, 0.08539051959110845, 0.028496373617540927, 0.017552510760123693, 0.05322766257449985, 0.12352636880091122, 0.05318689903604889, 0.021577801014627182, 0.022131410622668844, 0.016945585262991728, 0.10742117049953631, 0.13759656178374446, 2.3579065982372533, 16.297803040473692, 17.350067092526345, 36.96851145836615, 30.739305173197103, 21.309788034808253, 13.85523428840022, 0.9113866727679008, 1.4079860093132144, 0.03584966664352725, 0.0288218843765677, 0.031156481784437935, 0.01968823940372996, 0.06813746110926713, 1.038315981145828, 1.5540843697324878, 0.6054230454948641, 2.194952464872791, 13.323212823560162, 37.81038545793103, 53.20562954871885, 55.14222529626662, 55.964816924064394, 54.6679558292512, 50.306072312016646, 47.9980359538909, 44.421791415060724, 46.14759114480788, 44.192591636411606, 42.817722443611395, 44.893860432409475, 39.94970498546478, 38.87295553761144, 39.97888741954681, 45.09727062717561, 49.062045543424546, 53.25366289384904, 53.14173413861183, 52.20565265224826, 53.45526095359556, 56.18676816263507, 52.93823372933173, 52.86244961523241, 50.369328375785585, 51.524431090201105, 53.78642274487404, 51.48437584600141, 47.725113514930975, 39.60833718699794, 37.02840997326759, 37.74810998670517, 37.492085118447584, 38.32621635929231, 36.48253763875654, 38.28102673253706, 38.896046530815866, 43.65339125356367, 45.03109239762829, 53.40644705680109, 50.05397765867172, 53.00130544170257, 52.022105340034734, 37.52391123002575, 54.32678022692281, 50.36015395195254, 51.334027474926366, 47.74897329268917, 44.981380278064364, 41.62276844824515, 39.79827404022217, 40.992063091647246, 38.94218537115282, 37.20532847988991, 37.65944873133014, 36.38117182639338, 36.705830327926144, 35.809615811994, 37.747878566865005, 36.44791879961568, 35.78840363410212, 36.082624543097715, 37.57768300271804, 38.328542324804495, 43.18124378881147, 45.73447927351921, 48.80572257503387, 49.13603713435512, 49.74689137551093, 48.55831515404486, 45.54341670005552, 38.65798219557732, 36.0249617791945, 36.291663339061124, 44.70054249609671, 46.88778946476598, 50.28357359670824, 50.18463573148174, 47.80005431944325, 49.88836342288602, 49.96217458478866, 47.309306975333925, 51.96975346534483, 50.580912789990826, 48.664297596100845, 34.438963167129025, 13.464487771834097, 1.2105380623571336, 2.4490811123001963, 3.257043770244045, 4.152701064463585, 7.701116877217447, 5.517783943683871, 2.5417500493987917, 0.9327882888817018, 0.35690547117302496, 0.1221079876526229, 0.2502469105585929, 0.059257567439588814, 0.14512181282043457, 3.1094121308095994, 17.06278681755066, 31.21129966551258, 25.608595917301795, 34.652595058564216, 18.6812351980517, 2.152219467586087, 0.02884348422559279, 0.030875858032114567, 0.04276045004747087, 0.057583630851079384, 0.0455418701523975, 0.07748106013863318, 0.03068961439684274, 0.029786406310215115, 0.020245083818031896, 0.022743863444174492, 0.07704724752975088, 0.04439237437421276, 0.04234368672534343, 0.027154158845904375, 0.02660554796156864, 0.020334359874287923, 0.035242668368042476, 0.03561181166479665, 0.06225638414522814, 0.03686417006857453, 0.0700475404699964, 0.014749788622852537, 0.05247968879918899, 0.022659053680517023, 0.040098623928403666, 0.07436796992776856, 0.03683198671487551, 0.05089187964556679, 0.059684213295939474, 0.03784308870953899, 0.006656854942951713, 0.08834079313542574, 0.014928328286435817, 0.04164903650000211, 0.02532437890617838, 0.014277008951701706, 0.05099516361951829, 0.048957350588734114, 0.017872425246863596, 0.007065250669726201, 0.048370397003788146, 0.010512513221211491, 0.07836105767637491, 0.03678299156167815, 0.06333312838368359, 0.03902867105939696, 0.03787144545405623, 0.06937933559980124, 0.04267544876183233, 0.05467230904727213, 5.2609319456162, 25.84938433862502, 28.917472093336045, 51.114276686022365, 33.565043403256325, 28.281546062038792, 14.38514453749503, 1.1604250030171488, 1.34274069099657, 0.11733492280566886, 0.03993448959062657, 0.06470530293881893, 0.018209544153163032, 0.1723978983899278, 0.9695131956569611, 1.364995606483952, 2.809227993411403, 4.044724342323119, 16.213696637461265, 40.330182736919774, 56.6457207741276, 58.54713678359986, 56.982373883647305, 56.362494268725, 52.86727413054436, 48.95408230443155, 45.760680706270286, 47.600582184330115, 46.59680058879238, 43.958739926738126, 45.22750508400702, 41.40188409436134, 39.71572775994578, 41.42388859102803, 46.50522893474948, 52.12274943628619, 55.108457611453154, 53.704417751681426, 52.21585081469629, 54.48345930345597, 56.19763705038256, 54.48694236816899, 51.96104972593246, 50.56468202221779, 51.57535129977811, 55.31088329130604, 54.700048662001095, 48.982637159286014, 43.05780679948869, 39.35866263604934, 39.87123404779742, 39.80482832078011, 40.099735644555864, 37.90532642795194, 39.85570930665539, 41.925598959768976, 45.638847966347974, 46.92471073519799, 55.046982303742446, 52.89176933227047, 52.85571490564654, 53.53359460830689, 41.14570233129686, 55.23119249651509, 51.67959220947758, 51.66798983850787, 49.22414533553585, 46.92360070443923, 43.83318093515212, 42.085537525915335, 41.890387842732096, 40.28234551029821, 38.40238094329834, 39.37980421127812, 38.347142204161614, 38.53256440931751, 37.968892358964496, 39.00104053558842, 37.862086219172326, 37.95421092740951, 37.94202412328413, 41.106345268987845, 40.02785821114817, 44.42882814714986, 48.08603825107698, 51.29519601022044, 51.17952139146867, 50.673719990638, 49.78511487284015, 46.532477640336566, 39.911661917163485, 37.63044280390586, 38.24071653427617, 47.27299367227862, 49.55342831150178, 52.2197731848686, 50.50234771543934, 49.614487847974225, 50.218430872886415, 50.86569255398166, 49.00204112452846, 53.23145051156321, 52.74969323988884, 50.919362345049464, 36.658495164686634, 17.095581754561394, 3.2029461956793264, 2.996029647127275, 4.1273767717422984, 8.66315366760377, 8.91203099681485, 6.9323323234435055, 5.1489526898630205, 1.0046682350577847, 0.4075660382307345, 0.5376263479551961, 0.41512181021032796, 0.17391349609580734, 0.3787181087799611, 3.025919333581002, 20.474070195228826, 35.0669660106782, 31.984034046050045, 38.837716963983354, 24.048814427468088, 3.1444553213734783, 0.04299251340149392, 0.011369642076803552, 0.028235223820252765, 0.04156292438687336, 0.0348271690909901, 0.06492429683285375, 0.03052371422640018, 0.04213044615161996, 0.04422903676787692, 0.06077658189761062, 0.04405371371596571, 0.04655092286186353, 0.04311258619230601, 0.03195201238286832, 0.008621535305264256, 0.06353010491077458, 0.06215307718863892, 0.018205133401938987, 0.048129079307639794, 0.014653331449916287, 0.045116315971338944, 0.04883420578534565, 0.21625198874502413, 0.08625624491082085, 0.0997143719465502, 0.2045433920237326, 0.08637225360519464, 0.2720865144604637, 0.2196329186159757, 0.08464744494807336, 0.05486579221342841, 0.14957540368120517, 0.10130514586043936, 0.07237322252964781, 0.10843408429214071, 0.1813414999313893, 0.14105387062074679, 0.17372983417684035, 0.16950154977460063, 0.14647359028458595, 0.1168515443080856, 0.10503168097667157, 0.11392863542442361, 0.1911213170857199, 0.13964989192543492, 0.11809813790023328, 0.1227809422679486, 0.12544807737633107, 0.17947648952324546, 0.13534996298051652, 5.381951284024024, 32.14321951712332, 36.93229229219499, 56.56391582181377, 42.52913013581307, 34.3110546758098, 17.047697459497762, 5.691610642017857, 4.133203942929545, 0.3125369680985328, 0.09525774737759944, 0.10193458668166593, 0.17684439527651957, 0.49050838596397833, 2.469822850919539, 4.420641112712122, 1.8156283805447242, 3.929679018835868, 15.331303573423817, 40.317058486323205, 55.92918611341908, 58.43836945872153, 61.30719100275348, 59.07768441784767, 56.148940824693256, 52.61401845562843, 49.04350057724984, 50.70618152618409, 48.16609774866412, 46.53298362608879, 48.815195099000015, 44.36414826300837, 41.633060747577304, 43.35699735149261, 47.99192490116243, 53.88410152927522, 57.35846642524966, 53.62164005156487, 54.967130691774436, 56.765976721240634, 59.84792809332571, 54.97150805688674, 52.74277810127505, 50.78786880739274, 52.07024851152974, 57.24101105043965, 57.278034302496145, 50.16882465731714, 44.28017423998925, 40.976930587522446, 41.70857421813473, 41.603129140792355, 43.139803947940955, 40.032184585448235, 41.296235053770005, 43.43071829888129, 46.24096708913004, 47.89026098866617, 58.48132725684874, 55.4354577679788, 56.259245718679125, 57.28371781687583, 44.00312938997823, 55.06106361266106, 54.41465308589321, 53.80899598521572, 52.619596066013465, 49.69721063490837, 45.89324112861387, 45.749164627444365, 43.50295266797466, 42.16349463309012, 40.14351321804909, 41.25450887987691, 39.70751039443478, 40.09075733923143, 40.03634229783089, 41.76012985167965, 39.54068022389566, 39.32481258146225, 39.97682425283617, 42.55771636962891, 41.80757484128399, 46.42607158230197, 50.191080185674856, 53.510629130947976, 52.344524168199115, 52.105773418180405, 52.70168735134987, 48.3081385397142, 41.40246068277667, 38.92526426622945, 40.3919953684653, 48.84329888128465, 50.10827502896709, 54.798657048133116, 52.14767217636109, 51.32100912832445, 51.380644844424346, 53.48253711577385, 49.561606453311065, 54.81478583428168, 53.938555794377486, 51.77808684687461, 36.8287613314967, 16.689404633737382, 2.7969977980659855, 3.785990832313415, 8.603868023041757, 10.051444230541106, 13.904093292451675, 11.589149640452478, 9.427654993149543, 1.8772587444513076, 1.4193092791303512, 0.8317917308980419, 0.8571292616186604, 0.23436655140211507, 0.4188055899595061, 4.262025856202649, 23.935452045932895, 42.97891224584272, 36.12786123829503, 45.497913283686486, 26.29860358853494, 3.083685059701243, 0.17126266333845355, 0.14463599050237289, 0.14357938671544676, 0.1903761280400138, 0.1534345409562511, 0.13140868575822923, 0.12191163931762981, 0.1425318840530611, 0.20266891276884466, 0.13389698530156768, 0.16631620215071788, 0.19130416695148716, 0.18298840510749048, 0.09425385810074308, 0.11221208519512609, 0.16496629394110174, 0.13788341574611204, 0.15023469894884095, 0.14292717010023134, 0.12391387905565002, 0.15688104795352106, 0.19131205765710724], [0.024218322228520148, 0.030022539506335894, 0.09403489485022523, 0.0224953789954945, 0.01740544677651938, 0.029413212323561314, 0.09192196306802573, 0.061802094006129814, 0.015622632814601306, 0.06474232030732018, 0.007040065050410528, 0.010059917094035736, 0.06012205552730349, 0.033980603630263964, 0.06901059449920732, 0.05930888000875712, 0.046966176990780144, 0.06771802797072357, 0.03564000753084979, 0.06905562514739652, 0.01418384021118043, 0.05399203446182994, 0.07104239757022551, 0.010045803839250678, 0.04142674459745327, 0.009761273038513478, 0.03813543552232366, 0.090547141679112, 0.7173139866321319, 8.94718720066932, 11.293096003993865, 25.873940337088804, 37.441109995688166, 18.789659315539947, 26.62953003760307, 4.576298411815397, 1.2925712475853584, 0.15769300922270746, 0.02068880577421477, 0.12720363680273294, 0.05171923928203122, 0.22417235728954116, 0.36198175362040924, 1.9970337109219645, 2.3830119736732978, 0.9590856358408929, 1.4939089600116977, 17.809272696894986, 41.23041375990837, 54.53454425258022, 57.80830344846172, 54.59369751714892, 52.34286108324605, 49.27481451342183, 48.70853408690422, 46.450809970978774, 49.16567456337714, 48.20954976543304, 48.04104866520051, 43.968828262821326, 40.71814829303373, 39.07753067631876, 40.39556080295194, 47.64613659151139, 50.739172581703436, 53.937841923006125, 53.69451376699633, 53.73157624275454, 53.9250942199461, 53.41021645453669, 53.0853618344953, 52.50657689186835, 49.521727715769124, 53.542667050515455, 51.81393731024958, 51.695528799487704, 48.430575324643044, 41.420068202480195, 38.410731669395204, 37.99998106495027, 36.79501718090427, 36.637596776408536, 37.68438716088572, 38.40560513157999, 42.320067805628625, 44.232615501649924, 47.59138030390586, 48.82389099367204, 52.41784111146004, 47.09423557404549, 39.60183781962241, 52.17319896144252, 51.928768619414306, 49.421726888225926, 48.79988608821746, 49.03529890121953, 42.972628608826675, 43.51167601923789, 42.7022204091472, 39.492470372107725, 37.13667523476386, 37.05460748364849, 35.3485058969067, 36.764799241096746, 38.58534774472637, 37.183410275367, 36.86359982336722, 35.80840772198093, 37.17101950799265, 39.3186426931812, 41.35944012672671, 44.870149704717825, 48.05093303803475, 48.10185324761176, 49.48447696624264, 49.40023229968164, 47.24354451702487, 45.25192968307003, 38.875116763576386, 37.485271961458274, 37.055450793235536, 45.495453957588445, 49.19339787575507, 49.450591610324004, 50.130734520573775, 49.76144336885022, 48.1724480659731, 46.8627804325473, 47.94064383352957, 48.87533287848196, 49.43962858569238, 37.8072867854949, 18.51521303576808, 3.2882761330373826, 1.110683465676923, 2.8103875440935937, 3.4479884274544257, 10.982943407950863, 11.078992447545453, 7.310721903078019, 2.6917588903057963, 0.5916252503952673, 0.547231251914655, 0.1327890995889902, 0.35137964833167296, 0.4999468036957326, 0.7813729105457183, 6.1628255632615865, 21.01625354059281, 27.33201280716927, 28.864104324771514, 28.277651148457682, 11.613920388683198, 0.6561264215457825, 0.04386778800718246, 0.00957046160399313, 0.06332892256097929, 0.0683466567387504, 0.012280218971652851, 0.08406458227264305, 0.06096027062965497, 0.015008260942845335, 0.034419292388784314, 0.05047048149149745, 0.09512316105106185, 0.030672448281679424, 0.012982336639036095, 0.04028413211926818, 0.02422783321010009, 0.015259864326987057, 0.005326386214414191, 0.05238299701182593, 0.0997340067800495, 0.04228006312323194, 0.05884443537422246, 0.05163772752688778, 0.022880301788269032, 0.027514836871095245, 0.05256208538588497, 0.01705454020280271, 0.022762833696399486, 0.020603549764341405, 0.05057742353528739, 0.08814793816136737, 0.03798487626256482, 0.01549070768599068, 0.04962528732815578, 0.0449453174857603, 0.06597041287609647, 0.05620227856261115, 0.04413843537951189, 0.07405235702472349, 0.02887640110847931, 0.026734967025056965, 0.026101201637497833, 0.12628849881190446, 0.02625539981489701, 0.036763609537193855, 0.014943800389676567, 0.045982497113366286, 0.03910892643034458, 0.05766585123755279, 0.050149168894295736, 0.018448280133006555, 0.9402849188735409, 13.904928757298379, 20.479096712604647, 39.235939518097915, 44.8104198517338, 23.5940783639108, 29.397234839777795, 7.23441219137561, 2.571407090271673, 0.23643432996205746, 0.06225770564689752, 0.3409723132368057, 0.14928548536714048, 0.17069050291132543, 0.18608579051590737, 2.8503920426291804, 4.873284591782478, 3.3802088902842615, 2.3945900749775673, 19.931684847800963, 44.2980053347926, 55.95422260222897, 58.297215123330396, 55.96865300209292, 54.000101704751295, 51.28173443578905, 50.280204280730224, 49.365978240966804, 50.619775633658136, 49.74054105820195, 49.40281321925502, 45.020050925593225, 41.310814503700506, 39.53802870165917, 42.346861516275716, 49.76389485020792, 53.04964080933602, 55.003981359543346, 55.82627488720802, 56.167038640668316, 54.62549617213588, 54.43447282237392, 55.041259565661036, 52.30272739164291, 50.56613722155171, 54.460046675897416, 54.54997877920828, 52.50244271370673, 49.35578792325912, 41.65492403891779, 39.257296823686175, 39.77979967671056, 39.50150359061457, 38.93398369512251, 39.80501267217821, 39.533459140408425, 44.416476603477236, 45.88433734832272, 49.27299453366188, 50.969725578062, 54.46291000612321, 49.91734189371909, 41.47618555253552, 52.33789928497807, 54.661829087042044, 51.89144726722471, 51.286892352565644, 49.56912171456122, 45.11260317217919, 44.38075950068813, 44.59994154591715, 40.68500818744783, 39.51007396944108, 38.65783314551077, 35.92164262648552, 38.45850221572384, 39.87278730638566, 38.413783273389264, 37.53099110818679, 37.4874214203127, 39.36476192166729, 42.38888579030191, 42.55781442888322, 45.79837468362624, 49.903174292656686, 49.85308562555621, 49.81859230226087, 50.57134612914055, 48.6086509304662, 46.86494558088241, 39.898847533810525, 38.352241285385624, 38.53993846524147, 47.60821903905561, 50.23371634944793, 50.56721195097893, 49.67098959030644, 49.588772789124526, 49.29660327972905, 50.19663426183885, 48.36941380654612, 50.224510546653505, 50.23106874958162, 40.402009179515225, 21.172103035834528, 4.96094907483747, 2.209441945437462, 4.216093430596014, 4.458486101319713, 9.924699702570516, 10.965474151795911, 8.400971658768194, 4.468017460838441, 1.6699574359001654, 1.1759892130090346, 0.8264572461766582, 0.05949085270385108, 0.15945024638166352, 0.4167079799357922, 7.371700540665658, 24.826563558270855, 31.303736202178467, 30.63209502927719, 33.55777525132702, 14.4007339977449, 0.8685394977369617, 0.03326801162573599, 0.056945161683665174, 0.072117755189538, 0.0403797781966146, 0.008972773212008178, 0.02008625272391064, 0.05822711023351839, 0.025353214455648296, 0.019559904354654496, 0.0492786746772547, 0.08105151250117248, 0.03386218558936831, 0.03268354782654393, 0.017721586365012393, 0.031192127855554707, 0.0032666127944755703, 0.02580772867546447, 0.024607512131032926, 0.02366920381093458, 0.07668216832943502, 0.0935587865270434, 0.12016452218015349, 0.10312891009473994, 0.13696283853102115, 0.18937823723160452, 0.11704450653445338, 0.07883692085142098, 0.10900730192060433, 0.1442551069081791, 0.20037403510462856, 0.16664201934491435, 0.16266222322179427, 0.15234188507160834, 0.13896821156865166, 0.20130728341398701, 0.10669229912661737, 0.1611734998802985, 0.14185049480968906, 0.30083656851803103, 0.21541508365302317, 0.11844837031657658, 0.1917861281864105, 0.06166035624881906, 0.08040466616230627, 0.20207111903977013, 0.15066845793156855, 0.22929946200982218, 0.16911395525019016, 0.09291079105629076, 0.18643276705857248, 0.7604681484160886, 17.778236942906535, 30.078750579587876, 46.715507199687345, 51.084219563391905, 30.94676717635124, 34.69514100782333, 10.888590793455801, 4.226816700350854, 0.4333827722697489, 0.18946420761846727, 0.46354016048773644, 0.3319809231306276, 0.4824167201595922, 0.7972409203648568, 5.506451235663507, 8.601848002403013, 3.0569104706087424, 2.956822370329211, 20.6838365908592, 45.11738454141925, 57.442338466644294, 61.84887816829067, 58.68438443829937, 56.23657441908314, 55.19988806016984, 54.04734665347684, 51.11815983249296, 54.97582266407629, 52.127413134421076, 53.25574567241054, 47.29054627879974, 43.972856536988296, 40.68288226281443, 44.24239789285968, 52.57562237401163, 55.48816657835438, 56.46527605672037, 55.57279955956244, 58.00334330528014, 56.60614013671876, 56.93443859777143, 55.91679142367456, 54.070198382100756, 50.089467263990834, 56.13487128288516, 54.75610717650383, 55.85005621756277, 52.332988477522335, 44.707453712340325, 41.857565449130156, 42.87722479912543, 40.78814298875871, 39.68855750176215, 40.37303463105233, 42.87241597329417, 45.49991369247437, 48.93512941175892, 52.11954093748524, 53.8258582545865, 56.67422856053999, 51.184251769896484, 44.223825470093765, 51.43032950739707, 56.58653613059752, 52.10255707463911, 54.37147563503635, 53.05379067697833, 47.082268422649754, 46.95879613199542, 46.52170288947321, 43.10662069628316, 40.899059772491455, 40.75945085094821, 37.798477142087876, 39.46208769275297, 42.612660931002715, 40.40264068111297, 40.753633975982666, 40.011141069473766, 40.95491824611541, 43.32048400755852, 44.62567621661771, 47.80512986644622, 52.135720714446045, 51.43693477876725, 52.251210981799716, 52.19169293680499, 51.40695610354024, 49.88924203380462, 42.46909041558543, 40.57362464166457, 40.54279088973999, 49.393811379709554, 53.337036794231786, 52.280609146241225, 52.56535753127068, 51.66973137086438, 50.29783141228461, 51.16199231916859, 49.91032869585099, 50.824036982751664, 50.04199089542512, 39.365354199563306, 19.811322996693274, 4.872061792881259, 1.950127311771916, 5.543035182260699, 10.348184281779874, 17.17363888217557, 19.06876733226161, 18.398218539453325, 9.32561747489437, 1.5687621240654301, 1.252042009465156, 2.9018547650306457, 1.5981020658246934, 1.5135827107775597, 1.6514369845390322, 8.850527251920393, 28.374716081926902, 36.79867675227504, 39.61547197834138, 38.51521576604536, 15.782523232121623, 1.0513709773940425, 0.19771664463464292, 0.1289985271831674, 0.19633259954712085, 0.17679967106350009, 0.15581356571807017, 0.22356408347766246, 0.15426973001130168, 0.20783778460275745, 0.18517259838840655, 0.16427402624920492, 0.2826798557033462, 0.13342522835779574, 0.07148373316252424, 0.12765771243721247, 0.12410433617450538, 0.07190032411486873, 0.11225761380046607, 0.08752330837230529, 0.16365893425480013, 0.09984328922244812, 0.19208989737014617, 0.2599416919533284], [0.09522528057136843, 0.06596899561343655, 0.056694585814951896, 0.05711950797347292, 0.03734608533822241, 0.018896839934431257, 0.039208870260946216, 0.020131900072878888, 0.03840408723561033, 0.017772466094503482, 0.0647830072369787, 0.05429010012096936, 0.028282581460511977, 0.0328913836499616, 0.01777227840296203, 0.08251173737188501, 0.019934224490556988, 0.03123595383048298, 0.058060260114049723, 0.033413729209813385, 0.12285539069243016, 0.04144215828648979, 0.0789539561036133, 0.06234478303081086, 0.015906514355822677, 0.017617630148907343, 0.046833980858566306, 0.04348849021499196, 0.1625031374034382, 4.032538273642141, 18.25725640020063, 23.218703616049982, 40.459573884164136, 41.00237892520043, 32.0855704815157, 9.203534683873578, 2.079282258787463, 0.04200123010143157, 0.06005559356943254, 0.178009262608905, 0.08993548175860798, 0.21366921523886345, 0.1118669779069962, 1.3333187901204633, 2.5162132132437924, 3.4607917791412723, 0.6314466232734343, 1.3758398568437946, 19.40672855223379, 47.512940745199884, 56.20998859405518, 54.58726483006632, 53.96031318172332, 51.722950089362364, 50.41296082158243, 48.892834494190836, 49.91390197507797, 48.22066968487155, 48.86919436916229, 49.07566009029266, 42.98099502440422, 38.894532495929354, 40.57722929985293, 44.361928201490834, 50.21182167914606, 51.76638641665059, 52.34353965328586, 52.757031994481245, 52.40492082411244, 51.171876692002826, 50.86697516902801, 54.17541203960296, 50.31084583651636, 50.57207961236277, 54.13719246464392, 52.27327823638917, 51.35785587372319, 46.42691096951885, 40.24993104319419, 39.80739747324298, 36.60082455604307, 37.390762452156316, 36.928122812701815, 37.96875115363829, 40.57042398760396, 40.94268829591813, 47.767431966720096, 48.62973759251256, 51.62454174410913, 50.98685456860451, 37.24454433687272, 49.77743879441292, 51.77022641704929, 52.75053654947589, 47.77177795287102, 48.76071729967671, 47.61603240043887, 47.49126964999784, 44.98258836807744, 39.81065696285617, 36.73032945202243, 36.89607312602382, 36.575144798524924, 37.942918423683416, 35.77616583916449, 35.99150003925447, 36.39984623078377, 37.46706039674821, 40.22549075465049, 43.883183310108805, 45.16864991957142, 47.35413182166315, 47.16542659267303, 49.87074413607198, 48.5558872069082, 50.05930031499555, 49.48522221657538, 46.80532163189304, 39.334512602898386, 36.6123249453883, 41.64640465090352, 47.559934662234404, 47.96176579690749, 49.00751675328901, 48.61093374990648, 49.66007755648706, 50.055997679310465, 48.680967669333185, 46.81277021285027, 46.123025340418664, 38.07376869263188, 24.403708519474154, 6.512932402472343, 0.8825855053240254, 1.5579366275379736, 4.1131351359428905, 3.2001948981515826, 7.371829978881344, 6.465410436353376, 3.7451660681155423, 3.5571600016086333, 1.527614377198681, 0.9363316600361179, 0.2785689053275893, 0.07378597293169269, 0.06438400566337571, 1.7494298037021392, 10.543888980342496, 24.08134068212202, 24.747559178260065, 33.68056504957138, 24.21608978702176, 2.9719173667892336, 0.1429575531473083, 0.03911750278465691, 0.06362699205055833, 0.07900903016448983, 0.027744171036888036, 0.008702432274848463, 0.02481510855197426, 0.036808372054609566, 0.004126410987678795, 0.01850724017487899, 0.032394192587103576, 0.036588382246273185, 0.03571672740602686, 0.026194275574638482, 0.014163208505769652, 0.020879958117861423, 0.046665349584673686, 0.05494367654225039, 0.030263211773408037, 0.027139017118080973, 0.05257268804275701, 0.03211485394727319, 0.05787240386369729, 0.0803222197798952, 0.02307074741580554, 0.038213875264890736, 0.03457137616351247, 0.0387196809864573, 0.020366357451665307, 0.03610044552554046, 0.0869897740983194, 0.05477954603491291, 0.03462220226684886, 0.06208957233015568, 0.05804202339101223, 0.04001443852640448, 0.01450054670473741, 0.04639865905647317, 0.054654666042375954, 0.04670115653425456, 0.030014759883464828, 0.020151829850229046, 0.041848326612624435, 0.08815307095046006, 0.01470852712725079, 0.035049618041563424, 0.08660489152516089, 0.07642443336906933, 0.024054143840687412, 0.015396599530152258, 0.09309953979907498, 0.15530227863740537, 6.433781423876363, 21.41268357153862, 32.20190405845642, 48.386840897221724, 39.35190046987226, 39.46829288236557, 12.577414339588536, 1.7923366110171042, 0.22066490033701544, 0.05759989489771186, 0.1795350186406605, 0.10703405861051814, 0.11216837987904588, 0.23839959063597266, 1.6890634235835846, 5.9184996543392066, 3.687141710712064, 1.6170889115141285, 2.758219285357383, 23.3233916759491, 49.657520171134706, 59.0170681092047, 56.05576099887971, 56.23502508286507, 53.23393729425246, 50.64326278624996, 49.29255539371122, 52.23978119511759, 51.348814810476, 50.080081032168486, 49.056197289497625, 45.40022273217478, 40.65437055403187, 41.42781096120035, 45.352385505553215, 52.396581865126095, 51.68065124942411, 55.500910359044234, 55.03520342611498, 53.756942210658906, 53.152512811845355, 52.86097480404762, 56.25808469710812, 50.77640371937906, 49.759195850741484, 55.55144225397418, 54.229854537594704, 53.08194545007522, 48.666117575860795, 42.554578473491055, 39.82733488082886, 40.10266957744476, 40.24978199312764, 40.25395147262081, 40.45780097284625, 42.17328486904022, 42.51615101291288, 49.38729240048317, 52.192736287270826, 53.120729846339074, 52.29006598072668, 40.16056376118814, 48.775261448275664, 53.05297482398249, 54.465934153526064, 49.6377553478364, 49.868143604647734, 50.65169980449062, 49.670483604554214, 45.75702113489951, 41.94312018732871, 39.233233082679014, 38.59711877761349, 36.75278109888877, 39.76296486393098, 38.663500970409764, 38.37539895888298, 37.510786979429184, 38.81932104787519, 41.89924455458119, 44.66210326840801, 46.02606827212919, 47.70761582159227, 48.93356438606016, 51.09808121958087, 49.44855590020457, 50.731559261198974, 50.21854069925124, 48.72588665254655, 40.736465761738444, 37.81036192371, 42.38508109123477, 49.76232590213899, 50.515766143798835, 50.81240715519075, 50.14671425665579, 49.18858512755364, 50.27134756888113, 50.49737022769067, 48.840243354920425, 47.1816808946671, 41.61374307447865, 26.342847924078665, 10.1929094137684, 1.670369897638598, 4.3937606196249686, 5.769254449875125, 5.957190894311474, 11.058898145152677, 11.124442911917164, 8.459244351233206, 5.2431008508128505, 2.8315102429159227, 1.2533991495447776, 0.6392936925253561, 0.13245174511065408, 0.06132567924777828, 2.3167712313513604, 11.539179625049716, 24.305510021025135, 31.152034613393973, 38.60782292581374, 28.196283540418072, 5.316464372219579, 0.09371830901551632, 0.09989510740964644, 0.03976617624322253, 0.02704483426866993, 0.04851217689593473, 0.019702461826044227, 0.01364098743520557, 0.051397716010650324, 0.047341414516971964, 0.01934094493457627, 0.011864782896854225, 0.016224527986900463, 0.012082843121231325, 0.017499263818946578, 0.03252117549099269, 0.021415727453366406, 0.06756064286755939, 0.07947704859919126, 0.031138229739641955, 0.028797239328043598, 0.04464789534047727, 0.06353809137738521, 0.025423652409846266, 0.19718907052470794, 0.15077877459266495, 0.11094378833208354, 0.16614796924254588, 0.17970446196775283, 0.1154452137228462, 0.2005403987582653, 0.1510224211961031, 0.18876369682050523, 0.14297721096344534, 0.1581300317399925, 0.17609828692530433, 0.1671227088738834, 0.1694229951188449, 0.15067601155850197, 0.13450669935874401, 0.10211475523969821, 0.15475844814171716, 0.17786067219511156, 0.19808874886122443, 0.24782742103261335, 0.0705124945530007, 0.16307341325427258, 0.18844540260972517, 0.11322954188912146, 0.14206527522014034, 0.1154615697000296, 0.21758358745325, 0.26028750404234857, 7.824691149496264, 32.65785409558204, 41.4420570096662, 57.18902787854595, 51.77858106551632, 44.902654386335804, 19.29287979679723, 2.362456302489004, 0.49552693602538883, 0.2700341342677993, 0.5118987252635341, 0.2750073932111263, 0.5948276817798615, 0.5975493776702112, 3.586691281487865, 11.409707088624279, 7.098657979119209, 2.3072484520173844, 2.4140293415515655, 23.119422543433405, 51.84676754859186, 60.12445126810382, 58.597849107557735, 59.05189483396469, 56.13531451071463, 54.26173163998512, 54.312965639175914, 54.34840425368279, 51.78293097403742, 52.14788398435039, 52.16640933867424, 47.09040341838714, 43.65087309191304, 43.48542751804475, 47.613561307230306, 54.45772855512558, 55.59096405583044, 56.36291396233344, 57.26809109410932, 55.56431155050955, 54.929177837987105, 53.309489988511615, 57.876611525012606, 50.31458777766074, 50.3274727636768, 58.038295545885646, 56.5234330392653, 55.766137107726074, 50.465026363249756, 44.64793174497543, 42.38037424702799, 41.93764063619798, 41.51233411604359, 40.82065159274686, 42.043819196762584, 44.107942965722856, 44.47013070506435, 51.69691339615853, 54.2077245250825, 54.89408439205539, 53.73705579388527, 43.320762495840754, 49.00070751866987, 53.591818271144746, 57.019114725051395, 51.502736460778024, 52.98310172173285, 53.41824946864959, 51.61689312227311, 48.048301127649125, 42.92528952321699, 41.18936223368491, 40.41030499242967, 38.423514673786784, 42.584761111967026, 39.4519248316365, 40.41425874156337, 39.89668630784558, 40.926712482206284, 43.493284025499904, 47.57964064998012, 48.26034445916453, 50.985721003624704, 50.76298529101957, 53.18413888254474, 48.757771599677305, 52.579250566421024, 53.13643109413886, 51.724048353010616, 43.24233078187512, 39.843326384021395, 45.27133364831248, 52.5763911585654, 51.11803431664744, 51.72886110121205, 50.85615727209276, 50.42820315207205, 50.832842703788515, 52.15352435265818, 49.55360874052971, 48.46266815739293, 39.831790693344615, 27.27940597841817, 8.688199962339095, 1.2013179183967653, 4.1415909509505, 10.617720734688545, 6.897006967375356, 16.21488021266076, 15.524106698651469, 12.58341262417455, 9.670364395264658, 3.8925807514498314, 3.425433328074794, 1.8788701031477222, 0.4323113829858842, 0.33894935082043376, 2.9637353026097824, 14.8302766776854, 33.5474358835528, 36.36715719776769, 44.35000811853717, 32.71856257992406, 4.967082190898157, 0.2475794996585577, 0.21379827041058772, 0.1585453586472619, 0.16710550253910406, 0.12572519436118104, 0.07876071042471355, 0.08595111209057993, 0.12621411167445684, 0.13341909965440152, 0.1066041070847742, 0.13650856371368134, 0.2208461873834172, 0.13987970298096059, 0.09593352885736574, 0.22418610090690277, 0.2202558859942421, 0.1479769152619185, 0.14417393223172234, 0.12307136620004332, 0.1597556243500402, 0.12670748761945194, 0.16829560480771527, 0.23443831851886165], [0.042056127962085514, 0.023959273427364328, 0.004811709194684461, 0.040622589764215296, 0.08854641879518187, 0.08734235074371101, 0.04874356226214478, 0.010363123203147083, 0.04031081496167087, 0.06596315036257429, 0.04421001863515666, 0.08606317543214367, 0.044457572287008654, 0.02510105853059119, 0.03912926989517385, 0.03830901572420713, 0.040103978882994384, 0.05094673920182451, 0.07806760769697928, 0.06237195999992471, 0.09968788828700782, 0.032797346357256174, 0.06255944086719425, 0.02111815975137776, 0.06404922907090475, 0.022477310811800343, 0.032247682102024555, 0.07236426696181297, 0.11933566867223672, 1.0258797387922964, 14.749314054366081, 19.113670625994285, 34.4671061731154, 42.16520478648525, 23.068990668942853, 21.450185352756133, 5.686388986725961, 0.5574577902593921, 0.02095137857982228, 0.11878810732835725, 0.12293570735041173, 0.22047451216607328, 0.09409265021883673, 2.014213569702641, 5.862498014203965, 2.675631820194183, 1.3557966678373277, 0.06548547922002693, 3.0869354788334142, 26.394689890646166, 51.389081862664995, 56.956627445836226, 56.28403509816816, 53.387776574780865, 52.457147182956824, 50.84182493148312, 52.24178944864581, 52.048883361201135, 51.881084365229455, 50.4635319402141, 47.15321625432661, 41.660835050767474, 38.65982963192848, 40.26766407874323, 43.04392553144886, 48.000201102226015, 51.41224738090269, 47.701206668730705, 49.48341008155577, 49.375125208208644, 52.09026436651907, 51.73838461599043, 53.88626275524017, 51.26064385137251, 52.58700509225169, 54.23091357754123, 53.33247900009156, 51.92980020276962, 48.435529278170684, 42.43403227098527, 37.66409281761416, 37.729945490437174, 38.67922967480075, 38.73713170328448, 38.353147352895434, 44.99483400775541, 49.10789020599858, 50.726248371985655, 53.56376547967234, 48.47478828122539, 37.55138351071266, 51.31208965855261, 50.60787516255533, 50.0073524444334, 51.292560177464644, 49.86540971263763, 52.1890139579773, 48.68719639316682, 46.23887646582819, 44.721032957876886, 37.732338136242284, 36.28173189778482, 37.47173586199361, 36.12162466972105, 36.21618124746507, 36.55846295818206, 37.1857480079897, 44.18519796863679, 46.83355877476354, 47.19133384766118, 48.84800964786161, 49.52232391603532, 51.725083858736106, 49.774422491750414, 49.3032556195413, 49.38657460674163, 46.579455867890395, 44.52989193700975, 37.38854631300896, 39.343906679461085, 46.010065001826135, 48.25359798246815, 49.01405926673643, 50.98912954330445, 48.735570984502, 50.21010760338076, 50.20542821576519, 48.67913592246271, 47.972830803163596, 41.93212970610588, 27.105284121728715, 12.76286498192818, 2.088637601944708, 0.5197324339420565, 5.20514456495162, 3.85676117673997, 4.163266949115261, 7.854510968731296, 10.006560548659294, 8.68375591693386, 3.374364558727511, 4.135759367096809, 1.1467009975064186, 0.33145051449537277, 0.10266220933126827, 0.7241236502605101, 5.286539629582436, 17.618421931420606, 25.172544064060336, 21.29007616350728, 25.427780535913286, 12.57442843529486, 0.9434822634343178, 0.05907180643970928, 0.051530747178701625, 0.04925581844403379, 0.11478539751542192, 0.01967851966319065, 0.0272078731007153, 0.07936912213241862, 0.013359599510177731, 0.07284023738916844, 0.06625433272171406, 0.04311139875602338, 0.021718667346924063, 0.07480162165818677, 0.05880552193810863, 0.020403221602581685, 0.03754242984277587, 0.05075653106154454, 0.06129069584271601, 0.039502105735723055, 0.06475003481271767, 0.04380089320963429, 0.04943669946383565, 0.03282524727945847, 0.07658621581691889, 0.04504756724101402, 0.09048785413465193, 0.06964811754803504, 0.03217385420876165, 0.06020039567844041, 0.025491905098240224, 0.04814961429445013, 0.05088635998207235, 0.05802153819991697, 0.011630684621782314, 0.03066208311206391, 0.07459480856214801, 0.05177042927713164, 0.013805401395075025, 0.027892342017542933, 0.03048669302745933, 0.07621873110052078, 0.06536733314034439, 0.02429354248658544, 0.02071067949967279, 0.021809125093803294, 0.07101817387005976, 0.01559365075081587, 0.07076362583545909, 0.07356349333760238, 0.055975922563624, 0.03234807792450151, 0.14767242595553398, 1.2984047926241353, 22.319115861769646, 27.91708923155262, 45.9110761457874, 50.1503542161757, 31.920179820829826, 21.248142103995047, 7.2068389096567715, 0.4928079980515665, 0.16346670747283967, 0.058164011401635025, 0.15230362664066976, 0.20396072087028336, 0.43998078112640693, 1.5693855357746926, 2.9854608206979694, 4.647851759387601, 3.1743807994550277, 0.43518004518362785, 4.661957583119793, 31.238917073895855, 54.70751685480918, 58.22001503359888, 57.814218382681574, 56.28819281055082, 53.291164675066554, 51.39489873763054, 53.968632528858805, 53.520435056378766, 53.63217946021788, 52.712960243225105, 47.28543543046521, 43.01582567153439, 41.16199977936284, 42.492212787751235, 46.82940498475106, 49.76546379827684, 53.43983819407802, 52.71822798636652, 52.73079133802845, 53.079807758331306, 54.00094501433834, 53.666821833579775, 55.04367966805735, 49.381040142428496, 52.990048239308024, 54.55483467348161, 54.8801560555735, 52.29540040416103, 50.49785660159204, 44.9297736537072, 40.605089895186886, 38.961707007500436, 38.97055587460918, 39.244145116498395, 41.365280535913286, 45.868957734877064, 51.547855484870176, 50.9609277017655, 56.05013239768244, 50.45869565779164, 40.476777399739916, 51.184341984410445, 50.192758960108605, 52.08581639874367, 52.12929979447396, 50.23045293746456, 53.530437100318174, 49.778948906929266, 48.53668328254454, 47.236582309969016, 39.781498062995176, 38.37910167632565, 38.527186839811264, 37.261081049519206, 38.96956743732576, 38.62984703433129, 38.398964558878255, 45.1913369086481, 48.807048336152114, 48.505982891205825, 50.52214391769902, 50.909646634132635, 52.719718487032004, 50.78456617170765, 49.9719177522967, 51.39183536652596, 48.0643436216539, 46.28023001455492, 40.21027588075207, 40.96195890057472, 47.320556332988126, 49.43574936159196, 50.939166392049486, 50.78799432323825, 49.44552390806137, 50.54683131556357, 51.76187569095243, 49.21215072754891, 50.79782378289008, 45.002768962614, 30.177298168982233, 15.194673692026447, 3.6106184749834003, 1.5465308653731502, 4.759288257168186, 4.166257756371652, 6.692755424207257, 9.633396056390579, 11.55160471316307, 7.812353824415515, 5.5723490157435025, 3.6920392801684723, 0.807838796848251, 0.25553899997424695, 0.09621446096007863, 0.6854425226488422, 4.3270920938061135, 18.56605479794164, 29.0650708829203, 25.991293730274325, 32.19015263742016, 16.82396938723903, 1.4092648245634571, 0.0991942595329977, 0.019812077516689897, 0.0333247825713648, 0.09547125608209642, 0.02630599609185611, 0.030384200039289655, 0.06237225494377556, 0.03522218700738684, 0.030775100233093388, 0.061571310018940326, 0.053834722137018565, 0.01692810888221908, 0.03485909963567411, 0.05056173405459812, 0.023637838256094727, 0.022275040617152568, 0.1113855222901029, 0.036440393211500305, 0.03781892629640718, 0.021873206433449543, 0.09835562308228786, 0.0568435094769924, 0.07913732690916908, 0.2149069834981234, 0.09253131706387767, 0.19577170061247964, 0.14787465784578555, 0.12793010265956964, 0.1654851499704584, 0.12994574893626476, 0.15522726330785983, 0.13594746559617982, 0.19306816100593538, 0.10290276093949234, 0.16116518016544082, 0.21508336758180974, 0.14839516862505867, 0.13478371675216383, 0.10107339660246527, 0.15256595046770188, 0.23449261883093467, 0.2211603600411646, 0.11117776690591728, 0.2149232858491521, 0.24286114881115578, 0.21029482775878525, 0.08955732543742465, 0.1609786683993955, 0.1291211931816032, 0.1803236448716733, 0.20002776336285377, 0.23881309425398228, 1.582944311441914, 26.41505091421066, 37.028570790444654, 51.7454017362287, 56.048143756005075, 37.339810863617934, 31.799798357871275, 8.785952291181012, 0.9629619794507182, 0.3173065089410351, 0.26227951650657966, 0.5604823053844514, 0.40288956174927376, 0.8909090812648497, 2.8635403177430554, 9.515348403684555, 11.41824314671178, 4.404849160102106, 0.46151787222873786, 4.402659987249683, 31.539664806858188, 55.19084307455248, 63.04838995779715, 59.19480246882285, 58.518268139131614, 55.75694307204216, 55.45606197849397, 56.53682401103359, 56.86032933573569, 56.050744287429325, 55.581844545179806, 49.887006282806404, 46.87891314106603, 44.189991104987364, 45.77131425180743, 48.251205336663034, 50.17493178767543, 55.96165549370551, 54.11852590499386, 53.3362562425675, 55.294958468406435, 56.565924075342, 54.51680337229083, 55.192855250450876, 50.174112012309415, 52.8638538237541, 56.37806215593892, 56.899368686060754, 56.408127123309725, 53.30058228585028, 47.957184468546224, 41.69446545262491, 41.74468355794107, 40.2584308193576, 41.295803593051055, 42.38885441134053, 48.153593232554776, 53.24031899052282, 54.912849010959754, 57.19205594831898, 51.984646704889116, 43.29964837720318, 51.046227485902854, 51.278816192380845, 52.20497408220845, 54.61072844843711, 53.22005602621263, 56.48614306603709, 51.63390051934027, 50.50238693914106, 48.38247922159011, 42.02050462845833, 40.37141076980099, 41.97321261129072, 39.923146617028024, 40.773049708335634, 40.113385492755526, 41.30145965083953, 48.83359885984852, 50.81551759473739, 50.90129590803578, 52.93753946981123, 54.548958962963475, 54.634549002493586, 53.272729535256666, 49.294665628863925, 51.962218592243815, 50.3830841279799, 49.94955631994432, 41.06094383424328, 42.515017447933076, 50.759031541885875, 52.413216637026885, 51.198297777483546, 52.97877142506262, 50.34246406247539, 52.002991630185036, 52.75208588569395, 50.89847964625205, 50.75318328795895, 45.051520101485714, 29.850811842949163, 15.118578730090974, 2.8603310834976936, 2.0249613542710585, 9.239652849012806, 9.1226299155143, 10.115790713217951, 18.089208333723008, 21.55559316758187, 16.540066272981708, 10.271609810090835, 10.603495278666097, 3.8727011988239908, 1.035292201465176, 0.37356512560959787, 1.239759474992752, 6.491441736298223, 24.25543704340535, 35.221456404655214, 31.379730163082, 37.52719425385998, 18.115768663344845, 1.659795065079966, 0.25718497052308054, 0.12632301107289332, 0.18125307806316884, 0.2657179336153692, 0.08874042290112666, 0.17705378242798392, 0.17192701478638958, 0.1023935039918269, 0.2325895032094371, 0.17257556950132694, 0.08789721290550886, 0.12578171632823446, 0.17473961466983443, 0.16596914899926032, 0.07537879230033967, 0.09284369707588228, 0.22302768403483977, 0.15066096559166908, 0.14308472374273887, 0.20414995990933912, 0.13065994206455447, 0.2087011963369385, 0.1870208927580426], [0.025792247953734575, 0.058631953227544026, 0.03424904466937146, 0.009575348287340133, 0.08420285348209643, 0.033039181162753416, 0.0218826484671163, 0.036375478751236395, 0.08528355073424117, 0.020257044365749727, 0.012448788958511526, 0.04205955237510704, 0.10296710466425266, 0.07255394267098558, 0.009112558402721922, 0.07772956373951129, 0.09411625338778382, 0.01805164194064996, 0.011429729225534585, 0.029352733512378992, 0.021892881486564878, 0.057221960742026574, 0.025443892452805757, 0.01691261858439013, 0.02314505219880131, 0.012186796464506659, 0.0758336723271397, 0.00823646025251477, 0.06806108214321636, 0.26193186580654115, 5.8581343773872625, 14.860017068924444, 15.108581589114282, 31.078450948961322, 25.910983200996156, 16.48994818810494, 12.779931214547927, 2.8057971452513053, 0.045323117576058836, 0.09263314547077303, 0.16943103904204984, 0.023175791476763064, 0.2919731150952078, 0.6542720597597861, 3.95938876655794, 4.380499086072368, 3.0033710983491715, 0.7947600212308669, 0.23812021369174605, 2.4716143934957446, 28.995927341522712, 54.17318413334509, 55.94480891381541, 54.69849148104268, 52.184146296593454, 52.31751080482237, 51.167099245132945, 52.488039770433986, 52.58928006695163, 50.05759800634077, 46.73182425960418, 45.44565554588072, 41.35599628571541, 40.57691551023915, 39.120931702275435, 40.60040266283097, 43.782080296547186, 46.021220222596206, 45.80551731971003, 49.269633062424205, 50.08245014375257, 52.09510457131171, 53.200153919958304, 53.71792247218471, 50.27616423945273, 52.494656808914684, 53.553739901511904, 53.43541768289382, 50.73494426665768, 45.01194338644705, 39.751727273387296, 39.29537519331902, 37.39380621141003, 39.63891598486131, 41.23917633487333, 47.32598097093644, 49.60218729511384, 52.342155056615034, 52.96732202652962, 49.292971164949485, 36.49859974461217, 50.592020942318825, 52.342904229317945, 50.876486916695875, 50.888320707505756, 53.10132588109663, 49.54691325464557, 47.726129408805605, 50.45096074381183, 44.64895156122024, 37.21334972689229, 36.07845114123437, 36.114627161333644, 36.99699963292768, 36.09831794615715, 35.85416609241117, 42.21825484306582, 48.0231705019551, 48.75327264108966, 47.35492414043796, 49.04537939256238, 49.10501510866227, 49.66070513571463, 50.46979596537929, 48.80518128795009, 50.305095641843735, 47.112019600406775, 43.58814262574719, 40.48728935180172, 42.59623404472105, 47.67498954649895, 48.60350870317029, 49.419181269984094, 50.100924507264175, 51.24301671981812, 48.30394944837017, 52.14781338168729, 49.93168207906908, 49.8501399255568, 33.911769159378544, 21.34139253247169, 6.056153274351551, 1.513310964069059, 1.3488249000041717, 4.400229588631661, 3.2270589663136393, 6.227098011201428, 8.872107152015932, 8.331117187776874, 5.664267309250371, 4.354308930135542, 2.3573550149317715, 0.3240269386479932, 0.13344010578528528, 0.24504779357342954, 2.3957709535475704, 18.424123833256385, 21.628590437673754, 17.61079292143545, 27.438993492434104, 28.17619316039547, 5.701391562338799, 0.2962642187072385, 0.018147912379654667, 0.04922946884987816, 0.010177260696617587, 0.10040230358079558, 0.04969285628307731, 0.07524145571815391, 0.02017358291683899, 0.0593576108616206, 0.062110655069831884, 0.11505366618474645, 0.020761411757238453, 0.023367323033932238, 0.10772793508705594, 0.051311799249942266, 0.06747823478954454, 0.01889179141501025, 0.03645501399953519, 0.052201985757076935, 0.014001100470552282, 0.029719130383924614, 0.07774485485447992, 0.017761089688827916, 0.051863972443125905, 0.029652861863254543, 0.06434249901963819, 0.01237210164207124, 0.06333912685213071, 0.03419536488851713, 0.045397615796255494, 0.021938132385032314, 0.04771081062274114, 0.07356684880271074, 0.01691220872735064, 0.05454377098489673, 0.05688097500692933, 0.05964571737774438, 0.04375994197964188, 0.007924451793153441, 0.017771230777725577, 0.02894274815316162, 0.05138059394554265, 0.03272257234540678, 0.012595113667268908, 0.07492623351995023, 0.02656792921404685, 0.025801730207017353, 0.006873433744805235, 0.03853188219269918, 0.04652220605602188, 0.04328240107204165, 0.09668958869071738, 0.021089688093671878, 0.26798337818153445, 9.55545856106666, 24.48076936506456, 28.818192981904556, 46.01023758611372, 29.926972504585024, 23.110742338242073, 15.940965414047243, 2.2131745709526927, 0.09737085536002152, 0.10324698722650928, 0.07358135084711737, 0.11424596436441907, 0.4190799107234325, 0.7042973560671653, 2.712397666708116, 3.8733996258627985, 3.580205397259805, 2.6218048891713543, 1.0549096907338789, 4.590673408200664, 33.33422760809622, 54.57497212194628, 58.22487877261255, 54.86344283626926, 55.6442847559529, 52.87078072947841, 53.58474231535389, 54.206849836534076, 53.82235950039279, 51.50019868727654, 47.36602837039579, 45.018709474994296, 41.7035065158721, 42.193896924295736, 40.30476970057334, 41.717387783911924, 46.13462378901821, 48.22427434305991, 48.91231298446656, 50.16207033588041, 53.814757946998846, 53.993696474259906, 55.65569493078417, 53.03624199282739, 51.884539973351266, 53.77720517496909, 55.31690020715037, 55.5459705475838, 52.936386292980565, 46.71535030488045, 41.21973706829933, 41.16484349773776, 40.419428425450484, 41.60270552481375, 42.594437599182136, 49.404578285832564, 51.67370080947877, 54.29631125542426, 53.23762824458461, 50.25985894664642, 38.51784375406081, 51.32182498132029, 51.25804724231843, 49.524540055182676, 51.68687605088758, 54.23864456915087, 52.03557475920647, 49.34516614483249, 50.971600471004365, 46.446460062457675, 39.92918314472322, 37.108744036766794, 37.939800139396425, 38.3767286423714, 38.151333562789425, 37.71768416127851, 43.72444891160534, 49.920307205569365, 49.821898860316125, 48.80595791724421, 51.118108841680716, 51.46712918435374, 50.495840503323464, 51.45219672110773, 50.093475926306944, 51.9916049895748, 48.902554127477835, 45.75382832557925, 41.83720442556566, 44.370447589505105, 49.00154298351657, 49.68265471919891, 50.36644935607911, 51.77680030945809, 50.166031929754446, 50.806547134153305, 51.55972849938178, 51.482802975562315, 48.0620764916943, 36.181731070241625, 22.695769302306637, 7.657552582602348, 1.6502309782851128, 2.7561409194623274, 5.938484130367156, 4.672303815041819, 5.887610498935946, 10.213831336267534, 10.124167915313475, 8.169236558098948, 3.835223932420054, 2.3558745653398576, 0.23489383439863884, 0.20169555209577086, 0.038456797915240454, 2.9214727445956203, 13.72847701272657, 23.542683547542943, 23.65801888127481, 28.967884355975738, 31.48929176792022, 8.195922893862571, 0.4028545668528926, 0.015088140930710061, 0.05491752613095507, 0.013020543359039773, 0.10677315970702518, 0.07905128757439314, 0.02510021200343486, 0.011310997088589977, 0.016492773673587268, 0.056702277337711667, 0.01760218390113404, 0.008673646521093625, 0.0211608519161781, 0.07367479059124186, 0.04130077676006383, 0.05796521158528425, 0.04546546437326939, 0.08989188369483718, 0.04575996006268167, 0.05550401240226723, 0.037929855827842994, 0.024781912046995376, 0.06501642656662772, 0.04785665078088642, 0.07718036296747385, 0.16821389386971153, 0.16311770845805446, 0.1328757747767433, 0.16869173355160222, 0.12616867499966777, 0.12156535225409655, 0.18386651040805926, 0.1876960307239525, 0.21177051228380975, 0.09713528332330527, 0.15271101687704364, 0.2228728423435842, 0.1442641620674441, 0.07815209187326894, 0.19078652134105084, 0.21102394427983992, 0.11643630167048787, 0.16664073231720156, 0.08887444232260028, 0.26958376649887333, 0.2017453171673321, 0.1534412518864678, 0.08959748376641544, 0.11224099735338842, 0.09682402946054937, 0.14032763459028738, 0.24029043352892324, 0.10170117501289615, 0.2851828488130724, 11.670733959444108, 36.45821502131801, 35.407721919398156, 53.27557717600177, 41.593891959036554, 29.054082362882554, 18.20310611878672, 3.605280374327014, 0.31047441425823397, 0.338821291563011, 0.4350737121797377, 0.22533451267067464, 0.6779837067569456, 2.753698753733789, 5.925030400676112, 7.497444373946037, 6.634683262917304, 4.022922583164708, 0.6881455259938395, 3.6790908007852496, 32.11363504009862, 55.537274652911776, 60.535323466024096, 57.25883037813249, 57.22001460290725, 56.494717367233775, 55.77210303275816, 58.4853280744245, 57.45978516917075, 53.70045615780739, 49.88336240091632, 49.67853623051798, 43.78457492397678, 44.629453459093654, 41.14748308735509, 44.2399856352037, 48.900910654375636, 50.02468932059504, 51.783919411320845, 53.14908858268492, 54.50251025538291, 56.728804419117594, 56.17906462761664, 54.888585229073804, 50.92391229444935, 54.51956864326231, 56.35442595328055, 59.214508456568566, 55.67825640401533, 49.93443166055987, 42.51886137070195, 43.801743138221006, 41.211676597595215, 44.065581367861846, 45.68091146407589, 52.08855421312394, 53.801104176429014, 56.45197137709587, 55.92558145523072, 52.11599903721964, 43.21495656044253, 51.311905307154504, 51.05292689415717, 49.44134658382785, 51.86393576283609, 55.297617835383264, 53.71739295221145, 51.685118829050374, 53.990044747629476, 48.79495566891086, 41.32984976614676, 39.34462839557279, 39.274484649781265, 40.71637538171584, 39.03321573811193, 39.36381270808559, 46.02805691380655, 51.62769532972767, 52.09773648169733, 50.772293075438476, 51.464940501797585, 52.042533043892156, 52.47925758361817, 52.40745075287358, 49.769123369647616, 52.554700451512495, 51.05599026526175, 47.60134312414354, 44.86602729366672, 46.825043309119444, 51.75698841771772, 53.32967058304818, 53.07048036206154, 53.316891501026774, 52.477308165642526, 50.02262223151423, 54.172431038272, 52.70116567611695, 51.747798304403986, 36.03295164723551, 24.217052728899066, 7.345360354069741, 2.2004175522635063, 5.447536255082777, 10.060114629807012, 7.27031413585909, 13.151342407349619, 13.81359342605837, 15.90349599238365, 16.473827246696718, 11.906658641753658, 6.605247345662887, 1.7297835095274834, 0.5977469057806077, 0.7539013040161903, 3.8847494942526666, 20.518096839227987, 30.19176975373299, 27.872684078831828, 37.55801231630387, 37.76279926300049, 8.308823416309973, 0.4870660158414995, 0.12084932051478856, 0.24289214472857215, 0.12065742315063555, 0.14878409614245738, 0.20403270249164876, 0.08672502943344655, 0.13855100008508853, 0.1222924386421519, 0.13552551968924462, 0.20562474045061296, 0.1873239111756125, 0.11753537737193609, 0.1481752860690317, 0.11056665856871875, 0.13236203621472084, 0.14081043852192743, 0.12258698412727927, 0.08642597935132443, 0.18159709750644623, 0.12924176009912647, 0.1417144988813708, 0.15665105303689358, 0.16998052326661928], [0.02913334891350279, 0.021520880681853143, 0.05586883496312846, 0.020178328831529906, 0.07525894550546523, 0.07660750540033465, 0.030580672863570434, 0.029236000864916754, 0.037329055203665654, 0.06422641371647198, 0.0016853042559946078, 0.05029995798043186, 0.029909937988005342, 0.008203501234792413, 0.036397710622799014, 0.02229973163095213, 0.06998354914568125, 0.06253524398010585, 0.023033458086091186, 0.012867314282864814, 0.07937117524805569, 0.050256762112821304, 0.034936083811185056, 0.04549994599074126, 0.039104333733238524, 0.03865432985607655, 0.026995551832500967, 0.04064185304507133, 0.012658884741305824, 0.06965937904052197, 0.48091917148520874, 7.864890540799788, 13.460271223898857, 15.567338082098193, 31.048654663947325, 24.447797921396074, 16.243852799938573, 7.694715078799956, 0.8969150880171407, 0.13868992246927755, 0.054273587095761494, 0.12634434662158453, 0.36530513496648886, 1.3852672735529563, 1.679043974126539, 2.2782072232615564, 2.597363129738839, 1.4259887078116018, 0.49061284971333324, 0.24820016877305126, 2.845399355696094, 26.979552545855125, 48.170781058649865, 56.19676236183413, 55.63321582732662, 55.487554688607496, 53.0984115600586, 52.79037998568628, 52.94085387260684, 49.84064386736963, 49.88231120571014, 44.71090147572179, 45.623440896311116, 47.62449687527072, 46.85394725491924, 44.21196814506285, 41.09521358243881, 40.51294557509884, 42.30191115410098, 45.45400234960741, 48.61528365842758, 51.33335282725673, 51.08409796991656, 53.81793898920859, 49.56923154092605, 50.0882827081988, 54.4770658400751, 52.22326017195179, 51.31609439849854, 46.770020300342196, 41.4800843884868, 39.22205825005808, 38.23650783108127, 37.955167985731556, 42.869799752389234, 49.39890261619322, 53.340994465735655, 53.48800882216423, 51.882386592126664, 49.04380259975311, 38.863530082087365, 48.32157657992456, 47.88194948627103, 50.27227717061197, 48.013019407949145, 49.1190375820283, 47.15524019733552, 52.13083344121134, 50.042147790232015, 43.59262981722432, 36.396865229452814, 36.76798812804684, 35.79684849708311, 37.43131583736789, 36.52530716311547, 38.25205610644433, 45.469228990616344, 49.67754779323455, 51.08941278150005, 50.22842899445565, 50.455510693211714, 48.57481264298963, 49.43968349887479, 51.12470234594038, 50.36759076579925, 48.16655274360411, 46.46481675486411, 41.4577974811677, 41.45613831858481, 43.27969920250678, 47.725897988965436, 48.27102507314375, 50.64977392073601, 48.7726491497409, 49.06003336752615, 49.34123200754966, 50.98412459896457, 50.74786847637546, 42.05526859529557, 26.42896748358204, 12.07263961915047, 2.364764862483548, 0.5385899027028392, 1.8415621115315346, 4.0812766648107965, 2.9913889929171535, 3.346460081877247, 8.288635957625605, 9.311269444804038, 4.79523628950119, 1.8149580229674618, 1.3752811642423755, 0.25584462309075945, 0.06906385293170329, 1.2271708730728397, 7.132984111385961, 26.683190022745443, 33.9077801089133, 19.913639983823224, 32.5616148210341, 18.418020625268262, 1.4634967403065775, 0.05449516653654076, 0.0736664938590219, 0.025646557182734533, 0.12625116734735428, 0.012291461311941667, 0.048705211900655306, 0.033529511908249515, 0.037499532749455784, 0.037916510576202024, 0.04627870500928933, 0.039434165228158236, 0.013666740438390165, 0.027582189406178174, 0.01655521941551518, 0.03494518493572551, 0.010046604401131552, 0.044825853734848, 0.06369262280303144, 0.08649692675399204, 0.026878642984816146, 0.033998503274614775, 0.06665380926983011, 0.11137350237057095, 0.06546802007623258, 0.012741803225400227, 0.08326732989160285, 0.04855675172180899, 0.030389528180803024, 0.07850820018399148, 0.007837765592886436, 0.01709682634100318, 0.010520856876316811, 0.0687557170467992, 0.015264490540439804, 0.0165494775865227, 0.015235776607427868, 0.048430814527936523, 0.03313910967159656, 0.005373625589850089, 0.003715582213537287, 0.03470721887424588, 0.01937909611320544, 0.09031504002069274, 0.05466669362278716, 0.07829823080570468, 0.018910053035905285, 0.00904434114589446, 0.05516250189694186, 0.03924175841553558, 0.03933954953906998, 0.017791568496895414, 0.08771719756506144, 0.0893675348150634, 0.06843953723869017, 1.5858949144040386, 15.677243874919032, 20.778020543436853, 28.567612363446145, 43.74790860760597, 23.25049246511152, 19.512106949283233, 9.308102130889893, 0.46250508377148264, 0.05530252361730222, 0.12159274755826882, 0.714148388754937, 0.2350367710835511, 1.0635378019463633, 1.3224725785755342, 2.919690517648574, 3.883342589101484, 3.378663721584505, 2.5018534160429433, 0.793672850535762, 4.898391683255473, 32.070781184780984, 51.61051142600275, 58.56483059544718, 56.599515253497714, 56.98718663184874, 54.80738432176652, 54.31289111414264, 53.49522990565146, 53.413091551872995, 51.80007565406061, 46.1599152318893, 46.10279375506986, 47.22871011303317, 47.217672563368275, 45.94620881542083, 43.1150734040045, 42.827916683689246, 44.85746083721038, 48.03523571260514, 51.4172758594636, 53.45874009593841, 54.160432507914884, 56.052258322315836, 50.20098417035995, 51.50501143547797, 55.698625272320164, 54.841893334542554, 52.90551723972444, 47.10359434927664, 44.02247451966809, 40.13324053056779, 39.661285261954035, 41.2891669427195, 44.2207032634366, 52.19152819725775, 54.42024246338875, 53.811623973231164, 52.7204558926244, 49.464641540281235, 40.96575967727169, 48.773672888355875, 49.453596145876, 52.458233679494555, 49.407445538428526, 50.17166053095172, 48.71026385215021, 53.96450619543753, 52.00669434762771, 46.06333078876619, 38.14569319448164, 38.73143249942411, 37.145037727971236, 38.73451940474972, 38.2161428851466, 38.82477706478488, 48.743851107935754, 51.953412871206964, 52.27254083079677, 51.74806110320553, 51.399456531770774, 49.98123730382612, 51.19139440598027, 51.485462342539144, 52.29039545982115, 49.726357767658854, 48.27781077354185, 43.692693402690274, 42.758655471186486, 45.23960951835879, 48.47541586045296, 50.49923335352252, 51.460786711785104, 50.642297883187574, 51.156744187878026, 50.364390111738636, 53.07817997470979, 51.29417619397564, 46.47539146484868, 29.188262724107314, 15.31489041543776, 3.5576905021744394, 1.5495200791666586, 3.085677133452508, 5.872768740500174, 5.469590761969167, 6.952305032360939, 10.296077555225743, 8.289209604263306, 5.821512187680891, 3.6029752464063707, 1.2227863986645977, 0.2632646749336874, 0.06090178364707578, 1.0280335490261356, 6.41408916442625, 28.06054403704982, 32.313075796250374, 23.568390761652303, 37.091913146357385, 24.013864148047663, 3.037368977262128, 0.010194046640648477, 0.08108626224941785, 0.05928295176295985, 0.0497263036818514, 0.05777527923665701, 0.11104948548299652, 0.06503109715037769, 0.06760420262693398, 0.04947216550429021, 0.00471992276406156, 0.0428594094550898, 0.03760936677515988, 0.04823378437469083, 0.020744027307016716, 0.020640398593499296, 0.01667411051570408, 0.04561630708556022, 0.05177812463033104, 0.01707687932667473, 0.03924237511631462, 0.07527591435298805, 0.004762866301462054, 0.07223436143249273, 0.020180782228107416, 0.1415393558601218, 0.22508974757886704, 0.17308131010541994, 0.0626864314319626, 0.2770336038402973, 0.15008327400972768, 0.08623143898383265, 0.13579807845094513, 0.24425699165271175, 0.25186429070609234, 0.17480200487038783, 0.13373949294609408, 0.07357165983487522, 0.22583844530726635, 0.10805498568281051, 0.2670052677633301, 0.10607163767300307, 0.11724162861824998, 0.16488121221623114, 0.18010607590117764, 0.23919459071851548, 0.13043766931420372, 0.17552228073679632, 0.19959401970188465, 0.13312043261624154, 0.3547958488906584, 0.1204136539731295, 0.1685686538656873, 0.1454202347104588, 0.17731034527382544, 2.2673236266259225, 23.327598417958907, 32.211486408787394, 36.08966127518685, 51.10944432597007, 35.92128961317001, 24.234118961518814, 11.234123168453094, 1.2756483040509687, 0.3136261306222408, 0.33562713392799903, 0.7374696986329171, 0.5654588125405774, 1.7406167282212166, 1.7383546237984013, 5.340384946715448, 7.922210587609199, 3.864270554434869, 2.63621298055495, 0.6149026174699107, 4.598854491787573, 30.10990792705167, 50.61937555190056, 60.22333814251808, 59.55819045343707, 57.53222350151309, 57.19322089226016, 57.99949546014109, 56.80527494799707, 54.35152646033995, 54.94670691028718, 48.62201444564327, 50.06869046918808, 49.189459816102065, 51.46448158448743, 48.414258264726215, 46.43497536259313, 44.19309762216384, 48.030976018598004, 48.7331901058074, 53.6980321330409, 56.26563918206, 55.39390417837328, 56.5016560400686, 49.92416681781892, 53.42595300366802, 58.1693733123041, 55.085849069779925, 56.74741214321506, 49.27499102007959, 46.1126781279041, 43.1730931035934, 42.04297588717553, 41.87642420491865, 47.27597075123941, 53.68444504276399, 57.129078372832275, 57.034106023849986, 54.83997529552829, 50.72160428570163, 43.62256534637944, 48.53597333354335, 50.36994418790264, 52.25731811215801, 52.97513931028305, 52.130727537216686, 49.71479854276104, 56.482934567236136, 53.00811075395154, 48.25490020936536, 39.8615026473999, 42.085894461601015, 37.679205709888095, 40.375799902023815, 39.93314081622709, 42.02733739729851, 49.27013904817643, 53.11272428881738, 54.628347735251154, 52.902744124012614, 52.7829941626518, 49.9689132167447, 52.990793489640765, 53.756600964453916, 53.66581378444549, 49.72489864595475, 51.17850941996421, 45.793985551403416, 44.753416046019524, 46.46176122849988, 51.8145295881456, 51.06652967391476, 54.62368403711627, 52.75991885892807, 53.038838601881466, 51.24535445244082, 54.35399755354851, 52.73810655839982, 47.009402551958644, 30.065314500562607, 14.242679149873796, 3.4787096563846838, 2.0177634372826545, 4.921784208666894, 9.865500350152294, 9.162513556018952, 10.522791531778152, 17.125556507418235, 17.997642563235377, 13.408513588290061, 7.17572323737606, 3.960232811589395, 0.902994332774993, 0.3227086239043744, 1.8320009665143107, 9.709639087800058, 31.717616858020907, 41.68250222359934, 30.46167196766023, 43.83165905552526, 24.953103142399943, 2.9267480873292495, 0.19527729810966601, 0.15623701315733696, 0.11301191163159187, 0.19107645497687403, 0.12360264817553183, 0.11465188371197832, 0.12616690533656266, 0.15746454648192854, 0.08797352292364644, 0.09649994362506176, 0.15808834123515314, 0.11591309426172126, 0.07909963538329448, 0.14279109756312064, 0.08382426049079626, 0.0822566990410128, 0.1899815161502169, 0.12151353406689822, 0.16577215715041085, 0.117472650092696, 0.08954945005356305, 0.16242882687478297, 0.19602873843283425, 0.20591806019506148], [0.015610487448171744, 0.026651635811093356, 0.07838391007915621, 0.061917604743352825, 0.07391535752122441, 0.11584887311102883, 0.08110371373233297, 0.03729026434161971, 0.008493922294057425, 0.04148744940457325, 0.0032163045186955003, 0.036078504767389066, 0.03402998182742346, 0.021897822753676487, 0.03099086315130755, 0.03214019230536876, 0.014471956303403264, 0.07554815135776036, 0.02161246266276125, 0.0027686108754301866, 0.027530535927883563, 0.01793626143837408, 0.03751742856336698, 0.03344329637325099, 0.04635935491551796, 0.020633480819543044, 0.05442270611022269, 0.06051086047063432, 0.034856456632335345, 0.03212100180286554, 0.19454940732929016, 4.138458938367905, 11.801491072100978, 10.713671715028825, 18.99703306536521, 33.561940808450025, 16.1642228018853, 8.623106268144424, 1.9451615911337639, 0.1659723665685423, 0.2399653058138586, 0.47552502383628203, 1.1707591001064548, 1.0052318306219195, 1.8385830713856606, 4.620744259126725, 1.7681984675507394, 3.2732708607950523, 3.2650284901742017, 0.14509173620852733, 0.12745872875975986, 2.489517071554738, 22.978393723887784, 45.97831733765141, 54.13087352629631, 54.32159877592518, 52.909498445449344, 54.94397301827708, 52.16102000205748, 51.851023320228826, 48.37870197911417, 54.520843413568315, 55.59282325929212, 51.823731468569854, 54.270733479530584, 54.4134489182503, 49.74822105899934, 40.77922351898686, 40.75133938943186, 42.90384200311477, 46.578479197717485, 52.67918863604146, 53.188433877883426, 52.89989256089734, 50.57559797840734, 51.59821479551254, 53.2141528591033, 52.69243448011337, 50.13905779007943, 44.0015604419093, 40.67046011647871, 38.74275245974141, 40.21857953840687, 37.718162690439534, 42.5787010500508, 47.58500645237584, 52.13998825319352, 52.418998210660874, 53.71676929535405, 51.1130960526005, 39.06052720162177, 52.29032485715805, 47.165775683618364, 47.411068947084495, 50.709970535770545, 52.06784017624394, 52.38380670547486, 51.53786128567111, 50.68207071673486, 40.18145038235573, 36.29653100044497, 36.47162952730733, 37.49879237144224, 38.40311050415039, 35.52383584360923, 39.555279285677024, 48.53007801117436, 50.371983820392245, 50.66706372845558, 48.37433245874221, 49.73208442811043, 48.64554082193683, 46.76563116811937, 47.994156729790475, 49.08643876352618, 47.85733269106957, 43.81252181145453, 41.63668109524635, 40.36411516128048, 44.88643538567328, 46.61746363486014, 48.67835144842825, 45.721429547955914, 47.48173044573876, 46.99418767806023, 47.40414204136018, 50.0621989465529, 50.94825060136857, 39.198504417173325, 19.72420323279596, 6.6959727483411, 1.0361800054388663, 1.3315232026000179, 2.6736392561466467, 6.376847240232653, 4.55640709207904, 5.727959736700981, 8.848132644930194, 7.094491441403666, 3.997728954399786, 1.5410744807412549, 0.803125333641806, 0.038952996894236536, 0.25084056741287636, 3.6678588486486867, 16.909129927235266, 27.905424102660152, 42.07151897491948, 30.73206447785901, 27.11582353038173, 10.09655442930037, 0.2774732157347664, 0.028852646637167183, 0.048226257560834776, 0.01638709950531202, 0.046074661321096846, 0.01830093461209007, 0.025973261123703375, 0.023759305326929017, 0.06831172312940322, 0.02017252380028367, 0.05686548087866076, 0.01399273479041914, 0.08791761382693246, 0.048091226903301094, 0.026989233522345463, 0.044131785736329136, 0.057513081814132394, 0.10612092777005128, 0.040167024088723045, 0.065936038510934, 0.023842862536830288, 0.001277014225413422, 0.06275534104075163, 0.025872999366613168, 0.04621951705625942, 0.0417743876366125, 0.04350252494576477, 0.08180726589935441, 0.0726891418678626, 0.036343111536435546, 0.06409160139399671, 0.0520717584708285, 0.022070753696044127, 0.0243869056219175, 0.03449890424587554, 0.017812300751346256, 0.018995877866062428, 0.028668134360604232, 0.048411175863997596, 0.045694811945600856, 0.11554944764582381, 0.01820817094055876, 0.0518155058905963, 0.0482535915779731, 0.035750393139859366, 0.028354528607920777, 0.08962882442339774, 0.01569630557505955, 0.013309194755199696, 0.0017972172528032155, 0.01702632518455146, 0.03628447516671112, 0.06143250254793994, 0.027218697923085382, 0.01754715197509335, 0.2134424685350349, 5.958983907776495, 19.904598920576035, 18.873507822713545, 36.514226467378684, 39.020060108553984, 19.914465642744496, 13.959303594404652, 2.6759921879537645, 0.20544601213787833, 0.19788929020925877, 0.6641270761047641, 1.590614138591674, 2.8077580851893273, 3.164882289786493, 4.951654038121624, 4.990984134135708, 4.513235524777444, 4.977071977430775, 2.427679680047497, 0.9723768936049555, 4.182800352573395, 28.407124665475664, 49.93374132340955, 56.83756389925557, 54.628649757754424, 55.08300535140499, 55.892398203572924, 53.882238403443374, 52.87550718553605, 51.27602346481816, 56.025127287833925, 57.22974600330476, 54.34474075994184, 55.99514861260691, 56.41276728722357, 49.53651505131876, 42.8259672657136, 41.918864250183105, 45.55059071510069, 48.61540132953275, 53.31944888637912, 53.43490777477142, 53.90696894737982, 50.08011241112986, 53.91944208452779, 54.372636656607355, 53.602534186455514, 52.62054920196534, 46.15569868395406, 42.76604521659113, 39.069623178051366, 41.473588943481445, 39.61966891442576, 44.77488317797261, 49.92122896255986, 54.099612236022956, 53.93412351608277, 53.51822676197175, 50.553118874949796, 41.391862438571074, 51.70387560321439, 47.556082894725186, 50.92877211109285, 51.482155784483886, 54.929197449837964, 53.54065879698723, 53.46736538794733, 52.808732755722545, 42.523274037145804, 36.196369355724705, 38.905479831080285, 39.892301097992934, 38.93834537075412, 36.96503623839348, 40.50294745352961, 49.25716777001658, 50.95384390123429, 50.58616092128139, 49.08968648602886, 50.26321649551392, 49.014549563007975, 49.83779230425435, 49.01779728551065, 50.14689860805389, 49.8244248667071, 46.47330084154683, 42.01006327905963, 42.57979931369905, 45.47917219900316, 48.714107774919086, 50.760710316319624, 46.98395421428066, 49.26579698439568, 48.80480866278372, 49.845484072162265, 50.7628950765056, 50.74156522750855, 40.98451645143571, 20.396579850104548, 8.333850099194436, 1.811244151284618, 2.220751609533064, 3.7014679226183125, 6.0145550677853254, 7.471977405009731, 6.960737147638875, 10.090089382663852, 7.188269428668484, 7.556250999050756, 2.2213975748708172, 0.3198518513912155, 0.025729484285318086, 0.3409125890222288, 3.339699631737125, 17.183493837233513, 33.66219659005442, 44.03045262059858, 29.581572509581047, 33.574386489006784, 13.623740903792845, 0.5758063927773507, 0.0037321534135469027, 0.02665224868143278, 0.007365282780806264, 0.03468637745226583, 0.006980235019939081, 0.047101583031396714, 0.04677097778767348, 0.020799049656958352, 0.029828964409628705, 0.033290691658734314, 0.05828039930953134, 0.04996931443231241, 0.02961466854978954, 0.10098188739990997, 0.027152527078625657, 0.06159989275939523, 0.02927901287142548, 0.022717962011454568, 0.06340741976014068, 0.04219310831338648, 0.04136214806367794, 0.022063830176428444, 0.03305841380009248, 0.07415498982393935, 0.09303508116112602, 0.16205537433345474, 0.17667420118326144, 0.1504734885548392, 0.12512005384891264, 0.1480391062796116, 0.22594611130414471, 0.10549780717420001, 0.16592488443899542, 0.16394509873803587, 0.09807777065303057, 0.12464830456601998, 0.10706680120840188, 0.23610641368694846, 0.2191995733207272, 0.14744949436956836, 0.16107936299616293, 0.17292276054861086, 0.14863742094847465, 0.13245775123998044, 0.10633766170470946, 0.11209360969763611, 0.22666499289053105, 0.09111207789711415, 0.10210317965116232, 0.1417153722216045, 0.08592184753187242, 0.1670547568749997, 0.10306601427615651, 0.07426559759844696, 0.36280563521769743, 8.940912388986158, 31.627012068225493, 28.993950466955866, 44.60231065750123, 50.113742812987304, 25.78125669110206, 14.30975462159803, 3.0165831119783464, 0.2737852991107972, 0.6812210717508871, 4.2605520256104015, 4.38254117004333, 2.4191806393284954, 4.216169916814374, 5.620749102484796, 6.227973680342398, 6.83641811532359, 9.367045548654373, 1.6945774180273858, 0.5109212583591861, 3.3743388181732548, 27.36129918406087, 50.06331289968183, 56.476195935280096, 57.37605825547249, 57.7648945777647, 59.322295188903816, 56.42676622636857, 56.022683651216575, 53.66710032186201, 58.920432675269346, 60.23849810323408, 55.65069783118464, 58.303812549960234, 59.225777426073634, 54.19239590244909, 45.15703185912102, 45.654749255026545, 48.52576340398481, 51.111978177101385, 56.61738557200278, 56.424722671508796, 53.276632293578125, 50.48039028721471, 55.25991209091679, 56.33058970974338, 56.102362678897, 55.04004363090762, 47.72392503676876, 42.89098839606009, 40.968336674474905, 43.10729926632297, 41.759498350081905, 47.09177624794745, 51.545698181275405, 56.47191270705193, 55.95315179517193, 55.47353221524147, 51.86896816376717, 46.921827793121345, 52.00697675828011, 49.497907161712654, 53.22135825310984, 54.7145418197878, 56.11806000432661, 55.24549345816336, 55.52449949326054, 57.1706162729571, 43.72910868737006, 38.20815693947577, 38.99074431388609, 41.91052529119676, 41.49447556464903, 38.71258551074613, 43.02639253677861, 53.0265498161316, 53.47557098634782, 52.317212704689275, 47.98720628984513, 51.42109232564127, 50.686903076787154, 50.68046254496421, 52.775310239484234, 52.12582457450129, 52.59081371368901, 46.70392836293867, 44.29952329204929, 43.965462869213475, 47.7358490420926, 50.54386208134313, 51.91831550290508, 48.24378028992684, 51.22667220331008, 49.840400680418945, 51.19288882901592, 51.64913108271938, 53.09826250999205, 41.263840198516846, 22.17802232311618, 8.495298777857135, 2.037646421982396, 3.6057733672280468, 7.488921063561594, 12.00072100085597, 10.739797642154079, 12.620227010019365, 15.513043653580452, 17.186604276780162, 13.435979004829163, 5.786096617098778, 1.3758495401951576, 0.37167399160323605, 0.593111889977609, 5.269329249858856, 20.75171124550604, 37.2953547200849, 50.34189924117058, 40.81627422763456, 37.58846559832173, 14.13063076234633, 0.7398022218577324, 0.06978824269026518, 0.2597406091949632, 0.08544334135348759, 0.13421771567194693, 0.1056953352845965, 0.10254574098413992, 0.1790725926478063, 0.20026235480702695, 0.1563613185839307, 0.11152318829009611, 0.17447244916712085, 0.18404873208172862, 0.09855996171433119, 0.17490643797622574, 0.15226325380706018, 0.14718415215611458, 0.15798596124495232, 0.15324669619721754, 0.14588532668928947, 0.12622876693644833, 0.09926637138931022, 0.19742680292937065, 0.15471982198857492, 0.14071127610100856], [0.02828635635875887, 0.04960342317879681, 0.04129021623802762, 0.02488754216521498, 0.03908190267881559, 0.02359386863968065, 0.06124501785023078, 0.03388882629693516, 0.02105068847266657, 0.05399521755715532, 0.06885022165313845, 0.13669432471356086, 0.01540056978081984, 0.018578901954535997, 0.1357539364647481, 0.04578775756301419, 0.0305730426278446, 0.043852860783977855, 0.017708731409642967, 0.02869281962874436, 0.05562663626586718, 0.04042257569850453, 0.04250530446428926, 0.025354784935893073, 0.014071712709753024, 0.0162834707917946, 0.03479464865860439, 0.02553628074125417, 0.027772242413653482, 0.03393299126576993, 0.04546681651845575, 1.8423796805643269, 14.768223800966817, 17.707359713892785, 13.038009443590719, 26.863754372442923, 23.14704191300177, 10.667545622394933, 6.031238869313271, 0.3110030455695045, 0.20320569525562948, 0.17486373623532636, 1.0399925492463573, 3.6236265253636146, 2.1202881874576693, 2.2241505884355117, 3.3160497007831453, 4.726541859488334, 2.9597992041418633, 3.0066416196284758, 0.18233618849227506, 0.028554764839129585, 2.2992286759038127, 19.018286428143902, 39.23497069266535, 53.62293443372173, 57.91740025243452, 55.08546467750303, 52.06704393509896, 54.740821699942316, 50.726303285168065, 54.2304507378609, 55.82483929972495, 55.14747734992735, 55.2792925219382, 55.62600258857974, 54.66754005801294, 42.965874287389944, 40.15721797943115, 40.58254803380659, 45.94692660916237, 51.079940257533906, 52.64756256534208, 54.218067815226895, 51.83540051983249, 51.889780259901485, 54.53122592741444, 50.98911777619393, 48.727518358538234, 41.47606788143035, 42.51833969546903, 39.7780659890944, 40.52044906923848, 40.27716798167075, 39.933631112498624, 46.82537278821392, 51.344417833512836, 51.21376760544316, 54.795468161183024, 51.41689931192706, 39.90069889253186, 50.463853574568226, 51.291720790247766, 53.84699198507494, 50.71413217052337, 49.37923585214923, 50.30449551920737, 48.274233571944706, 43.23000669479371, 35.76575194635699, 38.15373013096471, 38.62108053699617, 38.242862070760424, 37.80613753103441, 35.96391793220274, 38.09149388344058, 48.81367714174333, 49.908720524080344, 51.54239162322014, 52.108177831096036, 50.687075661074736, 48.34361245555263, 48.2211168350712, 48.43305818496212, 48.16772553228563, 44.203503670230994, 42.80892456731489, 41.52917285119334, 39.50313529660625, 43.8272189324902, 44.07345356479768, 44.36416003011888, 44.64268753605504, 45.20620269160117, 47.60711685303719, 48.968889251832046, 51.29891833951397, 45.757566344353464, 30.12489922585026, 11.574377013790993, 4.210727137904014, 1.3786552606090423, 1.9802167939562954, 2.1236886372489314, 3.386663885847215, 6.206520276684915, 5.722288479728084, 11.256275734593792, 4.819953595438312, 4.024365034795577, 1.3821444540254533, 0.3550957569912557, 0.18150125990711874, 2.101261995492443, 9.663832668335209, 25.14137298830094, 27.115723509942335, 29.809938784568544, 38.42720562411893, 23.61581810059086, 3.7254931753681557, 0.05372681865288366, 0.06418636263979059, 0.10156112647945843, 0.05446148931138939, 0.03920630386639987, 0.02832479482035964, 0.0679130050083322, 0.00897290057412559, 0.04172803165631429, 0.05512339310840734, 0.00965745854867442, 0.02892351360060275, 0.07617273518154699, 0.06476799957454205, 0.018029193649248734, 0.0668495677171215, 0.039885647655014074, 0.035251390279060414, 0.04099639470598871, 0.004066736090012015, 0.016228643794273658, 0.016887358750306794, 0.05242917679190155, 0.03737738386036889, 0.03624637761423665, 0.07493414720820804, 0.052743652054379066, 0.11044622188614261, 0.003104210294212305, 0.08224687013294428, 0.05491172684536827, 0.05231023398077777, 0.049975841501427275, 0.028095006747471712, 0.05996351363137365, 0.044024541087809115, 0.12555535266836806, 0.011719549863388943, 0.028048683325910283, 0.030070586625726956, 0.02777337813900123, 0.041006058905153506, 0.03961691167205572, 0.060108066761806134, 0.04047497228208569, 0.03507860297817857, 0.03304139132641497, 0.04407806765107859, 0.03747608279809356, 0.02233542749778398, 0.049878215086796594, 0.03227080263557934, 0.03511223806849411, 0.07372331460036578, 0.04748316376560158, 0.04039959306077611, 2.414227911541539, 17.989384012837565, 24.189337261261482, 22.41483542226976, 39.431501050149244, 24.7805247383733, 13.99330956320609, 7.090462186644155, 0.4810834207361745, 0.2112094448098252, 0.10750064446080117, 0.9952495823944769, 3.8430654858389213, 5.15709602063702, 6.900505721569062, 7.7212303011648125, 5.564616062948781, 5.584685850527979, 4.227154514481945, 2.861794617868239, 0.506906375409134, 3.4991564817966956, 23.855380781235237, 43.06262347006029, 56.61755031155002, 59.061579165920136, 56.761320867846095, 54.01555192086005, 56.6160519661442, 52.06412961406093, 55.41668138196392, 57.06500645606749, 55.73449926991617, 56.71689610327444, 57.39803137317781, 56.75244062177597, 45.320488791311945, 42.387473737039876, 43.02813406913511, 48.36573462332449, 52.457253086951475, 54.10784529101465, 56.97796121720345, 51.186640493331424, 52.461567694141024, 56.27649630269697, 52.91982996848322, 50.998554998828524, 43.156850568709835, 43.94219144698113, 40.795120885295255, 42.39442417698522, 40.756932689297585, 42.92029634598763, 49.56785871136574, 53.043937683105476, 52.727527926045084, 55.750428015185946, 53.39361698396745, 43.661989088981386, 51.954248336053666, 52.56906417108352, 54.50129824299967, 53.25138399677893, 51.271591186523445, 51.95125164524202, 49.046375674586145, 45.68410819576633, 37.71542487605926, 38.9068801172318, 40.319980652101584, 40.34597812160369, 38.73642959902364, 38.82798556358584, 40.00552423538701, 50.30728040202972, 52.18589567369031, 51.68940597964872, 50.38612788723361, 49.71032311839443, 49.25082921981812, 50.98590143265263, 51.27832197373914, 50.02794881020823, 46.142295945075254, 45.065687702548125, 42.78384101006293, 42.040128246430434, 45.17721637602776, 46.28907888166366, 46.44399681398946, 47.00335033478276, 45.68882680708363, 48.36654263157999, 48.59452255310551, 52.02772609649166, 48.03846382325696, 33.339679702635735, 15.438085198402407, 5.2580514550209045, 1.830051303390534, 3.7466266607084586, 5.020300909396141, 6.12286739772366, 6.201921787954146, 9.001232558681119, 10.056733546718474, 5.640611494741132, 4.069223711567541, 0.5673242672797173, 0.08845924565027799, 0.1686862483620644, 1.8946284704631375, 9.3717739658971, 26.894395928229056, 33.10779702278876, 38.913881547989384, 42.43048252597932, 27.74007658804617, 5.905230766342533, 0.1236361108960644, 0.0353778675649195, 0.06481493778166271, 0.04963002558196745, 0.012553113854430135, 0.036482332694915034, 0.006089743035244606, 0.05640457557033628, 0.04607391438537067, 0.02667513938861028, 0.009195308347472982, 0.015323645934732932, 0.05935320585605599, 0.06113748591873915, 0.023309266975810452, 0.0534571863470539, 0.04482795281576053, 0.11135138541219697, 0.016024516794019412, 0.021301494167757132, 0.07467293420866614, 0.07360427219781183, 0.04571367686073627, 0.030758211824802623, 0.055621377072267, 0.18071997279842056, 0.10316760519579535, 0.1375182522761245, 0.08816511385262975, 0.15681378543376923, 0.09982214519573797, 0.15173900451871658, 0.16069756009646002, 0.12500064372415506, 0.1368574861196741, 0.1266433890428274, 0.25797054772415473, 0.15180107296234177, 0.10148195895336329, 0.2939335034499246, 0.1103966253539247, 0.19830106246855952, 0.1706259216993086, 0.09704653203727738, 0.23599825739379854, 0.20815368861921374, 0.08332122417707598, 0.10280663988763288, 0.1494007509562277, 0.16558379145158877, 0.09070741493375072, 0.06328658471184392, 0.0991853652521968, 0.13726392640702187, 0.11819035190367892, 0.2113931220505507, 2.6154388823816856, 24.008702308900897, 38.08885412831461, 32.326066686261086, 46.27316582587458, 34.774882793426514, 17.709799428139966, 9.541891082640618, 0.7083301654746457, 0.5785991816270737, 0.5876569762345284, 4.577740863446267, 9.540387834272078, 12.131369267740558, 11.681904869694865, 9.428609109693959, 11.012698508078053, 10.066555161629955, 8.31590231387846, 2.170823024165246, 0.22005696360382343, 3.1206796294258488, 21.4596402260565, 41.764777860333844, 57.37052771352953, 61.115096845934474, 59.953467307552216, 54.69409058170935, 57.81550099772792, 53.39422495134416, 57.83090806776478, 59.60501178618401, 58.63796710968018, 57.80868784073861, 60.03689219874721, 58.48031528534428, 46.840709255587676, 43.727292629980276, 44.437033745550345, 51.778392791748054, 54.727540554538855, 56.33267248830488, 57.7769519436744, 52.539489499984256, 53.1232480079897, 58.30313005755025, 56.05805950780069, 53.025973227716264, 44.82132404081283, 46.53726293194679, 43.48074813042918, 43.21140289306641, 42.93008658193773, 43.88816864259782, 51.72959850680444, 55.98065153245003, 56.0474181175232, 57.61672704450546, 54.28330467593286, 47.486896207255704, 52.052590001013975, 55.8934219421879, 55.1810920623041, 55.78889077709567, 55.08284453422793, 54.62232689703665, 51.31649448025612, 45.82599601437969, 39.44468021392822, 41.923104332339385, 43.98011684417725, 41.567133549721014, 40.959597633730986, 40.42402152092227, 40.81195962044501, 51.70362849389353, 54.19133686250257, 54.32441896007907, 50.142254521769864, 50.431639148342995, 51.43357722989975, 52.269665733460464, 51.370827151883034, 52.15255160485545, 46.11435297996768, 45.98504028012676, 45.08620169854934, 43.96748288985222, 48.399055157938314, 47.72212859122984, 50.00541479356828, 49.19286051104146, 46.99214804557062, 51.39388676612608, 51.74154604634931, 55.12201724513885, 49.57065143892842, 33.18012160639609, 13.889283403273552, 5.73654874678581, 2.600163211745601, 6.3804587625688125, 8.065780612730212, 9.346957129816856, 12.047613916858552, 14.070455720347745, 21.497228299417806, 10.77671597080846, 8.849856526620927, 3.085061811631726, 1.2554901405688257, 0.5385361539740716, 3.0530550258774913, 12.75093803482671, 31.8484632045992, 37.076560989502944, 42.18351833281979, 48.5110584382088, 32.29905332288435, 6.148702579159891, 0.35820932217663337, 0.11328936569512853, 0.24199801286862743, 0.1439766799129786, 0.10151565916115239, 0.11777698618149567, 0.19580085791887777, 0.11484594144407781, 0.13247586155851043, 0.1282232538646748, 0.11443023149284626, 0.08724284358322622, 0.15989247829683367, 0.16745635548666601, 0.08541147975671677, 0.16526027252116512, 0.11683544113991723, 0.18091183185817736, 0.152543458126245, 0.12593649673245608, 0.16973630975811713, 0.16368853589219434, 0.09268933035913976, 0.13436108136609679, 0.16731780082468065], [0.06745673070151, 0.03271631340706541, 0.019255380574313384, 0.03452353014220153, 0.03670740549662902, 0.05253893803925284, 0.019386716772832217, 0.09966620799875069, 0.08196155600730451, 0.0379369804455388, 0.012125063184348327, 0.025237533263862136, 0.021553998662819786, 0.03561897458688867, 0.06834811230580654, 0.011442260508756004, 0.03034954796725464, 0.010102842915652981, 0.03863780916998944, 0.09329071704057917, 0.012160337702821822, 0.026254097465425733, 0.06932478247871322, 0.06311817177300973, 0.06396941803095323, 0.009020436329827195, 0.03875115570882636, 0.08943038466837137, 0.09771412403713312, 0.10289882324756154, 0.038723227973546714, 0.09038952674957053, 7.319330525013709, 16.348963495223753, 14.373557856006009, 20.826446125584265, 34.09659516426825, 17.18829481832443, 8.405351965658127, 3.681783998204816, 0.2734921632274505, 0.12215533954722267, 0.7235865919820724, 3.205190036566027, 3.15097184911851, 6.9416489331952995, 8.113789933343089, 3.532738099175115, 3.521754482100087, 2.8869534355978814, 3.8944948680939215, 1.5045268160681573, 0.1344788137583002, 1.5280514763247584, 15.01637843347365, 33.380935192108154, 44.4954849058582, 54.08092214215187, 55.01089257578696, 53.38735295880226, 55.69686805048297, 54.250282241452126, 57.0673284992095, 55.97560736440844, 53.88262671809043, 54.68677928370815, 53.25136438492806, 48.57769558506627, 41.450019421116004, 43.271697567355254, 45.11977718722436, 54.044114620454856, 52.32135472759124, 53.94100727573518, 51.355310255481356, 54.771220068777765, 53.793114308388006, 50.98139070695447, 46.3547589701991, 42.275392009365945, 39.585763946656265, 39.45283482151647, 38.698492434717, 41.46470085267098, 40.12194410447152, 44.149912326566636, 50.60887928931944, 52.39069046512727, 52.48727883062055, 54.25708363133093, 38.08446499609178, 50.6935279600082, 50.877808755443944, 50.150632704457934, 50.75155550433744, 48.646344907822154, 42.127557877571356, 39.6102552260122, 36.40956978644095, 35.61146551562894, 37.68758389257616, 37.19383201291485, 36.79835119555074, 37.10600622238652, 36.24560686849779, 38.47155194128714, 46.520628160045995, 50.857337905514626, 52.310081835716005, 48.48805765951834, 44.58949627414827, 54.141801249596384, 51.85124689532865, 47.28728286681637, 45.749184239295225, 44.04086259103591, 40.121057648812574, 39.10264561253209, 38.54998365525277, 40.93862472041961, 41.456224610728604, 42.215968101255356, 42.64581280369913, 44.01926209849697, 46.62906208345967, 47.344055252690474, 49.628745663550596, 42.870509701390425, 22.35325028819423, 7.470430029976753, 0.9067683883251683, 1.5150195240013062, 2.0666127579827465, 4.110531907889151, 3.660482341243375, 6.7061307064948545, 4.96437918755316, 6.999512228273577, 3.596805112977182, 4.4713294121526905, 0.4698779139547579, 0.0971842899678215, 1.025536286254083, 8.748482869517419, 20.847777935766405, 30.233635171767208, 27.88433155705852, 25.859478558263472, 30.4931587942185, 13.650289466304164, 1.0535307324701741, 0.08383872423080668, 0.04179394969175901, 0.05369065164197838, 0.049177876658617496, 0.07582025812758554, 0.047787166606154174, 0.011671406983007348, 0.03697086313378908, 0.05863609393277477, 0.01845185201795351, 0.052679668390943166, 0.05957454014869948, 0.03532547481177795, 0.023073631736840454, 0.029126308565478654, 0.03248286726433904, 0.03585353921798449, 0.0574138964105758, 0.0385594115622582, 0.0308462085142251, 0.0230965128679189, 0.04489436497791641, 0.0630174963284404, 0.10514267179514132, 0.04143525583429202, 0.10056791646826653, 0.03619639037717735, 0.050951213155302315, 0.07122774488262593, 0.019938031947540662, 0.018235949288693168, 0.016535643953830004, 0.05251674064164681, 0.051304417992791826, 0.04321487808239557, 0.029620398887463158, 0.07123189707917553, 0.05273237907057328, 0.05049424170846901, 0.05765829378017976, 0.032553351183812466, 0.027175703153554952, 0.03433150254310139, 0.09850507917543573, 0.07704666530292842, 0.02349472154052027, 0.019317979533826152, 0.07389311798878255, 0.03841978820761846, 0.03476552582616287, 0.009543630332055112, 0.04143044863256716, 0.0707355640347927, 0.06308042662098043, 0.06502538213446256, 0.05824652673195928, 0.15698837687171277, 9.985272865141592, 24.253973999331077, 20.167205525982766, 31.823889555469638, 38.30946783865652, 16.072656050805126, 11.845958002151983, 3.379622250795365, 0.48648611792633617, 0.09692430270895844, 0.704443586930152, 3.325779630291847, 4.6796244286721755, 7.261332398460758, 9.024652050387475, 7.613997603616408, 6.278601673341567, 6.574205708119178, 6.780768998207585, 3.2616314724568403, 0.7885063535744145, 2.463170756255427, 18.084840774536133, 37.9520026330025, 49.83447790145875, 55.25935119198215, 56.44712724993306, 55.52074578500564, 58.9528706765944, 56.386161850344756, 59.060673098410334, 57.023146921588534, 56.63126684004261, 55.27918661794355, 55.55601965996527, 49.63695126195108, 43.30474353605702, 43.50666715252785, 47.96828085376371, 55.01465412878222, 54.83908883986935, 55.5020909924661, 51.48252056490991, 54.546068176146484, 55.84777732049265, 52.82801904985982, 49.28727588345928, 44.609292476407944, 41.89957795604583, 41.13226429108651, 41.20797388015255, 42.699592421131754, 41.68389858738069, 46.15143114520658, 53.33807622232745, 53.264241526203776, 54.022722013535045, 55.2349030586981, 39.698759586580344, 52.9247211640881, 54.36970664608864, 53.31590306374335, 52.11530477769914, 50.094236866120376, 46.26940427287933, 41.04751756114345, 38.375128315341094, 37.201057018772254, 39.936749396785615, 39.58008435464675, 38.55199583115117, 37.83262529680806, 37.8258199845591, 39.748926701084265, 48.18502710711572, 52.33115673065186, 53.14526427176691, 50.116916010456706, 47.41229664894843, 53.57244960723385, 54.22113510870165, 49.261580436460434, 47.62733274890531, 46.399607350749356, 41.80014194980745, 40.54955697828724, 40.37963990242251, 42.32005603851811, 43.23942038320726, 42.495625249801144, 44.28111560883061, 45.84259548494893, 47.276378677737334, 49.208142065232806, 51.16929185005927, 43.258235992923865, 23.634525845127722, 8.711700843226525, 2.2882494714952286, 2.5401936038847897, 4.099627718810113, 4.133990868445366, 8.08875491542201, 9.447277630529097, 10.803829354624595, 9.109157554564938, 4.843409859365033, 1.3207095957571462, 0.08525885972044162, 0.24873466831782173, 0.6771853818528114, 8.81090150725457, 21.128811836242676, 35.665696205631384, 32.451855136502175, 30.67669826169168, 35.83646835819368, 18.60375662003794, 1.5415221212371704, 0.1046688923792493, 0.015277266971796993, 0.07846418077186232, 0.016962511975678708, 0.06307230991942268, 0.03349847385599729, 0.037895519767076745, 0.033132735820066546, 0.04178719662670647, 0.07496137397303697, 0.061747383837017326, 0.09724049017794671, 0.03188942491467441, 0.052119217617737676, 0.0585727614440745, 0.0962676810881784, 0.04012835580074499, 0.031961077118232366, 0.037327921393537716, 0.0032720256844655645, 0.02411267295810244, 0.03730267496599305, 0.04758843573771658, 0.035299389517956206, 0.05434103347661515, 0.16519664125817438, 0.12165036503105395, 0.167633643554103, 0.13543006513387928, 0.13460344094182217, 0.27648116251634014, 0.1069387649336169, 0.17987013614225775, 0.199819908387238, 0.2501201230071245, 0.09350270889098607, 0.14936888169857765, 0.09785487737146117, 0.16452642157673836, 0.10938439337957291, 0.15090029145921433, 0.15976397470841486, 0.10484064163099374, 0.17342663189816862, 0.24447716532214997, 0.06836466746585024, 0.15040654779201554, 0.13243515164621417, 0.13543827759642757, 0.147605316653367, 0.0655098484768983, 0.1683295578245194, 0.12584439764219907, 0.23707551491116327, 0.2305952997337426, 0.20931581335683025, 0.1643377187992296, 10.582708677937909, 32.048468782055764, 30.817987918853763, 40.2630356819399, 50.20781693920013, 26.561822083688554, 13.663857925322748, 5.191975697394341, 0.47107616739888347, 0.38126078524416496, 2.722515420567605, 9.914239721913493, 11.717892616025864, 15.850120379078774, 15.360935118890579, 11.773912887419424, 11.585095870879389, 8.809843447900588, 8.739159395617824, 3.591457206395365, 0.4463630902671045, 2.227258086204529, 16.59976866937453, 36.67564768945017, 48.2843219080279, 56.34807955834174, 58.59770005749118, 56.66680743617397, 60.018590419523186, 57.52067996609596, 59.57142060802829, 58.27214333318896, 58.220626923345755, 58.47298829786239, 58.98539104769307, 53.534230032274806, 45.347533533650065, 46.75259713203677, 49.288550653765284, 59.0114002843057, 57.35392432059012, 58.08943933056247, 51.500720362509455, 56.092466538952245, 58.64596090009136, 54.374954777379195, 51.80300174220916, 46.488174469240256, 43.92168921809043, 43.84395568601547, 43.004831267941384, 44.122420434028875, 43.60265539538476, 47.08573187551191, 55.99639592632171, 55.56322505397182, 55.699974567659446, 57.14585435005927, 43.852733950461115, 53.861108595325106, 54.08677431844897, 55.09949499560941, 54.715275303010024, 52.9223834314654, 46.55093239199731, 41.85425104633455, 39.214154674160866, 38.26456454492385, 43.413624609670336, 40.679665919273134, 40.25334742761428, 39.429590855875325, 41.20433392063264, 41.60800464691655, 50.08258350433842, 54.147237654655214, 55.116871095472774, 49.524861689536806, 47.30879706721152, 54.42493754048502, 55.92991175190095, 51.09129159681259, 49.525775601786954, 47.5218641373419, 44.41400943263885, 41.973628382528986, 42.107628314725815, 44.61321876895043, 45.73287894648891, 44.976367488984145, 46.56761423234017, 47.928264833265736, 49.307358418741536, 50.752881265455684, 54.27337323465655, 44.13977692204137, 24.64649146603, 9.385180627146076, 1.5198625479975056, 3.609993837533459, 5.906556037164504, 8.165917252340625, 9.24545011212749, 13.991110094131963, 15.198879453443713, 17.603246281223914, 11.165571904951527, 8.526172734075978, 1.2343977175412642, 0.3938884882917328, 1.725989351830175, 11.101125401835288, 26.256218456452896, 39.78075673503261, 36.12896734668363, 37.38218422858946, 39.63034168366463, 21.056236220944314, 1.7953155285889104, 0.20356420908243428, 0.15163749786874942, 0.16069979707319892, 0.12734635132214717, 0.16386727952668745, 0.13956398282560611, 0.1110739466704188, 0.11829972627662844, 0.13259449793446448, 0.22471779656987037, 0.10587060087991339, 0.13066187260612366, 0.13800416652473713, 0.12192512246509715, 0.13352851233174726, 0.2053157312254752, 0.20110589422045216, 0.13822729729356306, 0.1384771185656709, 0.1643159006151461, 0.10022156045682008, 0.2157717588688097, 0.2722910599362466, 0.12776340192724622, 0.1122260662997442], [0.056277454770620794, 0.06554420752030227, 0.027954531120016213, 0.009908004731480635, 0.043413122485001246, 0.044219744121355396, 0.06491217732189164, 0.09712203766309446, 0.004743271208773818, 0.015733338265319266, 0.09540113605438702, 0.034501248474923835, 0.054437269441663265, 0.03413014016264389, 0.05109326500866202, 0.04919283452533907, 0.09133668721563394, 0.013155371003273516, 0.020321020368306388, 0.05644067363332837, 0.012837138079527407, 0.018172249077789245, 0.020477497657280297, 0.020610534570991032, 0.07330141465870604, 0.027092643900804465, 0.042037182607718056, 0.05153771091793334, 0.07593419072368453, 0.05681885293714943, 0.04520456163933681, 0.09083495325138492, 1.1592595687796994, 12.036058614330909, 15.82143412482354, 16.145067907148793, 33.34288035669635, 27.95391440391541, 9.825752031418586, 7.441637381430596, 1.7083483694061157, 0.14758130745782008, 0.3295506164431572, 2.0768937805006584, 3.0245587614274796, 4.621035004815748, 8.120554551001518, 3.3773203098004867, 3.1853041100886563, 4.643204241029678, 6.0295497986578175, 3.549029418537694, 0.8848049539712168, 0.27204505378200167, 2.6992991566658024, 14.048287464726357, 28.882812069308375, 40.84508403655022, 52.22137743426908, 56.736288301406375, 55.81307218920801, 55.464844165309785, 54.90310192108155, 55.9247342232735, 55.32951847199471, 54.66587697305987, 53.37570744176065, 47.77182894368326, 42.00921996947258, 41.89394935484856, 48.34161989150509, 53.691222898421756, 55.09785544487738, 55.45336338781542, 50.85056004985687, 53.04466332158735, 53.63653329110915, 52.5612311978494, 48.064096512333045, 40.59894354112687, 39.194919370835834, 39.473250758263376, 39.3979569404356, 39.829939334623276, 39.34598161328224, 43.66990050961895, 47.80791867163874, 49.68085042891964, 53.586703500440045, 56.320736715870524, 39.35462259477185, 48.9135249968498, 54.64479423338368, 51.85140379013554, 48.44912029081776, 41.653523752766276, 36.26640327515141, 34.53324517896099, 38.01220709277738, 39.05341986686953, 38.5225074521957, 38.44481314382246, 37.084778355013945, 36.86336840352705, 37.022848052363244, 36.04626024923017, 43.09513599641862, 49.227330300115774, 50.938652561556914, 48.795332216447406, 48.1008412761073, 52.203542417095555, 50.96004124610655, 48.833575325627486, 47.847303190538966, 42.544988278419744, 40.937228356638265, 39.34846839597149, 39.74183897818289, 38.990928665284194, 41.543489502322295, 41.4623317410869, 44.36594470854729, 45.34395240968274, 49.603913137989665, 49.30840569157755, 48.51891494566395, 32.23888220325593, 13.24315626775065, 2.8598248525973293, 2.013369402097118, 1.9823196746649283, 4.5050068824521965, 3.896985818301478, 6.421357316355552, 5.616445772109493, 9.118997800734736, 7.726564724599162, 3.578914692324977, 0.5120229540813355, 0.08399616296012556, 0.7235621997425634, 6.1186773257870835, 15.563666743616904, 26.24185277569679, 31.5041575508733, 27.34763756875069, 31.112563802349953, 20.736027648372037, 3.497568657321315, 0.10166303915602547, 0.00900925719179213, 0.041691611836394, 0.05765632493421436, 0.04661072368523286, 0.06825071188711351, 0.09704876135313704, 0.05456745076263624, 0.07471751286498002, 0.07600074844254602, 0.17377578413053868, 0.02445775917881439, 0.03509850211201176, 0.037368949232322556, 0.02292112278331432, 0.0075049434822323105, 0.03634821368201125, 0.06259634332250684, 0.06499176619634514, 0.06367843485467377, 0.04421819279330873, 0.009919985389006476, 0.06165156155944832, 0.04098402238601158, 0.05580206273964817, 0.15042603706880925, 0.05679975819563674, 0.06408606640874379, 0.024327543383884816, 0.0275307217042052, 0.039289252036401344, 0.045871058133460825, 0.06064752672588634, 0.05620847238347896, 0.012146362343863135, 0.04751679119503787, 0.0202415406613821, 0.023731032852083448, 0.04643426682319372, 0.061127097766485915, 0.05681746248756686, 0.011900407900553078, 0.06235485708701515, 0.01604842735574611, 0.04244688642962326, 0.09102480516078011, 0.06782807650104647, 0.04354343021048173, 0.0580371855457704, 0.0385423737668222, 0.029084901513171293, 0.022489870823318922, 0.014739780641731717, 0.01978288573633519, 0.027498582400561824, 0.073921654763962, 0.042262144326683015, 0.09539165954676368, 2.070864607249537, 15.290562895036514, 22.882087769046908, 24.608938694000248, 43.445701752939534, 29.632773168625373, 12.9630402018947, 10.768948697274732, 1.4642953103588474, 0.19417730310270864, 0.2922854951072124, 1.00400872528553, 3.3790495847502067, 6.02614272986689, 7.809153660651177, 8.98206981920427, 8.11289514264753, 8.24661756715467, 6.92555986104473, 5.781630018065053, 2.1753616967508873, 1.4097179808924276, 4.568125172968834, 17.658600730280725, 32.80615302824205, 45.03401848577684, 54.08880610619822, 56.63791133511452, 56.459510172567065, 56.74166979328279, 54.80073198195427, 55.47122978395032, 55.96113381847259, 56.038196625248084, 55.074764451672955, 49.43136415173931, 45.144260621839955, 44.817111415247766, 50.29762744903565, 55.17851506510089, 55.87186851809102, 56.860321490995354, 49.98007235988494, 54.239460422146706, 54.65731836134388, 53.54611089152675, 49.804891463248964, 43.11599908336517, 41.1505425360895, 40.155299940416896, 40.66851462087324, 41.79642354288409, 41.26864117960776, 46.15716957276868, 49.121108593479285, 51.500308513641365, 55.7688396207748, 56.37648144075948, 42.30105607740341, 51.424595002205145, 55.97281071447558, 54.307172298431404, 50.514055990403705, 44.758526894354056, 37.907283690667924, 36.6774009889172, 39.734668885507894, 40.53502851916898, 40.419338210936516, 39.53287862962292, 39.36363620142783, 39.777399186165106, 37.97869043965494, 38.726109843100275, 44.73589481845979, 52.50313697322723, 52.693756318861446, 51.51267574679468, 48.19573125531597, 51.57349994105678, 52.43586440240183, 51.05199337005616, 49.11987304687501, 44.612708860828036, 41.199458414508456, 41.1399442918839, 39.1494865571299, 41.29541920077416, 41.93271806163173, 42.55656319279825, 45.49521469300794, 47.54026397582024, 50.23712881149785, 50.79937311910814, 48.57614232647804, 35.82111227896906, 16.028754922651476, 4.057241360987387, 3.3842442737471674, 3.7524283364895856, 4.798951264350645, 5.27815556333911, 7.223351597785951, 7.687486640868649, 5.282869271693691, 4.370477920578373, 1.0174970821507516, 0.5088407167744252, 0.1286122656517452, 0.574378282312424, 5.482960650997778, 20.010096949915734, 30.945111936138524, 33.48531338476366, 28.997078557168287, 33.231457587211366, 26.650295065295314, 6.131130360787915, 0.10539926528449982, 0.00627629597851586, 0.03761653735813114, 0.025651098168905706, 0.05175372856038232, 0.027217188729874553, 0.003588382889809568, 0.0843697917016764, 0.036313218785630125, 0.02159051807417024, 0.08060863707214594, 0.0808214792801488, 0.04859070090817348, 0.03192546169063257, 0.02886799520873014, 0.009294746560044587, 0.029143405732728785, 0.028535514964812228, 0.04837761355203487, 0.017234373597368118, 0.0339632862127356, 0.023592895708016814, 0.09949846538685023, 0.06493260122595296, 0.04825113243573616, 0.01868745852862635, 0.14313220587228576, 0.1573019060156038, 0.14349333971979158, 0.08963588009318037, 0.10997660232767945, 0.2567416660848164, 0.1953110672653683, 0.19565792123396553, 0.11899927180380591, 0.18499774648056877, 0.18950010649859908, 0.13977208294935767, 0.16840143219357537, 0.19936572550044906, 0.1784486753205138, 0.1272569412005044, 0.19099742534660524, 0.10402006953353844, 0.11276051221835999, 0.11832781105993256, 0.16007891345408656, 0.14191884517429337, 0.1451638404039606, 0.1398093148224777, 0.2512857717491927, 0.23569120935374693, 0.1013404471919902, 0.12413849603504905, 0.16639449633657935, 0.17692143307818523, 0.1298926896866291, 0.20046432622738425, 2.068360419042649, 21.218037912922522, 34.249194975822206, 34.394620772330995, 50.90225688872799, 40.534169520101244, 17.220160153604326, 10.712381255242134, 2.6398186193358515, 0.3371260309171292, 1.5368662678426313, 5.799400806427003, 9.4049915382939, 11.314408202325145, 18.744565786853915, 12.814150952523756, 12.965915299231007, 13.090004382594941, 13.193038182873881, 7.274868988221692, 2.121311926072644, 1.2797903269529343, 3.7733644775805937, 16.587115103198638, 32.076143064806544, 43.59649335184405, 53.54638153506864, 58.05132173722791, 56.8377443282835, 56.52810065977035, 55.72098278230237, 57.816662019298924, 57.01937752385294, 58.07831548875379, 57.051921429172644, 52.08522412084764, 47.600009518284956, 45.89664966829362, 53.58009822906987, 58.17104424199751, 58.89038731974941, 57.601794581259455, 50.681215640037294, 56.28784764197565, 56.611902098501886, 56.16534809912405, 52.94044202373874, 45.22351995591195, 44.05029196893015, 42.55940691117318, 42.51022823395268, 43.25737307148595, 42.36275103784377, 47.54154266849641, 51.28408785789244, 54.21909547621205, 58.35664295381116, 59.588455461686664, 46.28404255836241, 53.46399214959914, 58.95850712253202, 55.2518908439144, 53.188810425419966, 46.63001129704137, 39.39357565295312, 39.27223320930235, 41.290331886660674, 43.6271466747407, 43.89087115564654, 41.79144997750559, 40.02014290901923, 41.01114542253556, 39.763141370588734, 39.29763840090844, 46.36821662226031, 54.5527675844008, 55.25613484844085, 53.18884180438135, 49.28883306441769, 52.62741334976689, 55.464538220436346, 53.17570578667426, 52.064749348548155, 45.48116084068052, 44.150249650401456, 42.764648852809785, 43.44298355041012, 43.001422728261645, 45.820336034221036, 44.99036250575897, 48.208933953315984, 49.448669648939564, 54.08994359354819, 52.52678494299612, 52.84077459766019, 34.0380302552254, 15.326348639303639, 4.0691347227942565, 4.90773476900593, 5.24900499851473, 10.770643161189172, 9.646873320302657, 12.095384463187187, 12.607351829928737, 16.474752926057388, 14.760533013651449, 7.79207468032837, 1.8468707944116287, 0.3065859664592051, 1.286089530875606, 8.30994031121654, 20.705089953637895, 34.55231966510896, 41.32741789663992, 36.639114733665224, 41.54610180085705, 29.686305676737142, 6.297232931660068, 0.25483462809314655, 0.15473374946703836, 0.08778180942059526, 0.18587528487607358, 0.18962307893220456, 0.26144797403004866, 0.1833201824657379, 0.15832075698962136, 0.13994244558195915, 0.19146545910306517, 0.30890681450405433, 0.16958704518695034, 0.09990389443813794, 0.0700235236135702, 0.11284956227867834, 0.10097071783797396, 0.14764677733182907, 0.15548604780868178, 0.2139489599052937, 0.09627873573692576, 0.0849944980995309, 0.0892003361255892, 0.17622815415022836, 0.13563709273453683, 0.13122624957994108, 0.23235457468657728], [0.052220904298367045, 0.026192130528450496, 0.033652974638126554, 0.035402822879052935, 0.022383903626412637, 0.02482135982943639, 0.025057558143030734, 0.01589534862432629, 0.0036346799770986004, 0.03686744509445083, 0.05132104210074871, 0.008219396601611329, 0.03661997571227051, 0.06786119448201311, 0.020087206503376365, 0.03073052349199932, 0.11147089512838472, 0.04154444634613972, 0.02549470706482328, 0.05917761084293166, 0.08177596354676832, 0.02249379893915067, 0.053413243543717175, 0.031988889940323374, 0.04230588028628019, 0.02445420836128535, 0.07832486002195267, 0.024561621549148715, 0.024033499686347864, 0.029548963103743813, 0.060875958823148286, 0.05497055090663414, 0.12835004141614323, 5.804881338150271, 16.490311007345877, 17.35519951389682, 27.990243396451397, 42.01637045029671, 28.439258683112364, 10.010395646095276, 5.614258070145884, 0.8531420497644333, 0.19299294649352952, 1.051536697533823, 2.2029320366920966, 5.084695931403868, 5.449819074523065, 10.296133449000697, 6.644141568291572, 6.636552762600684, 5.237447734802, 4.41404466667483, 3.166946437089674, 1.2411153893316946, 1.184330746050804, 4.056584363983524, 15.595077083956813, 26.619131834276264, 38.47489772304412, 49.86393882382301, 56.943385524134484, 57.5660421771388, 56.912771424939564, 57.69130306859171, 55.25669182500532, 53.324002758149184, 49.96593613778391, 48.9791815511642, 42.43618957458004, 43.15217510346444, 49.700752535173976, 52.35733070681172, 54.77070623828519, 53.41408391152659, 50.06696462631226, 53.64810428311748, 55.94178868878273, 52.9111340738112, 49.4785031964702, 43.3512746134112, 40.85125392483127, 39.826872041148526, 38.428488239165276, 39.84365586311587, 38.17003150140086, 43.85215736204579, 47.529500992067405, 51.07055402571156, 51.79895385619133, 55.521267460238555, 40.27390849205756, 52.04340381007041, 52.99740268338112, 52.58996255936162, 45.58617053493377, 38.07412562831756, 38.167430969976614, 39.41851016013853, 39.047124462742964, 41.50680749647079, 42.97485259271438, 43.6252913936492, 40.81698809900592, 37.63423965823266, 35.680973837452555, 36.79556239035822, 37.335123631262014, 45.154352880293324, 49.04381436686362, 51.166048049926765, 53.588574471012244, 50.370363881511075, 52.44743931678034, 50.40230766419442, 49.18354880425238, 46.87877978048017, 42.772552428707, 40.58655277375252, 40.52464600532286, 41.82368401558169, 41.95889596016177, 44.79691120886034, 45.71352204968853, 46.26261857248122, 47.82462404620263, 49.140096787483465, 41.53800995119157, 20.567408877034342, 5.247604222066942, 0.48608238959024036, 2.374522738879727, 2.801734305197193, 3.3948814965063527, 2.661787569522858, 7.1533686691714875, 8.616753009057815, 4.118505351005062, 3.4212346759534653, 1.5298339484199401, 0.28576247093658297, 0.27239224482928553, 4.430284259780761, 15.48167351753481, 23.96026299845788, 26.970758591928792, 36.36333288684968, 32.95136897794662, 22.556411412454423, 8.759874413090369, 0.7538971977849162, 0.032157904258178126, 0.04781830424983655, 0.04084903386331374, 0.0823053609459631, 0.026377449112553752, 0.02275620895107427, 0.059406353205802946, 0.05763957059131034, 0.05765992171701886, 0.027820998164374503, 0.019733128325653174, 0.02930329211296574, 0.09752172871582931, 0.03722703527478922, 0.06283661913907816, 0.053351106152178786, 0.017963536083698273, 0.03701597422121033, 0.021631024973166567, 0.05043144165087612, 0.0485969675073941, 0.01416089779306804, 0.040095463815716006, 0.038649235371380083, 0.060404673023449804, 0.032530682642133005, 0.06095066771752412, 0.023074129693991235, 0.04851305789704766, 0.10507532500571783, 0.010909207912552501, 0.03431449156074274, 0.02538790674729934, 0.0446879540780379, 0.05156193844853871, 0.01303665227286758, 0.05187025053366538, 0.046198664142960505, 0.05127662432289893, 0.011593118542805316, 0.04368879922455357, 0.005342716336130135, 0.10354453577629982, 0.028479483294030352, 0.02758589344129207, 0.05416584449009069, 0.06723522403908354, 0.0306174814731123, 0.03356705021653925, 0.013598619900163145, 0.04136775965772329, 0.05748116276076725, 0.04614296955086532, 0.024345852885275118, 0.08117892058385957, 0.018200400893786745, 0.040474811403621594, 0.06265394547353349, 0.1394157754557748, 7.9824596643447885, 23.558890781094952, 22.567517603597334, 39.34414594404159, 44.68688088078653, 25.045272957894113, 15.380875468254091, 7.286536568595517, 0.9360762769656797, 0.14779320737767607, 0.26277958806003293, 0.7878840450317629, 4.790341171526141, 5.62832074780618, 7.815262261898288, 10.188376134441747, 8.515336205882411, 6.210196518128918, 7.26677909974129, 6.827976684416495, 2.5109317418067687, 2.1803791436456867, 5.20111874226601, 18.768582459419004, 28.785527483109508, 42.205311021497174, 52.03318603577153, 57.67449179003316, 57.50048760444888, 58.30712303038567, 58.882103273945475, 57.01876955647623, 54.94465943305723, 51.87336514073034, 50.19623810245145, 43.970687466283, 44.24720671869094, 51.940861286655554, 55.08587652637113, 57.12192396963797, 54.82345034999233, 51.24380511622275, 55.2151107788086, 57.091282413851836, 55.44106675732521, 51.697470372723, 44.00337649929909, 41.77425430667016, 41.633986426937966, 40.193472446933875, 41.235975680812714, 41.51277734387306, 45.37629627412366, 51.15725409600043, 52.13512843655002, 55.891805925676906, 55.30411328038862, 42.97652744477795, 53.143636488145404, 55.554556615891, 53.37489551113498, 47.56892865703952, 39.79788180320494, 38.677170430460286, 40.6484438527015, 41.22529898920367, 43.585487181140536, 44.01134675548923, 44.51452016830445, 41.36269569396973, 38.79655561139507, 37.798300635430124, 38.514329310386415, 40.172593670506636, 47.591027290590354, 51.522309087937884, 53.178902518364694, 55.17329439040154, 50.53300103833599, 54.08488765839608, 51.61438280536283, 50.71325748197494, 47.15456947203606, 43.60181600816789, 41.61737518925821, 43.34379073112242, 42.264907513895345, 44.55388507535381, 46.15778538488573, 47.16971766564154, 48.41352085913382, 50.14666718821372, 50.39624367990802, 42.6182738427193, 24.127620727785175, 8.967788469406868, 1.7451614069361843, 3.836511205280981, 3.6399200510594154, 3.9635982051972425, 4.679997544134817, 6.43523907469165, 6.505919204604242, 3.8209604784365627, 2.783743864105594, 0.49058508668695733, 0.17851762323369905, 0.2626902009210279, 4.260078889708366, 17.944592506654804, 24.58584966198091, 30.14291271086662, 39.82346350146879, 37.07754550441619, 28.787971119726862, 13.271894493410665, 1.3831715021402606, 0.059789738077069485, 0.07313983905459605, 0.050016310096027396, 0.05581762581582993, 0.03456720098432514, 0.026038298158035166, 0.06393622727163377, 0.02765300848911847, 0.03159785185069327, 0.021650552554356477, 0.026073049821500337, 0.005425222090355331, 0.03193923595151113, 0.054719274067470146, 0.05154162562722641, 0.03399573769720812, 0.028026673619845704, 0.018483495279665918, 0.054570905819174745, 0.035901224360831326, 0.01471190461738696, 0.017726213536075047, 0.033333389569194086, 0.02990922744145557, 0.032731738587420796, 0.01491825614545134, 0.3888513989025547, 0.11119374750001777, 0.16057339256569264, 0.1669337303047219, 0.1348867096127041, 0.10151927509615499, 0.09639921838477736, 0.0973825918270215, 0.1574529632325134, 0.1429910771548748, 0.10323470683708307, 0.1274698829999374, 0.13330833866230904, 0.20868094097222054, 0.06689790020426435, 0.15697057298835249, 0.21677226969792, 0.10122817700668689, 0.1469167108617483, 0.24157487186453036, 0.18258979423872887, 0.10143068468859119, 0.18340583109567243, 0.12967167332047416, 0.13197847131279208, 0.16375985867794485, 0.1856338752493743, 0.09860725232189703, 0.09987468350558512, 0.19211197602412394, 0.17728650461762183, 0.1407200707903793, 0.260467013764766, 9.820290130953635, 30.79176295188166, 34.446129337433845, 45.217675624355195, 54.91996419045233, 38.07441196134014, 16.70023233659806, 8.252498180635515, 1.4422682600636638, 0.485427935998286, 2.095126427950398, 5.680432377323028, 10.716396781706042, 14.604840413216623, 18.93205508109062, 17.311212093599384, 14.626404623831473, 12.123749083088292, 10.207157423419337, 7.06808114244092, 2.8353936345346513, 2.1726111346675507, 5.7084635957594845, 17.94934053574839, 27.905784960716005, 40.09744498037523, 49.94550451155632, 57.5832849164163, 59.094260354195875, 57.66729031839679, 60.46579945471979, 59.505371816696666, 57.21539405084426, 54.132936693006954, 54.25619325330181, 46.54162068520823, 46.849836610978656, 54.674074726720015, 56.49952227069486, 60.14203133121614, 55.68511662944671, 51.364476834574056, 55.83848522555444, 59.078696389352125, 56.781999603394546, 54.56473081342636, 47.14829367976035, 44.14695093708654, 44.309525335988695, 41.49808022283739, 45.02837027272871, 44.17268168541693, 48.53240005431637, 52.68212256893035, 54.01752487305672, 56.653781244831706, 56.76425872310516, 47.35006040142429, 55.85384522714923, 57.24013636189123, 57.53540846609301, 49.06514813823085, 40.15443309660881, 41.86901092529297, 44.09944711192962, 42.504019121969904, 46.205512785142474, 47.60046451322494, 47.77897942450739, 43.42487004495437, 41.22059606736706, 39.19954384526899, 39.872104813975675, 41.77945929188883, 49.1929115018537, 53.243260768152055, 54.91362564025387, 56.1197897695726, 49.959260263750636, 54.31944539470058, 53.73464353622929, 53.28888970036661, 49.969748681591405, 46.59556504218809, 44.23282338726906, 44.74952897717876, 43.79439261651809, 46.74818838796308, 48.25477469351984, 48.96838326607981, 50.48010395419214, 51.008023600424494, 50.675241870264855, 43.86778800718246, 23.900609631692213, 7.572376843421691, 1.316522220450063, 7.656013542605986, 5.8653083924324285, 6.354073959012186, 7.585802626225257, 13.974695955553363, 15.719088700509841, 12.409563372212073, 8.595218216219257, 2.2881526379815997, 0.8498287501354372, 0.5648904978748291, 6.084765493869782, 19.73050452047779, 30.904248683683335, 36.22613230059224, 47.781642713854396, 43.37307122445876, 32.55788268581514, 13.052960538095045, 1.3302822627367512, 0.18806818091580946, 0.11990310999775126, 0.16231703932487196, 0.14872697662682305, 0.1860612910240889, 0.13232039167515694, 0.1677764423431889, 0.17555261781859785, 0.19079844166915264, 0.15155557242612686, 0.11150507797156611, 0.08398623446062689, 0.14144495850609196, 0.15279125692623277, 0.16092387779105097, 0.18266009046666085, 0.08990455478910478, 0.0902843045731706, 0.16844837806157528, 0.09059331379830839, 0.09034102572308433, 0.058580100566389105, 0.1740878423856151, 0.1774149622407652, 0.2324669751068277, 0.10468448226850842], [0.021333405560243036, 0.07174955801137033, 0.04597808444692243, 0.0889130684757425, 0.045155938038782734, 0.04757053992380539, 0.04502102995531694, 0.052193409402764616, 0.03057221716810619, 0.0378675039316858, 0.014585414882599106, 0.03299369852268889, 0.05226658995173151, 0.022000909459987478, 0.06663884757266891, 0.1031863896716987, 0.07202274496516875, 0.0673749431547138, 0.04381351067774719, 0.04928966803896812, 0.05182487514591025, 0.05681247908561941, 0.007969707479670404, 0.03804503331681894, 0.1116537296723935, 0.10404353480665915, 0.05877329644957378, 0.0182122235456782, 0.05162472318437311, 0.007725611757186632, 0.08540086943896548, 0.01638627404557361, 0.06379131024943725, 1.9504437980151947, 11.958469229359782, 25.199100471312, 21.67253863426947, 32.20935852296891, 55.836669168164654, 38.05656909942627, 8.158227935914072, 4.053519276841994, 0.7302704946168008, 0.12132581188193253, 0.6505044393481747, 3.0999141114373363, 4.400449731657583, 6.566335472368426, 7.346781722960934, 6.689413564820444, 3.251502686931241, 6.396685117675412, 4.776139249724727, 2.679414701077246, 1.970942349683854, 1.4914647105240053, 7.1193121998540825, 15.96687266903539, 28.775931404482936, 43.896146743528305, 54.51988635524627, 57.053239345550544, 56.59826009504257, 55.69773881666122, 54.30462668018957, 53.67505881094164, 50.140665961850075, 49.16247390931653, 48.72809102458339, 44.52869953647737, 51.62408674916914, 56.851049007907996, 57.30016823737853, 52.493119239807136, 53.60101622919883, 49.746785471516276, 55.14300192556074, 53.61121046927668, 52.377789789630526, 46.57092863513578, 40.6608267753355, 40.37853379403391, 39.6456193154858, 40.85369363907845, 40.280439238394464, 41.5448348752914, 47.38897815827401, 54.6690187915679, 51.6704373974954, 56.49899667309177, 41.10877713849468, 54.02464397491948, 55.82165041277486, 50.26153379871, 47.84362400731733, 40.18585520405924, 39.35532469903269, 39.005798370607444, 41.22829175764515, 43.38892936706544, 48.49283510638822, 48.71702209595711, 49.61400147407286, 46.71553465627855, 41.466434540287146, 37.870444790009536, 37.310236192518666, 40.03124321660688, 47.36979384576121, 49.46279802630025, 49.645596165810865, 52.82329651617235, 51.82878348135179, 52.02137970155286, 49.58324616955173, 48.32231398551695, 43.42386199582008, 40.765452077311856, 42.87411828194895, 45.11603916845014, 46.8981445220209, 45.71319649296422, 48.05344335494503, 48.66871418491487, 50.66505155255718, 45.5316182105772, 27.24876638381712, 8.228144184235605, 1.7959204316139223, 2.372721880674362, 3.0510764352736937, 3.609350568825199, 3.2355401112187296, 4.385024520658678, 3.5522109510437136, 4.113309681415558, 1.7777457616982923, 1.233985746099103, 0.2069483565226678, 0.12466928005338677, 3.3849255404164715, 13.286079745138846, 26.16739050034554, 30.20876342250455, 35.729430798561346, 29.592296269632158, 28.57848713474889, 12.092227935791017, 3.2423221343948, 0.10747405354894939, 0.0419293059366605, 0.04123704207520332, 0.03333140157103058, 0.018974513589074055, 0.018663782581326463, 0.038215549167005286, 0.05952703886695447, 0.0025870413341063767, 0.08326706176082935, 0.04264527638893455, 0.0438892001646661, 0.053940112852761825, 0.037750729149387735, 0.03473000232911399, 0.018598117354896762, 0.06037674145773054, 0.03968149288407257, 0.03535058717393587, 0.05321866104138955, 0.020260807772677754, 0.06314174429843984, 0.01303180197869698, 0.07727472201710747, 0.02325353599453886, 0.04662341776213819, 0.024984883212093866, 0.06175361596228135, 0.08037916309530697, 0.02859255404121453, 0.019163279568836577, 0.05637662102197928, 0.0539921532054582, 0.04539632110766346, 0.03879214524321499, 0.058626590612074064, 0.02089475319089909, 0.020544631857304804, 0.028846920129933187, 0.011785549295675612, 0.01845962972560477, 0.034042147303661036, 0.09658363106991015, 0.023724524935166684, 0.025419996255227638, 0.015568975058774796, 0.03259007743890247, 0.04539011579547678, 0.10839759552430724, 0.02512607513175857, 0.054637566959906014, 0.0121562353019873, 0.07953331775722966, 0.0966616188206019, 0.059801842266273116, 0.009018473229521226, 0.027227239803441113, 0.020044761401931607, 0.027661266916942213, 0.1284262441819714, 2.614850281707702, 15.569556182430638, 29.68969656575111, 27.335505677807717, 43.7646375163909, 54.19567892628332, 28.652164936065677, 10.047732687765553, 5.7877229298314745, 0.5520680859204262, 0.03293971613710446, 0.7011016049692709, 1.7673565062784382, 3.9097158706957296, 5.356142088290184, 8.777058316815285, 8.74295428875954, 8.112375428599696, 6.0054174161726435, 9.385733681340373, 4.322965270088566, 2.4373603347809087, 2.7698846593979867, 6.834899667770633, 17.467693090438843, 32.4289131933643, 46.154918132289765, 56.81183315092518, 58.057907396747225, 59.244083127667835, 55.46064722922541, 55.09401152210852, 56.29979518152053, 52.36379085048553, 51.508525879152366, 49.78953146165418, 45.210132906513834, 55.86594181676065, 57.30520848304995, 58.72130178636121, 53.73272549721503, 53.592959680864894, 51.848532615169404, 56.963385689643125, 55.93494023046186, 55.05937307111679, 47.432818489689986, 42.30637873372724, 42.112707784098966, 40.253802422554266, 43.629366736258234, 41.82652381158645, 44.2643553210843, 50.65237052979008, 55.54864168167115, 54.47033897522957, 56.10541036052089, 43.64021601215486, 56.00936328211139, 56.56908942807106, 52.62632293085898, 49.83229706364293, 40.77842727784188, 40.558288174290816, 41.53064374000796, 42.856726492604906, 44.83280874067738, 49.915427777075, 51.4293763714452, 51.171519756317146, 46.04072616946313, 42.99647269710418, 39.29135084152222, 38.02409971913984, 41.79623526911582, 49.633079882591005, 51.09968546898135, 51.91237703446419, 53.664876337974306, 51.49969270152431, 53.81418920332386, 50.38811260654081, 48.82834288381761, 45.48880554014637, 42.640545060557706, 44.27694220696726, 45.7092898122726, 49.521064835210005, 48.36299680894422, 49.34868451087706, 51.610735001102576, 51.57544935903242, 46.1394836056617, 30.2849397736211, 10.564894253207791, 2.815232896997083, 2.838384686939178, 4.156208153693907, 3.5923573903499113, 4.513594911944482, 5.772689465553531, 5.510071583332555, 6.239195581405394, 2.4982132113748983, 0.2855237579393772, 0.21032429150035306, 0.23806651092825398, 2.939268783215554, 13.604767418676808, 28.866057665117328, 31.131967767592403, 37.58849305491294, 35.492158782097604, 32.3295497509741, 15.83797279865511, 5.393341356708158, 0.15210804439360096, 0.0635134999550158, 0.05114427114266062, 0.028933917074614478, 0.017869558162806977, 0.02154351858001563, 0.047204966596778364, 0.030933238017643173, 0.05414115347629113, 0.08055381582028444, 0.0316281218998014, 0.12715275324280226, 0.03257785450607058, 0.050149770273316296, 0.022430790122598413, 0.049945688280727596, 0.020293199885336143, 0.07142243080682333, 0.020975887647739822, 0.04506916325959948, 0.026976786508795716, 0.010934309741001456, 0.041747601372340036, 0.02813502526541631, 0.08606243232685713, 0.05083519296960966, 0.06309760997312204, 0.1488244536543085, 0.32794232209843976, 0.14606931036518467, 0.14569700695574284, 0.17980272040492107, 0.1465402246122399, 0.10329502860024091, 0.1200325328916792, 0.1415281709764273, 0.20434730415863378, 0.15685818788986053, 0.162151457080918, 0.14464573514076973, 0.06237328916247334, 0.13396697509432995, 0.22778167329247923, 0.1602634027480118, 0.22150025793140937, 0.11427985609418924, 0.11576017545115565, 0.10196981906530359, 0.15594173222780228, 0.08518164571855338, 0.11746700402469405, 0.13563716934332926, 0.18044733742792762, 0.2125853846871084, 0.11531006049124465, 0.1653492000074156, 0.14257087792840697, 0.15314784021146838, 0.09000868145977298, 0.15645167099372034, 2.6273498948543303, 19.58362744700524, 41.502626249867106, 36.98866067394134, 46.13216446292016, 64.95761148391232, 45.566731268359774, 13.469920254522755, 5.827276600945381, 1.3579157283229213, 0.32960893105595346, 3.2535097147187884, 7.682962677171154, 11.959170353028084, 16.337062043528405, 18.416237908024943, 16.870486736297607, 10.101725093780026, 13.196303556042334, 11.888194084167482, 6.476778936001563, 3.8068933881098226, 3.005577676719235, 8.409215500277858, 17.56500905559909, 31.987197437594016, 47.70891804848948, 58.593875746573175, 59.33120681393532, 60.98741585208524, 59.170919156843624, 56.9169879728748, 58.86419765410885, 53.867866839132006, 53.50268240897886, 52.175532771695046, 47.30935404377599, 57.65675090974378, 61.064623786557114, 61.08812662862963, 54.77853528914913, 53.32624243151758, 51.34058567785448, 59.68657355154715, 57.87535636655746, 56.146912959314164, 50.654916148031916, 43.68846901001469, 44.41167170001615, 42.6028432384614, 45.346235229123025, 44.176152983019435, 45.07053182971093, 53.19525487961308, 59.79334046763759, 56.268820224269746, 57.09203550892492, 47.917301808634114, 57.08639514061713, 60.19739950856855, 54.2395467142905, 52.98484325408936, 44.3213552044284, 42.220467059843, 42.523054384416156, 45.27820956322455, 47.79183303156207, 53.49096628927416, 54.92085849085162, 54.938391485521876, 50.04340294868716, 46.99709415435792, 41.94691311928534, 40.58588597082323, 43.474652767181404, 50.97101211547852, 52.717757301945845, 53.218122297717684, 55.89060960277435, 51.08003439441804, 56.3703860775117, 53.03692840760755, 51.5793481949837, 48.875081846790934, 44.69567483471286, 46.61077207134616, 49.675692512143044, 52.67066924802719, 51.74861023502966, 51.523983940001465, 52.51982273594026, 52.93883777433827, 47.73490767325125, 30.201548222572576, 9.833053523494351, 3.3029151539648733, 5.784608077618384, 7.7580652794530325, 9.213162141461527, 9.310677166908018, 8.797109473136164, 8.816931170801963, 11.385061856239073, 8.86224631340273, 4.053338357517797, 0.7760643502396922, 0.5441645713102433, 4.083845326977392, 16.828523259009085, 31.851375564452145, 38.94596261362876, 45.86206613048431, 40.70648316414126, 39.79062149601598, 18.78495639370334, 5.290990539135472, 0.2666809367797067, 0.11332794588299529, 0.22950367040691838, 0.07450631008513513, 0.08667193954029391, 0.13799175590036378, 0.10709523073127193, 0.15500874438833806, 0.13482752165967418, 0.23861976430541088, 0.11931316866990059, 0.15736752910719765, 0.1929074817246968, 0.10585064428948587, 0.19084206271556117, 0.18981398804293526, 0.24995599633022664, 0.24483693553315056, 0.10911195719194029, 0.1271582920584948, 0.14183546416461468, 0.26478208060706815, 0.12011001502434093, 0.14388355426490307, 0.26321579852411825, 0.152822942322781, 0.11371333407418382], [0.05449428553542784, 0.01510013020672505, 0.05350640749618892, 0.05484744057720227, 0.017852286710554076, 0.031077867756868084, 0.019669696245522752, 0.05527765257284046, 0.03906251299345205, 0.007674841195224755, 0.04153261411814921, 0.09784488758492856, 0.04491475440802113, 0.02322024181334963, 0.02199829901538549, 0.020106483190771074, 0.029565688718350667, 0.08706236092914497, 0.018679274794375225, 0.037070941029777454, 0.022479754632278796, 0.027437565412612695, 0.014164096210151913, 0.04303980783949937, 0.04402454491824873, 0.0545749431025357, 0.019312092148128058, 0.10813347139065305, 0.053318604871991186, 0.024074182785566778, 0.047459288635441375, 0.019594845624880928, 0.04645542234122273, 0.06654913867673566, 6.568489343889299, 19.09265064424084, 24.452728340702674, 19.324878492662986, 36.06896292778754, 70.03722206238778, 34.72192687373008, 9.890569198516108, 3.382130361372425, 0.9469553996478358, 0.2033188770855627, 1.7672356482475036, 2.671491023032896, 3.7402351585126694, 7.299794179777946, 5.59026248032047, 6.0339462853247126, 5.1019823070495365, 9.035881796190816, 4.055096805095673, 1.4086898296110093, 0.977457098422512, 2.437061744351541, 9.350950102652273, 17.795365933449037, 30.47085619741871, 47.773786206399244, 55.508217734675256, 56.689561105543575, 55.35966973150931, 54.01787396400206, 51.95085940822479, 50.32569200761857, 49.87581576070478, 47.24966341449369, 46.25330294332197, 51.61601058898434, 55.89618329078921, 56.51339177162417, 53.40183827184862, 53.42278372856879, 52.59698360197006, 54.04181218916371, 55.19900944925124, 54.635137358019435, 50.2885236278657, 42.832960851730846, 39.69409981081563, 41.02974137952251, 40.83277956131966, 39.703917503356934, 44.185366630554206, 50.401330994021514, 53.51825029619279, 53.53201389312745, 53.46159558142386, 41.73045712132608, 54.015716660407286, 53.232454638327326, 48.361094459410644, 46.86104282256096, 39.99966813671974, 41.31904363632202, 39.031897821734034, 42.81724391445037, 45.20492007655483, 48.57794269438713, 50.25286536062918, 52.668715907681374, 49.69209586420367, 48.58956859957788, 45.45164108276368, 38.609740964828, 37.00424032826578, 40.90669662721696, 46.5323874258226, 50.189558306048, 49.89849098267094, 52.099921241883315, 50.5633484163592, 50.422029341420824, 47.924860215956166, 48.86510725944273, 42.089903123917125, 45.00867997446368, 46.14194685412992, 47.42259679302093, 48.17860226477347, 48.54133129119874, 50.945230376335886, 46.63810706907704, 31.279158630678733, 11.077213652672308, 1.744108495693053, 1.2493251552504878, 2.92357292867476, 1.8760445257348402, 2.0180621502860903, 3.391521986453764, 4.421565321183974, 5.010741602989936, 4.822651695820594, 1.8884509825898756, 0.5805734208514614, 0.3036097455168924, 1.7417285975910004, 9.284709115182201, 22.322512634338874, 28.450047162271318, 24.50347988836227, 25.271730999792776, 27.44506924383102, 22.92634975525641, 6.104167497927143, 0.5210803196795526, 0.031836262243168975, 0.04541194164043954, 0.024715122586536794, 0.03365909185020193, 0.025176206010303674, 0.037467521765539726, 0.06568827035446322, 0.03619312301218029, 0.08040267433370314, 0.032462025842358994, 0.015362486592493953, 0.029721968739684072, 0.016876800143490397, 0.029297822245186376, 0.04431864224194039, 0.03921848849483556, 0.024022550374690085, 0.013855286167874454, 0.08192721994653826, 0.08458988876232217, 0.039020370496737386, 0.08228246257790635, 0.06838784928643896, 0.030629976367157315, 0.03723238639894032, 0.02391079346829605, 0.025796120528191812, 0.009458340805835061, 0.026685673097569137, 0.055385510091699904, 0.052311750834867846, 0.029882579073009473, 0.03188391865771865, 0.02743145777663637, 0.04135261792989989, 0.07968434433062231, 0.02631814050067577, 0.02957692722819986, 0.09076196805483873, 0.012276837651077057, 0.023086745246884324, 0.05728209481364297, 0.08178712544782508, 0.05381415650669125, 0.038208390075352885, 0.026316049080642483, 0.0068621885316867024, 0.010701463062075839, 0.0246878479412126, 0.009090077552583911, 0.10485027901708119, 0.036056115847801974, 0.05264251695705518, 0.01782242460326562, 0.03951441676866624, 0.05889644508340186, 0.06412280798559228, 0.05847507374240987, 0.040598209016025066, 0.027770677679068143, 0.11639692475117984, 9.076758776941608, 26.271011675557784, 29.28742220324855, 28.19709154867357, 49.65722207100161, 65.05675723475795, 26.7810570809149, 11.280372815747416, 5.309997364397972, 0.8286748562128314, 0.058237096189611384, 0.5294342327021784, 1.3507876785532122, 4.019012715547316, 8.084826661694436, 8.985560728657632, 7.274089417149944, 6.513024578171392, 9.383418502346162, 5.088670763277239, 3.852198724785159, 2.8843683485061895, 4.014288710971033, 10.167772904519113, 19.19802119654994, 32.828498771113736, 49.82322462143437, 56.74061075333626, 58.35443073703397, 57.18767073846633, 56.87525395424136, 53.86029666469943, 51.86462609998642, 49.99992347532704, 49.59293442387735, 47.58549282627721, 53.58995122294272, 56.761234575702304, 57.971960421531435, 54.97339863930979, 52.761401514853205, 52.90823936462403, 55.42354552976547, 58.28300045382593, 55.937058310354914, 52.48056765525572, 44.70393142392559, 43.1183603502089, 42.51173442409885, 42.019484812213534, 42.735442884506725, 45.15305457576629, 52.03106403350831, 53.80064525911885, 55.37666928383612, 55.66695605554889, 44.688944047497166, 54.236644160362985, 54.42106223875477, 52.48708663448211, 48.65717064949774, 41.95698968825802, 43.573508262634284, 40.233947384742, 44.72865412312169, 47.72405055261428, 50.36139734329716, 52.800872325897224, 52.84446554799234, 51.87194524272796, 49.47356885479343, 45.42661243869413, 39.072600257012155, 38.63336540037586, 44.21506681749898, 49.85819255152057, 51.90683080304054, 51.45031006105485, 52.74200931672127, 50.92067241668702, 52.69765123244255, 48.758446247346946, 48.55292973979827, 44.005361218606275, 47.385738280511674, 47.96660600170013, 49.711256642495435, 49.39547054229244, 50.32480555195963, 51.0938411374246, 48.953470414684666, 36.42853444622409, 14.074550674807641, 2.8672548022962387, 2.3488101315113807, 3.6166552478267304, 4.525602757930756, 4.285458585908336, 4.875644387737398, 7.9383501602757365, 6.2326569903281435, 2.4046771853200855, 1.319200954129619, 0.06974439181747936, 0.04491634404046401, 1.3127970719529738, 9.4831516281251, 24.372433500905192, 33.80845392903974, 29.00931242973574, 32.46639536273095, 34.080564437373994, 27.991831956371186, 8.563904954541115, 0.7630567901557492, 0.0404099352477539, 0.027112539204198028, 0.14215553569937908, 0.05300039110044318, 0.017974625206402233, 0.07148553346914631, 0.08006452312392574, 0.020647025254044323, 0.03799518780602563, 0.03155222365392312, 0.035078438269274856, 0.04606572873589974, 0.02566739094383534, 0.06674307383476727, 0.08534110691999236, 0.06426035524195721, 0.032959197753018914, 0.09090432251292853, 0.018433531025244344, 0.07190176436016638, 0.0162922942094625, 0.05305263829687911, 0.014535776215545354, 0.05021848452968463, 0.038023927594505014, 0.029601294569851413, 0.02592345391730628, 0.10310791928561465, 0.1317476183776894, 0.15610883132584635, 0.20017057747369815, 0.07858852450285228, 0.13827310935143503, 0.11470919474959375, 0.12857841988725047, 0.14969609317279634, 0.12726642536900698, 0.10150163209125881, 0.22638089684469087, 0.20361276373507517, 0.2663496190742139, 0.1592603485069929, 0.20538627260154296, 0.11313495301311055, 0.11653312752323768, 0.14094458051746891, 0.14388127132288872, 0.10802110161391959, 0.11721683035214102, 0.10492989853505166, 0.24907122606471663, 0.15406043479038825, 0.2027516809081839, 0.07853590192333346, 0.22460346560805078, 0.11325528244337729, 0.12606753607190427, 0.14527722141675412, 0.1542191222430237, 0.08817366339386472, 0.2500201485330059, 9.554622115627412, 31.94516924119765, 40.68184675708894, 35.28318666642712, 48.05757753310665, 78.12973853080504, 42.11227240100984, 15.381287317122183, 5.150865335618296, 1.4458801501220273, 0.5438490656595076, 3.7280262910550643, 9.406780139092477, 12.766804022173728, 19.195971758134906, 16.01936084608878, 15.77348413005952, 13.244676186192422, 17.425406017611106, 9.984582527991265, 4.012351795550316, 2.090345794154752, 3.188561148220493, 10.8993871173551, 19.2035811562692, 33.80856375540457, 50.5829288882594, 59.47230623614404, 59.734803015185946, 59.18832663566836, 60.149609350389056, 57.952011246835035, 54.91255091082666, 54.64888134310323, 52.20306781030471, 48.96597493079401, 55.27633505482828, 59.10874566724224, 61.89966893965199, 55.95772527879285, 53.228712697182935, 54.59572930489817, 55.70945493636593, 59.071220351803696, 58.993529965800626, 54.821657826823575, 47.496325585149954, 44.5773212371334, 45.447016608330514, 43.58547933640019, 43.584459520155384, 49.270350856165734, 54.269643060622684, 58.26764437460131, 58.31992172425794, 57.35810948956398, 49.545971885804214, 56.4323438367536, 57.18643519186205, 54.059713886630156, 49.69347653850433, 44.5742892449902, 45.93141363513085, 42.524446825827326, 47.74412132078602, 49.941648821676935, 52.7270297850332, 54.91913657034598, 55.37178985534176, 53.97586930182673, 51.724977954741455, 50.051702683971776, 41.63749302587202, 40.457079256734545, 45.43199393057054, 51.17007632409373, 53.01411982505552, 52.57769338546261, 52.940665598838564, 52.088797400074625, 54.27937053865003, 51.32972463484734, 52.26615913452641, 45.06177709948632, 47.8929909583061, 50.480523647800574, 52.945509726001376, 51.67831351680141, 52.02357230647918, 54.34168915594778, 50.49632687722483, 35.327693800772394, 12.57546394102035, 2.745068068465879, 2.709544142407756, 5.96926296910932, 6.218638929628558, 7.156603153674834, 8.35322464666059, 12.663798659078537, 13.19567793799985, 11.360043998687498, 3.598035756618746, 1.6883811763217373, 0.7006816049256633, 2.4253860740892352, 11.815056589341934, 27.817866994488625, 37.75194214236352, 34.10880550261467, 37.210239287345644, 39.89799245711296, 30.517381391217633, 8.695630892630547, 0.9609950946704034, 0.20183735497055516, 0.152803284506644, 0.17873917586140095, 0.14307943773606133, 0.11827694282176034, 0.1709075202985156, 0.1526356644688114, 0.15610487831215705, 0.1807019237669245, 0.06746710353200475, 0.13699141361059683, 0.1077538978068098, 0.10505809568830075, 0.11332341064248355, 0.12507352166839186, 0.10319258732300612, 0.1998903884762718, 0.23684089282347312, 0.24691615944668172, 0.14052110243468516, 0.15887454662832523, 0.18895626068115237, 0.2617323765110585, 0.17210424156679263, 0.09421591376585346, 0.17066923631054742, 0.11837282638636329], [0.0438093776333957, 0.058846668520521735, 0.053624622523784644, 0.050297847408200466, 0.02635068200047939, 0.025428147430741982, 0.0636598457311911, 0.018770257311482585, 0.026104428782878865, 0.0303196705382077, 0.049566589671397404, 0.052809688833452044, 0.015805995001667933, 0.03932254621759057, 0.057321713050647136, 0.03173230985750354, 0.05883854032764512, 0.06930710116942083, 0.03499847401173846, 0.013171070060061832, 0.03593203258670626, 0.021825492562305544, 0.03353092534046981, 0.0809353965544893, 0.05103511510476951, 0.007214589455660674, 0.04596767714247108, 0.050837399302831585, 0.059259693333578695, 0.0884478462619647, 0.02284680459377987, 0.07353395298724213, 0.05637928700795578, 0.06925089329841637, 0.35868625787477343, 11.73127378186872, 25.241738596270164, 24.285062705316854, 18.72228672427516, 35.08921761666575, 56.8386935418652, 35.560592374494, 9.607051457128218, 5.079012907320454, 0.3240656107664108, 0.3257055292206426, 0.7248248352158455, 0.9624700897162961, 4.5373894802985655, 4.929778489374346, 7.245713520434595, 3.454747897002005, 8.64117858871337, 2.8959800351050595, 2.757068314859944, 2.647570448537027, 1.22517732843276, 4.56512701126837, 13.649590303820949, 23.586198322234615, 41.79345430866365, 50.488992045002604, 55.59642007274013, 53.54420854199318, 52.57234719491775, 52.12860161258329, 51.99508805428782, 50.24566388899281, 49.54284575677688, 48.104081153869636, 53.377186175315614, 53.884929149381584, 57.87713712261569, 54.01986260567942, 53.39746090673631, 55.804792065774244, 53.74823062650619, 55.056129270984286, 54.14943025958154, 53.704919815063484, 45.691580310944595, 40.13842982630576, 40.87596485691686, 40.468701239555116, 41.07311102651781, 44.84557213321809, 50.370363881511075, 52.538830541795306, 53.17288560252036, 50.24789571762086, 40.861350105654815, 53.88396032394902, 55.52548008580362, 50.88955625411003, 50.25474025357155, 43.657533276465635, 40.723129703152566, 39.50518669620637, 42.422096498550914, 44.54320446137459, 47.48989289806735, 50.78942206598098, 53.75157640826318, 50.61287226215486, 50.34158152918662, 49.37110477878202, 48.41078304475354, 43.033954866470836, 38.80649881978189, 42.24551923813359, 49.482860949731645, 48.78460845639629, 50.52226551117436, 52.28752428485502, 51.28490371088828, 50.210339023220925, 47.93768636641964, 45.6681872952369, 45.99985899463777, 49.27377900769634, 47.76314481612175, 47.840564558582926, 51.55012653719995, 49.644917595771055, 33.94576826403218, 13.16962359413024, 1.6262754701798963, 0.6199372247342141, 2.0413992722188277, 2.301937317655933, 4.196045216052763, 1.9458379548403526, 4.323818385601044, 7.080243431752728, 2.9165023661428884, 2.5148639179045156, 1.899608777415368, 0.0321578812755404, 1.0370350821364311, 4.595827402607087, 17.663627247656546, 28.227178089080322, 28.548726151066443, 16.243518417881383, 24.822301903078635, 17.746471628066033, 10.557614334167974, 0.8730712448877673, 0.1123710867438105, 0.06179911009366475, 0.0826707695640864, 0.08966542810441987, 0.015679725517158308, 0.008803473526401626, 0.05049992991130679, 0.0026936190073273236, 0.010776297403349271, 0.04241284148226823, 0.03140219107961222, 0.03649230332924955, 0.011612715071908409, 0.028664332649279988, 0.07089480307073363, 0.03146792142351549, 0.05419879776215362, 0.008890675399602662, 0.02346964556753876, 0.011746194401395418, 0.029219315469925924, 0.014946234634055968, 0.05497767552432995, 0.0432352866646984, 0.050829589036443544, 0.07916515122257894, 0.023748913344236153, 0.09528035463224496, 0.06096197900572612, 0.04795190232295183, 0.05931958608749894, 0.046371424630765, 0.08899220535832067, 0.034026055626811526, 0.004558957636266226, 0.012961396583235793, 0.024273532270003232, 0.03258696712192989, 0.007546653618074714, 0.04385535823061101, 0.02399652636790228, 0.02995085282882135, 0.10348261288938024, 0.10570927042393916, 0.013589715085653289, 0.017702470556081786, 0.07570879999548197, 0.05359364192812674, 0.03475501126940212, 0.06323008572742825, 0.02716952273922582, 0.05709125082038584, 0.04798481346017892, 0.0395335957798506, 0.03534401413954554, 0.050265357619331735, 0.012151504709054867, 0.07554884083689221, 0.043642945031845765, 0.038230840281973925, 0.016498113306419506, 0.019851481249075265, 0.9578896806605401, 15.282151372201982, 32.106364926984234, 27.765513158613636, 25.37666028545749, 50.284216865416504, 55.75530352131013, 29.687064655365486, 10.243338346481323, 5.106014993882948, 0.405776793918302, 0.11130982514230475, 0.20774228408211665, 1.8256459913907515, 6.2133721670796795, 7.605544895895067, 5.7473460512776535, 6.578773308184839, 8.587142056034459, 6.801375169907847, 6.93636893264709, 4.497787269853777, 4.205525094462979, 6.522913853968344, 15.043466321883665, 25.90876117829354, 43.232211066830544, 52.46579600918678, 58.313940109745154, 54.65396081247638, 53.92888715190273, 53.64670007459579, 54.29793119430543, 52.616528772538715, 50.94892524903821, 50.3647078237226, 54.73771126039567, 55.45515983335434, 58.1435876507913, 55.43585784973637, 53.14579771411035, 54.493704534346065, 54.980305933183246, 56.70466223070699, 55.76391704620854, 55.01671729549285, 47.38291025161744, 41.95924897347727, 42.44836461159491, 42.10770676212926, 42.58083089705437, 45.80583110932381, 53.27211372313961, 53.9944338798523, 55.08237777217742, 52.316392929323264, 45.228528822621996, 57.1549032580468, 55.562130712693744, 52.77114075999106, 52.084023875574914, 44.478642248338275, 41.98312444071616, 41.38468450115573, 45.334373981721946, 46.228866577148445, 49.78284382051038, 52.237310101909024, 53.995375248693655, 52.45566060466152, 53.90167767001737, 51.620042785521484, 49.073702827576675, 43.68383669084118, 40.159387050136445, 45.99495603192238, 50.62203099650722, 50.98355585528959, 52.19864337675033, 52.42058284821049, 52.37005095328055, 51.19060993194581, 49.230432894922075, 47.551948716563565, 47.46782564347791, 50.20867201589769, 48.37627795434768, 51.66356932732367, 52.383084989363155, 52.319279793770086, 37.005283678731615, 16.598607647803522, 2.9571655777192887, 1.3385517222266043, 4.589846768686849, 2.69149731724493, 3.7729538544531795, 5.0452045279164475, 5.653167982255259, 6.339311628572403, 4.883681324220473, 0.5768008974771346, 0.6635914887151411, 0.1856124860745284, 1.174999549984932, 4.968709484223397, 19.683742023283436, 29.76640832039618, 28.24986703934208, 20.475513627452237, 27.77155164749392, 24.86469684108611, 14.461505240009679, 1.828079331786402, 0.13631590792248327, 0.016824566353593143, 0.03848215542553413, 0.03827572537345752, 0.013334666221072117, 0.022088281787751664, 0.061844125420095465, 0.023385994511866764, 0.015347667579208652, 0.025399566605506886, 0.03273713184640773, 0.059845141555753455, 0.06581304309469077, 0.009176699114182304, 0.02036298283435885, 0.04469309452800982, 0.0356025496617921, 0.04940437438387064, 0.027150119647323608, 0.025554396805443594, 0.018280843956275813, 0.02270889727609052, 0.041301286208533475, 0.04157256943384006, 0.056690958388630426, 0.04468881592695271, 0.04259253889622708, 0.03492361573021739, 0.19355687913635086, 0.24414246150803184, 0.19954725769498657, 0.1331177819520235, 0.11035150277518457, 0.14221653161991027, 0.30135870340370363, 0.05915837437515298, 0.11306021347521775, 0.12364125900691557, 0.12969510028919867, 0.23235727131607073, 0.07416219871130682, 0.09353745097835219, 0.21286963395053343, 0.17886533522077147, 0.13257097903518908, 0.17246140707885066, 0.13349613745606717, 0.11884308945868285, 0.10587699771408113, 0.18250419157406977, 0.09343379162131779, 0.15191186459795122, 0.18464788944730837, 0.05056063471842678, 0.20272217120134062, 0.11144385222465762, 0.14381488214337057, 0.1838286809863583, 0.14487209880063612, 0.20555974555111703, 0.1309450340246962, 0.1056716401850985, 0.9145832818842704, 17.661919055446504, 38.88011778554609, 40.46327267923663, 32.18929167716734, 47.75903417218117, 64.91734050935315, 42.954103254502826, 13.0538381684211, 6.424391269683839, 0.8343156535298595, 1.0042370194869659, 3.8993203639984135, 6.545533672455819, 11.577905185760992, 12.597159551035974, 16.067575600839433, 9.732905607069693, 18.37117575830029, 9.63396970302828, 7.6237799948261635, 6.368892673523196, 3.1808657030905447, 6.037836295943107, 15.65697894942376, 25.841988709665117, 44.089296017923665, 54.034147877847, 60.858063928542606, 56.904357940919944, 56.09328239194809, 56.5353060537769, 57.212142405971406, 54.7943385185734, 52.8285603369436, 52.0256943087424, 58.26276494610695, 57.3145241122092, 59.8675948573697, 55.307172729123025, 53.230407161097375, 55.470119753191554, 54.776997720041585, 58.976828513606904, 56.69063975734096, 57.53074084558795, 49.44901481751473, 44.69373718384774, 44.84084567716045, 43.67523101068313, 44.38728240228469, 48.06237066945722, 56.90674274198471, 57.15576617948471, 57.23910477853591, 52.68195390701295, 47.64958043252268, 58.57557396734915, 58.38289929974464, 54.10035356398552, 55.20769357681275, 47.60643436062721, 43.68910051161244, 42.91836653986285, 47.442589113789225, 48.951207207095244, 51.63512037646387, 54.38388209189139, 57.1268779231656, 54.13015965492495, 56.35312764875351, 53.229724668687396, 51.416911079037575, 47.00128324570195, 41.651013435855994, 45.92261183646418, 53.00965224542926, 52.1880922009868, 55.68504602678361, 52.10672263176211, 54.01552446426884, 53.19206991503316, 51.0266117126711, 50.07725692564442, 50.681180338705744, 53.023223646225475, 51.67568945115613, 52.611515983458496, 54.35344449935421, 53.172520822094334, 35.886643317437944, 15.385386193952254, 2.3723394495825616, 1.6975884500049776, 5.77857792377472, 5.972411651765147, 8.835233930618532, 7.1248344067604314, 11.12167077679788, 14.998605193630343, 7.047962815530839, 6.424246141987463, 3.270020196514745, 0.3039290509637325, 1.7145492689263437, 6.329534140325362, 22.440024883516376, 35.231638877622544, 37.375382838710664, 24.01908286156193, 35.578588208844586, 30.027083158493046, 15.16887822458821, 2.0156755106103037, 0.1704894354747188, 0.15604832570158667, 0.24746000526412842, 0.12372212724820261, 0.12800363177854207, 0.12422042913855084, 0.1389405098293097, 0.08438972530946617, 0.09850732381305388, 0.1194460925856425, 0.11511478467934555, 0.1741919843780418, 0.1513230034540738, 0.10468222230913178, 0.1932384929950199, 0.10438034536256906, 0.11355200361820961, 0.16656822975604765, 0.13553422244806446, 0.0680064830568529, 0.08377411237527287, 0.15410730404959572, 0.2067389387276865, 0.15520346861693168, 0.19562879457108437, 0.09471544139688054, 0.10294588402875009, 0.17137763781412957], [0.032390699226168856, 0.12401478815703623, 0.01031403037373938, 0.01737354112969291, 0.020310848635891755, 0.03497896175230703, 0.1429527574369023, 0.028676492379858132, 0.03827379100144871, 0.038644592878558946, 0.011574210535224167, 0.022419191551424807, 0.0520944346733872, 0.03873386510437535, 0.02690941099107506, 0.01044264025685768, 0.06089402317640282, 0.007371544113172399, 0.06890628396743728, 0.04208860242919576, 0.02792647123456963, 0.051376752014602386, 0.01244905804689493, 0.04560841254950051, 0.019575938574909683, 0.040728570367660255, 0.08944052001160961, 0.0329768062839585, 0.017889233215922312, 0.0018110032444031189, 0.046268684579239744, 0.08842182991605613, 0.08011165285302747, 0.07685810808212527, 0.057900017502927975, 2.4581822368406483, 18.84382332524946, 30.974637577610633, 24.599858407051336, 24.189707925242764, 52.20346396969211, 60.521826590261156, 40.078248900751916, 17.22453163516137, 2.971641084840221, 0.6441106695321299, 0.3428624972941414, 1.8652341058177335, 6.124329951501662, 7.890801227861836, 2.966943801410737, 5.479058382972594, 4.855089697145647, 4.469181424187076, 5.5504200247026265, 3.9802768586143373, 3.603713142295038, 1.5493231026395675, 5.380589731277959, 14.609070689447465, 27.341167619151456, 43.591284444255216, 51.98660004523493, 53.995359559212964, 55.60205259630757, 53.875217360834924, 53.034829939565356, 53.19371338813536, 51.531079507643184, 48.843742109114125, 51.491149779289, 55.30031250369165, 56.91030425410117, 55.183994616231615, 54.32031223850866, 56.76760058249197, 54.96580493065619, 57.87938071835426, 54.95457518485285, 53.96643207919214, 42.75598825946931, 41.173790424100815, 43.05404132412326, 43.81651870666012, 43.51602592775899, 48.98726163371917, 52.002921027521936, 54.520717897722804, 52.21582728047525, 55.14055828894339, 42.27268949631722, 50.78720592683362, 55.062942427973596, 50.564136812763834, 52.7005773205911, 46.301783438651796, 44.23436880111695, 43.768171571916156, 43.01672781667402, 41.39119955801195, 45.26156302421324, 48.98736753771382, 50.81137557183543, 52.099301507396085, 49.82363647030246, 52.08118407957016, 49.60846308738955, 50.4246534070661, 45.68435138271701, 41.52234008235317, 46.931335618419034, 50.985701391773844, 50.813870199265025, 51.13486128468668, 53.04355721319876, 52.85372626396918, 48.6141618605583, 47.08430805513936, 47.47363859607328, 49.182187741802586, 50.625376778264204, 52.74275848942419, 46.63913865243235, 35.71490626181326, 14.153100059878442, 2.824361232980605, 0.5309721695319299, 1.1722822054739923, 3.5884158986230053, 2.017310771249956, 1.5735175076030916, 4.091360343079414, 3.078132209277922, 5.4319384597962905, 4.884257912635803, 0.5964057003298114, 0.2278635527698263, 0.6631260136923482, 4.929525496498232, 17.514318304677165, 21.459540205617106, 31.904692342204434, 43.38024131713375, 19.891560962123258, 31.19818522084144, 14.577168091650933, 3.1919265418283405, 0.08059098640637052, 0.029298053986783472, 0.057475336662103096, 0.16913770397584285, 0.06868659293339138, 0.04703057434169516, 0.02087724616660947, 0.039476824834221796, 0.013441345879747985, 0.015267673635765191, 0.036525903945608486, 0.06038840131593808, 0.04128424458265786, 0.046457268613120245, 0.017227354316761898, 0.06144885469468371, 0.009058287776555986, 0.009953890525315319, 0.047495110906780734, 0.026266322313477437, 0.02753894374285254, 0.021688288130286722, 0.04346734235784219, 0.0160472801390795, 0.05030711324164464, 0.08629866319918826, 0.032724518208734454, 0.02857449926405905, 0.045721701631743106, 0.03120427226437436, 0.08594260085374118, 0.04377498411603513, 0.024310875225872285, 0.029496717822527694, 0.034945154292208534, 0.02964867710796816, 0.06015950190504232, 0.026688339083545634, 0.06009744112229636, 0.05667315067483052, 0.011692585483674082, 0.036667005849942085, 0.005040242319791428, 0.05951275898804588, 0.036554789290793484, 0.016370538599608887, 0.025570436771358215, 0.021566725298461896, 0.017800895617373528, 0.020534203485435536, 0.09079625048945028, 0.07417113129650393, 0.04123142282027872, 0.06339071138251214, 0.006945788355228762, 0.019565615540130005, 0.04149536309283107, 0.040423682695555116, 0.05240001565506382, 0.035303066739992756, 0.06090726500617401, 0.13850707260351028, 0.07482046742112407, 0.027262878213678638, 4.113814686575244, 23.445242066537183, 36.17932273495582, 26.72579284637205, 28.881866778096846, 62.058383726304584, 57.673566110672496, 31.098445230914702, 14.550116485165013, 2.878579910724394, 0.5215786445525386, 0.03345725066479176, 0.15903527187483926, 3.1330051873960807, 7.046332090131699, 4.491516380540786, 5.708783268928529, 8.059379304608992, 11.6371702378796, 10.793173255458957, 6.892332482722498, 5.601385831832887, 3.336094238104359, 5.965867177132638, 16.782896287979618, 31.08388343164998, 46.210807984875096, 54.690301572122884, 58.17952440631006, 57.335904952018495, 55.49311268714167, 53.94971101514755, 53.76732472450503, 53.24510035976287, 51.25864344258463, 53.55599134199081, 55.20409676336474, 57.3623574164606, 54.70926230953586, 54.65033654243716, 56.14341028275029, 54.53961587721302, 58.29957246780396, 56.04019703403596, 55.93325753365794, 45.873091913038685, 42.85802087476177, 43.49881848981304, 44.411291230109434, 45.54705665957543, 48.78671476917882, 54.066150496082926, 56.65892739449778, 56.00973982964793, 54.41592785619921, 44.68442155468849, 52.90840410417127, 56.3893428925545, 53.099207801203576, 55.13622406990298, 49.131216541413345, 45.27297319904451, 44.60665664365215, 44.5623730844067, 43.09909759029266, 47.484840885285415, 50.482163198532604, 52.96014408911429, 53.28826604350921, 52.40014337724256, 52.6345952095524, 51.80091896364766, 50.40819906419324, 46.51685483994023, 42.43758201599121, 49.623701495508996, 51.67454804143598, 52.543772728212424, 53.18987338773666, 53.511680326154156, 53.6964161165299, 51.632931693907715, 48.264129546380815, 49.40706114615164, 48.81012347436721, 50.97139650775541, 52.2350468943196, 49.74291016978603, 38.835041907525834, 18.1692894043461, 4.951481944130314, 0.7775407548873656, 1.497118561979263, 5.6083916752569145, 6.010926385079661, 5.136377571090575, 5.358538656465469, 5.529822678335252, 6.042500484374262, 2.780728787183762, 0.7696414690825247, 0.04194598367077209, 0.6550704459509542, 4.025124994016463, 16.291159525994335, 27.05701739557328, 37.84387857683244, 40.588580639131614, 19.921735755858883, 36.170838648273104, 17.597115616644583, 4.744135650896258, 0.1944147903592356, 0.08317433447847444, 0.02205904021168188, 0.041230511175648826, 0.03105715082417573, 0.037301878234551805, 0.03863062709569931, 0.09909240814346461, 0.03351514775966925, 0.02979887439118278, 0.01414897459213652, 0.06237409738523345, 0.01091889892479465, 0.06647067595153086, 0.049243928759448954, 0.06308270190211554, 0.035120561613791415, 0.03551577488260885, 0.01961367032040031, 0.02667273770296766, 0.023438818189465714, 0.047717230439546614, 0.0477783834081023, 0.05153465422711546, 0.0375328767263601, 0.04233298447704123, 0.030197946827918775, 0.06314269807790557, 0.060395840029682846, 0.17619600910092556, 0.2211831588177912, 0.09440589591019577, 0.13025091240002265, 0.11666387574927461, 0.1647396391678241, 0.30501453626540403, 0.13899090309296885, 0.1408604793851414, 0.18529129605139458, 0.12762871600927847, 0.08910774673906066, 0.20447635933035807, 0.19867388681778986, 0.155614628005893, 0.0749117314755436, 0.2356831501087835, 0.1448511386350278, 0.12520301351023297, 0.13983778264974395, 0.14261380949568364, 0.10674315970391036, 0.14078601563890136, 0.1364381908769569, 0.1147152545050748, 0.17600539110360608, 0.1777224239682959, 0.14764945863956405, 0.1342456625594247, 0.0967444099425789, 0.17221566139449998, 0.10922561399638654, 0.2003599390868218, 0.20524989362926255, 0.13990556610928429, 4.2088228271853545, 27.064152186916722, 44.31551479524182, 37.588159653448294, 37.588818611637244, 60.428250605060214, 68.50020208666402, 47.325439683852665, 20.628315441070065, 3.939934300799524, 1.1498958905858379, 1.0936016661505545, 3.8531092049614077, 11.658429484213553, 17.410326465483635, 10.57759782960338, 15.029322255042294, 12.826306377687763, 11.474224194403618, 13.360063491329072, 10.679037186407275, 7.213873680560821, 3.264201850660386, 6.830657624429272, 16.86315582644555, 31.228587512047064, 46.87512805384975, 55.08223656685122, 58.74495367850027, 62.933174256355535, 58.1577552518537, 56.84573027395434, 58.84417787674935, 54.95643438831453, 53.32204941780337, 55.28325803818242, 58.670197225386104, 58.89334478685933, 55.618608920804924, 55.59825574198077, 55.27962984577302, 55.55557250976563, 58.57955517307405, 57.92209925190095, 58.750872535090295, 47.64064527327015, 45.04709959030152, 46.33409984650151, 46.429205556069654, 47.69373063118228, 51.75968700839628, 56.57985241182389, 57.88996327307917, 56.78598473148962, 54.61198360689225, 47.423087089292466, 53.533214138400176, 58.52574025430987, 56.207901893123505, 58.02226481899139, 51.89678561302924, 47.35824246560374, 47.37875646160495, 47.190804327687914, 45.333311019405244, 49.02693248564198, 52.89000426569293, 54.95043708432106, 54.67058381726665, 54.15830266091132, 55.75063982317525, 53.9907782308517, 54.58697849704374, 49.88326826403218, 45.346607854289395, 50.721188514463364, 53.582224153703265, 53.473366614310976, 53.99898382925219, 53.52208637422132, 55.39653216638873, 54.208512921487134, 50.3870221876329, 50.7906654573256, 52.11017823988392, 54.27851546195246, 54.071159362792976, 48.99421599603469, 39.00948932093959, 16.772386297102898, 4.142877978663291, 0.9198433641464481, 2.462457375180337, 8.946195821608267, 8.136987320838436, 6.873667884257532, 11.202447087534013, 9.558219909667969, 13.986155160011785, 10.154492739708195, 1.7161153977917087, 0.5697072910205011, 1.3279836312417062, 6.406373372001033, 21.47790474276389, 28.222112348002774, 38.309969902038574, 50.372929111603774, 29.085939853422104, 41.82397034860427, 23.454096817201187, 4.770830811992769, 0.3516208434537534, 0.16958448645328322, 0.1211355233024205, 0.23307730203434346, 0.12150149116472853, 0.1663525760053627, 0.1895529818871329, 0.135024176429837, 0.19275176669320754, 0.1332433284410546, 0.09304140138650134, 0.1224929391736946, 0.12929083569155586, 0.15282163997330975, 0.11644546408206226, 0.1447354900019784, 0.11633583690009772, 0.16073799421710355, 0.09539607221320753, 0.18106141818627236, 0.16455207020044327, 0.09112434296478188, 0.13849244032415653, 0.13004308806792383, 0.16180418942484165, 0.1319457593584253, 0.12474901448454588, 0.14844225238888495, 0.12270106994096311], [0.027146884841063333, 0.009448302181197271, 0.02313969149855116, 0.021568219169914242, 0.05908405618561853, 0.04217629651388815, 0.047997990172476544, 0.09073444251571933, 0.053005604328767914, 0.051653267620431806, 0.01794148615801767, 0.06393868641387071, 0.0029684394042217926, 0.019404514910533063, 0.08745858160358283, 0.023812887431573004, 0.03735534734122696, 0.0567641887333124, 0.010430340715233358, 0.02616632868716073, 0.04624847901023684, 0.024821706484222127, 0.03692588994219419, 0.044745812868519176, 0.06805928949747356, 0.12033378164614401, 0.024314219199661768, 0.033443721552048965, 0.03131126027343975, 0.06477050468205445, 0.0854922560674529, 0.06038099324571029, 0.03732517496832917, 0.03623731479409241, 0.05033170849445367, 0.12557839659313041, 5.969736105011356, 25.806391239166263, 31.400510880254934, 23.697583829202962, 17.79644262406134, 47.96056162926459, 57.06877585380309, 37.79632768323345, 17.85859650181186, 3.915218956047489, 0.3312700548239293, 0.23497623481577445, 2.87531110548204, 5.316085373201679, 2.6616078759393385, 3.936234525134487, 6.166052203024588, 11.39629944678276, 10.17132951367286, 4.415518497267078, 5.880311948637809, 2.506197686156919, 1.450761049505203, 8.467918672869283, 19.313121188071467, 28.192743601337558, 40.6630939052951, 51.1681818193005, 55.88525164511896, 54.11076353442285, 55.09271713995165, 53.457837950798776, 54.252384631864494, 51.885771597585375, 53.381622375980506, 55.80020289267264, 55.98941018504482, 54.691011521124075, 50.82333095612065, 51.410580373579464, 58.385644958865264, 57.06858365766464, 54.901383922946074, 50.90766975956579, 43.30388845935945, 41.71010394250193, 41.346186437914454, 43.26209560517342, 47.05747904316072, 52.67268142392559, 50.584446845516084, 57.325098822193766, 52.604420415816776, 55.92700527560327, 41.40597512645107, 50.1824313594449, 53.52524388221003, 51.156528457518554, 54.305603350362475, 48.766898955068285, 50.99739005488735, 48.75723031259353, 46.39673225341305, 42.12358059421663, 40.83251676251812, 44.406494171388694, 49.26285128439627, 49.556829006441184, 52.64871966454291, 53.25724009544619, 54.183856902583955, 50.02166517319218, 49.26369067161314, 45.91478670797041, 44.56688773247504, 47.52170724253501, 50.196646028949374, 53.218781255906634, 53.12163199147871, 50.65001710768669, 51.87643635657526, 48.37607791346889, 49.1135972545993, 49.3582001809151, 50.666757783582135, 42.93671538752895, 31.842764000738825, 14.513582548787518, 4.016845851175247, 1.1395847148472265, 0.1436506941794388, 1.7773538924032644, 5.96675020071768, 3.7291390184433233, 3.7687836395156, 3.7282228998599516, 3.870878032138271, 3.3106451649819655, 1.9283471256494524, 0.5332584823331525, 0.5896258221999292, 4.242534127927596, 13.20965628470144, 20.50924993330433, 22.25729930785395, 21.864326846215036, 52.15439904120661, 34.85803311870944, 23.527078397812385, 9.151700562046422, 0.7800638807877418, 0.02238569627215545, 0.041607755852202256, 0.05158624641837613, 0.049884389755466295, 0.11053622189548709, 0.01932191148009752, 0.03138869835604583, 0.025781741057853066, 0.022234577768211885, 0.05920115655528442, 0.004299946660701667, 0.0605209690007952, 0.0461783321694501, 0.028374575213679386, 0.04984198295841775, 0.09619785983475948, 0.0437483127649513, 0.05341008726146914, 0.037514210994085, 0.04962777328347007, 0.05315892150505416, 0.0029385152916919684, 0.06449673550143357, 0.08077060338109732, 0.025523220857364998, 0.01864940502620753, 0.03625534850382998, 0.05622647928013917, 0.05225805956269464, 0.037588326170319514, 0.028344504347431566, 0.08370343310337874, 0.0694609929116503, 0.01435735242276062, 0.010277562673323819, 0.0362375982466244, 0.043675507599067305, 0.04385762202042726, 0.0047442656866605246, 0.05034778484954469, 0.02002013742082542, 0.017430480614665057, 0.025940983924233628, 0.06406547396533913, 0.05218732666464583, 0.04179072829203741, 0.033529577025723074, 0.07378807201260522, 0.016768950285510193, 0.04369759391392431, 0.05057823558848712, 0.02620828923799338, 0.01539442575566711, 0.030653114137690396, 0.08378915068122648, 0.03177141673081825, 0.07115685110611301, 0.08017307012191704, 0.023676541018029375, 0.03994997988845553, 0.1044186497587831, 0.06493267017386614, 0.018402311027110107, 0.05422320149298157, 0.3387300658129877, 9.10207179284865, 32.05011029397288, 36.56528003754155, 26.237673490278183, 31.160285319051436, 57.984453170530266, 59.776148719172326, 39.742223370459776, 15.846471594225978, 3.606356819791179, 0.27273952780712035, 0.23076452855621618, 0.517875007804363, 1.3500952576437306, 4.1141284761890295, 5.7636292807517515, 8.292748562751278, 18.610614884284235, 11.589061387123602, 7.5109201669693, 7.764719090154094, 3.244817252120664, 2.1353699459183604, 9.94457042986347, 19.62654798261581, 32.86915609913488, 44.00760481434484, 53.29488308198991, 57.16050440265287, 55.87104874272501, 57.02129948523737, 56.12169996384652, 56.65778206240747, 54.23509090177475, 54.26028820776171, 57.20094796149962, 58.39584704368346, 55.7369468289037, 51.55871652787732, 50.86781847861506, 58.67252319089828, 57.8996358379241, 55.94906468545237, 52.541505598252826, 43.82626579653832, 43.77921696632139, 42.44362638842675, 45.57596060537523, 48.6913227265881, 55.165990937140684, 53.15408960465462, 58.83404639459426, 53.95459828838226, 56.16694450378419, 43.691657896964784, 51.26344050130537, 54.728611361595895, 54.05684271166402, 54.92087418033231, 49.51850744985765, 51.8152513042573, 50.416361516521825, 47.64302615196475, 43.77980139947707, 43.04748312119515, 46.57535306869015, 52.14712304453696, 51.851078233411236, 54.978980172065, 54.98634246087844, 55.02948068803357, 52.12354959980134, 50.40327648962698, 47.302497740714784, 46.2461720743487, 48.90750808100547, 51.308834091309585, 52.54323144112864, 51.80881469480453, 51.07691611013105, 54.147951526026574, 49.70619678497315, 48.791856996474735, 51.217587993990996, 51.98241487626107, 46.10961867916969, 34.78410820807181, 19.111332893371582, 4.97582515401225, 1.7119046108376597, 1.212408174910853, 3.2889811790758565, 4.201137923425244, 6.507936283465355, 5.638968511935204, 5.959862518695093, 4.88615486891039, 2.909046675889723, 1.5347078610812466, 0.26106646224375696, 0.412017070357838, 3.5713239254490023, 15.363560165128401, 28.398885726928714, 27.149279386766498, 28.224979600598736, 55.7892555575217, 35.85871604181106, 29.197376351202692, 12.874333839262686, 1.1306209958368734, 0.060520739174417915, 0.02938951913928313, 0.08691075978980911, 0.07010512729926456, 0.03971074978190084, 0.01332839196097226, 0.027232715416879907, 0.01663333165549463, 0.07156888383530802, 0.04696414302734118, 0.03148337150172841, 0.028906571566157287, 0.006723362866098122, 0.046865696898631515, 0.035921927886985006, 0.08518457217442413, 0.02083082123839807, 0.12328135856096784, 0.06859060211647904, 0.08863641880452634, 0.03985140352479873, 0.0705038684029733, 0.018912046779728225, 0.10794676044174742, 0.04917354826184531, 0.037361790140670155, 0.02775970155433301, 0.013989183972890099, 0.031198509367963964, 0.15071456110285175, 0.10699175523533937, 0.10886910731994337, 0.20606062915777007, 0.14623950445844283, 0.16301313745639018, 0.11192274144700459, 0.1941330385424437, 0.11975984389503157, 0.07209566121380176, 0.13802174058172012, 0.19004104118193352, 0.10349037336005319, 0.10734545036910043, 0.17044843444901128, 0.11302069099920412, 0.1297959787470679, 0.13332623447622025, 0.14876767121736081, 0.09330037740930434, 0.19869090929146738, 0.14331546942553214, 0.15761142085877158, 0.09202805858465934, 0.14878215027912972, 0.19415366162936534, 0.07777100143533561, 0.13126608615200366, 0.2931371397308765, 0.134084569590707, 0.21173464404719494, 0.2999074264399467, 0.16410855125756035, 0.2797001414000988, 0.1251892162667167, 0.4123339549668374, 9.360910961704871, 36.30822750829881, 45.82198735206358, 35.88585492103331, 30.11767225880777, 59.64857755168792, 66.23204446608021, 44.414389902545565, 21.623181489206132, 4.641946140796908, 0.5924170788738036, 1.3235591976873338, 6.767391754734901, 13.98006764150435, 10.257173526671625, 11.976649415108467, 12.646992283482707, 18.962278904453402, 19.69803317900627, 10.834183596795606, 11.463868156556162, 5.133739777149693, 2.0268518141200467, 10.342051656015459, 21.92260738342039, 30.971344747850974, 44.38805118683846, 57.18305018640334, 59.3947256765058, 58.831810643596036, 58.6584379596095, 56.00434264829082, 59.63891675395351, 56.982958316802986, 57.70390564395536, 59.268421434587054, 60.14594585664811, 54.372887688298384, 51.58042292441092, 52.188241251053356, 60.01878261566163, 60.66203563444076, 58.96045261813749, 53.81973935711769, 46.52985749706146, 45.45629693615822, 44.86814537355977, 49.0620808447561, 51.68651127046155, 57.18786685697494, 54.795966302194905, 60.98245797618743, 55.49865107382498, 55.36838131566202, 46.82865581204815, 52.372980963799264, 55.446962079694195, 57.73935994794292, 57.62169668751379, 53.55164143346972, 54.851675725752315, 53.80905874313847, 50.541316463101296, 46.811220876632206, 44.47879522077499, 48.45842807523666, 52.71412518716628, 53.841214333811116, 56.61321217013944, 57.74926393262802, 57.410269168115434, 53.54149818420411, 53.38845906719085, 49.22199195431125, 48.74688702244913, 51.24211457467849, 54.581746055233864, 53.698004676449685, 51.89007836003458, 52.139572481955256, 55.187006996523955, 51.254332757765255, 51.532864186071585, 53.10475011025706, 52.789713182756984, 44.40889466193415, 34.615246249783425, 17.56468742124496, 5.076476114411508, 1.9702829011986334, 1.6193516288072833, 4.9190861082846125, 11.229735016822817, 8.106453630232043, 9.2903906683768, 10.716996904342405, 10.430047089053739, 7.957688425817798, 6.148774652711808, 1.1867938719449507, 1.0669572507181475, 5.545650912869362, 16.76419834936819, 27.106198033978863, 30.612285098721905, 29.786335922056633, 58.2442395917831, 44.17811024573542, 34.76319805268319, 14.376248601944217, 1.0899368240948648, 0.11401785402408532, 0.10950501392325086, 0.1473169151933924, 0.18310673504827485, 0.1858739672048438, 0.12256405511570555, 0.09694726236404912, 0.1009428782028056, 0.12730165775264465, 0.25994460308744066, 0.10959603282953463, 0.11251926347012482, 0.12070972397322617, 0.17100554890930655, 0.2017553375973817, 0.24274870242562988, 0.13049564684831327, 0.2330802284902142, 0.14741307454964808, 0.1615035612015955, 0.21818933317497854, 0.18245217420401114, 0.09497818657227101, 0.1843004379301302, 0.15602312140887784, 0.0873724733208937, 0.10964531526570359, 0.13549630109581257, 0.09423581673012627], [0.05498030703634985, 0.06304073560562345, 0.050506472302180146, 0.05282688367691252, 0.027868830779146765, 0.02373900974259502, 0.04279048452454229, 0.05874875099247983, 0.052262728868593136, 0.047708531511166406, 0.046738606742433006, 0.08244449017389167, 0.030486777297131, 0.12203108008590438, 0.021603533908003764, 0.04488469311787237, 0.03294400622948043, 0.03386973155542247, 0.044612720413433934, 0.025160893827917117, 0.05664437258195493, 0.04941431437468818, 0.03178855028724478, 0.020306209973510236, 0.03640675812118477, 0.06643691445670782, 0.045494119892077106, 0.07520626929979171, 0.09851632534616417, 0.006491417776898391, 0.016791716503399997, 0.13012286846435842, 0.01876934183641307, 0.04516997276955555, 0.056056499691499825, 0.04640112585958935, 0.1977984168596806, 9.902940354039593, 27.679711311094223, 30.287905085471373, 20.132251324192172, 26.59352856297647, 52.17758417129517, 33.10424727778281, 33.61384945531046, 20.835391090762233, 4.231176905093655, 0.19397948387890093, 0.3518251744249175, 1.5626138088203247, 3.140350315840014, 3.935709172679532, 6.047846674919129, 21.995906676015547, 9.480893323498389, 5.160888462297378, 5.424617355869663, 2.207170157663284, 0.7020111045529766, 1.1284971549626321, 7.519438574391027, 17.194805952810473, 26.97616557921133, 39.156927293346776, 48.597283901706824, 55.67964492305633, 54.980862909747714, 57.94008724151119, 54.091826331230905, 55.82369396763464, 55.19368287055723, 56.72217953589655, 56.94517020256289, 55.45490880166331, 54.10414257357198, 56.23527219218593, 57.00617874822309, 57.92581765882431, 55.20577161542831, 48.346797420132546, 42.173218188747285, 43.542007707780414, 42.97957512640184, 45.56201265704247, 50.77551334134994, 55.06376612570978, 51.45861764107981, 57.30485546973444, 51.74319736419186, 56.41576397803522, 41.492698730960974, 48.69061669995708, 55.18737177694998, 47.65396564237533, 56.4583569957364, 52.28061699098157, 54.99185339097054, 51.36897971553188, 52.130798139879786, 46.291228340518096, 39.15197726218931, 39.56349272881785, 45.10053403915898, 47.81933669121035, 49.89735349532097, 50.406053527708984, 52.40498750440536, 51.7127715387652, 50.100697009794175, 47.69791187778596, 46.58895584844774, 48.73976007584603, 50.04594072218865, 50.01786831886538, 53.566020842521425, 52.04847935707339, 53.671512988305864, 50.390226764063684, 53.25988769531251, 45.95617555802869, 40.48714814647552, 24.706354679599887, 12.247584192983567, 5.309452154944021, 0.9059480613758488, 0.6038583262312798, 1.9110696979107398, 2.5255300681437216, 2.626323214461727, 7.299601983639502, 4.623440888620192, 5.12481197234123, 3.7951466248881434, 2.531195196413225, 0.9609224695351817, 0.15833581827821272, 2.8328200694053405, 10.820349397197848, 18.57069496185549, 19.734395511688728, 21.50495929102744, 18.238564345144457, 42.85463194693289, 35.4729470129936, 14.890734130336394, 2.406929361243402, 0.14467435618562086, 0.0698899025578172, 0.046901040365018194, 0.02062470145193079, 0.02754058125579069, 0.03024879016823346, 0.028511630258552974, 0.05361039244059113, 0.0539167165275543, 0.0515481565267809, 0.09899503070740931, 0.07758603716689734, 0.04463040172272632, 0.06293745546211159, 0.04313289901361831, 0.06637377348998863, 0.04709981719873125, 0.027666014746852943, 0.017623368147460204, 0.04291988060539288, 0.025849727530693336, 0.01267317132348375, 0.02625148893604356, 0.031635487835193356, 0.0460452665274422, 0.0369300076647872, 0.03728780519938277, 0.02307272009221056, 0.03156209086638785, 0.02611768784962835, 0.04821018886662299, 0.03193181638996447, 0.049533916021426844, 0.02969475729661363, 0.06579572184672279, 0.05359181863886695, 0.03702004214808826, 0.027303323825641025, 0.015651456872752358, 0.023928834838912855, 0.029720811946918408, 0.06001634688507165, 0.04395827448235885, 0.05690598394721747, 0.0581187087922327, 0.03630912787611446, 0.04880135210471288, 0.0351179109495734, 0.08712469750354368, 0.051584170320101326, 0.08725842581160607, 0.06887678192147324, 0.04516079503622267, 0.04355107576796605, 0.0240965582986152, 0.009998214457394376, 0.008745616651140153, 0.04058283746182438, 0.04347234108154813, 0.037715155856623765, 0.06819462659017694, 0.05470626206407624, 0.05282540129677904, 0.026743225452880708, 0.061649650170077244, 0.04361561867558668, 0.4373889524609812, 14.621000578326566, 32.84662796605018, 34.05484937852429, 19.712942108031243, 35.199255789479906, 55.93260642020933, 42.21096315691548, 39.80036858589419, 17.346030973619033, 4.285212457180023, 0.053318681480783614, 0.0779377481329345, 0.9480749298968624, 2.4207542452120014, 3.559057938475763, 7.561974717724708, 17.388918169083134, 10.323987180186856, 8.372771778414327, 7.515080821129584, 2.629289261756405, 2.1340623257621645, 2.5931144673978133, 8.800609207922413, 18.83043823703643, 29.49844767970424, 42.661208106625466, 51.99993610382081, 58.64774165614959, 56.450378894805915, 57.7602897151824, 57.28110551834107, 57.92780630050167, 56.436489782025745, 58.49997028227776, 58.28153348738148, 56.32014051560433, 54.48240810824979, 55.10825757057437, 58.35222244262696, 59.73584244328161, 56.059338200476866, 50.35110112159483, 44.27271781429168, 44.79650720473259, 45.20298634805987, 47.721724587102095, 51.80688881104993, 57.2066040192881, 54.40259179761333, 57.29715193471601, 54.09568202111029, 54.915076917217625, 44.2775462519738, 51.06507447458083, 54.998870511208814, 49.163897729689076, 57.66941232066001, 53.92840077800136, 55.573093737325365, 53.1696496471282, 52.90481905783377, 47.94813556055869, 40.88149932123, 42.925383660101126, 47.84442417083248, 50.72582867837722, 51.87643243420509, 52.45726093169182, 52.02578452325637, 54.00269831380537, 51.72866498270343, 48.947963406962735, 48.82963334360431, 50.52273619559504, 53.02085845701156, 53.249054108896566, 53.85389927894839, 52.67284224110266, 54.02531470021894, 52.03958342152258, 53.705292440229854, 47.69709210241995, 43.19492109360234, 26.76170999003995, 14.797217961280579, 6.011648101191367, 2.4176342448880597, 2.518775011262586, 3.7917672578365575, 3.863405181515602, 3.228596780569323, 7.286955281611412, 6.407510369054734, 4.002029097849324, 3.900164409029869, 1.4162641715618873, 0.1709495019167662, 0.31328816327356523, 2.476400665698513, 11.849085111771862, 23.465430505814094, 26.023013937857847, 22.407318199834517, 19.904604804131296, 47.34889545748311, 40.93921307594546, 19.81924814562644, 3.769295999119359, 0.2115835868302853, 0.024724895953230804, 0.022725318370747472, 0.03332661735194345, 0.07466034738407021, 0.05492858844058168, 0.0389443094571752, 0.04493018341881614, 0.07722524805895745, 0.0407280953931472, 0.11835011187940837, 0.04540653689013374, 0.0888441282234365, 0.022642103985192317, 0.02108931271058898, 0.024997115721024817, 0.039369974720982776, 0.018985083687209317, 0.052164773036155014, 0.028545259603209076, 0.030697478289385478, 0.026943948149921435, 0.03734667905636373, 0.024524200069267425, 0.016459552270750848, 0.043775654442968874, 0.054192971663489464, 0.019920038457419124, 0.07996762832326275, 0.0532976140628659, 0.08960698325667651, 0.08785946009260032, 0.1493978857873909, 0.08506432701382907, 0.19641454031150188, 0.10254951779760661, 0.08603941904561174, 0.12435563599630711, 0.12831016653968444, 0.14182988704452593, 0.12976145882519985, 0.16052774904716402, 0.2041482898376642, 0.19669066904292953, 0.1731483121552775, 0.11304847700821777, 0.1437526604821605, 0.24085310978754876, 0.1686894199660709, 0.17320831216150717, 0.22512118782727952, 0.14424769117707206, 0.14607888646423817, 0.1837427718865295, 0.11800359498949782, 0.14911974990560165, 0.15579491913799318, 0.21052463881431088, 0.15576248297527914, 0.1726220403948138, 0.14080409531391438, 0.19298225190610657, 0.17668411436100162, 0.2104545724127562, 0.15367236529146472, 0.18302877794110006, 0.8027389801798329, 15.2249583121269, 39.75080943876697, 43.017637806554, 30.731719309283843, 36.7000565990325, 60.181933602979115, 43.246755215429495, 40.41253289868755, 24.036105948109782, 5.82935594743298, 0.6975412573064528, 1.1528969940639313, 5.79110989647527, 7.489185823548225, 11.6776353697623, 16.05004260616918, 34.355095048104566, 19.080822736986224, 15.226212489989498, 10.421273727570812, 5.057362894858084, 2.1232745820476167, 2.6187765742501905, 8.802036950665137, 20.525969036163826, 29.56103890172897, 42.125153464655725, 52.86500700058476, 62.13874524639499, 58.306165972063624, 60.940398400829686, 58.298819372730875, 59.86768507188367, 60.33800863450574, 60.68988838503438, 60.311705220130186, 56.26102255236719, 55.2319142126268, 56.20075925703972, 58.48568501011018, 62.51745793127245, 58.495910629149414, 52.34015072545698, 47.159033129292155, 47.789954216249534, 47.34825611114503, 49.99362022646012, 55.42377302723547, 60.24266366035708, 55.4788980176372, 58.016691130976525, 55.153760986943404, 55.6237119243991, 46.96549946261991, 53.13783922503072, 55.0902303572624, 50.78091444507722, 59.365974703142726, 55.94775853618499, 58.15841028767248, 54.84123829872378, 57.086187254997995, 51.04294053969845, 42.54972257921773, 44.99726195489207, 49.406037407536665, 52.07162526346023, 53.76556750266783, 54.22274720284247, 54.282818302031494, 56.929547402166556, 54.875496279808786, 51.0755628924216, 50.37254079695671, 52.71156387944376, 54.27764469577421, 53.72075442344912, 54.72634815400647, 51.6387564136136, 55.4145868362919, 52.34125683384558, 55.90877017667217, 49.337058605686316, 43.463383797676336, 26.539921529831428, 12.952080119040705, 6.689079673059526, 1.6498502632302623, 2.157004759196312, 5.305684718393511, 8.566908509500566, 9.299273856224554, 15.692634274882657, 9.718155534036699, 12.880432144288095, 9.534599396490282, 6.463035441214039, 2.355330336478449, 0.6585505075993077, 3.6203770868239866, 13.298937274563698, 26.192730972843787, 28.82622599601746, 30.02159380143689, 26.439147995364284, 51.43717404334776, 47.76023833982406, 24.026111748910722, 4.0355163331954715, 0.22924559070698677, 0.1251539455786828, 0.14407967277351888, 0.1831640843902865, 0.10430389744860512, 0.21639860265197294, 0.1688993740225992, 0.2728828475359948, 0.1477339581376122, 0.1377209591408891, 0.12430089901411727, 0.1186302089462838, 0.17170334775601664, 0.14874546998931518, 0.13981991747934974, 0.16663714702571594, 0.16798514001552137, 0.11177661783632734, 0.1392768530715858, 0.14153848251988813, 0.11927128664308018, 0.12541200229597668, 0.11684992020168614, 0.16011159476493636, 0.14770567417144775, 0.08724506523820662, 0.1019790044595157, 0.12259692028765717, 0.16681592130372602, 0.23993078589199052], [0.09237642940734664, 0.0641571746898755, 0.07501911401988999, 0.04592237070262913, 0.021459373397632472, 0.04304206013799675, 0.07477558232964047, 0.03797091431014481, 0.06092929386443669, 0.10453762321342384, 0.042791928600279555, 0.03457917493858165, 0.034838028387316776, 0.027727951040311206, 0.05105849227777893, 0.04967823932548204, 0.02010729141353119, 0.04055363035971119, 0.055396051461538004, 0.05849360540929822, 0.04304030579665015, 0.06079918915225614, 0.04963729958680849, 0.061511340656227646, 0.02635746762426871, 0.03302762855685527, 0.019634772212274616, 0.042206120316780386, 0.0635182956654218, 0.057721112989970756, 0.01676771305351248, 0.06610536692483772, 0.04928666114386532, 0.04076083416059133, 0.06978946843094404, 0.02424979695088921, 0.03755185655468414, 0.7636221017568343, 11.908811042385718, 32.21010573448674, 33.829187577770604, 21.461118959611465, 38.3331040413149, 41.735269869527514, 21.431261877859793, 27.870756233892134, 18.293807006651356, 4.778895695363322, 0.38107214375369014, 0.3766113669881898, 1.7495500488627342, 2.2046279714953516, 6.872959896441429, 20.11886231360897, 9.418524695980935, 7.657701632668895, 5.247535580588925, 1.5339751133034307, 1.7131402800160072, 1.330169617168365, 0.8914447299415066, 5.46991337691584, 13.319174743467762, 24.834802496817804, 31.180465913588005, 41.50169664813627, 47.95385437626993, 58.868641699514086, 56.165485382080085, 57.09398492690056, 55.419109329100586, 59.4916513658339, 55.499894465169604, 55.69307119615617, 53.748383598942915, 57.267494893843136, 56.390119521848625, 54.60928893858387, 52.027490754281324, 46.717229120193, 42.867799343601355, 45.48852705186414, 46.129246219511955, 55.29031045975224, 53.22517864165768, 53.81364791624008, 54.983698783382295, 55.65596557432606, 50.832536758915076, 56.76073643469042, 42.26802972055251, 44.62347184458087, 58.93508272786295, 46.71856272605158, 54.526028786936116, 55.235091332466375, 54.396225790823664, 54.287670273934644, 53.49236657542568, 50.88021709072975, 42.5124639849509, 39.51317656424738, 42.85786790232505, 45.33597430875225, 47.16726226191367, 49.49924861231158, 50.945191152634166, 49.28757790596255, 49.14191676724342, 47.43027679381832, 47.78859315379974, 47.874210649921054, 51.10880105726181, 54.07161435773296, 51.8180283423393, 51.83924836497153, 50.58668651888448, 51.304429269606075, 45.94927610889558, 34.531652696671024, 24.310662054246475, 11.012745576520121, 5.246473598864771, 0.9055419734889462, 1.6536127968180565, 2.8708121468943935, 1.7463846961336753, 2.44424777165536, 1.5750398775262218, 4.302811641846934, 4.439037028820285, 3.400038677838541, 2.394555999386695, 0.6817263220587085, 0.07846899946490604, 2.066372512809692, 8.714710281741235, 21.24940118482036, 23.628726620827955, 16.837083831910167, 22.306013184209025, 25.601519961510938, 32.58437045158879, 24.974674217162598, 6.473874911185234, 0.5204350897862066, 0.04199226687271749, 0.042957066513237455, 0.023567164729860042, 0.013777221808390272, 0.07423736725843723, 0.042359571558453386, 0.0508479445031093, 0.022502471054453525, 0.03308379812346351, 0.012948322335198041, 0.014995287243847646, 0.023000671438151793, 0.04871788682536252, 0.024175507489651926, 0.07139129699358056, 0.04753984661111909, 0.028619796127801942, 0.02290321547808426, 0.07297716794475433, 0.053050171493762927, 0.03096848572303932, 0.04649837689113714, 0.022222287802686615, 0.01655431160132491, 0.06529771106978578, 0.06497786936139868, 0.016682707937434316, 0.01320247200407809, 0.025063246345868515, 0.04527136450633407, 0.009064603213881774, 0.1002547627074584, 0.07903627225107725, 0.033300420975372676, 0.03097097359357342, 0.03998632693002301, 0.003578077810215614, 0.004993562667345208, 0.036189353859592835, 0.06442851537177641, 0.019910299564681707, 0.08450204146004493, 0.019489077610834953, 0.05516573478798232, 0.050077217916447314, 0.05303453180878874, 0.03129199890780353, 0.03270933051563559, 0.048916851350617026, 0.06538891383717138, 0.033946895761595625, 0.0680994937917398, 0.04683341395350234, 0.019321970851911653, 0.016466994814935233, 0.0032718710304658503, 0.024785462864524415, 0.05921048367576254, 0.10051527090610997, 0.024806401962714813, 0.024162890021539023, 0.03281281750288702, 0.03680412792750905, 0.1016648164800098, 0.017925767949031248, 0.14317343672437055, 0.004464742706923356, 1.9984032309824422, 17.06124924844311, 39.53724030525454, 34.403803040904386, 24.334402199714418, 47.524456824025805, 39.24905984632431, 31.93558296849651, 40.689609127659956, 17.641756111575713, 4.520376199676145, 0.23900012695981612, 0.25544801937235945, 0.6065487657343188, 1.8452256052724778, 4.166850524563944, 14.054626995517363, 10.314483277259335, 5.862459280798513, 6.523738532297074, 4.260770697747508, 3.2720100639327883, 2.340967597499971, 1.8072846411697328, 8.233519792556763, 15.005286951218883, 26.005837878873272, 33.88393994300596, 45.20022107708839, 52.98621608364967, 62.276761685648275, 58.30893516540528, 59.03892355580484, 57.562908203371116, 60.78220528941001, 54.776213246007124, 54.97117073305192, 54.01408887678578, 57.43032816917666, 59.08568997536937, 57.02369213104249, 53.772792508525235, 47.33971711127989, 45.30099068918536, 46.6708549376457, 47.81100557696435, 55.319328154287035, 56.01465063710367, 56.328271588971546, 56.50966944233064, 56.27390361601307, 51.77281910373319, 55.486452502589074, 44.58041990956953, 48.131094517246375, 58.100500414448405, 48.19754339033558, 54.63326246507707, 56.94933968205606, 56.97943210601807, 56.123288523766306, 55.63865223238545, 52.28395100562803, 43.07106441067111, 41.36926958637853, 45.022012110679384, 48.085026279572524, 48.55865640024985, 50.30590757246941, 51.92970998825566, 51.6280601101537, 51.2197688318068, 49.375533134706565, 49.83903961796915, 50.35026173437796, 52.01130705495035, 55.80696898121988, 52.92908283971971, 52.93969285103583, 51.51302483774001, 51.03508795461347, 46.530359560443515, 38.280552125746205, 28.025205442982337, 14.349205820791184, 5.829920278441522, 1.8252372068743554, 1.679272084466873, 2.3488498455093754, 3.231188976956952, 5.822837948799134, 3.862769512399551, 7.700263761704968, 7.991336968637283, 2.4222091993977948, 2.949308334819732, 0.6144953651293632, 0.15142121592596655, 1.6210563889434262, 9.406361426076582, 24.436627011145315, 26.21675745133431, 22.85138345533802, 26.260199662177797, 27.081434149895948, 39.29028787920552, 32.29887289385642, 8.787364344443045, 0.7607241443568661, 0.049083314595683936, 0.04291812626404628, 0.019039793856321804, 0.07104183832604079, 0.03731496301629851, 0.03549949934465751, 0.014835410439709743, 0.05096044834522952, 0.03508426819837863, 0.0019763471631919064, 0.013951908049714423, 0.051747511756876786, 0.026846689457494407, 0.07067864370201865, 0.027904930757358674, 0.03814776187702533, 0.048750223396646405, 0.012622998310102811, 0.009883928503240309, 0.014572947759241348, 0.029345555268528483, 0.08014123916866318, 0.0012146709477453823, 0.10775343815405523, 0.016657825401653687, 0.036139408757369366, 0.01335724953547, 0.03936535521079937, 0.07130169534995671, 0.05268451389706424, 0.17216436414709016, 0.17191797494888308, 0.2588900064508761, 0.11456770597085839, 0.06437488921707676, 0.19110536713513637, 0.08390885191939532, 0.10845574925863936, 0.1545450466895296, 0.19941069486160434, 0.1808287266401514, 0.16923087558919386, 0.18947033632186153, 0.10602605544150838, 0.13166140284269087, 0.20762908693042495, 0.13738692948414435, 0.0989777401029583, 0.2122323254063245, 0.1926605715867012, 0.15440123666438366, 0.15925573665768872, 0.13378718958025979, 0.12123483894092422, 0.11062118104628979, 0.1293904424434708, 0.12016256865594657, 0.1700490574923254, 0.16357238164111493, 0.16901307679232092, 0.12681897639507247, 0.13754704186031896, 0.12957680099193128, 0.14979836591068776, 0.12716366999572323, 0.17990022807592349, 0.15910631886893706, 2.0456174136169496, 19.99860832768102, 46.25509938886089, 44.68910094230406, 33.764221360606534, 49.63406831987443, 50.83600805651758, 31.913129360445087, 36.3637133567564, 22.56549366058842, 6.05837578735044, 0.5375890241515252, 0.7772012860063584, 6.0548039790122745, 9.943546691248494, 17.02350231908983, 31.388351532720755, 16.77564186434592, 15.447637150364539, 9.155959275461013, 6.3478192494761565, 4.890235604778414, 2.7882001669176164, 1.8040973476825224, 6.4475195254049, 14.601410300500932, 27.629599109772716, 33.87111379254249, 43.66148702559933, 52.121231479029504, 62.7660773646447, 59.78331881184732, 61.24511165003623, 60.40927810053672, 63.87954019731092, 57.0002834258541, 55.80652967576058, 54.27291431734639, 56.80666738940824, 59.95465578571443, 60.17793278540335, 55.62091527446624, 51.14298843568372, 47.282258310625636, 48.99176843704716, 50.914412313892, 58.340392574187256, 58.12053195891842, 57.074333852337254, 59.07408760439966, 55.31761015615156, 52.1950073396006, 55.80424685632029, 47.09800497178109, 51.152535484683135, 57.66583511906286, 48.35238287525792, 57.976416234047186, 58.14403872336111, 58.340412186038115, 59.14922844979071, 57.334532122458185, 55.34547467385569, 46.55120695790937, 42.77629044748122, 48.153828574765114, 50.56072042834375, 51.55446075624036, 52.86222996250276, 53.74769718416276, 52.860931657975726, 52.69321895414784, 51.37887193310646, 51.82903059067265, 52.14748390259282, 54.546797736998535, 57.33895655601256, 54.0072992540175, 53.183609362571474, 51.845210367633456, 52.30652424596971, 46.822313339479514, 36.18057004867062, 26.84939849761225, 12.925803180663818, 7.281239407677805, 1.5357107621046806, 3.110049515962601, 6.062890435418775, 5.14575791935767, 6.277555871394373, 6.385375453579811, 11.785163225666171, 12.041701924416328, 8.762480828069872, 6.331961106869483, 2.4413332054691934, 0.41878882795572286, 2.915150619322254, 11.673580619596667, 27.94247873367802, 31.528307584024247, 24.371423490585823, 31.5591727149102, 37.939553030075565, 43.06113296939481, 34.370286387781945, 9.852895813603556, 0.9604079648852349, 0.08541176320924874, 0.10382958177116611, 0.09634825821605422, 0.18070178587109814, 0.1907290647467298, 0.24693240051067647, 0.1648669936243565, 0.12772394839914578, 0.10324752348805628, 0.12320029113682048, 0.11044665089538021, 0.11258523130128462, 0.0961337919016519, 0.09670179247135118, 0.13953664880846778, 0.1156066437702506, 0.10566757225822057, 0.11146697275821241, 0.09332852347964242, 0.21431789252786868, 0.138753860167438, 0.2185107377027312, 0.18400780766481356, 0.1629274122176632, 0.09100052017358043, 0.15962206458132114, 0.22588699995990724, 0.0990831921057355, 0.15422088424524955, 0.138392373919487], [0.01120551635751561, 0.051868178265830206, 0.06275539083646671, 0.012344056120773238, 0.022905159426192125, 0.036519909307600996, 0.010374272655275081, 0.06865077832293126, 0.013471531659184445, 0.10068367235362531, 0.06266224603619307, 0.02446784089589792, 0.033255620153560754, 0.04677593054610395, 0.015568480932063635, 0.028179803104590506, 0.029163245494747837, 0.05136089016413016, 0.02580248480362277, 0.015478325789914498, 0.030548805521140178, 0.04391977856416376, 0.035391013633700154, 0.06390330464308781, 0.025872798268533042, 0.07418840657919645, 0.02579680043122461, 0.059278527605197126, 0.017857203079808145, 0.03924220657697128, 0.02611339584203257, 0.0452741798794558, 0.13773199080699874, 0.04517701694801931, 0.03946486620172378, 0.11605517292815833, 0.032270388948100234, 0.21614363326901392, 1.8076115462087818, 16.975792569498864, 31.199463913517615, 27.80830817837869, 20.227817912255567, 52.31725585076117, 21.60323819806499, 17.175362763866303, 29.949135857243693, 16.370388461697488, 5.132119838268527, 0.7258638343022716, 0.03993401844655314, 1.140761793621125, 4.3210781197394095, 9.48357230232608, 8.666312156185027, 4.561094324434958, 5.836504957368297, 2.0480909583068665, 2.4260555736480223, 1.024082067512697, 0.4716249008572871, 1.2595396200495383, 3.699544490345063, 9.764732699240408, 18.85393911792386, 25.338393642056374, 31.546956493008523, 40.2341317361401, 50.610295264951645, 56.152953409379535, 56.87382621149863, 58.61161270449239, 56.05643564654935, 55.1219819438073, 54.4169633619247, 58.2279460660873, 56.20653690830354, 56.458047128492794, 49.720952741561405, 46.48969634886711, 45.08208713223858, 47.80280390093404, 53.79398507456626, 54.48385546284338, 54.85939102788126, 57.07067035859632, 55.806160972964385, 53.69599250055129, 53.65648638817572, 58.80817444093766, 46.547547386538604, 43.998246039113695, 60.151962772492446, 49.378843615132, 54.45030743075956, 57.586336520410356, 55.56644139751312, 54.183731386738444, 54.23852297567553, 49.18760453501056, 41.476817054133264, 39.83190836444978, 40.591844051114975, 42.215026732414, 43.757353674980905, 45.30793328439036, 46.48066705273044, 49.429269606067294, 47.23839444498862, 49.091604525043124, 50.10237578422793, 49.69851678417575, 50.262326117484804, 54.01474391260455, 54.196333962102095, 52.58539692048104, 49.86357012102681, 42.35438069989605, 32.853839243611986, 21.731646791581188, 11.365486287301588, 4.754156326093982, 1.1884312163437567, 0.6681965351585419, 1.1387588107778182, 3.1835596359545186, 4.01693434965226, 5.51278341201044, 2.8730417691892196, 4.181922722247339, 6.4571239390680875, 1.0930609919371144, 2.1230519875403373, 0.3960861187548407, 1.4626366380722293, 5.551028972671879, 13.859496924184985, 21.579652986218854, 18.63024046344142, 19.55224064088637, 21.861849869451216, 26.885311718909975, 16.79289048717868, 7.468773809171493, 1.424412773020806, 0.10104741856095292, 0.05210908993537869, 0.011795126352339022, 0.02523535757415718, 0.052487713570195826, 0.01370927268233631, 0.01667772453548687, 0.020640092158329584, 0.031637087043735294, 0.016628922819490397, 0.05954049903178408, 0.04102556733414531, 0.03941871706516512, 0.08372826967388393, 0.03145156927677172, 0.053331636027583194, 0.04092248637349375, 0.02757000286252268, 0.05463983458016188, 0.05415595812542785, 0.05334151090092717, 0.055375271326591896, 0.09178449625089284, 0.059443236508917426, 0.009793132720064494, 0.02712573698391357, 0.06839412354653882, 0.01459767133177769, 0.008691562444812829, 0.03407701579553466, 0.0455099396077135, 0.028074996530889507, 0.027510498898224007, 0.020750889539598458, 0.03399223667539416, 0.10843518745875168, 0.020750021945024212, 0.04446527913152691, 0.014930964586505247, 0.025925296358764175, 0.035045806754140124, 0.004233984575201307, 0.07427909606767279, 0.08484208490699531, 0.018561337473652056, 0.041622407283754125, 0.10805395912499198, 0.05240827025244794, 0.0649745062354111, 0.03449629571649336, 0.05960016195932704, 0.008428131620730124, 0.048152755254939686, 0.04968936292214259, 0.07710717092718809, 0.029479762381543557, 0.05530460354601664, 0.05144756918232288, 0.03816363904925604, 0.06067238627902924, 0.023652131541541988, 0.02975778909580362, 0.018145863094457218, 0.11271153621736074, 0.05316094014673464, 0.06361293433714779, 0.13503729185510066, 0.026423339694437963, 0.17239912413060668, 3.41419622782738, 22.016004900778494, 37.44440478663291, 29.651025918222246, 28.614984789202293, 48.37939231626449, 20.141743460009177, 28.062061994306504, 34.059666049095895, 15.266486406326296, 5.370436676086919, 0.4287670005954081, 0.21690201434877612, 0.13698287939112033, 4.110220079460452, 13.867454432672071, 9.76694001305488, 8.107516102252468, 5.919210093636667, 4.862383344481069, 3.648068039647995, 2.6937901877587844, 1.0893596228091948, 2.2834796242175566, 5.678592785712212, 13.713122894687038, 21.449846067736228, 28.609046320761408, 34.92463888660554, 45.19685568348054, 55.23254179185437, 58.00702248850177, 58.26420445596018, 58.545544301309896, 56.78739286238148, 56.75431943708851, 54.83282873707434, 58.72856209355017, 60.086608240681315, 58.0428925637276, 53.073700627973004, 48.020471911276545, 47.53653772415654, 50.50008843022008, 55.195138069891165, 55.562966177540446, 57.107791669907115, 58.71666554481753, 56.55593772088328, 53.659675275125814, 52.85183175917595, 56.28485879590435, 48.827354446534194, 46.346423933582926, 59.8506502182253, 50.06798444255706, 54.839892925754675, 57.76496910279798, 56.43780377603347, 56.408201648342995, 56.9029615771386, 51.65177868258569, 44.53982337828606, 41.297909905833585, 42.88897622016169, 44.71560831992857, 46.23143965198148, 47.00101260216006, 48.60734085882864, 49.86391528960198, 48.90208736542733, 50.61138176148938, 51.98585479490219, 52.240589203373084, 53.87315027175411, 55.87230782355032, 52.80116650366014, 51.28600981927688, 50.83726713734289, 45.03282608524446, 35.743288532380134, 25.58310247236683, 14.432059026533558, 6.400024035284597, 2.190181637002576, 1.6000585930962719, 3.896701691612121, 7.80633936005254, 5.15407040234535, 4.630772779064794, 5.643253211052188, 8.165710837610307, 7.291836180994588, 1.6787934327317824, 0.6651765552739943, 0.06573307883715437, 1.2968754359791357, 6.487488967757072, 16.221149140788665, 24.819591545289565, 23.413563043840472, 17.33429524206346, 25.751289782985566, 31.983735945916948, 23.9267659571863, 10.932497805164708, 2.545941347076047, 0.10127003605086958, 0.02817511656171372, 0.05088201243310206, 0.07732860864170137, 0.027237800325477318, 0.037330162200716235, 0.05784585891712097, 0.05496034661548273, 0.02042191606315394, 0.027982972134205124, 0.05454830239496885, 0.02678450227024094, 0.08193252893585352, 0.010316983642687481, 0.02968224899602994, 0.05442988818451282, 0.05008021715067087, 0.07125391444611935, 0.01242037571500987, 0.060556488667404464, 0.04961198804179027, 0.06128268639346766, 0.04140301119355906, 0.0632727989596465, 0.04911069840853734, 0.023008332317394596, 0.09554202728454145, 0.031818636475251086, 0.02276426436559808, 0.04283670260901413, 0.06710960860213927, 0.11862524469653446, 0.10133382819232442, 0.19521899881862825, 0.10805180641792475, 0.28779125562117946, 0.15573183945830793, 0.08961905680236318, 0.17153010463281987, 0.14118091864210947, 0.10904700825771979, 0.16868722895460744, 0.19666753318761626, 0.14935916770369778, 0.12208188703704266, 0.1058650007771869, 0.14683435640988812, 0.14536455544012208, 0.20189179317845454, 0.13305162259888265, 0.13688440644933333, 0.25361038894662935, 0.10624741654722922, 0.1722211619057963, 0.13676837477232182, 0.225968174636364, 0.2567675445348986, 0.07457505881546006, 0.1301320155541743, 0.1445203418693235, 0.18663895196251332, 0.10440047815321915, 0.09326069405482662, 0.23326957478157936, 0.21222385247388195, 0.15725785595995767, 0.21996078892580925, 0.13415414569599016, 0.33309417145867504, 3.605168586777103, 25.04647320316684, 43.64541707500335, 41.35609042259955, 31.84757871012534, 62.70495899261967, 28.633396394791145, 25.53242741092559, 38.07908350421537, 20.46245017359334, 7.229960791526302, 1.0700654839315722, 0.7049965798374146, 3.9797931813424636, 8.824550374861687, 17.553747930834373, 20.83051754582313, 14.059537802973102, 14.751670418247102, 8.662938917836836, 5.348275284613333, 3.38283246563327, 1.5841182032900474, 2.3412455954859337, 5.046814170575911, 11.233859389059006, 19.96274217482536, 28.543042636686756, 33.995127370280606, 45.85061280958114, 55.03876101586127, 58.22789899764523, 59.07390325300155, 58.9119250543656, 55.36980905840474, 56.59167443552325, 54.08550739288331, 59.26780954484017, 60.480857433811316, 60.470231733014515, 55.84737723873508, 51.01404051626883, 49.22319612195415, 51.71919638110746, 58.721772470781886, 58.22225470696726, 60.07682584947156, 61.805881146461736, 58.14019872296242, 53.57667399990944, 53.27405529637491, 58.56004922620712, 50.94548925276726, 47.57733821868897, 60.27973005848547, 49.962311867744695, 55.879293564827215, 59.642666539838245, 58.3831738656567, 58.97697364130328, 57.579935212289136, 53.05999194422076, 46.37692036167268, 42.77044611592447, 44.581918254975356, 47.87823107934768, 47.35315907386042, 48.72854209715321, 51.88907423327046, 53.842340054050574, 50.0930719221792, 52.82608924373504, 53.33693481260731, 51.67117872545796, 53.39966135640299, 56.840819466498594, 53.47660649207331, 51.73844345154301, 50.02917651207217, 43.68649605781802, 36.02797808185701, 25.426386133317028, 14.395471157566195, 5.498946760931323, 1.7939461311025007, 1.6185606583472223, 3.0037407817379123, 7.421622016737539, 9.91855138732541, 11.735712924311239, 7.030843630913766, 14.092778909590937, 12.685865913667987, 4.852555846014331, 4.596307402656925, 0.9160811369938235, 2.0270831113861454, 7.710998308274054, 19.361187873348115, 28.28361118993452, 25.684485935395767, 25.96940298234263, 32.762716700953824, 39.606889832404356, 26.728595379860174, 12.433134855762606, 2.370941860060538, 0.2896025939093482, 0.18433374743307793, 0.12724880534674854, 0.3228587158504994, 0.16233591573132625, 0.11140917142432545, 0.11337285395711662, 0.12516109317901636, 0.17938823619436833, 0.13692514700514657, 0.16839898071221768, 0.14181632728826615, 0.1595462984856098, 0.10567597624274994, 0.09476188164685043, 0.21113167156375226, 0.14473737457827215, 0.1265049186505137, 0.20802808084314872, 0.22874352732493033, 0.11472886022661002, 0.25017014854858, 0.18532786908889973, 0.12215066641088455, 0.08275371390364825, 0.13402680656121624, 0.15909686534395143, 0.1994075385793563, 0.1507921198443059, 0.10509785565157091, 0.16912838834668362], [0.01837615678537517, 0.0488094802975895, 0.06284093987497111, 0.027691885536055894, 0.029067833074218327, 0.020268650597802574, 0.046950862893173774, 0.053925534199562766, 0.0582539577848248, 0.04587039929784594, 0.07467106495413088, 0.03161913185800997, 0.019917359064903953, 0.017238763281174244, 0.055438983028814684, 0.06179269793773852, 0.02057108678855002, 0.030953926222038367, 0.03236337286990977, 0.10139902227468069, 0.04831145802933363, 0.03546686399908316, 0.036773817658784895, 0.04479484249567313, 0.04434994842496611, 0.10497770242152676, 0.0897565312803753, 0.017523016375038895, 0.04522194034389911, 0.0433596189043695, 0.026595418363989844, 0.02264498447578761, 0.02850693030913751, 0.04759598936464998, 0.1251214404680556, 0.0176497656221111, 0.0373637666475148, 0.01966491202643562, 0.09436684074781596, 4.188509852655472, 20.881061207863596, 29.283019342730125, 23.393531499370454, 30.351953468015118, 27.33013399185673, 21.90276803508882, 19.842811784436627, 29.931687193532145, 16.3274424306808, 5.3930064843546965, 0.3884157093782579, 0.34794447943568235, 3.0720152729941956, 11.463498473167421, 7.180585505500917, 4.484633111184643, 5.8962465774628425, 4.086116624455299, 4.03718015359294, 2.6317409882622385, 0.9647098243717225, 0.9322203419381573, 0.6745185378578402, 2.3784478056815366, 6.391124667659883, 11.640665069703134, 17.725857611625425, 24.297324034475512, 35.16628826818159, 45.654517835186375, 52.451510737019206, 55.38474152165075, 56.63844085508778, 56.55092493180306, 55.047233335433475, 56.731565767718905, 57.17136544566001, 56.22582712481099, 51.24655862008372, 49.1492162981341, 53.1320615737669, 53.97281377546249, 54.03818791912448, 55.89397891875237, 58.33518366659842, 56.777171165712424, 52.565839982801876, 53.889384961897335, 54.326607642635224, 56.32500033224783, 48.10492054108651, 41.5302554253609, 61.00832992984403, 50.56603916229741, 52.84987449645997, 55.878669907969815, 54.89787732401202, 55.05691374501875, 52.34437119576239, 47.96383680835847, 45.26805062447825, 45.48914678635136, 45.70579498044906, 45.562149939998505, 46.24599164532077, 46.77575872790429, 48.039762127783995, 47.46079675612911, 49.089341317453695, 51.902602487994784, 51.00088488671088, 51.226111304375436, 54.52680541623024, 55.86878553513558, 47.85988615405175, 41.76620952544674, 33.913192979751095, 25.02436084132041, 15.017391385570651, 8.873085783373925, 3.2817988289940745, 1.1309467977093113, 0.7260780937729344, 1.0452084435570625, 4.151194384021144, 5.465377646107828, 1.7253075948645993, 5.1439433328567015, 4.993845993472684, 7.96977520950379, 6.085734319302344, 1.4060342624302835, 0.45055408150919024, 1.5106106573535552, 4.185635245615437, 11.300520070137518, 27.82364856812262, 29.197819579032164, 20.259340040145382, 21.45683180901312, 24.555151231827278, 20.552962787689705, 7.011699522695234, 1.8029846202942634, 0.06451083918011959, 0.032646354257820115, 0.0559621406418662, 0.022352894302457574, 0.03758667142040307, 0.02624501932352301, 0.050183612207371386, 0.07913499034100002, 0.026870643111666846, 0.042098580724409515, 0.06561842611840656, 0.04819051955916709, 0.0051476579016795565, 0.08398562159028747, 0.060784828834115505, 0.08905810424156728, 0.04598149353818548, 0.03100809246872462, 0.11289400303916586, 0.030146078845005364, 0.05932534706868953, 0.04986765456476039, 0.029312127021952506, 0.08404332333274427, 0.03861035257878323, 0.04035043319867503, 0.06096856353143531, 0.02786515164189041, 0.07515245928399025, 0.03857661406659792, 0.056417284969000094, 0.02140872540973848, 0.022177651689778415, 0.00841677149442295, 0.033588711352598284, 0.060495174820384676, 0.041816070480572606, 0.022168452889027617, 0.08786988654924978, 0.025667672481147513, 0.03734228554211798, 0.02982843580896095, 0.051795710178632895, 0.07795473230221579, 0.021852424383283626, 0.02751277226413931, 0.04775471895212128, 0.01698106854042459, 0.06310089265987759, 0.04758646689175118, 0.025191696308132623, 0.07126128421195092, 0.014516339607296452, 0.02391179895869667, 0.06548331119120121, 0.01279759645131567, 0.01797784469090402, 0.03229368185143798, 0.05228758459129641, 0.07258716024338238, 0.026742149099347093, 0.10229182880251639, 0.046916454054054715, 0.018353068810557167, 0.00952420808795479, 0.04743620640628281, 0.09907187698709388, 0.04610827725921427, 0.045759013944095185, 0.05405632839087517, 0.07722460454510105, 6.896675527095796, 25.895329021638442, 33.84671272770051, 25.74606126354587, 41.31973397347235, 22.92300593468451, 16.36607777687811, 29.606636454982144, 33.743915250224454, 17.077329004964522, 4.814428446754333, 0.44264217057535726, 0.339843436715103, 1.2358154092104205, 3.914778179699375, 7.4376032237083685, 6.130466499636251, 6.550603335903538, 4.711521633209721, 5.289653010906712, 4.7605792072511495, 3.6641816266121405, 2.432072489492355, 2.7139761755543375, 4.679887717769993, 7.407269573980763, 14.163026598192031, 21.625738874558483, 27.82875353290189, 38.35757570881998, 48.45024601105721, 55.612439032523866, 55.711867194021906, 56.23324432680684, 56.963319009350194, 56.375932308935354, 58.005477074653875, 58.686439760269664, 58.45734980798537, 52.6600553143409, 49.35312855628229, 55.32908701127576, 56.65124739370039, 57.56242182946975, 59.03025119535385, 60.54278381409184, 58.02563413496941, 53.54283963480304, 54.45563400945356, 54.55926695177632, 57.31990560408562, 50.08354056266047, 44.336679904691636, 59.26125134191206, 54.46946820905132, 54.69596155228154, 55.52236180151663, 56.76104630193403, 56.47955740651777, 55.28633709876768, 50.30420134144445, 47.464679902599705, 45.75042763063985, 46.39826197778025, 48.00468437133297, 48.237049502711145, 48.72917752112112, 50.03042382578696, 49.3446405472294, 50.33535672772316, 52.78326872856387, 53.20755543247346, 54.306662390309, 55.92744850343274, 55.51580752095869, 50.776717508992846, 45.71999396047285, 38.04080117133356, 26.953054974156043, 19.11639863444913, 12.47657020245829, 5.515752646230883, 3.569031054935148, 1.671804014232851, 4.4055816627317865, 6.359289730748823, 6.688895321661427, 5.221575373603452, 9.028709742330737, 6.680862307548524, 4.122092848823917, 4.931499919583721, 2.0137014552470176, 0.35702804524090986, 1.31987486635485, 5.2034265668161455, 10.851691096059739, 26.709440485123668, 28.30813188706675, 21.41021247833006, 24.235327051531886, 27.642166383804817, 26.41332114896467, 10.053666253243724, 3.0304881593873425, 0.15053134351488084, 0.03509317397049839, 0.06822430483636356, 0.05080896594952192, 0.029120775495445537, 0.023330299919771574, 0.02199102884098407, 0.039145863359613765, 0.01617563434035307, 0.0037345383410161783, 0.055723347205428354, 0.041242508112543055, 0.09849492851043902, 0.03174060850494331, 0.015048185615019213, 0.055170327485088384, 0.06489137803474743, 0.025314877500697493, 0.0495409601998906, 0.036593070704369776, 0.0731137001346196, 0.015109229416045693, 0.017655381046596075, 0.041631301564555016, 0.011167123861190294, 0.01510036290593205, 0.04953251791096503, 0.016380957395379103, 0.1075172609078788, 0.032148282193849166, 0.059376253611257965, 0.02492396006991546, 0.10481808800250293, 0.0887941409863772, 0.0791583407009321, 0.14999854468530224, 0.09757650400241537, 0.09628642725968554, 0.15470584854483604, 0.1012100820099154, 0.16603207546136073, 0.15536013359744705, 0.156948187899205, 0.13612251668687791, 0.10471023048364347, 0.06563029282035367, 0.09768830687408486, 0.1257916754712501, 0.2246983992236276, 0.1930471701968101, 0.1005787029862404, 0.2308201618612774, 0.15621752388054327, 0.11982011969291395, 0.15951806048472084, 0.20566168121032177, 0.1285313361234242, 0.256730925532118, 0.1679199612549236, 0.14490404466707862, 0.1239357278832505, 0.15825750877059278, 0.13176632624480034, 0.142603314091121, 0.09720139671117069, 0.15267467366591578, 0.22129614146486407, 0.09990510485705831, 0.16489365348412147, 0.14086239460495212, 0.3342597589137093, 6.921717409164676, 28.566980861848403, 42.04315631620346, 35.79763297111758, 42.710057304751494, 36.38569824157223, 31.410152066138487, 30.87334432909566, 38.21862574546568, 20.532697862194432, 6.95438486914481, 0.6926842598665146, 1.016480023822477, 6.322836202959861, 17.483861100289133, 17.411040336855, 9.768895314585778, 12.615766294540899, 9.782678523371297, 10.43095805952626, 8.880406887300554, 4.33368657865832, 3.1179097006397867, 2.0218777584452785, 3.6830411178450433, 7.45558483946708, 13.107771738882988, 19.476860530914802, 26.590361249062326, 39.80498913795718, 49.52446160777923, 55.905961759628795, 56.242948270613155, 58.04929387184882, 55.63341586820541, 55.3377515269864, 60.38507315420336, 61.199066946583415, 60.195642286731356, 54.88725554558539, 52.636517170936834, 59.59147568671935, 59.097951304528024, 60.610311338978434, 60.374800466722064, 62.082976987285, 57.3601608891641, 54.42184279041906, 55.13126619400517, 54.83202465118901, 55.71111409894882, 51.06232097071987, 46.28707062813544, 61.216309685860914, 51.90378312141665, 54.73564417131486, 58.00300990381549, 57.34826826280164, 60.04908684761294, 57.19453880863806, 52.40010807591101, 48.93303094371673, 48.30761686448128, 50.57457816216254, 50.68005854083646, 50.71404587837958, 50.684353536175145, 52.08458085213938, 51.37078400581114, 52.199208198055146, 56.63885270395587, 54.822599195664935, 55.36545914988364, 56.96441335062827, 55.88186663966025, 51.128271702797186, 48.54749333473944, 41.94765052487774, 31.041904264880767, 19.23311072011148, 12.511323382777553, 4.7958962282826825, 2.35313160284873, 1.7740966091232917, 2.9034229776551648, 7.076746148447837, 9.63716055116346, 4.747258838145964, 14.508055929214725, 11.450360494275248, 13.175191398589844, 12.003922635509122, 2.6521865879335715, 1.0371239483356476, 2.252921909093857, 6.646732784086659, 16.509446290231523, 36.91775598833638, 37.7069172551555, 29.083786472197506, 31.802173353010613, 36.56496232555759, 29.197813695476903, 10.667432854252478, 2.6735997872967876, 0.29508566904452543, 0.1788047223442024, 0.1185878289623126, 0.08699731240349431, 0.14815411139880458, 0.0634179458082203, 0.15241716087104815, 0.16756523190246475, 0.1255084144612474, 0.1372119396804802, 0.14730087331225797, 0.18161687789665115, 0.17362560025386273, 0.1291567549830483, 0.19588701216684234, 0.1615510586529009, 0.13849763440028315, 0.09595935368129323, 0.21549857191501126, 0.14089624036944684, 0.12159455552577011, 0.26383544108079326, 0.1408083394410149, 0.15429681888030422, 0.11107173267631762, 0.13167241918704203, 0.2831298251065516, 0.11624016017923433, 0.2319202334770272, 0.11308516495891156, 0.14194676141825416, 0.17365284234045014], [0.004738126928362275, 0.040369991423381914, 0.04976145945669663, 0.015744246399751114, 0.07700241606442199, 0.027076121299497546, 0.07385315884265208, 0.05096614420894654, 0.06484305320848381, 0.014962303328267751, 0.02897913349912532, 0.07456872326832625, 0.021590069912734534, 0.054264382549351266, 0.022507726417614088, 0.023864950766907107, 0.02362211621666868, 0.08577455946755025, 0.029624388290328846, 0.04192556359715039, 0.06365256789591044, 0.04962850489743775, 0.007334351023253535, 0.06468418189474652, 0.04675166471110237, 0.06020601876380463, 0.06080166744669119, 0.01697671907623449, 0.042183857801700794, 0.03607084771858589, 0.043925118196995995, 0.05306845418207588, 0.0026243809383407596, 0.0529122680065132, 0.03675974079317624, 0.06128324180721276, 0.0854743602535417, 0.12633836347489588, 0.04182219535352723, 0.0448708116046844, 6.917746989957749, 19.60323145312648, 26.47790297385185, 24.09083477912411, 23.557517951534642, 18.605960992074785, 8.71748241686052, 16.489536339236846, 27.029333306897072, 17.384789874476773, 6.064249536683483, 0.9119024031585263, 0.5488248986582602, 5.77324350034037, 4.899474747719304, 6.478754339679596, 2.984049502880343, 2.0247881571131368, 3.1265104778351325, 2.2641065476402162, 1.5791589790774931, 1.48197318757734, 1.6899363960950606, 1.7633201422229892, 1.9891385926354317, 3.252695577759897, 7.514191423693012, 16.494311824921642, 24.343478564293157, 30.213329061385128, 35.54255339407152, 43.91271875750634, 52.3347496217297, 54.83482522349204, 59.42188808994909, 60.11685363708004, 57.751621277101584, 55.96739784363778, 52.490663836079264, 55.46758197969007, 57.039707168456054, 58.35434444489018, 56.90110629604709, 58.0229433890312, 55.51880028940017, 56.454783716509425, 55.18217071410149, 53.48715374546667, 53.14353058415075, 57.18845129013062, 52.40319105886644, 44.71836966852988, 59.41251362523725, 60.329928551950765, 56.674283473722404, 54.36372895394602, 56.10885420153218, 53.40069686212848, 53.25179584564702, 51.02592529789094, 52.8384643216287, 50.40383738856162, 49.130341852864916, 47.72943204449069, 48.62813726548226, 48.75920718716037, 49.719015090696274, 50.296678235453946, 50.903315928674516, 51.68320471240629, 53.203056473885816, 56.24447407261018, 51.30827319237494, 38.93995354252477, 37.37091133671422, 30.323508439525483, 18.64312348827239, 9.578212230436264, 4.7986639507355235, 1.7488437770835816, 0.7945145053728935, 2.850147629937818, 1.3909081321570183, 6.349086175041815, 11.983221346332181, 10.984303489808115, 6.027892106963742, 3.366669603893834, 4.789108076403219, 3.630892961255966, 5.494922899430798, 2.7138026106742124, 1.3443565849334964, 2.6039546728134155, 7.909873752824723, 23.652880576349077, 27.296478094593173, 26.378396364950365, 21.34127486136652, 25.270695494067287, 23.121781849092056, 8.071367538744404, 1.341604674535413, 0.05812539673981167, 0.05658275613020505, 0.013643537550383519, 0.021288468757824554, 0.030699822518433777, 0.03495713207690466, 0.03176382671470844, 0.025924771588536042, 0.02718137603463425, 0.06732333947213427, 0.024179232592183738, 0.06369809650125043, 0.04059882954724374, 0.06004870260855364, 0.02231447690827472, 0.07729653254031174, 0.09132741755175014, 0.07196674393790384, 0.04680241420564633, 0.057435925268838485, 0.006507340435599608, 0.04100710844560977, 0.04464169385873022, 0.05010175188222239, 0.016331962242181745, 0.05171191548147509, 0.028815857179823424, 0.07564745933538483, 0.028212492076319554, 0.03986700873581633, 0.043990454005618254, 0.0737788176704799, 0.015455245475975737, 0.010399918406150274, 0.07416326357352157, 0.05962919669165727, 0.07424453784140848, 0.04367869835527193, 0.04478110653919078, 0.0519946747038874, 0.036556926676102226, 0.04222165274944517, 0.04202266907199256, 0.06844776502299695, 0.0720276785714011, 0.01764067024323008, 0.019792628459512226, 0.047143124149090825, 0.015182659901197881, 0.009108931934010358, 0.031479182916002414, 0.09402069158010906, 0.12496929540629349, 0.12251556941097784, 0.019043729633032795, 0.025428511322506016, 0.05802250730114118, 0.04407489987751169, 0.04820699044953912, 0.0773850999652378, 0.0945414704901557, 0.06562486891784976, 0.03339889008672007, 0.06557614572586552, 0.137712562817239, 0.06023962704104282, 0.05214953554734107, 0.03108148752231031, 0.03462682943791151, 0.021551156476620707, 0.10191971691505564, 0.05213265863036917, 0.09538969836167752, 9.48862627629311, 26.286734496393514, 30.991554760163833, 29.51856551631805, 30.75949949602927, 19.80497464056938, 14.495523956514175, 30.435719605415102, 34.09319054695868, 17.07172393798828, 5.502989253690166, 0.7440425491621419, 0.3154738734085714, 0.9320120273097869, 2.3873243745296233, 3.4807338445417346, 5.136666845890784, 3.085480279499485, 4.669664059915851, 3.3061511093570344, 2.985028869682743, 3.3419378342167025, 2.763748356411534, 3.9123149312311605, 2.6246017842523517, 4.6133407854264785, 9.062550971584937, 15.909544287189362, 26.980650809503373, 34.2497911760884, 40.55985712235974, 46.34313698737852, 54.41137398442915, 55.19063911130352, 60.40897215566328, 62.15959656623102, 59.990569007012155, 57.15692327868555, 56.2353467172192, 57.20457223153884, 58.07579732710316, 59.53864136049825, 58.82114179672734, 59.91291784471082, 57.96124842859084, 55.291891174931685, 56.3077615153405, 54.66793229503017, 53.01082111174061, 56.90181624504828, 52.338875955150975, 45.832385555390395, 57.657613831181685, 59.62554931640626, 57.252946822874016, 55.44121580739176, 58.467206724228404, 56.996278685908166, 53.969507217407234, 53.2341726364628, 53.93470402686827, 52.43940238029727, 50.22874670643961, 49.40340941952121, 49.98018610861994, 50.39727134089316, 52.51251536030924, 52.33965650681527, 52.384049892425544, 54.414103954069084, 55.84290573673864, 57.88688813486407, 55.402443178238414, 44.63498792340679, 42.574798291729344, 34.3300546369245, 23.75962591940357, 14.156398773193361, 6.9942317374290965, 4.166442107769751, 1.6606344522968417, 3.2954810367476557, 2.1187430187579124, 6.563412816293779, 12.072430752938795, 11.839356653151974, 11.147103424995176, 7.696498286339545, 3.7607584701430414, 5.324881288313097, 3.547117017930554, 1.0015338322808667, 1.0915760071046892, 4.177408564475275, 6.939643621444703, 23.29293643274615, 34.79692259142476, 31.475914524447536, 24.732726735453454, 28.645840114162816, 27.18578684714533, 12.18211885421507, 3.081573598807858, 0.2944899590746049, 0.03422591647493743, 0.0771072092315843, 0.02915410223537155, 0.04547636197399228, 0.00905877711521762, 0.0114712713008386, 0.02378197961426791, 0.035940233557935686, 0.06307792917434728, 0.048638083446290226, 0.023975351697675163, 0.06333829181629323, 0.04026887547825614, 0.051827115953088775, 0.010481640835472894, 0.0353893588837837, 0.02393314216826712, 0.03937664351636364, 0.08813309903827407, 0.03682964248582721, 0.04485307666923731, 0.036424696069931796, 0.10421877741933831, 0.03212258377442918, 0.08194688542355454, 0.08051310590798817, 0.05422779419008763, 0.019828031297713038, 0.0396031259198583, 0.022480220030692798, 0.08518144653569307, 0.06428811443789352, 0.1529717012759178, 0.12621175212365005, 0.18546977921599345, 0.12407422891908115, 0.07903540657172281, 0.21637998671541292, 0.21109969505379278, 0.08120683682782036, 0.15398793222923435, 0.1882667049405075, 0.20490290176483894, 0.1781554781501332, 0.1337748095994034, 0.14569176691434077, 0.1610609615642217, 0.10767547338600121, 0.06787418733320891, 0.13995242004673328, 0.18927794100055773, 0.23765103080339972, 0.19233812517937154, 0.12516362893004573, 0.13520613763361208, 0.1351937729745142, 0.16777841885003353, 0.18055400751050443, 0.217744343343281, 0.17854440566753188, 0.31278652890074643, 0.138074585326737, 0.09982291128366225, 0.20968218724573814, 0.12443440515668162, 0.12184154993343739, 0.1236353218255024, 0.1862302287331512, 0.291681174309023, 0.19587519909104995, 0.1497905364921016, 0.2991007052121624, 10.360694681444476, 30.744131649694136, 39.851884995737386, 37.29999488399875, 36.03199066654329, 29.692918792847667, 18.01059226835928, 25.71742992247305, 35.90108548441241, 22.599069149263446, 8.358211940334689, 1.4806770893835253, 1.045146298504645, 9.611062080629411, 9.610732601534936, 18.42792853232353, 9.637421388779918, 7.007957581550845, 10.471954672567307, 5.999408835364926, 4.194140905334104, 4.0811558067798615, 4.1819398826168435, 3.5202090682521945, 2.7268437560527556, 4.835259664443232, 8.74232376775434, 19.475560265202677, 26.869610471110192, 34.21137156025056, 39.849155026097456, 46.31933212280274, 53.60941794610793, 55.5160899316111, 60.64499293604205, 63.379892995280606, 62.84426196928948, 59.51864119498961, 58.5362639734822, 61.14277701224051, 61.50065406676262, 62.43192672729493, 61.77670263474988, 60.59215076508061, 58.72012507530951, 56.45528185752131, 57.08781503861951, 54.59970266588273, 54.76761148821924, 57.28180370023174, 55.27116537094117, 49.433403784228915, 59.91699710969002, 59.19119781063449, 54.72931738822691, 57.14585827242944, 58.82048283853839, 59.04561119694864, 56.70042607092089, 56.08240173709009, 57.18819633606942, 55.677962226252404, 50.611522966815585, 51.406889423247314, 52.7693796157837, 54.2923810405116, 54.65552583817513, 53.594489405232096, 54.46074878015826, 56.301740677126, 56.842596300186656, 58.36354632531443, 54.90381579245291, 49.95810708691997, 47.882784951117735, 36.318543341852006, 22.916284953394246, 12.620624149999312, 6.768835186958314, 3.0737116980937222, 1.7315317834577255, 5.241777050879694, 4.065571739788979, 10.723075597516953, 18.39352934591232, 17.53919005393982, 16.679924265030895, 8.199282894211432, 11.075084786261282, 10.910259927472762, 9.010335399258523, 4.250488694637053, 2.2291954919215176, 4.467990494543507, 12.470592510315681, 33.31403132407896, 38.82520460313366, 38.168858712719334, 32.28901793879847, 35.10234186726232, 31.424231413872015, 12.319081156484543, 2.7161445108152207, 0.35604359161469246, 0.16082817808754984, 0.1510765223253158, 0.17725478857755664, 0.10640011319229681, 0.15505458708972703, 0.0974691444407067, 0.10863433201466838, 0.09891122068849303, 0.16473723365174187, 0.12876220438028538, 0.09846966293069626, 0.12303399643109691, 0.1694321575304193, 0.15385860126585732, 0.13106616784728345, 0.17767200006111977, 0.22334055434311592, 0.15413879026328364, 0.2369223586133411, 0.19185411082881113, 0.09633669794927682, 0.19497424904857913, 0.17284475747616063, 0.24564436156182523, 0.18286619876180926, 0.15810119619052257, 0.18199351736374442, 0.15521851458376454, 0.15658251881118745, 0.13204878286248253, 0.1781827202367206, 0.10203839159540593], [0.04375104386840136, 0.0346175023174334, 0.010178016250832908, 0.03562108132868044, 0.03613217305692454, 0.05162706358298179, 0.02122378603915774, 0.01570664680442743, 0.07104189961307472, 0.055527416388354, 0.05110251935078733, 0.035603116566856066, 0.05334728720387625, 0.0560773104699629, 0.07494322535011076, 0.019322388369830388, 0.08891291525815764, 0.03194200727457722, 0.030197515903461366, 0.052204739843164726, 0.04853950708263344, 0.026331267417258313, 0.07516151444325525, 0.027221685665990078, 0.059199145574483185, 0.04174578574395949, 0.03446209372111386, 0.05342609083820736, 0.040737081604499015, 0.06447086471223062, 0.054353620301211075, 0.07741033490146361, 0.05700323114832563, 0.05154358298187295, 0.04473254039523102, 0.06288957879728367, 0.03640367844772916, 0.047030624137410236, 0.01758129459865872, 0.04582167227542208, 0.1285090506257069, 5.958136675819274, 24.075333572203114, 27.095788063541537, 23.266201557651645, 22.589243611981793, 11.624253872902164, 13.948107188747777, 16.197904194554976, 18.678179671687467, 14.84860493290809, 6.482636015261374, 0.8692947378562343, 0.48573801774651776, 2.2289471568599826, 1.736817422413057, 3.263566181544335, 2.0491971892695275, 2.481227387343684, 3.44662344263446, 3.844758724012683, 3.0457299995806912, 3.4597773561554575, 2.05415996813005, 0.8169191450841966, 0.8532845421183495, 2.634895064177052, 3.619757842633032, 10.832692115537583, 15.962723781985623, 21.031580202041134, 27.09431325235675, 36.76467372525123, 47.8522846006578, 57.37652109515283, 59.34331124828708, 56.35028000800841, 57.09555779733966, 58.93901686514578, 58.607623654027144, 59.39052874042142, 60.87582834305302, 57.76077608908377, 58.146549040271395, 56.3439061564784, 55.01420697858257, 54.01018611846432, 56.80335298661263, 55.68025289043304, 55.045966409867816, 52.41445610600134, 41.07887691067111, 57.139280457650464, 62.234082375803304, 58.650977611541755, 55.02583288377332, 55.86341581036968, 54.98214160242389, 57.82603256164059, 55.415794926304976, 54.89292729285456, 54.163582171163256, 53.630253576463275, 52.15457947023454, 53.66212675648352, 52.20249514425955, 51.80505706417946, 49.62001446754702, 52.33890341174219, 54.608861400235085, 56.23237356062859, 51.27971441515031, 34.71213663777998, 35.324391165087306, 33.01901809630856, 17.905070704798547, 8.498911280785839, 3.78476313044948, 0.8082168765606419, 1.514178665895616, 1.0269948563748792, 2.237049057599037, 2.2281751853804437, 7.543776391013977, 10.44379597710025, 6.456329168811922, 11.970203980322808, 12.116686855593036, 4.791381580214347, 2.9256961566786615, 1.9361175861089461, 1.1840414712505958, 4.11043752585688, 6.778489610841198, 7.500478327274323, 22.06703297553524, 27.73526187865965, 23.294250426753877, 26.128311926318755, 23.889648568245676, 7.7300502407935365, 1.5242077987040243, 0.027109967063992258, 0.026675196845204602, 0.030361154199307485, 0.028198645037088185, 0.07754718884825706, 0.021882395658101288, 0.02963232304600458, 0.07714366735590082, 0.04485819030613188, 0.05036537422828617, 0.043682961634570555, 0.03706331845493086, 0.057909746819566336, 0.03752676334472434, 0.04414523057940026, 0.0438316784528715, 0.051069949122686545, 0.049032817910154985, 0.050998882976390665, 0.05318352058830281, 0.061188323513394406, 0.028396533208809076, 0.03126004538048179, 0.01399717522755025, 0.08996500678720976, 0.09730030632307453, 0.07440481875692645, 0.04395903673984351, 0.07665212236104474, 0.026309776735762437, 0.05048567684547556, 0.028672240591878374, 0.11031631635682237, 0.07966469417536452, 0.05211287057928501, 0.018131403184886423, 0.00790170233343698, 0.04231522655895641, 0.029637745033288677, 0.08349472777016702, 0.05780384665535343, 0.06289543936990442, 0.06389096679706728, 0.01434465068497605, 0.00432846476248796, 0.015928079730891172, 0.022501576646801927, 0.06664127607138888, 0.057011761537362496, 0.022070506632688548, 0.04182694126821814, 0.08051901244588437, 0.030764825078808976, 0.021984729683026675, 0.01815131572525828, 0.039999476829243284, 0.05796351087009234, 0.10592400486911498, 0.06713416172011245, 0.05062949836194035, 0.06128904492323918, 0.044234862866541075, 0.017064800035328637, 0.029575540609056913, 0.04530480807466854, 0.05134469889585049, 0.07086635056522585, 0.04124037072723431, 0.03247936241208546, 0.04034002972466331, 0.013888356268345831, 0.04593558571932297, 0.031155692713875926, 0.03304892197071064, 0.4053585099116449, 8.734129936464372, 30.035224037785685, 33.439441265598425, 31.750943276189993, 26.056163849369174, 13.230606644384324, 14.870746712530813, 27.717005206692605, 28.641919705175585, 17.346960575349872, 5.842465979437675, 1.0001952621725299, 0.17224261236767616, 0.8357291776807079, 2.0438192520410787, 3.315319649634823, 3.3935959396823763, 5.60219285949584, 5.573351181322529, 6.443426532130088, 5.414783973847666, 2.9122870439483277, 2.9409907037212006, 0.9180744977728014, 1.8945847115209027, 3.847768407675528, 6.232687388696979, 13.288589081456585, 19.28001834500221, 24.80947575261516, 30.588099764239406, 40.76293391566123, 50.746515258666015, 58.51463994672222, 61.617317122797814, 59.08965941398375, 57.93926746614518, 57.97833819543162, 60.644863497826364, 59.61821448418402, 61.85276523713143, 59.54466219871276, 60.262397104694, 56.78843229047714, 54.77056503295899, 56.10681456904258, 56.74698460486628, 53.93286051288728, 55.49774892868535, 53.21242309385731, 46.35064440388834, 58.08279875786074, 60.92817237300258, 58.86696292508034, 56.92835500163417, 56.67287926520071, 55.65288651374079, 58.2487307056304, 57.572965160492934, 56.45607809866629, 55.56182084545013, 52.88032385610765, 53.26256275177003, 54.07334020060878, 52.84647772389074, 52.35120396460257, 53.02222344183153, 53.92408617081181, 56.22944355010987, 56.831080221360736, 55.570736392851806, 39.52604978315292, 39.99646356028896, 36.16579840260167, 22.007489435134396, 11.094714287788639, 5.806759172870267, 1.970279223976597, 2.1418857382189844, 1.2003028825406106, 2.0729924930680186, 2.663536701471575, 6.102453912458112, 8.704670975285193, 5.575742356238827, 8.150425851345062, 6.913545641206927, 3.6150193743167387, 1.8472987004826147, 0.9943297253020349, 0.9820699896062575, 3.8035922233135473, 6.8509980555503605, 11.19389141759565, 28.77846133324408, 33.22302449134089, 29.024788141250614, 29.936317551520567, 29.07753029177266, 12.907242525008417, 2.4493000295854386, 0.1502845865944701, 0.06866678956054872, 0.02155965813736041, 0.014720793152528425, 0.021986608513660973, 0.02126660269324578, 0.04498096738731669, 0.017270054142441482, 0.020492233358503833, 0.027550258861494162, 0.05322388959147277, 0.026401975417449593, 0.04542154455257039, 0.038985927183661735, 0.0672449380339634, 0.05859340368319423, 0.04340798586546894, 0.03854125144801313, 0.04623791082732139, 0.06317613015492117, 0.05460288615957384, 0.027947735920127843, 0.03647296727004071, 0.047329589949860695, 0.01534939606508781, 0.050449812439300364, 0.050568027466896086, 0.047771553734257344, 0.014643956448942905, 0.10568070300524274, 0.04343963295762097, 0.04357638348254465, 0.08509989647615342, 0.035831571646755746, 0.14305622527195563, 0.12156702998665073, 0.11261467972109396, 0.0838136884774412, 0.07509406040152235, 0.1844607801326821, 0.1217696755643814, 0.1615655377146698, 0.19875936690838109, 0.20077278386921654, 0.1431515572532531, 0.13011304721716913, 0.11659291302484852, 0.17162847032229747, 0.18709811442081006, 0.20513720209560088, 0.17151135080043348, 0.1338846053207113, 0.10652074139685401, 0.14970045987396471, 0.13205595344545382, 0.1514693722128868, 0.20780856600932537, 0.2148628261901679, 0.09045737149614481, 0.25964454176925844, 0.19685501022444618, 0.10979818045011452, 0.12103265301594812, 0.19582984668593253, 0.21393814274380285, 0.21554513473904904, 0.13979900327901687, 0.14011864580454367, 0.13575441143926115, 0.12712610104391653, 0.09176715202028714, 0.13066271530284038, 0.18362876268163805, 0.129611688636003, 0.5655966470799139, 9.313425767806269, 33.10272147578578, 40.665204140447806, 40.69180957732662, 33.31447062953826, 22.028317220749397, 20.948282787876746, 23.324521318558727, 28.600577923559374, 21.331323808239354, 9.478939983152575, 1.4696432169406646, 0.9085153139406635, 4.344880532833838, 6.160352018571669, 9.148532267539732, 9.541431184737913, 8.44312439041753, 10.63914668175482, 10.181268799689509, 7.804736581540878, 9.581372680202607, 6.463940528131301, 1.6477119586160107, 1.059057842339239, 3.5446339124633424, 5.059054416994895, 13.232368769184237, 17.270405715511693, 24.209692401270715, 29.164565724711267, 40.22633798660771, 48.84394214999292, 58.59313834098078, 62.504392516228464, 60.902602441849254, 60.3320780108052, 62.270301541974476, 62.1137793602482, 63.31573870874221, 64.00030213017618, 60.00585840594385, 59.631530930919034, 57.787597256322066, 55.963424482653224, 56.54491586069907, 56.98101282119752, 56.137338453723544, 54.33171456859958, 54.67380016080795, 48.3889550547446, 56.756633635490175, 60.68761733270461, 57.94097761954031, 57.83187297082717, 56.97753367885467, 58.11023965958626, 61.80892098334528, 60.77909877223354, 56.91072787007978, 59.24496958332678, 56.69123203523698, 56.28455285103091, 58.828331501253196, 56.25906136728103, 54.5953998258037, 55.03497200627481, 55.713118430106874, 58.794814848130756, 58.831026169561575, 55.89600678413145, 46.59023454112392, 42.1597840709071, 34.17601923788748, 20.356628548714426, 10.358107878315835, 4.943607295713117, 2.0655853421457353, 3.0203096087901824, 2.4233616407840484, 4.478079811219247, 6.072082019621327, 14.787133547567553, 18.615096192206106, 14.334555768197584, 21.371520257765248, 18.780041663877427, 12.029073853646556, 6.768255656765354, 3.110925675399842, 1.7492414073598002, 6.100846721280006, 10.22631427934093, 15.027484624616562, 33.704620945838194, 39.48733206718199, 34.78756381619361, 36.55741176297588, 31.047509331857007, 13.00138823447689, 2.443859947304572, 0.17825045773098547, 0.1134151956366916, 0.1038183968874716, 0.08157364738684508, 0.20689750360625409, 0.1859289416742902, 0.20728044031608492, 0.10673988850847368, 0.13325817522502717, 0.15340881572375376, 0.1450075584674074, 0.16951347010270243, 0.12571777096919476, 0.11729581401713433, 0.14365060224888787, 0.17196534982612058, 0.12142260709116537, 0.14689421852029141, 0.25753495013040884, 0.12786416547192683, 0.15990695735860258, 0.11104009324504484, 0.1101626544409702, 0.14644037271218915, 0.13433085153660468, 0.18077940589958624, 0.09665015048437542, 0.17674078954563988, 0.20105248257037134, 0.17569132569816806, 0.1693333475099456, 0.1154601754200074, 0.2482692239385459, 0.14291466754530707], [0.01296892339709185, 0.007413797692636089, 0.028462280789690635, 0.030550184479403882, 0.018935452681034803, 0.05503425494797769, 0.07236984408190174, 0.06265744649534745, 0.017554263186250484, 0.12924952823067867, 0.1278077814006998, 0.05597588042878816, 0.014529454074950229, 0.023587184522541303, 0.028118841658015887, 0.014653686723191173, 0.0282908188209178, 0.046901235717438886, 0.08122385164061863, 0.024722854328912594, 0.056288869480692574, 0.06552955991919003, 0.02113555186247874, 0.06932443007826805, 0.06833184059829482, 0.05013501925033428, 0.05689637720464699, 0.049492566425713806, 0.005898960329021418, 0.018079583082468282, 0.04950321121742168, 0.029298534706955957, 0.054416650185181256, 0.03961217724868367, 0.028821020612433076, 0.05272978203250997, 0.050973579092251683, 0.042315100154448906, 0.03417747673548518, 0.06674768568407144, 0.04444510803648061, 0.1556136780568669, 5.838925550060888, 17.12873754962798, 25.51518467164809, 25.330858768955355, 21.166321462200536, 12.992984556382703, 12.633396367872916, 20.061725147308845, 26.439193102621264, 19.242118443212203, 7.407031289992794, 1.9555949732180566, 0.4072956704804975, 1.1933781831495225, 2.750244126204522, 1.3973129949262066, 4.075923610118128, 2.7626697046141473, 3.1584412676672784, 3.404056165487536, 1.0740001115106768, 2.8302018873153196, 0.640384050146226, 0.5773760762906844, 1.0046852115661868, 1.227448503336599, 2.494708328477798, 5.44564224058582, 10.540100951348583, 15.750224474937687, 21.237557588085053, 32.965340460500414, 45.16200542449952, 56.42365186445175, 60.31663171706661, 61.76707321597684, 59.981688760942035, 62.15017503307712, 59.386676972912205, 60.29172466647241, 56.12679120033018, 55.71802139282227, 56.38136086925384, 56.57971905123804, 57.32740909822526, 57.01167398883451, 56.26385842600177, 56.98570005355343, 55.12804200572353, 41.74005908350791, 56.318791220265055, 56.06767715946321, 55.684912666197754, 56.78402354640346, 56.88432247407975, 57.92984201062111, 56.938655145706676, 57.019577564731726, 56.66669760980914, 54.83788859459662, 55.04133016832414, 53.41769249208512, 52.18237338527557, 52.22759831336237, 52.1421298673076, 54.6586755014235, 53.18720225364932, 56.15785244972476, 50.66083892699211, 30.04180185256466, 32.33997344970703, 26.370688907561767, 10.974973151760718, 4.057949839099761, 1.5000923314402181, 0.9461632034470959, 0.3612554409811574, 2.3546748103634005, 1.2987418713108188, 2.841962378832602, 2.423417534559004, 4.977255348236331, 8.62751599281065, 7.664399570034397, 5.326473280306786, 5.140439185404009, 1.070919702610662, 0.4755003558051202, 1.3714151781412864, 3.82824162321706, 11.240556836128237, 12.153073703089069, 9.617781100734588, 20.693328726676203, 21.54974099128477, 27.018648770547685, 22.777688003355458, 10.146569551960116, 1.7702721756312156, 0.09772612097402734, 0.0033792509413850045, 0.00653828512088606, 0.019710358277323748, 0.016176848589713057, 0.0781035142379903, 0.06473519568962437, 0.10878669924192852, 0.0075817313477126586, 0.06750871742805166, 0.09772354691860177, 0.01916220513052277, 0.02865938563650895, 0.05626151248091652, 0.06277502566996603, 0.021230655932618726, 0.029171703105431893, 0.05598231556735212, 0.013916432433160804, 0.03858548153432147, 0.05677704368868182, 0.0983410444290888, 0.06734660556239468, 0.04493902790390196, 0.06892634014929495, 0.06448139076031024, 0.025526210515489502, 0.05141204951571361, 0.035486732489399375, 0.062394973281170094, 0.03716423521719633, 0.015600062906742098, 0.05461778656970109, 0.03454640552762055, 0.04068207266109605, 0.04153606534424809, 0.02976077683870831, 0.02180414935273509, 0.02496798714292386, 0.01759552276663242, 0.0090320885271555, 0.036159698596043933, 0.026500212787199887, 0.06572977699820073, 0.0469225712661301, 0.05100314242524966, 0.07659622858608924, 0.03333197230653417, 0.05487185579934909, 0.0432317435080486, 0.03936514836705981, 0.0073729316899252524, 0.0681525607022547, 0.04848993736349287, 0.027067954802224715, 0.0981906537086733, 0.0758263561874628, 0.08140678577605756, 0.01743101687621205, 0.0819553430342386, 0.04195207406977012, 0.033888389626818324, 0.05149976658304373, 0.025840898367366003, 0.028614935299922383, 0.026823461671630223, 0.02634668302151465, 0.034538200725951505, 0.03682075969634518, 0.030457815343153574, 0.0912858879253749, 0.034767973477080945, 0.08122838688113036, 0.028641985864528728, 0.03482812287045583, 0.02134017203183424, 0.40005022539727153, 9.896758698648023, 24.1603882082047, 31.664380488857148, 31.136050954941783, 24.90682701910696, 12.864284726881213, 13.329368983545612, 25.00993632501172, 31.34825118126408, 19.528773100145404, 7.1163003098580155, 1.798681535067097, 0.05071798151719475, 0.3220866830839265, 0.31850908312105364, 0.781349866620956, 3.6566830354352153, 4.084250801993955, 5.6969720317471415, 5.6977864138541685, 3.7414586928582962, 4.519707925858037, 2.8346684863490443, 2.196624375158741, 1.4987997878943722, 2.2200887289739426, 2.7506064551491893, 8.73047624864886, 12.266167402267458, 18.76945322559726, 23.166606695421283, 36.24772494839084, 49.10232436272406, 59.081332222107925, 61.06736552330756, 63.86008524125623, 61.94067339743338, 63.37837111565375, 59.66523585780975, 60.25551726741176, 56.318175408148, 56.84384361390145, 55.61870698005923, 57.21443307015204, 57.15944928507651, 57.73261347124654, 56.771770061985144, 57.175578071225075, 55.01493653943462, 44.363065688840805, 55.96480907932405, 55.32590204669584, 56.09434535426479, 58.80352250991329, 58.39338379521524, 58.369759359667384, 57.488442005649695, 57.990874090502345, 56.30671424250449, 56.08699875493204, 56.42282032197522, 55.78339161411409, 53.93559048252722, 55.00997866353681, 53.57564241655412, 55.723010647681456, 55.23398130170761, 57.664725088304095, 54.33970443664059, 36.68870525975382, 37.85049169294296, 31.345370200372514, 14.538886739361672, 6.158168729274504, 2.218748749263825, 1.571488906779597, 0.6050148738488075, 2.4570790702296845, 2.3816048233739795, 5.144574834454445, 3.4985708229003416, 4.54542592648537, 6.738905541358456, 6.688975239953687, 6.565627974848594, 4.243221523300294, 1.9277696792156467, 0.24295222134359423, 0.888852901276081, 3.007383683035451, 10.981165593670262, 14.285449654825273, 12.971554686946254, 26.852961970913796, 28.590477820365663, 31.166235554602842, 27.775689748025712, 15.46936708111917, 2.992294570130687, 0.20570715618950708, 0.026893244620652932, 0.05865318152392584, 0.027884646664343538, 0.017954664785535108, 0.04384045015960451, 0.014542586737192206, 0.05206651076854718, 0.014788342955251856, 0.010665225188037562, 0.131395080036694, 0.023513686047085834, 0.04261304323952045, 0.014815716234396302, 0.03811107392633154, 0.03528811653415042, 0.07718675214076236, 0.04546565972569008, 0.00583779682675677, 0.016572789642058553, 0.03210141868030112, 0.024601745404182904, 0.012043328306096937, 0.007875785100153618, 0.008987856525627357, 0.015073438745833214, 0.02867845164972448, 0.029460412915796045, 0.05562911072986261, 0.0629203487187624, 0.0513906603408677, 0.047201603470790776, 0.04573731067320032, 0.03728028604640596, 0.029820424444492788, 0.12095073523420481, 0.09591138125547478, 0.10079994151789336, 0.15685860157733963, 0.10534221471677865, 0.15959065497642563, 0.15474683424878508, 0.11751543610326706, 0.13193302697712375, 0.19657371806040888, 0.3424765421978889, 0.14381376365500112, 0.0833333973141928, 0.10306150967916174, 0.09928088875547533, 0.13267112204865103, 0.16883160588481735, 0.13616615305504493, 0.263428985471687, 0.1650519272492778, 0.1655308394542625, 0.36634946602486795, 0.2432043868447504, 0.12639373631006287, 0.17061064590609845, 0.18618547387661474, 0.13541370149581664, 0.1508190708174821, 0.13595200083669157, 0.14522776278036256, 0.18126008010679678, 0.1919677676332574, 0.18462573418453818, 0.11204756015250761, 0.11378300977089714, 0.12081689967383301, 0.11141058102610613, 0.18935488687167246, 0.12843645613400206, 0.18135378798169477, 0.12892066200654353, 0.5010213799053623, 9.633258773434548, 27.628363563168435, 39.321839424871634, 37.41955264922112, 31.74869771926634, 22.357666877008256, 18.85974422577889, 28.497909884299006, 34.86287332350208, 25.765926107283562, 8.91699573686046, 2.528565247212687, 0.7572413860790191, 2.7885316071971773, 6.325341126611156, 7.49189422015221, 9.026499486738636, 8.21546757413495, 7.272275320945248, 9.40207427547824, 4.909489539361769, 7.355020171211613, 5.240554251978475, 2.699258952371536, 2.9853752639985855, 2.5327384039278957, 2.915628903335141, 7.043652621007736, 12.146756725926554, 18.01431655883789, 22.320394554445823, 35.88823187735773, 48.83454807343022, 59.66527900388164, 62.063675003667036, 65.48170681922667, 63.86476070650163, 64.96541307818505, 60.547443589856556, 60.548765428604625, 56.53814192741149, 57.26325088931669, 56.66502668011574, 57.966167080786924, 59.343158275850364, 58.83534469912129, 57.20676875883534, 58.91547479937154, 57.839635341398186, 49.95368657573577, 56.4375017535302, 56.9221027435795, 57.26194081767913, 58.9284303880507, 59.783742427825935, 60.20274962148359, 58.85916917554794, 59.071973446876775, 58.254449521341634, 58.252378509890654, 58.55076497600925, 57.08011542597125, 54.823281688074914, 56.437548821972264, 55.41026046199184, 58.015514419924834, 56.652745739106216, 59.47338096557125, 55.39899541485695, 40.42364497338572, 39.13704872131348, 29.275986533011164, 14.197349298384882, 5.7011169964267365, 2.295872352776989, 2.1535020826324343, 1.013028215496771, 4.144384659105732, 3.417622663321034, 9.066406661464322, 6.145262170222498, 11.036804414564564, 17.235892780365482, 16.604897168374833, 13.343714071858315, 9.77398164810673, 3.1257970967600426, 1.0008479690840169, 2.3119065117451454, 5.428278398129248, 15.690273988631466, 20.076938060022172, 18.781047751826627, 32.690956938651304, 33.40484596067859, 38.568901246593846, 32.4102250606783, 15.569862127304079, 2.7248742359299816, 0.1938676197201975, 0.2090973710461009, 0.16919434851696416, 0.14365178202429127, 0.15027407586814898, 0.22021816382485054, 0.13151143347063374, 0.15996939352443143, 0.13591824700274777, 0.11200803767649398, 0.2907668943366697, 0.08810364295758548, 0.09760622055299821, 0.10309655054081833, 0.26967186661016557, 0.13823645970513745, 0.12271833756277639, 0.13311611188034858, 0.1449713378303474, 0.11724319143761551, 0.12806590706590684, 0.1914053978098016, 0.1341515409970476, 0.1843699680701379, 0.08374850971684342, 0.1595512933788761, 0.11866190966459052, 0.16523152890224613, 0.16301912826395806, 0.21449415403748714, 0.145185244900565, 0.14278878397758932, 0.1409806172934271, 0.11680936350697473, 0.16448048694479853], [0.06024952489702452, 0.03242817624742466, 0.01537246201487799, 0.0328564117362182, 0.06176575462544157, 0.0344133475464919, 0.02475139110409204, 0.050118820321175366, 0.06688591858912861, 0.037703147428410674, 0.08845140090993336, 0.06062984541659394, 0.01878791563813725, 0.06905434578056298, 0.02069148325151013, 0.08015807012035962, 0.06698411573926288, 0.040438050674574996, 0.08415762365104691, 0.0658908469842807, 0.04669364121171736, 0.05054077388898981, 0.057400532006736726, 0.03517198526570874, 0.03557138903547199, 0.036432858736765, 0.017084545951576966, 0.04334445036346874, 0.07684650185007243, 0.03665069966847378, 0.015348754466451226, 0.03442236440136068, 0.013488136614943224, 0.11821093668620433, 0.04478643468070415, 0.059176067175764235, 0.015354787408854934, 0.05243806724226283, 0.007444013636784569, 0.04484586012099059, 0.05507350929321782, 0.030518010701803915, 0.514824690838014, 6.054026859421884, 16.002931998622035, 25.11068828644291, 26.701534948041363, 20.110729279056674, 11.466440250796657, 17.852750209070024, 22.08108094430739, 17.882570028305054, 18.755615103629328, 9.512580190935443, 3.160932953319242, 0.438561465350851, 0.28464196009501336, 1.1741719298785733, 4.9621355918145955, 3.9529774073631536, 8.228139281272888, 5.101804819799239, 1.5785467216084081, 1.8414984955903024, 1.0199832519696606, 2.2269974937362056, 1.4360472583963027, 1.4149631704053571, 0.8710936348765128, 1.916130045729299, 2.040266687831571, 4.160835569904697, 9.240084309731762, 16.181345908872544, 28.159727050412087, 42.56968744339482, 54.90875013412968, 60.53786908426593, 59.41845601604831, 57.8113668195663, 57.90816307067872, 57.26335287094117, 56.85119413560437, 57.76836979773737, 56.79352352696081, 58.15564893907117, 58.38049488682901, 58.80996304173624, 55.808996846598966, 57.674174078049205, 55.92243963672269, 49.78222016365298, 58.196363141459805, 62.00187413923202, 61.61723083065402, 57.66507025687926, 60.34999147538216, 57.58939204677459, 56.507539595327074, 57.68326220973846, 57.93431743498772, 57.36207108343802, 58.29197875915035, 56.73100094641409, 56.944346504826704, 55.90074500729961, 56.710569320186494, 56.99724751134073, 55.96161627000379, 47.4590709132533, 30.54035471331689, 30.961113245256488, 19.83853836213389, 5.39036133596974, 1.3631762395943365, 0.07868616240880183, 0.1940663122842389, 0.8624811518576838, 1.032984131766904, 1.7415971981902278, 1.7198955820452784, 2.4373331233378384, 1.759546944691289, 1.6405472592000039, 3.2205098338665503, 2.359481429861438, 4.275971843350319, 3.239209978811203, 2.2226238058459376, 1.2209564904051444, 5.590866525327006, 14.238763643849282, 23.79362698524229, 19.235064060457294, 20.300475897327548, 19.25599382769677, 26.36537409597828, 22.974053621292118, 9.908447361761525, 2.1200315173595183, 0.14492282914298196, 0.05288083158854035, 0.10700793501230017, 0.05285751187212525, 0.03632247695819505, 0.0538786840925534, 0.03438301046469039, 0.01184190942665502, 0.09013747616160302, 0.05545109870933718, 0.0574850736396207, 0.013965535796277467, 0.019199825793264375, 0.08023494704356117, 0.10350738817285146, 0.0393161608747417, 0.05070586583667225, 0.07660889968035683, 0.04796326723730853, 0.09794031915765616, 0.03467287515260039, 0.05698866781688506, 0.025214615743607286, 0.025648550926557472, 0.028118945079885667, 0.044798240095617316, 0.04549418883999029, 0.028741671140455914, 0.04330173713125048, 0.014991810162281318, 0.03897195757036248, 0.10894221509055746, 0.05030757672483883, 0.017750347220909693, 0.028267412919611223, 0.009649497937531242, 0.03582590642655569, 0.029124324397754767, 0.01826892745861363, 0.045154631858871835, 0.06339503594884469, 0.018376982245113582, 0.03731577506949825, 0.04350807908321581, 0.07061318148888888, 0.0474807161146835, 0.017111797614263433, 0.06385720530224424, 0.02955725983596377, 0.031735650000853405, 0.03179894801559708, 0.05087481503705344, 0.034982194643347495, 0.0074202807116953125, 0.062191733985298106, 0.10326922675895114, 0.05690906362067308, 0.04152850022599582, 0.033163023106152975, 0.04822613498676689, 0.050232726104197004, 0.05319256425624894, 0.020898780898160992, 0.05132271983330289, 0.05950432052955993, 0.05163131920140117, 0.050383354311869036, 0.02951767990335582, 0.02915369620877168, 0.018511604960827578, 0.01297654405671863, 0.09785451731013675, 0.0338413326760694, 0.04372872772716707, 0.040152679092340895, 0.0415189394487008, 0.07641676482894728, 0.042527846601461215, 0.6353397595305598, 9.763367714420442, 23.575503979959798, 31.410891432915967, 32.61477274279441, 21.429498772467337, 9.42874639264999, 18.079347495109804, 29.662130148180072, 29.390100048434352, 21.96520040112157, 10.877544418458017, 2.872806917275152, 0.30338476081528976, 0.30551595613360405, 0.5320111686183561, 2.1534805095964864, 2.7836283993336464, 2.9791597781642793, 4.170872915175654, 6.446088350588276, 6.687853932380677, 5.352491342252301, 5.338781677907513, 2.952432992958254, 1.9133346215371165, 2.1462704577753624, 3.0880830172569524, 3.10172256923491, 6.238189493456195, 10.729981910797859, 18.690146823083204, 32.19352587576836, 45.87652790930964, 55.59416470989105, 59.92449275908932, 60.053217103404386, 58.8979967178837, 58.17479795025241, 57.9355098355201, 57.804216338742165, 57.929971448836795, 57.56672859191895, 57.73988554554602, 59.60940091840683, 59.37534524548439, 56.12681473455122, 58.507854246324115, 56.7020538545424, 49.38196582178916, 56.379030981371486, 63.451029100725734, 62.45653960012621, 58.09416186424994, 60.85820513386881, 57.25889705842542, 57.91623530849334, 57.32081951633577, 57.63788430921493, 58.98646577712029, 56.884530359698886, 56.359654472720244, 58.50298658494027, 56.97814164623138, 57.1033162455405, 58.282616061549035, 56.72063019967849, 51.02688235621299, 36.9685193031065, 36.14758291552144, 24.04989504045056, 7.432814009727971, 2.5793114016132974, 0.8112503395926568, 0.8204847634319337, 1.352768230342096, 2.2674481618788938, 2.3041274711009, 3.94448890801399, 6.178693511793691, 2.5894781850999404, 4.751089522915502, 4.018914656293008, 3.495075991076808, 3.059688489283285, 0.5214218723197137, 0.4230263973436048, 0.9375637745664966, 5.658654887830058, 13.998490033611176, 26.182934853338427, 19.478333380914506, 24.375345860758138, 25.955472684675648, 28.423551551757324, 28.73798639543595, 15.027087484636615, 3.8412700208925434, 0.3102370495757749, 0.027279963889609904, 0.06401455593145182, 0.04490450032115464, 0.050691279522593946, 0.09422794134626467, 0.011399918829181023, 0.04144234597803124, 0.04523003789325876, 0.0500233810875685, 0.03793570490914487, 0.12568648393836715, 0.11553368921722136, 0.08890785907785739, 0.02846890170457623, 0.022221575340917035, 0.014219192296056258, 0.09424887852923525, 0.04722109657802409, 0.0742133963672865, 0.03223054088471878, 0.02284571674892739, 0.02891491234843289, 0.035699835167296474, 0.04650293894472622, 0.08844770070525909, 0.023244984538084077, 0.01853007342546217, 0.06467292806313885, 0.0029808038239172033, 0.06999164669504089, 0.023312913554330027, 0.045349149243725885, 0.07773410664090226, 0.036289539007890614, 0.05525813265252979, 0.18994385526785929, 0.15324183919977757, 0.07417815632276958, 0.16155459797911106, 0.14471382503547978, 0.15345286577939987, 0.16319299957925276, 0.11520960338173375, 0.18013584607791516, 0.12209078131784355, 0.14922202264349307, 0.2525177483837451, 0.12096916730966299, 0.15905361201974655, 0.12195332216158991, 0.14447236944350506, 0.12903808796357724, 0.1570412675820051, 0.18489596403894887, 0.2885350044215879, 0.13938392151988324, 0.11147836448564646, 0.158939189127376, 0.1974686772953118, 0.11842828349120195, 0.15656384158759348, 0.14298114865537614, 0.16786486421140934, 0.1990471401762578, 0.12648440281590148, 0.0784464228537775, 0.18440055030007518, 0.08734007546257588, 0.21944954781041992, 0.12830227583406434, 0.3395306583373778, 0.13213744987883877, 0.17050135580282058, 0.07363264043364795, 0.15500990884198299, 0.22964075418008914, 0.1314034916821026, 0.6578547771899932, 10.117734247638333, 26.893417296871064, 39.78580874781455, 40.49243942383797, 32.05107323585018, 19.999202566762126, 25.864354064387662, 32.59928526416902, 27.097923794100364, 25.618952935741795, 13.145504939940668, 4.14957199365862, 1.0169076847453271, 1.217165397059533, 3.380572690117744, 13.159793153885873, 12.887918968354503, 14.89242369128812, 12.537928819656374, 5.917382269136368, 5.92257107457807, 2.8130324473304134, 6.696813116150518, 3.8070245423624596, 3.4980876359247395, 1.9839093377513273, 2.864645935835377, 2.9994560826209287, 5.5357483990730785, 11.113378886253605, 18.134195958414388, 31.337680393649688, 45.95409277946719, 55.96863731261223, 61.24009886095601, 60.356400628243726, 58.586438932726466, 60.246542884457504, 58.0260028377656, 58.69786562458162, 57.40749997477378, 58.62126957985663, 58.027010886899895, 60.57463345989105, 59.63783025741578, 57.828852745794485, 59.503018394593276, 58.08718004534322, 54.34831011679865, 57.234692112092056, 62.22123661348897, 65.83734420038039, 60.63120188251619, 61.99519434282857, 58.35589770347842, 57.41268142577141, 59.71188852863928, 59.41782843682074, 61.90864724497642, 58.42277411491641, 59.79014765831732, 59.792963920101045, 59.618708702825735, 58.209714889526374, 58.475514304253366, 56.88909207620929, 52.16039242282991, 43.32781491741058, 39.153471685224964, 23.45448120947807, 7.36038891538497, 1.8851771518107385, 0.6310641921816335, 0.30420714088024636, 2.298214007769862, 3.15902300419346, 4.238277865994362, 6.0650791179749275, 8.620828351666852, 6.6108504514540405, 6.79115935679405, 9.242009212893825, 5.579906442473012, 10.53814172744751, 8.185374169580399, 3.9157087620227573, 2.0553168221827476, 7.298739062201593, 17.883436872113137, 31.03892718591998, 29.055357133188558, 30.500756425242272, 31.640322631405247, 35.61922396382978, 32.67782876568456, 15.485838094065267, 3.5288650037780886, 0.30628109410885845, 0.2072672482820288, 0.24308443279756656, 0.18929231281001724, 0.07534859311436454, 0.16392965440548238, 0.1428756736699612, 0.12436322792763672, 0.1360825881842644, 0.21687385295667957, 0.1565295361703442, 0.19937418311113314, 0.17170688708222684, 0.24079911591064548, 0.2131832243814584, 0.12496391746906504, 0.11381834174596495, 0.17978149976941848, 0.20699838206412333, 0.25345128780651477, 0.11368160271236014, 0.14131052539713923, 0.1417482527153146, 0.11945078870461834, 0.15233748772692296, 0.21098861230477212, 0.13196072871646575, 0.15617237065828618, 0.1862470520239684, 0.16521136546807905, 0.17709482941896687, 0.1726432150650409, 0.13904374783798573, 0.1387293606756195, 0.12086505596075328, 0.08998648023172733], [0.011490657155762517, 0.03847428387211215, 0.05559553692658102, 0.034351401676934575, 0.031410305865950165, 0.03634117716442674, 0.045495314989238984, 0.0710301554851955, 0.013928934030475156, 0.045158412502778154, 0.045359307569601846, 0.04423698493009133, 0.009111996285707481, 0.022075746674090627, 0.025263174226687803, 0.09101714428153732, 0.0388293196597407, 0.019931052886550466, 0.07032661863993253, 0.061712997980536, 0.03695796987402343, 0.04304677157873108, 0.036398606945670424, 0.05602712405004329, 0.013929499977929218, 0.029831662954341982, 0.02711841701379707, 0.04238600159184106, 0.03239801536584574, 0.06570518557583133, 0.05363381940931563, 0.04025589794881883, 0.04628895143527658, 0.025461453103250074, 0.03623309748006925, 0.04240529168577444, 0.009591033937589777, 0.06950406237475334, 0.001422387069924885, 0.005675673469780915, 0.06968676668381499, 0.056304444048193195, 0.04551958465468019, 0.270446534719198, 4.8716857356409875, 17.341945825084565, 26.6365961874685, 24.51676299495082, 25.331003896651733, 15.03014301100085, 12.172653194396728, 15.778639105058486, 24.090842623864454, 26.664452860432288, 12.394925086728989, 3.182770504105476, 0.651430547718079, 0.13081836904729569, 0.48750109249545687, 1.388789684541764, 1.903003098503236, 2.483286141387878, 8.419686267452857, 7.673303840621826, 4.983039863647954, 3.6374553317023866, 1.0969725755914566, 0.8336344481475892, 0.8489682801788854, 1.5426051857010012, 0.8778292637678885, 0.7906764661592822, 1.2061165705803902, 4.576478840843324, 9.137454513580568, 20.32375712548533, 34.46598045287594, 51.46605053255635, 57.83023342009514, 58.792359444402884, 59.719439091220984, 61.26514711687642, 61.08305108162665, 59.38978349008868, 58.4125602629877, 59.54239114638298, 61.579678058624275, 57.549411327608176, 56.87541477141842, 59.05987293489518, 58.13443676117928, 55.25362453153057, 59.33635688597157, 51.479739604457734, 52.234223196583415, 55.918179942715554, 59.95058436547557, 59.8905054215462, 58.76729549900178, 59.906559682661495, 60.137724568766934, 57.36265159422352, 57.813590803454005, 56.402761320913996, 57.31327287612423, 56.87286130843624, 56.756382603799146, 52.0263179655998, 42.03102834763066, 24.416403270536854, 25.203860267516106, 16.791329383850098, 4.478066082923643, 0.5927345457096255, 0.08246060866381853, 0.832425193680871, 2.242751448385177, 2.0168674208464163, 2.052014676793929, 2.0894877756795576, 2.898920341845482, 4.449359236225005, 2.0398455233343187, 3.6563251191569917, 2.489372189006498, 4.432747998545247, 2.7996184316373642, 0.3783032262036878, 1.0741601932433344, 6.4794211426088895, 14.079809592616174, 18.405737723073653, 20.07412572060862, 28.13128790547771, 26.767436650491533, 24.32717719385701, 24.10019943791051, 10.905368731867883, 2.4625375386207335, 0.19547966789574395, 0.027210085179596662, 0.04521802180416642, 0.02538812891279738, 0.024450619239360098, 0.010898366810814028, 0.010505903797644761, 0.004139112725463366, 0.021830784314642512, 0.03228384911292984, 0.01495051610794279, 0.04636627268947421, 0.05748860147451201, 0.030685079156331, 0.040390139535790494, 0.02287220806934901, 0.046048706262222225, 0.037416029165709214, 0.017499064636086265, 0.034477097553110896, 0.05727364869427778, 0.048458022140567346, 0.02363038613581129, 0.03590174913105946, 0.0459137751961187, 0.04857212327600968, 0.02617428259503457, 0.02393459198966382, 0.08338906126277101, 0.03319335635751486, 0.04329400347365488, 0.050724420486198324, 0.08989733824085805, 0.05985633410032719, 0.07062383777191562, 0.02031138298221894, 0.023571567820204843, 0.011341502709734825, 0.055529201373217575, 0.13174813931747792, 0.006116256859499, 0.03769381647749293, 0.060158306807880445, 0.029153487449812315, 0.038015768758111426, 0.07669688487846045, 0.035595700835749026, 0.032326562345148094, 0.043902361555205244, 0.009271812760421346, 0.05921375487119921, 0.009689168843080201, 0.04520798222191873, 0.00985936102111854, 0.013850253927821835, 0.026309311337348436, 0.03014169107641905, 0.03517892985274235, 0.034508342449102676, 0.018699763815910108, 0.021837571853651636, 0.023885840069382422, 0.023959966736935803, 0.026475337912298502, 0.08020836379258864, 0.003796040118979891, 0.024601741573743285, 0.038719845695361015, 0.031021985473231446, 0.04962599978992536, 0.018044138109431635, 0.004447715445196316, 0.05296303282281565, 0.023961644469489975, 0.029825900057931582, 0.02520045652354677, 0.07125762231167286, 0.028205126140927596, 0.012902679774279316, 0.08059423461916947, 0.7065611765269311, 7.310312015395011, 23.921262871834543, 33.02545470576133, 31.66422163286517, 26.4702739638667, 13.748950804433516, 16.28636540905122, 22.312106586271717, 33.60645186516547, 28.52692561764871, 13.046031671185649, 2.7754004924528064, 0.2362438345388059, 0.18485352276794373, 0.2108557573369434, 1.0716779457945977, 3.6181168210121895, 4.16898331334514, 10.839616079484264, 15.193479330308977, 15.272206202630075, 6.963900539182848, 3.5041351952860436, 2.6180423555835604, 1.418327951142865, 2.8969439575749063, 1.4526944102779513, 1.706761648097346, 2.1788354458347445, 7.037611680646097, 11.903196169484048, 24.546361200271118, 37.42069013657109, 52.19212831989412, 59.29888648371543, 59.85876560211182, 59.8370905845396, 60.12765192216443, 60.343115560470096, 59.81540379985687, 58.98148044463127, 60.13511227023218, 60.77179139660251, 59.974859914472034, 58.16780828660535, 60.39285121425506, 58.20943640124414, 55.27952394177837, 57.34254160235005, 51.95422872420281, 55.61613782759636, 57.600437441179835, 61.19884729385377, 60.247629380995235, 59.03382447458083, 58.14242270685012, 61.16268696323518, 59.01454994755407, 57.96973643764373, 58.717689283432506, 58.422832950468994, 58.921699600835005, 56.09072892896591, 53.5310136887335, 45.6325682517021, 32.37993455702259, 29.094904430450935, 21.312721967697147, 7.690603454266825, 1.0435565128441782, 0.5136865599741859, 1.9148881252734893, 2.935828129130025, 3.1457722571588334, 3.1558238210216647, 3.550079388003196, 3.485328901198603, 4.482002181391563, 3.627516781130145, 3.1295267804976437, 3.1682091951370244, 1.7227489837715704, 1.1086066932447496, 0.5547547869143948, 0.8372205363646631, 4.86472450917767, 16.806293226057484, 21.58654262942653, 28.34728890849698, 28.77795534749185, 30.303394525281846, 27.487597542424357, 31.181036618448076, 15.326996810974615, 4.054135334107184, 0.391594851689954, 0.1566364360792983, 0.010595470009702108, 0.0376429635610792, 0.05260750290847594, 0.056538162152132684, 0.04317588037661007, 0.0579298566275787, 0.04347889879417997, 0.07958609355433334, 0.0380941012483691, 0.05252026847653812, 0.06478421765589906, 0.04460303706207103, 0.01863992851858418, 0.032995648216456175, 0.025482836532436555, 0.053961490536288875, 0.08428317780095725, 0.06275883823212597, 0.036700219591899265, 0.02985397334991684, 0.049641968892706986, 0.046949005129957394, 0.022204284736466025, 0.024930944876565088, 0.046332530346849275, 0.059443171391443866, 0.09696263774868943, 0.009482543438582892, 0.06250506777676844, 0.04134673437464141, 0.10038915751201492, 0.02435069073051695, 0.02962535930677287, 0.03566800804448224, 0.031614292097548326, 0.13466399253135727, 0.0979423109862593, 0.2904215419004041, 0.0671645600889479, 0.13543682202937143, 0.1457317720257467, 0.15534162491319642, 0.1259866525088587, 0.19938356002732632, 0.11394039487406132, 0.10345872626790117, 0.14169208314870635, 0.10214397383313026, 0.1354101315260895, 0.125872696930122, 0.11920735660579898, 0.15391636429534805, 0.10718953615475087, 0.17020019131802744, 0.1608899707395223, 0.09493330148078742, 0.09770094732483549, 0.13429368095051858, 0.11712762707423781, 0.1875232319317518, 0.10434504403101821, 0.09264200144717771, 0.16668619197462836, 0.15396948483201767, 0.17096022714770612, 0.25918191659354395, 0.2237198444744272, 0.13338638770003475, 0.09256959081657472, 0.16664692230762976, 0.1137147973021192, 0.07925525082335358, 0.10975871926113483, 0.13318544283749598, 0.1572557722008036, 0.22436066170132932, 0.12873966607355303, 0.22159534476457105, 0.5993292144229335, 7.704698001184772, 25.728989147370864, 37.97029264511601, 38.33352765729351, 37.49009647677022, 24.246288114978423, 21.012362549381873, 23.132960604083156, 32.564358518969634, 31.860928497006817, 16.958232118237405, 4.455896846709713, 1.242411732673645, 0.45934684033836093, 2.210568891417596, 4.287991456447109, 8.505370443867099, 9.670073159279363, 13.75085021218946, 12.17526549293149, 10.739442667653485, 7.7618086914862365, 3.898530006408692, 3.677431147906088, 1.7258672680585616, 3.6104103442161315, 1.7781489078075656, 1.4602014590655605, 1.8985518212279968, 6.035772148639926, 10.972413805223281, 23.269153141206314, 37.55805938474594, 53.002682193633056, 59.328731798356586, 60.149134743598204, 61.502713311103086, 60.837408727215184, 61.38347325786468, 60.83671446769469, 59.289492407152736, 61.43484061764133, 63.7386094370196, 58.316485727986986, 58.85482318939702, 60.52237179971511, 59.23519111448719, 56.127407012447236, 59.24210233073081, 57.01685543983214, 58.990039056347264, 57.230899180135424, 61.79265883661086, 61.44750987329791, 60.04272868556362, 60.298765320931714, 62.2390990872537, 59.07787661398611, 59.08146166032361, 59.13370763101886, 60.373070701476074, 59.80799052023119, 60.20450292095062, 56.43964336764429, 45.282390809828236, 35.396813807948945, 29.248735866238995, 19.124445376857636, 8.380895007041193, 1.060184052874965, 0.9409827330420095, 2.5881855189800262, 7.002252003838939, 5.810093187516736, 5.0336850170166265, 6.546143601017614, 7.915118452041381, 10.153671003157093, 6.18354695458566, 7.209993966164128, 9.03599456433327, 10.222150683403015, 5.572518658253455, 1.5847525240913516, 1.7376826727582564, 8.256215606966327, 18.25392826910942, 27.195512363987586, 29.901312358917732, 37.44224356066796, 36.69648724217569, 34.97101699152301, 34.310332959698094, 15.671683915199774, 4.006044869461368, 0.4714349723390995, 0.16012107893343897, 0.09170191963353465, 0.19100219041349428, 0.16247701380522023, 0.1911891311887772, 0.12691555709968652, 0.18770677127665092, 0.18997036191003938, 0.17195577372706708, 0.24183226208533012, 0.13562324186486585, 0.15062043954047466, 0.1505720381054186, 0.15681721750767003, 0.12966649456610604, 0.12212360052451973, 0.17111068681603478, 0.11819550767540933, 0.174986555451347, 0.13172488088809675, 0.1389741564109441, 0.1851832929758295, 0.23865713407435726, 0.15794172732820436, 0.11077428371795725, 0.1129100449203003, 0.10846650513309626, 0.21897538535056577, 0.0982440423761164, 0.13134226593519413, 0.15128590947678014, 0.17468177503155125, 0.17857817482323418, 0.16126015974629312, 0.12547577911567304, 0.13053920660768786], [0.04912498977876479, 0.07267155248912112, 0.05979980447239453, 0.07297522208142666, 0.018541616455261267, 0.031978607125159715, 0.014555527877453116, 0.012167956447228791, 0.031145275833325523, 0.09387971608028298, 0.04090553667816905, 0.03505636344573671, 0.042379489844484676, 0.043189122206381256, 0.10076771219891888, 0.018570358158960458, 0.011740152840502562, 0.032083429020619204, 0.04470411853324022, 0.016677942870545293, 0.03935613534263065, 0.06672321683576991, 0.07614500279868804, 0.02876293965645375, 0.0034943568490205276, 0.053495100038426543, 0.050266502920778534, 0.006333968513870553, 0.01326554210766429, 0.06942199903630442, 0.03378630458046833, 0.031345818499704046, 0.07163294410753636, 0.017245751918263493, 0.06192708125097617, 0.04145511283328937, 0.018589550576683496, 0.0680647210608567, 0.04639446089464811, 0.04174706511079304, 0.059603613185425924, 0.08144099160187668, 0.0765787541205364, 0.0014552268652140254, 0.40626558865750995, 3.778864376006588, 14.19781311865776, 23.435047826459332, 33.03145985449515, 22.564534641081288, 13.530166879776987, 13.223744457767857, 13.272177884655616, 18.994711022223196, 28.10198191673525, 16.74488263745462, 5.679847944167353, 1.2821463231117496, 0.6094330561257179, 1.284571205896716, 1.8067540180298591, 2.8858544365052254, 7.813802649897914, 19.266427332355132, 24.675203215691354, 8.593744385627009, 3.7525060484486246, 2.3946704835660997, 2.184914139009291, 2.5048356431145824, 0.4124095831667224, 0.6250431701060265, 0.1954912051798836, 1.0727472819628254, 1.0104702172740814, 4.709221653399929, 14.866381114529027, 29.738912505488244, 43.491197324568226, 49.66157590189288, 54.59944378945136, 59.50859208260814, 58.912129017614554, 60.99668441280242, 57.9978794436301, 58.67692409023162, 58.36532708137267, 58.06483430247153, 61.7713721336857, 58.83656847861506, 56.21063578513361, 54.77578178528817, 52.53450808986541, 56.0822016962113, 55.959855125796416, 63.56821775436402, 57.89028098506313, 60.92115133039413, 59.49264764785767, 62.32158260960733, 58.93064260482789, 59.18637329532255, 55.299414280922186, 58.89916950656522, 55.32602756254135, 55.66064103957146, 47.72214428071053, 37.45498734135782, 22.616796301257228, 14.613855000465149, 8.631383449800554, 0.9958533822528779, 0.35266017961886625, 0.10800610161236218, 0.300575822832123, 0.8268966129229915, 2.017110485223032, 2.045186075472063, 2.6179303228855133, 2.058665300569227, 1.729230455333187, 3.1577543625908517, 0.9518119067915025, 2.4924728226277137, 2.143533623987629, 1.0355949594128517, 0.6417272167821085, 1.6894529639713227, 5.770542948476731, 16.6912010792763, 20.581135211452363, 19.662673011902843, 18.54325209894488, 24.319920809038226, 29.258618277888147, 26.084820685848115, 10.416806147944543, 2.7837664177340846, 0.1635204408798487, 0.06628517542154559, 0.029351622684888785, 0.026742593430343176, 0.04978467958168157, 0.04565445826418939, 0.014817837340336655, 0.06636031332515901, 0.021169527861920577, 0.057264252625886476, 0.031339647661473964, 0.044785779675528894, 0.03401395909848713, 0.05990071740422038, 0.02058001171286789, 0.023587573312162876, 0.07416466551442301, 0.019570112476245533, 0.025313165294186726, 0.03143231940245436, 0.06288410126862508, 0.05004332235623753, 0.016223625918369622, 0.040542962585365584, 0.15466366774372517, 0.05864930511902898, 0.03315919266653157, 0.05147281944030716, 0.03585487987185198, 0.048715963944672584, 0.030866385354930838, 0.08460665842698467, 0.05786909819430402, 0.022225262139052637, 0.02692915690732339, 0.02538141606736087, 0.07759651724970149, 0.01089813794204665, 0.03919317694981733, 0.07392744638866956, 0.03705743873011201, 0.02775100454117262, 0.07391573290430731, 0.03678528599501137, 0.0270382784712579, 0.02781375097261081, 0.037996298633515835, 0.0358451122508174, 0.03419922214121588, 0.016441599000245333, 0.023705403380576643, 0.03645241696147188, 0.06885798978469065, 0.0176464905962348, 0.03800944470229649, 0.057848042267705166, 0.03613739394612851, 0.024129739481835596, 0.052094947952296466, 0.02397260527246662, 0.028850949752414902, 0.030898637656543045, 0.07231053355480395, 0.039934669621288776, 0.08079424485444062, 0.021563172565713044, 0.06594055842968725, 0.039067055894843036, 0.06674377863565761, 0.028895041942896865, 0.014930942561477424, 0.03751938974845313, 0.032628688270286206, 0.005351749470367307, 0.024516418531176545, 0.027007826476267753, 0.03417088071845713, 0.029831425467085455, 0.08109213048291784, 0.07711371331806145, 0.09205184561470825, 0.04843549149471426, 0.6806389062154679, 6.702889848139979, 19.952838190140266, 29.033617396508497, 38.88009817369523, 27.37254854171507, 14.117198605691234, 10.898685013094257, 17.509132931309363, 29.450057398888376, 32.91877800418485, 16.946680738079934, 6.233242404076361, 1.2886064667855541, 0.026221781961559772, 0.42874692909179196, 0.38413922272382245, 2.630026912496936, 11.560836011363614, 15.585608482360842, 17.300639344799905, 10.17128146463825, 7.395382831173559, 4.707881673689812, 3.8332164143362357, 3.175336386888258, 1.720300689339638, 1.421069565319246, 0.8674576590138098, 1.8596295291377654, 2.2933537008300906, 7.3175159385127415, 17.54435581545676, 33.24606841610324, 45.71519297938193, 52.701781488234005, 56.22854924971058, 60.763719158787886, 58.57300089251611, 61.11566951197963, 58.45150547642862, 59.49060017062772, 60.39980949894075, 60.72379335280388, 62.854052205239576, 60.655293080114554, 58.355034782040505, 53.32827814163701, 53.63936132000339, 58.6798894020819, 58.428736117578325, 63.62526862852035, 59.77703517483127, 61.71016746951688, 62.008338205276004, 59.97315760581725, 59.08427007736699, 57.614220649965354, 57.39553674574822, 58.306342478721376, 55.915818675871826, 56.52845367308586, 51.523756442531464, 41.95215732820573, 26.75524788518106, 18.332285458041778, 11.132017008719906, 2.554034422482214, 0.3663823771620951, 0.08180659174198106, 1.1274876349395322, 2.6172171869585594, 3.4493333101272587, 4.931828418085653, 4.634544137985476, 3.678937092904122, 4.028193758380029, 3.3483236980053688, 3.098597665948253, 3.762148705220992, 1.595781616145565, 0.9171735783738475, 0.4495922121549807, 1.0409569620124757, 6.106912666751493, 18.515746478111513, 20.1250361242602, 22.855005764192153, 21.524129875244636, 27.975499206973662, 33.393412251626295, 30.639949575547252, 15.80431886257664, 4.991910794088918, 0.31192253493974287, 0.15716111437687952, 0.014564879895788769, 0.02578912423022332, 0.0663586815578803, 0.0228286617165131, 0.039990705122510274, 0.043634406981929656, 0.03721460166777815, 0.06388686439623276, 0.08372068540343354, 0.04993751795301515, 0.07411496172989569, 0.009303542207025233, 0.03798049040919831, 0.04714613104419363, 0.023529011636011066, 0.03926613150284656, 0.05457756695367637, 0.02327566252901189, 0.05472855905311243, 0.050139477882053585, 0.059939730431764364, 0.04983452126203526, 0.0379634679355208, 0.047929605333915645, 0.026459363063857443, 0.028139834382360982, 0.04852337710138771, 0.02406558536383654, 0.019565447000786662, 0.058705283163656155, 0.07143052835618297, 0.029257822879439885, 0.06177166116333777, 0.06719455243118348, 0.028779261159680547, 0.035737549675808805, 0.1226615168214325, 0.1978814914341896, 0.16023540989525858, 0.16554735630991, 0.1841794726468863, 0.16527449111303977, 0.08524847156818836, 0.1355243858791167, 0.13468211817164577, 0.228036382205544, 0.13954636280334767, 0.10190811068300279, 0.1085206139231882, 0.12665251315000559, 0.12975494707784346, 0.16914821470216398, 0.16317688108932588, 0.18283494237449863, 0.23214932440990405, 0.11500312736438167, 0.16382969525312224, 0.1590231063986017, 0.22716445157364493, 0.16503648291672432, 0.13235048360882268, 0.08464471767506293, 0.14068849264614045, 0.09426439180970193, 0.1548222939093267, 0.15037814125178323, 0.16385427135373318, 0.0749920174900082, 0.14072120460050722, 0.08170565199707785, 0.12347673396429709, 0.1063798348449411, 0.09671402689550193, 0.1945253981337432, 0.24163710884749892, 0.15076599624608794, 0.2633720498171545, 0.16242862769192265, 0.2152259671880353, 0.14557087823988932, 0.5916747090316589, 6.438147512174423, 22.03300053073514, 35.13191653836158, 46.56448810331283, 35.321398396645826, 23.097882847632132, 20.85580114395388, 21.263857080090432, 26.347309620149677, 35.84403853262625, 20.616073723762266, 7.34730928174911, 1.9288368090506525, 1.8273587188413067, 3.15143199216935, 6.363570017199363, 8.196564201385744, 13.892468367853473, 32.37181721195098, 42.701004474393784, 21.990340832741033, 7.195271840018611, 7.6016445890549695, 6.252867002641001, 5.5407857029668754, 1.4359163492918017, 2.2269690565524565, 0.8240495237611956, 1.8644187431181631, 1.9330479637269053, 5.653876950663905, 16.230579499275454, 30.800676538098244, 45.843442716906154, 51.047600315463164, 56.97942033890755, 61.555347596445394, 60.2949566994944, 61.023544803742446, 57.97591417066513, 58.82331871217298, 60.88934090829665, 60.700929857069454, 64.00796644149288, 60.428305518242624, 58.673013487169825, 54.35547628710347, 55.65847981360651, 59.60420377792851, 59.00126095741027, 63.965400880382916, 59.7930698240957, 60.07735929181499, 62.178757344522786, 60.866567627076186, 61.05751645180487, 59.869371691057765, 58.5540166208821, 59.74445596818001, 58.000946737104854, 58.523025974150634, 53.822516395199685, 41.6653222422446, 28.857157807196344, 18.058031374408355, 9.855252177484575, 1.7561765255466586, 0.6432384937520951, 0.39284421852038753, 1.966890296147716, 3.311811334663822, 6.294580919127311, 6.1885872002570865, 6.374104032593389, 7.204921851235052, 6.257418422929703, 11.267217186189468, 6.151733100414277, 9.091074447478018, 4.89778567706385, 2.827201028985362, 1.4031565910385502, 2.20374372216963, 7.814931311914998, 21.886129340817853, 27.52530917044609, 28.160178122981904, 28.008721682333178, 34.24676310631537, 39.341576791578724, 35.23657714166949, 17.076670046775572, 4.204470467182898, 0.4472849085446327, 0.3539682900713336, 0.12680403768054901, 0.1544321559730076, 0.15715457198600616, 0.15965414834359, 0.07781832268641842, 0.12043093691670126, 0.1790049930493678, 0.1773162441508424, 0.16257761647143673, 0.1455040140858581, 0.10514054973159107, 0.14995195121774751, 0.1594713444430982, 0.1830093652730988, 0.1768963360377858, 0.08042284542874945, 0.10619519233343103, 0.16299997606585104, 0.23062454897069165, 0.09281126857404748, 0.09552264526005715, 0.12270846268943242, 0.31008505773159767, 0.15746260061860085, 0.1233852094399833, 0.12717939778080872, 0.10966927849597509, 0.09831317415040347, 0.17203541622767526, 0.28065667878235545, 0.16482726430460332, 0.12793207150553504, 0.1537989843035898, 0.1861667813312623, 0.180717904361025, 0.1506579931705229], [0.0086517000172828, 0.08676336447317755, 0.015881673954877884, 0.0163252072619094, 0.059869349934160716, 0.04049451135459446, 0.05279797917952942, 0.06629063762844571, 0.005747474102874197, 0.03095438970523256, 0.06893662871011803, 0.10737518224144176, 0.00838052787472524, 0.051941707384802645, 0.05191262285675734, 0.07209144006933897, 0.037303862402275685, 0.01238445959789979, 0.07323507910534259, 0.040722847690865885, 0.05792887986547524, 0.01869726445405714, 0.06426603578391575, 0.08292452086724582, 0.029169923866227753, 0.04541219061901493, 0.03191630885515723, 0.04849078772108882, 0.015594483871433525, 0.03468788281503705, 0.03438332073029972, 0.050642724869953054, 0.03504300670277688, 0.00901839183267927, 0.007166293357694222, 0.02284427075797031, 0.03673357506012244, 0.019589733903206164, 0.026196968373692325, 0.05145112383029154, 0.030664358393199025, 0.03808477795833061, 0.043888905220815254, 0.0707019021313998, 0.0143242028406671, 0.18198377272534758, 2.5086685342173425, 12.505963463937084, 25.38808418858436, 29.22814734520451, 30.283317873554846, 21.944447140539847, 15.652982054218171, 15.329796402685105, 17.39363874158552, 27.487291597550918, 21.54412807956819, 6.957378618178829, 2.098029227026047, 0.28296913050355454, 0.5423566650959754, 1.8155490751228027, 15.712754072681552, 18.71320055377099, 18.535301454605598, 3.682176970666455, 3.616097045521583, 1.9483735220086191, 2.0783278970949115, 2.038806340386791, 1.4381685252151182, 1.0013041284776505, 0.842288667636533, 0.8792477521684863, 0.5651711924902855, 1.166856586933136, 3.452588877370281, 13.215817347649606, 21.546789407730106, 31.418963670730594, 37.24133976044194, 49.577970581669966, 57.758108877366595, 62.22526096528577, 59.913694474004934, 60.81068954160137, 62.16375820098385, 59.42232347303822, 61.63902351933142, 55.73059651159472, 48.104175290753766, 45.54871582215833, 47.33218616054904, 60.47443259146906, 54.3086745662074, 61.28145240968274, 56.47020647602697, 64.00511487837761, 60.57257029318041, 61.49106779406148, 59.48275543028309, 62.88013204451531, 61.36300633030554, 59.67013489815497, 54.34148127032865, 46.26448169831307, 27.768566723792787, 16.843402770257768, 7.4551646555623705, 4.542719981362743, 0.5958096839247212, 0.5863937278909068, 0.21280381167607926, 0.2429904644527743, 0.6052345265784572, 2.5817545479343784, 1.873881093436672, 3.834917252102206, 3.101616910388393, 2.397650504304517, 1.9242723959107555, 2.723428107077076, 3.220988363027573, 1.4250296883044706, 1.2292928753360626, 0.7198915354186489, 2.2997780528760727, 6.903472014011876, 15.04349377847487, 17.03069398480077, 21.024953357635006, 14.420146788320235, 21.45078939776267, 25.796573546624955, 28.987402069953184, 12.177652255181345, 3.9505894193726205, 0.21258397508532773, 0.047971889556896304, 0.04603841387095951, 0.052351303954398444, 0.10649126999440695, 0.025173758359385595, 0.04730595230695702, 0.052893326482585365, 0.032569737804512826, 0.03500096379749237, 0.08679720257679302, 0.028664809539012855, 0.06967011193234114, 0.042057874642552874, 0.03674721908605388, 0.013127818651076768, 0.022699238822585153, 0.09636020152679375, 0.036932413180869435, 0.08108758758152686, 0.026897739641548648, 0.019688344740819548, 0.058553444537063765, 0.03281918369353779, 0.04728730572688003, 0.04178104111023488, 0.0639542916248883, 0.06238712471038584, 0.02713174694367955, 0.047177073335455316, 0.03970411546047657, 0.04931775282227224, 0.08513964111766509, 0.051482004834519285, 0.022970711654652993, 0.023883311979232297, 0.010603081093229836, 0.02220088139086241, 0.06618838787319199, 0.09422149854682146, 0.06199931185091696, 0.04648302065869493, 0.03958868133204599, 0.04657115524394378, 0.07644006156272466, 0.03379175529604958, 0.10099068975015994, 0.034682091190329487, 0.08693731239726467, 0.031143176752412995, 0.08465411757389385, 0.017250518900372328, 0.015982331204859, 0.13386821103913168, 0.05187401585581322, 0.09428267066757526, 0.04100399429819757, 0.05898820709497218, 0.03783859560386308, 0.06285163063195444, 0.04766690995424025, 0.038677883229308554, 0.10774541721348802, 0.024556124868292003, 0.04370534289327841, 0.012494254361597762, 0.10313388966624776, 0.036314486661144806, 0.027931402925582185, 0.031070658869500604, 0.028604210068982457, 0.06253884459334998, 0.02817984140898672, 0.04054030426026833, 0.06185334528826418, 0.05471168596658015, 0.054060606991932283, 0.05481799598783255, 0.08616030005918396, 0.031049275440314127, 0.04942698163851615, 0.017824347483955564, 0.07482104198706728, 0.06942369975149632, 0.307673167797827, 4.561621883223134, 18.055350434395578, 31.01321016588519, 35.14125570174187, 30.322941657035585, 22.0586371421814, 11.61071385106733, 12.201088416960932, 28.53285231897908, 37.54608046623969, 21.02711262241487, 7.583083443103298, 1.1391132949821412, 0.05692160064955393, 0.37877191879576255, 1.271768221932073, 2.6918616073746837, 4.508079569185934, 6.610249838521404, 4.815595842176869, 9.226108904807798, 6.205536742364207, 3.4323835228720023, 4.072018890611587, 2.903218524109933, 2.9444509696575905, 1.836962151911951, 2.7084147449462646, 1.4229166339482031, 1.9404722750186922, 4.863942486624564, 15.815828077254759, 26.328413601844545, 34.36967449803507, 42.94831775849865, 52.53939536310012, 60.602341082788286, 61.422489073968705, 61.911483118611, 58.84438576236848, 61.640023723725356, 60.96510541054511, 63.111434213576786, 60.05946936145906, 53.163012996796645, 47.677064480320105, 50.328610251026774, 63.34234414562103, 57.707298494154415, 62.100937520304036, 57.915054675071474, 66.659363162133, 61.932710985983576, 61.466682418700195, 60.31212099136845, 61.342778667326904, 59.84504907361923, 61.216054731799716, 55.11209757097306, 49.73100185394288, 34.553347326094105, 20.939239763444473, 10.376169412366806, 6.570945728209711, 2.2045809030532837, 1.0665260351473287, 0.8798839115808088, 1.1073458963824858, 2.048355350571294, 3.196350730234577, 4.9861287301586525, 4.648007183305679, 4.927251502390831, 5.294491254514264, 4.532992503335399, 2.7843415352606007, 2.6431597432782574, 1.632985542378118, 0.438198370318259, 0.39509697667052673, 1.768967619826717, 6.835024693319875, 16.856240687831757, 21.007481159702426, 23.162739238431378, 17.551796551673643, 25.115195089770904, 31.122004947354718, 32.984112924145116, 16.967328094667007, 5.63766481414918, 0.5251647940566463, 0.07647747729694651, 0.050937730007834976, 0.09132266014574036, 0.08237037116721754, 0.037064632295721, 0.04953158711413703, 0.0340426605825703, 0.02351490604210525, 0.05086739547550679, 0.0352913877295871, 0.02744388946842763, 0.04521476593048823, 0.05292763956071389, 0.010159597581913395, 0.07085393994085251, 0.051240009150557944, 0.06024048122907839, 0.021496856164547707, 0.10113108302316359, 0.058659348531716296, 0.06524334947067885, 0.07663329191986593, 0.014227873029848261, 0.057683743221024354, 0.034072683568322853, 0.05963120001157927, 0.061807000799284834, 0.02651117359017653, 0.011537689208653907, 0.13666216434249956, 0.02668764577397416, 0.07335405255998335, 0.06293401572733157, 0.020575009158722336, 0.035809159744530916, 0.020241578965778315, 0.041784174409845186, 0.05189496453010267, 0.14502177705928204, 0.18130046826216484, 0.09659517601492906, 0.15601247278673036, 0.11182596155953024, 0.2117401139149743, 0.2138942152622246, 0.18641776705701507, 0.10994274124142625, 0.13243046318811755, 0.13648662295552993, 0.19321384028561656, 0.084976832111997, 0.14625459639055116, 0.25603603781952017, 0.09547315598014863, 0.15791351997083233, 0.08241255962920767, 0.13584373729123225, 0.16701435339787316, 0.11352194998894008, 0.11795696321754687, 0.2788489870727062, 0.24292550019679532, 0.0961254875085527, 0.16081924550235271, 0.14153570928160222, 0.13822931976568315, 0.23686893164150177, 0.17311408334682066, 0.15240268180927924, 0.11848131209732064, 0.11342405161309628, 0.12748217105024284, 0.1371735893189907, 0.12942647921942896, 0.11779772418160593, 0.18240156643573316, 0.14101299216910718, 0.1527907206646858, 0.10701161989521597, 0.10225713268042573, 0.16208143664463875, 0.17098572255382616, 0.10897726361309329, 0.36339843405350564, 4.223351286303613, 17.71127227813967, 35.254847541932136, 42.976782398839156, 42.34841869723412, 31.5748720015249, 24.27450760718315, 24.614530032680882, 27.591801189607192, 38.02652766627651, 27.902221487414455, 9.658392340906206, 3.1722686031172356, 0.7380875945091249, 2.162621348134933, 4.297031539101755, 25.315698808239354, 30.75563007785428, 31.60113423101364, 10.870232139864276, 9.894427830173123, 7.764014044115621, 4.212394145227248, 7.373035127116789, 5.4283401754594625, 3.8168829294943043, 3.436068834797029, 2.711625695228577, 1.9778437600020442, 2.3049268991716447, 4.739270440993771, 15.837605076451457, 23.06043794078212, 33.86221001225133, 39.675527388049716, 51.18918218920308, 61.259467524866906, 64.48908044445899, 61.87026293047013, 61.59268856048585, 63.393319268380445, 60.15056248634093, 60.88288076462285, 60.687789916992195, 52.938167049038796, 48.125030532959975, 51.742648232367735, 65.59954266394338, 59.18369039412468, 63.2267205176815, 58.127564768637384, 66.55863669610792, 62.16063207195651, 61.611661065009336, 60.68729962072065, 61.505423668892156, 59.77789025152884, 61.177133052579826, 55.74382666618594, 50.023712650422134, 34.195482038682506, 20.814086737171298, 9.407095889891348, 4.888170967178961, 1.9245388719343373, 1.2673766382278935, 0.6478217220114124, 0.9826138507454627, 2.6816575613714035, 5.9283286236947585, 6.134996837185276, 8.178138377205018, 8.263060142917018, 6.02708556959706, 8.979713455323251, 6.39455674156066, 8.304519595638398, 4.181596675226766, 3.6152081383812815, 1.5991818207886912, 3.6164270149123285, 9.344904749624192, 19.48813146160495, 23.977223327082974, 28.69828220336668, 22.329637619756884, 31.825884080702263, 37.09115220654396, 40.0442615632088, 16.93550394427392, 5.45066140351757, 0.37672266424182926, 0.17218351634519716, 0.1775638897332453, 0.16835686119814075, 0.24024702698713352, 0.08529752417798005, 0.16137360204612056, 0.14210353365107892, 0.14941262531905405, 0.22729860889094494, 0.11551029289201384, 0.2110011148596964, 0.14477662892351228, 0.140712394589378, 0.12113383790898709, 0.13895321156709425, 0.17050881749920307, 0.1608997613431946, 0.13587102534309511, 0.16509318874487955, 0.2480896069638191, 0.2986490810590406, 0.12808238561715812, 0.07440161650940295, 0.07384864658477806, 0.14507295173262397, 0.22272343987659102, 0.16029988385496602, 0.12158312549393986, 0.22319774023227154, 0.20471059837408606, 0.12907643832506674, 0.23494301724337766, 0.2382124813213464, 0.150614739846318, 0.2858488243674078, 0.11265709800946136, 0.09463420543338984, 0.15034475514004308], [0.03473743721241913, 0.049463512541185466, 0.040653367346573266, 0.023095511207957903, 0.035292402796086766, 0.012488122785373802, 0.06734555602193841, 0.029756339274406917, 0.0062827876160642315, 0.041471752263004744, 0.02973048955262188, 0.03348918120947576, 0.040048755434972626, 0.10292102447560719, 0.04088805838217659, 0.04956271709694017, 0.06435709299459573, 0.022786999939970916, 0.047837502413219025, 0.03354564571993486, 0.03294441608651992, 0.06808670778428355, 0.01779450261364541, 0.0728165346287912, 0.021508715205615567, 0.010016047069051815, 0.04008999394793664, 0.04292874041223719, 0.03332083721855476, 0.04171681612910282, 0.05642706025091391, 0.06791547181144839, 0.07274425423313534, 0.03298841634645097, 0.038238899526937355, 0.04192754393443466, 0.08468708999815487, 0.02488896325831452, 0.0038622126392569515, 0.036939779116261395, 0.0885912042952353, 0.03967129625380039, 0.10390003121668294, 0.09749392738505717, 0.036418314557522535, 0.0533093007341508, 0.029261249207681226, 1.3958737302211024, 9.176145753552838, 19.600128858320176, 30.1012747903024, 32.380422892109046, 25.352818158365068, 24.82268825654061, 18.852154439495457, 22.891068035556426, 38.4587493250447, 32.417344162541056, 17.064989228402418, 4.603695186876482, 0.7833238606972079, 0.9940806547960929, 2.845043645751092, 1.9822190413551948, 2.514129208941614, 3.1684911154931594, 16.808458374392604, 4.838618684199549, 3.5283232263980375, 2.5222083109040416, 3.138133196100112, 1.3764445147206708, 1.4371290971194546, 2.616104704718436, 0.8163550592237904, 0.5684029803641382, 0.3437090857375053, 0.9115516574632738, 3.5353440238583476, 9.355314720061518, 16.51297446220152, 25.768165780651955, 36.25469500018705, 47.82308647709508, 54.12426825492613, 57.9081513035682, 61.137701465237534, 62.042835450941524, 63.28760354749618, 54.814503423629276, 35.574469720163655, 33.076214098161266, 34.63265372860816, 62.250317065946525, 52.1648286234948, 61.636179800956484, 64.90016837273875, 62.648849487304695, 61.6412631926998, 62.70777917677357, 61.16885292914606, 58.08648970819289, 51.54823595477689, 47.779363816784276, 31.353664052101877, 19.41273566215269, 12.091418946942976, 5.706793646658621, 1.970264147366247, 0.5635187714811295, 1.2522166775118921, 2.133523245011607, 1.1968884593056095, 0.8979217275496453, 2.276431615314176, 2.315568534597274, 4.3703700553986335, 4.1250169757873785, 4.4791947449407274, 3.9311741773159277, 4.145065190330628, 1.5101821384122296, 0.8816449945011448, 2.076054883580054, 0.8372280133828041, 3.076816744381382, 10.122810775233853, 16.432328570273615, 18.213884792020245, 17.745714610622777, 14.755025025336975, 22.903584318776286, 25.1781177520752, 26.645117536667858, 14.067582584196522, 3.933838937551745, 0.38971462677563395, 0.10934281778792221, 0.041998311306440064, 0.05278855629806077, 0.04679061645161241, 0.022958833461387024, 0.07689789868891239, 0.04454617801633093, 0.04064871336243326, 0.008107700982251236, 0.013347153454237889, 0.06168810778387612, 0.006361924498642405, 0.0614363789528368, 0.025082687742166945, 0.09695833999543421, 0.015877179891592073, 0.041719688958818876, 0.013328832461528722, 0.044966576425659086, 0.012311619000449296, 0.025626257767960913, 0.025951121182691668, 0.02664880128577352, 0.05190956616593946, 0.01160295415414317, 0.030223149205407793, 0.03881262660387062, 0.025760711944331566, 0.03502557437205988, 0.04216526484777851, 0.05843142205248437, 0.026221927518265385, 0.07824702548884577, 0.004779301281462634, 0.012863003123070926, 0.06182809119984027, 0.035293927311056086, 0.04573798483057369, 0.06833908779005851, 0.013799587745339641, 0.050871030562707496, 0.05862646037712694, 0.04112290646580439, 0.07832820016530254, 0.04935345634998334, 0.02523937379010022, 0.00617870930469625, 0.02117199083459714, 0.018486008048057556, 0.08198171178059233, 0.08730645186357922, 0.04292091482409066, 0.04872057196353713, 0.05356195270113888, 0.02931086106165763, 0.04358228235956162, 0.07796966335586003, 0.08737911530319722, 0.02060341952939428, 0.03127544949341926, 0.07240496921323, 0.038538160283238664, 0.03182275228262429, 0.007324670544720345, 0.030124850548623554, 0.04405803445185866, 0.05311051240911888, 0.03588592558498344, 0.04699879701459601, 0.026624127508952256, 0.010566409421904434, 0.06439121455074319, 0.033161387508434635, 0.010092158861938986, 0.03661134190136387, 0.1031421480940715, 0.05984471637695547, 0.03905351146034176, 0.02654727931404787, 0.10259386662754322, 0.01225017108804276, 0.03729103425998361, 0.08997050729850609, 0.07950123399496078, 0.049514660401450056, 0.061168792101764874, 3.0273132458809884, 13.768575402998156, 27.398828421869588, 37.30253657987041, 37.52109496824203, 26.555638467111898, 19.79571000222237, 13.826262681714951, 29.136685517526445, 45.741374800282145, 33.02070863785283, 19.645059608644058, 4.7303215534456315, 0.6989219928941419, 0.4126181122997115, 0.3874109391002886, 0.6136143027294068, 2.8920503104886706, 2.901789800774667, 9.059473872184753, 4.1205601826790845, 4.373754570561071, 3.1903546519817847, 5.19622411458723, 2.282151411617956, 3.378145968721759, 3.2862588090281335, 1.9217865938140501, 1.5570626744339544, 1.2107951001774881, 2.038705216780786, 6.247954234000176, 13.211157571884895, 18.721696407564227, 31.022921954431844, 41.673865164479906, 52.2821427929786, 56.67114949995472, 56.81126048488002, 63.29792722578972, 63.91477484856883, 64.39425714554326, 56.85029591283491, 41.7107746678014, 38.27545696689237, 41.827441646206765, 64.26590150402438, 54.60330732407109, 65.38319649234896, 65.66016681732671, 63.08924536551199, 61.847619087465354, 61.21786686681933, 60.67066877119003, 58.262560982857984, 55.351189567196755, 49.39523912245228, 35.5864917847418, 23.29486623887093, 15.542614402309542, 7.559448221037465, 3.3641418814659123, 1.6949551913046068, 1.623752405566554, 3.953278204125743, 1.798614364477896, 2.5115325998875404, 4.765183089240905, 4.631195414450861, 5.404053349648753, 6.179589283081794, 5.5192469877581445, 5.227508448785351, 1.8484497935541215, 2.2060233546841532, 1.5650906630100743, 0.24825756408033833, 0.3354531706821534, 2.1462052483712477, 10.008659016701484, 17.063381056631766, 21.080201902697166, 22.59064389813331, 16.225253901173993, 21.90531953688591, 30.797844586833833, 30.69052069417892, 19.622384386677897, 6.161674347616011, 1.0073587971348916, 0.10089528116007006, 0.07766718886071637, 0.06887229264623697, 0.05358480893435979, 0.05600872644854169, 0.033364239929904865, 0.07514550320563779, 0.02248528387187229, 0.021675766423164357, 0.016649980661309054, 0.1318617654784072, 0.035211875463926026, 0.009979440515199977, 0.0035789279284090887, 0.04739924649437589, 0.07615386643597195, 0.009638653962963052, 0.026047085186526663, 0.04044678024647217, 0.009465318909215351, 0.11311368641233253, 0.030116232059475397, 0.10432385403903262, 0.06983271409426967, 0.04386098514641485, 0.047518890275950396, 0.047465746756643064, 0.08501478410776585, 0.012425423276820972, 0.010900646879998668, 0.029670707881450657, 0.09050553544394432, 0.08570751145241723, 0.028333738896875616, 0.0189301360308403, 0.017917120731585932, 0.03956376815274839, 0.055836682252946405, 0.043657791815818324, 0.13148935481665597, 0.18385192409398096, 0.17673030946283572, 0.10245931094452258, 0.1419196572274931, 0.23799468252447345, 0.20027488800546817, 0.09906600875359389, 0.1615491281113317, 0.09562563812059742, 0.15108571538040716, 0.24874402991225644, 0.18597743503989714, 0.1913838707391293, 0.13613547889455674, 0.09194006572567648, 0.10074014069452401, 0.15787532282692773, 0.1296744159152431, 0.2236679650001949, 0.14328779832970712, 0.12166720364362964, 0.10672768472783989, 0.21081186049888212, 0.08969295364353927, 0.09587052578647291, 0.1993461136495875, 0.10122618517808377, 0.19508533179759982, 0.16219526198842835, 0.13133538646563409, 0.1215836157902114, 0.20529014388880423, 0.12759138454472826, 0.1432517462319905, 0.09542865393262717, 0.14731070988120573, 0.23721532595734443, 0.12010720348165882, 0.18300132134989386, 0.1679822288814091, 0.11271429413388814, 0.129556315800836, 0.19124415162349903, 0.32726920660465, 0.1519069922787528, 0.16989773980552153, 2.5035814652519846, 13.698098255741982, 29.803292328311553, 44.532433632881414, 46.60317836269256, 35.965192702508745, 36.177616503930864, 26.945261224623653, 31.917198819498864, 49.51604420138944, 39.00348809457595, 20.851600285499327, 5.695593318631572, 1.0879611752686964, 1.643628648692562, 6.02854420100489, 5.43738418048428, 8.548211551481678, 10.856992179347623, 29.157246581969726, 13.41165638739063, 8.075932197032436, 6.61858634602639, 7.704218491431206, 4.938392504569023, 3.936964576282809, 4.5452837405666235, 2.364957548918263, 2.1365194455269845, 1.3571067394748813, 1.4397588011718567, 4.6394593581076595, 10.73921517018349, 18.793609142303467, 28.57449612309856, 40.08399909542453, 52.198368810838275, 54.82483886903333, 57.980730841236735, 62.77850735572077, 64.37633191385578, 63.90738510316419, 59.524379622551706, 44.04102733058315, 42.041983527521936, 44.50496135219451, 66.64331282338789, 62.55014304191836, 67.31492457851287, 63.53993746542162, 64.00413036346436, 63.013920168722834, 62.72482187517228, 62.89068322027884, 60.16046254865585, 54.19536121429936, 49.892301482539025, 34.077634426855276, 22.07886480516003, 14.607509586118884, 7.527929034925277, 2.4790845474889203, 1.0831703678254159, 2.2191277482817253, 5.506873380753302, 3.422114757760879, 3.0092897097910605, 7.552497290795849, 8.650603063644903, 10.354331616432438, 10.054615466825425, 9.10985573645561, 10.906020825909032, 10.16289935958001, 6.8945216555749225, 3.9549439857082986, 3.7834312406278428, 1.1203208517643715, 4.408251325930319, 12.923175192648365, 20.84819959055993, 25.258494961646296, 25.68580189058858, 22.35290708080415, 32.83221129448184, 37.20494800998319, 36.64479432567474, 19.924587318974158, 6.327157674297211, 0.926943957324951, 0.18589909488876022, 0.25535569045572515, 0.13273234779555954, 0.16626200909095426, 0.11673568117041742, 0.17415508958360842, 0.16997021172315846, 0.18288176566843065, 0.10255180073962097, 0.18754442192373738, 0.2365509898311669, 0.1312277204687557, 0.1700290319539847, 0.08626811927364719, 0.22671950770722282, 0.15873773864680724, 0.20223438769819277, 0.055650362008882154, 0.14794118492113006, 0.09342596986361089, 0.16450264220756872, 0.17341596795426262, 0.1915341159028392, 0.33488923803933207, 0.11778697596802828, 0.12363677739255852, 0.20597465877090732, 0.19233683815165875, 0.16834469572190316, 0.09854961186647417, 0.13270109140824887, 0.19331810485211112, 0.2175828213653257, 0.11212370929218109, 0.09241068885932047, 0.0943258473829877, 0.0991926507483567, 0.1499959246646012, 0.20039462754803322], [0.026164166403994448, 0.028123501387815324, 0.0334997647141497, 0.038262652083029675, 0.06591096445317231, 0.02525164077298776, 0.04328594422869144, 0.07243961937004521, 0.011498859084601845, 0.022536498764830253, 0.04000351794304387, 0.09832448160816586, 0.11159710811390994, 0.08575004465397328, 0.01818921409487244, 0.0303438137991414, 0.021126473720576015, 0.060970865625647776, 0.07614404518878268, 0.047788085911663315, 0.10449351953162302, 0.08336308322125867, 0.019399401273638494, 0.0716037101923458, 0.025049881942029444, 0.050502362240466385, 0.06136890958934542, 0.060751553805124384, 0.028646779659714912, 0.04003370563770014, 0.02258751255970809, 0.016159584798339396, 0.06225625774072063, 0.009395781108328413, 0.10153817448524699, 0.019411675917405277, 0.0793371532833384, 0.021967609533138817, 0.08556884953812247, 0.03169528865856269, 0.0644047819678822, 0.023434995410723553, 0.019695143771147536, 0.07401888664331167, 0.020229101308711597, 0.027947169015063878, 0.05565662860810276, 0.025992491845822623, 0.4763176184027426, 4.670473048763891, 16.144517794732128, 26.60242057615711, 32.08382110441885, 32.37654759037879, 31.75669150967752, 19.15119594143283, 14.960576834217196, 19.845349557938118, 16.942693648799775, 8.309548074199308, 3.222577168095497, 1.337531293111463, 0.17064225469385425, 0.5129604005525189, 2.1446711113376002, 1.2466107525171772, 3.7545206758283802, 3.990419862731811, 3.462310716990502, 2.423348157636581, 2.979999410529291, 1.9020755805315512, 2.49260863469493, 2.95168504599602, 1.2959379895079521, 1.499118357896805, 0.7485176058065507, 0.04845179001530332, 0.18313164822757247, 0.46960169329277934, 2.0500118165246906, 7.788930410338987, 15.806912529853085, 24.55375682923102, 34.82977636398808, 41.828763484954834, 49.132554069642104, 48.91765917501142, 50.52304998520882, 50.205236019626746, 30.900563616906446, 28.278033579549483, 31.924492466834288, 50.42431216086111, 63.41322529700495, 50.09697468050065, 56.30774190348964, 62.53288853553034, 60.811909398724964, 55.8689110509811, 52.25823202440816, 46.77910843203145, 31.70656950243058, 19.7493750433768, 10.616325351499743, 3.112085226082033, 0.6843752089527346, 0.3620737454583568, 0.5829577929069919, 2.9275977707678273, 2.085036130682115, 4.649501606341332, 3.1331807134612917, 2.323598852080684, 1.7500877812985451, 3.210486707187468, 5.048789574253944, 5.604009407181894, 3.591543498539156, 5.967732264149574, 2.0081748356742244, 1.2384402103001073, 1.396073403377687, 1.1509055331830056, 4.887895910970626, 11.745587491220045, 18.839665612866803, 16.105998158454895, 13.625196103126774, 10.593097075339287, 20.73841833299206, 26.28858977748502, 25.769109110678396, 16.85181821546247, 4.333190889127793, 0.4296560303097771, 0.10022482399137751, 0.01400526128559103, 0.07254874093397971, 0.06718104630107842, 0.03949238407996394, 0.015919993672850394, 0.05890606714773083, 0.04269859227802485, 0.05943324289194519, 0.03025783766661921, 0.008029387644191664, 0.10126047527357455, 0.04776529862635559, 0.0386439761777799, 0.07912964304728855, 0.028407710431624326, 0.03354865261503766, 0.04200355517828176, 0.037073645320150166, 0.03959818848318631, 0.05579225681421738, 0.03758148883559531, 0.03424272061355653, 0.02887382705305373, 0.010919300163344992, 0.02644297069749765, 0.04887465139730804, 0.008038478235023157, 0.07232506624272755, 0.051289927439704064, 0.017764556236685287, 0.04240399699718241, 0.0021761208688164313, 0.07384319969963643, 0.04720497425765761, 0.04642565599492481, 0.06204645307133756, 0.04855947899481943, 0.03754881518562475, 0.04755436014684458, 0.07211830677284349, 0.023431011753517295, 0.031107270211401968, 0.04983979577739393, 0.058850257642446994, 0.031649327213545485, 0.016915931914662643, 0.019342456043006915, 0.010501186611251006, 0.04325572972095782, 0.07246617963838001, 0.02351474133320153, 0.09809661641596787, 0.05026988902940385, 0.06366874384243162, 0.01542562947443296, 0.01550208313405634, 0.024120226585035844, 0.016339318601474646, 0.022872328728197083, 0.059715507987646334, 0.049437419586484475, 0.06270305937035911, 0.018519346279302434, 0.04397577193054942, 0.03965919206459676, 0.0061306760706488165, 0.029150499706907623, 0.052838436282810666, 0.033746502482362335, 0.048389936076296915, 0.008444120833319763, 0.04829344730223379, 0.04202268439375105, 0.024863937081048088, 0.035715631900295135, 0.034562581474141735, 0.07528039596734509, 0.021629102092476624, 0.05456941960860164, 0.021186969768736633, 0.022824658907108733, 0.03904853571927355, 0.08033261559302769, 0.04492376360201067, 0.0628493132159835, 0.02861962184279917, 0.07000794904606958, 1.5902346492775026, 8.162965178489685, 22.717858129932036, 34.20076939367479, 36.62425287308232, 36.65755771821545, 29.34921326175813, 15.808925686344026, 24.771836688441617, 33.59236271150651, 26.61773939286509, 11.458216021137854, 8.335261171863925, 2.2010890130073797, 0.5505196690078705, 0.5626212841560764, 1.4208798206621602, 0.6843153928076068, 2.8265075049092694, 2.8197536737688127, 6.060999362699448, 5.059188758173297, 4.9358993480282445, 4.059903424593711, 3.169879879682295, 6.1724819483295565, 3.398075776715433, 2.9303054319274042, 1.8702139224736922, 1.1980241080445628, 1.0191509740487223, 2.000509788913112, 5.150524089413305, 11.335386018599234, 19.21784289421574, 28.919313646131947, 37.26426209172895, 43.644769883924916, 51.86060959292997, 51.7615540565983, 53.43962638608871, 55.02289502851425, 33.12887191772461, 33.08693393584221, 35.53721897063717, 57.717500578972604, 62.56187877347393, 55.96760180688674, 61.26688864923293, 65.99864775134672, 62.10824097356489, 57.97420401727, 55.007370287372225, 49.945681018214074, 35.04011346447852, 25.673638620684226, 15.316954562740943, 5.818137478443885, 2.6142114256658866, 1.8096430888099058, 1.4405040515045968, 3.3503535245695426, 2.899827144799694, 5.640555600966177, 3.6312606834596206, 4.885009536820074, 3.593766501834316, 5.427211023146107, 6.1189680714761066, 5.6844145636404715, 4.215819354980223, 2.7895857441809873, 1.6975590322286853, 0.4279138850829294, 0.16192120169439625, 0.92849102592276, 5.173733244019171, 13.004157427818546, 22.83604502677918, 22.95605386457136, 19.31100114699333, 13.365774462299964, 19.5995875712364, 30.699710807492657, 30.670891192651567, 21.003519565828388, 6.95748059980331, 0.8372565731406213, 0.07062856453440844, 0.024226674502114617, 0.025388856696325447, 0.1088340511365283, 0.01899474214071468, 0.07814658370109336, 0.08111451557206531, 0.03567677209033601, 0.02275486446676716, 0.08887677889076934, 0.03879671495768332, 0.057039896116381696, 0.048871249966924234, 0.010962718196453588, 0.0025832661964570085, 0.05139199333385595, 0.08317218943228645, 0.10592394358208103, 0.027527779926575964, 0.030639881884018262, 0.0723037766593118, 0.03224333072261464, 0.018143068788753405, 0.0790238080005492, 0.07488037549680279, 0.04310852592630733, 0.02127892330228802, 0.012922086696621152, 0.05563800884110313, 0.1260549262646706, 0.1004611008289841, 0.03233974288788534, 0.08480584894817683, 0.05951843186912518, 0.03920881280435189, 0.02572652527071055, 0.10752456938667644, 0.07681417293966779, 0.0522814252443852, 0.03220908276195968, 0.1873126190396086, 0.0908088909402009, 0.09621359528072419, 0.17316777078855425, 0.18934638329571296, 0.09170268572145894, 0.13155857852149394, 0.1421448564337146, 0.11957283417183547, 0.1468373901180683, 0.17344543169583046, 0.1500902760533556, 0.2118955684765693, 0.3278131290308891, 0.17167691772262897, 0.1323131138398763, 0.0727835162392547, 0.2072974781115209, 0.18785502461175765, 0.19652298771806304, 0.1979927580443121, 0.2027956696767961, 0.13738821651185715, 0.1432252242680519, 0.10133059530128395, 0.11796968027708993, 0.10644758766096447, 0.12907991636424296, 0.1521385806582628, 0.13679503463208675, 0.07959986015433267, 0.11993159314677601, 0.16385614060826842, 0.2603675142651604, 0.19886700226174248, 0.11165373733327275, 0.13008096345490025, 0.15943766721794683, 0.1613350218582538, 0.1849189313549188, 0.09680228022437903, 0.12324971912969505, 0.18901938632611306, 0.22519696924474933, 0.15725211030052555, 0.09195754785210856, 0.20057229865943232, 0.1777451154926131, 1.1744399993650376, 8.008565489322908, 24.197870377571356, 40.0482427689337, 43.45150293842439, 45.21582426563386, 42.57013459359446, 28.390811527929, 23.112221071797034, 28.46647404855298, 26.441458271395778, 13.027387665164087, 6.140652894973756, 2.0287476672280222, 0.6619963710827212, 2.3336852269787944, 5.496549212163495, 4.672213600527856, 11.330988061043525, 12.403367007932356, 11.173459791368055, 6.891463187433059, 8.95758540399613, 6.23513690886959, 7.093319143018416, 7.042570537136448, 3.8446643419804114, 4.196214858562716, 2.0650398875436475, 1.0348137948782214, 0.7850065575011316, 1.2196607599335334, 3.5953472170137593, 8.499968359547278, 18.52646435460737, 27.407681211348507, 36.924365182076734, 44.173517150263635, 53.19181888334213, 51.16092151211154, 53.19748278587095, 59.88687330676664, 39.523092316043, 37.95519544232277, 41.20003892529396, 61.59716398485246, 69.55889686461418, 60.546627736860714, 64.79157363214802, 66.355481455403, 63.11526244686496, 59.88069949611541, 54.22937208606351, 48.303294412551395, 32.27378149186411, 22.668634345454556, 13.026019738566491, 4.436880215521782, 1.4489802934469715, 1.2737773334787739, 1.3845545053482058, 5.559775367859872, 3.647597110079181, 9.383956847652312, 7.802487592543326, 5.762564357249968, 5.854676317784095, 8.810209208919156, 12.588957875005661, 13.2648548195439, 10.98286888291759, 12.918034926537546, 5.062503160968904, 2.853970469967012, 3.2663530255517657, 2.0969826896344466, 6.59200934633132, 14.873231534034977, 25.342041446316628, 24.498174882704213, 22.994779425282633, 17.564179474307647, 28.960010197854814, 38.18640739687028, 36.80520357624177, 23.488156718592492, 7.30732120813862, 0.6969017883942974, 0.17474877708140882, 0.11597269590223029, 0.12121079144098106, 0.21971222403789722, 0.14517563815799453, 0.1391550297698667, 0.1972658784999963, 0.13144096870335842, 0.13516358911029755, 0.1966138457458827, 0.15567387724595685, 0.26585086519199036, 0.14273189428833225, 0.1189310440132695, 0.19689510726640302, 0.106819661244029, 0.1522793416534701, 0.14631833490585128, 0.13856292041319032, 0.19825186430206224, 0.2603990464441238, 0.11168228176933144, 0.13892541789720136, 0.1313464334535022, 0.18560508566517986, 0.13930778770196822, 0.1411093200647062, 0.11204727669997562, 0.19933863663144652, 0.1722571373947205, 0.137223860008582, 0.13592328786128952, 0.14720186410892397, 0.13849335962966566, 0.12605579194402503, 0.13233966644733183, 0.2267832921877984, 0.18624107653815902, 0.1440073540734668, 0.16102814235754553], [0.0773341627791524, 0.13407873200072398, 0.021604175506640347, 0.008559903531755892, 0.023266833365684556, 0.09030981530104915, 0.015900995649938143, 0.04607197618292225, 0.017893458190824718, 0.062091782493817235, 0.082420994257254, 0.009579044661574788, 0.05091934772809187, 0.03147593853364308, 0.012841747056001858, 0.03656415088522819, 0.023975897535321214, 0.01360890463054661, 0.024294136204726757, 0.01652511407531077, 0.013713624061746223, 0.06197030393166408, 0.0399136788121635, 0.019906162689890594, 0.02495656477197284, 0.07449482642715016, 0.05336617127120976, 0.03155384584510278, 0.034499792907867706, 0.03289146791963327, 0.10441606804247826, 0.05249902868883745, 0.10127776587802557, 0.07836138709418236, 0.04465319666891329, 0.021728637981258576, 0.09477099043227012, 0.07618357532567556, 0.1322270515224626, 0.03388103901318485, 0.014341453225502085, 0.04615854028792632, 0.06821429972807247, 0.06894244331746333, 0.02917444953064044, 0.03301445950543688, 0.05466296277459591, 0.06264358796479721, 0.07982901237424343, 0.1640382243861114, 3.4269517756277517, 11.341803996793686, 28.640631206573982, 34.58090197655463, 38.06531990728071, 30.67201887407611, 20.03228383679544, 36.30238317674206, 63.46891510871149, 35.91162489306542, 12.734360137293416, 5.368629934326296, 2.8101002304784717, 0.3691522753046405, 0.5549406704883422, 0.36635207072381054, 1.6971033018442894, 1.177242900575361, 4.676494867570939, 3.5390641468186534, 4.589885992388572, 2.2577415214430903, 3.895572049002494, 6.750771691722255, 3.0901667764109955, 1.454930651572443, 1.0798742285659237, 1.5423100273455344, 0.42234041157268715, 0.5274575419964329, 0.24182827842812388, 0.48038704681300354, 1.9021149268073423, 6.108382084677297, 12.59458843738802, 17.78971968158599, 20.808626797891435, 28.004646339724143, 30.194591899071973, 32.22190226277998, 26.56050220612557, 24.3825061475077, 35.50159992710237, 35.467624356669766, 38.58319828587194, 49.66398423717868, 45.29993949397918, 45.92943676056401, 43.01279367939119, 37.7454702315792, 22.26395360885128, 16.61261639287395, 8.83459948724316, 5.288121325354423, 2.104441076517105, 1.5684132782682296, 1.5214258576593094, 1.014687807088898, 2.7317641242857906, 1.6921440776317351, 2.4910754782538262, 4.909704779424976, 1.6257588204837616, 3.212430241607851, 4.81229369678805, 3.2179137151087485, 3.0936405254948527, 4.030857292875167, 2.327641099691391, 1.11299067735672, 0.2679354517209915, 1.10168150355739, 2.506513682103926, 6.8063982552097695, 12.734548411061688, 15.002579535207442, 13.660290529651027, 9.0168700679656, 11.279168648104514, 20.940241929023497, 26.361736097643455, 24.53004610153937, 14.277803974766886, 4.486548208421277, 0.5652354213018571, 0.17729592749909048, 0.07362607506013687, 0.08549163553623423, 0.1803939104560883, 0.038330998617194356, 0.008397716014916378, 0.05810861941426993, 0.03078373787443965, 0.0252819836004487, 0.06112642743955217, 0.03734800821891235, 0.03363827724129923, 0.033122182958909584, 0.06923428451221797, 0.04919706716112072, 0.05282889848815338, 0.0565754438209678, 0.01630824607526583, 0.01685200379260125, 0.08850527221276876, 0.015458030205580498, 0.04676116420136345, 0.04588678208810668, 0.06150312053280012, 0.011955426420055091, 0.12449842712451374, 0.08815761385185104, 0.011066066330268739, 0.06709650083775483, 0.020905907431076613, 0.037825637226623875, 0.11891188415428323, 0.07746013827742108, 0.02374699237876602, 0.05739570182237414, 0.0598499832314349, 0.027953142585653453, 0.09556425915610406, 0.05912630210420298, 0.03331701060937297, 0.09527130713385921, 0.10847602760599506, 0.05690129931956049, 0.04597474047313294, 0.04134316440491427, 0.06061350093072942, 0.012171688253029942, 0.02231033237260436, 0.013895613993818482, 0.012058685496149045, 0.11643458563353747, 0.016697365114645615, 0.03466660089250054, 0.039274474200341976, 0.0583384151480371, 0.02820250228978694, 0.04278566200105895, 0.053656913129793066, 0.04330489724393814, 0.021485004784359087, 0.030114194265596812, 0.039506889954810186, 0.05429244435001766, 0.040964663344165014, 0.04242858841955181, 0.023998845699093035, 0.02012256529152153, 0.0582709955802608, 0.06048145035522119, 0.0469731675430892, 0.014460902612265802, 0.028786822447493195, 0.06519883976227815, 0.03570312551493126, 0.1143200297449385, 0.06081673256572216, 0.025445374832939238, 0.020999651695151004, 0.06273834154971185, 0.10488998535419665, 0.0064581393962726006, 0.011898362445795249, 0.02473298201127158, 0.03783763799395773, 0.06928769616229881, 0.016597601314706188, 0.06234071127349331, 0.051201428962691184, 0.06641934039972483, 0.06018189465506904, 0.6608075864853398, 6.357351589587427, 16.323125862306167, 35.139588694418634, 38.60326905404368, 40.36552721454252, 29.78302936400137, 13.399193056168096, 25.635640659639915, 44.77291807051628, 27.31411699325808, 11.910089735061893, 8.942131265517204, 3.2301951464145415, 0.6416029266772733, 0.5322340695608048, 0.10594733224640931, 0.404751523127479, 1.9310149502369667, 2.8349759021113, 3.9177665354744082, 5.287953644029556, 4.794460640799615, 6.295252134723048, 5.482337484436651, 5.748281046267479, 4.862203896045685, 3.1610807776451115, 2.1771309308467375, 1.9558461274831527, 2.875606263837507, 1.544247187914387, 2.9257343997878413, 5.01630352389428, 8.519650813071959, 16.609080376163607, 21.70547477660641, 28.075372557486258, 30.802951512798188, 35.62876316808885, 36.907887304982836, 30.815422688761068, 29.016986546977876, 40.233786567564934, 42.81653396544918, 49.68765574116861, 54.32707440468573, 52.51802236803117, 51.11252338655534, 50.20631467142413, 42.19839588288338, 27.22756597303575, 20.38695631488677, 11.78599084577253, 7.130537532990979, 4.184178575392693, 1.714925816462886, 1.9512052281248955, 2.208408400897057, 2.1064628131927985, 2.6721656707025345, 3.9880149595199095, 3.9220149526672983, 3.91521601426986, 6.255877912044526, 4.850414231900246, 5.465302140482011, 4.163125743789058, 1.8181184727338053, 1.6573634407212658, 0.7274449784909526, 0.4068792250848586, 0.23301517230368432, 2.2368779442002698, 7.3608659736571775, 15.345392727082777, 21.02993476775385, 21.150063237836285, 13.03580605214642, 13.352871825618129, 19.91667393715151, 27.774267888838246, 26.887918133889478, 19.931439699665194, 6.942074510358996, 0.9920503379356478, 0.02125753604266192, 0.042655944163280154, 0.030543869999688, 0.023146507765857444, 0.039392524519033974, 0.03835522614779972, 0.020341202954671556, 0.04796334384610096, 0.04990986983982786, 0.055161862213525086, 0.048585579610399665, 0.05874198260566881, 0.05887392209842802, 0.06390920352010478, 0.04962519539760486, 0.05648539401590825, 0.0887508646795346, 0.036677631489451856, 0.014282094817909022, 0.0774246147803722, 0.012235004462361818, 0.03332546438961741, 0.003692067862908927, 0.062452629058351444, 0.02579128459816979, 0.016511851178121664, 0.06789175372931265, 0.024982648150574778, 0.059616540919148156, 0.03126858917605733, 0.01809433027501068, 0.075077926589837, 0.04106048562173401, 0.058732360541339845, 0.07223965510004951, 0.06280715156707072, 0.030219337917984496, 0.04762592041985162, 0.022030813702111764, 0.012243737864698614, 0.06324377954907476, 0.22849428827964494, 0.2859303054790343, 0.08301544018209943, 0.15896491435987337, 0.23793584697188871, 0.13349368597470945, 0.09175386039480087, 0.1603764773256356, 0.0845816073518607, 0.31189535414018943, 0.20870433729742804, 0.16220146730061502, 0.10155528888947542, 0.1530533815704046, 0.07889831513767281, 0.1457334727409386, 0.2012570433679127, 0.16336440409143127, 0.15981639044419413, 0.11077346400387826, 0.13210182679035973, 0.10922667119772204, 0.20474695690697242, 0.05611315955437961, 0.08151434452062653, 0.09357031615030381, 0.2021854959668652, 0.09767769655633358, 0.09641872298332954, 0.1417801066512062, 0.16104939363656506, 0.14498943282711893, 0.20705982231565062, 0.29674241078957436, 0.14364638876530433, 0.08046846596464034, 0.17768004398432471, 0.273450120322166, 0.2686076479092721, 0.10337066446100512, 0.09638479294916315, 0.11855176920371673, 0.1424443661685913, 0.1670000581972061, 0.09526497158672541, 0.21521312755442437, 0.15283213537787238, 0.2554213901561114, 0.15374728869045937, 0.5323158877511178, 5.987756454175519, 17.091671151499597, 40.26419278114073, 46.25785289272186, 50.79565863455496, 41.41144683284145, 27.773579512873006, 44.30998817566903, 70.63524230833977, 45.45035454534715, 18.96676805711562, 7.853405840935246, 3.867506019530758, 0.890937457161565, 1.1983516259539513, 0.947052049300363, 6.393286874217372, 5.287347637837933, 12.030105437001875, 11.04800376199907, 9.744431491821043, 10.023037445160652, 12.336217011174849, 14.187818919458698, 7.608542077002987, 5.3405403706335255, 4.1884779833978225, 3.499585981330564, 1.629909791292683, 2.4698226057714034, 1.155633705277597, 0.845877820205304, 3.0741414427757268, 7.416458706701956, 14.27501222779674, 20.24748859866973, 22.70158225490201, 31.23762465292408, 34.68891620635986, 39.252844933540594, 36.13456456891952, 33.35936607853059, 42.83607129127749, 51.36553587452058, 53.305873563212735, 59.61107969284058, 56.06853615853095, 54.61790638585245, 50.36369585221814, 41.26464428440217, 26.550504084556337, 18.918632730360954, 10.733866037860995, 6.966773675334069, 3.3864045191195706, 2.3795825964020145, 2.930445656661065, 2.49303690848812, 5.164262681238113, 4.110277444124222, 7.904246132219992, 8.657562328923134, 5.025739765936329, 7.906256346933304, 10.586178014355323, 10.34765083943644, 8.526716962937387, 10.104142254398717, 6.585709529538309, 5.390036759837981, 1.3903310534454163, 1.9014483690261843, 2.976020165989476, 8.751028487759253, 15.86068626373045, 21.58668383475273, 21.941711287344656, 17.118017711947044, 18.802795333247033, 29.321931216024584, 37.55588639167048, 33.000269166884884, 21.66171289259388, 6.63085404903658, 0.7507535406658727, 0.3221174798184826, 0.20787726877437485, 0.2686736540448281, 0.2784750135915895, 0.16655580380991583, 0.14968742105749347, 0.11464018554937457, 0.1632787554614967, 0.19365548997396426, 0.13922336481271252, 0.08828325993231229, 0.13349409966218856, 0.2523877739065117, 0.152539229320903, 0.22075793405454006, 0.09384617675095798, 0.16819098784077555, 0.1335992528906753, 0.1295918776022811, 0.33808321181324225, 0.10750918634115689, 0.13920644959134443, 0.13429645418880448, 0.15673112454673938, 0.13120171944460562, 0.1967901838642936, 0.14250102603147108, 0.16899363348080268, 0.24505736967248304, 0.07111934344134024, 0.04234351818600009, 0.15189341720073454, 0.15099384611652744, 0.13815183763302144, 0.3262346814717016, 0.18732479983760467, 0.10329816189985122, 0.2798668114889053, 0.20180781462019493, 0.1800313670068018, 0.24676813593795224], [0.04547266943019725, 0.06618834956879578, 0.053265388574331045, 0.09184672557298215, 0.007373677189236568, 0.06061979051258776, 0.03657327116196675, 0.08238940079125666, 0.1112662883655679, 0.04216570151789535, 0.016092720644308195, 0.03115474084963001, 0.04041146742360246, 0.025302922698639096, 0.06611735620085271, 0.013243969071716552, 0.06357156941967626, 0.050113557297135555, 0.11902721103040442, 0.030871539211441434, 0.009397436815854764, 0.019295688290449402, 0.052255106293746544, 0.049589036047578826, 0.06505217222917466, 0.014924368569477191, 0.053805308191165815, 0.03660663046062954, 0.016566513466738885, 0.08395935243536388, 0.04667066240442857, 0.04345888857759776, 0.08112505694190342, 0.04928469612833954, 0.05969579271491497, 0.046241101583526026, 0.041815151175063466, 0.055923495336525866, 0.027511944889181086, 0.009203642426479247, 0.041963262783904234, 0.03725868619738087, 0.044651300601300695, 0.03497364893255215, 0.04735105190305941, 0.016430787584413926, 0.04542387729029983, 0.09961402208934869, 0.04654042745730089, 0.05283161043940533, 0.034249113617284645, 1.7015104524550901, 7.827507411279987, 25.59685822456114, 43.58961743693198, 36.368498648366625, 47.565104346121515, 72.25366715461978, 43.793561074041556, 21.84247139961489, 18.336247051915816, 12.764116218013148, 9.747865526906907, 5.394229283255916, 1.8673572112475674, 0.5381140088842762, 0.5222682462584588, 0.5285176851095692, 2.40313888076813, 3.4476491424345204, 3.854977478904109, 5.215385873471537, 1.4463580664127105, 4.306297158041309, 3.276632332032727, 3.5964069924046917, 2.9172245725508663, 1.679139949621693, 1.7487128679790807, 3.438000111810623, 3.1958410672603117, 4.675885919601687, 0.5456825898539636, 0.242880086504644, 1.9704977735396356, 3.0780594002815986, 6.6744055959486195, 4.9559098097585865, 6.483689661948912, 12.674878374222788, 15.243661153701046, 12.659296758713262, 20.067675382860248, 24.005582063428818, 18.316072340934507, 25.403038224866314, 28.12366281786273, 25.05435520602811, 15.782543824565028, 12.22370578396705, 6.653685185217089, 3.0686932706063796, 0.7819624305252106, 0.8098439247377458, 1.4831918189602515, 1.1260616082337596, 2.205927501763067, 1.694429103405245, 2.2722832185606805, 2.9040059399220253, 3.7162569742048945, 2.7105048779518377, 2.7290812230879262, 6.75775743299915, 2.262110306370643, 6.125700329580615, 4.495921202244298, 1.311150779647212, 1.0199812294975406, 0.4640696804609991, 2.3701397353602998, 4.299669823338909, 7.5479850942088715, 9.986620199295784, 16.55051938949093, 15.034803767358104, 10.79419699407393, 13.6597276695313, 21.57988048368885, 27.20850129281321, 27.528874604932724, 13.441793918609621, 3.674060851335526, 0.4395638454344965, 0.03716398623862094, 0.006014278586653452, 0.06218382795791953, 0.05139464399807396, 0.03348199913518564, 0.011091722614852893, 0.03829270188185958, 0.15924367843376053, 0.14415612834836208, 0.08243135942686951, 0.037822952088449276, 0.028115603021315994, 0.02112320827079877, 0.05700646786980572, 0.01643931797345079, 0.023525060537541588, 0.04858129334846332, 0.06007628560426736, 0.02453748977953388, 0.064927238610483, 0.0027659008393980445, 0.02823774424952365, 0.025708100856131604, 0.016551591989193714, 0.03898128086040097, 0.0165768958733327, 0.13328610679074643, 0.01340913188253199, 0.03091397282156733, 0.029320670817528042, 0.06763587270172373, 0.04820455812037953, 0.010951662590096315, 0.021466032616914283, 0.05965512493745454, 0.042538292210308776, 0.09908279374001489, 0.020279622892098084, 0.05518891660857105, 0.02569349922029482, 0.07141699158256093, 0.047945903854504715, 0.04154812356817626, 0.03493735168669974, 0.055882360245431625, 0.11633304834005334, 0.02333100089022229, 0.11570019842756372, 0.09966667531238449, 0.049965924493247466, 0.1270860576281144, 0.040489669678913015, 0.10016769681486393, 0.0594140408981231, 0.05822087810825437, 0.050752405678072286, 0.06935726460670272, 0.010821839415227935, 0.07225123834946463, 0.009416305561429791, 0.04672801940731945, 0.03398477497901167, 0.028938034797207485, 0.006186470254174164, 0.02293620513932359, 0.05406516138464213, 0.0805591248095997, 0.06707727969173463, 0.017477815272286534, 0.04707934349895485, 0.052951809634724935, 0.015473748414566921, 0.03840872972843148, 0.07915228860633028, 0.035162842006332455, 0.031636721236751444, 0.01626114315924145, 0.035189808301267125, 0.03576154738003689, 0.06005950444828599, 0.022282519550513358, 0.07441629475403218, 0.020872896702419368, 0.12655609332385565, 0.035143295272944436, 0.1063940994020912, 0.016487702171528534, 0.007007482852185927, 0.0476822393736051, 0.0697333524904905, 0.014842484304080568, 0.07738653254965622, 0.07757028639917413, 3.699290026580134, 13.193201941828574, 33.23742743461363, 47.8304095422068, 41.03279690588675, 40.71605766973188, 64.5948903022274, 54.646029779987956, 35.46895011778801, 23.035152381466283, 16.525273053876816, 14.831382786073993, 6.88930441294947, 1.7245274109225122, 0.24875944360129296, 0.06382019942506187, 0.30033327939529575, 0.3287332312714669, 2.077034250382454, 3.571233956083175, 2.6145556136485073, 4.349342719201119, 4.94863038101504, 5.723151891462265, 6.545054162702253, 5.1319163653158375, 3.764332239666293, 6.155034265210552, 4.806320907608156, 6.000004545334847, 8.838447332382202, 2.468797396267614, 0.8191960196821921, 2.635632469769447, 5.422558601825468, 8.574690491922441, 8.594394518483071, 9.602907473041165, 17.20792628103687, 18.431495927995254, 16.091094132392637, 26.06686015282908, 31.56914926344349, 25.674393676942397, 32.77452107398741, 33.00439157793599, 31.25148827029813, 21.258893320637366, 15.266911983489992, 8.423755726506634, 4.01250574857958, 1.418180984835471, 1.5881365489575172, 3.1843002284726794, 3.7110706202445494, 3.0622794599302354, 3.559484741380138, 3.4318061990122644, 5.901193666842676, 5.730885824849529, 4.340730665191527, 4.822291328061012, 6.635473130210754, 5.4059037277775435, 4.122045290085578, 2.3375757278934604, 0.6293529356198927, 0.6297133646665082, 0.43977556149325064, 1.3264568486521322, 3.948223249566171, 11.727402402508645, 18.80173040974525, 22.413950927795906, 19.375724177206717, 12.063901558999094, 15.002726624088904, 21.31761904685728, 30.442226817530972, 31.769639253616337, 19.08659646587987, 5.468926900817502, 0.752176748168084, 0.058400655961445266, 0.03243112185549352, 0.006966610625010705, 0.015583545093484705, 0.04467689176841129, 0.044688168582656694, 0.05224687084856053, 0.04820216792605577, 0.034779300087041436, 0.07398101125633524, 0.027263362764290748, 0.08644146964915338, 0.02452790793482094, 0.012479477483148297, 0.0510372793031556, 0.06707668214315368, 0.02942707085411155, 0.04457952199323524, 0.04614655867279057, 0.05289221182465554, 0.023532775042939092, 0.00635207835359559, 0.044654970162458, 0.05231028377649285, 0.05920391447181183, 0.027833161725392266, 0.05415225792075357, 0.024038398818623637, 0.040895186830312014, 0.026657071204916127, 0.06540959055024771, 0.05525510660522888, 0.11795179212405799, 0.05464328197582115, 0.0644168631744481, 0.019682541624793125, 0.10659071586785779, 0.03180681573857944, 0.058410266534455364, 0.03236468671069991, 0.03556488877943447, 0.009223480273278491, 0.17250846019915997, 0.10859846377805357, 0.17910545781975795, 0.19470571990936034, 0.11133951871024986, 0.23128372166425953, 0.16278945510425877, 0.15534148701737005, 0.2705075459614877, 0.17371803642280642, 0.13510605590718408, 0.16671312762604606, 0.13339204142891592, 0.14165220061136832, 0.12396447916304874, 0.08112030719677288, 0.1813802639803579, 0.1185903876959797, 0.2565517835319042, 0.08867614812427953, 0.10862064202346149, 0.09850461186180193, 0.13914047409930538, 0.1419288196390675, 0.13420121413805794, 0.1476006741605459, 0.11468381425666233, 0.12847688259376636, 0.10367821045820752, 0.15774419921780788, 0.25479689060199645, 0.11924695569060503, 0.10378230648535876, 0.14518549004870077, 0.1290950082963513, 0.1534298524981545, 0.15928645678345235, 0.16918861817929054, 0.08083607325510633, 0.15058755904676455, 0.15822986831828473, 0.1822028738716918, 0.12768405054004925, 0.2298843088529764, 0.17056843446147057, 0.12363915226512379, 0.15399078207631267, 0.1583374270628537, 0.21099944478802143, 0.17364219371830264, 0.1561102868929025, 3.176392975353426, 12.966679180822066, 35.377986431121826, 54.511661144994925, 49.52701899313158, 55.51978872668359, 78.63006822524532, 48.647039167342655, 29.21201659787086, 27.07941805162738, 18.308943433146325, 13.185876915531775, 7.471258140379383, 2.5350126431834314, 0.8403806184088031, 0.9430837751396242, 1.3045195225746402, 5.121348029182804, 9.454548724236028, 11.182107637005469, 12.8235666021224, 8.019669719280737, 13.225539922714235, 9.062684332170795, 11.278171385488204, 8.006499871130913, 7.474466639180338, 8.27313377011207, 8.820760384682687, 6.977299355691479, 9.203193437668586, 1.9852748128675648, 0.5046203077560472, 3.6671822397939624, 3.7991040512438747, 8.483514997266955, 6.920214160796135, 7.758836025191893, 16.66158130092006, 20.797969718133253, 17.212670387760287, 27.07094769324026, 31.9797331671561, 28.636636272553478, 32.50073375240449, 32.17929355559811, 30.75407485808096, 22.373721138123546, 15.436023992876853, 8.496647092603869, 4.015979742811573, 1.4785349849731693, 1.4310551843335553, 2.390223741531372, 3.668413373731798, 5.869428842298447, 5.284647085974294, 6.036759605330806, 10.707242950316399, 8.121896982192993, 7.77898867284098, 8.49863475368869, 13.826457819631024, 8.321567196999828, 12.191382511969536, 8.736235268654363, 5.427669450159996, 2.566575710811923, 0.9889531363883327, 3.388071281294669, 5.7067455976240105, 10.602644124338704, 15.382612097647884, 24.705346630465602, 21.92852035645516, 18.008117252780547, 21.231436729431152, 30.577075942870113, 38.84504395146524, 37.921153191597234, 20.10770317046873, 5.484542837066035, 0.7449136830625996, 0.1272619897199254, 0.1278762773220097, 0.11960790567700902, 0.10509642306715251, 0.08130156359965764, 0.11094204931249542, 0.19246088310835824, 0.18545163825394648, 0.1377645342220222, 0.2142828363444536, 0.19013559175354822, 0.1980951686780299, 0.08194522301275885, 0.1552541223504851, 0.21273803536690053, 0.16306213644002715, 0.15188768686306092, 0.2025591017257783, 0.22356912433620424, 0.11334608684504226, 0.1333244724739944, 0.11561451149323296, 0.10552320298888992, 0.08090944149561467, 0.1186309443906911, 0.1029890913876795, 0.31446220833928357, 0.12575247475216467, 0.21185809145531348, 0.12544453805012087, 0.2833658414742639, 0.1355886606559638, 0.2335256013658739, 0.20310866255914012, 0.20637575176454362, 0.1585349398514917, 0.1945983450258932, 0.08530890824453485, 0.19192039275601988, 0.14251365116046322, 0.0944693279903262, 0.19120154181315055], [0.027893535199485002, 0.04541230936264319, 0.07565380254339787, 0.021336958292991887, 0.04827616435866203, 0.027278044839359583, 0.0836798375953109, 0.04314280453047926, 0.01993212732486427, 0.02606417852333717, 0.01766313194116998, 0.010584623162304203, 0.04275755040467747, 0.05565043095679534, 0.05056099477975119, 0.06851420016779054, 0.05952627660946981, 0.02112552951720934, 0.03283229911880147, 0.046570975213281574, 0.030140063139579953, 0.06343491465574311, 0.04815234539790019, 0.002123846859303153, 0.03368737581636637, 0.019488206185821085, 0.022945528429362084, 0.048205213125554786, 0.03254865889527625, 0.05979094466555023, 0.050744595411684246, 0.021381831893156615, 0.09252204739999387, 0.018954382713643775, 0.030917261253982305, 0.07357904492246528, 0.03700758938887908, 0.023911923447984363, 0.040278600964454875, 0.018927692210361845, 0.05401282991853453, 0.0356555437939542, 0.08275312401594655, 0.05959602891497555, 0.049047840894350124, 0.0026447023781422047, 0.06994407263494308, 0.03341279075210614, 0.014659859476641062, 0.07914057512196802, 0.026484988704924623, 0.045803424061065724, 0.7366672674975088, 3.3547718294205207, 18.664700446590302, 39.30593813619306, 41.22965282009494, 29.038200686054846, 17.833193271390854, 13.90675069824342, 11.718989899081569, 12.015225925753194, 8.94888166458376, 7.060949292875106, 5.977800498085638, 3.814333143734163, 1.058844808609255, 0.7581266159972837, 0.22681318493860386, 0.9383475744435865, 2.1932665811431025, 2.05517414596773, 3.0526885294145156, 2.6105849492934445, 7.153213735549682, 7.332723457967082, 3.6424347806361417, 1.788689174479054, 7.449894951235864, 5.602808181316623, 3.2205679339747277, 9.085882209962415, 2.9828779399394993, 2.0423169842650815, 0.22643593260117117, 0.6971527587982916, 1.3481479234272435, 0.9824302347917712, 1.1056987460582488, 1.5835597558367638, 4.029542563423034, 4.538158755148611, 6.688359918132906, 5.278341875922296, 6.543391077749192, 5.707497712104551, 5.226762217860069, 5.0088774965655425, 3.498592641084425, 0.4609803236540287, 0.1500457663449549, 0.38738513725899887, 0.16522777507141714, 0.6122392055488403, 5.69157337950122, 3.8887615886426743, 1.8008672758456201, 2.385336223148531, 2.172313769978862, 2.923177504731763, 3.6275873837932466, 1.3779462922003962, 2.6511454438009574, 4.464252966065561, 5.136248623171161, 2.338211887305783, 1.6527017037714682, 0.36808266334476014, 0.9659517448275321, 3.2640550069270597, 8.974562402694456, 13.423500964718482, 12.748672866052198, 15.784542272167823, 10.379017053111907, 16.55959379288458, 21.929369549597464, 29.739189032585394, 28.008498107233358, 24.841146930571526, 11.089019986890978, 2.1689388155937195, 0.3011291221745553, 0.03284350315469407, 0.027441275193386024, 0.07260036759919698, 0.028711879896300457, 0.020058834437100638, 0.0133560324132803, 0.009108546017218501, 0.06678551510577241, 0.010808678024688797, 0.04203987157633228, 0.07848274308226763, 0.03422218179630657, 0.026768935363619562, 0.03416046192268691, 0.07662873369671645, 0.004436422351582517, 0.045555828274377895, 0.02460503383659788, 0.02321093384506962, 0.06497278253758146, 0.014133190308066626, 0.0940844300954092, 0.06140173262646122, 0.07750303154030154, 0.08666197273639903, 0.04752427587405809, 0.028768246730549202, 0.03541241429986493, 0.05690488844148575, 0.14995659371056866, 0.06032306933775545, 0.01811355716669031, 0.11105868619896712, 0.051432159323725975, 0.07799067714762303, 0.015321021125982366, 0.029627510098620292, 0.05398928803662139, 0.025870180163051815, 0.028819385014714736, 0.06681818875574297, 0.013199829000739322, 0.05324468887861698, 0.04040576389900619, 0.05074196773010397, 0.0364212601655914, 0.06658837770021732, 0.07497248224793904, 0.0499607036040435, 0.018151890291201494, 0.024539495014675686, 0.01078241270020484, 0.019591082217952898, 0.027902291584459525, 0.007332922269274751, 0.06633039759171587, 0.02677254172252311, 0.07833000813280383, 0.09071098490347786, 0.02739725961169649, 0.09469475702292497, 0.022958423604347536, 0.019382118330066724, 0.05000479579452546, 0.021708177688020854, 0.024311815598799337, 0.051986450750020244, 0.04763978278084148, 0.004841623012907803, 0.008321992054040874, 0.020928884323145595, 0.04778194571695021, 0.023647094513439847, 0.014173272985874886, 0.026122108176951448, 0.03602679383250014, 0.03733999493922438, 0.06262519419373525, 0.08648106107308019, 0.09009636788358612, 0.031976259065671794, 0.048921463199921196, 0.036984522481478994, 0.02882554244640614, 0.0383874363145761, 0.04900727270831985, 0.04178103344935564, 0.008976970416223331, 0.03495295306727771, 0.09277265774266374, 0.016377626828128294, 0.01165827815120499, 0.009676187483203268, 0.049493922401339784, 0.010038414921220994, 1.2115913413224684, 7.338935021431216, 26.229061926564864, 44.724402273854906, 45.544550265035326, 36.54491509160688, 17.162875898422733, 9.291977267111502, 10.950755457724295, 15.70921511419358, 15.09573974917012, 15.609240762649046, 11.938476908591486, 6.041400259540928, 1.8271445819447119, 0.09907995921469505, 0.10205536810380798, 0.43171984053427176, 0.20899534345634524, 0.8644598650355494, 1.759476832324459, 3.036546014970349, 3.3774080728330924, 3.9634861724991954, 5.737654364878132, 5.606441766985002, 4.875717441881857, 6.596781890238486, 6.506347723545567, 7.294691176183763, 5.282194624024053, 3.556276978023591, 2.143371090773613, 2.9403839620851704, 2.4285747158911923, 1.4407176981049201, 1.9800592862790631, 2.8640159051264487, 5.927706928022447, 7.780530654614973, 8.917558596980188, 8.657176956053704, 9.664216080019552, 8.588242280867792, 7.897072117174826, 6.830669391539789, 5.0511572149492086, 1.4590117551626698, 0.9737198763797361, 1.1915838213697558, 1.0353614558135311, 3.7088515393195616, 6.2877221645847445, 4.033058477986244, 3.955435017424245, 3.2640616259267254, 2.764586517887731, 4.500141182253438, 5.294089211571602, 4.670800076377008, 5.001283787911938, 2.2094154694387993, 1.5180151116463447, 1.0418442756898942, 0.3781181393611816, 0.3637537762763039, 0.862150876031768, 3.772658450949577, 9.41604575803203, 13.763342961188286, 18.178981581041892, 17.494222041099302, 15.080480748607268, 15.844506486769646, 20.469414341834284, 29.42728411766791, 30.657727718353275, 29.251897296597882, 16.96897941250955, 3.5402249232415235, 0.6286674401452464, 0.03217860012345257, 0.008189208906955056, 0.04085280684634082, 0.030503066241621014, 0.028939484618604187, 0.0939908984207338, 0.06778665412698062, 0.048106452900796175, 0.050573443708520745, 0.1113088139062447, 0.013113999382532654, 0.03624927342659043, 0.03436452859351712, 0.02410087520406852, 0.02126725578320123, 0.021482683537948518, 0.046859200473033616, 0.02004952646882063, 0.001026472351851783, 0.08374590501790086, 0.07457126668023487, 0.03949655542871164, 0.06517464670562936, 0.07437426717050614, 0.019487035986516747, 0.0027130419696350734, 0.047024832512702675, 0.04825745266111148, 0.08228781753249707, 0.02826159639704612, 0.08202278941509225, 0.009052419543055999, 0.05777932035045759, 0.05613015521497977, 0.031313723246116316, 0.10803550406689606, 0.07205660605142195, 0.1175618686923577, 0.07688085323259716, 0.05353371086981028, 0.06993784434011868, 0.05831227239762103, 0.004063259008445687, 0.0983097957026574, 0.21957599828320168, 0.1752776535408151, 0.14988139451992127, 0.1947734880471422, 0.18391178620438423, 0.14340896279581133, 0.1542897402278839, 0.06980401644062612, 0.09579823006905856, 0.13889033107026932, 0.19572159846223172, 0.1357829865188368, 0.2162460898680072, 0.24807929542035828, 0.22228816403977333, 0.16068498093274333, 0.08840692184504964, 0.11900353125266491, 0.14312307410422834, 0.10067582761328067, 0.2311890791620939, 0.14975589399616565, 0.11976955788991145, 0.12609398908792965, 0.08297954896284689, 0.14229991262958896, 0.12748152753638645, 0.2063962063121219, 0.13553080569592216, 0.11225099480080028, 0.09843403218133796, 0.22716573860135772, 0.07643525819143943, 0.14058329345237824, 0.1628351905533383, 0.18124708725560099, 0.10844428092241289, 0.14463608243292378, 0.11260138809560769, 0.0833222124304983, 0.11793448619784848, 0.11699476444552984, 0.1428209596704091, 0.1231740219818969, 0.15684914805235403, 0.20188154292202767, 0.07683016885552676, 0.18431920708427507, 0.17304202511666283, 0.13975550480667623, 0.07114582710088262, 1.0401365737761221, 7.392143934003769, 29.640070738330966, 51.59377075010731, 51.83712244033814, 38.50540199587422, 24.924607123098067, 19.74198922034233, 17.30065699546568, 20.393722403434015, 14.6589808887051, 13.273645831692605, 10.072778001908334, 5.702696731013637, 1.4250124053608988, 1.0970247921443756, 0.87026828239041, 2.2887373162854106, 5.368889791350211, 5.188638250673971, 9.897581415791667, 9.5741408101974, 15.692118483204997, 14.957162410982194, 10.834173790870175, 9.328522970599513, 15.1859454378005, 12.208541900880876, 10.36862277215527, 15.021817780310109, 7.454516483891395, 4.820729734436159, 1.3836501538753512, 1.6765829319915466, 2.509685898980787, 1.8288106086754032, 1.8071391457511534, 2.053509957848057, 5.4907519490488115, 7.808060299965644, 9.336491265604574, 8.005116255052629, 8.846971623359188, 7.755457883880985, 7.011065569616134, 6.2814909892697495, 4.913539876860957, 1.4425216206619818, 0.7238237728034297, 0.7592625711714068, 0.7056017280105622, 2.4804843433441657, 10.292800414946772, 8.305954202528923, 5.827549695968629, 8.032005083176399, 4.80765990672573, 9.377275090063772, 9.371389573620213, 8.697289074620894, 11.970306942539832, 12.314346855686559, 12.223799920851185, 6.959456984073886, 3.608115512517191, 1.0403739997456152, 2.0469168213105973, 4.499736687829418, 10.45606024803654, 17.53305350580523, 18.061308514687326, 22.76062765429097, 17.48760892498878, 22.62717881510335, 29.59426922182883, 39.034361070202245, 38.51830267137097, 35.32856456695065, 17.22484346359007, 3.686614887368295, 0.5678607739748494, 0.1017795917728255, 0.08333294532231747, 0.28437131655312353, 0.16066785120675642, 0.07091811512626948, 0.18548496307865267, 0.1960627220931553, 0.1614798277977013, 0.1509264916662247, 0.20301284028157113, 0.09372240758591122, 0.1332549423339867, 0.09889258943017452, 0.10449334333140044, 0.22553083036215077, 0.09658003811754527, 0.20362059315366132, 0.16280779524916605, 0.09994571517792442, 0.23151943159680213, 0.09698505348135388, 0.1534179321700527, 0.11091211825729379, 0.23654786419243584, 0.18269476360611378, 0.07229698145942343, 0.16532224903423942, 0.1256884757669703, 0.22109035492664386, 0.23751903385404619, 0.16470372496593386, 0.10015417536300036, 0.27859455395129423, 0.1941218843022662, 0.20747141071384956, 0.29262857992322217, 0.1407743557806938, 0.13505325712744268, 0.2479955926537514, 0.17557016123206387, 0.16653606938498636, 0.09886740045922418, 0.05349870448211028], [0.03192983605268021, 0.05248128992295074, 0.04711426561698318, 0.08103623670796234, 0.03246944540390565, 0.06082059747930016, 0.04372000581614914, 0.04999313210587829, 0.019478541986656286, 0.01892090850179234, 0.060827898297218554, 0.052778551189769665, 0.026126310169216127, 0.04200299593409704, 0.03836078028525076, 0.039435827638953924, 0.029073804729588093, 0.00258821057580081, 0.024912706238307783, 0.05560225934811658, 0.053383316318955154, 0.030317757233616807, 0.06995731829515389, 0.03893533473714225, 0.044984207939236395, 0.04896070222340284, 0.05823056912049652, 0.04963832997506665, 0.048781778558247516, 0.14544093440617287, 0.04338637069468537, 0.044678535027008866, 0.03903196906791099, 0.03735627047717571, 0.14778269665135493, 0.02394570026456589, 0.08087310594536605, 0.02529460489900122, 0.030053462645399476, 0.01447137599180062, 0.04291127360756359, 0.04514656878346878, 0.022593137560292118, 0.032710483477961634, 0.04268266914051868, 0.030257215220180732, 0.02098658415038259, 0.031426864856433485, 0.02591288381917102, 0.020547274860643575, 0.07083311001019132, 0.00416890349081387, 0.02495932077328044, 0.14767745149231729, 2.9376454122604865, 16.312965942967324, 34.93975570124965, 43.63618381561772, 49.137476644208355, 42.993734882723906, 34.02226624950286, 28.115731785374305, 25.763617792437156, 18.376978904970233, 14.744374809726594, 10.448129215548116, 6.544886971673658, 3.7556542408081794, 0.8512761047290218, 0.46139542073492085, 0.19029800239349567, 0.6813877724832105, 1.8152472977676701, 1.710291168382091, 1.4562330010437197, 3.3907730588989877, 4.414217250962412, 3.8567327395562208, 2.0160879723487364, 3.9061440623575643, 9.907196125676556, 9.905396738360006, 4.397541784471081, 3.6251153099921445, 1.5962888276384724, 3.430305647273218, 1.5862432699049673, 0.2387134108932749, 0.3259730471238014, 0.3048869979477698, 0.28734922288886966, 0.7446351947803652, 0.6437987798163969, 0.9107530261239699, 0.23865767033590427, 0.04841174659950118, 0.13465882909874763, 0.08800521598107393, 0.07757223992338104, 0.0822929962868652, 0.3934360674071697, 1.9033105142654914, 3.196176429910045, 8.857057017664756, 5.610336680566111, 4.899612520971607, 2.607441169600333, 2.4593371297082594, 1.3910047205225116, 2.5085641011115047, 4.854913680784164, 2.5287915189420027, 3.562603515963401, 1.8234239686881344, 1.8835824631875562, 0.5510384024631593, 1.1733175886254157, 1.6966700025143164, 5.744294937579863, 7.029082486706396, 34.29167816715856, 35.73225490508541, 23.09609228564847, 18.05342455064097, 16.14423146170955, 19.877811093484205, 25.08746393265263, 31.237510904189083, 24.60617538421385, 12.066605052640362, 2.5454525216933224, 0.23440056570595313, 0.063015527482475, 0.08926961345658188, 0.022100443433549617, 0.08560695475147617, 0.04647896422313587, 0.09515201192229025, 0.018630568839369283, 0.059026243360412706, 0.006094508580938583, 0.01044658465205782, 0.04883941518323076, 0.08745174809929826, 0.020258762317919926, 0.03738153988735811, 0.028030009932755947, 0.03389571725781407, 0.04053113035737507, 0.03803001799350304, 0.058333404933012305, 0.06212348321212396, 0.013375368472489138, 0.007951887316941735, 0.01652904602158214, 0.010308861195470297, 0.022264070238076875, 0.08528205686278882, 0.06856460109232895, 0.14212256327511805, 0.04587466640758418, 0.033527696279868964, 0.0464269430226376, 0.055708006294744636, 0.022997806269314983, 0.06644334193439254, 0.06074768506110676, 0.02248516895868365, 0.03846034873276949, 0.08352345606732754, 0.044258385596256104, 0.01483930791202452, 0.019450378679339925, 0.05599137072661712, 0.06388035264887637, 0.031053253351860953, 0.010962994945716235, 0.051492573017434734, 0.06650811466839045, 0.07526318963256574, 0.06740020107357733, 0.0897016027762044, 0.08616003192841046, 0.03163861155870461, 0.021909760318756587, 0.06771190692820857, 0.013838990520115101, 0.06098829412592515, 0.03056456778018225, 0.047658896674552274, 0.025945228051334143, 0.02793157721058496, 0.04449165936919951, 0.008498632777181846, 0.020545974426392107, 0.07549597310923761, 0.020682533429334723, 0.0362526327221384, 0.023100475457707242, 0.022370008706685998, 0.02402445601840173, 0.029009600815873955, 0.013969068419218305, 0.08786657704941689, 0.06898744332213556, 0.06301351267123415, 0.07105126886838867, 0.09502606706753855, 0.04840064215503874, 0.05029856370040967, 0.0340609509317625, 0.042284544737588976, 0.07172865147191672, 0.07679652227389236, 0.05986031775753345, 0.03571201979573216, 0.03161327703104865, 0.03602393632454257, 0.03167792144531925, 0.06505164362850689, 0.03751505752124133, 0.011290026389272704, 0.013086856887375396, 0.012482461395613369, 0.08141348904539501, 0.027270328418742266, 0.013999591277341449, 0.004443785414144758, 0.05346592357983032, 0.022609570146267934, 5.1688910780414465, 23.05243826681568, 41.23505000145205, 45.63194067247453, 47.522440725757235, 35.25203912488876, 17.60462695552457, 12.839381598657178, 13.977715199993504, 16.986847769829534, 19.156891222923033, 16.766412527330463, 10.889310548382422, 5.159516613329611, 1.6741711646318438, 0.317255548772312, 0.2411568176842505, 0.28758147010399454, 0.3067880298101133, 1.0473153692099357, 1.6560273833813208, 1.569690622629658, 3.159062718191455, 4.197170936292218, 5.869237136456275, 4.662840116408564, 3.7280172205740407, 8.347031224158503, 5.0334006451791335, 4.463011045609751, 4.981254694923278, 5.3753278716917965, 2.9905422512562048, 1.737971579836261, 1.237551425733874, 1.2113697274077324, 0.5828454537737755, 1.4257463788793934, 1.151252172646984, 1.265639641111897, 1.088605792291703, 0.42178236248512424, 0.6664078117858979, 0.36733496153066236, 0.4704994257659682, 0.7251818934755941, 0.5263730679308215, 3.6155819892883305, 5.6679808132110105, 7.080004657468489, 8.142033940361392, 7.702803986687814, 4.701195013138556, 4.067884957598102, 3.948739531540102, 3.9897881159859323, 3.8019526725815194, 2.7023559087707154, 3.7399262718615995, 1.2518406202716212, 1.127313334615, 0.2838232878956103, 0.7676089458888578, 1.3370747047085918, 7.643047657705123, 12.033911116661566, 30.130365048685384, 37.638879822146514, 23.672492427210656, 14.81181113950668, 11.18192034382974, 17.903391930364794, 28.985293795985562, 34.98450994491577, 30.35449124151661, 16.96204858441507, 4.0088898135769755, 0.5607322339088686, 0.033601895725775155, 0.061008756334382686, 0.022981371768119357, 0.05377661436796189, 0.03702945353823804, 0.04170209574963778, 0.013697134976785992, 0.07888978091819633, 0.051183582944495064, 0.019622761868841706, 0.05444327940142924, 0.03258413642704968, 0.01947379607196537, 0.021260456752873236, 0.019372448385242495, 0.018802645593701352, 0.028262431432883588, 0.01422043814654312, 0.05553773942313368, 0.012933560778507063, 0.04972517753260271, 0.013305375806897158, 0.061662800069297516, 0.07245089618429061, 0.005428084865167377, 0.00950713390334239, 0.031116384742481094, 0.11425449858389555, 0.05147133322973406, 0.055834406971811294, 0.07083170806928989, 0.09631543134849879, 0.06242561679814131, 0.0742757176199267, 0.033928605412403424, 0.024287521035500595, 0.03344007880396901, 0.013090478568037432, 0.02864388001692151, 0.08187560860307948, 0.0614358771652464, 0.06417515094301875, 0.0637713804720871, 0.026295104236792655, 0.09965025804816716, 0.11154538951814176, 0.115638428758229, 0.16334782594874983, 0.10537671165600901, 0.2260037364378091, 0.14446404972864738, 0.11681035942127628, 0.09658773730118429, 0.13085587671206844, 0.15009130261117412, 0.20007846306168264, 0.10418082542356946, 0.130910636676896, 0.0921732705507067, 0.07606292413848062, 0.1372961327433586, 0.11927992811486607, 0.16264828042157237, 0.17052705039180097, 0.18462542774936846, 0.10083490577075752, 0.11131387008654495, 0.059173719116276315, 0.13116346101366705, 0.19400265037773118, 0.10525154055006082, 0.1734855134160288, 0.21403535930139406, 0.23157740913091168, 0.17553633078932765, 0.20305869830471857, 0.1818205040669249, 0.16621039008661626, 0.31204636539182357, 0.15829630346307833, 0.2886747388589767, 0.22567318482024057, 0.11955814060544777, 0.08524623459144946, 0.0849849756266321, 0.1345321641213471, 0.13862007057234166, 0.08721979965846385, 0.12357857769295094, 0.08376671962680356, 0.12420358286509592, 0.12114568162829646, 0.14058071939695266, 0.12326661902930468, 0.19613694069125961, 0.0948979158795649, 0.18440133170975795, 0.37584972237387015, 5.458219320543352, 23.696311020082046, 47.14716403715072, 56.8220744594451, 60.825547479814105, 55.46953924240605, 43.64390696248701, 37.89148046124367, 37.29815137001776, 27.539306148406002, 22.75525792952507, 16.649906366102158, 9.737761501343021, 5.245786203492073, 2.055192899800116, 1.1940742812810408, 0.7199209531949413, 2.3358273313891504, 3.058472799678003, 5.9145493372794125, 7.115043680514059, 10.289806665912753, 12.347929208509385, 13.590949889152283, 8.85609603697254, 8.932649916218175, 24.20654469920743, 23.49787831306458, 10.171899237940389, 8.508659351256586, 4.4571765199784315, 9.075340840124316, 3.5237058612608143, 2.1030800140673116, 1.0522578007751897, 1.2689544116297078, 0.8624284450084934, 1.5141492481193237, 1.2762722060565026, 1.5832962215908113, 0.7918718084692956, 0.45617958771124967, 0.4543757877282558, 0.4229624136801689, 0.5430184424884859, 0.623895999404692, 1.007042433465681, 3.861604323310237, 5.083632478790899, 13.954982123067303, 12.564016503672446, 13.125179217707727, 7.412094089292712, 8.090976938124626, 7.6334138262656435, 7.5496530821246495, 11.531871268826148, 10.446846600501768, 8.695203354281764, 4.677667656252462, 3.584059616250377, 1.622430076522212, 2.1181169104191566, 2.7096076357749204, 7.995495171316209, 9.466905170871366, 39.33324175496256, 41.933977142457046, 31.187020194145944, 24.05917144590809, 21.74619290136522, 27.155749336365734, 36.60096576136928, 42.584223747253425, 34.161890860526796, 18.012508346188454, 4.165674794104792, 0.6117519123419639, 0.14403283415782836, 0.24719084793281174, 0.1517714713249476, 0.18126449277324064, 0.1819399831395957, 0.22179699442800016, 0.13650991202842805, 0.22554586100722515, 0.17744850157009018, 0.14476792616469247, 0.1250703960296608, 0.2469720685433957, 0.13674657190999678, 0.139851035970834, 0.1214478113838742, 0.09723394778707335, 0.1816011730942034, 0.12233839625672949, 0.17266242855018185, 0.10407048577983534, 0.10452420135299045, 0.12356691783474338, 0.16609953716397288, 0.12328508174827985, 0.09950303893175819, 0.1830754633392057, 0.11607881440150163, 0.22231992604511402, 0.18554620414731965, 0.19611028083149465, 0.1564657823332856, 0.29091006084795923, 0.13341235808066784, 0.14373669520981852, 0.18288475341133534, 0.08121936236538234, 0.1294375108855386, 0.10838858633031768, 0.16622517558355487, 0.1525963948018128, 0.14923057218472804, 0.1792159276984392, 0.13030469177230714, 0.08661349469255056], [0.049132658318886836, 0.08147034043025586, 0.03720692546677686, 0.04068673813655492, 0.02203073900853915, 0.07734799066618567, 0.05974818546805651, 0.049626543712351597, 0.07894390503004675, 0.07189329908860308, 0.0071271328582248146, 0.019682070480719693, 0.010527693253431109, 0.01657621980073952, 0.05930962311404367, 0.035202636443559206, 0.020128983193107193, 0.06256414464704933, 0.02571562766998766, 0.040684811425425356, 0.017811293345725825, 0.04043558004101919, 0.05015914335906987, 0.0689905459782289, 0.02942076020483529, 0.037868212563015764, 0.025442459868387352, 0.047425814423589945, 0.051302498942541505, 0.03513458868368499, 0.07067539548921971, 0.052056689521357905, 0.02471819076867354, 0.021547519474200184, 0.09071441697737864, 0.02332261031223161, 0.03454087437280724, 0.08124438279698934, 0.04782232621143903, 0.06343132170337824, 0.03578760969122091, 0.020453614866240852, 0.024415082335772536, 0.037197992881579746, 0.03276220590416943, 0.02972389736603345, 0.019239982207035346, 0.02708938228146684, 0.0656689572778921, 0.03499138386799924, 0.037445060067599824, 0.04863008931880036, 0.053619692747991894, 0.07299910870290573, 0.13988889603605195, 0.9242134361017136, 9.95938620259685, 25.623038084276264, 35.120686792558246, 37.74366986367011, 33.646514954105506, 30.05443972925986, 27.75785080848202, 22.06005507899869, 26.332318321351085, 22.580673233155284, 17.984055472958474, 11.7906064948728, 7.781148427917112, 4.366374631081858, 1.326902160240758, 0.42087108557743413, 0.229235248520009, 0.9141935576354304, 0.6949045665321812, 0.9312852243742636, 2.369999755774775, 3.0894085332270596, 5.358739187640529, 7.4364598528031385, 1.779781839539928, 2.8631282237268265, 4.460461995294017, 3.142551991247362, 9.218260242092995, 5.915101410881166, 3.317747106475215, 1.341263918626693, 1.578669418250361, 1.0075677859206353, 0.3912782428726074, 0.7962006342507179, 0.21418716728446946, 0.25708648225953507, 0.7325340699284308, 0.07935923193731616, 0.3927703982880039, 0.08246201060471997, 0.8908511650177741, 1.2269392080845372, 0.22451654527216192, 5.262779872263632, 4.129911113169886, 4.369843967499272, 5.924444006335351, 3.202096021944477, 3.6179319793178193, 1.405683332873929, 1.9840140160053008, 2.288304384677641, 1.9898685212096863, 2.3018247946616146, 2.8119687495693086, 0.17580898148157906, 1.0216892378464824, 1.0697476493735467, 5.208299131162706, 9.519793429682332, 12.644631016638971, 14.35701035684155, 49.719650514664195, 35.38708240755143, 12.737390168251531, 18.26364201884116, 24.75036563411836, 26.907086756921586, 28.942808643464122, 23.007295708502493, 7.6491121322877955, 1.4397895672628958, 0.29976995962281383, 0.04087785792146479, 0.057288744456825726, 0.021513579863934748, 0.0017642623049229566, 0.10050446140549837, 0.10710172715686983, 0.00959004472655755, 0.0564847773151292, 0.028924348636440216, 0.005119463472041272, 0.0413882180357412, 0.031056566682133465, 0.017272741195835897, 0.021756489107745792, 0.04408425764150677, 0.015274280186502204, 0.02612446581253842, 0.06502595670040577, 0.0886542380096451, 0.02848854228373497, 0.05584258496040299, 0.015756559347914114, 0.05287328945292581, 0.018231657281097387, 0.027216602672612476, 0.03465090375093203, 0.03499331824000805, 0.018014835246327906, 0.04493332820974531, 0.01072797257708566, 0.03402540062163626, 0.011870640596645254, 0.04454489481905776, 0.08529907933646634, 0.04681834117359212, 0.04383431762577065, 0.04972322017795617, 0.04538490639759168, 0.03905109445294065, 0.03659464118461456, 0.013678069921180367, 0.028663127976019057, 0.020079394321768515, 0.02762949533550249, 0.07316528849544064, 0.06984423605665084, 0.04523071588107175, 0.040075277398911216, 0.09363329623855891, 0.09191830882862692, 0.03285476847762062, 0.05120697160882335, 0.04001309021165775, 0.04975692804662451, 0.02933284970030429, 0.03135937059508457, 0.02957772012920149, 0.02122480876653666, 0.015364196883784908, 0.043343113540040876, 0.09847096528016752, 0.03646816772919509, 0.0955969481278331, 0.07219360555492102, 0.0294787856194401, 0.056187991022823326, 0.01589508049355279, 0.04846655636004383, 0.01924974025197087, 0.06403881410557417, 0.024999134362705296, 0.064733985270704, 0.020531255962146867, 0.05977244364217885, 0.031227396628368768, 0.022106914961289977, 0.039636772501492695, 0.03668479441154388, 0.02851546835905362, 0.0814768598384915, 0.09474805375981717, 0.020129730128833366, 0.09558109010780051, 0.0219305059797461, 0.012186115603863954, 0.011903217528015377, 0.06196828145954398, 0.07602128725979598, 0.030519357101330837, 0.021415177785280733, 0.08038506197232394, 0.03177395056662781, 0.06268778740758858, 0.036990448171573306, 0.0371999349144678, 0.06486521613213324, 0.03624332858429801, 0.04460949135283309, 0.087793001965169, 0.3138929743680262, 1.997829461770673, 14.674469347923035, 32.96365384132632, 41.96943144644461, 41.842668287215695, 37.21928819533318, 23.894904544276578, 20.05200159165167, 14.162283309044378, 26.10145349656382, 25.184301368651855, 22.61142461530624, 20.737755452432943, 11.457025581790555, 4.427436619035659, 0.8464168396688277, 0.6034445161781004, 0.13937166411309473, 0.19588088346344812, 0.43234466184531495, 0.8806865878643528, 0.376416259715634, 1.6013718516595903, 2.528715523019914, 1.012848154191048, 2.259383523656476, 3.239380111617427, 5.595810182632939, 4.525517936675779, 7.7511369028399075, 3.386057144211185, 3.7349968331475414, 3.2370168835886064, 3.189770709122381, 2.334489312864119, 0.8368655005770346, 1.3257817106862224, 0.38974015282527097, 0.882043911805076, 1.2059412896633148, 1.6347414159005689, 1.5271538664256374, 0.8806623181989117, 1.7838921157583114, 2.5416343394787084, 2.664872023367113, 5.853941853969328, 9.01411166114192, 8.826414481286081, 6.507244475426213, 4.748915058951225, 3.5502213287738065, 2.984525090263736, 2.634620007968718, 1.3244292284211805, 1.8436126531131807, 0.3521510375843894, 0.381639784262065, 0.29013333962328974, 0.1865129304989692, 1.4044243746226834, 4.551769379646548, 12.34247221100715, 17.881642387759303, 17.069911802968672, 54.57014368426416, 41.425112370521795, 14.12472955642208, 15.019672243825852, 22.910132715778968, 29.640714007039225, 32.275189622755974, 27.121765921192786, 11.187038056312069, 2.976934813684033, 0.3389872874944441, 0.045833362777146607, 0.023841669354888222, 0.03394478518936423, 0.04020240202906632, 0.04247964051882586, 0.13989649562826081, 0.020329527774705522, 0.028082644003593636, 0.04263365100468359, 0.027636545259625684, 0.04539364746080772, 0.027159870031379887, 0.03668405130625733, 0.004866438515995059, 0.03235860780302075, 0.030704076221633344, 0.05177228704034802, 0.046686436154789505, 0.01805554324340436, 0.03574509564186296, 0.06173072142466422, 0.03331030734003552, 0.019466577608498837, 0.051940205852471055, 0.05077946007311825, 0.05403853216839414, 0.04509284686777861, 0.013159512666114157, 0.0156816924479039, 0.020545838445785548, 0.038677722350844455, 0.030073806110228744, 0.046334365127427925, 0.07354006636887789, 0.01725603281820734, 0.049881819530480334, 0.014449340430268598, 0.05930670431905216, 0.03884851016224392, 0.0029947439907118682, 0.021235150953514442, 0.05090246698068035, 0.014361003789329722, 0.010242585971530889, 0.04697143618438033, 0.1482600460369741, 0.16062999114153848, 0.20357543993140423, 0.17083973683897527, 0.1793262137160186, 0.1933833908650183, 0.16151546620793883, 0.12170622050161324, 0.23413575975404632, 0.16594946053960632, 0.17495540631634576, 0.08062370602161655, 0.09598700945535976, 0.1493698929346377, 0.14264981562812484, 0.2111422742206243, 0.11642631954483448, 0.1423158319366555, 0.10809096883261397, 0.1660073921084404, 0.1544088669001095, 0.11975880201545455, 0.16422724892054835, 0.09983919065205321, 0.15687306531735007, 0.1253420584684899, 0.20971143648268717, 0.12564993388349974, 0.09700881752876506, 0.09546403187297045, 0.1987463587354268, 0.12279231101274492, 0.33472330339493295, 0.117418349780623, 0.1547298730621415, 0.16413986893190494, 0.10336062104831781, 0.20075623637005208, 0.15666629818658676, 0.1449614552961242, 0.10812012613901209, 0.15511184450118773, 0.22739764873779592, 0.20070143043994906, 0.14490493332907078, 0.20295375958085063, 0.10771969964186992, 0.11526329848434656, 0.11951186123394197, 0.1034196787664006, 0.16938821472708257, 0.15998515961391313, 0.18225934987346973, 0.24631522475711762, 0.405276415929679, 2.5232874529977, 15.04662382987238, 36.81111066572128, 48.533419870561175, 50.79141463002851, 47.46058887050998, 41.20883287922029, 38.54217029386951, 32.66920739604581, 35.37771578757994, 30.692811358359556, 25.525575030234556, 17.777699578192927, 11.120672533589026, 6.449485123157502, 2.0290699144524913, 0.9243882267225174, 0.5400990959136718, 2.061790203855884, 2.8167111402557743, 2.6246476269537404, 6.196156394097113, 7.010165385661587, 11.45491828841548, 17.957746175027665, 7.954140641996938, 9.03982279762145, 14.259898354930264, 9.862058470326087, 21.322261171956217, 14.561543330069512, 10.253905211725543, 4.6522453042768666, 5.056681383040644, 2.952754382164248, 1.0532491798362424, 2.148708701133728, 0.5958598167184861, 0.7210152331859835, 2.122177298991911, 1.4879456090350307, 1.465441255319503, 0.9606616319187227, 1.9188956844229854, 2.841065872100092, 2.4207103636956986, 10.464189360218665, 8.905104091090541, 10.932313453766609, 14.498413762738629, 8.709357227048567, 9.980066899330387, 7.673775995931319, 6.392381787300111, 8.299856878096058, 6.919692485563218, 5.03939010443226, 5.251654559566129, 1.0775074458891347, 2.1150557456478, 1.737805614548345, 7.322007052360043, 12.375509354376025, 17.11262837533028, 20.266939632354244, 54.922760840385195, 41.24213772435343, 19.015803567824825, 25.75384128478266, 32.94304178607079, 37.74015541999571, 39.73105638257919, 31.2524276779544, 12.7030292249495, 3.0291623982691, 0.40723649784922605, 0.16304753480419037, 0.15333315688035182, 0.07325085285570353, 0.141994841096382, 0.2523615430559843, 0.306741543594868, 0.07356251274505932, 0.14054466729923604, 0.15681429105179925, 0.09024817586666153, 0.09990744142522735, 0.13221009033581904, 0.12530635111033916, 0.21052284616856806, 0.11029996037963899, 0.11149884201586248, 0.09862733914727166, 0.15952164577620645, 0.1484351890582231, 0.12371808996484165, 0.23854822701504155, 0.14887265590650423, 0.13074549876393812, 0.1760426382984846, 0.13029655591855127, 0.17011409835709682, 0.20222617523564448, 0.07570726781963341, 0.1711137818112489, 0.10636236804026751, 0.26339371478365314, 0.11635021637043647, 0.11097027199162592, 0.2544575749385742, 0.22991231702748807, 0.10264403772570434, 0.16006360701735944, 0.17273643264366736, 0.08613029239518989, 0.07968906343223588, 0.1466763890799015, 0.13426391077378105, 0.0984468718149489, 0.08422710782577915, 0.12725167051558534], [0.017572323709065397, 0.05097840544617465, 0.041917872074390614, 0.02119755518863038, 0.021731878533178282, 0.01905826998183564, 0.034559766101020004, 0.07560569222175306, 0.02480043796822429, 0.03151433677562783, 0.04505298348263868, 0.026864926180531903, 0.028323251153192217, 0.025291174740320253, 0.025529033549490477, 0.017922207555403153, 0.06850866901297724, 0.07856080744175181, 0.06201499367072698, 0.04099786942524295, 0.03366118710067484, 0.0544349673474508, 0.045999561721879634, 0.09896652457574684, 0.06986977742804636, 0.050704218747635046, 0.06647299719794143, 0.01894852214102303, 0.026179156829452804, 0.024802441288146283, 0.022424253477384488, 0.05918510318283112, 0.03580664314569966, 0.03829144166722413, 0.039916513337483334, 0.05628458321875623, 0.036003378355094505, 0.04913840014787932, 0.07917122629981849, 0.04165947061753081, 0.005322109528576895, 0.004130608191893947, 0.03805467453334601, 0.017418112125127547, 0.028613261397807833, 0.047612000602267446, 0.017511030929463527, 0.025778328136150396, 0.06785447589091717, 0.04586774480318831, 0.05492920897180035, 0.006114005039806568, 0.03459854547174708, 0.04062928920311313, 0.047175843764336846, 0.042151869800422466, 0.46188902650629327, 3.8529861405972516, 17.816603606747044, 33.10610648124449, 38.26111285917221, 32.17544767164415, 28.640488040062692, 25.787754097292503, 18.70782494544983, 22.541112207597305, 20.5996193808894, 18.918697449468798, 9.22805832278344, 12.029067970091297, 12.224513792222547, 6.5796499579183525, 3.1257358097261, 1.2116466222270843, 0.4322695239417015, 0.7400529471135909, 0.44402453026944594, 0.800264516184407, 4.230603258455954, 0.6988457518239176, 0.31539852100033916, 2.5313447367760444, 2.2862642618917652, 2.8203140824071826, 4.108285125224821, 2.3558863324503747, 4.175133589775332, 3.33508177630363, 2.6963076139650037, 1.4352032133648474, 0.6020250471849596, 0.9165826487925746, 0.030582907925089522, 1.469964360998523, 0.8488599247028752, 1.8241258278008432, 1.8041422097913682, 0.8815613989868473, 1.1016799100945074, 3.9894351026704236, 2.4340478931703875, 3.494947288305529, 13.827584520463022, 7.4215043456323695, 6.625015601035088, 6.882279938267124, 3.5865164908670613, 2.8854300850822083, 2.980427929470616, 1.1218948253700811, 1.5274530697253443, 0.40825177885351643, 1.5098341506335045, 2.0254971255217833, 6.042943221907462, 9.725881622683618, 18.168179373587332, 18.279005942806123, 14.38707140184218, 21.09119630629017, 39.93042653606784, 30.067728719403668, 24.00777270717006, 30.235755212845344, 30.064049536182036, 31.459350355209846, 15.197192834269616, 5.087260180904019, 0.4000808076272088, 0.08907060679649154, 0.0600766878004276, 0.0506572115926012, 0.0686932195939364, 0.008958168703341677, 0.025557844201102856, 0.04394063530790229, 0.01846792645782473, 0.056513815877899054, 0.02528667588898492, 0.09695344469359807, 0.05952862466895773, 0.03343094703591159, 0.07778287579816195, 0.060493282583211704, 0.06982918242893874, 0.03208795468503189, 0.08184907131738241, 0.07095951451769761, 0.02172564066225483, 0.034994122632328546, 0.03872614676853822, 0.027522704594077605, 0.048759044899094495, 0.04925630874030533, 0.01881845956367831, 0.07239668780276853, 0.044306235448006666, 0.07188150133456915, 0.015230707020588942, 0.05584406734053647, 0.04309347995947446, 0.03620302852904124, 0.05408547420595443, 0.04201307382074095, 0.008427276475084646, 0.08029817227995203, 0.06479905677899238, 0.062427064704318205, 0.0424228580818782, 0.04054694241213222, 0.01999814686695895, 0.08461146945914916, 0.06922778808662007, 0.026117490581987847, 0.04676252017698942, 0.023852333298794205, 0.07080492563545704, 0.01253544978211604, 0.04176469662437036, 0.053327181226303505, 0.029673925450732632, 0.05329017151868152, 0.05595272925171641, 0.04664595989931015, 0.049262280395675095, 0.05883253419831876, 0.03559543270497553, 0.04867032808702319, 0.01809678367158819, 0.026718471236827395, 0.030347709356236364, 0.09001499402426905, 0.042735142332892266, 0.07904778655257919, 0.01659353721826788, 0.10944137499938089, 0.027818381974113085, 0.018101355301276333, 0.07577648386359215, 0.07076947874720059, 0.006640203064307571, 0.04185185061707612, 0.055667794339599154, 0.061994316957650654, 0.05497101822026795, 0.03416183705051099, 0.05418383606499242, 0.061035772425032435, 0.03488093314151611, 0.06022124859173933, 0.03838434898024125, 0.017553366863379077, 0.01375838274872231, 0.031565950034306414, 0.06433016500405728, 0.04798374859796417, 0.01641213908911713, 0.01421851622346308, 0.07405461698410011, 0.0726260009011434, 0.04725323779688728, 0.061249671834370786, 0.042763460773013295, 0.05768658923766306, 0.04865548896392988, 0.01579181088374988, 0.04607333215854822, 0.03468487975037387, 0.025907084533584215, 0.05986122557172372, 0.08861490705561254, 0.0914753491299287, 1.0338139582064845, 6.154383151761948, 22.2211056370889, 39.204172242072325, 42.70036905042587, 34.394977708016675, 27.82236791426136, 20.506398370189054, 13.26222683152845, 16.82761130794402, 22.184160832435857, 22.06806848126073, 18.430627123002086, 21.13806470747917, 14.852871491063027, 6.807079276730938, 2.7815380211799376, 1.3627623069670893, 0.5528466763996309, 0.19004684812839956, 0.054979096617429495, 0.0784045255051986, 0.1255964915899019, 0.325108869301696, 0.21090051219347986, 1.0626719387308246, 1.7648267000913622, 2.6664341072882376, 2.7864826590784135, 0.8138635574329285, 2.0576584771756203, 1.2941703488749843, 2.230563908815384, 2.274615312776258, 1.1989201244808014, 1.23041148627958, 0.8542056249514703, 1.578819326335384, 2.8114946330747297, 1.2823990708397282, 2.494730146661882, 1.2742428697886006, 0.9475657572188686, 2.726957504787753, 2.6126196788203333, 4.171185724196896, 6.490007129407699, 5.288475319262474, 2.1466852484210848, 3.8081051553449328, 3.1458602653395746, 1.127460178348326, 0.9941564668570796, 0.060075381620516705, 0.2044776157145539, 0.24550334009672367, 1.4303256234815045, 2.9915208826141977, 8.12358065958946, 12.234867868884919, 21.75290603791514, 23.916732534285515, 17.616864750462195, 16.763784539315008, 44.6175451432505, 31.171720989288826, 17.035602831071426, 29.332831482733454, 31.583452186276837, 36.7420220375061, 20.61197288574711, 9.040053236869074, 0.9948249245362898, 0.11238414854291948, 0.05333802137043207, 0.05035310533017882, 0.012292600867729033, 0.017784478353156198, 0.01215746678832558, 0.0712564118927525, 0.04950983787796671, 0.04094651472123881, 0.019981059275807875, 0.031943141084705154, 0.021663838434183312, 0.055387697272723725, 0.015857364069820655, 0.09248542839721327, 0.10128680571553209, 0.042488741643366315, 0.04132559800881051, 0.037516087909499486, 0.02420674855520408, 0.07795481657188746, 0.0647992559618527, 0.007115816303168334, 0.05073210434807886, 0.010379907231958163, 0.0053668179410329515, 0.08169701052529198, 0.039465954046576254, 0.01359407508355235, 0.030840788442160816, 0.026833865145641952, 0.08003094549020452, 0.08906239433394325, 0.044469025301476645, 0.07514098328688452, 0.03767888159340909, 0.06340131020894454, 0.0216147800787322, 0.06426141244329273, 0.052065844272053054, 0.07654678527145617, 0.03463883403568499, 0.013876471371810525, 0.052096522262980866, 0.011276827651947256, 0.039081010186383804, 0.08798828543794733, 0.16767469054508596, 0.1607905325269507, 0.1873840490776685, 0.15423830508464767, 0.07927506185707547, 0.14405970852221214, 0.18931114325119605, 0.14338881468340275, 0.13491211308827325, 0.2074584638279292, 0.13817144948388302, 0.16199329056807105, 0.06934768850764922, 0.14389349808616025, 0.10879313438049248, 0.21457068622112277, 0.19387382503238418, 0.26077718744354866, 0.12984638733248557, 0.23435361983795322, 0.12209320215568428, 0.1323226746171713, 0.1288626691506755, 0.1958639835638385, 0.1423771802576319, 0.19227708329356488, 0.12915054967086162, 0.14181508622582883, 0.13056073367836016, 0.16503220814610683, 0.13899793578011377, 0.1605548992032005, 0.0972298568775577, 0.1271761189244928, 0.09335591878381469, 0.15751585905109683, 0.110034579861789, 0.20290471463193818, 0.2220886900660492, 0.11558903906975063, 0.1012998215493656, 0.1008842801374774, 0.10333218386456852, 0.19503133792069652, 0.11660452691778062, 0.09200539770385913, 0.11713998407245645, 0.12768794992758384, 0.16245058377183255, 0.16590884255786098, 0.21084389829587555, 0.12890394596803573, 0.15191394835710526, 0.17170989014689, 0.1930199127884642, 0.1801211218680105, 1.0110848036504563, 7.000652657401178, 25.45309159063524, 45.57055557927778, 53.78644627909507, 46.175938114043205, 40.43752624142555, 37.16819147909842, 26.29863496749632, 30.58058450298925, 29.27070898394431, 25.829380250746205, 15.8283826035838, 19.136565500690093, 16.149524700257086, 8.777735906262553, 3.985488217684531, 1.8688501633944052, 0.7391848775648302, 1.6524682001721476, 1.7739804089069369, 2.1553732983527647, 7.179924095830611, 1.9721960372501806, 1.087779275351955, 6.132195284289699, 7.394305159968715, 7.925842702388764, 9.114257616381492, 6.704249929997229, 8.542870263899527, 10.81035029503607, 6.956573551700962, 5.504008579638697, 3.765391524760954, 3.2976738868221163, 1.878844975463806, 3.4009942652717715, 3.8272328386383676, 4.326069335783682, 5.367843499106746, 5.3365351403913195, 4.6360115947261935, 8.106347235941119, 6.710703209523232, 9.460383249867348, 19.94054744320531, 12.984874075458897, 17.36147334498744, 16.409566075571124, 7.926143254003218, 7.4956645984803485, 6.0040563537228495, 4.2666768066344725, 3.3510298882761314, 1.1770275379380872, 2.036544603686179, 2.990099023426733, 8.36580466839575, 13.847207157842575, 23.805341143761915, 24.200949438156623, 22.607716014308316, 30.320460757901593, 46.94363617127942, 36.42434927725023, 31.906494671298613, 39.520174072634795, 40.54556792782199, 43.813812271241225, 22.398934133591194, 9.088844580035056, 1.0426213952802843, 0.19679445863491107, 0.17950318002652738, 0.12309386620237944, 0.14485211922757088, 0.11219474862539962, 0.127413330389367, 0.13586380879484838, 0.12526583272002398, 0.19835234439421087, 0.09517658802290117, 0.21097952650199014, 0.14458598028267586, 0.13597925824503745, 0.19912279901965974, 0.20877621166648405, 0.30466219710726894, 0.11890916454215204, 0.1110516305291845, 0.168340083872599, 0.11488352571764301, 0.0950059266160092, 0.15521661468571232, 0.08327003418197555, 0.23262056041388746, 0.15853579786996688, 0.09433503277719983, 0.19489285986750357, 0.2687636846976896, 0.1659460897527395, 0.18048265408123695, 0.13838351794308232, 0.18192319049229547, 0.17017134044679905, 0.12342919820859549, 0.2325152999330913, 0.13874362523276962, 0.16954615141355223, 0.13386056548164738, 0.184574835302849, 0.17431861871192533, 0.12356617472945683, 0.18059719954767536, 0.09854638663631293, 0.13527761363694746, 0.07944498015868087, 0.14479359011015586, 0.20299137449793278], [0.060236865294075785, 0.009417989039643398, 0.05138527474276001, 0.03645193049563997, 0.06130874104377243, 0.040679682466772296, 0.04324460229385765, 0.044146031141281135, 0.025487950169331124, 0.044828010272354855, 0.0633858199111156, 0.025752480329585173, 0.07774316180016726, 0.05654339836309514, 0.007492198173197047, 0.04341638601955868, 0.03205787041224539, 0.015342239846265125, 0.04360295907263795, 0.02091310291190542, 0.054982850448258465, 0.028550398137961185, 0.0340504095619244, 0.028508341826137998, 0.029508096143423073, 0.014258522292478912, 0.029096749062920292, 0.03721714507968676, 0.07939464052117641, 0.0678468916204668, 0.005189536098060349, 0.02565552998754767, 0.048572414389420906, 0.03928650944163242, 0.04055564134051243, 0.05039137908287587, 0.025624003554243716, 0.04651180258201015, 0.009654905560666756, 0.046829296230909326, 0.016445908244819413, 0.018933156332481774, 0.029318799647772988, 0.054133515579686056, 0.05522666176060035, 0.062122881833103404, 0.006365719506697309, 0.018916718000846527, 0.03268546687679426, 0.04025553788749441, 0.015976896768646137, 0.030360052947916334, 0.009400121954029367, 0.02961756244692351, 0.02054855231225731, 0.05163130387964268, 0.05004703405223066, 0.09128633225637098, 1.7185010568749521, 8.14777874177502, 23.317182563966323, 34.540474107188565, 38.694056234052105, 35.49404151978032, 32.22592857576186, 28.511430294282977, 21.679349830073697, 25.821966971120528, 23.1167455257908, 10.38414555211221, 12.03150180078322, 14.974261983748406, 14.953768580190598, 11.354468349487552, 5.702359407178818, 3.203889035409497, 1.8793258335321181, 1.0652315304163964, 0.09908254093099987, 0.04499625850228533, 0.9329594022804691, 0.41380012467984234, 1.5224059599061168, 2.531513153545318, 1.4921497769894139, 0.12550172651366842, 0.46410755584797553, 1.0219449273520902, 1.4124671946610174, 1.9338633264264755, 1.2245844376664008, 1.3075833839754905, 0.4292181957392924, 1.5096836296781417, 1.788201697411076, 2.021253366143473, 1.2578916117068262, 0.9628175259117158, 1.1708104586408985, 2.3318605894042603, 2.4788205229466964, 2.7969107704777874, 7.664735913276673, 6.506424700060199, 1.4845169672081548, 1.5884531577748637, 2.0161960826766108, 0.6433974110311078, 0.5420313535198089, 0.6258264796868448, 1.0591029495962205, 4.039656640060486, 6.785574391964944, 12.036779349850072, 17.138098286044215, 16.78911324470274, 13.591532361122871, 17.277928821502194, 12.940129637718202, 20.795881056016494, 32.05642923232048, 32.38722820435801, 35.91888127788421, 29.834975273378436, 24.62520476310484, 11.048473465827204, 2.40765794150291, 0.5718789970682514, 0.02480912540528563, 0.03013867077477757, 0.02115036225727489, 0.03555357366079285, 0.019002150210942474, 0.04761064079620185, 0.09786544172393699, 0.03272210503177297, 0.027277749895508734, 0.024852870940981854, 0.009775799023167742, 0.02598100627261785, 0.0807888362736952, 0.06471427382841226, 0.0031094977373046983, 0.07021794906787335, 0.07411203527402493, 0.10221119804848587, 0.056750920090463855, 0.06020518372796717, 0.013381667630446535, 0.02373462388922851, 0.02636026192997252, 0.03187510864658943, 0.04359352469985043, 0.017964823111411066, 0.04577766052417217, 0.054125057969002, 0.055938725164460565, 0.006854989220418277, 0.029042209348370953, 0.04968891859114651, 0.06437253732714923, 0.043984861563771, 0.048447503753366976, 0.033769753250864246, 0.0423942408674667, 0.06836971598527125, 0.0203592692231459, 0.028602509353790554, 0.007594629874332778, 0.039713741355245157, 0.0172280342197947, 0.03129943570632848, 0.053845684855215015, 0.05393930846044133, 0.01831267873996929, 0.01629879638071983, 0.0204575966082273, 0.013366923310733853, 0.010633340608629008, 0.029434800681267536, 0.07024650116481128, 0.04992601131239245, 0.059175132548496615, 0.06396144688610109, 0.03950319741101515, 0.02348125371481142, 0.04688842672734492, 0.03329876239501661, 0.055387613003052054, 0.03559510328716809, 0.05427151482792632, 0.0368194918208305, 0.028782448085445552, 0.040739429663986935, 0.03360391053701601, 0.08916319618302007, 0.020979624241590503, 0.019157022545715014, 0.016817173605123838, 0.03463066753841216, 0.059033138151731224, 0.059679195420035434, 0.012618426680414668, 0.0038268430780003513, 0.05125194863085786, 0.04393223515381256, 0.012700130915149085, 0.11229512912611808, 0.04169900841530293, 0.04218702174482807, 0.044653610356392405, 0.03218496248366372, 0.022856985902293556, 0.03350403182388794, 0.022585666287810575, 0.038454200877177144, 0.011623042894737616, 0.049852761815512375, 0.04025232797909168, 0.02434768383541415, 0.04447549874443681, 0.04204417699046674, 0.013013053891970026, 0.07710301873063849, 0.022975166455932686, 0.06687605137666387, 0.05274573964397273, 0.024434617577841686, 0.0631279010896481, 0.03905638429005781, 0.04012523016201393, 0.061756377709248376, 0.024608320353793043, 0.12681325371827812, 2.9112596281113166, 13.530984693957915, 31.89916180026147, 42.125545701672955, 43.13064913595877, 39.277963792124105, 25.66111057035385, 18.020482524748772, 12.667676902586415, 14.963917713011465, 19.03618028087001, 20.24931642317003, 25.330301792390888, 23.152407715397498, 17.52353979695228, 10.27832490782584, 7.809726326696335, 4.202868178967507, 1.3853530754004757, 1.022243150059254, 0.22996272561290573, 0.022557694502475283, 0.16404694246668972, 0.22096119250261018, 0.29938219655906, 0.6361926911819367, 0.6264604327659453, 0.24782627190072692, 0.3723733073040363, 0.6026388981169271, 0.6930790709391718, 0.5994332185195339, 0.34075137347944323, 0.775060529910749, 0.8563181277244323, 0.9318266953191451, 1.4469759622889182, 1.7557603865861895, 1.1876276207547034, 1.4381621513635883, 0.42398982951717995, 1.208327316468762, 0.9502379331857929, 1.630930833278164, 1.5223211386511404, 1.8830135969385025, 0.574606147504622, 0.7739338290787513, 0.3743565863659305, 0.10105082765221597, 0.31591749960376375, 0.441042180623739, 1.3655960968425198, 3.056232636013339, 6.916779635414001, 10.82448749772964, 19.19586781532534, 22.94048401617235, 24.186528844218103, 21.844856200679658, 11.964879362813889, 16.666144978615545, 35.118643237698464, 34.66353454897481, 34.14922944961056, 35.60443270590998, 31.05726230529047, 16.79331998671255, 3.9286126244452695, 1.0020792255959203, 0.05724759021353337, 0.015460279631248165, 0.03200794254700023, 0.018566058490485437, 0.02071256790640614, 0.043716087276416446, 0.0879054866550911, 0.03671464885795309, 0.1181158958183181, 0.09434820948949746, 0.06503267529150171, 0.013438120649586762, 0.019026628635343046, 0.07919781721167027, 0.007522498865822151, 0.05763595848674736, 0.04996965917187834, 0.12663685431283328, 0.026308102833647883, 0.014388625089439654, 0.03216606692501134, 0.06298142507852567, 0.0554661370152908, 0.021621153930262215, 0.03695767109973296, 0.01805207478032718, 0.040602207994989814, 0.032531628760719494, 0.05985492449854651, 0.02335735623003735, 0.04097194884032492, 0.05916012105562034, 0.045116817758929346, 0.09207779301270362, 0.026786379185655428, 0.06946371252378149, 0.02717061824495754, 0.10119846045610406, 0.027035646959237998, 0.07291802595699988, 0.05652508886170484, 0.06701963157543252, 0.04810582470869826, 0.010308869813959445, 0.07174779600914448, 0.020472307411593296, 0.02721959041551717, 0.04438113586436357, 0.1473664197950594, 0.08602715397794401, 0.08514671977008544, 0.1917921956027708, 0.1991275334430318, 0.2075063902884722, 0.18816352821886542, 0.17415115189167762, 0.09523117178750616, 0.14078517294218465, 0.17506304166970715, 0.12395508692509706, 0.13818415122166758, 0.15844083361087308, 0.09618073010877257, 0.21521868935275465, 0.1627130608164495, 0.1285377252967127, 0.09327539528209357, 0.21130545094849604, 0.14418773713611788, 0.0843979454328937, 0.11951820444195502, 0.1976224311417149, 0.1890158316781444, 0.0809250007413568, 0.13727883447802838, 0.0886265515920616, 0.16411028261626923, 0.1875644474620781, 0.14097865610834093, 0.26569170276484183, 0.16446640624875025, 0.11432343117532232, 0.15715074154638475, 0.19196551533476, 0.1259699134877132, 0.08421356339127788, 0.2389868429952091, 0.24759682856740492, 0.11877021917532529, 0.140149703008994, 0.13212778184923435, 0.11104079038505593, 0.18311821104538056, 0.23805529540104253, 0.0670998256593462, 0.18347788932583026, 0.10867703375556778, 0.17650624406674217, 0.09291362558161059, 0.1241981742843505, 0.10671043242778509, 0.10172308512753057, 0.09506654715345753, 0.1399315364899174, 0.2045080447269063, 0.19023768063033783, 3.1934927932677732, 14.925490252433287, 36.39762616926624, 51.13936808801467, 54.44969946338285, 48.53065067721952, 42.48257944660802, 38.80645175133982, 29.684468046311412, 38.168835178498306, 31.52914893242621, 17.40652764997175, 20.67426012408349, 23.424194628192534, 20.006660953644786, 14.358599897353882, 7.531970547091577, 4.8214293872156455, 2.55400451440965, 1.6057017806076235, 0.5471800159542792, 0.1932555307904559, 1.4394182904112724, 1.8431679543948944, 3.3738548957532455, 5.5977140030553265, 5.77062237647272, 3.5897713226656762, 3.0472565370221294, 3.3974874211895854, 5.790859355080513, 7.110820758727289, 4.439994577438601, 4.224618702165542, 3.436037700983786, 4.490391640893875, 6.72165495734061, 5.440652985726634, 7.38036995933902, 4.137439122123103, 4.6910547056505765, 6.794648305062325, 7.865192073006784, 7.7814999703438055, 15.416485686456005, 12.520743935338913, 4.55648995214893, 4.677992232384221, 4.06339555978775, 1.7652884366050845, 0.8081916263026576, 1.223342884932795, 2.021069137319442, 5.331622862046765, 9.610358995776023, 16.661122383609897, 23.55881037250642, 23.788296484178115, 20.96561574166821, 24.41405769317381, 19.165210570058516, 28.538341676035238, 39.92939103034235, 41.653131515749045, 45.75753496539208, 42.46567403116534, 35.61772954079413, 16.948063373565674, 4.189942498360911, 0.8247873583628286, 0.07362680284366493, 0.09712075063538167, 0.10480602977857476, 0.11065132660611023, 0.08102754161002175, 0.11487102316271876, 0.277807996157677, 0.1036314944165849, 0.18391008548919233, 0.1479488151568559, 0.19916151710335286, 0.09757959133675022, 0.16264857153498358, 0.18174410977911565, 0.10660218420408427, 0.1745861059715671, 0.13327351230527126, 0.3120116156435782, 0.14179905966645287, 0.1615197256567978, 0.09034882449815351, 0.11565599515433274, 0.240519585748834, 0.12117296201928009, 0.11905123554770985, 0.11491949354568798, 0.1362903052640538, 0.24587542900154669, 0.1361045442641743, 0.10769629565578316, 0.1220103420857941, 0.11807266547675095, 0.1963978242729941, 0.1841335993019804, 0.1284385935193108, 0.21192918441468672, 0.16900012990640056, 0.14884899911140242, 0.10532035822829894, 0.23479670977159856, 0.14331608229587156, 0.18996265506552112, 0.1649299047646984, 0.0761652198590098, 0.09391970586993041, 0.17246739788641854, 0.10184896103436909, 0.1695477755199517], [0.04846718455214174, 0.044176847028035315, 0.056349501509459755, 0.08030749556999053, 0.004209524345388937, 0.06175794435905353, 0.03142982578626083, 0.030338638875212882, 0.010533532758633937, 0.04118740340814956, 0.06273932980313417, 0.015755704202268635, 0.08102323619588729, 0.03329461019846701, 0.02077435481271917, 0.02267557436660413, 0.02395026040293517, 0.029694761127053253, 0.011749005944077528, 0.017365194601757873, 0.11121497579639959, 0.04265867143629059, 0.04502624701408129, 0.04042286681191575, 0.042588271786488836, 0.028922623023390773, 0.040666214641063445, 0.005100404162095079, 0.03129595383671263, 0.04856406020060663, 0.020022297788771893, 0.044749846321440516, 0.057955014955012076, 0.057743743227254, 0.05196886520171839, 0.016447254644346335, 0.011188046680012298, 0.0738507839700868, 0.03326081422968738, 0.05831953874158283, 0.06676051765680313, 0.025311056637175144, 0.018208950435021715, 0.09528806913764247, 0.08459453125514331, 0.03337856960452853, 0.09172789767504701, 0.06431451382776422, 0.08829272877905639, 0.02193052513194421, 0.10409264104260553, 0.03844424556460112, 0.044286298009777264, 0.06624973619416838, 0.04824156782800152, 0.033088176315950776, 0.05061280147563066, 0.1475919101146921, 0.03146900735314816, 0.6260001671410377, 4.961370239334722, 14.489081463506146, 29.900931889011016, 37.56588059086954, 37.04770018977504, 34.65140658040201, 31.483290541556578, 30.827011331435177, 27.954167396791522, 26.821681068789577, 20.37929984831041, 14.890046734963695, 18.221623628370224, 25.60917446690221, 24.081940804758382, 15.317435053087051, 10.856564640998842, 7.170852634214587, 5.183247933464666, 2.9749978982633163, 1.676459990201458, 1.149817075460188, 0.5024374168246023, 0.38242453408818095, 0.37906496274855833, 0.01010804177982913, 0.44371726772477554, 0.07158470355094441, 0.23740933006328924, 0.2874107857144648, 0.20063353972809933, 0.4346498816965088, 0.5766294776431976, 0.5907750766604178, 1.3047437105448016, 0.6795395394006084, 1.0943930043328194, 0.6864274052842971, 0.4328344984640999, 0.4642909572970483, 0.5079175808256673, 1.1178428944080108, 0.6835317155045848, 2.2633257508277893, 0.6476795360926659, 0.7662259426809127, 1.6170903824029432, 1.1069183580337034, 4.445408919165212, 6.513719327988164, 12.377093011333097, 17.552108380102343, 22.268203496932987, 30.98097808899418, 27.346282389856157, 23.142342913535334, 17.718369806966475, 19.5360843981466, 19.720459330466486, 26.024147502837646, 31.474002368988533, 33.36897196308259, 30.391512532388013, 17.10854911035107, 4.919253789609479, 1.3892072943910476, 0.10694395900974352, 0.025671060504992644, 0.050265974320110776, 0.033320557596462394, 0.058381921281256986, 0.0511836250793309, 0.06345546879475156, 0.07280875883635975, 0.044200170574890035, 0.039738777108610644, 0.019878200480654355, 0.015079520526342096, 0.06286411403468059, 0.05477947708699973, 0.031093811961792173, 0.03483912006260888, 0.029027408529673854, 0.039977095570535436, 0.10168111883103849, 0.08560341542526599, 0.04870430025602541, 0.0698562176717866, 0.08498783313458966, 0.04228215454326522, 0.03527798502135181, 0.03326045799880259, 0.037898155109536265, 0.08364589990026529, 0.05476596329601542, 0.017024475082214323, 0.0153133851445971, 0.014033296273180075, 0.04013158869178545, 0.08143388230593936, 0.020630874205380678, 0.027178788572669994, 0.024581206586932944, 0.06751175879711105, 0.1148178949651699, 0.05703597374620938, 0.07453438720756, 0.07511514314119855, 0.05180853449048535, 0.03542706573141679, 0.03003096455828317, 0.012004322939432197, 0.021760861554573623, 0.05472261038038039, 0.0370677464431332, 0.03725043159999675, 0.013027331855658804, 0.06727456265399534, 0.06140862358734012, 0.051146760928414525, 0.04796682571571681, 0.03598024633022086, 0.005379659489863703, 0.014509266700535534, 0.01964333132960864, 0.0319373513752174, 0.016112276953795267, 0.02324584064133946, 0.040919602052458835, 0.016670383497952454, 0.031247985241333806, 0.030860120670930035, 0.025015411815876444, 0.04421105285385444, 0.03400731711618362, 0.021634755821357814, 0.03999356263046784, 0.04860914447495053, 0.024447016710896167, 0.012310537858866157, 0.10385696175357989, 0.029475746165600517, 0.07878877222537994, 0.024888955597435276, 0.04115245830748351, 0.02650278684262547, 0.07258790334866894, 0.06158665092962404, 0.08821393663604414, 0.026407039258629087, 0.027268748362398437, 0.00291253054691028, 0.022853643843723882, 0.04832751140178693, 0.01783766017685975, 0.07275070469345778, 0.048982037772094054, 0.01588807174665553, 0.03629248078551985, 0.02474532177251193, 0.04305399195741742, 0.041246717765686974, 0.023934092117293228, 0.022811882475751544, 0.024472900906637795, 0.009273951103339994, 0.04158832786244251, 0.020823371033334447, 0.09935372073443667, 0.052094507451740005, 0.09239171286143603, 0.054474041662028724, 0.04632611436048343, 0.07419612108459396, 0.07397346529028109, 1.4730314093251384, 7.164328752025482, 19.258272724766886, 36.376684634916245, 43.9738332071612, 42.503799469240256, 36.41464141107375, 24.367858056099188, 24.21975720313288, 15.674943404812968, 12.911857193516148, 15.422474165116588, 22.92173508674868, 26.95114281869704, 31.231433191607078, 21.62277356270821, 19.58327051131956, 16.015945442261234, 8.275836283160794, 5.512564739873333, 2.879472495086732, 1.3466054513569803, 0.5667927248343345, 0.7897694793439681, 0.15572125212319438, 0.22814587149168217, 0.05940234273551934, 0.27917105043607376, 0.1602737142914726, 0.289960540831089, 0.3156031890501899, 0.30883875525286125, 0.1940914246463968, 0.49492047018101143, 0.3229338231105959, 0.29619827385871644, 0.3271111779876294, 0.4792403970514575, 0.276610141079272, 0.20194843771957582, 0.1865963881174403, 0.2986649544008317, 0.3488192905581767, 0.06369403240481211, 0.7413893721757397, 0.40500374991566906, 0.3355157141002917, 0.9140150285055562, 1.293892841185293, 4.3099219183768, 6.9643864227879435, 13.52367731832689, 21.545914719181678, 26.264924157050352, 33.49490357983497, 28.506648925042924, 19.381431225807436, 12.252338105632413, 13.902591024675678, 18.207040256069554, 25.508173434965073, 35.304124278406945, 37.45668180527226, 36.106013636435236, 23.178589536297707, 8.45149080599508, 2.3939850493784878, 0.24991623636695648, 0.08311443406367496, 0.01691906138383333, 0.04162975789738759, 0.035952364560216665, 0.07230181547422564, 0.03641405510866354, 0.03508000874951963, 0.027766065829763972, 0.02859874977730215, 0.015207397837882802, 0.02806249014552563, 0.039179349062784065, 0.06047538676930051, 0.012069951776685494, 0.10693394624057317, 0.05798511071911743, 0.04667224820643183, 0.05496642935360151, 0.030012708683047565, 0.0433333650712044, 0.021722591632316192, 0.03969204574522953, 0.03986293697849878, 0.03644653723665303, 0.0299280425608759, 0.06032320723358182, 0.05727530344419422, 0.014374098147175485, 0.02920670949313189, 0.03923815397185184, 0.04949391474046054, 0.08898579320239444, 0.07682340429915537, 0.04024267144080612, 0.06592446292239813, 0.03742929014767851, 0.0887464443522115, 0.008008552446675999, 0.13293025894991814, 0.07655332000145028, 0.01383215701583052, 0.049149362866075776, 0.024233146029854977, 0.010312249219315428, 0.02838870762066255, 0.013724780217143557, 0.008356470798683024, 0.042469317484046185, 0.049358543173800555, 0.14101876847205624, 0.14739844227029433, 0.14691174661199893, 0.2194599053191562, 0.1857042634078572, 0.12248912405583168, 0.08796903364841016, 0.10252466590534295, 0.15352668601178354, 0.12934855275577115, 0.23849123007347509, 0.08832423797538204, 0.12780900714137863, 0.10231959948977155, 0.1531248116084645, 0.1378952747871799, 0.1671150326728821, 0.19682954546184311, 0.2570288418041122, 0.11048732250328026, 0.18167597391913015, 0.10398927279898237, 0.13123691352384706, 0.08388034578773283, 0.12126095487826294, 0.212543724825786, 0.22852900738437332, 0.13487364015271588, 0.1135930046439171, 0.15248197190944227, 0.15063609837764694, 0.19067461121707194, 0.25651277433479985, 0.3692948289455906, 0.16200093612555536, 0.16741791319462562, 0.12009087814799241, 0.1494754138853281, 0.10736034311834844, 0.13974940674679895, 0.16727661593787133, 0.11447870187581548, 0.08140123163860652, 0.19815294702927913, 0.11713419244774889, 0.118482522516241, 0.17446226019772793, 0.1559887547045946, 0.09681846000133984, 0.11161499626694188, 0.25530100709969, 0.14937815136246144, 0.2575394853709206, 0.2138448332346255, 0.20864769275630676, 0.16051749879073712, 0.19327201700258642, 0.25970736097904945, 0.1393379562444264, 1.6953642209691389, 7.165673634698314, 22.217122470178914, 41.78510358256679, 51.95611146188552, 52.57641861515661, 48.71347235095117, 40.86825739952826, 40.403060374721406, 37.67876640442879, 35.69073269444127, 29.205346607392837, 22.66147209751991, 30.258306880151075, 35.690160028396114, 31.218508981889297, 19.72668020955978, 15.43165643368998, 9.058782554441883, 6.450288718746555, 3.8318259341101495, 2.100981055728851, 1.4325671354609153, 1.0545886692500885, 1.060232101909576, 0.9767837990676204, 0.3965096734464169, 1.1602549927849923, 1.1156420770191378, 1.4686350452323116, 1.3191004433939535, 1.2353682590107764, 1.737340323386654, 2.4037738144397736, 1.307312495285465, 4.364538471544943, 2.0911148238566617, 3.1835434561775577, 2.5346880670516723, 1.2394100163252124, 2.0375601298386052, 2.2762877133584793, 3.0132020288898103, 1.9807051290427486, 4.5087551974481155, 1.7358341332404845, 1.6683146982423722, 2.7796569995341764, 1.6968689402264936, 7.225861914696233, 9.392878278609246, 17.501923614932647, 24.36778941462117, 29.981938638994773, 39.06801892865089, 35.10878632145543, 31.12822190407784, 25.6690945548396, 28.08920087352876, 30.044625959088727, 36.81037718249906, 43.047898892433416, 44.48427477190572, 41.06865129163189, 26.16262285940109, 9.548168836101409, 2.47824368938323, 0.2737274441507555, 0.14620283949038676, 0.1289569132871205, 0.10819105821992121, 0.1366983083707671, 0.13455405891422303, 0.08064008498143765, 0.1867193758728043, 0.11986493583648436, 0.18393501399024842, 0.09981922640074646, 0.06708179194960864, 0.17598098354233851, 0.08463155628452379, 0.0755811084602629, 0.1965935137723723, 0.2644965136724134, 0.16569067603878437, 0.21925221888288376, 0.23334690369665625, 0.1928553264588118, 0.1758441755608205, 0.1499894435607618, 0.11829230288464217, 0.13713853313557564, 0.12944823611647854, 0.15241855515107033, 0.1436778596572338, 0.10326859856685323, 0.19022782873963157, 0.16128266740950847, 0.1984743209135148, 0.17848760790882573, 0.11871898321494942, 0.14215293100043652, 0.1820830883638513, 0.15521275360257397, 0.2531218853208327, 0.19519868216687636, 0.1968824668156524, 0.3069754455599093, 0.13046158657919976, 0.16485778524750666, 0.1238118974311698, 0.13234262354671955, 0.10753727878534025, 0.09268346978651901, 0.12968437505825875, 0.10881759556791476, 0.21699725439952267], [0.014082143954452009, 0.06209935910338837, 0.054998681655213724, 0.10779542743318504, 0.036941368748704274, 0.006128922208107167, 0.07156904471377212, 0.043774463176246614, 0.029169004560718616, 0.061988854750750534, 0.03291956419425626, 0.04769967170432211, 0.09272125324294453, 0.03592535613044616, 0.046086593140517516, 0.01973230286591476, 0.010725855301584928, 0.023253348302997412, 0.036227401616352226, 0.04900978547671149, 0.03604545190389599, 0.10404659149747703, 0.02736719257588829, 0.07409459911286831, 0.03837946516972396, 0.021329149941823656, 0.03015846074108155, 0.04095651599909029, 0.018565911018560012, 0.07258684614733343, 0.06723161576496017, 0.08891073190757344, 0.010479053373508638, 0.07934413234432859, 0.04962551715453306, 0.07114172086960847, 0.10436691584125643, 0.005832768417143774, 0.04764479299586627, 0.03490187032448669, 0.07050466513441456, 0.03616293531752402, 0.01378187100448075, 0.04722945842771761, 0.038307012404285135, 0.03567019522550606, 0.05776392581361917, 0.03902315522634214, 0.019077194268785177, 0.05492498016645832, 0.04660936004872765, 0.018318690614955082, 0.046506374849066626, 0.052847931942632126, 0.07521843477602928, 0.06961041070040196, 0.046472203497204094, 0.014004480833518169, 0.033083775140825784, 0.015315371227540798, 0.06967042602839009, 1.6687768024782983, 8.840741918933007, 18.93034492769549, 30.791961031575358, 39.38953953404581, 39.04194693411551, 35.02692253358903, 32.57671594619751, 37.37449638305172, 32.57590205438676, 23.568700628895915, 16.892693235028176, 16.39714785160557, 50.3777850058771, 34.50297624834123, 15.71889062081614, 16.91774345213367, 18.75023949530817, 14.5667944031377, 12.356219137868575, 7.595329082781269, 6.719475100117346, 5.388828179528637, 3.5747069697226252, 2.4679376617554696, 1.3040709014861815, 0.7662532154110171, 0.6913239328611283, 0.42272210722008063, 0.41541439451036916, 0.30824442424120446, 0.2716253908170808, 0.44314677736932234, 0.3420325789240099, 0.7199853045805809, 0.3746887314463816, 0.5026830859001606, 0.9174740687012674, 0.4569359309971333, 0.6141866623393951, 1.1616079653463056, 1.389101635544531, 1.9691316855530587, 3.7662885217897357, 6.393096639264015, 8.795174764048669, 12.615885926831155, 14.417424663420647, 18.95865463441418, 17.638722158247425, 12.384338609633907, 16.10202087510017, 11.820430236478007, 17.17982053756714, 23.296888220694758, 36.0799769432314, 43.04112103677566, 29.704485862485825, 31.18988548555682, 28.654706631937337, 23.748327532122214, 12.99708245262023, 2.922821549638625, 0.3093981832986878, 0.06635774693061268, 0.03131905904850893, 0.04997675697649679, 0.03533332721300183, 0.04820663038821471, 0.04262329349594732, 0.04509127255709422, 0.0742638509179796, 0.05431001457656103, 0.041077013968700365, 0.01615937795459984, 0.024694834663082036, 0.09064012943136115, 0.022299865696338877, 0.0257247977424413, 0.022076160361569737, 0.045555452891295, 0.08301104283741406, 0.02459536389177365, 0.041744674916469285, 0.002771045119809588, 0.05839807041470082, 0.041408948374972235, 0.03960698317255705, 0.024181195692489707, 0.0060194831964890325, 0.06687727711734272, 0.047052829195895506, 0.03891368509240208, 0.09201220056462674, 0.07965138722811976, 0.05832851346161577, 0.038687244823743264, 0.006096600958581774, 0.04089987145796899, 0.051874084803726406, 0.051713631518425486, 0.06375292158355156, 0.028935656094202594, 0.007389354220997062, 0.03840434004462535, 0.005123334610083651, 0.0757264506612574, 0.044294797755297155, 0.04141740981609591, 0.01885379345396594, 0.021733866531341788, 0.04018093241498836, 0.04394366518564282, 0.025512173869496873, 0.08112943130395106, 0.040937080348451296, 0.057762730716457295, 0.011328055951443892, 0.030243316470014475, 0.09214078076183797, 0.014920789981260897, 0.1132220648709805, 0.035714563207640763, 0.032555507721319314, 0.023970084843195738, 0.023509462987403237, 0.13411340514017692, 0.03049402257367488, 0.021012498989641186, 0.024451389157723998, 0.029214856838206613, 0.0572448744318418, 0.06573549201411587, 0.019147318126934192, 0.06652460088052096, 0.03884765597420835, 0.012642425342252659, 0.03059980782469915, 0.08861435547230706, 0.02565205960925068, 0.035766289464288184, 0.036007362012300766, 0.048656484878231446, 0.025887055164803902, 0.040107468413489486, 0.05551294498746434, 0.07650612132443536, 0.024406345102996118, 0.022642262948436603, 0.05341974763019432, 0.035278712804879875, 0.05294955350578793, 0.031104424194763267, 0.04496484506695021, 0.060156360944552775, 0.0782714790153888, 0.01782157041523005, 0.0039837872018031175, 0.07930755930682344, 0.047429300123645414, 0.015181196673262506, 0.04247828837363951, 0.08286655865489476, 0.01741353283456016, 0.013799759157512699, 0.015662149544955505, 0.04870344989842946, 0.019532290715423804, 0.008659851192797144, 0.05045260866022399, 0.0556553645630277, 0.05819050655249627, 0.04007578684738086, 0.08940568599369257, 0.06666696299949, 0.051689744896946416, 3.189992077888981, 12.253144152702825, 25.566053890412856, 37.931363121155776, 45.362081604619185, 42.48938868122716, 36.90276861190796, 25.038601006231, 23.291693041401526, 22.49705614582185, 14.090254864385052, 20.365091062361195, 23.20423399248431, 48.49194865072928, 33.02109303012971, 25.79280218770427, 24.90832144214261, 26.102165406750096, 19.197262217921597, 14.832299640101773, 13.766552440581785, 5.986249773733078, 5.504745004638549, 3.5671291956978464, 2.3076401987383446, 1.4076288284793979, 0.9557778520449516, 0.6198508100163552, 0.17874558035644794, 0.2729111927891931, 0.3184301454213358, 0.4406728343136849, 0.49236118493060915, 0.3444220071598407, 0.44877954608490395, 0.2511912364993365, 0.3840536047374049, 0.4068242506154122, 0.3298267451745849, 0.7083757630278988, 1.2376657873392105, 2.1614198771215256, 3.326789640611218, 4.3565240886903585, 6.267543531233265, 12.445764887717463, 16.018494982873243, 20.348954431472286, 25.282660684277936, 25.530117134894095, 20.579691779228952, 22.48660106812754, 20.54837557577318, 19.27075174547011, 21.8902595966093, 31.11750598876707, 38.28784773426671, 30.747477431451124, 34.110868669325306, 33.83866010173675, 29.44895129049978, 16.615718987680253, 4.507499548696703, 0.5159993794175887, 0.07227453508324201, 0.03555839235383657, 0.12008341645160991, 0.01957595198144836, 0.018072950676263824, 0.04680840884365382, 0.0456247149005292, 0.0065239779500951695, 0.05816134924609816, 0.02502364726106246, 0.01429780632362611, 0.056244976473070925, 0.07169754830219092, 0.045072507233388966, 0.051795281169395295, 0.012220176830587369, 0.06615786693028866, 0.02276327994261538, 0.08273440848795638, 0.0026848992509316775, 0.052045470163706815, 0.0389580722267349, 0.02939542950761895, 0.06267752565984284, 0.05576159031460843, 0.023092665191319202, 0.021129754492111748, 0.08251321592157887, 0.006377887376959646, 0.04974474724862845, 0.01857974848169233, 0.01782236331623168, 0.08033940313203682, 0.047901248589398406, 0.05743087291897786, 0.038988830656894756, 0.06136966801639046, 0.03779761756079332, 0.028916682011537978, 0.051128076043941324, 0.04768321996614818, 0.033819399578797246, 0.06633628880785358, 0.04424393334756455, 0.04495691605693391, 0.04809683466690683, 0.010273443993120905, 0.00830171179146536, 0.019013019083368204, 0.05420866114417872, 0.021494994570891705, 0.15970630360947502, 0.17474580466026263, 0.10107424696006122, 0.16208964910718704, 0.16390313244154378, 0.17872157116090098, 0.2350716740493813, 0.1923723386660699, 0.14773153729977148, 0.24410210399618074, 0.233294993578907, 0.14044250181365397, 0.2423557146422325, 0.11424339030899348, 0.14216406991885555, 0.10229436455354576, 0.22302527851875753, 0.12903690818817387, 0.11510364576092652, 0.13545712335936486, 0.13408182699593807, 0.09353878397134044, 0.10711285841440964, 0.3092363548855628, 0.09388560729642069, 0.1216292363261023, 0.18429677602985214, 0.08517200833246594, 0.1338986400514841, 0.26109067062216423, 0.14836115432122063, 0.25092019459172604, 0.12494503340173153, 0.1707497521513893, 0.15529210498977095, 0.15685081812402896, 0.2579593015534263, 0.11192372203954767, 0.1682418254354308, 0.08728739925690236, 0.1307501719002762, 0.14416714469271322, 0.09066341850425928, 0.16512744819685338, 0.11080170966564648, 0.08627375001989065, 0.16600890896253048, 0.13279512104007507, 0.10182058513765374, 0.12759107044867932, 0.14128768065523717, 0.10582652018075028, 0.12864677025185478, 0.09119139864079415, 0.15535829498642878, 0.17129920573244173, 0.1279293059281284, 0.11314537946976001, 0.21111184520827186, 0.17472780159404203, 0.09834053881105878, 2.521524347605244, 13.169067598158314, 28.501394910197106, 44.87106361696797, 55.584880459693174, 54.956297105358495, 49.560072806573686, 44.31640517327094, 51.39256492737801, 43.04184275288736, 33.66463238193143, 24.517641605869418, 24.231626295274307, 63.831247975749356, 44.0032470610834, 24.09706154177266, 26.167598385964673, 26.55657199121291, 20.737467158225275, 15.378902516057416, 10.66028041224326, 9.148297905921936, 7.472571153794566, 4.889492805927031, 3.548881594211825, 2.0093158776721647, 1.4758584576268352, 1.5557602023886097, 0.8759993555084352, 0.9754206528586726, 0.587785127422502, 0.49637413733909214, 1.1334837131923245, 0.9969862117882698, 1.4310621710554248, 0.9484476776373003, 1.4165682778243096, 1.4032970609203463, 0.7310754998076348, 1.0011985309181675, 1.8360515491616343, 2.0541583746671677, 2.824950814247132, 4.95937277232447, 8.704143416497017, 12.578960734028971, 18.168355880245088, 21.347940929474372, 26.87749247397146, 26.5233200980771, 20.7954692071484, 25.049499311754783, 20.627289741270005, 24.87261610646402, 32.72523649277226, 45.96777008425805, 51.54003427874658, 39.73884620974141, 43.08473779309181, 39.7314525419666, 31.976938478408325, 17.431573944707072, 4.802660355644842, 0.5301794830349185, 0.2208354161872018, 0.16224009345375723, 0.23835713404320905, 0.14055136290769424, 0.1351960099512531, 0.1583668141956291, 0.15359324373064503, 0.19042033131324476, 0.22819628007709983, 0.28525461592981893, 0.13211451320638581, 0.18133391566093893, 0.16088018013585, 0.07479689489569395, 0.0972385902798945, 0.13427616818056953, 0.18044949779587408, 0.15408645113629682, 0.21013129863046834, 0.12445894295289633, 0.16191585440068476, 0.17142038552030442, 0.24054367155317338, 0.16726075791783873, 0.10118203553100748, 0.13207761841195245, 0.1939195911249807, 0.16400561968405403, 0.1277749775157821, 0.21735118702054027, 0.10383164254768242, 0.17551330218632377, 0.1665741745983401, 0.21472398041477128, 0.14794282434928804, 0.1819672252261831, 0.15680122159181104, 0.21283508338514837, 0.09154609734973601, 0.14853747711787302, 0.16528779039940528, 0.11240038194603498, 0.2277473219099545, 0.1378401164566317, 0.0704419072116575, 0.11205873737532286, 0.13994790012798003, 0.1016808353785065, 0.16085520566951844, 0.16716708068645772, 0.21387777501536956], [0.03893677881287952, 0.06688287722006922, 0.008561818751566594, 0.07691659123426484, 0.028950535436911933, 0.04116915136335358, 0.04028351541848914, 0.048196376301348216, 0.044702609340029384, 0.08370340245986178, 0.00847844731798696, 0.09723856729725677, 0.09794788044546882, 0.033707910803176706, 0.019796386120780822, 0.07746229864536755, 0.10206037065795354, 0.08061340213903496, 0.0636553181515586, 0.05812308698471996, 0.06549715439999296, 0.11370240966038359, 0.02154734518919741, 0.011480055456500382, 0.01528750190646538, 0.06932506593124521, 0.08235605298391274, 0.05543389620499746, 0.024308008141815666, 0.04279852461730761, 0.05737458460874135, 0.05137875150408476, 0.01624107740128473, 0.13353646432440128, 0.07376672880303475, 0.0950480001648107, 0.046698394787287524, 0.02716791012414521, 0.037954420437135046, 0.0497536874947048, 0.040593191140121034, 0.05438637055997407, 0.01981085369123086, 0.016796895257768132, 0.06789818120699737, 0.007158677486116968, 0.02646796240080749, 0.04163667184090422, 0.048273303020264835, 0.03135254858211885, 0.028295198928624875, 0.06271301468293514, 0.024032080508468133, 0.03516949931039445, 0.017367816537678722, 0.057571622422866287, 0.08996430964719865, 0.05597926653741349, 0.06396997727513795, 0.15636565464158214, 0.05179916906561102, 0.03339389136301414, 0.14987825355943174, 2.1954150594049886, 8.354473921560473, 19.035462487128473, 27.483930126313243, 36.55847472529258, 40.59757855630691, 37.3048900019738, 29.093768904286048, 35.32699561888172, 19.551346340487083, 20.62251033321504, 31.80142810267787, 58.576174089985514, 37.38694206360848, 22.92256074566995, 21.651608867029992, 23.839832505872174, 18.47378496200808, 21.549207548941336, 26.40288176075105, 18.85153666619332, 18.583215167445523, 14.467944791240079, 13.476706935513405, 10.664762700757674, 10.663653650591451, 8.651657200628712, 7.893834690893851, 6.342309790272867, 6.098937507598631, 5.3512401061673325, 5.55615698137591, 4.648117990263047, 5.206608099322166, 5.201129528783984, 4.812456965446472, 7.215101872721027, 8.288514364150263, 7.768124688056208, 9.023763633543446, 10.213107658970742, 16.141368131483755, 22.96650305871041, 20.359227118953584, 16.768838513282038, 13.935791926999247, 13.834961518164604, 20.201555682766823, 22.4324409807882, 20.855722696550433, 22.698644399642948, 28.269855437740205, 27.488538911265714, 32.903165009713945, 34.28985034265826, 31.583493371163648, 24.350048534331787, 11.53719392514998, 4.961330525336727, 0.8963163136955231, 0.013298001253016055, 0.08515289443875514, 0.0603893167910076, 0.0819984584626171, 0.026130923933740106, 0.06227631009213867, 0.06748265511686764, 0.03687584141810094, 0.02568786847405136, 0.020803582982250282, 0.030588354810231158, 0.03243339330618901, 0.03542685122679799, 0.038973478254892176, 0.061027360779623833, 0.05610458703050691, 0.021864201069899628, 0.036446629167203946, 0.010965028909155199, 0.09729439212429909, 0.06880062512092053, 0.04240081390185703, 0.1107535687004847, 0.017826519343220902, 0.05250351030319449, 0.04235124801315608, 0.06641852834652509, 0.02956742007705954, 0.034486007155670274, 0.012918335738621894, 0.010413368037270923, 0.042209935434643304, 0.019122753517642137, 0.06488796128260513, 0.015313608267705048, 0.13739883449048768, 0.0346867643266676, 0.04682804367715313, 0.024810025558596658, 0.03581236582249403, 0.02111081296818391, 0.020907587078850598, 0.0401631668360243, 0.00592523570840938, 0.01075964360948532, 0.06802592636837114, 0.048428451146690116, 0.10989583367782255, 0.01051455867596932, 0.12004272952195137, 0.06914152658634609, 0.044013716265439026, 0.05227942958534245, 0.01403417248624347, 0.03811110073940889, 0.031107149552553896, 0.010600939877481471, 0.012064994230205494, 0.04904741571555215, 0.015545178452626833, 0.047220096833282904, 0.03702748469227264, 0.06251593090353474, 0.0643629765498542, 0.08072604770742117, 0.03945353576132367, 0.0937592027889144, 0.0193843150871896, 0.046888848075703274, 0.04920015066501595, 0.021156946782984083, 0.06387593232155328, 0.020445161085996418, 0.008084723132572347, 0.025817408196387753, 0.06113445221055901, 0.03721833251596939, 0.02558310020474657, 0.029903035535807573, 0.024747323177214113, 0.04922876787942745, 0.05595578977297391, 0.050653637792434425, 0.023337388148290977, 0.02575624182129339, 0.08108477603884474, 0.011416398338042201, 0.04034957134976022, 0.0588862331313712, 0.020672742825662418, 0.031708796703887564, 0.06128420707799735, 0.0324498029095271, 0.050386112228396444, 0.0630147920380677, 0.04552076443008358, 0.024932896485552195, 0.02647412940859795, 0.0433366745710373, 0.023348067413955446, 0.1230904954155126, 0.005864677415604914, 0.032710946961155826, 0.03285733487216696, 0.06373050585088712, 0.022364594380281145, 0.0702055920696547, 0.011578571490733134, 0.10776456175071579, 0.06982736680055819, 0.10243157090078439, 0.03435542746897667, 0.10473879790233989, 0.07057115390536285, 0.013304645150539376, 0.5486038363268299, 3.632987261779847, 11.990719937509107, 25.962013236937988, 36.55755296830208, 45.23870737321916, 45.6767733635441, 39.78731886033089, 29.237239399263938, 24.396981654628632, 14.582895732695057, 17.325422840733683, 42.93566026995259, 46.71451876240392, 26.4937081644612, 24.229647459522372, 30.96494540091484, 30.657868923679477, 30.5446889323573, 25.87435022477181, 31.82604293669424, 25.252717310382476, 23.67623632954013, 18.94796617569462, 13.072994043750148, 14.609886542443308, 11.041645599949746, 11.12286513851535, 8.05496124490615, 7.187661461291775, 5.473335154594914, 5.0088216027905865, 6.982286649365579, 5.233256682272881, 6.020232698609752, 7.38805829517303, 7.406353700545527, 6.354514245064029, 8.166640929637417, 12.029025804611946, 12.958114685550814, 15.416792611921988, 18.34711790084839, 26.861159724573938, 23.013855872615693, 24.71070851049116, 22.008709292257986, 19.26961229693505, 19.204536253406157, 16.230241194848094, 17.75008216980965, 15.865739257104936, 24.853200374111054, 30.44194244569348, 37.69533449603666, 39.17094976671281, 36.07258327545659, 29.883387127230247, 16.509269783573767, 8.03416140617863, 2.0768700011314887, 0.09135810703399683, 0.04583350833385222, 0.03482361444302144, 0.032206727041592526, 0.01950870286823521, 0.015174059606637928, 0.010315276224226242, 0.06837035949912763, 0.02503404881985438, 0.0440604935940956, 0.0486031421760638, 0.008238592849773987, 0.01927481430973257, 0.07170058967125031, 0.05904100970515321, 0.035496622684501836, 0.05443678680627097, 0.06186980851775697, 0.03863176090582725, 0.028475242997369463, 0.022484776338622458, 0.0016734045165057686, 0.056861692573875196, 0.012527168371654566, 0.06624707786907112, 0.012658568730037059, 0.04014815917358764, 0.05307623380494695, 0.06282250779951293, 0.00687940156973538, 0.035039689542064746, 0.04684007891844358, 0.0262809373558529, 0.0026474490427532264, 0.09063920246497278, 0.047830967683224916, 0.06516077285332066, 0.04889722034755734, 0.02830991164721068, 0.04662649360515418, 0.055078619099672765, 0.023462208769013806, 0.10167901975012596, 0.07433994643149838, 0.030295496633757028, 0.02481207484379411, 0.032458865729671334, 0.10438468908109974, 0.012751679056354109, 0.04900659472050686, 0.07535302110256688, 0.0541195459663868, 0.04750325825185545, 0.09483756347289009, 0.21629424615492746, 0.10007414981843003, 0.3562010073613736, 0.13008983475306343, 0.13777830848290076, 0.1621195878232679, 0.2907148310013356, 0.2095113189951066, 0.18791113289133196, 0.14083850798347305, 0.24432954017914113, 0.19435200179296155, 0.1834407953485366, 0.06532502976516563, 0.20475469439500765, 0.1498653832823038, 0.13526166368636394, 0.10798413787157306, 0.11825304087852279, 0.1492268030321406, 0.21413917953689254, 0.18164267973794093, 0.14330978505313396, 0.118801950537149, 0.17414002829501707, 0.13179582062988512, 0.13100195435747025, 0.1526969974680293, 0.12684977312962856, 0.13644972816109657, 0.24020676140583333, 0.20159617517023318, 0.23637673547191007, 0.19068544370032128, 0.15593974039919917, 0.1817809126429981, 0.11977281376358964, 0.19414106714389018, 0.15585556265807923, 0.12079476739370054, 0.1519673446854276, 0.12786096322440332, 0.12224294936224339, 0.1279836828489938, 0.07091200940551297, 0.09556156252661059, 0.2812825419729756, 0.12892594801322108, 0.10387478095869865, 0.07388383300314028, 0.22057908316773756, 0.10408426770159315, 0.10231207650635513, 0.12288349079749278, 0.1652541131742539, 0.17898387966617463, 0.19362709875549042, 0.16324599754185448, 0.19697824312794596, 0.25806508297401093, 0.14596437164131673, 0.5655273927315589, 3.4403780487275895, 13.461262602959911, 30.580321704187703, 44.02709899410125, 55.89598717228059, 57.15398150105631, 52.25345065516811, 40.24160385131836, 48.11753880593085, 29.393196759685395, 30.140021924049627, 42.211190654385476, 66.58741120369204, 49.65849291893744, 33.049043839977635, 32.157116474643836, 33.821233011061146, 27.783308952085434, 28.508408108065208, 34.56809543794201, 25.584853810648767, 24.145924468194288, 19.21348317976921, 16.769013058754705, 15.152121859212077, 14.085346998706942, 11.926690186223677, 10.802401611881873, 9.126203194741281, 8.44007965057127, 7.637977503961133, 6.987496537546958, 7.179787793467122, 6.848548045081477, 6.9221684817344915, 7.055264797902877, 10.15703639676494, 10.972089229091521, 12.283384646138838, 13.512554457110744, 15.719037709697602, 23.036811544049172, 32.21498320179601, 30.317277754506758, 26.421077635980424, 23.692698517153342, 22.33000828373817, 29.133326007473855, 31.344375879533832, 29.830666549744148, 31.391989531055575, 37.37305295082831, 40.43401572012132, 45.09044570307578, 46.775495929102746, 40.46670867550758, 32.3573064034985, 17.333599021357877, 7.963658273220063, 1.7887184696812786, 0.1843036401776537, 0.11124922758749417, 0.17945349156375856, 0.21425082919097718, 0.10974620904533133, 0.27382982414095636, 0.09945205578039731, 0.21985249473683297, 0.0773988435825994, 0.1272619207720122, 0.15269250819279304, 0.22994861427334048, 0.13548078015446663, 0.17176449689413273, 0.1865023738073726, 0.1178724560586195, 0.09865189226524484, 0.09867013281872196, 0.10441327182155463, 0.27669229634827186, 0.19392369735625484, 0.10695975574274218, 0.1658536535837958, 0.05786068654889542, 0.20345340212506635, 0.10203662193230084, 0.1684432452724826, 0.1671190776171223, 0.1722962232006173, 0.18094537118750234, 0.10231690286027809, 0.11524438377349608, 0.17985689814292616, 0.1161382475026673, 0.18681309906946075, 0.23202077485620978, 0.37119938481238585, 0.13804962618216393, 0.08349077475647773, 0.138497281999838, 0.15463123158101114, 0.1099924526868328, 0.2024214204040266, 0.16296023142433938, 0.05943654090045922, 0.20861839755408226, 0.2132876574872963, 0.1976256487109969, 0.0951473311250729, 0.21758967019136877, 0.15278908123652782, 0.1354418322443962, 0.30869384206110434], [0.0647891819056484, 0.037517455376444325, 0.04639375992419739, 0.011159521396151714, 0.04677043769568686, 0.013096009722850738, 0.030519343694792162, 0.03350257625683181, 0.029940841974870815, 0.013294617059610546, 0.08307399994303143, 0.04202452300476932, 0.09810046217734776, 0.029770268668090145, 0.025501057933715564, 0.03614317790995683, 0.059273831486221285, 0.03811178638810112, 0.06695275976052208, 0.04583695189907186, 0.026505358982831243, 0.016500273674365976, 0.03910651708382272, 0.01800337648620048, 0.046023118925551255, 0.05543737807461331, 0.07874808529572142, 0.01678014857574336, 0.020746540075408357, 0.07897613434902123, 0.038385187846518336, 0.04216726050682126, 0.00909784664174602, 0.08741011888149285, 0.03941453422509855, 0.03168466110383311, 0.07828758984443643, 0.04370531991064068, 0.0429505241223641, 0.012652872866320034, 0.07508793935900734, 0.016102515078420122, 0.005526775663207856, 0.09202434305822657, 0.019836975374229012, 0.028935200271887646, 0.011525529478075764, 0.07054877647709462, 0.063884474201909, 0.015350316328206852, 0.028154933975348552, 0.08515991946502079, 0.05812114112139229, 0.03732041756231939, 0.026730540952074434, 0.06862283909633275, 0.042591768977863174, 0.042432227337192145, 0.052311861917616866, 0.02747983622905468, 0.05139519558137944, 0.05922138127648543, 0.04890428750865883, 0.020251846459183483, 0.3452066037683718, 2.368359714746475, 9.41403946568889, 20.495315713267175, 29.667631272346746, 39.44023224615282, 41.45755037184685, 40.341804719740345, 37.11974628510014, 33.869709584020804, 23.236534710853334, 64.60543363325058, 59.80027914047242, 28.20386548196116, 21.788670209146318, 20.791036928853682, 22.3131009071104, 32.96286936729185, 26.438120334379136, 25.30202542581866, 20.637754624889745, 22.69219602307966, 26.221146583557132, 24.193249825508367, 26.08036095096219, 21.10015499976374, 20.205864406401112, 19.272765882553596, 20.980238337670606, 21.544114351272587, 16.947312239677675, 19.253607065446918, 15.850792084970783, 14.279645527562788, 14.85328628170875, 31.330204356101255, 30.965245462233025, 17.059829350440733, 20.906860597672004, 23.410336894373742, 26.41226995375849, 24.471541989234186, 30.421959930850615, 17.152983680848156, 18.097123676730742, 21.81704071260268, 27.152115260401082, 28.902196422699962, 28.14865419941564, 39.02766950668828, 38.71738649183704, 38.09030148290819, 28.489461098947835, 23.77228144676455, 13.072549835328134, 5.881892663817252, 2.2331244810934994, 0.18465792519911645, 0.03860066156654108, 0.04121680586268345, 0.02537662993305393, 0.02634990633645606, 0.055526114038882725, 0.07551075860617623, 0.02345427018289845, 0.044551682358066884, 0.03408146676637473, 0.050432958504966194, 0.02989991947317556, 0.003868983420092733, 0.06687407486981924, 0.0144606517184706, 0.054219371053360166, 0.052276572077384884, 0.012907424731360329, 0.042180142275268034, 0.06623126581431397, 0.021288317455459508, 0.017430130129439697, 0.02346323532683234, 0.10525497262396159, 0.011447722715656123, 0.05514981165047615, 0.05376937866751706, 0.12083297985936366, 0.05446741883192332, 0.06415241728386571, 0.052638399234462174, 0.06199707870461768, 0.07719222200854171, 0.05054025677964092, 0.03792890204837726, 0.021139834293975465, 0.021468959072785034, 0.02472250958934667, 0.02063672520190237, 0.06661395737600904, 0.028312133302191095, 0.009002826841277702, 0.0962456483994761, 0.038230706216587175, 0.0721071755153037, 0.025170266913670688, 0.08432640048164515, 0.048894140674101735, 0.02969076406330832, 0.09245178947645812, 0.03086701929268818, 0.07153122295295039, 0.02265041603917076, 0.056643916759639985, 0.05139623363051684, 0.049938797319848696, 0.037910715121054844, 0.040273479666681065, 0.05724536472811334, 0.02502370663287659, 0.06728862036740588, 0.03357258137135256, 0.033228711315220406, 0.030209202574746265, 0.04819662144948398, 0.04347468531059642, 0.01928385606245889, 0.05603640903568557, 0.04348205124598838, 0.02419603673080283, 0.04017359712311337, 0.048096846158225695, 0.038252555044187654, 0.02799535403028131, 0.038160475106128765, 0.05888439068991331, 0.02996415019996705, 0.01978640016468783, 0.04090067585028949, 0.07090134546160698, 0.05958164561419718, 0.034774738033452345, 0.05746006852977219, 0.024688926209966024, 0.042942097155197013, 0.012818535549506065, 0.01842881766929021, 0.05110719248712544, 0.038627516778726737, 0.09057403136525424, 0.02967189148729367, 0.036901103167404095, 0.021797038141577955, 0.02919678865451246, 0.039663099113010594, 0.0415129256584952, 0.03222806642072336, 0.038132811671182994, 0.07943076156680623, 0.11906775240335735, 0.04539384281322841, 0.05112337992496548, 0.018811361759059855, 0.03782813084281741, 0.04551647050726799, 0.05562285179152124, 0.12546631792980817, 0.047708830285456874, 0.04430614734789537, 0.07005666457717458, 0.031653462173116785, 0.004214986552289057, 0.047748218696083755, 0.028742881559376276, 0.04885194455123237, 0.054624083812438676, 0.055191475342238144, 0.05097535641623601, 0.08643436801409529, 0.6538536531790611, 3.895843673136927, 11.902459744484196, 26.87738656997681, 38.416878023455226, 47.75042064728276, 45.10480550027663, 44.66171103139078, 33.32629657560779, 29.46602732904496, 26.20420978915307, 68.0106589101976, 49.44819504214872, 20.242891580827777, 16.438707324766344, 22.900542520707656, 19.57449224687392, 29.787591080511774, 34.33925259497858, 30.607293882677634, 31.53760752370281, 32.26079452422358, 38.2849451803392, 30.74252740029366, 28.353374465819332, 30.090333338706728, 33.425359956679806, 26.40057344590464, 27.378112423804502, 25.762913726991226, 24.762122938709876, 24.945256440870224, 21.073914343310943, 20.793435458214056, 23.60014627056737, 30.713184149034564, 33.358020705561486, 24.011000817821873, 23.930362770634314, 23.66315522501546, 34.024886392777965, 32.50579164874169, 34.64500919465096, 17.166406031577818, 16.4966554410996, 15.97701003474574, 24.174746044220466, 26.045712694045037, 27.73895871254706, 39.77455939016035, 41.812552329032656, 41.422150981041696, 33.19583069893622, 28.747770747830792, 18.765744624599336, 9.098524989620332, 3.2644621979805732, 0.4467034171665869, 0.05722100313212122, 0.015137777682544004, 0.04027426107636383, 0.007546324679072226, 0.08149070304728324, 0.09480747153922435, 0.024824835953392813, 0.010119919973095099, 0.018622454053031343, 0.05291734716945118, 0.025050188377199155, 0.019743112366526358, 0.05132866084515568, 0.03674172623563678, 0.045493445734703736, 0.05767642708134748, 0.05459947706831079, 0.009509293313678956, 0.026268551629337094, 0.0961425253039887, 0.033758254271120794, 0.04345120471571723, 0.012323394729455393, 0.023815128238751523, 0.012072025002130579, 0.08189158919717997, 0.0578310274549069, 0.03501823141930565, 0.016985590374397657, 0.02188502717012119, 0.010013919259842125, 0.0385280555835174, 0.06177734936617556, 0.03734437313171164, 0.022284566920490998, 0.038323261129159125, 0.029124747661332932, 0.03695941778020032, 0.02937131114454279, 0.09177178685222903, 0.08131117800310736, 0.07237031139553556, 0.03424805258550952, 0.035710709785381635, 0.013017860136084981, 0.06599937099963427, 0.08346904850294513, 0.05801194677910498, 0.051990101158979445, 0.00501061913617436, 0.046805382796352914, 0.006327276257047009, 0.04011651591187523, 0.04208681361389257, 0.15275016396997437, 0.078040212392807, 0.2198431944294322, 0.24227267071124048, 0.11414065791834747, 0.1757826433787423, 0.13831866093941275, 0.1163486305684332, 0.18451670455115457, 0.10173405550660626, 0.1776400388729188, 0.12163448402838362, 0.19175974411829827, 0.18803583668364635, 0.05975848168975884, 0.14026388075322876, 0.2158202062691412, 0.09253487937272557, 0.23692900825652385, 0.09482688420722563, 0.12157511987513113, 0.1402230482668646, 0.11022737354881341, 0.09900662161770368, 0.2630461560141656, 0.22900945176520657, 0.19012042321264747, 0.23750791025738563, 0.18731998880544018, 0.13940328822260903, 0.19319599043698082, 0.17237879215709626, 0.16169350504154162, 0.21583931250197275, 0.1938120477021702, 0.12649214796481595, 0.2186148337298824, 0.1101151723114233, 0.1883230124029421, 0.14320391170199842, 0.1700653291998371, 0.0998947243656843, 0.07862153523150953, 0.17145625375691922, 0.18891662329195008, 0.13728649535727117, 0.06712002739790948, 0.1644491999139709, 0.08133093541067454, 0.11789372265939752, 0.13677318580448627, 0.16228129366232505, 0.2060655014769685, 0.12257826604670095, 0.19311501494338437, 0.17312900673958564, 0.1237616267415785, 0.08977223608282306, 0.07003611809904538, 0.253999914012609, 0.11605570918970531, 0.1408109901052329, 0.18852738933938165, 0.15036281949329763, 0.5664650843508783, 3.5629447621683923, 13.778905945439494, 29.531674077433927, 47.092109649412095, 60.21451673200054, 59.16504344632549, 56.43872945539413, 50.25084926236061, 46.225230539998705, 33.886148237412975, 70.39150622583205, 72.9158809108119, 37.38210970355619, 30.932034753984023, 29.584808464973207, 33.21656434766708, 44.47753613994968, 37.24279888214604, 36.33470742933212, 32.205920565512876, 31.889822636881185, 38.4991850391511, 32.78294632511754, 35.195768802396714, 31.0119903087616, 29.911749785946263, 26.65385069385652, 29.198190243013446, 29.284882468561975, 23.793742695162376, 25.36925877294233, 22.934257253523796, 19.864435811196607, 20.955670572096302, 40.243674862769346, 40.20159567556074, 24.427709502558557, 29.075959382518647, 32.09057738704066, 36.9598900887274, 36.09400726133777, 41.25233196443127, 25.41430719437138, 25.79135875548086, 30.05949566441198, 38.43783524728591, 37.96672721062937, 41.26161621462914, 51.478970819903964, 51.32739082459481, 48.50057002036802, 37.74346982279132, 30.958714715896118, 17.859267227111324, 8.413482058432795, 2.680975804405828, 0.4639683117068583, 0.2027337084854803, 0.3252730572656278, 0.14259404442723722, 0.20714217676751076, 0.225478399304613, 0.15779618594434955, 0.08009482190133103, 0.12229548767209054, 0.11278020833889324, 0.10528221471054901, 0.11364813233094831, 0.09152035679548018, 0.18171838454661832, 0.12318562055307052, 0.155825991664202, 0.0964422878478804, 0.2090579788050344, 0.08246562653972257, 0.14925485717192774, 0.23259860433397755, 0.1124129840923894, 0.1563174370676279, 0.17997843033123404, 0.11411632696587233, 0.23580596932480413, 0.18404090266314246, 0.24933390229219393, 0.16312585963356882, 0.1902054283287256, 0.24853566931861065, 0.1501258225330422, 0.2051004758405109, 0.1533255113228675, 0.19019582158615514, 0.09012157217629495, 0.170304486528039, 0.08185666324871202, 0.10088956614415492, 0.17155380739319712, 0.15624056780530562, 0.1819914029610734, 0.19922700229912035, 0.15239102195107168, 0.18674286412856272, 0.11719032370996092, 0.1695728112733172, 0.1262187771499157, 0.16744628909134096, 0.24630672118115812, 0.10934838724713172, 0.15681858114417524, 0.08251690080449467, 0.09830179008384866, 0.1433639474693806], [0.07070334237669745, 0.1298648806949777, 0.062139279945122625, 0.05588386560820284, 0.040638106875121593, 0.022475895464360233, 0.030297691475660093, 0.02452700203585048, 0.020635302193583022, 0.025418598144765825, 0.055710764211272044, 0.026124850771720373, 0.02215830605447052, 0.05595796163223925, 0.009936310722672892, 0.05408937359348901, 0.042743730178523454, 0.05626726963166749, 0.03291138620566457, 0.009868481297857098, 0.0344062076070376, 0.0694115266143795, 0.038831441723290956, 0.06291050065849578, 0.026410749039402413, 0.010470398495184078, 0.03546423631750288, 0.037506630554074244, 0.06755567861781006, 0.030548255853054505, 0.07725592221944563, 0.04414855923143126, 0.04022230499333913, 0.04306536453265337, 0.04041830092788704, 0.019109749175127477, 0.14872901442070163, 0.03815691279728086, 0.014082442728742478, 0.03670624104298411, 0.038106764681757464, 0.012359087723457526, 0.055733386787676045, 0.05445983839191256, 0.10354014609249369, 0.022281477670936335, 0.03755083765774485, 0.02970399057132102, 0.0725082531871815, 0.012808940298254452, 0.016521739458004316, 0.0314856965785786, 0.058520648313025316, 0.07625063866256707, 0.034868771495718154, 0.03669579543413655, 0.1088643882183298, 0.03295514131745985, 0.06607510645182864, 0.02066780730421024, 0.05477164383797396, 0.02797247098398305, 0.02100065143989219, 0.03648742334917188, 0.06760028025676167, 0.043073661264873324, 0.18962914634856487, 1.1981807577033197, 6.174002357067601, 14.254638456529188, 27.046803543644568, 34.90675680098995, 42.913565558771936, 41.04227727459323, 39.90559401050691, 46.243575465294626, 67.99496942950834, 52.365622597356, 36.02685236161755, 24.689225689057384, 31.93152919892342, 28.02105361415494, 25.190920368317638, 24.40832514916697, 25.87858638455791, 19.358314737196892, 20.677070502311956, 33.74658246194163, 27.45132346307078, 28.7222243508985, 18.27093762736167, 26.907039688479518, 24.82910525414252, 17.145458613672567, 21.040805616686423, 13.208154016925445, 17.35565450883681, 27.566662719172818, 21.6444525026506, 55.030402445024066, 45.97972939091344, 17.968807258913596, 18.21069198269998, 20.42555243738236, 17.689430559835127, 18.990268938003048, 30.22400771417926, 26.97687945058269, 30.967816575880978, 39.30938197720436, 40.88152677782121, 40.94890917501142, 41.39339216293828, 29.525947416982344, 23.66676380557399, 12.283740601231976, 7.370242399554099, 2.9458904795108305, 0.7104775405699207, 0.10298725277666124, 0.0196669306681161, 0.03712545584646925, 0.06586416414187801, 0.03419211667571818, 0.05157272496651258, 0.058636159050248327, 0.03261077330417691, 0.04071342097895761, 0.011321458976805933, 0.03250000848164482, 0.02546865432973831, 0.016817328737928502, 0.021283797536706252, 0.03695228167118565, 0.08357053983115381, 0.017395621698890484, 0.024113153678274924, 0.04933130108721314, 0.009962761823478486, 0.1928958678317647, 0.03395192512881852, 0.056881166528910405, 0.028092557181333824, 0.039073862586050265, 0.03355274352455332, 0.17057653967170947, 0.007586796625307011, 0.04268330499349583, 0.03727031924251107, 0.07710080473653733, 0.02101469574676406, 0.03849855736799298, 0.0367252093799893, 0.042480781989833044, 0.022999822995775653, 0.02353499095226007, 0.008377051750768819, 0.02520239089555558, 0.04154165778609534, 0.04570546439818798, 0.03350659055755504, 0.04679040577743323, 0.07080251245849556, 0.018407482120599, 0.05051490693022648, 0.03872050836141552, 0.05777897178045204, 0.03620503184896323, 0.06751820159655425, 0.06723281086212204, 0.08175644362645765, 0.04832147079850397, 0.0051157402847292685, 0.05149669840090698, 0.025086836108276923, 0.02645515915637295, 0.07137645787048726, 0.1298100594431162, 0.028060555773516817, 0.012768952423826823, 0.03811529890123395, 0.0629614225228227, 0.03240515913573965, 0.05538653664951844, 0.023731078817358902, 0.0603468104025289, 0.02230005913353976, 0.07323284212860369, 0.04292749551936023, 0.034483728044095545, 0.04176625561329626, 0.08764503974347346, 0.020571647947954557, 0.0481899296714654, 0.0875021720064744, 0.01913349981599998, 0.01683207018481147, 0.039827275585623524, 0.037270978078125946, 0.026637819415378957, 0.14350519876085943, 0.013805247219880263, 0.039887344539766355, 0.07929703325874383, 0.0279842744836764, 0.04305083567516939, 0.07439005624262557, 0.04735390941101698, 0.06029564722050583, 0.019832013039699486, 0.04751855319726372, 0.018650270705561967, 0.07257389926141308, 0.013667532381781889, 0.07043361814031679, 0.12481308241765346, 0.05115393534182541, 0.027175289466075843, 0.03741567293482442, 0.0997221400781024, 0.024988958799851038, 0.04330002875517934, 0.08866091063546558, 0.008192475314342208, 0.05325609975824914, 0.024901866094179215, 0.055104501380194584, 0.018426649640464497, 0.009601890361086737, 0.021239898783425172, 0.06564196033944046, 0.05175591957184577, 0.056930169342987, 0.029724734317090724, 0.028757925610989336, 0.0094587592813637, 0.06589148283725785, 0.018883465954493132, 0.012928237425043218, 0.06008437932318738, 0.13033193385889455, 0.05102471929163702, 0.3814213266295772, 2.3463030015268633, 8.988120075195067, 19.75895151015251, 35.793683144354056, 43.58082348300565, 49.64157573638424, 46.59943642154817, 39.55158049060453, 52.584494775341405, 71.76282175125615, 49.06492064076085, 30.489544330104707, 15.555109112493454, 23.278447197329616, 23.884170978300034, 26.229240394407704, 23.516727262927642, 19.073833073339156, 18.14655730801244, 24.91454428242099, 28.423477026724047, 35.732423567002826, 27.368184904898367, 21.596868268905148, 28.586300496132147, 32.61995811616221, 26.53306522677022, 27.773104906082157, 22.147523933841338, 21.341490591725996, 27.111838402286654, 21.086399247569425, 58.856482351979906, 49.276073594247144, 20.541444747678696, 21.042992338057488, 21.018924674680157, 21.07514988991522, 21.743494310686668, 31.325207256501724, 22.84492919521947, 26.05666002919597, 37.65908395090411, 41.62286650749945, 42.671653378394346, 43.99022086974114, 36.868828342806914, 30.906429521499145, 20.06736747680172, 12.437653426201114, 5.967932795324634, 1.9369599151034511, 0.4662708042850418, 0.11594374543957173, 0.07380094995061237, 0.06568774175379546, 0.008717344176294583, 0.04886362739207764, 0.06987422073800718, 0.03731959018736117, 0.05493869697074256, 0.06769208823360744, 0.04371372389517004, 0.021556875322975462, 0.048698991266710144, 0.043107671738271756, 0.02288122492421779, 0.06573551499675359, 0.01692818549101151, 0.05957282411174909, 0.04525927563888892, 0.07196547989282878, 0.056854154268700274, 0.06088520167395473, 0.06826525223591635, 0.019901612127620368, 0.03837300321808265, 0.014851593089500263, 0.005770374386150751, 0.04066159130044041, 0.04465849033647007, 0.08219947227306905, 0.03882890597226159, 0.03146457553450619, 0.07580738785045762, 0.006828245090981645, 0.023135395660515756, 0.05168913585704662, 0.08513965643942357, 0.031059608051192858, 0.018056520005507816, 0.03887500914354478, 0.0068680131939359975, 0.035844733037294886, 0.07811948717121156, 0.06498075751287323, 0.013730650365863357, 0.026728765543309913, 0.03708818566895301, 0.03284510427845582, 0.03255062391080203, 0.04268931112282219, 0.03209809768914936, 0.03692752170947291, 0.08470376773226647, 0.055344738892369696, 0.010829261849604307, 0.030145429585489537, 0.026650674370748383, 0.14840681316150775, 0.24605999490426433, 0.23743559155733357, 0.09545300020686082, 0.11302594636236468, 0.14976867234274266, 0.20127052651538005, 0.11347645202711706, 0.07406771708760532, 0.15376179839574522, 0.13779913075268269, 0.19853687965341155, 0.11170030015731051, 0.09517834236424777, 0.16039225873687576, 0.22811482960899032, 0.0851422381557284, 0.20897009319836096, 0.13724710311620467, 0.1437368331056449, 0.11550164375934871, 0.09699986962180945, 0.159842069711416, 0.17292211703475446, 0.22104394532019095, 0.14439471877149998, 0.12894673963948605, 0.22592608576580403, 0.2277508305926477, 0.08884404395376483, 0.2114743580140414, 0.25453248301581033, 0.15455027140917318, 0.11691179712333026, 0.11433412576274526, 0.08027620087828367, 0.2240101917977295, 0.16566158001942022, 0.14921950987510144, 0.14156655198143375, 0.07588503086158345, 0.1430687125051214, 0.10869251639251748, 0.15634231960340855, 0.23082480435409855, 0.18744139841968016, 0.1794164895170158, 0.08929133971011446, 0.2056099089883989, 0.09267605405541197, 0.1597519011627282, 0.09653447886868831, 0.16505198853631176, 0.22871564172448652, 0.24829557736314115, 0.16890948638319972, 0.19094289520815497, 0.10347166549294226, 0.20543919395535223, 0.12033355181976674, 0.18393018763632546, 0.06120135466898642, 0.10169261014990269, 0.094451968437962, 0.13624873733328235, 0.1980638969689608, 0.3627553798498646, 2.1589213273217602, 9.842415240503128, 22.65206233147652, 44.32150033212478, 53.68218967991491, 60.65040972925002, 57.21525284551806, 53.85060448800364, 57.78316497802735, 78.45689558213758, 63.773573444735625, 46.4323159956163, 34.23182672069919, 43.899814159639426, 38.60375935031522, 39.436721724848596, 35.30015483979256, 35.882022765374955, 26.50365529521819, 32.77472699842146, 45.70716781000937, 41.934294854441, 39.42604111086938, 27.280478746660297, 39.29735206788586, 35.82771362796907, 29.848450576105428, 32.26869221656553, 21.52719912990447, 26.818925603743526, 39.41104588970062, 29.827999338026974, 66.66971037464758, 55.660903838373, 27.43925236886548, 28.622080356844013, 30.20748276864329, 26.927663510845555, 28.629530898986328, 41.85308610239337, 36.697055985850675, 40.50796416498, 53.4074943296371, 54.52539728533838, 55.64758739163799, 51.96104580356229, 41.2624869808074, 32.59086197422397, 19.638277830616122, 11.056206418621926, 4.919021389176769, 1.3507040830389148, 0.4057105732781272, 0.17366942048313158, 0.1440774204750215, 0.137695019403773, 0.0836270388155695, 0.14613643498911014, 0.25912485836494353, 0.11511163605797677, 0.17684070273272454, 0.1657270652151877, 0.1325880015088666, 0.1119657879274699, 0.08244189313582836, 0.14435600068780685, 0.13866689386627368, 0.14308431005525973, 0.0837690178905764, 0.11955893733688902, 0.15198638963122524, 0.12304044689141935, 0.27895345082206113, 0.1841011478175079, 0.14284069409533856, 0.1591314771963704, 0.11795158528031842, 0.09075616110837267, 0.29198975452492315, 0.14056625565694225, 0.10814696985987887, 0.2876684670486758, 0.08902081108141331, 0.09861955569396097, 0.26905660607641746, 0.13675332880548893, 0.13967561715793225, 0.12697246211070207, 0.16532540531648746, 0.12996376732424383, 0.15029462234627816, 0.12906733720052627, 0.16084345388076, 0.09076628112985242, 0.2035056186779853, 0.16897610538909513, 0.18184514145456976, 0.15929963349575, 0.27643495209274754, 0.12007788529679661, 0.1187491900618038, 0.153406456172947, 0.09316045144993453, 0.17062354682674333, 0.14755965781307992, 0.22874764887796295, 0.14141869701204762, 0.12744736767584278, 0.12389149396650254], [0.03853843224445178, 0.01809231354855001, 0.026621390659842762, 0.02533596024037369, 0.021159792799622785, 0.06067209133517839, 0.018217415706585013, 0.04016788976807748, 0.03601948152326288, 0.02184069366194308, 0.08389665579964077, 0.045484746806323535, 0.013302383275942938, 0.028973190572052717, 0.04299550114439861, 0.061641246185547886, 0.04579732217074883, 0.020424719944956805, 0.0169135972617134, 0.07530556961653695, 0.021155642518292994, 0.03331449784098133, 0.05796865515050389, 0.10267834314295363, 0.010967614455899645, 0.03359581681809599, 0.02328517542581164, 0.10017653746951012, 0.019487823141858946, 0.03722896198591879, 0.04952196121936844, 0.06171089506918385, 0.04703928093095461, 0.037917517981822454, 0.035427414301422336, 0.025711408440744685, 0.02764110156755534, 0.025982245419835372, 0.10322955106535267, 0.059579550363724275, 0.07673966322815226, 0.03450332074275902, 0.10331420378098566, 0.049802311095258886, 0.09198372507648123, 0.02975902441258152, 0.02711942058897788, 0.03869315902251871, 0.010239558966620075, 0.01303327669795122, 0.00935660528710052, 0.035186586901545525, 0.010572219241200196, 0.06876047445280899, 0.0449532273435785, 0.008432347019533477, 0.0024500001745764166, 0.020806928871259577, 0.038394633710624716, 0.03498540838218985, 0.021848764398225376, 0.05455626204850213, 0.07781777110311293, 0.04586746135065633, 0.0212522711034023, 0.06585754514221223, 0.015329840713210646, 0.046308383255475954, 0.06383383579011406, 0.513989930792201, 2.467752084616692, 9.279706132027412, 21.198781036561538, 36.29134954944734, 42.08552575880482, 44.75193731246456, 54.62333102380076, 53.66226403943954, 42.956138964622255, 49.33041411061441, 44.256843982204316, 50.37379987778203, 33.83154884461434, 31.576725321431315, 43.7094929141383, 31.895768950062415, 31.694570972073464, 38.49909482463714, 19.619693640739687, 29.07271754357123, 25.97753013333967, 27.87061110619576, 22.769782466273156, 20.663797201648837, 27.379575467878773, 20.74535700582689, 20.25667871198347, 30.32366337314729, 46.45558349547848, 85.32224362896335, 38.49556861385223, 22.623015219165435, 26.20007168862128, 24.004432808968332, 40.838749408721924, 34.066086969067975, 45.557945159173784, 45.36674530275407, 46.54473504712505, 35.708877578858406, 32.662484453570464, 21.219853970312304, 12.435105846774194, 6.456156094228068, 2.249243461316632, 0.5789246770643419, 0.07328502037712643, 0.027147637522448937, 0.01240428595338017, 0.11644609227416017, 0.09939413953332171, 0.07782150195130418, 0.03765373475729458, 0.06501860225633269, 0.03750217958323417, 0.024450856726616624, 0.03268902535520254, 0.03690765321915669, 0.01573262484593978, 0.04398579619103863, 0.020135048694247683, 0.01874052926958088, 0.03224482076362737, 0.006447364848422548, 0.07676103708123969, 0.06308894934913804, 0.05908837309107185, 0.01929808806087221, 0.03872705841316812, 0.024411384046318072, 0.050933746350628716, 0.014129403918500871, 0.09133703195519986, 0.013957073397543884, 0.025467825039560278, 0.02740633009271997, 0.04513622276605137, 0.03507586038340965, 0.04673473033753615, 0.08680882413060435, 0.0259808185810764, 0.0034312788451526075, 0.0172966527151725, 0.035833896723605936, 0.11995380969658015, 0.061863794727551366, 0.08633986340775605, 0.06344516874260961, 0.015854826403571474, 0.08599729187065557, 0.11153611219337872, 0.06920933302852415, 0.06283966050813757, 0.09194011169095194, 0.03740006389336721, 0.03340986046579576, 0.020847841796855775, 0.0032379680487792943, 0.07040997666697349, 0.07078709876945904, 0.054120626150360035, 0.02533669376956119, 0.0428231313614355, 0.09162811472290948, 0.06686438385757708, 0.10767528186402014, 0.022444323065780827, 0.005378508921562424, 0.041269731046932365, 0.049788839439110416, 0.012279464375047434, 0.0578971408427723, 0.01781266464311029, 0.04035095030802392, 0.10602910447144702, 0.019147027013522964, 0.053839039042471885, 0.016507811979540897, 0.02281547734333623, 0.05511243805109013, 0.06417869793010816, 0.08078997008382313, 0.03821798149616488, 0.033092719217341755, 0.008407092931109571, 0.06945013744576324, 0.021674506208528916, 0.01525143352938035, 0.06455983816375656, 0.10500638475341183, 0.04997032566837246, 0.048442535673178015, 0.0852023913795429, 0.05403341087062032, 0.12775971704433042, 0.03253405342899984, 0.03040208627710179, 0.023381357764705055, 0.07551232142554176, 0.042257911690901366, 0.016693021396114942, 0.011371974814532986, 0.06619165906862867, 0.029322229806453954, 0.0701413402754453, 0.037447852458083825, 0.035096165543842706, 0.052682671455606345, 0.05228625542874779, 0.04590360537892388, 0.04809576214381284, 0.02973775015092425, 0.03850978055608369, 0.02449624552091043, 0.029437393888891227, 0.051834780662771196, 0.014953396598538084, 0.012057214607334426, 0.05399177399193568, 0.030858105859689178, 0.05235819874571697, 0.06424646606789002, 0.08427937034397356, 0.10617989355758314, 0.024880429038838036, 0.02506481491089348, 0.04112401346285497, 0.011131204871250498, 0.02816885953859216, 0.04879372186898705, 0.03792889438749802, 0.0498335789738884, 0.0637462719403688, 0.022368470785178007, 0.06760171284118006, 0.8484928153695599, 4.234459438631612, 13.312031126791432, 25.622551710374896, 43.056065267132176, 48.686815923260106, 50.27474041908018, 62.491193740598625, 60.50848660930511, 47.14649723422143, 47.24352882754418, 44.35967283864176, 46.46300854221467, 32.72909218265165, 25.703862444047008, 35.414103615668516, 23.43194130928286, 27.212200087885705, 36.552238156718595, 22.872219085693363, 27.672017582001228, 19.893798674306563, 28.386526338515747, 23.384757157294985, 19.15537326566635, 22.048729235126128, 14.452269038846417, 20.813115950553648, 28.67705825836428, 35.938575498519405, 85.3652249613116, 41.77200286619125, 17.24426704068338, 21.31014300930885, 23.484822703946023, 34.873322517641135, 33.15020568909184, 45.40225059755387, 46.86285495758057, 49.430069769582445, 42.64233366135628, 38.58647346496582, 29.01567843652541, 20.346685340327603, 11.543307919656078, 4.805553593943197, 1.2159765511751175, 0.23762005020774182, 0.12361502049550896, 0.05757976976794101, 0.06260172892061454, 0.044147819956584324, 0.06863101325448483, 0.06420124389771974, 0.06710917193202243, 0.04837135078325387, 0.06841485388576984, 0.033118858137318206, 0.05712701946557049, 0.030521119103556683, 0.022904100309636806, 0.07933209710303815, 0.007973290855936226, 0.04396771268558599, 0.037528831782119895, 0.06523198072588252, 0.008336139782782524, 0.07793725783666296, 0.06021431932646421, 0.028468940008972442, 0.046664736714334264, 0.008573488185873196, 0.01771698983746671, 0.10244470164780656, 0.013737634214903078, 0.011092910051135527, 0.11442196540414326, 0.02228096822246669, 0.060266106870145573, 0.04178175740244408, 0.02805802002248745, 0.02739617176684401, 0.03455361058454841, 0.03536774371300013, 0.018572286785309835, 0.04950547883767755, 0.0343629849263497, 0.040090128013323394, 0.07651167546188639, 0.06635987665504217, 0.022241794316458608, 0.07418642241147257, 0.05311850270616913, 0.06134617209975278, 0.062195472494368596, 0.0454551030340935, 0.03726833507478718, 0.11046633169415498, 0.09458495364073785, 0.08926544593827379, 0.0853811503357945, 0.050823249658870126, 0.021773138113560218, 0.04891930666241435, 0.03219353117709679, 0.012843041744593893, 0.0489664210697576, 0.10820456435002627, 0.11442773404621309, 0.21362268305834264, 0.15995895940690272, 0.15761940349494258, 0.2654314167316883, 0.10819620633077238, 0.15473460748551354, 0.1527916552919534, 0.08778259849115726, 0.14142897791199147, 0.14537013256021086, 0.0872774018094905, 0.12340260729674371, 0.20586425017926002, 0.16826915945256912, 0.10270972210433214, 0.09880793671454154, 0.16058796355801244, 0.1301915252641324, 0.08998169984307983, 0.10309292694493648, 0.1422102343771727, 0.19498819184880103, 0.16069166121944306, 0.14694111842301585, 0.2682423771869752, 0.13613299676968207, 0.19329000474704852, 0.15690657400315808, 0.12388069978764943, 0.1337939005104765, 0.14513600076879227, 0.19519270668106695, 0.14116176644400244, 0.08170638744148516, 0.13840735859928593, 0.14285742545560484, 0.25620724314883836, 0.16807259661295723, 0.13310365529069978, 0.16143878080671833, 0.13683845649563497, 0.10801422214435955, 0.2178567744070484, 0.08788385999298866, 0.14417886583795472, 0.08087568000079164, 0.13513063200779502, 0.21446773932585794, 0.16031719744205475, 0.15082765100223405, 0.12087915963943928, 0.1675081277085889, 0.09851193566235805, 0.10681255194809168, 0.18558717452951018, 0.18505368622079973, 0.15239063890710955, 0.17476599873794665, 0.09603576329086097, 0.15373763598261342, 0.18611206733171018, 0.12272043664368892, 0.1276192395016551, 0.1797536907777671, 0.12839096583305828, 0.1708830514502141, 0.17481830722141653, 0.8636186392076555, 4.525464004085911, 13.863903707073582, 30.78680507598385, 50.467011082556944, 58.431732808389974, 60.14018389486498, 67.34122014814808, 68.20470640736242, 59.36613159794962, 62.43171491930562, 59.258737102631606, 63.43033075332642, 45.47551655000257, 41.154857143279045, 56.41917644008514, 43.54470629845896, 44.270768396316036, 50.32271492865778, 30.836934927971136, 40.817097925370746, 37.64319050696589, 40.14383485240322, 34.78122918836532, 32.59376845052166, 38.32193705343431, 30.03285492620161, 31.754893102953513, 40.4258297335717, 55.64168814689883, 90.67965999726327, 44.753376822317804, 31.591249858179403, 34.70831232686197, 35.91877537388956, 51.68832340548116, 46.73593882591494, 57.71144836179672, 59.93251792846188, 59.45171379273938, 48.09790734321841, 42.50455648668351, 30.243529350526874, 19.72036127121218, 10.637359061548787, 4.751962740575114, 1.7003125360896512, 0.23932321688100217, 0.26797283681169637, 0.144874366420892, 0.30108533258880343, 0.1425023896679763, 0.21408350026655584, 0.23290461049445216, 0.1431432375383954, 0.16849164670753866, 0.159871349591882, 0.09648204781115056, 0.22485828177342493, 0.16927633524662064, 0.17235070737379213, 0.1080879657679508, 0.15715227372223334, 0.13520354825642802, 0.10473569524624657, 0.16289517523780947, 0.08804622466766066, 0.2034587647405363, 0.08954670745879413, 0.12148665204163521, 0.1254494793172325, 0.14018917185885293, 0.12460486738071327, 0.1587630961571009, 0.11467279791231118, 0.08849286158839542, 0.17926129542531508, 0.11428025445990986, 0.17655755663591047, 0.11539907224716679, 0.157241522965412, 0.10027027598792508, 0.12078940477823058, 0.17056806673926694, 0.15449376476387824, 0.21701738719017277, 0.1159817893658915, 0.17187914961288053, 0.10640717652295867, 0.14097318624056157, 0.11948692507200664, 0.22769614723661255, 0.15459551656198117, 0.18102544269734816, 0.22658820023700116, 0.12513846294173311, 0.18069452335757596, 0.15743761083051083, 0.20943895432977908, 0.2903540342325165, 0.18116470216022384, 0.12812684936028335, 0.13322131107411078, 0.14998323824857512, 0.22892665298235035, 0.09945029377817147, 0.14730208373117834], [0.04803278588599736, 0.035193163766375476, 0.01511938199626222, 0.03502867702815322, 0.02481668860831809, 0.09574749972671272, 0.0779389662127341, 0.04467454753936299, 0.08488285610632551, 0.009751652889404326, 0.03764760222346072, 0.056001598000406265, 0.06310561176149115, 0.06257977667114427, 0.14755044943623005, 0.039733736250068874, 0.0311374866343554, 0.08050686229140529, 0.039825406331088276, 0.030428181147022598, 0.04453561749429472, 0.04068581117016654, 0.06316955329009122, 0.04441757483648197, 0.009717718067188418, 0.07515859564826374, 0.02089649987136645, 0.02733602811912856, 0.04168182889360093, 0.04204933276219715, 0.030008799719413923, 0.03724977659482149, 0.03558433209095271, 0.059034930797474044, 0.024753557217697945, 0.010225237910485557, 0.01271681726774982, 0.026551607710820053, 0.0975773313773736, 0.038430092090200034, 0.04446355160325766, 0.08126348902982089, 0.03343860791515439, 0.03266535323834227, 0.05223870052084808, 0.022123698032491153, 0.017967694025907307, 0.03267674496577632, 0.06338588119814954, 0.04359889880663926, 0.029402697766800562, 0.07398015323786006, 0.02176885951250311, 0.009234876788762069, 0.027541144330415036, 0.021032633695511088, 0.02403297300089992, 0.014533774810843171, 0.06907661595652181, 0.03949199337512255, 0.04566131092067208, 0.02389441067803531, 0.013505354441041428, 0.07142971630298323, 0.07792011278891757, 0.06781765770527624, 0.027456008979389747, 0.053505384768810005, 0.019568208747753696, 0.029113524473242225, 0.04127227445884098, 0.06389702272210872, 0.8947344953494688, 4.246312841292351, 14.314383018401362, 23.282938311176917, 29.824445670650853, 38.23598615584835, 46.38142716500067, 48.112216149607015, 50.205910667296386, 48.935070576206336, 47.96251104724023, 50.015867910077496, 52.15768990978118, 47.64500694890177, 52.99441775967998, 55.95038652420045, 47.15007443581858, 41.16046613262546, 37.96798236908452, 36.21126259526899, 44.46036400333528, 41.10343487031999, 46.90915853746476, 43.723464396692094, 34.969879504173036, 33.26027524086737, 51.59024061695222, 75.81484979198825, 42.69892169583229, 49.945677095843905, 46.76310123935823, 51.45090233895087, 47.20259497242589, 40.35092030802081, 36.44354927924372, 27.746401409949026, 18.808557295030166, 10.551045344721887, 5.100159385511953, 1.5650896824175313, 0.44442366207799605, 0.04583843044876572, 0.1328122048007865, 0.08041529946269528, 0.02619998101445456, 0.028852725161179423, 0.09464598020478603, 0.07539640466171889, 0.07528552109555853, 0.03801656165911305, 0.08485929890265388, 0.03623883930906173, 0.02246908111227376, 0.013846296126083022, 0.06105505485808658, 0.12004963963502839, 0.010977728731719958, 0.05275857161670443, 0.06183911520507067, 0.07562824585024389, 0.08885173547652461, 0.031600906626291336, 0.08841784625884988, 0.027334269947342338, 0.027450621466062246, 0.07286363371437596, 0.05939964610602587, 0.05178515731747593, 0.02994019654579461, 0.026787911361503988, 0.028933583826367414, 0.02300047225529148, 0.05049893399700523, 0.039373184629385514, 0.03341248431693643, 0.006349756628380067, 0.07575745423955303, 0.015709680512607578, 0.027540811082167972, 0.029120965102206797, 0.07929832028645663, 0.03393678340099512, 0.05050970136278099, 0.005562849785952319, 0.0439939703491907, 0.035173984755191116, 0.022325014447673194, 0.046104102080026944, 0.049998019746835196, 0.05243829323820049, 0.08877946274174799, 0.046578846766703555, 0.044732574869187615, 0.05687220330019632, 0.013958464804736358, 0.06946350568004193, 0.03635065750248971, 0.00798587337128758, 0.03464873572210631, 0.10663848911081591, 0.041983364931037354, 0.021983230065914895, 0.016154258572045836, 0.02916977447908252, 0.0357599385953959, 0.011878692180729442, 0.04952203782816087, 0.03453877529189472, 0.07823872875662581, 0.03861474226258936, 0.034097271160252636, 0.08391354037749191, 0.06607360491949706, 0.027878602230620962, 0.006723245080079764, 0.05573626344783172, 0.06559329843449016, 0.06475679170820983, 0.05533843398875287, 0.010419440241680752, 0.022031229304810687, 0.04359473894921042, 0.04856499482787425, 0.06672866372091156, 0.06903644996665179, 0.035137833066044316, 0.051274257111212904, 0.11884225442284539, 0.006331752604549571, 0.03264832693422514, 0.07159454778077141, 0.03906621319812633, 0.00463509145418122, 0.015561615826652176, 0.03016275274867733, 0.08169965352863073, 0.010863658239794596, 0.05769633004562028, 0.05684086264321401, 0.02513053567869769, 0.01768060449150301, 0.07822873897009319, 0.03769216555801611, 0.032518528657214295, 0.015418722234185667, 0.04132197058248905, 0.06230803762352275, 0.037928599443647175, 0.06657520864879893, 0.04410335238301947, 0.03158611921413291, 0.02567503650131966, 0.009105851302944846, 0.012254920833173298, 0.044062673114240176, 0.03977691679592094, 0.07408954293256806, 0.0495504635205913, 0.02599613076346296, 0.021972931928992755, 0.03178552998560331, 0.019756846407788898, 0.023656902354090445, 0.07194658050373678, 0.06349343994271851, 0.05788800141383564, 0.027323213383375157, 0.025392240889730956, 0.033666147519984556, 0.02608944218786013, 0.030294437517201712, 0.03451557048866826, 0.03699743489344274, 0.010557079428596603, 0.028267303752082012, 0.23755398278515186, 1.4848656904312874, 6.287597139035502, 19.087186782590805, 29.96957728939672, 37.60877955344416, 44.83718218341951, 52.82537537236368, 56.73577839328397, 57.48962656144173, 57.75411198216101, 51.77490580466486, 53.6599459186677, 57.958267427259884, 48.934733252371515, 53.02411794662476, 57.852512482673895, 45.91664983380226, 42.32974429284373, 39.49600442763298, 38.045092244302076, 41.737980227316584, 41.02706240069482, 40.40704550281648, 36.788419754274436, 34.39946489949381, 33.21499932196833, 52.82390448354906, 81.71938188614385, 41.82322117590135, 43.0666321323764, 47.57757748326948, 53.49386099846133, 54.68961515734273, 46.903216146653705, 45.78331670453472, 35.541204098732244, 25.638186277881747, 15.24498397304166, 8.68905209725903, 2.852323809939046, 0.7919041680232172, 0.09140483073649869, 0.17158049789647903, 0.1309255753914195, 0.07532998483868376, 0.01370122588630165, 0.04762701592558334, 0.02682649154937075, 0.027095788691733635, 0.04159467873133479, 0.018561050190680453, 0.04276917961936805, 0.04691744613791666, 0.04059679558380477, 0.014378462933124074, 0.0320658894375928, 0.057437756218977516, 0.03655504976068774, 0.027197645826926155, 0.023602967849001292, 0.09473309206265597, 0.052506758515993436, 0.03038083116764263, 0.05311161174529022, 0.0640440273338989, 0.06028094599323888, 0.041685540589594075, 0.0216455634067496, 0.04541845721823554, 0.008026746556072707, 0.053832791595449375, 0.03198173276389078, 0.014688413488798806, 0.017601216715129635, 0.03856727545480094, 0.04696186774620607, 0.032641593021370714, 0.029915254638199846, 0.07004611554645723, 0.009353086070698357, 0.05378033372483427, 0.06216993112297309, 0.04378055740568427, 0.042567706156161525, 0.05350226679095819, 0.02634785896647842, 0.025425240127069336, 0.016298719771927404, 0.07463711959820601, 0.038707687880002686, 0.0372168309836378, 0.03518714231529063, 0.03174737880697414, 0.06444833406637754, 0.10857187286620179, 0.020587414037436247, 0.045987197062781746, 0.024329307301330472, 0.021985823273538582, 0.058618041070839094, 0.06820136050303137, 0.05750470081224077, 0.09268520114522788, 0.024986469014097127, 0.18861757320982797, 0.10194404020665154, 0.11500753236994629, 0.19070995851389824, 0.13865624524412618, 0.19412044405696854, 0.14389702209061192, 0.2478701687387882, 0.27927977363428763, 0.11519967488223508, 0.10950950319848715, 0.14527738995609746, 0.14969338122154438, 0.16665217767079032, 0.24906235476655347, 0.09866877684309598, 0.09748448918183004, 0.23144810881105163, 0.16396463398010502, 0.18371503950367052, 0.12722334824502468, 0.09852893515339783, 0.15274133863708667, 0.18839493273727356, 0.15967031279879232, 0.20384406100117392, 0.2699974233344678, 0.20542811632396715, 0.1418392026736852, 0.11127172758983028, 0.09718946872218963, 0.10837116549091955, 0.10927613749499283, 0.2114927747677411, 0.10446928050969878, 0.08645759579995949, 0.0778913232047231, 0.10713252389142591, 0.11328187335522906, 0.09563862331091397, 0.13191454893639012, 0.2456921807700588, 0.2177893739914702, 0.22222430295040532, 0.15605934204593783, 0.13047479393501438, 0.14060121990980642, 0.06189418926594719, 0.14290746631881884, 0.0968803599056217, 0.09649557692389335, 0.19949738537111592, 0.19795734946045185, 0.1056273603030751, 0.09900731875771478, 0.0899320650064657, 0.12425407572018525, 0.09006825245676503, 0.12867830243081818, 0.1623853590459593, 0.1806703303009272, 0.18644395194226698, 0.1422593099696021, 0.1049530803556404, 0.10213208414854542, 0.1252691652024946, 0.12441064110927044, 0.1437366032792676, 0.08795576500556163, 0.15604377513931644, 0.22108067157528094, 0.2583499144642584, 1.720494478940964, 6.468088434588525, 20.282799736146007, 33.43929221553187, 42.7803030321675, 51.433063399407175, 59.95091384457004, 63.19791463113601, 66.89233626088789, 66.86538173306373, 65.26018311900478, 67.0688586081228, 70.17983944185319, 63.25598139916698, 65.19360873007005, 69.87593420090215, 59.73247704967376, 55.21015290291079, 51.586133895381806, 50.73119448077295, 57.472878040805945, 54.25138050510038, 59.72568350453531, 55.34103455082063, 47.23397393380442, 45.31568781022103, 63.54944921308949, 82.2524319925616, 53.2083438288781, 62.771435322300086, 62.76315127649615, 67.37026137690391, 64.18756000457272, 55.89898386309224, 50.0044342010252, 36.903129469963815, 27.18319416046143, 15.609313326497233, 7.959751592528436, 2.824716452629336, 0.9793182630692759, 0.1965747599399859, 0.22468928277732866, 0.1428827063571061, 0.15254503626736904, 0.1529397554094753, 0.16829519112023617, 0.11325369664137402, 0.13130702589067722, 0.12961429333494556, 0.17810246486577297, 0.2168431787961914, 0.1106084026997128, 0.23648470790395815, 0.19413665447744632, 0.14198183292342773, 0.12232655253742011, 0.11427379633870818, 0.16277934274365827, 0.17685679057913442, 0.2111360995519546, 0.17102526801247753, 0.13573035627843874, 0.1264653272265869, 0.1294983076232095, 0.09740621797860631, 0.15554460756961377, 0.1237221425699611, 0.16259226407254898, 0.1533942906967094, 0.1837227157046718, 0.13012856815851506, 0.1941727831839554, 0.10157398143482786, 0.17113199938208828, 0.18353660230434712, 0.1938134113386754, 0.08385521810381644, 0.1540206595053596, 0.10221381806918692, 0.1293558459128103, 0.10612626740288351, 0.15018890221272746, 0.10059505130254454, 0.17058286755796404, 0.2863240746721145, 0.152318841146846, 0.17301248476630257, 0.19278228763611088, 0.12057863866850255, 0.19535735429775333, 0.16804763746838416, 0.13644847177690075, 0.15801478147266373, 0.22258488521460565, 0.1782588540546356, 0.1727566267213514, 0.11216380633413793, 0.09500429484873049, 0.1881278591651109, 0.1331462344575313, 0.12502297518714783, 0.21029291253897453, 0.08000958695887558], [0.01912726960595577, 0.01000551910575239, 0.027124051590480154, 0.04102950885651573, 0.03575259564264167, 0.05109482016714831, 0.0021644092996739935, 0.03611449557807177, 0.016303931085032322, 0.03828455070634523, 0.03743290225224149, 0.039522135104503364, 0.04439725052385081, 0.027481171137262738, 0.08251482470621986, 0.04659425662530046, 0.034603337351713455, 0.045323929629258575, 0.07312659339438524, 0.012654274807221467, 0.016875239239344676, 0.016319153252087774, 0.06842699637936969, 0.035923969511303215, 0.06798306374900764, 0.006899811109648117, 0.11271599484908004, 0.030558297350522012, 0.05084167790388869, 0.07958435453474522, 0.03156448872159085, 0.04814460024898572, 0.08244932418869388, 0.031078723860123468, 0.024187462291710322, 0.035771491201294046, 0.01594124303665012, 0.012848482884076095, 0.020496385555053433, 0.061408033699638424, 0.05570534030876814, 0.027095618237170483, 0.01750778846232401, 0.034662670861448974, 0.06096048896471339, 0.039667799062426054, 0.08125314684284311, 0.016563027766683412, 0.08154274339997962, 0.05398582148876402, 0.02315677142882299, 0.05511560582465703, 0.04223956005467523, 0.0390850896045806, 0.08272977365601449, 0.005309744390674056, 0.017429570885254972, 0.08325242182059635, 0.05892566367683392, 0.007774346919294688, 0.019389815598485932, 0.13159073889255524, 0.04073952542497747, 0.027356833151932207, 0.020531629430009954, 0.020945320739561034, 0.03983271097944629, 0.017291495028222283, 0.025602643107694965, 0.047166068482423024, 0.052819353032616846, 0.007276848463657042, 0.02668076438919431, 0.01827638723977631, 0.2901846062271826, 1.3284263687749065, 3.288363650921853, 7.756752756334121, 10.465678880291602, 14.95707513824586, 15.68502389615582, 23.147840115331835, 25.00015393380196, 24.792470316733084, 35.986867720080966, 40.48710107803345, 41.116060979904674, 44.077866231241536, 46.73002389169509, 47.107242153536895, 43.625620872743674, 44.27924071588824, 48.40849630294308, 48.453034816249726, 53.46225846198298, 47.77585721785023, 50.73997666758876, 49.905798358301965, 55.29897889783306, 52.89285190643803, 47.51933420858076, 41.71033928471227, 32.83084434847678, 21.26075448528413, 18.216724588025002, 10.228954034466899, 5.047053435156423, 2.4422314282386535, 1.1346332128009489, 0.13550428373198356, 0.04300504276949552, 0.1138626292888676, 0.03415483500688307, 0.039281771187820745, 0.07255325319185373, 0.029451509058896094, 0.03735140198841691, 0.046995958658836545, 0.029798232792546193, 0.027505856405402866, 0.06396110214653515, 0.060544801996119564, 0.044097664180181684, 0.05057837731475311, 0.07894595048480457, 0.083183313028947, 0.036067212631385175, 0.029620418039661263, 0.029695178644971985, 0.043724391669515646, 0.0401976369621773, 0.03873460054878266, 0.058683422844736814, 0.03200680873687229, 0.020777129966224876, 0.03172916315135456, 0.0042667611682366945, 0.04378764371898386, 0.09760062045027172, 0.016869401649361657, 0.061558470385329384, 0.07490983923837062, 0.0663660896281081, 0.04082353462675407, 0.05657128013309933, 0.030931271086897583, 0.04751526284962893, 0.027841056261451978, 0.006943327297772011, 0.09404300006046411, 0.012323548904650155, 0.065245310655765, 0.06722402383363055, 0.03904041135683656, 0.03487198906500013, 0.02135551677295758, 0.05105368124561445, 0.020715722273434364, 0.008328047021472407, 0.0342192515099962, 0.03163156546502104, 0.08469778458557783, 0.05461949111533262, 0.12888430347365717, 0.01919721534866239, 0.05841618839411005, 0.032303357541921644, 0.056480751523087104, 0.05573216487743682, 0.0494671514588258, 0.047240884629108255, 0.09098162844536767, 0.042399220438974525, 0.08532838219957006, 0.07942182898160913, 0.010120043504772889, 0.04091922666937594, 0.05265527998187369, 0.04445606309379782, 0.08089474026834773, 0.027273873490611875, 0.10648092780742915, 0.0530673127110687, 0.07526539596578768, 0.015745294024987568, 0.04837813066138376, 0.047459755949075186, 0.004155174716405812, 0.024523160104910215, 0.02769886842748571, 0.08863811185883899, 0.04138642155955877, 0.047964569586779804, 0.03506172606120667, 0.051674660625717336, 0.052376879799750545, 0.009642618467971202, 0.00989916982249387, 0.09493288013242906, 0.06791879663303976, 0.03434811132929979, 0.060832253507068085, 0.059234366466801976, 0.030879355223488905, 0.019967229473554803, 0.07104759164635213, 0.03576783313145561, 0.015967751594050037, 0.0385961186651501, 0.006188693824374388, 0.027287504110004634, 0.06360442310030903, 0.02910752983523473, 0.026080111236942392, 0.013200665951796598, 0.013547229764592505, 0.004593666207285658, 0.07238901160176724, 0.0028908943087087888, 0.023435529757050738, 0.09053042564060419, 0.02676344251320247, 0.056921654275708625, 0.03774366198828624, 0.046808765074538614, 0.03100500513438977, 0.03509846380761555, 0.024528616566150904, 0.07588075609096596, 0.046779607768140496, 0.042138352178998535, 0.06126129338818212, 0.059328250541922554, 0.047469339709007935, 0.11979212684016075, 0.031502360906151515, 0.04421562639876239, 0.022858133118960167, 0.10825819816560515, 0.0434716209588993, 0.08204666071481283, 0.06578950121277763, 0.051807446645632874, 0.047195562867507826, 0.03865189752691696, 0.012502574076455449, 0.053663520638139985, 0.05885497291362094, 0.06087329283717179, 0.047162893047976884, 0.4815539212957506, 2.0304263190877054, 5.246188736731007, 11.32500840771583, 15.949862330190598, 21.577782015646658, 22.861793425775346, 31.45292551286759, 34.79665587025304, 34.53457094007923, 44.834977811382664, 50.731975032437234, 51.87855835883848, 54.484667393469046, 56.84136859832272, 54.89481395290744, 50.102477765852406, 49.991682575595, 57.374646202210464, 56.10427287317092, 61.329015070392245, 53.23198003153647, 54.45365713488672, 53.91240927480883, 58.73097827357631, 58.960954681519546, 56.03458804468955, 51.83238029479981, 42.748335715263124, 32.81328389721532, 24.342668594852572, 15.38153736822067, 8.108253017548593, 4.395248668809091, 2.058359355695786, 0.33176991187276383, 0.06990398325386547, 0.012047287065445656, 0.02061076439736832, 0.011547542056970058, 0.027229273766880075, 0.005264603617345734, 0.021823085131003492, 0.00849024698724069, 0.02561846665377098, 0.07739974756635006, 0.046548410093471895, 0.013542856360154768, 0.09728406525907979, 0.07700397888378752, 0.05204075489253287, 0.027643972482051582, 0.03295438289041481, 0.06620128113295763, 0.05827721238376633, 0.01577927960052846, 0.02530549675406468, 0.021161305823273236, 0.016039862492752653, 0.027075579292291117, 0.0116261541693201, 0.05092190263131934, 0.03547934357136969, 0.01887908393156625, 0.05501447072733314, 0.004635262866354278, 0.06479796127326067, 0.021396224770034035, 0.04108883087493239, 0.01090300260036583, 0.026276338913087404, 0.025098291037964727, 0.029389176314937013, 0.03882804029290715, 0.016876489877881064, 0.0017915462869437292, 0.035573434490229816, 0.06979649345720969, 0.034281392731974204, 0.04813643758215251, 0.057073653780765114, 0.13605666376890677, 0.037294845547406905, 0.07737953816690753, 0.03974296377911683, 0.046005303550872116, 0.03212442430066726, 0.03992470281739389, 0.03373704895737671, 0.029332457080243096, 0.047829236324516036, 0.005101340225777559, 0.02933494686599701, 0.08298452087347546, 0.021070474608530922, 0.06393150433958059, 0.06056847411297983, 0.10896184992405678, 0.026056935162013097, 0.06729879401504033, 0.0325615176810853, 0.036193896760983814, 0.08890208277490833, 0.1272002277114699, 0.11745099278707659, 0.17955731179925705, 0.17731195405846645, 0.17742950258956802, 0.12366650160402061, 0.1745699261946063, 0.1568961398856294, 0.09020048689337508, 0.10058563608195513, 0.1812254376108608, 0.1380668171951848, 0.045999082916926955, 0.16058143648889758, 0.09629041091689179, 0.0852564771869971, 0.18479251152565404, 0.21449930214833832, 0.1198047519691529, 0.15484873926447285, 0.13877863545090924, 0.26380087519364975, 0.19474817650212398, 0.12274372571658705, 0.1769430827229254, 0.20888957735751906, 0.16870127900713877, 0.18813964159738636, 0.26002887275911146, 0.12209341666030309, 0.08727821386269025, 0.2444218844175339, 0.1410588655140131, 0.11064403344907107, 0.13406863496188196, 0.13578637262746213, 0.07793598613070865, 0.13926258851443568, 0.1276399775017654, 0.12446662681477687, 0.1829948862113299, 0.14856907058387034, 0.22325737251629754, 0.3211970098557011, 0.1298458204274216, 0.1546590712161795, 0.13202855814128153, 0.18276702101913192, 0.10374974008769759, 0.09138121224579313, 0.21033987372873292, 0.12346119770119268, 0.16488450639430555, 0.18202863483419343, 0.11727283137940592, 0.1430668892158616, 0.20547872409224513, 0.2210499514495173, 0.12281093461018418, 0.14420920291975622, 0.22291038065187394, 0.27465796518710356, 0.14451407527010288, 0.16453851044418352, 0.2080107519343015, 0.18720850769069888, 0.08977228970897776, 0.13951172030741169, 0.1499077785880335, 0.11745037991673717, 0.14302044896589172, 0.1326341046801498, 0.15287998522962296, 0.5806125832661506, 2.2190922018020385, 5.683188332665352, 10.558436070719074, 15.318311702820564, 22.070312076999297, 23.38112896488559, 31.51448907390718, 38.35440643372075, 41.68779742333197, 48.99632230881722, 58.86165203586702, 60.96783538018504, 60.982650172325876, 63.15250142928093, 63.65233298270934, 61.01310737671391, 61.72226013675813, 65.94778245495212, 64.76723924759897, 70.5185910194151, 63.257216945771255, 65.30696915042016, 64.61989933444609, 69.0041325169225, 67.63300526526668, 65.4524302482605, 57.91983604431153, 46.98585656381423, 36.28364993679908, 27.218171896473056, 16.520093564064272, 8.587012617818772, 4.482883243791519, 1.804210606121248, 0.36765469598674005, 0.18304638264160003, 0.14003348747088065, 0.11336667928844692, 0.17478789353082258, 0.24119098520567342, 0.13927591844431816, 0.1014078476075684, 0.11350575489022079, 0.12810571299445245, 0.12736037839204073, 0.2122016359240778, 0.1342430885039991, 0.30529464865403794, 0.20593158930780428, 0.1701548848781855, 0.17893917077491361, 0.13305195967756933, 0.19632181302914697, 0.130880820534883, 0.192902471509672, 0.08870063229433953, 0.10818195709538077, 0.1306618419626067, 0.11988637097660573, 0.08934998374071815, 0.21094094631412338, 0.09609629955863762, 0.18560225113986, 0.13339777176658954, 0.14523378423144742, 0.08345268486488251, 0.09135413869854905, 0.15807495001823674, 0.07814867512112664, 0.11255215928559342, 0.07771256424847149, 0.1260311622172594, 0.162755134365251, 0.07489427999262849, 0.22379559524838002, 0.12344358533981348, 0.1328646052148073, 0.14013693998417548, 0.2356490745179115, 0.1206875916930937, 0.18493236853711068, 0.1724618207663298, 0.18139486561619467, 0.06456201385346151, 0.1768126332711789, 0.14753977017056558, 0.17034150389654024, 0.13494628060969616, 0.19791518398109945, 0.05606524075471586, 0.20175104750500572, 0.2701805489918878, 0.2866097948243541, 0.20654606843186965, 0.2176967386396662, 0.15207680332804882, 0.24221550523033067, 0.16838417989352059, 0.22061475222149204, 0.22613879773885975, 0.13145648964470433], [0.044449034237092545, 0.028986924613315253, 0.07039783417337364, 0.06995764005208208, 0.05385865855421271, 0.09845274770932813, 0.039207127410918474, 0.010039065138346726, 0.06821935590837272, 0.00921813585239673, 0.12049319688230754, 0.07119124079303396, 0.012583055443340733, 0.04479768085143259, 0.04088164239581074, 0.02141199660517516, 0.00695987862737609, 0.016110085942331823, 0.04536756982786521, 0.01732036505164879, 0.02908601042544169, 0.05254764845895191, 0.01554762993398453, 0.0253366420586263, 0.03194173148292447, 0.11682175114871034, 0.022891471350205042, 0.049166055921945846, 0.025643253428561073, 0.03822779508247491, 0.041383977739080306, 0.0331821599825015, 0.06597403647197832, 0.026999533574487415, 0.04386887202159532, 0.013093212544317208, 0.03231657255861548, 0.08712232263097841, 0.059252622342037584, 0.034470467062126246, 0.008722225113982155, 0.014233335236748381, 0.037890183964684125, 0.03614427341568855, 0.0418842944406694, 0.04615797721330197, 0.06269291636624164, 0.025766811919428652, 0.037899629828790506, 0.0223042898541016, 0.05167354596778751, 0.08458960530979019, 0.030491655361988855, 0.035025727589644735, 0.04370076934837046, 0.02685961719121664, 0.055233200321034084, 0.00505997626591594, 0.04056326391535901, 0.03867107653810132, 0.0689923539457302, 0.031153451906697407, 0.03507360042403302, 0.04997386499458263, 0.08238710252748382, 0.0497424106804594, 0.02754342535720958, 0.05897946986219576, 0.06222756391751671, 0.010915690931611726, 0.0635055173188448, 0.09832862614383621, 0.017697636541279576, 0.05160092083256572, 0.025671799779839577, 0.025837085164722898, 0.018822429814345894, 0.05417628626849863, 0.10039923156821921, 0.26214811710580704, 0.24918624650566812, 0.735714070258602, 2.0262391889287583, 3.7644705032148673, 5.380838311487629, 6.861754665451666, 8.105394099989246, 12.178510273656538, 11.943549513816835, 15.094074703031971, 16.24128168629062, 15.666790758409809, 13.192895016362591, 13.890661135796579, 18.591818886418498, 18.447312885715117, 22.549039317715554, 26.502270698547367, 25.50198393483316, 25.117766203418856, 19.301299164372107, 13.91253815543267, 5.199337495911506, 2.1499484152563157, 1.0557266468963316, 0.26185691176402953, 0.1062079476973703, 0.04151459189973051, 0.02939394138182604, 0.07932390762312759, 0.005560937917776286, 0.1098959332692527, 0.0505199937540437, 0.029423950961039915, 0.029577601385573228, 0.005255900858525908, 0.020181684296638257, 0.009582809983722625, 0.05201401076309624, 0.010877895983867349, 0.044741373388997974, 0.027972107092219017, 0.049699689787361896, 0.03736378579971291, 0.02826162129490366, 0.012408719687241943, 0.024868903246017236, 0.034192595480670857, 0.030231417209330588, 0.0430101755585882, 0.07684031185964424, 0.027018737483529315, 0.04338643198171931, 0.052748650778085, 0.07375075586981351, 0.020083253489687078, 0.01777451346448112, 0.02779921062380797, 0.013887888954712019, 0.0205519690643996, 0.020556408543920806, 0.05209768288618615, 0.027476714420763236, 0.08692222812603559, 0.026710818018463832, 0.0773892674835459, 0.023300125631653977, 0.02421444390840348, 0.07051677698449743, 0.07075286230012294, 0.03727258686276694, 0.029747619278608795, 0.018482554906738863, 0.03829322665208771, 0.028844014741480354, 0.034205331692412015, 0.041924402973945105, 0.046596551058633674, 0.03808476263657212, 0.01723784972132454, 0.02483099721552384, 0.021994104684000055, 0.04344107703335824, 0.015724521550920703, 0.024687886245608814, 0.032095717070924665, 0.022857451300707557, 0.07083340112360255, 0.054775148690227544, 0.04927889301231311, 0.10379989586410024, 0.05206703553877531, 0.03530616173520684, 0.031107528766076413, 0.06306661788614527, 0.053431560705986716, 0.06118346268551485, 0.09463756855937744, 0.10971434744856051, 0.06874658527874178, 0.04279445669042968, 0.05804041077593162, 0.021855302958659107, 0.013950908304973236, 0.06308270956299479, 0.07946593266340994, 0.06608975405294089, 0.05857514014707939, 0.03397535209754302, 0.10330544739601114, 0.04254321049478266, 0.038363166649134896, 0.025392476461767673, 0.03400152166103644, 0.03107007089701872, 0.0131427688569191, 0.013268773083484942, 0.04140306098927413, 0.053705395004081155, 0.027380283103294434, 0.02160380395399707, 0.09008368912843928, 0.021761033924356587, 0.06852034419294327, 0.024041344426692497, 0.04698247934180883, 0.09527346750180568, 0.041501606709413955, 0.058231990213596055, 0.02242838269129636, 0.021518199374118162, 0.02606735012734369, 0.001506147652229805, 0.031201085338609356, 0.07457595513833147, 0.08472747815352294, 0.051735384585035425, 0.015570823245892122, 0.03907203929679048, 0.023489703664616234, 0.006246655079115543, 0.044330386369819605, 0.025508797336970607, 0.032470881818763675, 0.036042950626823216, 0.03614319323171531, 0.024585056178752455, 0.039358299541016745, 0.013555956463659964, 0.026388999803232092, 0.040398777177136753, 0.034603865952381206, 0.01921485835355857, 0.06469181213047236, 0.020253631444047057, 0.04304436223220922, 0.06324446136732736, 0.039877576918731776, 0.017509144437949986, 0.04393713428608833, 0.06114986589959553, 0.05536283005870158, 0.03846848075608573, 0.04728386216166039, 0.01983992289751768, 0.032512928554487806, 0.010156598347689836, 0.08475244495897524, 0.06315980865169438, 0.051447304881989, 0.016537404040836038, 0.016815505448668715, 0.0462887407610974, 0.09963927234733298, 0.2990578349319197, 0.6228107286076392, 0.9359046732706409, 1.7914814117454716, 3.572479553761021, 6.343784111161386, 8.552585974816354, 11.055608257170647, 12.965921182786266, 17.78410873105449, 19.172080601415328, 21.460081492700887, 23.710053043980754, 22.76705053544814, 20.942263910847327, 21.2952733039856, 26.0564717554277, 26.875574434957198, 30.482184002476355, 34.53115063328897, 34.94380750963765, 31.941592039600497, 25.691514822744555, 18.170736758939682, 8.09484439511453, 3.0822551106252982, 1.7562483539504392, 0.6469845411277587, 0.12886060071327995, 0.043552860752829624, 0.0413178988251715, 0.04862948027890056, 0.003409675644492851, 0.19212463179663306, 0.038414172783133485, 0.03185968346623404, 0.028358360962761987, 0.04714296710106635, 0.024060902651399377, 0.07049335001577293, 0.0987394178105939, 0.029866519954896746, 0.09960619267076255, 0.031189685950296062, 0.03390976731034537, 0.04598929231325465, 0.04796329405038588, 0.049442904776022326, 0.04377395372777697, 0.041269780842647444, 0.03444467671215534, 0.06732163109606312, 0.03175674423184847, 0.047700035596086134, 0.04941586187229522, 0.07972358335410396, 0.015409874876270132, 0.04227556618711641, 0.0649656655807649, 0.06965237699689404, 0.026151924318964445, 0.06004236706141984, 0.03308941737838811, 0.049634296522145314, 0.05637017822253609, 0.032539772275354595, 0.03067494572831258, 0.03684825076150798, 0.0238834556207181, 0.008425774942753057, 0.04237211624821348, 0.030249211516591813, 0.011401789998936077, 0.07545493377913391, 0.04212119563993427, 0.023092540702031508, 0.0439280906181422, 0.025574780489888885, 0.032088423913885514, 0.03809471411870853, 0.06573562990994224, 0.032207217337864066, 0.06992767835336347, 0.11628669235975513, 0.014420085447660137, 0.04138550608448925, 0.05856539167824292, 0.0682291235294073, 0.07832846829607602, 0.04911416112595508, 0.04449008122807549, 0.08660753452849966, 0.10865271812485111, 0.06131091673347739, 0.057571499848798405, 0.10308129006936666, 0.1326313467636224, 0.07658404778809318, 0.13538699567077622, 0.19716345254452, 0.1983354751381182, 0.2071939949547091, 0.23894715964073138, 0.23266111710859885, 0.15935287660648748, 0.1226219790236604, 0.1287044719943116, 0.19804952515950128, 0.18478102020678983, 0.15880965898113866, 0.14783814609531434, 0.19331372282918424, 0.10959279993849416, 0.11353322680318549, 0.15269590962317683, 0.18163103520149187, 0.23453928890728185, 0.08408222527753922, 0.08366368080098784, 0.10300700252334918, 0.1398237938842466, 0.15037757434671925, 0.1851725524231311, 0.2202616163319157, 0.18045309840911822, 0.12527425968719105, 0.145574402244341, 0.11929440717663496, 0.13588217958327264, 0.1327559126601104, 0.18124998306795476, 0.13991874282158193, 0.15820657924538659, 0.12552390475907635, 0.18579587220184265, 0.15816498067109816, 0.1762504779523419, 0.12881437496792886, 0.1748165145756737, 0.0929262430497235, 0.08629345380130314, 0.11831107203878703, 0.10561239094503465, 0.10040257171156908, 0.137426674125656, 0.14108517297333287, 0.1158407602399107, 0.14077645486160634, 0.16432429693879622, 0.16108124757245665, 0.07809587634138523, 0.25393459735618484, 0.12808997754848775, 0.11600049723300243, 0.11077943182880841, 0.12656442836047183, 0.08093744200924713, 0.12087711418468146, 0.20369827446918334, 0.10827596374456921, 0.14495575560196755, 0.15626378026941132, 0.17112466025977366, 0.1257281361388103, 0.08420744234876287, 0.13288041726956445, 0.18333908951570912, 0.07797917050700034, 0.14866115435236885, 0.24426906519839842, 0.12114439460058367, 0.19600296723506144, 0.1571958334816079, 0.06676273931178354, 0.15554508254412683, 0.20940944462293581, 0.31139099249436014, 0.5593752776903491, 0.7028360893168758, 1.4145483797596348, 2.7360336242183565, 5.301179876250606, 7.7769093263533815, 10.249967152072538, 13.863478129909886, 17.66432542954722, 19.171037250949492, 20.941279395934075, 23.88648713788679, 23.538808245812696, 21.88705894254869, 23.536562688889045, 26.814501170189153, 28.17927614335091, 31.28443814093067, 36.85642973069222, 36.62749275084465, 33.43086304203157, 27.269745180683753, 18.905753627900157, 8.586206570748361, 3.366943189213353, 1.436042600581723, 0.6646713662532069, 0.2190642821932993, 0.1957403369728596, 0.1065137240314676, 0.13909930453425454, 0.2147070192281277, 0.30959926605705296, 0.2838868119062916, 0.09560562790401521, 0.12464962989812899, 0.18735389585696882, 0.0906246927596869, 0.1641645063195498, 0.1996828705793427, 0.10977505225568049, 0.1779594515720683, 0.1145699812519935, 0.19792750267492187, 0.17378146850293683, 0.24308135312411094, 0.11546052782045257, 0.10205398914554428, 0.12083640427238519, 0.14871277335670688, 0.23999311480551, 0.14504995377313706, 0.1850229660950361, 0.115943186195387, 0.24473230324445233, 0.1584444495458757, 0.11594887056778516, 0.1024741500676159, 0.13795556590682076, 0.10532713044554957, 0.15187512302110273, 0.10316748262172747, 0.12538328165969542, 0.09915796994802453, 0.2138283317007365, 0.14987014834919285, 0.1595759154447625, 0.15469415804311154, 0.11799623288454548, 0.19055746105169097, 0.13871748631279315, 0.10964710791144641, 0.2080549245640155, 0.2662338172235797, 0.13259279721927258, 0.1426591006137671, 0.10468817481230344, 0.1200900354512757, 0.1686884700170448, 0.15052685423964454, 0.10762320320692756, 0.1639123867836691, 0.2553983309095906, 0.16176971546824903, 0.16131182471590658, 0.10757160718522726, 0.17061246919535822, 0.15611263112195078, 0.16318233563534676, 0.1071208716940976, 0.18293142348768252, 0.16235223340411342, 0.15348756956236978, 0.11665803049841236, 0.18077477872852357, 0.24700600623844132, 0.2870785487034629], [0.02922211743650898, 0.0361124616146328, 0.0754323112027299, 0.010843554177441666, 0.05038001799895879, 0.045928752215038386, 0.010525617155156309, 0.057836098956965634, 0.015527898381884783, 0.02873221186981086, 0.03257513106349976, 0.008651099595872146, 0.04641989884417384, 0.037551381580171087, 0.09769049022466907, 0.04473390020129662, 0.14781347806415251, 0.034449062565521854, 0.04542953484962064, 0.031766218824252006, 0.033147046342492104, 0.09081245324904881, 0.039640794463095166, 0.018541166378605752, 0.007976731069521199, 0.07728242886162574, 0.01775236203215055, 0.0441794747096156, 0.05179928397879966, 0.045943231276807286, 0.025331365628047817, 0.027056538176933126, 0.06164676201860271, 0.005430069990501169, 0.005475265826399048, 0.0676017894499725, 0.04015038465900768, 0.06497415383496592, 0.0339230168009958, 0.01907413374752768, 0.01914382093555985, 0.048794928457467794, 0.049932572855463916, 0.004632464730210843, 0.045619011375932925, 0.04745925799192441, 0.047041215302963416, 0.028856902255586563, 0.015131230503621121, 0.06261351901376921, 0.015147415068631452, 0.008597408323698949, 0.10239192585070288, 0.034539468601466186, 0.006105569454150335, 0.05162634729077259, 0.004115069534764776, 0.033038958997255376, 0.047278652763775283, 0.025735676190966082, 0.04199602836442571, 0.02605530530995419, 0.0381822090205406, 0.03875319733314457, 0.06226676846704176, 0.0167941871369558, 0.04285334586916913, 0.008604931307115383, 0.06406330593651341, 0.015060188297572878, 0.06959127382405343, 0.026075834551105098, 0.07496742606763879, 0.053234967222857865, 0.03708658454519126, 0.010068377577549508, 0.04053854991892173, 0.10956616306136693, 0.046361565079179504, 0.007514999343848397, 0.03130601640159805, 0.03192306000498995, 0.06508962626779272, 0.031762748445955016, 0.025276695678551352, 0.0513992328647404, 0.11625825517600584, 0.029726477167118463, 0.3317203306623044, 0.3452164096938026, 0.5012954248776359, 0.5006855882463918, 0.7321575836789224, 0.9251677365072313, 0.6017422688103492, 0.529358972224497, 0.9342865730004927, 1.047963418306843, 0.9873843721805081, 0.8434058689782697, 0.6618321831187894, 0.21819592153112735, 0.08450033308397378, 0.010335169612399994, 0.074986900022674, 0.13308189839365023, 0.044122952742562185, 0.028941514751603527, 0.046889464776482315, 0.027920292735460307, 0.06578716464460858, 0.011787128394409534, 0.039570908092202685, 0.009976604074660328, 0.027170480349131172, 0.07759441816878897, 0.03141678122413014, 0.09391692497076527, 0.060564789230064045, 0.047747441116840615, 0.03955492749810219, 0.014401576763409522, 0.05182688995715111, 0.05997142348919184, 0.04249099777230332, 0.03271809073104974, 0.0751831794097539, 0.034037991276671814, 0.06020891074571879, 0.07961897404804345, 0.035786265206913796, 0.025677618217624487, 0.04956230340946106, 0.05425357304873967, 0.031454210364890677, 0.04649713199826018, 0.04969091041974964, 0.013966156327496133, 0.020432832816074935, 0.06318072285202724, 0.05662936108907866, 0.03389790826927751, 0.022020128690787864, 0.0514464277113157, 0.03537879070086825, 0.04447789276920019, 0.08703110454183433, 0.011576797997188425, 0.04352517816568575, 0.026112026459867918, 0.053180103836160515, 0.07509918552973578, 0.018170000609731483, 0.007049151331997447, 0.027519736003371018, 0.011328292481090513, 0.050575324454374855, 0.07857003880123939, 0.06034394906413171, 0.01611133658086821, 0.031700848541673154, 0.03731266475252567, 0.010597480032893439, 0.05273207646584319, 0.06609274179584558, 0.05777235278078626, 0.09215257085499265, 0.07056595982923623, 0.045329748067043485, 0.04714863998214564, 0.05914535854131945, 0.07583692820081789, 0.048678961897929834, 0.028063156642019752, 0.05311420878335353, 0.02134142267037063, 0.05325229613170509, 0.08356381357917864, 0.0440369593730617, 0.010982140440553909, 0.06462269567794378, 0.02937330488836573, 0.0013193960049031905, 0.051902575613630396, 0.02176098795908113, 0.069057785515343, 0.06565520599965127, 0.0460213377711273, 0.013918682816438379, 0.030614018755694552, 0.024321970094235677, 0.013949477635774643, 0.07013095212319205, 0.014933030151071088, 0.022113147086554, 0.02445682455154677, 0.04036202027852978, 0.15532107843506723, 0.01745441511663939, 0.045257992441615755, 0.026981384951561212, 0.052819958242077025, 0.01137056521275231, 0.059433097335239576, 0.03776948298177412, 0.017681929823612014, 0.007568248200245323, 0.016969651915133, 0.012482760169903838, 0.05039410635588631, 0.02794529784530882, 0.03466663536645713, 0.03697919817040524, 0.05420933530155209, 0.08787350248425238, 0.03649255230782494, 0.02573531804486148, 0.044968005179637865, 0.05358075249880072, 0.011338882689033786, 0.05470387953063173, 0.0628275869624509, 0.03553120772384348, 0.03231991270196534, 0.0391413051364643, 0.07624785776340193, 0.05218418187371666, 0.033847204740009004, 0.06720658001159469, 0.05012102282395767, 0.07070295167185607, 0.08815537687511214, 0.06468360732880331, 0.03754910246859636, 0.02172070131036303, 0.014856096728885127, 0.01937196958028982, 0.022435474750255386, 0.015268471324816348, 0.05010792655089209, 0.04233710603007386, 0.023114422088368766, 0.054618422422678246, 0.023161724187253464, 0.050288141074199835, 0.06350920603220021, 0.010221356717539171, 0.02690287817630076, 0.09362751993560985, 0.027499903902231206, 0.02665303392155517, 0.027318614940609665, 0.03671637255578272, 0.08062360643018639, 0.05221236241801132, 0.013943755916590172, 0.03466734782822671, 0.018058682288674098, 0.08279816998589425, 0.06846397544347471, 0.04888960926402961, 0.14380850829184055, 0.3461843158208555, 0.359647085349406, 0.7204295742896296, 1.0751005814921473, 1.1802313789244623, 1.3735316645714546, 1.482493882217715, 1.4616418269372757, 1.3094318009191945, 1.4239684420247234, 2.243785483221854, 2.2532656067802064, 1.7207490652799609, 1.711826531156417, 0.883222584041857, 0.42170630527600167, 0.10214025064581826, 0.03741893646938186, 0.031401846340046294, 0.03381972899660468, 0.03807502948949414, 0.048442842108347726, 0.009374096989631653, 0.05470054321772149, 0.057339911469288414, 0.03675181944403918, 0.03591872563946151, 0.025296384138205362, 0.05062064621597529, 0.01312814998410402, 0.06633990474285618, 0.07649735727858159, 0.054195200979349115, 0.028664016638011224, 0.04865846521551571, 0.021639953727924058, 0.034423540346324444, 0.03884483294020738, 0.022410121070401325, 0.0334671906556093, 0.04572597640236059, 0.03809236988966023, 0.029074791067790602, 0.07043781630214184, 0.032289200237080935, 0.08097449002126533, 0.03271396917801711, 0.03527022072023923, 0.04411166826743753, 0.02010694284352564, 0.05364927140274837, 0.022849953215148662, 0.01658621533293157, 0.045056492165331884, 0.03461873188855187, 0.04936708122371666, 0.030859145824046388, 0.020070421516955383, 0.06800751727555068, 0.05267401849250159, 0.0370254545592733, 0.014419698573258376, 0.03500069183627925, 0.06290073686790082, 0.056376567395824584, 0.06534723099321127, 0.020866955690566572, 0.02828548876418462, 0.07660071020044627, 0.07724135122712582, 0.010348052338456676, 0.0280362305667011, 0.08709501159647781, 0.020925992341231436, 0.054473363674215736, 0.05030625905360907, 0.10234796006472842, 0.027639898809514223, 0.06362257938411447, 0.048218497090161815, 0.12413845006977359, 0.011713386686038108, 0.08975698327225062, 0.024519682065733982, 0.02238432114433137, 0.01796407426046508, 0.06059972283941123, 0.10818651531853023, 0.009834784920507622, 0.0715184829107696, 0.1420345550943767, 0.18309329786608297, 0.16404686585789727, 0.08853935546452, 0.12898957927621182, 0.10249218377735346, 0.11809832176133511, 0.1509606898311646, 0.09328081918459746, 0.16746072218783442, 0.14118124039903765, 0.10069635876965138, 0.09516495880821059, 0.15715690089329598, 0.30617016457742263, 0.14346592909386083, 0.15500056256930675, 0.1032002405413697, 0.11535757326430852, 0.08602792006586829, 0.11450703946813462, 0.1353750906644329, 0.18957830875390963, 0.12182858006487932, 0.11712607191575151, 0.11397925085358082, 0.09344070173439481, 0.09437464718376437, 0.143354999562425, 0.19295042861373196, 0.09451566864886592, 0.16369984334995671, 0.18482721530862395, 0.14550606720149517, 0.0734414172268683, 0.1670433728084449, 0.17305702511822024, 0.1626089494675398, 0.2927091417293395, 0.12069824797612046, 0.07104165446493896, 0.11912738468738333, 0.20867974587505866, 0.09161974904277632, 0.15624326443479908, 0.23650145458598293, 0.11968490517427845, 0.13302692392420384, 0.11479355635181551, 0.18474947270606795, 0.18426518256385482, 0.0705991697407538, 0.1740233990694246, 0.12676213267109088, 0.13729026450985862, 0.2411939882703366, 0.11845097501551914, 0.146440556573291, 0.11765217513687189, 0.2951944841732902, 0.13737588249627622, 0.09673605192332499, 0.08022535562274918, 0.14109246613037202, 0.1802799625382308, 0.10818385699343298, 0.1448667974722001, 0.10785063938988794, 0.2155660642611404, 0.2059441225062455, 0.10902933460930664, 0.07972817988164964, 0.2511643927784697, 0.14996989299693417, 0.1096700139403824, 0.08716177615907886, 0.11379217984335077, 0.26747733114227173, 0.12455294194120554, 0.1359797332195505, 0.16405584440836984, 0.12274771703467255, 0.20716483764831098, 0.16024149263337736, 0.12488309519305346, 0.1945951427783697, 0.3201637104634316, 0.32084617222989764, 0.7379009142037362, 0.8580754721356977, 0.8738017863323613, 1.0501654614363949, 1.3134652231970143, 1.207027173330707, 1.1772049026143168, 1.385632544275253, 2.038039517018103, 2.2680767216990074, 2.0622944735711624, 1.630008708565466, 0.8605855438978443, 0.47584675012096284, 0.21761522688452276, 0.08309906633991389, 0.17196268384014407, 0.14539679241997583, 0.17118492073589758, 0.11434992249574392, 0.15134529661267035, 0.19397021421501714, 0.12917023813051562, 0.12021051809912729, 0.16135711583399004, 0.10295307759435908, 0.22937895129284552, 0.22703561090653945, 0.1059267474638839, 0.16101671232571527, 0.13333311394578026, 0.16482545633710202, 0.18756662315178305, 0.10197157340665018, 0.08355340244428766, 0.14461404974422148, 0.1436800659904557, 0.10374997757495412, 0.17400548793375495, 0.12581192317508882, 0.09408670537654432, 0.15709942897721646, 0.09934836577984596, 0.22331784749704026, 0.14992625662876716, 0.11514365087233244, 0.12568463766646962, 0.11734761688257418, 0.1814437113822468, 0.09685912394836065, 0.16813334738535268, 0.15202492385381652, 0.10117799058676728, 0.14921001038484036, 0.22016338853826448, 0.1734908607097403, 0.09925658078563791, 0.15037745177265138, 0.08910595409331784, 0.06798834975568518, 0.12880211756114038, 0.10941435507829152, 0.20242639997553444, 0.22236164719347032, 0.1696101657205051, 0.11064941904717877, 0.14896519932775729, 0.16230468998753256, 0.13192421696599455, 0.14223084214233583, 0.20064375934100923, 0.085306357171747, 0.11099293287242613, 0.16424459315115408, 0.16078736092294418, 0.17015741296833561, 0.20250981162873008, 0.1262241091218687, 0.27703875195114847, 0.1255855365325847, 0.23137546835407136, 0.11597583686271984, 0.1419009340386237, 0.1708022291742025, 0.1523027533004361, 0.1375239826137981, 0.15465962279948497, 0.21059672768798568], [0.02091643730959585, 0.038656930724579486, 0.054290080968771255, 0.04977232641390255, 0.013037267058426815, 0.05889168767739208, 0.03400422978184877, 0.05962407922432308, 0.05031279378360318, 0.027417811835485122, 0.0502807253430928, 0.05746607082865893, 0.10082696909986197, 0.05767480680538763, 0.036607844709989526, 0.019180943641150673, 0.05993085530316157, 0.045686729717999704, 0.05288823965876814, 0.019390606584267753, 0.02278125428053881, 0.011475990402452167, 0.0635405428587429, 0.03223943133508006, 0.006262886088206283, 0.020504146025726394, 0.02616166129648205, 0.03890714653196835, 0.0425451333754726, 0.05653265397995711, 0.10149413975135935, 0.09766073536969001, 0.04967096149020138, 0.03626366055780842, 0.015001977106646426, 0.0340792068069981, 0.023460373988435156, 0.04193211364890299, 0.06541940413655774, 0.0415623574818094, 0.06035499222156021, 0.06390925331581986, 0.10299977065334398, 0.07116985927906729, 0.07085009417947262, 0.019975754116932233, 0.04324586250849309, 0.039380427990709586, 0.035609628314212445, 0.005512284152510186, 0.012876425941114225, 0.05952331567964247, 0.08064432910853818, 0.05546654304189067, 0.05674377632056994, 0.0073939454816882655, 0.004598877041585623, 0.03203182150760005, 0.010538069914365488, 0.03143592576135791, 0.0422522617924598, 0.03637242972129776, 0.08312120628092559, 0.045831102817769975, 0.043955773205286076, 0.04651246907850427, 0.02936575317665214, 0.05034094751482049, 0.04080687987528021, 0.031142058264043544, 0.022907327455017838, 0.03826209283884495, 0.07663116985631567, 0.016261512796664913, 0.029533401942781867, 0.031538313412438, 0.04224450898266608, 0.12119729297175524, 0.010789325686111566, 0.022214561805970246, 0.06569836739330523, 0.014043106029050486, 0.028583192446779822, 0.02879000745803839, 0.03929012920707464, 0.09014535154546462, 0.019168686234362183, 0.036364519863479564, 0.09003070648759605, 0.014464049318414784, 0.003819538669044813, 0.02728346874186349, 0.02984739073942746, 0.06927880954237715, 0.04394209087495843, 0.03461054240864131, 0.0651732217820902, 0.03783966429651745, 0.023878552658002705, 0.03227814175789395, 0.05201587618719186, 0.03166786271087345, 0.01447277889031196, 0.017254376153071082, 0.0325164525589395, 0.013632686872545992, 0.0655612146722213, 0.06826349023369051, 0.04693706181921786, 0.03832897997551388, 0.020969088617411834, 0.017097272587219076, 0.015552776129615885, 0.04029841965905601, 0.016590846334433845, 0.0485412001369461, 0.004502170890073983, 0.04602441361414329, 0.031351259639186245, 0.03595513396806294, 0.022362769175801548, 0.0730657200479219, 0.014709744249440491, 0.02000593223548945, 0.022026929636335662, 0.09717474451228496, 0.0293968333637402, 0.03353359515688593, 0.08049127240214618, 0.01850106167576967, 0.09052188376024847, 0.04145232810368461, 0.0368589032140951, 0.016761921428804918, 0.04200838919308397, 0.10649997275322677, 0.056607899135879935, 0.054648770995798616, 0.026985159849808104, 0.05194220534195343, 0.04395974537117347, 0.048012197273032325, 0.040285388503464005, 0.021334711740153934, 0.056838529905484575, 0.047549755958419655, 0.0804165022207364, 0.016597275727338368, 0.07930972733564916, 0.05544979252942628, 0.07324218840127991, 0.04677485802300996, 0.02398803811370125, 0.07171064074481688, 0.031223909013093482, 0.0336450724411876, 0.0453168279942005, 0.023008458721902103, 0.000600593181931594, 0.010150378671354585, 0.0231848179077309, 0.07663663206321579, 0.009528333471427041, 0.058339679193112164, 0.03178484050647146, 0.06306700476054704, 0.025086977834542914, 0.07301199430179212, 0.011890423859679892, 0.12773933910554455, 0.02837108951362391, 0.031834540460559155, 0.0339538365181896, 0.062889241718597, 0.010559457173991588, 0.037257606013407635, 0.03274373169387541, 0.04183536823538523, 0.04983643265140634, 0.023335375252269933, 0.05468746609685402, 0.026244054052738414, 0.07110044405224823, 0.06767829099009115, 0.02538900608347068, 0.011829578283903821, 0.03757979578128265, 0.007806280815613366, 0.07287176190725259, 0.02319811719409641, 0.003125488386309195, 0.021232883333258575, 0.008576087139156318, 0.0614646016319673, 0.04238740736318212, 0.013234869862395911, 0.051875942566942786, 0.0566658805004291, 0.022240585812758056, 0.03984440148117081, 0.03717964507579323, 0.019336375220107938, 0.005831274066886475, 0.009391374187543988, 0.05814849046028911, 0.041686486708180565, 0.06205111854679643, 0.022785370087912007, 0.04774070720398619, 0.03862775809642288, 0.04962290862515088, 0.08016836634206195, 0.035282734766482346, 0.06986459101279897, 0.09692158309682723, 0.03288719314901579, 0.033184550176825256, 0.030262416957186598, 0.10327809805711431, 0.03482760193066732, 0.08258563421306112, 0.042346486776706674, 0.007614514644017384, 0.03753641605257027, 0.021324005661412113, 0.04199583301200502, 0.08676214639337794, 0.03940041522465406, 0.006793919563924353, 0.04934490680874837, 0.02670360338543692, 0.012586933763457403, 0.054988251368124644, 0.04893815242535165, 0.01983071452066783, 0.020551532394282764, 0.07118175662453137, 0.010234557370084428, 0.02847414749163774, 0.017903007476800875, 0.024446271690389803, 0.041531622034287265, 0.03155959533497451, 0.05234382693625746, 0.05404444636716958, 0.05923876381148735, 0.0014046186181311045, 0.021537091102330916, 0.021590564039445693, 0.032424085337909005, 0.06229838108523719, 0.0687471981490812, 0.043151197023689754, 0.08645719743423885, 0.0633960395240255, 0.012692734336240158, 0.06089896061307481, 0.03484882639660951, 0.032567734484590834, 0.009020831822718104, 0.039359555925212564, 0.05286022765381683, 0.03486262747056542, 0.009472794969746423, 0.05955885832888946, 0.08704803508496092, 0.10029892767629317, 0.03194892887897309, 0.0032804241627379656, 0.054463301109330314, 0.04648090625602392, 0.08179588183279961, 0.09079871729256646, 0.008037150030084437, 0.05758730041223669, 0.04531594316264795, 0.03121532499790192, 0.005902779277323956, 0.08065261817987888, 0.0024326904179272995, 0.024397186521861344, 0.04975941017149918, 0.02893957846437491, 0.06591968253375062, 0.10529990368072065, 0.028420929278757785, 0.050258481980211316, 0.02660280919723934, 0.020491591759867245, 0.020009216837464802, 0.006588161754001293, 0.09441856700446337, 0.041307840090725696, 0.02116248751389644, 0.03254361037585524, 0.04585194807018965, 0.06074329154686101, 0.0894393555579647, 0.029413603028402697, 0.009093376518707843, 0.11643600289619739, 0.12545924693826707, 0.03877584672262592, 0.07885854751352342, 0.004061846055030342, 0.0038239405623772334, 0.04731018494273867, 0.036380094430980184, 0.02837486058143118, 0.04248785681181377, 0.03402619735307751, 0.008389254573792701, 0.07021278563526369, 0.09107598749500129, 0.03977284503860339, 0.03890652983118931, 0.06314849353305275, 0.059466832016985265, 0.024473565487912106, 0.06354984316614366, 0.02274298627350119, 0.0631270085972163, 0.03099433736004416, 0.04431678830916363, 0.01741603985729237, 0.07445403990606148, 0.029666352671601122, 0.06923020126358156, 0.007559496603320323, 0.0365192657937446, 0.06510424322538799, 0.0136478295579793, 0.040347242442470406, 0.0430137723413927, 0.08109733988080295, 0.060802100286368406, 0.021922291601978002, 0.02823441176705303, 0.07760907343078045, 0.05691388614415642, 0.03054730781924821, 0.060568458791221344, 0.0516667431070199, 0.043440016001583114, 0.00039743755722508557, 0.08800203671618816, 0.06243426593080644, 0.02547930486710562, 0.07858133093724329, 0.07125462690788893, 0.002872460557433266, 0.038295019297830524, 0.13041698494024817, 0.12829153528136591, 0.14212823232575772, 0.1177032195752667, 0.1411168736916396, 0.11752195551150268, 0.17445807735766136, 0.15882885714452114, 0.11057156153143415, 0.10766408165856715, 0.1449630334372482, 0.18875122490909793, 0.25372165555675186, 0.18561882928254145, 0.22625542696445222, 0.13250056023318924, 0.09255116640199577, 0.10941659971590965, 0.14461832451483897, 0.11141333128175429, 0.2421785491488634, 0.14645612347991238, 0.10734695190143202, 0.0911584415382916, 0.12396479325909769, 0.15643581297368775, 0.06709471585289126, 0.18037673476482594, 0.19738322784823759, 0.12120902177787597, 0.1230784142089467, 0.17348511505030817, 0.15425462275743484, 0.17122783698141578, 0.14536020406071218, 0.14322044387940439, 0.11202585688161273, 0.11730110002381187, 0.25451276391263933, 0.08312713580145951, 0.19561730325222018, 0.11353473599639632, 0.18220837438298812, 0.12975018201095442, 0.16026746301401049, 0.14074190429622127, 0.16605761683275624, 0.10578461517129215, 0.1377802696679869, 0.13253960007381055, 0.14581627152379484, 0.1287495026425008, 0.20819219219828808, 0.17588716841513113, 0.17630421135935093, 0.11187728945045702, 0.10871772068522631, 0.12121757131911094, 0.1255995636024783, 0.15860048633429313, 0.23061386970502717, 0.14079306364780472, 0.2118345572342796, 0.19891764067353743, 0.16211963378854338, 0.1872950296608671, 0.1564584278892125, 0.24762823817230042, 0.2004706694353973, 0.12237876909033907, 0.0715402627904569, 0.1232439811311422, 0.22930888489129084, 0.18670048414459153, 0.13488706201314926, 0.162616211981062, 0.1600245671767381, 0.1580998938410513, 0.14321858994662762, 0.06050353283963858, 0.16278289739162694, 0.1299857234041537, 0.11291464144784598, 0.18963365094555965, 0.11000596647781712, 0.1586134945072474, 0.15176618531827005, 0.18007083585666073, 0.21417972090984547, 0.2268185781975908, 0.20540415309369567, 0.14526949925047739, 0.13056159169683534, 0.10483323356076595, 0.0998067238458222, 0.16284363284226389, 0.21159005261236624, 0.11596554064101751, 0.1583768193039202, 0.11503423053410747, 0.10419838415879397, 0.16628963422150383, 0.09844412155930074, 0.06673562746014326, 0.1296748449244807, 0.07538850629521955, 0.08068043483240951, 0.13057668362894367, 0.27475899686255767, 0.1256368644235115, 0.26179890358640306, 0.12112069950108567, 0.08981592607714477, 0.1439699843045204, 0.038976615384942105, 0.14565284964778732, 0.12556557228127796, 0.11697118425922048, 0.16463954211963763, 0.15960043025833948, 0.16289201895556144, 0.21195244284406786, 0.08314208217686223, 0.07669195893310732, 0.1812757236222106, 0.16211362765921702, 0.09198546409606935, 0.16693812764940724, 0.1714313558993801, 0.10629928836058225, 0.15149048559608, 0.09832316393693609, 0.18050790433922123, 0.13668035126982198, 0.14015615346931642, 0.14047918210346855, 0.13524290985397755, 0.15855449041531933, 0.18299695464872545, 0.1671047824164552, 0.17523990072790654, 0.1328769545521467, 0.10628783534611426, 0.18524500901900953, 0.1882693862482425, 0.10826670940244391, 0.1433345756583637, 0.08307409953446158, 0.12139253047925812, 0.17318908335460773, 0.17831050370249057, 0.16829097763665263, 0.08163414535022552, 0.27197411404021327, 0.15863048633740795, 0.12589545740235236, 0.1931523387470553, 0.11438955222406696, 0.13686094883709185, 0.14596938185634153, 0.12802169613179662, 0.1447033755961926, 0.17183891467509732, 0.19581872308927198, 0.11070650025841691, 0.12315076355251575, 0.09040156199086098, 0.19595251268436834, 0.08727025420915696, 0.22728599908371128, 0.17989010039356448, 0.11108534605873209, 0.19033955500250865, 0.23744666918871865, 0.07458075084873746, 0.13870092349187021], [0.01578057141629078, 0.03277239104312274, 0.06732489463062057, 0.0690635311747751, 0.029605946638771606, 0.01345857136672543, 0.047272956900058255, 0.05372507580285592, 0.02448204033557446, 0.04445624695489964, 0.05259668191654548, 0.057926133440266696, 0.01824651938682843, 0.03557584383675168, 0.06025441253798143, 0.049707676253972516, 0.026978856861411084, 0.022839390777892644, 0.02478082994780233, 0.05391532990841135, 0.08591872189314136, 0.04336958187782476, 0.009409292026483005, 0.057473099685364196, 0.06153703141476839, 0.07092216007050968, 0.024035255942914276, 0.016568558921496716, 0.025378085500110063, 0.04468780469089266, 0.033201480719951854, 0.029910690669390946, 0.06874760417568107, 0.03247727099205217, 0.024748284617559086, 0.011148306826550153, 0.09134268568408105, 0.03543576082935737, 0.004559238215968494, 0.025674331700429324, 0.05862873565826205, 0.06415822039989215, 0.0650824633457007, 0.09298790546674883, 0.025890531288760326, 0.010272515111512715, 0.03866700478078377, 0.03239501613162218, 0.12265456074308004, 0.14548328374662708, 0.07271963216724896, 0.03764305166119049, 0.013094991783521349, 0.03156167143324931, 0.08128454878685937, 0.024178506723875483, 0.015553585309985907, 0.039898134888179844, 0.027387672021324118, 0.03241551664447592, 0.02950839491771354, 0.02710134474440448, 0.045758029521112485, 0.08563412022927115, 0.024465376008001548, 0.031004183505090977, 0.004823165560787123, 0.008770395765051005, 0.026321149310998382, 0.024167034557209383, 0.033827569906509695, 0.15593365766108036, 0.03542418141038187, 0.020127893433034904, 0.032945737588189306, 0.03611896187067032, 0.05420894842715033, 0.03208611798923343, 0.09353545914974906, 0.07982640767530089, 0.032166932604365775, 0.00832114648449445, 0.03591178105242791, 0.05018430551694286, 0.05236705089168203, 0.042003279386629025, 0.0450528800607689, 0.030658053489582195, 0.019466131362282944, 0.015423933547290583, 0.027824437899154522, 0.03213068706944826, 0.053832052320602446, 0.03816029890590618, 0.06858620477179367, 0.020260915024987152, 0.03862352546064123, 0.012838578324825054, 0.032645492408905304, 0.033818480273288105, 0.024884753605170597, 0.027765654057504672, 0.014181683673673581, 0.03046913237701501, 0.02890756939567866, 0.024238841893572, 0.028827120587530158, 0.1479755516254133, 0.06076934619716579, 0.051653539581644925, 0.07424509708559321, 0.03443053089863351, 0.03308017835802129, 0.06391550459328198, 0.045762557100744984, 0.082992740996903, 0.10222069753874695, 0.06741540025799506, 0.1050545410403321, 0.027748099152719783, 0.017308712854320486, 0.05629743434368603, 0.012715589611851161, 0.04405134267384007, 0.02108800653067808, 0.11943467787557072, 0.06445437083922087, 0.016746155339323224, 0.03770214768366949, 0.05866285338396988, 0.03194802681044225, 0.05769745236442936, 0.032421921139522906, 0.05971505982621063, 0.04798636095778597, 0.002228816944895493, 0.05446089176280845, 0.015376588355960145, 0.029550083507333073, 0.045754336977317456, 0.017011650770361868, 0.014988791775859654, 0.06100589882642512, 0.06573065799931366, 0.05155444610863925, 0.040986856911331415, 0.023989284921798016, 0.06573703185084366, 0.009052743215204008, 0.03980684785112258, 0.052181293722242124, 0.029878951646688006, 0.02802379312925041, 0.038662147783343835, 0.01098382679159723, 0.06017093193687259, 0.04053610226800365, 0.037618352986511686, 0.012310976444202806, 0.04031581751581642, 0.05443579855284864, 0.024153583968478828, 0.060071532028697194, 0.045371867581120426, 0.04730008407345703, 0.05381150584247324, 0.03046009636994812, 0.009696192911735946, 0.06622217235065277, 0.04543090231656548, 0.02463100804767061, 0.021959931416917714, 0.04184748774634735, 0.025081368155717373, 0.07486834791639159, 0.03836114417701479, 0.031508744333780585, 0.03177807978053968, 0.014732905960221206, 0.039421773755983006, 0.039802956124467236, 0.05221182615646432, 0.0343347622472192, 0.05534610252887492, 0.024416254450296684, 0.05855965367969006, 0.05673662872023641, 0.03129074443882752, 0.09453636834457999, 0.027000705689011563, 0.05078233290283431, 0.054675863695240794, 0.044468730357625795, 0.012249191453109586, 0.015694897888498684, 0.026028542028319453, 0.03301746257010006, 0.03362593939527869, 0.007632930440107181, 0.017454148901085702, 0.029608670081342423, 0.0381645621852048, 0.03171902397767671, 0.0781265811453904, 0.08305247287235915, 0.017386068582474705, 0.003902489472473521, 0.04103697821377747, 0.05862105179638152, 0.04252756697936885, 0.027064938331022862, 0.004807671432518551, 0.05428086110060254, 0.15036995943275192, 0.03901082121076123, 0.027104993238143867, 0.041801537792649, 0.03875205969257701, 0.07651957382838573, 0.07598409369107216, 0.021720111422661333, 0.011904736297325262, 0.028532555950204694, 0.02667429477667376, 0.07755890233261932, 0.026202158619379325, 0.01211758616620735, 0.04575815975605961, 0.021695968161727634, 0.01161904200055306, 0.020372748540173617, 0.04604921571069187, 0.018357176957051122, 0.041148459328518766, 0.03803413188565643, 0.035487188311714324, 0.07823807758189018, 0.024840628855951855, 0.043755946831116756, 0.06770244574234371, 0.010993028465177744, 0.04462850182467411, 0.017296447786652756, 0.00310219859520364, 0.02587328473436496, 0.030299426664808587, 0.014754410048255758, 0.08978727438877668, 0.055920886807143695, 0.06612948337269407, 0.013029161848187929, 0.025425152026958046, 0.06464450620114803, 0.034787654275855714, 0.03349358621504038, 0.024267311636058074, 0.01010189966989621, 0.0012640372944823016, 0.03393868329904733, 0.032172011767303756, 0.023413556440162565, 0.048502164126764384, 0.036718647836917834, 0.03867901320899687, 0.0268126291883809, 0.0181467191977126, 0.024031515518623977, 0.06608498898605186, 0.04821942022611057, 0.14994658860227755, 0.028187785740761508, 0.04814766843112246, 0.011533469979410932, 0.0456930652651335, 0.060710966466896, 0.029610864923245488, 0.056559490039944656, 0.040549332606455976, 0.0283230155811555, 0.018756712876981305, 0.03136457424731024, 0.06167353679155631, 0.02728109578451803, 0.09175775212145622, 0.0202509367297734, 0.047416567742343874, 0.07762856270757414, 0.01859362424922086, 0.03254600057017899, 0.03295963442313575, 0.02553352665516638, 0.035446443925461465, 0.030489858885806416, 0.03064018065830873, 0.03211467966227041, 0.015784730316109715, 0.03268917857278739, 0.04351436866507415, 0.07643361110240221, 0.01162784530841295, 0.05641034421240611, 0.04467241398449387, 0.0451619633203072, 0.054426616989076144, 0.010735094321951752, 0.09811278853204944, 0.013971522773405718, 0.04654934089029989, 0.052418738843933235, 0.04202803551790215, 0.058382511168958685, 0.05680731565300977, 0.030783423778390696, 0.044006446091037606, 0.029457494120804534, 0.024105986925743283, 0.05042381141515029, 0.04909049666997406, 0.055128070075185075, 0.04088178412207673, 0.0355166252402048, 0.06490296128416254, 0.016055092320687348, 0.04852174150366937, 0.0021117388396599, 0.012316772856959894, 0.08829237637861122, 0.04105894195456659, 0.02893657539971173, 0.025130347987156243, 0.04036396997229707, 0.0568907234757658, 0.052837574433895855, 0.02712573506869376, 0.024707486605151527, 0.04320484999146673, 0.02238249210941215, 0.044595031443262295, 0.03575502414136164, 0.018966530952903054, 0.10819321858786768, 0.0171250892397497, 0.06547947309070057, 0.02114058314492145, 0.026741551550766154, 0.033678217235231594, 0.02834528192667471, 0.04141700378949604, 0.04162862791769928, 0.07416740044831269, 0.04591355686106029, 0.03883638299040256, 0.12036175917713873, 0.14892369268401978, 0.13223745499647435, 0.09190556878644614, 0.17141503822659293, 0.1227185520673952, 0.11279386002570392, 0.13146902284314557, 0.1452813889350622, 0.16934597263893775, 0.20885825968317448, 0.19290450930355058, 0.20063542430439305, 0.14003433016759737, 0.16195130894982046, 0.21586385795906668, 0.1669997211185194, 0.1774937314011397, 0.08274131094015415, 0.162116308966952, 0.11790412613340925, 0.10801756994858866, 0.05802325806730698, 0.13226031506013486, 0.11522427396548372, 0.1806138849426662, 0.08499272843642582, 0.1494180338997995, 0.09556329388531948, 0.1625327237190739, 0.10229811838437473, 0.16985853142555685, 0.2601522742019546, 0.22739682136283768, 0.12327264048038952, 0.10337310828148358, 0.14780215528463164, 0.2566658387020711, 0.073941090414601, 0.09565401401731277, 0.12440557726809096, 0.11340514456312503, 0.1513016908880203, 0.20266744188003002, 0.10920099959137941, 0.06026390819780289, 0.10392564919687088, 0.1510743619573693, 0.2937382736033009, 0.2341408006125881, 0.18187190856664412, 0.12203789826843048, 0.15918605330009616, 0.13409500370823568, 0.19379327854802533, 0.11033883934179622, 0.14608104683218465, 0.14462036230871755, 0.11426042810442949, 0.11203219242874654, 0.1299774190110545, 0.07910210218641066, 0.09546184852238625, 0.23492861479040117, 0.09238435841736295, 0.23100958476143502, 0.0844354224541495, 0.16265379625462717, 0.11168715408852986, 0.1731634653744198, 0.15770425539343588, 0.21777152414283446, 0.1545789843845752, 0.11480721569950543, 0.12208842176703677, 0.07963031981020205, 0.14548279345035553, 0.1094975905312646, 0.12046825305949296, 0.17657543712806317, 0.1230228958170741, 0.07826693611399782, 0.20025811067992644, 0.14697706326842308, 0.155859530993527, 0.13942034133980352, 0.19021756316144622, 0.10834960011585106, 0.13535918667912483, 0.10679174500006823, 0.18882478467158734, 0.14036272141721942, 0.11740586254745723, 0.25571163022710436, 0.1278205444255183, 0.13816717471326553, 0.1842201672374241, 0.16717238201489373, 0.15472532249987125, 0.1223326505972974, 0.12720251065348426, 0.1800250697640642, 0.1302982413119847, 0.11543222853252966, 0.1301298858297448, 0.16104519547474, 0.10278263835296517, 0.23660162824296185, 0.16225297905264363, 0.248638033987053, 0.1959561745846464, 0.20741723297584444, 0.13149333847386221, 0.14717039321699452, 0.10414656597159563, 0.2648103645732326, 0.24918898910043702, 0.10487918351446429, 0.2850697435919316, 0.16000918413121856, 0.12485011510791318, 0.23269735306741732, 0.17610988549647794, 0.10558108859244855, 0.10434510531805216, 0.2621437044393632, 0.2337378077208996, 0.14926363653954, 0.0882074861757217, 0.11488942459465996, 0.11849657256877232, 0.14341752765880478, 0.15730687026535312, 0.11740746367121897, 0.11542256816380447, 0.11485350273189046, 0.11999487967020082, 0.13266294022961972, 0.1295057539978335, 0.20566351982134007, 0.15452902013015363, 0.08592210800176667, 0.20444016933681505, 0.12286601633193994, 0.30611279991365253, 0.15077878991442342, 0.10678526389622882, 0.26393736141823954, 0.07462549804439468, 0.10886913030258111, 0.2102513139646861, 0.15705985287504812, 0.11016625505421432, 0.12121280625222192, 0.23997825269977893, 0.18129407908887635, 0.10126621327212743, 0.0803452713655368, 0.10601867801479756, 0.1649397260118877, 0.14956679285293625, 0.11093868618650783, 0.14155072460491813, 0.13632796614641143, 0.17883680610647126, 0.13418235305336215, 0.14498840626930037, 0.10896460784058418, 0.11501975913321781, 0.09698584255191589, 0.17984019742617685, 0.09824847036431875, 0.20470765659645682, 0.16533775465382686, 0.24163450414855636, 0.10800771039700317], [0.05284671386283252, 0.014886929852617605, 0.016715697598673643, 0.00512442053971632, 0.019629823284283764, 0.04850564599638024, 0.027534036949697523, 0.053625756333912575, 0.03368560232282166, 0.02607354011777188, 0.06534092608959445, 0.073379187904779, 0.020190613051395745, 0.04160934931508476, 0.044670697947543477, 0.07137658044455514, 0.02182611309352421, 0.05648316853048821, 0.04084539111523379, 0.06858495604847709, 0.0406498663247593, 0.014947116592778795, 0.049593333800834034, 0.01425004552959675, 0.06910356692969799, 0.04947174415593186, 0.018713277606894414, 0.06696780572735495, 0.06089873461713714, 0.033089336939156055, 0.022134486465684833, 0.04835411380495756, 0.05229244158873635, 0.08977169982127606, 0.09699381752720765, 0.05072236737056125, 0.07993239593962509, 0.08348272317239354, 0.015827486640773714, 0.031056501564659902, 0.07288958877325058, 0.0396276100899183, 0.03264656876243892, 0.02914320846508828, 0.06501800470775174, 0.03735278094668062, 0.11532562739786603, 0.038322253723538695, 0.009583227501641358, 0.02112400308702021, 0.04505419773199866, 0.01099002252768485, 0.052293571568424665, 0.08015635408340924, 0.05501012317836285, 0.034328173891070395, 0.023473682850899718, 0.05123095782173257, 0.08410741424848957, 0.0053499908197761304, 0.05346919860570662, 0.02854071670181809, 0.021596664014542778, 0.03618590646393357, 0.12241401679573521, 0.019654717311383258, 0.019047897151340882, 0.014385477425680767, 0.04120524942634567, 0.03461785088743895, 0.13654864543387968, 0.040149787110426736, 0.1590779582939802, 0.06965418496439535, 0.030303935092242978, 0.03345554994959985, 0.024201384024514307, 0.025084357813841877, 0.022867833707301367, 0.03906270834587274, 0.05917520532684942, 0.013473786830511546, 0.013587428313199312, 0.10440348121788233, 0.012944109809224405, 0.022749806371247096, 0.057328385676467614, 0.02314859535545111, 0.016235167032948906, 0.0452292756357741, 0.0839200521248483, 0.06157769919222882, 0.05176253857151155, 0.023396982127920758, 0.025373362568056872, 0.04249832923373869, 0.014042142673485703, 0.03339292609222955, 0.09412109506346526, 0.021151494152183016, 0.047774223550673456, 0.02912493152243476, 0.03450579520675444, 0.03760796100381882, 0.026212916409056035, 0.04086452416114269, 0.09224026493968503, 0.004218373139719329, 0.06120358398484607, 0.04213518440543164, 0.10623870612753016, 0.019991658102240295, 0.08659740684614067, 0.07467559253376338, 0.07775216333327756, 0.11852816603476964, 0.035986352050977374, 0.0315298845300511, 0.020133855512305614, 0.02508945229853834, 0.02814271678817609, 0.11962760179754227, 0.1310169083937522, 0.02909409456826266, 0.019602952750339624, 0.03785916506463001, 0.031068852817219113, 0.05794567251277547, 0.017656534008922118, 0.03963897117383538, 0.027538824999224276, 0.012058641446093398, 0.07107940727784749, 0.06594884750102797, 0.04637064322108223, 0.030163637580229875, 0.026483933418808926, 0.05007305805901847, 0.039185657796840516, 0.036627586795798237, 0.016640935078143113, 0.04523983232737069, 0.00847634057619519, 0.05385434930963863, 0.020010559406552105, 0.054407008968654184, 0.054789405586498405, 0.04521352486805089, 0.041814101634607206, 0.10097250282283753, 0.009092251327069057, 0.03840049428324546, 0.025294836640598315, 0.021987523988730485, 0.039028862581378033, 0.01710555974333998, 0.05454924468311572, 0.007712735255594336, 0.04933322013746347, 0.04111619936602731, 0.0540822489757932, 0.010018883509591464, 0.03494510066605384, 0.015252755988659638, 0.05711475439790276, 0.043509703189615286, 0.03385035719181742, 0.06991932033410958, 0.023929489844088114, 0.042303379009207415, 0.05829477111899084, 0.06552737656860583, 0.02769097197620619, 0.009915110196978336, 0.03037022659555078, 0.03919290115816459, 0.03422235033564991, 0.02669799945227081, 0.010687562396689769, 0.02031910514849569, 0.053467444264360016, 0.008402722399501551, 0.07024995622134979, 0.01191417833099202, 0.018278442270633195, 0.041224562502916784, 0.015955631125478015, 0.011564102962673193, 0.02701759984296176, 0.028673073712496028, 0.05628424614006954, 0.07342401937010788, 0.028924310332044, 0.052949017244240934, 0.009574299704493775, 0.03445097778533255, 0.034200248699034416, 0.021398775842821887, 0.06627854110012132, 0.012753462125997872, 0.0066837719209762595, 0.01721602770680141, 0.08753101521682355, 0.02177702984021556, 0.04169399436983851, 0.038283700348749276, 0.007610593231454973, 0.05273338647619371, 0.020481374062177156, 0.03696509066127962, 0.02938840639657311, 0.0341805755611389, 0.04785490026997943, 0.047093608056104956, 0.03280348655196928, 0.03874170984471998, 0.058299317850821444, 0.06637506051770141, 0.027683519855922753, 0.017253349595252546, 0.015936515316547408, 0.043862590100616224, 0.0579942156740975, 0.06720563006256858, 0.04137529413245859, 0.010345528078746172, 0.0306655534903609, 0.012492963503445349, 0.037278554687697085, 0.026632805369914542, 0.017697793589304053, 0.03095275985317365, 0.03478383532755318, 0.018034094696744316, 0.08768791002371619, 0.023024119474294207, 0.036647600842820066, 0.10177346306943125, 0.031183208676896272, 0.015457321574250537, 0.043557729241588426, 0.08810849995502541, 0.05073147615598095, 0.026387461881724097, 0.010662827332834563, 0.036412898315897876, 0.05111210311072008, 0.041359152659894004, 0.03839684770472589, 0.03918437076912772, 0.0413158227268967, 0.03799154122750606, 0.024172130957125657, 0.022265175319907647, 0.07089962176377736, 0.03183598836673604, 0.055216296590984836, 0.018658027345795306, 0.03093271324741504, 0.04166189528581116, 0.027225690390614253, 0.016711719687126817, 0.06124053623587374, 0.016446235747407043, 0.020827823919394327, 0.02241070904288321, 0.042807085649861444, 0.03488531133400337, 0.036372820426139145, 0.018042247787478472, 0.027230495677119302, 0.057660955935716636, 0.05772246130471749, 0.036904956589663224, 0.048790194034095735, 0.01634257830559246, 0.00835750118694118, 0.0523150718260196, 0.05062202900467862, 0.07525619524981707, 0.020638477628029162, 0.027868834609586387, 0.06257205450486752, 0.06712635528416404, 0.05474708305912153, 0.13005949767126193, 0.07405875385889123, 0.051851083013799884, 0.10509195677455395, 0.04342760920764939, 0.017450220785253955, 0.11032341799188046, 0.055682384484117074, 0.061777981388713085, 0.010893129642241666, 0.043393652360405655, 0.0038922957150310643, 0.1253994767584147, 0.02676833206937919, 0.04220045892701995, 0.01529105463921423, 0.0539580776145862, 0.03240302175043091, 0.037272108057814266, 0.1701635263499714, 0.010228817456311757, 0.08663832360217649, 0.02044292219403771, 0.04632784188875268, 0.06537960586889137, 0.03379537506149181, 0.02887381364651505, 0.027903620747008154, 0.01600070295089315, 0.04066665131118029, 0.08883783098069892, 0.08860846425616935, 0.044783220941861795, 0.06643394203556162, 0.08876698316946145, 0.03366882116684029, 0.023102746908402732, 0.008167551601335647, 0.0443460988331466, 0.0379998532814845, 0.06671364073671641, 0.02063516429775665, 0.019059210354762695, 0.025581930005442233, 0.010587668361803217, 0.023678513694434397, 0.06172910880958361, 0.030949718484114257, 0.027590760014831062, 0.062458064452174215, 0.031247460471105673, 0.01998421172761629, 0.047960984295294176, 0.08621672243480721, 0.020788678741683404, 0.05744601081636164, 0.05162701378726671, 0.016174695882645827, 0.07808446163131345, 0.025613866295785676, 0.07725763825639602, 0.0043904355299028185, 0.05224790123681869, 0.03426195708133521, 0.017293147862918915, 0.03035062240556844, 0.040888062212616205, 0.22201715277567988, 0.1663109314657988, 0.08924272377043964, 0.12796197957809896, 0.1507199696835972, 0.12556922652067679, 0.139236694742595, 0.10853999594767248, 0.1521744335731191, 0.14601566888872655, 0.17613279152541392, 0.11604107691035156, 0.10128574851419657, 0.10000098076078201, 0.17186885339117822, 0.1719373263298504, 0.18349478922543988, 0.20277654812220605, 0.06975451183895912, 0.15706400507159773, 0.15262516906424878, 0.11961483877272376, 0.14479155231627727, 0.16446302014012493, 0.18170969710955698, 0.1192269761175398, 0.18542577512562278, 0.11199852286447441, 0.1893154486653305, 0.1666480407959992, 0.10100452529807245, 0.1204824333469714, 0.11412511399436383, 0.21651728499320247, 0.14347199651022113, 0.18497441144239518, 0.15600871895590138, 0.16634968019300894, 0.09222416943239589, 0.14723043918849962, 0.19297704250822145, 0.10467688267629956, 0.12009446343947804, 0.12337400923453032, 0.09711831447578247, 0.08600833885852369, 0.259637585690906, 0.1634303642617118, 0.17577522764763526, 0.24125345201501924, 0.2480117724307122, 0.22714673962083556, 0.11658633232957895, 0.09885270689283648, 0.11751160566364566, 0.11727755814189873, 0.0878333977814163, 0.10383019464150553, 0.1480343105692056, 0.1333508565421066, 0.13324388002436008, 0.21867985927289535, 0.10692332826194265, 0.1896873537090517, 0.20099871851984533, 0.12442407063058308, 0.12151319698821153, 0.06983367170417501, 0.1459588711300204, 0.1498464455888156, 0.16352128357656542, 0.13289279725042083, 0.21432844921946528, 0.1435300506531231, 0.16089016992238261, 0.12355407820113244, 0.10412253379341095, 0.1611213446144135, 0.23905386036682516, 0.14064176128275935, 0.125110630967444, 0.12494774535298349, 0.1513138563642579, 0.15688766695318684, 0.16169548154838626, 0.11565378116023158, 0.2254504217736183, 0.10970818044077005, 0.0990117620676756, 0.16798633511268324, 0.17229171860362255, 0.1321551771534066, 0.21504278024358137, 0.10098564123073894, 0.13872298682408948, 0.13680877824944837, 0.23692349242346905, 0.10235105505994252, 0.17061407797999922, 0.17380310282591852, 0.18661425328783451, 0.09249539520110815, 0.19600308980912934, 0.1704516213747763, 0.07662961469782938, 0.08169328733797997, 0.1942411182268012, 0.22002992070009633, 0.16366169217132753, 0.18378358905113515, 0.18526003966408391, 0.0843280935359578, 0.20021530168671764, 0.11214623227715494, 0.13625938595542986, 0.23931474394855962, 0.2198220197592051, 0.20875629338045276, 0.14837823808193207, 0.15325691581012743, 0.07326032936332688, 0.258711262816383, 0.17238839889966673, 0.08513555020814942, 0.1358233440306879, 0.15040014329696857, 0.1398485998112348, 0.15164158877826509, 0.19494827866794603, 0.13756239426232156, 0.19077945801038898, 0.2251354523844296, 0.15324786065086243, 0.1360060560006288, 0.16656055355504637, 0.1090136144851004, 0.09013143938875968, 0.17691513583544763, 0.2521348882827067, 0.17267073294328106, 0.16743758633252115, 0.13240665317543093, 0.12586168058577085, 0.12473900171537554, 0.07439377942993756, 0.13326194437761463, 0.10010056453005922, 0.1362354993339508, 0.0926960489502357, 0.1794733638845144, 0.11053345631808044, 0.13560629599998075, 0.11236134210541365, 0.1572603534065908, 0.13376083615566456, 0.11744640392041016, 0.16326893421430744, 0.21127957249841384, 0.18137484007785398, 0.12367335043006367, 0.14118435071601024, 0.07628471425343906, 0.18174198005468617, 0.124570561963464, 0.14412323253289347, 0.14604251260959333, 0.10066955335318081, 0.14391356958977639, 0.13056413510874396, 0.18094901776602193, 0.09403278810843345, 0.12504255639449244, 0.1368359896925188, 0.07768592737134426, 0.17513951256630883, 0.15609709485884637], [0.03281953226354334, 0.03692689351737499, 0.014438470600232964, 0.02280345933902408, 0.04316852593253698, 0.016725982329057112, 0.035071428564767686, 0.07041686379741277, 0.07983683413195033, 0.04039015485754898, 0.021778588829141472, 0.06474756800960149, 0.01186057611654002, 0.0418477826901982, 0.027819312770941088, 0.015429854449335367, 0.06131517618233639, 0.06582052011283175, 0.030476232096853278, 0.05405819764541042, 0.09434994084820633, 0.0509503513063875, 0.02967864072190658, 0.03905285262472687, 0.040164304476591854, 0.08283213832445684, 0.04136317845193609, 0.030746375766372493, 0.018462155900535085, 0.12418513546787924, 0.023616527605261055, 0.022647016524006764, 0.0521370291619772, 0.03407711538696482, 0.02560899589180706, 0.03608546084574154, 0.004893865421294205, 0.07671235219365166, 0.014139724080450835, 0.03816978307440877, 0.03318387601945189, 0.029028829622773394, 0.05345732424288027, 0.03206919127654645, 0.052975439616749366, 0.028083676307071603, 0.02736803718782481, 0.03155325021174166, 0.032662047568949006, 0.04068816306009408, 0.05740074651135553, 0.021516088801886768, 0.01101794068686544, 0.11088690630370572, 0.04850104946883456, 0.010890306608240691, 0.024606255746837107, 0.0687356532040623, 0.030784998089075092, 0.03460693796495757, 0.04613177317585196, 0.0843601466547097, 0.02791977754133123, 0.035554355070475614, 0.07243393499764704, 0.0648249045855576, 0.0544562109655911, 0.046498292621465466, 0.024902168698909304, 0.06539861251029276, 0.05353156199318267, 0.039179283945310506, 0.05041987372321948, 0.019287755449993477, 0.09213524194614542, 0.07116335519259015, 0.05050985841080547, 0.03131329998253815, 0.020457152277231216, 0.030888829815892443, 0.03428069942240273, 0.06561041283871859, 0.0494317160618882, 0.021539262961596254, 0.06382489554403771, 0.023277797999100822, 0.057744279488801, 0.0530734682275403, 0.01452610052506169, 0.10379943621134567, 0.04569375091382573, 0.06155714888366, 0.061844470159661394, 0.007913888398287518, 0.032019746046693574, 0.06556489189425785, 0.022597751324816097, 0.0814508205099452, 0.01178195347048102, 0.035842277725497564, 0.04007209430358583, 0.04206628245752185, 0.052836011614530325, 0.020176197191880598, 0.04309466356531747, 0.02912223297772148, 0.05111626679858854, 0.07632768412511196, 0.06346967206486771, 0.029615622329255267, 0.0876188088929461, 0.07653761519900254, 0.05835828363835331, 0.03389493967857092, 0.05205118901006157, 0.0516682101653949, 0.028419776316431743, 0.06393045479912432, 0.03653109802173511, 0.046923954054833426, 0.04098259746247242, 0.03211606053575393, 0.11550762690603734, 0.035361392844107845, 0.03054826351393375, 0.043400501186448726, 0.015953713990447503, 0.022523180326266636, 0.019574469601314877, 0.037590107324743466, 0.04943924670618388, 0.06271466177197234, 0.016737852861443837, 0.08074966619812673, 0.06174169946461917, 0.036695052328849995, 0.07745483694898506, 0.06359346038211258, 0.04656798747037688, 0.05427538357194393, 0.05407740346967213, 0.07578140214806603, 0.05855121522120411, 0.05514232314101631, 0.0286541149515899, 0.006610100118127922, 0.08976597714448169, 0.029235322877103766, 0.0736788431963613, 0.07479273503826511, 0.030257904699312586, 0.03785799295010586, 0.04025435811209102, 0.029235468433809378, 0.05879180130338477, 0.015163891704662915, 0.04963141603155002, 0.0156372717972244, 0.06404661288064334, 0.05986764155808957, 0.06755605400089296, 0.02640229525915798, 0.019510110554796074, 0.08859812206919156, 0.007923614842096164, 0.036707156518053626, 0.012933109744241642, 0.026129173422833125, 0.0756574567827967, 0.012949071186144027, 0.0474193639632675, 0.012884458373000306, 0.02819090180339352, 0.06255048912979903, 0.0737604009167802, 0.05596809314503785, 0.06608588530892326, 0.06386660520107516, 0.02470492404104481, 0.05018914336218469, 0.03727555928391315, 0.01009452032796558, 0.0781804524482258, 0.03403361308418455, 0.0627905044764761, 0.010492679204851871, 0.013605349024968042, 0.05864830537428779, 0.041583018873127243, 0.0249146425255364, 0.0674932960781359, 0.012813611519372752, 0.07337688198012692, 0.032581696437010844, 0.016983594715354905, 0.02710139262489975, 0.03213823112028261, 0.020667656001845197, 0.023494972434315472, 0.02850023087023968, 0.06185552480840876, 0.06265999373769568, 0.05212277992658558, 0.02689963187872162, 0.09746730582968843, 0.022007017095963803, 0.06335288579125078, 0.03596224709443989, 0.034363084517779856, 0.025168420641773173, 0.08025730148919168, 0.0393942290646655, 0.005422764863338201, 0.07787189521496335, 0.010584793616867354, 0.024556327881591938, 0.03647400914961773, 0.03508403454156172, 0.02323840001237489, 0.03935599744680428, 0.056974770981938615, 0.027623908639314677, 0.04834220879861424, 0.05502828712304754, 0.016703015013087182, 0.04617920550968378, 0.05627216876394326, 0.028629422022570527, 0.021125221166819818, 0.01422229782497931, 0.009677048374508179, 0.09594685878724822, 0.02888656134957508, 0.02085989810556414, 0.021503413877179547, 0.039791319248897415, 0.038410051230100856, 0.0667040646376629, 0.03424363225818642, 0.032153326882830555, 0.05749325545865202, 0.03904314246028662, 0.08347198261969513, 0.02368976752604208, 0.022319450734123107, 0.028095265302146157, 0.07195198142360296, 0.04325783646274959, 0.02311743664435081, 0.018863155048400648, 0.017375293555819703, 0.05179640348820437, 0.09818520682353167, 0.05681838562351562, 0.01754207089693556, 0.03905019813006924, 0.05791227874015609, 0.05950098038621007, 0.049439767645972396, 0.01625021874544121, 0.10936755476699722, 0.07864107813445792, 0.1391704894241787, 0.02686182352443857, 0.08397778451082208, 0.06995040818207687, 0.05320885511595876, 0.06835507604503824, 0.043342450873986374, 0.02936650202759812, 0.008613278792660323, 0.03637694580961139, 0.03253206160039671, 0.09048665137661081, 0.016096675573217294, 0.018253481210840326, 0.008114029826115697, 0.02475744702913348, 0.02246874977924651, 0.016779608483756744, 0.04958361980595416, 0.03734051587901289, 0.05345065161705979, 0.029703571138182477, 0.022606099767970945, 0.01982191217041785, 0.008701010224139018, 0.022422468492520914, 0.06032700702968625, 0.0671802189261202, 0.035896489937459274, 0.01604082489070753, 0.02894484531885434, 0.04820643503579402, 0.011723184950589653, 0.02439889489793249, 0.030217725302903887, 0.026863459122156905, 0.05982658690622738, 0.03861490697149308, 0.0473199985290487, 0.07834582784844023, 0.01582629154361184, 0.06329329564206063, 0.05291007699504976, 0.022700115993258455, 0.03228252761126046, 0.01798125186694726, 0.04843023230111407, 0.029240323516029506, 0.05166728702944614, 0.04761423374856672, 0.011842574965539239, 0.001142677954762363, 0.03424528317766325, 0.048848294142273166, 0.033481401586604696, 0.06148290730291798, 0.025705555529003183, 0.07793948715252262, 0.04221369692635152, 0.03161564998839411, 0.05460532998005229, 0.036992934126887596, 0.06625907480596535, 0.044414640719731974, 0.03083290348220016, 0.03940965424502089, 0.049016841146494114, 0.03277094696738547, 0.05607752880502132, 0.027449648534398408, 0.048435108450752114, 0.036578909569089456, 0.0394433391310515, 0.0355163571094313, 0.05880398210138083, 0.10213677260664203, 0.07047383775634151, 0.05634910314373913, 0.026725936763649507, 0.07088176425426237, 0.03970825999614693, 0.024241603640539032, 0.01303337341655166, 0.028023973159912615, 0.1028327941293678, 0.016456034011958588, 0.024760898255232363, 0.05965716273133313, 0.023086942514524828, 0.010196874462698978, 0.13330319055145787, 0.13875661808396542, 0.1125840285432435, 0.16447242769983508, 0.17031409327060948, 0.1183264933887028, 0.1610733109015611, 0.11535205743125371, 0.1842924552939592, 0.10213962245372035, 0.1243388816534031, 0.20514628789838285, 0.13206120880861438, 0.1667996649179728, 0.12071768362675944, 0.08271183187682783, 0.1494298316538334, 0.1567109917560893, 0.10727490899303269, 0.16453887816638718, 0.1398844833696081, 0.16402864828705788, 0.16149593096586967, 0.1114618706126367, 0.15150681859062565, 0.2133931937597452, 0.14469113351116258, 0.09443221103039481, 0.14449699150939144, 0.16433312227168392, 0.1775955291645181, 0.1134313064657392, 0.16719692747198767, 0.16257963894355684, 0.14631782928782125, 0.09916347045932086, 0.12218130226697653, 0.18418829797977404, 0.07311591412872076, 0.11014262124175027, 0.16392415389418602, 0.11595287720762915, 0.17003811775676667, 0.14327103632592386, 0.20760556803114955, 0.08580783066610176, 0.1251081258599316, 0.1782500900087818, 0.08543559620457311, 0.1392858929090923, 0.23068191363446175, 0.13872217477088974, 0.10410276872496452, 0.25624396940392835, 0.06994571972398028, 0.2418368586128758, 0.08478641329753785, 0.1229517568924254, 0.09131643185091597, 0.1259849671154253, 0.13939345165366127, 0.2554854351065813, 0.13721454437942276, 0.14230758883059025, 0.20860160490678203, 0.10920439336088397, 0.140945024848465, 0.11820781870835251, 0.1191351451580563, 0.1308809431089509, 0.19346240517352858, 0.0806730957100949, 0.11870769873982477, 0.10039148641930473, 0.14469928468667692, 0.27711477851675403, 0.21422588536816262, 0.23433825211419215, 0.13351505982779688, 0.12444244907988657, 0.162389955573505, 0.1600609716748999, 0.1257443159157711, 0.0993271298225849, 0.15154375935033446, 0.14392873813067714, 0.27929435994836593, 0.1455522623033293, 0.26848118211473193, 0.1410310718441202, 0.21104412303576547, 0.18735012670438136, 0.2000030493664165, 0.14465883524427492, 0.13243101477142305, 0.13670475883108957, 0.1258106821126515, 0.17483316932714757, 0.15595444928734534, 0.19006966222678462, 0.10592822601357776, 0.13776767518251173, 0.11110769284348335, 0.12896445159229541, 0.16194746318844058, 0.11073702886219948, 0.3025125543917379, 0.18911978980946928, 0.21215767779898262, 0.12858427279899198, 0.2501535244406231, 0.13115768471071798, 0.12722240595687784, 0.10481783519348792, 0.14167472359634217, 0.13575442676101962, 0.20920739659378607, 0.21543843401295526, 0.1552131366465361, 0.13667811429308308, 0.1294329296797514, 0.16107770824624648, 0.21374724895483066, 0.1663056301373628, 0.19915644560129414, 0.1288522350331468, 0.09959042658128085, 0.15448012839882605, 0.12537834805346307, 0.10753035335050476, 0.13881435046993917, 0.13086300132976425, 0.09091625816278881, 0.3318645696966879, 0.1566085504788545, 0.10538234240225247, 0.2916880691003415, 0.06251983029106933, 0.11421001185813259, 0.07670244667679071, 0.17445925713306473, 0.248710950235686, 0.14726114399250478, 0.16111253460328426, 0.11093694716691972, 0.08535191642060395, 0.20919068055527829, 0.10566704365755282, 0.18741081618974287, 0.21749836783255302, 0.09074274690881853, 0.17019041603611362, 0.1458605973710937, 0.09835397599325066, 0.18009115250841265, 0.12179480324829779, 0.17691902756210298, 0.1726647268139547, 0.18882712890063563, 0.15380875958550363, 0.132462470341594, 0.13581376793163438, 0.13550123470204492, 0.22546782729125794, 0.10843645916470598, 0.26270411307773284, 0.10888701845561305, 0.08583318817639544, 0.1228704826245385, 0.12110938438244405, 0.23107160723978476, 0.10367358328714486, 0.10784645654982138, 0.13642597943544388, 0.13161457954875885, 0.16444431227301398], [0.021810825808995196, 0.053637577070584225, 0.09978008696869498, 0.10652190585049892, 0.023257398992897044, 0.02628697221347642, 0.005866455218394197, 0.031158586611009897, 0.028721318099527594, 0.07247293653387217, 0.05292801111335716, 0.04310554201384226, 0.046268929727375514, 0.07444683867957323, 0.04588434592850747, 0.023343635595313484, 0.0882250602327047, 0.13046938535426894, 0.027777480539835753, 0.01955364350109331, 0.06080044553645196, 0.05717066732505637, 0.01645253873580406, 0.01079683430537942, 0.021826722133424015, 0.10771288145934382, 0.00943677638837647, 0.06914901126536631, 0.022082538043539372, 0.011074583312766928, 0.05353633089051132, 0.03859709542725356, 0.03281108231373853, 0.011778641097818413, 0.016335809918781443, 0.004484074456887621, 0.041124595689677426, 0.028298422243566285, 0.024558107120796077, 0.07118860545057444, 0.06258738392423238, 0.07480479326219329, 0.030238863583954594, 0.03218135803997998, 0.023380593592000586, 0.05507290025331801, 0.017884060207213608, 0.06897654189097305, 0.03484503426138432, 0.08015685970143926, 0.06486738416095895, 0.01859570417793528, 0.06688725158211685, 0.06422157587123013, 0.045422479179838014, 0.01883055226156308, 0.11264164601602863, 0.06222760988279216, 0.04595923868398513, 0.06864224410345478, 0.0381293221406879, 0.07131366164333398, 0.04416452450377326, 0.0658363321675889, 0.07851439017441966, 0.02372246798908999, 0.037655381846331784, 0.11231157703385239, 0.0434050249356416, 0.03290386705268775, 0.0438657004175888, 0.06303955966065969, 0.020477685348821745, 0.037520098379783096, 0.08576164322514689, 0.0193998858242506, 0.04914626787086168, 0.05755360403488721, 0.018582106117279302, 0.029885020978268118, 0.026013245167691382, 0.13709635233446477, 0.037553070804044124, 0.04140792181715369, 0.05013014310069623, 0.06955575032700455, 0.0217066646643704, 0.0038235237626659297, 0.018989664892996513, 0.035206279191639156, 0.06162708121982794, 0.012704055200541213, 0.04267814156088618, 0.03912852295944768, 0.07118121270210513, 0.14365889132022858, 0.025648748194197976, 0.021405701277657382, 0.06244906291906392, 0.028141960276350863, 0.053095527729319955, 0.023484553638545257, 0.0386241996180146, 0.015854219278891482, 0.055607418950286605, 0.05138978700063402, 0.026830186008385597, 0.00451161292374074, 0.046972501046595075, 0.00925255043717522, 0.030434589472509203, 0.07486515332974734, 0.01371238874496832, 0.17162801066954292, 0.014841497008268152, 0.035300672715229374, 0.052226944901649995, 0.044696492127954, 0.018731880136915756, 0.036397806383789554, 0.021125650176057414, 0.06032020799935826, 0.061057422069772604, 0.07318637889599608, 0.043905694037675864, 0.07664105239053888, 0.0335104133362972, 0.04551331805545957, 0.01262982223828834, 0.03986122477198801, 0.040296167360558625, 0.04247050492032882, 0.03572453384197528, 0.011995347261789345, 0.09518687658372427, 0.0720907659119656, 0.021103617487355106, 0.0386723788875726, 0.042439681372695395, 0.005409240059839983, 0.05906791471305394, 0.0237826939912573, 0.009669949612279814, 0.059658403793770465, 0.03613942790956747, 0.03060682710530537, 0.0595289234432482, 0.003282524201260399, 0.06107103545218707, 0.07745721182155033, 0.011081221464630819, 0.07628786287480786, 0.020656394509358272, 0.065863911332863, 0.052803043020708915, 0.021145597190385865, 0.06330184135285598, 0.09689767349271045, 0.050604554539125775, 0.057309673978917064, 0.05929323266290369, 0.02419977523987332, 0.06590329591305026, 0.023187424521893266, 0.051084673332591216, 0.019462507766401096, 0.05950370765922051, 0.027687290923730023, 0.0472032007641129, 0.053684224164293665, 0.0480142695408675, 0.04888282938589973, 0.03383716898820093, 0.06276833006150781, 0.04442327836107823, 0.03533999217794307, 0.04109377597248362, 0.08712952385746664, 0.0871553793249111, 0.04957132792520908, 0.05948408048660044, 0.03835046874178994, 0.0580278086295772, 0.0362202923204149, 0.08754557088738488, 0.03820320749054513, 0.05834768098148127, 0.02468075588225357, 0.040231865770634145, 0.028584598218120878, 0.03176529951874287, 0.040752522106612885, 0.016982663918526906, 0.005504317795707574, 0.029420725730878693, 0.031742207713485245, 0.004940288913090744, 0.025252470063165795, 0.06414372218592514, 0.015496050191652632, 0.023553819478219076, 0.06388349743980555, 0.029641590794668566, 0.007031033352588214, 0.026502336765969955, 0.041696932317028125, 0.01867869065233296, 0.0035512158947606245, 0.019226422450775583, 0.05430792315652775, 0.02276735553037255, 0.028615391122237332, 0.03445452860286159, 0.06324806964145073, 0.018110466001915838, 0.03598277058993136, 0.0027009820698895644, 0.04107312990292426, 0.02370460664913539, 0.05492601821559572, 0.01323861028668621, 0.021316285410355178, 0.008829003406478273, 0.1760783226739976, 0.009555575558014456, 0.02116205658943903, 0.06951614358131925, 0.028384003840807467, 0.03780810913491634, 0.05210252073142798, 0.033383518532519384, 0.03351132115048747, 0.0623028741909131, 0.025459133772059314, 0.0703931916805525, 0.06909579113726655, 0.07681135373610644, 0.009108653269527901, 0.027627534150416334, 0.047215063635620384, 0.0980972139645488, 0.05514008233383779, 0.019916849616434307, 0.010478906859193119, 0.014938764319184327, 0.054764136176316015, 0.048642289268994526, 0.023070163273763274, 0.08152578987421528, 0.005512570477871886, 0.07883550358876106, 0.027930098660891096, 0.026460048712549672, 0.0830462905428102, 0.03124127622633692, 0.051775857010075164, 0.04383222620573737, 0.009979236544290138, 0.014819165545275376, 0.02825496016040204, 0.019300338444149783, 0.006480902262527737, 0.04482584224352914, 0.002624283022727938, 0.09530709110080235, 0.07245799015846945, 0.04316084973153569, 0.012563865898447412, 0.0297937952282448, 0.0756059143872511, 0.061720026837241274, 0.06641202426004796, 0.07119235928140341, 0.08374099439430623, 0.020569790184738177, 0.01504425654157756, 0.0476428471325386, 0.02607401700750474, 0.04089543580888741, 0.05164640347263025, 0.04676168131071233, 0.02522927292081858, 0.052823758038181456, 0.04210580493353548, 0.03875201755774118, 0.030838086067007917, 0.021130813608667063, 0.01867800500364073, 0.05207321786832425, 0.07321886102398557, 0.018914689783066995, 0.030252065194109758, 0.036768638904416756, 0.049303369521493876, 0.05277600011698181, 0.060975052296153964, 0.021031890590224537, 0.04799708618872589, 0.06931734376496847, 0.061878461480861714, 0.010318803101507647, 0.018147383778986913, 0.1270885627356268, 0.021205602942274946, 0.042672993450035016, 0.008595604186637268, 0.035294226085346554, 0.029598975238660653, 0.08606201863937801, 0.08672709020996287, 0.06760061733544835, 0.04573843682244901, 0.01427886767252799, 0.023219627027790395, 0.009065643178238984, 0.013194878157528659, 0.09394019872190491, 0.03980463002658179, 0.02700747407582258, 0.06132798900286998, 0.08754976904920994, 0.015388749044148192, 0.0058676886199522885, 0.004681592991185045, 0.028833777891592156, 0.08552242460991107, 0.026776755206106652, 0.014276289786662788, 0.01555905900820489, 0.043850991529442614, 0.06640869943845658, 0.03967418823571455, 0.006591301278075985, 0.05976839486749903, 0.01842827566208378, 0.053237698326307925, 0.04344519858639087, 0.016630426267041795, 0.05748610019743924, 0.03423730437193186, 0.03313758515662724, 0.05039064363846856, 0.06210063847022192, 0.01846088610980059, 0.003892311276192026, 0.020479297963902354, 0.019501396304657383, 0.07734261272895722, 0.06705861012901991, 0.07595744915306568, 0.027117968852361365, 0.057951805046609337, 0.10037520705091377, 0.10823081052231212, 0.1955028956816081, 0.2786052178952002, 0.1510266040361697, 0.14708785490403253, 0.174713475749858, 0.09050413350304289, 0.15445371368719688, 0.13742036156115994, 0.1389867968616947, 0.07746928536723699, 0.11283441672041533, 0.17983006974381788, 0.11267239678530924, 0.10316767414370853, 0.15301392804230415, 0.19274992808218927, 0.1402989675801608, 0.14616511732099519, 0.1795491606237427, 0.20208685448573482, 0.14516181793184052, 0.1452544532836445, 0.1964355004771102, 0.14757398365726396, 0.12532597828295924, 0.16732512462523677, 0.17174756635100613, 0.10673307798682682, 0.14225836002057599, 0.1351276595866488, 0.13979288989738112, 0.11324702401555355, 0.13192594832470342, 0.10851763384116274, 0.14682280380399, 0.23156562669863626, 0.10558418358766264, 0.16587893448529706, 0.11593174084179825, 0.20263440816873507, 0.12704724761387035, 0.1435830792592418, 0.09666147326389629, 0.12926938522967601, 0.11178496819470199, 0.2887509492856841, 0.14633851366177683, 0.24614005109235165, 0.2112701342951867, 0.12496053136043972, 0.08152918364371985, 0.2801029504306855, 0.19796778357798056, 0.11503875811373997, 0.17548454324564627, 0.10448273301364915, 0.21953386344736625, 0.19543529608316962, 0.21238151336869887, 0.186931045966283, 0.15679811127483845, 0.15345631317505914, 0.3321207801420843, 0.16610508364054466, 0.11316452400698779, 0.1729733836386473, 0.17232925691191228, 0.12962941591057087, 0.08718997585557162, 0.1424857655600194, 0.1314875008838792, 0.1913678135362364, 0.29558570995446176, 0.14192232321346962, 0.10390527891896426, 0.18404730715818945, 0.12441445622713336, 0.18929168461791931, 0.1265739278507329, 0.189295208622371, 0.0773424135460969, 0.0943219633172116, 0.12647237523549026, 0.09664902433512673, 0.22196046226928312, 0.08200030473451461, 0.1775375056651331, 0.17218708631492433, 0.23471035634077367, 0.15797071609525912, 0.09467883005497918, 0.1387579970422291, 0.12057938177378909, 0.26136554296939607, 0.1648200630781151, 0.13622569340852, 0.22693378249964408, 0.1125249325207645, 0.09525865902222934, 0.1301593955365881, 0.11217620929763203, 0.1286263923130689, 0.11845583201295908, 0.11186364542452559, 0.17377630507032718, 0.10798646677886287, 0.1638009975994787, 0.23876927402471346, 0.09258606170694675, 0.12163284460022566, 0.16945841902446362, 0.24807039347867815, 0.11721962657306464, 0.12724716591859056, 0.23083765930946798, 0.12471076371448657, 0.13623776695420667, 0.16555737673995957, 0.11908205526490366, 0.1671835822203467, 0.2495124773873437, 0.22638547805047807, 0.15706486309007292, 0.1514160524933569, 0.21895680005752274, 0.09466497152442895, 0.13432737349742843, 0.09315512713886077, 0.12300755107595075, 0.1487272064532003, 0.20204583813826885, 0.18087092276302077, 0.14595249727849038, 0.168300706953291, 0.1295106722823074, 0.14717532682322687, 0.13376201593106793, 0.10148270205864984, 0.11206226904065379, 0.1084254198377171, 0.13742773132699151, 0.1582958131668068, 0.1861944677488458, 0.1384744832232114, 0.07925715838228503, 0.07917583814912266, 0.10009824328364865, 0.2129334337528675, 0.1736248801312139, 0.12284021449065018, 0.09319932275121251, 0.17522713770308804, 0.15882779994318563, 0.08519428616930401, 0.1308137878415085, 0.10313614962562438, 0.14196412097061836, 0.23258588727443452, 0.23408495280290806, 0.0709112816219849, 0.1416325121517143, 0.09812621805336207, 0.12267913684369096, 0.14513672089144108, 0.27924379814536343, 0.23312109162009534, 0.18216487591064748, 0.08100003905354008, 0.10918130347084616, 0.21663330134845551, 0.11069771322992542, 0.1414904028417603, 0.08213148196978916, 0.08266057293381422], [0.04508143598814646, 0.02865963653030415, 0.035864590036292235, 0.012977020946451494, 0.06008253688172949, 0.05969426819994565, 0.1010687847531611, 0.04650519890410285, 0.05468893698566864, 0.017196503956051126, 0.06610122238916737, 0.052467331800970345, 0.022351379363587307, 0.029257437920257933, 0.028535514964812228, 0.03953466447250497, 0.0656725732128947, 0.021896273340849627, 0.028560830340270075, 0.06158508811025851, 0.12490708906684192, 0.0023778607869791167, 0.030487857481104233, 0.09690935633355573, 0.02601736289028439, 0.0568745973249597, 0.034003364102494334, 0.06340536664450361, 0.01166723563425964, 0.10142941298263689, 0.0813455293856321, 0.016486832661734476, 0.08281356069229304, 0.012527008450800374, 0.043028956204051935, 0.028453137530314348, 0.08585768000733468, 0.0212779178118874, 0.034854663986592524, 0.06488865842261622, 0.06579777496235986, 0.024445645413511706, 0.038805609238484216, 0.11144915355309365, 0.023509493630920208, 0.04754552715307763, 0.034994321815188856, 0.03292743957811787, 0.06278322281075582, 0.03407475583615803, 0.1008002173095461, 0.04430581409964831, 0.05094301601451251, 0.013998711233838432, 0.024828053522674788, 0.05992780627322294, 0.1488243464019991, 0.01358780944194164, 0.007954783129295515, 0.05800434335645649, 0.009341794892304368, 0.010432246358945005, 0.021146527987213868, 0.014484190727554023, 0.07619994662461743, 0.04349466871410128, 0.05839587940323738, 0.05292832903984574, 0.009088097215299646, 0.03150993177006322, 0.030553511216215072, 0.07537784235131356, 0.0713362152718248, 0.03946642136021007, 0.06810556120810009, 0.026266146113254854, 0.01847822842518649, 0.07818602956831455, 0.035655896194399364, 0.054051195601782495, 0.061340510709992344, 0.05704051664760036, 0.05604243431721003, 0.02576530847187725, 0.03463658556762723, 0.03528329018022745, 0.039840391010887204, 0.02275232871573779, 0.03802206600084901, 0.06425942444512922, 0.05012226005595538, 0.04726385960595743, 0.013458471775295274, 0.011109142496641125, 0.0143948792397315, 0.02600223073856004, 0.046038789254042416, 0.021247992502345193, 0.021263942452928713, 0.02988895867019892, 0.053099748873782736, 0.07849030437008028, 0.0894555889610802, 0.028786062105228345, 0.04202192213626639, 0.02346178359021583, 0.026448683798192974, 0.05775525752875594, 0.029855677895548365, 0.05508006700584966, 0.10063251300204186, 0.014380299628922536, 0.014793090785162584, 0.003841145460741715, 0.05001927485629436, 0.019008704093134692, 0.06384624641448741, 0.03598709515626392, 0.06558330864795754, 0.08792526704529602, 0.029139745747670535, 0.01589146360094028, 0.025110898929978573, 0.030907533852563753, 0.06972856444096373, 0.030218238581813155, 0.10877402048678168, 0.04804441893112756, 0.021340223742769133, 0.02807323452866366, 0.043448197820614425, 0.03986230495596125, 0.014584532923876278, 0.03422231203125369, 0.05046760483134178, 0.010612955966573811, 0.06403149413545767, 0.006923797322557338, 0.08930617883320778, 0.02700063674109838, 0.037408188255804206, 0.004358236375640357, 0.10690788392938914, 0.014900686876517872, 0.03662200967570947, 0.08600636235167904, 0.05540198481251156, 0.03997763566252205, 0.06929431516196459, 0.021806104792161815, 0.022961583717035192, 0.10707569548920279, 0.03193271462805569, 0.0828291429206729, 0.03172492093947386, 0.028321289968106057, 0.034239736701091456, 0.020244643317475434, 0.02706073250831856, 0.02710992875959604, 0.03213917340842947, 0.038584351554633155, 0.048667631457529725, 0.07037077594788806, 0.025642755471410292, 0.047593365513509324, 0.024318984266550794, 0.01783777125960877, 0.05119917283375418, 0.017722381181233836, 0.05431315553705058, 0.06093128569303982, 0.07140780618834881, 0.057894402078443, 0.03769017372941298, 0.003251282656903289, 0.013821938360530524, 0.015883229113364174, 0.030918441029385697, 0.042306439530464916, 0.055537233805103656, 0.03065705757528063, 0.0754936058975516, 0.05164586721108325, 0.07227311782058209, 0.02135747604282393, 0.08757829816351015, 0.048600552798879725, 0.021754384281173832, 0.07217861321424285, 0.04202169997076835, 0.05483062111682469, 0.037506519471325224, 0.03815157699488825, 0.06374744405489295, 0.05601113962550318, 0.07651951254135178, 0.02324908310847898, 0.030816507285400748, 0.07913572578540734, 0.031345119444473137, 0.01579869801418916, 0.040753506529595585, 0.039744384872216376, 0.04192989965480182, 0.026799764656912417, 0.04453042724860772, 0.0026731654173589403, 0.005786998015302684, 0.004654169437520567, 0.08350702348135172, 0.012215088091550336, 0.006455205279522606, 0.027858538387884057, 0.014957747020338093, 0.00723565208552886, 0.040606498087365786, 0.024566095502626513, 0.04374009647196339, 0.010498540735082522, 0.040133404320166, 0.052069130789248214, 0.04256275339773105, 0.05120197671555704, 0.042883353533163186, 0.03762808613358967, 0.1381157855353048, 0.032945465626976186, 0.04347068633163168, 0.04404282760656169, 0.008774586265996821, 0.012273817349435582, 0.07915347604261291, 0.037674005443771044, 0.027977986817037868, 0.04450159936001705, 0.0575291007126291, 0.024240789672119484, 0.03719219359599295, 0.025018311458669847, 0.028055049516561053, 0.03396127140149474, 0.029702990826579834, 0.07479474984950597, 0.006355531016109332, 0.07486750521967489, 0.11141440380484828, 0.03457621017831468, 0.04583068913029087, 0.024104019994997693, 0.0687707476918736, 0.0270230658803015, 0.0052164789315523406, 0.0227113640792067, 0.022423244156544248, 0.07330191261585682, 0.057832517495919625, 0.06490747354203655, 0.03891722824905188, 0.019911739809979356, 0.033814048454646146, 0.03420566494065908, 0.055810895733415126, 0.03440608886340934, 0.010646333459824806, 0.03241722885098669, 0.03862523383671238, 0.02647336140545386, 0.017819957800149437, 0.11424966456909334, 0.04494389256222114, 0.06432675591279423, 0.048567273939448985, 0.04853836178118664, 0.015854361005157473, 0.050972483586519964, 0.03089696375442849, 0.09216290538109119, 0.0900928208964967, 0.006482251056079423, 0.013730622595176102, 0.06935060730264073, 0.057639245003942526, 0.004710475942345276, 0.08980913087725641, 0.02749600259947681, 0.0416072808776892, 0.032176267385723135, 0.012435784615996866, 0.03662309369012233, 0.046514051050067916, 0.023544344885815537, 0.0025713975792900933, 0.05580561738761683, 0.0604480910565584, 0.08622415348767273, 0.008387770278439408, 0.019713116193851157, 0.01730138139288512, 0.0257042876534885, 0.029555116704995596, 0.033012525133428075, 0.08791678645197423, 0.10006497208509715, 0.03634830944300179, 0.033542711603184866, 0.050691539992488203, 0.017043357234328024, 0.03043789131146285, 0.023795167817884398, 0.09280232066709189, 0.026027314372420795, 0.03259062136132871, 0.007068406473169284, 0.08624327504226277, 0.0200047773579436, 0.06593114320909785, 0.01942480283398782, 0.07053058188889297, 0.054234083771945975, 0.04355579103914, 0.03935445761007648, 0.03832616077195253, 0.04894504338623055, 0.008464092745505756, 0.030926636254955685, 0.030248204110971386, 0.011453025959311955, 0.08904562466928075, 0.028507378470573216, 0.07705789615189837, 0.02205562728997921, 0.04438256078790273, 0.013960032412151416, 0.064565216100985, 0.027905819419350837, 0.03884464141822631, 0.045003015397777485, 0.05140842591983177, 0.05374193739806933, 0.017375249505764054, 0.017705644075308117, 0.06354726528027846, 0.042241908114163146, 0.07218856469637926, 0.010843373189169553, 0.01925526183068512, 0.06953106697408423, 0.061526413436137864, 0.029869601543572162, 0.04152156713028108, 0.03210909679652222, 0.16901157525998933, 0.08585518256070153, 0.10869208738327989, 0.12568365707392656, 0.14731299282322008, 0.11063853293777474, 0.22489263315594968, 0.10719472256999825, 0.14081771635720808, 0.11924623556795622, 0.17511933381038328, 0.08876864558025714, 0.12842239842059153, 0.1433321088552475, 0.10639544771683794, 0.09275642433954824, 0.15976536898843705, 0.15354550113120388, 0.09808049792604101, 0.12351401946357182, 0.18979926383303058, 0.06300104075982686, 0.14598864130675793, 0.17958000332357424, 0.09657253045588733, 0.15174308010647375, 0.09918755626366024, 0.1755296811461449, 0.15329180345419915, 0.19973039867416506, 0.11447214416318363, 0.12914932393018277, 0.25727374479174614, 0.07131682558646125, 0.20041621590573944, 0.15707473030253766, 0.16737979265951342, 0.1307415763937658, 0.25233540413600786, 0.09508448127176493, 0.11363537696700905, 0.08686038184790842, 0.14896408083938784, 0.1628756399957403, 0.12714136917624744, 0.09980053385539402, 0.13165728128965826, 0.1388158060369953, 0.12617206876917234, 0.09359270890033053, 0.21558248918623696, 0.11871290813770988, 0.1378763064501747, 0.12386480346322061, 0.09531034697448054, 0.09269255558930098, 0.25335882099405416, 0.20121837124949504, 0.14250117924905595, 0.12848301895803985, 0.1328710097098543, 0.1516745765242846, 0.18418550941972964, 0.11412791787616669, 0.13635758310556412, 0.1623450934646591, 0.17281011498022467, 0.19462857485538532, 0.1265506847431102, 0.18387089243098614, 0.22204603429042527, 0.12417050318852549, 0.16606889364700164, 0.1138935179539746, 0.14904072027533286, 0.09996821518026053, 0.193208048660909, 0.18503877814979325, 0.09491902926275808, 0.18455591293111925, 0.20571771288110366, 0.11554589299785516, 0.15728088456296152, 0.09144144207840005, 0.18117078489834265, 0.13983278775647764, 0.19216848266941888, 0.13207711279392242, 0.10010264062833402, 0.13790679674956108, 0.15017757943320661, 0.09930745668468938, 0.08974927642773237, 0.16114566024513016, 0.21485574753774753, 0.22633865475654605, 0.11681801263963985, 0.1452771294862032, 0.15264222218144327, 0.1628846032244544, 0.15115483183293574, 0.20610964346316554, 0.15333525596126435, 0.08017272538235111, 0.08414012620285635, 0.10690416840295638, 0.2519564357616248, 0.16591707034216774, 0.2509678146170993, 0.1260615146208194, 0.12426011249302857, 0.04745197632620412, 0.08672983280473179, 0.13214000861250585, 0.1253919537749983, 0.12471915237725743, 0.1383559847430837, 0.12461950732094627, 0.12632237521991616, 0.17006261724858515, 0.10715705402676137, 0.13825406440563742, 0.09865389941560646, 0.09187778277743248, 0.15162386150369722, 0.17582833286254637, 0.15726156382551118, 0.17917062125859723, 0.1276048140660409, 0.1995449900747307, 0.11556797165183291, 0.09967650422045302, 0.07959389232940252, 0.08855567313730718, 0.2006430392183604, 0.15613173735478234, 0.16092879607552485, 0.08648902072661346, 0.2201148032421066, 0.0895305583253503, 0.1275585653380521, 0.3009724725157984, 0.23966480016468034, 0.18827186837311716, 0.17204666239840372, 0.23134997294795132, 0.185246096863862, 0.23866824234925935, 0.08627433990759235, 0.09368388102419915, 0.12581323318543935, 0.12342209657353741, 0.19791636375650284, 0.23437395181146362, 0.2406303160974095, 0.08524701600113223, 0.12361531926979943, 0.1528581057585055, 0.08670587723533954, 0.08980332393079035, 0.1438813019664057, 0.2983826969660098, 0.13446779741394904, 0.20001492372924284, 0.20234404552367427, 0.10596468413789427, 0.19657128190080966, 0.23844492771933157, 0.14278106181131256, 0.10387428300154787, 0.11521343382135515, 0.17049841402519136, 0.1318273834523655, 0.12023341646718404, 0.1003019230800771, 0.1632391333940529], [0.07164249722395213, 0.018442224207965117, 0.01659665136568008, 0.053690781876925504, 0.02970371669488809, 0.051016817094698075, 0.03144597108926504, 0.007094801074990462, 0.09205134765755746, 0.045137705146184856, 0.04641474690288306, 0.003003544665144516, 0.02356237093467386, 0.039426623092543696, 0.007001671596475307, 0.019955717087272676, 0.04520538518385542, 0.03412524103036812, 0.04750415074428724, 0.010151003990622779, 0.03136337340448893, 0.07249021181656469, 0.03185131587088108, 0.10071922649419117, 0.040602204164550196, 0.08268377007616144, 0.11851561751456992, 0.05127392003252622, 0.04561079508294502, 0.016812820310494112, 0.02653775301070944, 0.027413542810527068, 0.08705231751645766, 0.00900936252888172, 0.031108436580266685, 0.05272292171514804, 0.03571113496417961, 0.045027457433001655, 0.008160032448358834, 0.026421217630887707, 0.03073902706795883, 0.040642040736612775, 0.04545199654756054, 0.034390456839314396, 0.04954452633917813, 0.08067320296240431, 0.025323630055232395, 0.04887830563670686, 0.05503758360000868, 0.03726366193844907, 0.09261319654122477, 0.01860723954685513, 0.02392789638120561, 0.034735816936459274, 0.10467062373795818, 0.04711314329817411, 0.019441275639579664, 0.03047208947640273, 0.01586060270652055, 0.01548496968743782, 0.047931080053169886, 0.10251168837590564, 0.015854560188017786, 0.027673851826318333, 0.04961169692837904, 0.06685079345780034, 0.04701466269550785, 0.03660528980676205, 0.04316733849625434, 0.03559938571866482, 0.037149093489372925, 0.023412008942555518, 0.039949539387899066, 0.04049473352009251, 0.051137472112332626, 0.05907132763475661, 0.07188470358209265, 0.07105017336265695, 0.03375967536422034, 0.08334086667145453, 0.06411806207090136, 0.0520708813001552, 0.04630844837294952, 0.04081546389047177, 0.02692331357168094, 0.040244341512481054, 0.015533278234333042, 0.06696317089541305, 0.05962217166539162, 0.058957467817010424, 0.07478377947043027, 0.046154353617420124, 0.005992934419473093, 0.013080463883647276, 0.01529188297178236, 0.03295179351323074, 0.017926966876632745, 0.03426617056491875, 0.054673645870700005, 0.035641662280766234, 0.03397573897194478, 0.03823003588965343, 0.061521502812543226, 0.059884346105278506, 0.02131460193214157, 0.0401483660173272, 0.04414741776042408, 0.030956762662578016, 0.03027916555443118, 0.054225189491145076, 0.058110166911876975, 0.08029218913326341, 0.04612910335943584, 0.02943929187172363, 0.03170900163240731, 0.042886831572339426, 0.039053159059896585, 0.008892081170943717, 0.03733153732854032, 0.03850026574406413, 0.11126598193039818, 0.05422495966476779, 0.018438309498672045, 0.07370359549719481, 0.07191376895793984, 0.06491049958933746, 0.02265054627411789, 0.03202983350943654, 0.019568969090018543, 0.03753405650176349, 0.0205616868897191, 0.02456726187149123, 0.019290842784328327, 0.041334549746205734, 0.024655982514002153, 0.017458153625709877, 0.04044653892877602, 0.058005281814163735, 0.010240300156686817, 0.013625670464769488, 0.08028317993927388, 0.06905178704689588, 0.048904647569983244, 0.05142485084492834, 0.05843874585304049, 0.010899087891072757, 0.02319598746966691, 0.049310271973691644, 0.01101953702257766, 0.0345102806515511, 0.0672923282329594, 0.05216175081929372, 0.0057391467271372685, 0.02003384464901061, 0.06913351330665812, 0.032537274828721444, 0.02516502878748842, 0.051108134775272304, 0.053105590294205376, 0.044983790421317664, 0.028144589873150955, 0.03299775878868757, 0.01718665972622412, 0.03943866982515301, 0.057704419934100686, 0.03322396923096911, 0.07845364706290346, 0.02736910779569899, 0.039618972448572036, 0.0008692319674845486, 0.05266536935983647, 0.04174419611151661, 0.003343407842030208, 0.024397636598516858, 0.023920861778840907, 0.03822766101708816, 0.0345740306581701, 0.046391748943396156, 0.017020409070556203, 0.031940680027248404, 0.025374703221924366, 0.022221270820967132, 0.014427496390717645, 0.027664352336057255, 0.07373865168060988, 0.014068201154230103, 0.03609565747601371, 0.025848082356875943, 0.06889516037077674, 0.05447252097749903, 0.022704835094872023, 0.008717716686547765, 0.01647034836482377, 0.02974230645885391, 0.02594080197835161, 0.04409047061457269, 0.04265896638014144, 0.00682279437540039, 0.04443931258133343, 0.06448443212936963, 0.02726464787678373, 0.05930733251115007, 0.06722475927803787, 0.03898652090180305, 0.02303999856174473, 0.026686540692143386, 0.014687635909555661, 0.038526301242170796, 0.058104026717163866, 0.022355089144360636, 0.04234707283396875, 0.02308566314769128, 0.04606860156561579, 0.022237711067822193, 0.01005207522652082, 0.022580299841900988, 0.024009197462169875, 0.023043840492684996, 0.010990085729938603, 0.03776174549373888, 0.06423201381919846, 0.07935550108912491, 0.04936053883284331, 0.024827622598217382, 0.06058451599411427, 0.025768817154570453, 0.06582330867287613, 0.03805333770991814, 0.06183430417290619, 0.042808583351753415, 0.05011080704148739, 0.03759674164616773, 0.042329939277542215, 0.0510458518270283, 0.0556269082270803, 0.027827285831013036, 0.028632143549921534, 0.09827571245090616, 0.03192597113910221, 0.0270242111817483, 0.01217253094974665, 0.08592642873765961, 0.02061672456141922, 0.04964835040511624, 0.08177766426196022, 0.026909091149366675, 0.05590825784771193, 0.06416392392448841, 0.028470629232845483, 0.07593027601439147, 0.06579007577872084, 0.09573502015442618, 0.030949825736423655, 0.014976971039188006, 0.0753032713527641, 0.044000861310069604, 0.062452073644606344, 0.039398967318477175, 0.012435772167068097, 0.01976204048391552, 0.06653806870622982, 0.03340525244693122, 0.024982960331403924, 0.01347363744336631, 0.06765456524707618, 0.024341520658063314, 0.04821041869300027, 0.053367688125299836, 0.024489923380315307, 0.0512147665534529, 0.04017864181209476, 0.06038204661660618, 0.014439392778571817, 0.04823882906367222, 0.03638867461573213, 0.03282676030310892, 0.020300717123093146, 0.004938213293620896, 0.012895339694354805, 0.0173319463858441, 0.06141594738789624, 0.04785370134237794, 0.0169853299045034, 0.07319463732381983, 0.010859691819566633, 0.06021450318756604, 0.02378244118224229, 0.08410467931459989, 0.019964998242475336, 0.023218025904028647, 0.03811077515204107, 0.019794735201304, 0.006001234024522767, 0.033093320596362316, 0.0441564959023268, 0.027129312699300148, 0.04725471634658114, 0.01496446369621422, 0.05134304797637367, 0.02281468252711479, 0.04783226620225657, 0.05084204562609235, 0.05245004119651933, 0.021737130065899224, 0.03732910882982035, 0.029634238265815283, 0.08500910739624694, 0.03682588865499824, 0.045324799139052636, 0.051034544369265925, 0.02597549235478284, 0.0225027889809421, 0.00241090503198305, 0.013739661475072705, 0.062248003143336506, 0.066383219354095, 0.029042205517931335, 0.04754384175964421, 0.02148612518794835, 0.057144447965847875, 0.06611913352483703, 0.02170609009842719, 0.013793636199777887, 0.08213704376811944, 0.044036783172839114, 0.02930225023338872, 0.06310691411096243, 0.03462700180769448, 0.030648395036076827, 0.03166718089262084, 0.05433848623426692, 0.04694329011404226, 0.012444773700178392, 0.022672226562375025, 0.011660345630990642, 0.036630861821674535, 0.0744836645260934, 0.05959979040668376, 0.03352822488053672, 0.01194033353033686, 0.023408887134264075, 0.1091050164353463, 0.026454998277908853, 0.01272605054245721, 0.027286190269214493, 0.02898869427642034, 0.04272815944146245, 0.0077679419454427506, 0.028478067946590246, 0.046723886362967954, 0.05020096409885634, 0.032793420156644236, 0.179539262767761, 0.13024852220569888, 0.09317152908131962, 0.08404241168811437, 0.24171978505628727, 0.15322017423327894, 0.19437118463458555, 0.12028908807664149, 0.22134143258294753, 0.19507014793494057, 0.08579089246209591, 0.07753000549611545, 0.10861029983648371, 0.08743984309295494, 0.13478010081716124, 0.08464616558123982, 0.11604308406071318, 0.06575724891116543, 0.1091574015276086, 0.260785338619063, 0.13375639284570373, 0.1686582248657942, 0.0771925590872284, 0.13485585159111407, 0.09810174920506055, 0.12936519218548653, 0.1933266543933461, 0.13692343096819617, 0.11606023676933781, 0.042416851952551834, 0.10013120804703045, 0.1433958933358231, 0.10591159424474163, 0.06549523151930302, 0.11873321712858255, 0.1168899329739713, 0.14080571942031384, 0.10897599190713898, 0.13157838955521584, 0.08926236626481818, 0.1053640558834999, 0.09129180978502958, 0.08682416121084845, 0.08572292514145376, 0.19259873296945326, 0.1701300789511973, 0.09643622809239934, 0.11220882166056864, 0.27310516625162096, 0.23667649035492253, 0.1275498166139568, 0.12056801302899277, 0.20316051138985544, 0.14295464201319602, 0.22370970147030972, 0.13341842549702815, 0.16817350571434345, 0.14009641393298103, 0.11885830396485907, 0.07853892030975512, 0.08609769535401175, 0.16918955280655817, 0.08557422747535091, 0.15548309070929406, 0.1553358945755228, 0.21031335176479435, 0.1565911909264903, 0.11600569130912905, 0.19154468791619425, 0.13419695468919893, 0.15002802374862856, 0.21695211649902407, 0.10421212777615556, 0.1380115516123272, 0.18707042800322657, 0.1313887215069225, 0.21350533371010136, 0.1861808313837936, 0.1849741969377764, 0.18980396761288568, 0.09160533892892062, 0.14570860552691645, 0.06271519420307971, 0.16326338773773563, 0.1544717933622099, 0.13588240940964993, 0.11703748150818771, 0.10863815479341055, 0.07141147574950611, 0.1074023400583575, 0.15408709465015322, 0.07807051883109155, 0.07416816653623697, 0.10254607806282659, 0.11269557860589798, 0.13182292482064617, 0.1140671058167373, 0.06673081642797878, 0.1353453970964878, 0.18710644945742624, 0.09758656273686117, 0.11288098720533234, 0.1072121817137926, 0.1817135122274199, 0.14450284442113293, 0.19874926986953906, 0.17428092718605073, 0.14669747181957768, 0.12746766900583623, 0.2401372772311011, 0.1455282071425069, 0.21562989470699143, 0.10215120570313546, 0.10799849435927407, 0.15142610356692346, 0.12724690544869632, 0.1490452555158446, 0.14786888154283648, 0.11933487194079546, 0.10927247559471477, 0.26862220357983346, 0.2039744185223695, 0.10879727891616284, 0.2384410819579517, 0.11647184048929524, 0.11328652350892944, 0.15982722292744345, 0.1328517196159209, 0.09470182801446608, 0.13625147992805128, 0.20653123696965558, 0.12607041656249954, 0.13054306769082624, 0.12332577633881762, 0.12800062105299967, 0.09115644204880922, 0.08993888318899179, 0.14459354923136775, 0.1631896441141444, 0.13934537197553343, 0.16587844418902553, 0.11608474392203555, 0.1267045075374265, 0.0842173248829861, 0.19620556684751667, 0.10309361642406834, 0.1110707444228953, 0.21779453742407986, 0.20750153329103224, 0.11297406688813241, 0.3647298029353542, 0.10404906596147245, 0.0996581027885118, 0.10381530189225752, 0.14161987170096368, 0.09103385265916587, 0.1250234041963854, 0.13805557102445634, 0.25108525589589153, 0.10442415027007942, 0.15277840197086334, 0.13834132182021297, 0.13187019244557427, 0.12779910928539692, 0.19424925408055707, 0.252742518580729, 0.21865652423472176, 0.1799496101035226, 0.16676627880623265, 0.07483471665651568, 0.12994087661706633, 0.11804977476957346, 0.13928511149940953, 0.08076443637330687, 0.11396439640872902, 0.09951453025062239], [0.0369502323859882, 0.023681285017500484, 0.014408753092040219, 0.097400686823793, 0.06224906800555126, 0.019610546596889055, 0.05295553665247656, 0.02527376539224098, 0.09039571673999872, 0.04847190748419493, 0.029924305967025222, 0.05706757487308595, 0.029352417501110225, 0.15401929586885438, 0.04906926837359225, 0.07035797461867332, 0.03640071751790182, 0.020514509280122096, 0.04139430077385999, 0.05233568725206199, 0.030283739099339135, 0.028551531948089123, 0.05686630059273974, 0.06297419320852046, 0.06376825866379565, 0.035769575981483344, 0.031469219942547144, 0.043508205487723314, 0.0894409490208472, 0.05766374066532139, 0.05295338011496971, 0.028451222310503645, 0.012660599820646308, 0.03740871685647196, 0.05707151639545637, 0.030779114533816616, 0.059677000578132376, 0.04157561463333907, 0.04663192516853733, 0.031844740921270945, 0.028070294666254235, 0.010129815913856992, 0.08876040247419188, 0.046650269143884225, 0.02322311081262606, 0.12416004608835905, 0.02361150972935702, 0.030318383510494908, 0.05919132381677628, 0.039061942257948463, 0.02941971257959883, 0.060921046927931814, 0.052658991677866834, 0.03117725808894442, 0.05762222253026501, 0.05736572480189705, 0.05160097445872042, 0.021289644702788324, 0.00038609122648561046, 0.04895137510292473, 0.0366125638116031, 0.02418699880851613, 0.04867227395035086, 0.06177130876289261, 0.09262607447923192, 0.030214254924606894, 0.06794378642112979, 0.03447913534698948, 0.04908141469763172, 0.015476725623762656, 0.0986252707098761, 0.08246145902141448, 0.0476196882945876, 0.06286396847797499, 0.008356732226187184, 0.014833521075366486, 0.022085119759844198, 0.036245354886857734, 0.04083001573059348, 0.025073868154938665, 0.012860580370010389, 0.06709614077643042, 0.04083782982742114, 0.009952560405156786, 0.033749321685923685, 0.03354005327808761, 0.03698625000974825, 0.043676442226334926, 0.03132706466731766, 0.031202745834185235, 0.031413774329027346, 0.134654707545715, 0.041365453733071204, 0.05703766680052204, 0.07534026573862761, 0.05671979010766072, 0.03701657176979127, 0.06629282863990915, 0.039079815089221925, 0.038764941461023786, 0.042450050372750535, 0.0032098693801315445, 0.03317570186129982, 0.042047505642497734, 0.035578747309984705, 0.06900969817633591, 0.021567106427204226, 0.05485877867848162, 0.07817538094616706, 0.01464853190907067, 0.1243024618334828, 0.021504045899717078, 0.05222745051968002, 0.041782921856088985, 0.06346720909219115, 0.06703724393681174, 0.038960634790841615, 0.04529032135202039, 0.06946124572066531, 0.02480074248817419, 0.008577010275105075, 0.054062093202505386, 0.06297884336222084, 0.011186366074628407, 0.027034434625097824, 0.0640212630312289, 0.10010869272293584, 0.017400494018088908, 0.0311179245792089, 0.03763766989352242, 0.015583777792691706, 0.00793390483933411, 0.040686094622698524, 0.03545147329268437, 0.03149707106903436, 0.05787983491656281, 0.07113405999036566, 0.04102780431088421, 0.037805362709707795, 0.04483099418481992, 0.05741703354062573, 0.021114101400598887, 0.06441308636098139, 0.024191537879467494, 0.04792573658989803, 0.053788324021884514, 0.0959538531699969, 0.02689099998303479, 0.0070850688855223845, 0.0632602542698864, 0.022930622273575396, 0.03858956095251826, 0.024640804397002346, 0.011965533992606065, 0.031932477140799165, 0.012607332769661181, 0.04957889304346135, 0.07697705089324906, 0.016811588824155833, 0.02791611755627298, 0.04349592126785748, 0.004986729163060626, 0.007540856726512674, 0.08372136722168616, 0.029029775741359884, 0.08590231228980326, 0.03552196870347665, 0.010835502593357478, 0.016992776279127406, 0.02841534258256997, 0.055321809880795984, 0.03743969362169024, 0.027782050254304084, 0.054315151196093335, 0.0382631232271031, 0.037850523592844125, 0.0703460159861753, 0.06462067320582367, 0.016185532196334774, 0.07334005613360675, 0.040064019736863916, 0.0441082093804594, 0.014309352226254922, 0.02435462076156851, 0.06336262659920801, 0.065579884234936, 0.05049321515065047, 0.05060132164808531, 0.027668104251666416, 0.0561312162467549, 0.06239661653976768, 0.14736484165393537, 0.03776562572907537, 0.05191145840311243, 0.070218853051624, 0.04848713348169, 0.01612425090805177, 0.04448319409763621, 0.013492089628632511, 0.0721705692910379, 0.047172894325828364, 0.06036765182450895, 0.0656296186629803, 0.04828541103990809, 0.07873523800123124, 0.051528605962953264, 0.012284552156474563, 0.030270305747586875, 0.04440056768456294, 0.04841257780489903, 0.06066401293801685, 0.030279531361415025, 0.06895053320594373, 0.04877026042630596, 0.03170562509988104, 0.037526437757356514, 0.03143766861138565, 0.01441850922175593, 0.015302869630226446, 0.028817218901108832, 0.023328447902214625, 0.021206098984205918, 0.028137110939790166, 0.01994478118215357, 0.04123957399579306, 0.06558660282603195, 0.05019924423146633, 0.05272272253228773, 0.019700774517391, 0.06370861105801118, 0.08244525626181595, 0.0314470914928543, 0.06524575498676108, 0.037860291213878704, 0.006735878827561054, 0.026088271988555792, 0.03124162671156228, 0.01964284486377672, 0.023684673041345614, 0.05574217764660717, 0.017466978958597588, 0.08083023566512332, 0.07404452760613735, 0.04002844261366033, 0.008055233535537077, 0.02771987455836948, 0.028412816407639655, 0.08188300901242802, 0.048537063262154984, 0.09365560471891396, 0.03010164957583672, 0.003724094647388425, 0.05803756475929291, 0.03064292899873709, 0.017197375381064993, 0.04301297944039107, 0.017891286331559383, 0.11490036433021869, 0.04832180021631141, 0.07248454276592502, 0.017159957731623324, 0.07312176704046226, 0.021738938033400525, 0.021362878877909917, 0.022698794491589073, 0.020126539372628736, 0.0390624861803747, 0.06907258633404009, 0.02500130622197063, 0.044400801341379845, 0.01886346722922979, 0.05973456825520243, 0.09550503289867794, 0.07809646622908693, 0.07711604222535126, 0.0273628814160944, 0.0062725024068758135, 0.026161462113621737, 0.03761958638806978, 0.046333319417411284, 0.025726197768122922, 0.02613825731039528, 0.05831758904781553, 0.014861924742769091, 0.03858644680510606, 0.019052821181474194, 0.06735191455170994, 0.045544141603092995, 0.03148014627156719, 0.05201858813844381, 0.07908749288969463, 0.10612804472686783, 0.03988880393726211, 0.047408615749689846, 0.04216451408161272, 0.010868191565086525, 0.05071138550016669, 0.03122791948337709, 0.04370392563061849, 0.014946661728073754, 0.03367892203612193, 0.0694794632915047, 0.03673237613252094, 0.03345728513874835, 0.0223812127425786, 0.026397317602869966, 0.010137491157248376, 0.03403771165457945, 0.07247819955791197, 0.05016113135723337, 0.04757976745285335, 0.054379479599095164, 0.07122538533181914, 0.04686267851220985, 0.03724740555269584, 0.04319417455624189, 0.047908162532915036, 0.051475891452883525, 0.028562002454794226, 0.024024237683343313, 0.00661201294391386, 0.05429313382914951, 0.046291958330379385, 0.062369159948561466, 0.0398178220606379, 0.024119675001730363, 0.029136028306017962, 0.050788021105672085, 0.014319721226310058, 0.008571940688266149, 0.03990704449073922, 0.017656311843424075, 0.06250787548901093, 0.024317431023284316, 0.034273310504373045, 0.06675636546025354, 0.07539753847184681, 0.002788956973686694, 0.023612185801950195, 0.02004269104931624, 0.1248444460572735, 0.08711433233392817, 0.03574407291448405, 0.07091407784290853, 0.040257947234016274, 0.019037740740684733, 0.028781025077126203, 0.029213596623571172, 0.019568620520012996, 0.023396995534459432, 0.05568032370760076, 0.014070728286770324, 0.1580179071113948, 0.10721991154094858, 0.05410569892715543, 0.25433273325043343, 0.15633285075666445, 0.2591555631689487, 0.1298511370776161, 0.0976626659112592, 0.2404742639872336, 0.21646854647945976, 0.1237719153024016, 0.11570383734520405, 0.06961529834135886, 0.24264938678712616, 0.15778052710717724, 0.2363056884778123, 0.06279137015583054, 0.1914454029212075, 0.09140380417868015, 0.13359847148099255, 0.17381765849647984, 0.12487487506962593, 0.154716037514229, 0.16901747413700627, 0.11247937327190755, 0.14387243066824254, 0.16814810223877433, 0.11478013449138212, 0.27102379729190185, 0.10239186456366893, 0.10815371143361253, 0.18659006023118574, 0.18868282857921817, 0.13330671455590956, 0.07923595306854095, 0.1288089051001495, 0.13809122475645236, 0.1528843059655159, 0.23543158215620827, 0.15088279401102375, 0.049211806692783876, 0.05918980313224658, 0.1426105919264017, 0.09598142467439176, 0.07957824881398871, 0.2306826184353521, 0.07359668026648222, 0.13407533057034016, 0.11729078081947182, 0.1409087122808541, 0.1808943190882283, 0.09702269138107378, 0.149710817382701, 0.13590044311938748, 0.11551981536491264, 0.1234216828860583, 0.13016572342284266, 0.09294602343992842, 0.15478654824677976, 0.1349736146268345, 0.18389232757110752, 0.13293890042170403, 0.16983594715354905, 0.1313321688963521, 0.09762639930892376, 0.1429278749011217, 0.12878264360610517, 0.10086466062573657, 0.10982086431355247, 0.14607920822116638, 0.16287294336624686, 0.2446573032366653, 0.13104836396392316, 0.18793661297569353, 0.1516534784628499, 0.10713682164468112, 0.10252641258581031, 0.19955614431490823, 0.15500952579802083, 0.12800717110475227, 0.22675578963131676, 0.24408218571014945, 0.1977919357558412, 0.09040684033665927, 0.15195527113974094, 0.29717399408259704, 0.13624829300228627, 0.11167802998135168, 0.11371519566783983, 0.13606861474052553, 0.12176640436894472, 0.27531422674655914, 0.15128143552330234, 0.1364714237711122, 0.17528837877175502, 0.17055260708495495, 0.19626083243037426, 0.23632649542583575, 0.1603133210371579, 0.14130548453859745, 0.13006072341194078, 0.11347642904447933, 0.06763466228280338, 0.1251918669309347, 0.06915091882429777, 0.11378823449054074, 0.12959771519226412, 0.1514125284889052, 0.24748566920959184, 0.08019923202453122, 0.21446505801812296, 0.0951204490998099, 0.14166583697642052, 0.10771080536106903, 0.20031602692700204, 0.23270820087242514, 0.11374498116633586, 0.17134679511429804, 0.1403911586009687, 0.11353854345337999, 0.12866333307277772, 0.15217305461485542, 0.14652795188369291, 0.07717204325261616, 0.11584554828943745, 0.19864079181946095, 0.1782342473105077, 0.07774239571224298, 0.06681304830577105, 0.12788890245100185, 0.1544847862134057, 0.1353485687004943, 0.21694595715211284, 0.13269028956851653, 0.13658691918657673, 0.17470293438001988, 0.12069248699492986, 0.14405149605966386, 0.12708064138648972, 0.1436313121549545, 0.1758674033466847, 0.1766529345824834, 0.16327040510312205, 0.10672125725015517, 0.2198610902433434, 0.15407776369923545, 0.17837844037961575, 0.15617247791059558, 0.12478136637758826, 0.12205715771884688, 0.11616168979315028, 0.0884301266482761, 0.11065825204094572, 0.1159236586141971, 0.08613702630804432, 0.11443250677398137, 0.13881355373849794, 0.11122547120096223, 0.07754427771414481, 0.18857335461483848, 0.11656814540225653, 0.12342522221226847, 0.13704900810074422, 0.1377020214474009, 0.1700051912977811, 0.17931957939459434, 0.11383721049153998, 0.12388941020734849, 0.18130852750712828, 0.13147571845160377, 0.1322031036139496, 0.12176432060979067, 0.09899068698887864, 0.1215030616449733, 0.14532819690723575, 0.10132954576082769], [0.12619617755614942, 0.009584058707039203, 0.0456231942159995, 0.06143848186418895, 0.048158960567126353, 0.06849465726484215, 0.03207921936747528, 0.010552399588989155, 0.022711226183380333, 0.052558243454944704, 0.0427932960672244, 0.04910471526184871, 0.010611741717213826, 0.017567924449160215, 0.020080675603821874, 0.024089395376523177, 0.03866801984728344, 0.05772389771957552, 0.02395771443843842, 0.051259011961519725, 0.018921439017679904, 0.06210513540633744, 0.028721136153645577, 0.010918388518715098, 0.06804632728979473, 0.025252054460466872, 0.021682885295200734, 0.055745119424236406, 0.021137566673719597, 0.04990667142274399, 0.0110882694735342, 0.01790474649638899, 0.03707318183695597, 0.03246169259411193, 0.008708600240248826, 0.017007270662654794, 0.036553716767699494, 0.062178936486523, 0.058739937150910984, 0.02525297568119582, 0.029440387377455354, 0.04131007323702497, 0.03141354067221044, 0.06794581655412912, 0.033584919217373096, 0.030139605402045196, 0.038842553828632644, 0.029504629595565702, 0.016704068383983067, 0.04783396691744847, 0.04868476118351664, 0.033191475611660755, 0.025809377679721485, 0.0413702302912791, 0.04661075049831022, 0.04430343922708304, 0.05328534133431893, 0.06639217492192984, 0.04093814521066604, 0.06015254582668986, 0.015531905021728768, 0.0336190675865979, 0.028722658753395084, 0.04810741051070152, 0.05207914355841856, 0.03576365795226828, 0.02830236951159614, 0.029699495550425305, 0.06964394236884772, 0.018507140583448836, 0.05723076309227655, 0.06545503488591602, 0.011334084105798075, 0.006304949582103761, 0.0299828082713629, 0.08920390609531634, 0.04089228335707899, 0.054328622852241805, 0.05739495871708759, 0.012094374659711556, 0.014097273233346643, 0.014528146937429426, 0.015484462154187984, 0.04499536984029316, 0.017508232793320092, 0.026539076427598635, 0.0829547277141002, 0.013373885134745751, 0.04429561746937614, 0.059783302938505534, 0.014096309877781859, 0.030199044248870308, 0.04081137681139573, 0.052211236268762624, 0.09865523240859471, 0.08142506463393089, 0.027994392589936336, 0.016777179985036774, 0.06436194233115643, 0.031247742008417848, 0.012766519137057326, 0.05736801157435102, 0.08182818009968727, 0.0873799886434309, 0.040117274338920275, 0.04845355201752917, 0.058365695539020726, 0.045739455719388304, 0.011113974596223524, 0.030848001159967917, 0.05848074662348917, 0.027123635987781232, 0.05501572328108934, 0.01804016019788481, 0.04573660587230998, 0.034806473225715666, 0.0017187043727796166, 0.061431690494740204, 0.07679098345819982, 0.07260392990804489, 0.04917006256178983, 0.040879413079951084, 0.03768975621149425, 0.036037492250362714, 0.03963558123477044, 0.048934222394300085, 0.043062771325029676, 0.035869217207354885, 0.05406511158892705, 0.014948611421841047, 0.026526089322062272, 0.021156900817708626, 0.09301971343736495, 0.0360738929180849, 0.044379787549616835, 0.033486829319548224, 0.0606393410764154, 0.03858617867433256, 0.07530845010713225, 0.05515310199811094, 0.06917705008339498, 0.04585982345405125, 0.015297300171016928, 0.045657576242041205, 0.03697909474853547, 0.07191888642527404, 0.012795671655405915, 0.032891709237329425, 0.039573072290588776, 0.058580050770674026, 0.04793897075878997, 0.037739364235031034, 0.056451555912292777, 0.017306665484342846, 0.06233273246776193, 0.09215280068136993, 0.02498063333933392, 0.030585673502496177, 0.06652260139103859, 0.03117023306267877, 0.04635425660038187, 0.021460528275178328, 0.032417382068571546, 0.060149217174658855, 0.0037088217270079883, 0.013771634154592552, 0.06997387345519758, 0.014820781990795609, 0.045939220806523684, 0.01854770876947911, 0.04461424875884287, 0.04324111659380217, 0.031396677161777214, 0.04538471487561061, 0.015099254951271561, 0.021394286567585605, 0.05947481848359589, 0.02758827788995639, 0.02038266746357324, 0.0594215753728584, 0.02013362568592833, 0.0665681146746201, 0.04564203614849718, 0.03125464637583542, 0.06318076498686306, 0.04687379827843078, 0.04654277934722843, 0.01667772070504725, 0.044334749240548386, 0.030716193817375653, 0.015045669973797858, 0.023024136711272503, 0.11898889897331116, 0.04813115157547498, 0.026785004057831345, 0.07185079653056399, 0.027495278646388364, 0.019103752621900172, 0.1027700285457315, 0.01945689042669631, 0.060924735641287225, 0.023731517402695555, 0.020876066391206077, 0.05094258317483529, 0.03302726849553085, 0.06933926154048213, 0.03769306954176676, 0.00918141055491663, 0.0057909309191839595, 0.06702382973725758, 0.02942590640046664, 0.0069684305626358245, 0.04198722984461535, 0.02079975828828831, 0.03880239166920224, 0.10441655067787056, 0.05335503618323034, 0.06151599464036765, 0.03893860210213931, 0.03348721619394999, 0.01144129523797141, 0.07970605526239642, 0.034191059474382675, 0.08702945745279712, 0.06651378371903012, 0.051880910647131746, 0.023837875304443222, 0.0725322547218492, 0.032276494668856744, 0.045649677875541875, 0.06416523010439931, 0.04833249863417399, 0.02436777832166803, 0.03695287921976659, 0.034881074867782094, 0.038755652644941886, 0.03979405801322672, 0.03789999372055454, 0.03209686045715165, 0.036718954272087545, 0.02628235844895244, 0.05336499532624599, 0.04635311895981432, 0.11322363535122526, 0.06724252485700193, 0.016432856021809484, 0.06599473616769237, 0.03694080567407993, 0.08548775913133737, 0.05287607035209095, 0.016320405805843975, 0.05579233342300981, 0.026477722360962824, 0.02412212456786825, 0.051743918804511915, 0.04335436737164856, 0.038030286124276544, 0.032954179877114874, 0.044220088860921325, 0.0617203371028506, 0.020482092269606168, 0.05751796562464968, 0.0804915252111612, 0.02731933506325849, 0.03793503841265075, 0.08089980410952723, 0.02107202019091816, 0.0158486565229513, 0.06871334472370726, 0.014262900484966175, 0.03678974462673068, 0.06487614054593348, 0.026108628859923735, 0.031540410578130715, 0.052032492634269505, 0.03256722503612119, 0.004558637794557839, 0.03078941267073876, 0.06994257110261148, 0.029974570910957073, 0.010286368854013423, 0.03863279895496465, 0.028555358557270902, 0.0450103200461355, 0.03113216040806184, 0.04377643968309126, 0.039047164421889095, 0.011440169088722718, 0.09353164403188614, 0.007423836317273879, 0.06570445013142402, 0.03853841309225367, 0.07092961410601294, 0.09424320181771632, 0.10131145076405618, 0.0445393713251237, 0.09478446591885821, 0.041035250685508215, 0.03021778850515764, 0.047528535322917086, 0.04975644158079259, 0.05061849350890806, 0.004318979157570509, 0.0825420361492903, 0.006056105550904308, 0.06712000441527174, 0.019981522759002064, 0.03526460912619387, 0.051950528887250734, 0.041859990301271605, 0.050598153874518416, 0.013330763003097908, 0.012033618141656682, 0.0011070772504148585, 0.08601304263837876, 0.0700763377150701, 0.047554172455303134, 0.0599310927904181, 0.0551804781500851, 0.021469014614159544, 0.03812207877936383, 0.027103325081688744, 0.03845482523883543, 0.044610751567468535, 0.019966007563315576, 0.015547131019223843, 0.05531277004328947, 0.08151344819775513, 0.07029292609302268, 0.019840562580934456, 0.030586133155250744, 0.02145239433664228, 0.026247116489215728, 0.023054515927909844, 0.046917082246152625, 0.05616528417674765, 0.0437775198670645, 0.032850953359757705, 0.084433828991267, 0.06923597756653063, 0.07306866948643038, 0.025837916370120742, 0.07294663168009251, 0.04908046091816599, 0.08007582292080888, 0.037893723290894306, 0.035645373976759376, 0.02999166616298739, 0.019570524248504834, 0.06668871223566032, 0.03349193529556355, 0.02882728529643388, 0.23690346688512834, 0.1345068219328119, 0.1917894070427264, 0.12647504122146677, 0.15386564927476068, 0.2167792870633064, 0.14937962225127607, 0.09571279594374281, 0.2177058857294821, 0.17367959413076603, 0.18156234775820088, 0.07673907334045058, 0.12276918281831088, 0.16717644228089243, 0.14967934649077155, 0.07961004146284635, 0.27147563594964247, 0.14402166459589236, 0.13316203119052997, 0.11535950380587771, 0.13857623502131433, 0.12269766084970006, 0.1992160165982862, 0.16359876570922716, 0.18007273575471294, 0.08624156666619164, 0.15049556720881693, 0.11165085684267745, 0.08100999819655573, 0.2231038944615472, 0.13161765922221447, 0.10310332275806897, 0.13643089771991776, 0.13512939094535767, 0.08630394920586579, 0.13018170401694315, 0.11233171748538172, 0.1639536636010293, 0.18626721545813546, 0.13081637721869255, 0.18635795091188725, 0.2077681931757158, 0.0706920195971766, 0.11248829053534616, 0.11630229757077272, 0.16645624302327636, 0.13925017789006233, 0.1576739029898759, 0.145558436971999, 0.12198251777238424, 0.11817321451681277, 0.14212843150861804, 0.16627682523140985, 0.13416767480873293, 0.2831552592256377, 0.12281314860428534, 0.17196046218516367, 0.15512883633134827, 0.11772370476636196, 0.20908655388461006, 0.18611891615775325, 0.2185574537443538, 0.10787270272210722, 0.1322962905490591, 0.07942932898238783, 0.08405236317025078, 0.1912352343600604, 0.13684970266636343, 0.2507613998867812, 0.07203911626411062, 0.12049759422699291, 0.20423562386103217, 0.1489507049442299, 0.17495517648996847, 0.11243382168392982, 0.21065533341419315, 0.14475534700097578, 0.15291344795015552, 0.2631236534685858, 0.15034201254527416, 0.15835169162000381, 0.1538428658198926, 0.07602186948661843, 0.13586514178783665, 0.12214950195723966, 0.15656037887017574, 0.19918135878059173, 0.10720996005881218, 0.12039536745437693, 0.20985572148234616, 0.19606472924351695, 0.16548659021575607, 0.1662501653716449, 0.14396351852243947, 0.20490910707702562, 0.2606058595401626, 0.11456902364208815, 0.08994390872577507, 0.24900836088965017, 0.12018899868933425, 0.10155883587656483, 0.17281423653325728, 0.19778134842072764, 0.14812501537944042, 0.118669654813505, 0.09990651445883898, 0.16988848546339622, 0.14524259424257666, 0.11892530601471664, 0.08997358697196169, 0.14328907003566144, 0.13431598943087364, 0.23181124980891907, 0.094309292222944, 0.17246637132860002, 0.09595949923799885, 0.07395490297987577, 0.18488366066688494, 0.24686896843054604, 0.1032176920242848, 0.1822298708101434, 0.09188872251299121, 0.07710320259174032, 0.18048554989359072, 0.20245414768015185, 0.09213380170084777, 0.13479059622172387, 0.1572287292970765, 0.0900274046486424, 0.1607118552971271, 0.100248534412634, 0.13460111203453234, 0.16656628389272, 0.11731404690973221, 0.15350339693888543, 0.1250177657892627, 0.16294504756168013, 0.16522395995355424, 0.18831018809108965, 0.17984126994927085, 0.22971537114391405, 0.11918003791041913, 0.08235907903121364, 0.2018035551713359, 0.13754448312665188, 0.19577320214481125, 0.14485023465127717, 0.1581908131559049, 0.16781439433895773, 0.20647807046771052, 0.10994320855506005, 0.14282112820975243, 0.17117830173623177, 0.07433204040411981, 0.1674779898096477, 0.164410772943689, 0.15482407123331102, 0.2073919367525847, 0.11792896270391443, 0.09918990815358777, 0.16501089558005333, 0.14709199177882365, 0.19556965258332992, 0.1589043934138552, 0.1676048080046331, 0.1369511939945721, 0.14530594971391464, 0.1896698869043781, 0.17762441067926346, 0.14401585764942632, 0.145324734189818, 0.17976751100392113, 0.08453761092236928, 0.2025274622945055, 0.108788323348328, 0.14818069464977712], [0.03398336537723099, 0.015586720527930847, 0.02956824362157814, 0.027604400210322875, 0.04251026488359898, 0.048082160252717235, 0.081848711256058, 0.02170825046637366, 0.02276574291529194, 0.049133252037028154, 0.038894146019893314, 0.008979885380775219, 0.021549576420276877, 0.02554294187575579, 0.07469169570193177, 0.10614672961134104, 0.024817115702335874, 0.014897456858307125, 0.026395620718117685, 0.0501351494852814, 0.026475849275987957, 0.028726546649610805, 0.04117617255917961, 0.03912915498198521, 0.06335247976465092, 0.02633480482824868, 0.060241526939095034, 0.07832471446524705, 0.01639545177890649, 0.014774593592230833, 0.13188562145636928, 0.00932032240539669, 0.06841971088320979, 0.037091054668229435, 0.07487381778417096, 0.029982204977122527, 0.05515230909710931, 0.02704245365044523, 0.011531023286102761, 0.0269037266186769, 0.021810768352400874, 0.032484598623047915, 0.08861018795399897, 0.07187534964853717, 0.03548156905678972, 0.04547705145312413, 0.07656513307724269, 0.024097697854402567, 0.031302101692304976, 0.03685870403123479, 0.04268051643345145, 0.025839753065919204, 0.020093316054572503, 0.04097276089352466, 0.09348895761274523, 0.03803454557313554, 0.06043457343513447, 0.06855190701542363, 0.0596542937320567, 0.02722638944584516, 0.031852625881231604, 0.037685186497025916, 0.012521482084036596, 0.07945544491972654, 0.08512744499791054, 0.01100585660746982, 0.04519101720483554, 0.0689697313693262, 0.065072565489719, 0.10308551121382944, 0.01969848582971721, 0.03944388688391736, 0.06716152638076775, 0.001670094298465448, 0.03839078028836558, 0.03109782051685597, 0.157789321796548, 0.054170448678515615, 0.08118441343427667, 0.06651045889743874, 0.01709600279648458, 0.05560664520148308, 0.027208363396986842, 0.0411422195423755, 0.022272679151125976, 0.016022699250419055, 0.07103659062375946, 0.022896016166815837, 0.08552399509015583, 0.03730463232063959, 0.06059740542344028, 0.0835154657702773, 0.017789055728503776, 0.07793242382186075, 0.017464676864385124, 0.030959903623067567, 0.045576236856680725, 0.019076250065418503, 0.04235986267186461, 0.08530550681415104, 0.02443003637205449, 0.06436277736699389, 0.029886708286921346, 0.022367214400982185, 0.0289185474356336, 0.07834791160759427, 0.042089674952289755, 0.09831143513081536, 0.03133576359569786, 0.012796825575341862, 0.013553458059416905, 0.022948751744303494, 0.031961176709662524, 0.03960504880054824, 0.029302610294713132, 0.04538758770532666, 0.027512262815669663, 0.0222064814935889, 0.058454216998671336, 0.04683349439273438, 0.023180244362822944, 0.0330791786132801, 0.12620741606599864, 0.026276342743527026, 0.03038527830804308, 0.011841241972550992, 0.0551791183440195, 0.029253398721677162, 0.031126131296097755, 0.020687323394081285, 0.03729944973583183, 0.028348767626730186, 0.008932213644467054, 0.04674197369886022, 0.04971676971763373, 0.04858528849698844, 0.03329700805367001, 0.027894906496869463, 0.06382073185616924, 0.03612784082971273, 0.05975573143411068, 0.055561116596143094, 0.06603269582434047, 0.01870302160480811, 0.02225701648351406, 0.012018443855096497, 0.043525994049325105, 0.13865606138302436, 0.03058486719495587, 0.02933896116672024, 0.02439771895296872, 0.06563771621233995, 0.06692642165768532, 0.04210510779352438, 0.017106059615710573, 0.027878079375612642, 0.02041187073524681, 0.02004067049241595, 0.023984194267541174, 0.025589236569020058, 0.0907386253557859, 0.03518446483799527, 0.027107938846212723, 0.04050944623867831, 0.01949655271375612, 0.03658666620932279, 0.07207717551218887, 0.03675622444960379, 0.023601855106291272, 0.020412108222503337, 0.03504789817417341, 0.05712596992511423, 0.057336192112416036, 0.02255621595278142, 0.019247078096433994, 0.04767419545040016, 0.11435183771555463, 0.08420206441153442, 0.036055797921313394, 0.027138471280434923, 0.013115308435273268, 0.06393225510574638, 0.013566203847257121, 0.05580576677476207, 0.06697840072334775, 0.028079068288207058, 0.05923432050152652, 0.029450231607282357, 0.050188948009764, 0.0260336326825763, 0.05159606383512578, 0.04540465997471925, 0.021484727077486537, 0.020778409333058426, 0.04946592188770733, 0.016397412963992646, 0.006651052305730241, 0.13071597373533633, 0.017997839585727742, 0.03752417779797989, 0.00826838888197897, 0.013647138163627637, 0.10258301116165616, 0.16567471076644238, 0.048545919238559665, 0.050805166153417486, 0.049674696168832244, 0.03709677734502381, 0.07132517594483591, 0.06609692463591214, 0.04647830921796061, 0.03456628167881601, 0.02095664543430171, 0.01916263222454056, 0.008405602890096845, 0.04010882055867584, 0.03487677328408726, 0.02183573132741355, 0.07240451722135467, 0.032930335390471646, 0.030729719099678823, 0.03890378340598076, 0.02460001021503441, 0.03580403844675711, 0.01435875532127196, 0.04202168081857024, 0.03322594956825337, 0.059721314934112375, 0.028929965976145, 0.03463402300352051, 0.07705843241344537, 0.03676087077286455, 0.0037808677476395165, 0.018911878240384886, 0.07550409364123499, 0.0246370199226564, 0.029317562415775274, 0.036122187100831545, 0.05449159273637399, 0.016502644716491623, 0.06409335573534332, 0.0037483118836873124, 0.03086551584513678, 0.03481768875292713, 0.068001595415896, 0.020421609627984224, 0.029849554937813553, 0.07737764592973456, 0.04006013950152744, 0.04420403165802841, 0.02531367474265637, 0.029528198290556192, 0.024556592181925813, 0.0597084676396222, 0.08023546032247045, 0.03302270261150214, 0.028539412437127005, 0.06938141935895528, 0.039861374159133246, 0.05202612261317911, 0.029102155728445902, 0.09836854698557047, 0.06995111298296722, 0.046540553861808394, 0.11783058935355757, 0.019628243227939934, 0.012565481386357739, 0.045664612759625724, 0.025957336070977395, 0.04992998347827985, 0.033100383927024184, 0.05470381441315817, 0.09088344661699188, 0.03152268713400249, 0.04212883736697897, 0.06825171546229432, 0.05967150006683604, 0.06741844162705445, 0.05579020369858031, 0.0677223257239788, 0.01977790616482737, 0.06983082951797594, 0.050458695228782394, 0.047321618805008556, 0.0741123493700739, 0.03730963870522477, 0.014306950540612302, 0.042764667361494035, 0.058713970600717494, 0.043550041549268274, 0.06168574823306934, 0.03814802234691959, 0.026934467811858463, 0.00879296854573993, 0.04693819945978542, 0.03967188614150209, 0.12016924128176705, 0.08322910210418125, 0.023791754896181728, 0.027546826787593386, 0.028201864521589973, 0.02469850613945915, 0.03852371186498673, 0.022946980165978594, 0.052156422677780354, 0.020615527549037532, 0.07177780367313855, 0.0227665760359096, 0.032225611108926036, 0.04605350197262822, 0.0740850383355733, 0.0777136750759617, 0.03273695947662477, 0.03763174420342811, 0.05002430422351726, 0.05737917730584741, 0.01676730128125318, 0.02544540739167602, 0.077886366615853, 0.05410745709894165, 0.06751888341480686, 0.030008039377149076, 0.024409846124810078, 0.14895061301367898, 0.00893927889034873, 0.04692720992851162, 0.07968163237937036, 0.04503306136616776, 0.06276827643535311, 0.08926677893126204, 0.0097312452647114, 0.10258457398102169, 0.04771895796781586, 0.00743700536869226, 0.08193103506440118, 0.03768735835629125, 0.043706373281536565, 0.018880543329062003, 0.08565240674802373, 0.09500149096692763, 0.0260149841872795, 0.02952579660491357, 0.028365341938971996, 0.022347577652263067, 0.05390175866083272, 0.01725912781342143, 0.031628104662823106, 0.024960730375061115, 0.011165342706766342, 0.07066296954308787, 0.007086985541747944, 0.04616907016644555, 0.2335593858433347, 0.202118631812834, 0.14077256313495098, 0.10795641314959335, 0.16989663663891055, 0.1511254906654358, 0.24019392177222237, 0.11658844673224997, 0.11601065555887839, 0.1244696222185608, 0.07489473198450382, 0.11763401885306644, 0.13485739908872113, 0.10920413289098971, 0.16886620241547787, 0.1773074034961962, 0.052526293758062594, 0.12082125105324293, 0.11497368660545158, 0.15590771792396424, 0.09985563855978752, 0.1608495212971203, 0.17241530390756746, 0.16577185071524114, 0.184901142793317, 0.13914859463130275, 0.17059537011288828, 0.286928272896236, 0.11634530574684182, 0.13200672463543955, 0.1359123481257308, 0.09250316333266036, 0.2508034427920657, 0.19279105168196464, 0.12461705583958857, 0.0818837214741976, 0.13413215897256328, 0.2000252659162206, 0.09324319660663606, 0.17682199486561362, 0.09433127894637086, 0.04535663775318573, 0.14582244619246454, 0.20119969402590107, 0.14154975933413352, 0.12606286293556615, 0.11936915437540702, 0.07182373064419917, 0.10320058528093562, 0.12909323097236697, 0.14003644457026837, 0.1421834825868568, 0.18465758812042976, 0.0975284013416498, 0.12818993670084786, 0.23018832318484786, 0.11165578278803057, 0.15633340233996992, 0.18028580012821382, 0.08097440575159366, 0.08298260565366476, 0.08979575498209846, 0.2350243911026947, 0.2856550041225649, 0.22002437422352455, 0.12197715515691428, 0.11238722055549584, 0.21565347489330078, 0.18223157152533534, 0.22037542635394683, 0.09681577103272562, 0.11590288997056986, 0.0814942040690972, 0.118227805942297, 0.21111610465713088, 0.1733945941011752, 0.25349086390868314, 0.10360890248369786, 0.19764922889730624, 0.15872719727696913, 0.14374967273925582, 0.1648621059833996, 0.14543538792960106, 0.16203306585309968, 0.1033141041895555, 0.15536309069683477, 0.15214766646104474, 0.24578060263827925, 0.16500214685595807, 0.09748753055088943, 0.10221436199161316, 0.18441930413246158, 0.08031725553014586, 0.12521073567650973, 0.11414718498746235, 0.12587546250752865, 0.22779754663427032, 0.12854342499086935, 0.1983158939307736, 0.15231429058457577, 0.1623882395365546, 0.17601044728390633, 0.23301170958626657, 0.25407814691143654, 0.10935564209977466, 0.19603198664563318, 0.08561686792921636, 0.12853159659331845, 0.1490109654203538, 0.09234899579877816, 0.1086916583740423, 0.1374429611549262, 0.15505250333057297, 0.17698222981585612, 0.16786615123912213, 0.13866021357957395, 0.15494463815083429, 0.2473182177111026, 0.12217011738328204, 0.14167772666100534, 0.2231735318538643, 0.16558615100239554, 0.2643673512483797, 0.1327133028497619, 0.11050011617161574, 0.1218676658707761, 0.1952275943251387, 0.11872160323565045, 0.22324575862336546, 0.22628486006250306, 0.15528763103629314, 0.09835524769920496, 0.1267320330765459, 0.09716451723849583, 0.13184520265748426, 0.16308033868910807, 0.09514830405673674, 0.1548726258859519, 0.16089937829923245, 0.22090486971841705, 0.17107707087791738, 0.1969412410812032, 0.325725355576123, 0.12267304644469293, 0.1808780320589581, 0.17811292962681863, 0.07887606028347247, 0.36501202972665914, 0.11451889850920248, 0.19552747178221905, 0.128748215614788, 0.15420355533640231, 0.12609240328592639, 0.16517660039807522, 0.14394121004208443, 0.23282947259083872, 0.1754867649006267, 0.10273420627439216, 0.1480049081146717, 0.09249670521145867, 0.11651013722463001, 0.11634981800471583, 0.15845024117058323, 0.27022669812844646, 0.14978765600150631, 0.14908394295602076, 0.11195077260415401, 0.11796873032806382, 0.12814828450040472, 0.06754293091475003, 0.15128840692341328, 0.12530327143688358, 0.1677348897341759, 0.16937811768824057, 0.21931673880786667, 0.15202627216856326], [0.06577123001578354, 0.023301757398932692, 0.03260246891107771, 0.05305673303683439, 0.04303221590816975, 0.06863518843367215, 0.05374656073869236, 0.05208559018830138, 0.05360368151037444, 0.04603168378854471, 0.059782759016079295, 0.040428704401898774, 0.04398540165575762, 0.06222397096515183, 0.022898274210972652, 0.023716913851638956, 0.017161428620437943, 0.012256645488612836, 0.018594733161491253, 0.05845471878626174, 0.07660236495036273, 0.03780582619290199, 0.07121938686337202, 0.05055093604530539, 0.06131190115646009, 0.04931781793974581, 0.05743645003906662, 0.04930388280040315, 0.06764427668625309, 0.06371422648249615, 0.04052886656755882, 0.021776574017900615, 0.033718923317088235, 0.0867499502736234, 0.056920497482942964, 0.02287483000526986, 0.06942104142639907, 0.05108221802079389, 0.022312824073578083, 0.051158731052231406, 0.019744004858958147, 0.021137543691081867, 0.03333070060057986, 0.006200177482359352, 0.02579545977735712, 0.07306987990535076, 0.043349230752116254, 0.05235716452701919, 0.038870366650723645, 0.027110543545155276, 0.06045857113936256, 0.0414754677894375, 0.03153992602751861, 0.024762258061297962, 0.05390691443256313, 0.03447771425388994, 0.04068430963783495, 0.04323833569463703, 0.02362746351038016, 0.02178284061712123, 0.04404846218324477, 0.02452410239305708, 0.07653523266555802, 0.02508847553643488, 0.037662479650950244, 0.048580255299325914, 0.04993517372396685, 0.060875847740399266, 0.008663060143589973, 0.01676276795596125, 0.011995975453887257, 0.042712029460216724, 0.012587437466267618, 0.06307972948096933, 0.009117046720348299, 0.03460406896568114, 0.035886438863892714, 0.0054977935994224205, 0.014672945215997678, 0.03969954191556862, 0.024773437199333025, 0.07735226543680315, 0.06199428248369406, 0.015723544788817247, 0.07681188233677419, 0.08385124210748943, 0.01866775857765348, 0.04412692490844958, 0.07399136110419229, 0.03629458752731162, 0.03817031167507653, 0.026410069136369615, 0.0208723834235101, 0.011828749951335692, 0.0959770656341026, 0.08409295050847916, 0.010313243218397182, 0.026593395891869744, 0.02700914031705789, 0.023475446768345374, 0.011757836065014765, 0.01826137957733966, 0.07626392262717409, 0.07399829419990701, 0.0596443614021184, 0.008426200121551031, 0.07756496974897963, 0.021133600253491633, 0.046335866659759514, 0.020347421673396905, 0.04076984718502049, 0.03579030632071438, 0.049746991886246594, 0.03942254750478653, 0.02272277112839924, 0.03777204554588084, 0.019202641166386106, 0.07491614414198745, 0.03743436548017687, 0.005589938176149924, 0.02429537152150466, 0.03173543166579499, 0.03895029643430345, 0.08607399259363452, 0.013324131554503356, 0.07390256385288893, 0.031399274199840524, 0.05965230573389319, 0.06088803619927457, 0.06811738960565099, 0.03743411650160148, 0.0476825802827314, 0.06687834197955747, 0.028776148927488157, 0.025151451794250358, 0.051292175907761826, 0.10336041420457825, 0.046822750009596355, 0.021221177509775566, 0.027015642488315224, 0.003406146612589158, 0.07300129205348992, 0.026936528588374777, 0.05272965562800246, 0.026730023842725544, 0.05006270821116144, 0.045206718176843665, 0.05656840730338328, 0.014013410545885565, 0.032448075381257845, 0.03385575811168359, 0.028879879147655545, 0.027316697805579153, 0.11569814531192665, 0.05385457147513667, 0.08813325991673816, 0.09520806657570986, 0.042656273581087596, 0.09122826279171052, 0.03054597099582034, 0.0599709331929203, 0.026558295658399022, 0.013615683551066586, 0.022557976039787455, 0.012235671916465846, 0.06426204446583025, 0.04161151734391048, 0.004321258747950196, 0.03771495284332383, 0.06406465425126015, 0.10485901241941799, 0.02033825926182251, 0.04190523162363999, 0.03412585773114716, 0.061545331977427974, 0.017217841419962146, 0.018014207054229996, 0.015924169809647625, 0.07854925483585366, 0.11168174550778444, 0.043398965180160544, 0.013765553331693575, 0.05123952651516565, 0.03091173776004824, 0.055510309645004814, 0.09860186672378933, 0.08885052505760424, 0.03303789796548025, 0.019779022737977006, 0.07908193109136435, 0.043075369640944466, 0.011740290736328932, 0.08288985538867213, 0.012981799419879193, 0.036635351096910816, 0.05510803687596514, 0.04674905235128057, 0.018471358531725504, 0.026898440611999364, 0.041478945828613736, 0.06620285927408165, 0.06452611497332973, 0.039044092409312725, 0.006911744844288596, 0.037835389525899966, 0.041460084743917956, 0.032637444655260736, 0.040745830328594294, 0.01145652219307639, 0.045879940922942855, 0.005536103741295877, 0.05452721199441341, 0.02861816819096285, 0.011602165083581162, 0.018322718322216984, 0.03036379145698682, 0.003630788729248208, 0.04285881573694848, 0.03404010184890321, 0.051730217321986155, 0.02016842714510858, 0.06331337480655601, 0.048928993844216874, 0.06842413121053288, 0.07884596834980673, 0.07633655542327512, 0.0424577227433122, 0.019215969181048776, 0.05836694043189768, 0.01136493829694847, 0.05544463675769587, 0.009283277266208203, 0.01889362236514928, 0.07492572024104095, 0.038181044566895694, 0.05340990723080693, 0.014426896926916897, 0.01813437369081282, 0.03606664955676083, 0.0921228160000136, 0.01844133363075314, 0.04102263321739532, 0.015056894119498471, 0.03333901648499793, 0.04838598689304725, 0.021626127756110603, 0.060302331337645176, 0.06472529783364266, 0.020205138078440103, 0.03905118255305194, 0.03726128323544418, 0.038867819408375415, 0.028018237076579567, 0.004780920599812582, 0.04638784572542195, 0.010465169945100864, 0.018985212006936633, 0.043817567113306255, 0.0751728525445346, 0.02728304356306551, 0.08418034581888108, 0.033625640620988224, 0.06445184274907075, 0.04367431250190543, 0.02083558822050691, 0.03572414696757351, 0.036825360054330486, 0.021742722507746472, 0.006172154464894125, 0.05307878104729518, 0.05744587292053527, 0.028566909247949242, 0.021693924622189616, 0.05672157126208467, 0.05955491297607941, 0.09670991300334854, 0.052420845585725004, 0.07192795690629752, 0.020931316652305184, 0.03949828678742051, 0.013327906452750247, 0.047163237787542805, 0.03378430126054633, 0.013771099808265366, 0.045772240452107885, 0.022906220457967252, 0.04820002287986779, 0.027063678116387418, 0.01139312841734218, 0.0630732445466903, 0.04344361278438761, 0.03675179646140145, 0.028171222919838566, 0.07500153230202776, 0.0207191294494776, 0.04273874294613639, 0.06204163820873346, 0.024258647181634462, 0.07247190997605363, 0.059983412765206835, 0.017640748767242316, 0.04172567593594713, 0.053481973121843995, 0.0606163431169285, 0.084873027198257, 0.059794510804837754, 0.05029158080897985, 0.013592885732049904, 0.020046887295921485, 0.045738348722337716, 0.016049960489204575, 0.07263634308812118, 0.055165600722595576, 0.039928705626798254, 0.023517897615449566, 0.027805427427313505, 0.027143257414741863, 0.03215379802690398, 0.04922917390602732, 0.03111671607550835, 0.017848739723464655, 0.053793587045924324, 0.05480902509823923, 0.023156911239869172, 0.04813333875649879, 0.01561359010426508, 0.00019337431284281682, 0.027859135936464996, 0.010027921431878162, 0.026043515216799516, 0.08076655843685712, 0.02551240561109397, 0.04571160842334071, 0.09569719839360445, 0.024177754042489875, 0.03168606495995435, 0.029228144633253256, 0.08878438102622187, 0.019536753177582737, 0.03762494900353974, 0.026120271481152986, 0.05198710958563513, 0.03417674895195711, 0.014352408282819295, 0.08820899536893254, 0.05801370112045158, 0.10072208400214873, 0.015124864312970351, 0.03228055493485543, 0.02623160895440848, 0.05847767461091281, 0.12338840402662755, 0.10269957143933543, 0.14617573529962571, 0.1831351262667487, 0.1846364594154781, 0.1658799610431156, 0.11468245828103636, 0.12532272240928105, 0.12846515378764561, 0.16333705475253446, 0.16654170779210908, 0.1853671847211738, 0.07135381997232476, 0.10583182917006555, 0.1257187439008586, 0.12490991593128252, 0.20295602720110648, 0.1906408267396112, 0.10025526066460919, 0.12754101426370684, 0.13312398726421018, 0.17572005399532858, 0.11260694223305873, 0.205289347157363, 0.20781628817560213, 0.09929606495725532, 0.1338900445449737, 0.2874440339303786, 0.15498663509084334, 0.13703379359456802, 0.11241230227413679, 0.1274767011824635, 0.14699468329068155, 0.11780676401911244, 0.14621722662160475, 0.17224081972193334, 0.19342877391365268, 0.08910249903677933, 0.13310287388101702, 0.11385314512036501, 0.14692366694010076, 0.15408709465015322, 0.12562465298199846, 0.11124614791403856, 0.12264892999683658, 0.18345925806751176, 0.17437382300774898, 0.07106397060617324, 0.14323158279782341, 0.16312362265682992, 0.10351311084964585, 0.13311451841746608, 0.15392053181365614, 0.16228806587957567, 0.12351469362094519, 0.2096486938816886, 0.13064114226689263, 0.17620029919330152, 0.22040291358867, 0.10960753180927808, 0.15584860657972677, 0.19491208867440302, 0.09103390628532057, 0.25535532273352146, 0.32785716376477675, 0.1458677219887895, 0.15944220245845858, 0.12900393576391284, 0.11105173012061466, 0.1620856654499808, 0.11497232296894636, 0.11935374834724974, 0.2096614875500241, 0.13641465665592303, 0.1525980801952462, 0.1052727994899596, 0.11523742769514361, 0.23157607613792344, 0.07777279408107843, 0.14419904459388028, 0.2225097779545092, 0.0914355968275378, 0.17648802649590278, 0.155451221451644, 0.12731862660016746, 0.0897776676462062, 0.2910957912043218, 0.13755804288291162, 0.15915484287806098, 0.15189338655721757, 0.23522608673139928, 0.25350151253083064, 0.1656462582609346, 0.12844541936271614, 0.1338974755978392, 0.1589954199810182, 0.1600424629906493, 0.08883465171581315, 0.13248330793313443, 0.11416538723654325, 0.1783733841993155, 0.12186319957817755, 0.15260531206525144, 0.18843867635775, 0.1539102509137123, 0.09515178209591298, 0.23440882413377687, 0.15367809562913834, 0.09912763286622302, 0.1478118079924776, 0.15197381046750855, 0.15790541476059347, 0.1375593605541414, 0.19819060791163676, 0.12143302588693558, 0.11312659499385666, 0.2178652933047664, 0.15777818287812895, 0.1372880734983952, 0.15693257502730817, 0.09653939715316219, 0.09742359285272899, 0.08899141628775867, 0.1731833530169341, 0.14909282957594241, 0.059341450236857905, 0.19643082734077208, 0.12485671112494123, 0.1698142975088089, 0.3058915230776033, 0.14977014323155727, 0.13216878287494183, 0.08914530802998813, 0.14913675705752066, 0.14072947835008945, 0.08467062676866209, 0.1491979368391537, 0.1692086896829067, 0.12436705070637888, 0.08462992451724508, 0.0642625539142999, 0.10265846316131855, 0.16763201944770353, 0.1098518678918481, 0.1655287250515915, 0.13371018242211113, 0.2823979966342449, 0.10888786115232976, 0.11609041297267522, 0.09991227544002956, 0.07809779156119594, 0.13779183759564353, 0.08324943407769166, 0.08328700302949837, 0.22422219896989487, 0.12487479846083349, 0.1151942586406104, 0.12812681871676637, 0.1737255134409474, 0.14515242569388884, 0.10539026375138953, 0.14014749667577206, 0.12002848028655975, 0.13139760812684415, 0.1274488232428989, 0.09238093400434141, 0.12222182831817097, 0.161939020899515, 0.071872882845421, 0.18064060608946508, 0.13546931947911942, 0.13387521308275963, 0.28214028465651697, 0.11773013990492591, 0.14108935581339946, 0.17275055930499109, 0.1544627228811864], [0.019500549777501056, 0.05225217983787579, 0.1057674241582713, 0.042736689830499316, 0.0363124986629813, 0.028453415237186898, 0.08087011054158211, 0.048029813464851155, 0.05803862196062842, 0.046657673383672396, 0.015353847993537785, 0.04658698645089904, 0.02121320828014324, 0.07196901921903895, 0.015614013367843245, 0.017159025019575513, 0.05174756921347111, 0.024097113712360303, 0.016079501797174735, 0.02447289516097836, 0.055224796336504726, 0.06716329604387283, 0.06985291583283294, 0.0165332805725836, 0.10676079504792729, 0.08179823372272715, 0.05726753531264202, 0.04474635679094542, 0.05172110470612684, 0.027277646473638957, 0.0017057397710760276, 0.05425537718580135, 0.06820991004426634, 0.03699756512838987, 0.055611969512556834, 0.022646518566855983, 0.021486144340146455, 0.024866551356089693, 0.027685414008315534, 0.03032354694310456, 0.06175018388838057, 0.05256286679556774, 0.009287948487326503, 0.038227714643242865, 0.03813412168153352, 0.03592748202443604, 0.04465034299139534, 0.0206556475736321, 0.030586885836636348, 0.07546037300339631, 0.07540326880952043, 0.016394344781855905, 0.022952990125744574, 0.043429830862629804, 0.07057447106607499, 0.0721609778702259, 0.04855960922976656, 0.03531480703743235, 0.037779580020616134, 0.03732434759337095, 0.06023902566202226, 0.04640206431729659, 0.017924283653677955, 0.06195079167223266, 0.0289480418207184, 0.06208573806009466, 0.07151464481026897, 0.0666823537058888, 0.014201573231407713, 0.08662097937157077, 0.03619003950828507, 0.031983307074575175, 0.037675051153787685, 0.02459654366717704, 0.01446419008707087, 0.05456935066068846, 0.008617847549518751, 0.05773841125530101, 0.027696880429322203, 0.015894177467412045, 0.03413451069425191, 0.08153518211216697, 0.025344415935837937, 0.014902500589678605, 0.05370693101036934, 0.013647590155502962, 0.011595778783122379, 0.06582684799908631, 0.03323681269501967, 0.07769800857791016, 0.04017951132188882, 0.014395743003866125, 0.025735409975412394, 0.0742520914683419, 0.035742065764122435, 0.0884055199041482, 0.029508438967769186, 0.014809391220971463, 0.0807449700791509, 0.03597781017062164, 0.0060095599638448375, 0.042162499270371856, 0.05034611477786976, 0.059884212039891756, 0.02200550790275297, 0.06510232800557729, 0.041605836801951936, 0.06243169187538086, 0.016859381219312068, 0.031110485865464135, 0.051213326308155255, 0.05650173467133315, 0.039370403730220375, 0.0339143370248137, 0.020512892834601865, 0.040370864763615594, 0.05399574232738345, 0.04198629904778735, 0.07341139424111574, 0.02088606766905756, 0.04868738120421768, 0.04406061616816348, 0.024740878462551102, 0.043891659306903044, 0.03564599833841767, 0.039628912439389576, 0.021628862690000285, 0.02357467622195761, 0.048352669729220296, 0.022460029783448385, 0.012587914356000483, 0.06677045381718105, 0.02176222136063922, 0.061525045969193025, 0.11605185576744619, 0.021272277489544886, 0.03887870551777944, 0.025661672097480586, 0.029252693920786825, 0.034626036536909884, 0.03154714066054552, 0.049592138703672156, 0.03478971888281165, 0.05600424866462427, 0.09864274517542894, 0.011740839446804697, 0.012140502728852294, 0.07054909057314358, 0.013424231475519558, 0.03562901799957599, 0.01224690659587542, 0.05950999341063923, 0.060289821121841676, 0.017736862158222545, 0.04495184455487517, 0.07046230813308109, 0.05127429924604874, 0.05364887686746736, 0.059649471208573356, 0.019032799473573125, 0.029589100365316676, 0.02299965828687193, 0.05548372639403228, 0.016448051375787587, 0.07641690272477365, 0.05046378588303924, 0.045566886753564885, 0.04592110665755407, 0.022597010134749358, 0.004934362744191481, 0.004497212385984078, 0.01642085716969544, 0.014802265645665749, 0.045966110492665926, 0.04134534009461922, 0.014457666848395622, 0.10174645847010036, 0.010840333735329971, 0.05492535937998084, 0.07337366441084493, 0.03931618385737942, 0.04140221829255743, 0.03251386318175543, 0.04054883847974482, 0.06077785360356493, 0.050092432422623526, 0.050182715884499976, 0.012553104278331083, 0.05213966450443672, 0.05522311860395055, 0.037462599650626226, 0.032609892303063985, 0.0650799046120336, 0.02002446773281742, 0.031111137040199775, 0.034271318675769914, 0.03776980473870232, 0.007698019664178813, 0.027420562091133287, 0.0329938440793945, 0.02372314597690298, 0.08226693397568119, 0.10352191319989582, 0.02561308871654253, 0.004911934083793312, 0.006862963716905084, 0.06719372505622526, 0.04234558279295603, 0.03884681710793127, 0.012639446217837113, 0.05294994421062931, 0.044937618302121285, 0.04441616140426167, 0.013437654293562858, 0.014467745692649437, 0.05106336076653773, 0.046145727467392726, 0.039315590139238105, 0.08678539716187986, 0.05091549813627236, 0.0397950386057698, 0.024365865017077135, 0.024127628909604206, 0.02503569016323215, 0.02062330908712841, 0.0632413357285963, 0.04441168362034425, 0.05394850534597232, 0.03438350842184117, 0.016416735616662813, 0.04364820039500633, 0.023390474211003993, 0.03908400175972812, 0.0548215314836031, 0.043865225443075744, 0.030579596510036822, 0.08215493958203063, 0.08744657700580936, 0.0233373919787306, 0.09923106239688012, 0.03548933335790231, 0.06650419995909737, 0.045644522103811466, 0.009844967186631215, 0.06714638848338397, 0.022581088912462997, 0.019452403066679835, 0.02859246977154286, 0.045990790015146624, 0.03567110303969633, 0.01900810271411413, 0.1082695362668845, 0.04114882322028279, 0.019276553329320687, 0.043565099007420005, 0.040518578006735737, 0.049711698215574994, 0.015501892569685176, 0.02634477354736338, 0.04149175864914733, 0.007437914140492438, 0.09736282675857506, 0.060393242991619536, 0.021655118438385187, 0.023907399698791486, 0.04922639300686218, 0.018387100351373517, 0.05862908039782798, 0.03614325834918888, 0.01060324292930384, 0.056452862092203675, 0.04322577568311845, 0.028624440535842895, 0.029737732913945953, 0.03648761104071333, 0.0472485531692303, 0.02713402030959485, 0.016813908155346592, 0.07833288862339913, 0.05650185341496141, 0.11855555367806267, 0.04137930843318182, 0.04459993440597769, 0.045059368825487556, 0.028653452285535397, 0.009347738776986879, 0.040746182729039467, 0.05609979898098016, 0.06569974635156893, 0.0712531713408328, 0.008104774526380485, 0.09458336017785535, 0.06490601031410118, 0.05661339581673665, 0.025800186539849928, 0.04114960079952594, 0.036783769140921296, 0.06894058172380732, 0.031345981293387955, 0.012371673590443548, 0.003291462532116942, 0.05755720081769171, 0.01881134643730137, 0.04600265671709373, 0.05124768918199886, 0.049270423910310196, 0.03922930182588678, 0.03995010629296303, 0.005481021061930205, 0.047999614278876016, 0.06401892646305984, 0.01707797291718664, 0.016720648441884308, 0.04585167610897653, 0.01924681188088031, 0.029264928344937585, 0.0716480053961277, 0.030197494836043448, 0.02093561632078021, 0.04346665670914997, 0.11449659002884743, 0.06478791786057335, 0.019032144468397866, 0.04261937878665425, 0.03138558995429307, 0.054538833548224745, 0.0025479998176677096, 0.04188324490021314, 0.023905951792614597, 0.03690683350507771, 0.013393223109174401, 0.011260950479716545, 0.03759769159519384, 0.033129993225297624, 0.06916615631311171, 0.04446896018400308, 0.026415537088929165, 0.027833945050294844, 0.07558616464056316, 0.044680580481766694, 0.026581747524981058, 0.03147817742560179, 0.026365381312526526, 0.09698788800667371, 0.06435046633405071, 0.0733074207880324, 0.03908083398616122, 0.03469257127313364, 0.034731879244528474, 0.03196509716461503, 0.02598828027745889, 0.026405918855039824, 0.18257906900778895, 0.16022948037472465, 0.15283965836128882, 0.20134918842344515, 0.11055719738285388, 0.12243291618482721, 0.21124463888906667, 0.10630891808579046, 0.19155608730450754, 0.0765145942568779, 0.10106742111665588, 0.19864641490482515, 0.1439887381369068, 0.14235594430037085, 0.10598818005453195, 0.10296952550209339, 0.11669995082962899, 0.136924151090845, 0.16000929138352796, 0.056655814105104056, 0.18877440672968665, 0.10483106553194024, 0.08792199584985934, 0.07706360350693427, 0.18104744474253348, 0.2374417355824863, 0.196886619012202, 0.12580605494158884, 0.1268831745631272, 0.10464982445081396, 0.14421776778274967, 0.1251064251447397, 0.1636300987053302, 0.18236871658554002, 0.13669951878968747, 0.17557026848437327, 0.1755473164901618, 0.12186535228524478, 0.15703228903153252, 0.1609007266139792, 0.1374254330632187, 0.11466980250852724, 0.1768551205074595, 0.16142332115240637, 0.14768426967484338, 0.12160282161447311, 0.14267780848087805, 0.09082828062556444, 0.09814325584879807, 0.16931942003148218, 0.15734204902283608, 0.11468222845465907, 0.07647865707234991, 0.1702013098063969, 0.13870878355397334, 0.16522374544893542, 0.16495463408289418, 0.08984755018665906, 0.1433903468592513, 0.11883352102050859, 0.15864317275343404, 0.1848703767022779, 0.08753010357219367, 0.1403154691140498, 0.21040736607486205, 0.1617046899252361, 0.12379997710306799, 0.16756250462945432, 0.10662807797592495, 0.12912844037336688, 0.13491169940079414, 0.09181297173903835, 0.15604748300486998, 0.1320111373018834, 0.07838831508472081, 0.143489693141272, 0.0889001292507014, 0.1023557588397976, 0.10017637659104602, 0.13276646935170697, 0.12832569514190958, 0.23118226097956782, 0.1296185068185291, 0.2207884549974434, 0.15283812618544027, 0.30388326954937755, 0.19489577100161584, 0.1356876851810563, 0.1423955970113316, 0.12312464761517702, 0.14635251774903268, 0.16277427124159952, 0.1856467608482607, 0.16218424564407719, 0.22058409338276233, 0.19757715534538994, 0.17553933385399081, 0.10522017691044078, 0.13747156687801884, 0.1468135034965892, 0.23860634244497747, 0.21552870981395247, 0.19954232408875422, 0.19934524030935383, 0.32735994205840174, 0.22666819513805453, 0.1254102479546301, 0.21388724386211366, 0.1816098911747817, 0.13136907901254394, 0.13222718941828898, 0.17289053889051562, 0.14754953013072092, 0.30801058356319705, 0.13036303702862034, 0.1947734727253837, 0.13697992229173261, 0.22103839884361914, 0.20129851936813326, 0.13874167936944193, 0.21143050714125558, 0.1450365319127037, 0.11514913606187029, 0.1183157375142459, 0.0989209346833729, 0.09523259671104532, 0.09932962726921805, 0.17883700528933158, 0.19828578667534938, 0.16621270367214758, 0.12999939041272288, 0.09667208358164757, 0.09138633737400656, 0.14853470387958712, 0.21189978196015283, 0.08493092046269486, 0.13896048940237493, 0.14127113315607273, 0.12420395058729958, 0.1324505500134922, 0.12951081017813376, 0.19958804421607526, 0.09536098538627548, 0.21610342897474769, 0.17851429841210767, 0.14543540325135956, 0.12394792400300504, 0.14120166430309897, 0.1626987043287485, 0.19881121573909638, 0.08691213108719358, 0.14061228221943303, 0.2048406647818704, 0.1718721628910111, 0.1503643363473877, 0.17675796523690226, 0.15139066433954626, 0.1884318581752239, 0.13324976357961857, 0.16176055305667464, 0.17032293392525566, 0.12626920105709186, 0.1341359740904262, 0.09824823287706222, 0.12681535279919065, 0.16240981257250234, 0.12690707650636474, 0.13440988116687344, 0.2001943721646263, 0.24072659802773308, 0.12759903776309184, 0.050661720020035585, 0.13387665332805726, 0.11545757072106486, 0.3249075413951951, 0.1821289617087572], [0.01563187566540775, 0.014923746123038715, 0.05649217389403813, 0.01505482855493263, 0.0288998625511604, 0.03557369879056369, 0.08281408163208155, 0.01141486807741345, 0.04744528454818553, 0.031153507448071917, 0.012440800576681092, 0.02434525150625456, 0.006569099092420432, 0.08086374435093134, 0.026580592647435206, 0.008285407525216861, 0.008631926330347216, 0.03864647362441306, 0.045759554036081805, 0.10261786816221091, 0.03935001813055527, 0.04549407775724127, 0.023772196671474847, 0.055862675616217244, 0.0807995768263936, 0.019326908288583643, 0.08058760795862445, 0.046079866888542334, 0.06528674069071008, 0.05908541982212375, 0.015182693417544569, 0.05794060867159598, 0.017986175897080573, 0.043500169225397615, 0.015916840263432073, 0.02575348581998579, 0.07938322581110463, 0.02703747982459684, 0.04820307957068567, 0.022120001658256498, 0.05184639072526367, 0.05539845697762025, 0.022938652790241668, 0.012367657374500508, 0.03989899673709466, 0.03879832374232431, 0.05815971364837982, 0.01899083317708104, 0.040463209002008366, 0.030112451415569074, 0.03168210237016601, 0.0463256087424534, 0.01073715222563835, 0.0587764680535803, 0.11575518055788933, 0.04722545561831325, 0.09184524702328829, 0.04709260448092415, 0.00987657310155731, 0.01953173338645889, 0.04399192489443287, 0.02630276128559584, 0.04125806735828519, 0.046342114106782024, 0.03251369464241209, 0.025550451452633547, 0.03479586290796438, 0.004994423079845166, 0.018397637890771996, 0.022156176330041022, 0.0546920434722016, 0.03741851895146313, 0.015084776847112565, 0.04526639259570549, 0.07452671866743796, 0.003822152704683944, 0.055046734520264214, 0.022251083132540508, 0.040944783362529935, 0.026400969927048972, 0.034086634029424, 0.03824333134557932, 0.026735874839247237, 0.03533277562969635, 0.013830883394656403, 0.051538312296953895, 0.10459285815276446, 0.024354768233493935, 0.04830215772193286, 0.02491523815889753, 0.0352060187217449, 0.038509952925866654, 0.08007037603566725, 0.06257255629245793, 0.18088685739184582, 0.026576572601052544, 0.0722138992240352, 0.0034045404613754085, 0.12457999250581189, 0.033187844354899666, 0.030639941255832394, 0.014095453774526477, 0.032951410469268604, 0.08279328234493732, 0.09286551525996578, 0.12205143504205251, 0.08103547062003806, 0.03580884947892159, 0.015783591717932255, 0.022634948723979538, 0.023065662507208127, 0.05354782987025477, 0.05096832372909112, 0.04988961064467027, 0.006692320025796372, 0.023342135978201707, 0.038327765726153894, 0.04984061166103329, 0.046089511935509024, 0.02072794520626626, 0.0667336662750571, 0.03090392174800077, 0.03967380519175241, 0.041433823249873616, 0.00702996944798337, 0.04463958328649883, 0.04550571846325071, 0.025588679240055145, 0.03974520841673498, 0.02854844269853446, 0.07058578618471661, 0.06700447835629025, 0.046025650846141006, 0.04089194627839231, 0.07202904220790633, 0.014755133043734298, 0.06675801254929074, 0.006597777593865871, 0.023067786485978195, 0.046600151671877796, 0.035986279272624565, 0.02008151063965934, 0.024846022114938787, 0.0568350442054291, 0.018445989530112956, 0.014059711942419171, 0.030973635749110294, 0.08821710824005066, 0.021812467152372967, 0.09455273198264261, 0.0955010185979547, 0.035111824381015, 0.0151846143830147, 0.04719776537029013, 0.049167300814822804, 0.010667872979425857, 0.05066891358564458, 0.06382198824036507, 0.05886036617260787, 0.050602091566449216, 0.031589568525011984, 0.025588246400377927, 0.041097556616389946, 0.017717732942753264, 0.055803997111656976, 0.03361374710596377, 0.006678874703920297, 0.03669541622061403, 0.052594640292227275, 0.006437019309810093, 0.01905712276516903, 0.02140401971466359, 0.031654076958676024, 0.01692414054677131, 0.018897245961031126, 0.024646209147308144, 0.028566338512445652, 0.013962759685161856, 0.046759225998915015, 0.05532132341496407, 0.022904831923604495, 0.037334222466714924, 0.1155307091351959, 0.04943553501019075, 0.03547709893375155, 0.01251945673908678, 0.028069963333226984, 0.019353278950157187, 0.06362629491054723, 0.05144848082695277, 0.05814317764053422, 0.03756722810888483, 0.03064866891250976, 0.04723286751898066, 0.05032232008694161, 0.030019398545846347, 0.06682636291389504, 0.05904254188100177, 0.037266316433106704, 0.07275700193619536, 0.059939680636049285, 0.022982432799894485, 0.02007484758993791, 0.04597246902243746, 0.07898558787400685, 0.005614764212946138, 0.01979358415419777, 0.03256463565893712, 0.03588943809811627, 0.052575315724337296, 0.026962412784116405, 0.04716985678720859, 0.06278465539517422, 0.08514517993335763, 0.09642655240191568, 0.04602319553434368, 0.017429990318393516, 0.05722233612510947, 0.041781359036723455, 0.013826684275221442, 0.03092432266942436, 0.033236498598970717, 0.017036728658563188, 0.02069531177591172, 0.04811897077747891, 0.03877575096163539, 0.0009386429449096473, 0.07200478020334436, 0.03676901811793928, 0.0423204857525566, 0.10208167556312778, 0.07705235733620583, 0.06811743557092644, 0.06780946056448645, 0.04939904624235727, 0.042096749774270484, 0.04385063529855782, 0.010890882131793808, 0.026108404779205882, 0.021156190271158854, 0.047711385188684355, 0.021447569897939122, 0.019502436269014593, 0.060864727974178336, 0.04652589859981691, 0.07727429300786988, 0.03317863214761019, 0.034801367249700337, 0.028624980627829512, 0.04568931909518377, 0.02352864008336779, 0.014148950651888887, 0.015436490685979446, 0.021601304592144106, 0.026869323525217273, 0.03486764917690908, 0.017857967252512614, 0.028545973980198466, 0.03959575998446634, 0.011695078142257708, 0.038111342057105035, 0.06508867631876661, 0.052699268750485875, 0.02408978608136456, 0.06394115321698689, 0.011162658526201644, 0.07376629979379716, 0.014857423976213943, 0.056303283424987915, 0.060425483801912885, 0.07481289847243218, 0.10059497469375211, 0.0660461942935663, 0.016682096982314702, 0.0685468201916064, 0.049915106050790324, 0.026801044023745967, 0.06755593142682506, 0.023770658749966853, 0.023063525121899384, 0.030856575599060427, 0.07213203506844659, 0.00929266567372026, 0.019362142587441112, 0.03176062446718495, 0.0929762839129375, 0.03755870538072721, 0.005919532183813112, 0.08150846096536807, 0.05807761966641392, 0.06437262925770014, 0.04258415789433545, 0.041113391653784824, 0.04338129536218701, 0.06006686272279871, 0.02051623297795173, 0.016971743335166288, 0.025876682334309144, 0.027469589803067428, 0.04415353114205984, 0.038492876826034444, 0.04832282677412995, 0.014418018925484392, 0.019027007848865563, 0.06884572471702291, 0.05596250836406985, 0.05134176094866088, 0.015984572969647427, 0.05418455235720162, 0.03509468316370922, 0.06830042333252008, 0.040144447477594505, 0.009815431624320487, 0.06647128116099105, 0.006871495063551852, 0.013448589241072057, 0.07219787266465925, 0.02773782208321556, 0.031940988377637924, 0.047740665069150354, 0.0757975206379929, 0.0224581892572103, 0.04128544734069898, 0.07198670052833135, 0.04683555899969032, 0.027099012006675045, 0.047358138216359, 0.034193261977164977, 0.07731346308343834, 0.0732603523459646, 0.01337976964761413, 0.023161287517136624, 0.034563776571303606, 0.03999436702278834, 0.03717301458480858, 0.009216069330220983, 0.04380897160679583, 0.024067941084203702, 0.026489725043516488, 0.021174704701068903, 0.045955752983929656, 0.02226528831787648, 0.018696383452944217, 0.06400352043490257, 0.0628715604093046, 0.03343555122433651, 0.043314350768923766, 0.060302446250833815, 0.011211101138483615, 0.061529094743872845, 0.045865729991947456, 0.06338181327127161, 0.07050242815767566, 0.09599811773026183, 0.15094051107523904, 0.1496434169671228, 0.1172845142202512, 0.14667666487155423, 0.3065190716616569, 0.15231075125836557, 0.1324307236580118, 0.1685455946191665, 0.14348272174116106, 0.1502770176457782, 0.10895651795210377, 0.16694172826265136, 0.17445646857302036, 0.10874803478439009, 0.06795243555379492, 0.11333376815121983, 0.16942579900064778, 0.1784350695989786, 0.13644540742520364, 0.1883333545899199, 0.14353766556709044, 0.18662986615973134, 0.23412575464575525, 0.08312286103084203, 0.15649769755621112, 0.16115247842765626, 0.1913151832958383, 0.20071318222870752, 0.14967318714386033, 0.24903381033049476, 0.11891457312289747, 0.11300973594188692, 0.15110273785408468, 0.14860098580679587, 0.1641682295068618, 0.22046672871276257, 0.13650822663499465, 0.17055672863798757, 0.09815457862831893, 0.13606720513874485, 0.14498734906796487, 0.07691310553420937, 0.07760309794497106, 0.09007306348892952, 0.12801092493558122, 0.10700697740239483, 0.10459052924547466, 0.12623828174846788, 0.1319817348473495, 0.08684466172370219, 0.12843104755325666, 0.22371822036802771, 0.26596574773711545, 0.16870959872199645, 0.20340162990314348, 0.23176281773034604, 0.1266428527812804, 0.21975435887373265, 0.26731200936821203, 0.11106141347197757, 0.07706408614232656, 0.0683547466272308, 0.18982327302857754, 0.14467113861633887, 0.13671810408273052, 0.168492857126459, 0.10450943117781032, 0.097797573994725, 0.14636114389906008, 0.12372068700290496, 0.05895890040142883, 0.1320748145301496, 0.141198982995364, 0.13128087164894228, 0.14465060745996816, 0.18896934546289906, 0.12388401694836156, 0.12398801338408263, 0.13846397249689027, 0.1769199621893706, 0.21871831688669421, 0.19558240028638996, 0.15650339725036777, 0.24893729857379393, 0.16463122240477995, 0.1995761698532489, 0.16275853579563482, 0.13153502897870156, 0.16976358248822151, 0.12109266834393626, 0.1928419965289293, 0.1494326048921193, 0.30307333075231124, 0.14467732860676705, 0.2139907883059594, 0.07806103466258896, 0.27528637178963233, 0.15808599700610484, 0.1349874348529885, 0.1616179074851736, 0.10350247754925683, 0.22658386417934973, 0.1475345301291635, 0.27330459426006964, 0.18084243961399604, 0.20873876528874521, 0.10224156577380435, 0.3191260903352692, 0.1100421334887224, 0.25456953102782853, 0.1786689715640199, 0.1486700409722905, 0.146342589249534, 0.09582127399382093, 0.1344677514486736, 0.09499477237583169, 0.207421952077458, 0.10661528430758946, 0.12668270467510148, 0.11547113047732462, 0.21585403671187742, 0.14466573003559344, 0.0966401606978428, 0.09460447356104852, 0.1004237846861924, 0.09147239969142022, 0.1985383045769507, 0.13920493273725434, 0.24886366220251208, 0.24139741525775005, 0.16995390937212976, 0.11901441736206894, 0.20151090958426077, 0.19326783416251983, 0.18043685734512346, 0.19888457631872547, 0.13886328816654223, 0.2026728964260509, 0.16510881693853488, 0.11998631480720737, 0.20816154868131687, 0.26293642157989167, 0.1430152548897651, 0.0641749632514773, 0.13604995283869006, 0.14671818683705024, 0.06779467506754784, 0.22949469185644583, 0.13505219992610717, 0.1177401067088208, 0.1458857250550101, 0.1662058548461045, 0.12650737779275065, 0.08217512599883542, 0.13294122932899383, 0.169205701940002, 0.14582607744922563, 0.09526847260853938, 0.14375387090108088, 0.10869027175489934, 0.1096517427433883, 0.1727876992475602, 0.20665336670654438, 0.09756206324504269, 0.08699548145335528, 0.1583613749713667, 0.24525924916228942, 0.12176233644206678, 0.15351537855402117, 0.11034558091552989, 0.06761470569237586, 0.145167670843582, 0.1864968426525593, 0.15189275836511967], [0.030849416507408026, 0.03293842527895205, 0.02658186626860932, 0.028973299739581924, 0.04104653899107249, 0.029317150643515973, 0.11381892397278741, 0.012385013096425082, 0.019685897089901472, 0.03135130177402208, 0.05751924882192285, 0.03308041201483819, 0.0565896739041613, 0.038899681005146236, 0.05938330545060097, 0.10231291920307184, 0.06127491826191545, 0.027883669902240078, 0.04643353137878641, 0.06792804331428583, 0.04288276747590111, 0.02961914824892677, 0.051385745886833444, 0.03759985579357993, 0.034997631315021746, 0.01890036585410276, 0.007133768137258988, 0.0659926294259006, 0.034678073059166634, 0.02390244310992139, 0.07126340627550118, 0.013211417995813875, 0.10310045758923216, 0.07865013329372292, 0.05955525771564534, 0.01707685251359738, 0.03325375089902551, 0.03569267224520445, 0.02270422605497222, 0.07536819730434688, 0.023541272873239174, 0.07746781447842237, 0.04419416444556368, 0.022521115719310703, 0.035478807309822696, 0.02375545765032932, 0.05500696306567519, 0.05112237634978468, 0.05285915513072283, 0.047746851229138916, 0.0567207707002038, 0.05069497206638898, 0.09537296700141124, 0.05111522874945114, 0.058787116675727794, 0.06571022643437309, 0.004136726361579232, 0.08739403869596221, 0.005398378848293496, 0.042050899412002296, 0.025696347152153333, 0.019558898864253875, 0.047109282215035735, 0.04989107004216602, 0.09900700466166582, 0.045275620124753446, 0.09772065876712722, 0.03744261624712137, 0.026528885542985894, 0.02980729178225081, 0.038408760371948444, 0.015314357118651032, 0.01992287106751915, 0.049251601130010626, 0.014761165028528101, 0.019928620557390878, 0.04356487301148234, 0.04248314537107945, 0.005484872090164573, 0.04354354129323075, 0.06610875303346304, 0.09698777309348507, 0.02336533886620835, 0.0677602700588684, 0.024553047110056205, 0.0456455295094319, 0.04961171608057715, 0.03249021021709327, 0.061190909060138854, 0.05931962439189515, 0.045899154408083814, 0.05878512484712466, 0.03229371249495495, 0.002974428057167379, 0.049450852938236735, 0.01632484528536518, 0.06589909009034596, 0.030979875535253557, 0.049817222996705005, 0.10121572807791734, 0.09847262769096321, 0.011936762602999808, 0.04907923900792676, 0.017852999172323657, 0.004362367025967087, 0.008391155429454821, 0.016406525579851963, 0.016074531801765966, 0.1640301498193895, 0.04756711934122348, 0.02214483822876167, 0.04928520557680919, 0.01971667467225944, 0.04531894622731113, 0.028952684313539537, 0.11168331598802922, 0.0313993776217103, 0.018996055981504823, 0.08388472781065973, 0.015442500645745427, 0.09179216479101489, 0.018451371297781027, 0.01250481871407359, 0.020179491369955, 0.0650532370913894, 0.08905703937935253, 0.057367368060494625, 0.05842112200034242, 0.035326761839490746, 0.057727843072385564, 0.0897863474223883, 0.01626166984468939, 0.016383675092290488, 0.014415419014591365, 0.06981602869927883, 0.024969245442339492, 0.002655545873905442, 0.045296212568158106, 0.03937923289354771, 0.026607853886220726, 0.014403559973523503, 0.029640116075414325, 0.027861164154244528, 0.03296415051144939, 0.021314877723794312, 0.041188429965968096, 0.08896527736778222, 0.024635803758076603, 0.057401639003787315, 0.09088835724058653, 0.01881238448643877, 0.0663003899277218, 0.021314722590989644, 0.06991872278552863, 0.0038024582599680275, 0.017845949248200463, 0.023883850155999104, 0.07846169864698764, 0.07898557255224836, 0.026629486293982596, 0.0241507513583788, 0.026124069362037608, 0.02726787693738457, 0.018492481491017728, 0.04797086682951739, 0.04715304881814988, 0.06445317574205899, 0.016476235750521866, 0.08493206193370205, 0.007077104922744536, 0.06169619001147728, 0.01565799830601581, 0.05278718500067631, 0.06499322942428051, 0.04267216224463717, 0.05666460113359555, 0.08405518237381213, 0.019115211382027597, 0.0033367773510455606, 0.04423336899508873, 0.022917709861611648, 0.009438322928373613, 0.0703699792164468, 0.09976743119618586, 0.048034306570527055, 0.02820857353658686, 0.04017597199567864, 0.11509457527990304, 0.027423557494917226, 0.0576140943373884, 0.060280268005425894, 0.014334986485811252, 0.06588011409246153, 0.03655338734989205, 0.021289776852955262, 0.065172900025162, 0.026185626441973354, 0.01770835219612045, 0.026127861497262796, 0.011232046939943348, 0.02684691353821226, 0.06833937890346974, 0.025094765118293227, 0.04558309717404266, 0.019786725752055645, 0.037970155883099765, 0.05901839478962845, 0.08538926320691263, 0.04169753752648831, 0.03939096553010806, 0.04098072437749755, 0.043690365874358726, 0.009601961224219732, 0.014225003072961926, 0.038456855371834776, 0.023485764057465622, 0.018340085535460425, 0.0979335775839225, 0.04642065727121888, 0.03330132878956295, 0.030866435150645917, 0.037220098348634864, 0.03081706269914585, 0.04596955405788557, 0.035430379061689304, 0.023417930802210205, 0.05062513166077195, 0.10863369616169123, 0.00860061057122244, 0.06936622017453756, 0.02801485862883349, 0.034935237284028725, 0.00565960621198399, 0.11651876337465741, 0.04045360608987751, 0.042936914570389256, 0.08616530261332951, 0.009764678299336905, 0.053534622514440175, 0.0642712145382839, 0.07488745414922315, 0.04263646637780532, 0.05925076840926082, 0.03485872808303084, 0.03780394161660825, 0.0455708627498919, 0.030813230344304637, 0.02591204686811374, 0.03407546829792761, 0.03913820248037096, 0.004751378813037469, 0.028779864453920917, 0.07992637448854024, 0.03224137719840773, 0.0027841045248938067, 0.07327806429877397, 0.03064519853421277, 0.051326891182050596, 0.015971803241559578, 0.08480719726292357, 0.050343180661119764, 0.0633353308864659, 0.036458158790464365, 0.07990880043155725, 0.03023054578431672, 0.052268102975381966, 0.06756974399209985, 0.04222387823486521, 0.02757124775539964, 0.031626323508399154, 0.025788790981976256, 0.09874046735105016, 0.12199051573031372, 0.033516622478923494, 0.04837444960890759, 0.0730499692801987, 0.06987713187211944, 0.033245419692848964, 0.04250076922377752, 0.03159486027734895, 0.0681765239325262, 0.03828233288180444, 0.12170376902025555, 0.060566428658222, 0.05859762865809664, 0.010158812341791008, 0.0966295810236085, 0.02509559440847126, 0.024725047255595847, 0.02008888423593054, 0.017548310683078824, 0.0077462109038606295, 0.0522782574708183, 0.018246984785242427, 0.03731390581496301, 0.03868572413921356, 0.045583116326240763, 0.022080170831853346, 0.046898309261568134, 0.04045979608030569, 0.04258782362505313, 0.06608347979284103, 0.12280031663155365, 0.023038809210242286, 0.017847944907243216, 0.05995633538752314, 0.04379579872493783, 0.06828566081821918, 0.008728906358291787, 0.02223474439233542, 0.022249196641026966, 0.022217547633655133, 0.027689841996517875, 0.007069887416887909, 0.09290543610170003, 0.0796597146038567, 0.023746320136612462, 0.023850151863429817, 0.08571404618241134, 0.05715536471876887, 0.017045214997544404, 0.02739773267098973, 0.07510983415188328, 0.01167626110761757, 0.10272282220783735, 0.07981135404758877, 0.043565700386440566, 0.03948705593845056, 0.03034922812554625, 0.04582802314431437, 0.06530976929371396, 0.05292213138853831, 0.04014867245249691, 0.08205285836612025, 0.004202824427686151, 0.009939899844598147, 0.015492523314371226, 0.049657964808565956, 0.05062844499104446, 0.068655060754428, 0.033033856851679665, 0.03624543532608979, 0.059491998005297884, 0.018185251505084096, 0.08578528469849019, 0.024640344744247776, 0.07030545163058466, 0.05755973656872108, 0.06683707282307648, 0.058980802855184006, 0.008376314391141698, 0.03464030109405999, 0.1969881716274446, 0.20105615979240787, 0.18977879396369382, 0.06464041529163238, 0.12736547287673722, 0.12994387968172952, 0.3052507364942182, 0.19942175717123095, 0.2260588947683573, 0.09738867456514029, 0.1924750863784744, 0.2070574934083608, 0.14873183362426298, 0.16640373535694616, 0.3177217898830291, 0.17887762327107692, 0.16009202887935026, 0.14056538231670856, 0.08770402085276381, 0.22319585565597783, 0.11714491001780956, 0.13307546325508626, 0.1454545094841911, 0.13927181221304402, 0.11868163642864074, 0.15812537392541287, 0.06849431252527623, 0.12529329697210945, 0.16247359705307793, 0.06692259887894315, 0.13698055048383054, 0.16684285695514373, 0.13169146413283964, 0.15067009735972653, 0.15629099171248176, 0.12630817194979999, 0.179468460921799, 0.10891329527141587, 0.07511176469345247, 0.16758780085271405, 0.06582300989858567, 0.21296913345013896, 0.17170284213798662, 0.1476801021565353, 0.13357388005862314, 0.09914063337829807, 0.1046092217908271, 0.12635109585619744, 0.11630314792836867, 0.1098486656443246, 0.318127540691245, 0.27088397092396216, 0.22185970638548175, 0.1399516386370505, 0.14071406466105293, 0.13622636756589337, 0.07217688185553398, 0.12392823554335103, 0.2039553582548134, 0.1751908711007526, 0.17198775023702653, 0.10311187229930394, 0.09541831940652863, 0.1326168677018535, 0.19795627693735784, 0.12039797215331947, 0.15128247740287937, 0.1366853308413298, 0.15939013912312447, 0.20734333613466835, 0.26289159011456276, 0.09086981025193969, 0.07798325375563676, 0.08331727116338669, 0.11335835957358922, 0.17318713749128004, 0.14908702262947637, 0.12669363674978096, 0.12597065659299975, 0.12303724464389587, 0.10156213005463924, 0.17824987550416302, 0.15896269270489294, 0.1693034087938647, 0.2234669588506222, 0.1678374229419616, 0.1042910271714772, 0.17983033021371211, 0.09091523160497028, 0.17060975724410626, 0.15274280952590127, 0.151269561160476, 0.11421707518879445, 0.15474499563776678, 0.08950555321550177, 0.12511800839415482, 0.13058150998286663, 0.10086517390464583, 0.1331982977928654, 0.14756794688442063, 0.23083601988131003, 0.14041833940052217, 0.16155274404633432, 0.13496160236818178, 0.10952995774606544, 0.16099149271124796, 0.21521188649198703, 0.1317709380941045, 0.23843218001627156, 0.13605868624102685, 0.19600103669349225, 0.11726582167489875, 0.10834596119821073, 0.11647113568840489, 0.07703040125629596, 0.1607776469280643, 0.1900020779501046, 0.08150177301778909, 0.15025748240370906, 0.13306651534813066, 0.14757027579171045, 0.1018936162994754, 0.13171317506461375, 0.06586727445885059, 0.17749956899112274, 0.22838942616456942, 0.3257667549675511, 0.15965804007024537, 0.11670820925745273, 0.12470392254932273, 0.16336015996433076, 0.10149464536938937, 0.07767135637902445, 0.10309315677131377, 0.16671844427624058, 0.12362648883173544, 0.0806957719126536, 0.08928976156899045, 0.17057454784310636, 0.13308998828213062, 0.06276658338104045, 0.11370152865927066, 0.12008314832083641, 0.126278608616802, 0.10094529137976709, 0.16488812232930816, 0.21399697829638759, 0.06630412843679229, 0.20257681367858765, 0.22960600443184379, 0.13190887988575045, 0.1932533857442679, 0.15811518495601995, 0.2291911678208459, 0.13906499911700526, 0.1207859343999336, 0.19630895807377755, 0.20025405041392774, 0.22728357824587056, 0.11349459298916402, 0.11626199368507632, 0.10567586132956129, 0.13205641309820837, 0.12472816923212622, 0.20118306991794419, 0.15419673715387622, 0.12674583032006217, 0.0942700608603416, 0.21113579311678488, 0.1423798462436084, 0.19896913710380756, 0.13886098990276938, 0.17632878745996183, 0.0932969146918866, 0.12934409412405184, 0.10484887707617976], [0.019504060375414068, 0.039184857234959646, 0.06288812706066717, 0.07056638883847384, 0.05299520085475618, 0.017416712099445925, 0.004459313058760017, 0.029438736457978527, 0.050778127080130006, 0.04051425727084279, 0.05018960684537888, 0.013053030275078792, 0.01860139238077306, 0.025459026519749916, 0.06996808949136926, 0.043907505835616784, 0.050342468199350184, 0.037050421364725604, 0.022865451173856858, 0.029008158655356497, 0.055728564264192704, 0.016784827457740903, 0.05652834473538303, 0.01811336947514886, 0.10687186247518948, 0.04548031498768157, 0.09666544159934407, 0.06277748864264258, 0.01690639028956573, 0.019067509002202464, 0.08252194932391567, 0.010583981563667617, 0.04176494560294575, 0.08105004927323711, 0.10549465855283123, 0.04556000728400485, 0.03754682718746124, 0.017512639714104515, 0.016492059296597878, 0.07659373880033532, 0.0325017053663971, 0.017894323870179155, 0.06302401573667604, 0.026655812905500495, 0.047914455945213, 0.01378632389054063, 0.04405829875219253, 0.017269098447755944, 0.08070077446679916, 0.03682112358810921, 0.06476760120882143, 0.045494836184286305, 0.045625396718781804, 0.021996740026459582, 0.031172023793201775, 0.025550710007307992, 0.030536864125620455, 0.017934336642464323, 0.05922098674120442, 0.02202784702662499, 0.02780457706971755, 0.05267003483529534, 0.03689857507725397, 0.04893990293625863, 0.03495037901185213, 0.0410179409288591, 0.09029100018162882, 0.09935948171562727, 0.03069453459653643, 0.03411528954823171, 0.008262067698993751, 0.07526453028643325, 0.04342321569340364, 0.012737646240801101, 0.02632732589488789, 0.035380644633645014, 0.12962941591057087, 0.019263206162459908, 0.021052318324725476, 0.06021882009301936, 0.08965863290453151, 0.04925026813702238, 0.044331627432256944, 0.008791959224899691, 0.0374308989323195, 0.05732333715704661, 0.02372366500147168, 0.08153978630059189, 0.03982087875145578, 0.03772642884042956, 0.03516405625569244, 0.02117127645760775, 0.029104825544862017, 0.0009531020165717741, 0.05111167410148248, 0.01817955372614726, 0.03682029621315099, 0.0061138451189523746, 0.050461177353657065, 0.09005132191363843, 0.0427872822770188, 0.03707711952888677, 0.015183437480441025, 0.006817722873341653, 0.06245062956886907, 0.054494879253569155, 0.011101572590339328, 0.013029367734317579, 0.04246098244743001, 0.04029558513373618, 0.073013189398954, 0.06937177431198858, 0.022732780067129962, 0.03815893526940096, 0.030721711565650282, 0.04274241633773331, 0.0870829993378251, 0.041058390371261105, 0.03998911932050701, 0.02207668704701768, 0.08764710818086902, 0.04957438078558734, 0.02140478197214825, 0.025401815073564652, 0.011185765653217753, 0.03493556287139654, 0.05108463119775538, 0.05598124304425813, 0.07652882050963179, 0.10463436479650198, 0.05894882251478492, 0.0198946024231132, 0.016931257503587874, 0.045883729227728424, 0.04926156410346589, 0.04879520807956015, 0.0055091211669928124, 0.007413684694667257, 0.027777409676702756, 0.019892424818188436, 0.061126998175055756, 0.014198652521196394, 0.02664378340986948, 0.09725522204873063, 0.07088890419371667, 0.01661571929411542, 0.05558337145034344, 0.03548154607415199, 0.013610418611806969, 0.005362090220930236, 0.04732217804919328, 0.03947062335247475, 0.013173625920899214, 0.07277398610547667, 0.07054552060341643, 0.042696588958102855, 0.06043704023825065, 0.04527004300466469, 0.07381871552957643, 0.02606688472892969, 0.030410089980690714, 0.009896138987143435, 0.06729009891709975, 0.07853613174971073, 0.03527847148718373, 0.05018147099162302, 0.1243223111716009, 0.060435534875479445, 0.031545637212994124, 0.01757042572623299, 0.042527444405300964, 0.013680883379082286, 0.005277804269890992, 0.06393125153056557, 0.01696219021875051, 0.028356497453886177, 0.04586845726495789, 0.047222529162442496, 0.01400215767188779, 0.028407405911674424, 0.06707802279702119, 0.00999501699792041, 0.05475394337648346, 0.01708057378568957, 0.1291915660183276, 0.05442137311723444, 0.04927659474854027, 0.03729462721234849, 0.026416268702896855, 0.03894308754693597, 0.019848359440783822, 0.1323109534719298, 0.04474564432917584, 0.03449781640102306, 0.047826715895245155, 0.034533305424115354, 0.03824705836333094, 0.027327903756691564, 0.03734151179331445, 0.03721318057467861, 0.06044666613301924, 0.050449111468849644, 0.020259063007430207, 0.04878591160259901, 0.03819801724485813, 0.021338942460715774, 0.08936791785902555, 0.06786169243916389, 0.007415780423945117, 0.02328926250488768, 0.026582823878514673, 0.0332679235256247, 0.019544415972045353, 0.023161371786808296, 0.047390459465884396, 0.019771020949607896, 0.008469584638312941, 0.02584853434875127, 0.031243528524834304, 0.027057838611184593, 0.05482737673446537, 0.052989405399609, 0.05251316301104042, 0.06429130136365853, 0.048868308189294996, 0.03592644014485902, 0.04244869056668493, 0.14893221158173778, 0.08611190628500716, 0.05390666928442736, 0.045023017953480446, 0.0376494599866771, 0.025969265975178252, 0.03763616453075121, 0.07059209874921268, 0.06720798961337536, 0.010847204586400861, 0.058071000666748133, 0.011648816007730222, 0.05327010384550499, 0.026534399460820902, 0.05458543850709835, 0.06627233578793465, 0.05637685850923581, 0.001457976163252287, 0.039586988277733326, 0.007677451161021788, 0.007256723333886194, 0.031231610111952312, 0.0252821981050675, 0.04629307298830921, 0.004869779138149875, 0.029954191056951403, 0.05793783926374971, 0.014325571265221845, 0.062374698764254013, 0.061201733882508935, 0.07574346547405567, 0.028893900471889687, 0.04406608986638246, 0.08075317488081994, 0.12217656018272524, 0.01711728280380128, 0.06117281789380697, 0.06888307150333159, 0.032180427243151975, 0.10969355582229554, 0.0335104669624519, 0.024919187342147195, 0.01615236250443324, 0.03950312463266235, 0.031244532100015113, 0.04273738697051041, 0.02630740952407641, 0.036388678446171746, 0.03366117560935598, 0.046436293125753446, 0.05043339134464341, 0.030830137904793508, 0.05062064621597529, 0.034473385857117754, 0.03900747340653212, 0.02764692000534025, 0.09122067852126015, 0.06744067349861707, 0.03538201593102948, 0.059342522759951895, 0.023524018657964565, 0.06058200705616225, 0.036712618724953745, 0.039647091705832756, 0.04738426947545621, 0.03120319974128037, 0.06293120035420983, 0.004651466104757762, 0.021577096213736845, 0.05322503489291957, 0.12405596538296632, 0.023735744292817773, 0.03808532188075685, 0.06110968841840664, 0.06938195562050228, 0.03516213720544212, 0.040203374960730155, 0.020972313847573056, 0.05587449252244927, 0.012542111874227563, 0.040970615847336675, 0.06579775964060137, 0.02262386917737463, 0.025301857836424343, 0.05179361492815999, 0.028353323934659846, 0.07445645308302296, 0.08276296824577355, 0.029886804047911882, 0.01777665084978986, 0.012875597608546096, 0.06106279234612181, 0.060153373201648076, 0.03604835920756863, 0.013848783996617122, 0.014129701735181435, 0.07773173176833699, 0.060763006819592374, 0.06367679159607618, 0.016920147313465996, 0.04391807401853223, 0.02008000336166832, 0.05543551648095731, 0.03383888119471169, 0.00843027666691811, 0.06526321413055544, 0.08920102560472104, 0.10337151481860107, 0.08291920421705132, 0.025163071432841883, 0.023751732547797506, 0.013393952807922278, 0.04453826815851274, 0.016421776475204576, 0.02514355725819065, 0.04062899425926228, 0.08218294775654232, 0.03427054492696639, 0.052601669148932544, 0.05803844959084546, 0.01975397932373228, 0.022321356377834757, 0.030651763907723853, 0.05156060928599008, 0.04223875183191511, 0.20665411747271017, 0.17114010459232717, 0.13628546358837237, 0.21254597712428341, 0.11095796095868272, 0.1931016850135019, 0.15706942897410164, 0.06578865085518168, 0.23991364084424513, 0.19221803323636133, 0.19712424416455532, 0.11631602586637582, 0.11537191443025105, 0.19887078673608843, 0.31104003229448873, 0.126534144904825, 0.12912968143580422, 0.10469036582376688, 0.10502897668629886, 0.150318248497863, 0.09314573490090909, 0.2133966871206799, 0.1686134087222238, 0.0932930306261105, 0.19999923424855356, 0.21886568155980882, 0.18637103569363395, 0.23547888042465334, 0.14725165982400218, 0.17389365441856847, 0.2588469523095316, 0.15803482233276292, 0.11819160062699549, 0.14968927499027024, 0.24992786558164706, 0.13451330303665132, 0.08139612949303082, 0.1208868051969236, 0.15146776342824583, 0.18037382363071366, 0.09062250174822346, 0.20487348398854657, 0.15077741095615974, 0.10824835393577815, 0.25972311174677265, 0.08297647695027052, 0.1596119062554452, 0.15862259563178788, 0.1857285330732984, 0.15215111385670402, 0.09602057176732248, 0.37977819060606344, 0.14933983164448894, 0.12495663963378438, 0.24931920872580624, 0.16436417947613424, 0.12326294946814738, 0.0920185131291228, 0.14710743611137714, 0.12570291652434296, 0.19751275799447493, 0.14810137390609712, 0.21905890425607083, 0.10996599200992815, 0.1484761900839306, 0.15053920357698394, 0.18947572958084846, 0.18804997866672857, 0.08635352275544599, 0.20814428105950358, 0.08752876291832618, 0.10326030183463328, 0.13516718972354166, 0.15152140490470395, 0.13020523823797703, 0.09897059250262477, 0.2790561066039147, 0.1039891195813975, 0.1563714309445312, 0.25526687022178407, 0.24134001995046295, 0.36509237702815767, 0.1689727346022283, 0.05284920747902605, 0.1862751674507895, 0.18990640889012045, 0.15322368291597213, 0.14659369754935467, 0.15680093047839982, 0.12952371109877864, 0.20455943390486703, 0.13455511611555854, 0.16833021666013426, 0.14186440696639402, 0.13065802684474376, 0.10929568805882048, 0.1169388630096951, 0.17148081453577166, 0.10733517713003582, 0.20601785080807827, 0.10444795262188682, 0.14720675174988088, 0.14917414214822555, 0.08627876023491544, 0.1501296836161806, 0.12550158861784205, 0.09775004589990263, 0.3504547963459646, 0.14558267599392324, 0.1154832806318037, 0.1589004557219244, 0.14670876395558158, 0.08767775935871948, 0.21699800516568848, 0.18902706252711435, 0.15086938747234885, 0.17709695914339635, 0.11827798470133737, 0.09887816399456033, 0.06437391628541293, 0.19955664993293826, 0.2360777160333049, 0.08843053267487595, 0.09873381004698815, 0.1173879437509083, 0.15221166544623915, 0.0638504522371917, 0.1677371420326733, 0.18127843557346254, 0.2072768397028408, 0.2287629553146901, 0.14184240492120867, 0.18853869679714405, 0.1386385639348338, 0.2318462600270587, 0.1703793333182412, 0.07457222429014022, 0.21615297954169013, 0.11253152853779255, 0.1260848879633892, 0.11420268805757647, 0.10511739089364007, 0.12525166009342478, 0.23628085190730713, 0.1319976081891406, 0.10395236268279054, 0.19638063325997324, 0.2777743802195595, 0.10468728615031128, 0.14793068951656743, 0.14897598584573116, 0.18987746608834113, 0.07481734178239301, 0.19259363082387757, 0.22229210173170413, 0.07818734723954432, 0.21000847941444767, 0.18718019308101747, 0.16282576767186965, 0.1359956065613416, 0.12819099390218336, 0.12318580441417233, 0.10802180641480993, 0.189461327127872, 0.16373005785769032, 0.10117805953468047, 0.20992024140732907, 0.18419381381282884, 0.05859608499092921, 0.21852325557941393, 0.1937127320636665, 0.16473545632775755, 0.12492424943634581, 0.18754848218973608, 0.12177032673911703, 0.12616195640857183], [0.10619637210883441, 0.006244975431341559, 0.03659061922301208, 0.025941878331885226, 0.036557715746664235, 0.004954665510599772, 0.06248065638506125, 0.020673210139296228, 0.03368140033055698, 0.03554295568216232, 0.12102317650832477, 0.04839766973389253, 0.04620920168235899, 0.02402160808654322, 0.04164251709176649, 0.04815509565354836, 0.007163022641062497, 0.021625196959282604, 0.01911038694332444, 0.030482830029101144, 0.023252597536831614, 0.03454159832589569, 0.06178393772232437, 0.04273821434546863, 0.07009441739008312, 0.02042650876026, 0.04874591415207233, 0.06718232566791196, 0.04175421271112658, 0.04808580300079719, 0.03333572230692352, 0.04872335669314189, 0.018859422284989588, 0.025464101852248275, 0.05754829887601157, 0.03137104194461098, 0.06994219571952859, 0.029985056739420663, 0.04095101931823358, 0.05343702674332646, 0.07731945389100621, 0.1237727733208768, 0.05747783793917587, 0.03124299226328731, 0.06513310941837488, 0.029722436053317883, 0.028411977541362567, 0.08852263176513296, 0.00715473500613664, 0.04683804878544423, 0.031946870017676585, 0.05674404062090382, 0.03869838757260192, 0.01423006499892161, 0.05175430695676515, 0.032398252853102265, 0.07273652440597934, 0.013240599242459624, 0.038996150627011256, 0.05758445822603761, 0.05968733510423092, 0.027164581472114212, 0.02539558486352044, 0.030665319833543994, 0.021965257643211274, 0.04487728504764457, 0.060873465206954754, 0.044913521006463036, 0.06684427404956472, 0.018270543904133865, 0.012647215306999223, 0.01727588790198488, 0.03450019127358833, 0.03516873322247017, 0.052122787587464824, 0.040096203090562936, 0.04855682833060142, 0.04310092633409847, 0.09238294881558226, 0.013662489608020313, 0.027984659442858353, 0.03720894410845734, 0.0531549378478479, 0.03483050923433996, 0.058969966541495056, 0.03348011838933153, 0.031042355751138062, 0.023594916264917103, 0.10297464296942758, 0.03011648103805079, 0.03016302854033007, 0.017769662212700616, 0.029767365194857124, 0.024212582314747478, 0.05466996481822384, 0.0635853398501152, 0.013380692783562888, 0.007681619158134826, 0.00935922913824118, 0.04191076277845329, 0.08944677128907173, 0.09571332454441056, 0.02162277803666169, 0.028345479194315213, 0.040922616608440876, 0.04727491808514442, 0.024253194550833395, 0.02155876564492862, 0.01898165544374816, 0.039831301377665614, 0.026480154690122413, 0.021366536947748354, 0.035038126722699216, 0.10924678866661365, 0.06056252160980817, 0.03615192280361249, 0.028066966014223236, 0.05947089611342358, 0.03687489529951446, 0.03087901622958241, 0.04697508659333952, 0.011624146061348579, 0.016896511585782134, 0.0865579303354025, 0.02029633510016626, 0.03269411217901976, 0.022691897785050735, 0.025098635777530652, 0.0348102921740182, 0.06476450621360733, 0.036480314053234555, 0.02781831111098009, 0.030595400903914726, 0.09376540044022184, 0.05364909520252578, 0.05280873505398632, 0.02467367531461341, 0.010750679423161333, 0.03404809597639307, 0.029051013613840746, 0.07221180014312267, 0.09462239235759744, 0.04174813763388703, 0.03771000391533298, 0.0019327245606672802, 0.015195004450487755, 0.012407738137088958, 0.06137477782284541, 0.0234335360132278, 0.022139774387582176, 0.06769123787601149, 0.05246997863474873, 0.052319135922457904, 0.040286484009195725, 0.019104308035645275, 0.03606677213082871, 0.014153136364785174, 0.046888254357561956, 0.027426455222490816, 0.026352537848475962, 0.10117307996317264, 0.10256110104702174, 0.05358200505255692, 0.057646070847347866, 0.09315230027442017, 0.029907846567972057, 0.032949024105384465, 0.10080607788216683, 0.04989180165613371, 0.04690705032478418, 0.016645604384041602, 0.02228883594544905, 0.01068797225372926, 0.028129785224014235, 0.03510506365508322, 0.08101307787001133, 0.07990848633550829, 0.04360624942027273, 0.08196153302466677, 0.00955496460289484, 0.06620172546395371, 0.037505818500874505, 0.03762307208812526, 0.0184254871020394, 0.02348443106447737, 0.09813919558279938, 0.06782531092363982, 0.004363896328985932, 0.04470270510101992, 0.014660500117667742, 0.03133004474934311, 0.03512865150227182, 0.017079769393369075, 0.02659783728661076, 0.0655683009855209, 0.04153400073729215, 0.06703051768483655, 0.029835763439956694, 0.02427341735681459, 0.0424113322890574, 0.033774771126768285, 0.051807151701782024, 0.06105718075207645, 0.034526759202802376, 0.04101714802785747, 0.03521138899809411, 0.030397041588120406, 0.027373371074997613, 0.06531091842560038, 0.0672165314937311, 0.05781218935284884, 0.06803429970938353, 0.045507503448114286, 0.036527099042770364, 0.07836630537865624, 0.038631209322521766, 0.0203234565279056, 0.013667391613125803, 0.040996574736650915, 0.018075275753114014, 0.020140836488515623, 0.04547964849118744, 0.04415547700538751, 0.015413781924683963, 0.010265492000466874, 0.05191989303115876, 0.009094541929962655, 0.051109080893858794, 0.008957736821274364, 0.07494415231649915, 0.04707979166039056, 0.07237054122191283, 0.06792656476459197, 0.03350576701303644, 0.020455825029902404, 0.04795170697053114, 0.08491624221806565, 0.026848867062419176, 0.023935446177699396, 0.04926005874069468, 0.06601230256379613, 0.07218759942559466, 0.016802413006042762, 0.033561584179199515, 0.045665187325568936, 0.06631574999060362, 0.04842311917473713, 0.05043857009901155, 0.07260107240008731, 0.00601270331835915, 0.013694726587874035, 0.06518730247813849, 0.014531646044023577, 0.028629770592576074, 0.006226130147209212, 0.039364991319035335, 0.05324973739803799, 0.05453020356775773, 0.044918477595333135, 0.0492920620637315, 0.03509181033399317, 0.041199070927236355, 0.034524437956391804, 0.024746107012634317, 0.04393739092554297, 0.06090395550634112, 0.03636651935296194, 0.01089245931530792, 0.03841511124084073, 0.0447289397819869, 0.029350232235306216, 0.01855694778984593, 0.039625725513624574, 0.031161884619523923, 0.05222380394116045, 0.05142535263251874, 0.04234274826763619, 0.10078689504054286, 0.02247404727724291, 0.06260438724571178, 0.037454260783570434, 0.03669618230853831, 0.027061780133555015, 0.04711089866055597, 0.013524347675904153, 0.009656641707425157, 0.04188124158029114, 0.0591172507753776, 0.0409190581300326, 0.02845633403217841, 0.02497207996765933, 0.05001293547872094, 0.034194541343998526, 0.05102468098724081, 0.00701730362057025, 0.019791961963018103, 0.029848963134892048, 0.036075773663939006, 0.03346300781554273, 0.07286217048644059, 0.04106466846180059, 0.0036566791494542193, 0.0199501016627877, 0.011594435256425173, 0.04141703443301301, 0.05717835501737653, 0.05909309985356466, 0.036185983072726, 0.03506234276198572, 0.10132190020334336, 0.01576844615966923, 0.02436757339314828, 0.008841745363878868, 0.04730795562687901, 0.08166262083837102, 0.01874729957161171, 0.038369506026708314, 0.026784270528643846, 0.036937258686990514, 0.027306987641138897, 0.07585447927516314, 0.054972466126444845, 0.04373969427580315, 0.04413018461256739, 0.037871740397907076, 0.02373978157617873, 0.009214556306570528, 0.04375505433868497, 0.059139938469255166, 0.044474238529801376, 0.030066784914402716, 0.04433065067015348, 0.0560868674168183, 0.02554045975088112, 0.05342406070520801, 0.04005146355578496, 0.01888810653209446, 0.032768801921197487, 0.04460419385483669, 0.05459445919240675, 0.05178701891113193, 0.04227752737220257, 0.03598642482933018, 0.08574169429559862, 0.025166934431200067, 0.029651239672074878, 0.008931136333323535, 0.01758995139220309, 0.04979594873504774, 0.022308210309054104, 0.028550352172685728, 0.011156658142534717, 0.17290043674649733, 0.11382992499538007, 0.12978309314818154, 0.10473456143611863, 0.14679683342335687, 0.15727166086435318, 0.17299903226235222, 0.07691151207132686, 0.2731835217245164, 0.15750202350318432, 0.1920899893006971, 0.08681178122999207, 0.10932252411880802, 0.08151450539909064, 0.08403965377158697, 0.104772498110129, 0.15799015940677735, 0.11063921475602735, 0.11403662317823018, 0.09113556615287259, 0.19735592447461622, 0.11093311672729832, 0.12266330180629609, 0.10492819781985976, 0.25802650278614414, 0.14779371299570607, 0.08007246745570053, 0.16160819349029373, 0.15521810089628543, 0.12676628486764047, 0.160788081045593, 0.09431322225399556, 0.119852808664643, 0.19820412170262108, 0.15948320348416606, 0.16506099773030128, 0.156118759825345, 0.3256703504631597, 0.17569549321647615, 0.1607100320078673, 0.16545456774052114, 0.1951633808353255, 0.14346694032992088, 0.108624633341547, 0.13146631089189362, 0.14474315088122122, 0.13268380846467712, 0.13918014213202462, 0.0985806001230113, 0.19876537303770744, 0.11643367398890758, 0.1582177641290811, 0.13895976927972611, 0.13128370617426213, 0.12393882287846458, 0.11686915666946482, 0.092728209321297, 0.12291909856421333, 0.12007403187453748, 0.11194425319591839, 0.17021617191212793, 0.1317803916190901, 0.1846947280629989, 0.09968727541666839, 0.19967897885268737, 0.09299614857281409, 0.17858191333230466, 0.13869191429788066, 0.11358139841186424, 0.15123254379197476, 0.10934300164902404, 0.18060533540143123, 0.11368450618559316, 0.14401974937608167, 0.08728110201416478, 0.11543470299652508, 0.12043138124769735, 0.14585733383653626, 0.10851103782413468, 0.18344410484836948, 0.162628423422575, 0.08585024895446916, 0.22156807203446666, 0.17193931815845354, 0.1655645779664478, 0.1367211224691522, 0.14446516821701683, 0.11313342849814123, 0.18699211849560662, 0.19628404489447995, 0.19414313558128574, 0.07620959933246337, 0.22966733743106166, 0.15007484704256058, 0.16916483881012087, 0.1742189813164934, 0.21076509849198405, 0.16278216194721962, 0.13084202584239746, 0.11697643196150181, 0.2112922895579569, 0.2646388528087447, 0.14012060698962983, 0.15368966355679498, 0.17096217301103378, 0.09906033204207498, 0.1080055883334529, 0.10662266939517953, 0.16609340846057863, 0.17524648908405535, 0.15459654311979973, 0.14270439173185057, 0.18691786925398535, 0.19400094966253928, 0.22005829659681167, 0.08577393893633159, 0.1041998933520048, 0.1354072510354942, 0.12928859871481696, 0.11695868936517548, 0.12981554463265405, 0.12186887628969648, 0.12049429238803926, 0.2800636347984114, 0.1162532373001018, 0.11030072646756327, 0.11296326504840006, 0.09725529099664382, 0.16307774931192398, 0.1480330388632513, 0.1210143052101616, 0.20661195199335777, 0.1194142003453547, 0.23005580529570582, 0.08227260302632086, 0.18043037624128405, 0.08832281305184288, 0.1588585200689493, 0.13959877853912694, 0.1613192557687721, 0.15309769209594498, 0.17033488489687446, 0.2442910366000668, 0.1455552653679925, 0.3473871351490098, 0.1778948090730175, 0.11508293074345398, 0.17131480328258009, 0.13768663840188136, 0.13433558595997674, 0.1753430314842732, 0.13510461566188645, 0.1502121912856256, 0.15523420406445382, 0.12186447894501111, 0.12952786329532825, 0.12293041368285496, 0.11887420795016712, 0.11543940677638016, 0.16073589513619102, 0.15166567458260446, 0.12451221670715079, 0.19415001505084578, 0.22628015628264797, 0.146495929408458, 0.17982528935517036, 0.09981218605272232, 0.23460442170260415, 0.1260767061443579, 0.17019361828363713, 0.1140252620943131, 0.12535734192257927, 0.10454660942477566, 0.09101277758036891, 0.07664846046076668, 0.22206442040060798], [0.024907109966020913, 0.049263218853382335, 0.022024671592178847, 0.034560122331904794, 0.01884820484255831, 0.01989225436362528, 0.040499563704455094, 0.08660733534563934, 0.06303210179471681, 0.05785746897961344, 0.008277678655670776, 0.01867592890536593, 0.004019323865988202, 0.03720857638625368, 0.05485469542984521, 0.11758308932786027, 0.09992429535956153, 0.009613272512421734, 0.036916654752266985, 0.0564573590283192, 0.015533336648537267, 0.037475113696869344, 0.04780741047955329, 0.01929008818772291, 0.02491048649854718, 0.10005454562844769, 0.054010393758935314, 0.021139727041666067, 0.020345044885611823, 0.019396426937272473, 0.05116541899981038, 0.0467355270689774, 0.030819673143747835, 0.06596353340653643, 0.058598996125041485, 0.008270900692760704, 0.04555978128806718, 0.02012537300376402, 0.031121128741952202, 0.06191345254680323, 0.05129907069908035, 0.03549270414476914, 0.029467865036079482, 0.01847844867546472, 0.05375059802205332, 0.06109700200238055, 0.06445561956253744, 0.041813822012514844, 0.047316807772844076, 0.04465108226624228, 0.017626262044594172, 0.06339196776670795, 0.06473468241071509, 0.04295698990444503, 0.0244878281298424, 0.033050377537766774, 0.0274842603868174, 0.038852467006372834, 0.035512496026292924, 0.005449773771913662, 0.06495991226045356, 0.013713334863554808, 0.09079211361465916, 0.058158227437806714, 0.06804143964883781, 0.039787871853238156, 0.044540512796130874, 0.03771278481449812, 0.07125370760237978, 0.016963896679601843, 0.04971223447712199, 0.002805282786158064, 0.042541590218822804, 0.0677685208258129, 0.01786017167051473, 0.022952641555739027, 0.012676822690052852, 0.020535450293532303, 0.0751305798128728, 0.03018798960012294, 0.04429213559976028, 0.0866729584372332, 0.04104701396558554, 0.031675152037472974, 0.040671971791814414, 0.0410342624320859, 0.05711347886150884, 0.013038130822561443, 0.06622698338281724, 0.01967572918792646, 0.0445290980860591, 0.021623128521887046, 0.07413898624720112, 0.007721362842036592, 0.0211073387594473, 0.04296930859826746, 0.03328976086190632, 0.01408997433064806, 0.050165800663131865, 0.04712509426979288, 0.09987456859239649, 0.06099513146064936, 0.012171215193736698, 0.0018880367368241894, 0.06602253749846451, 0.07270471643536322, 0.06959580140368593, 0.05213373498390279, 0.09444589336072245, 0.04068204201757908, 0.003149579457503053, 0.04513994212292376, 0.01818935965157805, 0.04824048764402828, 0.048633184314014456, 0.05583850171176657, 0.01591002974178522, 0.03891411027120006, 0.06805042586018963, 0.002780067002130372, 0.03150136499184995, 0.028896878638695327, 0.053440048960187746, 0.042286659140259995, 0.01935254925140931, 0.03349084745071108, 0.04237665531916484, 0.03817807214574949, 0.0037727946173324585, 0.05489326029595348, 0.015942684239557674, 0.08056313144944369, 0.013761767899737725, 0.008522097092692651, 0.021773170672296997, 0.01583745823271813, 0.04395431380779032, 0.04608159441681159, 0.04583111047864922, 0.04237967753602613, 0.028534771859525677, 0.014119594162630459, 0.04102359465774029, 0.02399490034628299, 0.04770960786470002, 0.0320845379328896, 0.0098256713470384, 0.034333069192906546, 0.037503359358637564, 0.05361122364598898, 0.028930389239723166, 0.01676425416653435, 0.04697052453975043, 0.06371869660553432, 0.011867746699511284, 0.06302835945520671, 0.0393299772704561, 0.04031023273484842, 0.011544987153742584, 0.029842081750112198, 0.08363828498629794, 0.08104919125476191, 0.0194842895613082, 0.020649576326832175, 0.05094994527978763, 0.05224595537349101, 0.006128489368429949, 0.0403966742657846, 0.013828821660530184, 0.06250920848199917, 0.02409354948829259, 0.045582683486563545, 0.06070692535309542, 0.021430011162714615, 0.02496211316376444, 0.07913864458039885, 0.09506438678551106, 0.01529773396830405, 0.08048656862229109, 0.04090193223448531, 0.043917062782472184, 0.02110504049567446, 0.02038635809214846, 0.02824528063947876, 0.04935371298943797, 0.0682949151603445, 0.024193703993073395, 0.01800910490865429, 0.037113738531667384, 0.07558333777612256, 0.03976625668245458, 0.06619740472806078, 0.06217924292169272, 0.052579203620553024, 0.03927799054391442, 0.0841081343711384, 0.07231730577205459, 0.0066410404941698005, 0.07466570233866092, 0.03282648068101656, 0.029298630467946493, 0.04875874612480403, 0.03438336669557518, 0.07441858535692578, 0.05692188027164629, 0.020484122402605512, 0.034691640476305644, 0.013986015241713294, 0.020833776422565984, 0.062432795041991826, 0.027185239032992435, 0.056722180301984476, 0.07723503866262975, 0.06510983566723524, 0.03725451484863316, 0.058368821177751794, 0.027277284497094732, 0.008436632323859921, 0.04296840078407719, 0.019901926223669323, 0.050490813465007854, 0.0374510164012111, 0.007495951046416116, 0.0406668504940406, 0.02895373193877599, 0.03132846086255966, 0.007235501740773719, 0.06194060270283973, 0.051212858994521444, 0.03717913945776321, 0.023384904751794475, 0.06356562840782347, 0.03397310745992488, 0.052994580323537516, 0.01947098835972288, 0.01021598931401968, 0.013458953453077665, 0.039681427766599005, 0.02739847577627628, 0.0586777116592613, 0.02897296074567543, 0.13098067243493375, 0.028291983274562706, 0.0566455485269187, 0.019384142717406638, 0.04366889242984114, 0.01973129162985471, 0.04309876213571237, 0.07006341381178749, 0.06945687135861767, 0.026310722854348923, 0.10312240600826279, 0.04328957548545253, 0.08467425802542318, 0.026305772011138262, 0.05689892444699522, 0.028033380719622778, 0.025600829394534234, 0.03859566667327478, 0.09378246121829557, 0.0471106535124202, 0.024406649622946017, 0.023286115798738696, 0.0693116057664156, 0.02743068977349228, 0.05691629166023866, 0.05427918719848799, 0.032310937981932394, 0.1037331159797407, 0.03627694452241544, 0.1119784053955828, 0.10922746026828405, 0.026507149713354248, 0.01995482267962108, 0.01945388927725294, 0.019628463478218165, 0.09013615849037325, 0.039650922145454154, 0.020357949636696328, 0.022810562889301972, 0.016583313774918357, 0.06579782092763532, 0.03594366180139684, 0.05301012807796079, 0.06893176405179886, 0.014409026968473149, 0.02826449412461971, 0.028108106850976908, 0.04731201972331732, 0.029942377981158997, 0.04867392103938807, 0.03329533415155546, 0.062322700546393474, 0.05948661240719019, 0.03325413011254803, 0.04007610860430906, 0.05358482042567865, 0.043813912873907436, 0.04287401875180583, 0.019155273950027845, 0.028578456108187957, 0.06027533056875391, 0.01763769207642444, 0.025533530485606002, 0.04429552936926485, 0.05676880058261657, 0.057975779768199696, 0.049116777316216505, 0.026980931044466076, 0.0484468640699502, 0.00604190611122777, 0.03379512608291642, 0.0553241043141292, 0.0684608421438644, 0.007739527265526235, 0.0553983956905863, 0.07564540621974776, 0.007694038879802271, 0.05592737557186235, 0.0930703365274014, 0.026586790298742634, 0.024230820953004786, 0.03601874224841595, 0.04051603842526674, 0.06919562005467954, 0.03989340046480779, 0.02418822454919498, 0.050556685535177115, 0.02812368907935677, 0.02715307674671133, 0.05893047853943802, 0.039410964255371404, 0.021201098345280178, 0.03764985835239772, 0.06306458775314593, 0.04243396635678026, 0.07528785000284834, 0.039596817185801846, 0.042766486820314205, 0.03054051070414003, 0.04439087667232079, 0.01787029743765391, 0.0671545549806568, 0.04406755309431784, 0.030852103560802438, 0.025935659613159877, 0.01499947774479346, 0.039627020202216603, 0.06076171979187958, 0.04878749357416265, 0.03458307049567661, 0.023362956332763838, 0.1492204138588521, 0.1159526167377349, 0.12913516662534208, 0.15040688487070222, 0.1104909614209206, 0.08012865234406726, 0.17219335291414492, 0.21252647252573123, 0.29025906997342266, 0.15797491425708418, 0.1512330340882463, 0.12516270196365734, 0.16714538507644208, 0.2358035638087219, 0.0971513941523529, 0.14896735969570377, 0.13678035638745756, 0.11668554071577326, 0.146906353353012, 0.20074123636849467, 0.15481081791222095, 0.12942703080273446, 0.2109093988134015, 0.11203525678044367, 0.11049882914390295, 0.216741886650843, 0.18780340560741965, 0.09388746122919744, 0.10352472474257793, 0.11632963158791104, 0.14634686402015148, 0.13742353316516648, 0.15075626692944957, 0.2253661674237059, 0.18803738418125338, 0.1076249115829987, 0.21730943522866697, 0.15081782975504476, 0.10767264652156061, 0.12482265851670697, 0.1608862169086933, 0.15056564893213012, 0.1418749636579906, 0.09969268399741381, 0.12278185391257848, 0.07025505836692549, 0.13875802768574608, 0.1320176337274813, 0.18505342575090547, 0.105824428760717, 0.1595074271843318, 0.11761937891283344, 0.1633645726307746, 0.12095052072958601, 0.15074426999255536, 0.1418732476210402, 0.13359646433063094, 0.12166477514490967, 0.1815380321274842, 0.1780099061227614, 0.122088712880448, 0.1119524350149497, 0.1827958718903603, 0.11014570857608512, 0.11188081345490872, 0.1802069390372884, 0.069739205402232, 0.19056054072514658, 0.1532335348066784, 0.16696337790739152, 0.14077426385014288, 0.1513565274616403, 0.15273019971866764, 0.19505487214173042, 0.07788728592136214, 0.19515300800483074, 0.1671525096941379, 0.1856838088602789, 0.1358901162541682, 0.19632599586921354, 0.10645308051138155, 0.1762043747810587, 0.07409132791743164, 0.15503833070397377, 0.20417219178090174, 0.1657268507105689, 0.11326061441533028, 0.2059366761316215, 0.17389017637939225, 0.10908923502410613, 0.1780036242017823, 0.13037218411843624, 0.21025332111504771, 0.13556071376848605, 0.2142213194841339, 0.2030393775672682, 0.11446991484732398, 0.12423789594322444, 0.09906454552565852, 0.12551594510554306, 0.13277406894391583, 0.14902368247989686, 0.10657252894053537, 0.08362975842770069, 0.10997651805800777, 0.1672383115416573, 0.3478178297800403, 0.165597397173124, 0.14789043925702572, 0.12254478034353065, 0.0716848542252856, 0.1257694972258422, 0.11194395442162791, 0.10137565659299012, 0.17009923625136578, 0.08184775364615264, 0.12842285807334608, 0.13197010563265893, 0.19308095467427086, 0.09355962156288086, 0.1695116927787181, 0.1576441941001723, 0.16588972100327093, 0.13295140297662827, 0.11365098217802663, 0.15094083283216725, 0.1366471030539082, 0.1293573321233834, 0.2342520672227106, 0.1490696324335952, 0.20841130866639077, 0.19870313605473888, 0.09191552026858253, 0.16740320430647943, 0.15419523562154464, 0.11530361003092221, 0.12178977771151452, 0.17894298589277655, 0.11911611553401717, 0.21442745842279928, 0.18496635219743177, 0.16082450086551328, 0.14191293097551794, 0.13234018738712036, 0.22035350091755393, 0.15337069518864155, 0.15050929550442005, 0.15191816184068882, 0.07604541136853157, 0.11365277482376945, 0.20018812088716417, 0.19226637338438343, 0.09295578340008374, 0.18128487071202648, 0.0972458910978129, 0.17471497728218957, 0.2574466968015317, 0.15463274843510122, 0.17307348068683379, 0.12527530156676808, 0.23595117362997226, 0.24229983618903547, 0.11490780304396346, 0.13578068825506395, 0.11584788485760651, 0.10625365250293287, 0.17093580426468005, 0.13000208704221633, 0.22170046734954083, 0.2409302548415238, 0.1519807512241025, 0.16771091118214593, 0.1390930839003094, 0.12210244117605111, 0.15340642552943, 0.18393996291823927], [0.0302492268383503, 0.034799057494608626, 0.06638180975231432, 0.011358186189505843, 0.04475075413563079, 0.06509291278498788, 0.05275970925727198, 0.005647751001355749, 0.01694208424117777, 0.03165642118772432, 0.057308911721432404, 0.044256635085349126, 0.03017811089633934, 0.047726898469151034, 0.023357352399597728, 0.020007067960837198, 0.03048830372732013, 0.0970949487940919, 0.07203991299555187, 0.04938398112332629, 0.015511891932316847, 0.03148957298347547, 0.06623652883835378, 0.038472678917910785, 0.019685987105232575, 0.07394548009840712, 0.07262811530381441, 0.014859860135813155, 0.017329854965810815, 0.019217968670531146, 0.04948231233884731, 0.044645616228902535, 0.07529832242477326, 0.07545597565871093, 0.024126265273098985, 0.032111375908096956, 0.032884282014903524, 0.05819072871799431, 0.04688731206941509, 0.08588781024539664, 0.03167414654707236, 0.044343597556073824, 0.03824745672905157, 0.026753056276169036, 0.06423317444240374, 0.056781525303038864, 0.08846086209579822, 0.03082596464082599, 0.07420465530407044, 0.01448845496446255, 0.042873440355423, 0.025244428055180658, 0.026659672073419058, 0.034539947406418865, 0.036650423876821034, 0.03135056632961477, 0.049145045960622455, 0.02704101340514758, 0.05486318368404623, 0.018318374603686315, 0.020580980814092105, 0.017879871621487603, 0.05954039177947468, 0.024958409128650546, 0.04975082615630762, 0.0742840220130259, 0.01603682112369326, 0.02227471119934513, 0.010337991688791062, 0.08714614796542353, 0.057268378009358724, 0.03141579680114744, 0.051056822206104, 0.05684134144816668, 0.06756778280701368, 0.0526095713458715, 0.04298185711846717, 0.06172693311987866, 0.04939561799889611, 0.01712329084834745, 0.07218766837350785, 0.04120115468639039, 0.01958157506681258, 0.03335694294242609, 0.048484643695936094, 0.007317074304146152, 0.005229487104506623, 0.027531884242630297, 0.0576286461775101, 0.04356334849651303, 0.04105533751088285, 0.009158955560246063, 0.05939136852600402, 0.014251139120108659, 0.042004374892360745, 0.026284545629976258, 0.031849080809361996, 0.09246430735314086, 0.03588096899611335, 0.012604337365877245, 0.021012418550409136, 0.031823547098845724, 0.02493242151103914, 0.02392874099314213, 0.036355935848288, 0.03324475702679446, 0.020427615757310585, 0.0670224201354769, 0.003171207077215396, 0.05120755000520618, 0.06020829404493975, 0.0311550970805148, 0.03373572362526771, 0.06613962637681155, 0.012121676118113102, 0.03178002564386735, 0.0287772482636595, 0.03738664203293381, 0.07999957418970524, 0.013804517521132386, 0.050455577250930576, 0.018341081449761987, 0.08638414328977947, 0.023866810445343296, 0.036448169003931746, 0.012388177039552362, 0.037442528147010073, 0.059806664789756464, 0.010382079091223498, 0.0487080387650959, 0.050946206770717144, 0.03361150246834563, 0.06783814289637151, 0.004647378546876773, 0.03842697028190859, 0.017453112767168114, 0.05056329687396365, 0.03284963185808832, 0.039285793149423216, 0.0739267569095377, 0.048616050757587924, 0.045084527152920925, 0.034176963456575914, 0.05993694187171998, 0.030042432894509648, 0.036731797736138105, 0.036594890163189946, 0.13259267464520472, 0.03308814184199418, 0.005862610893429167, 0.028306749619303212, 0.06226219109169418, 0.10630000848323108, 0.033877626091482184, 0.017269784096448172, 0.015810136664508572, 0.03325357086836331, 0.028245165726290117, 0.05615146395059363, 0.03598335664719343, 0.011478703311314026, 0.04185644331418219, 0.07060240263179426, 0.04575642839735074, 0.008108285124293499, 0.03355395394347368, 0.04056714032025587, 0.05009853814338004, 0.1385665516699514, 0.01565988096708973, 0.0425444707094181, 0.05136265216635601, 0.08356916087289011, 0.013474431301977847, 0.021048905403022806, 0.008127552235589154, 0.04110499533013471, 0.02717490067645427, 0.025200450777887337, 0.04078523023054004, 0.02759499456583252, 0.040019601959014134, 0.02367537464916466, 0.032271384862401796, 0.01799829157760307, 0.036835388145259315, 0.061215435365034696, 0.033562802258999117, 0.026325184679139527, 0.03654847289585779, 0.031714094201883966, 0.059477013325498956, 0.04426095199080245, 0.06779842889837681, 0.020400647547156103, 0.015673417740711765, 0.05172756665776815, 0.01509626242031734, 0.04304433924957149, 0.027924169140357166, 0.010150196725472568, 0.024829917031550602, 0.019642067284533576, 0.020155740729082498, 0.026011837481130517, 0.008174515340567358, 0.03074808988810307, 0.04514937649571127, 0.032201831739756374, 0.03565742453980831, 0.05184851661925355, 0.03771395692902227, 0.03180366137155122, 0.07976338162177032, 0.06964974165443452, 0.06126535365418081, 0.013885831051025421, 0.041137676640984513, 0.036135405947965, 0.00498953256605854, 0.06075650273311523, 0.06728720310474597, 0.054756655327735416, 0.030719792515399958, 0.039848752860580726, 0.040196840230736046, 0.1048070410146348, 0.05313086736526701, 0.030892438090015805, 0.03667284343992511, 0.0683740213994057, 0.009829804391389894, 0.05092908087516985, 0.044940299609856266, 0.05215380648751894, 0.046774333252781825, 0.05329986253092366, 0.011836239418405439, 0.022290055940468467, 0.05069674555993369, 0.032109592838453195, 0.05807878028961921, 0.03762330191450254, 0.02719701955004806, 0.02611747334500955, 0.05965800925848946, 0.08906014203544586, 0.07700451514533452, 0.0028417330101928526, 0.02934634050865087, 0.08658202380062112, 0.01438343580136256, 0.01165303427936329, 0.02444871168042864, 0.02167358690301978, 0.043655539517320936, 0.053011928384582845, 0.01160219859992785, 0.009817521129133961, 0.007029830115742141, 0.051728765585369645, 0.06085045192570937, 0.028454573945172375, 0.005939624276042226, 0.03034982567412719, 0.04960334273956476, 0.02542633946324068, 0.010722544844142132, 0.05234473475044774, 0.007151591172817374, 0.016070046356969302, 0.012240094159008756, 0.027626565049192118, 0.01645191628936558, 0.047162092486096006, 0.019111101320313833, 0.02749912057732863, 0.020501801796678095, 0.017635091207921505, 0.09785323028242397, 0.006885009812146065, 0.037780204382274425, 0.04111652878383475, 0.042297794228239406, 0.025294340598667343, 0.08289678082350763, 0.026214165132372614, 0.05861272442064459, 0.06204901563544428, 0.06177351126567491, 0.005628126222760447, 0.020434502887749867, 0.0600057250760015, 0.00897465970352172, 0.0670101244242922, 0.03631309238112262, 0.03813499119132757, 0.05704071200002105, 0.05284183771319447, 0.05258989820797598, 0.08544544809527936, 0.02093245046243312, 0.031136684157254717, 0.017495517648996848, 0.06511168193913276, 0.008789450286947673, 0.04274171919772222, 0.021868977628107515, 0.05236445768405834, 0.013106058881197487, 0.02124909949939578, 0.053831473924219615, 0.05347488297810478, 0.07898330493199249, 0.04030410403145417, 0.025519359774226626, 0.009163260016770614, 0.05504263978030893, 0.044563414994627244, 0.12492053390991305, 0.03189276697324409, 0.009789237162969526, 0.04819535740440892, 0.06275560917152513, 0.03424900636497525, 0.03861899022012949, 0.02165681723835728, 0.05108144044155075, 0.02862074416160824, 0.022509042173624042, 0.04096652493782101, 0.049059033438923864, 0.032737200794320916, 0.03785477538082389, 0.015190553479647685, 0.06036814595122011, 0.008927374841615317, 0.04605259798887757, 0.04548240257727523, 0.056116166449482405, 0.04609429232415654, 0.001449895372065986, 0.0762744639970122, 0.042590964585542686, 0.11848118952325276, 0.09696190230428212, 0.06356103188027779, 0.014450563298117731, 0.025373126996020158, 0.013702785832837466, 0.01701084254760175, 0.0551244771228202, 0.07008348531540363, 0.08967070645021816, 0.13108997785997006, 0.11563434550959258, 0.1403198204934597, 0.1943613480656378, 0.16410996085934101, 0.16691552805564097, 0.09340428191447452, 0.11903839591409891, 0.12537382047383056, 0.12918877745828322, 0.12397341174824585, 0.21586611025756408, 0.08273097641405561, 0.11329591574688112, 0.12340560270052765, 0.22684615736286487, 0.18863099507026135, 0.09479706806521263, 0.07627529903284966, 0.0966403752024616, 0.1398889573230859, 0.13056221988893327, 0.12329759196408334, 0.19286799755307937, 0.08907521098491647, 0.1912349279248907, 0.12931397154686913, 0.14365604147315025, 0.15451539908685993, 0.16597127872368983, 0.13797249644994736, 0.13941082652778397, 0.18435288430942645, 0.12333111597164986, 0.11671770108683456, 0.16680783141524563, 0.17122776037262333, 0.13664932470888863, 0.14811741578723156, 0.11299492746231057, 0.11370915123411726, 0.09161594158579266, 0.14267544893007125, 0.21651763739364766, 0.24878081745438038, 0.17539371586134359, 0.1791664077750137, 0.11555460341755422, 0.17900025862599575, 0.18497693953254532, 0.1193218331243242, 0.17408428773764642, 0.12370668291564911, 0.11975683316948915, 0.24545742078654229, 0.14433038270761891, 0.18121737836589738, 0.05933728654898944, 0.12023443536412333, 0.09126665145759622, 0.14452945831562244, 0.11093173010815537, 0.10624095842602754, 0.2336824502074911, 0.0908177852210018, 0.16607747383175359, 0.14606869749484525, 0.1333528024054343, 0.19251196585114927, 0.18141224049031737, 0.15592644111283366, 0.11940368961903358, 0.12348287032857058, 0.18887643431944234, 0.12077590630900477, 0.19058303306660346, 0.13557338486275367, 0.15384878001866803, 0.13726493764308192, 0.10679391302889395, 0.0902839445118462, 0.17916243943956592, 0.09804199434696667, 0.17998088181259173, 0.08473606599915413, 0.06504021359667664, 0.14603290586702286, 0.2002316040377463, 0.14495918767586832, 0.11137506518993648, 0.13768709805463591, 0.060735255284535314, 0.10818538916928154, 0.1058532949537039, 0.2599640310772004, 0.2052812419471241, 0.172350860591377, 0.16167763169975052, 0.11743891158051069, 0.20138150201209132, 0.10359404803884607, 0.12323632025189939, 0.10545944149095206, 0.054486157342551224, 0.10945013904523467, 0.17209955310869604, 0.18198918130609298, 0.19120236918810876, 0.07283895036145564, 0.12007494351916737, 0.1569578712505679, 0.22752884895570819, 0.0766767444269311, 0.13965997364251845, 0.08262845852802839, 0.07288760460552669, 0.15287094539211643, 0.10774385439412248, 0.17306214258555444, 0.1612241995791274, 0.18132927316811778, 0.09931638160900724, 0.21009446512306892, 0.1016168900194668, 0.12146334764697861, 0.12672447178873325, 0.13666214902074109, 0.10847003679842719, 0.1578277640885884, 0.12234006632840443, 0.12916705120475064, 0.07600741340748726, 0.1579601900471795, 0.1324590689112102, 0.18093984003268904, 0.1505078552591224, 0.09403920792523893, 0.16190287687124746, 0.10607777403727656, 0.11200157189441305, 0.0858795518175729, 0.15655910716422144, 0.1278591705786605, 0.1444403776117871, 0.11381340047885334, 0.26374442983538876, 0.09740639417882889, 0.1065193777603488, 0.1362383798245461, 0.16683709597395313, 0.22099185134133986, 0.10258392280628605, 0.18165977882041087, 0.15178418838449065, 0.14049019844781968, 0.14263250204103609, 0.11013922747224571, 0.13475368610553204, 0.13719772108860556, 0.16385269321260915, 0.11712176650161706, 0.17530046763920015, 0.10082984192957802, 0.10347387182616419, 0.12913582546095695, 0.11787541315800722, 0.22625675995744046, 0.25732881119174345, 0.16901073256327262, 0.17651169861276306, 0.2397702598283368, 0.12186950448179439, 0.18140131607651713, 0.15205040393817812], [0.03679267491304106, 0.03829941664251589, 0.07857618282639212, 0.018497298268841642, 0.06092253696894454, 0.020487604272221367, 0.004510550934355706, 0.028283713355420098, 0.04204096325162438, 0.036332164139997576, 0.027535348875267852, 0.035600883420556784, 0.019659580054482626, 0.09470231831073762, 0.04630128928129712, 0.023650003732332302, 0.03691287027792104, 0.05251798936496339, 0.049572454074457775, 0.01748045061474606, 0.026318232431226683, 0.08690826234317596, 0.0541047451476897, 0.02388509504887606, 0.046010459322602525, 0.0927605535534601, 0.02267677520942544, 0.049261001028841546, 0.016874046057402607, 0.03403036104094598, 0.04548639006492111, 0.010804047023186521, 0.06853668484836817, 0.01866018962896159, 0.06624386029978914, 0.027293019943059455, 0.03694156027068535, 0.0886170827453175, 0.021060638039583163, 0.03167354899849142, 0.0730999718390165, 0.013732495680150968, 0.009005064775626506, 0.013498385913760192, 0.033695745326939135, 0.040650969491370266, 0.10488096083844863, 0.06511145211275547, 0.027502809290684042, 0.004492330490686601, 0.09167775722040285, 0.06741320924653162, 0.05842520141853921, 0.04352596340580814, 0.07046538780653669, 0.027243249125838764, 0.04913513661332188, 0.04092062094939813, 0.07578627446726446, 0.07556030151223944, 0.018565516483279008, 0.027615353352420276, 0.0440616580477405, 0.014991413711780503, 0.036233442219635176, 0.005208185072162099, 0.08066951807948851, 0.06241727027020628, 0.020981619900633252, 0.07672999519854784, 0.05263699729356074, 0.09805648873049407, 0.033389126296125116, 0.12600774290941416, 0.025743609031422005, 0.024313822749160954, 0.05893366929564265, 0.02668147302052427, 0.046738629725070736, 0.014386490576960629, 0.009748935192492942, 0.020260784790040027, 0.010584353116310893, 0.012307034921832384, 0.058307511161171624, 0.0330896127308088, 0.030203137073605776, 0.05624871881258103, 0.08105395632165094, 0.050272409458674734, 0.04929918285098769, 0.05544055350905946, 0.01973601073146828, 0.06939352354815892, 0.07823264601850703, 0.03022746036520168, 0.032663503136005134, 0.054403427507608175, 0.036691520663519064, 0.006842423942045219, 0.042312618029574235, 0.03858849992074313, 0.07435757411463607, 0.06639824999916939, 0.010963936276253193, 0.04372533778810213, 0.02443994571935506, 0.012301837972876047, 0.027471351805293275, 0.08042178056653469, 0.01015872328406981, 0.05016547890620367, 0.02380302021910827, 0.07251644266709205, 0.03170918166306952, 0.03762734685874274, 0.034092513754242854, 0.10479095316822491, 0.05229850900509665, 0.03375381862203922, 0.04843694323133077, 0.037918659452829635, 0.03927258962404825, 0.03503291732481411, 0.031960732378666444, 0.014067344093364815, 0.05439796147026843, 0.048947073519229896, 0.05933543261621268, 0.06240690893103039, 0.008466817145686477, 0.04958102276789085, 0.07027117685685236, 0.05228960706341652, 0.011259183689441172, 0.03536020540782521, 0.038148589251983556, 0.04431363585735521, 0.06443033100015695, 0.05875350456804999, 0.03030536576144157, 0.057612895409786896, 0.01123413069909739, 0.04031632696428607, 0.050401487613036755, 0.030788698293749365, 0.03342967149951766, 0.013140500279053325, 0.009257790478577298, 0.016180345781087395, 0.05193903373794691, 0.05889004824923412, 0.010951831129439657, 0.008340827283269216, 0.029957314780462655, 0.029670592968262015, 0.032504945918316805, 0.05549456653816085, 0.038153783328110175, 0.007271776961598306, 0.08123872906810815, 0.06326535641546212, 0.059139655016723185, 0.039299337583924496, 0.06347352931756647, 0.06796015772007166, 0.06107842820065637, 0.06237171102134932, 0.035195982969936826, 0.09557455537780639, 0.023572096420872598, 0.026197403128589355, 0.01518370848404424, 0.025983333264687852, 0.015585787815883037, 0.03865855866141858, 0.03885338248144235, 0.0269347780774678, 0.03264029450233906, 0.026073308376174782, 0.029498385978982817, 0.04888135466664549, 0.022956653941242446, 0.06249995797031349, 0.07050024480709145, 0.013107343993690467, 0.01146144909603942, 0.033542454963730234, 0.006455290506804183, 0.019176184319921078, 0.01680663989616498, 0.05250978073285473, 0.030768588485737002, 0.02579224220807514, 0.05061321899354939, 0.035607632655169696, 0.0037685667696003354, 0.06902881207004671, 0.08276427825612408, 0.06776004789337035, 0.014711654681201666, 0.022133595888472857, 0.058552620992545164, 0.026100385753858476, 0.02236269065178931, 0.06338950862447101, 0.05452656081967777, 0.053743113343033104, 0.03762715533676167, 0.05403727578419832, 0.06562245574088828, 0.0683026832918967, 0.07326693304123418, 0.0072547262384285854, 0.022826972492640058, 0.011753803569703333, 0.03045397915787274, 0.015625664607561644, 0.053567897543431296, 0.03494893876655448, 0.028811268313156984, 0.03455484781654612, 0.03593352645815861, 0.10133592727323694, 0.044186764036215125, 0.05485843776935532, 0.03070034920388172, 0.04828440363428766, 0.02537220194485159, 0.02289954400170715, 0.06753650343706531, 0.042994401808227264, 0.042979382654471744, 0.049039191761684996, 0.043736656737183376, 0.0365614504252951, 0.018686016368108894, 0.07606127704944342, 0.046008727963893645, 0.08225040179827521, 0.0741400204658989, 0.013201224238371417, 0.02167992436537339, 0.016827575163915753, 0.03596648356066116, 0.046527955545893604, 0.11695406985499206, 0.016946772699274363, 0.06357218229001568, 0.07070289804570137, 0.10979011354427184, 0.010787593369792787, 0.03546886731900516, 0.011174249436496007, 0.03322476596241036, 0.0039992784572419745, 0.05311146235814499, 0.031043583407036723, 0.025688783949120872, 0.019422516061533845, 0.0480831561670188, 0.021633281102103573, 0.016068540994198095, 0.060754568361106424, 0.018926991239911126, 0.04743922096226485, 0.07134330158512439, 0.04678887743202429, 0.042027575865147576, 0.09753924148577837, 0.0999486646164329, 0.048069178892840306, 0.04230155571994763, 0.030438580790594704, 0.052413598393961314, 0.022219796101712895, 0.07055067637514684, 0.031184292691309127, 0.049356107014201345, 0.06427325233216248, 0.04289038622030809, 0.08138359629458959, 0.014291647934324801, 0.05155748747769864, 0.009203440370789219, 0.00896837586732281, 0.026642674497599085, 0.0336090624783068, 0.07216216530650854, 0.03083602146005198, 0.011183396526311916, 0.03616020038363434, 0.01346135226589057, 0.03252290301926194, 0.05236040124849928, 0.020293619318474686, 0.054786697465686075, 0.02852803794667125, 0.032848249069384994, 0.06045324682828881, 0.03519729681072697, 0.030477454007092505, 0.04732106339126345, 0.005620137840930012, 0.05736443011330501, 0.054399849877001784, 0.01793926258781745, 0.056302425406512716, 0.01917527842095062, 0.040960407725745634, 0.05963656262704923, 0.02124136584180017, 0.009926781546504749, 0.05631744839070786, 0.051550351368683967, 0.039673161677896016, 0.007743563112472335, 0.03434766699830371, 0.03776453788422289, 0.03344983876412434, 0.019431456307610197, 0.02157544337904021, 0.03756012647382675, 0.020778773224822456, 0.010000344181823875, 0.025825065245190938, 0.008625111978260741, 0.0602400713720389, 0.01966777528005262, 0.07507520697770581, 0.031565344824846235, 0.07724678279050896, 0.037642526890962355, 0.0335025915785903, 0.01696699933569518, 0.09077165140620164, 0.0700975277070557, 0.048858245624409574, 0.05132963377681952, 0.06790881450738638, 0.006531249082106496, 0.03525112597872654, 0.036348761434877114, 0.11725100553444318, 0.06316471927528901, 0.1027277175096735, 0.019332230684437582, 0.026350940555153836, 0.023839035927648508, 0.06126199435863284, 0.02997324749406788, 0.02690817567429716, 0.08238369343622078, 0.16627553820369706, 0.18592319601485807, 0.12335862618901076, 0.14634608261046872, 0.11050485825586705, 0.13605962086829448, 0.15083814640679669, 0.15667463322320294, 0.1207911974239734, 0.09359578857378614, 0.12658138954711537, 0.1746175155764626, 0.15339893318953055, 0.133526106815665, 0.16536044617814405, 0.11985539038094783, 0.12501632554396508, 0.1159545319575456, 0.10819017721880829, 0.09153272145457807, 0.15367319266642296, 0.14905470904083024, 0.1720909576021856, 0.07775158110645511, 0.17978513102617957, 0.164432575806014, 0.07527988268843583, 0.09574045171780933, 0.14949076628733068, 0.12905843525884614, 0.12377967577307455, 0.15116175726777123, 0.1441736564400696, 0.13533670965942646, 0.1510985703357766, 0.10095644561994462, 0.21421327556092895, 0.09646562288605398, 0.14886977541590893, 0.11848122016676974, 0.075782758123692, 0.18813239440562265, 0.11845664406615881, 0.11074950843448601, 0.1291453709164935, 0.2816401824595467, 0.15948829030798328, 0.18327103026451605, 0.08965548428316271, 0.23273895164170574, 0.23499494268288537, 0.18285423246843202, 0.12826917317485617, 0.11602364841007418, 0.09871589891131848, 0.17857008493475376, 0.1140900118456733, 0.09902757412243275, 0.22935645895138865, 0.09521102367509758, 0.16630163115839805, 0.1361852286443595, 0.19289946844500883, 0.14851832491976602, 0.12853371099598948, 0.11478217994613994, 0.11332066804771462, 0.10101525052901238, 0.11935403179978171, 0.1571760377696445, 0.30875748864585356, 0.15886949044802498, 0.17037945589230907, 0.21722446075610577, 0.11575656717703228, 0.12012339858037811, 0.10663540943736032, 0.1503427173461645, 0.165963648487964, 0.19807178767458086, 0.0645130608351, 0.11456061199667955, 0.13501242464107854, 0.26213965949512297, 0.12466668301532347, 0.144138615578413, 0.3945232993893085, 0.1936145349135322, 0.10070599615573884, 0.10112971938665836, 0.1987066294156736, 0.1801166632362912, 0.155345271491716, 0.30260773315545053, 0.14256119457704408, 0.14025749157994025, 0.0996513382321404, 0.1036643366058988, 0.07834250302684885, 0.1549237699157769, 0.23356784345401874, 0.42612764383516005, 0.1430032119875954, 0.15224296779882524, 0.17821673454055864, 0.13247596881081983, 0.10549879542762235, 0.09030770089837814, 0.1651234798614056, 0.15476469941917928, 0.12018830154932315, 0.20746217169348272, 0.2849004994476995, 0.12591894565811082, 0.09308722110525255, 0.14921448433831816, 0.19424841138384036, 0.11342698572984627, 0.1920925327126057, 0.1925682733135839, 0.14843500519712127, 0.11038756253378046, 0.07575638937733828, 0.10885523346763466, 0.1536946278065443, 0.14701081710236688, 0.10807839732977653, 0.20329574123024943, 0.22471848604900224, 0.05790318527649488, 0.08076432912099747, 0.14014409524538826, 0.09375074517823036, 0.13157521795120933, 0.08632559885060595, 0.1399844425219682, 0.24136090350727885, 0.19312543373915458, 0.13452862479513691, 0.1265219411241912, 0.11612592114796562, 0.15956008806824684, 0.13610558614375132, 0.12229295192106117, 0.12236228287820855, 0.14888482138274178, 0.11328824720675908, 0.07738181344804264, 0.0890505735972716, 0.11618646507662152, 0.1799964487192131, 0.10042399152993195, 0.12952058546004758, 0.1686452166928399, 0.1854516076104295, 0.11891288772946405, 0.1183875046309925, 0.066398931817422, 0.1499020176068429, 0.23858112283051017, 0.20636999078335302, 0.12224189216090788, 0.18852870701061142, 0.09389924366147288, 0.1608927286560497, 0.16957454263202607, 0.19187588304761918, 0.06794188652307757, 0.21697264765539478, 0.10228452032371875, 0.12172081447657078, 0.15797131364384007, 0.1966014964085433, 0.08886860473261726, 0.1330945694879178], [0.013468233650670418, 0.04143023795838799, 0.025328247650195996, 0.07879956640423307, 0.04520862956621474, 0.07386817416596798, 0.048574616892203215, 0.03823341433739951, 0.027875763874861504, 0.02104396796635082, 0.04467944667163876, 0.02037605995522632, 0.023584325099363927, 0.05731340099666869, 0.04686857355878719, 0.06827276755845355, 0.014405217596269665, 0.027581980647218805, 0.02730839149726014, 0.02487402454379105, 0.08129277657116614, 0.03679282813062591, 0.03836460306399292, 0.056158496637738524, 0.04330263728456151, 0.08971154659746156, 0.01655518302633878, 0.07854381561159127, 0.10785217922661575, 0.015211761666221485, 0.014819542843578084, 0.027215591436552427, 0.045510200077607754, 0.030046004779456608, 0.03764240048645485, 0.07572337864868103, 0.045863810941697135, 0.05174308759911407, 0.05540236402603407, 0.05940140427781209, 0.01991516230778108, 0.018544226899863254, 0.014326485782681454, 0.02605970073941975, 0.02952761797895355, 0.040486482753148006, 0.02830576136588089, 0.006069440747641268, 0.05376107044397824, 0.05282923556684006, 0.07138834755507208, 0.08605991189758624, 0.017451042414552743, 0.050062872920065164, 0.05154712613852275, 0.040536293789984724, 0.05193209298135293, 0.06268928510948055, 0.01465169968263757, 0.04317547818044982, 0.03200026443077913, 0.030147055607108824, 0.11758783141211157, 0.049938000588407444, 0.08417011854509193, 0.08461651031769092, 0.05582642050520067, 0.0311738892172974, 0.07700708153988085, 0.013429436085355139, 0.05965697503979168, 0.03357812784792435, 0.05159959167001709, 0.02887080483619244, 0.054514514087068464, 0.048028913311540126, 0.056843697168533845, 0.03699394153250802, 0.05325300859347467, 0.04530733999525828, 0.027974819043470968, 0.02903438567544424, 0.05506936858798708, 0.03716790094791401, 0.004604372764832431, 0.016944254185223294, 0.06304646211285746, 0.02852601547455115, 0.052935116578854864, 0.07377068947760329, 0.012292252297723487, 0.03961655544117093, 0.02557599665446868, 0.05408714810806898, 0.04687367187392327, 0.013762575164887936, 0.02062903942480203, 0.04959943186071131, 0.04986884200104302, 0.01546939895037682, 0.038656785167873874, 0.021649439811646458, 0.0569337661257915, 0.06814833189691268, 0.04262877868548517, 0.12143517859400281, 0.025861624876157414, 0.042376007974868825, 0.004491169867481316, 0.09727478027343751, 0.09131150590556283, 0.023025743580693682, 0.016376493018000357, 0.05067640209510442, 0.056199114619483875, 0.047888420447106325, 0.09964053639240804, 0.03710778985893534, 0.018898632580174074, 0.11472540517007151, 0.04123818354621049, 0.05975197377284208, 0.08314608881670622, 0.040585442160766934, 0.08373085905106799, 0.028121425289540525, 0.02692434970559853, 0.041986892765928666, 0.06203340276354744, 0.034695206615593166, 0.05648319151312594, 0.02400980650206968, 0.07795169859403565, 0.02301211104608111, 0.04449079368984507, 0.02320979045884263, 0.057190394089106596, 0.055783741746939, 0.044087180266937906, 0.027307612002797188, 0.05540683031863263, 0.016349666534111868, 0.030748097548982313, 0.0795245383896174, 0.05001755115846473, 0.0014990837230617483, 0.08179097887008421, 0.025279597236564564, 0.011203431640751662, 0.016856554354871475, 0.017294130370681806, 0.06899649082052131, 0.012499636129265832, 0.05598796546579369, 0.009468664798224646, 0.04481725056745833, 0.029948797797964468, 0.04537462932808746, 0.041407105933514335, 0.031132192966798623, 0.024521970753407767, 0.12277361846739247, 0.059083205828022574, 0.05540221463888884, 0.08296264140235801, 0.030163811865232648, 0.04413467005736405, 0.05525218397979775, 0.03774859559451861, 0.02803865331976164, 0.008627302032114278, 0.10315980642072617, 0.06482590049985917, 0.0925529054215839, 0.10759089727916064, 0.005911623762409774, 0.020890830820726774, 0.026511755816998984, 0.02455767811155848, 0.049810309053188374, 0.08842222828177676, 0.04570245750308518, 0.04031213646334025, 0.03952891881307287, 0.022419270075437044, 0.033901133499438726, 0.05277957391714858, 0.023746996209205642, 0.04957253451368982, 0.023055492690013304, 0.05375511027992733, 0.02482554458472277, 0.034337723177046545, 0.0020248453168483873, 0.0303600472022569, 0.014852388863331609, 0.09013033622214872, 0.03954494537244882, 0.05336543199636283, 0.04571516307130937, 0.023167119361460212, 0.04215776101656018, 0.05244113542439957, 0.06944648320636443, 0.08319244479700443, 0.015477835493642959, 0.026500132347967838, 0.019671910239623922, 0.00547723850280407, 0.11042564476449644, 0.01219958630240252, 0.027172700088891773, 0.024436925417713584, 0.05414131052431561, 0.07098058193561531, 0.12154861323295102, 0.026574988714269093, 0.06533631424029028, 0.038064005484263745, 0.019858150044456124, 0.060880107189258265, 0.032419412201570894, 0.06895337539214282, 0.005036465506324726, 0.04293349781824697, 0.06473436831466614, 0.05596640775160444, 0.006239939360849319, 0.026898831316840746, 0.02214603715636317, 0.03191908400866293, 0.04073913088969646, 0.03147684251739374, 0.02096875345394496, 0.010651609890403287, 0.045340955933375705, 0.019312961657922116, 0.042285245708039695, 0.07640107534825802, 0.06755270619666384, 0.02705884410158521, 0.08587358399264275, 0.03627450453237661, 0.022623143309066375, 0.03800803510051581, 0.013414958938806048, 0.03930711720679556, 0.031840510200709105, 0.08493341024844878, 0.03834434386883532, 0.06515177898108959, 0.04676257763358374, 0.04512487317345316, 0.06437663589754412, 0.08848189887019897, 0.08565920960879134, 0.010963784973888148, 0.06400050587892052, 0.06814664650347925, 0.014653845686435461, 0.017288913311917457, 0.07057541335422186, 0.021895798366336573, 0.05619949000256677, 0.05125321267593292, 0.10131352686233099, 0.0144215821919422, 0.020007058384738142, 0.03547432186502603, 0.029895594906843, 0.04801859027676044, 0.05431332407639392, 0.00812363752629608, 0.018429369252595692, 0.04347944654704582, 0.0986228728546731, 0.04787634690141967, 0.022614293078321124, 0.042706368070456295, 0.030328894236816034, 0.028014092540909207, 0.016974880465216214, 0.052513450294012026, 0.015134843565794009, 0.04127617384637556, 0.033572236631786635, 0.042824786111351945, 0.06404380516840086, 0.024414390941420873, 0.007690184978738188, 0.09448716251720345, 0.053070668176177054, 0.0704338709493318, 0.08683377561429817, 0.034870368789040276, 0.034908964298665524, 0.0200328583108081, 0.04179534014134158, 0.022142333121249275, 0.02878128937746008, 0.05634488199927634, 0.0552699648805203, 0.053981653970455935, 0.03594625117858091, 0.035187950538050745, 0.0201945603194256, 0.07340862866370909, 0.020259036194352854, 0.03614239650027406, 0.009641588079713045, 0.020393588046933857, 0.013570081209763886, 0.04381689295593289, 0.02987240734059484, 0.0017947566741514172, 0.04926381257152365, 0.028503444609082038, 0.017717637181762728, 0.035746654630788875, 0.01844788559772555, 0.005885764464525687, 0.02367073598678314, 0.07845879517375462, 0.13548692417961938, 0.0630878844869233, 0.029391882520529534, 0.043130171740607876, 0.017089588725338542, 0.06691810960370688, 0.03550992963174659, 0.013647951174437279, 0.01899069145081505, 0.018293779350877292, 0.01115763586224808, 0.06727283129528647, 0.018714258199437492, 0.04847689854702161, 0.07636005900079205, 0.04072428793616353, 0.022809971086380464, 0.03642602906292004, 0.046049629398170984, 0.09672115151319774, 0.0322187507915641, 0.019257272811486356, 0.039786730382230975, 0.04637591007556166, 0.09534086025650464, 0.046371267582740516, 0.09049587507521914, 0.06051043529183634, 0.055037863222101045, 0.07076983114764576, 0.15811231978718313, 0.14226556124706424, 0.29541045968090335, 0.13696637785723134, 0.15580268726954538, 0.15080114436005393, 0.20639904083744173, 0.13152594317591962, 0.23409187823774355, 0.09889864152477634, 0.1269138027583399, 0.06952351334715082, 0.1354221591065007, 0.20547864748345268, 0.11377485859538279, 0.15559653300912152, 0.11808854647942128, 0.10697450293528457, 0.1446795196182305, 0.2714971783420732, 0.09017482294791168, 0.12455205327921337, 0.09441410071186482, 0.14658462706833117, 0.24138825284617565, 0.14099578583432784, 0.24331936132042642, 0.19154767565909894, 0.11178465409865303, 0.2429826043906712, 0.10576221476038618, 0.11662426900358931, 0.13453754205857554, 0.14789443823599047, 0.11871170537966876, 0.198632747896256, 0.20072389213788897, 0.1564979273825884, 0.2053182133503499, 0.0670492485345852, 0.12698205353151407, 0.21742434841730904, 0.07879712258375461, 0.18032571330906885, 0.1955311336824971, 0.15449356558101793, 0.08591940371139396, 0.14658565362614973, 0.09452050266366813, 0.10963662016776302, 0.18640912558522918, 0.19710146070968723, 0.12160731855058864, 0.11223384975305489, 0.14984100636455322, 0.14718571497548014, 0.1398231350486317, 0.11953494346310055, 0.08340363991597007, 0.11873690201149834, 0.15223211999381744, 0.15576278941044885, 0.11654004529719392, 0.17087578893669192, 0.22962016173668448, 0.104642853050703, 0.13676408467994583, 0.19064416688296104, 0.14231390139508632, 0.17771120844108446, 0.06890675894195034, 0.23556161792047564, 0.19696420839717313, 0.2746211929667381, 0.14941817179562586, 0.23165801690230448, 0.1906578338915302, 0.34844859593337585, 0.13198519756476726, 0.11413162574172021, 0.14510894254330667, 0.15332463798263382, 0.1395983648516478, 0.07245110302803016, 0.11309585954633453, 0.1579635914775633, 0.12152001517073763, 0.14795984682296554, 0.2312495694645951, 0.0746216522830148, 0.07091721880339807, 0.13925860485722943, 0.13768789478607718, 0.12895250062067665, 0.16133356629119766, 0.0828603380209496, 0.13477403340080094, 0.15846441379718243, 0.2912952804998044, 0.11305593104372103, 0.08273508264532975, 0.10478179075665052, 0.14976858041219174, 0.10001905277491578, 0.23384135216474536, 0.10361196683539499, 0.11425180195440209, 0.13679123483598232, 0.10055195885680376, 0.17202774002667398, 0.2084535507545356, 0.12272819711436188, 0.10583714582026006, 0.16152809133693097, 0.23275500884459865, 0.21783009922552496, 0.15266174210175393, 0.12693205097269628, 0.20116546521744422, 0.11318100255823905, 0.09955010737382597, 0.1282866093360128, 0.13883400828607623, 0.1280924443516039, 0.08491677847961265, 0.25533653825761815, 0.11279851784028354, 0.15205873897479427, 0.1281826282220502, 0.09230928180078346, 0.07521710944392028, 0.12957415032771327, 0.06181138282221171, 0.11002694196518391, 0.12046496654229781, 0.15538737568403446, 0.16065588491337915, 0.08729784103531031, 0.16238488407144624, 0.15688277931222994, 0.07494059000765124, 0.19432485163692506, 0.22066172873300893, 0.18657483040325104, 0.0774868977286162, 0.24575282429014486, 0.3441625178581284, 0.12145128176217118, 0.08382495763080736, 0.09574775253572772, 0.14306866653984593, 0.12186372051796607, 0.19181821194867935, 0.15601835634198882, 0.18773234329156338, 0.15422473000662942, 0.09210806880747119, 0.12343686674871754, 0.19572081705254896, 0.13620343089344042, 0.19224331413786258, 0.16011747832019485, 0.10875614765550821, 0.22241625394071304, 0.09698558974290088, 0.14962331481998967, 0.2099803639876266, 0.12667946412318176, 0.12109876640381352, 0.10425590970102819, 0.19115966744720939, 0.17675445655420904, 0.14405604662193408, 0.1724674591734525, 0.0778357358649373], [0.029970887943261096, 0.04753181800967263, 0.022810662480732127, 0.02694967274193562, 0.04700285728059469, 0.011318973979101548, 0.026597684069025903, 0.03571717556746256, 0.14715294173407942, 0.03806000267485938, 0.03340097767631373, 0.040018073613605196, 0.035692603297291264, 0.021518021258675767, 0.0839033360863405, 0.026098524160202474, 0.013529855848079728, 0.0023053472133113015, 0.044338246431922725, 0.01144883162792652, 0.04285366762609732, 0.020376764756116657, 0.023263223176341385, 0.018557020568198735, 0.012417439683040064, 0.038155468721543594, 0.02652261511332566, 0.03513852254517617, 0.062374867303597356, 0.049535180066501906, 0.04251132208493449, 0.08647538436156127, 0.013222532016375374, 0.05620497519210462, 0.08578330819164554, 0.041911237752966346, 0.04946514047802456, 0.011822290872524103, 0.05507080117240549, 0.01916962852250905, 0.03047888850673072, 0.02097292671791248, 0.03639437814032839, 0.016159148128222556, 0.001862175284317815, 0.0283454945160737, 0.05922397448410911, 0.01584991769519665, 0.06103809367144301, 0.029044948112700256, 0.04013269568883604, 0.05591805611226348, 0.06231726515257071, 0.058338556874303095, 0.08418960016100638, 0.029367158947993192, 0.04528198631540422, 0.02030343673522434, 0.009270186738802061, 0.010660592271315475, 0.029216486690265518, 0.024826509855507363, 0.12613133587423833, 0.04215631694082291, 0.022760263471413526, 0.08579417897929108, 0.022248505246675303, 0.0289293933254216, 0.030532104804390864, 0.02176811832243637, 0.014451630075552292, 0.14012963150537786, 0.056285238223931486, 0.019445136722718036, 0.01893164139361151, 0.06921682536842362, 0.01475560610302754, 0.03473790835649256, 0.1120700907983607, 0.03822880248809534, 0.013158948633879905, 0.03110724722876424, 0.06552642661957972, 0.017743389227337415, 0.08713491711645358, 0.06177934119477869, 0.02632576116030255, 0.07261238751872894, 0.02820422407239676, 0.04364548078287513, 0.031732920812623154, 0.0121556626512639, 0.048717921299319115, 0.03744092319280871, 0.04911832864426317, 0.008710944469297125, 0.03542317783520107, 0.04085133212708658, 0.02587819344273979, 0.015424452571859284, 0.043352540251949144, 0.05556848636197467, 0.059886314951243906, 0.05495329860657935, 0.006042853666229114, 0.06736032619711853, 0.02318949295928882, 0.02275620320541484, 0.05690757357966035, 0.03645879464344152, 0.020286841355564616, 0.07745225523268023, 0.027779999053886825, 0.03016729181962869, 0.04492557923039121, 0.017747734861087897, 0.036433544385457234, 0.0335352192632854, 0.05267397252722614, 0.019164043741541046, 0.045460419684288, 0.033430426096123074, 0.060617453944418705, 0.03793291251866087, 0.04126742512228028, 0.051547930530843236, 0.057071485751939405, 0.06927711648806449, 0.05765902156370783, 0.03421628291928961, 0.03464931794892877, 0.021969053608876084, 0.03666277704460006, 0.0643401930949861, 0.01694317974690949, 0.04311232572241176, 0.03778054529140073, 0.053415951664529504, 0.01577282914020602, 0.05644102220333392, 0.06901646273270731, 0.016468304825285753, 0.03354697488248348, 0.011285966123274017, 0.018572939875265284, 0.021457578836669846, 0.01466064663198326, 0.024157194157822, 0.0867396770345588, 0.03358791845159666, 0.02473078716936852, 0.03733434887122243, 0.026798584881509026, 0.022578298437198805, 0.024453380986327128, 0.11541952679474508, 0.0022364964975314515, 0.023383213612701625, 0.010139196660489807, 0.045071105292487534, 0.03408799766592922, 0.025543865011704546, 0.023058507245995348, 0.02880792625458731, 0.030959625916195013, 0.04331829995217343, 0.012413017440497155, 0.04886902831194382, 0.007472871211282308, 0.03080308350974754, 0.06769748149259437, 0.03710068056299802, 0.05082017764629376, 0.04919039453530023, 0.006125096556535292, 0.03308074526308525, 0.06016514031216503, 0.01893632219082886, 0.05062441919900237, 0.07265561786029609, 0.03639229055073473, 0.01266081145243539, 0.02224002465335352, 0.04767629836175231, 0.02612246823827586, 0.028441793683375564, 0.05812460383881004, 0.04819781654664586, 0.07962150213819358, 0.030238484370432077, 0.11078634960276466, 0.011998811894426904, 0.037064176473406055, 0.05621509904402399, 0.08643290478615992, 0.07568512787862171, 0.025878287288510514, 0.023883771631986867, 0.0386486646358765, 0.04818699938515502, 0.018175746269163587, 0.03868860462980886, 0.048738881464927435, 0.06009269520760544, 0.05552697971823716, 0.0666054844435665, 0.04154225533467628, 0.08710869392680545, 0.03777596025517391, 0.11572973111704474, 0.02541948489153818, 0.05173733427880272, 0.034697704062226324, 0.04110860743469769, 0.03791231241437697, 0.023805381685134866, 0.021977850213466633, 0.007585908442119798, 0.023073848156679063, 0.0764287234614453, 0.08835044584327167, 0.038452603583855015, 0.037662468159631375, 0.036159361517357255, 0.03501475338012942, 0.011491800541989507, 0.03710481743778914, 0.017253996939548565, 0.04717430009716942, 0.012945557715401295, 0.02811537894059814, 0.05331206631155745, 0.053466854376658324, 0.012143982683248337, 0.047657444937935764, 0.05191735728012939, 0.009038785093223617, 0.015429133369076638, 0.04767940484828526, 0.05385426503996696, 0.09066134240598449, 0.02741529906709348, 0.10822275893822794, 0.022832662610697652, 0.026302483578723286, 0.07636616472154856, 0.05132383832167234, 0.03518258409214116, 0.1362580682842001, 0.047216304698057716, 0.035167679851574284, 0.01355617575632829, 0.001854091021795607, 0.040713930427427256, 0.07434595256082474, 0.061782175720098524, 0.07829475276652845, 0.058674245111403935, 0.025076959319713137, 0.1422697287653723, 0.028948557014847477, 0.033382817562068665, 0.03526262878890961, 0.045280009808559576, 0.06933391424677066, 0.06559449353165205, 0.028737243152253573, 0.03617289829097929, 0.06313936176499532, 0.006433608782132187, 0.051576632014926405, 0.09012840568057953, 0.09903105982248822, 0.029108663645362663, 0.0045258272063708116, 0.049089270929295215, 0.05272903126634417, 0.07984970440907825, 0.025642667371299, 0.03305327718056018, 0.051774428256096384, 0.020551850320771337, 0.08479346130644122, 0.021516988955197797, 0.04681081052929644, 0.05269644571648491, 0.02696999322412716, 0.01528423741429804, 0.06115391850471497, 0.04052962882504348, 0.01485092659300614, 0.0206316651911625, 0.006004692911500893, 0.06454718239124745, 0.020275231293072144, 0.046972033732961264, 0.07908911699609411, 0.02280255727049324, 0.005422809871003753, 0.04031576772010134, 0.026619259020193454, 0.11373699086928561, 0.0414028579759742, 0.050324001649935404, 0.0029560431439970294, 0.03308019751021939, 0.013566203847257121, 0.07882938254624605, 0.02128434145913249, 0.05539697842792638, 0.010597751036496654, 0.013985897455694936, 0.06244769162167946, 0.027972350325134974, 0.028308775921862935, 0.05666722498473622, 0.09428055626490424, 0.0322613989063088, 0.047063837879367416, 0.02550205767845675, 0.04947853552538061, 0.0171860660080828, 0.029427220241256782, 0.021607613326200557, 0.07977275853796352, 0.03136685144366517, 0.01793123398637099, 0.024178841887342355, 0.021890173365752545, 0.04059601034368238, 0.021696782130147182, 0.017434619404675982, 0.014843146012525165, 0.08292703363563746, 0.06538568094613091, 0.056614284478728814, 0.03922973083512437, 0.011337946146546353, 0.021659119332569744, 0.06188890708970928, 0.04605128414808743, 0.0584688684302232, 0.007577319160073756, 0.021625658527256984, 0.032525304704904556, 0.055178470999723485, 0.07859242389038687, 0.04624579387206224, 0.02842057879353243, 0.046758977020339626, 0.05269173427575058, 0.04899256382017367, 0.19378727241869897, 0.12508270706260396, 0.18576608670334663, 0.15393816715767308, 0.2186037560984973, 0.18666631662316863, 0.15960563965622457, 0.1779909684292732, 0.28866618931774174, 0.09086647776946907, 0.149644811247145, 0.10322941316952629, 0.19924551098337098, 0.09226895493244933, 0.3043845055564758, 0.16331454708931908, 0.09143787210867291, 0.16576737676176334, 0.31097681471897715, 0.17355171873444514, 0.23729253229835343, 0.08610095122768995, 0.1190256865154351, 0.13625694979583064, 0.0938616976923039, 0.12434965284961848, 0.13723351271642795, 0.12364731110151737, 0.16711112562446825, 0.0840168243514434, 0.16563715713639415, 0.15824784074098835, 0.1653680304485944, 0.24601953014010386, 0.1854021030087625, 0.15849052207364192, 0.138725652810066, 0.1174432629599206, 0.1720695684273397, 0.10840629062224781, 0.12858226564863037, 0.09728235688300864, 0.1268839483119307, 0.15235444891356653, 0.13688269041238293, 0.05631942106711288, 0.13963312992165167, 0.09178350799747052, 0.0876303002118103, 0.06514120696773452, 0.15495145633336038, 0.15420130303790494, 0.234545509541227, 0.1576225750989491, 0.18248932946833873, 0.13778520327421928, 0.2308009943414119, 0.07721785531048814, 0.20383103750646117, 0.11174084153026344, 0.09684184866566813, 0.08428925287819679, 0.22069611075905063, 0.19997249777999618, 0.13001601452067976, 0.15245630796397888, 0.16417852572856412, 0.18483142879220749, 0.1735899465218667, 0.15973782046667992, 0.11992901143047119, 0.26672647304592595, 0.2585028562574618, 0.09719761989770398, 0.11399386015029685, 0.11608334964201336, 0.11100494513107885, 0.1759965504489599, 0.2520911140187133, 0.1066953098521598, 0.11342962873318505, 0.22803757730270588, 0.12705241104648, 0.23493831346352256, 0.20471088948749727, 0.18447475357642099, 0.15169349889601433, 0.2112839851648577, 0.14221795654344943, 0.15420553184324695, 0.09437342144308553, 0.11644851311200088, 0.14286091881653956, 0.10109349108871915, 0.18632128594383118, 0.17044319440760922, 0.17302730090675816, 0.2303650137037039, 0.1593993781434913, 0.14581484660025568, 0.19448779853841952, 0.21231916913342094, 0.09998744398715997, 0.10714805249365107, 0.11045304772954796, 0.10069791392813768, 0.25189205373246826, 0.1054772760178293, 0.1553179221528192, 0.1428694990012915, 0.08619966931761273, 0.19964088896109214, 0.1598547408056836, 0.06901411084277977, 0.11039448796861595, 0.06256739669028791, 0.07549255635709533, 0.17202735698271185, 0.1162817127882473, 0.19661707863692315, 0.19439896298271997, 0.15052440275828685, 0.16402987402773675, 0.17995894105444032, 0.14809581210776684, 0.2940094687284962, 0.17946649973671283, 0.12699932881420659, 0.12482591439038516, 0.14549235422765056, 0.1672647262532865, 0.1414826040666911, 0.20167701276800326, 0.10473508237590713, 0.0614391713433208, 0.11179328024868043, 0.09463593679209871, 0.25713407164139135, 0.09832616700159927, 0.2232900078618719, 0.21896845991573027, 0.0988210674615637, 0.1646297974812408, 0.13370347149189443, 0.07015987960321289, 0.0883637298078787, 0.08615876022245615, 0.06121452755084442, 0.2684092617804005, 0.13637684255598054, 0.09514580661010358, 0.17553481393523757, 0.07299528592416356, 0.13683690899802795, 0.1445054184765585, 0.16074715662867795, 0.10115741346512111, 0.08985583159712054, 0.19351249200201806, 0.1266058200910207, 0.12864667832130386, 0.23658181720923996, 0.08789138297640509, 0.10926406394930617, 0.138866183978896, 0.2233846810075545, 0.10908056290880327, 0.14239371243503787, 0.08915263949142349, 0.10586827197262358, 0.15941203391600042, 0.11304231766130655, 0.18535921740676128, 0.1815488952542505, 0.08686722301307225, 0.09896988770173443], [0.0230947585265723, 0.04629287763588852, 0.03359131988198046, 0.10336380797408282, 0.04032363927352332, 0.03941564505258876, 0.027232598588471452, 0.002306919608775887, 0.04233910934999586, 0.044543301356175256, 0.03989539612385054, 0.04005937724404278, 0.08017842507650776, 0.08955620694905521, 0.04702965503618602, 0.03347443401693337, 0.05611020245499188, 0.0452135784942056, 0.05783161351216897, 0.00368875740546613, 0.02666765279437025, 0.03273078480795507, 0.016612258491917484, 0.02572815895320908, 0.030635821618019577, 0.030891838626215057, 0.06998734894178568, 0.129110238124286, 0.03748434505635693, 0.06781863829781933, 0.06092061025781497, 0.026597149722698717, 0.03867017638479029, 0.020273015383751165, 0.05482642678543926, 0.038643325003044265, 0.06517327540824491, 0.05232680446257996, 0.06755387065030875, 0.010780552064158745, 0.027004698922316876, 0.05672552427577396, 0.013152261643910841, 0.02042568713096121, 0.009959075025342887, 0.029971661692064618, 0.020137214807853587, 0.048378188117978074, 0.04720053860857602, 0.0724957276496195, 0.018502664714751225, 0.0557842243823313, 0.021988159841707638, 0.022370506663836782, 0.09369495865558425, 0.012004319108992577, 0.03349887605215754, 0.07347193050889239, 0.05999383156097705, 0.007557960597032141, 0.11740707296637759, 0.025235890005264553, 0.03035523808531223, 0.034179288533426104, 0.03730832869487424, 0.07653111111252539, 0.03815959410501584, 0.026823385062837796, 0.06741906215827312, 0.037063153746027144, 0.04688680262094544, 0.08124148698463556, 0.03325304226769555, 0.01368573080042317, 0.01342002948325488, 0.04110597975311741, 0.005471106447775158, 0.06165132790263142, 0.005835342472569356, 0.083104275737799, 0.04517397557895991, 0.05318245572608806, 0.029128034178528096, 0.08147350437338315, 0.035004851693708094, 0.031193273157001506, 0.03424873440376213, 0.012379908078019659, 0.05203044334907205, 0.04714212440434964, 0.08803697798641459, 0.05329984337872556, 0.044295249747172485, 0.05526171794401542, 0.06997321461958271, 0.05465328708411225, 0.032166698947548866, 0.00379829672672185, 0.030460021676375505, 0.038643807638436556, 0.044354724983174, 0.031150140491644704, 0.056403200442512194, 0.05649597752058218, 0.018658877703391256, 0.053306121469265035, 0.027009061793045654, 0.050425933478700544, 0.005679331539619354, 0.1008261876901792, 0.029726925328554168, 0.04692445584242383, 0.02991772335653584, 0.04257864206128063, 0.031900971774913134, 0.049450174950423746, 0.05250388568627739, 0.04644886462859089, 0.018661919072450652, 0.03197125268108662, 0.0651097743802013, 0.036775629456725814, 0.01752038103257937, 0.0455887240898465, 0.07015414160466002, 0.0611289210557457, 0.01928647991359955, 0.024502757268266815, 0.0750211211702516, 0.04066848992219856, 0.028051152044246276, 0.10226027364091528, 0.005879784190666772, 0.04333698483664663, 0.03285567246137127, 0.01621455160690652, 0.025978146849440473, 0.06111791620271341, 0.12098946097877719, 0.06136909345044725, 0.021386175611687284, 0.06076064343834597, 0.09775360820875054, 0.05109565520298578, 0.05159767261976677, 0.043343385501253995, 0.013135223848474844, 0.021289728972459995, 0.04055091840845924, 0.03872529641094227, 0.009060451017332175, 0.022977730935259212, 0.03614801958563828, 0.03959256922826171, 0.04567882369062112, 0.027293155923666015, 0.0398952275845072, 0.08429443929344417, 0.0452277357990463, 0.026711260434240106, 0.04056630145397879, 0.019906091826757597, 0.005455131120529147, 0.03971152353070436, 0.01584318569756203, 0.035918679674186056, 0.028998810467460466, 0.07689937723860626, 0.03831150550996104, 0.0334554158842131, 0.02638380955754509, 0.08391858123603367, 0.009738037591770051, 0.0400961609557271, 0.03536769391728505, 0.027067700077989892, 0.009764264611857794, 0.04018475902417014, 0.06352856124360716, 0.021154198442555724, 0.030248456919986396, 0.03872217077221121, 0.05658982329130654, 0.02290629323632006, 0.03777289590347679, 0.047135559030838554, 0.025752627801510598, 0.0700110670239214, 0.026822320200623046, 0.01822656088118111, 0.050764054044960975, 0.001126742488028662, 0.02016301281870373, 0.0425321213720787, 0.025979445368472128, 0.03157065764460112, 0.010811820900398157, 0.015244613431634442, 0.002716834823067691, 0.008302112072405797, 0.03630810514873555, 0.025752713986402078, 0.04040264592115437, 0.05686016422846625, 0.04490663004558414, 0.045239142848238836, 0.08144824645451962, 0.020822135716556542, 0.08107879289215611, 0.055922116378262166, 0.06156705057008132, 0.08270099173269926, 0.06574346698940763, 0.03447596374298296, 0.051224936370647726, 0.030490536873619405, 0.07434735450172618, 0.050369874994841315, 0.028495977167040113, 0.023993563522855123, 0.05274455986856934, 0.010016970205000572, 0.04840751013327991, 0.061668603185323946, 0.09590542109142389, 0.02546594812414579, 0.07164715503853175, 0.02553019225747595, 0.057116079730011766, 0.04443736288756613, 0.07552787301040466, 0.04587124582500227, 0.06209292013438479, 0.07746779915666388, 0.03426774870604277, 0.0331769161106598, 0.05186470405709359, 0.05619333065565556, 0.019093410434922384, 0.011667991188474962, 0.049990220971766024, 0.03279011831769059, 0.04630513121223739, 0.06265785252194732, 0.09137402634106337, 0.013042847051345294, 0.02149628925948374, 0.03637619887388522, 0.03174082300956211, 0.027252235337190574, 0.037223201004728194, 0.08368367569581156, 0.0063167731916051245, 0.06248023120626327, 0.08224894623121909, 0.030611408311092568, 0.007291202557333295, 0.012059310815417239, 0.06984383769093022, 0.06519205988414827, 0.004718533750893849, 0.024549230076973478, 0.10867373191661413, 0.04109701269396371, 0.013127739169454623, 0.027741499305252108, 0.04341398433391606, 0.01906856045787854, 0.02589020761661232, 0.1607920187375238, 0.048666807913011124, 0.02297506494928272, 0.031626668247965076, 0.07322858267974469, 0.04726702354908471, 0.009626296007134503, 0.04429293616164116, 0.03148179719104402, 0.03801343602038199, 0.054843460750435634, 0.2042579476631457, 0.05646999564863021, 0.0398031821204049, 0.035173877502881715, 0.04046143550846366, 0.02321426249710062, 0.0639948636413582, 0.024209954633167195, 0.046766879217278574, 0.028094194694271976, 0.049362798792219935, 0.020431446196931987, 0.04946280390985551, 0.04063841714073093, 0.02446092503716148, 0.0270550481359204, 0.0645542610436678, 0.04544614746625866, 0.03962311315380278, 0.0369200753348489, 0.06526630146489029, 0.028699362019617713, 0.012837445472307023, 0.046447757631540305, 0.01693234534844035, 0.00968300662333927, 0.042093252582896146, 0.04624390546532889, 0.010187641187991587, 0.03863389446069637, 0.09285691209257611, 0.018790709943841064, 0.03296008641501108, 0.021757841252932147, 0.03405142845886369, 0.07000935864785025, 0.03617740288797406, 0.010517177739060454, 0.05926192647987797, 0.03136913821611914, 0.0925155739570337, 0.05043778102844954, 0.07525879994875963, 0.08740925320213841, 0.018906883347118576, 0.042229999277380206, 0.0528385665177578, 0.018166082069998788, 0.009025993340107943, 0.08976903383529956, 0.06140390065528693, 0.011691891216492702, 0.014431540377347942, 0.041581383275408904, 0.0182003932329075, 0.028368155396873915, 0.03486532410005889, 0.052462880830130273, 0.05464209453953851, 0.12469370293641284, 0.03320903817732488, 0.03584807701108437, 0.019553112985205748, 0.08937932490821808, 0.05816451701966505, 0.0395647908801273, 0.023806086486025203, 0.05705888743602461, 0.071038942513687, 0.03616938194740684, 0.029064954498842843, 0.028161631499026573, 0.153734372448056, 0.11709661583506292, 0.13473926833079708, 0.13877396231457112, 0.10097284756240346, 0.1148488219346731, 0.14577908561595027, 0.11645651873080962, 0.1590490921009933, 0.1731634500526613, 0.11576205236657013, 0.1972228550021687, 0.10381799852175098, 0.2016330086776326, 0.08741097689996805, 0.10249660410467656, 0.09168473628139304, 0.11651805857376707, 0.13002286334672283, 0.1188878060108231, 0.11194958516787137, 0.14093543342765302, 0.25336646655153844, 0.16141592074305783, 0.1399834925729421, 0.1533854653638217, 0.1611403895602111, 0.1546090303529655, 0.1623257267619333, 0.13875933003521737, 0.19518230320705524, 0.12958712785715057, 0.13516426326767092, 0.08689833384367728, 0.12369895308849313, 0.10671012599261538, 0.2640940110769964, 0.13640342580695308, 0.20537605298863304, 0.0662211228101965, 0.13043766931420372, 0.20384039910089588, 0.1135930046439171, 0.1263042189361107, 0.11719393964496352, 0.11667574245122173, 0.09975737246174006, 0.08664334913895977, 0.18199296578043894, 0.16151310665713203, 0.20977264690783717, 0.08729368117788146, 0.12643297533354453, 0.17453709166617165, 0.17843223507365874, 0.14422996390250423, 0.13237351221182656, 0.1913658829946672, 0.15126378485752692, 0.0914444221604255, 0.23144053986235974, 0.20000836601661098, 0.12177765053967315, 0.08492937296508782, 0.10415553686118896, 0.17614881808478988, 0.17034055394751413, 0.12553862130810178, 0.2597641740595141, 0.0495734078539235, 0.14667271185786496, 0.2086870543538563, 0.125848749021609, 0.1864918324375345, 0.1078385505224428, 0.21530875064913305, 0.12909301646774815, 0.15062192575104777, 0.12186318425641907, 0.1841918373059842, 0.07973738825849949, 0.172258225239573, 0.21078838756488216, 0.12760956381117144, 0.11380845921174174, 0.1391499123025325, 0.206788964269142, 0.1032915888654609, 0.12423450217371988, 0.10981409975718107, 0.16180461843407926, 0.11822337795409465, 0.11327521605116707, 0.27386003864868996, 0.16119623736989114, 0.2173515700645024, 0.17030260195174526, 0.12515391493516584, 0.09629734401260653, 0.09595092671412615, 0.15304011292755604, 0.19598884057373772, 0.23507974861610323, 0.1096797509179, 0.32364505913949787, 0.17278829679614113, 0.10016034237079083, 0.12919354252517223, 0.1379073023675911, 0.11434321922640647, 0.143399202835656, 0.1033798038899418, 0.11154864539181995, 0.12278586055242247, 0.15001890730232964, 0.10128184146578274, 0.11146055294140694, 0.12943674479761433, 0.08806501680444326, 0.14639505095058872, 0.2687441647773789, 0.14298012209755762, 0.08905507819426638, 0.07780680072403724, 0.22180030392783306, 0.19280226720917612, 0.09911297760423153, 0.14027793080576006, 0.2492738869642058, 0.12004027037971443, 0.17025354168107434, 0.1318189564851984, 0.08904263692637605, 0.12902639746185274, 0.22375067185250022, 0.1503520789405992, 0.191272389624388, 0.19569708364865473, 0.2582080043371647, 0.18899147008215228, 0.09380339840126616, 0.13155476340363104, 0.2807123886962091, 0.16194516492466773, 0.27649596333503723, 0.11268843866644368, 0.1564713134880989, 0.10352446427268368, 0.18385629079514937, 0.10878731211226796, 0.1639312019030894, 0.08468664566715879, 0.15353327436793238, 0.12524218358580144, 0.1310603455790589, 0.09778890187942213, 0.13066558047167717, 0.15619860150881354, 0.1616508339441592, 0.16945498695056285, 0.2177412483480669, 0.20343665544304157, 0.2263590480170904, 0.31298813259890007, 0.08500041229830635, 0.11905793115616807, 0.12611209940645965, 0.20014140484554155, 0.16005024644396, 0.1118500626856281, 0.08676996815108484, 0.20221131312991344, 0.15129016892563912, 0.14204238451296283, 0.09434168242038259, 0.14207679718252153], [0.024121751100005164, 0.12852891528558347, 0.015921275912513657, 0.05135442055160961, 0.03339144754253569, 0.09505284184049215, 0.053195440916404615, 0.07049895011849942, 0.06550776471774425, 0.012516660518163155, 0.021080694221440825, 0.03724614916850002, 0.061068246892142686, 0.0452607388668243, 0.017059849192117973, 0.08511364775439424, 0.05724629552494134, 0.04989986856197638, 0.04341540159657598, 0.0812832311156296, 0.038369789479240295, 0.06018757136658796, 0.019407799512508418, 0.012813322321181337, 0.08508682701616518, 0.09499057421400663, 0.018377200580172, 0.05119469121939713, 0.09556206814464062, 0.027170905527929147, 0.03395294402575782, 0.06230693062647216, 0.08464416609175744, 0.03190037422633219, 0.04219175999863975, 0.01673289052691431, 0.04944566652298935, 0.03737225490171583, 0.06703799470297753, 0.04019667552183232, 0.01672800480117721, 0.022100083372225205, 0.03548662523708997, 0.018685778880852367, 0.05189414481602369, 0.025546234138610385, 0.020794476112050396, 0.029414439979459972, 0.031767929115542964, 0.03335226980608798, 0.0403789010259413, 0.0703107376372622, 0.050326767227342056, 0.04900033578216549, 0.09554764270902642, 0.0509925167857399, 0.04158945784213082, 0.053989709384979746, 0.015068263821904699, 0.011968858814197443, 0.040827142900877425, 0.06629659013161737, 0.04009302382567718, 0.004978122165231335, 0.055393672758533116, 0.02256055775609228, 0.04056401468152481, 0.019306704634800553, 0.042258811844212395, 0.04744975850166333, 0.04920084397458742, 0.09911013541803246, 0.057359741655208414, 0.05361847083775267, 0.021156912309027488, 0.07248840384906338, 0.04201129649675662, 0.041230622258397846, 0.044119129963820024, 0.034673495683819056, 0.08226211528263747, 0.04562643476791921, 0.03942561951736289, 0.033124458240044695, 0.042828524620422435, 0.04325955249969998, 0.09136535422576052, 0.019788188979991024, 0.09359528295575612, 0.07443112621624624, 0.005330205162716729, 0.0848283029852375, 0.027199086072223804, 0.03288863722475306, 0.03446963968716803, 0.012689345354785123, 0.032359665004356254, 0.04392276247662883, 0.05424110113733238, 0.008573516914170356, 0.007142671994158939, 0.029482736717909578, 0.07119753803577154, 0.042816914557929964, 0.0993110956023297, 0.06524236121725652, 0.07177873063952693, 0.012421948110474455, 0.03172325278301874, 0.01590113641859423, 0.06678093389998521, 0.0256103269695755, 0.016642134005744613, 0.10149571789248336, 0.028845495206394026, 0.02304706955328584, 0.020279599909460353, 0.1220334472975904, 0.035023712778403875, 0.028723681480773998, 0.08005181372526192, 0.030478651019474192, 0.03969443976999291, 0.023546664217006297, 0.03659014041805941, 0.02564592132975738, 0.03834352798519596, 0.07788793709609779, 0.011345832064116915, 0.0341153048699902, 0.04972358790015982, 0.03403681533170804, 0.048326779787819234, 0.11312923799719542, 0.05108274662146165, 0.010992094795520027, 0.053667975439419674, 0.04860933982737122, 0.030155467252517422, 0.06397807865493721, 0.016214367745804693, 0.011490695460158731, 0.07650547781057897, 0.04606165314814256, 0.026460673074207963, 0.05157731766361864, 0.02650412558127315, 0.024610377299869736, 0.019979086599402854, 0.06144196373380481, 0.03792545848315762, 0.04932305798114789, 0.06428563997389809, 0.031536298601197145, 0.029308578119643276, 0.05272965945844209, 0.02327337001089848, 0.024727665361077077, 0.016756419002288775, 0.00865302630700171, 0.05691860907620961, 0.017708145352380893, 0.05951567778303739, 0.023387580313870025, 0.038186502943356196, 0.03218576687598421, 0.03285515152158276, 0.10409319262591102, 0.03395786614067132, 0.039057721113485676, 0.034917804953311725, 0.03601377799866661, 0.0761946069917852, 0.05535007469476231, 0.029569511497092825, 0.046740108274764595, 0.07211491300333893, 0.03656724588044229, 0.05529370977573338, 0.05547040795546867, 0.04513679350155496, 0.05372881048148679, 0.029905088651444645, 0.1074455091128907, 0.07885461748247186, 0.025311640779217406, 0.030199346853600397, 0.0731719381386234, 0.013293108824009617, 0.03777453150119513, 0.08901955469721749, 0.049684609346572435, 0.09616556922875105, 0.07797904027205321, 0.024463895543087876, 0.06587311970971285, 0.009905915226667159, 0.06822078083191188, 0.018165001886025555, 0.03114120216078816, 0.0439309711087375, 0.05465739331538639, 0.04570327338672454, 0.009788236460618435, 0.04571643477726368, 0.08145631336036228, 0.022337363785012596, 0.037936831058393565, 0.03415794149341603, 0.04072840182831691, 0.03094921478130404, 0.09320104644904215, 0.011846672578324235, 0.05277623760423834, 0.008694074255594564, 0.06491990714904762, 0.04417028548496385, 0.02186658743378376, 0.04147756303991041, 0.03985797272874944, 0.0947036053384504, 0.0216398005103392, 0.011962796185886668, 0.034124068915843964, 0.04108996468506033, 0.030031514226368843, 0.07002806651496118, 0.0524221326134378, 0.0457663377446513, 0.07559346545848154, 0.09857068694527112, 0.025842727402285225, 0.020871241952502922, 0.08995583671475611, 0.017046065355140357, 0.1284105470404029, 0.04626882630550573, 0.015463807466139477, 0.011831132484780205, 0.07116752271089824, 0.06642190679427117, 0.011414061769873146, 0.01713418653385053, 0.10092703550453148, 0.07012884538140028, 0.028361469364514755, 0.03988951639903169, 0.018362541487740896, 0.037374974513847026, 0.050081190082334706, 0.049104240287335656, 0.040822002450905504, 0.0032389974794275462, 0.05190197040417022, 0.032389213015595754, 0.019155526759042855, 0.11326953167876891, 0.010527619517468398, 0.02234639213120024, 0.049225841423556696, 0.0374543986793968, 0.07334471394818637, 0.04492867039516569, 0.013767486746092478, 0.04494021917062421, 0.07556548792748682, 0.04119724763797657, 0.08044744451199809, 0.03894918560681324, 0.05947503681865431, 0.04373319785020525, 0.03537660351984444, 0.014376458655592176, 0.08531358138087296, 0.05146945248387995, 0.03907368255538806, 0.024758893020090558, 0.011123146583896973, 0.05556938268484608, 0.065547417428705, 0.060789911827493104, 0.052282275601981155, 0.04781336298272495, 0.0067205058369455084, 0.04421531996359268, 0.008439235107582665, 0.07425471914992218, 0.03404460261545835, 0.02358360689193491, 0.0324560503565496, 0.04071440540194031, 0.03589555531019165, 0.022456392781027866, 0.0159645052964709, 0.023921815558306636, 0.037301092994429415, 0.052045742124919935, 0.04046682493701097, 0.05752313671813858, 0.10188384101756158, 0.10685193652827894, 0.006395858842053361, 0.08808694990171541, 0.04314503001589929, 0.03622385845970243, 0.05718804219917906, 0.03731851000338793, 0.046255668745406216, 0.0696199944603347, 0.04087165643971774, 0.0592118204991904, 0.02619031873050957, 0.03885412175628928, 0.03407940598985842, 0.026775780359223008, 0.020696334503290635, 0.04146466594970515, 0.05400355642421111, 0.05871192897639929, 0.02256259554997087, 0.0168485410751835, 0.06899790808318124, 0.0385466332156812, 0.04299595313627393, 0.021015576747876984, 0.013662095072739308, 0.0331608435860084, 0.026132806594814026, 0.04912733017737347, 0.02065630640924698, 0.0559970053033002, 0.028129480704064333, 0.03780242476251818, 0.04041906701581132, 0.037235439259318576, 0.04044439771302766, 0.02416479183481105, 0.048348303028051896, 0.0340689871940882, 0.026383144976270777, 0.041109879140652, 0.0479837179544472, 0.06921790555239686, 0.03737543416660159, 0.015354667707616764, 0.020261411066918124, 0.06266230732322702, 0.060067127023132584, 0.06508966457218894, 0.03480787133617747, 0.04192550614055607, 0.027433085713475466, 0.09426443777497738, 0.23653625029950376, 0.14619280373857868, 0.2354568937012265, 0.09686621026166024, 0.17711061083020704, 0.20602329003234066, 0.21712736677258246, 0.11885677178901051, 0.17384493122658423, 0.18843319116821214, 0.1713334192191401, 0.21247526720887233, 0.15261205363898508, 0.2142701805719445, 0.17917987560072254, 0.15953888275450276, 0.09096279800418886, 0.14278521400786218, 0.1402605559316374, 0.09379810473370938, 0.19506214997701107, 0.10240275833395221, 0.13975343636928067, 0.17743036060804324, 0.18778465177503326, 0.11834400615865186, 0.15515215604776336, 0.14225031609737104, 0.23683925339531517, 0.09804589373450126, 0.12900603484482537, 0.13578572911360573, 0.13656877822452976, 0.12412440001724229, 0.1369632215749833, 0.06895209602530926, 0.16253493005229583, 0.20735266708558608, 0.15562212034579248, 0.12794550102684768, 0.11631389614194633, 0.13450008035907823, 0.15531893338887923, 0.2839382930148033, 0.11512822952241668, 0.1093341380117401, 0.1344147381643134, 0.12386185402471213, 0.13783392646620352, 0.26160600264706924, 0.17166823028556763, 0.10098384092411689, 0.12781914248461687, 0.1417449432154817, 0.09300179464081604, 0.09267302800811107, 0.14939186433630605, 0.11348346939250348, 0.2983003884794251, 0.10874673243491881, 0.11961633264417611, 0.15961504721593472, 0.11193683746481135, 0.19765453022574225, 0.16159532321316583, 0.1226468768811995, 0.17699810315764722, 0.15453994454395387, 0.12230954538550108, 0.28652117377327335, 0.15109501568780792, 0.18252424775592743, 0.2597480862131042, 0.1526835909293544, 0.21340214166670077, 0.16794973143166111, 0.10849604548345651, 0.13284529979911544, 0.16574500699437436, 0.22319404768847653, 0.1956967006046926, 0.13414469217100453, 0.11150393650055894, 0.14781006131201022, 0.11846465734584678, 0.1665352879753036, 0.08169046813441862, 0.19504175671646673, 0.19126794631442717, 0.12555804163698228, 0.15417560844892456, 0.11109545841933259, 0.16174677879579608, 0.206262998943848, 0.14324368698702705, 0.10753455917320906, 0.23545471801152154, 0.1929820067579708, 0.16348268806694016, 0.19501275262765347, 0.13113897684360706, 0.16191239168326702, 0.20195799849687085, 0.14070294106439238, 0.12037350330501796, 0.20538827975190457, 0.12990284801250504, 0.1488005823545879, 0.14458290060922024, 0.15884577236588926, 0.09427310989028025, 0.10527871368873505, 0.15626371898237737, 0.15462464322486233, 0.14012682762357498, 0.04559379942234486, 0.23340555538813915, 0.12369131519188806, 0.10628968927889101, 0.25304933679440333, 0.14216984622180462, 0.11360930699494579, 0.1708390780033604, 0.21704059965427847, 0.15805181416292347, 0.14007287971194715, 0.29241275763319385, 0.15715593562251137, 0.2238305441794857, 0.15243323339569956, 0.20947666117741218, 0.14827676207548188, 0.19948129752470603, 0.174301948638693, 0.14489154211215435, 0.12437321771416934, 0.1642789445336788, 0.11198170723453646, 0.17148340391295572, 0.19848988782013618, 0.2283793291257274, 0.19176208834734657, 0.13745359445531524, 0.0679059186950326, 0.1226909729021211, 0.11422275190031338, 0.12300586568251734, 0.10049300839103038, 0.11451312986713265, 0.1185590317172389, 0.21640315321424317, 0.16720559958729053, 0.14163458058910985, 0.1272600745001147, 0.18600711328608377, 0.1562182440031921, 0.18254341527579293, 0.12903807264181877, 0.16548795385226128, 0.13414548890244576, 0.20824804000796812, 0.08884166908119956, 0.12587589151676626, 0.2069033411962371, 0.16338410787284374, 0.19520102639592465, 0.19346758392789673, 0.09189164130798272, 0.12265787790379218, 0.18142066745748445, 0.11185382417733632, 0.17664138197658524, 0.18635741465034025, 0.11637421024422492, 0.09983892252127971], [0.0482429429558256, 0.028812407868944352, 0.07724867502768194, 0.02588797447031304, 0.011735804333922364, 0.06633992006461467, 0.028306717060566432, 0.03387523589715843, 0.023189711294347243, 0.029653547511946772, 0.0169776881774587, 0.03621007653794462, 0.060836570412521405, 0.01264008973169351, 0.03401449536003413, 0.025485297589893305, 0.05922616932601218, 0.043345553530079704, 0.07923494183248089, 0.024964093501048706, 0.00891803814503815, 0.006908892603185509, 0.033402586460954724, 0.027789102093647086, 0.02521979449797542, 0.09749056425906959, 0.01793855395648749, 0.0023515107140185372, 0.05353123640581485, 0.009794774063442264, 0.03981252839308112, 0.004225958846584564, 0.021710970078504855, 0.016593330374528325, 0.009693612153041027, 0.05143941417636891, 0.004657122227663716, 0.02438758935538992, 0.042184148915112026, 0.014934608292195105, 0.021868868460578304, 0.06463103837543918, 0.01984939557470141, 0.006218968661532047, 0.04369471342332902, 0.02097609449147938, 0.025413210631438324, 0.02508011177152155, 0.012329902646372156, 0.0325564346877077, 0.02297643624666718, 0.01241549860776192, 0.005406873805763861, 0.04321139238234009, 0.022707412980737227, 0.009053649114174469, 0.027000927854509606, 0.03578498200964063, 0.0168451224078214, 0.006052665337319336, 0.03894555051961253, 0.06091433982815474, 0.06044927466240141, 0.03615099966766373, 0.021750207186766693, 0.07418531158398237, 0.049739338667883035, 0.04960286010417247, 0.030305783279360305, 0.028957340212899352, 0.005644677552364526, 0.02039665814429041, 0.03767808486196784, 0.03427475458011031, 0.0889920674624943, 0.05385025456968335, 0.030044062746568557, 0.0925916005226393, 0.053736214721274954, 0.06596504259974727, 0.06073246289405131, 0.023892462899487828, 0.08875342341320169, 0.031776649111341086, 0.02272806479595602, 0.03609139036627547, 0.02968101750969166, 0.02885547350160778, 0.07396156028393777, 0.02421184687034017, 0.04585446849946053, 0.012813595240004362, 0.05350596699563246, 0.043913186377575325, 0.014699027636989713, 0.0506202363589358, 0.04005689511916811, 0.057976446264693816, 0.020935240937697313, 0.019761398885278933, 0.05411635904062179, 0.007859849992523631, 0.01932802677695309, 0.058187924836191444, 0.03794063851537724, 0.0490965525950155, 0.020881587969920328, 0.022790820803493265, 0.013461800427326273, 0.06069626523962906, 0.09607609015919509, 0.04196789761584613, 0.11797467517035624, 0.09780669044102393, 0.025968158978127667, 0.023841041162790313, 0.01266571154232107, 0.040310018230229616, 0.03837118375926249, 0.0928726781820578, 0.015360603931420034, 0.021178073572715925, 0.04746993342714925, 0.01977581091435446, 0.04848044553411104, 0.023203847531770027, 0.02283888324464281, 0.013144667797361412, 0.017027786497267026, 0.027075816779547644, 0.07085342666194325, 0.039554448693149516, 0.01566437694559535, 0.027136105983968706, 0.04931171221898929, 0.03116119322517226, 0.039538471929488644, 0.047862055531192216, 0.0298647579526709, 0.0464384688154584, 0.06440186317289068, 0.041213289519111, 0.026984562301227165, 0.031684486818830335, 0.06770845953254931, 0.008623439033756094, 0.024633584018316, 0.024847466190676057, 0.046518122807385466, 0.006869274844986297, 0.03406586155535714, 0.04760160478913496, 0.0324693113385189, 0.05675832049981241, 0.03551393627159057, 0.020878784088117462, 0.031186205995900017, 0.04335440567604477, 0.11240782065977974, 0.011058758809081009, 0.08639638537480947, 0.004028510696615183, 0.03063758936590485, 0.04795448786969628, 0.0580545297763761, 0.044946455126327854, 0.04231439535355857, 0.036830247695287394, 0.035128310593145515, 0.05512401747006563, 0.05388132709589216, 0.023467006394639615, 0.008782667535988074, 0.03010263399881942, 0.06292365438815567, 0.017410343993575345, 0.021939758406651598, 0.007015947166139321, 0.033354951113822966, 0.022192613386939612, 0.036272551008169694, 0.012350674162829115, 0.021054584029761535, 0.026890027051370953, 0.038696924344666546, 0.036770741815768906, 0.008205614679853522, 0.040574536899164806, 0.12588046506167422, 0.007743281575160162, 0.029946330994848284, 0.06110852013432211, 0.026886129579056176, 0.06643637819516082, 0.057678909206222144, 0.07162267852935099, 0.017748102583291552, 0.013744120106792018, 0.05911614377832702, 0.02733255391039195, 0.033291254733358665, 0.057616905880070506, 0.014062833750710614, 0.03946707636538533, 0.048335363803010796, 0.01739501074377087, 0.036486094186623255, 0.04283377232270376, 0.043073573164762034, 0.042333800360680594, 0.029918282600720564, 0.05220292421478418, 0.012817772334411502, 0.0958815114873071, 0.06158305031637992, 0.018319991049206546, 0.02425221778872994, 0.037190450745965206, 0.002576700344140972, 0.02826888763886546, 0.02057635747346907, 0.04585770522094062, 0.04886435134516609, 0.03737877430995146, 0.026791998440580025, 0.04185769203749876, 0.05257884738966823, 0.0575089296175828, 0.06804415160008977, 0.08525391845333, 0.035782637780592326, 0.025884471533279267, 0.017761817472355983, 0.0821125366154217, 0.03473384042961463, 0.01981539276218222, 0.006665773642805195, 0.04160354236861871, 0.08438653072282191, 0.007226767380827017, 0.016573613186577157, 0.06849608984926055, 0.041982526064760266, 0.06588759877148175, 0.034249630726633534, 0.010236056987196207, 0.03149996879660795, 0.02776743329670881, 0.05254304044008736, 0.040552140318698464, 0.011312259218445229, 0.02810952985929626, 0.04116858062784999, 0.070179192679784, 0.03319275114805468, 0.0687872339040041, 0.08485222791111277, 0.05139464782851358, 0.060080043265535954, 0.04693708480185559, 0.03613215007428681, 0.05156238277953479, 0.04745440865536371, 0.020359251986167604, 0.09691218319799631, 0.040195675777091135, 0.08896733814429852, 0.004776778936971941, 0.02488753641955555, 0.02387960219845897, 0.025405262469223915, 0.03349853131259161, 0.02322125496462949, 0.03266252254346206, 0.06494351031799471, 0.05675348265457058, 0.03608665594290342, 0.032025367216837984, 0.04598091514180264, 0.066765183132262, 0.02713269880792547, 0.017707162844618003, 0.072999338529283, 0.013952030623782308, 0.04050556217290221, 0.046884469883216005, 0.047415384136500864, 0.043320261137259584, 0.031929129336570064, 0.07658437720590061, 0.013172803333990518, 0.05512448861413906, 0.09082920759195283, 0.06375631535305612, 0.026166326771940918, 0.03287189437316791, 0.05462933534515962, 0.02289670373072788, 0.04019439641025759, 0.017040574419943076, 0.05654018079381316, 0.05741016939282418, 0.03407658295585744, 0.03015546916773723, 0.01881624173913752, 0.043616089819660114, 0.022407682995582302, 0.03983914228757063, 0.011043924474037223, 0.02108917098432299, 0.05033604838254471, 0.03327776775545171, 0.04562078486947764, 0.04158579594185276, 0.04922068182138666, 0.08545222797340925, 0.03726202634073073, 0.007546724481207709, 0.04184424719442764, 0.05561520623403692, 0.015937458562304177, 0.01234328141435981, 0.020909898749162114, 0.030382430376184565, 0.04346863321599461, 0.052607954900351264, 0.011315265155938125, 0.062178446190251466, 0.0749330133980801, 0.08433160987953026, 0.023338717310839606, 0.07251457341255681, 0.02043285196827304, 0.06536558645987703, 0.017160570601962747, 0.026736604537995114, 0.10548194915416742, 0.0414403886233847, 0.016618004151349588, 0.03374159951964694, 0.047010928016876986, 0.017154357628896832, 0.01592645945493132, 0.03728657945870392, 0.07099700686071189, 0.07585332248239748, 0.03117730596943969, 0.024155056772513256, 0.039097799003244414, 0.041277445552329865, 0.06982476976249488, 0.01688164948005109, 0.19527519902875348, 0.14459206302079464, 0.22751614721792363, 0.12838335857997019, 0.14685724711706563, 0.27430093757087187, 0.16454537459198507, 0.13941399813179048, 0.1447125226860085, 0.2271059224562299, 0.10972421466102524, 0.15912813705302056, 0.3194546501242346, 0.17274956339068953, 0.22352648388233878, 0.1405591923262804, 0.13381386476178325, 0.17527814383708662, 0.19974440276142091, 0.22297460946344563, 0.17669745961264258, 0.09079452679162064, 0.13763662818218433, 0.1349976544658984, 0.13896890104778353, 0.15899715133972708, 0.08995731526444997, 0.08815190649681515, 0.1547866095338137, 0.0972134625959781, 0.10780920935494286, 0.1350395135100811, 0.18723584170783722, 0.07115294405769917, 0.1399910768433925, 0.179387025775448, 0.11020694198387285, 0.18629988144722678, 0.1332571486672086, 0.08481284333092552, 0.088473602137979, 0.21532365872013956, 0.16597923071634385, 0.06766454737272955, 0.1109875932395939, 0.09769868736545886, 0.15944989398121834, 0.2611311507080832, 0.14588857490208842, 0.11672425879946641, 0.2150906607388489, 0.1403944681008016, 0.09594705797010854, 0.20003809022807306, 0.09947175956180981, 0.09185492271377195, 0.07261763522101027, 0.15154622615345065, 0.11187464644711827, 0.07431601384474386, 0.13030974795260739, 0.11624030573593995, 0.16508528271750098, 0.12692929305616887, 0.10010260998481706, 0.26479256068987234, 0.17980345584932836, 0.27401595286303954, 0.15724166086123836, 0.16047225363792914, 0.07629373110830784, 0.09874255111020419, 0.2536404655585366, 0.13490984546801738, 0.2145868200328081, 0.18337154100018163, 0.09193264999456945, 0.2456416189670563, 0.115335785723742, 0.1897184568787775, 0.23320690878937322, 0.20683221759334688, 0.26715149862631676, 0.1776724903573913, 0.15430210488698176, 0.15706380588873742, 0.16097767248509393, 0.1889260768169357, 0.2829520007775676, 0.09265263474756673, 0.15834069059741113, 0.09826217567728412, 0.11203106627949785, 0.16749196325338658, 0.19026571944836648, 0.12727788604435422, 0.14737368230858158, 0.1062855524040999, 0.16829322993515, 0.14221856941378888, 0.08866148520140879, 0.09882429269172492, 0.08726411784488348, 0.1865205760564535, 0.12644517145329906, 0.0906554205463298, 0.10761387991688906, 0.07353332479514423, 0.15698148208039422, 0.13241592283931472, 0.2065259049977026, 0.120085186114715, 0.11991737455490137, 0.19344087810285632, 0.10475867788397497, 0.1351318271049569, 0.13998920758885725, 0.18746980495991247, 0.14411698125543135, 0.19111990748393923, 0.2020405674533498, 0.15051088896730255, 0.19053386554362314, 0.127173506564671, 0.1144332652010264, 0.18366035614763537, 0.11567616624937904, 0.09450676670718579, 0.08226680374073406, 0.07672070255202633, 0.1235146782991867, 0.16184499126768884, 0.13533894663616536, 0.18470347678709417, 0.12177219599365227, 0.11495836484696596, 0.10897557055878063, 0.13338667881344596, 0.11261872466533415, 0.16776485909377375, 0.09988540873652506, 0.13214575427193798, 0.1374696976234836, 0.25359699772971295, 0.12304924924166934, 0.12012141441265423, 0.07664041653756173, 0.09166877100905103, 0.1952537792103906, 0.10380139739643182, 0.17955312895919048, 0.10163247990872591, 0.09083656969690516, 0.12684209692862727, 0.19378877395103056, 0.13020980412200575, 0.10298253367504767, 0.28234360439162104, 0.15963632913847126, 0.20465521021716057, 0.3972188870031988, 0.15232055718379636, 0.13056350691664603, 0.1411157245597532, 0.13231686767070525, 0.1439032427245571, 0.18333371157848066, 0.0727880438188872, 0.12228323026530205, 0.1945879109083645, 0.19646923898929552, 0.10728943402007704, 0.16895209619354817, 0.24472577617533747, 0.16974089096390432, 0.15275281463419238], [0.02060189884486458, 0.07698419083270334, 0.023978272407886483, 0.03388742818647335, 0.02204566623174375, 0.044807015632789944, 0.04179781077489738, 0.04088724249853723, 0.036148858451915365, 0.0026181753867516116, 0.09193982823841995, 0.057604357359870795, 0.06192356490740373, 0.02765759927100472, 0.017858794627470836, 0.005494028277274582, 0.006169459271815516, 0.05317537707366771, 0.007202374183708021, 0.04161829339160074, 0.010691323888397986, 0.06344234953904826, 0.05085922897823396, 0.040651513413796504, 0.03924397624007637, 0.03819982138191981, 0.015560222504239891, 0.04680090884287511, 0.05544796157928725, 0.02194661872401353, 0.03999144822779683, 0.029924803924176003, 0.06036983900553277, 0.005445323279878546, 0.09279868174945155, 0.06496735863507756, 0.036239371740169106, 0.03895173284916147, 0.05719869082132655, 0.03847782319832233, 0.02473819715481612, 0.09043562992085373, 0.03921125662483035, 0.026510194912853263, 0.056508725223642205, 0.02794330027104626, 0.04777245005712875, 0.042360387442092744, 0.03625302342697978, 0.03822329048548014, 0.018028575033249877, 0.01723339683526466, 0.04423650612513866, 0.04053284256388584, 0.007830383378126088, 0.015582933180755185, 0.025993753975677877, 0.030493804238616463, 0.039066381737469666, 0.04988662290176557, 0.04417574003098473, 0.03343547461554408, 0.053930739767008254, 0.0139268837876678, 0.010818173684510253, 0.026222343120964307, 0.008371623060215385, 0.002007706254164899, 0.04726615020885103, 0.022825018968433145, 0.050819537962876984, 0.020734836167145162, 0.047157852189435114, 0.01956909549452605, 0.03393069300199709, 0.04827751650384838, 0.12523174946827273, 0.06487005014693545, 0.04530495746181377, 0.06836783906985676, 0.05068408978742458, 0.021097086587800615, 0.039704728330815994, 0.05520032748820321, 0.031392138090825854, 0.08904408483255295, 0.03465959501843299, 0.04023927767130156, 0.048064888800464334, 0.056812919586175875, 0.02269152240196784, 0.12167661886421904, 0.06368153368032749, 0.10364061852376308, 0.03971186827027029, 0.044754523288218245, 0.05461434683492107, 0.08670507284301905, 0.02448599909492318, 0.056383726487476984, 0.030469310492457404, 0.0440062660603754, 0.05062361480668188, 0.051766054915084, 0.025545581048654935, 0.04162144967384877, 0.039130583735963995, 0.022334328161612637, 0.04329657369864084, 0.03999843111922664, 0.04884124996380941, 0.0305995837439813, 0.028964198615041473, 0.027796559959589958, 0.04053647382064693, 0.06427676867573492, 0.03227461392300264, 0.056844769691627835, 0.09102930209689564, 0.015833935185876346, 0.020567907523664258, 0.05465306874905383, 0.060062944183066014, 0.020910086440703562, 0.06928494590665064, 0.03207547702796517, 0.014635970939942186, 0.03498766068068724, 0.024535427087797754, 0.037559341233704364, 0.020249935069812403, 0.01985244651985986, 0.0486112856906989, 0.005374958582838337, 0.04510198629671528, 0.03341156884186691, 0.006162462973847024, 0.025764370014170007, 0.02112045226949117, 0.02003215350991776, 0.05439255671996263, 0.0103690144192848, 0.014171494704280651, 0.01975276507437229, 0.03172972814119872, 0.02402294874041071, 0.030016636798879313, 0.031895927085931745, 0.02027038387173126, 0.040759842076729384, 0.07127367951456579, 0.03696581844480769, 0.036996714770793915, 0.03274987571902814, 0.029460447389752637, 0.024685482644746383, 0.07699170615524054, 0.04005776845940179, 0.013056103245265061, 0.02965799273712741, 0.0400230493546734, 0.034652665753157876, 0.056333325562938574, 0.0437525722138103, 0.054253507931266105, 0.051830291387534914, 0.012015712751646437, 0.044588646100413416, 0.07045585767275865, 0.0166925483368217, 0.019974342599931746, 0.04908829033675213, 0.04861169171729877, 0.034287655500755194, 0.08520928617086142, 0.017574348096405307, 0.02390871928524106, 0.021219421253209154, 0.033977439687136686, 0.07059684849434322, 0.05727131212610872, 0.040313561386879415, 0.041022713656627366, 0.048667213939610994, 0.0556273908624726, 0.027671896386891607, 0.03698631895766143, 0.04504634916121441, 0.048216210317707835, 0.02933976364382092, 0.03232305749289451, 0.04867242716793572, 0.01854186543383666, 0.026215178283652472, 0.07665190785642594, 0.0239431070569422, 0.04936854062121242, 0.03963486111212162, 0.022065345115298708, 0.03995351155378646, 0.059393574859225945, 0.03583008926662226, 0.021388860749861887, 0.013312489890884007, 0.03671207097208789, 0.025803377296054558, 0.07038048228188869, 0.009986295086902477, 0.06937185092078102, 0.01687702613942806, 0.05018994392406556, 0.05613480536868015, 0.027769536208060962, 0.03545647967726954, 0.1745592928942173, 0.06823876091549474, 0.03158823361680393, 0.016471888201551575, 0.04184880924801673, 0.04100675221472498, 0.02585205452276334, 0.04218645867020373, 0.027348310423774586, 0.04670607864916806, 0.02156111561963635, 0.10668024090268921, 0.015085886716992866, 0.05081286150661688, 0.0726924896720917, 0.05878616289626207, 0.022586696676068732, 0.020302490616637855, 0.0358454876339003, 0.08037879537310332, 0.05158489427318977, 0.03762245538734621, 0.008423834825084816, 0.027409578305518916, 0.014833985516170581, 0.03452258785405467, 0.00809365763298927, 0.013341012301914876, 0.035717780776922746, 0.07386201481905676, 0.03452609270630825, 0.06731237675393782, 0.042789297088259654, 0.017519716451305057, 0.08058147925523021, 0.01191749644931406, 0.08590372189158395, 0.07694364179887118, 0.09013343121736281, 0.034739528632452416, 0.044000317387643366, 0.026953510842436267, 0.06501915383963816, 0.049587810306899974, 0.05709164535566684, 0.04535201824300232, 0.028109330676435947, 0.04975988897645185, 0.010385906658015184, 0.04825020163890816, 0.013778504048053537, 0.022703649573809197, 0.030576248705807715, 0.09380597245669174, 0.03178881267235885, 0.03549257007938239, 0.008846689503820193, 0.02649836268486275, 0.02305507900253419, 0.04597279077936565, 0.05265726031915796, 0.041854861342618545, 0.009134490542384166, 0.01712154991353952, 0.07022143476792882, 0.08748446005366503, 0.07176747680791924, 0.038334679669670524, 0.07878562360401116, 0.023937432260643092, 0.012409739541791141, 0.018361336814479965, 0.027742981685385592, 0.06532380402448677, 0.03299527283337328, 0.013375956444971025, 0.1059220053796326, 0.0782227251798876, 0.07055963960386093, 0.10675042221743254, 0.019919364300045758, 0.09674960401870551, 0.03464944052299665, 0.0732520632746239, 0.027437350907993895, 0.03875880126631068, 0.036232250952912916, 0.03988884990253756, 0.04146393433573746, 0.01959523632972231, 0.06084612352893718, 0.03518790457277529, 0.023558287686037443, 0.017879308546863256, 0.035315002389853044, 0.07710104222379385, 0.04455109247036519, 0.029624685149399504, 0.0027307041267293597, 0.043638946052881024, 0.04760953762959089, 0.04935355211097387, 0.03362794654564031, 0.0851149271212278, 0.012475404768220842, 0.028098078760048075, 0.030227395247728116, 0.040946127846837044, 0.025539318279873942, 0.03192783273275822, 0.07729755143725103, 0.0831586143542682, 0.09593319177867905, 0.0481129914612299, 0.02399055854297213, 0.05468576538166212, 0.011712736468912374, 0.018052555500499664, 0.03450415194815686, 0.03402051681111898, 0.062346537372157465, 0.04361743813440685, 0.02407883102404735, 0.03892801093658613, 0.059654883619758396, 0.036961195104184656, 0.05204175080683443, 0.02406768635996888, 0.011022174280256996, 0.04986082489091543, 0.05349585846547158, 0.056417124090535994, 0.09000999913100274, 0.04063686581268426, 0.04801970876512989, 0.03654860696124454, 0.0904646186879085, 0.05793633773141812, 0.12428239032986665, 0.16819628916921156, 0.13555974849770147, 0.15043595024654943, 0.13114294517905484, 0.08293610411666094, 0.15736783554236736, 0.1491139429591356, 0.14165800755783436, 0.07361145044166235, 0.1462773338801438, 0.10814425024774768, 0.16908562531875027, 0.09542656251259389, 0.13033386440046374, 0.17292020181494375, 0.11771702447966223, 0.14487010697203298, 0.1936740599452488, 0.1643535921410207, 0.14976209930835233, 0.19067281857132914, 0.20478276385655328, 0.1453980947694471, 0.1648156657334297, 0.13253855819423355, 0.1113294676366833, 0.15681187021395854, 0.1606236938988009, 0.17074247431610862, 0.14017709831316627, 0.11740625325229861, 0.25657447505622144, 0.09949831983014461, 0.23392085676952717, 0.11293731765040468, 0.1308510197146285, 0.1585773198354629, 0.28698720037937164, 0.10205251059585041, 0.12455289597593008, 0.10894765431481986, 0.10112439507558461, 0.15583605805952705, 0.21579104896274307, 0.15487619585567905, 0.10717645137300415, 0.20731411754123627, 0.1106713138400547, 0.24054371751844886, 0.099778194731522, 0.19271019876243609, 0.306035608894402, 0.15449522033093438, 0.12331401688917992, 0.07540401191480699, 0.08959146231533059, 0.14154450397097296, 0.19416705284628177, 0.13263094839790177, 0.11773885798550422, 0.09745016844282228, 0.09486842915535935, 0.13850937086728313, 0.11686452949840216, 0.10793556023629443, 0.1318680627211448, 0.20045024553133597, 0.13899851800693622, 0.21250802512851455, 0.14872012780077998, 0.12259121293262129, 0.11427407979124016, 0.06042794294414982, 0.15130069497371876, 0.16873065081815566, 0.2865393760223543, 0.11575557892360996, 0.22157734169835047, 0.143918763665903, 0.21296547154986092, 0.15653021032771758, 0.08958030041427383, 0.17532826130909307, 0.14289819665493506, 0.16224490448592171, 0.1848171642350574, 0.15703855563075314, 0.20540928588278834, 0.15684665060572087, 0.09271389879887143, 0.1963706434734406, 0.16969198391081827, 0.22547930328836366, 0.2142309109049459, 0.13244690343497262, 0.20194509757622597, 0.21692478248188574, 0.08387290707398808, 0.19482547477368387, 0.06164974593106778, 0.124489379626128, 0.18030738848592007, 0.2939363226534859, 0.13754483552709704, 0.09122480007429278, 0.19400117948891657, 0.1195737534773446, 0.09986695367842914, 0.13129279197704408, 0.16818470591979642, 0.19790588367369868, 0.10078769943286335, 0.14199186867523578, 0.1809613977468783, 0.23797332399314453, 0.2015398217425231, 0.2411038043998903, 0.14895942302480822, 0.14566668519569984, 0.17094787781036672, 0.15014408606915705, 0.2162773768988348, 0.11572266778638286, 0.19436065858650595, 0.2929426453286602, 0.10831019255302607, 0.11009261868293248, 0.14411880454469111, 0.11810983606283704, 0.11844304600550283, 0.07473597558395517, 0.13273817006378405, 0.1266077889369861, 0.16538816323924452, 0.11989330407232048, 0.07867947446122285, 0.11665364081460623, 0.21332041540693855, 0.09578963456254813, 0.18907030052956075, 0.1587613035113581, 0.12528366724690124, 0.12346604703775338, 0.11727218786554953, 0.10048146344601147, 0.11315072676347149, 0.11927300268003058, 0.1437230741665248, 0.13155344573240127, 0.2301343905949785, 0.15244343768685095, 0.1869134565875415, 0.14995830974751903, 0.12215782933297659, 0.17013141194418555, 0.1518947348719643, 0.12788987538266566, 0.13157604532616754, 0.1568350060692718, 0.0926915749967579, 0.16598797944043914, 0.16908629947612364, 0.11718855404685583, 0.21434550233665975, 0.136242731203956, 0.08922194746593315, 0.19426897318372804, 0.11603628119994557, 0.1381856067887237, 0.11440224630097229, 0.09764235692038652, 0.19208462668522713, 0.1358682980700847, 0.35594703389271615, 0.10504099660583081], [0.012735916797312037, 0.022944197351593646, 0.007293390217162068, 0.02196502398639437, 0.019532507135262413, 0.01664600083454242, 0.038644926126806006, 0.037889716651050315, 0.03404445705875274, 0.01980118183118682, 0.020665884423520298, 0.06788102083749349, 0.012715523536767692, 0.023174123320307945, 0.032934568026253296, 0.0650665363777549, 0.042706567253316605, 0.0025403454022917657, 0.03896402472990655, 0.018685003216829033, 0.019623190878079306, 0.0275329586809441, 0.024304346241537603, 0.020632450431284886, 0.03492617829432411, 0.03600294168497767, 0.032634717382250295, 0.01683723170220131, 0.035038153535776564, 0.031604154839090286, 0.015412019922458118, 0.04567950550887374, 0.05162870684157937, 0.02555791889467547, 0.04918151557625783, 0.03290800392747887, 0.014877381524251354, 0.07598898133202907, 0.021832341388348612, 0.03838518018563909, 0.026328038356657472, 0.011744484110104461, 0.1027475668477916, 0.0034544570747041896, 0.08716137779335822, 0.015066008650577598, 0.03285580652675802, 0.0035317297301991216, 0.01747624287682195, 0.07287363116178783, 0.07408064099088793, 0.05509902002109636, 0.035100953593369455, 0.06001798631322961, 0.04187409397995761, 0.032171383575205846, 0.05598870474064062, 0.009717281397071578, 0.08587323925307683, 0.03381362710628779, 0.043685359489773555, 0.07341423642731483, 0.015068424700368798, 0.030982575995186647, 0.015055279589198051, 0.024544612482009877, 0.03923548798587534, 0.022942636447447925, 0.07445604705642309, 0.019207367928878918, 0.047254566959435904, 0.058291235623220285, 0.08045905840493019, 0.0613106141287473, 0.06544156706020718, 0.034347057958403905, 0.0032299691332399005, 0.032466649182982026, 0.04133472977686794, 0.01453101306387614, 0.07551383827963183, 0.10112117750630265, 0.07020598277449608, 0.038001917888440435, 0.007636375920546632, 0.02554491072172119, 0.04001904271482941, 0.08460686527072422, 0.05704065454342673, 0.04877605205101352, 0.012943378195256717, 0.11197221540515462, 0.04723671328036055, 0.03225691729195176, 0.058021618639149015, 0.027133267628209248, 0.021869063812998996, 0.07460718854300438, 0.03190398824611499, 0.028952069527980302, 0.05020436169880052, 0.03146768393625896, 0.04663740652763555, 0.046153342381360075, 0.04791192402462325, 0.042238537327296315, 0.04772738110454333, 0.03027772147869391, 0.059166065897912755, 0.04102380533191947, 0.04398300763099425, 0.04839711432014743, 0.020361952446100694, 0.031689366798908, 0.044021809984359055, 0.02188226733837397, 0.026693582955387332, 0.03986374520125889, 0.11370582641252588, 0.01657438502016087, 0.04648976606286822, 0.008307021738390529, 0.07050156247832122, 0.039143388895618345, 0.05386918460229232, 0.04374571572688799, 0.053270494550346374, 0.0415788053895437, 0.04160554568854071, 0.022025261479880542, 0.02706116343277597, 0.034730979091217445, 0.07208796969104199, 0.02551428827216789, 0.0448191236524332, 0.020799275652896014, 0.014631538163690318, 0.027915477872856205, 0.04502443904657999, 0.056705157828306964, 0.05243895590425499, 0.02913875174858878, 0.059316441296569766, 0.0060353148822492415, 0.03413358372786353, 0.027586129013328787, 0.01998795981278583, 0.035861035388323574, 0.01213952117869931, 0.12182609794000465, 0.03237543875471719, 0.012250342500215818, 0.014346510363412241, 0.028635770976243, 0.07239021435980836, 0.03066372445544168, 0.05274688494541953, 0.01857823354282206, 0.0647261098868424, 0.034962720688312285, 0.0772523905541147, 0.07791144833449395, 0.05476110246813586, 0.05527066585097102, 0.029725395067925417, 0.02764909761026502, 0.03813381141592418, 0.020025930960752794, 0.017783555217207443, 0.04939844103289708, 0.05767268857227699, 0.013142023836412739, 0.02615332817508569, 0.03778555933686514, 0.06179460549666997, 0.04319790157399351, 0.04197701406214507, 0.038587810441611275, 0.06903506334750883, 0.05439079088729717, 0.02930627219499119, 0.01882694781787934, 0.027757906993370385, 0.018080850957982966, 0.02490491703933766, 0.021175874900373242, 0.06423225513689461, 0.004914515321293185, 0.021216069618540428, 0.03524871280176505, 0.03979128477494082, 0.025143153146810593, 0.09079647265494832, 0.03414718944939875, 0.05740261193545115, 0.06317961202453702, 0.046493925920297066, 0.04361497899216991, 0.06485362522183888, 0.011293641366665403, 0.051570369246145414, 0.01608592927485945, 0.039245987220877604, 0.06631727450557294, 0.02306887433083067, 0.026585807790979746, 0.023722787830798377, 0.04281918983906508, 0.051963778377901164, 0.11214525168461185, 0.03384486434140033, 0.10621900234611766, 0.0025539238319446846, 0.03404374842742278, 0.02488238064782514, 0.006765912347022565, 0.034951240860766945, 0.02477613191360668, 0.02571138928854658, 0.030019555593870824, 0.0737705132773807, 0.038105056305686315, 0.024254665439648014, 0.039446464769782565, 0.0878802900232615, 0.08840499130348045, 0.020883518511489518, 0.0944550634331761, 0.008182134084974327, 0.028163818680050395, 0.03373109645420506, 0.11055397981357191, 0.022056958367747646, 0.019862629743593357, 0.010217154725274492, 0.03739549034845926, 0.020508549116071195, 0.05644159676927713, 0.03877000530220328, 0.03344777798760803, 0.026479469041430184, 0.05566414393063995, 0.09626185115907462, 0.07113356969409412, 0.05502727588698749, 0.07005697867322354, 0.04294761298825184, 0.020079444117483594, 0.04057416917696115, 0.04404347878129732, 0.028206650655896916, 0.03311854404126925, 0.0028501329248801117, 0.01698175418911682, 0.05663213432736455, 0.011304361809555803, 0.03392544913015539, 0.02208179685347263, 0.022337189500009822, 0.017492462873398777, 0.014696510080548545, 0.03681564988989023, 0.03125769349055425, 0.05961724955047812, 0.0234465652536, 0.0198251067570621, 0.0657917688330335, 0.040843847448066364, 0.031170265621415554, 0.04400454236254577, 0.06508665384664651, 0.027832223267685023, 0.04447051917292899, 0.03266596993912132, 0.0874111837437076, 0.027664076544404514, 0.04067795493850305, 0.010055610722291374, 0.06471262673937506, 0.043495802524229216, 0.062303655600595864, 0.11636579093793709, 0.11978320191584288, 0.011340524990021462, 0.07152736953069126, 0.06365524154276618, 0.004757995418678489, 0.04557998685707008, 0.05198866857456104, 0.030316813030250134, 0.0418045791617084, 0.0260188146269009, 0.034940676508291114, 0.0430984633614219, 0.023221789310956677, 0.08018021006137133, 0.06975500213523066, 0.029368392349551284, 0.0159649352633184, 0.08059018967492927, 0.07161114124521133, 0.038623310956022436, 0.05814035077609363, 0.025309254415333274, 0.05181455211113057, 0.03398893483644051, 0.019620919427383813, 0.0068164300999694295, 0.15723974564142768, 0.08873134475922392, 0.014779517622364145, 0.05689025233169237, 0.016761283660607956, 0.056390096508567376, 0.029813115965695153, 0.04426606562769702, 0.012904355591613681, 0.051200727992240465, 0.017977354394632484, 0.04749765048824972, 0.04511740381619142, 0.054993192635236256, 0.0283424703839926, 0.03157557018341557, 0.0663518097491995, 0.030526451075509674, 0.03550482748617088, 0.02422804388427927, 0.05969152943561635, 0.003908978715997129, 0.04501532643072067, 0.019143453213356195, 0.05237646228183181, 0.029753613916616288, 0.03851022871751939, 0.030045665785550114, 0.02730761774845662, 0.11888648833959334, 0.025135182001958453, 0.08456581061886204, 0.05873707581251379, 0.04381297058576057, 0.011316241918041581, 0.06751018065598703, 0.04712168517852983, 0.052336786588233326, 0.058014616595521096, 0.01211883393191402, 0.04861284467962481, 0.03359503923885284, 0.016439800608843085, 0.018372898996477167, 0.1688577601265523, 0.1554695156312758, 0.19616637378931048, 0.11762153161990067, 0.27903192886902445, 0.10855301944238525, 0.16501373010537318, 0.11687750702783947, 0.14181016794135495, 0.09534241541499093, 0.127767370262694, 0.09605771937077084, 0.1159251448247702, 0.12981108600093474, 0.10999569323875251, 0.14442422847834327, 0.18432357378544348, 0.15273081258900706, 0.10143749521023805, 0.14108520361684984, 0.08657656925460024, 0.1320153967507424, 0.1442901477698357, 0.14212553569626424, 0.12120147581182181, 0.17125126395014026, 0.16590374041228526, 0.07701549318528945, 0.17357499248558478, 0.18351171976856648, 0.08196278940886259, 0.18106186251726844, 0.11288029006532124, 0.2943732992054955, 0.10194276850069724, 0.18211258274893607, 0.07034888881589137, 0.2796634611102843, 0.07714973477226111, 0.20507134917762973, 0.14359800265200678, 0.10029898130244787, 0.15469000584656192, 0.0963414017291319, 0.22816497772451372, 0.09310491773630343, 0.10358514609716593, 0.0760419792946308, 0.21267114056935235, 0.19679743105605726, 0.15841656394543188, 0.2981035651699189, 0.13992654159665108, 0.15410842253796517, 0.17661538095243517, 0.28522360469064406, 0.11692180989250062, 0.12245982119272794, 0.1625065235120635, 0.16682902140723121, 0.12299668028830521, 0.32596348634650635, 0.09505073509870038, 0.13700371698266076, 0.13480947262817813, 0.15778656388002057, 0.20326803949090744, 0.12346935653758627, 0.2766660961412615, 0.11618423576076185, 0.10423036832963267, 0.10562330769795565, 0.22841303699439575, 0.1963457456159015, 0.11934066356550302, 0.10562333834147263, 0.17489986494183543, 0.09466183822481863, 0.15713148209596836, 0.1500471299814601, 0.2766755037009716, 0.16430771879611478, 0.22843723005104452, 0.09113369689833734, 0.09683142220901866, 0.10983543530587228, 0.10370494692676491, 0.0944241900898276, 0.14377976467292156, 0.15292022016740617, 0.14554738998413086, 0.19656693052139976, 0.12351717574581986, 0.13731386001792648, 0.18881767537565003, 0.15851090001242776, 0.11538578828255977, 0.14229055103515426, 0.15055218110642127, 0.11806847497580514, 0.15967529237030015, 0.08183418622901363, 0.17429899153930528, 0.16279198319440888, 0.09486963957427971, 0.17963091752702193, 0.29261197113702375, 0.12196849070249066, 0.17644592230358433, 0.2595975959012585, 0.12626706367178311, 0.11644262189586317, 0.2307197890214382, 0.09793586052593686, 0.2502845101539166, 0.08602495530560132, 0.13865190918647474, 0.12248597543446288, 0.21259264720063056, 0.15942464372323406, 0.15628901520563712, 0.09265045139698252, 0.15038856004755344, 0.22848098899327943, 0.13742921753756462, 0.1744390783771392, 0.17755370076385238, 0.11434165640704094, 0.0953910543373035, 0.12073217801028684, 0.14899624121044913, 0.10776453110719882, 0.17223614658559525, 0.13322324161567997, 0.1641858035638448, 0.13586929398438624, 0.1804036091292097, 0.176821565856376, 0.27095742343414214, 0.15760259552588388, 0.13393990154708588, 0.1106202694016599, 0.16440891901091223, 0.12008766823958968, 0.10973998841138617, 0.17625662197749462, 0.1427922926602825, 0.08603803242646879, 0.11646247123398128, 0.23133259807382864, 0.11225939878532964, 0.0896981860240621, 0.2216591598886636, 0.13194663269865897, 0.1772046404620332, 0.2107214008367831, 0.1472728498159878, 0.1448820119783763, 0.18143240392448443, 0.09989205837970781, 0.10791150507547202, 0.2605313957939225, 0.13848899292849726, 0.2550720080973641, 0.1365641816969841, 0.22626929315588168, 0.14321033151880389, 0.17879902265004574, 0.11159429657122782, 0.16371461352513683, 0.09735163421400132, 0.08527100221404145, 0.15706521549051808, 0.1610848328639423, 0.13974088784908095, 0.12848707156315928], [0.03898828290402889, 0.035073202058312394, 0.025586723800628416, 0.05625988837451704, 0.02243310945378917, 0.027046464120728836, 0.028962787098040985, 0.0627901635673498, 0.04329626726347112, 0.010218512616120279, 0.13433808340660988, 0.02751782269878013, 0.0338054491176961, 0.05147183118688484, 0.030161766410474817, 0.037149905542572664, 0.030132388853798472, 0.04355471085516676, 0.03776225494220853, 0.06360247340654174, 0.042920355579905936, 0.0724708144703219, 0.03940410393800947, 0.08281480941560962, 0.026922124220178496, 0.05198447041273598, 0.029973021498130217, 0.03875538834460801, 0.011037360058136044, 0.021043362756890636, 0.01172115481759031, 0.07002353127444945, 0.02104828487180414, 0.11815328090902298, 0.035635705947154955, 0.05282979481102479, 0.03032948220929792, 0.051969803659425634, 0.015453158843991979, 0.03752402074995541, 0.06074446366138517, 0.041753086561877886, 0.04720759427835865, 0.03971530800505031, 0.019933485215710058, 0.05138079695884259, 0.031140476292479905, 0.01938202639951581, 0.030756070609054262, 0.013538381449067065, 0.01824885595499748, 0.028550373240103646, 0.04263407618348156, 0.04955655775002895, 0.05254491352506223, 0.03940134602148206, 0.033513508331511295, 0.060179745778441436, 0.026163854223165302, 0.019892804031710953, 0.058153186579264944, 0.11260239933166774, 0.030029258097431837, 0.049156460670694235, 0.027276167923945095, 0.042123110859744975, 0.02842380593891346, 0.019761651694293947, 0.04811975984804092, 0.01632918900389585, 0.047688823899314295, 0.051739651694773674, 0.017140548894061677, 0.06515776978865748, 0.08252515157143916, 0.028124918650475242, 0.04213236903230991, 0.02354880543275466, 0.049303641482706995, 0.04530979147661598, 0.06223084660427225, 0.03371458342899719, 0.04488162493573562, 0.04033387420819171, 0.021406532483055227, 0.028897763470247872, 0.013401626136093853, 0.006351753723837676, 0.030271937514865593, 0.1305123475650626, 0.06232709789107885, 0.015239608004659176, 0.010674051478535179, 0.01114638777629983, 0.024341930515102805, 0.006537689487524932, 0.010990043595102767, 0.07052972387041777, 0.013336138067496641, 0.13732980996851, 0.020150328317897457, 0.011708091103261518, 0.04811656909183629, 0.03198093986288915, 0.01894420715078952, 0.008267519372184912, 0.004017996618659386, 0.04413409549142084, 0.04096437223075379, 0.035228212288911306, 0.05677609757009534, 0.0268402811320078, 0.07181919540368742, 0.02336153907010392, 0.08019367022620094, 0.05403870070773748, 0.0348813621507537, 0.08051378006536154, 0.058772342670108044, 0.023278872437414624, 0.026501940315469142, 0.04246469797386278, 0.005548686735452183, 0.09307899332094578, 0.04306527643254207, 0.010581399847362793, 0.019303431524144068, 0.03333548481966699, 0.01379072506566562, 0.003916920893149631, 0.03021989524694941, 0.0056161786027763404, 0.01597532437318155, 0.06627278777980997, 0.0690650173853482, 0.06014954276202668, 0.027394513186487942, 0.010773809532815171, 0.0033024649911244674, 0.021388144457652684, 0.06249116328094275, 0.037583461512000337, 0.09622284962284951, 0.018020950543183475, 0.11126253453473892, 0.02968992519703123, 0.01702348491357219, 0.055854715962683966, 0.030715490931705124, 0.03890385618433356, 0.03847249505680896, 0.06928735908361212, 0.008926487137233059, 0.028464128976807963, 0.02334553166292608, 0.043154150292637854, 0.03866193327872503, 0.009672065930170639, 0.0668403670011509, 0.10521646904488725, 0.022394527350702596, 0.0030879220679297203, 0.02609490056432063, 0.04275373911725418, 0.039880629779110034, 0.0635490272825043, 0.037026864161053975, 0.056802807225575375, 0.03852248229386826, 0.057350540939237804, 0.029121884407715935, 0.013633284421126931, 0.05343710718255851, 0.06786474912998176, 0.06105393636971713, 0.01590641667961233, 0.026801310239299655, 0.0031630444103821873, 0.012143568995769226, 0.0585974601187533, 0.030661587070132938, 0.042600808815369685, 0.013615030461111137, 0.025067505794727517, 0.033338495545209415, 0.03002325962898472, 0.09559443535944147, 0.0381086147840946, 0.044959145372793566, 0.042069756666258465, 0.02981951854552233, 0.022259220901516177, 0.028430348329786814, 0.015966374551006142, 0.03203933683013724, 0.07183566629405945, 0.02360361710851712, 0.046534685628308405, 0.059510859089993665, 0.022636308530045134, 0.024650535628860517, 0.05837089344558697, 0.03655158321283037, 0.006942546366894197, 0.046554921840828274, 0.02301744110281429, 0.01088430718218367, 0.08557438069293577, 0.01193245335842573, 0.021877121142742616, 0.015282759822214083, 0.03109137580219296, 0.025584138253883972, 0.03409142207895075, 0.015910134121264904, 0.04370349662138089, 0.043939179740846164, 0.019175402910238313, 0.018047991531690764, 0.036380561744613994, 0.016566886934601975, 0.026438810840068806, 0.023171694821587974, 0.022988873684117873, 0.09540695066173231, 0.031929744122129296, 0.013217930700780164, 0.02034727611669129, 0.03975574595613345, 0.03628439855791869, 0.04891042387293232, 0.05826803848087307, 0.060487314758281556, 0.058619849038340395, 0.03396377267856752, 0.0499021093691549, 0.05437495584990229, 0.013598549994640054, 0.060192478159742976, 0.022214607771245704, 0.07161778322751484, 0.06561534644495096, 0.03585228283378867, 0.0327448578431241, 0.020351435974120133, 0.09024872744996702, 0.00741962714293491, 0.039993662221898, 0.03260858995359271, 0.046664031913443926, 0.05489959584308728, 0.029684752188322526, 0.048901376374546564, 0.019483096379366134, 0.058549506845132965, 0.018928984983734066, 0.057227940058275584, 0.0891337401023315, 0.0380273788206039, 0.02187309343548071, 0.02242079267518655, 0.04389461640629076, 0.038345332122257644, 0.023498728180364258, 0.0643406757303784, 0.03049328329882795, 0.04281646256605464, 0.014709240546630276, 0.08151226842235174, 0.09323352091615239, 0.03228414022634107, 0.04182080490394466, 0.074729502140995, 0.03629097542274864, 0.0376446642762711, 0.07157887362184064, 0.029394730452388048, 0.012028703687622423, 0.07389402963341245, 0.01197689220369343, 0.018932972471379948, 0.04174324999293012, 0.04165303547896686, 0.06239889182090279, 0.040384248319652774, 0.03600327493322473, 0.035309785331088694, 0.016202437841603835, 0.09150033891801873, 0.024115898188263662, 0.047669683192526145, 0.05326982422341263, 0.05148170606022881, 0.05244551744732646, 0.031232606026253877, 0.027825213563177856, 0.019544674526719798, 0.0377038330771029, 0.01234164581664147, 0.04767288927048926, 0.037097252319536866, 0.04078725270266014, 0.06667140630945083, 0.02927526670147575, 0.01079739259195424, 0.02036220908555533, 0.06137621040726381, 0.014815438527523752, 0.02645039600470374, 0.041085184296412815, 0.021473275978238355, 0.03450723162161247, 0.030112890000905723, 0.025829288304873535, 0.036765946105362914, 0.0986242671346953, 0.044585953301359574, 0.036098480510014685, 0.0849510609142242, 0.022515360483779542, 0.02908849638075598, 0.08041991897287869, 0.03761646457977834, 0.09097094917970319, 0.02973624287293323, 0.05897029212886288, 0.046010103091717734, 0.05055473584140982, 0.02771509608494178, 0.03982452532997535, 0.007753614186038895, 0.04941961187268457, 0.04702157663902448, 0.04392554720623359, 0.050657939376129266, 0.05210394565496714, 0.024412483382489414, 0.030245183809329907, 0.11506775454167398, 0.03128905521495448, 0.04729443034457584, 0.05595841362411457, 0.02693068716795214, 0.03258124444513552, 0.08265579254516671, 0.05340044221450245, 0.03158163376933625, 0.08929895462408181, 0.024725755886925806, 0.05451400463859882, 0.03582918528287161, 0.05570496109524562, 0.1251374057403976, 0.1392125170077047, 0.07565059263499514, 0.17552053405632898, 0.08957872227314981, 0.11465730761448223, 0.10480368554952646, 0.12195732114055466, 0.1401701422348138, 0.16843947611989515, 0.2577878817194893, 0.09412428965010951, 0.12110023729262814, 0.19748422888017472, 0.1425456276704227, 0.15456415292236114, 0.10911715892894615, 0.1390434567245745, 0.09726878946586963, 0.22644204598280693, 0.23922560195769035, 0.13059041192454676, 0.14235464195089956, 0.15584040943893696, 0.09725172102691666, 0.10626073881623246, 0.08998657216227825, 0.1538375338479396, 0.16339333157145208, 0.16242390859030909, 0.1336457850711961, 0.14607157798544054, 0.10105022244275579, 0.14945092971526808, 0.08637439099050338, 0.145808105026522, 0.08747866842895748, 0.11366291016700769, 0.13713605101070098, 0.16601077821706572, 0.19100559184387808, 0.22638166293261514, 0.19021644467307677, 0.10927582339894389, 0.11833454497278699, 0.14101449370143876, 0.11911838315427305, 0.17641575376112617, 0.25164782490220766, 0.10974525909630523, 0.08231918117211712, 0.11799659294586991, 0.15559457182403535, 0.10043317692414408, 0.09324008628966347, 0.11089417647810713, 0.11213228181605378, 0.20768635966364415, 0.06582617384171294, 0.11135165354297047, 0.17975595839802297, 0.21077642127150492, 0.18735496838006283, 0.14095061729031225, 0.1647797821750564, 0.16900507883439142, 0.14377850828872574, 0.08821241212107482, 0.15682176806994025, 0.2012046582756504, 0.1090294878268915, 0.14617651670930848, 0.10402928557126753, 0.2551561245514501, 0.19542607238456128, 0.11033590522504623, 0.13068810345665102, 0.14079804321931255, 0.1653126729351859, 0.15981157941202964, 0.14895167021501451, 0.21454362799563717, 0.09491922078473915, 0.10774628289284245, 0.09779017358537644, 0.12420734435680414, 0.08845649539462982, 0.1410995294610339, 0.09351392441819753, 0.17368307216994225, 0.15524201816128147, 0.21222089537449423, 0.16876152416150417, 0.16783293366672533, 0.13137929862545383, 0.09402578606480554, 0.16605228486080326, 0.21674675897004145, 0.13069038639866537, 0.23174300669662415, 0.10134816935826695, 0.06536007828770146, 0.1166073001560665, 0.11872376360359693, 0.17152264293643738, 0.10418717629246174, 0.06234254605407196, 0.11665015511455075, 0.12616014078019128, 0.1522642037560863, 0.2725229394291678, 0.2000697756246213, 0.18270882898040358, 0.1306708664783547, 0.09133398292526122, 0.12855297044640587, 0.2010024570289158, 0.19531931037143355, 0.21970866938992856, 0.13473703135405818, 0.08449878558636674, 0.09861780901349361, 0.10797509037318731, 0.12457016359774337, 0.19903342720241318, 0.17031695843944628, 0.12578132562339306, 0.09757020675967779, 0.08339256994546422, 0.165173627976929, 0.15722390294315355, 0.058510964961662415, 0.13442699557110188, 0.16123071132648378, 0.16608017046124707, 0.133976505228108, 0.07933120078016674, 0.12396904504707745, 0.07261967301488885, 0.18076914032140087, 0.1485139582185976, 0.14125800240905056, 0.1768207231596593, 0.16678621241402242, 0.129193282055278, 0.10848751126398003, 0.12517770196521474, 0.18242683201547594, 0.11709362809215823, 0.12765514604266615, 0.18314841023135572, 0.16219953675904583, 0.09837953268640465, 0.11684554583963849, 0.09248692226866562, 0.09858802351499758, 0.1906109952758397, 0.1570999345952465, 0.23055860412216958, 0.17425366977770484, 0.07915611138507243, 0.07873310827680173, 0.19741342703421272, 0.23253943170270613, 0.20365529693663123, 0.22502181090174184, 0.19297027029097083, 0.13388527947808468, 0.15381951545996053, 0.13492170450908525, 0.11379443214184816, 0.247764433283479, 0.12534726786637498, 0.13310583098040474, 0.15455618560794862, 0.1286643289870793], [0.04765480576503662, 0.07583029387939362, 0.059269855489894274, 0.016948331688200275, 0.04265380677797141, 0.040210066738748745, 0.08695256520783709, 0.0447231941225548, 0.06018847918077823, 0.029015605029980504, 0.022193553759866667, 0.05685509272640752, 0.052964258563494494, 0.041187679199802305, 0.03455014403669104, 0.07943492142423507, 0.02669201630558218, 0.032808611680182724, 0.019668037665166685, 0.0935999331094565, 0.037134897880136006, 0.07719963007876951, 0.02797329644372146, 0.03576237858543473, 0.07348136871211952, 0.019594301702454686, 0.04856596009865884, 0.034621926475196116, 0.07686518673454562, 0.049732823090087024, 0.03779873987960239, 0.03195975561656299, 0.0061324035989180695, 0.059672503642016844, 0.025218254661247618, 0.044681476804638104, 0.047627762861309514, 0.05135853827420262, 0.045557057845496365, 0.04744128556922079, 0.04449416830715153, 0.00817530345351946, 0.10099597575683748, 0.010682419073888132, 0.05214593493409696, 0.015065451321612685, 0.028771663482691494, 0.05358004386747076, 0.06759357698742421, 0.030810112366452817, 0.039618271478121324, 0.005019444469062071, 0.04193215578373882, 0.035361281761358825, 0.0370302157957227, 0.06501202922194235, 0.028385725623417287, 0.040919812726638014, 0.04279243421830958, 0.0296506708517911, 0.025190068371293527, 0.024013514367623195, 0.07274772461143232, 0.024631676459384542, 0.05406291674702399, 0.03781172506991894, 0.012561420162749148, 0.062322623937601046, 0.07633071783329211, 0.05095409747633723, 0.07676419336348772, 0.026989070728661555, 0.00512689596132165, 0.012800798698839162, 0.03412618331851498, 0.02551456406382063, 0.0266565828238644, 0.023031592661995563, 0.054747370342093135, 0.08550000887724661, 0.00911033004447217, 0.039914038873487906, 0.12410641993365942, 0.019259446585971503, 0.07730233948677778, 0.07883517417095362, 0.043849601079860044, 0.10499074123799802, 0.023243341279486497, 0.03848382166676945, 0.014915343096119263, 0.09322532377536259, 0.013846956876917713, 0.0306318705195501, 0.026094647755305615, 0.052173357051346576, 0.03423257377899943, 0.06189022476093904, 0.056479544934606364, 0.020097891514700268, 0.07541718096622536, 0.04003639843675398, 0.02466529431272178, 0.03072716611167116, 0.04318729891712147, 0.07405733659623132, 0.05261221817964989, 0.02634614292952803, 0.0642434400205891, 0.03764785886291535, 0.04805971387653582, 0.007171786208111312, 0.026420876721761404, 0.04963279882025334, 0.05228188872757939, 0.022055447259317004, 0.044539390477321805, 0.0532524953145654, 0.029849809662048376, 0.0612243143240771, 0.009486191932322278, 0.016188257554125403, 0.04930151558871712, 0.050693321146912156, 0.006267123990842412, 0.034586127186494495, 0.044621652998631044, 0.004667486918474278, 0.0657610716899076, 0.018621584543237285, 0.013262885697786848, 0.02083723722476392, 0.06261914592957304, 0.02256905367117255, 0.022502670237313838, 0.06875999947829593, 0.03153113899902711, 0.060432263680042765, 0.05077707753967374, 0.02472721336920175, 0.03245060730184759, 0.014231581853011684, 0.027746729770555135, 0.062306926796032544, 0.008748160063048765, 0.08655662798593122, 0.0428058062830279, 0.052703229425054406, 0.014402084296659358, 0.03957846554957571, 0.018752807743787285, 0.06124170068951865, 0.025273424483114676, 0.09133913869699163, 0.023616581231415756, 0.0645514878053819, 0.09019933776148865, 0.03032382464997711, 0.028480935030646866, 0.006227123667486013, 0.033671942975131736, 0.048065539975199974, 0.059940481197930155, 0.026655320694009145, 0.05532866636771829, 0.05597194656729699, 0.0354893142057042, 0.021258258080530553, 0.055529228186294924, 0.06255121308288748, 0.06136969865990743, 0.08369702860833177, 0.08917054296621392, 0.016741093413363543, 0.0751109986055282, 0.025048615981734572, 0.02122536226506195, 0.09815474716766227, 0.03701195225960786, 0.04367435463674126, 0.03323284052913228, 0.017048823271667766, 0.07357260978390133, 0.027259612763901393, 0.01048235617007219, 0.05424522269036501, 0.055861729497630755, 0.02912162393782168, 0.06691520613047384, 0.07913902762436098, 0.06344431838501366, 0.03499266323483279, 0.06188265198180753, 0.08813214142836871, 0.07227705551251289, 0.05523649832954811, 0.018032807669031526, 0.034786865205293706, 0.018729696786331556, 0.0478340435262409, 0.04215804446909217, 0.04989637903148129, 0.0600761323866825, 0.02507958891651323, 0.050229366808649034, 0.053737034435353936, 0.04552172970086817, 0.060949893968720595, 0.07687959684840134, 0.04469206797019128, 0.06631804825437647, 0.002296689701559503, 0.023818960593592738, 0.008529076153682846, 0.043213001166981076, 0.04017105371120476, 0.03674854441816288, 0.03601675808069206, 0.041009000682782744, 0.05509404044958854, 0.026067499514488925, 0.028143456063023018, 0.03498551180405963, 0.0646752110051532, 0.03944271093895359, 0.05557916562763914, 0.0601115869358182, 0.02179579516392081, 0.01509909024236784, 0.0521319653207977, 0.03548333105901557, 0.01647744999988185, 0.03793400802439259, 0.09298913886830693, 0.049805114977061755, 0.005453162274563746, 0.015332959648672373, 0.028884776364711505, 0.01389034809694896, 0.027089688716636553, 0.05087895574228418, 0.05794167353381073, 0.016879987069255403, 0.025253439164390008, 0.0722015115822996, 0.03294863723098271, 0.019729824571479714, 0.019931265475949454, 0.03702944204691918, 0.011373528057799466, 0.0803638106933044, 0.05239882821878118, 0.04976851129603963, 0.0418193263542508, 0.04841936151346853, 0.04579926037319726, 0.03769115815239568, 0.06343672645368403, 0.020757089106125698, 0.017958899336536566, 0.005596330222268139, 0.14716994888599844, 0.013386521755056757, 0.014461721368734876, 0.008665306696427927, 0.011094408710637401, 0.07264307700097561, 0.08150004165908022, 0.02677379427627931, 0.009935427806340158, 0.018619977673816106, 0.046328481572169455, 0.046109709843632676, 0.02299654222423992, 0.03796706088788567, 0.04251834328076051, 0.026116012032293988, 0.06473955472991352, 0.04503335631001861, 0.034578290107029105, 0.09286346214432871, 0.02279261153401627, 0.01948158144049587, 0.07282330684604184, 0.04932378576467595, 0.03744928887294185, 0.03339614749195115, 0.04183998391512902, 0.021669210625752326, 0.08571730205608953, 0.03224678194871353, 0.0519278105498562, 0.06805238704527579, 0.03681343589578906, 0.070247060408996, 0.020549852746508775, 0.01927656290541974, 0.026807452349232572, 0.0689258115486272, 0.04235045511215445, 0.033948140654472575, 0.06153235444799066, 0.017665633218242757, 0.07841144327915485, 0.03881858293748191, 0.07987243423779165, 0.019357153439834233, 0.03272560222314731, 0.05877663659292364, 0.028701361509100087, 0.01384381017076873, 0.028122741045550476, 0.03228704753001371, 0.03114450591496162, 0.035802368375082175, 0.041127843902476376, 0.04565178461733364, 0.020156937741464185, 0.07819968125512523, 0.020819958111631776, 0.0015953801372351366, 0.09154775209965245, 0.037993245773137584, 0.056073257864843455, 0.02129870369249294, 0.03337936250553016, 0.043650395236909396, 0.053939373577914895, 0.03767320488189017, 0.021770244216426246, 0.0628185318031859, 0.0026608711425890968, 0.09159280573047938, 0.005277819112844525, 0.06256997840659273, 0.04187295250895043, 0.07441824061735984, 0.04117228849340351, 0.04724370000222999, 0.022330334928307324, 0.06258995414921834, 0.0174006893705096, 0.036818928746206146, 0.014804082231656199, 0.03433843180837651, 0.042677180120541204, 0.05258938492906671, 0.009345651187393214, 0.06527364058720489, 0.06391945377653165, 0.012726162582816137, 0.03780768012567874, 0.1513156490100007, 0.18494451869158976, 0.1484231461560534, 0.07629641241604283, 0.17202979314231104, 0.16871663140914134, 0.15107626185542153, 0.10921652053272533, 0.10206557239495939, 0.24939734969408284, 0.10003539343034068, 0.1398210972547531, 0.12560118770887777, 0.2208206153685047, 0.20884819328784945, 0.16932423106364666, 0.2273670052208247, 0.3115584899581248, 0.12544870556842896, 0.21189936827267372, 0.12309807968596298, 0.36009549193324586, 0.13329885449380646, 0.1420538298665516, 0.154618070190472, 0.16969291853808588, 0.09414831416741495, 0.2546848885474667, 0.10289164500371104, 0.1345685839412674, 0.11612422043277372, 0.3282102383673191, 0.20823236584903734, 0.15239597087906254, 0.15509747269172824, 0.0812786116054462, 0.1486407610918245, 0.1016173879766176, 0.09701788034890929, 0.14697271188901317, 0.11822808173394973, 0.12443710178617509, 0.17751617777732112, 0.11934453997039988, 0.10654804477047537, 0.13199789930255185, 0.1960503880775744, 0.21094614039025, 0.17418536537837598, 0.14101516785881213, 0.25559958220729906, 0.05788114875735295, 0.11036130103973613, 0.19015289001887847, 0.17197140192072238, 0.17061764794972636, 0.12825884630963688, 0.20460066475695182, 0.08361696475936521, 0.1414157399126599, 0.1331232364980444, 0.05008017884627466, 0.21397788738531454, 0.08539565238020114, 0.16458818358519386, 0.15942953136419097, 0.12978635668273897, 0.17711891522330625, 0.12789896884632687, 0.09211480272032561, 0.18876230254048304, 0.167085844722967, 0.1886859848614662, 0.13857684789165375, 0.1651100733227307, 0.09669736448314883, 0.1134303028905584, 0.1440902907521494, 0.2451171245305769, 0.1610421311230429, 0.1508477071840917, 0.13728510107724898, 0.23090807811146785, 0.19697346273929844, 0.23480601007899932, 0.4902846576465715, 0.12364754092789466, 0.28351222555483546, 0.10478834080840312, 0.11018318559734092, 0.19552244624543577, 0.15879392353517396, 0.12050755337000855, 0.10742520012201802, 0.1081950648597652, 0.1792071789743439, 0.14361729274594015, 0.119827535424021, 0.2309413569708986, 0.11682875319233826, 0.20985549165596887, 0.21211103836615242, 0.13125199013419692, 0.13724146470908197, 0.20364464831448373, 0.13480541236217947, 0.16160977163141774, 0.20026773274425538, 0.1575106649749702, 0.12041439707841604, 0.1939881559942038, 0.18913452934113242, 0.11467910281592801, 0.10984102774771953, 0.1823367707190975, 0.10568837154536478, 0.16418888323730038, 0.09655964485700093, 0.23050350707865533, 0.19319917736274583, 0.1570703023143353, 0.16934991033086855, 0.16949888378862413, 0.097938894234117, 0.16824844443509657, 0.16883149863250796, 0.08593412792129863, 0.1062674037811737, 0.14627675165332135, 0.1162408343366077, 0.11506193227344945, 0.1625408902163467, 0.19410470861100382, 0.1509909196606567, 0.20792868859585256, 0.13338281773030758, 0.09715879456170144, 0.14987364171012757, 0.2296098195497067, 0.16208310671631368, 0.12432467072240769, 0.12196380990527331, 0.14341510682096406, 0.11330846426708084, 0.06602136538394036, 0.22885059577322778, 0.19983999521261264, 0.14243241519697253, 0.13479470245299802, 0.13119410453063826, 0.1274935091515222, 0.20735493470584193, 0.14164126087580958, 0.19131622517541533, 0.1350435278108043, 0.19293328356598655, 0.18643357911177222, 0.09101552783601707, 0.14137608720169914, 0.08400994488188336, 0.15977077756918248, 0.18134185233183447, 0.14127946819268888, 0.07885804189549339, 0.23540392638214175, 0.14649982113511334, 0.11734294374623608, 0.16793206544412723, 0.11075527707655584, 0.2844774044088779, 0.09319762969689985, 0.1793245283225852, 0.22826089193263363, 0.1616969217936839, 0.19271982082676506, 0.19744616963209646], [0.08585638531874265, 0.0038051558470713997, 0.052107730129313086, 0.08365308580499503, 0.02613029957208182, 0.02205104033853258, 0.039514160129211606, 0.02954635840480126, 0.060579662827113946, 0.016596120849792517, 0.10030431327440086, 0.03272590099743778, 0.1631113805717999, 0.061528160116605224, 0.031330286067039255, 0.0276091116510572, 0.0368976672630637, 0.054455502334261136, 0.011777073490403354, 0.03811853562271403, 0.035777321130397825, 0.07226073017884647, 0.040764614804497654, 0.01630458034454815, 0.04413721729971228, 0.03083850166970684, 0.04416633630171419, 0.04568812782846151, 0.047258140759602676, 0.036257393958587805, 0.0355521870416499, 0.04321016281122162, 0.017973387974404523, 0.01773332474723218, 0.06602152626240446, 0.05388008220301521, 0.004316065150628528, 0.014072700005565441, 0.054965701570073446, 0.08642663052606006, 0.018535822915333896, 0.02558397354498025, 0.031235017287995548, 0.01840019470921928, 0.018095115515133067, 0.019134198871230888, 0.004563793566288246, 0.0325260631319496, 0.05364901093285411, 0.06063729945209719, 0.026851414304767406, 0.05533817734929824, 0.05717269745805571, 0.0085736500219472, 0.04029036807497183, 0.016152504230699232, 0.04516218165536562, 0.007830778871016998, 0.04753641070677869, 0.09841746169953577, 0.08748399274003121, 0.06638814529944813, 0.01853151941641925, 0.042883832338115865, 0.06688709070365276, 0.023690832388256828, 0.07049214725773181, 0.025432581164603753, 0.04995214257148966, 0.06733213416150502, 0.07668142522414846, 0.11028054771163773, 0.020490434967101585, 0.08733436044666075, 0.027938067890523423, 0.05976429246666451, 0.06140248722306663, 0.035221509019573854, 0.010673270068852412, 0.044779861646313826, 0.035622701604640296, 0.07030591894421848, 0.08815987381122767, 0.01381931929743939, 0.08196540942956364, 0.04611040315320415, 0.055290810132939974, 0.06875091367551396, 0.04096181349708669, 0.020695560754487113, 0.0682298589738146, 0.019562692914698875, 0.06467118138267149, 0.02844303091537328, 0.03443368718088154, 0.08118513355692548, 0.041599911111857624, 0.040766828798598824, 0.01692655180851298, 0.01200628125168864, 0.03424232607827552, 0.01445202173800358, 0.026096593618633288, 0.06249953662195514, 0.018566326621258934, 0.03907826376117526, 0.007285948151782636, 0.09677391198854293, 0.01125531015737403, 0.003433035341121497, 0.01163502929792289, 0.054892383125280185, 0.0012189353043551468, 0.012676105440233745, 0.0524398330749283, 0.013842972262101549, 0.03907435671276143, 0.05138229849117418, 0.06483081878433306, 0.024500518376308105, 0.10808333859688814, 0.07046289035990354, 0.017811885148647334, 0.029280818923706972, 0.043478324228236755, 0.05933018108349174, 0.010155299828658182, 0.030499745250469258, 0.05438011545207232, 0.028366703660257404, 0.031785656390110814, 0.03403242181746229, 0.04700932306267562, 0.02495591168201739, 0.09140207281997127, 0.04230760398410982, 0.04499332821597496, 0.04864458370232775, 0.04202869818395665, 0.026750432425028375, 0.020458376102690256, 0.01597292460275874, 0.0099628001278747, 0.03614920702192091, 0.03168605729907511, 0.030312668494579774, 0.026258828058358163, 0.08262236046815112, 0.1283620077095205, 0.021639371501101602, 0.045322611958028815, 0.05868921446944437, 0.0356550611585619, 0.10305906585868328, 0.08102327450028352, 0.034413929773314346, 0.10173128226832037, 0.04536907902107604, 0.030453190087310733, 0.027812203475003763, 0.022703705115183707, 0.03740123600789136, 0.05640144610116559, 0.01921959277693062, 0.06475374267827119, 0.03841825986220952, 0.06177692418737758, 0.03313699909936517, 0.022683344413376143, 0.04823526675482431, 0.037066195115086534, 0.03766593087704913, 0.03358067125983296, 0.021190304166427063, 0.017405732144271175, 0.05073894551324268, 0.07539187708208639, 0.02429589629173279, 0.028073441372403217, 0.0065769821371612774, 0.03182779314116605, 0.0759760267852295, 0.03155447786764032, 0.06804050502157019, 0.02546819084654412, 0.05058766996127464, 0.030328101335814407, 0.029008534038439397, 0.06797465210359904, 0.03247270127758384, 0.020792043782890807, 0.03929275305821531, 0.030534627148881558, 0.07514035509478662, 0.06980059202760458, 0.07310855968464768, 0.059897044012623454, 0.050099802188455105, 0.06689181746614557, 0.07379118999045703, 0.06396149668181617, 0.03155302230058418, 0.03603725859354581, 0.015514443962714605, 0.05911198392089817, 0.09632392726357906, 0.0957968051455194, 0.028780423698105642, 0.010680955845952756, 0.05704821583123938, 0.03819452005348379, 0.08376809858506726, 0.017913587151035186, 0.023690581494461627, 0.02683973529436175, 0.09860300053391727, 0.03427239502930353, 0.033149245014834794, 0.034776005908967025, 0.02317640434710249, 0.07962283513118183, 0.0428431224258196, 0.021554868172613845, 0.03837203411685844, 0.04011846560564253, 0.09809186667083733, 0.0890850245712265, 0.045365915077948765, 0.03702858402844399, 0.052093768176893075, 0.05035852157180348, 0.016333931088147145, 0.03190238137669381, 0.018262318035046902, 0.03620734926493418, 0.03020845372380028, 0.1234093335487189, 0.06690574494460899, 0.05409078702570931, 0.02388566961481927, 0.04407754671129008, 0.04460242802217122, 0.11892412623931324, 0.05501326796929202, 0.03836604330929057, 0.030838846409272765, 0.04507014385214256, 0.016594745721968434, 0.04045980757162456, 0.08178665813419127, 0.06357017513965407, 0.030206747262948946, 0.026050408092898228, 0.0944548872329535, 0.06484656955205625, 0.03679533323813831, 0.009438597762416448, 0.10994075707370236, 0.04052071539204448, 0.02416716862259613, 0.06164631002672738, 0.06657708556421342, 0.09046219785006777, 0.03742897222118993, 0.04849737224679801, 0.014718423068012684, 0.021870504058296644, 0.027090360958790107, 0.02721706998624629, 0.08109347113678533, 0.03868231887839014, 0.07041260434855377, 0.027235507807363907, 0.057130279169688304, 0.029285693158125205, 0.023352640958863403, 0.04176822445926167, 0.039866863179110715, 0.052100816185796456, 0.06522563751786947, 0.02530968342457087, 0.048038179144984296, 0.06124875252886165, 0.040451349960940505, 0.014032815553007588, 0.038538305839944276, 0.0326578762202013, 0.04363181760474559, 0.04625417870439349, 0.031452293229860165, 0.04959392751897535, 0.04778231343915386, 0.043781400102400975, 0.07631325102861851, 0.030839397992578246, 0.07115230820472203, 0.04936045839361126, 0.042513076426281084, 0.029843765228325804, 0.0155310335967149, 0.025571783170885137, 0.028859855524534662, 0.040192400751214837, 0.03320656371332946, 0.04681768999885648, 0.03784687701432455, 0.08294374201326601, 0.04054582009332315, 0.02022765914819414, 0.009156876589141546, 0.05769104020850313, 0.019842169450355635, 0.06354706609741816, 0.05638076555764964, 0.04354103235527874, 0.042126987264641834, 0.00883386710718755, 0.021974785861769514, 0.03923561055994323, 0.015145696158851347, 0.03488601230445408, 0.0233449264534659, 0.06095779999609917, 0.052774873967733116, 0.04209847347210011, 0.05622947085348349, 0.009829808221829515, 0.03391663911902616, 0.022875439045169664, 0.05701191092450773, 0.07798988041618178, 0.010095296949598818, 0.04550815462284992, 0.06028772587136877, 0.054961273581871105, 0.014301354268325434, 0.045315908688691356, 0.029701263298310583, 0.03305506982630299, 0.06164904879105668, 0.03868541004316461, 0.015150409514805483, 0.04612298614736046, 0.04314119191539865, 0.0713668741105545, 0.041964687707443396, 0.08545916873000323, 0.01602245314467338, 0.013103884149102435, 0.08828598720532271, 0.03475693415009207, 0.06851485900340543, 0.1835095747223785, 0.15691490903977426, 0.14778085804033667, 0.12426097051150377, 0.13300331309437752, 0.14371737447236815, 0.14750736465136852, 0.16685280077640088, 0.12991611665535358, 0.13790935548322816, 0.16852808184921744, 0.09768409339050133, 0.2992261291271256, 0.10329041675093675, 0.09205147023162535, 0.12700574863101208, 0.15069389205065467, 0.27262945629415974, 0.1105114542728951, 0.1299784915341485, 0.17959330260993975, 0.19849578669715315, 0.18324279226362708, 0.0784565735187742, 0.15408026114586862, 0.15850913801020192, 0.1816162956698287, 0.15314764102860806, 0.11137093597602461, 0.19934416778625982, 0.20441704880326025, 0.2454793768664522, 0.11464239188259649, 0.1232454673417153, 0.2986522373412886, 0.1516787133990757, 0.20011408615016169, 0.08840793308110968, 0.19886320246563804, 0.1735682355900926, 0.0899878362073533, 0.12326582995874268, 0.11821391676822979, 0.08171093034287615, 0.13643986094863186, 0.11642549983075551, 0.12332176969897364, 0.11371191681152391, 0.13683266487092743, 0.2798740127153935, 0.14325985144222939, 0.14940911663636086, 0.14928574583703472, 0.13039643846211896, 0.1256653016072608, 0.16483256563303933, 0.12048074029265873, 0.14381786988627526, 0.2049847046333936, 0.13791591319586002, 0.38493031575795145, 0.18378899763188056, 0.15498337155628591, 0.1885650348999808, 0.10545658398299448, 0.13542995788156986, 0.22714332286869326, 0.10880374469824376, 0.10098027095438973, 0.1654279998113071, 0.15573594568958207, 0.15375972995834966, 0.10710516689164985, 0.2753295178615278, 0.14295539277936184, 0.17044120257900608, 0.1582982646481645, 0.1384588243860391, 0.16571393446816554, 0.30514164557380064, 0.21136773389674005, 0.21654936875547134, 0.1620155837266676, 0.15620617045750543, 0.31569839845741954, 0.23063669912517074, 0.15330320284251245, 0.11890571714649278, 0.1708818716748107, 0.1252383071809046, 0.1377629254373812, 0.11429290257153973, 0.18804144444725207, 0.14557693033449112, 0.14666453003883362, 0.17161679514233144, 0.08675041758725721, 0.16533199367263626, 0.09381410064956835, 0.08289897183497107, 0.14498117439929517, 0.11904254044976928, 0.1643954205416864, 0.2222716165406089, 0.09532664166463, 0.1025419794924317, 0.20235195155105284, 0.27052188712743025, 0.1281409070736939, 0.14637402949794648, 0.09947354454667338, 0.18467413561959423, 0.08340455156059996, 0.14121825776753888, 0.0883142252062117, 0.1332433284410546, 0.1575790459830915, 0.15135805963748886, 0.1763373370011968, 0.1449886054521607, 0.16032637517538764, 0.10803266188069698, 0.1606860840993543, 0.11080499618284165, 0.1414546112139379, 0.2241815809881495, 0.15999959271040656, 0.11008470499467467, 0.15391892302901516, 0.17053268879892367, 0.1501219920934208, 0.08639741193262801, 0.1684245374053717, 0.08278704638923369, 0.13189905863856116, 0.19313335508829166, 0.16723423595390013, 0.11754861537126765, 0.13435720496119993, 0.0840124040241203, 0.11831422832103507, 0.0909718991287293, 0.13272548364775796, 0.1523138156100627, 0.0932597058014043, 0.1313105345733704, 0.2483535548972507, 0.18019238336672708, 0.15376253384015254, 0.16749099798260197, 0.14337527024890148, 0.20742913798218776, 0.16495927657571532, 0.2533358996433597, 0.24004520878436106, 0.08898572425448126, 0.19212317622957692, 0.20152158884992524, 0.157733412699834, 0.15406679332015977, 0.16666596725342736, 0.14697989779374293, 0.12580899671921808, 0.18750696022424007, 0.08490933210498865, 0.1604446285073796, 0.17533563107492464, 0.11912618192934221, 0.16713170274611444, 0.09158968009174832, 0.13668249631600995, 0.1047025389608837, 0.10342426763306703, 0.21698629934220545, 0.0684214499027979, 0.12617196917774218], [0.038762087783505844, 0.04720218186717361, 0.02498346403421414, 0.02601735714462496, 0.006691231223333988, 0.079741096124053, 0.020343275222506736, 0.034034474933099364, 0.027293969892085563, 0.004957586220811092, 0.056723597564644394, 0.03549985940598192, 0.04360759773501947, 0.0681806761290758, 0.032073759075794975, 0.028426414468295635, 0.0721799462072311, 0.06047650908810958, 0.01441106763518145, 0.02809240779418859, 0.013507603866709097, 0.030230396397171483, 0.07703808511817649, 0.04706203757274536, 0.06449301231412158, 0.037639462539265235, 0.09921769416260143, 0.022861915678086302, 0.014514645595373887, 0.03324732725178042, 0.041453664927112485, 0.065677851558693, 0.033791268830217665, 0.034747894312585556, 0.03527957848423431, 0.04527048350522115, 0.012192431998799646, 0.037287265107396154, 0.04547815845017472, 0.04654638762135179, 0.03991532973164032, 0.07089436640061679, 0.02342026162471983, 0.07778286813728272, 0.06857118178759852, 0.05200266883137727, 0.05301342225603519, 0.017383258955012408, 0.023785168455252727, 0.08674326232604443, 0.030356829632974924, 0.019409075048902345, 0.047479352478178284, 0.026326705363669226, 0.04733127151285449, 0.022221920080482963, 0.04072355249175622, 0.06495216711153907, 0.022682283381601016, 0.07484038570715536, 0.06574139089113282, 0.07849467873212793, 0.03334457445288858, 0.03586246797274198, 0.024258647181634462, 0.09062699102345975, 0.018335973558526848, 0.056426447380574486, 0.0022710202498391514, 0.025230004534786268, 0.023247769267688838, 0.04133989320947759, 0.026791379824581168, 0.0701049357772835, 0.04977408458568877, 0.06009699296086066, 0.04004060042901866, 0.08754119652533725, 0.01277409766184827, 0.024992065286383997, 0.040857307612895966, 0.03872138936252844, 0.029412218324479558, 0.016467688124506705, 0.05079305813377423, 0.03452412386034285, 0.012052665960284011, 0.01971020122929927, 0.029029375460419445, 0.08612969484660896, 0.032812043754083496, 0.08617458759897179, 0.015125321092895203, 0.034253158561524846, 0.011491852252924395, 0.015415519029052268, 0.03005491821245561, 0.009461180119204425, 0.033124887249282295, 0.06956562520034852, 0.03257274469961563, 0.062136598637387644, 0.029390955554141156, 0.03256152534196454, 0.0409846697303076, 0.03191131779233054, 0.05186949210662035, 0.0646171875057682, 0.06107973438056727, 0.06103625506042473, 0.046519379191581285, 0.01291805228608991, 0.04302915538691225, 0.03887687073720079, 0.008469739771117608, 0.057856024903876174, 0.04293882979019996, 0.04691510190886836, 0.013511090524374478, 0.057308689555934364, 0.02064540114764485, 0.028555412183425603, 0.022679868289419723, 0.015588074588337013, 0.0405948497204771, 0.005110700383797409, 0.021177887796394287, 0.023160678477236823, 0.05584677929178842, 0.02861661877813599, 0.028514922521407568, 0.05935892470241074, 0.0428872031249827, 0.04644893357650407, 0.022768399325169386, 0.02417893764833289, 0.012143717425304556, 0.04216698854560814, 0.023694693471395203, 0.009524944489972006, 0.023617090679885402, 0.024465395160199657, 0.04014830473029325, 0.019999115968183167, 0.033394454437638485, 0.06847065573017444, 0.05706937517970801, 0.031338194009637645, 0.026033305179988666, 0.04044151722243236, 0.09883765326512438, 0.03249315965560175, 0.07314678747206926, 0.021395481664747484, 0.14558816118346107, 0.025232341102955323, 0.035991308639847466, 0.08854220531159833, 0.03856003592391649, 0.04062899042882266, 0.039980926010156834, 0.04339796543541936, 0.05391172546472761, 0.006197472234376737, 0.014141561733859201, 0.037464656596702915, 0.006639665845150669, 0.07860209958087053, 0.05109608038178375, 0.056205561249366695, 0.015723460519145575, 0.021221882310665904, 0.02666729847870527, 0.049550961477742086, 0.016633894730118975, 0.03245596608687793, 0.017303206597364718, 0.004726564267560119, 0.011774983985589878, 0.03605209771663912, 0.02281025262369264, 0.12519242617511941, 0.024527528721298424, 0.06624834191414618, 0.04052823454502129, 0.009183164896263231, 0.05415995710439259, 0.043422633466581186, 0.09423357975338736, 0.040233378794284604, 0.080018465917918, 0.034154513249954874, 0.0483944253515332, 0.06515020083996557, 0.013026369457703926, 0.02542956277818209, 0.03899445757269859, 0.01682957848383775, 0.04040383718787663, 0.006959050294807962, 0.026171779402741985, 0.04472694795338377, 0.08122481691140322, 0.03221280977971131, 0.042321217366524284, 0.03664608781916961, 0.05143548031487773, 0.06422256795509208, 0.07811256173637607, 0.08830991979207724, 0.04011477689228712, 0.0436064945684085, 0.007049280609334669, 0.013898814326122165, 0.051736614156153896, 0.04984086830048792, 0.04673203370804268, 0.04940060523128317, 0.018753324853136175, 0.08770620420334801, 0.08844426097047907, 0.10895123194542625, 0.05438484604500475, 0.057864585936430006, 0.01637507958578006, 0.01291548397632376, 0.030155633876640952, 0.015488757992223387, 0.038296160768837705, 0.04818464749522748, 0.07542607524702627, 0.02586696450898965, 0.027248052497124, 0.07764077414908717, 0.04647735160805526, 0.05960830547396214, 0.02291897007624709, 0.06628643180574141, 0.03295147558674216, 0.05730802688987986, 0.07244705808378997, 0.08470523096020184, 0.07941665788812023, 0.020409256460205204, 0.007805015812928398, 0.024861573699801683, 0.03714431693116504, 0.013326714228418086, 0.06080248716077017, 0.01808796983001934, 0.05835484007313367, 0.04412917720694696, 0.025905360835754586, 0.030658377161730203, 0.03299498555040167, 0.01952236796158456, 0.03270813924891334, 0.012102125554285463, 0.03955498495469651, 0.007668609069960733, 0.07378598059257192, 0.00795996523529832, 0.042201853207042145, 0.010318873007030738, 0.011379408740228223, 0.04030369034397506, 0.11093846402100979, 0.08464422737879139, 0.038093492208469304, 0.0825984278813966, 0.06541419473867263, 0.07254516330337332, 0.03454253678360293, 0.034747695129725246, 0.013729929285604629, 0.01429828608618869, 0.01946335812399705, 0.05489477331960394, 0.027435100524716323, 0.007566928134990797, 0.0665724813757885, 0.051478400390835545, 0.10741085129519624, 0.0630803844861446, 0.039392988002228166, 0.023492917403458588, 0.08515163805455932, 0.025669532159583706, 0.025372077455563892, 0.028267855335387494, 0.024364273469414444, 0.07932632846096832, 0.013600908587836932, 0.014606083934796194, 0.0766669155188626, 0.012533545096014297, 0.040356964098229524, 0.04161603726266373, 0.05301040770005315, 0.0449860695328924, 0.02933227130392146, 0.037694969439818975, 0.016503826407114827, 0.03269030472203609, 0.03162930550564441, 0.05354927011555242, 0.015936383166380467, 0.056000111789833155, 0.021731642961141565, 0.05751628789209551, 0.04502263873995793, 0.028826191705921968, 0.040836749643447905, 0.026681993960312782, 0.07581962227460838, 0.06571329844694945, 0.02306395987679641, 0.027381880396616556, 0.0023791858796856457, 0.04184006818480069, 0.037367547291421124, 0.045146197230825504, 0.007726554524138451, 0.05502426899188469, 0.009871063971771829, 0.003440492728259415, 0.0903191309302084, 0.0056033461512396895, 0.014494764656128903, 0.04491081288565071, 0.03339963702244624, 0.015139917940682462, 0.016811381980416276, 0.017917601451758417, 0.024020593020043546, 0.058713208343232834, 0.03707473699544226, 0.07188142472577673, 0.0025312574448875125, 0.04120845167386917, 0.08189487571437513, 0.034519868241923476, 0.03736403860872792, 0.04891811156525247, 0.013510000764302189, 0.14024558657359693, 0.013781873877310466, 0.006621040811296553, 0.033354326752164674, 0.05890533936420276, 0.00674532421286248, 0.03858232142163381, 0.15114334051407155, 0.09456212422059429, 0.1223961899297372, 0.06569349507410681, 0.10748833342785798, 0.18705286926800208, 0.11491962378063511, 0.10246433648130587, 0.11485373255826774, 0.1635131324010511, 0.14813442293915058, 0.1523683304267545, 0.12858877739598676, 0.28952816080662513, 0.16991655492494184, 0.2101458849445466, 0.23103117311914123, 0.1770579346245335, 0.27462281707313757, 0.13629782824747025, 0.1903217051538729, 0.17756289381894375, 0.13978145986555085, 0.15378018450592795, 0.11942494855893236, 0.1274809989357187, 0.21149688099901523, 0.2367477365318806, 0.14896463242269334, 0.1480503064850646, 0.1829679658816707, 0.23870400333356476, 0.16956249972985638, 0.2029089587590387, 0.16640702953502057, 0.09400870996497332, 0.12622279911151818, 0.113265433108374, 0.14575260961728712, 0.16102887780195282, 0.17666715317435805, 0.24379436647699726, 0.19271085759805096, 0.16103960303289278, 0.22132131511405592, 0.26249414369944607, 0.14652455045330912, 0.15129422919163782, 0.09692493856193558, 0.13986261922024912, 0.16616165157287352, 0.19762241581995643, 0.11412539744689582, 0.10321786056362814, 0.1772909019623072, 0.17144474711629654, 0.1740575053038136, 0.3357122616181451, 0.07185129448771477, 0.1955197649377008, 0.1414003262236234, 0.17412823054098314, 0.16064696764994055, 0.24320095477084963, 0.16190905153991716, 0.21863652933989802, 0.1928432682348836, 0.08901507308286044, 0.11721073229226375, 0.1669312635016057, 0.10385203580822676, 0.10692308311380687, 0.16416101295861507, 0.18105846108688464, 0.2981563333061434, 0.13117178072852473, 0.1412270831004266, 0.17611402237126905, 0.1567823145418398, 0.09790447390367908, 0.11977117433543168, 0.13902614313748576, 0.22228346025991827, 0.057771441136156364, 0.15571970462558732, 0.11309714657404732, 0.09437237190262926, 0.1299591401531812, 0.10010699966862317, 0.1299940431190114, 0.20220852456986907, 0.21107464397866882, 0.12737591465514514, 0.08147939558952086, 0.13759386515425098, 0.25252770752676074, 0.1304993393921083, 0.13781177120343333, 0.07246742070081734, 0.15478857071889987, 0.08105241648492315, 0.2016636521946038, 0.1466978855070568, 0.08783417919109907, 0.13572274136447138, 0.12632368523026669, 0.24613274261355403, 0.16651232065933366, 0.21234150825729295, 0.1097513035300278, 0.1672167231839511, 0.19750793164055194, 0.15022178270643757, 0.2024767779174351, 0.11290150303994456, 0.14308081669432504, 0.16360843373883158, 0.11894277281939022, 0.15329194135002552, 0.19299236426670707, 0.10131538079510774, 0.12237889166440695, 0.13805652097348245, 0.1707107582760434, 0.08874053015343605, 0.09577256612359517, 0.11452108185978667, 0.21439045637605653, 0.17616832268334207, 0.1269317675201643, 0.10587174235092056, 0.14948479080152127, 0.12371653480635536, 0.1466249539366653, 0.1228244177576515, 0.1109705554441579, 0.1708777041565026, 0.06682836240337742, 0.12694115209723675, 0.14046522398148814, 0.07245302590872012, 0.10391027381223056, 0.11432499399468785, 0.174609640192601, 0.12334567164221119, 0.21482845948588467, 0.2161658191753011, 0.12193767098529686, 0.14134242529830626, 0.07360493869430597, 0.2095610687449094, 0.05348778772918929, 0.2310000086623815, 0.09183900340670541, 0.1504888869221172, 0.0743708963836393, 0.1022814329893839, 0.1832208055402002, 0.11563937104637585, 0.19548046462718519, 0.24953247228216743, 0.11466023407035297, 0.15747087436818308, 0.07974861910746944, 0.13545556053999933, 0.1575960837785275, 0.08315163529327801, 0.15041923420804162, 0.1578335863568129, 0.20115536817860222, 0.13528181179877252, 0.08995317838965886, 0.12852143060656326, 0.13510556561091255, 0.1600217020079013, 0.15178567459506376], [0.1046463770551547, 0.03079523493896329, 0.026793620631759687, 0.019962818722330758, 0.05594892179473274, 0.010570744521945957, 0.06108463734328266, 0.03211966689465748, 0.050864170245345564, 0.032740694155255635, 0.0496627681798512, 0.03050724716646777, 0.027326781437882496, 0.017647605254164627, 0.08478161758713185, 0.046438043636660424, 0.07035081935746056, 0.008072062572013707, 0.051476584762455, 0.05328137682931078, 0.11843659554518039, 0.04587310358821865, 0.02438015447208478, 0.0370826545141397, 0.04345215083430371, 0.04194668847166243, 0.01839563457085, 0.026714815082208767, 0.05304152619153742, 0.051493346766238256, 0.022418157332727028, 0.01724123966038948, 0.03275676284946742, 0.06370514067971418, 0.02809798108383773, 0.06012111323915663, 0.0059693154499625735, 0.027425773404238206, 0.05868151911624497, 0.006852489379760359, 0.04126361383485698, 0.0364277757433874, 0.040529617333724614, 0.05604510030318653, 0.0056016229322150115, 0.024829805948801582, 0.04193650333270912, 0.02567765460680089, 0.0651350629425818, 0.007564310508314521, 0.07713454324872264, 0.030340138492324663, 0.048357235613249006, 0.03300064694016211, 0.0899470650080231, 0.02217070710274481, 0.01710482812937229, 0.03651202243242053, 0.020958660245542566, 0.007468662994553245, 0.027907983617736932, 0.015018003666022373, 0.05810527544048044, 0.010185016379241022, 0.01888802034720298, 0.052521559334690535, 0.026935475217478893, 0.01275248823672413, 0.03524469084016258, 0.026098311570803487, 0.03114542713569057, 0.06920757868717756, 0.05896972522379891, 0.06842558677758902, 0.01038651090986546, 0.009878695165107568, 0.037544984746003346, 0.04992131136297699, 0.06873891673861973, 0.07787125170110695, 0.06858697085971795, 0.060501510367518475, 0.03106203463469302, 0.01350374948684006, 0.03512301309514911, 0.036504844188570015, 0.031544087800167264, 0.04030624907764216, 0.0073217555801684585, 0.028113751003759044, 0.09100741496489895, 0.009788175173584494, 0.031654852622699355, 0.03266731059298881, 0.04231490097158859, 0.03659739527070234, 0.04835575323311552, 0.028340723703525243, 0.04305968016025521, 0.017215207992722432, 0.04913547752244819, 0.010057323886412046, 0.029860207390400673, 0.06448922783977563, 0.04676266573369504, 0.0064487763654230345, 0.026916610302343488, 0.01588673492322766, 0.008056138476897633, 0.030878757674907966, 0.03613870012603941, 0.039911518444217024, 0.08101217388626068, 0.02345924400874684, 0.08056893073503049, 0.017437425201698657, 0.03166507223560926, 0.006944440998091933, 0.028096416349252386, 0.048347433518257835, 0.04720662900757405, 0.009316586769155918, 0.012507477039170843, 0.009803332223166383, 0.03494431925637107, 0.03445614504838183, 0.03394301552625914, 0.058033707506594166, 0.022816613068683975, 0.06739643192098987, 0.02713729342025134, 0.056806518921568516, 0.05508799601586596, 0.054325830461757804, 0.04591315083446042, 0.04606872413968367, 0.044975593280527866, 0.02082707506844834, 0.010555613327831512, 0.04393403546043462, 0.05800527415328449, 0.04020330601281697, 0.057511997799719536, 0.10252317969476986, 0.022333186690605456, 0.02666536027625684, 0.014786679586846263, 0.01411858675701003, 0.021707068775750456, 0.01109956831280743, 0.05194991984735093, 0.049966192624020966, 0.026608746378652515, 0.07301157295343376, 0.02432772149932721, 0.04434188534956306, 0.013630852091967339, 0.00270841934721947, 0.03981225260142838, 0.03474930391436623, 0.05780521412229827, 0.03919798798198181, 0.056987262045544, 0.08717606369886668, 0.013624134458481305, 0.050559776699951584, 0.04730308713812021, 0.03126151626929641, 0.1091733131737959, 0.06184234043523189, 0.035506390305536414, 0.04458624824521042, 0.020117170117314787, 0.03570888649612185, 0.09286312506564202, 0.028949330763651, 0.07210399625041793, 0.011135608919205205, 0.030657703004356836, 0.01904824763656624, 0.023148608761989785, 0.04285745210044327, 0.05467586752568042, 0.020036995185599215, 0.021814922464170286, 0.03271096611335393, 0.04239353223613674, 0.039628380008282206, 0.0055897878313947835, 0.04214114839992216, 0.06041982624259207, 0.08446180652226172, 0.00606102766581781, 0.005053654125320816, 0.050766957518193996, 0.03813912423567907, 0.08273256221605886, 0.02610369716891118, 0.045190641821752635, 0.003384692320269683, 0.06270303255728175, 0.09482453997817733, 0.004654753100757878, 0.043635242017767126, 0.08066211767013996, 0.07240952743637948, 0.024536595371882283, 0.020605403697118163, 0.028456600247732097, 0.04038072048476146, 0.027840391680177663, 0.02069891621959546, 0.035235903811671083, 0.007341929069239527, 0.04258908000924895, 0.0628910688382964, 0.0060963826235233545, 0.021399344663105665, 0.008601459971208487, 0.04900657173786913, 0.037713926285505295, 0.040517348435617266, 0.05279883336756499, 0.019611776168007525, 0.01635062605923703, 0.03199224349021191, 0.03389808063906047, 0.08091407632755657, 0.017815330629086783, 0.015283919487809463, 0.07578319479380885, 0.011794409102519915, 0.0764472091630582, 0.01673799841814945, 0.0363010264963152, 0.01553227753198195, 0.013169477554789234, 0.027346450745338396, 0.07598158092268052, 0.030639726751213594, 0.05241020845489637, 0.029976673822309223, 0.055264077494822206, 0.016961866546602502, 0.04979756901100759, 0.034772891761554826, 0.060650334438128825, 0.20826598178715477, 0.06178339763033775, 0.04594517330969534, 0.05778004047310641, 0.053964960914585865, 0.033412204694844065, 0.04984461063999803, 0.049918082302376154, 0.03022505484911944, 0.05377232427558592, 0.03618521698480172, 0.012720195715495897, 0.026336043975466204, 0.009793614397846885, 0.018184079390559948, 0.04182772267790091, 0.06874578854730053, 0.027039362485670758, 0.029933587122227878, 0.1245676814728687, 0.11837039022676407, 0.027741549100967187, 0.0026760612297127206, 0.06267931447514603, 0.057897627308604226, 0.02599624759187141, 0.014399784117666705, 0.10384722477606229, 0.04291829480338962, 0.05235650186096469, 0.017666253749461427, 0.052218479630086696, 0.043355822938704686, 0.07174183584509358, 0.07833247493592002, 0.024934484202775265, 0.05068526956282797, 0.036728388644875064, 0.07375888406269013, 0.05150794840207504, 0.02304707721416508, 0.03939533606171608, 0.03421089732118192, 0.07633938994859496, 0.004065154118448376, 0.0318723296626441, 0.022527386148970936, 0.032338172407640565, 0.08066987814081293, 0.03936273519009833, 0.03878645320993759, 0.034840514342631065, 0.06166687948749431, 0.05445434171105585, 0.07164350079913294, 0.0265828468611524, 0.009462602169913872, 0.011563618412061084, 0.038668372247728615, 0.019571790208799705, 0.03778929018505639, 0.046796021201918205, 0.04371100428303884, 0.08573892105731272, 0.014666798318015232, 0.024594205183788173, 0.01742374287137101, 0.055568103318012534, 0.041718681553198446, 0.03871897618556696, 0.008953955219758135, 0.04035484203467927, 0.04820497563829826, 0.03462206437102249, 0.04628648080172078, 0.0513402249423727, 0.05173197166333276, 0.05456494565512385, 0.04024621459745592, 0.01992759783001196, 0.05493235759316914, 0.03329491663363672, 0.060778803552591035, 0.07096201962521, 0.048496035423370144, 0.03886691159418514, 0.009920366517748806, 0.06472214921227386, 0.043395065792625954, 0.011403987713668857, 0.0149551710496927, 0.030410995879661173, 0.03002121991988632, 0.024352636593844623, 0.05030256267937441, 0.022656680723171563, 0.023754572818776774, 0.08566472544184617, 0.056763123871097644, 0.038162961061443054, 0.023680518929576202, 0.023380172243642233, 0.07865793206879208, 0.05816887605995421, 0.01720512436041909, 0.16547592627185007, 0.0853651161155393, 0.15141240591483732, 0.14364827334159805, 0.14234143459508497, 0.11238718225109963, 0.2772478633109601, 0.12504255639449244, 0.1643640262585494, 0.08128080261690963, 0.14762102145581477, 0.15102727819354306, 0.08392513894866552, 0.11015548385799893, 0.23739425345293938, 0.2304370872556202, 0.1291789868546109, 0.11369216706483595, 0.16395818351978259, 0.15257476047883112, 0.18349003948030934, 0.1291143596773186, 0.12928908901108851, 0.09061184546519672, 0.21236067577715845, 0.16465215192687127, 0.1257311851687489, 0.18636031046269402, 0.19035181240929713, 0.19887651707376205, 0.14258210877737693, 0.12335602915094745, 0.08518579025422374, 0.20763282543949543, 0.09605135318012008, 0.13618605601931774, 0.07091152677012068, 0.08950971307293062, 0.15851350471137032, 0.13417073916043007, 0.07729227309145274, 0.1153144731576885, 0.0998388842168835, 0.13392234281186136, 0.14834377944709795, 0.09006911813611947, 0.18082973787621145, 0.0974333681346428, 0.1455644890666008, 0.21255083412172335, 0.15868140054085564, 0.10448483975544091, 0.1361056780743022, 0.11991245627042749, 0.1956222675019695, 0.10848105314277834, 0.16754126867219327, 0.13519285366900508, 0.08400179370636902, 0.1085764387502305, 0.09702437677450719, 0.08622992212974256, 0.17649305203268606, 0.15546422962459827, 0.11093873981266253, 0.15816574675902245, 0.18893413606189913, 0.19088669499802977, 0.25124676255208833, 0.08635039711671491, 0.08999579586088659, 0.4607036126957786, 0.1849427566893639, 0.23050548358549997, 0.13051397167146206, 0.15843741685873078, 0.12060167493238566, 0.1730952069403664, 0.13775416139152744, 0.2027328657887636, 0.1912958165931125, 0.13729525940312495, 0.10000344756389819, 0.09724654993342777, 0.1050161523744464, 0.06546747615380634, 0.13505933986556146, 0.14816276819234894, 0.08901419974262677, 0.14765773238914628, 0.32131492610900636, 0.19019173067663947, 0.16267898522557753, 0.12200850347477583, 0.15219537841696895, 0.17259331209765327, 0.18346449810891383, 0.0778073676291012, 0.14920785001689388, 0.12875564666765352, 0.20459433687069725, 0.20509230934323805, 0.21450328580554456, 0.16160773383753915, 0.16500387821466694, 0.1499857356952083, 0.16540763719427973, 0.16738900103636328, 0.2590287602957218, 0.19210099032328976, 0.12750969658936226, 0.14476915190537132, 0.12263389169088296, 0.1307613874274877, 0.16594939925257238, 0.08539210539311172, 0.11864047452446916, 0.09632440989897137, 0.11257676602972132, 0.16043698294989525, 0.14674251778952538, 0.1302253863503856, 0.11870486421450493, 0.11362803784469444, 0.14448979028290318, 0.10973086430420799, 0.1341047789901495, 0.12383910887424024, 0.11013072389628618, 0.14432883521001186, 0.1312784201675846, 0.13960077036773005, 0.13765277731562817, 0.16189408218187673, 0.3178587357603735, 0.1279142906048125, 0.15877803487162437, 0.1280885373031901, 0.10901434226862847, 0.1354151417411143, 0.16093452641319844, 0.1386609183804643, 0.11613054831902828, 0.19776890715283735, 0.11549081127609938, 0.1889005354455402, 0.17876442611938526, 0.1286138591146277, 0.08331067514635863, 0.07314474201731144, 0.11288615829882123, 0.11787670784659925, 0.1258936570957303, 0.21578862812490235, 0.136306086675294, 0.1531992447111876, 0.1477017977665509, 0.07152281130754179, 0.1289787161494455, 0.17609102441178215, 0.14232684828100667, 0.10932784076900252, 0.23440871688146747, 0.17594716842136077, 0.0792807232468359, 0.13136236808232724, 0.09531931786407387, 0.1726555797241388, 0.20277734485364732, 0.11450000678098972, 0.1581234280620852, 0.13504794047724816, 0.14532520916433106, 0.12817546529995819, 0.11177628075764065, 0.1000159960840979], [0.06143176710353263, 0.009986413830530741, 0.029475633167631687, 0.09830916751055949, 0.04690590119289775, 0.027294856638857917, 0.01273432620725925, 0.023338050814345482, 0.052003128484131834, 0.02701729915345148, 0.029914630276541558, 0.03879952650036543, 0.054916407642585624, 0.0712733960620338, 0.002959621492810848, 0.021798560741327463, 0.028990096217321775, 0.012671144063314124, 0.15670432679114804, 0.027203793682518507, 0.007686859678341857, 0.02947986963385296, 0.039775254385125254, 0.006797167776723303, 0.020643200560082352, 0.028199483903365272, 0.035295834869987545, 0.04973835424490033, 0.03418865012786081, 0.01951656293033833, 0.03547989898511479, 0.04299358592458791, 0.0014293438664847806, 0.05256195132049823, 0.017380947284700892, 0.024793441670255798, 0.036992581726442424, 0.015427807079357727, 0.06942628912868039, 0.052283053181224295, 0.04689616038494053, 0.027252869274947914, 0.015724413341001397, 0.05942888768209566, 0.05065254994758195, 0.039313510210523685, 0.011023315751264173, 0.06406352044113221, 0.06226290355346376, 0.023948398809279167, 0.02434763403969907, 0.04162145350428839, 0.018211922856167923, 0.06928747399680077, 0.015455591173151569, 0.02646982207924368, 0.062271154320408265, 0.059002180538711056, 0.04295062754423388, 0.03567532418415912, 0.09619539303164329, 0.023714257441761515, 0.08533919936106091, 0.04436284168473175, 0.10359548828414372, 0.03708935012259791, 0.11599552532237385, 0.022037905761070793, 0.05326556860499325, 0.010800493332827765, 0.05868470221157036, 0.07634406308493308, 0.02597131142993608, 0.011106674735915038, 0.08736789977598576, 0.0660708929682451, 0.05274833285159642, 0.09128922806872476, 0.0840751159816019, 0.07420146837830544, 0.02553062509715317, 0.06532876061335688, 0.03675016852456235, 0.019103873280748244, 0.039230585023159945, 0.02114006220513294, 0.04477032385165653, 0.03672125636630001, 0.019140415674736424, 0.033799795388814904, 0.059430504127615885, 0.04807053103802666, 0.09080786438238236, 0.00879039832075397, 0.05776925778557217, 0.0423165480606258, 0.010032193329665932, 0.04452257101694423, 0.03659777831466448, 0.042537664018210866, 0.06102887763371391, 0.055885987671753096, 0.04109437735150418, 0.10110751049773348, 0.04704850079912332, 0.06644196297612882, 0.01998612503220718, 0.007994605337209519, 0.010702610278742449, 0.02662998425113338, 0.009843019408083731, 0.07884936978019054, 0.01496526330048519, 0.04440200026898135, 0.05653943002764737, 0.06320733291607711, 0.03879135617265298, 0.0440384264314367, 0.022106644915296667, 0.07166931030130194, 0.05111318329469331, 0.03984525183876676, 0.006257742765404645, 0.0595123146570498, 0.09910601386499983, 0.02583738393901337, 0.04640546957812002, 0.039911549087734, 0.044380143780501626, 0.042414856293509086, 0.07365693308172688, 0.054402144310335, 0.02834815284117095, 0.008601679263876812, 0.041527205537403786, 0.008219027921797769, 0.013298679240829041, 0.028664537577799735, 0.029367988238171227, 0.03389670168079677, 0.01866415604918955, 0.04635790317890145, 0.08452194442431774, 0.04192304316787951, 0.0142961400823908, 0.035586584389450095, 0.0413249506645145, 0.008590703139141684, 0.03745114280571861, 0.0466289680691496, 0.013819303975680904, 0.02444276109247679, 0.03303108361339377, 0.020918837080018658, 0.055140400260326364, 0.022334184520126834, 0.011186046232920022, 0.020782733899390986, 0.034174136592135314, 0.03670579671198803, 0.023131155363854863, 0.07346816135630493, 0.04150949358459442, 0.032632170139902064, 0.07470456597905967, 0.014576946738206092, 0.0532730762666512, 0.01685475979390885, 0.019229243569556746, 0.02842561199119495, 0.026497701934028058, 0.045107172711962656, 0.04929698800908462, 0.09321377116946444, 0.014252606178483656, 0.021748165562448483, 0.057308689555934364, 0.005317340631248249, 0.06302342967941396, 0.07383258938188515, 0.031604108873814825, 0.04990458000271071, 0.033991010934715314, 0.02714160074960561, 0.02071566098640042, 0.03890363401883552, 0.023372586057972045, 0.047488679598656394, 0.04178132456276686, 0.03598324556444441, 0.03507003045430587, 0.03731940249581972, 0.030825922505990155, 0.03472038409522465, 0.06757427157173235, 0.017163286383654323, 0.01528375956695527, 0.0177065001785635, 0.010182906764619535, 0.025348506845353592, 0.01045434320751097, 0.009820791366960733, 0.024983126955527454, 0.0202646994993331, 0.032570967375631296, 0.04296409536994273, 0.05144015728165546, 0.031160394578511198, 0.03166723643399535, 0.0715671984418746, 0.03916042669105434, 0.03330422843235635, 0.017430315905761336, 0.01168919554460914, 0.06372603955828855, 0.08867405670424623, 0.034920896118086193, 0.0019853271500793316, 0.016101335303016728, 0.03939897497935642, 0.03529858512563571, 0.024644820612945387, 0.07372643257821761, 0.04071422154083848, 0.07342570476354131, 0.04001040890392277, 0.08341990396260254, 0.03864178516631646, 0.03275331162336854, 0.05801560867938304, 0.03801473453941365, 0.01626427262841213, 0.0074098006288911555, 0.06876212920272542, 0.03773608154827549, 0.03067746424236365, 0.04978319337110847, 0.03315712805957564, 0.02717022562489635, 0.008792785642248009, 0.038717761936206976, 0.020283393959905353, 0.0695508397034099, 0.014957458779756582, 0.023008958594272697, 0.03251230419282952, 0.0795806466691917, 0.023966800241220384, 0.0259617583135203, 0.025509249328845934, 0.03546063570425876, 0.03831148635776293, 0.029159654457602772, 0.025931716175569643, 0.05436830237627991, 0.06075505099649872, 0.007389539518513747, 0.017976724287314762, 0.00993264690717502, 0.02207037448252161, 0.03642096905218017, 0.05087140977623002, 0.06395640985799894, 0.0689150020480156, 0.04599911739088355, 0.07295080685927983, 0.057410766941405116, 0.03224231182567535, 0.08177519745884404, 0.04412041699153282, 0.05841108624853435, 0.05113944861917727, 0.017849180224021117, 0.033209597421509605, 0.10569810852288239, 0.012159889541386117, 0.04110465059056878, 0.03181789528518435, 0.0378338573500514, 0.022251309128478173, 0.0396950641316512, 0.08238219956476843, 0.0676828645349991, 0.04317313395140152, 0.07870303166489448, 0.022041132906451825, 0.05300938497267423, 0.05907470608250268, 0.01633093568436321, 0.09204921793312797, 0.04713169794770018, 0.025132516015981956, 0.02678259279608967, 0.05773645773109409, 0.06884914913004445, 0.01938658653788509, 0.05604478620713758, 0.035760137778256214, 0.02207698199086853, 0.04762385581289569, 0.043869075034895254, 0.009828108464247517, 0.05118478187209657, 0.05621530588776354, 0.01774156785329744, 0.06260345261844416, 0.051230364103591254, 0.05625270630022692, 0.021686688921744787, 0.03347880454854139, 0.0696141415485932, 0.023464482134929108, 0.020288697203561183, 0.04232128248399785, 0.05831282398092651, 0.024805128341540698, 0.02362104752401431, 0.029409552338503064, 0.020013405423190807, 0.03160124370497802, 0.01865456654359737, 0.02675514003532308, 0.03091689927743808, 0.016144881655852643, 0.048370546390933376, 0.05120347441744901, 0.03311496258022324, 0.015137398469021485, 0.050971610246286284, 0.03506059225107874, 0.056906615969755, 0.008806175901554525, 0.09156248397043637, 0.046567650391690196, 0.016180100632951628, 0.062146477341171236, 0.013310116933538549, 0.018036820054534945, 0.02404126781790007, 0.016924921956454075, 0.11712971083339184, 0.01648529665544629, 0.014289759527591449, 0.02816421704577102, 0.06317418812203311, 0.06091394146243411, 0.019356061764542135, 0.029009081791305256, 0.008245663841315096, 0.022746087014374715, 0.00833390184843372, 0.028631540255681164, 0.17165675428846192, 0.06458394695073366, 0.14223842641278622, 0.13548992724428255, 0.1706331535693138, 0.12033755845961072, 0.0811690993366703, 0.11757237941867883, 0.18420305283319566, 0.15985737614814313, 0.0847917912347663, 0.11594495585849209, 0.1027879779857974, 0.21958773475020166, 0.15153387681611125, 0.08983407470007097, 0.0986547114688062, 0.15758758020256797, 0.1833711579562195, 0.17616038601244652, 0.09225683542148722, 0.16393054306747454, 0.11624345435730873, 0.12056307176188116, 0.10863653068701107, 0.09849961696853561, 0.1452174205933848, 0.11256167409761299, 0.1542440507440798, 0.2060100367112506, 0.09808591416766567, 0.16914222389459613, 0.18955494307221907, 0.18936130668847792, 0.214009863895274, 0.20104247746208023, 0.1373737834153637, 0.09683486960467794, 0.1687690471449206, 0.21086954691958046, 0.14683158317160222, 0.20354055228733248, 0.21572384773002518, 0.11791063021988639, 0.21928516066362783, 0.127484668496876, 0.14442176167522708, 0.18719879369581902, 0.11985801806252812, 0.19232514764993422, 0.2142548588134589, 0.1773578733686478, 0.10306952295884972, 0.16435733065009117, 0.07965717885282733, 0.09269075528267892, 0.09254339827044357, 0.13728534622538474, 0.10006036023579298, 0.11579047422856094, 0.18044172966432187, 0.0969109651181967, 0.1340625215802462, 0.10675692630390968, 0.21443544105897028, 0.18235319564419408, 0.3393798922338794, 0.14898056705151835, 0.14359363595083838, 0.0739050842821598, 0.1727992058881829, 0.21756731574573826, 0.1381495393692486, 0.1581818652489493, 0.11901588059000431, 0.20516308054568308, 0.16331994034830602, 0.25880300950619484, 0.25751705431649763, 0.15110338136794108, 0.05898260699224569, 0.13183148968363964, 0.09500505327577553, 0.1593644292123856, 0.12007908039395848, 0.12604952534480443, 0.2114749862061393, 0.08211103508309012, 0.13919993784398804, 0.12979112174962798, 0.20389235518392057, 0.10750270523731748, 0.146997379920175, 0.12602350899889586, 0.13039600945288135, 0.07964053942311196, 0.09594335776543426, 0.11593974646060698, 0.15200422415810247, 0.10114403756996317, 0.17596759232542208, 0.18437557583374364, 0.1584607212533874, 0.14581627152379484, 0.16466128369492872, 0.1590577182510207, 0.2112400270397625, 0.11893458333947968, 0.18216017213079239, 0.08766576242182525, 0.12090254830376757, 0.10389279934667772, 0.07329584519949651, 0.12755347085335564, 0.1541594899589977, 0.09899617983929573, 0.09387057665134631, 0.12347098064398575, 0.1683324076715977, 0.17061628431322115, 0.14209706786899798, 0.15051433636296183, 0.12786443360270033, 0.10882582335222153, 0.20386043996099504, 0.13902027490398577, 0.13400380860172934, 0.2083563188751859, 0.15778412772042139, 0.18702840041970054, 0.2235533888902395, 0.10877711548199577, 0.07816961996497647, 0.25990810665872793, 0.16169114549073482, 0.05365540776702185, 0.14923490824237948, 0.10107151202617154, 0.12375850110284745, 0.11209501929941679, 0.1157984875082489, 0.16953934855278463, 0.15671702852893263, 0.13479677089039357, 0.10858737848578923, 0.1305954834266055, 0.1363740233524192, 0.119109642091057, 0.09708197892553384, 0.15445621113383, 0.12630503098931045, 0.1461393308014639, 0.22058585538498818, 0.0877520009394615, 0.16523292318226832, 0.1657601602135166, 0.2097235406718908, 0.12656931600142873, 0.10748320063876529, 0.12746543202909733, 0.15510609884175564, 0.13392670951302976, 0.10607299364862904, 0.11583823214976058, 0.19139044377351963, 0.09639832972278518, 0.15972194712488882, 0.12161229812209645, 0.12350267370141323, 0.22118565626442435, 0.1535803887752756, 0.21156040500969658, 0.0965131586417556, 0.23672850772498116, 0.16198665624664677, 0.1401316999427734], [0.009913063784610602, 0.012319636110576892, 0.05019393141171144, 0.030169387070101597, 0.030287345458242684, 0.02441334714662404, 0.011417822303971457, 0.06358417922690993, 0.029789378731361324, 0.0917559594757134, 0.017226628448453643, 0.018036910069866047, 0.05393786821514369, 0.0021821167038363074, 0.06926875080793135, 0.03083648494324617, 0.0725141597250777, 0.05405351301775344, 0.021447359223759944, 0.11220948049618353, 0.0824834763883583, 0.03219035191221103, 0.07908791423805299, 0.005794491791617005, 0.020223750184560498, 0.04331584847081573, 0.04800238368672229, 0.054634858839093685, 0.07646616217830489, 0.02477752619362887, 0.10433400470402934, 0.027018653213857647, 0.03318031754104361, 0.060269044817335186, 0.026475761175876664, 0.049778432134659066, 0.005810144883129867, 0.04330150347443358, 0.09089159779250623, 0.018333698277391734, 0.027571454599139192, 0.0745020276536384, 0.05732575416444771, 0.036177778271056955, 0.04082201011178475, 0.022694322453331084, 0.05963168647741118, 0.05731137469410897, 0.048607290542173776, 0.03669463481093126, 0.05313061072581238, 0.09902054143528785, 0.03881283344761018, 0.02933683144229074, 0.0027170182053645655, 0.019415062026030595, 0.01700434229156423, 0.013909250358870674, 0.055122672985758514, 0.0531643875423939, 0.005605517531700072, 0.05116796241171899, 0.02520886816895537, 0.04918039325744875, 0.013985736577230838, 0.0538136279060235, 0.03627122567606069, 0.05890534319464238, 0.04629450940316723, 0.06174168414286068, 0.07069864625772161, 0.08153027148857232, 0.03215906488138341, 0.07439449189170715, 0.059126394034753886, 0.058150516762848825, 0.04077479228257172, 0.0843943678022873, 0.03714080441803221, 0.047721057048728394, 0.032634089190152385, 0.00600694568880323, 0.036122298183580565, 0.025360331412464864, 0.02015844501945521, 0.027476057500368165, 0.016965541853419235, 0.03863993889441894, 0.042346950259900866, 0.015002288329865665, 0.020196343389069362, 0.03220747780775832, 0.022353106891856562, 0.039392313844854795, 0.016966909320364078, 0.018118048357146404, 0.013740174753981975, 0.003414307843007508, 0.014780061544790385, 0.06902799235596772, 0.06433533609754617, 0.012573948573140849, 0.001834119827817044, 0.03014945537753163, 0.05053802363334164, 0.04425729775140363, 0.03533541480259549, 0.039799106532647725, 0.05304768170800902, 0.09643564586557689, 0.07089932298948688, 0.007288496351740774, 0.024002082420573122, 0.05814952084854726, 0.04764154478306732, 0.02951356218076281, 0.01631294410946148, 0.047470124949130325, 0.054423050849788615, 0.07998219931558256, 0.04455743184793861, 0.049870106046118086, 0.017221001532649802, 0.05161943717769558, 0.02901264410015316, 0.0641813179508092, 0.040367279472129966, 0.050246216912543586, 0.014878405209240175, 0.03657475737253985, 0.09427350825600087, 0.06110081712024347, 0.01314006265132658, 0.046317289027595715, 0.04715158175977488, 0.04313702822753018, 0.03139643775930088, 0.017885506198170687, 0.013689697220651133, 0.028551110599730766, 0.05799226981076983, 0.021493332160096017, 0.09893604193723972, 0.017579233822142406, 0.05715782769144543, 0.050067967404761625, 0.034492944081824635, 0.06879579110611832, 0.03480233635092455, 0.04371181633623858, 0.05282625165437499, 0.021690777916040634, 0.015016256985555013, 0.017484976279158747, 0.06371733296902911, 0.03793479326451498, 0.08693684508363086, 0.03277203098179833, 0.019121686740207578, 0.029322225976014332, 0.03934254877329354, 0.030044913104164506, 0.02285347338916073, 0.08790861229382216, 0.015010408861863037, 0.038424013182520866, 0.07734010762144482, 0.029087308944473346, 0.04510775876922473, 0.008437487469505399, 0.05007738262535103, 0.0227441871163225, 0.05395790907524286, 0.012490648002694211, 0.0212254963304487, 0.057815429904768546, 0.007548017254579933, 0.039919930089625626, 0.04166635774797009, 0.06736145234636723, 0.023332263020077543, 0.02599194026251714, 0.05542268833866524, 0.09666737980179249, 0.008399474186702602, 0.05837312276144663, 0.029413003564601945, 0.05002509712451889, 0.08626602785361391, 0.021873252398725, 0.03364769246188864, 0.009879268773440874, 0.04035281956255917, 0.0031981546987569142, 0.013177483173597966, 0.028408229456193028, 0.17605463523537884, 0.028142354811631867, 0.050076133902034456, 0.05041934129211211, 0.03056356037456182, 0.03198822344382925, 0.05278643040407089, 0.055494191155077956, 0.017278364281200113, 0.06604019582511918, 0.014588531902841022, 0.04985493367477771, 0.028035341904708938, 0.06343170857778, 0.020663189709246643, 0.02585101455840613, 0.03330872153803226, 0.04874198795146039, 0.046105737677745284, 0.0032119066952051778, 0.015805670371910018, 0.00868406340164403, 0.06722962393635704, 0.040856840299262155, 0.03778534483224635, 0.07078711409121752, 0.07682856773176501, 0.053111424053748774, 0.04626942768452629, 0.03629451091851919, 0.032834344573559306, 0.050068702849168936, 0.03968120177066134, 0.05672285062891822, 0.06736584203017336, 0.008690455447762244, 0.03275783537256141, 0.017426985338510528, 0.08576922749559726, 0.01857300116229923, 0.03283731699470551, 0.02153756990728359, 0.010644599228286216, 0.062167943124809576, 0.03139998091595068, 0.08896761393595128, 0.06750257340289893, 0.0644589597058873, 0.019488097018291874, 0.03805516482961755, 0.04306285559470135, 0.07174232614136512, 0.03853361738184768, 0.028385989923751163, 0.02095978639479126, 0.1398410308625429, 0.013788372218128175, 0.022130860954583175, 0.05873016186899716, 0.11975327852152048, 0.0538377711669572, 0.019422862716319583, 0.039376088102618535, 0.021455552534110123, 0.0687242691375075, 0.02733135689801026, 0.049998827969595316, 0.0587841289328231, 0.0277822322001861, 0.03137204168935216, 0.029812213897164312, 0.030820956341021007, 0.07623938483095939, 0.02331698339642777, 0.03332140412361872, 0.05548311352369286, 0.02338057635502229, 0.01769541680151897, 0.04308641279837297, 0.025582667365069353, 0.046895961202080214, 0.09265990492196814, 0.033519081621160435, 0.048125693199014476, 0.03478677710518241, 0.024752547896857706, 0.01203698797091361, 0.04677881486713887, 0.07227652691184513, 0.0190671221278007, 0.03910868128220882, 0.05383770604948363, 0.0519398381302674, 0.042060532967650124, 0.03358599174046709, 0.05224215174694696, 0.08077183678265541, 0.04120610361438125, 0.011714143197863333, 0.0792871124201244, 0.011689131384745482, 0.021539125065769882, 0.04280021001074103, 0.009901598321213838, 0.02637282960237034, 0.032925635441056186, 0.030362764899168285, 0.019954778629565434, 0.026621003785441, 0.03924283093862957, 0.05561242533487178, 0.04232757206585619, 0.0038421085769040214, 0.06303535383795539, 0.07839219148961768, 0.023048620881332506, 0.019539769648784594, 0.016306512801337148, 0.04919524387186093, 0.08751044575605663, 0.04973432462241861, 0.00946213485628006, 0.029836615712772456, 0.014602020795967792, 0.008507561531939335, 0.05894445964405614, 0.03824833389972487, 0.050017577971542077, 0.012208799467301898, 0.032673994710128156, 0.012774266201191613, 0.10835629572430927, 0.05992293012358489, 0.017554621332355084, 0.013600589703738451, 0.03300341634800838, 0.012364832425279724, 0.02697906370515064, 0.05583821825923459, 0.032589755681974274, 0.010757667102640676, 0.06880892185314048, 0.020417097370110212, 0.010185968243486939, 0.035127820296873974, 0.05183721299193079, 0.06211010731696602, 0.05228805956580947, 0.009798115164402032, 0.061744863407746445, 0.09288683548689851, 0.027159052232520717, 0.019475830035404335, 0.04494358229661181, 0.0069036022872634, 0.051629426964228196, 0.09919201489537956, 0.1802809431307739, 0.12905831268477824, 0.23365035112346375, 0.1447387228930189, 0.1403890441982977, 0.127731938696196, 0.18578148507062467, 0.06110146829497911, 0.1737152938280375, 0.11722041564362666, 0.18846265490977995, 0.11156490943845242, 0.0998512871803776, 0.14134080119190678, 0.1681745169504035, 0.09494293120599563, 0.10021874125325873, 0.1705672546860672, 0.16131695750499928, 0.2163143329803021, 0.10192338647621293, 0.14905009719152607, 0.09608273980237785, 0.07883911186288442, 0.2055301898789983, 0.1369160458806061, 0.2209734958746741, 0.21724393471114098, 0.1635408801056685, 0.17208099845916996, 0.17337988521302902, 0.165568117292658, 0.19422844713253362, 0.21629815320334128, 0.15218578699615695, 0.1579874627772839, 0.1715635979968694, 0.13841318086751048, 0.1193302064653366, 0.08980719267480797, 0.11733009645174589, 0.2247056157718743, 0.13478756251354373, 0.16267972066998482, 0.27758898694188366, 0.19504146560305552, 0.1571086526758248, 0.16939111053943637, 0.16457393434980225, 0.11687783644564691, 0.19077214953159133, 0.1669926884313745, 0.15182471443568507, 0.10502736790165787, 0.08324289934769755, 0.14453721112541615, 0.10021414472571305, 0.2255075872545281, 0.12791871859301485, 0.05771943142697696, 0.07284153207776047, 0.09230032623294862, 0.08292737071432414, 0.11982625605718744, 0.1320920821519629, 0.19321918757932802, 0.21218776973264836, 0.19282060735408338, 0.10614519743549247, 0.1364373635019987, 0.20570472002990786, 0.09659472402305373, 0.18039193394924366, 0.12488862634786677, 0.3210049362913255, 0.09948001798963356, 0.21355782605467305, 0.08975360482450455, 0.15905989394072564, 0.1209774180766075, 0.1714508604979323, 0.24269901396286106, 0.09827868487205237, 0.18760865073530905, 0.07326996674941433, 0.1515984427063696, 0.1360962092275581, 0.0911975120224299, 0.1378720776448327, 0.08579875252419904, 0.14847995923651805, 0.19147186359811216, 0.1830675266683102, 0.1187682886337561, 0.15156125679852503, 0.11453071924587412, 0.10219436709678943, 0.13058253654068516, 0.21019877565483894, 0.13210493710733232, 0.18912916672566246, 0.09740075577170619, 0.16628215720336284, 0.08381918898873753, 0.24125593413989393, 0.13844641376166575, 0.234107383857331, 0.2190997214206765, 0.2816613571297738, 0.14651829917584697, 0.17566555450039525, 0.15918024635363012, 0.17810778151596748, 0.16952195835690345, 0.1476487691604322, 0.14907789086141895, 0.1501994282608071, 0.1130808595447771, 0.19083676138712516, 0.08147526637560899, 0.13243507503742172, 0.2029132182078977, 0.12334410116196641, 0.18847408494161022, 0.12527791392658988, 0.1752098241159993, 0.18309896691672264, 0.07578805945212803, 0.13396404863845918, 0.18836300219258956, 0.1881952442589306, 0.1284351154801346, 0.15992886747323698, 0.12554438228929235, 0.17752849647114355, 0.18360803234240702, 0.033342912042092894, 0.13375378814676117, 0.14790818185335206, 0.26431320415389153, 0.13862561704891344, 0.19498157284913525, 0.10377935704685028, 0.14999958656487927, 0.12200615924572754, 0.1312230320106591, 0.18954440170238096, 0.08734852541238071, 0.11175518269620596, 0.13260473286913288, 0.2606024581097788, 0.14419532140656827, 0.06199204933739478, 0.14058810448454273, 0.11385383459949687, 0.27537824105351205, 0.12888658641567155, 0.1428476654954495, 0.09635119999368345, 0.12058839096777862, 0.1734367749022861, 0.1435091824180657, 0.10820461797618097, 0.11118391859194926, 0.1283516502007842, 0.10966781526803972, 0.16042838744338483, 0.21357700889629705, 0.08857369918616549, 0.22243042656731224, 0.11882107975261828, 0.25660216147380494, 0.1445761283919696, 0.11034158959744439, 0.12413809766932843], [0.058883743345617294, 0.0624229469817252, 0.029176293887318145, 0.05694991142879571, 0.0584576107681759, 0.011208517506958978, 0.006510704040392152, 0.053937960145694595, 0.015602229977957906, 0.05812713575939979, 0.03929106383434227, 0.0834258564657742, 0.03656536130414855, 0.01611526852713958, 0.013493725226350851, 0.04326347870031192, 0.05571441462023124, 0.08611174540654307, 0.02665045029003053, 0.008323361436205526, 0.04019868267219394, 0.033763651360547355, 0.018921084702014923, 0.06742672303751593, 0.14662385077005433, 0.029448887122975245, 0.02616649531128426, 0.010338530823167776, 0.04772175418873949, 0.07252195850014687, 0.018468705952287685, 0.016867082318170898, 0.05504114590885659, 0.04516626107356241, 0.039018960894956704, 0.06317876549738069, 0.04538114107544384, 0.0837039080778918, 0.018050446843488083, 0.012685605888104728, 0.03222807791204222, 0.04621130076327151, 0.024997969909060388, 0.026846503681172768, 0.038157609937291954, 0.05591473512111172, 0.016507222091839198, 0.023420470383679195, 0.12064891957467604, 0.020914169689339977, 0.0758947371955841, 0.027156949321168567, 0.019379387226616664, 0.07462523757450043, 0.022086523615965442, 0.038280268274848504, 0.06855328597368733, 0.03754794567583069, 0.042881346382801576, 0.007187983700855365, 0.021678348139469183, 0.03881405918828903, 0.014150188841496505, 0.027991883651984316, 0.0677312583091759, 0.040481380607572295, 0.10983306809418625, 0.0532508482255282, 0.04096542943208929, 0.07220079912053001, 0.027309521476948456, 0.04836609158965369, 0.053058977674452536, 0.055843377861404614, 0.018257110552381606, 0.044174809234156724, 0.030089713925976428, 0.021053708774308046, 0.0607799603453567, 0.016272942828495177, 0.06881244585759218, 0.04626695705097049, 0.05119389065751626, 0.01573506962402814, 0.06473465176719813, 0.03585971388665419, 0.04223350029919417, 0.05346929819713678, 0.020264733973289692, 0.028657460840599194, 0.05159834677714014, 0.020803985178410526, 0.04781331701744949, 0.04949415222771707, 0.03624547746092562, 0.04209613690393106, 0.028263647597463384, 0.014930506848970489, 0.055682384484117074, 0.03932828804658305, 0.020252474651281393, 0.02545355282153093, 0.07037737962579535, 0.06349850378389801, 0.013290778001499994, 0.028412818322859468, 0.076380597818042, 0.03975142138980089, 0.035443751126407616, 0.023293782423640934, 0.025488706681156353, 0.029799358941794887, 0.046004889863393, 0.01605928377924307, 0.019680333376351385, 0.06663964430411017, 0.049603162708902554, 0.06956944797909068, 0.06340203033159338, 0.015971899960160015, 0.03112814802255842, 0.056655040356300534, 0.07296311023134379, 0.037371504135550036, 0.03882743891388659, 0.06626267541920947, 0.05792507240849157, 0.04464730545277557, 0.026011527215521184, 0.020312206526737542, 0.03467521938164869, 0.02222661428423899, 0.055526286408665686, 0.0374903358639248, 0.00570654729193437, 0.06301502952532423, 0.012658143551239084, 0.041886267117074424, 0.03524385197388549, 0.03027152382738648, 0.03982115454310852, 0.09599938943621614, 0.0064337284833703556, 0.0498734193763906, 0.043259648260690516, 0.02072737830120229, 0.0048821725255449215, 0.006594785541716603, 0.0332299638689766, 0.03366514394480375, 0.08944418957276691, 0.03686842185655429, 0.05135397239017391, 0.0423953861689135, 0.037213088644127694, 0.0154618606452019, 0.037556916565424016, 0.037969960530679074, 0.0455173323561828, 0.08703134202909085, 0.027523055079302965, 0.02750356388728946, 0.0388214634280772, 0.12129771943774917, 0.042943656144122926, 0.02561808744024846, 0.06836846726195467, 0.03157508371758365, 0.04318584718050496, 0.0239080106539111, 0.04198274056937906, 0.0964036999991344, 0.08557089499288029, 0.031092999908592434, 0.010684420478590315, 0.01713462703440699, 0.06512094394213731, 0.02834787130385878, 0.07526235459672828, 0.06017305016998322, 0.08746681704876885, 0.023043997540709474, 0.03975361623170395, 0.009643509045183178, 0.0479134715222303, 0.02375125565806464, 0.023751081373061866, 0.031187711358671228, 0.07440021456850153, 0.04801700064431756, 0.03190563533515219, 0.04365920907847824, 0.09548060235477264, 0.02175201323904818, 0.09597273723733041, 0.008102559574669408, 0.012399712408472215, 0.03446198263836484, 0.05834006606751393, 0.038915316859680804, 0.03271964205909641, 0.006363045859841571, 0.028869726567439018, 0.005534007054408111, 0.016416283624787486, 0.037695999828077136, 0.04982251666426178, 0.04888094864004562, 0.04994564614589176, 0.020821109158738006, 0.047785082847000136, 0.056504481096541694, 0.037952861448209134, 0.039463870287422216, 0.036881004850710594, 0.029392108516467196, 0.031702039808395414, 0.057489402036392884, 0.019181138993571364, 0.05501567348537426, 0.04125825888026626, 0.03414591774344444, 0.01944449703930126, 0.00818110369671617, 0.05352673180882008, 0.04150441825209607, 0.025022344911591183, 0.01793894083088925, 0.03129246047577791, 0.003170732102702342, 0.061189112583956415, 0.04911610698928276, 0.04458824390425317, 0.007643641306898527, 0.06106119505279969, 0.040824745045674425, 0.014665051637547872, 0.042725907142965064, 0.04718081950540504, 0.03397456685742063, 0.06335215800772272, 0.06996314056337842, 0.037231038084193584, 0.0355869252985764, 0.021460168213853915, 0.02452656153529402, 0.06435186827495214, 0.028437645317265586, 0.03322607214232126, 0.01222751116485245, 0.03941438866839294, 0.028958927930122422, 0.10165104221913124, 0.022569932757065665, 0.07166918772723406, 0.07443399904596229, 0.052863311157712055, 0.019702302862799937, 0.02205849820447545, 0.037090920602842685, 0.02059848017750248, 0.03624222924812667, 0.04025071919445069, 0.061215228521295136, 0.0927546623373224, 0.004769375654793675, 0.0622524043184615, 0.028100306160687923, 0.10073897624087912, 0.037447136165874625, 0.03445151404687955, 0.03258096099260353, 0.020677103781171387, 0.10249167815932345, 0.05621390777730173, 0.014625100152296646, 0.02884542434326103, 0.05007491199179523, 0.04897499359363029, 0.020610090239994952, 0.04559320953464316, 0.004275962841817208, 0.02813108948870532, 0.03821485585743382, 0.025069802143280546, 0.03014677406979665, 0.04848585794529608, 0.011303093934041119, 0.03279636959515272, 0.025622885065874266, 0.026029072544207017, 0.026324740348143444, 0.0747114607703782, 0.09120982305537309, 0.05082319603271542, 0.008880390669219196, 0.04970381900127377, 0.008369429175922228, 0.08582738889080864, 0.005367264666053797, 0.014684850222340997, 0.03015004526523333, 0.02992403209059229, 0.05577351064271024, 0.06163686033218138, 0.04273347609165696, 0.06582312481177431, 0.027792216241059285, 0.07008595211851983, 0.03598186660618071, 0.028684605250976263, 0.042934355836722164, 0.026210422792862502, 0.0036327712211547602, 0.03811624118938081, 0.04081804943721622, 0.05482517040124344, 0.01025670018392585, 0.056267671827827735, 0.061670020447983864, 0.004795566285705014, 0.01928633627211375, 0.036976045718596834, 0.05818609771649203, 0.04591913781158867, 0.03951570762681865, 0.04504192500345169, 0.027364342728809967, 0.05625307402243057, 0.025852010472707694, 0.08565210797373327, 0.026566186364019112, 0.02510561866896047, 0.030754601635459452, 0.022800113450014786, 0.07074634289188732, 0.07772009489276717, 0.060375282060234785, 0.04922618999356224, 0.004968112268890705, 0.05916837565300446, 0.021935705801532156, 0.052174640248619744, 0.024542005867847515, 0.04764930142330066, 0.0454635683056568, 0.07382345761382773, 0.041676255603951794, 0.05603129922923061, 0.025677137497452, 0.08039249302518946, 0.058244994556110714, 0.18513722044806327, 0.12462865441076218, 0.12464031426896974, 0.09940248989169637, 0.14179974914558474, 0.0817936601778192, 0.13191827212370213, 0.14112865612391504, 0.19906063864548362, 0.16961491546563565, 0.09802000762353982, 0.20338483725584325, 0.22786140772363833, 0.09085001453997628, 0.14305109248286293, 0.08491919165657413, 0.1868379816052414, 0.14339135809531137, 0.16280425592295586, 0.15950826988104852, 0.11069777451695935, 0.08706907952024091, 0.14672932575546926, 0.11401415381941105, 0.16408069630063352, 0.13585933484137058, 0.10370629524151165, 0.06626046908598754, 0.1644055482240454, 0.18783119927731254, 0.14649045954067863, 0.11792957557425385, 0.2628420395476203, 0.15802693162714282, 0.18743199085996998, 0.1763097731576812, 0.09412313285734385, 0.14345567883743396, 0.15082149165532283, 0.08362989632352706, 0.12263140956600829, 0.16933150889892734, 0.044583884863964016, 0.18932304825753937, 0.16194462866312073, 0.16058949573386103, 0.10415177536948074, 0.12293739274384514, 0.20508570566533074, 0.13971271113522593, 0.2517119771049869, 0.04661417874177137, 0.12659550088668062, 0.08928255268162297, 0.23039882882468163, 0.20465887211743863, 0.16627307140058087, 0.18557620415043447, 0.12338646582417911, 0.11659683539502083, 0.07788242126304297, 0.09982208390870403, 0.18367382397334422, 0.0963770707828864, 0.12351977278388317, 0.19685963739550885, 0.21330284134995556, 0.08455244238458334, 0.11216681705968035, 0.17701435954340045, 0.2600904355847067, 0.12086912388763121, 0.1378632369901865, 0.11547506050837618, 0.08744687578009983, 0.13291884423984637, 0.1995934527968207, 0.060431907449157975, 0.12226971647431775, 0.16971511976613154, 0.17389797515446143, 0.13816915122011017, 0.17402284748611913, 0.15349169111540242, 0.17344057469839053, 0.1836566329603234, 0.1136336149647832, 0.09286238962123472, 0.13071946709627105, 0.09409618188416767, 0.19891497468756092, 0.11422835200303987, 0.243353865920536, 0.15904596646226224, 0.10877935245873467, 0.21155504239422662, 0.16769226460206896, 0.13115097378050128, 0.126813659744878, 0.14824392754704724, 0.05807837043257971, 0.1574473248253907, 0.1608822792167625, 0.19198515782913855, 0.1868174198053537, 0.10834123443571791, 0.11965371007400176, 0.10402494185273686, 0.1843441968723651, 0.12101062032724581, 0.15465695681350847, 0.10427482441187867, 0.17560308769104943, 0.1277310423733246, 0.17051016581394982, 0.22620569253640793, 0.22563815928034245, 0.18605819602887477, 0.165050670865082, 0.08242844829275724, 0.14162770111954984, 0.11386415380383692, 0.21269554813061992, 0.07951567475233348, 0.1150547310469612, 0.184876658623257, 0.12796348111043054, 0.13168394114942322, 0.19310386070320684, 0.06630304059193981, 0.1259076152177107, 0.07588821778734846, 0.1888124812995234, 0.11356374774608882, 0.11145024905882536, 0.1534159250196911, 0.145244877184591, 0.0995111671246348, 0.16382318350576586, 0.12929627491581824, 0.18299540715111842, 0.29752182864373733, 0.0829974677593958, 0.1399156631481263, 0.17979450794237276, 0.09765701984325725, 0.12441556705462357, 0.1160672311520865, 0.13715969248404428, 0.15590771792396424, 0.2029087289326614, 0.1359024502697491, 0.17678323081664502, 0.1369559743832196, 0.14213776245953577, 0.0763708608405244, 0.08611486338439488, 0.10474940055921193, 0.10352957407913863, 0.17141298511095587, 0.12357369771287327, 0.08839832633853921, 0.20045557750328896, 0.20349973512272682, 0.08052357066903384, 0.1297666222578095, 0.1860673431186907, 0.1591205221390532, 0.1439255971701876, 0.14840613900413438, 0.10851174262502503, 0.14568243596342303, 0.14613632773680074, 0.06767179456449325, 0.14909354969859123, 0.15800073142013243], [0.01383397551704078, 0.05180646988352941, 0.017230516344669367, 0.07595650686491882, 0.040769521597652666, 0.0366074463442689, 0.04407356305408382, 0.03264316733205511, 0.04577016818427271, 0.04850913935731496, 0.046775218084334366, 0.01563507982815105, 0.07361481356764994, 0.061866885892325835, 0.006961763682474773, 0.06530922537128772, 0.05512461884908619, 0.058538532635617646, 0.05224965940860491, 0.08243807801796545, 0.04530194290583173, 0.0442010247629256, 0.0087241479946721, 0.02467248213267134, 0.03168221919857447, 0.037808473026680375, 0.08640725616245501, 0.02739606068409499, 0.024136465733810782, 0.017303064871098728, 0.06274908976328951, 0.02297444441806405, 0.030405349811659228, 0.04364741132444432, 0.061153252008220846, 0.058088475132300976, 0.1100137652528863, 0.034990066196769476, 0.0686327446131937, 0.06307951114591091, 0.005605515137675309, 0.06630655693551225, 0.032083195363802296, 0.11790058680719907, 0.013058294256728505, 0.054154847297937646, 0.028572040121822108, 0.029971414628709038, 0.06431299697367415, 0.03233099799422968, 0.05612871496968212, 0.02273145473502096, 0.06304555046822756, 0.0022693058887060975, 0.033302546869362556, 0.007111617662538324, 0.021464540660681746, 0.08268190848250544, 0.020664005592886, 0.00818424657242553, 0.05995921204767882, 0.021491600801387144, 0.012732136153405713, 0.018184818665406877, 0.00698563977024488, 0.019096436482223294, 0.06579666413486966, 0.01378498706711276, 0.03397350199520588, 0.04913221015745113, 0.05573024199674687, 0.018978930085957534, 0.013859466135111308, 0.025555185876005602, 0.04037431598971448, 0.020051229099232345, 0.043230372210664135, 0.03292292732024386, 0.046929286026786414, 0.005589962116397557, 0.011724704677509445, 0.013463793213539308, 0.05710207564275592, 0.01721550102135347, 0.025881817038621635, 0.07174505341437555, 0.02648598461922619, 0.019528902691578674, 0.04847677980339335, 0.04081560944717738, 0.06178877173712658, 0.027317335573776115, 0.025784765189934163, 0.09666119747224355, 0.042843470995825146, 0.009732292889947853, 0.026903048630863912, 0.053162694488081245, 0.066211799520158, 0.010789210772922924, 0.08174577968255167, 0.04516237700778631, 0.007645147627279644, 0.05722599036450829, 0.11382345921329914, 0.053842704773189566, 0.015649638371542096, 0.021150486746562586, 0.013826500414119614, 0.03320878153787025, 0.05315330225012956, 0.047239076661606955, 0.023265973431989554, 0.05465318366224247, 0.015322718010734648, 0.034282951720900116, 0.02019245357763383, 0.051410605439976345, 0.012457411278099304, 0.05464484096474705, 0.008489756690969151, 0.04443858862824498, 0.01173172300050576, 0.04779380092757845, 0.08088862688671197, 0.03090089378548005, 0.017593105759231314, 0.038970858234191136, 0.04710309988548679, 0.06539221567612502, 0.086037281660303, 0.03580380095950058, 0.051405035980766824, 0.050834729486415466, 0.040685240434662956, 0.02642037876461062, 0.026968581707126675, 0.026642126744733225, 0.08295304232066678, 0.0495220608107986, 0.04844964879955496, 0.05976047351836197, 0.03839289852147622, 0.056611737236380584, 0.029757450101897124, 0.05000723961500391, 0.06151626277114115, 0.01767088283574389, 0.0625740003681952, 0.020695104932172165, 0.01677056481581061, 0.025540963453691334, 0.043523125050048676, 0.004646625386686215, 0.004068266829445718, 0.015068684212653147, 0.0031407172566339857, 0.05042799808565648, 0.029899431092123833, 0.038765113830806754, 0.03584547997302106, 0.013050531870835732, 0.06038535228599945, 0.028095918392101606, 0.05277072943206276, 0.05149234319105745, 0.032607812374349565, 0.03715812949643981, 0.0539105418588846, 0.005325455896391143, 0.042640063160609816, 0.006883958835274943, 0.03927155157491084, 0.04494005063128087, 0.10722188038691398, 0.02512054014650564, 0.02084439631641632, 0.015590715676455971, 0.037246681599607395, 0.03836564494356994, 0.0841615230385815, 0.015967799474545304, 0.04401756202681892, 0.0305954679366081, 0.043176393655519334, 0.005550626374315471, 0.0060464006533185325, 0.03893579822033644, 0.020995093472001534, 0.05562661711366908, 0.02107562846504152, 0.06814619451160393, 0.11174346155096447, 0.07489355220910042, 0.028301431053888895, 0.020910668667526017, 0.010340475728885542, 0.03272920283639143, 0.039415453530607686, 0.04063490079715848, 0.02353416740774147, 0.058336848498231945, 0.03602887759165418, 0.018242949417101282, 0.0010056603763763223, 0.03847449454629133, 0.0262744945564097, 0.022503782980023854, 0.0423783483734775, 0.07236137881033844, 0.039638358303495956, 0.0504435190270024, 0.0683064064792087, 0.06358704439574672, 0.09036598486765739, 0.037878102758118225, 0.06569080610549258, 0.05568124684354952, 0.0109133955406686, 0.14983918307529343, 0.04556028690609721, 0.04222794999218276, 0.044275802605214624, 0.02661217845255329, 0.06169144792722599, 0.016284309658071688, 0.08992799707958776, 0.04064054303472081, 0.020044736504074068, 0.006728449211110391, 0.06745892171297344, 0.07982562626561812, 0.007493481370470217, 0.03902358423557974, 0.05910300537042561, 0.01705204850182899, 0.03959879369264649, 0.04527267451668459, 0.0322894798591733, 0.05164948697652548, 0.019026458180779894, 0.04149066314341561, 0.07030916715701742, 0.03238640147291365, 0.07517954049211356, 0.03140498538531604, 0.056264768354594714, 0.07973269213952365, 0.040530892870118546, 0.03543352002217885, 0.044174410868436105, 0.043609375059003794, 0.07152412897877156, 0.05697870101299017, 0.03479109401063573, 0.03429283808556295, 0.021564938398378513, 0.066638219380571, 0.03249921941108281, 0.02222229546356586, 0.030889021337873517, 0.0564586115820754, 0.01906239536530789, 0.08017396644478844, 0.032268569489280065, 0.026480380686060078, 0.06298946900173061, 0.04029707134430928, 0.02288206953615431, 0.025086656077614716, 0.0283726446721102, 0.0051717992473934455, 0.02582902591975947, 0.04640415573732988, 0.041217817098743496, 0.028774210725039728, 0.035220945944949504, 0.04973419438747149, 0.011867648065691034, 0.04683452861143216, 0.028961689677089456, 0.010736818977391288, 0.05974931927818445, 0.011962253221070335, 0.011414239885315541, 0.07463582490961398, 0.08375533556024875, 0.033359172258285746, 0.06273285252973437, 0.11615056619648972, 0.005073149147773943, 0.06607656967976401, 0.062467020020009055, 0.01733863624864288, 0.025870235704426325, 0.06557896492942687, 0.05916023213836936, 0.031137224249241334, 0.013546126597981541, 0.047753014406489755, 0.040401699802567886, 0.048442991495492964, 0.007740976608117983, 0.02420578711485911, 0.0396655161204117, 0.02436699116632583, 0.05568545266625382, 0.08473993474317175, 0.0419940748402188, 0.030744347548592958, 0.04352638858460611, 0.01731683530153767, 0.03333682547353449, 0.026113920612260703, 0.05763780475864488, 0.05278593627735973, 0.01983914723349435, 0.00889160045077123, 0.01624025577198594, 0.10002234695299018, 0.01725958363573638, 0.02699717210846082, 0.020546305759419358, 0.02408365929319013, 0.014443079576707415, 0.006869575055691624, 0.0795862850763144, 0.03616056427539837, 0.05060571516233106, 0.0035021944072908696, 0.03401239244868198, 0.04383943126266522, 0.032880306018576506, 0.013961103977635505, 0.020472502764013988, 0.06498877845344044, 0.021486872123674523, 0.0182848142069434, 0.04651957071356235, 0.00945499204399605, 0.04755158307811907, 0.04230370076613561, 0.045074502892431714, 0.01865378321869479, 0.03332775116207139, 0.017201452884041978, 0.04888601631166474, 0.02299998578945956, 0.055876564790284446, 0.037975579785603675, 0.03786178508533105, 0.05195302250344427, 0.11285691672275144, 0.16518020101131933, 0.11844748931546366, 0.11629047683410107, 0.17780460988081273, 0.13847336473484195, 0.24369471375980686, 0.09999476012683685, 0.10086621578422286, 0.11212175576797417, 0.21675339329146573, 0.10028215801163066, 0.2048297097245532, 0.17741016653035918, 0.11088609425050598, 0.16848027796274231, 0.15359525088100665, 0.1690086028388431, 0.11881320436875667, 0.21957621278782047, 0.09434024983596417, 0.14993309013305173, 0.089579044030078, 0.1770234606679409, 0.12980800632747913, 0.1835505604263275, 0.2026426819183173, 0.2833601111365903, 0.043331760117003036, 0.08350219712742875, 0.163352437798054, 0.0939681149658657, 0.09566173618358952, 0.12411796487867834, 0.13372896689801447, 0.09153276741985353, 0.29993941827166465, 0.144894591142093, 0.20262003635927556, 0.19240060731047587, 0.12352348064943669, 0.1674935107509936, 0.20809279995099192, 0.37228866991016174, 0.1034253171735233, 0.14702221649068017, 0.14779455569242278, 0.14255521909123467, 0.1801873578299438, 0.12711811074686627, 0.15763581309828067, 0.11091780262969195, 0.13945481529639614, 0.15304225797374404, 0.11152577766728018, 0.10471072077991501, 0.11206560918400366, 0.17262600873026157, 0.1644936943006131, 0.0629562322771357, 0.22424300591791832, 0.11760325276202734, 0.11848069922698122, 0.10929004199081853, 0.22618237281999282, 0.14944941286117802, 0.16899142714758075, 0.09538356965828328, 0.16690566084317623, 0.14453250734556106, 0.20447036852279019, 0.21298686072470682, 0.16649059440580108, 0.17900597364191087, 0.12692200756000896, 0.1546330855137879, 0.15924367843376053, 0.19992440278010987, 0.1645590722440712, 0.11638702689519814, 0.1839449424897471, 0.12946035562744065, 0.15351723248679794, 0.10491461508096227, 0.1016847730704373, 0.12388656802114942, 0.19239378912794977, 0.16296498116946992, 0.1539325900375843, 0.15488773313981874, 0.19582028590863754, 0.1541172172273359, 0.07806795243654521, 0.20236889741593794, 0.21971167245459175, 0.07887140246889285, 0.12502224740361975, 0.16760419513429367, 0.18600374249921692, 0.1753030876599012, 0.2145671162513956, 0.18313310379462858, 0.08205345591470119, 0.14932521468689366, 0.16291426614888255, 0.08513193427314682, 0.15345343268446385, 0.169485722398085, 0.13282198008270035, 0.1721566573025719, 0.16212000151074704, 0.09653647069729145, 0.15624991407798183, 0.21790421057131984, 0.13597233281020196, 0.1544071661849176, 0.11802898314330848, 0.19092651624833384, 0.15830689079819188, 0.15132219140087405, 0.10100684654448303, 0.1859175269642184, 0.08577666620934203, 0.13489145935783464, 0.1858332113272721, 0.14776593464757168, 0.08159128273086202, 0.1026591909448466, 0.12305065884345001, 0.23618981001838563, 0.09911526820712513, 0.213577070183331, 0.13380298631325846, 0.10203308260609066, 0.13553072908712974, 0.12341605980069408, 0.1361769395730188, 0.07726907594910554, 0.19622047491852315, 0.1484243259314568, 0.10599955646020752, 0.1706657276278542, 0.07918212007010177, 0.1339336809131407, 0.13164989620206818, 0.167083194058749, 0.09157423575919482, 0.13546587208346014, 0.19193448877382666, 0.09571095733272453, 0.20367823360908419, 0.11689189415905746, 0.11135549164347111, 0.11058425560833947, 0.12039699156077639, 0.11565533631871786, 0.1588123096453567, 0.13528792518040827, 0.19254991784691813, 0.12662353204383006, 0.10586960496561182, 0.1011259119296747, 0.08437544543055758, 0.07998496489298922, 0.17184282172351115, 0.13307477377595442, 0.09952363137516285, 0.12100030112290576, 0.1478368131023261, 0.16517465453474753, 0.18288930397360556, 0.10934006753227404, 0.19799012270185257, 0.13377529989567497, 0.20129035287086042, 0.13737583653100077], [0.06533708032821456, 0.026031633193093925, 0.04880171216603729, 0.04165441826767018, 0.05572060078021981, 0.022214255370800535, 0.021393418973011356, 0.05475013208906016, 0.08138875972719924, 0.1340030118702881, 0.012176100919473798, 0.07096843944201547, 0.0051381411744401825, 0.007360160525422544, 0.05101598971973985, 0.054363537309390884, 0.03424915575212048, 0.03985081363709704, 0.04463054344899232, 0.045027311876296036, 0.08638269538360258, 0.037446511804216334, 0.024297677446156744, 0.040409636473463434, 0.03610858520973594, 0.028710857168921543, 0.0662554512100835, 0.05071996185447901, 0.03509210144740439, 0.0295876371373813, 0.01838501084656004, 0.03343978386011816, 0.04426911465763565, 0.02582054149599806, 0.046073286193272764, 0.014316936496705299, 0.018598036915664713, 0.07466559508635152, 0.014011917632043123, 0.0280711833282464, 0.028928862809534037, 0.015269314979142962, 0.06450854857722599, 0.034154436641162446, 0.0313060432146754, 0.029705091822712176, 0.03827688982710242, 0.06632719534419237, 0.017564011655086954, 0.009534404718226964, 0.017462190909070835, 0.06849275736678993, 0.056727397360748825, 0.049919242925581434, 0.047091099118152936, 0.04276881572760401, 0.07838982427793165, 0.03270900109782815, 0.03735936164195019, 0.019906928777814876, 0.011502552586006782, 0.020716838846584002, 0.025691771692025567, 0.011677878510747707, 0.06664201151579618, 0.048879370498921604, 0.07347419046826902, 0.05022208514292875, 0.044138615410174095, 0.07190249214369444, 0.10443137447920539, 0.019358635819967718, 0.016451433653973283, 0.031325143701847524, 0.07273473942111577, 0.03587789315309736, 0.0356879569740305, 0.04467939304548406, 0.0556705943909624, 0.02803071281842647, 0.06701116630386922, 0.043274667414446036, 0.07443982897506607, 0.0181678019373888, 0.054892628273415955, 0.04225551766613799, 0.020958173779710647, 0.05390360876316986, 0.117000448817928, 0.013422238689306523, 0.034624512021940564, 0.08034989087572021, 0.017713632457138553, 0.027079396325373845, 0.021101970398317904, 0.0372654392624334, 0.017555329963685046, 0.02571873415652062, 0.15500906614526627, 0.053851442005965984, 0.04566252517003206, 0.029447307066631415, 0.047424152012794256, 0.01105338087185256, 0.060240630616223624, 0.05008386755963007, 0.07340241569064318, 0.0237135028451561, 0.04235709326401834, 0.019451497167709376, 0.0777251663948259, 0.03469068286640029, 0.0345876325492657, 0.055682962880499905, 0.023128236568863356, 0.051639665729336204, 0.01149734031529196, 0.05632448490829237, 0.012521405475244168, 0.039629992623362816, 0.06407392008470432, 0.027882174115567922, 0.09306522672094646, 0.026664852743007006, 0.06579730764872606, 0.09065178928956871, 0.01973188534799603, 0.03889124637709991, 0.04295049347884713, 0.02491963167314328, 0.04773295439419247, 0.05995931163910897, 0.06754492274335316, 0.03166094493691719, 0.06996351594646132, 0.08180333586830286, 0.01973740501149047, 0.07330801833661334, 0.03524985810321185, 0.036794597793731, 0.05867745501980667, 0.03736852022308496, 0.04918171475911814, 0.028400415359365366, 0.04118254258027, 0.08600461567121168, 0.10125083022660787, 0.021478611780630968, 0.016593035430677475, 0.04454096095756658, 0.04252646764319751, 0.04611635182593619, 0.026084347703163663, 0.03416367183108965, 0.035236110655410637, 0.04403163123154833, 0.06752511170963127, 0.01927885542353315, 0.01749587387988164, 0.03158017628706031, 0.10361709962448767, 0.03803040103746518, 0.05421611517968197, 0.10136580470228389, 0.03537572634917113, 0.01037383406993843, 0.06435242751913686, 0.07835929567414908, 0.0480368193389187, 0.03857072668089982, 0.03532353660932953, 0.0198188612252594, 0.05323337375997536, 0.074837313694579, 0.03558654225461426, 0.04184204852208496, 0.014503419534453462, 0.014478122353583816, 0.03982108559519534, 0.024489187935907996, 0.010384938514400876, 0.029048903041609356, 0.03693793284436388, 0.06121796345518482, 0.03134826040496269, 0.06867530845826672, 0.04716891832950135, 0.12558854725812713, 0.03483793262632624, 0.031117346182826067, 0.07066811765393904, 0.035902633962612, 0.014693433279922653, 0.0819685350682947, 0.03352900245977986, 0.018722562592536695, 0.037825932170474724, 0.038642306106104966, 0.009696736834162186, 0.05676727223720762, 0.05170655286600513, 0.03235077455399498, 0.14330512723855435, 0.03147628901886844, 0.040195514898627036, 0.04951411264858419, 0.019136290291264173, 0.027913486044253075, 0.04672676685356325, 0.07080512481831736, 0.00990412736897387, 0.12271552602009428, 0.00995504348764136, 0.07774743657078474, 0.012393886309808061, 0.023845101428788998, 0.05499430729316608, 0.03975390734511518, 0.01328571224510069, 0.01368942813226773, 0.03229124569183877, 0.05444858456030489, 0.024608414199563767, 0.01928260350870269, 0.0433912085399272, 0.03177910825357803, 0.03277694926627221, 0.01883346914133478, 0.020600188553573626, 0.036610859265971574, 0.03717974466722339, 0.031141148534633463, 0.0135756679059517, 0.042318126201749816, 0.0859465768500682, 0.0720003675369005, 0.019971707257472222, 0.055213492709181966, 0.051877428777515895, 0.007726859522893304, 0.04935018132410703, 0.05207930443688266, 0.05762334484907408, 0.044397541637262034, 0.05267295746072646, 0.012453262911989324, 0.03075358273852016, 0.06274392633067985, 0.032218769943762215, 0.02538104834515722, 0.044467585056178996, 0.028081636597973206, 0.09179399574115392, 0.048092824196623224, 0.020250159150530255, 0.03724392368307999, 0.06223045589943087, 0.052408446452670523, 0.024950277105334307, 0.010179275507858444, 0.03113122769601403, 0.05862763249165109, 0.059124942298137376, 0.06338627956387016, 0.04040166149817167, 0.016398387810876294, 0.019684705823179216, 0.018519673781890063, 0.06798796671172304, 0.04874525148601783, 0.05889629569625663, 0.07400860574336783, 0.07814088400693671, 0.024871850769305905, 0.09048028518596003, 0.027942361813339017, 0.04920023876512724, 0.04986801079564518, 0.03622373205519492, 0.055922376848156416, 0.04994961831177916, 0.04467600310641912, 0.06054938320190676, 0.027260708269633116, 0.013027500395002145, 0.05343651346441719, 0.038659305597144755, 0.016286242114860686, 0.06593642921577539, 0.08163701817994157, 0.0213248981538439, 0.00421506938554587, 0.08381961033709588, 0.01868382344142564, 0.04260155575109586, 0.035953666909687945, 0.03240497910507745, 0.007072694171520491, 0.011364553337766519, 0.023310862353912765, 0.02883737084395703, 0.05782567250031618, 0.024349231333021196, 0.015642516626676005, 0.026346863052176855, 0.01776467114987393, 0.06797148049959252, 0.061075122531263105, 0.025676120515732516, 0.07498511503781043, 0.07329357757924065, 0.09409596737954887, 0.024954015614404797, 0.038477673811177095, 0.020987015074839997, 0.022588512304449276, 0.054440605754573504, 0.03439485801443939, 0.08017189034651365, 0.028413689747873335, 0.018348589111419938, 0.06446167931801851, 0.03817870799872664, 0.016824847890905315, 0.06494783105388766, 0.03241203860529969, 0.03737269157183267, 0.0446478110708056, 0.03435081178923288, 0.06796838550437843, 0.06619067081520635, 0.049375665238908226, 0.05648185085925845, 0.04393225813645028, 0.04331159285239635, 0.02443995146501449, 0.13704007551554712, 0.04550320952529869, 0.06021588597626937, 0.05194075743577654, 0.03110863959356662, 0.04754215636621079, 0.08714790230677014, 0.05122747978255634, 0.021794917993247512, 0.05753328355269567, 0.04447361033770346, 0.03438013380453472, 0.01617055134697547, 0.03668249614777104, 0.047978677095905434, 0.07724804683558403, 0.16046278479118503, 0.14629208873356545, 0.19400395272720247, 0.14084406978180333, 0.15616118577459168, 0.08455769774774391, 0.1431672926992178, 0.12109372554527176, 0.19010425875744513, 0.2770719082365113, 0.09472555375748104, 0.17519071788316773, 0.13235089729630178, 0.09727505606509025, 0.24529113374169798, 0.15755128295671555, 0.13754397750862185, 0.15992640067012082, 0.16791901130589748, 0.13877724117088702, 0.16703329109136136, 0.08889410779961655, 0.12760059292157813, 0.1883082575495205, 0.19732305930266458, 0.1878879970360187, 0.2161071368403012, 0.12462008954776872, 0.08466147201796693, 0.18739901843570894, 0.09648189459356571, 0.11186281804956737, 0.11363641118570683, 0.1585303586457045, 0.11925853894002016, 0.15930681940047972, 0.12342590403052107, 0.24770009721959793, 0.10183756930693504, 0.1455056228704991, 0.16499212642590846, 0.13294355823628365, 0.22817708191371736, 0.10208303153875375, 0.11951962170461494, 0.16266032332374206, 0.13095145384150167, 0.11286132172831606, 0.07716735479451957, 0.08325555512020666, 0.13067363971664062, 0.09217114848715645, 0.12408247202514641, 0.15658464853561696, 0.17344020697618687, 0.1582011400211242, 0.15681194682275096, 0.15052303912178164, 0.18414253188717752, 0.14545659324334514, 0.08211563927151504, 0.13193275118547101, 0.18540083130280818, 0.09031603593499431, 0.17257190760104887, 0.1736366165982139, 0.19238698626718215, 0.1427462048107578, 0.10970802722318519, 0.11265526705932234, 0.22169861341676406, 0.1384171951682337, 0.07276547486863791, 0.15379172179006761, 0.19485550542031566, 0.16976767339773718, 0.15130343756848766, 0.10521548079146494, 0.08561425556939456, 0.09651822248293508, 0.1710932200113612, 0.1288170869191808, 0.18349160229967487, 0.07537698433283838, 0.17402699968266874, 0.19712792138659185, 0.1692978163520175, 0.20089975528178677, 0.12542757686347733, 0.09193435070976134, 0.08160330265039399, 0.1330748963500223, 0.12274075329544083, 0.11334872984838103, 0.14918574071939916, 0.3027484788288993, 0.15156519449045583, 0.20334725298227804, 0.20068845291051174, 0.10526126986669918, 0.12420393526554109, 0.12854258229415264, 0.1340786247484146, 0.12511448438970313, 0.14437185870783945, 0.15510966881148278, 0.18759536677070204, 0.14595277307014312, 0.15019244153893765, 0.23477567299719782, 0.15434122133639552, 0.12941872640963525, 0.1744359833819251, 0.17754093773903387, 0.1294449725819211, 0.1186962150818398, 0.1322635939164508, 0.18108135179406215, 0.08299257245755966, 0.12424276060154363, 0.19767892246525134, 0.11893778558700316, 0.29612629223735104, 0.13386174525705077, 0.13115684201400127, 0.24863104726518356, 0.07055221621187464, 0.11655347481850656, 0.16888803592131985, 0.10902391836768198, 0.12580621582005294, 0.27115289842890156, 0.13713277215438505, 0.17349253078141522, 0.12832417062694026, 0.18561838495154537, 0.10384444387689715, 0.1912511077018515, 0.17567658616650492, 0.08611685521299801, 0.1399563270951471, 0.0631750423100687, 0.23997805351691864, 0.0868894242411179, 0.12411562064963004, 0.10803741928670677, 0.12055800792070166, 0.10019999508175159, 0.1459107608083756, 0.1856524145771419, 0.10540795272156116, 0.1303714946393044, 0.09612470609886993, 0.12029121014019174, 0.15516018464920983, 0.17179517105462092, 0.14594966275317056, 0.12346838360592244, 0.1778536088644497, 0.09518460896346839, 0.2560885761293673, 0.10219915514631618, 0.24562209904674562, 0.1486392902030099, 0.11331895967164349, 0.14764757406327034, 0.1348257136921729, 0.17790639232243263, 0.1774078069795524, 0.13285093820623814, 0.10157716069971362, 0.11554811465283556, 0.14585904987348666, 0.13464643379613278, 0.15464673720059857, 0.14522731844936648], [0.0781981184357597, 0.02768015864515497, 0.019694785625042937, 0.07414650923061757, 0.029777015987483245, 0.008635609298043193, 0.031237993539581378, 0.03142947721625528, 0.051218673601866736, 0.041518594709134875, 0.058793203244286205, 0.017873880813919732, 0.028754602704617768, 0.03424003930582154, 0.03899408602005532, 0.055372950080181324, 0.04597378286322759, 0.05041997331464964, 0.042536940065122424, 0.06567530814678439, 0.0429810565565863, 0.07765148405826862, 0.029440992586915533, 0.053844145018487215, 0.11192574451166777, 0.04341658903285862, 0.03241259018860517, 0.020627122289771517, 0.04390321957368044, 0.021894674132307692, 0.0528655557953302, 0.1045373091173749, 0.07055125094109005, 0.055874423574536085, 0.019665662792601415, 0.04467710244259046, 0.030733762128699212, 0.02662042155861855, 0.08516578769852078, 0.03227978501649153, 0.03807167402438579, 0.02904634622316207, 0.031275874672217235, 0.034287395030860944, 0.016473717236470793, 0.0175084492131587, 0.04755349829792977, 0.016759042853429433, 0.05629080385270138, 0.08786623230985097, 0.038414023395988255, 0.04417814937750659, 0.02656631276852662, 0.02557949193062321, 0.039410493111297976, 0.09104054060674484, 0.015727287128327355, 0.03741619004417331, 0.045846945516044096, 0.030743098825276382, 0.06141242721388417, 0.08550850479232688, 0.04730488361430265, 0.02414094543294801, 0.0013794188740693274, 0.03451080159133962, 0.019595517867034482, 0.0468347852508868, 0.05276376186239143, 0.05182224363389035, 0.03779684764242942, 0.0130514387274161, 0.012768894967232502, 0.03736944335903372, 0.0452458844219725, 0.03568569701465388, 0.028628098605681333, 0.022767750065653555, 0.029203660463193254, 0.08785041259421457, 0.06995473657884906, 0.01003854324094831, 0.049677515372393594, 0.01515604121865885, 0.03631198538407203, 0.010805883718984983, 0.052407902530244285, 0.03286701056265062, 0.05304655938919994, 0.059052581463249466, 0.10360271249326969, 0.029848411551586566, 0.017691829594813527, 0.028116782796719385, 0.041087310190402695, 0.06453345409564434, 0.05453727838973846, 0.020805729943658077, 0.06363237764866603, 0.05361726424927193, 0.02290157030426687, 0.07419841934836681, 0.04752470488329569, 0.02901338145978028, 0.05512261935960382, 0.036117475660097216, 0.053421138079776886, 0.03676198160035476, 0.027607045128881454, 0.04049353842293063, 0.02797077792967039, 0.023341256892308596, 0.026622645128818772, 0.03378568787968928, 0.021176020457078854, 0.08991374784419615, 0.04665888763303238, 0.04616452343461495, 0.016371817966442437, 0.09119720558726019, 0.05056905402471462, 0.07198826334769688, 0.03810178127981002, 0.048279148271127094, 0.015223876389134076, 0.010475253577404206, 0.04331447334299165, 0.013925276918246621, 0.0677552215394474, 0.03527608129285997, 0.04696621912561598, 0.013358707975355849, 0.028595685425605026, 0.04812922869478503, 0.06474936831622355, 0.026982840518617345, 0.04869067538229208, 0.06729054324809583, 0.06542642150194415, 0.03887593610993317, 0.034366447643767443, 0.03513523985842063, 0.019396516952603575, 0.05430899184918212, 0.019781342069167766, 0.07322021699961155, 0.05075538192965812, 0.019986743648206035, 0.06313331733127275, 0.017164550428729386, 0.07488170848979105, 0.03350393223245779, 0.020073719525469408, 0.022569174330020626, 0.023776749148964885, 0.03542254964310316, 0.039637427506667954, 0.021788176419513843, 0.023668669464607394, 0.059023328395860816, 0.11066998084706646, 0.01970683810331168, 0.05599582552789681, 0.08130256717483844, 0.06396006792783737, 0.08862303524848916, 0.029827955088788466, 0.053434253505040566, 0.02450230336117168, 0.02673498617725507, 0.039965880043323965, 0.034960284528713075, 0.044267207098704194, 0.03919545989183169, 0.03138374176717574, 0.025454248046322216, 0.03719439609877525, 0.043661323481149254, 0.02292121088342561, 0.0536823702315169, 0.034785478586150755, 0.10449902004291935, 0.052679178094671625, 0.05942159069461688, 0.04954705825976787, 0.03288686756164797, 0.019950281693449905, 0.032270266374032346, 0.02371471134885665, 0.01956920849249488, 0.0309986753329154, 0.030634268374753096, 0.011933144752777392, 0.057356910960328196, 0.04781180016335942, 0.014531167239070901, 0.038796642179330515, 0.035148723005887963, 0.03088562373792933, 0.01371713657487905, 0.05093148639125209, 0.09203679198699613, 0.02804250674202077, 0.005476541841597927, 0.08140549874834477, 0.05938206055772401, 0.014293383123473296, 0.10233802390435051, 0.0356948287827113, 0.030010904545985886, 0.04211767929636183, 0.025177981419068192, 0.03660402959212661, 0.06343612124422385, 0.049915144355186535, 0.013260191941123097, 0.052142962512950745, 0.05133318459434856, 0.030527764916299816, 0.0026614153044178124, 0.020212747246748018, 0.03418676172112746, 0.05349549840414717, 0.054534899686733564, 0.021759555374662724, 0.04733084250361689, 0.008002139333139865, 0.06385728191103666, 0.09709215257316829, 0.06379040243524699, 0.06375173797770854, 0.07818370066102474, 0.03272056519504517, 0.02831849183196262, 0.030646035485270045, 0.03814355605432103, 0.030184909926667332, 0.04727491808514442, 0.024490390693949118, 0.0386213536013759, 0.057480886969114506, 0.03542877410748794, 0.07662779140856958, 0.041458280606856274, 0.00841614330232504, 0.0501674898870049, 0.014795739534160784, 0.011995200747473827, 0.03281602741128976, 0.040631384453586036, 0.04745834251685489, 0.04651655232714069, 0.03347405097297123, 0.01825838417355572, 0.04545306524021491, 0.01029219207984786, 0.05196903374106173, 0.018015836906288902, 0.056290650635116526, 0.023192009558120084, 0.00849906848968878, 0.022524235612382332, 0.01740377478962464, 0.026791829901236682, 0.03286012726265096, 0.049858361918238864, 0.018773120565099582, 0.08855870684548732, 0.02344424400718943, 0.07480167528434147, 0.04415815831312249, 0.09954271462535667, 0.04846725733049455, 0.032795806520528374, 0.04062086223594604, 0.04023308768087337, 0.015593388365701804, 0.0345542004722501, 0.051529847025390596, 0.03572457214637149, 0.03920913073084047, 0.01174461242983178, 0.04616307935887768, 0.03037292705548387, 0.021846605945498716, 0.008687722429092373, 0.02573646334630828, 0.04639137739075288, 0.025268829870788802, 0.036131119686028654, 0.021356296267420537, 0.023581624639430837, 0.04395212279632688, 0.03354503284959543, 0.03320380962724167, 0.05977139793216221, 0.08865050716145385, 0.016818022047499978, 0.03945648519983215, 0.0710692795954885, 0.03749647605863791, 0.00996897096610478, 0.011202483606945363, 0.049579747231496926, 0.07670469131440887, 0.021489597481465148, 0.04271337394452384, 0.00944879247746881, 0.06994205016282297, 0.105473070195125, 0.024042470575941187, 0.02500509644197601, 0.056731472948506, 0.0668740518871815, 0.0546634798839448, 0.03610983393305252, 0.030653196492142258, 0.04074641255541675, 0.03748198550555014, 0.047524513361314615, 0.07019356448924349, 0.08010585356744067, 0.02676125533217865, 0.02561780973337591, 0.060619916917095264, 0.01525115773772761, 0.05777059460900003, 0.04029620566495484, 0.03392787379843574, 0.0463725890844099, 0.011205994204858379, 0.026728116283794085, 0.019575252926217455, 0.03322872280653927, 0.061248652937431494, 0.021563333444177143, 0.02008112568047739, 0.04928883683357028, 0.03392810745525264, 0.05136572034849275, 0.00961807013804754, 0.07145754061639309, 0.026348649952260238, 0.06541445520856688, 0.009345160891121675, 0.050789790768777175, 0.022621498135248982, 0.07078801807496818, 0.09134943491869396, 0.028269065754307855, 0.016601039134266398, 0.028186468069531748, 0.11198156933871009, 0.2038856136101869, 0.16851165692412085, 0.13937431477731274, 0.14883177745486462, 0.21626822980901889, 0.10430111654943998, 0.19154988199232087, 0.19105598510753727, 0.14288426917647162, 0.23785637301062387, 0.13156956422232813, 0.06798782881589667, 0.10469061097190266, 0.1682980409673145, 0.12349347298544262, 0.1545680446490165, 0.12676905044504713, 0.15163334567219983, 0.15243068998379095, 0.12160905757017675, 0.11078933734566936, 0.07641059782115683, 0.1713959166720029, 0.19989339154093497, 0.13686307856152136, 0.16269089023192085, 0.10432082799173172, 0.12693871593763753, 0.1308533792654353, 0.20391075661586178, 0.22030928232256444, 0.13930156706802307, 0.13762394176615825, 0.15291661955416203, 0.1131256373839513, 0.1440519557124184, 0.17562389463907288, 0.19034962139783368, 0.13356883920008136, 0.13250871140870357, 0.09140160550633747, 0.08835708016469594, 0.09448062778720934, 0.15249986772335347, 0.10160035784206084, 0.10578427043172622, 0.15445572083755849, 0.179412015563538, 0.17594673941212316, 0.09186761679067727, 0.151723652116714, 0.18495829295246832, 0.3500772682168792, 0.2438987995828352, 0.15636141051448163, 0.1741672397380875, 0.10482787860617523, 0.09243305862670945, 0.08063845321415894, 0.15578203353910677, 0.1905057041515266, 0.19058471846003688, 0.12836747757729985, 0.15540801409271457, 0.1896949226577436, 0.14613917758387907, 0.21411869434579728, 0.08667848193116727, 0.09723469855323916, 0.13679740950465202, 0.1605115845919617, 0.1393707448075856, 0.14518274745393187, 0.09699853662882121, 0.11381245819070648, 0.0904034618889132, 0.16001713612387258, 0.059310672654499935, 0.10931241175820751, 0.09352052043522559, 0.12691706629289737, 0.13223399227905658, 0.13368526924281351, 0.1283818187432424, 0.09095291546996563, 0.12219018122601895, 0.04661830412524362, 0.15431742664546738, 0.17169305153431433, 0.2483931463211775, 0.23343894149987932, 0.14328124061707528, 0.16797865891168196, 0.08849943462278574, 0.16703529824172297, 0.16916678467344853, 0.09638614892478913, 0.23173767472467116, 0.17562872099299587, 0.13149402795299409, 0.15278776356529805, 0.14702201730781986, 0.15532497016172256, 0.13675620929608423, 0.12982556506270362, 0.15920863757210393, 0.16111867862843698, 0.10212877464871253, 0.1136638601160338, 0.1176369836133334, 0.14548844717923673, 0.09963323557448965, 0.18783973349678904, 0.2271380828272912, 0.12945477850735188, 0.14360267578834487, 0.1821759075767571, 0.0899433264989526, 0.2557261246106317, 0.1739092826122238, 0.22566412966097557, 0.1888830686408666, 0.13350041222668466, 0.09555684342499703, 0.10035797007261746, 0.15876766204112963, 0.15248020990721642, 0.2268606057811168, 0.11143700339861455, 0.1440611181239928, 0.13617943701965196, 0.1592891687347043, 0.23492892122557088, 0.11612612033082594, 0.14730933092294202, 0.16524067599206202, 0.2227549873773129, 0.18085857342568137, 0.11895046434215001, 0.11499385770049789, 0.21949551308587675, 0.10144678019588033, 0.11046340523828423, 0.09968057214733093, 0.14890444855536186, 0.14794610320560395, 0.1307680830359459, 0.13618613262811016, 0.1391210767530626, 0.17098389926456636, 0.151259433478117, 0.07583404771022259, 0.1341924041269287, 0.06386284370936694, 0.17365982906231958, 0.14234871243036565, 0.22026507904933346, 0.1304088490864923, 0.09482443272586792, 0.16958076326597124, 0.1578045363027242, 0.23686813491006053, 0.1348201518938426, 0.12552055695484723, 0.13390193422955854, 0.09765344221265086, 0.24433812036389307, 0.12266127167329674, 0.13625768524023796, 0.07584874893748954, 0.15111072049025567, 0.12890736272017803, 0.07294050297669827, 0.18011658662749877, 0.10982058086102048], [0.010598845584618469, 0.008787954500275514, 0.02116598279005097, 0.06551979229815545, 0.042786895402617035, 0.07153611825478655, 0.030269918873185114, 0.008563914959649406, 0.02611156489189354, 0.014787116256963103, 0.036661210394794905, 0.09134745075097007, 0.036533480555179625, 0.07640151967925411, 0.04218377736246875, 0.014534176049393513, 0.02730485600148959, 0.0645460102767233, 0.06814877622790876, 0.051236465993908145, 0.02862890874366126, 0.023953345822050207, 0.06889074004345364, 0.031266166422996795, 0.03377251499783128, 0.016288044336702556, 0.07952508997292289, 0.022417259094635808, 0.02804597520509795, 0.005098769043181693, 0.034795341968175866, 0.017049769390254252, 0.07793950247428111, 0.05570360128918002, 0.032505351944916674, 0.025836499107460824, 0.05760754811607542, 0.04629536359120281, 0.04464303068215809, 0.04283443881919788, 0.08763129612611187, 0.02166992500274172, 0.02004321581954437, 0.023748426878404234, 0.040029492154116594, 0.010480009068194176, 0.037697034046774915, 0.038924195818723216, 0.041887163439945835, 0.027222168301382375, 0.03670432199273379, 0.015118768168312889, 0.013133593996415937, 0.04685177708104734, 0.08015628513549605, 0.0965084012357458, 0.04525169136843855, 0.039791698462419936, 0.023345843843755223, 0.028194707345157385, 0.04097400961684124, 0.008333642336149371, 0.03558077361254442, 0.03963435166365197, 0.040532087967280424, 0.00924293986416512, 0.046548877407105706, 0.062159799610174475, 0.02791538211186567, 0.05264309152299839, 0.07648108557106988, 0.031017036545240594, 0.035821030276917645, 0.03270800135308697, 0.04617021163745273, 0.024514229434932915, 0.008212442438478672, 0.05392881688631831, 0.06499425598209904, 0.04579128922834512, 0.026925293908965205, 0.031553351718391624, 0.030669324558168173, 0.0781955213976964, 0.07258659333831842, 0.0276555193422903, 0.03809230477218667, 0.050252835912209366, 0.07914807512274674, 0.0029819838387230716, 0.10745593556954015, 0.06483705474003669, 0.04635079388296412, 0.04981010603988844, 0.040414669671125954, 0.016829875342908408, 0.012447401381758674, 0.032526856032951225, 0.053774469321773904, 0.04955699058970617, 0.04224041041227118, 0.021335734467532848, 0.01821708245833795, 0.013226433319129772, 0.05217474367048952, 0.008614246936274633, 0.016313453557931127, 0.03292984892463973, 0.007304229403680732, 0.032631469169451345, 0.024976017659590132, 0.02434380743051729, 0.020693371658243483, 0.05748400877740595, 0.005444169359942598, 0.0638725193998506, 0.029538119129175623, 0.03889264831800134, 0.06526348226132893, 0.028267564221976266, 0.0339371013274837, 0.07166773216017792, 0.04733201078770142, 0.02117524287783571, 0.011254928071021793, 0.018806960583934863, 0.0121883075729373, 0.11005305024164339, 0.018195440474477027, 0.039517519424759576, 0.07334913427550947, 0.043422817327683015, 0.06386925586529317, 0.018525764180888093, 0.020096250171322497, 0.020827329792683164, 0.061789602942524426, 0.04352828465221871, 0.023204395284635887, 0.03907970783691253, 0.04838883290968595, 0.1173008012495214, 0.01539693469361913, 0.013499229568086807, 0.052117853981232455, 0.024524259441081556, 0.040163875467354254, 0.012777387051873151, 0.0816850595536732, 0.010722641562742573, 0.014481903955100045, 0.05676584348322884, 0.04738811906727572, 0.02913837061984645, 0.06916297704822595, 0.06373358552434272, 0.06530690412487715, 0.01652806925947868, 0.043030001914068576, 0.08155442624082489, 0.00890377933354748, 0.01575996460873754, 0.04054799961346773, 0.04290239464852118, 0.03175420273515967, 0.0071065428088449185, 0.011613145038755912, 0.013900579201177725, 0.06098863886549108, 0.07562223972091753, 0.0855616253289965, 0.09022750681446445, 0.036801438958894823, 0.027282423031846845, 0.0038189590756495997, 0.03196079749614, 0.012683118017570627, 0.03239661342494431, 0.026976623715111808, 0.046009992008968714, 0.048793281368430585, 0.02552232261927378, 0.023563577523154598, 0.044058026790979414, 0.014150364084109185, 0.01406936752309482, 0.03574452107591975, 0.047625617815121535, 0.04942909987162679, 0.05983688312792971, 0.02520507220329056, 0.043666000447926984, 0.04082687860054355, 0.034093164928978494, 0.03285375341112095, 0.014706251846115678, 0.04764129963493155, 0.02408353480390243, 0.013600291887057886, 0.012746840253502372, 0.038746919242605087, 0.013998239132155095, 0.055576848211668195, 0.025955750268974134, 0.023787788475953767, 0.02287487980098494, 0.008063034225826063, 0.02739065593378919, 0.0400282051264038, 0.03745140327561287, 0.02643187391391445, 0.02099901584217385, 0.03482109784419018, 0.04755879962636579, 0.03736527584072563, 0.0377245749076528, 0.01280068570087033, 0.024520093837993282, 0.02428150341485537, 0.014899844179801164, 0.03220758506006772, 0.04514626617873869, 0.050498711831507184, 0.056881721942655505, 0.010780015802611748, 0.05645547445202547, 0.03482248446333312, 0.03585870265059414, 0.0632754113194683, 0.033274021585501974, 0.07409437694737027, 0.02988322067164606, 0.06390537308048337, 0.022195051461758635, 0.04967030648502612, 0.03690525919439332, 0.04588114368098398, 0.05260042425605559, 0.02065608424374894, 0.10863378809224214, 0.007083111052070895, 0.07384998723864555, 0.12725978338670346, 0.02369473560623104, 0.012737080293347039, 0.07236252794222486, 0.045628510866194, 0.03000796468357646, 0.02636244336533691, 0.0709829414864221, 0.03840013039148143, 0.07076274483434616, 0.016274049825545762, 0.07031479024238164, 0.06302424939349294, 0.03409281252853332, 0.00886246516940094, 0.008797308433830978, 0.03607847795431172, 0.06863110518503575, 0.1105816815529139, 0.03316512218706551, 0.01918601131276979, 0.07504477796535339, 0.022111365932130048, 0.05501287343401102, 0.1290778479268474, 0.061407072259293455, 0.08078261563975005, 0.03866970907115648, 0.054685037598134055, 0.009767595179108603, 0.033051790969987074, 0.01885833635535692, 0.03272035835130561, 0.029541047500266187, 0.01565008270253818, 0.017739863307665915, 0.04509964206766698, 0.030185382985960574, 0.015494476838578141, 0.02289569249466783, 0.022385949081170465, 0.026916139158270052, 0.032691637715024334, 0.010372570024863368, 0.04269035300239921, 0.010992872374763173, 0.05337582780949531, 0.011770139437078709, 0.019333626879679582, 0.01991448431996809, 0.03519751897622501, 0.01924909099245504, 0.005494373495645461, 0.06643539760261774, 0.01495570635362979, 0.06599695016179355, 0.03157923782935306, 0.07542193837223515, 0.062406161995304216, 0.05046560917229903, 0.05716007998994282, 0.05753519111162713, 0.006439303209434354, 0.02501594807742344, 0.008588915281448393, 0.020445210881711497, 0.023326888913288716, 0.01515142745413487, 0.03011080241131206, 0.06432049697445286, 0.1262556949269868, 0.055194340511074955, 0.0800048448746243, 0.03707057713801342, 0.04161172801808965, 0.060453078288945465, 0.023651080085865916, 0.01578100138313828, 0.03362065338860116, 0.07801843251311973, 0.06311793811619282, 0.06099191389136738, 0.07983122636834461, 0.045940549969072306, 0.08228255450845727, 0.017059475724254886, 0.051093900861639174, 0.023069318661826755, 0.05807447104504513, 0.018138928083522667, 0.023461352665758422, 0.019875362124894897, 0.05626120987618643, 0.026126953683072524, 0.02311573784437872, 0.09366176406582517, 0.027281789094089504, 0.05311981654695926, 0.03284348400249597, 0.017214855592277263, 0.05768892963627174, 0.03133580956097332, 0.06735728482805914, 0.07647018413990736, 0.03391713324573732, 0.05893790576186392, 0.028973811103271383, 0.02620191347124356, 0.014350397302018059, 0.04673181154254464, 0.2107072282101839, 0.10816116546911579, 0.11008761612878692, 0.21927515555533672, 0.14423826829560343, 0.16461812230127473, 0.09022380660979018, 0.10784627268871955, 0.19799766100702748, 0.05525153280506211, 0.10498224532291775, 0.1282742983030696, 0.20132462764459275, 0.18754224623403243, 0.13550177096359192, 0.1349422816307314, 0.12696333034264465, 0.16131004739192226, 0.16335907211947828, 0.11321264965039109, 0.14428863091574562, 0.1371045188317376, 0.10546504925455778, 0.11811803320362685, 0.17919138224134523, 0.07217217041479965, 0.22823360388077077, 0.09688939974312821, 0.24765261509005101, 0.13947261917975642, 0.1481279111917942, 0.10863674519162987, 0.2973387336298343, 0.13100909429692453, 0.13403495773673058, 0.1127903130386145, 0.22143638152028286, 0.12683424452740338, 0.13205152545725146, 0.14508381485939026, 0.18974566832184794, 0.18741443212474548, 0.13973193994212535, 0.0914805738495723, 0.15468350942096404, 0.08185474802890132, 0.18981593390626295, 0.18838220035597203, 0.08481117325925058, 0.10098369536741127, 0.07156146044332175, 0.07590264322296267, 0.11961486941624073, 0.0851371743145489, 0.2336039721605278, 0.13896045875885796, 0.10847085651250617, 0.13225820065746385, 0.1566491224953244, 0.08903492242097856, 0.281453563441192, 0.1160599303341681, 0.1492767213212867, 0.19335121517219853, 0.11237276447636467, 0.11679285431220648, 0.1526351282072644, 0.15929656914405285, 0.1444460313406683, 0.2430613735510457, 0.10778645654359173, 0.15063548550730751, 0.13090869081356835, 0.17302855729095398, 0.1807929809776045, 0.22183563590290087, 0.0920689830015744, 0.12925833824180788, 0.14530562795698643, 0.12671522510748717, 0.058797899363262046, 0.11158449064579704, 0.22014235176386374, 0.12900978867565432, 0.23236652565819604, 0.20095062351995902, 0.04304526238552025, 0.1716238737947518, 0.1066856801269516, 0.12230851882768255, 0.18662926861115042, 0.19826569984997475, 0.1418928288283848, 0.17030111574117215, 0.16156182984911627, 0.1662356709881175, 0.09121467239193379, 0.1378042175764999, 0.15258652758934807, 0.10926764157991256, 0.2542806545933408, 0.12457757166797116, 0.15593284560788065, 0.11216185280993102, 0.13528452375002448, 0.09703321742915338, 0.1475886312583762, 0.14159466740825485, 0.08272947488172401, 0.1198883857878466, 0.18295557057905584, 0.1638359312088259, 0.07957530703635947, 0.142354182298145, 0.12550611619747457, 0.186950734425937, 0.11247204947135142, 0.20590653823268032, 0.06901181257900692, 0.11531035160465587, 0.12361865941314928, 0.15541429601369366, 0.1415868533114272, 0.1508992495796373, 0.12530960698401736, 0.07109550278513663, 0.10396500313354116, 0.21537543094206243, 0.15601107850670815, 0.22311759211363333, 0.22399030415521515, 0.10072687205167548, 0.18586840540651353, 0.09719936657817134, 0.11668279812100435, 0.1243936492791099, 0.238284754056123, 0.2965932381489585, 0.16037770306631444, 0.20841601244624586, 0.12357401180892222, 0.15116440793198926, 0.11640614078890894, 0.1035834223993363, 0.12033332199338945, 0.11382144440205828, 0.16518822961276577, 0.10024154002988532, 0.20175624158113234, 0.13728736869750485, 0.19070119446804448, 0.16005442928402655, 0.13500473311831876, 0.12318752045112273, 0.13862540254429465, 0.13237279208917774, 0.18065436502858517, 0.12342650157910202, 0.16720987435790802, 0.15863316764514293, 0.15667398970934654, 0.22590776094265524, 0.14043070405962008, 0.19798745671587606, 0.14550015300271973, 0.08500441893815033, 0.11073010342736399, 0.10764637736663704, 0.24425775774063604, 0.17642532986017967, 0.17349654508213844, 0.1819198503489456, 0.11163940382820946, 0.08028131834561787, 0.17440452781175414, 0.13892174067516483], [0.03368727622493621, 0.037940569567464055, 0.0372313445193633, 0.03381397567629334, 0.015743883465596988, 0.021081056197985046, 0.037059610589377345, 0.04777597789202006, 0.034911718384753314, 0.036000191429329496, 0.04938477785476754, 0.00561206758345267, 0.0688224356441248, 0.028105718571872964, 0.04057373633728393, 0.07748803153874413, 0.12383211449149156, 0.08694688083543893, 0.015313100734455212, 0.02622825348930013, 0.027613388336894494, 0.11697155964230338, 0.04072289365614134, 0.06793634004650578, 0.05317765235480282, 0.038717455501037265, 0.07372945862551851, 0.055099640552315025, 0.028293530772169753, 0.032361112910533146, 0.056558482634324225, 0.03458836033279377, 0.09720791611940631, 0.05885766954311441, 0.04772679504728125, 0.01367176884800316, 0.036382821703990625, 0.011024802919447182, 0.07869011542249112, 0.008432059736561873, 0.043893540052757155, 0.11008992971431826, 0.03889141108600363, 0.01775621736962949, 0.029531787412481445, 0.06096567154952115, 0.030021735114015402, 0.029485569328009605, 0.06121132913376055, 0.05264261654848534, 0.061557202509814696, 0.03162796485177692, 0.059917414290530074, 0.030959417157235648, 0.02613300960811396, 0.04236950388839168, 0.029580238643252564, 0.04300034665051968, 0.014021135584992028, 0.024513547616680304, 0.03865803389119045, 0.05574186355055821, 0.05010705321065841, 0.049565812092154264, 0.008632889685911999, 0.030003986772029635, 0.0681790826661933, 0.09533476985750661, 0.012578291334061614, 0.11323975384115212, 0.025460190973394824, 0.06960194542883866, 0.017745225923135877, 0.029494565115460468, 0.011288232785919982, 0.012205084898479044, 0.03127819783384762, 0.08565842819910857, 0.0642055684640523, 0.060734148287484725, 0.015645521606558997, 0.06748145235882652, 0.035098272285634474, 0.04050566942521161, 0.03151053314908378, 0.06070274634346847, 0.02347961620187327, 0.031447039781919414, 0.03158005371299242, 0.0216991474266134, 0.02276729424333861, 0.023417384964564157, 0.0321685835238426, 0.0735344662661514, 0.02837846885555454, 0.04855248844251037, 0.0416066718377894, 0.03442574284910675, 0.051572510461893775, 0.02782120883855368, 0.05214322681328462, 0.03727206592297843, 0.018954185446003274, 0.03252143213044732, 0.03284475953888989, 0.054445524039047385, 0.05482618546774311, 0.029816756798555295, 0.011836710562478873, 0.021429011417973428, 0.07157363358043856, 0.0945911206485283, 0.06023907545773734, 0.03740028605886525, 0.03286678073627334, 0.021446535679241343, 0.06315875145035886, 0.03203278869360445, 0.0220559298947093, 0.03133645307482972, 0.026503681250277068, 0.020796845238956235, 0.03624144400800428, 0.02038709545177558, 0.032593333312580665, 0.07241474449514382, 0.012051742824335254, 0.042464529434519435, 0.04102787325879739, 0.06098087839481812, 0.04000650951638818, 0.03684119126128574, 0.06030387883525222, 0.07086801297602154, 0.055718708543046835, 0.039698553662146294, 0.05111158217093156, 0.015334361589573806, 0.02374832728697408, 0.042895974831715714, 0.056489274251244725, 0.007812255343812849, 0.016023575463482452, 0.001987094299458418, 0.07133809218723929, 0.01743300678959537, 0.05352797670169704, 0.04747134302892993, 0.07665442828569682, 0.04978253453549358, 0.03559357877219877, 0.05014860965011101, 0.037882124719720696, 0.03249860271030376, 0.01587095446959739, 0.04841033316728088, 0.05159108043317834, 0.03374623818202846, 0.09643571481349007, 0.08626589761866678, 0.08875205977669648, 0.01585869514758909, 0.011331637412489904, 0.05221227431790002, 0.06583297670248055, 0.09156285935351927, 0.021616275865404357, 0.025324080131887913, 0.02104062016212171, 0.04736798244618601, 0.007115945101700604, 0.0275404759187011, 0.02898784391882439, 0.048981030366473624, 0.03720193440395017, 0.03107106298088066, 0.11277738147445264, 0.02305095170384213, 0.03882351271327465, 0.09496514775579977, 0.040988894705210006, 0.0440322709149651, 0.09759034721120712, 0.029225346497109825, 0.031617783543263236, 0.008043056567980638, 0.042079574083008116, 0.06819124048155162, 0.040060786845823454, 0.01846221718756903, 0.06555860997327874, 0.03800646462027104, 0.012128587188800017, 0.04131707911109252, 0.05092726907722893, 0.0621401877593129, 0.03527765943398399, 0.08115274335948691, 0.025939258311184186, 0.010727460255786296, 0.06658748903822514, 0.07450283970683813, 0.17896604513929737, 0.012356626666000774, 0.08814138810961478, 0.03206378078058122, 0.043205669705545714, 0.019479108891720255, 0.005677166383623356, 0.032615588166781014, 0.039189557184375105, 0.02337133733465547, 0.06410752453150288, 0.046489180005606145, 0.08469571614818228, 0.058377382210305626, 0.061784156057382786, 0.08302890034692903, 0.041602772450254816, 0.061725389452711235, 0.031143699607421315, 0.02355579598506372, 0.03321004558294531, 0.05039701748999858, 0.06923594692301366, 0.024732191025489764, 0.05795567762106658, 0.009929882287378273, 0.0079765792883512, 0.03159953724412668, 0.06091722414918965, 0.050918516522694024, 0.03596950194708282, 0.04233748524359638, 0.0247246986855903, 0.03981027226414412, 0.03459832330624904, 0.03856438347288678, 0.055862740733690804, 0.007544333329274049, 0.03146510413517395, 0.047234376712191495, 0.10086076889908123, 0.03821636888108427, 0.13858355882187046, 0.05159149412065745, 0.04509208844073358, 0.02663148961390459, 0.03552135966357685, 0.04228495842506809, 0.020569962554521138, 0.05952219719127302, 0.038005855580371235, 0.08646444462600254, 0.03427206561149609, 0.06188614151230263, 0.023100463966388377, 0.03408802447900657, 0.0650550067544945, 0.06348097186175085, 0.030385462169144905, 0.013317502021128613, 0.02996141718129718, 0.027356777610557697, 0.03730263666159684, 0.03370593429633206, 0.016442771114769484, 0.05316049964617818, 0.05071614290617647, 0.07548864930868149, 0.06921966755462271, 0.04498885043205754, 0.04105394323086066, 0.07173712440435925, 0.05398753752571441, 0.02231532726587067, 0.0410596773989739, 0.025045517156080856, 0.025871934504398418, 0.04310879022664121, 0.06943164408327111, 0.023775094399048437, 0.05531696054423529, 0.049776133870886224, 0.024630534988377365, 0.04215268951450144, 0.02850916345543679, 0.030982085698915106, 0.032759210500385494, 0.02738748432978267, 0.06235058231639767, 0.020824979817975434, 0.03272961652387054, 0.02664099101938548, 0.01697188506143228, 0.014849188531027928, 0.011719479957865852, 0.017828436478251414, 0.02426268446499542, 0.016463917056699435, 0.05850569044630374, 0.004043882729620823, 0.025705739390105013, 0.03986555699919982, 0.03141716426809228, 0.016201401707686244, 0.06759460354524274, 0.002229149714337602, 0.0834355015127409, 0.03320625344772012, 0.06549394449159023, 0.061257999210107716, 0.05605457681080988, 0.02421155384170913, 0.04570060357030842, 0.03105032498077039, 0.01392656873400894, 0.023120368845880996, 0.009852158837020397, 0.07182482614993088, 0.07927637952830523, 0.03621812046114956, 0.03621425171713195, 0.08323575940824325, 0.0956134649834806, 0.0652784746020071, 0.04019783997547723, 0.03793123861654632, 0.036570716258739276, 0.02831731780221866, 0.021032505375783772, 0.02256339419663193, 0.07343399383488201, 0.035509343574484514, 0.14963739551603794, 0.11951536225575594, 0.08706859688484862, 0.012407668231565867, 0.05645165167328331, 0.04080753871089509, 0.04812335663084542, 0.06021868985807223, 0.04473648191760144, 0.13103347121467515, 0.04779724832323771, 0.01783416681592503, 0.01900547503253385, 0.018394994887433225, 0.025460064568887317, 0.041473805378641815, 0.017793010657412872, 0.03773836449028985, 0.15793981210839364, 0.10545590982562113, 0.15477493435384768, 0.18206462564487613, 0.09521896800687236, 0.08579021830472254, 0.18849708290109712, 0.20858331072715022, 0.11014783830051461, 0.0964731765129874, 0.13671936046692634, 0.15887379586215944, 0.2337366279454962, 0.08227430374151276, 0.13020001351833344, 0.15225403010845184, 0.15290811597820253, 0.16604204992613486, 0.12019300532917823, 0.18040048349047863, 0.08150443134288635, 0.2720402733933541, 0.15839840766162644, 0.13089497783972373, 0.21868195835380785, 0.21989971639648562, 0.2193175508610664, 0.17598190284784765, 0.11387453429521092, 0.21596398565077016, 0.20102923946274867, 0.08649435269856647, 0.13989572954033652, 0.07842750048204776, 0.14108796153337727, 0.16311807618025811, 0.19100706273269272, 0.14955988273985926, 0.1345719853716512, 0.18465311416695196, 0.23681348219754236, 0.21055915873617898, 0.15447248284134174, 0.12144809483640617, 0.10243497999204744, 0.18179913021383748, 0.12150865408682054, 0.12521962229643138, 0.16956829135456394, 0.1791095640510321, 0.08584127806487583, 0.12136158052711718, 0.1785768724737629, 0.11475336737930776, 0.08030868300627317, 0.14576442269307954, 0.11068573161478966, 0.19270935606571937, 0.10717441357912556, 0.17056089615629566, 0.1638273050587985, 0.1614446796837353, 0.2618210282056563, 0.14402229278799028, 0.1037471277278758, 0.16674320423795333, 0.21536686607906896, 0.17133314342748734, 0.2756410092115402, 0.18448829801092226, 0.1504754803834423, 0.17874182652561896, 0.1817818625920242, 0.13610025417179833, 0.12957937504735687, 0.13988261411507286, 0.18422442668628308, 0.26514784162563665, 0.1399409134061106, 0.12445210944861175, 0.14727729312594862, 0.13168844574641797, 0.12509075864668817, 0.15884019524580048, 0.10916642604335662, 0.13493002422394293, 0.06414245047997083, 0.11685724400224225, 0.20294668092843027, 0.15062558765132583, 0.11212462093681098, 0.1910577624315216, 0.09799901681441454, 0.17060022711032824, 0.12926946183846844, 0.16676954234079008, 0.1529030138326268, 0.18737952915891526, 0.1854011530597364, 0.14258440704114977, 0.10216627465260607, 0.09788094734352443, 0.09516737198517208, 0.15025693082040356, 0.10342266650930529, 0.12877649958095244, 0.10321648926624369, 0.08145805237995041, 0.07521039085282434, 0.15095250801213328, 0.13481365546824473, 0.18940299719331727, 0.12631455346220924, 0.12224625886207628, 0.1935638658582203, 0.0984663074655879, 0.10338470685265719, 0.15944758039568702, 0.12466764828610806, 0.10891632131871679, 0.07597876937999841, 0.10909725596467335, 0.11081933734878419, 0.1575530449589414, 0.21986168779192433, 0.12906733720052627, 0.15044370305634316, 0.114020052696428, 0.17327745925755272, 0.07812084314683754, 0.19819105224263286, 0.14731927474419917, 0.16220586464530037, 0.09043000683548952, 0.18866442714727696, 0.24476815615930866, 0.11693120979133154, 0.10268920626971992, 0.1999462975729858, 0.23655207767601938, 0.21454398039608233, 0.14848544442605588, 0.08845667925573165, 0.21010014949546707, 0.18918686846811927, 0.11837401382264592, 0.15022950487271433, 0.1594131064390944, 0.2750858406145727, 0.1336652590262313, 0.12079037004901517, 0.14502709370947656, 0.11332450614821528, 0.11887111295495303, 0.14072626078080747, 0.10419666812184358, 0.12526253088107034, 0.19973965301629037, 0.23321326731914477, 0.2772773117307694, 0.3716637260250507, 0.1290983177961842, 0.19115724660936864, 0.1356046565718228, 0.18135050912537884, 0.18579855350957764, 0.09017941181457813, 0.30309603759838694, 0.1744681437529864, 0.15720983756886375, 0.09343491777056649, 0.1318082006107415, 0.1336012753627954, 0.20007578175394766, 0.13244101987971416, 0.14462482094043685]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.050542578026051485, 0.047583536605440804, 0.06316081222687518, 0.022364759089184866, 0.05569241640548553, 0.043096084658417015, 0.0655609465414478, 0.03164877563024, 0.08281891564688376, 0.05702540173285431, 0.03506980062792859, 0.08942416403442623, 0.08564345884106814, 0.01208863378832898, 0.018966245585151257, 0.020903356358288758, 0.053085771599604245, 0.017853430096781062, 0.02486987043202164, 0.016311398527074247, 0.009839334525167942, 0.01806045769743862, 0.05086798153276886, 0.02652804859192862, 0.05375806737931506, 0.03987449341483655, 0.05859629949554802, 0.031584544903448517, 0.03705371554280001, 0.04373807783028291, 0.031700980691840096, 0.07429419566066035, 0.035010731418526946, 0.024207062651253036, 0.05736647173762322, 0.06583620193264177, 0.08744198047826368, 0.03527039309002219, 0.0378983581228362, 0.0675576551246547, 0.02486375705038588, 0.026213900832038735, 0.054352796756692474, 0.026286941569959445, 0.018333721260029464, 0.04717109018876668, 0.05366831251810636, 0.02989387886989261, 0.028444220266875722, 0.03636203007772565, 0.028089257257599986, 0.030286610013835376, 0.04980319209637181, 0.03885849994877654, 0.026675060864598043, 0.06736737420602192, 0.01843827310949564, 0.036724688440200784, 0.02012381401483811, 0.021923442649084236, 0.041553394253095316, 0.04417292082742338, 0.053225471563036406, 0.043856403940627654, 0.061713840677252704, 0.051527633031289426, 0.037533570035931565, 0.026147362265375354, 0.021382758859544996, 0.01094337160353579, 0.03682360188254426, 0.017501652098050522, 0.018808665129566388, 0.013986483512957011, 0.013696191731029221, 0.05773868321651413, 0.03214025742284233, 0.02448329671977028, 0.012938313396467317, 0.05288686453094406, 0.014750006957910957, 0.003813126034313633, 0.054410908356188774, 0.026683876621386698, 0.04436060853843247, 0.028241247186557423, 0.007047753221535635, 0.00679046833782547, 0.021586086255528276, 0.03187597815638348, 0.019851268659676277, 0.04672741802829889, 0.08575201349993868, 0.051800076879801295, 0.019831781298102393, 0.08876816294486485, 0.061666515595730276, 0.008802408664186877, 0.05551630811345193, 0.04506760427067357, 0.017009653196099307, 0.047233009245246656, 0.03317846360826685, 0.054265665746624434, 0.03084142237991816, 0.037884189326676636, 0.02725496452542082, 0.013711861101910474, 0.013053172001344784, 0.036272007085743456, 0.04316635790371126, 0.050835108699937986, 0.023118141445241148, 0.01417673666090254, 0.011081028985039843, 0.04052153510612346, 0.005737085950620954, 0.024744358416947148, 0.011874701820253845, 0.01287895211604454, 0.03013836433960786, 0.01092176792407108, 0.028468871061059258, 0.01067204911622309, 0.013720645257572254, 0.021158680056912765, 0.04542300395006615, 0.01749617456939192, 0.06488948579757445, 0.04034733437302132, 0.0413772285044674, 0.03299329249608902, 0.0414910193743004, 0.024644106235955993, 0.06445430955218692, 0.028283098569860863, 0.06035630606235035, 0.07118541852480943, 0.04600314318292564, 0.06373039093769847, 0.04104028771361036, 0.05275065026756737, 0.03927238278030869, 0.003181826492260781, 0.05676947090955031, 0.06671334196242594, 0.033142369375714374, 0.022864732966427843, 0.059674556757653915, 0.0642813805250391, 0.04320111148239624, 0.05048725881703919, 0.03622797618229543, 0.044326337595139785, 0.024628591040269505, 0.05281843755754733, 0.06566856657305072, 0.054809729899129564, 0.06201976639849525, 0.025767826985928322, 0.04003822938689301, 0.05368500940441605, 0.12428182342480268, 0.0502397051651872, 0.07142348034727959, 0.01825076159870913, 0.03833190260094501, 0.05836516310791335, 0.02920982364054409, 0.06110731354584137, 0.06879108732626324, 0.0323565585178233, 0.06254885736252032, 0.07337737993727769, 0.012058627081944818, 0.010892857681028547, 0.015293504205352117, 0.05964937927802244, 0.008640698994690133, 0.030405347896439415, 0.08125382866109572, 0.029174874709438414, 0.029351787393792506, 0.04470918620485933, 0.034276926439375646, 0.06461940916074861, 0.004365698072022849, 0.03719188716082323, 0.11968525757472362, 0.021535955376983173, 0.03762846534711219, 0.06305387018308525, 0.021588238962595502, 0.03573555018632643, 0.025373280213605014, 0.018417856866313566, 0.05905406384338295, 0.02166242117152339, 0.031483009525184194, 0.015532482460501696, 0.03825665744502218, 0.042869008536781036, 0.02158107604050348, 0.037335363937722105, 0.028114057438928756, 0.08133204623816476, 0.03342889392027452, 0.060547399034182874, 0.05190277096605109, 0.06209958509932603, 0.027796851073001182, 0.032749182409456665, 0.12991838427560945, 0.04717236189472099, 0.034392605715942, 0.02365808404471365, 0.09010845675103127, 0.11613068621485464, 0.026145975646232406, 0.025124265249037457, 0.01667814971428485, 0.03538137241717308, 0.017039400390199116, 0.05199917164000292, 0.0841917145636774, 0.014056926255204506, 0.03516541989219766, 0.07284529356946869, 0.046806723450220404, 0.019219588946491, 0.021447635015412685, 0.02212317709270264, 0.055771901858069246, 0.04644007376965977, 0.04794696871671946, 0.0731510162774113, 0.022047257779406446, 0.029522146195954377, 0.10972215388450893, 0.029775838127299666, 0.018036232082053058, 0.09613396810187448, 0.012176562487448176, 0.033159931941378507, 0.031001278116638144, 0.05214503478078593, 0.01579297246456507, 0.05769777029091793, 0.0464732070723849, 0.09964173915044916, 0.015789052009612562, 0.05285840436455704, 0.06692256823542618, 0.04773722533437033, 0.005244917072911537, 0.07463616198830067, 0.03536073400849297, 0.14835562316640732, 0.0694434188546673, 0.03666247443986997, 0.021994464745324467, 0.08409894131604703, 0.02679548605585531, 0.04206228730899673, 0.0351663928238615, 0.045968600278419834, 0.03880908727766045, 0.028552780671405698, 0.047107290386432604, 0.030454212814689647, 0.011338907586891326, 0.0365170824431604, 0.0669002520941919, 0.0653160205711761, 0.0926193788707737, 0.02651526833013181, 0.040894577790412216, 0.04147046140485233, 0.009462545670929455, 0.05733881979399631, 0.011384990648366513, 0.02287717997997759, 0.023923920384878596, 0.02711451571104267, 0.024567344225943092, 0.04310666816309095, 0.03856519552608652, 0.03450046706524107, 0.017870713040352832, 0.04799414824153628, 0.01629040771794896, 0.05483041810352476, 0.04729391323522695, 0.03561741559796276, 0.016281105495328387, 0.010912382389388738, 0.0457449485698054, 0.040997497872599674, 0.0297971602694522, 0.06185911009989439, 0.03337451699940908, 0.009766284211148179, 0.04442325920888013, 0.02520908650401379, 0.022410661162387942, 0.020093021110721657, 0.041359030085826115, 0.03458732994453561, 0.036771615156002586, 0.023045702086340998, 0.054027354945578886, 0.018731169590365984, 0.014519885636775967, 0.02286926054606034, 0.01580625930200181, 0.03443060367698631, 0.05191895457345152, 0.028010919021682876, 0.025175941709969795, 0.013095286727372198, 0.014875670275350493, 0.09463432800745773, 0.05686617801867186, 0.06044378564242394, 0.005380384879367006, 0.06563108189091568, 0.05583307397882304, 0.035175390526532166, 0.026551134651526812, 0.0362474424764514, 0.026557893462238774, 0.03245226588220366, 0.06342451118173138, 0.0256055484961478, 0.046412908291864785, 0.04468605034954606, 0.0790892242484035, 0.048924110033699585, 0.07538464521208117, 0.023986323991970673, 0.03164434955725747, 0.059519098365619305, 0.022479992119535323, 0.03863779767867058, 0.008582581649534404, 0.01993349096136949, 0.005025678030740951, 0.03295544775262956, 0.05235684660053062, 0.07258995646430601, 0.017142883547010924, 0.011064543730519232, 0.17407947670548193, 0.1473845301135894, 0.16485329597227036, 0.1843830528518846, 0.17693362919793976, 0.16555688644368804, 0.15829193676190992, 0.0838191123799451, 0.1907742026472284, 0.1393883188645686, 0.10392132846097793, 0.20012288083953245, 0.1626282089179562, 0.16005176329805007, 0.11418414106892963, 0.11550017287053409, 0.12219019654777744, 0.07492955834154161, 0.15022161416709423, 0.1294630675786926, 0.12768680845657665, 0.15360950011639826, 0.14143670007826822, 0.11731215467255925, 0.1559009457067136, 0.0929841976011953, 0.110039092119663, 0.17147978797795313, 0.13649408465191243, 0.1544360017343875, 0.17435218868476732, 0.17219399642800132, 0.09208333182839618, 0.2329733285812601, 0.09428690713379653, 0.14073343136377875, 0.35534801442296277, 0.13802216959095773, 0.15724740652067049, 0.18867155176497277, 0.16941633015390367, 0.21174336212777325, 0.20115691567620925, 0.14297716499816987, 0.08350659447211413, 0.13343215379263126, 0.12401914719732539, 0.17070907288261, 0.18798464668854592, 0.1099722815917865, 0.11055341290850794, 0.16685846982704056, 0.09137739712793021, 0.11796155208421331, 0.09300882732796092, 0.22002199935095929, 0.07896284272353496, 0.06441340045703035, 0.12888050367755274, 0.14928326371216005, 0.15156634362234225, 0.10418837138962361, 0.1949495963391758, 0.18704597447668353, 0.0901621901580403, 0.237106648724406, 0.09998216564136167, 0.11979691488968751, 0.13375303738059538, 0.21474935324682345, 0.26102411290330274, 0.18455773622037905, 0.14872939746466377, 0.18654700608984118, 0.09394493314527697, 0.19063970825124174, 0.1515326510754324, 0.12788919356441306, 0.19945518924824654, 0.128164763051656, 0.11932239236850893, 0.2490951126861957, 0.21485646766039634, 0.09221009639722687, 0.09436779069684206, 0.22958867552299655, 0.09118398290968711, 0.14307802813428064, 0.1784705088263558, 0.06266501544403934, 0.1541532080380186, 0.09833468589931728, 0.17155016081467753, 0.12485543941898693, 0.1801583077758551, 0.21969658052248342, 0.16890994603595427, 0.15877593579071184, 0.1452470988395714, 0.09985445112350488, 0.0846877181902528, 0.11972940722179991, 0.06292074325404341, 0.11128121941921212, 0.1060040993615985, 0.11761907247766373, 0.08597538941690037, 0.13917151598199723, 0.08997028513300805, 0.17233688714763812, 0.20851080816599632, 0.08359051940421905, 0.12409983923838985, 0.15959670707102747, 0.12105089356942524, 0.1322290739945827, 0.14379819674837974, 0.1465885494385035, 0.12847804704741125, 0.08667284352404457, 0.1034738565044057, 0.11193926596353132, 0.13563451867911125, 0.13131893089702054, 0.18066479914611389, 0.10249990594363022, 0.17775381825143294, 0.13055045277841631, 0.15742598161582025, 0.08302677828337877, 0.15192619044213526, 0.1125878589828649, 0.20089169603682336, 0.11865856952124065, 0.17054442526592364, 0.09306789270692295, 0.15384772281733253, 0.08924841580371703, 0.12900709204616087, 0.16822875597544257, 0.2965066395699978, 0.12641388442247145, 0.10841837948969296, 0.1419145704036759, 0.21389055336194657, 0.16194688096161813, 0.21885532405107253, 0.153420812660648, 0.18269870129804458, 0.1868345648530991, 0.17475015603967253, 0.1253241473328202, 0.1164568558094963, 0.11912145516684941, 0.09617107740092663, 0.12742020985892705, 0.12205827620721633, 0.14226007605752639, 0.24186462163925174, 0.16888967534947782, 0.13554670968123023, 0.13253698005310952, 0.2284050850017417, 0.13636361987840745, 0.15609304991460618, 0.1398760717241995, 0.1546487137074432, 0.2362717048174912, 0.0883680428828924, 0.1565278354551523, 0.139984657026587, 0.12003539039963677, 0.12989379285324004, 0.3362581452294704, 0.09081013966351749, 0.08097989860201076], [0.047165562864393, 0.07046482856235198, 0.026659147303190925, 0.06778716740588989, 0.016925199663326625, 0.060650472333955194, 0.05495951541008488, 0.017616161175312537, 0.050331750629289504, 0.037611278164530956, 0.05829166080201826, 0.03191276378328762, 0.06277021080736192, 0.05617244709883967, 0.024073673337097132, 0.0106225828189523, 0.011467070266183828, 0.02239267916358527, 0.0009029210430584969, 0.037260287321142616, 0.039429403991708835, 0.037421081515569846, 0.056637619516902396, 0.10375753120188752, 0.030472671703225186, 0.05580572463992623, 0.05539861402564472, 0.037881213075090805, 0.034530145311427694, 0.031097238290033517, 0.03959613536754924, 0.08845721551727864, 0.03750209148312288, 0.03305896921383758, 0.031837848045172236, 0.06864716238792866, 0.03780558870564546, 0.0316863235146288, 0.012419626864063884, 0.03878016745851886, 0.035153947725531556, 0.06156925307286363, 0.06891354648095947, 0.045178805763322505, 0.015389499810313987, 0.010368831515792879, 0.04428245990927662, 0.02214734525149388, 0.02093192569220499, 0.028628508462720824, 0.026566824132216074, 0.08116412742604172, 0.07478323554800403, 0.050938136034434846, 0.07772168069477044, 0.07351520681573499, 0.010404267870340376, 0.03318786733753739, 0.04098073586881642, 0.026898599575243654, 0.06188126153222496, 0.01384152627114447, 0.043877953993937666, 0.04279005934574431, 0.012572618452982317, 0.056541632530429674, 0.04939877811158377, 0.051340994860736594, 0.0662478975831501, 0.033132873715892915, 0.018666594124008572, 0.04298845313549523, 0.011736022668980784, 0.02930492579546427, 0.04345601957832133, 0.07904504395781026, 0.04294162218068396, 0.015243031460070803, 0.028923094167464206, 0.01011230314390794, 0.05887667235407618, 0.03909214910480284, 0.02166136971584732, 0.055379664840837645, 0.010331900332183128, 0.00784350790068387, 0.04134999407875923, 0.030118551390666156, 0.011385255906310295, 0.0661689369007945, 0.014396500473301259, 0.05492642807263521, 0.041424316098733295, 0.05470742651772115, 0.05454796531628217, 0.0621211274917568, 0.0221138097526085, 0.05177510241346975, 0.05102117996542685, 0.05098130508896805, 0.05192096172381313, 0.05214930572096379, 0.03361743198887956, 0.04204951279285935, 0.0735165704522402, 0.022923719821377628, 0.03756329807783327, 0.03238149467975863, 0.07191965251319832, 0.05669052171851358, 0.05001061040187075, 0.007232539374531517, 0.019988781442084623, 0.13080559070071868, 0.0313356084628932, 0.08615666880242287, 0.04640752652419671, 0.05880822622848134, 0.033600421006520914, 0.06744149321269605, 0.04814142098409995, 0.0653877570444057, 0.04244059301732529, 0.04719856210173138, 0.030325261064835136, 0.08189802433574393, 0.05570220317871821, 0.000423590751574187, 0.030788908967928543, 0.022962527920401866, 0.050355740672638344, 0.04292852973805801, 0.00848554512260542, 0.06658007330711811, 0.016326450239566546, 0.024150644106069402, 0.014691354308818138, 0.029605862369099935, 0.02479760344290445, 0.06990582186488375, 0.036080201652141354, 0.03388718303833758, 0.034237511215671416, 0.03268309200422899, 0.03523512623242794, 0.025410845334972107, 0.016301887545494304, 0.07566286536354212, 0.04311342122814348, 0.0569377382916789, 0.008013213612890292, 0.020186686850783807, 0.06393095658671472, 0.0452277357990463, 0.049347913703851165, 0.012924154176406804, 0.0161399882692363, 0.0635159859103301, 0.033297686041483, 0.06316371953054782, 0.026798243972382722, 0.08717080067482688, 0.03331675780035796, 0.017203090396980127, 0.02549702639601404, 0.09741259183013633, 0.0597180973648304, 0.010794079261681726, 0.00909596206545229, 0.017214196756662383, 0.022275461965510925, 0.08021237809331187, 0.015946868994844057, 0.06101694198385362, 0.0772407766611826, 0.055340165347461744, 0.05645724411513056, 0.1139858162270919, 0.10276213017923218, 0.07300437938782477, 0.03783966429651745, 0.04235517421376802, 0.03185784485521576, 0.03902207887280853, 0.059198739547883315, 0.032825231957699985, 0.06388659626545926, 0.04545903689558468, 0.005856147026568051, 0.011436304175144723, 0.027615020104173212, 0.02889402496117738, 0.013781741727143528, 0.0815313057072701, 0.07762510765103564, 0.018046909432497718, 0.04258785043813048, 0.014535685242604346, 0.07380596016563716, 0.05828977622572453, 0.06109241313571411, 0.030836159355878353, 0.040213782265181505, 0.05704914279762776, 0.04261419620184649, 0.022791837785212744, 0.04611925146872959, 0.061267031386734984, 0.062384294015505624, 0.04875085924962356, 0.03776893522890826, 0.07177223421392903, 0.026616074009648254, 0.013442142611189235, 0.03743456083259756, 0.07806016132235527, 0.04634756099192366, 0.04807881627892775, 0.020548669140665762, 0.04177850918964513, 0.013649531230781109, 0.028818264611125476, 0.018807663469605388, 0.01744404420136444, 0.05098960182118801, 0.07121327348173627, 0.031862826341943394, 0.04534277922263549, 0.05335861764427635, 0.03798626671214739, 0.051324692509707906, 0.05260870566651706, 0.04191226431078488, 0.019977839791306087, 0.04981533458997166, 0.014285741396428598, 0.023099931535281004, 0.025987816794264703, 0.0635684629331433, 0.027684439161431887, 0.02038947223956066, 0.06295786404441442, 0.042822618082526236, 0.03508384301958065, 0.025883954423930378, 0.06653818361941846, 0.010075550075740585, 0.019175351199303425, 0.04842952366978411, 0.01602112877017428, 0.017095721259172407, 0.008480124092931229, 0.05190219256966826, 0.021047999504052346, 0.05037826748805181, 0.03708736978531365, 0.06888702451702088, 0.04871431302519576, 0.06389920607269292, 0.03490714867028498, 0.06147518896708085, 0.047272244438288674, 0.047847687552172335, 0.029940506811403943, 0.06999307161858005, 0.04739890558524959, 0.04558737194466014, 0.06724467756406916, 0.009408321010038979, 0.015171327545577961, 0.045054339458264654, 0.021605230792756044, 0.008954931024251687, 0.04453615375584172, 0.01991849862069132, 0.09241982828825714, 0.02526661587668763, 0.03948259347629163, 0.02790415509333534, 0.024539556301709627, 0.034688158606689785, 0.037048981119427955, 0.04226619693180246, 0.07252694573253393, 0.09638593442017034, 0.060728264732226256, 0.09319537739840247, 0.07000906753443903, 0.07699788848478949, 0.07111782658725016, 0.04291588545686776, 0.041345474160005974, 0.01133116243797685, 0.020278132851085356, 0.0062262431451780426, 0.010205780234818738, 0.018301882645896366, 0.03599477135726521, 0.060142054252566836, 0.059664578462440165, 0.04750739512664657, 0.052570887736134955, 0.05139270196518591, 0.04062491101062587, 0.04101042943676153, 0.012381401949472005, 0.06544257063538798, 0.05082829051741189, 0.010591254610898755, 0.05165917798876763, 0.016030978745660715, 0.06368148005417278, 0.017360387400033015, 0.09939971665341048, 0.0706293995702459, 0.05160092083256572, 0.0030013325862631563, 0.0341713058972551, 0.004779306069512161, 0.07407160115338142, 0.02873138832529226, 0.06481375034538008, 0.03034537661850693, 0.027661033260125308, 0.06442903631156491, 0.0726058834322518, 0.05581382985016512, 0.02269706504810001, 0.0061705523835224735, 0.036360409801765796, 0.047751244743384665, 0.03464533812216213, 0.008856505005350037, 0.053189978709504496, 0.0376556538075449, 0.04009671636947221, 0.037713570054620504, 0.055347569587249915, 0.06538468503182934, 0.05192912056020672, 0.015864238751331167, 0.12169736452520856, 0.03375851474101505, 0.024142697859074802, 0.02904266708590571, 0.03346587298437953, 0.05865585134034196, 0.03271185860578572, 0.012368376539539427, 0.07274028589768756, 0.00954545553653471, 0.05565904944594349, 0.1249690119537615, 0.16073659993708134, 0.13136088187175413, 0.1680651502383332, 0.17768701538443568, 0.13952773154502915, 0.17964260802874643, 0.14308737440695687, 0.11567433529924001, 0.17771335348727244, 0.17591586606877466, 0.14032556615289182, 0.16098683489666832, 0.1070247276596004, 0.11947088319087222, 0.1247976610677377, 0.09572263251269057, 0.12938794499683764, 0.1353535789155191, 0.1415185948773738, 0.11006431939500956, 0.24679986729977593, 0.14784539328707805, 0.2098670595836255, 0.08581155385341376, 0.09684891199632999, 0.09214865614569957, 0.2322343295259822, 0.10970798125790973, 0.057965081350337115, 0.09998579689812276, 0.17554598349717357, 0.15437698232070093, 0.07543654766895118, 0.107162784364435, 0.20510315714824587, 0.16092018524725593, 0.11423774424099153, 0.16581652896298518, 0.156531359459604, 0.14450429998818906, 0.16437461359366295, 0.10030258191569198, 0.16861112578020943, 0.16539993034976144, 0.13267469201837817, 0.14053907485738878, 0.08613152579674799, 0.10742824915195666, 0.10277515367394495, 0.15777058328592009, 0.22427104473594697, 0.17078450189963465, 0.10141124137707296, 0.15157314648310985, 0.18691656690451408, 0.21411711620467327, 0.09525490519140037, 0.1454863634200827, 0.19654321243926404, 0.12762638710198865, 0.12708532984458631, 0.10423976056758436, 0.1337083897763683, 0.10833787897060956, 0.13060171938230916, 0.15754808070919207, 0.14314663896877922, 0.14548820203110097, 0.14359899856630834, 0.08747016485299795, 0.10633424495256717, 0.08624551967988092, 0.13569732256714376, 0.14800201230231794, 0.1439247544734709, 0.12612717601680948, 0.08282790185823556, 0.13912902874571664, 0.0707261334924448, 0.19437309985439624, 0.24594267619954002, 0.1275343339770071, 0.13766964657172082, 0.15144303411005006, 0.09230569650929782, 0.10399713286108549, 0.09418954501949972, 0.16924239755157502, 0.10147137927912897, 0.1319012649717831, 0.10115169078832674, 0.08503520035094793, 0.1926871701594322, 0.2782074650449138, 0.14459693533999307, 0.10452336631715299, 0.16381618146213794, 0.17203938456312304, 0.1778634147898805, 0.14116846205246064, 0.16628854637665136, 0.17673698974953544, 0.11980513501311503, 0.16677266797952114, 0.1343781957703252, 0.08242983491190019, 0.12121557182962857, 0.16030042011651302, 0.1668751705437899, 0.1584481574114292, 0.1654779181004532, 0.22162768899673418, 0.24490747690921832, 0.17604266894200157, 0.2904345041080829, 0.13794799695812887, 0.06184820483829226, 0.04880758039953728, 0.11824764761953585, 0.12355345766991378, 0.1996550922312083, 0.21308323458558132, 0.1535827483260824, 0.1253837642950877, 0.13929042814960405, 0.21194870433499738, 0.09435908793802224, 0.06257248351410513, 0.10893756493685708, 0.21441012951395205, 0.15814516963737626, 0.08781660513411607, 0.13935045879935065, 0.1000544383761383, 0.13751779262336994, 0.07800002342029926, 0.13819784887375372, 0.16076882159517658, 0.2845020724400398, 0.13435867585001454, 0.14419239495069752, 0.09031189906020319, 0.13479438069606983, 0.16848801545077757, 0.11901463186668775, 0.12641124141913268, 0.1058572709500309, 0.23214751644240272, 0.21748535965959873, 0.10952727643833046, 0.09089818614865504, 0.10739915313259249, 0.08219253151647507, 0.17948742925880418, 0.0948896268082242, 0.08017698483121011, 0.18039354273388464, 0.12228934364693782, 0.15728787128483096, 0.11993334748812261, 0.25776747313718645, 0.1997601994944196, 0.14229793612274433, 0.07462821765652589, 0.2008323548662086, 0.10568051914414091, 0.11851459095675139, 0.11739616387433584, 0.09350163636789208, 0.27414499271300535, 0.11621936089209012, 0.11883947352368025, 0.12389926975893399, 0.15514411212455842, 0.17942598900727688], [0.06906169256375683, 0.019914465167769985, 0.06956535706957502, 0.03997171380286736, 0.02249008341271791, 0.013914958671516469, 0.024421687928899646, 0.04451515911627681, 0.035994962879246285, 0.041578357228107994, 0.050259060376594146, 0.018350521568208933, 0.04970149392442358, 0.019943967213734023, 0.05806164290275305, 0.04184175740867373, 0.10558260544653862, 0.0020098692555386094, 0.009099669931005807, 0.01502630039824233, 0.06730210351487322, 0.03630022593443433, 0.0978935418289996, 0.002763154414189499, 0.020035430451013872, 0.005585971755921962, 0.0776548625060147, 0.02619350374105477, 0.026821864378308097, 0.05150984063924802, 0.0666613245923673, 0.014517475332644199, 0.12325546478912716, 0.03832215030166892, 0.021743802691719705, 0.03859903362970199, 0.027299192696509343, 0.019791617223452178, 0.01889599915293436, 0.01431778493908144, 0.04418624309642662, 0.03140706339881065, 0.03835227287885162, 0.050948838282737045, 0.005641457589057785, 0.11872999955930057, 0.09595640424278476, 0.02582678702780076, 0.022242684893670584, 0.041175414132134575, 0.027027315753061446, 0.02845977759739805, 0.013283410150888226, 0.07296397591069823, 0.09825882787305502, 0.0536824238576716, 0.05702002379562586, 0.04183698468090546, 0.11158621434362666, 0.16693278035569578, 0.03969034503003763, 0.021112262789580612, 0.02105875346328943, 0.02383379397102662, 0.013628080768901254, 0.04536707187071443, 0.025916030525320002, 0.08117790934779952, 0.04105641769485609, 0.031207417055303534, 0.04369555228960611, 0.03787996435177423, 0.022160694333574465, 0.0046416822043547955, 0.058398380680310155, 0.020791986326296485, 0.026353778910913297, 0.05281273020251144, 0.07407681055126653, 0.03786976772150205, 0.0847620133971495, 0.028531108044027805, 0.013169802184547148, 0.01174100798614804, 0.009309192105466801, 0.04934835420440763, 0.05847973538742912, 0.08658133432148926, 0.02491974658633192, 0.09518220344738615, 0.04240154934626433, 0.08772366334714236, 0.03386852496694173, 0.036800155761621656, 0.042019259980729515, 0.011821384973553641, 0.01776019911161594, 0.005462688577902173, 0.03485005596772798, 0.032214380259956085, 0.010694451442348861, 0.03843479587005512, 0.05469722222656973, 0.031237060827533566, 0.04420951301712663, 0.038069011868848916, 0.022229847175279455, 0.04002015737275924, 0.04146074740997246, 0.03945578422938143, 0.00652529179088531, 0.024975621209089315, 0.025498345982463613, 0.06655198086293475, 0.009803247953494711, 0.013657121246890917, 0.03340955786106568, 0.039317091671569694, 0.058879326848733815, 0.0206032797183481, 0.009887486981648591, 0.017506474621533867, 0.02358458748447799, 0.030891221925436013, 0.009252244959615413, 0.015715061322665744, 0.0768793057349901, 0.038835613072038665, 0.048461986645575494, 0.027232303644620606, 0.048987400387564016, 0.06932034682963165, 0.030803502942886085, 0.014353548796216567, 0.0604272764476557, 0.04835163168008289, 0.05313381297333587, 0.07189499980379498, 0.032932020783905065, 0.06863999946583664, 0.028614004503094384, 0.02046977932144317, 0.0037271290737760044, 0.029667078539909377, 0.09970740054643924, 0.015343049984245051, 0.012368485707068637, 0.0184795192833389, 0.010087466573402768, 0.09405945562907765, 0.03298390408857696, 0.05096843481184014, 0.06849298719316721, 0.009643954333789166, 0.02071287434157585, 0.030816505370180935, 0.041027930715391715, 0.04158969149894772, 0.05234499905078162, 0.04440084347621568, 0.06251293933019042, 0.02291028455440556, 0.054400072042499824, 0.04147567080273744, 0.044415085050728054, 0.017135241819966226, 0.045222453622808384, 0.046229897547633424, 0.030760012131424683, 0.03828769166683478, 0.023828262816213315, 0.04573232344081325, 0.04885566773854437, 0.04028622736974109, 0.026075606639947624, 0.08026064929342078, 0.06666982816832681, 0.011282412432915261, 0.011905895005310736, 0.02795064705424011, 0.014476065407507123, 0.07388764046012394, 0.038855925893350955, 0.08146217393298304, 0.01708294865825484, 0.045277906897207426, 0.04092109209347156, 0.015601240766925678, 0.04655047470042783, 0.09232110253745511, 0.013505245273512219, 0.03538143370420702, 0.047675785082843036, 0.018530038951505578, 0.05118522237265303, 0.0028131050226699204, 0.030398102619895534, 0.0232311355836329, 0.034946184680466695, 0.0476821665952523, 0.03868209288245247, 0.03724783456193344, 0.014616762242850759, 0.03145177037485185, 0.011794897483571643, 0.06029630988656033, 0.05213863794661818, 0.02994312300166536, 0.06343017640193144, 0.059409605249041514, 0.054105040091540546, 0.022537046517696113, 0.0638581475903911, 0.0292927794714248, 0.04348648306463034, 0.02805189706475264, 0.016216859446778413, 0.01939172315741739, 0.019880738146903536, 0.0936542334215295, 0.09209436349450581, 0.05806266563013197, 0.04011421764810239, 0.060456253723391605, 0.12022520400463574, 0.020924969613852522, 0.03414466902012787, 0.02994415913558295, 0.06014930910520977, 0.015130086159784228, 0.02221301047792358, 0.008104563852201306, 0.04701639788465635, 0.05152750662678192, 0.058295870455162185, 0.0801567218056129, 0.050796505529433496, 0.07027499197471528, 0.014061414572830885, 0.03240329754208365, 0.030082621867017403, 0.08100658910529268, 0.005849865584393904, 0.10182319749747554, 0.012968330636560436, 0.013343201398158507, 0.03850191666354095, 0.04198834067210556, 0.02329153395558317, 0.04084816435351968, 0.026794298619572676, 0.04047848479521852, 0.07068596750257478, 0.05556057650415648, 0.058351021124831134, 0.016957969074287725, 0.08188470206674069, 0.02008011252919753, 0.04779983003954253, 0.09769448154275456, 0.05514415026071572, 0.011492480445022305, 0.02429542706287917, 0.0859735125014859, 0.02785960899575824, 0.03178007735480224, 0.016886895267112602, 0.03171043804726534, 0.003985957624653595, 0.06384335060213363, 0.008988491420994603, 0.022778067354773803, 0.02604077262203059, 0.03521888516843319, 0.03614707729749141, 0.0273971542746069, 0.04219200514677552, 0.11856964203499018, 0.051397371271084395, 0.015642160395791214, 0.03135695741812308, 0.07116923108696938, 0.008175901959710305, 0.05521418984919306, 0.08496377031288802, 0.03273466121285193, 0.05217080597855872, 0.08268294270120322, 0.03196555873258941, 0.022733440817964655, 0.052320415289291454, 0.058685292099272056, 0.06050778079717871, 0.07501996437748594, 0.02453409792524913, 0.04572047972150388, 0.03702329419132683, 0.06902107458201147, 0.11053477398931019, 0.02398839625980585, 0.04257081264269449, 0.011688374872920255, 0.011389719326079134, 0.018027558051530394, 0.018721966959175565, 0.07414011239644981, 0.0731488329268271, 0.06245608794532957, 0.058853850594811866, 0.015173108700001913, 0.025145399699648543, 0.019076958696748463, 0.06595468509101099, 0.08300824661649044, 0.034611101652826035, 0.06872411591992264, 0.07292947131058863, 0.016058363516124028, 0.017945626863248406, 0.02615729268009384, 0.07984595823912852, 0.0505388931431357, 0.05208733686876874, 0.07025510433220095, 0.021518708822587808, 0.018330992071799213, 0.031819335530481996, 0.047827022330414866, 0.028191058851417997, 0.026689944037747, 0.03581400142021237, 0.06265341687286574, 0.03518528455207425, 0.036538490770204414, 0.008051841681252324, 0.031411401371681885, 0.05480486141037076, 0.046885994398185325, 0.043571656720051845, 0.0011579812792572946, 0.03447408682756847, 0.09474536479120294, 0.027541224769647085, 0.06601604873374586, 0.05895158426175195, 0.05935016448699659, 0.0372517109668303, 0.08056883880447957, 0.015233671780855907, 0.0281983615845562, 0.05439652505541041, 0.051839112889983004, 0.121951368637383, 0.14305959605882246, 0.16991493081854236, 0.13364506494854728, 0.08098423465966217, 0.13515718461525056, 0.11682364338588332, 0.12629296510450302, 0.08311608115271216, 0.1185768049570822, 0.09888842191186645, 0.12618303148736879, 0.1503497653550679, 0.10808195197774519, 0.1532723754644394, 0.20506583334457493, 0.17164691771951415, 0.09609737974261084, 0.09260945803215427, 0.0766359732276009, 0.12432751290860677, 0.09328838813328937, 0.18414144404232505, 0.19459929497491932, 0.1760435116387183, 0.11975651907344019, 0.10487019730311249, 0.1764142369070361, 0.1293477407025714, 0.11352780290068158, 0.10745469450710282, 0.11270874765731635, 0.37133424693057615, 0.14562154729520121, 0.13128278686875297, 0.1199272264456076, 0.1301444874655816, 0.0971708298029919, 0.15478743690877192, 0.1282988667428013, 0.10737643862563757, 0.07786287069921533, 0.12002270398361069, 0.22350532453387018, 0.2137553848085865, 0.27641086628840816, 0.19446113867865455, 0.12184709641000918, 0.17981111672857117, 0.10815377272064648, 0.1828697840532949, 0.1039541629894126, 0.1530630649217675, 0.19015627612750377, 0.28639948836738066, 0.09331196065871947, 0.14650406526221385, 0.149888611068168, 0.17348885355937868, 0.2961872728361238, 0.1385311124425742, 0.13930469270675414, 0.08594804007800357, 0.20359093022923316, 0.11053630616515876, 0.154852845495747, 0.13704139318677688, 0.18580501929165857, 0.14770647090288902, 0.10769559085489282, 0.18120343556567547, 0.1003551661908146, 0.09234385534880624, 0.19311372791567158, 0.12031979288064665, 0.06761016279098488, 0.17754122885244508, 0.1389913780674819, 0.07767190030145069, 0.15740479162383467, 0.22397859833173214, 0.09876891985655793, 0.09357087539448854, 0.20425826942007388, 0.16458043077540013, 0.2221035062065048, 0.14163707803574302, 0.17601162705930973, 0.10471363191402729, 0.17083667248727816, 0.10415151489958649, 0.2353518936903246, 0.10493505430678207, 0.17901150479672417, 0.1454193920137421, 0.14456192512185345, 0.14198906479343293, 0.12466999251515636, 0.1263925795172972, 0.13891509103198207, 0.13671199070109477, 0.2528599292160042, 0.30690095117015226, 0.10171465816036349, 0.1240980389317678, 0.18470534604162941, 0.16262626305462854, 0.12336192036708518, 0.1750623521905753, 0.20604509289466566, 0.15962511361125978, 0.20001041913224807, 0.13439164827427558, 0.11422252973481534, 0.10932507519159587, 0.12539845020059617, 0.12336686163419679, 0.14415519372109445, 0.12173302591808381, 0.14209691465141314, 0.0777534427001111, 0.07383372319201309, 0.09981783978160351, 0.1721885878472559, 0.14648989263561465, 0.0920143609325732, 0.14766527069432123, 0.11597557639282559, 0.09025545370194221, 0.13594864537158322, 0.18016187774558223, 0.17427023259862778, 0.13833087238092578, 0.07383588355995956, 0.11174438851735286, 0.09858869767237095, 0.20193670125257587, 0.11213342328706097, 0.11942725448358445, 0.3507213643000972, 0.13831021865048718, 0.10608345840967472, 0.059408421643198504, 0.1487192544605463, 0.27181718858980364, 0.14372368703686422, 0.1576057364863734, 0.1774448856350876, 0.13670570878011568, 0.12947333315687795, 0.10499577443566054, 0.16235442441557685, 0.15760616549561102, 0.1342109434546963, 0.11505375045441812, 0.14239768077048565, 0.17426099357826097, 0.14504451454887468, 0.2598142149227281, 0.06490963390998303, 0.10103342979545556, 0.16712070172352178, 0.16135677875530335, 0.20570334107164415, 0.10091838637186636, 0.11980176422624819, 0.21535059437155726, 0.130127020660908, 0.1469242491669232, 0.08442187035876898, 0.08389355314354743, 0.1822027512976239, 0.1279245638438771, 0.10859806541233294, 0.14131657749174104, 0.24465518883399426], [0.08104835621892445, 0.04692706054136638, 0.02533918930097453, 0.017381064113109343, 0.03967721428301546, 0.039260244117148464, 0.03852867228429645, 0.022802509389997973, 0.029658467711640463, 0.047114449478085005, 0.0593103968628472, 0.06356852805061687, 0.05009191148283501, 0.06456277228050655, 0.030658765951351776, 0.057663997304776025, 0.049505019184922984, 0.02929209573795238, 0.06000571358468264, 0.027657892299635757, 0.007430618589428524, 0.02670969378443495, 0.037931579525672623, 0.020575608622523087, 0.011063142747227705, 0.06141292134059533, 0.01444132810819053, 0.05818396799206253, 0.05707453095143842, 0.015060731262389212, 0.053066041005114396, 0.056506005611511013, 0.06133751530620841, 0.03624707858468737, 0.019595573408408992, 0.02183712177699612, 0.05859589346894815, 0.019809200856534225, 0.06382320248972505, 0.020948088232187495, 0.07656178527301358, 0.12839951537429325, 0.1167501372495486, 0.03881498232423779, 0.0398940286569057, 0.022080276168942935, 0.07883648418130414, 0.006192589860274307, 0.0467923861147175, 0.019293985660037687, 0.04190711619993372, 0.038122105592441176, 0.027524361259213863, 0.053606255565800016, 0.026756656889413154, 0.06103378442686893, 0.07200045946745143, 0.0068260626980073515, 0.03585283824753377, 0.04782070593547918, 0.014528868017688155, 0.02726012604281066, 0.05067407701825423, 0.03173604453613441, 0.008856050140644995, 0.037537109362141746, 0.039363493617143364, 0.024999864061453173, 0.04499093036077196, 0.040992368913946614, 0.06113747825785991, 0.01157064056549702, 0.03953952146994491, 0.005922595099095376, 0.0377922089800479, 0.03852909746309442, 0.01015406259666047, 0.04057845926933712, 0.06786500959987603, 0.036169044868720156, 0.04780089107131766, 0.0304827323528908, 0.06173052607224353, 0.03186167721005698, 0.01978967902100375, 0.01409530055694162, 0.0016792178071374376, 0.04662016188846, 0.11998957068088556, 0.007736877080113177, 0.014509595160733068, 0.08638712337180492, 0.04044992886784096, 0.04863904105619558, 0.008616432202078642, 0.024331354671308113, 0.022433775950283296, 0.09620856208306167, 0.027976481454266657, 0.034626932859781294, 0.062086569265492504, 0.021382542439706383, 0.016174079181866783, 0.022791039138551683, 0.04886722034444252, 0.06051389417881447, 0.06275697663846998, 0.04274022532626987, 0.06185048011942737, 0.022968976465504498, 0.06900032126014272, 0.03718770432075666, 0.056250166718757925, 0.026720223662954186, 0.035302676035151366, 0.02367214941900344, 0.03946637539493461, 0.03041486270845898, 0.02774161804888037, 0.0349673401984957, 0.03348207191353844, 0.08388931667732616, 0.041288431253164046, 0.04056635508013349, 0.04281143319883174, 0.025581656129009304, 0.03113863576624182, 0.08787650554891556, 0.04256564154920559, 0.019368548997707905, 0.0429528147252577, 0.03725861724946768, 0.07635717084931751, 0.04832027187090247, 0.043124970003602006, 0.06094065877879339, 0.032296811320608666, 0.04447757867315123, 0.10540485772634707, 0.042281196933359876, 0.03798977922528021, 0.04253651871676407, 0.05063659999699843, 0.050042747790294315, 0.04212688001233243, 0.05378615982349842, 0.028982791568963762, 0.020389322852415424, 0.024379355825423717, 0.038072248590329004, 0.05371024434064185, 0.08161464075167334, 0.037779147180938916, 0.03668755615851091, 0.013409647076661068, 0.09334107199984212, 0.060985421296209104, 0.015260707981313671, 0.03391384289810254, 0.02237178411545052, 0.07355487484845423, 0.04080393426721135, 0.009351219688992827, 0.04370710106506463, 0.036498297967257044, 0.056152023194778355, 0.08301090494158768, 0.05513708309961423, 0.030293280724436048, 0.0633191894139013, 0.02953535163654916, 0.01321458672699068, 0.06803499684939462, 0.04195298188396039, 0.035515713595574906, 0.038050349967013446, 0.01284698422457422, 0.04154591340451472, 0.04715410601948539, 0.04666897701099516, 0.05644066214200951, 0.0075570570920864425, 0.06381251556318134, 0.07008073505975547, 0.039713963520743197, 0.0622050485934221, 0.022571953313965953, 0.02715693399941008, 0.025867759325211088, 0.04562293757654486, 0.07187882002683417, 0.06938274469106429, 0.03791076491676992, 0.048179219762283954, 0.0503156436306815, 0.06608765497202836, 0.015337395297753957, 0.03862160641039091, 0.0512746324942958, 0.039945360378272114, 0.08610156409802937, 0.03133706977560876, 0.01996386826278702, 0.042466253132349065, 0.04785048760353558, 0.007866113240109577, 0.08582680666398618, 0.058001370935310284, 0.004143859118959236, 0.03828383058369641, 0.022397804291798704, 0.03359392075048339, 0.09834569458278919, 0.0362574284325444, 0.044492678266138806, 0.01930816020185669, 0.10348013842538481, 0.022888880057801163, 0.15674646162698347, 0.028265725610957994, 0.03227267189011459, 0.03502560884601647, 0.08790422261001603, 0.04015426106390454, 0.04523847635174471, 0.027958907397283662, 0.028416669829898787, 0.048719962923637325, 0.011466604867769827, 0.050518254734455585, 0.018306701338940093, 0.024062312253180052, 0.03827814621129825, 0.044057770151524775, 0.021705994337436654, 0.020567170164037137, 0.05227508586681178, 0.029131502641605276, 0.0038143821791069765, 0.03675442414298173, 0.02599911276070822, 0.0252267352545694, 0.09684432312966355, 0.08583737101646201, 0.0059606782874212635, 0.07403288306968828, 0.03329343042306362, 0.04359331019523163, 0.061485117466579524, 0.028206271442374396, 0.016203414603707292, 0.04999843343431431, 0.01890148817291183, 0.088583275285219, 0.04571335510380807, 0.0386453359838455, 0.07236584510293699, 0.04868493738373922, 0.05191291013972894, 0.040426819825605045, 0.040690618371891404, 0.016098996819627863, 0.06479811449084552, 0.03199062129903225, 0.04623744734412721, 0.007738573007255553, 0.04420210111645922, 0.05853440342170577, 0.020252365483752182, 0.07605124129763535, 0.03181694150571862, 0.058838954015124234, 0.035907287946752006, 0.01221526429177292, 0.04421264248629732, 0.08426505216066876, 0.025673439207997535, 0.023850615346624006, 0.03476997296656332, 0.10567591495571599, 0.007397829068659415, 0.05743429733199939, 0.031148671518049897, 0.029670001165340507, 0.022344373489519762, 0.030324056391574206, 0.006976630097450389, 0.013087027341938548, 0.11438405937364987, 0.021018125905445027, 0.01998781425608022, 0.059790496504114526, 0.04823896312905897, 0.05518875189966733, 0.019668916751059796, 0.02175123949024466, 0.035933641371347254, 0.008856900498240946, 0.009169609928052993, 0.027090757409290924, 0.037344982171611446, 0.0043425191242638375, 0.023599562588177865, 0.037671921684617, 0.04076540004462004, 0.01318719142281841, 0.04634859904106106, 0.015621410904362079, 0.029428765823644017, 0.08822713633097949, 0.012862871930513893, 0.06873202194730121, 0.05661531486698697, 0.009617508978643005, 0.16281755520932137, 0.02311106662326042, 0.023957331394476276, 0.07484212472674347, 0.025297372391627684, 0.025518946086747513, 0.06297227032783051, 0.046642677212554606, 0.0031718323964835897, 0.06782667456014503, 0.08053010539902795, 0.054900833075085, 0.019115879793741533, 0.06526558134224146, 0.01448632907047267, 0.008115745863066086, 0.06957048219778846, 0.06019176186753377, 0.052758092811751756, 0.044018354927820545, 0.055358846401495326, 0.023606036031138034, 0.027857243699292024, 0.02895061587614398, 0.05226021226976187, 0.032464239836460164, 0.015878453512766188, 0.07289609285972773, 0.027827437133378083, 0.03530605448289745, 0.058918473941664544, 0.054324489807890314, 0.060499135494953206, 0.06165878193813467, 0.08752233544064146, 0.028640919087094166, 0.02847549197594485, 0.018754993009591298, 0.18461030517374316, 0.10262354487372984, 0.12257461946818138, 0.147557957097888, 0.2071417171147562, 0.07007708082035666, 0.16342916916454994, 0.19468923369722982, 0.08354311388346457, 0.20071868274000385, 0.1288411880452787, 0.13352020793864805, 0.24934216072001766, 0.18042512087812348, 0.1832111221888373, 0.21052105352282527, 0.1684530511979134, 0.12574913460881482, 0.2200288788205193, 0.14260846220197218, 0.08279547335640078, 0.09302298463280163, 0.18215330798299084, 0.11180742223176265, 0.12795369050675823, 0.1393714036432005, 0.06283736990524397, 0.16871597257352647, 0.26499483854539935, 0.08419031262277596, 0.18759922785384042, 0.08839574462223439, 0.21000071128289546, 0.27708027391664447, 0.09851362105579146, 0.14791035754305704, 0.13340301180799163, 0.09937049805997841, 0.13673393145924614, 0.16517814789568225, 0.20047828434936463, 0.20405499565024532, 0.3595708136356646, 0.15216873387896246, 0.0689096317716664, 0.08085059828215069, 0.13938453439022266, 0.09272692995446344, 0.16786771405848766, 0.10151981135770198, 0.11054295580834152, 0.09692969596794537, 0.15568843291651818, 0.13480271573268598, 0.08644540734108418, 0.12157071486956651, 0.15497647676496737, 0.19749028097477653, 0.11683548710519269, 0.11313425587309946, 0.10114201509784307, 0.07292557192305404, 0.09548521420407681, 0.17030093188007034, 0.07796348868719033, 0.12784142032145493, 0.1814757645009987, 0.19526317144834227, 0.12218068939663711, 0.14633336555092566, 0.10114505646690246, 0.10838663280611077, 0.24273705788918082, 0.13535724081579717, 0.13189729663633531, 0.19686424924481302, 0.14248414145361993, 0.22372522241165563, 0.2439946371821627, 0.09709073531050837, 0.2282149419789353, 0.14942324329768458, 0.20499308563528523, 0.15193162966639767, 0.13314681668435374, 0.16484854622713982, 0.08262972257310346, 0.21467355650759515, 0.2799201924954691, 0.08183486804726624, 0.098057622540622, 0.11857090608006525, 0.2594956449202953, 0.18161422723243315, 0.1637116870692661, 0.13380493217658612, 0.15414389240885937, 0.11102759069012058, 0.09173073220036684, 0.15886068043689575, 0.16940983372830576, 0.10581726583862498, 0.14280516293741044, 0.15239037843721528, 0.1304295181386894, 0.21204570638796977, 0.20225855011132457, 0.15232354492670105, 0.16431315802037716, 0.13450737351611738, 0.15539578732944306, 0.0878640029939913, 0.16735012973508528, 0.040601480211461746, 0.10446205630057281, 0.11111059631671637, 0.23613068335238965, 0.15693309596709668, 0.15079964282772235, 0.2213903396360336, 0.1449238863443175, 0.22818527905450714, 0.12033554364836986, 0.10098992366223566, 0.08542284850151309, 0.13055455900969046, 0.1282406670431937, 0.20394947469955493, 0.15329774829649156, 0.11410359458457078, 0.16487535930448965, 0.12631536551540898, 0.1690384343026146, 0.26741938425167916, 0.10191094520832263, 0.13045748034792562, 0.1477414198339947, 0.06740900342382732, 0.29328217549670127, 0.116066963021313, 0.18281361448668665, 0.16875058442594545, 0.18433311924098, 0.11417425853470642, 0.20187785037823264, 0.17623645854332756, 0.21846305639032396, 0.14404832445565732, 0.15420058291525612, 0.1435701936603554, 0.11689998404753786, 0.1735285522356149, 0.1179402701616768, 0.09473625600578324, 0.3461260931386102, 0.16906000733856233, 0.1550345768731448, 0.14782070993415772, 0.1971825128120761, 0.1535859352518474, 0.13061511059922556, 0.18661488147993244, 0.16893383265743334, 0.10741332575919167, 0.19889398387843565, 0.18871287454760846, 0.2322251824361663, 0.14921203285696047, 0.1747748853578683, 0.18081296055066973, 0.18162712815307802, 0.1779980011164181, 0.18283757771695816, 0.09042832910293534, 0.12113572248528082, 0.10068307480504436], [0.01392456062603742, 0.02372475284632416, 0.05612534801325491, 0.02877774430559047, 0.08605130873019658, 0.06609845681176071, 0.015500850690108155, 0.03324517071427357, 0.009301964065901214, 0.029583867984793843, 0.030660185129231507, 0.030854763801119504, 0.011049740996602322, 0.04946254727040087, 0.0323025799626785, 0.024598054775607683, 0.05032577897391973, 0.03566067658304688, 0.03257541451603174, 0.036114304056090694, 0.009293310145186561, 0.0779336495625396, 0.023587785901561863, 0.03196791062251695, 0.00999588842293428, 0.07014361555658041, 0.028526902221323504, 0.04435771655651831, 0.03403489628145772, 0.06594631174999861, 0.03172303827839994, 0.09086178165049323, 0.060395912808035655, 0.026671933310647166, 0.03013525210741547, 0.060690573206351656, 0.08249866025101754, 0.047986659732076435, 0.036893415475083936, 0.08785033598542215, 0.05609983345493675, 0.03774135606363416, 0.0524544921673594, 0.007694546413052106, 0.08165462288044154, 0.033641977445973505, 0.021085304155525182, 0.0347366979375722, 0.03924862256333713, 0.058245090317101254, 0.03332761326624501, 0.045799118646931265, 0.028676423431944945, 0.0029072512435020822, 0.0038853374820563102, 0.02037499509301157, 0.031140686966659083, 0.06333197925179716, 0.018566908848081386, 0.017895202956072265, 0.11387539997456536, 0.05230597836235839, 0.052126625687965465, 0.03233571709584325, 0.017171738248678948, 0.04459988461026261, 0.05623109112944334, 0.02314766838906273, 0.03521652178718679, 0.030892809642659082, 0.07332789065736918, 0.04398977218736564, 0.038428586727428826, 0.06601352064359574, 0.02667972634005691, 0.03996705215784811, 0.06567406708434706, 0.05400133093879108, 0.06062735563084003, 0.05428310190778106, 0.03560659843647192, 0.07489712217882757, 0.03700761620195643, 0.016085938850958503, 0.058808804624864174, 0.056131235398953004, 0.04759066505357624, 0.020916745659985372, 0.02727397308204203, 0.043657335993503375, 0.033857022156758655, 0.10246155558214073, 0.014754712652985849, 0.020924712974397887, 0.04977388923326808, 0.1390268479383761, 0.017571779786639156, 0.08064048334715829, 0.04380026118709676, 0.06391389963908062, 0.012394322979924901, 0.0704936487900634, 0.08423360425137705, 0.003859701546682646, 0.07036850066675295, 0.058638989745128545, 0.01307222652324145, 0.037943323653551846, 0.07390441012478645, 0.019832440133717273, 0.064933612462013, 0.04714533431275238, 0.07444584276527166, 0.041332826048376105, 0.025951356754728386, 0.055993270624669335, 0.02991070790636924, 0.01944107262627973, 0.0244122478104527, 0.0551819452084601, 0.01985425065692154, 0.04842315747913334, 0.017196611208360524, 0.051999290383631186, 0.05950891705710561, 0.026905459892605583, 0.020441796044789014, 0.03308520772524419, 0.05144208016234541, 0.02362113370890579, 0.016101275931202596, 0.051572778592667276, 0.03896500915288925, 0.10481382855364393, 0.014612383092753591, 0.053190338770828904, 0.056297070451922, 0.0684632553208259, 0.037728133386061076, 0.017816918346309857, 0.10527356557788388, 0.02017039024541455, 0.009728356155626958, 0.02861333992182007, 0.01567802575957631, 0.0248620601656336, 0.009882956529186379, 0.06267890844854616, 0.07731091201065049, 0.012923825716209269, 0.042611671942135984, 0.09836632533059006, 0.05202394692347415, 0.05425094153671976, 0.05871328878246489, 0.05671735777850113, 0.03426452347588155, 0.038171510602678024, 0.02306706636332937, 0.019726239279994083, 0.031416863578582005, 0.007633475798948278, 0.02763913846724937, 0.00928333759563224, 0.042692517200785304, 0.042880231724871744, 0.03438438559251447, 0.06186253451291592, 0.02433954415121867, 0.010661242488441209, 0.012974421993168372, 0.03496482743010406, 0.07868387180590823, 0.021446727201222412, 0.0047626292930104805, 0.02551885032575698, 0.027032659216333303, 0.01955648185685277, 0.06052386481314898, 0.03976294718262169, 0.01469120779450262, 0.0538783087094705, 0.07266430529735743, 0.005706320817191755, 0.04142793969461515, 0.033958574772001274, 0.058707903184357195, 0.046925310030459404, 0.023035990006680933, 0.03055968205444515, 0.03445290832690174, 0.07258110814878056, 0.047671740138602835, 0.05536257341924695, 0.06657165400083027, 0.017185663811922554, 0.03491609274680096, 0.010489882983928247, 0.026054357276147893, 0.050718525439620986, 0.00912793378736223, 0.1051092550398842, 0.05529506958179897, 0.08833623491227628, 0.008869812910204694, 0.05918544792239705, 0.022592942207871426, 0.10003022999773103, 0.060617342861669685, 0.08121962283527659, 0.04951079165743244, 0.09412062774983146, 0.03961526458301852, 0.07466377179709173, 0.024625691397476102, 0.031324369953044, 0.1095186732709408, 0.05382641391347974, 0.05832560232750351, 0.05903587691606053, 0.08914068085892547, 0.07569985208852638, 0.10738515670621589, 0.07695553148345602, 0.02515675312268638, 0.030440009544573488, 0.01906586382838507, 0.0597813647360571, 0.03043972226160188, 0.015055090940046697, 0.016659302036127737, 0.08176246507754249, 0.024463206063956026, 0.015452004924056031, 0.046675400658240246, 0.024354427324367628, 0.047424374178292296, 0.027118267626651836, 0.028501226784541246, 0.0493416202915532, 0.07128379953604552, 0.01711862154244896, 0.01883432332937035, 0.016331054427991473, 0.02166903251030993, 0.07281508672261432, 0.10023318201063142, 0.06306521977568347, 0.03657451605484371, 0.0859955451901882, 0.0925015775306571, 0.03950339276343584, 0.015156768044577012, 0.03538495387821909, 0.03330766050625713, 0.0554290890032726, 0.01929487240681004, 0.05836128287257687, 0.031779677073861805, 0.060785024186536196, 0.07354860824923362, 0.057378422709242, 0.04198582024283467, 0.006982737254621762, 0.05829138884080514, 0.03675992082383844, 0.026676070185438282, 0.019472422859361096, 0.027167140205781308, 0.03433475075590034, 0.06782553308913786, 0.036774595238028035, 0.02923757517560115, 0.05686422066402532, 0.04566876495617532, 0.02463426200612899, 0.03462364251214651, 0.03386699279109317, 0.09213426901448159, 0.015028070061347418, 0.01746777377481903, 0.027976990902736306, 0.03050456394351298, 0.07258510712774531, 0.09776091668754817, 0.06149287027637325, 0.020865287534111453, 0.06545118912453614, 0.06434796122653831, 0.058812455033823374, 0.046363039798433744, 0.024617312310804284, 0.04051169470673607, 0.06503297406579218, 0.012379647608125403, 0.022307202903433673, 0.039906967881946795, 0.08849005004571331, 0.030904643785869403, 0.07521449708409848, 0.025031723743004185, 0.06977430755092252, 0.02153605305319352, 0.03246170025499117, 0.0645104484752782, 0.038399594129934427, 0.04670098416447159, 0.06174220508264919, 0.06278087092082828, 0.09117561722955397, 0.029052235524079977, 0.05841027036489499, 0.06230709533537589, 0.008196229145171182, 0.014904850564386337, 0.06528675601246857, 0.041608705801228364, 0.019293654327010436, 0.0762069027029699, 0.033533365330508644, 0.025120746990245198, 0.020822059107764114, 0.06280361990173979, 0.03465072755070944, 0.025888254092405402, 0.05095758317639271, 0.02128411546319483, 0.037412175743450085, 0.047997534350161596, 0.04867960924222585, 0.026367491884757916, 0.016249197933282104, 0.08184425262433868, 0.027318781564733195, 0.021800830276803147, 0.008025316844484019, 0.02708331869554616, 0.05378382708576899, 0.04063511530177728, 0.04818809106044712, 0.04202779036976638, 0.016968267211209864, 0.09256284924284106, 0.0103640032466501, 0.03631621418941406, 0.026323776992578662, 0.02133249583083295, 0.061391202747941985, 0.07023253538195165, 0.019370736178731727, 0.03412837432997842, 0.055331543027873964, 0.11767335746797825, 0.17152437429514625, 0.19979373882374457, 0.1962629927983207, 0.1786680982237862, 0.13478062175694974, 0.13864032593705963, 0.11791213175221799, 0.10477418350356241, 0.1540869873978438, 0.13921561200291882, 0.12709249276667833, 0.11477509363284034, 0.19191095455279275, 0.21743052308597874, 0.22773575398229787, 0.1521675387818006, 0.11545237664493824, 0.12374844236840164, 0.15291318748026125, 0.1017446581634783, 0.22921474800715524, 0.15604469444482558, 0.1232506920613589, 0.1413630330634694, 0.2215326787723649, 0.1739950691379847, 0.21138788200914863, 0.13818614305027072, 0.1108734461388761, 0.16432797416083275, 0.17225606487162654, 0.15494053191956014, 0.1403271749375328, 0.19812910637307554, 0.22165479318749523, 0.18666935033134877, 0.20084323331473336, 0.09356802554741021, 0.1606887500853308, 0.24506441768138643, 0.07412590912633366, 0.15309122631386404, 0.1175299228259152, 0.2031577994386035, 0.15314112928125168, 0.16218988405119988, 0.17208692797970387, 0.08640268261754706, 0.19335553590809146, 0.15523553705744206, 0.15910238117700623, 0.10538736793903575, 0.1868738345200977, 0.07823287584488431, 0.1656646750146343, 0.18297778712885995, 0.1570674371454985, 0.19336031629673897, 0.13943967739901236, 0.1824277206774681, 0.14481597519930334, 0.12434700218540047, 0.23081142845894062, 0.19990164996875873, 0.1354565411325424, 0.1381894678718621, 0.13094999827444553, 0.11049025662003026, 0.18351118350701948, 0.24140919769002547, 0.16745876100274826, 0.15989258554914307, 0.21143605361782739, 0.25194339694515355, 0.13289468182671454, 0.13593048908777777, 0.24380683838840456, 0.10344004138342797, 0.143042006680081, 0.13117919645963177, 0.2468002350219796, 0.11588826535209534, 0.23470424295913792, 0.21219840303303736, 0.20295702311540806, 0.16423562992243998, 0.055372103553025, 0.13098853249703685, 0.10385977329626199, 0.11081403602034816, 0.25402651258534004, 0.0756321682204162, 0.16200502703507103, 0.1195000711407873, 0.20164952553328008, 0.12055472906438575, 0.19897272239529318, 0.1093858949119045, 0.12891980398806835, 0.17042021176988081, 0.08171090736023842, 0.2086670288155156, 0.06835676143847166, 0.13857029017902192, 0.13771168947700532, 0.14196723128759092, 0.23578923796453785, 0.24756068453913738, 0.11292322929347716, 0.15639536353128572, 0.13615231750713241, 0.1424096777073799, 0.1297943852841854, 0.08844783094020621, 0.13091645894512055, 0.1417213170638969, 0.15609265154888555, 0.08449594340016765, 0.10013027341976281, 0.13486504464620544, 0.17767370077631167, 0.15450786078168502, 0.15243113431478703, 0.12233754589913354, 0.11906252002283452, 0.13360737342267268, 0.1388739521104482, 0.19556689466680252, 0.12615719900256203, 0.06416121197323646, 0.10431571818527677, 0.15674427061552004, 0.20883403598300873, 0.12509419838146818, 0.14953617997948201, 0.15734957200625252, 0.1575410480220472, 0.09810307453716956, 0.18474205697496093, 0.20600243711904173, 0.1511323241697204, 0.14410970342015067, 0.11754682272552483, 0.17360804151863823, 0.20150442848042135, 0.11066225868078972, 0.12094759427371526, 0.10502285564378386, 0.1877913167399745, 0.12432502312285286, 0.24281807934805272, 0.11210389059757996, 0.12663028127844297, 0.12310541114739834, 0.1876306374587359, 0.15646224300707542, 0.08831921243859876, 0.19657279875489975, 0.17722196937088044, 0.13400955426116146, 0.08026795777221842, 0.10025282450500997, 0.1259497806970631, 0.12838977839677565, 0.11453517787759343, 0.1993901790269921, 0.10027379233149752, 0.23821105639780724, 0.0667065314407791, 0.09493166205262947, 0.1645038219829721, 0.2646541745672303, 0.043350215175098954, 0.11105670203124324, 0.21675696326119287], [0.020493369083851576, 0.013333619553445569, 0.029210955535452214, 0.06580320652574301, 0.030184268328030745, 0.03558739644264983, 0.039966297561242696, 0.012656801939761687, 0.013103977037263254, 0.01108864198378738, 0.03080370595618602, 0.08121295787033536, 0.03317728766330308, 0.07812982935818934, 0.0935374356565937, 0.03834001164162352, 0.018514592703732274, 0.01734920443155833, 0.04491900619600089, 0.05499602333011647, 0.03614571749142582, 0.05540239083911142, 0.05829938296829501, 0.04675132380197606, 0.00877220947821174, 0.04994505625819007, 0.03855730865090605, 0.0403104625612257, 0.049854864726864526, 0.055825857430576324, 0.06749516533267114, 0.04135839423284896, 0.0058064346235515854, 0.025318141035254926, 0.03716488639193197, 0.03858104588523988, 0.05845668380178752, 0.0256021125918074, 0.04941462847073713, 0.023940747506135417, 0.03791348835934074, 0.05566441589185307, 0.05808138881900138, 0.04170294993767335, 0.002692699701818187, 0.014506106587847876, 0.0657149148924697, 0.05666234883509817, 0.030513262871893185, 0.017893779947752916, 0.027647699499803207, 0.047200979109132485, 0.0728392644575046, 0.06065258290618659, 0.05106395065423943, 0.06895733606671134, 0.004787367708500355, 0.009301330128143872, 0.08929798169241798, 0.011703962846959551, 0.04148919608504061, 0.037122617490709796, 0.05182984322609921, 0.01293863036534599, 0.014371346933917414, 0.01410890244803722, 0.05457645995662578, 0.006057338473657447, 0.025946695109709136, 0.03377918379321214, 0.09411786217242481, 0.0705482172329099, 0.01686429950378595, 0.04456314303341412, 0.02696307736539072, 0.026226169730146087, 0.01168509888943405, 0.029380816380463304, 0.07898620840522551, 0.015770222526043653, 0.06731266020646981, 0.026866190225606965, 0.057090036571025855, 0.058841980062425144, 0.050780923301053625, 0.043259541008381114, 0.022058105584414258, 0.05998162778034326, 0.03615984032230993, 0.019440681921438347, 0.053105850764099634, 0.03820337602988847, 0.05288904022064902, 0.02247268938639712, 0.016136372334233696, 0.020564199658110738, 0.0711641519240314, 0.002140679008011977, 0.026399192603064642, 0.018068677820866148, 0.042322040911042885, 0.11338131156780067, 0.051056849019181345, 0.011828354458444783, 0.012718613743932258, 0.032358565668184916, 0.0525054102012467, 0.07548397617234338, 0.026969589112747102, 0.012562228385509263, 0.052024900702939886, 0.0317649471182977, 0.04215403399880856, 0.005734566478959976, 0.016993655365020517, 0.017399235718673276, 0.006794097679366748, 0.0231034746919308, 0.05939643619762314, 0.010506832679252951, 0.03654561538790022, 0.01965846156611318, 0.02609346223424279, 0.01327021141356278, 0.030668064343532732, 0.03410287892385837, 0.0626969919539988, 0.04148127473590355, 0.004560014837601733, 0.022728978355805722, 0.026626157641951597, 0.026180277233042067, 0.03430842031394282, 0.016783276129694238, 0.03141113707134801, 0.04370178058443051, 0.08601014682602498, 0.031127255530126637, 0.042583460754324357, 0.005374669863451874, 0.0303346149983906, 0.05779967913704534, 0.015674141693800207, 0.031502680747859904, 0.0898818479430291, 0.03525733512135283, 0.0180357743445183, 0.14125268575885605, 0.02618722948095491, 0.021569364471361045, 0.0459843970114185, 0.029497610314959483, 0.020458096480597893, 0.05835031249350118, 0.034387748718502066, 0.021006929530431668, 0.0855312192992818, 0.030993410393655784, 0.026546262332328388, 0.014540536494384852, 0.045712573694125305, 0.0954145732365789, 0.07348476248162408, 0.053548649584333745, 0.057249221980812094, 0.055105650512081, 0.03561499476012203, 0.041944455325363145, 0.03123122323755055, 0.04163573338319698, 0.041592637107016585, 0.05904631486402885, 0.01247728551407495, 0.04021600392016192, 0.031938232376330325, 0.007991630522038547, 0.023921099266097434, 0.05862701196043242, 0.010923752091794966, 0.12799814658900424, 0.0436987545371296, 0.07219715254201044, 0.06584765494710977, 0.028367908333518335, 0.019485306543027683, 0.03315354659852963, 0.05066725117484889, 0.013708727802300166, 0.042069132304600174, 0.01685017858812165, 0.04197558530816629, 0.04967237492242167, 0.08539962071564891, 0.02315373772064284, 0.05081329817673372, 0.021850647059299295, 0.028208133036030397, 0.021029149910675424, 0.028668289493408897, 0.054296148385131554, 0.07102470860005387, 0.017151126653076183, 0.05988979299042014, 0.029066976970962943, 0.037571284544443896, 0.059144220900751894, 0.07222054120633872, 0.021621697852688453, 0.016180261511415724, 0.03799991839895806, 0.05176316293316984, 0.0660053005201682, 0.02122470725988669, 0.028244587329907284, 0.018585785254535657, 0.0037238976191503992, 0.024941099372001427, 0.07849713021348562, 0.04285008233461169, 0.008163429090693113, 0.03801555425349263, 0.03982896480949656, 0.045251518998655586, 0.037066585819927916, 0.025110420125025897, 0.0070925052052423845, 0.040007888474651886, 0.025630499979841615, 0.06953111293935968, 0.04143317973601722, 0.014649882139037214, 0.0455381814390421, 0.055563292285848054, 0.0740415322023534, 0.03162300634768701, 0.0381192097800874, 0.07545739292137085, 0.057030028903916966, 0.01564463294456683, 0.024826421755396073, 0.040665475366216515, 0.0030767709399843893, 0.02694503024911448, 0.03788859050180163, 0.031667856965214014, 0.05040790742984222, 0.16701542592096716, 0.05281239695426437, 0.04566176674298702, 0.014355976337326631, 0.041144069644712636, 0.03689205949945796, 0.013932754893997505, 0.03151972237373552, 0.06869217005348013, 0.024102575919260422, 0.08233568270600612, 0.03049923580199961, 0.06399124387591597, 0.06931260168071716, 0.058272646499737624, 0.027163035889726975, 0.044275090143445044, 0.031493650486452446, 0.031236041930594274, 0.01634569245300466, 0.011257427432874759, 0.0071774662712649, 0.022130514299797437, 0.010644879807988483, 0.017634870957643274, 0.02338057060936286, 0.11055819329715545, 0.06056842814770438, 0.03625315749236653, 0.027499074612053174, 0.029814967983252103, 0.08251170672836804, 0.033073245262306546, 0.05798451317053649, 0.04349245472000011, 0.01784162085142828, 0.020183710599197976, 0.029799772629273996, 0.10195515614243285, 0.04283039387495768, 0.05946416220056915, 0.030375866917893294, 0.0455470603980845, 0.01799184686294006, 0.013201132307820504, 0.028360088491031242, 0.05618645118609552, 0.04638222264005773, 0.05220696149814514, 0.06261955195617291, 0.04425680745513209, 0.01518392873432247, 0.0268084769918313, 0.09415498679323543, 0.08471781778479777, 0.05865102881685861, 0.04051077540122694, 0.01896067804116155, 0.03647364142741408, 0.010523855152930464, 0.0785742829283399, 0.056797145835814945, 0.008017449600306611, 0.0330557861185122, 0.03798966431209157, 0.020307248022647637, 0.037774251879102765, 0.04818445980368603, 0.02309670630511978, 0.09045813758406909, 0.020125846063057264, 0.01943023439737097, 0.023476239669347004, 0.07574657579102824, 0.11650769340415155, 0.01918185911622019, 0.04954499748325156, 0.13229687277588154, 0.08984486887892408, 0.030216034163811037, 0.13808146479629702, 0.019386927447011395, 0.07825924459123805, 0.05119281430398265, 0.024721596029496962, 0.038895486673760804, 0.07618847828839095, 0.08088966876628899, 0.02750065275317719, 0.01357627981868122, 0.01528429295567255, 0.0550498639894349, 0.05798650499913962, 0.027361445001236377, 0.07435143775036258, 0.05759326823716683, 0.07133250740627128, 0.04627801553015748, 0.007175978624276938, 0.05502214692833443, 0.08722569853548082, 0.027372966963617552, 0.048289478966786016, 0.03566313572528382, 0.025932183489203457, 0.05728327075860674, 0.12933480913840956, 0.1248408837484256, 0.09153694259904085, 0.2368489061031611, 0.13283218437385175, 0.12503447416689129, 0.22648483965425725, 0.18555152079751416, 0.09312727984281317, 0.1318863415790181, 0.1854934666546122, 0.23477147483537275, 0.12865240865897748, 0.21579172312011644, 0.26261049713338575, 0.16937986436870792, 0.14927301345573318, 0.12099002022296192, 0.17490518159202992, 0.18824595927951798, 0.13701203669751846, 0.15893201854440475, 0.21523048710678855, 0.13493449817742073, 0.15196582783133755, 0.224100666781587, 0.1613250320717212, 0.1503559400237376, 0.1466820428087827, 0.22615612664770698, 0.2976738511314315, 0.18667449844219994, 0.09460935354112618, 0.13233929872512817, 0.18456110700724587, 0.12102093953158587, 0.19691223699238994, 0.10075389197276485, 0.15579326438807672, 0.1068365381610009, 0.10552766928148848, 0.1255109961775522, 0.1693601912308124, 0.11602509631625108, 0.062108031218691226, 0.11290007045552616, 0.12457696645851098, 0.14278329878805146, 0.11137300441342016, 0.09190888594715826, 0.08759212605054341, 0.14683826345830195, 0.19058445799014262, 0.12764704083242726, 0.1481976558364207, 0.1377743248256945, 0.1071699626082855, 0.132723307958053, 0.14051878884915384, 0.08199141045371372, 0.14191832423450487, 0.11723248918931331, 0.12159946614936476, 0.07006964976749114, 0.11368680444936599, 0.10812522828458779, 0.11316165117727173, 0.16354031320060455, 0.0948476068855774, 0.116391439561642, 0.20965428632353583, 0.14554323778758127, 0.13374666352906536, 0.13629856369187757, 0.11019751144152497, 0.11471317840680001, 0.0765756591253223, 0.14451355433031438, 0.1747661519555315, 0.11201527720737843, 0.17480595788407713, 0.12844985501179773, 0.20213125694182613, 0.22328588630883928, 0.15597749321210772, 0.16131910255118725, 0.11529868408556908, 0.1267293824123279, 0.11826371248330801, 0.07260003818138953, 0.2052876311204126, 0.1284419030191437, 0.19453387106618575, 0.2096842403613752, 0.13580495792050518, 0.08134741396192582, 0.21735556904346715, 0.25822856613705236, 0.13338359913999034, 0.11267514704095741, 0.13286273596027207, 0.15519510293679853, 0.16613203461372084, 0.17306051847915496, 0.11517830102914765, 0.0921267919963406, 0.13900028000916206, 0.24087537230262834, 0.30371163521082173, 0.11583699108732325, 0.1783424189254161, 0.1409357705063397, 0.1955474207117673, 0.14224689934522877, 0.15341854504039212, 0.10351006948058644, 0.12989249050376878, 0.14765917263444395, 0.17227147856066305, 0.19268154707406798, 0.23250204661200125, 0.08379981462513247, 0.13415520289732566, 0.12064599311880528, 0.12366972683418183, 0.15558082820667377, 0.17857013090002924, 0.18151982987840332, 0.11550606408667181, 0.05974026794935908, 0.16316777996478543, 0.15329074625286365, 0.13668189876742903, 0.16994753552059974, 0.13072363461457914, 0.16663765264374597, 0.1915885081454631, 0.14452737455646839, 0.1190975608844911, 0.22054862351186816, 0.15172155303580148, 0.1140951676174037, 0.16256830084227747, 0.103925526622803, 0.21680688155033898, 0.11347881157792385, 0.17465773519248734, 0.38046874226100985, 0.22246966559079387, 0.11383715686538529, 0.2206092670319542, 0.14351097506380853, 0.19404388122981597, 0.14290141422421704, 0.07428694080801741, 0.20243396892422633, 0.118291950484197, 0.14146850804888433, 0.17173975225417845, 0.1005121069629827, 0.08035084848562557, 0.27401656573337896, 0.14186797693612116, 0.09742701726575052, 0.23941458052685186, 0.14877050574268066, 0.12461769169256573, 0.1580442145707146, 0.17583227055447717, 0.11202444727983206, 0.20003366223987074, 0.2104361556590565, 0.12150028074580817, 0.20614713580617983, 0.1228710188860855, 0.13975647007746084], [0.04594588577146492, 0.024997123381904057, 0.038060044809695215, 0.08226848913416748, 0.05479578709890766, 0.012152716085585135, 0.06192227404925132, 0.07763227823400691, 0.08088384649806446, 0.03462669537252477, 0.08169301920720647, 0.06134666622646394, 0.05107695499675409, 0.06036255350937286, 0.08055199253102464, 0.0492962678864358, 0.004783690007658856, 0.04702769385109987, 0.05607493176695801, 0.028442935154382742, 0.030209752242831938, 0.01861767366438383, 0.0643860434572543, 0.06113173642886743, 0.01442484476888973, 0.06261394802300681, 0.011931909435999491, 0.01237139301074128, 0.05787780861400309, 0.026603586776482484, 0.017729151483264663, 0.06722318113691385, 0.05058919064580433, 0.05497962138765762, 0.03749282181923909, 0.08079812892021672, 0.05601719172010499, 0.02552308870719806, 0.01404640691039423, 0.015261941382871761, 0.03689127042889595, 0.03847904893900118, 0.02495828655458266, 0.016785595460884997, 0.05069587221970001, 0.0447768317685733, 0.0782092496932995, 0.05830066616556818, 0.04209214941628518, 0.01739678615253539, 0.10314383348750492, 0.04074972205524964, 0.023881002224140593, 0.1016756259806214, 0.03294209484010935, 0.024020591104823737, 0.1463176607484779, 0.03924200739411097, 0.07373069968795584, 0.09200234867392049, 0.020740593317896128, 0.03588124861820571, 0.0656935487002615, 0.021898154086703737, 0.06734811475560551, 0.01971640654148594, 0.01622004637254342, 0.021434760907845154, 0.005938040868063728, 0.04200393439180428, 0.05753636322615128, 0.037179848089093165, 0.05267576134252933, 0.057558361440896995, 0.03665491315205732, 0.024644518008215294, 0.05094164471712805, 0.04681374081560681, 0.015642838383604203, 0.12662949220788094, 0.1000353627868237, 0.04025708155466184, 0.07841496728360653, 0.1277874877315856, 0.022810731428645314, 0.062382819296251384, 0.03259512212788386, 0.08447670693238897, 0.09660781646567969, 0.0689120679312656, 0.08400370126530048, 0.10763643354537988, 0.023754057624647697, 0.043814858992493926, 0.012050708605637474, 0.004194156621627871, 0.02764983113945252, 0.014129521704519228, 0.062113114212068825, 0.05088126166693626, 0.006504149200590027, 0.02140099175214287, 0.095223625821452, 0.050160966648329655, 0.009757073919078516, 0.013096125593649284, 0.02704698697573716, 0.027663448352306604, 0.0743685138501948, 0.03873707118233846, 0.040715343859647556, 0.03846106119453907, 0.014650767928199663, 0.017213195096701384, 0.08277804485612339, 0.02087199654910834, 0.019623058727912365, 0.02650966822740532, 0.0031803005408766053, 0.012094502021828967, 0.01898411650120491, 0.04205891269169027, 0.04398642821357616, 0.02718929929899112, 0.026842604293638182, 0.11271272365364338, 0.10383445409036453, 0.04819868605643992, 0.043832118953427965, 0.03960070891245719, 0.039862814404430895, 0.04242147529317487, 0.10395853735146024, 0.029608491965900027, 0.023678919721034267, 0.05903365526108011, 0.025803963353316632, 0.02850190477235423, 0.0298852508046454, 0.027335445892306107, 0.05274026977619337, 0.014412323061767367, 0.029083382743861408, 0.042347026868693294, 0.00944429649896319, 0.04061175728096597, 0.0929698411134943, 0.04005876437370335, 0.03948321783794992, 0.026317253753903414, 0.07419943058442685, 0.00871050301113076, 0.008711169507624883, 0.041233491257674275, 0.04775065485568297, 0.04201659782519264, 0.04244243162834356, 0.016142127569764853, 0.015402173777411302, 0.044450842204593846, 0.039804407861083746, 0.04355592893496637, 0.023660633202281692, 0.012012381226785723, 0.02353897652468614, 0.11722338040389362, 0.0779214611036643, 0.02394693175090417, 0.043836523958992575, 0.025900831340902278, 0.08404391322044596, 0.03375153184958524, 0.029654870928835966, 0.05730546049533352, 0.03624976372286197, 0.023071814193240097, 0.030176753005493554, 0.028556298930197958, 0.03825323303200064, 0.040573973824540456, 0.06245653610676528, 0.03492512875386784, 0.03609006120372684, 0.05136830589523719, 0.04168201658514239, 0.044527914480216084, 0.008308581684926345, 0.07206145538798264, 0.041268106940532887, 0.007021084743281527, 0.037459328455189546, 0.009049950824720005, 0.03276066989788125, 0.03792345516323563, 0.03809289849032799, 0.0461752716481926, 0.03322771157047922, 0.08977296386635111, 0.026271943483621846, 0.10879532539195592, 0.08103651249961508, 0.060390611479599635, 0.020827467688509536, 0.03077281729107903, 0.05037478944887558, 0.0574315777198682, 0.024626823292384227, 0.015266395226541548, 0.043243583396918354, 0.023770570649855563, 0.0762771146612302, 0.0809627458933861, 0.03896367232946139, 0.044009805386585575, 0.028273014937557524, 0.05067125781469288, 0.034785957391103434, 0.05032774398944551, 0.029148105682144244, 0.059953592792754216, 0.10600950028146468, 0.006839064167692296, 0.009985558684885262, 0.04057816432548627, 0.03388889141440873, 0.007907754428038795, 0.047056705600792365, 0.01956999373261727, 0.09130782102264705, 0.045753666650383704, 0.06826290034598882, 0.05036755374843075, 0.009669916095933127, 0.026977933725462328, 0.02360357305846147, 0.051582278082928354, 0.014108838288173562, 0.03805409613696318, 0.010567178382658431, 0.04607163144335632, 0.023303038680986054, 0.0390436404174374, 0.010848921580961155, 0.04757815100733311, 0.025274740239124627, 0.04126920627670423, 0.05960504193940471, 0.05616211640318075, 0.017152542000516288, 0.02900283625950256, 0.060807416936562914, 0.04828256885370901, 0.05903234142028998, 0.03256538642510291, 0.06505018040057152, 0.0269419735582966, 0.02257825055670354, 0.019188439811489755, 0.043858296177800626, 0.058342115352711374, 0.03332793502317321, 0.07049906503168807, 0.06277383440324376, 0.0400528310227298, 0.025971575730269956, 0.02059765663298388, 0.04752747429114196, 0.01723418016016724, 0.020531150625057278, 0.03287362190143716, 0.04206613307037661, 0.022309110462365132, 0.03183901824447657, 0.02479038689465773, 0.03224014762728926, 0.03215068770993141, 0.10260214037712544, 0.02705886516900313, 0.07009529839119605, 0.03530691633181226, 0.00814800295272782, 0.027752699510705088, 0.03308761707176605, 0.04159424206121795, 0.027327898011032133, 0.025611121785796942, 0.01465828420834676, 0.038451557873838374, 0.09904180803606588, 0.01999967521236789, 0.045201700300939625, 0.05759867298747263, 0.1151193199198573, 0.018021684072370973, 0.028436925194616762, 0.0846225930558097, 0.08475390818691061, 0.016219130897473906, 0.031834272329785654, 0.0330961819347595, 0.044634090436081734, 0.01797837520679159, 0.02295034903762562, 0.015962516340697487, 0.021607410312900623, 0.00657005622352083, 0.07633047268515633, 0.05041444982071558, 0.010855812541840058, 0.11261381404173952, 0.03496143749103912, 0.043274360979276325, 0.06342112890354569, 0.0660352775406453, 0.06869089834752583, 0.04988876411751394, 0.05751225826961379, 0.015070583153095458, 0.03479056157952836, 0.035134634648960446, 0.07128622803476549, 0.023435384200345126, 0.03290340356949357, 0.021857250737206593, 0.04354718404131071, 0.058480815571402354, 0.07627256409895998, 0.003403935491317703, 0.037272307240674575, 0.016064493177128176, 0.05955254576439339, 0.04886045578807112, 0.02968629010983052, 0.026574603755087144, 0.007667194201325578, 0.04127207527598066, 0.03229657383335214, 0.05873046064328763, 0.02616330263985982, 0.005716730036862916, 0.037425942343449405, 0.060381211580768715, 0.01386091595650801, 0.02249287005754248, 0.0196637092683945, 0.05435444001529006, 0.037738061885559754, 0.02312696486290905, 0.032021735960076896, 0.0888060076883243, 0.013597031225330167, 0.01869289775288874, 0.17257734682531128, 0.1381206731762617, 0.13391373198359244, 0.17897362940974776, 0.15063640481281668, 0.14568833484044, 0.2191668920098774, 0.10913253431358647, 0.18073540180921557, 0.16033475617727927, 0.11262717461513896, 0.25611819308851996, 0.24786802369260022, 0.16863323507770417, 0.16576045132692785, 0.1174823487658174, 0.12463882805839663, 0.14860069469338463, 0.14320538259081303, 0.1457046065479517, 0.09746402697337252, 0.18386940622041303, 0.10772428850853637, 0.21556033392346677, 0.18916368664753055, 0.2328612192744209, 0.07106628419170458, 0.21746939438725674, 0.14472831941900716, 0.1921872977888392, 0.07106204006460405, 0.2295269901233335, 0.09791342181063468, 0.18784068344581514, 0.08266005965490496, 0.16993455799116244, 0.1564730295250493, 0.21325528261161622, 0.10335191062861875, 0.14007968257271475, 0.161931605168408, 0.1383543912802012, 0.09057782350047942, 0.15891711047339827, 0.1610512782128588, 0.1621488677037339, 0.08096038634257932, 0.12978683165725202, 0.09090869687497617, 0.07792694629320214, 0.16585723887528145, 0.0964872265655187, 0.18595175577267525, 0.16235379622347895, 0.10662037113140668, 0.1450113735852703, 0.20257232440335138, 0.12667839926096702, 0.15971529748170607, 0.225481586230378, 0.15173494425271788, 0.16874203488471048, 0.16158144169997785, 0.1209815702731571, 0.12783536822685312, 0.14900197154812275, 0.13630175061764258, 0.1308798705858569, 0.21265630910713829, 0.0962880130616888, 0.14138120466903334, 0.19706963741731262, 0.12366542142004737, 0.1386256476924304, 0.16879990516651064, 0.15690110413537872, 0.2491447551836891, 0.09725420315179134, 0.14617132263318186, 0.15897427595430808, 0.2589347766291711, 0.15488583324176652, 0.20514673222937893, 0.13468997823374887, 0.20591171698704844, 0.14417371772710355, 0.10552141800402634, 0.21927213716891505, 0.21408382202348403, 0.16769062517391098, 0.11675235124364977, 0.18708415629882968, 0.07567540622286259, 0.1268767164419255, 0.06289499503890834, 0.13671629611522923, 0.10780445194893307, 0.22772148942514775, 0.11588964431035904, 0.1612896847748949, 0.17742391014772077, 0.07944099650147461, 0.14625874858710075, 0.13803211341221489, 0.14762912666605366, 0.1203764833870434, 0.0984099846813948, 0.18115580021854372, 0.14929547515367309, 0.11154889820083497, 0.18500649520466406, 0.15402548585928258, 0.2158503135245654, 0.10464155070123174, 0.1309875365827353, 0.2530604144257884, 0.29320470868579807, 0.15255236006792516, 0.12290696373149274, 0.24427225212416342, 0.24616592954243385, 0.12295355719904746, 0.16641637580769678, 0.11381208280762357, 0.11959027799387133, 0.20416269229064066, 0.20375383116545218, 0.2345149426330482, 0.10264583037144716, 0.09687849065108646, 0.12751254643644058, 0.11727999430149795, 0.17460266879249006, 0.19868583778940863, 0.12829628502649645, 0.22617149437146805, 0.15164158877826509, 0.1388146262615919, 0.13996876836303743, 0.1661955586244022, 0.20867386231980017, 0.21710366401220524, 0.09951644547043309, 0.09422620232667654, 0.1300571687639721, 0.09940554658251424, 0.17024598805414093, 0.11168634203533012, 0.11254527215515414, 0.13179401266238383, 0.14229747646998975, 0.16667309187112317, 0.13334621404928546, 0.09312521906629687, 0.12445726522034216, 0.11044396958764523, 0.1018185550046544, 0.14677015824183343, 0.0774420126371326, 0.223845666755111, 0.11244960309517, 0.15111810557784575, 0.11172252436799389, 0.10908510581019426, 0.07798227316309368, 0.2370345904942482, 0.16443594659288086, 0.13035260291109163, 0.08791134722771184, 0.07390271707047379, 0.1408457858187537, 0.11718929715214238, 0.15162868785762018, 0.24370209884739694, 0.1489091983004924, 0.11842862823076787], [0.07002988214334173, 0.04590128030207369, 0.028022567388571562, 0.06662173316844049, 0.037204083280577775, 0.07905412976059221, 0.029517902068853862, 0.12750865470978523, 0.03198146463311728, 0.03439583860698246, 0.029813196404927203, 0.033943823749019254, 0.02330144713332336, 0.01036988775951848, 0.007136865047692892, 0.06997155986966626, 0.033515293316374865, 0.05998890944606355, 0.03002162403126638, 0.04287014617734859, 0.1269142624110945, 0.013128024537206419, 0.04181563381045576, 0.0711038378217528, 0.04797590385761954, 0.05511177921547525, 0.02841610484005463, 0.031585423989341624, 0.03693991318164814, 0.02128168504925505, 0.011673168027623287, 0.062490220992795886, 0.04434836262296285, 0.026749643354466366, 0.08140870099586826, 0.0771542776736521, 0.08689603557990444, 0.04998453276892824, 0.00824879139526597, 0.08997835203885071, 0.06222388286504054, 0.04985586447160571, 0.05459999034722006, 0.03529907542190725, 0.030278725053874717, 0.03754138796319885, 0.02633302941948416, 0.055038981710470496, 0.06282043936211737, 0.011063993104823656, 0.03760557847037431, 0.018332003307859265, 0.039657047018408775, 0.014903257101503833, 0.032328960200351094, 0.010878100912387093, 0.05659818897143968, 0.06744911578754265, 0.01352487723418181, 0.016756279191242594, 0.0428452521502491, 0.019068935840961435, 0.004612529207201254, 0.05652740627767579, 0.0028008641346523, 0.04911945096307224, 0.027028654491709127, 0.0026046783539406477, 0.07985804710657367, 0.07051927443113058, 0.040619797373731295, 0.06743839055660271, 0.02734799441250582, 0.06611964680374631, 0.06939839586735734, 0.040448929123099775, 0.019557334129668532, 0.05671219051545186, 0.055314930411235946, 0.04840606988798227, 0.044682350144871784, 0.020894264809847362, 0.03486889790022566, 0.06788123534211228, 0.03143270436163632, 0.04188543591167658, 0.030622625753523845, 0.03100386366338259, 0.07928991630192726, 0.028741833934139822, 0.015940543981419218, 0.018219880594481385, 0.027418729225774447, 0.017944064043882876, 0.0214311545489416, 0.04080618656570873, 0.03308333464026932, 0.045484762128082015, 0.07322240801107499, 0.029620299296033, 0.026707759412426143, 0.04190234347216545, 0.033395841056781436, 0.03954488408541487, 0.05924866166746905, 0.057041485748824575, 0.03996455854165458, 0.026914674015114867, 0.04950283200389916, 0.027134951106422854, 0.041827404751412334, 0.04364478364286404, 0.07913599391618083, 0.04358111407547709, 0.010163699982747918, 0.05981237597523197, 0.009075506560264096, 0.05543384640928238, 0.04115076908361047, 0.03426075815373371, 0.05262291659751246, 0.006263525771623057, 0.009039703441122848, 0.03793689617586713, 0.06207547631234892, 0.031765971760896426, 0.05148886132144159, 0.08319055255983146, 0.08603666112908433, 0.022948290176329114, 0.03176899014731809, 0.1257485600428716, 0.0372092773567044, 0.013899213649452695, 0.013136310735717418, 0.0591104670668081, 0.0745489888433968, 0.019887954695150256, 0.016114349221630443, 0.0328758473868572, 0.05452321684588829, 0.02760035143564305, 0.11226789470040992, 0.05289394701380403, 0.05158089146378541, 0.015054587237236482, 0.054808917845929825, 0.05358521496095965, 0.07529825347686007, 0.10982405890019671, 0.04328083825267611, 0.05304907215759159, 0.0419339407686024, 0.07706295999307787, 0.010509872133092535, 0.010973597602588276, 0.04871368100265822, 0.005471079155892855, 0.004715758597388143, 0.02925245451831049, 0.09381301280471588, 0.028313416499464263, 0.07548248996177027, 0.014624282353437476, 0.037757558823232694, 0.03638287916058495, 0.026723385690861655, 0.012278107441811553, 0.015143726355276041, 0.02873455418363935, 0.06034232112729262, 0.05803933059195838, 0.0440376028869181, 0.005321003010331263, 0.0343788774203389, 0.05110172261934608, 0.027700866001748273, 0.025233178054012602, 0.012239369248310405, 0.05901119356314021, 0.03024016018776644, 0.059225728825455716, 0.045161128284469734, 0.03563055400586417, 0.08085304210262914, 0.0535931516318552, 0.019546049654543884, 0.07517373354564752, 0.010260040327275713, 0.04473811368488016, 0.03742586573465698, 0.053891876126609506, 0.00785825317800646, 0.08902389841574816, 0.017735542571772973, 0.022210066785074534, 0.024804938734779437, 0.012307295391726638, 0.03195480668857213, 0.08533076473301457, 0.02637790110442908, 0.07255699170092422, 0.022942146151176384, 0.06222134711401117, 0.01206607441417873, 0.02436540536432257, 0.022274362629339583, 0.05257826516284578, 0.0407828974928106, 0.033411836972640406, 0.02077621257593555, 0.0984702451575187, 0.036219296406113335, 0.019849248102775986, 0.04927859806846227, 0.05502467884892418, 0.06019211426797894, 0.04062589160316894, 0.034328641204704205, 0.013441500054942745, 0.03547139157871566, 0.023941490611421968, 0.023021116409631028, 0.11571472345460808, 0.028898979634827668, 0.031906767230060314, 0.021403054443878994, 0.03590614264530521, 0.0731354646925484, 0.026237360359500014, 0.05335452290432108, 0.05762396154985313, 0.07064526525115775, 0.030457478264466892, 0.026920973173072262, 0.018805882315181436, 0.02217706754773615, 0.04984008306036553, 0.038617875562199665, 0.04814965642928597, 0.012401908207985183, 0.012459305430492087, 0.0202335043990564, 0.057687366816906206, 0.0873384130517802, 0.09048648283726747, 0.016000139876268804, 0.00898626785079438, 0.022726500061370676, 0.041554045427830956, 0.025324170147219015, 0.08487613751522957, 0.018028653557262114, 0.05894573518045007, 0.04086137170933428, 0.044201315876336834, 0.031282305980341575, 0.03000632908585812, 0.03717283072370676, 0.03279343930884235, 0.046938620808143774, 0.039324319711135286, 0.030614428612734043, 0.053162843875226476, 0.04316505172380036, 0.028083459887232994, 0.024428772326979428, 0.0573841875208722, 0.02934354811816687, 0.018891854617264003, 0.03515293265903189, 0.012303415156390158, 0.07460184891017214, 0.03539009815863064, 0.027044851505648226, 0.017583646488586263, 0.06010911630226239, 0.03500459888469308, 0.08701508564333763, 0.009053648156564563, 0.07698752331517397, 0.05661619969853952, 0.05094092459447923, 0.04461465861588236, 0.027842877635491953, 0.05952154601653738, 0.01612354227672181, 0.018287152690332265, 0.02841768681161827, 0.051487099319215746, 0.030160257217263987, 0.03584680147469044, 0.023841326530542106, 0.07425759964051747, 0.03658595374755321, 0.06427736622431586, 0.02246635192404351, 0.018829611888636025, 0.026690012985660184, 0.061194180255575534, 0.029933433904643023, 0.006162016727631131, 0.033381124507756, 0.05187616473244083, 0.03311907647237663, 0.01569928086903547, 0.032732849414911, 0.08268953871823127, 0.04270465586394553, 0.0482287856509849, 0.021724202332176992, 0.06762530068836867, 0.010088098595940299, 0.07956503379729488, 0.02885311012036137, 0.09159167192035145, 0.023754660918888067, 0.051754031165112416, 0.04540477871834751, 0.01871850998741725, 0.046645519398753686, 0.012487376807257535, 0.05354819759245842, 0.134522159013056, 0.055718490207988414, 0.03527427715579829, 0.07858082531921326, 0.038781646008212725, 0.051731902715419574, 0.08126699005163486, 0.14535822755386754, 0.0059164204304256755, 0.05867882631719113, 0.04101136789446877, 0.030481870503975984, 0.01254248534209065, 0.056131036216092695, 0.033599118657049634, 0.07428206848881899, 0.02343263202947715, 0.02256907665381028, 0.0465097532968127, 0.04062163598474957, 0.006114497730102871, 0.02361334834037529, 0.08847326505929233, 0.039143289304188186, 0.020704943416339737, 0.026501840724038984, 0.05563812758473139, 0.02325045057542382, 0.011683281345833695, 0.16476885776125616, 0.0915660156357673, 0.06747883999900472, 0.25431735020491386, 0.14057822195031952, 0.1296892014121817, 0.09783144274185743, 0.21041300448198474, 0.11062579289559396, 0.13898771616720385, 0.14315691986872306, 0.1567035147379483, 0.13713275683262657, 0.10525693380904776, 0.07516264825338319, 0.1560482950580697, 0.1270076485290643, 0.2147942153556693, 0.18333170442811905, 0.1646810947286506, 0.4135185720459108, 0.19277574524523752, 0.15634595086016964, 0.12499546496978692, 0.154289081392269, 0.1843041917609592, 0.1541470333693489, 0.22582571292596482, 0.1301273577395947, 0.09013724633522573, 0.1078591506267267, 0.14420695062125885, 0.15882024631625222, 0.1482311645222287, 0.09363665170366726, 0.22103447647344684, 0.1577510940091264, 0.19441506615088833, 0.11310332890359626, 0.1890711891915529, 0.13931618402561835, 0.24844386134176488, 0.0802849036371035, 0.10290225532146231, 0.13294548877785284, 0.25078032225851093, 0.13794189889825162, 0.24817939246854476, 0.13957168967012437, 0.09047570398017284, 0.15792711037060908, 0.159341124817729, 0.1400310819547984, 0.1174418303755022, 0.16500898036024264, 0.13733961589394078, 0.12842236777707455, 0.14374280859145427, 0.07286584770847714, 0.09840858274049337, 0.12093381235195745, 0.10995326728950586, 0.15753550154547538, 0.131665003455935, 0.09671087827413313, 0.16497317341066178, 0.1074775469098841, 0.157221298244211, 0.12448922640854314, 0.18810728204346475, 0.11439512168327648, 0.11324666395422914, 0.11118460041020187, 0.10400801130961027, 0.20688775896785722, 0.10443609358081896, 0.08896290249521695, 0.19482411113717865, 0.10868080290815524, 0.21637312256761138, 0.08805144172642501, 0.15786709504262095, 0.21031629354242357, 0.17730234731589595, 0.13868892655497597, 0.08627560395266741, 0.10052126937455709, 0.13587663310670084, 0.1461593716615631, 0.06561974378963632, 0.11547158246919995, 0.19553430528650362, 0.1366325167398299, 0.1229148850806298, 0.11494734084173558, 0.14685272719831238, 0.1480320889142252, 0.13932035154392644, 0.1722733631369568, 0.12077258914829263, 0.15240478089019177, 0.14089550492503952, 0.1161623026634897, 0.15336475034634914, 0.21348636537309618, 0.21830944043974723, 0.16081144672728356, 0.12548950741127615, 0.14407138370217817, 0.08381767979552669, 0.13401186784669278, 0.1231801966505666, 0.2587287296210566, 0.1781611165572559, 0.08813777217461218, 0.1303424139416987, 0.21430417955402406, 0.17650864958282442, 0.15782289176938996, 0.14096794619915948, 0.13915703692022832, 0.10333116496762923, 0.07241845236069734, 0.18704427376149163, 0.16313284635543823, 0.13939489189895893, 0.1333959178338128, 0.22432261777500953, 0.14954250786573658, 0.14768655261685773, 0.14108328839703915, 0.23225103024273153, 0.15438154820472966, 0.19287901389743053, 0.15806094593098088, 0.22298384848381245, 0.14653139927935216, 0.08351551173555274, 0.08501537399546755, 0.13077274085052554, 0.1735336543811906, 0.1492447601330857, 0.14633128179177163, 0.14411989238954362, 0.1883275936087293, 0.0988161261944521, 0.18421049920781968, 0.3418796064872896, 0.1622482446292716, 0.17104844983306625, 0.11426294853370036, 0.20419270761551397, 0.11709597232120654, 0.18753434020665385, 0.21533870468697242, 0.1626612273074927, 0.16701810722870214, 0.14439436637105482, 0.06938321966557734, 0.10663016939595824, 0.2497843926351878, 0.09205015256039559, 0.1270783661053546, 0.1176707910734319, 0.1528551026938423, 0.18007203095382263, 0.15203866747117814, 0.06952640149862536, 0.08841925586063056, 0.1801825467977793, 0.2567316916200423, 0.12182160100388913, 0.15685869350789056, 0.13471185770486632, 0.13811839023424735, 0.09329503011559287], [0.03402215240883731, 0.036346681506162694, 0.057983616847665086, 0.01946770567296734, 0.05949683968097933, 0.01749224836877998, 0.10278784008997102, 0.0753304751349553, 0.030986419841346723, 0.010651647237189596, 0.05544110892280456, 0.02628193327015446, 0.020268351823512106, 0.054355573825417995, 0.026808609141998237, 0.03928500407886121, 0.05655664019286633, 0.006008294003549964, 0.023671653377072468, 0.08489732750721517, 0.0852982672832666, 0.06593972339384979, 0.06358307606029896, 0.004739732361368595, 0.018503116706626552, 0.0376506780664767, 0.04780856727231895, 0.022894566345419136, 0.05974080421090607, 0.06599608448243911, 0.02808554939204647, 0.0573381188235456, 0.05202362899698558, 0.016693536590244022, 0.09891744132243818, 0.03130492664152577, 0.05720500338582262, 0.06198818442381679, 0.04647678470299129, 0.03930129876901065, 0.02522373218990622, 0.02360646504037563, 0.015646676484104848, 0.041703735177795735, 0.04560822485795906, 0.015421843084867205, 0.010808170491438961, 0.005652299169601212, 0.004590224557285828, 0.023996817481313503, 0.06973860785365105, 0.009802768190932131, 0.019239842395989165, 0.024594180285930637, 0.015800659199275317, 0.058687372027986476, 0.03553995644793876, 0.03277282005236034, 0.06952802560502483, 0.08166983738661775, 0.00831779963787525, 0.09475521668190919, 0.008715310212855619, 0.025910583640178366, 0.07654310038854038, 0.04954348829004073, 0.047718950306936625, 0.0741897548939432, 0.009205618933323891, 0.02922869813177855, 0.06203423013850566, 0.04654490141077869, 0.014083140826363479, 0.07238443805685929, 0.0690690623295884, 0.06599395475800961, 0.05406582788113625, 0.04625160464896791, 0.03877760489441214, 0.022645566702610063, 0.02189048554658169, 0.0411124570265172, 0.050659858426379586, 0.05619587789800379, 0.03876267384076792, 0.020879965778740666, 0.05406756690072437, 0.05347312097587893, 0.055988524709978414, 0.009262736533738433, 0.02721100640032561, 0.10544631840480913, 0.042724857602508805, 0.02811827283773211, 0.03463260191042097, 0.11462867124787263, 0.083429794157705, 0.06712029552868298, 0.03274159813900629, 0.032121894295297326, 0.03506817652152912, 0.04662893359519301, 0.03410192514439264, 0.010961765374597764, 0.048994475209544745, 0.011542957978353146, 0.05048466943985513, 0.017614025705223604, 0.03196960559204942, 0.016428793840590986, 0.014003694635785878, 0.01884831592530733, 0.031157816692645994, 0.036266732570384784, 0.05545558415413384, 0.04128723998644179, 0.005157416425420032, 0.0759864609027582, 0.05876300788875069, 0.005464367268066253, 0.016764842139016238, 0.039283812812138955, 0.03726232128458158, 0.04025840305633122, 0.08300920422639578, 0.05995232108679991, 0.04174261030951335, 0.029525555287217422, 0.04933418157780844, 0.06439136776832804, 0.054156854448299256, 0.014877849795495071, 0.04173794100361486, 0.12050121782287476, 0.02694797585718334, 0.020203617393910404, 0.010797539106269759, 0.037199984710182876, 0.08389744487020277, 0.02846018553921773, 0.03322953485973901, 0.016476873518718828, 0.0533127366384912, 0.03199184703971109, 0.04858485948775084, 0.019999694364565997, 0.06468726156820213, 0.04243528785844965, 0.059919961532878305, 0.0058454462146807105, 0.022645605007006277, 0.06297251547596629, 0.024284952725734443, 0.035169200536103985, 0.014018613240501333, 0.09436613594692561, 0.10249241360373075, 0.058528581153481245, 0.02643101206499963, 0.01163877738309243, 0.021224540635763157, 0.09385144743587702, 0.012739138197033636, 0.03032409469597042, 0.0670314752947419, 0.01844840462229425, 0.009416251935275092, 0.05648535188107241, 0.043061614532264016, 0.03654173132212412, 0.008740413956524385, 0.11527426886342226, 0.02190889080896253, 0.09545634801108992, 0.004563714084666102, 0.03247375464847973, 0.05973652560984897, 0.02718945826223541, 0.03219543490558863, 0.014286583135535401, 0.019413771167878183, 0.05681487694082241, 0.049275729069185835, 0.020907950970614632, 0.05746138620100195, 0.010071393091141457, 0.02483761621518962, 0.05995777180238117, 0.03473556029700464, 0.04395682657618196, 0.037568775606491876, 0.02017535832560351, 0.018338580172689214, 0.020826130865081664, 0.020186987540294087, 0.07650456616594907, 0.07368003829352318, 0.026420235123124816, 0.096198633583563, 0.04806469727848326, 0.042617957693554705, 0.026906940357519255, 0.07727826134331765, 0.032668632094658194, 0.010751173549872494, 0.09545244862355533, 0.06746882722983438, 0.01770095944765114, 0.08798185796026262, 0.025982055813074115, 0.04638018101573952, 0.0269687655682285, 0.05026796231827429, 0.01438399600315719, 0.05406367517406902, 0.06316230226788791, 0.039819354236486464, 0.03676359804587499, 0.034959939789147146, 0.021835922849394625, 0.04594610410652334, 0.039048949406752666, 0.09986585051181818, 0.05174371579121198, 0.012245207795903329, 0.011486231082779987, 0.013455100030818535, 0.07859420121437119, 0.0467972546034763, 0.039528543429989974, 0.04925911262210819, 0.08330278444073855, 0.07380107252468025, 0.07959750826440512, 0.03510515175519451, 0.052819218967230096, 0.037955860682432695, 0.030864247969622095, 0.02703497471708444, 0.04120446801666291, 0.015316121036096688, 0.0315591107843624, 0.009633651408817499, 0.023979636044391704, 0.015159580544869026, 0.012898118678300131, 0.0418301550070605, 0.051949234198658704, 0.024361948392564253, 0.1316726796569363, 0.018407665981700825, 0.05042992479678604, 0.04623545168508445, 0.02535857515589845, 0.052355375711715994, 0.01468379302100549, 0.03173497967391966, 0.041444969829171896, 0.0510961071948611, 0.01685190420117109, 0.00361703769040985, 0.018389988502848054, 0.024878843236834775, 0.03452906895789408, 0.07341231354662488, 0.00829127767393666, 0.1295545384768517, 0.05524477590956996, 0.07736528127063667, 0.04622815469760568, 0.023083606201614586, 0.10224725780708176, 0.03521685503543385, 0.03764859430732266, 0.027500855766477126, 0.05538426902926257, 0.04390483984964029, 0.045616927616778886, 0.037497916303935556, 0.09699527309426377, 0.04732071865169753, 0.031779885832821174, 0.0506690246683936, 0.041928080195981654, 0.014102638721646321, 0.021842107094163378, 0.061969986005175504, 0.06813490237560003, 0.025578790960172494, 0.04326239468589906, 0.04502767193762045, 0.027634551515802745, 0.03483555392332135, 0.024754181579356233, 0.04175777118953486, 0.047825509306764415, 0.022214793547567342, 0.03109369704860353, 0.03332743706602243, 0.007047523395158351, 0.04871364652870163, 0.037494894087074265, 0.06433647756855335, 0.04341696441594151, 0.007110276529865881, 0.024762926473011895, 0.08161199008745533, 0.052705876258832794, 0.06780752236203802, 0.10302746473180671, 0.04344061738060367, 0.07124430770354886, 0.034060234639553294, 0.1286547375662673, 0.02803599882510401, 0.04460517061694015, 0.04220329728277941, 0.04081698840544109, 0.11406090816542988, 0.043141467707051386, 0.0490154430360323, 0.053740470339694334, 0.09181673323074657, 0.033039073910444014, 0.01793728033531337, 0.0402942291581102, 0.04870100224751139, 0.01634869360244803, 0.04721234785392881, 0.022919169259107402, 0.02200113737114495, 0.031883910996839404, 0.09811168536543848, 0.04925483785149071, 0.03147803378411599, 0.021851547212610324, 0.0509225040103399, 0.08917187595920217, 0.03411956814928882, 0.026270007196393226, 0.03074585291136417, 0.025526273717743256, 0.04807164569595649, 0.04074946158535538, 0.05684082816925742, 0.049368506147255825, 0.05753594187779292, 0.035852742486543236, 0.04515007746616199, 0.06562691437260759, 0.03842041639971637, 0.06014017733715235, 0.23257402823336665, 0.13367235300041017, 0.1858497128611611, 0.13100302688056423, 0.13819309912862318, 0.1206887714684971, 0.15288266653735794, 0.16372161556876477, 0.13126800137181438, 0.1356365871165068, 0.11671245338455324, 0.19947095533772824, 0.10588707943116465, 0.2237257739949611, 0.1313389870788782, 0.13855210325169948, 0.12837569770072738, 0.1012317393155348, 0.12859136677317082, 0.1687735057766399, 0.2442632429301739, 0.13378671460574673, 0.2662679234579686, 0.20995807082903004, 0.11735577571896777, 0.1831802641672473, 0.22671150974929336, 0.1203666391572164, 0.15073152228949532, 0.12889145873486996, 0.1412901934236288, 0.1437081660955183, 0.18648994786124076, 0.08636638537169465, 0.19375676679755413, 0.09848889173759569, 0.21182122730439712, 0.15279357051176412, 0.11955892201513053, 0.15162982166774813, 0.11882831162262349, 0.1184386563216967, 0.12530448185580392, 0.10796317770596474, 0.1300793240267423, 0.12860003888847368, 0.14482257887721062, 0.14606203252990402, 0.14432917228869854, 0.08814826757917482, 0.17193772469557103, 0.13464899252979987, 0.10798481968982566, 0.11344108174765304, 0.13424529483722103, 0.17096666228627005, 0.3194241904683652, 0.11230721033268398, 0.12987430357644636, 0.2404653007585195, 0.16805160580383194, 0.2272573167518262, 0.10096096553869786, 0.1595667530331881, 0.22833776119495594, 0.20122440802233837, 0.11766491517905267, 0.12280030130979516, 0.12704195394631357, 0.1045646201518755, 0.146416578021261, 0.17847666817326702, 0.11305672011428303, 0.23061503415867207, 0.10017349610045072, 0.18414086181550257, 0.12979453850177028, 0.142877496959221, 0.21212826002269022, 0.1604506806019814, 0.09810761743856054, 0.19316338573492345, 0.11884752510776443, 0.14835070488193344, 0.17056558461439225, 0.07929770741611719, 0.17181283704215483, 0.1643382550607766, 0.11612352329276263, 0.07669179039376398, 0.24394409070091866, 0.10951772332191469, 0.31507474160002125, 0.11199341305801946, 0.10756206172969072, 0.25120766142443307, 0.15235005156888118, 0.17189353674409852, 0.1370514749038604, 0.09859592188149692, 0.10839444690293844, 0.09117859731157942, 0.18618372719614737, 0.1774478274127168, 0.1042987033724785, 0.10190929811928542, 0.12498968866683784, 0.09503765031695367, 0.11333591319740781, 0.11858554602029825, 0.10343375946244887, 0.14356438671388935, 0.1258303322679093, 0.08284592790709389, 0.19919994407363478, 0.09874964508438304, 0.10960877287171542, 0.1908574610828392, 0.09979928513207745, 0.18149658677078065, 0.17340933363283836, 0.17284405267527028, 0.17099848557864467, 0.12225942025261542, 0.2813294878409755, 0.10851826969413988, 0.1761101459663722, 0.21249728457581615, 0.27992448258784514, 0.1565098477106902, 0.17897589703000363, 0.15238618027539025, 0.11079846145284754, 0.2788288849255731, 0.14920132294777902, 0.1507606183088595, 0.13920004509629744, 0.21152698825443947, 0.12242434366095452, 0.16172443967192404, 0.1526054346393193, 0.13015432403452937, 0.2191309011991947, 0.10426026874131734, 0.15444252880350237, 0.10847765937327378, 0.18228623955961198, 0.19707097041030086, 0.09573672086961808, 0.14871936171285569, 0.1613006245104536, 0.15444202318547234, 0.21880569687533766, 0.15765851994435634, 0.0983105464688232, 0.15411303438726934, 0.16518655954109085, 0.13393003433462114, 0.13788439633865512, 0.11472030302449582, 0.142804550067071, 0.2017268084830815, 0.14463098028734808, 0.19955914737957142, 0.1149143071304406, 0.17294140712868783, 0.09038884493131792, 0.16375198329408325, 0.1711263303314486, 0.17589021744506975, 0.13548438076771077, 0.16951091136903534, 0.3136006965031547, 0.22201796482887962, 0.15098748758675593, 0.17766320537174904], [0.04100394833292212, 0.039007699402469787, 0.01967617543414235, 0.02111872474122192, 0.03487863104730364, 0.049493773014194546, 0.016252614685424393, 0.022929635935372884, 0.018013770384113156, 0.02176976541147357, 0.05353540775456256, 0.04202793592647199, 0.011094063971071474, 0.02755686636984108, 0.07634031691498334, 0.059737123158429904, 0.0034185550823402143, 0.035385651018230185, 0.03973225386993539, 0.04080153641200835, 0.03406939322068807, 0.1296038132521414, 0.026605942496849645, 0.027882128150292465, 0.0603231153030309, 0.03766659354310363, 0.08338356841235392, 0.017911394224351933, 0.0874193272583427, 0.048769402407830766, 0.030344193012663917, 0.0529057179547606, 0.041639816631833394, 0.08945122992079105, 0.042744898462607976, 0.02084634792540343, 0.04416539401356732, 0.03465915834831615, 0.04019271101682417, 0.028887118678539995, 0.02794591837652749, 0.03386444554874494, 0.020989129477511012, 0.01766842369350695, 0.038483515231599735, 0.07628672140380068, 0.06450802763743747, 0.05685142699568983, 0.0013771153434420065, 0.03111180736713352, 0.01174232182693818, 0.034548849348099, 0.06948982846112021, 0.027796462283379612, 0.046618752286679326, 0.03501441247100311, 0.03549915077465196, 0.05969631365470349, 0.05620123285259451, 0.015064391247447462, 0.034045801543059855, 0.09722044931784754, 0.011086834016286079, 0.03981489560476715, 0.056464027823700066, 0.010653023322623585, 0.05617908142026394, 0.040439962063946074, 0.009525430955803924, 0.032505524314699635, 0.021253755398755594, 0.0666940748511303, 0.0042533440958528275, 0.03199214581400156, 0.1641241334859402, 0.022158645048377015, 0.02280255152483381, 0.057822577505102085, 0.01124869881858749, 0.051424923623281146, 0.01977553512270172, 0.06834602088577325, 0.016752893082617272, 0.006063597411998818, 0.02930012433939884, 0.09072016263681074, 0.047767642855403886, 0.020824765313356634, 0.035001591989590276, 0.024033279436069633, 0.07643145073445574, 0.03911868639049992, 0.024376423623893532, 0.05351518303336156, 0.033349626802749215, 0.041551130463279067, 0.04500794517357023, 0.05552862680727436, 0.029437330686637474, 0.02323379773916977, 0.03285554988730339, 0.022443175849114216, 0.023536029001397472, 0.041238830890506506, 0.0416823230203121, 0.05422786313800081, 0.059212356760737404, 0.025289353366280277, 0.05344707015601378, 0.011748553952202203, 0.05150631663479632, 0.007403983148716151, 0.023810016517076763, 0.04103343505712767, 0.03997378607070254, 0.02844276469981959, 0.05121255638979135, 0.03689759065427127, 0.06870296423233326, 0.023527563729834174, 0.04774690485529361, 0.0657730303224056, 0.036568613347387126, 0.028211871545100888, 0.03657924664777614, 0.07791607550555661, 0.050034236553455555, 0.053168562721581235, 0.042006822543278824, 0.03243051664603334, 0.06392444100891871, 0.049085972920781186, 0.01917375582120111, 0.014182595318303475, 0.016822247022402384, 0.016666177675248157, 0.029533537923388427, 0.01459740320100419, 0.006648741593028629, 0.04633558320722753, 0.02828551940770159, 0.055697844138429056, 0.08871993004915216, 0.0205541524149838, 0.0021352776093408465, 0.02535455893995541, 0.009405594694638445, 0.020425411339308468, 0.07623923927425377, 0.0702664424334803, 0.060840630678520094, 0.03280616785970426, 0.04219673957014757, 0.026709078998875715, 0.027588886929856195, 0.039054289039584904, 0.05254612011354297, 0.013784059143114476, 0.06252202513297239, 0.04594914164514311, 0.03715083633940067, 0.06881102859493225, 0.01989025104370329, 0.03504581058457975, 0.06813825017982914, 0.04701899109228004, 0.055893874546933564, 0.023145199670726736, 0.03722561418168968, 0.039535568456255624, 0.00597419734526005, 0.032055378711271676, 0.03704953270273344, 0.013879785659692943, 0.05242825365595279, 0.05435498010727668, 0.059195024021450555, 0.04711741040791235, 0.03514739384333934, 0.032689691851696664, 0.016854639135060773, 0.028821957154920506, 0.0684866133416372, 0.04498397811285911, 0.04346506324626746, 0.03277097378046282, 0.03383620371741634, 0.016038934568754368, 0.027988664167482528, 0.02286027241948872, 0.06401247983317702, 0.04134996726568188, 0.018222092673362746, 0.02352190042485393, 0.0546541374417082, 0.021519331269026287, 0.06281900294725934, 0.03511215762926206, 0.03193807724352566, 0.03773222812601636, 0.05322160281901879, 0.050821652365548, 0.03169764437892985, 0.023419104831954165, 0.06115247059853808, 0.023518506655349367, 0.03901358678816788, 0.036026763188983166, 0.08042878261016262, 0.06727745080546987, 0.06228523501645654, 0.023119407405536023, 0.05755397941797011, 0.003789857071223519, 0.03128636433112045, 0.060166205174379775, 0.060184089496972105, 0.005644706280661688, 0.07207542883172151, 0.04426132737388534, 0.03294652282831169, 0.03388841260945605, 0.03885643534182061, 0.013316124020474813, 0.027601743800445434, 0.025279539779970245, 0.009030345677127762, 0.009090044993847128, 0.06122117719402718, 0.018028052178241553, 0.09835210673871542, 0.023706627206035683, 0.020875166237895048, 0.07791150196064865, 0.05191687464473709, 0.03787122328855819, 0.053090417922865, 0.03700947779561243, 0.010361588154468807, 0.026051197163460237, 0.01756572577681753, 0.02482895367598582, 0.04178797803638924, 0.03844242610578095, 0.031513195304620656, 0.014932130955369964, 0.02897123513262599, 0.07090787253072185, 0.046199449383082895, 0.03162922315119255, 0.06662279036977599, 0.038959393728404276, 0.04802242837726109, 0.01845033899430306, 0.0564612239418972, 0.012239693878068319, 0.028955357960395278, 0.006485470540581212, 0.0577615509410539, 0.059402197178813725, 0.020771413035089933, 0.04818251010991874, 0.04387566339104407, 0.010286524944427994, 0.04938186289021566, 0.02413351438008249, 0.08681948807451033, 0.02182703431425316, 0.05072910128341568, 0.03863775937427436, 0.047961171986835624, 0.01823822265460847, 0.038766308927968625, 0.09213642938242805, 0.02239347589502652, 0.02856515873704226, 0.08586622188769041, 0.09606589352892292, 0.05286144190317681, 0.05588401499534807, 0.055052277166396386, 0.04630794658535912, 0.03278186372030647, 0.0210343899520775, 0.06277179277892556, 0.031375812757159435, 0.042007535005048405, 0.059128140715221246, 0.012315516472764075, 0.06827416183847575, 0.05288153638943069, 0.02735108366206048, 0.05314603590616777, 0.059083914459352536, 0.012479059007619659, 0.02180169212571796, 0.02514276627240883, 0.02171085133487659, 0.008328778635440095, 0.02538638606276964, 0.05023014438789218, 0.07598145834861264, 0.023616744025099664, 0.08177251615110906, 0.016398765109179002, 0.015778822820603607, 0.061869502082587256, 0.018840434795786298, 0.013630994775843237, 0.033551621205744245, 0.0017370867722239648, 0.02287417691531441, 0.003919166967182631, 0.0767930212520784, 0.030294291960496097, 0.009454102424393979, 0.038708204989351576, 0.04669462180426044, 0.023978084716345036, 0.042985074687749154, 0.05029224730547398, 0.03162461896276763, 0.0363718819684319, 0.0730992057510922, 0.015248388329881336, 0.05212672527939562, 0.10523065699324494, 0.02888726806568523, 0.019678169177965294, 0.029021645633263454, 0.03936754622226281, 0.038814564806319056, 0.018894298437742457, 0.011752726258559814, 0.0171257155166278, 0.02665503532625735, 0.046237206026431055, 0.05585235258143756, 0.02733296951309087, 0.0650333724315128, 0.026405616250309735, 0.03989047400893704, 0.0707636105137006, 0.010801088966188893, 0.02425795004162337, 0.005803274032058976, 0.029829945002171784, 0.06753929965798894, 0.008664626793395127, 0.07014252771172794, 0.03877851653904204, 0.05073064878102272, 0.09607975205947315, 0.1266805060027588, 0.10291093509764442, 0.09165576283609675, 0.12381527587891587, 0.11852661853716259, 0.17795335351219102, 0.1357270927438813, 0.10171052128557237, 0.10879331058071506, 0.10075440525167412, 0.1503494282763812, 0.09638993339913507, 0.07044348535278151, 0.13829630649378225, 0.10771458983541497, 0.17334564108281367, 0.08806066542503335, 0.144912134555559, 0.059817646660151026, 0.18314732238650325, 0.20762038417160514, 0.1255523342819464, 0.1836594674856432, 0.19683202758671778, 0.07992694905448346, 0.18042551924384412, 0.08376511850304182, 0.2796441863381094, 0.16514494564504395, 0.15613368321811, 0.15411300374375236, 0.1308965100155723, 0.18357597922365512, 0.11082649260999695, 0.09374351330822515, 0.1540908178374652, 0.1120877031597399, 0.12472547260263275, 0.12353465021137269, 0.12728837378803762, 0.09215201927168716, 0.12656298045429493, 0.21180178399287888, 0.11944676674301587, 0.1358958465918418, 0.24797878468469267, 0.13786643923770997, 0.1012141116323971, 0.08121170914701878, 0.13289328754669236, 0.11178445491579272, 0.16176688094292918, 0.10549723260825682, 0.17563630526344623, 0.08511085153347062, 0.13171938037680042, 0.19674898365572577, 0.24746069474326027, 0.14407106194524996, 0.13261533552600493, 0.13238794530832, 0.11324225894866452, 0.07173828119712491, 0.19861981633209413, 0.1799311627063059, 0.16672964448169356, 0.1097693449006446, 0.19639989271038966, 0.13811158737347973, 0.16783887850901774, 0.14366575546803015, 0.11903131726167857, 0.10007702264814608, 0.3303937115255864, 0.08433904859327501, 0.15284364201849507, 0.09641659325890004, 0.12909248020620118, 0.19916548543880064, 0.1062608537294211, 0.11969177698295926, 0.11046824691396569, 0.17525577406969764, 0.13415891076287917, 0.17376135103404525, 0.1277209836388788, 0.11671646768527648, 0.19369436127524223, 0.15281897398733324, 0.24717356498923995, 0.10162947684406273, 0.12232769400842729, 0.08354843053365908, 0.1116766740057257, 0.10550158398766672, 0.10427047303246875, 0.1838468525919222, 0.11823435599404959, 0.13810686827186616, 0.20695436265199416, 0.1309160912229169, 0.1544106748676108, 0.09248066333032424, 0.16890133520768535, 0.1232884908395429, 0.1589457161964909, 0.19991628224811248, 0.1715456102524073, 0.11906409816395853, 0.11723992790305808, 0.1722146808019569, 0.11550255540397861, 0.1809112343095964, 0.12263677218147825, 0.10074062332991632, 0.25377097629731704, 0.14016101046675636, 0.18796249142577573, 0.11803309703546187, 0.14212075530761673, 0.2266931542826276, 0.07959542450525108, 0.07393628704331576, 0.16521812236357122, 0.1471154493910651, 0.07541711967919143, 0.15535585882682956, 0.11528550737327146, 0.19828263039310134, 0.17981836392033487, 0.16389436839569002, 0.14099627613059937, 0.1387379868256469, 0.10067261004399869, 0.12592806210440974, 0.0755005160106286, 0.12463677494275956, 0.10346457151876343, 0.13304739379354064, 0.09613091907193584, 0.20394947469955493, 0.15202670117780087, 0.3141543942113077, 0.11698103614992673, 0.09995421109300467, 0.1585630552783128, 0.10852719461845775, 0.17554750035126365, 0.16365757061829492, 0.27731154053922624, 0.13422949810422238, 0.07726287063691886, 0.09732819958439759, 0.15227771754707062, 0.1823705705183168, 0.12241405510013142, 0.12438954304783575, 0.18094016178961725, 0.19845072540544695, 0.13278896169316384, 0.17248883302653992, 0.06319708649008986, 0.1257544282763716, 0.15357219163448582, 0.15397515388265734, 0.24467990283043156, 0.09371020380527743, 0.14744832991592347, 0.10663102741443342, 0.08274324914260257, 0.25218344293534756, 0.10293231661161108, 0.13939124532043934, 0.07247668270382189, 0.12891347610181378], [0.03191970070944198, 0.06528204457173425, 0.027768875457226273, 0.023410687440886133, 0.01675447505418091, 0.060686440162000164, 0.02061793114989996, 0.05688344947092476, 0.029436495650800008, 0.027322221299513217, 0.06026366688010674, 0.02748929166926011, 0.005667739671715085, 0.03587329662555168, 0.05963053351508514, 0.06321834159954902, 0.026885656519762935, 0.024452040332459637, 0.06016402948467482, 0.07394604700347109, 0.02699694994296278, 0.054830356816490816, 0.1033621762068041, 0.022036356348243934, 0.04947400411530849, 0.04232027890881704, 0.02186470860314946, 0.04420442619330941, 0.04570442251861096, 0.005146848242504583, 0.03663404874743954, 0.08326558321113549, 0.02509346085360214, 0.0484052884782995, 0.03956710063521901, 0.016261849875351595, 0.027169781293900266, 0.019740948168140267, 0.05643385162036266, 0.03419400891289115, 0.0897238499695255, 0.04517642706031761, 0.06857336513818273, 0.06293215030323594, 0.012967811611991738, 0.008342829645581303, 0.05922522703786531, 0.04549033924817078, 0.052197630547227404, 0.03329593936101564, 0.005388095554324889, 0.02410177535737955, 0.03136548397672032, 0.051405342415936535, 0.03950308249782651, 0.03902828801543482, 0.028770489452947533, 0.07815880280348562, 0.04116652751221292, 0.03576728920902937, 0.026110161035772295, 0.031373070162390514, 0.05223508458584548, 0.049843388729758804, 0.09073178419062207, 0.040991675604375145, 0.08294656887770661, 0.02667435031804827, 0.03522845360660746, 0.01723413227967197, 0.03382152547278712, 0.028565126178305478, 0.04063317709932885, 0.03430881867966345, 0.09790112609944998, 0.02730260178777239, 0.03941650690150358, 0.04379197211575605, 0.05810755072161556, 0.026137562085603996, 0.044983602729776216, 0.09333809191781668, 0.005728748041175066, 0.02832602439147811, 0.0368397356942296, 0.018726262797210968, 0.034425934371087825, 0.030342875341434154, 0.03881753339702564, 0.030072191579928322, 0.0692496445750998, 0.13571269029090482, 0.06983194800634539, 0.033478781565903656, 0.010186762102098476, 0.04045101288225382, 0.033605913856938, 0.05424655185291364, 0.028300134450077053, 0.021907383530971505, 0.028862891147934625, 0.05976127791068247, 0.030340500468868884, 0.03406789934923572, 0.049499568469341726, 0.053661256848323735, 0.028487379745309873, 0.02475955377092525, 0.050113335131637515, 0.009176611971680917, 0.023913327304105607, 0.050605623231780146, 0.030322687009409554, 0.027552292824933128, 0.02783265227692262, 0.06509210073178814, 0.03668190242962972, 0.04292711247539809, 0.04264208946316954, 0.016468996219637416, 0.06332897235669437, 0.03586525270234674, 0.09317649333106895, 0.10154495436337688, 0.029888259614968014, 0.07149089608461627, 0.07448282949025593, 0.02413359481931454, 0.05273353586333895, 0.022362324844805465, 0.05772376365418877, 0.042690636454931194, 0.05057449324897701, 0.027885709611338474, 0.04450185216903206, 0.0524250858823859, 0.018735243262903347, 0.052495688545487584, 0.033024483765926094, 0.023231700573477055, 0.06197873855971041, 0.03212301086844697, 0.03276071586315671, 0.05285756932871957, 0.05436718005747084, 0.036225743035996155, 0.03137360259349788, 0.04129204335772703, 0.058160774680154945, 0.1490286467296462, 0.08122506205953899, 0.02917737024085176, 0.006605004675821552, 0.05743875979415833, 0.02741045356097241, 0.03675997061955352, 0.048291470795389146, 0.058882195848010244, 0.03037648744911196, 0.13416712322542745, 0.07630314632889725, 0.012985745730299144, 0.04720605444163085, 0.012353233854106117, 0.07339539066437753, 0.06201105214835656, 0.03507222146576932, 0.03762607132234881, 0.01994204050260446, 0.04437838177827578, 0.009489397052675486, 0.01692441633842405, 0.019572682701231494, 0.017286810400565306, 0.017227421349455273, 0.050156722521229144, 0.030016956640587702, 0.04520143600060575, 0.041061132966030034, 0.00353461716346623, 0.03346663524186419, 0.06309632677584887, 0.0392100845103062, 0.04590934720791636, 0.09413738975361471, 0.0410675872567921, 0.07890041421858535, 0.0336228788740212, 0.03407998438624125, 0.022335360465090603, 0.013154082060340914, 0.049534283743630496, 0.0481877118469246, 0.036796490030903975, 0.05389592873172895, 0.1258258966188277, 0.02166881034481189, 0.0344384407564517, 0.025072918205912557, 0.04245346712489282, 0.11337466958549716, 0.02575429978840534, 0.08878829573551494, 0.016410894196240172, 0.013357615342453845, 0.0033925181478186846, 0.05347007960681954, 0.03009567217480752, 0.021359182503675262, 0.026077740194816745, 0.012770908820863455, 0.06251033080080826, 0.027734684953165632, 0.014877770313872926, 0.0357338801146515, 0.05212827660744229, 0.03095658454713562, 0.012414401186810387, 0.03788546869351018, 0.009999331030544015, 0.016165893532395843, 0.02462655899205035, 0.09109452682276888, 0.04104055967482348, 0.03164705193241037, 0.0889842993309421, 0.017328430042271654, 0.02285521623918847, 0.04350982193324355, 0.0422494157758211, 0.04581593810730884, 0.027415467606436823, 0.024389263257504474, 0.09127002224446305, 0.06015003305829822, 0.07269610560709432, 0.01056496438855726, 0.05469678172601327, 0.026210365336268183, 0.026859412262696895, 0.040666065253918214, 0.042905681165716344, 0.040686853049743565, 0.03674259191499122, 0.0449981507394583, 0.05777601468106432, 0.04694249338260101, 0.0578542399190126, 0.04608310744046204, 0.07327696879304225, 0.02245239188684331, 0.020508305883155237, 0.059728240368947874, 0.009316940127210993, 0.043931909566444736, 0.04261513082911411, 0.04873024765402079, 0.02519152585356947, 0.0252254463116368, 0.029877691432052565, 0.023154538282523715, 0.05495553558331825, 0.057445861429216406, 0.04674936644732953, 0.06009118218395499, 0.08625610701499448, 0.081308105990531, 0.05268448708398689, 0.031119090948073618, 0.0867192914348937, 0.05479443112328168, 0.06691138335173169, 0.038156192674632036, 0.06353650557538194, 0.017555975392761252, 0.05753587292987974, 0.01642547859509866, 0.029735005640935515, 0.01692330359571403, 0.028942895625087044, 0.02079831421255104, 0.017861234617509672, 0.03848240440410953, 0.03431970095862785, 0.03192841879002029, 0.01558126598190997, 0.04011651974231486, 0.024785160259794325, 0.04297820287906835, 0.03507268111852389, 0.023004509538652438, 0.008325785146875968, 0.03490884555503726, 0.09005373509059991, 0.02155892077773329, 0.028975270500767137, 0.030836417910552798, 0.09201420005410911, 0.06352109571678505, 0.0662651345614464, 0.06827010157247705, 0.08000286836777964, 0.09165516528751581, 0.06965144236962642, 0.058423757342801946, 0.03124610832591932, 0.00692333766980277, 0.04887958117310078, 0.05070114290461906, 0.03555094214877294, 0.0434438081368083, 0.022417843236678073, 0.07408991065477172, 0.02007058048019967, 0.04224294999374017, 0.05147144431248308, 0.031158755150353237, 0.016073072404270212, 0.002013264700860506, 0.037830115010541294, 0.00992084723792129, 0.0882382522667608, 0.010975741691166356, 0.04636620757200065, 0.02258956376012535, 0.05464928427470788, 0.017657121981404, 0.04836995267279206, 0.025306576938037912, 0.047347244446075736, 0.07467060530137631, 0.03697032304180246, 0.026835184732091524, 0.0251020084796173, 0.020187696171624046, 0.06242082108773532, 0.04848718327740508, 0.05628866646739264, 0.08144571070349024, 0.020144153649227756, 0.08430691120485145, 0.038542082653410976, 0.03268201948113499, 0.044087295180126544, 0.06947218545622404, 0.1209232786429986, 0.02347364263128369, 0.022602705998466383, 0.01415524023374723, 0.023316830178842913, 0.08976033873735897, 0.022243535251266534, 0.1158976729118055, 0.16241497600511198, 0.17839222996225282, 0.14467559724805817, 0.17139439981791282, 0.23339919685836763, 0.17161659595947112, 0.1314266122156574, 0.17370374122213933, 0.1478120071753379, 0.16020804523460327, 0.18109465108042766, 0.12636896102659165, 0.1465296832424018, 0.11279040496916541, 0.1347326493311313, 0.09064599766486114, 0.11955743580455742, 0.17818685711151172, 0.20790337705083434, 0.1485351482105832, 0.12805075384676456, 0.12423179022246793, 0.1742684246311265, 0.15350857569325357, 0.1212733501808778, 0.1660738425749925, 0.12171553613077249, 0.121701953391875, 0.11469516767970017, 0.13628463621341413, 0.13706388552823376, 0.1217389477777385, 0.11357842599071803, 0.12711568224814632, 0.15488218666324693, 0.14396917225132067, 0.14315596991969695, 0.2295459124950632, 0.1104940410943762, 0.1809834457573391, 0.1420403007538088, 0.19364003031965227, 0.1936822724077971, 0.1664238068605623, 0.12407262779531941, 0.1850639517989851, 0.24687943319159172, 0.12613495947012018, 0.20300349400889492, 0.06780507854155957, 0.12622522761023816, 0.09329034165749628, 0.12541451506436835, 0.1750090171492869, 0.10309988302328896, 0.18838333416609995, 0.2550844340434959, 0.17317262778599418, 0.16394439393714552, 0.16623326547203526, 0.16249872473699434, 0.1663949713110924, 0.12328807715206377, 0.2105802108323382, 0.16485668208089568, 0.13181036097868798, 0.1544114103120181, 0.10781860925377378, 0.10785729669394994, 0.10151004373666742, 0.17788239844864417, 0.15916808087739254, 0.18040737828179715, 0.2658643483394577, 0.10056961718345843, 0.21880082455613922, 0.15434788630133675, 0.08346662766510442, 0.11588825769121609, 0.20696436776028526, 0.12318755109463969, 0.09505734643748692, 0.11310409499152053, 0.1300021330074918, 0.1331623069821827, 0.18224260319144497, 0.09450387855571124, 0.1679753034465736, 0.15721814196196296, 0.1954636260146095, 0.3302802998692759, 0.12935852722054528, 0.16556261678136167, 0.09368814047305815, 0.21215669720643954, 0.11742355151762886, 0.1603619676203497, 0.11924319419889681, 0.12584197680435835, 0.22715072327804184, 0.06949582692956732, 0.08004740105881807, 0.1271759733677872, 0.12221077366942361, 0.13942797157552936, 0.11737400861156565, 0.10345964557341031, 0.12452187707587598, 0.13563202123247808, 0.1668012430590968, 0.17712826149598246, 0.1227569790376771, 0.11287272111662935, 0.196589560758683, 0.1715378421208551, 0.12797282738310675, 0.16493157483637333, 0.14349603634928504, 0.1314067092513846, 0.14737895299350062, 0.19333629177943354, 0.12545216062496747, 0.20542266177794627, 0.1363073583812483, 0.18016652023840338, 0.2901066797635248, 0.18577511121909465, 0.15075229859400183, 0.16545723372649762, 0.12801554444576466, 0.20233082284610118, 0.18428793537520594, 0.16410185564910212, 0.158666645687434, 0.19801282954792823, 0.10323639223051649, 0.2195811770375698, 0.21620084471519918, 0.2489353220669493, 0.10320721194148065, 0.13986929950694885, 0.13888919726014137, 0.15341954095469368, 0.0882552900621968, 0.18758566809758065, 0.1474769356390161, 0.231522235478605, 0.11525013709380744, 0.30090576157935206, 0.16496946554510825, 0.12572165503497088, 0.09228924094068428, 0.14032708300698188, 0.16076223323902777, 0.09340592900351172, 0.2468782687379468, 0.15640270265360035, 0.08878454956556521, 0.18900803290307525, 0.1907780484086083, 0.12129120002951353, 0.22436286803455124, 0.13367639794465036, 0.19295248172936902, 0.10610281745152128, 0.1313414385602359, 0.12941681118982454, 0.17855220444260106, 0.2793086704707915, 0.0997717519320788, 0.12195781909770544, 0.08066844555639452, 0.12757912713793979, 0.19561851367114053, 0.17737488052056682], [0.04822969346517517, 0.011511467934225597, 0.0591022890782164, 0.036107524177960815, 0.02953800230076717, 0.07000976467445012, 0.030478618460737412, 0.02985909847813028, 0.02540846854718703, 0.04648304364133266, 0.044595203813045256, 0.02593708262147923, 0.05152040499172384, 0.01637693160333701, 0.019650781534672267, 0.04015577408755499, 0.04346222106006838, 0.03973642904912272, 0.03410760185591156, 0.015804452292110412, 0.02411649190640498, 0.0633266702624819, 0.03830858288452991, 0.019735761752892888, 0.11787360519050591, 0.021983973171201446, 0.10699057545993598, 0.039659544465041933, 0.012805784016006417, 0.062195009011174404, 0.08709356369030091, 0.030328312009993582, 0.05094451371640448, 0.030112621870132226, 0.018980115607020356, 0.07921548319920417, 0.04979380368885975, 0.026930752285425703, 0.03625626014845987, 0.046182239217863935, 0.07492918295845871, 0.05043062193679714, 0.008542487480407281, 0.032420235746089494, 0.0123146086585738, 0.0199098686402243, 0.03776246944682733, 0.049719102455363165, 0.060322138540927446, 0.029317108508680138, 0.024344257507172805, 0.06410632943434101, 0.03714552351964578, 0.04399472877623574, 0.04132908370886599, 0.018664188607926332, 0.006686424979219034, 0.04868165469698368, 0.039585942567716685, 0.017258589636654626, 0.0331104809658662, 0.03349002007575285, 0.04414698109030724, 0.03625756249793115, 0.044893752107576984, 0.014666620202572837, 0.0143032991740432, 0.12247924152160845, 0.03951433249899457, 0.03678498339028128, 0.06655679189509923, 0.016205967591714956, 0.04916436669807281, 0.006768928818224419, 0.02361132203781557, 0.03027146062513273, 0.04048529148642575, 0.024365843949659217, 0.05933521045071464, 0.024714440768284184, 0.036812148868076267, 0.06193856873940076, 0.04769782926286421, 0.03449246144643234, 0.07146201456987089, 0.009140897910260867, 0.000644020491886148, 0.05627216110306402, 0.0213622315336139, 0.050327062171192906, 0.02479718975542534, 0.030334695437622648, 0.017558225776038824, 0.04398784164579646, 0.04875873846392478, 0.04065863037061307, 0.028200885844266707, 0.034592278872526465, 0.02802821728701313, 0.022279388166122863, 0.013542488637951114, 0.08990002720947228, 0.04670673748478294, 0.027780334217353698, 0.044677221186218724, 0.07004226978507734, 0.05337257959669637, 0.045191354283522216, 0.0257551156720447, 0.05894342159491874, 0.04643473796726716, 0.027504998386927673, 0.015819982809555388, 0.03596091793189126, 0.04526530475085301, 0.039970664262411096, 0.016119288573522243, 0.05930060242873527, 0.050719820128213015, 0.04821855454675613, 0.02189457837131716, 0.051282952209153486, 0.04283140128057811, 0.01110448276684169, 0.07674730112475735, 0.05748615765403356, 0.035862705459998506, 0.007893511417111563, 0.022143652707698847, 0.11600139355587384, 0.047987816524842096, 0.028389778228536732, 0.006904574740122283, 0.05382207019494907, 0.009114680466272179, 0.028469106633095976, 0.019750455319280588, 0.06591225914176434, 0.08341661744540738, 0.10466519217457503, 0.03888758064638223, 0.013551550500485446, 0.0007409146341923324, 0.007130304462231335, 0.032805524345847874, 0.01886641283729865, 0.04428515653877009, 0.03157483090856864, 0.0751173188309035, 0.020221947962718628, 0.09580994355342082, 0.06209052227918179, 0.08635065758660918, 0.013291130401945163, 0.0310176283481621, 0.02174807554711738, 0.031100185813322186, 0.04242947325110436, 0.04460926152645581, 0.09505117942969646, 0.04474260679055606, 0.025996178643958225, 0.04783230450665278, 0.012040389401297416, 0.09189150341215635, 0.03305978126703732, 0.06735500188604479, 0.03111855277130681, 0.038359477935779485, 0.039507924173507965, 0.03868764318946389, 0.0021986335594837945, 0.060004005208611495, 0.004563991312733702, 0.03316553970498424, 0.1102686427052944, 0.0512095571555678, 0.02797589156656496, 0.08197511576356427, 0.006321879646425406, 0.02841646298615923, 0.03674211311003855, 0.02695688929018234, 0.031061431340452646, 0.03942745046750192, 0.04606947490584947, 0.06638551761786785, 0.04436153167438123, 0.005422298028509343, 0.063326831140946, 0.07566806710054798, 0.06814948868967834, 0.04394707044646625, 0.04434512590148276, 0.009066836360181052, 0.01770999928515765, 0.010884829079582086, 0.06507923045466024, 0.030600340255806525, 0.04386505307329278, 0.09973929278672704, 0.004661713488354919, 0.03204021208559073, 0.0662025451780327, 0.11785532633263258, 0.029073875592721087, 0.03771314487582253, 0.037817137481103984, 0.055081656638292543, 0.08334144889827698, 0.06229626668256618, 0.03938836083116551, 0.06675071939225159, 0.010562152845875151, 0.11599113563856772, 0.06105057324372953, 0.030530030621335875, 0.04060537193811709, 0.006671833398286254, 0.024556571114507895, 0.01364691504051969, 0.016354523531551805, 0.0028943302130491864, 0.008129323813914052, 0.040047732707593715, 0.043002778979679274, 0.04920226506768696, 0.024500278973831766, 0.05644396398096316, 0.02110575678788366, 0.030744422242165576, 0.008571048195834362, 0.033207896706317706, 0.05964234276043792, 0.0683468712433692, 0.0386052466027679, 0.04071799835430519, 0.006209712404186928, 0.03391046828079609, 0.03284844059136606, 0.011140240878317387, 0.014842830958866305, 0.04001788592206375, 0.012467958393596835, 0.033171461564638925, 0.010679717656345138, 0.025338183810573914, 0.025858353680720734, 0.09714661376370538, 0.02790022506228378, 0.061165344706105615, 0.027025176452532895, 0.08978871463407433, 0.06937309198321835, 0.023209549141146486, 0.04775729683798648, 0.06496332901259584, 0.06065177468342647, 0.05875252397550691, 0.0682443380355835, 0.13237053979068034, 0.03484969973684319, 0.020558231833180594, 0.05934357613084778, 0.09745052850414669, 0.06400394178326092, 0.04450340349707873, 0.010924115025949095, 0.026860973166842616, 0.049970252890019655, 0.07957230397169629, 0.020681229164643634, 0.006576732679780934, 0.01202622252035766, 0.056247485411022945, 0.05451033507744151, 0.01653918328004018, 0.04627772058630663, 0.04211184170637881, 0.015025122538058749, 0.02910718126522918, 0.05818880583730437, 0.05487639870074007, 0.052601558066183524, 0.03256599163456309, 0.060665418709357904, 0.03226095840575234, 0.027978203236876477, 0.04791891840737193, 0.06307790619170954, 0.0377850498883955, 0.05084759210266414, 0.04014723603763888, 0.01981208326234933, 0.0802107003607577, 0.030780363257133195, 0.029436924660037604, 0.02720781564412098, 0.027881331418851213, 0.04667907788027679, 0.04561765156986733, 0.027887184330592715, 0.011652110185804627, 0.0645818248871834, 0.00616460083796072, 0.02533614984713495, 0.035205593542946924, 0.057093679319105806, 0.02801067578876692, 0.03987869157666161, 0.032932537893253955, 0.038199334916087894, 0.04062924323783767, 0.027156332620389523, 0.03951579189649032, 0.03848079944990816, 0.03385034953093818, 0.06053805276150666, 0.04638722519420328, 0.0472596844267701, 0.036017030041905186, 0.01645284325575396, 0.03878986230120063, 0.01751721325901247, 0.06089244120483918, 0.03167167399829674, 0.04133427395455299, 0.018058448631857193, 0.062403541974603176, 0.04879307835513065, 0.007881885554055654, 0.03450184602350478, 0.016734631461722237, 0.02350119306826063, 0.012951425948901283, 0.059917046568326415, 0.02142459109065033, 0.04184392926793906, 0.03325383133825756, 0.023031169398417397, 0.08108179595681929, 0.027115697401665875, 0.044932573613139896, 0.06639679443211326, 0.07130772446192081, 0.033485212874027996, 0.017083666865683852, 0.051435652684660695, 0.0377321821607409, 0.0026473417904438272, 0.12132817143273932, 0.07747719905549481, 0.148551864249091, 0.16180305561471373, 0.3359389623566982, 0.08958676619635475, 0.19131568891386833, 0.20033640486578788, 0.095084136532199, 0.14796879472992114, 0.17693218895264212, 0.11573167698037241, 0.13995716979186382, 0.10152555701713409, 0.08584858654367347, 0.15974712077408068, 0.1257104931339141, 0.200236767470356, 0.24199830398203867, 0.09119579598547951, 0.06702415915506502, 0.1537090302595208, 0.0716551989617367, 0.16002409220222505, 0.14552278324000298, 0.09200686859267374, 0.20263646128437213, 0.118587399953075, 0.16645089572956487, 0.1779557130629978, 0.261498719694153, 0.15031892265523636, 0.13063816984574642, 0.13818983559406575, 0.16339504760840248, 0.16061269287620822, 0.11763183550248224, 0.20824453132527493, 0.12745659903533038, 0.08732181958734028, 0.17748168849897, 0.1647381682790095, 0.18345711302132378, 0.1247847754688513, 0.13799612260153218, 0.17223230082421534, 0.12928469166640313, 0.22327762788101552, 0.0901764010890357, 0.21357284137798896, 0.1227388150929924, 0.12664272254633327, 0.1321879810383243, 0.16573006827985087, 0.13538250639553995, 0.13236981966803152, 0.09694510965698189, 0.15760135446344653, 0.09808671089910692, 0.16682010414379259, 0.12652427003148103, 0.23963319137692454, 0.16716824514010262, 0.07131637359458594, 0.12869852715201918, 0.13646665870422317, 0.1403344221292965, 0.09594712691802172, 0.11358769565460183, 0.19139572978019717, 0.06592073207420689, 0.11299636004672897, 0.16460416417929435, 0.11115771838493886, 0.13560396709269093, 0.1502545559478383, 0.19136733856172333, 0.1269090759958471, 0.1824235684809185, 0.1543676513697832, 0.23217091276761026, 0.16224095147223244, 0.14502179238104052, 0.19784030654738027, 0.13060322091464074, 0.20215895868116812, 0.15191664498659874, 0.08556985311330327, 0.06825016796468727, 0.13708964140424806, 0.17882582040563708, 0.1461550202821532, 0.16675521649660605, 0.15687756991434484, 0.156911967262145, 0.16537910807997952, 0.1353630630840217, 0.15770402556705862, 0.15129746208267827, 0.09157391400226662, 0.12011055894676717, 0.15684655867516994, 0.13140804224437283, 0.2381345395359301, 0.11218548662239507, 0.09324348005916804, 0.19960672143966923, 0.1594549654832771, 0.15508098647959773, 0.12606009735815948, 0.09855075333748134, 0.21669440452129612, 0.17188854185083222, 0.15457587406760262, 0.07751302132683416, 0.12980224534628854, 0.09935579683271148, 0.1647607372292588, 0.08736901060347596, 0.22201338362309242, 0.10979270292145592, 0.1886273025264663, 0.1073012394349902, 0.18156052446894108, 0.10858664304138192, 0.1462269865817601, 0.10283958932925617, 0.11985884543748633, 0.08565718713667124, 0.11622761931991386, 0.07035324019530127, 0.181242797163225, 0.13468136740547998, 0.2647359314705095, 0.10491119066794073, 0.08101261055637753, 0.130968660176281, 0.19837384082136617, 0.1376105658710003, 0.18843095419147324, 0.2430730180874948, 0.296602247342948, 0.16903184594646578, 0.07806283496921101, 0.1302754425353581, 0.08705650801740347, 0.10594301917139562, 0.12690051113285367, 0.1180238503542158, 0.18948001967322445, 0.2000170994189478, 0.22100979312052652, 0.14289844180307082, 0.11234074966200899, 0.2552831419292958, 0.10593730415548049, 0.09413178965088823, 0.06750674092120702, 0.0901322131375632, 0.11849787491824358, 0.1393208265184395, 0.1952184319135643, 0.16716142695757652, 0.08381809348300581, 0.14077985629199014, 0.1459138404818312, 0.1490826406065495, 0.19177976965663895, 0.24195802307898, 0.20187602708897284, 0.17908903289466135, 0.1857850550403518, 0.30348802946748277, 0.08790738655314331, 0.20203811597199212, 0.09410830905600902, 0.1857835841515372, 0.2006688870249256], [0.03877337225863049, 0.049420270708299456, 0.1019226816753226, 0.04790356983580897, 0.024156475950392987, 0.04371249815449119, 0.008595618550785849, 0.0618396399752988, 0.04428507992997766, 0.009947629671754136, 0.039907052151618466, 0.025139824494779594, 0.026374392421735872, 0.029367790970530723, 0.017554399166857044, 0.019352175783546224, 0.028499612254240823, 0.047534583587079286, 0.021833982731726383, 0.034766927767064304, 0.061425511995630885, 0.027345341833068, 0.029248920937759743, 0.11153721535998969, 0.063977109553713, 0.04553297587159661, 0.03638325837410746, 0.0357690665330137, 0.03606862989404509, 0.053983584512025125, 0.054714708183441436, 0.05982806545592124, 0.008575934879181367, 0.08409219208143412, 0.03270125211847406, 0.057643125239279, 0.02897448717586456, 0.04630430383727916, 0.02105680376952214, 0.05657053702781278, 0.037195901461546464, 0.028827557257646998, 0.09607200691055867, 0.027061404750472116, 0.05570280838817839, 0.03696216420540887, 0.0267596005822622, 0.06194456337740826, 0.052427154319781455, 0.0912442587075695, 0.013872503993972657, 0.06343384596308874, 0.03921196908659993, 0.006592169830260138, 0.032043803122735796, 0.05943638002199512, 0.08049067485356524, 0.005042202547267681, 0.06190119897045436, 0.08696739667005117, 0.023046083215083328, 0.05599076934759656, 0.052116490344727234, 0.03961780033404789, 0.045276700308726686, 0.045741336465242415, 0.08224037370734638, 0.06514781830652107, 0.14169890133123245, 0.05962313693617621, 0.06473155677198403, 0.027322924185183742, 0.08136675002113467, 0.02248461929059798, 0.03332313165188797, 0.019898961463402358, 0.0033950857393774056, 0.022044287273480047, 0.04666990014694391, 0.0297670568444676, 0.0052868216035647266, 0.06080597286082565, 0.024530654360029488, 0.08454712573438884, 0.01946873989166512, 0.031472123415780165, 0.021822905100341287, 0.03661473567086843, 0.01379588658305546, 0.03141553058559376, 0.02741261201369907, 0.00833827238004174, 0.04113714804031676, 0.058838636088635654, 0.06156670966095502, 0.058032504748553045, 0.06594902370125055, 0.09061371471973197, 0.045482632403652516, 0.028144346640234994, 0.03504070843900404, 0.03342951062105356, 0.14369505067025462, 0.05380433525950198, 0.052888898494383024, 0.07925892038451088, 0.006582510419144866, 0.034952742393098535, 0.06412083530918726, 0.02171084367399735, 0.0637453947696955, 0.04075539110588931, 0.054806788121500326, 0.038551199099709915, 0.054947679351654746, 0.027774180616101915, 0.01487726086540328, 0.011122350810065625, 0.09562589092961243, 0.02364664635200414, 0.1618317073030818, 0.04885938326497713, 0.0263382445630287, 0.02814987396460868, 0.1338576543475351, 0.037613875202594266, 0.028660743527354735, 0.024333658680740385, 0.04861686664122728, 0.025827600996220307, 0.010448419432636472, 0.0545927852902922, 0.06711027509863339, 0.024699415868869232, 0.03312881344989423, 0.015437871559462963, 0.0739091445481585, 0.018665475635639122, 0.06233639819847961, 0.029565196506859317, 0.04944102019972859, 0.008425467549973439, 0.019088800500838027, 0.015658332511872774, 0.04128644708544016, 0.036234108716129296, 0.03587072640056572, 0.09856380747571107, 0.08924039486314982, 0.05793808441188547, 0.022411486622126355, 0.009321954172675409, 0.04910024896925015, 0.032367988549653566, 0.03449296323402274, 0.02037881978697354, 0.053663938156058716, 0.04148727703479029, 0.03264459991647351, 0.024045569401594902, 0.07793013321896715, 0.013326755405644016, 0.038644742265704184, 0.06697600286814474, 0.03594620138286583, 0.1292057233231683, 0.018257405496232452, 0.028952209339026484, 0.035067900729876374, 0.03169170528229687, 0.04182280439342703, 0.03567836172277889, 0.045264661236996614, 0.15185572567485994, 0.06302683494023739, 0.023847771245205117, 0.01827867401223029, 0.07579060286403665, 0.053921129193998156, 0.046695751783948754, 0.05826796570252027, 0.023035153055623658, 0.054389542163980585, 0.021478077434303782, 0.04671644764922319, 0.08903262415720571, 0.03459887871999414, 0.024319652678264726, 0.047243531462886644, 0.06503868908170732, 0.02878333674743772, 0.07622795479912912, 0.06084412020901519, 0.03815685534068654, 0.02991032294718729, 0.03582607879633865, 0.08464257262887494, 0.061381055913384885, 0.029219125863164667, 0.027468118914252812, 0.007352464693418194, 0.029152633261776743, 0.040691169955196886, 0.034059445568991285, 0.04298676391162219, 0.03298414157583349, 0.07325221649220875, 0.012788516394193135, 0.02333865219336604, 0.0312606371834033, 0.09487608237372291, 0.05067278616010182, 0.017556540382605408, 0.023304737480958144, 0.04796697127242242, 0.013029683745586345, 0.044613949984552405, 0.04316136684088458, 0.058203277238194025, 0.04315895366392309, 0.05165432099132769, 0.02424728226727776, 0.05560654944049255, 0.011872016682079243, 0.016346226799331846, 0.04294857059815719, 0.0391551215321787, 0.07238296716804467, 0.03634814856453769, 0.04417833323860842, 0.07844111386446223, 0.05256599626473842, 0.06074065620440149, 0.0902822437966543, 0.08020745980883799, 0.019183517696576256, 0.030755873341413758, 0.05405729366165977, 0.12344245919056478, 0.08127842008346513, 0.048322853587207296, 0.0620969306046684, 0.050214110167636994, 0.05069280020712365, 0.08122237309092477, 0.022560481147299853, 0.02227834054088641, 0.03352543632049234, 0.0612706856261338, 0.016335532211908893, 0.02725312782962236, 0.03454312667130463, 0.011640541300538087, 0.033666086232950615, 0.07221904733488638, 0.0017275124686890312, 0.006633860813904434, 0.0376958504409319, 0.05857320577507058, 0.041269903416715326, 0.0324867436692359, 0.016245030414974018, 0.020412952834439856, 0.038333951886142456, 0.08626924542289588, 0.02805178789722343, 0.063936234932513, 0.03514709889948849, 0.07887376201969963, 0.031156008725144693, 0.016385222589897535, 0.017207683094086188, 0.02085804417278738, 0.04803153333224116, 0.036680791602139516, 0.012176449489479345, 0.038392802760485685, 0.027681204355171615, 0.09863598061905754, 0.027555673187899015, 0.09385260422864268, 0.05162868002850202, 0.04160250814992093, 0.07459516096259318, 0.04924998851493002, 0.022013055784026944, 0.04178626199943885, 0.03820342199516393, 0.009449034752774864, 0.011375484454836096, 0.041422531113869725, 0.11092295074054312, 0.023103020784835664, 0.03807598326895987, 0.06621700891804311, 0.06439435551123274, 0.15533304472844447, 0.14680965773520932, 0.058982932579613505, 0.061178766566539006, 0.06334699074467344, 0.018108227109957128, 0.032595830759213816, 0.0507371950023357, 0.07559202521318391, 0.017008555775147774, 0.04433608223353663, 0.041135926130077535, 0.016125386633399515, 0.011767618050197921, 0.016391458545601176, 0.005961547797215322, 0.01909869452638011, 0.022294746313784874, 0.035135741646011034, 0.056933386912268985, 0.07244760200621621, 0.02117816550326684, 0.0366569854198925, 0.010175209496200327, 0.0574498335951038, 0.02897812034784546, 0.015409861469731457, 0.05631281355876596, 0.024297823002862356, 0.07380752298500269, 0.015935256059521872, 0.0449051017001752, 0.025048324868323344, 0.07262593195323022, 0.050505204426665465, 0.04916825076384891, 0.06906513229853685, 0.027953772692971175, 0.031108323582297856, 0.0753649797350649, 0.044452592715500824, 0.04188881818986228, 0.01568283296130117, 0.01836873147816908, 0.08534870651220122, 0.05896830796113899, 0.06149614147180992, 0.033223819843823874, 0.008956602053536523, 0.031866379074692246, 0.06406735088075362, 0.028220191259958574, 0.011304585890273654, 0.030230543869096908, 0.06099119759915818, 0.037437889484628555, 0.08374038918484604, 0.12431462730972037, 0.20187141523966867, 0.13833557616078085, 0.21395985367557696, 0.19240319668765993, 0.11570042059306176, 0.1745309629627774, 0.13634390077523648, 0.20446177301627977, 0.19839959669738047, 0.13181653564735768, 0.1624607420977085, 0.11733864599298086, 0.06708800492267455, 0.16737205517147818, 0.11032714117919246, 0.18778192450202283, 0.11113035372428356, 0.1031753120403136, 0.25285262073720655, 0.10446466866039461, 0.1062609073555758, 0.20951593084441078, 0.10489792968597143, 0.1501315835142328, 0.16500704981867345, 0.0998940425474317, 0.21762990512915198, 0.19025957542321376, 0.22974636706133045, 0.18347681680273625, 0.13273997803128537, 0.15569820819843203, 0.1227447216308886, 0.1480581818689262, 0.15812986320064915, 0.13245943663341384, 0.2224770047131085, 0.10609780723649649, 0.1186169096599183, 0.1957927220651219, 0.1802463466001134, 0.13803680187031148, 0.25764456199061486, 0.20331880047677026, 0.08136593030705568, 0.18940348748958882, 0.12128071228583014, 0.12313597805557713, 0.11107091296223864, 0.1754914533587233, 0.09925139437039053, 0.10061344507360652, 0.16272378604738943, 0.1581637855739363, 0.17894712276756766, 0.12523901964267417, 0.17016631491001577, 0.17994893594614922, 0.068813702241788, 0.1848053358375065, 0.30898256527800716, 0.1698211923001274, 0.18657481508149257, 0.19161257862804398, 0.25954945493609677, 0.23307714881675862, 0.19551291611165772, 0.10731813167372059, 0.13294689837963353, 0.16668590086121715, 0.15399830505972908, 0.09349753779749717, 0.16280067063147025, 0.11838554344590634, 0.0760936136207273, 0.19076983594606, 0.10148191298808783, 0.20274671665843458, 0.07052453745517039, 0.1673669530259025, 0.20867743228952731, 0.16444374536795003, 0.15796103274389622, 0.14599282414682452, 0.09884946634091678, 0.10954323404979323, 0.19612495907612387, 0.09986722180920263, 0.10664726081754893, 0.2123811916117707, 0.17170828136224903, 0.27079424670627045, 0.18278669415702745, 0.1682955894859568, 0.09362039531791404, 0.2071455781978946, 0.13162965615910868, 0.12791711746925308, 0.12031408552561076, 0.08095726070384826, 0.210401022866849, 0.09203226440736363, 0.165219945652831, 0.15066220665410643, 0.14343160835485305, 0.2157567435454938, 0.09231310457952561, 0.12363720640179612, 0.17596127976092601, 0.18202838968605767, 0.12376614666033177, 0.11109120663135283, 0.14097723118480177, 0.21168987386889998, 0.09536778058616385, 0.08827805819530642, 0.20963850491229566, 0.14016560699430206, 0.3814872101910653, 0.27862887469030195, 0.12492289346071983, 0.1420758778770124, 0.2700698339650708, 0.1979946732641228, 0.15331218139298503, 0.15505132355516957, 0.18243757256817433, 0.09565435109599944, 0.0920460922943969, 0.10569707430418461, 0.15517100181070068, 0.07093350583266828, 0.11111080316045593, 0.06093592052498172, 0.11585471070101185, 0.11347578553062294, 0.17730234731589595, 0.19933808504814104, 0.13013082045701244, 0.04463486801532488, 0.27791460495321985, 0.14599925928538846, 0.15500843795316835, 0.1526005469983624, 0.11914934842817246, 0.3059913290123786, 0.11786294890747917, 0.11540656458706626, 0.10666347889890594, 0.12003958090058259, 0.16023639048780167, 0.11057579799765542, 0.19503930523510904, 0.18358255225804546, 0.2049206290394068, 0.14829108791966594, 0.22742751084508436, 0.1568780295670994, 0.1567884892105095, 0.14100715457912416, 0.1481537896418764, 0.14784900922208064, 0.12182140182102881, 0.22283030914202814, 0.19049595951312975, 0.12912905324370633, 0.135732194889457, 0.10695310609955942, 0.12206540848579138, 0.09746092431727918, 0.2098656806253618, 0.12654375164739548, 0.16569655959404286, 0.09894093723907586], [0.058033010366583065, 0.06556653898329505, 0.03860047387499963, 0.06775127618663734, 0.02522590979483099, 0.056549684114513867, 0.03525273859380715, 0.018821085330038782, 0.028368366071053093, 0.012194841345321509, 0.06430876816833211, 0.017963800384032152, 0.028213353925234372, 0.06635097471336204, 0.038421209300718004, 0.024823177373036746, 0.03866802367772307, 0.030980220274819486, 0.10887762621766138, 0.03783409100686831, 0.03692240424213871, 0.04364677930190679, 0.03430861949680313, 0.02265140237737327, 0.049208501023390604, 0.025179500188378078, 0.053161936061036204, 0.021222533485401544, 0.09239677670261554, 0.02262589164949473, 0.05591696060653176, 0.019979758841556408, 0.04484733100980521, 0.0158510189465878, 0.05945176689795429, 0.04091177263387269, 0.04241226691632502, 0.015603855999577192, 0.019155350558820273, 0.039527838629099636, 0.042674127260162946, 0.05411036823305392, 0.04834811150607082, 0.09961600625707258, 0.03317888878706483, 0.07312748971725665, 0.04398457045035978, 0.029795882817838463, 0.06838451680396834, 0.05508713416695114, 0.03187401122563789, 0.0471981905490881, 0.04220208686385905, 0.047406106811737826, 0.045114776134611144, 0.0702029797098329, 0.0656297795414444, 0.022164417520886468, 0.023296521187970237, 0.010757352048981815, 0.05843177445292954, 0.054662560578435666, 0.11034043280467873, 0.009005699670993754, 0.01987656871337564, 0.0050785419279559246, 0.052722396944919904, 0.00715816229198789, 0.042720467918702675, 0.05011485198572759, 0.03455786237252816, 0.00860245205507043, 0.06949171303741394, 0.007951382177716662, 0.011859075541818335, 0.016732469178555955, 0.07188690225443534, 0.037185199213244265, 0.022208595896259915, 0.04545244853943587, 0.023400670841276165, 0.015917704985176605, 0.01773501205588541, 0.019252048091842763, 0.015813110043264685, 0.016700887203877492, 0.06218513413783043, 0.01452932000956348, 0.05331257192958748, 0.034009266809950915, 0.03809779379216414, 0.05076621058246782, 0.04425655464611707, 0.02245215056914716, 0.03050234994941181, 0.10192141763024753, 0.018530165356013085, 0.08802032323494073, 0.09071912841811296, 0.0314459461914075, 0.026354905060161988, 0.019224679600747845, 0.02705324974451815, 0.013254748886421084, 0.04417840601696123, 0.018627699840092854, 0.014572593443576368, 0.05402102322888471, 0.024285366413213556, 0.028134105959907178, 0.06648199873105173, 0.01652718442792614, 0.030659556937133594, 0.04923024259868169, 0.06866971601641948, 0.004104940894795883, 0.0561824560375704, 0.04303402004523143, 0.04785633285439784, 0.08154452072396394, 0.017892138604375146, 0.11118037926573908, 0.03589451343061463, 0.06418646606166037, 0.017870012069902113, 0.012317259322791811, 0.05473782871699622, 0.040645940124147364, 0.014759300562042384, 0.06238872583414759, 0.06368495043246977, 0.08479852514762072, 0.07091906507529559, 0.03222504037342245, 0.046314531111068306, 0.08162122144694291, 0.04607467281241571, 0.054719837142094496, 0.04869652446359397, 0.018410038939046285, 0.00972142305991222, 0.09622861826491934, 0.024198216250947407, 0.04240336114420526, 0.059816888233105985, 0.02781404974690128, 0.03269954757284253, 0.02286111703142524, 0.010687987575487745, 0.06635174846216556, 0.03415472009369443, 0.07990143832660491, 0.017955235521038695, 0.03954399925386233, 0.021190848088853305, 0.04401410313984079, 0.07655682868414349, 0.03229092776535019, 0.03315248939719412, 0.05301413471780477, 0.027876662112952724, 0.011544179888592373, 0.039176001258554964, 0.05164062716968117, 0.012815412783604718, 0.07252000497593995, 0.03187708706865388, 0.02057240062934016, 0.05076664725258466, 0.0420147285706574, 0.07034750985762767, 0.01627073841049306, 0.058586547196271925, 0.019561461428360596, 0.018035433435391997, 0.011885170411739138, 0.06353434137699586, 0.0834837344084536, 0.033370996825397015, 0.06139266597587736, 0.019534673248868317, 0.04088849505229343, 0.03953349618842045, 0.05966853147612945, 0.019953987643783613, 0.0465234624402177, 0.03427774615345463, 0.04595107601715192, 0.036571528311939015, 0.06068925170468227, 0.05137555691744051, 0.10250637172571114, 0.03704312054680721, 0.0401831579004084, 0.016052578594685805, 0.03791589387542298, 0.04774677462034649, 0.018242742573361725, 0.040715075728874055, 0.017925373413750244, 0.06391855362322062, 0.03927820504853322, 0.040650590277847745, 0.09606330415173885, 0.04235440046496449, 0.028870293472502983, 0.10372494948246788, 0.03157674612837934, 0.062479258274599436, 0.012762268306687476, 0.02823389082726452, 0.041375194541028434, 0.005466168532298217, 0.011629017422937099, 0.00920338674463452, 0.03271203863644793, 0.0033810873977809905, 0.03461804623985964, 0.051684623599172606, 0.099593460289461, 0.01166314089430436, 0.014647575256775224, 0.03182449896309165, 0.07785953821674471, 0.056501673384299206, 0.020622410849037192, 0.0533854000781092, 0.010683678330913668, 0.014733488187043658, 0.01534661133548305, 0.059544452045473366, 0.08796295091029137, 0.014014112473946187, 0.047599478895145084, 0.011926849425259617, 0.059622562370233, 0.026744181147566246, 0.06920485907504637, 0.03910375150641607, 0.03781747839023029, 0.05776247790744228, 0.08102964835181352, 0.0968766903444644, 0.040357454394501065, 0.04054513827507054, 0.027372513056522416, 0.020211190173041918, 0.023859433018632477, 0.05588327189006152, 0.03351327084425477, 0.024149809070231936, 0.05781681269347187, 0.024288723793541713, 0.03363892841603487, 0.019161988710684162, 0.008034931247933738, 0.045159025373117584, 0.021119329950682098, 0.06120788556854091, 0.04956903349187586, 0.03055710799901957, 0.03561356600614325, 0.07052774736357313, 0.040591724081746036, 0.01035975241628025, 0.07398815885666879, 0.07227569953688691, 0.03409678469442072, 0.08695343088719153, 0.036320216998818426, 0.055466232776281335, 0.04754140943048462, 0.004662397700632292, 0.039183114384931904, 0.022839176273273847, 0.044248752040608276, 0.0864595493241664, 0.011187265270329531, 0.031071411550886212, 0.01804093586190814, 0.013967272900645773, 0.02906536244066252, 0.04935047626795788, 0.04266147148765383, 0.016765623548699003, 0.02890991362472696, 0.04471334223184855, 0.05238294721611085, 0.032419818228170756, 0.01224735954536065, 0.04089021875012306, 0.07514491331793609, 0.05233152739463314, 0.017248532817428632, 0.06893727988485368, 0.04556955273954138, 0.04251371994013748, 0.02121312784091119, 0.02004277914942753, 0.04400970962559504, 0.03595844346789583, 0.055968250193062334, 0.045480200074492924, 0.04726063437579621, 0.020161216342521292, 0.02076490511817317, 0.038409740964491526, 0.07589726528573422, 0.12589189509350446, 0.02804589285064609, 0.026304329850620804, 0.026216369550374728, 0.043421415386781584, 0.05416829980188801, 0.035496917628352685, 0.06793793350938829, 0.012013352243229749, 0.03320808822829877, 0.004834849359242306, 0.05653090729948975, 0.0994282304459522, 0.04217371479758332, 0.032178374127514904, 0.027819379803634463, 0.05233158868166709, 0.040846896478005, 0.08097484242171049, 0.032886691361425385, 0.052106550353909695, 0.06553289240166064, 0.01355956569539323, 0.025458773710734905, 0.049526630525266936, 0.020067594652514786, 0.028971524330817407, 0.03054351376880321, 0.046550267856688275, 0.03729075463789125, 0.0390005977674117, 0.018715129624451363, 0.03909146728655023, 0.02129214214942148, 0.025174530192969308, 0.04441092136285959, 0.05601362558081747, 0.004297890672234878, 0.03307769240270699, 0.017785585350206783, 0.05870916339899263, 0.043098076487020145, 0.049104673127012874, 0.09867950973491516, 0.20199581259681335, 0.1492092442969161, 0.14680800298529287, 0.18684624003306513, 0.13903909002340611, 0.15359793218874163, 0.11710186353734425, 0.13816749647019372, 0.1396295905954415, 0.12020884802745235, 0.17211868998504457, 0.14358087292601987, 0.12388096025754368, 0.11127579551670821, 0.11523559674500458, 0.16117080325080504, 0.13868999907806998, 0.18606538193360453, 0.2531911856344631, 0.15399732446718603, 0.13213093813148238, 0.10711023839370859, 0.20576081298772367, 0.13972388069716193, 0.10299577933525848, 0.11400145974250571, 0.09183878124120737, 0.12730008727239986, 0.14338008128106594, 0.137178078594227, 0.20902862231577599, 0.12300460163744227, 0.23122326200527532, 0.05276954965665937, 0.18484647475904037, 0.16938188684082803, 0.1003812974499118, 0.1069108640114146, 0.1108770773956372, 0.17558185173378837, 0.11723766794368146, 0.11532905181088757, 0.1437992079844398, 0.26692792352649475, 0.08902458023400077, 0.11634072454105462, 0.08178025363914429, 0.23210455423160908, 0.20956661522148118, 0.16924624331295493, 0.10479492150367269, 0.20725324419477295, 0.09529907782111438, 0.211520032176087, 0.2214702885718115, 0.2897236970884185, 0.12166007136505459, 0.1278071378868434, 0.12559600895450962, 0.12165794164062509, 0.11435060431399655, 0.2562497916721529, 0.1703856152392203, 0.11749035438462613, 0.14624397841192063, 0.1437601375003015, 0.19746673143198415, 0.13356234277448348, 0.13923868657119814, 0.14191411075092134, 0.14517723162087703, 0.14756718079649633, 0.14635512244797524, 0.1472184116080884, 0.06630063507585757, 0.12851794490650778, 0.15257332023353348, 0.1444223745455665, 0.061131541076446735, 0.12938679586495125, 0.12335708635228297, 0.09231156474279781, 0.10182042425918965, 0.08055614472757425, 0.09095777246740558, 0.09551904464681303, 0.16171978185734442, 0.14205539268591713, 0.14303056132649222, 0.14877976008480595, 0.11715450143862156, 0.1087693703330813, 0.19575985689317027, 0.10591468923995573, 0.11107825208455326, 0.19491463208631163, 0.14479608755678902, 0.1730730363558377, 0.12047422854530236, 0.1188199382816111, 0.2018313488412288, 0.12210242585429262, 0.12286289069320887, 0.11269623744151286, 0.13141090741320965, 0.1296132820988855, 0.13424719473527325, 0.1806415713602497, 0.1613098022437865, 0.11296258323014745, 0.19427588329680506, 0.15844949040441744, 0.22753048838386614, 0.14845055678198416, 0.18737975898529255, 0.10660272046563127, 0.09980007420263945, 0.14162344167069083, 0.1491321452082165, 0.2173205894688445, 0.18688216955671388, 0.14535586800306075, 0.10100785011966383, 0.08639156668176574, 0.09322022162978688, 0.12839109606800542, 0.14920051089457928, 0.27262115190106057, 0.10046364424089271, 0.15484129288984885, 0.20773099194611275, 0.19482892216934314, 0.23590079568807157, 0.10633789919196598, 0.11350603834275277, 0.2810611425628585, 0.12493714269611145, 0.10215677516234499, 0.08333116799833314, 0.14046372244915656, 0.07730361119273209, 0.1841255094135, 0.10243687222922042, 0.16081706981264776, 0.2370801727257429, 0.11108121684482021, 0.13147666840062988, 0.08152349161044245, 0.1386774965231457, 0.1253739507087777, 0.1720861465700211, 0.14369089847370503, 0.25315268205538877, 0.1672467385088244, 0.14584895283464464, 0.1485629265587176, 0.1785674955575697, 0.11845899595608635, 0.1468846577429964, 0.13629087216911778, 0.10081894815929475, 0.15787048115124627, 0.08283144884532498, 0.1618919831009642, 0.10513239855607671, 0.19215242546652594, 0.08222191864925046, 0.1101835226760276, 0.14820174674593634, 0.12912551391749613, 0.13110422709536168, 0.104418205427787, 0.11980881223515158, 0.1366059028453404, 0.12385493625075587, 0.2617541334081081], [0.01371720648040214, 0.1624028105288744, 0.02881303606104226, 0.04833799914547032, 0.03672942669401246, 0.025573334498931805, 0.042483214318992636, 0.034712945381479884, 0.03499044157985238, 0.06650121987707193, 0.016859563165194085, 0.054099972419921434, 0.04450321197509766, 0.03367533291419668, 0.02842435560699913, 0.0714793051743219, 0.06169204547580692, 0.02892674840686302, 0.02644411216850483, 0.038558630152575435, 0.009584059664649109, 0.1298721125649829, 0.02752178337334866, 0.07111395018235331, 0.007568102164734756, 0.04363827189550765, 0.03349940848326491, 0.014074800044087874, 0.022393751686679262, 0.06029407290982143, 0.026421947329635584, 0.028489882937602462, 0.04889675686436315, 0.07407158583162293, 0.02418655447752005, 0.008792259914409972, 0.0425144745367429, 0.04722317650673851, 0.030768833633872773, 0.026574996375148336, 0.07763056985793576, 0.012843694834549342, 0.008715202960546219, 0.02603546937837476, 0.011893229656702569, 0.024318953623033823, 0.05079136124902195, 0.025768815239350644, 0.03297066608924539, 0.028047459500451243, 0.04534717273688124, 0.05476084582868123, 0.018686056587724917, 0.06694216476452929, 0.03638659085657808, 0.06796843913053313, 0.0494281001268856, 0.10894343317035707, 0.05753249448213366, 0.05332543071539653, 0.023621804035839536, 0.020450962286803032, 0.029809297017392614, 0.048957668515222694, 0.045566469235646154, 0.0021222682393741824, 0.06669414379904348, 0.020387867285359292, 0.06731978482416562, 0.09417325032935028, 0.026076855363264203, 0.03130128772388543, 0.029142750727553523, 0.08441073144034994, 0.05260683641198182, 0.07971095822511182, 0.024412759174142155, 0.06056686149789922, 0.0167087453507608, 0.0889550730766308, 0.02610222628009656, 0.014524290642340579, 0.009143155954417684, 0.10089771731966928, 0.017178554515985232, 0.057182645109752496, 0.0639527517881605, 0.01563967539808683, 0.011560787717180868, 0.05776100318818804, 0.06572398537349317, 0.039056296189946514, 0.031586268601278146, 0.058592633764830336, 0.05352028517893726, 0.008028391729890099, 0.05812919270547648, 0.004203059999722867, 0.10195496462045178, 0.019356827852466417, 0.06488250673658426, 0.046747451227518826, 0.02474676967868882, 0.046397372028760375, 0.020030165511754253, 0.040342147957773945, 0.04057481652125716, 0.02168998118459938, 0.02759444106730723, 0.030121382085546374, 0.03817575089933892, 0.053557984365691105, 0.04727543136405368, 0.05423148290344304, 0.046658611841379635, 0.07015509921456538, 0.023993318374719352, 0.02817710839031685, 0.02319983514626661, 0.03054288174626568, 0.025222684564669768, 0.0683018252734215, 0.02715349043419044, 0.057897481751898607, 0.04048508847312581, 0.05872327090811826, 0.021376293077464067, 0.05242562214393289, 0.025976461456007054, 0.04788576595244869, 0.024255793504116517, 0.05008005627220677, 0.029247806279829917, 0.048827640411834565, 0.024046728109580376, 0.040988749148504394, 0.09022311713065832, 0.030642670444062645, 0.06290504228203528, 0.012433450920657526, 0.04222045765228329, 0.056711615949508645, 0.01949089898487493, 0.03362130073289718, 0.012831232499241108, 0.03169571000692104, 0.03982376307249069, 0.07050182294821547, 0.11585536187574749, 0.04653878802914293, 0.03717854957006151, 0.025079948977837642, 0.05005803507482333, 0.047070912701348146, 0.03582027568031223, 0.04296956140728247, 0.03461173367536357, 0.060308460041039416, 0.07903233455914645, 0.04079543835213108, 0.0329438032161805, 0.029058214840328986, 0.02168852370232344, 0.07474690765863465, 0.07356363123342877, 0.05129155537654316, 0.04579688550063199, 0.036683622297019734, 0.019713679268475504, 0.06199550056349366, 0.046113819905346444, 0.014580769516948252, 0.01675843189830982, 0.09672468317852867, 0.06319804793043483, 0.021372600533669035, 0.007313451665874211, 0.05936521045382946, 0.03585335152644304, 0.049648775583914215, 0.009980798406045764, 0.06714626590931608, 0.03399206813605082, 0.024790758447301005, 0.032104168935949286, 0.04388974408709234, 0.11708730020590367, 0.022429650566811045, 0.06752322713333754, 0.024650690761665185, 0.032073241966446085, 0.04803571234186811, 0.023834416417465098, 0.006854224568908855, 0.03398958218073653, 0.06256323300241944, 0.019350934721108888, 0.03483649621146821, 0.008924471368382295, 0.08874816805004113, 0.02857946925946782, 0.029787339022262927, 0.009282384773776417, 0.07746860354898438, 0.05105833906019407, 0.08270875986425147, 0.06878289784635268, 0.02238719397404742, 0.11593804574541508, 0.03296173350404828, 0.02500591998649461, 0.019493118724635532, 0.02800743523684721, 0.04307366509531294, 0.026285620068290064, 0.038132585675245335, 0.01675170756155445, 0.04499284941102228, 0.062000380543571335, 0.04579064571448872, 0.04326151368478614, 0.030119338546008356, 0.07348935900916977, 0.03295781113387596, 0.04750717296114853, 0.03417815089285855, 0.04529133258808044, 0.057068632074421456, 0.02676169966317473, 0.05543663496932676, 0.026019701373673258, 0.041956693579953526, 0.02518813399928472, 0.007956619825093977, 0.08304370882650537, 0.021326307755624576, 0.003359762861603691, 0.029019956409390417, 0.02552134585717032, 0.10215118272049774, 0.0174398307177809, 0.051624458884039236, 0.017106747179622614, 0.005389671301424143, 0.08023621874951548, 0.023688825237895214, 0.06304923918158298, 0.019921051608698986, 0.018306297227560032, 0.04992358664411211, 0.06080323026605672, 0.034634363912646814, 0.012205646057883579, 0.0563681059547009, 0.019900947546346054, 0.09310405971782823, 0.035182810088078824, 0.02040815712403386, 0.02442195222923352, 0.14087460604646515, 0.08140467903426579, 0.05560860638656924, 0.027079731488840717, 0.03169754287227988, 0.04980139562018937, 0.023486848071878477, 0.04074215693699737, 0.030776186162726055, 0.052660550666792746, 0.06142380744999936, 0.044248916749512, 0.0042190075562816235, 0.060094089487627636, 0.037271161939227776, 0.06906203730332275, 0.031400204996668526, 0.05199285907550685, 0.09699269137795895, 0.01762740160038154, 0.023174918136529388, 0.057124322836077025, 0.005081869143572066, 0.04711985805883043, 0.04042367503467587, 0.07232175674289465, 0.03583409207602663, 0.0010939195706141031, 0.032355011020216255, 0.06344234187816901, 0.073584399877056, 0.042172427769870534, 0.06548621466443424, 0.05825819042060645, 0.05132840420570105, 0.02871855060690113, 0.04926821757708827, 0.021047262144425226, 0.013256226478505039, 0.0652910001395691, 0.024826190013798977, 0.08060176526346514, 0.021048736863679463, 0.03604672360985029, 0.1299720104303091, 0.031671616541702426, 0.022804558675195423, 0.03628697261334427, 0.13821091833374194, 0.04459363716324011, 0.08309895142672524, 0.0520873292078895, 0.03997487774599464, 0.019328333212122805, 0.048346740208686366, 0.052822777445638375, 0.01246729189710271, 0.013545995405424508, 0.03442846629167757, 0.14835378455538906, 0.025138033764256586, 0.03005071622019093, 0.012132251004297889, 0.0677096929341074, 0.06309237759259921, 0.02198949666513551, 0.10673755960118388, 0.027855996891195257, 0.023684975646075704, 0.07427415480056117, 0.08505276674705167, 0.054027722667782545, 0.0475382914526328, 0.023421131134513887, 0.030574170692313104, 0.025783880358381618, 0.06723614334459267, 0.03375017204351964, 0.06040108390152455, 0.0773606311169363, 0.08270608621739572, 0.023677686319476175, 0.04492818775977339, 0.037317897133048505, 0.05945384682666871, 0.027192685407616442, 0.06637126072159698, 0.07945641019051114, 0.03121295012533665, 0.03455466778588391, 0.10512139753348405, 0.09094402885004398, 0.03153195488266647, 0.1131226649628051, 0.25743195726986856, 0.1188298514593513, 0.10342622881815319, 0.09937936935814158, 0.14587674650453752, 0.12046606970890877, 0.13431779739837493, 0.1850240232963716, 0.24645460679406123, 0.17659120321754487, 0.1077316506134887, 0.23022284310671592, 0.09870466040146929, 0.09246565566788759, 0.24403903963825396, 0.12581837363541126, 0.10851076969336118, 0.13850774676088365, 0.176949349322146, 0.11606169233639395, 0.36949539076416726, 0.12729922925392467, 0.12956394603656185, 0.21527787730578454, 0.08306640035082256, 0.11379319107941083, 0.1975652809825636, 0.075057701868636, 0.1668531225333291, 0.23161310882818317, 0.11458167175371801, 0.21214060936002962, 0.15701120629185633, 0.11917486681693024, 0.13511529492755092, 0.17021191246326894, 0.11377354858503227, 0.07885680083305606, 0.10030948436788975, 0.15450562380494612, 0.09192904172044608, 0.14494575049367645, 0.15486576173815036, 0.07469468344483646, 0.13409546336099026, 0.23415498856094577, 0.24451275776711204, 0.1430279413057912, 0.11404886526326019, 0.16606006831411393, 0.1705631178112761, 0.1498951994243168, 0.15879859667151205, 0.2337596412267416, 0.14724565369467582, 0.1587376620380148, 0.2982772832676288, 0.21861173873466833, 0.1216104978154744, 0.07929152508656825, 0.08755697793657742, 0.09391335500103813, 0.15144081245506966, 0.14842426464442285, 0.12133541096362377, 0.13411550422108945, 0.1579649857575855, 0.14771483658302217, 0.19925989811458897, 0.11805508375888872, 0.09986213498538542, 0.11555575254944064, 0.1172765852102349, 0.10888151794431672, 0.14795131260348907, 0.05410693615915314, 0.16307971049701014, 0.18945856921134457, 0.2338169139599608, 0.16046889817282078, 0.1495710982670707, 0.10429654300453202, 0.2424103213894752, 0.1807116224400459, 0.12668217607443372, 0.171575763473107, 0.16699935339631575, 0.19507770156187398, 0.09605574286392621, 0.1002205262381223, 0.18952023928924916, 0.0922760182631112, 0.20830457729678, 0.150754229135571, 0.12534522241161716, 0.14557637875118565, 0.09169785936753597, 0.155708335880791, 0.13867224115998517, 0.19149386564329748, 0.1352520263002765, 0.16068761627520287, 0.10383954091418175, 0.07878651992688257, 0.10314024053514005, 0.16087264183067507, 0.13832739434174954, 0.14863867733267047, 0.08033075399937169, 0.11374530292326406, 0.12522670094885174, 0.14017475408411798, 0.20479607846467726, 0.17995837414937635, 0.2203269023448229, 0.17507071787070844, 0.13812752200230477, 0.10701544267395813, 0.1289858714106583, 0.1356293552465016, 0.20581545037848337, 0.20072962247556259, 0.09725309998518038, 0.14154675626947036, 0.16714137077571886, 0.10633295026397514, 0.16557695794730418, 0.16541238693941027, 0.0814929706675391, 0.12208541104149435, 0.21729803584035368, 0.08596289452285537, 0.1628681016905654, 0.08950281828161209, 0.1384011073218238, 0.21807350068082734, 0.13255012612189018, 0.2215629239236155, 0.10583888483984817, 0.17001921070679543, 0.15723870376185065, 0.2106245060361201, 0.0751223290459283, 0.12041078880429269, 0.19959265606537943, 0.26179991482246306, 0.16439145220623863, 0.1993173700306685, 0.17258715275074207, 0.11494085973789615, 0.11929728766723026, 0.22417814891424873, 0.12933108595109757, 0.18180600968339752, 0.08306828492711629, 0.17005366934162958, 0.1483833402275078, 0.20198450513905097, 0.18850768555796918, 0.08134494715880963, 0.17008992062220651, 0.14071126077925006, 0.2778294772630738, 0.19927181844269076, 0.11262891363472709, 0.13843590303534462, 0.18201231716140626, 0.14171826803395826, 0.22340479847644606, 0.15632528180797256, 0.07180012747525208, 0.19717266092136984, 0.2671658704357763, 0.173206887237968, 0.11062727910616707], [0.02502604703148527, 0.023571987253343387, 0.06818578593553075, 0.030522831310067448, 0.024774823818475972, 0.036734961679265384, 0.07648637157774742, 0.05949301690223718, 0.0462518536275433, 0.0464338148313184, 0.03538634815824128, 0.04957454166405144, 0.008783045791900687, 0.023356406281011242, 0.034647735977365125, 0.05349000172329046, 0.02276679628618783, 0.044507299054173693, 0.028862182516604665, 0.01919372390294748, 0.06286954559806375, 0.024046105663141897, 0.03537626644115775, 0.04508275365937622, 0.10176161935012187, 0.028976082553966876, 0.1291127815361946, 0.06318935283249424, 0.029127021027248234, 0.009462053459438105, 0.03618945728146261, 0.01344940608232132, 0.022245615179980957, 0.018728310167188608, 0.022771320035380703, 0.014530065987679749, 0.06498813493958404, 0.007061958406871606, 0.03035379017913534, 0.08351184983527468, 0.007703071056429538, 0.013974969211455076, 0.02315515498330276, 0.03443138125622946, 0.05592389753268612, 0.027862443521078077, 0.042762009036396785, 0.037283721950746355, 0.06037853410347335, 0.03916855488393096, 0.029429005226120356, 0.02665793305383094, 0.08053602725868264, 0.07226610811607492, 0.007258652439040523, 0.05911314071366384, 0.057087282484938065, 0.042846374469058174, 0.029527380491697022, 0.03445566241298953, 0.04527948503833144, 0.058783263253468665, 0.044707948972861615, 0.024535507527029803, 0.02802324154594493, 0.046058328326551184, 0.01975589645876279, 0.058352212391553394, 0.038044508546590805, 0.026916549015309543, 0.019976506798317837, 0.05037555553679986, 0.053485910813774795, 0.008034259005780182, 0.08203014385916534, 0.03887824203458525, 0.043650521641416896, 0.09187929963152255, 0.014244323810412279, 0.013843571725902299, 0.030824386499701973, 0.007757250709654464, 0.017707308401323615, 0.04824206961559192, 0.030283170279055357, 0.06826823997882105, 0.06322323307094556, 0.06527514978041572, 0.05557662221573054, 0.03231695943301724, 0.05730776258954599, 0.0705868204034144, 0.056296974690931464, 0.05830752648293011, 0.06128589630187039, 0.08367555516381418, 0.02850190285713442, 0.06441798166281755, 0.04224360882935505, 0.04161754645587456, 0.11888235146480224, 0.03044764552595875, 0.05052373992399343, 0.025952500140955372, 0.05367510005711548, 0.025938515205897635, 0.0692359699056514, 0.0532767994539632, 0.09871904753268727, 0.0427900746675028, 0.03980465683965914, 0.011471726165543641, 0.1381729356944561, 0.025352245354424083, 0.05698982460965073, 0.06105395935235485, 0.016517951153218746, 0.0389843107381415, 0.05085410768046014, 0.04909326607782034, 0.02133278694424418, 0.04513897685213916, 0.03473105953044949, 0.03173913187046926, 0.005484249643726094, 0.03679178625104889, 0.05339077418489803, 0.006998432002165505, 0.03549925036608212, 0.0947690905342179, 0.0507470392321627, 0.035100080253135775, 0.08034513346971044, 0.042003662430591164, 0.04201268311589957, 0.04629077472453637, 0.009891500324761916, 0.037315349890700275, 0.020193669742213625, 0.039319485696333076, 0.02504213679311497, 0.0274537988157282, 0.022685560322697126, 0.07471520694032793, 0.009010860230773687, 0.031098406574118043, 0.0328537993763964, 0.00853694100383549, 0.03972143670844455, 0.04055574093194258, 0.02244671326010458, 0.0643910919766753, 0.05410819254334896, 0.021651990884434313, 0.03779294825489483, 0.0389610446478811, 0.03661790344443533, 0.06184231362215454, 0.03608741053950883, 0.02413966223567484, 0.10170899677060305, 0.03507543137417205, 0.018250797987885533, 0.04853000759237236, 0.01994955007948222, 0.06173260983139758, 0.033093431679111336, 0.07016360279052489, 0.03466636340524401, 0.029105790815646612, 0.03448058708360599, 0.05133600762834953, 0.04443801406230177, 0.022409906565782525, 0.03754806824989858, 0.04714909197402097, 0.02522675440676751, 0.06319611738886564, 0.012302938266657295, 0.014779494639726417, 0.027003049918059862, 0.04078856654345028, 0.020951221531797803, 0.027684303180825327, 0.028353538439278642, 0.09907492601703252, 0.040084776889172294, 0.02144366093430548, 0.018504974469842932, 0.01536522248399354, 0.04853484160717457, 0.01556514940720292, 0.0814296841441143, 0.046278364100163026, 0.06677685831222804, 0.03680145811109293, 0.058148731777985255, 0.024857925206062295, 0.02186235862844173, 0.02116638690143103, 0.07570320755363473, 0.051269702718503056, 0.022228619519380793, 0.09235328589115413, 0.0061598841303719155, 0.055844737667470216, 0.07300936662021183, 0.03698259960078905, 0.020648595734289097, 0.038668789765647346, 0.03888783728583686, 0.024597309755101323, 0.03760889563108644, 0.02775904271871813, 0.012560587999741397, 0.03388767333460912, 0.01784367205184554, 0.0431311255200736, 0.019262397939699794, 0.04676186517181416, 0.04103894322930325, 0.03923522751598109, 0.016499716345401063, 0.05208196276197991, 0.03441591777147786, 0.02711287053722528, 0.009967652337265112, 0.062487355823959076, 0.0349561553148012, 0.020505959738887126, 0.005580892592983982, 0.06682755801105691, 0.022751593271330483, 0.017319664081198075, 0.03326518093085578, 0.0332810772552846, 0.02612260421888242, 0.03721395049304251, 0.05367601170174537, 0.046402661865877534, 0.03778666250347611, 0.0566741848935283, 0.049652023796713164, 0.030225922443693688, 0.0647436686220669, 0.03258418622276476, 0.0065501120820220925, 0.07523992354230535, 0.041055019584394274, 0.06507599756361977, 0.04260465457674958, 0.006453636714497642, 0.01875787158496678, 0.04125082399696112, 0.020998431700131586, 0.01819875380474954, 0.03426799002373892, 0.037010795466842196, 0.027095589508873322, 0.0284088691396098, 0.04224086623458613, 0.05489543981609806, 0.027563309169284282, 0.05726928965398862, 0.09907859557818982, 0.027861815328980168, 0.05169704571486481, 0.05520894980779099, 0.04380289652955629, 0.0448229004658999, 0.019597101753817934, 0.09514777545606899, 0.07186354423362402, 0.03242820306050201, 0.022816892690776337, 0.0711147009485191, 0.04522058053783352, 0.04457256974532239, 0.031990255492048404, 0.05672778806559021, 0.015856437103432274, 0.02292478468359238, 0.08515839495005147, 0.020768216533225872, 0.0673296980019058, 0.08421805266651415, 0.04682637743591782, 0.04243399316985761, 0.035932580339572126, 0.010928870516739065, 0.035215284555189075, 0.03763506136414024, 0.026089480492256345, 0.009666082783482008, 0.02551786590277428, 0.05536964824122768, 0.013645966049103488, 0.05488823092873058, 0.053038795088087363, 0.0855660992824743, 0.030768042648090955, 0.04391216365019641, 0.042813478653589566, 0.08694157184612367, 0.04170806740500754, 0.044573726538088054, 0.036960080446254824, 0.030180451294948018, 0.05832407015165495, 0.04273696945259168, 0.01701944379977161, 0.02958055848496095, 0.15125204839052694, 0.021733719059416366, 0.030010092492786147, 0.018264673755414063, 0.07489176722423685, 0.048643128135271614, 0.05197656821579703, 0.03147388924844563, 0.041420907007470247, 0.028696219143908352, 0.02747044016066338, 0.03697205823095095, 0.055906740993621855, 0.04360045779556517, 0.06459038975017686, 0.030231091621962768, 0.06510936835360143, 0.026776462177475615, 0.012156905628921045, 0.0357374960496541, 0.05704998549434447, 0.013275484971311546, 0.07711775826230165, 0.02694731893678827, 0.03469291984313919, 0.07107456560216605, 0.045762028500077226, 0.03865724482062844, 0.010933223811368789, 0.02148055764395864, 0.04516286730405785, 0.025855124620119893, 0.019931537437162573, 0.05473910808382977, 0.03824120545158944, 0.034170440217900666, 0.10202601161454955, 0.02208627655260986, 0.048722667214010036, 0.029198272949865753, 0.08471372687528211, 0.19581006629572761, 0.12773550866592315, 0.13017840983886875, 0.10204433643769834, 0.1298504169549673, 0.2323826288263644, 0.12963819527818313, 0.08161746761611394, 0.17379456860644205, 0.14169464188237346, 0.09074945783903522, 0.2115536634359629, 0.059948613221246394, 0.18403794556375475, 0.1350207749994532, 0.10909668139873013, 0.15701520527082105, 0.1344737116127245, 0.16776668238303355, 0.16244384219809888, 0.13714132169562002, 0.07780175986549548, 0.1314624038434798, 0.21820272439189498, 0.15477773823565052, 0.17431720911014467, 0.18744388054455483, 0.10964486327382827, 0.24841504111405344, 0.15874228920907746, 0.08874103577146608, 0.13151527923201362, 0.136125611682092, 0.10525340980459606, 0.10718738344768364, 0.09728306168389898, 0.13288159704496785, 0.12126057949518004, 0.18393198028206828, 0.056667711450568134, 0.15004676225925648, 0.04812914442511336, 0.16139819346848996, 0.12151623069639168, 0.06739352844775685, 0.07068705534742725, 0.10058847060727497, 0.126749231750446, 0.11380541784268235, 0.16932646804038556, 0.14522253806071897, 0.16661817868871076, 0.11603664892214922, 0.09747666742412314, 0.10702735534118069, 0.1819937471901217, 0.12286007915052677, 0.18819915130734446, 0.0910677214062983, 0.1503483710750457, 0.1491602453132791, 0.17831105528579605, 0.09986410383135082, 0.11887068394571544, 0.17385823051294974, 0.12278102653762027, 0.2077194086966976, 0.20944093083662374, 0.1521429167159142, 0.07030273201845347, 0.2001926714494344, 0.22273140719100354, 0.12225883036491372, 0.19780411655383726, 0.07507875396479523, 0.11283370425864575, 0.1483180695363591, 0.14327871252692517, 0.103537694611136, 0.14711684367108732, 0.09398001231132977, 0.09270727979920565, 0.15850305527208314, 0.1662342920298538, 0.19775303381104625, 0.16345612013772612, 0.19076556117544252, 0.19568056679300724, 0.1065781367041411, 0.13316396173209916, 0.15798770792541966, 0.22621837895243402, 0.09669697377830745, 0.17245454293104912, 0.1552367627981209, 0.1925397135557667, 0.1475491164432418, 0.15077710452099002, 0.16844588061494215, 0.18311441124927613, 0.10607260294378766, 0.1797897888407592, 0.12808008735338527, 0.12917982955132762, 0.1127616077240917, 0.19026948860095394, 0.12382466811686756, 0.18817284384802466, 0.13740255767779966, 0.1387082932577018, 0.1708286592075902, 0.3453354597572358, 0.13519945734691236, 0.13323330801100502, 0.13073889508603082, 0.12454614674131717, 0.18033686754924638, 0.1135138294569427, 0.08092642566489597, 0.14318908023978436, 0.17817473760054958, 0.1655142306680641, 0.19140446318253396, 0.20407276889008863, 0.1649230865821723, 0.2148112684728638, 0.17825893066342802, 0.14478606712673942, 0.1869465669076289, 0.15686414805391144, 0.17221835802399343, 0.1490557968856827, 0.16669668737919102, 0.11259538196628133, 0.148138758996802, 0.12723182117746723, 0.11631837775630337, 0.09884957359322617, 0.17934001862041413, 0.12041257378915626, 0.14904363140944513, 0.12269573796901012, 0.27219698433914497, 0.21727851592004302, 0.10224272256657001, 0.07856564145655402, 0.10241349888665062, 0.12821498011509258, 0.17109326597663665, 0.1651966259364159, 0.09847537028573214, 0.2129398076043975, 0.14661622053432852, 0.0938293764427785, 0.24685461194284503, 0.19743895308384973, 0.10653129808845059, 0.1435946778304154, 0.06747687115303933, 0.11816461134942309, 0.1546614001234693, 0.12268991570078558, 0.26968363372068255, 0.18444732762873176, 0.21352655434560394, 0.07885398929037395, 0.265677698677586, 0.12131801310686335, 0.24317162892510816, 0.07584698693526369, 0.14574116426369838, 0.25717522588468367, 0.06755854378664686, 0.14300646020039437, 0.2894999074839777], [0.061927985234726826, 0.052304545777939984, 0.029842974242543983, 0.057075243413208, 0.021851145016450076, 0.01899809569060322, 0.018069357723898945, 0.03750041375056871, 0.028181459769726764, 0.07615336081794194, 0.05360770730241653, 0.0654426472441804, 0.02391209964820695, 0.05165956486316939, 0.08342422469849549, 0.10476807012192665, 0.035573154868137453, 0.09710228791640652, 0.029840371458821242, 0.03054979185934269, 0.05122892768873323, 0.011044855270865224, 0.04562031755584382, 0.0178061701327322, 0.018627837735919223, 0.04242082411843923, 0.029985096959036686, 0.04470697221075816, 0.030667834517155445, 0.0307177777041591, 0.01769555086690572, 0.011833776445728878, 0.028820695025065256, 0.014192496047114894, 0.032932196984127644, 0.05802923738355598, 0.022248949577671387, 0.03951741983332942, 0.039590715295484954, 0.018732456618078777, 0.07806521750265553, 0.06194689228469807, 0.04338112299240405, 0.07337394786337692, 0.10959301444311297, 0.07918030444172122, 0.052481205653279066, 0.04716616424341356, 0.0449156430700133, 0.096387880283498, 0.02526494388979289, 0.016244896349587267, 0.012994500200053858, 0.029606435019823334, 0.046989243898180225, 0.021817797209106145, 0.0005681457673011709, 0.04057763955525814, 0.026742754308807275, 0.007181900962736579, 0.05453848880865882, 0.05427322320399746, 0.03192102987199061, 0.014447027802347176, 0.008042799928526004, 0.05459854244104317, 0.043983651144850644, 0.07579274024934539, 0.05457980776085489, 0.020422465731239608, 0.026342980901620565, 0.03154799293336128, 0.04690796196941407, 0.049355317943639336, 0.00375458805900698, 0.07658463001491563, 0.04476903299350412, 0.04817971388899511, 0.04156363684864294, 0.018242225464012836, 0.024860916779406612, 0.09919280396594156, 0.04363661714559121, 0.011157919314780064, 0.048290030550091505, 0.017143691769771038, 0.052941953913579066, 0.05942665070535676, 0.03315895900971467, 0.030882365949031328, 0.04616595218859373, 0.04244525849278416, 0.06542092099064781, 0.059216171878600316, 0.01329061616542599, 0.01778267996175395, 0.024991590311870943, 0.14293703731269608, 0.03501866425898287, 0.04572458978321764, 0.013291062411641883, 0.052451795537865935, 0.03922370938403953, 0.11816173851970704, 0.046765350871869636, 0.016280289611689026, 0.012104496596411113, 0.037074691030166806, 0.08755264187892599, 0.014801766730905061, 0.04133225531287251, 0.05164260367652582, 0.020262292068031047, 0.07386678754682503, 0.036234392168661284, 0.08349445963939352, 0.06209369388318831, 0.059461982680424574, 0.038232035379135804, 0.014540538409604661, 0.016049346661255244, 0.08144258506475918, 0.052345654055956876, 0.02091269688530555, 0.056985189777708826, 0.08638224339172726, 0.04172539248341515, 0.025209287602093913, 0.055953954992395256, 0.027698437503028302, 0.0451491313475755, 0.03258731952237506, 0.03320976213041333, 0.030951076374960043, 0.028523380132091623, 0.017218854571242007, 0.04048780425481739, 0.0827242271794427, 0.005949234370247371, 0.028061005850172335, 0.010116108685671803, 0.02091633771816569, 0.043977893994099675, 0.046070149063222834, 0.042668676544581695, 0.03330166586824963, 0.021593320040753292, 0.046107074501173156, 0.03070903089528363, 0.021079826626866575, 0.009920030396672027, 0.0374191050087252, 0.0419405980726644, 0.06573130151317005, 0.021086321137244665, 0.10276869555274326, 0.04078960459258768, 0.026251866234346267, 0.057005253620445735, 0.07724773273953507, 0.03571347536278829, 0.0657253336882399, 0.08349081306087394, 0.07966266404236517, 0.04784071232162176, 0.0380802120743019, 0.041041448336815646, 0.02868438308547822, 0.02280201143284719, 0.050163992695630565, 0.012516590612640065, 0.06320540620494755, 0.029671360971406106, 0.09075183271160049, 0.03611451473026987, 0.10833048622214025, 0.03548705041588795, 0.03505225721446257, 0.010213976417998634, 0.04795342683792115, 0.03027528340387489, 0.012877755103662852, 0.038918358228740194, 0.04332954995334149, 0.013741044263776033, 0.018389682067678343, 0.07852197444487004, 0.016930060491206187, 0.05643552552247721, 0.008855759984843673, 0.027607138974652178, 0.013958729105070235, 0.0362160864977106, 0.07022288267410572, 0.011226150935756104, 0.034753800850481756, 0.09814199946460225, 0.01781223563387269, 0.02668338632511516, 0.027292876301573652, 0.03842148509237074, 0.09816688966126212, 0.02506126600858425, 0.03213959475678783, 0.0067910989239481434, 0.04825793529650377, 0.018366046339994477, 0.016578439540500124, 0.020903971143847993, 0.04496765660963232, 0.019271435861986493, 0.035522198529853936, 0.0214693650993849, 0.016476798825146213, 0.058137217476483316, 0.07019668246709532, 0.05673404317349196, 0.06614117387441859, 0.0866116407597738, 0.021342119810381727, 0.1251744154480196, 0.1228069662747364, 0.09801680537601633, 0.06778112297216732, 0.017473358555787036, 0.01767916233098555, 0.08768215670340485, 0.07240080169492191, 0.0023446056283935304, 0.06810821953319735, 0.05426790655380296, 0.05650057404812786, 0.02893316439322887, 0.04949873343350426, 0.0464547903186852, 0.014447682807522436, 0.013418274184298373, 0.03134030075142941, 0.014512717926634416, 0.046160011176740935, 0.05301572051980803, 0.03401037763744112, 0.033312992478210124, 0.0285863563899071, 0.05263281062305455, 0.016828582569536184, 0.01062698207885748, 0.03883236102880009, 0.004060887966320039, 0.059460347082706234, 0.0992747447303226, 0.05233762928495004, 0.027591947451113697, 0.06657297167206003, 0.009689710850286628, 0.037086304923098896, 0.12678284768856343, 0.04488799112638639, 0.04556079252412723, 0.026507251220004215, 0.08045756453347784, 0.05576388474794165, 0.031036002967025966, 0.05551222486481552, 0.05447937363398172, 0.06148327119468201, 0.03807402591431334, 0.015431975555275718, 0.02445406280457974, 0.020099996341272228, 0.029308061010294387, 0.015980141151005465, 0.07841545757987807, 0.020322975807733113, 0.037262689006785234, 0.03206375588272368, 0.008932932809505974, 0.06613752729589902, 0.04800784589362241, 0.059272598084663196, 0.06381001428610857, 0.024487274631317106, 0.022304584797952446, 0.03165039399098004, 0.03525717424288873, 0.03281935989376038, 0.02541345386435428, 0.027967456938518633, 0.02629946327708181, 0.010944461363608078, 0.015045191168845182, 0.042313353473981546, 0.005491674950932183, 0.03778301209451691, 0.048108839264680306, 0.022445250032169205, 0.05012821638956667, 0.020216267420760086, 0.03825393400245136, 0.011108504728444163, 0.052417980416888194, 0.10096949209729511, 0.01042011822949374, 0.06234875902713788, 0.02192747035634614, 0.04669149616552938, 0.03871605739057545, 0.02476503704524329, 0.04691669154131124, 0.027397995056103797, 0.06759523173734065, 0.04577606706128967, 0.0803084378581374, 0.052410449772592516, 0.06817449379952685, 0.08512861711243469, 0.038486050982629104, 0.012923449375516465, 0.04811833492450176, 0.056168003788878845, 0.014171783902472066, 0.035769522355328646, 0.011467149747805971, 0.02424201158235871, 0.048671925380345316, 0.03360295675755028, 0.07780504638269063, 0.03427513379363283, 0.045700557605032964, 0.017721678295563308, 0.029869944367918278, 0.02106556973059572, 0.028830993161987395, 0.0341515293374898, 0.0853516559507097, 0.017110211812260172, 0.008834066290047862, 0.048635486408226916, 0.05905452349613752, 0.08759363524375424, 0.04803177848037693, 0.033969633251188264, 0.04127832655344279, 0.032376162707805634, 0.025041389857388796, 0.06304542789415968, 0.02901338337500009, 0.06815646008978929, 0.028252430155032107, 0.03882538962868914, 0.03059565562814955, 0.08090482198543127, 0.1701837510711724, 0.1577947456990519, 0.09601163918212538, 0.1740284246062079, 0.14248539783781575, 0.15656932677713134, 0.0863727285797077, 0.19314847766391693, 0.2004298829143086, 0.1684183474149435, 0.325983036910334, 0.17340510482749633, 0.09872549799300971, 0.13026972751944296, 0.18885850786201416, 0.1839999782462274, 0.08028871109408718, 0.15698131354105088, 0.13866041276243427, 0.2386774200825922, 0.1739038587097199, 0.10433506956624408, 0.13006470706914702, 0.12966709211468697, 0.07018571974889887, 0.22298282192599392, 0.12671772255412034, 0.14118991251434052, 0.16100162039360694, 0.19460652684492452, 0.11152029247774232, 0.14393482086879594, 0.08575919174378918, 0.1051700517775551, 0.07957970438104484, 0.11041933986087961, 0.06917302046091327, 0.12822948982037846, 0.09488067124038936, 0.09380881464289081, 0.30543107359159377, 0.17345727541513983, 0.16227416904462924, 0.11806789274898269, 0.40072046040046605, 0.2529622938844466, 0.15633625218704825, 0.1811238543521012, 0.19221256336858197, 0.12779823594516324, 0.17421426221487984, 0.1939678240206934, 0.13334118851250218, 0.16947835263225342, 0.1419093610057908, 0.16292721303480287, 0.14254354391126864, 0.33404451885050346, 0.09992909106996753, 0.09193145489740757, 0.18698952911842256, 0.10813601480256166, 0.10806705156761794, 0.16504111008778696, 0.08729579558055248, 0.1405388450310115, 0.12493328161297307, 0.096002729579566, 0.18649578545122378, 0.15592158411539372, 0.12901634638828616, 0.08824923796759498, 0.08195623935711, 0.1515863231954075, 0.22356134088289356, 0.16509504267765632, 0.14971441799594512, 0.13499652065577047, 0.09811259701006836, 0.14758631767284486, 0.249316803209724, 0.18466365553679007, 0.18250264407646272, 0.10569328216895943, 0.18963925870916537, 0.23704431981088656, 0.2197574998342222, 0.11292680692408355, 0.1004855313728894, 0.1852300396609691, 0.18970282868512217, 0.15275538868961797, 0.11473989189271966, 0.13955759365231762, 0.23705852308100273, 0.09762345753129452, 0.16523755035333096, 0.18720345151039863, 0.10688133132193359, 0.09748601369679936, 0.1445154542283666, 0.1489114352772313, 0.15975309625989007, 0.28666522894655505, 0.20269189540657306, 0.15908142101139794, 0.12589384095683215, 0.13750210314268066, 0.20058464799677173, 0.1503650564700365, 0.11470894960145797, 0.08666172758826325, 0.12086121786025264, 0.17834885406398004, 0.10690136452115352, 0.12323121044544444, 0.13599088745972804, 0.18195225586814268, 0.18791272635421447, 0.1634118402557027, 0.12759162969286406, 0.27961813934868385, 0.1688959725922154, 0.11166891353505273, 0.1843452693954591, 0.20267954606923366, 0.12049000995654253, 0.10445460226506957, 0.17735421146836974, 0.17414652472061498, 0.4788768730096279, 0.14643983645064218, 0.16306405165983787, 0.12928291434241881, 0.12988184188162127, 0.08484037653092416, 0.12328864405712775, 0.2608629280040341, 0.1169690928391872, 0.22778985511151054, 0.14157557649718178, 0.08605117849524944, 0.12909283260664633, 0.13036964070652762, 0.1342679097527458, 0.12650717860989033, 0.12697661430725168, 0.11074656665685678, 0.1353426391799604, 0.22499861375939464, 0.19805373864308481, 0.09715956064962572, 0.18544409994877156, 0.12084325309842826, 0.15995361211319126, 0.1257457868045857, 0.11650592374104647, 0.07533715542165503, 0.16462016009515332, 0.16015043542269738, 0.13396931932337824, 0.14327993826760402, 0.30580127792012307, 0.13444011099636555, 0.17884607577035505, 0.11816134781486566, 0.12187706576960704, 0.07764309539549774, 0.12340040862440102, 0.12270110058448008, 0.1061961729259741, 0.18856989189742074, 0.11195742990821601, 0.20995981750949738, 0.1324854529793224, 0.2846491613215016], [0.02869596825011315, 0.023280996416184693, 0.021618704364124327, 0.08926179169887498, 0.09951595517416155, 0.0643363626553647, 0.05536219803616405, 0.06593746343447317, 0.05982814589515329, 0.020359303697102496, 0.0639762170612812, 0.08823808372741745, 0.04437883760059073, 0.0011140767803167805, 0.03554500496735977, 0.08765959541403479, 0.04436573366664591, 0.046311493572448535, 0.08237932673505238, 0.07702319236892848, 0.08662134709377443, 0.008311673807310722, 0.058409098250370835, 0.08695493241952312, 0.04836341411235833, 0.04948033966244229, 0.04901939604972159, 0.0276701056563686, 0.008851286031365877, 0.021164839403823982, 0.03313951952863605, 0.1203758551949455, 0.03863820370527045, 0.0026570986383669683, 0.04232624290330757, 0.024330209369861314, 0.04057619547952087, 0.05674939557549454, 0.05946908431548265, 0.01651617574445423, 0.11642773680749441, 0.008723926786783963, 0.02830208988950378, 0.01908589128194557, 0.02555215599826507, 0.03937566675426018, 0.054861988586884354, 0.03929899667479819, 0.03065254914784624, 0.016993203373145194, 0.024948492120470733, 0.02571510289975953, 0.02799145272752691, 0.018169140676036477, 0.023008809207127463, 0.037043691282310796, 0.019427648850626523, 0.04484019490079053, 0.008729798850723574, 0.032049449190737746, 0.042316084577431606, 0.026852059733843612, 0.07407410626089381, 0.010433996869851987, 0.07794433648908332, 0.036911954802851525, 0.018244031516294328, 0.03186884204736881, 0.021014494648683938, 0.024790044070311615, 0.020770566507933602, 0.05259441812672923, 0.08579027193087725, 0.04851561663071475, 0.020661969714227225, 0.03640057962207544, 0.032045281672429655, 0.029288475972510157, 0.04472652660502542, 0.09715299527611464, 0.06353821395145309, 0.04275165918853976, 0.017648871214459502, 0.02810472840323083, 0.049143494632575786, 0.02960180976398049, 0.013272505846896, 0.05793850192980421, 0.04382767947390676, 0.059196881784666935, 0.01533083854273202, 0.03759918929708581, 0.016230417287818367, 0.04167150968926088, 0.02926308973391931, 0.010956982113120538, 0.034999033255923184, 0.05794674120542984, 0.02100556780914626, 0.06927664151355144, 0.032303261780931104, 0.019574733901648753, 0.04849007525931924, 0.021361995961577184, 0.006622109025145971, 0.03811241841063865, 0.02818027424866394, 0.046259790298438845, 0.016145927365869284, 0.0366490219359196, 0.010077976659240742, 0.05005690126469539, 0.07495723709824585, 0.06344861996870849, 0.013199724621259639, 0.021311857422152837, 0.04579067252756608, 0.02033962672876735, 0.06002245260582817, 0.01540495084613682, 0.05688571326074101, 0.052801863245305516, 0.05327811712519296, 0.01641643301193272, 0.022353304159497062, 0.1099637626940685, 0.015538342075512536, 0.012443601585654242, 0.030302194157435052, 0.03769774267810487, 0.0239798141598341, 0.07703592475023001, 0.08810838504183678, 0.054656657870979085, 0.060042485805048104, 0.08978809410285565, 0.04971218851184653, 0.03880896470359257, 0.09283065059853178, 0.021320548689653798, 0.036541501495746836, 0.044294770942219806, 0.05049061811258716, 0.026157635504439957, 0.009185408576271467, 0.07038274224126531, 0.05608257349400271, 0.03961473598235077, 0.060719090829332995, 0.08904015480150139, 0.047466474540171125, 0.03710338102293111, 0.030759527580812577, 0.02554567872486528, 0.031345376083927776, 0.05032894291704701, 0.013454837645704468, 0.01932862241031422, 0.014332840482013361, 0.05709660194453694, 0.036928119258053844, 0.005929166218265892, 0.026720302186966426, 0.1337232978473748, 0.019044321435954303, 0.04938971529143953, 0.04019980499100301, 0.033840869192875205, 0.014826195359590554, 0.019655893256347028, 0.06618288736189566, 0.060306146455508094, 0.021771634666008816, 0.06160653857213836, 0.022682856032324415, 0.01061885292837096, 0.08347071857462007, 0.019152381968113686, 0.04002985221544101, 0.025887725491737647, 0.09436443523173371, 0.07762953563923798, 0.06070994373951709, 0.010800346818512246, 0.014562327865391009, 0.04939939864280243, 0.017509468110097993, 0.03816392633222765, 0.0173232302204856, 0.05735120360529231, 0.015504660062311638, 0.09763792127130494, 0.04920742466985699, 0.05198877965731006, 0.02086078293711668, 0.033529328047147686, 0.05431133607823042, 0.06402892008003208, 0.04743845487434057, 0.02160954003733012, 0.04453790043630908, 0.026833445712503408, 0.03292773452196871, 0.04143165139060828, 0.024523276933318666, 0.03150563976246744, 0.08336106074913856, 0.08501788676385919, 0.04045396615120192, 0.006435173037912577, 0.06151451992111341, 0.049526619033948074, 0.030427545294045445, 0.05848943406055051, 0.05137558756095748, 0.027232680942923315, 0.028639471180917277, 0.10471852721586343, 0.02490352275931547, 0.04887608015128682, 0.03317841764299139, 0.024196885173178972, 0.02411209839215923, 0.03941048928085835, 0.005480866407930491, 0.04492325798398064, 0.06547096185386181, 0.0567799931271903, 0.031859463215955806, 0.01644940543619375, 0.06600271880386338, 0.01591151690996823, 0.01998656553276364, 0.034550921615934184, 0.07506565386129004, 0.026570081921114076, 0.02361339622087056, 0.03440225076290869, 0.025279708319313587, 0.04873695858423749, 0.05223724495379194, 0.014466693279363457, 0.03636349330566103, 0.02428376528945181, 0.03343258646406955, 0.018360429000289693, 0.0306873697592246, 0.027599434045353727, 0.03448239122066767, 0.027680710228460453, 0.051831743124151425, 0.030983343998330738, 0.03910162178198657, 0.041809428498269095, 0.04257260911887692, 0.08174966374832777, 0.057280754159775474, 0.008385573521316534, 0.015424849022360099, 0.04692676559751553, 0.01604195774322556, 0.028966690316015196, 0.0957323388466912, 0.04779264413481278, 0.04614302700745963, 0.03300098784928841, 0.022699543342535055, 0.05679077581472455, 0.027751598259313937, 0.033481501178034855, 0.0488458120173985, 0.026570080005894267, 0.015867939913615344, 0.028047128167423992, 0.05480273168594126, 0.08572945987144787, 0.05291916662827135, 0.05235885375089223, 0.012688540004854722, 0.01855113892816007, 0.05720617166990715, 0.04218865734254641, 0.02686838123707041, 0.01104969407371696, 0.024477085661924174, 0.018650381788310987, 0.04555276775312039, 0.08588899768167928, 0.034744278377582954, 0.012681049580175071, 0.027630575519475727, 0.032672937508792646, 0.07047221364994204, 0.010937946743421979, 0.04702125488209629, 0.025682260710445624, 0.03145891989040519, 0.05348706377610084, 0.0427608484131915, 0.031363155069430514, 0.034123758650234634, 0.04605672337234982, 0.017542645462878773, 0.02224362909703726, 0.028453702520158504, 0.0427016796123597, 0.04585696977653331, 0.07194188438476094, 0.05872487586231963, 0.017298901183230263, 0.05554297180365651, 0.052787817023213834, 0.04440083198489682, 0.06496840051465458, 0.06106753826081272, 0.026051333144066796, 0.06276343092923203, 0.06039503563736236, 0.019236666961543022, 0.0254258778952663, 0.02907571228851955, 0.006307298599201585, 0.020453702966352145, 0.037055623101731466, 0.03920583655276606, 0.032699164528880394, 0.059901816740391724, 0.048570204225759354, 0.020705973804597894, 0.021508234485443083, 0.030393873814553506, 0.015339199434815636, 0.00998427165717247, 0.025442034689589374, 0.020804215004787813, 0.06278859308710502, 0.08031702570376859, 0.02214114951540626, 0.05995412905430121, 0.09837475995863638, 0.08133621375647285, 0.03121534989575946, 0.07172878170686384, 0.06885208324679444, 0.016016394346802226, 0.06004421716375698, 0.046851485967636115, 0.05124272876268914, 0.026834998955769886, 0.03738563462731339, 0.059239656303919135, 0.022573544861628644, 0.08711906675730022, 0.12476959160619205, 0.10094876941894332, 0.20827534338158948, 0.2557933411651081, 0.19631609801323185, 0.1620085663612812, 0.15189341720073454, 0.14064554575710528, 0.13659626545925296, 0.15078972964998216, 0.11525073464238837, 0.13794258837738346, 0.15821672224950406, 0.11640046407739002, 0.3532309457659722, 0.1375713728127941, 0.14382807417742668, 0.16030602788011875, 0.14350719058946257, 0.14778249746849462, 0.13915158237420744, 0.07839206125467055, 0.17007030877134494, 0.15248456128662632, 0.2026958024549869, 0.19371637864218605, 0.17729433403620798, 0.10255325630667711, 0.13791882432997227, 0.19979119541183596, 0.2198367133255928, 0.2490598726416788, 0.13429879841785278, 0.17636119297915892, 0.09823713992391864, 0.1588527437660002, 0.19204039276847917, 0.21574399584243376, 0.10355514609405111, 0.2373974403787044, 0.17283040098845961, 0.12372336831063994, 0.14758994892960595, 0.10130022757596548, 0.07087129183233747, 0.17044589103710267, 0.16901869987768514, 0.09090666674197682, 0.14579955548528703, 0.13205943148463004, 0.16774898575198266, 0.10307892285768064, 0.18206267978154844, 0.1793696355795668, 0.17430824588143057, 0.19783590920269492, 0.15605762600898743, 0.10601053450016246, 0.07478879734633431, 0.12262550302811208, 0.06480386015027761, 0.18794936067875356, 0.19913301863256963, 0.17591096310605928, 0.10543838173391358, 0.12344037543141073, 0.1326045949733065, 0.18600112247851588, 0.11511317589470457, 0.11316945761322014, 0.16627449632412003, 0.15075568470262712, 0.12959514113683857, 0.18767533102823844, 0.09505085767276826, 0.2773231237886414, 0.11860249954606257, 0.07504865437025025, 0.18967425360554652, 0.1330463519139636, 0.12073687412926268, 0.09997192304581405, 0.13130494213152316, 0.19330966256318555, 0.18274763899464763, 0.0907541769406488, 0.1616427287339203, 0.1857958262365672, 0.1388060307550815, 0.13346540200854504, 0.13677151573281135, 0.10808020529727783, 0.1499073649005544, 0.13042363458343093, 0.08914500925569765, 0.1696304057634646, 0.09076576019006391, 0.17288421100426107, 0.2967574873999242, 0.22484323580659207, 0.10817539172186967, 0.08353559856092738, 0.14279770124102795, 0.15029912694327294, 0.12874738823982979, 0.17725155568651615, 0.13938775195950462, 0.16185648258655302, 0.1419026347538156, 0.08096689042905647, 0.15153004637648984, 0.14910111864728315, 0.15369946948222576, 0.1102202642528761, 0.12598276844308262, 0.1803310606027803, 0.12432180555357088, 0.1501133965869104, 0.1386069398253195, 0.16509683532339914, 0.15885905633049627, 0.1264020253814036, 0.12599614433824055, 0.15262094025890674, 0.1837534817957109, 0.09606295175129369, 0.10843894128958065, 0.21522616637089562, 0.12421215538896861, 0.1415228696479913, 0.2544356495021813, 0.13002998796441864, 0.1262493134145775, 0.12253664448977479, 0.2916888045447488, 0.11292796371684921, 0.1608177899352966, 0.23753366613339996, 0.12364629986545733, 0.13370409968399233, 0.11691666178164944, 0.14310269616544247, 0.11941675141814256, 0.14137777259513257, 0.14225901885619088, 0.177376274800589, 0.12950909414118336, 0.26363892420645685, 0.1388189010322094, 0.17815828203193604, 0.10926558846427549, 0.15700572110231847, 0.1543972530071774, 0.12882038109725522, 0.1283802865673938, 0.06700280062373608, 0.11862864612691826, 0.07040649862779726, 0.1471790193670219, 0.20895362230798892, 0.08155346097004029, 0.1133765005356362, 0.23311859417346217, 0.15833482236391114, 0.144824325557678, 0.2238443031186058, 0.1161310156326621, 0.07235534969837436, 0.19832576114323833, 0.11077933223737825, 0.24003532625013785, 0.11853484632146936, 0.14428421824930177, 0.14828983153547012, 0.1370170775560602], [0.07179756108070574, 0.00860823123084922, 0.021770518092859178, 0.03723081974913517, 0.031885002672131506, 0.05549699886732044, 0.05196752071741128, 0.05538034282865063, 0.11667790281916819, 0.07052252264392954, 0.08591826224038679, 0.013337656836806527, 0.0320620053718167, 0.012781384115618084, 0.05057944983784711, 0.05545055095647132, 0.028327728937109633, 0.018485184503538955, 0.05881014910917129, 0.08919499649275696, 0.028549595660860502, 0.019222902276763515, 0.026678318653496045, 0.038668544617511576, 0.052825642614475185, 0.03851400936142572, 0.050726006288201585, 0.025377104907566984, 0.02636708968859767, 0.019825612375092123, 0.04804312041209591, 0.0474131892945978, 0.02418393637203882, 0.036308672053799514, 0.06884205515586561, 0.01718843130454902, 0.04070655300071643, 0.06438304039259111, 0.051939225259927974, 0.019380145653661703, 0.018744451639753197, 0.033736290530331677, 0.019933351150323308, 0.026650772046958728, 0.031638443019361265, 0.040434185760997, 0.017322205577886874, 0.04596142969544857, 0.013506690306859392, 0.03955549440316616, 0.027631360759598114, 0.04422511439770461, 0.03197598135879925, 0.0137526361316803, 0.051569656784375834, 0.020344792076596813, 0.030379561376908136, 0.016097150547730348, 0.06588649560487078, 0.033397001679986715, 0.015610078548742159, 0.02364813830823668, 0.057787689861030354, 0.04545540563882359, 0.03083704993309033, 0.032430731150652134, 0.0543184032393319, 0.028960657373611486, 0.014533250998224945, 0.017427510108738657, 0.01304360164795071, 0.04439788254638834, 0.06713092116819275, 0.05868123183327337, 0.05748926797100613, 0.03451455925260821, 0.0772731515368627, 0.04348044246134739, 0.02456016406687277, 0.007276278685763359, 0.0157994564412342, 0.03352709490084841, 0.06110267488345985, 0.03198814683503682, 0.07030762732028961, 0.05387173184464055, 0.030072233714764158, 0.06678661061150414, 0.0327375914991623, 0.01977995353480501, 0.033812022152086424, 0.01356477892371796, 0.015077767142605399, 0.034481870280879165, 0.043005322391587886, 0.017432439884531404, 0.10156863414111639, 0.06820734364972, 0.03659362611811488, 0.015226045375569694, 0.12335068951811522, 0.03708086569883651, 0.03049038174081474, 0.02369552850723267, 0.02633261190156543, 0.03535294672474265, 0.044917025858716625, 0.028863057772058155, 0.09195879657542513, 0.06278680810224145, 0.02123161162730427, 0.047540651003439585, 0.08396794028099507, 0.0005535019966285496, 0.05515262702359788, 0.09436564565065408, 0.00418042401678019, 0.01250114819530638, 0.045032785574515025, 0.02739623113865814, 0.05352290136919868, 0.023844097853608193, 0.01894737492435642, 0.05691602735990479, 0.06689356414661293, 0.046804681825902195, 0.02535384647818583, 0.07650744665654437, 0.05894159064477971, 0.024001379534902594, 0.07354170579703585, 0.08372580287076774, 0.02851795431436791, 0.04907527450291861, 0.04121620065322326, 0.08726000395273009, 0.0509995686250829, 0.043991990011906436, 0.06570150069291554, 0.023036560742184523, 0.05262030040725105, 0.027141675443178224, 0.014813641093731409, 0.02652337928603013, 0.04018642143496583, 0.014221727089475722, 0.06382261643246298, 0.008051164651049242, 0.05423893310850667, 0.04009806851465856, 0.03304503407449492, 0.06049769524965556, 0.04942117852248973, 0.012693542559000274, 0.06602991492517533, 0.07456146841568333, 0.021890154213554436, 0.02426773489963624, 0.0518527492550352, 0.04034568728398412, 0.017938657378357266, 0.031100873377234228, 0.030209068509359515, 0.02051328928510268, 0.018258064331847335, 0.03437588584699458, 0.020374658014324885, 0.0441500875768402, 0.05156062843818819, 0.013087671813404849, 0.036754925930572134, 0.024560089373300155, 0.045463664066647334, 0.02417582733136031, 0.03868999124895181, 0.011660264234148688, 0.0536447668057536, 0.007469844206371495, 0.029949719018693415, 0.06506486630607998, 0.02698859766936831, 0.021636397164735584, 0.010009009593857393, 0.05187567826660891, 0.03116263730090953, 0.08023340720683336, 0.0334425647592833, 0.02369796658205169, 0.027634210606676438, 0.04852425044162139, 0.030203154310584072, 0.0030925181166704505, 0.041060604365362276, 0.026292696805490602, 0.0791483202708825, 0.009254055799946431, 0.04372156863551467, 0.02256544922748881, 0.05945700693935637, 0.014595132707918604, 0.04343644220141634, 0.005963698110257786, 0.08709756266926566, 0.011996306786914507, 0.01958603178331208, 0.01589196921897031, 0.06968860529483327, 0.017644899048572107, 0.023827856789613445, 0.04690968949768332, 0.05507386552410261, 0.017892506326578798, 0.013331643046600925, 0.045218355052413485, 0.011728811866393494, 0.04001488285740057, 0.01046503683732402, 0.037640052426966934, 0.017223454929227312, 0.02028264702417918, 0.011546067337715819, 0.017759082538466302, 0.028498470783233646, 0.0983719177724373, 0.06464835196252793, 0.029663633059469924, 0.0705018995570079, 0.03361373944508453, 0.010125823638161585, 0.025086491368710998, 0.011563038100458441, 0.026269704591663137, 0.03960144052642488, 0.059603142041352496, 0.09604491038067688, 0.07213584252543027, 0.022450873117533424, 0.04768305525724446, 0.048034034609313936, 0.0464107096195221, 0.04401488837996318, 0.025308714323346655, 0.019658262383252866, 0.044474797773986094, 0.04398786079799456, 0.08942987905034135, 0.039761533750401395, 0.08256931654027394, 0.040625064228210724, 0.049354605481869755, 0.06263035379590527, 0.0340884419969253, 0.011046626849190123, 0.03951373495041363, 0.039861512054959615, 0.05632104517351236, 0.06635089044369037, 0.02767485923193876, 0.04502863337796542, 0.014144941139215184, 0.02427155384793878, 0.137306367678027, 0.07026374580398684, 0.09610449669942742, 0.054422334557579416, 0.018692648774313352, 0.03970718364261332, 0.050798344140451764, 0.026094486876841516, 0.024200878406484282, 0.020094855891300306, 0.01843719675596203, 0.029404233773088748, 0.10329102962127618, 0.013253723286212453, 0.020223822962913304, 0.052503732468692534, 0.01664911881239424, 0.014033236901365943, 0.03441841138767139, 0.021236470539964015, 0.04021017399105815, 0.07295385588921847, 0.0609339478485767, 0.046520057179394274, 0.09474190973466444, 0.032414823334904454, 0.011892907899774373, 0.029874613673816768, 0.0243589146843841, 0.021847835516617186, 0.07497700982757154, 0.022745106421831637, 0.02910616619872951, 0.02015651447788602, 0.05827555380341026, 0.0683688503059168, 0.053522177416110234, 0.024276797719780478, 0.04654146933687791, 0.042134969900812835, 0.08393633149323926, 0.024151657257349263, 0.009599240654478631, 0.020585701830925483, 0.036602148846272504, 0.07967002614731751, 0.05202772373694086, 0.03942404137623887, 0.044554991857899774, 0.08891611750568114, 0.03617304767812452, 0.04042256037674604, 0.033604665133621425, 0.02006662172085095, 0.008818066543749264, 0.06234424293882424, 0.08576193433855811, 0.09190106418945136, 0.07874967875860392, 0.030322688924629363, 0.03067882596364906, 0.025154278658690955, 0.023954265127559344, 0.031822030244755654, 0.04063888062392512, 0.010193781382704695, 0.08778772361937069, 0.018492582997667695, 0.009029929116818934, 0.046471207582902525, 0.04540831421411807, 0.03015745525068093, 0.059033207099644415, 0.013428301317617299, 0.07655184911263567, 0.0496017914115181, 0.004862456774008611, 0.0513997882784855, 0.05886838328273547, 0.04038157850323666, 0.01413408758854794, 0.004624211569241579, 0.033445751685048306, 0.03235262848677174, 0.010928781459017867, 0.010659851081248735, 0.01716043845179581, 0.054083513020868265, 0.0624655606225133, 0.014927677111700179, 0.05513152513172358, 0.133361091476775, 0.1604706908185636, 0.17333545211342075, 0.07969795005215753, 0.12524014579192286, 0.17057738236842618, 0.14680291616147564, 0.13708222567314102, 0.13282440092054107, 0.1361156218955594, 0.20304976571952144, 0.03882339013920676, 0.1312653047423209, 0.14689674661044153, 0.25821762640149365, 0.14856787548670847, 0.11007172746523736, 0.1724137870534774, 0.18295553993553887, 0.1551759813822085, 0.10594692621980945, 0.10932362728541899, 0.11450919983608109, 0.13337999852674623, 0.11233634465644438, 0.12772757199502763, 0.17408088630726262, 0.1385613575938248, 0.15121175216570978, 0.14096310452347802, 0.2079855016763172, 0.16529572707030082, 0.08611473314944776, 0.11027230460557247, 0.20547975065006366, 0.07933903785963213, 0.16701321958774523, 0.21433240223315456, 0.1672033932540686, 0.14563959632669726, 0.17558240331709388, 0.12328375641617084, 0.10254806989142973, 0.06872444533773008, 0.09848251022518643, 0.13046391548648958, 0.08598460545462948, 0.12993310848551412, 0.1445120527979828, 0.2237330058649663, 0.18713091830572776, 0.10003809005983415, 0.14225364091896242, 0.10004598842633348, 0.18957381947867333, 0.08759067048348727, 0.18030950288859107, 0.15897525654685113, 0.17616662196815017, 0.1261019640632214, 0.08918371201763231, 0.10643178326708656, 0.1786051717616858, 0.14269153677648114, 0.1977342340133844, 0.12409434638797276, 0.14037952938627812, 0.10824425536538325, 0.1605166714157789, 0.1803283486515284, 0.1423051986362665, 0.1970077988000647, 0.15799648729303192, 0.1877746007014667, 0.12019836028376896, 0.1718888789295189, 0.13875903892180613, 0.09194907491966602, 0.11987595218083552, 0.08786433241179875, 0.12043854416978937, 0.2321497840626586, 0.22843197468788395, 0.12525076377055339, 0.22466171893381306, 0.18161134674183785, 0.21983441506181994, 0.1566729478297695, 0.1709174334762558, 0.07295916487853374, 0.14307465734741381, 0.08482813444589415, 0.12826849135660356, 0.12975707680227297, 0.1270982460869897, 0.18982580111872768, 0.20854185004868817, 0.2185150890821411, 0.18885685311209774, 0.08012235510132967, 0.32287014588232965, 0.16423916924865017, 0.132185636809276, 0.1147557039474768, 0.08814826757917482, 0.10493263346894134, 0.20351458190669938, 0.09685323273222293, 0.16978288790391338, 0.21351374535550996, 0.08979334180513698, 0.11439326775049972, 0.18520656672696914, 0.10833521298463307, 0.171623123028586, 0.255483029590499, 0.06941792344854725, 0.11844131464679396, 0.1456508271756672, 0.20533397943983156, 0.18079175523692564, 0.14428702213110464, 0.10969059106202857, 0.147539341161328, 0.14381745619879616, 0.09988085051337559, 0.09756392483869869, 0.128239824346477, 0.15503952580113567, 0.09359892953427569, 0.2087531677417217, 0.16916722900444464, 0.10989282295228013, 0.2894787328137506, 0.29926124659757464, 0.192227992379377, 0.12388021715225712, 0.1447778853077081, 0.15158255404282003, 0.08878187591870947, 0.11336247346574262, 0.17561065663974132, 0.23382903347092293, 0.15562673219509665, 0.08838994533664758, 0.16560550238336288, 0.10929483770122451, 0.11495164625587002, 0.10743047080693707, 0.10166275570349348, 0.14368352870787346, 0.21897040577905796, 0.12057828626805737, 0.11951334744451508, 0.2625052672961066, 0.1638264623620818, 0.18854441181305917, 0.09484441995981241, 0.17191779108778124, 0.23398232766457144, 0.12480278619595113, 0.08516835409306711, 0.16880388882371689, 0.12469055431504404, 0.15931596649029564, 0.13285579520367807, 0.16200573183596134, 0.16162247336920232, 0.10663020003947521, 0.10081854979357413, 0.16184497594593034, 0.11820377376411231, 0.09677188185554358, 0.14012135775579562, 0.07068926934152842, 0.11664659280570285], [0.0470415523816501, 0.0649374965277891, 0.041984571519518094, 0.019472466909416744, 0.032307674447374965, 0.052065901728647376, 0.028350217448126887, 0.07384394280492299, 0.10947326723966869, 0.03903270834275792, 0.040636406159929694, 0.039485401188534115, 0.02446428816314907, 0.07625321271799265, 0.0148849246174758, 0.07137179239502839, 0.09381037746225634, 0.03743308611334332, 0.022471559406708808, 0.0441181417103977, 0.05945509171954567, 0.021166296886099924, 0.052307793990738934, 0.04461369717553739, 0.023429018009694356, 0.026931022331419013, 0.044512669330522905, 0.11903847252289135, 0.0328465675063912, 0.027835496378341512, 0.04942171478403672, 0.000562738084315037, 0.03149670526205051, 0.037679777916280494, 0.02922869813177855, 0.02618014508287513, 0.05735080523957169, 0.07314269656255361, 0.05005757925250838, 0.012380548719046338, 0.09877221403463234, 0.052143012308665825, 0.20345559313652978, 0.016775190071653456, 0.07008261197516996, 0.05395417822705162, 0.02788446663368133, 0.06047281271387493, 0.022240886502268336, 0.026585673725592996, 0.04081248763888594, 0.03174958322497626, 0.041892284737719644, 0.11051772087211571, 0.03825636250117133, 0.07282002032884667, 0.05302874018408118, 0.023404683226779587, 0.005301992538490243, 0.04778695976241462, 0.07197346252899978, 0.01727387117552421, 0.015858065997881275, 0.057752319581566326, 0.102217449325948, 0.05066202262476568, 0.09110188126684197, 0.04710945841525832, 0.026746963961951198, 0.062471781256458456, 0.020524698249515028, 0.08294106836641028, 0.05547710356392688, 0.0034788541022628067, 0.0410938257681987, 0.038773502493577625, 0.07396731360424912, 0.052131164758916826, 0.009480799630945249, 0.03196835303829322, 0.037458347862646464, 0.043877904198222586, 0.025547000226534666, 0.03713885472426492, 0.0287334356952699, 0.007618666840566984, 0.03978278502942093, 0.054052781403785756, 0.014111318497828419, 0.04496664920401189, 0.03585936914708826, 0.04818357880257311, 0.0632993592279813, 0.06389251429467432, 0.011144040674421818, 0.049672455361653725, 0.0716554670925102, 0.07045385052239703, 0.04492631850523814, 0.010888909455388786, 0.07342565113738661, 0.04950652837813382, 0.038716854122016704, 0.019234790046128537, 0.04851265187044779, 0.035387409190016414, 0.017515129499858426, 0.009853961058862267, 0.04377947339127141, 0.04528793881857588, 0.030405351726879037, 0.03077154941556435, 0.03303103381767869, 0.05062511250857384, 0.021333430458100575, 0.050912698084909114, 0.0215725782102034, 0.0339028112319929, 0.03367643608080764, 0.019880678775089405, 0.006386917638367103, 0.019172426658652483, 0.04611774227551876, 0.02618955072736548, 0.026776245757637006, 0.032210668563962944, 0.03937979596817205, 0.08399401025305833, 0.015478117030955132, 0.0415536777056273, 0.02730939890288057, 0.01666583676612185, 0.05299851035458907, 0.022397467213112022, 0.02511133176965579, 0.04249420768070606, 0.028886410047210036, 0.019773058743486484, 0.044419091690572045, 0.061953009496773445, 0.02630424175050951, 0.023825041416491714, 0.04434069025240118, 0.025120515248648105, 0.03191750012187949, 0.013032668615661323, 0.06774565310127313, 0.03481092419655573, 0.08543653849271998, 0.05012840025066849, 0.030169869705493894, 0.037172711980078495, 0.00594614512069271, 0.05100310795129307, 0.016058219874638225, 0.03242743697257773, 0.05018488391332569, 0.005275794246699662, 0.02935387689860598, 0.1032296659785413, 0.017929445171067794, 0.02112178909291904, 0.064679684958631, 0.008105742669994793, 0.029548032306915814, 0.05170103320251069, 0.025914458129855416, 0.011904615638477188, 0.022881759270544977, 0.08061203850252975, 0.02871005469182086, 0.04835705941302642, 0.03749727279007916, 0.043254163071152665, 0.027311300716152596, 0.037234550597326416, 0.048071825726618694, 0.03369294910601551, 0.03135662416987602, 0.04218829345078238, 0.020324203463631774, 0.0153454210263707, 0.016414626959651228, 0.08889569360161982, 0.02850306731077933, 0.07515858032650526, 0.04513067245903996, 0.031679185490394314, 0.09636117445845759, 0.018274016197650664, 0.022643525078291857, 0.08345310621324085, 0.07194147069728182, 0.051379544405086394, 0.030584271561594743, 0.026246693225637562, 0.06189776306611396, 0.017565649168025103, 0.05425018310967473, 0.0543522643255851, 0.03655050302885714, 0.053773929229787285, 0.03616382397951619, 0.124592901087336, 0.009174027382546376, 0.054447209432480805, 0.03449282150775675, 0.04860264421891301, 0.029944147644264084, 0.02394868226181115, 0.03976621454761874, 0.028053496273294575, 0.07092078111224598, 0.027363048040217934, 0.07601067694204469, 0.00444504227714553, 0.05050799298670985, 0.027786824897292162, 0.09242987170094445, 0.040531287405399546, 0.05405485367162093, 0.06275909104114098, 0.011586147142694363, 0.01845954354071329, 0.045211035082296985, 0.003939930822760348, 0.035038203331491644, 0.09191980270007927, 0.013951074929096767, 0.07096359010545478, 0.019759024012713663, 0.10973262630643384, 0.055337606613794645, 0.013534608466039984, 0.024152722119564013, 0.05557209463609804, 0.034501983919331146, 0.01624500743233629, 0.04011428659601558, 0.018274119619520444, 0.10491145113783498, 0.058074317827460274, 0.022434245179136916, 0.08232932417623459, 0.035693426841809865, 0.047422052931881724, 0.08485702362151877, 0.09016824225264211, 0.02700397305400862, 0.023989114467234864, 0.058645976466997984, 0.05181668949643931, 0.03151387903809307, 0.03896655282005668, 0.04761118854906771, 0.03367621774574922, 0.01565773400568193, 0.016263747858184, 0.05011063467170443, 0.009174076220651549, 0.016809524217199896, 0.014553801306793767, 0.023262012757421024, 0.08249030989264289, 0.03063307519281103, 0.04377575020395941, 0.035116516669551213, 0.0341558079385469, 0.032643967893935984, 0.0367892466695799, 0.0375179686553536, 0.060959489219972206, 0.027714747514936234, 0.023519755378665946, 0.06895570429943262, 0.04007551871660737, 0.06467156442663362, 0.0595593677773591, 0.010566813533284493, 0.02050907771673895, 0.01289538374441045, 0.019446789557414672, 0.011200147038776309, 0.018189196857894142, 0.009557208282903079, 0.009736047678386733, 0.04175736133249537, 0.014041852517684382, 0.02982206578787056, 0.03176117605049043, 0.03289563543794136, 0.04739665711719183, 0.058426319906908664, 0.023407056184125044, 0.019809913318303805, 0.031107036554585063, 0.021234997735929587, 0.010813580029794287, 0.03840361992197652, 0.030952294454759652, 0.019688769919617523, 0.006433924793400952, 0.02200337626310366, 0.013793990515442866, 0.052954797377629634, 0.016681445807579066, 0.051166012717951695, 0.012024222073265383, 0.007826426055192227, 0.025383639637561097, 0.017022621149437565, 0.014886934640667131, 0.04636379056459954, 0.05557515898779516, 0.0033777553941153234, 0.048251209044528585, 0.019228952456145518, 0.00666072560218914, 0.04889237484143627, 0.043735354387712096, 0.034181130974884, 0.08124317237806898, 0.14461971879486116, 0.016540883995232084, 0.02043574586540701, 0.0344192540843881, 0.10026829948108043, 0.014519176047836101, 0.03641439218735022, 0.07557741591646787, 0.036375762203768376, 0.05443191448707254, 0.01919500326978103, 0.019599501524240743, 0.08647732256400971, 0.04202159654889857, 0.057293666571739225, 0.01758053042595425, 0.03455602376150989, 0.009522796570954305, 0.04332448611216199, 0.02749909376425128, 0.04203525589658849, 0.039824149946892456, 0.0435942716355766, 0.029993675228568818, 0.02871180711794765, 0.036721769645209276, 0.0528314265783035, 0.035083693632435416, 0.02395919107291247, 0.021328519834505937, 0.14018885010192472, 0.15670031249042482, 0.1343487013852404, 0.17373561047978942, 0.1252811391567511, 0.134347521609837, 0.09913651948614467, 0.11756899331005351, 0.18372303746160001, 0.17056664181572778, 0.12305530133627116, 0.20726493469649748, 0.1475908529133566, 0.17488843491000516, 0.11130251666350711, 0.2088066100353195, 0.16908692766822156, 0.12074214481418172, 0.10214735994175558, 0.19295393729642515, 0.3284596765954649, 0.12150026542404968, 0.14860904505175931, 0.3117306758799861, 0.10708029967762771, 0.1583920644536134, 0.1579659510283701, 0.24228451443054985, 0.1391126804294125, 0.1395027724004561, 0.19674803370669966, 0.1477792186121787, 0.12056920812615465, 0.14571088846893082, 0.12877613185874878, 0.17104037526634433, 0.1415222108123764, 0.13254415063608077, 0.12224496417348424, 0.11837285702988026, 0.14795996939703343, 0.13658213879792921, 0.3278924650963276, 0.12386972940857373, 0.2489056131772457, 0.20443410192045475, 0.086558987536738, 0.12451328156936554, 0.12175276034301329, 0.2317567809575027, 0.1540443775874953, 0.16808428711468176, 0.19949992878302453, 0.1850896157444485, 0.07105824792937887, 0.1772999571215722, 0.14992604212414834, 0.10035993125770362, 0.09747449939529743, 0.14005250177316128, 0.09773047235343726, 0.16115575728397216, 0.08499910994883507, 0.0954860185963973, 0.1813268063650016, 0.16176991465110935, 0.1498025947160298, 0.17139003311674442, 0.09849070736597623, 0.14570088336063972, 0.11395603838947513, 0.222933761655323, 0.20498715611475132, 0.08585275406198156, 0.15304910679978712, 0.1283101435570467, 0.13665772103253873, 0.17966962028895656, 0.14153463675850822, 0.09901866451987336, 0.1373272359130844, 0.06099893508719341, 0.10926524372470957, 0.16470450637561662, 0.11956330403805741, 0.10064665498512407, 0.14068516782454907, 0.15675050657122366, 0.07997348123500425, 0.13198702085402705, 0.0936567921551966, 0.18178275125401636, 0.1779687059141936, 0.19239273192661424, 0.18655909495728631, 0.13553365554300048, 0.20397434191357708, 0.13827787441832406, 0.08522024888905787, 0.1357398864122168, 0.12651889209425257, 0.1929497391346001, 0.09274549226486876, 0.09781243610045603, 0.12470074328443698, 0.20337098638617224, 0.0900516743140836, 0.12948591232059464, 0.14369736425578594, 0.08622892621544101, 0.09518261713486525, 0.13626643396433324, 0.16953205539574548, 0.20488299880056612, 0.10714052951023464, 0.16037002686531315, 0.1451715319267204, 0.07399952760146511, 0.09023516003282801, 0.11371498116322103, 0.1347625880472122, 0.06374557096991809, 0.17970274593080246, 0.075166302492782, 0.07129232609464277, 0.13259049895549976, 0.22208758689943822, 0.12045052578492511, 0.1255789481764359, 0.10158817704406478, 0.10996646698444121, 0.12682815412840537, 0.13044712283918936, 0.1302601207768725, 0.08727232264655252, 0.1857624094813101, 0.1714008196347183, 0.1218457404343832, 0.10238430327585629, 0.2362396516987393, 0.12469115186362498, 0.10394840966910125, 0.15723669661148904, 0.16334830092326288, 0.1272148140255482, 0.1652024941699159, 0.21661955773109393, 0.18093513625283397, 0.14974506151291633, 0.15136884615546273, 0.18045377256649156, 0.09883124110919815, 0.13366887496123392, 0.10381813641757735, 0.11776483602701657, 0.14824951998889446, 0.19500913669265088, 0.11464558646924074, 0.1904750299910384, 0.1873444576537417, 0.19006034659762538, 0.131569717439913, 0.21111316287950163, 0.12242314856379263, 0.13794761391416674, 0.12036255590857999, 0.12574481387292186, 0.20071762553866834, 0.18855573459258004, 0.2563477283523929, 0.14717324306407284, 0.12741276348430303, 0.12886904300220553, 0.10504766157077206, 0.12348335296396287, 0.11407559407093834], [0.07671041399120324, 0.03391824407322753, 0.022261226136657982, 0.016972997804142295, 0.026416467885757168, 0.016899357602420836, 0.026364670765976754, 0.041377408535129605, 0.02859026726876055, 0.01945158526782067, 0.012017309087358657, 0.08124521017194757, 0.02842886211921371, 0.04633576706832936, 0.06651792059382124, 0.006532520788060802, 0.01392861801920639, 0.07447523755892631, 0.05380811207296868, 0.06424706744691057, 0.08078836129918214, 0.0588935531014877, 0.05197817316999839, 0.08458733768953432, 0.005540735700408058, 0.051478645538971315, 0.045529785115391984, 0.057412475317476265, 0.09609617698456972, 0.032530238311136925, 0.049689259500272816, 0.1595425752982978, 0.03115851383265709, 0.02536040610603748, 0.08485012883020025, 0.050213570075650374, 0.013270004569823224, 0.019165118179854848, 0.07583151195919322, 0.016141501292886756, 0.013072848012070022, 0.040765978441002874, 0.054945882875472314, 0.02329702680600026, 0.04244619312005178, 0.03869262659141133, 0.02241327926786917, 0.05494566837085351, 0.030947140598249052, 0.03546372303859361, 0.0927843022791128, 0.04467140657887344, 0.1079627946620026, 0.06370810543998115, 0.022763527005970962, 0.02616343479002676, 0.02313879326045994, 0.05959374214252157, 0.037599331023351806, 0.053488530834475835, 0.042465824123111465, 0.03230208583596734, 0.007379401781250753, 0.03985851665117568, 0.01668331506211431, 0.06992405475748163, 0.050576898765059254, 0.029971023923867655, 0.04562157777047927, 0.02080284753784297, 0.05289758593144436, 0.07982504403879566, 0.045722429415271174, 0.05916818413102339, 0.01091284970302255, 0.05078291129921714, 0.045902031068239486, 0.05097554410777746, 0.04149069378693258, 0.07721986246084975, 0.03278466377166971, 0.05059672512053963, 0.02886531198577535, 0.028877094418050784, 0.11547227960921104, 0.03485222016611407, 0.06637493028275429, 0.03998361497877106, 0.023538195115003376, 0.024567380615119493, 0.04000852815806866, 0.037527468145614674, 0.056327261977017894, 0.11894762215595092, 0.052822961306740204, 0.0431088974789506, 0.014993216891232279, 0.021998963596659805, 0.02645667984090265, 0.015450305166474033, 0.01741161186909003, 0.05906694561182972, 0.025825490423988913, 0.11824757101074343, 0.005543838356501393, 0.031253029930315195, 0.09824846270343951, 0.07210057183739639, 0.04532317886309278, 0.05597774585288379, 0.013450832921080293, 0.060320602534639264, 0.019816319728570602, 0.13058097372131963, 0.027948331553488973, 0.048778898067652225, 0.05541613062603339, 0.08446231214029175, 0.03076376979269328, 0.06697291553380989, 0.010346149567574745, 0.060863414133388194, 0.04173960724485017, 0.0199653142537441, 0.040634410500886946, 0.1154227520249063, 0.0706267872104241, 0.011320643093166573, 0.06101391593655271, 0.05145621065410876, 0.0503989365402489, 0.032084919061631925, 0.037862700560400565, 0.026420945669674588, 0.032314898656500925, 0.07517241587441775, 0.05846531378225454, 0.018041583206204158, 0.03178396333579815, 0.054359733682846835, 0.041754208880686955, 0.03184938341409209, 0.0753669485810303, 0.04495747913155825, 0.0141551990565213, 0.030375301928049138, 0.025371116015218922, 0.05867384291524368, 0.010058191480986294, 0.03453414429039244, 0.02390918851409468, 0.027690958569667516, 0.02048982592720178, 0.025425399090313626, 0.08223137983511533, 0.03596007140473493, 0.0314562730566268, 0.0541595817213097, 0.06757290027434788, 0.01715107494214129, 0.03683027833880436, 0.02200867567631987, 0.014095401105981682, 0.036901892237966104, 0.06330928389704035, 0.07316280637056598, 0.01971465028491953, 0.02880027495144356, 0.060479699844314214, 0.009426028174798816, 0.04750404732241746, 0.03868786535496193, 0.02662580715672624, 0.04975883177511635, 0.046344707314405716, 0.03166275481963831, 0.019015535682199464, 0.055657731774713726, 0.035943815018981695, 0.04208941831283512, 0.01811639360722996, 0.030895000654122526, 0.02900832719469984, 0.019056726314668215, 0.025250060716643933, 0.08244101979559468, 0.056121207308024175, 0.031859551316067096, 0.03230010166824345, 0.020546211913648634, 0.04053314899905555, 0.01628567329457691, 0.008982977503159595, 0.06220581085090676, 0.02657178455152579, 0.011008039000444116, 0.06061695598726792, 0.028877510020749706, 0.05080505124022884, 0.0588639323118954, 0.005680466786162147, 0.03458718438783, 0.10112141499355917, 0.022913523191105456, 0.008756058429548097, 0.07691623117294043, 0.03047380551335312, 0.11121425567375076, 0.0665332500131861, 0.020487600441781745, 0.10735714087082494, 0.01276834721436664, 0.014221768266701651, 0.035560456960792505, 0.04066397766432455, 0.033968893976341334, 0.02331291929998946, 0.023736452924147732, 0.03291654197739498, 0.05098348843955225, 0.01990025040633496, 0.0204305537045002, 0.025499313168468016, 0.020033557366039005, 0.11040405640679021, 0.08570012636482717, 0.07116610544823831, 0.005172991950530559, 0.03296690076709755, 0.04636770910433224, 0.04774377155568331, 0.005994488620349477, 0.055726139595912355, 0.05609673079884341, 0.03677566776112203, 0.09880457358855395, 0.030624864645482554, 0.04420107838908031, 0.02194367311594467, 0.05099085820538383, 0.053817783933012724, 0.005420960247471568, 0.10220862399306029, 0.011595860179964335, 0.008438243981330626, 0.01062242002526839, 0.03767658716007587, 0.052637809346760475, 0.022033902951666427, 0.03389643355002327, 0.062059097352527806, 0.008588601185399438, 0.03773040483675657, 0.026880190482423193, 0.030225397673465555, 0.1183257962486917, 0.031232326404161515, 0.06032237985862359, 0.012037139273278657, 0.07312995652037282, 0.09675105958576165, 0.0231628579973814, 0.02644914153572773, 0.059523062870627454, 0.06023103536497201, 0.05823541845705721, 0.020224692472707362, 0.047509195433268626, 0.06049436659762456, 0.014760089632604393, 0.058268969277701074, 0.09737234157059463, 0.07445412417573315, 0.009577389911658341, 0.027200652722028956, 0.07580476016887734, 0.0611167862230251, 0.05039484946117286, 0.05756641302498118, 0.05280140359255095, 0.016572864335631172, 0.03696935011013862, 0.08315520526300516, 0.0050459649965858035, 0.03677866316490597, 0.04088243146637275, 0.018325100855661497, 0.04006018163636327, 0.03509321993577384, 0.10219383083524243, 0.020779792121761752, 0.056795402985787204, 0.026480382601279887, 0.03607657039538026, 0.030573778072251912, 0.10387255930371823, 0.022012077106703675, 0.14647051061113037, 0.024421852637803363, 0.0493986402157574, 0.018061997534166423, 0.07759110866895608, 0.05419713535135793, 0.019246582054503022, 0.04281285046149166, 0.041007744298586925, 0.0345879543061939, 0.02380948408596939, 0.03399258141496009, 0.026603176919442993, 0.03735382282625764, 0.05418359474729627, 0.028340482385829095, 0.035524895159347404, 0.004928020493788344, 0.05439284400293424, 0.049737691578845826, 0.033234495279048724, 0.07981035047240796, 0.08141929599186105, 0.0285749914755504, 0.023154291219168135, 0.0031149551561552914, 0.047055537316707835, 0.0123623225297178, 0.04523452716849504, 0.035584186534247095, 0.027021713735115145, 0.012638836220327406, 0.06859245604925579, 0.07860271245120995, 0.011562750817486837, 0.03124975107399927, 0.0461437547909877, 0.07656792929816632, 0.03802902974008072, 0.04107240594983582, 0.027138760478626338, 0.020519672712731748, 0.08372467672151905, 0.0517610255478611, 0.027970166974550778, 0.026513582936698393, 0.029742168563027537, 0.04166846065932224, 0.05940641066239727, 0.07696752842035025, 0.04801193680313807, 0.012234445218177093, 0.004158909395036678, 0.03555699807381438, 0.03486745382448839, 0.1638517892288585, 0.13976832911852868, 0.09909535758197309, 0.1380813881875046, 0.14499292618805362, 0.09411007871911412, 0.09636800030186292, 0.07860221449405917, 0.12368100364842724, 0.11319121451026971, 0.1417126909138695, 0.17727623903943648, 0.09277764497505081, 0.11725642943694708, 0.17910003391725404, 0.05388502347012682, 0.03874566668884889, 0.2020072273068851, 0.20214015888350628, 0.12060440986627534, 0.2181050788250662, 0.10043104719971457, 0.17274475235852504, 0.1253834961643142, 0.08196772301509496, 0.12009170552295063, 0.19731434122208627, 0.09531897312450795, 0.14741851377391046, 0.15194054692983627, 0.15456032248273974, 0.23653908482482358, 0.24023578081640506, 0.24670732387852287, 0.18443134703463127, 0.09182828583664472, 0.05822474685227198, 0.10867760832151098, 0.23438266989204193, 0.11641220054439, 0.12303419561395723, 0.111241965073972, 0.16502113051472173, 0.17769556492567065, 0.1347528893740908, 0.1060762954875827, 0.14867158846989756, 0.15091705346299758, 0.2387317357164237, 0.12787560316463634, 0.26708199912982605, 0.12901187243480838, 0.17132008928925763, 0.24886124136467136, 0.1689426120250456, 0.15131367250315605, 0.12260428239260951, 0.17048968062285455, 0.130252122818943, 0.18011701563673635, 0.09918214768291482, 0.1230264044997673, 0.13267597904609096, 0.20085912197828296, 0.13494965139656298, 0.13145054480241192, 0.20584718174030706, 0.11055268512497987, 0.16311228455555055, 0.08773500910930096, 0.10241081757891564, 0.18470182203717772, 0.08042482193559408, 0.14511507124670092, 0.14035043336691397, 0.08684391861841564, 0.10392296022825664, 0.14527985675921365, 0.1594522841755421, 0.197227313633888, 0.11501841081847107, 0.1437937687601774, 0.11352333660808303, 0.20838875503789997, 0.2465055209975089, 0.05402964937891211, 0.21345170755540172, 0.13481658192411547, 0.175674379833283, 0.14621848300580056, 0.12038289554296963, 0.18170419659826065, 0.166886217531658, 0.2315276747028674, 0.23711772635579112, 0.20359336638883238, 0.20618393867006227, 0.08733098199891468, 0.1601024170316035, 0.14632765053501054, 0.17116716281781275, 0.16229889836282502, 0.09604522447672584, 0.26236807627062647, 0.10335613177308153, 0.10337118540079364, 0.2277789460194688, 0.12297139172592472, 0.12037477501097227, 0.1410982424333211, 0.09283562250916036, 0.1238021604536522, 0.09266833955001447, 0.33130259823895275, 0.1436119301304702, 0.15267144077487532, 0.0823352153923723, 0.2253672399467999, 0.19401492310627816, 0.19853622081779665, 0.1750251969262477, 0.1782931135066094, 0.18748768545206518, 0.07045712937871296, 0.10556898440324491, 0.2451815678467674, 0.20675122677799196, 0.14423503540456295, 0.13646253715119055, 0.08928127331478942, 0.161340675587135, 0.11630646508908081, 0.18285604043593331, 0.15727149232500987, 0.18889874279979738, 0.21585654948026906, 0.1420979871745071, 0.06393685546373168, 0.21429443491562722, 0.12735472466315956, 0.18086336913608736, 0.11390333920116387, 0.17660404285115583, 0.18880909519089809, 0.13249106074292816, 0.1062526029624766, 0.18108515159016658, 0.20207107307449465, 0.0689502037881363, 0.14004526990315608, 0.06921127123097259, 0.09867710421883291, 0.08652440632783598, 0.17401621316469487, 0.14908345265974923, 0.08304261332077366, 0.15153214545740237, 0.1368288497530645, 0.17022593187228327, 0.1762449161540116, 0.16764021658849332, 0.1530749852498693, 0.09836565117321669, 0.08038605022574626, 0.18126147438681897, 0.18118180124269379, 0.11599540274830596, 0.1938816697727288, 0.19089041818534175, 0.13146615767430875, 0.20776636988645603, 0.13819430954754353, 0.16370615591445278, 0.11292328291963186, 0.23140358378089246, 0.12241749483491145], [0.02783216389587089, 0.012918918923054253, 0.06710379399479398, 0.031582133641706846, 0.08133028423593891, 0.033456994025337125, 0.04183823723466166, 0.041857799289808165, 0.031154455481878215, 0.03752953275257061, 0.006484332900013655, 0.01524247796154551, 0.023461806572853558, 0.042211793197859684, 0.026710498176755446, 0.0179044975178136, 0.03257778555815739, 0.061023285191866665, 0.024090393206044555, 0.05211071021133854, 0.024964415257976904, 0.06003819188223251, 0.07254468832886027, 0.02970833237463188, 0.045078352484251225, 0.0132266890009745, 0.01473245205312607, 0.07283307446707642, 0.0803835527791131, 0.049502912443131215, 0.014663288677712123, 0.03187506651175359, 0.05858492308987245, 0.017691816188274853, 0.05728335502827841, 0.021983262624651678, 0.04292485251602146, 0.0413252915736408, 0.003297018824190262, 0.05316003616298399, 0.06335580841668191, 0.04773869239274533, 0.11471101803885353, 0.0268388849367658, 0.04253166171932413, 0.022628178421948707, 0.05954242957335326, 0.017989958456206708, 0.09789801578247741, 0.06596545628722637, 0.07469784738796373, 0.039037986688556216, 0.039327165727773984, 0.05561256323069815, 0.024358954904000127, 0.043710602086878596, 0.03275315074490444, 0.04102527622073408, 0.02425137317679342, 0.059773041190759796, 0.03721687311847364, 0.01787030318331334, 0.024853604470169353, 0.026507444657205094, 0.012205401867357715, 0.04927774004998708, 0.0304880126139089, 0.05200290248819417, 0.08756299172678302, 0.07666992624440501, 0.004714711450956642, 0.02226119740836082, 0.04172731153366547, 0.018428444201427124, 0.04454975564693732, 0.058826294412175496, 0.033525478455328175, 0.02140401971466359, 0.06776491255168954, 0.07513783466551574, 0.05118580076903586, 0.01433451725695763, 0.053262722588354544, 0.011687167326829607, 0.06150714249440259, 0.057971045344827644, 0.055957364083658305, 0.03668854058149361, 0.03017151870975091, 0.04298427029542866, 0.05682292469446698, 0.05460822196196645, 0.0775417343022362, 0.05311589417678695, 0.04368026883551671, 0.06599211614699134, 0.050004121637152094, 0.016797862443772536, 0.04162351045036509, 0.031029138819224415, 0.024373845738028328, 0.04357673205255021, 0.032078853560491435, 0.008875599746862728, 0.05214102431050232, 0.057257204616983096, 0.03456486824659571, 0.04057236887033909, 0.06846599791559481, 0.01437644716427331, 0.031556647811685844, 0.028755110237867604, 0.049386727548534834, 0.07215770667478924, 0.05401944125732107, 0.03345581808037335, 0.02667058116546081, 0.006476369416040759, 0.03399317130266178, 0.04386646267507346, 0.013588441464479172, 0.02505618493042646, 0.03633628186259059, 0.05808980046440998, 0.03199330069154742, 0.02822865461630206, 0.04534361042803334, 0.024943740460120385, 0.029536778475308133, 0.019902209676201307, 0.0321184354083192, 0.04765733002474712, 0.056742405023185484, 0.009954732264422122, 0.04213146887899887, 0.02874021748861959, 0.016993915834914775, 0.01875945738697004, 0.028423987884795474, 0.01227043985929941, 0.060048970739327134, 0.011211518656402346, 0.030167084975889137, 0.06365114297237127, 0.04134117257631114, 0.08134737565752961, 0.016515488180542187, 0.025876764688761007, 0.018244948906583652, 0.05564369321350129, 0.02474796669107051, 0.03470117827096293, 0.01663573908679668, 0.0850403331400406, 0.04379784417969566, 0.034260723679777116, 0.07181051562750532, 0.03472738996929219, 0.046737281410324, 0.0019030297957097872, 0.0364578600161739, 0.02570925573367746, 0.05653888993566075, 0.09986639443424442, 0.0399660830566239, 0.042300797292902585, 0.062497119614554036, 0.05254956367876261, 0.05014743370514724, 0.10570135673568135, 0.011296522814870603, 0.027619185707261486, 0.021288363420734965, 0.03093502683294637, 0.043990798745184176, 0.03308916839981272, 0.06342551475691219, 0.03500112084551685, 0.05105498359508572, 0.0230612191972473, 0.011503346444618319, 0.07155930007537527, 0.019805621310708024, 0.05248784763558258, 0.09545519887920349, 0.03938852937050885, 0.014921086840331556, 0.0336402575785835, 0.003180583514603636, 0.036840693304134954, 0.052621606587161945, 0.014011765372068172, 0.03519903966075471, 0.04239798703741643, 0.032320433641753854, 0.007098282944606318, 0.021053850500574036, 0.047877595624736244, 0.017749778400625915, 0.03729984427111284, 0.07281161634431732, 0.02132022501750579, 0.0840495746102064, 0.04206005799313707, 0.04492805752482626, 0.03223067495010553, 0.05238825237498649, 0.023995999682454333, 0.06819864089090018, 0.012011315406961067, 0.005065132516451301, 0.03273683307211726, 0.04424651123342976, 0.007966682868784354, 0.011142785247835902, 0.076475883834064, 0.03508431033321446, 0.03908067310769712, 0.021321768684673215, 0.05768945823693949, 0.11237551473201284, 0.02881303414582245, 0.03855434389063909, 0.006545388671163951, 0.0157710001052868, 0.04644681917383306, 0.03337049503780661, 0.019793572662878903, 0.04354224660463872, 0.08480895160427017, 0.0637070942039211, 0.019058578332225164, 0.021901580414945082, 0.05258969902511566, 0.04345203209067545, 0.04634568407650917, 0.013473245780915024, 0.08528253183730188, 0.03940411925976796, 0.005185771733522415, 0.012696359847341816, 0.03400025761596138, 0.040346307815202785, 0.049802985252632256, 0.1188692283786593, 0.021232498374076623, 0.005993580327354252, 0.01066529126312103, 0.03481408430924339, 0.03205421617284658, 0.036476843674937566, 0.02423384125464626, 0.040929568856353724, 0.03526910223186978, 0.03725057332626274, 0.09356352095041545, 0.03294006087667039, 0.0345646882159335, 0.027026168536394838, 0.023621668055232976, 0.022897845201735056, 0.012405770248733463, 0.04938386621013765, 0.04181127477016661, 0.04329877620142314, 0.03749899648790879, 0.07276655505261115, 0.06094551960667295, 0.1180933268680688, 0.04123694631421278, 0.03864506019219276, 0.06593053799963768, 0.014774452823574745, 0.016078904248593796, 0.08655082870034442, 0.05775009026570667, 0.0430844133088906, 0.04687232355917654, 0.07434074316293963, 0.023247679252357736, 0.026732730048318065, 0.09208444265588638, 0.09577009165959974, 0.05110831097549489, 0.03217860395389219, 0.060181385206599394, 0.016839545287732637, 0.049066598557176135, 0.06218591937795282, 0.034087741026474584, 0.07611094252957452, 0.015575314436348216, 0.027400716583454804, 0.08177309071705227, 0.014726788748145826, 0.026278757835708322, 0.03099670457173019, 0.02161447747400211, 0.11133126794330536, 0.05252397634209164, 0.03501009173511017, 0.050497455447311365, 0.10458591739617049, 0.07592766365456967, 0.042767088199334766, 0.05307238038268782, 0.01546649068909427, 0.0464946115689893, 0.009868974466958355, 0.026655403048461004, 0.08593354569447618, 0.03511360553543895, 0.022303002826388807, 0.06438235857433851, 0.013408197255264367, 0.021826423359133547, 0.07747234205805487, 0.02940607812976645, 0.09134775718613979, 0.05705807538282487, 0.0332905461020287, 0.041691592684195894, 0.013514377999179547, 0.01702548248783475, 0.04349353107353372, 0.11908844443819216, 0.03251186752271268, 0.11239033087246841, 0.027280057735380628, 0.028628914489320693, 0.022437401461384954, 0.018542740689290148, 0.05066376930523304, 0.024328612076539188, 0.0454331967498987, 0.007560470492594065, 0.014676898229686965, 0.08721641354983853, 0.006822762295468561, 0.030142688905940424, 0.06079104563762104, 0.03227464073607999, 0.010148553466874986, 0.08357240142480982, 0.05677679087966681, 0.037437311088245724, 0.02006055430449065, 0.0500688752189519, 0.035162646653911764, 0.036023587754537026, 0.1402413884117719, 0.03031003315212025, 0.11955089341368406, 0.0965860365859924, 0.1967401123575626, 0.21682650872295905, 0.11660685582507042, 0.23310848181286167, 0.08950530040648677, 0.16534031338749394, 0.23121653575330015, 0.1709463915997936, 0.12186305402147195, 0.08169694157737879, 0.11249648001525672, 0.10794957964530877, 0.12423742862959063, 0.12017871012851117, 0.10570094304820223, 0.20136156840430153, 0.168566340280156, 0.11805285444302906, 0.14703013783981725, 0.15843596129167467, 0.24960705860247537, 0.13186032523310956, 0.16680366389693754, 0.09487199146420726, 0.19615301321591103, 0.14488964221410214, 0.22584524816803395, 0.11080448290393238, 0.10750864241873065, 0.09967108797882834, 0.22962590739611657, 0.1726341599057759, 0.12416543934734599, 0.11047475866132206, 0.11613768825848257, 0.14002073976782062, 0.06285706602577722, 0.18305522329624624, 0.13134041200241736, 0.12829046275827194, 0.17799593267902253, 0.13911303282985765, 0.20748719212508973, 0.08207892067730427, 0.10163885376025593, 0.11657944519913967, 0.21617678955437677, 0.07726320771560555, 0.12947095828431268, 0.1170369758901577, 0.1245619741178328, 0.20042946922682947, 0.14283421299149915, 0.1858181653604392, 0.1348108975517173, 0.14050262439395153, 0.07474253329658702, 0.1155549021918447, 0.11364116093083737, 0.20809663039061332, 0.14648745647601544, 0.16911456812052958, 0.09636202481605353, 0.13796898776725416, 0.19669782430414232, 0.15545126741691945, 0.19565004585010393, 0.18495118365653102, 0.09865802862951834, 0.1496084986795341, 0.24642760985560958, 0.20764333616581657, 0.17627244935401026, 0.11393422786627086, 0.14149470825589475, 0.1491971860729879, 0.13873467732581402, 0.21274664619516945, 0.1031970919200009, 0.15048692573703107, 0.16827335761439416, 0.15893332089387602, 0.1937826605693948, 0.1398117509820769, 0.16026597680343738, 0.15292487798198579, 0.1399878592741105, 0.1133393835757048, 0.23128091778245666, 0.1379309438409344, 0.2272468060255051, 0.17836636683392912, 0.15211072570133596, 0.18008879295760588, 0.12586035525366185, 0.11090574440576377, 0.14858908080045255, 0.12284071244780095, 0.17530169337987903, 0.17001331182977847, 0.2635160130598853, 0.15366041431984595, 0.11123920715744458, 0.1885750400082719, 0.145775638220291, 0.11923312014269254, 0.22979043243873506, 0.1290092830576243, 0.1000155134487056, 0.23490095901633465, 0.18417754210531714, 0.1564298834531538, 0.18737048932140876, 0.1022289559665707, 0.14012943232251754, 0.1372617660390754, 0.13550665860454883, 0.13872363033794588, 0.09952301850482341, 0.14365607211666723, 0.18496894157461582, 0.16664136050929948, 0.1854234921836084, 0.16622198865778987, 0.20402018461496602, 0.26126779015025786, 0.12162231089126681, 0.10159330217227822, 0.1255390732999771, 0.12790741113525245, 0.13063671427869028, 0.16185349484364833, 0.19022761423501278, 0.12770030692580248, 0.2098698328219114, 0.2333765512993259, 0.14148280324955143, 0.09016701651196327, 0.23415806823440138, 0.09142173829698756, 0.1252818362967622, 0.10926034842287341, 0.11041943179143053, 0.19229787491982986, 0.18656940650074713, 0.0704076324379252, 0.08385020788879165, 0.3123796749259195, 0.14881107775915056, 0.1653489701810383, 0.09041762685463314, 0.18617074966671007, 0.11647832159313465, 0.1500014864629315, 0.2137047004315161, 0.19549085277943842, 0.10057221422152174, 0.11914220082783893, 0.13416278716777602, 0.11002810641882882, 0.12450942814710642, 0.2762493136669359, 0.19487341655598533, 0.20786015437014643, 0.18122347642577466, 0.2576920287984033, 0.10038400174028451, 0.23765588780083965, 0.08158703860376151, 0.1662519580173877, 0.135852531980603, 0.09536300785839559, 0.14994298798903344, 0.11556051761632967], [0.008607210418690116, 0.028153035992516146, 0.035899971807075125, 0.007072652515489609, 0.036040886019867276, 0.03399160848329625, 0.012175700638533361, 0.08689729962497951, 0.03421278189747565, 0.01355699738562708, 0.014671599774080661, 0.05340808011110752, 0.03122639113796815, 0.05209850260026513, 0.02756661292345774, 0.08058816720280917, 0.029992210085413633, 0.06407855874708583, 0.066674156565099, 0.03585260076027724, 0.04579904586857846, 0.0677050044760108, 0.027717287096405224, 0.03986497094193774, 0.03800086834798417, 0.06432440402286668, 0.03826728308453195, 0.02964256181111259, 0.05341464165417899, 0.018218321605555473, 0.04077121848240495, 0.023787164114295475, 0.04708941755515914, 0.043422656449218916, 0.07966017425661126, 0.05329223612563745, 0.03199626545181438, 0.10251622361641738, 0.021202561573215553, 0.013909622869123856, 0.023873205364291227, 0.07100363352125691, 0.014737665281450797, 0.03277803711112469, 0.029927598229879816, 0.09628888640192249, 0.06850400353751837, 0.03559323403263285, 0.07712577920286887, 0.013568955060515194, 0.04891977397604816, 0.06592863044070621, 0.035931484833840406, 0.023213542374451796, 0.10633259786352997, 0.0265985784766775, 0.02506909925761002, 0.1131727058260191, 0.022716990995010542, 0.01003590694087888, 0.038359454953141754, 0.057687565999766516, 0.03800734945182358, 0.07110746141763465, 0.01091388775215995, 0.03316117300381584, 0.03856171365647066, 0.0058965945537502494, 0.013029704813004262, 0.05264620183997097, 0.023735231013908505, 0.0833196536968312, 0.04207454854622484, 0.02198565090375562, 0.0069502891217839095, 0.07170075821059366, 0.0633189021309297, 0.005671727638165917, 0.04031829197981185, 0.012185192467915195, 0.030489902935862064, 0.04515839335058005, 0.07659030672643455, 0.035336935487125194, 0.034633639959558364, 0.006580542530789371, 0.03967667036058922, 0.045378831320352135, 0.05731046304947907, 0.03669473440236142, 0.04987956723198295, 0.037617579237708164, 0.027088729191511392, 0.032843043501939506, 0.02220385955766805, 0.022601943740981723, 0.061831887165505084, 0.04123271367843113, 0.03906275048070858, 0.056405031392651225, 0.10341886671320086, 0.06449497349920773, 0.06074462070940964, 0.051509645286827326, 0.061456894787449035, 0.027624431494322997, 0.022642642161959124, 0.05893031000009468, 0.033978646275617426, 0.04111978082707332, 0.023598970785256357, 0.02070413136314, 0.029915601292985584, 0.017675871983350768, 0.04851737480250098, 0.049102876650830435, 0.027558900333280047, 0.08728095645745916, 0.07183747426156076, 0.0547083305014718, 0.0454838466530125, 0.06785170265263127, 0.030967282964998198, 0.08001780708230312, 0.06111476758134462, 0.02992692790294607, 0.03765219109012716, 0.03724450974034206, 0.019487357743444945, 0.06311941283544706, 0.03706989148932119, 0.030355582824878158, 0.031232579213176525, 0.02916074230245525, 0.04449945048338944, 0.0737375638357574, 0.013663181002371976, 0.06747313264396883, 0.06888422829609725, 0.01987223265572421, 0.028614544595081, 0.12292026301785824, 0.016140005506214597, 0.032535539639572945, 0.0575129400878664, 0.025408711780102986, 0.011009700453629898, 0.07735612651994152, 0.056202745876244964, 0.011899039475998331, 0.0379980989401379, 0.04336758621878201, 0.007678367593701208, 0.02133155928834552, 0.02507295076464934, 0.024586151684484175, 0.04738431544073167, 0.043663292327114654, 0.06214873347010824, 0.013107319095832928, 0.03565724833958572, 0.08212758258225457, 0.08020591997211018, 0.03644996931055381, 0.0414651753981748, 0.04171806102197978, 0.01545758491697451, 0.00807412813657955, 0.011914435928056558, 0.042518829746592435, 0.011659478036416395, 0.017652971700074214, 0.031854345748621615, 0.011205494332487785, 0.07392163944220351, 0.015908043658841523, 0.02159431978549448, 0.056553721397874825, 0.013793365196174672, 0.032372765107861454, 0.034265301055124694, 0.04347674225667312, 0.054187103429989475, 0.002201468563608585, 0.040316587434180325, 0.004381337756997034, 0.03347783927775679, 0.028120310631610697, 0.01980998226621699, 0.12694487528454873, 0.110701865426475, 0.06213101768685926, 0.03420372290777103, 0.05188851790021985, 0.005057588465616949, 0.06735864080368512, 0.025658739895950404, 0.08039810078879518, 0.03307945440493284, 0.03688125765972561, 0.03658788811956202, 0.012667059857067803, 0.02511572719912135, 0.0231508304169702, 0.03760148373041903, 0.03264854909972318, 0.06924240504421535, 0.03177904313610446, 0.01571731745160275, 0.028850198986249107, 0.006998756631923419, 0.06689862032691318, 0.01636838397732185, 0.032884504180401564, 0.07346005614606604, 0.03644561410070427, 0.053233875547565764, 0.05826608495666616, 0.03921116469427943, 0.010732809464717585, 0.035782810150375294, 0.059904444421972, 0.04058528894318208, 0.04380486154508206, 0.07903172168880701, 0.06665197065881183, 0.09551069428843838, 0.12119373066290734, 0.055270930151304895, 0.034178748441439484, 0.039433410631552826, 0.007317032169310317, 0.03383547210344865, 0.030663617203132282, 0.005560364309442981, 0.0155877681531673, 0.03310418755356823, 0.058973260719569466, 0.012801296655989945, 0.05779427438673954, 0.06006532671651053, 0.028363267755917007, 0.03987238284260516, 0.040107889761847836, 0.035594409977596615, 0.027565676380970308, 0.07091577089722119, 0.03713048904413178, 0.06481889845623125, 0.04012789614799042, 0.0028192828035718135, 0.1461909957710774, 0.051369604414268855, 0.022172432715794253, 0.04848119630027683, 0.037635034551062894, 0.04793196488472243, 0.03066453842386123, 0.07024195060254106, 0.0287586533945174, 0.007040842629653672, 0.03991210067103948, 0.05828831299778916, 0.0605230987252247, 0.030366936247915994, 0.007209952708498966, 0.03473610421943088, 0.019790941150859, 0.033771733588148514, 0.085838979801103, 0.1521677379646609, 0.061866713522542874, 0.009477911479470712, 0.08209214335487736, 0.016299753990625183, 0.08487874221417212, 0.0336021370434713, 0.012398060531385485, 0.06141020172846414, 0.0913729231744524, 0.07833188504821832, 0.05054409871058119, 0.04864402828858264, 0.05582833572501137, 0.039998871619783105, 0.02335497752703246, 0.007384411038665642, 0.019664362358349948, 0.0468175865769867, 0.0624434934598544, 0.03515830676582071, 0.026516672186253053, 0.027879718803770603, 0.05184665502559754, 0.08049897924666444, 0.03880192818600805, 0.07426468595381706, 0.03502342166499265, 0.03853717202981634, 0.03470285217307749, 0.035104374175951365, 0.008180624891763494, 0.04404062510377938, 0.03195692683690258, 0.039364700205624104, 0.03475335268904606, 0.02082332889849861, 0.06971365636995724, 0.0610586209973741, 0.031782408177311865, 0.021561347361233447, 0.04996904247109929, 0.04857108139643266, 0.013146208591699121, 0.02937485047075297, 0.031295285424998695, 0.05861719837412239, 0.12558668566447112, 0.02977454343870763, 0.015711757568492284, 0.02675363850299149, 0.03443824157359139, 0.032272330980988286, 0.056632881263090726, 0.007709652230504059, 0.08983335457742216, 0.0350320746280974, 0.039023940466464534, 0.0499927950271916, 0.03980444616547996, 0.01818537024871236, 0.0926226883706066, 0.016771070433840636, 0.00886621325457048, 0.021565733214599953, 0.02270111573799964, 0.05905379188216983, 0.03675620912784531, 0.05531665027862596, 0.03883052624822144, 0.030510830542733593, 0.05580719552874085, 0.03382178211224175, 0.003216683492815543, 0.054260222691922426, 0.044158958875003367, 0.09023872234167592, 0.056354400641735525, 0.030745958248453758, 0.0505387322646716, 0.03450073519601457, 0.02549916569654259, 0.10672461271526353, 0.1236351992514345, 0.11948538523527885, 0.12003628672250818, 0.14663221645018748, 0.11994529079886214, 0.1181334009273879, 0.1255905467476095, 0.08726528229852838, 0.1438317820429802, 0.16394382703208155, 0.1292559786910011, 0.10945586938290827, 0.3009755368674955, 0.1849946361635962, 0.13978878366610697, 0.08692080320249643, 0.20638957199069763, 0.12875966096837677, 0.19117451423118192, 0.12316102146982186, 0.151817865609642, 0.11236935538510162, 0.12435399656814915, 0.16565523681140717, 0.11789130948243604, 0.20192269716532002, 0.05759834356966519, 0.10637611931850834, 0.12085633788017497, 0.14260967262089252, 0.14294725692560598, 0.1611014263283822, 0.13064259783394877, 0.09861611595918095, 0.21374795375572098, 0.11884859763085844, 0.1602781882449504, 0.13687945752134248, 0.08810703672709004, 0.1679678570719496, 0.1823789668419669, 0.17779147913379056, 0.15768948521825576, 0.12172243858297026, 0.14991525560617447, 0.1530085654268342, 0.12945215848665084, 0.17027975720984323, 0.09711466789726289, 0.228519216780701, 0.23397102020680907, 0.1300223577286928, 0.20059453053099496, 0.29357004069512893, 0.1275572400059431, 0.250187216987533, 0.34907222214725714, 0.07344543152759153, 0.07935050619585861, 0.13840821661776112, 0.2020663233293641, 0.17680659649833558, 0.196148248149022, 0.21297513957946532, 0.04631311001796876, 0.10291138708951975, 0.0880264902427312, 0.1476815883671084, 0.13566497833498065, 0.15368848378139158, 0.09079468767008475, 0.21693475694665987, 0.17921776630945746, 0.12578812082328145, 0.2787258614215159, 0.1349867913391321, 0.1484762820144815, 0.13488390573090123, 0.12194796720699919, 0.13713171495304954, 0.14200651627634803, 0.1468508885872941, 0.11627849521896533, 0.10141789102025571, 0.16964192772584577, 0.20679239634304278, 0.0944746446405207, 0.17425949204592936, 0.13636576492459546, 0.16776030853150353, 0.13409524885637147, 0.12458881017782035, 0.29966356533188976, 0.2182203750576704, 0.10788566492978605, 0.17022265301596734, 0.10467964825370621, 0.17565291404964464, 0.1923274305919486, 0.2026994183899895, 0.2047937955226629, 0.13340661242123575, 0.1425160260330285, 0.1983970073201964, 0.13162440079594814, 0.09970197664393533, 0.11261983549282437, 0.10751585896697738, 0.0862612474649664, 0.10211646361576934, 0.15408513346506705, 0.07085831430290015, 0.18475278220590086, 0.11724627877195036, 0.15718490906780766, 0.12944578463512083, 0.18587102542721456, 0.3149920653912329, 0.16403281580536597, 0.15256823340971626, 0.10932117580406128, 0.14848997966656763, 0.19534964745323505, 0.0862858388873358, 0.09512520650581968, 0.22301288321614268, 0.15172975017659127, 0.13094796048056695, 0.2517105215379308, 0.13475302726991717, 0.08651237874742478, 0.15065364179111299, 0.09536706812439427, 0.15760700819232773, 0.18674839528337603, 0.16387130914916917, 0.11772971089568832, 0.18443307839334014, 0.14325936114595783, 0.24612183352151226, 0.1828015256192415, 0.15155757957648847, 0.09686129197718636, 0.11974722642691867, 0.10123902481169471, 0.13489971778565837, 0.13529976889971765, 0.11134010093707232, 0.157989990867434, 0.11911231573791274, 0.11708498662037235, 0.12571368005967912, 0.10534565445155868, 0.11481312223740163, 0.23761349249511, 0.10680214847407996, 0.2641505790093253, 0.0760059884839481, 0.09287080126664332, 0.1642437044891619, 0.16820440970120892, 0.13733102038743036, 0.09152456261818448, 0.16946096243637224, 0.1558295922774461, 0.14197576550706742, 0.11938777031196703, 0.21149056843451916, 0.21882956817505822, 0.1439988351757488, 0.12049571731157842, 0.13239229668772992, 0.10222049835588663, 0.24526891719189384, 0.08197395130991936], [0.05049450983924251, 0.0343567221575687, 0.062016939534054655, 0.03592555148286685, 0.026601075923310655, 0.022904175003209425, 0.05123018407292905, 0.041710181807678555, 0.056747771469095064, 0.029950094401776314, 0.04836398484786192, 0.047341966100277445, 0.04730131747501512, 0.028455016360948646, 0.050805928410902146, 0.003367867114232673, 0.014291833710646438, 0.007389817704191252, 0.052158475793417425, 0.02967243924015953, 0.025624486189636014, 0.1209072061183472, 0.0020017118555598805, 0.013672226585537918, 0.029554731745813644, 0.011936079827137293, 0.052579058063847404, 0.03901650558315939, 0.0514760829748646, 0.05032954429606757, 0.00911334555806412, 0.026786969073357123, 0.014411114558066814, 0.03365375987824894, 0.06792499428434719, 0.03614858266026263, 0.06988341379309855, 0.04949914329054375, 0.07153394256508158, 0.08672709020996287, 0.021372715446857676, 0.023493346412696188, 0.020854974075430827, 0.08498818553503483, 0.05850624969048847, 0.06473838261538936, 0.03877567818328258, 0.08054526627904947, 0.10198549322423436, 0.03324627388088453, 0.07995272791313549, 0.03394781506710476, 0.042485960744201176, 0.01886945229113823, 0.027504059929220427, 0.09151929193326543, 0.014288505058615439, 0.020210529422207225, 0.007220371504269181, 0.03598581961987, 0.03907505768321214, 0.03021465137510771, 0.09401607973080489, 0.030737376148482005, 0.0309631307684486, 0.02722048865360839, 0.027094471020503875, 0.02540574510461621, 0.04875951604316792, 0.030599246665294615, 0.03479295943473135, 0.009055295245601766, 0.0472593090436872, 0.0027407133048625606, 0.02499494003131986, 0.059701350682805625, 0.054387504370102, 0.03086644281152516, 0.01825799155349453, 0.06412365451274861, 0.07029367685918847, 0.02338002668693662, 0.03410556023159335, 0.05876129568223992, 0.04372531863590402, 0.013980279158380245, 0.1359132214659645, 0.018179773976425492, 0.05144504109217275, 0.03275908026543837, 0.04214482945239833, 0.025200761043496674, 0.020797527057208845, 0.03234540044720615, 0.06845539525872277, 0.026339140885900107, 0.020725198781057712, 0.035475811906038754, 0.031073208027068647, 0.07294820216033729, 0.0466319021858996, 0.03759605216703588, 0.06007344341806828, 0.01584919853015773, 0.10864616041221928, 0.009847084462131945, 0.10348362412544028, 0.04730972912042372, 0.006238103622660762, 0.038388229215577725, 0.054979590744140654, 0.03945227937712785, 0.04292711630583771, 0.024681634968146685, 0.01503818433716773, 0.04110417944649535, 0.08671977407028598, 0.017096127285772277, 0.08266846363943431, 0.08330893612677052, 0.014943878913688806, 0.10768738605322377, 0.05633189680895979, 0.090821830165242, 0.04196668719692577, 0.01910298270353627, 0.008255887284664618, 0.022779519091390317, 0.04403244328474806, 0.044222191772273475, 0.05200261903566219, 0.004730261599404677, 0.04243040021749274, 0.013883976160638757, 0.1474656588247707, 0.04477905725399333, 0.02194656509785883, 0.01817288684598621, 0.054868864226004774, 0.032999754447730324, 0.026321785163975535, 0.054052586051365065, 0.024468279481234572, 0.05304542940951163, 0.030950321778354627, 0.02447731548830146, 0.007929066036482373, 0.03229508762277904, 0.04439129802067915, 0.027090598446046634, 0.016623868554409955, 0.026852523217037804, 0.04954929523650677, 0.05982949804033964, 0.04397385671073872, 0.08328077473467396, 0.03787963110352716, 0.02289996151962588, 0.05970274879326744, 0.053652661341813304, 0.047868957983389984, 0.021462491375484297, 0.03271192372325928, 0.04049459945470576, 0.038995131730071964, 0.028170181040261543, 0.04518524473232608, 0.004291185008872662, 0.010685331165610303, 0.0675841770885933, 0.047621044270213575, 0.025301363709713184, 0.0033872359715807704, 0.05001423782819221, 0.016689719557161295, 0.061160671569767504, 0.02243258468356104, 0.052824635208854755, 0.054689331520949645, 0.04296119572714933, 0.04807478282600642, 0.019102151498138424, 0.03680888150307921, 0.04077329458067975, 0.043389147763410886, 0.07842946166713392, 0.03762820104677831, 0.048440593640289964, 0.018652783473953605, 0.03189963686670507, 0.023235691891562556, 0.0230337108951062, 0.02388383674946043, 0.02116062783546025, 0.07480883820643348, 0.03102480850723242, 0.01979697409326271, 0.06162625767530934, 0.019664458119340485, 0.08045910437020563, 0.07841565676273839, 0.016972333222867984, 0.009045093827280066, 0.05572304843113788, 0.03650778979663888, 0.06944456032567448, 0.0872870315346987, 0.013930653897865165, 0.05850779335765589, 0.04290658131902737, 0.07483753586007703, 0.01240846879344674, 0.06224111984333685, 0.029163898584703286, 0.030045673446429354, 0.027009362482555935, 0.0051462880407099525, 0.010272023857631271, 0.022577015239925637, 0.05648738201407175, 0.03924824334981461, 0.014555315288054127, 0.01876199505321922, 0.008270993580921523, 0.00546117028739724, 0.04305316841289882, 0.01747178999076207, 0.03185967963579441, 0.030454502012881062, 0.057514311385250864, 0.03616043787089087, 0.016903837301558065, 0.03049276810469887, 0.05154175969261316, 0.030118266022914363, 0.06740165664063347, 0.03278896152492493, 0.07089108754430087, 0.05301035407389845, 0.0025650938726856465, 0.044457227547442725, 0.019679942671510003, 0.034419798006814335, 0.07410224467035263, 0.08314439576239356, 0.03333371515656191, 0.0062429970092771035, 0.020074709694111542, 0.06000356087761541, 0.012836588411441734, 0.022636699234886516, 0.03944020583144119, 0.024584573543360157, 0.06049215260352339, 0.02972512693715192, 0.02643386765773739, 0.06724689155817032, 0.03203527273369893, 0.07868426251074961, 0.014083918405606622, 0.015603439439268363, 0.09981803130358459, 0.0324087291054668, 0.09940386118908083, 0.06480807363386117, 0.014154880172422817, 0.07284201471315277, 0.028059435369927558, 0.026155207005719987, 0.014950223079311752, 0.0166173797896913, 0.0533847565642528, 0.03472924007162933, 0.04050990206099326, 0.02833129316117735, 0.023218916481240623, 0.05989210274551184, 0.044214098053353454, 0.025030427139192343, 0.0017463012538369625, 0.10972593069797563, 0.02927091915250546, 0.016031817611937803, 0.016020664329370184, 0.09686098554201665, 0.035978147249308326, 0.07302271953273205, 0.021573231300158847, 0.05882642464712263, 0.03633358906353674, 0.04857242971117939, 0.010972444640262233, 0.0764378858730197, 0.060746781077356114, 0.024462853663510854, 0.03581238880513176, 0.037458236779897444, 0.09763638909545638, 0.04504099803706331, 0.04282359484462969, 0.044725749025782274, 0.01532350229324713, 0.0266513753411991, 0.04603141565777121, 0.0036857974332486915, 0.025002602825782476, 0.026607463181379343, 0.036403008120795416, 0.03853346416426282, 0.0519852977876942, 0.07653698700690463, 0.06345786664995455, 0.033433915626618176, 0.053132081614627, 0.033579127592665535, 0.02282060438676948, 0.01207250859513278, 0.017226546094001784, 0.040839565016569636, 0.05043685023162154, 0.03285245872252891, 0.07868084575860732, 0.05524619317222988, 0.056694968858914035, 0.10891023091971876, 0.03468444691069665, 0.018757716452162114, 0.02419248399805398, 0.046315036729098334, 0.033282337469920036, 0.030280536851815643, 0.014670121224386799, 0.058699932039505055, 0.03888499126919816, 0.035308973277888955, 0.020542281882597074, 0.01872394921167964, 0.020614500991218997, 0.03438814708422269, 0.023213693676816843, 0.03717401049911015, 0.042348045765632586, 0.04610709748381088, 0.014697466732843991, 0.020690297730447307, 0.0354834268200061, 0.03691845888932867, 0.021703207692612084, 0.020265563263467724, 0.029003472112479712, 0.021607308806250655, 0.04615108625242307, 0.11290632173298829, 0.1690983730218103, 0.19741089894406258, 0.08806613529281271, 0.26441147791281827, 0.13253275124776748, 0.13892895722341153, 0.11750027522324555, 0.1960368589648316, 0.14499825816000664, 0.1675952165838211, 0.13659344625569161, 0.13528525919443177, 0.17456197420195227, 0.15646916844191092, 0.10994015952512143, 0.13864103073794998, 0.09303601578839364, 0.15160952033775468, 0.17791092756294435, 0.10561472751320371, 0.24166899342690748, 0.08250395391857432, 0.1266107613581323, 0.14571618979736684, 0.10906976872995015, 0.1250825691667776, 0.17311256649273057, 0.0762673776837126, 0.15660925527974484, 0.15398437758126568, 0.08965363801126519, 0.14334896278958167, 0.12074105696932924, 0.14293303833373133, 0.15692203365747007, 0.17003005851180325, 0.17673060057624695, 0.1589216303921515, 0.13433843580705507, 0.1022820228770856, 0.10703541458614411, 0.17683037586750525, 0.1748062030322129, 0.21035412296412453, 0.14379458081337715, 0.102940391178333, 0.26206062986485423, 0.16205643153479024, 0.1680738989624285, 0.15729323390030092, 0.08822165880232088, 0.19279186373516438, 0.11951407522804315, 0.1903878185417383, 0.18928898798842586, 0.1220701352482842, 0.23791304819526213, 0.11194573174561225, 0.20955103299310132, 0.0963051044832795, 0.26356210090941, 0.17236946120617852, 0.07068369222143966, 0.1291200287279583, 0.10803853777507622, 0.11161194723700324, 0.14719876911370985, 0.09905245665821338, 0.11816689429143745, 0.1966528242994701, 0.15498173212812794, 0.19089369704165768, 0.1632456604631678, 0.10094509985778602, 0.1778940736286102, 0.10575744969349717, 0.1309132107323216, 0.16379758084733642, 0.15763806539677805, 0.15326937239977623, 0.16421309161570766, 0.152365128179231, 0.11287334930872726, 0.08498827746558575, 0.17084699935249745, 0.3183314732966885, 0.1448111028801049, 0.17536923169128357, 0.20383356559661128, 0.14820651181282538, 0.11646863058089249, 0.08416547605227079, 0.16176415366991875, 0.11520977192107709, 0.1405575835416394, 0.18898724127681027, 0.14242895247955478, 0.06984320949883231, 0.15269630798889747, 0.23250596898217357, 0.13311788920433293, 0.15918282040905568, 0.08902974366661041, 0.1899068838646335, 0.11329302759540659, 0.17761524826768907, 0.13813571914309455, 0.19172718538151634, 0.09662362085955759, 0.21479393956401657, 0.09401963437877356, 0.17595004891195606, 0.19020552025927653, 0.11354464917413651, 0.08714107646336479, 0.17693457914696586, 0.2001857460145989, 0.19117141923596784, 0.1788801973265025, 0.08838556331372069, 0.2108519422190805, 0.11375976666327446, 0.15649152288754142, 0.12883962522591316, 0.11901588059000431, 0.056164338058161165, 0.2134936738518938, 0.15225511795330435, 0.09079754517804231, 0.2890085999763781, 0.11044593077273139, 0.11959204765697641, 0.08988113548125952, 0.30026249287109225, 0.1342566022949834, 0.09581123824201285, 0.13139163264103476, 0.20132292692940082, 0.17438908347920065, 0.16466563507433862, 0.08392527684449189, 0.13036582558866472, 0.0959148209902548, 0.1468995351704859, 0.17368052875803364, 0.0938543968743855, 0.12387952001224603, 0.2494034783974771, 0.12315346018200922, 0.16230746322581846, 0.12239680280007663, 0.21262819368031718, 0.12808584067369663, 0.15468553189308415, 0.09436078865321414, 0.16809245361195457, 0.1758387363365581, 0.17295462980626092, 0.09197892170519599, 0.10687154837914052, 0.07883936467189943, 0.14678961687511013, 0.07365828905735286, 0.1305618521667296, 0.14214073488068196, 0.1300564486413233, 0.14431552060188788, 0.11992833727309782, 0.15275296785177725, 0.20559815719964045, 0.07794818991134245, 0.10017211714218702, 0.17809440562080953, 0.13703167919189702, 0.1442334112981635], [0.019692916370507692, 0.04782402309619131, 0.016344993397773757, 0.040233880581875006, 0.06129333884605478, 0.03827237756922841, 0.06036181423452593, 0.036902359551599914, 0.028705898664831638, 0.06674973113882927, 0.03921590294809111, 0.02541580383906201, 0.045487949053847024, 0.10160597326654582, 0.06896897294228116, 0.046118627107071306, 0.035813242993167335, 0.058507398822374886, 0.009946408719124814, 0.04730276538119201, 0.04983314230377155, 0.0024909193246370003, 0.024153394361717567, 0.057876889308493946, 0.05322249148101096, 0.039667553914290284, 0.06919168236274874, 0.06721270871498893, 0.03425523465979965, 0.016993184220947085, 0.05570268964455013, 0.03660293791683451, 0.06138986592451411, 0.10083772497431887, 0.06804142432707934, 0.06156404367497852, 0.05550000193198362, 0.03432218308350252, 0.0630672307564847, 0.036878836821884885, 0.05845935744864326, 0.03969068593916394, 0.031703108501049786, 0.04952196504980807, 0.023529505762722225, 0.00792359281706834, 0.05342422158367211, 0.00849779774134438, 0.14219589321123016, 0.0698774995943231, 0.03861636636898883, 0.013325944310054185, 0.027849481313399253, 0.004176415940521345, 0.06208262391268246, 0.020704091143523975, 0.05877803470338545, 0.061100886068156654, 0.03896637278939447, 0.0415751894545411, 0.0392210204154253, 0.03495909709243044, 0.04170921653689396, 0.030630692659366517, 0.10214484717336395, 0.035419048621289195, 0.020266725801892822, 0.055738086737091505, 0.0638766524442021, 0.03881071138405993, 0.04313634257883795, 0.06296168682315657, 0.06947846737720313, 0.029772557355763934, 0.008772615504811608, 0.02877228401391016, 0.014478942067662795, 0.06277725115538606, 0.018870304563953992, 0.08405717420241526, 0.04883642744032606, 0.06965398578153503, 0.031448822851563175, 0.016061040993419387, 0.09782409595866358, 0.0615691036857184, 0.08484259818590457, 0.03331068655355804, 0.029454598308450756, 0.03961195125274601, 0.05653575663605044, 0.05905040194310489, 0.02976601304967077, 0.023750481909261118, 0.04365324508398772, 0.029848356010212056, 0.017911850046666882, 0.0377308568286319, 0.05772903433910782, 0.031061151718360283, 0.03832186684913693, 0.09828089886615354, 0.008008195736986256, 0.05182302887401274, 0.05387805973089511, 0.004857624195621259, 0.10818594841346627, 0.041329037743590535, 0.03820485457958233, 0.03726405647373007, 0.021117295987243136, 0.07397940247169427, 0.06053929765438361, 0.01836870083465211, 0.05153856510596891, 0.03267724675336673, 0.07713492629268477, 0.030457700429964932, 0.03088531730275962, 0.04629921701346194, 0.11291354594211425, 0.020148880411720565, 0.09207298198053915, 0.012909981549807615, 0.03976578936882077, 0.041712763523983384, 0.039446981879131454, 0.018065590486531297, 0.012120545180814882, 0.020339747387615424, 0.04242709071765985, 0.011968238282978777, 0.054610144842656395, 0.028410954813983653, 0.029879574093126485, 0.01661579398768804, 0.030224876733677044, 0.05244936703914597, 0.03673355973836395, 0.03744153223270851, 0.027060669306064808, 0.012124237724609915, 0.04065062858224396, 0.0340674473573604, 0.030052323089612108, 0.019192084474789522, 0.0675027112987253, 0.030962219123818704, 0.030288318389906522, 0.05636514502487356, 0.058731582962096705, 0.02360982242070379, 0.07240100087778223, 0.044209256377672, 0.007948634794898211, 0.034442876405533285, 0.03350588958710432, 0.02101577784595711, 0.03537114131294432, 0.09946996691606699, 0.03957879113694353, 0.03727809120450289, 0.04716137236344719, 0.02591722179204226, 0.025823693947806477, 0.014901203028256855, 0.0539899162287193, 0.03278868956371181, 0.051972818215407675, 0.08855813994042336, 0.050318738625895594, 0.030902435537427667, 0.032969578244392915, 0.07272625116691475, 0.00868285394033357, 0.03872304794288451, 0.03927536669277376, 0.035374933448169506, 0.024025744961334333, 0.01694692400163941, 0.0277219180979075, 0.014788025986373186, 0.0512929956218408, 0.013782857342683261, 0.029824932871927178, 0.08725039721015962, 0.0635744039449961, 0.01886565057981399, 0.04091829970298756, 0.04191749286086809, 0.042987840265155806, 0.037680536343325535, 0.03477962950484888, 0.07776717865659345, 0.006189933929201817, 0.05715290557653193, 0.027411941686765324, 0.031035422655423323, 0.03521672480048672, 0.0491491713440947, 0.008837568269471728, 0.05420577299270419, 0.009081207212030647, 0.03828037169671828, 0.018664835952222347, 0.042145511270650936, 0.04557376622312492, 0.0611903804594711, 0.06393607405404891, 0.0619635432057323, 0.015100551555083405, 0.09276598511684327, 0.01293425983373797, 0.060635977950427807, 0.03293536092725492, 0.04209059042735927, 0.07299334772171513, 0.04238906977397781, 0.029041594562811718, 0.03794482901632305, 0.04521392323377152, 0.043754115880977724, 0.018994267166201628, 0.03476629191408715, 0.1199331483052623, 0.06583880663158433, 0.047267690045578827, 0.0328755984082818, 0.046784495409097404, 0.03894544709774275, 0.018903219531620705, 0.04640920042631127, 0.022156626406696536, 0.018360649250567924, 0.007007720339442454, 0.05436484731974141, 0.07480764310927161, 0.0120014060596605, 0.035528139541706735, 0.03989714663475752, 0.04642770528012226, 0.039533745166995836, 0.04089776854661684, 0.01620543516060758, 0.06354891236931567, 0.0933690035655614, 0.04604391821269547, 0.01456490000559678, 0.09132766269988592, 0.08166209989858252, 0.013922705735650756, 0.026921421334507967, 0.07055466769323235, 0.040772459544842286, 0.008062730663486065, 0.016278537185562235, 0.022948100569567854, 0.08874090553651895, 0.028031498058548862, 0.04478821200468848, 0.030930150683308323, 0.03863670600337848, 0.019246794643902013, 0.004577010019396943, 0.023212343446850296, 0.06806976191939847, 0.021771931525079474, 0.021604347876423312, 0.05836435105471362, 0.04067792812542569, 0.012105185117933058, 0.036949374367513006, 0.04679181920965353, 0.04507154196260437, 0.05997461041495685, 0.1036389407912089, 0.04962814866655296, 0.061826624141465274, 0.016312492117586157, 0.036048795877685474, 0.07001210124261918, 0.051351720091676524, 0.05046374374820341, 0.03351208340797213, 0.027658099143375314, 0.04915064606334894, 0.01614810114035443, 0.04616225581435908, 0.06495151593680344, 0.015539428005145203, 0.08372283044962153, 0.012063326073750373, 0.07848192336818866, 0.03606783316260384, 0.07576609571133891, 0.03733336444823973, 0.04342704230258542, 0.02360491371232896, 0.022342741722241048, 0.023893414763733748, 0.11718291563973313, 0.038320422773399664, 0.025859257664471388, 0.028676971184810805, 0.0075071076806184035, 0.027402223861445824, 0.03217524465834422, 0.008318085005627045, 0.08350059600366701, 0.07767642022020395, 0.04585364112450231, 0.010910248834519617, 0.03042125762740691, 0.041230537988726175, 0.03957337872575849, 0.0648893172582311, 0.027616607821396286, 0.023389033965706345, 0.012271680921736744, 0.04686696860458582, 0.04708230825922182, 0.0395376407240908, 0.0344112906004152, 0.04383617921942665, 0.037572184697754925, 0.02632174877479913, 0.0564275237341081, 0.027181996565852917, 0.012889438902118034, 0.07740923939573188, 0.06081692791814285, 0.02794901337174158, 0.020438712540893786, 0.10242686712092931, 0.018260624980734243, 0.043042944969549295, 0.05733636065175938, 0.05292631422860488, 0.032634717382250295, 0.023461061552347198, 0.012685612591374065, 0.04347871876351776, 0.07557524022676292, 0.050291622943815686, 0.03549515179568722, 0.07793661432280656, 0.013453664573570414, 0.02404226181698182, 0.019003305088488326, 0.03189276697324409, 0.0046461599882722145, 0.04341781860397708, 0.1204697622527038, 0.11959243070093856, 0.12067947116109634, 0.14126745593403617, 0.12536556204600682, 0.10562632608437732, 0.2267185884017137, 0.15493308554493612, 0.16167058369084714, 0.16718182021812086, 0.16346765742186578, 0.15685708472324958, 0.12916576417703785, 0.1636762171983719, 0.12551838892602152, 0.18448737870541312, 0.11093828782078721, 0.1788894669903863, 0.1140361788472341, 0.110935062590626, 0.10092634602539963, 0.08561538171864326, 0.09160873269842518, 0.1430629515239308, 0.134404503229645, 0.21316695267394667, 0.2830551162121758, 0.11235206478065062, 0.0912796060043958, 0.11918441993334603, 0.12789572829440718, 0.18066790946308645, 0.14808897860348225, 0.18735086214878868, 0.10741393096865186, 0.18136106581697542, 0.19406678725875195, 0.11729973638730666, 0.1386264137803547, 0.10695674501719976, 0.19374699151564032, 0.1656022848140809, 0.09956655528156028, 0.1892880993264337, 0.12676910407120182, 0.17771874674625937, 0.16052448551260656, 0.14085649572793515, 0.20521860659843494, 0.13025301148093518, 0.12836079729060013, 0.09732248456848246, 0.1441607861629417, 0.08814141109225251, 0.15746748825955778, 0.20185831513616348, 0.3111350271970995, 0.1817588646325373, 0.15516170150329991, 0.14881959665686856, 0.22518091204185642, 0.17614046772641523, 0.1094298683587582, 0.11990413655556979, 0.18739399289892567, 0.09826522470722276, 0.14038141396257187, 0.11854881976520824, 0.17426375149478837, 0.1797593445066483, 0.12209693300387553, 0.1585075751908364, 0.11262098462471079, 0.17205105974308907, 0.1027001383443994, 0.15661584363589365, 0.11433820901138168, 0.17903813401297217, 0.13279124463517822, 0.12798488560703494, 0.17145588603471557, 0.21080945498279988, 0.13683560664855665, 0.10212304431103891, 0.29269651660034735, 0.14549482103076675, 0.24618425436558264, 0.11571720557948274, 0.07016099809158234, 0.09924038568691862, 0.2873863015444048, 0.22985124449816444, 0.13906578052668803, 0.08006214059048122, 0.10060294200816464, 0.19500237979715873, 0.15323865227401257, 0.15892795827840606, 0.2062073349952698, 0.1952478190463397, 0.20693835141437672, 0.18811213904090468, 0.16244007304551142, 0.22310335820000018, 0.2218732967852585, 0.14902285510493865, 0.223568833222793, 0.13619550954430334, 0.13862091326905837, 0.11964685358707944, 0.10397274828245563, 0.1538261651031433, 0.13375541225316065, 0.1286829602453978, 0.158749689618426, 0.13776721552975718, 0.14668098560744716, 0.1234094791054245, 0.13151048352160763, 0.15035460703074932, 0.24981502083040055, 0.11627813515764092, 0.1633631936725109, 0.1360347842977893, 0.1735684807382284, 0.1400582321108349, 0.11205499886625236, 0.07467657312630646, 0.11038784598631245, 0.09092777246429075, 0.22114022725051452, 0.12026990523501752, 0.16335447559193259, 0.1806089819799508, 0.18348234795754959, 0.07763921899060089, 0.1047965532709514, 0.15614328996068047, 0.08572690113778077, 0.19185584218752003, 0.15870162526205664, 0.10113156565855588, 0.0962069379766622, 0.1483524668841593, 0.143360867795925, 0.13601716427553084, 0.11411088774160993, 0.13499911003295453, 0.13826667421287106, 0.1830986911250699, 0.14927293684694076, 0.11422672789664039, 0.18403057579792317, 0.15101851414768927, 0.16668976194435553, 0.1567107466079535, 0.0973524003019256, 0.2643296290789881, 0.16308516504303103, 0.16941084496436581, 0.1584840409698025, 0.1987643618016474, 0.08498679125501264, 0.0782459223222348, 0.14834066913012536, 0.1483151890457638, 0.1582490511599087, 0.08049322592635309, 0.15724985800202818, 0.1387465210451234, 0.19221257869034045, 0.10644294516814333, 0.17274941017310466, 0.14466410592919396, 0.06783947588935976, 0.10163440278941586], [0.0865464773209345, 0.02560114349058319, 0.03731540351685497, 0.07185170051431464, 0.03520368981445509, 0.026508448232385903, 0.041442939696172555, 0.04081025832302628, 0.0411294948219532, 0.011377919656825403, 0.04995725620838423, 0.07213936652988195, 0.15838834126630139, 0.055052181405405846, 0.020430438791311557, 0.06749016277852558, 0.03007472350051807, 0.029302020407011433, 0.0247202247321125, 0.009501644883364921, 0.014269907316643626, 0.03552175036841824, 0.046821780908372135, 0.034431151429852175, 0.014966738977349334, 0.03817185534224395, 0.012156228598717962, 0.035707354320273284, 0.025457302821920286, 0.07894392801268448, 0.019882373744621873, 0.03742715276236977, 0.006730571753465601, 0.028809370330324578, 0.038217590791323496, 0.029673063601817817, 0.041579019894162496, 0.03358159439578172, 0.052404899465581106, 0.14025995838305644, 0.01101152087005997, 0.04163102577290228, 0.023451994901763338, 0.04103561074683263, 0.032786490891369126, 0.03391160592136364, 0.05896612461055479, 0.03679109677191704, 0.026995569069479263, 0.10349010522927969, 0.08434695462065359, 0.011822403870492935, 0.03420680258122664, 0.0766194180675572, 0.03563397458844608, 0.04074015361707538, 0.02248457141010271, 0.010354600474989463, 0.037509162474663994, 0.06157373851766029, 0.03601273611908959, 0.053131978192757216, 0.03438400254855233, 0.06457994031088968, 0.012783451595403736, 0.07035463447532347, 0.0846815435215831, 0.04608694937140231, 0.021838761205154083, 0.020694294794192238, 0.04977125389080855, 0.06128818307432437, 0.05670994587783372, 0.026543008373870004, 0.05891585775140313, 0.014639415462771732, 0.03940540628748075, 0.07373648365178416, 0.06648619689287678, 0.051974342730376995, 0.011990268098851366, 0.11227842074848952, 0.040466189084033814, 0.008125596796162426, 0.048932966010104266, 0.05401490984724895, 0.04806636735015819, 0.0517796759583777, 0.04875861972029652, 0.036467849802706516, 0.039693754121300676, 0.0312891299085271, 0.020378373540757645, 0.02803125291041309, 0.05151926352071667, 0.01958882225857627, 0.00828540369477724, 0.034755126182590766, 0.020155028267312917, 0.0155698167978816, 0.043180821643721674, 0.05071378718580931, 0.04012693087720583, 0.0497566407636529, 0.08236569037000019, 0.085460202948701, 0.04535327845763776, 0.029884624527767304, 0.07355593204978975, 0.059274260495458884, 0.06427704446738766, 0.06568389599241557, 0.04544439312491206, 0.018842139341417822, 0.07772788600695711, 0.05297281576560871, 0.017754256184543335, 0.04008661550019057, 0.052964836959877325, 0.07785167815464158, 0.03470694691303276, 0.06767883491251739, 0.00948414839278426, 0.05571085614182296, 0.0051131288825173775, 0.03349956553128939, 0.018165848413181883, 0.02460793539461109, 0.0347475802165366, 0.030050158891226017, 0.018284954017989578, 0.16653398562583233, 0.06186584401274882, 0.022076968584329854, 0.046290295919583696, 0.09006852058753853, 0.0352535889514031, 0.04705958226094804, 0.009295248347634991, 0.0700026017523581, 0.0348491826274943, 0.03128304142474888, 0.022705955498461283, 0.011117489024576162, 0.021199587236849532, 0.04283316711324357, 0.08093957939455587, 0.02225840693309663, 0.08796421495536644, 0.054406001563033754, 0.015930653786316754, 0.07857871857742149, 0.058127744799299594, 0.039530029640563076, 0.0122401736406309, 0.07856867516473418, 0.04321999554972976, 0.02751985283177947, 0.09464800267690614, 0.056431308208454045, 0.034636616211144194, 0.030950478826379104, 0.04840058469844442, 0.04654325049130186, 0.05179765987240019, 0.022209231749237068, 0.037803210002640565, 0.01373825570373165, 0.02445772662007761, 0.06830274457893065, 0.007942320315182329, 0.018490265581696745, 0.05413818871602417, 0.08102556510317711, 0.09347853115609578, 0.021574305738472653, 0.07831446420882018, 0.06284326112138168, 0.007846694347643925, 0.009741975283700853, 0.0335634074684593, 0.01942495222113306, 0.010449744764745477, 0.02620287299636872, 0.03411458474734137, 0.101539216364824, 0.020539908925251617, 0.037197475772230856, 0.028212930661656206, 0.043997586284193306, 0.02835800856231682, 0.022272047128588445, 0.0276729689099856, 0.03344744473936097, 0.04807872817881646, 0.020617237840328487, 0.03782883181326813, 0.02907011027057325, 0.010110592852616984, 0.07938393827287421, 0.012771975598298015, 0.01959316406188713, 0.037183881542014505, 0.043702979512032, 0.010080151391335794, 0.021901783428245017, 0.018097153309011654, 0.048619877366769704, 0.036370951171603896, 0.03092464825679218, 0.039417495154925895, 0.02903165648721399, 0.04755415713354465, 0.06605290522378299, 0.01939997200914208, 0.12318647091066647, 0.042356951537752346, 0.011725762836454857, 0.021275548684981563, 0.010508443379113752, 0.09195929453257592, 0.03470511596289373, 0.05528900982631792, 0.014446116157717284, 0.02411563005749016, 0.036285861785854065, 0.027208805812763113, 0.03707898878342202, 0.016787449393661755, 0.006896697441040869, 0.05736747531280403, 0.01652191757344671, 0.1252206641760084, 0.04796885584871616, 0.04079664877105144, 0.04999530396514362, 0.020272314413300446, 0.057119710986772855, 0.0407762210365505, 0.0697237074435238, 0.01538797721056448, 0.07269491817081168, 0.044563503094738534, 0.040507730201727925, 0.02971286761514362, 0.042116196916228345, 0.050481792779699455, 0.0742388841125273, 0.045413523612003175, 0.03910988787068956, 0.04064598608942282, 0.028451249123580998, 0.031573622404868086, 0.07018874579619977, 0.03855266232764529, 0.062041642039173076, 0.015984912921163826, 0.04877389168306705, 0.06380299692072215, 0.04729446098809281, 0.02157517141782709, 0.05769882749225344, 0.07248088852652619, 0.006171229892530509, 0.023553733293327595, 0.011836805365859501, 0.026747423614705765, 0.030842751542466785, 0.0623408874737159, 0.052703551181982604, 0.0376726916029809, 0.059006359548338, 0.04624909188057627, 0.020228069005233627, 0.0676002342914862, 0.01820920898969616, 0.03980956746325378, 0.09052074995012054, 0.02293606532827741, 0.044325402967872164, 0.016494453321361256, 0.02249587120698585, 0.020295906090928663, 0.08367158682836641, 0.043594022657001213, 0.015368195862749652, 0.03269679731719437, 0.014882908848625039, 0.03326407393380519, 0.032029770307182785, 0.11167588493516369, 0.08806142385207838, 0.07628455337497496, 0.03598746287846758, 0.09855594741360796, 0.02187451261336044, 0.029917709949997165, 0.06933060474693775, 0.03693481486651205, 0.020912135725901015, 0.030035103348294095, 0.09238172307490342, 0.07750523021264423, 0.03616487351997245, 0.047374245214967, 0.05744077460539918, 0.05199340682837272, 0.056389089102946946, 0.05796311633481134, 0.03142631518834781, 0.030456693024344506, 0.03403853519909805, 0.06613584190246559, 0.03695709270335013, 0.08653399774864798, 0.038643608455576246, 0.007744716074798377, 0.0551990557822489, 0.0385093706990442, 0.02195341200868209, 0.025435622533663146, 0.028158090257596587, 0.038261767251477126, 0.02956946170137775, 0.03220494971760819, 0.06411318592126332, 0.02194864119613363, 0.0170698945200251, 0.032510764356101715, 0.09416208076741427, 0.04035210710078959, 0.06718873016295895, 0.04943743107780334, 0.07767570009755512, 0.06349830077059808, 0.05308644192653799, 0.02883928223332811, 0.028239670960653215, 0.04193568744906976, 0.03356867432293873, 0.035207880315400904, 0.06295582625053583, 0.0524552965596799, 0.04661436643331282, 0.01173631378239201, 0.042387039640978466, 0.06698570154126614, 0.055643463387124004, 0.012105672541374882, 0.059362954324892456, 0.02144792229838429, 0.025139906849231453, 0.13233560618133317, 0.19223874825383389, 0.13853598476177262, 0.161613755288624, 0.19040736910556594, 0.13278828753579047, 0.17082079914548706, 0.13724753212544227, 0.12797617518733587, 0.23097642847607214, 0.1897184568787775, 0.1410199942127351, 0.27346081490958896, 0.1365406168324332, 0.128287183901956, 0.11381654910022214, 0.10819684218374953, 0.06837186103145923, 0.08996434795159487, 0.11764937891594826, 0.1329836552782405, 0.07767664238570199, 0.1504061800698119, 0.1677835669608847, 0.08534475349851194, 0.15397244193140538, 0.07315323793239172, 0.1812140382225475, 0.1353838547102867, 0.13449811917399207, 0.13507524385086953, 0.09601772958112341, 0.11112168926985995, 0.11079116829580839, 0.13695762913313606, 0.12204513013843568, 0.07960238058360354, 0.09725046464272084, 0.20662397957376896, 0.27746880306832256, 0.13720124509305726, 0.14958779898382005, 0.10026952522175928, 0.19606750248180282, 0.16375486378467854, 0.13879426364456454, 0.10945249859604145, 0.1126763804425155, 0.11594887056778516, 0.27259976272621467, 0.13692231247982672, 0.07610963251922401, 0.13944758342639094, 0.18474064737318024, 0.19655370784382667, 0.10952192148373974, 0.18834552006615748, 0.12045842415142445, 0.16150276447015424, 0.24614044945807229, 0.1265560473585802, 0.16689364858452352, 0.08752559131431965, 0.1415214600462106, 0.09889033713167715, 0.128577332042398, 0.20951599213144473, 0.1285919336782348, 0.11090089506920307, 0.18072539670092447, 0.13952563246411664, 0.15552162493188537, 0.1827814234721084, 0.07086121777613318, 0.15457029694751387, 0.1927162508570379, 0.10007555175933147, 0.21320582397522467, 0.1750893950943024, 0.2007778247277583, 0.09204130424487014, 0.1892962045366726, 0.12818098879389225, 0.15340368293466108, 0.17209316393540752, 0.12416994394434076, 0.11914901134948577, 0.17899334851291873, 0.18390774126014403, 0.08365231205619152, 0.19607482628235895, 0.13581392114921925, 0.20885456713937944, 0.14169815056506666, 0.10215290641832737, 0.1611715693387293, 0.14504371781743344, 0.06877970325970842, 0.19143755818086286, 0.08476880859703788, 0.20425482202441464, 0.15178903006017208, 0.13267567261092125, 0.11903609765032608, 0.24682266607640252, 0.13200402800594607, 0.0837390408700993, 0.24496576087849758, 0.25720200831851653, 0.1382323381521048, 0.10136310807279042, 0.09223707801392002, 0.08043688015952226, 0.17716158632068865, 0.20654415321205893, 0.22280090668749428, 0.08916454449776681, 0.1973382584870823, 0.15745875485722097, 0.15684009289308903, 0.20198513333114887, 0.16962588584471136, 0.17402016617838414, 0.0925476807019403, 0.11830989992426288, 0.28573265479456994, 0.1646668301715005, 0.1222249309742643, 0.1441495093486963, 0.08922726411612765, 0.13921916665088746, 0.23157265938578114, 0.15982509320301397, 0.14542591908285696, 0.2828018169008917, 0.2046512418817128, 0.16917528824940806, 0.07557881019649006, 0.24438760964380157, 0.17934873670099244, 0.1486153269727384, 0.18349949300529497, 0.11542505028867915, 0.14845377435126614, 0.09624604676519671, 0.07155144767415139, 0.11588908506617432, 0.2281165609676992, 0.1477548416944281, 0.1850600141070543, 0.14487217540942854, 0.16230652859855085, 0.21012222814944484, 0.1837996309322696, 0.13866189897300737, 0.16425315801414753, 0.15172457142222315, 0.15917857628195517, 0.12714570523389887, 0.1684180103362568, 0.17752665786012528, 0.13258850712689663, 0.11335613025772957, 0.13019074385444965, 0.15650701318537036, 0.2390035743554754, 0.1944582275445423, 0.14434702213733427, 0.14917147616224904, 0.16215576249505245, 0.13726999382338217, 0.2521418903263346, 0.12894825649357614, 0.15776359656405065, 0.21879071219553872, 0.1404846519712479], [0.09710121539331253, 0.03928794202605083, 0.07216852383628007, 0.00596627408090318, 0.04113855381165782, 0.04086141001373049, 0.039744561072438955, 0.08025678054940316, 0.007476718887882008, 0.06802499174110352, 0.03273745743377555, 0.03845505889565234, 0.05503981291586834, 0.04136852957608719, 0.02829663342826309, 0.015675126116782907, 0.04470712925878264, 0.011051608335917756, 0.006782397122738222, 0.04730234020239404, 0.04236971839301048, 0.018941648417122422, 0.02389541616843593, 0.04671021169351955, 0.043430164110876864, 0.05876926299665244, 0.01429306711220453, 0.01862012131530191, 0.04699158812722853, 0.057058630796569976, 0.03424074027627226, 0.02858927901533823, 0.04423799233571176, 0.007564759148555178, 0.05680297193447909, 0.03575325447825655, 0.049249276053160436, 0.030049854371276115, 0.030116113315847133, 0.057382609379748185, 0.01933785951546123, 0.00711068447168556, 0.08918379628730398, 0.01197535332457553, 0.04921503575338472, 0.04550644624677878, 0.013554527709681182, 0.05395044737886037, 0.05495061346840474, 0.03798729710040554, 0.03035231929032072, 0.004359571762653369, 0.000505806559475229, 0.08031094296564979, 0.06608591595244023, 0.07640888944508568, 0.05486353225405178, 0.08527608903785867, 0.05653537742252793, 0.05928377530747845, 0.02980245010656936, 0.03568721769918357, 0.019638052983810345, 0.03264456544251692, 0.04235797043469164, 0.013319326267998307, 0.01595389019067009, 0.056688955068708434, 0.07583053902752938, 0.10080803140637376, 0.025704544292943134, 0.046550716018123973, 0.04334248151750334, 0.02267201780341566, 0.034986668596825296, 0.020942018900607384, 0.009338875139702954, 0.01306964576454653, 0.03725597424612891, 0.009621230250735198, 0.027970027163504597, 0.013783808249319273, 0.007448972140874474, 0.06733314539756506, 0.014018692722123478, 0.04087662835034632, 0.021954689460295825, 0.07519298533518469, 0.03049366251235047, 0.09367577581396026, 0.043028906408336856, 0.0448070079719107, 0.028822638973173116, 0.0476879314068825, 0.06821647541777742, 0.02047770258580004, 0.02863406834583129, 0.02463166496806568, 0.073400737958089, 0.036437773190799265, 0.0169212753779345, 0.019320557419691357, 0.0936659392450125, 0.06906284169564325, 0.04618212047423567, 0.03242160704347395, 0.06501147763863688, 0.08231096104868958, 0.022587721318667455, 0.010240339418692936, 0.014015668590042381, 0.04175470683783774, 0.07771986506638989, 0.08631370150514188, 0.036085479997939644, 0.045483720248505, 0.03806982009160904, 0.02622309197191029, 0.08074592768905625, 0.06279440003357108, 0.05192226790372403, 0.06580840060186964, 0.006331073180321725, 0.02417232630954635, 0.025210185840185133, 0.03257712289210289, 0.012978042716220503, 0.018822044855163946, 0.01284494355786592, 0.01993966371481938, 0.012185287271295826, 0.031643815210930286, 0.02744219258367535, 0.12487709672460634, 0.10212686708978108, 0.0284529862279493, 0.05493160299656372, 0.06033282163703154, 0.08453122174908077, 0.04022975902884238, 0.0016853098819528017, 0.021618623924892277, 0.04487121380084465, 0.010028392575951594, 0.024246895392876, 0.037961679120217605, 0.030023759501355312, 0.01626003999263048, 0.019321995749769193, 0.015526831604450222, 0.040191431649990624, 0.11314813738628743, 0.029778264710799824, 0.014728716416885296, 0.05335544604026983, 0.043745650609414426, 0.027381583537545898, 0.05854496394374198, 0.01720397331331286, 0.02725088893766365, 0.026304982940576253, 0.06214940762748161, 0.030331299752898278, 0.08254422716075376, 0.04747165712497888, 0.07039594193620068, 0.03809638802082308, 0.04618944044435217, 0.07150566625979639, 0.05913847907175941, 0.021220413337071097, 0.1410475886997677, 0.03811533720563016, 0.07136082201595269, 0.09467214976827945, 0.04594371774263921, 0.08179467907475849, 0.025731319065896735, 0.03122207423251483, 0.02678777346567762, 0.06465484838812582, 0.004565389902000466, 0.015813909647535655, 0.03723697143516714, 0.06772168987100163, 0.07538109056411252, 0.04409407888869605, 0.01677446037290558, 0.02169961474024721, 0.013848985094697246, 0.08202760044725672, 0.06450335450109936, 0.02001232140877795, 0.07125845734751032, 0.05693384656502355, 0.043097735577893835, 0.02416061665562372, 0.009115391012821949, 0.015654892777092755, 0.039305156021709406, 0.0007584927610174243, 0.022157967060564027, 0.018130951193011096, 0.03299264132135338, 0.047871126012215694, 0.06774130172186321, 0.014878251991655319, 0.07029068145540453, 0.06535627849159703, 0.035715765965681885, 0.01755581259907734, 0.045635581857735114, 0.04570240387693048, 0.032964004954743775, 0.014505023531044924, 0.048053493242590666, 0.03966525565051744, 0.03787197405472398, 0.09503793376948565, 0.0524177850644675, 0.04551272816775788, 0.057428164798165524, 0.03102884579059338, 0.09254269346955324, 0.024682671102064273, 0.054367976788912094, 0.05974874471224124, 0.006012129231220893, 0.023909477712286097, 0.02691219572067982, 0.038687195028028185, 0.08988949350051342, 0.0192455938010807, 0.044096641452802766, 0.03565676187375381, 0.05497721204113576, 0.043095682462256764, 0.021201502456660234, 0.0254397306801571, 0.08750449325288497, 0.08135762591395648, 0.01405778810411932, 0.03793720644147646, 0.01466179384864987, 0.04658081944310858, 0.02570207748982695, 0.02000049684166668, 0.0184001621504825, 0.05931975079640266, 0.013584696252139346, 0.04974768902625769, 0.01952583067900231, 0.024812917540510817, 0.02885201461462965, 0.03730522986922053, 0.04572583850653422, 0.04506471228875941, 0.046321211397768035, 0.0027503248354825644, 0.054282626933268005, 0.027197322154778148, 0.0843236885303932, 0.04462595075188626, 0.05301277108129956, 0.042176093500588215, 0.019990756033709454, 0.07201643240067267, 0.05977556928090992, 0.029966982810067076, 0.038595586234042724, 0.035836849992554036, 0.06605116620419488, 0.022167979829734372, 0.039774955610834786, 0.04263119569288627, 0.0046109630362010535, 0.003682729251111948, 0.03713301330384228, 0.02907503238548675, 0.04223728860397974, 0.07313705049455166, 0.053334478213782274, 0.018391470882981535, 0.056064030335795496, 0.038207949574796424, 0.028940110895482284, 0.022080797108731443, 0.052906415094771696, 0.04920491190146535, 0.02593811684017701, 0.03966417929698383, 0.03609664189899641, 0.002107273983476203, 0.04885385977104307, 0.0306036823143762, 0.018121277417747245, 0.030633011990557277, 0.0236515608060384, 0.04267739462516001, 0.06668747883410224, 0.027529538098362186, 0.018835487783015258, 0.05029501288288063, 0.07121153446214815, 0.036131698082411484, 0.010972345048832077, 0.02626578796715025, 0.04041832008008515, 0.040165101208033106, 0.044741319762843276, 0.04408934829576362, 0.08427239894386261, 0.033103911761915496, 0.026093598214849353, 0.02749753669054518, 0.07938809046942381, 0.02052871255023826, 0.042666661733340834, 0.030574934865017573, 0.012864090010313498, 0.02992291743266246, 0.03903003086546256, 0.05241939767954811, 0.007051447680550478, 0.03311852105863152, 0.026286066314505956, 0.03492290326844781, 0.022816187889886, 0.06177677863067197, 0.03967290503844138, 0.09658939971197998, 0.024959177131794637, 0.03188161464828638, 0.021757967657439654, 0.021715943904353247, 0.08978304558343465, 0.03865653235885886, 0.0220269545341932, 0.032903480178285996, 0.10567118819322317, 0.03205633057551759, 0.03248673983879628, 0.03081280325028685, 0.015856396883816248, 0.03331565463374699, 0.05632146652187071, 0.0577507222882442, 0.06505529786790572, 0.0038853255119324936, 0.05061127696066134, 0.05937236954548186, 0.027068906666470632, 0.1812733793931623, 0.12476548537491791, 0.1618050780868338, 0.13298992187746111, 0.15018533224300032, 0.10537034546535824, 0.0940277319281332, 0.12927370596556895, 0.21838171317452387, 0.1606693680608465, 0.19143047952844253, 0.10734656119659063, 0.10514446444088414, 0.13938110231632186, 0.11847231056421034, 0.10243471186127394, 0.17699053420895533, 0.13136874193385725, 0.1581352411378776, 0.13203568275897734, 0.18653684776396523, 0.09565793638748508, 0.10747054486625618, 0.15690320321629125, 0.12420964262057697, 0.14440591897695296, 0.13755386004284506, 0.1441340803379013, 0.12253634571548432, 0.13297369613522483, 0.14592387623363925, 0.20052299324062564, 0.22644086620740353, 0.13799200104849954, 0.14268652656145636, 0.15120188495324505, 0.12658032468490063, 0.1669947109034946, 0.10785837687792317, 0.14858805424263402, 0.14519414684224516, 0.1200698490344709, 0.21236970029290647, 0.11458026215193734, 0.13611856367318861, 0.16445352064986385, 0.10008826115799528, 0.1638044296733795, 0.2189456304955867, 0.1523391884421149, 0.15808745257316098, 0.0987467033067538, 0.10294523285401445, 0.15066134863563124, 0.20842571111936725, 0.18887459570842405, 0.14193726192799308, 0.23171895153580174, 0.18572580580028797, 0.11172800955753173, 0.15196225786161038, 0.14865825854001508, 0.14973999001085758, 0.12254666491982438, 0.18807544342933163, 0.13881844137945484, 0.07177195076139704, 0.09500535971094524, 0.11392384737489686, 0.1557079221933119, 0.13732714398253348, 0.13050589710474014, 0.16846250472289903, 0.16244877580433123, 0.11785705769134146, 0.164295231562949, 0.11306625790894033, 0.13982054567144764, 0.0878917430377295, 0.2695570147085575, 0.11539881943815178, 0.0765093695372343, 0.13518048900990717, 0.1396113577028436, 0.0832795643157536, 0.15765609910651562, 0.1414393660642447, 0.27020353162961624, 0.1911447287326859, 0.2009185704012071, 0.1833297432430329, 0.18111447743590803, 0.18928845172687886, 0.07904987031173322, 0.17493184145179488, 0.1730261824183887, 0.07584128724110704, 0.11643226438712691, 0.2044015738271898, 0.15934539958834648, 0.11321238151961759, 0.08675257029432444, 0.13697477418088144, 0.15735829008683083, 0.1313656929039186, 0.11967712172096777, 0.19867782450972066, 0.20102747746052282, 0.1528440557059742, 0.14202108726866786, 0.13477273105132964, 0.1659575810716037, 0.17258528349620683, 0.13841897249221802, 0.11809930235387818, 0.11108616577281107, 0.11289581100666717, 0.16959196347142422, 0.22838942616456942, 0.12606349112766405, 0.15791034836682583, 0.14361422839424304, 0.12107924648350286, 0.16560714181152084, 0.14398737450040158, 0.07743668832605885, 0.13124884917370735, 0.09865820482974091, 0.124787226950209, 0.11360288717814031, 0.14164201164197537, 0.0893359260273076, 0.14284377376879417, 0.2232934246140142, 0.14814114919112575, 0.16063775927309068, 0.10223807241286963, 0.19569769651899416, 0.1490844485740508, 0.14183275221336272, 0.12545060546648118, 0.17961409423620472, 0.11076953397282671, 0.19927831486828868, 0.1311830115774947, 0.16984821988209603, 0.1283145638843698, 0.10117647373267721, 0.091854861426738, 0.11200591561294372, 0.09034417434445313, 0.2393715263855073, 0.23159991679412706, 0.09170735885779704, 0.24672469875264555, 0.11876251233080704, 0.13838019312149094, 0.08498772588228026, 0.06728156469762325, 0.12837629524930833, 0.09948089899074647, 0.09102769331225465, 0.21660526253042683, 0.18740266501422853, 0.14423566359666087, 0.2705538176721142, 0.3143359570493621, 0.11768705512006437, 0.2058949396615067, 0.11010873717285934, 0.12343927992567902, 0.24221133771202258, 0.09480878921045412, 0.16721721348022262, 0.1660265749500644, 0.15467937254617292], [0.03804283847491588, 0.06777497894701458, 0.039816906585568385, 0.03924539733317591, 0.037805090748494675, 0.024868378475789103, 0.025722137502124234, 0.05283658235003391, 0.073776580693741, 0.057998406175043316, 0.045145369855867284, 0.052042922921358585, 0.06736136807669556, 0.01707619559320231, 0.0480381255188296, 0.027618745206705028, 0.06337135234066556, 0.020164098748336398, 0.09984132037648272, 0.06314849353305275, 0.029652021081757643, 0.0697688453440224, 0.04865455050622264, 0.034110976473218015, 0.04411441086220645, 0.0517036838667287, 0.01786390826436541, 0.0434374189635198, 0.02316261284924563, 0.022195260220718, 0.012928242213092746, 0.03385283548625247, 0.036666511723230925, 0.06904496886436978, 0.07735011272973592, 0.09329982582599887, 0.033617163858106064, 0.02479749810581486, 0.05653774463421395, 0.035394790447166855, 0.08114112946655481, 0.024016436993054325, 0.06576172286464323, 0.035604166107312325, 0.030033291550353173, 0.02414940495885188, 0.03487660474474392, 0.015179130151086758, 0.061055246380067645, 0.07777592738068874, 0.039568154006114895, 0.05098442306681987, 0.02199395338163501, 0.02910012942588618, 0.06561898536259128, 0.05105797516843004, 0.05676695431071905, 0.03594268886973301, 0.05384820145404628, 0.037046782447085265, 0.06484043318778276, 0.0800755241465184, 0.04907329799607397, 0.06001846511818229, 0.04213671275084058, 0.04357074124498233, 0.014118058156342277, 0.022867226582621376, 0.024311700685610695, 0.027166806957534245, 0.051091119962474035, 0.06251328406975636, 0.0510268260334288, 0.01104627732157467, 0.030761869894641063, 0.018784935556111798, 0.056264534697777806, 0.029088377637127717, 0.024095378523211808, 0.05063709412370959, 0.08846273135033347, 0.05838510437658238, 0.0065970349673842715, 0.028598881927469087, 0.0069930080996615995, 0.05696848140008027, 0.07143904725390096, 0.04836337963840173, 0.08768533596829062, 0.02453341802221633, 0.07088379438726172, 0.06555097207667367, 0.08021092252625574, 0.05536330886365426, 0.030657090134017413, 0.037195001308235436, 0.03718789201229811, 0.06329787684784782, 0.045506545838208935, 0.06692989969686156, 0.03204413062532342, 0.04799053230653367, 0.03499117702425968, 0.03097114404813657, 0.024171079501449585, 0.04410677296560138, 0.05439674339046883, 0.0048371227251576086, 0.038902867930911245, 0.08161114739073862, 0.032961312155689926, 0.018804907468297792, 0.046022234093998714, 0.04455710626057079, 0.017175386742418332, 0.03757302739447163, 0.049517039104454943, 0.0394889060407877, 0.05765418371846599, 0.009480799630945249, 0.07094234648731447, 0.07648516115882704, 0.026062280540504766, 0.04973820102731547, 0.04943462336556085, 0.12890969162746785, 0.07326251271391108, 0.007950256986077875, 0.05719086906361965, 0.07233299525274385, 0.06143688457086683, 0.019583564980195898, 0.007958526905220484, 0.005850798775246668, 0.04412238583749822, 0.03683925305883731, 0.01864118681799981, 0.0748435266676449, 0.04920672369940628, 0.04043312472922187, 0.02970245456503284, 0.023074518483612808, 0.05754173733294011, 0.05486516785177012, 0.010963197001406263, 0.048380153133503856, 0.010173323004686785, 0.007436511241981099, 0.02514434632875266, 0.027140083895515532, 0.03077817224566975, 0.04236380036379542, 0.04078908365279917, 0.006907461933986916, 0.04514863722086434, 0.0282358022166356, 0.013489079860699995, 0.06620982301331337, 0.04030948579912225, 0.020234483076379668, 0.06378858297642681, 0.0272804465250022, 0.023693628609180454, 0.02286190610198725, 0.025439324653557232, 0.03536315867677331, 0.0693234877901212, 0.05294425983823115, 0.060955735389143235, 0.03291286092491881, 0.0908010155563393, 0.058054744280994906, 0.04108636790225583, 0.021854171063750986, 0.020284412856844646, 0.01009454905626274, 0.09374028041718468, 0.02021638616438835, 0.007372340365808698, 0.06781178947177625, 0.05863624331992, 0.022215161269770998, 0.031435460362943916, 0.02428882530019168, 0.08456611705403175, 0.011467182306542752, 0.0509371247983748, 0.014703005548536539, 0.05082318071095694, 0.013935747424951725, 0.03133263221130737, 0.032122413319866025, 0.028694098995577906, 0.042108198958298856, 0.022036394652640148, 0.03772566275250527, 0.028498277346032764, 0.031154503362373482, 0.06781186608056869, 0.07980184689644845, 0.03607052596165769, 0.04814337833874649, 0.014125133935932913, 0.029306465632192073, 0.03292457823972068, 0.0237059147442661, 0.01923400863644577, 0.022637944127763474, 0.0074241145029513836, 0.017319746435649933, 0.07411057970696881, 0.07749227566584464, 0.038622931742499915, 0.02945810890636377, 0.06764225421413299, 0.055667495565308686, 0.05936911367180367, 0.07918307768000711, 0.0476517069393829, 0.04428361670204228, 0.020273904045743328, 0.05845895142204339, 0.028614197940295263, 0.015536222884791995, 0.02852459055101199, 0.026145770717712662, 0.10931180654874734, 0.0073222157117279795, 0.011845699646660398, 0.027220996186858224, 0.0019836940660869946, 0.040703117096376036, 0.02097858427723329, 0.024350041471001123, 0.030219824383816415, 0.07671297272487033, 0.03908455717347322, 0.05221518928245191, 0.03392364499309371, 0.04752322633360182, 0.05501852716289221, 0.003077954306424926, 0.013003376286266553, 0.020532035456609823, 0.04391045910456488, 0.04459587030953938, 0.09886767625087693, 0.0329909635887992, 0.0333667335460984, 0.038273921236395836, 0.05104829181706713, 0.007554716693477766, 0.050574769040629755, 0.020540069803715717, 0.06453691681306209, 0.025039913222914743, 0.015862674016745824, 0.0647123279650846, 0.02997870778574819, 0.01598093884005662, 0.022487909638232762, 0.015238026033095537, 0.057337153552761005, 0.0555225670517933, 0.03518680140616433, 0.015509819664481669, 0.052446716374927954, 0.08702122966849035, 0.05018285761076597, 0.016431526859260855, 0.06070395293194921, 0.015155572947415133, 0.006427374741648354, 0.08214865000017228, 0.051267492554841504, 0.04049898913851188, 0.029411226240617615, 0.053152938358365535, 0.05525243678881277, 0.08864676099150412, 0.02871093569293378, 0.009991583008799824, 0.04202610114589334, 0.01432977804553605, 0.034347647846105604, 0.011616325261251581, 0.04236139867815279, 0.024862267009373155, 0.02405147019383167, 0.06375004492339588, 0.027594138462577137, 0.06872095197679536, 0.06587331123169392, 0.08025927799603633, 0.10154527612030508, 0.0269678883975552, 0.06794763218250967, 0.04893477780804519, 0.09312013224247964, 0.011335728322005561, 0.05637675891780565, 0.06239686551834307, 0.03350868197758833, 0.05728113720373762, 0.08107436490395377, 0.029335370129575173, 0.07487625394377016, 0.07304747183356555, 0.02942095747247579, 0.03741263156576503, 0.08003241637901914, 0.07318591158236228, 0.039968140002700596, 0.03424807556814725, 0.06190962593762144, 0.08281872412490268, 0.0661746442558304, 0.09394478758857136, 0.021857938301118634, 0.027426706116286018, 0.026328260522155512, 0.014259397547932403, 0.00715338908541467, 0.03885887150141982, 0.06189766730512343, 0.04444846350158896, 0.03591921210529343, 0.02275757641801911, 0.01946600878821506, 0.048325856651870475, 0.00989216299081642, 0.07508482138115553, 0.032824308821751226, 0.03991637161121734, 0.08280212299958353, 0.036464823755405606, 0.054034724711410465, 0.036971851387211395, 0.03330395647114323, 0.06232561934138499, 0.04644015803933144, 0.025210515257992575, 0.06600502472851547, 0.10980194960270198, 0.01252743171437854, 0.03301611808579295, 0.09385320177722363, 0.03749331594595025, 0.05136348337175385, 0.041198664900636485, 0.04949525539432803, 0.04826375373428868, 0.15111625164506898, 0.13209387479770568, 0.12382152715637801, 0.18811777744802738, 0.15624700294386956, 0.12593603707970152, 0.12310919562174429, 0.31864792889645027, 0.3327429967541849, 0.1605958082983571, 0.1534706083757262, 0.15244630285568778, 0.13465260846480248, 0.12638886399086446, 0.12311255874773189, 0.1216941852603228, 0.16151880635128868, 0.07106744098447024, 0.1882794832870845, 0.15967359165510825, 0.1317010861971686, 0.20017909637141615, 0.17880636177236037, 0.17034605445881046, 0.07970732696835073, 0.20951893390907397, 0.19888347315211452, 0.1207682530906412, 0.12313493617600012, 0.14338285451935184, 0.08275243453681469, 0.1194294301732894, 0.129606387307567, 0.16838462422451667, 0.23309985566283428, 0.21879789810026848, 0.15064398908326704, 0.13932651089083764, 0.1368958211594051, 0.20063042941112674, 0.16601647791122237, 0.12257159342088046, 0.1308620054154627, 0.14719173642656497, 0.18353009055699074, 0.09586491802286717, 0.10973708493815315, 0.09372421555341252, 0.17662325633629677, 0.17944511056186693, 0.24210449909010243, 0.12972732194729392, 0.11427113801361093, 0.15777062925119556, 0.18235742444953612, 0.1188342028387612, 0.14990664477790558, 0.15569195692096988, 0.14271458070124352, 0.12871987036158963, 0.2009657614173428, 0.19649281917560488, 0.1603415590380469, 0.11690223634603525, 0.15668203363255148, 0.11299922521556578, 0.13505935518731996, 0.19681500511304026, 0.10263225529342891, 0.2505214917924135, 0.21276815794408324, 0.12926561607708856, 0.12014250481320966, 0.14481810492373284, 0.11070534346565125, 0.14323942753816807, 0.14064838028242513, 0.1855681908707465, 0.1672995219668073, 0.09063728724516208, 0.1983299593050634, 0.15672487326927725, 0.1739305798565188, 0.1577067988053445, 0.12155296461236094, 0.16652266284631145, 0.22979141303127815, 0.11825462668052605, 0.16881968555671556, 0.14006181740232054, 0.2957250153826129, 0.1462284727923332, 0.13158286350869364, 0.11448515999701717, 0.15807484276592731, 0.18316391585094316, 0.15381784538828558, 0.19622491822848398, 0.13463675044476986, 0.11468620445098608, 0.0991356997720657, 0.17812334842258887, 0.11694400345966702, 0.19712524007885687, 0.11337421759362183, 0.1677571522492555, 0.14469560746464039, 0.07360391979736668, 0.09318670528309961, 0.19301058183754646, 0.06168526942811667, 0.1366911837530713, 0.12409790103594143, 0.12096218058779357, 0.09247118682270089, 0.14705832987543077, 0.1695339552937977, 0.15998488382226037, 0.1722100995961697, 0.2162331889473623, 0.1199446932502812, 0.13526077502437178, 0.12432991076380977, 0.16324225903278397, 0.20551050141934427, 0.2292084047991422, 0.2284141554827652, 0.13633859944680046, 0.14233345195891398, 0.13547739404584133, 0.18039532005786899, 0.19811651188760035, 0.0708976452569327, 0.09998494654052681, 0.18479986596972714, 0.17082475215917634, 0.12360905267057881, 0.1704983833816744, 0.14447996903571392, 0.1255942163087668, 0.13304797602036308, 0.1823723478423011, 0.2255185729553623, 0.1265275412269177, 0.09158902125613344, 0.1182265189145842, 0.14390721106000487, 0.16361364313671667, 0.16768599800284834, 0.11944639902081221, 0.16418603339022206, 0.11693173839199929, 0.15593528176747984, 0.19822607778253096, 0.134494993535261, 0.12147599575860847, 0.15795982232497585, 0.15860587959328007, 0.17782959966890274, 0.18937895735425336, 0.1273413104636054, 0.12704716334419866, 0.11488042306154968, 0.14441708853888896, 0.11424769572312794, 0.10336810572733802, 0.22182596787329645, 0.18089307802579097, 0.2132638168310927, 0.12300454035040834, 0.21784732088206277, 0.177586060317774, 0.1520554141532029, 0.11989401653409006, 0.1131122308452764, 0.137496434092041], [0.026002198179823258, 0.03393146292036099, 0.039326510722598726, 0.06136893257198315, 0.04651211284761948, 0.05383896243367946, 0.03749233152296755, 0.01840898748337021, 0.05883072623081746, 0.022261526826168263, 0.04151189527023704, 0.030116368040081956, 0.0491937538308482, 0.05463908764443571, 0.05179577529610646, 0.07340160363744344, 0.0858192223935358, 0.010206142211362961, 0.03882265469479946, 0.026340876075048602, 0.02437726823583005, 0.04908129595400346, 0.05517676262365234, 0.01447056872665041, 0.04093606528195162, 0.06508408745210018, 0.03953369537128076, 0.03316702974599696, 0.03076705822510825, 0.0016832377338188611, 0.024081874308326555, 0.009802619761396802, 0.05442855519152457, 0.01914313337164781, 0.06679635524990098, 0.03203212411233014, 0.07432995664496576, 0.04809437935510951, 0.032167855740314534, 0.0628634168946695, 0.060939398564157955, 0.04336895368572685, 0.0842628381665676, 0.03026846522134879, 0.029306042368613908, 0.02399161191386802, 0.031891656145753886, 0.0037598060753812356, 0.021776564441801562, 0.1197238224408319, 0.03599981987668622, 0.025236709719343532, 0.039014873815880674, 0.02802777487123686, 0.02868761023085925, 0.025893566912160288, 0.035524263136809876, 0.02330149884425825, 0.043161619649899584, 0.03409532146648534, 0.07005029838652381, 0.015157769704538008, 0.03246653043935376, 0.0428755164536978, 0.0629439901921057, 0.045850132441809105, 0.022369064503319325, 0.06229069339291704, 0.04082622742580791, 0.02998040658572028, 0.09836510725079045, 0.05499483972427346, 0.0369166394305085, 0.03824757930311946, 0.036641108247661786, 0.045167720471058166, 0.044577193085945425, 0.044548901458901745, 0.039908404296804825, 0.032661178059154944, 0.05331445267544158, 0.01656159901270463, 0.033430537178872094, 0.07458042909180926, 0.05014837982373373, 0.030047247757113753, 0.04277370336856093, 0.0480912805294558, 0.042046593997867844, 0.03212517315161324, 0.025088567466985796, 0.04295482953649856, 0.016426474509400227, 0.07775121338425145, 0.013311159770725476, 0.06621559931626243, 0.06737352589205389, 0.003169214291002361, 0.03658053750592855, 0.03214261697364911, 0.04702697755889066, 0.021505371231826085, 0.06869609242365246, 0.018781294723251657, 0.024727607904482755, 0.04676326328227597, 0.01001457139218767, 0.019148639628603574, 0.03584398227112909, 0.06347771215763304, 0.03805079429800953, 0.012360027138774675, 0.012787173825105833, 0.043123012648955475, 0.07562295218268711, 0.03144656289218655, 0.026061397624172034, 0.08345911234256723, 0.032556135913417224, 0.0294336132449849, 0.060215866824071256, 0.05091632168079096, 0.033821211376738165, 0.02754028439672003, 0.02387859287761873, 0.050761093115133625, 0.05725407897825203, 0.03050071435169347, 0.13759558119120138, 0.03899782835956543, 0.009723954980501966, 0.04153219660023048, 0.0230023913055418, 0.02341714364686801, 0.08427888004770202, 0.02662128149231355, 0.0174695759966609, 0.0701055639693814, 0.05779677949425194, 0.07491301850325639, 0.07990170645737842, 0.05686658787571135, 0.02802294085643465, 0.10668864488721856, 0.03491059223550462, 0.06575492000387562, 0.02428450839473836, 0.033733413870176004, 0.06582893175824035, 0.016119604584791006, 0.0313185534304789, 0.011583431361002788, 0.07016031627332972, 0.019632941262135585, 0.04724911624385465, 0.038500974375394084, 0.06678379140794277, 0.025917022609181946, 0.07934282999485731, 0.024467197382041526, 0.056831075869981325, 0.0452508601630407, 0.0021184528821087895, 0.08335038914435333, 0.04912271066719005, 0.01327364061463384, 0.027167774143538652, 0.04647742821684769, 0.08015787859837856, 0.01840918475101071, 0.02098729469693236, 0.011846174621173452, 0.013304623125511552, 0.024952860736858942, 0.07064256096078504, 0.04089436328579341, 0.005690716563784067, 0.027160691660678676, 0.026008003211069494, 0.025563327475420894, 0.021402089173094403, 0.04988453148173229, 0.06184959911831445, 0.028749452678546793, 0.025890523627881083, 0.02827161108143628, 0.03382596878274795, 0.023945849651711124, 0.08465585659348196, 0.030521201458008542, 0.017243181693277532, 0.03853640594189206, 0.021713456033819148, 0.005954083706808067, 0.10068848338578978, 0.11522058908256794, 0.0763046402003496, 0.03518612724879096, 0.01962372139396687, 0.02933210851023755, 0.024737655147609693, 0.025117023802933194, 0.05779946846286616, 0.03950421630795445, 0.06224470130438286, 0.039913127228858016, 0.03455573647853828, 0.1853557853328605, 0.04458999441516015, 0.04121603211387992, 0.023666961088536248, 0.06140422241221513, 0.04272775724530221, 0.04473729397080118, 0.05151283987347157, 0.031876931935849215, 0.08841751684104243, 0.07575619019447796, 0.05291456627028604, 0.02369839942172891, 0.035226120868878025, 0.016191739423741257, 0.07360929773459512, 0.06999730042392208, 0.007765536908165462, 0.045031222755149494, 0.03871976142568934, 0.08098882352632862, 0.03454438688594007, 0.04592840364503284, 0.039102315091558044, 0.04435267952841617, 0.04679606333675404, 0.008857011580989968, 0.05824856452583786, 0.04718518620657344, 0.0035446617731659286, 0.014561309926061621, 0.018883644069935528, 0.041826236467327804, 0.08343219967378725, 0.12881247506987664, 0.05167369918537237, 0.034123685871881825, 0.03769007796842245, 0.03672335544721254, 0.05330350910944324, 0.019313448123754035, 0.09233841612454384, 0.06433116857923808, 0.010059667157850439, 0.08499941638400478, 0.026538829364243056, 0.028864597608785958, 0.019964697552965056, 0.07106902678647349, 0.03728657179782468, 0.044305189737990025, 0.03254595843534316, 0.0799298755103542, 0.018072468040871526, 0.01789671023406329, 0.01649731082931882, 0.07505782444270388, 0.012600588323097798, 0.050742071151973746, 0.03754401947521875, 0.011442721119120477, 0.05849743967935924, 0.0581514782031938, 0.03216765655745422, 0.056884636907207395, 0.10992293786858359, 0.018538002435478474, 0.03901231125177395, 0.05510697201375039, 0.02094842531087418, 0.06162593974882077, 0.027853985910394022, 0.03149939231544493, 0.02759065084730185, 0.03440879315378205, 0.027605283126655607, 0.03713331590857237, 0.023260024759257515, 0.050894403905277295, 0.07572215290800219, 0.025199083310942498, 0.051561459643586036, 0.08506228155907124, 0.023689011014216853, 0.05206905035001617, 0.018326217428811135, 0.004148057759589246, 0.07555990314651882, 0.009623050667165269, 0.07429653222882941, 0.023048749201059825, 0.011316122216803413, 0.027835009912509593, 0.05539045901969076, 0.06875553318569738, 0.03830252312904885, 0.014235975367257432, 0.037192948192598364, 0.008970091904273197, 0.04463654574787906, 0.02723921950335705, 0.007568079182097028, 0.01813470310862026, 0.03027932834811509, 0.05022460557219963, 0.04326596465562621, 0.021118334036380536, 0.04285112421418871, 0.010628511381876326, 0.06214490686092646, 0.09855116702496045, 0.053682722631962075, 0.06556336737928853, 0.06293547895526694, 0.06045451087336387, 0.04377085107168363, 0.02531962916104784, 0.02503351830396681, 0.041675244367891745, 0.06417978194452102, 0.04863018124935128, 0.04523550010015888, 0.06637707532894227, 0.03621471903076576, 0.08404897706162545, 0.034926871603895585, 0.0753368106820891, 0.05337215441789839, 0.014792047947975657, 0.026578819153890498, 0.029998940167828437, 0.04014157847831807, 0.09324151121320264, 0.006276359180769613, 0.037527885663533406, 0.04927428882388819, 0.03493470485292135, 0.06593867385339353, 0.042727171188040126, 0.05980214104056359, 0.028726247875320337, 0.0417589241518609, 0.04348157627147533, 0.01947568447869872, 0.028794312872172847, 0.08546096137574605, 0.12741657094128672, 0.1253783174099461, 0.23536621953450867, 0.13463834390765236, 0.14522019383167067, 0.1643220906055743, 0.09770718328053914, 0.12835049340801855, 0.17741084068773255, 0.2367995853625959, 0.2139659977007297, 0.18314335405105547, 0.10989205686435585, 0.10318663481983448, 0.13237959494994533, 0.13088429857405925, 0.07450727535591972, 0.2938241367378543, 0.23131343055396314, 0.21408293336149187, 0.14034173060809413, 0.2444710825840312, 0.1786616324417053, 0.12898297559830452, 0.13796397755222936, 0.10451358337435993, 0.21451500695078604, 0.1968407456672961, 0.14946137915455526, 0.08421773090958597, 0.24239415693427288, 0.17207676965382793, 0.09180619952178772, 0.11433247101282883, 0.1487623545671663, 0.15203373386494576, 0.12995163249152322, 0.12697788601320598, 0.20094585845306998, 0.2782824803744593, 0.2492046785811263, 0.22994406371107026, 0.06261975879991247, 0.12281713992237084, 0.10485124428786578, 0.10689492938258957, 0.1441123387626102, 0.11802296935310287, 0.15940990419157092, 0.1663143482179411, 0.10162753098073507, 0.145111792390385, 0.17817651492453393, 0.15114692580555716, 0.17175623846630897, 0.148261210490619, 0.0965990677415844, 0.19233959606818615, 0.11539042311450166, 0.139994248447399, 0.13797146989212883, 0.10992413296574548, 0.11385824726594072, 0.25462101213634014, 0.24713132290109513, 0.21195893926966577, 0.11514089295580504, 0.1267413793492221, 0.1176627011849515, 0.13324234784851152, 0.18781342603746923, 0.1420367767493571, 0.13506842566834343, 0.28889390129235487, 0.1520215683887082, 0.15161289112462153, 0.16714503267599692, 0.09950512269091222, 0.1176749432699815, 0.16914066107523057, 0.11280964909782333, 0.17911216874997463, 0.20712339229160742, 0.22660353731724525, 0.17144920574801584, 0.07989270492426812, 0.12645757441679317, 0.0883525985503389, 0.15920958752113004, 0.10949618859036316, 0.11578056871169999, 0.17340869011898197, 0.1257971529999087, 0.11139563465070342, 0.14483002525183464, 0.19207623036157703, 0.14519586287919553, 0.07722952282957493, 0.10162896356515347, 0.1011159987519345, 0.10627058304605946, 0.12705205864603483, 0.11321245812841, 0.11977863603181417, 0.16382615592691208, 0.12385036270584791, 0.07895234731897231, 0.06721882975750393, 0.1736910241625963, 0.13426803232681367, 0.09913834277540447, 0.17318365945210382, 0.13805313486485712, 0.17482224491334733, 0.11267198309783014, 0.07293935384481184, 0.07555753593483279, 0.19737834020728068, 0.11804602093874447, 0.11173848964033589, 0.11690831142327479, 0.15332227843182702, 0.1458469763278, 0.11247173537530246, 0.1397156069475797, 0.11042570605153039, 0.09939881266965982, 0.2538615891770009, 0.2072170082359545, 0.09345344943745483, 0.1459115881833338, 0.0842077870883288, 0.10615789917327705, 0.19336863601159668, 0.1407745702853126, 0.17724234730966631, 0.1069905065120228, 0.1302310400792668, 0.1786832514429285, 0.18808356396132903, 0.1600123250917081, 0.12671174706831095, 0.1580301491964248, 0.10647568776602707, 0.14972169583122577, 0.10043435669954746, 0.13029997267069357, 0.1935075277522687, 0.2210574131458998, 0.12952846084390918, 0.118949139010041, 0.12443779892618619, 0.10762311893725589, 0.13052382356216832, 0.1626919014679809, 0.22132437946575306, 0.1519858840131952, 0.17070138135985022, 0.13578995791894777, 0.1419611945147476, 0.11514165138285007, 0.09555695067730643, 0.2013190352027455, 0.14283623546361923, 0.10448929838716023, 0.08155912235980073, 0.1537478862390403, 0.1664756710130361, 0.10373177532587322, 0.14779012770422045, 0.12962486534830064, 0.14610805909239477, 0.10157933638941857, 0.13581076486697122, 0.07214864385464499], [0.022841208321493, 0.016745226457715034, 0.07802824609942975, 0.028890510532824747, 0.06019797101016006, 0.04961942675553503, 0.024655208765198628, 0.08986046642906244, 0.018945969153015364, 0.052677726358055114, 0.03255210246049589, 0.06107294301111853, 0.009090185762503216, 0.0056504873716602885, 0.02768018354301251, 0.01760546275744996, 0.03177145311999465, 0.006647097376821142, 0.056999967613768195, 0.025373667088006775, 0.029237366416641784, 0.04554534819157374, 0.022417080979193413, 0.07313204027952687, 0.05687065580258927, 0.06002756624272274, 0.007727174097747212, 0.04361262710224237, 0.012689405684209159, 0.08367881869837161, 0.028846609864323854, 0.047372858595824054, 0.0612058975703774, 0.05639058680483892, 0.014662870202183485, 0.05110770959647433, 0.03428964349891871, 0.0680601398550695, 0.04199936084689633, 0.019678159601866238, 0.04289434689487662, 0.07439281415915297, 0.03913359063106679, 0.07932560833831949, 0.10032379489031532, 0.0821703992363426, 0.04386676911024317, 0.02626512530109575, 0.009856763983055229, 0.06665858199759837, 0.08984810943084379, 0.030109969290694403, 0.06607179695199575, 0.08190998296824195, 0.03363055124458286, 0.02522547312471415, 0.04617398079004019, 0.07066973409945927, 0.04417230412664433, 0.009077289629907859, 0.04592668377764283, 0.024404881875060742, 0.026576988203751466, 0.010741815785877408, 0.008859151839128426, 0.049408438480308944, 0.03761418163776398, 0.01028436744931124, 0.046268964201332106, 0.07809549329742309, 0.044142357749684204, 0.04065368144262222, 0.07328797747651417, 0.013948407985510365, 0.04657433450882954, 0.024609101763475808, 0.0058995870847044695, 0.028732416798330607, 0.046586879198589635, 0.06760474654936022, 0.02080330910581735, 0.09415857974560031, 0.016505237924115315, 0.011466481336092037, 0.016274595663191813, 0.0013570828624295012, 0.09959772739919925, 0.05555417966998874, 0.02195263059899932, 0.03430533297960797, 0.03461669026423366, 0.016407234211181922, 0.022631043590785518, 0.03358689189377812, 0.0436963566819266, 0.01482102043566204, 0.0866194625174807, 0.032630373663719625, 0.016520069386329383, 0.027699343401998765, 0.025092491752377925, 0.10167826898396017, 0.054278444093201435, 0.018776481775867365, 0.02863803476605925, 0.031102185302804557, 0.04643952218635429, 0.018123048996072144, 0.11511927395458184, 0.04023407210385607, 0.010599037106599539, 0.034472734682382114, 0.014131525982051127, 0.012623965496107215, 0.04765080678607187, 0.02113028117755969, 0.0052047333672582624, 0.13025380821237642, 0.009455772496068911, 0.035834402341635964, 0.05580621110575815, 0.012154412012727512, 0.004107771589676098, 0.041615826588484554, 0.0553289536506899, 0.04505494466772483, 0.046300779832827474, 0.04610591387796787, 0.03106319142745868, 0.03826349477974638, 0.03684420198682816, 0.04782200445451083, 0.007789056765050778, 0.0415718071763554, 0.04336833698494781, 0.0298189765383159, 0.03976185167688997, 0.04315719932257649, 0.0420323409320366, 0.06699857947927329, 0.026659001746485313, 0.009276531862034913, 0.0395930863376106, 0.014288736800212535, 0.05184705339131817, 0.01872675692392213, 0.052879647982697335, 0.04860611459721, 0.03944850256366115, 0.05794975959185151, 0.04171585851919748, 0.02085855745169665, 0.031259449747120666, 0.011971137925772177, 0.11933046693523085, 0.019043235506321636, 0.013738795795718269, 0.037410049849460204, 0.04152324869327488, 0.08429998577001595, 0.026841319181145202, 0.06756888597362465, 0.036398289019181844, 0.02897158370263154, 0.021422723751334895, 0.06333856377750635, 0.029171626496639465, 0.06683962389586434, 0.015878825065409465, 0.0639225794152627, 0.021884956306988196, 0.07324224202743462, 0.044998821066392046, 0.016514787210091468, 0.032873258009673126, 0.04647571984077654, 0.005052760675279123, 0.09031095677205632, 0.019359578108114582, 0.042305976047270724, 0.012470480738087528, 0.02989185639777251, 0.0225402296130215, 0.07708625672685523, 0.033336143655281876, 0.08559642870339655, 0.004731075089019273, 0.028251754082438928, 0.043144922763589895, 0.013980342360633998, 0.021678928451071826, 0.031285751460781025, 0.06889831665302477, 0.03682336439528773, 0.040208798863234065, 0.038770564546388005, 0.025031886536688096, 0.11810356946361643, 0.04462223905589312, 0.00967305418359296, 0.019071006193576802, 0.015468877052978404, 0.019317301546013164, 0.01458897719144701, 0.05009594493575635, 0.018767937980291825, 0.08903638564891393, 0.06567871723804744, 0.024251585766192407, 0.05325446033009118, 0.008323629566979024, 0.01380696134161084, 0.051751215791990685, 0.033624813246030005, 0.04778259306124622, 0.025202275982366937, 0.043491573718887185, 0.04578355940118913, 0.05453017675468037, 0.07444205829092572, 0.06924413640292422, 0.08215627257501887, 0.08588158195057223, 0.06013827360866051, 0.06616029542900863, 0.03890545730809531, 0.041005369426021655, 0.06654881691980748, 0.05867978392709648, 0.05974147453783982, 0.028322460167410395, 0.0363077910526866, 0.02950899246629448, 0.04618447236416321, 0.011177240052230416, 0.050400185263565475, 0.04377997517886181, 0.022562725784917994, 0.05768838188340587, 0.03438260443809052, 0.0003653497251141216, 0.05095044323693841, 0.06476110478322353, 0.03715248725887749, 0.011164871562692908, 0.05459424085734833, 0.0700848566127881, 0.06034008032011409, 0.03848118632430992, 0.038698130933147286, 0.05467749163207989, 0.012251502165811197, 0.024473950447094057, 0.0446539321133206, 0.04165416928909479, 0.06247643524059846, 0.028971260030483528, 0.03597263524669313, 0.03668859420764831, 0.011777712216210223, 0.021563021263348, 0.029532365808864276, 0.02252589802317802, 0.06983738723060778, 0.019143686870173104, 0.05471952687648516, 0.02663375531894065, 0.03679277833491083, 0.023248968195290338, 0.011652803495376101, 0.046924769938472784, 0.05103175580922154, 0.05687482332089736, 0.01974893846519051, 0.02249784388339087, 0.024396091016129624, 0.04171996858091124, 0.09796123335798902, 0.02365032931970012, 0.029664052492608468, 0.037268970927764336, 0.02177787062171246, 0.047803277435201796, 0.03988569362028953, 0.06333576755658274, 0.03732723957528511, 0.035213154830759576, 0.002035427385107464, 0.05955735679655787, 0.0365205911258536, 0.05250720667742914, 0.003582838567860064, 0.06703565813480847, 0.0570023118428165, 0.01315979420342633, 0.052917967700669845, 0.09693997686788922, 0.0280365159344529, 0.07826332017899522, 0.03970424952586332, 0.0859029251601427, 0.02844582139063747, 0.018939692977695696, 0.05336740467276785, 0.04681455286880655, 0.003008085890718165, 0.06512202412611054, 0.057191022281204505, 0.058379006316705104, 0.019799601774842992, 0.04424381077349667, 0.04710653962026681, 0.08177413259662929, 0.01990085944623476, 0.04868406404350554, 0.045128466125818036, 0.02110944741645888, 0.025486362452108054, 0.05955683585676936, 0.0073954652086080565, 0.016788219312025655, 0.028662666408044678, 0.045210383907561345, 0.03085026878022379, 0.06291214008665373, 0.05440241627154812, 0.02481302479282022, 0.0862279762664149, 0.07084934341330683, 0.05977008409137207, 0.06922607971054894, 0.03238958839867865, 0.07913404039197391, 0.01563977403190708, 0.06789361532296866, 0.0314598698394313, 0.09864022474615805, 0.0675116055795262, 0.016898723664663492, 0.04974860833176682, 0.08400774620954068, 0.05894339861228101, 0.03672629339440215, 0.04362515263980435, 0.008996608122552355, 0.002553809876365948, 0.012019115139640147, 0.061002508887360175, 0.02352105964335703, 0.02115380199205491, 0.06079713603661907, 0.06676143696231228, 0.08387666090481705, 0.24201322737480366, 0.19796566917530953, 0.17943721985624683, 0.13192247028552717, 0.09725123073064512, 0.11361680699572449, 0.2739406310983243, 0.15530641551219648, 0.20559444933408694, 0.10031172900550789, 0.16990953755955543, 0.12126029604264807, 0.10457289390145771, 0.09519128925016812, 0.14647852389081834, 0.2195945835762447, 0.12992348642118517, 0.10491956400895312, 0.0806798066403116, 0.10148287059799319, 0.20900300433558805, 0.11713962401113204, 0.09652366170719748, 0.15807341784238815, 0.12108874597376394, 0.06688080112179441, 0.1740275819094912, 0.1347835482128205, 0.3039490305367978, 0.23348222546760114, 0.21173386263751218, 0.1616166204574608, 0.13670956986325403, 0.10762265162362207, 0.14681690492697302, 0.1834790231359582, 0.11212590796452378, 0.10152411677183644, 0.10662222506418344, 0.11399791275541629, 0.17119451215670956, 0.17805204095859684, 0.1425059902812204, 0.19168742541824618, 0.21322863807360973, 0.17446009982978145, 0.11989813042624343, 0.1328982364746832, 0.13592411523624776, 0.2969542800659134, 0.152571696127134, 0.17898328211759368, 0.10208703817859774, 0.22333123871395666, 0.1536238412823408, 0.0948793535691596, 0.24220980553617402, 0.09204416175282772, 0.09598608248897138, 0.08781623741191241, 0.09339734115788052, 0.1415914345172144, 0.06996621257595478, 0.08601756255713203, 0.10904972786985098, 0.13770228191729517, 0.08379730951762007, 0.09026757321290432, 0.2076752360669836, 0.16823201951, 0.26681279583323386, 0.15170773280964744, 0.13902530044076905, 0.16723668743525782, 0.04388146267663087, 0.09244461123260761, 0.11846405213638661, 0.1242183453793968, 0.13974804311029373, 0.14759929520228218, 0.1876756834286836, 0.19224282384159105, 0.18069328229513862, 0.1157084798380252, 0.11673869189595985, 0.13804351280052818, 0.20963735578040923, 0.13963720550940883, 0.19064902388040098, 0.09508020650114744, 0.2286420053532047, 0.09858921861215945, 0.11987933828946083, 0.15445699254351278, 0.11951071210205556, 0.19395627141479524, 0.14315647553772698, 0.13982518816426878, 0.16929548744472767, 0.13346642856636357, 0.19903782454709854, 0.16282277992896496, 0.09263769603304325, 0.09195987675939837, 0.13051458454180148, 0.12080601356442898, 0.15846311144771116, 0.24489597026859564, 0.1274115913697789, 0.13772941675157319, 0.19552551059713288, 0.15663692637556986, 0.1457830999166735, 0.18598020827818304, 0.06493381930575257, 0.19412321729525445, 0.21395668207157045, 0.07492870032306641, 0.12334382537031367, 0.20802346899384455, 0.22499691304420272, 0.16390228974482707, 0.12257628187897707, 0.1562125902743109, 0.07477768907143224, 0.13862016250289258, 0.19450426942879157, 0.12907683669078734, 0.1118926418524596, 0.13172138752716203, 0.1651761713888376, 0.10708247536733266, 0.10959777951000199, 0.18675815524353137, 0.2877983955606338, 0.15666502648063246, 0.1268553655714758, 0.15124778894166793, 0.10369317981624797, 0.11759959086174927, 0.13793089787565893, 0.13738072417195768, 0.1170885565900995, 0.13117325161733936, 0.1495869716088618, 0.12654434919597643, 0.1123193298436461, 0.16837523198656498, 0.16909746903805964, 0.1342174398802942, 0.13413215897256328, 0.16561011423266706, 0.09458665435592975, 0.2179394965811122, 0.12121875875539358, 0.16230991470717615, 0.1308531647608165, 0.17512575362718877, 0.29244456560381, 0.23263556041544486, 0.229374707165745, 0.1787010246827718, 0.19238263488777224, 0.10889376002934673, 0.18542251159106532, 0.07876012053701185, 0.20296417837662084, 0.08535158700279652, 0.10123020713968624, 0.0997381053504444, 0.12978244963432514, 0.08851945250024719, 0.1145733826823773, 0.20326626216692312, 0.17584947688925653], [0.007195589996333565, 0.017149627035964402, 0.03729840402581519, 0.09197323733279783, 0.011906519366969025, 0.06860818383434127, 0.04334746108901116, 0.033851215210292614, 0.08399375744404332, 0.04187823851562796, 0.015526123930730168, 0.05659865245463387, 0.012003409379582492, 0.03442768871243443, 0.09240610765353327, 0.06422157970166976, 0.022980031114251866, 0.026236734082621914, 0.04660401658545579, 0.0628016012600593, 0.041241879920445146, 0.029229988989930962, 0.053296476422298344, 0.08356160724595671, 0.048474002734667836, 0.0061510712464129735, 0.027907983617736932, 0.010385721839303452, 0.0008123817796360762, 0.02295887942666248, 0.09776852394063627, 0.04342928310976394, 0.02197870823194183, 0.025791652320373445, 0.019255616146350102, 0.0430431594741681, 0.017220358018793406, 0.03610016207300848, 0.09262312504072344, 0.024436385325726964, 0.03135004155938664, 0.03517430268167969, 0.03547159842245522, 0.034563742097347014, 0.06873238966950486, 0.05080494015747982, 0.041591959119203596, 0.030505366420613664, 0.024700645439987703, 0.02536206660161336, 0.05779143603098008, 0.043033395683573145, 0.019268993956727848, 0.08008329993894986, 0.002332536870756397, 0.017385896212691744, 0.08783290748514476, 0.04543621130588074, 0.025221024069093892, 0.016178646981115305, 0.044312521199425386, 0.06063977391609262, 0.0876872128837051, 0.03081747638662496, 0.03753390328417863, 0.009087555208093217, 0.04672751761972905, 0.03638020934416883, 0.09429980039356217, 0.005488085829006929, 0.03456635062672919, 0.01356377151809753, 0.05912273213447583, 0.031710219712206916, 0.04561047715645644, 0.014677468007580649, 0.0394462923999996, 0.022898352734984893, 0.037496774832928376, 0.044099001003609556, 0.017760808151515744, 0.06413936314563598, 0.015394465975283135, 0.02337865730477197, 0.0611742198347084, 0.059333195639473785, 0.04459236928772542, 0.07529449198515185, 0.013397612792980528, 0.004785823562527977, 0.0753396375465297, 0.03445804494643404, 0.004842408731835144, 0.058060095405146006, 0.043256940139878186, 0.013568730979797342, 0.050059712807377504, 0.025063181228394953, 0.03336345085934286, 0.02297313823815315, 0.05392150840752068, 0.04737381237528978, 0.021783599044166265, 0.03509645282681431, 0.1010622883275632, 0.031979972676884745, 0.024670745028303038, 0.023889662848124583, 0.041183461885779135, 0.0790442089219728, 0.05439988052051875, 0.06640633988764978, 0.06489755270341713, 0.053345559675606995, 0.014709553685069326, 0.008380939646984541, 0.023233669419442455, 0.062005168593098084, 0.01555621682200581, 0.01187281054069078, 0.027591284785059192, 0.05243756928511205, 0.004839353477432123, 0.04188008095708586, 0.037915192904972264, 0.08137005952096756, 0.04412381842191662, 0.0812146662464065, 0.03109596275363959, 0.06624933782844775, 0.014618355705733261, 0.03864510232702859, 0.027064626150193716, 0.13670282828952038, 0.07143013765134158, 0.02861836354338354, 0.031219304824668555, 0.06924408277676952, 0.0004969407974943264, 0.014138548135487063, 0.012915804775642052, 0.024259807804839748, 0.02395698857013016, 0.02883518557815302, 0.024112851073544835, 0.08575008295836949, 0.0661122004291223, 0.029436170063432188, 0.042621807285374215, 0.010102316230205039, 0.02898090699267003, 0.04000221559357259, 0.06849468790835912, 0.01846283197312826, 0.05972260579226479, 0.0059498391009026, 0.07989774578280988, 0.073560168516011, 0.023273387247876778, 0.025446759536862377, 0.04142790905109817, 0.05212736879325202, 0.059904069038889105, 0.04399979644785485, 0.06854649077379896, 0.04789733388010533, 0.02896913222127384, 0.015673817064042295, 0.06321175324340021, 0.03681489529328481, 0.022886101073855837, 0.002715826699239833, 0.08872536927341454, 0.022228318829870513, 0.031006313229520476, 0.017443322163495808, 0.06963618189817475, 0.0896149275884513, 0.04008945385595003, 0.05316822564289455, 0.027827101969911207, 0.04686404597915469, 0.042153076388903206, 0.03034947901934145, 0.006203039778366445, 0.06216483663827662, 0.014051880608613213, 0.028241555536946947, 0.026549152399022734, 0.03133733024550302, 0.03895872340147053, 0.015025473980894013, 0.03336236684493, 0.0030320563030639485, 0.034771378737904375, 0.08676897989766252, 0.04173094279042656, 0.09667494875048438, 0.08551467946099658, 0.04769077359308158, 0.01574906126235522, 0.010708773456093286, 0.10332064658042886, 0.025207990998282068, 0.008580228801996959, 0.02482445099421086, 0.045340067271383545, 0.03464641447569575, 0.034515838619441755, 0.017967010292434887, 0.05384212254636711, 0.06406306078837765, 0.054688596076542334, 0.042327663996407104, 0.05387820528760072, 0.00851279391246217, 0.020606545168125344, 0.08155128528033534, 0.03645597160944054, 0.059566323855711575, 0.026514113452585957, 0.019586585281837373, 0.03157569467270326, 0.009382186878112056, 0.011712357255389855, 0.049936288381896676, 0.03384683318736573, 0.00438187928539851, 0.012399432786379852, 0.06649189658703343, 0.0843965128484753, 0.04048565154775016, 0.039494218860542586, 0.08424769260830457, 0.04071947690399905, 0.006833456882891516, 0.007362385053232673, 0.05066432471897814, 0.056582878704272935, 0.06292245163011455, 0.03523461295351867, 0.020132767667453137, 0.0738656001105424, 0.03742123856359432, 0.03189311362802982, 0.02599734309760313, 0.03650196752841434, 0.05075911277784936, 0.006766960929868924, 0.04027953942216212, 0.019459221249205932, 0.018626138935947133, 0.005628904759613497, 0.03625200069960087, 0.07462018139420018, 0.026628107335718892, 0.05202657843549406, 0.02776291720839518, 0.06039426954943807, 0.03614524634735238, 0.04036406956372723, 0.031137365975507328, 0.03770976259763684, 0.02867573203759328, 0.025571511209672017, 0.04823997053467939, 0.011738779627898288, 0.033830094166220195, 0.039067982861231414, 0.01309376412762269, 0.016304206876685063, 0.040045445935139735, 0.007787630883901711, 0.04375781225521238, 0.08957906701271573, 0.07764320264780715, 0.04758876898596364, 0.07874925741024556, 0.024695133437372507, 0.021370928546774293, 0.023340303112842867, 0.04013310937631515, 0.022212257796537974, 0.12107258917944086, 0.05243730881521779, 0.027633712649525657, 0.04443994077343134, 0.045426662019904585, 0.019465233124191725, 0.029812215812384125, 0.060384743246099645, 0.04913056306841393, 0.02125155864163272, 0.04561488599246068, 0.02339229941548359, 0.0500954891134414, 0.0566200454599194, 0.050315540208811724, 0.0091051273498564, 0.03045179772250835, 0.1374029713652788, 0.07901027122692716, 0.032797698757701346, 0.056136291579253254, 0.042024917540050326, 0.045971978726165916, 0.04157628112983319, 0.05655737946771326, 0.014467371267176446, 0.10986829281694467, 0.046931496190447966, 0.0360103574160847, 0.007514157125936642, 0.04095491104488892, 0.03890646088327612, 0.044123557952022364, 0.04427328600638336, 0.051505661629621065, 0.01685067463005262, 0.02491357191766222, 0.021982550162882097, 0.05504875699238432, 0.05325764725585619, 0.07198900645298344, 0.05778044649970628, 0.0343782339064825, 0.03020372887652728, 0.03586643247775013, 0.03390036358107482, 0.02350146502947375, 0.022584356277460055, 0.023416308611030542, 0.010079495428550628, 0.035246839716790185, 0.013030301403975295, 0.02301199804811228, 0.05063871823010906, 0.026127430572805387, 0.030673189471746166, 0.03001249800886839, 0.09591839095998196, 0.03474253552755521, 0.05288841968943035, 0.018682339146072348, 0.03580385075521565, 0.09939731113732823, 0.015518129803240301, 0.03458606589946055, 0.09433088824152948, 0.07473504861756679, 0.032561299346026876, 0.018950178806159287, 0.15354183923092582, 0.11206317302440444, 0.09159806875451919, 0.1635671875649883, 0.0950058346854583, 0.23370722549096232, 0.2455355923983359, 0.13802711851894855, 0.15987930158453603, 0.11275956226933388, 0.05053258057863963, 0.11973493071573398, 0.08496782291800746, 0.11900579887292079, 0.17401679539151732, 0.14706346266452344, 0.16497364838517484, 0.17829721973788354, 0.13863476413872935, 0.1533678913068387, 0.11132139306996139, 0.23454478941857818, 0.1830951824423767, 0.1932265879886766, 0.10365176510306136, 0.05259733309128112, 0.14067770612816657, 0.05588037224726812, 0.08375660726620306, 0.1409892127999375, 0.20353750325739386, 0.1356898455490028, 0.0989709219204322, 0.13000015650064717, 0.21872545682614852, 0.20921856615572207, 0.15971958757408206, 0.2884698869480241, 0.14703474968912142, 0.1121148533157764, 0.13015207173603197, 0.1509185243518122, 0.1253306590801766, 0.11950272180500532, 0.11775835492317716, 0.15805480190582816, 0.09715477260009897, 0.16140536405146122, 0.08551421214736278, 0.19067571438368291, 0.12688139723914285, 0.14927047004382457, 0.07918038105051364, 0.11246162301470196, 0.24267013244811567, 0.13435728156999235, 0.25714375499275427, 0.1296047632011675, 0.17384212734478136, 0.0941221752474385, 0.10165593752096738, 0.1322163262915227, 0.16418978722105104, 0.23011016689481276, 0.2572313954512919, 0.1553192857893244, 0.16016941908146107, 0.1425003518740977, 0.10874335398717273, 0.0734741521638728, 0.14687592434065957, 0.20622181405703868, 0.13970065291129774, 0.10520094810354133, 0.11990241285774017, 0.08631574695989971, 0.11850203477567244, 0.1987924772284685, 0.1095833540743878, 0.09549364117124388, 0.07299726243100821, 0.10621695689135983, 0.09128235626004397, 0.11736053312497756, 0.1220822164548501, 0.1494738051006871, 0.24834728829803007, 0.13069902787045126, 0.1531909096745714, 0.0993853678265887, 0.20216065939636002, 0.19267218547963327, 0.10957815999826116, 0.1687504158866021, 0.12065424388574979, 0.11755994581166776, 0.13851384482076093, 0.08543738885031593, 0.14004317082224355, 0.28309918158958036, 0.12585152225989488, 0.1462913686109166, 0.12642295490349495, 0.18341232752127035, 0.2347283287634773, 0.1702777500594816, 0.15225119558313202, 0.2793626337041778, 0.10431152768433095, 0.145333253087536, 0.14057097475855582, 0.20095443863782192, 0.12314486467549879, 0.1767339407195968, 0.12609187468525865, 0.13569848702078866, 0.10543426018088095, 0.1236712436882719, 0.08438404093706801, 0.1183465189270435, 0.17040827612002052, 0.1575734995065197, 0.09413945819101027, 0.30994170735920634, 0.24958773786502503, 0.17835867531116933, 0.1389083341364899, 0.1828976849754972, 0.11294399027622516, 0.13941862530285312, 0.09556396804269283, 0.15162390746897267, 0.09276362556603648, 0.28600820129917515, 0.1740395941681439, 0.23265717941666805, 0.11808293871581556, 0.22318796495035773, 0.07245193806386764, 0.14323069413583125, 0.1136089162901044, 0.10632434709658546, 0.07069974942433258, 0.04786608898411355, 0.10318698722027964, 0.21073656937768384, 0.18988498907175758, 0.1667981633856412, 0.13588193443513688, 0.18446362997976043, 0.1438760772467621, 0.2046351693570614, 0.12642942068557586, 0.1137095342780794, 0.18630144426659231, 0.1400454690860164, 0.2549499549692677, 0.17839091229102305, 0.14212881455258017, 0.11448358951677239, 0.21609904695182078, 0.16020743236426385, 0.1016297909401117, 0.17187381764092755, 0.12034091392471907, 0.10887790967019335, 0.1036565684743466, 0.07745078434386561, 0.13993764987155316, 0.17471064122453814, 0.09645891195583729, 0.12616382566310708, 0.18711631666989098, 0.14271658785160513, 0.12102363616107933, 0.08347837945386287], [0.05396848874947718, 0.04806306168076493, 0.04033792681331116, 0.03798543550674954, 0.07294621033173415, 0.02039001999242652, 0.02274664434333963, 0.024816845656342568, 0.01874582102191785, 0.029786910013025327, 0.04932154495749743, 0.04329662349435591, 0.056256751244467114, 0.042316735752167246, 0.034544352411983476, 0.08042931887170962, 0.006518363004415146, 0.06051286762099593, 0.050068951827744325, 0.031202041033294894, 0.03320640666530498, 0.03919926734881536, 0.03934001302226417, 0.032508596327276, 0.023719648785528638, 0.02855830033490014, 0.014040508990987174, 0.021441648038284435, 0.04709507511447995, 0.04621521930300421, 0.06103531277227787, 0.018174890165908203, 0.048474301508958303, 0.06382931970180043, 0.030367323122317755, 0.02344055912427364, 0.014293162873195065, 0.02671930627266486, 0.015256030056926032, 0.06562034133821726, 0.05925450691833131, 0.0597951083534187, 0.020094855891300306, 0.06993451185764805, 0.07699736754500097, 0.015137454968005901, 0.05604155331609711, 0.025736344602680015, 0.08473152309776315, 0.019493145537712885, 0.04459830646913859, 0.04910685264715745, 0.11691148302728131, 0.042149065918619597, 0.015970478867060475, 0.06619196550379838, 0.008742003588967266, 0.09677099319355142, 0.05947259299817586, 0.031804527050905654, 0.0061320224701757395, 0.10304340702151099, 0.03991021992518537, 0.0698506175690601, 0.047451635417077816, 0.06597772901577335, 0.017689584957195387, 0.024547876016567313, 0.028344996558922916, 0.027237193200797327, 0.04299867274840513, 0.03389311638931113, 0.08118696450706452, 0.009777561983003492, 0.01396615728510604, 0.06439614049609631, 0.06786362298073308, 0.07921700005329425, 0.06170945099344658, 0.01738301763731626, 0.008367679622625152, 0.04955289201931127, 0.03584111327185266, 0.021378009114414457, 0.053897916729892456, 0.05171580337769082, 0.04696857101554352, 0.07431583764452128, 0.062029422936780806, 0.0354548977057059, 0.024198612701448224, 0.01383577773888265, 0.015001172714325932, 0.046634778846055276, 0.05124684265484253, 0.011218498675002447, 0.033235184758180575, 0.009661836741161684, 0.005251019920838336, 0.0474829530914224, 0.049029669288786194, 0.004629805447503684, 0.05867755844167644, 0.04001405931288197, 0.035787954430786834, 0.009534441107403367, 0.1008447116961883, 0.04041345925220559, 0.09374485396209264, 0.06444571404567649, 0.03528538926113998, 0.07050231324448701, 0.06983323503405818, 0.01727291548083867, 0.03254493187752462, 0.03275088695508819, 0.026749400121550408, 0.051530302847705545, 0.015354968397127045, 0.06459797402062724, 0.01933029631242877, 0.017502506286086097, 0.08860144689078293, 0.03046198286146166, 0.07023853385039876, 0.04070783236754998, 0.04286213672810024, 0.008399514406318627, 0.06457406441651045, 0.035522137242819996, 0.07478931828612283, 0.061734394816261154, 0.061179333471602974, 0.07097853648085749, 0.04645378291306477, 0.020380049358092008, 0.0475179250051658, 0.03466986442705797, 0.05381102703752057, 0.05764982850861646, 0.06973527537118043, 0.023980620467374404, 0.03849919705140976, 0.015468448043740807, 0.036835855458893126, 0.018606701370088324, 0.03407972391634699, 0.019722186674874638, 0.025803532428859223, 0.08334806023706352, 0.09448589081124914, 0.0031063883779420248, 0.030144113829479586, 0.0631246988421246, 0.044354851387681506, 0.013677361289850407, 0.04690523086596401, 0.02563824321353628, 0.011074108338253874, 0.026957906271901824, 0.06758084460612267, 0.08060112174960875, 0.07279327619941005, 0.04368253645577258, 0.04648947111901738, 0.021943732487758803, 0.06113586181233968, 0.03713419307924567, 0.0364424156836204, 0.02040616146499111, 0.0658372438122188, 0.03549340894565948, 0.05390216468743259, 0.05398902756672713, 0.06901981053693641, 0.03858842714239032, 0.04398509139014829, 0.053220170234600385, 0.010678985084767544, 0.04068686454106243, 0.04971967319086675, 0.04529683309937677, 0.04231374800926255, 0.029160947230974996, 0.02834279597136042, 0.00542815333427561, 0.06062984158615432, 0.05941587184826213, 0.047744085651732264, 0.03980164994455634, 0.017119648100267497, 0.056505438706447045, 0.04461361673630534, 0.013761830144381572, 0.02895257131557071, 0.06499864566590517, 0.03603422488536566, 0.021519275727651773, 0.026807214861976045, 0.009900489408943442, 0.0056111482779435335, 0.02251403898211016, 0.015592731445306733, 0.01108977483630541, 0.029262216393685633, 0.04567080658049353, 0.004891026586729793, 0.041017228467089516, 0.07567469376109301, 0.03729545075686709, 0.021449758994182753, 0.03513833485363472, 0.018595830582442786, 0.025645369746451898, 0.05332387555691023, 0.035567593069807175, 0.0646793095755481, 0.10301966595673755, 0.06148790219618429, 0.09364084986549231, 0.06678502480950087, 0.061381952236256296, 0.04881382018568055, 0.015009995174383926, 0.016925515674595392, 0.035389573388402505, 0.05861027293928689, 0.06101477012458829, 0.06314557090762161, 0.02469057904466266, 0.03377847133144256, 0.02913597467986326, 0.0883898763887344, 0.04508661091207497, 0.010139855496104687, 0.0048581662028276875, 0.05193237260344529, 0.05368340445021468, 0.04163383348514477, 0.05641533910567242, 0.018998442345388958, 0.025883914204314355, 0.021526892556838935, 0.01093221449052855, 0.050243018495459715, 0.06739892936762303, 0.019671984933196537, 0.017647842741421154, 0.07760223992649587, 0.022748973250629443, 0.026334073214280992, 0.04136324739984928, 0.012422866458373686, 0.03848543811228968, 0.006574036050287466, 0.011870649215134402, 0.04796960661488195, 0.07540834797245842, 0.07572416771924304, 0.023771660409927852, 0.01280132634189701, 0.022919437389880903, 0.05860319045642692, 0.06304200731157776, 0.03688402323713226, 0.06373299563664102, 0.04195161824745517, 0.029882025574484182, 0.0603298262332476, 0.044294993107717846, 0.06281447919806646, 0.013564320228573297, 0.04814760714408852, 0.0842017196719685, 0.032654486281136354, 0.08317872416228057, 0.03065919113014975, 0.01274417139469616, 0.07505973200163535, 0.006284574037342663, 0.04647535977945213, 0.01729237028367577, 0.05121038836096564, 0.0450093547753509, 0.033735505290209286, 0.028189932702169306, 0.025654677714731906, 0.06283740437920056, 0.008386835651171785, 0.10875984019930325, 0.07168519896485152, 0.03639350480009471, 0.0076043395599680805, 0.030971078930663008, 0.02255322820987673, 0.023345160110282804, 0.05921937412612381, 0.05509153917251576, 0.11341906438070921, 0.043624884509030855, 0.04192130414829139, 0.03102095891541291, 0.0681912558033101, 0.03367814828731841, 0.1125969141421299, 0.050961030572051966, 0.10429408386229508, 0.03299122405869346, 0.06417130135119924, 0.0505153589221018, 0.0247354373230689, 0.03935335061302589, 0.014552503745372017, 0.008413530942503243, 0.04777606216169173, 0.020121180587598396, 0.09916814359565897, 0.02329235366966215, 0.025044482937383077, 0.031504243567225435, 0.031657606708787145, 0.02091991534877208, 0.012859526999114503, 0.024300010183886177, 0.0693715061812151, 0.052647182432514046, 0.03808204302444093, 0.04134820909389565, 0.08021144346604425, 0.045266319817352685, 0.02242102824722327, 0.0387489800191214, 0.05744435989688482, 0.03540538927359927, 0.05912431793647909, 0.044718294990279024, 0.07548019935887668, 0.03499388897551164, 0.018156048233410525, 0.03234538895588729, 0.038910371762129574, 0.0321424177907888, 0.05370388581087032, 0.024831012537282322, 0.08060316720436658, 0.03592155250390211, 0.023156315606508045, 0.030649751011702805, 0.03730564738713926, 0.01590395179171596, 0.05345176627498962, 0.06016475726820289, 0.15141130274822637, 0.14414393222860752, 0.12481459927174354, 0.16276952149646898, 0.18658719506234894, 0.14304482588364234, 0.13658357904322688, 0.15225701785135656, 0.06904582688284498, 0.10172676234956711, 0.1498670993192542, 0.15463523055997588, 0.11362863539327538, 0.1925165930222119, 0.12176282673833833, 0.17010502787607332, 0.15764613996349996, 0.2713754622926635, 0.11951916971273961, 0.1858199120409066, 0.11666271129562972, 0.1440547136289458, 0.1013381029629419, 0.13223786868395346, 0.20507939310083467, 0.13165763369010341, 0.08910196277523234, 0.10842646171729411, 0.19504869747306072, 0.14233040292897534, 0.14758193564991798, 0.08584346141546004, 0.13922736379167727, 0.10008899660240259, 0.18598143401886189, 0.13979719531151558, 0.10762404590364426, 0.07660146862749131, 0.1279583406604586, 0.1557385810320416, 0.1823869341563794, 0.1563098068319021, 0.15423067484892186, 0.2661324484694389, 0.19274923860305743, 0.15555517958296886, 0.2006801791609295, 0.08375259296547982, 0.14450226219431048, 0.08971110226646548, 0.17137529358508127, 0.0913456121399518, 0.1803178838904827, 0.14389544394948792, 0.22576660158172732, 0.10966700321483998, 0.17299792909574124, 0.12240332220831227, 0.12749641262475522, 0.15696516440760705, 0.11638207030632805, 0.19943537821452464, 0.09391120995485014, 0.11570232815199322, 0.08063371879078689, 0.17104302593056234, 0.11916922840980754, 0.13791343107098533, 0.15747400000691414, 0.13673108161216782, 0.11412299959169281, 0.11613047937111509, 0.1852504942085474, 0.14981506662743707, 0.13270381868125933, 0.20431249312335448, 0.1566577333235933, 0.1303411422357444, 0.12981551398913707, 0.14868839643895626, 0.18620666386860033, 0.16370874529163684, 0.1776900644143743, 0.13164749068598594, 0.22659921658135232, 0.07456776565842091, 0.17857321057348483, 0.22081064090373057, 0.14766988254362537, 0.13085045280956453, 0.09436243574225134, 0.07421050821581195, 0.15852381625483114, 0.1448907607024716, 0.17332530910930327, 0.09026683776849702, 0.09373474926237138, 0.17431704057080133, 0.14604056674626567, 0.1579320746203584, 0.19370283420768478, 0.11727006580199927, 0.16810546178490887, 0.05894470479219191, 0.14400059717797464, 0.0943900072466462, 0.15919805023699038, 0.09583244355575693, 0.1478377477295937, 0.12391924167111998, 0.09176709839413244, 0.18119208214263763, 0.14632717556049749, 0.15111501058263166, 0.1581903841466673, 0.07914525591918538, 0.13778031563326237, 0.10078957634827784, 0.183758185575566, 0.13492328265020925, 0.14441135820121537, 0.13754740958252262, 0.3353876854863859, 0.12541731128529196, 0.1764373574405909, 0.11987893992374021, 0.1860581653853578, 0.11217131399579587, 0.1776603708464292, 0.1110150651525586, 0.2039224317958278, 0.20137422417681064, 0.13864441684657527, 0.11460280811954891, 0.0883826828231254, 0.16694267821167746, 0.14539420304279174, 0.12256244633106456, 0.16738820430492202, 0.12079349568774625, 0.13589688847141881, 0.1687577703306752, 0.14778156284122698, 0.13352388516068459, 0.14677610308412584, 0.13966870704485526, 0.10805880080067343, 0.15381309564315504, 0.10080360341817142, 0.12444607267576842, 0.14945679794876807, 0.28597096942605515, 0.17129441002203574, 0.17779060579355688, 0.1387249020439002, 0.12620099624919315, 0.19173507608713644, 0.07123470096097839, 0.10011315135465515, 0.16386819883219658, 0.2110519677761101, 0.20446214073848343, 0.2487483353263909, 0.13228846113047293, 0.16192981252266517, 0.09588544151835865, 0.23450263926098425, 0.12891578968734513, 0.1467837026763347, 0.15341082287411537, 0.16753221351292827, 0.10829604290906461, 0.07943862928978859, 0.27636618804066415, 0.2096737143132956, 0.18360803234240702], [0.04041776083590042, 0.019701149900473898, 0.025927441404952158, 0.029626376288492354, 0.02612947985800284, 0.08010655836833101, 0.06133733144510658, 0.018209578627119624, 0.01678945845924318, 0.0361257953749549, 0.04909523492378574, 0.018588918554145965, 0.0742500000483086, 0.026747009927226652, 0.04048291661386048, 0.04227160551254788, 0.035890817056379976, 0.08833058884427433, 0.03416788914511281, 0.05392292950062021, 0.06200141476226911, 0.0060215789257668925, 0.06856201937602413, 0.04893226120921393, 0.01859371426455196, 0.027561928295800765, 0.024620868873992757, 0.02601446133227118, 0.042201225014944235, 0.04261647531342122, 0.06639297165337109, 0.06348727676536768, 0.026813680644056974, 0.0496003779792978, 0.07303728286417262, 0.02220822817405626, 0.017857860000203216, 0.05839573384653177, 0.08907812211902873, 0.05515138596116055, 0.05499192092928195, 0.020094846315201254, 0.02217193284342366, 0.07916905827099278, 0.04394070042537586, 0.022478000290932196, 0.017040765941924146, 0.030375351723764214, 0.04190105644445266, 0.0759023827530684, 0.10167038593921932, 0.04914777323363289, 0.04509711780795648, 0.06346578416865199, 0.0214321025827479, 0.025793038939516393, 0.05580141156491253, 0.0247918137334167, 0.05799582445873849, 0.07396552861938555, 0.05881086923182011, 0.037500084332761266, 0.02241439201057919, 0.015313681046057855, 0.07785895598992225, 0.020098588654711362, 0.039223939210416815, 0.0690690623295884, 0.02744246262966866, 0.035482549649332805, 0.02037518661499264, 0.010846721951008565, 0.03767534226719891, 0.03639665342146351, 0.05610942104530912, 0.02730008710416094, 0.022875659295447895, 0.08108957941012998, 0.057509477370448654, 0.027781257353302453, 0.005775386995200309, 0.0469078776997424, 0.06103500633710816, 0.10238036558392549, 0.01606178409870594, 0.020406584728569276, 0.0821378788039569, 0.007904216059438524, 0.06435320126794039, 0.0478902590581246, 0.024408396303413377, 0.08701482517344337, 0.026773859393752875, 0.01388077678594498, 0.03540207211288714, 0.030246131843136206, 0.012390248349777633, 0.050225846634636966, 0.055091987333951466, 0.06455321916409078, 0.06671099007249841, 0.03732074698012683, 0.0254261460260398, 0.062268534299707225, 0.06486985096407515, 0.04719696097796963, 0.005534264172667698, 0.014126609612797058, 0.06041244498544163, 0.048239265733789054, 0.10639203862557489, 0.03035149000014269, 0.040015652775764465, 0.008218519430938027, 0.025085799974359335, 0.09524666208533511, 0.024575395810027278, 0.01769330431406777, 0.030383183057570172, 0.04065628997200439, 0.025293932656847665, 0.011099074186096269, 0.082047265924273, 0.0330688709002589, 0.06334470014177984, 0.04239219541270887, 0.007047236590991698, 0.03609891718013152, 0.07548668812359534, 0.03782325086273974, 0.07147100844210194, 0.061351998198416934, 0.038890124058290836, 0.07157238485712199, 0.011351079766398237, 0.013664267889614548, 0.08988449094636787, 0.038224726900338166, 0.10545830768082412, 0.029574992856191053, 0.024704544827522292, 0.026183381804355213, 0.04707556668548815, 0.036527727234868274, 0.07481441532652225, 0.06862634011814672, 0.007565785706373713, 0.03258809710161821, 0.026956318554678754, 0.02515035820373845, 0.014633827808974011, 0.02173551170515918, 0.09242028028013245, 0.0336637573256608, 0.010226432050037529, 0.07049023203792111, 0.0550482360525958, 0.05436127351957464, 0.05644081152915474, 0.07764414493595401, 0.03185625139233326, 0.07255230324282762, 0.011106375004014662, 0.023217886092982466, 0.03565526034142222, 0.023201920820640463, 0.03418908296753803, 0.03793427615516609, 0.03811768526511808, 0.06125022341767627, 0.00868637602956545, 0.01844304009160448, 0.009061711231967615, 0.0825384738404424, 0.06152566650041169, 0.07214541862448377, 0.029596418420213367, 0.03170774141777187, 0.009929457108580298, 0.0038352461049198025, 0.05784051545384911, 0.06034552720525573, 0.09700903203338386, 0.04408369839732205, 0.0501360266559547, 0.017344738138959776, 0.0423981594071994, 0.03190296743395588, 0.029603341939829053, 0.022335163197450103, 0.015659428017604497, 0.06390806970997684, 0.04389427549716446, 0.02657633894423564, 0.04725349826678153, 0.02977703322446154, 0.05476264230486366, 0.03625709518429734, 0.0278749039411665, 0.09710711427032949, 0.016776059581447515, 0.03124413756473411, 0.010207592990369567, 0.02273946609948912, 0.03803055042461042, 0.023732430962545258, 0.0655271390813493, 0.04956323420628906, 0.04945468720829776, 0.03278191351602155, 0.04353688398916875, 0.025192391532923908, 0.015481260864274397, 0.04127976679874044, 0.06565163602992412, 0.01868982765553219, 0.04823526675482431, 0.06595493023914677, 0.03935169969354907, 0.04275347864735992, 0.02324337575344309, 0.03496419923800615, 0.004680374911385439, 0.0404605123725149, 0.020749382261607437, 0.08074474791365285, 0.034207702734537666, 0.022244349219686082, 0.009883473638535268, 0.009773608969314205, 0.028312384195986296, 0.060173843070984855, 0.03295537880471638, 0.04807763650352436, 0.0139892375990448, 0.015776271747815755, 0.06016366176247116, 0.030189883752515724, 0.028657031831361597, 0.06918248930765737, 0.1232800638723758, 0.10105603705010108, 0.02243575437234775, 0.011265276003659013, 0.030628379073835192, 0.034213130467481194, 0.029579445742250934, 0.02726758582397334, 0.018723031821390314, 0.02377220433235409, 0.06261248479507144, 0.03336887476184676, 0.02093528690297277, 0.04863097798079253, 0.03664376274231942, 0.015140589225226113, 0.05296354610172491, 0.05045444344080264, 0.01691821677189681, 0.06422049185681729, 0.027554830491182306, 0.04499638873723246, 0.02797312981959793, 0.018005349162605502, 0.10161265355324554, 0.06384714273735881, 0.045861497356165806, 0.048013737109760125, 0.034229038283228874, 0.01713282481256512, 0.03660488378016218, 0.03247270510802346, 0.043488298693010886, 0.062838270058555, 0.031421144094858924, 0.032125387656232046, 0.022461196152313102, 0.033989593672055396, 0.08299421954659686, 0.010155953876223537, 0.0883742328733206, 0.02892275708877752, 0.08075242411465415, 0.03407931022886788, 0.08068706915383378, 0.0449565215216529, 0.03542600469964166, 0.07088527293695558, 0.055346202120305076, 0.012747746152472834, 0.07560566923911534, 0.0851435098616827, 0.055774916414051294, 0.017231276686934215, 0.04913619381465739, 0.0459500341375749, 0.023647726535977378, 0.05086756018441051, 0.0629108262458636, 0.02449075075527353, 0.06312838755548, 0.011347303910541439, 0.0439159021592669, 0.009338871309263332, 0.03939251302771511, 0.02418904234805415, 0.06507904659355841, 0.07739317453195972, 0.04818722155065306, 0.046457402678506995, 0.0808161473081958, 0.07885555977061873, 0.020474699521136862, 0.04660425407271232, 0.04672648340103127, 0.05966848168041437, 0.058221310947931586, 0.07660800335748542, 0.02143311764924757, 0.03275291708808753, 0.02663056456273602, 0.04695623316952298, 0.00967428183949162, 0.06595145986084977, 0.01871916690781232, 0.08175238336045897, 0.05010802231188263, 0.018706371324257027, 0.04359181632377929, 0.005255168765753267, 0.020340423460208604, 0.018607048024874062, 0.08871357151938063, 0.050205744487503846, 0.0372680171482986, 0.03915897112399821, 0.0795940149034704, 0.055902462392564745, 0.022717333819356658, 0.023781539113711447, 0.013448170765543417, 0.0721617975843049, 0.034674058758443406, 0.07802806223832792, 0.022707700263708833, 0.07833750813358253, 0.026110741347374938, 0.033356207498018785, 0.037988090001407175, 0.03129675631381331, 0.09582120504590774, 0.034865251321706085, 0.2109294396735007, 0.10545036334904934, 0.20816364776222937, 0.13450031018545552, 0.13122640279752593, 0.1308548807977669, 0.21707390915722619, 0.11604255546004542, 0.16264904650949663, 0.09009508085587332, 0.13240525889540875, 0.10529502370064298, 0.15269888204432305, 0.09510122029291046, 0.09847760726247104, 0.13906395723742826, 0.14311890658592025, 0.13704274150152362, 0.09569997929276959, 0.1987641472970286, 0.20382140012037372, 0.1004430441366088, 0.2720036850340905, 0.1597824833926655, 0.08531213347469607, 0.12338854958333316, 0.10459598379149553, 0.09206083182606006, 0.16590306625491189, 0.13342697503826312, 0.1772404320898556, 0.134768103880267, 0.09690140434090169, 0.10708033798202392, 0.16295185042244775, 0.14242680743336678, 0.11897433564187058, 0.1604008389216277, 0.20857497569053404, 0.1250411008274363, 0.15262585854338062, 0.1986283811950876, 0.15947488376930838, 0.20231937749251244, 0.17308872583652699, 0.08607376276725724, 0.09517644246619555, 0.10579039913512046, 0.13237236307994013, 0.1750678680236301, 0.28427868120131955, 0.11795123287987326, 0.14094841095709032, 0.20557313676803343, 0.150718039142028, 0.1248109603541032, 0.10280184417722688, 0.14563469336398188, 0.16727106946129955, 0.2067249959274646, 0.1145043351777619, 0.1076265586720359, 0.1539239638875569, 0.16684538504529386, 0.17355223967423364, 0.18315625497170035, 0.18924548951608522, 0.09860550564142967, 0.11843215223521956, 0.10526928314638716, 0.06611109726251134, 0.13052564685142812, 0.1800885631312286, 0.16621458824844132, 0.16130134463310242, 0.09690256113366735, 0.08616688841533277, 0.20800384182122447, 0.18041174498296556, 0.12540991087594341, 0.1280208151306837, 0.12229045447442802, 0.19989481646447413, 0.151697559162013, 0.12069118464545858, 0.1084355321983176, 0.13434271057767255, 0.19686228805972686, 0.19164011182804264, 0.1133091537462127, 0.10543780716797037, 0.2817215716406223, 0.17767777636406884, 0.09384806898813094, 0.09233888343817766, 0.10815731204685666, 0.147176246128736, 0.13627628585503948, 0.1175115750201287, 0.1738604062026547, 0.11733039522603636, 0.10477636685414661, 0.16751814813863847, 0.18079964594254572, 0.13906654661461232, 0.09053496088111594, 0.1604994344374826, 0.1410707551985979, 0.13279760316494973, 0.0946801783697259, 0.14144603102918596, 0.1492201840324748, 0.2009294335279734, 0.14018396246096781, 0.16542715711459038, 0.13996999410371627, 0.20595311637847655, 0.15337451030650448, 0.1326709535093077, 0.10232060306495237, 0.17281768392891655, 0.22181576358214503, 0.11594785167084587, 0.151923279308023, 0.17239178500829205, 0.08315253161614941, 0.08598432966297673, 0.16635884260458333, 0.09784167767652581, 0.1185167053594224, 0.15084836601970658, 0.23901390122069469, 0.1347586350335229, 0.17638330227665364, 0.147386001002404, 0.1566704044178609, 0.26664790306841174, 0.14272280848555027, 0.21557887325123434, 0.18975726689302153, 0.17614947692040475, 0.31197251451592295, 0.11193512142786097, 0.1203081330224391, 0.12250950199461753, 0.31636281119238946, 0.10456432903846426, 0.12890871103492477, 0.1281592165750842, 0.1883173893175779, 0.10184030424082473, 0.19307585252869516, 0.21417777504651778, 0.08960814771032141, 0.11289232530661168, 0.1835418576675077, 0.15371845314098945, 0.1726205541842407, 0.19817735459054672, 0.21083695753928156, 0.33967164915896236, 0.15085371331341807, 0.21713715737625477, 0.09073745324126176, 0.1006373546777233, 0.16301436319706902, 0.1655125452746307, 0.16161275937432246, 0.16712238711695518, 0.1508785958491987, 0.10516917843732143, 0.23794127087439262, 0.1153551524264678, 0.23506056577447923, 0.20765208488991185, 0.16544895997691542], [0.0073167745722457775, 0.06067825834296885, 0.013559964061113856, 0.035367985030696276, 0.029253151658321583, 0.0356114630947911, 0.012521009024743353, 0.052689719464509725, 0.024662953914113106, 0.06306466053149874, 0.02802562024894982, 0.1234585700196124, 0.04379872518080858, 0.013784243961826209, 0.058163613035914406, 0.02914552205061961, 0.0277256585221978, 0.04900830692701763, 0.039474794701222456, 0.05989788670934016, 0.050447303501348344, 0.08882833149043784, 0.05742027026210582, 0.01639218058346981, 0.016608851315874248, 0.02129222641909315, 0.034674514580758355, 0.037732660965693575, 0.017568359204057245, 0.09280291055479357, 0.061356464491015485, 0.06340417537778135, 0.009573781637534981, 0.08668490940885198, 0.0289095631395016, 0.07654655544507889, 0.036037810176851294, 0.035467392599750916, 0.026935668654679775, 0.024122352479025725, 0.014335527535407774, 0.05758806266972135, 0.05732231442966769, 0.014375045223371878, 0.03333838829290002, 0.03662180283196992, 0.03160049485403203, 0.050564396210135, 0.054538132577774026, 0.05330879511612077, 0.03702152835866136, 0.01010698745132334, 0.03605951727818578, 0.017952694024349895, 0.027170876799631986, 0.06274435917035708, 0.01437047455129364, 0.02483830186388185, 0.02196420810275501, 0.011449339161176356, 0.06622097725349088, 0.06102741440577854, 0.03926195632365923, 0.030943886639790672, 0.05416383350928945, 0.045393888778503866, 0.06806012453331102, 0.04622994351290888, 0.04067577924879809, 0.0275120904458867, 0.017855354892690817, 0.026314641394081618, 0.05323560307583502, 0.007754922759974556, 0.021252889719401157, 0.03516171585708376, 0.0357792325197689, 0.03146956851255269, 0.08454326465125046, 0.020760231981835058, 0.026566988841119795, 0.01740613242521161, 0.04649472265173832, 0.018571677745410034, 0.055452071641001015, 0.057535750355811856, 0.04462117802411799, 0.12440555428545322, 0.01656501768006673, 0.10616536086965954, 0.03201103945743413, 0.0753516115007862, 0.018189815473893, 0.016709967261000026, 0.0522028744190691, 0.029061848012309884, 0.06120760594644855, 0.04021986117286067, 0.022236755373136654, 0.034572942813317624, 0.027636430346437042, 0.020845445856872587, 0.11801412103757744, 0.03604768121975564, 0.0596400291749066, 0.021811476983730833, 0.041510401398784695, 0.03830885867618265, 0.021252742247475732, 0.00915858113477307, 0.030650105327367786, 0.02701085635400828, 0.0250090686078634, 0.032502276101900686, 0.07445670589203797, 0.04857899125425085, 0.050765433003224676, 0.06512220798721237, 0.007365927252272565, 0.005367261793224081, 0.00977555004459235, 0.028141021818643617, 0.031576757619698206, 0.04160169992716082, 0.027208955199908347, 0.0031275539508750366, 0.07106970860472611, 0.030185708573328394, 0.0418952648197451, 0.011830170086825327, 0.01886248855190652, 0.03668973567865549, 0.044157242838052974, 0.008080047123404521, 0.01028626447453374, 0.027245166260869275, 0.02490721147267088, 0.029639763674969156, 0.014371897559612991, 0.04823056297496923, 0.06689347987694126, 0.01621587119335609, 0.06304345138731503, 0.04738264536905674, 0.05524114082236925, 0.01168169841666015, 0.03777936168555771, 0.031629966256479104, 0.04941048393506677, 0.023586556330443393, 0.029226556916030186, 0.052647883402964765, 0.052284294243661635, 0.028924626343312766, 0.05985136218969861, 0.02850640170846976, 0.032797813670889985, 0.024717363393715313, 0.05732159430701887, 0.046673998717338815, 0.0368148033627339, 0.02580539976817466, 0.05765003918279564, 0.004783838915999138, 0.06738228993790765, 0.045604137778883024, 0.04920676200380249, 0.03299947865607758, 0.049548651722650376, 0.04153229619166063, 0.022020628563158458, 0.044665745189113, 0.05206006796910398, 0.00804410227799728, 0.053861098544251536, 0.03774516735105746, 0.018362648740050294, 0.02859873062510404, 0.026140042295258854, 0.052246123912834355, 0.02423693050420092, 0.036998151185651945, 0.0396135255634304, 0.02147520651980754, 0.011064605017553174, 0.00528104673703051, 0.03619380099999328, 0.03169311296885773, 0.027510202039153348, 0.034757439768122095, 0.04660690856736995, 0.014292973266433806, 0.09961967581822988, 0.05413673697940765, 0.02980071300220105, 0.014186892113948782, 0.025343609628297632, 0.07789802647406056, 0.023491586325690154, 0.006757934498901089, 0.04518353635625494, 0.05186066677373263, 0.06593293585484067, 0.06161131129990663, 0.008681584149599075, 0.04036111246433951, 0.057799928115620736, 0.02988078642726666, 0.030333450544745694, 0.06129174538317227, 0.053321519836543076, 0.03226999058237961, 0.057286089962168094, 0.003367303560803374, 0.01523535621667942, 0.01797131187612972, 0.05390950764018682, 0.06812692740030828, 0.0396782944669887, 0.05581061228088314, 0.03734606235558468, 0.04452028807492987, 0.02419770297203814, 0.07154450691755741, 0.05007004350303643, 0.0025369190740504215, 0.026924313316422126, 0.011605168148244341, 0.015197572760253906, 0.021509207417106917, 0.018705277733745116, 0.06741573733668174, 0.02957875626311908, 0.02773535336487957, 0.013210878861437162, 0.01939145311142408, 0.0778140402549217, 0.025855017367810495, 0.03902254235600272, 0.025579648978647687, 0.03993832003024798, 0.06644462896210533, 0.0813118674822392, 0.012488037558092226, 0.12408257927745582, 0.031095074091647423, 0.018215751380569512, 0.03934065270568094, 0.06269041508916887, 0.01504859834488842, 0.020089202162419117, 0.025632459249707962, 0.019874956098295028, 0.027933295162755157, 0.1389143096222993, 0.05630895630606721, 0.017022837569276174, 0.045753268284663084, 0.040669030014185176, 0.014443083407147037, 0.03469903705521457, 0.022579909137059605, 0.06270200216902361, 0.03495505980906948, 0.03916503470991889, 0.014567195396539907, 0.032956121910002925, 0.015778556605049922, 0.03597078131391637, 0.04765836807388452, 0.05663853499197191, 0.025709322766370835, 0.056751954309161634, 0.054277237504720695, 0.04160565677128973, 0.05524288750283661, 0.03884319734248904, 0.04447549874443681, 0.04607378031998392, 0.045251905873057344, 0.0792754065966414, 0.04482971481798638, 0.007609693078143943, 0.05269729224364123, 0.03555292631649683, 0.061875320520372167, 0.026490098511379574, 0.013934034260831053, 0.012951283265025386, 0.037172577914691744, 0.08289072106802657, 0.010227664493985716, 0.014407986046506033, 0.06857523439271797, 0.066403980336843, 0.02774863158382716, 0.0625365041947413, 0.02593719944988768, 0.049692239582298264, 0.01798838031508269, 0.08974838010486096, 0.03903727039634701, 0.046913684646208445, 0.018863913475445682, 0.022821414524749405, 0.036428116652513706, 0.03074502745162576, 0.025655924522828673, 0.04834172999366157, 0.045426489650121624, 0.02222386211337101, 0.034672779391609856, 0.03651764168734512, 0.0594970120507623, 0.005294695551011471, 0.033255911266971985, 0.05651681128168299, 0.016235281946137547, 0.05739552945259118, 0.031508855416529605, 0.014962799370198723, 0.08635749109089376, 0.04212251331116404, 0.0328774944758944, 0.04937203015170751, 0.05261908232745144, 0.04840363372838305, 0.014915339265679641, 0.015237279097369362, 0.009734836301856465, 0.06409946145609983, 0.0881759693185168, 0.021574376601605647, 0.03888438222929835, 0.01590341648777887, 0.03093730211408148, 0.04132925607864896, 0.029309788538563638, 0.017243518771964218, 0.045684994528851205, 0.09001136276750796, 0.03289576184244887, 0.008699319085046169, 0.023128782406509407, 0.032636598128104405, 0.03385295422988073, 0.02155093814156229, 0.09116487667685555, 0.002115092389548438, 0.023373560904855692, 0.04235990097626083, 0.0231653094787391, 0.19763108793525927, 0.09537223921788317, 0.15539109887134644, 0.12641697941768554, 0.16270319360398477, 0.19534380986325203, 0.21519017556021292, 0.09013252723361216, 0.11831109502142477, 0.15568775875914484, 0.20652268742842061, 0.2734386902903357, 0.14408361046544968, 0.16981849567063395, 0.10393268188401576, 0.1488513893057262, 0.36191400080438585, 0.09783490545927517, 0.10748071085301139, 0.1984745354181336, 0.2050405064777982, 0.28296548392503496, 0.09399590097487935, 0.15500407125199997, 0.16928499204016503, 0.09051626067488425, 0.16617066076686307, 0.14403694038910253, 0.12873148425452172, 0.2240707433872646, 0.11991571980498492, 0.3230016065701362, 0.05730845972955708, 0.23055863476568655, 0.09389316092335409, 0.11713527263172212, 0.26032289730445035, 0.09210389362828386, 0.17293135605512128, 0.10030864933205229, 0.14469808958951505, 0.20504747787790917, 0.15340288620321982, 0.14677616437115978, 0.14521769638503754, 0.17274625389085663, 0.17352574835381201, 0.13725294070618768, 0.06557351804428524, 0.1707656254931804, 0.15320419363917845, 0.13191058060094235, 0.14476791084293397, 0.1376635791553605, 0.1188392666799407, 0.19438649107131267, 0.10440837651971849, 0.10458964824436173, 0.11305002450582483, 0.09118850282844036, 0.20378093535621322, 0.14101916683777688, 0.1202830589646774, 0.1133419959355266, 0.12178254584150931, 0.14202747644195635, 0.1640002264250671, 0.14247139375055992, 0.2309185428725135, 0.15278609349362313, 0.1127544831063959, 0.1288652432061011, 0.14063944769722803, 0.10462999043445434, 0.11841188920962235, 0.0874702797661866, 0.1382652646110904, 0.08564272339666083, 0.20673322371177136, 0.10976818810787894, 0.1083842579335455, 0.0972033502353776, 0.14783152709564856, 0.08888119155721319, 0.1606319063613492, 0.13428624989765306, 0.210467565263952, 0.22860403803567733, 0.1297076488093984, 0.18732380392330308, 0.14106422812948305, 0.272894338854859, 0.10214768169868378, 0.13329339994778558, 0.17296762265745672, 0.10362613946199419, 0.17579304685275401, 0.19090552543920858, 0.17255149901874606, 0.12057782661530281, 0.10597772295436553, 0.154639367434767, 0.30442513885997957, 0.09627807690131088, 0.15806868341901611, 0.11457787961849283, 0.11556114580842758, 0.13585384965183275, 0.058375007337740356, 0.12426601903092478, 0.1467906434329287, 0.0896009311620747, 0.07384760470520105, 0.1023277123608897, 0.2007396122620952, 0.08478768500349215, 0.15444798334952325, 0.22257016100470098, 0.30412124710217603, 0.12198822512742012, 0.18116675527586093, 0.0773384222280114, 0.081597434416894, 0.07975887702477556, 0.12220305150314686, 0.18499298141367976, 0.21542110510410803, 0.17464953805169753, 0.11996110285361929, 0.14849163441648408, 0.09497024990137547, 0.16988920558604503, 0.1639156809617435, 0.0979834039425177, 0.12982758753482374, 0.11895539794838238, 0.16465486387812323, 0.18479707740968276, 0.07992554711358202, 0.10495841232759338, 0.1542214817938305, 0.13592670461343181, 0.1293691451991758, 0.12430849094544688, 0.13273190346456346, 0.09311296165950837, 0.17548848093757707, 0.17357169830751035, 0.1877451982469328, 0.12574094512890424, 0.12984246496231328, 0.1473164861841548, 0.07758531704424851, 0.06692002482351757, 0.25166976566035903, 0.16344525701095983, 0.1706340269095475, 0.10247641768787177, 0.23014456424261295, 0.16447887816015752, 0.1708821934317389, 0.16416357169228216, 0.1788596661701318, 0.10303986003442157, 0.2211646041682651, 0.15411248280396386, 0.08722883183509113, 0.08815748361690391, 0.20556014391683763, 0.1940727014575274, 0.05312799836599058, 0.10329070020346873, 0.11047629849804987, 0.08746076495416703, 0.12494650429054616, 0.08845919968500253], [0.04025907338326497, 0.015319208370431539, 0.07655467597707626, 0.12933868554330644, 0.022832871369657018, 0.07237188953665957, 0.009028930329687653, 0.04743476999142478, 0.08821136258061855, 0.03644020168951923, 0.06538101547067204, 0.024985555454247424, 0.039823238302262566, 0.026318027502706936, 0.04612166464569108, 0.05718082565093233, 0.009137720560594913, 0.04426675893726849, 0.03949102810433796, 0.029174141180250916, 0.08176935986886102, 0.056257888885034676, 0.03758969746770398, 0.05875256611034275, 0.07817734979213246, 0.05594954615639103, 0.03588418273495571, 0.04330305863291987, 0.029930269961515744, 0.03435679493592151, 0.03896293305461446, 0.04480030470257325, 0.03931130387730176, 0.03324893220598179, 0.05558319908056048, 0.0285164317146184, 0.007335026617041759, 0.057851229193470174, 0.0066422987935854305, 0.033801270108069145, 0.07800285794561909, 0.014431655290536584, 0.039432675187145515, 0.025628019770186757, 0.031751640171052954, 0.02154334812545248, 0.07677524801223509, 0.013292026724816572, 0.03706536007924907, 0.05350004130553815, 0.04923512640919897, 0.04437874950047943, 0.029816310552339402, 0.0777901689552011, 0.06705317856563676, 0.06773336505096766, 0.06756653408369712, 0.042614403045586044, 0.04785741303837107, 0.027136408588698795, 0.025754376397197767, 0.04725648600968623, 0.11243883189895462, 0.017225192033595616, 0.024969249272779114, 0.06353052242869331, 0.015609559524173458, 0.031236254519993262, 0.025877122834865606, 0.009026151345742327, 0.07098765292715642, 0.0281032555991964, 0.06475203430220004, 0.02420111972418043, 0.03431888124454887, 0.0477368614426063, 0.016395599250831915, 0.05542830759358983, 0.06980141174168357, 0.04600786228453921, 0.011083524516453187, 0.053154934017408284, 0.05978995258168829, 0.04770576976419938, 0.05188880135275183, 0.03404005588362775, 0.013800193912409728, 0.017315571256462606, 0.02770798104334503, 0.082359500379572, 0.028020837945082498, 0.054549118278608213, 0.038704121740715164, 0.012418170339397848, 0.07582932094772978, 0.05023325470486476, 0.012637380653271272, 0.013170590297499252, 0.028920003002689734, 0.055234380096437476, 0.02349111709683653, 0.04149285415487905, 0.07032741537137378, 0.017691793205637126, 0.009422791453318731, 0.04883293790983097, 0.053522062502921595, 0.07349697392313712, 0.04740412264401394, 0.05824086534219885, 0.062771585935186, 0.012660309664844986, 0.01475860725247091, 0.053430120460689075, 0.03733604575597471, 0.045824705983602235, 0.04072454074517854, 0.04205874415234693, 0.02189106202774471, 0.05716372273802277, 0.02653236549738194, 0.03717655774145838, 0.08743789722962726, 0.04502602484858325, 0.023510985587152745, 0.032958113738606055, 0.027539916674516378, 0.04512581546160002, 0.03903530921126085, 0.02862101037716193, 0.007887505766590157, 0.04255903021041905, 0.06711148551755375, 0.015191177841305975, 0.06598198846463235, 0.10483677288697613, 0.016390232804922328, 0.0704913045610151, 0.037880941113877686, 0.04382740368225402, 0.09229697076784027, 0.04032801363557097, 0.018658151835083, 0.01376386123499082, 0.05460011675172756, 0.029040386059111165, 0.05167740322048626, 0.05977270028163349, 0.06371997214192826, 0.015060490902302968, 0.0330213351445573, 0.029414451470778837, 0.010974760141013371, 0.038027555020826484, 0.04288130424796574, 0.0724133808586386, 0.018211382764181303, 0.04966736087695726, 0.02070972572020706, 0.033303163570141604, 0.0606538201381843, 0.07876655567557582, 0.01857284602949456, 0.04850135207356465, 0.019611096264974728, 0.03268512213722833, 0.01380403871617971, 0.034083960382568265, 0.063339073225976, 0.02408901999344028, 0.04546438418929616, 0.04328252364610953, 0.04359406479183705, 0.05781357980243141, 0.030505640297046596, 0.06593835975734458, 0.020339749302835237, 0.07102680002008716, 0.052454882872200785, 0.017690172929677273, 0.02510447145229386, 0.06566126575513233, 0.018242526153523116, 0.010841383275786235, 0.010742608686879037, 0.0692439372200639, 0.09242567353911939, 0.01636366104526866, 0.047235912718479676, 0.07071151653484953, 0.04133544989951676, 0.046855178511431145, 0.028954291182960716, 0.028672872614415906, 0.12691124402467283, 0.05781211274405641, 0.05349042690208843, 0.01571022635025363, 0.0731729417138042, 0.02546635989640509, 0.03214890272506783, 0.04580047845299687, 0.03444673748867166, 0.04645690089091659, 0.01442756342341102, 0.06117370655579914, 0.044794072577309225, 0.05484953199723556, 0.060897957037894, 0.06007558846425626, 0.04295359996538009, 0.03966792546693356, 0.019243739868303942, 0.03507272325335972, 0.05872686769092276, 0.035328313167537415, 0.03901012024031051, 0.05469775082723749, 0.013073301919165158, 0.02217510444743018, 0.023168797094014384, 0.07435224980356232, 0.026541663889562892, 0.020868526170811346, 0.023505015847002788, 0.020025620695143458, 0.05456041807549135, 0.016361684538424015, 0.045516658198809436, 0.03117168288407547, 0.04426687768089675, 0.014810098894691516, 0.02898804118646489, 0.0449456392426885, 0.040709686300326745, 0.02946599961198386, 0.05124487763931675, 0.05583991514398687, 0.016305200875766816, 0.030026850666129784, 0.02870375170342384, 0.024147943646136313, 0.030133672051071644, 0.014121838800248601, 0.010383701282403162, 0.02797137164781171, 0.016339318601474646, 0.028702171647080013, 0.009946492988796485, 0.024094786720290303, 0.04099460972112514, 0.059842180625926104, 0.03616257908663923, 0.0240507232581055, 0.09522597005050029, 0.020873084393960815, 0.020384301146071766, 0.05057478819282786, 0.04106951396792166, 0.09243646005709326, 0.020782626647081588, 0.04993701999586436, 0.037263918577903704, 0.06916900616019003, 0.07659006157829877, 0.03319842402913398, 0.04708982741219863, 0.023220418013572212, 0.053219921256024996, 0.02826705477350662, 0.036201423574839874, 0.02957730261128276, 0.02967942787724878, 0.004694981335271751, 0.019950440656694195, 0.03043868038202486, 0.012408945683179604, 0.053293511662031376, 0.06438578298736004, 0.047224122625325, 0.015557004934957912, 0.08140310089314177, 0.049166722418439966, 0.04625389142142189, 0.021062861609783386, 0.020077611252124754, 0.02568472751356181, 0.060867930221701824, 0.040161807029958696, 0.026873994746335575, 0.011169377117297583, 0.013309349888004364, 0.04465188282812315, 0.041120795893572995, 0.015209743982150912, 0.009390340926456115, 0.03648366951834291, 0.01802427153433523, 0.0437267282376847, 0.03914422776189543, 0.02545458129456928, 0.06377547138160275, 0.03312887090648855, 0.023468739668568297, 0.08037399200181808, 0.025378755827043808, 0.01606085713231756, 0.04554634027543568, 0.06986658284140211, 0.0417580469811876, 0.047448820043956084, 0.017185554644393346, 0.00792226126049495, 0.06586665392763193, 0.06893392441974533, 0.03293110913927517, 0.040702722561095035, 0.04250057387135683, 0.04019604732973441, 0.06435353834662708, 0.040548179644129934, 0.026954495265418967, 0.02952609729442385, 0.021462085348884427, 0.031549806646522016, 0.0302154193782518, 0.013826016821117412, 0.05516783769933447, 0.032035192294466885, 0.01875178118596875, 0.06863993051792346, 0.025432330270808552, 0.023912580368379434, 0.049394537814922874, 0.06075679001608684, 0.08988034641069752, 0.046530165709555156, 0.038087191135292096, 0.03439566240675988, 0.05162908988554151, 0.053725669520997235, 0.04267408512532712, 0.017772558025054393, 0.03691996042166026, 0.09781599840930394, 0.03605337708347267, 0.054026642483809305, 0.04149542437986501, 0.02740582064425032, 0.05612645117986587, 0.02940831510650535, 0.029055075795059244, 0.15172829460953513, 0.2299598910875859, 0.20295285559709997, 0.323965375822398, 0.051538630223442475, 0.26305835213392015, 0.1399139930764514, 0.167508005134521, 0.18407297110365284, 0.15528496505031664, 0.11889034176185248, 0.08068172952100154, 0.14326242549765494, 0.13531712845208185, 0.1586986834844274, 0.1806225264144521, 0.15362600165028728, 0.17781266912577615, 0.27175384844022415, 0.11297478701078123, 0.16490459321968018, 0.1850750141086117, 0.11554775459151115, 0.107151584158982, 0.19859232909737096, 0.21776729533749245, 0.10261048307462085, 0.21031566535032567, 0.18924904416405386, 0.15906609925291232, 0.11477804307134883, 0.19964468875719657, 0.20322817227532788, 0.1693660288207954, 0.14468547978228138, 0.17346904252565679, 0.12598268417341094, 0.12224988245795812, 0.20144142540952853, 0.10065342720237472, 0.15867625243000447, 0.1823286961523756, 0.15498586900291905, 0.10048225251657349, 0.09303923335767562, 0.20173784014919113, 0.15262181359914043, 0.09513188679251941, 0.08901247604479713, 0.16754710626217628, 0.14058726178782602, 0.11051624232242185, 0.160438867526189, 0.16745857714164644, 0.19499672606827753, 0.11736907500533328, 0.15873943936199914, 0.14109029044066707, 0.1413824150879537, 0.14450528058073214, 0.10434895874031129, 0.18818421259282098, 0.2923258219755465, 0.13038634142327693, 0.0980695964948785, 0.13961996853111253, 0.09657982361292648, 0.14033290527520642, 0.10562968154948567, 0.12704981400841667, 0.1113821744858738, 0.08088026886745807, 0.10746633904355188, 0.14165396261359417, 0.12765415778924383, 0.15418199762221307, 0.11158256776510708, 0.16901367434090184, 0.3346219959278261, 0.10659011831927685, 0.19422515295445922, 0.1517674110589489, 0.13167493195543367, 0.21783929228061633, 0.12522314630088308, 0.12899434434310084, 0.06763768066922504, 0.13833942192216075, 0.1947100253234948, 0.1690378061105167, 0.1508863793025094, 0.11898048732790256, 0.17194299538049007, 0.18641127063141716, 0.14903411659742558, 0.17942552935452233, 0.09964830452396024, 0.13903424834772465, 0.12635011526365436, 0.18312567274176306, 0.1173183753065044, 0.11903615127648078, 0.10190732161244077, 0.14414667482337645, 0.21231294849947577, 0.16639503259812632, 0.14012086745952407, 0.2135913194187226, 0.09434944289105554, 0.1400901626555189, 0.1311977051438824, 0.12900808796046243, 0.0735732839412747, 0.11556091598205029, 0.13233847135016996, 0.13754768537417536, 0.10185310557003945, 0.09490898585007077, 0.09857893005133637, 0.11934115386177456, 0.18082742429068013, 0.10533161972078586, 0.21727440968876888, 0.10720196210088269, 0.12056919280439617, 0.15409313142299652, 0.11627850287984456, 0.10856753680855037, 0.2231748954903695, 0.09247309438163236, 0.11497461357183995, 0.21948094209355695, 0.16688445552943215, 0.13777381920766446, 0.19009267550803002, 0.11990340877204173, 0.1157123639038013, 0.1266404549260774, 0.13565353298139188, 0.16796997147462062, 0.2164356966292666, 0.1470971552114333, 0.09175886294894642, 0.10995908955773039, 0.10772240393224264, 0.12599383075270923, 0.14960702779071947, 0.15939282043085945, 0.13182879305414616, 0.09576557940172573, 0.09626801816686507, 0.12657949730994242, 0.13541722550026833, 0.1047561957591003, 0.17703116751245915, 0.16703338302191229, 0.10011842970045344, 0.16187837737942898, 0.20744481214111854, 0.28325923267872105, 0.13125172966430265, 0.1870984055342213, 0.0985765168743749, 0.14231292080254326, 0.17699211235007933, 0.21369380666123283, 0.15357884127766858, 0.10061927500271028, 0.16400966462829422, 0.16135584412803575, 0.1621464621876517, 0.13764755259598457, 0.15767830033456126, 0.11384824981852887, 0.14087888081708264, 0.20521040945764513], [0.04008966836056883, 0.020739608894913428, 0.08958035404042852, 0.13897447816787228, 0.024566919047145114, 0.029043412106412075, 0.04401429849226148, 0.026920634179165768, 0.03555211426329709, 0.0058367836754769096, 0.0212846115051258, 0.010369524825364351, 0.04533785710772199, 0.05534799476604789, 0.07609513047481738, 0.020726845870094917, 0.041738963730993776, 0.022529580990874, 0.06657690936399084, 0.029533591549543124, 0.008852185227067001, 0.031085247098798716, 0.04293187371184749, 0.045432947771323305, 0.045701136001415794, 0.027797109627675627, 0.025352689685420166, 0.06447425082085595, 0.04800422229774056, 0.045563366579552816, 0.05626952193016487, 0.07435469362404078, 0.05939725591170211, 0.03663651555055573, 0.04340713550787299, 0.006470831557958117, 0.0376060955797232, 0.05314877850093669, 0.06897204495485752, 0.05425259245619659, 0.06679048701640099, 0.04476315326868527, 0.040405748577247706, 0.07603228828238864, 0.020553091383208672, 0.011902161284289774, 0.06614656713340553, 0.07606314630397866, 0.012942782561895589, 0.07681716068257248, 0.04312533389536604, 0.05963952355687657, 0.09553413657892136, 0.008666186739930944, 0.03462998955059917, 0.04750364512625722, 0.052982870669614886, 0.04614837813161073, 0.04549457571439205, 0.04420207047294225, 0.010611351012372443, 0.01902077380838173, 0.03627560386854795, 0.005071075443523906, 0.04028262292605735, 0.038766488958630836, 0.0518142533368401, 0.04760586040755434, 0.05342784517955396, 0.022403184144246965, 0.05743057031424777, 0.02650390724621473, 0.029391286887168407, 0.019529550035874692, 0.06226897096982407, 0.04975669055936798, 0.030976106382666097, 0.04445276508528379, 0.05348126449051404, 0.012760151031186745, 0.04039957773901763, 0.03296531879553392, 0.09027971570650417, 0.04839706452443235, 0.02888208356565766, 0.023637499262188232, 0.042403636935858, 0.0362955681198547, 0.053065489421808915, 0.06164954674820747, 0.07269229815011063, 0.05531295007395168, 0.027477806096055338, 0.05101512787082503, 0.03208611798923343, 0.04191035675185342, 0.0298164714308035, 0.04138375174314265, 0.034818496975687244, 0.07727404019885487, 0.030619542249628616, 0.024225061887034008, 0.029670985588323207, 0.017577312856672273, 0.016974683197575714, 0.008401609656791533, 0.034949678041401415, 0.04129200888377044, 0.15340575137205664, 0.04713428349444463, 0.004348256644011746, 0.025192789898644534, 0.020121668968650124, 0.10417712521889519, 0.04682089607681959, 0.0061802960643094155, 0.03589714877307415, 0.042681542991269986, 0.04105207014588579, 0.029664316792942347, 0.07185215250618997, 0.01626517086650335, 0.063009548166226, 0.013350257067941131, 0.024422990278370922, 0.06035031142434286, 0.021212846303599018, 0.007627252770978357, 0.026768326323719758, 0.033524854093669884, 0.026115019948432044, 0.056904122353561466, 0.037066191284646915, 0.038599822700264, 0.021593731813012593, 0.028135103789428552, 0.015362867721236281, 0.054763190057729526, 0.017549680065243475, 0.05306490336454684, 0.017582755911374287, 0.05049363266856921, 0.053807142971744465, 0.03386003288230108, 0.022757310202465426, 0.051009140893696785, 0.04825404356984843, 0.027070735701389854, 0.06281138420285237, 0.05016023886480159, 0.07448791631407316, 0.03070611401551193, 0.01165611969847833, 0.012094761534113319, 0.05667662105312752, 0.021089142256025827, 0.06822252751237924, 0.03403414934573155, 0.027289942184823657, 0.03217025359551753, 0.04283560327284279, 0.06473617628216743, 0.0272314973370803, 0.051654278856491855, 0.01727409717146187, 0.057205880556495926, 0.03985282078745865, 0.08665320869054526, 0.04234302022884931, 0.026939652311886032, 0.013044822600580031, 0.017615833672724904, 0.02347235751879071, 0.02363965196925546, 0.05217044591723431, 0.03691292390407574, 0.037885595098017685, 0.006593625876121224, 0.027369123117457476, 0.12038161617613609, 0.02184604287087437, 0.09198095183819534, 0.08357004953488227, 0.06334175836415061, 0.027245108804274953, 0.056225096491435846, 0.036770596259063294, 0.024915783996543577, 0.031388667712528864, 0.029224915572652416, 0.06762775983060561, 0.023778857805976467, 0.020007232669740915, 0.03482542624096236, 0.01043740691872494, 0.07670830724941147, 0.05855933192276186, 0.02624021595223777, 0.06432706234796394, 0.05494393701214464, 0.03540346639290933, 0.04968647477066806, 0.06353228826135879, 0.031118453179876653, 0.04346719680113658, 0.01031441150248171, 0.042497635924167214, 0.008407444373944835, 0.06574532092218438, 0.014973305308470323, 0.03305014005051025, 0.01871736468597045, 0.015657434273781558, 0.046286913641397996, 0.06717674088694396, 0.017864699250147227, 0.021629814554246205, 0.03248630316867944, 0.04444718413475541, 0.06669101049943317, 0.06470842857755, 0.01576225425402123, 0.05675662361506013, 0.05136206227865431, 0.02104951444292261, 0.059339052381654905, 0.028597196534035668, 0.0033901564423896133, 0.07030678462357291, 0.0689118687484053, 0.019616338221596617, 0.029709623232784293, 0.04920879596724145, 0.09065865343737026, 0.04336359490069651, 0.04545825931634154, 0.04577717788877987, 0.024921410912347418, 0.028507016494028994, 0.05263914617018835, 0.013994430717561516, 0.025161071943359512, 0.025500173102163022, 0.022681649443843675, 0.017063378942229094, 0.02613866525221496, 0.046150021390208316, 0.030198521393861984, 0.04157170758492524, 0.056087158530229525, 0.06827575530135824, 0.016417137812823057, 0.034963371863047925, 0.10211547536234702, 0.039003348023059874, 0.04502347760623501, 0.05203135882414157, 0.04113482679390619, 0.03577007393863413, 0.05534592632865233, 0.046689301323626316, 0.05240057872968817, 0.01971323493747942, 0.005437366499174988, 0.10866858380576296, 0.042318130032189434, 0.06353354081511497, 0.03983353069352527, 0.03433516827381907, 0.08271872666814635, 0.021465611268555927, 0.017377051727605924, 0.007963989112120604, 0.014287829943632167, 0.10919605066338856, 0.0432528798738795, 0.04349992024682222, 0.023179459122700558, 0.0265849229594272, 0.04170861132743378, 0.02363279548233315, 0.039016559209314086, 0.01855069459716399, 0.0791517906491795, 0.06694532104677732, 0.029839727944964846, 0.08208006980919069, 0.01029137045054907, 0.018347507012226892, 0.08067453595539255, 0.0076197537278095565, 0.019872598462708054, 0.07494948428845213, 0.04894320477521227, 0.05389970937563528, 0.007241407321060017, 0.03663295324170782, 0.02780303531776994, 0.0599182608176864, 0.028883405067327044, 0.04106169604065438, 0.018353662528698484, 0.034003264511064175, 0.04312911070883275, 0.018046407644907315, 0.010099258581777255, 0.005440393025280848, 0.041216480275315624, 0.06233650162034939, 0.0383148456533109, 0.05862581303283092, 0.019613643507322958, 0.03411249332730809, 0.026792228266957308, 0.013638728433438848, 0.02494560588421601, 0.0029316236126056363, 0.02759057232328961, 0.009639527303196732, 0.013047394740785803, 0.039980960484113426, 0.010765010055394904, 0.045548496812942534, 0.03486540453929094, 0.029093332310778, 0.030982679417056423, 0.05318158238585438, 0.12739733447350804, 0.04381191338442507, 0.06373238659674121, 0.06866606177702066, 0.04324626087421372, 0.03586270162955888, 0.013069325922838142, 0.02032485463836741, 0.02385073217503246, 0.01683176949530119, 0.036828830432627475, 0.08142980671818219, 0.03471846504497432, 0.01749640248054939, 0.0305244151968509, 0.02483110829827286, 0.08179613464181462, 0.03311867427621638, 0.05193050717934967, 0.05163263687263093, 0.042439152772027644, 0.06314149148942483, 0.022183301588219982, 0.07636769689739713, 0.046210756840845274, 0.13204631605936637, 0.15683183446526527, 0.231180468333825, 0.22480384356552557, 0.07383297242584728, 0.2640871469291949, 0.12997688274950753, 0.1826026645158568, 0.14074299214107377, 0.19212766550481322, 0.14020208810125628, 0.07679135118040346, 0.1601889696452887, 0.15958201350463977, 0.19318868195818317, 0.14335763490488454, 0.11038907938787054, 0.0964225993882264, 0.22640210215843495, 0.20200031719380812, 0.19511885580516633, 0.10774972262762247, 0.20415069535374644, 0.12107183841327507, 0.09635418773658815, 0.11962235409526095, 0.16866286735861533, 0.11900055883151871, 0.15625461785783692, 0.10313629518233, 0.16824668243287072, 0.1382161736969025, 0.250560914676997, 0.2478293822176995, 0.15791543519064305, 0.16906198384540697, 0.1468206434360435, 0.15614120620152644, 0.2635848996860366, 0.11893804605689742, 0.20043841713378507, 0.11947145009593618, 0.11308813738005777, 0.13490126528326543, 0.15493869330854187, 0.16911323512754134, 0.1614658696757209, 0.20629031763922787, 0.09563273975565549, 0.2622002417281751, 0.19526255857800284, 0.11593774697112462, 0.1864854585860045, 0.14947892256802128, 0.1095285175007678, 0.24881012797836335, 0.08541194707035057, 0.22039486966546507, 0.11635911065123736, 0.16428973105165268, 0.1432722007795688, 0.07538145828631616, 0.09817176198046054, 0.1404710002844372, 0.0944600047002877, 0.13022881842428638, 0.11648053558723581, 0.1343114695121204, 0.13253972264787844, 0.15509776380513945, 0.1179477701624555, 0.15543327967245735, 0.10949536887628418, 0.13795677632574113, 0.11919817121158685, 0.10117546249661716, 0.0954092565863844, 0.1892780942181426, 0.16892675400501297, 0.11431491227760432, 0.15728940346067952, 0.11498492511530077, 0.11934022689538619, 0.17600882317750685, 0.11889709865734463, 0.1403774303053656, 0.11343997858104207, 0.12427240054333404, 0.1587928050468045, 0.13904445263887608, 0.1461390243662942, 0.11690444267925718, 0.18265904858708384, 0.20167485240005678, 0.1100795032576688, 0.14373456548538902, 0.12709744935554843, 0.10846616039353033, 0.1936176145869878, 0.15211372876599913, 0.11523372749046934, 0.1031570178606818, 0.11302635238896455, 0.18216173495015792, 0.18576803256667432, 0.1802831801075128, 0.19918817696311783, 0.14460505587199043, 0.21503318882276937, 0.26393117142781136, 0.15825110427554578, 0.1437133908151619, 0.1062518675180693, 0.19713947399249002, 0.14145219037609716, 0.13016207684432307, 0.11730301524362258, 0.13596312443335212, 0.15778002148914724, 0.08943950877554956, 0.13584157692328577, 0.11779596984025933, 0.12086283430577287, 0.1012965273712912, 0.11674502744309365, 0.1483438407341319, 0.11530937101211279, 0.11609059683377705, 0.0927298564103342, 0.08119575919643526, 0.06791275986019643, 0.23899755290439054, 0.16798270385592215, 0.12310688203621296, 0.16234008324963434, 0.16009564481435284, 0.12318796478211881, 0.18290254197293715, 0.09885176460468963, 0.10000299557202286, 0.06413010497307105, 0.17116442022304382, 0.16254983812330231, 0.2207287307828665, 0.06852448106773439, 0.10538119327036605, 0.13332197502736123, 0.1561224064038646, 0.1560869365329704, 0.15377816203380787, 0.1381894678718621, 0.15770230953010822, 0.26550229518644275, 0.12156456318353454, 0.18501855342859225, 0.10763714600714946, 0.09446775751008142, 0.11623788489809922, 0.07709707388834608, 0.1350588648910484, 0.23263272589012501, 0.09038707526821284, 0.1748878526831827, 0.10483637452125551, 0.14884435661858128, 0.13325595357004674, 0.20086229358228946, 0.16518550233975535, 0.2246415401778875, 0.1573315995835489, 0.1523697093850182, 0.1142043428074929, 0.17018929754774417, 0.130759472207677, 0.20086731911907274, 0.10766508523374797], [0.04993168419347175, 0.023524076114558888, 0.026445812883696733, 0.025224618936678576, 0.01931644544275778, 0.03036556878097115, 0.05321121083632593, 0.03788908462851279, 0.01807611653461091, 0.068273096976261, 0.02444765447909313, 0.05906163662251446, 0.006291648380518441, 0.020919266089256254, 0.021701208203129714, 0.023525382294469786, 0.047430491390367674, 0.034746848602568915, 0.04285640639042662, 0.011653064922880263, 0.1164530943177881, 0.024439909330178654, 0.05159443589828668, 0.0026559703344959888, 0.05298582776900261, 0.07362478803242407, 0.0255920538573616, 0.06675030570477247, 0.02699219062173319, 0.03249741910446075, 0.08461603534317787, 0.025569837307557467, 0.0764116473616131, 0.01928251923903102, 0.07530196900329283, 0.07593154772034577, 0.014134743551333106, 0.07666159886866808, 0.02939326913967248, 0.07391921094348354, 0.009881715466749045, 0.04381096726583858, 0.017796982823300268, 0.01318799677274881, 0.029964494939532973, 0.05020742605049765, 0.043860119467060414, 0.0535745203735367, 0.024772381913217328, 0.013344455867134517, 0.02389274252158019, 0.02926450508135942, 0.00661302944682839, 0.05392862153389762, 0.023990154431592074, 0.09865536264354184, 0.1098146053752111, 0.03513977892937199, 0.14352922327816486, 0.03252358866795417, 0.062360353767871864, 0.033310276696518544, 0.026971107882056988, 0.06282255376478837, 0.01654297924570499, 0.04446111927409807, 0.024610699056797934, 0.042826628552809845, 0.032864068785021384, 0.023082047212688674, 0.034436613636752295, 0.02647047708441894, 0.05757481317907091, 0.044955617537902254, 0.07064007117503113, 0.04840562555698618, 0.03558267351059664, 0.04452038766636003, 0.0593718754187707, 0.07384251788138382, 0.042467938525782484, 0.020744891071151343, 0.054875146146983876, 0.07266246668633915, 0.027579894972844955, 0.05721694669656216, 0.029174717661413937, 0.04809146822099725, 0.06555580609147588, 0.019888887407198068, 0.04556529329068238, 0.03516538158780144, 0.03117156988610664, 0.052975110198941924, 0.029820160144158912, 0.04251184685516261, 0.04209807893681911, 0.03946907202442808, 0.024216366789093422, 0.07010243066977109, 0.03207689046018547, 0.0841118575584504, 0.009205634255082378, 0.058750761973281065, 0.0891243095599836, 0.03253628657529912, 0.02743427889541753, 0.06446953938012162, 0.03961999517595095, 0.017915033141992266, 0.036620538786894856, 0.061879039877244545, 0.01877062503368624, 0.019970680699653683, 0.04589852238554628, 0.005221995722217065, 0.033034998322686845, 0.09548827855577392, 0.026286683015285, 0.020750173247389255, 0.03964216193004001, 0.02550685721930237, 0.03778764309601919, 0.045164931911013784, 0.014741504339561349, 0.044758583554216934, 0.05132761513513904, 0.021896288662608114, 0.04971539458980964, 0.023825610236775492, 0.015602164860484342, 0.01229083695028338, 0.02034683178569521, 0.08405300668410717, 0.025811999615642334, 0.07010765538941469, 0.042613640788101384, 0.0048799422520753605, 0.07556074584323554, 0.008552778914060083, 0.011099558736708377, 0.045856996589610656, 0.02802308641314026, 0.08180171176190339, 0.0228570835785039, 0.02724521031092492, 0.08770372973935259, 0.012478272809887366, 0.06541149810917916, 0.04440712156675516, 0.013172543821706167, 0.08486334384689409, 0.010758497350428615, 0.012993459278086742, 0.007519601617053512, 0.06697956517699265, 0.07715122098283422, 0.052273320034146316, 0.025095333938577005, 0.014496790958688626, 0.04557580018656389, 0.060332262392846815, 0.016325663084224347, 0.01604923462089632, 0.057866937826357545, 0.024683054146026413, 0.06106804770928237, 0.060298937568140615, 0.045728458527235255, 0.037034586327330726, 0.0052211942027262865, 0.07289792380986676, 0.014457264652235374, 0.08126953346354347, 0.01482973277058092, 0.060338096152390205, 0.03102306374198487, 0.035195638230370904, 0.10057918562163269, 0.028156692147134777, 0.03798573428104001, 0.04337132855829212, 0.040924573963087414, 0.028813311852695003, 0.021697398830926227, 0.062068508742677594, 0.036483746127135334, 0.03290731827878664, 0.07931600925662825, 0.03068485890605277, 0.008484046463103545, 0.0325255804965573, 0.028110723041238326, 0.09262268070972736, 0.018707277223227486, 0.02964581002391154, 0.026550598389979814, 0.009938620477764597, 0.01070948496025296, 0.10340637948003509, 0.05009441275990779, 0.029212512609158314, 0.03538847022179154, 0.10451566713351397, 0.020857843074707255, 0.02960801316094735, 0.05292475140923935, 0.06294598968158807, 0.04781151671082743, 0.020920794434665192, 0.10428865229891193, 0.0460200124390183, 0.05745348783450262, 0.059628338673182076, 0.01637608316096087, 0.057444363727324435, 0.06275532571899314, 0.026497858982052536, 0.02716760560419531, 0.043993158295990965, 0.03844755889487363, 0.03848012529253479, 0.05213773013242791, 0.04599482729850758, 0.02670165560688944, 0.0023423131102801214, 0.015586083717343789, 0.05433356411935342, 0.035208159937493266, 0.035438066754009456, 0.04304798199765144, 0.06795324760699464, 0.044629229608202176, 0.02666453864695805, 0.06609744557570066, 0.020927197014492367, 0.06341822926075229, 0.014060992266862624, 0.02793125545365676, 0.04172005285058291, 0.023289444450769695, 0.03511277049960148, 0.008258913331965526, 0.05550971975730312, 0.056867920868699594, 0.04924913815733406, 0.022742022917936408, 0.007395384290571055, 0.026067465040532332, 0.06584004003314242, 0.025757668660052364, 0.07639724490863663, 0.057015048054557656, 0.06174927224375068, 0.05087217969459392, 0.10612605289826471, 0.05052372077179532, 0.04153683143217237, 0.043015400278231794, 0.011368130968372908, 0.01449894653858557, 0.05758085761279349, 0.02813012804836035, 0.07951685452773687, 0.08710900802285441, 0.058507620987872926, 0.026780057045060302, 0.030268402019095038, 0.0098911393058276, 0.029334883663743257, 0.027461714419205824, 0.0517696516978885, 0.04854619886065203, 0.015390351125519845, 0.04360674354698389, 0.008864484768691323, 0.01978148571065357, 0.03828212220762526, 0.08633889047609222, 0.0602552130998623, 0.06963108741347829, 0.038450868394706524, 0.030205891159693563, 0.046890721160678134, 0.013923919985010741, 0.016520647782712214, 0.06643553549844412, 0.019186354137115905, 0.06545625296571563, 0.01673135643584594, 0.022929660833230423, 0.019674631766974926, 0.010724934080855982, 0.010199697496699951, 0.04425505694422511, 0.06009921078540145, 0.03480484528887657, 0.062251320304048646, 0.05459013845651381, 0.022777096338329778, 0.0021663249982896474, 0.05477257463480196, 0.054646166296856064, 0.04202177657956078, 0.03568250625844925, 0.045597591557570046, 0.028588627840602593, 0.02204516827459297, 0.0164746135593422, 0.033721236902619564, 0.04310761811211706, 0.08480198020415922, 0.08171127508244208, 0.005317788792683954, 0.01050040711678805, 0.03418552065869013, 0.016829917477744243, 0.04736480701173987, 0.06441660270455384, 0.06163140961660012, 0.037857104288113695, 0.01809153788452668, 0.04994782183559672, 0.02639571647910822, 0.06370601018950825, 0.01774299086161679, 0.04353895242656431, 0.07361079926692671, 0.06299303514101813, 0.06609048183646894, 0.02947244432664687, 0.03411613224494842, 0.020318044116720557, 0.12223626907554366, 0.019910460443145806, 0.05816516436396107, 0.028482693202433088, 0.04297753638257423, 0.0316483466210024, 0.043823090607240316, 0.057740954667209625, 0.0284364483048839, 0.04756347659314352, 0.01619611570100871, 0.012303747447027315, 0.039128124593727054, 0.05663371246848857, 0.025161083434678377, 0.0301874456776967, 0.05584590595155474, 0.011111002175077316, 0.01486772690118561, 0.1178486000806574, 0.17158696367855997, 0.13916629126235364, 0.17194016085517022, 0.1559208486709864, 0.13834294592661245, 0.18199462053035537, 0.09755627928121437, 0.1136749760518151, 0.2658401706045674, 0.15805584378540516, 0.1703798542580297, 0.13577036138984466, 0.11392096688430156, 0.12480028874931798, 0.17367686685775557, 0.15525055238075797, 0.1285006236585398, 0.11902986169462243, 0.13330974826408973, 0.20850919938135534, 0.08762685281615104, 0.09621491295195396, 0.19884536793876081, 0.1721547267610027, 0.11998524228411338, 0.13276355821759472, 0.22903756719202767, 0.15720327985623192, 0.12145472915783045, 0.12069773469721118, 0.11023305026033234, 0.20674290706313428, 0.12836291169327113, 0.15651396926372282, 0.11821851329577547, 0.12942341486773185, 0.16192227421749025, 0.1528774877829898, 0.17583299067712602, 0.1201991723369687, 0.07892698214779939, 0.10135360092165009, 0.09333367925137283, 0.11365418442555013, 0.1284331696168069, 0.12704694883957987, 0.14130497892056743, 0.19419432557638616, 0.07837896115116536, 0.0715701325586246, 0.10059708143554388, 0.09222319650073206, 0.21006737625406635, 0.12268511999037959, 0.23838276734515546, 0.2082996896558231, 0.23701933002279651, 0.15341419366098222, 0.18917249665865976, 0.18420129083096984, 0.13605410503523965, 0.12949623918581393, 0.1587567376273294, 0.12946637707852549, 0.11067540474957037, 0.17192206585839873, 0.1393733954718036, 0.14895205325897665, 0.1252113025815737, 0.09920455575470002, 0.1306767347118547, 0.13121065202980273, 0.2179165139433838, 0.13350278709924993, 0.1121175729279076, 0.1314063874944564, 0.18991869694042593, 0.11263511128603451, 0.22109194838952637, 0.1141755608841777, 0.14442294145063048, 0.146226542250764, 0.1629549913829373, 0.1276701690268613, 0.13969509111296746, 0.17873183673908635, 0.24280580661950574, 0.29736036795281595, 0.10803223287145938, 0.21569755559246387, 0.1147024914802563, 0.1262998522349423, 0.24906384097712658, 0.14260291572540038, 0.2364449632624465, 0.1981444740968366, 0.08417601742210888, 0.14014510648144832, 0.15424878516745183, 0.1605728103388702, 0.14297241525303933, 0.19481122553829225, 0.1383138192637313, 0.1721455949929453, 0.15841584382278306, 0.15419203337402115, 0.0989465450026816, 0.11207182215706957, 0.09023152111518769, 0.15813688056603556, 0.16196978699055412, 0.12805267672745452, 0.09274128644216446, 0.16002262131341044, 0.07126479289464413, 0.10011502060919039, 0.11395098987005411, 0.1054970870515512, 0.14307836521296732, 0.16051975108923452, 0.1394615875136468, 0.1411951372339841, 0.12520926478769512, 0.0937656072839614, 0.21582153926212944, 0.10238462503278449, 0.1933583704334113, 0.08499662016308115, 0.12787335086613894, 0.074718332579059, 0.185344600449166, 0.07753871591581453, 0.10283799586637367, 0.07673298294145255, 0.25561260570201183, 0.2239722551237191, 0.10179109075256895, 0.20342378516591367, 0.12491538579906188, 0.09174945538923626, 0.25272459212330084, 0.12607981646133046, 0.17947773058568278, 0.11786631969434601, 0.08698953661106287, 0.2551453227117177, 0.17422311819128453, 0.17883950273596472, 0.10366198471597127, 0.14310785959805214, 0.24432416224191267, 0.13351066248311153, 0.12976496750789304, 0.19450669026663228, 0.10991066514003663, 0.1904813119120175, 0.19966629243666129, 0.0922386484941648, 0.30864753970696085, 0.14478150124271072, 0.109845838779884, 0.10405384635011997, 0.15185825376501008, 0.21302467482464932, 0.10460746744948049, 0.12910286835845441, 0.12778725024432908, 0.1212830871583954, 0.14311466245881974, 0.2727874849111803, 0.23098088710779147, 0.16403773408983985, 0.12524142515875641, 0.11428793832179039, 0.10561004671598635], [0.03471003424736761, 0.015159145789971996, 0.06528611249861217, 0.07419024519021473, 0.06727936602528058, 0.02802436194953419, 0.07229918013176612, 0.03149512903614631, 0.025089406333262884, 0.07154379445578783, 0.028660301111578464, 0.01808065560556227, 0.020818406783585108, 0.06259274270926272, 0.04661884421723024, 0.05034761631020135, 0.012654300662688913, 0.0707278878337914, 0.0617721131552131, 0.03343997538209923, 0.03565372050469441, 0.012442846989048826, 0.009271324379369617, 0.012615433191850543, 0.055816223874928496, 0.04756559099581453, 0.11350600003835656, 0.010511171609734096, 0.013053823176080422, 0.060976699385191166, 0.04245737800374628, 0.05431773291239816, 0.029193852622542652, 0.07315306173216912, 0.0651283520123651, 0.04882631891016518, 0.03687803626000401, 0.02279636153440562, 0.04267240739277294, 0.06657374542086356, 0.014763471910790091, 0.04666885443692727, 0.010055181713053777, 0.028327181184243773, 0.10675103508777196, 0.1036008892040099, 0.04389368560946277, 0.044082212186748945, 0.07793207908229483, 0.06824251474632372, 0.033829626852586385, 0.01754848688330141, 0.027977373946698445, 0.04408212025619803, 0.09241161582570884, 0.05640688149498836, 0.033287539206925905, 0.05265731777575228, 0.023169980699857397, 0.033249269284668474, 0.07406036264353222, 0.056750180815616925, 0.02842541855399407, 0.017978721861577323, 0.030583179886302644, 0.031177455356584925, 0.059911879305277145, 0.06323300069198012, 0.038265712604287176, 0.012515080461819327, 0.04025400188120623, 0.050544837985428116, 0.11423619674338449, 0.051158780847946485, 0.03305970848868451, 0.02283596253443149, 0.018130185105086818, 0.00821499063843681, 0.07862282225922232, 0.05968377279538301, 0.04663801939797498, 0.0825650877349319, 0.03980662568562454, 0.03724442930111001, 0.022397913459327914, 0.05028755884737738, 0.002764294448781819, 0.07218097276504963, 0.02317613430110918, 0.020445036596708724, 0.04902687689830219, 0.025573133400851683, 0.0456115611708693, 0.023250387373170065, 0.03375299507752061, 0.004976704902571416, 0.029074005827668215, 0.05720871508181576, 0.010126573446717475, 0.007311873045945241, 0.08358928600266095, 0.04711622680206934, 0.08608726123648305, 0.00956695004847021, 0.018281035478256883, 0.040423904861053156, 0.012281960864070685, 0.03502204653716857, 0.006211201008784795, 0.07620563099701559, 0.0262642749434998, 0.012918989786187248, 0.06034533185283504, 0.026006810029127428, 0.01357448813054831, 0.02823338329401468, 0.003888336955682345, 0.02225288343916257, 0.07149890936430424, 0.05504945030195579, 0.0158736405653819, 0.016504697832128695, 0.05599640009384002, 0.03154194275397928, 0.031264128629118204, 0.026469477339677756, 0.036579786739762754, 0.016469023032714764, 0.0444259749905717, 0.0626436760649085, 0.04937285752666574, 0.0222763525427229, 0.02506844233721495, 0.061706421115706046, 0.0389356833071478, 0.02459900089419417, 0.044571979857620694, 0.05532829864551464, 0.024454296461396643, 0.08335196728547735, 0.044400035253455566, 0.02712682482876605, 0.0405401012469684, 0.014405697358832245, 0.06028516713770167, 0.0545177776216259, 0.04071632062175101, 0.028301915604501005, 0.07211669032732326, 0.04036926363985385, 0.0397780544364885, 0.03420245503225634, 0.044688145600018964, 0.0355461924036424, 0.015167876319479079, 0.036959858280756784, 0.07280400143034997, 0.030659170062731833, 0.047055177255383426, 0.04005739690675851, 0.0462709675212541, 0.07312482373128015, 0.05701956031243167, 0.0474295835761774, 0.045532665605987274, 0.011020062750415697, 0.06922958073236289, 0.011373640098158392, 0.015173961930427582, 0.07645100129828339, 0.05358098615561763, 0.010060507939347338, 0.050180084372480074, 0.0843395465504258, 0.047162303160275185, 0.014853967962065532, 0.041466680760946006, 0.0296325586180413, 0.034584085562176285, 0.07531646338682021, 0.05365508984053328, 0.0179694292150558, 0.042284284267694726, 0.04320487297410446, 0.03444716649790926, 0.041259668482046936, 0.0499661275065474, 0.042060862385457566, 0.0032184907421094157, 0.050661313993435715, 0.04525932926504363, 0.08120381844139869, 0.06130692924583151, 0.01739916102510066, 0.04835470752309888, 0.07019623813609924, 0.04053216457607285, 0.021247145975188866, 0.005118282260223022, 0.05476702815823017, 0.059021658324185884, 0.017398036791071776, 0.041371011700961864, 0.034104752008833235, 0.022439674827300256, 0.024930303277928504, 0.048528195794431433, 0.05542136300655623, 0.06261210558154891, 0.023452173017205733, 0.05902246271650638, 0.06776666689303613, 0.07756986505081577, 0.020094583930087187, 0.015153742954886008, 0.016102459537045612, 0.007545118090591484, 0.05566222488038963, 0.04839235308369802, 0.04585156885666713, 0.027589246991180608, 0.05166738279043667, 0.03765559635095058, 0.014124365932788822, 0.0878111505880952, 0.046161133495550004, 0.034251894516449784, 0.04949881004229669, 0.029707035770820036, 0.04972593595964774, 0.037783490899469585, 0.031051422401721922, 0.016129538829949115, 0.054719013597575895, 0.02115006348298442, 0.019145063913216995, 0.04251755804063813, 0.07240703765062556, 0.06793955761578775, 0.008423935374124877, 0.05717404960324207, 0.04736027943210737, 0.0628703078555484, 0.03832672767701649, 0.01074216531349286, 0.053977605195776115, 0.02719434398797251, 0.03826631015286811, 0.043229793814281305, 0.027094172246213404, 0.019705244640429175, 0.025503541973810044, 0.022540130021591342, 0.039418295716806766, 0.05739576310940808, 0.061551901181378675, 0.02451029174300211, 0.04924858274358896, 0.06033444957387063, 0.097415326764026, 0.03179391673315437, 0.033553118907636216, 0.04921154239245, 0.04662425662841528, 0.04302183924723537, 0.043219497592578975, 0.05108586076887385, 0.03303403688234187, 0.052423082562463905, 0.015139381679135467, 0.07699323067020986, 0.032938578496536905, 0.06049944576056254, 0.02863803093561963, 0.022300394297006632, 0.027797722498015053, 0.06450325490966921, 0.043838282130778804, 0.03970845534856762, 0.0272932248715792, 0.041013478466700164, 0.041458636837741064, 0.022683286956781824, 0.023100728266722253, 0.023961389745255152, 0.05559537987855654, 0.028281566394012303, 0.03396127523193437, 0.022402017775382248, 0.06755373275448238, 0.04043186451458643, 0.05166013559867298, 0.03018026168818676, 0.07815629769597324, 0.02926303802298442, 0.0363362129146774, 0.04603730687390893, 0.059843122914072976, 0.010995947260169253, 0.008828716123506667, 0.020698351229751305, 0.008856351787765181, 0.051568388908861146, 0.03690067032772688, 0.02533492219123629, 0.020307194396492936, 0.06268043296351548, 0.015488279187270712, 0.02742660269441624, 0.09283982833186466, 0.006637038163570387, 0.021619332556222236, 0.03975524416854305, 0.07721368779218005, 0.04931251278087016, 0.05874893485358166, 0.05593918481721513, 0.027839596863956224, 0.05251291786290465, 0.05394094405815967, 0.043793849031170534, 0.015818391261892696, 0.015493863968238717, 0.005833293187371906, 0.04671364376742033, 0.03033158129021045, 0.03444975970553295, 0.026610067880321896, 0.08088786845966693, 0.02513336637357791, 0.04554142965184105, 0.06898441727483465, 0.05968895154975115, 0.029009491648344748, 0.03298250597811515, 0.03608079920072229, 0.032865271543062506, 0.04111988041850348, 0.058895947126251076, 0.045249270530597824, 0.012192856219987716, 0.047967519025288285, 0.04111498894710695, 0.03951602555330723, 0.048472895737617254, 0.07006113086977313, 0.025098829214731534, 0.040860896734821225, 0.04469489100419226, 0.07828743662685156, 0.06373711718967365, 0.037899051432407675, 0.1925784929264938, 0.08980835712845288, 0.16819872532881078, 0.1508967827765211, 0.2025635603574976, 0.14056107690257413, 0.2004485141726271, 0.13410788930712209, 0.13169362450078612, 0.13650323174172832, 0.13566398242067906, 0.16459008348324608, 0.1312606009624658, 0.20229466349607517, 0.14772099592993337, 0.24092539784408387, 0.12580449978310254, 0.10830459245029958, 0.18161741415819815, 0.19518693037811788, 0.13410825702932574, 0.16600981294628114, 0.11497856658552924, 0.09170163618100267, 0.2788264640877324, 0.1840978229959165, 0.17311077384698778, 0.1106438955532447, 0.09904069720857567, 0.13826115837981626, 0.17942985009041526, 0.13479074943930874, 0.1679187814795202, 0.15047226281416032, 0.15196392793328534, 0.14350895259168842, 0.18598766997456553, 0.09926883053154716, 0.178167367834718, 0.17040315865268632, 0.07748345033295694, 0.18840653130844717, 0.1275166679894732, 0.1232725638715971, 0.17612563626420114, 0.2588494650779232, 0.1720088789419782, 0.08832874257237681, 0.2056667833558975, 0.17597753614667924, 0.12541072292914315, 0.151803509121941, 0.11311272114154794, 0.1666496189371232, 0.19621272210872945, 0.08315244734647774, 0.13295354802281628, 0.11151109176177172, 0.14246716494521788, 0.1498178245439645, 0.16965515040341886, 0.09056306098617854, 0.150802124952597, 0.04115467230158468, 0.2701085980140394, 0.14969416263122715, 0.17755221455327927, 0.09360630696098651, 0.20408559320194108, 0.19044406471713898, 0.10197443091460776, 0.13966273155904588, 0.13851637291091104, 0.19428273212284813, 0.15718527679001132, 0.11504602062726214, 0.19574050551220296, 0.10619632614355896, 0.1831157442422644, 0.16464473619576425, 0.09538298743146081, 0.14780989277266687, 0.16838759664566288, 0.21736387343656635, 0.1758549314352774, 0.13130014642111718, 0.0870164952451183, 0.12138374345076662, 0.13321132128757815, 0.18949057636482103, 0.1924577268261102, 0.13611393650212597, 0.12223482883024601, 0.057802387257857676, 0.16505879139707935, 0.1565136628285531, 0.16426264218265013, 0.15699559341995947, 0.12783338405912922, 0.09140155954106201, 0.19737250261729766, 0.16203704951030595, 0.10059826887182652, 0.10470152006394441, 0.09741827620253449, 0.23710844137014883, 0.18116142330390794, 0.07418610065454438, 0.21153083401581935, 0.21916303092673903, 0.0961912944612484, 0.08400967675110987, 0.0905387300337034, 0.14568327866013975, 0.2712987922132015, 0.16669091107624193, 0.09820144022664717, 0.1539123653163833, 0.17983114226691185, 0.11791766290703129, 0.15914802469553488, 0.144821107988396, 0.08687976387239273, 0.08713258820916377, 0.17975151508806214, 0.09201980781771484, 0.1552735043749694, 0.11903588314570727, 0.12335073548339068, 0.1989397193275152, 0.12175219343794931, 0.19561053103496953, 0.2075216047946484, 0.2395511127167171, 0.17600280172642202, 0.0851946232479907, 0.1720465551460943, 0.1810511679298455, 0.13820656695433203, 0.18643077522996934, 0.14893418808858241, 0.09842590398846135, 0.1489486824721098, 0.12508754873828543, 0.1578900317150739, 0.10188928024182398, 0.13572962083403142, 0.08612640066853455, 0.14501174130747396, 0.08122841752464734, 0.14164942737308242, 0.11887207822573763, 0.11950120495091524, 0.18850387044010625, 0.07481582492830292, 0.22914520254538906, 0.16375912323353753, 0.10250058776188282, 0.1595656958318526, 0.12846945920178007, 0.15780896429092656, 0.20496820309950461, 0.23715783871950644, 0.17092213725611088, 0.21194508839999476, 0.16933871012541557, 0.17875020752751059, 0.15311091477351804, 0.21927809733296597, 0.23423096916127592, 0.16269148778050177, 0.17110241306645257, 0.16898675401124263, 0.1549910477572872, 0.1386696211392841, 0.08188780472283402], [0.04363387072038266, 0.06605960849312044, 0.07369873849975486, 0.02886006236827422, 0.04942459910507164, 0.02573911784096591, 0.06526046387490726, 0.03487851230367538, 0.015831782478809116, 0.050233300670140216, 0.055771484340150515, 0.1027097297652114, 0.019777195618277597, 0.027181067684244727, 0.07926491119207875, 0.037367359599879676, 0.05764717784439845, 0.04747723041462803, 0.030091270999682528, 0.03248960117719347, 0.03472691116433951, 0.02331665589384014, 0.037406296018631234, 0.07003676161290177, 0.011918544074550513, 0.05620861794018457, 0.013515899641319148, 0.010512784224814706, 0.05321837758885757, 0.017672100915543495, 0.009853509066986942, 0.021443161061934887, 0.08788038961469166, 0.0339030793627664, 0.012172402630019332, 0.05182237386883748, 0.02939758221468618, 0.049560832520646435, 0.05341072694488591, 0.03536572890175927, 0.04214949109741757, 0.046583703764143496, 0.14588171075428688, 0.026988304640737273, 0.049460191550033714, 0.03041505231522024, 0.03185315831233898, 0.058032849488118966, 0.1344664797427193, 0.03261733867768799, 0.03337209999200798, 0.058224643430402206, 0.012641709050043456, 0.05042502566451027, 0.03642019147293703, 0.02556982773145841, 0.03701949822566202, 0.01879291436184318, 0.06104889934161498, 0.011664970886833485, 0.05015370030436785, 0.07397948674136594, 0.10489458954262157, 0.03264655727112005, 0.046555814333260066, 0.05240260503224788, 0.030254055107493075, 0.0694734878056953, 0.0024375522034167643, 0.01938669762063411, 0.09012149556750253, 0.03120137070636115, 0.020815656527936943, 0.07086945322131918, 0.06313782192826753, 0.040293325174359546, 0.03336245111460167, 0.06551081374768289, 0.04751849191022977, 0.0322286294953477, 0.024801661793683327, 0.0071630274291120235, 0.0195085400745513, 0.056016923589331497, 0.03705019919922756, 0.08150519743081062, 0.053329529285791426, 0.043756601836292014, 0.01850980465420552, 0.06948144745922859, 0.024040141668651375, 0.04214825003498024, 0.053152237387914816, 0.008067865367798556, 0.0621244025176331, 0.023614780924793695, 0.03629745269614843, 0.02919693229599826, 0.07558026576354619, 0.025273625581194798, 0.014156196886042674, 0.034456554905421315, 0.019253091886639595, 0.04615541464919525, 0.026077441420526277, 0.029341347530604373, 0.04980845895085124, 0.05908400638990345, 0.05313060689537276, 0.023821795118912577, 0.04032638186829225, 0.040813265218129086, 0.009118032100940905, 0.015846338149370448, 0.01516389457749263, 0.07339953520004788, 0.012613336026157825, 0.02389600988657725, 0.05147881407831466, 0.038643681233929056, 0.08350526914000513, 0.030038709707197644, 0.04184400587673149, 0.0025330512876427106, 0.034068523710894014, 0.030848675317341284, 0.013930986188502322, 0.016493026482602282, 0.032585423454762466, 0.030727543409973867, 0.026800086413840615, 0.03740636113610479, 0.028014841391855193, 0.039917176003537835, 0.04400667591741489, 0.08969018806613262, 0.054679096586281256, 0.045711926349829284, 0.06989616915703782, 0.03979419973949271, 0.034498161140588984, 0.036969315636182026, 0.05024979454314998, 0.04801941382127905, 0.050675015475961475, 0.020695242827998537, 0.042409849908923915, 0.009703049398658257, 0.035071750321695884, 0.056781969634034944, 0.024288771674036983, 0.04134465444592699, 0.009468054800714937, 0.053886513511139544, 0.11172101517478306, 0.04998991070615669, 0.021237732669819268, 0.04013217091860791, 0.03744116451050486, 0.040630610704782515, 0.0980457941430711, 0.007638475480264114, 0.03765034098779002, 0.05129066288411137, 0.017888997643885594, 0.10242003361664473, 0.009586828114885476, 0.01979317621237809, 0.04494824394163105, 0.047697388762307745, 0.028269561796238827, 0.03436013124883175, 0.12086856464344649, 0.0319707298260783, 0.028882501083576394, 0.024627401688767057, 0.03402124076420742, 0.015645089724491683, 0.04129120066101032, 0.07054313806997192, 0.01858024069318368, 0.047064933385099136, 0.02734295929962349, 0.028582811318037492, 0.025141354755408345, 0.025617193032596863, 0.006710871802492729, 0.03267175007251001, 0.027645391659931313, 0.015037499646085405, 0.055944876850492535, 0.024047059442607627, 0.018120222131631548, 0.049434443334898645, 0.0816060452451629, 0.030193986153350245, 0.01793625952315427, 0.023208503431129842, 0.03677526556496178, 0.07390794179011738, 0.03862360206943366, 0.03960466958702572, 0.0746456001915278, 0.013586693826401907, 0.03888951501839104, 0.10607286341368191, 0.046153909286424044, 0.03247396149221928, 0.03200877566761788, 0.04144027371019606, 0.01274924002392518, 0.009586520722105859, 0.022048535231020183, 0.01718406268816081, 0.012033715817867028, 0.034690039352543896, 0.029239067131833687, 0.06434379370823022, 0.05046631397318937, 0.04674838202434682, 0.09672675927680346, 0.012913389683460758, 0.082180886980026, 0.12620220666811352, 0.044271263534263264, 0.017525207386502338, 0.0862690692226733, 0.02197890358436252, 0.029521133044674516, 0.04542541329658801, 0.031688681150215774, 0.008705696767015804, 0.029692999124827407, 0.018697327656310894, 0.015834905244710467, 0.01595023595127127, 0.027559298699000673, 0.06729555346312062, 0.03859833265925127, 0.03863067689141439, 0.041577238739738544, 0.07124467542575252, 0.021165578678670912, 0.057591686265603195, 0.03742074826732278, 0.02734291141912822, 0.046042566067509116, 0.09009175603428195, 0.03898003979796364, 0.02680089272138092, 0.014946846546785486, 0.011421660404472102, 0.005550449695287934, 0.011873278811934495, 0.0285713583035695, 0.03247999443462299, 0.07323691771636087, 0.05021149397737557, 0.06030975089919183, 0.07547195625281142, 0.006724618292684037, 0.024396814969218066, 0.07461959916737772, 0.015465129925418767, 0.07728104224248279, 0.03479441500178749, 0.03609991309443309, 0.025822577374656836, 0.05755333590411371, 0.027101928886446743, 0.05847718048420164, 0.052282114723517056, 0.007227921779567917, 0.026453119447274555, 0.029593988006273587, 0.03029369632713497, 0.045977552015815056, 0.0952513505434317, 0.030170917330730348, 0.09817487995831237, 0.018790355628176082, 0.03383904207317579, 0.04273952435581915, 0.0463222264642677, 0.03284454886471072, 0.03773608920915473, 0.1433083601295948, 0.06072138143222659, 0.005775893092035286, 0.015926102266436624, 0.03060068499537245, 0.03701149260685329, 0.05692833073196873, 0.11615128631913856, 0.01678047416311118, 0.03431619993681389, 0.008657805738039315, 0.007070322171784938, 0.0051722229897765626, 0.06809819910314775, 0.03170914718911293, 0.025594300410199552, 0.007834616971517643, 0.042430442352328575, 0.03557633413302322, 0.02937796653338498, 0.05318170495992226, 0.042242409901753555, 0.02076104786547442, 0.02694459357899764, 0.005981509175692355, 0.028161589364190737, 0.05102951500204302, 0.028449197923163735, 0.10059050074027431, 0.02707601979284758, 0.038136550180253484, 0.02480156411747298, 0.06759104123639484, 0.06790236404706394, 0.0948496983056107, 0.007918555310161245, 0.048036455447154666, 0.021977467169504494, 0.04514353507528863, 0.08339361182504124, 0.028543179674494653, 0.06287455964352816, 0.017218578779589266, 0.029331244746102925, 0.05300581883338671, 0.024808818970115918, 0.051477032923890706, 0.029475271191087463, 0.008246813930811421, 0.02142527673934256, 0.05354716720420027, 0.0030365156529906898, 0.060091925289241545, 0.04194945404906908, 0.0263520973479195, 0.02196705794983333, 0.029458061025868502, 0.046637647845331705, 0.036388866137713194, 0.016038912543726545, 0.025585452094674114, 0.03410954771923923, 0.04929321502605754, 0.05054635100907857, 0.02245084055879664, 0.04567243834777225, 0.1546209660028258, 0.21985894519715543, 0.16417736127491922, 0.11689780069695366, 0.1578909969858585, 0.18700731768002435, 0.2078810379269623, 0.09966898123703657, 0.1719843794501597, 0.0891600322398928, 0.17597585075324582, 0.22247079940092182, 0.19363898844007524, 0.103720031197994, 0.12184130478530161, 0.11926986171954101, 0.09648546456329285, 0.1316342220431374, 0.22774287859999368, 0.10344839174180262, 0.09009522641257894, 0.09007994295848955, 0.1648815646166763, 0.20185543464556818, 0.10053246191913083, 0.08274713320837868, 0.0926213094123429, 0.0883105556450544, 0.13274730183184147, 0.15414046033495857, 0.17166430791539533, 0.17617532472696998, 0.16814614105368816, 0.13777927375368534, 0.17195027321577075, 0.10159170870939571, 0.1741098597525589, 0.13429081578168178, 0.13485692411420808, 0.1377502543431136, 0.08848943717537389, 0.13870751184801902, 0.2684227142843508, 0.11204547639335356, 0.27822539150234193, 0.26464746363701364, 0.17755138717832106, 0.21894328626653842, 0.28051918132170556, 0.09437455525321346, 0.24505105710798697, 0.13320660218596458, 0.1584519725292921, 0.12359765328226552, 0.14331281876131413, 0.137148262452214, 0.1274617777896985, 0.12255522212193859, 0.12966275605703556, 0.1585151288177698, 0.1864291204800529, 0.1605662832697553, 0.18965022908824106, 0.14904232905997386, 0.18692827272799709, 0.1632111405412997, 0.12579660141660323, 0.11716824505598315, 0.1025098191213704, 0.19562744625633766, 0.14951695117258257, 0.15622703869256283, 0.13050856309071665, 0.20049294727223538, 0.13793780798873595, 0.12264827882210094, 0.09350897549020667, 0.10832222013343727, 0.12342042650186247, 0.06643440934919542, 0.1101254302287294, 0.08304633650808566, 0.15859759052193936, 0.17629192330904547, 0.1344217708514583, 0.17175401681132857, 0.19417417746397758, 0.19500607234095374, 0.12648670107967433, 0.16850836274604644, 0.11831742290767933, 0.17924845579170412, 0.14593355958500218, 0.12208735690482202, 0.20084730890249053, 0.11891468037520686, 0.16379591077566147, 0.135119968063889, 0.24990146619177636, 0.0845939566892001, 0.10854187286308697, 0.1486822064485281, 0.11036258040656967, 0.12105278580659821, 0.11888857975962663, 0.1036288284306084, 0.169706646833689, 0.12428854201589862, 0.16587928688574224, 0.2255306924663244, 0.2254508354610974, 0.1433982222431129, 0.1494748929455396, 0.08182205139629303, 0.07167461162973797, 0.16461989962525908, 0.16621210612356666, 0.11183156166225673, 0.10629341246620302, 0.125396236206495, 0.17810813391641264, 0.10993987607258944, 0.16556264742487864, 0.1379129407747138, 0.29639102158046543, 0.1300199215690936, 0.1213838123986798, 0.15679463323566223, 0.10294410670476575, 0.05217330342519188, 0.05580153030854079, 0.1450438403915013, 0.13089802686966237, 0.16515849007954522, 0.14653066383494487, 0.2237654726711973, 0.20159969917468487, 0.11667350547448282, 0.2240161213182634, 0.11286784113655168, 0.15446958702898797, 0.10046613402664663, 0.20865506252213833, 0.1407128389203741, 0.2226605134144906, 0.0719425585421343, 0.08111558043428006, 0.19273748681429895, 0.16309979732238478, 0.18224929879990318, 0.13477302216474088, 0.15669413782175512, 0.04412526632809351, 0.17477022754328866, 0.23285918148054233, 0.14523101099316152, 0.10994248843241124, 0.12326324824243785, 0.08751278998510492, 0.11567459576913428, 0.18256763897595868, 0.15986097676138725, 0.1518698370144252, 0.15045795229173478, 0.16004932713845085, 0.22717955882751176, 0.10024736229810985, 0.15623405605794924, 0.13660277720660935, 0.14797061801918093, 0.12016944812550662, 0.09080904415778576, 0.19336489750252617, 0.15514660957119158, 0.07051964981421348, 0.15196772772938977], [0.03351170419444961, 0.04781002666981471, 0.08365675536615234, 0.028409688853688782, 0.030808507412251447, 0.04579701956601874, 0.07611699462417634, 0.026986554129830292, 0.016245231513054143, 0.04112731913224824, 0.026530002116135536, 0.03780640075884519, 0.054527736764641545, 0.07233736195391224, 0.03275741785464268, 0.021611673592199242, 0.0648856476970738, 0.014653509565358682, 0.03010331964751165, 0.11789007608087794, 0.027464183137541818, 0.08478240665769385, 0.038818169250002796, 0.05460669744699713, 0.02912474383089331, 0.0228919827138945, 0.10528491900092173, 0.04349706656930428, 0.03294429734289166, 0.02558820043510247, 0.03911410518471272, 0.04302375446704607, 0.05034773888426924, 0.04454643082534594, 0.011579562616985173, 0.02504190122107825, 0.003906354386051516, 0.015729169789401275, 0.036880671602463534, 0.0356763584028569, 0.062394011840825124, 0.09502208341033229, 0.0786241782348483, 0.044145962193367944, 0.018919855130896456, 0.07112616928474558, 0.03431122802618531, 0.03290232338552033, 0.03932227808681708, 0.03792150929990796, 0.02341010521406368, 0.053298579333650495, 0.020388307785915754, 0.030915480099558353, 0.021000829555334586, 0.044537555696743156, 0.05719262723540587, 0.07902435192297544, 0.036650408555062554, 0.01580070420694087, 0.0137881979331254, 0.04958984427033894, 0.0533007282102781, 0.056141753786153374, 0.011023825199733819, 0.030719461182372707, 0.0252919523195634, 0.046170280585365917, 0.042074973725022814, 0.011231815198346252, 0.057002315673256115, 0.07565722695641941, 0.018100767328794447, 0.07496141993831243, 0.02973943937479729, 0.009363195558469142, 0.05768908285385659, 0.05779628153710116, 0.025115221581091324, 0.04217525463431113, 0.05571729128038692, 0.009805149766766738, 0.019829963754502036, 0.030485484523758776, 0.017843593527833303, 0.01645948715327728, 0.05563014494856039, 0.021336814651506084, 0.04570910331582831, 0.07583485976342233, 0.07564085565747754, 0.021447629269753254, 0.07224471894122901, 0.03582964493562618, 0.04136594019890313, 0.06652984858280228, 0.05111506404054742, 0.055447616839721325, 0.022819416950486844, 0.03816611734369109, 0.02096901392383922, 0.020705215377552856, 0.010332547676479144, 0.018688937078320214, 0.026836061902764826, 0.014006906459408422, 0.006061477263668372, 0.03484817139143425, 0.013340905049605476, 0.01687918459215472, 0.04211018312602274, 0.043496825251608126, 0.0379059998498809, 0.01768792446161951, 0.047734586161471186, 0.04571229024159332, 0.026611831797767552, 0.04988619389252798, 0.05631113965665141, 0.01184021445712255, 0.03551862856012679, 0.006726033640124145, 0.04289053560745332, 0.045906673561060624, 0.04421107966693179, 0.02987619947582003, 0.0779724519159044, 0.0016630595763995042, 0.09241424350728912, 0.014449035910318696, 0.01860537412275951, 0.019783330067331274, 0.035144712535604354, 0.045693827522618156, 0.02135912121664132, 0.021526976826510603, 0.023442780779254054, 0.029700052879390218, 0.0607229212689544, 0.0660448000135441, 0.016605922944783684, 0.04035836986957058, 0.03401844837372342, 0.04634890930667039, 0.04565714723280361, 0.04759939079503379, 0.04266820540050826, 0.05543895238529771, 0.057706545828090566, 0.06302789597201251, 0.035099635922139695, 0.032900994222971706, 0.019172399845575134, 0.02334353600388333, 0.04449080901160356, 0.04664469202379546, 0.027747832937166098, 0.05192541652509282, 0.07350787535429963, 0.04245633229372963, 0.027764824767326637, 0.03059369061262377, 0.1037509045413425, 0.029286283045826905, 0.051314541844711195, 0.05609642819411332, 0.07033355173564727, 0.02993593901215542, 0.02869511406207758, 0.021006973580487316, 0.02248664367793789, 0.06430343619637913, 0.010688601403437074, 0.07648737515292822, 0.045780357153665636, 0.0821373425424099, 0.03400405741206581, 0.04122576143051829, 0.030806042524355075, 0.0126486431033681, 0.052858695477968266, 0.04143252090040234, 0.0639781859072466, 0.05071603565386707, 0.027667384129017595, 0.04759233895569079, 0.023813705230432174, 0.014452521610374173, 0.037465024318906574, 0.00423849156622084, 0.02138533866063001, 0.032905832068213535, 0.01694195209101083, 0.006433831426435181, 0.028686497488149235, 0.07868170377708252, 0.036224896508839824, 0.045354412267765695, 0.004430875396205774, 0.026831631999342676, 0.024530347924859777, 0.05515122125225683, 0.10168985989425453, 0.0744291343876431, 0.050407934242919575, 0.054883695688218846, 0.016071442552211306, 0.07414342189628272, 0.011588735562268526, 0.04913908962701117, 0.033019795307829496, 0.03222594818761272, 0.028184734795603062, 0.025459639390089342, 0.00997700339799086, 0.029025081537603855, 0.041074776991961465, 0.06635252221096909, 0.021659894996593078, 0.16412416412945718, 0.04668524105762763, 0.014805216041784135, 0.013459079857585172, 0.030005170377872648, 0.07698025314077254, 0.06841930485660992, 0.046055072452873, 0.029696295218121622, 0.009088811592289038, 0.05822904077508758, 0.02854303028734942, 0.06867577577190054, 0.047842313445383505, 0.03022008485371067, 0.01777558215713549, 0.042022297519349286, 0.04841839624268394, 0.0031197025072610667, 0.013893394254057879, 0.06519865590117632, 0.05755865638474784, 0.01690677716396749, 0.017650843890864524, 0.020322491257121007, 0.040806868383961345, 0.02699562078041415, 0.05895235418011585, 0.0502528052686924, 0.05842104539154999, 0.10843618337305323, 0.04163904671346949, 0.033405918943425345, 0.044517430566972306, 0.04930640706011365, 0.04317375448262019, 0.0765226841453583, 0.026077472064043247, 0.0029181076669990416, 0.00734807740363683, 0.08578132402392165, 0.07824247492657554, 0.06119420323821326, 0.03946395455709389, 0.06020731345239667, 0.03626679768785834, 0.053896675667455124, 0.0675511586990568, 0.05880466391963344, 0.043526139606030724, 0.04156206253795855, 0.08120893590873288, 0.03943575486060112, 0.04943530518381346, 0.04785155629618995, 0.013240369416082339, 0.007330481800430965, 0.03886952395400694, 0.17250580953494196, 0.013736719697443469, 0.026972768377632867, 0.02090901200238976, 0.05025835557570381, 0.07130644509508725, 0.0798240481244941, 0.042712964087484345, 0.04332435970765449, 0.03206346668453226, 0.03671569839840935, 0.0246474540401851, 0.019539162524104602, 0.03433669278878839, 0.04253156978877322, 0.027156154504947128, 0.04261840585499041, 0.04452221478605944, 0.015606877258828571, 0.01257885440868596, 0.029097440457271955, 0.041289132223614765, 0.0333970170017452, 0.03613305405803746, 0.04583623943730228, 0.025917604836004398, 0.020669483121544607, 0.11717545394335063, 0.04064430835686865, 0.030258833580920776, 0.08692850238613545, 0.0350711987383904, 0.03505439843021093, 0.05656682916225926, 0.04914957737069457, 0.02203674896830513, 0.012049649489082158, 0.03433321474961216, 0.022119038302691716, 0.02835814645814319, 0.06229894799030116, 0.036254222354581284, 0.040655631136389515, 0.07567889958379731, 0.012915519407890257, 0.030855991457018162, 0.0262443911314251, 0.015147440924098896, 0.015546059453739755, 0.025926501032025106, 0.04307268450276987, 0.030757786646004648, 0.061693405281872525, 0.03196893143467605, 0.030977634728075038, 0.01543928690690307, 0.01557364340706338, 0.05044523123351317, 0.009151423000730574, 0.029920657473285834, 0.028768170121756774, 0.031207803929705295, 0.013976629707030954, 0.02458962972366041, 0.00709859847707013, 0.025179705116897825, 0.04301553817405816, 0.030310778172626614, 0.07230717042881636, 0.028816925872477795, 0.030029938000464634, 0.020048769956995404, 0.013086911471140002, 0.04126805331437819, 0.12142754835827697, 0.11057014426877422, 0.17127170317596005, 0.20967172248469246, 0.13805428399674355, 0.10588180108536636, 0.3400264397984551, 0.1509231974881503, 0.15057392268171235, 0.13333870638762751, 0.12636446409047614, 0.12493631532115322, 0.1103512729488073, 0.098596366212493, 0.1906205866966517, 0.11467140363228899, 0.11772064807554407, 0.16650853618498773, 0.08387847653319759, 0.12982096853515795, 0.2194998185000112, 0.11390756034562666, 0.1576608948169216, 0.12732895346538675, 0.1529068442722482, 0.1326259228611185, 0.16912771418931025, 0.19647994889847695, 0.15598066481611422, 0.07595526580248149, 0.11794586260352405, 0.1407817102247669, 0.18014634148247782, 0.08733246820948778, 0.20869097672402862, 0.09512322999897505, 0.1400934568335933, 0.16992872040117943, 0.05987850851529549, 0.1556119620199165, 0.10753036867226325, 0.07266262756480325, 0.21403589556294106, 0.12206068938417781, 0.21007652334388227, 0.10324994432589701, 0.07632430567736588, 0.10318787588227181, 0.09313254286685298, 0.1907578236874073, 0.14889931576626916, 0.13813527481209847, 0.17810215843060326, 0.1728991803623015, 0.147137911089005, 0.1007989302818333, 0.1408360105368399, 0.13912749656986806, 0.21186184528614246, 0.13167310866617388, 0.1399321800037738, 0.09059565036647743, 0.25162615993570897, 0.14200001985075014, 0.11986603900309532, 0.095263822454839, 0.09402672069207316, 0.10112474747602979, 0.20249300365967138, 0.11599000948931902, 0.16737283658116095, 0.1427319402536077, 0.13519414069671787, 0.16418565034625993, 0.15547570562170399, 0.10582987564585863, 0.12604067702927899, 0.10535464066291049, 0.12275491060028154, 0.1061260682200232, 0.11630612034951487, 0.10389407871351128, 0.15463867795563516, 0.1414584416535593, 0.204254959920241, 0.17086103408327027, 0.11388053276365805, 0.21058321389700138, 0.2047906239186564, 0.10992666871677484, 0.18213691370141122, 0.22695564664900306, 0.2228519587867683, 0.2086098480128473, 0.14795241577010002, 0.18406838989786564, 0.11376047912504404, 0.11360006797457896, 0.22363012025673545, 0.1648740263115014, 0.1186426655359326, 0.1747317546077313, 0.1981620328320611, 0.10449914261698724, 0.10187232671605964, 0.12268869762098598, 0.11829558174095808, 0.14455754309892654, 0.13556080569903697, 0.08423869873607352, 0.1313749778895609, 0.2849379151819214, 0.14377011196507564, 0.12554706359702733, 0.10800633143873946, 0.2118316767436843, 0.17358893528580668, 0.1073658666122825, 0.1462087536891622, 0.10546751605767397, 0.0659174608787702, 0.10022425708631355, 0.11142945743256039, 0.181871494879165, 0.1552864972261652, 0.1666610183254365, 0.12300280133082021, 0.16269904140743519, 0.18018214843205868, 0.20096559287799945, 0.1384886405280521, 0.09326256330936186, 0.15055755904364973, 0.0637642941587875, 0.1573630091884444, 0.09597270659381345, 0.17627673944638622, 0.10424262573642117, 0.15591588442123708, 0.09490039034356033, 0.15750052197085274, 0.10530855281338578, 0.23266185255300617, 0.17450257174430356, 0.1788320716830992, 0.1365665106042739, 0.16765348523134188, 0.1562559355290667, 0.11868869975930262, 0.20346359109445927, 0.10919760582187485, 0.17453945121697842, 0.20104894324416117, 0.18770542296190418, 0.15782523599843826, 0.13319140300154686, 0.11378647248831489, 0.1662317332961867, 0.12095376894238496, 0.16156806580481992, 0.12427562577349525, 0.09124720814607798, 0.09205991252055092, 0.1843003153560623, 0.2269484607442733, 0.12049636082543481, 0.13379940102177282, 0.12851767677573428, 0.21553312248039633, 0.08110435724618935, 0.18447076991921474, 0.10505424992692088, 0.154694204008387, 0.14254555106163025, 0.23795314523721897, 0.16925039550950452, 0.22319060029281726], [0.020648040320543994, 0.07455306443115396, 0.017156360948818828, 0.03842083391763511, 0.0052723363173314405, 0.08685639819070216, 0.03181866711876806, 0.020744157541963845, 0.05088195114606812, 0.031706174767966715, 0.05289221565509516, 0.029027324260002183, 0.02668909942581048, 0.11937100064730453, 0.07306816386840037, 0.010537385223283163, 0.04164237536550049, 0.06906664149174768, 0.13510582608080682, 0.06420383710534343, 0.022136847931711424, 0.013383726491743039, 0.02403711562135047, 0.025343894996049426, 0.08347211285464226, 0.009902258114438626, 0.033312130629295306, 0.038710396000815016, 0.03456273852216621, 0.052634415577255914, 0.03366148204452569, 0.039108512742865476, 0.0726854186805506, 0.03591618605799252, 0.026502821316582062, 0.08304810617119075, 0.020292117786143097, 0.022749963419271574, 0.06101001654901813, 0.04191704086899277, 0.03410687024194387, 0.07778743402131143, 0.01733634373052947, 0.03175227410881029, 0.02315073082554004, 0.11126708509700914, 0.06979391174090487, 0.035077787094539216, 0.009073160415995986, 0.0730392134057418, 0.033362998867467526, 0.05095731121517959, 0.07965925495110213, 0.0517542609914897, 0.01727710023612505, 0.07395577632010945, 0.004765939271648325, 0.012046146552048385, 0.0421107308788886, 0.030317571457295172, 0.03594060894101858, 0.026502371239926548, 0.027081169818918553, 0.03894221803714191, 0.03954500665948276, 0.024438210530206565, 0.024153281363748738, 0.00903333437764236, 0.017923456278719732, 0.05201532460388638, 0.04562260815873743, 0.047814879836815025, 0.025295326936869852, 0.04514339334902264, 0.03018206391002863, 0.05394511540690738, 0.09618619231567269, 0.02184489948464738, 0.04645459496626451, 0.03986423932797006, 0.0544874596920225, 0.023697351796492457, 0.007587786793949143, 0.03598515312337587, 0.034819320520205845, 0.047169040903569236, 0.027340674442389322, 0.05191137413344076, 0.08696923528106944, 0.02384489458504944, 0.03884746445222728, 0.057619748066269585, 0.016442294225036617, 0.050953488436437426, 0.07365737741272296, 0.06696768315328706, 0.04135005919623279, 0.04194678423265296, 0.03790202385355388, 0.02993157231098702, 0.02944059613641472, 0.07322315111636155, 0.03515485553972183, 0.10277686205001609, 0.0152727939759291, 0.03228596734604047, 0.02205136975634002, 0.03078187628078365, 0.0574806341600995, 0.024794694224011996, 0.022773643197011084, 0.08229485021964197, 0.07700390227499508, 0.007621916968585744, 0.03365685487346303, 0.016579508233154495, 0.0485462831303237, 0.02695988469396628, 0.09702036247378397, 0.017115633799544266, 0.03578303997675258, 0.02454390193546011, 0.06448645460148973, 0.10857293006753731, 0.02118259349146918, 0.08210047839149352, 0.06415892137034286, 0.06026899502162011, 0.03374718430061494, 0.013393760328331302, 0.010402457987619265, 0.057603583611067266, 0.02740543760028818, 0.01992164149640068, 0.02255397706082271, 0.09773182066818399, 0.02418161321040844, 0.046048989714754206, 0.02183198515746382, 0.05853680127690877, 0.0318035502888022, 0.0558218086558965, 0.05923763000135941, 0.01659162391367699, 0.03913341826128383, 0.01857183479343451, 0.08301803722016274, 0.07969714565983704, 0.11154277715831996, 0.08795755765130443, 0.06694594923887523, 0.011144238899672225, 0.08352590754868523, 0.05404216725559485, 0.035186326431651274, 0.05505146511319665, 0.014701990482036867, 0.03375230176794914, 0.02731608493523973, 0.06250435914543849, 0.028996950789024274, 0.033446893156055486, 0.03513908561980052, 0.017812446308051868, 0.031401670139823715, 0.040032997006370176, 0.04349313653825272, 0.03495667242415009, 0.04646011462975894, 0.02487339826691295, 0.02323930974178497, 0.05183148648469679, 0.08489943424900694, 0.04520715101652088, 0.013335441885095452, 0.06412004623862524, 0.04718135959739166, 0.08420558841598612, 0.04900849078811946, 0.06559926625942031, 0.08039000323943554, 0.04672878166480411, 0.03607208878102322, 0.0443431991903532, 0.12900749041188148, 0.014077252483055478, 0.03407361053471123, 0.041354111801352234, 0.05203814636315069, 0.06840443508999963, 0.0323055523838247, 0.03169382926106694, 0.07270982624181817, 0.04833699173984989, 0.03787366327859702, 0.07524158595310104, 0.05452196046169247, 0.07769986251068693, 0.06495212880714286, 0.014618244622984241, 0.07204326079978098, 0.06019468832340452, 0.029059860014146375, 0.03282071969982597, 0.06624693997324475, 0.009699126070876037, 0.059005049537987485, 0.027389573834596143, 0.04296497637105565, 0.08593486336570594, 0.01607647574987383, 0.03253712927201583, 0.05330306094800753, 0.054052609034002795, 0.06502931216551412, 0.012043753484894913, 0.0423542051125438, 0.07464730856759895, 0.027221455839612795, 0.047482118055584936, 0.016197559776745977, 0.009281828402421408, 0.08114771016182439, 0.04769363876191839, 0.026911831828915787, 0.007779906802405153, 0.06850802549912084, 0.05338084951583898, 0.02781350965491466, 0.06476911040203226, 0.03192989350927453, 0.1208342056000425, 0.05852131097907982, 0.03829328027824241, 0.0908133802154372, 0.07802819247327505, 0.010949394969840445, 0.035984172530832796, 0.023100956177879727, 0.04278093140812651, 0.0025649370640636452, 0.06841470832906424, 0.03731889687778969, 0.02842877784954204, 0.05982415074662817, 0.030077649956388824, 0.03823021975075526, 0.009628760895030874, 0.052643895915318886, 0.04505183818119188, 0.010230146618860384, 0.10833738101345879, 0.03100404943970423, 0.02619757741359213, 0.06286919319761858, 0.04679266573680986, 0.05618308039922869, 0.06704164894237634, 0.03986124392418612, 0.0972811311423298, 0.020586835641053416, 0.05295740207657219, 0.009373305046239929, 0.028023189835010037, 0.047961984040035356, 0.007372306849462011, 0.03314916074516312, 0.014631210661102689, 0.012159757391219179, 0.025788967182198842, 0.04109859849596697, 0.04025397506812888, 0.07218926183639035, 0.06533704968469758, 0.0534736878809429, 0.030177461636823513, 0.06243698937337726, 0.06473934788617396, 0.020822438321286635, 0.06823413374443209, 0.06549526216281999, 0.03729279243176983, 0.01792537149853043, 0.010277098232519724, 0.0608739746554244, 0.07106066110634035, 0.04622974433004857, 0.060242499870758866, 0.04876066134461472, 0.02800415446531148, 0.067982948835819, 0.032244349619553934, 0.07053716258416254, 0.01935361985928349, 0.016384291793069532, 0.050072996771984526, 0.025666471638326204, 0.026025561946294, 0.06192815760450979, 0.056981769195126916, 0.02721407458246235, 0.012064552772039128, 0.08478145670866774, 0.05689577582562643, 0.04373511690045557, 0.0467011297211772, 0.025724217430838657, 0.01142057734766915, 0.021961270155565395, 0.09994362375789112, 0.017051527562040477, 0.021393327042460445, 0.010168422914801106, 0.03307315333175563, 0.03651684495590387, 0.042409283003859946, 0.051383727245152964, 0.022421484069538214, 0.07135557431367136, 0.008526619884275622, 0.08219213315075444, 0.040741842840948415, 0.08334380078820453, 0.06194460168180447, 0.1261004931744068, 0.032014687951173515, 0.024313629311960072, 0.035838263424774336, 0.07612495427770961, 0.007553514893046551, 0.02244241933728899, 0.05975730191435545, 0.036114782861043374, 0.0381169919555466, 0.04740640941646792, 0.042348252609372146, 0.004397482581196293, 0.04527281241251096, 0.10264827419192561, 0.00625272536830556, 0.10532373667604501, 0.013338091591703556, 0.04643044787489119, 0.043737690955881155, 0.026884472913919922, 0.036883797241194595, 0.04662720606692376, 0.026746433446063634, 0.035131328979567174, 0.0005365367999935012, 0.03301383131333897, 0.013743693012774233, 0.13009988582662999, 0.16362844395541376, 0.2348491561508948, 0.12140594467881227, 0.16491390884883944, 0.17099732112499977, 0.08759726650051533, 0.2077981318917967, 0.30470148209602604, 0.102617239970113, 0.126019885403014, 0.12828765121558983, 0.11269616849359967, 0.165852933461147, 0.1464250203101866, 0.082262069317362, 0.11277126809281689, 0.16177582884988478, 0.17842955376592376, 0.20466345332322583, 0.18626330840972163, 0.13517647470918395, 0.14745016852694173, 0.11426019061717296, 0.2678972392553284, 0.10151662443193699, 0.11944836786677761, 0.13903265488484215, 0.19776518396552534, 0.11047706458597414, 0.09686331444930646, 0.22888105542909717, 0.16371046132858724, 0.27291162179843076, 0.10436860889556909, 0.1725821118922003, 0.10181424959051995, 0.16492483326263968, 0.1962320428461798, 0.14267066854142374, 0.09070671013286037, 0.12418800063671605, 0.06829867665205272, 0.18828852312459102, 0.1358492071590116, 0.16140973075262963, 0.18331500371136975, 0.10986059363330565, 0.1268366423826064, 0.220090426324356, 0.17497682613470864, 0.18046616786910644, 0.12145449167057393, 0.18338238880518945, 0.1482444638085942, 0.2294067449627384, 0.12063755849075895, 0.12484943328966057, 0.13751560161190649, 0.12604287570162168, 0.0803454322440009, 0.11875682795840888, 0.14833380498232382, 0.15692517461795963, 0.21298238677122902, 0.24114669000189154, 0.08581793536582301, 0.12222046468166575, 0.15307628759934058, 0.15939749356719757, 0.22914817496653528, 0.13629421231246766, 0.16372990464010548, 0.17770291936974372, 0.0938147365025455, 0.172631922929037, 0.11767377115545735, 0.19023389615599187, 0.1765456056642917, 0.11792075790224538, 0.14027132712785276, 0.20315067482090768, 0.11472071671197492, 0.21483667194843295, 0.13029042721515702, 0.13298901789371045, 0.10200895083647582, 0.1426519759960713, 0.21653027784439827, 0.07966727589166935, 0.11325748111571997, 0.14254067874243184, 0.09001186838553799, 0.17779509506879315, 0.1149288934445189, 0.16513431234465492, 0.12455904766196206, 0.15131992378061818, 0.11462495572143987, 0.11321168437960649, 0.26060579825312863, 0.14884844752809695, 0.13792887540353885, 0.17675073336689703, 0.23720159766174134, 0.22012240283431547, 0.09491768094801134, 0.19623403467478293, 0.19382884034947043, 0.1704058246386628, 0.07314434365159081, 0.18298805270704532, 0.12741288605837092, 0.17165770423748802, 0.1564553328939984, 0.10577709984875495, 0.15423822847585525, 0.24339908042982702, 0.1863143605089957, 0.16961336796802862, 0.0770728808316973, 0.14234261437048837, 0.1636912325216878, 0.16398162581026554, 0.08554693942348804, 0.12516860850155354, 0.1966958171537807, 0.24566265574145704, 0.10205586606095876, 0.21980153456810983, 0.19847171621457224, 0.13795199593709362, 0.13310796070483424, 0.2284474803074714, 0.09433907006056079, 0.210903576545177, 0.13062494716817333, 0.13837012672616592, 0.13959856403450813, 0.1599494139513662, 0.14745792133673546, 0.19349173101927006, 0.17887855789834456, 0.14032539761354848, 0.1731826022507683, 0.0642920827733413, 0.16391905174861032, 0.19638503060465862, 0.2036710783478714, 0.22550924200444455, 0.13692500910932018, 0.11029219224808678, 0.2158072134179454, 0.16507763716001667, 0.1385113167306108, 0.09728882266508956, 0.14691995907454722, 0.10848908940510404, 0.17539131034526134, 0.14156526495372096, 0.0735173365401645, 0.20414323365736395, 0.16588153918423962, 0.14646893247000634, 0.17305325596563279, 0.08346091264918928, 0.17262760219314408, 0.14692578134277176, 0.047906737609375874, 0.13607178634453204, 0.13620231240507097, 0.11753465724928726, 0.15243946935140318, 0.1903132015779134, 0.1121525984678057, 0.264191334886897], [0.05770271155802954, 0.04202075385218186, 0.024251830914328178, 0.03536626516330627, 0.07568280663221114, 0.030833512522099964, 0.024896436446015874, 0.052419884145380034, 0.052170901739549254, 0.01985304981410023, 0.04512693778040909, 0.04643679874378347, 0.012924695226003327, 0.023796927904890432, 0.020771719470259645, 0.024555887381035476, 0.05200798165113215, 0.04372335362037824, 0.06590917946830874, 0.051206879678272435, 0.03709142622087271, 0.034713117751262845, 0.011027409533609547, 0.027111346022255962, 0.06609416671938474, 0.05700677813541505, 0.06362509981338536, 0.09807480589276361, 0.04354480916874544, 0.15022090936620391, 0.10906029988320605, 0.06203889178352491, 0.044937461254096804, 0.09193922302895978, 0.013220373563648713, 0.04202435063498636, 0.07627210444620541, 0.06638968513617594, 0.04060629890450547, 0.017631224379123702, 0.08006969421741464, 0.023772729102582223, 0.06283917404230564, 0.01450251172026319, 0.018310319189162507, 0.007437200721112952, 0.06208181185948272, 0.017051684610064954, 0.018873918583736788, 0.0634218107217983, 0.03755381390933068, 0.03364007371748167, 0.01979651444050814, 0.04220765249262895, 0.026446728358766245, 0.03987177380270535, 0.04074424835703066, 0.04780349577026022, 0.029184090747167508, 0.07279810255333301, 0.1242473571290893, 0.023001054482113932, 0.007042508870888983, 0.022591953954449105, 0.07606136897999434, 0.02821922598917398, 0.03789763416974776, 0.038922414664299264, 0.08647670203279104, 0.07288528335911613, 0.019928377324474916, 0.07701880268512235, 0.01875292457219574, 0.02754760819727615, 0.01632135192443046, 0.05048211836706727, 0.044328651180671114, 0.00876309781996233, 0.14867177233099937, 0.01087657352458806, 0.0302046807407732, 0.023873414123250593, 0.03802224986195084, 0.07163234655895541, 0.052440993698133584, 0.03193702387262977, 0.05317915005669479, 0.049223026050434965, 0.012906385724613023, 0.026901277052539013, 0.04563707189874784, 0.027681045391927325, 0.06482208538199626, 0.028117353532222972, 0.013589159671908185, 0.0691144300564643, 0.04212440554833701, 0.053351868409663446, 0.038129486849591616, 0.08162060857660348, 0.05599157757035667, 0.06591995832540336, 0.04662849309463655, 0.025193567477887677, 0.0237807787714466, 0.019387865904718637, 0.01449213505932881, 0.09082307122767934, 0.058124312725398815, 0.01679353404700035, 0.024389098548600753, 0.06008430271439495, 0.07002723147912372, 0.03241526000502129, 0.022872717517818657, 0.04990842959453022, 0.03821030529516359, 0.01953811489886815, 0.06433182741485297, 0.031248854751127864, 0.04611254819939214, 0.03168404631827387, 0.0384820596645436, 0.06872763992437432, 0.09765991565561104, 0.03294634662808911, 0.034001345460813855, 0.06360310159863965, 0.022451472581334175, 0.04229161189869047, 0.07730918831282085, 0.020415563279041843, 0.028817010142149466, 0.0074970192602655346, 0.03645305664488866, 0.011499412583127137, 0.03349548228265297, 0.1158425835291705, 0.029849064641542015, 0.0246526442858721, 0.016354910405953566, 0.01441480997469156, 0.05117671113581427, 0.05527278408408166, 0.0360503395448529, 0.05012586449963912, 0.07464173910838943, 0.024063731431059783, 0.04631631226549226, 0.005891414362967255, 0.03557952105878823, 0.04880600991929251, 0.02537537546407792, 0.017165339499291395, 0.1012651177663957, 0.05509847609867012, 0.009152370076926966, 0.048627392689306895, 0.044495340421675675, 0.03358860410028889, 0.023707067706592144, 0.009613319435307096, 0.05165733554730973, 0.09262170011718428, 0.08888191167986201, 0.058042199591234814, 0.06399180695054031, 0.09744515056691824, 0.03234404447158018, 0.04506517960239322, 0.09567931024057251, 0.07150954266469325, 0.06795408264283212, 0.03726694845564423, 0.005203849014510671, 0.04449963434449127, 0.025409228889451876, 0.025455406754307693, 0.03549126772991112, 0.02346040846239175, 0.06438248880928563, 0.015368310775938294, 0.03439421450058299, 0.0357981319088609, 0.05313882318836066, 0.05806057037965906, 0.05676995737538223, 0.042473695676533446, 0.03599300552459975, 0.019077586888846372, 0.03495558840973723, 0.040853775947565035, 0.019012325773796728, 0.006054146759842913, 0.05620277651976194, 0.0749628831662478, 0.05011454555055788, 0.01929945552781705, 0.06777821183805505, 0.048840273201705954, 0.017178803494560625, 0.028841645614574515, 0.08198697480463213, 0.0319862641739629, 0.05070251803244314, 0.041707412399832285, 0.028897196565183903, 0.09858858275918231, 0.014016548633545399, 0.012928638663593561, 0.006217365143745537, 0.0211775143285312, 0.031296195154408776, 0.09799937687573895, 0.02189214987259719, 0.01003162738221187, 0.02734113792558351, 0.08170786599117903, 0.04417233093972168, 0.05039039082945355, 0.06789354637505547, 0.013711557539570476, 0.008639705953218283, 0.062161239855472124, 0.04313396004539344, 0.07389678754993985, 0.021376270094826337, 0.026504954871451183, 0.041999318712060495, 0.014128983527752421, 0.06196118365492552, 0.017788722480256713, 0.0513470622770969, 0.057727877546342156, 0.00796378801404048, 0.025628197885629152, 0.11197880376130344, 0.05059395954313298, 0.006786831335404949, 0.03577453640079306, 0.022099677345625336, 0.06733920515304612, 0.02953237730018314, 0.04525446460672444, 0.06408070379327382, 0.05358908753541689, 0.0591648210050358, 0.11112195740063345, 0.04978279117494822, 0.017427669071982947, 0.0034603260264116074, 0.04816382522544554, 0.043378740458959536, 0.024026557014534072, 0.05681527913698266, 0.024366274874116627, 0.00934144823751863, 0.05874434598691522, 0.07432129219054215, 0.03540630857910841, 0.08005305478769927, 0.04099007065017377, 0.08755049683273801, 0.036279982061035214, 0.03318649220971331, 0.05809111813563974, 0.08776776702894319, 0.09406292600737465, 0.062446856585841995, 0.03842969372447941, 0.008573850162417419, 0.033193455948945016, 0.1403926754550588, 0.06866664400384312, 0.04883662279274675, 0.042586896658664754, 0.05177434015598509, 0.030810771202067697, 0.06961871509350116, 0.06855969812961356, 0.037730274601809444, 0.01959375969524826, 0.058736049254695256, 0.024316415956784642, 0.02618072730969758, 0.019611169043327534, 0.04061793578007529, 0.007276028749578062, 0.05432818235168534, 0.01113237219772512, 0.03734199059826713, 0.03141056825106423, 0.012883232632321457, 0.017733830365262205, 0.018875284135461818, 0.013044248992246727, 0.07474163697371561, 0.01474799597710972, 0.0732314478485815, 0.04237506568672196, 0.06511673045855376, 0.05496646765799773, 0.05111782961795407, 0.001690873834905365, 0.05473166553964538, 0.07970923452728218, 0.05444428680704967, 0.016955370121004603, 0.06236519161311369, 0.03822378078175168, 0.02963106091614933, 0.037512226826361114, 0.011861455202433131, 0.047972969740869544, 0.00881562655371043, 0.05476340456234832, 0.034778476542522835, 0.03461485931409463, 0.025458243194847338, 0.0138427127498172, 0.033018071609999866, 0.030404715873901884, 0.055897072964017434, 0.030489726735639478, 0.036922201228838776, 0.028728061588481072, 0.03334961148099073, 0.028425782445758104, 0.037712635427352884, 0.09831790091289629, 0.07199519644341162, 0.043374668701641986, 0.05030337856301377, 0.031269416551015554, 0.006050181297224857, 0.036616417233862227, 0.04291079480261092, 0.051820657831887086, 0.07001178714657022, 0.05482688643819383, 0.008292434466702324, 0.046700693051060366, 0.033730449109909036, 0.062385389521237344, 0.08305860157575339, 0.05387810186573094, 0.028130930525461034, 0.07043672079641013, 0.018030181902671055, 0.03516733128156874, 0.051852940777016264, 0.02475400537913365, 0.08853353319629546, 0.08906211088141126, 0.09486810739843116, 0.09340979008665008, 0.27496286818096716, 0.1562563492165458, 0.09820153215719808, 0.08681902076087653, 0.18812790513038638, 0.09896093213389959, 0.11491553287111944, 0.1401835334517302, 0.08576688326654897, 0.2164697568983801, 0.11408931470566219, 0.14346824267939215, 0.1720821475910564, 0.1454677321617642, 0.22534689265153102, 0.19603777827034075, 0.26667897559462056, 0.11883564308405885, 0.18393495270321447, 0.1271308354672886, 0.1269966475064716, 0.12908727080831606, 0.1528637441656282, 0.11705688651530974, 0.15185160412182733, 0.2554634790266714, 0.14596342169229062, 0.22582542181255358, 0.05335423945178909, 0.17441557479962227, 0.11983237709970244, 0.11964933571195412, 0.1065502511036973, 0.13551871682847702, 0.17702145351757928, 0.0708277014294459, 0.1334646818858962, 0.13258942643240576, 0.11085834654588854, 0.16291668698672326, 0.13749402857595874, 0.10071859064121401, 0.24683060274729807, 0.15068071533835706, 0.09346883248297438, 0.21116691160826914, 0.09439713952522125, 0.1806198297849586, 0.1318082159325, 0.1488577478354977, 0.18528409482490632, 0.07213496918519659, 0.12355279117341965, 0.19908326888276687, 0.07610231637954712, 0.10569061618298294, 0.3639341746607135, 0.13361858894988415, 0.0769482459872961, 0.12162998709226809, 0.14061510142299438, 0.13979039245074795, 0.08073621369417637, 0.11107056056179347, 0.16438973616928826, 0.16587852079781795, 0.10532171420392492, 0.19560841663229853, 0.20370107835098622, 0.10679574397903298, 0.1679980102926493, 0.16148682984132923, 0.1286448550320441, 0.18365237351146438, 0.1530446481680678, 0.1219533374833484, 0.1462308170213815, 0.15677724303978105, 0.12460394041432489, 0.13720971802549978, 0.16188191670563915, 0.1452069711540976, 0.2238588741109256, 0.13982347212731838, 0.08248803461150778, 0.199623468121694, 0.07924533764561338, 0.15260103729463395, 0.22391597830480148, 0.1098376952652489, 0.0926669146264753, 0.19751073552235482, 0.1872618427319873, 0.2253232818217047, 0.1661430662798305, 0.19441368719262464, 0.13613681188754498, 0.13621008053662317, 0.19148441211831188, 0.16409615595494548, 0.15318833561914583, 0.125618516617725, 0.1682727907093302, 0.2049202000301692, 0.1571564412405414, 0.06954395257297062, 0.11978890927087878, 0.11793600305193856, 0.15715556790030774, 0.10330288100146479, 0.10058477806347994, 0.13412776162787793, 0.08085214577975773, 0.08013695673716646, 0.1170694963225434, 0.10462684947396479, 0.13323770535569038, 0.1320356214719434, 0.24042338042730288, 0.20339321825773488, 0.24076952959500977, 0.11018962839678412, 0.21347024688316932, 0.14806417267649405, 0.1187868815876784, 0.1515168696641922, 0.07810500810944265, 0.09518296187443119, 0.24284037250664928, 0.12812052913490804, 0.13193986048140835, 0.11604293850400757, 0.12202612349703429, 0.23155065734059582, 0.1230755873445061, 0.08558204923305782, 0.17205830693485277, 0.08923550722219291, 0.11545526479641277, 0.12737290392960274, 0.11386908741006929, 0.14510371782366308, 0.16180130893424635, 0.11512482043115363, 0.10235588141386548, 0.1230860750881895, 0.12561724491177068, 0.11793518333785957, 0.09145547680917288, 0.24346660341947313, 0.1586183055394119, 0.14540154216510637, 0.168189961282957, 0.11778490753063273, 0.10239225526851031, 0.13854988159671908, 0.07522880760652405, 0.1745451355893766, 0.13283036108459198, 0.19678661389456642, 0.1666492052496441, 0.11852023702475334, 0.07622210188738762, 0.16538491502644556, 0.16970362844726733, 0.13067121887879987, 0.11884673603720243, 0.17954629545490589, 0.19290325291935476, 0.14435771672475722, 0.10325077936173448, 0.11503970806276607], [0.036052216460267385, 0.0231681554953778, 0.06026113112907737, 0.07404205314214192, 0.08756525168615965, 0.07172928732489386, 0.01070214488032845, 0.01368348807802484, 0.006161784028424131, 0.04264003251709285, 0.033214998341375784, 0.06498263442828771, 0.05585604129479297, 0.0404061239603306, 0.03221913383552625, 0.05323297156381512, 0.03004797937108144, 0.03588340515571256, 0.008923190086328936, 0.07314893251825726, 0.020331084848411625, 0.009597087947411403, 0.05186687208591931, 0.06242295081216482, 0.07009450932063403, 0.018585170468976422, 0.007972227908941287, 0.018121170165437846, 0.0004962178020157867, 0.06793765771773554, 0.08775537938720758, 0.017420667028355024, 0.051705108790267865, 0.03235594181704425, 0.05265389336273075, 0.018309848045089075, 0.03595859668548069, 0.022844841493473902, 0.056052493051655834, 0.02634119400153718, 0.028439719500320575, 0.013040006780366023, 0.044927165032394474, 0.020029510506578994, 0.026972766462413054, 0.026786557301097823, 0.01629785792301259, 0.04649921958785384, 0.02937119623135415, 0.02477777325698445, 0.024573086054935574, 0.04963842190561756, 0.030452772569392, 0.019111850171259815, 0.013020204365133278, 0.04915477144682119, 0.01784011548865707, 0.04389700660061452, 0.07838697443085332, 0.07705136908278351, 0.031058457004086628, 0.005325007256150487, 0.08544846648170103, 0.16349422535107982, 0.03311112831016222, 0.08315014142182567, 0.041026455996137474, 0.09618346504266224, 0.03871778108840508, 0.016959641061182466, 0.048829842914616874, 0.014013188380387523, 0.024313995118943915, 0.08118442875603515, 0.08746634973513503, 0.06230384329213731, 0.05584255431688601, 0.06594622748032694, 0.053861198135681694, 0.02479847295269851, 0.06828672568043394, 0.043056623469437325, 0.030864872331280383, 0.10468586122677212, 0.0638667201142638, 0.10054962994951396, 0.0654805149702776, 0.08126771017428368, 0.09376511698768986, 0.03891693330520103, 0.08535851243763201, 0.029659478947700515, 0.02269379576788314, 0.04484494081548145, 0.10745677060537762, 0.025633388131316152, 0.05037060660880901, 0.09504079893832246, 0.17734592239702904, 0.040940294087293654, 0.057628247811789476, 0.030024148290976885, 0.04649466136470438, 0.03522493726303501, 0.010499365237211029, 0.058941081196310065, 0.013013336386892104, 0.07751731141921013, 0.02195631548191511, 0.058615639385196476, 0.014895235203326711, 0.10086270710152966, 0.028455483674582456, 0.04312640258802041, 0.04550961402034567, 0.02599546043652921, 0.01537986433944635, 0.009914129604435256, 0.02991080941301921, 0.038021640822051034, 0.05703702328666564, 0.031742904853496345, 0.0053823690470908925, 0.03389280229326218, 0.044674168325840466, 0.08102344303962686, 0.01044051915091733, 0.06245935531032663, 0.1007983403941316, 0.02045119402840013, 0.041774912406840635, 0.010813148147726973, 0.028365692424197352, 0.04346852979412483, 0.04993894287655431, 0.05697349927598431, 0.01903158330899333, 0.08611658708222451, 0.02781331238727416, 0.030882950091073592, 0.027871460375946858, 0.04328435842668818, 0.02853858314694897, 0.01102224322817018, 0.03542611578239068, 0.02143357730200214, 0.025151267933148532, 0.03359257626617628, 0.017155198410393733, 0.023724588137420437, 0.02685991021984768, 0.029539854318324118, 0.03427395401822944, 0.10886302458182459, 0.038462478457198995, 0.01962307021923123, 0.007922265090934572, 0.038480305323196996, 0.044399901188068816, 0.03522497556743122, 0.022978523836260843, 0.03316604149257464, 0.02774921381064961, 0.02392811471626403, 0.03156388351213067, 0.01174512092069152, 0.012466766169264674, 0.07012669267433305, 0.027619737290566968, 0.0944431814094705, 0.03698014811943135, 0.07145366421149624, 0.1045605062597221, 0.040757245038666075, 0.0412489585728655, 0.03614129716410272, 0.07548195370022329, 0.027805590220997413, 0.03947603959409941, 0.053784754052157366, 0.05496663619734107, 0.035949729217757145, 0.036486622787291006, 0.046247709091872945, 0.05423517161679845, 0.02283803863270629, 0.0534099187221258, 0.04466957179829479, 0.11005263655416428, 0.045059958713189255, 0.026698941740417675, 0.02794605818757367, 0.07077687915654914, 0.1098460149801066, 0.04822588217775187, 0.05209185295708237, 0.02105749707909361, 0.03019820921303284, 0.03208894676889383, 0.014533996976341211, 0.06590135004972258, 0.04142025200229499, 0.018270984404690323, 0.02355230070890919, 0.05031910251765963, 0.04597177571286598, 0.07528357523223085, 0.016556594543339267, 0.04632332196999942, 0.03271846228369302, 0.014189945931936947, 0.016142803642358032, 0.013228963324499708, 0.014810609300771068, 0.03208439812184342, 0.011201365118575914, 0.010896032157864784, 0.05753926286894468, 0.050374375761396466, 0.051764155017031785, 0.0235020108671198, 0.029478686028009946, 0.07444214256059739, 0.03764141223303253, 0.015447078021093002, 0.06800885026853892, 0.03896104847832073, 0.013939552009105684, 0.058037315780717524, 0.022019017863297657, 0.017081814848126906, 0.04672313176636254, 0.04204614583643214, 0.05293599757996779, 0.05567430608695554, 0.030088329222053293, 0.014213637200995319, 0.011579870967374695, 0.05454665913637127, 0.11950622282681927, 0.022938512979195486, 0.08469189336944012, 0.035303193144500256, 0.11669867146279543, 0.02614122781632168, 0.046089508105069406, 0.1208248976317625, 0.018804267784881017, 0.09323167464425487, 0.045443983267872565, 0.04323998661411386, 0.018977823088906946, 0.03856681580204637, 0.10981830557988537, 0.013470692792907359, 0.04742481467884876, 0.06505314516083849, 0.04272710607056657, 0.09169677918356273, 0.09777364906884971, 0.07579310797154903, 0.06695189408116764, 0.023412144923162077, 0.10102233684231197, 0.021145411414064227, 0.04058502847328782, 0.14048126586262258, 0.019537860174633322, 0.012268794685482018, 0.0916009875495107, 0.10172520719108083, 0.14671951983003848, 0.04029155551125446, 0.01809405256813813, 0.13930290006101131, 0.07730361119273209, 0.09848135343242077, 0.009683143561555734, 0.02331526544425757, 0.033022219976109844, 0.0014286127313220454, 0.043625217757277915, 0.019790814746351495, 0.0965495631399174, 0.01756897973527591, 0.011009472542472426, 0.016563234610422965, 0.040448312422320734, 0.06952545154959926, 0.04861784340333074, 0.04200313382992341, 0.03266934838686739, 0.07150366677031403, 0.03533492067588433, 0.03800220517141204, 0.003446113898403823, 0.05305568732681775, 0.11016591797552763, 0.01694872622348128, 0.05371859086857689, 0.08461281011301665, 0.03535326465123123, 0.0645476037396058, 0.03544428738795462, 0.05610442998248243, 0.010768733242706907, 0.04176887946443693, 0.016968680898688974, 0.023585301861467383, 0.03095870661068588, 0.05059432343489701, 0.04673369228839875, 0.021791886200287172, 0.07409992342394206, 0.024941733309758768, 0.0332654528920689, 0.0290854033007617, 0.045028778934671033, 0.03145542078381104, 0.03992974367593566, 0.023442192806772167, 0.016404432244598866, 0.027067357253643776, 0.019854790748908155, 0.0577854796973688, 0.08922010119403563, 0.041816909346849694, 0.054324302116348866, 0.02542694084226124, 0.08858164351794029, 0.047395454359150706, 0.009669041798089542, 0.00045513882087693826, 0.04371077828710118, 0.08057994707938164, 0.05272972840635527, 0.060122067018622355, 0.05191358812754193, 0.022860421806633956, 0.0017719984762445695, 0.01926115879248227, 0.09078262178527732, 0.017662595679622986, 0.04678713075155693, 0.02668401643243288, 0.03261688285537305, 0.03359414291598144, 0.0540227392658351, 0.06416700359794401, 0.05954086292354811, 0.04167611387768581, 0.029015233477337227, 0.13331281261578684, 0.07836792182417647, 0.12787245454326754, 0.2419110772109801, 0.23304134186717773, 0.1623103896816892, 0.10276296521506964, 0.10437984740541828, 0.12994269990632612, 0.07198770410351216, 0.17824394598362908, 0.18483323675970878, 0.2015547604570466, 0.1428442640650657, 0.1153193761204039, 0.15908396442330655, 0.14815812569952783, 0.2801207236705288, 0.14047585728187717, 0.10811805004073728, 0.11581208556890489, 0.09664994364063587, 0.12180329150249883, 0.15927283574015866, 0.2761613974167455, 0.19195868183047543, 0.1410481862483486, 0.14022297165807218, 0.22996304736983395, 0.21472816325483784, 0.22686969158389877, 0.09614944307794494, 0.21130126810842947, 0.12557938484655273, 0.10633909428912787, 0.12077604420483114, 0.15803784071918459, 0.11291914604484074, 0.1270451332111993, 0.12223363373308413, 0.08690202638747231, 0.13802160268589375, 0.0911255993489777, 0.11453140106412674, 0.06324615442164003, 0.13313134170828328, 0.18048263875947845, 0.14827201233035134, 0.14525885062832988, 0.1303375109789833, 0.09660691248192903, 0.19199413637961113, 0.19000993801220772, 0.08940686576909597, 0.1007734961627472, 0.08030276880749772, 0.2427102294900725, 0.188611674332811, 0.18470330824775083, 0.22092863376582825, 0.17090598812266705, 0.1609636530760796, 0.1931596012605775, 0.25199086375294194, 0.11709362809215823, 0.20959944974991584, 0.14892668042692447, 0.20047995442103958, 0.2373807090184381, 0.14665021951640808, 0.12960663245570275, 0.11242446008949511, 0.1562415330760902, 0.19600601626500008, 0.1632014418681783, 0.23803762941350862, 0.25965575729646995, 0.20043806473333992, 0.1786179501082628, 0.21736192757323866, 0.15088993395047803, 0.15607829506118454, 0.19415824283515254, 0.24088793614458656, 0.22497123377698086, 0.17231643260005983, 0.14998244151713389, 0.30495548620820045, 0.19021397786996058, 0.18517284353654231, 0.2060244085207101, 0.09510108239708409, 0.1031434351217843, 0.20021404530252182, 0.38463855883286846, 0.2823524910115427, 0.10675399984803893, 0.18648631660447967, 0.2284245742785354, 0.3730531643715597, 0.16131344882230605, 0.1031382640282954, 0.2059094340450341, 0.17868636175990107, 0.16466318359298093, 0.1308146152164667, 0.08936320641829122, 0.15496731435339298, 0.11324502452607117, 0.17589991611819114, 0.14409055122204367, 0.12646720414200138, 0.12623993649838433, 0.18282450825696994, 0.20516652794134235, 0.10664598911159462, 0.13310770023493998, 0.17260091168986214, 0.18380343072837402, 0.16796260170878904, 0.09707562805664155, 0.14405131219856201, 0.1200346626161087, 0.10662378022266973, 0.1838139874199706, 0.1387551318733923, 0.22977386961781213, 0.10505264114227988, 0.12802800103541345, 0.14644144523528316, 0.1920458013492246, 0.17530622862039075, 0.11078430414800683, 0.12251150148409991, 0.18445596910051762, 0.11097755748778583, 0.11631164384344894, 0.14329968801429196, 0.08692121688997553, 0.1688297366302821, 0.10555635927425278, 0.15126162448958044, 0.12255736716812658, 0.13963145984997674, 0.16100339771759126, 0.18455749107224328, 0.11503416924707352, 0.061866380274295814, 0.1598237755317842, 0.13150748045694444, 0.16204121702861402, 0.11733993302069365, 0.14168835996139434, 0.16191279004898765, 0.15026325870665813, 0.12474099354397868, 0.11815796170624034, 0.1769447987598758, 0.1212259216774856, 0.16972262742778949, 0.12865315942514327, 0.12324667776063566, 0.10976400526781237, 0.23177251640346744, 0.11402281827383465, 0.20074096057684193, 0.10949947510755832, 0.3096079994593897, 0.06103248973827689, 0.14312500464579753, 0.1036946890094588, 0.1575366506773618, 0.2537669466748353, 0.1467753063526846, 0.13898840564633572, 0.11726402902915595], [0.07812026092001507, 0.04678772446969825, 0.03724146071040342, 0.0845049372723987, 0.07297588091704153, 0.04117321929023151, 0.040632062441399025, 0.03112852915130075, 0.0375350256029877, 0.046896945625062914, 0.04063775830511605, 0.06375476402500946, 0.06184257026160918, 0.04610723154919763, 0.05375291926846389, 0.05335065799074308, 0.05280513061030258, 0.046639149377663294, 0.07620373875984261, 0.05337893812646789, 0.03565377030040949, 0.002624984711386083, 0.022041351241510243, 0.021375900457402872, 0.03106859617776448, 0.03851104077071913, 0.11627183025402409, 0.02624786534016171, 0.03839301726510448, 0.020391163378653508, 0.031116411555558447, 0.015351199244539586, 0.03759201871411454, 0.05883058067411185, 0.04405190191802479, 0.03862919834172053, 0.02063043562004403, 0.05292931729326806, 0.022377209933174234, 0.03853596927177522, 0.06315160385002533, 0.0488553344902973, 0.030222475048034426, 0.024012194781173623, 0.05339185436887126, 0.05941672986673732, 0.016099130885014613, 0.026746105943476, 0.05484294747152636, 0.034582066920495806, 0.02303658180960244, 0.034779709944080923, 0.047016371071579, 0.027325875538912033, 0.042579220457663464, 0.052986498095936356, 0.0375124566527384, 0.03565169420213469, 0.03571066382010618, 0.025575240142643455, 0.039873417061302936, 0.017578172790367278, 0.048813234128418474, 0.021586787225978992, 0.07189247937452409, 0.1273587236421243, 0.02887626704309256, 0.07062176167364083, 0.0580678980106548, 0.04802856474153457, 0.04041032212215566, 0.050642924052813364, 0.05670512718478999, 0.004038009708071308, 0.06783043605185325, 0.08144997781322849, 0.06353933627026216, 0.4089921568670581, 1.1689045544593566, 1.5514378730327854, 2.4274021723578056, 2.194630095074254, 1.3592582820884644, 1.3536165654659273, 1.9515260044605502, 2.895006551857918, 1.4967677549969767, 1.647063296648764, 1.3131006879191245, 1.0905723706368478, 1.1563981997389947, 0.801861533714879, 0.21436650846754352, 0.39538450479026765, 0.5278994827981919, 1.3733209597487606, 1.1931976315475281, 0.532461689604867, 0.15764515937095688, 0.8754663421742378, 0.35573176318599337, 0.1612241995791274, 0.02889816566640812, 0.07578524790944592, 0.02516035948158993, 0.10039031430478058, 0.06433185805836994, 0.01860649835678839, 0.027631460351028272, 0.026103992112762025, 0.03744742727928585, 0.010369475987259178, 0.05162835061069458, 0.06152246042244858, 0.03618425937489637, 0.08980035150964415, 0.03517637111907525, 0.008004407432200688, 0.02037033344799232, 0.06615131687853607, 0.026795553088548685, 0.09886561547436061, 0.1086360710342565, 0.02801698643804318, 0.0360300267235406, 0.05194529267628828, 0.08053678568572768, 0.06205790608580555, 0.04825334259939771, 0.0902713270437333, 0.018701474107201063, 0.0392388281292252, 0.03134540481222493, 0.014470752587752237, 0.08859881154832341, 0.018417881764171105, 0.08030794756186586, 0.018109696083551934, 0.04406682531078977, 0.03119503324400754, 0.07150490017187211, 0.016763281234870517, 0.03522663414778729, 0.024335003165047497, 0.02229615974600517, 0.003072308956630408, 0.02576181894138215, 0.013331949481770638, 0.06563272131907363, 0.043232681965755845, 0.026418653151561177, 0.020691504318928047, 0.025866215658043663, 0.0031947913333668465, 0.05802752900748484, 0.024802998617111195, 0.09863689992456667, 0.01540593718433933, 0.04546698122735947, 0.06476856647960602, 0.06496105373146073, 0.04966741067267234, 0.05205548293287716, 0.06634178165827068, 0.037326002343287396, 0.011747722746804358, 0.05515610889321374, 0.01615534067123888, 0.0506819830456328, 0.028295097421974908, 0.03327376877648696, 0.0511760714523975, 0.01123989359550779, 0.07008203740922675, 0.012446463881661336, 0.05955718059633529, 0.06957311754024799, 0.048680631969604767, 0.03938829571369194, 0.0394561174776285, 0.04189480899743015, 0.06763376595993197, 0.05509462650685061, 0.01300420270361487, 0.05119999637827278, 0.04511941096655304, 0.011302901454450143, 0.0254965897258972, 0.0178195038930543, 0.08647838742622445, 0.017521428657815825, 0.0483528497598825, 0.01807933410389289, 0.012447259655492681, 0.014612546844047405, 0.07465677741434305, 0.015058023141576879, 0.01722659397449705, 0.07626758452745215, 0.04486361803907541, 0.04090586609597649, 0.03802347943306931, 0.03208022294265609, 0.002937421940582534, 0.039520055175788944, 0.032277632309424306, 0.02810939579390951, 0.031000868259598652, 0.08544381632800065, 0.09127526994674437, 0.10303572315963046, 0.02427816710194513, 0.08282843811978256, 0.053602478752333316, 0.04301646514044654, 0.025895899649889722, 0.03980223600181841, 0.050423064479424115, 0.05092861739197566, 0.074741744226025, 0.060593770336239576, 0.007404801426380272, 0.05266966711309168, 0.013341218188044526, 0.050969790787466114, 0.026528743816719904, 0.017172305153742913, 0.041849399135718425, 0.02395395103151039, 0.05324214546670837, 0.028119579017643007, 0.02605300513096154, 0.085896750491473, 0.015447225493018427, 0.01269893773320702, 0.012335806311438642, 0.02244681859719417, 0.027301058120604967, 0.05632436233422449, 0.018609185410182805, 0.05300556219393208, 0.010126277545256721, 0.012230823537515057, 0.07349685900994847, 0.038431210578569484, 0.026771271931788614, 0.04707372424403026, 0.03401251885318949, 0.04721194565776856, 0.17723696937243785, 0.03607612606438418, 0.05210623625786074, 0.10989080048016003, 0.7623271067296306, 1.6628662809248895, 2.0743329630744074, 3.514023490490452, 3.3115698637500888, 2.5920919545235175, 3.0474639323449906, 3.195818268483685, 3.802987933158875, 1.9151496983343557, 2.3927789205505006, 2.1211204653786075, 1.6319969825206266, 1.5229184420839434, 0.9199356624195654, 0.2948952195865493, 0.3466162055490479, 0.8601733885945813, 1.914117747256833, 1.3585184250147113, 0.8854518386144793, 0.7869603881432164, 1.3358433256226203, 0.6562402315678135, 0.15773112975781964, 0.041134891911379756, 0.020243938516585097, 0.07329849586371454, 0.04371938145449085, 0.07903637950338664, 0.018616827137227503, 0.030986751174373977, 0.06218968470010066, 0.11214325985600872, 0.07023786735390464, 0.06949261702116459, 0.02020119655606968, 0.056515439984298525, 0.07779709439003661, 0.03949603448892313, 0.02773997287506298, 0.023726281191733097, 0.10249892535108714, 0.05807190082005917, 0.06597546139551748, 0.012639813940040769, 0.0501060113310814, 0.027347318339912642, 0.01310592002776121, 0.07501992607308973, 0.027416760379809047, 0.04469881337436457, 0.022992127642576254, 0.045201075939281334, 0.03793744775917261, 0.0522614341800011, 0.028037954264530734, 0.02067646026731499, 0.09068872238839827, 0.03147299292557423, 0.034442236722116513, 0.11322825486140867, 0.02668144812266673, 0.019451690604910254, 0.014368217464746728, 0.04583734643435286, 0.017526316298772732, 0.01717284333050972, 0.010052721613206932, 0.020833228669700124, 0.02040648705235893, 0.034417522725679224, 0.01964183171249686, 0.004818020801570628, 0.038176061164948254, 0.03979775821790099, 0.04707400769656224, 0.07574221675073908, 0.033161054260187575, 0.0560400479533259, 0.07562024023143515, 0.01697486131301811, 0.03271069798258043, 0.05555687246904258, 0.062279837927029985, 0.041443452975081826, 0.06723471076017426, 0.01929406992970936, 0.010000570177761538, 0.0396957267977057, 0.049433029902678345, 0.13792427887599315, 0.07774257191246556, 0.06726354630964418, 0.06112107631540107, 0.0462388071501928, 0.05718049240268527, 0.020326750705980008, 0.05943785474124936, 0.11926672075905147, 0.12521824333816767, 0.11550381178817443, 0.18516335936803974, 0.1915921394022242, 0.1640768505392536, 0.06840930740919805, 0.13882878356643263, 0.14930502060920964, 0.1482378754524454, 0.11960210639142221, 0.22214813848897336, 0.1093944674357772, 0.16985064071993675, 0.16236606895202593, 0.17156258676080935, 0.15916935258334683, 0.19775499499613242, 0.10690321079305104, 0.16232223340099858, 0.11800033911581963, 0.11299932480699594, 0.23806188375719134, 0.0995265042048789, 0.12986155587338633, 0.10725761838858167, 0.22856541188253512, 0.15721504696674887, 0.11968258392786789, 0.08842553012073041, 0.1456801223778917, 0.09122495329187763, 0.14442370753855477, 0.15362869827978073, 0.22471016633414456, 0.13168136709399764, 0.16890963960078456, 0.15898342304412397, 0.11586486136600857, 0.18506104066487283, 0.11555888584905094, 0.1171464192110204, 0.11543426632640824, 0.2116876215704026, 0.13452560640871525, 0.19734138412581337, 0.1586566405791429, 0.1628893836131019, 0.18656024408917274, 0.0921227470521004, 0.17362694856860947, 0.15248158886548013, 0.1294969286649458, 0.221117903448401, 0.15114703305786656, 0.06078428108124964, 0.1742358199290691, 0.10246066692014856, 0.1553356647491455, 0.07924371353921392, 0.13569289457894143, 0.111972606109996, 0.17284134072401833, 0.09909515073823352, 0.10941971003288224, 0.2867794373343068, 0.11254677368748574, 0.167604363673637, 0.18650372212211933, 0.15479468410053562, 0.14201681249805037, 0.13872994290244195, 0.16672748411374708, 0.21889562027588969, 0.20339283521377272, 0.20959617089359991, 0.317120349575435, 1.1785875381000581, 2.2451592933747078, 2.768723882975117, 4.043954822324937, 4.312635708239771, 3.8495574987703756, 4.0092440526331625, 4.451065957546234, 4.514432828272543, 2.9848430473958296, 3.3707905440561237, 2.976438633857235, 3.0898056732070063, 2.374863494788447, 1.6986608505249026, 0.7466853686398076, 0.9657624904667178, 1.4023331384504996, 2.870426528876828, 2.192731422762717, 1.884307979095367, 1.663089243154372, 1.818730117332551, 0.9355079622999315, 0.3306273989860089, 0.1592631983540712, 0.21381186081036446, 0.13124512598639534, 0.17272780649363997, 0.14695749738283698, 0.08597113762892063, 0.1534126308416167, 0.20789004712095185, 0.23977137831670625, 0.19180721092608669, 0.17784633102916902, 0.10087714785890234, 0.1468590857280839, 0.20425391804066398, 0.13826688871748988, 0.11943761965319996, 0.10439994189167216, 0.18190307302340386, 0.18514952382012723, 0.16624734616808354, 0.2543656137441435, 0.16703178955902978, 0.12020988990702938, 0.1576604811294425, 0.22565208675880588, 0.17442360340106874, 0.12127217040547442, 0.19581837068882682, 0.15726836668627878, 0.1345127820968628, 0.12077530109954458, 0.1337303458562782, 0.18586399274006968, 0.12265852141764857, 0.2044877127533959, 0.08400344845628546, 0.1416685182841555, 0.13047556002293864, 0.14651140438452845, 0.07331865163700235, 0.13559351765340374, 0.11918121768582253, 0.14984957122754666, 0.10758859135450856, 0.12410908591963592, 0.1060097377687212, 0.10307203572724136, 0.07662268926299388, 0.11574510650168504, 0.12159598811018853, 0.10448003638415568, 0.10883944439551524, 0.14202330892364826, 0.14914705327922298, 0.19016182260407558, 0.23418486598999272, 0.11966932294589859, 0.10688587422332457, 0.20104436203837397, 0.1479097293509591, 0.07440730854268036, 0.19805537807124277, 0.16364997102608606, 0.09380184324277986, 0.2102484334740908, 0.2578679225858181, 0.1486891165616051, 0.16731030848478118, 0.17739487541539056, 0.12172746411975353, 0.12164166227223412, 0.21728004809589158, 0.1415062302182759, 0.15249793718178428], [0.053816837814426234, 0.02633021979202186, 0.09691132517952113, 0.11115676843591275, 0.0336963658581578, 0.062105227336888356, 0.05290262678998613, 0.09647187416351612, 0.08872097192872917, 0.05302919217595651, 0.030336874957767226, 0.06649679188886959, 0.10952769012580957, 0.029821621456874475, 0.06413429547401686, 0.01664024751423107, 0.08583328010694635, 0.03266433434140298, 0.05447547807688675, 0.05150018027052284, 0.014812803185064227, 0.020818669168699174, 0.006670371127960783, 0.04750914180711393, 0.03109462593021172, 0.02253949416861419, 0.008878598981086285, 0.04811468068510295, 0.0526718006679608, 0.04345314674860528, 0.03723623216032021, 0.056474906272224845, 0.09742579918595091, 0.03594563064736224, 0.05267100010607993, 0.0674357935185394, 0.05140732658366042, 0.01252319907859689, 0.08830097954600089, 0.0917948307769914, 0.030572234405084487, 0.05790200550109149, 0.05172901839438466, 0.0797921558842063, 0.055237409974178, 0.047303918343518055, 0.03796403484058477, 0.0902334746393946, 0.028755711616888165, 0.021081015978369023, 0.027734547057339264, 0.020892504722841328, 0.03628846648479662, 0.011598638206299756, 0.05806742303614175, 0.062118231679403016, 0.060163114009605306, 0.039436206852476445, 0.0495667313976634, 0.012597915633851963, 0.04147722596122373, 0.05958849444024025, 0.05351263579101332, 0.09567241544925398, 0.04732024750762409, 0.01921418036574558, 0.08533770548960856, 0.03845789725141179, 0.029452024253025174, 0.13085914024662587, 0.08295833598822355, 0.06265210303207559, 0.31248251456887494, 0.45913435819168247, 2.0711484887907585, 3.650384934679155, 9.469748889246295, 15.279592025664547, 16.690622529675885, 27.866773066982148, 41.789249527838926, 30.845652395679107, 38.609815489861276, 42.28189137674148, 42.527745539142245, 42.02266977679345, 29.160168747748102, 28.140493708272135, 28.351589787390928, 26.63972035531075, 19.854680876578055, 19.04478596102807, 9.84998639552824, 8.143952959968198, 13.173331214535622, 21.823151765331147, 19.121132935247115, 16.93840257583126, 22.415482613348193, 15.976526602622002, 14.378073484666887, 8.83410526860145, 3.147886169533576, 0.5152399717800079, 0.02683011897569222, 0.06179667393406553, 0.03653793918689893, 0.030749669944446896, 0.052402773571591225, 0.11157224856076703, 0.02464909729878268, 0.039308637891325264, 0.03630733523037165, 0.0365455043051512, 0.014873913061174174, 0.03727897986649506, 0.08071821828883502, 0.0055852219473660715, 0.020376038887808402, 0.09468714976983686, 0.007546592809845724, 0.027170405655558554, 0.036052239442905115, 0.011320591382231685, 0.03315193398344902, 0.04452688409195793, 0.06032224579323685, 0.01200295259965764, 0.045059368825487556, 0.13130138748355452, 0.013499041876545357, 0.02613909809189218, 0.036589971878716064, 0.023004061377216733, 0.032421258473468405, 0.05266497865499509, 0.0222883437339577, 0.035013240356478965, 0.07400363383273925, 0.07707551617415682, 0.03738659989809798, 0.010912463786230694, 0.04105364828700981, 0.030572944951634255, 0.059999948773052425, 0.0443474050130575, 0.01713462128874756, 0.03758931825418146, 0.013015048593402872, 0.006167224210296428, 0.012168000497284436, 0.0305305362393659, 0.020182011799225887, 0.058004837483167655, 0.024244480300694708, 0.05688847117726842, 0.04672496271650157, 0.05011541122991232, 0.08662457232393565, 0.022459455217505177, 0.024809010492096988, 0.07894923700199974, 0.013333038284233021, 0.06766427924195606, 0.005343623671515455, 0.06511034128526527, 0.02361706769724767, 0.006840575276122939, 0.02387482372503127, 0.09651826844821054, 0.0645142789148996, 0.04065206116666237, 0.06041531015427844, 0.009020811712910092, 0.08475454403988777, 0.11938875856538934, 0.1076212803262376, 0.05467669107019902, 0.06837831149178167, 0.034154363862809636, 0.04182817083933661, 0.07530057472327063, 0.043743547698062275, 0.05957747426544947, 0.08995598227146173, 0.07878358581013258, 0.04776280501016206, 0.11260328033278066, 0.04231334964354192, 0.029615697022827885, 0.06319211457946128, 0.03229532894047518, 0.009110137564881195, 0.0315230835845033, 0.011249599929508424, 0.04139933780196213, 0.05619245348498226, 0.09641253299290135, 0.05959180777051276, 0.031139771491589568, 0.005424668113025086, 0.016732007610581575, 0.0085408442218097, 0.04240012442272517, 0.029802708661243803, 0.0772265121040325, 0.05083143530834106, 0.05248806980108062, 0.14636557188726243, 0.05588055610836995, 0.02257825438714316, 0.023583223847972772, 0.018216109526674115, 0.08883154905971982, 0.04241843392411548, 0.09779887634419626, 0.009468144816046041, 0.03777385734382176, 0.07672961215458571, 0.06532854610873808, 0.03758403224750392, 0.020015372353936398, 0.06957031365844511, 0.09026758853466281, 0.014448499648771701, 0.041684935380133896, 0.020820586303729686, 0.004852241949148236, 0.03343418375739167, 0.015517094626932617, 0.0222794666901351, 0.05290294088603509, 0.044155603409895015, 0.05941991296206271, 0.027993846752290285, 0.07074283420919411, 0.09191782619323462, 0.0652787427327806, 0.07289386354386806, 0.04548295799102034, 0.13166452848142193, 0.1257857842551124, 0.035939115069566235, 0.02475845634997372, 0.1076869264004692, 0.12480109314163848, 0.07390437182039022, 0.09808863377979687, 0.5047779686508641, 0.903067754641656, 3.0663435257250264, 6.270926575506888, 12.792644596868946, 20.18681149328909, 22.395011763418875, 36.8871065878099, 51.43551488076487, 37.90512638707315, 48.15675466291366, 52.04535715041622, 51.861652943395804, 49.751868863259595, 36.97433225570187, 33.73478005009313, 32.967780174747595, 29.816598969121134, 22.886927973839548, 21.3827343140879, 10.897773062029193, 10.758252393814827, 16.362465273949407, 25.0513389033656, 23.941321872895767, 21.662587581142304, 28.375378962486025, 22.902156576033562, 20.74077175509545, 13.55079854688337, 5.188417127055507, 0.9508052672589979, 0.09356576558803359, 0.023387584144309647, 0.03116151689732027, 0.027141560529989582, 0.03194247267299122, 0.030648113498764656, 0.029172434719399582, 0.036405654954573805, 0.030376778562523188, 0.08086295528036934, 0.041826163688975, 0.015702390228398144, 0.02743534375763228, 0.07629155541860289, 0.09594410853160006, 0.06360933372390366, 0.02372948726969621, 0.07641659628960394, 0.011114708125411023, 0.042844984019475604, 0.01792124611505818, 0.04329317609869665, 0.05946527302805936, 0.027528896499725602, 0.028837541298520182, 0.05988415458329743, 0.08877243005460309, 0.04296323735146754, 0.059578071814030416, 0.025614733890359922, 0.028822771123340054, 0.03497356466288048, 0.05786381984850573, 0.027545179698556185, 0.07276025780987355, 0.030489064069584976, 0.0763964711598331, 0.042425286580598166, 0.07029934590982814, 0.05966033050490003, 0.01564450366722961, 0.01658752534328209, 0.03243863717803071, 0.02252395024463054, 0.05991186398351866, 0.048740639636713656, 0.1094222457839116, 0.028439277084544305, 0.04531007109870834, 0.05538492403443783, 0.013410414122195255, 0.02698602744438235, 0.03528103022085082, 0.0365411376039828, 0.042458810588164676, 0.10900817526083802, 0.008221141366858878, 0.0023460734049759566, 0.0657306120340382, 0.01701742515809113, 0.08199639768610079, 0.05216919336347811, 0.04064476800962322, 0.10170090688212265, 0.0521872500558534, 0.1052780088878447, 0.047922101502697316, 0.09255216997717658, 0.0092019158558199, 0.07603404262373525, 0.12694965567319624, 0.03670327245227752, 0.17824504915024006, 0.3008455777120206, 0.161004209770791, 0.13272804238142508, 0.09399256849240872, 0.22866112690779472, 0.13340745511795246, 0.23460007032319424, 0.19407691494111093, 0.18036165815447608, 0.1459496321096536, 0.25385625720504795, 0.19387851349048077, 0.19765227792724488, 0.1695388429347546, 0.15610359128444426, 0.13342374214722266, 0.1159803414597146, 0.16558723884724802, 0.12012916722244794, 0.09513223153208533, 0.25193561349184285, 0.14053070917725563, 0.16269469002802528, 0.17309309253769536, 0.08520769270797891, 0.11256292282092957, 0.12425029890671854, 0.12499832247774448, 0.1245491038407049, 0.09297684315712222, 0.10056145834706484, 0.36549383774399763, 0.17290043674649733, 0.1810377460694121, 0.14655068937328555, 0.11686413113268153, 0.21194377072876502, 0.19910262026373418, 0.21536948609977, 0.1437584367851096, 0.14061716986038994, 0.34123710386695405, 0.20588346366440097, 0.12270110058448008, 0.18710378347144974, 0.15150039877382018, 0.14732168026028142, 0.2093776213305612, 0.19468567904926118, 0.12227505610714998, 0.13563857894510994, 0.0929739933100439, 0.10794574154480811, 0.17260342445825377, 0.1448296422078725, 0.14937163961510505, 0.12908184690581215, 0.20498499574680484, 0.10019590417223592, 0.14774181819971532, 0.12804323086334815, 0.13909441689329763, 0.15577763619442142, 0.24036998409898053, 0.1408505968509182, 0.1878758622032981, 0.1285474239698341, 0.30387502644331227, 0.3388587072972329, 0.21960537009421857, 0.1944484216191115, 0.9343912512544663, 1.416737062315787, 4.101435441163279, 7.368384666981236, 15.111324306457275, 24.837193181437833, 29.856093314386186, 44.79298099394768, 58.02488103989632, 44.35981404396796, 54.32349720308858, 61.616548338244044, 60.16609899459347, 57.67452709136471, 43.15097485819171, 40.79081412284605, 41.83054816338324, 39.46322125773276, 29.967319965362552, 28.388630690113192, 17.72742852087944, 15.904436380632463, 24.17650522724275, 33.03255419577322, 31.42072677612305, 29.546686949268466, 37.60464537528254, 32.575678479286935, 26.87899474174746, 16.399155124541252, 6.260434725592214, 1.1788232480326009, 0.18737781312196486, 0.1173791184180206, 0.12442856756669861, 0.10218054687063541, 0.14372852871254568, 0.1416565673125367, 0.10412870080120142, 0.09212958821726423, 0.20667962820058872, 0.11250876806556218, 0.19838641998508286, 0.077302377791174, 0.17021105444479376, 0.16622794882184075, 0.1646668301715005, 0.1769773574966577, 0.15810309608857478, 0.11281419966009357, 0.06896157253293261, 0.2281409225636913, 0.17162128441756772, 0.11827601585537197, 0.2890793252135477, 0.07620533222272512, 0.1330732722436228, 0.16997361315354226, 0.12889630041055142, 0.12364233153000956, 0.1403435692191124, 0.08330402550317588, 0.12372614920980508, 0.12794773800358658, 0.1570654299951369, 0.17001887362810875, 0.18015259275993994, 0.20671986313837193, 0.25972197793664475, 0.18111527416734927, 0.17281829679925598, 0.15285582281649113, 0.13265242950329859, 0.18542635735244523, 0.10680571844380711, 0.14315030086905728, 0.16268451638039083, 0.09608769639124794, 0.2090010431505019, 0.10823827987957386, 0.13075554983750468, 0.21455580879363323, 0.08479292504489423, 0.08206054222800079, 0.19704743618926696, 0.21683181005139507, 0.27104481874454406, 0.1548555114817235, 0.10853589737727758, 0.18934325765698187, 0.16569442986961336, 0.12690940541365456, 0.2046172888649087, 0.14157329355516743, 0.12524556969442677, 0.20919389812456024, 0.09386447093058979, 0.2587586376936205, 0.20311027134378112, 0.26240932244446974, 0.18085713318038374, 0.1502586315355955, 0.21423890886287536, 0.22971258258386967], [0.04654366800922059, 0.07335274254963284, 0.025335973646912365, 0.04619774483745137, 0.017233902453294685, 0.014576220869897835, 0.04607347005437459, 0.07733649934732145, 0.039292496418760675, 0.06494459050196795, 0.016717235520181638, 0.02264553222865347, 0.0878166281167538, 0.11773076809702382, 0.026130326385159167, 0.03735071250928506, 0.04278231802726946, 0.0391007139677963, 0.040080862179879224, 0.04391030205654041, 0.049421994406129086, 0.07101107989588092, 0.03200518846091244, 0.01791871036402881, 0.050528834408689896, 0.041210485637308135, 0.09764716029167177, 0.023521482906935197, 0.028200449174149867, 0.05508313901842602, 0.024675628838820324, 0.029974821804752274, 0.03168722558315964, 0.06982421051831016, 0.007437509071502475, 0.037266737781465054, 0.018669139451136994, 0.03272803838274652, 0.027306790373498396, 0.020997338109619675, 0.036424378143443216, 0.01997137975488459, 0.016860080274542975, 0.04249953582221943, 0.018209235802773508, 0.015379283070233802, 0.04753171075736323, 0.02886853338549695, 0.013348789051956227, 0.024226132494908188, 0.07384767365311423, 0.09078796141810956, 0.06950963949484211, 0.09731921337304578, 0.06370740446953044, 0.07408035753835594, 0.016634679970241362, 0.023768178540311997, 0.02123923611737067, 0.03766099727081676, 0.025488005710705638, 0.11986282909469259, 0.038183699061553326, 0.03626964370449705, 0.1521975541066739, 0.18054741915435563, 0.39029391182045786, 0.2931315932543047, 0.877141990969258, 1.057272183318292, 3.817339885619379, 8.39607261842297, 16.36910878842877, 19.473044064737138, 27.650554372418313, 47.00876320562055, 58.32851563730548, 60.058190668782885, 62.154724982477006, 59.7288017888223, 77.19586926121866, 78.25410119948849, 83.73103218693888, 82.07712558008011, 74.96867687471452, 88.63943130739274, 85.17499785269462, 79.68167920266428, 73.00272218642696, 67.53194147540678, 60.39764435060563, 56.26142263412476, 48.12687404694096, 38.81928966891381, 40.31754878259475, 55.56352707647509, 49.15384469493743, 49.27648936548541, 61.251928729395715, 58.14973400485132, 63.76181810132919, 51.548730173418605, 34.61218680104902, 16.16201548807083, 3.3425288863720435, 0.05724066477869788, 0.09677679247913823, 0.01837366508440145, 0.031351935711779425, 0.09167644721005233, 0.020619767845698425, 0.04308881065357597, 0.02822974246115454, 0.016728719178166603, 0.01676056545317894, 0.0819007209652374, 0.09279594681556187, 0.014766130235887345, 0.034113791846339746, 0.0074156679047812386, 0.0239591431924172, 0.01373057758751055, 0.03917866341409184, 0.03381914293934261, 0.04085957523315184, 0.04071498379832314, 0.028266413174870036, 0.04541928842363339, 0.03471389916094561, 0.01256583953246234, 0.07677872605141133, 0.03452078371699299, 0.027511831891212254, 0.020365173845822294, 0.020104462633870786, 0.023755103334664338, 0.015918141655293445, 0.05040331473273616, 0.02804876568036214, 0.006078366629569041, 0.10479222487417922, 0.03422777423815381, 0.04171868921407769, 0.015623128856532277, 0.08616180159151555, 0.0634190911096671, 0.02604382548240885, 0.036641552578657866, 0.012272164514738948, 0.04312429201578902, 0.06886835495430617, 0.029208751117450096, 0.005252999300512696, 0.010786154082105046, 0.0037487310774233797, 0.11111941398872484, 0.029517524770551154, 0.0683278646019678, 0.01710231153054103, 0.038504797154136246, 0.032737066728934165, 0.011351063487029845, 0.06580758088779065, 0.07778715056877944, 0.030533368849465926, 0.10192473479095968, 0.022922444284983703, 0.04402375967812635, 0.0267253621977063, 0.050808502466327725, 0.07364197904544492, 0.0031023870049525174, 0.06727063262294378, 0.08147839201434005, 0.03596132778893075, 0.029880556600889372, 0.06454745052202095, 0.028983032886659908, 0.043317641116558545, 0.06775852337840103, 0.02767124904259559, 0.022996528817701246, 0.08226196206505261, 0.06320310028029547, 0.07969513850947542, 0.029400928103695476, 0.03255019490156443, 0.05361162584214922, 0.10808085647201347, 0.04222724519129242, 0.08529933214548134, 0.044461027343547156, 0.08428903837357798, 0.05389383731169566, 0.12540014325490884, 0.027806254802271727, 0.02492285881852431, 0.056501887888918, 0.010590386058714603, 0.021161545225749576, 0.023538677750395674, 0.04388201042949673, 0.05147639707091355, 0.06671065299381172, 0.05135795221694055, 0.017221959142555154, 0.008998261914858896, 0.03843113396977706, 0.029008530207999775, 0.050796003741843086, 0.033001049136322354, 0.04354414267225131, 0.04815072895237996, 0.04042884612816476, 0.028268048772588376, 0.024002699121352167, 0.0133162647891309, 0.05503590203701489, 0.04049256932170641, 0.05516171665681947, 0.008517674850149742, 0.029721700608910575, 0.06160855721381884, 0.08687652332047302, 0.023574898387455655, 0.014765742403875678, 0.03657473822034175, 0.08632529241543624, 0.03618432449236993, 0.040139628784550775, 0.06083573154624432, 0.03716656412448614, 0.0108840620340479, 0.05549177797811647, 0.023046650120147297, 0.12535327399570134, 0.014383303651195622, 0.03298983743955051, 0.07586001042997645, 0.012669397382846764, 0.1456368843754453, 0.17361044703472048, 0.4042621155179316, 0.5286876953417255, 0.875938926492968, 1.5335133767897084, 4.5294962006230515, 9.54896507724639, 18.53573291532455, 23.782238383446973, 34.44285808071014, 57.82061184606245, 71.32244156252953, 74.53452540982154, 75.80126270171135, 74.40838198507987, 89.34767799992716, 90.80125347260507, 97.08857751661732, 93.51621612425774, 86.81741975968885, 98.86849418763192, 96.88437892544655, 90.0751599957866, 84.54093886959939, 77.54829422120126, 71.47801845304429, 65.46179294586182, 56.0793815120574, 47.53420391390401, 50.90204508073869, 66.85363815676781, 58.75210808169458, 62.23434125223468, 71.99996040713403, 70.62444794562556, 76.56650927758987, 63.91121333645236, 47.03582755980953, 22.527183871115408, 6.4749584659453365, 0.15731960264665468, 0.15552102738330442, 0.04220034401383131, 0.018732213385162816, 0.030916826499085275, 0.012830881056405846, 0.037474179069601724, 0.03958452147461715, 0.02127635690774168, 0.041178861527793834, 0.03747151691406485, 0.040731718989029046, 0.01983898443981044, 0.030589419672445908, 0.05949543390963828, 0.048517589307119774, 0.03212623609860819, 0.07538666768420128, 0.09353485394028888, 0.11053976888257651, 0.024269688423843156, 0.05491531979773314, 0.03201640015768428, 0.014312388807264789, 0.03275655600572786, 0.04266105780017473, 0.05013593089496417, 0.04121868277809793, 0.05835731070668948, 0.041236885027178836, 0.05854125607818846, 0.03347352237230347, 0.09958053638617839, 0.04801662143079504, 0.04872758549848392, 0.042526961769908674, 0.02202254761340878, 0.036498297967257044, 0.034470861597407254, 0.025480195444317597, 0.048744404958861495, 0.05523383234357161, 0.03975102685451989, 0.02975604816099569, 0.016951957199301933, 0.005834246488032682, 0.03833280658469566, 0.020958294438558723, 0.025776786384202784, 0.011678651301941324, 0.0826544289086615, 0.006817044885528665, 0.05064875398191714, 0.020505115126950607, 0.06936138615973535, 0.06306268402465409, 0.09574039043077538, 0.0800870307871411, 0.03849662299598417, 0.002313463196661624, 0.07492129225283861, 0.009789564665557157, 0.024365121911790584, 0.012247524254264371, 0.08300780994637359, 0.02944740474284176, 0.009045885770671792, 0.046426625096149025, 0.02764197490778902, 0.12645624142380493, 0.025809345120984702, 0.24525270677141606, 0.11968604664528563, 0.15013610343298606, 0.22613302143591069, 0.07564415749643119, 0.11227127314815599, 0.15635776393596204, 0.11960198381735433, 0.14141112806335573, 0.1259871121616133, 0.1867229611642899, 0.14397376877886636, 0.3081176520114945, 0.20222344796263403, 0.1535080087881896, 0.10605514379999331, 0.23407687823618614, 0.1827932365479008, 0.18681309906946075, 0.1035752788847012, 0.11419852053926838, 0.20975901054278498, 0.1537916451812752, 0.1231281869413872, 0.12140537011286906, 0.10244593504936465, 0.3976953017615503, 0.1816157747300402, 0.23781785410979103, 0.20609571598470214, 0.1439295348621184, 0.16404347974927197, 0.10638721227165192, 0.2295498655087525, 0.11021048131008303, 0.11451058645522404, 0.24450618473272173, 0.19138278289427682, 0.1060362597326598, 0.07693969644606113, 0.15979042006356103, 0.22217803123977878, 0.15448164525291613, 0.19752179783198143, 0.08189653812517082, 0.15288585346312294, 0.16145612503732407, 0.15351988315101595, 0.11704478232610611, 0.15153395342490367, 0.1179694964159881, 0.26340937362082545, 0.19222973905984433, 0.17681405819471807, 0.18001854269494935, 0.15346982696604344, 0.0654926881073944, 0.12718152750523823, 0.12240363630436121, 0.18230244998008976, 0.21172416396439078, 0.1907832578064934, 0.14556272706437498, 0.19984643035117658, 0.3250207385468868, 0.3895296012201617, 0.8186810860230077, 0.8123590833237095, 1.485174699656425, 2.9288870048138405, 6.889145556957492, 13.405011892318727, 22.945486999327137, 30.99686368819206, 42.39468305341659, 68.20993884917229, 83.24019462831559, 83.17597758385443, 88.37660897162654, 88.57246075907062, 101.77204439716955, 104.31348923713931, 107.72819488279282, 106.15958413770123, 98.89285995114236, 110.63863277435304, 108.95384142475744, 103.09799378918063, 96.2062168121338, 88.68933954546529, 83.42488335024926, 76.22198397113432, 66.46078140504899, 59.832501411437995, 61.87458146002985, 77.97680531778644, 74.64885465560421, 75.16617605763098, 84.28222717777376, 83.44240065543883, 88.0349156164354, 76.9701760815036, 55.15574178388042, 25.68600977620771, 7.654313685432558, 0.42238576397780453, 0.31193384239750527, 0.1256645355193365, 0.1342862039323776, 0.27229231632044243, 0.23673161804195375, 0.13238042232490357, 0.0876186326927235, 0.09411104398989871, 0.12753783499882107, 0.13608955958437535, 0.1875889009886211, 0.1226113304015129, 0.15252648161784296, 0.1725013968684981, 0.1642275400339596, 0.08126405593488487, 0.2035244644409226, 0.2150211152770827, 0.15148241102935808, 0.13283229162616114, 0.17694165779938623, 0.20014063875761726, 0.09103491752138061, 0.10018167791948204, 0.12393936680089082, 0.1249823801880402, 0.15292660934069466, 0.10111055952767212, 0.06661906718246399, 0.1548013031002014, 0.07990456396533598, 0.1733227044103607, 0.20973644159253568, 0.18156536614462254, 0.18198124463519744, 0.12460147361120871, 0.13490218458877457, 0.11456913855527678, 0.17972125461505306, 0.16714138609747733, 0.1837968270504667, 0.10164630779575917, 0.14491011208343893, 0.19284005066560161, 0.1641526779219989, 0.10084801353514196, 0.0904175119414445, 0.14632973429416457, 0.06507594393746507, 0.16402135513001875, 0.13013152525790278, 0.14054724135466162, 0.14480771677147958, 0.1527016859261259, 0.14688945345340237, 0.2035261651561145, 0.2635335105080759, 0.16465685570672636, 0.15302689024998298, 0.3622191183028683, 0.17609381297182652, 0.17752659657309133, 0.14328476462152698, 0.24680595003789474, 0.20841035871736466, 0.11532165140153901, 0.17107886352366017, 0.2221010240816301, 0.25263641540321613, 0.2832778332935226], [0.026153299446788528, 0.025479892839587508, 0.03182602539328078, 0.048322079838403774, 0.016220475381781018, 0.12173849578586318, 0.03167166250697788, 0.03237384912227431, 0.03573221004297657, 0.0516723278879879, 0.03131831019756294, 0.030265965859495828, 0.09609775512569374, 0.05420850792659387, 0.057303989606518904, 0.028393212217657317, 0.02565622138189933, 0.029137391942523183, 0.02581105732749547, 0.03812616202800024, 0.053278772130368225, 0.06657516268352348, 0.10573383120279159, 0.10599531999398625, 0.045581120667198015, 0.040899488414006854, 0.024747405531665972, 0.08167153810180965, 0.0446519096412005, 0.04475789407508508, 0.06331407577700673, 0.0746246783303157, 0.03334622920280503, 0.03318128664226782, 0.04852189855169385, 0.047684189067372394, 0.03802555553134411, 0.07984574373450973, 0.01759325706159636, 0.017709930337244467, 0.040527671470396945, 0.015470506905037311, 0.02212293385978668, 0.03875454947833092, 0.01906706658642619, 0.06432661801696786, 0.04153975022716388, 0.05542127490644494, 0.04429362181033339, 0.07729902998694489, 0.031732669918827956, 0.032410701781871824, 0.010677283411965737, 0.036400388100094376, 0.032589100676799015, 0.033915440191424666, 0.08290007500158203, 0.07134538534427844, 0.1465711898861393, 0.149280674334976, 0.5082546288688337, 1.1550486592515823, 1.841489302535211, 1.329801282094371, 1.720208145918385, 4.140618693444037, 4.876347962887057, 7.2522418152901444, 14.570861901006392, 19.735128994910948, 30.47090130467569, 36.79492304402013, 53.97736372486238, 63.872358337525405, 63.43739101963659, 78.98743537164505, 84.69664912069999, 85.1807794263286, 88.84825829536685, 59.23663062434043, 70.74346050139397, 81.42632592108943, 83.23776275880876, 69.87949571301861, 63.84498803846298, 73.8441490357922, 80.25840097858061, 67.36996327677082, 67.47277644372755, 74.37209221624559, 68.91524376407747, 68.78395418966971, 68.31789816579511, 69.53848485023745, 70.25059899976178, 68.18510240124118, 66.4631897403348, 70.78500624625914, 71.44048921523556, 70.11760711669922, 70.67797260899698, 72.58110661660471, 76.55899401633971, 59.37281139435307, 40.81614478941887, 18.10579211481156, 2.954735669397539, 0.4986923500414818, 0.12394561807835296, 0.030128753766597762, 0.058233809672416224, 0.02557580513248761, 0.06422251432893739, 0.05839858369361009, 0.07795672413081893, 0.023359422752213095, 0.02039670410956587, 0.03139550504725307, 0.018562938597413804, 0.06284868885432521, 0.049326643272633516, 0.033276308357955954, 0.06780690183081935, 0.029824699215110273, 0.01278592222895954, 0.08075594811910584, 0.04037120950318152, 0.04937711314508512, 0.0286730507298583, 0.08465676823811186, 0.08156596352496455, 0.03576096515321443, 0.021305075628803145, 0.02241428858870941, 0.027399598095085353, 0.04295849526721624, 0.08031589955451988, 0.040637612748410434, 0.040049295526959246, 0.02160390929108666, 0.04493959863940555, 0.015211185185058464, 0.005004501445294028, 0.014364795924554911, 0.03406051809208528, 0.07153968056363445, 0.06214825466515557, 0.076925998793975, 0.032244173419331355, 0.0066928500628789835, 0.02925497111714175, 0.041711116434946176, 0.13119960504193462, 0.052463834609596006, 0.053648401892954306, 0.006231072850735679, 0.0366434907811063, 0.08390995508600628, 0.06963390661703964, 0.060665736635846484, 0.019733013412464532, 0.008353412192645333, 0.05731561116033024, 0.04252970053423797, 0.01759347539665478, 0.06895419510622179, 0.04723428478164058, 0.060132336427247336, 0.024076322086095333, 0.043053559117740205, 0.03188470389784104, 0.0616238521592271, 0.061120494088578614, 0.050288830553331686, 0.09296699126641597, 0.03486807818614668, 0.028826664765215212, 0.0557008778466092, 0.01917129284852455, 0.05915829776636055, 0.045987798441802306, 0.035367483243105874, 0.012471162556340138, 0.03492284581185349, 0.013109393278887917, 0.03665659088461149, 0.007841314495195666, 0.016770348395972003, 0.021984224064996647, 0.10814601224997353, 0.0805650313474959, 0.02283809034364118, 0.014534774555584357, 0.023960527896340338, 0.04298017172503375, 0.06055731604236269, 0.03488307052682485, 0.020649384804851106, 0.02072128598698445, 0.054030469092991085, 0.061688965802351316, 0.03249110270952506, 0.00952954676317712, 0.038408415632382516, 0.029993966341980045, 0.055688421256960406, 0.04070701265347101, 0.07984709971013569, 0.05755944162487023, 0.06567121723726874, 0.03512080293148756, 0.03142322019313372, 0.028438591435852072, 0.0778601281044464, 0.03493687671218668, 0.03520191632091038, 0.03820639441631014, 0.01088701338777619, 0.007251551761592348, 0.043227821137876286, 0.035303043757355025, 0.04899606484198763, 0.009993261698963902, 0.015713635441516677, 0.009101141777430332, 0.0949949179325373, 0.14074352840262075, 0.048604659030153874, 0.028389196001714277, 0.0096740635044332, 0.02525455573753965, 0.028869883615463495, 0.08444564972793864, 0.04702402428994256, 0.15905865287828833, 0.14374420287147646, 0.5256784406881179, 1.3600883536761808, 2.223937064409256, 1.5434346444183782, 2.262577803865556, 4.697697239537393, 5.533858306946294, 8.565211103808496, 16.70092463493347, 24.300432512837073, 36.03263001288138, 44.446745534097, 61.50708675384522, 75.75932471982895, 76.59359716599988, 89.55432415008546, 97.11437102287047, 97.3031468545237, 97.98338782402777, 71.45966960537818, 80.4015596451298, 94.60800001698156, 92.91070415127663, 80.80008029937744, 76.63719038809501, 83.3418232394803, 88.90637213183989, 80.76935245144753, 79.65815282637074, 85.45527473572763, 79.39831933667584, 77.67960732983005, 80.23643570561563, 77.74449902196085, 78.8401895953763, 76.47390996256183, 74.66495990753174, 80.1154854989821, 81.34361097889563, 78.15001718459591, 82.97021788935508, 82.04079658754411, 89.30017809714042, 75.89266177146666, 54.11903581311626, 25.469055637236565, 5.270840833264013, 1.3247589526637908, 0.014092769593961779, 0.06132551836931418, 0.10011842970045344, 0.005099816668418146, 0.057100865223835555, 0.017820867529559522, 0.04398896779504515, 0.054035498460213986, 0.056414189973786, 0.04467856567052584, 0.030519077479238474, 0.07731992886551926, 0.1666095065734079, 0.07214669799131733, 0.07395619000758856, 0.031635009030240684, 0.04559812398867742, 0.042835461546576796, 0.016903009926599842, 0.03684818564403442, 0.02575460430835524, 0.05820356452116563, 0.027831800004106858, 0.09020613296137703, 0.08924560426103492, 0.013225106071800956, 0.07809113425713393, 0.054340887919909535, 0.0240749737713486, 0.008692709661479439, 0.0799369618236538, 0.03677652961003684, 0.024647760475354812, 0.026585777147462773, 0.05698082307654043, 0.004419220326047752, 0.06262748479662884, 0.06910408020860727, 0.032270783483381235, 0.04300877361768677, 0.0273848413264439, 0.0073307456219598895, 0.02868373382596239, 0.0372897434018312, 0.10057111871579003, 0.035083628514961857, 0.02873644450559251, 0.05206598216787942, 0.06535775704129089, 0.03415242566036121, 0.07836721702328614, 0.1140134490185207, 0.05374623132088492, 0.03221379803313363, 0.048108643912259615, 0.04327455250125739, 0.02274535540040703, 0.032300775825616815, 0.027753423463793534, 0.06007366175312669, 0.034047008131540595, 0.04218321045740478, 0.04136723871793478, 0.030363990639847134, 0.012961298907025447, 0.02859006617068043, 0.026014099355726957, 0.07412223956517636, 0.13523195479666034, 0.15673641055341692, 0.14726520425850345, 0.14463514780565617, 0.1157341284617301, 0.29129344188878614, 0.11435068858366822, 0.19591235435537754, 0.07078687660396099, 0.21675849543704143, 0.15154650194510338, 0.12439616204750155, 0.178672572177264, 0.19442804368032565, 0.18474967188892827, 0.07834145348639258, 0.10378799085775692, 0.10654387725216728, 0.10501755431534783, 0.08276073126903466, 0.10586582049126587, 0.14836078659901697, 0.18314082596090533, 0.3196381128603413, 0.16831726977421393, 0.13392082595777127, 0.09370782893271216, 0.1528295766442053, 0.24290260948961784, 0.1476212972474675, 0.1357100549484453, 0.23430345640067132, 0.17681589680573634, 0.13691057601282675, 0.11499722082648547, 0.2096563700826899, 0.2228573060804798, 0.11758315827577345, 0.11281145706532464, 0.16488079852875204, 0.1143689597806623, 0.16024179906854708, 0.13374226618437998, 0.09739221389135046, 0.17702618794095132, 0.152061696074182, 0.19430833478127757, 0.17368641231329213, 0.08244619854996282, 0.22516297026266976, 0.25226035816294534, 0.12630653252164203, 0.1004767979705526, 0.09293643201911643, 0.14236712918406533, 0.13607362495555034, 0.210896099527036, 0.41198942990553, 0.3546919980116429, 0.4692753091935189, 0.9701708055311634, 1.9178421603095148, 3.1584515638889807, 2.9638971003793904, 3.8799521903837886, 7.668478344717334, 8.166231532250682, 13.45257749480586, 22.8463137918903, 32.016022935990364, 45.013955562345444, 51.10683202743531, 71.23380384137555, 85.8609184142082, 88.56555738756734, 104.93199994487148, 109.09048111208024, 109.75163582832583, 110.06124419550743, 81.89912057692005, 94.24380010174167, 104.16723974289434, 106.76374681534307, 97.01096165564753, 87.10682007574266, 96.47566795349123, 100.81040474676318, 91.57763173503261, 91.59693764102076, 97.91011794920891, 92.84877777099611, 90.72259426116945, 90.8030185391826, 91.67655391077842, 93.22206974029542, 90.40015974352437, 86.70462808301373, 92.42571876895045, 92.4282761543028, 91.79584887719925, 92.7920602983044, 94.6739350595782, 101.4717948052191, 88.35507515938052, 61.70949674421742, 28.20467741258683, 6.393899744556797, 2.025899291038513, 0.35783829047314586, 0.19688262003323725, 0.21592269351165141, 0.15669214599315198, 0.13338358381823187, 0.2579245518051809, 0.24957894317565427, 0.1270419079810381, 0.1368331398454405, 0.13518125509783147, 0.13059654062794102, 0.2673617437962563, 0.3056020337727762, 0.22438752074395457, 0.267599506844436, 0.15647777927017983, 0.1524671251254697, 0.11588621989733751, 0.10653249318561248, 0.14048681233919438, 0.20775714618784769, 0.16446764731118757, 0.20339521008633799, 0.20878655385346184, 0.18304797610448253, 0.20530526646442954, 0.13779681716715136, 0.12859554961323738, 0.25296658397682253, 0.1392945190591197, 0.129998731577108, 0.19826674172955178, 0.09954469879308056, 0.08935811193359476, 0.1265350029233002, 0.12032765294274977, 0.16795792857245093, 0.1098217299929069, 0.10875575695066683, 0.28628224627144877, 0.14637455043773498, 0.11873152407426989, 0.11515414627689509, 0.15221762561029004, 0.20634483245591964, 0.13232604540403814, 0.1636791896195181, 0.11846718543599691, 0.14637390692387858, 0.13465666873080118, 0.19360669017318757, 0.24308155230697126, 0.1553644390115815, 0.10771837430976092, 0.15994097166244062, 0.2603644499134633, 0.1292219031001291, 0.1478610827677673, 0.12611159378842962, 0.2101629380617411, 0.13730748616639646, 0.13767271092341793, 0.09341527527618794, 0.13365983512372742, 0.17808951797985262, 0.2197382403838058, 0.21426970559743144, 0.11774916952896504], [0.03512649879520459, 0.015649344385301155, 0.07322174151458087, 0.07398869511821578, 0.06562879894890132, 0.009178289704235091, 0.05231729731143964, 0.09534982348521871, 0.010899248769536856, 0.016347224628853223, 0.023861202681737564, 0.030837693446946722, 0.02640169771057704, 0.035724154628452756, 0.06660381437189157, 0.015304711114074436, 0.016890855941681132, 0.06446303529364449, 0.02038471483355088, 0.013750478636563547, 0.05132340548199512, 0.03218803449624008, 0.04857494631001065, 0.03762874113876493, 0.09147659785324529, 0.012444093797145592, 0.06125317668662437, 0.03908960186245461, 0.040646920716690446, 0.04453853628928623, 0.04688239378494121, 0.029746387792270512, 0.03582524376050119, 0.012338715530331097, 0.02951025459614973, 0.07004059205252318, 0.04528889259804161, 0.027285033476448832, 0.06163099209868139, 0.0399126943891808, 0.03918774538643418, 0.0741178268987325, 0.05407039376516497, 0.026930564593884255, 0.04007240839963479, 0.05303837373972901, 0.017646069247876445, 0.020216301894716678, 0.02309727512540356, 0.053187584684741114, 0.04249278658760652, 0.07591083270287322, 0.06657839557456394, 0.06342688988473627, 0.10937086426683011, 0.07729213519562637, 0.13146448760263382, 0.5102754462390177, 1.6284439280148477, 9.402528289825687, 10.17458115854571, 14.47020309586679, 19.074023308292514, 18.223225916585616, 17.778011406621626, 20.815230108076527, 33.07049528245003, 36.803862125642844, 45.3505890600143, 59.58709439923687, 64.62857953963741, 74.48765308626237, 67.08731728215372, 73.85150740223547, 76.65890462936895, 68.37594924434539, 59.434263167842744, 58.38907311039587, 57.386911453739295, 44.050711662538596, 46.96375400789323, 41.069769167131, 44.07805450500981, 22.28403026057828, 30.45420377485214, 35.856013528762325, 52.49216610385526, 35.84236760293284, 33.74908885648174, 43.9313147144933, 40.066748511406686, 56.33385704409692, 57.03392559482206, 55.9017530564339, 47.94741776681716, 53.04781298483572, 55.35931279582363, 62.19576081921978, 58.193939116693315, 52.33467509669643, 53.675019587239916, 61.51630432375016, 72.10211461590183, 75.14847047867315, 67.13018878813713, 62.929408780990116, 43.36788585109096, 19.50342086053664, 8.68812249552819, 1.9024551924197906, 0.3745885271458857, 0.0746435777194077, 0.016545061089639223, 0.025580951328118964, 0.143090438758654, 0.02718034373115628, 0.11931051800568258, 0.08729171999279531, 0.02499002174684598, 0.03328180120837304, 0.03281692373416117, 0.06792102594889941, 0.015557517256257276, 0.0457370387119872, 0.008703253904147255, 0.03357439699973311, 0.05202153374651267, 0.023326394786577553, 0.07404171606345523, 0.041409722123775757, 0.0397715924848472, 0.07689296508268004, 0.04826895164085492, 0.07633762794636911, 0.08688350238146321, 0.04651050406297849, 0.06517423301815026, 0.012015048170372123, 0.05642876479654543, 0.052126326913675, 0.01745969346243768, 0.06213708127277994, 0.046663346264751694, 0.03784186679929976, 0.013747736999404528, 0.029029861926251364, 0.024515738628143748, 0.07415228553356663, 0.053828030358999975, 0.036337404181399656, 0.12821504906300576, 0.06349432860471069, 0.059391184664902195, 0.023667981900695353, 0.039066883525060075, 0.019851236100939494, 0.02281162966673653, 0.0447655396325694, 0.005656493979791601, 0.012417887844475768, 0.03897442054303904, 0.04838741564702603, 0.03129604385204373, 0.047072904529951276, 0.023559279769899386, 0.06457681467215862, 0.03292112701362179, 0.02675106636278572, 0.08112525612476372, 0.01358186747247894, 0.06678278017188273, 0.09425363593524504, 0.03257881977685517, 0.06178826994953617, 0.04179690296070711, 0.058104838770363605, 0.045967504772688114, 0.061826497736957774, 0.05857135184229382, 0.02276918265007196, 0.03131447784272173, 0.021856634036427545, 0.10317407097787627, 0.04090943223526401, 0.028855190049075795, 0.014742651556227959, 0.02688619278130993, 0.023915539382986968, 0.05710354653157054, 0.030106498912397413, 0.07442528862626323, 0.024550756507162607, 0.061820001311359875, 0.06447697043298714, 0.03715201228436443, 0.03856693837611425, 0.034883139474738034, 0.024912093367968357, 0.03153669122125834, 0.05102705202936646, 0.044273082993083426, 0.026002623358621232, 0.057132428046315915, 0.05002159993314455, 0.023051399865277836, 0.04427247395318362, 0.011308351212421493, 0.06153972804426186, 0.017595404023004156, 0.011333587106257197, 0.03285942629220025, 0.04061449987573489, 0.050835342356754895, 0.04163132454719275, 0.031206191314624685, 0.03343896031559956, 0.02440646001618476, 0.015037731387682501, 0.014445705343067888, 0.09460830400066991, 0.03358521033078432, 0.08675145946683423, 0.02466047753489787, 0.02047024663507698, 0.06353922135707352, 0.06198476001079525, 0.05784969701762161, 0.016502564277259574, 0.06514680707046101, 0.1315363772934483, 0.07148127402028731, 0.04110917817020128, 0.19141318126311227, 0.86843702581621, 2.490658481274882, 10.695785707043065, 12.244876776972125, 16.229976434861463, 21.715288546777543, 20.610082303324056, 19.68412837674541, 25.565838160053378, 36.66614770889282, 41.253626346588135, 54.23154900150915, 69.53595884384649, 75.04213502330165, 85.13479355842837, 77.79146548240416, 84.0432999210973, 86.80030253625686, 80.84200259177916, 70.74077760019611, 69.86266090023902, 68.51875489757907, 53.17819649173368, 56.84275711736372, 51.144478936349195, 52.35829560987411, 33.320067851774155, 40.09739398956299, 48.13941386438186, 66.98100536100327, 44.7548084874307, 44.752345238962484, 55.923220188386985, 51.14295705672234, 63.74874091917469, 67.00641447497954, 64.66851711273193, 57.83137090744511, 61.49270734479351, 63.6725135772459, 73.2504669312508, 67.91199561088317, 63.873323240587794, 62.80143360937796, 70.50138750383931, 80.88084974596578, 83.35224105465798, 80.82255548046481, 74.45112013047742, 56.01290518237699, 26.810492507873047, 11.21243344199273, 2.5636971814017144, 0.4775019290466463, 0.004116118596416087, 0.035966606134729046, 0.012058790833238634, 0.1027317624539137, 0.04584594194086329, 0.12901268448800812, 0.0713879568502307, 0.0396778118315964, 0.020484490124809168, 0.02997422425617134, 0.02676620042972988, 0.02821108247453888, 0.04760370770048711, 0.0239130936472887, 0.055900428429125786, 0.05240649292846361, 0.03746828019258477, 0.010121406183668203, 0.039870774057964166, 0.020071086098229694, 0.0663703873813633, 0.06882626608374619, 0.013036151442887082, 0.03753512519441786, 0.06659255287940465, 0.03308385558005783, 0.04328501726230306, 0.06123441519335874, 0.03752324700115189, 0.01150867267091188, 0.04386897161302548, 0.001965938901130651, 0.04218321045740478, 0.035326899735317115, 0.016438549970306696, 0.017486081360989524, 0.02570970389511316, 0.07806341719603346, 0.06652231027762737, 0.11384677892971425, 0.08511540975662009, 0.00993566433598678, 0.06273615053824841, 0.03757138030543443, 0.039016670292063106, 0.018607883060711528, 0.05221710067182299, 0.0422221047413205, 0.04057549067863053, 0.05162418692282612, 0.07042590363491928, 0.01884760346353775, 0.08177776385339038, 0.045721950610318494, 0.031089383973589832, 0.0499463854207387, 0.00021386203262673301, 0.028065058455291777, 0.059331866476925156, 0.09974152210258669, 0.1044893290306772, 0.02881464484568325, 0.08333012611875612, 0.046090825776299166, 0.00907883808512481, 0.20788687551694535, 0.15363186988378727, 0.214652948742432, 0.13284954392621595, 0.16673989473812043, 0.07677442829815612, 0.22921721481027144, 0.2035768495331849, 0.26423972100019455, 0.1021263538108718, 0.14688962199274572, 0.12233213731838811, 0.09925905524963334, 0.17737370074516345, 0.19964058252592243, 0.07448436932698374, 0.1794159532554688, 0.2314054530354277, 0.09744548764560493, 0.22630076404781113, 0.23763387043389583, 0.10942023863355, 0.14793027582908833, 0.13030325152700947, 0.16489153908145043, 0.10149825364351274, 0.14464633268935068, 0.12894865485929674, 0.19391968305553162, 0.18348703641564618, 0.08529893377976072, 0.137100335991671, 0.09770832475154631, 0.12175128179331943, 0.13286325690006057, 0.1058738261100746, 0.16040056312997497, 0.22470129503598138, 0.19918157328521052, 0.1776913514420871, 0.10943311657155715, 0.12454983162423297, 0.11211874504243174, 0.17013642215921035, 0.11030123974647253, 0.2696434294264163, 0.0902202136574253, 0.09458659306889582, 0.16555561473773373, 0.16128470520338706, 0.17534382821571443, 0.18362269526527775, 0.2014505112123105, 0.17548359329662017, 0.17822240359119831, 0.09106302528732246, 0.5402282889812224, 2.0867526579287747, 4.678619811611791, 15.085588655164166, 17.200271775645597, 23.883515942481257, 29.339868214822587, 29.133016140230243, 28.98153812654557, 34.377130923732636, 46.2713066224129, 53.16797871743479, 64.84163484265729, 81.314710955466, 87.6485856886833, 98.6545681184338, 90.25367490706905, 94.90235036419284, 97.84279438757129, 88.67683502935594, 80.94086985434257, 79.95225998663133, 79.80608893978982, 64.40817371491464, 65.92569166614165, 61.25541179410873, 63.85564119585099, 41.18456909733434, 48.76372183522871, 55.75973972197502, 73.05889052729454, 52.92739229817545, 52.090817420713364, 63.8212537765503, 60.41188647670131, 76.06363004253757, 77.81556452474287, 75.63858632118472, 71.16354634684902, 73.0493591677758, 77.71531658787882, 80.96644370786606, 76.05227085851854, 72.77651125384916, 73.5638407737978, 83.0466962629749, 92.94002779068487, 97.61738361850863, 92.70441101443384, 86.18105442293229, 64.33900663929602, 30.578717454787228, 14.128326369870095, 3.673994661338868, 0.8749807650043119, 0.17340792403105768, 0.24952023019713743, 0.1553407975382382, 0.21940863871526337, 0.1262330417070658, 0.18173626503877102, 0.29640300319560114, 0.11447584436785792, 0.15766918388826234, 0.12610702790440093, 0.15141301878517674, 0.08814304285953123, 0.12457511252573422, 0.13043593795549485, 0.10129779141636626, 0.15939939346524978, 0.15792406134067044, 0.1256728935385904, 0.11989484390904827, 0.14595991300959743, 0.2605633263386065, 0.11935638368970926, 0.17373303642436383, 0.21037659998382294, 0.1856989620794212, 0.16981829648777363, 0.15248344279825687, 0.1526120229954681, 0.27950711788669713, 0.0963305922285203, 0.11758938657059786, 0.13176195954363193, 0.09850655006425035, 0.10575015653645801, 0.20299106806276307, 0.10834485803159977, 0.07616335060447454, 0.08495643885145265, 0.11481906707969405, 0.21496558922433087, 0.20498703354068343, 0.19931429035721288, 0.13369751132784352, 0.16227651327367754, 0.08898360985181025, 0.1223933783870551, 0.23434036651686316, 0.16279110985417522, 0.15831514922601564, 0.2407914090661272, 0.15867614517769507, 0.13530657176048527, 0.2220743029348312, 0.0944186436132558, 0.2346805248770022, 0.1128705301051659, 0.193778722877464, 0.15645925526417073, 0.26312104876964326, 0.16715201939786636, 0.2748400489649465, 0.24335028062905037, 0.22734636681214457, 0.1472270530798743, 0.15867669676100055], [0.022196179526227138, 0.06864487178503506, 0.01519664292103581, 0.005909444242265196, 0.0431355994735514, 0.010060425584895477, 0.04350502239239793, 0.05512541558052744, 0.012312602465822092, 0.066329455303569, 0.06451042549264047, 0.059509836362614754, 0.011920854787252123, 0.03680161132867779, 0.011938854023033093, 0.021573242791477713, 0.04284341736967045, 0.021924967164053552, 0.05906346374221387, 0.010384072835046438, 0.016619536327198148, 0.019057017428079442, 0.09426685095193887, 0.06208585680372292, 0.10307139221338496, 0.0755170175445176, 0.06362962356257824, 0.026473822973428235, 0.05059498610095151, 0.07079762481753865, 0.021598791823752468, 0.009295564358903757, 0.04458839329139841, 0.029057176791191585, 0.04399169889849521, 0.08781931708536803, 0.05181216957768606, 0.08049633624332567, 0.017129036507779555, 0.04952887516288508, 0.04950402327062142, 0.07429101639577458, 0.06028017224443536, 0.00753609357484346, 0.026366400209465818, 0.010130950681594832, 0.03649432963180927, 0.08915597963477336, 0.07323859544891505, 0.02093048161646772, 0.04562292225478638, 0.021181902097117518, 0.017825984996893716, 0.04662389656709087, 0.4869032374793484, 4.600044440838599, 9.815110641141093, 19.634686900723366, 25.828172160733132, 41.14452169787499, 40.98193553186233, 46.52136948800857, 46.142586200468, 49.5280780330781, 56.962691430122625, 54.73826823696014, 61.19463859065887, 66.20257177660542, 71.47913240617322, 62.66663743603615, 63.86654146255986, 55.420682199539684, 44.29571467061197, 47.49321514560331, 34.370639401097456, 37.177718916246974, 26.19604733682448, 27.980641434269568, 38.27798689565351, 24.037774916618105, 37.37329613777899, 45.11720411239132, 44.81426377450266, 39.73626529016803, 57.40062798223188, 25.82131781885701, 14.974219818269054, 23.66641079225848, 19.637373724291404, 20.559573942615142, 24.204144208661972, 28.885500854061497, 29.91220085851608, 36.59356817122429, 33.4068855931682, 39.733060713737245, 39.21524901543894, 32.14362156006598, 38.13236890300628, 31.7444242969636, 28.21704660692523, 50.05715870088147, 44.648257301699736, 51.174732177488266, 58.54999619145548, 71.24100531301191, 67.32530316998883, 54.76500703442482, 35.64365640763314, 21.681799350246308, 8.261739284761491, 4.404128424582943, 0.7280055097033902, 0.17614198458050528, 0.025926301849164793, 0.11793955003902798, 0.08796960055347412, 0.0707519966207685, 0.021286482674880855, 0.06181223701024729, 0.03912586846479005, 0.05826954001320466, 0.05742687777045274, 0.0069446210287541395, 0.14664787528735979, 0.06578574738194866, 0.07024640157338112, 0.05368196803535666, 0.014354832951099643, 0.03567556550185527, 0.03503866298424621, 0.06537738421391096, 0.027274344634685307, 0.01835301709962228, 0.07009611044439577, 0.023101906126905835, 0.045462135721238396, 0.037023504865506006, 0.04259564921319966, 0.04319120979597492, 0.03906087356529409, 0.07949847607843338, 0.010175802256731738, 0.022375294713363535, 0.006579595454592979, 0.007080376118181214, 0.03736265198958497, 0.03674844865717235, 0.038453304554305734, 0.008435271560184417, 0.024674939359688473, 0.03778076745689877, 0.06325962990822812, 0.027942938294502038, 0.0339129235925934, 0.053749054354885896, 0.06690532359625063, 0.025423617935889674, 0.05316102058596669, 0.03491071097913288, 0.04386157503411655, 0.06374056458533292, 0.04305530962864718, 0.06099551833505112, 0.017315686169651248, 0.016881948254341562, 0.04596754307708433, 0.044732061590278344, 0.07437727789604857, 0.022424726536677732, 0.06978926924808372, 0.05608826169684049, 0.03561354302350552, 0.11185580068418097, 0.03637413426692929, 0.024870351152194124, 0.027260097314513503, 0.056452908057479136, 0.07072558190913932, 0.038174498345582716, 0.04938049542327081, 0.015961537663374218, 0.07334934878012828, 0.040218332827451735, 0.07231695337160941, 0.03223819027264272, 0.025031647134211757, 0.01235293891025527, 0.04868558855847486, 0.0838455653959705, 0.02323510008864105, 0.006826025351221043, 0.01718819381729249, 0.05109175198501156, 0.04054900701908816, 0.11150082618358637, 0.042204484719062046, 0.010080447292796547, 0.061358456319618615, 0.05840290059906341, 0.07540492355943688, 0.00818172135510512, 0.04115257322067215, 0.03290734892230361, 0.008485486708401192, 0.026550002756618687, 0.018043287751835682, 0.016892008904007175, 0.026414303687371077, 0.07133649872435678, 0.050850982041729074, 0.07921875439464085, 0.015178300860908725, 0.07598511258801145, 0.0559804501432565, 0.01447634598720939, 0.047345053434612296, 0.09757883290970519, 0.04724141706021563, 0.026941739901479696, 0.007313143315484688, 0.03085194651277796, 0.11520178162402685, 0.0372503166868081, 0.04005425211582934, 0.047334623147523215, 0.023647929549277313, 0.038920679475150766, 0.030597691506808324, 0.1351310763387911, 0.9695081088331439, 6.192271776737706, 12.003363697759568, 24.296019846393218, 29.678602141718713, 46.65980169850011, 48.78379652577062, 54.328333485511045, 52.93383282999839, 56.1716317361401, 65.73593131957516, 63.48640103493968, 71.45333889992007, 75.77180570171726, 80.43231102728075, 74.09379220777943, 72.57367764749836, 64.6413193979571, 53.8991791202176, 56.315100269932906, 45.41503752431562, 46.446762084960945, 38.73913603444254, 40.445939725445164, 48.03124273976972, 33.28677869612171, 42.841860709651826, 50.3875046391641, 47.66373626647457, 40.96763457021406, 57.51707923027777, 31.753916432780606, 27.1907074605265, 35.95419437654557, 31.83558802450857, 28.113823552285474, 34.190633989149525, 39.11681713596467, 41.23926654938729, 50.192005865035526, 42.0955591817056, 50.88639482375115, 52.639619765743134, 43.89180860211773, 48.88546043826688, 43.98350577200613, 34.46433697977374, 59.73039034874209, 53.55036274079354, 58.917616413485625, 67.36734313349571, 78.89713456553798, 79.57572029482934, 67.62228150521555, 46.058627866929584, 26.99078425284355, 11.407265413192011, 5.609451695795983, 0.88978654795116, 0.18788162318448867, 0.043571457537191535, 0.12195565106887972, 0.053760679739136855, 0.02959822447249486, 0.042992727906112714, 0.02681187650699529, 0.025661695080118316, 0.028173456066137845, 0.05478811855878561, 0.0167657308010084, 0.04130230893591239, 0.038563046649458914, 0.07955291428633275, 0.04480635296673544, 0.09689440995815302, 0.024195550264970913, 0.034727290377862034, 0.018842413217850754, 0.03796585046896531, 0.0040995351868801785, 0.013702889254707242, 0.006735962139622819, 0.08109666572342958, 0.03960149032213996, 0.06843845705471693, 0.027018863888036822, 0.01653609786092514, 0.03641795066575851, 0.04200833939736889, 0.06695877355072768, 0.06740607696795656, 0.03131195166779142, 0.009930736475413846, 0.04268225162259994, 0.022376305949423584, 0.011479782537677357, 0.03945681844807921, 0.0283056196396149, 0.0376006716772193, 0.015029209617134786, 0.011216014634907968, 0.007618117651286265, 0.06324305176554669, 0.032123100883778066, 0.042499853748708, 0.04978138157316754, 0.02316329658271805, 0.05614731175404403, 0.026291026733815673, 0.025855614916391434, 0.0018877810549794607, 0.04151311335003665, 0.0997950716484939, 0.007907715644837629, 0.10833587948112719, 0.04296199245859058, 0.04721413283879238, 0.035184012846119946, 0.03845199454395521, 0.03813922382710922, 0.008664171928690087, 0.015551898001332679, 0.14153708823986594, 0.1473299080445882, 0.22845003904113848, 0.16428997619978844, 0.12314929266370113, 0.10473308288642477, 0.1413595243807762, 0.15752102248370647, 0.15441383114985882, 0.17111252542705307, 0.20984479706854592, 0.17202616188554995, 0.18791556087953432, 0.135494232658417, 0.09496946083081347, 0.07968710224714973, 0.3122123306797397, 0.19083994831289017, 0.12364247708671516, 0.3757798245116588, 0.11632623781840648, 0.13970757834613323, 0.2536034481900354, 0.33209706205994854, 0.2631241744083743, 0.16139946517444428, 0.11907804862505968, 0.15667918378547316, 0.18017655599021143, 0.12103369489552514, 0.125824012042534, 0.1590307979213615, 0.1202231738716364, 0.11752043865741262, 0.1243074031005944, 0.1448584930791009, 0.10868729933375314, 0.2518998984728129, 0.14652778334434957, 0.13664503461651265, 0.14695486204037744, 0.21748706037479065, 0.15325860120356083, 0.19021285938159113, 0.10652353761777764, 0.11214571899824566, 0.20181009756220927, 0.11091082356870176, 0.16319701387997598, 0.11172493754495537, 0.1699988940550435, 0.16987460395020826, 0.09423406238877967, 0.32630534542183726, 1.4988303088372754, 8.496130320333666, 17.267520812249955, 33.65394392321187, 41.28469151835288, 57.66983201426845, 58.69737532831008, 66.67733546226256, 65.55543168898552, 68.37463917270784, 77.84099717294016, 75.09538512076102, 81.47519865343648, 88.84166086873701, 92.91331644981139, 82.62357450300648, 84.62920788795718, 74.78415289232808, 65.66889409096011, 67.76192572809035, 51.11484150732718, 54.69118410541166, 43.45114600273871, 43.98780861208516, 57.73353130586686, 41.22581674206642, 55.950308076797, 62.75879352323471, 62.94858132639239, 55.66716394116802, 74.40030190252489, 40.3027496799346, 28.81723592358251, 39.0191226620828, 33.60196075131817, 33.897805521565104, 39.14317154115246, 45.09310114768244, 47.42427556745468, 55.203908489596465, 53.04147051226709, 58.92954041880947, 59.88644576841786, 48.83431665359005, 57.646525290704545, 49.23688911622571, 46.58031486695813, 67.06539123289048, 64.5756903002339, 73.70375956258466, 78.93354200547742, 92.12118594877182, 91.60654744794293, 79.2923604288409, 52.36919587658298, 32.39625946167977, 14.102454416213499, 7.469932869557412, 1.2778152909971054, 0.48750044898160044, 0.16693184572842815, 0.21265249398927535, 0.22899970712680973, 0.16666405203361667, 0.1383284055778096, 0.15398610893997455, 0.13402498327195644, 0.14067327813996425, 0.1834723122057415, 0.09819231611946899, 0.23694659763526535, 0.13264723542717197, 0.18452730720802663, 0.09053173565095471, 0.16932850583426415, 0.20160527629477365, 0.12019359521687993, 0.15414176268442986, 0.13773203677227422, 0.10311269967426216, 0.26919735174986625, 0.0898434592771434, 0.13169302695220517, 0.12683745443580613, 0.09712687167789667, 0.14152565820803567, 0.18854220547983724, 0.09956990308578938, 0.11220336711454777, 0.13455922234683268, 0.1571505883287999, 0.09748513269568644, 0.2017500362689457, 0.15034668568161227, 0.1922173131137125, 0.11967121518307156, 0.17989909426579553, 0.19502439716410255, 0.17306042654860407, 0.1497919307721238, 0.06926121250275644, 0.19847312581635293, 0.1933050200703644, 0.09763953005594593, 0.12848455879476764, 0.08755340030597103, 0.12779394585278728, 0.18196423748327842, 0.10290754898901909, 0.1337885685385235, 0.11667567350330854, 0.09917667781513545, 0.19906892771682433, 0.17958210240448677, 0.174142234628239, 0.12409102156638138, 0.1948331203311682, 0.17872527902645452, 0.0972596730195707, 0.16996098802455012, 0.1515822476076503, 0.15376043475924], [0.10218424707530968, 0.04115899303747762, 0.0752916727815905, 0.07411538307825405, 0.07241240026609552, 0.09162841349719994, 0.018896880154047283, 0.018484111980444962, 0.10195680323147005, 0.06932417726925305, 0.049895092003768494, 0.02766936638152167, 0.025779906277274414, 0.006742864113015634, 0.04347336763936666, 0.029374729811904893, 0.028605518164113167, 0.005895288373839351, 0.014270609244704248, 0.03345177696657277, 0.05533468398836352, 0.05995415203693894, 0.04090780812886454, 0.04758890305135039, 0.037399638714569236, 0.013865555576499433, 0.02253354358066234, 0.0554582616314292, 0.05822006605505463, 0.05947064713484818, 0.010148541975556123, 0.012278983654874948, 0.057159627998067494, 0.024290072108288447, 0.006823582967157446, 0.05890927705613356, 0.02744553464224502, 0.0737569994863964, 0.0841333539856057, 0.015802410667792203, 0.042639595846976006, 0.05056075346205504, 0.04065422536504846, 0.04902466673464064, 0.044542094767694516, 0.009879947718863767, 0.05242760248121716, 0.06178388792660929, 0.02351812935704666, 0.06557039240555418, 0.08874223086862795, 0.16336186067952266, 1.6529727150355618, 8.075659102009189, 24.309971717096147, 39.67190704038067, 51.397334529507546, 59.07951616471814, 67.0058653431554, 68.1730999485139, 69.60517298790717, 68.53898648292788, 61.833855490530695, 71.56410663358628, 62.28189606820384, 63.05716429987262, 69.2137518236714, 55.98440524070494, 57.71158172238258, 47.38781321433283, 40.44806565007856, 40.68627119064331, 31.938203111771617, 27.461896211870258, 18.167553755544848, 19.266533236349783, 17.86930065001211, 15.981163824758223, 23.203082776838734, 24.65862924052823, 33.98641186375772, 29.0469632610198, 36.62112674405498, 33.79417650161251, 72.52299278013169, 36.853480108322636, 15.011837309406651, 24.669733470486058, 12.812429032018109, 24.027394363957068, 16.816930693964807, 16.933876160652407, 14.307715969700968, 14.14841086633744, 17.969285788074618, 15.20169375404235, 14.55263170503801, 17.65698471376973, 19.154875124654463, 12.81170633531386, 28.761114651157012, 56.29155820415866, 51.8411232579139, 33.25292079679428, 34.861877041478316, 42.633755437789425, 41.056907715335974, 55.55932621802054, 62.160592848254794, 52.405371896682254, 41.82969308668568, 29.523701860058694, 12.458657718473866, 2.271879214432932, 0.561110926491599, 0.35010472480808535, 0.08916894950333143, 0.04143901732600024, 0.03706535241836983, 0.029655386122965047, 0.10731220215318665, 0.03849231758184972, 0.021576355023670103, 0.030982382557985765, 0.05296381806293803, 0.023071538401587356, 0.05671025614344305, 0.07296156273373673, 0.0723664196688802, 0.11026145680056465, 0.02255083226989354, 0.052738377539020394, 0.04990814997243786, 0.03357181145298866, 0.05229985348940377, 0.01797155510904568, 0.026493317995881362, 0.020269108335337332, 0.024085666443551743, 0.05305722333310593, 0.0679543660953641, 0.00889897404704243, 0.06718881443263063, 0.034725988028390754, 0.016249343489987716, 0.05046861223696221, 0.04483553325577129, 0.02490496875027255, 0.05709333074910026, 0.09397350822485263, 0.03328166331254667, 0.061424853160016, 0.0499616880270262, 0.05768377003410171, 0.04586659950174151, 0.06574326780654731, 0.013213990136019647, 0.047373126726597554, 0.06208695613989427, 0.023225121793427297, 0.018912161692916866, 0.08198463057558383, 0.020640151530143716, 0.053349658246001894, 0.015999843017198145, 0.0789697758192497, 0.031263655569824966, 0.07717384355923823, 0.043000193432934826, 0.03538053738133561, 0.14772858020038376, 0.044227336052685015, 0.031195247748626337, 0.05366632835038247, 0.03771090406864401, 0.07985303689154886, 0.03967752071818517, 0.0247769228993885, 0.017630640237081437, 0.020516064438608386, 0.07037907268010801, 0.050561006271070054, 0.028272779365520806, 0.012362088872900894, 0.06044068681677023, 0.06829727471115128, 0.02764289995895759, 0.011358349940799659, 0.03485123574313137, 0.07774449479315551, 0.043545785930848895, 0.02032914090030376, 0.04274655321252443, 0.02038021789743535, 0.13070724033299955, 0.02075329122524108, 0.04092513320727214, 0.028458643787270112, 0.028984080511896364, 0.0179014906227108, 0.01573436099269818, 0.05173658351263693, 0.00769325124565512, 0.053027181195155274, 0.042036814885514404, 0.034023856954468835, 0.031472996756013845, 0.057331273827942154, 0.0838072839823942, 0.07768456373483905, 0.023528094245721737, 0.07012115385864051, 0.03913027347035466, 0.018253743595954393, 0.02280971636214564, 0.03831642762487454, 0.07319197899872258, 0.03113094998914148, 0.08344111693722588, 0.09453822993823598, 0.020169277502704534, 0.03512785094039094, 0.031222734983349522, 0.032760106823256904, 0.05070526445765169, 0.04695051815360785, 0.03430310749418793, 0.08568606865141662, 3.4263134098822072, 11.540929982739112, 32.01603078073071, 48.481738721170736, 60.05939875879596, 68.00004497651132, 75.04599463555121, 77.2278287333827, 77.0085996197116, 77.06877662289527, 70.90469344969719, 80.94047761732533, 71.35727220965971, 73.8378026408534, 79.20456993964412, 69.80748884139523, 66.7443452342864, 56.180782625752116, 49.064112632505356, 53.74146453795895, 42.69479928478118, 36.077882397559385, 28.013603072012625, 28.561870013513875, 27.687073599907663, 27.134376341296782, 36.977223042518865, 32.94019806769587, 41.93325934871551, 34.46929093330137, 48.26901681961552, 49.175056872829316, 72.72665792895903, 44.26470441202964, 21.680106847516953, 31.964834044056555, 19.49030053231024, 29.281632784874212, 22.19389811638863, 25.40331082959329, 24.13177255661257, 24.747417972933864, 29.500475545083326, 31.539925644474646, 23.122354515137214, 25.04040529651027, 32.9000682984629, 26.23922674886642, 31.05339877067074, 61.65476399083292, 60.1259417687693, 45.30785483698691, 44.748065933104485, 52.934013259026315, 52.90144974185575, 68.66385905973374, 73.1150588681621, 64.55214038971933, 52.530315076151204, 37.520957685286, 17.85179707311815, 5.008579396432446, 1.072148262493072, 0.46269099798894703, 0.2235120967511208, 0.026518708064911828, 0.04160528138820683, 0.014257811745929142, 0.05804120750737287, 0.13976134239665924, 0.035688504726896365, 0.01960217134065686, 0.0728812690583929, 0.00743327021125644, 0.03232271658376821, 0.017404500657932895, 0.07221472659899343, 0.07773306476132524, 0.06711991248472084, 0.03416985416063859, 0.012551051162694012, 0.03771286908416979, 0.04978074955063001, 0.03782224728755894, 0.03752312825752362, 0.00585563853570831, 0.009440589591019578, 0.035038869827985764, 0.02416765700364786, 0.02085370811513595, 0.06688717497332443, 0.051517409587939905, 0.04787224833102477, 0.08080399715371671, 0.047727944179167675, 0.02785554106888031, 0.02695914158867973, 0.047857554764637066, 0.06714464946379585, 0.04830952748776444, 0.06069973178748643, 0.06074730201714462, 0.02264435053803027, 0.0035641771448295446, 0.0390823163662947, 0.031958443690992655, 0.08783774916082622, 0.03179336323462908, 0.02267978018930843, 0.05924764660096938, 0.017878019603930654, 0.035608172747156316, 0.05082527596142985, 0.027691376087586247, 0.007995249329870868, 0.04552693909875328, 0.04749404221412636, 0.06125950840331855, 0.058630516812686, 0.037687967396191055, 0.01559967507473043, 0.051957281952303265, 0.043684620214926626, 0.0313683070107213, 0.2876269450831798, 0.10258779155030366, 0.14112735377444377, 0.14979458143634183, 0.22325153492631453, 0.13983035159687843, 0.10397065686242235, 0.1028635755421654, 0.20559091000787674, 0.24226194548030056, 0.09289660310793309, 0.08123398698385685, 0.11173002436877259, 0.1513821760853452, 0.15675505713349389, 0.13365318548054467, 0.12477857015666463, 0.09937916251440203, 0.2011233457033673, 0.11563397012650968, 0.14929075605205952, 0.13068954370194866, 0.1480089683806704, 0.25292653290014117, 0.07386005363397061, 0.13375839999606534, 0.10243801370022759, 0.09954024016136125, 0.15783642088213276, 0.1758267240779054, 0.12424318961078122, 0.1358153613945169, 0.15168375425761746, 0.07386644280725911, 0.13456463092757812, 0.1399754026844617, 0.10518104513926853, 0.1393712810691326, 0.1355730324623085, 0.1054099445501643, 0.154190072188935, 0.20575188040252657, 0.15791376511896812, 0.25814987358547026, 0.13765852297506026, 0.09265429715836242, 0.1687769378505407, 0.1582760940636358, 0.1313787010768729, 0.23062909953296187, 0.17223060010902344, 0.2412640393501328, 4.614879825422841, 15.793529402825142, 39.86733128947597, 58.10368537902833, 70.06556510925293, 79.00334450506395, 87.02480331543954, 88.58765602111818, 90.70604185904227, 90.95083698149651, 80.47910490343648, 91.12824578439036, 84.03721240258987, 84.32328654873757, 90.7879723272016, 79.49610402507167, 77.4415429945915, 68.21221382387223, 57.621849659950506, 59.27325771700952, 50.32467611374394, 43.75698889455488, 32.53913179520638, 35.18190322383758, 30.417170716870217, 28.21248292922974, 40.22889929433023, 39.66376027753277, 52.02052854722547, 46.394845593360166, 52.82654423867503, 48.111110041218424, 84.09832292987456, 50.19850523241105, 26.95988774299622, 37.697303525863155, 22.90039150945602, 37.07274452332528, 30.02166440409999, 28.2318849332871, 25.920232149862475, 25.662859947450702, 30.22726916497754, 26.9542512970586, 26.41917528644685, 29.669774847645915, 32.262647844129994, 24.499449653010217, 44.97734415915705, 71.69731816937848, 68.58014783551617, 51.236062357502604, 55.26464246934461, 68.34807688190092, 65.5164158728815, 79.27201117238691, 84.15720555090135, 72.20405701668032, 60.4694119576485, 42.643812394911244, 21.42584312346674, 6.892704617592597, 2.127902488554678, 0.9552754822277254, 0.2839596821896492, 0.15836563442022572, 0.1430781813518655, 0.1306904783292163, 0.18014421175804832, 0.1813982670465785, 0.13688580072935552, 0.07778892023188454, 0.12891125444683338, 0.14752978038403297, 0.15781068032787693, 0.13577624494510313, 0.1575291889809793, 0.32278443596536116, 0.13931509618076587, 0.16973261721432212, 0.16954985927910576, 0.24547960669282945, 0.12378588108526123, 0.09522194042801858, 0.12110966783497604, 0.1041536293022575, 0.11027376017262859, 0.17272092702407993, 0.14136663367671354, 0.1732955695760827, 0.19263598016433178, 0.16390869423987406, 0.10281602446470531, 0.12166626135548278, 0.19863067945886045, 0.09162833688840752, 0.12757831508474005, 0.21092461331957774, 0.18340219983891135, 0.19570508160658423, 0.1685387764366404, 0.16363094140204693, 0.20659782533203402, 0.08806516236114888, 0.12794204597030917, 0.1379480888886798, 0.20958636496816913, 0.17205360315499768, 0.11326796119852413, 0.13345037136347065, 0.1116935509226976, 0.14567062288763064, 0.14132053050543034, 0.11806927170724639, 0.20258652767346752, 0.12911120339507057, 0.1664399866375231, 0.20035304429550327, 0.28739717999292963, 0.15773071607034053, 0.09346563023545089, 0.14288201687797425, 0.15306255930373747, 0.2298326285616044], [0.012203987477527512, 0.05002665994388442, 0.03138928824374753, 0.07497607520030392, 0.004092244902670745, 0.07083857221709144, 0.04535811247243997, 0.010087434014665985, 0.056371200949915, 0.011868519490704903, 0.02481699312826799, 0.012754207146504234, 0.04495973909093488, 0.03236838691537419, 0.030614459256251014, 0.029102766683565515, 0.05564094295785312, 0.01210226632294155, 0.027622296024234067, 0.03362767075398757, 0.05711477355010087, 0.049216288307140914, 0.10696159435376044, 0.11748194273921753, 0.05302341204256781, 0.055367729190977356, 0.012875001017575063, 0.015193690609697615, 0.01157916137843483, 0.07878529418620371, 0.008463280692306018, 0.039229144777862296, 0.04095344015607431, 0.03168860262620353, 0.0153515238742975, 0.0314033497875977, 0.04929179010251838, 0.04637630461084266, 0.01953244201778885, 0.03680777833646825, 0.04739777177512165, 0.0434900185604009, 0.00905877519999781, 0.02942869304529121, 0.10733493964277929, 0.0205882643950322, 0.045701775684832566, 0.03081886300576791, 0.07025501240165004, 0.09567607734953204, 1.4631466687686983, 9.722431898117065, 32.3821997257971, 53.282912008224, 62.92332126248268, 72.22170768245574, 69.12771855631183, 71.8860940010317, 58.22645164305165, 60.65369667545442, 53.83453845977784, 59.248954711421845, 57.26736153325727, 58.85004182015696, 53.8037556986655, 52.765535693014826, 48.716551411536436, 32.352728997507405, 38.591737285737075, 28.1354122777139, 17.745257654497703, 9.761147652902912, 16.47247402898727, 14.999337696260023, 17.184382254077544, 15.26852015526064, 25.96473732302266, 20.19296176971928, 20.93334444107548, 33.33402364484726, 38.3688642901759, 27.003830056036673, 24.152698401481878, 31.09276956127536, 51.65887032785724, 31.820379034165416, 37.17118816991007, 61.63288893238191, 58.454749276561124, 46.89534394971786, 33.549138192207586, 24.78777720082191, 24.732516888649236, 27.60198562375961, 19.186956190293838, 20.54784409461483, 38.118562159999726, 31.76419500381716, 19.827820485638036, 20.02203860590535, 40.03693065335674, 25.792133423589892, 46.275935019216234, 53.64044781654112, 32.77169500627826, 40.82093792576944, 44.31953522466844, 61.639298085243475, 50.09833182058027, 60.621545007151944, 62.68243282072006, 63.90603580782491, 47.73160895993633, 40.950027050510535, 23.076468667676373, 11.886034819387621, 8.821295788211208, 3.6440780085902063, 1.2852449955478793, 0.18701281819132068, 0.03980968620688204, 0.07481566404983883, 0.07727060046407484, 0.07761939263512051, 0.03800105603952562, 0.048984669284113956, 0.015123300535994914, 0.042471037351436196, 0.06587127343781533, 0.016491069127955747, 0.08630060140163669, 0.01047502183580711, 0.032076086067864974, 0.05416804316243338, 0.03717843082643325, 0.04305252106860281, 0.019608192791741703, 0.03176855922286068, 0.020826067662827914, 0.02726026202341722, 0.030265105925800822, 0.04155044864502646, 0.05322146492319242, 0.0246554539133344, 0.10074973977621525, 0.10075706357677137, 0.010640646214596929, 0.017669162968353882, 0.07758898660540581, 0.07288106221465335, 0.046275904957926085, 0.1491624976117765, 0.04000349112996652, 0.046312451182353886, 0.07622623110129949, 0.017169277191222194, 0.05283548684430219, 0.04755478149520294, 0.08145655850849806, 0.06890108989131066, 0.023863751839305607, 0.04132328825371881, 0.05750491914729919, 0.02720628921393185, 0.08909526716677413, 0.07557746954262257, 0.03673566648015573, 0.03969496837066066, 0.011245516680872009, 0.07468368242224378, 0.08801512915881411, 0.060472931457503196, 0.02877621212974191, 0.03621291489370408, 0.062317418370155565, 0.10469300882710565, 0.03785643396117995, 0.03364444424908969, 0.043880845975851825, 0.10122628476951392, 0.04550222510231599, 0.11552178421087804, 0.038219410250143665, 0.08852484575923412, 0.047728867315116434, 0.03269261447712779, 0.07384490041482834, 0.01560133748552612, 0.04836345241675454, 0.016753346989712408, 0.027715086508842728, 0.032570147661552314, 0.0008912851250985818, 0.01831036515443796, 0.030775483277055527, 0.021465391018277696, 0.09275739727121207, 0.10139057998575511, 0.05762549755614131, 0.022956351336512356, 0.026579705900662852, 0.0894759362563491, 0.05847848283367292, 0.032881068276061166, 0.0458278316223333, 0.11388753480728596, 0.018549258182305964, 0.05170357278397968, 0.02572592006125037, 0.027254728953384107, 0.037692138744938763, 0.037508155069043564, 0.004821358072090774, 0.030035777505667462, 0.025509664931544856, 0.016320166403367635, 0.05124122723035755, 0.03223060983263197, 0.038706324243497466, 0.030248292211082675, 0.034934252861046025, 0.03834889443110555, 0.03075817543562622, 0.028715832909989743, 0.08685207745480923, 0.1714646960458448, 2.392394528273613, 14.033843336566804, 41.235563831944624, 62.437155246734626, 73.38363139860093, 81.68760284300774, 76.14503491309382, 80.38560344326882, 66.27188005755025, 69.1394542878674, 61.00565879575668, 69.53800632107642, 65.91174371780889, 69.90696014896517, 62.04600080367058, 62.27248630216045, 57.51636535890641, 42.0174059560222, 49.09232624115483, 40.04175909103886, 24.73809842140444, 19.93101804487167, 28.592746911510346, 28.1454574677252, 24.115518254618493, 21.354697212096184, 35.40070087678971, 22.924239520103704, 30.938134039601973, 38.39626204582953, 45.523569506983605, 30.267310680881625, 29.102523634510657, 32.35567273632173, 57.099327195075254, 30.71111313758358, 35.47948560407085, 57.34846830368043, 37.27191071356497, 33.16136483223208, 22.590483080956247, 19.67328106203387, 23.9161677129807, 30.006392655834077, 21.022709761896444, 14.381528112196154, 26.23612807643029, 22.086087849832353, 14.727066370748705, 13.801626274662635, 42.09350778210548, 41.71068837565761, 57.20185010663925, 57.78892693981048, 40.88275055731497, 47.81718723235592, 51.61470443971696, 68.38397441371795, 56.570089632465, 68.67266870314076, 73.25449128304759, 74.1315254088371, 60.86941134545111, 52.44224609867219, 33.37576943059122, 18.664743592662198, 12.504027774257045, 5.455117216033321, 1.8522489767882133, 0.12253040853407114, 0.06130730079847479, 0.038498760381292914, 0.0922224150910493, 0.03829752440534292, 0.02985686341661119, 0.04635738606955256, 0.021068187836076946, 0.029063328477223555, 0.053321274688407305, 0.05852851220556806, 0.05681185472396113, 0.011108425246822018, 0.047663730689354485, 0.08254298609831641, 0.035226749060975934, 0.07623716317597898, 0.022377204187514804, 0.02663214844951947, 0.020063681858441523, 0.026124829704302455, 0.02464873915267808, 0.03229953476317948, 0.07504978051949894, 0.021708198755438772, 0.056016620984601403, 0.03619354053009902, 0.04452121121087863, 0.019102576676936402, 0.05533674859531945, 0.053601965473424044, 0.01890804013988424, 0.06902438408184437, 0.027040404365247777, 0.050068273839931336, 0.020219735883837266, 0.02701017262053586, 0.037891831053721334, 0.04209679573954594, 0.0620846885196384, 0.0806173628136035, 0.06953917984520236, 0.03536475597009544, 0.04524413774150514, 0.06015860941261054, 0.0851842810610129, 0.08156780213598283, 0.027256207503077966, 0.024010497896421342, 0.019617288170622724, 0.05818919654214575, 0.03703727912638457, 0.06212272861551854, 0.07635018412744807, 0.03069715270201766, 0.0275868836099342, 0.057020165521891854, 0.1233042262855076, 0.13632462600306158, 0.1292463872701891, 0.2898255254953139, 0.1600568348001088, 0.14049720049144762, 0.12697082268254412, 0.40258934721350675, 0.14614726747235945, 0.1470425331424321, 0.12601717345176205, 0.09223248148637433, 0.10923070082020377, 0.1952093614325408, 0.11605007844346187, 0.059464909136295326, 0.21471900084326345, 0.13048938024909268, 0.10323162716362747, 0.11626476692336223, 0.218514675394662, 0.19937168566449998, 0.26835051815836664, 0.16060279502022654, 0.13852395718136143, 0.21229637035679436, 0.10100873878165599, 0.0900646671652794, 0.14745985187830465, 0.26010802496344815, 0.07569995167995654, 0.21472496100731436, 0.09061536180876917, 0.08094553955860677, 0.10844769767455517, 0.1434755358364313, 0.11320233044605102, 0.17660926757079942, 0.10492775348886367, 0.124459563484115, 0.13409330299304378, 0.16003999618753312, 0.10457883874375014, 0.15798229934467425, 0.23560988145970532, 0.1623115847788511, 0.09825957097834158, 0.13106537111584218, 0.17943335877310845, 0.3451568386968105, 3.7826712814069565, 21.18445654069224, 51.55173078660042, 74.9832602470152, 84.60206508636475, 93.24581576931863, 87.16123119477304, 93.14289277599704, 78.01263224694037, 80.1561918566304, 70.17914910470286, 77.09551934273013, 75.66889839787638, 76.98512031186011, 69.49300104571928, 70.09242550019296, 68.23897223318777, 51.447682073039395, 57.87070835790327, 43.94187765736734, 30.02094464917337, 18.947279760914466, 26.785179491966005, 26.958791440533055, 27.405323866874944, 28.18403005599976, 40.52060988641555, 31.541616186018917, 34.990475869947865, 50.548733665097146, 58.35468569109517, 45.914665114495065, 40.515981489612216, 46.31632366488057, 67.82936696083316, 42.97164017154325, 53.20624143846574, 76.81334403253372, 76.09862542921498, 64.02437371592369, 49.324565856687485, 38.4893242005379, 38.96102843746063, 42.51402901064965, 30.38788433997862, 33.460104311666186, 50.424649484695934, 47.20947873207831, 31.11839048324093, 33.96629402714391, 54.48045476790398, 38.2630975784794, 61.32575558077905, 69.06424676218342, 53.72568484275572, 57.23431164218534, 61.6648405598056, 79.76091892488542, 70.72733171524541, 83.08057769652336, 84.02481771284535, 85.36667623827535, 70.76630438527754, 62.09228477170391, 40.28470285477177, 23.791093134110977, 14.057691347214485, 6.8248520262779735, 2.2336552268074406, 0.3102026675497332, 0.21498432773495876, 0.19854971928702247, 0.27193038574149536, 0.15716287637910537, 0.09218251723195277, 0.1606403180067578, 0.06999043627612053, 0.15239983196220092, 0.21359496599724218, 0.15920397975752432, 0.1417224968393003, 0.10535606558644965, 0.09316513224715188, 0.2104570238941139, 0.14393298225777765, 0.12859449241190188, 0.11062105081134266, 0.09045589294645096, 0.2520130036939537, 0.10577292466956763, 0.13788690910704676, 0.09239846209604895, 0.2624119884304462, 0.15662379562854767, 0.26482066079493494, 0.1679047314269889, 0.16272145714009964, 0.1865378130347498, 0.23621855363730462, 0.19055962141963745, 0.1738161109988728, 0.30908981758740645, 0.17679213275832517, 0.10406389742368653, 0.16043479193843183, 0.07964016404002905, 0.15729611439089622, 0.1363740233524192, 0.13481544811398755, 0.14690685897104203, 0.13593762902723205, 0.20479347376573473, 0.17599008466687896, 0.15643569039961985, 0.19911990320730596, 0.1466589222752279, 0.16728919510158802, 0.07601112893392002, 0.10686211783679263, 0.15548558815592722, 0.24500120010587478, 0.24491521439725356, 0.2637440008261512, 0.17271297503142588, 0.12535921117711452, 0.20833670702432433], [0.020577818786184636, 0.012976487557734213, 0.09276157245039941, 0.09984659872228101, 0.024753143530218832, 0.006921040363639834, 0.04762518114500469, 0.04296236401123386, 0.07355797750454757, 0.026578721477680152, 0.09458823249705377, 0.06628734345037131, 0.02431482057868233, 0.1285733943504672, 0.06055688703312509, 0.043489248642036994, 0.028472391235071327, 0.020071225909275875, 0.07340102141062099, 0.0570967743143199, 0.04462878144676647, 0.060797044106068156, 0.08567141338942513, 0.01055828314424763, 0.0370032265181503, 0.06701934046202129, 0.07663218875325496, 0.021255337370319233, 0.031385679969624165, 0.024697646205764145, 0.021638770122081045, 0.05836092664169208, 0.027649547686920534, 0.02576009715877233, 0.04745228276137383, 0.013487063134239327, 0.031097270848770297, 0.03771976387548832, 0.03794026696273396, 0.06694015761416766, 0.0659925757997459, 0.027670798965940074, 0.0760286646865068, 0.007613586241214146, 0.021581143073196855, 0.042315912207648645, 0.09540928722990137, 0.12129198143919631, 0.7120069585019543, 7.742521416756415, 34.60842524805377, 56.461847905189764, 66.43094785751836, 68.04792927157494, 71.41651568874236, 64.85556317913917, 67.10377554739675, 54.96862511481009, 49.756544328504994, 39.24404313487392, 38.66352842700097, 39.78851518323345, 36.23385152509136, 37.86578501424482, 31.990974680069957, 29.096000732914096, 20.24992831291691, 21.527106954205422, 20.75705743605091, 14.481431861077587, 22.756632720270467, 34.02450200050108, 21.203017196347638, 21.82169460481213, 30.98293927408034, 37.54302101750528, 47.22650181862616, 54.76120625772784, 44.88521160617952, 44.71808725787748, 40.02620689330563, 41.45711498875772, 40.380938206949544, 50.21712472361904, 38.58148421010664, 61.00809458763369, 52.18454637835103, 43.17958854859875, 59.20978984525127, 43.4987674990008, 43.201667570298724, 56.86398106236612, 55.89061744751469, 51.105200321443625, 55.02640947218865, 89.91333869195755, 63.98475385481312, 54.3065917876459, 57.89496821741904, 62.11958446810323, 27.453920072124852, 13.709189737996748, 14.793007296900596, 40.37243843078613, 44.943494104569965, 41.3496224341854, 53.65133631613947, 60.40668541385282, 59.246903311821725, 48.759105205535896, 64.00733101752498, 60.49578597468715, 66.58954497306578, 62.27334530122819, 66.05804028049593, 50.80258946264944, 45.796519402534734, 30.84371082244381, 11.03997172847871, 6.552807217644108, 1.7347078001306904, 0.25516505713664717, 0.09111433019561153, 0.10251203311547157, 0.014752919049633127, 0.011206145507223424, 0.05012272736958919, 0.04625975582448225, 0.12863511039364722, 0.07284583749189492, 0.03925690014335898, 0.07227405244784971, 0.04183819893026545, 0.03178520822867511, 0.02692074526191479, 0.15649077212137563, 0.05494697072032479, 0.01840262703837887, 0.06689323472880548, 0.03396743457884558, 0.022610673312878898, 0.02102714467553362, 0.026092458659061984, 0.025542283040140907, 0.13171554993717902, 0.10060896345924947, 0.05253133078616473, 0.04135233064692828, 0.02017407512833034, 0.03740605853137471, 0.021954992065025915, 0.0202222295000308, 0.046030166934454636, 0.03872720780031335, 0.022002564209903923, 0.021556616768301017, 0.06000128942691992, 0.017012074033940033, 0.07693316171606703, 0.02276325121431822, 0.03302116277477434, 0.07291414189122378, 0.04974632538975247, 0.03738427099080817, 0.01970856371636112, 0.0760598061606288, 0.011176027718090243, 0.025405260554004102, 0.02852265617900318, 0.05815461916368335, 0.0561934991949989, 0.018273342040277297, 0.015399610255694678, 0.029113664284288406, 0.048201275433623986, 0.05681005058689945, 0.010768136651735875, 0.022125373849825516, 0.03380119349927672, 0.07841931866301645, 0.031592839720448664, 0.03508126513371545, 0.014224303060121114, 0.05196062975653237, 0.03148543036302492, 0.0497564607329907, 0.05932871402511674, 0.010327180272959655, 0.03809700855204175, 0.02388982181136887, 0.03927107660039779, 0.042360299341981454, 0.059717082298330726, 0.053626273443261464, 0.09893665480757914, 0.09282443762546586, 0.034684577145643776, 0.022729635276200793, 0.08111486797251048, 0.014572437353161796, 0.038567880664261124, 0.04892613250581969, 0.05348118022084237, 0.05896996271105544, 0.013361180524131464, 0.06273253460324581, 0.06927861035951684, 0.048392801245133725, 0.01279497643061463, 0.022456419594105215, 0.0374392569515734, 0.032306211219439586, 0.015999791306263257, 0.038648925105770754, 0.058978971905044975, 0.04205577556164034, 0.05138371192339448, 0.05530894726454731, 0.03180423593749443, 0.034231566373379, 0.018419507785790393, 0.08846938099351623, 0.06320607653188129, 0.07619017134270362, 1.4699107961308573, 11.463713222934354, 42.26842195756974, 67.66910676033267, 76.56447748984061, 77.37862033228721, 82.42977019279235, 77.91771873351067, 73.02921387457079, 63.205053344849624, 55.58909308525824, 48.692432757346864, 48.08556364428613, 48.824730380888916, 47.167983978025376, 47.15236902236939, 40.161724782759144, 37.91055102502146, 30.090252930118194, 27.23524009027789, 35.32793698772308, 25.292739214435702, 31.397233739975963, 31.223835560583304, 22.47642251753038, 26.313135970023374, 27.041410284657633, 34.431812686304895, 38.34680880269697, 39.17028688615368, 41.228946793463926, 38.96696298353134, 35.78189642198625, 41.358847848830685, 35.60735879405853, 37.88693443421395, 44.33546004756805, 42.52110888881069, 27.60480384672842, 27.567180472035563, 45.097568727308705, 42.49185585206555, 40.16695722456902, 33.34392370716218, 30.799641032372755, 30.74987399962641, 32.519778820776175, 66.71027552696967, 72.34749809388192, 61.185244514096176, 50.581053995317035, 51.59275485623268, 44.57000209439186, 17.647059156048684, 28.575080556254235, 55.03139480467766, 59.326880439635254, 53.139627825829294, 62.810262864635845, 70.96430563157605, 68.24036859696912, 56.3883230763097, 71.44041861257246, 69.56824779510498, 75.42454258088144, 74.2305495662074, 76.56213191247757, 62.49912085071687, 56.548116514759684, 41.30558598426081, 16.96641222123177, 10.369742608839466, 2.115853212533459, 0.3504126002230952, 0.06224815253048174, 0.04267950902783102, 0.047796995514222694, 0.06330723461184291, 0.036340997133764534, 0.06680449110365684, 0.0769071147266415, 0.11198318578423032, 0.057694445469326554, 0.10211221948866883, 0.06343320627967197, 0.08745631398332697, 0.01696115600005273, 0.054269561303719405, 0.01633749914265448, 0.015570328161571056, 0.03974557230849901, 0.0783612875027522, 0.042366071814490903, 0.0377581870153306, 0.08806040495513909, 0.01660058714239107, 0.043097291246897755, 0.12093012746904166, 0.0969126811551471, 0.03445217671293405, 0.026525012968528657, 0.04584919398410186, 0.04694334757063658, 0.050565740694442106, 0.009816113442573096, 0.049556979098387306, 0.0347081879754701, 0.028072322884033767, 0.10206405554086932, 0.019472124085070628, 0.05372889858159808, 0.007867246092627607, 0.034603421621385126, 0.10235310051470034, 0.0163678917658305, 0.058072119155117584, 0.05870957325603213, 0.023646382051670266, 0.011339870942456108, 0.047879154613662156, 0.06475970284232209, 0.0025511628031850823, 0.09825409344968297, 0.012344068569702007, 0.04162406969454981, 0.018938239325859377, 0.05135412560775877, 0.020201531719536554, 0.19414384038217608, 0.10347944128537372, 0.18382383931067683, 0.18646587737865988, 0.10979243479068242, 0.1308509124623191, 0.13238812916942183, 0.15553938284997018, 0.14951535770970006, 0.1916079667787398, 0.1594410073612967, 0.14518034193784962, 0.13929127084632076, 0.24369120507711367, 0.16177529258833778, 0.28897617913542256, 0.11951962170461494, 0.24384068415289928, 0.17621529919485893, 0.1579885353003779, 0.1324495847427076, 0.13041056512344268, 0.1213084293469306, 0.06117171089675638, 0.18410146957443607, 0.10566461515883285, 0.19206311493631334, 0.2823696513810466, 0.1529256134263931, 0.12061167237979752, 0.09282819911717408, 0.121522550921767, 0.17163020168100634, 0.10703271029577141, 0.1400785794061038, 0.15147795239763875, 0.09473423353366314, 0.22562965570438295, 0.10734207958223359, 0.15090865713934745, 0.17185232121377222, 0.18162686768318378, 0.16483616624628344, 0.10163467092018935, 0.1223737282317973, 0.14484651146396516, 0.1407543455641116, 0.2283378837690238, 3.150281511968182, 15.35214214555679, 50.948438875136844, 76.74498496517059, 86.37513329905849, 88.25623143103816, 89.99268039580315, 85.54837611413772, 86.24902125327819, 72.80916890790387, 67.19664942833685, 56.852370846656065, 55.598196906428186, 59.07540944314773, 54.518129133409076, 53.299574236716, 48.190020284345074, 42.75415651259884, 33.62789546289752, 35.282123704110425, 33.18722501877816, 24.641002108973844, 33.84513593489124, 47.301517148171705, 31.538792079494847, 34.5761166849444, 44.542651407180294, 54.72446933869393, 62.64324442032845, 73.93327313084757, 61.52794984079177, 63.02606382677632, 55.12585332316738, 59.33117151260377, 54.59673343166229, 65.77197397908857, 49.83254417296379, 76.0748480212304, 66.6149462423017, 56.934948505893836, 74.64813293949251, 57.27644966494653, 56.54837539119106, 72.14477431389594, 75.59769168976815, 68.4051630573888, 72.84818080163771, 106.73190501428421, 80.5338768805227, 69.85887189065257, 73.658401273912, 80.40319135112148, 40.77573653190367, 25.045047421609205, 26.76939783557769, 54.8010967623803, 61.190920183735514, 59.38987370460265, 70.1336339212233, 80.10261228007656, 77.46550867634436, 68.13208764599216, 83.82544363698652, 79.03313882889287, 87.98451315972113, 83.79816747480824, 86.84121285715412, 72.0626869509297, 65.52909297327842, 47.30881667906239, 19.66947244059655, 12.272618720608374, 3.3757138540667877, 0.6722417245468786, 0.16910051806799828, 0.1692438224751142, 0.09267303566899031, 0.12809103474982325, 0.1796896151837803, 0.17072779607147942, 0.13032470198888935, 0.20031853969539368, 0.15594196205417957, 0.2988172526801786, 0.18348063192059919, 0.14884581218563742, 0.2590039696904921, 0.32205864426589786, 0.2127591487500937, 0.17857385408734122, 0.14724700200942256, 0.15908500630288355, 0.21287683517702166, 0.12345130750609022, 0.19855197158551988, 0.1571003482827256, 0.23146916090721087, 0.30351340229953494, 0.21189115581012544, 0.1427855817300658, 0.10129637415370635, 0.3189693181024444, 0.08278039674605094, 0.11667193499423804, 0.23850500433435365, 0.21914315860598318, 0.09510780098818003, 0.1140362860995435, 0.18731972833554592, 0.18559567810546967, 0.09613966779603113, 0.12265152703489988, 0.13471409468160522, 0.240101715429656, 0.1414083854685868, 0.14240918741110833, 0.17259600872714675, 0.23365703141016347, 0.07272569958360926, 0.1629298636990209, 0.22117030386242176, 0.21124457760203272, 0.17401679539151732, 0.1748081029302651, 0.06972324779076923, 0.153627349965034, 0.10556668613947208, 0.08982377847836864], [0.08219292222131645, 0.03147610132732699, 0.0069233271360938115, 0.10325339172155627, 0.03911280283524145, 0.05050216305760607, 0.043796614608577186, 0.0252935457824459, 0.052030090948626886, 0.054904720971300724, 0.0796096584188842, 0.06811649328277958, 0.07928063131628499, 0.08312941874347388, 0.008848524284398845, 0.08051212531544509, 0.13400295058325415, 0.04828294040635229, 0.013959066183756919, 0.019150985772871686, 0.038098165344807415, 0.056194598531170245, 0.016413573588755344, 0.09612566370877529, 0.03560161503452448, 0.07077949917725018, 0.03151578851224434, 0.0314739907550956, 0.07399165221760351, 0.06414203679249172, 0.016701113199815154, 0.047593005452184915, 0.026420275342740843, 0.00711212711100797, 0.019324682803163608, 0.08425744490758066, 0.01588049034903487, 0.059507449998730616, 0.04070442710672656, 0.05529845569042429, 0.041977469884460016, 0.07610643027170051, 0.03445264019612824, 0.05378270476695992, 0.050622710822931224, 0.17064372558266888, 0.7312088603934934, 7.6592029198523495, 23.917926896002985, 52.795259414180634, 61.25909097733037, 74.75936351283904, 64.43641085778513, 64.75262841870709, 58.92114262427054, 55.07152457391062, 53.50045842509116, 36.27422055890484, 36.391903431184836, 23.764558299895256, 17.807893983779415, 23.140079705945908, 19.683610623882664, 22.77519533711095, 16.71068545310728, 14.979670932216031, 15.232040151473015, 25.9607365054469, 18.80994189170099, 26.380536017879365, 26.813975572586063, 57.11122766617806, 84.91045751879292, 75.87772538585048, 62.18384858100646, 58.746483402867476, 64.47293989119991, 51.17177863274851, 42.7227657841098, 33.34631635296729, 24.731618665879775, 15.126719609383615, 15.51935866955788, 18.519661003543487, 9.15872258524741, 11.653283334547474, 20.84757201133236, 22.274702864308512, 10.426000183628453, 11.834468399324725, 15.9732965307851, 19.494234669593073, 29.680837892716934, 35.975798791454686, 43.13603455020536, 38.79937187317879, 28.035185913885794, 28.296829577415224, 36.80080659927861, 40.00700296894197, 37.170729252599905, 58.13126748608005, 25.492181931772542, 16.972784111576697, 12.342272170128362, 11.906813575375466, 8.318399883085682, 24.882980969644365, 29.504172378970733, 33.200298278562485, 31.508474119247932, 46.77737866678546, 38.770840552545366, 49.09012971385833, 57.512564582209436, 54.05605431525938, 64.5074136026444, 62.71660843203145, 57.84163182781589, 40.30445983332973, 19.225746470112956, 5.473067943126925, 1.5649957906815315, 0.046756383812715935, 0.05459590709858364, 0.0205670744030466, 0.05010850877771455, 0.078217500460244, 0.004311207674383637, 0.050262136219610135, 0.02978600794449449, 0.026601263614852103, 0.05984526029938172, 0.027191164723086744, 0.07324807195653839, 0.00990796834230423, 0.055880100286055, 0.009101290206965661, 0.08117542722292485, 0.06026136478589428, 0.04962053758302524, 0.018411772212974967, 0.0479228139644669, 0.03562779225889714, 0.045682941413214134, 0.07313201729688915, 0.028046312283784635, 0.08691563210900753, 0.04285444137490085, 0.03568485814837679, 0.114593944482265, 0.05457457154989243, 0.03128337084255632, 0.022272621694531654, 0.03384736178803348, 0.024516742203324556, 0.02686765153832253, 0.02516582168849005, 0.054353976532095866, 0.06210197529364979, 0.012330498279733284, 0.028386464898264217, 0.04540300905524243, 0.007661291972673949, 0.06327420473098755, 0.040310791979033145, 0.02689580143910022, 0.03470280620780203, 0.048007344106032, 0.07220982363627804, 0.0614314032117686, 0.08891021862866418, 0.034546987754443, 0.06974440713923785, 0.02686816864767142, 0.03654906661399911, 0.012999178124441495, 0.03971496326548438, 0.028425263421189402, 0.04793789440525636, 0.10322765882817969, 0.08307320321159017, 0.06548134234523581, 0.026116431465432532, 0.052318147669035586, 0.0047271713922401115, 0.018371228924802235, 0.04280669494502006, 0.031383084846780665, 0.044871401492386095, 0.03937454060501149, 0.06075047745159077, 0.05402171270801656, 0.07038500986152119, 0.049168518894622405, 0.05934620381242806, 0.059637612167505495, 0.015100161807851927, 0.034917513839900494, 0.06667181999692995, 0.04963860193627977, 0.04375895755665918, 0.041289155206252495, 0.032241530415992585, 0.11789933808388249, 0.10037105485436418, 0.028324036393314603, 0.08173228121332585, 0.033544485096729575, 0.05663063662547258, 0.040612871938895796, 0.05823888117447496, 0.04088355761562144, 0.0599967580168478, 0.035141016161369706, 0.0845649985656623, 0.05852057553467251, 0.028691501957514597, 0.05331217739430647, 0.05338428925061899, 0.023369692160838076, 0.2002584630803716, 1.4866150675281402, 9.921607894282188, 31.707026458555656, 62.6491593545483, 72.28266131493353, 82.83462939723846, 71.2897760637345, 71.23227411700834, 65.8379796243483, 63.68863059628395, 65.55552190349948, 44.18415069580079, 46.565908001315215, 29.06913838078899, 26.733255155624885, 31.260260651188513, 29.269416562972534, 31.9015799414727, 26.829551304540328, 26.433017330784953, 27.223941702996534, 39.621528117887436, 23.767488310413977, 26.78715048297759, 29.697349109957297, 56.38388687564481, 71.80665031556161, 49.59867285143945, 53.36255965694305, 44.89451546822825, 44.51175489733296, 41.31747861062327, 34.50165048722298, 25.514227613326042, 21.86778049315176, 14.71853913799409, 11.251553200906324, 10.731742074412685, 7.516392363655952, 10.507442316701336, 11.397893890257805, 15.103576644774407, 10.224002042124349, 12.006129949323594, 14.692769165961975, 21.25612020492554, 23.415655628327404, 29.873453724768858, 39.99519271235312, 44.04089789236746, 29.272550536740212, 34.2055860642464, 43.96700043832102, 50.41248621479158, 38.82051737077775, 51.144223982288, 29.558969851463075, 29.412498743303363, 25.445641048492927, 25.7903899300483, 20.4123281663464, 36.2646617427949, 43.34908200848488, 44.94789108153313, 45.424035441490915, 57.325012530049975, 44.98992712266984, 57.43781205146544, 64.76167732669462, 65.5460140782018, 73.32489782764067, 73.75824912901848, 70.62368700581213, 51.23258713752993, 27.9216254526569, 9.589238993583187, 2.8709165800002316, 0.16038038437404942, 0.08878666396823623, 0.06643860751102049, 0.014081600989635675, 0.05225647376069138, 0.05137562969579332, 0.03484097782582526, 0.07736142784837755, 0.0033813481070777223, 0.05210982921022562, 0.028760417311963056, 0.05995278840043372, 0.021111533090832735, 0.07720844775077797, 0.018358751267735517, 0.04673794790681812, 0.06628713660663174, 0.05411204596560809, 0.02663918879754361, 0.04519309713354996, 0.08606545837415804, 0.04367662991787638, 0.0081206344616329, 0.0384659526659356, 0.07746304941153334, 0.010380460730483456, 0.032954953625918396, 0.04623215367657043, 0.06808489981678224, 0.046961289349823236, 0.013436033059993099, 0.01934687062467058, 0.0915188552631486, 0.023865559806806907, 0.02997639228499705, 0.03079335993876861, 0.10511137710343446, 0.08929138567538993, 0.014762001021975472, 0.060621586988770196, 0.03874790749602741, 0.027675138854031122, 0.02996273868296656, 0.028200776676737496, 0.02359002096308095, 0.026940182827773596, 0.027340143926501758, 0.07852952041092419, 0.022570857808234233, 0.01897963488684787, 0.10256035028085594, 0.016278240326491576, 0.012899078203425294, 0.17614832778851833, 0.12484895831514752, 0.12036181280329344, 0.18126734262031896, 0.19927666011837222, 0.1584713698755349, 0.24310592922472188, 0.11326902606073888, 0.18060331292931112, 0.17322951747525125, 0.11909779071086839, 0.3272041197746031, 0.21163542033924213, 0.21855768357073108, 0.10135624392498886, 0.23723787958583525, 0.32160855228862456, 0.14715292641232092, 0.16311708026595656, 0.12928744958293054, 0.12135837061871445, 0.17658081506529164, 0.11245026959166413, 0.1716908298793339, 0.1032503350307384, 0.20144697188610033, 0.11714549990551126, 0.07581167028195436, 0.20798637501655087, 0.20746670693399447, 0.16184908217720448, 0.16170708011955987, 0.16873547717207865, 0.18077303204805623, 0.13851776719093323, 0.16843221360637298, 0.22332218355469166, 0.14626769649405635, 0.1473739887437513, 0.11671399322128105, 0.2334650344545803, 0.13123225570926744, 0.21479651361944216, 0.10358681616884086, 0.10755063169786047, 0.32263989049580794, 2.2348182095635325, 14.664426119096818, 41.58241902628253, 75.04174278628442, 82.12876750576882, 93.75258599558185, 80.4235484523158, 83.58173108869984, 76.18739651095483, 70.75885188195014, 71.85117706175774, 54.56900619691419, 53.76837591971121, 37.59916190178164, 29.995863053106493, 35.05358288365026, 33.89029418268512, 34.75077982871763, 29.3487641503734, 25.475707977048813, 24.659639250847604, 40.20775771910145, 28.115529783310432, 37.17123916072231, 39.89928291689965, 74.29806924635365, 101.939678653594, 93.58010368962442, 81.46240388193439, 76.62268546319778, 80.28058590427523, 66.70110502550679, 54.570598679204146, 45.37073827558949, 33.287778900515654, 21.764500564144505, 21.688008462229085, 24.32364117714667, 12.901121666354518, 16.490862100355088, 26.560557119307983, 27.77762543770575, 13.171087618797058, 15.835573288702196, 21.544624259394986, 27.829251673913774, 42.08472951765984, 48.02516698837281, 52.28586119990195, 47.45475630606375, 38.71114600089289, 40.00978392939414, 49.83821984260313, 52.024835309674664, 52.52440406430153, 79.50061475076984, 37.76855338004328, 31.87191309467439, 24.962510947258245, 27.393486153694894, 21.227155462388072, 37.63727165037586, 44.45550418669178, 48.35512853437855, 47.79046412437193, 63.30422262991629, 59.29342654443557, 69.24495820076235, 76.51030171302058, 76.74234913241479, 83.86014092353084, 85.00144081730997, 81.29280844042378, 59.07754713489164, 32.1342961249813, 11.318298212943539, 3.4020334482192998, 0.5331779511705522, 0.18605799684601446, 0.21177377581836718, 0.14050207281064603, 0.13392408949232873, 0.15461138990377227, 0.22243986477053937, 0.10069920861672971, 0.07074206046039058, 0.2674623464624728, 0.2153613196024972, 0.17937758757222086, 0.12153131496762076, 0.155277656571519, 0.10925390562343021, 0.2145761714106606, 0.1453543511489707, 0.17284992090877027, 0.146696629122861, 0.15812679884895203, 0.2988224314345468, 0.24287074023196775, 0.16160672260147912, 0.14314256338102205, 0.12981598896365013, 0.2359368631075467, 0.14850344749227648, 0.35551830044677185, 0.14531774746794857, 0.13402338980907394, 0.09239540540523107, 0.11709116128904205, 0.14418162375448212, 0.10205357545806516, 0.11785667464737931, 0.10361990350629054, 0.23694920233420788, 0.16740361799395856, 0.07456965789559387, 0.18988503503703302, 0.1058790508297182, 0.15324649701435722, 0.15599822355133874, 0.15492692619802492, 0.14311349800517484, 0.20426989863476447, 0.1355761121357641, 0.15346581266532022, 0.20942367853656893, 0.08937731009697722, 0.25614972526748336, 0.1170216388099136, 0.16176476654025818], [0.018224908046484477, 0.10469942098303188, 0.008034998280627113, 0.05395851045426342, 0.02604604522216945, 0.10514176781139067, 0.061805855497838035, 0.08032584337577706, 0.05131745680926308, 0.03065528408173592, 0.0336401503262741, 0.007165933775174762, 0.022262442301237778, 0.0248169950434878, 0.051226131467809605, 0.09108847472816707, 0.0413277430549985, 0.028632607033115723, 0.03398971241568366, 0.0538572068175962, 0.06878793870489444, 0.08862246834342519, 0.05824809721220405, 0.011279445757428485, 0.024330705411792285, 0.07571725760616603, 0.04698719461298278, 0.04639723413293401, 0.03837231756939042, 0.10088405797197934, 0.02467989594855857, 0.09536747415099414, 0.04994803634021552, 0.05337187096536641, 0.08229611426471703, 0.014780024198004076, 0.019097648816363468, 0.10749165824944935, 0.044462716567420194, 0.04425224157110338, 0.03873859952774741, 0.015305642868512341, 0.062119376980849815, 0.028582401460998004, 0.39454744648068185, 6.460409904679945, 21.401293008558213, 46.2871176965775, 62.35048655540713, 75.1372132762786, 76.00418260020595, 66.37048844368228, 54.47839944593368, 53.70515907964399, 49.515628430151175, 74.95393660760696, 29.28169946516714, 20.35824260404033, 19.37108205210778, 17.707506802774247, 22.13287780361791, 17.09624267393543, 14.519812253213699, 10.906965136528017, 14.637170549361938, 18.25640524587324, 21.050866496178415, 18.649507145727835, 40.78519336638912, 49.18489025485132, 61.63445395808066, 44.28059785596786, 50.69428497745145, 57.45547056198121, 38.14476751512097, 26.82130648243812, 17.273669127495058, 13.464414227393366, 15.086385876901689, 10.905075534697502, 3.4866740290195715, 1.7560116634253533, 2.6336592724246364, 2.7920043756884914, 1.3643317453322874, 0.4857863119292644, 0.6828356786601005, 0.1848407903866422, 1.1378419567500393, 2.936170110779424, 4.914622451028516, 3.818263113498688, 3.8697966837113906, 5.832714476893026, 5.128690215849108, 8.192421688187508, 22.91170362503298, 26.32274381576046, 15.981980658346608, 24.53240344601293, 40.69774804576751, 42.54922443820585, 62.92918912826046, 54.7122040871651, 47.60965070416851, 33.740220377522135, 30.258091149791596, 21.320241151317475, 15.330020958377471, 16.03868930570541, 13.21532803197061, 24.84454958669601, 28.870282057792913, 41.98059058958485, 36.22453589593211, 44.32492848365538, 58.010842877049605, 58.79994530831614, 66.63581325161842, 62.0478678518726, 61.3466892703887, 38.26528233866538, 23.30513696516714, 11.226120552709027, 2.7963410462102583, 0.921413905678257, 0.1792300543597629, 0.12007141185383644, 0.029583521330008106, 0.06269040742828962, 0.05498130295065142, 0.09263443249848582, 0.020433240757894613, 0.032770196201219674, 0.04290940435302835, 0.01610215118665609, 0.026268609085931417, 0.05168533606094219, 0.0210004560874715, 0.028748315037979234, 0.015187525517126967, 0.031569194416665745, 0.10675879555844492, 0.08674043546160383, 0.051674576356045665, 0.043370102817613276, 0.0575874268167442, 0.031203339552326553, 0.0479212932799372, 0.008370403065195969, 0.04062016509593495, 0.05127579694794071, 0.049019817398079944, 0.01856148303035767, 0.041965132038439476, 0.05237131034054103, 0.03663964118928679, 0.026145468112982573, 0.05256934023852791, 0.01840227655315351, 0.021913738230303414, 0.032758310347074465, 0.13137871639863138, 0.021646250970661644, 0.09655416732834232, 0.028625070643160614, 0.03387411357834935, 0.09639302839434917, 0.13901485100148187, 0.026064682226147384, 0.0471746371758561, 0.012583121518424202, 0.10071886643286675, 0.01466136771224199, 0.026201028639691013, 0.007689129692622491, 0.04880320220705002, 0.03300300649096889, 0.04373722747268696, 0.03024641146522857, 0.055380695229095805, 0.13982923310850898, 0.023167215122450745, 0.047758204652176756, 0.025527643099907908, 0.06102980843054191, 0.005226307360815906, 0.04434471987488289, 0.03878808880765592, 0.03636475352029647, 0.05120630511232922, 0.026518342257927985, 0.044826600670574174, 0.021628801402966344, 0.06413945507618689, 0.07264399630648476, 0.0748402324895705, 0.07031321210125763, 0.05984866556020514, 0.011727522923460892, 0.06250422124961211, 0.06073326728637181, 0.027948398586182345, 0.07551660385703848, 0.01127634310133515, 0.06953656748538056, 0.040794174307056015, 0.03659949435161487, 0.03210623928856465, 0.07383789071032117, 0.03839936430355714, 0.030343591633643356, 0.035265084100706924, 0.04685211799017364, 0.10916483258047413, 0.005852143738358732, 0.06603845680553107, 0.011307476914577909, 0.06667307638112577, 0.04686892978967198, 0.502950971525523, 9.70173845368047, 28.374404253498202, 52.81397304227276, 72.354260260059, 82.71820560578378, 86.93171762651014, 76.158810277139, 63.399057695942545, 60.51046348387196, 56.988328041568884, 81.61494485793575, 41.77236372424711, 32.89332182176652, 31.38236991820797, 26.6107673798838, 28.95424823607168, 25.706129574006606, 22.886590650004727, 18.62145631544052, 23.09269943544942, 24.822060677313036, 23.18143717704281, 29.406213145102228, 35.34779594790551, 42.999834168341856, 44.644817383058616, 34.30982697394587, 44.23599658473846, 47.50329955931633, 30.155246603873472, 21.50277453084146, 15.00556936187129, 11.52898342378678, 9.419880855468012, 5.625298561588411, 2.5121099237472784, 1.2629041556389102, 1.3263937230071714, 1.1233843454430181, 0.7924386522462292, 0.11091116064738844, 0.46649401166266014, 0.18983432001644568, 0.7921019412817494, 1.2979222185188726, 2.6382920818944133, 3.204238126354833, 4.213361499770995, 5.390273082640864, 5.444643507080694, 6.6647050842162106, 14.964715915341532, 18.10295820236206, 14.369196180374393, 17.299866637875958, 30.57371251044735, 42.65133942327192, 44.92353316276304, 45.950841134594334, 39.364875670402284, 32.52338151777945, 35.41105201167446, 28.079626367938136, 26.44442162206096, 28.15866997165065, 21.778797603422596, 34.152390879969445, 40.46006418043568, 51.74643331958402, 44.19438808195053, 52.27737319084906, 67.94448852539062, 67.76984891583844, 74.29213077791276, 71.5931635518228, 72.55252822752922, 51.68440888004919, 31.825438891687703, 15.945788948766648, 3.221398986154987, 0.9927260274848632, 0.09522492817092328, 0.055176157414192156, 0.09169795895896612, 0.06038912143858691, 0.006954643374023539, 0.05535131958763927, 0.044086540583521135, 0.016301052509656837, 0.04715899749088192, 0.05168606384447025, 0.018688316547101545, 0.02568576939313883, 0.04259945283974371, 0.054471494419680494, 0.0037461656404869452, 0.06812496621522211, 0.011775608347248168, 0.019816428896099813, 0.0843892120305569, 0.039421482642571774, 0.012082868976698769, 0.03314309332880282, 0.04057670875843014, 0.06852825022032184, 0.03816017250139867, 0.05056219753779231, 0.017266865301456664, 0.03042163492570962, 0.03979452532686053, 0.010432719418238248, 0.033432073185160276, 0.01940390204019364, 0.007694024036848738, 0.08801433242737286, 0.04680007380703765, 0.03900642769651548, 0.011137888988389844, 0.01987031360547389, 0.010902319824503315, 0.038089654107968655, 0.022475510505178285, 0.06862637076166368, 0.10126497987056933, 0.046752511238258694, 0.025727272206436724, 0.026703170545759703, 0.02836756933961184, 0.04563403819056769, 0.006778070162380896, 0.039820782990465244, 0.15076398909572633, 0.18254497809515846, 0.15574533792753376, 0.10177532466308725, 0.14133643449073838, 0.33636061715022214, 0.08689828787840183, 0.17657699994742873, 0.14853116455337695, 0.14515642467285358, 0.1647791386612, 0.19485165965893578, 0.11668054582250696, 0.09983067941521445, 0.19352689445499452, 0.18854298688952, 0.15297620587291258, 0.2159108038270666, 0.2114224172527752, 0.13828726665627572, 0.14608438697553452, 0.22335037559030518, 0.21153708529328147, 0.1399652750021027, 0.1964216342856807, 0.1526311905153336, 0.09798502038803794, 0.21812331171766405, 0.07183397323974679, 0.14905031169614485, 0.12069375104000493, 0.23869219025777233, 0.33066650011366416, 0.30630033823751635, 0.13072319028358306, 0.17021298498636292, 0.1241274796906979, 0.16186458779679191, 0.24897442319460455, 0.17336436427168309, 0.15999942417106322, 0.12245382272428083, 0.14892887143838793, 0.16736163637570797, 1.1487207729970257, 14.144346310246377, 35.96543196708926, 63.71791893436063, 82.60073061912291, 92.3087929141137, 93.91221077211442, 84.201857812943, 72.19945215409803, 69.8145491077054, 67.17173453300231, 88.37806024859029, 43.32226868598692, 33.8059946029417, 33.19192794061477, 31.542510486418205, 34.64065928612986, 29.0461983988362, 26.04239829124943, 21.840267027578047, 25.831031568588752, 28.893753520904053, 30.379988608821748, 28.641798111700243, 58.50417506310248, 67.28849564829181, 77.88016596148091, 60.365975133834354, 63.892668370277654, 69.42685419513334, 48.637896122470984, 34.858166479295306, 22.859528257000832, 18.866898628973193, 19.627667819300008, 14.343621346258349, 4.670335275511588, 3.467665242571985, 3.9103218768873527, 4.373303988287526, 2.6053265217811834, 1.0274758983042933, 1.2452309362349974, 0.4845639420372825, 1.7990676433809343, 4.612954431964505, 6.728832894755948, 5.448054988538066, 4.912949069853752, 7.598247816485744, 6.966555003196963, 12.301019622433571, 29.620503994726366, 34.462367949947236, 23.011910377010224, 34.46948705180999, 56.05064230580484, 55.170431060175744, 78.0880751148347, 72.11667445398146, 64.61337643284952, 49.3674805087428, 45.76807829641527, 34.67435636828023, 26.189826457731186, 25.757538118670066, 24.07420785196366, 39.01518068005962, 46.174424079156694, 58.38886130240656, 53.570657084065104, 61.58227466767835, 77.66314906458702, 75.71462538934524, 87.11463343712592, 83.07043444725775, 81.9445808472172, 57.18006134033204, 37.590724883540986, 17.65355460105404, 4.302812132143206, 1.2942734336660755, 0.35186001610371376, 0.25554903572605503, 0.1280908508887214, 0.17984736800914813, 0.2217643744041843, 0.1893387837035041, 0.1362716740057353, 0.1553872377882081, 0.1853290641860616, 0.2215004417925112, 0.10975902569630455, 0.17457231638893006, 0.151663483571141, 0.252051507273028, 0.08152599671795484, 0.12891808795111795, 0.27901109127748397, 0.18594231756944812, 0.31416303568309356, 0.18932926889148452, 0.14164991766935395, 0.16368055325602332, 0.1509533353870915, 0.12128810503429945, 0.11306549182101605, 0.17591491611974855, 0.2529893521099322, 0.08803192180611434, 0.15717439834148655, 0.12458938474376356, 0.16156555303642828, 0.09367497908251901, 0.10990361713113324, 0.10359636928525665, 0.11612816578558377, 0.11791892695210635, 0.1996447806877475, 0.07374530898467188, 0.21980464488508242, 0.14040223623235382, 0.1411841821766669, 0.22877884397823967, 0.22124738762936286, 0.12175639926065361, 0.1730443999892281, 0.15166271748321672, 0.1398766999162974, 0.14400329380746812, 0.26752896546836824, 0.11846183814228543], [0.012737629003822805, 0.04168834830183656, 0.05257796638855531, 0.036883908323943615, 0.041228067355170366, 0.010800026019193954, 0.034569633313484734, 0.0794702380775444, 0.01776768570585597, 0.07248086554388847, 0.047507720714014386, 0.03361955788286944, 0.02772336600408439, 0.07733434664025422, 0.04232585219846618, 0.046802391223008596, 0.07384677733024282, 0.07718335071037855, 0.01749905697520702, 0.07762785024580456, 0.047254624416030226, 0.04557695314888993, 0.029008938149819453, 0.013774325038426587, 0.042949941895541646, 0.009949516163267677, 0.03492977124668899, 0.02127455468589981, 0.05173327401280404, 0.11778787229089968, 0.027309601916180506, 0.013882461221768491, 0.01602376507024371, 0.08819076247633466, 0.016085207236990813, 0.06199048268758963, 0.05915255593736807, 0.032429352192388426, 0.038172935526217186, 0.10367791168391706, 0.07954995718694503, 0.12368320998164917, 0.5627378520946349, 4.046187876693664, 14.064501562426168, 50.21653636809319, 63.56543679391185, 61.56132921095818, 69.55518630243117, 66.30907197152415, 41.73160637578657, 44.632218730065134, 50.678148346562544, 45.54470323747205, 25.343112253373672, 15.685510270057188, 18.514318735368793, 8.881059961934245, 18.098114075199252, 13.881289612862373, 17.42306044024806, 24.226674302931755, 38.468923953271684, 38.13935856665335, 39.3430829817249, 51.13810900718936, 61.871027792653734, 62.34412447098763, 51.098999054201194, 44.76105290074503, 35.050268480854655, 27.455185036505423, 15.763992974835059, 4.762865949061609, 4.540129255863929, 1.5877852516789592, 0.9438732134238367, 1.0502220906557576, 0.7013396438091033, 0.13885122994261404, 0.03870006913559572, 0.06374226530052482, 0.01993005314180928, 0.10519514881795454, 0.05192778373677885, 0.04827995266344759, 0.06378917286412851, 0.05137470655984456, 0.0695712942509882, 0.1256425947611851, 0.17720729112625125, 0.5729535426343642, 0.42666249578037574, 0.9055903289587268, 1.326859627039202, 1.8633769861152096, 0.5746044314676716, 1.9148220578508994, 2.723051314392398, 3.7207767703840813, 4.21234707678518, 12.522084405345302, 25.834532283967544, 36.23973115797966, 46.91306914052656, 53.704331459537634, 52.215682152778875, 45.75484814182405, 45.391840627116544, 27.572518817840088, 40.10197139555409, 33.23446212276336, 10.413504492851997, 23.86700668642598, 23.711976966550274, 22.027507251308812, 30.071723653424172, 48.039671913270034, 46.9183761073697, 54.54474633739841, 55.88817381089734, 69.25061425855084, 59.874823785597286, 42.48388167350523, 19.31350754153344, 10.390881242290622, 4.14701460830627, 0.44593356008971896, 0.2018495664120682, 0.13726329821492397, 0.09598961415430231, 0.023416950209667126, 0.03007728606462479, 0.058864491556080124, 0.018326355324637507, 0.04929481614981929, 0.04544568781350409, 0.06538614059888548, 0.11140046866550563, 0.02432478929779703, 0.039180812290719444, 0.043527702425396254, 0.02510065441921113, 0.019655424027493405, 0.05414491879843897, 0.048843850832312345, 0.014854428572430006, 0.01145318779538596, 0.041831939991924076, 0.06858896268832107, 0.025691051569376743, 0.013987527307753843, 0.026321243156769106, 0.013158441100630068, 0.035759957747594, 0.05097125018496187, 0.0279272890334288, 0.012519579313154663, 0.03155921037579256, 0.06588064269312928, 0.013705862633463357, 0.02787020399175104, 0.07540195879916992, 0.038841737944993286, 0.04475725822210793, 0.03335742940825801, 0.06143385086268668, 0.012648854735157183, 0.027371423296450127, 0.012471283215188212, 0.01800834265116963, 0.02656511192570531, 0.06742538238364844, 0.05019201236146112, 0.038507332905165614, 0.018414612483954238, 0.025392120230882883, 0.016484892544066234, 0.031654605559343775, 0.019526117961973916, 0.036048328564051664, 0.09402278300014236, 0.04554744727248627, 0.05792977235790703, 0.05101859058824278, 0.033494294846370336, 0.02877438692526231, 0.028604692704374754, 0.06177063077507962, 0.03476612337474381, 0.052869263660883715, 0.07742468372828538, 0.056521396317909804, 0.030407609771035855, 0.010426316838411075, 0.018414137509441184, 0.05841931403284112, 0.038151546351371274, 0.026061688737583258, 0.02572231753278644, 0.06353729847638358, 0.07876947447056733, 0.058793417748905, 0.03240484887013032, 0.047249411187705495, 0.013534790411922, 0.04389548974652444, 0.04591700042627993, 0.02376641462286634, 0.030597009688555717, 0.009249639303062954, 0.008643135154289345, 0.05122912304115392, 0.04947392750651606, 0.07243211170838726, 0.018407914960276217, 0.02979269972251308, 0.11389819109031271, 1.1943011658806955, 5.912953913211823, 20.715988259161673, 60.97363264329972, 74.98679822491061, 72.0637224566552, 79.89061601700323, 75.76710670225083, 53.12679383062547, 52.75626320992747, 57.27562204484017, 57.587889778998594, 35.77910761679373, 27.857463321378155, 21.880843947010657, 14.017755735305048, 28.193816369579686, 17.7060398363298, 25.787981594762496, 28.765399840570268, 35.12393059269075, 30.88489570925313, 33.98444675630139, 39.72299983424526, 42.43864890067808, 40.494290782559304, 41.02000997912499, 36.62336641742338, 31.906449564041633, 23.721355353632283, 11.735394231734738, 4.34168674292103, 3.2884384211032622, 1.6257448470400226, 0.9312467974039816, 0.7706145846074628, 0.2695691495412781, 0.09020138321624649, 0.014776127683299204, 0.08435538158782067, 0.07001295926109438, 0.08391784579162637, 0.05307306986181967, 0.08167816476235468, 0.051037520620851755, 0.08280720982340076, 0.03450828116206873, 0.10300936207415597, 0.04986676973320785, 0.2785110810110646, 0.3409383295764846, 0.6090333420903452, 0.7908504600486448, 1.2255771650422005, 0.36109882196591747, 1.007460717472338, 1.8154838657186878, 3.1288494361985117, 3.5907023952853296, 9.250427599876158, 18.095627292510002, 27.8198968210528, 35.59321472721715, 43.64802152879777, 45.788529534493726, 41.36459804350331, 37.145324060993815, 29.981699374414262, 46.81404890552644, 34.129766648815526, 19.490439776451357, 35.48938566638578, 38.24581953787035, 33.49198925879694, 39.075345916132775, 52.99117395954748, 56.45458367563064, 62.02712243603122, 65.68504641132971, 79.21848650901549, 73.84157596095916, 56.01299147452078, 32.48645436379218, 17.584930773704283, 7.396381074382414, 1.1898223094401823, 0.3956857918491287, 0.1932971600082613, 0.05979006366443731, 0.059354232413874525, 0.04343799352946301, 0.02633600184063037, 0.052275422945498466, 0.05338322055796462, 0.027715737683578368, 0.04890879593609322, 0.06925843926447053, 0.050133192130634864, 0.05313151470956303, 0.022386027605182702, 0.0532417394401085, 0.0348272227171448, 0.0013673309642340868, 0.08095212025387634, 0.021945268494046984, 0.0179195492303059, 0.02292770347858389, 0.015851559996184324, 0.05575464572757483, 0.05105444733353873, 0.026370703708380464, 0.02120891818776727, 0.06666371478669106, 0.00875888146354907, 0.03360313678821249, 0.02531202382317955, 0.015519142954520162, 0.08132994715725222, 0.06478089283430769, 0.04318166434043839, 0.0059667275091933635, 0.03107495853797563, 0.04842566258664574, 0.05019915996179466, 0.08542425044241451, 0.030487924513797608, 0.07872805975738072, 0.021835241031142014, 0.0367848799684115, 0.03700078269767185, 0.02118810740930419, 0.044539635625457576, 0.03265729399337884, 0.020648375484010866, 0.10194922662189893, 0.11746351066375933, 0.16871096235850166, 0.07208638388903872, 0.1805252945351024, 0.2022688310112684, 0.16073160504381503, 0.13640886503121546, 0.27679440054682, 0.12069680773082281, 0.1341963418188595, 0.24546687431152792, 0.14849521970796972, 0.1560311653320828, 0.21229359711850845, 0.2055302511660322, 0.1952527066872966, 0.1353592326444003, 0.15543096608692603, 0.14877044445564672, 0.10322832532467381, 0.12497705587696646, 0.09415877892846063, 0.19084146516698022, 0.1851130273914145, 0.14254083196001668, 0.1815305091440678, 0.22376200995377957, 0.2303253150274677, 0.23328923259771642, 0.1963096781964264, 0.09361124822809812, 0.1215967541981128, 0.2786363823519599, 0.10842381105307611, 0.12813038868649354, 0.09319334726540313, 0.12628377204941166, 0.1995897296095087, 0.23696631673843632, 0.12534506919403232, 0.2241407944670608, 1.760251623007559, 8.795634661951373, 27.781885131712887, 72.90422362665977, 87.59417456965294, 81.74917620997276, 88.98386247696416, 85.77501066269414, 58.3209886089448, 62.87658229950936, 67.5221904631584, 61.93974379570254, 39.390261250157515, 25.821878717791652, 29.57250987329791, 16.672156010904622, 29.619091941464333, 24.012187334799, 28.169038757201168, 36.960894215491514, 52.73994615001064, 53.940999430994836, 54.06387159901281, 65.30648669888897, 77.57830035301947, 75.8313786598944, 68.02721915706512, 58.20275268247051, 46.39631648217478, 36.373938975795625, 20.642451663171094, 6.875915892662541, 5.821787243889225, 2.485062484779666, 1.8102703003152725, 1.826097921979043, 1.200161922362543, 0.482938640540646, 0.3588451138667522, 0.28386677104619246, 0.1550732489915625, 0.20566511328422254, 0.13313702608068145, 0.2753030112193477, 0.31434404693784257, 0.5285717402735065, 0.2916711232354564, 0.43106560144693623, 0.47516799622005035, 0.8842754339979542, 0.9225781754620614, 1.3989795119531694, 2.4172172479091154, 3.0543633814780944, 0.9812592847212669, 2.747892910434354, 4.481864898435531, 5.631516989200346, 5.313202431125026, 17.42745153365597, 34.46743565220987, 44.90183853333996, 57.17183613008069, 67.58367753797963, 66.67594694322156, 60.83678899272796, 57.69195810441048, 40.74655802019181, 55.09348984687559, 44.950291572078584, 22.1863789327683, 38.15750737344065, 37.83137798309326, 36.22053900072652, 44.867741369432025, 63.176012116093794, 67.16175602328393, 72.51096679318336, 76.19245636847712, 89.66740608215333, 85.96217047783637, 65.31562582139047, 38.65853132740144, 21.17788068709835, 8.989544876160162, 1.480090817616832, 0.5691731745196927, 0.28067506489253813, 0.20631343817278264, 0.16443879643995918, 0.13646733286159654, 0.1192629669282225, 0.1552319824094734, 0.1965064095753816, 0.14667163933477095, 0.1551274114078091, 0.26164681981167487, 0.08398372935311449, 0.10360121096093809, 0.14331407514550995, 0.10118426484686714, 0.15199860107273827, 0.1644992560989434, 0.17127501267579295, 0.1233277758283, 0.14455181276125295, 0.13761902348168437, 0.09521034951772421, 0.17220018641842952, 0.0856933847910935, 0.17966706155528947, 0.0635238612941917, 0.18194087180158786, 0.13464517741193696, 0.11257378594769586, 0.15776188052710027, 0.22887034551991572, 0.2396749431687978, 0.14863987242983234, 0.22688498269886742, 0.156995578098201, 0.22791984491050246, 0.12903418091516342, 0.19480736445515387, 0.2053656801581383, 0.1257724390034714, 0.16638927161693576, 0.09347345199315779, 0.09648256109005983, 0.11617685833405103, 0.1900975937925039, 0.1372249172099175, 0.11095632153052477, 0.0818887470109809], [0.03402721241957719, 0.053292979230924006, 0.016421443226957516, 0.05807868452862867, 0.07044248177760071, 0.024117966625659217, 0.08835099742657716, 0.019651957479636037, 0.02300273604510773, 0.12387972685598558, 0.018420999742022926, 0.05747509534440695, 0.024913414869637742, 0.08252499069297507, 0.06289451240351604, 0.0667208496240839, 0.030654663550517255, 0.03585827747179616, 0.02350468642919535, 0.07048553591894527, 0.007551607812920045, 0.04737799521535636, 0.05308131296788493, 0.015920561535524267, 0.030124718398456613, 0.06880453216933435, 0.02148380202631797, 0.08394431412941025, 0.10739806528774001, 0.04188220302063612, 0.03356640287224324, 0.013598627561042386, 0.06426220151385473, 0.019613189600227822, 0.09102675868498702, 0.06459023653259201, 0.047250368797610846, 0.09263690696248124, 0.07538626165760141, 0.07917061342947906, 0.10300452805935376, 0.32058530396992163, 10.96843259949838, 36.66529263219526, 59.759498257790845, 69.00731748150241, 69.99413874841505, 66.24356838964647, 58.17545690844136, 53.58344401082685, 69.82861472714332, 66.44033801171088, 49.32873925855083, 23.602136873429824, 21.78501259896063, 17.305571725291593, 26.766742390971032, 39.04093496261105, 33.38999586720621, 38.76991879555487, 37.40094884749382, 42.63784254750898, 51.25900822301065, 63.390216673574145, 60.438178123966345, 64.73527977543493, 50.88767351642732, 47.396968026315015, 18.625798379221273, 12.100168774204871, 4.856358583896391, 1.4310265020016701, 0.2934459344513955, 0.4245865507231605, 0.07850835340157633, 0.0470994494765276, 0.052468549880769946, 0.11568836236913359, 0.039051573257893324, 0.06827321188944964, 0.08242673225580685, 0.047919898999915014, 0.13169152541987358, 0.05932841142038665, 0.06233919058896362, 0.08700275162775671, 0.03219662617231089, 0.045130434971783435, 0.017488617112018892, 0.021518007852137092, 0.04081770469765029, 0.04991639307850311, 0.016333304811269045, 0.05834688425004002, 0.03621892485347006, 0.025084327170324903, 0.16370448584277786, 0.05819664291676976, 0.030282130314698143, 0.009746611073252656, 0.3578324988484383, 0.380375953691621, 1.131217563825269, 2.7863838643796983, 6.602916477187988, 13.802014589309694, 33.652594627872595, 40.13484085759809, 59.50042570790937, 60.61348845881801, 45.94148628173336, 66.74687908541772, 53.17058317122921, 25.247726094338205, 13.102618725069108, 17.58574466551504, 21.21115219208502, 23.473918514866984, 26.267575679286836, 36.108084647886216, 44.56245545418032, 51.012142089105424, 53.28071155855733, 62.85955529059134, 68.07242055093089, 56.122900209119244, 40.86801029020741, 21.23143869061624, 12.580851316452028, 4.952384089269946, 0.6391314044594765, 0.1149093122371743, 0.02710336530130477, 0.040164721994510585, 0.05480037213513448, 0.041828779879236416, 0.03128318315101487, 0.04513312394039766, 0.028431844116458972, 0.05635471473778448, 0.044998882353425994, 0.01588749718071232, 0.05624798719861335, 0.01817107504804529, 0.058654093168555736, 0.04938927479088307, 0.026942172741156914, 0.02207591712865378, 0.03140274457813751, 0.048979095994464816, 0.03224655212233624, 0.02315468958488876, 0.03880556327320876, 0.0445856890010257, 0.09128283123455702, 0.03728304396293337, 0.06811209593809421, 0.052441349929018374, 0.041082499158238216, 0.03622502291334733, 0.024646927354737155, 0.07382357252701637, 0.04124135898065664, 0.04856876015002209, 0.037196502840567025, 0.03058587843101592, 0.0534388768456636, 0.056840471938372626, 0.041364982588997776, 0.012460795471504813, 0.03649606865139739, 0.009765091986816016, 0.02340617518301212, 0.05076907575130463, 0.013132161411997533, 0.12716448204892297, 0.021353971190570344, 0.02207682685806386, 0.044604553916161103, 0.07355658322452538, 0.04463787107998806, 0.05190491601223907, 0.04853052087128163, 0.036506989234758, 0.007455056315408119, 0.07710792935423313, 0.04953246428481033, 0.037114339910687945, 0.04453265273402776, 0.017111858901297374, 0.018192286107448802, 0.03409704516431497, 0.06441995050878295, 0.0652719245502545, 0.030605361962150184, 0.02290020283732203, 0.009220150663637587, 0.037991755732124856, 0.03526517220081822, 0.027222028490336194, 0.045589892373931025, 0.025357609885113857, 0.051255744596522664, 0.07650367750395691, 0.1617102364018079, 0.010842750742731076, 0.07305446621631423, 0.014577635259728038, 0.04757122557249762, 0.03160607771978023, 0.033493210831957484, 0.05806342022673738, 0.059119380499807105, 0.064771247787341, 0.010340848239138722, 0.10291963785646424, 0.07525912170568783, 0.7997144037677396, 14.693624242659538, 46.32996174596971, 70.31181935341128, 78.60321567904565, 77.86344097506615, 77.20875816960489, 65.13041542422387, 65.0798443055922, 66.6133302257907, 71.72587302423292, 62.10265551843951, 33.885289238345244, 32.75920029609434, 24.581895912847212, 37.08842223690402, 27.729097873933856, 31.66864802760463, 33.84541834554365, 28.378971853563865, 35.42714549649146, 45.012939668470814, 53.04512616126768, 44.01264506001627, 44.035492866270005, 41.31459959091679, 32.44452226546503, 15.104079688749007, 8.798071434420924, 3.833193615559609, 1.2778830744566456, 0.5749821434578588, 0.2975287540785728, 0.10376648676972236, 0.04693974695739247, 0.12281289579527033, 0.058955031657411214, 0.0407501625558061, 0.03712856616344183, 0.015134669280791236, 0.026484209210461667, 0.023606696781972726, 0.0612269803100536, 0.28998502500114903, 0.1265594717716017, 0.16112194216299444, 0.06096798130461286, 0.03997065660153185, 0.21579351576585926, 0.08044109364310581, 0.16851105937553992, 0.05200421249854469, 0.042418755681043675, 0.057396559840849334, 0.06712575007470385, 0.09646147835038363, 0.08401415836546691, 0.01460473562004946, 0.030798100107800097, 0.2103039288833257, 0.28236284852027893, 0.8828854440681396, 2.329540017151064, 4.7945636030166385, 11.502803564071657, 20.61536377476108, 32.585774660110474, 44.89460568274222, 45.13604717869913, 40.37448983038626, 59.880530834198005, 48.56823090584048, 31.03950965789057, 21.30064695112167, 23.522712799810595, 28.03098309424616, 32.69073336355148, 36.064601252155924, 44.87425642628824, 54.18901481936055, 58.29367714543497, 64.11420383761006, 74.00004756066107, 81.83487215349751, 72.14027143293812, 52.8823438767464, 30.820868899745328, 17.209442277108472, 6.4154806252448795, 0.880216945323252, 0.17750496225010964, 0.016883599173818386, 0.027765883883881955, 0.059209246443764824, 0.002883787406796229, 0.027089338231411193, 0.0255463260691613, 0.03728424672097449, 0.016494832534883774, 0.04825654101648158, 0.023989060841080163, 0.04721604422816346, 0.010333097344564815, 0.03336170034843587, 0.050334964368131854, 0.044806065683763836, 0.016268476535896623, 0.026923305910801696, 0.0399613945985273, 0.05191483685085851, 0.03259288132070534, 0.05781970467538603, 0.012559887986900586, 0.02041006276774551, 0.03914661029533994, 0.05345950376302485, 0.029437912913459926, 0.05598856684481425, 0.0836350903996537, 0.028956526244479804, 0.08781363271296987, 0.02001188856910073, 0.06457668443721148, 0.05232107412490634, 0.025544426171109084, 0.008285705341897424, 0.03071805349581184, 0.06425196274874673, 0.02181501822516082, 0.04331589443609119, 0.02671023004598195, 0.04207125436815043, 0.01949663123776836, 0.05109582374232912, 0.11727290798819835, 0.1296168214250957, 0.08822845400220926, 0.07256852898506388, 0.20485315201503618, 0.18469744001425084, 0.13630637778870522, 0.254055823109323, 0.122771205290431, 0.05764624704757045, 0.19034447328698254, 0.1788160144802063, 0.1589576518463512, 0.21161409245143015, 0.23180127534414494, 0.18633912047070844, 0.20835650273628775, 0.2045683052030302, 0.1778797784279431, 0.10091088637108765, 0.22239448172190499, 0.10303925482496139, 0.10009718608231315, 0.09947706855112508, 0.10795080538598761, 0.09634682563163581, 0.13161839466662179, 0.11729534670350053, 0.2827754941198134, 0.34070261964394205, 0.16231553779254038, 0.20682501636685865, 0.24595309499531026, 0.1899266948983554, 0.18736089790059676, 0.131313644890343, 0.13589740941120734, 0.15754297856361638, 0.18285581060955602, 0.12208823790593494, 0.16420668712066067, 0.20612355561987047, 1.4036004317383612, 19.85683818017283, 54.66358238650907, 82.7383508989888, 87.10521190397202, 87.95301652723744, 85.44235444838002, 78.33340367963238, 71.22238974417411, 82.37171126950173, 78.96040239641744, 64.30427405142015, 34.738098805950536, 33.04600792546427, 26.516497135162357, 40.79745077317761, 53.45487263894851, 48.97001889444167, 56.74293671884845, 52.411310365123136, 60.05448795134022, 69.37886007370489, 82.62598283829229, 77.91371007119456, 81.39802994266634, 66.64476410035165, 59.24960582487045, 25.812396387900076, 16.033796148915446, 6.191820213871618, 2.1816453337669373, 0.8532260742879684, 0.8076037610730817, 0.41737487479563684, 0.21538796414050365, 0.25994855610112994, 0.26235345931303117, 0.12232161893118774, 0.19608892230016572, 0.14416901394724846, 0.18390441643855265, 0.45053468416294745, 0.3361449174342617, 0.39374308480370435, 0.2099724732820065, 0.3038469569817666, 0.23640313486178077, 0.3848986303614032, 0.25233209463617495, 0.22398633581976737, 0.36148005796055643, 0.12643722712152428, 0.26358940428303135, 0.17846520749791978, 0.13897561197800024, 0.33878929973129307, 0.41971168811282805, 0.13209940595251898, 0.07726657084159314, 0.6844637074297475, 0.6505325700967544, 1.7073709637888017, 4.16053697947533, 9.155525853556972, 17.973288566835468, 40.43624754874937, 51.487921668637185, 74.05755735212757, 77.83610989970546, 57.85018259479154, 79.09104870211694, 67.31067272924608, 37.850142601997625, 23.603301817371, 29.62460679392661, 34.02174065189977, 37.749608332110995, 40.88751623707433, 52.80594002815985, 61.939108371734626, 68.36042450320336, 78.03996332230108, 87.63211957869991, 95.30613483921175, 82.38443543834072, 64.65030162565171, 39.68679243518461, 21.50526915827105, 7.650990457304063, 1.1685976289933728, 0.31165703950870427, 0.14569660859002223, 0.10842460778451736, 0.2021191527526225, 0.15717617566547087, 0.12574368772367317, 0.13408447766015608, 0.09484154713009635, 0.15283176765566872, 0.13022671934337388, 0.21900092672196128, 0.13968536179632912, 0.1849531141981002, 0.12361968597096783, 0.2027881160498627, 0.19219175642055852, 0.08809497850316186, 0.20013720668371648, 0.19284204249420475, 0.13457659722095536, 0.14174161839389032, 0.17248825079971747, 0.14499617440085258, 0.11979548996614835, 0.2033193827035927, 0.13004313403319928, 0.19456817648343502, 0.12255853162177148, 0.1924606073167055, 0.13976056098697648, 0.23687234839364407, 0.11088276176803535, 0.11436204966758529, 0.12552803397298823, 0.0791770638898015, 0.13727911026968112, 0.11381669465692774, 0.1587339235289443, 0.15522950028459873, 0.08451769263633797, 0.09367555364846222, 0.09263270880065619, 0.08814496574022117, 0.12281992082153598, 0.284781847749987], [0.026650833333992673, 0.06477743777776919, 0.009878023880563918, 0.02424979312044959, 0.053187224623416705, 0.030372758516140526, 0.011620221775956454, 0.08043792969997852, 0.02215106269314645, 0.1153582474216819, 0.12149041353334343, 0.04420362180098892, 0.02938769201958372, 0.010832619229932467, 0.06014978791016245, 0.005732572735137036, 0.04904890192612525, 0.06766687628001937, 0.07567698436398661, 0.012745188376415643, 0.03987433253637245, 0.06501494035605462, 0.03678435902862299, 0.018107259923952724, 0.020515731190361326, 0.029958322186083085, 0.08957714413202579, 0.04410653547834485, 0.013758353062815244, 0.06671860498646576, 0.04657366035145618, 0.04416757736415152, 0.045034754420480425, 0.007848102513009743, 0.09995821007196942, 0.018269410094005928, 0.019055829991796808, 0.03893248489006393, 0.057935184769092075, 0.12623116479165133, 1.2187792072373054, 9.734177435598067, 48.99268234929731, 66.73216235253119, 70.39112967829551, 66.23211506874331, 63.70912890280447, 47.07620836073353, 42.30536283985261, 42.07935979289394, 70.11631273454236, 55.955434614612216, 22.306001417098507, 25.823153488097656, 17.738232689519084, 46.224163655311834, 17.237673536423717, 42.8341571746334, 75.72170918987644, 48.02764592632171, 56.39031564035724, 41.68294937379899, 27.614123398257842, 22.199377667519357, 23.129597171660393, 17.805062032515004, 10.32898526037893, 2.909017012965295, 0.5033568142642898, 0.46941096804315047, 0.19973540888918986, 0.12467605227063741, 0.11864761446392345, 0.06900766038245733, 0.030972678139204943, 0.06656995328563838, 0.2063493830181899, 0.08830267260031355, 0.10222747741687684, 0.08076449766034081, 0.08641644921754638, 0.08340946984507384, 0.08926547658179076, 0.05932930391281844, 0.05758571461023343, 0.02227144000390845, 0.03286899856081413, 0.012196209769876254, 0.13780219510437983, 0.0997802172036421, 0.02992943301045847, 0.07266730070114136, 0.05459327558656374, 0.059421759233960224, 0.06478910529685598, 0.12100269131722952, 0.037776381603532264, 0.05289915641168914, 0.010692956613286609, 0.1620238881197668, 0.01786540788147719, 0.05106268660916437, 0.07656129497674204, 0.19905775815488833, 0.217375946982253, 0.1876631042649669, 1.7318917834951033, 2.941665106242703, 8.361658723123613, 24.790324780248827, 42.8923180795485, 42.58353733247326, 51.116720322639715, 54.477038383483894, 46.8585011266893, 36.7415278188644, 25.85060419574861, 13.84838975244953, 17.913297876234978, 21.724292347508094, 31.82322471372543, 38.403032056746945, 43.385226649622766, 59.944147756022794, 56.461934197333555, 66.75133489793348, 70.0648198589202, 72.66921089541528, 54.20606144012944, 32.58679839872545, 15.595684070740978, 1.54307697328829, 0.4726360449867864, 0.1006419358835105, 0.006667729561036874, 0.051556958877030885, 0.056622477789078994, 0.01583735098040873, 0.04337374173525361, 0.08969280042595441, 0.031381813140826366, 0.025305659547748587, 0.02036122657779244, 0.027926097766706542, 0.02898882259614766, 0.05770144751295448, 0.01806603098708776, 0.0266398495483783, 0.03933027221430694, 0.06508598735015239, 0.03827259590428683, 0.10024464268597866, 0.08713815000749404, 0.0219843408934051, 0.0843657314356777, 0.10131779397206922, 0.09422700671899704, 0.03268154067618232, 0.05787414288328541, 0.06446216961429005, 0.06427763435508936, 0.014079327623720371, 0.0062740393707739015, 0.02520471022674634, 0.029527116191363143, 0.04043414362616116, 0.012588342407628173, 0.01783856033017078, 0.02937307314676864, 0.028465494528532993, 0.09211795134169441, 0.02224152810090492, 0.025779151680668997, 0.04773016966458771, 0.029837289870145823, 0.08587062689325503, 0.040552864271786906, 0.08211028431692431, 0.058561415681915904, 0.05982850212603808, 0.05511636425170207, 0.06884715730144132, 0.04862995908385323, 0.04689859271410012, 0.023626741472511523, 0.08492712066659043, 0.05556467507455138, 0.0873243629992489, 0.02415850225295271, 0.032410418329339837, 0.0263403742874582, 0.03561640436190271, 0.03337739749000438, 0.0704767182469368, 0.02890699866017507, 0.05108676092218488, 0.018949738305602825, 0.0339317502033326, 0.018383325453126625, 0.062393739879612005, 0.07015047970438196, 0.029658712859776233, 0.08591040217828366, 0.016220693716839436, 0.0786229984594449, 0.04742483383104686, 0.04559408287487684, 0.043067658965986584, 0.018971351561166586, 0.06354142385985583, 0.029659748993693825, 0.07650210702371213, 0.05367434163007045, 0.0543006299994886, 0.09834415474606138, 0.18519879859541694, 1.7718226150158913, 14.719986492587676, 59.94794853271977, 76.08840373254593, 78.75672940284976, 74.07860479047223, 73.21245916428106, 55.55951449178881, 56.20899231203141, 49.072651632370494, 74.481612636197, 63.37118141112789, 34.82749746691796, 31.936336063569595, 24.378158200171686, 40.14126177757017, 23.310000704180812, 43.61531288393083, 59.982383020462535, 44.422269944221746, 42.68894318611392, 34.58261605231993, 24.64681310038413, 20.411524080461074, 19.155747852017804, 15.878980198214132, 9.39345878939475, 3.3103470648488695, 0.4759825621881793, 0.4579781476528414, 0.3639620296176403, 0.21438998140154347, 0.1183222875659985, 0.04649116417333003, 0.03883645959919499, 0.0660064113476584, 0.14842518394993198, 0.2284180778529375, 0.3176956203195357, 0.06619643179639693, 0.1239971528130193, 0.09846087590220476, 0.10631296303003065, 0.2740553910693815, 0.06838777267764654, 0.06455627585490865, 0.11947194039220772, 0.2726378219742929, 0.5995331163848601, 0.37092230613193206, 0.2966217059762247, 0.03507991298852909, 0.2602188319208161, 0.09150461368863622, 0.12083854165769393, 0.18144610157657057, 0.044505686439093084, 0.0917769349630802, 0.1412356939286955, 0.23364967696609037, 0.09342770888319901, 0.02436177985322091, 0.07449774522214167, 0.09825896576888139, 0.24263490772535726, 0.16971790832617592, 1.3333751741916904, 2.308052537902709, 7.097200818600194, 16.653477684144054, 28.63401024572311, 41.41114873270835, 50.61032272154286, 49.19139746696719, 35.43076584416051, 34.61610524885116, 31.544730547935735, 25.79438094169863, 25.234391996937415, 32.19538115685986, 41.55098515172159, 51.79890678774927, 54.02907233084402, 67.73884650199645, 61.18884132754419, 73.49540325903124, 80.25341956846177, 83.05685520172119, 65.89524622886412, 42.28946547354422, 20.648892194994037, 1.945081550267435, 0.4256137826990697, 0.11098670457760174, 0.08926015227071701, 0.033949933300215396, 0.11366198320061931, 0.026819366931674943, 0.04878640572931017, 0.030367273326602676, 0.04841276166600086, 0.027860135681206183, 0.00724312958247479, 0.06506604608148336, 0.019418172343003175, 0.07994567224335286, 0.021615140140056614, 0.012339228809240365, 0.045331521560588194, 0.09572960391280153, 0.029551209656581767, 0.10748577469419088, 0.06607486896457211, 0.042834170688424385, 0.05185254241129564, 0.08814757043916373, 0.01936341812383504, 0.02501078081437417, 0.034268537776604775, 0.018717222959704457, 0.03966789482341659, 0.10273701781707426, 0.03761281034037952, 0.019148928826794993, 0.06112114143287463, 0.012220505290784904, 0.027865013746064038, 0.039216975471185106, 0.0477493180322551, 0.057256710490271936, 0.014110275660641493, 0.07840477831421361, 0.02427614654504484, 0.029710940904014056, 0.01719092109030293, 0.044224566644838745, 0.14651797741891878, 0.22497739312389206, 0.26864086548166893, 0.14040572959328854, 0.19674556690358347, 0.15904906145747633, 0.2835037679441514, 0.16913698385319403, 0.17263347042664406, 0.23530159235721637, 0.11923518858008808, 0.12757263837322114, 0.15548446966755777, 0.19303894241250333, 0.18076799118951445, 0.19541032161683808, 0.1273519744075114, 0.2222205950848518, 0.2266568110714997, 0.11496700631875185, 0.10860826970348436, 0.18693849234090698, 0.058917056679004626, 0.13163835891792852, 0.13773465679297525, 0.11680243041125998, 0.1844290794143754, 0.1328161578144758, 0.1566626362863087, 0.1946484778196581, 0.18383362991434915, 0.16407210079412307, 0.12862723500978562, 0.20756698784328279, 0.13749336974034387, 0.13539366063571748, 0.16720049744171483, 0.1457156075705444, 0.12554697932735567, 0.30955805052672664, 3.127544757819945, 20.328385522288663, 71.88422695282968, 85.1906402649418, 87.59848917684248, 83.99638052909606, 83.01966328774729, 63.087084139547045, 60.95436596101331, 57.199873232072406, 83.0556235774871, 65.4055618470715, 33.61589301017023, 36.26691318327381, 25.93096571583902, 60.94609368231989, 27.193961066584436, 60.38088406285932, 94.70434127315399, 64.89057817766744, 72.16771233466365, 53.671815010809134, 36.00022731288787, 28.933746007180986, 30.759948607414003, 24.800317018262803, 14.442083624101455, 4.741600328876126, 1.0454713649326757, 0.8712798248856299, 0.7731114183702777, 0.4090893274593738, 0.2459910469910791, 0.1824498452967213, 0.11067283069414478, 0.13916912578767346, 0.37381830234681407, 0.46209902652809703, 0.5257949473396425, 0.24351414683605396, 0.2359812808853965, 0.1650247924149998, 0.2055943727252945, 0.4155582045355151, 0.20318995980966478, 0.2675652473924622, 0.15986610955047995, 0.353312028511878, 0.6011725445428203, 0.35734928122931914, 0.2976393771748389, 0.22982161221725328, 0.30048110372116493, 0.2015288820069644, 0.2597546132822191, 0.3233533022144149, 0.1406561637357358, 0.2291159073431646, 0.21447100286041537, 0.426902832883981, 0.1318873068498027, 0.16288160015979122, 0.36743280628035146, 0.3798730935781233, 0.49704189021741196, 0.5051594497936388, 2.1700262927239944, 4.441410062774535, 10.701776146888735, 32.54440542190306, 51.923391049908055, 50.59289955323743, 63.614458576325454, 68.58785921527495, 61.10419265685543, 49.398639817391675, 38.89248109632923, 27.174584557933194, 29.579058270300592, 33.212030087747884, 47.31490419756982, 55.707321166992195, 61.91123600929015, 75.52064065010318, 73.60942655994047, 83.4658250501079, 89.43811216662007, 92.29133052210655, 76.94384128816667, 51.02892198870259, 24.98591180770628, 2.6295206815965715, 0.6584175147356526, 0.17776210732277364, 0.14499476479907192, 0.22098181558953178, 0.13374013645995048, 0.10815304493711841, 0.1285584862794607, 0.09961222944360587, 0.10288165521717842, 0.07384145301916907, 0.12070348801752254, 0.1598717939228781, 0.11243873230752446, 0.2134835614912933, 0.1517658175960664, 0.10371118288246856, 0.12498794198637048, 0.15707135951567083, 0.10872698268823086, 0.24685286526237768, 0.1508575131095225, 0.1269960039926152, 0.24307390674948695, 0.22817147415011163, 0.17327814873668457, 0.0846448019447346, 0.2895302445657792, 0.1980715272046866, 0.16526240224559463, 0.20134598617592167, 0.09474250728324538, 0.12618342985308942, 0.12118739511577353, 0.14767011237000266, 0.11630458817366632, 0.21736324524446843, 0.15356437753765814, 0.10553128521649108, 0.17886626984803908, 0.15607173734855267, 0.09994874122522532, 0.28282538176544253, 0.09420926412267071, 0.18703937079877625], [0.028027140933479515, 0.005656550478776016, 0.014797817547655395, 0.09082353854131314, 0.025663031903546185, 0.04753909967539292, 0.052561426550270095, 0.026672871768354412, 0.08398994998705965, 0.01706762498454942, 0.06927275744777533, 0.1099221871024178, 0.021678321326391834, 0.043250631405821735, 0.014107305154715095, 0.06449102048551844, 0.059460875683373986, 0.04620861945553653, 0.03302603509397276, 0.04805522460129954, 0.01310473163386867, 0.03218598521104263, 0.032915327728034995, 0.09655892473435211, 0.037691299878661676, 0.03780313339384814, 0.033546725903908094, 0.09310452703146205, 0.022656958430044116, 0.029028942620742227, 0.011578610752739254, 0.05383452678459787, 0.042505913504189065, 0.048370473612580574, 0.0346404466507656, 0.11502218763193778, 0.0542384198295974, 0.03643100097354862, 0.2022228504140531, 3.282032700315599, 16.65907294519486, 55.008319500953924, 70.8495763040358, 75.20526639876827, 65.21656636268862, 50.981728030789284, 46.641017467744895, 46.87062517289193, 24.661792632072206, 29.158123231703236, 37.76539194968439, 21.390016194312803, 21.86035348523048, 22.916029999333045, 39.73670459562732, 76.4313522461922, 49.46134674933649, 38.32223907593758, 40.54862345418623, 30.790529366462465, 17.922374240813717, 8.627918035753313, 9.112958331261913, 5.416085220152333, 1.4643197025983565, 0.6986957824518604, 0.5310281245939193, 0.11906612063607863, 0.06657181487929437, 0.037258923684637395, 0.05893717414789623, 0.06803997642090244, 0.1038962850467332, 0.17341117224385663, 0.03177499053098502, 0.01891290479820342, 0.052057133852353984, 0.04584253284960024, 0.18902856405944596, 0.1675450684682977, 0.08579836948023689, 0.10112727556617991, 0.08807165112586753, 0.11974262223849375, 0.32022138156237145, 0.18545807339251044, 0.11687857955093346, 0.07673681338107394, 0.08346891060711877, 0.3285062853847781, 0.06753471845220174, 0.11458455990519255, 0.18837141383799816, 0.04696438817547695, 0.12702655557903553, 0.08540056300379577, 0.11443878103408123, 0.05228895205824126, 0.05607172951943452, 0.08842628854777544, 0.26138938362559966, 0.1456128292146229, 0.0747489760960302, 0.0474464604931493, 0.052121864451516065, 0.08743507036518666, 0.0345034969429816, 0.09074855385528457, 0.25457280988414444, 0.8896929626503299, 4.236779520588537, 6.5331365312299425, 17.449508982319987, 37.470563073312086, 58.306789628921024, 56.988449635044226, 48.88141647461922, 33.9530050370001, 23.42319638498368, 17.152818941300918, 22.721345117015225, 16.621214228291667, 26.1140521495573, 47.79804998828519, 53.34884312845046, 55.114556897071104, 57.94668466814103, 64.19221193559709, 70.10325908660889, 62.85297355344219, 51.18329471157443, 19.622288288608676, 2.6991393200812803, 0.4761508563833852, 0.17831926774834433, 0.17767858841726858, 0.0386006462447826, 0.049075148098411105, 0.027177162551050706, 0.12820433149294508, 0.012150752985279166, 0.016188121573518843, 0.07912551383337668, 0.0786406644469788, 0.06279140846022675, 0.04518945055503038, 0.04391145118842683, 0.05206507052324953, 0.06079864139939028, 0.03785309764826971, 0.05890351607494297, 0.012179990730909331, 0.0832969774942725, 0.08972791789640343, 0.04734769643795106, 0.06480786679012161, 0.03629148870165791, 0.04340816589613115, 0.043014879338443286, 0.11010517486401143, 0.09695987983216202, 0.023311699304970044, 0.01736010586272084, 0.010874988680194703, 0.01105384818548637, 0.03539041225467959, 0.017973202198082884, 0.052151339684402755, 0.01946398631609496, 0.021651395251073187, 0.035559629585834286, 0.027638111909430836, 0.029099786601540063, 0.06792759898328973, 0.04109212888344642, 0.019535276543108687, 0.028270268512348977, 0.01827200330162962, 0.02683861106033287, 0.04338815950998857, 0.044890998021489194, 0.08104535315426127, 0.08588090779319887, 0.0535508597479953, 0.049639019454198505, 0.018072741917304454, 0.02326569380989719, 0.021006728432351546, 0.023698324728156292, 0.08892296633172421, 0.029724759214948264, 0.0291797221307793, 0.03932339657518653, 0.03470390937441299, 0.023620622345216336, 0.015796642983332276, 0.045785007307366024, 0.07229755602536664, 0.054005310765557715, 0.08687815508775174, 0.08890438103868116, 0.043411789492013, 0.036049374274068305, 0.03982242624906283, 0.012262253252218568, 0.01003910344274294, 0.04577943018727726, 0.059834684455587026, 0.07386156282718144, 0.02582198557173533, 0.06189179907162344, 0.022705488184827472, 0.04799077745466944, 0.022795932525168025, 0.2365828437670585, 5.448808573907422, 27.182958818251088, 67.96941911020588, 81.08204380158456, 82.89822670721239, 73.88906801900556, 59.79929462555916, 57.50583771736392, 56.17298495384955, 34.03801456574471, 38.44495042677849, 39.9101008138349, 31.658681284996774, 26.039597718946396, 29.67158502148044, 31.56582505472245, 62.34622293902982, 31.13137745088147, 29.62548148247504, 33.95970836762459, 23.263261741207494, 12.932553579730373, 6.9652508151146675, 5.370878923323847, 3.7047514367488126, 1.3932279689658074, 0.6233626183482909, 0.296151879574022, 0.08393521300486981, 0.15273176253803317, 0.08409283559529052, 0.14216154182870544, 0.25216317224887114, 0.2546660274627709, 0.3988807768590989, 0.10853972015601974, 0.13555156667867016, 0.5973533817356633, 0.12302730082263871, 0.44980432657945546, 0.38318155153143796, 0.14179032626411608, 0.1266198318391558, 0.23176833356340087, 0.19410642464795422, 0.3385395857114946, 0.20633907147472907, 0.25716995519976465, 0.5211474289817195, 1.0935667325412075, 0.9305524765964478, 0.250449096483569, 0.500706579055517, 0.36018950624331353, 0.3585306500955936, 0.25200385660413777, 0.029664912426303473, 0.5312625474987492, 0.18151520270734064, 0.24531247695126843, 0.2799638901506701, 0.5006465790492873, 0.8693370259096547, 0.20504182414902797, 0.07684410399486942, 0.06099053110266405, 0.16117164594752176, 0.04708093696183736, 0.050665190398332574, 0.2639073307716078, 0.7732927667037134, 2.9943126295843436, 5.935260922678056, 13.064616841654624, 28.648874067491104, 49.66824393118582, 52.340888131049375, 47.384687085305494, 33.4401669040803, 26.416278616074596, 24.537049493482037, 29.916642942736228, 25.499291227709865, 34.641651645783455, 55.34556881073983, 63.3322322753168, 64.72777235892512, 66.89326194024855, 70.5621999309909, 77.76746057694959, 72.72650887889247, 60.8126546490577, 26.800998410870953, 4.143829153430078, 0.6770688752012869, 0.1373043605276654, 0.12941970700217834, 0.057026669608368996, 0.044330125899925354, 0.04554905988756688, 0.06402356895588099, 0.03897325225895451, 0.05239227050614934, 0.04653586923415142, 0.060760494051200736, 0.055564721039826834, 0.017621462503748558, 0.024757353183362755, 0.027770940064182206, 0.0489994969158884, 0.06910433301762228, 0.06368293562122891, 0.03861483036270065, 0.025447173224341486, 0.035856040495057265, 0.09403545409440996, 0.08376544025997001, 0.04451148572467989, 0.04431412615362675, 0.03896025940775871, 0.03939235214925101, 0.07206485681836644, 0.08813284622925906, 0.03293963569787241, 0.06227667015346308, 0.06486125545756471, 0.03659318944799804, 0.02619134528832811, 0.06459250415284788, 0.043666575013870196, 0.017040840635496764, 0.027602293468531103, 0.0556768763119415, 0.0606454084927757, 0.01399523702510182, 0.034094283417347944, 0.022126270172696923, 0.1101934205320093, 0.16330670234897446, 0.10903202357792086, 0.10424513084393355, 0.16200430691242218, 0.19894765599841074, 0.15151785025673528, 0.1270193543525473, 0.17930920656409957, 0.1495711442323462, 0.10924540970834995, 0.16740744843357996, 0.11793777271504365, 0.22712600928160454, 0.1420428594874759, 0.14323195052002707, 0.07858634115226808, 0.1668425658417325, 0.1511172782028875, 0.17093347535739023, 0.1578797048498546, 0.15183239063668638, 0.1169151679101971, 0.22281370035582976, 0.13381191889845556, 0.1911245040114849, 0.18526362495556956, 0.24995320777018226, 0.16258645712608294, 0.10074167287037258, 0.15115461732831695, 0.26127918953857115, 0.2087639236161786, 0.29238113352367956, 0.20778282545506957, 0.25614028706425623, 0.07538176472148589, 0.13385760838225966, 0.2654026731127693, 7.127183906493649, 33.571440789007376, 81.19509435469105, 90.62301312723469, 94.0796567547706, 83.0095749516641, 71.27028972871842, 65.33395113483553, 65.94012598837575, 38.30370979924356, 43.362527893435576, 47.871233570960264, 30.039258195507912, 32.175471205865186, 34.00927143712198, 54.878402756106475, 91.2098075497535, 66.1192370999244, 51.595100433595725, 52.1499942195031, 37.99516831674884, 22.86760049481546, 11.089983909360825, 12.801754301594151, 6.9781372720195405, 2.225169178939635, 1.2648839719833866, 0.8455142042329236, 0.23116389019114358, 0.2380911023506234, 0.2458635086734449, 0.21259342861031333, 0.26293066059870107, 0.30907320880120803, 0.4621218865917575, 0.21741965995921245, 0.16160466948584204, 0.3375614752932903, 0.18641384468684274, 0.3831659539812996, 0.5152828114167337, 0.4411104850230679, 0.2814367095068578, 0.31529347502416183, 0.252370935293936, 1.246417330638055, 0.6611441135887177, 1.193747253667924, 0.9002780914306642, 1.1899111756393987, 0.6191553247551764, 0.21851740266767242, 0.3312982775030598, 0.5475173397890983, 0.24742044448371858, 0.2853326036805107, 0.126723644413775, 0.4370460515060733, 0.4037016149490111, 0.3599277493213454, 0.3814961580980209, 1.3114353966328407, 0.9402328861817237, 0.18164776656175816, 0.32542884890590945, 0.215725640375768, 0.2503024978983787, 0.19817240566255587, 0.3690650332118235, 0.8280799429743522, 1.4229675021863755, 5.676854195133333, 9.227469967257592, 22.753704670936834, 47.191569189871515, 73.4555519780805, 71.41470355372276, 64.84580824452063, 44.75027030514133, 35.10365978364022, 28.344496180934293, 33.9654742517779, 28.24636632396329, 39.83285757803148, 65.95157146453857, 73.50098871415662, 74.78776147288661, 76.9758713629938, 82.08311111696305, 86.76093762920749, 84.07573007768201, 74.01350913509246, 36.47847014088785, 6.721350973652256, 1.1878216555041652, 0.34623518405902776, 0.24352462691885812, 0.17187832223792232, 0.2181361360295165, 0.1937507300247108, 0.1955827986521106, 0.09999092202633621, 0.14144940181605278, 0.34926496986900607, 0.25562495503935123, 0.18693121450562633, 0.08813111487055018, 0.1787463617661307, 0.19332974938856018, 0.17981741397130876, 0.16210756024285672, 0.0812912826997138, 0.15507481181092803, 0.1355668577936388, 0.16742721350202638, 0.1975008376663731, 0.1950071908293232, 0.14462613861166662, 0.13556019282869755, 0.1863459692967515, 0.116367744462144, 0.1924530383680136, 0.15684697236264908, 0.13517316520935105, 0.1137422155889292, 0.1282657947271101, 0.15481074130342853, 0.1251559986943199, 0.15155517406040622, 0.13387060123345546, 0.17599126444228236, 0.10716771797066736, 0.13228674509352253, 0.2475954496091412, 0.2203451045939038, 0.15008174183387912, 0.12479625146595702], [0.02728759795577536, 0.042499160439136534, 0.06979462420267445, 0.029389789185276436, 0.014971202397118173, 0.030823256520013657, 0.0937500556990985, 0.05643345708508165, 0.03552221768205205, 0.03978402992229789, 0.10329437742550528, 0.026655508385550593, 0.038710066583007574, 0.015969152577341567, 0.037347357044176716, 0.05204403374884879, 0.01133822672624862, 0.034576788574697516, 0.040720721796876004, 0.025062959062896913, 0.06445168187060664, 0.039123424644311594, 0.05248484074047977, 0.03403348284923742, 0.03169747009392708, 0.04399956662147757, 0.02529641669694214, 0.027269359317518053, 0.028831807130406943, 0.03312337039519222, 0.02956220110307538, 0.01822505934884952, 0.01825111974481373, 0.06657809680027348, 0.04034686705938751, 0.04697806667536498, 0.0935543125735656, 0.07278428998805823, 6.802298888083428, 32.96470895890267, 65.51980480071038, 69.4627752611714, 68.35215614688012, 62.37138102131506, 50.443457249672186, 39.40135371300482, 26.941493788073142, 29.194018802335187, 24.35964265177327, 25.17744702677573, 28.207446605928485, 19.249310108923144, 37.71470708231772, 45.21153711503552, 74.31115427324849, 48.858894225089784, 38.30597692920316, 27.165616058534194, 9.813392643005619, 4.696484736857876, 2.934413134090362, 1.1210773789113568, 0.17694410928074392, 0.05589632985873088, 0.011940935866967326, 0.04741632642464773, 0.011951514583591734, 0.07145758658166855, 0.05045906295098605, 0.08416608892261021, 0.04914321884092304, 0.10803997035949461, 0.2431937382226029, 0.04959843211597012, 0.12584363921515404, 0.14317950414073083, 0.2536617168375562, 0.44216076092373946, 0.4465397194989266, 0.0840840638885575, 0.19267414666471944, 0.12335727787426404, 0.12276668537167773, 0.06414117111313729, 0.18651999382963105, 0.1337006216448161, 0.2312333896876343, 0.4030648733098661, 1.1066955183782885, 0.7802461484266866, 0.39562055180149697, 0.33430220018471446, 0.4838300298058218, 0.18953856411239794, 0.3696123264249294, 0.21389556357697134, 0.1516285652835523, 0.29120043881477853, 0.1742476330048615, 0.4596673408823629, 0.9405170741581148, 0.4497712009376096, 0.16128901061752152, 0.1889134057226681, 0.10739300910743976, 0.06862011182332231, 0.11789925381421082, 0.03063602654653932, 0.10138769183428058, 0.028664187092574376, 0.1578809765558089, 0.36750068167044275, 3.729382940838414, 6.316149052112333, 13.026020719159035, 30.408125731252856, 46.98580949537216, 59.04334014461887, 43.01622183092179, 35.04671481347854, 27.845825649076893, 19.296221656184045, 26.405243027594786, 31.466383164928807, 36.94854267181889, 43.930608687862275, 41.229892084675456, 46.6437082136831, 51.16739734526604, 61.38523832444222, 67.57282041734265, 49.109341482962336, 26.90254072989187, 9.556295987098448, 0.9545760745963744, 0.09386080903031173, 0.09674628685799339, 0.03579440489110928, 0.07259291356369373, 0.06365585058266598, 0.04251139486328729, 0.024228800396104495, 0.024229401775125056, 0.04812801061498542, 0.08357604034245016, 0.08335972009527107, 0.005506767840650414, 0.007921940461176658, 0.014928686432540418, 0.041314497394787694, 0.06749816073645508, 0.03537495260036761, 0.013087472630544536, 0.04183513457856832, 0.08654803247942079, 0.030583352256085605, 0.014520541599561131, 0.02394259377803293, 0.022638275460790724, 0.09077941187687459, 0.05134729210347418, 0.03943733683216476, 0.1203627550914403, 0.048496567854477514, 0.018567376161715197, 0.04490237825760438, 0.01642276281340709, 0.027887779963953842, 0.027434093119095893, 0.03486966398814994, 0.05773376876247987, 0.022011387627571825, 0.01556958601389441, 0.06682260908306607, 0.010867661049198962, 0.03655472417331992, 0.03458701967892628, 0.05578493684410088, 0.053959265050868836, 0.017773655446005926, 0.027255579310980056, 0.04438986160582112, 0.014528744486010364, 0.016732459602456902, 0.10019481632738345, 0.06746845950763072, 0.0402354548925594, 0.04659878037449333, 0.027945516180367242, 0.01182018030029271, 0.03607486968018836, 0.0566956966424421, 0.02486288754059182, 0.029322997809598045, 0.017743193874916723, 0.021156776328420928, 0.05967659072109288, 0.07396504598399324, 0.010532384584357422, 0.025782281149839683, 0.01608224056150404, 0.06221397351773997, 0.03147584660309217, 0.04022752971298272, 0.034108911866262075, 0.015725721436132108, 0.010977335154048858, 0.03261546942315275, 0.07267158313263809, 0.09340032123990598, 0.013893986056979387, 0.042100794718510685, 0.0783319156917353, 0.2908995501216381, 11.036609276648491, 42.9264073987161, 77.76586809465962, 79.40476771323912, 77.92466917345601, 70.54608683432303, 59.78095362263342, 51.271171492915, 39.313829944979766, 46.740539766127064, 29.70778261461566, 27.05720959171172, 35.78940776086623, 30.1694671569332, 36.096423441363925, 30.13022776572935, 53.996728466403106, 43.6461897819273, 29.82239034868056, 23.159693517992576, 9.302811834119982, 4.006916125935893, 1.886325303104616, 0.5569346441376595, 0.14761389683811896, 0.01284236854483043, 0.07732152232840177, 0.1302552024923986, 0.05086115951980314, 0.16253250921445508, 0.1047272912617172, 0.34207989251421345, 0.7804914804235582, 0.724618849494765, 0.4322827006539991, 0.4152298286076515, 0.7486066558668691, 0.9503832447432703, 2.1346413656588523, 3.816375472853261, 1.7449310902626285, 0.6901641370308015, 0.2868001829952963, 0.45152915821921447, 0.33331082112366156, 0.3834453309255262, 0.659326340161985, 0.10739300910743976, 0.1891377315886559, 0.8953116966351387, 2.308372456219889, 2.240136698369057, 3.0535916551466915, 2.0332560640188957, 2.4152487083788845, 2.47288205450581, 1.9864184289209306, 2.0924660803810244, 1.0774652804097822, 1.4151445800258269, 0.7509323149438828, 2.5700913802269967, 2.673767223473518, 2.834582684501525, 1.278952655773009, 0.34851634874939924, 0.3456239684695198, 0.2713788943665643, 0.516506836058632, 0.06640906716066022, 0.18315106089557373, 0.01699029415425274, 0.044806065683763836, 0.12155915460278913, 2.23899259201942, 4.298427412586828, 10.941200563984534, 25.051054531528106, 43.332294264147365, 44.11956494854343, 37.306047101174634, 30.18811018236222, 35.98445546242499, 25.025633650441325, 34.82310441232497, 41.896361612504535, 48.36478540974279, 52.353239674722, 48.64365023951377, 59.13603751890121, 61.76884220492456, 68.05848829207882, 79.57922689376339, 58.005316257476814, 33.119089526514855, 11.80881021484252, 1.2213173484609974, 0.06703465455962766, 0.1532940863962135, 0.058261871473082615, 0.043586403912594246, 0.05340745957988886, 0.0571344658401945, 0.012659586669366448, 0.026302431867788398, 0.03934265985604256, 0.0661333904211079, 0.032829464593481635, 0.04486170281926471, 0.024982833926896417, 0.027211605864126357, 0.05578964828483521, 0.06197100107167518, 0.03147975173628619, 0.10063816673092305, 0.019363439191252958, 0.05479681748716582, 0.044669613933130625, 0.05222529398217317, 0.0352752271048244, 0.02152066043157491, 0.10391327687689375, 0.09037235105830817, 0.013781870046870844, 0.03472747806940348, 0.029535884067656535, 0.030089125953494545, 0.03144947977195824, 0.01484872025978421, 0.02567479709884332, 0.033486538206137, 0.04837271441975909, 0.035699318057947585, 0.04132462507714668, 0.011090031475760044, 0.04964775668697492, 0.0383303436120191, 0.039888378758464134, 0.13410856346449546, 0.1380086557999734, 0.1743534757124801, 0.288855413035039, 0.2011799749227301, 0.0979565755434094, 0.21111552243030843, 0.14535222142454118, 0.2647387200305539, 0.2622045318205511, 0.15477738583520537, 0.10223377465961442, 0.10171494927377471, 0.08695733027472612, 0.16688349025864757, 0.1110146897694757, 0.09317498413785812, 0.13616089769188436, 0.1869238753833117, 0.13215790442641706, 0.11075972038651667, 0.1408399482287707, 0.14409960638130867, 0.10704584870367281, 0.11537749921121906, 0.1113597664140886, 0.13726274663161847, 0.08082479644086092, 0.17054612598111554, 0.18956071937516814, 0.10891848934754249, 0.0879432701115166, 0.11706948100078492, 0.16744918490369476, 0.12144182057630633, 0.25134157359359727, 0.1990585395645711, 0.5153140678040443, 13.568599243317882, 53.98748343990695, 89.9543196155179, 87.67192379120858, 85.68370572982296, 80.41054971756475, 68.75479528980871, 58.32120826167446, 42.48347374700731, 42.604961318354455, 37.09995008284046, 37.77377405474263, 40.189475551728286, 28.69613470569734, 53.3438224946299, 62.337891824783824, 88.91183207111975, 59.106898230891076, 49.28877815123528, 33.463406947351274, 13.983660532582192, 6.279412623374693, 4.307990641363205, 1.5427384237127921, 0.5059328002314414, 0.15427049609922594, 0.15688991925168425, 0.4673627860123112, 0.18793802257747422, 0.2917721242673936, 0.1739054521726024, 0.3439566240675988, 0.7149720864911234, 0.8753654024293347, 0.48725867163269754, 0.2258923778971357, 0.41259889881457057, 0.5602619172103944, 1.264592000553685, 3.016535798388143, 1.2690344524960364, 0.4129537200975803, 0.4522818549265785, 0.7476089029542862, 0.4929790808068168, 0.6418200053514973, 0.7224516786875264, 0.35854597185407916, 0.7920220229894884, 1.709928103993016, 4.078767818789329, 3.556699858557794, 2.477135619809551, 0.9477023047304923, 1.7212829979196673, 1.8643260771228423, 1.4729299179969297, 1.8882890622461996, 0.605457243659804, 1.0075109115531369, 0.674536801393955, 2.5398226947553697, 3.973071219459657, 5.8878953610697105, 1.3115291657947725, 0.2214433682421523, 0.5803514392145219, 0.19639367207644448, 0.4259266223638289, 0.08200028941275612, 0.2809823887242425, 0.10745542229063089, 0.2826103868503725, 0.6061034541456931, 5.064599667826007, 8.399368389960259, 16.547189297214633, 37.24360296803136, 61.242479739650605, 76.289103569523, 57.8627694806745, 47.36391029050274, 41.94015487547844, 31.445776993228545, 39.05884450481784, 44.734066993959495, 52.10018011831468, 57.4317676790299, 57.75557894860545, 62.95575141906739, 69.25128890622047, 76.90220140641736, 88.55447276946038, 69.25472490249142, 43.035884672595614, 16.274780688747285, 2.079073392575787, 0.25897599215949735, 0.23097259803645073, 0.09355369970322618, 0.1807006520609702, 0.18687476914736534, 0.16471702425229937, 0.17217450715120763, 0.15191633855142903, 0.1421432629708321, 0.14964252830513064, 0.1361390335425254, 0.09056630153809825, 0.0982943130657077, 0.14227115368891147, 0.1365183849608706, 0.1813722813441869, 0.13734995808091857, 0.20619624204212622, 0.13159424757524846, 0.22543126957551127, 0.1787952228539413, 0.11195916126692489, 0.12173545441680378, 0.1065060095260701, 0.188130954160325, 0.17809848120856672, 0.15299606287190992, 0.21794135051388897, 0.11295194992975843, 0.08409154856757772, 0.1184240163814637, 0.0553503772994924, 0.11456857165021282, 0.09422355932333777, 0.20480470461470468, 0.18443997318465866, 0.10738321850376745, 0.12969928312926524, 0.2735187005131476, 0.1053434404574575, 0.07514612373685645], [0.044683330737414866, 0.04021078686139757, 0.021918888256374388, 0.0332974179107095, 0.07361495912435555, 0.0428652968407879, 0.018225172346818353, 0.03658026171427581, 0.01700439591771893, 0.022976420924908692, 0.040910964411112576, 0.023745506168192914, 0.01828470503941419, 0.08034183163075678, 0.10573555490062123, 0.01888957933612889, 0.02314127921577423, 0.042002689498927326, 0.03191940193515151, 0.03428839477560213, 0.01372114034189332, 0.05904855567120737, 0.04373582936222515, 0.016081733028254202, 0.009567171256358345, 0.06531933007100899, 0.027074501023537693, 0.017717809551545692, 0.03477740018898922, 0.05279912448097622, 0.06284551725031869, 0.09762851371159477, 0.0647764725069846, 0.03386550275008044, 0.045244202858978705, 0.03156913696007142, 0.566842183470726, 10.73675976645562, 47.59590279671454, 66.67446428729643, 70.45155771317022, 63.40819681844404, 49.120233904930856, 53.8618185443263, 38.05319586107808, 25.547340262320738, 18.272151600930002, 18.10127942792831, 25.54247848449215, 24.76829086580584, 13.158792949491932, 40.31121807713663, 52.642643913145996, 65.1128588953326, 36.892629285012525, 14.831161172159257, 4.9654396983885, 0.5320609336899174, 0.19157120988013285, 0.13394399245660152, 0.043839994337289565, 0.045750414607145136, 0.0885725730369168, 0.07746004634687016, 0.019659756254705212, 0.05223788846764834, 0.10604077199053381, 0.11015978161125414, 0.12105196609251923, 0.28825529039867465, 0.3865478031577603, 0.8403143671251113, 0.15370757469246465, 0.8370144280695146, 0.5889704799459827, 0.6014206344562193, 2.927945390824349, 1.7813615741268283, 1.6696201120653462, 0.8841932480854373, 0.04642251120399564, 0.11215980735517318, 0.3288320872572161, 0.42412049347354525, 0.24775150171931715, 0.2690349411099188, 0.19917621066974056, 1.010623925155209, 1.6148352647019972, 1.5398842865420928, 2.0679703883586393, 4.1378249852888045, 1.755836627656414, 1.142408698797226, 1.4095325263277179, 0.8929296534868979, 2.56913848942326, 0.31398993045572315, 0.6178831285045994, 0.705198459327221, 1.3196829153645424, 1.743828536522004, 0.8625142468560127, 0.1806249472522928, 0.06409998239588834, 0.2180543791262373, 0.2805571179957159, 0.1434159035524053, 0.1298918163463954, 0.21274140615376735, 0.16078235070791938, 0.047841290718004595, 0.03847431068518951, 0.044852406342303565, 1.4611468728511565, 4.331728825646063, 11.462118779459308, 25.37478147014495, 45.82040271451397, 50.95969607753139, 31.879526415178855, 37.44804866852299, 31.994659746846846, 31.2902432487857, 29.363218084458385, 41.200121295067575, 49.700772147024836, 21.60381674766541, 44.52639318281605, 53.865854663233605, 67.69322933689241, 63.53969820084111, 56.973172003223056, 29.84513617330982, 11.894771898946455, 4.477211006226079, 1.080814003944397, 0.005749002448283137, 0.061679508446926073, 0.07522973457291242, 0.059931475834380236, 0.0481945300294507, 0.04862392997188915, 0.023049250988650228, 0.02949995645922759, 0.08111850689015082, 0.02626857461197482, 0.007941995206619463, 0.039829072061805956, 0.06499307620669566, 0.02221888637230281, 0.031112910533744483, 0.07287108774987922, 0.015559315647659524, 0.06300159234313235, 0.06551481272664762, 0.02727134923090137, 0.038314665622648694, 0.04196860624717609, 0.06297893912321137, 0.01876399454270159, 0.014751520939171316, 0.06241245540760218, 0.0372023519218689, 0.032031026691378604, 0.07979206395365539, 0.005678440004797472, 0.05195941550717239, 0.06402059270429515, 0.05578309057220336, 0.04039963136517233, 0.10450572331225681, 0.021173695380228664, 0.016349005783277176, 0.10095957125867568, 0.037515697204658104, 0.0026794820516971092, 0.03956568337255909, 0.04619803978130222, 0.020770273479302565, 0.06756390640211683, 0.08176844056335189, 0.018773505524281534, 0.03800197151459513, 0.0467606202789372, 0.015924553811219672, 0.020009709048956152, 0.03751130752085197, 0.05103437582992258, 0.04540350701239321, 0.03499315736154395, 0.0368299450905573, 0.032048763542045514, 0.05274685813234218, 0.02229107675262757, 0.021958123449416413, 0.012396429721716673, 0.057002698717218254, 0.01947275993804778, 0.02550494966037091, 0.06925594947871662, 0.028946329614207632, 0.04778484919018323, 0.016032451549695147, 0.05873833219670962, 0.03457341778783068, 0.030026546146179882, 0.07053148587264362, 0.037773983748329264, 0.028944621238136486, 0.0901256094596559, 0.03876989038901464, 1.7375332549695046, 17.67418234579025, 61.34674026120094, 79.47741785357076, 78.81361161508869, 73.67612254235053, 58.1509264053837, 64.09742786038306, 50.47948029733474, 40.71463777172951, 26.990244926944857, 25.049501272939867, 22.117429548694243, 25.680357640789403, 25.431347931585005, 31.784061808739942, 42.782778047746234, 48.236386622152025, 33.17909002304077, 13.794319879624153, 5.326316875796165, 0.7982472534621916, 0.3038202664784847, 0.03855544705725005, 0.03568645927213854, 0.03167079874284325, 0.17896777649800624, 0.2189255130266951, 0.3256310041873686, 0.3294281036623063, 0.7810129105083404, 1.172652992029344, 1.164176627512901, 1.2477776576434414, 1.628575449989688, 1.9803347102096005, 2.663414617699962, 3.20783592039539, 4.138577099769346, 3.707961896734853, 5.684863675025202, 6.347160291287207, 5.138437305727313, 2.7975888502213264, 0.705762790335763, 0.7658137873776498, 1.34854972122177, 0.6688551256252874, 0.35760181445267897, 0.4006144644752626, 0.33681309932181913, 1.4316213539531155, 2.6210137961372255, 2.7550811440713945, 4.324177282471811, 7.08381720127598, 5.556662967128139, 4.711916812004582, 3.395618166654341, 4.006550855213597, 6.019055006965515, 4.0853206284584545, 4.267624549327358, 2.962437978675289, 4.173190055354949, 4.418069018471626, 2.8956439370109193, 1.6371512220751856, 1.6997873062087645, 0.9765640850509367, 1.2410227233363738, 0.9655332769597731, 0.7256097382595463, 0.5687132153299548, 0.45374983260708474, 0.014443528695753025, 0.04098500297855466, 0.04430456920677135, 0.42800020787023735, 2.8726436486167293, 9.941075598039935, 24.32756943087424, 42.43298107577909, 43.25625127361667, 31.725944049896736, 31.345319209560273, 30.269348352186142, 31.375876434387703, 39.98710478505781, 52.267508429865686, 55.89803857188071, 28.995368403773156, 50.57375054205618, 61.7001340466161, 73.47724268513342, 74.47772948972641, 68.05218112084174, 37.796264925310695, 14.425969546841038, 5.373174490467195, 1.0844432995204003, 0.06185945866989994, 0.09592808963310334, 0.06523017275838122, 0.040505922234226624, 0.05629385288264002, 0.06510906191843172, 0.012390924422370811, 0.08959574474682731, 0.06255021716858591, 0.024498957472162384, 0.04699439966991063, 0.02658219377119695, 0.03150199701438748, 0.04388335874424346, 0.045439850223521074, 0.026549644610514084, 0.009732022843954545, 0.0572214474631173, 0.030402367814413966, 0.013319778259873632, 0.02265921838942074, 0.028486609826945973, 0.0084576576069418, 0.01571944717603225, 0.06087012506360489, 0.08714726645379298, 0.048205312716984944, 0.011888427243027236, 0.05327235614400237, 0.07599769175172814, 0.09155141399993051, 0.1211517030793813, 0.08803833396204057, 0.007522016709234807, 0.011505810374904786, 0.04041979096889977, 0.03327187270887437, 0.05367197824882404, 0.0334415267101459, 0.10951821361818623, 0.1341672917647708, 0.12149294162349356, 0.13242185235984866, 0.1570929938386525, 0.24422962699205647, 0.13252332836629885, 0.16590067606058814, 0.11720787478430618, 0.15758374976294656, 0.11991933573998752, 0.07237676951673723, 0.1568995413160132, 0.19734654755842304, 0.24898527099961237, 0.1053475007234562, 0.15772015937874395, 0.19500760451680232, 0.11599646761052071, 0.18555856880641755, 0.20264911705688124, 0.2240471172356798, 0.12625214027901813, 0.22069836305754803, 0.10636010808089089, 0.1852639007472223, 0.17415208651894526, 0.17298104451789012, 0.13550292009547835, 0.24009054586771997, 0.09032922030817117, 0.15763592035059007, 0.18019878786177407, 0.12072564328029273, 0.19287409561295665, 0.11094728169301826, 1.7163963375553009, 23.573013274900376, 76.64912223815918, 92.20847437458654, 88.90345388843168, 83.72176754859187, 68.28604067525556, 73.38586714959914, 53.90849082700668, 40.480111414386386, 28.052658111818378, 27.748884270268103, 36.77793525880383, 34.27006982987927, 23.978443184206565, 57.1487686710973, 68.42105650132703, 79.36188051777502, 44.17567053148824, 18.95361242755767, 7.48520952078604, 0.7764804892001614, 0.8351494636266463, 0.2641480355974167, 0.16236116598931052, 0.1517141679482114, 0.24440156776578198, 0.24605742084883878, 0.2897897951545254, 0.24853047524248403, 0.5429105160217131, 0.7574205893662669, 0.7606984650896442, 1.0800002347077093, 1.3900526877372497, 2.1936840684183183, 2.1638389989253017, 3.6288035636948006, 5.021056455950584, 4.735910930941182, 4.804680866579856, 5.720350338566688, 7.236541057786635, 2.4877586239768616, 0.4562390974212078, 0.6326757347391498, 2.587690074597636, 1.5199506787523147, 1.5041912082702884, 0.9262035486678925, 1.2413447254127072, 2.4411787621436583, 4.67749213018725, 7.025778380132492, 5.413146874596996, 8.306789667375627, 6.471272418575903, 4.11708741418777, 6.051219422971049, 4.5176864343304795, 7.158347627808971, 3.832831776911213, 4.250470063378734, 4.6002312437180555, 6.6165849566459665, 10.883528974748428, 3.1577448018135565, 2.0152446627616882, 1.1293769916219096, 0.8228860507088324, 0.9302505766672473, 0.5278204838114401, 0.5843177521901747, 0.3779511321936885, 0.5784660661893507, 0.19059999425324703, 0.13285202605109062, 0.20627743204034146, 2.1917866218474606, 5.823568490243727, 15.268333842677457, 33.65219454611502, 58.82486804839104, 68.64154077345326, 45.240331234470496, 50.88883453799833, 45.93933290050876, 45.63758888552266, 44.70070331327377, 55.45118254999961, 65.94930433457898, 34.12707982524749, 59.22753464791083, 74.4501866063764, 84.3356498595207, 84.30798930506553, 78.52285415895524, 46.90851134638633, 18.830497072589015, 6.92034605049318, 1.6765171097170923, 0.21567641156575373, 0.30517636467852904, 0.22777293989014244, 0.13606101514831667, 0.13468072389162358, 0.1528149750083685, 0.11191326493938124, 0.23768345164435528, 0.10062277602452425, 0.13079900234456987, 0.09807377167406583, 0.15291370842004978, 0.16263718746842878, 0.12763354236320143, 0.13292141829527196, 0.13841129629121673, 0.11312605107143042, 0.15149299836447164, 0.1836271079317216, 0.12046114376355564, 0.13175914034007058, 0.13891732800872097, 0.13614416633161808, 0.10898795820051625, 0.1359655605929513, 0.22291634081592485, 0.137224396270129, 0.10239793964090849, 0.15462810594228008, 0.15584972506809622, 0.13114472250303916, 0.13117996254755607, 0.15646041971781563, 0.12892723504093387, 0.21076865313995272, 0.15422704359216077, 0.1510179625643838, 0.25228514876817504, 0.1125461761389048], [0.04373362685944285, 0.06867703215609636, 0.02839444753443522, 0.04441387080136807, 0.01690835722031132, 0.051876099614967267, 0.039518109312461275, 0.02460713866316984, 0.06337335183014793, 0.04613549253272434, 0.021529412986109817, 0.007428040224758368, 0.09501869730170696, 0.07159247934337586, 0.04181782482191921, 0.040109035063294635, 0.029119639770097794, 0.012443683940106103, 0.041827960165157434, 0.03938769816511101, 0.01696178227693083, 0.05236792423191571, 0.055976838038693515, 0.031591732723398075, 0.04188641267378004, 0.01374353692235966, 0.06061091538398497, 0.03353995368665746, 0.016651679461281148, 0.0326610976199229, 0.051646468590103814, 0.025001026599878268, 0.10734076957188307, 0.04120353338939529, 0.04130976680185526, 1.4816720230925469, 23.9674723148346, 65.42132585279404, 73.4289739977929, 70.92368556607154, 67.04526162916615, 53.84114765351819, 52.21753743387038, 42.68013354270689, 23.607116322363577, 15.229548465821052, 23.43789350601935, 25.70846534544422, 25.183095239823867, 19.94253020132742, 31.360408567613174, 57.52723816902407, 39.33894095882293, 15.57214592733691, 5.158467869604788, 1.118867858763664, 0.354229801845166, 0.2705889657860802, 0.062392081299255935, 0.048896331685565175, 0.06983439948770308, 0.030856826492855628, 0.10373458686855533, 0.04049476033316986, 0.14962316160240482, 0.25399315711711684, 0.7997820646532121, 0.825625948848263, 1.1274035491289631, 1.4207164294296697, 1.796952382691445, 1.3104497785529783, 2.4307143688201904, 3.2418806226022783, 3.506561916682028, 3.9956152871731794, 7.935400047609884, 8.59795799178462, 4.011249119235623, 2.456105341834407, 0.6242400035262108, 0.10858134937382515, 0.18895636793346177, 0.198867523201531, 0.5107763451674293, 0.011482275196260983, 0.40187903049011386, 0.7366637128495401, 2.552626781886624, 2.08137852049643, 5.37308378565696, 8.622983694076538, 5.505616261113075, 6.398027548866888, 3.429411837170201, 3.9806507095213863, 3.195672405342902, 3.833698130423023, 2.152332971172948, 2.6992839574813847, 3.1659408394367468, 1.8280692807128354, 2.080444015802876, 0.9733806526468647, 0.7265245698152051, 1.5186213629861034, 0.8705215204146601, 0.689917640580285, 0.4644947979719409, 0.19578734412789348, 0.030273008122739774, 0.13607592321932316, 0.14031215961421692, 0.117370706772612, 0.032426927524108085, 0.14485058705172232, 0.7358233450401215, 4.353306274260245, 10.606429211554989, 27.053848120474047, 52.089436746412716, 64.61387457386141, 53.958485357223026, 82.74696442388719, 61.234599697974424, 42.635822526870236, 49.246459699446156, 26.888047572105165, 31.855682326901345, 40.9268105414606, 53.32998045029179, 56.81632426477248, 65.38354558329429, 60.76456639074511, 42.352125337046964, 16.867813641025176, 5.256403078955989, 1.58027820289135, 0.054351256919964674, 0.01273518518334435, 0.04061528511585728, 0.05069021849081882, 0.058073865835584944, 0.032548283512193354, 0.018846360485880606, 0.0340576222797315, 0.07829858320614985, 0.018540965280525627, 0.0726597700568457, 0.029263972650252046, 0.04851791106404797, 0.07966113186651662, 0.02052082567505779, 0.0846748708957626, 0.0726856178634109, 0.029534631513900338, 0.03490158304151508, 0.014209127815951024, 0.06835769606573928, 0.03087786135203656, 0.045556946762747345, 0.05109695755245705, 0.07503627438939388, 0.09601662641451245, 0.021017848198572477, 0.03830223201563762, 0.01175702784225465, 0.015542649404866802, 0.026534631202418, 0.0169306714463258, 0.028146072253284436, 0.036174101049020406, 0.017615121210955324, 0.024099408145693522, 0.038569661818685076, 0.10128871327446354, 0.050511647226108666, 0.04943998215059119, 0.03510590252136031, 0.059368255653328476, 0.04870197900961484, 0.04062687985659127, 0.06285360330835947, 0.02852257190933151, 0.09757798255210924, 0.06537375295714987, 0.036999219878306316, 0.056953634616107716, 0.04998699191116518, 0.06137956970281178, 0.02183815025003447, 0.05280376697379736, 0.08285620880703773, 0.05656405209353375, 0.009724422294135776, 0.05515756062983025, 0.08142603756559473, 0.024723534231945395, 0.015581117552374641, 0.003223749696307125, 0.03447032916629988, 0.051018257339995716, 0.030413975961686626, 0.05908229418339268, 0.021020738265266823, 0.053120402604221344, 0.026396488312691934, 0.005325375457159094, 0.02692839464983873, 0.04062157469771562, 0.009332074194155153, 2.269970245899693, 34.366183588581706, 78.34043256698116, 82.48285555070447, 76.88313868737991, 77.06512097389468, 63.9469265168713, 63.13857701516921, 56.78453737689603, 36.947161997518236, 22.82383861080293, 36.02720929730323, 24.50209725287653, 26.323026226412868, 27.064362033720943, 32.11011471286897, 47.247659083335634, 35.770309740497225, 16.184209239098333, 4.628400235406814, 1.0331801277014518, 0.25383397936820984, 0.2848675576669555, 0.10367537593288768, 0.08240019497010978, 0.09157757590254469, 0.5161238533835257, 0.6181482562134343, 0.46752774006416725, 1.2528105488707943, 1.2486950019674918, 2.3150664712152174, 3.0448960056228027, 3.3967485447083754, 5.136453076716393, 5.919917100860227, 7.984974884217786, 4.884536891214309, 7.564248221535837, 8.273840777335629, 5.591766218985281, 10.79064921025307, 10.409188905069906, 8.288690870808017, 4.621918028400791, 1.9309608950730295, 0.5562411813486008, 0.23326441134896972, 0.2313387880642568, 0.7701345845576256, 0.3667942873172222, 0.761694195530107, 1.2697859541062386, 2.168122717449742, 3.3903489526241057, 4.637422667395684, 8.776579787654262, 6.893047824982674, 8.811052518506205, 7.612467879249205, 7.843500875657606, 8.00806244534831, 7.5377933056123805, 5.555625990513833, 4.991731835949806, 4.655694048250876, 4.2060776583610044, 2.997039902594782, 3.2336635022394122, 2.5075205054975327, 2.625581886499159, 3.0228606202910027, 3.162699490785599, 2.6974622616844797, 0.9718384870117711, 0.793529132441167, 0.46029881183658883, 0.6202114842111065, 0.3022072836756706, 0.016689238836988807, 0.05663765399085899, 0.5302887578164378, 2.713044612638412, 9.351110919829338, 23.018278344984978, 35.93994440570955, 52.40208495047785, 47.840282147930516, 73.21126676374867, 62.97286864249938, 46.71453445188461, 51.609260189917784, 28.740296671467444, 40.279548860365345, 47.520389326157115, 61.26959116228166, 66.28935029429775, 75.36318102190572, 74.1809315835276, 54.42878930799423, 24.151392252214496, 7.520970750239588, 1.9291659204229235, 0.05321343249130634, 0.11848613079036437, 0.03591500245214951, 0.03908887790936617, 0.052617561642921744, 0.0208739404972162, 0.018629860208039323, 0.049300550317932526, 0.03313733234761223, 0.01669568738209144, 0.06468026718545346, 0.05869536232503672, 0.008573359866145878, 0.0499396400165654, 0.07971146384314184, 0.04086403769531077, 0.04151483704786628, 0.03977253477299406, 0.04936562565666053, 0.021212233433259592, 0.05583033138405412, 0.06209942422086193, 0.03518534583910819, 0.07435213489037368, 0.011121667076593206, 0.012866478289417442, 0.05320279153003808, 0.04889943051121889, 0.0782921863719821, 0.06188227276828501, 0.03717412924273841, 0.007651295482871995, 0.052472093037419745, 0.020905886363658695, 0.0031637788971795914, 0.045807139587498484, 0.08701142374305956, 0.012541478894080126, 0.13045302171620632, 0.1756858405086302, 0.1646665084145723, 0.17540044211331876, 0.1662528160358629, 0.12122972913446928, 0.2467214505398466, 0.1426628238010791, 0.18971177659207777, 0.2582416509187991, 0.0840640000458206, 0.12244125122144339, 0.3005096328354651, 0.1675909418132036, 0.19667778344404316, 0.1320868574323193, 0.18413438071166316, 0.09766174660575005, 0.12269269659995072, 0.1530477125197649, 0.2103423405318491, 0.21309247360594813, 0.1338974755978392, 0.12224038296769704, 0.07928988565841029, 0.10718759029142319, 0.12038126377569092, 0.10279156327728303, 0.10610523062848276, 0.18408864526258362, 0.1637983316135022, 0.05744370106126993, 0.150088238259477, 0.11562306869534716, 0.11239380891164465, 2.7007683294434703, 43.84905084486931, 91.42912295556839, 92.77832415796097, 87.28484861312374, 86.58875342338317, 71.33567563949093, 68.14930685104864, 58.86817493746358, 38.30520029990904, 24.045317634459465, 32.115205949352635, 40.134746720713956, 37.58979920418032, 32.65165871189487, 45.342152041773645, 73.68834464780747, 51.496390065839215, 19.91295749141324, 6.8966137497655815, 2.036961968387327, 0.6086029845380014, 0.9484097409632899, 0.27389457389231653, 0.20995142118584728, 0.2965144536668255, 0.34858888195407006, 0.4161712587360413, 0.35317514392156757, 1.0751226448243665, 1.5192066541602536, 1.9378647568725773, 4.277620709711506, 3.2344381703484446, 6.05362726796058, 7.99925035045993, 8.910668953772515, 8.716612631274808, 8.74358775154237, 10.758562261058438, 10.852563823423079, 17.275595011249667, 18.822742546758345, 14.070096823476977, 11.601206025769635, 3.6632767848430143, 1.540782631885621, 0.5409670428883645, 1.6254818030903417, 1.2751413377061969, 0.6794833391904832, 1.1247941923718299, 4.502866739226926, 7.329045745634264, 7.357550099972756, 14.648596413673895, 21.634877997059977, 15.288795867273885, 17.48194306127487, 14.208112282137717, 10.871499065429935, 14.189954650017524, 11.067045888593121, 9.975323773199513, 9.479964702360093, 7.44910067127597, 7.916073549178339, 7.065767434335525, 5.113284616701065, 3.833212737114199, 5.482432601913329, 4.6450541288621965, 2.180013382627118, 2.1852097876610297, 0.5940732996790641, 0.8212705857811436, 0.3413358066351183, 0.47498358353491754, 0.32284366988366653, 0.10863220229023889, 0.2998827277652679, 1.2832565990186509, 5.570040210600823, 15.516552213699589, 35.60130265451247, 64.80938119273033, 74.16782302241172, 60.05439773682625, 90.03765429219892, 69.61963868910267, 53.49228812802223, 60.27251289736841, 37.13898943316552, 47.00364059017551, 56.7878713915425, 73.10187970438312, 76.1492161596975, 83.14277079797561, 85.50231964357438, 63.550633768881525, 32.023481322873025, 10.514886975288391, 2.4423667500095987, 0.19653339119207477, 0.19386309980144426, 0.13974782860567495, 0.17215265832360716, 0.15939292768316884, 0.10507181632302462, 0.1313372710419278, 0.23071600454709223, 0.1298819184904137, 0.2804631343291652, 0.14325294132915237, 0.12888974269791958, 0.17174549791361057, 0.26594527786777866, 0.2014613743390768, 0.1662914728325221, 0.17251956847406205, 0.22481384867381668, 0.1613855836612563, 0.18251320076805932, 0.14430845727122601, 0.1975821042733808, 0.10641672197849521, 0.29627647611402697, 0.14590633282017323, 0.27382758716421746, 0.17122376139365858, 0.2325756676615246, 0.12666646361110673, 0.1480374055644197, 0.1716855438726564, 0.14999001046582577, 0.1338196717082493, 0.2206633528394084, 0.11239878082227324, 0.0892427007878019, 0.11230203157831585, 0.18987737415779024], [0.02011532001497765, 0.04208112158061516, 0.0651938372081326, 0.019905323823613506, 0.03555729301766523, 0.0434276475120456, 0.07071428977313542, 0.0069191979221819395, 0.042522089450710246, 0.010958945213426507, 0.015122410916392843, 0.01749796338469511, 0.10065417030766126, 0.032297761269634774, 0.056585142494089184, 0.056229869219204115, 0.031934917130838, 0.045922600529006416, 0.010921336042003767, 0.08979624527837, 0.05427138842341881, 0.020899899386530443, 0.0032358079202352997, 0.08617053499385234, 0.08875907714208288, 0.03761641861450288, 0.033623694757660555, 0.03738020306393024, 0.027955902417400674, 0.0742009244558792, 0.06711576794905048, 0.04166531203795345, 0.07608787562217444, 0.0776162593355102, 3.3591786123091176, 32.80666097517937, 68.69094694814375, 77.98784286745133, 63.231490119811035, 53.852557828349454, 50.50453247562532, 58.098131302864324, 33.849579980296475, 19.078396751034646, 29.99895388080228, 30.554891017175493, 25.68920454671306, 30.068287657153224, 20.578077723903043, 34.57478700145599, 46.82984821258053, 27.463261196690222, 7.833869985995754, 1.965275137655197, 0.29534935650806277, 0.03124451869347644, 0.09339277527385181, 0.09410450159902535, 0.03170921039136668, 0.04101990594438488, 0.1390451574397664, 0.5364099229055067, 0.5930271300096667, 1.0162792474992814, 1.188236201001752, 1.61022856350868, 2.779741575641017, 3.524813685686358, 2.556772727158762, 2.6366927354566516, 3.4628157221501876, 5.328146171185279, 2.976995610421704, 5.497148354207316, 6.85256798421183, 3.1830156522412456, 7.142883683404616, 5.958149913818606, 4.7422313401775975, 3.898313540604807, 1.2158400036634938, 1.331056685697648, 0.9111128423002459, 1.466635984759177, 0.3123276422341024, 0.2837550141397984, 2.8840028326357565, 4.096607738925565, 4.012561152058264, 2.0540117760819774, 4.122710622126057, 6.380839722771799, 4.5736718946887605, 4.010365605354309, 2.37691072687026, 5.695584493298685, 7.173798824510268, 5.534793301936119, 5.552219902315448, 3.339891092431161, 4.548814854314251, 1.4057914432018035, 7.153965850030223, 3.50881727953111, 4.3667604942475595, 1.879348387160609, 2.7461150961537517, 3.5301716433417414, 2.129158872750498, 1.5466328469976303, 0.5657222854994959, 0.2147662378246746, 0.1779884250173646, 0.0634561046477287, 0.1339496615072412, 0.03731254983933703, 0.07643698188926905, 0.1655667230126358, 1.9739372018844852, 7.4238308014408245, 22.564915110988004, 35.805234524511526, 48.343945857017275, 54.362203151949, 54.036771943492276, 38.89104158647599, 61.75192502237136, 34.506569139419064, 23.243283148734804, 30.970073899915143, 37.625120147582024, 48.38565241905951, 54.899850276208696, 71.05178233115905, 62.71553370260424, 55.34705931140531, 23.401242879129228, 6.155255879125288, 1.5148268375665912, 0.1833033438531622, 0.10713764135876011, 0.08323211282972368, 0.029270239249472658, 0.072088475309072, 0.06077611075353719, 0.05633543230473034, 0.0097837021777166, 0.034242421839266055, 0.05422344664111734, 0.08822886002880913, 0.0698263479036189, 0.022988854531919765, 0.052434129550332026, 0.15420415288498326, 0.09530376627921097, 0.06237629988801576, 0.0554436216911962, 0.034726451511584946, 0.012274272214140625, 0.01513656726362364, 0.03595437554101791, 0.02476577440487041, 0.0575686538321597, 0.03167628201716129, 0.041995863655521985, 0.02818016699635454, 0.04857843967094537, 0.1338294469901631, 0.010162502012756324, 0.08704472558512803, 0.04155666161809237, 0.06953186370552548, 0.016978626635165948, 0.019518951209442272, 0.008461410480160868, 0.07806602189497602, 0.10927870388953917, 0.014730390318999849, 0.10588786084084742, 0.05182347320500882, 0.08656536138826802, 0.0492259142019095, 0.05353063502679429, 0.017894241515727296, 0.05299479482815631, 0.05505461373456544, 0.01142644749638895, 0.047901313706871965, 0.019937106896372094, 0.04428454366843066, 0.0347810659197069, 0.017122021057612954, 0.04602945830312468, 0.05607585490290677, 0.011693266344316786, 0.06573743787744353, 0.05491058154392147, 0.06070448536305659, 0.056085201175582994, 0.003089584478725409, 0.09299942742913, 0.022775644601713267, 0.015314334136013304, 0.03382038017134032, 0.0856469062367274, 0.06909297959458444, 0.03472140682260356, 0.048695260418518904, 0.04233844668394135, 0.02441293728958455, 5.615434290901308, 43.6919677642084, 79.17047669810634, 86.14310941388531, 75.33723062084567, 66.52655170809838, 63.62040096713651, 65.46137717462355, 49.07767618856123, 34.6883160837235, 41.71028437152986, 30.008098886859035, 26.383348357292917, 32.265354279548895, 27.4284952686679, 39.21251512342884, 37.1042372334388, 24.935962384746922, 7.468802736651513, 1.4957536997333651, 0.17910161205837805, 0.2113703232739241, 0.08615327503291831, 0.03401181022185953, 0.1316477358341217, 0.3343025679069181, 0.34040215996003925, 1.4943016873252009, 2.0843656505307844, 3.259041237254297, 3.526340958572203, 4.179129504388379, 4.959929748888939, 6.73869324307288, 6.533266459741901, 7.996224241871988, 6.776704442116523, 6.553787319890915, 9.640201368639547, 11.297731264945, 9.342396393898996, 8.658521348430265, 8.156917373980246, 11.510651246193918, 8.170574576623979, 4.136033442712599, 3.857049470947635, 1.4185599838533711, 0.6660640528125148, 1.4002039043172714, 0.04642929108212552, 0.31389135026162673, 1.5826881316400345, 3.5244388541867657, 4.741956283969264, 4.557557817428343, 4.656674150497683, 6.031740442399056, 5.080820139377348, 6.286108109258837, 6.6375657146976845, 7.1062531586616275, 7.421132701058542, 7.8704549131854895, 6.620767183842198, 6.655194807437159, 6.520736938522709, 3.4759617909308407, 8.779023424271616, 8.287288623471415, 6.283668395011656, 7.470792849217692, 5.865432437389128, 6.419083322248151, 4.837675844469379, 4.3777352859897, 3.816455145997386, 1.4870494700247243, 0.904827795682415, 0.7510219165875066, 0.29194887607328357, 0.13931020853980897, 0.08043451294783624, 0.11428472841338766, 1.3521761975942121, 5.762605051840506, 21.390306449705555, 36.98054529005481, 55.627238135184015, 64.83653576143327, 55.01970221919399, 39.11140818749705, 61.51354297514885, 31.11656265874063, 32.07157546474088, 40.67279392673124, 45.100561495750185, 58.982492416135734, 63.88240744990688, 77.9081638397709, 73.70599531358289, 68.39919320998654, 34.707896555623705, 10.696163235172149, 1.6945404006588844, 0.34930355005687286, 0.01348154442835479, 0.04454792086635867, 0.1012784706789159, 0.08027904306448276, 0.08379788408356328, 0.03148106749229614, 0.05539427413755367, 0.01420441829043651, 0.07249175931417173, 0.058174357419052435, 0.08031992151612237, 0.04980526819464661, 0.037764399988396515, 0.09325414400307402, 0.10126328681625667, 0.059505665013867046, 0.07561467077222563, 0.04339642176825193, 0.05254779401565752, 0.028826367906144554, 0.005388010327043313, 0.02044038452778853, 0.043603173577256744, 0.02036715418310656, 0.05226955088155885, 0.012592188169008062, 0.020008672915038564, 0.05839415570540775, 0.039357954801450816, 0.033398664090782404, 0.032399210463007616, 0.16998276024335818, 0.018199090883436225, 0.05474278913630594, 0.03366581044129787, 0.10924260582654707, 0.2635304767998957, 0.08149227352752801, 0.218626462944573, 0.20316634897983846, 0.16260360217382833, 0.198109463878697, 0.18524850237994425, 0.14530564327874493, 0.15276891780236077, 0.14541277301407632, 0.1268718441227271, 0.12625977051474396, 0.2964832892100657, 0.16185219249417707, 0.17329029889116365, 0.09801275277089688, 0.1691232862011079, 0.16710914911762362, 0.14281830900619108, 0.13758199079142464, 0.17017368467584734, 0.11512927906287294, 0.17428249000541626, 0.21810126370720326, 0.327110503830256, 0.10980217942907927, 0.11310676097749703, 0.21571428695273018, 0.19839762019053583, 0.21000193702357434, 0.12871983971807266, 0.21094494529308813, 0.10861793007220953, 0.19117759390463754, 6.937044070613, 55.854853276283514, 91.03207711250552, 95.51259271560177, 87.01162415166056, 76.20860868884672, 67.7216116074593, 74.04080098675144, 47.65149454916678, 29.69327965090352, 43.71815350747878, 43.15073951598137, 33.38626961554251, 43.851114011579945, 31.670852399641472, 48.86799412388956, 63.7132473914854, 35.355593619808076, 9.666966642102889, 2.8581262211645804, 0.4969083151269344, 0.31327976694991516, 0.20937359170807948, 0.18829169472859753, 0.17236733148174901, 0.308815619397548, 0.3524970028909945, 1.3505417949730352, 1.6648506325098777, 5.706596547557462, 5.410542420802578, 6.02423498707433, 10.153257193103915, 10.607469620243197, 12.110936660920421, 13.330328003052744, 13.38453515883415, 15.22815308263225, 15.372756161997396, 18.97121798607611, 17.390673429735248, 16.52953274788395, 18.32121260704533, 23.217830888686642, 17.58509551325152, 15.181744579345951, 13.71663929954652, 7.4729153417771865, 5.233716089879313, 2.9116153380563183, 0.6772115514163048, 0.8605165959846589, 1.766212032206597, 3.0247963099710407, 5.124639388053648, 8.877709277214544, 14.449240969073388, 16.8422221368359, 17.507079570524155, 14.201849237565073, 12.811156222897193, 18.10909082812648, 18.87123480919869, 14.647727608680727, 15.450159234385337, 9.782145081027862, 11.689025932742704, 5.718852483457135, 19.322266194128222, 13.379252706804584, 11.309138497998639, 8.871365824053365, 7.566539866309013, 10.304138025929852, 7.410708021733069, 6.316058347302099, 4.322546557072671, 1.7269292497827162, 0.6927965377126971, 0.3508377790210709, 0.22055243862973106, 0.18540067808522334, 0.2843991715100504, 0.4578856655186223, 3.2795616071070395, 10.16447909416691, 28.633366977014852, 42.61963882753926, 58.58477977014358, 65.28622765694895, 62.45620227629139, 52.17419132109612, 72.50024303313225, 46.461725927168324, 35.780460834503174, 46.132187997141195, 55.7310240499435, 66.93985969789567, 73.60013054263207, 89.0388854857414, 83.85855628598122, 81.82156747387302, 44.44554921119444, 13.639232304788406, 2.353323063542766, 0.4298812295159986, 0.3115169679926288, 0.16275458278194552, 0.2083350522744079, 0.19677739019595808, 0.2695560034724974, 0.1030645816917381, 0.15967581331008868, 0.14857654760201133, 0.21185269819632654, 0.12928449248354282, 0.19725444846816603, 0.1680646292985447, 0.12426095518974528, 0.19426243079285468, 0.12965409926349117, 0.1382705965830434, 0.13240703621939307, 0.1686386283366911, 0.16197433755282434, 0.0884921261439881, 0.13239222007893747, 0.15496155337220238, 0.1649094808606371, 0.16655494579144065, 0.1751475258459968, 0.08731716177276067, 0.10389090710950476, 0.1914280433688433, 0.1323699728856164, 0.2141877648330504, 0.1709601352171552, 0.15314883612576993, 0.0986192952240667, 0.06666810447049719, 0.11681040538655174, 0.2559318038965425], [0.06435970535441753, 0.0313261779205453, 0.03684679519445185, 0.034206672346279506, 0.03019222798156402, 0.06752705757295893, 0.07444195103861632, 0.10606678833644237, 0.031298240609166604, 0.04932202759288973, 0.00763716834274331, 0.06710230012334163, 0.04376297951826165, 0.011290869085989412, 0.014053632077130099, 0.05079680047328434, 0.028703081376490094, 0.04818130352143799, 0.09735337323358945, 0.08718588494605596, 0.09910906289493847, 0.10512309058779672, 0.1067845284518215, 0.10520057272045844, 0.08764133953879918, 0.06592922032840791, 0.0323759596945057, 0.05116809647710574, 0.01520673325660849, 0.10460064160607516, 0.020134131303958355, 0.07187921073167555, 0.031861064339717554, 2.403982190355178, 21.530325258931807, 68.11002823614305, 73.29929259515578, 60.369968106669766, 51.36694008304227, 43.53510041390696, 50.69936052445443, 40.07888432471983, 21.795365695030462, 19.45821946667087, 26.651524728344334, 41.61881469911145, 57.15520920292024, 38.72396038424584, 41.39993075401553, 39.81659150892689, 17.90826939767407, 5.1498567961877395, 1.1660958922678426, 0.35235343801398433, 0.1133111225921781, 0.022314134083928603, 0.035373876246833996, 0.09260411839932205, 0.24995852442037678, 0.2927028598083604, 0.1926747442133004, 2.6657550469521554, 2.6662683871484574, 2.5695182238855674, 2.9845226387823782, 1.9993669083041532, 3.540476445228823, 3.8992183823739333, 5.569754367874515, 6.741170710132969, 4.606871816419787, 6.911246641989678, 5.23849549793428, 8.529664624121882, 9.124194941213055, 4.761688747713643, 9.880109217859085, 10.233503003274242, 6.096483084463305, 1.9092904127413228, 2.1892157533476433, 0.3752062698045085, 0.05903652426035655, 0.3343794524909989, 0.7294925782949694, 5.02431006200852, 19.113478429855842, 23.466326767398467, 20.714058453036895, 20.12266112912086, 7.178015372445507, 4.132098815133495, 4.75906664325345, 7.898889645453423, 6.9453359611572765, 4.272295601906316, 2.953622696861144, 5.172632528889564, 4.0186354325663665, 4.498324634567384, 2.3101929262761147, 1.42280496897236, 2.7906876850512723, 6.11380034877408, 2.8571392547699714, 2.481138888866671, 3.6310412758781068, 6.388019131075952, 4.942534037174718, 1.6309929783305817, 2.069695495790051, 0.7379347446464724, 0.9469602413235173, 0.7629514377444022, 0.18898929439244733, 0.18248062670951892, 0.10989395676240807, 0.09499968299942632, 0.03809577132004403, 0.08766417661982198, 0.9788701935641229, 5.546835468661401, 17.626568694268506, 25.781388090502833, 40.05057657918623, 31.46256865993623, 34.298793346651145, 44.40148922704881, 19.173653471854426, 18.185932020987234, 28.62026429945423, 38.73573926187331, 54.96530678964431, 55.129763926229174, 62.70628083136774, 61.07739894620834, 55.61687523318876, 45.3231167793274, 11.167963570164098, 1.7870639649129685, 0.25276645116748353, 0.021806685103764458, 0.06244556572768958, 0.008621233658144071, 0.035500142858513904, 0.05742059201903402, 0.058113415124675924, 0.04709242445026194, 0.10531365495896149, 0.11701672818631896, 0.20080215568023346, 0.2545563236720139, 0.3422004134664613, 0.33934361030978544, 0.09290681505996375, 0.17814250062069586, 0.06350053008645773, 0.06260373990141577, 0.011953082191006792, 0.07746417556078204, 0.06334793303282031, 0.09958033720331808, 0.10409513082835944, 0.014771206525995608, 0.03102618171983669, 0.025552652040196043, 0.013201388947275138, 0.04269423323773569, 0.029108692373659824, 0.03255349674051808, 0.21189509350205624, 0.1356439415605799, 0.11755890393209074, 0.14921745675946438, 0.05476090711571517, 0.034224889917118896, 0.02613544193727355, 0.020524412881763234, 0.11191786912780617, 0.04994122964900829, 0.031486426277326486, 0.07932026870548725, 0.03292565459325429, 0.026117233942533215, 0.07083968304458164, 0.03126419183137196, 0.028294827375981598, 0.12053504826561098, 0.0696936921186505, 0.023706812982357318, 0.05088961585575054, 0.057447634922761115, 0.05773633132658659, 0.06750903918497986, 0.08287423485589605, 0.06782290540755757, 0.06248772737660235, 0.04818664698470985, 0.025581659959448923, 0.06359251043308647, 0.033004887236823, 0.0661185896024108, 0.03748931696698551, 0.025691451850317182, 0.024442753431597547, 0.05051766101631427, 0.06955119976473433, 0.021680328476753448, 0.07293568428365454, 3.677491454347488, 35.86575669627036, 81.44279987581315, 82.38715756324031, 71.77894269266437, 61.05185254927605, 56.83997223454138, 56.31418635768276, 51.75495662996846, 31.645353071151245, 24.864379129102154, 32.252465371162664, 41.939707725278794, 41.05556626473704, 38.40886462119318, 38.943617036265714, 38.73890853697254, 18.426659645572787, 4.812662889880519, 0.8732223787134694, 0.23912601052753388, 0.030443642716554385, 0.05661724540855616, 0.19462117444603674, 0.393227078621426, 0.8211206164090865, 1.6777316961557636, 2.523073928971445, 4.972158228197406, 4.867137747426187, 5.994826036114847, 5.512832441637594, 5.286523940101747, 4.654625202378919, 6.503656977607358, 9.234634176377329, 13.149985267269997, 10.976006696301123, 8.435530681763927, 9.402587125378272, 10.758741709493822, 9.097484580932125, 6.722399717377079, 9.13372532013924, 6.914099675993766, 5.547279677083416, 3.92696792560239, 2.83507616769883, 0.7955303992475233, 0.6518959614538378, 0.4591860538048129, 1.2945505736335632, 6.25902904618171, 19.923020332090317, 26.536332561123757, 22.498595676114483, 18.813754435508482, 5.170451200777485, 2.506945387971017, 2.9996914248312674, 5.373250976685555, 6.633846327181786, 6.0367684306636935, 5.172129484914965, 4.148998347020918, 7.251337218669153, 6.6449289841036645, 6.05076736980869, 5.179139250709165, 7.00007999135602, 9.401977196816476, 5.6449918016310665, 6.664552602075762, 8.25274234817874, 7.029419320244943, 8.043830048653389, 3.811867443784591, 5.533475385558221, 5.102952113074641, 4.976326236801763, 2.890731413518229, 2.013793876094203, 0.5124329030513763, 0.34985072069591094, 0.03665568307042122, 0.1065572684690837, 0.09925618241991728, 0.9533693941850817, 6.792704770641943, 19.551599333363196, 29.82382593616363, 38.122570822315836, 35.33722123792095, 45.99391660382671, 42.29950281881517, 25.43723148684348, 30.098091786907567, 39.937067108769575, 48.67951639236943, 62.166080244125865, 65.1579818417949, 69.78443314952236, 69.95527590474775, 65.2390964569584, 60.01674298317202, 20.666436956774806, 3.298743222990344, 0.2921500814057166, 0.01325665453013273, 0.07930287850960609, 0.027804132738721468, 0.04646790191350926, 0.03507931927038777, 0.037399213535771254, 0.037163449977073944, 0.0645799096673727, 0.0621374681471817, 0.1202457964480404, 0.15589804989435982, 0.16800901131524196, 0.11287443715357974, 0.09358484883822742, 0.08813003468657694, 0.0262843023970603, 0.062089951543678204, 0.04168499666716784, 0.03043570796087865, 0.04316387577883659, 0.048472466728379654, 0.11656684305278525, 0.10442060328299001, 0.044097503301717585, 0.03972931209230616, 0.05367856277453323, 0.04754919671423493, 0.022107671473115202, 0.054370458913786765, 0.06408728831898301, 0.01833332097908903, 0.0275267840122744, 0.10790797341014109, 0.05396116494892105, 0.040185207185605844, 0.1672616465798309, 0.09212244827780994, 0.2556627691392937, 0.24297737967102762, 0.12058852886360501, 0.19112853363396662, 0.13836908484658889, 0.36656161109285973, 0.12747984214295305, 0.17780871611208687, 0.1324377716669152, 0.17679268434163065, 0.15740647701726806, 0.14297658277134742, 0.10239965567785887, 0.16493434807465923, 0.12850922682592947, 0.15552821328803418, 0.22713544748483167, 0.18028855804474125, 0.14413844703906967, 0.08307768482594721, 0.13738126043350468, 0.14843128200980926, 0.12126345998577534, 0.23499564748377572, 0.12102748958333848, 0.17726752095885817, 0.1182964780638295, 0.21339852573169818, 0.14204068379777093, 0.1456917362708238, 0.21294808135397975, 4.4087994771619, 51.33347834310224, 95.15599435375583, 92.37363753780242, 82.70148846410936, 67.64442720720845, 59.97060414283507, 66.6261406867735, 54.27062757553593, 33.21469729946506, 28.794741130644276, 39.27911304658459, 59.39498847530734, 76.76771117794898, 51.48043778634841, 56.10011516078826, 52.735976711396255, 24.688964851440925, 6.939402395679105, 2.0170536108555335, 0.5724861064264851, 0.37024235713385767, 0.12825261035393323, 0.28779873263932043, 0.3955457816200872, 0.8160668875901931, 1.4676084874137756, 2.23182862804782, 9.298376614047635, 10.37290011682818, 9.016944592998875, 8.047930396372273, 10.782840751832532, 12.201454177979501, 14.092774987220766, 16.63857267748925, 15.033458394389, 15.421298434657437, 15.074787428302152, 17.50839944808714, 21.832857670322543, 20.83382998743365, 14.28786583485142, 19.729822028067804, 16.259872740314854, 15.7229414486116, 8.672210420331648, 4.6130618068479725, 1.5687520729918636, 1.1813991420692014, 1.2005433728618007, 2.831597515652257, 5.1923811724109035, 12.469635451993636, 15.75342316781321, 13.275382461086398, 17.551072874376853, 10.252866764222423, 14.777907152329723, 12.627510851429356, 20.993056643393732, 18.534216919252952, 18.911505783757857, 14.749397404732244, 12.477732204621839, 13.234597656034655, 11.710364607072647, 9.992965613642047, 8.55395390141395, 6.230007919573016, 13.462321642906437, 9.43449462613752, 7.306286683005672, 12.900322483431909, 15.428676412951564, 11.688934737636197, 8.231800813828746, 7.527231833627147, 5.129867417197074, 4.938602841669514, 2.6160191480190527, 1.3730156277456593, 0.43740620476103603, 0.34812025064902924, 0.1690468612697817, 0.11737315059309045, 0.2996346991389029, 1.7862182038445629, 9.54056336033729, 25.797254077849853, 37.7519029186618, 52.66008277093211, 48.19704524932369, 47.89874507534889, 56.084723780232096, 33.66087475130635, 31.552838087081913, 42.48849830319805, 54.978227076991914, 70.09838750285488, 73.90103124803113, 78.48590543193203, 76.79023342747843, 76.46835588639783, 69.77665901184082, 25.519609105202463, 3.5170204264502374, 0.48810884536754706, 0.1487045608941586, 0.20174347855631383, 0.10262248767239433, 0.15712400507782737, 0.09756176447075221, 0.14756505107206686, 0.267243858186468, 0.16046935782557534, 0.1633141180800815, 0.30387665054971175, 0.30630855070006463, 0.3081021463919071, 0.2922110620044893, 0.17128468070539737, 0.38740474910986045, 0.25160055727727954, 0.17078523734404197, 0.15139559794577861, 0.12260449689722831, 0.10150319491062434, 0.21212582386309103, 0.280394125128946, 0.11905716506824379, 0.14672937172074474, 0.12731899432237112, 0.16930570705763756, 0.18874714932134076, 0.15762934731619974, 0.23469025419364054, 0.3123968659389404, 0.21042737629144423, 0.25279471981188945, 0.19044381956900322, 0.1445619557653704, 0.12874343522614048], [0.11868206543787835, 0.0921206709538256, 0.026797167618849108, 0.03712909476410958, 0.03534027563047505, 0.08142369333654642, 0.023830367642785275, 0.056931667044878974, 0.11426867887137399, 0.023402520943613305, 0.023462697150065534, 0.03673908323229801, 0.052688194949540405, 0.038061814472800305, 0.023537553516366792, 0.029509739402020653, 0.031154409516602758, 0.1412400606298639, 0.15307087901859515, 0.11164982262397967, 0.42266054439448547, 0.30457755971339445, 0.302361297991968, 0.2938921347020134, 0.15244555208952199, 0.25769536894175316, 0.1581848683136125, 0.0778081720214217, 0.029424201854835116, 0.02614633953799644, 0.06460584940448885, 0.04671802579034721, 3.06058818294156, 31.433566654882124, 51.92157891488845, 66.5218448638916, 66.42027901064965, 48.786063655730224, 42.892137650520574, 56.5555807851976, 111.93039478794222, 53.85766083194364, 25.155562162399296, 34.0916294436301, 42.888431010707734, 46.695891426455596, 42.47580551332043, 45.52805669846074, 26.93582988554432, 15.294966736147481, 1.9187293514128656, 0.4084568146255709, 0.13785398264806117, 0.007664147086606752, 0.1031096276616858, 0.06998324271051154, 0.10608203348613555, 0.3129861714138139, 0.5591073920649867, 0.8319250301968667, 2.338611969063359, 3.02943304181099, 4.327107292990531, 3.830398436515562, 4.330000531288886, 5.071975194638775, 2.736766862292444, 3.8122748799862403, 6.968882439597961, 10.805011949231549, 5.7179469062436015, 2.540387761208319, 7.189176476770832, 12.825112015970292, 10.284021169908586, 6.498898652292068, 5.291691662803774, 5.990737455506479, 4.068043323293809, 2.405320699176481, 1.7727593260426677, 0.49772073604887535, 0.16569963926749845, 0.7218516786252299, 14.675832371557913, 36.2302194103118, 58.86315822601319, 56.41978832983202, 61.06214877097838, 50.99313820562055, 26.548793931161207, 7.262404676406615, 3.560352565780763, 7.231895990910069, 3.9029419374081398, 1.3180610152982897, 3.531535402421029, 4.017742357907757, 2.9542880289016233, 7.047191089199436, 4.940591483346878, 3.1746355083680924, 2.849062604288901, 3.615046830907945, 6.8421565428856885, 13.334627901354144, 6.610745528051931, 4.089126062970008, 2.8182165949575366, 3.3588233926603874, 3.764580574727828, 1.1001146392476175, 2.9835761218301715, 3.6489976413788336, 1.3131388084542368, 0.758598035862369, 0.07510600371226188, 0.13963325249571956, 0.0507902427606525, 0.06901463178256828, 0.09240529560033353, 0.9669251667876398, 7.262279160561101, 22.418422429792344, 42.3443276651444, 50.33326610442131, 33.65683078765869, 39.71720257113057, 30.302763023684104, 22.012647351910992, 20.66884333087552, 25.90745895139633, 31.22973676650755, 39.02973267339891, 55.35834004802089, 61.02703179082563, 70.00822790207403, 69.22060812673261, 54.26985094624182, 25.209828153733287, 5.88040461463313, 0.13711852291899343, 0.04859383037734417, 0.08736377056207388, 0.08756148253357218, 0.031156525834493583, 0.05264745056328755, 0.17914742411625, 0.1698878725930568, 0.22640669868598062, 0.13448319578122708, 0.45448322389875695, 0.7556321111417587, 0.6319284006472558, 0.4177788789233854, 0.32569262829999773, 0.04371055229116352, 0.05403691955331353, 0.08394802199496378, 0.08121737819765845, 0.10283199739792656, 0.06665128884055922, 0.0517444703878174, 0.06749813775381736, 0.010017900044218668, 0.02112916077397043, 0.03358873816567563, 0.08079620603952678, 0.04645254951150668, 0.04739741554423686, 0.23445506520088644, 0.31187041031737484, 0.18090409437014213, 0.04573148840497579, 0.1386716589331627, 0.24903715047384464, 0.10811619610796053, 0.055132724059325074, 0.08458461041652388, 0.07303516080062236, 0.05412786568124449, 0.05309172027233628, 0.057420595849473635, 0.08063047057798794, 0.10982821109674631, 0.0778492266732839, 0.05200153885168895, 0.03968690529525761, 0.0470691506991223, 0.014528218758172326, 0.059418917047761144, 0.010261411624660176, 0.0054167228236403926, 0.04067917301830265, 0.16687797442559274, 0.10461021004424942, 0.26773712687915374, 0.11668364081772105, 0.17743521760548317, 0.10228864187675138, 0.14319727738057414, 0.13723797134814725, 0.07153842417943863, 0.16940652422847288, 0.010448670326431674, 0.0518578322484128, 0.06563950119720352, 0.07650578424574868, 4.735402003411324, 39.2264199256897, 62.98281577325637, 77.26189844069943, 74.16318678086805, 58.34497390254852, 53.35961787931381, 67.00894832611084, 110.62630084253128, 56.894030340256236, 29.85209445799551, 29.581339128555793, 34.58757000584757, 37.6548634805987, 40.94155080856816, 41.12776925486904, 27.630336515365112, 13.063066524844016, 1.8708836671806153, 0.10630601461255744, 0.142475025007321, 0.11689155708037077, 0.16939399103003164, 0.4490906084256788, 0.35407462307522375, 0.7859405718984143, 1.8392513452037689, 4.955415100820603, 6.306289684387946, 5.985287812448317, 7.585442258465675, 6.189410407697001, 5.671176564308905, 7.472656465345814, 6.7179850897481375, 9.030042367596781, 10.175659810343097, 13.76111113256024, 9.741224954205176, 7.653682674131087, 9.125848220240686, 10.262632485358946, 7.911842782651225, 4.921360102392012, 3.9201493753540904, 2.497221342017574, 2.903836297412073, 1.3292037335134324, 1.037494244594728, 0.49651007198037644, 0.27743043738507456, 1.9176977680575464, 16.107669088148302, 43.53148006623791, 67.09400100092735, 67.65358201919064, 66.76842074240407, 54.305552359550234, 26.53391049754235, 8.477705967041755, 3.7407438408943916, 6.089944493386054, 6.820211372067852, 4.825037477477904, 3.5048135201777186, 4.559256203712956, 3.730479733597848, 5.75821788080277, 6.846199035644532, 8.761560051671921, 6.221029123952312, 5.806136496605412, 6.513490359629355, 10.914728487691573, 7.340422090022796, 6.157209709767373, 9.650797651660058, 6.698334015184834, 5.721392708439981, 6.0510385036468515, 5.5322172853254505, 5.6235589904169885, 2.8874503508690865, 2.7151724984568935, 0.2511303325093562, 0.2616106604616488, 0.07736461477414255, 0.11930158542048548, 0.15901978157701033, 0.5694281285808933, 4.635640440448638, 17.889542041286347, 36.274079353578635, 47.94837874750937, 38.56224498441143, 44.02256081181188, 25.494274516259473, 24.45050435681497, 29.00822004964275, 32.50341273123218, 38.38420467991983, 45.1793501454015, 58.638394648028964, 65.64199839868854, 78.38930529932823, 78.21299476008262, 69.7024477681806, 39.97472578479398, 10.822720469967013, 0.22177208124870257, 0.023821090318022237, 0.0454036487386592, 0.052198994183732625, 0.03528929630955381, 0.025695215257245208, 0.15191004130869143, 0.0718704313640633, 0.20415141547639526, 0.12170849578274835, 0.2947896220270665, 0.39243675167522124, 0.41941147357706104, 0.1604098940808927, 0.22910783277644267, 0.08614872447064809, 0.13540826227155425, 0.0625186964809414, 0.059012622317119, 0.043067658965986584, 0.05318337120115758, 0.01639518747857261, 0.07114148338235195, 0.020519578866961024, 0.008216815842916409, 0.02463685329853287, 0.019009740227052284, 0.024747445751282, 0.04677381231299332, 0.06508699858621245, 0.0678525683319857, 0.14379614363274268, 0.01641238998291233, 0.058117080855393605, 0.059759634652084885, 0.26306855642507154, 0.22719080499824018, 0.2145777801953016, 0.19917274795232282, 0.1347875012265098, 0.17942569789386567, 0.17972410446213138, 0.21804271926802976, 0.17007326587073265, 0.17836753128757402, 0.10808067261091164, 0.1362604278350069, 0.1761275055187364, 0.15820864768278214, 0.2525783612603142, 0.1287502227651496, 0.09325082684236188, 0.17129586558909188, 0.35491545053739704, 0.3740499979786335, 0.4657567286443326, 0.38276565771910454, 0.39743409642288763, 0.4045685506876438, 0.32498258736825764, 0.35674155900074594, 0.35514245771111985, 0.3008662314424592, 0.09414005573959121, 0.08603633171127689, 0.17410650428745056, 0.2973958837889856, 6.331031505138644, 49.89039521063528, 78.66979399035054, 84.70409377928704, 85.43901258899321, 67.01541239215483, 62.419512425699544, 70.89501304011192, 116.78035843756892, 62.16912008100941, 36.091504789167836, 48.47791441025273, 60.27349741228166, 62.463756761243275, 60.421009909722116, 59.798612133149184, 36.14250344614829, 19.652647433742402, 3.194936715787457, 0.5934699901169347, 0.21619024205832713, 0.16609665667337759, 0.23715118907632368, 0.5403165423100995, 0.3268939460958204, 0.7435901282775788, 3.406812611126131, 5.301182327731963, 9.397765551843952, 11.39964032557703, 13.202666621054373, 14.26313921328514, 15.32341862878492, 14.705378605473427, 13.688510021855755, 13.742860344148452, 19.751306810686668, 20.146111019196052, 15.479602506083829, 14.465913003490819, 22.591893173033192, 26.720258382058915, 21.330853123818677, 17.66832624712298, 16.134415730353325, 17.406255045244773, 14.03276272358433, 5.501614953241041, 3.161326170929017, 1.699626979327971, 1.1283957862084912, 2.3899276025833625, 18.030102137596376, 38.997741822273504, 53.238553923945275, 51.18143158574259, 52.71930271579374, 44.29422416994649, 27.42690278637794, 14.092368041315387, 11.589257505632217, 16.489330414802797, 14.557893564624173, 11.037104475882746, 14.940044206957664, 15.200912221785515, 12.471278925095836, 17.490021182644753, 11.705568528944447, 11.487373940406307, 10.694460926517364, 10.018207046293444, 14.822623152886669, 21.49457677718132, 15.478517970731183, 13.598419062552916, 13.968541756753, 10.090497309161771, 12.898677049144624, 7.607969410957829, 7.669892849460726, 7.407644160332219, 3.6519342708972196, 2.139677198663835, 0.19689218081053228, 0.20294499553499684, 0.1335807288846662, 0.21883752016771227, 0.38004711811100284, 1.5500473928066993, 9.509536431681726, 29.97029704432334, 56.154753777288626, 66.02298213589576, 47.58677151895339, 51.74338171558996, 42.687236955088956, 32.03315977127322, 29.20665667903039, 37.21806049346924, 47.18864702409314, 55.31138927705827, 72.31284003103934, 81.72822290851225, 88.45806091062485, 88.83736195102816, 81.51333978099208, 49.25584200889834, 12.3885904589007, 0.5528416508628476, 0.21023416891694072, 0.1944868792329104, 0.25852712592290295, 0.1724447676491353, 0.15368618551761876, 0.2988227991567504, 0.20926427096128467, 0.32639166820914517, 0.33007272068531285, 0.5774660456565119, 0.9156475925157148, 0.7354615063917253, 0.6031507061373803, 0.46413899609638803, 0.1439038862384135, 0.2540598527318047, 0.25569830029722185, 0.12558916012846655, 0.21075351524256894, 0.11706186608681757, 0.11613500695074759, 0.19567779355472137, 0.11729179205553186, 0.09851189735796183, 0.11083794562446495, 0.11712747385665295, 0.1324460607382559, 0.15705141058612257, 0.29217545423776875, 0.3867622158460079, 0.28613990713511744, 0.20594559339506013, 0.2201783578963049, 0.24202500980707908], [0.14728706840786243, 0.10909786883501277, 0.02798060875295872, 0.03592408442449185, 0.020215558789430127, 0.028369825468548847, 0.012657499079772783, 0.0573358818468067, 0.06283918553362451, 0.01769453388518624, 0.1121109156238456, 0.06180282178965788, 0.11242888041681821, 0.019685992850892006, 0.040638558866996924, 0.01733213024694593, 0.05899415959814384, 0.10913313952304664, 0.12453736737370492, 0.09151945281172953, 0.26142572683672755, 0.32100374119416364, 0.16640137580613937, 0.36224577816263326, 0.24922729349665104, 0.45842934279672565, 0.04469376868538318, 0.00915128606251411, 0.10632381083503847, 0.020700898472099535, 0.11369866349043385, 0.4387149280838428, 17.94466507050299, 55.1101795319588, 67.19641408612652, 62.33903715687414, 57.91466243805424, 53.18580981223814, 32.959013677412464, 30.72923448777968, 59.386943694083925, 51.299957767609634, 24.369328944913804, 41.92399863273867, 44.717596961605935, 49.856392183611476, 51.28112646841234, 32.207779768974554, 9.806384348100233, 1.9817669881928353, 0.2720804470441034, 0.06650632968352688, 0.22996241917773602, 0.08676051462609922, 0.18193351735751476, 0.5435666550071009, 0.5194658353444069, 1.0969438932595716, 2.037183092005791, 3.7293944628007956, 6.045698686953514, 4.79504507395529, 4.281517584477702, 5.4052006429241555, 3.205710731206402, 4.0861156438627555, 2.8661256499828833, 5.022083626639459, 5.081279546983781, 19.08829092979431, 13.786246661216984, 12.337397644596717, 9.256798509628544, 7.605650799889719, 7.17904156254184, 6.342718697363331, 5.717042799918882, 6.042057746841062, 5.455079953516684, 5.998739580954275, 6.911349604206701, 3.2413704693317418, 10.31676805788471, 16.14878043051689, 44.68738294416859, 58.93556125702397, 58.85255213706725, 56.93600754584036, 68.77832951084261, 71.23633769250685, 49.34149480635121, 22.2896667065159, 11.382485839628405, 12.558382018919914, 8.110410811439637, 3.5009688619644415, 2.6374921635273965, 3.916294666067247, 3.770123128929446, 3.579246132604538, 3.2401626244668043, 4.442191595031369, 3.930947905586612, 8.456740898470725, 2.5269580560345806, 13.189093259073074, 9.351458049589588, 3.5000789742315974, 6.71758157591666, 3.084361423407832, 3.1120653690830355, 5.36895303956924, 6.16973138624622, 4.184353611161632, 4.1778066850477655, 1.4955933728525717, 1.2397571460854624, 0.48258777227132554, 0.09890614152555505, 0.17264601894684378, 0.14322006083544225, 0.0485347037113482, 0.10571260290640978, 1.5462717437936415, 8.764567529001544, 31.654394134398434, 42.611343014624815, 33.42240641194005, 29.936031218497988, 24.79567881553404, 30.632210739197273, 50.21150396716211, 47.46713138395741, 32.785835150749456, 40.20145839260471, 45.816213623169936, 55.9496138172765, 62.24615543119369, 68.7991023832752, 57.12751726950369, 46.200503918432425, 12.927747695676743, 0.9327121703855453, 0.045514693183283654, 0.02098983236318154, 0.011426594968314373, 0.22530244423016427, 0.07102957325837306, 0.036889711439970045, 0.2601351444759677, 0.19884029643670206, 0.3546813647112539, 0.736572333881932, 0.8018276419851088, 0.23681988669258935, 0.16328736628976562, 0.17298856750130656, 0.055102348673127355, 0.04934549669645006, 0.17729715323976933, 0.06635462895276086, 0.0240945894526498, 0.0684270346837659, 0.044236915982178146, 0.06191522604034794, 0.021925727506318403, 0.006479617628839709, 0.023732526723535794, 0.07769718886383119, 0.13981673055358473, 0.12125205293658281, 0.10054045221618108, 0.13993447826754662, 0.03602658315832096, 0.06226488389074803, 0.09505806656013574, 0.02658899088630513, 0.06696847222384907, 0.060572381161393664, 0.00875444102641796, 0.08374105568134016, 0.10405608332685887, 0.009709420377358554, 0.036163276226650325, 0.023422893136739734, 0.05579100043002156, 0.09510889649391176, 0.01803303941062862, 0.08387547346853441, 0.10636180879608279, 0.018991030444721543, 0.05410368028547495, 0.07854999794114022, 0.0875786658857138, 0.15629378027252613, 0.08714890588195094, 0.30074543469855863, 0.182605636937003, 0.132276663376439, 0.19886664986129732, 0.17548907848615802, 0.26000536918159456, 0.09091046653808126, 0.04297895747567377, 0.14431909057161502, 0.048222729725943464, 0.13300947244128875, 1.1369494949617693, 24.187952664590654, 65.11602817043182, 79.9101729546824, 70.61206894536173, 69.11562981144075, 64.54040073579358, 46.29655884158227, 43.42928271139822, 65.26134021820562, 54.397418191356046, 30.68997940709514, 35.94783229212607, 40.24488295278242, 49.11837470146918, 45.63429801694809, 27.89381192576501, 9.185409411307305, 1.8307086681166005, 0.2039998679632141, 0.08253617557666956, 0.36332688144137787, 0.6439214151713156, 0.9985389800802354, 1.6017390835669734, 2.824774797885649, 2.2695949241038296, 4.283305694980006, 6.154048769704758, 8.19039676458605, 8.022196215967979, 8.266039183062892, 7.734547238196097, 7.7990055084228525, 9.66328255591854, 8.657817282984334, 6.27537650446738, 9.23178457444714, 5.011648651092283, 10.417204268517034, 9.648050031354352, 5.750958063910085, 6.720667990946001, 8.467878468575018, 4.954535509309461, 1.7323597712862877, 0.9775876398048094, 1.9355082704174904, 5.256644304721586, 5.455537890234302, 6.218155987801091, 12.520225201883624, 19.96052799686309, 50.38830872504942, 71.33511866292646, 74.70582315998693, 71.37480520432996, 80.27809127684563, 80.0172693498673, 52.64993559929633, 24.568281365979104, 11.940960749503105, 12.387692236131238, 7.888373771021444, 4.569352874832769, 3.2297323067342085, 5.019798846014085, 3.634760908542141, 4.028435474441898, 5.266573784812804, 5.725274874318031, 7.082124208250354, 12.416421636458367, 5.225599725400248, 8.969053433787439, 12.11682217736398, 6.228982710069226, 8.418826287792575, 6.469089129278737, 4.895526882140867, 4.986197371636668, 6.9540166566448836, 6.85741211137464, 6.968007260753263, 4.62542119526094, 2.438990079587506, 1.694409001258112, 0.7962756495802634, 0.3169172749884667, 0.2547219059159679, 0.06750033642616003, 0.04188203065085315, 1.3502547265060487, 8.471512544539667, 29.863269290616437, 37.25046319346274, 46.00040420409172, 35.341971228199625, 25.28247633287984, 33.26689620171824, 53.99361802685646, 49.84539778001847, 40.71778743497787, 54.11221481138661, 54.07743123269851, 60.586741816612985, 67.94299802472516, 74.00521724454819, 69.70023555140342, 58.949834762081025, 20.299628665370328, 1.2049676838421053, 0.08338841008803538, 0.040710042531211535, 0.043021096141948816, 0.08366761849291864, 0.029986406969387206, 0.07487263034788832, 0.17952470709719967, 0.21723098782522066, 0.3137499610743215, 0.510560400303333, 0.5193681438123027, 0.08782176856672572, 0.04957619258352826, 0.0761084144394244, 0.09436241275961361, 0.060244369125294114, 0.059380076390000126, 0.041194347995183164, 0.09302498412228401, 0.024702778994856824, 0.026052608680460724, 0.0660639675334096, 0.007770724759827699, 0.06028786376719514, 0.09115778270267672, 0.04203951534544749, 0.026546260417108575, 0.014782353105293888, 0.05542551137266621, 0.07433659862726927, 0.03804509077341326, 0.023205199676956383, 0.10002269935343536, 0.3344918835547663, 0.18196022318255517, 0.16869832190775103, 0.06044629074993634, 0.2199038073060013, 0.3999344541901543, 0.1449610262868866, 0.1841267811194543, 0.14024621476569485, 0.15532831030507244, 0.17078065613825477, 0.15118876952798138, 0.22582920628689954, 0.2451836822494384, 0.1859863063380603, 0.10011477546105463, 0.1349015104314012, 0.19725742088931222, 0.25149909659258785, 0.32774730675643493, 0.6573218251428297, 0.4824753105640412, 0.3884855153099183, 0.5473692703150934, 0.4389352856143829, 0.7300580124701224, 0.13956275708492727, 0.22567695397282803, 0.21804348535595403, 0.1929891466974251, 0.3648607733268892, 2.6535299997175894, 33.088373445695446, 78.70625634347239, 89.50910706673899, 83.22155552525675, 77.95931154681791, 72.49974881449054, 49.474588671038234, 45.56606054306031, 71.76600671583607, 61.19843544498567, 35.5375406049913, 58.282972997234715, 61.943732846167784, 62.04139986345845, 64.21438117181101, 41.13666519041985, 13.614803783355223, 2.636529221650093, 0.6443911802864845, 0.26249022132927374, 0.6909565170926433, 0.46142165158544823, 0.580738834556072, 0.7327420781216314, 2.2969556623889558, 3.234619579968914, 8.240785002708435, 11.385816912497244, 14.248850018747392, 14.579771564852807, 14.6056798004335, 17.019434821221136, 13.835001722458871, 14.731248597944937, 11.662146910544365, 12.244380597145328, 14.892052046714293, 30.75996625807978, 27.945810787139404, 20.141447321061168, 20.109813405621438, 19.66812510644236, 20.49192874662338, 19.108836304756906, 16.620951429490123, 15.129996749662585, 14.232713387858484, 14.536941243756203, 14.692224937100566, 8.0306905988724, 14.013076347689475, 21.125715124991633, 58.86299348646595, 66.7176103591919, 67.30576192179035, 63.62954401200818, 74.41355166896697, 74.510771536058, 56.165540295262495, 33.150699907733554, 19.695101207302464, 18.948070118504187, 14.715305143787017, 7.824919627558801, 6.438057787956731, 9.651581145101979, 8.85360925428329, 9.353243708610535, 10.544783280741784, 10.533533923087582, 10.923039009494167, 17.49013493137975, 11.14420283225275, 21.797083693165934, 22.26039013554973, 11.189230661238394, 18.20896221745399, 12.676249242598011, 11.66832366297322, 16.288048105855143, 13.82972711516965, 12.434824416714331, 9.855834649455163, 4.9020993036608544, 3.481721056084479, 2.1346499458436043, 0.359330905541297, 0.28935343147285525, 0.24060684316340955, 0.12179995135914896, 0.31571712164628896, 2.489380033746843, 12.474810038843463, 41.00380274557298, 56.96220505622126, 46.603723572146514, 43.631822139986106, 34.6974983522969, 37.25239299958752, 59.29206940435595, 58.41492152983143, 46.53279142995035, 57.691146173784816, 64.5705912190099, 74.28573731453189, 82.05120655798143, 84.53915026880081, 80.87543687512799, 68.02362626598728, 25.31706967661458, 1.8945084704506783, 0.14305781873483814, 0.14695169043637094, 0.12162896053444956, 0.38066054003373273, 0.36813733137903676, 0.30183266668069747, 0.6100400429098838, 0.5734824497372873, 0.6753553510192902, 1.2577316525482363, 1.295843362327545, 0.4882184878712701, 0.3705020302966718, 0.3150700224984077, 0.3190937920683815, 0.14305916704958485, 0.39721232929056693, 0.09010539239933414, 0.22987899220278188, 0.1621378053941073, 0.07090448642209654, 0.18996083177626136, 0.09609899618813107, 0.1509078910514232, 0.10392030956403864, 0.1560433154865619, 0.3063170083107487, 0.3017238515519327, 0.21655110011418022, 0.3450107916949257, 0.1315998246953372, 0.12867434941712888, 0.29279074541503386], [0.14605431036362726, 0.10613530724039001, 0.06361099996513898, 0.09240966996238117, 0.059316969897237525, 0.09311827064882364, 0.0685272389842618, 0.01806357184485082, 0.0407528821679373, 0.09278380432196202, 0.04646923490649751, 0.05444786826809568, 0.14870354965809854, 0.02819373632871336, 0.043230494784732024, 0.041999724738660364, 0.002163436128607681, 0.15837044545239018, 0.08678211830556394, 0.04178653013021235, 0.29784974491884636, 0.2257284044378227, 0.29326394260410343, 0.30967676351147316, 0.23764618912771826, 0.2873112555713423, 0.15426239088898705, 0.0428869886203639, 0.08039100681461635, 0.0967799027961108, 0.771337342598746, 11.143721361314098, 54.12364067569856, 74.88878603904479, 59.67536733996484, 57.64066919203728, 44.95461794637865, 39.98936014790689, 27.19483183276269, 25.957178915700606, 35.471974265190866, 32.6634709296688, 45.3451330431046, 31.564030570368615, 50.09752773469495, 37.89019784619732, 27.069568980124693, 9.384715826280656, 1.3912103998084224, 0.03388606454996813, 0.10880103274699181, 0.023709153380965995, 0.17310593217130632, 0.2961584985736878, 0.5548252670034286, 2.288720646212178, 2.4234104252630666, 3.2026919770625333, 1.631361803700847, 5.584709875045284, 7.018949043366217, 4.376599269528543, 6.798310327914454, 5.03191553777264, 5.276946002437223, 9.04908057182066, 9.595884469247634, 9.102276736690152, 6.602589939871143, 5.492326780672997, 6.098357977405672, 3.1164976473777526, 4.650219400082865, 8.35488380924348, 6.846897707831475, 3.156073626972014, 3.2680048336905823, 3.96639853235214, 10.572245755503255, 16.072521709626724, 18.942139494803644, 19.212810493284657, 31.60179318920259, 48.135785671972464, 57.89672936162641, 45.35378579170474, 47.53309780551542, 49.24259616482643, 59.706334452475275, 50.55592729199318, 53.12116915179838, 40.970584192583644, 27.3145955224191, 35.39797875189012, 25.06410033472123, 24.529946081099975, 19.27995558707945, 19.387781543116418, 8.25933094947569, 7.85047386923144, 5.653296930174674, 6.472172112234178, 3.737319856882096, 8.414281241355404, 4.815741460169516, 4.457368716116875, 7.270391602669993, 2.0743925340713996, 7.878357018193892, 6.819168021602016, 2.972504741722538, 4.6510455493004095, 3.7615667235466743, 4.259923956086559, 4.273420341553227, 6.273332459311332, 1.2219980022599621, 1.5984192875123795, 1.158852010003982, 0.18781987649779167, 0.0726902526953528, 0.05553470954539315, 0.20892749870977095, 0.11467782344909445, 1.270162501642781, 6.546835409056756, 25.28245475984389, 29.181667258662564, 27.65884037940733, 36.54998279386951, 29.288359649719734, 17.827884343362626, 20.461665699558875, 23.7468840998988, 17.45709288504816, 31.427534049557103, 44.20458232202838, 42.31845178911763, 50.569922308768, 65.752475876962, 60.271022396702925, 51.38576745986939, 11.354628186072073, 0.17449478829099288, 0.050778019827820604, 0.0634617583766099, 0.011423190665100853, 0.07605563864232072, 0.1346295951835571, 0.20093622106698253, 0.10448601953084431, 0.25924262140066395, 0.15592377512685715, 0.3207437615961798, 0.21640627885297423, 0.16412713655060338, 0.1300095793821158, 0.13422655632659314, 0.04832905889939397, 0.008719940256747988, 0.03848332754005829, 0.09577163149632754, 0.01686230192952339, 0.017624350655223095, 0.02155121967887446, 0.007867716279091134, 0.0642992610171918, 0.04280616634435231, 0.02248754191602911, 0.05325472846086468, 0.010373320791029162, 0.020802280632779006, 0.08578504721123366, 0.08789849993322166, 0.02172199216851544, 0.1061478864041067, 0.13556198547444037, 0.0527453757522087, 0.04967664586259954, 0.08796812966465951, 0.060414674301301284, 0.07541495931124495, 0.06238736219764237, 0.0474323568144633, 0.016610308798150192, 0.04711396684269271, 0.05909508019084892, 0.025096649694586956, 0.03237471097118912, 0.03979571659358279, 0.04785463213920594, 0.07299455814063549, 0.08978628613535436, 0.06863609241742281, 0.12049274489043221, 0.13064003910028166, 0.18344010586940473, 0.140427609064406, 0.18658174051632806, 0.18120453873228642, 0.1267030060050949, 0.13590732258894753, 0.08240928077289174, 0.048710785190304445, 0.09119095430979807, 0.13066967138119284, 1.1802649642190626, 16.255166876700617, 63.74914100093227, 84.2318247210595, 70.44467787588798, 68.38261727363833, 55.71729183197022, 51.465473944141024, 36.575235013038885, 32.69411836901019, 39.01279195662468, 32.03698604337631, 34.22724539233793, 29.925195670896965, 54.09195969181677, 48.27838343958701, 29.544641433223603, 7.884545047436991, 1.0363129983025214, 0.036653691241818095, 0.16025790223671546, 0.0871825448027061, 0.43031498849872624, 1.8385492409429245, 4.326803799598448, 4.955378818896509, 6.27525540128831, 6.118366968247199, 6.606234312057496, 9.036980059839065, 8.401809084799982, 9.907178475010781, 9.82532351247726, 7.774629938986994, 8.438721529899105, 11.099684911389506, 8.85187654725967, 7.946631754598311, 8.35828842655305, 6.945617881513412, 6.14841869761867, 1.4730672009529606, 2.22858164098955, 3.054624464242689, 4.373446174206273, 2.549788211622546, 3.5365038196886744, 5.547448829297097, 11.665243621795408, 19.0580573005061, 22.16741623417024, 24.09565733325097, 42.097481143090036, 54.07885505307106, 62.16998300244732, 57.73681825207126, 56.88837428246775, 54.19294111190304, 66.58280634110974, 60.27152446008498, 61.5003167429278, 47.66327734916441, 31.524867665383127, 36.28406178566718, 27.09632738944023, 24.869066361458074, 21.742305832524455, 21.04226669957561, 9.947478867346241, 8.420556053038567, 6.96889812907865, 7.162189589392755, 4.430565199544353, 7.410205468054741, 6.752385747048163, 3.774448277488832, 7.811533558753229, 3.638468038651251, 6.157925052027549, 5.777929752103745, 4.960680392480666, 5.3199616555244695, 5.187757678570287, 7.643261426879515, 7.564259008053811, 8.149172163778736, 4.229011756758537, 5.397746178411669, 3.3872125273750675, 1.2121268674250574, 0.7719701925112356, 0.37056739291837143, 0.07924614969881312, 0.046766002046605276, 0.7412925999491446, 5.568015777295636, 21.637896260907574, 31.246716706983506, 29.391288526596565, 28.072403323265817, 22.149192902349657, 23.693788936061246, 29.65681729778167, 28.58876374460036, 24.101648753689183, 34.50070519601145, 54.71036057318411, 54.979662664474986, 59.6554809231912, 72.46134881050357, 68.62858126240393, 62.41085967709942, 17.145493915004117, 0.31966146322027333, 0.03810375012577542, 0.06955699905032112, 0.08633159731905307, 0.054060591670173797, 0.10797963327457828, 0.11359847451169645, 0.13562419181389196, 0.23258630096191363, 0.12025141187252537, 0.16937480818840767, 0.11406814003543508, 0.16932436895947303, 0.053457013977270935, 0.06139807072618316, 0.014150975039228799, 0.04470792982066351, 0.05502732568270257, 0.11517506047722795, 0.08492639288306238, 0.06173652071025103, 0.019488713719070922, 0.07998311096021245, 0.03245846736395071, 0.010646051922512632, 0.022962688798865965, 0.02822080604551781, 0.07027432547822114, 0.10689204123111502, 0.11000937556908016, 0.05984421075892545, 0.041426074270519524, 0.04533330654545177, 0.39889953069148526, 0.2208552118991652, 0.15173287581532233, 0.22662596837166818, 0.23984257852838886, 0.20341397924048288, 0.14516249208921386, 0.12436843732552183, 0.1574717323866583, 0.25291236027354197, 0.20751524626487688, 0.08813236359386675, 0.15729681919178656, 0.21067370420261738, 0.21568316846124588, 0.16449715701803086, 0.20373045016200314, 0.2561186220977576, 0.41282854133075286, 0.24645364152327662, 0.489234289815349, 0.324031381957954, 0.49555975523206497, 0.47299947709806506, 0.3877454743750634, 0.41804204544713425, 0.4943041371241693, 0.1942890293655857, 0.2065597660839558, 0.24451200700094625, 1.864076271172493, 23.18947607471097, 74.73249527715868, 93.48648455835159, 78.90189632292717, 76.1448387945852, 63.22618707533806, 55.36954233723303, 40.879749944133145, 38.005209584389966, 45.74765451492802, 42.829877868775405, 61.96858890594975, 43.07874441146851, 61.324629860539595, 48.262329178471724, 33.93648009146414, 11.667496042866862, 1.889398357560558, 0.17943564171512283, 0.32068609049723995, 0.09322807403101076, 0.29396117454574955, 1.0577763304595025, 3.5910985546727336, 8.209845346789207, 9.778208982559944, 8.815035685416191, 9.657237202890459, 16.584865623904815, 16.49672996613287, 16.216872776708296, 16.691507024149743, 14.812789770864672, 13.202695058238122, 19.61147039167343, 22.612209089340706, 20.995223752913937, 15.39835943329719, 16.64422285172247, 15.858731942792094, 9.004733274059912, 17.276142181888705, 17.833712985438687, 16.267014395806097, 10.311128670169461, 7.937264644330549, 7.306926519640031, 15.074507959427374, 19.840958464530207, 23.531581278770204, 25.09613629310362, 47.03176790668119, 57.169623913303504, 72.91613978724327, 59.632868459147794, 61.111405895602324, 58.89351737114691, 71.94456085082024, 63.97830155587966, 65.70769417670466, 54.172105481547696, 37.667489590183386, 42.614692718751975, 33.54469414680235, 29.583176758981523, 23.71072965283548, 23.959309862506007, 12.096889672740815, 16.16115354722546, 13.468584687479082, 13.827619821794572, 11.367087594924435, 17.926443699867495, 13.482714045432306, 13.333968943165196, 16.837513331444033, 8.041292765448171, 17.70453364618363, 16.53551632358182, 9.648716834283645, 14.157230315669892, 12.726503629838268, 17.517605250881566, 13.89097982837308, 15.39427036239255, 5.2477424856155155, 5.901777119405809, 3.717555278731931, 0.8213747737388458, 0.3199518718306096, 0.22361242362568456, 0.39581703803231644, 0.19355160845143182, 2.4503095496085385, 8.885590299483269, 32.684494833792414, 40.909861979946015, 39.76280796912409, 51.88080195457705, 41.69319852705925, 26.576872218039732, 31.546215165045957, 37.37736363564768, 32.10650417112535, 45.31971216201783, 61.66426397139027, 60.89704836568525, 71.74377472169938, 82.01785856677641, 77.61211118390484, 73.44248264066636, 24.49077925374431, 0.8332816186931826, 0.12822794998365064, 0.15875434743300562, 0.2025670537184323, 0.24504348815929508, 0.41911536527256815, 0.36660353142407637, 0.423029431051785, 0.42995011614214995, 0.4990032591646718, 0.6993444444191071, 0.4363179002558032, 0.41812815372982337, 0.2976964047599224, 0.22747341483350725, 0.17983757740547582, 0.13946978465443657, 0.14673240542892488, 0.25135746225714684, 0.18629462608406622, 0.1421379156771206, 0.14476945834054103, 0.10596644614012012, 0.19303345722296547, 0.21081579819081292, 0.23468289974956746, 0.2073950011042818, 0.3750592422100806, 0.28859770105731103, 0.3594263907401793, 0.27244449202572146, 0.19764411142997204, 0.26034554286349204], [0.04732705419883133, 0.050058728384394804, 0.048418250685978326, 0.2305739105588967, 0.07936755931305309, 0.0793567498124415, 0.07663639457595926, 0.06638177144791811, 0.03569436529951711, 0.06482014717954783, 0.033091489646223285, 0.07639710701281026, 0.02959227963020244, 0.13093637723115184, 0.08935902357822464, 0.057703052467155846, 0.1173144759189698, 0.08234007238981225, 0.1073250800911938, 0.08926357668373855, 0.07849590447280677, 0.07085544913406334, 0.15942678876942204, 0.20061634871507847, 0.26551461388026515, 0.0688884954058355, 0.06850363581531471, 0.14057103604558976, 0.1637733111818952, 0.12675504635779128, 6.346029177788766, 36.528954967375725, 73.29600564895138, 64.0113357574709, 67.12062604965703, 48.51963273940548, 37.46663285839943, 32.35324871155524, 29.822419766456854, 29.95382897315487, 27.640185586867798, 64.1438961798145, 49.23083689904983, 44.014810208351385, 48.678025891703946, 16.77204308971282, 4.5775094436061, 0.4403683296855419, 0.06482799191989246, 0.04147769327485754, 0.06437549442653695, 0.05727448373011524, 0.7001066712602493, 2.7189843068199777, 3.851314965755709, 6.745265174296595, 5.633183996523581, 1.9965192675590517, 2.716434521059836, 6.381974758640413, 6.140820086002351, 6.149891547618374, 5.223901829411907, 3.7792306273214282, 4.907218487031998, 7.169620519684208, 9.525262194295085, 6.180579681550303, 10.159330002723202, 3.2868528029611035, 3.904763633205045, 6.7349655205203645, 5.941648012207401, 15.459355231254333, 25.369603941517493, 28.75562921647103, 34.20677454240861, 41.04605451706917, 49.08689375846617, 51.71746269349129, 47.458278594478486, 31.783314597222116, 39.552023718434, 55.5134815554465, 53.0417803795107, 27.26450489413354, 40.576240862569506, 45.60493123146796, 48.751797829904866, 42.13519473229685, 45.785285734361224, 62.99112335328133, 42.055551005947976, 44.745673287299375, 56.111054651198856, 44.1900146392084, 38.37573236034763, 34.89336975159184, 22.86107563203381, 18.186794942425145, 21.005021833604385, 18.866227903673728, 17.56714870852809, 24.64266715511199, 14.35915687391835, 9.717587770954255, 11.76181237543783, 8.444477608126979, 5.843762322779625, 2.43977161184434, 3.1342522559627413, 2.3719678050087345, 4.007162744960477, 4.050039889351014, 5.733238756656648, 6.10522702816994, 3.4280198860553006, 3.3394905203773133, 3.454965343398433, 1.5565886805134437, 0.9972582036449064, 0.2861397845610496, 0.04304870595073989, 0.05248267654209368, 0.0035942702755076632, 0.4395723030451806, 3.5285065972035934, 21.679669503242742, 46.329898988046956, 50.199838838269635, 44.8918874802128, 28.644129960767685, 14.308421996331985, 16.492676196559785, 28.606851754649995, 44.71420018903671, 23.45279655148906, 23.62647125797887, 43.421383057871175, 52.158364557450824, 62.332133785370864, 63.03006464435209, 50.70518916653049, 16.232624034727774, 0.17991178068182162, 0.10674702078704873, 0.06535419473244299, 0.030194729258636796, 0.059102702765695514, 0.19085326292101415, 0.11705441205131432, 0.12507711462075674, 0.15391648686941595, 0.13187739367206253, 0.16412580355761514, 0.16132918426827078, 0.08269442635918818, 0.14903309003960702, 0.0660667943978502, 0.05822024608571684, 0.02557711705805794, 0.0737997931578467, 0.071646626437864, 0.0959917055743356, 0.046033438129891316, 0.02677179861723656, 0.03681489912372443, 0.04460817368160333, 0.04897563327704707, 0.04089537452185347, 0.03968808890110062, 0.1728638330654752, 0.07669754371407532, 0.03707172243946022, 0.03340925908677521, 0.02441298708529963, 0.10377473753666687, 0.023260898099491195, 0.05865855946115429, 0.10582026124240891, 0.05490046918332096, 0.05759810225196904, 0.061571336832017674, 0.059227525301638155, 0.011470132702661139, 0.04448477606919985, 0.0271966690648227, 0.011795334153688483, 0.08098809574280055, 0.0402364737894987, 0.019226026000274767, 0.004208995744721183, 0.060410663831017675, 0.024024923332035545, 0.16844284690676198, 0.07043224684293233, 0.09424507107225158, 0.1939466340287078, 0.11228900042272384, 0.12052511976611231, 0.061803124394387975, 0.030381691101337635, 0.015781699480759283, 0.07890399951007097, 0.10490858596899819, 0.35115022032010945, 7.880399592461125, 42.85525560379029, 82.85198980762114, 73.5572982603504, 75.34687180672923, 58.58486998465754, 47.64494811334918, 42.6514845509683, 39.3110764411188, 34.17280289434618, 35.30237097893992, 60.684581418191236, 40.24977807075747, 44.53033516483922, 56.33687334675943, 20.800454539637414, 5.677243000076664, 0.434143957231314, 0.0347815677072973, 0.20932963358298426, 0.4483817625911005, 1.6546357999886236, 3.043035086124174, 4.009552203839825, 8.841211622761143, 11.214684882471639, 9.907151999012116, 7.822191128807684, 8.097470912241167, 7.948037434008814, 12.226909379805289, 8.10788284386358, 10.516449059209517, 9.241116873679623, 8.327152652125205, 9.369371514166556, 8.881769910935434, 8.254717261560502, 6.886024330892871, 3.7669457639417345, 3.175230973189877, 4.945477285692769, 7.434150067067916, 13.502157234376478, 25.420941883517852, 30.977724482936246, 37.38182729290378, 45.333236494371974, 53.29652655509211, 54.359728136370265, 52.32581838484734, 36.66544952700215, 44.71410997452275, 58.53492644525344, 56.05279176465927, 34.71830652606103, 48.31776011374689, 52.855091248789144, 57.20654910610568, 50.13308009793682, 53.073712395083525, 67.47444737342097, 45.85181697722405, 47.99782414590159, 57.53020740324452, 49.15201294806696, 45.312287115281634, 38.415156102949574, 26.135244715598326, 20.867048540422996, 19.986048898389264, 15.866013823017, 13.043356614728129, 15.840336026683932, 11.480215614841832, 10.926177886224563, 10.30874583028978, 6.793456885122485, 3.9450627997998273, 4.805823256892543, 2.8829582564292418, 3.425623563028151, 7.247943878173829, 10.389928106338749, 6.474035728362299, 7.635685859187958, 8.260619448077295, 10.786249291512275, 6.614279093280916, 4.620400071144104, 1.8595581910302563, 1.6777605010617165, 0.30957030793351514, 0.1825833744219234, 0.043737679464562286, 0.23399764942305706, 3.3955813944339757, 16.70478032481286, 36.211882329756214, 44.50799726670788, 41.147632137421645, 24.45955522598759, 25.061635125067927, 32.257358527952626, 39.64629396315544, 53.873420915296, 32.34622374657662, 33.2824444770813, 51.989196654289, 59.62316059297132, 69.76722963394658, 72.11384250271705, 63.34975742524671, 22.103136431786325, 0.5428323750534366, 0.1231464045122266, 0.1288658867199575, 0.07324788043455732, 0.04937722422783414, 0.0618501813451369, 0.06693179959491377, 0.17585899170127609, 0.1607480452906701, 0.13510527449750132, 0.16291576768121413, 0.003707438220097233, 0.06512262167469149, 0.0819534661188241, 0.04516511960255523, 0.1060878787369978, 0.0617115845483157, 0.04743799905202562, 0.049765270744119926, 0.024802967973594225, 0.04254403403930126, 0.021869312791574388, 0.07710920872106668, 0.0156822832932155, 0.026347184809105053, 0.05275738418042179, 0.04857589242859714, 0.1793366478335473, 0.08731473327404068, 0.023660663845798662, 0.059687361917308265, 0.01972578920333857, 0.2973421044167011, 0.1736563050578679, 0.12338622067604335, 0.44833469414903276, 0.20336580763180412, 0.17462692313617276, 0.14119754275006635, 0.126801923277878, 0.14423955532331623, 0.15533793236940138, 0.11860341119069247, 0.11137412290178961, 0.13953382960490643, 0.2416389321367587, 0.19568660356585058, 0.17321511502227477, 0.2886911637840733, 0.12339349851132402, 0.29603279886707184, 0.16931680001078114, 0.23040659695623383, 0.4346442126458691, 0.3264134557497117, 0.33442952399772985, 0.48210161287457715, 0.17591280171707754, 0.17968713305890563, 0.3045537190571908, 0.2653381378660279, 0.44521809525547495, 11.42834815286821, 55.49631334120228, 94.55323588463568, 82.32473696431806, 85.54719940308603, 67.29889777398878, 54.2976370165425, 47.72624707991078, 42.20749578168316, 40.90273895571309, 39.83939616910873, 82.16232730496316, 68.48648948054161, 56.484609419299716, 59.76675072023946, 23.557076684890255, 7.009252944300252, 0.8462735505834703, 0.22075712200134034, 0.3179607173848537, 0.2861475373708433, 1.0668389667426388, 4.295949945526739, 7.635930517027456, 10.450951360887098, 16.601216023968114, 17.1512911781188, 10.066477694819051, 11.869404950449544, 11.444303374136648, 19.40675012526974, 17.490617382910944, 19.40005267820051, 13.057712489558806, 13.339553417698031, 16.879749413459532, 21.82997668943098, 16.10940375635701, 19.308330012905984, 9.159747304454926, 11.400498344052224, 14.718422447481464, 12.369158056474502, 22.715132082662276, 32.84581407423943, 36.13758087158203, 39.34495002992692, 45.91242936349685, 53.162997307315955, 53.89298569771552, 53.2666890851913, 42.40719149189611, 54.83524491710048, 66.1413121992542, 63.61831426620484, 37.52976340632285, 51.990922497164824, 55.03758822717975, 62.44543537016838, 55.33417432538925, 58.55641318905739, 72.55134367173719, 53.40075177531089, 52.695795951351045, 59.82852412808327, 53.00966793490995, 51.79887148641771, 44.16315032589821, 33.62208643267232, 23.358165448711766, 29.08854234603144, 26.38236972593492, 24.22798437456931, 31.904409931552028, 21.833206761267878, 16.142772340005447, 19.805335498625233, 17.95962106797003, 12.014190420027703, 8.51488709449768, 8.846273441468517, 7.081260796516173, 13.521248390597682, 12.467871366008637, 15.298177196133523, 14.734652234661965, 10.736352820550243, 11.66772157915177, 10.734334761096585, 5.83426381311109, 1.4860915536842039, 0.9710499680330678, 0.17126892993767417, 0.17356668809248557, 0.11472997105410022, 0.7782234311584504, 4.86162877851917, 28.21055900666022, 59.79521143820978, 66.79641862069407, 62.864799499511726, 41.326523596240634, 24.118538479651175, 29.662510618086788, 42.15044098515665, 59.57723748299384, 37.56362130565029, 37.278963135134795, 58.9822139278535, 71.12906086829402, 81.4791210236088, 81.61906334661668, 75.77662237228887, 29.03076779457831, 0.8474689541805176, 0.3279851617351655, 0.23478489669580616, 0.24792342717128418, 0.42409129020187164, 0.4276145898526715, 0.22826993177014016, 0.30600052206746997, 0.4615375147231164, 0.3547713647205984, 0.30696937814354897, 0.2857300500956274, 0.24402927967809865, 0.3784990995641678, 0.17719331768251237, 0.1867140439008513, 0.1759595024369417, 0.11856131465925325, 0.24082608220558013, 0.16907626372431556, 0.13492040215961396, 0.16489196809068804, 0.12101214484221513, 0.1207346065090068, 0.1243671962630845, 0.17584068219988577, 0.29149571974431315, 0.5133376528899516, 0.16573425111991746, 0.10136523779721991, 0.180051407866901, 0.24565951478096748], [0.06612090318794213, 0.052566065212651614, 0.04070338139670991, 0.0963618409549517, 0.12260222927697244, 0.147538268638234, 0.14087967754852387, 0.05362319376980586, 0.012834065109341136, 0.026355715198141914, 0.07604462229796956, 0.0834430551396743, 0.04979087340254938, 0.18023525364696982, 0.17321851645265857, 0.15600521027320818, 0.07959332542433854, 0.03681649641704656, 0.029400162015771194, 0.05570230660058799, 0.17520593238934395, 0.15457219684556608, 0.24357190986554472, 0.16379781067371368, 0.17061191761205274, 0.049317247204242215, 0.13069191857451393, 0.190814039219291, 0.06506649041247946, 2.2343063402560452, 24.79516694622655, 60.835427930278165, 76.39401128215175, 62.715419953869244, 50.93272586022654, 36.32383461921446, 28.142805945488718, 21.735822154629616, 24.958121815035422, 30.230571800662627, 26.4363258500253, 31.759752919597013, 49.35135564496441, 39.356783820736794, 15.378054303507652, 5.277892764537565, 0.7458469007284411, 0.03460584245922585, 0.1827428892495171, 0.09064707018795515, 0.3262978377601793, 1.5602643090871073, 2.779828603229215, 5.77564153940447, 7.57379379964644, 4.940414976689124, 4.137238590948043, 5.77333910811332, 6.833521935247607, 7.458615851017737, 4.731249193991385, 5.664712498264929, 8.668394934746528, 8.430108985593243, 7.911629994069377, 9.138345872202228, 4.791060436156489, 6.511267356334194, 8.647312195070329, 9.495875796964093, 13.276358150666761, 13.786908561183562, 27.93875836556958, 37.28378372807657, 51.65589324889645, 58.393509311060754, 58.839086640265684, 63.57580754064745, 69.8247080464517, 66.85867448006907, 73.06653130439021, 42.76881048756261, 39.01327833052605, 67.52442621415662, 49.566474114694905, 27.619400947324692, 37.66941547393799, 46.42052927324849, 43.32886611261676, 36.95120596116589, 51.24106337947231, 49.50982332229615, 37.62133113799557, 60.04006147384644, 65.13984872448829, 44.63748647320656, 51.11665756471696, 52.11663053881738, 45.934610366821296, 40.51312208175659, 35.10059249016547, 34.198729761185184, 30.64391313060638, 26.083426283251857, 30.276212499987697, 23.011312215558945, 22.712309937323294, 16.638370675425378, 13.173716587405051, 7.673644596530546, 1.9741264562452994, 2.3771340568219466, 2.8324749008301766, 7.02251692933421, 4.9684716905317, 5.694185678035983, 4.238877988630726, 7.678323984146119, 2.3807164065299498, 2.7879204528947032, 3.178844701859259, 2.0101008420028994, 0.07253122816403067, 0.13925117380436391, 0.053064945499382676, 0.07651546759711159, 0.13763512664985272, 1.3049980517356627, 13.311212332017961, 32.73929230628475, 44.47752045046899, 52.22766891602547, 28.653314190526164, 13.28739962270183, 10.532718070091741, 19.911841577099217, 32.56029886584128, 35.37136154790079, 25.9452078419347, 43.96224260330201, 48.50278223714521, 62.973339326920055, 54.55162225231048, 38.97332899032101, 10.769788084491607, 0.05984950442648223, 0.16567045131758337, 0.06276287551548693, 0.07921717625351683, 0.06820588042178462, 0.13701416642194794, 0.05168676864536059, 0.20907421986902916, 0.10804396167758012, 0.1257737260311842, 0.010762774036265911, 0.11832801024279288, 0.1760124084689925, 0.07106934854340169, 0.10116576382349576, 0.001775294449837548, 0.07457476770204884, 0.14978872852460032, 0.05294059027707385, 0.02350345685807688, 0.0326102523643884, 0.048844605428917755, 0.07142784704844798, 0.015962932901006314, 0.09041118405518994, 0.08559062941780976, 0.09017741998597499, 0.0741861236371821, 0.03753936549107875, 0.07835770987214581, 0.053992283440405325, 0.07848472724999152, 0.0525339737895035, 0.09136032868897723, 0.10008933368108927, 0.05544863190622099, 0.08087759522060234, 0.07814353467115472, 0.02135690722254015, 0.01606539907609864, 0.025808826096416004, 0.10414640509313154, 0.025396584608261625, 0.034296645542546626, 0.012844112352468075, 0.0560748398364071, 0.09581092414596389, 0.07729016634966097, 0.07056020650892489, 0.06348155791901293, 0.0758854139055456, 0.2192579338987989, 0.10309942337053438, 0.32573807263566606, 0.00668091920106822, 0.1998827429187875, 0.08664727917001133, 0.10158934915858893, 0.12046048492794076, 0.23614402860403064, 2.9160530096100223, 28.799685278246482, 71.50552995743291, 85.2168260082122, 72.24240995222523, 60.032122596617675, 46.90070190737325, 37.507045038284794, 31.575734922962805, 30.928996878285563, 35.0831183310478, 32.47261624182425, 44.92772225410708, 49.44979144680885, 44.069060510204686, 18.67475348134195, 4.884235849303584, 0.7930277432164838, 0.10221472205293756, 0.263195880238087, 0.203521384767467, 1.4202926908769917, 4.585639046084497, 7.774780459942357, 8.23674496143095, 9.925569488156228, 8.598778747743177, 8.50288954473311, 11.054883599281313, 10.230587701643667, 9.475698144205156, 10.199630395058664, 10.134892655957131, 10.370160341262817, 8.486694078291617, 7.454638077366737, 5.291119977351158, 5.668247044086457, 6.17020256096317, 9.970648307954113, 8.05996128628331, 13.459430856089439, 14.944274483188508, 29.13363587471747, 39.79753663462978, 55.89035464871315, 61.75450986431491, 63.42838918009112, 64.38472578602453, 71.82176713020571, 66.47177188627182, 75.0536040336855, 46.929672533465975, 44.348658823197894, 69.30630407025738, 52.18163990205335, 34.586773764702585, 45.93940350317186, 53.795008813181234, 51.8041431519293, 43.87815090917772, 59.03140829455469, 54.24682663333032, 40.838408162516934, 63.59918878924463, 65.93286175881663, 51.2146266045109, 56.78634558954547, 55.005377723324685, 51.1169909661816, 42.48245393076251, 37.560561856915875, 36.67646746481619, 31.472282409667972, 27.057531226065855, 29.154049850279286, 23.99043190863825, 23.31201876363447, 18.35394282494822, 14.986386029951035, 7.462683348886429, 2.4027231095298647, 1.9319063088586255, 5.152628441010752, 10.169179074225887, 8.885129420988022, 10.853203169761166, 9.54946517944336, 12.982122532783016, 8.494884967803955, 8.026277932428545, 4.453275232545791, 4.1702085637277175, 2.0336746544607225, 0.790998284374514, 0.2830030528768417, 0.0922002598282791, 0.07345653214161435, 1.3931990414857867, 12.148355091771773, 32.24962361397282, 45.666571278725904, 45.12312296898135, 25.52418847237864, 11.857727073854017, 12.808139920234682, 32.407859871464396, 40.21698313374674, 39.896513723558, 39.8581882446043, 53.83566025764712, 55.216711105838904, 70.38060988149336, 63.12597443980556, 51.1211722127853, 14.307785591771527, 0.11205657700737638, 0.028900578843369603, 0.09493921567956287, 0.11334465426062384, 0.04230566195122177, 0.055644037953067216, 0.05482458051354174, 0.07798375937366679, 0.09138669743533097, 0.12769453828373264, 0.019228370229323066, 0.08534845370318621, 0.1539911651202748, 0.07599817438712043, 0.12630876949838094, 0.03207385675200532, 0.0584868370224872, 0.016241768795636394, 0.01839478038281443, 0.03835105479905202, 0.03641106353531923, 0.055176257005622314, 0.06698875057120478, 0.062135970445289734, 0.04999385605896673, 0.07622060035505603, 0.11996007629580076, 0.06689329601583943, 0.03971862133532282, 0.0464512471620354, 0.06480021357175804, 0.21148368896495914, 0.1601479686195812, 0.17494031438423743, 0.20796222792517757, 0.22725123401370742, 0.32510592752406675, 0.2940674769061227, 0.10686031753017057, 0.15451374433694348, 0.12676817710481345, 0.18052788391228647, 0.16561190687840985, 0.22478286807815875, 0.23995251214552313, 0.43541793080587543, 0.2016777175688936, 0.18547174040107958, 0.20410436235608595, 0.14674935129380998, 0.2996700924010046, 0.32462681613622174, 0.3486640811447175, 0.519335784258381, 0.4410757046313055, 0.47826685251728185, 0.16216415881870255, 0.1866592073272313, 0.4276984918021387, 0.21437937874467144, 4.43326477081545, 38.90475419259841, 81.0685351587111, 93.06101722102012, 83.43303403546734, 68.31945142438336, 50.30752751135057, 42.66878220342821, 32.356102235855595, 37.82695354953889, 44.863097283148, 39.904852682544345, 45.87923826709871, 63.04425577963553, 49.94812465483143, 20.567004872906594, 7.276589437838524, 1.4221314244693326, 0.4074233007286826, 0.419045222262221, 0.17743641270264504, 1.3131862446185083, 3.6480297965388147, 8.791984896506033, 13.537367370820816, 19.952944094134917, 14.714062733034934, 16.579103662121682, 16.85048068723371, 17.894623471844582, 19.998967224551787, 15.058952819916511, 17.940307317241547, 18.590253860719745, 17.984202561839936, 17.363944438196, 20.897644988952145, 14.229977534663293, 17.211305402940322, 17.177274919325306, 16.021725054710142, 18.8180592367726, 19.915314835886804, 34.295839801911384, 43.970824749239036, 61.61644635661956, 67.61216179017099, 68.91443575582197, 68.2048240784676, 71.02004251172467, 65.66306937125422, 76.65287986878427, 49.80840590692336, 46.71140047811693, 77.20731473738148, 56.10111928755238, 38.01332889064666, 52.885575909768384, 56.64503435934744, 60.15532816610029, 46.89774051789315, 63.35762962218254, 58.45057195232761, 45.49104521351476, 64.74174776384908, 70.5261847280687, 56.640860957484094, 62.690316784766416, 58.03403192950834, 52.21796889458933, 45.77092985953055, 42.90621503706902, 43.03044042279644, 38.15240436984647, 33.6746540377217, 38.480102708262784, 28.00242235583644, 28.570538451594693, 22.756377766209265, 19.46286943651015, 12.80271920465654, 6.199545321925995, 7.430032558979527, 8.565564117124005, 15.369104435366971, 14.210579452976106, 15.61479974177576, 12.957958771336465, 18.80100869363354, 11.678733633410546, 13.454894634985155, 10.146504832852273, 5.117173156430645, 1.274325729858491, 0.4334004535790413, 0.19343543887859393, 0.16955658553108094, 0.235483507595716, 2.006343211377821, 17.495079078981956, 43.350333244569846, 58.68603967851209, 66.75990135438981, 41.47222788103166, 20.194185549213042, 17.74856029018279, 31.750345114738714, 45.16890879600279, 49.73948594062559, 41.93455765324254, 61.25980484870173, 65.53908717247748, 83.53282697739141, 74.17495389138499, 65.84169018653132, 19.743997473870557, 0.39518682346228634, 0.32993359911826353, 0.2998622272524142, 0.31171296392717673, 0.20169254903110767, 0.253785394072052, 0.14817456594638287, 0.3664400789045519, 0.18959516268824378, 0.2976929113989876, 0.25618914815206684, 0.3233802072223156, 0.3815299885407571, 0.1844072305867749, 0.2901780791580677, 0.11478792560557205, 0.2012110780924559, 0.2740366065934781, 0.14523879444647222, 0.10224351163713202, 0.13497364527035144, 0.14045523419495554, 0.11534303291550568, 0.29820971431270726, 0.19909402475722376, 0.21828887863985955, 0.37989295057712064, 0.2753298549402145, 0.11931787244975568, 0.15886581322598844, 0.1584930961290675], [0.037128612128717285, 0.056020960872692455, 0.09926364411629977, 0.04489811114786614, 0.05888265550076481, 0.06741553049294219, 0.10255526345703872, 0.022860088558386893, 0.029337342805980198, 0.02553185658349145, 0.07524222180607819, 0.06244105730025519, 0.056275581685645934, 0.042503094300627715, 0.026791140422104832, 0.02469859232435063, 0.02293740215170528, 0.07089186129310439, 0.05099961075991873, 0.11055912026354384, 0.1602512525935327, 0.1411815161906904, 0.14129981548795778, 0.005840123818826772, 0.14640951469059915, 0.07600643281494418, 0.08967570900436371, 0.09518071723681304, 0.4970277941996052, 16.17895620484506, 54.89525325836674, 72.49725418706095, 65.63398107405632, 60.19118255184543, 56.78178387303507, 35.12765684435445, 24.5657455536627, 25.969389254047027, 25.79365138084658, 48.95481971002395, 25.635058187669326, 25.683291573678297, 37.75001233623874, 13.65566703581041, 3.6199993135467654, 0.6652179240219055, 0.04001049317359444, 0.10661917603424481, 0.013087962926816077, 0.9320750303806798, 1.009303741157055, 6.746771364442765, 5.026568366635231, 3.924576015241685, 8.921878107132452, 9.165722054819907, 7.736896737929314, 10.29859277509874, 7.83421858664482, 6.467806023936118, 9.814381080289042, 6.780520908294186, 9.888605071652321, 11.485330385546531, 7.3787284474219055, 7.482062799315299, 7.069290703342808, 10.666256143200783, 18.51863334255834, 17.81987290228567, 24.957170640268636, 35.86985949547061, 48.678810365738414, 55.047880526511904, 63.259550756023785, 63.33766868037563, 67.31163763230848, 66.06470046504852, 75.51683595103603, 70.86037066675001, 67.06380659534086, 64.8416034636959, 56.32565929043678, 66.8529478196175, 65.21071026402136, 38.50836338535432, 37.56873999872516, 45.075634833305116, 41.70929985661661, 23.031533994982322, 46.48428740039949, 47.68400315315493, 46.603170517952215, 67.80777039066439, 56.95023398245535, 67.29441842725201, 65.89019421608218, 62.006769257207075, 59.32249915215277, 57.676194098687944, 54.533014528213016, 49.964339733123786, 47.73735523223878, 47.02838290122248, 42.622572760428156, 46.2098156252215, 41.54026923641082, 35.691050406425234, 31.392628877393662, 29.40792133731227, 15.228263889589618, 8.293779165514055, 9.243407537860255, 12.026079124019994, 3.0037979012535465, 3.0649849147565904, 9.134303869739655, 16.437109939513668, 6.205974576934692, 5.496651684084247, 2.5030357655017608, 5.962036982659371, 3.05087786528372, 0.842151384680502, 0.051837266618085485, 0.04536109638490504, 0.07630784244787309, 0.03666853802579065, 0.5829003669561879, 6.757768219517124, 26.580255262313354, 37.24203401996244, 58.42713579054802, 66.50445307454756, 58.79664659500123, 31.493894669317434, 32.37895788684968, 31.1784262810984, 19.216915253669985, 26.488324711399695, 44.38101445474933, 55.28621550529234, 55.761218455529985, 56.596589165349165, 34.77336875854, 3.4915919457712485, 0.14100789002353145, 0.0819022071758105, 0.052635445965514074, 0.052113291927643364, 0.06463178914160499, 0.07439009454702178, 0.19079864085201295, 0.072262829259759, 0.021740991149037596, 0.07849798057108157, 0.07572937711712814, 0.023355513788579453, 0.07801597337088279, 0.07037200934944615, 0.0678691388137879, 0.08110679340578857, 0.042372269465798335, 0.021031815896651918, 0.12745684418346614, 0.015129061517185502, 0.0465909356341487, 0.010703745046480289, 0.017874440058104454, 0.030422355048358444, 0.027924626877891923, 0.04506671943912103, 0.02263474188023998, 0.02938162843366304, 0.07076888119861965, 0.03749597044060788, 0.012991392755910996, 0.05389829211297536, 0.11805049489222227, 0.10598487821557831, 0.06788726445407638, 0.0879837348756771, 0.06035395417242281, 0.016191155281698993, 0.04893094736842379, 0.022604129006785732, 0.06442012670900553, 0.03747643902897835, 0.06448278504033243, 0.10749210258044543, 0.06978661858386571, 0.04135151859372854, 0.0758493694687082, 0.04337523943714557, 0.06326810284067066, 0.03382365519721662, 0.13671051981228013, 0.07960396638560681, 0.13481348692890138, 0.0900237350874851, 0.2053586627927519, 0.13368675545338662, 0.03921722828020011, 0.0860222663369871, 0.7117824640966232, 19.18902720174482, 65.3521901561368, 83.11472585124355, 74.67598961245629, 68.55953970263081, 64.05267753908711, 39.96563765310472, 28.388817002696378, 29.067445878059637, 23.891492082226662, 43.35981361327633, 31.290351113965436, 29.358985847042455, 43.040450311476185, 16.549976141222064, 3.370247540935394, 0.6422896478925982, 0.08552768763395087, 0.33871967766073446, 0.22609811847008046, 2.1340508037997834, 5.553940842228552, 7.941468444562728, 8.56621228879498, 8.579688572114515, 10.1616540070503, 12.063039618153727, 11.742820259063475, 12.353333254014293, 12.89622752897201, 13.24954188639118, 8.928109772743719, 7.420539932866251, 10.257656958795364, 8.043823184505586, 7.307432015095988, 4.1968287094946835, 6.064648637848516, 8.865067478149168, 16.560352771512925, 18.941282456920995, 27.848679173377256, 39.12594841372582, 53.52092143028013, 59.55553500883041, 69.15630479012766, 69.09564141304263, 72.9148297156057, 70.31876194861628, 73.74667813701015, 69.56657686541158, 69.7986791979882, 68.1309344691615, 60.463548014240885, 66.12770157475626, 65.25540174976473, 44.48896200426164, 46.8347825542573, 54.27764077340403, 49.094059928770996, 30.60571316749819, 50.69785825667843, 52.18070637795233, 51.894938176678075, 68.60585504962553, 60.742008839884114, 70.8423512981784, 69.36591625213623, 64.78385833001906, 62.10080023734801, 57.305008442171165, 53.41702568915583, 49.4827825023282, 49.696265343696844, 49.870873574287664, 48.840761107783166, 48.731993782904844, 42.438711658600845, 38.70857684843002, 35.78849384861608, 29.88436968095841, 18.45773070089279, 12.214503903542797, 10.80361754663529, 6.285871296159684, 4.078044631788808, 6.0470219965903995, 3.649350164398071, 5.501433543620571, 12.139921015308751, 9.04283223613616, 8.604106307029724, 9.449379040348916, 6.901185272201416, 2.5666568548448625, 1.1346797909467452, 0.20232159914749287, 0.03584199044252596, 0.10460600422154512, 0.7097904516323921, 7.677277201606382, 27.364986212022846, 39.1575901739059, 47.8606588609757, 43.49314674254387, 41.938993853907434, 27.481513946287095, 37.80195628443072, 36.732573047760994, 25.18476813070236, 36.47413984421761, 52.301899771536554, 65.17469113872897, 65.29342912858533, 68.37845956125568, 44.97713235116775, 5.5195092962634185, 0.19098708315962748, 0.044075030112458814, 0.052311678056515036, 0.08147637720309919, 0.07610675968950795, 0.17929730155775625, 0.0629139403932758, 0.16879898586100148, 0.06282728818816043, 0.12553159628183613, 0.08278988091455353, 0.010074222828411769, 0.17883960998827414, 0.0848595517116689, 0.008729574770005721, 0.0501774222169432, 0.039448433615747965, 0.03077789070835758, 0.08467813443032005, 0.04705523854241737, 0.08101294763506421, 0.02640630572944159, 0.03526557822741809, 0.07882043463929046, 0.03698359168465099, 0.08455487088330331, 0.04319227465818967, 0.03200598327713388, 0.052338092768144225, 0.043497767539755, 0.15375864211349718, 0.18845327799358677, 0.15800736574155672, 0.29145156243635767, 0.1886551115181177, 0.20992673783292695, 0.27955627008791895, 0.16852206039813258, 0.10366415274479698, 0.18690924310395796, 0.1863013523360414, 0.17100193297430394, 0.17851952313175126, 0.15524448496439766, 0.17678491621007844, 0.14732371805416, 0.16442030307746705, 0.15701019505579628, 0.14428941232542838, 0.15049003605400363, 0.302712625914043, 0.2079969929951814, 0.3893420935398148, 0.1480485904481142, 0.41919776568970374, 0.24117943259977528, 0.22665328706704804, 0.35327920930520185, 1.096603750221191, 24.48651759855209, 76.9326860673966, 93.26691812084567, 84.32127045046899, 78.80604928539645, 75.64312842584427, 50.95217689391106, 36.28030807741227, 36.279982520687966, 40.80428746438796, 70.43377368680893, 39.469147959063136, 39.402565725388065, 50.05369132564914, 18.261739669307588, 4.902484186234013, 1.2560130415424224, 0.211458821750937, 0.27315361365195245, 0.19400565344239437, 1.9174017516836044, 5.71832541496523, 17.176955246156265, 18.96460683115067, 13.190908335870313, 21.565079419843613, 20.93907698508232, 14.849097190364716, 20.208568880634925, 17.4510092889109, 16.86728019868174, 18.221400053270404, 14.632032244436203, 20.96012834579714, 21.913493756325018, 14.466876925960666, 14.69628066785874, 14.447052286517236, 17.48994665761148, 27.206024316049394, 26.806230852680823, 35.471283928040535, 43.980866016880164, 54.74832519408196, 60.18936257208548, 69.27910635548254, 67.67120915074503, 73.72112781770768, 70.67044165826613, 74.49070469025644, 71.55965082107052, 73.32067735733526, 70.36575978802097, 61.14759368281211, 70.48216788999497, 69.64388678150793, 49.87174826283609, 50.9855091956354, 58.44307238055814, 55.43546561271914, 36.15285458103303, 55.60937173904912, 58.35056720241424, 52.993146911744155, 69.4258108446675, 64.92538529057657, 72.4301581228933, 67.75058223355201, 63.458607119898645, 63.50952732947565, 61.451820558117284, 56.56666932567474, 52.606832673472745, 50.43968785193659, 54.35983011799475, 49.55176914891889, 53.306246188379106, 48.54512030078519, 45.024165491903986, 40.54641123740904, 36.928111045591294, 20.61145905525454, 14.41274723699016, 17.853687655541208, 21.659114322354718, 13.557444022547815, 14.46491672146705, 21.306187298990068, 26.95464941763109, 18.022243668956143, 10.485225031452796, 11.505603155782147, 16.8183054847102, 8.008227675191819, 1.528879219005185, 0.8985224630563491, 0.2189738684964757, 0.1633734132854208, 0.18858072438067008, 1.177140796376813, 10.589113908429301, 36.032155406090524, 50.16912275745023, 76.13908859991258, 86.59978312830772, 76.31287313276722, 43.46557640260266, 45.1144584532707, 44.33930789270709, 30.208318233489994, 40.46271178030199, 61.299636517801595, 73.49140244145548, 75.08954078920426, 78.45553844205796, 59.88671248958957, 9.019335277618902, 0.2054684125487843, 0.2651355535753312, 0.15164541921788646, 0.2114247614818235, 0.1258333583152102, 0.30307428070133735, 0.2767486804194989, 0.3398600761448184, 0.21293933262988446, 0.2342997485351178, 0.255207835486339, 0.18278427331918673, 0.4448882790823137, 0.22824342512796003, 0.1709383936418641, 0.28174596388013134, 0.17785166300112204, 0.1466203727308781, 0.2053018037470118, 0.21210308637349837, 0.14473185874521732, 0.09467336018719981, 0.19783914209373538, 0.20404158911157042, 0.17921790420528383, 0.28029818027730913, 0.26797973160301486, 0.23456941148446453, 0.1716163354895769, 0.2035729118412541], [0.034343120266473105, 0.0639718656818713, 0.004988937890307317, 0.07574210949842969, 0.10444887192739595, 0.08091198490752328, 0.04990666376186475, 0.09478219829860235, 0.042704537120317264, 0.0679348231924157, 0.06496286935984127, 0.08859945506217981, 0.03290134279297725, 0.06811282372162228, 0.006415326572624186, 0.020840519911519462, 0.017355530402593074, 0.02681271537327238, 0.04178071552286706, 0.08586677347099589, 0.05934033557892807, 0.04890457862207005, 0.09064284904349236, 0.026025402983049714, 0.02540965023781023, 0.052002745440169695, 0.0033942205388279214, 0.4545375548543469, 1.6556649318625851, 39.44703755840179, 77.76181236390146, 70.80886994638752, 72.87244458352366, 55.13917369227256, 45.79439347790134, 52.89286367354855, 27.71190416428351, 30.62834720457754, 40.74686004269508, 41.397334144961455, 29.64591899225789, 42.141160657328946, 13.94989186717618, 3.600219291064047, 0.09014618658130208, 0.025968185791205016, 0.06780097997116466, 0.123408421904089, 1.0300928546536354, 1.480993698200872, 3.343400142846569, 6.159886237113707, 7.818486450179932, 8.602784468281655, 7.615978890849699, 7.893902842075595, 6.881028702182155, 10.23882762078316, 10.576115173678245, 9.301577268108245, 10.802506535283982, 5.630677601983471, 8.58524166768597, 3.6799211175211015, 7.173917966504251, 5.716418652765213, 12.824552097628194, 19.223106714986987, 33.94563098107615, 37.734671946494814, 52.437994249405406, 61.01222092105497, 71.0324764251709, 67.02746975806453, 70.82674026489258, 67.17755533033802, 65.80942476949384, 66.46795934246433, 67.879487006895, 60.634947746030754, 63.41331551151892, 65.28143844296856, 73.86537690316477, 74.31046393609817, 67.57681339017807, 51.145836076428814, 37.54948116117908, 43.03022469243696, 40.74517734589116, 38.244717351851925, 56.939286647304414, 57.184646591063476, 61.89954734617665, 66.17902971083119, 63.85833978652955, 66.95114043451125, 58.13227553521433, 57.60260651188513, 58.33785480068576, 62.735561324704086, 64.0708577248358, 66.37667794381419, 66.25083261920561, 61.98574143071329, 59.16449039213119, 62.23044633865357, 65.65154544768795, 57.719744174711174, 49.90824199491932, 42.98508997886412, 34.89717445065899, 33.22765288814422, 30.2895446362034, 21.122269322795255, 5.612748938222086, 8.511074550690191, 7.673516138907402, 6.5627974944729965, 8.510916675290755, 7.179227384828753, 4.185505317103479, 5.157366173882639, 5.324869030906308, 2.616342008113861, 1.5265034884214403, 0.07608249768494599, 0.21017504225094474, 0.08722398249853043, 0.04140815930441022, 0.24831940269758626, 4.228931838466275, 22.061576958625547, 38.856101112981, 41.29401891462265, 36.258923315232806, 51.49715100565265, 70.39138070998654, 58.48335119985766, 37.533407288212935, 33.00249315077259, 32.79537631619361, 34.679459371874415, 52.64682908211985, 57.08553221917922, 53.582188852371715, 23.751716459951094, 0.5928588971014946, 0.0425502163688502, 0.0706148668823223, 0.03886048411650043, 0.04294388214006059, 0.21957722402388052, 0.10007844757168524, 0.026190100395451152, 0.10280162967260807, 0.020705326460301876, 0.12342598830019275, 0.10469775857223619, 0.06350137278317444, 0.04974793417439346, 0.03410212049681333, 0.039240004074188976, 0.10167703558240207, 0.02466971464004488, 0.0033480819359782243, 0.08066632349284426, 0.04449285063592177, 0.03425572495607119, 0.0317846508997102, 0.05592425376357091, 0.053151819869996085, 0.037594094812389345, 0.04359048716123066, 0.08230042733973073, 0.09223710865743699, 0.061069664154802604, 0.00859223435738034, 0.023492551596474745, 0.04258415789433545, 0.07211194824307196, 0.07849079466635182, 0.0956672979819198, 0.07124005591556912, 0.1513519462558531, 0.031270217112896424, 0.037577030203876, 0.03525528583615538, 0.0385013344367185, 0.04848846647467825, 0.06195687824079107, 0.026854040071127877, 0.06633941444658464, 0.07626470403685685, 0.023779920752971404, 0.0288488908911184, 0.046717596781109615, 0.04423959345947351, 0.055105240655041514, 0.09996190261576446, 0.03763927101728417, 0.16331140612882955, 0.1426666848842175, 0.0364961069557936, 0.28864924345285664, 3.3573414721796593, 49.139065204128144, 88.56448265814012, 80.65091256172427, 78.07764945491668, 66.07526733029273, 53.52352980644473, 56.45125358335434, 35.0742341626075, 36.15894602191064, 39.1011001986842, 44.175297906321866, 27.372746621408773, 38.30403143359769, 17.109490479192427, 3.564130543701111, 0.07881122626244061, 0.05086666003109948, 0.24629067930002368, 0.6204462135511061, 1.5129216688294567, 4.577946297584042, 6.3568563903531725, 8.836939181050948, 11.622567253728068, 11.694411346989295, 5.97039653408912, 10.884130077977336, 12.25994554258162, 11.9158056089955, 14.525141773685334, 11.148816520167935, 7.54327726940955, 6.945875777352241, 9.039278568760041, 5.732058613531052, 6.680034197145893, 7.7268868492495635, 13.557132194119117, 18.714377264822684, 32.55144411517728, 41.51982192070254, 53.79909984527096, 62.395244721443426, 69.30369177172261, 67.85545072247906, 71.89666086627592, 69.5890598912393, 69.5512717769992, 67.80708005351406, 67.99777784655171, 64.17236866489534, 64.50965719838297, 65.70150859894292, 74.67481290140461, 72.75470287569108, 67.17674732208252, 54.94886813625213, 43.551899925354995, 47.87027651263822, 47.238669010900686, 43.85438526830366, 60.910572698039395, 59.35891051446239, 66.11092167515909, 67.03380046352264, 64.88341592973279, 67.90030694776966, 61.39810369860742, 58.898541927337654, 58.8104651051183, 63.43512781204716, 64.2792885534225, 68.04418733043056, 64.7295609597237, 62.56513041834678, 59.21392794578307, 62.771807947466456, 69.00590542824038, 61.28993649636546, 56.16395958008305, 48.44187175073932, 40.466889104535504, 35.007055728666245, 28.139028703012777, 19.902018001002652, 11.330131023160874, 11.389076402110438, 6.916733057268205, 8.290411810721121, 6.812664241560045, 5.4116269561552235, 7.925918698310853, 10.909090080568868, 10.127212655159736, 8.886744456906474, 2.9212896189382, 0.8670973525412622, 0.19676989785605864, 0.0930707119104843, 0.05928148470458485, 0.11901607211198538, 3.8561389907713863, 21.896515777034146, 43.19732550651797, 45.20001711383943, 37.12383731718987, 39.30660886149253, 60.29345835408857, 57.18816495710804, 41.825958990281634, 40.273163241724816, 42.79463145040697, 42.74268750221499, 60.89276513745708, 67.18486662833922, 61.89296168665733, 29.270608963504916, 0.6624964732796915, 0.058376225417539965, 0.0239192146898037, 0.0067273364684003745, 0.05003557337688343, 0.19145657248314352, 0.018809595926394387, 0.03971872858763222, 0.09768174916145303, 0.007331070251717804, 0.09731703002246157, 0.028016810237820593, 0.05353308267771237, 0.08940971561617429, 0.08623215144560223, 0.02996994182467461, 0.06579825759775217, 0.04436426277783129, 0.034494824827678745, 0.050412683988050114, 0.052516943654946746, 0.08310972262294063, 0.04597089471175306, 0.07071314830212824, 0.030412907269032254, 0.024334934217134313, 0.0228098523427522, 0.04487188412777839, 0.014137998467401392, 0.0804508995685366, 0.10634739102134783, 0.09889463488493236, 0.2332170671152492, 0.22890599925191174, 0.18421690370286667, 0.16162187582062137, 0.12910418602968418, 0.2946368947384819, 0.17226265322777534, 0.10147288081146057, 0.30654910230828875, 0.2309519902712876, 0.198790853122069, 0.13631635225347935, 0.0894088422759406, 0.11910786476707268, 0.16526656976390272, 0.11170996818691493, 0.16757021147397258, 0.17401483420643116, 0.12788679570921008, 0.26966978285101156, 0.29392155247830576, 0.2397981760722976, 0.23044888500965413, 0.22152117213174222, 0.16043460807732998, 0.5555589340867535, 5.871139485989848, 60.76922224413965, 100.43241377799743, 90.12629985809328, 88.72817885491156, 76.4754867553711, 60.541116806768606, 66.65017697118944, 41.81701990865892, 44.66313485176333, 59.13900283075149, 55.965934799563506, 41.356831750562115, 55.21764070756974, 18.154806052484822, 5.263897747762742, 0.23414922757975518, 0.13513933476661483, 0.2189982454142263, 0.5000986423223249, 2.019948810338974, 6.605035537673581, 10.250952647578332, 17.010191755910075, 18.35164039365707, 21.159776987568026, 16.60654652503229, 15.126416606287803, 17.499452521724088, 19.735140762021466, 22.42675550522343, 16.778626788047053, 23.200264553869925, 17.392711101039765, 15.249587855031415, 12.155674234513315, 17.875851008199877, 12.41192561964835, 19.411007858091786, 24.728927919941565, 39.25080137868082, 44.73429841379966, 58.323867628651286, 62.719055991018976, 73.1550827334004, 68.89924833851477, 75.98060915547033, 71.8266857824018, 70.84828192187895, 69.02606641092609, 67.99397314748457, 64.43572836537516, 68.19324524171891, 68.28604067525556, 71.48309400004726, 74.58298237093034, 68.58119118598201, 57.93766713911488, 48.25276251762144, 54.81929655997984, 52.30221356115034, 50.656951858151345, 66.22532152360486, 66.24630620402675, 67.3414868693198, 68.93831514543103, 66.12175526157503, 66.77970147901966, 59.45423195439001, 60.94984346820463, 59.61160529044367, 64.88875819790748, 65.52652774318572, 73.29591151206725, 68.72769171191801, 63.352346189560436, 58.39534890267157, 65.29053834176833, 71.28957210048553, 64.69408312151509, 59.447771810716205, 53.243099950974994, 44.04296498144827, 41.15633979920418, 35.59145358300979, 29.386085502562988, 14.038650201212976, 16.898702306132165, 16.43046348325668, 20.44824727119938, 22.000548801114483, 16.652583383744766, 13.69256575261393, 14.436914920806887, 16.924811563184186, 11.648439207384664, 3.097243957942532, 0.6391749795406096, 0.44080236445992227, 0.29797811061143875, 0.24517623587481438, 0.6544939188226577, 5.946718165951391, 27.87792240419696, 52.88871772827641, 53.812581031553215, 50.24719361336001, 64.25229087952646, 83.28378000567037, 71.24014239157401, 51.78678666391681, 45.27773103406353, 45.0127435499622, 51.26138910170525, 71.53564591561594, 78.59803030567785, 74.62967426546159, 34.667680494246945, 1.4717469556677727, 0.2064719111207993, 0.18233091780735602, 0.0887246797942827, 0.14133081140537418, 0.338677604111933, 0.14066330367519012, 0.09601117186849156, 0.17260515581696265, 0.13564976382880442, 0.20734180395881976, 0.1933500813620706, 0.16314496586640037, 0.15533410192977998, 0.10781728392166477, 0.11767380179897433, 0.23351578011868462, 0.16142283085613482, 0.21417584450494861, 0.11793126862856651, 0.16172189626001543, 0.11833860523878567, 0.12420978817728259, 0.19141285950618406, 0.10667444927798164, 0.1586003944037422, 0.13389284842677657, 0.14062970305883116, 0.21787980301005228, 0.15653877519071102], [0.06025700957604474, 0.02564534867903398, 0.05361093636301737, 0.02593392059357176, 0.0808300901084177, 0.020144967617647305, 0.023884338537050832, 0.054677127740315856, 0.044723914245203625, 0.05948700694247119, 0.05959453121308358, 0.008509110944766191, 0.09591022446270912, 0.07522929024191634, 0.06218144542447502, 0.039814481917288036, 0.110742062059862, 0.023205563568720416, 0.07118513507227744, 0.09927011755925995, 0.04034434663011663, 0.08978791024175384, 0.04883378060654767, 0.07744060303535193, 0.06169422116551188, 0.02844860995068185, 0.04977609173605039, 0.5674690272538894, 22.590932192340976, 66.70680815173735, 75.05841285951676, 67.99801318876206, 50.071243932170255, 40.737618938569106, 40.25364552774737, 31.766244442232196, 21.61523280605193, 35.95531225204468, 36.745046184908965, 30.080209701291977, 46.993516952760764, 17.03663637561183, 2.4900931696737967, 0.31299646763551625, 0.0420664165229086, 0.12033375100262704, 0.15999642110640006, 0.9173969083255338, 2.6048227423621766, 3.7150400588589334, 6.161132079939689, 4.436942483148267, 4.843925160746421, 6.5630544097192836, 7.200700400337097, 11.65649869749623, 16.767677491711034, 11.013985045494573, 17.506924636902347, 16.362128930707133, 5.840494007833543, 6.97790143951293, 9.51653492066168, 9.851538673523935, 18.019168530741048, 21.072204189915812, 32.69341822593443, 40.160614752000384, 54.06988851485714, 63.64583361533381, 67.14063798227619, 69.07733178907826, 64.6203778636071, 63.660365996822236, 66.79859945850988, 65.79555526856454, 64.96120829736033, 60.56715349997244, 61.31230185108801, 66.21149124637728, 64.63141933564218, 60.97517021240727, 68.07200477969262, 67.99609907211797, 65.36181173016949, 60.654057533510276, 37.03052805316064, 39.72499632066296, 37.3210423223434, 47.375963734042266, 61.07606141797958, 59.390007065188506, 64.23630329870409, 62.99056637671686, 64.16947787807834, 62.71352544907601, 63.14613934486144, 59.272626215411776, 67.84242060876662, 64.43322589320522, 63.3812266011392, 63.57982012533373, 63.914668944574174, 63.642985974588704, 62.997104967794115, 62.9443726231975, 65.56755965755832, 61.139184121162664, 69.22719770862211, 62.39384443529191, 56.424997237420854, 50.26130237886983, 48.87942391057169, 33.75388591520248, 30.44497443783668, 24.11874048171505, 10.102957698606676, 2.3335903546502514, 4.443800257098291, 10.36252054475969, 7.96853328904798, 7.548051284205529, 8.616244081527956, 7.667529131135634, 1.2402779632999053, 1.242027585544894, 0.23019564698540398, 0.08021145878780274, 0.17969399720670717, 0.06981812778019136, 0.48358809923933405, 4.310633338266804, 20.966162912307247, 43.211630390536406, 46.79089515439926, 67.7255339776316, 102.21964174701323, 79.45805703440021, 57.11184740066529, 19.231392721976004, 15.382162986263154, 30.74524952519325, 46.615737791984316, 54.28965499324184, 63.828718046988214, 39.61243606382801, 5.067357584353417, 0.04239318366613119, 0.07074788272861512, 0.14622087320012433, 0.0589534726684853, 0.01993329943938842, 0.05369060567670292, 0.04615942894991848, 0.03997629883909418, 0.0889699275214826, 0.08489003435017602, 0.011181952450574647, 0.05757570184106308, 0.07633863918242917, 0.0411352404813853, 0.02765361178335884, 0.06377957378243727, 0.012599222771372768, 0.0645066180356568, 0.07615587358633358, 0.0450210414466358, 0.024744842967559254, 0.010382515761340338, 0.06002033437271753, 0.054143298522479115, 0.03725127429671345, 0.045468030767815734, 0.05174265092899723, 0.024346630464518265, 0.04479219949233436, 0.017011978272949497, 0.04161400329922477, 0.07122988226793467, 0.08520916359679354, 0.06994023453444242, 0.021170043056049657, 0.022397202912778146, 0.05960716017251534, 0.010617751676979805, 0.004483632041111348, 0.05921478908989699, 0.02794842922969932, 0.09454112575058976, 0.05989951081573964, 0.07295764036356442, 0.09043108701946274, 0.055008165823716315, 0.0227882505785073, 0.07873796527424166, 0.11479943224619474, 0.03998219771611114, 0.07643209424831214, 0.030173715466873783, 0.07448826871451832, 0.06185452123322795, 0.05616107069316411, 0.08119645633644636, 0.865705891722633, 29.5131742185162, 77.15713193339687, 84.36535789120583, 75.16991799877536, 63.54589946808354, 47.79595544261318, 49.75979597337785, 40.73232766120665, 30.07602257113303, 33.30562176242952, 39.36740167679326, 31.5502610898787, 39.265161175881666, 19.659772419160415, 2.940345228679719, 0.08549427087869375, 0.041500350325218135, 0.32786289410245034, 0.390809059984261, 2.626572039819533, 4.341486702042242, 7.765346179085394, 12.525517459838623, 10.804720713246255, 8.75360744614755, 12.5869192231086, 7.908422475860966, 10.122077292011632, 12.053116021617768, 10.095821926670691, 12.00391577136132, 11.245519614988758, 5.0502977255851995, 4.557542127947654, 6.609103525838544, 9.974550085683024, 18.22388879714474, 22.61745918181635, 30.928475203052646, 40.86756706237793, 55.94347923032699, 65.59845616740566, 68.63060520541283, 71.33050595560383, 67.54898809617566, 66.33292782691218, 68.83802798486525, 68.72745636970767, 67.20549829544561, 66.07402001657795, 63.98518923790225, 68.49994321023264, 65.20126911901659, 62.93995603438347, 67.57979439150903, 69.03352675899383, 65.02422117417859, 62.17578811030235, 42.52187767336446, 45.0435459229254, 43.38336352379092, 52.139984330823346, 63.18964235244259, 63.71738941438737, 66.14531301682996, 63.73703264421033, 64.94231816261046, 64.7634933840844, 61.39937062417308, 60.79146600538685, 68.0024690012778, 64.52016130570443, 64.48107096456712, 64.86115647900489, 67.02216671359155, 64.97608192505376, 65.224815107161, 65.80748711862873, 68.05742140739196, 63.02485573676325, 71.51528096968129, 65.18564631862026, 60.900551042249134, 54.12303663069203, 47.669168749163234, 35.0062124190792, 28.190974612389844, 22.392517135989284, 15.478821954419537, 6.904488398182777, 8.763840909927122, 12.065886278306285, 12.451682763714945, 11.585957811724755, 9.540153472654282, 15.290305979790228, 9.285333752632141, 5.196866892999219, 1.3594019388960255, 0.3213141293775651, 0.11823501482966448, 0.033965829624644214, 0.1414678951785449, 3.9988826215267186, 20.74157584098078, 40.533475260580744, 41.97531500170308, 61.88681925496748, 92.02291488647462, 76.91285456380537, 62.54417711688627, 29.32325109358757, 20.19347560021185, 37.93429705404466, 53.64384851148052, 61.99226433230985, 71.0551320352862, 47.12519091944541, 6.527213261973474, 0.1497525538528158, 0.03931851276466924, 0.041411667987103426, 0.07179969846601449, 0.09756325834220457, 0.0837199959243017, 0.049768472991643414, 0.07154021682518144, 0.056189473402956804, 0.019257322607201435, 0.03047399512011438, 0.02105978768198721, 0.07441022733767187, 0.025453870748019507, 0.01663070397391435, 0.047848721770870115, 0.0715631534976344, 0.027604174214385213, 0.01726256563298164, 0.09693387880801194, 0.02550445170322013, 0.08174189561677557, 0.04230502992868424, 0.05598673589467522, 0.02689113787886116, 0.02260690032985182, 0.06411886263278223, 0.010854616487068276, 0.06328872975803192, 0.21472370462311854, 0.16708109497783646, 0.1498613843033391, 0.23365644918334103, 0.2534091070054039, 0.09873584784086674, 0.11562051762255932, 0.13484714883229426, 0.14608818677163896, 0.16748551279306415, 0.12938943120741075, 0.17844610126508823, 0.18798124525816212, 0.15247193615763419, 0.1260711979721823, 0.18090386454376484, 0.1863900346741561, 0.1376991562785641, 0.16119435279359742, 0.2619641947169458, 0.1251012157468546, 0.18671666392155234, 0.1909783344355322, 0.18334478920986577, 0.2712751967051337, 0.2064141021260331, 0.19396682810639182, 1.5617750344737884, 37.87027612809212, 90.95785802410495, 92.90948037178286, 85.85540356174593, 70.32325698483375, 56.814076746663744, 55.0566940922891, 43.34193152766074, 32.12143663437136, 49.57582504518571, 51.10649862597066, 40.19428829992972, 60.46361077216364, 22.50682088636583, 3.655128060810028, 0.7655937056387625, 0.17830310329314203, 0.4557844395599058, 0.22643043208987484, 3.5842775529430764, 8.786403363750829, 12.758569986589494, 16.750813261155162, 15.797905787344902, 17.02311988799803, 14.963765721167288, 15.56171634504872, 18.640570025290213, 25.9882656605013, 19.50950053430373, 29.235178193738385, 26.563716588481782, 15.611278433953563, 21.088640882122903, 17.315199182879542, 17.786868118470718, 27.043577394177838, 26.340649435597083, 37.89400254526446, 43.64656240709367, 57.5641986631578, 65.1220529310165, 70.08537307862314, 74.77071485211773, 71.6526266836351, 69.933224339639, 72.60009088823873, 71.96036800261467, 70.82757180736911, 67.21466095216813, 65.51942040843349, 67.7007681323636, 66.93216400761759, 66.6546327837052, 67.48699111323204, 68.2535477607481, 66.03577690739786, 63.6193536943005, 47.82192545552408, 49.81659973821333, 48.32240027766074, 57.81435174326743, 66.27522976167741, 67.08885485126127, 66.6402925983552, 65.78905982355919, 65.75259747043734, 62.192611155971406, 64.62905414642827, 60.82031896037441, 69.89269056627828, 68.6121779103433, 68.50712899238833, 69.56956571148288, 70.92349729230328, 68.11832012668734, 67.45417656437044, 67.95089767825219, 72.06668776850547, 67.98344550594207, 75.39973751191171, 67.59610360668552, 65.52181697660878, 59.40342157117782, 55.950323766277684, 38.08085249316308, 35.72661061440745, 31.24745607376099, 13.904114865487623, 7.816769922933272, 14.318126920730839, 22.441005476059456, 22.558776601668328, 17.96202744207075, 20.468582799357755, 13.642128975160661, 8.007365734346452, 3.7867270121651315, 0.8713952896575775, 0.41303903164882816, 0.3112428310898043, 0.2268850133423844, 0.820041535602462, 6.840162507949337, 29.112068722324988, 58.100198391945135, 57.51023469432708, 74.51718068891957, 102.91876500652683, 86.02892137342884, 66.43618814406857, 30.64185976982117, 29.202171448738348, 46.98670771814162, 63.428244052394746, 72.96012524635562, 80.21975778764295, 55.24534440809681, 8.684270728018976, 0.22215328659982453, 0.1345490793427152, 0.24400347783680887, 0.1455935697642065, 0.17927591238291035, 0.12383524013022262, 0.1481150409146663, 0.17310528865744992, 0.18840689903065083, 0.3303874908916412, 0.11108741449612765, 0.1400932729724915, 0.1656776525440716, 0.0932380868001811, 0.10647112188199837, 0.16382064009385724, 0.1218415882378336, 0.12149769902950334, 0.19177045402747972, 0.23278379842879313, 0.08764953667958898, 0.2153752624027191, 0.11843087286838602, 0.19122507603418445, 0.11684740743329448, 0.14831267627737216, 0.1741668260506084, 0.13243046318811755, 0.14405137348559596], [0.014602816569799138, 0.010682042733195328, 0.02738808379358342, 0.032987772832594575, 0.06345706608807368, 0.0640375845344557, 0.02736736494567125, 0.01335902302901471, 0.04688399107826333, 0.08443423501786687, 0.039834312103208036, 0.05231761140748859, 0.04734811012543017, 0.050993443752128276, 0.02720609003107154, 0.0038220205545170054, 0.044376022227468996, 0.06592855383191379, 0.0718367311562742, 0.08268396925902174, 0.03182443384561808, 0.04965139943505487, 0.024327652551414027, 0.03336839212645446, 0.04300619190138194, 0.035780718730342005, 0.07234445592809109, 7.308938205242158, 50.91354154771375, 73.46942147900982, 69.75170489280455, 54.739609687559074, 51.235560294120546, 41.053734517866566, 16.535932094820087, 20.603533906321374, 24.97105386949355, 42.69853338118523, 40.125101612460234, 41.740012015065844, 27.344466332466375, 2.9954305050834535, 0.6388841725645528, 0.07419128706979175, 0.04144185951219932, 0.15777046071185222, 0.3531755422872882, 0.5134804516790376, 1.0681433999730696, 3.7722201260828205, 8.109050729582387, 6.619974374771119, 9.425761468948858, 11.811461737079005, 3.901391865745668, 8.846637241301998, 7.632184653512894, 10.242498959264449, 14.55223652624315, 9.747895925275742, 7.100536794431749, 11.623537059753172, 27.639977701248664, 28.905057791740667, 35.649614487924886, 44.24568091669391, 51.631598088049124, 60.861025318022705, 62.61119081128029, 62.465215882947376, 65.25796697985741, 60.46179471477386, 63.79198897269465, 59.73254372996669, 61.44922394906322, 60.26566051667737, 66.53939354804255, 65.8783878818635, 68.3337131623299, 63.95373967386062, 62.62887677838726, 60.67362623829996, 64.64223723257741, 66.01781245200866, 63.51661505237703, 61.57440639311268, 48.986202593772646, 33.17879976764802, 31.797813638564083, 47.824627968572806, 63.34536829302388, 62.04176464388448, 63.149645943795484, 59.00398700468002, 63.528527290590354, 60.44713289506974, 59.90816393206197, 63.19377653060421, 63.0024629254495, 61.08895032636581, 60.803601818699995, 60.81401963387767, 60.98137932439005, 61.453597391805346, 64.48122393700385, 62.6859276525436, 61.82787387601791, 57.93461161275064, 60.32763396539996, 63.24237469703921, 67.63597057711694, 57.92329949717368, 55.5991304305292, 56.02291899342691, 48.47652196884156, 45.20604579679428, 35.09413626886184, 24.591013462312763, 11.95721112912701, 7.421048370099838, 6.081649170767877, 10.851809747757452, 4.976691017227789, 11.304736618072758, 5.483006738847302, 2.6523128392234927, 1.8282823144428193, 0.3957730032984288, 0.020400496244791056, 0.07614248236941715, 0.14161469294659554, 0.34977322324149074, 6.769692224840965, 32.38578869450477, 57.76143112490254, 73.25690746307373, 87.3030327212426, 85.29251990779754, 51.400009585965066, 20.39116305689658, 20.80721082225923, 24.223720758192, 39.44432720061272, 54.89472373839348, 59.94916446747319, 55.5385180442564, 13.89525423126836, 0.5755908462789752, 0.10523265648272731, 0.07141008146948392, 0.016777925005543138, 0.06617078317269202, 0.04151544225732646, 0.06786608978384925, 0.04314436351940517, 0.09051659775357093, 0.06531539237907817, 0.0507178666040061, 0.020605070448871103, 0.03932259601330565, 0.02077741533397667, 0.052155143310946804, 0.01578805130726147, 0.019790073556284753, 0.05463807640837566, 0.05810906374526601, 0.037877880592620185, 0.02639317881285904, 0.036860006380706065, 0.04765633411044556, 0.027512025328413136, 0.025753937811861118, 0.035878640088823535, 0.003569957517620717, 0.07581701757566583, 0.016802713695553043, 0.033852532881522374, 0.02123230493687574, 0.05064827900740409, 0.05324074735624656, 0.04548658924778143, 0.07525510740496459, 0.04558511964616276, 0.06988662370150128, 0.056441642734552586, 0.04651147316420271, 0.05021402589796532, 0.09652288029751471, 0.04990134328123062, 0.020697889661776925, 0.06972546944574964, 0.046057060451036504, 0.06172548138326215, 0.034207978526190404, 0.022852969686350515, 0.038192708255542863, 0.06573208292285282, 0.05546473507438937, 0.05385131177101886, 0.1010292316336305, 0.020908230592706994, 0.04205309425390536, 0.04665726352663291, 9.396695725379452, 59.16055625484836, 82.3563277336859, 78.87818167286535, 62.99458288377332, 60.02398760088029, 50.57546461782148, 30.51809722377408, 31.942960946790635, 28.020255411824873, 44.005055273732836, 39.76703628416985, 38.25325635171706, 24.785563022859638, 4.159577959968198, 0.41192912346413063, 0.04888926835490331, 0.14165056118321034, 0.3558082494043535, 3.6951117217540745, 5.627467632293702, 6.057786941528321, 8.53229457332242, 10.360890799953092, 9.64774408648091, 16.542174546949326, 15.73251203183205, 12.306598213411148, 10.803563614045421, 9.663075650891951, 7.193335660042302, 10.962080321004315, 9.23972737404608, 6.509924434846448, 11.736207142952951, 22.756640565010812, 27.07651745888495, 34.34454779471121, 44.509221046201645, 50.118520259857185, 59.259239166013664, 62.459728487076305, 63.16842625218054, 66.96915195834252, 63.33199693310646, 64.85898740829961, 62.92651407180294, 63.63119140748055, 64.13140343081567, 67.53472635822912, 67.98045665987077, 67.20541984804215, 64.92494598511728, 63.47786595744472, 61.93686085362589, 64.48078070917438, 64.76514862429711, 62.35852741426038, 61.65343822971467, 53.08818594101937, 39.1963549583189, 37.716911454354566, 50.04525822977866, 65.25855533538326, 62.52386708413402, 64.73138093948364, 62.15780796543245, 63.265348019138465, 60.88078621895083, 61.238235735124164, 64.08780628635039, 64.49156722714825, 62.67720430128036, 62.07488513761952, 63.04216515633368, 62.512288247385335, 62.09760742802774, 65.71387190972605, 65.67252620573967, 63.92699303165559, 60.41527540453019, 61.97002449343282, 65.52460970417147, 69.75463882569345, 59.082756042480476, 59.924869306625865, 56.96398581227949, 47.1298114715084, 43.099352544353856, 34.18422483628796, 24.873445687755463, 12.931076807360496, 7.847829701439028, 8.27031848892089, 14.716576972315389, 11.731848409098964, 13.31118977838947, 10.759853701437674, 10.40951152001658, 7.044954357608673, 2.3824076835186254, 0.1364071336725066, 0.17102470110741355, 0.07819952803754038, 0.271339854525943, 6.706271421524787, 31.840445879966985, 62.14542504279845, 77.84266025789323, 94.21369983303933, 93.88238506932413, 56.547779190924864, 25.342594500510927, 32.12647295767261, 33.260930276686146, 44.84120261284613, 61.60405558924521, 67.66889495234336, 64.0152895066046, 17.897877077902518, 0.7453422632909591, 0.05585338680013534, 0.017696177143783822, 0.09658727764842973, 0.058328793083708134, 0.02527695614844561, 0.04618749075058488, 0.022244716941889738, 0.14890299298830573, 0.030186365493723465, 0.05570411839852891, 0.06278287041031065, 0.02889183203449413, 0.03841406553082409, 0.01919554910742708, 0.004426369362796147, 0.03515869364022248, 0.02895487149456336, 0.0355694048677481, 0.06415131028681513, 0.08293830278900363, 0.0226501191801001, 0.027618745206705028, 0.010524642308272663, 0.058479892435453595, 0.030286135039322322, 0.006818238067470732, 0.09621495891722942, 0.03253371635031316, 0.14892000014022475, 0.12826106796461728, 0.20451005187726792, 0.1439557350691288, 0.18706489684841326, 0.09372078347951175, 0.1773048447625291, 0.1580252615554679, 0.16188127319178275, 0.16521341858371613, 0.16955379697103656, 0.1439709342535465, 0.1339448657968352, 0.0830696485636215, 0.11124086956824027, 0.09671329911197386, 0.2402887481354898, 0.2024633867005187, 0.11578561723112099, 0.16308930191782214, 0.13497971268671174, 0.159833045195668, 0.09721212960298985, 0.12498707630701604, 0.1652776627170463, 0.14904528615936158, 0.21415067085575676, 13.266361990282613, 67.87565092886648, 91.79988107373639, 89.59615230560304, 73.23630717492873, 66.20614113346224, 57.20906334538614, 26.844836781101844, 29.89859807875849, 37.15088990426833, 56.30302329217234, 55.67958608750374, 56.49572933873823, 34.1472251184525, 4.2957969730900185, 1.3262211387195897, 0.17449556970067565, 0.23219444698864417, 0.1882177366003875, 3.61150689182743, 4.652175682206308, 10.254345497777386, 14.586803393979228, 17.83479359842116, 14.815045133713754, 20.387980053501746, 22.348108060898323, 10.853411055380299, 18.946250138744233, 14.635448628856292, 21.056628457961544, 24.051944478865593, 17.441542648500015, 13.88028548609826, 17.367613815492202, 36.15116011711859, 34.1991102310919, 40.37905154689666, 48.47259959866924, 54.782332143475934, 63.337821652812345, 64.10091876983643, 65.48384058860042, 70.40697605379167, 66.43110475232525, 70.81160776076779, 64.58793593991187, 67.04514395806098, 65.63180023624052, 71.59597981360652, 69.38508879753851, 68.51630733859155, 64.29222060788062, 64.5332149536379, 64.49255566443166, 64.93575995968234, 65.36950742044758, 62.64081647319179, 61.78221748721216, 57.19972418200586, 43.3404214151444, 43.79347870426793, 54.73784462098153, 67.08298698548349, 64.53315611808532, 65.7776653382086, 64.37383336405601, 63.01852110893496, 61.15063744206583, 62.27387482120145, 66.118727191802, 67.1155426579137, 63.787603762842, 63.26805053218719, 66.06917196704497, 67.07790359374016, 64.81679447235601, 71.07224141397785, 67.48426114359211, 68.15760658633324, 63.146947353116936, 65.52535887687438, 68.16031302175215, 72.42037573168355, 61.401218060524236, 63.72434769907306, 63.01272776819045, 52.2094298947242, 47.364682997426684, 40.06321053351126, 31.255320425956484, 19.407593434856786, 12.893075904538556, 14.864500338031402, 22.67472774751725, 19.347063418357603, 24.242759943008426, 17.677339853778964, 12.742356869482226, 5.185418475058771, 2.1382114579600673, 0.1744813357870425, 0.24723669063420067, 0.25398016426592107, 0.6969706750204486, 9.77799423279301, 41.79340724022158, 69.83607507521107, 81.96176867331229, 93.26624347317605, 91.20869359662457, 60.214399060895374, 31.780400276184086, 32.21232775718936, 36.8537546742347, 55.53279138380482, 71.8274937906573, 78.93953538710072, 72.7029981920796, 24.357418667885568, 0.9819945452674743, 0.22330381276626743, 0.20280915282426343, 0.18837964162230494, 0.17088507392233418, 0.1629467942421475, 0.1589486579741201, 0.11286884471173249, 0.3275861525006833, 0.1463674104982807, 0.12084729038178922, 0.14622381497775355, 0.13813605622178124, 0.14475389143391965, 0.1433341313273676, 0.10830423238897517, 0.08941052000849478, 0.12923791433774656, 0.19488147580094878, 0.17209066648877439, 0.22674241373615883, 0.18448733274013768, 0.14696806939619203, 0.11045821882303684, 0.10734484515964024, 0.15038479089496598, 0.07735139209656947, 0.18310420695812474, 0.1526031976625804], [0.022678307385274002, 0.06936661087937894, 0.036761280629904046, 0.036800010204916044, 0.016886745879967368, 0.011887404515648322, 0.02918851682015004, 0.021351730383391825, 0.045779533609147036, 0.034793150956712426, 0.034710030416927995, 0.010223774682550181, 0.08886481259739207, 0.005577775572742066, 0.02336366113365418, 0.0622779610116155, 0.03506570588797331, 0.017408319606235432, 0.021430365478379593, 0.04982380752241419, 0.1238261083621652, 0.030093967629175995, 0.03299262599959489, 0.013340148537780249, 0.027444456373491598, 0.022482646614192955, 0.6389210060719521, 18.478629089170887, 62.2731178037582, 69.11271941277289, 64.49044935164913, 44.65219143898257, 48.05351787997831, 27.163313627243046, 19.33881663507031, 21.818850886437204, 45.58540959512034, 46.08156196532711, 40.66470207706575, 25.688975088057983, 6.588446853622314, 0.3763797632869213, 0.029906212885473526, 0.03411594072296735, 0.09474570186988962, 0.4959109605800721, 3.7095882094675496, 5.117182962356075, 4.7640210870773565, 8.959051389848034, 11.91585954158537, 10.394430987296566, 7.523152568647939, 15.914669844412035, 11.201270376482318, 8.84315319599644, 14.692407327313578, 15.205831854574143, 20.150957107543945, 33.229268904655214, 32.31195203719601, 42.91111799978441, 45.81802183581937, 54.04227895121421, 55.40591055347074, 61.02284662185177, 57.925280294110706, 60.5033443820092, 60.02032802950952, 65.14254339279668, 61.79803248374694, 63.4741279386705, 58.209765880338615, 58.82297746596798, 58.29135510229296, 62.02567900380781, 63.541812358363984, 66.01424309515184, 65.7894677500571, 65.28046569516583, 61.24922621634699, 58.07809583602413, 59.82108731423656, 60.193151581671934, 62.24386084464289, 64.14459436170517, 51.10973850373299, 32.02704871854475, 30.658696543785837, 55.38515729288901, 62.31983715488065, 58.93586720189741, 57.33201396080756, 57.999730802351436, 64.07481147396949, 60.69573271659113, 60.09710058089226, 61.5113542925927, 62.67074415760656, 60.29020278684555, 58.8162741353435, 56.76104237956386, 56.34950337871429, 55.411715661325765, 59.60017158139137, 60.686970141626176, 59.330998928316184, 53.97571632939001, 61.128644712509654, 63.108974887478745, 65.72907893888413, 64.26651339377126, 62.373193156334665, 55.57155616821782, 51.524199670360936, 56.828962141467684, 60.197211234800285, 43.22041257735222, 32.58261911330685, 25.79340034915555, 15.82020151999689, 13.338472804715558, 6.816081116276403, 17.408635923939368, 14.637624563709384, 12.579860917983517, 5.379564031477898, 0.9141489406747203, 0.15270171656964288, 0.06655728985225001, 0.1262129242381742, 0.07135137615184631, 0.21877217286777115, 5.375272958509384, 20.98704561110466, 38.75041677105812, 41.82566481251871, 32.450054768593084, 36.03587381301388, 25.6632855246144, 12.171703000222484, 25.47988530128233, 37.70967075901647, 51.873223935404134, 58.930383728396514, 55.115910114780554, 27.455596885373517, 0.7673709070490253, 0.08140520763493354, 0.06267555681387744, 0.03534490663197733, 0.0015664341035223897, 0.07947249803692102, 0.0978611669533195, 0.0599202641376084, 0.04070467991574157, 0.0641821759692844, 0.06538815541012634, 0.016894412504869605, 0.019009774701008876, 0.016194342207464, 0.060691695525160724, 0.0346401248938374, 0.0030834631968079318, 0.01522255297224488, 0.0904734593425547, 0.05777314185134827, 0.0035775853593217875, 0.013938401919609357, 0.13323051945096062, 0.024900536931630586, 0.021422114711435094, 0.1106469905484588, 0.013953629832324243, 0.06307643913333455, 0.02955378945766678, 0.04491613719672446, 0.010393930471412117, 0.015551064880715023, 0.05387931228465131, 0.01483756985004631, 0.015155271300294948, 0.08169033789947149, 0.04555506984733286, 0.028333583764070948, 0.04183270991028797, 0.06999832698174062, 0.04114887301599787, 0.0676074278570952, 0.06523597204396803, 0.014101646637784378, 0.03276167347306206, 0.05141866085450015, 0.04519472123994943, 0.06056543274392044, 0.11291556075335511, 0.03595445981068957, 0.08835001683403408, 0.061011219307059245, 0.018570095773846395, 0.05668975946102893, 0.051928025054475, 0.7222472864293283, 22.647031891730524, 73.93057454016902, 79.92177532565209, 71.8799437246015, 53.734890645550145, 53.14498186111451, 37.65579700469971, 23.335062688396825, 24.06598852526757, 39.90265223287767, 43.540740782214755, 47.3051021945092, 24.536502322843, 7.709067521556732, 0.43151817554908417, 0.12362746942427852, 0.05465085475495266, 0.5943839023670843, 2.0745276106942088, 5.3752778614720995, 8.703359923055096, 10.36848254742161, 11.202865800549908, 15.266254005893586, 14.464302870535082, 12.465399292207534, 13.750717832196145, 12.722876418021418, 15.23951913079908, 18.330514507908976, 15.434607036652105, 18.4200837919789, 26.043729935922933, 32.63814222428107, 41.014047976463075, 45.39725349795434, 51.72351491066718, 54.83937125052176, 60.34032675527758, 58.46217040092715, 61.74779084420974, 61.011887519590324, 64.72466584174865, 63.64018932465584, 64.54422896908176, 62.84437964039465, 60.00981607744771, 59.59252688192553, 64.70233578835764, 65.04066374994093, 66.33134318936256, 66.19518987594113, 64.88790312120992, 61.182396873351074, 60.76719830113073, 59.290261191706506, 60.51604501662716, 61.67507402358517, 64.11805952748945, 52.85391453773745, 37.70214765302597, 37.39774427106304, 56.27544118512062, 63.50607564372402, 60.80989330045639, 60.139611228819824, 60.31588646673388, 63.88024230157176, 62.33707597178798, 59.984807045229026, 62.38956120706374, 63.63208178550967, 61.80610472156156, 60.69806652684366, 59.65840701133975, 58.27060576408141, 59.46699534693072, 61.42937283362112, 63.028091692155414, 59.82104809053483, 56.23801785130655, 60.63066451780258, 63.47523012468892, 66.83868608167096, 63.98081971753029, 59.71901939761255, 57.25807336068923, 54.10609591391779, 58.30942153930665, 55.861693889864036, 44.81242026052168, 31.873758569840465, 22.12589598471119, 13.85770243983115, 6.865543675038123, 8.367090225219727, 16.81255921240776, 14.731839895248415, 8.745079232800393, 10.539697927813377, 4.620986955781137, 1.5738627987523235, 0.12890688774566497, 0.1524543774224097, 0.13816463130135692, 0.43533231281945783, 6.398686016759565, 24.956654848590976, 48.872830406312026, 55.339328319795676, 41.16646343661893, 34.66098108599263, 28.342274158231675, 16.46638847166492, 29.730836345303445, 48.48938342063658, 60.12106234027494, 65.75519015712123, 62.71001492777179, 32.874457182422766, 1.3837712570544214, 0.06798687886687056, 0.059082355470426624, 0.11401564002998414, 0.048226889583372304, 0.007528105193013026, 0.06712737418110333, 0.06057246160062571, 0.0766223521843072, 0.047640970217124115, 0.05470302917303578, 0.06471707004933588, 0.07734417554832275, 0.07469065382235474, 0.017192656279451424, 0.04761434100087612, 0.062047200007063735, 0.04845601499020573, 0.02987101306057265, 0.11214841562773913, 0.017054122684883977, 0.1178683421664661, 0.04335703718806467, 0.0035884257428528323, 0.025317667975961685, 0.023422647988603964, 0.060607736119099205, 0.034086461659641035, 0.032334100650323015, 0.11249199840089968, 0.2028769209620453, 0.26507671802274646, 0.15603516431104753, 0.14372235404387598, 0.10502166054662197, 0.183920550250238, 0.09463119470784742, 0.11900096485811858, 0.16570538492693057, 0.2555235556416935, 0.09925065892598323, 0.146933518830807, 0.14970436692237854, 0.10571756715615911, 0.17675002856600672, 0.2282459072528347, 0.1734791089209818, 0.13384463085282233, 0.1371029100470966, 0.18810388061308092, 0.16813282644556415, 0.21212102815268502, 0.12058754827106193, 0.14534407024902685, 0.13473729182395244, 1.5726615728870517, 30.94860676796206, 84.54877576520367, 88.04060305318525, 83.19661709570116, 61.588487702031294, 62.28028397406302, 37.00789597726638, 31.85118925186896, 31.726300985582416, 59.024563758603996, 60.81968745877666, 54.564362110630164, 32.887571627093905, 8.599472026671133, 0.7899052301241506, 0.2346087424384971, 0.14524440221007795, 0.8733801928258712, 3.2127116716677144, 6.930602067901242, 13.346629373488888, 13.042176961898805, 18.562789424773186, 25.16341474748427, 28.93758796876477, 18.723198675340225, 26.796346479846587, 19.394396620412028, 18.38472362487547, 28.680429535527384, 23.087055144771455, 26.431271876058272, 39.240826791332616, 38.18601908222322, 45.73585210307952, 47.023326966070364, 56.40392626485517, 59.59258571747811, 61.748904797338675, 58.51959390024985, 61.71874569308374, 60.88062932414394, 66.61872740714782, 66.85674467394429, 68.4383463090466, 65.68831766805341, 62.97535150281845, 61.40027669168288, 68.23188843265658, 68.91824829962947, 68.28642506753245, 67.27210014097153, 66.88376980443155, 64.043456046812, 63.28115124856273, 61.029557797216604, 61.230426296111084, 63.27879782645934, 64.89569294837214, 54.29096114250922, 43.700071380984404, 42.72155377172655, 58.7992432040553, 64.47786246576618, 63.189308950977946, 60.94139860522363, 60.812925292599594, 64.05908669194868, 61.25580403112597, 60.7936978340149, 65.01582730200984, 65.23390716122043, 63.35720600620393, 64.03193604561591, 61.647001620261904, 60.25250488711942, 60.636375488773474, 65.59997412466234, 65.13917407681866, 65.51082649538594, 58.725177088091456, 64.13540424839144, 66.47504314299553, 71.62300494409376, 65.07759678748347, 62.07863100113408, 58.90668476781538, 55.73901391798451, 63.34605078543387, 61.58766008192494, 47.436297632032826, 38.28813798965947, 34.356346284189534, 25.601978878821097, 23.197977812059467, 15.962957163010875, 34.39640937312957, 26.384548602565644, 23.637597060972645, 15.562694976406714, 3.3807531191456706, 1.3652693143775387, 0.324389145018593, 0.3312343857701748, 0.2188299205755034, 0.6500694239812513, 8.84483197043019, 29.57851306084664, 53.8948017551053, 55.945969935386415, 43.00829472080354, 49.058978249949796, 32.94857232801376, 19.791664077389626, 37.846400660853234, 54.953908381923554, 69.06402710945376, 76.18342707234045, 72.8696910796627, 40.13287182777159, 2.690910432607897, 0.146031710769861, 0.29178925399338046, 0.17930646396933064, 0.12033152168676739, 0.17568856778164066, 0.3289539871677276, 0.12268151937713548, 0.178052393359042, 0.121233222495404, 0.22941500339056217, 0.2045007056045917, 0.1870332574171405, 0.1586594904262212, 0.13656974349531437, 0.15638678334653378, 0.20063597588769852, 0.1419438502841419, 0.17517037058789886, 0.33613403898573696, 0.1369714187157731, 0.24006013217712605, 0.20857063963288264, 0.07215607490751051, 0.13305819563327298, 0.23722966712328697, 0.07749448965994582, 0.18871649048261105, 0.12243912915789312], [0.029578842448010564, 0.0332944646417614, 0.02909608256642617, 0.04431643973915808, 0.03643251399719908, 0.1568912216011555, 0.052731731726277264, 0.05586243429852109, 0.04454349287815633, 0.05550134258585111, 0.03942450102899344, 0.07596458909251998, 0.023598905667782794, 0.027237363655360478, 0.0365885278029788, 0.03659991569997322, 0.062206285825419816, 0.03010285616431746, 0.07019017838061818, 0.014455715239408517, 0.021396847216472514, 0.07654293951007628, 0.0188037104559161, 0.07784767917567685, 0.008181641873482975, 0.12069955798647097, 3.0142993119455155, 26.244631774963874, 67.4053273662444, 63.77069442502914, 56.86871536316411, 48.29111153079618, 34.04696541447794, 21.745018151498613, 29.166083681967955, 39.919510579878285, 56.32399228311355, 56.422388861256266, 25.217837633625155, 8.653839999629605, 0.20856826476031737, 0.056038013989886934, 0.06801045905317991, 0.1374649325565946, 0.42502858345547034, 1.870856210589409, 5.573051120004346, 9.986276011313162, 5.721508908656336, 6.5861988452173055, 11.213864126513082, 8.355725157645441, 21.917380825165782, 17.570061068381033, 26.424554817138183, 28.76759832905185, 38.625002907168486, 35.35235766441592, 52.93185987780171, 56.16467737382459, 59.22811515869633, 62.668335822320756, 63.58597824650427, 57.3189014773215, 57.36741335161271, 59.280063029258486, 61.041772057933194, 60.642521842833496, 58.64234839716266, 62.351600508536066, 61.56774228618991, 60.693191020719475, 57.548238538926654, 54.33445630535003, 55.83203684899115, 60.247970627200225, 65.28648653338033, 64.52897487148162, 62.927612335451194, 61.835565643925825, 63.19962478453114, 58.00390028184461, 61.12486747003371, 61.96496463591053, 61.57073897700156, 59.68284337751327, 56.533988137399, 36.23644028940509, 41.19019377616144, 62.924917667142815, 58.025889089030606, 59.12107367669383, 61.68166360547466, 59.25628954364408, 58.685282661068825, 61.72773968788886, 57.866276079608554, 59.97234959756175, 58.817776403119495, 62.81069824772497, 57.42864155000257, 57.15627608760711, 53.06798573463194, 52.97947352932346, 53.053390595220755, 55.73745673702609, 53.77834658468924, 53.33907250435122, 53.352173220726755, 59.08947506258565, 62.782257141605506, 60.82867360884144, 59.291080967072524, 62.458661602389434, 60.19647775157806, 63.84603923366916, 60.99344453504009, 63.45764613920643, 49.98109609849992, 29.922444128221084, 28.40561063058915, 20.521393591357818, 8.451898732493001, 8.971668674099831, 8.513439739904097, 8.467297957789514, 13.21829334382088, 6.203867773855887, 2.433007484482181, 0.13152601978471204, 0.14867333515036493, 0.0745001124338277, 0.09325506330858316, 0.34222281387736725, 6.820459461981251, 21.871983312791397, 40.42881857964301, 43.765092511330884, 45.5136812117792, 34.20599006837414, 30.385381867808682, 23.773573867736324, 30.552888647202526, 43.952181723810014, 54.047076009934955, 60.44526584686772, 34.707523930457334, 7.940753592598823, 0.05921884935589568, 0.19089352850231434, 0.03344337298204342, 0.043854408281584906, 0.0358261937095273, 0.05567314929418987, 0.0332798438537265, 0.023294500631069946, 0.020381043357173764, 0.13853534124791622, 0.04801104048026666, 0.01102685890791397, 0.057353402277634996, 0.0651180787733005, 0.03897265854081319, 0.054873721223444714, 0.0834201108063421, 0.026266236128585956, 0.02359135778650882, 0.09148202175574918, 0.04522231189654239, 0.049421059778861465, 0.05957650133378564, 0.03157437508625369, 0.011888021216427368, 0.044502461208931865, 0.07326668789309841, 0.061721788839467114, 0.011895108487336867, 0.045629954941931276, 0.04702315094970888, 0.023837743154276284, 0.05204024927450284, 0.04536525624233388, 0.033650166925884066, 0.09113375052449205, 0.04164855769504944, 0.027947272436933655, 0.010899839614848457, 0.035060358594261834, 0.024865137923869397, 0.05666788765079072, 0.05673542213175566, 0.06093515060661782, 0.058405972611639774, 0.04657359523398261, 0.013275665001973752, 0.027151473707729773, 0.026459757599138448, 0.0921967511455859, 0.04864291363065282, 0.04626706430327989, 0.10487103233894995, 0.1032382538241725, 3.456515415060905, 37.46424413496448, 80.72652801390618, 72.73337302669403, 65.62609711000997, 54.64721433577999, 42.45062781918434, 27.681395969083233, 32.41580855461859, 38.106347899283136, 52.056567284368704, 51.964179777329974, 25.08070568884573, 7.498953996166107, 0.42324672423062787, 0.08898619922899431, 0.046909180049213677, 0.649075287003671, 1.730736890627492, 5.651302895238323, 9.755719092584426, 11.154777542237314, 11.516460276419117, 12.718133291890545, 20.012271904176284, 17.13616455754926, 19.591050532556352, 9.109053611755371, 11.279549118011229, 20.84409679135969, 31.38696497486484, 33.75800832625359, 49.64797312213529, 56.496125498125636, 60.90635222773398, 65.18951377561017, 66.08857985465758, 60.82196243347661, 59.95980193538051, 60.40566559760802, 61.73813004647533, 60.26882194703626, 60.20369099032495, 64.06777081951019, 64.04649980606573, 63.123644551923206, 59.06976907483993, 55.57232495277159, 58.72456912071475, 62.535532213026485, 64.77813166956749, 64.90331411361694, 64.0129949200538, 63.588586622668856, 64.38524353888728, 60.081669976634366, 61.83325144552416, 61.474495780083444, 60.44463826764015, 60.15314732828448, 56.84851515677668, 41.03890795861521, 44.73029367385372, 62.87472701841786, 59.90961520902572, 61.13464986124347, 60.969208209745354, 59.943520176795225, 59.52239882561469, 59.00745437991235, 58.71800699541646, 60.343974559537834, 59.13981868374733, 63.671419235967825, 60.7574119875508, 57.929422317012666, 55.480816056651456, 56.933183439316295, 56.380639153142134, 59.4530434762278, 57.38363627464541, 54.421913393082164, 56.70535256785732, 60.80077378980575, 64.99470533863192, 59.991478996892134, 60.34312732758061, 61.57173525902533, 60.31141888710761, 66.46791227402227, 63.75393805965301, 63.759452912115286, 51.299098768541896, 37.57966772202523, 30.614354148987804, 15.33103391047447, 8.046168761868632, 7.9458257075278995, 12.487001745931565, 12.187651357343121, 10.161073496264796, 6.559602233671374, 6.556572693009531, 2.4635799084940264, 0.13651479966938496, 0.06599210848611209, 0.14616812038565838, 0.5629246549740915, 7.091788928354941, 24.035186152304373, 36.55203027109946, 37.81686129108552, 41.69821523850964, 29.14001168743257, 30.384615044439997, 32.109644028448294, 35.96135662448022, 51.59387665410196, 61.37524804761333, 69.61584183477586, 43.24058140477827, 9.056579162997584, 0.03272779323461075, 0.057549467160096096, 0.022116981356615023, 0.025249857703343998, 0.02303745323461631, 0.10066957633581855, 0.04111236126552667, 0.029065588436600183, 0.05435555467321988, 0.06787024198039886, 0.048739597757136634, 0.049413172903680996, 0.001256158678687268, 0.023404252302322178, 0.035506512879604296, 0.037437422170994744, 0.07763548814240964, 0.02533372134841498, 0.12725702547017606, 0.08893418185893567, 0.07097121268030136, 0.06706668469574183, 0.09124630416232733, 0.018101849427987492, 0.02576511120423675, 0.07676159632542441, 0.017173013785072876, 0.056527260720970175, 0.0769623113615859, 0.13736694991107912, 0.11549806612874232, 0.13868106649287287, 0.20336790671271665, 0.2166079898034373, 0.11567773672962382, 0.34483701231018193, 0.2809089668575795, 0.1241357840837971, 0.07755606014642023, 0.2710668820767634, 0.1367881858060437, 0.14293452454430444, 0.10744001626247361, 0.16252567571017051, 0.18924441699299122, 0.10695557290267561, 0.12291514555052405, 0.12560684143775894, 0.1500895406089483, 0.19788211962628752, 0.17816552922369974, 0.16308810682066027, 0.2035364154125414, 0.19733321762854056, 5.3901495279804355, 53.36643888104347, 90.48318063059162, 80.84716443092593, 74.73166373468216, 64.05102622124457, 47.606610867284964, 30.928439901721095, 38.22909062908542, 54.57287365390409, 71.54193739737235, 71.69088548229587, 33.23769807815552, 10.780403979362982, 0.6701846865396346, 0.27426836351233147, 0.1404862454341304, 0.6993157620872221, 0.9920160784836739, 8.676593668999212, 16.302623633415468, 21.741087936585952, 16.248837151835044, 17.31234173620901, 20.654916955578713, 19.912020044942057, 36.68608903884888, 24.08823620888495, 37.85888948748189, 37.39798745801372, 45.21158418347759, 41.17006809480729, 58.776238502994666, 60.66158848424112, 61.95437815881545, 64.35206028722948, 67.76853884420088, 62.19609422068443, 60.36022101679156, 61.3467598730518, 63.31160060821041, 60.856377309368504, 61.82911726736254, 67.12290102435698, 66.86522483825684, 66.28727928284677, 61.93172254870015, 58.72760895759829, 59.037778223714525, 66.00300942697834, 67.81054742874639, 68.56508593405448, 65.65957061706051, 65.8533945391255, 66.87150847527289, 62.75460050952051, 63.759833382022, 64.85253510936614, 60.401598099739324, 60.91218086981005, 57.30893473471365, 47.57842863759687, 50.34067153930665, 64.53475644511562, 61.860861009167095, 63.65775369828748, 62.069562481295684, 60.302134636909734, 59.372415234965665, 61.5276478182885, 58.972137358880815, 61.81325520238569, 59.779694541808105, 67.34729197717482, 62.433393693739376, 60.75935748315627, 56.36012123477075, 58.88751614478327, 58.19508444878363, 62.422324765113096, 59.36734361033286, 58.14266981617097, 58.01221962898009, 64.14091125611337, 67.80560524232926, 62.30242575368574, 59.78175378614857, 61.45758644227059, 62.02214887065273, 69.6607372837682, 65.85211584644934, 69.93658973324683, 54.20135851829283, 39.20942429573306, 34.18815897357079, 31.896953505854455, 16.806308915538175, 16.25155241258683, 21.259970011249667, 18.054171762158795, 24.26167949553459, 14.145015074360757, 6.319811565260734, 1.6934498591769127, 0.4728360858655745, 0.13071903808703347, 0.2887150657273108, 0.7365187690142663, 9.980882752326227, 31.312581146917037, 55.97020626068116, 58.88768872907085, 59.596990539181625, 47.87583451117239, 43.28812837600709, 35.831694833693966, 43.64775480762605, 58.11188313268847, 69.82854412448022, 78.17401424531015, 53.25255678546045, 13.272604442411854, 0.1778573320517617, 0.23734470288599693, 0.11135421227663757, 0.2209699871919809, 0.08980479481960497, 0.2208190219056222, 0.13813775693697317, 0.1270366449569983, 0.13323888513109378, 0.20071826905252474, 0.1640900732168267, 0.1094934230129565, 0.14549013257267016, 0.08949838263253052, 0.0750409322039735, 0.13343313438517432, 0.1836515921017816, 0.1406002852825388, 0.24520545446824646, 0.23075201067953344, 0.12728347848620147, 0.20825262121375532, 0.14731100099461694, 0.13494752167213347, 0.14468347263191977, 0.16931788785563362, 0.15814933715568436, 0.1486762309627187], [0.047901003441262635, 0.07690888438974658, 0.0411314445157205, 0.056475890695207545, 0.05677974414861491, 0.03338335382361566, 0.038496270595539006, 0.05280069113078137, 0.02591488330865339, 0.029544376152297182, 0.054767173714935787, 0.009837229698595983, 0.08119467135158279, 0.09089911311504342, 0.03460476993613186, 0.03504316375080136, 0.03150848386388633, 0.06903327070176601, 0.04954425820840463, 0.06608149562511714, 0.049317147612812064, 0.006206188399735238, 0.07060551294876684, 0.060668973357326565, 0.07428090403517408, 0.48743438155901053, 11.037505538232866, 58.25679509870468, 70.21989468605288, 57.615628780857215, 44.23984835224767, 38.905730862771314, 20.055645473541755, 18.420044568277177, 33.70179683931413, 34.6727874202113, 44.44769867004887, 34.32863473892212, 15.409274408894202, 0.7015627898996877, 0.053935435885984095, 0.02042940457261378, 0.09690509688469673, 0.30665457729370366, 1.331659137241302, 1.9715383048019104, 3.3335216535675913, 4.915292686031711, 11.206897997087049, 10.924226507063835, 21.194452701076386, 13.046171895919308, 11.235116508699234, 16.306622489806145, 24.069995226398593, 52.00551371420584, 59.22817399424892, 66.4151563952046, 66.96703387844947, 64.53001822194746, 64.80692971137263, 64.74726261631136, 62.02626735933366, 64.28899641959899, 60.34872062744633, 58.71969753696073, 59.423813973703695, 58.217720447048066, 59.3913681276383, 63.07218697763259, 62.398115896409564, 59.66646355967368, 55.06702953769315, 50.5151895553835, 52.160447336012325, 58.38988111865137, 61.29953453617712, 63.208136327805065, 64.33676696592762, 64.8054039093756, 63.721374542482444, 62.50095651995752, 62.25127412426857, 59.3775966859633, 61.273870468139656, 58.87706302827405, 59.853238982539025, 39.61380104864798, 45.60443309045608, 62.179326088197776, 59.656877286972545, 63.82947506443147, 61.604122269538145, 62.044012161993216, 61.230583190917976, 60.41768766218617, 56.84119993640531, 56.23873956741826, 57.03562790347684, 57.826052173491455, 61.72104027963454, 57.632957812278505, 55.1639630717616, 55.61849124969975, 54.958324970737586, 53.71427466792446, 52.63409314617034, 53.47836763628068, 56.15957829260058, 61.307230226455204, 60.77321521697506, 60.66218076213714, 59.60521967180314, 55.53902010763846, 61.96699642365979, 65.0487869785678, 63.80990243727162, 59.9833793024863, 62.128194070631466, 51.88993715470838, 43.47131090779459, 21.060531216283, 16.222968139956077, 14.183883801583322, 11.311242849596086, 6.110904168698096, 8.58326675430421, 7.54370431746206, 2.8602286115769417, 0.8089355896076849, 0.4007623500881657, 0.18650436563597572, 0.04398402652793354, 0.03515871279242058, 0.243525285754473, 6.575510386497744, 33.33882854830834, 51.32429607452885, 45.98970005589147, 38.40865673557405, 15.561152504336452, 35.438814547754106, 56.941365503495746, 42.224381585274976, 46.12481001884707, 55.97940814110541, 58.765593190347, 21.207767186626313, 0.5784549119491732, 0.07093388887663042, 0.05894699156464589, 0.013032883120280121, 0.017700224003243833, 0.09272776499030091, 0.06463742754872769, 0.0669425248258537, 0.039085951453495416, 0.01118254904154568, 0.0364341649166759, 0.021040375013985944, 0.01807750889941329, 0.013941934542550195, 0.017602716332241412, 0.058322097475249926, 0.09796923897679775, 0.02325108259796135, 0.05254137036841243, 0.031622830147464434, 0.05848905867746761, 0.04882253060537962, 0.061795398397671605, 0.03276103762008491, 0.035201525616069, 0.052936035884364005, 0.04577248176980404, 0.030630271311008164, 0.09829944585480037, 0.0341254708567454, 0.04046409383356091, 0.018257141195898576, 0.062384205915394335, 0.09310972876846792, 0.04895258935228471, 0.09544826578348876, 0.00562002292774137, 0.010718967213535742, 0.014850024524475298, 0.044236942795255495, 0.0052939385603812915, 0.05343757449619232, 0.0726156204097694, 0.018145575811485612, 0.015185852572622319, 0.0384673469459578, 0.004778656809996333, 0.042189994165974284, 0.05098621571256269, 0.047177479362055186, 0.011366019438531612, 0.05938297603279353, 0.020129291543496713, 0.6568198230478072, 16.53946811153043, 69.98514083123976, 76.44304090930571, 67.31247701952535, 53.861720485071984, 49.169514563775834, 29.819123014327023, 24.222830380162886, 26.61825518454275, 32.924728239736254, 41.1073140944204, 33.91022766790083, 13.128025877860285, 1.1004648333595646, 0.05135501810019055, 0.08309124458220699, 0.6420962260134759, 1.8151254591441925, 7.07995415695252, 7.800978950915798, 10.527086527116838, 10.591990966950695, 17.267014826497725, 8.795922956159039, 18.04002377294725, 10.197441712502512, 12.094202849172778, 11.350540095759976, 23.741410432323335, 39.93398020344396, 54.43740675526281, 62.022423436564786, 70.67485824708017, 66.95615322359147, 68.16673001935406, 65.97107348903533, 65.14970564073133, 64.80041857688659, 60.726766509394494, 58.64647865295411, 59.183380526881066, 59.44492809234127, 60.241785049438484, 65.75880266004994, 65.62555974529636, 61.48475670045423, 59.474283110710886, 52.34654811120803, 53.927573157895, 59.8031856167701, 64.54315423965454, 64.68288083230296, 66.38879806764665, 65.51876537261471, 66.92618631547498, 63.9260987312563, 63.693094253540046, 60.956848821332386, 63.04573059082032, 58.10653301977343, 59.246491462953635, 44.83656637130245, 49.226439922086655, 62.85169486076602, 61.51860283267114, 64.79043222242787, 63.829071060303725, 61.52086996263074, 61.14812320278537, 61.050362048610566, 56.89074731642201, 57.131847566173924, 59.179764101582194, 58.84460541509814, 63.36239137957173, 58.12438372642764, 58.7983645931367, 57.38479337384624, 56.06008345080961, 55.397202891688195, 54.34820813517417, 53.29160398052585, 58.61038108025828, 63.07445410759219, 63.481619665699625, 60.00505432005852, 59.52458358580067, 55.919242905032256, 61.79449842822168, 68.24110600256151, 66.59495784390357, 64.54154214551373, 65.99911059102705, 53.89062443087178, 41.36331542845696, 25.60083943028604, 17.71679889771246, 10.70678109122861, 13.247644439820322, 7.7907714728386175, 12.023450155411998, 11.906809653005293, 9.932502277435797, 3.927964943070566, 2.0686815631005073, 0.4950547500723793, 0.018573098838509574, 0.03588217175415447, 0.16530346455833606, 6.3530801284697755, 32.423266941501254, 57.426625451734, 49.15099313182216, 42.7645194145941, 21.039564186526885, 30.806758173050422, 58.43345080652545, 48.671130364941014, 52.78488866744503, 64.03000231712096, 69.50880819751372, 28.069612556888213, 0.5461989331149286, 0.02652094887209035, 0.025892059634169264, 0.02555600559008458, 0.061748885369348916, 0.01916962660728924, 0.06654920762464886, 0.006131030865118749, 0.042040515090188676, 0.03601959643645152, 0.07919076154188764, 0.06211950338535732, 0.008485611197688888, 0.03950294460200014, 0.014006855706083439, 0.017523135118667158, 0.0718581892790333, 0.016208089655265212, 0.0333696331888918, 0.021712553965288307, 0.02416396829029245, 0.06945413642472799, 0.03404773591506866, 0.03327157010414428, 0.023027028693186662, 0.11068560904072178, 0.05403290908302992, 0.0827752716178375, 0.2765908663070971, 0.16153846416742573, 0.15766763639065529, 0.22385151966685252, 0.11577837770023655, 0.20971122197806838, 0.11785651376891522, 0.28409102030338784, 0.0955506993998443, 0.12235321239718508, 0.14890981117083182, 0.22371546245150029, 0.1574019724202733, 0.16310928149088738, 0.16707501223971769, 0.12773329467182198, 0.15688896930265814, 0.08177777151426963, 0.13130667349023203, 0.10670575929144699, 0.09797075583088784, 0.24370067392385777, 0.12596854219032874, 0.17889665289511605, 0.15295227328615804, 0.9896519924363784, 24.97992430963824, 82.65938574267973, 88.25994983796151, 76.18866735889067, 61.98512169622607, 54.273816462486025, 31.142615041425152, 27.98314194525442, 45.34979674123949, 46.37410409988896, 58.16428599819061, 44.069939121123284, 18.982737987272202, 1.2709298153077404, 0.31653842918815156, 0.18677485596028068, 0.5351673895793577, 1.757689089544358, 6.539600597273919, 11.521430900019984, 16.22831040813077, 15.053656639591342, 23.641950891863917, 21.238040039616248, 35.212399651927335, 21.242609600866995, 21.18136179062628, 25.44437216174218, 31.11788057511853, 58.75941153495543, 67.27409270501906, 69.07875168708064, 72.41597483235022, 69.03134592117803, 69.93624456467168, 69.8697054770685, 67.27794447252828, 67.53347119977398, 61.15085709479548, 59.85030112727996, 59.751739809590006, 60.00387368663665, 61.140286307181086, 67.30326729436075, 67.40427617103823, 65.36372192444341, 61.55692438925467, 57.00343308910247, 56.686180022455034, 63.7991512206293, 66.39511308362408, 67.85956136641964, 68.58359167652746, 67.42005978861164, 67.33964335533881, 67.73149598029353, 65.0354116962802, 64.56929683685303, 63.32204980234947, 59.75896089307724, 59.994291336305686, 49.49840138035436, 51.517194317233184, 65.14628925631123, 62.67961263656617, 68.11042831790063, 65.47772561350178, 63.891295540717344, 63.35563705813501, 62.06655402337352, 56.443640262849875, 57.50831273294265, 59.06155563169911, 59.65375115794521, 66.16136335557508, 61.68755500547348, 60.340016888033965, 61.00214827445246, 58.14037130725, 58.28421246620917, 57.132271182152536, 56.7948845894106, 61.24881828984907, 66.3473621491463, 65.7397085620511, 60.48692926283806, 59.2444557528342, 55.8888602256775, 62.98248237179172, 71.11495602515437, 69.17104505723523, 66.88490729178152, 69.15484566842356, 56.41881558202929, 49.94365315283499, 28.069736111548643, 22.909491408255793, 23.505179805140344, 24.182098527108472, 14.137851845833564, 19.751096963882446, 17.639943976556104, 11.842809319496157, 2.8170651341638258, 1.3047687156546501, 0.44138189465288197, 0.13731621956873324, 0.11467221568548873, 0.5191215860747522, 8.801250515445586, 42.34934437659479, 65.23922197280392, 61.72074610187162, 52.368882086969194, 24.384761510356782, 48.29877191974271, 69.59251157699093, 56.331558535175944, 63.61447034343597, 71.53659512919765, 78.44477545830512, 33.886360045402284, 1.0840547397252054, 0.12825736009906377, 0.15585101209580898, 0.07481665230326115, 0.11297859446776491, 0.18393804769842856, 0.12327870023587059, 0.1636212733724425, 0.1890949532389641, 0.07604462995884881, 0.3012172529293645, 0.11065848186732301, 0.2206422854214907, 0.18736501945362938, 0.1636510895144555, 0.09972000269279366, 0.23622650562995867, 0.08162943390949119, 0.2619610690782147, 0.0867668271905953, 0.2022184990346432, 0.1533277329778479, 0.13549777198462717, 0.12656155553075576, 0.10253236508898197, 0.1329269034848098, 0.12150565868303662, 0.19161728240789908], [0.04068644319270407, 0.008640160817923325, 0.017301800826023665, 0.05139920988210267, 0.04605324916361321, 0.001917687451726036, 0.03206015718469937, 0.05334633725485014, 0.07822108575172963, 0.04639342284551071, 0.07319138911102088, 0.023218673248324665, 0.05365587891109529, 0.07849306994748693, 0.018361082090245142, 0.040752460819578944, 0.04615579769315739, 0.006586604680295193, 0.060269795583500985, 0.010785602498799564, 0.07233478789848667, 0.006204751984877212, 0.06002277436275637, 0.03077743105560301, 0.025750555533675418, 2.3771906860413092, 36.36325443944624, 68.16129361429523, 66.87269303106493, 52.76763416105702, 50.78143612031014, 37.19098829453991, 23.77547033371464, 29.74400374197191, 51.89398504072621, 70.51724956881615, 47.43776459847727, 19.059714501903905, 2.042592285621551, 0.11572554827697816, 0.02174689577171399, 0.07549277852259337, 0.2724595992795883, 1.118862588078745, 5.239222607304973, 5.415532656254308, 10.397784613793897, 9.005214744998563, 12.541900219455844, 8.349246382713318, 23.424386824330977, 24.175883531570438, 43.07739903849941, 26.696955580865186, 44.64560185709308, 52.11004487929806, 65.24741188172372, 62.886443138122566, 63.23843271501603, 59.29552501247775, 59.92684225882254, 58.96686569336922, 62.68886158543249, 58.789025429756414, 61.079297373371745, 55.573144728137606, 60.30224446327456, 59.05185561026297, 59.4481405135124, 60.45248693035495, 62.15023779099988, 56.56211545390468, 55.25022383659117, 49.83115565392279, 48.74198405973373, 49.11058095193679, 59.87541998586347, 60.97524473744055, 67.21508456814674, 62.440457882419715, 60.75468986265121, 58.1947628144295, 63.693670841955374, 60.20483240004509, 63.23647937467022, 57.513545174752515, 61.829144723953746, 43.33476143498575, 53.18803379612585, 64.31955168324133, 56.30753401787051, 56.97027337166571, 59.52595641536098, 61.376032521647794, 60.30531567911948, 59.47359277356056, 59.87503951595676, 59.33020660954138, 56.451987066576564, 56.68092796879431, 58.192495684469904, 58.47160762356174, 58.336026976185465, 56.363682746887214, 57.60766244703724, 54.27837425662626, 55.031061403213016, 52.41948458456224, 55.399838724443995, 60.074731303799545, 62.357197730771965, 57.92615106028896, 57.590011781261815, 58.617857117806714, 62.241177943445024, 62.721354499939956, 61.799570052854484, 59.328680807544345, 61.92947895296159, 62.39535454780825, 56.962605137978834, 45.809031763384425, 30.532051055662095, 15.32154275525001, 14.299258359016912, 9.591102119415037, 6.416238132984408, 3.9609787973665425, 12.725789758466906, 8.604458339752691, 1.2105509326342614, 0.27247669836205823, 0.08562963861491411, 0.04892427857304293, 0.030991248110489502, 0.11672698607247685, 4.886754991546755, 24.840795878441106, 50.41287452943864, 32.75647032645441, 43.893899225419574, 89.74733614152478, 58.33826272718368, 28.429078171330115, 36.78204982511459, 56.368173860734515, 59.057641106267134, 42.19637978461481, 2.744386801796575, 0.15451846343855705, 0.0868868655074508, 0.02291968253801667, 0.044331382284121174, 0.02231568158153565, 0.05794039416697718, 0.018839998125669458, 0.07504474732183641, 0.040420020795277053, 0.043509484854556864, 0.04932803755265571, 0.02604429279604266, 0.03504352381212577, 0.061620481372360265, 0.1024695688618287, 0.04298049348196195, 0.002777514253525184, 0.037271912705393574, 0.04571847640158189, 0.052392121119004105, 0.016216913072933114, 0.05413551506916842, 0.010803278062432524, 0.02138163462551611, 0.05538053052019208, 0.03679619125661351, 0.04989802995095811, 0.06116785747449725, 0.017399229973013845, 0.012261471842535803, 0.029810612773402568, 0.037417009758252295, 0.051230743317113775, 0.025311248159156214, 0.029803804166975523, 0.07654804931653124, 0.008009953429967525, 0.00704445569182656, 0.05407035546076875, 0.016769501868815675, 0.04065617888925537, 0.05022210812556648, 0.044862530194222934, 0.022873696195141926, 0.0554087761819603, 0.05706302814125534, 0.06587312737059209, 0.026511539397160375, 0.03462643873307013, 0.09920630243516738, 0.011296077526264615, 0.04512300008847829, 3.3955304036217355, 45.075246518658055, 78.31054410626813, 76.73291975452055, 58.99025086433657, 57.72914609601421, 48.69443316613474, 23.427154056487545, 24.66817040597239, 50.93530677979993, 51.5151233057822, 43.756251488962484, 19.22750565313524, 1.927077258306165, 0.0875163293113151, 0.011921831549355581, 0.2002033200715819, 1.2219595140026462, 4.594545277857012, 8.061281163846294, 11.68103998707187, 11.485035227191064, 11.99703593407908, 15.280754027828095, 14.59995706235209, 15.00503788071294, 16.363770442624247, 31.3773218277962, 28.43113349330041, 44.064141858008604, 52.785986931093284, 65.02020074475196, 66.58076670862013, 65.75134231198219, 61.38568155227169, 62.320692231578214, 62.41566065819033, 63.89379409051711, 60.61470047120125, 61.67052407418529, 57.17544078826905, 60.639176061076505, 59.37077960660381, 58.27040964557279, 63.09891008561658, 63.872036703171275, 60.12269404626662, 56.767420153464045, 52.89139278473393, 49.5374721096408, 51.8241354726976, 61.01411934821837, 63.27246712100122, 65.4175211537269, 64.63816581233856, 62.74570065159952, 60.404308457528394, 65.69246753569573, 62.09064129860171, 63.870773699975786, 58.491042967765566, 59.929576150832645, 47.49390548275363, 54.56076921955232, 65.52034216542398, 60.04576852244716, 59.436377325365626, 61.88845096095916, 65.03662763103362, 61.600607825863754, 61.04789095540201, 61.524502077410304, 59.02393225700625, 56.99783978923675, 57.86114169705299, 59.104297699466834, 61.437605888612815, 59.56751000496649, 58.42404104048207, 59.31839243058236, 56.73796315346995, 56.5021228021191, 57.44200898754982, 59.53256560910133, 61.153265430081284, 62.47380979599492, 57.78247071850685, 58.4339685593882, 56.22135562281455, 63.448208916571836, 65.94890425282141, 62.50291770504367, 63.13556463487687, 63.725951948473536, 65.63571476167249, 58.97394949390043, 46.396951906142704, 27.659813127210064, 14.168251195261556, 9.082688420049607, 8.51436443867222, 14.535050661333146, 9.693035694860644, 11.913320787491338, 6.536980453998813, 3.337528599846748, 1.4982748031616213, 0.3074759767661172, 0.08277536354838841, 0.04157987408219807, 0.2889354539013678, 6.212727427482606, 27.343587721547774, 49.47451414600496, 31.90104453794418, 32.004542158496, 74.08655935718168, 61.61730927805747, 37.189933176963564, 44.170806792474565, 62.9187556236021, 66.30490641440115, 48.414399470052416, 4.295203714601455, 0.17093506882027273, 0.03194613457326928, 0.014591229489944397, 0.04270160683400689, 0.09420729527670531, 0.12618150697239947, 0.028291071629932815, 0.05548649580187856, 0.0655818530809014, 0.03803842580847202, 0.08597153599464125, 0.10694963572126244, 0.016060915546521785, 0.04446242545400897, 0.024819676351222782, 0.05197698956415538, 0.05856577472220506, 0.06293004356144417, 0.03086573609541501, 0.0346085352582797, 0.0436386204655132, 0.047899612991680066, 0.02502348255215874, 0.07839340190853804, 0.013819345152906835, 0.012890308411912093, 0.12891534535634902, 0.11631768827717151, 0.12253922620607961, 0.10582939301046634, 0.15802069567143917, 0.17419797518560964, 0.1195143356979374, 0.16459526223761423, 0.19075733339113576, 0.1553671203193165, 0.11945874835815161, 0.18846544346982436, 0.21202479218763692, 0.1400612351754981, 0.12153127666322455, 0.13481288938032043, 0.13666973329119145, 0.0698320399368963, 0.12378501540590679, 0.19740127687973363, 0.11749279054422533, 0.18453930414492087, 0.20762513391673568, 0.15888197768119075, 0.13808855877047585, 0.08645216423657634, 5.285800262804955, 56.22172824798092, 87.8970286153978, 85.57993550454417, 70.62814281832787, 66.4462294117097, 51.881009840196185, 34.5228861993359, 42.25550559259231, 67.80725263780164, 85.9323133960847, 57.879733731669766, 24.784394156548288, 2.7146147864480175, 0.4127108395820664, 0.24026607193293112, 0.36259398044597724, 0.7271876955224622, 5.10906953965464, 17.040019419885454, 17.11213807905874, 18.816435375521262, 19.44660140622047, 20.87762128922247, 23.64709115797474, 30.664462427939142, 38.11891517331524, 54.25581278339509, 32.565505812245036, 47.05190927751603, 57.16887474060059, 66.26412945408975, 67.50814837794151, 68.05117699407762, 63.66393927604922, 64.95568167778754, 63.32061029249623, 66.77442981350806, 62.67346236013598, 64.62330395175566, 58.291347257552616, 60.93657016754151, 60.51519386229977, 61.10736977669501, 64.96739387512207, 67.32231432391752, 63.162566231143096, 59.57520569524458, 54.97683855795092, 51.642737619338504, 54.670101365735455, 63.75137282956032, 65.2755391982294, 69.98610573430216, 67.04071167976626, 66.21691980669576, 62.92006177286949, 68.06146929340979, 66.99117214448991, 66.38300080453196, 58.36874738816292, 62.547907290920136, 50.184933831614835, 57.492097654650294, 67.35804711618732, 61.5637493133545, 62.480442523956306, 64.81241318487352, 67.62938099522745, 64.81067949725737, 62.88565474171793, 64.34938915314214, 60.58925213352327, 59.24663266827984, 58.65111097212761, 60.630970462676025, 62.4514405189022, 62.929373479658565, 61.34352391765964, 63.205571097712365, 58.97068608191706, 60.23465418046521, 59.39919717850224, 62.197212096183534, 64.16741863373788, 65.3915629079265, 58.8635386959199, 59.062736265120975, 57.98239784855997, 66.29217440082182, 68.31094772584977, 66.83316338446834, 65.32243505600961, 67.73934072063815, 70.00419570553687, 62.8489492016454, 50.93930759737569, 35.27099201756139, 21.562302381761615, 26.182789725642053, 20.8608845356972, 14.55072053017155, 11.948472088383092, 27.03262221428656, 17.059882302438062, 2.65731361604506, 0.9393900668909474, 0.5293369088922778, 0.17511467599580366, 0.09058913861912105, 0.5893467823343893, 7.687200798142341, 34.51583770013625, 65.25771987053656, 45.21866406163862, 53.38010441872382, 98.01071889938848, 65.04768871491956, 41.382750772660785, 50.37948339216171, 72.21063090908912, 74.29952836805775, 58.94917972626225, 6.116352340867443, 0.35171314172687074, 0.31837609025739855, 0.13625779249254735, 0.1410819554040509, 0.13563330826019088, 0.1599732392858113, 0.10471174733773356, 0.21436502225697043, 0.15896203386927807, 0.153181241644967, 0.12712605507864108, 0.1306692730154722, 0.1438401017578379, 0.13573748089613455, 0.1352153919757374, 0.18948308402492156, 0.1959691521140837, 0.1946836412553826, 0.12227070472774007, 0.21976407286861252, 0.14711934111772046, 0.15870226877591304, 0.1523472630088368, 0.15928043533236752, 0.1901824303692387, 0.20567366282545751, 0.16042155393910024], [0.018224459885048772, 0.02113877709263996, 0.012864591797903903, 0.08578215905975911, 0.04252411192283035, 0.03645698284550059, 0.02090928970926231, 0.0875273533165455, 0.04343640772745975, 0.038335258066053354, 0.033569233567123456, 0.02051042028582625, 0.037681876997193026, 0.13738873745164565, 0.031214449742448427, 0.028928098636829568, 0.02055807670037593, 0.04179748518752956, 0.07947746994754962, 0.025569622802938667, 0.019590743224046404, 0.06082009569170976, 0.03584742966678835, 0.051859027345574675, 0.21138556842361728, 16.16677038131222, 60.398883819580085, 69.57817923638129, 59.19147629891673, 47.173847921432994, 33.62295719885057, 14.825141314537296, 24.573103920105968, 38.11118025933543, 34.95033433360439, 45.33523690315985, 22.15804961419875, 3.7024485151613917, 0.27958277673009907, 0.10869117573864999, 0.08336646166900474, 0.21103578799914932, 1.8572685074421669, 1.9673559550316104, 8.128323295424062, 5.94775612315824, 8.908452814625157, 12.233357756368576, 20.8084051839767, 4.741884210417348, 19.290055690273164, 34.47492345686882, 44.75892305374146, 45.520682642536784, 61.86929410503757, 58.24993095090313, 67.2030193574967, 59.11723367629513, 58.78293791124898, 56.003785671726355, 57.97225067692419, 56.41478730786232, 58.05975091072821, 60.34637897245346, 62.59759979863321, 56.865812809236594, 58.72867976465533, 58.57990818638956, 57.315649832448656, 60.27846705528998, 61.317408777052364, 57.737496822111076, 54.58090666801699, 48.073647483702636, 49.31302232127036, 46.867063660775464, 49.91388236322711, 57.79042136284613, 59.61349195049655, 58.041664861863666, 58.370865468055975, 55.01116321932886, 60.50886315684165, 59.38170340753371, 59.63477080868137, 57.26386670143374, 62.83712717794604, 40.04652084842805, 52.31982892559421, 63.26213559796734, 55.71347928816273, 59.55051045263968, 56.65569928384597, 58.91698491188788, 57.60595229364211, 58.78330661404518, 58.78537762549616, 57.61150244743594, 57.631902694702156, 54.91818735676428, 56.569477742718114, 57.16315592488935, 59.42293928515527, 58.59525249850366, 57.32944480834469, 59.470537247196326, 57.66011238098145, 58.09670748249177, 59.097927770306995, 61.30572011393886, 58.21572788300053, 54.55717632847448, 57.65341689509731, 56.22974949498331, 61.937688473732244, 62.79483618274812, 57.24468238892094, 61.11988605991487, 64.87592420270367, 60.83153693906723, 62.389788704533736, 63.853907508234826, 55.5297044784792, 38.199339451328406, 28.232553697401478, 9.402802855737749, 15.4719695737285, 13.670297476553149, 7.006564649843401, 5.1523509333210615, 5.769236799209349, 1.3055371324862204, 0.06349391491723157, 0.12359898627525377, 0.051617138913922736, 0.10749934211132989, 1.0059133424393594, 11.386775932004376, 40.12664310393795, 53.7740437446102, 63.83390734272619, 87.28513102377616, 79.83444767613565, 32.14122695307578, 35.30899978453113, 48.45944004674112, 55.397755945882494, 47.41153963150517, 9.633315647802046, 0.15012036798702133, 0.02360585791569564, 0.03408838454033098, 0.03117834210335728, 0.06111716543654762, 0.07785776089276038, 0.12293909345903706, 0.022422315274936058, 0.042408815690226136, 0.036352584213619275, 0.03469598802527593, 0.03380175274346144, 0.06258700854114949, 0.0852646743277869, 0.0504080644778667, 0.028586498116173094, 0.023386000257526195, 0.02208488227258767, 0.06411045481781326, 0.048841069933147206, 0.07850538098043011, 0.02668259533933334, 0.05461677150320142, 0.01978971541018015, 0.0629461199165352, 0.007318557163084587, 0.037275333287975485, 0.0047440018651316, 0.02076075675206319, 0.06753747636872916, 0.08235242938803089, 0.02994718901332348, 0.027378304681229978, 0.04279846333027367, 0.02945193040725445, 0.05087070497533968, 0.042906960532549894, 0.04255503123145431, 0.05660454750121121, 0.015022190336528567, 0.045824234839528806, 0.022231549805691166, 0.03574774247564135, 0.010953272332347209, 0.02781405166212109, 0.033069556548951135, 0.051282806652447874, 0.08425432692972884, 0.06321049302876477, 0.011136648883562417, 0.01097855036101875, 0.3373272975365962, 21.07319654956941, 68.13763387741582, 77.96503820726949, 68.80151856330134, 54.946506869408395, 42.61985848026891, 23.96756645171873, 31.150783377309, 44.57027273793375, 41.70210230735041, 47.067045704011, 23.255873956987937, 3.9829011694077527, 0.4495870334006125, 0.06374237255283421, 0.20613282528375426, 0.9587144202763035, 4.440676089256041, 7.398958071585625, 14.097755416747063, 11.812341328590147, 14.042640232270765, 15.078816683061662, 11.407283063857786, 9.520446504316023, 12.36428156975777, 27.477275825315907, 38.74590212298978, 46.41231190773749, 60.63447706161007, 61.96296422712265, 66.85904318286528, 62.88821997181062, 61.310097479051166, 59.09791992556665, 59.980747392100675, 59.51181627088978, 61.14369484686083, 62.170132052513864, 62.9304168301244, 57.826087474823005, 58.07499716358801, 58.46692823594617, 59.41012097943214, 63.301288697027395, 63.127088392934496, 60.36566918896091, 58.06703082976803, 50.33975762705649, 51.278349430330344, 50.00812122898717, 52.84541868394422, 58.8511989193578, 62.457747690139286, 60.3849672502087, 61.967725984511844, 56.905868053436286, 62.86758830470424, 63.83578615803873, 61.914330759356105, 56.47619985765027, 62.01734788956181, 42.26495458233742, 55.4145162336288, 64.25202808072491, 58.45976991038169, 60.495193696791134, 58.59777066015429, 60.83238417102445, 59.877608668419626, 60.78394682176652, 61.0686638278346, 59.71363790573613, 58.19030307954358, 55.27204398185977, 57.60962755449357, 58.74049394361435, 60.14192934959166, 61.064498270711596, 60.749226001001176, 61.19924737561134, 59.5159935951233, 59.47939003667524, 60.4882981700282, 61.955962796365064, 58.823628579416585, 56.13701289699924, 57.13354987482871, 57.0493915004115, 62.9193086777964, 63.369537938025694, 60.661812059340946, 61.3445358891641, 65.25686087146883, 63.07664671251851, 64.13106610698085, 63.85468413752895, 54.356076409739835, 33.57659870578397, 20.296235815171276, 8.464142410985886, 8.152375759616975, 12.46111802516445, 13.285337436583735, 11.174394296061609, 5.687246514904884, 3.8692816274781383, 0.8534023970846207, 0.2358592584008171, 0.008998228398512208, 0.05657609499570343, 1.1922728102053366, 11.983545922463941, 41.993918803430375, 46.04647244176557, 56.09387859221428, 88.5719665404289, 78.82872058499244, 37.7606733383671, 38.87644252469463, 56.01301500874182, 61.65663888377529, 58.098821640014656, 13.165691418032493, 0.24924004119971108, 0.030827100366173737, 0.065276452129887, 0.07454996177506062, 0.04723076460762851, 0.011868568328810076, 0.008281646991118548, 0.026589193899605065, 0.058955276805546984, 0.018284559482708573, 0.029121941864310257, 0.07025171822357563, 0.008531362926136822, 0.033294874498800885, 0.027845173984044985, 0.025526597389891267, 0.0183940774971439, 0.03971428910811101, 0.10490548331290485, 0.03551570210425604, 0.05477437877186364, 0.02224458670694261, 0.02321518754826919, 0.07280780888733364, 0.10864606082078912, 0.048656438912955985, 0.05571385920648614, 0.15632367302333156, 0.1694590012512861, 0.20861989908641387, 0.21376224895638807, 0.07491913188489215, 0.06492608181771732, 0.13996757326587556, 0.1247973776152057, 0.10636012340264936, 0.13021407889262324, 0.10314528905456105, 0.1342710966785108, 0.18375279231657907, 0.3003625133104863, 0.08812104847522513, 0.12162841661202332, 0.09415723909173282, 0.1963157149692697, 0.1874637222217937, 0.15543813666989728, 0.27249857783317566, 0.17992198497297304, 0.2503290811493512, 0.1904572567511951, 0.4817185689124369, 27.300018033673688, 79.04348604140743, 88.75796533400013, 77.27793308996385, 64.21880168299522, 47.22990643593573, 24.42476772492932, 38.29640634598271, 52.014080170662176, 48.4398203511392, 59.80341703661027, 27.60658656397174, 5.032191084277246, 0.5913937692680667, 0.31201529286561475, 0.2550482134064359, 1.1750409800198771, 5.689512664271939, 11.247948542717966, 22.253098449399396, 21.190355785431404, 23.910917620505057, 22.414747168940885, 30.56965089613392, 17.86189913749695, 26.78639150434925, 42.64223560210198, 47.921420297315045, 46.21799768940095, 61.8186523837428, 62.203664395116995, 70.29640443863408, 64.26657615169403, 62.67916156399635, 62.10740158634802, 63.80376392795194, 62.567409315416896, 63.66106810108308, 65.06203674500989, 64.75817857250091, 58.97498499962592, 59.911929407427394, 57.51534946503178, 58.78684459194061, 64.87359823719149, 66.04588093296175, 65.28326234509869, 60.51005947974421, 52.88077492867747, 55.23976679771177, 51.759173177903705, 54.39278979455271, 61.522489901511904, 64.18805030084425, 63.54535818099976, 65.00504078403597, 59.72341637457571, 67.13605665391492, 66.00069522857666, 62.439406687213534, 58.61307182619649, 62.98268633504068, 46.63980937773182, 58.22357654571534, 67.15789641103437, 60.86803459352063, 64.14273908061367, 61.91311482460269, 63.25241596468034, 62.141357544929754, 63.833197393725, 62.40195589680826, 60.55359386628675, 61.334082772654874, 55.13549058668075, 59.19033881156676, 59.861401434867616, 62.805508951986994, 62.81190241536787, 63.01383779894922, 64.16104870457804, 62.18288760031424, 63.04055698456303, 63.434606136814246, 64.91961940642327, 60.00984745640909, 57.75455913236065, 58.45390988934425, 57.96971682579287, 64.4832557247531, 67.50614796915363, 63.85334268693001, 64.13421184785905, 69.76710411810106, 65.35212739821404, 65.98165604376024, 67.29040192019555, 60.80748496517059, 43.19516035818285, 34.007431845511164, 17.386074450708207, 23.794560509343302, 29.054502056490993, 16.621408385615197, 16.68876136502912, 13.671951736173323, 3.925734340183197, 0.6603131226954922, 0.34920932124218634, 0.12929564672372035, 0.23887712388269364, 1.494635824234255, 16.366088563396087, 51.65520291174612, 74.45690170411142, 73.8398265838623, 92.14971726940524, 81.99933713482272, 43.463348496344786, 49.975522410485056, 65.29845760714623, 69.78773578520745, 68.1397911810106, 19.57910103182639, 0.45291170177440493, 0.09922406035325221, 0.11682444011732457, 0.17361121312264474, 0.1587980144446896, 0.2091559308070329, 0.1474609703666741, 0.09403939178634076, 0.10712208211301796, 0.1667783676736778, 0.12034298236211462, 0.15135637424405546, 0.17868862938015692, 0.1531432283621642, 0.262965839356184, 0.08234372662921106, 0.06086319579832977, 0.11004659212044171, 0.21050049172293758, 0.1410607654120653, 0.16310045615799967, 0.14073047426439103, 0.13386710787252074, 0.08109494202559994, 0.25836594102363436, 0.10439721461866172, 0.1629775450114281], [0.01415559646463202, 0.048456842365163955, 0.028163324553339232, 0.015032632114936509, 0.053202354859921246, 0.08413676307686875, 0.05806653054370996, 0.012521136386860764, 0.03458249209929378, 0.02807598478431183, 0.006861069564512301, 0.05008729580309122, 0.05901777425840978, 0.02072777858214273, 0.09513511202268063, 0.04101221059118548, 0.03029639870228787, 0.05655310086665615, 0.04956748982470843, 0.01774318046837805, 0.08993745826545263, 0.052948929144129644, 0.03152878710909957, 0.11370669975275956, 0.5359861843528286, 39.50633595066686, 76.91538841493669, 66.13613467062673, 53.56580511216195, 47.718727896290446, 38.64742709744362, 22.153252555478005, 23.56627464294434, 34.153673495015795, 65.5759496073569, 28.63555762075609, 8.45143687340521, 0.4893380181202966, 0.08268474300782527, 0.06800335741812183, 0.12946930353439626, 0.44599254885988854, 4.4935373817720725, 5.460681098122751, 4.8090062602873775, 12.707363443989909, 11.163797032448555, 11.435478041248938, 14.702320137331563, 29.959082988000688, 37.78982047111758, 51.067780909999726, 65.34202337265015, 65.09457672795942, 61.514496111100726, 60.71250477144795, 63.09495241411271, 58.83613309552593, 56.984994026922415, 51.44659949887184, 50.31429752226799, 51.24963768066899, 58.780270699531805, 60.33653382332095, 60.15876808474141, 56.54522180557252, 61.09541047003962, 57.27968169796852, 60.26231081255021, 59.126772880554206, 59.15589647908365, 54.93821105649395, 53.455347245739354, 47.5556985024483, 47.33190767226681, 46.50220478734663, 48.56020573646792, 46.01235958837694, 51.4251402116591, 48.631867439516135, 51.730845820519235, 54.50257301330567, 61.926937257089925, 62.605687725928526, 59.22945660929526, 55.02038863397414, 61.486384484075735, 33.103184315466116, 50.58769849038894, 62.911887553430375, 55.30150490422403, 54.63494908425116, 53.14079669214065, 56.39416348549628, 54.375417617059526, 56.76773394307783, 56.68510921539799, 60.849246440395234, 56.240528168216834, 57.68496844076342, 52.34718745754611, 57.2608268645502, 55.90609512021465, 57.520032775017526, 58.080355121243386, 58.8446524835402, 59.47505581763483, 59.503238047322924, 60.11309208408479, 58.049725332567775, 59.08285410173478, 56.10661452816379, 56.153094614705736, 56.742728833229314, 61.77236057096913, 61.11708548761184, 53.09891754581083, 57.20772581715738, 62.80726225145402, 62.70211527424475, 65.81031906989314, 64.88600077167635, 62.87489960270544, 54.50910375964258, 38.817908994613155, 29.890737648933168, 29.128195547288467, 8.891259104974809, 10.830323984546046, 5.110652706315441, 5.300628783241396, 5.122886088586623, 0.4301582775529354, 0.23788459568975434, 0.040551017999889395, 0.07797081248774644, 0.035257798604547017, 0.8970795211292083, 14.559152645449485, 40.48407693063059, 46.173796499929125, 58.973259156750096, 36.7685176480201, 22.303232223756854, 40.66610628558744, 47.271420801839525, 56.27200518884967, 54.36080286579748, 28.82014632225037, 1.4238512612158254, 0.17523349623285955, 0.02562698746670879, 0.010465916880827037, 0.033391206224839536, 0.0196572664689513, 0.011102345381532947, 0.038157560141576875, 0.08870701380674878, 0.05664606946670721, 0.05909597268328071, 0.09205317094681725, 0.052192497758134726, 0.09799733142098112, 0.028056286748558767, 0.03107512324687935, 0.015706808640501432, 0.02785999778537981, 0.03850188602002398, 0.05123003468578381, 0.05796411607955253, 0.09517321723603434, 0.017873394348087813, 0.02496839508474354, 0.04237880802623207, 0.05279396870924581, 0.0486189465699417, 0.03545518115823788, 0.06121906279135616, 0.06426225897044906, 0.02468547498386714, 0.10602292980277732, 0.04727997043500504, 0.09914302357262182, 0.03211285828823044, 0.04146909776834711, 0.02958006435824979, 0.02135472004151633, 0.033344880888058294, 0.059567212517703735, 0.036123558398216, 0.04947341039716717, 0.012510699396502348, 0.05937097909589929, 0.0419143442394993, 0.08092899205944232, 0.07147099312034345, 0.03154365304527024, 0.11227033852088837, 0.02188683322240268, 0.16113568578035603, 1.384412442003527, 47.76104634807956, 83.0949806397961, 75.47379970550537, 61.134438053254165, 53.68916757645146, 42.61828168745964, 21.186270636896936, 25.04687720729459, 31.756818986708122, 52.136736608320675, 29.10048596320614, 8.76921553765574, 0.6685483227333715, 0.01679364321452956, 0.040433220490212404, 0.9150683687579249, 2.208227726720995, 6.285452583143789, 11.868704807373787, 12.687094596124465, 19.036315602640954, 10.292593509920183, 11.878227341559626, 12.3332840588785, 21.80871940428211, 35.39523701513968, 49.59983387301045, 61.46382693321475, 63.6362708768537, 61.97897141979587, 61.85753483926097, 65.12952896856493, 60.41445562916418, 59.29075541034822, 54.0783255330978, 53.304018282121234, 53.51297470831103, 60.675669793159734, 62.43888501198062, 61.970118630316954, 57.11458129267539, 59.00979211253505, 56.649666678520944, 61.07090742357316, 60.562980098109094, 61.109425098665305, 56.680182718461566, 56.06260945720058, 49.59800212613998, 49.91365486575712, 49.33446199663224, 51.23198309252339, 46.980894765546246, 52.33798949949203, 50.46036266511487, 54.06326755400627, 57.58837615289996, 64.20850546129289, 64.15016020497968, 61.02463914502052, 55.88921716136318, 62.52331010756954, 35.6475866225458, 52.11966253096058, 64.0871512505316, 57.544673104440015, 58.59391889264507, 55.618895253827496, 59.29781567665839, 57.15562105178834, 57.35203373816706, 59.1208657910747, 63.18883826655727, 56.04557852591238, 56.93606245902277, 53.924976548840924, 58.2777758567564, 57.64252839549896, 57.83082177562099, 58.956836192838615, 61.063537290019376, 60.593821694774014, 61.466325483014515, 62.21632580603323, 60.39051348163236, 58.02932508530156, 55.47240257263184, 56.52378605258081, 56.2473334804658, 63.1931411066363, 61.991558305678836, 55.454343980358495, 58.84397391350039, 65.40592662749752, 65.28101090461978, 67.14584688986501, 65.30821646413496, 64.40253726897701, 56.32358043424545, 40.15661785679479, 22.242107968176565, 10.538465322986728, 6.100193646646315, 6.684438528553133, 9.589198789288922, 10.02128512628617, 6.543284683458268, 3.2410316746081076, 0.6799453821393752, 0.1371378436564438, 0.08233228893650156, 0.07290139418816374, 0.8911712671960554, 16.986700680948076, 40.41078744396087, 49.51374177009829, 69.72763722942722, 42.97054975263534, 30.740526991505778, 48.61560529278171, 53.035861522920676, 64.02811565706807, 62.43069510306082, 37.700300216674805, 2.481244302565052, 0.21662557918217876, 0.005662986574949878, 0.04000536038450176, 0.05834581172694603, 0.08669073933795576, 0.052620982225503654, 0.051698539586317156, 0.057155127231512344, 0.022055485563713218, 0.02254211993497466, 0.09465606192186957, 0.024434018114040938, 0.03538609917966589, 0.016461074870500355, 0.06051280633396199, 0.0344867272783191, 0.06988491532543013, 0.05938367317280462, 0.08740992735951178, 0.006387801033504789, 0.0192690207698052, 0.023544521086038123, 0.021009275674699776, 0.027227504103774988, 0.028019633271821567, 0.01942616838571285, 0.09406507871444188, 0.22640600920684878, 0.08551782042148613, 0.12021716774231005, 0.24095573492588537, 0.16011392367222618, 0.1056751105633955, 0.11357507818648893, 0.08697200085847609, 0.2325613111738236, 0.11702062757385355, 0.13684389571989738, 0.06443139586237169, 0.1031321966119351, 0.1702429543459608, 0.1564326413696812, 0.14630558720279127, 0.11979817127388333, 0.16778180495865885, 0.20722158944174168, 0.15189547031637163, 0.24431121535599234, 0.166439572950044, 0.3582117430144741, 2.804041394302922, 59.478970343066806, 91.10975573139807, 86.41724386522847, 71.10205142728745, 61.95421734163838, 51.64480078604914, 34.24175423960532, 35.48118791272564, 46.369479625455796, 80.46196414578347, 37.299320236329116, 11.046823128577202, 1.11852501909579, 0.18177947239770045, 0.20847319324891414, 0.6771085279122476, 1.6815788058503982, 10.798302735051802, 19.13246270148985, 14.25347645436564, 21.407380527065648, 20.81504575667843, 23.905851879427512, 27.45049192059425, 38.51086585752426, 42.647660240050286, 55.47948637316304, 66.01918528156897, 66.38386372596987, 61.07894828242641, 63.37714341378982, 66.4728073919973, 63.685092618388516, 64.15044653800227, 56.560687711161954, 55.84430602289016, 55.55249344918036, 64.28239899296915, 65.11303932436051, 64.26175163638207, 59.395765104601466, 60.78990490205827, 57.0605427988114, 62.05044484907582, 63.16336247228808, 64.34720439295616, 60.29287784330307, 58.681128871056345, 51.30881447945872, 52.539069806375814, 50.61358221115605, 53.29549889410696, 50.325990107751664, 55.83966978134648, 52.52437660771032, 57.261383841114665, 59.52773717141921, 65.6684704749815, 68.53183207973358, 63.09601929879958, 57.36759378064064, 62.56552265536401, 40.7173442071484, 55.706018940094985, 65.56291949364447, 60.57028355136995, 60.79179548448133, 58.52806229745188, 60.73303053455969, 60.12546323960828, 59.60139143851496, 61.43369528555102, 66.22863984877064, 57.96144846946963, 59.2362658439144, 53.226394576411096, 59.464426194467855, 59.62912651800341, 61.24998715616042, 62.48769890877509, 62.83498948620212, 62.00920112671391, 62.66954391233383, 63.66263312678184, 62.32555204822172, 60.91069429151474, 55.51537606023974, 56.43155936271914, 57.565210634662265, 64.81255046782955, 65.4913362379997, 57.40579374374882, 61.83934288640177, 68.39130140119984, 69.53192664730933, 71.72207616990613, 70.372725917447, 68.3903443428778, 60.727723567716545, 43.98085032739947, 34.023690069875414, 39.41312866826212, 16.531741042290967, 21.062294321675456, 14.092729879963784, 17.37637442927207, 11.554289575546019, 2.801536960947898, 0.5020516762329686, 0.3986150056364075, 0.2106590872450221, 0.18221209757030013, 1.3058287361937186, 20.58371024747049, 55.69333007258754, 57.310531139373786, 67.271041101025, 44.99495952360092, 32.81997349954421, 54.109261266646854, 59.46277879899549, 73.60605332159227, 70.5259023174163, 47.49850250059559, 3.450328121262212, 0.32707351710527177, 0.10027381531413525, 0.15689925020260198, 0.12246332987542115, 0.16088428636712415, 0.08504486838055235, 0.14538162387907505, 0.08210483743178268, 0.1446642744685373, 0.09955600625084293, 0.17335901697797163, 0.09869368236151435, 0.1513580136722134, 0.11239129614325301, 0.12593549315727529, 0.1449867821629009, 0.15984272854703088, 0.07327680791457815, 0.17883979384937596, 0.145811291952287, 0.1671121368605283, 0.09440867680936091, 0.08280690338823103, 0.12662393040955067, 0.15598938289669254, 0.12522500789453908], [0.06422042673934372, 0.02526251539107292, 0.06648849515664963, 0.02663182286215165, 0.039719425727643316, 0.029432644143760688, 0.03042832670372821, 0.020541557929508632, 0.06327078797884526, 0.06933062772957549, 0.06018940614716661, 0.044703226040808425, 0.041923847560200005, 0.06499103075193782, 0.06519763700423703, 0.05281025956895563, 0.07095563811280074, 0.06363474486035205, 0.03358965364074515, 0.0797602636439185, 0.04565899733514075, 0.03430808323525614, 0.06721774191265145, 0.06815993812896552, 7.687783270112931, 53.7142825126648, 72.78761940617716, 64.79151871896559, 53.09882340892669, 46.60034641142815, 23.466505235241307, 37.36478851687524, 69.26243628225019, 68.511992731402, 50.097700318982525, 14.379486518521464, 1.2802307355788447, 0.09201032364921224, 0.09467467019755034, 0.09676046714547182, 0.538493130476244, 1.505602280939779, 5.0235824623415555, 10.27854456055549, 16.03455512754379, 12.601476119410608, 11.165559157248467, 23.21363199141718, 25.079287752028435, 40.90599060058594, 51.49099680685228, 61.945368474529644, 60.586063246573175, 63.989468543760246, 60.32214264715872, 59.43127432177144, 62.77887605851697, 60.30678264556393, 55.5631426841982, 47.55883639858615, 50.440017331031065, 51.76927720346759, 59.16041504952216, 61.11783466031475, 61.669374819724794, 57.45308183854627, 59.62138768165343, 55.543605358369895, 60.86809735144339, 59.78868069187288, 58.816493788073146, 54.791275147468816, 52.51399017149403, 46.43850157337804, 45.02612275461997, 45.982914355493364, 47.638535038117446, 45.74013140893752, 46.26466604971117, 44.722339107144265, 54.89556704798053, 58.595570210487615, 58.39355245713265, 54.98070601494082, 58.12616448248587, 53.77117649201424, 59.38737515480288, 30.705778714149233, 48.388551050616854, 61.606138367806714, 54.752533897276855, 55.161852836608894, 49.441283825905096, 52.05104458716608, 49.74049006738971, 52.90117909831386, 55.502687192732296, 60.416856119709635, 57.05912682317919, 54.95634025143039, 53.45094634640602, 54.42414522171021, 53.987193184514204, 56.08681440353394, 54.12875544640326, 57.14319890545261, 57.75468072583599, 59.314630877587106, 56.44378146817608, 57.952317191708474, 57.15558575045679, 57.93123052966211, 54.77434227543493, 54.254843957962535, 58.50258258081252, 60.35344708350397, 54.695145699285696, 52.46383482410062, 63.40516482630084, 62.43318580812024, 60.186734584070024, 61.27239957932503, 67.00473570054578, 66.4453664902718, 60.00077501420052, 44.067240530444735, 26.099668818135417, 21.237634074303415, 14.36423340151387, 9.098624029467183, 5.006025933450268, 5.600909754153221, 2.98167597862982, 1.3277604238640879, 0.19549580170742928, 0.1161006632291021, 0.04402928317206041, 0.07852497750953322, 3.001522191109196, 31.200530798204486, 40.706118383715236, 24.13386121872933, 20.318522722490375, 22.956248021894886, 26.638308302048717, 39.254645301449685, 49.93946798386113, 57.7704918000006, 52.639584464411584, 12.830104212607107, 0.11557143436925066, 0.03567351621665782, 0.07985671411358541, 0.04717057690985742, 0.021869416213444164, 0.03908361871576598, 0.032651104002950654, 0.08979590053880408, 0.0867513828580418, 0.07581874893437471, 0.00950003226828431, 0.055162206953091014, 0.04101629000938228, 0.06652228729498964, 0.03855693709826277, 0.02116450615557692, 0.030314087672459505, 0.09961570748278212, 0.016620367532595992, 0.04345297437882231, 0.0727754952986875, 0.07198095486889924, 0.02674503725082163, 0.040536086946245165, 0.0384635356585345, 0.059967922467377886, 0.025217205120791352, 0.019039680858352975, 0.06478901336630506, 0.018492740045692173, 0.008917310361510083, 0.033734126331945585, 0.012017621268187801, 0.012356249367698066, 0.042074073571711786, 0.04260658128787914, 0.00354330986738205, 0.016044589255245465, 0.03073597229236076, 0.014361285326641895, 0.05859749076227027, 0.051347598538643895, 0.025008850272804983, 0.04806619881081486, 0.06252754096602721, 0.07049723408154904, 0.0028062226802801657, 0.0105299465095384, 0.022462709175963557, 0.06010142860994224, 9.866316203148136, 64.80987541137203, 79.69096737523233, 73.29529962232037, 59.806099937808135, 57.0621431258417, 34.93688844865368, 43.641631987787065, 69.0077018737793, 55.29170290116341, 47.12543018402592, 16.425043748271083, 1.2105385526534052, 0.047901068558736194, 0.12685354994309525, 0.15440356557167348, 2.1653902963284524, 5.76847585939592, 7.880772707923767, 10.484069893437049, 15.315109087574868, 13.511215948289442, 9.628172439913596, 17.954902456652736, 25.892687305327385, 40.849582995137865, 52.16867646863384, 63.69260787963868, 64.83044432055566, 64.5425227380568, 62.63787469556255, 60.3055117976281, 65.12640676190777, 62.69735351685555, 57.693570198551306, 49.74574604342061, 51.744962430769405, 53.64245999243952, 60.3313837512847, 63.917783306490996, 62.71186236412295, 56.77587678355556, 59.48966272415654, 56.07942858049947, 62.225696348374896, 60.49524468760337, 60.44681126071561, 55.60328422054168, 55.33087168970416, 48.32174524184197, 46.36743607059602, 49.03897023970082, 49.8691398866715, 48.8963528602354, 48.47114439933531, 45.61994214211741, 55.34997755481351, 59.887363603038175, 61.846383540861076, 59.765628922370176, 58.83064177728469, 53.47770475572156, 58.55339688639487, 31.946779374153387, 50.36602181773032, 64.66303363923105, 56.09622024720716, 56.0783185497407, 51.36279806014031, 54.51680729466101, 50.79792576451456, 56.17797813107891, 58.824338528417776, 60.806265108047, 58.66338406839679, 55.99256377066336, 54.87958731189851, 55.02221253610427, 56.74173647357572, 56.41106105619862, 54.68759905907416, 57.923287730063166, 57.80138438747775, 59.12362713967601, 58.249009193912634, 61.1632792411312, 57.618727453293346, 57.94984609849992, 54.50875859106741, 56.63355750422324, 59.52994546582622, 62.9322446546247, 56.3764226052069, 55.09178753822081, 63.155807987336196, 64.915493073002, 61.62894302798856, 63.60276991321195, 67.88194241062288, 68.88887759177916, 60.526839379341375, 46.29583712547056, 26.394462393176173, 15.367105987764175, 5.668115644685685, 8.836823471130865, 9.848644944929308, 11.32303741670424, 7.838488576873657, 2.9367849423039347, 0.26041390854985486, 0.03132745154171942, 0.06845125838393165, 0.06640794101141154, 3.8402296122043365, 30.991627324012022, 41.30007113179853, 32.68199236162248, 21.303998616433915, 24.568724593808575, 35.52217668102634, 50.879624812833725, 58.141093023361705, 65.02954383050242, 63.08957484460647, 17.57366768775448, 0.2432971141271053, 0.11999168508355657, 0.04553379941611521, 0.03741048268913742, 0.08869291778894202, 0.06922266295840664, 0.059629997253538146, 0.0233809364163467, 0.05316779280321733, 0.034430883299078674, 0.06592960337237005, 0.012793556295124995, 0.0748092518939126, 0.03139922631934526, 0.02977151164574729, 0.01526969036222586, 0.0533349838318123, 0.07956288875110688, 0.020724501641046618, 0.012599809786244746, 0.0496990462735055, 0.016114724604713342, 0.04903459523413931, 0.038316707246966904, 0.018066159306815075, 0.0146328414707715, 0.11369081875008923, 0.08443323144268605, 0.18542727665795436, 0.09251789520344428, 0.09225043858731947, 0.06244334407270916, 0.1585737958310112, 0.13001229133336775, 0.10643058050904544, 0.11148732005348129, 0.1053300339187826, 0.08873034118404312, 0.10785787125989314, 0.17075919035461642, 0.2578185558799775, 0.21422069129203597, 0.16016974083838925, 0.23055652036301552, 0.1511355110954854, 0.17128118734446265, 0.1036871890086801, 0.14478528571705665, 0.10978019270565241, 0.14915276829513813, 15.443690265378645, 75.26444711992818, 88.83445155236029, 82.0419889880765, 68.30677432398643, 63.06731931624874, 35.619522063962876, 49.593252135861306, 82.44702862155053, 84.96799084448045, 62.211167889256636, 18.741316103166152, 1.934052335639154, 0.2227009015698587, 0.3378182373219921, 0.30169342253958026, 1.9371936638509075, 8.248940590889223, 14.435275370074859, 18.4053062623547, 26.567742901463664, 23.138779440233787, 21.259301247135287, 31.626168758638446, 30.9910919204835, 44.648261224069905, 54.30893344263877, 65.23764125762447, 64.74173991910874, 64.90433785223192, 61.663969793627345, 59.54449353679534, 67.41976168847853, 65.14084500651207, 59.636465272595814, 51.64991555675384, 55.5134109527834, 57.640908456617794, 63.31478949516051, 66.73750462070589, 63.534677567020545, 58.300427544501524, 60.55405278359691, 56.59442793938422, 65.53369391349055, 64.26823139190674, 62.21263485570108, 58.91784391095562, 57.3194976775877, 50.70747983071112, 48.84992768687587, 51.458770613516535, 51.49668424360214, 51.97054186174947, 50.87993468007734, 48.42839056445707, 58.240572175671986, 64.68310440740278, 64.37269979907622, 61.64896672771823, 60.28629610615393, 54.34707457019437, 57.121449362847116, 36.62146014551963, 52.9802187796562, 65.5426682964448, 59.366598360000125, 57.727639905868045, 53.3269327686679, 56.773515516711825, 53.84166932875111, 59.42915231950822, 61.3670777505444, 63.64202891626666, 59.1866204046434, 55.74477980213781, 55.714789359800285, 54.45233921850882, 56.56679091915008, 57.646525290704545, 56.276892462084376, 57.63514649483466, 60.995750888701416, 61.513123281540416, 61.5607879238744, 61.035080494419226, 59.31645477971723, 59.16834215964041, 54.300982798299486, 57.709710751810384, 61.738792927034446, 66.29783045861029, 60.38202547257947, 57.203297461232836, 68.12183457036173, 68.63396275428035, 64.82282315531086, 67.28862900887766, 72.96116075208111, 73.06182446018343, 66.27477476673742, 51.06377224768362, 30.104489172658614, 29.779248199155255, 25.11385560035706, 18.952751467304846, 14.518056011969044, 19.371580193119666, 9.290147481426116, 3.479168083398573, 0.3914925329867871, 0.27514185696359605, 0.2077213545600253, 0.22463424702084836, 4.1441958950411895, 42.064199832177934, 54.58656664817564, 32.76166746693273, 28.381427257291733, 31.898067458983395, 38.98083248446065, 55.87475930490802, 67.48714016329858, 71.52497706874725, 72.20319409524241, 22.702745237658103, 0.4164723925773175, 0.17354600371853, 0.1507157868435306, 0.17515880266024222, 0.19561848302762355, 0.16378993528985208, 0.18214869613368667, 0.12089393747549866, 0.1833651058616177, 0.11937263241458325, 0.13165876750023137, 0.11909190715560991, 0.1327725214463088, 0.12204939724817393, 0.12558882304977986, 0.19582227773724065, 0.15026888179202236, 0.152820291658563, 0.12031466775243321, 0.11488500426733687, 0.215401952906001, 0.19797765079044527, 0.13562794564472092, 0.07512209155867178, 0.08703106623743811, 0.13795579573319805], [0.045346663288411596, 0.051424027300409736, 0.04332123789936305, 0.038620311721798875, 0.04025914616161778, 0.055484166894588745, 0.05578254664977712, 0.012691649364217395, 0.06757589567813181, 0.024423110937218995, 0.021977216275709293, 0.13148149475455284, 0.06291592456099969, 0.02035634085205534, 0.02477948354827541, 0.09934040612631267, 0.042081703807437615, 0.021471389486724814, 0.09307725430135766, 0.032651977343184334, 0.06913466243854455, 0.057323463561554114, 0.06542239187946243, 0.2329759179584442, 22.991859220689346, 59.77010434673679, 65.47117133294383, 55.88002704804944, 53.71607895820372, 29.12004290088531, 20.596018645071215, 23.124686364204656, 29.142274895021995, 41.98269297999721, 23.143007755279545, 4.051665466639304, 0.14551204268730458, 0.03289371255725142, 0.04417701173693903, 0.23302778211091799, 2.513729372332173, 4.155009379309993, 5.160696266158935, 8.249007271182153, 14.159665126954357, 27.462055067862234, 17.55128468236616, 33.01372289657593, 49.99664437386298, 62.840751447985255, 67.68852249268564, 65.67998655380742, 64.8723195445153, 65.87659143632459, 60.87196873080347, 59.45368282256588, 61.753395911185976, 60.59924633272233, 55.049676972050825, 46.40571055873748, 43.294623821012436, 50.96030012253792, 57.733625442751, 61.58173730296474, 58.78849590978315, 57.67489971653108, 56.98193850055818, 56.17220440218526, 59.11338975352626, 57.11506374420659, 54.39275841559134, 50.18338841776694, 50.79428580499465, 45.84125795672017, 44.20178959446569, 44.573861706641416, 47.32673014363935, 44.518262109448834, 45.73541279762022, 48.80420854014736, 60.697631143754535, 56.47972999080535, 59.41225474880588, 56.52285645084997, 59.98654857758553, 51.41936256039528, 59.85054823660082, 31.82040256838645, 45.651003391511985, 63.4065729571927, 56.0262647751839, 55.500800532679406, 47.253099410764634, 50.19303352602067, 45.1395223986718, 52.008145624591464, 55.08271901838241, 59.506638742262325, 55.98290689529912, 54.065656277441214, 53.37681747251942, 54.9684250739313, 52.63479132806101, 54.682225411938084, 53.7509645185163, 55.1032800828257, 53.80788203208677, 53.112971398138235, 53.63698044130879, 57.78099198495188, 54.20535149112825, 54.974798925461315, 53.44422732630084, 56.67420502631896, 59.40705760832756, 61.269198925264426, 54.763763643080196, 49.80926882836127, 48.085504808733546, 56.566426138724054, 55.98905324935914, 57.35466172618251, 58.50332783114526, 60.40916435180172, 61.886768264155236, 62.168170867427705, 46.66602649996358, 27.762753771197413, 12.30873590515506, 9.594177257630134, 6.594233330219023, 6.3324116891430275, 5.668277932751564, 2.1851960593654267, 0.28416582112831457, 0.04842008163611736, 0.03579898226645685, 0.07215243598987019, 0.03216433173586284, 7.680046394948037, 41.853788206654215, 36.793483534166896, 18.34700022974322, 16.562668931099676, 32.7340147572179, 34.615191336601015, 39.08634424209595, 52.66312260781565, 54.02809958304129, 40.13554688422911, 2.113754499343134, 0.10496093275686426, 0.01830563264628572, 0.12541637665802433, 0.019443466651043104, 0.015928435961775962, 0.06840954489645458, 0.012383909929814118, 0.04537965103443112, 0.04950630238219615, 0.03428280233375488, 0.020758056292130102, 0.0058389732505254935, 0.13622802231580983, 0.05811615388900523, 0.059194334542318705, 0.05737304477201355, 0.05696395382044777, 0.06138803497437508, 0.050702104344964034, 0.025419774089729594, 0.07372396577510142, 0.017969821835116997, 0.04666479034048896, 0.048169563223998395, 0.03399614755424761, 0.02435683092523006, 0.044198990799486644, 0.057142023297567526, 0.047228937487929105, 0.04464510678043289, 0.09985797512795656, 0.038458360734605984, 0.006140258394166708, 0.05804681144053898, 0.1265481183485639, 0.04932165604024645, 0.05823134286930004, 0.017722383096453645, 0.02569213749900941, 0.014110115739787299, 0.05836075427190912, 0.018445790347252643, 0.03417801299703217, 0.047807069570426984, 0.04508098782671075, 0.016757516423240304, 0.03324687525990509, 0.03695642237641639, 0.548234336799191, 29.51994226824853, 69.26726079756214, 74.29504902132096, 64.57826337506695, 61.98057174682618, 36.09142241939422, 23.188483715057377, 27.112373805815174, 37.30475271901777, 46.2500826774105, 26.280848979949955, 4.4508507174830285, 0.1552977893621691, 0.07417061035671542, 0.13740180691163387, 1.0394109352942438, 4.650860217309767, 10.424627354068141, 12.861650855310502, 17.237573515984323, 15.059041073245389, 12.703759766394093, 14.026930159138097, 29.3442161621586, 47.11178425819644, 60.20515403439922, 68.82178152761152, 66.82425175943683, 66.178206013095, 67.58015524956488, 61.930604673201046, 58.50672068134431, 63.39792020859257, 62.5660482529671, 57.94722595522481, 48.85246938274753, 47.05205832758258, 52.13807021417926, 60.22143187061433, 62.620184806085405, 61.178411745256, 58.09357743109427, 56.920635777135054, 57.45479591431157, 61.17495613713419, 58.92782634304416, 58.48128803314702, 53.50285891563662, 51.897523018621634, 47.184528535412205, 46.22561885464577, 46.111544562924294, 47.75990101598924, 46.70222997665406, 46.537863054583156, 50.34990872106245, 61.662024298021876, 59.8814525911885, 62.335412886834916, 58.400440139155236, 60.25689401934224, 51.677984037706935, 59.10152066138483, 33.24679405458512, 47.734903750881074, 64.26743122839159, 57.31961534869287, 57.00577866646552, 49.19978741676577, 52.034366669193396, 48.04397475334906, 53.98272952725811, 57.78350230186217, 62.00096414935205, 55.35606899569112, 54.46189018987841, 53.8948017551053, 56.12937996464392, 54.10861407556842, 54.889993359965665, 55.92671894258069, 55.23524038253292, 53.78870164194415, 56.02714730847267, 55.54690799405498, 58.720293737226925, 55.38307843669769, 56.23848853572723, 53.709842389629735, 55.631874376727694, 63.28621502845519, 62.57593654817151, 57.893140392918745, 50.21009191390007, 51.523732908310436, 58.853332688731534, 60.31078346313969, 59.28756260102796, 61.27605130595546, 60.88544207234537, 65.56387655196652, 62.73864430765953, 49.799557039814616, 28.876757890947406, 12.434813630196357, 7.527873631446593, 11.203546331774804, 9.803069945304625, 9.175549553286645, 5.584802541040606, 0.9859305211613256, 0.3738001613847671, 0.015903065044943605, 0.04483153810724617, 0.014582542052883056, 9.94877815246582, 40.762831934036754, 36.85603357130481, 24.15584610354516, 18.24832712450335, 37.80826737803798, 40.76730343603319, 44.80637981045631, 58.19057764545564, 63.63745935501591, 47.146818868575565, 3.4650450992968778, 0.0416095714805828, 0.03877056837682763, 0.08385565477393328, 0.03818360330056279, 0.05871194046771815, 0.03688670071442762, 0.13685181706903443, 0.0029016633503018852, 0.08472522585502557, 0.014531884488890008, 0.043573617905138, 0.022342749383120288, 0.026692746004330057, 0.07886489072153646, 0.08424519516167142, 0.018635083012463107, 0.029514778345342607, 0.06480451132501326, 0.039679056724473354, 0.06043379968633095, 0.08968423556296096, 0.027262872468019207, 0.0499917378258561, 0.049566995697997274, 0.016181571521766244, 0.0897358775499367, 0.08308752139489498, 0.06601323719106375, 0.16398878107147832, 0.12173323276182338, 0.3227815554747659, 0.22820263860687134, 0.072489085667316, 0.14926754358795383, 0.279645626583407, 0.0824362087634302, 0.28428867098785215, 0.07793436968518842, 0.11700414136172303, 0.09056771113987892, 0.17604197946286973, 0.13157733235388033, 0.18141722006182517, 0.1452062203879318, 0.13508255232966718, 0.21408834194223728, 0.17418554923947782, 0.2833372510729298, 0.9921329528574021, 37.22975307895292, 77.9707884019421, 82.68415158794772, 71.75382383408086, 68.21517913572251, 40.965198778337054, 29.931175324224657, 33.52178750499603, 40.44366475074522, 55.23150236375871, 30.611763423488988, 5.628301135955319, 0.45343962828478507, 0.34948903526509967, 0.25979711584025816, 0.7172602379033644, 7.345433898510472, 14.390933955869368, 14.700156950181531, 20.567628529763994, 25.873377476969075, 39.92966559625442, 23.35583948319958, 37.59065820324806, 52.93892798885223, 62.26290002945931, 72.40409789546844, 70.58891911660471, 70.30047585887294, 69.93341261340727, 62.78052345398934, 60.87187459391933, 63.52243192734257, 65.6069520211989, 59.86426084272323, 50.48219457749398, 47.908598069221746, 55.10814382183937, 62.9624939733936, 66.09915456464215, 61.12223555964809, 58.92508068392354, 57.640943757949344, 58.53464403460103, 63.025075389492905, 60.90487349417902, 60.521469654575476, 55.81035790904876, 55.79574315778671, 51.04451733250772, 49.400852034168864, 48.162991231487645, 50.52784312155939, 49.56593282761113, 50.806080372102805, 53.510487925621774, 64.18797577581098, 61.09754031704318, 64.36245064581594, 63.07575241211922, 61.33971137385215, 52.314474890309, 58.75150011431787, 37.10242117604902, 51.28671976827806, 66.04840693935272, 60.998461246490486, 60.741381260656546, 52.425772143948464, 54.47478302063481, 49.63825348884829, 56.47281485219156, 61.84979992528116, 65.23205972486927, 58.29690133371661, 54.61534507812993, 55.06897895566879, 57.022150639564764, 55.578051613223174, 54.774554083424235, 56.54259381755706, 57.05686361558976, 54.689407271723596, 55.477709539474986, 57.28474547786098, 59.34363288264121, 54.98167484037338, 55.93188470409763, 54.352350158076135, 56.729620272113436, 64.55638831661594, 66.22266215662803, 60.20813111336001, 53.20748482981036, 53.1113749934781, 61.65035916912941, 61.4692594159034, 61.91624879837037, 65.8865777907833, 64.75340112563103, 67.30316531273627, 67.86168729105304, 52.49560602249638, 32.53913571757655, 21.12666237738825, 15.103969862384183, 16.548528786628477, 15.03495477860974, 17.697824432003884, 6.137524804761333, 0.5771174450074473, 0.3322577873064626, 0.16446786181580636, 0.12067480568563747, 0.22233000776219755, 11.14251523248611, 54.939697634789255, 49.70650272984659, 29.257884794665923, 27.88241351804426, 44.12150652177873, 45.73078440081689, 53.52541646649761, 68.87171329990511, 72.47990162141862, 57.24028933432795, 4.1991723256726425, 0.28009746524114765, 0.1584715843801537, 0.20653974054561508, 0.09749520675189073, 0.11958039545964812, 0.12845370843405687, 0.28700816054497996, 0.18169362458490557, 0.21581511944532397, 0.17385179537438578, 0.11124204168276441, 0.11703820929171578, 0.22434425209799122, 0.15403942865950448, 0.24315741033323351, 0.13035876225800286, 0.1631235154045205, 0.12149844979566914, 0.14626182826055636, 0.09588968564545917, 0.2909930741354343, 0.11130531288443074, 0.1972882329456268, 0.16885455787902878, 0.10686158923612488], [0.04240055726240239, 0.013271413213993995, 0.03724711826972423, 0.01574211763293152, 0.046365621514738574, 0.039926671663359295, 0.03221394358983925, 0.03921046755426834, 0.039216734153488954, 0.05869355435753542, 0.01544185713188903, 0.11187932724433561, 0.09196318625923126, 0.010513592447574821, 0.08704182211189501, 0.01865238702345279, 0.04183446042119496, 0.0495732278232613, 0.020362996240897525, 0.053894457842914335, 0.025043718764678608, 0.035759191659669724, 0.046061078582199357, 0.8495507521494743, 32.30987710337485, 72.0225767935476, 59.46471644986061, 58.85267373054259, 41.45822501951649, 30.466467065195886, 31.921846828153058, 42.02443092100082, 54.12137746810914, 35.80303015247468, 9.994464939640416, 0.48066234816947295, 0.024981522001326088, 0.032626619832890655, 0.4501017831986951, 0.26969224454895147, 2.9393129098799924, 6.457025879813779, 6.731436367957824, 9.75221739661309, 15.532357404308936, 17.599778905991588, 26.789256795760128, 53.859665163101695, 59.68043504222747, 63.55138686395461, 62.90800440695978, 58.584336542314105, 56.62848980196061, 60.463457799726925, 61.80885430305236, 57.82449499253304, 61.15287711543422, 61.583529826133486, 58.869198676078554, 46.76469764401836, 44.55146105058732, 49.461609548138036, 57.19125578480383, 60.14326687782042, 60.92995705143098, 58.29755244716522, 56.05108945600448, 57.46589229952905, 58.17648456942651, 58.46188799027474, 53.88309740251111, 49.20363133953464, 48.67008309210501, 43.35821328624603, 46.0840997388286, 44.53967825058968, 47.13963308641988, 42.42281821466262, 45.66288425076393, 54.06581709461828, 61.42627416118499, 56.34872674942017, 57.10029209813764, 54.23510266888527, 59.50637986583095, 50.84389202056393, 59.72686806032735, 33.031765799368586, 42.907089725617446, 62.75451029500654, 53.3393588373738, 54.512088683343705, 45.17150932742704, 47.86646004646055, 45.10748055673415, 52.43458570972566, 55.55330145743586, 58.36806097338277, 54.2814572395817, 53.91435084804412, 53.83520134033696, 53.00765575901155, 53.02239210374894, 55.20801521116688, 52.45303653901624, 54.6161138626837, 54.47624214233891, 54.24545772614018, 54.16044035265523, 55.28932594483899, 55.004302993897475, 51.91604445057531, 52.85080409819081, 53.70593963130828, 57.18062616163685, 59.5649447748738, 58.242003840784875, 53.88197560464182, 49.53473429526053, 44.69529828717632, 48.3059145558265, 54.813742483815844, 56.17263194053404, 62.57228482154108, 61.32644984029955, 64.20575195743193, 62.64233443044848, 47.04955977778281, 17.524165414994766, 11.23346911322686, 9.711998393458705, 7.6327891888157025, 8.081607376375507, 3.2719276941591695, 1.4061830673486957, 0.09915704298163615, 0.15688598155975342, 0.03310902539881007, 0.1131796695652508, 0.8540546749868702, 20.09396703012528, 46.90262386875768, 44.484062963916415, 25.171530131370794, 20.342906136666578, 50.30489952333512, 36.16363325426656, 48.25161718553113, 52.655948592770486, 48.69401347252631, 12.060156676077074, 0.5814623279917626, 0.0725250611562402, 0.08333321345309097, 0.017363645188931017, 0.06801359235279023, 0.006995698983495635, 0.07067618455978171, 0.010100405798443865, 0.06094229437651173, 0.0526156923883865, 0.037974300418770125, 0.06189983533394914, 0.03845898126582465, 0.012159344661349972, 0.01215811987828103, 0.04043746461731292, 0.03673857761426799, 0.03994572427003615, 0.14199393711263134, 0.002941482206581221, 0.01717901225351999, 0.03531253558673686, 0.02487112681621746, 0.08124216880288818, 0.07205115916628031, 0.10669341761498682, 0.04305221080299347, 0.02514587850460122, 0.025892417780273867, 0.011851677047689597, 0.04935334143679469, 0.0375285828035445, 0.06120923388328764, 0.06361198438812168, 0.09351632227340052, 0.017501632945852417, 0.03806424297152027, 0.09956575088923979, 0.020626582197784897, 0.09087048440931306, 0.022224434764094414, 0.03872423154872753, 0.017855803054126523, 0.01786339690067595, 0.0600464771231336, 0.07053014521877612, 0.02926349001485975, 0.033997480547235864, 1.4599923477057488, 41.44651282218195, 81.2696272327054, 67.51673836861887, 61.879527568817146, 49.569466883136386, 38.76800075654061, 38.45653710826751, 33.46862369968046, 44.31495781867735, 37.77851620028096, 9.949950941147344, 0.630576960261791, 0.022984817248558807, 0.08186654578293524, 1.299147223753314, 3.2616876113799314, 8.127563336203176, 12.427973997208381, 12.723123527342274, 13.755215810191247, 10.22835587301562, 11.743217399043422, 26.644260498785204, 50.70475378344136, 61.152124020361136, 65.72640780479678, 64.45698368933894, 59.60700042786137, 61.36541466559134, 63.871985712359034, 64.01457171286306, 60.370219138360795, 62.6790556600017, 64.42329052955874, 60.483960028617616, 48.7429528851663, 46.98464455143098, 52.287026143843136, 58.7582112896827, 61.379558732432706, 60.89397714984033, 58.58365012753395, 55.341968074921645, 58.009811293694284, 59.50551302202287, 58.98972526673348, 55.97587408558015, 51.51913981283865, 52.50069333660988, 45.93508497361214, 46.14257051098732, 47.34921709183724, 49.64512155902002, 45.15371745632541, 46.845420022164625, 56.44995920119747, 62.55832510609781, 58.30169447006718, 60.356600669122514, 57.55122738499796, 60.36946212091754, 51.70261652238908, 59.7482410553963, 36.31529561934933, 45.08942588683098, 65.06765357909664, 54.989080275258715, 55.82941278334587, 46.29947708499047, 48.28903659697502, 46.86823252708682, 55.32823193457819, 58.18493335477768, 60.64738950421734, 54.96208260136267, 54.61986757093861, 54.528974486935525, 54.17905199912287, 54.13226596770748, 54.51720737641858, 52.98922846394201, 53.84798042235836, 54.314762084714836, 52.14398907076929, 55.29354249277423, 54.7036180188579, 55.67746408524052, 54.33759420148788, 53.40821996811898, 53.41324060193954, 58.18938916729343, 61.96727491194203, 60.64319649050313, 56.268690786054066, 49.65309573758034, 46.14810105293028, 49.78746437257337, 55.57506276715187, 58.99529895474834, 63.701629331035, 63.19339998306767, 65.63023128817159, 65.76513336550805, 45.1759494504621, 19.03878277347934, 10.580676890188649, 8.109687134142845, 6.7503402310033005, 8.352849079716592, 9.4796165920073, 4.961151076901344, 0.9226090028401345, 0.02849156641581607, 0.049360672898230054, 0.060778715452479745, 0.95551339849349, 21.51702057930731, 44.54319269426408, 39.53534187809114, 26.18489996079476, 28.270741893399148, 54.93032709244759, 39.85956107416461, 57.446456955325225, 58.73045267597322, 57.76953081930838, 15.768055569741035, 0.6150832303589391, 0.022238651440749248, 0.026183272636826002, 0.017634516641978296, 0.06309924174040075, 0.012710361061767947, 0.06302714903628634, 0.014779664136679664, 0.03930204953517645, 0.057234559057941364, 0.009544234583905388, 0.03103385600561817, 0.006882808266973664, 0.0331897480833915, 0.06318940645864894, 0.047191494940629894, 0.08102928829048911, 0.10326266138544006, 0.09696614643138263, 0.022470235989819613, 0.013097650108618603, 0.02282635004620158, 0.0159836019532034, 0.04594875860118097, 0.07793475272915057, 0.2620671262904521, 0.11593868159839224, 0.17397513553019495, 0.08664801461441864, 0.08806699331128791, 0.21141255004031045, 0.0809282029888803, 0.16821309713827026, 0.1451263787044633, 0.2218982252863146, 0.198486348493926, 0.11787270120675526, 0.12403922636182078, 0.2007468441321004, 0.1686947366162654, 0.1480572012763831, 0.1812543957343986, 0.18845310945424343, 0.07177088589918229, 0.196854688467518, 0.27482754641002227, 0.14234880436091654, 0.17558068728014348, 2.6324629495220804, 51.08367043156778, 91.82002636694139, 76.87342689883324, 72.80066520937028, 57.31133130288894, 43.76201345074562, 43.254525430740856, 56.677994035905414, 68.0902281115132, 44.479481635555146, 13.263787934857032, 0.8451309151226475, 0.12587524034203063, 0.21499744316022243, 1.343135624643295, 2.803288544377973, 9.816169681087617, 14.676774720991812, 18.99132601676449, 19.283209193137385, 24.008166905372377, 25.435666461144727, 31.259156503985007, 57.69962241572719, 61.13438314007175, 66.38001980320101, 66.31670490387948, 64.07387794986849, 61.39890386212257, 66.16432866742535, 64.72801946824598, 59.116829672167384, 63.001435264464355, 66.73415491657873, 62.17250508646812, 51.67033149350075, 49.048427074186264, 55.3933628912895, 61.7824096833506, 64.10222099673364, 62.28787376034645, 60.40739928522418, 55.71579740893457, 58.94592023664906, 62.69204655001241, 63.1454215511199, 59.045391544218994, 54.29554247087049, 54.329208174059474, 48.63865706228441, 49.606941207762695, 51.03268746406802, 51.21585430637483, 47.559652251581994, 50.27987872400592, 60.18696600391019, 65.15747977841285, 61.478626035874896, 62.21347816528813, 59.205969456703436, 62.2220406993743, 53.318687946565696, 59.0364367731156, 38.87988244333575, 47.851284396263864, 67.2324763574908, 57.962421217272365, 58.411760099472545, 48.30525952000772, 51.998002375325854, 50.86165643507435, 56.39510877670781, 60.49351099998721, 63.768795997865745, 56.37698742651171, 55.59869896981024, 55.88109001036614, 54.64440199636645, 55.15024262089884, 55.03303827777986, 54.40919314661334, 55.052348106138176, 55.12402942103725, 52.785076941213305, 56.057110294218994, 55.74008080267138, 55.74817265233686, 55.89716780570246, 53.76896427523706, 54.49277493261523, 60.485497597725164, 65.1175186710973, 63.67706352664579, 60.13421404746271, 53.47996011857064, 48.146909513781154, 52.05178983749882, 58.84558208527104, 60.243907051701704, 67.89678465935492, 66.25041684796734, 69.82844998759609, 68.12945181323637, 53.07108440706807, 21.79315151706819, 18.78397580116026, 18.994565894526822, 17.10131233738315, 17.39115195889627, 12.7935084988994, 5.142948521721748, 1.0612026433790884, 0.4521374933181271, 0.26636190712451935, 0.26835909834311855, 1.4483851963473906, 25.81933113836473, 60.70634665027742, 55.138087195734826, 36.323285487390336, 27.809226012999012, 61.39853908169655, 49.63624523532007, 65.73607252490136, 66.95047363158196, 66.13320858247819, 20.03848510403787, 0.8198824957493813, 0.13937501957820309, 0.1237236824066889, 0.11426027488684463, 0.27404325623666087, 0.07771301624034682, 0.1401300911581324, 0.21070451625893194, 0.15585753916492387, 0.24745464264865846, 0.15646346874775427, 0.12910509001343481, 0.11851199391868808, 0.12560887157075828, 0.10437473759896333, 0.1790031850818665, 0.11312450357382337, 0.1285685986400612, 0.19365679232343552, 0.08505978411243809, 0.09026426371307143, 0.10329612410597264, 0.07112597010188526, 0.24420013260697168, 0.16593881191745882], [0.013624331726121807, 0.05193527224623869, 0.022691102968829296, 0.021227777357243245, 0.05278740716617435, 0.058915493859639095, 0.047589021794978655, 0.008270960064574836, 0.050931961365765145, 0.046683950199475216, 0.04785063316024119, 0.03245303963100718, 0.014787220636442786, 0.04751852255374674, 0.07713737777404248, 0.02821980821599643, 0.03565042249618038, 0.040510016974181905, 0.05019160250442163, 0.09009805327701954, 0.04423655592085374, 0.03150215406241196, 0.045812992499239986, 4.283918075023159, 50.20467119832193, 62.797468093133745, 57.3001721597487, 48.195276260375984, 23.29854738327765, 15.68883251759314, 19.398936763886486, 53.6959062084075, 53.26535547933271, 15.658812657479318, 2.0120250097205563, 0.01876454229556745, 0.21416773929470972, 0.030045453196151123, 0.4438555925603836, 2.828523112881568, 5.155801148183885, 13.67553089895556, 19.881194137757827, 17.095693542111306, 20.364210490257513, 27.759266784114224, 47.24148135031424, 56.43535229467577, 64.02785285826653, 64.25842938884612, 64.78616468368038, 57.94093447346842, 58.89288586954917, 59.571930516150694, 63.806340925155155, 58.563422464555316, 60.11421388195407, 58.758552535887695, 57.43707072350287, 49.659681397099654, 42.88512445265248, 47.93146940969652, 58.403613336624645, 58.78414207889188, 59.332352146025634, 57.49347440658077, 57.84626806935957, 56.788043975830085, 58.41545889454504, 55.22710538679554, 52.10105872923329, 47.881000272689334, 47.89543459492345, 43.3397271556239, 46.26763528393161, 43.06093685088619, 44.602247899578465, 42.04241891061106, 47.88538156017181, 54.850985388601984, 59.201941182536466, 56.1024332815601, 60.20491869218888, 55.3556179231213, 58.994796891366285, 52.37456952371905, 60.08355271431708, 32.17866793755562, 38.40067078990322, 61.894008959493334, 54.64389993298439, 53.7955383331545, 44.01393159743279, 45.793538401203776, 44.75042327757805, 50.47436552663004, 52.8209940848812, 58.31381067152947, 56.26706692480273, 55.71334592757687, 54.0717084946171, 54.66867754536291, 53.31378890622047, 54.66932081407117, 53.05949772557905, 52.58933105776387, 53.15973781770276, 53.226645608102125, 52.51154653487667, 55.26867466588175, 55.44545196717786, 49.741243162462794, 53.84219100398403, 53.47104457116897, 55.17202746483588, 59.14508250451858, 60.291740355953095, 57.2609680698764, 54.4231685515373, 51.218195961367705, 45.554340500985425, 46.64355916361655, 53.02713817165744, 56.49451340398481, 59.33692955201673, 61.616564027724735, 66.39111226604831, 56.54162891449467, 38.19334999207528, 21.236561306061287, 13.037351465994313, 5.001101397698926, 4.493189271419279, 7.587648591687603, 3.7084485157843563, 1.5041804217523145, 0.17051463976742762, 0.11621339306715997, 0.10748360666536516, 0.1369445903166648, 3.420540906729237, 35.49950930380052, 44.566675924485736, 30.124193199219246, 14.4115303216442, 20.926233183953073, 45.489660616843935, 45.835115525030325, 57.30826400941419, 51.40604219129009, 20.79436702112998, 0.4762418676287898, 0.18231182689628295, 0.02205473288232761, 0.03062610187748027, 0.035764688340526436, 0.03649013530042383, 0.04518997915569813, 0.04757491428585303, 0.03686570224442309, 0.06167959654703737, 0.04883352779753266, 0.10289021241929262, 0.020599068149984367, 0.029626736349816767, 0.012599533036982101, 0.1105445109668278, 0.03512802331017391, 0.014247103751967511, 0.023864125307168693, 0.02929613493653315, 0.03013103862383193, 0.026481422565637097, 0.04003165252206307, 0.03441470735255749, 0.010703742173650574, 0.062434568535536535, 0.008277973599521624, 0.06514960329138464, 0.029832394568309672, 0.047839877285784295, 0.02505894476217368, 0.022968455525715987, 0.046287124315577174, 0.041908062318520206, 0.049724982180182016, 0.018804371206750794, 0.02406339243715329, 0.06259571896084855, 0.015697494926561993, 0.022612785800330104, 0.07580791645112538, 0.029500372061926513, 0.04551293884193705, 0.014200304398283124, 0.05512803177078886, 0.05897114248645883, 0.08270470725913202, 0.026863995383703904, 6.608392105948541, 61.43433855425928, 71.51630863066643, 64.55343084950601, 56.88236913373394, 34.785002508471095, 24.167562223249867, 23.8364847629301, 54.57854147880308, 54.928573792980565, 18.9661189048521, 2.3354782404438144, 0.03826862756883906, 0.11223764954915932, 0.27096897604004033, 1.0041329541033315, 6.955832714034665, 10.164473210611652, 11.351568737337667, 11.522965527349903, 11.426241840085677, 19.64779350065416, 26.471627181576146, 51.223298964961884, 60.63643824669623, 64.60484135535457, 65.09223115059638, 67.42457051430979, 58.667545703149614, 60.67398709635581, 61.423395141478515, 65.89969419663953, 59.18163114978422, 61.407195752666844, 60.8324900750191, 59.37490201765492, 49.99629528291764, 45.213235501320135, 49.82940627682594, 59.37053641965313, 60.007792134438795, 59.954075274928925, 57.483099737475, 57.40186352883616, 58.1296593143094, 61.12507535565285, 56.31753213943974, 53.25440814418178, 49.71712843064339, 49.38542142991097, 45.88266249625914, 47.365377256947184, 45.79595850360009, 48.03803628490817, 43.906521412634085, 50.0724990906254, 55.96134954883207, 61.40740363828598, 59.93433006348149, 62.30360246473744, 57.09026259760703, 61.18773521915559, 53.39061244841545, 59.113170100796616, 34.72063641394339, 41.38765765774635, 64.65614595720845, 56.297237796168176, 55.94106305030085, 47.01277579030683, 48.91763171842022, 47.334300318071925, 50.81616086344565, 54.099243533226755, 59.84218966576361, 55.92338885030439, 57.21422126216274, 54.16235446929932, 55.92570304870606, 54.286650457689845, 55.74883161052581, 55.841372090001265, 53.52118422908168, 53.54851530444238, 53.56917835051014, 52.58127058705976, 55.676016730646936, 55.3146723008925, 51.35915417825022, 53.939481473738155, 53.00345097818683, 55.767651142612586, 61.63818413211454, 61.082239151000984, 59.33135194163169, 56.47840422968711, 52.859547061304895, 47.080907360199966, 49.322514457087365, 56.17574238008069, 59.98885100887668, 61.96693366573703, 63.67661637644615, 68.0339656337615, 58.896655267284764, 39.24650638334213, 16.34004206426682, 9.513448995928611, 10.74341308686041, 8.743952531968395, 7.706463067762314, 8.020764060558813, 3.7243179352052755, 0.22007749476019414, 0.18611445752603395, 0.04202329343365085, 0.06241406802268279, 4.311686004361799, 37.67401249177995, 49.191993667233376, 33.33283908905522, 19.88765428143163, 33.5126248482735, 53.74343749015562, 51.25952989824357, 63.16477060317994, 62.29976246433874, 28.49668022124998, 1.1536641851548226, 0.1482039377573998, 0.04030733309205502, 0.015338744570110596, 0.04550581422424124, 0.05015947277687731, 0.01689431482865926, 0.08229926288608583, 0.033133708751730384, 0.09458447100534555, 0.01745159974351766, 0.08110773569393544, 0.06540451904818897, 0.040884442447173985, 0.02227514978468178, 0.06516797407980889, 0.026195401723887173, 0.015083100072168296, 0.04133505153379614, 0.05324191564033109, 0.0651422028820361, 0.01954164656419908, 0.016390608188005227, 0.0638515247602857, 0.03837552747779316, 0.1900738450668512, 0.1340907442593767, 0.32892389523406185, 0.12429146847176938, 0.15411504153763095, 0.12275553879237945, 0.08756119142016096, 0.15894422998591778, 0.13009193383397596, 0.16659994579611287, 0.13861611755865236, 0.08897088513138796, 0.12537922905457596, 0.11599175616978638, 0.12338616704988865, 0.15902837708352074, 0.14657531143917193, 0.16733918999952657, 0.17227170838704034, 0.17966261824532864, 0.16817983360059802, 0.09801320476277221, 0.1585263137014643, 9.673176734678208, 71.9342528620074, 77.4769227735458, 73.09687476004325, 62.46097972316127, 35.59876488101098, 23.676938433800977, 27.919154359448342, 66.34508717444636, 63.342528497019124, 23.5802500478683, 2.9662946491472186, 0.14103572965869982, 0.4211893797882142, 0.41902754095292866, 1.0392096686747767, 9.529168874986711, 14.117810495438116, 25.812576816928004, 28.41202762819106, 25.417611791241555, 27.751488724062522, 30.821867142954183, 51.99919869822841, 59.191601814762244, 66.55578905536284, 67.23492391647832, 69.87806797027588, 61.71487823609383, 63.65234082744968, 64.43681093954271, 67.16291704485494, 59.44149994081067, 61.27562376760668, 63.06005116431945, 62.896374579398866, 53.12294598548643, 47.335049490774836, 52.355369521725564, 62.87636264677971, 62.25325884357576, 60.88392019271851, 58.31824687219436, 58.17537061629757, 59.32068701713317, 63.17094049146099, 60.020320184769176, 56.07494531139251, 53.74561048323109, 52.672100913140085, 49.1513422227675, 51.08441568190052, 47.464981925102975, 51.61280993492373, 46.479549177231334, 52.53495524006506, 58.25543795862506, 65.29384097745343, 61.07759898708713, 63.081718337151315, 59.63879516047817, 64.32315241905951, 57.0349964018791, 59.845284415829575, 36.18188404267834, 46.12809696505147, 66.84464808433287, 59.34845739795316, 58.598849311951675, 50.63023267253753, 51.39141175054735, 50.01875085215415, 54.4734101910745, 56.80047004453598, 62.016112342957534, 59.4493446811553, 58.76762497809626, 56.36778946845763, 58.198877380740264, 56.64957254163681, 58.25492020576232, 56.407075928103545, 53.722766599347516, 55.211431595586966, 54.87051094731977, 54.786999763980994, 56.172977109109205, 56.44306759680472, 50.86718697701731, 57.32149024163523, 52.4189668316995, 57.260489540715376, 62.64381316400344, 65.63112951094105, 61.240785275736165, 59.33354454655802, 55.71964525407361, 49.647322008686686, 50.75483852817167, 57.75239398402553, 61.669692531708755, 65.26302291500953, 66.29156251107493, 72.09492883374615, 58.453890277493386, 44.36370111280873, 26.72107227386967, 26.10140838930684, 15.821553757113797, 18.423458991512177, 15.229188588357742, 11.018992931612077, 4.2497630561551745, 0.2096367429100698, 0.4373554590969317, 0.24443510709510696, 0.34491665481079015, 4.779716941618151, 46.75128313802904, 57.322961130449855, 43.10110584382088, 23.858565745815156, 30.74264507139883, 58.300815859148585, 60.28716687233218, 71.7666264503233, 71.05213534447455, 39.13466784261888, 1.6686657503727944, 0.21791058442284986, 0.13378841532093863, 0.1066702357943981, 0.15454581277745386, 0.1498878909455192, 0.08618940373942738, 0.15971972546990842, 0.16646561993946954, 0.3071291534410369, 0.12878969161500856, 0.21707184071983063, 0.1824691353906547, 0.12796436211154347, 0.07708174446898122, 0.14482919787687643, 0.0933358779237155, 0.10892867831693542, 0.17996050387380585, 0.10668933436635042, 0.13838426870924814, 0.1615671158557938, 0.10591324899465808, 0.10531017691978525, 0.1317946714979987], [0.03950607790161045, 0.042129568980946656, 0.021711619338020686, 0.04633649868229705, 0.10419705882668497, 0.02664684010068736, 0.018800734204330274, 0.02590040999254392, 0.019355816616406365, 0.02468091101505824, 0.05048543169733979, 0.033449490194118796, 0.0629256615385173, 0.03189769483381703, 0.057188574630286426, 0.04897007147871679, 0.038023226624054295, 0.0023852006275011527, 0.04077196541813113, 0.0398309949424959, 0.060706492513418205, 0.035330182422072656, 0.1286743340953704, 16.70036373599883, 63.26774458731375, 64.58347228265578, 52.17504247542351, 32.973612739193825, 20.516035633702433, 24.60964079826109, 43.65955329710438, 41.41535351353307, 31.312139880272653, 6.888609172836428, 0.2535684686154127, 0.05785015283993656, 0.05291645084657977, 0.10527487558823441, 1.6815142093166229, 5.408738620819585, 6.636825857623932, 8.135466912100393, 9.251252278204888, 21.59386177216807, 32.39398840935, 37.98375814191757, 61.38980788569297, 63.278664465873476, 64.04594282950124, 61.10003886684295, 63.59296006541099, 53.20888511596188, 51.33939719969227, 57.555993064757324, 61.73268971904632, 58.532922114095385, 57.84080028533936, 59.066109503469164, 57.83134345085391, 49.64212486820836, 44.27881317753946, 46.90408299046178, 53.91735538359612, 57.97895792991885, 59.13637092036586, 56.556992838459635, 58.59840216175203, 57.846789744592485, 56.804361035746915, 50.918970108032234, 48.35603852425852, 45.756974066457445, 45.661825210817405, 42.147452139085345, 43.97226425909227, 44.34115140668808, 44.8351425509299, 41.15614368069557, 50.33995766793528, 53.85017302728469, 58.586976297440074, 56.1206683804912, 60.23057099311583, 55.80540395552113, 59.31155181700184, 53.200950161103286, 58.90844983439292, 36.95785437860797, 38.79861093336536, 62.01639083123977, 53.879171109968624, 55.31430752046647, 43.615332495781686, 44.43588056871968, 43.546553734810125, 46.3511464672704, 49.66949124490061, 53.80231618881226, 54.15954997462612, 58.02302575880482, 55.978823707949736, 56.4681472316865, 57.40704497983379, 56.684054097821644, 56.38626383196924, 56.58588893951909, 55.39669690593597, 53.55508527448101, 53.41574307410948, 53.900351908899125, 54.81968095225673, 53.272533416748054, 49.06576395034791, 52.98654556274415, 51.985144845901004, 54.8332013622407, 60.16816216130411, 60.19500686276344, 61.33063500927341, 59.89290983446183, 51.26402101209087, 44.84235186730662, 49.38909276839226, 58.17140902242353, 58.61502908891248, 61.901532065483835, 62.31522444755801, 54.61769850023332, 51.43948824174943, 35.53181786690989, 12.956684001030462, 7.519822966667914, 6.344876000958105, 9.9319492232415, 6.978671204659247, 1.044760803061147, 0.19519603150265832, 0.1449793204665184, 0.08773169194858882, 0.025489825169525804, 0.1628314673660263, 13.211367418689113, 40.00671271354922, 42.88103342056275, 25.73308998538602, 19.308024068032545, 35.82081025646579, 36.51562283116002, 51.012122477254565, 50.35325842518961, 34.79279233563331, 6.390297537849796, 0.15909804511935483, 0.11184081600438203, 0.04529147048390681, 0.027014102651587418, 0.06643180465025288, 0.0951874205061505, 0.02205276020592259, 0.009417707502331224, 0.026969238627521742, 0.057734462072051344, 0.027499574484423767, 0.0412835895774826, 0.07164368466023477, 0.009373700539130838, 0.017579662831380002, 0.07567659365914522, 0.10494922693338125, 0.06796337528935364, 0.030513609526678923, 0.02265902112178024, 0.04010833792328354, 0.06524561709093471, 0.0447767245162639, 0.01322156674559078, 0.07059962173262913, 0.05517984995798719, 0.12788434422785236, 0.057570174516689394, 0.08122293999598873, 0.05016797635283682, 0.02173495246097446, 0.003319397688873353, 0.07396395813914076, 0.08458013646304609, 0.02624207180023434, 0.07836791416329723, 0.07082351092850009, 0.020703152685816732, 0.09073065804137338, 0.013078564943204965, 0.03928754749076982, 0.07016599298484864, 0.04370810847068506, 0.02352523099210474, 0.037849562152499155, 0.0432150810956955, 0.014886816854648774, 22.757603506888113, 70.96605500867291, 71.80449301196684, 61.0974108788275, 38.14878402217742, 20.830768577514156, 23.344690145984774, 37.08691604675786, 42.39748362571963, 36.65956597174368, 7.065132990960152, 0.18419612739836017, 0.06756059690228394, 0.06069181426878899, 0.7104405844884535, 4.541224087438276, 10.212168251314472, 12.363885410370367, 13.88679171762159, 10.85989277209005, 12.431541392880103, 26.585572035081928, 44.01957981048092, 63.67590642744496, 65.23568791727867, 66.88174586142263, 64.77787279313611, 64.69713472550916, 56.41430485633112, 54.84719637901553, 60.11490029673423, 63.87106395536854, 59.52438746729205, 57.48617095331992, 61.15841550211753, 60.16933494998563, 51.51167554240073, 44.578180236201135, 48.731723139362956, 55.644496563942205, 60.939594314944365, 59.717870143152055, 56.62938802473007, 58.14714916290776, 59.83822022714923, 58.87929093453192, 55.457054338147564, 49.9997587357798, 48.259010853305945, 48.26567496022871, 44.21444316064158, 46.366894783512244, 46.07022239315895, 47.78865983409267, 43.777589182699884, 51.96103795882195, 57.32548713684083, 60.31631792745283, 57.70943226352815, 59.57014191535212, 56.65168669915969, 60.8901842178837, 54.677126330714074, 59.75487378335769, 38.32876589990432, 42.528016182684134, 65.06821840040146, 56.560307241255245, 56.40624438562701, 46.06680208636869, 47.04910086047265, 44.56715445364676, 49.34154971953362, 50.76610749767673, 56.90792729777675, 57.508873631877286, 59.63901873557799, 57.87507395590506, 57.80979787149737, 58.510725421290246, 60.07520983296057, 57.35907831499654, 56.99621592798541, 55.71106310813658, 55.32047740874752, 53.57367730909779, 54.88718886529246, 53.95009540742444, 53.8159268133102, 53.10809589201405, 54.09303442124398, 52.320652623330396, 55.69990004262617, 62.637404011141875, 63.36970659994311, 62.263119682188965, 62.81239663400958, 53.006004441169004, 47.57761278460103, 50.429838780433904, 59.276819229125984, 60.35916589921521, 64.35614739694904, 63.88525901302215, 55.673981020527506, 53.62657439324164, 32.571142258182654, 11.957215051497183, 8.510015510743665, 9.691858983808949, 8.996655152690026, 9.109641967281219, 6.802715639914236, 2.9013022011326206, 0.2515681977233579, 0.0408064317138445, 0.05400778522955314, 0.10387583816003415, 16.137052543701664, 38.927017565696474, 32.38935412899141, 25.04574364231479, 19.137473529384984, 43.40336761166973, 42.79967561844857, 57.00875182305613, 58.7333042390885, 43.23628248706941, 8.6560865371458, 0.13709558624654047, 0.03430760443030346, 0.03192156996397722, 0.027649666430548798, 0.07067376372194098, 0.018635818456870415, 0.0504274656545491, 0.039077896038971605, 0.014091591733778197, 0.018775495437664852, 0.01709526926729708, 0.05424975410043713, 0.03726202634073073, 0.015205637750876768, 0.026287650201289404, 0.040888196278002956, 0.06380010876924762, 0.044249747954909845, 0.06368275176012708, 0.02386491054729108, 0.055142231210465395, 0.06110591160493994, 0.08238914032136241, 0.06590727190937727, 0.11551672803057779, 0.11723602851552349, 0.17352239288870366, 0.1226663661579932, 0.1759061673956533, 0.11119704167809218, 0.09545721369044435, 0.141695668440192, 0.2705187308451822, 0.15757572116150012, 0.17918313913527997, 0.13966752726945186, 0.24323415702148793, 0.07524991332883797, 0.2779667602191048, 0.09518861560331238, 0.09654814587725748, 0.18880532603831063, 0.1355399068204626, 0.15467830002307892, 0.1197654516586373, 0.19116063271799397, 0.2801350954799883, 30.5951423798838, 82.65499268808674, 82.15944828525667, 68.90404931960568, 46.84992290312245, 31.22095261850665, 33.33100341981457, 59.16401578534035, 55.37424133669946, 42.55100519426408, 8.742529692188386, 0.6416004139088816, 0.13421224580416757, 0.15657337172137153, 0.35308425525023096, 6.06467854592108, 15.336060427850294, 20.0846984694081, 18.666528271090602, 21.29159019839379, 30.947939965032766, 37.842729322371945, 44.945812225341804, 63.70876412237845, 67.20487071621802, 65.94481714310186, 65.2988459217933, 69.76544887788835, 58.28987636873799, 56.40143948216593, 63.57948280149891, 65.97677661526588, 60.13654393534507, 58.71065647371354, 63.35589985693655, 62.90485082134124, 54.273173193777765, 48.55094502049108, 52.30893258125552, 57.7856517607166, 63.978631034974136, 60.2435108923143, 57.75779901012298, 58.19280947408369, 62.530119342188684, 61.986090521658625, 57.23928912993401, 52.01406840355166, 52.01970484948928, 52.619113614482266, 46.854598368367846, 48.99977399456886, 50.123980199137044, 49.50613629433417, 46.59119552181613, 55.81437441610522, 59.86569250783613, 62.95144073424801, 59.29918066147835, 62.64276196879726, 59.714340009996974, 62.77157260525612, 56.58950536481796, 58.78544430578909, 41.16525534660586, 45.30011600063693, 65.78690644233458, 59.497546688202895, 58.58115942247453, 47.657240821469216, 49.06766629988148, 46.71250266413535, 50.923465144249704, 53.318229029255534, 59.58989104916973, 59.15670448733915, 62.91872424464073, 59.006885636237364, 59.96490493897469, 60.545184304637296, 62.040089791820904, 58.74144707956622, 59.81770230877785, 56.99541968684043, 56.44777051864132, 54.740464764256636, 56.72267375453826, 56.29555117699408, 55.93123359064902, 54.610834352431766, 54.55112018892842, 51.980547828059045, 56.265074360755186, 65.89706620862408, 66.81472824465844, 66.24776532573085, 65.98928113137522, 54.15239164906164, 51.174214424625525, 52.53504937694919, 62.847168445587165, 62.487647917962846, 67.33953352897399, 66.41469355552428, 61.129378195731874, 53.90064608666205, 41.070455581911155, 18.78799819177197, 16.291790046999534, 14.589000901868268, 23.686154042520833, 17.629171186877837, 9.45582643631966, 1.8474478731232307, 0.1927903622028328, 0.29238968306491453, 0.1431019300775182, 0.37674236802324174, 17.550861066387547, 54.26381441854662, 56.74883596358761, 33.593229555314586, 26.6198633563134, 47.91822356562461, 49.14492130279542, 67.24387476521154, 66.08769339899864, 55.15223518494637, 11.974223429156888, 0.426081984994873, 0.1670566874165689, 0.1532104142731236, 0.13657138292347232, 0.15796559862792492, 0.20484984251520327, 0.19478520919238368, 0.16540334710190374, 0.2430162203287886, 0.1581412013019285, 0.13027435469050563, 0.1549602816662481, 0.15277257970263883, 0.11505720551095663, 0.09661853403574037, 0.18235652046578546, 0.21678661086386253, 0.17113795954613917, 0.14910902467466172, 0.16359024681150913, 0.1322943446857314, 0.20616607349966803, 0.09142937619359263, 0.1730514479981315], [0.029596849344670776, 0.02090603383558412, 0.03778251796780575, 0.03867516744761698, 0.03982871200048155, 0.022846969302683588, 0.03349299249689906, 0.05649997266910731, 0.06554547922625657, 0.0274409132168418, 0.05873295425948116, 0.013878180705491575, 0.034738927253431855, 0.059503156075915026, 0.021140150305244233, 0.015922709454541967, 0.03221139251705139, 0.052026402235271475, 0.00939229062022341, 0.04656312664249732, 0.04586828106473531, 0.02589789147849285, 1.5833298068854118, 34.45545673370361, 66.36928819840955, 55.26268128425845, 45.2112860833445, 34.682742395708644, 33.49584102630615, 31.746930691503714, 40.881605225224654, 48.514772922761985, 18.39339794651155, 1.1903189795632516, 0.041228484873089104, 0.03729780264679463, 0.13968957527991266, 0.4617806097432491, 1.8487269335216092, 8.175524607781442, 12.320362790938347, 9.340337149558529, 9.950441237418882, 24.300481542464226, 50.58930273978941, 59.52675657887613, 64.03177130606868, 60.27800813797982, 63.16605714059646, 61.76080134607131, 63.20830891209265, 51.954162043909875, 56.145559741604714, 58.63730030675089, 62.903309329863525, 57.38327933895973, 59.00747006939304, 59.506552450118534, 57.97382354736329, 49.56680359378938, 41.55788852322487, 44.01719108704598, 54.231490165956565, 54.728913384099165, 59.738905814386186, 54.331632198825965, 60.25001418206, 56.63627178438249, 58.54736820344002, 48.92201300590269, 46.151795925632605, 42.089569722452474, 44.00511410928542, 41.16267442703247, 44.30306126994472, 44.24210763746693, 45.53905110205374, 43.01908516114758, 49.35180279516405, 52.10513799421249, 55.77943002024005, 57.44200506517964, 60.84457489752001, 54.13143442523096, 61.19816087907361, 53.84389723500898, 61.44317173188733, 32.840305105332405, 34.80017423629761, 65.54478245396768, 53.03972897991058, 57.107152323569025, 47.35474371141004, 45.789886674573346, 42.59810109292307, 44.95960327886766, 44.12617414228378, 51.895965837663226, 53.136752728492986, 55.78010859027986, 53.69016385847523, 53.944902189316295, 54.19880113294048, 56.11201563189107, 55.690886435970185, 57.55622840696766, 56.99905572399017, 56.02329554096345, 54.69324334975212, 56.60611268012755, 54.41706142117901, 49.44240562377438, 49.745165532635106, 54.23746785809917, 55.33968133311118, 54.812079398862785, 53.35105926759782, 56.875010767290675, 57.84826063340711, 60.08004611538303, 57.55641275836576, 46.720641582242905, 45.332236289978034, 52.640969061082416, 59.82389573127993, 60.07376640073715, 62.601981086115686, 59.38690054801203, 51.64059600522442, 42.68733109197309, 30.71291546667776, 18.83777306925866, 5.592468323246126, 2.7422868628655714, 6.251832967804325, 5.441704180932814, 2.4050069095626956, 0.27726971213856055, 0.06353426859864304, 0.08030437759213871, 0.032037444592964266, 3.0667916565172137, 30.68832024451225, 54.07633689142043, 38.18360682456724, 31.33251463213275, 30.503637406133837, 33.14166668922671, 48.16371686996953, 51.67463825594995, 55.14253124114006, 20.286206314640662, 0.6949983969811471, 0.0655226115017168, 0.05331961993849086, 0.09958801340431937, 0.058771136081627304, 0.04393713045564871, 0.010758941681424697, 0.004280090140509269, 0.06146775408377571, 0.035492439844435265, 0.05548642685396537, 0.06408116727646801, 0.09345952451469437, 0.06345818840688275, 0.06659282867105738, 0.02502316654088997, 0.025439351466634584, 0.05457650592190124, 0.02341939211492577, 0.03953449976360125, 0.08882944231792804, 0.026414405194021044, 0.10020696648186254, 0.05734482592332268, 0.03885064371711305, 0.05683535447103843, 0.021947130087702986, 0.036494915689071344, 0.06095079795247125, 0.07705534507911052, 0.047549372914457516, 0.08064315699401402, 0.07923851946308728, 0.03311634536892657, 0.003958534070989117, 0.015398132663610724, 0.030772005237879294, 0.026508829361128233, 0.07571632297889841, 0.047536357080623995, 0.0209287598338579, 0.024770290493184043, 0.02902935822344115, 0.06671912592625426, 0.08908380649142689, 0.09650496916184503, 2.570070787783592, 44.03905830075664, 74.09665553800522, 62.584561840180434, 50.75210463616156, 42.777200437361195, 40.01129404191048, 34.78223723749961, 46.13067788462485, 50.15306849633494, 20.930771366242443, 1.4752739018970922, 0.09389375847193504, 0.08572323157662347, 0.26013943456834365, 1.73506829046434, 5.574290588978799, 9.092395305633545, 10.683941129715214, 10.169202608446922, 8.480955650729518, 23.399195401899277, 45.20450430531656, 63.87768099384924, 64.1135605689018, 64.96115730654809, 63.026432529572524, 64.71719372657039, 64.89645388818556, 55.34604733990085, 56.31355485608501, 62.73305885253414, 63.369126089157604, 59.36069127052062, 58.63854762046569, 60.72973182124477, 59.90225292021229, 51.086804405335464, 43.86454420704996, 48.21358980671052, 56.73011449075515, 59.350073414464156, 58.12092027356548, 53.81920983714443, 61.25352513405585, 57.6330441044223, 60.466936942069765, 52.27438042240759, 47.824380859251946, 45.777907756067094, 45.828447495737386, 43.42012397704586, 47.16233576497724, 46.276005621879335, 47.151262913980794, 44.83587603415213, 51.56923632467947, 53.81901371863581, 58.88309563359907, 57.47738092176376, 60.42980778601862, 56.52739463313934, 61.9160879811933, 54.60642560835808, 61.357114930306714, 35.65479201655234, 35.53240230006557, 66.82098834745346, 54.331314486842004, 59.475918739072746, 49.136009677763916, 46.92884883572979, 44.36287741507254, 47.77407253942182, 45.94829943872268, 53.62022015356249, 54.599267282793605, 59.12283089853103, 56.65828412578952, 56.71413475467313, 55.887067702508745, 58.53302409571987, 57.34812313510526, 59.83656106456634, 59.13045598614601, 57.64740390162314, 56.27141291095365, 58.719972102872795, 55.35789682019142, 51.6409803975013, 51.332533051890714, 54.68204890528033, 55.99077516986478, 55.02340885900683, 53.597827342248735, 58.328146934509284, 57.40514263030022, 63.353099284633515, 59.878801068952015, 48.454945010523645, 48.075436084501206, 56.357748200816495, 61.84286125244633, 62.94814594330327, 63.76739571171423, 62.2358121410493, 54.92196459924021, 47.925107325277025, 25.444952672527684, 15.159623392166631, 6.000762543370647, 11.708310265694896, 12.364226656575358, 9.35233764110073, 6.438512292600448, 2.0438206003558252, 0.1721083018327913, 0.09732069958361889, 0.009733238050924435, 3.412344623957911, 31.401265936513102, 51.32271928171958, 26.906141465710057, 31.26577550365079, 36.479070263524214, 36.38346249057401, 55.58481770177042, 56.784305957055864, 65.807220397457, 25.556049885288363, 1.0767655050562275, 0.09833457098612863, 0.05843330279833848, 0.03421398465551677, 0.004146482012489991, 0.0745258836316005, 0.02243974569043325, 0.027827337541947925, 0.029975961360539642, 0.06912758378612419, 0.02609916384361925, 0.09469366151719324, 0.02728213957931486, 0.05200768287684168, 0.03426142081978821, 0.061135846490581194, 0.04250034787541917, 0.030192783395309123, 0.03293375214261394, 0.050586114802788344, 0.05070413064752376, 0.02834601737108202, 0.04188638586070269, 0.025141358585847963, 0.1249022167476435, 0.2477209960981723, 0.11236348715160163, 0.10069669584833807, 0.17325340409673032, 0.22467066684076864, 0.1417672976611122, 0.23282708239651498, 0.16558464947006396, 0.20311462272319103, 0.12330827122974782, 0.103370534226058, 0.08581157683605149, 0.22028519651822506, 0.19386300787089333, 0.17253170330678264, 0.10575821578142144, 0.1801753149277741, 0.09472458848669645, 0.146528396214689, 0.15889031271780693, 0.27909634154169793, 3.614776187366055, 54.242080565421816, 82.51475226494574, 72.12718640604328, 60.81680059432984, 50.60222302713702, 48.33281024809807, 45.66126038951259, 54.59825923365932, 63.075195435554754, 24.898901870173795, 1.8598799479584542, 0.27881310351433297, 0.33857549991338487, 0.42665394623914077, 2.0720506339303912, 7.307299144806401, 18.208101257201164, 19.360995677209672, 18.12879877705728, 19.800516866868545, 28.727770582322155, 54.44360410013507, 62.225766951038, 68.9405587411696, 66.90042418818321, 66.6756017746464, 67.21328027786748, 67.0829006933397, 57.061280204403786, 60.973412990570075, 65.25142838878017, 65.33422177837741, 60.054805663324174, 59.38904216212612, 64.08220906411448, 63.19967577534338, 53.809713778957246, 45.525479701257524, 49.40855949155746, 59.67029571533204, 61.41449528355753, 59.78134193728047, 53.55237099432177, 62.23103861654959, 60.26747657406715, 62.86130466768819, 53.58640932267713, 51.36849726400068, 47.296649486787864, 50.28055337167556, 45.947860133263376, 49.644631262748476, 48.43567832823723, 48.745133722982104, 48.34045494756391, 55.38063480008034, 55.31947328198341, 60.20438524984545, 61.0889660158465, 64.3251096817755, 59.253626254297075, 64.74770192177066, 57.6521146682001, 60.99041254289689, 37.250474960573264, 38.985315753567605, 69.56493731467955, 57.978106775591456, 61.52711045357489, 52.3043865542258, 49.67215453424762, 47.06768897271926, 50.12245439714002, 48.918173005503995, 57.15995134845857, 58.97756199682913, 60.7255191956797, 58.2545828819275, 59.84736719439107, 60.474777760044226, 61.73136788029825, 61.23477228226201, 61.8391820692247, 62.12466393747638, 59.65879924835698, 58.66296829715852, 61.46599992629021, 57.75189584301364, 52.926097916018584, 52.64824113538189, 53.16892400864632, 57.423424797673384, 56.41934902437272, 54.03476761233423, 59.37728681871968, 61.1371954794853, 64.22780744491085, 62.64360135601413, 53.170434121162664, 51.54392919232769, 58.12642728128741, 66.23098542613369, 66.7738571474629, 68.07866496424522, 61.903759971741714, 59.21085672993814, 45.860359899459354, 38.69915923764629, 29.674377749043128, 15.597628585753904, 9.720094165494366, 15.041869917223531, 15.407747626304628, 8.320041395002796, 2.039666565195207, 0.21944761726885073, 0.19881213504460551, 0.2757483840950074, 5.014112880153041, 40.15279746824696, 71.7103639725716, 53.59823134637649, 42.531259982816636, 40.313689170345185, 45.646371072338475, 62.069366362787065, 66.59156891607469, 70.98470980121245, 32.66425736488835, 1.7485945840035717, 0.20825770803757254, 0.1697074895304057, 0.19180618436826816, 0.18381496801251368, 0.1736910241625963, 0.11827587029866635, 0.0896421313706425, 0.1325591506376382, 0.12772591724511118, 0.126970945256612, 0.21183510881758508, 0.16500708046219043, 0.15865541483846404, 0.16498633480120092, 0.20056966331697282, 0.15946875506591413, 0.18095811889056237, 0.1770043084698339, 0.11828757612214935, 0.11700575780724326, 0.15452143585970327, 0.16269300463459185, 0.19785138417876538], [0.11187001161517636, 0.05434882076036546, 0.032940853777672016, 0.021044615310646837, 0.03807264312561001, 0.062262876740386414, 0.018976041934482994, 0.02226122039099855, 0.10089383325389317, 0.0696281379749698, 0.03240061240390905, 0.03476458736845563, 0.05044094880201644, 0.03143605599630504, 0.025273152521901557, 0.027259266109115658, 0.06212555931039876, 0.01905275223356101, 0.10550441851298656, 0.030139542199791442, 0.09686351363216678, 0.037759121642598224, 3.818894860244567, 45.26924694738081, 62.998462107873735, 53.27715789118121, 44.3770646279858, 22.77036297705866, 12.276170426799405, 25.367909477603053, 47.50068726078157, 34.19625474560645, 8.09052243348091, 0.22935805241427115, 0.05287616228264186, 0.05243146356435553, 0.08276341257676964, 2.607792712027027, 5.02921792768663, 7.224594008538031, 9.45276306521508, 13.113229716977767, 15.525717812199748, 30.67999501382151, 50.30047901215092, 62.325928595758256, 59.16194477388936, 60.90446164531093, 58.18060698047761, 58.11584472656251, 52.40536797431208, 47.99794573937693, 52.92738837580527, 59.98606612605434, 61.870298231801684, 58.03987233869491, 58.786668085282855, 58.704733694753344, 59.246150216748646, 49.03929971879529, 43.67715689443773, 43.842837810516365, 53.1308142600521, 57.40609184388192, 60.03436619235624, 55.457352438280665, 58.62301111221314, 56.567496945781095, 55.7985084287582, 47.05753395634313, 44.16082436038602, 43.30916796961139, 42.885740264769524, 39.96801460942915, 42.842111741342855, 43.32335518252465, 45.76875294408491, 42.33940116820797, 48.013678366138095, 51.995966665206424, 55.19091759958575, 52.69713740194998, 55.18216679173132, 51.638854472867905, 59.9682899444334, 52.666695887042636, 61.739440118112874, 33.01113020989203, 30.17683925167207, 63.36087734468522, 51.377899185303725, 60.22112984811107, 48.25743406049667, 51.29712581634522, 41.75703117924352, 44.527350241138095, 41.456346204203946, 43.399723729779645, 46.83715951058173, 50.42598309055452, 50.23177085384246, 49.7996158753672, 49.673319478188795, 51.33179564629832, 50.24044321429346, 52.599662580797755, 55.02934340507754, 55.84736939399473, 55.46454606517669, 55.09274459654286, 56.20999643879553, 53.369874877314416, 51.71510142664756, 54.3910914082681, 57.676154874986224, 57.365177600614494, 57.79202953461678, 49.5895690302695, 57.95010497493129, 61.09724221691009, 56.23100465343845, 50.179120879019464, 40.94577127887357, 48.193726924157914, 54.482157076558764, 59.105917638348, 57.62004144730107, 64.46215337322604, 60.49189106110604, 52.42194783303046, 40.44370005207677, 24.258973060115693, 12.616521350799069, 11.551207573183122, 11.549785713995657, 4.941810850174197, 6.834022037444576, 1.5709718893612585, 0.07067136586673799, 0.07311956836811959, 0.03258583714224158, 0.09439995106790336, 8.565704341857664, 33.13814440081197, 49.02663046313871, 17.24660869567625, 27.46775427172261, 42.47382471638341, 31.686785067281416, 54.1993934108365, 50.67135872379426, 40.354870134784335, 2.371833218682197, 0.030055364458671505, 0.03949331870723156, 0.06377480871554825, 0.07483477794354962, 0.015151956054802625, 0.022537402748580904, 0.040677027972114664, 0.06542973100177704, 0.0379220723745323, 0.016680652906577435, 0.04001037059952656, 0.07989999808130727, 0.04573618835439125, 0.0463688122709432, 0.006125749167685788, 0.03616286636961084, 0.03756279245980325, 0.01721126647035201, 0.05752576056927924, 0.029928687989952105, 0.03277267449565473, 0.07436217064218176, 0.02408106417034663, 0.04185311083171157, 0.06016821615518101, 0.021296522257128553, 0.029075647171045986, 0.0633435471794538, 0.08839226658305815, 0.024253037502808918, 0.08542631121893084, 0.037262003358093, 0.06108907682280387, 0.051150794381335865, 0.028243495654615185, 0.07374989785133831, 0.01716497369230755, 0.046574663926636985, 0.010007313666715017, 0.01198524160445818, 0.07480987242513126, 0.02834951647767617, 0.0754203372484734, 0.056513643508116086, 0.036746671333188013, 5.395751162882775, 55.46174549287366, 72.64807716492685, 61.47297390045659, 52.71254839435701, 31.335503478204053, 20.358430877808605, 27.838979151941118, 48.4619935097233, 40.285981547447946, 8.398052434767447, 0.1633985256475787, 0.10502901499069507, 0.04052508209321288, 0.7909419615903209, 4.125971582628066, 10.172619973459552, 11.23981256638804, 14.664204505182083, 11.638272423898021, 14.119447104392515, 36.57818855777864, 54.81189896983486, 64.68075490766957, 62.659777210604766, 62.70852442710631, 62.06194131605087, 60.41362800905782, 54.80519171684019, 49.38645693563646, 56.14647757622504, 62.01303720474244, 63.61672962865522, 58.09323618488928, 58.02362195907101, 60.8206170605075, 61.36538720900013, 51.650617661014685, 45.677428399362874, 46.418007189227694, 55.57055596382388, 59.25026086068923, 59.65399826726606, 54.526993689998505, 59.78993977269819, 58.71597128529703, 58.26178827593404, 50.38087583357289, 46.872123518297755, 44.34478744383782, 46.02183603471326, 41.83669843981343, 44.77707970526911, 46.074242822585575, 48.25559839125603, 44.728359945358775, 49.85030858747421, 55.14226844233852, 56.59536146348523, 54.979627363143436, 57.167039071359945, 53.695615953014745, 61.0822783747027, 54.8897619401255, 60.219584434263176, 34.15633678436279, 32.75152029529695, 65.94557808291528, 53.19043036430113, 61.53972087367889, 50.466811041678156, 53.218479233403365, 42.72444063617338, 46.97300687912972, 43.84604238694714, 45.573222790994954, 49.43865583788965, 54.20791672122095, 51.57293119738179, 52.008714368266446, 53.02569473943403, 53.41966152191163, 53.0791566448827, 54.416779010526604, 57.02070720734135, 57.96537868438229, 57.20799646069927, 57.609192171404445, 56.745097944813395, 54.533285171754905, 53.005788710809526, 54.93203332347255, 58.013537545357984, 57.82955485005533, 58.41775740346601, 51.466885997403054, 60.46890989426644, 62.74649297037433, 58.86262870603993, 53.37668411193356, 44.09941573296824, 50.844982439471835, 56.37066456579394, 61.92474072979343, 60.42433607962824, 65.31686921273509, 59.50826652588383, 55.3661024185919, 44.51388082196636, 18.849036155208466, 10.80050318471847, 9.399284489693182, 10.383350291559774, 11.906435066653836, 6.928172159579493, 5.811777845505746, 1.1182766840342553, 0.05462978733703495, 0.10509095319937314, 0.2223585828417732, 9.877291975482818, 38.39628165768039, 45.145252981493556, 20.983890064301033, 33.59893660391531, 48.12411662070982, 39.93192488147367, 59.65238225075507, 57.61809987406577, 47.68537990508541, 4.294288821758763, 0.07490239286374661, 0.02370033953939715, 0.0323744926361307, 0.056147028301512046, 0.08490536376954087, 0.025245807013444366, 0.0473821742249833, 0.05637454492370448, 0.06300819219060003, 0.07578301093270702, 0.08909140608363575, 0.02918213147730116, 0.04605878414886613, 0.06436538206593645, 0.04524370490182792, 0.10533165802518207, 0.022782146772970597, 0.022470869927576954, 0.027230555048933434, 0.02731699083421019, 0.013780296693796353, 0.0676660948703366, 0.1392371390735911, 0.14035424848477687, 0.1570723401082139, 0.2331886299314999, 0.09441466761692878, 0.16849293373525145, 0.1538798985101523, 0.12958738832704483, 0.12497913963612049, 0.16766394999238754, 0.160639030979045, 0.137553921329879, 0.12518648899370624, 0.2210212997611492, 0.15861632903256725, 0.15935652318500704, 0.15186778389878813, 0.14572864638701563, 0.203250419468649, 0.11742044886153553, 0.18315122943491707, 0.12246318431871554, 0.20660102757955753, 8.56077294195852, 65.2977398134047, 79.15608159957394, 71.18971640063872, 61.1533477998549, 36.035595324731645, 20.860204004472305, 35.79604833356796, 62.23300372400592, 46.760198685430716, 10.489749485446561, 0.44851775851941883, 0.3337386659076137, 0.19780157314192867, 0.5060180811391723, 4.254591003541024, 17.66040894293016, 20.306806602785667, 22.27404586730465, 24.382135483526415, 22.778543080053023, 36.91991721430133, 54.427424323174264, 67.11538576310681, 62.90237188339234, 65.63731508870279, 63.281574864541334, 64.64323351460119, 56.53916174365629, 52.052625302345525, 56.90439716462166, 64.50859423606627, 64.33370359482305, 58.21591223439863, 59.22674625150619, 62.98483579389511, 64.54209127733785, 53.014755249023445, 49.12056730639551, 48.57789562594507, 57.88821781835249, 63.22845420529766, 60.606247763479914, 56.0345095972861, 61.19111237987396, 62.566252216216064, 60.32132679416288, 52.05461002165272, 49.67490803810858, 48.451430566849254, 47.729463423452074, 43.888035282011955, 45.34563118411649, 48.85895698301254, 51.72990445167788, 46.61189779158562, 53.41966936665197, 58.278136714812256, 60.232547867682676, 56.6843286637337, 58.61957903831237, 57.035408250747196, 65.04394677377516, 57.60032369244484, 60.409740940217056, 37.30809065603441, 36.686661704894036, 66.5567853373866, 56.246694134127715, 64.62743028517693, 53.43613547663535, 56.38528323942616, 46.093964499811975, 49.80553473195722, 45.2523454543083, 47.32703216614262, 51.421900333896765, 56.182783034539995, 55.566959150375865, 53.576109178604625, 54.922403904699514, 55.614631637450195, 56.62874083365164, 58.04290825320829, 60.383712091753566, 60.818200880481356, 59.55068695929743, 60.83389036117062, 60.134245426424094, 55.55486256076444, 54.21548689565351, 55.703061472985056, 60.56884796388688, 61.760095319440296, 60.21090030670167, 51.2000040085085, 60.61155080795289, 65.17272210890248, 62.66298570940572, 55.28200287972727, 44.97341394424439, 53.007251754883804, 60.57104449118338, 64.94460098205074, 64.10749266224524, 68.28611912265902, 62.12771946384061, 58.34133394302861, 45.88393334419497, 26.39344453811646, 27.086443016605994, 20.002705243326005, 23.003190948117165, 19.52489583723007, 18.32235990032073, 4.573364478926505, 0.8548246239942889, 0.23748544855944573, 0.24014043351334913, 0.4143793790811493, 12.564123388259643, 47.81971716111707, 63.320237667329856, 25.384550133059104, 36.721747306085405, 54.13155209633612, 45.54264007076141, 66.65708818743306, 63.83796307348437, 59.623097835048554, 6.831438176093563, 0.09998067943078857, 0.20745060376582608, 0.16021432715558237, 0.2018965122800681, 0.34721642011596315, 0.21465915405461866, 0.16056678888778533, 0.20444478118611922, 0.1675714678581684, 0.1937094072420751, 0.1635438831703317, 0.19144436104163048, 0.20908188074827197, 0.22552586611240144, 0.15138285024271858, 0.25113983199961726, 0.15057476537842907, 0.21929991551704947, 0.16563881188631058, 0.19847433623527327, 0.15161701267765415, 0.15257215577988856, 0.27920052949940005], [0.05247846305851014, 0.08780008827846858, 0.06926293620058606, 0.008687832554231488, 0.11112755750335994, 0.05786264773398157, 0.024639356490825454, 0.05969132642231642, 0.06679997884578283, 0.020940138154753277, 0.01086991430530625, 0.028891661579930977, 0.06591215955033418, 0.024396918391087846, 0.04570916077242263, 0.027205639954416022, 0.03637613758685128, 0.031152590057782592, 0.01640140811251777, 0.04162004390250772, 0.038654115351457755, 0.02782213772016187, 11.661855674559071, 63.37854369994133, 62.153920896591686, 54.81003976637318, 42.696262328855454, 25.114791085643155, 25.12468722558791, 42.85722463361679, 52.277224140782515, 27.09286589776316, 1.7821036375338033, 0.03355635945955592, 0.12204586558284299, 0.06656878117111421, 1.7948742619445248, 4.190281293084545, 5.594175534863626, 6.765269262175407, 7.099035507248295, 12.581452419680934, 23.99558786422976, 53.013578537971746, 58.13708828341577, 66.96484519589332, 58.58331280369913, 58.13883766051262, 52.61135516628143, 52.34168829456453, 46.652211912216686, 51.253779703570956, 58.21748118246756, 59.68420443996307, 60.36358248802924, 57.840388436471265, 57.46666892882317, 57.907672774407175, 57.244070499174065, 48.831865172232355, 41.87960916949857, 45.087727500546364, 50.92161378552837, 57.079680042882124, 56.88189844931326, 55.3322837429662, 57.2236624071675, 58.12032015092912, 53.78514012982769, 43.912620698252034, 41.325291972006525, 40.46429641785161, 41.27099460171115, 39.42997132578204, 44.88143044133341, 44.152885483157256, 45.68898762426069, 43.36623061087824, 45.493014243341264, 47.99940093871086, 51.81712619719967, 49.83903961796915, 53.07853691039547, 51.40693649168938, 58.58860015869141, 54.60218160383163, 61.91004360875776, 32.21745821737474, 28.367885274271814, 60.61245687546269, 51.4624027282961, 56.80859719553302, 50.13216618568667, 49.76479699534755, 42.63534792007939, 42.08096011992424, 43.505965048267, 41.68902904756608, 40.092781282240345, 45.48203160685878, 45.09762364049112, 43.74708098749961, 48.69837122578775, 45.575948838264715, 46.67366727705925, 48.82019219859954, 49.75020185593636, 52.58267871795162, 51.519720323624156, 54.450703590146965, 54.3960649736466, 52.196407625752116, 50.685777356547696, 60.777498445203236, 54.57189698373118, 54.42997386378627, 55.76692942650088, 58.43890290106497, 53.8562213220904, 59.80685303288122, 57.58277893066407, 56.15798973268079, 45.79199298735588, 44.581977090527936, 47.22287362621677, 57.27104856121925, 58.22799313452936, 62.50170177029025, 59.33095185987411, 55.04346786006805, 48.148372557855424, 44.53944290837934, 17.412883850835986, 14.272100848536338, 10.454546213150024, 6.012085935761852, 5.583027668537633, 5.796925790848271, 1.0933380093305343, 0.08881467214274792, 0.16810858742363993, 0.02780211218182118, 1.4300926101784555, 23.327282667160038, 42.802746834293494, 38.689117970005164, 16.44958797962435, 18.25984516451436, 33.58208217928487, 49.2365361029102, 53.05702271000032, 47.997843757752456, 15.447273350531056, 0.1487822881749561, 0.07364176454082613, 0.023419206338604132, 0.05429012693404671, 0.04914429902489628, 0.07676303657072206, 0.054867519741697665, 0.030252733605823694, 0.05760790434696021, 0.05467035552306522, 0.0603318295531696, 0.06359138428383777, 0.06288110586484114, 0.04846458368363881, 0.052968820617083585, 0.10673995745638687, 0.07074521674263863, 0.04414173338802592, 0.028360509839389595, 0.05834262480118102, 0.017753110883096536, 0.019605875375770757, 0.02318330679930026, 0.05269792426617877, 0.029875487014050447, 0.007453693636512805, 0.05867632120967873, 0.025496551421500986, 0.05664079878178816, 0.04750769390093704, 0.0005261471514747809, 0.010205901851276717, 0.05491257720296422, 0.056418085530880964, 0.05228527483620471, 0.038167634197781165, 0.06616361258972077, 0.030501018871643373, 0.06722002485466581, 0.008988130402060287, 0.07349506636420566, 0.015841449550803632, 0.0633824184807318, 0.022702278276424737, 0.06491479734259267, 15.800171936711958, 73.19656572034283, 69.07081280985187, 61.176497628611905, 49.66685148977464, 32.62292538919757, 28.184061434961137, 35.94423155630789, 46.857681351323286, 29.068251925130046, 2.0410208860712666, 0.029030798468738798, 0.15121515359609358, 0.2362206067529417, 2.8858247735807976, 6.158804643538691, 8.013383140487056, 10.154191697797469, 8.873278960104912, 10.19470291752969, 28.780826522457986, 48.51769508854036, 62.0054631079397, 65.68155550187635, 61.33485547957882, 60.000708333907596, 56.521856246456025, 54.290502225199056, 49.400314669455256, 51.78041281238679, 60.457860577491026, 62.81345175158594, 61.90062207560386, 57.7732256920107, 58.43920492356824, 60.49225976390224, 57.78022712276828, 49.01940937965147, 44.38960836779687, 47.57334916822372, 54.37674730054794, 60.65968613470755, 58.12033976277998, 54.47936827136625, 57.48753593813989, 61.11361026763917, 55.9222827419158, 45.9164458705533, 42.65686996521489, 42.668590007289765, 42.83549078049199, 41.23400665098622, 46.594698198380016, 47.56177425384522, 47.29217014005108, 44.79599337424002, 47.186219076956476, 49.56773319552022, 53.320045086645315, 53.00620840441797, 56.177413309774096, 54.48374955884872, 61.84753279532156, 55.340061803017896, 61.67326188856556, 32.944787240797474, 30.242123180820098, 62.613693283450225, 54.20035831389889, 58.953396274197495, 51.8674345170298, 53.87509184498941, 44.62825321382092, 45.17483549733316, 45.02021174277029, 42.134884865053245, 41.18777367376512, 47.66867845289169, 47.67273810602004, 47.32398448451873, 49.866947281745176, 49.278819253367764, 49.00475148231753, 49.94078197786885, 52.13505391151675, 54.88129354292347, 54.2309331893921, 57.042401836764434, 57.23752406335647, 54.539988502379394, 50.47292993914697, 60.52281502754458, 56.50749644925518, 57.377442852143325, 58.427951643543864, 58.45727136058193, 53.63906714224047, 60.64207077026368, 60.9633638781886, 58.10347357103902, 48.578009374680065, 48.007920326725134, 50.555668415561804, 59.18749117082166, 59.85615330357706, 63.80362272262574, 61.12591082049955, 56.42213782956524, 51.461853596471975, 41.17986225312756, 12.560441263260381, 10.088890117983665, 7.972056558055263, 11.92724225982543, 7.774121011457137, 8.583772740056439, 4.796582152766566, 0.09331496372338265, 0.00940362680628295, 0.038811236154288054, 1.7434470860227462, 26.952201858643566, 47.52482160445183, 36.86330564560429, 21.91192480825609, 24.01400927574404, 37.68121004104614, 57.85679963327224, 59.75968260918895, 57.6973827423588, 20.528973571715817, 0.2828125114883146, 0.16990901661976693, 0.018636601781772993, 0.049526032976686, 0.0729257787667936, 0.020033021104492007, 0.05605361537046491, 0.026421673453202652, 0.12259675940919308, 0.052456074138923045, 0.03545313187304043, 0.046832812574481776, 0.01604105567469472, 0.08943496587415857, 0.04459362184148162, 0.029376585659901464, 0.0390345661059743, 0.08415488105627798, 0.07193700440468327, 0.08270928080403998, 0.11036294046789409, 0.029400931934135097, 0.05116562584354993, 0.25234016920289687, 0.23455119391362514, 0.20374627753851876, 0.11974795421044673, 0.17604250040265823, 0.1050853071313712, 0.16382575756119144, 0.18862140364944938, 0.1086981394778817, 0.17552171383173237, 0.1200666621087059, 0.13017935978789485, 0.12202741052474707, 0.1896692433905217, 0.10279693355363223, 0.27859783280761014, 0.1636363959480678, 0.2283491759050277, 0.19145537738598165, 0.11165432722097444, 0.15636649733829885, 0.19341271671075977, 22.823701327846898, 84.62323019581457, 77.18257242633452, 68.41532984087544, 56.83866216290382, 37.734742549157914, 35.172214969511955, 57.22102265204153, 67.36999465573219, 35.63664320976504, 2.3943422302123043, 0.09921379477506685, 0.4004382642526781, 0.3237932205440537, 4.465909677167093, 12.717228204973283, 14.768941594708352, 13.956868783120187, 16.436556885319373, 22.4848928759175, 29.262760300790113, 55.935308933258064, 61.37692682204708, 69.55666111361596, 61.929302446303836, 62.65007326679846, 57.44392702656408, 57.34308681180401, 50.41806382517661, 54.987334820532034, 63.350047680639456, 65.97501154868834, 61.491820889134566, 58.68296061792682, 59.67781882132254, 63.449868079154726, 61.91856299677203, 52.10294538928617, 46.553034782409675, 50.09464087024812, 56.63466361261184, 63.42819306158251, 59.4852618248232, 55.599750165016424, 59.21915254285259, 65.54471969604492, 59.08696474567537, 47.58570855663669, 44.86283840671663, 45.807035276966715, 44.135576063586825, 45.10275017830634, 48.97144663718439, 50.49229860305787, 48.006527885313965, 47.49864370592179, 48.77580665772962, 52.89483270337505, 56.33510828018189, 56.082535097675944, 57.85990222807854, 56.02818673656833, 63.664876722520404, 58.86153436476185, 60.22345973599342, 35.9819608349954, 33.460359265727384, 64.12237805704918, 57.421071375569994, 61.39263591458721, 55.557208138127486, 53.76679128216159, 49.378529825518214, 47.172510393204234, 46.92780156289378, 45.582118726545765, 45.4622354045991, 49.66645925275741, 51.446595576501664, 49.14869854527135, 54.032935865463756, 50.07489173643051, 51.745033033432506, 53.09468923076507, 56.252915013221006, 57.49709083187965, 55.980180848029356, 60.10978552602953, 60.40168831425329, 56.21073776675809, 51.420829526839725, 64.30047327472319, 59.751280892279844, 59.74968448761971, 61.52908732814174, 61.51461378220589, 53.1428716259618, 62.02249011685772, 62.37733517923663, 61.458927892869525, 52.18904141456851, 51.9387432067625, 52.14631895865164, 63.13364267349244, 62.540921549643244, 69.3580872012723, 63.52851160110966, 60.013616854144686, 53.698255708140714, 49.51039598834131, 22.205288679369037, 28.28294242582014, 27.497240689492997, 17.711350725543117, 18.30622523061691, 13.159116545031148, 3.2000085855683977, 0.25474824401880464, 0.34313231346107304, 0.10480213039104017, 2.639427362911163, 31.810426019853164, 56.375951920786214, 50.83322317369523, 26.038919148906587, 29.15589140307519, 49.97321605682374, 64.77882592908799, 68.30013767365487, 65.32367844735423, 26.844872082433394, 0.5393515779606758, 0.2693566980381166, 0.1529148575519362, 0.1296137264298816, 0.2132971416557989, 0.1849000855919815, 0.113000336043056, 0.11568363560664079, 0.25326509779739764, 0.14700497951238387, 0.1412176908624749, 0.11099824952262063, 0.14626510711687227, 0.17652009493641316, 0.1435876451432705, 0.19433655746040807, 0.18358462069544101, 0.16367574222385883, 0.15650264648420198, 0.1835827207973888, 0.19436223672762995, 0.11924125599644839, 0.16942008398473266], [0.0060094996344208, 0.020474105802995544, 0.04170462767022752, 0.06272706473546644, 0.0356994099884985, 0.0033880458701582208, 0.06195224723928879, 0.06322825094684958, 0.05918061773803446, 0.03840237885953919, 0.041219234361403415, 0.04232379142194987, 0.028908230146513354, 0.04314919753420738, 0.041638043138288686, 0.011676498594874097, 0.06976052562916471, 0.036139270861543, 0.0405912529376726, 0.007373692989800006, 0.05178559015715315, 1.5148392175474477, 36.78786277770996, 64.8191910405313, 56.628607473065784, 47.64357920615904, 38.89612105584914, 16.254493209623522, 17.26724624633789, 39.286357664292865, 45.620557954234464, 13.28497559793534, 0.4605165646681863, 0.03139341937287921, 0.054763695675759554, 0.11470135000924911, 2.160695464380326, 3.4824449785294074, 8.925565135094429, 9.640481818106867, 14.465580582618715, 23.28490341863325, 41.91334155298049, 58.72775800766484, 62.53424175323979, 60.58116420622795, 59.21183340011105, 55.628520750230365, 50.114186040816776, 44.65519205216439, 47.26254840050974, 53.775800966447406, 58.25466132933094, 59.8252607160999, 59.841915099851555, 56.49971838920348, 59.9520670214007, 57.44801413628363, 57.046575238627774, 47.87029612448908, 43.610500135729396, 46.476501495607444, 52.87077288473807, 57.10525389640563, 57.20410939185851, 55.157589220231586, 58.79060614493586, 57.65562518950432, 49.132679585487615, 40.86868101550687, 41.72844886779785, 40.785648361329116, 42.269418239593506, 42.98549006062169, 43.88519156363703, 43.93172264099122, 47.589709374212454, 43.47696696558307, 42.51292290226106, 46.44105111399005, 46.893802458240145, 44.036846083979455, 47.68727048750847, 49.92597503046836, 58.844111196456424, 52.41276556445707, 61.494354740265884, 33.70982985342703, 26.990597940260365, 62.663413247754505, 50.44670889454503, 59.88610844458304, 49.92676734924317, 51.00720774742865, 42.9031712778153, 41.45547936039586, 40.40346437884916, 44.07228077611616, 37.833880455263206, 41.959347032731586, 41.94496762367987, 41.70929985661661, 42.94445030150875, 42.72292660128686, 40.630295045914195, 42.97760217420517, 46.85564171883368, 46.39332763610348, 47.18588567549183, 53.35781751140472, 54.790204340411776, 54.608575067212506, 53.57455199764621, 55.39528093030376, 49.584744514957556, 51.07786532371275, 53.8929033279419, 56.77543747809626, 56.44347160093246, 57.22467045630179, 57.30188231314383, 54.13679630525651, 48.319897805490804, 45.06578183943226, 44.93892454331921, 50.651531142573205, 57.3793452016769, 57.838568456711315, 61.85370268360261, 61.297012452156316, 52.15424999114006, 44.84901205185921, 26.90283883002497, 12.61098002233813, 6.821135090243432, 12.93510312034238, 3.177585130737674, 9.776566490050286, 3.3325900906516663, 0.4194688075973142, 0.11673998658455188, 0.0512821133428764, 0.035291050650900414, 9.166924261277723, 39.1773549972042, 32.24564436943301, 23.077057023202222, 22.26008419067629, 25.883632513784594, 35.9996428797322, 45.65452175755655, 53.40012419608332, 25.181120326442105, 1.1046615242958069, 0.016221726020317406, 0.010662769876240243, 0.024481827746175473, 0.024341777297517946, 0.07717587369223756, 0.04216679702362707, 0.055990566334296624, 0.05746987062476336, 0.020258511424124725, 0.04471049621520985, 0.06848031609889961, 0.06498189132300115, 0.031014571657344222, 0.023413037415593866, 0.015390370277717952, 0.028103745895467942, 0.06304167406333071, 0.029173892201675527, 0.028708622107402455, 0.07611679544131603, 0.05819424123112714, 0.09395589586347343, 0.05213637798724156, 0.0508575550761194, 0.009576399743016209, 0.016127765336404407, 0.0320354106295253, 0.048082650548988776, 0.06304521338954087, 0.015748705989080333, 0.05068913447640596, 0.12302039837044094, 0.03431546449240658, 0.035228361676056544, 0.03529448655524081, 0.008493209832287844, 0.0618703869141398, 0.010245054689866882, 0.06732178431364798, 0.028886168729513887, 0.07066470090179675, 0.10338415526935171, 0.025655575952823126, 1.8253595357941044, 45.48831132150466, 72.12205594585788, 63.52919801588982, 54.255236194979766, 46.91438705690446, 21.230216872307565, 22.629579305648807, 41.463641812724454, 48.24290952374859, 15.110653581157809, 0.4172639146206841, 0.026813602120044733, 0.01515307358556217, 0.655194245759518, 4.7231980389164345, 8.795233599601254, 9.44293164437817, 7.003956273678811, 7.689458612472781, 19.3755849330656, 39.63746863026773, 57.50320580697829, 66.46817899519398, 63.11977317256313, 62.14515832162673, 57.03661241839009, 51.79284672583304, 47.71435053117814, 48.799991992212114, 57.21759057814076, 60.41358486298592, 61.515696356373454, 61.17558763873193, 56.48049877535913, 59.85669459066084, 59.486638576753684, 59.05587603968959, 49.70163899083292, 44.74328064149426, 47.35639895162275, 55.932257329264, 59.38739868902392, 58.35449349495673, 55.442412130294315, 60.63401029955957, 60.010498569857695, 54.55438752328196, 43.22864563234391, 43.6757448411757, 42.2713323562376, 44.8474274143096, 43.784006180301795, 46.11878133589222, 46.983071680991884, 48.72262324056318, 45.336625422200854, 45.20022892182873, 47.622229745311124, 50.679556477454405, 46.52896319666217, 50.01441271074357, 51.63819551467896, 60.22282038965533, 55.09897724274666, 61.83605986256754, 34.41809615781231, 29.857042527967888, 63.90578085376371, 53.07049605154222, 60.64128629622921, 51.8684543332746, 51.98364257812501, 44.92142292761034, 44.398115988700624, 43.2839039833315, 45.5150697308202, 39.8387921241022, 44.36563876367385, 43.44189705387239, 43.45144802524198, 45.645888620807284, 45.92979761861986, 42.67824688265401, 45.452806026704856, 48.45014402943273, 48.50481794726465, 49.78693093022993, 56.0541763613301, 57.894124907831994, 57.40972395866149, 54.896692768219985, 58.03276108157251, 52.44408569028301, 53.720181757403964, 55.495630848792295, 59.736069940751605, 55.71105918576641, 57.633577546765736, 60.3973658623234, 57.65519765115554, 52.299185491377315, 47.90813130717124, 47.655409074598744, 53.52553413760278, 60.25543489763814, 59.881958576940725, 64.0767373577241, 61.563404144779334, 55.58035404451432, 48.55633827947801, 28.860283936223677, 10.880918637398752, 4.337636405421842, 11.112016843211267, 10.522188467364158, 10.108973633858467, 5.690873236425462, 1.5771747500665727, 0.16759993568543466, 0.05451131950042421, 0.10795435237307703, 11.154382363442453, 45.555587814700225, 37.89089995045816, 22.719623196509577, 27.00491459138932, 35.06164727672454, 42.05653552086123, 52.10553023122972, 59.73832922597086, 32.737754737177205, 1.6994903092422795, 0.06710765507793234, 0.032522094796501824, 0.04696186391576644, 0.011253542409488752, 0.07165871530530915, 0.061054369209394346, 0.05546953844567461, 0.005252388345393082, 0.044659233441756624, 0.03159453085954151, 0.08708682211656725, 0.04306598889431165, 0.028507889834262674, 0.046660274252175324, 0.03907370936846541, 0.04609067255871431, 0.06393314376773854, 0.004840592145844693, 0.04785219981004635, 0.08768591053423383, 0.0589984841644764, 0.025726153718067274, 0.12508864424401714, 0.09535599815388841, 0.11284265982648058, 0.1796100492919645, 0.10822303472988068, 0.13700109696195972, 0.2707631128930277, 0.060375331855949864, 0.20405190065503123, 0.22814299100108687, 0.18779338517737007, 0.15806967933331767, 0.20067067967066843, 0.1610185815802505, 0.08417192651259323, 0.13480521317931915, 0.11591052786717493, 0.12389429018742616, 0.12409697406955304, 0.2235662898108844, 0.16756808174954307, 2.579690645779333, 53.243492187992224, 79.11692065577354, 73.78531348320746, 61.6200549371781, 55.06901817937052, 25.12952546919546, 25.684582033464988, 52.367917183906805, 57.54808556648993, 17.636047101789906, 0.8375576150513465, 0.29478189986078973, 0.3099836583339399, 0.6823334927039763, 5.099546024876257, 12.453877329826357, 24.612712014106013, 22.180828778974472, 24.587251909317512, 30.30254533213954, 46.28730597034578, 59.703537802542414, 66.58340254137593, 65.53623168699204, 64.3307500500833, 59.986164185308645, 54.55539557241625, 49.22588294552219, 52.24453118539626, 60.00263029529203, 62.96108976487191, 63.427781212714414, 61.840680414630526, 57.972638991571245, 61.83226300824074, 61.35971938410113, 61.805830155649495, 52.917021551439845, 49.40484892937445, 50.52048083274595, 57.79610879959599, 62.531825573213645, 59.2321865789352, 55.81062855259065, 62.3989748954773, 63.47249623267882, 55.76010450240105, 46.36497674449798, 45.58979480497299, 45.68683424303609, 47.52433130818029, 47.7990972611212, 49.08068072411322, 49.82304811477662, 52.86549337448613, 47.35770510089013, 47.495682316441695, 50.963073238249756, 52.383559596154, 48.990858447167184, 52.90146935370661, 55.1821550246208, 63.05323408495996, 57.9900307809153, 60.05471152644004, 37.084566547024636, 32.519496410123764, 66.6240853648032, 54.923725743447584, 63.22664991501839, 54.436853701068515, 54.44418461092057, 48.31856812200239, 46.27781775689895, 44.84942390072731, 48.32354560975106, 42.33840880855438, 46.19541268194876, 47.65987273185484, 46.13468654694096, 47.91959639518492, 48.405664351678666, 45.1520896727039, 48.017832156150575, 51.93525229730914, 52.12408696451495, 52.49602179373465, 59.59753967100575, 60.739882915250725, 59.93112548705071, 55.71369501852221, 61.33742463204169, 54.56562511382565, 55.484028477822584, 57.31350037359423, 62.992558940764404, 59.34135790794127, 58.26855044211111, 62.81437350857643, 58.68299984162854, 54.29565621960548, 49.60588216781617, 50.5934839863931, 54.57950638186548, 64.02487185693556, 63.780653322896654, 67.35132417371197, 64.26670558990972, 57.51918554306031, 49.210213076683786, 33.90127289679743, 15.648136946462817, 12.787559243940539, 21.489469851216963, 12.43827316068834, 21.378590330000847, 7.403536948465533, 2.2380615193997664, 0.2695164733356045, 0.2007380954080051, 0.15735349437642485, 13.496588449324332, 51.963822841644294, 45.221758811704575, 34.713905626727694, 32.89919164872939, 38.22780801403908, 49.11823741851315, 60.70678595573672, 67.94116235548451, 41.066176276053156, 2.63943275617015, 0.17270808739046897, 0.0696205460436402, 0.19485979551269164, 0.14287084731603825, 0.2073652002840273, 0.11617077559593225, 0.12717564394997974, 0.12295993871145672, 0.0778779549704444, 0.08890747603389526, 0.15616279455923265, 0.14234250711817897, 0.08125370608702784, 0.12866498782269417, 0.1506164558832684, 0.16319425596344858, 0.2624894245978325, 0.12178488240967836, 0.13709935539912793, 0.1810725724264499, 0.14103321689030818, 0.2368130072230293], [0.020469187518521663, 0.05938021045538688, 0.054951762600291165, 0.07567700734662433, 0.02267478529604212, 0.06721472352622979, 0.021146349871771473, 0.043602518572081486, 0.023819334061455824, 0.06464007821294569, 0.08098443384252249, 0.043061308097094304, 0.05693413001755553, 0.13543211824951634, 0.09995494653741199, 0.05687627888795349, 0.0563893304206431, 0.03167756712965427, 0.10009614420273613, 0.02918828124811332, 0.1063497122677584, 5.010476843003304, 50.13455883149178, 60.241604620410556, 55.653784736510254, 39.42660985454437, 33.165102851006296, 29.250279318901804, 42.74720999502367, 42.095327761865434, 31.866937568110806, 4.287584510541731, 0.03808067172705647, 0.03317203613058214, 0.05839141311063882, 0.4234440071928886, 3.1157315594534722, 6.6694638998277735, 3.996545134052154, 10.598418751070577, 12.95695464457235, 27.408165624064786, 51.666467958881015, 59.83690231077133, 63.155792297855506, 63.75555799853418, 59.185682958172215, 55.40298446532219, 47.554639462501775, 44.433358484698886, 53.82901576257522, 57.69938315114668, 61.503642912833925, 58.8689515667577, 57.886048747647195, 56.11293346651139, 58.44553955139653, 58.121536085682536, 54.675769190634455, 46.558204466296786, 41.672904183787686, 46.0356859237917, 53.06074503929385, 55.97453655735139, 57.027606656474454, 55.829801097992934, 56.47595667069959, 55.348404684374415, 45.7419906123992, 39.64796489284885, 40.623289692786436, 39.02925022186772, 41.27166140464045, 42.93708409032514, 44.784645957331506, 44.208265427620184, 45.65367452559933, 41.5681690554465, 45.71545577818348, 42.69029248145319, 45.37231899076893, 42.381982418798636, 45.89766556216825, 50.7448874750445, 57.673530809340946, 51.692536031046224, 62.848792306838504, 35.0103073735391, 29.47875149788395, 64.56852805229926, 52.24387222720731, 56.21671938127088, 47.18956093634329, 46.797461202067716, 43.698463209213756, 44.87228347409157, 40.977785664220015, 43.66916702639672, 39.10862722704488, 42.310187355164565, 40.291688596048665, 41.1118483543396, 40.34010241108556, 41.51287540312737, 41.521508539876635, 41.034656109348425, 42.17168454200991, 41.77098697231662, 43.20624105391964, 49.975149785318685, 52.83516560831378, 53.73243524182228, 52.951840431459495, 57.62449333744665, 51.311046308086766, 44.988671964214696, 51.090887592684844, 55.38921694601736, 56.9285354306621, 55.82708289546352, 57.6806773677949, 59.28634666627454, 52.91731965157294, 49.05126294782085, 42.96192446062642, 47.48331508328838, 51.98778852339714, 56.03388594042871, 56.931916513750636, 63.031511998945675, 52.50913035485053, 53.71781656819006, 41.28223219225484, 28.92277513780902, 7.447676360607148, 5.15919792075311, 4.094597524212253, 4.894650722703626, 10.997705248094375, 1.1367734786002868, 0.11862671558534908, 0.09415976718188294, 0.08072638478610786, 1.7076104735174489, 24.957827637272498, 44.0376619369753, 37.062762091236735, 19.61337862476226, 25.86291063216425, 30.559758678559337, 53.56577373320057, 49.32371077998992, 34.513947117713194, 4.413210182420669, 0.32112040106327305, 0.02674271408919125, 0.06180251152404855, 0.003809910859056418, 0.032290969900186026, 0.06533101291185425, 0.012658070772886278, 0.02775709685539046, 0.008181969376070606, 0.0699108397407878, 0.026363197961942326, 0.027914886069934697, 0.04712557690518518, 0.04755596893148557, 0.006568626511932141, 0.05542020238335094, 0.09026506810539192, 0.016248412693159717, 0.031202636666656024, 0.0031808849223213453, 0.0032415835049769454, 0.043983444301111084, 0.05881653062158054, 0.019616872567923802, 0.03908195247453067, 0.01771196813112305, 0.011016624930855489, 0.05511030832666063, 0.06834311741254023, 0.04900981995066808, 0.02399079411500885, 0.020756485811885328, 0.26516656481450607, 0.040728505250186696, 0.01503252677784692, 0.07106649869632337, 0.0713464885108894, 0.03077276174970452, 0.10180554683170012, 0.029694741974855145, 0.061041008635994896, 0.06396346169734193, 0.08217926287362654, 6.827026980538522, 60.74580961658109, 68.80358173001197, 61.67843549482284, 43.734607850351644, 42.0798893128672, 33.196426899202415, 34.41571527911771, 41.96087675709879, 36.963922285264545, 5.018554474076917, 0.1191364704901653, 0.03627515187667262, 0.31875996159449704, 1.9107099430214975, 4.130268048855567, 8.778118337354353, 8.071183187346305, 10.92607786578517, 15.56488169777778, 29.840574456799416, 49.29543833578787, 59.6266201234633, 64.68488124109084, 64.29035748204878, 60.97667248018327, 57.92337009983679, 50.089588857466175, 46.25996705024473, 56.89077477301321, 60.438197735817205, 63.84008507574759, 60.56326643113167, 57.14858824206937, 57.149011858047984, 59.2321865789352, 59.619124474064, 55.756099762455115, 48.30755410655853, 42.946372262893185, 47.87779569625855, 56.876971952376834, 58.907492776070875, 57.56548127820415, 57.60333607273718, 58.37149696965372, 57.021562284038914, 50.33704726926742, 40.81076329754245, 43.24559027148832, 41.821236456594164, 44.060466597157145, 45.07805885807161, 47.25903787920552, 46.83561801910401, 47.48104010858844, 43.534967053321104, 46.82253299220916, 44.619451415154245, 46.57796928959508, 44.47862263648741, 47.05465101426648, 51.797326072569824, 59.66095655195175, 55.70947062584662, 62.61910223191785, 35.672885910157234, 31.528087931294596, 64.926032481655, 53.94806754204535, 58.930470020540305, 50.187463760375984, 48.499208957918235, 44.30949787939749, 46.82524334999823, 43.11069603889219, 44.93535126409223, 41.15071119800691, 43.42757648037326, 41.86759494966076, 42.838024631623306, 43.248775236068234, 44.20294277129635, 42.799765832962535, 43.12562457976803, 44.45779092850224, 43.375365811009566, 46.38249797205771, 52.351670726653076, 55.281779304627456, 55.515242699653875, 53.29588328638385, 59.612507435583304, 53.39264815853488, 48.429449604403594, 53.24462183060185, 57.398196112725046, 56.729514368118785, 56.76716519940285, 58.970336990971724, 61.58218837553456, 55.80597269919611, 50.394023618390484, 45.42382363350161, 49.38460557691513, 55.682559244094364, 58.50254727948097, 59.7331242407522, 63.67941302637901, 54.37275432771253, 57.517432243593284, 44.0217371140757, 24.930186694668187, 7.419932455785814, 9.253838100740987, 11.816129357584062, 11.409542349077041, 11.371986635269659, 4.023046137825135, 0.7171963155269624, 0.10134790122749344, 0.043646170262006984, 2.0751390101448184, 25.892281340014552, 43.16648390985305, 36.56292661543816, 25.277059539671868, 28.266344916435983, 37.039016062213534, 59.33438001140472, 55.52477405917261, 42.66764863844841, 5.674737095832826, 0.2978289379708229, 0.023985479380034154, 0.0495048966108551, 0.06648949873183044, 0.09062963402679852, 0.04374456659500157, 0.08912407207272707, 0.03595913294702768, 0.014277532764319933, 0.010143930126251954, 0.008552438962543684, 0.06268417913346522, 0.059549129012251095, 0.0006864961171466407, 0.02773771100046654, 0.05397645223345007, 0.024756665619450714, 0.04171685826393866, 0.003807939619066254, 0.053016245290036165, 0.021414304445047053, 0.07250482111328072, 0.19567312041838325, 0.12620063618786875, 0.1101588776275035, 0.1710179288901629, 0.1324622558369752, 0.20926258556785124, 0.12874677536949036, 0.21312235103499508, 0.11621447325113321, 0.11320970787276184, 0.3496733253761646, 0.10933871155664807, 0.19507238491167947, 0.203878044661495, 0.22958587164119368, 0.10919267221564248, 0.19556240539156622, 0.14039076023524807, 0.1766217548039652, 0.1787438183542221, 0.1668407578742312, 9.279208971608071, 69.81289386749268, 75.5393974242672, 70.30533959788661, 52.86716038180936, 45.977242608224195, 38.84436145905526, 58.740725363454516, 55.0046677743235, 42.04581176081012, 6.380125851400438, 0.15425538884535914, 0.16240973596370992, 0.2441346167676872, 2.4758507984299816, 8.55416767058834, 16.971728994000344, 14.104896091645765, 20.63751143793906, 20.42217919903417, 34.07879544842628, 56.434940445807676, 59.66985248750257, 66.17274607381513, 66.80422413733699, 63.86475286176128, 60.49480538214407, 51.75240708935646, 49.35094379609632, 59.87147015909995, 62.9368063711351, 67.20217997027983, 61.725884406797356, 58.26311011468211, 55.86384727108864, 59.88902668799124, 61.98258392272457, 59.59606093745078, 50.85703196064119, 45.051163165800034, 50.41734603143508, 57.74341960107127, 61.29053269663165, 60.02794135001398, 59.986446595961056, 60.46073567482733, 60.35997782984088, 51.83657723088419, 42.93917471362699, 46.73933167611399, 44.13965532856603, 46.16759915505686, 47.952834560025124, 50.06479555560697, 48.82630717369818, 49.86533518760435, 45.26051182900706, 50.065787915260564, 47.5639864706224, 49.72827580667312, 47.39634829182779, 49.292955475468794, 55.8618821636323, 63.5115748067056, 56.584163096643266, 63.71852297936717, 38.05631414536507, 35.507401112587225, 66.79369649579449, 55.83210745165425, 60.049435938558275, 54.85171887182421, 50.18591834652809, 48.19023601470455, 49.71611253676876, 46.09621201792071, 47.81340998987998, 42.039826223927165, 47.46466813548919, 44.44185433849212, 45.84433701730544, 44.76305330953291, 47.41976876412669, 45.61274067048104, 45.990398237782145, 47.00689223504836, 45.93275900809996, 48.91170501708985, 55.20261802980977, 56.709973119920306, 58.47678907455937, 55.15065054739676, 62.27430628192041, 56.98248371001213, 50.05147518650178, 56.196381891927416, 60.19129237821026, 58.900769833595525, 57.44352302243633, 61.81464372142669, 66.24408614250922, 58.78556197689426, 53.08742500120594, 47.797779344743304, 53.50860126556889, 58.10064946451495, 60.98106553477626, 60.91136109444403, 66.3752737352925, 57.114710730891076, 60.21084539351925, 43.014637193372174, 33.35105849850562, 12.791296282122213, 15.18333706163591, 13.010373403949123, 15.524326351381118, 22.623183881082845, 3.933901450326366, 0.9780964447605995, 0.21830844452544568, 0.2273779602781419, 2.424151017781227, 36.4318919950916, 56.711173365193034, 51.350160183445105, 30.189051551203576, 36.24997638886975, 43.76998370693576, 67.60589384263562, 64.08614712376749, 52.72939497424711, 9.23181006985326, 0.4278814335984569, 0.08517717942595483, 0.15900332600839678, 0.1761475310570771, 0.16485960853676643, 0.1684531584502228, 0.15202898411981522, 0.09391477226369804, 0.10952498583543686, 0.13215896162775256, 0.10097401201604836, 0.2048146790794788, 0.2728337259782899, 0.17684650967919058, 0.08971136273635973, 0.1328282007166455, 0.1696029338504999, 0.1458918997236798, 0.08973885763196215, 0.16986202478649157, 0.1388149786620371, 0.1648138424441699], [0.03991792293926401, 0.03697489275627079, 0.0901634082378399, 0.049692113177790764, 0.04070314773989301, 0.05938331311148021, 0.04535170031651374, 0.051631533706019965, 0.005437613083725615, 0.05019085173825583, 0.0219471856290775, 0.03537713595095181, 0.04710604549355565, 0.004853778913046324, 0.015522899658178851, 0.09537639141443277, 0.028392268014290643, 0.04356067484965728, 0.027868618189747778, 0.042455796032182636, 0.18937999923383037, 9.61455887363803, 51.81856962942308, 57.79965462223176, 50.31139889071065, 34.82227286984844, 22.507491611665298, 19.501089011469197, 40.57911203753564, 44.187010103656405, 25.389307968078125, 1.051568689365541, 0.05362523539412407, 0.05477587264331599, 0.12793729622517863, 1.4427947156852292, 5.517639306283766, 7.07158774137497, 4.802007771307423, 7.208189185588592, 27.453582748290035, 45.86147385258829, 58.87775728779455, 62.62540155841459, 62.23989532839868, 61.38842328902214, 62.75225100978729, 55.91469687800254, 44.266559693121145, 48.580492234999134, 57.35179447358655, 58.7927399143096, 57.18039474179668, 56.261508926268554, 58.388712252340014, 53.71543176712529, 56.617573845771055, 53.19163453194403, 52.60597759677518, 46.70885093750493, 43.30476707027805, 44.9479656065664, 52.407564501608576, 56.60332387493503, 58.79601901577365, 56.32912666566911, 56.17317714998799, 48.657951201162035, 42.51292290226106, 39.89157545951105, 40.95034476249449, 40.63365651715187, 45.20908563367782, 43.68557037845735, 45.55089273760396, 44.66271515815489, 45.84347017349736, 42.856338177957845, 44.308101515616144, 39.97074457906908, 44.07994508743287, 43.494099878495746, 45.957022789985906, 47.677170384314756, 57.057750071248705, 52.17787050431775, 61.556128148109686, 38.769075485967825, 30.622975518626554, 59.68480456259943, 50.97219274890039, 54.348000249555035, 44.892185580345895, 47.77598665606591, 45.883411668962054, 49.706585099620206, 43.274639344984486, 43.359374307817035, 41.08963989442395, 38.829762397273896, 39.63207929365097, 40.88894397981706, 43.03737125089092, 43.23467823766893, 40.81780787437193, 41.617049632533906, 41.43438877597932, 39.62295978300033, 41.6093147185541, 48.1820539505251, 53.79329081504576, 54.89858335064304, 56.32666733957107, 54.92032897087836, 50.83699257143083, 42.243314866096746, 46.84387853068691, 54.63144248531711, 56.06136214348578, 54.583099272943315, 56.341344848755874, 58.50959577868062, 56.55501988626296, 52.712411111400975, 50.46899972423431, 46.071661903012185, 49.33690955561977, 53.70167993730115, 58.15700607915079, 57.34793093896682, 60.143176663306456, 50.06332858916252, 57.54103314492011, 36.31600164598034, 9.27574355756083, 5.642671719674142, 15.11676267270119, 7.312791933936458, 4.897808720988612, 1.9806583057488165, 0.4972940557185681, 0.05772192121273088, 0.038827998158071315, 0.14376392197464744, 15.158938938571563, 36.95941940430672, 28.37712637839779, 23.504056046085974, 50.226593325215006, 32.17342176745015, 37.17574596405029, 50.07016528037287, 41.41381594442552, 12.975035790474186, 0.395345863315367, 0.0536776089950675, 0.0691853391547357, 0.027882187522106597, 0.0454609904197916, 0.02514008304945404, 0.04424319407271762, 0.027602467753533876, 0.11614952431691271, 0.09621826075618306, 0.1281167982867168, 0.10758027930053012, 0.03514860043182008, 0.06675654166047612, 0.07385761747437139, 0.07981817989099411, 0.015606689567287124, 0.044296100104768435, 0.08099167337340694, 0.02497282307294588, 0.034246183330974275, 0.07107914680795324, 0.0648399735350282, 0.08945219519157564, 0.03290770132274878, 0.012923376597163659, 0.0610242581235305, 0.02710011134284639, 0.013335447630754883, 0.051676395814865834, 0.031854581320658326, 0.012094453183723795, 0.03723962976026439, 0.00334638983927547, 0.018519344364082622, 0.07379859039980559, 0.08960326773024375, 0.08080220450797389, 0.025823793539236632, 0.06944030853769473, 0.04597240773540351, 0.04367220576011366, 0.14189480533522947, 12.614997509987125, 62.77788369886337, 64.40407876045474, 60.22137303506175, 42.79156023456205, 30.668569149509555, 25.198857284361317, 45.778923649941724, 47.01219135715116, 26.13415821906059, 1.056209833871934, 0.15079737520746647, 0.04545048352391009, 0.520085385970531, 3.18528302734898, 7.688452034227311, 13.992726110642957, 8.0583369347357, 9.570167449212844, 26.029705501371815, 47.88480497175648, 59.76347946351575, 63.22278245802849, 62.19066173799577, 63.89750073032995, 63.78044543727752, 59.15404904273249, 46.25860991016511, 50.79114790885679, 58.79634065012778, 60.63109205615137, 59.3202712458949, 57.67670008444018, 59.043732381636104, 54.65230949463383, 57.00109927884994, 56.237515787924494, 54.77331853681996, 49.08986691505679, 44.799072434825284, 46.926628774212254, 55.36199961939166, 58.282008094172326, 60.621572463743156, 58.83871401509931, 57.604234295506636, 50.892725529209265, 44.002882280657374, 42.86693642216344, 43.7252490751205, 43.304716079465805, 46.6509057629493, 47.44085542617306, 47.58686173346735, 47.198272520496005, 48.257587032933394, 47.28314868865475, 46.08001655147922, 42.28898302201302, 46.53915351436984, 46.210039200321326, 48.0669088517466, 49.70240777538669, 58.68871473496961, 54.725418552275634, 63.62361731067781, 39.04791678151777, 32.05043781188227, 63.004659452746, 54.60835149211269, 56.12222948381978, 47.279053734194854, 48.989948457287205, 48.367334950354795, 50.97269088991227, 46.669152628990915, 45.50311042416481, 42.877585657181285, 41.59344480883691, 42.61346893925821, 43.44091253895914, 44.916143417358406, 45.87111896084201, 43.242299402913744, 43.65396391960883, 43.98484330023489, 42.46013564448203, 43.117446437958755, 52.4492592965403, 57.48623763361285, 57.4835390429343, 55.05493294808173, 56.7024931600017, 52.86503837954614, 44.57454812142157, 49.32530326227988, 57.22710624817879, 58.73202162404215, 54.684202286504934, 56.67962181952692, 59.81906729359781, 58.62408191927018, 56.356983338632894, 51.00656055635022, 48.40571534249091, 51.72102812797793, 55.252683162689216, 59.621689704156694, 59.913372839650805, 61.12496552928802, 52.729041960931596, 58.954451391773844, 36.740304039370635, 13.871988692591268, 4.569853957622282, 6.238089473016801, 10.43161407593758, 8.451696730429127, 6.487765985150491, 1.3951496852021064, 0.032492075641188896, 0.036776368731572744, 0.10992919680692496, 14.135083633084452, 39.541174442537375, 31.47560073483375, 25.28611040884449, 52.99292333664433, 36.89277049033873, 44.90660029072916, 54.75106300846223, 50.279027569678526, 15.786779984351128, 0.4139919837395991, 0.07195133790974656, 0.008994632573317616, 0.015797722209695608, 0.08574987611462993, 0.005257759100547241, 0.04544582187889084, 0.03685961950630431, 0.021872991928830746, 0.0213254171784126, 0.08586787663760685, 0.011009836434236458, 0.021358232554649154, 0.012355831849779333, 0.06906999695685602, 0.05149595529562043, 0.0221554025812375, 0.04627064959476552, 0.021037347051465226, 0.006425014712036618, 0.03504794413944887, 0.03685672752439015, 0.22127020172774794, 0.113699835604958, 0.15150746210448204, 0.13423550423354874, 0.1471361490867792, 0.19887665496958842, 0.13986341595169038, 0.17865881323814395, 0.08170080266051716, 0.17927836386426804, 0.11666858719000894, 0.1455603368700512, 0.18251051946032434, 0.1673917436311322, 0.18077670927009276, 0.2708914172985862, 0.14529458096911832, 0.17272442038501465, 0.11349640095666533, 0.2135517279947958, 0.40448100215965704, 17.20264284841476, 74.26137155102145, 73.4059496848814, 66.45894573580834, 49.57168694465391, 34.29010529671946, 29.504656791687015, 54.47229231557539, 57.44859072469897, 33.03607256181779, 1.5133786249545313, 0.2970245762938454, 0.1274635321310451, 0.4166407174160404, 2.4486964748751734, 15.076152413122117, 14.526362611401467, 13.241963867218265, 13.149142938275492, 32.662609969415975, 49.58384236981792, 60.200921796983295, 64.16962300577472, 63.14140112169328, 65.9179332179408, 65.88498530849334, 62.13781564466415, 48.584818609299205, 53.90309364564958, 60.975503613871915, 62.788713362909135, 59.459111382884366, 57.81908996643559, 60.74862587836481, 56.406185550074426, 58.96592824689804, 58.57471496828141, 58.06046870446975, 51.667523076457364, 47.466288074370354, 49.24918182434575, 58.61483297040386, 61.20998682514314, 63.17769089052754, 61.19012002022036, 61.97281722099551, 53.41899471898233, 46.354911942635816, 44.35786462599232, 45.721696269127634, 45.024522427589666, 49.513863363573634, 49.23808936149844, 50.442084420111875, 49.68592989829279, 51.23457185683712, 48.638092240979596, 48.62022976721487, 44.521662804388235, 48.684070264139486, 47.91351672141783, 50.47824867310063, 52.93093812081122, 61.53420209884644, 58.271115672203806, 64.44665216630506, 41.14682412916615, 36.36158350975283, 64.35653178922593, 57.425582101268155, 57.52743820990286, 49.8155838443387, 51.38206474242672, 51.102097726637325, 53.32049615921513, 48.75977593083536, 46.1480422173777, 45.76680744847944, 42.7158937915679, 45.2901884817308, 45.62763783239549, 46.88368274319557, 48.473984195340066, 45.179040278157885, 46.23312627115558, 47.30059931355138, 44.46261544381419, 45.25253372807657, 54.681990069727746, 60.6334533229951, 59.78501327576176, 58.95876992133356, 61.42757246571203, 55.873963063763036, 46.648830829128144, 50.24751524771414, 58.9781895760567, 60.27441916927215, 56.218311863560835, 58.6522170805162, 63.14612757775092, 60.793513482616795, 58.40870849547848, 55.29696672193466, 51.439496086489775, 55.254326635791415, 58.296481640108176, 62.68196605866956, 61.49371931629797, 62.992594242095954, 53.85908465231619, 61.00816519029679, 36.02242400569301, 13.78640845898659, 11.117365975533763, 22.931368427891886, 14.527566779044367, 16.409404277801514, 8.541825932841148, 1.2747932273534037, 0.3551307212441199, 0.17366346031908067, 0.2551879172003077, 19.680333483603693, 49.447630220843905, 39.43155988570183, 33.8121291898912, 57.118974347268384, 43.029573578988355, 51.58305875716671, 63.80790595085391, 56.92466012893185, 20.989718706377094, 0.7555026116390383, 0.11727123025564418, 0.150614203584771, 0.09081809931705076, 0.1591292708631485, 0.10959489135852746, 0.10396435195880552, 0.08381499082691247, 0.1235405031231142, 0.12715769450991385, 0.18364345624802575, 0.15553195179710466, 0.10193389720253407, 0.2013056133423121, 0.1939927525217495, 0.25186885659012104, 0.1341805910511363, 0.2023001640073715, 0.1406276499431941, 0.13396545824023987, 0.11729342382281058, 0.11639237418890962], [0.03009234352277652, 0.06397675715326782, 0.05960206568781888, 0.023023650245440584, 0.033336166637919606, 0.04035881037012704, 0.022848932402989557, 0.052677515683875936, 0.014014813444396902, 0.015964685327133105, 0.021157479214091456, 0.045318773857528166, 0.03920359957602717, 0.018641110209207383, 0.08870517519573051, 0.044486541901865316, 0.025222506449227373, 0.03436213456875375, 0.017375349097194213, 0.021547109617160696, 0.06313817049827307, 16.60833316464578, 53.899587046715524, 54.50841734486242, 41.79343469681279, 24.79600633344343, 21.582961505459203, 28.374417981793805, 37.27987704738494, 35.37191067972491, 12.240969115687955, 0.1750561009131132, 0.14241356943403521, 0.07723383590458863, 2.4323335722569497, 3.7010688214532794, 1.9532563825768812, 9.107236573773047, 8.396122628642667, 20.69422302707549, 39.75294713051089, 58.35423461852535, 60.556625858429946, 62.05016636079358, 61.425019002729854, 63.032943664058564, 60.27934174383841, 52.57253939105619, 44.47501405592888, 55.27961807866251, 59.06763138309602, 59.7280800727106, 57.88483281289378, 59.16486693966774, 56.2091217502471, 54.734655734031435, 56.51681992315478, 58.10958462376749, 52.96601979963241, 43.6514457579582, 43.0896839018791, 44.3319809052252, 47.95606267067694, 53.451668062517726, 53.304037893972094, 51.218446993058734, 48.49822052063481, 41.31965552606891, 40.659822648571385, 40.12635677091537, 40.81743132683539, 43.12170220959572, 45.74878807990782, 47.58748539032475, 45.950821522743475, 44.95800295183736, 41.56038315065446, 40.20159175319057, 40.823091306994044, 40.40795157032628, 43.622749697777536, 41.672068718940984, 43.56554977355465, 44.80494422297324, 52.90925918086883, 51.323382162278705, 61.067087035025324, 41.04125353597826, 28.024742603302006, 62.74643805719192, 51.939508068946104, 54.811742075027965, 49.59800604851016, 52.46765913501863, 49.49114499553558, 51.945693646707845, 50.59824966615247, 47.409731418855735, 40.075558154813706, 40.72763258411039, 38.53054438867877, 42.726374364668324, 42.59626150131226, 43.168272510651626, 41.965748340852805, 42.123513913923695, 39.34101197027391, 40.36145579430365, 40.05991574256651, 46.24207319751863, 51.14029768974551, 53.9830982300543, 53.6002984354573, 56.310695448229396, 51.02942012971448, 42.61257463885892, 42.88681107182657, 52.163126314840014, 55.10253483249296, 55.34886360168458, 55.069700671780495, 56.01775715428015, 57.40516224215108, 56.15354176490538, 53.39726871059787, 49.68206636367306, 46.28428182294292, 46.767239339890025, 55.212000339261955, 58.356584118258574, 59.705102828241166, 61.10495751903903, 51.71567017032255, 54.02357709023261, 30.384071796171128, 9.032687025685465, 8.947588263019439, 13.124158420870382, 9.75683206512082, 6.187006485077643, 1.3739319914771666, 0.34743064894310893, 0.032856882880291635, 0.057180863955328544, 1.8088011275376044, 36.59467427961288, 43.45305619701263, 25.361331662824078, 29.147246499215406, 45.3954452853049, 43.66441311374788, 50.35701605581468, 46.79050291738203, 26.654968569355628, 1.1734811024319742, 0.07543138423634153, 0.009216305859867603, 0.03358344066767924, 0.02710606576123786, 0.04771929887694217, 0.03252232079243949, 0.04158582658536973, 0.11556203447041974, 0.03560336171499184, 0.03212907445436764, 0.0128366180973488, 0.031731172216935985, 0.016648258878699234, 0.04884043408017005, 0.030979584421842333, 0.06736796409372361, 0.027724511305531187, 0.13365600468410602, 0.017102882266044617, 0.005858949950761012, 0.03374944425999157, 0.014444899993137488, 0.049127985182548725, 0.05003686423503584, 0.011616774380297191, 0.11620695026771677, 0.03814462091653578, 0.01234056850549795, 0.04858119375703316, 0.024720207495134205, 0.15731313686457374, 0.016659298205688115, 0.06859174358748621, 0.01350534773777209, 0.06272206218132088, 0.06126465268373009, 0.06725023170152018, 0.012708222718849298, 0.060172184490628784, 0.047290078965165926, 0.027754593663097873, 0.13017945171844575, 22.89680842430361, 63.74460674101307, 62.41672362050703, 50.354137036108206, 33.426979895560976, 28.43125116440558, 26.48630272957587, 34.30284907740932, 39.26340787641464, 13.383214300678624, 0.09447515025855073, 0.11465634234369763, 0.05083474863861358, 2.094086999854734, 4.667843589859625, 9.549562258105125, 10.764505632462042, 10.992408087176662, 15.573173588322057, 38.34430240815686, 56.8052553361462, 62.19727485410629, 61.56693820030459, 62.745724185820556, 63.5309434706165, 63.226124317415305, 55.95166913924679, 46.78919284574447, 55.3797051983495, 61.429565029759566, 59.382574173711966, 58.44474723262172, 59.34006352578441, 57.19357390557566, 55.29779434204102, 59.943837888779186, 58.745396906329745, 56.39468908309937, 46.505687852059644, 44.214078380215554, 46.127371326569595, 51.63151571827551, 54.99776440282022, 57.04060539122551, 53.652305141572036, 51.36896010368101, 42.9467527327999, 42.31102282001127, 41.92843483340356, 43.05874816833004, 43.65496804637294, 46.99477603358608, 50.32960261068037, 48.533800340467884, 46.95747429324735, 45.52673093734249, 41.93475769412133, 42.61694023686071, 44.07699938743345, 45.59641968819403, 43.51268799074235, 46.20697975158692, 45.726434492295795, 57.71749273423226, 52.81886816024781, 62.9038231603561, 41.61524534225464, 29.30124071336562, 63.9609960586794, 55.376751653609745, 57.40267153709166, 52.14744075652092, 53.896178507035785, 50.40547301692348, 52.70376620754119, 52.848489899789136, 48.72689077931066, 43.74784584968321, 42.293713400440836, 40.64519220782865, 44.19031273934149, 46.103017330169685, 45.22629699399395, 44.89457038141067, 44.237447861702215, 42.14602439634262, 43.12003127990231, 41.26220849252517, 48.03022684589509, 53.274808391448, 57.36641314721877, 56.9919523116081, 58.223321591654134, 53.52893483254218, 45.3132833973054, 44.69892255721554, 55.06499382757372, 57.17060058347641, 56.8140257558515, 56.46021227682791, 58.67430786932669, 58.56974140290291, 58.2448632486405, 56.36146268536968, 52.39514235527285, 47.82344733515094, 49.57340494278939, 57.32456145748016, 60.569502999705655, 62.43465277456469, 59.47608740099015, 54.437245938085745, 52.478520178025775, 28.14679107358379, 11.422407723242237, 5.4513071237071875, 7.624997890764668, 10.632205067142364, 11.484878332384172, 3.774082761618399, 0.8048601244245807, 0.03301948121178054, 0.03771355856330164, 2.981189359580317, 33.70502494996594, 38.240151712971354, 26.07630914257419, 31.403966488376742, 47.09150952677573, 47.447637204200994, 59.061845887091856, 54.31307938791091, 33.26178143101354, 1.306655743429738, 0.10207502591994502, 0.056910680066193306, 0.048920800533866694, 0.04803360943051596, 0.020856467946883173, 0.11626713413504824, 0.02032246827448328, 0.13366850723903026, 0.027764301912318316, 0.08629022857114192, 0.0880071082182469, 0.04865912405113059, 0.04274682134329792, 0.03678222547375387, 0.05614489474664292, 0.07514984692416846, 0.07207504578775938, 0.02392108777477857, 0.03179954747939783, 0.0428868277418998, 0.06466591069775243, 0.06487524422306208, 0.12650481905908356, 0.12599507181514658, 0.09212729761437063, 0.31288176895149294, 0.10917322890412424, 0.14622615920680185, 0.20433267187928, 0.10029807731869722, 0.18578493246628394, 0.13663671490165497, 0.18433691903708443, 0.20205428042719442, 0.14964496446472986, 0.20289400472275673, 0.1308525212469601, 0.11478025706545, 0.19010502484536942, 0.13051424746311482, 0.21486305601654515, 0.5667257381062354, 29.067610617606874, 72.45416302834788, 70.12706002881451, 57.72607095779912, 37.360136585850874, 31.68981509823953, 40.28973133333268, 50.039151099420366, 47.673608872198294, 16.482077952354185, 0.32631662223608265, 0.26027184520517627, 0.17666257196857085, 4.90529211298112, 9.740592472014889, 12.307786691573359, 17.795161970200077, 16.699842060765913, 25.81401828796633, 41.8980521540488, 60.81586314785866, 63.46973488407751, 63.722425737688624, 61.6349599438329, 66.60838019463324, 65.19857052833804, 56.056168925377634, 48.11953529234856, 58.833273687670314, 63.35523305400726, 63.153097629547126, 58.51212570744177, 60.00388937611734, 56.42521689015051, 57.32249436839935, 60.90866250376548, 63.26580301407845, 59.62706335129277, 48.71892052312052, 46.15411012403427, 47.74305443609915, 52.459712413049516, 57.61836659523749, 59.33417997052593, 56.53379201889039, 54.1227149963379, 45.6250019996397, 43.933817186663234, 43.91915144458894, 45.798264857261415, 45.9614158445789, 49.39098727318549, 53.08213764621366, 51.46095929607269, 50.48436364819927, 46.449939204800515, 44.111492710728804, 45.15137972370271, 44.98939760269658, 47.282956492516306, 46.31508419590612, 48.52697541636806, 49.08476783383278, 58.10530531790949, 56.420984652734575, 62.9659652709961, 44.89468020777549, 31.781039622522172, 65.87945476655038, 57.095651934223795, 59.352677868258574, 54.87100908833166, 56.824200384078495, 52.442614801468395, 55.6622649008228, 54.57634495150659, 51.177995589471635, 44.7008131396386, 45.152407384687855, 43.192238192404474, 47.1644106987984, 48.70239165521438, 46.66083328185543, 47.42385587384624, 46.07442717398367, 43.868392052189, 45.61630610496768, 43.270599303707, 50.95668369723905, 56.861427599383944, 60.719223791553134, 58.47006613208402, 61.63722315142232, 56.48772770358671, 47.47616852483442, 46.417414911331676, 58.092408564782914, 59.86353520424136, 58.62747869183941, 58.52622270584107, 58.8626600850013, 62.12666042389409, 60.195430478742054, 58.51109804645662, 55.9717163731975, 50.0217475429658, 51.41845649288547, 60.57850091688095, 63.934955443105395, 64.14593973467427, 63.72760326631608, 57.01154455061882, 57.88541332367928, 31.662942940188994, 16.687068862299768, 17.772314163946337, 24.961704900187833, 21.410696891046342, 15.389726296547922, 4.458930800038, 0.8235466023606639, 0.0982656077511849, 0.23713159254722058, 3.4240153912575018, 48.36001972998343, 56.21843345703618, 37.34745556308378, 38.9900775109568, 57.09644817536878, 58.41871838415823, 65.96581751300444, 64.00318114988266, 39.433885851214015, 2.1988797380078227, 0.3286398911187726, 0.11857552559024866, 0.19478629703723616, 0.15047215556185092, 0.09821103930833841, 0.26289428674405624, 0.14451759927455457, 0.20468263616484983, 0.09933770949681921, 0.13788625027143186, 0.15336222225619903, 0.1787315762691921, 0.13797110216992517, 0.1293805445874891, 0.12934174989500355, 0.1607287551967367, 0.16247856130282726, 0.17613892022880817, 0.11329364812662525, 0.10609759273187769, 0.1640359874093725], [0.012458789278753104, 0.04195460982079949, 0.04973257028107202, 0.02107783862870307, 0.05206697808218099, 0.052755139542803656, 0.0969589988310491, 0.04491047963740365, 0.0208199983312478, 0.05435998649186185, 0.029721018790657965, 0.01252956526924766, 0.0118307379494992, 0.037246348351360335, 0.06456824214828592, 0.03896223208416374, 0.02410532425968878, 0.039346674156765786, 0.01960121947641094, 0.0922838400208181, 0.4857822056979903, 34.18697441777876, 63.448420724561146, 51.3577264355075, 46.89115485837383, 30.826271964657693, 21.118854899560255, 33.168421176172075, 50.52272835085469, 32.332071834994906, 3.8675587263799485, 0.08161964330581889, 0.0823160095681106, 0.07184456823573959, 1.02625273168087, 4.052283485089579, 4.079980566616982, 19.291479510645715, 16.313837689738122, 26.863891655398955, 50.36191509615991, 60.93536207752844, 60.77492929274037, 60.786308088610255, 59.996487863602184, 59.02416759921659, 57.60135919817033, 48.52991719399729, 43.35572650355678, 56.21349519298923, 60.577543858558904, 56.81165664426742, 56.83081742255919, 58.70982100886684, 54.210936946253625, 56.776531819374334, 57.83146504432925, 54.26641102760069, 47.995047107819595, 41.829740155127745, 41.31328167453889, 40.89130524666079, 40.88361347875288, 41.803138640619096, 44.27069387128277, 41.36066782859064, 41.1079808973497, 41.6776345622155, 41.597959456905244, 40.474055274840325, 41.63339414904195, 42.084843266394834, 45.13488615712812, 47.345906611411806, 45.19618495818108, 42.304558753967285, 40.87038724653183, 39.17617044141216, 43.194677906651656, 46.45284960346837, 48.93386248619326, 48.257084969551336, 48.944182242116625, 43.08379250188028, 53.29174126348188, 50.608600801037205, 60.79863217569167, 42.80550426052463, 27.65363931655884, 62.721856563322014, 52.574327991854766, 57.92441737267279, 54.45611646098476, 56.145520517902995, 55.62238224091069, 57.552713963293264, 52.76731252670289, 53.990974349360314, 44.176474617373565, 40.16398014560823, 40.26034101363152, 41.760455408403956, 44.30797207740046, 45.915594716225904, 43.26568457388109, 44.208689043598795, 40.60679612621185, 41.06162632665327, 39.545583186611054, 41.58462339831937, 46.30063418419131, 53.645515518803755, 53.91131101116058, 52.98326646128009, 44.03427693151659, 40.21518276583764, 40.4398992753798, 47.18020216111214, 56.24939664717644, 57.12241818827968, 54.8186376017909, 54.46713439879879, 55.303407253757605, 58.3086488323827, 54.8995247194844, 51.50910638993787, 48.35489711453838, 46.38951116992582, 54.70581846852457, 56.901345560627604, 58.26136465995543, 58.93407467872866, 57.14812540238904, 46.16387682576334, 35.971001732733946, 18.54336388649479, 5.760620332533314, 8.853602390135489, 5.388914961968699, 6.6038774578802055, 3.0617702872522417, 0.1418613272929384, 0.10295366748206078, 0.0980198084406795, 0.28356266478377007, 17.572894980830533, 40.19608866783881, 30.467026002945442, 18.27632696397843, 23.59578851730593, 45.069237447554066, 51.088957786560066, 51.44443042816655, 31.066819160215317, 4.745922290509747, 0.06647421527774104, 0.01802595884298846, 0.05293062347317896, 0.023971235890301968, 0.02868742062409799, 0.06865307658670411, 0.028043096629722465, 0.058897827872105186, 0.05154425713924631, 0.0691618585598565, 0.038869799745659676, 0.05249318343797519, 0.0030406874805433497, 0.03366501370985662, 0.009966288700759893, 0.038534850783405766, 0.0607334626387925, 0.025658504323913686, 0.03154045079774674, 0.07957698476891364, 0.04766572634839723, 0.009689368983550418, 0.021041179406306437, 0.07066664676512442, 0.033325073684776024, 0.06290307343606988, 0.03769121177855038, 0.022190931823945815, 0.029891869804311185, 0.037393096323695876, 0.06174247321342269, 0.06419222704285095, 0.04757591403059421, 0.08056706148049525, 0.06701910297476477, 0.02768669145992927, 0.015561595716844163, 0.06518326519477753, 0.02867222910055951, 0.0407258584164083, 0.05870740522720641, 0.972739406410725, 44.351455473130756, 71.73428258588238, 57.71626503236833, 52.790729076631614, 35.352067409023164, 26.187735834429343, 34.637921471749586, 45.491064825365626, 34.05295487373106, 4.368443681347755, 0.20356266158482722, 0.06408000282282311, 0.41744599839852703, 2.951555362632198, 8.430251171511989, 8.788899952365506, 6.375682786587746, 7.617661587653622, 26.25413371670631, 53.19488225444671, 62.90284649018319, 62.71746743109919, 63.218707115419456, 62.89129118765555, 61.236400065883515, 60.37740492051648, 50.70210226120488, 44.68039328052152, 59.00641102944652, 61.361213807136785, 59.33900056346771, 57.19863768546813, 57.772425528495546, 55.74464251918178, 60.026745027111424, 59.57275421388688, 56.48845334206858, 51.14514573927849, 43.94677277534239, 42.16520478648525, 42.88792110258534, 44.37089866207492, 44.48425123768468, 46.86550647981706, 44.78607370007423, 41.947458328739295, 43.728775285905414, 43.74031489895236, 43.51748897183327, 42.878942797260905, 44.89089119818903, 48.30769138951456, 48.96620635063418, 47.72093226832729, 43.658019650367, 42.90352429113081, 43.02152879776494, 45.39648471340057, 47.663999065276116, 51.24487984564997, 50.46759159334245, 50.32881421427573, 47.30969136761081, 55.67342796633321, 52.702232560803814, 63.027267994419226, 44.2082340486588, 28.257119501790694, 63.35178921299597, 55.18438293087868, 61.73053241545155, 54.36769447019024, 58.65830067665347, 56.80673406970117, 59.16162313953523, 55.2333733343309, 55.072587536227324, 46.2676941194842, 42.914475548651914, 42.336361331324426, 43.93054592993952, 46.28562719591203, 48.70456464828984, 45.22440248920072, 45.654498223335516, 41.88313930265365, 42.73301101499989, 41.06584679695868, 44.5198114456669, 49.962900223270545, 56.46974755871681, 56.85904279831917, 54.97705428831039, 47.53329000165386, 42.95151056781892, 40.88093057755501, 49.92485323259908, 57.266498611819365, 58.784298973698775, 57.34698172538512, 56.52462151742751, 58.212903776476466, 58.31797622865247, 55.670439120261904, 54.12975957316738, 49.4712781906128, 48.564834133271255, 55.681005985506125, 58.65573544656077, 61.71778471239152, 59.80992032635597, 57.95364295282672, 49.07266732185118, 35.7600409753861, 21.20413311066166, 7.994939665640555, 6.8441922530051205, 9.141807363879296, 16.884966165788715, 7.63034898427225, 1.1018396241049613, 0.03513044414801463, 0.08262215362441155, 0.5261618115248219, 19.688923474281065, 41.373215490771884, 30.747742191437755, 28.290292947523056, 31.187969407727643, 51.54818104159448, 55.66987037658692, 57.91612940449869, 38.02684145589029, 5.975778025965537, 0.11393920743777869, 0.06681250438334481, 0.05437596708596234, 0.01306926655102401, 0.02486942801624537, 0.06187856107229187, 0.03301961144672767, 0.08494711556141415, 0.08419154602433405, 0.03868989165752165, 0.08789475376327192, 0.0606088622683479, 0.026936789058269035, 0.10161373373721877, 0.044277204546116056, 0.030408078999889475, 0.03976151842864291, 0.04222596199401925, 0.03593221261736847, 0.03983157716931836, 0.04560773456168752, 0.1089202436888891, 0.18945188892464485, 0.13106538643760066, 0.17528525313302395, 0.10714527925536518, 0.15935695219424464, 0.12197017609592407, 0.10256844016933635, 0.1362614850363424, 0.14513710393540322, 0.2455503472517575, 0.1041817447290786, 0.20736271815915264, 0.22622642287563896, 0.1509705723653878, 0.1246783964996857, 0.14233513735234737, 0.12161891712176225, 0.08286614496741565, 0.17300057975995928, 1.6850982750615768, 53.88397209105953, 80.30208049281951, 66.62615637625417, 61.210300614756925, 43.1410865629873, 32.30076151509439, 45.626080651437086, 64.66269239302605, 42.87341617768811, 5.521709255633816, 0.517444895400155, 0.20948746301714452, 0.3623632960502179, 3.3976457868852927, 10.151032228623668, 15.163828172991353, 32.21868003568342, 23.986227127813525, 28.060746039113692, 54.32887477259482, 66.62745860315138, 63.60964190575385, 64.81169539113199, 64.69508724827921, 64.65738542618291, 62.574473504097234, 53.314608681586485, 45.93961531116117, 60.842484274218165, 63.97879969689154, 60.07853600286669, 56.29369981827275, 58.60415235642464, 54.61860456774312, 61.118705426493, 63.12442902595767, 59.984505022725756, 53.39844149927939, 46.52302080585111, 44.82899619686989, 44.36887471906601, 45.885784702916304, 46.84478459819671, 48.36211819802561, 46.507201886946156, 43.57362593373945, 46.83191137929117, 46.50492691224622, 46.886973611770145, 45.15269764008061, 46.729251184771144, 50.289582667812226, 51.356184944029785, 50.52349321303829, 46.48509933102516, 46.127779253067516, 44.639043654164965, 48.03235669289866, 52.04828716093495, 53.881579445254424, 53.363583395558024, 54.51102572102701, 50.308159012948316, 57.47609438434724, 54.48109411424207, 65.17598159851568, 45.790561322242986, 31.08041801760274, 66.09179619819888, 58.122485299264234, 63.68248424222393, 58.10203013881561, 61.496261012169626, 61.04706725766582, 60.48583884393016, 57.842632032209835, 56.969398683117284, 48.468869424635365, 44.747418742026056, 45.476791320308564, 46.700959128718225, 49.46668117277084, 52.10915450126895, 47.062962516661614, 48.83855673574632, 44.376150715735655, 45.03171605448569, 42.56162697269071, 46.99208136527769, 52.29911096634404, 58.4913920587109, 58.57133388519288, 58.11487982350012, 48.44024004474763, 44.34062580908499, 44.828199955724905, 50.410156326909224, 61.60338486394575, 61.68890822318293, 60.11591226823869, 56.7733625442751, 60.43467544740247, 62.0937595828887, 58.600849720739554, 56.32825197712068, 51.6120489951103, 51.954817079728656, 59.14013247336111, 61.32194303697156, 64.12397838407948, 61.44462300885109, 58.02511245973649, 53.47308812602874, 41.367881067337535, 23.55876918761961, 9.918899497678204, 20.6590138712237, 12.975510397265035, 13.13494788062188, 8.01114199622985, 1.2329944896121179, 0.1774219642843931, 0.17732804190487633, 0.9998752212812825, 24.28248570811364, 53.98120764763125, 42.18607571817214, 31.572191061512118, 34.976818177007864, 58.1740919236214, 64.90073319404357, 65.73866521158527, 46.996027269671046, 8.29851640808967, 0.2543377587872167, 0.144225413340234, 0.2040352152600404, 0.07621295479757172, 0.07441182080055438, 0.14587691504388087, 0.17159077879642287, 0.15616493960542066, 0.24047086255684977, 0.14134055604377102, 0.13979134239977406, 0.15290799340413463, 0.1339900036973338, 0.20206797807928056, 0.14750480591770143, 0.1364616484891984, 0.1817421792375465, 0.11457616358154243, 0.17764541681014723, 0.16130313727884524, 0.1793780472249754], [0.08272101727103995, 0.07869111133679267, 0.05376453316139598, 0.043497277243483456, 0.05673649848528928, 0.03246740761002706, 0.02356841728361624, 0.0674388348875988, 0.01855574120136519, 0.04969162288151922, 0.039841030694303975, 0.027674458950998324, 0.07137490271200096, 0.025632053223108093, 0.08128150741779998, 0.018668369532773094, 0.02908888325515774, 0.03516392602074531, 0.023137109782246333, 0.10904967424369628, 3.916234604773983, 48.1709457981971, 61.18093775164697, 53.214572552711736, 38.022985766010905, 23.46023532652086, 20.761034719405636, 40.81534070353354, 43.16594654513944, 17.45988953498102, 0.8143616371577787, 0.054722817224119945, 0.029267105949862354, 0.03625214625630648, 2.012389667572514, 5.205802542548026, 8.60425437650373, 8.041608516247042, 23.446561944100168, 45.474100574370354, 59.27049636840821, 60.326822034774295, 61.224130891984515, 58.58246164937174, 62.134258054917865, 56.95112828285464, 53.05348473210489, 42.32166028791859, 43.97941081754623, 56.78251343388712, 59.397055564388154, 58.13265600512105, 56.49088913394559, 53.68540994582638, 55.6710627771193, 58.901981845978774, 54.94809935169836, 50.9021705965842, 44.179938070235714, 40.059954966268236, 38.89328910458473, 39.39108887026387, 40.701007535380704, 39.82156899667556, 41.54003781657065, 41.71026083730882, 45.58920252707697, 47.63573054344424, 49.4646336955409, 45.955900992116625, 44.52188245711788, 41.531079123097086, 44.577823300515455, 44.09998055427305, 44.74489665800526, 40.915227782341745, 38.74629828237718, 40.215524012042636, 51.064537109867224, 52.0604072847674, 56.449417914113695, 53.50905233813871, 55.96275767972393, 51.39605975920155, 54.14472341537476, 50.56464672088624, 60.052432629369925, 43.68801009270453, 22.98942538999742, 59.339553617662006, 51.18149042129517, 56.84679323627103, 52.02378803683866, 55.96653099982969, 52.64612697785901, 56.079609009527395, 54.98313003970731, 56.47811005192419, 48.3487311486275, 41.238968449254195, 38.19282439447219, 40.980852957694765, 44.19035196304322, 45.129602724506015, 45.50031769660212, 45.15190139893563, 41.68312980282692, 40.29841546089419, 39.82802521797919, 40.612809119686005, 38.833665155595355, 40.24850722282164, 44.06809952951247, 42.7400791260504, 39.72260759722802, 37.9062952533845, 40.79243406172722, 40.7256753213944, 47.820066252062404, 52.84281815251997, 56.40962154634538, 56.58009559877458, 57.20407801289713, 53.77023904554306, 53.445557009789255, 49.46469645346365, 49.396321696619836, 46.63956226841096, 53.171214672826956, 57.685748992427705, 60.61884249410322, 56.97297980708461, 45.821528434753425, 58.07747217916674, 44.53954096763365, 30.881830376963464, 12.147404897597529, 4.944340288639069, 9.916848098078082, 20.506090464130526, 5.98990002947469, 1.3070905136485256, 0.02490016154854769, 0.045069875721369064, 0.052480669391732064, 5.62803735656123, 37.55008520618562, 39.388480494099284, 19.23222230326745, 25.66514276689099, 40.25729333200763, 47.539326529349054, 51.74909268656085, 35.571704449192175, 13.566438017352937, 0.30212537355480656, 0.057525530742901954, 0.013675345520999645, 0.009338619457858225, 0.09889050567102048, 0.044480685159684195, 0.11844326817100087, 0.046037008099618464, 0.02953674400135154, 0.019603165339738614, 0.0273335115202973, 0.0771552812488329, 0.056281323514638416, 0.023098081432943864, 0.01889697591503782, 0.08670639817512805, 0.05787542991099819, 0.046090473375853994, 0.05263949857063351, 0.017380012657433268, 0.06605383985105061, 0.03123660308999881, 0.0495641190378416, 0.016420621597658724, 0.044945294503122575, 0.006570347815737009, 0.03308668627493805, 0.04683730568015768, 0.051424149874477625, 0.026877242959134524, 0.037441317728089715, 0.02143245498319307, 0.021502360506283662, 0.037814984774036754, 0.028130041863468867, 0.05928865911799574, 0.016337644699360096, 0.024106676404875134, 0.12532142772068902, 0.06558465696270428, 0.0801420282392252, 6.09175221573922, 57.32724435867802, 66.60156311527376, 58.958209022398925, 47.84778564207016, 38.1054457541435, 23.648928788400468, 36.35301705329649, 45.42058767810945, 20.399472598106634, 1.027561577577745, 0.005199241474451077, 0.030352786603954532, 0.7288591155121404, 3.4038583309419694, 8.50986449949203, 8.405312741956404, 4.790663786472813, 19.525658738228586, 47.72431727378599, 60.3639002000132, 62.930020670736994, 62.95042484037338, 61.072539129564845, 62.51820318160519, 60.50461915231521, 54.29125532027214, 45.30715665509624, 46.15427878595168, 58.04049599555231, 61.4692319593122, 59.08026141505088, 55.37263708729898, 53.391714634433875, 55.48296551550589, 60.49799819146434, 56.42791940319923, 53.22656716069868, 45.476912913783906, 41.88717542156097, 40.38792787059661, 42.118807069716915, 42.0515658778529, 42.00289318638463, 42.052824958678215, 44.29382801055909, 48.74376089342179, 48.558079811834524, 50.64239594244188, 47.27766129278368, 45.13336035513109, 43.101262738627774, 46.78480763589182, 46.59074052687615, 45.709305501753285, 42.54386648055046, 42.29879286981399, 42.03836317985289, 52.80442991564351, 54.9989293467614, 58.592553907825106, 56.093800144810835, 59.8644648059722, 52.52377648507395, 56.9950274498232, 53.8249796436679, 61.07333929308, 44.165786158654, 24.202332073642363, 57.57976655037173, 52.179239411507886, 58.18851055637483, 53.56718970883278, 57.66343070614723, 55.27959454444147, 55.53841998500209, 55.72402261918592, 58.56459133086666, 49.08690552557669, 42.68489137772591, 40.33106919257872, 43.23572158813477, 46.966189799770234, 48.8290253762276, 48.056628319524954, 47.68932580947877, 44.18958317848944, 42.36425330561977, 41.72329879576161, 42.52837704073998, 40.98134717633648, 43.06077603370913, 46.07252874682027, 45.79477787017823, 42.054033048691295, 39.84144364633868, 41.838157561517534, 43.11435168789279, 51.906379730470725, 55.167736391867365, 59.077445153267156, 59.01471468710131, 59.22890355510097, 57.58815257780014, 56.06602976399084, 51.29342309890255, 48.68736113271406, 49.41255638676305, 56.07072091871693, 59.68163136513003, 60.43050989027947, 58.102885215513176, 49.86817106123894, 58.020331090496434, 48.18508986503848, 29.860351047208233, 13.509581300520129, 4.164620657120982, 4.764641802157126, 15.321032847127608, 5.631837152665661, 4.108158628786764, 0.44461267129067455, 0.04380441338364636, 0.05410778651674909, 5.750917369319547, 37.901808061907374, 41.34831628491802, 23.921323668572214, 30.057650189245905, 47.28364682966664, 54.121506906324825, 57.56962722347629, 44.55538342075963, 17.769899945105276, 0.33102349708637885, 0.032064263415973515, 0.03204480478269679, 0.04071921643410479, 0.031760446351742556, 0.032174830970865105, 0.05842061255187277, 0.004334516378284823, 0.026799542491414377, 0.025040845934962554, 0.03302176798423452, 0.05842385310379248, 0.07814397134127156, 0.048875543889739824, 0.04396526886510753, 0.045689717460904396, 0.020545690973860123, 0.020180563893048994, 0.010037864295525417, 0.05471380419969078, 0.12951333826828387, 0.1880254332096346, 0.18924178165053168, 0.1865035382610175, 0.07678663973966915, 0.0934528518888739, 0.15564392320811749, 0.12543035776264247, 0.10955019778902493, 0.25267196188290275, 0.1346784409496092, 0.23391489660547626, 0.10907781265315511, 0.10209178792372828, 0.09063722595812813, 0.1864133697123297, 0.08835487383147402, 0.10131042420623765, 0.1488262309782928, 0.16174469503664202, 0.19953703808207668, 8.961511696538619, 68.20158420070526, 73.21948805162984, 68.8769849654167, 49.91520420197518, 36.66182133459276, 31.64513145723651, 53.58724086515365, 55.92050198585757, 25.20817683589074, 1.1397197914700354, 0.21574555866179929, 0.24479038803087128, 0.716042525825962, 5.249866449063824, 13.1815093563449, 20.189472821451005, 21.053753360625237, 28.022261704168013, 48.040542679448286, 63.9901981046123, 64.92536960109588, 66.2647884122787, 63.71783656458702, 66.05832269114833, 62.7288854506708, 57.15000421770158, 47.55246254705614, 49.18536878401234, 60.062771997144154, 63.648618498156154, 61.59412022559874, 57.575655906431145, 53.48151729952905, 55.80531374100716, 63.461921522694254, 59.455832281420314, 55.01069645727835, 49.0854581709831, 44.828839302062995, 43.48752206371677, 43.55220194785826, 43.88716843820388, 44.43732400094309, 44.664342941776404, 45.840877486813454, 51.027400109075735, 51.62291788285779, 52.8194918171052, 50.3839901954897, 48.068109097019324, 46.41478300094605, 50.065556495420395, 48.283043215351725, 49.096703606267134, 45.31088682913011, 43.51989730711907, 45.439564105003114, 55.495913259444706, 55.92164339557771, 60.46353624713037, 58.865876428542606, 62.5560030629558, 56.43448545086769, 58.538931185199374, 57.03624763796407, 63.595701802161436, 47.13962131930936, 27.25990003155124, 58.24791093026438, 52.51297035524922, 59.179618973885816, 55.08681005047214, 59.267119207689845, 56.76308201205347, 57.60310857526718, 58.36006718297159, 61.730155867915, 52.22504485038019, 46.416332337164114, 43.245347084537634, 45.71629516540035, 49.38191090860675, 49.735163488695704, 50.883919808172415, 50.18757750911098, 47.33449251421037, 45.10949665500272, 43.71204245475031, 45.03806637179467, 42.984187833724484, 44.55459894672517, 48.58019021249587, 48.3752973618046, 44.64779053964923, 40.67662608238959, 44.45147199015464, 45.25975088919363, 51.634967404027144, 57.064237671513716, 61.7651669440731, 62.2995271221284, 62.66424871260121, 59.990427801685954, 58.39991061918197, 55.213981136198974, 52.976837696567664, 52.40648977218136, 59.218113114756925, 62.301060768865774, 62.66859469875213, 61.89410309637747, 54.521502371757265, 58.8454173457238, 51.20611506123697, 32.19575378202623, 16.749932689051477, 8.886342413963812, 21.0601487851912, 31.18530611838064, 12.677423011872078, 4.273059973793646, 0.4617759212851525, 0.17065408309140515, 0.1595811248426476, 8.24535652514427, 50.37568653783491, 50.257317250774754, 28.306660998252134, 35.49573990606493, 55.00380093051542, 62.115356153057476, 65.88831932313981, 54.420415047676336, 19.933030220770068, 0.7675200796896412, 0.1826904888354963, 0.13170661735198191, 0.09602247932625395, 0.10450681881798853, 0.204898581028946, 0.28129216403730456, 0.11817289275988457, 0.1549744236493303, 0.08848903114877402, 0.1545452305506314, 0.26912926185515623, 0.12294477783143522, 0.15232038864445302, 0.12213350604138068, 0.21408455746789135, 0.22937236293669672, 0.13929885511677112, 0.16504325513397494, 0.1466456076671039, 0.143128206893321], [0.06322082755486332, 0.07277838345016203, 0.018202530618216244, 0.05220108560376591, 0.025455782137390588, 0.05006445106118918, 0.04772394136976331, 0.0221279479052511, 0.017175214372635368, 0.05319930966042223, 0.04065185815336243, 0.07408264814124954, 0.06347856634566862, 0.09256373790483322, 0.07479739285284474, 0.026111603196289752, 0.06286761505649456, 0.011154285185189258, 0.0589881764514552, 0.0269815975409602, 14.993376674190646, 54.953904459553385, 54.8641449405301, 45.5963530079011, 29.65350485617115, 10.438691992913524, 33.81357262211461, 48.48306840465915, 35.833993342614946, 10.902881949178635, 0.09897240047012607, 0.19025778277747094, 0.1790214792614983, 0.9526506198510047, 4.276358687108563, 11.24587360889681, 7.404436642123808, 7.122837430046451, 26.16193448343585, 56.04562167198428, 61.12447523301648, 61.18606036709201, 55.44693854547317, 55.6341689632785, 52.08714608223208, 48.559519321687766, 44.60031809345369, 42.84196269127631, 46.20798387835103, 53.61288139897009, 57.78939370186099, 55.61932671454645, 53.2649318633541, 55.979823912343676, 55.590312942381836, 55.76748248069517, 54.74500686891618, 51.9711890528279, 50.016032649624734, 46.18714824799569, 43.182769590808505, 39.496906572772616, 42.007470592375725, 40.97452617460682, 44.928357678074995, 47.382439567196755, 50.804064273834236, 52.860417827483154, 54.72745818476523, 54.34467015727874, 48.587552501309304, 44.11932960633309, 44.79647190340104, 42.76211892404864, 43.19738434207055, 40.871975806451616, 41.055589798958074, 46.21385958886916, 56.71449561272898, 54.51819973607218, 56.60882303791662, 54.04940197544714, 57.29510053511589, 54.06795478636219, 57.297606929656006, 51.16297683408184, 62.63971428717337, 36.42050143211119, 21.4059704349887, 55.13558472356489, 45.31493079277777, 53.77980570639334, 49.90707705097814, 53.45351549886888, 51.06096775301042, 54.54703307920887, 52.92961628206315, 55.26466992593581, 48.070893979841664, 42.33137599883541, 38.991371893113666, 42.03061649876256, 44.383316886040475, 49.50726201457363, 46.43415558722712, 47.398003532040505, 46.10035796319285, 42.946191833865264, 41.82243670186689, 40.678485285851266, 40.092334132040705, 39.645348671943914, 38.71748062872118, 38.156718977036014, 37.50625271950999, 37.655177270212484, 38.94260898713143, 37.83779498069517, 40.505536217843336, 41.18278441890594, 43.347571895968535, 43.589515455307506, 43.61345760283932, 46.44775836698471, 45.131744338620095, 43.61483043239963, 45.5429381708945, 49.60365426155829, 53.787320967643495, 57.11161990319529, 56.724062273579264, 52.831553105385076, 52.224809508169855, 54.83863384492936, 51.49792371257659, 33.454134464263916, 17.365968381204915, 3.5699015759652664, 3.9866276662195888, 25.227045397604666, 7.762925586392803, 2.5764524840539504, 0.1498067469125794, 0.030195215724468715, 0.06504377590552454, 0.9669620615820732, 21.609443387677594, 33.25265015325239, 30.919985232814668, 18.063036318748228, 31.170944359994706, 42.6825418779927, 51.715689782173406, 45.84967144073979, 22.817098017661806, 1.3491507018766096, 0.093293298756884, 0.023362667134572423, 0.014102641594476037, 0.04529430117878703, 0.028120008026880604, 0.03546537012763081, 0.04829455429928438, 0.06041993349490147, 0.06902652912803235, 0.08424326462010223, 0.033045443931534406, 0.02128715108659479, 0.02350203768019715, 0.03610555150155579, 0.03904332632138845, 0.04880320220705002, 0.0764004624779186, 0.020754980449114117, 0.041516468815144994, 0.014186000579126902, 0.030707538939051093, 0.09187830371722099, 0.052949813975682186, 0.048666206533990564, 0.05464980138405677, 0.02219383529717884, 0.06007868728990998, 0.07412887388660062, 0.0036000906285123843, 0.03824286403194551, 0.11258261128058357, 0.04840662147128775, 0.023991749809694388, 0.0300045172879172, 0.05700282895216539, 0.025209651493857947, 0.09971238011794706, 0.07266829661544293, 0.08283988347337132, 0.02791767462997908, 19.613325672764933, 63.436637924563506, 59.1958732758799, 54.320237713475386, 33.830289763789025, 18.253789024968302, 29.087340139573623, 44.59125741835564, 41.43312185041366, 11.643884355022061, 0.1131627926482789, 0.07990996488520215, 0.1933656023034165, 1.7023454270055218, 5.273279076622379, 9.306474347268383, 9.010221650523524, 6.218986549685079, 28.621629284274196, 56.43091609401088, 63.80987498068041, 64.81736321603098, 60.44623074993011, 58.86005563120688, 55.45380661564489, 51.608012876202984, 46.00536207998953, 43.985608162418494, 48.76200775946341, 55.460655073965754, 58.4060138271701, 58.51552640238116, 54.652234969600556, 54.29001192892752, 54.87104831203338, 58.21263313293458, 56.633800691173924, 55.02961404861943, 51.661243361811486, 46.77466830899639, 44.41424869721936, 41.73823910374796, 42.873580917235344, 42.93938652161629, 47.26344662327921, 50.40520237338159, 53.30108827160251, 56.43625051744523, 55.931115919543856, 55.14081716537476, 50.64768721980434, 45.27541291329169, 47.58621062001875, 46.602511559763265, 46.043938590634255, 42.89953131829539, 44.23935805597613, 48.32530675395843, 57.973027306218306, 57.8807496255444, 58.53800942820888, 57.169031635407485, 57.68190114728866, 56.30776936008085, 58.309645114406464, 53.76658339654246, 64.01584648316907, 37.344015644442656, 23.237758490347094, 57.90165978093302, 45.43211944641606, 55.184045607043856, 50.42120564368464, 54.4749124588505, 52.716188353876916, 56.5236879933265, 55.071948189889234, 57.27505330116519, 49.41972647943805, 43.4430149293715, 42.07593164136333, 44.31263577553534, 47.03863205448274, 51.39564398796328, 46.56282894072994, 49.421260126175426, 48.708741972523356, 44.4160569098688, 41.52026907090218, 42.95046329498292, 40.98371236555038, 41.314219121010076, 39.88594685831378, 39.85612507789366, 38.19363240272769, 40.957157919483805, 40.53309479067403, 41.12801244181972, 42.64762886108891, 44.73878168290661, 46.37534749123358, 47.498376984750074, 46.71825678117814, 49.24270991356143, 46.221841612169825, 46.52363269559799, 47.01949873278218, 50.851136638272195, 55.79443308614916, 59.092616881093676, 58.80136128394835, 55.68882719162972, 56.34973087618428, 56.23554283572782, 50.95068247087541, 34.49170727883616, 16.868150964859996, 6.4148113708342285, 3.1692223923821605, 14.231707299909285, 11.34585286340406, 4.9345887860944195, 0.9074084088206292, 0.12884177027210114, 0.03460199286740634, 1.3963216158651537, 24.521248225242864, 36.74256724696006, 37.861235064844934, 27.381205212685373, 37.52090277210359, 49.38173047957882, 58.56564644844302, 54.56480141608946, 27.31214600224649, 1.8464187412492692, 0.028084934606487234, 0.025732784209051923, 0.03230353757258385, 0.008649193952160497, 0.05179561441764236, 0.008806940074258996, 0.008004980082924088, 0.09686027308024707, 0.014410236429783606, 0.006100280095838131, 0.023500932598366372, 0.047725067519012, 0.0363347994824571, 0.026837573011195468, 0.023089508909071167, 0.032615967380303534, 0.030804943188183734, 0.028851047428625248, 0.06455267524166454, 0.054695582798411774, 0.11645242016041472, 0.19039376338403072, 0.10413569518395009, 0.20658388253181212, 0.10807869610406699, 0.1598871003596052, 0.17240863894262623, 0.1692620247241951, 0.20241014358978118, 0.13438470751768158, 0.17208962460919736, 0.19940550078547772, 0.15822476617270903, 0.16084230474887357, 0.14140928945233747, 0.12571024032489908, 0.22490280680358413, 0.0909291590834337, 0.25308198746173616, 0.23092644889989208, 26.625158556046028, 72.66222907650855, 67.73548895312895, 61.10742076750725, 42.14778161817982, 20.615671680819606, 46.925020602441606, 62.7506193037956, 47.60249237860403, 15.120080017274427, 0.22725118804843197, 0.28933948867263337, 0.3651741339314369, 1.2050325255240164, 10.802177056189507, 19.77219931540951, 15.330193542665052, 10.65765634659798, 26.441954451222575, 61.06464339840797, 64.32552545301377, 66.10899186903431, 60.69508944788287, 61.17348524831957, 56.937984420407204, 53.259232659493726, 47.57573396928849, 49.269727199308335, 51.43900579021823, 58.49987614539362, 60.94497188445061, 58.97273748151718, 55.17523204126666, 54.90984055303759, 54.68316285840927, 59.32594691553424, 59.54581145317324, 55.75782168296076, 54.28481871081937, 49.789127457526426, 47.49536852682791, 43.934723254173036, 45.79492692024478, 45.5506181716919, 49.08943153196766, 53.189704725819254, 55.604511922405614, 58.84638617115637, 59.11630799693447, 59.00278675940729, 54.005161562273585, 49.27920364564466, 49.110035742482836, 49.108843341950454, 47.75386448829405, 45.16237412729571, 47.34361594723117, 50.74982181672127, 60.22196923532794, 59.09355040519469, 61.25947929197743, 60.61217838718046, 61.37005875187536, 58.65349577319238, 60.854110179408906, 56.376630490826024, 65.60503005981445, 39.33990586188532, 26.439171529585316, 57.273252933256096, 46.729447303279755, 55.707411381506155, 52.17403050391905, 55.9200156119562, 55.71144750041347, 57.957020113545084, 56.22049662374682, 61.31696554922289, 53.23691437321325, 47.453359942282404, 43.660812377929695, 45.61342708526119, 49.15709241744011, 55.88757368826098, 50.75323035640102, 51.05560587298486, 51.78577861478252, 46.81909699593821, 44.633285614752005, 45.202056746329035, 45.37677480328468, 44.16202852802892, 42.737192261603575, 42.23520732695057, 40.74041558850197, 44.12402076105918, 43.339942885983376, 42.88918018341065, 45.38734951326924, 46.8182340745003, 48.20699630245086, 48.56839564538772, 47.41753693549864, 51.26181271768386, 49.6593911417069, 48.15961407076929, 50.28156926555019, 53.66227580655006, 58.29497937233218, 62.10060019646922, 60.7641702313577, 57.29521036148072, 58.32105921160791, 55.42083124960623, 52.86067278154435, 35.6974595592868, 20.243511315315, 9.025487515234179, 15.451992942440896, 44.549829344595636, 17.946932200462587, 5.991098313562333, 0.9167612392094828, 0.28464358420141284, 0.16191447544242107, 2.0793114314156194, 30.46271335694098, 46.475917062451764, 41.79473692371, 28.112464451020767, 44.06373785388085, 58.153699521095525, 67.11330690691548, 66.25643376381167, 33.13248834302349, 2.4689033002622667, 0.13747326759321077, 0.08785765212509902, 0.19061902387728616, 0.12260494122822439, 0.15621828996846754, 0.1338154888681827, 0.13769429928112414, 0.14217070424027983, 0.17075375113035404, 0.12178947893722404, 0.10088308504031551, 0.14902834029447648, 0.16070031801298743, 0.12845927023238715, 0.10575313661848346, 0.11660195286235503, 0.24693973963299107, 0.15412725297914398, 0.1439794531512645, 0.09059160542223724], [0.04709660729032852, 0.037992851237856576, 0.05538822204295186, 0.04558382112713111, 0.07926820537015315, 0.0032633360927819366, 0.0411748817010272, 0.03787148758889206, 0.05563921542958387, 0.02455485507755751, 0.07069144503123338, 0.025988967841370933, 0.01793506251077258, 0.017405563604927832, 0.03932214019099071, 0.06609985875266214, 0.08801378850494662, 0.04716935883005781, 0.022704327561622186, 0.17061067654961543, 25.57778177722808, 53.59752924211564, 50.514875765769716, 38.217225459314164, 27.586833507783954, 26.58622903208579, 33.05472343198715, 34.670547746842914, 30.182232510659006, 3.6603310848436053, 0.061930927012356064, 0.04175597471335242, 0.030952685159601034, 1.6016644359596315, 1.515259278878089, 6.3020809811930505, 8.499416285945523, 13.388217283833413, 46.0298768935665, 62.38302261598649, 62.12758218088458, 58.996679629049, 51.900586389726215, 48.790378262919766, 46.12709676065753, 44.09407738716372, 43.375048099025605, 43.449263265056, 43.15607001704555, 50.30145568232383, 56.62300632845972, 58.7068086285745, 54.564095389458444, 55.25428741208969, 57.474823536411414, 52.88312442841069, 54.715436120187086, 52.27505114770705, 55.70813309761786, 51.91639354152065, 52.890423959301366, 44.329121497369584, 42.112531277441214, 41.024638375928326, 47.89227708693474, 51.468309817775605, 54.12408782589821, 52.52624365591234, 54.713620062797304, 54.47872892502816, 50.4474227659164, 46.52779825272099, 46.52707261423911, 41.22521661943005, 43.08598902917678, 41.195947893204234, 43.1373603113236, 47.43327740700015, 56.22898463279971, 48.82614635652112, 49.84383667668989, 51.71063776939146, 54.52535021689631, 51.92407354231804, 58.27712866567797, 51.70356573597078, 56.96361318711312, 29.52042668096481, 21.940318845933486, 57.51398840258199, 48.08835637184882, 56.019902690764404, 52.010157800489864, 57.01324293690344, 53.02997012292185, 56.39711703023603, 52.44554088961694, 53.190438209041474, 40.67753999463974, 42.6674368304591, 40.06721135108702, 39.83538358442245, 43.057030170194565, 47.21464449359525, 47.33891694776474, 50.749260917786636, 47.55678107661586, 46.40919754582067, 40.26453010497555, 40.60441524751725, 37.21314576364333, 38.87685437356272, 40.659465712885705, 42.02157935788555, 39.37315579383604, 37.992858040717344, 40.11791583030455, 40.76178858357091, 41.54403863414642, 42.11309217637585, 42.08656126453031, 42.36850123251639, 44.33775071174868, 44.546620845794685, 44.302429768346975, 43.22890058640511, 48.07143134455527, 52.86988250670895, 56.54810474764917, 54.04096887957666, 56.88152582414689, 54.76732123282648, 50.93078820936142, 56.57473371874902, 56.34773831213675, 43.13827814594392, 27.298917808840354, 4.270065244167082, 1.8856467330648055, 3.851057560213151, 4.672229780304817, 7.3396567375429225, 0.9943622074300243, 0.0685235004751913, 0.06628534396088893, 0.03362384031436617, 12.319167448628335, 45.74053541306527, 24.598322799128873, 15.621697229723777, 26.828117678242346, 42.31859691681401, 49.630832364482266, 47.063315529977125, 30.855134725570682, 8.270490092615928, 0.06628307634063306, 0.03931726787179228, 0.04673277298288961, 0.05101643405073593, 0.055699395466475725, 0.018366258929393465, 0.06794390133431844, 0.03494331185075064, 0.05540841995107551, 0.015649177761177625, 0.04728462058870543, 0.051969742372391686, 0.07129418768829877, 0.04543381345067774, 0.04481980930112543, 0.025373176791735237, 0.03415749716241995, 0.05392528522098738, 0.018022915558709253, 0.013129543306516304, 0.04155924333439719, 0.04137344019968183, 0.04770866174611354, 0.027166155782798608, 0.07314679513294851, 0.02258057563355373, 0.03383202087734977, 0.016489353091005358, 0.026523314168556567, 0.07660826382737967, 0.0144065841056046, 0.02759537760979466, 0.02905478659686783, 0.06324635743493996, 0.049358949200400425, 0.05574573995545507, 0.056870108049723415, 0.0400421287744276, 0.05531434818441349, 0.26959482880849994, 34.98512183466266, 62.54021552301223, 58.18025396716211, 46.42069401279573, 34.91881024452948, 25.643153959704986, 35.58743707595333, 38.46355030613561, 32.9766917997791, 4.469762915565122, 0.010838751763766332, 0.12528547521440253, 0.41116193237323917, 3.095577195767434, 5.823031615826392, 7.10637818421087, 5.149399840062665, 14.789122189244917, 46.30609412347117, 64.56059701981084, 63.02506362238238, 62.65694133697018, 54.78301071351575, 50.79252858315745, 47.79598289920438, 45.74236715993574, 44.71092500994283, 45.44452198090092, 45.8295928278277, 53.59352450216971, 58.4139487820287, 60.17177074186264, 54.65623578717632, 55.66694428843837, 57.286749809019035, 55.09876543475736, 59.01529519788681, 55.31894768438032, 57.652565740769916, 54.498842839271795, 55.35681424602386, 46.4543910949461, 43.58698160417619, 42.99856332040603, 49.79033162516933, 53.049680033037745, 55.20835645737187, 55.007711533577215, 56.308361637976866, 56.211843875146684, 53.15776878787626, 49.0310666638036, 47.224799509971376, 44.10108666266165, 44.27814245224, 43.32974080116519, 44.62865721794867, 51.05118536180066, 58.9632139667388, 51.956746885853434, 51.592817614155436, 52.40217516499182, 56.74525091725012, 54.603350470142985, 59.27701927000477, 53.03790900015062, 58.265891075134284, 31.38100885575818, 24.333300013695997, 58.85866318979571, 48.25891671642181, 57.131168996134114, 53.01442576992897, 58.58656837094215, 56.49199916470436, 57.503347012304495, 53.40912995799896, 55.54229920910251, 43.425450555739864, 44.67082661967124, 42.397224749288256, 40.80355790353591, 45.032567208813084, 49.74134514408727, 50.55117337934433, 53.15106545725177, 50.45989198069419, 48.20338379952216, 42.00667435123075, 41.16848737962785, 39.58412047355406, 40.1734056011323, 41.76767256952102, 43.97774773259317, 41.808147507329146, 39.97419234245054, 41.27806271276167, 42.870278281550256, 42.95939845423545, 43.96552562713624, 43.60810748992428, 44.03913674816009, 45.20527701224051, 47.1785508432696, 46.51711763874177, 43.649774828264796, 49.59997900070683, 54.303712767939416, 57.775583036484264, 56.742548404201386, 57.17977108493928, 55.091677711855986, 52.76185258742302, 55.70221031865766, 55.64766583904144, 44.05697568770378, 25.156960487365726, 7.316729503293192, 5.570991875663881, 7.643017749632559, 9.487337777691504, 8.2718187955118, 1.6330806598547967, 0.1283929040355067, 0.05280163341892823, 0.10593016421602619, 13.78283812153724, 43.9655020929152, 25.366811213954804, 18.402240930065034, 34.149629531368134, 49.83303446923533, 55.54135391789099, 56.130976369304044, 39.64449751761652, 9.34155112312686, 0.03177895886643279, 0.04368007731353564, 0.06718088542261431, 0.060555504244421764, 0.03351407906701488, 0.10323799335427823, 0.0309368577830854, 0.04032684535148644, 0.030741405770963723, 0.07965074371426337, 0.013395300165059106, 0.044838566963951436, 0.035775639567404025, 0.029032121885627992, 0.015693878991559388, 0.040595366829825986, 0.044550694104644566, 0.057374845078635606, 0.05669673852201912, 0.05517223504401984, 0.11044854313255319, 0.16749174874876777, 0.16053433740331283, 0.08072826170152234, 0.20095385641099947, 0.11784637076479774, 0.10107161927848093, 0.17003237209733457, 0.10686070823501195, 0.10067068716330875, 0.17215063585148704, 0.11129738387441444, 0.14954309009255903, 0.1730612232800453, 0.19054716482998865, 0.19734270179704314, 0.14483172596702654, 0.17176363887565751, 0.14726480589278285, 0.6220740584596511, 44.523302355120265, 71.40035552363243, 64.67899768583237, 52.51000112102878, 38.22636458181566, 37.896481483213364, 47.26789066868444, 46.250902452776515, 39.87428957416166, 5.561050138165874, 0.21746312778803611, 0.2384567254733655, 0.39834368793714436, 4.740919797651229, 10.972791333352367, 17.53589918536525, 14.574450869714061, 15.622111039776957, 49.84615087509156, 66.17285590017995, 64.45426548680952, 66.03572983895579, 57.350700132308475, 54.191325095392045, 48.74644771698983, 47.7007830527521, 47.63644833718577, 46.80596882297147, 48.41375620134416, 55.011457397091775, 61.53075433546498, 63.38805936997937, 56.66567779356434, 57.05352567857312, 57.781341075897224, 55.10155423994988, 60.10859704786732, 56.62412420395882, 60.86301003732989, 57.17216168680499, 58.39838089481477, 48.229330278212025, 47.2810306087617, 45.445553564256244, 54.175404194862615, 56.93654883292414, 58.50735218294206, 57.10118639853693, 57.28744406853953, 58.38506837044993, 54.75302027117822, 52.64286748824581, 50.769280695146136, 46.95280275037212, 46.69582866853284, 45.34797283910936, 46.87626946356989, 51.95841781554684, 60.41633444447672, 56.714880005005874, 54.543200923550515, 53.27017214990432, 57.5623159254751, 57.36482458729898, 62.23508650256742, 53.94576118838403, 57.10958027070569, 32.181229245278146, 26.039505543247348, 57.332555247891335, 50.18970343374437, 58.717567689957164, 55.51822762335501, 61.01730039042812, 60.09727316517984, 59.6898526530112, 58.18078348713537, 57.09507926817864, 45.26968625284011, 46.98273827952724, 44.49304126924084, 43.648692254097234, 47.852759207448656, 51.15344155219294, 52.50334878121653, 55.81248383368216, 53.115379733424035, 51.649048712945756, 43.95345257174584, 43.89145951117239, 42.200157027090754, 43.82546955539335, 44.96277255396689, 45.91736370517362, 44.78023721325783, 41.81330542410574, 44.26803450430594, 44.09875677477929, 45.313091201166955, 47.51588252282912, 46.36446683637558, 46.85006803081882, 48.914372228807025, 50.07333847784227, 48.73504930926908, 47.94410336402155, 52.8668426698254, 58.652319062140684, 60.991957956744784, 59.7584705968057, 58.99747979256415, 56.80340789979505, 54.03259069688859, 56.59081935882569, 58.67220547891433, 46.27191458978961, 31.866041306526434, 7.413619400993471, 5.673678546182572, 15.288254580190106, 11.417097814621465, 13.843343623222845, 2.449642501531109, 0.15661768224691192, 0.15320270742860534, 0.3093804407023615, 17.488148250887473, 60.46637212076495, 33.80098965860183, 25.439904582115915, 38.373363248763546, 58.93034450469479, 62.060607710192286, 64.46246324046966, 51.650672574197095, 12.079320396146468, 0.3631359416871302, 0.1031940658727, 0.17656222977224859, 0.2446127782065061, 0.12350053631610448, 0.2732932561587903, 0.19015854374775965, 0.13901468246213852, 0.08127180108379933, 0.14316822732648543, 0.1469849233305262, 0.10930232238024475, 0.18358275144090577, 0.11777562254499044, 0.1356251877281935, 0.12852103224084263, 0.25470960254390396, 0.15470549614439089, 0.12234758931182085, 0.10463779687040276], [0.0597908144306031, 0.02816276722437432, 0.05433790017700484, 0.0197133747485256, 0.04051031191803275, 0.03380119349927672, 0.06136225228528343, 0.06368793051449523, 0.035698517496066715, 0.03737355342074748, 0.06479509610442385, 0.08192181902667207, 0.014145427605047101, 0.07902623649926917, 0.05885182429225214, 0.027239093098849542, 0.023798557756949338, 0.0232136323897829, 0.03467989634842642, 2.313808616130583, 39.76806786752517, 52.225629283535866, 57.385679829505186, 35.70524938644902, 20.591374558787194, 19.459843327922208, 24.758382958750573, 38.91566622641779, 25.597844700659476, 0.6271399833982991, 0.1469844943212886, 0.03763157183364515, 0.6252334663464177, 2.0966718417982904, 5.172192242837721, 5.017796476041117, 9.894921068222294, 23.069284846705777, 51.13226075326243, 60.655952038303504, 58.35500340307913, 52.24244840683476, 47.77835969002017, 51.03516640201692, 50.1042506771703, 51.77799270999048, 52.333631746230594, 45.94612644564721, 42.847442242407034, 47.39501076359903, 53.06408297631049, 55.73439728829169, 56.10739507982808, 53.84429339439639, 51.56984429205618, 51.50430933121712, 55.19006644525836, 56.83826208114625, 58.67844204748831, 55.182284462836485, 53.413821112725046, 50.83692981350807, 43.2460178098371, 42.86088028261739, 50.011608216070364, 53.72926204435287, 53.98517316387546, 52.6110335319273, 55.31002036986813, 53.633697417474565, 48.764102305135424, 47.78347053835469, 44.00648693884573, 40.81974944760723, 41.94019802155034, 41.43716189169115, 40.50064894460863, 47.41768598556519, 55.09381932597007, 51.27124994031845, 54.301108314145, 51.51371909726051, 52.88576026116648, 50.48411653887842, 54.131775671435946, 45.50436950499012, 57.208953519021314, 29.510277548143943, 25.484672554077644, 59.13495494473366, 50.18333350458453, 56.735186115387954, 50.98635642759262, 54.196263359438994, 50.066211531239176, 50.03012572565387, 45.70864654356434, 43.316891116480676, 38.700010391973684, 45.27134933779317, 38.56253916217435, 41.88970535032211, 41.32883387227213, 46.76731778729347, 49.319145141109345, 53.19017541023993, 50.847637884078495, 49.417843741755334, 43.25977748440158, 38.75229558637066, 39.7818628434212, 46.47362247590096, 48.6176331581608, 52.035582603946814, 47.05055605980658, 44.06100788424092, 41.83908716324837, 41.25354005444435, 42.194077353323664, 47.55716546889275, 48.88455829312725, 52.464634987615774, 53.30708165322581, 55.11119542583343, 51.773705559392134, 52.3525454152015, 51.32361358211887, 55.60855980842344, 55.252883203568004, 54.94077236421647, 51.895059770153416, 53.19029700371527, 50.650836883052705, 52.12503225572648, 54.89557489272087, 49.1393554595209, 33.68990029058149, 17.306528783613636, 2.915796339511872, 8.541486647821243, 10.58320583835725, 6.429593313124872, 1.1069917799003663, 0.0659257116457147, 0.12264692284647497, 0.03426320580465179, 2.7348049417618783, 36.694914371736594, 58.02011928250713, 19.119999370267315, 20.5294579844321, 41.766272283369496, 47.978808495306204, 54.14168750086139, 39.765757591493674, 13.788107825863747, 0.33323387525254683, 0.03883885362395837, 0.04227048702417843, 0.008747033913800073, 0.05907356844193513, 0.06645011415164317, 0.055902090839921474, 0.024561788173272245, 0.04303425370204834, 0.034395589628407074, 0.036987008436793284, 0.054845958197068785, 0.0417105303776841, 0.032111169064357396, 0.058934626905548, 0.01272446665567376, 0.058474491515587416, 0.007392129374502768, 0.03899749894175799, 0.01641689649512691, 0.018959300998117656, 0.0689610515931441, 0.08811476655424604, 0.03640862737572001, 0.08439184737301643, 0.018894654668627248, 0.0536301804916753, 0.11944384794802436, 0.014065248842891908, 0.037085125147695505, 0.04047092733784549, 0.03567044037364183, 0.061661003593115084, 0.10044866722197303, 0.04685951073864295, 0.06703965711377322, 0.0505592251166461, 0.058854907796147375, 0.09058282605462498, 3.701762100381236, 49.12689016711328, 59.4197190192438, 64.26824315901726, 42.74686090407833, 31.46106246979006, 24.678388180271273, 25.068930733588434, 40.13174218516196, 29.693756218879457, 0.7934297248721124, 0.10579751609193702, 0.04334783264165444, 1.2806256692255698, 6.581033573996637, 6.90188737646226, 5.489261938679603, 6.413130144919119, 23.82566490480977, 54.19247042748236, 63.20595156761908, 61.84263375497634, 55.426938379964525, 52.34926239136727, 52.477629799996656, 51.56756147261589, 53.65183837952153, 53.11537188868369, 46.9302922679532, 44.241636953046246, 48.590757077740086, 55.89288457747429, 57.386232883699485, 56.442687126898, 53.354130483442745, 53.66641390708185, 51.01439745195451, 58.61973201074908, 58.34585643583729, 60.11701053188693, 57.02923444009597, 57.5691447719451, 53.69441178537185, 46.23616218566895, 45.701456839038485, 51.30112663392098, 54.4032193768409, 54.77771943615329, 54.07885897544123, 57.54512417700983, 56.79319012549616, 52.07921112737348, 48.58620320597003, 45.85241317749024, 41.66289821747811, 43.40415208570419, 42.911443556508715, 42.96333651388846, 50.14500410326066, 58.06484999195222, 53.88225017055389, 55.91118243432815, 50.52401881064139, 53.22784585337485, 52.65645850089289, 53.98984078438052, 46.00837838265204, 57.40496612364247, 31.10576829602642, 27.182260636360418, 60.0747940617223, 51.915256054170676, 58.801984940805745, 52.65451300528742, 57.30016431500835, 52.85158072748492, 53.437798561588416, 49.37428974336194, 44.36001016247658, 41.41809525028352, 45.760041359932195, 42.476935155930065, 42.94734108832575, 43.2773575475139, 49.74997435846637, 51.32857930275702, 56.56878348319762, 52.51736733221239, 51.86726977748256, 45.038768476055516, 41.20886818055184, 39.6449250559653, 48.426915753272276, 52.444756415582475, 54.64179754257203, 49.767970192816954, 45.06051409629084, 42.32911671361616, 43.254494051779474, 44.556842542463734, 49.85165788281349, 50.078304198480424, 54.28903525875461, 55.103837059390166, 58.362059747019124, 55.66615196966357, 55.683073074586936, 52.412145829969845, 59.0496983066682, 56.88625228020453, 55.89816408772623, 51.80004427509924, 53.66583339629635, 50.8888659169597, 52.48474105711907, 53.67134040401828, 49.73429664488762, 33.96157149345645, 17.792637924994192, 7.429309371979007, 10.933961829831524, 11.574509393784309, 9.169431636410376, 5.904931195320622, 0.6576184543871111, 0.1075106189255753, 0.028883359102051587, 3.529327108014015, 40.22976613813832, 44.12500135360226, 19.387087283595918, 26.34381086595597, 46.082550402610536, 54.56598204951133, 61.63859205861246, 48.496282869769686, 16.700985431671143, 0.6682317139160249, 0.007177708546570953, 0.0281329108627453, 0.02428944774663016, 0.055192455934781226, 0.06923411597287463, 0.029442135973142523, 0.04257120334753587, 0.05262808769100136, 0.03678521321665856, 0.06867876351480523, 0.031818019774472045, 0.017501276714967626, 0.07084868457769194, 0.01464724488135788, 0.048738981056357586, 0.04996210171450531, 0.041797918027206775, 0.028002576324187463, 0.028741778392765312, 0.13193282779426346, 0.15233400968774674, 0.20378358602043123, 0.13078102992186624, 0.2099504252715457, 0.1535087442325969, 0.10730749837333158, 0.25132222221262995, 0.1050252611598661, 0.07648713000479244, 0.11670225675428107, 0.14121159280259765, 0.18469028475303806, 0.18085264390514744, 0.16904062531407804, 0.09894512007914244, 0.2024500414488777, 0.19270014768886953, 0.19589062810184496, 5.822672718955625, 59.30360509503273, 68.51319297667473, 72.94893864662417, 49.002962881518954, 31.987923076075894, 31.89670051297834, 37.12451588722968, 52.87957860577492, 34.51255859867219, 1.3373978099515362, 0.2639715595831794, 0.15408225297447176, 1.716645408061243, 6.2666580561668646, 14.99171260864504, 13.106035109489197, 14.833921540168026, 25.516202526707804, 53.22246828386861, 65.11447883421376, 63.3114044897018, 56.78663192256805, 53.114540346207164, 55.6425275341157, 54.93431614291284, 56.99671014662712, 55.98726857093073, 50.39618484435543, 46.806910191812825, 51.13512408348822, 57.76397282077421, 59.8749061553709, 57.413528657728634, 53.98979763830862, 53.43393502696868, 51.029310303349654, 58.32711927352413, 59.95107466174711, 63.076583954595755, 59.95195719503588, 60.6017448825221, 55.09445474993799, 48.63408750103366, 48.23954805251091, 54.765175696342226, 57.2268081480457, 56.08280966358801, 55.513599226551676, 59.25917248572073, 59.771386961783136, 53.663005367402114, 52.94445460842502, 47.763105592420025, 44.56075314552554, 45.9927987283276, 45.90562405124788, 45.3181432139489, 52.84925083960257, 60.12023864253875, 56.681508479579804, 58.05296913270028, 53.77164717643492, 54.602067855096635, 54.12171479194395, 56.088504945078206, 47.17447157829039, 56.54389996682444, 33.68021988099621, 29.055843507089925, 59.55194604012274, 54.906212360628196, 60.957798034914084, 55.42863676624914, 57.87205373087237, 56.508983027550485, 55.138373528757405, 51.00995340654927, 46.092301414858916, 43.20230691663681, 48.00510798731158, 44.92514525690387, 45.75408327964045, 45.15873024540563, 51.779161576301824, 53.39634695360738, 59.2618553869186, 55.21423609026017, 54.40308209388487, 47.57253331522788, 44.68952848065285, 42.990636210287775, 51.70157709429341, 53.83878246430428, 58.622006985449026, 53.34578367971605, 47.194295237141276, 46.57800459092664, 44.00150160635672, 47.44269109541371, 53.46126610232938, 54.00878975468298, 55.8712487836038, 59.110910815577355, 61.96661595375308, 57.87578390490625, 58.40220912810295, 55.03444248630155, 61.514068572751945, 60.20147092880742, 56.630447064676595, 52.26795165769516, 53.961180025531405, 52.34783464862455, 55.00297331040906, 54.66635942459107, 51.8326509383417, 35.3523458973054, 21.736634085255286, 8.073124760581601, 10.916609264189198, 23.290584971827847, 15.934502328595809, 7.065337444505385, 0.6330125069906635, 0.1836240435800245, 0.16148433239469606, 3.988249811433977, 47.784341304532944, 68.6870716464135, 29.025817763420847, 30.29268841589651, 53.8138440347487, 61.78825401490735, 68.77032003095074, 59.2102958310035, 22.488370057075254, 1.1951707063182708, 0.16835174373080655, 0.11290391621690606, 0.1598190870736876, 0.1374142481795242, 0.26530176401138306, 0.12910453843012934, 0.12297729826382092, 0.12834805724841933, 0.10829700051896995, 0.17157455305418662, 0.13579907436524669, 0.13425818043610743, 0.12968178568107466, 0.18960087770415893, 0.12546850128039239, 0.19222940198115765, 0.1376430326772313, 0.22645119307262285, 0.10738645905568715], [0.05700633380441897, 0.043657018067014795, 0.06530989952866109, 0.0217969921763025, 0.05778716892124184, 0.029430746160928282, 0.03374445319716488, 0.03313226084555349, 0.061720088124275214, 0.022031710024983175, 0.01822648044194906, 0.015305323026803954, 0.027052052732136463, 0.04197011927082654, 0.05460612671149354, 0.040411099701398806, 0.06361327907671371, 0.02928321294847035, 0.03217856564949597, 7.525048054033711, 45.39866947358655, 56.54698687215006, 48.0051197544221, 25.003331053641535, 21.054590786657027, 27.512402611394084, 43.27701630130891, 40.36171074836485, 15.10765394856853, 0.19402837561022854, 0.017545370820669398, 0.036171036697323286, 1.5397704152330276, 4.0004746135204075, 3.8865076966824073, 3.293438462480422, 5.018068590471822, 29.173728381433797, 60.709912084764056, 61.24615892287224, 56.71773941286149, 54.46175290692238, 56.202606693390884, 55.984922993567686, 58.408767331031065, 57.585857991249334, 55.51908270005257, 54.46076054726878, 48.402883391226496, 48.81372028781522, 51.88198651036909, 55.501102555182676, 58.19585715570758, 52.08479658249886, 48.4935175987982, 50.2778979270689, 51.20874304925242, 51.263856272543634, 51.32567674882951, 51.76144423023347, 53.335055997294766, 51.03575475754277, 44.935527770749985, 41.91393383087651, 48.70073249263149, 52.8820889226852, 55.54857500137822, 53.30587748558291, 54.46034477603052, 48.56313182461647, 43.321492056692804, 40.68049353937949, 41.04548969576436, 38.493454456329346, 41.55950846210603, 39.3292958505692, 41.90706183833461, 42.44619161851945, 52.35287489429597, 53.24478264777891, 55.813950800126605, 53.79543635153002, 58.10931790259577, 53.46355284413984, 56.33013863717356, 49.77769374847413, 59.44812482403171, 27.670370186528853, 27.634376556642597, 61.90443854178152, 52.56402392541209, 56.047716217656294, 49.53717793187788, 48.07646374548636, 42.450196358465384, 43.84142575725433, 37.98972406694966, 40.992977003897394, 38.830676309524044, 43.313470809690415, 41.843574354725504, 39.09539315008348, 40.43833817205122, 43.649441426800145, 50.94351237820041, 54.62159341381442, 51.18493426230646, 48.707027896758056, 40.82816685399702, 40.43090135820451, 43.132386745945105, 52.92497219577913, 53.94815383418914, 54.790529897136075, 52.29800878032562, 47.68256756567186, 44.87130288154849, 47.27706509251749, 52.18403254785846, 54.04158469169371, 54.45755989320817, 55.8006618099828, 55.59217214584351, 54.67693021220546, 54.79804515838624, 55.25520132433984, 55.584986363687825, 55.488429377155924, 55.09519607790055, 50.96521877473401, 55.01359116646552, 54.784022685020204, 56.832739383943625, 57.15810783447758, 56.0089082871714, 53.73857375114195, 40.55946488534251, 24.263868178090743, 19.000827958506925, 10.817188947431504, 8.59530843073322, 3.8476173964238938, 3.044155413104642, 0.9209941507827852, 0.037929319566296, 0.08276853004410382, 0.9089305948826575, 17.830651575519195, 47.54326066663189, 54.77325970126737, 35.130908489227295, 30.455539341895815, 44.085946313796505, 45.59661580670265, 42.68573076494279, 32.909682027755245, 2.7001910055837324, 0.0608593883413461, 0.03943057993667261, 0.05591929334426119, 0.06127865677098594, 0.032353402235575264, 0.06338500019703662, 0.030619488623473915, 0.011397629183897329, 0.02335247050430025, 0.05464903529613249, 0.020174498391908505, 0.07438872324963731, 0.08149403552975386, 0.06302051854530169, 0.0349369686427376, 0.03473788920429445, 0.008816896344444925, 0.04873687431456582, 0.05846796444647255, 0.03793803381643469, 0.06913181259146622, 0.0504993055496485, 0.04924795455149105, 0.026331700256935535, 0.04616746138180456, 0.038469170235217585, 0.07131908554583788, 0.04086553156676312, 0.05819074787019242, 0.07188143238665597, 0.020180510266894297, 0.05971327484134705, 0.04451654956585938, 0.04388568765153328, 0.03869322413999227, 0.0394706693177502, 0.014800449059675298, 0.02543570871855463, 10.740893944617241, 54.10074580100275, 61.71044988016929, 54.69001916147048, 34.3669915968372, 27.008725174011726, 27.06231063412082, 43.234646858707556, 44.46190157244283, 18.19989173643051, 0.05439508481011276, 0.1339651058397947, 0.11151427868753673, 3.1163265339789854, 6.651027289129074, 8.294770544575107, 3.735547681008616, 6.1544135501307835, 29.991060110830492, 61.384461695148104, 63.87763392540717, 59.103756412383056, 55.92351436614991, 57.10390067869618, 56.69340895068262, 60.31382722239341, 58.53305547468124, 56.60875635762369, 55.9243655204773, 50.310084896702925, 49.425260943751184, 55.64807376553936, 58.17066377209079, 58.41186208109702, 52.49715928108462, 51.56964817354756, 51.10237229254938, 50.917110904570556, 52.17816468208067, 53.32567368784259, 54.44798538761755, 56.77366848914855, 53.40843962084863, 48.23379001309795, 44.51072723634782, 50.11240136238837, 54.324622923328036, 56.07913832510672, 53.81071790572136, 56.549967873481016, 50.267888038389145, 45.876457306646536, 43.88159475018902, 42.90065311616467, 40.81530932457217, 43.59884677394744, 41.22934295285133, 42.40366920348137, 44.198581095664736, 55.35510017025856, 54.57150082434378, 57.067269663656916, 55.88504375949983, 57.71169547111758, 54.93581448831866, 58.813732439471835, 51.98742374297112, 58.82934347275765, 28.44255739642728, 28.624765219226962, 61.61798000335694, 54.61462728438839, 57.48010696903352, 51.57146815330752, 50.384429500949004, 44.99485754197644, 43.876393687340524, 41.242784915431855, 42.79328999980804, 42.62911527387558, 44.72718323430708, 43.71605111706642, 41.45542444721345, 42.25216373320549, 46.30794155982233, 52.685935112737845, 58.44288410678987, 54.20571627155427, 51.064913657403764, 44.37676652785271, 41.68403979270689, 46.056486252815496, 55.45655619713568, 56.19036105371291, 56.50743369133242, 55.95303804643693, 51.62554587087324, 47.76698481652045, 49.366849007145056, 54.399351919851, 56.09003466944541, 55.74323831066009, 57.24879303286153, 58.00197832046017, 57.629749313477554, 57.83814876310287, 57.3832126586668, 57.97966787892004, 59.28174964843258, 56.31823032133041, 51.85457698760494, 53.42281118515999, 55.420894007528986, 58.44569644620342, 56.365498804276996, 57.65955148204681, 55.527684457840465, 41.358381086780184, 24.458152978650986, 11.930316417447983, 7.3133263568724365, 11.880125768723028, 6.970786750316621, 3.93592024522443, 2.1463895997693463, 0.09390621506158384, 0.08972542811064951, 1.1022735363052738, 21.4996660524799, 56.330699536108206, 42.150217410056825, 34.660871259627804, 37.242081088404504, 49.11767259720833, 51.29348585682531, 50.166977220965975, 39.7987094233113, 3.627791347042207, 0.08380209756714684, 0.008632426202717808, 0.03330471106774865, 0.03087775218450735, 0.05290530426728149, 0.035678993745316426, 0.04698824032299942, 0.038036104562061454, 0.05932263511743757, 0.03288929606036794, 0.047391455380185965, 0.0354704684427669, 0.0701621012581933, 0.04943723189494303, 0.050370242717044975, 0.06532561199198808, 0.0862259384725363, 0.07133815347427322, 0.0747351558698762, 0.19400206815090873, 0.1998993363832274, 0.19432020914410392, 0.16973238738794483, 0.21503128892471715, 0.12224200707409652, 0.05506245081403083, 0.27682749554514885, 0.15485981689585795, 0.10566682149205478, 0.16020730979019598, 0.12170396054223662, 0.17877328209578994, 0.17950993692201955, 0.16563252996533148, 0.1900619400605079, 0.13819193467497826, 0.1103770288248216, 0.12207689214377634, 14.908985899340722, 65.13506735524824, 69.59017384436824, 62.11998847223098, 39.0379657283906, 29.725333259951686, 39.46726129901025, 60.5940648817247, 52.82797590378792, 21.471221023990264, 0.297222993066234, 0.252197370413811, 0.24877052123267807, 3.922816096774994, 10.878774081507038, 12.303180848398517, 12.645746930952996, 7.750025891488599, 30.633844406374042, 65.44160450658491, 65.2627169701361, 61.911279155362045, 59.17492781915973, 59.004995053814305, 60.44794090332524, 62.080792227099025, 61.14077268108245, 60.81197215664772, 58.37130477351528, 53.55034312894268, 52.11772880246563, 55.36587099875174, 59.37454115959906, 60.23216739777596, 51.428744869847456, 50.801075427762925, 51.95094570036858, 50.97815082919214, 51.96532903179046, 53.72726555793516, 56.27905761041949, 59.010717791895715, 55.8999958345967, 49.05114527671568, 46.61822457467356, 53.020536822657434, 58.314614757414795, 58.2933045202686, 55.449923469174294, 58.902448608029275, 52.46774150479225, 47.28945978226201, 47.52187982682259, 45.501529708985366, 42.1256947517395, 46.18343376344251, 44.01930524456886, 44.25406694412232, 46.79475476664882, 58.04237088849468, 58.29711706407609, 60.72206358755789, 58.130306505387836, 60.63488891047817, 57.85128478080996, 60.82550433374221, 54.87775556502804, 58.735559601937574, 30.839090270380822, 32.3763906955719, 62.58810374044604, 59.66838552105812, 60.648672119263686, 55.05947505274127, 51.674559808546505, 48.180924307915475, 47.84912317029892, 42.75149714562201, 44.90365851309992, 43.817864079629224, 46.931763156767815, 47.07152897311796, 42.99950076687721, 44.71271753311158, 46.860909461975105, 55.831993702919256, 59.74712317989719, 56.21566426369452, 54.362991548353634, 45.790459340618504, 44.16245998874788, 48.868464808310236, 58.521100090396025, 59.109251652994466, 58.96748935022662, 60.068063274506606, 54.05537966758975, 50.64300390981859, 52.298279423867505, 56.023523038433446, 57.60921962799565, 60.196501285799094, 61.29493751833516, 60.26280895356209, 58.86134609099358, 60.76510767782889, 60.79857726250926, 61.61871740894934, 62.011993854276604, 58.023123818059126, 51.67455196380616, 56.479526027556396, 57.368778336432676, 59.760694580693404, 57.69832018882998, 61.08357667922974, 54.43377856285342, 45.941392144849225, 28.24378344320482, 25.544212172108313, 18.795005506084813, 20.49253671400009, 16.47251521387408, 7.491356855438602, 3.013437371100149, 0.14051506566184183, 0.1599521871896521, 1.4087269695535785, 27.13990688323975, 62.03096635880009, 63.33847276626095, 46.0658371833063, 41.293454093317834, 59.15897946203909, 57.39006111698767, 59.578751517880356, 47.81666947949318, 6.038486428799168, 0.27966379818897097, 0.14351411602429806, 0.16525526230614032, 0.1533410629077304, 0.1440425941179837, 0.1508808481476961, 0.1622341792549818, 0.1505097704789331, 0.23557833395898345, 0.11064969483883151, 0.13819141373518976, 0.3214922601417188, 0.21185708021925342, 0.17377247463070578, 0.3008058330705089, 0.16124362756888713, 0.1549621815643003, 0.14637759946767362, 0.2202776122477747], [0.016262725130805088, 0.02845669600872263, 0.062331184970154885, 0.16715583451572927, 0.08599369125741144, 0.040678123477846384, 0.08113828728035574, 0.0256833121661217, 0.04280741889810851, 0.039148510193392154, 0.03752210169970509, 0.054206125393149354, 0.0447889129751392, 0.031641467151442365, 0.03076442862830816, 0.01727048123645927, 0.008110319087732463, 0.09870069972690075, 0.1972047600053972, 17.14355234176882, 48.84193389646469, 50.20553411975984, 39.64158319657849, 21.53639708795855, 24.376014624872518, 41.286464429670765, 44.67891846933673, 39.96947765350342, 7.1973605021353695, 0.07256789313208672, 0.08039388730521164, 0.18567372714319538, 2.0691426867438905, 7.68238804994091, 5.479948270705439, 2.6958035893978614, 8.527155287804144, 33.78950103636711, 59.88486897560858, 57.64739213451263, 58.675763068660615, 57.22061864791378, 58.69700662551388, 57.50653197688442, 47.178947002657004, 52.5129036749563, 56.225301527207904, 53.14292653914421, 53.76018208842124, 50.32897110908262, 54.58144795510077, 56.50975181210426, 56.08590049128379, 48.70149735481509, 49.69272344343124, 48.553674990131015, 50.23090401003438, 48.82395375159479, 49.346495828320904, 48.01483154296876, 54.49999209373228, 54.36092445927282, 49.20000706949542, 44.54287105990995, 46.01603092685823, 51.62221185622677, 56.673067538968986, 53.562278901377034, 56.169015515235166, 47.090697596150065, 40.2482993372025, 41.159811096806685, 40.50937621824203, 39.62288133559689, 41.045446549692464, 39.17011430186611, 40.67118575496059, 40.806691877303585, 42.76579810727028, 43.244617523685584, 49.12131255672824, 46.9499158859253, 51.662867223062825, 47.37976843310941, 54.59633334990471, 49.035479330247455, 59.862903702643614, 30.714184353428504, 29.290365942062873, 60.25659591920915, 51.23425022248299, 55.81394687775643, 47.20557205138668, 52.654379644701564, 48.152757767708074, 51.244868078539454, 46.15606738675026, 44.35233408404935, 39.46388806066206, 41.33356817307011, 38.86803688541536, 41.66537715542702, 40.9861324679467, 44.59022583500032, 50.6394188634811, 51.53244057009297, 52.1657072344134, 50.01320069836032, 43.576987404977125, 41.81276413702196, 49.034588952218336, 54.30727035768571, 52.95209930789087, 53.52386320790937, 53.76430842184252, 53.21821643460182, 51.23109271449428, 53.348039042565134, 52.17417170924526, 56.01381909462714, 53.26567711368684, 55.172890386273785, 53.43534708023072, 53.84306177016228, 51.832623481750495, 53.417261031366166, 52.35417319882301, 54.20137420777352, 50.365315791099306, 57.85734876509636, 52.023211448423325, 53.69947164289413, 55.56863008006927, 59.32445249249859, 55.252702774540076, 55.16544965005691, 52.36716408883372, 39.038801193237305, 22.017709170618367, 15.849886017460978, 9.526940968728836, 5.832627204156691, 5.932420146080756, 1.3262425891814695, 0.1500165017862474, 0.05660311874723243, 0.16091135991436822, 10.072182782234686, 36.46652652371314, 63.77918635645221, 43.874408968033336, 24.8636358399545, 44.80039427357335, 47.86113346776655, 50.41576531625564, 46.289553488454516, 9.873630442926961, 0.2835610406773706, 0.03830875142387325, 0.06060050807953362, 0.011206907764708084, 0.06512406191998912, 0.05559364468940804, 0.01970673276622209, 0.08780695242627014, 0.07343840650132588, 0.029276927197051626, 0.057996460311715646, 0.07071152419572876, 0.028974998539554018, 0.023311762507223797, 0.08050231172913506, 0.04103781708005456, 0.00995108281307283, 0.02878951141610742, 0.02392035233037126, 0.015133833287343865, 0.045653833902531096, 0.06373566162261753, 0.06015940997449141, 0.08750504483619044, 0.012400620222662487, 0.03225160064175725, 0.04049140869850113, 0.030518997040006424, 0.03214673852668174, 0.07147984909674815, 0.040511288680136204, 0.17451686694497065, 0.02892745129253355, 0.061649033469298196, 0.03236516934609221, 0.02978902058525672, 0.059344120053274024, 0.32150721417800077, 22.63444304466248, 58.12590952842467, 57.62967871081445, 46.74775300487396, 27.095411516004994, 22.57521721624559, 33.449639428046446, 50.267150632796756, 44.34786650442308, 9.465685313747777, 0.1532656798559812, 0.19902006662901373, 0.6236016377806664, 5.051566612335944, 10.095284561957083, 9.33569404386705, 6.794766466463766, 9.785330045607783, 35.90377623035062, 60.27849843425136, 61.90797259730678, 58.286307011881185, 60.71854914388349, 59.48967449126705, 61.6137909120129, 49.074063685632524, 55.15802852569088, 57.819278240203865, 55.80909882822345, 54.96533816860568, 52.01665716786539, 56.46750004060807, 58.491635245661584, 57.67618233157743, 50.81443894294001, 50.2618162093624, 49.17677487096479, 50.062379375580825, 49.64803195768788, 50.23912137554538, 49.74859760653589, 57.44151476890811, 55.42503603043095, 51.560281553576075, 45.76905888895835, 48.629568930595156, 52.72751615893457, 58.00366493963427, 55.700955160202525, 57.545920418154815, 50.92585779005482, 43.46678449261574, 42.01792763125512, 42.64774653219408, 42.288190703238214, 41.40362562671785, 41.86667319267027, 43.22020861410326, 43.59778381163075, 45.74395571985553, 46.74132424016153, 52.2197025822055, 49.267726790520456, 54.17144260098858, 50.20239230125181, 55.817053394932906, 51.834266954852694, 61.43886496943813, 31.874635219573978, 30.427688552487282, 62.30745030987648, 52.118195564516135, 57.80748367309571, 49.70782064622449, 54.28573262306952, 50.659336659216116, 52.44593704900434, 48.28658511561733, 45.896963457907404, 40.27256311908845, 43.15596411305089, 40.90690843520626, 43.88669383141303, 42.81024640606296, 47.60553613785775, 52.18873939206524, 55.27879045855615, 54.902595935329316, 52.50658865897886, 44.858315913907944, 44.136666482494725, 51.598152037589784, 55.52004760311496, 54.006981542033536, 55.45798393987841, 55.121828971370576, 54.59392501461891, 53.65354461054648, 56.64275153990715, 56.191463239731334, 57.36071002098822, 54.83188736823298, 55.997776600622366, 53.172944438072946, 54.80082611883841, 52.87962567421698, 55.472583001659764, 54.189524727482954, 53.50908371710009, 50.6025525062315, 56.78498844946585, 52.40352838270126, 56.058283082900516, 58.10268125226421, 60.386053746746434, 56.425475766581876, 55.42772677636916, 52.54338833593553, 36.277432980075965, 17.411175658625943, 8.630654869541045, 10.019226862538247, 9.788887635354074, 7.027693967665396, 3.167424966250697, 0.14255454493386133, 0.03452027426852334, 0.16861279585188435, 11.554015009633957, 41.19802674939556, 69.29880449848791, 48.49406673062233, 30.957361498186668, 51.0220774527519, 53.83910409865841, 56.47686666057956, 54.189112878614864, 12.537610127079873, 0.2284285119704662, 0.039242137629058094, 0.026634594185217738, 0.02840700946117361, 0.050223238105254794, 0.0017285568619920544, 0.046838975751832615, 0.014686727137755484, 0.12329854191310945, 0.02419808410078047, 0.015367336886664553, 0.08849526710447767, 0.04746625620511271, 0.02084671564760708, 0.021736151388575955, 0.06247707492401523, 0.01886445548265211, 0.12746407605347135, 0.04447057279908369, 0.0931754974167674, 0.16997862336856706, 0.18755839536747626, 0.27355130521520493, 0.21652068642358627, 0.11099304778561478, 0.13395283311124773, 0.10560540422316521, 0.1434068483931403, 0.18065552948223007, 0.16655721341169652, 0.14708846777437196, 0.3281255703299277, 0.18039556520600475, 0.1292727100512674, 0.05999213084578515, 0.10651976080431093, 0.24430364640730046, 0.4153971728538314, 28.276278318897372, 67.65835946606052, 64.91651681161696, 54.34807869695849, 32.00336936981448, 34.259612790999874, 54.9891822568832, 56.46163609720046, 52.16507573281565, 10.826802676723851, 0.30903913321033605, 0.2282573219629065, 0.7132330669030067, 3.1841516687024027, 15.834216148622575, 14.106618992743956, 7.125976306776847, 11.149537255687099, 36.023204557357296, 63.11650976057976, 62.585220798369384, 64.18192748100527, 63.07176336165398, 62.82899218220865, 61.40400294334658, 51.404622293287716, 54.78080241910873, 60.123423607118674, 58.255088867679724, 57.03181928203952, 53.826556436477176, 59.84497062621578, 59.713516312260786, 57.44404469766925, 51.28549206641413, 50.48846252502934, 48.27283720816336, 51.88018614246, 49.75303380720077, 50.01266725601689, 49.25706971076227, 58.762031678230535, 59.15417063620783, 53.80151994766728, 49.82705677709272, 51.20015305857505, 55.790345976429606, 60.82657121842908, 57.11536184433968, 60.3787620605961, 52.62477359464092, 44.91205630763885, 44.858919958914484, 44.65006943671934, 42.94772940297281, 43.8308745814908, 44.236075032141905, 44.674701921401486, 45.20573985192084, 45.78895315047234, 48.38030622851465, 53.363316674386304, 51.43928820087064, 55.61218407846267, 51.97814733751359, 58.759301708590606, 53.84527398693947, 60.55296628705917, 33.86535183075936, 32.478191891024196, 63.258303442308986, 55.69756231000347, 61.614567541307025, 50.894117970620435, 57.815355870031546, 54.43222922663535, 56.16982352349066, 50.84275845558413, 47.87361444965486, 43.38334391194005, 45.61922434837588, 42.26491143626552, 46.50328736151419, 45.563110920690725, 48.185313440138295, 55.81797122955323, 55.224642138327326, 58.4038604459455, 55.372225238430886, 48.364699117599, 47.14607754061299, 54.228779808167495, 58.95331390442387, 57.13205545179306, 57.58683073905207, 57.29180966654132, 58.28163939137613, 55.27330306268508, 58.50297089545958, 58.29068045462332, 60.67512458370578, 55.61904430389405, 57.080056590418664, 53.421610939887266, 57.77930144340762, 53.70747327804566, 55.99771384269961, 54.36425455154912, 54.90611822374406, 50.2148066028472, 58.72230199075515, 53.59357941535212, 55.942651610220636, 60.32094632425616, 63.051531776305175, 58.07077277091242, 58.87094805317541, 53.93311154457831, 40.89920490018783, 25.38483254371151, 21.779442833315944, 16.143922575058475, 12.441012936253703, 16.519601306607647, 4.065302321987768, 0.24291209365812041, 0.16846441994270972, 0.2399300810911002, 14.386276141289743, 50.76947681365475, 75.2368728576168, 52.039450060936716, 36.417492974189024, 59.62244672159995, 62.35535813916115, 64.47017069785826, 62.06627553509128, 17.943704089810772, 0.5590263706061148, 0.1714587512035524, 0.14567290582964498, 0.11369300210067343, 0.2532094798140949, 0.14847652716261728, 0.10582719433812365, 0.11608606925414455, 0.2516722477852337, 0.15140624656792612, 0.09207347993768993, 0.31131665132218794, 0.10426691072362085, 0.09701295440355617, 0.10609178578541165, 0.1661459314486673, 0.13434876267227436, 0.3467642750230528, 0.1449530436507156], [0.06018884307254226, 0.05098860590688644, 0.020943710039700233, 0.06460200364310896, 0.01910681122793786, 0.06468733817699455, 0.07581501808618346, 0.032599764620705, 0.06593187099262592, 0.0310938349444299, 0.029225970858768113, 0.10844228909380975, 0.038653303298258015, 0.03688023493234669, 0.008716749500543361, 0.043022666622193596, 0.038818058167253776, 0.09740706833620226, 1.7845627184837096, 23.360336480602143, 48.164340526826926, 47.75986179228752, 34.089032834576024, 15.427191795841342, 31.537542804594967, 49.98806615029612, 55.54101659405617, 31.423999994031846, 3.136362491115447, 0.11780781355956871, 0.08797993507957266, 0.48409129643151844, 7.617701301651617, 6.5643816417263405, 7.672807170498756, 4.2710674097461085, 9.037141857608672, 34.677180474804295, 57.32293367385865, 63.04432638229863, 57.75481800879202, 60.44685048441733, 56.219735683933386, 58.334673758476015, 51.32332332672612, 46.17234522296537, 55.17353365498205, 57.01835378523796, 54.71681287211757, 55.135961271101436, 56.292727070470015, 54.03043339329382, 51.971773485983576, 50.16600839553341, 52.438535536489184, 54.63816150542229, 54.32722345475228, 53.15721573368196, 51.57282921575731, 49.42346057584209, 53.233862769219186, 54.96642858751359, 51.227001682404556, 48.199088804183475, 47.6721340610135, 50.285981931994044, 57.56974097221129, 54.2503293098942, 54.21008579192623, 49.50767386344172, 38.787702821916156, 38.55481209293489, 39.381439839639974, 39.45818101206134, 39.437631714728575, 39.22001469519831, 38.80209792044855, 40.64257206455354, 39.663689674869666, 37.76567828270697, 38.61284355963431, 39.67714340456071, 41.413937537900864, 40.450305323446955, 52.49299372396162, 48.56944291822372, 60.33512177005891, 28.37126243499018, 32.7277664215334, 62.20884192374445, 51.89348297734415, 55.30919274976177, 51.687593844629106, 54.27753486940938, 53.69190931320191, 57.97417263830862, 52.21902401216569, 53.032351001616455, 46.875230035474225, 41.23677976669804, 38.944291683935354, 41.02393234929731, 38.53407844420403, 44.28099009298509, 51.586722250907656, 54.42243506831508, 53.451244446539114, 50.47152965299545, 45.26223767188288, 44.24307646289949, 50.19626555904266, 54.08370310260404, 53.73705579388527, 54.18698303161129, 56.08550433189639, 54.71711489462084, 54.6712153188644, 54.2452419957807, 55.606504486453154, 53.13004155312815, 51.204718697455625, 49.14801997523154, 50.41303142424553, 47.87368112994779, 47.54797535557901, 50.79365038102674, 50.66791488278297, 48.4702540213062, 52.920359488456484, 51.10699284461237, 53.016626219595636, 56.0956044350901, 54.70226872351862, 58.496644112371634, 59.62777722266413, 59.34586471126926, 44.03157834083804, 28.953106826351537, 24.803829500752112, 10.01669301140693, 12.189005555645114, 6.024883649041576, 1.9801748736250786, 2.837156249630836, 0.3840723585697913, 0.16571787216009634, 0.2078904454866725, 3.844311328664903, 36.46223545074463, 22.28565412182962, 22.947020646064516, 26.03577340802839, 39.45671796798706, 44.4139035286442, 46.71631913031302, 46.763069860396854, 20.791782179186423, 1.4262868079446978, 0.21201156951006384, 0.027070764429687012, 0.08187105037993, 0.019257719057702252, 0.09743858519340716, 0.04063192071513303, 0.014809377814432787, 0.03953687463616652, 0.06673215708184628, 0.06255417784315444, 0.021805668122044975, 0.03331655478705803, 0.03700712973612451, 0.018804212243506507, 0.022961405601592797, 0.03853249506303861, 0.02113571465616265, 0.06411389072215365, 0.06628568870045486, 0.06731714182082685, 0.028516259344835437, 0.03011625887255275, 0.025196679710080067, 0.0591642311173341, 0.026793254824775844, 0.021638607328397133, 0.03279841888035017, 0.03798145184954328, 0.04133140495527656, 0.20290773301835985, 0.014701952177640653, 0.06925374314549469, 0.030409576701781446, 0.05751040816727666, 0.055102459755876375, 0.18992761420386453, 2.194663190072583, 31.96669520870332, 55.602048673937404, 55.635329984849506, 42.87074896597093, 23.87112125273674, 29.793741356941965, 53.48303917915591, 59.20876218426613, 38.937317709768976, 3.3135795881671295, 0.07172757128794348, 0.132474176165077, 0.5353614856158534, 8.684711994663362, 10.022166678982398, 7.375212042562424, 7.749666014025289, 9.972496724897816, 37.021867459820164, 59.47502443867346, 64.93663464823078, 60.23635648912, 62.93040114064371, 59.19957991569274, 59.94241014603646, 52.20074968953287, 49.733182691758685, 57.99043870741322, 58.50356709572577, 57.73228791452224, 56.96009482106855, 57.69826527564757, 55.047998197617076, 53.45620624480709, 48.985096485384055, 52.668358971995694, 56.495254731947384, 55.040196603344334, 54.52994723473826, 51.38962707211895, 49.36306391992877, 53.85977891183669, 57.313994592235936, 53.84211647895075, 50.72745253962856, 48.86145945518248, 52.09941133376091, 57.29022110662153, 55.63414542905746, 56.265733318944136, 51.1266399968055, 40.831881338550204, 40.99246709577499, 40.994259618943744, 40.5745267868042, 40.26383584545505, 41.085042876581994, 42.06348988317674, 42.69140643458213, 39.7269888847105, 38.602900351247484, 40.11724510500508, 42.017488325795824, 45.08133403716549, 43.70644523251442, 55.14428846297726, 51.95031419877083, 61.60960182066887, 28.950606315366684, 33.862076651665475, 60.458856859514796, 51.83628697549143, 56.747490590618504, 53.13633695725472, 57.09125495726063, 56.024362425650324, 58.064634261592744, 53.435017601136245, 54.03670918556952, 46.958878501769036, 42.88590108194659, 40.18699269140921, 41.7143440246582, 40.847590431090325, 45.38643167864892, 53.723033320519235, 56.41076295606552, 55.40112918423068, 53.483529475427446, 47.59933879298549, 47.103943440221975, 52.580839126340805, 56.37104111333048, 54.56900227454401, 55.51778439552554, 57.62894130522206, 54.41880295353552, 57.73517477896906, 57.41826688089679, 58.345852513467115, 54.216640072484175, 52.1375681507972, 49.82917877935594, 51.195873752717056, 48.82931563162035, 48.980605371536754, 50.69097449702602, 50.38857544622114, 49.557311457972375, 52.66904146440568, 52.80321398089009, 53.5316098889997, 56.40785647976784, 56.692557796355224, 60.600254381856615, 61.80526141197451, 61.824045642729736, 46.070198858937914, 30.43649231233905, 25.457651345960556, 9.172347918633493, 6.4834430429243275, 8.316811323165894, 6.969924809471254, 4.953688767648512, 0.9732550142272827, 0.06354950991789661, 0.12237064089746245, 4.309873869342189, 37.17801309400989, 30.325295079138975, 30.154024785564793, 35.78722692305042, 48.590384452573716, 50.64995827213411, 53.52030169579291, 53.512158855315185, 25.805840146157053, 1.8102413728352518, 0.15704378035039673, 0.020663444433481466, 0.06283035253985755, 0.03153179208898256, 0.056564680285631656, 0.05087178898975254, 0.03674666367230877, 0.0772724697186101, 0.02652616976129432, 0.05487135018131906, 0.041194631447715145, 0.05427830236693544, 0.021824109773602218, 0.03170059381743833, 0.08384991677538042, 0.012468477418165536, 0.05007582363642512, 0.02854693542054344, 0.17435948184180647, 0.2304871281188342, 0.14386899859434174, 0.15052149162417458, 0.1898983649669155, 0.20382169123378494, 0.1305912239777465, 0.1156012581721429, 0.14765236977367632, 0.1177532987428769, 0.16063935273597318, 0.254945894703269, 0.09421654195795137, 0.10695790947084466, 0.23790855892002585, 0.2542791990262847, 0.21844774995359684, 0.37212567704339183, 3.1391221236798073, 44.606115356568374, 65.14804255577826, 63.677887224381976, 48.19384067289291, 28.14693816246525, 44.41093821679392, 62.76981146104875, 64.91067640243038, 42.1996118176368, 4.734051727479504, 0.2880990391056384, 0.4615131224836073, 0.9003898176935412, 17.275483223699755, 16.526953789495654, 20.17665843809805, 13.36253164276, 10.375456521587989, 39.05002701667048, 58.630138058816236, 68.83372122241606, 60.29700809909452, 65.61533412625714, 57.75422965326617, 61.94689427652667, 51.35817750807732, 50.17244500498618, 58.7553205028657, 60.45851169093963, 59.410266107128514, 59.08896515446325, 59.161807490933334, 56.0474181175232, 53.33462061420564, 51.20211816603138, 54.213949326545965, 57.80489883115215, 57.991266327519575, 56.22596440776702, 52.78464155812418, 50.306821484719556, 55.32840844123594, 59.96361055681783, 55.89277867347964, 54.21138801882344, 51.97030651953913, 55.48769197156353, 60.35616136366322, 58.851599001115375, 57.070599755933216, 53.51609299259802, 42.1856834811549, 43.21082630465108, 42.943301047048266, 43.60081580377395, 42.57260568680302, 43.16269097789642, 42.83158017743019, 46.43834075620098, 43.035366919732866, 41.34274259690316, 42.185699170635594, 45.03344189736151, 45.47788566158664, 46.424745821183734, 58.497726686539195, 53.89836718959194, 62.883003219481445, 31.25317292828714, 36.50855079773934, 62.90083039191462, 54.98924501480595, 59.3849354405557, 58.60021429677164, 58.923751000435125, 59.02158667964321, 61.8323100766828, 56.3223841113429, 57.293441372533, 50.7917558762335, 45.65482378005982, 43.647621447040194, 44.41211492784562, 43.48438024520875, 47.59363174438477, 56.820478054784964, 58.91970703678747, 58.18531774705457, 57.62196733105568, 50.28214977633569, 49.26242766841766, 55.11102676391602, 60.141089962374785, 56.80747539766374, 55.9969646699967, 60.12223120658629, 58.59429544018161, 60.490220131412634, 59.33086556773032, 61.62787222093152, 56.71777863656321, 51.53809662788145, 49.06280256086781, 50.24235340856737, 49.621348073405606, 49.504214332949736, 52.66510340475267, 51.55611991882325, 48.87273626942789, 54.49619916177566, 53.64111854184059, 54.79577410605646, 59.23409677320912, 57.12549332649478, 63.06935894873835, 62.48563181969428, 63.63951075461603, 49.15968118175384, 33.54342329886652, 29.44073392498878, 12.199649887700236, 16.776100781656083, 15.582618655696994, 10.292986727529957, 8.417691742220233, 1.6435552268258988, 0.1740398239945212, 0.3713460753281271, 6.177432960079563, 47.92927288240003, 33.672367295911236, 32.79716687817728, 36.45087626672561, 52.63455990822085, 56.45012394074471, 61.92670975961993, 61.897660686123764, 33.04410557593069, 2.697456378129221, 0.31112699859565307, 0.0904634006081089, 0.30207821318218786, 0.09125079343756361, 0.2630323970750455, 0.10607781234167277, 0.128766862194865, 0.18322840513240907, 0.10769808064064673, 0.22183915990735256, 0.190816153621962, 0.08731287934126393, 0.1678968560431273, 0.13525856869114986, 0.16187325991209478, 0.15837306547309124, 0.15298847860145956, 0.19291462166415108], [0.041585872550645185, 0.13810551995711942, 0.05907240781872984, 0.022282314621993614, 0.07054680763112922, 0.028717261663968527, 0.041938954814066814, 0.024695748222931743, 0.05372515624208797, 0.025475526138419108, 0.01875434375007547, 0.07924300873832357, 0.09425951182962426, 0.04592651140785987, 0.06143132660297617, 0.019625724713888862, 0.052916561929328795, 0.09052890112563487, 5.243013578076517, 32.54558409413984, 46.06644907305318, 53.6012751056302, 27.361754179000858, 23.033932524342692, 49.8237306071866, 58.79047670672017, 56.58273143153037, 18.652186124555527, 1.6878963958832527, 0.12178476749648973, 0.28890373786130263, 1.264995391811094, 7.324743395851505, 9.364154761837376, 4.635100624253673, 6.567007668556706, 9.220301835767685, 37.21616991104619, 58.77318297663043, 58.80866081483903, 56.27496657832977, 54.73560886998331, 56.42966093555574, 54.785803441078436, 55.274064002498505, 53.98912691300916, 50.55325615790583, 54.44950334487423, 55.94651906721054, 54.42978166764783, 55.120683639280266, 53.53844265783987, 50.99744496806976, 52.51283307229319, 53.06652661292784, 53.66155409043836, 53.91323689491519, 53.77763663568805, 55.348106584241314, 49.84460153887349, 49.176198282549464, 52.22350335890248, 50.79281099380986, 51.558536098849395, 50.78892784733927, 49.78976288149434, 53.31714645508797, 51.68811551986202, 52.78754411205169, 47.4617616591915, 38.296845651442005, 37.91169243474161, 38.94084784292406, 38.12463791139665, 40.75827413989652, 40.80760578955374, 42.110993708333666, 44.008404977859996, 45.6354864951103, 44.11006889035625, 47.09167426632297, 43.39823322911417, 46.51749418627831, 46.082071873449514, 53.370176899817686, 50.22770335597377, 60.28511547273206, 31.307117285267, 29.385120599500596, 56.75892429967081, 48.975506290312744, 57.41446218182964, 52.61491667839789, 54.5964902447116, 51.29182277187225, 57.505786726551676, 55.552430691257605, 52.71694929369035, 52.044494228978316, 47.55216836929322, 40.000464377864716, 40.197606625095496, 37.75786884369389, 42.81315288236065, 47.87578744273032, 51.375102535370864, 52.66397768451322, 52.71735722018827, 48.20865938740392, 51.24655469771355, 51.0991677161186, 56.19056501696187, 48.56905460357667, 49.564693358636674, 50.474298846337106, 54.89345681282782, 56.06979131698609, 54.8126442201676, 49.17976763940627, 49.867931796658425, 49.30683674350862, 52.647731227259484, 54.40250550546954, 53.94916188332343, 50.277262503100985, 51.932608619813, 49.30937059463994, 51.52508612601988, 48.92176589658184, 47.80324320639334, 49.669287281651656, 52.938347478066724, 56.828287493798044, 57.9066490357922, 59.33700407705, 50.469933248335316, 34.08185489716069, 48.837889932817035, 34.35289067606772, 16.056025201274505, 11.243769257299363, 10.017060733610585, 6.430618522628662, 2.3627772013987265, 0.7610499462293041, 0.04128673819885139, 0.027376021739215623, 1.141118239010534, 21.6507008383351, 48.83704662322999, 19.443561569336925, 25.674221092654815, 34.863897062117054, 33.02288555329846, 54.0645384019421, 38.5785698890686, 29.445825161472445, 3.806382009098607, 0.14692012761389056, 0.019090472487732768, 0.018998762187097343, 0.026831630084122864, 0.036104632196046656, 0.03236072986657101, 0.035935533608520226, 0.02634199073297843, 0.03927797522215594, 0.027088982000526403, 0.049280758436408736, 0.09554202728454145, 0.02455819139046775, 0.07936923704560726, 0.025057588786547704, 0.02558713940332734, 0.026833738741134445, 0.020668387615812883, 0.029408878181129697, 0.034557329941420786, 0.04753891198385147, 0.012676129380481379, 0.026236157601458893, 0.038493715692311525, 0.05875402167739888, 0.055229017480967514, 0.01713159332622684, 0.02390776933621495, 0.029203670039292307, 0.02634706989591641, 0.06033314339395973, 0.0245961069970602, 0.03714628577713044, 0.01565064290433281, 0.11469755021314468, 0.04373496751331034, 6.468229149618457, 41.48735646278628, 54.396665096282966, 57.96177010382376, 33.55054240072928, 21.90631385772459, 50.19270012455602, 64.86644383399718, 62.663221051616055, 24.394275219209735, 1.4833624420627471, 0.09862992086357648, 0.3351457855634151, 1.923384959659269, 9.849764781613505, 9.559306406205701, 12.219539246251507, 10.696151468061633, 9.760958398542098, 38.9371019794095, 58.0329179763794, 58.966057685113725, 55.95014725961993, 55.97326178704539, 55.892378591722064, 54.46176075166272, 56.8021527413399, 53.19982051849366, 50.88089958313973, 55.833848984010764, 57.67422114649127, 58.174397868494836, 56.19465997142177, 54.74678762497441, 52.03567674083095, 52.261389532396876, 56.09914241298553, 56.6027904325916, 56.551266178008056, 57.06486917311146, 55.7799046270309, 51.68880193464218, 50.65846197066769, 54.95787782053794, 54.082730354801306, 52.7868341630505, 51.7964788406126, 51.79927156817529, 56.86176100084859, 52.14586396371165, 54.47204128388436, 50.316133191508634, 39.58334384425994, 40.02842695482316, 40.244694679014145, 39.75530447498445, 41.99355010063418, 40.757285702613096, 43.88865109412901, 46.83437070538921, 49.1607637559214, 47.572250904575476, 49.99720527279762, 45.69296490761542, 48.27012292800411, 48.21062057249008, 55.099789173372336, 52.159180410446666, 62.03355512311382, 31.761013961607414, 30.61823925664348, 58.25324143132856, 50.99064750056113, 59.83570991023895, 54.57242650370444, 55.74102217151273, 52.80892887423116, 58.41634142783381, 55.979721930719194, 54.869306779676876, 54.265022508559696, 48.22571385291315, 40.01906425722184, 41.79452511572069, 39.913160262569306, 45.09787467218215, 51.35336868224606, 53.29206289783601, 53.55483424278998, 54.98010196993428, 49.60075170763078, 53.23727915363928, 54.767619332959576, 56.41799972903345, 50.48849390399072, 50.66138021407589, 52.188241251053356, 56.034631190761445, 56.93953767899544, 56.46182437096873, 51.14098018215549, 49.51211398647678, 50.05329908863191, 53.55679542787614, 55.2389274104949, 53.60247535090293, 51.94579562833233, 51.271273474539484, 49.71827376273371, 50.220643089663604, 50.7729834125888, 49.60545462946738, 53.08502451066048, 54.54025522355111, 58.59114185456307, 57.72103071212769, 60.545502016621256, 52.365402944626354, 38.24304249978835, 49.2477148579013, 35.48699694295084, 14.110788472237127, 6.160926645801914, 10.441049337387085, 7.934223336558189, 5.714366272572549, 1.6516264840479822, 0.13793762412763413, 0.025510254819246552, 1.170108476954122, 25.930267533948346, 45.98144346667875, 22.946661749193748, 25.96568261423419, 40.39781224343085, 39.135197362592145, 58.39979687044698, 46.12225263349472, 36.54855505112679, 5.215997763218419, 0.21707982335600162, 0.020161520862471194, 0.004848997566788908, 0.07696348347611005, 0.024120391293939565, 0.012019562343465946, 0.06026185508216582, 0.02870770663233294, 0.05834208087875478, 0.013796787693976395, 0.030282974926634666, 0.08460321103132541, 0.028500294072493434, 0.10239869040707428, 0.01885731554319782, 0.06480175340848585, 0.025970290617776975, 0.03175724410421906, 0.18393872185580193, 0.30481817260865246, 0.1630115286717492, 0.12330943568339273, 0.11911488979333833, 0.12917003894765533, 0.16235356639710166, 0.0818040406691932, 0.10581486798342198, 0.1399563270951471, 0.0923318737336705, 0.23985855912248935, 0.20505716122927206, 0.22305674941068698, 0.1399287632516315, 0.10918557824146365, 0.3071707979806008, 0.23528936559394484, 8.268615199673562, 51.32425292845696, 62.26167232759538, 67.47661252175608, 38.868342830288796, 34.92068121510167, 61.182859713031405, 67.61926128018287, 65.50022040644001, 28.020506443515902, 2.002431382575343, 0.2146708445563432, 0.5153689809864568, 1.8579223175202648, 19.117634181053408, 20.532546850942797, 19.301452136808827, 15.279647919439501, 11.869751099617252, 38.58654014525875, 57.93323486082016, 61.5357945811364, 56.05821248023741, 56.775582605792636, 55.62660663358627, 56.80616140365601, 56.939639660619925, 54.928252158626435, 54.53451287361884, 55.92697781901206, 59.09064785126717, 59.22477329930952, 57.91531355150285, 54.938360106560495, 52.00792204949164, 53.51327280844412, 56.63897821980139, 57.89863563353016, 58.718336474510934, 60.47366380691529, 58.282953385383856, 51.62704421627907, 51.616171406161406, 56.460592746734626, 56.42893921944403, 55.47040608621413, 54.60966940849058, 53.53399469006447, 57.61391078272174, 53.60924143945017, 57.50279003574003, 52.3476581419668, 42.90552077754852, 41.99840207253733, 41.728331196692686, 41.11805746632238, 43.70482529363325, 44.58788418000744, 47.4144539525432, 49.836372406251975, 51.55191121562835, 51.450051184623476, 52.97764570482316, 48.399482696287095, 50.65570062206638, 52.24280142015027, 56.74723171418714, 55.19466346310031, 63.61086176287744, 34.76627711326846, 31.767056372857866, 57.27622608984671, 52.59190021022674, 60.773097545869895, 56.26931444291146, 58.0462226560039, 54.11774535332957, 59.78953184620027, 59.85490598986226, 57.029348188830966, 56.355253573386904, 51.85049380025556, 43.570782215364524, 44.917822191792155, 40.94201757061867, 48.19314641337241, 52.26259370003977, 56.67704482232371, 56.532211303710945, 58.78216912669521, 53.088954725573146, 55.877010745386926, 56.60182160715903, 59.44710108541674, 49.91712616335962, 52.21731385877056, 51.398597532703036, 56.118562067708666, 58.56549739837647, 57.20480757374918, 50.596300248176824, 50.553354217160134, 49.4036094604, 53.89141282727642, 56.029940036035356, 56.04583740234376, 52.77221548941828, 53.16025949293568, 52.71553724042831, 53.38285007784444, 52.84628552775229, 51.51275811656829, 52.770258226702296, 56.87732496569234, 60.79746330938032, 61.321350759075536, 63.37054598715998, 57.92968119344404, 40.896827943863414, 51.5164686787513, 36.11829849981493, 18.465169475924586, 15.332520488769779, 16.76613207786314, 12.922972209991949, 9.898533571150995, 2.3445367092086427, 0.27609793469309807, 0.16131953156042486, 1.6269672782190385, 31.852375768846084, 62.066620703666445, 29.067845959817213, 35.820143453536495, 44.23756945517756, 45.165402197068744, 65.94736668371385, 54.21670283040693, 43.461230416451734, 6.9983144344822055, 0.33596228207311324, 0.10483291180383776, 0.10173325111428577, 0.17613007957416196, 0.11446596949451393, 0.1197411819931961, 0.22701616759502122, 0.13577238386196477, 0.1181369632362358, 0.08274640542485061, 0.13261528956072946, 0.1614191229905813, 0.21592459340970363, 0.2234072193142868, 0.20382702320573792, 0.10130743646333296, 0.07197230573623412, 0.12126066376485171], [0.0637472563633515, 0.048067987626118046, 0.07873765117819272, 0.024797396599164894, 0.07845475022951443, 0.03843137911791283, 0.050263059355558894, 0.05361701144025691, 0.06072657167791359, 0.04229527762940815, 0.055561062969988396, 0.019078785816447872, 0.06755699628903981, 0.05820462555294076, 0.06631280821297439, 0.020545043629564105, 0.11004196494937905, 0.03518761345936406, 11.674621028284873, 38.05889898730863, 48.06515947464974, 41.30009858838974, 35.05644229150588, 40.68253709423927, 54.720127274913175, 62.45642585139122, 34.57253556097708, 16.921669744676162, 0.12066546707384049, 0.11659834458823166, 0.057836562440159826, 1.1671419393631721, 7.602974272543385, 6.400938437831018, 5.157628482387913, 3.4666319431797152, 8.410860934565145, 40.53918230918146, 55.22515204644973, 53.335899306881814, 53.78118245832382, 53.88061061982186, 54.574666177072835, 55.67178449323101, 51.86360628374162, 49.586015362893384, 47.02850449469782, 53.651971740107385, 53.82608967442667, 53.142263658585094, 52.57045661249469, 51.875216499451675, 53.51594786490164, 54.56963377614176, 53.733906130636896, 48.46283289694017, 49.431356306998964, 51.142764860583895, 55.472026025095296, 53.64691972732545, 51.20992760504446, 51.920676769748816, 54.90258024584863, 52.801978434285815, 53.61700381002119, 54.76193581857989, 56.65757025441816, 51.842700050723174, 54.3243169784546, 45.775875968317834, 38.303921607232866, 38.68868258691604, 38.681932187849476, 38.6201117115636, 42.543097695996686, 45.42188990500666, 52.00102652272871, 50.8932864281439, 52.80962313375166, 51.96982799037811, 53.21463923300467, 52.090476174508375, 54.55277935151131, 52.17456786863266, 56.416183671643665, 50.04603878144295, 58.51398098853327, 26.79368711286976, 30.22865180046328, 55.752746135957786, 44.827591988348196, 51.17691301530408, 48.53116058534192, 50.22526364172659, 47.78242326551869, 48.95715352027647, 51.16778958228327, 57.51444731989215, 50.29711361854307, 54.335519267666726, 41.99854327786354, 39.08783082039126, 37.16059777044481, 40.080531720192205, 44.898069135604366, 52.630076639113895, 52.39172204848259, 54.18610834306287, 52.112104123638524, 53.52878186010546, 52.576061679470925, 50.45678546351772, 49.92400600064186, 52.97971279390397, 53.80299868122224, 50.775238775437884, 48.089662521116196, 49.69817946034093, 50.7508377105959, 51.57366075823384, 52.59245326442104, 56.727306073711766, 55.28683523977957, 53.081129597079375, 53.44085801032282, 53.38655279528711, 51.06751811119818, 45.642876240514944, 47.6082778746082, 48.52695972688737, 50.8738197049787, 55.803431003324455, 53.48550242762412, 57.38135345520512, 56.04696312258321, 56.739481110726636, 58.82755879432925, 53.176815817433024, 41.45215319048974, 22.83861614042713, 10.66201606104451, 6.346366991919856, 4.301100998155532, 5.711880960772115, 1.2123459072843676, 0.29738555692376634, 0.9543425097100197, 0.07459789589648286, 11.455904764513816, 35.38976138637912, 34.60687198946553, 55.70428525247882, 32.06367385002875, 34.25084237129458, 45.11186968895697, 45.01346134370373, 38.87117478155321, 8.750914739024255, 0.1206575763682204, 0.03987506415034014, 0.02982581004260048, 0.09233029559254648, 0.044889274323659564, 0.0519288485989936, 0.05213392650588386, 0.02514432334611493, 0.024791595398358283, 0.02396599967933951, 0.07227912394990844, 0.04294081778836347, 0.015777075182526343, 0.06938952456919417, 0.046306525492259575, 0.07167775259022752, 0.08642887516367821, 0.049928344050121885, 0.019453128934988094, 0.02611613077592225, 0.024543135847535827, 0.01743781973697966, 0.06402172651442309, 0.03634637507099298, 0.08047621111355482, 0.018347930275805054, 0.058841585527144136, 0.07657537567279032, 0.10190902998851192, 0.03956874389381659, 0.04932208887992367, 0.11584701917825208, 0.062193825405331395, 0.029963613938420054, 0.07661964789393448, 0.1295586600298843, 14.00893726656514, 46.78491353988648, 55.33029117891866, 48.529607326753684, 37.196154056056855, 42.3337294209388, 63.13102253021733, 71.00012471598964, 46.34149351427632, 17.473180486309914, 0.2625371978407906, 0.1000793515554359, 0.4380271649889408, 5.278214398891696, 8.138727382306131, 10.878322028344678, 10.756092148442423, 5.999203401227152, 11.07086431595587, 41.342318980924546, 56.8984704632913, 54.66290773883943, 54.64916375375564, 56.231079178471724, 55.72716836006411, 55.454712683154696, 52.54227046043643, 51.276976600770034, 49.95761286827826, 53.83862556949739, 55.06894365433724, 54.27422831135412, 54.083393235360425, 51.6707198081478, 53.70255854821975, 54.78820000925372, 54.42724781651651, 50.12141889141452, 53.10522079467774, 53.68834780108545, 57.90090276348976, 53.29090579863518, 50.63097792287027, 51.28946150502851, 56.30377246487526, 55.34252505148611, 55.11333703994752, 53.964945500896825, 57.69495871759231, 53.308725126328014, 55.594309837587424, 48.01450598624445, 39.54460651643815, 41.48206518542382, 40.726797119263686, 39.707781037976666, 43.727116123322524, 48.80057642536779, 53.06664428403301, 53.948020473603286, 54.16699463321317, 54.08438559501402, 54.77532679034818, 53.91293095004175, 55.51143800058673, 53.11579158229213, 57.247224084792606, 52.06887175959926, 58.97277278284873, 28.272220626954113, 31.22171355832008, 54.722818020851385, 46.39221368297454, 51.832039048594815, 49.195151175222094, 52.18066323188044, 49.04804268190938, 49.44926584920576, 53.62573500602476, 58.4898623343437, 52.33563999975882, 56.57204297281081, 44.74270013070876, 40.23204503520843, 39.532407945202245, 41.2929912536375, 47.35004863431377, 54.94330229297761, 54.15352129167127, 56.24009278512771, 54.36862014955091, 54.1498185742286, 55.8757673540423, 52.59547741182389, 50.46002534128005, 52.49187192609234, 51.93322050955988, 51.09948935047273, 48.654707401029526, 50.47668756977205, 49.96723836468112, 51.594712118948664, 52.32057025355678, 58.360985017591915, 57.15468360531715, 55.85007582941363, 55.277056770939986, 55.4788980176372, 52.91424451335784, 48.92188749005718, 50.97142396434661, 50.28665657966368, 52.03180536147087, 57.494878615102465, 56.11373755239672, 60.614414138178674, 58.174860708175174, 58.01304724908645, 58.69974836226433, 55.557600375144716, 43.10853481292725, 25.068956228994555, 9.23654240946616, 7.041478157043458, 8.931230018215796, 7.446838934575358, 2.64710957004178, 0.9383548676006256, 1.271333574287353, 0.11453566051298573, 13.263731060489533, 41.48050015972507, 30.695925720276374, 52.142600551728286, 35.065436286311, 39.93139143913023, 51.79595324300951, 51.13036232609903, 47.27936752380864, 11.481344276858914, 0.19671277834042428, 0.04602083981397652, 0.027598725414023768, 0.016262198445357142, 0.128110432096066, 0.034379325581774596, 0.05091208521456969, 0.10025175964279522, 0.022423428017646078, 0.022074001908843077, 0.11102093338605859, 0.040879451384347294, 0.0494984001852572, 0.02458359103559727, 0.07944737801388388, 0.010953278078006641, 0.010091751877729212, 0.05604398181481708, 0.21516585992949627, 0.12244891210068619, 0.1749773930397726, 0.14424868709137365, 0.171388378366828, 0.10105302632455865, 0.17890155585783143, 0.1927749178702793, 0.12311129470265682, 0.18037419135291732, 0.15655161482432198, 0.1921148105494438, 0.14545023471357363, 0.11014587711542846, 0.11372546124602519, 0.11607942727184105, 0.18833396746025932, 0.23709894187988775, 21.578227204661218, 58.50544198866814, 63.69503582677534, 54.1845590068448, 47.5114933906063, 53.43319762137629, 64.40966421558012, 66.40742932596515, 43.65256363345731, 23.238097775367, 0.36754088596470896, 0.4072271515765498, 0.21221928658985326, 3.6846017308773535, 11.292737107123099, 15.119268086648757, 13.52089439668963, 10.077750586694288, 11.765814173606135, 44.23884422548356, 59.95480875815115, 56.27336232892929, 55.26834518678727, 57.03453356219877, 55.718931382702245, 55.94473831115231, 51.490235867038855, 53.258161852436686, 51.83597318587765, 54.23146663173553, 56.40621300666564, 55.577835882863695, 52.58671875922911, 52.37516180161507, 54.80224993921096, 56.61785233405329, 56.6010332107544, 51.11070340679538, 55.472328047598566, 56.47879254433417, 61.82929769639046, 55.671168681113954, 51.70722530734155, 52.05086808050833, 59.857890913563395, 57.907331528202185, 56.8467971586412, 57.82854287855087, 60.17506553280739, 54.950550833056056, 57.20816904498685, 49.90853225031207, 41.158226459257065, 42.614767243785245, 42.97936331841254, 41.88810110092163, 46.43815640480288, 50.156802592738984, 55.903969195581254, 57.03482773996169, 57.19058505950436, 57.890128012626406, 57.62167707566292, 55.76503492170765, 57.55858575144122, 57.47548641697053, 58.514365380810155, 55.07177168323148, 59.757768492544855, 30.172369710860718, 32.162968650940925, 53.580600292451926, 46.92478526023127, 51.3486736051498, 51.16129805964809, 50.66046630182574, 48.50475911171206, 49.19176616976338, 52.960897184187374, 61.00303080774123, 54.036771943492276, 58.2957834582175, 46.5156545946675, 41.867928351125414, 42.881025575822406, 44.169394739212535, 50.427606951805856, 57.52740290857131, 55.61597701041929, 59.13229557775683, 56.584700461356874, 58.181034518826394, 57.177162708774695, 51.59937973945372, 50.1405639802256, 52.58614217081378, 54.116623555460286, 52.77805982097503, 48.53687155631281, 50.78949659101425, 51.11743811638125, 51.98050075961698, 53.911766006100564, 59.6777246844384, 58.87077154651765, 57.86566418986167, 57.10472045406219, 58.12570164280554, 55.14667326404203, 50.48355563994377, 52.80935641257994, 50.17577901963265, 52.852486794994725, 58.850979266628144, 57.280372035118845, 64.35888521132931, 61.929969249233125, 60.09523353269024, 58.31974521760018, 58.27065675489364, 45.787321444480654, 23.91251402516519, 12.686091449952896, 18.479482204683368, 12.411749112990595, 12.211629786799032, 3.473751780486876, 1.026176306749544, 1.738678587059821, 0.15623116024559544, 16.424339682825153, 49.76858600493401, 46.97945525569301, 67.01643220839962, 41.22731116510207, 45.179593332352184, 59.1949946649613, 58.4267984667132, 56.83051147768575, 16.605575738414643, 0.35679126278527323, 0.09227652388114123, 0.15006390730700186, 0.1392272258958509, 0.11503033880745211, 0.09602104674183554, 0.18927227194991805, 0.15669269757645746, 0.13131350699451663, 0.10902024114564543, 0.24328527040779593, 0.21353469019935978, 0.09522940978528031, 0.17222283197747124, 0.22355187203614946, 0.1392487376447647, 0.11348709298838532, 0.14263774208243818], [0.05664462156053032, 0.048024500645096266, 0.047440787612070004, 0.023935116759891954, 0.011027023616817691, 0.07410252812288462, 0.05718219694831679, 0.04932688075989004, 0.07931368034933844, 0.09371747397967885, 0.11513038222948391, 0.058286585469519904, 0.006259212696609358, 0.021379127602783904, 0.0753785088478077, 0.039072349562399813, 0.10858978400187147, 0.35685693184214257, 13.388589908999782, 36.11447811126709, 45.738307506807395, 29.98895968160322, 25.369005780066214, 27.020737432664443, 39.45744360646894, 27.25991572103193, 33.649225311894575, 11.432606866282802, 0.08666480726171887, 0.08867859960563722, 2.5856494615154886, 9.915010467652353, 6.463068291064232, 8.553176291527288, 13.747826064786604, 10.763866286123953, 9.297812773335366, 40.47394937084567, 53.40142642298053, 58.5012685868048, 57.227741672146706, 60.53387611143051, 56.059463716322384, 57.754955291748054, 53.783257392144975, 55.4367325382848, 49.369457383309644, 49.551886820024066, 52.65818826613888, 51.915244287060155, 51.911070885196814, 51.63566558591781, 53.50835023387786, 53.56513438686248, 52.37619338497039, 48.618409787454915, 44.30721898232737, 49.65422145781979, 53.84112019692698, 54.25443210909444, 52.29196440789008, 48.869390487670906, 49.83356791157877, 52.272089758226954, 54.68747746559882, 53.992276576257524, 53.76944280439808, 53.841304548325084, 52.38565021945585, 42.33779691880749, 38.117154029107866, 39.440271469854544, 38.45854143942557, 39.690306878859, 50.76566034747709, 53.316907190507465, 53.81855480132565, 53.648990738776426, 54.07263417397776, 52.12319266411566, 55.47148866038169, 50.25046487008372, 55.59617688578945, 50.10719637716971, 56.59748738811862, 49.23286476442891, 59.30012203031971, 25.220679390814997, 24.084641356622022, 57.08334745899324, 40.80598585067257, 49.715280994292236, 44.17439968355241, 46.24372843773135, 42.48426606578212, 44.86480743654313, 43.08998200201219, 49.957499119543264, 52.62778597493326, 54.284622592310754, 46.2652857841984, 40.26119216795891, 37.88285124686457, 39.604897268356815, 39.51509068089147, 49.44988558369298, 50.88970530417658, 54.754389178368356, 54.0657857156569, 55.29312279916579, 52.851702320960264, 49.696371247691495, 47.97250524643929, 48.87974946729599, 44.47072298296037, 48.58037456389397, 48.037463618863015, 51.86932509945285, 50.5157426095778, 55.05278741159747, 55.03798046419698, 53.72032688510034, 50.80020858395485, 53.60475817034322, 51.505085960511245, 53.407702215256236, 51.481022219504084, 51.05941449442218, 52.06048180980068, 49.86038123407672, 49.55724870004962, 50.11511172017744, 52.87850779871787, 51.00192823717671, 54.509970603450654, 59.33829453683669, 62.473315577353205, 61.73243476498512, 44.84063779154132, 23.44104316926772, 12.26773242796621, 10.35638693840273, 10.08427348829085, 6.369868363103559, 0.9365979521985978, 3.347452441530843, 2.668086650871462, 0.16444394455081032, 7.229713682205447, 33.26072631343719, 43.986318111419685, 27.677908982000044, 23.510992757735714, 29.13906639622104, 44.6123597698827, 43.66436604530581, 49.04878793224212, 18.476416872393703, 0.1926689832321098, 0.008084812190293545, 0.08936426361962672, 0.06970494595025817, 0.03790215791894063, 0.09227538241013404, 0.026986310896914334, 0.06473187086803299, 0.03263508127401433, 0.02324097023736085, 0.019392604158530315, 0.023229329531351407, 0.04074429432230611, 0.04902649768477967, 0.01669617767836298, 0.04605363603801497, 0.06658218770978913, 0.08136853500599824, 0.03301054479614381, 0.023664521098497416, 0.061351469597749175, 0.061827666021042296, 0.03770691275055851, 0.03646136103798786, 0.037852672469471736, 0.028056472524880405, 0.08893504753829011, 0.01976108670444979, 0.05560351956275202, 0.04245424470413597, 0.022181849851603472, 0.02068135556915114, 0.006799478489424914, 0.03463927836668107, 0.008341107862971483, 0.5430806488279374, 19.916926930027625, 46.75195386332851, 51.84450434100244, 35.011013400170114, 33.51060875000493, 33.03432710709111, 45.068292156342544, 37.159464205465014, 36.73493431460473, 12.692505505777175, 0.14732664451003075, 0.06942959862851328, 2.4809302678031306, 7.294573505078593, 10.274739861488342, 8.963810205459595, 10.0031735820155, 4.594276105203937, 12.003228375988623, 41.6240785198827, 55.21312998187158, 56.922808770210516, 58.20471778992684, 60.48937289945541, 57.569576232664055, 58.031235279575476, 54.43206448708811, 54.25872710443313, 51.19991771636471, 49.71135862411992, 52.40942762744043, 53.30530481953775, 52.028859661471465, 53.036520481109626, 54.75470296798214, 54.575321212891616, 52.98965207992062, 50.97281640575778, 47.21274214406168, 51.3970442741148, 55.23190636788645, 55.821442527155725, 52.86479519259546, 49.578562859565984, 51.2109709555103, 55.42420448795442, 55.90090974684685, 55.14002484659995, 55.12974039200814, 57.29027994217412, 54.90238804971018, 44.47868539441017, 39.23481772022863, 40.35678032905825, 39.21560595112462, 42.52828682622602, 52.11927813868369, 55.566068772346746, 54.432448879365005, 56.91320680802869, 55.83990120118665, 54.046009125248084, 56.791738848532404, 53.26502600023824, 57.20374068906231, 52.192649995127034, 59.541155599778705, 51.638317108154304, 58.81312054972495, 25.68680797853778, 26.53024700380141, 55.95300274510538, 42.492036281093476, 50.50522281277565, 46.527739417168405, 47.7256626467551, 42.52933017669186, 45.15624738508656, 43.006113882987734, 51.807579148200254, 54.04475396679294, 57.839674565099905, 49.674704074859626, 40.39656100734588, 41.13736337231052, 39.17332280066706, 41.00341443092593, 51.71170073170816, 52.84871739725913, 55.680386251018895, 56.34571436912783, 56.21951210883356, 53.5191406742219, 49.443884357329345, 48.646466501297496, 48.616393689186346, 46.67267099503548, 49.456439864250925, 48.93909100563296, 51.92697609624555, 49.96914855895504, 56.05347033469908, 57.026355420389486, 56.956894167007945, 53.96010529610419, 56.53781637068718, 53.169700637940444, 56.4974904829456, 54.10548402417091, 52.767245846409956, 51.69086902372299, 50.84848903840589, 49.57347554545249, 53.47517090459024, 54.55177130237703, 55.67440463650612, 56.8472090075093, 61.6649386190599, 62.367505719584805, 61.67304223583591, 47.06315079042989, 27.586786439341886, 13.816162578521238, 12.157770741370417, 8.441857464851873, 7.303540043292507, 3.843714147806168, 3.8023039698600773, 3.3946998417377476, 0.16163912812067618, 8.671862309978856, 35.12217729322372, 44.63579200929211, 36.7971666397587, 32.474787273714625, 35.72644979723039, 50.87383539445939, 49.36062420568159, 56.509053630213586, 23.759561200295728, 0.47327805731085043, 0.020229040021677653, 0.018292477001406012, 0.0482938609897129, 0.046027769079251636, 0.03914135493217938, 0.06390280668593704, 0.027863314946091948, 0.07679667549147721, 0.017436260748053753, 0.04514101847645737, 0.05664750205112561, 0.054977434206633806, 0.06794191716659455, 0.028714469273484526, 0.05028567044064403, 0.025975335306758364, 0.08146660192118538, 0.15802722274055406, 0.11862257104967872, 0.20472731441259387, 0.18462820098765437, 0.1342275675626532, 0.16540746865493638, 0.15894318810634075, 0.13584467191849986, 0.18337728665961375, 0.13125585121733527, 0.22661930340672695, 0.10544801912000103, 0.2660937457075042, 0.19175537741712986, 0.1265081208980372, 0.11777982836769474, 0.1929681558882998, 0.9116096349973833, 27.41869522679237, 56.791126958785526, 60.32839882758356, 42.10653005107757, 38.81702646132439, 37.93230448999713, 49.32735073950983, 33.88620707296556, 44.89945765464537, 15.028567198784122, 0.5129864475419444, 0.39457802871061914, 3.930029335521883, 14.944424513847599, 17.32649560897581, 18.977580070495605, 23.992828476813532, 21.906731590147942, 17.805791593367054, 44.108978471448346, 53.3983552071356, 58.13627243041993, 60.838079452514656, 61.8468895266133, 59.40197421658424, 58.54352035830098, 53.13707044047695, 55.170372224623165, 52.049220685035955, 50.27843136941233, 53.688088924654075, 53.848117705314394, 54.007212961873705, 54.36839657445108, 57.54368466715659, 55.978380480120265, 57.15900605724704, 53.439489103132686, 50.12206608249296, 53.636368551561915, 58.19440195637365, 58.00851691153742, 53.951358410619925, 49.23899542900824, 52.10018796305503, 56.48187552728961, 57.55797778406451, 57.261419142446215, 56.28113646661082, 59.63968161613711, 58.24520449484549, 46.07286607065509, 40.830296701000584, 42.50356412702992, 42.68635442180019, 44.679942207951704, 55.94457357160507, 56.63389482805806, 57.22510976176108, 59.31058299156928, 58.89783197833646, 55.36376076359903, 57.203634785067656, 54.33775894103512, 59.72922932717108, 54.005553799290816, 58.50469281596523, 53.142922616774044, 57.672177591631495, 27.491749371251753, 30.504380695281494, 61.668762929977916, 44.96773435223488, 53.11739975406278, 49.878180949918686, 51.21432458200763, 47.08577894395398, 48.274272795646425, 43.96374094870783, 51.99152261980119, 56.25593916062386, 58.02866220474244, 51.930078691051854, 43.71377614236648, 43.31147824564288, 42.00014752726401, 42.91563657022292, 53.1811539588436, 55.39756374974405, 58.737603156797356, 59.25039422127509, 58.34052593477311, 54.3629248680607, 50.484626447000814, 51.08297617204728, 51.57129556901994, 47.3932300075408, 49.26272969092093, 48.17391895478772, 51.748778896947066, 50.90574779818135, 57.33807794509396, 59.20275311316214, 59.39773805679814, 56.493811299723966, 58.45976991038169, 55.629238543971894, 58.81821963094897, 58.181654253313624, 56.84091360338273, 54.707740429909, 52.148966558517955, 50.31770213957756, 53.19213659532609, 55.48493454533239, 56.81467686930011, 58.471984171098285, 62.633073714471635, 65.29184449103572, 64.03339516732001, 51.16056849879604, 30.442817134241906, 17.641838481349332, 17.15451732758553, 19.05120295862998, 15.654374495629343, 5.156695938879444, 6.53485550995796, 3.4031952052347125, 0.17981784298054634, 9.88553777817757, 46.61110939518098, 53.66992835075625, 39.40773933164535, 34.846615099137836, 40.806723256264966, 58.0228296402962, 57.51434926063784, 65.2991714785176, 28.345816058497277, 0.7876067824902073, 0.22064709645365516, 0.11097812439284979, 0.13663611735307402, 0.19587581196138937, 0.1477948621275925, 0.2928833501233209, 0.240021322162882, 0.31139148279063167, 0.13800827275601127, 0.18960974900232208, 0.08638169180842177, 0.08423782539583984, 0.18104628028888858, 0.09300419249601903, 0.2159253901411449, 0.134467322439436, 0.16330055832382173], [0.06054948279333692, 0.0921546929185429, 0.018204930388639053, 0.045405552467151035, 0.02333832086033879, 0.061594920848766645, 0.0424441744783713, 0.03265708714963929, 0.02697070951633636, 0.011864007232830891, 0.030182345447340803, 0.07010181779943167, 0.05409954724112346, 0.05162240959884179, 0.02180086475075974, 0.0856998658949329, 0.05285499910373361, 1.7433057581224751, 17.20905004009124, 38.40953142412248, 56.16794078580795, 42.314239163552564, 34.27202709259526, 37.53832594040902, 37.72918062825357, 29.491140304073213, 43.42112810380998, 3.135417199903919, 0.23947546919507368, 0.48653263478509845, 17.94734404933068, 8.814034500429708, 5.703628293929562, 8.283389787520132, 7.007180952256726, 2.2423241551845305, 11.40422361512338, 46.80368600353118, 54.408165485628196, 59.08248147656841, 57.772068592809866, 55.88281193087178, 57.18279523234214, 58.69151530727264, 56.17020399339738, 55.22119045257569, 55.974458109947946, 52.7985659722359, 51.10746352903305, 51.948027456960375, 55.09074418775497, 52.942815057693, 52.51532769972279, 49.99835060488794, 46.91244548366916, 43.54091728887251, 40.80931986531904, 43.09071548523442, 50.613217430730025, 55.572607363424, 53.41133040766562, 50.63370004776986, 52.79943281604398, 51.55678279938237, 51.036743194826194, 48.979036423467825, 51.40655602178266, 53.98901316427416, 53.315106822598366, 38.010861719808275, 38.9864218619562, 37.847785257524066, 40.07519337438768, 47.238351298916726, 53.11481491211922, 47.96721789144701, 49.62095191401821, 53.31887229796379, 51.8626727596406, 49.61036151455295, 50.77365806025844, 48.37686630987352, 52.74914018569454, 46.69167095615018, 50.30216170895485, 46.26839230137487, 55.89818369957709, 25.882345976368075, 23.679633102109356, 50.974181390577755, 44.34287332719372, 50.66781682352866, 47.73615106459587, 50.27110438193045, 48.153059790211344, 49.14556457150368, 46.672984784649266, 47.86279263034944, 48.4078138105331, 54.154741148794855, 52.35828776513377, 41.053538399357954, 39.61132211069907, 40.63665713033369, 38.1986177352167, 42.728814078915505, 50.0882395621269, 50.62594552193919, 52.51785762848393, 52.42200274621287, 52.23770626129643, 48.52471220877863, 41.926261840328095, 46.75006720327562, 52.088193355068086, 55.451202161850475, 52.025149099288456, 51.92481879265078, 49.29685431142008, 55.09998136951078, 50.86745762055921, 49.7996158753672, 46.639483821007516, 46.86493773614207, 49.854968363238925, 52.67228134216801, 50.299227776065955, 53.13840404633553, 53.87926524685275, 53.329921614739206, 50.871081890598425, 53.83277339320029, 52.93922216661515, 54.574199415022335, 50.30424056514617, 49.78416565925845, 45.51812133481426, 51.912855563625214, 51.80079344780215, 37.31784166828279, 12.382019508269526, 8.517421926221541, 6.275349538172446, 5.256659013609733, 4.926312585030833, 12.837953855914455, 1.7581529098172344, 0.03842811558335539, 1.6906805432611898, 26.40073230189662, 28.75529777619147, 32.82684156971593, 30.245310106585105, 24.18137484981168, 39.24894609758931, 47.66277136341218, 49.7184738036125, 21.49982490847188, 1.207136877121464, 0.06869547955331302, 0.03794086834175452, 0.004533855329012318, 0.1669969478802335, 0.08119426532498292, 0.05909476992523959, 0.04891109419986606, 0.08871023903691, 0.08239497025046619, 0.028783116497159488, 0.05162698314374974, 0.028960054079371116, 0.06689095178679114, 0.04364653798421064, 0.0919740187424806, 0.024362810241479068, 0.043326075744604876, 0.05586239216368526, 0.04575957318827991, 0.04743781902136342, 0.04805767225221761, 0.04311186606965719, 0.016069561806357196, 0.05162613278615379, 0.03773086831995076, 0.04756164564300449, 0.04498759404786172, 0.08711750393793469, 0.09777445346117021, 0.048810675394751375, 0.06849088045137544, 0.017091122816406915, 0.027245060923779686, 0.042276255666248264, 2.36982619089465, 22.699950548910326, 47.826730358985166, 61.45750799486714, 47.953167961489775, 40.156284455330145, 46.033026556814875, 39.61491107940674, 27.232914124765706, 42.97249524824081, 4.0923490255109725, 0.07104013761084887, 0.54571409138941, 15.966507888609364, 9.229836137064042, 7.9807352923577835, 10.859654488102084, 10.405210641122634, 4.28445347855168, 12.293586730957033, 45.331310610617365, 55.51460727568596, 58.03274146972164, 60.167389454380164, 57.50753218127836, 58.56703496748402, 60.69626615893457, 56.77311151258407, 56.345502561138524, 55.32965575495074, 51.978849441774436, 50.382452626382154, 52.9816072986972, 57.44140102017311, 54.75215734974031, 54.92707152520457, 52.46115584527293, 49.546787738800056, 44.79791533562445, 42.654277278530984, 44.862053932682166, 54.09437979421308, 56.430484633291925, 53.78873302090553, 50.53514265245008, 53.02600068430747, 51.475024915510616, 51.88915268067391, 48.53798550944175, 53.258663915818744, 55.83002859546293, 54.51123752901631, 40.065928736040675, 40.45455717271374, 37.87228830399052, 41.61443733399914, 48.11089038848878, 57.078181697476296, 48.07847592138475, 50.8320660744944, 54.33891996260613, 51.6550499393094, 49.26586758705878, 50.88702632534889, 47.599656504969445, 54.1798129389363, 47.8359636183708, 52.091884305400235, 45.4574187340275, 54.989774534779215, 27.603005440004413, 26.748303328790975, 55.68119033690422, 47.761034580969046, 54.95209232453377, 51.27379555856028, 53.26022109677715, 51.55500204332414, 51.41462825959729, 48.37825482891452, 47.522797661442915, 48.935019585394095, 55.64593215142527, 53.04432599775253, 43.92817681835544, 40.95042713226811, 42.78982654694588, 39.02973267339891, 45.03314379722842, 51.46296362723074, 53.987550120199884, 54.39954019361927, 53.9540256223371, 53.028930694826194, 49.23529663393575, 45.85268382103213, 48.765812458530554, 52.31747158112065, 54.97783876234486, 52.25440379111998, 51.271289164020175, 50.52741558321061, 56.86407912162043, 52.27169359883955, 52.623090897836995, 49.227416592259566, 50.311316520937034, 52.40266938363352, 54.358339617329264, 52.683311047092566, 54.214949530939904, 55.02220076899375, 53.586613285926084, 51.3071317826548, 53.575414919084125, 52.919806434262185, 55.448095644674, 53.72917182983891, 52.474546817041215, 48.615216978134654, 51.45124358515586, 51.22608384778423, 37.4977921670483, 13.385589295817962, 7.063440488230798, 7.536735736554669, 9.269938449705801, 7.09945422026419, 12.769968394310245, 2.1609268842204927, 0.11463676879723227, 1.8279220692573057, 32.168852206199404, 32.823705634763165, 37.35606124324184, 30.750117186577093, 27.553316854661514, 45.02428316300915, 53.52971930657664, 57.2689736273981, 28.092370148627992, 1.6155004741684085, 0.0396650143328213, 0.008696643522970619, 0.0523843874614085, 0.10392714306832322, 0.04544195696531285, 0.0838012855139471, 0.02097746961930346, 0.07555090161340852, 0.05212661036620698, 0.029468797748127294, 0.1182998258680586, 0.03509495895536196, 0.017455665755175778, 0.03469489251954421, 0.06183585550095286, 0.04784957595890568, 0.02221424196426186, 0.20665155873904306, 0.2827449425333931, 0.12238133548488542, 0.21907614123436714, 0.12875558538061957, 0.12644085071740613, 0.1151422106270348, 0.19566866178666392, 0.13316575437784195, 0.1914881965926578, 0.14266941215722792, 0.2084475905904847, 0.17905167844747344, 0.18607760869687606, 0.11391118394150851, 0.1926913376777403, 0.2748258303730719, 3.5666509116849596, 32.45641293064241, 58.1895068383986, 70.84457920443627, 54.490358752589074, 46.23630731336532, 49.57858639378702, 47.156660095337905, 41.1545668878863, 53.04792281120054, 4.435490225591968, 0.46867267378876293, 0.7015114926522779, 20.83658153010953, 14.515663366163931, 15.549802145650311, 18.052298830401515, 17.990374411306075, 8.908819556236267, 15.792698840941153, 49.200983739668324, 56.48249918414701, 60.43505199493901, 61.74092669640819, 60.151625448657626, 59.42829724281066, 63.70304138429704, 57.7366574348942, 57.70114821772422, 55.79583337230068, 52.422614635959754, 51.001281046098285, 54.787125279826505, 58.760498031493164, 57.91634905722834, 56.8473502128355, 55.722030055138376, 51.38627344562162, 47.72766697791315, 45.00704434610183, 47.009222122930716, 53.96297647107033, 59.72474213569396, 56.17582867222448, 51.74030657737486, 55.0000629117412, 52.33034480002619, 52.42372858908869, 49.83476423448133, 53.78204145739156, 59.32932799862277, 57.66104590508246, 42.31256823385916, 42.60139980623799, 40.197661538277906, 44.4704915631202, 51.91905290849748, 58.565728818216634, 50.40918357910649, 51.91756633020217, 54.15897338621078, 52.2544430148217, 49.56083766875729, 50.600093180133456, 47.897046689064275, 53.32575605761621, 48.42184412863947, 51.37337669249504, 48.049924988900464, 56.089767948273696, 29.806304708603893, 29.589740845464892, 56.089967989152484, 51.55153466809181, 56.30161908365066, 53.02034854888917, 55.61958166860766, 53.40745510593538, 52.955296039581306, 50.14682800539079, 49.992761227392386, 49.61369160682925, 58.41820847603583, 55.876512604375044, 47.61698945876091, 43.51669665305845, 45.42764009967927, 41.77730198829405, 47.05206224995275, 53.61504262493503, 56.339791590167636, 57.84629552595077, 56.20593286329701, 54.024777335505334, 49.83971426563878, 47.75506473356678, 50.58808680503599, 54.845654887537805, 58.17881445730887, 51.71301080334572, 53.04038793809953, 51.39286302751111, 59.931164710752434, 55.51576829725697, 54.926377265684074, 50.347394481782, 52.342531604151574, 55.55290137567828, 56.64809773045202, 55.830977809044626, 56.357050018925825, 57.66491336207236, 55.30502719263877, 52.13894098035751, 55.36692219395792, 53.0319901435606, 57.33446936453543, 54.01756409675845, 55.02307153517201, 48.657935511681345, 53.811282727026175, 52.501842591070364, 41.426642094889, 16.05977204538161, 12.65216883151762, 12.330549186275853, 14.819515655117652, 13.654478557648199, 16.336568805479235, 2.639854410963674, 0.20456306516162812, 2.250236801562771, 38.61198063819639, 41.00773296048565, 43.8426338472674, 39.90889272382183, 34.964321505638864, 53.743500248078384, 62.63102623724169, 65.65222794009794, 35.70166041774135, 3.0265447064753506, 0.1714609728585328, 0.1274353783998278, 0.1213598108640121, 0.22538755659855184, 0.19146270118653777, 0.25765338732350257, 0.1365996362461198, 0.17772354245666536, 0.15387471975578418, 0.19816446899166032, 0.1817574703525151, 0.09935847814044646, 0.16970978779417856, 0.14745217567730337, 0.14179175118765525, 0.18165884419314324, 0.1502260115117796], [0.03206405465701415, 0.08393597143191485, 0.13134096358572284, 0.02052833716715536, 0.0370739747379576, 0.04073420877478296, 0.024593280132619605, 0.16687172314813062, 0.032037346916753924, 0.060679047413530855, 0.04898161259329608, 0.10934418908530667, 0.017730118669269067, 0.012944805991625594, 0.02165799701376067, 0.03426360033993279, 0.01168708018432822, 4.059658766754212, 27.736377792973673, 49.63058917753158, 43.968506628467196, 41.065536929715066, 25.68876720243885, 10.246915548078476, 26.36537801834845, 43.46857701578448, 31.717971832521503, 0.8037178566859615, 0.1854336045442089, 3.348969908491258, 6.11109979691044, 3.301466328482474, 7.624363447389296, 4.178961332767241, 8.967903198734406, 3.793778943438684, 22.62174633241469, 43.67389348245437, 56.97170503677861, 58.291280577259684, 54.87460982414984, 53.834530615037494, 53.89859468706193, 54.19219193920013, 56.58553984857375, 53.96906398957776, 49.99539313777801, 53.822743892669685, 51.90239460237565, 53.02309028563961, 53.20623359372539, 50.984167745036466, 50.091832453204745, 45.45266874374882, 45.143154513451364, 40.88857919939103, 41.54009665212324, 38.438149036899695, 46.54475073660574, 52.828399519766535, 56.35492017192226, 52.515872909176736, 54.28687011041949, 52.2242642987159, 50.983438184184415, 53.18670411263743, 53.4687303727673, 54.543106786666385, 41.97640934298116, 36.97085311335903, 37.116729982437626, 37.966131010363185, 41.99975529024678, 49.6993169476909, 54.16842629832607, 48.38151431852772, 48.73294299648654, 47.784251090018984, 51.54345850790701, 52.11041750446443, 53.67319960747996, 47.51084227715769, 48.84560915731615, 43.691602983782374, 48.30667549563993, 42.37646756633636, 52.17140643827377, 26.421828769868423, 29.002199211428245, 59.1806976256832, 45.48517734773698, 53.89162463526572, 48.07003498077393, 53.81860579213789, 51.12672628894929, 53.924223453767844, 49.40940280114451, 48.92004789844636, 46.862623537740404, 53.34980803151285, 51.74533505593577, 42.88438704706008, 38.58623027801514, 38.10790900261172, 38.33255883186094, 39.70657294796359, 41.98994152007565, 54.259574336390344, 53.588339128801906, 54.84783964772379, 53.30334755682176, 51.968282576530214, 50.67806597678892, 55.56331526848578, 52.58262772713938, 52.60717391967774, 51.92180641235844, 54.58693927334201, 51.95660568052723, 53.91907730410176, 48.663689628724136, 43.44937701379099, 41.1540412902832, 46.14157422896355, 46.31181293918241, 51.25354043899044, 51.473263771303245, 52.85762509992046, 52.55541824525403, 54.00829161367109, 52.500022611310406, 53.393711120851584, 51.96068102313627, 53.87499378573511, 44.79400081019248, 53.60762150056901, 42.58510235817202, 33.97184418093774, 26.96153513846859, 30.72280768425234, 19.081834708490682, 10.72155567907518, 5.554504682940822, 4.641561748520021, 3.373744579092149, 4.33052759978079, 0.49415539349279103, 0.019924527732655406, 1.0160525467607284, 19.355425911564982, 30.312237508835334, 29.684211131065126, 32.77037512871527, 22.485553795291533, 42.93983367181594, 41.70042353291666, 51.216913346321356, 35.461136756404755, 4.418611286147948, 0.0476105067308151, 0.0865659665977282, 0.0751627784883303, 0.0599663864610897, 0.12034500483423473, 0.04081751700610884, 0.09011876063361283, 0.050225490403752175, 0.016855681014637795, 0.02424626337033847, 0.059723172697328755, 0.03671385595695146, 0.05158838380368487, 0.04179340576933276, 0.01132094665550657, 0.036323825272941784, 0.023125210521562446, 0.07718682874955478, 0.11583387310947142, 0.01768950643318315, 0.059503293971741394, 0.07515845775243736, 0.0401198560552251, 0.024002612936460686, 0.11727744322871009, 0.034175745376776305, 0.06127632786369613, 0.03517323398902532, 0.12089402174517033, 0.02230400065591018, 0.06981948375581734, 0.011793997330260615, 0.026501432782219305, 0.02081732085395244, 5.146427664064593, 33.66321248392905, 56.36632250201318, 52.332690377389234, 45.7821439158532, 31.032176786853423, 19.150954715667233, 31.07452661760392, 39.53939760884931, 33.51855939434421, 1.2569884859746503, 0.308447161749486, 4.7111372409328345, 8.381528469824023, 6.229710309736191, 9.980139463178574, 11.793229579925539, 9.60123360157013, 3.4739417702920976, 23.78821607558958, 44.10832735799974, 59.40309993682369, 56.692969645223315, 59.09248744287799, 56.275507865413545, 56.613773069074085, 56.33147616540232, 59.62160733438308, 54.905820123610965, 51.34075826214206, 53.983788567204634, 51.957531359887895, 54.2407940280053, 55.545193918289684, 53.52993111456595, 54.26189637953236, 47.39993726053546, 48.065061415395434, 44.99628136234899, 43.675838978059836, 39.705392314541726, 49.16340743341754, 54.67192919023576, 58.19027562295237, 55.681594341031975, 55.818387000791496, 53.753784702670195, 54.865815870223514, 53.806415065642334, 54.795950612714215, 56.534282315161924, 45.515850282484486, 38.90181241496917, 39.45701999049033, 38.95888290097637, 43.541831201122655, 51.7276490888288, 57.44435064254269, 49.02426135155463, 49.47605955985285, 48.18760410431893, 52.78121340659357, 51.54518042841266, 54.575678148577296, 47.88056881197038, 49.11988873635569, 44.33094147712954, 48.80964886757636, 43.997602770405436, 53.57173573586249, 27.672262730136996, 29.357101148174657, 58.63194627146567, 48.86786860804404, 57.26026596561555, 50.38336261626213, 56.527222048851755, 53.268556133393325, 56.223320730270885, 50.88045243294009, 49.60014766262424, 47.715397804014145, 55.79361723315332, 53.684986329847774, 44.634787882528, 40.15725328076271, 39.86742150398993, 39.882016643401116, 43.12968815526655, 46.88922112987888, 55.52315412029144, 55.71653481452696, 58.522763175349084, 54.91718323000016, 54.611552146173295, 53.403234635629964, 56.280638325598936, 55.77795128668509, 53.97752061966927, 54.136929665842366, 55.558816309898134, 53.701585800417014, 56.27589225769044, 51.292277766812234, 47.12652844767417, 43.73173667538551, 47.330919234983384, 48.29995255316458, 53.6513049371781, 53.42132068449452, 53.272019586255475, 54.97128055941675, 56.58745396521784, 54.50585995951007, 52.32047219430247, 52.843535946261504, 54.5745288941168, 47.46743732883085, 55.47792134746429, 46.77531157770465, 36.571865697060865, 28.963634467894032, 28.757790442435976, 18.38861853845658, 8.040917198504172, 5.536343618746727, 7.348221723110446, 7.168271224344931, 9.970391392707825, 0.544805878833417, 0.047561220464206515, 0.6226388797644646, 23.058714059091386, 34.70211498198971, 34.54654201384514, 37.25165559399513, 31.319237409099458, 47.54130732628607, 48.5464931303455, 56.52134241596345, 41.376996655617994, 5.818224751180218, 0.04238039382823533, 0.11722551778920236, 0.11284645196170577, 0.0526794960211602, 0.07332713223032414, 0.041681886350195256, 0.060321353300805056, 0.026368560577412287, 0.02986281975022247, 0.035111816720135754, 0.009855406092209442, 0.011201468540445693, 0.022887819026026036, 0.013228541976141353, 0.06573585973631951, 0.023668698192904555, 0.06852064296723374, 0.20293276877172534, 0.16145866844923268, 0.2160444095610611, 0.1317640279810275, 0.13365022838115692, 0.14509605694442027, 0.160035323051195, 0.3346390030797451, 0.11463292303585237, 0.23300297618392976, 0.16638887325121512, 0.28272392108075084, 0.11936985151541811, 0.16124747333026704, 0.10794762612110186, 0.2247419436612437, 0.1488965272062248, 6.144360515379137, 41.87604373501193, 64.87005633692588, 56.221128125344556, 52.04856957158735, 36.02934698904715, 21.425992173533288, 37.01401487473519, 56.96922609882971, 38.71184418278356, 1.7160993405888159, 0.47809809866932135, 5.606281440104208, 10.366661587069112, 8.337891121064464, 18.0580392191487, 13.250597984560075, 16.80253951780258, 11.932468818080041, 31.280317691064653, 46.70909804682578, 59.08349344807287, 59.27242617453299, 59.732951656464614, 57.31266098637735, 58.20558071136475, 58.33024540255147, 60.85515745224492, 56.98258176926644, 52.251944465021936, 52.47200119879938, 52.033872450551684, 55.01503459868893, 57.69008713383829, 55.56653945676742, 56.38015277924077, 48.9876970168083, 50.73615627904093, 46.198436829351614, 46.32250924264231, 41.113742859132834, 49.88521375963765, 56.7400106306999, 60.55695925989459, 56.860925536001886, 58.672248624986224, 55.56747298086844, 56.30799685755084, 56.32735767672139, 59.24868799025013, 59.409261980364406, 46.151152656924346, 40.11815509488506, 40.52893707829137, 41.32756302433629, 46.19358877981863, 53.84184191303869, 58.57486401834796, 50.776360573307166, 48.06901124215896, 50.313791536515765, 52.44795706964309, 55.90029785709997, 56.03003025054932, 50.685757744696836, 48.77248833256383, 45.24555583154002, 47.80977395273025, 45.107339351407944, 54.05309292577929, 30.479779589560728, 33.26889268813595, 59.293846238044004, 50.33496056833575, 58.073510585292695, 53.90470966216057, 59.572409045311716, 56.57469057267713, 58.91500019258069, 53.038112963399584, 51.445646362919966, 49.1571081069208, 57.31739528717534, 55.706379798150834, 47.169533314243445, 42.12087023642756, 42.677948782520915, 42.37675782172911, 46.49082991384691, 47.311766301431966, 58.93572599657121, 59.79075170332386, 59.822624883344105, 58.60756481847456, 55.806145283483694, 54.098670867181596, 58.14402303388042, 56.97587451627178, 55.51973773587135, 55.64619887259699, 59.400189538155836, 56.54485702514649, 57.956039521002005, 53.70630441173431, 47.84422805232387, 45.449009172378055, 50.50238693914106, 50.01222795055759, 56.48023205418741, 55.578153594847656, 56.14698748434744, 57.70716513356855, 57.95187788624918, 55.306807948697, 53.20443714818647, 51.728990539427734, 54.68590067278955, 48.27855994624477, 57.71090315234277, 47.67393442892259, 39.932681898916925, 31.222384283619544, 34.80149215267551, 22.191283856668782, 17.61456428035613, 16.0376989072369, 10.969089596502243, 8.211939402164953, 8.632044369174588, 1.8933604417308685, 0.13003816978344995, 1.4188226600808482, 26.5549010615195, 44.925466891258, 39.8617026882787, 45.25469495404152, 33.82369233715919, 54.451562589214696, 56.023825060936716, 65.12395528055006, 49.064344052345525, 10.00454346979818, 0.3018392856803633, 0.1980213790891632, 0.24366911110137743, 0.19924289096266995, 0.23733146488666537, 0.23883623010929556, 0.26271508345680855, 0.13819155163101612, 0.21234042041244047, 0.10304014348695356, 0.09296088554565946, 0.11620028530277553, 0.14115104121306252, 0.19002127611348707, 0.14205078083661296, 0.19198080644972865, 0.1790634455579904], [0.05146197163529935, 0.01993056833593836, 0.03250724035165003, 0.022914427174856106, 0.03602291742760328, 0.022175027838637753, 0.025701625497951627, 0.04438134270810312, 0.08047518455573628, 0.02456791304622687, 0.04632573514696091, 0.10514383624878623, 0.054967436759221944, 0.035027095056589574, 0.046669287276604486, 0.019951783225781495, 0.009140572322893047, 2.9344364231632603, 31.481086169519735, 48.625395528731815, 42.310563902701105, 41.02638383065501, 22.332377395322247, 24.015921431203044, 35.82829806112474, 42.41260044036373, 21.155342748088223, 0.2780842474631725, 1.985170012039523, 10.157174660313515, 0.530166183748553, 5.655351271552425, 5.454404815550774, 13.043683152044974, 7.855844084293612, 11.429126743347416, 40.545524781750096, 58.217257607367735, 64.13017572895174, 56.760465791148526, 55.82303893181586, 52.10584402084351, 54.44685182263775, 52.09497513309602, 55.342756471326275, 57.04846974342101, 51.87833086136849, 50.29951018671836, 55.01863533450712, 52.235435208966656, 53.36115152605119, 48.80463607849614, 45.19982099533082, 42.406960072055945, 41.26637797201834, 38.69843359916441, 40.00441420462824, 36.031598429526056, 40.034212450827326, 45.61355652347688, 48.62102208598968, 49.767750540087306, 51.26094587387578, 52.834781216036895, 55.18738746643067, 51.902763305171845, 53.79789567762806, 46.951049450905096, 38.29645733679495, 36.79759417810748, 37.63736970963017, 38.91342263067923, 43.03936773730863, 51.552562329076956, 51.774741065117624, 49.74564013942596, 55.530465418292636, 52.279008819210915, 53.78459884274391, 50.87934240218132, 55.55902811788744, 50.94386146914575, 51.70502093530471, 45.01057055688674, 51.79396852370232, 40.74091765188402, 51.468898173301454, 28.757917919466575, 32.386818316675004, 60.55144832980249, 48.0219937909034, 51.77675716338619, 47.73599809215915, 51.306480669206195, 49.852242315969164, 52.771634978632775, 51.77865166817942, 52.873126306841456, 49.542869290997906, 54.804807324563306, 50.27540722200948, 43.65132024211269, 37.82503158815446, 39.18880831810736, 37.038137451294936, 38.97446255530081, 38.293511636795536, 42.497617813848684, 47.74123445633919, 51.56332531282979, 51.27069296375398, 52.08679699128675, 53.065228308400805, 52.10200402044481, 51.26197353486092, 53.162644294000444, 51.27692560995779, 53.26255882939985, 52.742750644683845, 49.84498200878021, 43.347622886780776, 39.985881005564046, 39.05280405475248, 40.516071704126176, 43.8648070058515, 45.08156153463548, 46.88153328434114, 51.13099382769678, 49.93744011848204, 54.094909314186346, 55.66031940521733, 55.57068147966939, 49.961456791047134, 51.554594116826216, 49.904813843388716, 49.26536552367672, 51.65039800828504, 47.66346954530286, 32.723412590642134, 21.96187815358562, 18.994446262236565, 6.875480999869685, 4.493946288862537, 8.522200353683965, 11.178640261773142, 29.263323160909838, 16.421793083990774, 0.28392450343216624, 0.08066461511677311, 9.154188325328212, 31.850442040351133, 37.948896115826024, 21.706170997311993, 13.126547144305322, 25.74100728957884, 44.60297353806035, 51.141466556056855, 44.96507890762822, 8.841978446129831, 0.13888519828117665, 0.06589715954877677, 0.01704793077923598, 0.035263471485626315, 0.09640525515762069, 0.03523555524166554, 0.023477714388601245, 0.029702173027720664, 0.040746148255082874, 0.02355080492223703, 0.013376633475174107, 0.03872153874967368, 0.052756016713476954, 0.04621467921101759, 0.07454987750538895, 0.03793757799411974, 0.004824533506536916, 0.04258094415549309, 0.04996129349174519, 0.08209582823779314, 0.021129275687159072, 0.027486859340100523, 0.06125416110960707, 0.07312938961530886, 0.028714601423651464, 0.03455737207625662, 0.026130726666099606, 0.04617676168920533, 0.09109563765025909, 0.059139532442655296, 0.035258744723133506, 0.10495445165302485, 0.019600168020734866, 0.03816984053100309, 4.034184198225699, 37.305674476008264, 56.63713862819057, 48.25119749192269, 46.82763599580335, 26.922956666638775, 21.54720517896837, 38.75400966213596, 43.94976162141369, 23.67271011875522, 0.20119600148210603, 1.9183601583203964, 10.639893893272648, 1.7075713723897936, 7.277910786290323, 8.86777783593824, 11.504647078052646, 4.946390707646647, 10.222639999082013, 40.09255770714053, 58.01482800514468, 62.89408783758841, 57.918102356695364, 57.3417139822437, 54.276526820275095, 55.72738409042359, 54.09601150020477, 56.61809944337415, 57.54560662854103, 52.41680168336438, 50.34850059017059, 53.87910835204586, 52.77571032124182, 54.45770894327472, 50.61349984138243, 47.56079758367231, 44.304500779797955, 43.394887447357185, 41.271735929673724, 41.184306298532796, 38.74847912019299, 42.64824075083579, 48.79612845759238, 50.30132624410814, 52.00884380648213, 54.388914492822465, 54.61616093112577, 57.40652722697104, 55.40384346438993, 56.07841660899501, 49.18642390158869, 40.439573718655495, 39.3231612636197, 39.550572441470244, 40.82705682323825, 45.096639125577866, 53.95870893232284, 55.32481555015811, 51.67166117698916, 55.127430115976644, 54.32304613051876, 56.42177304913921, 53.53122549672281, 56.83293942482241, 52.18821771683232, 53.58910399098551, 46.6101013460467, 52.090460485027684, 43.522893997930716, 52.25197584398332, 29.957443437268658, 34.91296199060256, 62.6012436805233, 47.62041761029152, 53.797358312914454, 50.09920258675852, 53.576038575941524, 52.21881220417639, 55.38248223643149, 52.353455405081476, 55.26469738252702, 50.526274173490464, 56.665689560674856, 51.16816220744964, 46.30965171321746, 40.42966581160023, 41.87979352089667, 39.62027688180247, 41.377384970265055, 40.49514585925687, 44.858668927223455, 50.35653752665366, 55.72381473356678, 53.9946182312504, 54.20447288020965, 56.038031885700846, 54.810208428290586, 53.254651331132465, 53.79888803728166, 52.78083685905703, 55.85246455284857, 54.45238628695088, 52.655234721399125, 47.05301146353445, 42.493263982957416, 40.779607911263746, 43.7523526530112, 45.84147368707965, 48.24019132121917, 49.742274745818115, 51.93743313512495, 52.054590409801854, 55.990147590637214, 56.385181257801676, 55.99829043111494, 50.39591420081354, 51.918629292518865, 50.015812996895086, 53.019870019728145, 52.57164901302707, 50.05207530913815, 36.81055761152698, 25.658764992990804, 17.082561446774392, 7.371393615199675, 11.87857251013479, 13.456915636216442, 3.068188020298558, 30.063584735316617, 19.370887894784254, 0.12061266063321983, 0.11279331610327768, 11.854036123521867, 35.73123901121078, 37.301104914757516, 24.11613210555046, 16.383308749045096, 32.381130879925145, 49.954910355229536, 57.58677974823983, 52.20525649286086, 12.488189243501234, 0.22986080527545946, 0.07683045230805874, 0.040687864285803614, 0.04753625365875421, 0.0338351771595978, 0.047493069282462524, 0.020300740105730873, 0.022791512197844928, 0.07880746477073239, 0.03958622218980905, 0.016350633720116272, 0.03543414438383714, 0.05131354976084925, 0.12986164780393725, 0.022022587833024805, 0.06707025466546898, 0.023418557079088305, 0.2234772857158415, 0.13563421224394154, 0.12680402235879054, 0.13439235307516592, 0.07324427982131321, 0.2684285978396093, 0.20269906598954432, 0.14242817106987202, 0.18470022857429522, 0.07233796716337243, 0.1125075346640041, 0.19455630212060868, 0.11838461647951797, 0.09984315898750099, 0.1358315564932362, 0.19665294687353796, 0.0873135534986373, 6.425517480219565, 43.712305253551854, 62.4068235581921, 55.5209066021827, 52.622306423802534, 32.373270450099824, 36.154992272776944, 47.848036673761186, 52.30978373558291, 28.230280683886622, 0.5491170539490638, 2.374754649016165, 12.610636814948052, 3.4350406835156106, 16.325552828850284, 15.902384981032341, 23.87481612543906, 16.338196589100747, 16.07704028006523, 44.89133834838868, 60.18841728087395, 66.36923328522714, 60.289579129988155, 60.6849697328383, 56.089379633626635, 59.36750050513976, 55.962577250696, 58.56794103499382, 59.759498257790845, 52.788018718842544, 50.11287596917922, 53.99023694376792, 53.68557076300345, 56.115816408588046, 54.03757210700743, 49.579343411230276, 48.66155585935039, 44.81413041391681, 42.69769399396835, 44.75209812964163, 40.28695037288051, 45.7023040709957, 50.684530042832904, 50.76260874348303, 53.55654439618511, 55.29658625202795, 58.13928481071227, 60.84665375371134, 57.23309962980209, 57.76575357683244, 50.88721067674699, 43.304237550304784, 41.652366653565444, 42.11996809128792, 42.16425165053337, 48.13409513042819, 55.727093835030836, 59.72702103276407, 53.41941441259077, 56.91144566382132, 56.082068335625436, 58.18263092348653, 57.48729275118921, 58.891160026673354, 53.81269478028821, 53.64808859363679, 47.28958529810752, 52.969808809218875, 44.24442575823876, 52.00189728890696, 31.939460231411843, 38.43958854675293, 64.97565830907514, 51.13448473715013, 57.0767931784353, 52.36795640760853, 56.03807895414291, 55.8689385075723, 57.054129723579656, 55.27655078518776, 59.007917219592684, 52.98896958751064, 58.81561909952472, 55.60001688618814, 47.487676758919996, 41.284111007567375, 44.3420692413084, 41.83920091198337, 43.739044051016535, 42.94429340670186, 48.010375730453006, 52.91496230709938, 57.24877734338084, 56.70749025960123, 57.30760897359541, 59.94170411940544, 57.18084973673667, 56.291993587247795, 56.27351137899584, 55.83734773820447, 58.29972544024068, 57.7128682597991, 55.08115007031349, 49.179963757914884, 44.28871323985439, 43.70171093171643, 45.81184410279798, 48.85834509326566, 49.071031693489324, 52.355738224521765, 53.81899018441477, 53.68745742305633, 58.320000171661384, 59.96251621553975, 55.97427768092002, 50.13396655359576, 50.928611293915786, 51.659713637444284, 54.35822194622409, 56.411496439287745, 52.35194921493531, 42.59602615910192, 28.59275475625069, 22.451642943966775, 9.10391922919981, 12.933801874037712, 16.002318147690065, 26.021537165487967, 39.401369402485514, 19.394932023940548, 0.6030085202186339, 0.2844714902101025, 13.359692827347788, 44.89480180125083, 47.685909425058675, 31.620253824418594, 21.66041066569667, 38.27341341203259, 59.065764334894, 64.96073761293965, 59.97620136507096, 16.564600698409542, 0.3270342627600316, 0.3040925954138079, 0.15752908172866992, 0.09310536972817876, 0.17668109597457995, 0.13335775133342515, 0.06562931222781059, 0.1159439369615528, 0.16286059402890746, 0.12362979067068909, 0.12927238829433918, 0.12075625615374697, 0.1667075658277158, 0.18782876311771332, 0.14607707849673687, 0.1148045956788044, 0.07292813065672114], [0.026102239686635234, 0.05940495892578076, 0.012695536302823215, 0.04283133233266492, 0.07635703295349114, 0.0735272727005424, 0.047277174214081424, 0.11584826024068941, 0.06222880114951442, 0.046049874546306754, 0.10506418608729878, 0.05764130578045884, 0.058963075580616156, 0.05587695932556545, 0.05128994659190217, 0.04322641536653523, 0.07074193022544346, 5.0544255298952905, 28.67505196602114, 52.22915157195061, 53.34004132978378, 34.59230822901572, 19.572295719577422, 26.861634331364787, 33.81150945540398, 37.9325359098373, 13.551878179273299, 0.27624824114384194, 0.8357185137368018, 1.361116627531667, 2.215935919554003, 6.934829402354456, 7.401380625463302, 9.247924147113677, 6.537229034208483, 22.63130318733954, 54.14708860458867, 55.452359261051306, 57.00868122039303, 57.24729076508553, 56.15049016091132, 50.25773302201302, 53.16406026963265, 52.753607765320815, 56.539342172684215, 53.54516560031522, 53.17219134299986, 48.981440836383456, 51.98034386481009, 50.18563593587568, 54.21933866316273, 49.50933694839478, 42.84526140459123, 38.64442256189162, 39.14832161318871, 40.29242600164106, 43.390168836039884, 40.88967354066911, 38.01672174084572, 39.13557783249886, 42.884398814170595, 45.26945091062977, 48.426758858465384, 45.710960741966005, 47.92399337214809, 45.53817249113514, 43.5335785342801, 37.78365842757687, 38.89182606051045, 36.724724385046194, 39.08250816406743, 37.72352064809492, 42.98605095955634, 52.70195407252158, 49.80830784766905, 52.47908892170076, 52.1772115461288, 49.81023373142366, 52.55009951130037, 48.05709900394563, 52.475170473898615, 49.86091075404998, 52.171630013373594, 46.37067987072853, 51.923999017284764, 42.7025185092803, 48.69220525987687, 29.780721049154963, 31.976114780672138, 60.85436905584028, 47.257465008766424, 51.800212937016646, 41.929556631272845, 45.153454657523866, 44.01097020795269, 50.363589948223485, 49.19307231903077, 52.24997935756561, 52.2834175632846, 53.441148265715576, 47.862851465902025, 40.56400306763188, 37.120330718255815, 39.801113836226925, 41.001033552231334, 41.68426729017689, 38.64314386921544, 38.706623508084206, 38.967896507632354, 42.51941442489625, 46.68632868797549, 48.23113849086147, 49.35338743271367, 46.801438485422445, 44.70799499942411, 44.80031582616991, 46.96156532533708, 46.138730510588616, 44.78847419061969, 41.80213843622516, 40.385448932647705, 38.661394657627234, 38.09505539555704, 41.30185973259711, 41.298498261359434, 42.52265822502875, 44.75401224628572, 46.537651246593846, 48.647164683188166, 52.332298140372004, 52.605761866415705, 48.87669786330193, 53.45112285306377, 53.018254003217145, 57.16079073567545, 57.00473923836985, 54.41826558882191, 58.320141376987586, 53.52486341230331, 44.67565113498319, 26.966908785604662, 10.688016472324248, 6.630466714982064, 8.411191394252162, 19.588746140080115, 18.96639347076416, 8.325038494602326, 1.2250379617175748, 0.08518841027492478, 6.565295063680218, 25.86905110266901, 38.838697556526434, 60.79384296171127, 40.32506796621507, 38.13958606412334, 41.91988406642791, 48.27251165143905, 49.275461704500266, 16.160070973057902, 0.1816650495053299, 0.13160319548220406, 0.02957818169717587, 0.036326334210893804, 0.037327101679458734, 0.017644301499991168, 0.04690024746401657, 0.025579723672220306, 0.07305143250813408, 0.05433500053421144, 0.02162723283794138, 0.022541865210739837, 0.056861508712773366, 0.024811373873343392, 0.05885708348585233, 0.05373272519077986, 0.016593198224361387, 0.05695028681187861, 0.04224722476435765, 0.1035959326151398, 0.06670620202297164, 0.0898369245471493, 0.026196560431872646, 0.030350915434199478, 0.034480617727122964, 0.10384999035346894, 0.03641461435284826, 0.02111406309620267, 0.03656028214121058, 0.02565034740273991, 0.00881775627813993, 0.01030518205821394, 0.02372052404098213, 0.13418514161340653, 6.155356389860954, 35.73288640668316, 57.84694663939938, 57.79482226217947, 40.32947278791859, 22.963894682545817, 30.16045355027722, 36.26927445011754, 43.01870861361104, 16.252351595509438, 0.19113942740424988, 1.140166573947476, 4.027755188365137, 4.12949828370925, 6.285610458543224, 7.0661832055737905, 7.340311283065427, 5.718872585604268, 22.468116898690504, 56.31120143398162, 57.990321036308046, 60.044030912460826, 57.786455846601925, 58.087948829896995, 54.776232857857984, 56.19501690710745, 54.590398803834, 58.33971400414744, 55.660366473659394, 53.496669415504705, 50.454549712519494, 52.73503926492507, 52.723499651878114, 56.76934995958882, 52.11901926225232, 44.87580968487648, 41.64262348605741, 42.46148886219148, 42.50191280918737, 43.93355438786168, 41.52374036850468, 39.48035417064544, 42.31647883692096, 45.392319156277566, 47.78313321451987, 49.917565468818914, 50.39235661106725, 51.53917135730867, 47.46207544880529, 45.631360161689024, 40.79099062950381, 41.008662562216486, 38.54661433927475, 41.190370282819195, 38.62421451076385, 45.2676897664224, 55.82356845178912, 52.16919814386676, 55.95266934364073, 53.73833448656144, 52.89719004784861, 53.686398383109804, 50.55576647481611, 53.765194877501465, 52.281695642778956, 52.40326950626989, 47.67801761627198, 51.813388178425456, 43.92745902461391, 50.62672215123331, 30.50635756984834, 34.28744592974263, 60.672618189165675, 50.43514574727705, 53.58649561482092, 42.730473241498395, 46.4415257207809, 46.988986615211736, 52.943850563418486, 52.27562773612238, 55.009315782977694, 53.97897974137337, 54.820783138275154, 50.236010935998735, 43.30420224897323, 39.60483451043406, 41.09221689162716, 42.99999498551892, 43.54032893334666, 39.64425433066584, 40.75788190287929, 41.39789112152592, 46.5418521050484, 48.33359472213253, 50.72378512351744, 52.63956877493089, 49.11737449707524, 45.88967961649741, 46.682394550692656, 47.64443428285661, 49.98918402579523, 48.216790460771136, 43.92802776828889, 41.42731674255864, 40.29959609431606, 40.737979796624955, 43.193414903456166, 43.85967262329594, 46.50014554300616, 46.38016416180519, 48.60357930583339, 51.82357849613313, 54.676714481845984, 54.7817280984694, 50.91363568459788, 52.953872219208755, 53.55036274079354, 58.22432179604807, 57.36381261579452, 56.33413553237916, 57.46432335146012, 56.063582205003314, 46.763748430436664, 28.578438105121737, 10.857744293828166, 10.259908399274273, 9.449026027033407, 22.792581242899743, 26.688255763822987, 9.803394521436385, 1.2192083390489703, 0.01960919828214232, 7.129726092661581, 32.125931670588834, 40.33507393252465, 50.865539581544944, 34.813690723911414, 40.66068164763912, 48.89380724199357, 55.01667414942096, 56.72248548076999, 20.72891050769437, 0.2865956681630304, 0.02191980181622409, 0.03972741219425394, 0.06216417014178249, 0.06373087740353038, 0.08754685025421843, 0.05526911069248473, 0.05335893940120455, 0.07614784498488711, 0.03231066219027966, 0.03630113757906422, 0.05361554821232154, 0.0694863734045817, 0.019838519041396437, 0.0460116007936097, 0.03773095258962243, 0.04380842002349035, 0.17216375127675074, 0.1445121140850167, 0.16324034381297328, 0.20060467353511244, 0.2199281689019934, 0.10760167613625528, 0.15708268229519168, 0.25450297330896704, 0.22406303654274634, 0.07732772764058844, 0.18977838027621471, 0.24863755901253995, 0.13883780808218066, 0.11497197056850118, 0.12252845500986423, 0.18498636241401398, 0.1938244123612681, 8.66595620109189, 42.94070836036436, 67.5161970815351, 66.2914683741908, 47.52133069499847, 30.948220414500085, 37.82500805393342, 44.13198709487916, 51.884092823151626, 19.77205026534296, 0.33426643920040905, 1.4701731046361308, 3.6853938045040255, 4.046146446658719, 14.535302673616718, 14.734847372578038, 21.794075235243767, 14.422536492347719, 25.745618035716397, 56.88674649884624, 59.550000544517275, 60.599254177462676, 60.678360539097945, 60.985733155281316, 56.20083770444317, 58.01342379662299, 56.82643221270654, 60.496441010505926, 56.056612153207105, 53.464470678760165, 51.66187094103906, 52.415930917186124, 52.09622244681082, 60.178709414697465, 54.00549496373823, 45.529809997927764, 42.81949535492928, 42.360574122398134, 44.32526188512003, 46.685822702223255, 45.11258356032833, 41.63486896022674, 43.66552706687681, 47.35711674536429, 49.79971785699168, 52.41451494155392, 50.27652117513841, 52.498849822628884, 49.919703160562825, 48.28833449271418, 42.66913913911389, 41.81887518975043, 40.18643963721491, 43.49637485319569, 40.251449000450876, 47.41634845733643, 58.88990486821821, 54.41542187044698, 57.85289295258061, 57.91943204018378, 54.182460538802616, 57.02925405194683, 52.06949541645666, 55.29849644630186, 53.24959539598035, 53.41422903922297, 49.50400252496043, 52.20742948593632, 46.06407603909893, 51.28288369024954, 33.88517941198042, 38.35227658671718, 62.7592485181747, 52.75145046172604, 56.17023929472893, 44.687983066804954, 49.4834336157768, 49.844950629818825, 54.053700893156, 54.309647314010135, 56.98388399616365, 56.73751992564048, 56.64375566667127, 51.85859741703157, 45.04596994769189, 41.40839522884738, 42.43598168896091, 46.214765656378965, 45.66392367885959, 41.66986826927432, 42.82746561111943, 43.077300979245095, 47.54601417049285, 50.985148337579545, 52.89897864864719, 54.356088176850356, 51.06043038829681, 48.05096441699613, 49.49863280019453, 50.615994468812026, 51.66473034889468, 49.54497560378044, 46.82975015332622, 44.469016751935406, 42.61919952207997, 43.420614273317405, 46.251706538661836, 46.61946012127785, 49.35037505242133, 50.386606416394635, 51.35263127665366, 54.97967050921533, 57.69205224129462, 56.003820973057906, 51.317361324064194, 56.076078876372314, 56.00714714296403, 60.833105887136156, 60.54203464138893, 59.20311004884782, 60.46264194673108, 58.38333468283377, 51.393784784501605, 31.330367134463405, 12.55286128290238, 11.575038913757572, 11.365465694858182, 25.02405293526188, 22.49490276459725, 10.12853547450035, 1.2186490335772115, 0.09777125887452595, 9.714402806374336, 39.37088474150627, 51.54662386063607, 71.95946585747504, 52.8840579525117, 49.4186282157898, 55.3573045422954, 62.18206782494823, 64.25379706967261, 26.970007458040794, 0.6544035204475926, 0.21719556391960193, 0.22249194342763196, 0.11867399087115643, 0.12799661441315568, 0.18539059636813982, 0.2203462843693072, 0.09386007358590442, 0.2421582937841454, 0.12207688448289711, 0.10987848944721684, 0.1295686957816924, 0.1989091524193364, 0.12263693305994235, 0.09220893194358196, 0.09771162659049996, 0.13902215948027952], [0.07392585292578706, 0.059807105290312926, 0.023172506874787713, 0.06086427598230301, 0.05147741979829246, 0.015479644418754166, 0.014392443080132288, 0.06189753323973668, 0.07674857283071165, 0.010423504338119059, 0.036938476766790115, 0.01389429440736891, 0.046162041309740276, 0.036905580951321515, 0.041562043385760444, 0.021183154650873715, 0.08904000158391653, 6.88807818197435, 37.067845482980054, 49.24803256988526, 50.472980929959206, 41.58051667674896, 29.97259359205923, 26.467973493760635, 38.5080260615195, 38.10721866546139, 10.06471949238931, 0.0491467543366936, 3.090465366840363, 1.8240445611938354, 0.5798097844085386, 5.3696600467927995, 5.087837259615622, 4.30509691276858, 12.481208405187054, 41.36440976973503, 53.95397463152486, 59.771653682954856, 55.348051671058904, 55.858269660703606, 50.78482112576885, 50.9574838607542, 53.18320535844373, 55.683732032775886, 53.69098363384124, 53.50368653574298, 51.58808723572762, 50.03995910767586, 50.788519920841345, 54.44491809414279, 54.405706159530155, 50.2087426185608, 51.12650271384947, 42.618454271747225, 40.07309098397532, 40.705106412210775, 40.91603186822707, 42.187483849064, 42.05254254802581, 37.42790729768815, 37.442023907938314, 37.94743307175175, 41.61535909098964, 38.86282405545635, 38.22365030165642, 36.75657010847522, 37.59653391376619, 39.0342120201357, 39.924888149384536, 37.50305598781955, 38.19272633521788, 35.6388593489124, 42.819522811520486, 51.30342514284196, 55.80456456830425, 52.4607204621838, 50.24770352148241, 46.127034002734774, 48.13397745932303, 48.381828108141505, 50.975307110817205, 50.403821699080936, 54.32996519150273, 48.07854652404786, 47.667831220934474, 42.13626946172407, 48.18519576903313, 28.861635192748043, 29.30981697574739, 60.12826381191131, 46.79527251951156, 51.38862686772501, 41.90813656776182, 43.35542840342368, 38.779308949747396, 41.74494243437245, 44.2170044683641, 47.147854374301055, 47.56482585783928, 49.079621684166696, 42.30615123625725, 37.820191383361816, 36.10538605720767, 38.75587278796781, 39.12156320387317, 40.09257731899139, 41.30663325709682, 41.685349864344445, 39.09429096406506, 40.37930257858769, 37.252902907709924, 39.77861512091852, 37.86318448282058, 39.19349555046328, 36.31081627261254, 39.10463033183929, 38.42220067977905, 40.28128254798151, 41.28958663632793, 39.42654709662161, 37.307796478271484, 38.549450212909335, 39.43923204175888, 39.28606348652994, 38.65321651581795, 40.982814142780924, 42.188048670368815, 46.44067064408333, 49.10298724328318, 52.34236294223417, 51.92046496175951, 52.80583804653537, 51.699914009340354, 57.6354092936362, 55.399089551741085, 55.36893829222649, 59.11113046830701, 53.631092963680146, 59.04242623236872, 50.5101453873419, 33.20084741038661, 15.351074280277377, 22.68206846329474, 16.11179247979195, 2.7580116448863863, 2.8582081006419275, 0.7244602999379559, 0.12149708615916392, 0.04153956253562243, 4.226176373420223, 24.40370459710398, 49.995954036712654, 63.185531708502005, 45.339829998631636, 26.331933929074196, 33.813247065390314, 50.172417548394975, 49.12510548868487, 19.120297470400413, 0.3537522839202035, 0.02444569520922678, 0.04948671734441192, 0.14165362553490748, 0.055398192677286365, 0.053732790308253425, 0.014669629012895449, 0.012971787608318753, 0.09782083242410615, 0.05186814762231323, 0.025690327616288297, 0.09540655229601169, 0.020142868536734776, 0.043299913841990695, 0.044025314836612636, 0.005731530376755062, 0.02977240988383851, 0.09184975162028305, 0.053125458784521594, 0.01481924311167771, 0.056851017138650345, 0.030249657762807705, 0.02630357908445501, 0.03939154392649089, 0.052534647946876865, 0.06870874053528232, 0.04621558702520786, 0.028484489678615527, 0.03075096080259931, 0.013301867124203955, 0.020236070793602737, 0.10111170099867929, 0.01772775145758304, 0.0725372113107193, 9.555830205640486, 43.0267612395748, 55.110136385886904, 55.98138893804243, 47.976188352031095, 30.673297566752282, 27.552448049668346, 37.91128450824369, 42.42978826645882, 11.884596290126925, 0.05845586791814816, 3.6235022352587793, 2.9607307670577883, 2.1425013051879023, 7.86069360471541, 7.491862841190831, 7.779287263270348, 12.08785645423397, 45.02837811746905, 56.63251807612758, 60.44451275179463, 56.74944393096432, 55.850766166563965, 52.943140614417295, 52.751932913257235, 57.232291621546594, 56.340701580047615, 55.01870201480005, 54.82280315891389, 52.12405558555357, 50.379808948886016, 51.29383887014082, 55.40587132976901, 55.84417658467447, 51.10715366178944, 52.84727004266555, 43.608829206035985, 41.5333148740953, 42.33177215822282, 43.87731544433102, 44.926416104839696, 44.668230010617165, 40.00969371488018, 40.14954974574428, 39.94773595563827, 44.91695534798407, 41.81273668043075, 40.394843009210405, 39.03431400176018, 38.9390004065729, 40.503931968442856, 40.984292876335886, 38.023072058154696, 39.28327860370759, 39.18376022769559, 45.8987206797446, 53.259448389853205, 55.54514292747744, 52.568805294652144, 53.32500688491329, 48.49481982569541, 50.29239108485561, 50.77820408728815, 53.73556921558996, 53.496402694332986, 54.421054394014426, 47.727749347686775, 50.55824933513519, 43.488432053596746, 49.640159760752034, 30.889977139811364, 30.327858348046583, 60.899966609093454, 49.670342399228005, 53.73819328123524, 44.18930861257738, 45.00093329337336, 40.59304429638771, 45.18100538561421, 46.25313035903439, 49.08071994781495, 49.42977559181952, 50.677450164671875, 43.9802658942438, 40.217614635344475, 38.82987222363872, 40.43073661865727, 40.35928280122819, 42.33586711268271, 44.28969383239747, 42.47745683116298, 40.5421672328826, 41.801251980566214, 40.09766855547505, 41.978907892780924, 42.00088493285641, 40.982064970078014, 39.59794682841147, 41.45371429381832, 40.78083169075751, 41.435149715792754, 43.15744676897603, 41.65000538672171, 39.34184743512062, 40.00018981195266, 40.794779639090265, 42.076763183839866, 41.513346087548044, 41.823570266846694, 44.82670945505942, 48.44153050453433, 51.94507391222062, 54.96874670828543, 53.366450648153986, 53.409063277706025, 53.39583704548498, 58.487956062439956, 57.51321961802822, 55.59395682427191, 61.9984342205909, 56.440004225700136, 61.85567171342912, 51.87642066709457, 37.001592728399466, 14.14803529939344, 12.133209839943918, 11.250949155899788, 8.472024413847155, 5.75768590934815, 1.9400962177784213, 0.2459848723224094, 0.08527487095805907, 4.494974930440226, 24.91973161697388, 48.87133990564654, 63.807643152052364, 46.86989953441005, 33.47247546718967, 39.507999035619925, 56.18958442441879, 57.00714365128548, 24.874194860458378, 0.5998081113061597, 0.015140568157808195, 0.007222377218215937, 0.05488689027486309, 0.0641964596786326, 0.05599927292355607, 0.05684359757710369, 0.05488053940597081, 0.04185774183321384, 0.06521613036672916, 0.05668803576319929, 0.021849440470818552, 0.04564927950982125, 0.0716420452320768, 0.015755777938231345, 0.06259049041076534, 0.04294344546994375, 0.2027076155307793, 0.18605746058446748, 0.1022181464659591, 0.25351013868085803, 0.20658651787427165, 0.10553676274514968, 0.0896240746782672, 0.2502493007529167, 0.2196051402678413, 0.1607538062718607, 0.0836685071549108, 0.1631678259300609, 0.24438604682443604, 0.07547752571202095, 0.24386830928344883, 0.11274776451529996, 0.2676266570004725, 12.320646182183298, 54.93610474371142, 60.32171903118011, 62.832388954777876, 52.86443041216943, 41.44242963483257, 37.211969052591634, 52.247116027339814, 49.538091844128026, 14.107911413715733, 0.2657061052178183, 5.099937771597217, 5.157044539528509, 4.495675073515985, 12.481964442037768, 15.494241772159455, 16.573025949539677, 15.745806905531115, 47.70867093916863, 56.42815474540957, 63.30338324269941, 58.912521254631784, 60.72156544654601, 55.005997457811915, 55.696997488698656, 59.41341184800672, 59.63558273930704, 55.42594602031093, 55.02624865501158, 52.559050360033595, 52.33396514769524, 49.719081770989206, 55.60861864397603, 57.07041148216494, 56.08627311645016, 55.2934326664094, 45.98473825762349, 42.6566699243361, 45.27318500703382, 45.189948389607096, 47.287643724872225, 47.1542517600521, 42.21587004200105, 41.65032309870566, 41.10620014129147, 46.294887911888864, 43.58970765144595, 41.80620201172368, 40.24508691603138, 40.42182891599594, 43.442434418586, 42.82552011551396, 40.81966315546344, 41.65899153678648, 41.31508988718833, 47.9853980771957, 54.75493438782231, 59.046552565789995, 55.775123257790845, 55.431037256794596, 51.19265740917575, 50.50592491703649, 52.42121042743806, 54.771200456926906, 55.44163157863002, 55.40786781618672, 50.19217452695293, 50.15514735252627, 45.83057342037078, 49.67452756820187, 33.94803539399178, 33.93552303314209, 62.45617481970019, 52.185217103650494, 56.43825092623311, 47.31302538225728, 48.01964429117019, 42.59572021422848, 47.65835085222798, 48.430928337958555, 51.184106642200106, 51.37534964469172, 53.62801782546505, 46.37756755275112, 41.996519334854625, 39.62049261216195, 42.76930470620432, 42.7641232552067, 43.703013158613636, 46.7844428554658, 44.67717693698022, 43.03100524410125, 44.3261012723369, 41.21058225631714, 44.30321032001127, 43.94459585989676, 42.68605239929692, 39.849394290677964, 43.422038093689956, 42.55330762555523, 44.37607619070238, 45.941121501307336, 44.00386679557062, 41.60034033559984, 42.58325099945069, 44.513641557385846, 45.65030128725114, 44.58408732568064, 46.239904126813336, 46.99566641161519, 51.395683211665, 53.15401900199152, 57.76465139081402, 55.624496398433564, 54.94596950469479, 53.993363072795255, 61.464991877155924, 59.34425653949861, 59.76263223155853, 64.38902470373338, 59.95657382472869, 64.10092661457678, 56.185560072621996, 37.92206710384738, 17.320763064968972, 29.624334189199633, 25.56691485066568, 5.256974274112332, 4.62465682337361, 3.4005397606280545, 0.3845546262398843, 0.16379958799769803, 5.571855777694333, 34.58038030132171, 60.71644675347113, 68.32586842198526, 56.43462665619389, 39.01267036314934, 47.633173158091886, 64.79660995544927, 63.68138597857568, 31.11401115694354, 1.1065009933325554, 0.1349833899087483, 0.08262773074450032, 0.14816892753926017, 0.12400089898296904, 0.14134712907816135, 0.12382806188637212, 0.14994767644713003, 0.2334668424220816, 0.16246780542837036, 0.15061846303363002, 0.15011183376754486, 0.1921346215831657, 0.14406121005454373, 0.11946454764373841, 0.15053168059356753, 0.12593542420936207], [0.06143089376329895, 0.04194111518201329, 0.08058521010342144, 0.039926008997304786, 0.05052673915821699, 0.08222303713761991, 0.045793078043648315, 0.007379172912483374, 0.056813593743549246, 0.022462816428272955, 0.024256986686058586, 0.04628944173154812, 0.05297080478480747, 0.03718289328859218, 0.055849418464687564, 0.10031000530767827, 0.3072989185250575, 6.048397277632068, 34.300915348914366, 49.95986430875717, 46.62394731275497, 29.01520382973456, 22.300796431879846, 26.44299387931824, 36.192803921238074, 36.80470935760006, 7.235901711448547, 0.2709995276264606, 14.531547004176726, 25.744058893572902, 7.345600108946524, 5.288968067015372, 5.22509717172192, 5.7493758778418265, 16.84585229043038, 43.82801517363518, 59.39260759661275, 54.88816161309519, 53.3726832943578, 52.66745290448589, 51.849011144330426, 55.54797095637168, 53.732478387894176, 53.35859806306901, 51.24371882407896, 52.100992048940356, 51.191402250720614, 52.07768140300628, 50.35261123411117, 50.330657728256725, 52.468702485484464, 52.45372687616656, 49.82462882995606, 45.86137187096381, 39.244749161504934, 39.63741763945549, 41.406963563734486, 43.182663686813854, 45.17109747855894, 44.10410296532416, 40.963206214289514, 38.521942630890884, 38.74410959982103, 38.893532291535415, 39.29318258839269, 38.271456149316606, 39.6287727355957, 38.432802846354825, 38.489175150471354, 38.1279876155238, 37.702939971800774, 36.71655408797726, 37.47674472870366, 43.330658635785504, 46.22781145957209, 44.56510305404664, 43.22157359892323, 41.35075992153537, 47.48274241724322, 48.309817314147956, 53.831392718899636, 50.88675960417717, 51.22009831090128, 45.87061689745995, 49.4568399460085, 43.79698138083182, 49.13074193462249, 29.58834252049846, 27.11311121140757, 59.661352711339156, 48.03717336347027, 53.9048900911885, 45.85551577229654, 42.13785409927368, 37.62250000430692, 38.14862712737053, 37.359654134319676, 40.16624335319766, 38.35436721001902, 39.612224255838704, 39.936035525414255, 38.113408165593306, 39.834630489349365, 39.11584438816194, 40.029725259350194, 40.6011204565725, 42.56585921010664, 47.63612670283164, 39.58255152548514, 40.95527910417126, 38.938568945853945, 41.45756606132754, 38.071391736307454, 39.23639843540807, 38.980550073808246, 39.120955236496464, 42.08365478823262, 41.21858781383884, 39.45289757943923, 38.65048654617802, 37.674769509223204, 39.10970980121244, 38.41733694076538, 38.51411358002694, 37.472598783431515, 41.09195409282562, 43.5454240922005, 49.78759381078905, 51.73437595367432, 53.7168045966856, 50.62757722793087, 49.87179533127816, 50.951043328931256, 53.26911310995779, 53.52760514905376, 52.51234669839182, 53.27913868811823, 55.750286809859745, 56.87249652801022, 58.84328749872024, 43.18884534220542, 21.198571189757317, 10.889610609700604, 7.71933138370514, 15.107448024134483, 8.479495548432874, 1.5616182622409638, 0.06908072984867519, 0.14186886559811332, 1.524303038754771, 23.788902490369736, 52.12472631085304, 66.13035309699275, 38.66204184870566, 21.69584731901846, 42.17841925159578, 49.76378110147292, 55.086566863521455, 26.992690524747296, 0.7565353594480023, 0.07836078188472217, 0.025366121121952613, 0.07409066142093751, 0.03144635221800737, 0.059694053695326856, 0.04017800595911761, 0.08136512591473519, 0.07878510266422264, 0.020380941850523797, 0.05681586902468436, 0.043080425821244724, 0.11887215483453005, 0.014804446123420231, 0.04457117163486058, 0.007410472871044712, 0.04873444581584585, 0.08682725620606253, 0.014854249499377706, 0.03392670551435121, 0.029093316989019517, 0.10729167099681594, 0.060799284913246675, 0.013738586079148997, 0.009066496408664653, 0.024863019690758763, 0.03116528988034735, 0.03545480577515499, 0.04588755966734983, 0.04716511087251767, 0.03005835603201582, 0.04547974042173836, 0.04708392470474205, 0.28162660738152845, 9.039599222521629, 42.74319741033739, 53.9117189376585, 52.64730761128088, 36.101251879046046, 30.772635513736358, 32.40718326260967, 39.57696999272993, 38.52016579720282, 8.568260746617472, 0.2533770385648935, 17.318772462106523, 25.4662315307125, 9.97855188385133, 11.026810215365503, 12.774836055694088, 14.33289562502215, 19.89906249507781, 46.64460643645256, 60.400291950471946, 57.636001571532226, 55.12785765432543, 55.228956745516875, 53.421846282097604, 57.425813521108324, 56.07303511711859, 55.04315014808409, 52.387650628243726, 52.42318730200491, 52.73412535267492, 51.72999074382167, 50.10357210713048, 50.479966671236106, 54.100581061455514, 53.905556894117794, 52.021462071326475, 47.790719078433135, 40.48730111891224, 41.60878519858084, 42.11221356545725, 45.133117168180405, 47.041813096692486, 44.27647544491676, 41.00832916075184, 40.3793574917701, 40.55094157495807, 42.61528891901816, 41.44721100407262, 38.823572897141986, 39.849676701330374, 40.297783959296446, 39.62524652481079, 39.02366868911251, 38.318952129733184, 39.514878872902166, 39.9837903822622, 45.428742285697695, 50.052291039497625, 47.88164746376776, 46.201002059444306, 43.95122466548797, 48.57088635044713, 51.10651823782152, 55.331271771461736, 53.156901944068174, 53.45317425266389, 47.79914825193344, 49.644933285251746, 45.278590033131266, 50.09368381192608, 32.84010114208345, 29.049583404294907, 60.10031692443356, 50.20529485517933, 56.57123104218514, 47.631996447040194, 43.945815717020345, 39.58066878780242, 39.19724925871819, 39.34252600516043, 40.555617040203465, 42.04268170941261, 40.86183647955618, 40.73575581273725, 41.53695875598539, 40.011341110352554, 40.24121161430113, 40.29896459271831, 42.13819926784885, 44.352494901226414, 48.33159431334465, 40.41524325647662, 42.72118899130052, 39.24061498334331, 43.22927713394166, 39.20740035272414, 42.527835753656205, 40.56821177082677, 40.75980778663389, 42.662937871871456, 42.98332491228658, 41.538461023761386, 41.29182238732615, 39.66854949151316, 40.68758910702121, 41.51098089833414, 40.88159738048431, 39.21469988361482, 43.130339268715154, 45.41299004708567, 51.20177299745622, 53.046561748750754, 55.21866444618472, 52.56522417068482, 50.854254922559186, 51.59357070922852, 55.77256195006832, 55.00053751853205, 55.44571084360923, 56.282834852895434, 55.492190930151175, 59.59317015063379, 61.23799254817348, 45.76422652890606, 22.406769068010394, 12.144782793137336, 9.71566188719965, 12.043253221819478, 5.919241472598046, 2.169045945329051, 0.2241344206155308, 0.09381370994472697, 1.5255227733042933, 26.837280334964877, 56.48546057362711, 67.48698326849168, 49.52809764492897, 28.43137864143618, 47.66865884104083, 57.66236382146036, 61.180204268424745, 33.60044279406148, 1.1083164378519983, 0.08395091780731756, 0.07130299003854876, 0.06182219615326293, 0.0352700368591374, 0.025202448352149902, 0.06270280273090448, 0.05540735125842114, 0.025967911914772084, 0.02647774151316093, 0.021430168210739092, 0.06021986197259638, 0.039881966602537906, 0.11937266305810022, 0.02353069319900486, 0.041884459149573124, 0.04941773112683047, 0.24899495435097527, 0.16528736139016767, 0.152872477567965, 0.14943563860029946, 0.12720195907017878, 0.12913723506273764, 0.11382449343199692, 0.21674344947020854, 0.10561817490886297, 0.141011061627538, 0.08227174500784568, 0.12257200710835958, 0.13458150018367077, 0.12323502556330736, 0.22159238766518333, 0.16306723858560287, 0.49073854941994915, 12.258700190051911, 49.562661570887414, 61.21485056415681, 60.92088853159259, 40.886810210443315, 36.72860360914661, 39.16208521012337, 49.11757453795403, 46.37640653118011, 9.691476552717148, 0.31007068592213816, 15.999421477317812, 32.44556757711595, 18.784513165873868, 14.69194939059596, 14.8825510855644, 12.085173553036107, 21.47374899156632, 47.04693571213753, 65.0056173724513, 59.459633058117284, 57.55312973453153, 57.1383547782898, 56.14531655465403, 59.313422787574034, 57.60220643012755, 55.48688396330803, 52.061089777177386, 52.713678036966634, 53.34344594709335, 51.893937972284135, 51.1460361173076, 52.51832831290461, 56.05275646332772, 56.914964029865885, 54.62345653964628, 49.75461060001005, 44.102114323646795, 43.41445615214687, 45.66265675329393, 47.10651651505501, 49.9185303718813, 47.37924283550632, 44.764179029772365, 42.323009583257864, 41.926618776013775, 42.95356588978922, 43.393946078515825, 41.25777229186028, 43.279918855236424, 42.70050241101173, 41.45025476332634, 41.415624157074966, 40.386323621196134, 40.52941560745239, 42.91507174891811, 48.50907371890161, 50.70873106679609, 50.29033576288531, 48.273629526938166, 45.381799359475416, 50.921802059296645, 51.27181083925309, 57.17092221783054, 56.50160504925636, 54.937556020675174, 49.356101712872906, 50.4675562920109, 45.15855766111805, 50.9314432451802, 33.97119306748913, 33.12903273490168, 60.928823486451186, 53.6322618299915, 59.06261467164563, 49.263588689988666, 47.305918047505045, 42.09870884495397, 42.10199971352854, 41.41975441286641, 42.85584788168631, 43.53119373321534, 42.404285015598425, 43.86866269573089, 41.87805198854016, 44.554430284807765, 42.725193731246456, 43.35591869969522, 44.786018786891816, 46.63752655829153, 49.56070430817143, 42.794454943749216, 44.09622292364798, 42.70133395348826, 46.99453676900556, 42.49336988695207, 44.63863180529687, 43.81172557030955, 43.07239017178936, 46.85204098301549, 45.42705958889377, 44.39295022718368, 43.78473181878367, 42.7815778024735, 44.33189069071124, 43.07213521772816, 44.60232242461174, 40.919295280210434, 44.97746183026222, 49.134962404927904, 55.02680563157605, 56.271491358357096, 58.27602647965955, 54.96229833172214, 53.01207234782558, 52.11317885306574, 56.99507451826527, 57.51086227355465, 57.43548608595326, 57.678865232775294, 60.445865969504084, 61.450475185148186, 64.51493278626474, 49.82784125112718, 25.617825254317253, 14.973882494434235, 13.892185957201066, 24.76008918977553, 15.416019904998043, 3.545151420177952, 0.3976745561005608, 0.34822115975041545, 1.7539466581036969, 32.90177452948786, 60.66038431659822, 70.7390203783589, 50.10053619261711, 31.985893249511722, 54.53262229119578, 64.3152331536816, 67.92618674616661, 41.54171266863423, 2.293172291209621, 0.20814141589066676, 0.1563978456561604, 0.1716792313081603, 0.1678966415385085, 0.17423926732472836, 0.16272119667020538, 0.19191457048779537, 0.21981325571335134, 0.2887486203783943, 0.14228129669302894, 0.14680752801077981, 0.16196050200491183, 0.18094016178961725, 0.1483482993658512, 0.1067355601117015, 0.11723588295881787], [0.061181815596477646, 0.019657996167699178, 0.09258923331095327, 0.027857711012925834, 0.012848241566379946, 0.03449230822884748, 0.07059730048621855, 0.08852797905884444, 0.06016900522574302, 0.03759505625273432, 0.028892555987582575, 0.006098019657656551, 0.019532641200649164, 0.054293267894536264, 0.020042453562059713, 0.0806815073555035, 0.21371202423207222, 4.782849444497017, 33.251979427952925, 50.74770373682822, 42.33371373145811, 27.727811336517338, 16.988263745461744, 28.692904633860437, 38.77322535361014, 32.23764861783674, 4.635584546673683, 0.08671120154641329, 3.192054754303348, 13.134500730422236, 9.076952934265137, 8.130882641961499, 9.695447952516618, 13.944543715446228, 20.142404379383212, 49.34138497998638, 57.74301559694352, 57.83865082648493, 56.930174981394124, 55.85231550278203, 52.38755256898942, 51.382641330842056, 52.95127953252485, 50.31442696048368, 52.155975834015884, 49.45795782150761, 51.371019348021484, 51.87753069785334, 55.8927276826674, 52.77452576544977, 49.873615311038115, 48.84688000525198, 50.74620931379257, 48.04967787957961, 39.96554743859076, 39.16807859174667, 43.142278963519686, 44.30290045276765, 45.94493012274466, 46.32450180668985, 44.94480417620751, 39.969281534994806, 37.5110968466728, 37.60905411935622, 37.48182027570663, 38.23298162029636, 36.87687312403033, 36.75687213097849, 37.91952148560555, 37.31639823605938, 36.6142390620324, 38.0696149026194, 38.94047521775769, 36.050484641905754, 38.439545400681034, 38.53359599267283, 39.43471347132037, 44.598894273081136, 50.99163986021473, 51.36588888783609, 52.194379760373025, 50.14275658515192, 48.6086077843943, 50.55352287907755, 50.60647095403364, 42.927525274215206, 50.595672668949256, 34.7221504488299, 25.40219883764944, 53.1318772223688, 51.42508922084686, 52.89788822973929, 49.252417779737904, 43.98893040995444, 38.391763087241884, 39.3383643704076, 37.037855040642526, 41.948156510629964, 36.36265431680987, 39.175758592544064, 37.90222775551581, 39.36151812153478, 37.45031579848259, 38.166179733891646, 38.57702447522072, 40.414439170591294, 37.043793509083415, 41.912019714232414, 39.36762525189308, 38.579989787070986, 39.038067710015085, 40.276407041857325, 38.678453045506636, 38.46313845726752, 37.41916041220389, 38.60248065763904, 38.1770956900812, 37.2545071571104, 39.640304503902314, 43.39595040967388, 42.8124233215086, 41.66209413159279, 40.497012907458895, 39.370366988643525, 39.06469668111494, 39.43382701566143, 45.07576034915063, 47.769110741153845, 51.54934598553566, 53.69328998750257, 52.363245641031575, 53.234058887727805, 51.79532566378194, 57.403561915120775, 53.7122703367664, 48.35232011733517, 50.94279850682905, 53.47782242682673, 56.330860353285274, 57.02380980214765, 52.80200196850685, 24.40608939816875, 15.39634039325099, 11.88423543207107, 11.093417944446688, 3.794520271401252, 1.358973542528768, 0.2967584373489503, 0.038087918918820164, 0.5418804035552087, 15.889398993984347, 52.83994305518366, 45.94291794684626, 22.29526000638162, 17.84039278184214, 35.65747491775021, 43.816169615714784, 51.601164417882124, 28.26272260758185, 2.194044681326036, 0.037944396176645835, 0.02286770538757405, 0.04229129014176227, 0.005138161284248195, 0.05472431109557229, 0.03389004437673477, 0.05247247991182151, 0.0851016661392585, 0.06859400354686283, 0.037894956692452395, 0.04062355886543951, 0.04370036715221021, 0.07860003880435422, 0.023627894434837565, 0.01083956573218588, 0.10201233694510115, 0.0334711474997382, 0.0406006298538658, 0.01103672899320842, 0.05162873365465672, 0.02456578715223699, 0.0670466898009181, 0.09548227242644756, 0.07364092950498866, 0.020639216902876095, 0.05758215996226477, 0.05620928060623908, 0.07713614437248438, 0.06442789484055773, 0.06538636276438352, 0.010555326044859906, 0.05791770264265999, 0.13441542764344525, 6.130429727415885, 39.973545151372115, 55.59861660003663, 48.76025838236655, 32.35385471774686, 24.484101418525945, 32.2572918476597, 42.94530930057649, 36.89870111403927, 5.453999340534211, 0.1189980537240063, 3.750213913379177, 15.53745746612549, 7.485899857936367, 8.960545812883685, 14.058641541388727, 13.97907724303584, 20.91372278428847, 51.439033246809444, 58.74166673229587, 58.85804737767866, 56.29810071760609, 58.11367173348704, 53.746924477238814, 54.429189389751805, 53.59628192840084, 52.1864487278846, 50.80692368168985, 52.50946767868535, 52.05222129821778, 51.69479531626548, 54.94405146568052, 54.198420663033765, 49.460856453064956, 50.729684368256606, 52.92030457527407, 49.44726544041788, 41.68047043585008, 40.67044442699802, 45.09634887018512, 46.38368252784976, 46.98404050642445, 48.17781386836883, 46.360866100557395, 42.874561509778424, 39.845824933821156, 38.0292772477673, 39.430269425915135, 40.72942902964931, 37.927303468027425, 38.98039710137152, 39.1468075783022, 39.953972524212254, 37.759006331043864, 38.4694456285046, 40.60083412354992, 38.21272650072652, 41.394266851486705, 39.65653919404553, 41.81432524035054, 45.844313483084406, 52.07414734748102, 52.96605902333414, 53.82514830558531, 50.59645322061355, 50.33968310202322, 50.12150910592849, 51.46774107410062, 44.105840575310495, 51.246060479071836, 36.01434000076787, 27.358947723142563, 54.419987509327555, 51.71737247897733, 54.6804093545483, 51.5319973422635, 46.045825250687145, 39.70911072146508, 41.596978864362164, 39.88042416111116, 42.10494149115778, 40.36313064636723, 41.32661773312477, 39.549662451590265, 41.69477531986852, 39.29432007574266, 41.307747210225756, 41.29907092740459, 41.86126424420265, 40.64843993033133, 43.07680283823321, 41.28570741222751, 41.05651940068891, 40.84329543575164, 42.78422932470999, 40.53062369746547, 39.482738971710205, 41.10283867005379, 40.82336195053593, 39.677794518009314, 40.83628223788354, 42.02124203405073, 45.322500967210345, 42.07955198903238, 43.57913294146138, 42.6812945642779, 42.02750998158609, 40.60720405270977, 43.04432561320644, 46.696322887174546, 50.50416377282912, 53.09898814847393, 54.11709423988096, 53.81892350412185, 54.59564301275439, 52.18261264985608, 56.158534942134736, 57.723219394683845, 51.19103747029459, 53.14309520106162, 56.61934675708894, 59.73882736698274, 58.49941330571329, 56.02080483590403, 25.43088705308976, 11.698595535370613, 8.558089060168113, 9.352746548191194, 6.0649178105015915, 3.187070892703149, 0.15935175811811803, 0.051880765090426134, 0.5663455133476566, 18.716411013757032, 53.807289754190755, 51.74447605686804, 32.079294689239994, 22.79201053803967, 40.211429057582734, 49.27384568798927, 59.67041730880738, 34.02524332846365, 2.9384345441095294, 0.05895065729536357, 0.035215127507164594, 0.06757126084618992, 0.029494448287052014, 0.10540421421249067, 0.06637068615565378, 0.013573544884791539, 0.09302279311082057, 0.08409111189746088, 0.028043039173128146, 0.045501133427023895, 0.040408985298727794, 0.023965047815093593, 0.06942438156974894, 0.01802473884796904, 0.03667958118321915, 0.23983789007029227, 0.20274971972309774, 0.16290692702656792, 0.12108440991611251, 0.11885247403575529, 0.20135527116156396, 0.1751666014353114, 0.15098941812832511, 0.10166065662258095, 0.14762980082342703, 0.17714318488874745, 0.17145225477795448, 0.06093656403883811, 0.16599780068762843, 0.1070293088653876, 0.1464244687268811, 0.39673128736115276, 9.390358155773534, 48.86517001736549, 62.37031413662819, 55.44275729886947, 38.76616508729997, 30.235851310914565, 42.21425010311989, 50.67475157399332, 42.23225378221081, 6.039288063203135, 0.23095292489855523, 3.9711222917802877, 19.65120792388916, 14.41521538842109, 17.428518418342836, 17.04754056469087, 18.540259330503403, 24.917593925229966, 51.28708062633392, 62.133869740270804, 59.54461905264086, 60.82842649952058, 58.58204587813347, 55.869166005042295, 54.133026907520915, 53.80671316577543, 51.3455278642716, 51.12031321371756, 51.37165084961922, 53.37542503110824, 52.76934823682232, 56.74350546252344, 55.36938152005596, 51.66383997086556, 54.32397965461978, 54.60489980636105, 52.257043546245946, 43.83087065912063, 42.35236460162748, 48.73916779795001, 49.74357305034515, 50.395945579774924, 50.87800487395256, 49.443868667848655, 44.086636650946836, 42.20192601603847, 41.49458146864369, 42.41469106366558, 42.663475236585064, 40.07093760275072, 40.715033931116906, 41.35436065735356, 42.45703304967573, 39.034784686180856, 40.66225059570805, 43.238965388267275, 39.87727842023296, 43.150198228897594, 42.1182422484121, 43.93836713606312, 49.10659190147154, 54.097639283826275, 53.05523410920174, 54.5789219487098, 52.84245729446412, 49.40447630420808, 54.45817178295505, 54.17668288753879, 46.31151483904931, 50.21510078061012, 39.06007612905195, 31.0570171571547, 53.8774178105016, 55.460474644937825, 58.32124356300601, 53.82119063408145, 47.00403282719274, 41.73251244329637, 42.60298444378761, 42.70143593511274, 46.198793765037294, 42.253799361567346, 43.03312724636447, 41.38441777998402, 43.78050742610809, 41.51730375905191, 41.77342276419363, 43.57106462601693, 43.55042119180003, 41.84964618375225, 45.168861727560724, 42.05013421274001, 42.05050683790638, 43.32575567307011, 45.93649702687418, 42.56818909798899, 42.63758759344778, 42.325472831726074, 42.41049804995137, 42.39786409562634, 41.69394377739199, 44.449675544615715, 47.326510490909705, 46.00835877080118, 47.48131075213033, 45.48004296518142, 45.057505638368674, 43.880810276154556, 44.89863003453901, 50.37675342252178, 53.271960750702895, 57.029603142892164, 56.29989716314501, 57.645831031184045, 56.98887325102284, 51.96274026747673, 59.37170528596448, 59.8254019214261, 53.12644081730997, 56.23273049631427, 58.20412158966065, 63.545891623343195, 59.721094331433704, 60.97507999789331, 27.72752304230967, 22.94250599799618, 22.696112509696718, 20.265209867108254, 13.012247316298946, 5.774376575023898, 0.49530774294849367, 0.14785838613827385, 0.9015649352823535, 21.311937493662683, 63.087425385752034, 53.76921138455791, 33.51002431684925, 27.423637413209487, 50.30501327207012, 55.66994097925002, 66.03481200433546, 41.18636162050309, 4.588347442688481, 0.20354638987731552, 0.1354174859701626, 0.23750866102355145, 0.1750962132768285, 0.20326154306530955, 0.16102968985515256, 0.07571656046615494, 0.1534542600594221, 0.2725140834527631, 0.19268831929131863, 0.1174667435547998, 0.11341118899684761, 0.16034663054010562, 0.13071788895514705, 0.13810590300108158, 0.22680745460093024], [0.11250561178331414, 0.05038631524169638, 0.021691553580063968, 0.0670354666128274, 0.03478303093523268, 0.042716553209409605, 0.02191319047743755, 0.0114948601056371, 0.043270645452843565, 0.017556197558259292, 0.008932414742547178, 0.0992615910006627, 0.05508644468781929, 0.0440988477860247, 0.046737204801531575, 0.02328271436835489, 0.3606039291668323, 10.98812387835595, 40.77658376386089, 48.81518333188949, 42.79116407517464, 35.59800001882738, 16.988736391067505, 22.65893824638859, 34.834847988620886, 29.497488660197106, 2.4237543680975517, 0.028706674328854972, 0.47100029405086274, 0.42569697984764654, 6.148853100115254, 7.426149412508934, 20.04981683146569, 23.703987098509266, 28.90071180558974, 51.97214611114995, 60.322330920926994, 56.063739099810206, 53.17311702236053, 49.821463477227, 52.93698641561693, 53.067887675377634, 52.32251967153242, 50.77891403628934, 50.6842750887717, 50.971208233987134, 53.35511892072616, 53.64265611094814, 50.58384672287972, 52.01312311234013, 51.696509392030784, 49.0710356158595, 51.817063439276914, 45.81945742330244, 39.681183445838194, 39.11848806565808, 43.334329974266794, 47.20444633114723, 48.179092561045, 49.787899755662494, 47.263003395449736, 45.40487466319915, 43.264460794387325, 39.65151071548462, 39.25060918254238, 37.90881341503513, 38.3087343554343, 37.39460637492519, 37.77021646499634, 35.013849273804695, 37.33530798266011, 37.21805657109907, 37.65078421561949, 39.11026677777691, 39.42438194828649, 38.957180592321585, 42.641706082128714, 48.12927453748642, 51.818687300528254, 52.675525142300515, 49.11047504794214, 48.436400044348936, 49.084363829705026, 46.28660778845511, 47.10174691292548, 42.24891993307298, 49.914298134465376, 38.3506723373167, 27.83556276752103, 53.8311142306174, 46.935591390056, 53.93999138186055, 52.799020967175885, 44.79461662230953, 40.29206906595538, 39.07735024729083, 37.28722756908786, 39.52015053841376, 39.67098920576034, 38.38700917459304, 39.34834288012597, 40.371912833183046, 39.12862347018334, 39.52077419527116, 37.90977439572735, 39.2655808694901, 39.9913566343246, 39.00806550056704, 39.37862750022642, 39.06674023597471, 40.09495035294564, 39.5402919092486, 39.08155502811555, 37.98087127747075, 39.11816250893378, 39.43115588157408, 38.522032845404844, 40.0645362946295, 46.33226025489069, 45.63975011148761, 45.37205619196738, 42.499739816111905, 40.90729674985332, 39.474905998476096, 38.75488042831421, 43.4375314558706, 46.38731464262932, 47.26313283366542, 48.43628629561394, 52.343151338638805, 53.64966538644607, 48.8229613919412, 52.25348203412948, 51.59759506102532, 55.12306844034503, 50.827029751193145, 48.96704181548088, 52.68083210914366, 57.42653523722003, 60.89492636342203, 56.405416765520656, 32.91713845345282, 15.726917751373785, 5.5231521975609565, 8.461396751865264, 2.8672101853355287, 1.8714161289315072, 0.23035408928990367, 0.09439914667558286, 0.24709753842363436, 10.860149687336339, 47.979020303295506, 43.17798429919828, 28.918217343668786, 31.85019296984519, 37.22206523341518, 52.497206349526685, 54.43097799055038, 35.100404216397195, 2.5610672322011765, 0.18287185249069046, 0.020247843649779117, 0.044901405325940544, 0.07027302312874986, 0.08650919948253902, 0.01731930018943404, 0.04713138385165123, 0.015840619303015693, 0.04346115236741401, 0.11280262407155768, 0.026084179163820324, 0.0353628522416036, 0.05035669062166445, 0.041450726979922865, 0.0453997646728831, 0.09001655684363458, 0.06619834701620764, 0.032981349185349486, 0.039487013803614725, 0.0364905949531784, 0.04374303441915301, 0.02600280530450325, 0.05525714439910747, 0.03671172623252196, 0.04661021423676322, 0.02658016363819761, 0.057076430849490635, 0.045857720542699106, 0.029246272188761545, 0.06846245858938464, 0.054764940568636504, 0.1317953150118551, 0.3470816499283237, 12.02858747974519, 48.24339982002012, 54.140871647865545, 48.621692811289144, 38.7324680051496, 20.549866076438658, 30.449847982775783, 41.36334288504816, 33.0200889033656, 2.6551401326733255, 0.11368132692070738, 0.377478854310128, 1.2346361241033001, 4.621947446177083, 11.106529447340197, 13.449012060319225, 12.076061887125816, 27.83891247164819, 53.11974140905565, 59.637175221597, 57.99640855481548, 53.652042342770486, 52.73075211432673, 53.68847331693096, 53.1222281917449, 52.272858542780725, 51.789375428230535, 51.180007765370036, 52.01337414403116, 54.27635815835769, 55.787302217175885, 52.67189302752095, 53.95097401834304, 53.32747013338151, 52.08230587743944, 53.343363577319735, 47.36447118943738, 42.94952584851173, 41.61837539365215, 45.422431192090436, 48.473752775499904, 48.5740085571043, 50.86368037808327, 48.71396656959288, 49.00260986820344, 45.46523209541075, 41.25628571356497, 40.01913485988494, 38.58696768360753, 39.506661507391165, 39.460020603672156, 39.85406975592337, 36.83358976917882, 38.18072388249059, 38.52822234553676, 39.41853369435957, 40.75875266905754, 39.3394979353874, 40.88153462256155, 44.96108201242263, 49.55562091642811, 53.476633948664514, 54.201362440663004, 50.44896033502395, 49.4390872986086, 49.27461839491322, 46.48166333475421, 48.63319320063437, 44.54445177508939, 50.533381508242705, 39.441479559867616, 29.947553180879165, 51.9747740991654, 49.74740128363333, 55.93734856574766, 54.41627302477437, 46.293350342781316, 42.08610626959032, 42.79665147104571, 38.16678377889818, 41.85854211930306, 41.51999450499012, 41.88503380744688, 40.2886526815353, 43.24403701290008, 41.91003107255505, 41.621736864889826, 39.69733184383762, 42.31128561881281, 41.50236345106556, 40.42406466699416, 40.46630467137983, 41.60209755743704, 41.03859416900143, 41.76453467338316, 40.968732833862305, 40.57004351769724, 41.83634150412775, 40.986987544644265, 39.9953809861214, 41.64736955396591, 48.518605078420336, 48.27440615623228, 48.08662268423265, 45.86851450704759, 43.52443156703826, 41.61631222694151, 39.7694367747153, 45.56714703959804, 47.88543647335422, 50.27971006208851, 51.17552449626308, 53.016163379915305, 54.63626700062906, 51.07392334168958, 52.63488546494515, 54.30021401374571, 56.57283529158562, 52.72852028569868, 52.29904036368094, 54.3602184326418, 59.179548371222715, 61.35186287664599, 59.02548159322431, 32.61028555131728, 15.67436779699018, 11.083964051738864, 10.733205118486959, 8.13147541015379, 3.1222978522700653, 1.0310457454573725, 0.08718053765234449, 0.12585128477263835, 13.214094446551416, 53.006981111341915, 47.43272435280585, 29.757906583047685, 30.922621065570464, 42.8272145794284, 56.93949845529372, 62.1729326248169, 40.2987253281378, 3.625470039344603, 0.37535387962575884, 0.039931789130693486, 0.03551662907064442, 0.0900336329434668, 0.07278524759796358, 0.011654046473033246, 0.05605870219428213, 0.05151029646156296, 0.016684372263449817, 0.0531492994407252, 0.05161213635977718, 0.007701645654085423, 0.02002238014322375, 0.04932247958476505, 0.024603957483064265, 0.01785243609769931, 0.206202324780245, 0.08625674286797162, 0.13894112269964912, 0.1944062867832761, 0.12530897879191946, 0.1306613976316106, 0.16338072176421845, 0.12989592257766955, 0.10442163750168779, 0.15459638990221486, 0.14235764501556275, 0.22475279146625152, 0.1338133744655117, 0.1418412098240468, 0.13204239368919404, 0.21532719804634973, 0.7798424507341077, 17.69562202115213, 55.834025490668516, 62.15591346063922, 54.62600608025828, 45.24927816083355, 26.819109955141624, 34.111798271056145, 47.95175590822774, 38.76520410660775, 3.0689903901469324, 0.14554211929921182, 0.7787640440848567, 1.9491122759157613, 14.904516358529369, 18.480643226254372, 32.623804000116166, 30.47156026286464, 30.60578573134638, 54.8824231855331, 62.32259850348196, 58.62731395229217, 54.78722726145099, 53.476935971167784, 55.548382805239775, 54.07043764668127, 51.929804125139796, 51.661670900160274, 51.055821603344334, 54.863556585004254, 57.49918537755167, 57.51563579805436, 54.75000789088588, 54.474045615042414, 57.88615072927168, 52.85330264799057, 55.81999125019197, 49.876988549386304, 45.04063552425754, 44.58735073766401, 48.36586406154018, 53.34461873577487, 52.10432214121665, 54.50711904033538, 50.521759525422134, 50.46515972383561, 47.476462702597345, 43.435950740691155, 41.32174222700058, 40.38014981054491, 40.91220755730906, 41.771441967256614, 41.81001063316099, 38.02719054683563, 40.818882603799146, 40.260831309903054, 41.0951586692564, 42.6082992553711, 42.271595155039144, 43.288399019548976, 47.203320610907774, 52.05515915347684, 54.99914507712088, 55.594741298306374, 51.225307218490116, 51.95985340302991, 50.61751634843888, 48.90351118579988, 50.80505271111765, 46.71032967105989, 51.23960425776821, 42.53732396710304, 32.63585548247061, 52.2234994365323, 51.27694522180865, 58.287162088578754, 56.72219914774741, 47.38874281606367, 45.101240065789995, 43.69817687619118, 41.47553836145709, 43.0254158666057, 43.07959164342573, 44.30750531534995, 42.98865149098058, 44.69407058531239, 43.25807125337663, 43.98282327959615, 41.83335265805645, 43.73323894316151, 43.786375291885875, 42.75547442897674, 42.76034601273076, 42.44266933010471, 44.64845342020835, 43.79789137071179, 43.304304230597715, 42.162035511386016, 45.248356403843054, 43.459622244681086, 42.229088429481756, 44.2825198173523, 52.00102652272871, 50.10118730606572, 50.601183599041356, 47.74454101439446, 45.71608335741105, 45.130171468181, 42.1566814761008, 49.67774783411334, 50.883100032806404, 50.15462959966352, 53.119000081093084, 55.41191570220455, 57.43423484986829, 51.88952138347011, 53.6160389069588, 54.66153490927912, 57.948908652028734, 54.271804286587624, 54.804148366374356, 57.59813108751851, 62.4801875698951, 63.926518424864746, 62.83990813839821, 37.77797099082701, 20.291252443867346, 11.616921982457562, 20.205417256201468, 9.768083383960109, 6.592662911261282, 1.7793172838226443, 0.2633018148762565, 0.4086911455998498, 15.54562678260188, 58.137437374361106, 53.220887568689164, 38.95388972374701, 43.19302658880911, 48.50513958161878, 65.80460809892224, 69.50949853466403, 48.492042787613414, 5.218808631743155, 0.5127159572176395, 0.13033672956930054, 0.21394519075270624, 0.14723307453095913, 0.24419847785705523, 0.1794665457019883, 0.20689966397420054, 0.13121837419607948, 0.11354317828532189, 0.212124245721967, 0.18162872161596053, 0.14173421798454178, 0.1490162973923068, 0.14593067909440688, 0.12141889922561185, 0.2240392265300597], [0.05846728645865956, 0.04368406480118152, 0.04120020090692467, 0.07143756104332787, 0.051821496698164174, 0.06991005833110503, 0.04327141537120746, 0.01524193020867965, 0.07962840459039135, 0.030762467443222002, 0.06995375598630599, 0.018666550073952928, 0.02805435237654996, 0.05677463817259958, 0.11805300766061391, 0.12430721923949258, 0.6335684416755554, 14.35972365640825, 37.76209715873965, 49.68958162492322, 41.13772423036637, 28.380525112152103, 19.36730088726167, 23.986982184071696, 34.82489301312354, 25.75700663751172, 1.0688820313061438, 0.0908513245503268, 0.6746878739326232, 1.7840699707308125, 0.5238918623616619, 8.410112742454775, 13.52847339645509, 19.244318892878873, 31.45815991586255, 57.55718154291953, 54.69895039835284, 56.41058644940777, 50.05495432884463, 49.00729710055936, 45.53917661789925, 53.60935518818518, 50.51608385578279, 52.296494745439105, 51.82694388974098, 55.0023300417008, 51.446309243479085, 50.30387186234998, 50.07718240061114, 48.05371399848692, 47.90497379918253, 51.630382153295706, 49.30735449637137, 42.95020441855154, 38.42104358057822, 42.779534247613725, 44.330863029726096, 46.46621704101563, 48.90755122707736, 49.14392109840147, 50.693763302218535, 49.55032963906565, 48.244266663828206, 44.21453337515555, 40.38266012745519, 39.0016955714072, 37.75052224436114, 38.42307929069766, 37.43100597012428, 36.05405007639239, 34.94368591616231, 36.29455804824829, 37.412053077451645, 36.866172898200254, 36.64233107720652, 38.30301553972306, 46.62067213366109, 48.78798561711466, 53.53717965464438, 51.21084151729461, 47.751962138760476, 48.85478750351937, 47.67966108937418, 47.85241796124367, 47.44117313815702, 43.8552717239626, 49.28280438146284, 39.53982906956827, 31.885615894871375, 51.21667408174085, 47.910437660832564, 55.087331725705056, 49.60258737687142, 45.040910090169604, 38.65793904950542, 41.855643487745716, 38.435956431973366, 39.51515343881423, 37.75498590161724, 39.15279703755533, 37.51983588741672, 38.86342810046288, 40.14751795799502, 38.668062686920166, 37.73171840175506, 37.626630260098366, 39.03862468657955, 38.78927176998508, 39.84522481118479, 42.42490491559429, 42.402614085905014, 44.370196557814076, 45.82153627949376, 41.6915628986974, 41.296999915953606, 40.74972337292087, 41.59955978393555, 45.912903970287694, 49.908128246184326, 51.41834274415047, 46.26564271988408, 44.83269891431255, 41.55116558074951, 39.66350140110139, 39.29921127134754, 41.69899579017393, 43.4750920726407, 46.23316157248713, 47.907370367357814, 51.54996179765271, 52.614461683457904, 51.93424032580469, 51.208821496655865, 57.11618554207587, 56.54913633100448, 51.37120369941958, 49.02864656140728, 53.93309193272745, 56.89439904305243, 60.23738415010514, 58.31630137658889, 40.493969148205174, 13.93541734064779, 10.50560566686815, 4.071420974308445, 7.642558832322398, 1.0262972260675123, 0.5792109487998871, 0.08601577757226844, 0.06440464407205582, 6.032849492565279, 37.265489793592884, 36.23023902216266, 18.80367394416563, 18.191750857137865, 27.318127616759273, 42.72348357785133, 52.59783083392728, 33.41597764722763, 3.2622377237965985, 0.07157730314159585, 0.0173696379117187, 0.06337921240276868, 0.06949852355906079, 0.08328157146611521, 0.008466066379520682, 0.055912536448769035, 0.05741611040467697, 0.09552851349355714, 0.0667341489104494, 0.06126813072290632, 0.02690074653665145, 0.03885552369719071, 0.05259711858666232, 0.010707631985086107, 0.014364510556803116, 0.05332929945941414, 0.007099714092609863, 0.0138521088182085, 0.0348326274674506, 0.04993696253927005, 0.004216167764107307, 0.010539178826635884, 0.030985393283528187, 0.06811702188344733, 0.04945913817913783, 0.06844155204993102, 0.026357032869371678, 0.027767036846207998, 0.009978330645319677, 0.10157974241601844, 0.03149579553264043, 1.0198377565510812, 17.45654767559421, 45.23955852754655, 57.032329190161924, 46.153137376231534, 34.536763545005556, 18.781977353557465, 28.08427437659233, 40.337697998169936, 29.910877058582923, 1.361624329320846, 0.1210760518968586, 0.9692110505796249, 3.1365978333257862, 5.978169691178107, 14.532675666193809, 9.469426274299622, 18.19529079621838, 32.813501588759884, 55.967990121533795, 57.29615565269225, 54.39894791572325, 52.876801567692915, 50.659999539775235, 50.01179256746846, 52.286045551300056, 50.77624290220199, 52.28074642919725, 52.97930486740605, 56.84714232721637, 53.58164364291776, 53.17272870771347, 51.82748517682476, 50.64172913951259, 52.20889645238077, 52.18875115917575, 50.87933455744098, 45.85971270838092, 40.16602762283818, 43.85151409333752, 46.33235046940465, 49.9123251822687, 49.73810918869511, 51.14897397256667, 52.55668909318986, 52.06912671366046, 51.09975999401462, 46.651450972403254, 41.70699742532546, 40.369559411079656, 40.073596969727554, 38.98808494690926, 39.95212116549092, 38.522334867908114, 37.4761289165866, 38.78896974748181, 39.613185236530924, 39.06254722226051, 38.31432765530002, 39.908724061904415, 48.58777215403896, 51.42763483908869, 55.10593160506218, 53.21647097987514, 47.75298587737545, 48.649412201296904, 49.255355634996974, 48.31497130855438, 49.80819017656388, 46.234679529743815, 50.43679314274942, 40.79544644201956, 31.514781290485015, 52.58578131275793, 48.067430526979514, 56.676444699687345, 50.46944295206378, 46.32320742453299, 41.479005736689416, 44.3824343527517, 39.388939411409446, 41.29221070197321, 39.615577882336034, 40.79492476678664, 40.968320984994214, 40.71275503404679, 40.78503647158223, 40.65667298532302, 39.72624363437776, 40.26983707181869, 41.44462223975889, 41.58636493067588, 42.00631349317489, 43.71124621360533, 44.40649024901852, 45.5361524704964, 46.401191988298976, 44.13678023122972, 43.52430997356292, 43.423383466659054, 43.45020071152718, 47.79049158096314, 52.67163415108958, 51.857385404648326, 48.51121141064552, 46.619534646311116, 43.3563893841159, 40.32219679124894, 40.88860273361206, 43.93312292714273, 45.806321405595355, 47.266082456035, 50.150950416441894, 52.74408425054243, 54.876029722152225, 53.27190191515031, 52.75240752004808, 57.33928211273686, 59.628408724261874, 52.67795701180735, 50.116417869444824, 56.654495116203066, 59.66653808470696, 62.06455753695581, 59.62598077712521, 41.90481824259604, 14.59164457936441, 7.482876200829783, 7.16387915034448, 8.812037033419456, 6.450624081396288, 2.2930421175495272, 0.06339597440655194, 0.0622114377667106, 7.276543349989, 43.474884187021566, 46.92330260430613, 26.209683456728538, 22.708593491585027, 33.124902479110226, 49.220575978679044, 59.5255288770122, 40.02288464576968, 4.440855537691425, 0.16448417948859353, 0.08082883372422188, 0.034852028644133004, 0.050713825490205526, 0.03441124463513975, 0.042188986760353854, 0.0639041971355196, 0.023611827655845595, 0.07045521415890225, 0.04368128007157676, 0.08987777235527193, 0.02791538402708548, 0.03614165722542713, 0.05311566051997004, 0.07459996433387842, 0.02176508461425622, 0.1927562866119608, 0.08555268508292015, 0.11835972628285808, 0.16602819905646388, 0.18319734792795875, 0.10579775357919355, 0.09475867939932693, 0.07516879227853591, 0.22837447212828746, 0.12305160113159688, 0.14683654742135158, 0.06802915159853236, 0.1888056631169973, 0.1542520027367338, 0.23873478474636234, 0.14333368699637153, 1.3692698868051654, 21.077799450966623, 54.63088158638247, 62.95461000934724, 53.548017163430494, 40.38800631800006, 28.069912618206395, 36.07218711606918, 47.899455024350075, 33.965944936198575, 1.5178009747497498, 0.4995033307181251, 2.081593025115229, 4.810629140946173, 4.066861218983128, 14.145715217436514, 24.316241625816595, 27.116298137172578, 33.05590406540902, 59.71586581199401, 56.8001837115134, 57.443087639347205, 50.773885557728434, 52.545561329011, 50.27108084770941, 55.540541987265314, 52.51133080451719, 54.77671923175935, 53.75091745007423, 60.37691462424494, 55.124680534485854, 54.42413737696987, 54.91492394478091, 53.45925000406081, 52.062752862130445, 53.44276428222657, 53.388827769987046, 47.12537134847334, 41.91049783460556, 46.68290053644488, 49.73804643077236, 52.37928813503635, 51.67150428218227, 52.60892329677459, 54.71485560940158, 54.33180086074337, 53.134007069372366, 50.44863477829964, 45.21441221237183, 41.51011013215588, 41.11025979441982, 42.161643274368785, 42.49642933568647, 39.8219023981402, 37.99707851102276, 40.861354028024984, 41.17184100612518, 40.80342846532022, 40.546309255784564, 41.95915091422297, 49.82415814553538, 53.67505488857147, 57.53473381842337, 54.15237595958095, 49.624988032925515, 50.92282972028179, 50.83217197848905, 49.68257234942529, 49.31122195336127, 48.163187349996264, 50.57120884618452, 43.197603994800204, 36.64725757414295, 50.75761164388349, 52.10587539980489, 59.19296287721204, 53.65441537672474, 48.07111363257132, 43.60183562001875, 47.0059234096158, 42.007054821137466, 44.143008955063365, 41.21567349280081, 42.57562591183571, 42.2217849762209, 42.78367627051569, 43.822892558190134, 42.191755310181655, 41.999229692643695, 41.00914109137751, 43.04996598151423, 43.65001801521548, 43.82692867709745, 46.58190734924809, 46.110865992884484, 49.561908475814334, 49.672087853954686, 44.93289978273454, 45.79518579667615, 45.3138364514997, 46.92056871229603, 52.12151781205208, 54.07352847437705, 55.17460446203909, 51.660427508815644, 50.070314330439416, 45.7747894717801, 43.52994641950054, 44.194874455851895, 46.77789641964821, 46.78980473549136, 50.801251934420684, 52.51883822102701, 56.60482222034086, 56.92584468472389, 54.98935876354095, 52.28699084251158, 60.98690594396284, 62.704598134563824, 56.07184663895638, 54.42118383223011, 59.07747653222854, 61.72992837044501, 64.25596614037791, 61.011212871920684, 45.90402764658774, 17.966357738740985, 18.218675967185728, 11.497338721829077, 16.34184733513863, 7.861575647707909, 2.5448376901688117, 0.2440696831552252, 0.14333771661885325, 8.733382724946546, 48.00810467812323, 49.05378110947148, 29.579201436811882, 29.479310435633508, 40.2021957981971, 57.88009851209579, 67.84820218240061, 49.10908260653096, 6.431865836343458, 0.3451386058042127, 0.23486859946241304, 0.23826492770064264, 0.239326082049839, 0.14005234855557644, 0.19715154753817668, 0.14023481537738156, 0.15058156823919666, 0.22816675504849804, 0.16338753994674454, 0.178198792761372, 0.10400645615112397, 0.17594624911585163, 0.1315796152958947, 0.19168584727712218, 0.10237786047641309], [0.020025773912728317, 0.02186381036505824, 0.010575299872265709, 0.04134038350574913, 0.09612491294260948, 0.05826976217870271, 0.03859386636665271, 0.05375258985065645, 0.0613196348140557, 0.06829850045183013, 0.05161971296934832, 0.045549098191963094, 0.03756072785284731, 0.0947763377259816, 0.10026931837801972, 0.014698821750860062, 0.22965219953367788, 12.796297304091915, 40.110694746817316, 47.9513087580281, 39.84674276844148, 22.699109200508367, 22.075213078529607, 29.786043705478793, 38.57340804992184, 19.312158246194166, 0.32166913452167667, 0.872495575777946, 26.003023578274636, 11.414193299508865, 4.823478825630681, 18.74050025017031, 7.1779810517064995, 21.76270607979067, 39.87439940052648, 56.67934333124469, 55.524017041729344, 53.895127311829604, 48.16896892363026, 53.39596256133049, 47.89696824166083, 48.804055567710634, 51.85083504646055, 52.41228311292587, 51.32178575761857, 50.01915877865207, 48.38371084582422, 45.74934505647229, 44.949056025474306, 46.90072544159428, 47.63444400602772, 47.087614613194624, 43.09148034741802, 40.713594421263664, 42.861723592204434, 44.68515896028088, 47.55809507062359, 50.83721614653065, 50.15327638195407, 50.65725780302479, 49.94073490942679, 51.74210694528396, 53.84995729692521, 47.89632497295257, 43.50664754067698, 37.334409759890654, 38.41212803317655, 37.156110578967684, 35.87271105858588, 37.151117401738325, 36.22896817422683, 35.53605794906616, 36.39735160335418, 37.30283468000351, 36.970825656767815, 45.5330773322813, 51.16279248268374, 50.71282994362616, 54.010974514868956, 43.40992581459784, 48.90521741682484, 48.666615716872684, 49.80921783754903, 49.18831448401175, 49.11189886831468, 45.30203011728103, 49.12781976884412, 38.67554264683878, 30.43154424236667, 54.46695789214104, 51.6528534120129, 52.6790984215275, 49.01457701959918, 41.12787123649351, 38.435262172452866, 37.31733568253056, 36.72596777639082, 39.48140536585162, 36.07463075268653, 38.772746824449115, 38.12133135334138, 38.46844150174049, 37.24334801397016, 37.92103552049206, 36.70987821394397, 38.87497163588001, 39.00675935129966, 41.726691645960656, 44.95683800789618, 48.887131367960286, 48.743917788228686, 49.68539645594936, 49.77377530067198, 47.104963256466775, 45.821226412250155, 43.84781137589486, 47.37439478597334, 50.454761520508804, 52.71153250048238, 52.081756745615316, 48.80070978595365, 46.0008317424405, 42.488898384955625, 39.718602857282086, 38.867860378757605, 39.18063017629808, 41.975824909825484, 42.90988637555031, 46.51551731171147, 51.25148903939032, 51.35273325827814, 50.47507155326105, 51.78376643888412, 56.02853974988384, 55.905338102771395, 50.29448170815745, 48.93800450909523, 52.47268761357954, 56.944377883788086, 59.30895913031794, 58.4163571173145, 46.929425424145116, 33.53155812909527, 15.136882470500085, 9.003251598727319, 10.487778494434973, 2.078023668258421, 1.300511105406669, 0.03504801308736205, 0.006987852327931192, 3.104515051649463, 33.06683178870909, 41.113938977641446, 27.16539444461946, 27.24018227669501, 34.52987978535314, 48.646027195838194, 55.25449137533865, 31.10548980774418, 4.024809488365728, 0.08243379558646872, 0.04700941116278691, 0.0023923657042154624, 0.06274147484932216, 0.06285022869105301, 0.10430244954242822, 0.014657176253686269, 0.011846478183513448, 0.04997903608807153, 0.02108798163282054, 0.06717362290909214, 0.022430010628135457, 0.06909189941061121, 0.04969570996059526, 0.0268313504620305, 0.07004639133810997, 0.04410636310856189, 0.06136975611650175, 0.02074964273150169, 0.028290554520583926, 0.076371542658777, 0.03456476482472593, 0.06673906719492328, 0.038565716465875026, 0.03802831727831114, 0.0873531066181679, 0.01682120131238574, 0.05134114807832146, 0.05168309525376366, 0.0243523282434551, 0.0667402699529644, 0.09383984120382417, 0.4754296612114676, 15.542148620851579, 46.44262006205898, 54.554073733668176, 45.38428221979449, 29.94774929938778, 29.624043933806885, 35.908122216501546, 43.48049709873815, 22.411568087916223, 0.5841361587086032, 0.8851630541105425, 25.71391155642848, 11.646508420667342, 7.375737640165514, 15.897204510627256, 8.07124202289889, 23.061108666081584, 41.27064158839565, 57.88967694005659, 55.32047740874752, 54.301590765676195, 49.9200326396573, 53.28601068066013, 49.255787095715924, 49.8816365580405, 51.807347728360085, 54.249101608030266, 54.33147530401907, 50.462782767511186, 49.06059426646079, 49.61645687780073, 46.316492326797984, 49.066787688962876, 48.47852237762944, 49.62351322174073, 46.88007024026687, 42.268025798182336, 44.17193251271402, 46.73261657837899, 48.701238478383715, 51.962842249101215, 52.777714652399865, 52.999477617202274, 51.05309555607458, 53.18898693207772, 54.275758035721324, 50.66895038850846, 44.930303173680464, 39.46435090034239, 39.85403053222164, 38.18832151351437, 37.99919659091581, 38.124018176909416, 39.092765162068034, 36.81522523203204, 39.051364544899236, 39.50485329474173, 38.48148338256344, 46.48962966857418, 51.82504546257758, 53.5618160616967, 54.799194412846724, 45.65875399497248, 49.20388237122567, 49.990749051493985, 50.202368767030784, 50.460664687618134, 50.14814199939851, 47.25828870650261, 47.59938193905739, 40.67210751195108, 33.33403933432795, 55.85980722981115, 54.41407649747787, 56.18275165557862, 51.66259265715077, 43.060987841698434, 39.53640484040783, 38.94777867101854, 38.32935817780034, 42.0241641998291, 38.22675681883289, 39.701972007751465, 39.922554339132006, 40.59060065977035, 38.345090804561494, 40.91780477954496, 39.243839171624955, 39.18132051344841, 41.79551747537429, 44.51202946324503, 47.19328718800699, 49.341875276257916, 50.83395665691745, 51.8565107160999, 50.92849754518079, 49.328539217672045, 46.97388156767815, 44.68668476227791, 48.520805528087, 53.92093650756344, 54.18341759712466, 52.94801612054148, 50.358526168331025, 48.34896256846767, 44.0362734179343, 41.62629465903006, 41.45272193416473, 42.68781354350429, 43.815255703464636, 45.9249613361974, 48.27542205010691, 52.743021288225734, 54.98060403331634, 52.55127229998189, 50.55185587175431, 58.83838453600484, 56.66860780408306, 53.049695722518436, 50.8553021953952, 54.953939760884936, 58.62805920262491, 62.702942894351104, 58.87590592907321, 50.91552234465077, 34.50212117164366, 11.683266912737201, 4.728895281591724, 8.820252437745372, 4.061231882341446, 2.10573251689634, 0.06521496591308425, 0.040235703871134794, 3.655949797361128, 38.29461382281396, 40.88259366250808, 20.967692636674453, 26.180481410795643, 35.42296424988778, 53.40589400260679, 61.48887518913516, 38.59443587641562, 5.536302433859918, 0.08276441615195045, 0.07652279139766771, 0.012606898972374058, 0.03479143875020166, 0.01845028345292855, 0.0569569785898972, 0.08692724600193963, 0.03682177859328447, 0.053493303562244104, 0.10713411735430842, 0.02627561495999896, 0.03647418151940069, 0.06047008544086449, 0.09798446114385322, 0.08466067528652568, 0.05710045919723569, 0.20930026177196734, 0.1148758648384002, 0.18880903390386414, 0.2041233613366081, 0.20251626208905252, 0.09709146309403643, 0.1725945838036076, 0.11967551293632678, 0.2334282009471809, 0.21348769836608442, 0.09300688146463326, 0.15500866777954564, 0.21125571652045175, 0.2479681207407867, 0.1846121744282784, 0.11618555343199162, 0.852033980190754, 19.725938881597212, 56.843596504580596, 62.136631088872115, 51.75869857111285, 34.233238773961226, 33.895824724628085, 40.912623328547326, 50.90668916702271, 25.173656056004187, 0.9508960946433006, 1.2062257840748758, 34.76425709262971, 14.894868308498015, 13.416183783162026, 31.165262806800108, 13.834785992099395, 26.556075811386112, 42.49850034713745, 60.29696495302262, 56.57042303392964, 55.25567200876052, 50.72400477624709, 55.49243803947203, 48.577370028341974, 49.981496180257494, 53.55816825743645, 55.040604529842255, 55.14602607296359, 54.32930623331378, 51.56305859165808, 50.22621677767847, 49.03959389655821, 52.38338308949625, 52.43504854940599, 52.165283618434785, 47.93041821449034, 44.0935988580027, 47.70627044862317, 51.2037302601722, 51.42412039541429, 55.121774058188166, 53.688963613202496, 54.81367972589309, 52.15261828514838, 55.712565375912575, 57.66516831613357, 53.04570274968302, 45.96973126934421, 41.039009940239694, 41.65227251668131, 40.114064062795336, 39.05086248151718, 40.507728822769664, 40.097080199949204, 38.31634375356859, 40.984583131728634, 42.18420866997012, 40.69487687080137, 49.75029207045033, 54.410126670714355, 54.72251992071829, 56.966664791107185, 46.182712047330796, 51.50685887182913, 51.54523534159507, 52.1662877451989, 52.649457070135306, 52.76486496771536, 49.917938093985285, 48.066273427778675, 41.874812110777825, 35.618023718557055, 57.08240216778171, 57.48084829699609, 58.221964451574514, 53.968934551362075, 45.26398312660956, 42.26452704398863, 41.27119072021977, 40.13387987690587, 44.81371856504872, 39.3628046589513, 42.611970593852384, 42.27141080364105, 42.871686412442116, 41.19357485924998, 42.495927272304414, 40.315528761956, 41.42412393323837, 45.46417305546422, 46.477234978829664, 49.66129349124048, 52.98704370375603, 53.8300944143726, 53.60427179644185, 53.94618088199247, 51.774811667780725, 50.18878559912405, 47.07325481599378, 51.79908329440702, 54.94952709444108, 56.91533273266208, 54.890009049446356, 52.95194241308397, 51.69214379402899, 45.63635333891838, 43.79448675340222, 43.50889505878572, 44.24417472654774, 46.11280364374961, 48.59891560769851, 51.525462673556426, 56.30077185169343, 56.50228754166634, 53.329902002888346, 52.386972058203916, 58.36534277085335, 60.48729012089392, 56.1773701637022, 54.39035400267571, 59.11577063222086, 63.6740433016131, 66.37660734115109, 61.41412265839116, 52.13359871218282, 39.92885366562874, 19.974113125954908, 17.41165614897205, 14.994919146260909, 7.136356859437882, 4.354587418417777, 0.35093874940949105, 0.20798992966451954, 4.358378389189321, 44.3201078907136, 53.840731882279925, 38.10357870594148, 38.37680316740467, 46.351848571531235, 62.7385344812947, 71.37424038302514, 46.699570609677224, 7.779650572807559, 0.19180891164127858, 0.13403459001452694, 0.05265215434314263, 0.1481354648187276, 0.18832606143288075, 0.19162665932409226, 0.19006434557659013, 0.09581699922320344, 0.20373811104124595, 0.25200992402049804, 0.18803894700061893, 0.09642079142072509, 0.23514500398549343, 0.17239523240395133, 0.24805470399798887, 0.19418623568790574], [0.02274312799976718, 0.01794598883979263, 0.06369587867670963, 0.10276667308062316, 0.020139896115588567, 0.03886889576190903, 0.02236963140838329, 0.01171605937528394, 0.07409091422995252, 0.04827909847541202, 0.0194437520187949, 0.05232364051945267, 0.04159662076422284, 0.02861842483041748, 0.05979968955920589, 0.03984105750738133, 0.4344503924010262, 13.683643341064455, 39.647792308561264, 48.83293990165957, 38.03904002712619, 19.169130979045747, 15.744115383394304, 27.008664377274055, 36.93283750164893, 17.899155770578695, 0.2934255871561266, 1.1261417716741562, 23.60787137862175, 9.500962130485043, 9.133590978960838, 11.566706818919029, 10.994201590937953, 27.370667765217444, 45.85288778428109, 56.583127590917776, 53.799460703326815, 54.697377527913744, 51.178156406648704, 53.414052532565215, 52.808556249064786, 51.96517605935374, 52.94343479218022, 54.35156960641184, 51.678144854883996, 50.15061701497724, 46.40440833184027, 43.543129505649695, 44.64804549371043, 44.9626862618231, 43.58316121562835, 44.396366611603774, 44.73300795401297, 43.823763324368386, 43.85898620851579, 46.5603421580407, 50.5536287830722, 50.48137480212797, 50.642670508353945, 51.42064125307145, 49.63863788112518, 50.46427326817667, 50.380401226782034, 47.19819015072238, 41.507403696736986, 39.83062967177361, 41.341660022735596, 37.73584081280617, 37.24759201849661, 35.90822027575585, 37.042185337312766, 35.0393525246651, 37.10833611026887, 37.55306228514641, 39.11684067018571, 48.09009398183515, 49.63467236488096, 53.384905399814734, 46.138608917113274, 44.969326834524836, 51.78091879813902, 49.46360995692592, 51.79307422330303, 48.036086866932536, 48.72248595760715, 47.62759554770685, 49.95434553392472, 40.43863627218431, 31.41463141287527, 56.96067925422423, 49.01535757126347, 49.253782764557876, 41.71014708857383, 40.82805702763219, 38.43924730054794, 40.695943755488244, 39.091961076182706, 37.664979273273104, 35.773396645822835, 37.58775172695037, 37.08500977485411, 38.92574279539047, 36.423125497756466, 37.58016194066694, 35.368537441376716, 38.17509135892315, 40.026336331521314, 44.576415169623594, 47.17630332516086, 49.31892156600953, 51.93136522846838, 53.42500379008632, 51.87394565151584, 52.49882236603768, 51.31820463365125, 50.184863228951734, 51.26601749850858, 53.23291355563749, 51.571781942921305, 53.562133773680664, 48.44996360040481, 46.01912567692418, 42.04015178065146, 39.31372011861494, 39.43098721965667, 40.07925302751603, 39.45789860140893, 41.32695897932976, 48.173310987411014, 52.80967804693407, 55.428244529231904, 55.55732580923266, 52.29510230402793, 54.89598674158896, 55.02224783743582, 50.727762406872166, 51.30150318145753, 50.110479401003936, 56.977772943435184, 57.49253696010959, 62.7583424506649, 47.00487613677979, 29.613277027683875, 14.032226339463266, 4.765530219001155, 8.978413189611128, 7.799731637201003, 2.29726601992884, 0.10384905572620132, 0.08158315453798541, 1.9224080443382265, 31.73854074170513, 52.41407955846479, 37.403851401421335, 28.406708894237397, 43.077336280576645, 51.10450213955295, 53.42716109368109, 35.166453007728826, 4.524052441120148, 0.05236591325111447, 0.05488098756740651, 0.031502494971538265, 0.04558437654087621, 0.055758801754564054, 0.05637328470906904, 0.01699158309718534, 0.042120674700145765, 0.02952216151771286, 0.012781701084496755, 0.03407802320115509, 0.03322073250948902, 0.007323615258604649, 0.06486193727581732, 0.039190453507246516, 0.056693260482842886, 0.060761126073738264, 0.030232635289130193, 0.0492472305984026, 0.04943297627652365, 0.1314202230423689, 0.050935814788024274, 0.0033658858193385027, 0.06697367396085493, 0.02752602750044917, 0.06467833664388427, 0.054830077194398454, 0.09051964678350957, 0.08588208756860226, 0.01880006579261634, 0.07251919292274021, 0.049536708411910844, 0.4781021742570785, 15.63879680248999, 47.877811385739236, 55.058698423447154, 42.53668069839478, 23.080593039912564, 18.118131891373668, 29.33125468992418, 43.206146917035504, 20.81412596087302, 0.13297915068124572, 1.3660732776887956, 26.549192051733694, 14.644458313142101, 12.102711450669075, 14.162175443864639, 9.816085350128914, 25.727375092044955, 48.650549688646876, 55.80636101384317, 55.824439217967374, 54.129959614046165, 52.19019851376934, 53.617011654761534, 54.548531424614694, 51.91526389891102, 54.93161362986411, 56.17584436170517, 53.16737859479843, 51.04468599442513, 48.626132934324204, 45.21649499093333, 46.4290015928207, 46.554462525152395, 47.54290373094621, 46.2090507630379, 45.84059899853122, 45.99233196627709, 45.743532103876916, 48.437635590953214, 52.4442151284987, 52.04365091939127, 51.393820085833156, 54.366898229045255, 52.89720181495913, 52.408192080836145, 51.80302919880037, 48.110415781697924, 43.86024921171127, 41.93951160677018, 43.29152514857631, 39.558770195130386, 39.15096136831468, 37.97623503592707, 39.355803228193714, 36.87189171391149, 39.60692121136574, 39.366303413145005, 40.476765632629395, 48.6452897902458, 51.42618356212493, 52.74454709022276, 46.83216633335237, 45.83200508548368, 54.262402365284586, 51.41735038449688, 53.489413030685924, 50.069977006604596, 51.675277602288034, 48.80793086944088, 49.99640903165264, 41.71259464756135, 32.91904864772674, 55.16425332715435, 51.8210603344825, 52.04921284029561, 44.35632705688477, 41.380040414871715, 41.113260407601636, 43.37305945734824, 41.7220240254556, 40.59208723806566, 38.12718745200865, 39.53207846610777, 38.76639650714013, 40.33498764038086, 39.08118632531936, 38.837818945607836, 38.10808943163964, 39.657613923472745, 43.18335794633435, 45.51547765731812, 49.9678227978368, 51.043069977914136, 52.73725148170225, 54.256518810026115, 54.91421007340955, 55.263155891049294, 52.79021916850921, 52.81642060126028, 52.55023287188623, 55.86323145897158, 52.39586799375473, 53.83603288281349, 50.94131192853374, 48.591314054304554, 43.59632468992665, 42.74697073044316, 40.99405173332461, 41.20512623940745, 41.35473328251993, 43.35908013005411, 50.91072136355985, 55.64910927126485, 57.240795320080174, 55.29897889783306, 52.51202898640787, 56.917654775804095, 58.39647070054085, 53.261197766950055, 52.06179972617857, 52.63301841674313, 58.71960732244677, 60.46030813647855, 63.44431400299073, 50.07615081725582, 35.67907541028915, 24.069149955626457, 11.754233375672372, 5.620208795993559, 8.026124469695553, 2.943461306633488, 0.17827230655858595, 0.029154412500980883, 2.370236078577657, 33.37370626388058, 56.81227637875465, 45.39524916679629, 36.02795454763597, 47.85341032089726, 56.54701825111144, 59.556327327605224, 40.52998435112738, 5.47896130431083, 0.10030828927072788, 0.04008240584704665, 0.026459213676712206, 0.008442695909780602, 0.024218241789288098, 0.020044583286489212, 0.07080701705549033, 0.08970227693357775, 0.022033569703419364, 0.05183501815002772, 0.0422779448901213, 0.03519116810733273, 0.10046195118658005, 0.05076193198141071, 0.043626497124111464, 0.02631821902468801, 0.12524142515875641, 0.15615724808266088, 0.19255678199471968, 0.14707924407576362, 0.16633379152945935, 0.14482904465929156, 0.12432232649335939, 0.14578345231711864, 0.16151181962941924, 0.09059424076469676, 0.13039827707313723, 0.15061357539267312, 0.17098288802850634, 0.1819312344155004, 0.13176545290456665, 0.09792903468253152, 1.038601456149932, 18.904978959791123, 54.611905159488806, 63.30856861606721, 51.62584397100633, 29.29549836343335, 25.491717130907123, 38.666544729663485, 51.09863819614534, 24.60936623234903, 0.5994091327151945, 1.783928765404609, 28.85825214847442, 15.196380903643949, 20.404361832526423, 18.90606349514377, 15.74305045989252, 29.48374467511331, 50.83276425638507, 57.00304477445541, 57.59485590842463, 56.75237786385321, 52.680887022326075, 54.744783293816354, 54.82494869539815, 54.24341024891023, 56.289997100830085, 58.08681526491719, 55.45257106904061, 53.750827235560266, 51.664879398961226, 47.79174281704811, 48.6613989645435, 49.07362045780305, 49.55860191775907, 47.91696840716947, 48.58204941595755, 49.524167430016306, 48.96205648299187, 50.71511276306645, 54.895680796715524, 53.22347633300289, 54.353562170459384, 56.36507911066855, 55.136447645002804, 56.169980418297556, 54.140283292339696, 50.40555930906727, 45.14267990666051, 43.565416412968794, 44.694862904087195, 42.14545173029746, 42.59102513713222, 39.76299232052219, 40.655755150702696, 39.44664139901438, 40.67399024963379, 42.347081169005364, 42.08221135600921, 52.67963186387093, 54.24723455982824, 56.24820424664406, 46.58208385590584, 47.80586727203862, 55.980894719400716, 53.431342340284786, 55.20621484325778, 52.755215937091464, 53.517705086738836, 52.038826404079316, 51.62853863931472, 42.281675646382, 37.507735375435125, 57.980891658413796, 55.682021879380756, 52.994594266337735, 45.67549074849775, 43.22672759332965, 42.629511433262984, 46.77067533616097, 44.328744949833045, 41.793815166719504, 40.397639659143266, 41.930325415826616, 39.72993458470991, 43.807183465650006, 41.58204247874599, 40.99387914903703, 40.09180853443761, 42.63057047320951, 45.23288657588344, 49.0565973712552, 51.60958966901226, 54.56316971009778, 55.008374414136334, 55.97694881500737, 55.97042199104063, 58.27058615223054, 56.866291338397616, 53.84384232182657, 55.744583683629195, 58.255767437719534, 54.02034897958079, 55.62192332360053, 52.82926244120444, 51.34783029556275, 46.62970535216793, 44.88679624372914, 43.37470293045045, 44.782578868250695, 44.33549927126977, 45.66992882759341, 52.92539581175774, 59.223141593317834, 59.10535673941336, 55.53441916742633, 54.000097782381125, 60.134386631750296, 60.728425671977384, 55.401870512193256, 55.074156484296246, 55.69873902105517, 62.529079914093025, 63.125578280418154, 66.04147218888806, 53.02658119509297, 35.475261211395264, 17.85467609282463, 8.893958676245905, 18.819314395227742, 16.824020378051266, 5.349067113091869, 0.34634289602118157, 0.21159812717908816, 2.9893645596119667, 41.36564531633931, 65.39280629927113, 46.62835213445848, 39.228757658312404, 55.880078038861676, 63.89843425443096, 68.34107937351351, 50.25288497248004, 7.411196847115794, 0.18062172968301082, 0.1417303569014034, 0.15546769234201602, 0.09331774462254779, 0.11409018038501663, 0.1644348127827529, 0.09010564520834916, 0.14987738021919805, 0.20559282522768746, 0.11508729744462237, 0.11974133521078095, 0.12403476006922223, 0.18066023326208516, 0.1528199852233933, 0.1796676744256289, 0.10780131098844352], [0.0295890505696016, 0.03201081729193609, 0.041758958625817494, 0.0385468285681019, 0.1026701613239223, 0.05997080295797318, 0.023915997120521726, 0.036756967554890344, 0.09751956834788285, 0.11094264686107637, 0.021079004997567787, 0.041764060771393205, 0.11803269866974124, 0.04388608218681428, 0.08729139057498786, 0.07607446142262028, 0.3881699790156657, 12.012241982644605, 36.889632594200876, 51.58445512094806, 41.32011052100889, 26.13781386806119, 21.677757347783736, 34.24123648674258, 40.023053307687086, 14.286796988979464, 0.09786906531981884, 1.0223097690651495, 16.391051507765248, 4.534437896743897, 7.3125227612833825, 12.917996683428365, 10.15161862296443, 32.08087736560453, 51.80392742156983, 53.85963770651049, 53.70603376819242, 51.99231886094617, 50.09229921525525, 55.49261062375961, 51.78540991198633, 55.1337137529927, 54.608500542179236, 52.22636668912826, 51.65005676208004, 45.89907761543028, 43.20638225924584, 42.33547879803566, 42.212688999791304, 45.426694808467744, 44.78672481352284, 45.55909441363427, 43.33450255855438, 46.78732971991263, 49.33387364110639, 49.31005700942009, 51.393090524981105, 49.61900249604256, 47.155000932755016, 44.45831260373516, 41.55255017742034, 42.60296875430692, 42.45904522557413, 40.44744199322116, 38.71933198744251, 37.249655185207246, 38.43794899602091, 36.800814444018954, 37.21793105525356, 36.18842655612577, 36.5682335822813, 36.9013173349442, 36.59805144033125, 35.77961752491613, 41.928513280807, 48.0450455604061, 52.20664501190186, 47.042385762737645, 48.73115831805814, 50.584960676008656, 52.032625136836884, 52.69019480674498, 47.822345149132516, 47.54328027848275, 49.32197317000359, 49.027834630781605, 51.58418055503599, 45.410824898750555, 30.897157038411788, 54.72182566119779, 50.399589461665, 50.02101798211375, 42.78904991765177, 43.57923100071569, 47.258798614625015, 48.57086673859627, 47.65870778791366, 48.20541950964159, 41.88553587082894, 39.398745336840236, 37.215495263376546, 38.87499909247122, 36.67507894577519, 37.10614742771272, 37.53126959646902, 37.85245680039929, 39.41812184549148, 42.532503374161266, 46.94075715157294, 50.83851837342786, 52.5537080918589, 53.169163273226836, 50.34405654476535, 51.26097725283716, 51.9269133383228, 51.25530550556799, 53.540933362899295, 51.65658358604678, 52.68927697212466, 52.38318697098763, 47.48285616597822, 44.61931805456839, 40.30404798446163, 39.45978918383199, 36.297135045451505, 40.43785572052002, 37.05387400042626, 43.81065868562268, 49.98954096148091, 53.639757479390795, 51.96969462979225, 45.429114910864065, 46.77616665440221, 55.911009850040564, 54.27906067140641, 56.53173669692009, 53.39466425680345, 53.20935580038255, 52.83308282975228, 57.75671251358525, 50.69011942032845, 50.370595301351244, 42.74226780860655, 28.63237265617617, 10.089032303902412, 3.7549786125459983, 2.1256233463364262, 1.464293594321897, 0.16637085486323605, 0.05857715878875987, 1.1256370116626064, 23.481988791496526, 45.780061137291696, 22.62415466770049, 20.779005058350105, 30.426953108079974, 48.16373255945022, 51.12968767842939, 32.828241855867454, 4.8493944156554445, 0.02371779293753207, 0.0558184263777108, 0.017182595629785812, 0.08344578241268474, 0.11895074013380275, 0.0775859222537087, 0.07537048024636123, 0.026733469323164998, 0.054328710952353094, 0.04572627900709068, 0.023756020724953666, 0.07558928261841498, 0.06061070470980579, 0.05338596315273354, 0.0420594910880731, 0.016967619866913846, 0.036144698594486525, 0.017127711175670548, 0.07214030115714959, 0.05637545273789475, 0.08247142582530938, 0.024415164690224395, 0.03374630329950202, 0.030202077957050457, 0.05238287060731842, 0.07029511710448612, 0.018209772064320503, 0.07015958082892242, 0.05522528280233664, 0.012809471771751922, 0.036559768862301306, 0.03802364031153341, 0.790868355862556, 14.69823891116727, 44.539152652986594, 59.1772420175614, 47.474179883157056, 28.203233980363418, 25.00014020550636, 37.63360815663492, 43.159200068443056, 16.564502639155236, 0.07865325127157473, 1.6331116710939717, 16.376751526709526, 5.882504063267862, 6.700219694645175, 8.886557163730744, 10.157486488742213, 31.98062158400013, 53.520376220826186, 55.470672807385846, 54.75210635892807, 53.44947153522123, 51.81461588028939, 54.96591867939119, 51.964932872403054, 56.75506468742125, 56.47859642582556, 54.397881031036384, 52.993131222263465, 49.58133205290764, 46.47072384434362, 44.95554362573932, 43.76467674009262, 46.835563105921594, 46.278206071546, 47.09775394009006, 45.62417437953334, 47.802984329961966, 50.48535993022304, 52.262605467150294, 54.15651406011274, 51.57097785703598, 50.818561353991115, 46.91187673999418, 44.739217065995746, 45.91816386868877, 46.27515054518177, 40.97017234371555, 39.8213218873547, 40.031168691573605, 39.489352087820734, 38.58636756097117, 38.11759725693734, 37.538223958784535, 39.053204136510054, 37.695785568606475, 38.38795446580456, 37.67112170496295, 42.01280893818025, 50.63123287693147, 54.47800720891645, 47.164951985882176, 49.84868472622287, 54.047127000747196, 52.85460095251761, 53.387396104874156, 50.224545847985056, 48.26858928126674, 50.30289519217707, 50.403794242489724, 50.60013632620535, 44.57777623207339, 33.43987664868755, 57.64378747632427, 52.923226741052446, 53.60892764983639, 45.12577056884766, 45.006228493105986, 48.93190522347727, 50.37440392278856, 51.31185431634226, 49.737909147816325, 44.144421008325395, 40.625647037259995, 39.074581053949174, 40.332653830128336, 38.661410347107925, 37.80456073822514, 38.883392964639974, 40.79812149847708, 41.59754368566698, 46.70046098770634, 48.78094888502552, 51.987372752158876, 54.89484925423899, 55.07158340946321, 52.44431711012318, 52.60432235656246, 54.65262328424762, 53.36958069955149, 53.93819493632163, 53.037822708006836, 53.11638778255832, 53.653289656485285, 49.60021434291717, 46.99889452226701, 42.774093920184725, 40.50206884261101, 38.82604006798037, 40.746161860804406, 39.448759478907434, 45.38605120874221, 52.78613598115983, 56.63478912845735, 53.92039522047966, 47.520138294466086, 47.50166393095448, 57.66397199323101, 55.3678321838379, 58.826672338670306, 54.936681332126746, 56.042295502078154, 56.108348215779955, 59.28418936267976, 55.63286281401112, 53.64415053398379, 38.563088293998476, 22.851809032501716, 9.9966065537545, 11.897217496748894, 6.322111054774254, 3.354360715996835, 0.2843034411630323, 0.04816149631815572, 1.2528446244616664, 26.980464496920188, 50.072883482902284, 28.398440537914155, 24.4151500732668, 37.698605752760365, 53.416480479701875, 59.99511895641204, 39.37723898118542, 6.052695705044655, 0.043287487895858866, 0.1595623863320197, 0.024875077914686936, 0.04668208860581921, 0.05140150814587551, 0.01835656983237113, 0.042624193649258346, 0.11766723642546324, 0.019679509831832784, 0.012260417514030012, 0.015083838389405321, 0.016431174458815687, 0.041527672851037596, 0.020772102514221784, 0.055939169495456645, 0.027168002054696123, 0.12015158295511238, 0.09145021378513306, 0.1667602726769063, 0.14365968805166984, 0.3405665930721068, 0.1374189213158623, 0.13565258303236577, 0.070593623264182, 0.2031665175191818, 0.21207860220343838, 0.15382743680909758, 0.1269221914211108, 0.19257657770668307, 0.13436419168306937, 0.18177371141650986, 0.13748650559254233, 1.357883123620864, 18.421452699169038, 52.25304272867019, 67.82345987135365, 56.97366229949459, 36.68062125482867, 33.43453830288303, 45.86841252542312, 51.29657668452109, 18.852181896086663, 0.23848367644654167, 1.5655548510051545, 22.575558462450584, 8.223852620970819, 14.132138913677586, 21.318336840598814, 14.334475359609051, 34.90417588141657, 54.57996529917563, 56.38251796845467, 55.44234152763121, 54.142852444802564, 51.56840085983277, 55.36477665747366, 51.65755633384951, 57.66661959309732, 57.64334032612463, 55.49250471976496, 55.63951123145319, 50.74395395094349, 47.04355855141917, 46.86869928913732, 46.4631183685795, 49.02695209749284, 50.19426515025478, 49.922676317153446, 48.29057416608257, 50.63304501195108, 54.89489240031089, 54.703421900349284, 56.10376296504852, 54.28040212200534, 51.82525334819671, 48.78272571871358, 46.258943311629764, 48.20890649672478, 48.138029267711026, 43.65800003851614, 41.781122376841886, 42.12396890886369, 41.17114282423451, 41.039080542902795, 41.26882160863569, 39.19963013741278, 40.21297447143063, 40.18579636850665, 40.25008401563091, 39.27164877614668, 44.69716925774851, 54.24843872747114, 55.93927444950227, 47.97457625789028, 52.51218588121476, 54.78597994773619, 56.888558633865856, 57.333708424722, 51.968604210884344, 51.523505410840436, 52.50348998654274, 52.90825897647489, 51.922712479868245, 47.22556044978481, 38.04481767839001, 58.814767945197325, 55.72009240427325, 55.05810614555113, 47.28649447041173, 47.79667323635471, 52.878601935602006, 52.44665484274588, 53.162067705585116, 52.37921361000308, 46.00354210022957, 42.50953397443218, 40.90513160151821, 41.372713427389826, 40.35867875622165, 39.636899886592744, 41.64991909457792, 42.54583551037697, 43.94188942447786, 48.23225636636057, 51.36208418876895, 55.39626544521701, 56.452124349532596, 55.616647735718765, 52.88884324412192, 52.51873623940253, 56.1279365324205, 52.88326563373689, 56.273809479128936, 54.81685292336249, 53.03685388257427, 56.72969871951688, 51.502626634413204, 49.05356930148218, 44.864713299658995, 43.02292908391645, 40.069070554548695, 43.383465505415394, 41.67423778964628, 47.73439776512885, 54.541879084802446, 58.778344815777196, 54.52466772448633, 48.38571909935244, 51.67724663211454, 57.75106037816694, 59.02091595434374, 61.10996638574908, 58.071098327636726, 57.662371666200706, 59.69759148936118, 61.80459068667505, 60.32127188098047, 56.67835489396126, 43.31231371048958, 32.69783873711863, 19.516378410400886, 13.651538741204048, 8.842607986542488, 5.519859367801297, 0.7857890703505086, 0.1325847073307922, 1.7009573982607935, 30.81861157571116, 54.73889973855788, 31.350637943513934, 29.989338190324847, 43.4095492670613, 61.4310202290935, 66.44307582609116, 48.02804208570912, 7.939374389186983, 0.13236539167982916, 0.29609901950724665, 0.09889402967547217, 0.1624400883672699, 0.19268916198803535, 0.14040196044070108, 0.23783072438691896, 0.31356079864405817, 0.1797477152919577, 0.13332353784672676, 0.08674386753550462, 0.28485104081130797, 0.1783477355756106, 0.2685887102157839, 0.13555882919219234, 0.06296139954018497], [0.051185931003982985, 0.07097765547974456, 0.05348755024193276, 0.11206409232991357, 0.09627265299880698, 0.052795654102679224, 0.06849941467085192, 0.034613660386493134, 0.006898486735149017, 0.02794603137449632, 0.004979477662052359, 0.033720669997555595, 0.03103625194560136, 0.015380261747557071, 0.0645351624717155, 0.02753049953870716, 0.9596556052565576, 14.984630769298924, 36.183390232824514, 41.636288858229115, 41.30751579038559, 27.301208473020985, 14.899101526506486, 30.93594143467565, 37.402262841501546, 9.994452191937356, 0.0372572421216436, 0.33977991270442165, 14.640470243269398, 9.500947421596898, 5.209117925936177, 9.078159063093125, 10.990821488441961, 33.61784242814587, 52.11227670792611, 53.85031423261089, 56.279163514414144, 49.4758399071232, 53.326426782915675, 51.85454953101374, 54.70717560860419, 54.22472799977949, 52.64235365775324, 51.74914759974326, 46.82602782403269, 45.712706196692686, 43.178439294138265, 42.23443069765645, 40.96672458033408, 40.02036648411905, 44.93546109045706, 46.96011797074349, 45.83601767016996, 46.22183768979965, 47.75250734821443, 47.117903155665246, 47.01197170442151, 41.08545864782026, 37.32555304804156, 35.96656945443923, 35.20759867083642, 36.73130612219534, 37.21897832808956, 36.250784397125244, 36.578443511839836, 37.062409077921224, 37.51077913468884, 36.82466245466663, 40.66297623418993, 38.42377747258833, 35.52750325972034, 37.082448467131584, 36.652035021012836, 36.724955804886356, 39.40216172126032, 48.02528858184815, 50.07412687424691, 51.60493381561772, 51.6814318010884, 49.51936644892539, 45.98799774723668, 45.22882692275509, 44.9617370482414, 43.47895560726043, 46.65038801008656, 49.43531397850283, 52.00394084376674, 46.434406618918146, 33.024297606560495, 53.399096535098174, 49.94520248905305, 49.715265304811545, 48.05074868663665, 49.29306530183362, 49.15482528748051, 51.59326868672525, 51.97569193378572, 51.75731005207185, 50.62005412194037, 40.679826736450195, 36.997262431729226, 39.41091252911476, 36.86646707596318, 39.733845187771706, 37.94770371529364, 37.2065326475328, 38.9066957658337, 41.60331741456063, 44.7411076484188, 50.61092284417922, 51.94625454564249, 52.10148234521189, 50.73420686106528, 51.44133567810059, 51.718027514796105, 49.73588912717758, 49.534561710972945, 48.83253589753182, 52.213681743990996, 53.651222567404474, 50.07442497438001, 44.61388164950956, 41.524309112179665, 40.05014904083745, 37.443412426979314, 38.44522499269055, 37.49595649780766, 41.18472206977106, 49.53194549006801, 54.933527746508204, 50.94763478925152, 49.16353687163323, 57.19895539745208, 54.27043537939749, 54.537815509303925, 55.530218308971776, 58.42195433955039, 55.892861043253255, 57.177735374819854, 55.09671795752741, 58.84475838753485, 55.50007489419753, 37.520000626963956, 34.234027170365856, 17.10409918139058, 5.7513566747788465, 6.257402733449013, 3.077124405291773, 0.36014743269451205, 0.03620140442264177, 0.8419305674972073, 20.570476170509092, 52.529969907576046, 40.93747154358895, 24.859201600474698, 36.60602954126174, 46.36784791946412, 54.88219176569293, 27.59152270132496, 6.6792031449656335, 0.062061855269055215, 0.04225835219145783, 0.029944645601414868, 0.043017012893312404, 0.026491678567723404, 0.1358884002172178, 0.06873445044602118, 0.020055354482704596, 0.04063654788619569, 0.0884900117413171, 0.027054647854979963, 0.03469661621737384, 0.1202174282122043, 0.07778790899582448, 0.04829848816077556, 0.031863632649483706, 0.022961719697641752, 0.05971492193038425, 0.01114725537087408, 0.02119698445312679, 0.06920741780871345, 0.025231555862832936, 0.10068906561261225, 0.036825716285215276, 0.010866013960161758, 0.04164340958419827, 0.039220189210027456, 0.00539763143376237, 0.07766892788030448, 0.012767790843011632, 0.06365878469941598, 0.055709124783114086, 1.520875622668574, 17.975775349524714, 44.44092865913145, 51.34660651606899, 47.768134070980935, 30.025706406562563, 20.404916847905806, 35.51234329900434, 42.600470204507154, 11.752591863755258, 0.07547669067618347, 0.2741356464403291, 17.77980589097546, 7.75251659654802, 9.398485306770572, 11.933684752833459, 8.076171461612947, 37.731035909345074, 52.00922819875902, 54.36132061866022, 55.46935096863778, 51.17654039013771, 53.655874498428844, 52.294090332523474, 54.61410953152565, 57.5650066714133, 53.295212561084384, 53.39125179475354, 47.65914317100279, 47.0104419800543, 45.24397903873075, 45.41113476599417, 43.69013601733793, 42.877852378353, 47.685144562875074, 48.43512919641311, 46.124433471310525, 49.49045073601508, 49.558648986201135, 50.294913168876406, 49.50083717223137, 44.09159060447447, 39.632349937192856, 38.19494639673541, 37.23679373341222, 38.84248264374272, 40.928901164762436, 38.83183733109505, 37.93736434751941, 39.71777523717573, 38.01875745096515, 39.61602503253568, 40.72935450461603, 39.8056088724444, 37.43873303936374, 39.24564346190422, 36.98968049018614, 39.88640577562394, 41.163196102265395, 50.29325008392335, 50.993259799095895, 53.15139493634624, 54.427188980963926, 51.88898794112667, 49.04876832039126, 47.30115236774568, 47.32123882539811, 46.51088107016779, 48.995886925728094, 51.11492779947097, 52.826689366371404, 45.64358226714596, 36.6580048684151, 54.329117959545506, 52.15664655931535, 52.92103805849629, 49.92170749172088, 52.40905892464423, 51.05971651692545, 53.32816831527218, 53.481819322032315, 53.941446581194484, 51.427070017783876, 42.78854393189953, 39.17685293382214, 40.20312539992794, 39.26461596642771, 40.30034134464879, 39.72753801653462, 39.334693031926314, 40.06237899103473, 43.7397853789791, 46.20322604333201, 51.75021448443013, 53.484368862644324, 54.7225748339007, 52.50987168281309, 52.29068963758407, 52.78988184467439, 50.589169379203554, 49.747142407201956, 50.09387208569435, 51.631653001231534, 53.937398695176654, 50.91488299831268, 47.68841189722861, 42.60037214525285, 41.50823916158369, 40.467544140354285, 40.35437983851279, 38.95616077607678, 44.11680752231229, 51.84634001024308, 57.676884435838275, 53.12128290053337, 50.65048779210737, 55.62295098458567, 53.70502179668796, 57.69670809468916, 57.86639375071372, 58.543390920085294, 58.9475009518285, 57.680304742628536, 59.411172174638324, 61.112115844603515, 55.34037559263168, 39.07560871493432, 28.942418367631976, 11.986597526458002, 7.211777173703717, 7.772208365701861, 4.147275936219001, 0.3318134563103799, 0.03768607132857846, 0.598746374730141, 23.241920125099924, 54.50042355445124, 38.60647755284464, 28.47296949355833, 39.533011990208784, 52.40185353063768, 60.62041144217215, 35.86090472436721, 7.891249848950294, 0.01701105322178093, 0.06255880118377748, 0.06482942450431085, 0.04051500420656897, 0.062305509533372626, 0.0860794471396554, 0.0333369710302401, 0.05183404521836389, 0.053651600310038176, 0.011823509909933614, 0.01183567921661081, 0.028444520956386003, 0.037293033749465986, 0.041189104123341466, 0.05147841188215441, 0.051439674646263166, 0.12591069489116632, 0.15535397425053582, 0.17953592262441115, 0.2485090094588457, 0.16304883715366164, 0.16865378155583338, 0.23677514715781137, 0.08643318823869191, 0.08001519472248132, 0.15451130817734426, 0.10262746724390215, 0.14020988687632546, 0.21119962356263594, 0.11869536472424386, 0.16638289776540574, 0.11185301212413658, 2.170381022076453, 21.497334203412457, 53.53305332122311, 58.73398280912831, 55.148889403189386, 37.16020553342758, 23.700666812158403, 42.621576478404386, 49.44299005693006, 12.995109500423556, 0.25271932143838177, 0.5266235480385443, 17.88056177477683, 17.09401280649247, 14.542054053275818, 19.54742200912968, 15.630715739342476, 38.7865064990136, 55.51832960497949, 54.87963438034058, 55.16547710664811, 50.82701798408262, 53.60492683226063, 51.403916266656694, 56.66463444309851, 58.24006226754958, 55.51423465051959, 56.08131131818218, 49.33548965761739, 49.454494368645456, 48.175056442137695, 47.63194937859812, 47.36969186413673, 43.81487131118775, 50.16379617875623, 52.107997402068115, 49.10889041039252, 52.09567723735687, 52.41624078442974, 52.32013094809748, 51.00823148604363, 46.198170108179895, 40.36060071760609, 41.8519054689715, 39.00514333478866, 39.92021660650931, 42.238486428414625, 40.17369977889523, 39.700952191506666, 40.84941433322045, 40.98287297833351, 41.27095537800943, 43.17212427816084, 41.6220663439843, 40.66874211834323, 42.570871999186856, 41.17104868735037, 41.902602103448686, 42.23322260764338, 52.47680610226047, 52.583514182798325, 55.86725973313855, 57.447774871703125, 53.0488641800419, 51.3994800659918, 48.12778795919111, 50.887304813631125, 48.27545735143846, 51.056496251013975, 54.19993077555011, 53.35608382378855, 47.0686185744501, 41.74100045234927, 55.40899745879635, 54.34264621426983, 54.102236301668235, 52.79530256025253, 54.92938964597641, 53.403940662260986, 54.965094981655, 56.60422602007466, 56.4048009534036, 55.37313915068104, 45.10284823756064, 41.34992837905884, 43.07301775101693, 41.87805198854016, 42.38958789456276, 41.55633526463663, 40.88294275345341, 41.903527782809356, 45.30932180343136, 48.50232331983505, 54.83599801217356, 55.39204105254143, 57.44348772110478, 54.695683063999304, 55.177542317298155, 55.539526093390684, 51.65281418831118, 50.82552748341715, 50.43294529761038, 54.33961422212663, 55.2432067163529, 55.20577161542831, 50.25950593333091, 45.613478076073434, 43.08655777285176, 42.026313658683534, 42.593782563363355, 41.14858527337351, 45.91105653393654, 55.1884033603053, 59.78560555365778, 56.4513869439402, 55.35619058916646, 59.302616657749304, 55.13474533634802, 57.11167089400753, 60.48588199000205, 63.919999445638354, 61.24697085349791, 62.81610327382242, 61.626797491504306, 62.273392369670255, 54.7886706936744, 42.78380570873138, 34.88953759593349, 23.27371289653163, 11.101900069944321, 15.725224268051887, 6.91894184197149, 0.6140723007340586, 0.21343742767649315, 1.000945905764257, 26.535644185158517, 68.71487340619488, 51.96829042127056, 33.69400701215191, 50.361126699755275, 60.98778847725161, 71.20390753592216, 43.87564059226744, 9.524859170759878, 0.14974017387195943, 0.21446294361545196, 0.285894452564178, 0.18149148462520492, 0.1383776803530993, 0.25285744709112956, 0.1409309901176922, 0.12245239780074167, 0.1643433878498693, 0.17418314372339558, 0.16983924133162345, 0.1161871775383911, 0.15876381627974973, 0.14355441224911522, 0.13752919201168323, 0.10895943674709528], [0.015479074640860482, 0.053532780072982275, 0.04089249786169779, 0.007470255021020891, 0.0683549764536081, 0.046547486957523136, 0.02399653594400133, 0.05149910774742884, 0.04998599216642399, 0.04834701983077873, 0.0706784368582791, 0.07648378220056334, 0.033507149801739765, 0.06905540298189848, 0.045856958285214446, 0.011876185157997234, 1.1994109110486124, 12.747013703469309, 43.546177187273585, 45.148622297471576, 40.548058632881414, 23.739674783522084, 28.54217775406376, 37.943185144855136, 36.430754507741625, 7.193030205465133, 0.09458214975893499, 0.015686549445343836, 7.538625338385183, 9.759129593449256, 7.145629832821508, 5.35626515265434, 8.498474917104168, 36.22533213707709, 53.02368256353563, 60.389615258862904, 47.17521682862313, 48.77255501285676, 52.760671954001154, 54.15287017822266, 53.83503660078972, 54.486542286411414, 51.06784759029266, 48.26892660510156, 40.64463523126418, 39.2372299778846, 37.95805092780821, 40.26242771456319, 37.66762295076924, 39.09997447844475, 38.50504898255871, 39.956337713426166, 39.05800903997114, 40.82605269647414, 40.96770125050699, 38.92804522668162, 36.90820501696679, 35.801065045018355, 33.79763603210449, 34.42030052984915, 34.13181412604548, 35.437924169724994, 34.377974233319684, 36.30964348393102, 35.89353492183071, 36.2327689509238, 36.37110702453121, 36.127233659067464, 38.42456194662279, 36.569743694797644, 35.49419841458721, 37.242540005714666, 35.98383180556759, 35.70744199137534, 38.9533249024422, 44.11874125080724, 47.437505722045906, 48.6671805381775, 45.723904563534646, 43.95911647427467, 44.12002386585359, 41.51044353362053, 40.44201343290268, 43.93815140570364, 47.61713458645729, 50.27454822294174, 51.7544271099952, 48.39068481999059, 29.295253215297578, 52.61101392007644, 51.94685466827885, 52.84222195225378, 50.546293950849964, 53.389114103009625, 52.99873236686953, 52.964752874066754, 54.18994442109139, 53.36243021872736, 52.853800789002456, 48.2400030474509, 35.954104162031605, 38.18587787689702, 36.562044082149384, 37.556835605252175, 38.24152846490183, 40.74606772392027, 37.66800342067596, 38.98338202507266, 40.56380302675309, 45.01821525635258, 47.89652501383136, 50.54412880251485, 49.141344101198264, 51.919696177205736, 48.6272821887847, 50.97916672306677, 51.72991229641823, 50.74536600420552, 49.86140105032152, 51.396601046285326, 49.81328925778789, 47.905821031139745, 44.55816830358198, 42.47424048762168, 38.19545238248764, 38.04253485894973, 38.21372670512046, 40.84269531311528, 44.72866196786204, 52.081631229769805, 50.76325593456146, 54.60065187946443, 53.788874226231734, 55.86341973273985, 50.887661749316806, 54.56962200903124, 53.43540199341313, 57.888990525276434, 55.93893712566745, 61.69012808030652, 57.53082713773174, 61.48236405464911, 38.002734568811235, 17.273392600397912, 5.646373456524265, 13.059903133300043, 6.710652218710992, 3.171553015708924, 0.7090816057978139, 0.07835003367114453, 0.5396851632864245, 13.622613222368303, 45.23617352208784, 31.270352909641883, 21.421732479526153, 29.82327288196933, 50.94622273598948, 57.868056835666785, 33.1492486307698, 4.848816356351299, 0.10459595314797857, 0.01603140871250822, 0.049280452001239025, 0.05947858380574373, 0.04623636332971435, 0.04498508894034932, 0.04341852723530704, 0.07579275557110388, 0.06582685565996556, 0.016693605538157207, 0.019661292260993394, 0.0703132963709293, 0.023743330478487958, 0.07499661401755388, 0.04571889008906099, 0.05723826309305526, 0.016896959747217836, 0.01694052716747167, 0.050580637274129744, 0.026825648852654045, 0.05438162464528315, 0.011431163725172801, 0.040005429332414945, 0.08463046843967131, 0.05672847754472206, 0.032997034835599126, 0.06707426130531297, 0.06613558143257134, 0.041873189996206955, 0.054684669875930396, 0.03669045963174394, 0.07041532396068496, 1.3985681533813479, 17.191238557138753, 51.673316417201875, 50.13020500060051, 48.28017204038559, 26.88925370093315, 27.840193125509447, 38.96667272813859, 42.371195900824766, 7.8247852863804, 0.0038056887569837277, 0.08794474100033123, 9.010658014205195, 11.29306854740266, 7.973714249749338, 6.946969628334046, 7.075540509916122, 38.437156677246094, 52.15014719193982, 59.24232590583063, 50.17041321723692, 51.784562680029104, 54.64422156733852, 53.15841990132486, 54.16388027129635, 56.91727822826755, 51.626801029328384, 51.82340198947538, 41.97227908718971, 40.672888063615375, 39.4575338209829, 42.91697409845168, 40.432191817991196, 41.32863775376351, 39.99611446934362, 43.28417854924356, 41.08454865794028, 43.99274295376193, 43.344504602493785, 41.29183807680684, 39.85988270851874, 38.93543889445644, 36.40163483158235, 36.68425729197841, 36.16311157903364, 36.92221572322231, 36.44016427378501, 38.2101220469321, 37.07107751600204, 37.78759648722988, 37.382866720999445, 37.6866150671436, 39.265533801048036, 37.443588933637066, 38.009528113949685, 37.92443621543146, 36.49717592423962, 37.25554266283589, 40.37110874729772, 45.282837960027884, 51.425897229102354, 50.48073153341971, 48.13868430352981, 45.34672160302439, 47.31494342127154, 44.61031621502292, 43.11156288270028, 45.61308191668603, 47.80968373821628, 52.08483580620059, 52.666699809412805, 47.74074023769748, 31.19088568995076, 54.21684403573313, 55.27963769051337, 55.06971243889102, 52.93853182946482, 55.00131807019634, 54.56505244778049, 54.67051713697372, 54.86505100803991, 55.026986060603974, 54.42405892956642, 49.3618558299157, 39.152753891483435, 40.228004993930945, 39.96323716255927, 40.07780959529262, 40.976503049173665, 42.52860061583981, 39.22481175391905, 41.22950769239857, 43.377985954284675, 47.06015409961824, 49.75380651412472, 51.317031844969726, 53.001364277255156, 54.661613356682565, 52.5146452073128, 53.18485667628627, 52.31132522706063, 51.52556073281073, 49.567827332404356, 52.87538559206071, 51.96187342366865, 50.275677865551366, 46.13383931498374, 43.64536608419111, 39.95438437308035, 40.079837460671705, 40.02429277666154, 43.95056178492885, 48.323318112281065, 54.28186908844979, 54.39580217484505, 55.29446032739455, 55.9433929381832, 56.78600826571065, 51.417766155735144, 57.24272512620496, 57.35224554615637, 57.420337892347774, 59.919950654429776, 62.22423330430062, 58.55910785736577, 60.24589569337907, 38.2968181948508, 21.120429731184437, 13.90173496738557, 10.294179128062341, 8.07725501637305, 3.3658015343450733, 0.9894349750491881, 0.04410146780672573, 0.5401649794751598, 17.104397281523674, 53.20544127495059, 29.775945563470167, 18.005459846988803, 40.1344996113931, 55.44408698235789, 66.40542107243692, 41.02962370841734, 6.16066433729664, 0.043262061437652, 0.06376827398555414, 0.06433388053049004, 0.007629978128768985, 0.057852680930086685, 0.03713690886093724, 0.032558422685871204, 0.057997532834809636, 0.05824316743641131, 0.0346070681999047, 0.05513101568325393, 0.04770160990677053, 0.007659716704379648, 0.03981822808723777, 0.08484884180248746, 0.05150555437731166, 0.18246663794402154, 0.2201069125364865, 0.1431421956588184, 0.11206030019468839, 0.20102905560164683, 0.05932353144030898, 0.1500500257938139, 0.12513185160294657, 0.20951945484886247, 0.1203738327228254, 0.11662284408005015, 0.15566149726510048, 0.09194353610397347, 0.19556294165311322, 0.20958573677607123, 0.1665166720387436, 1.7403914370844442, 21.208214336825957, 60.141360605916674, 59.577472825204175, 57.11162382556547, 32.27095346296988, 40.72494576054235, 48.77813654561197, 49.026693221061464, 9.420131887159041, 0.2233869792713273, 0.20725525134513456, 10.265479145511504, 14.282956988580766, 14.121335725630484, 12.168975972360181, 11.1062244830593, 39.7791995540742, 53.694172520791334, 61.82901920810823, 49.84661763714206, 52.37876645980343, 53.256094763355875, 54.81852777542607, 57.07243150280368, 59.6885072800421, 55.49810586437103, 54.38073635101319, 42.713230502220895, 43.413287285835516, 40.075518931111986, 45.01985088471444, 42.16491060872232, 43.72243281333677, 42.46092404088667, 44.523694592137495, 43.37305945734824, 45.58748845131167, 44.85341295119255, 42.51369168681484, 41.11651597484466, 40.42763794622114, 37.04750799363659, 38.38018817286338, 37.571654319763184, 38.843439702064764, 37.17722861997543, 40.890873785941835, 37.26305792408605, 39.29947407014909, 40.29661117061492, 40.1057525604002, 41.601309161032404, 40.67831662393386, 38.97930276009345, 40.08396771646316, 39.916815911569905, 38.46995161425683, 42.5550687697626, 47.11993102104434, 52.436393922375096, 53.46927165985108, 49.367209865200905, 47.2286081314087, 48.23158564106111, 47.04904594729024, 45.73619727165469, 49.39834563962875, 51.279561442713586, 55.29517812113608, 54.03614044189454, 49.88331925484442, 34.81708357411046, 56.513274100519, 57.0740161403533, 55.599338316148334, 54.89501399378623, 56.901667194981734, 57.970548368269405, 55.824219565237726, 55.90850737787063, 56.98686891986478, 57.275414159221036, 52.34155885634884, 40.66720847160586, 43.94077939371909, 42.272967984599454, 43.20294234060472, 42.60493386176325, 45.48876239407448, 41.18633024154171, 42.83392183242306, 45.48371038129253, 48.94642583785519, 52.884544326413064, 54.607237538983746, 54.79984160392515, 56.795245447466456, 53.72712827497914, 56.67445605800998, 55.17709908946868, 53.44742013562111, 50.674775108214355, 54.94711875915528, 55.99978093178042, 53.49354328647737, 49.2716020922507, 45.89168787002564, 42.10055235893496, 41.167957859654585, 42.08351358290642, 47.01129705675187, 49.89901265790386, 57.385001259465376, 55.223143792921505, 58.68752233443722, 59.0781198009368, 60.0455645591982, 52.384889279642415, 58.17713176050494, 57.30908770715037, 59.799074972829516, 58.77028042270292, 62.60606427346507, 56.93065743292532, 62.25249005902199, 39.76097622225362, 23.428079735848215, 10.269296592281712, 22.085534795638054, 17.577817555396788, 5.768888688856556, 2.1707605113906245, 0.1270155239129259, 1.0882676104384086, 18.81865151466862, 59.70476158203618, 42.32934421108615, 31.194625669910064, 42.81432567104217, 65.03295237018217, 71.44495287249165, 52.42365406405542, 8.774530349239226, 0.1775395128154947, 0.16110939364279472, 0.1702951249336043, 0.17119290337206858, 0.18002280214380834, 0.11310386516514326, 0.12352185654303721, 0.18641182221472266, 0.1471429213040298, 0.07978041175632708, 0.2167171113673718, 0.14359438671700417, 0.1366953206278624, 0.16828618192624661, 0.1203910697011217, 0.16710691214088472], [0.06984305628124746, 0.04551631345924351, 0.052680940096897465, 0.032631626217475826, 0.01707541226829973, 0.006851743401644091, 0.09077195784137135, 0.07577015597733759, 0.09095635520474565, 0.028191348049609412, 0.03747605598501621, 0.02959277184169379, 0.08961502717988146, 0.032921234265931194, 0.030941274279968876, 0.02245187286227461, 0.8941971919228955, 13.336822467465556, 45.25967244179019, 43.63272820749591, 38.328581548506214, 18.02504816362935, 27.240576474897324, 38.71893975042528, 35.68524137620003, 5.879774583924202, 0.06286504866194821, 0.05287549961658736, 18.621350411445864, 8.19383030937564, 8.956613636785939, 11.425110236290964, 7.681569255167439, 43.23221891157089, 53.86939264112904, 42.218411737872714, 40.01489870009884, 50.464426240613385, 51.750441981900124, 53.9689306289919, 53.900049886395855, 51.61821888339136, 46.14123690512873, 43.94399965963056, 36.029511728594386, 39.37677221913492, 37.114910002677675, 38.14080592124693, 35.68132685076806, 38.20630165838426, 37.805835508531146, 38.27991277940812, 35.453307705540816, 35.976904899843284, 36.108622012599824, 34.44169705913913, 34.69800826041929, 36.354287901232325, 33.802856706803844, 36.50843312663417, 35.347411555628625, 38.47734920440182, 39.50100152723251, 38.85790540326027, 36.270353101914935, 35.312553451907256, 37.645849873942716, 37.046233223330596, 35.96270984218967, 36.088668915533255, 34.03464917213687, 36.006891419810636, 36.83605694001721, 36.86992268408499, 37.34739672753119, 41.57546466396701, 41.856055336613814, 41.296446861759314, 40.89295264213316, 39.442424851079146, 39.476565161058986, 40.43371369761806, 41.58928317408408, 44.32261820762388, 46.21286722921556, 48.630086683457904, 51.82447279653242, 50.9629241881832, 28.025872245911632, 47.87283782036074, 49.40636688663114, 52.46690211757537, 52.56891904338714, 49.57689192987258, 43.42534465174521, 47.295076616348766, 47.133769143012266, 44.38916121759723, 52.16200451697073, 49.541265041597434, 38.95746300297399, 37.16199805659633, 37.321022710492535, 36.075497596494614, 37.88361610904817, 38.6258226825345, 38.251185340266076, 38.32974649244739, 37.84618885286393, 38.01955369211013, 37.68318299324282, 41.08208933184224, 43.98680448532105, 45.88595336483371, 48.78007027410692, 52.33154112292875, 51.597838247976, 51.498668962909335, 52.310599588578754, 50.29590160615983, 52.78566137436898, 52.52947568893433, 48.3545833249246, 42.523752566306825, 38.93096347008982, 38.079758151885, 36.74744667545442, 38.75810461659586, 40.861530534682736, 43.31385520196731, 44.2360475755507, 45.59466246635684, 52.2337015213505, 54.741747379302986, 57.54992123573058, 40.04887427053144, 45.74823502571353, 53.262547062289336, 52.70910063097554, 53.83264787735478, 56.8549164648979, 60.40729338122953, 57.01525903517201, 36.743994989702784, 18.371285584665117, 3.9526251294920525, 5.894125065495891, 4.479910087200904, 0.4075392557969017, 0.04393683168135824, 0.048879883777830875, 11.862247605477611, 43.78640274847708, 47.05678478364022, 36.17798128435689, 20.308946255714666, 38.25617067275509, 51.36807364802207, 39.89799245711296, 6.214593004795813, 0.07656702531441566, 0.055069131100730556, 0.05580733725500684, 0.04549534946319558, 0.05233371457565696, 0.024979308007224917, 0.03407639909475561, 0.029190698255514427, 0.04512495744312483, 0.012111471826961685, 0.05480632846874576, 0.06405504750868966, 0.07295750246773805, 0.03820199707162477, 0.059815287109344244, 0.015769918006093755, 0.015957903533783412, 0.031344393576164885, 0.09614188945101154, 0.021580595320330995, 0.058341510143251195, 0.006374733967541327, 0.11473997616239133, 0.013065505059315793, 0.07341088862308572, 0.03326660585439494, 0.05727126233039364, 0.03118719424932234, 0.009906497453489612, 0.04546149603782162, 0.011166736986788531, 0.015303042957619315, 1.2677762296891983, 15.962621800361143, 52.93817881614932, 52.23795729298746, 46.14429635386313, 23.01324006049864, 28.001555512028357, 41.58521959858556, 40.64104234018634, 6.987946629524232, 0.08124323366510292, 0.22242730092858115, 19.560108915452037, 14.758178610955516, 11.156269023495337, 7.146746727728075, 8.836122347462563, 44.24941501309795, 53.39768840420631, 43.79047024634577, 42.49217356404951, 52.156348459182254, 51.59331575516732, 54.50940185977567, 55.940172672271736, 53.99809737359324, 48.463782110521876, 45.226551948055146, 38.935183940395234, 39.976953691051854, 38.16182590300037, 39.85667420971779, 37.131238829705026, 38.98673172919981, 40.36404063624721, 38.67978272899505, 36.95216301948794, 38.13666782071514, 38.142076769182765, 35.56403229313512, 36.39128761906778, 37.59817346449822, 35.381602856420706, 37.886365690538966, 36.94161184372441, 40.284200791389715, 41.10120696406211, 40.53075705805133, 38.44203218337029, 37.71839018790953, 39.12944716791953, 38.705234989043205, 38.25670019272835, 36.98990406528596, 36.99379113412673, 38.15783293016496, 38.392402433579974, 39.1529147086605, 39.79854860613423, 42.477327392947295, 44.784571432298236, 43.18809616950251, 43.33256490768925, 41.720557059011156, 40.426574983904445, 41.96326548053373, 43.03051494782971, 45.718409322923236, 49.413866458400605, 50.73120232551329, 52.927521736391135, 50.11843396771339, 30.188265115984027, 49.461872346939586, 50.50832540758195, 52.607793654164965, 54.08285587064682, 50.68771500741282, 44.53889769892539, 46.67272983058807, 48.397964739030414, 48.13832736784413, 54.99778401467108, 50.80255023894772, 41.309853523008286, 39.4668298382913, 39.64278736422139, 38.73207576813237, 38.65320474870744, 40.88578254945817, 39.449967568920506, 39.4418639521445, 39.48984630646245, 39.77343366992089, 40.01771496188256, 45.102632507201164, 45.986318972802934, 47.91980820317423, 50.038170506877286, 54.38829868070541, 53.62120859084591, 54.23982520257273, 53.84936501902919, 51.32111110994893, 55.49783129845896, 54.173996063970755, 48.11939408702236, 45.30669773778608, 41.07260504076558, 41.129342125308135, 39.893713151254964, 40.54323019519929, 43.598701646251065, 46.73431104229343, 45.870895385742195, 48.05640474442513, 54.9330609844577, 58.56622303685835, 57.51409038420647, 43.97349196095621, 47.28594141621744, 53.90478418719385, 52.4803440801559, 55.812664262710086, 58.35376393410468, 62.601212301561915, 56.928445216148134, 31.548119475764615, 19.30352903181507, 8.478555160184062, 7.732205583203224, 5.677137096082011, 1.597760697045634, 0.02846035407856107, 0.048131867867684176, 12.68092372725087, 48.97040720908873, 45.71551461373606, 38.09143897025816, 25.0121348134933, 46.19393002602362, 57.49598864586123, 48.33566181121334, 8.080484597913681, 0.0365959205514481, 0.051613722161780444, 0.08153563410404228, 0.051316893734638734, 0.09078674333830995, 0.051182215477550225, 0.04288397406438186, 0.0196976967591552, 0.026317399310609026, 0.011686018194943186, 0.05256265229094894, 0.07906589687110917, 0.060342397736085046, 0.07868495198988146, 0.0376883695923513, 0.06879209090144404, 0.18375994757779185, 0.1430738146506971, 0.14403500984753334, 0.15323279936227108, 0.18989937620297556, 0.08525159720691942, 0.19487130215331433, 0.22947485017920696, 0.2742440325598563, 0.10038148897189288, 0.10376091731051285, 0.12732320780595466, 0.1443554031392259, 0.12699616487107931, 0.21206124265107418, 0.08926667167895264, 1.7880712786028463, 20.66794510810606, 59.943504487314534, 59.05855894088746, 53.24300189172068, 28.604788587939357, 39.6210378216159, 50.63519054843534, 46.49312450039772, 8.255497813224792, 0.21543950653604924, 0.36989614667911686, 22.488585787434733, 15.57025730609894, 12.962353787114544, 21.705890547844675, 10.883463275048042, 46.09828695174187, 55.651325410412205, 43.13683471372051, 44.25483572867609, 52.89728026236258, 52.665036724459746, 54.35388772718368, 58.092996920308764, 55.17742856856316, 49.306519031524665, 47.04575900108584, 41.568718187270626, 42.775254941755726, 41.10207380787019, 41.91857791716053, 40.32225170443135, 41.70191795595231, 42.36054666580693, 41.37355673697687, 38.70110865562193, 40.048568325658, 39.85519547616282, 37.606233935202326, 37.56364876224149, 38.998847930662095, 38.32853448006415, 40.9061945638349, 38.18897654933315, 44.068044616330056, 43.918374815294825, 42.830917296871064, 41.270472926478234, 39.27931308746338, 41.938617306370894, 40.3083312126898, 39.4238994967553, 38.987131810957386, 38.59061156549762, 38.89352052442489, 39.01274096581244, 41.030627835181456, 42.085255115262925, 44.01882671540783, 47.283278126870435, 44.82607403109151, 45.18966205658452, 44.46720853928597, 42.57525328666934, 45.50632284533593, 46.5427581725582, 48.484052919572406, 51.20812723713537, 53.90978913153372, 56.32440413198164, 52.03588854882025, 34.00296034351472, 49.108325589087706, 51.30900275322699, 53.62848066514539, 55.276468415414136, 51.209531445657056, 43.636336788054436, 46.4596039249051, 50.649389528459125, 50.90948581695557, 56.44609958894792, 53.35065918584024, 43.70195019629694, 42.281432459431315, 41.710151010944, 40.55548760198778, 41.29879636149253, 43.39627204402801, 42.51775526231335, 42.147848298472745, 42.689609989043205, 41.967529096911036, 41.75624670520906, 45.89045624579153, 48.71668084975212, 50.40836380374048, 52.99312337752312, 59.01122377764795, 56.22558001549014, 56.225658462893584, 54.05532475440733, 53.29655401168331, 57.60304581734442, 58.079123497009284, 51.005972200824374, 47.08474736059866, 42.96407784185102, 42.83683615346109, 41.513236261183216, 42.708437365870324, 44.99237468165737, 50.48272409746724, 49.21352355710922, 51.25696859052105, 57.73923443209741, 61.151092437005815, 60.95262835102697, 44.07871346319876, 49.86160893594065, 54.233631780070645, 53.25576136189123, 55.88008588360202, 59.791606780021425, 62.540631294250495, 59.6804311198573, 41.5177587539919, 27.014944091919933, 11.680980170926741, 13.013003353149662, 11.172167370396277, 2.180518142638668, 0.23648714406355736, 0.11266698820456383, 15.457667631487693, 55.24277133326377, 57.988183344564135, 46.625457425271314, 31.545495410119337, 52.96747107659617, 64.43138237922423, 58.159347734143665, 11.041263168857945, 0.17728057509708792, 0.14651531143294227, 0.115083972623031, 0.1644402673287738, 0.19489384046004665, 0.1178963503409778, 0.17178109035857264, 0.1826451211086204, 0.2525916605466797, 0.0835574167450109, 0.09339551786862074, 0.1791888847947121, 0.277722745893463, 0.1683492156406564, 0.22654445661652475, 0.14083107693060753], [0.028953471468881737, 0.020817102518894022, 0.04626226476243427, 0.05776034052213354, 0.07456642500455342, 0.05458744182702034, 0.010656679477242213, 0.022978361042576934, 0.032185376171142824, 0.04229233968221853, 0.01036187160700079, 0.12195277057828442, 0.05548221337038183, 0.04834614266010542, 0.019915589401798866, 0.05876812535608488, 1.0417590867127142, 14.297037316906838, 42.6792117857164, 43.36947441101075, 36.00189824258128, 19.744379904962358, 21.148964974188036, 37.0757451365071, 37.50237741777974, 4.859375867151446, 0.11575892672783906, 0.34905411182872714, 20.5477774143219, 11.375438321021296, 5.956986931062514, 3.1107253893729183, 7.641367412382557, 32.82173072138141, 19.302948521029567, 27.523801019114835, 41.53586441470731, 54.92897779710832, 50.331065654754646, 54.022808305678836, 51.50525070005848, 49.98591276907152, 44.722158678116344, 41.02652111361104, 39.15563291118991, 40.5875333662956, 40.21093483894102, 39.86381684580157, 35.72315108391547, 37.95253215297576, 36.93549294625559, 38.56700674180062, 36.97034712760679, 37.42826423337383, 34.682848299703295, 36.60219738560338, 37.85606930332799, 41.19613224460233, 42.97005161162346, 45.73981369695356, 47.351578358680975, 48.91315629405361, 49.12840812436996, 49.535718810173776, 44.74976039701893, 41.83474117709745, 36.451825480307306, 37.619362108169064, 37.87106060212658, 35.815028682831795, 35.36361094444029, 37.73014945368613, 36.518807795739946, 37.75912007977886, 36.483828098543235, 33.13548895620531, 34.73527862179664, 36.327925651304184, 35.24373546723397, 38.43758813796505, 39.96392357733942, 38.888935273693455, 38.57982112515358, 41.2550776235519, 44.093626314593905, 47.802933339149725, 48.21101280950731, 51.90244559318789, 30.59987864186687, 42.366332161811094, 44.053782878383515, 45.75819392358103, 46.87844245664535, 45.72913308297434, 47.07291356978878, 48.89263837568222, 50.60252897201046, 51.51664910777923, 52.07534759275375, 46.46844886964368, 36.64943841195876, 37.15960933316139, 36.686873512883345, 37.05923195808165, 35.010425044644265, 37.976384085993615, 38.82374940379974, 37.01588192293721, 37.546633520433986, 36.265203029878684, 37.12553178110431, 36.81442506851689, 37.67580501494869, 37.29057727321502, 40.77501089342179, 43.28430798745925, 47.48469575758904, 52.71079901726016, 52.44023784514397, 52.779675837486025, 52.54300002128848, 52.49022453061996, 50.47164732410062, 43.6209414851281, 40.416255227981075, 39.361863290109945, 39.15014159294867, 44.36266560708323, 46.42853090840001, 46.16147633521788, 44.33597387806062, 44.31518923851752, 49.46788141804357, 52.21266192774619, 50.70726802272182, 47.72221488337363, 54.41509631372268, 53.43967737690095, 55.58413520936043, 56.52756721742692, 61.461387218967566, 61.543843284729995, 57.95782812180058, 37.204693055921986, 28.320571684068252, 9.327875779521081, 4.722151256376698, 3.070995947045665, 0.6885643615838021, 0.04153973107496577, 0.06905247652602774, 8.853540612805276, 44.099403965857725, 34.80144508423344, 25.630718085073656, 34.84256721312, 45.02396937339537, 53.95637512207032, 44.05733262338946, 8.099864048342551, 0.16228785137495688, 0.06364037177615589, 0.04160679441185729, 0.022317773001568935, 0.011053727526638297, 0.027903475190302538, 0.047480842519191005, 0.04776891839179782, 0.012513609573004708, 0.027662615231688947, 0.016315167679661707, 0.05023072278427501, 0.0881435561384405, 0.07229125878262906, 0.0807679680386378, 0.038796776244717265, 0.045161350449967774, 0.05020287548822742, 0.020195598368563, 0.02428205116772123, 0.06867903930645797, 0.011852920982956648, 0.08632277198616536, 0.052286864468647595, 0.10221680581209161, 0.05745410070484204, 0.009298608600792867, 0.023785225911847046, 0.015009222383190308, 0.11102739916813952, 0.01764545446231721, 0.02029474738294319, 1.585531359718692, 17.184446973185388, 51.76192668176467, 49.46899929354268, 43.238839872421764, 23.09121677952428, 29.916240899793564, 40.58493675724153, 41.204098578422304, 5.89729336000258, 0.1101301340085845, 0.17534583536607606, 20.746580785320653, 12.276795064249347, 6.1203953239225575, 4.122241898890465, 8.475294689978323, 33.83691072463989, 22.303147892798147, 29.74342323118641, 45.57872587634672, 54.69562422844672, 51.402343396217596, 56.05414105999855, 54.18357841430172, 52.38539526539465, 46.72651337039086, 44.6717679885126, 39.944307804107666, 41.41016029542492, 40.38771606260731, 40.591326298252234, 38.34857386927451, 39.197202190276116, 38.244858557178134, 39.438969242957334, 37.99641563046364, 39.04981913105134, 36.4534414968183, 37.63785216116136, 38.600566540994954, 42.73396807332193, 44.67599630355836, 46.022185125658595, 48.00843415721771, 50.40554754195675, 50.952949600835005, 51.88606185297812, 47.273346685594134, 43.023776315873675, 38.19115346477878, 39.77481826659172, 39.79122554102252, 37.24674478653939, 38.05847537133002, 38.873261482484885, 38.03511765695388, 38.3843498076162, 37.87749721157936, 34.829344903269124, 38.10379051393078, 38.63908029371692, 37.472900805934785, 40.74839761180263, 42.58573778213994, 41.055299543565326, 40.472949166451734, 42.60452201289516, 47.047104374054946, 50.00510100395449, 50.03726836173765, 52.702299241096746, 31.382622911084084, 42.51151869373937, 44.300272464752204, 44.84851391084733, 46.70611704549482, 44.71421195614723, 47.52857923507691, 49.25204907694171, 51.19196314965525, 53.90615309438398, 53.6582749889743, 49.17924204180318, 38.96863391322475, 39.093188778046645, 39.41405434762278, 39.03792258231871, 38.340046636519894, 39.814822519979174, 39.14037881358978, 38.64609349158503, 39.43750227651289, 38.656562297574936, 38.0845199092742, 37.6675445033658, 38.489979236356675, 39.804373325840125, 43.963105524739916, 45.56393461842691, 51.11850500106812, 54.909224740920536, 53.99632446227535, 54.50585995951007, 53.65035180122622, 54.71524392404864, 52.187833324555434, 46.00565233538228, 42.63824655163673, 40.79029636998331, 40.57433066829559, 46.43680318709343, 50.25796444185319, 47.80784806897564, 47.53236824466337, 47.44621730619862, 50.59615119811028, 56.01224230181787, 52.84352025678081, 46.017839139507664, 52.86667008553782, 53.38669792298348, 56.16394781297254, 58.14636861124347, 64.15776175837364, 63.79388739985805, 58.25450835689422, 39.350358978394546, 21.045096689654937, 10.976690169303648, 7.712390259388955, 4.530199285476439, 2.0981167449105174, 0.09580392976321521, 0.17811374168001837, 10.745117356700282, 51.794866746471776, 39.2378261781508, 30.36154954664169, 35.94601231236612, 49.32975907479563, 59.151346529683764, 53.912813278936575, 10.506101846694946, 0.09574678726494314, 0.045470355844665925, 0.1137068146659482, 0.019560996029946594, 0.04411378650054817, 0.07282091665171808, 0.11937748175114395, 0.01187249740225173, 0.04825223560234712, 0.09510940211194177, 0.005564329293256085, 0.06885741521874744, 0.014544660920247197, 0.006536249242227285, 0.07290601369834716, 0.016492281462095918, 0.16902796954156893, 0.12107053606380379, 0.21441570663404083, 0.14502663405672198, 0.21105835694939862, 0.15231815166771412, 0.14438966259119973, 0.13290893106210616, 0.2784057285997176, 0.16631727467381185, 0.17192404236524336, 0.2337492990397638, 0.18530651055757077, 0.24772668047057045, 0.08551981225008927, 0.10611734247856563, 1.9879542819915281, 22.724126077467396, 59.28755867865778, 56.13750319327078, 50.805099779559725, 31.888822432487245, 31.65398228553034, 48.21243270750969, 48.74924044455252, 6.820809043222859, 0.2842932062283639, 0.6804617866873742, 26.224768892411266, 14.33597860797759, 12.135434804424165, 9.138405688347357, 9.091299003170384, 36.9961327891196, 22.097382314743538, 32.34746909910633, 46.435281307466575, 55.75194205007246, 51.2998204846536, 56.02289938157605, 57.290923210882376, 54.30525818178731, 48.22259164625599, 46.52562525964553, 42.080152111668745, 44.152909017378285, 42.54581982089628, 43.71681597925002, 39.04765398271623, 42.6930538300545, 40.18349785958567, 42.10574949941328, 40.37092047352945, 41.00404985489384, 37.188274014380674, 39.57433023760396, 41.02790571028187, 46.41286888430196, 47.55418446756179, 50.6393051147461, 53.033661073254, 53.399590753739886, 54.45836790146367, 54.196745810970185, 49.294740153897195, 46.618428537922526, 40.7556422295109, 41.54257559007214, 41.64371390496531, 39.454572431502804, 40.63896740636518, 41.78309140666839, 41.120916874178, 41.01728785422541, 40.00022119091403, 36.012225843244984, 39.150388702269524, 40.655633557227354, 40.47202740946124, 43.856409211312574, 45.97831733765141, 43.7388793114693, 43.43759813616353, 44.97929357713269, 49.2401917519108, 52.235933349978545, 52.04862448476976, 54.53663095351189, 35.077030812540364, 43.35329071167977, 44.74803455414311, 45.43449248037031, 46.809973562917406, 44.90277205744098, 50.298976744374926, 51.96006913338938, 53.43011463842085, 54.51905481276974, 56.051815094486365, 51.283232781194876, 41.35270149477067, 41.24712305684244, 40.71684214376634, 40.58170864658971, 38.77571213629938, 42.065913907943234, 42.010231940977036, 41.204220171897646, 41.205169385479344, 41.44994097371256, 40.7074127658721, 39.789205520383774, 41.63708902174427, 40.99419686102098, 46.04462108304424, 47.4015611217868, 53.28263744231194, 57.597872211087136, 56.94442102985998, 56.95199120429255, 55.02818630587671, 56.21185171988703, 54.58559782274308, 48.25474723692864, 44.53569312249461, 44.23201930138373, 43.3070263554973, 49.84256582875406, 52.45478983848326, 49.757536688158595, 50.441405850072066, 47.57505539924868, 53.46444322216896, 57.836677874288256, 55.337939800754675, 49.794155936087336, 53.9429174700091, 54.96311418471798, 58.09143581698018, 58.7320137793018, 66.39955320665914, 66.62916091180617, 63.39136200566446, 40.74260427105812, 34.19554479660527, 20.338158107572987, 12.351779995426057, 10.599155176070429, 3.2924242846427427, 0.30150386174359634, 0.3162161206766483, 12.176862878184165, 57.45104612842683, 44.86614888714206, 37.24527389772477, 44.69922457971881, 58.89040693160027, 67.77378697549143, 61.59500275888751, 13.911132966318439, 0.28086444182742026, 0.14320150618591618, 0.15527365759255427, 0.12376394798798908, 0.2077744750966949, 0.21074062964368254, 0.19303287499614302, 0.14795272220526973, 0.10602947219365066, 0.10277544478735617, 0.1033586675241109, 0.13969780306421942, 0.15922481734906474, 0.12266596779227258, 0.15994873979399282, 0.09405505062351305], [0.09206886808838576, 0.06252503585851481, 0.039184811269684185, 0.026366302533255472, 0.07027032649925641, 0.022188277329288186, 0.025019362914345922, 0.06540009872086587, 0.018361038040189494, 0.04196047805429947, 0.017686145222415368, 0.06148824310531059, 0.031132982037360632, 0.05592394349796157, 0.06822974406062596, 0.04937272346127899, 0.9629282102950159, 16.82705237019447, 48.07330623749764, 51.44365379887243, 34.12511471779116, 14.405022128935784, 25.051840966747655, 47.13352203369141, 34.975551251442205, 4.795693245626265, 0.10897024624770689, 0.02940804506051204, 14.882206897581778, 31.487105046549154, 24.290234350389053, 2.153271153088539, 4.941892729651544, 20.087799103029315, 22.426312277393958, 42.73261877798265, 54.63025008478473, 53.04755018603418, 51.682514375255955, 55.34841252911476, 52.20027508274202, 47.932202892918745, 43.54941314266574, 39.10536381506151, 38.09717739782026, 37.94003548160676, 39.00882644038047, 41.64611439551077, 40.096327104876124, 40.40191112026092, 37.70694471174671, 38.58306884765625, 38.79413158662858, 38.98779469151651, 36.68362186801049, 37.553784001258116, 45.67176057446388, 51.00397963677683, 49.853113082147416, 49.618225866748446, 50.71130414162913, 49.86910458533995, 50.151699589144805, 49.23682243593278, 47.56490430524273, 47.659362823732444, 43.14848415313229, 38.257178721889375, 35.32925490410098, 35.84218325153474, 35.03547722293485, 37.146324265387754, 36.56026332609115, 35.050339083517756, 34.45601763263826, 36.4791997017399, 34.585738258977095, 35.64579409937705, 35.54880957449637, 39.856525159651234, 39.37658394536665, 37.04791984250469, 37.30146969518354, 40.81161837424002, 43.13049224115188, 46.477125152464836, 47.351809778521144, 54.436104528365604, 29.055398318075365, 40.48018986178983, 45.65117989816974, 45.092948175245716, 52.03047960035263, 48.60495605776387, 52.84887036969585, 49.67016589257025, 50.45081561611545, 49.25640290783298, 47.39944696426392, 38.91809809592463, 36.5179644861529, 38.75206416653049, 37.53665501071561, 37.04123220136089, 37.40358860261979, 36.99193977540539, 37.301626589990434, 37.43026464216171, 36.01695229930263, 36.09990650607694, 35.68699467566706, 35.845866357126546, 35.65852219058622, 36.037238797833844, 35.19208569680491, 36.02100410769063, 39.17620574274371, 42.45963358109997, 46.81473139793643, 52.59339071089222, 51.5091299241589, 53.31461652632683, 52.01286031353859, 46.94238101282428, 41.03830391360868, 37.885993065372595, 42.4254697368991, 51.13570067190355, 52.77597704241353, 51.74353468802668, 50.842377985677416, 52.940720512020974, 53.83339312768752, 56.58278634471279, 52.722177813130045, 52.312399956487845, 55.007746834908765, 53.250697581998764, 55.45146496065202, 57.51891882188859, 57.38934332324613, 62.58176519024757, 61.06864421598373, 48.23478629512172, 25.43665882079832, 8.287452382426109, 5.637121075584043, 5.221502809755264, 1.6005390834423805, 0.05009532057409806, 0.021391867644964688, 6.6734573629594625, 39.605556226545765, 45.32012008851575, 27.048470550967803, 27.88508661331669, 44.83915121324601, 53.98008584976197, 45.679742597764545, 10.922736006398356, 0.20060430581290878, 0.06381392133452239, 0.05380287969244584, 0.05141729338755531, 0.022950151769985116, 0.0413275285503797, 0.0385278219267005, 0.03364941232927865, 0.06085634697228671, 0.042033762025136145, 0.028131828763552254, 0.007296956356449594, 0.040211706166906704, 0.020017174575778268, 0.02678892834322347, 0.017186232632206335, 0.06434546377990516, 0.06224074829069357, 0.011293134791025472, 0.005361754099853458, 0.033855482320030855, 0.0869865335463997, 0.024782726015414924, 0.05134675584192719, 0.043119829553630085, 0.03357032141197593, 0.06922060984276956, 0.034302092427688266, 0.04251020359656504, 0.10325294739056019, 0.0412259606133786, 0.0015563558577747656, 1.6956357225295038, 21.146397782910256, 54.50060006110899, 55.83807729905652, 41.24152191223637, 22.463064885908558, 25.68207563892488, 46.30525865862447, 41.744879676449685, 4.869613743597462, 0.0426654015187054, 0.03330523583797678, 16.516524207207464, 26.144601529644383, 12.955129761849681, 6.195083135558713, 6.010992084780048, 24.10069169536714, 23.780869476256832, 44.44956179588072, 53.15710590731714, 51.86964281143681, 51.11195464288035, 57.36371455654022, 55.31842993151758, 49.786723044610795, 44.76346908077117, 42.01577032766035, 39.05649108271445, 40.80146335786389, 40.87132861537319, 43.10550282078405, 41.55535859446372, 41.38379804549679, 40.00434752433531, 40.30877444051927, 39.227510344597604, 41.25719178107477, 38.08011900994086, 39.904993887870546, 45.798515888952444, 51.52403100844353, 52.21080664665469, 50.48575216724027, 52.2144466061746, 53.37571920887117, 52.61266523791898, 50.80976347769461, 49.53267505092006, 49.37991049981887, 45.31541324430897, 40.79406184534873, 37.034787747167776, 38.397878062340524, 38.184171645872055, 38.83229232603504, 37.866369447400494, 36.82478797051215, 35.93112691756218, 37.32456461075814, 37.228972527288626, 37.91760736896146, 38.42517775873984, 40.81568194973854, 40.736536364401545, 40.961915754502826, 38.87111594600063, 42.97063996714931, 44.17668642536287, 49.490650776893865, 49.84701379652947, 55.091626721043745, 31.00153523106729, 41.86481791157877, 45.548190224555235, 44.428616339160556, 51.532487638535045, 51.73928283875989, 54.08246363362959, 50.96094339124618, 52.62178082619944, 52.380861005475445, 50.836086503921024, 42.08791840460993, 38.21437781856906, 41.455812761860514, 39.19184423262073, 39.159190500936205, 39.090568634771536, 40.34153015382829, 39.24469032595235, 39.90411527695195, 37.42765626599712, 38.957663043852776, 38.3376226117534, 38.330432907227554, 37.34674169171242, 36.56493094659621, 37.30132848985734, 37.723650086310606, 40.671962384254705, 45.197047879618985, 49.35658808677427, 54.302912604424264, 53.90222680184149, 56.15900562655542, 53.64635490602063, 48.69599426946333, 42.29862813026675, 40.9853401491719, 43.48190130725984, 54.23014479298746, 53.8629795658973, 54.014363442697835, 51.85984080837619, 53.579090179935584, 56.52309179306031, 58.6025010385821, 53.73868357750678, 54.72890553935882, 55.16925827149422, 54.55004153713104, 56.706537123649355, 60.34385296606249, 58.44533951051774, 65.2207201527011, 62.265649610950106, 46.462380962987105, 20.970381421427575, 8.100683823708566, 6.1649117738969865, 4.285781691151281, 1.696775783934901, 0.0966568384319544, 0.07323848819660564, 7.682525823193212, 43.80893284274686, 50.364139080047615, 36.855225563049316, 35.777887759670136, 52.48855752329673, 60.60077997945971, 53.75328263928814, 12.84069755384999, 0.28311894665802684, 0.026731833725446658, 0.051445186648878365, 0.0362045070787351, 0.016121944983399684, 0.03617260717756806, 0.03321204124198806, 0.02929796397145237, 0.023129385700749776, 0.047241784782419284, 0.06433335959070152, 0.03721400411919721, 0.036525448123293544, 0.055200024883473114, 0.012671041599054252, 0.07214694313945309, 0.14056616372639133, 0.17756405827258864, 0.12278190753873318, 0.1266504983387647, 0.16543915405148463, 0.20134315165060185, 0.20476125210763949, 0.11616796405325014, 0.1548239793027601, 0.12592259989750962, 0.13079276638886622, 0.13092594311362313, 0.14997300331390676, 0.2104092353293973, 0.10373688513232816, 0.11639228225835871, 2.4717506958592326, 26.82290484828334, 64.66970559089415, 62.91626099617251, 47.35609692911948, 23.255491525896137, 34.470126398148075, 58.61727268465104, 46.53209717042985, 7.015045794748492, 0.23776099506405093, 0.47874832345593366, 19.067696525204568, 35.23164279999272, 43.09157448430216, 7.490557182219721, 6.986072226878136, 26.591498736412298, 26.89403114780303, 48.09409872178109, 54.157769218567886, 53.02401988737045, 52.33949176726803, 58.14097535225653, 56.85828185850575, 53.020642726652085, 47.82249812156924, 44.31383602080807, 41.165357328230336, 42.364425889907345, 43.89972002275529, 44.91847722761093, 43.610574660762666, 43.911922516361365, 40.84624113575105, 42.424022382305516, 40.885900220563336, 42.706774280917266, 39.49408638861872, 41.99844521860923, 49.403115241758286, 54.906126068484404, 53.91145221648678, 51.95226361674648, 53.092986922110285, 54.43774407909763, 54.782002664381466, 53.688179139168035, 52.62433036681145, 52.46829455898654, 48.176574399394376, 42.39057633184618, 38.533992152060236, 40.61312290929979, 39.233087954982636, 41.78904164221979, 39.78097246539208, 39.344369519141416, 38.14380261205858, 40.36702163757817, 39.20018711397725, 40.71432790448589, 40.17981475399387, 45.585429206971206, 43.82912128202377, 42.767751447616085, 40.40723769895492, 44.30863103558941, 46.09059910620413, 51.72402874115975, 53.07698365180723, 57.08978014607584, 35.73275696846747, 41.726303331313595, 44.71475324323101, 46.27790404904274, 54.513959653915904, 52.87698984146119, 57.40913952550581, 54.97135116207985, 56.152082643201275, 55.130120861914854, 52.30621045635593, 42.43982953409995, 42.12260392404372, 44.86472506676951, 40.756858164264315, 40.832359867711226, 41.6163279164222, 42.43939415101082, 41.72058843797253, 42.76833195840159, 40.32487184770646, 39.95103859132336, 39.54377497396162, 39.71185638058571, 39.60515222241802, 38.217401965971916, 39.52215094720164, 39.94683381049864, 42.5529859912011, 47.23181663020965, 49.90233490543981, 56.16250045837895, 56.2996853551557, 56.44571519667103, 57.64760002013176, 50.65561825229276, 44.80291635759416, 42.55228780931042, 47.0323758740579, 55.67267094888995, 56.86702874399001, 57.347370040032175, 54.79174583188949, 58.17306426263625, 59.711359008666015, 61.22781399757632, 57.77321784727035, 54.514296977750725, 56.24112044611285, 56.21263227155132, 60.769461508720156, 61.310791738571666, 60.339303016662605, 68.61055404909196, 64.1063904762268, 52.825689161977465, 33.126236084968816, 15.593433610854612, 11.810218345734382, 10.704844420956029, 2.362682083922048, 0.3497566144552923, 0.13624596409499645, 9.175010227387952, 52.47203650013093, 57.980460197694846, 36.218585660380704, 39.57665228074597, 58.712539211396255, 67.53230233346262, 60.39422796618555, 17.506495137368482, 0.41471618197617993, 0.24605411134900587, 0.12523839145057625, 0.09715920058830131, 0.1498910778712842, 0.1468101020662054, 0.19719084784869226, 0.10532116262061943, 0.11957414418218598, 0.316218480227455, 0.16846829634760657, 0.09279577061533929, 0.16959501250136286, 0.12745913478635973, 0.12240214243290887, 0.18196341010832018], [0.1017946454005376, 0.07685457641679434, 0.04338500705818015, 0.05509818498525889, 0.016139557344778892, 0.03806589772143672, 0.060891606169001716, 0.07308997439160463, 0.0275625967075147, 0.02276380088240389, 0.06763352847267544, 0.049049009178434654, 0.02991840325956864, 0.09350877630734637, 0.01062699069734663, 0.07942778914566002, 1.015926295470807, 22.77286348804351, 51.683063507080085, 49.34161639982655, 29.37846825968835, 15.827582440068646, 57.64657235914662, 56.525598187600416, 34.44558020560972, 5.79966115374719, 0.03218272167648519, 0.5298282470433943, 15.661115088770467, 23.916585445404056, 15.08073668326101, 3.4933925588284773, 3.591155674188368, 23.78941043730705, 46.498733489744126, 57.95390182925809, 50.3471238382401, 54.18569649419477, 54.37239739202685, 53.14331877616144, 49.88237788600307, 47.37230024030132, 43.372035718733265, 40.93998578286941, 39.34612281860844, 40.13189907996885, 39.471167979701875, 41.28588784125544, 39.79483804395122, 38.313621628669004, 37.555015625492224, 36.41425309642669, 34.64062006242814, 33.822750968317834, 36.85737894427392, 39.70632583864274, 42.41459300441127, 48.849888463174146, 49.17759464633081, 49.86761408467447, 50.140218811650435, 48.37804694329539, 47.48438589034542, 45.51721526730446, 48.880910488866995, 48.46106783036263, 45.05678392225697, 41.31052817067793, 39.84950803941296, 38.87572865332327, 37.81646120932795, 36.27416172335225, 34.975606164624615, 35.9695347662895, 35.482458760661466, 35.653572159428755, 35.005090621209916, 34.883987442139656, 36.797602022847826, 36.370244103093306, 37.70601511001587, 38.43230078297277, 38.08619476133777, 40.115691846416844, 42.006293881324034, 48.02439820381903, 45.83287977403211, 55.03152032052317, 31.15092654382029, 43.07436704635621, 50.381825047154585, 52.079987756667606, 52.92629795689737, 49.12709413036224, 47.62898798911802, 48.27390409285023, 46.331864095503285, 43.175356311182824, 39.958698980269894, 37.662033573273696, 39.92089125417894, 36.41437468990203, 38.59056057468538, 37.18582253302298, 39.0082263177441, 38.38089812186457, 38.64128858812394, 38.638699823810214, 37.743956196692686, 38.137444450009255, 37.78079901972125, 35.810623861128285, 36.027946702895626, 35.60431895717498, 36.62717896123087, 33.490914529369725, 35.17428990333311, 34.61672890570856, 37.02644878818143, 42.21898832628804, 48.830778675694624, 51.666946488042036, 50.76797454587875, 45.6555062724698, 41.55450744013633, 39.265357294390284, 44.9347472190857, 51.92593274577972, 52.5891859300675, 56.104335631093676, 56.42649558282668, 55.07477621878348, 55.261814440450365, 52.41161630999658, 48.35289278338033, 53.59559551362069, 56.14549306131179, 58.33315187884916, 55.993964056814875, 59.96053149623256, 57.96230354616719, 62.1194903312191, 56.61132943245673, 53.31305934536842, 23.23285945000187, 8.107066010275195, 4.451677356996845, 1.3821009402313542, 1.2476123052258647, 0.024550063197591135, 0.011050685199968999, 4.840820604755033, 37.872158865774836, 41.4473129856971, 20.87560126858373, 22.3238266283466, 42.200529652257124, 56.23228334611463, 47.50063626996933, 9.078759185729488, 0.35476928096144433, 0.06852248923913126, 0.07340493611991405, 0.028707179946884997, 0.010360095240626364, 0.07617566163741774, 0.03063037281765813, 0.001168709981533128, 0.06118219097956054, 0.05178264454908429, 0.014268449834367682, 0.029765896221262314, 0.023603502195328478, 0.01948171933632224, 0.03894099995734231, 0.0076464830142926555, 0.0056358397705480465, 0.04964451613505522, 0.05745254554635575, 0.05679247652991645, 0.010413188964218624, 0.021280957265726982, 0.013112631915587813, 0.02173416913607188, 0.05302601674151036, 0.0429892000712214, 0.02697070951633636, 0.036447862568762035, 0.013916218886151912, 0.00803837672837319, 0.052888113254260634, 0.049257484685269096, 1.6536938182769285, 25.656242908970004, 59.538841401377034, 56.87026469938217, 35.93692418067686, 15.636179600992511, 43.63468939258207, 60.84778339632096, 38.819654449339836, 5.212166588152609, 0.09116149822910947, 0.3484253681475117, 16.36491871649219, 25.217931770509292, 17.200056045286118, 6.620354354381562, 5.928307540955083, 27.484004651346517, 47.43848631458898, 57.2629096431117, 50.18595757022981, 53.82525028720979, 54.74694059741113, 55.35269575734293, 51.38233538596861, 48.776100835492535, 45.051767210806574, 42.23598787861486, 40.256638296188854, 41.730527723989184, 40.915012051982266, 42.51682958295269, 42.08456870048277, 39.76300016526253, 38.66824703831827, 39.265800522219756, 36.23263559033794, 36.24366137289232, 38.69100070768787, 41.75820396792504, 45.00827204796576, 50.586137387060354, 50.30193421148485, 50.121944489017615, 51.23699588160361, 51.43689163269536, 49.726428370321955, 48.079640865325935, 51.50700399952551, 51.06907529215659, 47.47482707423549, 43.487722104595555, 41.57144031217022, 40.75576774535641, 39.88290309906006, 37.8357514258354, 37.0842880587424, 37.20557558921076, 36.831428543213875, 37.15871111039193, 38.67113782513527, 36.93742275238037, 38.344678955693404, 39.07754244342927, 39.181210687083585, 40.973431833328746, 40.09347161939068, 42.73020652032668, 44.77174528183476, 49.51979398727418, 47.946252822875984, 54.66862655455067, 33.03097740296395, 44.23895405184838, 48.77238242856918, 53.38210874988187, 53.7613352652519, 50.49425978814402, 49.52681895225279, 50.875345506975734, 49.04024893237699, 46.480015939281834, 42.51459775432464, 37.66456350203484, 40.481150842482045, 38.73612757652037, 40.37606662319553, 39.68258373198971, 40.35641162626205, 39.38216155575168, 40.8152897127213, 41.062022486040675, 40.54929025711552, 39.78902509135585, 39.00623767606674, 38.16976870259931, 38.49650998269358, 37.32549421248898, 37.656938414419855, 37.92652291636313, 39.23548060078775, 37.3723743807885, 39.7109503130759, 46.30830634024836, 52.340480204551454, 53.357303680912146, 53.03977212598247, 46.747933433901885, 43.65298332706575, 41.32853184976886, 48.480973858987134, 54.710690052278586, 55.0873395704454, 57.503703947990175, 57.570541135726444, 58.88544513333229, 57.58604234264743, 55.633337420801965, 51.799930526364236, 54.6728862485578, 57.38216538583079, 57.876187909033995, 58.59352665562784, 64.1060374629113, 59.0009863914982, 63.33046720873926, 59.237936773607814, 53.9534725681428, 23.551095070377475, 7.184106813323114, 7.734905644770592, 3.604934470307443, 2.0972349470661533, 0.055994366130401055, 0.05367046905561321, 6.231272393657315, 43.36466558517949, 44.50619297642862, 23.257248747733332, 26.672189735597183, 47.56556718580185, 61.7633391195728, 54.52498935884046, 11.850610913768893, 0.3454947141149352, 0.02899166478234674, 0.012149808781912491, 0.059731388990316665, 0.0963110110211757, 0.06004872942163099, 0.020011070770241564, 0.05946144641887757, 0.019386751246788812, 0.025826528473126314, 0.028319190887193528, 0.029632305809026285, 0.007370704289285407, 0.026097579956835797, 0.1119331066166201, 0.05848692129215887, 0.1517409044167688, 0.16193597186957637, 0.1284560603239844, 0.18180907403509464, 0.08324122927602261, 0.16149986865780047, 0.1871774198427316, 0.16870814315494032, 0.17763357309083785, 0.1041090123415474, 0.16929488989614672, 0.10196349117904903, 0.08144728118373502, 0.17876195931626906, 0.15071555701715333, 0.18379894145313772, 1.95782300205, 31.697595119476322, 66.18987114198747, 62.29408287232923, 42.780177516321984, 24.90663874533869, 66.73781841031968, 64.04102417730516, 43.99576317879462, 7.822234765175851, 0.1763883737787124, 0.8137976738714403, 19.082923166213497, 27.513973520648097, 17.85857100640574, 8.539894165531281, 5.6829475971960255, 30.940746338136737, 50.59586094271753, 57.29318249610163, 51.44534826278687, 56.85832108220747, 56.65455787412582, 57.8769802278088, 54.62441359796832, 51.45448346291819, 48.62303818425825, 44.69137983937418, 43.08246674076204, 44.06679338024509, 43.20058107376099, 45.29815873792095, 43.76276262344853, 41.433953392890196, 41.330716609954834, 40.33141043878371, 37.975721205434496, 36.72158256653817, 40.242054923888176, 43.31533001315209, 47.451665478367964, 51.68920593876993, 50.96798404570549, 50.47841341264787, 53.89792003939229, 53.877904184402965, 53.432189572242, 50.38559444489018, 54.16211520471881, 53.96110157812796, 48.9585106603561, 45.304940515948886, 44.37341290135538, 43.24745731969034, 43.21428191277289, 39.84877847856091, 38.89818422255978, 39.75292751866002, 39.01825581827472, 39.86728029866373, 40.785326726974986, 38.01351324204476, 42.11678704907818, 40.86827701137912, 42.99859862173758, 43.626122936125725, 42.34147610202913, 44.74074679036295, 46.01599562552668, 52.006525685710294, 49.010842923195135, 56.92453461308634, 36.64579060769851, 45.62318201987974, 50.43923677936677, 57.553533738659276, 56.94329923199069, 52.71224244948357, 52.293090128129535, 53.97493577772572, 51.78224848162744, 48.58166110131049, 43.74166027192147, 40.59336200837166, 43.48151299261278, 39.83841165419548, 41.87788332662275, 43.373992981449256, 43.42667433523363, 41.60629057115124, 43.272442817687995, 42.62415739797777, 43.610413843585604, 42.25988688007478, 40.59730791276501, 41.03299302439536, 40.32021207194175, 38.82066249847412, 40.4545924740453, 37.99101844910653, 40.31291254105107, 39.64042217500749, 40.28426354931247, 47.09459643210135, 54.20538287008963, 56.98703758178219, 56.21515435557212, 48.00100911048151, 47.42257718117007, 42.95754317314395, 50.22644819751863, 56.928817841314505, 57.14864707762196, 59.97899017026348, 60.52299937894268, 60.20867240044379, 60.679788281840665, 57.17289517002722, 54.700746843891764, 57.55218444332, 61.49899490417973, 61.30930123790618, 60.502504994792325, 66.74071311950684, 62.04809142697243, 67.71768923728698, 60.775913807653616, 60.044246642820305, 27.883809881825602, 11.248689870680533, 11.736125753771875, 7.926416839322737, 3.6652791548159818, 0.21571664650353695, 0.22046070726167774, 6.889340694873565, 49.612326622009284, 50.87094460764239, 29.98518243912728, 32.56089506610748, 56.6900396347046, 70.85666794930735, 63.42023457250288, 16.522294013730942, 0.763361509288511, 0.12488534749155084, 0.19395571983148976, 0.1284099571527012, 0.13304272065720252, 0.19805283465933418, 0.13479916108471734, 0.07868009499244152, 0.17696287843488878, 0.18196569305033455, 0.0722675713440103, 0.09477425396682755, 0.13579637773575323, 0.17545442066846356, 0.1750785472892946, 0.17791987546989996], [0.055873565556060885, 0.02310038161193652, 0.03050417706911122, 0.05763714592302999, 0.023924058280704964, 0.06645956767662879, 0.013871617247200301, 0.01536481454217386, 0.0377787334934598, 0.0824338109082272, 0.09187952945789984, 0.06686930214205096, 0.06119568178790712, 0.00981987589189122, 0.025525362073113362, 0.018129712045793573, 2.199963292767925, 21.16408375001723, 43.814169206926906, 49.5710083746141, 35.74747762372417, 43.21150487469089, 58.709864154938735, 49.46402965053436, 29.886358322635775, 7.325229769752872, 0.053250369420575525, 8.874194833540148, 42.30597865196967, 16.737624291450746, 8.882694609703558, 5.997286342805432, 3.675822976135439, 26.569186333687078, 48.21325640524588, 51.95295003152663, 54.528307684006236, 56.050838424313454, 51.587773446113836, 51.75362302410988, 50.22131381496307, 45.973873292246175, 40.69570449090774, 40.200940639741965, 39.16401109387798, 40.62190509611561, 42.139878042282604, 41.905904739133774, 38.453073655405355, 38.34320022213844, 37.06024000721593, 34.77660079156199, 36.29583674092447, 36.34305423305881, 35.81177703795895, 38.76116406533026, 42.380040845563336, 48.42676670320573, 49.045234264866004, 49.100747569914795, 48.38774696473153, 42.93794701176305, 41.97158875003938, 41.96189657334359, 45.10837485713344, 47.7499891865638, 47.73841819455547, 44.493955181490996, 42.79489817157869, 39.1015120475523, 35.862893366044574, 37.339226430462254, 35.541968960915845, 36.649097165753766, 35.22216243128623, 36.132348429772165, 36.720821626724735, 36.520125712117846, 35.06813095461938, 36.647618432198804, 36.082287219262895, 38.48099700866207, 37.090897252482755, 40.87511762495964, 40.00247263139294, 47.80685178695187, 45.248340714362364, 55.216907224347516, 30.308754444122318, 43.69408584410145, 56.420949351403024, 44.95730869231686, 48.25303316116334, 47.01203838471444, 45.03517950734785, 39.958267519550944, 40.01534977266866, 34.677145173472745, 36.59705908067765, 35.80101797657628, 37.999631974004934, 37.45574435880108, 39.05005839563186, 38.41323021919497, 37.73615460241995, 38.684713148301654, 39.45423903003816, 40.1315107653218, 40.31825088685559, 38.69457006454468, 37.60005620218093, 37.674891102698545, 36.12313870460757, 36.6224838841346, 37.708729390175115, 36.87052672909152, 35.68118564544186, 34.76194289422805, 34.586420751387074, 36.23767975837954, 38.10232354748634, 45.520074675160075, 45.43222142804054, 45.23866814951743, 39.87912193421395, 38.501707123171904, 43.703656427321896, 53.17680797269268, 53.63553700908538, 52.395565971251465, 51.56790271882088, 52.979795163677586, 53.31778972379623, 54.303536261281664, 53.12779403501942, 55.64973292812225, 52.585522436326556, 57.06537123649352, 58.625968579323064, 57.19009476323282, 52.78857569540701, 58.88844574651411, 62.12300477489349, 55.76896513662031, 28.021873389520955, 5.316435444739557, 3.394421108307377, 1.7135136406267844, 1.2480870345907829, 0.005203366379118375, 0.07942908383425205, 4.05514509927842, 36.69076450409428, 56.21100056555964, 49.63503322293682, 39.59376165943761, 50.52064557229319, 56.98473122812087, 40.1040384846349, 9.585129330235144, 0.2662467487877415, 0.021467128122646003, 0.04081368656648744, 0.04568968681738742, 0.06234716939469499, 0.05133119276574543, 0.017322416252066052, 0.08631373214865885, 0.022424682486622084, 0.12100439969330065, 0.032849294779401635, 0.08600687563058831, 0.014797751472571926, 0.029648016357133468, 0.009947154697241082, 0.016425241107842135, 0.039761349889299566, 0.029579742601321592, 0.08992354610874768, 0.043038179902660276, 0.01053414371375355, 0.02962972026228184, 0.05936216142389083, 0.019123540672984336, 0.024209632876238996, 0.06744863315215034, 0.08157829754054546, 0.10809967925231304, 0.02500464061966106, 0.041844392751133254, 0.03042466671866996, 0.0899981783943311, 2.5640933407891184, 26.82132609428898, 50.8969852232164, 56.66103762965049, 41.07903772784818, 42.60382775337466, 63.718322938488384, 56.21957486675632, 36.990080571943714, 7.663428293120477, 0.06348920730693687, 8.405752047415703, 39.84301259440761, 18.61236426138109, 10.490032876691512, 7.188856313305517, 6.4590762988213575, 30.983443298647483, 47.42198882564422, 52.41211052863829, 54.67162324536232, 57.99003862565564, 53.51987023507395, 53.99504576959918, 52.832035556916274, 48.10282599541449, 43.13623066871397, 42.97850039697463, 41.409815126849765, 41.97917461395264, 43.55478678980182, 43.332062844307195, 40.84324836730957, 39.62551324598251, 38.15987256265456, 36.0249617791945, 36.66094272367416, 36.84620018928282, 37.28456820211103, 40.96198243479575, 43.84393999653478, 50.64582017160232, 50.370022635306086, 50.32651570535476, 51.48919251657302, 45.61270536914949, 44.96437680336737, 44.9010540593055, 47.51764366703649, 51.07034221772225, 50.57593137987199, 46.60861476775139, 43.57909764012983, 41.554793773158906, 38.422891016929384, 37.53815727849161, 37.46628768982426, 38.11689907504667, 37.16731679054999, 38.04155426640665, 38.005209584389966, 38.911830148389264, 37.015340635853434, 38.143559425107895, 39.24388231769685, 39.39381491753363, 39.596981925349084, 43.06285096753029, 42.4996417568576, 49.698042177384906, 48.017157508480935, 57.881232077075595, 33.421971028850926, 42.85575766717234, 58.03805628130513, 49.50057045105965, 51.14141948761479, 49.362805043497396, 48.36740163064773, 43.26011088586623, 42.06711023084579, 36.99869409684212, 38.486605998008486, 39.52291580938524, 41.154425682560095, 39.321286370677335, 40.90940698500603, 38.79087601938556, 38.89637600991034, 39.35885875455795, 40.76509121925601, 42.10158786466045, 41.653119748638524, 39.77882300653766, 39.34843309463994, 38.58190782608525, 39.10462248709894, 37.004197182193884, 38.19097303575085, 37.44603649262459, 36.96605213226811, 36.691952982256495, 36.411181880581765, 38.17691918342344, 40.93161544492168, 48.055698717794115, 47.409554912197976, 45.9447536160869, 43.20777470065702, 40.84738646784137, 46.51468969160511, 56.047786820319395, 53.719256078043294, 53.56869982134912, 53.31975483125257, 55.53003395757368, 55.117298633821555, 56.044613622849994, 55.28048884484076, 57.51777741216845, 56.16592076516921, 59.71196305367255, 59.46517928954094, 59.39016003762523, 54.86088545091691, 62.321119769927, 63.73042737284015, 56.494776202786355, 24.78119154130259, 7.930807442434373, 10.806855463212537, 4.72855648686809, 3.303503509490721, 0.07131878677154742, 0.07898142035569876, 4.369994978750906, 41.7440559787135, 54.192874431610115, 43.46335634108513, 41.53208717223137, 53.89403297055153, 64.07642749048048, 48.90531155370897, 12.507076436473477, 0.38165283840029474, 0.03183760864269589, 0.04757078507194116, 0.1084352104413894, 0.021225069236430912, 0.07322149636644511, 0.031962454161276264, 0.010853704842438382, 0.04824281272087847, 0.05206383329125182, 0.051346058701916095, 0.12179436657818095, 0.012503826630211646, 0.024672344236844973, 0.033215082611047456, 0.025857648879830396, 0.11886871509975004, 0.12284241316299285, 0.1537303121820573, 0.17925884394395739, 0.13304426815480958, 0.139285663082715, 0.14269974923902942, 0.1808565356318028, 0.14817691017543116, 0.142892925970016, 0.21919034962211886, 0.23394019282873602, 0.12813381309951508, 0.14410302313345094, 0.16305934787998277, 0.15186897899595, 3.2145559210931105, 34.13231226705736, 58.1992264716856, 63.90807936268469, 47.02833191041024, 53.91658659904234, 62.959811072195734, 56.90356169977496, 41.0738484321102, 9.604702937987543, 0.12931354253763153, 12.74471519454833, 47.62298284038421, 19.7470941851216, 13.392691727607483, 15.083566673340338, 6.208448121624609, 30.80689741719154, 49.00922298431397, 54.28264964011408, 57.09423988096176, 60.567647718614154, 56.188847018826394, 54.84557644013436, 55.35080517491987, 50.98331659070907, 45.8252860653785, 45.507558391940215, 42.78584141885081, 44.81496587876351, 47.05676517178936, 46.38684788057881, 42.20223196091191, 41.861291700793856, 40.193221415242846, 38.17014525013585, 39.59505996396465, 39.85532491437851, 38.805533916719504, 43.861335708249, 46.29207165010514, 53.75079977896906, 51.08399598829208, 50.93194138619208, 54.469303469504084, 48.02606521114227, 47.22498778373965, 47.56485723680066, 50.034620761871345, 52.74939121738557, 53.083447717851215, 49.48674409620224, 48.559738974417414, 43.12646788935508, 39.56548921523556, 39.87072413967502, 40.480182017049486, 40.69220573671403, 38.96410357567572, 38.75053836453346, 40.52867035711966, 39.24387839532668, 37.95860398200251, 40.28631102654242, 40.64357226894748, 42.04124612192954, 42.74183242551742, 46.441113871912805, 45.42946007943923, 50.2676958422507, 50.2877587656821, 59.04746647804015, 36.81327973642657, 46.0139246140757, 61.61843499829693, 52.59581473565871, 53.33233779476535, 52.238769223613126, 48.507391022097686, 44.4386262278403, 43.939026094252064, 39.130435605202955, 41.91293754885274, 40.00108018998177, 43.15596803542107, 41.09235417458319, 43.528369626691266, 42.531189380153535, 41.61336260457193, 42.99198158325688, 42.472051805065526, 45.419399199947236, 44.310199983658336, 42.27476050776821, 41.293520773610766, 40.7232944426998, 40.99893900655931, 40.148455404466205, 41.016891694838, 40.57478958560575, 39.146105474041356, 39.78087832850795, 38.365910745436146, 39.960122800642445, 41.957978125541445, 48.979644390844534, 51.23430513566541, 48.61682122753513, 44.570747344724595, 42.813941278765284, 48.459063499204575, 57.246549437122965, 57.27013072659893, 56.32295677738806, 54.98844877366097, 57.891520454037575, 57.778897439279866, 60.4945739623039, 57.219700813293464, 58.86337787874284, 58.05843299435031, 63.61885555328862, 62.05678339927428, 61.867164258034, 55.85750087614983, 64.36061889894548, 63.72769348083004, 59.90970542353969, 29.60928209366337, 8.374346610038511, 9.01403909729373, 10.932835128999526, 5.542756693978464, 0.3587876879159482, 0.19179476965819636, 5.5780501807889635, 48.173632621765144, 69.67570504834576, 60.93683688871322, 51.65910959243775, 62.03792856585596, 70.26384092146351, 60.972059772860625, 17.10118486035255, 0.7478982390415284, 0.1024474825469717, 0.18386736842653445, 0.18176605053726705, 0.11695436096840328, 0.3042125034957163, 0.2035461753726967, 0.15996875001057503, 0.13393620900329084, 0.22792465594266692, 0.10269348870121664, 0.2570398887919803, 0.1264541040384962, 0.12179401417773579, 0.13454017740103508, 0.16279500158083055], [0.024965152617604024, 0.012145009241066875, 0.04150752856906864, 0.04785835915695756, 0.03585529738977071, 0.07209732362459745, 0.024149512211161277, 0.0833300341882052, 0.08717431701839932, 0.06270955196551739, 0.05831716386901756, 0.05356103722606936, 0.052016772510063265, 0.038357781051027204, 0.029304265044629577, 0.05794548865167364, 1.1821529725866935, 23.701574840853294, 50.90555167967274, 47.471379310854026, 28.59459238667642, 25.896966611185384, 46.84172122709213, 44.573065465496434, 34.66666852274249, 7.267942572793654, 0.13092036599353438, 16.147295813406668, 26.464233513801332, 8.435791519380386, 10.041558877114328, 4.827714985416782, 5.551493773537298, 12.218796937696396, 40.01459667759557, 58.46612415006084, 59.22266306415681, 51.90343010810114, 50.99594270029376, 50.30444452839513, 47.08144472491357, 43.53035434599846, 39.45760834601618, 39.261093678012976, 41.81137169561079, 42.60368654804845, 42.87831129566316, 39.40424842219199, 37.75418573810209, 35.39878283777545, 34.967710433467744, 36.7911732581354, 36.41086416859781, 38.84562446225075, 38.38858596740231, 40.63856340223744, 42.87023513547836, 47.188195951523326, 48.10115114335091, 49.45965620779222, 47.82681665112896, 44.98072524224558, 38.76901665041524, 38.78548276039862, 42.889427292731504, 46.51150472702519, 47.80049754727272, 44.869365230683364, 42.56504727948097, 40.9282696631647, 37.45725447131742, 36.81970457876883, 34.661134058429354, 36.36927527766074, 36.958274072216405, 36.11945167664559, 34.65737642780427, 36.82148141245688, 35.41065977465722, 37.40525168757285, 34.726241480919626, 36.88971104160432, 36.03569730635613, 37.33800265096849, 38.85347312496555, 44.57754873460339, 46.12739486079062, 55.659315278453214, 36.59034398294265, 44.936045523612734, 51.06482736525997, 46.513512980553415, 45.72087649376162, 39.27808538559945, 37.79286815274147, 32.730633674129365, 35.38073601261262, 37.373096096900206, 36.809047499010646, 37.404157346294774, 37.69903329110915, 37.6985586843183, 38.99208184211485, 36.44675777804467, 37.409327030181885, 36.77202424695415, 37.66218262334024, 40.727091297026604, 42.865128209514005, 41.042038010012725, 39.04144487073345, 36.52301257656467, 40.132197180101954, 44.82841960845455, 46.53222660864554, 48.03347849076795, 47.52641016437162, 43.30069565003918, 36.76971397092266, 35.129904362463186, 36.352969984854425, 36.77006698423816, 37.89522632475823, 39.73431587219238, 39.4849354990067, 38.32966020030361, 42.35314515329177, 51.234795431936945, 52.630504177462676, 51.10312538762247, 51.17843097256076, 54.14587659220542, 54.494312501722774, 52.671798890636815, 49.91333323140299, 51.079744139025294, 48.69098540275328, 53.63368565036405, 56.74239543176467, 56.851707966096946, 53.03879937817974, 59.523257824682425, 59.65504554010207, 57.82597764845818, 27.259570552456765, 10.826577140438943, 15.399590076938754, 1.4867606855207876, 1.8103372257563377, 0.09475238215658935, 0.06321557602214237, 4.401345993241956, 35.08066292731993, 47.73062444502308, 32.80217378370224, 32.30581941143159, 48.8991730443893, 53.708591153544766, 42.3936475476911, 11.646051464542268, 0.6882630132379071, 0.0946505384279355, 0.07502624629846505, 0.021232969518150055, 0.08968300216140286, 0.02153576002456248, 0.03861297642992389, 0.07357286259291634, 0.017376186048251488, 0.021432613946437355, 0.04089213013949414, 0.04266024574697499, 0.07597251810253629, 0.022025372562629562, 0.045969385518542225, 0.06302159489883531, 0.024529781019795808, 0.01710001709720781, 0.015148267341447214, 0.09191490739824311, 0.11176768525113022, 0.06684907742084996, 0.026270851808329745, 0.06385391112416983, 0.09913818189694036, 0.04279416174657884, 0.07430314356761594, 0.046733405005427144, 0.031073380396851612, 0.01869384961713466, 0.03002932704534502, 0.043411942709597855, 1.7096719241911367, 28.94262625325111, 54.80415228874453, 54.251153007630386, 37.09714166579708, 34.56831116830149, 52.40769786219443, 53.37804125201318, 38.06409220541678, 8.315860148399107, 0.04647221115808334, 18.42404538585294, 33.75265821333855, 11.337362893166082, 7.353501233362383, 7.933833551022315, 7.675305720298522, 15.690792722086753, 42.18579722988991, 58.09665256930936, 62.06396918142996, 54.731302107534106, 52.8868349905937, 53.48642810698479, 49.63366431574668, 44.70234678637597, 42.306210071809836, 41.695442122797814, 43.926953038861676, 44.22618281456732, 44.671544413412775, 41.71769765115554, 40.538233095599765, 37.665049875936205, 37.770200775515654, 38.02877126201507, 38.01535283365558, 38.629658760563025, 40.01935451261459, 42.34148786913964, 44.30637567274032, 49.393913361334036, 49.39936545587356, 50.00075894017374, 49.573193134800086, 46.409377974848596, 42.701800715538766, 39.4870614236401, 44.625527166551166, 47.446621310326364, 50.312881546635786, 47.307561520607244, 46.10382926079535, 43.041983958213564, 39.3029296782709, 37.58201329938827, 36.648065582398445, 37.215318756718794, 38.44584472717778, 38.31327646009384, 37.67479304344424, 37.464342194218794, 36.73373014696183, 39.07123919456236, 36.94358871829125, 39.87448569267027, 37.3999878668016, 40.33988668072609, 40.963810259296054, 48.07791894482028, 48.149435520172126, 57.08373185127013, 38.672126262418686, 46.04914357585292, 53.2050568826737, 47.3055414999685, 48.983335341176684, 42.647515112353915, 39.04222934476791, 35.979434828604425, 37.31232289345034, 38.605897042059134, 39.34497356414795, 39.02103285635672, 40.29139441828574, 39.06872495528191, 40.192221210848906, 38.54181728055401, 39.825055983758745, 37.88787188068513, 40.14660796811504, 42.93748417208272, 44.6391377910491, 42.19602284892913, 39.951493586263354, 37.607504783138154, 40.80100444055373, 46.532214841535016, 48.93151298646004, 49.854309405049975, 48.980534768873646, 43.81926044341057, 38.75553938650316, 36.180091519509595, 37.25937874086442, 38.997184845709036, 40.61842987614293, 42.2307397473243, 41.37645536853422, 39.730346433578, 43.35801716773741, 52.50452156989805, 54.54503659279116, 53.01843835461525, 54.059627594486365, 58.41165811784806, 57.52784613640078, 55.49913352535617, 54.67097997665406, 53.35472276133876, 51.40157068929365, 56.66398725202007, 58.051451175443596, 58.78139641977126, 55.58497851894748, 61.011048132373446, 61.118375947398526, 60.99564106233659, 29.561270321569136, 8.645199018139994, 8.276419735723927, 3.9709129352723402, 1.90507925806507, 0.10065750279013189, 0.060553964407693964, 4.629483790166916, 40.06190830661405, 55.63378849337178, 38.641249364422215, 38.88234176943379, 58.75330048222696, 60.70220854974563, 51.0661845053396, 15.065360992185532, 0.7532923560469382, 0.029292819691040826, 0.01696634816095954, 0.07217516581858359, 0.06416244537479456, 0.03352560485983568, 0.106538315453837, 0.04616275377150986, 0.04637562662302967, 0.04958276944835821, 0.007935451858136202, 0.08829539476503288, 0.021478661576346047, 0.030503730822895325, 0.02991286061343647, 0.021288903512721582, 0.17930139246727192, 0.09168471329875531, 0.12489340673651426, 0.18954054061924258, 0.22545252085453082, 0.14181039776773224, 0.1456044328909728, 0.23618529009963238, 0.17568879760801795, 0.17005782153817917, 0.10342317212733532, 0.13701860973190877, 0.1312477460070964, 0.16741615119239978, 0.1437523693687493, 0.09081776989924331, 2.872477928476949, 36.41986600814327, 64.50451497108706, 59.9818770347103, 40.74716598756852, 37.54004786091466, 55.53805520457607, 54.27273388831846, 45.10412693023682, 9.53509851809471, 0.4339880123734475, 19.024570065159953, 31.04994904610419, 10.389326022517297, 15.884165571581935, 12.193063247588373, 11.228318060598067, 16.88562120160749, 42.10948751818749, 61.3855246574648, 64.35431172770839, 59.27094744097803, 54.60375055190056, 54.81963388381466, 50.399746356471894, 47.02620206340667, 44.49400224993306, 43.36257496187764, 47.63892727513468, 47.853300494532434, 46.275276061027284, 44.423430965792754, 41.712928049026, 40.190244336282056, 39.21554319320187, 40.54803509866038, 41.093974113464355, 41.90995654752178, 43.82891339640464, 45.46816210592947, 48.45468613409227, 52.055606303676484, 50.69885846107237, 53.03175480135026, 52.78868159940166, 50.32918291707193, 44.97858755050167, 42.994025138116655, 46.878897451585345, 50.493498848330596, 52.735961021915564, 48.31293559843495, 48.13515417037472, 44.95968172627111, 41.49052966025568, 40.21761855771465, 37.834664929297666, 39.08185705061882, 41.22334172648769, 40.26181974718648, 39.630890815488755, 39.86657034966254, 37.435602987966234, 40.364625069402884, 39.25262135844077, 42.22917079925537, 40.515608864445845, 42.758820210733724, 43.45619409315048, 49.86353481969526, 50.58601187121484, 60.03147148316907, 41.85505905459004, 49.389830173984656, 55.91456351741668, 50.26233003985498, 52.86722313973212, 45.4455457195159, 41.97713498146304, 37.66363782267417, 40.267581708969615, 42.6293388489754, 41.45792299701322, 42.445207103606194, 40.726891256147816, 40.933874730140936, 43.53242143507927, 40.38992043464415, 42.25014371256675, 39.851508448200846, 42.0246466513603, 46.866118369563935, 48.30354152187225, 45.13621976298671, 40.96251587713919, 40.10021809608706, 44.44399203023603, 48.33424191321097, 51.038170937568914, 52.856126754514634, 53.16199318055184, 48.59764868213285, 41.70167084663145, 38.374469357152144, 40.474392598675145, 41.429850593689956, 43.1799650961353, 43.53074658301569, 43.901186989199736, 41.787539374443796, 45.21038393820486, 54.347659003350046, 57.35140615893949, 55.78175206338206, 55.2769273327243, 57.385734742687596, 58.56337931848342, 57.370347284501605, 56.56538671062839, 55.17537716896304, 53.44308983895087, 57.48991681683449, 61.0975952302256, 60.183416258904245, 58.67822239475866, 63.72911730120259, 64.11736526796895, 60.28271890455677, 31.72337881980404, 15.81464057968509, 26.087527121267012, 6.55676979211069, 4.959590463869033, 0.3692988126027969, 0.28096571865101017, 5.748098165758195, 46.12643780246858, 60.98522324715892, 44.480105292412546, 45.808388494676166, 64.32282293996504, 68.14595714692148, 60.28094991560906, 18.630448349060554, 1.4761092441697277, 0.28717550479115983, 0.19203968796758883, 0.10074249258445156, 0.22659374671357296, 0.10609088946254024, 0.26647991530837556, 0.11985062531405881, 0.25130084835954253, 0.2016619514794119, 0.1247944051940595, 0.1610381781093536, 0.09632324544532646, 0.1812998707135839, 0.1644044910227099, 0.07604033220559359], [0.028786992902056347, 0.05929730058978162, 0.020540889517794696, 0.015094053214265695, 0.08868754751259282, 0.04610427828024953, 0.06219905778585423, 0.07752986760028908, 0.06609540012094282, 0.03201937257883049, 0.06741500955315367, 0.015576395577931357, 0.024337998568831433, 0.04432034295713229, 0.03122778541799034, 0.023832370962707267, 1.377408804912721, 23.867963744748025, 51.8926122111659, 45.091081127043694, 31.574050264973796, 22.668410770354733, 25.936300139273367, 30.445941302084155, 40.34424051161736, 7.883697815479771, 0.2774451156297038, 1.8159878902858304, 0.3784011935274447, 2.689714845149748, 4.197122396961335, 8.50007426354193, 3.053436476376749, 8.752935740255541, 37.808851811193655, 57.17944160584481, 52.378433058338786, 52.13732104147635, 48.61939822473834, 43.751238699882265, 42.32644557952881, 40.67835192526541, 39.54481832442745, 41.497260447471376, 41.427520705807595, 41.516464371835035, 39.58105318007931, 36.81886911392212, 36.362407207489014, 35.21827536244547, 37.63484762560937, 44.74903868090722, 46.390323100551484, 46.11329394002115, 45.06142016380064, 45.968397663485625, 49.00464557832288, 51.71056324435819, 48.37205356167209, 48.563567207705596, 46.51494464566631, 44.07621883576916, 38.49441935939174, 35.24754801104146, 36.54935521464194, 41.4292779276448, 43.83941358135593, 44.550170590800626, 41.72479321879726, 36.83321322164228, 35.75573813530707, 35.9077182123738, 35.7881643695216, 36.62876359878048, 35.794295034100934, 35.53714836797407, 36.37669640202677, 35.6582554694145, 35.460473875845636, 36.97663076462285, 36.03907446707449, 35.10294591226886, 35.65264255769792, 36.802010766921505, 36.02508337266984, 41.85475703208677, 45.07658796925699, 51.97520163751418, 40.8266253625193, 45.86001865325436, 53.23042677294824, 45.504706828824936, 40.65526093206098, 36.694094596370576, 36.98686030603225, 34.96105024891515, 36.45237068976126, 34.993543163422615, 36.553375644068566, 35.017516689915816, 36.99596804957236, 37.203637938345636, 36.773805003012384, 35.37947693178731, 37.07241896660098, 36.65292539904195, 39.43150889488959, 41.16351381424935, 44.590727898382376, 43.421685080374445, 42.41660910267984, 43.12134135153986, 48.71128366839502, 48.9690226124179, 51.43669159181657, 51.699074622123476, 51.13510447163736, 51.14398471770748, 47.805784902264996, 41.35970684789842, 37.82130533649076, 35.022349049968106, 37.8300836009364, 37.436297247486735, 38.93097915957051, 37.77310332944317, 40.2713942527771, 48.49331363554924, 53.19971069212883, 51.818220538477746, 51.28680998279203, 53.58806848526002, 50.2458913864628, 49.622897409623675, 49.44977967969833, 47.310997516878196, 45.46859356664842, 47.6374642310604, 50.18927589539559, 51.44047275666268, 52.626373921671224, 59.75122205672726, 62.503443302646765, 62.380555445148104, 30.515671237822506, 12.470265972998835, 10.590482815619438, 3.4050764720286097, 2.285298378236832, 0.15832290203580934, 0.07005182290149313, 2.696607920431322, 34.27168976876044, 42.15288069940383, 34.97606508193478, 26.27349453587686, 43.93481739105717, 52.952911238516535, 45.05537971373528, 14.472589858116644, 0.3458834271277151, 0.07144305389374495, 0.01980651188792, 0.04538272304700748, 0.021581997261232427, 0.041886795717742176, 0.07963615740018506, 0.039673586856694, 0.06018757136658796, 0.023632115579300353, 0.008173614229646423, 0.07312315365960521, 0.03511446738435376, 0.08288080022940714, 0.08997362527635791, 0.024380819053359093, 0.04266604120212217, 0.02616535192505727, 0.02558072150174168, 0.028489944224636403, 0.0321723411851112, 0.06073217561107971, 0.02833569242108253, 0.06166035624881906, 0.05521656089131871, 0.06246867860036512, 0.022880244331674713, 0.02439654683844457, 0.009896846660863488, 0.02136946914927854, 0.024172732336146217, 0.07629564632811854, 1.6684069965154895, 28.662359176143525, 59.25254760249969, 51.980885151893865, 36.49571288016535, 27.796550873787176, 37.96935519864483, 39.231840641267844, 43.29968367853473, 8.894098900979566, 0.23385209271744375, 3.1333439821197144, 2.287761381556911, 5.867900098523786, 6.638810086634852, 6.116161125321542, 6.688842859960372, 11.171893785076758, 37.73266761533676, 58.800910211378536, 54.214321951712336, 54.236910881534705, 50.4898000532581, 45.95760722314158, 44.373510960609686, 42.62632646868306, 41.76918660440753, 43.356040293170565, 42.33543172959359, 42.979728098838564, 42.33211340442781, 38.95135979498587, 37.2858900408591, 36.727289615138886, 38.83674029381045, 45.38192095295076, 46.858826683413604, 49.63655902493385, 47.966825654429776, 48.417698183367335, 50.4788056496651, 53.28689713631907, 48.91604315850043, 50.450321397473736, 48.298858211886504, 46.08038917664559, 40.2473932696927, 36.61101095138058, 38.981354159693566, 43.18611929493566, 47.46175381445116, 45.654466844374134, 43.44525852511006, 40.22248621909849, 37.37154283831197, 38.538004736746515, 37.028566868074485, 38.273346731739665, 37.43881540913736, 37.543060241207, 37.79852421052995, 36.53569752170194, 38.304204017885276, 38.496003996941354, 37.8250825789667, 38.12504191552439, 37.43425761499713, 39.09720920747326, 38.6260344905238, 45.03061779083745, 46.741230103277395, 54.5977101018352, 43.5322606179022, 47.253150401576875, 54.305266026527654, 47.87430870917536, 42.447325183499245, 37.968468742985884, 39.6810971536944, 36.64813226269138, 38.58736384299494, 36.7098468349826, 39.081064731844016, 37.05689814782912, 39.07665206540016, 38.74087756679904, 38.19590737742763, 38.134663489557084, 37.762144227181714, 38.02116970862112, 40.705071110879224, 42.857730619369015, 45.68920335462017, 45.471617714051284, 43.70169524223574, 44.562290714633086, 49.27489688319545, 51.304127247102805, 53.16924172063028, 53.31567164390318, 53.497685309379335, 52.2743647329269, 51.13109188695108, 42.16453013881561, 39.78223939095774, 37.06851228590935, 39.50119372337095, 37.64161763652679, 40.03594613844349, 39.85378734527096, 42.19606207263085, 51.80104447949318, 53.3317219826483, 52.49319768721058, 52.95516267899544, 55.53230500990345, 52.63031982606458, 52.60336529824042, 50.43813459334835, 49.59076535317206, 47.36945259955622, 51.01341293704126, 54.68613601499989, 54.47888189746488, 53.90624330889795, 60.760224326964355, 65.42521292163481, 59.93582840888732, 32.54504280705606, 7.83354050690128, 6.8900197552096465, 5.310110622836698, 0.9997718913420555, 0.05010309636652951, 0.13889616866025234, 3.4183654621724164, 40.49547141598117, 48.03050533417733, 39.69491958618164, 31.30833910357568, 50.05080838357249, 58.562426182531546, 50.92072340749925, 17.358013814495457, 0.27190832240927604, 0.020868357631468007, 0.027515601043799714, 0.050335615542867494, 0.13521191393656118, 0.012336071569382424, 0.07551209159916447, 0.08360582584094617, 0.09267627622091001, 0.0695446114085855, 0.02015317816497578, 0.05175209296266398, 0.05078401829626772, 0.06836747900853235, 0.03883132297966269, 0.054710134638533484, 0.12746224510333232, 0.1186067819775593, 0.08434837954419275, 0.12087873063020169, 0.17395616719318976, 0.14546633788174199, 0.156447779267065, 0.19900787050925917, 0.1949805616130752, 0.0788760832661102, 0.10162551616949421, 0.08788772107612702, 0.11499070141824985, 0.1395651932445265, 0.15046725259913554, 0.12916000319584725, 2.3786181836358966, 35.288364195054584, 65.78339984340053, 57.51656147741503, 42.986588324269945, 34.48401943329842, 36.45220987258419, 40.89002263161444, 50.66314528065343, 9.987438994069255, 0.4679778320414405, 2.8529766394246012, 2.410794121603812, 5.118583248507592, 9.371152270224787, 17.539029236762754, 6.660739077675728, 11.65710078131768, 41.414933819924634, 62.16467995797435, 56.75566088768744, 57.0383264941554, 51.62891126448109, 47.026390337174945, 46.04466422911614, 45.45954073629072, 43.789850511858546, 46.208685982611875, 44.24240573760002, 45.213984674023045, 43.76884229721562, 41.40016217385569, 38.84346715865597, 39.068787713204664, 41.05645664276616, 50.299208164215095, 49.63185610309724, 52.7798915678455, 50.633684358289166, 50.5602458215529, 54.051892680506555, 55.244791353902514, 49.270205728469364, 52.65767051327614, 50.50208099426762, 48.14985521378056, 41.91357689519083, 39.57092562029439, 39.762478490029615, 45.851303146731475, 50.164376689541726, 49.74513415367373, 46.56599037108883, 41.459036950142156, 38.974458632930634, 37.876210674162834, 39.05042709842805, 41.359573487312566, 39.45083049035842, 39.0740397668654, 39.97041117760443, 40.12996142910373, 40.88990496050927, 41.18619295858568, 40.32808819124776, 39.538840632284845, 39.55858192136211, 41.38877553324546, 40.36016925688713, 46.38647917778262, 49.54324583853445, 57.629196259283255, 48.70969510847523, 48.94829288605721, 56.84330624918784, 49.345797646430235, 43.9635330630887, 41.36364490755143, 40.0515297151381, 39.93621595444218, 41.059025795229026, 39.69272305888515, 40.73097052112703, 39.26547104312528, 39.54808173641082, 40.94394345437327, 39.43066950767271, 40.71238633125059, 39.99728333565497, 39.57318098314347, 43.94134813739408, 46.35030708005352, 48.86549557408979, 46.649309358289166, 46.72924726240097, 45.98134540742444, 52.43078885539886, 54.27300060949018, 56.97082642586001, 54.208811021620235, 55.10211513888452, 54.05968643003895, 53.801155167241255, 46.33084035688832, 42.57069157015893, 38.15172972217683, 43.36864286853422, 40.07742128064556, 42.01366793724799, 42.59195866123323, 44.7458968623992, 52.394032324514086, 57.40897478595857, 54.3144404503607, 54.84965962748374, 59.02274770121421, 55.05369740147745, 55.21614628453409, 53.94916188332343, 51.180956978951734, 49.27745034617763, 52.112406146141794, 56.389189920117786, 56.68081814242948, 58.213550967554895, 64.82245837488483, 66.88166741401919, 64.64018975534748, 33.68831957540205, 17.017683482939198, 20.029973560763946, 8.247950192420713, 6.71503693826737, 0.2599791996181011, 0.23604166393558826, 4.097154174120196, 46.09958917863908, 55.510571156778646, 48.001522940974084, 37.61809518260341, 59.469811608714444, 68.16342738366896, 61.711803097878736, 21.32711314385937, 0.6136751607541115, 0.14346111806169634, 0.11395346433404954, 0.12878000826364563, 0.21824582449851498, 0.12932708697213283, 0.20723740149649883, 0.25808334651012577, 0.33350494780367423, 0.18515813464839614, 0.06369356509117831, 0.0797325389219388, 0.13846953429522055, 0.3772836551070214, 0.1454625074421206, 0.14671830941111813], [0.0307098850833192, 0.05152359191748885, 0.07447313847801379, 0.049700563127595576, 0.03324462296140771, 0.04410456663237945, 0.04795036248622402, 0.0770372654040975, 0.018132498690618143, 0.0291276587954452, 0.010457577056161339, 0.04363270626673776, 0.03986658738745798, 0.09147408508485363, 0.04192002478145784, 0.011039600865314565, 1.830997697768673, 21.607386104522213, 45.20932882062851, 49.243961149646395, 34.43804141013853, 18.936536389012492, 19.015978113297496, 37.255181804780044, 39.567297427884995, 9.844505863804972, 0.0451169518243161, 0.44263748211726067, 2.5581715424214644, 3.606517391820108, 4.216988221291573, 6.538819065017085, 5.0518426491368205, 6.998501237361663, 27.734081245237782, 56.17212987715199, 55.038478605208866, 49.899346059368504, 46.01194773950885, 41.55239328261345, 40.43772628230434, 41.935942249913374, 42.60280009238951, 45.1539880998673, 43.827046348202614, 39.89369746177427, 36.88394123508085, 36.12125204455468, 35.84022206644858, 39.5623670085784, 46.79069511352047, 51.467843055725105, 46.00591513418382, 46.0562312987543, 48.27731263252997, 49.64490975103071, 46.87740302854969, 49.39441150234592, 49.09300873356481, 49.114601381363414, 47.0237466596788, 43.756871223449714, 39.05242750721593, 36.54740971903647, 35.232937182149584, 35.7397937005566, 37.089877436237956, 37.1085596853687, 37.98972406694966, 35.9855733379241, 36.39471969296856, 35.19690236737652, 35.385011396100445, 35.19158755579303, 35.68815177486789, 37.363592193972686, 35.94719686815816, 37.663763338519686, 35.22990126763621, 37.013446131060206, 36.868294900463475, 39.005959187784505, 38.336296850635165, 41.384641355083836, 38.43784309202625, 44.0901275604002, 44.13004944401403, 50.666330245233354, 42.049012414870724, 46.25547985876761, 52.13615609753517, 44.82034344826975, 44.29564406794887, 38.65349892647036, 38.065614085043634, 35.444133281707764, 37.45998836332752, 38.21675085252331, 38.015070423003166, 35.639624211096, 36.71537737692557, 37.86926807895784, 37.70870193358391, 37.05298362239715, 38.01691785935433, 37.70279876647457, 38.03951071154687, 41.098359323317005, 46.23445987701417, 48.189643736808534, 49.02050764329972, 48.30758548551991, 49.98900751913748, 50.83769467569167, 51.12157621691304, 50.07922595547092, 50.30881012639692, 48.837070157451016, 51.575774915756725, 48.90322093040713, 50.72729172245149, 42.39145886513495, 38.445068097883656, 36.400038426922215, 37.005962248771425, 36.935920484604374, 38.43999647325085, 45.65138778378887, 51.89465576602567, 52.30563779031077, 53.84835304752473, 53.13875705965104, 54.74941953536003, 50.467972063249164, 50.39491007404943, 49.51693457941855, 49.406629685432684, 45.966691432460664, 46.268211872346946, 48.280442683927475, 55.3858672418902, 60.05495471339072, 60.90391643585698, 58.386751067253854, 31.935259372957294, 7.870816751833885, 1.5176370932209877, 2.6304000279595776, 0.6101227191186721, 0.12257143254241637, 0.12320830441650846, 2.6379822146508003, 31.365760641713297, 48.09091375720117, 31.673658855499763, 26.259060213642737, 44.491586069906916, 54.68983088770221, 49.110553495345584, 15.0950199942435, 0.3841079969800288, 0.04392821702264971, 0.014675631311782187, 0.0468941685563374, 0.02513113131205882, 0.010038573884465283, 0.011815520570493274, 0.028558915120459376, 0.014630912844422124, 0.1162532373001018, 0.01681261921241399, 0.04152097724257939, 0.045190335386582924, 0.043738353621935656, 0.05737859507902496, 0.041557021679416786, 0.04963654499020308, 0.020917980976763274, 0.05385988812533118, 0.04098804051717443, 0.033481179421106656, 0.05205845918446299, 0.07360257914349919, 0.07614890218622263, 0.026740626499597586, 0.031873032548314625, 0.013251107095951035, 0.013090463246278947, 0.028047599311497425, 0.06380465933151784, 0.05862484776204633, 0.02773929297203018, 2.2281531220482242, 25.387631154829457, 52.019747995561175, 54.77609949727213, 40.011945155359086, 24.923863833950413, 24.88867036757931, 39.47092871512137, 43.55111545132053, 10.689795267197395, 0.19677009703891893, 0.4229490531067695, 4.407870365727333, 7.600018766618545, 4.896846269407581, 10.0381552403973, 6.168048689442297, 7.910243926509735, 31.225333905989128, 58.63360151167839, 57.104300760453754, 51.78004803196077, 48.05584384549049, 43.827046348202614, 42.46587407204413, 43.42769022910826, 43.967851592648415, 47.30571800662626, 46.52100470758254, 42.33476100429412, 38.82438482776765, 38.60517532594743, 37.08906942798246, 40.847229573034475, 48.64724313059161, 54.07465027224634, 49.31382640715569, 47.72579600734096, 49.9755302552254, 51.92969429877497, 49.27222182673793, 50.631562356025945, 50.47308291158369, 50.782420635223396, 49.069407832237985, 45.33790411487703, 39.599119617092995, 37.21172978801113, 37.19021950998614, 38.708266981186405, 39.167070542612386, 39.309342753502634, 40.53920976577267, 38.727070823792495, 38.02934000569005, 36.23981352775328, 38.585092790665165, 37.706058256087765, 38.273433023883456, 38.50540199587422, 37.270937965762236, 38.373276956619755, 36.7289173987604, 38.243324910440755, 38.009453588916415, 40.47849932024556, 39.68502344623689, 42.80918736611643, 40.276877726278, 44.68274670262491, 47.4356778975456, 53.884023081871774, 43.01394685622185, 47.84046649932862, 54.70811697744555, 47.48635492017193, 45.18783815445439, 40.920734790063676, 40.62263465696766, 38.104123915395434, 39.38542496773505, 39.503276501932454, 39.44392319648497, 37.69959419004379, 39.91024986390145, 38.27517847861014, 39.78819747124949, 38.19987289367184, 38.90049449859127, 39.17651560998733, 39.43567837438276, 43.33474966787523, 48.756437993818714, 49.58582708912511, 49.62501548951673, 49.27133929344916, 53.3238733199335, 52.40718010933169, 52.684346552818056, 53.06669527484525, 51.853521870028594, 52.61317122367121, 53.27130963725429, 52.16644464000579, 51.343703962141475, 44.26755205277474, 40.8988832658337, 37.82417651145689, 37.910562792131984, 37.79721806126256, 41.89031331769882, 48.21382907129104, 53.73914249481694, 53.77037632849909, 54.59676088825349, 54.96106670748804, 57.010395296158336, 53.07404579654817, 52.23010863027265, 51.371164475717855, 51.465313126963956, 47.28470586961316, 49.278513308494325, 50.64399626947219, 56.4721441268921, 62.63329336720129, 62.66896340154833, 60.934495233720355, 32.788510207206976, 12.329470534478466, 4.891264736652374, 6.528922925072332, 0.9661367090959704, 0.10390325644684416, 0.06671031591512504, 3.202050179243088, 36.180432765714585, 52.14794674227315, 37.65288268366168, 31.788282279045355, 51.362390133642386, 62.609362986779985, 56.204391371819284, 17.540105927375055, 0.3637346240781969, 0.04489546814452737, 0.03235990249161278, 0.07766440796155123, 0.06725788491988374, 0.05716389127736611, 0.01407536120349241, 0.033969652403386376, 0.061924641260937344, 0.10191266124527301, 0.0128822022440633, 0.0333689360488807, 0.02060405921281105, 0.10486486533115949, 0.04960137389359936, 0.04397851069487872, 0.10937163035475439, 0.21249973605717384, 0.11418529020081605, 0.11839669768608387, 0.13015138225690012, 0.16908254564529465, 0.19676522471972052, 0.2453712971820947, 0.1401540543884039, 0.12968576933828094, 0.15621861172539575, 0.09888263794803813, 0.21259586476991255, 0.17475905798135266, 0.22542307243472148, 0.15703372927683015, 3.371363210101282, 32.31377790051122, 59.6754300978876, 61.74180138495661, 47.723042503479995, 28.696866227734475, 27.928938711843184, 47.39644242871193, 50.48852136058193, 12.35836761613046, 0.23221529990194306, 0.8235505247308362, 7.536098351401668, 8.97236587539796, 6.308349909320955, 12.643783784681752, 10.450437530394524, 9.083226765355757, 31.09631342272605, 60.8910628288023, 58.67088364016626, 54.00096070381903, 50.44801112144224, 45.84412128694596, 44.2969855185478, 46.42745225660263, 46.97146146528183, 49.5926441684846, 49.43463933083319, 45.15797715033255, 40.53848020492062, 42.16170995466171, 40.800325870513916, 43.18253032622799, 51.59930129205027, 56.94023978325629, 51.501877461710286, 47.049763741031775, 49.6115735269362, 54.31727240162512, 47.68998476766771, 50.28690368898454, 50.61597485696116, 53.9756182701357, 51.83506319599768, 47.17272220119354, 42.345543599897816, 40.96738353852303, 39.07462812239124, 39.93976569944813, 41.83633758175758, 39.92650416589553, 41.908932808906805, 41.162003701733006, 40.74797399582402, 38.39052361826743, 39.93443519838395, 39.00748106741136, 39.44386043856221, 40.871873824827134, 39.473807734827844, 40.051023729385875, 38.554215892668694, 41.20056452289705, 41.12347033716018, 43.05238608391055, 43.038077277521936, 45.14166793515606, 44.107837061728205, 48.26762437820435, 49.72496140387751, 54.04732311925581, 47.45634094361336, 49.090569019317634, 57.3911044674535, 50.609495101436494, 48.44946153702275, 44.5398037664352, 42.58412961036929, 40.58584282475133, 41.39374125388361, 43.52708701164492, 40.65838313871815, 39.99451806468349, 41.04916495661582, 40.817529386089696, 41.99391095869003, 41.86898739107194, 41.34480968598397, 42.6530142753355, 41.20895447269563, 45.154415638216086, 52.235329304972005, 53.56577765557074, 52.05844217731107, 51.02723144715833, 54.47745807709233, 53.64192262772591, 53.51240988700621, 55.75771970133628, 54.61250528212517, 53.91437830463533, 55.55989496169552, 54.08929248009959, 55.23893525523525, 47.81909742662984, 43.35271412326444, 39.80805643143193, 40.40044415381647, 39.943080102243734, 43.71103048324586, 49.12763933981619, 56.889845171282374, 57.452575852794034, 57.11036474474015, 57.083116039153076, 59.686820660868, 56.00029868464316, 54.27638953731906, 53.239071676808024, 55.148446175359915, 51.11774406125469, 52.21650192814489, 52.734694096349905, 60.41909579307803, 65.55551798112931, 65.63130209522863, 61.63463046473842, 34.693277881991484, 11.478876125427986, 9.218012152179595, 7.416041464574876, 2.66223251338928, 0.49015433076889287, 0.12168493857907674, 4.02435498372201, 41.529620001392985, 60.9880591207935, 41.583423153046645, 36.29701345197616, 58.074185232962336, 70.09582227276218, 63.59111655143, 23.00898232767659, 0.46043208049189666, 0.21588389881916586, 0.10976629587070597, 0.17288316912468404, 0.13203461023588337, 0.16953677449735904, 0.13794929930760017, 0.12789368283964936, 0.15450528672625943, 0.254556737359493, 0.09615043899224651, 0.08716742222708079, 0.14451327853866164, 0.10487230404490426, 0.13997776223526848, 0.1380447538629655], [0.08353969713132228, 0.051764511247916575, 0.05257868268076451, 0.024114306640600967, 0.07461683358997107, 0.025710690233315674, 0.027850283790499936, 0.020515135557000196, 0.06083388144390718, 0.0036092118628608485, 0.05115107400342823, 0.03368046187284974, 0.05783385048890787, 0.08063629284621247, 0.1149841054012218, 0.03392040061073438, 0.907236130968217, 18.309065026621667, 44.68030698837773, 47.25740225084367, 38.02823781967163, 24.969806555778753, 25.62985320245066, 36.5942467412641, 39.29909360024237, 11.782505819874427, 0.4060937091708184, 0.03735949187689731, 7.393899684952152, 9.670075120464448, 3.273131861802071, 5.1345997568099735, 6.728889769123447, 7.507255692635813, 34.48515692064839, 52.78655959713844, 52.106805001535726, 51.33537677026565, 46.061906968393636, 44.41227966739286, 43.95031075323782, 46.279680882730794, 47.2709148160873, 46.3563592972294, 43.223111168030776, 38.8760502876774, 36.060875000492224, 36.21542815239199, 37.543609373031124, 48.29251966168804, 48.678010202223255, 48.75766961805282, 46.40854643237206, 49.54950986369964, 49.191962288272, 50.415396613459436, 47.23996731542772, 48.402244044888405, 45.48052541671261, 48.99681652745893, 47.832049092938824, 43.524804192204634, 41.12189746672108, 34.75933844043363, 35.403175892368445, 36.02271818345593, 37.822278084293494, 39.020487646902765, 34.756369206213186, 36.221900063176314, 34.98620833120039, 36.78530931472778, 35.027969806425034, 36.77580933417044, 35.78838009988108, 36.70448103258687, 34.933460297123084, 36.00042735376666, 35.133242299479825, 37.138252027573124, 39.97108974764424, 44.855213319101644, 45.757311390292266, 48.904601604707786, 46.500604460316325, 47.57694990404191, 45.57102234132829, 53.51297078594085, 41.194057310781176, 41.05921799136747, 52.080262322579664, 43.874965944597804, 47.75890865633565, 44.84561527928999, 45.026397320532034, 43.5089970404102, 42.00845902965915, 39.691044284451394, 37.420819574786776, 37.37939934576712, 37.81513937057988, 37.15943674887381, 38.30159564172068, 37.0991224627341, 37.65168243838895, 36.414194260874105, 37.34858128332323, 38.71100087319651, 45.042263307879054, 47.180355133548865, 51.665204955685525, 51.45020807943037, 52.790372140945934, 48.868394205647135, 49.23928568440099, 46.675251914608864, 47.358352291968565, 51.86704620238274, 50.871811451450476, 50.99646045315651, 52.28943055675876, 52.5275811841411, 41.83342326071955, 36.00834269677439, 36.49796039827409, 35.558584120965776, 36.162444776104344, 42.426289512265114, 48.632848032059215, 52.04658877465033, 54.688281551484145, 52.490805041405466, 56.462165617173724, 56.5718311648215, 55.92351828852008, 55.23138861502371, 54.52095716230331, 50.733147821118756, 46.514489650726325, 48.005260959748306, 54.77912756704516, 59.2539910347231, 64.06952411897721, 58.48868170092183, 34.405568107481926, 13.134117318737893, 4.133939387336854, 7.026643262755487, 0.7567202011423727, 0.05309791792364371, 0.042649187267788, 2.0984229349320938, 31.71989379390594, 47.995262838179066, 37.973442308364376, 28.403341539444465, 37.671098170741914, 51.67580319989113, 45.6038486573004, 9.11955968026192, 0.4497847147285939, 0.04392933168057953, 0.028493110082983494, 0.04379553825504357, 0.10485264622876722, 0.04814020290430035, 0.026010462353306434, 0.057866987622072624, 0.05502054963501231, 0.05793235024377223, 0.0300085449951791, 0.024656558995165175, 0.0513063102299648, 0.04210331131734195, 0.06868455513951278, 0.06104441389681832, 0.04345026625800998, 0.05726417984753367, 0.0350997623266472, 0.07442827636916792, 0.06070520165526579, 0.04396590471808468, 0.034724708661557205, 0.030459200047076713, 0.036632807685002204, 0.07672759734334485, 0.03560959384025585, 0.04578702977948612, 0.032173467334359884, 0.030775536903210228, 0.05856755587662901, 0.031808510708111915, 1.3352347453755717, 22.86223469241973, 53.179361435674856, 54.84402318154612, 43.50592974693545, 26.346531029670473, 26.116613457279822, 41.61124844704905, 45.87348807242609, 12.693106609006083, 0.3429305871888515, 0.029485513786635095, 2.875010063571315, 6.320298919754644, 5.408082114111993, 9.501462232682014, 7.706398348654471, 9.673746458945736, 33.097426276053156, 55.37080926279868, 54.533038062434045, 52.6471350269933, 47.72357594582343, 46.348063484314956, 45.626684696443625, 47.46815120020221, 47.586606779406154, 47.894567751115375, 45.691474406949936, 41.71504220654888, 38.489657602002545, 37.59290572135679, 39.062119683911725, 48.709404853082475, 51.05240521892425, 49.10594471039311, 48.85152016916583, 49.45789506358486, 49.19394308520902, 51.11924632903069, 47.60628138819049, 49.709915191896506, 45.497897594205796, 50.63930903711627, 48.523543342467285, 45.98464804310953, 42.12565552803778, 36.96327509418611, 37.04378174197289, 38.028728115943174, 39.72460016127556, 40.57296960584579, 36.80154008250083, 36.58082831290461, 36.84105403961674, 39.269495394922075, 37.10611604875134, 38.16105319607643, 37.957074257635306, 38.58103313753682, 37.49533676332043, 37.04313062852429, 37.198809500663515, 40.20050525665283, 41.208624993601155, 47.59366704571632, 48.31359455662389, 51.89824473473334, 47.672306645301084, 51.47184779567104, 47.40278490128056, 54.77722521751158, 43.11170016565631, 42.86897997702322, 55.0268840789795, 47.09289804581673, 48.87798832308862, 46.578530188529726, 48.13980610139909, 44.164601602861964, 43.13941563329389, 40.925888784470104, 39.171957815847094, 39.051690101623535, 39.36350676321214, 38.4651663226466, 39.55325534266811, 38.224725031083636, 39.005300229595555, 38.70349737905687, 38.546206412776826, 42.529494916239095, 46.9604003813959, 48.38478165288126, 53.66733958644252, 52.87581705277967, 55.81975198561146, 51.60796580776092, 51.69095139349661, 50.14108173308834, 49.87441547455327, 53.919281267350726, 51.58100343519642, 51.70327155820785, 54.021066773322325, 52.42355992717128, 43.47137758808751, 38.50866540785759, 38.16839979540917, 38.72307000621673, 38.287216232668975, 43.22567247575329, 50.74009433869393, 55.16226860784716, 55.96409128558252, 54.09588206198908, 58.00681852525281, 57.91317193738876, 58.984665409211196, 56.27633156314973, 56.04280148783038, 52.335753748493815, 48.45527056724795, 49.324918870002996, 57.27073477160547, 62.467255515436975, 67.47444737342097, 58.86153828713202, 34.604832356975926, 11.95858003631715, 2.8785750077616785, 6.883842022188249, 2.3048016284742663, 0.06353693075417992, 0.09940314872731125, 2.658093187116808, 36.27430292867845, 52.18258911563505, 38.08551226892779, 34.16032583482804, 45.998439096635394, 56.77438628289008, 53.65390154623217, 11.47812597213253, 0.5137499614107994, 0.06034481857392577, 0.06316777213566727, 0.034245038029527476, 0.12963519221351993, 0.045770972576593204, 0.041269681251217286, 0.02660410197061156, 0.029438759440616257, 0.014761670646558126, 0.07065726984893123, 0.03813953792315818, 0.05408493794440743, 0.05030241329222918, 0.05696371633319124, 0.019561070723519213, 0.1969303626326784, 0.14786750258457276, 0.13648484563154561, 0.1986456334951424, 0.16446646753578417, 0.0966156765277828, 0.14671141461979958, 0.11747123283003608, 0.15980955693990956, 0.16694205001957957, 0.20079221185897628, 0.09909983919633013, 0.13092830266442992, 0.23956766021588158, 0.22133746424749975, 0.07386952248071471, 1.856494329629406, 27.77269894076932, 59.95463617386357, 60.20975889698152, 50.06706660793674, 36.26589336702901, 35.935794538067235, 46.30854952719904, 50.947175871941354, 15.513531008074361, 0.6441959810833777, 0.16399985870286343, 9.550178070222179, 14.932822142877887, 9.553230654808784, 10.848240390900644, 15.80901982322816, 12.2803722658465, 37.29624902048419, 55.918838900904504, 57.75371974514377, 53.833922647660785, 50.98080235142862, 49.19325274805869, 49.054663642760254, 50.08884752950361, 50.971490644639545, 49.659877515608265, 48.17322469526722, 41.91523998014389, 39.54509289033952, 39.97902862487301, 41.8102655872222, 52.67553298704086, 52.51992471756474, 49.577366536663426, 49.558754890195786, 51.20168278294226, 50.02611706333776, 51.11386875952444, 49.30909995109805, 49.931933110760106, 46.16125668248823, 53.12879423941336, 51.44405780300018, 48.82462447689426, 44.83639770938505, 38.02214245642386, 38.660198334724676, 39.48172700020575, 41.116614034098966, 42.28054600377237, 38.96683746768583, 38.947676689394065, 38.043790017404866, 40.009179884387606, 39.577974119494044, 39.295202609031435, 40.853560278492594, 41.48842726984332, 39.50900316238403, 38.62435963846023, 39.35020992832799, 42.12387869434972, 43.81616177097444, 50.29100648818478, 51.60823645130281, 55.49824314732706, 51.71573685061548, 54.47849358281782, 50.030612099555235, 57.97651037093132, 47.05739275101693, 46.033775729517785, 57.112980965645086, 49.70057602851622, 51.895059770153416, 48.08755228596349, 49.91820873752717, 47.149568450066354, 47.31097398265716, 44.251015340128255, 41.550655672627116, 42.3544866038907, 42.26535466409499, 41.133154669115626, 42.75948701366302, 41.38752429716049, 41.01886464703468, 39.26898548679967, 40.42904215474283, 43.978959744976414, 48.154609126429406, 50.1629920928709, 56.29095415915213, 54.90740476116058, 56.26900457566785, 53.976281150694824, 54.336750891900834, 52.544823923418605, 51.66909202452629, 58.43220741518083, 52.36664633597098, 53.508777772226644, 56.73819065093995, 56.58295892900037, 47.06943442744594, 40.27423012641169, 40.279168390458636, 40.332536159023164, 40.54139844832882, 46.018121550160075, 51.711892927846606, 56.744360539221, 58.60026528758388, 55.77498989720499, 59.48761524692659, 61.04023841119582, 61.448000169569454, 60.069389035624845, 59.713806567653535, 56.325635756215746, 51.85213727335776, 52.10493010859336, 59.137559398528076, 64.84110140031385, 67.44708491909888, 61.42872564254269, 38.169898140815, 15.943437487848344, 11.17172218138172, 16.880202447214437, 3.5380793867572664, 0.12445200985718159, 0.4122687762062396, 3.5537156703010684, 43.09137836579354, 60.4431438446045, 50.59688075896233, 41.575652937735285, 52.48560397855697, 65.66984330454181, 62.63121058863979, 14.777027560818581, 0.882921296982996, 0.15244875433704547, 0.254485966157048, 0.09954710430916279, 0.27674956908149106, 0.23335022851824763, 0.21529632470300122, 0.16929154975279687, 0.2081221257967334, 0.09840891981918005, 0.18668534624720776, 0.1620452006858203, 0.18923482557217922, 0.10373313130149919, 0.22677570791734805, 0.2157382961482771], [0.043710900861169064, 0.04997055549474974, 0.08804507553577424, 0.04527119596699073, 0.03230397041226107, 0.028752356151779814, 0.029164532522460627, 0.028992965216598207, 0.05899516317332464, 0.007843699901469894, 0.035372696471430605, 0.021776650626693043, 0.06567900835145866, 0.05096350886648701, 0.04392527524502047, 0.024958244419746825, 1.2350754295625996, 15.142688558947656, 41.168954141678356, 52.841288428152765, 43.24133057748118, 29.89955121471036, 22.184666818188084, 31.59870432269189, 45.541180949057306, 13.970453912212005, 0.41167818370365333, 0.0967666035097453, 3.396137880702173, 7.364159293713109, 3.188483926557726, 10.212139814130722, 4.93878327069744, 4.045955231112819, 38.10513196452972, 58.87916541868641, 54.82435249513196, 51.87658540664181, 46.62154682220952, 46.32647083651635, 44.948844217485004, 47.468045296207556, 47.25628045297439, 48.48244082543158, 43.41811180114747, 38.33815997646701, 36.390157976458156, 38.13592649275257, 47.02542151174238, 49.69808924582697, 49.134264223037235, 49.99080788704657, 49.12778446751256, 46.39386500081709, 46.894461416429095, 47.64309675462785, 47.85437914632982, 50.80029487609864, 48.407147007603804, 47.119138702269524, 47.2355075805418, 44.99900740961875, 43.4166330675925, 37.13400802304668, 36.95575198819561, 36.33644896168863, 37.13780487737348, 39.496522180495724, 35.52309451564666, 37.79593152384604, 36.43281375208209, 37.81834786938083, 36.42714984955327, 36.808600348811, 35.242295957380726, 35.85914750253001, 36.60107951010428, 36.168665655197636, 35.47692429634833, 38.84192958954842, 40.87826728820801, 47.95735705283381, 48.41521924541843, 51.60181160896055, 48.577472009966456, 51.523450497658025, 47.520659969699004, 58.26982913478729, 36.470746994018555, 36.749097993296964, 52.385744356339984, 48.49017573941139, 52.0774656726468, 46.18997627688993, 48.56124516456358, 47.432834179170676, 46.274224865821104, 43.92671769665134, 39.07525177924864, 38.118797502210064, 36.697801236183416, 37.51365815439532, 37.21301240305747, 35.650826500308135, 36.24514402881746, 37.20105309640208, 37.01396388392295, 38.216350770765736, 40.47850324261574, 46.067272770789366, 50.95655818139353, 51.58481597900391, 48.54823074033184, 44.21543552029518, 44.055830355613466, 42.880758854650686, 45.48569510059972, 47.66488159856489, 51.000626010279504, 47.534172534942634, 51.80776742196853, 49.35001811673565, 44.29846425210276, 39.631761581667014, 36.753604796624955, 37.57736921310425, 36.54907280398954, 37.28465057188465, 43.18733915205925, 49.70214105421498, 53.50200383893905, 54.79383253282117, 51.634696760485255, 50.87289794798821, 54.87942649472145, 58.05707585427069, 55.84017968946888, 54.9390818226722, 50.8119325483999, 48.6420734467045, 55.71478151505994, 59.43834635519213, 61.969844064404896, 60.18477339898387, 32.38785774477067, 11.640222822466205, 3.3079019573427018, 6.169754430170983, 0.1465772573024996, 0.14434064828580426, 0.042637699779363415, 2.6085823341723415, 34.12028628010904, 46.16790117756013, 41.96256337627288, 31.23349439713263, 41.16536909534086, 55.956093572801166, 47.665564090974875, 10.714732716160437, 0.21263548683735634, 0.014897521018170783, 0.011746410821234027, 0.030802397861055313, 0.06956861294325321, 0.08937757056687148, 0.04726134683756579, 0.0640098444907175, 0.035532862473759926, 0.011879948564925262, 0.028549459680253943, 0.057227645114424734, 0.015849070210430413, 0.029249259931666237, 0.012681395277350902, 0.010041358614070042, 0.05367312738071046, 0.0528657358259924, 0.07005736171718567, 0.06495074984887916, 0.04013259992784551, 0.05280249909828267, 0.09702525011474088, 0.01961539976388937, 0.004872124324808078, 0.020845298384947163, 0.025043190164010853, 0.018251127405692975, 0.02309000878144176, 0.0623458095886294, 0.05021639694009097, 0.0586837254494669, 1.2864571305051928, 18.486240448490268, 47.70442693464218, 59.0324830239819, 51.978527807420306, 34.40719981347361, 27.414965052758497, 35.312196516221576, 47.65168674530522, 15.58228329304726, 0.3501000057064718, 0.13273968691787413, 2.189975957716665, 8.150164523432332, 6.435021383147086, 8.749512491687652, 9.881661495854779, 7.875218141463495, 39.86384038002261, 60.66012936253702, 54.5495512408595, 52.93732373945175, 49.86177367548789, 47.19973948694045, 46.89607351056991, 49.2505350420552, 49.068356637031805, 50.78644890939036, 44.84844330818423, 40.52530104114164, 38.516953376031694, 39.78999783915859, 47.608834851172666, 53.10902157137471, 50.20870339485907, 49.561641754642615, 51.33436087639102, 50.24451855690249, 49.74686391891972, 50.83301136570593, 50.56272083713163, 52.87285958566974, 49.82137326271304, 49.51906050405195, 49.688526507346864, 46.71964530021914, 44.64941047853039, 39.072584567531464, 37.73699398963682, 37.864051326628655, 38.89834111736667, 41.16219197550128, 36.988362573808246, 39.735072889635646, 36.61433319891653, 39.90833966962753, 37.41730120874221, 38.884812862642356, 36.56697450145599, 37.66323774091659, 37.604202147453066, 37.705128654356926, 37.382192073329804, 40.986987544644265, 42.57952867015716, 49.623936837719334, 50.35924003970239, 53.21852630184543, 50.39786754115936, 52.597560190385394, 50.49373026817076, 57.91862010955811, 38.059287301955685, 38.86028628195486, 54.542749850980705, 49.84695103860671, 53.683421304149014, 47.569493478344334, 50.882295946921076, 49.439557983029275, 47.617534668214866, 46.73154184895177, 41.42355911193356, 39.168639490681315, 39.011768218009706, 39.05099584210304, 39.37670161647182, 37.96259695483793, 37.164543674838164, 40.615750897315245, 38.95619607740833, 38.2466197013855, 44.27683630297261, 50.05326378730036, 51.6230159421121, 52.715815728710545, 50.20599695944017, 47.40316537118728, 46.39725785101614, 45.340441888378514, 47.40460880341069, 51.05600595474244, 53.8381705745574, 48.295936046108125, 52.49802220252253, 52.73358406559114, 46.29400145622992, 40.794155982232866, 38.42211046526509, 38.11078017757785, 37.92132185351464, 40.88661016956453, 45.797499995077814, 52.0344647284477, 55.458034930690644, 56.291409154092115, 52.80610869007727, 53.87193825937087, 57.247177016350534, 58.6186808155429, 57.95314873418501, 57.13830378747756, 51.06199149162539, 52.17821567289291, 56.991324732380534, 61.58319642466884, 62.02508280354162, 62.93781442026939, 33.97289537614392, 15.401918984228566, 3.465407918537817, 7.2604591808011465, 1.5426752980678313, 0.658516125573266, 0.13505221524786565, 3.271313843227202, 38.05776149995866, 52.04174464748752, 45.57941621349704, 34.51046797537035, 45.48382020765736, 61.4584219071173, 54.508433034343106, 13.431139780629067, 0.22647924721241, 0.04769279223476206, 0.061193123054240024, 0.029978236641674757, 0.03303610915017705, 0.03746436548329169, 0.039089042618269884, 0.0354445708404866, 0.05359007195839959, 0.09502570700621414, 0.043711636305576375, 0.06668770099960028, 0.04227354371499631, 0.012032853011342307, 0.07924231925919172, 0.06763156728758928, 0.14243691979396728, 0.14425349812353813, 0.32043162673231096, 0.12588470918877473, 0.08223950036711271, 0.1887291309333617, 0.16166036407793724, 0.07917869565708023, 0.1117273583827961, 0.10979716155317523, 0.10427942093942436, 0.1624428616055558, 0.10567882608982826, 0.16961640167620876, 0.10795075942071215, 0.15071077662850582, 1.5734147905342042, 22.370514600507676, 55.19968017455071, 65.95511728717436, 58.57735864577755, 41.041359439972915, 31.814250330771173, 42.023567999562914, 56.16071970232072, 17.88643748529496, 0.580954993924787, 0.29277769127680414, 5.348289993501479, 18.2828341760943, 8.697097859074994, 21.23722810899058, 10.039656527580755, 6.515889379285998, 42.70396978624406, 61.95900263324861, 58.8508576731528, 55.585982645711596, 51.649566465808505, 50.79195591711229, 50.55223241929085, 52.1810515465275, 52.6137399673462, 54.63800068824522, 48.035251402085834, 41.2968312540362, 40.36775119843022, 43.05736357165922, 50.96632096075243, 54.35243252784976, 50.60873808399324, 50.33261499097271, 53.94264682646721, 50.97973546674175, 51.22399714685256, 52.69148526653167, 52.742876160529356, 55.64879940402124, 51.982544314476755, 50.21671287475094, 52.259969634394494, 49.67654758884061, 48.41301879575176, 40.9106856776822, 40.04171594496697, 39.029171774464274, 40.98918014957059, 42.73592925840809, 38.86738969433693, 41.13470008296352, 39.56308480231993, 42.3097284378544, 39.472540809262185, 40.591985256441184, 38.83748946651336, 40.140347865320024, 40.14549009261593, 40.20762435851559, 40.98470080283381, 43.24335844286027, 45.84339172609391, 52.31090553345219, 52.94831422067458, 55.95982766920521, 53.695274706809755, 55.98008278877505, 52.40420695274107, 58.16303476210564, 41.06709803304365, 41.46152765520158, 57.39907864601382, 53.584491283662864, 56.75209937557098, 50.80569597982591, 53.61113986661358, 52.41544846565493, 51.50099492842152, 48.16260683921076, 43.797691329833, 42.03679030941379, 39.741599713602376, 40.53941372902163, 43.13401845193679, 39.88522906457224, 40.34912386248189, 41.23783096190422, 40.321141673672585, 40.87704743108442, 46.60489243845786, 51.40439087344755, 56.44126330652545, 55.396736129637695, 52.6640796661377, 48.90504091016708, 48.61786065563079, 46.782360076904304, 50.5378451654988, 51.632715963548236, 55.61913451840801, 48.10195130686606, 55.66311605515019, 55.6852029215905, 48.977738118940785, 44.089547049614694, 41.02816066434307, 40.5104156463377, 40.21555539100401, 42.01014957120342, 48.53900532568655, 53.568625296315844, 58.17274262828212, 57.53591052947506, 55.10880670239849, 55.96267530995031, 59.55900630643291, 62.056104829234464, 60.491341929281916, 59.196112540460405, 54.12921436371342, 53.82849016497212, 60.18857809805102, 63.580439859820956, 65.17007058666599, 64.25959041041713, 37.173153277366396, 15.468878746032717, 7.2922063546796005, 9.60453917903285, 2.609800720407117, 0.8950370081490087, 0.24218017325526286, 4.032480173533963, 44.88889471177132, 58.39201096565493, 55.19041945857387, 43.01740246434366, 55.17993888547344, 68.39010115592711, 64.09709053654825, 18.930676367975053, 0.5755603253360718, 0.09891354959578284, 0.14241618945473625, 0.18373747055809345, 0.14822923398065954, 0.19834459158441714, 0.20877385211567726, 0.14439975963004176, 0.11938004048481105, 0.17024228018858742, 0.10356210217240358, 0.12707396109979, 0.15482244712691154, 0.20831357116901106, 0.16804210631357086, 0.16086087472015814], [0.03621381504701511, 0.07296380737135488, 0.021843750352760958, 0.05874471370911887, 0.056814359831473524, 0.07964281470424707, 0.06429673292704167, 0.01681758920782276, 0.014379485660502988, 0.07545530150133757, 0.05655375587183142, 0.02107590234147445, 0.0363180834439493, 0.03196849093411959, 0.02961909462277207, 0.046090668728274685, 0.4260101259475754, 12.788076016210741, 40.512600406523674, 48.145124835352746, 36.33722951335292, 17.19469612644565, 16.84500309728807, 34.695364582923155, 43.691567682450824, 17.843646387900076, 0.498511124282114, 0.19404935109759533, 0.15995715143940142, 6.020466079635005, 5.26562653241619, 6.837900771248726, 7.676329949209768, 8.636057934453412, 23.47821939376093, 56.16014703627556, 50.30830806301486, 53.21465492248536, 46.41951337937386, 47.051905355145855, 45.82515662716281, 48.56781905697238, 47.18295174260294, 45.07675270880423, 38.41897649149741, 36.478124972312685, 34.8569623116524, 44.70388827785369, 52.13732496384652, 50.64633007972471, 47.70579584183232, 50.28343631375221, 41.88333934353244, 41.58922826090167, 42.58238415564261, 42.83834234360726, 43.700036079652854, 47.59839350177396, 49.63492731894217, 50.59992451821604, 47.65063162772886, 47.02519009190221, 43.72444891160534, 36.90339226876536, 33.71438372519709, 37.151172314920736, 35.58078865851126, 36.96955088646182, 35.76077053623815, 37.458368424446356, 36.46756595180881, 39.360596364544286, 35.839770993878766, 36.25553438740392, 35.5096290188451, 36.260692304180516, 35.29788770983296, 37.799693076841294, 36.19815795652328, 39.83688192982828, 40.49830336724558, 47.63353401614774, 49.13995558215726, 53.126554566044966, 49.95550655549573, 51.945066067480276, 45.11465457177932, 51.37537317891275, 33.3446297337932, 33.86732086058586, 48.40870026619204, 47.67082398937595, 51.6630554968311, 50.23811724878127, 50.288747202965524, 49.74654620693576, 51.14236085645614, 48.144661995672415, 48.234637245055175, 39.616962479006865, 34.922136414435606, 36.85659839260963, 35.80681523969097, 35.8503496262335, 36.387094605353575, 36.23271403774139, 37.62027209804904, 35.71163892745972, 38.4699280800358, 41.05498967632171, 46.17492222016858, 45.53644664825932, 44.393479747156945, 42.3720980459644, 40.83063794720558, 38.720712661743164, 44.04396910821238, 46.97193607207268, 50.562136403975956, 50.21586956516389, 50.75785090846401, 51.14089781238187, 44.660032256957024, 40.322781224404615, 36.92344342508624, 36.27712703520252, 36.1724546647841, 36.80137142058342, 37.38207047985446, 43.667445105891076, 50.55897889598724, 53.2184321649613, 52.66456211766889, 55.55836523732832, 53.50641258301274, 54.20371194039622, 55.592740889518495, 55.15380021064512, 55.134863007453184, 49.72854252784483, 53.256039850173465, 60.27110868884672, 61.778726577758796, 57.619743347167976, 31.734079045634118, 8.657676077658131, 1.3613897225549145, 3.4891098208965796, 1.3572163206915702, 0.13859209304134693, 0.008216832122284799, 2.8932275118366366, 37.056666727988954, 44.972319602966316, 38.936501856773134, 42.005007343907515, 41.92032337188721, 53.251105508496686, 45.798908125969675, 12.343285122225362, 0.11923856702783417, 0.033809214439843936, 0.03872951755540506, 0.027753953979681098, 0.018414878699507926, 0.08305919146345508, 0.02075165371230293, 0.0037177945318211236, 0.030473600584833376, 0.08708581854138644, 0.026335226176607034, 0.04003176360481209, 0.030008274949185794, 0.031299715328420845, 0.04670270020142198, 0.010749486241219266, 0.04188072447094225, 0.03601695343311276, 0.04830087835509931, 0.04181404034757326, 0.038368444994933186, 0.02488076994796434, 0.03890660260954211, 0.005192342373887979, 0.018324549272356015, 0.024520183853324384, 0.040238262604801886, 0.04072437986671444, 0.0435961140770345, 0.030230641545307253, 0.03255080011102461, 0.025978648637030876, 0.5896001429327073, 16.097064960387446, 48.06004078157487, 54.06056896332772, 43.49815953162409, 22.852832771116688, 22.40897147886215, 37.596788867827385, 50.10271310806275, 20.060974013420847, 0.5959913999803605, 0.0798601461874862, 0.4870010822290375, 3.9595172241810834, 7.837052008798046, 11.556485122249974, 10.544085098851113, 7.239479893638242, 27.602413162108395, 57.137993920233946, 52.2181297117664, 54.60958703871697, 47.93604289331744, 48.86513471603394, 47.856093222095126, 50.09797096252442, 47.93825511009463, 46.58075025004726, 41.025866077792266, 38.11010552990822, 38.26583539285968, 45.72499890481272, 55.125162986017045, 51.174198735144834, 48.67618630009313, 54.07801566585418, 45.83170698535058, 45.24823481036771, 45.060035567129816, 45.2331179957236, 45.38139535534767, 49.677473268201275, 50.100567571578495, 51.33548659663047, 49.57575836489278, 49.074083297483384, 46.250616119753936, 38.47586654847668, 35.14419355700093, 38.38266318844211, 36.18274304174608, 38.067716475455995, 35.88849859852945, 38.80518482577416, 36.31757059404927, 41.088890721721036, 37.91763090318249, 38.3351436738045, 37.06471150921237, 38.30196434451688, 38.07694973484163, 38.94629209272323, 36.90496121683429, 41.22172178760652, 43.14815467403781, 48.298893513218054, 51.72217738243842, 54.19079949778896, 51.58789503958918, 53.32162580182476, 48.0487012094067, 50.74336951778781, 36.36070097646406, 37.2274741818828, 50.71480681819301, 49.30429504763696, 52.175658287540564, 51.854875087738044, 52.26852040137015, 49.93537302940123, 54.38632572850874, 50.1696091313516, 48.19624116343837, 41.316717670809844, 37.42970374322707, 37.91352418161208, 38.39335556953184, 37.30526654951034, 38.46504080680109, 37.53026154733474, 39.13081607510967, 38.59082337348692, 40.36524480389011, 44.03299039410007, 48.68368979423277, 48.494396209716804, 47.98651203032463, 44.52037234460154, 42.167511140146566, 41.091495175515455, 46.473685233823716, 47.9325206049027, 53.49084469579882, 50.89420426276423, 53.03166066446612, 52.631629897702126, 46.42560482025147, 41.819224280695764, 38.047480967737016, 38.79062498769453, 36.57680788347798, 38.738057382645145, 39.919792990530695, 47.190196360311205, 52.953193649168945, 54.78807449340821, 55.79963414899765, 59.21118228666244, 54.94531054650584, 56.55072489092427, 57.58057063625705, 58.11915912935811, 56.470708539409024, 53.39396999728296, 55.654890844898844, 61.878088058963904, 63.47560274985529, 60.839597409771336, 32.803958462130645, 12.189328170591786, 3.3304048401694146, 4.881878014533751, 1.9409550942720908, 0.09013012937840917, 0.10830234015180219, 3.316947923552606, 40.09615844295871, 52.548852197585575, 47.35371997279506, 46.06961834815241, 49.784385311988096, 59.88810493100075, 52.842339623358946, 15.247499192914656, 0.22865337409800102, 0.06540930709771572, 0.05239048552128577, 0.03808344496534236, 0.0354816724786595, 0.061132353129646474, 0.03615690620555993, 0.05269099500090365, 0.02656730102194894, 0.05966925925965752, 0.04330814162629747, 0.03366927698915524, 0.05221220920042646, 0.02622260167563875, 0.03639120270588225, 0.045870862781040134, 0.16787828607184274, 0.16871845469840113, 0.1275735653396095, 0.1496425436268891, 0.24793487252487292, 0.1419987941100713, 0.08813665368624272, 0.1661197312416569, 0.15727337690130358, 0.22197682590734577, 0.16678898565230832, 0.09782487736834634, 0.18126199532660747, 0.23594639324132474, 0.12534614937800553, 0.08678586447551366, 1.0589931232313956, 18.507605598818873, 54.87110714758597, 62.07561077610139, 48.33145310801845, 28.158060043088852, 25.725251128596646, 43.80705010506415, 55.489409969699004, 23.398834543843424, 0.7901248215667663, 0.3612918761228362, 2.08167465944444, 12.054640843022256, 12.716853618621828, 11.467988606422178, 14.16177143973689, 10.60069372577052, 28.228764687815023, 58.62462320635396, 53.884058383203325, 57.09671489654049, 51.057194432904645, 51.08373318949054, 48.67191876134565, 51.450302216314505, 50.606906337122766, 48.72820869568856, 42.05155803311256, 39.53505162269839, 39.78424764448597, 48.30875827420143, 58.100822048802534, 51.37840909342612, 49.97143137839533, 57.69024010627501, 47.466994101001376, 46.43615991838517, 47.96696293738581, 46.1094617843628, 46.83009139953121, 52.26746528379379, 51.916950518085116, 53.14360510918402, 51.16486349413472, 51.73092426792268, 49.42379005493657, 40.196269096866736, 36.63131706176266, 40.46970536631923, 38.276700358236994, 42.08019525774064, 39.061798049557595, 41.09708455301101, 38.835387076101, 42.51596666151478, 39.257316435537035, 39.6851489620824, 39.05103898817493, 38.905319013903224, 37.92526383553782, 41.452196336561634, 38.71303658331595, 43.85777027376237, 44.337978209218676, 51.81860493075464, 54.013680950287856, 56.618287717142415, 54.021031471990774, 54.41779490440123, 47.09609477750717, 52.494888228754846, 38.79185661192864, 38.78142310727028, 52.26992460989183, 51.22578574765114, 54.85284459206366, 54.24046454891082, 53.87130283540296, 52.61953723046088, 56.440486677231334, 53.12146725193147, 54.16563749313355, 42.75307001606111, 38.360670458885934, 40.12252069288685, 39.105014724116174, 38.27098546489593, 40.705106412210775, 41.01849202186831, 42.53211898188437, 41.17027205805625, 43.14756631851197, 44.782845589422415, 51.455507201533166, 51.52854565651187, 49.38868484189434, 47.497910222699566, 44.53071171237577, 44.045490987839244, 49.94358255017189, 50.79729818528699, 55.44178455106674, 52.440100562187936, 53.32563054177069, 55.322787684779016, 50.22269841163389, 43.4375314558706, 39.97374911462107, 39.69848502066828, 39.89561550078854, 40.78929616558937, 41.205738129154334, 48.44967334501205, 56.12609694080969, 57.941154126198064, 58.50098617615239, 61.01829667245189, 56.53587871982206, 56.24072820909562, 59.293097065341094, 60.485956515035326, 60.09406858874906, 55.970982889975275, 58.07385575386786, 64.8394069363994, 65.19402450130832, 64.00917845387613, 34.01114633006434, 11.854223416697595, 6.200211634559016, 13.257923010856876, 3.6153946961126024, 0.2799943804500565, 0.33456371195854684, 3.7939240711350597, 46.89705802548317, 56.9568863222676, 54.20093490231422, 55.76443479907129, 55.63773047539496, 67.9964050169914, 62.43785735099547, 19.489702370858964, 0.3596479127243642, 0.16268375029246654, 0.16747541575422212, 0.1531615378635545, 0.10114565401548341, 0.2345640335472361, 0.2700932762555538, 0.18520898756480988, 0.20284875956994874, 0.2388377776069026, 0.11577211110101593, 0.14661997436515747, 0.13961429948047285, 0.14004431995412997, 0.21902970098439725, 0.1334220107885138], [0.12009025761677374, 0.051706066400173216, 0.04968298140973334, 0.09956610328968495, 0.051617138913922736, 0.07145783939068356, 0.05162147497157416, 0.0043932437209502585, 0.04139010644247455, 0.03881752956658602, 0.024803701502781723, 0.014958346484138843, 0.048786122276778185, 0.011499560055052562, 0.06397773391537129, 0.11588876330924612, 0.047570926798207146, 5.123558775071175, 34.09972521566576, 48.43913393635904, 43.65014353106099, 31.828525797013317, 26.978158143258867, 28.98550364278978, 36.87622985532207, 23.2897416622408, 1.2597824392780181, 0.1715084396663212, 0.971464942539892, 2.2983522713184357, 6.978548630591362, 12.422920023241351, 11.160522833947214, 6.755898719833744, 23.652931567161318, 50.67100178810858, 53.71327054116034, 53.58343616608651, 50.0106393906378, 47.115675249407374, 45.561706712169034, 47.060389441828576, 46.46839395646126, 42.08677699488979, 37.723987410145426, 36.996497569545625, 39.52490837343278, 50.59994805243708, 50.86783024572557, 50.04363044615715, 47.9475119037013, 45.32676066121748, 43.42645468250398, 42.8685720505253, 40.85380346544328, 41.56978899432767, 42.37648717818722, 44.83958659633514, 46.58007952474779, 49.850869486408854, 48.69403308437717, 48.98959936634187, 43.3869642596091, 36.358641732123594, 35.79219656605875, 36.28201038606706, 36.98487950909522, 36.27943731123401, 36.779990580774125, 38.421318146490286, 39.94725742647725, 44.40908293570242, 36.707465956288004, 36.56358949599728, 36.04767230249221, 36.5927444734881, 35.38776882233159, 37.33405674657514, 35.70419819124284, 37.83617504181401, 38.832994430295884, 42.08456870048277, 43.59947043080484, 47.750161770851385, 46.749667121518044, 51.03797874143047, 50.57247969412035, 46.89777189685453, 32.138206728043095, 34.03409219557239, 47.669600209882184, 46.72202225654356, 52.82548127635833, 50.082705097813765, 54.35424858523954, 51.1444357902773, 52.0882482682505, 51.78547659227925, 47.86569518427695, 42.11997985839844, 36.67420817959693, 36.26913324479134, 37.272530448052194, 36.622676080273045, 37.8997919636388, 36.92184309805594, 37.09408221706268, 37.068539742500555, 35.60141248087729, 38.04750450195805, 39.175484026632006, 38.32975041481757, 38.30412164811165, 37.95983168386644, 37.20611687629454, 38.22651755425238, 41.9982647895813, 47.08848145700271, 49.33337942246468, 51.00801183331398, 52.20130666609734, 51.956370338316894, 45.93424558639527, 41.97960999704177, 39.74490627165764, 39.61444823972641, 36.051786868802964, 36.742002425655244, 37.377359713277514, 38.49341131025745, 41.21264150065761, 50.48108846910539, 52.15056296317808, 55.82099145458591, 53.52525957169072, 52.10614212097661, 56.667882165601185, 58.65872821500225, 57.98869717505671, 54.8790224905937, 53.63407788738128, 60.51679418933008, 60.419527253796986, 61.377405351208104, 28.368118655297067, 17.235698623041955, 2.654625076440073, 5.511454709114568, 2.071232819749463, 0.12374853429895256, 0.1343860864759453, 3.8103519380092625, 40.91835783373925, 46.43182177697459, 31.702702045440677, 23.448895754352694, 36.06776268251481, 57.48331939020465, 47.17000792103429, 15.433719600400618, 0.2797120923717176, 0.05695590606680321, 0.042514842258946556, 0.043301572422346765, 0.06407746324135412, 0.005653311363271168, 0.04790050165367223, 0.020070182114479043, 0.06895992544389541, 0.057824837464478716, 0.014098543024081138, 0.044562629754504854, 0.04175542313004694, 0.030440191490455504, 0.032861854790920214, 0.01779783509611603, 0.04489563668387071, 0.06989389387590271, 0.05248388313057442, 0.05490638721253603, 0.10027070499716267, 0.059450334313535885, 0.019740810272313898, 0.044961340214696624, 0.14829366197509153, 0.018851715440471328, 0.04840986585364707, 0.02870579332774205, 0.01860119511313256, 0.08172799112094987, 0.012113765302685, 0.05564423330548791, 0.13484501910786476, 8.347276372294273, 42.077088740564164, 54.846380526019686, 48.27506119205106, 32.282632320157944, 26.213762721707745, 33.27919675457862, 44.611802793318226, 25.329533007837114, 0.9990432497955138, 0.10428416302367564, 0.29189031631235157, 4.293021896193105, 8.621272560088865, 10.604998527034637, 12.090716842682133, 11.267286808260026, 25.32028013660062, 52.65747439476752, 54.908961942118985, 55.367075166394635, 50.850132511508086, 48.99150956061579, 46.97639188458843, 49.25089982248122, 48.10040589301817, 45.12066364288331, 39.62113195850004, 38.73533133537539, 41.63793233133132, 51.60815015915902, 52.14496574094219, 50.13339780992078, 49.18296829346688, 47.99836935535554, 44.23288222282164, 44.61733725763137, 42.34100541760845, 43.47466453429192, 45.23680110131541, 48.08846227584347, 48.002272113677, 51.909176380403586, 50.15523756704023, 49.709334681111, 47.17307129213887, 38.44448366472798, 36.09974961127005, 37.936360220755304, 38.51120318135908, 38.052458455485684, 38.31416291575278, 39.59828415224629, 40.923747170356016, 44.85482108208441, 38.51332126125213, 37.59414519033125, 37.35655938425372, 37.727949004019464, 38.26140311456496, 38.22399154786141, 37.70235161627493, 39.5375854738297, 39.70746724836288, 45.68106835888278, 45.782112536891816, 50.64014842433315, 48.62598388425766, 53.39061637078562, 49.59728433239845, 49.96925838531987, 36.01548925522835, 35.82230467950144, 48.42931624381773, 47.22769421915854, 54.557105725811375, 52.21301886343187, 53.87071840224728, 52.06117606932118, 54.07550927131407, 53.43475872470487, 49.48896415771977, 43.341637349897816, 37.703343975928526, 36.9559088830025, 38.87543055319017, 38.13524792271276, 39.26636142115439, 38.27647678313717, 39.1712478668459, 39.07611077831638, 37.6572286698126, 39.47066983868999, 41.52608202349755, 40.87650614400064, 40.22992303294521, 39.213283907982614, 38.218472773028964, 40.57917871782857, 46.09569818742814, 48.99464353438347, 51.31677296853835, 51.78709653116042, 53.37378940274639, 52.603659476003344, 47.5019149626455, 44.12151436651907, 40.59584879106091, 40.027120805555775, 39.07756597765031, 38.34234906781105, 39.69981862652687, 39.654887876202984, 45.16697506750784, 53.80054327749438, 54.921619430665054, 57.6026378908465, 55.231753395449736, 52.437994249405406, 59.39799301085934, 59.237991686790224, 60.029843699547556, 56.74065389940816, 55.58285259431409, 62.96124273730863, 63.928091295303844, 61.53093084212273, 30.709816794241632, 10.027726638701655, 4.918644351343955, 3.1610827388301974, 2.9322303350894683, 0.0520523572941461, 0.11528530819041115, 3.9254024096073645, 44.56490693553802, 52.977904581254535, 40.11637433882683, 32.697775979195875, 42.073433091563565, 63.59410147513113, 52.77880507130777, 18.033149819220267, 0.5974760783776161, 0.06141999616257607, 0.041275660567466295, 0.029596686550986864, 0.11782577832139308, 0.022185406414791945, 0.05094700350215839, 0.06835221087620144, 0.04889201861055148, 0.04300870083933396, 0.01588052961104099, 0.022762058032376152, 0.04357138858927835, 0.06716416938410652, 0.08733224604398974, 0.035000327944515214, 0.235188058126838, 0.14869268653133225, 0.2234363766206849, 0.17432988020441226, 0.2773193546360539, 0.12510175966928083, 0.12879968140154116, 0.22565075376581764, 0.3252313820825469, 0.10644653045962896, 0.08730396973870455, 0.0802291171144574, 0.09498544908579319, 0.21534730019348286, 0.14555929499047418, 0.2726204777436872, 0.16493868413231066, 10.198897892428983, 49.64610215156309, 61.824739902250236, 56.624543897567264, 43.62518548965455, 37.9160148866715, 39.574424374488096, 48.20301901909613, 29.431553617600475, 1.6633967814906951, 0.31267468006380145, 2.175276630347775, 8.015097216252359, 14.465770817572071, 20.626287575690977, 18.460207677656605, 10.977198116240963, 25.747422325995664, 56.15834666836647, 57.973901994766734, 58.204400077942886, 53.316640469335745, 51.90952547134892, 49.65260936367897, 50.43220004727764, 50.54703527881254, 46.39883072145524, 41.49502469647316, 41.80063224607899, 44.48469838788433, 54.0487273277775, 53.27105076082292, 51.7658333624563, 51.26067523033389, 50.8118187996649, 46.970967246640114, 47.99030103991109, 45.404192170789166, 45.51500697289744, 47.532517294729914, 49.24119587867491, 50.79123812337076, 54.748435020446784, 52.52437268534015, 51.805241415577555, 49.16431742329752, 40.936318366758286, 38.04400182539417, 40.51956261357954, 41.59397040644, 39.63961416675199, 40.58356000531105, 41.882868659111764, 44.10741736811977, 47.91217919318907, 40.34384435222995, 39.46994420020811, 39.93615319651943, 40.212193919766335, 39.363698959350586, 40.096970373584384, 39.515898689146965, 41.726836773657034, 42.299138038389145, 47.19756649386498, 48.73009535574144, 54.07917668742519, 50.524022733011556, 56.57685964338241, 51.244617046848425, 52.463007203994266, 40.45353343409877, 41.663439504561886, 49.890250082938906, 48.27754012999996, 55.56348785277336, 54.155078472629675, 57.02503750401159, 52.109782080496515, 55.85711256150277, 57.263556834190126, 50.76591137916812, 46.477584069775, 39.48597884947254, 39.19739046404439, 39.95899315803282, 39.036945912145804, 41.45632266998291, 40.140379244281405, 41.04339122772217, 40.18427841124996, 38.42308321306783, 41.37989528717534, 43.2394007713564, 42.43642099442021, 40.70650669836229, 39.84119261464765, 40.39752983277844, 42.27066947567848, 46.02939444203531, 53.16477414100401, 53.142032238744925, 53.289254480792636, 54.66604563497729, 56.841890273555634, 49.56835293000745, 46.143613861453154, 44.11487379381734, 43.87038853860671, 40.03798969330327, 42.13749324121783, 41.77890231532436, 42.62200793912334, 46.4847816190412, 56.47397587376257, 57.48162884866038, 61.19677628240278, 56.31923444809453, 54.848451537470666, 59.15667310837777, 62.39092619188371, 61.180416076414055, 60.228037141984515, 57.570596048908854, 67.4763693348054, 65.98603340887254, 64.83008346249981, 29.669749352239794, 22.187912579505674, 10.043589684271044, 16.87464640986535, 7.179915270497722, 0.18299523861177508, 0.2671527243669956, 4.5024632253954495, 50.78036139088293, 57.17704503766952, 44.319229279795, 35.7049826652773, 49.791857427166356, 71.7448494511266, 61.046541660062736, 22.554169777900945, 1.0846242188445985, 0.18881507067670747, 0.11488606146867238, 0.11045918409382144, 0.2136526524179405, 0.15426395370835258, 0.15300997502861485, 0.15186363170223852, 0.2215933835794849, 0.22037732625199905, 0.09920649395714845, 0.08992378359600421, 0.15658330022087022, 0.11963038269670741, 0.1892962045366726, 0.1578032645967699], [0.0315274502856717, 0.053448043087677616, 0.024975613548210072, 0.07706633077994471, 0.023996143323940136, 0.03886511894844232, 0.05505280576706414, 0.005849285751596214, 0.03652413045206378, 0.03184265524689709, 0.08938802000615867, 0.03905821907063646, 0.008996498955023146, 0.0026179292810059366, 0.0245999010475052, 0.054263179791310144, 0.11761747135390198, 4.5365755884878105, 27.922360897064213, 43.13856055659633, 46.965974069410755, 28.850501545013923, 29.31734596529315, 40.56867068813693, 45.20111929985785, 26.529297790219708, 2.9016709039288187, 0.04652384931461946, 0.1503987336951879, 1.1254499636350142, 7.486804944853629, 11.283805870240736, 12.595249356762057, 12.190769641630112, 24.84295906559114, 51.07419006286129, 53.12931591464628, 51.750669479370124, 49.78052962210871, 43.94655704498292, 43.77977002051569, 43.63477176235568, 40.9634768578314, 38.6563544119558, 37.68559132852862, 36.29922959112352, 41.1110403460841, 51.88625404911657, 49.42710445773218, 50.86883829485986, 47.65846460096298, 43.227551291065836, 41.617320276075795, 37.93059041423183, 33.92368531996204, 35.923705793196156, 38.93160281642791, 41.004477393242624, 44.218530270361136, 46.33140517819313, 47.185862141270796, 45.58811210816907, 38.29842244425128, 34.13730936665689, 35.38885139649914, 35.8437757338247, 34.46651781758955, 36.141087470516084, 35.37715881101547, 35.978689578271684, 36.185457321905325, 36.21468290205925, 36.47899181612077, 36.246379575421734, 35.95830109811599, 35.59974155118389, 36.529629615045366, 36.07220672792004, 36.31074566994944, 35.60006710790819, 36.886016168902, 36.84540394813784, 39.41310905641125, 43.965247138854, 44.20352720445202, 45.647959632258264, 48.30749919337612, 50.847053450922814, 38.59974284325877, 37.33158957573676, 56.31040519283664, 48.74507488742952, 50.744487393286924, 49.04524210960635, 49.6406461346534, 51.17871338321317, 52.371568910537235, 51.050416577246885, 49.22747935018232, 41.931753158569336, 36.976850417352495, 38.021436429792836, 37.59149759046493, 37.85467293954665, 36.81906915480091, 36.98382439151887, 36.76417166186918, 35.9058472418016, 38.46562916232694, 37.76313658683531, 36.052528196765536, 36.07813735162058, 38.465601705735736, 36.34292479484312, 36.70013112406577, 38.27873606835642, 43.26730451276226, 46.038678692233184, 50.33041454130604, 49.30709561993999, 50.60298004458028, 52.84092364772674, 51.868940707175966, 48.73624170980146, 46.88823269259545, 46.9377447712806, 45.4869031906128, 43.83017247722995, 37.16633227563674, 36.14509221046202, 37.23459328374555, 39.585893384871945, 49.041578615865404, 52.11613632017567, 52.999834552887954, 58.225318078071844, 55.54159710484167, 58.71978775147469, 59.924606507824315, 54.183888281545336, 54.72041753030593, 57.88539371182842, 61.4244031906128, 57.40840211991341, 29.884522653395134, 6.871238466232055, 1.0618451766429409, 1.3945147515304628, 0.939433090388775, 0.032567734484590834, 0.14042835983057178, 3.3975244385580865, 39.25712423939859, 46.84751064546647, 34.40322253011888, 30.75446317272802, 44.19436847009967, 55.366271080509314, 49.692484178850734, 12.253465787056955, 0.1291217294431502, 0.05088401575302405, 0.022034873968110453, 0.061218181790243235, 0.0577581686628682, 0.06352464270387446, 0.06239860453793119, 0.01671448909497309, 0.054633667572371425, 0.054399221684903874, 0.11464681987079883, 0.04438048852006755, 0.06539487400122228, 0.055295828008844014, 0.01137198439063204, 0.0589383845668166, 0.029742072802037004, 0.014453504118137063, 0.03521019773137185, 0.04119235999701966, 0.03697202758743398, 0.047226489837011026, 0.0560540443797025, 0.0526993798332349, 0.07967177282778487, 0.07251125625184468, 0.025416223272200555, 0.04490646916712004, 0.014879861733906213, 0.04633603902954248, 0.07177070203808046, 0.05182443847579341, 0.08127070557806762, 5.862026839487015, 35.44271730607556, 52.47993615365798, 52.28789298765121, 36.99290075609761, 29.696156709424912, 35.875978392939416, 45.703492549157914, 28.739302350628762, 2.8844190941702936, 0.059355461984992995, 0.14570350338134075, 3.9719925676622703, 10.341385833678707, 9.680108543365233, 10.071360065091042, 10.365610391862932, 25.10556370981278, 51.79553747177125, 55.961035759218284, 52.25176011362384, 52.463007203994266, 47.480279168775006, 45.96668358772032, 46.40525164142732, 43.10724435314056, 40.50093527763121, 39.40470733950215, 38.01182270050049, 43.9540683838629, 54.28782324637137, 50.44316307190926, 51.26516242181101, 49.86498217428885, 46.39132330494542, 43.277565433133034, 40.614785994252856, 37.004675711354906, 37.49567800952543, 39.94965007228237, 42.80961490446522, 47.269428237791985, 49.08074348203598, 49.57101229698428, 48.61506008332776, 42.50317581238286, 36.00606772207445, 36.89775582282774, 37.56816341030983, 36.85965391897386, 38.159386188753196, 38.03217587932464, 37.51539968675183, 38.194334506988525, 40.06255549769248, 37.54682571657243, 37.03911804383801, 37.04793945435555, 37.35907362353417, 38.13137262098251, 39.30289829930952, 39.52357084520402, 38.62380658426593, 39.860478908784934, 40.30727609511345, 42.29783188912177, 47.09153306099677, 48.71497069635699, 47.88124345964002, 50.7650916038021, 53.18532343833677, 39.27750487481394, 39.02874031374532, 56.14922323534566, 50.72329090487573, 53.38115561393, 50.9875919741969, 52.87454620484383, 51.72135368470223, 52.96256026914043, 52.2493007875258, 54.267379853033255, 44.33648770855319, 38.42614658417241, 39.43186583057527, 38.712687492370605, 38.839085871173495, 38.88591504866077, 38.346510702563876, 39.99658907613447, 37.72260673584477, 39.61706446063134, 38.198343169304636, 38.394524435843195, 39.36915889863045, 40.221427179151966, 37.759433869392645, 38.995886541181996, 40.52154733288673, 47.26449781848539, 49.23525741023403, 50.92705411295737, 50.68012129875922, 51.73097133636475, 54.48816614766275, 54.847239525087424, 51.36795989928707, 49.162756319968935, 48.54892107748216, 48.07097242724512, 43.36200229583248, 39.32125499171596, 38.910539688602576, 39.201159861779985, 43.432557890492106, 51.76437031838202, 55.06460551292666, 56.24049678925545, 57.870535773615686, 55.83319787056216, 59.801801020099276, 62.48129760065387, 57.15229488188221, 57.491615203119096, 59.11442525925175, 64.73377750765893, 58.97931529629616, 26.86447216618446, 8.782464323505279, 8.065914953908614, 3.530186842526159, 1.81010703165685, 0.19186517313843776, 0.06427487643856196, 4.208709078450357, 42.67240255109726, 53.70151519775391, 38.415046276584754, 32.75418946819921, 47.81330408588533, 61.333972946290054, 56.32001499975882, 16.352075895955487, 0.4092686533206894, 0.04784537013620139, 0.11530893434199596, 0.049502483433893615, 0.037108065650588086, 0.020306884130883603, 0.04234816450926085, 0.01360837507226895, 0.03756543546314201, 0.05228633969841946, 0.04321456781678623, 0.027138095897352024, 0.04689418004765626, 0.01621865783818066, 0.050693554803729064, 0.04327197844583181, 0.32023875643649413, 0.1029620484839524, 0.12410814363148906, 0.13344618852340406, 0.0962056662707079, 0.1881958264857531, 0.14665044934278534, 0.09767298511559926, 0.15058319234559614, 0.12617052893244451, 0.1634643479220329, 0.15846176313296442, 0.0922211816894912, 0.13421622946137382, 0.15948764679412689, 0.15097613416371808, 0.2849123891322844, 7.453510395942196, 41.708009396829915, 59.023445883104884, 61.15878420491373, 39.36753503737911, 38.87518344386932, 49.778862614785474, 55.06331897551014, 33.305409954440215, 4.4108753915755985, 0.129791627367658, 0.9493122538251262, 8.410626572947349, 16.110731478660338, 23.85213698110273, 23.7875335831796, 16.44704040019743, 26.939834625490253, 54.95049199750347, 56.726380394351104, 55.589387263021166, 56.12959569500339, 48.78248645413307, 48.074420190626576, 47.65663677646268, 44.815291435487815, 42.68003940582276, 40.62681982594152, 38.83639120286511, 45.585750841325336, 56.79992483508203, 49.789951155262614, 51.627208955826305, 51.48528583588139, 48.353214417734456, 45.790918257928666, 42.56830284672399, 38.01114020809051, 39.332822061354115, 42.83231758302258, 44.788619318316066, 49.17806533075149, 51.02067324423021, 50.91851119072207, 50.7888376328253, 43.72509218031361, 37.27875524951566, 38.18300670193088, 40.68140352925947, 37.78463509774978, 39.95143475071077, 39.44122068343624, 40.401585563536614, 40.35145767273442, 40.92959150191277, 39.31018998545986, 38.61400065883514, 40.756250196887606, 39.44175804814985, 40.16327411897721, 40.25117443453881, 41.48092377570368, 40.08690949409239, 42.27907119258758, 42.02894164669899, 45.00974685915055, 49.78513448469101, 50.53385611503355, 48.70104628224527, 53.80346544327275, 53.35816660235005, 40.99603253026163, 42.90164939818844, 57.980107184379335, 53.146076202392585, 56.27884972480036, 54.11782772310319, 54.63816542779246, 54.666229986375384, 55.30656868411649, 56.203410779276204, 53.51239027515535, 46.169411290076475, 40.42322920214745, 42.03842986014582, 40.98958023132817, 42.09260171459567, 40.13212265506868, 39.824416637420654, 41.6801841028275, 40.09883349941623, 41.6458829756706, 41.24870769439205, 40.90831264372795, 39.76978586566064, 43.417637194356615, 40.17224850193147, 40.945069174612726, 42.483050131028705, 50.16451005012759, 50.20511834852157, 53.97188025136148, 50.82245234520205, 52.43533488242857, 56.18844693706882, 57.81586185578377, 54.70052326879194, 52.70892020194761, 51.23799216362738, 50.83576879193706, 47.66327734916441, 41.62962867367653, 40.376278431184836, 41.02769390229256, 45.317672529528224, 52.88374808526809, 57.5323490173586, 57.2766379387148, 62.2512270558265, 56.86367903986285, 63.53152005903183, 64.99212441905853, 59.45953107649281, 59.51556605677451, 61.86042170370779, 66.28938951799947, 61.94539200875067, 31.955014390330163, 11.648266623097083, 8.216937482357025, 6.778898517931662, 3.994764868290194, 0.2903149943918951, 0.21640116138564003, 4.4315153937185965, 49.09280084794568, 59.62529436234505, 48.003499815540934, 45.80362673728697, 56.49424276044292, 69.51550760576802, 63.98798981020528, 20.37789171741855, 0.7822479668163485, 0.1052918597575157, 0.27235862889116813, 0.16594285686169902, 0.1483609551383603, 0.15063769184052944, 0.21363183014815856, 0.14685819706609174, 0.1355370263298673, 0.09997433622277553, 0.1859801316693906, 0.20635598669609717, 0.23457198553989012, 0.1128289008873605, 0.0968372981033979, 0.13876159765547322], [0.06314809516733212, 0.01104758733192519, 0.025067881177810412, 0.028229062558121742, 0.027104146710987535, 0.04309026239019248, 0.022704892551466342, 0.05631844813544905, 0.06121134445551903, 0.0606619636528194, 0.046008934807633205, 0.05150343231376141, 0.04354053056768833, 0.07967167323635471, 0.06867549231936855, 0.07193533433300835, 0.09865087336830555, 2.615360434978239, 27.418793286046675, 47.50362903841081, 44.32787418365479, 30.992698131069062, 37.493614842814786, 46.7213789878353, 47.74505484488703, 35.35724493765062, 4.4878754404283345, 0.10376177532898803, 0.23614929928894968, 4.090775419627467, 8.590376050241533, 6.652211844921113, 9.328642602889769, 15.999778413003492, 27.15808314661826, 50.58282690663492, 53.48961699393488, 51.68167891040925, 49.16336820971582, 46.84626333175167, 43.38165729276596, 41.12010102118216, 37.42730717505179, 38.077396885041274, 36.43604186273391, 35.98053701462285, 45.73732299189414, 51.21558366283294, 50.01006672459264, 48.999805373530236, 46.1893565424027, 44.60765684804609, 40.67211143432125, 35.138980727041925, 34.006113929133264, 33.503058187423214, 35.62304043000744, 37.237036920362904, 38.231400905116914, 41.18795410279305, 42.257706042258974, 41.36420580648607, 36.89288423907372, 37.45917643270185, 38.180798407523866, 35.54650322083504, 36.6081319316741, 37.18415160332957, 37.53508998501686, 36.36348193691623, 37.38861691567206, 37.36620449250744, 35.82215955180507, 35.76734835101713, 34.295926094055176, 36.287635064894154, 34.82612855972783, 35.74926622452275, 35.56044332442745, 38.55942087788736, 34.75155253564158, 36.51589739707209, 35.56965304959205, 38.80171745054184, 42.89185523986817, 46.57962060743763, 48.01773801926644, 53.57392049604847, 42.527459206119666, 41.10860847657727, 52.60764852646859, 47.54949723520587, 47.68033573704381, 45.09261869615124, 45.62447247966644, 46.01180653418265, 48.95615331588253, 50.53493476683094, 46.63143119504375, 38.945095769820675, 37.30079112514373, 37.3726567914409, 37.962867598379816, 37.097384852747766, 36.89889723254789, 38.017674876797585, 37.76183043756793, 37.72237139363443, 36.90971512948313, 36.8406774920802, 37.603833444656864, 37.617416612563595, 36.685237884521484, 36.14756330367058, 36.57768649439658, 39.56404970538232, 47.30915792526738, 47.089360067921305, 48.724203955742624, 47.512387691005586, 49.35982011979627, 51.77221505872665, 51.4515926761012, 48.8050243931432, 51.11038177244125, 50.79579983988116, 52.26770847074447, 51.769638061523445, 51.38662645893713, 40.88595513374575, 37.549775338942005, 37.78010476020075, 42.01498193125571, 49.86430360424904, 52.19788635930708, 53.89627264391992, 53.875299730608546, 54.35761790121756, 59.40850496292115, 56.040459832837506, 57.92138538052959, 58.428610601732814, 60.643200412873306, 52.75590627424179, 22.761922036447835, 3.9507021875150747, 6.493075893771264, 1.6982483887864699, 2.0825719016213573, 0.2350485535158265, 0.045429416105992375, 3.687387594292241, 39.95563953153549, 53.07438312038299, 36.71134125801825, 25.105816702688895, 38.329275808026715, 55.487127150258715, 42.745911690496634, 10.894436105605095, 0.2685933986738805, 0.052900692417977326, 0.050029804734813596, 0.01897201039678147, 0.04455923981543991, 0.014486892145097017, 0.044041559731047, 0.009099390308913446, 0.0797857284065216, 0.02061388620565976, 0.04214279165851974, 0.11695059181581582, 0.057943217200978156, 0.0104365584763488, 0.08015530454295297, 0.06014442146425286, 0.07731353203135152, 0.056282112585200425, 0.01684654158570113, 0.019008604501704537, 0.006465298487925001, 0.017046231979263887, 0.019369929871191422, 0.04180444126588203, 0.008342758782448308, 0.045571536907265266, 0.022936105547893434, 0.03395172211551859, 0.04149575762811207, 0.08228956421296443, 0.09544381481264869, 0.03623785105563941, 0.07296134056823869, 3.6716571738643036, 33.454134464263916, 52.07884242457729, 50.33361519536665, 32.96909416875532, 36.9224432206923, 52.19062605211812, 51.19715244539323, 39.37358333218483, 4.531402472526797, 0.10414284278428364, 0.10244550604012706, 3.1084430602289017, 6.98505437181842, 5.292407985656492, 9.858949011371983, 11.990611091736826, 28.122519446957497, 51.86184121716408, 54.961819802561116, 53.8287058953316, 50.979351074464866, 47.868523213171194, 44.77931153389716, 43.75183882251863, 40.07687214882144, 40.22847960072179, 37.574427435475016, 38.077506711406095, 47.08302151772284, 52.71579219448952, 51.178956570163855, 49.36686077425557, 48.33778773584674, 45.65917761095109, 41.877428331682765, 36.80169305493755, 36.403086108546105, 35.55412046370968, 36.69823661927254, 39.75466120627619, 41.30044767933507, 45.165970940743726, 45.48352210752426, 42.31424308592274, 39.3282054316613, 38.086881176117934, 39.10835266113281, 35.93471196389968, 37.36611035562331, 38.05259181607155, 39.52106445066391, 37.33793204830539, 38.02928901487781, 39.18357195392732, 37.45966280660322, 37.59652214665567, 36.85459406145158, 37.77697078643307, 38.35939568857993, 38.10689310873709, 37.9542697629621, 41.26211435564103, 35.97990159065493, 38.31550828872189, 37.92549133300781, 40.695979056819795, 44.649151602099025, 48.98766956021709, 48.60020998985537, 53.97632037439654, 43.98795766215171, 42.736141066397394, 55.304089746167584, 48.76434156971593, 50.45740127563477, 47.48945751497823, 49.90596702021938, 48.375144389367875, 51.25510938705937, 51.456503483556936, 50.05477782218687, 40.824605341880556, 37.32953817613664, 39.43967134721818, 39.68288967686315, 39.640445709228516, 38.8742499197683, 38.285964996584006, 40.42134646446475, 38.51484314087899, 38.116620586764434, 37.27941813007478, 39.347091644041, 38.62654832101638, 39.18706286338068, 38.77535127824353, 38.385448071264456, 40.9390797153596, 48.578797771084695, 48.71390381167012, 51.338981428454005, 47.7211283868359, 49.31034334244267, 53.351867275853316, 53.47989343827771, 53.72369620107836, 54.50072557695451, 52.6961999554788, 55.60606518099385, 53.18019690052156, 52.01654341913039, 42.675328639245805, 39.4229071371017, 39.5840577156313, 44.72785788197672, 52.08968385573357, 53.762982660724276, 55.519980922822036, 55.43046851311961, 56.540518883735906, 61.12811519253639, 60.32030697791808, 59.54583498739428, 62.63281483804027, 61.73915770746047, 54.244328083530554, 25.658825789728475, 10.33235457635695, 12.840281782611726, 6.742704847166616, 2.2197680752123556, 0.1596648276092545, 0.15378648174866555, 3.9383121555851357, 44.44423913955689, 53.48145454160629, 39.876152699993504, 32.716146399897916, 47.04844974702405, 62.37562894821168, 50.871317232808764, 14.530893929543035, 0.3788118166548591, 0.04037112140307023, 0.026055895197655887, 0.03077939607112879, 0.011170672763499522, 0.044727089679649765, 0.011058970440870092, 0.05119793943219608, 0.01967501864137669, 0.004662424034904689, 0.02024640340448147, 0.014953357336531966, 0.06300745674619271, 0.04042454837490955, 0.16545553301130572, 0.01761147654765556, 0.29052888614035427, 0.10551073107748263, 0.13275842542850202, 0.09651765557787112, 0.07568950224066935, 0.20070814137016574, 0.14097298705770125, 0.15501816726980672, 0.15397377492439362, 0.19569766587547718, 0.13945525962739222, 0.09708698914055863, 0.09949057468123014, 0.17160700453865915, 0.23998764493773062, 0.20272807007835758, 0.2833772715060942, 4.902872991177344, 39.240328650320734, 61.36359468583138, 58.243015812289336, 44.033778790504705, 46.253754015891786, 55.104770583491174, 56.304725600827126, 44.85021229713194, 5.712848805612134, 0.18842795112681007, 0.6314088704605257, 8.76913610965975, 19.86938976472424, 14.472059357550837, 16.59615812763091, 21.172952228976836, 31.101547825721006, 52.858158542263894, 57.49424711350472, 55.27465628039453, 53.38690580860261, 50.61540611328618, 47.131631451268355, 45.93506536176128, 41.344970503161036, 42.1266596548019, 39.382236080784956, 39.6359428282707, 49.2885192748039, 56.227654949311294, 50.887449941327496, 51.01025150668237, 52.095885122976, 49.589486660495886, 44.68353117665937, 39.082119849420366, 39.12777231585595, 36.721100115006976, 40.39782793291154, 41.40542599462694, 41.84345276125016, 47.57162332534791, 47.37460267159247, 44.4073570928266, 41.903190458974535, 41.42186072564895, 40.445492575245524, 38.69377774576987, 39.998969954829064, 39.45059907051825, 43.780601562992224, 38.56346876390519, 41.47569133389381, 41.68193740229453, 38.80592223136656, 39.65649604797363, 38.483507325572354, 39.738069580447295, 40.018220947634795, 40.91171726103752, 39.26467087961013, 43.29429826428814, 37.8520018054593, 41.419962298485544, 39.66562340336461, 41.88590457362514, 47.137530696007516, 50.713751700616655, 50.91637742134833, 55.51408560045304, 46.6472501139487, 46.28092035170525, 56.25529981428578, 51.18629532475626, 52.555022085866625, 49.815834876029726, 49.7316921910932, 50.52745088454216, 53.35608774615873, 54.690266270791334, 52.386438615860484, 44.43280543050459, 39.58917640870617, 41.686416749031316, 42.02078703911074, 40.87743574573148, 39.832241765914425, 42.00037894710418, 43.35460078331732, 41.0587316174661, 39.5240415296247, 39.19387602036999, 42.31061097114317, 41.44029586545883, 40.4944045312943, 41.37389406081169, 40.11384441006569, 44.43211509335426, 51.477362648133315, 50.41045442704232, 53.737255834764056, 48.609458938721694, 51.129840650866115, 52.75215648835706, 55.546319638529134, 55.145775041272564, 56.19069837754773, 54.09389734268189, 55.88448678293536, 56.82933084426388, 57.094208502000384, 46.73094172631541, 42.293395688456876, 41.55406813467703, 47.226776384538226, 55.00236926540252, 56.65322426826724, 57.11600119067777, 56.74872221485261, 57.12793696311213, 63.607449300827525, 61.59566171707646, 63.464647569964015, 63.96728361806562, 64.67649129129225, 54.667587126455004, 26.023768994116015, 6.960744011786677, 11.021924903315883, 6.135436142644575, 7.272793564104266, 0.9337343768246713, 0.2311746154220835, 5.416300950511809, 49.30455392406833, 64.56861826681322, 48.325314598698775, 38.43400701399773, 53.07495186405798, 68.6067807289862, 60.043305273978945, 19.115386662944672, 0.6591151450430194, 0.14152503001593775, 0.1489985241524635, 0.09218781089950955, 0.11185455962174362, 0.16473308145519228, 0.12076722653282267, 0.09844679520615647, 0.14293130697502246, 0.13208573894394984, 0.11596190938425642, 0.1240390501615982, 0.21760395007027736, 0.09791560516121889, 0.30060254397892183, 0.2140543582819162], [0.030567364001105872, 0.021945810501253413, 0.08532624481426132, 0.10721912247038658, 0.014193484300537216, 0.017310189488794536, 0.01747380863244255, 0.06410329955660048, 0.025271570550337918, 0.039501450730547796, 0.05476752611538095, 0.03098053054042882, 0.05050369523345463, 0.058506364603677107, 0.050741776208122896, 0.16195559904219645, 0.041234559950328646, 1.9369149304205373, 23.233996937351844, 49.52246119899135, 50.301596887650035, 43.0290009129432, 18.520390564395537, 22.890185502267656, 38.92816682015696, 38.81632827943371, 7.498777979804625, 0.03350449530708213, 0.0930741822887813, 2.0253040713648645, 6.021001973459798, 3.2934722929231586, 6.196571184742836, 9.889740597817207, 29.178201844615323, 46.076313834036554, 55.60276646767893, 52.78888164028045, 51.663330062743164, 49.07301641279652, 44.684503924462106, 41.81040287017822, 39.72381176487092, 37.61674196489396, 37.248262743796076, 40.60907502328196, 47.028551563139885, 49.61124404784172, 47.87584627828291, 50.33492918937437, 46.19040773760888, 42.38147251067623, 40.52822712929019, 37.12824998363372, 33.67743499817387, 33.33055626961493, 35.274996757507324, 35.58392655464911, 36.16161323362781, 36.11113625188028, 35.417508232978086, 36.74121402925061, 35.435978674119525, 34.78845419422273, 36.461635328108265, 36.018105476133286, 35.35792350769043, 37.552999527223655, 39.00499036235195, 38.07574556719872, 36.22453197356194, 35.62924561962005, 36.62545311835505, 36.53402659200853, 36.33320516155612, 35.75842888124528, 34.58243170092183, 37.250796594927394, 36.934986960503366, 36.202127395137666, 37.871856843271566, 38.0746433811803, 38.63624834245251, 39.85692524140881, 40.50155108974826, 47.43653689661334, 46.46633078975063, 53.07882324341805, 44.86361895838092, 41.41027404415993, 52.793329608055856, 45.91712051822294, 45.26203370863392, 40.223372674757435, 40.72557726214009, 40.973737778202185, 43.01699453784574, 42.55025994393134, 39.956345558166504, 36.35894767699703, 37.50472691751296, 35.27690695178124, 37.48371085812969, 35.51056254294611, 36.477450324643044, 36.10082041832709, 38.01900063791583, 36.611552238464355, 37.05131269270374, 35.51204519887125, 37.901239318232385, 38.97726312760384, 36.60974402581492, 37.037427502293745, 36.20160571990475, 38.43812942504883, 45.534552143466094, 47.55889523413874, 50.60037559078586, 45.85697097163047, 49.55833911895753, 46.59745562461115, 47.740995191758685, 49.84980652409215, 50.518978564969956, 50.23564615557271, 53.51542226729855, 50.89303931882305, 52.9483534443763, 50.41845606219385, 42.37163912865424, 36.48647569840954, 38.613702558702045, 43.760691611997544, 53.334914791968565, 52.43535449427944, 54.28991779204338, 52.34059787565663, 59.399389374640684, 59.68824448124055, 58.55740947108115, 58.45225857150171, 61.78434341184555, 48.230216733870975, 15.160831482179704, 7.710442312302129, 16.31773946746703, 4.032495863014653, 1.0526325097007136, 0.046682820219786904, 0.056707839136041945, 3.8029043376445775, 31.938091324221705, 57.082068766317065, 46.62309223605741, 25.894566120639926, 38.74735732232371, 51.7813188798966, 47.35108414003926, 14.590840493479083, 0.4354455406146665, 0.06480236627882527, 0.03527072250782963, 0.004389234208276555, 0.04905946627860108, 0.052991002692931125, 0.02263721825945522, 0.04597290952299391, 0.0536492599114295, 0.08860418182467261, 0.021952712953451182, 0.03258360016550268, 0.09079978981566045, 0.08363506741701596, 0.045850304811592066, 0.062438667105931434, 0.09308929720352735, 0.0389805339246748, 0.0896767815274577, 0.08275781247404315, 0.02613770955752942, 0.0607305821481972, 0.0780548140286438, 0.06895805618936016, 0.0401225948195544, 0.06474048935718114, 0.06509591584965106, 0.07053170037726242, 0.06131069839841897, 0.027319735344198924, 0.05723672708676708, 0.038444077025257775, 0.04425629800666244, 2.706075296286614, 29.171694632499452, 57.1657996023855, 55.34114437718546, 48.47842039600496, 25.873679499472342, 33.38449670422462, 48.063880781973566, 43.18381686364451, 8.460383799768264, 0.10614947220610996, 0.1026265632601515, 1.643936309602953, 9.886132997851218, 6.765779660594079, 5.046431249187839, 8.89091883936236, 30.015633759960053, 46.91199833346952, 55.48103963175128, 54.218656170752745, 53.55976466209658, 50.557217751779866, 46.646030256825114, 43.57296305318033, 41.19438678987565, 39.48551208742204, 38.31248414131903, 41.16469052530105, 50.41586337550994, 50.957742737185576, 47.35121357825495, 51.17626974659582, 49.388869193292436, 45.91178609478859, 42.63658346668367, 39.139527659262384, 35.90516474939162, 36.014951890514745, 37.00294202373874, 36.592917057775686, 39.41916911832748, 38.22921222256076, 37.897834700922814, 38.842208077830655, 37.24160648161365, 37.92180822741601, 37.889648714373195, 37.35240559424124, 38.34017607473558, 39.425119353878884, 38.80716954508136, 38.87657196291032, 37.56301726064375, 37.78272098110568, 38.28875772414669, 37.424820392362534, 37.885726344200876, 36.831585438020774, 37.068626034644346, 39.25882654805338, 39.03131731094853, 37.521185182756, 39.14776855899442, 39.15904145086966, 41.65431999391125, 41.469023304600874, 42.98230901841195, 49.53220044412921, 48.44300531571912, 54.72135105440694, 46.988543387382265, 42.931824191924065, 54.947773794974054, 49.67102881400816, 49.77211613808909, 42.941928217487956, 43.26166806682464, 43.09467707910846, 45.000780320936634, 45.26207293233564, 42.28019299045686, 38.69042804164272, 39.65979868365873, 37.445585420054776, 39.42806113150812, 37.216444476958245, 37.86787955991684, 39.276320319021906, 38.43459929189375, 38.38499307632446, 38.49549408881895, 37.80604339415027, 38.53560816857123, 41.907544289865804, 38.82611851538382, 39.340788395174094, 38.64299874151907, 41.07429950468002, 47.12248056165634, 49.56122598340435, 53.56812715530396, 48.99193709896457, 48.87648213294245, 48.029830686507694, 49.01805223957185, 49.68168589376634, 51.75246592490904, 50.97449518019154, 53.63718832692793, 53.52841315730926, 55.192482625284505, 52.5974738982416, 42.24106734798801, 39.201355980288604, 40.92883448446951, 46.29239328445927, 56.42748402011011, 55.18156274672478, 57.294272915009536, 54.35080866659842, 59.85720842115341, 59.80349156164355, 60.98235991693313, 62.07199042843234, 64.51529756669076, 48.695417681048, 21.512119577777003, 10.895042111796718, 11.697691429045893, 5.675947147030985, 1.9096050603735832, 0.10476780199115315, 0.0876494677316758, 4.015103583374332, 38.312374314954205, 60.33920887977847, 47.948002199972834, 29.732032668206003, 43.56695790444651, 59.976554378386474, 55.57363502440914, 16.903493481297648, 0.6306834158397491, 0.06497980756384712, 0.04097970165011864, 0.018293245004550106, 0.0504589097334012, 0.09170097734538779, 0.032363587374528574, 0.013495609802644581, 0.09430415943385133, 0.05089352290416437, 0.03576745008749347, 0.05326130149525501, 0.010028827330848623, 0.03804766099839922, 0.011913462038782817, 0.058254379133183154, 0.22680025337444198, 0.13368303226607461, 0.16119936300862223, 0.2203448134804926, 0.1344077054771685, 0.1653904155377419, 0.11716660562782519, 0.17576563622682326, 0.13734773642593814, 0.13852075493383792, 0.1449824461052495, 0.14407077083183875, 0.20171364709254236, 0.11710938652076068, 0.2680860033198711, 0.1900586152389165, 0.16680697339677042, 3.42315026348637, 32.40013868578019, 64.13283901829874, 63.00258059655467, 55.645159444501324, 28.69181029258236, 34.823853585027884, 50.887042014829575, 47.9078959649609, 10.559758890059687, 0.3190223313868046, 0.2786751464009285, 5.52798455761325, 14.529805471820218, 11.729309655004933, 13.662073246894346, 12.802573096367622, 31.951584277614472, 48.73365686785791, 57.4736350582492, 56.394991105602635, 57.63412275621968, 52.925580163155836, 48.57275732101933, 45.34168920209331, 44.02416113884219, 40.181972057588645, 40.863476030288204, 44.00645163751418, 53.01587312452255, 53.5116607143033, 47.79166829201483, 52.99714772931991, 52.2839000148158, 47.026766884711485, 44.89430366023895, 40.43645935673868, 37.06833970162177, 37.20305350518996, 38.277555434934555, 38.67085149211269, 40.576315387602776, 39.67281310789047, 38.99482750123547, 40.80443259208433, 39.3551678042258, 39.359827579990515, 39.57999414013278, 39.16169689547631, 38.39155912399292, 41.18625571650844, 42.85958590046052, 42.21153582296064, 39.40470733950215, 38.542389946599165, 41.96085322287775, 40.21016997675742, 39.91832994645642, 38.63567567640735, 37.935163897852746, 41.0638895342427, 41.580806932141705, 40.01136072220341, 42.08339983417142, 41.45933505027525, 45.04836651586717, 44.429887187096384, 45.1159175749748, 51.195540351252404, 51.117767595475726, 57.08573618242818, 48.256924152374275, 46.98367180362825, 56.06280165333902, 54.622605385318884, 51.349360019929954, 44.925682621617476, 44.92091301948794, 45.349781051758804, 46.37839909522764, 47.870821722092174, 44.006035866275916, 39.41759624788838, 41.708060387642156, 37.732063570330226, 41.352854467207386, 40.00402196761101, 39.42744531939107, 40.61994783339962, 40.72372982578893, 39.75737548643543, 40.756897387966035, 39.04083690335674, 40.81097510553176, 43.3540516514932, 39.999201374669234, 39.61989248952558, 41.49179658582134, 43.58468309525521, 50.18503189086915, 53.35460509023359, 56.03005770714053, 49.24632241649013, 49.45236844401206, 46.68188856494042, 49.4835473645118, 51.113743243678925, 53.533002330410866, 53.72159381066599, 57.55935061362482, 54.92331389457949, 57.357462298485544, 56.10954061631234, 46.11882055959394, 41.58000676862655, 43.158792141945135, 49.193401798125244, 59.16285084139917, 57.84489131742909, 58.28556960628879, 55.071316688291496, 61.769763961915054, 62.7517960148473, 64.09399970885246, 63.43939927316482, 65.98950078410488, 51.289869431526434, 18.74310274277964, 10.812195770202145, 26.12313832006147, 9.973323364411632, 2.8629816251416362, 0.3238306362782756, 0.22769820035224964, 5.033971840335477, 40.588157023153, 68.11642169952393, 57.42717850592829, 39.56754061483568, 51.8199424589834, 67.15759831090128, 64.04015341112691, 22.337303892258678, 0.9014165593731789, 0.25358273317256286, 0.1268271582141038, 0.1410228440598134, 0.14166811991843486, 0.1512219564568612, 0.11543359216903487, 0.19861517383927302, 0.28467171494999244, 0.2152217230609348, 0.09835203779080222, 0.15118417300043568, 0.18388036127773025, 0.18838342609665087, 0.12576011264876974, 0.2003864150854849], [0.056185964720263604, 0.07862733451709633, 0.04283414004490741, 0.05964297478297546, 0.010096794651490788, 0.06172570737919981, 0.021394954979299538, 0.030520310880796566, 0.020078189648507584, 0.028886494316881704, 0.09773533701175645, 0.022071090774730812, 0.019796962601943843, 0.04335552033397459, 0.13609411014664557, 0.04677686134293195, 0.015179736318156846, 0.5571805277178364, 16.50132502278974, 45.240633256973766, 52.6317044227354, 38.20665467169977, 23.22726615013615, 34.31163910896548, 37.56901848700739, 46.502993183751265, 12.587303615385487, 0.3304463877312599, 0.08274239112412737, 1.2389246230163884, 4.190912304386016, 2.27885490463626, 6.389821460170131, 7.743491713077792, 30.568423194269982, 49.575495566091234, 48.365463979782604, 54.70492416812528, 52.940308663152884, 52.15155532283168, 48.13776646890948, 44.20699065731418, 39.5094189336223, 37.542624858117875, 36.52121220865558, 42.43381654062579, 52.59239442886845, 54.02553435294859, 49.78555025592927, 47.93256767334477, 47.163437950995664, 45.73138844582343, 42.22002775438371, 37.71508362985427, 36.44994274262459, 34.78877975094703, 35.831855650871034, 36.04083953365203, 35.71918949004143, 34.54146254447199, 35.94573382408389, 35.67437641082272, 34.67772176188808, 35.65433309924218, 34.65367763273178, 37.13358440706807, 37.32350557081161, 39.38968466174218, 35.49409643296273, 35.76638737032491, 34.98833817820395, 35.5656365425356, 35.897535739406464, 36.14923815573416, 34.855499267578125, 36.10283259422549, 35.41320147052888, 36.82170498755671, 38.698084508219075, 37.79052257537842, 39.033415778990715, 39.36815084949617, 40.403880150087424, 43.03253889083863, 42.68887258345082, 46.5376434018535, 46.86594970764653, 50.77403068542481, 39.50677525612616, 43.51355483455043, 51.65280242120066, 46.45834092170962, 42.646993437121, 37.66135500323388, 36.650666113822695, 36.525515048734604, 37.741536094296364, 35.71913065448884, 36.675753593444824, 37.09217202278876, 39.84244385073262, 36.94875840217837, 35.76264935155069, 36.63860090317265, 37.30123043060303, 37.63525555210729, 38.14701503322971, 38.69613901261361, 36.51865090093305, 36.55750982223019, 36.971892541454686, 37.66504595356603, 35.54944892083445, 37.43144527558358, 36.1399382160556, 41.210013512642156, 46.75236178982643, 50.26370286941529, 50.56807487241684, 45.56367574199554, 50.53339327535322, 51.27486244324715, 49.34094175215691, 50.9498195494375, 52.02949900780955, 52.241318764225134, 51.18615411943006, 51.32749672858946, 53.06403590786842, 52.84263772349204, 49.571945821085286, 40.50802692290276, 37.56948132668772, 38.29420981868621, 45.15889890732304, 53.43151100220219, 56.97467034862888, 58.43010110239829, 54.62945776600992, 58.80070624812957, 62.37301664967691, 62.619490546564904, 59.28684088491625, 36.70704234030939, 13.886705425477798, 13.528458687566943, 11.986298445732364, 11.775066064250085, 2.0964384607730375, 0.08108411720322986, 0.12025652167898034, 3.9017573816161004, 38.4407260341029, 48.66106556307886, 46.04749618038055, 38.27911261589297, 39.69477445848527, 49.7692253512721, 44.35376967153242, 15.375000738328504, 0.35801835177886876, 0.03239518467096552, 0.027939946721157724, 0.04059640487896339, 0.06000904223671364, 0.07193808458865651, 0.056350508915080186, 0.07022884283815661, 0.030868915360300776, 0.018614260742681164, 0.06443636777300028, 0.03234157383802437, 0.07252319190170496, 0.035911976404848604, 0.03852434771796388, 0.05241734073347142, 0.08490147970376477, 0.08066086128594414, 0.009225858018673476, 0.0265364391699193, 0.020210945024906148, 0.0014337749669193142, 0.02672006853014952, 0.05423224899136732, 0.017612175602886467, 0.04495501998932131, 0.07451528863560769, 0.006122994602793047, 0.014210133306351642, 0.025992465032745275, 0.057048051122335665, 0.008690801144938075, 0.037923382384882826, 1.1096619333951705, 20.270369745069935, 51.60910329511089, 58.13377780299033, 43.71327407898442, 23.682925931869015, 34.57911337575605, 44.482082166979396, 49.43223491791756, 12.890946057534988, 0.2829049323354998, 0.11269995296794562, 0.8769691002465064, 7.031723222424907, 7.4909508901257675, 4.768705377655645, 6.365768995977218, 29.38501273432086, 50.00972155601748, 50.87050530218309, 56.67225953071349, 56.36069782318608, 52.11676782177341, 49.32606420209331, 46.792256216849054, 41.25033155564339, 39.49485517317249, 37.09023044955346, 43.6227967662196, 53.315306863477154, 53.905913829803474, 48.33443803171958, 49.61586852227488, 49.412795651343565, 47.633490870075846, 44.228336195791925, 39.39965140435004, 37.3492088625508, 37.17990367643295, 37.969288518351895, 37.976686108496885, 37.40154112538984, 36.0553523032896, 37.88108618028703, 36.92594197488601, 36.244312486340924, 37.68319868272351, 36.06336178318147, 38.452767710531916, 39.53321987582792, 40.97884862653671, 37.59995422055645, 37.54673157968829, 38.52266434700259, 38.4397768205212, 37.723724611343876, 37.76364257258754, 37.89955269905829, 36.68834047932779, 38.76792230913716, 39.7202306409036, 39.273911983736106, 40.49247472516952, 40.75551671366538, 40.03843292113274, 41.74129463011219, 44.39877886925974, 45.67682435435634, 48.48993647483088, 48.41324629322175, 52.97328010682137, 42.112974505270685, 45.91080550224551, 54.43060536538401, 48.9446960726092, 45.09570167910668, 39.3371602027647, 39.0509448512908, 37.53996549114105, 39.49397263988372, 38.531250415309785, 39.09143155620944, 39.587156388067434, 40.88506867808681, 38.06036595375308, 37.23092979000461, 38.618538841124504, 40.60392102887554, 38.4640053010756, 39.07955461932767, 40.845750839479514, 39.3787020252597, 37.84813827083957, 38.51165033155872, 39.16034760013704, 37.05009675795032, 38.6122630488488, 37.915002915167044, 43.023227184049546, 49.01645583491172, 51.28162460942423, 53.85649196563229, 46.359497193367254, 50.70713858450613, 50.33653343877485, 52.25309371948243, 52.47006354793426, 52.70034982312111, 53.52805622162358, 53.37945330527521, 52.24657474025604, 53.019140458876095, 54.319865088309015, 52.9360842704773, 42.10651043922671, 39.66851811255179, 39.39445818624189, 47.54945801150414, 55.08318185806275, 59.01287901786066, 58.59642920955535, 56.184453964233406, 57.79755615418958, 64.63358448397729, 62.2485637664795, 62.27878562865719, 39.801447237691576, 19.374015984996674, 10.416560999808773, 9.326603950992707, 8.274636037888067, 2.456866771944108, 0.09653545946123139, 0.05154947419801066, 4.71635889622473, 37.63136456089635, 58.49167446936331, 54.670936830582164, 45.49856439713509, 47.45810993256108, 57.55352589391894, 53.18903792288996, 17.563357737756547, 0.5847091311889311, 0.03932009473623287, 0.054909505190387856, 0.03761163822585537, 0.03545531905406425, 0.0485994381409499, 0.046540366170266946, 0.035642497316603704, 0.026799956178893487, 0.03333136326663437, 0.049828499810950416, 0.062226227094088836, 0.0931410464428125, 0.01662928862647424, 0.058707558444791266, 0.020117878748644746, 0.2126387350501553, 0.16491807636714753, 0.12706951012894993, 0.17581412959243023, 0.09291006327276269, 0.12661698199207747, 0.1163474661147883, 0.09244589059944115, 0.16832384280860427, 0.12707143300963988, 0.1721933835576619, 0.1637523356945284, 0.07501985712517655, 0.16189328545043546, 0.21155951634770442, 0.1010029931222239, 0.11389118138580553, 1.2415109358487593, 24.119048387773578, 59.40415505440005, 65.95747070927774, 51.55756335104666, 34.570209595464895, 44.25667139791673, 47.422730153606786, 56.41311637816891, 15.754246865549396, 0.8037233112319824, 0.3291560811621528, 4.313489804344793, 11.580153684462271, 9.712227852113786, 11.701958967793374, 10.532592554246227, 30.232085835549142, 50.06740393177156, 51.89942144578504, 57.249310785724276, 59.007242571923044, 55.47893724133892, 53.058132740759085, 49.01518498697589, 43.28229188919068, 40.319682551968484, 39.87692148454728, 46.67288280302479, 57.00921858510664, 55.993924833113155, 51.19805851290303, 51.20822921875985, 52.33072134756273, 50.89601247541366, 46.7302200102037, 42.77492938503143, 40.0319766998291, 38.85661886584374, 40.737285537104455, 39.50958367316954, 39.53050559566867, 36.63195248573057, 39.253307773220925, 39.220807013973115, 37.7771080693891, 39.647094126670595, 39.05693431054392, 40.51327897656349, 42.41754262678085, 43.433240382902085, 39.539856526159475, 39.14947871238955, 40.28697782947172, 40.23335902921615, 38.98933226062406, 39.63964946808354, 39.403860107544936, 38.18856470046505, 41.1751671760313, 41.57287982202346, 43.63734091481855, 41.92753268826393, 43.96160717933409, 42.48527019254623, 45.38605120874221, 47.40561685254497, 46.1402916139172, 49.83996529732981, 52.426678211458274, 53.682707432777654, 41.808457374572754, 49.18219950891311, 58.17533139259585, 54.29058459497268, 45.99112387626402, 41.65984661348405, 40.10562704455468, 40.54787428148332, 40.91797736383254, 40.67746546960647, 40.9763853780685, 42.31612974597562, 43.88522294259841, 40.66066988052861, 40.58408952528431, 40.61026742381435, 41.40976805840769, 40.36753939044091, 42.46703117124496, 44.827772417376124, 40.279901873680856, 39.26320391316568, 40.9580796764743, 41.68456931268015, 38.459223931835545, 41.21977236963088, 40.99287109990274, 45.66755579363915, 51.89950773792883, 53.01871684289748, 56.627073826328406, 51.35840892791749, 50.12904790139968, 53.37169877944454, 55.10428028721964, 55.67205905914307, 55.92770345749394, 56.845557689666755, 55.339191036839644, 56.22227737980505, 53.971433101161836, 56.04139727930869, 55.20067645657448, 43.90905134139523, 42.46432865819624, 41.55305616317257, 49.03107058617377, 59.45852694972869, 61.72828489734281, 63.07785480253158, 57.40186352883616, 63.22944656495125, 66.0830493127146, 64.76228529407133, 63.05755261451968, 39.992533345376295, 16.583859535955614, 18.311500818498676, 26.039638903833207, 23.4340182042891, 7.357756024406803, 0.2757162696892216, 0.3441785444175044, 5.091934665556877, 47.76332916751985, 61.55130755516791, 57.96414313777801, 50.817243437613214, 53.534445762634284, 65.83546930743803, 61.13248471290835, 23.024214852240778, 0.8819099996359119, 0.1733069536426375, 0.07981276364936944, 0.20326279944950537, 0.12257409852839286, 0.23436586192298323, 0.1436998617024191, 0.17617399173398174, 0.12182412909403925, 0.18009081542972596, 0.15073884609005145, 0.13776764453899476, 0.12641921639442444, 0.09330013992204782, 0.14057059171459368, 0.10569040167836413], [0.04911801454821422, 0.014343851080705083, 0.017177386231900706, 0.029407261735609466, 0.0084285031733734, 0.025543558576534835, 0.07435708381836453, 0.08124506461524195, 0.0518441767311625, 0.048534918215967, 0.0364510418336478, 0.03458998443919324, 0.03955665502637144, 0.0169549755857236, 0.08052789906580603, 0.024754859567169222, 0.058861193547566096, 0.27093805673141635, 12.846487952816872, 42.39599312505415, 45.99684661434543, 45.11242666552144, 23.50005130614004, 30.499820939956177, 38.05694172459264, 44.81915497010754, 19.52792194581801, 0.39519387147118973, 0.05487789257219242, 0.5390612612808905, 10.42080500433522, 6.459071886154914, 2.066160949968523, 5.3268733620643625, 20.011801219755604, 46.82453732336722, 51.4817988487982, 52.36100989003336, 55.77352685313071, 53.952927358688854, 51.68726436553463, 48.21038523027974, 44.091374874115, 37.18252381970806, 36.948181813763036, 39.40064376400363, 49.19679464832429, 50.6434275257972, 49.08077878336753, 48.4971301017269, 49.564991458769775, 45.1346194359564, 43.94456055856521, 44.3885846291819, 36.52253012503348, 35.24411201477051, 34.49700247856879, 36.19587905945317, 35.42681209502682, 34.91744133733934, 33.95532315777194, 36.315444669415875, 38.30968749138617, 36.22865830698321, 36.028448766277684, 35.80180637298092, 36.60210717108942, 36.30675269711402, 38.242614961439564, 36.921031167430264, 36.935187001382154, 36.18562598382273, 35.07432829949164, 34.231230520432995, 34.325253655833585, 35.16077733808948, 35.81713499561433, 37.453320334034586, 36.540384754057854, 36.2183463958002, 38.098561994491085, 39.805785379102154, 41.82491956218597, 44.42806720733643, 44.26963483133624, 48.02255076746787, 48.372469332910356, 50.66009367665937, 40.75456357771351, 43.946086360562234, 53.23759686562323, 46.87930145571309, 43.76784601519185, 39.34374193991385, 36.80507021565592, 35.82373242224417, 36.93807778819915, 36.53140252636325, 37.098957723186864, 39.36231044030959, 38.97002243226574, 37.41020956347066, 35.92146611982776, 36.2595038260183, 36.566495972294966, 36.05066899330386, 39.93501178679928, 39.786404948080744, 36.64852057733844, 37.50359335253316, 37.034132711348995, 38.43903157018846, 37.33351153712119, 37.22807822688934, 35.77939394981631, 40.739317324853715, 44.65561959051317, 51.01032603171564, 48.34070205688477, 49.520350963838645, 54.343128665801025, 51.57437070723503, 47.56255088313934, 46.58280557201755, 48.08238260207638, 46.42579309401974, 47.196185819564334, 48.68485081580378, 53.05102540600685, 52.47389570359261, 55.5041737710276, 50.3258292905746, 40.27206890044674, 38.26712977501654, 41.00376744424143, 46.37355496806484, 53.23266252394646, 54.184727668762214, 56.58014266721664, 55.57023825183992, 58.11580550286078, 58.361510615195, 53.48138393894319, 28.580742497597974, 15.905770967083594, 6.236482281838694, 4.426864933583045, 2.226316717363173, 2.5265045319834067, 0.07392304904398418, 0.04865030637912212, 4.214273941132331, 38.95654516835367, 55.38899337091754, 39.05747951999788, 30.87204210219845, 43.95064807707264, 51.19488531543363, 40.84774732589722, 13.369337935601513, 0.3906974256519349, 0.059352324854943066, 0.0260999605750605, 0.05464448856430189, 0.13345959506207897, 0.04050399935353668, 0.02852251828317681, 0.0468309739634635, 0.017259721531562747, 0.0563932144864192, 0.07402552862561519, 0.041230698867190274, 0.013330545625649394, 0.031938565624577385, 0.04247545001788005, 0.07632569995738807, 0.03760144925646244, 0.10531268202729764, 0.0262231647502631, 0.02654023705080392, 0.01841347101294706, 0.030712411258249517, 0.0704476528710896, 0.04805196489718172, 0.05095744145012671, 0.05103439498212069, 0.08211353252972327, 0.014911580646801141, 0.012303713930680627, 0.016289676103981274, 0.03776262266441219, 0.040802896218073946, 0.016868949657486334, 0.35791014952044337, 16.752868583125455, 50.70716211872716, 54.58626462567238, 52.46572540652368, 30.071347105887632, 32.18411807091006, 44.712086031513834, 51.72668026339624, 20.309960188404208, 0.5860027166143541, 0.06046126010797678, 0.34449821758654814, 5.189583051589228, 7.730261068190298, 5.2587373795047885, 6.2123847103887995, 23.510343605472197, 46.80916947703208, 53.50819726144114, 54.802257783951305, 56.752566137621486, 54.658479382914884, 52.80374742323353, 50.734857974513886, 45.123523050738925, 39.8892455716287, 37.08386836513397, 43.82211592889602, 52.442634413319254, 52.11434379700692, 51.74611952997024, 48.34141592825613, 51.022728566200506, 47.69519759762672, 46.993999404291955, 44.62716671728319, 37.758735687501975, 35.48788339860978, 35.437355426050004, 36.28411277647942, 37.35091901594593, 37.63127042401222, 35.99177460516653, 37.2769078131645, 39.837482052464644, 37.82190938149729, 37.445044132971, 37.52421325252902, 39.62153988499796, 37.84554558415567, 39.918459384672104, 38.559362042334776, 39.10887433636574, 37.42646778783491, 35.646531504969445, 36.280194328677275, 37.28931819238971, 37.34889899530719, 38.170604167446015, 40.38274249722881, 38.418921578315, 38.665870081993845, 40.12037515640259, 41.327237467611994, 44.00021899131037, 46.35037768271662, 46.85073875611829, 49.93206647134597, 52.075998706202355, 50.66554184882872, 41.92364954179333, 46.967170392313314, 55.09577266631588, 50.001904272264056, 46.214141999521566, 41.45532246558897, 39.06606951067525, 37.96536222580941, 38.68831780649001, 39.25116223673667, 39.93479213406963, 38.944989865826024, 40.463123629170084, 38.92386398007793, 37.55379576836863, 38.435564194956136, 38.48217764208394, 37.821336715452134, 41.69121773012223, 41.38734386813256, 38.0476104059527, 38.62838791262719, 38.5205227328885, 39.826534717313706, 37.95315188746299, 39.71886173371346, 36.90561625265306, 42.932196817090436, 48.05565949409239, 54.02509112511912, 53.163958288008175, 52.78488866744503, 56.04466069129206, 55.163025625290416, 49.93649090490034, 50.01132972778813, 49.32539739916402, 47.48422899553853, 48.94271919804235, 50.88967000284503, 55.62601043332008, 54.08934347091183, 56.348620845425515, 50.539284675352036, 41.61111900883336, 39.87464258747716, 43.25826344951507, 49.213135242462165, 55.89315522101618, 55.9497981686746, 59.674171017062285, 58.31990211240707, 59.49646803640551, 59.577468902834006, 54.801245812446844, 33.53935580099783, 17.930485702330067, 12.924519585024926, 9.135545299899194, 4.763327317853128, 2.8292585572888775, 0.16436428672844366, 0.04236779934276016, 5.109395586675213, 43.24116976030412, 56.17339680271765, 45.56952399592246, 34.35052156448364, 47.93168121768583, 60.299404667269805, 49.98674038917788, 17.03578326009935, 0.3900291518338265, 0.14436956044406662, 0.023870820915626905, 0.05833572234898325, 0.014834046803204524, 0.024921428149325714, 0.027258687712732824, 0.017531025824287248, 0.017925430870344563, 0.09539810234620687, 0.054953658667903756, 0.03521164563754874, 0.04246375185527629, 0.010678711208334614, 0.04553247025356658, 0.004446720488504657, 0.1829367554596355, 0.2597309258436003, 0.09967514058394779, 0.10722187272603474, 0.1840638699791124, 0.17157050810994642, 0.1494372627066989, 0.28593591324264006, 0.21475519083680647, 0.20046008210028374, 0.18032972760979207, 0.19229744591059225, 0.18772537189145244, 0.1635519577370536, 0.22429487007039212, 0.1389848969636425, 0.21429101816348492, 0.36799692278427465, 18.698638754506266, 57.62064941467778, 60.42695622290335, 58.54927447534377, 34.65260682567474, 38.99767906435075, 49.46680668861636, 56.03784361193257, 24.59077027536208, 0.6988219724547479, 0.34655488787158845, 1.4628998045959782, 17.089005900967507, 13.360807761069267, 4.2916799552979015, 7.487522738595163, 21.295438043532833, 47.07060329375729, 52.511126841268236, 55.90863289371614, 58.455298408385254, 58.23785789551274, 56.44124369467459, 52.50305852582378, 47.385146002615656, 41.564172160240915, 40.77805073030534, 44.594760094919515, 54.378484910534276, 53.40928293043568, 53.26757161848007, 50.889893577944854, 52.59567745270268, 49.534546021492254, 49.53789180324924, 48.23934408926195, 39.75038190041819, 37.901627632879446, 38.3417607122852, 38.60162558094148, 38.46181661851945, 38.55411391104422, 36.48315737324376, 39.79814852437666, 42.45103574568226, 39.458326139757716, 39.17720594713765, 37.6515765343943, 41.416808712867, 38.99214852240778, 41.9635243569651, 41.09619417498189, 41.34754750036424, 39.400977165468284, 38.34313354184551, 36.98256531069356, 39.21051079227079, 39.528018812979425, 40.95728735769949, 42.66695437892791, 40.37100676567324, 40.30765264264999, 42.07480984349405, 42.997092431591405, 47.33475923538209, 48.22823593693395, 49.02008010495094, 52.217270712698664, 55.28807078638385, 52.73461172657629, 43.54846785145421, 49.908026264559844, 56.92453461308634, 52.97460194556944, 48.758591375043316, 43.26963440064461, 40.129608415788226, 39.68971460096298, 40.60371314325641, 41.13817922530636, 41.245032433540594, 43.19117523008778, 41.3218951994373, 40.861546224163426, 38.69889643884475, 38.79664974827921, 38.805977144548976, 39.0652262010882, 45.7405314906951, 42.9687140833947, 40.01718151953913, 40.54906275964553, 39.979946459493334, 42.23288528380856, 40.57935130211615, 42.27850244891259, 38.79122118796072, 45.40716140500961, 50.59798686735092, 56.31249973850866, 57.26696537386987, 53.94842840010121, 58.282847481389204, 56.540730691725216, 52.213203214829974, 52.67361102565643, 53.00354119270079, 49.98273564923195, 52.063984486364554, 54.68140955894224, 59.27281841155022, 54.69456126613002, 58.557935068684245, 54.3740761664606, 44.77904089035527, 42.06681605308287, 45.7074619877723, 50.20867201589769, 58.19533940284484, 59.00363006899434, 62.51845029092605, 60.341421096555656, 61.1959094385947, 59.81809454579508, 55.94485598225748, 33.90661908734229, 18.996283892662294, 14.049959375012307, 10.425693258162468, 8.218379443691623, 4.264910759464387, 0.32897225070384245, 0.1686857887093098, 5.851937522811275, 48.1140322069968, 66.65424054668796, 49.513984957048976, 43.034978605085804, 59.49604049805672, 66.6282509219262, 59.05134962451074, 21.89592153795304, 0.7631180771896917, 0.1709617286800377, 0.12209514801901196, 0.182824983231483, 0.32808107594328545, 0.1993578194730705, 0.11784946576001183, 0.11899552563385618, 0.08304276653835851, 0.19788049551988804, 0.16655598767101767, 0.14109372251456784, 0.12925216357313818, 0.11253501423784804, 0.11647731801795384, 0.19731470894428993], [0.023020262221595453, 0.028821549213100827, 0.02796905806228038, 0.03216326304320847, 0.0036863547622136054, 0.05289161044563498, 0.17311722430731022, 0.02837709372773046, 0.06881281357979582, 0.015006731639826491, 0.037802114496908845, 0.0525634145484336, 0.03172540740530578, 0.02920266454889169, 0.039294354181977055, 0.0504178359293409, 0.05608954489411366, 0.09682727001246907, 5.145524538332417, 34.485666828770796, 48.605818979201786, 47.22803938773371, 33.5954809957935, 39.768950400813935, 37.83744588974984, 49.791343596673784, 26.830384808201945, 1.8444410086639467, 0.0366415947134937, 0.23040719450481478, 2.77426153421402, 10.962273497735302, 7.013495477937884, 1.6223599641553819, 19.14490249849135, 41.41131739462576, 53.46109744041197, 50.080155557201756, 53.19484695311516, 52.535092523021085, 53.57828217168009, 51.32662596241121, 46.69016084363384, 37.93128467375232, 35.56792328434606, 36.44063888057586, 41.06160279243223, 48.6205239449778, 48.6075448220776, 45.99765070023076, 48.742168411131836, 50.35738868098105, 45.93147247068344, 45.258538876810384, 43.407835191295995, 36.747062283177534, 35.886286381752264, 36.001788416216456, 34.51955218468943, 35.513818110189135, 36.133846775177986, 36.98402443239766, 34.91924954998878, 36.29547980523879, 38.42951590015043, 36.42677330201672, 36.145202036826845, 37.54910461364254, 40.904727597390455, 37.41985467172439, 35.19656112117153, 35.735490860477576, 34.28512780897079, 36.02934698904715, 35.35492289450861, 36.08112619769189, 35.45232319062756, 37.01737634597286, 37.33946569504277, 38.18945900086434, 41.13960696804909, 42.80353523069813, 46.09782803443171, 46.95081803106493, 46.29587634917229, 49.77664255326795, 49.97496151155042, 48.20316414679251, 40.24239617009317, 41.24502066643008, 52.1983648884681, 45.94573420862998, 47.08690466419343, 40.914710029479, 37.19063528122441, 37.05410542026643, 36.272620231874534, 35.417437630314986, 37.40636171833162, 36.90467488381171, 38.81831299874091, 36.3691105381135, 37.30473310716691, 36.36744353079027, 37.467782112859915, 37.17546747576806, 38.46876313609462, 37.127194866057366, 38.170564943744296, 37.52995952483147, 37.95703503393358, 35.02819338152486, 38.109611311266505, 36.587076648589104, 37.413284701685754, 35.86790615512479, 43.095861634900494, 49.66870677086615, 51.327500650959635, 50.38610827538275, 49.00197444423553, 45.22864257135699, 46.3182887723369, 44.57317529186126, 44.12007485666583, 44.211081689403905, 44.46032477963356, 44.88390937928231, 50.24225927168324, 49.39536071592762, 53.998403318466686, 55.62292745036464, 49.99497736653974, 39.18749040172946, 37.93276732967746, 40.42943439176006, 46.36585535541658, 52.89633497115105, 54.65338814643122, 55.18962321742889, 59.63453546647103, 54.050876786631925, 50.06033974309122, 26.672362319884765, 15.88440973912516, 12.47293318471601, 6.417255007451581, 4.857429881249705, 0.9699958923362917, 0.004298718525998054, 0.18653078034760492, 4.121506454483155, 36.253510444395005, 53.02105457552018, 39.38280090208977, 35.29173743340277, 41.87197231477307, 49.56116322548159, 41.117645617454286, 8.72737169265747, 0.5457530086559634, 0.0772590478581767, 0.09855279113135992, 0.029259567644687432, 0.029191531376132084, 0.03263429986433156, 0.03412082453348464, 0.008976274233822142, 0.07260794420876811, 0.03308100956341913, 0.06276275677185866, 0.026711844576282368, 0.022090062942175616, 0.05339129895512616, 0.03357369602928239, 0.09286218277749517, 0.034746025058050314, 0.027581838920952815, 0.008758596095797277, 0.062093322330545035, 0.04008457004543274, 0.021853847391602975, 0.01970501481405189, 0.020873852397104906, 0.0133344842751901, 0.00850998045456025, 0.06297420853027894, 0.023259890693870765, 0.057158348631233945, 0.008441266198191912, 0.05183294205175293, 0.04996093343042078, 0.13709698052656266, 0.14653601112865633, 8.823074583084352, 42.806261277967884, 55.90548323046777, 52.6127476076926, 31.951450917028616, 36.546142793470814, 40.10316379608647, 52.92302277780349, 29.91388551650509, 1.797740166225741, 0.07363004339558464, 0.319741657304187, 4.806513594042871, 5.450112761989717, 5.481915339346855, 5.179308893219118, 22.342791288129746, 42.55661810598066, 53.594191305099, 50.78576641698038, 54.39817913116948, 53.628492432255904, 55.19380838640275, 52.73069327877414, 48.72982078982938, 39.5573934431999, 37.76404265434512, 38.859144872234715, 43.59621094119164, 51.76100492477418, 52.09865039394748, 47.633992933457904, 49.75578731106174, 52.224346668489524, 47.718994617462165, 46.89486149818667, 44.188492759581536, 38.71990857585784, 38.54851668880832, 36.6988524313896, 36.863572366776005, 37.51576838954803, 37.481757517783876, 38.393583067001835, 36.98043154131982, 37.30222279025663, 39.61445608446675, 37.98551928612494, 38.87101396437615, 38.917925511637044, 42.82363345546108, 40.74572255534511, 37.557098404053725, 37.33637878971715, 37.66489298112931, 37.84200760626024, 37.1754047178453, 38.07698503617318, 38.2248427021888, 38.849695882489605, 40.521013890543294, 40.88451562389251, 42.27523119218888, 45.09862776725523, 48.12179065519764, 50.34409969083725, 48.84449912655739, 52.69633723843483, 50.93539307194372, 49.11494654993857, 43.29908747826853, 44.05079010994204, 55.183998538601784, 48.200175300721206, 50.02191620488321, 42.463187248476096, 39.1403042885565, 37.414677143096924, 38.08972489449286, 38.4452602940221, 39.59898233413696, 37.87661075592041, 41.28098095616987, 37.92816246709516, 41.172935347403254, 39.0846223215903, 39.19717473368491, 39.34630324763637, 38.792056652807425, 40.17468429380848, 39.579401862236764, 39.21044018960769, 38.633388934596894, 37.85868552423293, 39.621010365024695, 38.79133101432554, 38.89163386437201, 38.79435123935823, 44.740825237766394, 51.605314285524436, 52.917806025474306, 53.378625685168856, 51.0826623824335, 49.572090948781664, 48.88586444239463, 46.503797269636586, 45.71013312185965, 45.606951252106704, 46.46803702077558, 47.232557958172215, 52.559387683868415, 53.064639952874955, 55.503958040668124, 56.35286484995196, 51.05703753809775, 40.77963536785495, 39.525896810716205, 43.85145918015511, 48.9846218785932, 55.45789372536444, 56.4188704952117, 59.18116438773371, 60.06719643069852, 55.84778124286283, 48.62375205562961, 32.57500775398747, 16.336071645059896, 8.702751955678387, 6.3483659298189234, 8.468221675965095, 0.941123754507111, 0.14274326303312856, 0.07977405322655555, 4.14280443422256, 41.08128916832709, 58.79274383667977, 43.91552717454972, 41.49563266384987, 49.74010567511282, 58.08817240499682, 51.06459594541981, 14.46000885578894, 0.6123713403940201, 0.04656535595835698, 0.06380295478588631, 0.04994920079386042, 0.04045648275003318, 0.006458051296161308, 0.07832015624209758, 0.07541092202788399, 0.1563830601592218, 0.03982124264321981, 0.05133866212300716, 0.07453987239709786, 0.04870449177800648, 0.04599437147619263, 0.04492157642098685, 0.015713327091127154, 0.1777614025218833, 0.14904550066398037, 0.1380483544762096, 0.13043028422661368, 0.13254479414993717, 0.20127654796646488, 0.22425523268118983, 0.11125332615788906, 0.1099389031409256, 0.14658376904985598, 0.1575123044031282, 0.21709148321420918, 0.10073059523898749, 0.05747195821435702, 0.20643457199536985, 0.13196175527428428, 0.26137035400156056, 0.23149415069530088, 10.873411220888938, 48.514188489606305, 61.975264779983036, 59.45571461031514, 43.505635569172526, 52.09686963788925, 47.73152659016271, 60.809610889803984, 33.48294819554975, 2.6565431154543355, 0.18485372195080405, 0.9899000823497773, 8.196813271891687, 27.03988644384569, 17.69869912055231, 4.156494977012757, 22.983708535471273, 45.187547899061634, 54.24254732747232, 51.84932493394422, 55.37180946719263, 53.79543635153002, 58.0534476618613, 56.083319571710405, 50.8851122087048, 42.5069099087869, 39.83311645446285, 41.24140031876103, 45.19882471330705, 53.01348047871744, 53.58963351095877, 48.74547496918709, 50.84931273614207, 53.56030987155054, 49.82253428428404, 49.465245585287775, 47.72818865314607, 40.32878637313843, 39.7231214277206, 38.515349126631214, 39.078052351551676, 38.99016772547076, 40.31845877247472, 40.3417262723369, 37.539169249996064, 40.86216203628048, 42.96288544131864, 38.633530139923096, 39.920467638200336, 41.13839887803601, 45.449052318449944, 42.12869144255116, 38.86988824413669, 38.82406319341352, 40.462092045814764, 40.33684292147237, 38.45628607657648, 39.49678890166744, 39.92176594272737, 41.666969637716974, 42.28205219391854, 43.613979278072236, 44.39875141266854, 48.03869524309712, 52.32018586127989, 52.26874789884014, 51.10600048495878, 55.11187007350307, 54.64329196560768, 49.55169854625579, 44.009730738978234, 48.70893024629163, 57.36658180913618, 51.57231930763491, 52.403751957801084, 46.5318775177002, 41.437769859067856, 40.70793051873484, 40.4762125784351, 39.42969283749981, 41.984524726867676, 38.763639080908995, 43.85807229626564, 38.89522283307968, 42.80172309567852, 40.98948217207386, 41.57988909752139, 39.65766099191482, 41.5221792651761, 43.28183689425069, 41.148098899472146, 41.30500939584548, 42.197446669301684, 39.74918949988581, 41.571322641065045, 41.96497563392886, 40.89990700444868, 39.428771080509314, 47.23406414831839, 55.11611407802951, 55.662072704684356, 54.55552108826176, 52.62313404390889, 50.54833358333957, 52.89452675850161, 47.89186523806664, 48.14483850233017, 49.222392036068825, 50.3759140353049, 49.13140873755179, 56.41225737910117, 53.50179203094975, 57.48426468141618, 58.883636920682854, 53.96452580728839, 42.667593725266, 42.47648408336025, 46.388624714266875, 52.25392918432913, 58.19193086316509, 60.599293401164395, 61.47334260325278, 63.60727671653994, 53.85689596976004, 53.05234724475492, 31.660305146248113, 20.464030888772783, 20.67484651842425, 14.068160153204396, 15.314623694266043, 4.408299865261201, 0.8142070712581758, 0.2551910275172803, 5.927736345798739, 47.46352672576905, 65.78316450119019, 49.93777351994669, 46.015179772530836, 53.874570169756495, 66.10510087782338, 59.73948240280152, 22.146172677316976, 0.8045291131542576, 0.21244880653196768, 0.10962591025858157, 0.19566204278699814, 0.13686693964465974, 0.10889076462556278, 0.11483022898075082, 0.1424815214329189, 0.27180407316453997, 0.11228610461037006, 0.14123575521572945, 0.1543594695507519, 0.15253884627694084, 0.13944433521359198, 0.15072318725287914, 0.11577070149923525], [0.039708171896035635, 0.036019443218866666, 0.04269323732343413, 0.10101994664798822, 0.04598452724636563, 0.03185350688234453, 0.08717155144099267, 0.08196007745761065, 0.06339894299725853, 0.015284030570558485, 0.019537886987710675, 0.021092005509642825, 0.029947675479155396, 0.007438844937320439, 0.03962154650399762, 0.0758695941899092, 0.03977614304711742, 0.023145203501166358, 5.338717449095942, 32.217711210250854, 48.666725543237504, 56.81328050551876, 42.216470164637414, 34.34073525090372, 45.137392551668235, 49.50064105372275, 37.61523185237762, 4.1992390059655715, 0.02379927404915854, 0.24618512770581633, 5.843953048029254, 6.3703228677472765, 4.2497302063049816, 6.72863922772869, 17.57378339767456, 36.81514286225842, 51.742679611329116, 53.94986398758427, 51.05765335021481, 54.929173915616936, 52.189653304315385, 52.11653247956307, 44.644036831394324, 36.56386798427951, 36.770486677846606, 36.55678418374831, 41.56829849366219, 48.95114052680231, 47.38920173337383, 49.2498407825347, 44.7710314104634, 47.10038192810551, 49.446939883693574, 48.090788241355654, 44.715239617132376, 36.35973607340167, 34.3255635230772, 34.42928275754375, 33.85114500599523, 34.84530894987045, 33.729347567404474, 37.12205263876146, 35.05933700069305, 35.344732576800936, 35.86756883128997, 38.232412876621375, 37.23684472422446, 35.824061901338645, 34.85840966624599, 37.19872713088989, 36.85291136464765, 34.80282183616392, 34.84064917410574, 35.69835385968609, 35.98429072287775, 35.84910623488888, 35.054402659016276, 36.30510530164165, 36.74038248677408, 40.913105780078524, 43.03282914623138, 45.65416482187087, 46.99710592146843, 47.93368162647371, 48.33301028897686, 51.802178044472974, 48.327150267939416, 47.39872132578204, 41.31896911128875, 41.06324626553444, 54.731427623379616, 48.904656517890196, 48.660253632453184, 48.110003932829834, 46.352436927057084, 44.09174357691119, 42.35907969936248, 37.08446848777033, 36.45402985234415, 36.37957542173324, 37.148783591485795, 36.97796829285161, 37.07107359363187, 36.7368798102102, 36.733847818067, 38.876689634015484, 38.58085663087907, 38.75944998956496, 37.36921687279978, 38.32594571575042, 37.22586208774198, 36.956528617489724, 36.40230947925199, 37.566068864637806, 34.93275034812189, 37.343595950834214, 36.67939747533491, 44.09252020620531, 45.23441237788047, 47.09332558416551, 44.943533328271684, 43.053821671393614, 40.63709643579299, 40.83869841790969, 35.856299861784905, 39.74193311506702, 39.444797885033395, 47.12493988775438, 46.21527164213119, 52.66943762379309, 50.32602933145339, 54.244022138657115, 53.133277508520315, 46.56782604032948, 40.422656536102295, 40.80566421631844, 40.178963599666474, 45.28650929850917, 50.62105432633431, 53.846203588670306, 58.00985051739601, 60.32902640681113, 46.301983479530584, 32.271453565166844, 13.145106819368179, 9.690078227750718, 7.527197022591868, 3.081894007421309, 1.4440393327705323, 0.09916782183873077, 0.051373837050050504, 7.673583309496603, 37.808388971513324, 48.84360090378792, 36.08306384855701, 22.000854745987926, 35.57173582815355, 52.194022824687345, 40.733170970793694, 5.974987668375816, 1.009770012911289, 0.1318982925506369, 0.04270471715097947, 0.013367473936429428, 0.0453771420964791, 0.0579229120405451, 0.021529188905391964, 0.056249894757544806, 0.013933474059036423, 0.026426371487398303, 0.05470898550664706, 0.013833570448050817, 0.05355186715361573, 0.04863509953382516, 0.0516140362578294, 0.051578351882316416, 0.04626754310823256, 0.043431619677933, 0.047512466628705306, 0.006853140075691045, 0.09460235149749825, 0.027375912571686412, 0.06598504515545023, 0.07260760713008142, 0.04364150861698774, 0.029683315773464503, 0.057325761825326955, 0.030145036965428345, 0.017531514205338977, 0.028866656470082463, 0.02036103888625099, 0.028728643815303524, 0.03498560756505017, 0.0479145631975224, 6.099511644532604, 39.904923285207445, 55.14029156777167, 59.94095494670253, 47.724168223719445, 40.6955397513605, 46.993983714811264, 54.51919209572577, 38.88083557928763, 4.208885585108112, 0.1526135398495582, 0.30992497599894003, 4.2205428692602345, 6.915103802757879, 5.79478858940063, 7.779346589119204, 20.47920653896947, 36.57909854765862, 53.24386089078842, 53.898551540990034, 52.01389974163425, 55.56345255144181, 54.26309662480509, 53.91059713978922, 46.566872904377604, 37.0332109543585, 38.27695138992802, 39.16648610945671, 42.857922815507465, 50.91500066941785, 50.4949854266259, 50.95238870190036, 45.151407180293916, 47.910241542323945, 51.937170336323405, 48.57201207068659, 46.303050364217455, 39.81096683009979, 35.854032731825306, 36.58702565777686, 36.63033646921958, 36.85286037383541, 35.81914717151273, 38.168235055861935, 35.80970602650797, 37.841085849269746, 38.405416857811716, 38.920275011370265, 37.822438901470555, 37.61201550883632, 37.073940846227835, 39.86503670292516, 38.049387239640765, 37.19015282969321, 37.30226201395835, 36.887561582749896, 36.884357006319114, 38.84840150033274, 38.00870049384333, 37.58266441283688, 39.07418489456177, 43.03845382505848, 44.42338781972086, 46.43950177777199, 48.143650024167954, 49.75280630973078, 50.31503885023056, 53.5598744884614, 49.39700811139999, 47.77753599228398, 44.01783435575424, 43.741236655942856, 55.01640742824924, 50.73485405214372, 51.63862305302774, 50.95653072480233, 47.30090525842483, 44.992433517209946, 43.45824157038043, 38.611404049781065, 38.08488076733005, 40.2164496914033, 36.703739704624304, 39.37893344509987, 39.84958256444624, 39.53427499340427, 39.600955286333644, 40.46168804168701, 41.77454063969274, 40.28258869724889, 39.919365452181914, 39.77000551839029, 39.456259050676906, 39.26916199345743, 37.44537753443564, 39.9264649421938, 37.24572889266476, 39.48192704108454, 39.249244197722405, 46.84039938834406, 47.70356401320427, 48.38784894635601, 47.28840074231548, 45.33721770009687, 43.830482344473566, 43.0138409522272, 39.580468746923636, 40.889853969697036, 43.57838769112864, 49.35448569636191, 49.65642190748646, 55.6117408506332, 49.756132479636904, 56.876846436531316, 54.76817630952405, 48.99081137872512, 41.37416862672375, 43.76024838416807, 42.895561879681004, 50.03817442924746, 54.012916088104255, 55.85610058999831, 61.4905696530496, 60.82684186197097, 47.65915886048348, 32.55789641411074, 14.176742146092078, 5.827923301727542, 9.776527266348563, 5.749368523397754, 1.8337315897787771, 0.07137892467360343, 0.054908363719380675, 6.729815448484113, 41.83680434380808, 56.372559070587165, 35.209351970303445, 25.557895360454438, 41.56116762468892, 56.97564309643161, 52.10075670673002, 13.70680199515435, 1.672148937659879, 0.15371917326363826, 0.03672285749006175, 0.023636438230413104, 0.047335029174123085, 0.033048680653014494, 0.06136423645300731, 0.025751036253847906, 0.09708516585129885, 0.10172484712975641, 0.03077461759770109, 0.028011823005433527, 0.022785915925558058, 0.05451361010331781, 0.0576117501083401, 0.037120625662106665, 0.13907420749385513, 0.09775334773885627, 0.1848724911049489, 0.29704173666334927, 0.2573160941322004, 0.12510127703388854, 0.17345148379043226, 0.14601197634493152, 0.27924005963629295, 0.10833748826576818, 0.18251275643706324, 0.1704834599889094, 0.10882901027798654, 0.13687332881794823, 0.15225649691156803, 0.17496573318156505, 0.1332522610262517, 0.11140509583656827, 7.9801332085363335, 44.73541628929877, 61.52375682707756, 67.92764586787071, 53.45353903308992, 46.079306602478034, 56.811099667702955, 60.500449672822036, 45.54475422828428, 5.6563436312060205, 0.3897275583397958, 0.8030583469137069, 11.726561054106682, 13.071906566619875, 13.625579514811117, 12.06292881119636, 21.186325550079346, 39.56948218807098, 50.604121454300426, 57.29135074923116, 51.92448146881596, 57.84991979599, 56.56894822274485, 55.86156052927817, 49.077554595085886, 39.75089965328094, 40.60104593153923, 41.21753269626249, 46.4350224310352, 54.05931772724275, 51.27978501781341, 48.906299990992395, 45.80146551132203, 48.96086016008931, 53.082361221313484, 51.002622496697214, 49.49151369833177, 41.39717725015456, 37.31455864444856, 37.642445256633145, 36.63507469238774, 38.69194207652923, 36.49400272677022, 41.48045701365317, 37.41617548850275, 39.12054730999855, 39.30185102647351, 42.40397514835481, 42.13709315946026, 39.58247307808169, 38.320732885791415, 42.974468200437485, 41.375729730052335, 39.0282186385124, 39.28526332301479, 39.37517189210461, 38.52599051690871, 40.60308948639901, 39.277336212896536, 38.00584893072806, 42.15951734973539, 46.07643150514173, 47.328683483985166, 49.45966405253257, 51.293128921139626, 53.093359547276656, 52.589131016885084, 56.15922135691489, 53.23017181888704, 48.66402303018878, 45.76652503782704, 47.02992831507037, 57.18925929838612, 54.92125072786885, 52.40101414342081, 53.78139034394295, 49.70134873544016, 48.87628993680401, 47.563092170223115, 41.21968999985726, 39.65350720190233, 42.20205153188398, 40.04418311580535, 40.884739198992335, 41.64383549844065, 41.19900734193864, 39.77168429282404, 43.14740942370507, 44.58513852088682, 42.75364660447644, 42.45680162983556, 42.45990030227169, 40.99318096714635, 39.81352813782231, 41.23052750864337, 42.04185016693608, 39.59613077102169, 41.83037165672549, 41.973667606230705, 48.37153580880935, 50.09676287251134, 51.62616560536047, 49.114687673507206, 46.96826473359139, 44.04779341913039, 44.71453359050136, 41.45526363003639, 44.26503781349429, 45.502388708053104, 51.63373970216321, 51.90390471489199, 56.29593949164114, 50.29698418032739, 56.87284954132573, 57.78956628614857, 51.37680484402565, 45.72367706606465, 46.39436314182897, 45.351848140839614, 51.45744485239829, 56.027888636435236, 58.91986785396453, 63.501125612566554, 61.899108040717344, 51.78543344620736, 37.56459797582319, 18.939760577294138, 19.058539752037294, 16.455860830122425, 9.499931527722268, 4.433089244750239, 0.5048338317823026, 0.13122257235790455, 9.624981591778418, 47.42630343283377, 61.509989307772734, 48.406770460067264, 33.22767249999508, 47.2549468471158, 67.4813429001839, 60.15033106650076, 24.338204937596476, 1.976984638360239, 0.2990826561806664, 0.10867785346964676, 0.17234771963088744, 0.11730539777706708, 0.18790454453518315, 0.15655501625470578, 0.13406501902687934, 0.1499576355901457, 0.17424470654899077, 0.1182707068660567, 0.10096793693880882, 0.15301709964631066, 0.18363622437802055, 0.16722154953787405, 0.09878670841815973], [0.06651856410767763, 0.03181560085185113, 0.03970705723810581, 0.03612892101368597, 0.057513710006230304, 0.029323966910822258, 0.015826852703016373, 0.053117303778567625, 0.09884521455293703, 0.05268969265143237, 0.0413203694587273, 0.1431631405026682, 0.03157622710381064, 0.04672283299207207, 0.07223256878674993, 0.05129100379323767, 0.05353679820414513, 0.014911382421550733, 2.2295904255682424, 21.279675998995383, 46.53294832475724, 53.68561783144551, 28.29248163007921, 20.29150543674346, 32.25353813940479, 46.26287744891259, 40.453764853938935, 6.3593554304492095, 0.12129666223641365, 0.6488214361090815, 33.708810037182225, 10.033620980478103, 1.3525692926299189, 5.438417234728414, 12.433289789384412, 33.73932607712285, 48.151777175164995, 54.31812747832268, 50.62252521514893, 52.07808540713403, 50.63525722872827, 51.611060557826875, 43.239287022621404, 35.8319733219762, 36.798209990224535, 39.70742017992082, 45.980521709688254, 50.99428353771087, 50.615053099970666, 49.17483722009967, 49.89453723353725, 50.808167073034475, 51.00828639922604, 49.13750410079957, 44.23365885211576, 37.53682367263302, 34.54231369879938, 34.968400770618075, 33.64501268632951, 35.38847092659243, 34.165856376771, 35.877515962046964, 36.80879254494944, 36.63618080077633, 36.5114611964072, 35.21943638401647, 34.6856253377853, 37.71132599922919, 37.17676970266527, 36.21190586397725, 34.42275985594719, 36.907122442799235, 34.50737322530439, 35.72865416926723, 35.247697061108006, 35.81269487257927, 36.44634592917658, 35.941583956441576, 35.89367220478673, 39.88391114819435, 44.46964825353315, 47.41098657731087, 50.494836376559356, 50.42751281492172, 47.96696293738581, 48.22296427142236, 46.19906833094936, 48.29729318618775, 41.73158676393571, 40.38438204796084, 49.7958896237035, 50.299600401232325, 51.40483410127702, 50.31271288471837, 50.34198553331437, 50.30795112732918, 47.84003111623949, 45.71245124263149, 38.089254210072184, 40.721168518066406, 44.40320330281412, 37.893520093733265, 37.42252580581173, 36.72262983937418, 38.21371493800994, 36.59463897828133, 37.744207228383715, 38.14544216279061, 38.26635314572243, 37.77837891732493, 38.74354477851622, 37.89302587509155, 37.69500109457201, 36.19092118355536, 36.19072114267657, 35.113202910269464, 35.01606933532223, 38.14221012976862, 39.79483804395122, 39.474356866651966, 38.25476254186323, 38.967410133730986, 36.607308233937914, 37.448244787031605, 36.900328897660785, 37.52537427410003, 37.35567292859478, 44.297919042648815, 48.06810517464915, 51.61902296927668, 52.35840935860911, 48.60834106322258, 57.116566011982584, 52.63903533258746, 45.88741640890799, 37.7728287635311, 39.37046504789783, 41.39090538024902, 45.957881789053644, 55.59909512919765, 57.40862961738341, 60.72808834814257, 46.3094477499685, 30.608921666299146, 13.14007539902964, 3.0651820138577492, 4.789672897708032, 6.207931349354406, 0.35461112977035586, 0.0914357960103981, 0.21277676877235213, 7.459792071773161, 41.96231234458185, 47.08758323423324, 37.17859752716557, 32.84252712803502, 47.012928762743556, 61.33971137385215, 36.50904893875122, 12.890283176975867, 0.6628402322530746, 0.09781808216845798, 0.08946021613214286, 0.04415328216348444, 0.015373875447098288, 0.02410433983670608, 0.05702124570586509, 0.06785312757617043, 0.06967761193311985, 0.03076254596723424, 0.037392123392032045, 0.01094675771216111, 0.009271087849722996, 0.025966835561238473, 0.041155890381384286, 0.06252984306023968, 0.0495608248597672, 0.05388352576823485, 0.024925342858618787, 0.009695374155266872, 0.0881862425575814, 0.041169660811823224, 0.025189348248644702, 0.03837694091001346, 0.07105038786727576, 0.024288618456452124, 0.037411168337829655, 0.10008106759238629, 0.07884311084184917, 0.047343605528435403, 0.01591337850362423, 0.003229503495423424, 0.03916651325961275, 0.07400533454793115, 3.2003348777371072, 29.154561719586773, 54.14675912549419, 58.58340694058327, 34.233776138674834, 27.461272555012858, 44.01134283311906, 53.81837044992755, 44.28843867394232, 7.282402390433896, 0.308718724596885, 0.632646745972095, 30.666100017486084, 11.9409970314272, 3.9083003853597953, 4.2867544389540155, 14.455903114811068, 36.36097946474629, 49.757340569649976, 56.421855418912834, 52.734749009532315, 52.902116544785045, 52.62888031621134, 52.53706547521776, 44.15694121391543, 37.761375442627944, 37.840454347672, 40.69427674816501, 46.703379231114546, 52.776090791148526, 52.64553862233316, 49.51191394559799, 49.57325589272284, 50.70746806360061, 52.37444400787354, 51.469215885285415, 47.17027464220601, 38.31786955556562, 35.62088704878284, 37.265344665896514, 36.97621891575475, 36.8190848442816, 35.993237649240804, 37.62780304877989, 38.39162972665603, 37.40682455801195, 38.714578074793664, 37.49060638489262, 37.38490635348905, 39.037851979655606, 38.85906642483127, 38.2104201470652, 36.16149164015247, 36.818943638955396, 35.75762479535995, 37.380925147764145, 36.39426862039874, 37.46039236745527, 37.27063202088879, 37.74978483876875, 38.13113727877217, 43.15006094594156, 45.13414090679538, 50.486030655522505, 51.68665639815792, 52.99832444037161, 49.54975697302049, 50.10725913509246, 47.23377781529581, 50.10259543695758, 43.77218023423226, 42.45020420320573, 51.84931708920387, 53.34786253590738, 52.79338844360844, 54.083793317118, 52.733285965458045, 51.7593575293018, 50.24083152894051, 45.92349436975295, 38.595498838732325, 42.92152404785157, 45.673400125195904, 38.351829436517534, 39.29031533579673, 39.823718455529985, 39.22222298960532, 38.510371638882546, 39.46524127837151, 40.3454093779287, 40.177555468774614, 38.53893041610718, 39.0334040118802, 39.046465504554014, 39.79922717617404, 37.10010305527718, 38.393226131316155, 37.77701785487514, 37.4822635035361, 40.72078020341935, 42.49344048961517, 43.59783480244298, 41.07379351892779, 40.632350367884484, 38.90192616370417, 38.771679939762244, 37.99603908292709, 39.765133934636275, 40.04763480155699, 46.95018652946719, 50.091848142685436, 54.46584786138227, 54.21335312627978, 50.83669447129773, 57.97057582486061, 56.6418101710658, 47.616911011357466, 41.14543561012515, 40.44642609934653, 42.40925073623657, 48.67027921061362, 57.530478046786406, 58.57992387587025, 62.422917043009114, 47.18696824965939, 32.54351700505903, 12.446530730493608, 2.8319154727843503, 5.175793468952179, 6.481918711816111, 1.2093508099356007, 0.2756566067616786, 0.0812427816732276, 9.759762075639541, 46.678366276525686, 55.99849831673407, 42.247703998319565, 36.576552929416785, 49.49041543468353, 68.81628236462994, 45.07747050254576, 17.46921104769553, 0.8813491007012706, 0.06884364095786888, 0.060049265683177984, 0.021665165681512128, 0.017967092646886746, 0.026679358617853255, 0.031183279540029266, 0.01771114458660445, 0.012219260397907949, 0.010302767923642552, 0.08021940311957752, 0.029910987528461604, 0.05607695423907811, 0.05543042965714009, 0.11290524154901506, 0.05074823049888496, 0.2561438263904664, 0.12272500252771763, 0.12160708872421135, 0.13820520331782682, 0.21777252005713604, 0.08885620176912316, 0.08537902827224425, 0.10738297335563168, 0.2513300669529746, 0.16251134986598648, 0.18269424266632528, 0.20875548132725302, 0.2089621871709824, 0.1882387120877543, 0.16275144182145596, 0.1170589013265506, 0.14612969341537646, 0.17985830774470685, 3.527051397869664, 33.53909300219628, 61.18437767028809, 64.97310876846313, 39.59864893267232, 31.11050848037966, 42.57129953753564, 57.14154758761006, 50.23200227368263, 8.508022946696128, 0.423402056218155, 1.1282955206209615, 39.84022378921509, 14.097147449370354, 4.767130055735189, 8.736681438261463, 14.571998407763822, 38.4525284459514, 50.651440928059245, 56.92959054823845, 53.525000695259344, 55.06494675913165, 54.589143645378854, 55.70827822531424, 46.47438733808456, 40.26922910444198, 40.76380075946931, 44.82670553268925, 50.016703374924205, 57.08966639734084, 52.321546923729684, 49.90570422141783, 50.1440627344193, 53.64280123864451, 55.179860438069994, 54.30208106194773, 49.75803482917048, 41.282451844984486, 37.13033276219522, 39.26388640557566, 38.463840561528365, 39.125642468852384, 37.87468487216581, 38.60693254778462, 40.76880962617936, 39.58474020804129, 41.20938593341459, 38.84643639287641, 38.841462827497914, 41.14185448615782, 41.856714294802764, 40.53085903967581, 37.669474309490575, 38.711922630187004, 38.09740881766043, 41.14756153475854, 38.28064234026017, 39.20337207855717, 39.435031183304325, 39.59832337594802, 40.388461312940045, 43.956064870280606, 47.66644270189347, 52.38697598057409, 55.071230396147705, 54.63607088212044, 51.891906184534875, 52.29414916807606, 48.495769039277114, 52.00866729982438, 47.95473298718853, 44.858315913907944, 55.772624707991085, 55.490480776756044, 54.2968721543589, 56.773264485020796, 55.945718903695386, 56.08082494428081, 53.524879101784, 50.28190658938501, 40.809312020578695, 43.92683929012668, 48.12602681498374, 41.14779295459871, 41.44566559022473, 41.58958519658735, 40.447845997348914, 40.95584784784625, 41.23881547681747, 42.760546053609545, 41.57742977142334, 41.7883042366274, 41.9245046184909, 40.52932931530861, 41.93575005377493, 39.670126284322436, 40.41263095794186, 38.86104722176829, 38.96761801935012, 42.423182995088645, 43.1925323701674, 45.23708743433799, 42.490910560854026, 43.31215681568269, 40.782212365058164, 40.66497664297781, 40.115687924046675, 41.978888280930065, 41.82422922503564, 48.109827426172075, 53.13742345379245, 57.669110298156745, 57.988218645895685, 52.142584862247595, 59.66522016832906, 60.01336582245366, 51.169064352589274, 43.68123223704677, 42.87816616796678, 45.89504934126332, 49.47853065306141, 61.688731716525176, 61.40104939860683, 65.45485819539716, 49.52429686823199, 39.30301989278486, 19.193771308468236, 9.662008766205082, 14.950986639145883, 10.57508849328564, 2.8693674889303025, 0.516143771669557, 0.5560766869494992, 10.80224765885261, 54.512123984675256, 59.81498410624843, 50.79281491618003, 45.23604800624233, 60.284142724929325, 77.75114351703276, 53.91524907081358, 25.253890099063998, 1.3327745612590545, 0.26852481848289894, 0.23590217464633528, 0.08778817561124602, 0.14215545909058663, 0.072085035574292, 0.18077402796235778, 0.21956862851737008, 0.16724914402490662, 0.08527963602494809, 0.195013273567442, 0.16041795332585612, 0.20412268717923474, 0.21532120723878184, 0.15375536325718128, 0.22249932851522203], [0.071357014558969, 0.045226697749908895, 0.06899741012603045, 0.04000866222345541, 0.036477816606601404, 0.06594537712273098, 0.020792708364165118, 0.09336341112371414, 0.07203258919499575, 0.02095604214006134, 0.03867520575201319, 0.016541322580568733, 0.01057396496405765, 0.032140337862074375, 0.034723624647144354, 0.08258909693047886, 0.025918738646132332, 0.03993311063236287, 0.5095327393181863, 15.463037356253594, 45.00236103611608, 53.748956264988074, 35.32196714032081, 23.236471952930575, 36.444714223184896, 48.43615293502808, 40.50936837350169, 11.628034057155734, 0.14577804373637324, 3.2248793542385106, 25.334141792789584, 32.52301477616833, 6.778677394313197, 2.5981816793641737, 12.045609585700497, 22.71593224617743, 47.23019669132848, 51.726068373649355, 55.59095228871992, 51.27594893978488, 52.818005238809896, 47.31056997852941, 41.11619434049053, 34.905415350391024, 41.66074875862368, 47.2586299527076, 51.5638195314715, 51.49171067822365, 50.4659128189087, 50.056389916327696, 50.46689341145177, 49.29171208412417, 46.0260800392397, 46.33213473904518, 37.969535627672755, 34.65536425190587, 35.460960249747004, 34.07599487612325, 35.8896674648408, 36.24806619459583, 36.50872338202692, 34.30654002774146, 35.49795996758246, 36.361618811084384, 36.8732213973999, 37.405098715136134, 38.03250143604894, 39.29225298666185, 38.15750345107048, 36.148265407931426, 36.19393748621787, 35.01821879417666, 36.289255003775324, 35.09081402132588, 36.29295772121799, 37.56131102961879, 35.76979198763448, 35.3612575223369, 36.079612162805375, 39.73153883411039, 42.897985904447495, 45.71191387791788, 47.97403104843632, 48.66971046693864, 49.677386976057484, 49.68891089962375, 52.03757516799435, 43.3111919126203, 39.49149762430499, 40.40762993597215, 54.02487147238947, 49.11522503822081, 51.36047209462812, 51.48022205598893, 49.63802206900812, 50.11234644920596, 49.769142981498476, 50.103705467716345, 41.820914822240034, 40.17813597956012, 42.464210987091064, 38.42875888270717, 37.44595804522115, 35.146723485762074, 35.73607137126308, 37.056129363275346, 38.71501738025297, 40.03034891620759, 39.717837995098485, 36.95513225370838, 38.889951167568086, 37.89577545658235, 38.745113726585146, 37.206936651660556, 36.32374832707067, 37.24010813620783, 35.52109802922895, 37.04065953531573, 36.09511729209654, 36.67719702566824, 37.1601035518031, 37.53070477516421, 36.22558316876812, 35.84524662263932, 38.46307177697459, 36.57199513527655, 38.17699763082689, 42.32845383305704, 49.21532392501832, 49.50530082948747, 51.3401149934338, 50.17811675225535, 53.98669896587249, 55.41496730619862, 53.30846232752646, 45.24444580078126, 38.48406430213682, 39.0000795548962, 44.233368596723004, 52.212665850116366, 55.9966234237917, 60.2839897524926, 50.5304358082433, 30.49502192005035, 10.744865344416711, 3.0504782738224154, 5.285831641766333, 6.279167965535195, 0.9759520727299875, 0.09182655447793585, 0.24592975995713667, 8.904115653807118, 42.411651226782034, 45.539525708844586, 30.83040418163423, 26.3991908104189, 46.23186719033026, 56.51972639945246, 41.81109712969872, 11.235058653739191, 0.09660116682249693, 0.030080256570551186, 0.026392916427744974, 0.048805864362586895, 0.017419113785088543, 0.03461905364548007, 0.029022296807999094, 0.02920367195451212, 0.05569101446458409, 0.06431195509409712, 0.0216196658044693, 0.009849512960851915, 0.02495951804092094, 0.04651717668879898, 0.07473893268334289, 0.04181155439225897, 0.0370118526681777, 0.041126664127072984, 0.04748115278480034, 0.05392386412788784, 0.01893240556631598, 0.002502647891355258, 0.06849554592683431, 0.058128346178320155, 0.057846862492301775, 0.03460346758666058, 0.005789823922133374, 0.01379558206310556, 0.038018392609252084, 0.041940456346398404, 0.06456327789853658, 0.025896049037034956, 0.04920965015527703, 0.07318699942721475, 0.6294650296049734, 18.97529136750006, 51.67213970615018, 58.65052261660176, 38.8545282425419, 23.296896065435103, 37.713773558216715, 54.08250677970148, 44.30394772560366, 11.630854241309628, 0.2073960736273758, 2.32364543022648, 30.826958379437848, 26.83619776079732, 9.148139049929958, 3.1392302340076816, 10.602117546143072, 27.345129213025494, 47.08657518509896, 55.56295441042993, 55.134913998265425, 53.41638242044757, 52.57788950397123, 49.57122410497358, 42.919606008837306, 37.863423747401086, 41.87893059945876, 48.6514243771953, 52.52875005045245, 52.92562330922773, 50.15012279633553, 52.9361980192123, 53.111190642080004, 51.78961861518122, 47.21912384033204, 49.10461110453452, 40.63365651715187, 36.80383466905163, 38.03353301940426, 36.101863768792924, 37.84979351105229, 37.81380184235112, 37.79548829601657, 36.82538809314851, 37.22006482462729, 38.2431209471918, 38.788757939492505, 38.77632010367609, 40.03472235894973, 41.47257697197699, 39.82376552397206, 37.139283610928445, 37.692169143307595, 37.48932376984627, 36.784677813130045, 37.154914256065126, 38.40687597951582, 38.479600644880726, 38.47099888709284, 36.776244717259566, 39.67641384370866, 42.48843946764546, 44.61381104684646, 47.2021831235578, 50.389328541294226, 49.84843369453184, 50.39841275061331, 51.660372595633234, 51.81839312276533, 46.20716018061484, 42.375192796030355, 43.16907659653695, 53.38606642138574, 51.25710587347708, 52.60248668732182, 53.54231795957012, 52.463171943541504, 52.833906527488466, 51.25279126628753, 52.739722574910815, 42.905026558906805, 40.736924679048606, 43.920088891060125, 39.44554313536614, 38.12234724721601, 36.307686221215036, 37.918207491597826, 38.42983361213438, 39.97252141275714, 42.52176784699963, 42.89711513826924, 38.82538503216159, 41.006364053295506, 39.20367410106044, 41.213402440471036, 39.66212464917091, 38.28043837701121, 39.398768871061264, 38.64115522753808, 38.52400187523135, 38.21608012722385, 40.115762449079945, 39.15352659840738, 39.067909102286066, 37.90783282249205, 38.44420517644575, 38.82707557370586, 37.30528223899103, 39.49942865679341, 44.98308258671915, 52.10587147743472, 50.607922230997396, 54.4277028114565, 51.58755379338419, 55.710211953809186, 56.779242177163404, 56.028516215662805, 46.36959729656097, 41.09512729029502, 41.46181006585398, 46.978737461951475, 54.83464087209394, 58.197284898450306, 62.30147654010404, 54.37888891466203, 31.212374394939793, 13.320007266536837, 5.131959511387733, 5.479147126597743, 9.480074528724918, 1.5386442046973015, 0.08969280808683365, 0.1507645406790318, 10.371662609038815, 46.32099913012597, 51.51779051749937, 38.48290720293599, 31.95471432901198, 51.37163908250871, 63.92945235775363, 49.25927408279912, 15.559118755402105, 0.21979090126772083, 0.017778872504770275, 0.08547905637251754, 0.055856317086445714, 0.05635009905804069, 0.050484228939298666, 0.03290814948418448, 0.04768533436881919, 0.058748279848406394, 0.06276816152216447, 0.05902716649636146, 0.01938390906058973, 0.03343513370641778, 0.10067073312858421, 0.08330475328670395, 0.0242019375230396, 0.12682595545606268, 0.12263544684936925, 0.16732216752584905, 0.12247792385037869, 0.20161727323166787, 0.19060846718568958, 0.10868769769947376, 0.15551895894590886, 0.15035106770453915, 0.09343164657512981, 0.16073486857837246, 0.13954475401870667, 0.14359207313147285, 0.1659535361273635, 0.20430614991534143, 0.14641581193333672, 0.16915664166933106, 0.19253265022510485, 0.9652517243258416, 22.067521310621693, 57.42127533881896, 65.51461942734258, 45.16767717176869, 33.12251767804546, 46.15996622270154, 60.15481433560772, 49.56423444132651, 15.61250025226224, 0.34864097593292115, 3.5170329290051616, 30.65491145656955, 43.14860574660763, 16.082749289851037, 7.019152516318906, 15.704577892057358, 24.23698817529986, 49.87567847774875, 54.12751205505864, 58.84570760111655, 55.02935909455823, 54.80098693601547, 50.94888994770666, 45.773518623844275, 40.594162171886815, 45.33922203125493, 51.06859676299557, 56.58122916375437, 54.72758762298092, 51.52467427715179, 53.73587908283357, 53.99126852712324, 53.81079243075464, 50.444457454066125, 51.97710006467758, 41.70841340095767, 37.47326558636081, 40.51142369547198, 38.153008414853005, 39.90247964859009, 39.45150906039823, 39.571376692864206, 39.146568313721694, 38.59485164765389, 41.44039784708331, 40.75867029928392, 40.161724782759144, 43.49207593548683, 43.761170141158566, 41.96856068026635, 39.39448956520327, 39.06941137006206, 38.78667908330118, 39.59494229285948, 39.6456899181489, 40.75267691766062, 41.02687804929672, 38.88381265824841, 39.61548766782207, 41.136869153668805, 43.49703381138463, 46.33779471920383, 49.37572925321518, 52.034955024719245, 51.49015741963541, 52.79780503242247, 55.32253665308799, 54.96556174370551, 49.31758796015094, 43.326610749767674, 47.33808540528821, 57.80372212010046, 50.90319825756935, 54.25576179258285, 54.92677734744165, 54.06484826918572, 54.64442945295765, 54.13146188182216, 55.03934937138712, 45.76803907271355, 41.87640067069761, 45.593277869686005, 42.448607798545595, 40.18685540845318, 37.04465643052132, 39.46739465959611, 41.80183641372189, 42.71967887878419, 44.46228988708989, 44.68553550781743, 41.64313731654998, 43.53047201710363, 42.09117397185295, 43.36134333764353, 42.224330594462735, 40.445618091091035, 42.047545448426284, 40.26974685730473, 40.223388364238126, 40.30344786182527, 41.23480289213119, 40.66858522353634, 42.025599787312174, 38.65760564804077, 40.263004302978516, 41.92625007321758, 39.47333705040717, 42.062681874921246, 46.61682036615188, 54.45117427456764, 54.27049421495008, 56.04295053789693, 52.77900511218656, 54.4959089063829, 60.236862474872225, 58.57065531515307, 50.40713217950637, 43.184177721700365, 43.91269522328531, 50.001429665473204, 57.202265877877515, 62.35567192877493, 64.18663432521205, 56.273221123603086, 33.15981941838419, 15.319485472094629, 7.384662503196348, 13.341960772391289, 19.313680125821023, 2.7035534574139506, 0.49229897859115757, 0.5515755220286308, 11.793196239779073, 52.0039604556176, 58.36157729548793, 43.250799179077156, 38.156683675704464, 60.16631864732312, 72.63721219954952, 59.310759498227036, 18.47008812812067, 0.2556393421705692, 0.11598208047930272, 0.14398683823885458, 0.11794610775165981, 0.09295939933508636, 0.09988306450747675, 0.2670162687859228, 0.14862429020145249, 0.1415578645443724, 0.17096710661726613, 0.142276975957136, 0.1562773400256711, 0.12779068997910908, 0.3123850068978725, 0.23087645400195356, 0.14448516311184054], [0.054188225748798544, 0.08794599738452705, 0.02541661206182213, 0.06313750400177895, 0.02693478765356685, 0.07487216303425451, 0.057508960261099765, 0.029442080431768013, 0.08092660186511856, 0.07900984221768957, 0.020548975575835477, 0.017895903926522985, 0.01731361390181607, 0.035854960311084025, 0.01912868303817607, 0.043610688899793935, 0.019930936058142015, 0.05685727607699172, 0.1639855328586794, 10.30254162126972, 37.728749167534616, 51.727366678176395, 41.40484548384144, 28.873172844609908, 31.50261409821049, 51.55280159365747, 49.08985907031644, 17.587084154928885, 0.45803477687220423, 2.270857927299315, 20.54940519794341, 16.256481851300887, 5.4507771134376535, 1.3241354183804606, 3.9990282395193657, 19.67242402415122, 38.943687638928814, 52.905454481801684, 53.34051593657463, 51.310175541908514, 47.96113821767992, 45.14446850745909, 38.0240487283276, 41.94326139265492, 44.49523387416717, 50.841652347195534, 53.34569346520209, 53.52532232961347, 52.13667385039791, 49.08408534142279, 46.50961022223196, 45.519470630153535, 43.09451233956122, 38.87210830565422, 34.13321048982682, 34.50179169254918, 35.05423791946904, 41.37584347878733, 42.81686344454366, 43.858813624228205, 42.84569678768035, 37.618679615759085, 34.949381197652514, 34.926400030812914, 35.9484520266133, 41.10738861945368, 41.748582393892356, 43.43942596066383, 39.78296502943962, 36.426384987369666, 36.048519534449426, 35.910675679483724, 35.07718770734726, 34.32902697593936, 35.47163301898588, 36.37806923158708, 36.86230544121035, 36.79171454521918, 36.79067903949369, 39.20499593980851, 40.06321445588143, 44.35196145888298, 45.437634298878336, 47.61272976475377, 46.00299689077562, 50.06763142924155, 48.048516858008604, 45.30589757427093, 49.32125537626205, 40.11957107051727, 51.3466182831795, 43.08181170494326, 47.65198876780849, 46.07144617265271, 47.7411481641954, 49.59404053226594, 50.96952161481304, 47.49347794440485, 43.772117476309504, 35.57278310098956, 37.18677959134502, 36.62965789917977, 36.40147401440528, 37.94337734099358, 38.19298913401943, 37.49710575226815, 41.94454793007144, 44.39641368004584, 44.8055874916815, 40.67426873791603, 38.41712121040591, 38.09129776493196, 36.3800774851153, 37.138252027573124, 36.740394253884595, 35.44697307771252, 36.10485261486423, 36.12595888876146, 37.32487840037192, 36.75561305015318, 37.16802673955118, 35.56898624666276, 37.02711166874055, 36.18291954840384, 36.31590358672604, 37.987868785858154, 36.840497063052275, 40.2120566368103, 47.060981719724595, 47.27289169065414, 52.88702326436197, 54.774911019109915, 49.616158777667636, 54.494402716236735, 54.5859782926498, 49.395552912066066, 40.659732434057425, 41.15858731731292, 41.344868521536554, 49.887845670023275, 55.578922379401426, 56.51007344645839, 51.35489840661326, 30.750028933248213, 9.71393604432383, 1.5783890913571081, 1.5754408173022734, 3.6153954315570096, 0.8065403697471466, 0.18876631684120626, 0.18631086714806097, 11.612271032025738, 47.57537703360281, 51.02223826992897, 36.01444198239234, 34.41512692359186, 43.30346092101067, 57.80859370385447, 40.815477986489576, 6.535709115766711, 0.10794296830652222, 0.044258052348009044, 0.07431737748124907, 0.02078942759262939, 0.13666230223832593, 0.033796547176015955, 0.06803705762591093, 0.020471020383880507, 0.0659972642578425, 0.010424112420408957, 0.011796235264609418, 0.05324631298501646, 0.06619104619828925, 0.09233502235503928, 0.08184386958037654, 0.05114086205139757, 0.05845429743790339, 0.01407827329521458, 0.03322376238722955, 0.03936310291230198, 0.05203216704690168, 0.06854058423590276, 0.05917268872801816, 0.08115922446332632, 0.06290696516272522, 0.11751053314055167, 0.059570472221821553, 0.057216536839522665, 0.018302102896174597, 0.07076079897101849, 0.03876508318728978, 0.03242586266189333, 0.07750293960975063, 0.03452448775210688, 0.32663084085910554, 12.965698588278986, 44.93355089618314, 58.63224437159877, 45.32423857719668, 31.8507440628544, 37.63948386715305, 54.83680602042906, 53.5293702156313, 18.513749991693807, 0.4484151640245992, 2.697125428145932, 19.738417902300437, 21.19398593902588, 7.166375738959159, 3.4826283493349632, 7.302393240313377, 21.71518852633815, 41.21315140878001, 53.90647472873811, 54.343489523856874, 53.35738212831559, 51.68605235315139, 46.02167521753619, 40.38185604156987, 42.40538720161685, 46.39541433703515, 52.15072378035515, 54.943137553430375, 52.87361660311299, 53.33898621220743, 52.035366873587336, 50.250288363425966, 46.716448568528705, 45.59101858446675, 41.57145207928073, 36.22470848021969, 35.90681606723417, 36.33577431401899, 42.15107248675439, 43.915487950848, 45.42521999728295, 42.89810749792284, 39.11166706392842, 36.37574326607489, 37.24974147735104, 38.718123897429436, 41.235297110772905, 43.53454343734249, 46.02522888491231, 42.232438133608916, 39.88891217016405, 37.36523174470471, 38.19523272975799, 36.49401841625091, 35.91112675205354, 37.50034955240066, 37.83909720759238, 39.39209299702799, 39.512403857323434, 39.282953046983295, 40.939903413095784, 43.14327524554345, 46.604025594649784, 48.67001248944191, 48.67542928264987, 48.55043903473885, 50.42347669601441, 49.86320141823062, 46.00279684989683, 50.24628362348003, 43.302307744180005, 53.26400618399344, 43.75536111093337, 47.37651678823656, 47.210733890533454, 49.50214332149875, 50.5358761356723, 53.8233087139745, 49.88920673247307, 45.112791445947465, 38.02158547985939, 38.2895500429215, 37.78676886712351, 37.19396929587088, 38.81901118063158, 40.050011757881414, 39.54079789500083, 42.94578390736734, 46.62397476934618, 46.11905197943411, 41.85180348734702, 40.27445762388168, 39.305969515154445, 38.228047278619584, 38.784106008468136, 38.67888842859576, 36.00404770143571, 39.62241065117621, 37.62840317141625, 38.66938844803841, 37.978662983063735, 39.88804924872614, 37.59076410724271, 38.31544553079913, 38.955807762761275, 38.340274133989894, 38.93884743413618, 38.56558684379824, 41.66846013838246, 49.22582410996961, 51.22287534898328, 55.9687981297893, 54.822814926024414, 51.23061026296308, 56.79718309833158, 55.9009450481784, 53.747226499742084, 42.39630691466793, 41.88041717775407, 43.44050853483139, 53.11656821158625, 58.729491695281006, 59.3143484669347, 53.114610948870265, 31.286352257574762, 11.976069884915507, 4.960342578349575, 4.5293564661856625, 4.107843123136028, 1.4257407404722706, 0.07894700768614009, 0.21544814800783513, 13.029666562234203, 52.30331182479859, 54.110171256526826, 41.809524259259625, 37.41705409942135, 50.68431039010325, 63.83372299132809, 49.70987596819478, 9.7694307181143, 0.09403145511544521, 0.0461716020870353, 0.03420759931266789, 0.02524287289669437, 0.054666597861796624, 0.034796598352371685, 0.015136844012886288, 0.06015870900404069, 0.051684049033229394, 0.05834545549606124, 0.02947310890792118, 0.02056633512819967, 0.05460177150164401, 0.0194043961669048, 0.030746306818459305, 0.05684017699452178, 0.10964032037243729, 0.17226809245203772, 0.2667720399556622, 0.13047949771486944, 0.15545826946054736, 0.17931793996643636, 0.11007174278699583, 0.10784418126868625, 0.2094973915166432, 0.1891717305707355, 0.10154627969548588, 0.27043896577050613, 0.060858296666054, 0.22721414003641377, 0.0890975884131847, 0.1658751653327096, 0.1463973338926031, 0.19613410616593976, 0.4156521269150319, 14.712940935165653, 52.83848393347956, 64.78815724772792, 55.10386843835154, 40.386084356615626, 41.67463787140385, 60.11191145066292, 59.678603295357, 22.4275811641447, 0.8311756123458186, 2.789312158861468, 22.577037196005545, 20.889698266983032, 13.156438546796, 4.195511283413056, 5.997866853590935, 23.05608803226102, 42.036260789440526, 57.22814175390429, 55.94688777000674, 56.48738253501154, 52.13864288022442, 49.88495880557645, 42.7563295056743, 46.7757155818324, 48.30389453518776, 55.367820416727376, 56.81490044439993, 53.78140995579382, 56.50917522368893, 54.927844232128514, 53.374173795023275, 49.352787310077304, 48.05482010687552, 43.875554300123646, 37.66463410469794, 37.33742214018299, 38.599260391727576, 44.911526787665586, 47.54619459952078, 49.0832341870954, 46.6076930107609, 41.291881222878736, 37.71804894170454, 39.33267301128757, 40.125580141621256, 44.694541269733065, 46.378018625320934, 47.676993877657004, 44.6091708829326, 42.07449605388027, 39.909022162037516, 39.32243562513782, 38.30671825716573, 36.36134032280215, 39.96131127880466, 39.44780634295556, 41.17415912689702, 41.284146308898926, 41.04026509869484, 41.73397548737065, 43.788430613856164, 48.39014745527699, 49.67847739496539, 49.90294679518669, 51.48428955385762, 55.41844252617129, 51.75154809028872, 49.67600237938666, 51.24345602527742, 46.361328940237726, 53.21828703726492, 44.59373635630454, 47.44402862364247, 47.28084233499343, 51.57289589605024, 52.42591334927467, 54.4849145027899, 52.69973008863388, 47.436815384895574, 40.420299191628736, 40.8182942482733, 39.77790909428751, 40.018507280657374, 40.382377716802786, 41.379169648693455, 41.80019294061969, 45.82337587110458, 49.352555890237134, 49.38875544455744, 45.68477499869562, 42.40905854009813, 42.41745241226689, 39.29262168945805, 40.03524403418265, 40.92876388180641, 38.129529107001524, 41.95776631755214, 39.28291774565174, 39.817156330231704, 41.288386391055205, 41.54987904333299, 40.16597270965576, 40.43088566872382, 41.170260290945734, 39.465621748278224, 41.73436772438788, 41.31793360556326, 44.039128903419744, 51.887520974682225, 52.655889757217906, 58.80990812855383, 57.91376029291461, 52.102651211523245, 56.69667236266598, 58.36782563117243, 56.46980247189922, 44.86666664000481, 44.884823291532456, 45.65704384157735, 55.703543924516254, 63.17818903153943, 62.43925371477681, 55.594007815084154, 33.359538662818174, 12.82246147432635, 5.719544291496278, 8.836517526257424, 11.699184871489003, 2.462613534542822, 0.53539065824401, 0.5157288584497668, 14.904699729334924, 58.88109914718136, 64.02987680127545, 46.78162267131191, 47.11889943768902, 58.61714716880553, 72.01078614880963, 55.91151975816297, 12.660116534079275, 0.22018612602785712, 0.2668090573241634, 0.10505827954940258, 0.1508644232225995, 0.2860178540070211, 0.202238401998916, 0.24290429488305124, 0.15171200758026493, 0.19969848345123953, 0.07501719880007929, 0.16746481309735006, 0.10684993703879657, 0.17245337847740422, 0.14094485630912168, 0.16801455779181373, 0.14496960647163853], [0.06684369182274227, 0.022851236412421833, 0.015716019890181, 0.015717388314735747, 0.08234384154239971, 0.022474524166975773, 0.0982816419714401, 0.007732142177936171, 0.03931618768781905, 0.04816441511314723, 0.06176560140785672, 0.027342162568182237, 0.05852937405448287, 0.10373511546922308, 0.07006290053287823, 0.04605413782560537, 0.042399170643259446, 0.03565576212901262, 0.17708246475986897, 5.549346275867955, 34.72977553644488, 53.66180119975921, 47.87517947535361, 18.03685842021819, 26.91035213009004, 46.2951664001711, 49.327935172665505, 27.51668780080734, 2.1948247426940553, 0.16067283077826425, 4.774997840004583, 4.71025666882915, 6.60209228915553, 2.00488114789609, 1.7906660490459012, 10.97540363188713, 28.08259560215858, 49.56860396169847, 51.50239129220286, 50.62330184444305, 46.96738220030262, 46.98446804477323, 43.8372641225015, 45.83145203128938, 51.24454252181515, 53.306069681721354, 51.96858067666331, 50.894168961432676, 48.86371481803156, 46.20233174293272, 42.25149300790603, 38.72193644123693, 35.6750589032327, 35.04779346527592, 34.58843684965564, 33.930306280812914, 42.403998682575846, 50.02370480568179, 49.12914160759219, 48.31202953092514, 47.515113738275346, 44.91150325344455, 41.802730714121175, 43.287226230867454, 42.94781961748677, 46.88125871842908, 47.09666744355233, 50.46021361504832, 42.61317083912511, 38.96554700789913, 37.26900423726728, 36.76611323510447, 34.84743095213367, 36.72032740808303, 36.97210042707382, 37.369122735915646, 36.82528218915386, 36.81632741805046, 36.65582795296946, 34.636885966024096, 38.703822935781176, 41.05545643837222, 43.727296552350445, 42.190704114975475, 45.41623384721818, 46.71329106053999, 48.86921790338332, 51.20680147601713, 54.123597529626664, 39.73979150095294, 42.35196844224007, 43.943732938458844, 46.76423480433803, 50.41070938110352, 49.19293111370456, 51.244691571881695, 46.45273977710355, 48.532815825554636, 41.93679340424077, 37.45028441952121, 37.28772178772957, 36.32940046248898, 37.181892318110314, 38.08467680408109, 36.52193784713745, 40.01329052832819, 43.59054703866282, 49.05197289682204, 46.92602865157589, 44.27883278939032, 41.58608644239364, 37.79486463915917, 39.09182771559685, 40.85909082043556, 43.87955904006959, 42.138309094213675, 39.187396264845326, 37.72346181254233, 37.40118418970416, 37.6240611076355, 37.4124570815794, 35.88345443048785, 36.417261554348855, 37.15156847430814, 37.18068422809724, 37.86755008082236, 36.70494779463738, 37.54887711617255, 42.94690962760679, 48.12277124774072, 49.702717642630304, 53.8132909805544, 52.078814967986084, 54.12732770366054, 56.951904912148755, 53.615760418676565, 45.28227706109324, 39.10759956605973, 42.07322128357426, 48.22892627408428, 53.60933165396414, 57.64898069443242, 52.81115285811886, 27.083316887578658, 12.32069128944028, 7.184138192284492, 2.935209865531614, 3.674360912653708, 1.524213559685215, 0.06035304252779292, 0.5313444882631302, 13.944314256791147, 46.55540389399375, 41.99309118332402, 30.754516124725345, 34.342461093779534, 44.441705288425574, 54.86523928180818, 36.09543892645067, 7.131720617894204, 0.0291700579316145, 0.09802357759326698, 0.04193196043131813, 0.04502525493021935, 0.031094043703389265, 0.057533969201387904, 0.01834480272185418, 0.05200447679887857, 0.047897203645158204, 0.042206491869423664, 0.07410714763306803, 0.03191391866083347, 0.016654468021325527, 0.024660536906712, 0.09340648058681719, 0.024539832093362367, 0.05171894050774075, 0.03610089751741579, 0.07716468114766382, 0.01698168907164326, 0.06691475413859853, 0.016077948553908258, 0.017959906742156997, 0.1547076258688204, 0.11367005010646199, 0.019981942192140608, 0.10027739294474164, 0.07321570474173754, 0.04088968631901568, 0.06884541062097396, 0.06944404704676521, 0.06506224628537893, 0.05013358283547625, 0.01296663087897844, 0.08304572363774623, 7.7198751222702775, 39.58779573440552, 60.80850085904522, 53.86754128240771, 24.819750401281542, 28.924224453587687, 53.75764039254958, 55.99051629343341, 28.72472486188335, 1.8741299187944782, 0.41959787809079696, 6.439716460243349, 6.372092837287534, 5.24727572356501, 7.061182183604087, 4.561122761618707, 16.74047193219585, 30.30586365730532, 53.8180095918717, 51.27458395496492, 52.13959601617629, 48.73660256785732, 48.84585626663701, 45.64643775263141, 48.01216825362175, 52.918464983663256, 55.420219359859345, 53.86750205870598, 52.697074644027225, 51.25084969305223, 49.09063177724039, 46.078329932305124, 41.135104087091264, 38.04364096733832, 36.89812844799411, 36.97202590204055, 36.07822756613455, 43.672795218806115, 51.597861782197036, 51.01548002612207, 50.647059640576764, 50.50007666310957, 48.13234967570151, 43.46647854774229, 43.43567225240892, 43.922226582804036, 49.6568690576861, 48.75960726891795, 50.965842431591405, 45.148355576299856, 40.40681800534649, 38.968127927472516, 38.05197600395449, 38.12021347784227, 36.65480813672466, 37.96054555523781, 39.331198200102776, 37.822332997475904, 38.15278876212336, 38.51075210878926, 36.37772014064174, 40.09338140487671, 43.07439842531758, 45.72248858790244, 44.11576417184646, 48.87719600431381, 49.938334418881325, 50.0264661542831, 52.736157140424176, 54.11841215625886, 44.2762283355959, 44.4101066743174, 44.38588211613317, 47.67573479683169, 51.08612975766582, 51.55346055184641, 52.87584843174104, 49.53626009725755, 51.23898060091081, 44.14633904733966, 38.57466320837698, 39.208341721565496, 37.3462906191426, 38.38736611027872, 39.002001516280636, 38.5547258007911, 41.0751388918969, 46.11135628915603, 49.59387971508888, 50.18807172775269, 45.60145601149529, 43.66884146967242, 39.37752139183783, 40.535738468170166, 41.29014753526257, 44.657263063615375, 42.616065548312285, 41.0743034270502, 39.1290117848304, 39.52315115159558, 39.16721959267893, 39.29582234351866, 38.41469718563942, 39.46645329075475, 39.11074530693793, 38.821847054266165, 38.619531200778106, 38.986331647442235, 40.900287474355395, 45.386667020859264, 50.84216225531794, 52.03791249182917, 55.508005926685954, 51.58088576409125, 54.58326401249055, 58.565764119548184, 56.06408426838537, 45.9442437079645, 41.768339372450306, 44.05357107039421, 50.94646592294016, 56.84767576955981, 60.728621790486, 54.85302109872141, 28.100922876788726, 12.447294612084667, 6.136844273536436, 6.937601537473741, 4.82580675232795, 1.5856668040637047, 0.018068637601250125, 0.4561663497119181, 14.775710625033225, 52.81343175518898, 49.55362835238057, 36.493775229300226, 41.678521017874445, 49.908685222748794, 61.76362545259538, 43.821959034089126, 8.299780391877698, 0.07522408850491047, 0.04769975214355415, 0.10310454083786857, 0.017229700461030006, 0.024916188107923638, 0.1451311437713523, 0.021439901357817075, 0.03935439632304254, 0.005669149752300714, 0.05985496663338235, 0.10436990358416112, 0.05106150300332135, 0.07007576314912689, 0.021023327642450892, 0.032250459170750076, 0.061249537768984036, 0.1640260895533908, 0.13546766472920296, 0.10264245192370108, 0.09767556683190408, 0.20248546535449646, 0.16363042046225842, 0.1287148907900818, 0.2474337437700841, 0.24661864154040816, 0.1958641674249403, 0.219692213821315, 0.15754106334380566, 0.2338580375597362, 0.1530431313139777, 0.1840403357580785, 0.19942134348375185, 0.167012392212787, 0.06864657250022696, 0.29523839633311, 8.34175955864691, 47.946754886258034, 68.14667101829284, 61.039132302807225, 29.867717258391846, 37.173133665515536, 55.23504818639448, 60.028466947617076, 34.144989367454286, 3.023551938033873, 0.3730159018549227, 5.8104496329061455, 7.18599102189464, 15.805489690073076, 7.743520640557813, 2.9419967916703995, 12.696826977114524, 31.096499735309234, 53.901030478938935, 55.24682706402194, 55.47333217436268, 51.223259741260165, 52.53351965258199, 48.110878621378255, 51.008823763939645, 56.20853339472125, 57.06941912251135, 53.91333495416949, 54.40485892757293, 54.73140801152876, 51.00091626567226, 47.63134533359159, 41.91881325937087, 39.33181008984966, 39.163505108125754, 38.934842694190245, 37.46303604495141, 46.34910683478079, 54.1998758623677, 52.8515415037832, 52.412643970981726, 52.64155349423809, 50.062987342957534, 46.20475576769921, 46.88685986303514, 48.496161276294345, 52.00259154842746, 50.35323881333875, 55.29136557732859, 46.90035673879808, 42.71308145215435, 41.10471356299616, 39.913623102249645, 38.14599913935508, 39.309127023143155, 39.2720841592358, 42.07270745308169, 39.114620608668176, 41.13630433236399, 39.583802761570105, 37.62940729818037, 42.81170552776706, 45.22921523740215, 48.27777939458048, 46.32774952919253, 49.992765149762555, 52.01503722898422, 54.616455108888694, 55.78364656817529, 57.08995273036342, 47.68452482838785, 46.08188752205142, 46.44558929627942, 49.43798119022001, 54.05342240487376, 52.05349214615361, 54.108080633224986, 52.26624150430003, 54.1856651152334, 47.27506860609978, 42.23808242428688, 39.69452342679424, 39.16148508748701, 40.921017200716086, 42.45660158895677, 40.41366254129718, 44.40847104595554, 48.5183971928012, 52.310403470070135, 53.05584207657845, 47.49428203029018, 46.4457187344951, 40.690523039910104, 42.27641574798092, 44.35421682173207, 48.42102043090328, 45.15916955086493, 43.64316171215427, 42.359413100827126, 41.466830699674546, 41.30411901781636, 41.715442288306456, 41.22573044992263, 41.737136917729536, 40.84515071684315, 41.007666280192716, 41.12275254341864, 41.161544784422844, 42.03127153458134, 46.624688640717544, 53.81889212516047, 55.55880062041744, 57.835626679082075, 53.32638363684378, 55.062208944751376, 60.50906712009061, 59.652919615468676, 49.22985630650675, 43.15957269360943, 47.749589104806226, 53.94378823618735, 59.67614396925896, 64.22618750602969, 57.43019088622063, 30.14437967731107, 16.584530261255082, 11.624323494972723, 9.893369770819142, 10.967910924265462, 3.5220893544535485, 0.1272817701101303, 0.7007884895128589, 18.04954336535546, 59.14065414859403, 54.96714638125513, 44.37906895914386, 48.081978597948634, 57.66321105341758, 70.16400875583773, 50.821695327758796, 11.047642903943217, 0.2091351851460434, 0.22561791923738297, 0.21854246906455488, 0.1569068804383278, 0.12421139696192358, 0.2548110785503542, 0.14875409613934257, 0.17857555480253312, 0.13509552985910447, 0.14236346728378727, 0.23849522905243983, 0.15480977603264395, 0.1268328502473812, 0.06639121731202449, 0.10041186435809059, 0.12713632065682642], [0.05510681879616553, 0.034430672624899496, 0.05853538018380923, 0.0322508383842726, 0.049202789837915095, 0.028205576217583114, 0.04397484879460066, 0.04845564343756245, 0.12570001305110995, 0.08530893888805183, 0.040331744483762214, 0.017671940037079396, 0.015337062049506894, 0.0663018225121402, 0.08760396976985278, 0.045974514477195284, 0.014565872937260617, 0.03000597860063276, 0.0322020692270129, 2.8199350833892827, 26.122381302618212, 53.489785655852295, 44.349855146100445, 32.27846087947969, 37.66349661734797, 40.50772490039949, 45.19209784846152, 36.20315505612281, 6.01071604797917, 0.14100425876677036, 0.11308514963715308, 2.4792279591483455, 2.7542905413335372, 8.24539771003108, 4.89918694380791, 6.92822216979919, 14.257885198439322, 35.5831773819462, 48.27569269364881, 51.04126568763487, 50.08123028662897, 49.358721856148016, 49.03018020814466, 51.489325877158876, 48.83506974866314, 47.288910650437884, 54.64349592885664, 47.120182052735366, 45.79722150679558, 42.173535900731245, 36.410719040901434, 36.731945468533425, 35.908247732347064, 33.97648434485159, 36.38150522785802, 43.34203350928522, 46.937395680335264, 51.611841109491166, 50.125811946007516, 48.69799075588104, 48.791998201800936, 45.44196459554857, 46.003553867340095, 46.08061275174541, 47.37164128211237, 47.88149449133104, 50.25730156129407, 50.265228671412316, 48.59155724125524, 40.53897442356233, 36.05903540888141, 36.1405893295042, 36.070198474391816, 34.95811631602626, 35.22486494433495, 36.94894667594664, 35.35943362020677, 35.663986052236254, 37.17006244967061, 35.591724226551676, 37.070163603751894, 36.960286248114805, 38.60904278293733, 39.65669608885242, 42.60372969412035, 44.719467932178134, 47.16024906404557, 48.66915741274434, 50.1929433115067, 39.31439868865475, 43.95063238759195, 48.36704077259187, 50.605357000904704, 51.194536224488296, 47.8952149421938, 49.39380353496921, 48.01172894816245, 43.91419749106131, 39.068183668198124, 37.4387526512146, 35.32224170623287, 37.26155565631005, 36.80970645719959, 38.56327264539657, 36.02208668185819, 40.296069883531146, 48.889790734937115, 51.53741413547147, 52.13851344200873, 47.665799433185214, 42.015189816874845, 39.091870861668745, 44.2375498433267, 46.60710073286488, 49.07699761852142, 48.50283322795745, 48.75262545001123, 46.363721586042836, 42.58916593367054, 40.47031725606611, 36.94448301869054, 37.08886938710367, 37.59116026663011, 36.89015819180396, 35.318617436193655, 34.98089744198707, 34.89248721830307, 35.52521259553971, 37.5737920115071, 47.261901209431315, 47.703968017332016, 50.95516181761219, 54.898045985929436, 49.9955931786568, 56.06193088716077, 56.123112017108554, 49.639908729061005, 42.699345311810895, 41.345511790244814, 48.64559573511924, 54.38263085580642, 57.60746632852862, 51.42784272470782, 27.51483448090092, 7.101127601438954, 3.0928180534993452, 3.6038114466974815, 1.6258239073138085, 1.032455960108388, 0.2775614077766096, 0.14825537290063598, 14.831651468430797, 48.066147911933164, 51.380735058938306, 36.982322123742875, 31.908218552989347, 48.25948153772662, 52.242315046248905, 27.680442833131362, 4.466003814051229, 0.054766009261290875, 0.05663142186559497, 0.03912404134509064, 0.03710711570156198, 0.10861731720187011, 0.04801519267681626, 0.034060269113509886, 0.023295287786412145, 0.06414022116411118, 0.037887031512875716, 0.08832776197983373, 0.03477498701202773, 0.05068729969582731, 0.02512506964135795, 0.013042398889909589, 0.05641191086221126, 0.03725617342898923, 0.043753292336459124, 0.11083398494989642, 0.0705617463456527, 0.09499603642090675, 0.06974572481046762, 0.028427347180343447, 0.06489234330553202, 0.03062954927313953, 0.019776768524259813, 0.057791734805270556, 0.07256825319341115, 0.04046769444680503, 0.03374814574095992, 0.10104399414793139, 0.04199496733265058, 0.04023958410647127, 0.02069287561631251, 0.023963069393029137, 3.9594902578861486, 33.2538111748234, 59.278282273200254, 50.60907540782806, 29.270848228085427, 37.584092155579604, 47.79451201038976, 52.86370477368755, 38.3527982619501, 5.6117551076796754, 0.06337760744856731, 0.4145093075931073, 2.482550696980569, 5.1968335528527545, 9.994698320665668, 5.249788491956649, 9.636596710451188, 19.286252952391102, 40.22845998887093, 51.165071379753854, 53.66125599030526, 50.69766606053999, 51.92550128506076, 50.54232451223558, 52.723232930706395, 50.68893878690658, 48.35528542918544, 56.38458897990566, 50.52763523594026, 48.40323248217183, 45.32681557439989, 40.72825624096779, 38.19624862363262, 37.073313267000266, 35.70273122479839, 37.8092558153214, 43.02851061667166, 49.656166953425256, 53.66392712439261, 51.856318519961455, 50.75486598476287, 49.85896918081468, 48.05403563284105, 47.55523566276797, 47.744423343289284, 49.571161347050825, 49.681077926389634, 52.12665611697782, 51.24438170463809, 50.57014196149765, 41.67683439870035, 38.193224476229766, 38.09931901193435, 37.87870137922226, 36.988633217350134, 37.75159697378836, 38.722297299292784, 36.690615454027736, 38.2979243032394, 38.401314058611476, 36.38423127512778, 38.00545277134065, 37.90212185152116, 40.380577348893695, 42.580925033938506, 44.78780738769039, 46.0712775107353, 50.98674866460985, 50.8339213555859, 54.09898465679538, 42.980775371674575, 44.27707164518295, 49.95000347014397, 51.987517879855254, 54.497113074025805, 50.81443109819966, 50.697599380247055, 49.305969899700536, 45.395009902215776, 42.15031546931113, 38.7160332741276, 37.585429683808364, 39.36000408664827, 38.946252869021514, 39.65560959231469, 38.55445123487903, 42.74331508144256, 49.972745372403054, 52.61825069304436, 52.20881016023698, 50.5667491112986, 43.7552002937563, 41.56216782908286, 44.41387214968282, 49.32510322140109, 50.10109709155176, 49.80536607003982, 51.126043796539314, 46.88755804492582, 43.63281842200987, 41.43667159541961, 38.968520164489746, 38.76419605747346, 38.69922199556905, 39.159833769644464, 36.34441921787877, 37.20569326031593, 37.032775571269376, 38.13082348915839, 40.03245522899013, 49.863185728749926, 50.86791261549919, 54.75785655360068, 56.32833826926447, 50.75459926359115, 58.0771936908845, 57.96086403631396, 50.967266251963956, 43.39169071566674, 43.856087576958444, 51.192273016898866, 56.17336150138609, 60.97429944622902, 54.33356592732092, 28.030437884792207, 8.020691006414353, 4.857903997744284, 7.625666654879048, 6.336247276875281, 1.1120105751099125, 0.12249738248365542, 0.33235952378280703, 16.449077090909405, 53.69670244955248, 54.15660035225653, 37.74749025221794, 38.290122708966656, 54.442341096939586, 58.96997613291587, 35.021976424801736, 5.875812009457619, 0.10450864976812756, 0.034230022706211574, 0.01667752535262656, 0.038898144998858054, 0.06219735324022271, 0.03670810646707973, 0.010929363685840321, 0.05605684443106575, 0.11215174811020975, 0.03262571584914, 0.019131709085476976, 0.04671802195990759, 0.06041778078783424, 0.02351137820721394, 0.02450283196183943, 0.04915052731972068, 0.14550640428018186, 0.10555927040836505, 0.15768337183662, 0.23990371234474644, 0.10102746963140466, 0.18929154672209295, 0.08474141329286561, 0.18517452892997574, 0.20492248297218355, 0.20156430591258312, 0.12262780895276416, 0.14072535679705683, 0.11560978473074014, 0.11841961903677833, 0.21756092657244977, 0.16169114549073482, 0.1023645458682891, 0.12781848364900197, 0.1764509478403676, 4.495798628176413, 37.25646834219656, 66.40501314593901, 56.744435064254276, 42.748245500749164, 46.8156413878164, 52.53593975497831, 56.84059981376895, 44.52205896377564, 7.816153130223674, 0.32244493644083705, 0.6235518727091052, 4.6223499794160166, 11.057650831437881, 9.971743629824731, 8.92814507407527, 9.355899153217193, 16.276095663347554, 39.546920714839814, 53.76659908602315, 54.622228837782345, 54.080235727371715, 55.13207420226067, 54.76195935280093, 53.65854563251619, 52.506639649791104, 50.667044116604714, 59.25581101448306, 52.67239901327318, 50.499864855120265, 48.16579572616085, 41.957440760827836, 40.88078937222881, 41.10244251066639, 36.61858112581315, 40.42961089841781, 47.158750718639745, 52.91042412481001, 55.14793626723751, 53.60613884464387, 54.113360143476925, 52.98812627792359, 50.567953278941495, 50.61454319184827, 50.99002384370374, 53.0761246527395, 53.07798777857135, 54.536458369224306, 53.63560761174848, 53.30091176494476, 45.54695075558078, 39.59101992268717, 39.406770506212794, 38.68887870542465, 38.878933229754054, 40.17436658182452, 40.57331085205078, 38.254021213900664, 38.973105415221184, 41.04231649829496, 38.87148857116699, 40.55284784686181, 39.572573015766764, 42.86479873041953, 45.93473588266681, 47.52952844865861, 48.49166624007687, 52.95379377180531, 53.518524862104854, 55.244501098509765, 45.612764204702074, 46.20684639100106, 51.85236869319793, 53.721554586964274, 55.99108895947857, 51.835639784413004, 53.16537818601055, 52.691124408475815, 48.48428433941257, 42.32137787726618, 40.544026436344275, 39.82087081478488, 39.996863642046534, 41.68783664703369, 43.121321739689, 40.16953422177223, 44.75445155174502, 53.035598724119126, 55.12761054500457, 55.912292465086914, 53.287846349900775, 46.582221138861875, 44.74139005907121, 47.590791948380016, 52.10554984308059, 53.0995019789665, 52.79571048675045, 53.003651019065614, 51.6354694674092, 47.978588842576556, 44.5723908178268, 40.802165462124734, 40.74023123710386, 41.161929176699736, 41.34717879756805, 39.57103544665922, 39.62833735250658, 38.652016270545225, 40.00205686015468, 42.10191734375493, 51.95433462819746, 53.155956652856645, 56.63540886294458, 58.86941440643803, 49.850508628353, 57.670738081778254, 60.779840100196104, 53.41962622058008, 46.786553090618504, 45.21886410251741, 54.860253949319166, 59.363158441359005, 62.99728539682204, 57.1643679372726, 29.990691408034298, 9.440266393846082, 6.726975652479357, 10.874814448818084, 6.572497025612862, 3.457197907470888, 0.730997481413426, 0.3433759294209942, 19.88266306538736, 60.0029323177953, 64.779986950659, 49.1131148030681, 43.668943451296904, 61.751634766978604, 67.86058902740479, 42.28288373639507, 8.087973383165176, 0.18865425349964252, 0.14894514314589963, 0.11939573762637955, 0.12249150658927618, 0.19922573059316606, 0.16441881686689394, 0.1565758538462462, 0.13187432932036539, 0.2493907766596925, 0.09498433825830299, 0.15218771753772614, 0.15917040978468236, 0.16704531867177258, 0.10412716096447361, 0.11507418968023793, 0.1803658103510257], [0.0467976491387573, 0.11150630371224497, 0.015235312166623773, 0.02238306667535536, 0.04756580166999371, 0.0591589336193377, 0.042111535271209095, 0.02826492313385731, 0.04283653023923117, 0.030009129137221365, 0.010823540130419838, 0.08540282296317239, 0.03841134591869289, 0.034965179830549226, 0.016480569892953482, 0.04287398427784924, 0.055769542307262464, 0.041916516098764636, 0.060721978980807535, 0.9111045072636298, 18.057566573542935, 48.51786375045777, 50.612201536855395, 39.61583283639724, 30.078756463143137, 42.45231051598826, 42.15842300845731, 41.296411560427764, 9.78565069936937, 0.24352785980989858, 0.09040848742569647, 1.4795190095901491, 3.763613465332216, 10.168587776922411, 2.7627726668311707, 4.967921578115033, 7.434715868965273, 18.811730492499567, 38.56714402475665, 52.170916142002234, 50.874988571290054, 52.86724275158298, 53.19223073221023, 51.812674307054095, 50.04846672857962, 51.92097486988191, 49.17291133634506, 45.29285177107781, 40.90019725984143, 35.352742056692804, 36.48564415593302, 36.68603804803664, 37.88308658907491, 38.7618818590718, 43.73794186499811, 45.98243190396217, 48.46017352996334, 48.55731102728075, 47.36870342685331, 47.10102911918394, 48.80945274906774, 49.413183965990626, 47.57789911762361, 48.88002403320805, 47.009135830786924, 50.40503371146418, 51.7078411194586, 49.76348692371, 48.28542017167615, 42.59619482101933, 36.19594966211627, 36.43643017738096, 35.04530668258667, 40.30576598259711, 38.92757846463112, 35.88716107030069, 37.188732931690836, 36.66485332673596, 36.925165345591886, 36.25671502082579, 37.06804552385884, 35.30388501382644, 37.0209849265314, 39.58543054519161, 38.80450625573435, 41.35460776667441, 47.00598616753855, 47.24301499705161, 49.593358039855964, 40.856505978492, 44.52015269187189, 51.174304639139486, 49.99427918464907, 48.50477872356292, 47.90481298200546, 46.16137827596357, 45.148681133024155, 41.99065931381718, 38.098597295822636, 35.903862522494414, 36.4652439086668, 36.81963005373555, 37.769667333172215, 36.776872296487134, 34.961093394987046, 42.99344070496098, 49.90854793979276, 51.83434932462631, 53.20253087628273, 48.29562617886452, 47.18554835165701, 45.60934389791181, 49.777454483893614, 48.186184206316554, 51.77228566138975, 51.82505330731792, 50.88231163640177, 49.486944137081025, 50.53149484818982, 47.6619751222672, 44.80064138289421, 44.287920921079575, 43.96385469744283, 44.16484478981265, 40.548462637009166, 36.651697697178015, 36.718966345633234, 37.07015968138172, 34.969451965824256, 38.42980223317301, 46.81993638315509, 47.32015232886038, 54.19441200071766, 53.70132692398564, 53.8787631834707, 59.66745591932728, 54.69527513750138, 47.609297690853, 43.07417092784759, 47.46287168995027, 52.20331491962556, 57.89230492807204, 53.548083843723425, 26.582365497466057, 6.525952219963075, 5.352793855051841, 7.308907806873322, 6.553351446505516, 0.6919747398745629, 0.1071364232789605, 0.5244697990917391, 13.527402589398047, 45.006765857819595, 42.40756019469231, 32.9893296764743, 25.69982240276952, 42.17601091630998, 54.053955847217196, 30.399635761014878, 4.259192434049422, 0.06124458501055356, 0.034557341432739655, 0.03417152806275314, 0.020733248449922092, 0.08280046058878784, 0.009717785099881792, 0.03354481068409739, 0.0315717991156083, 0.06107734801668314, 0.03168821192136215, 0.06642404417957991, 0.04202629266787441, 0.11329302759540659, 0.08268488856453089, 0.0073384701822614, 0.025642567779868845, 0.018958010139965245, 0.04910354697776418, 0.015474670592905774, 0.019792706983524467, 0.08328706431653231, 0.030311548090990514, 0.014066312747496753, 0.028925143452661655, 0.03747971788529427, 0.021280206499561187, 0.03562246411738377, 0.06867063532192862, 0.06531280300189411, 0.03331926290787036, 0.00810912111774087, 0.04625037124740981, 0.04481875593022955, 0.026044409624451113, 0.04266422940418125, 1.48121518954154, 22.943629757050548, 56.396662035296046, 55.00169461773288, 45.5654525756836, 33.619026983937914, 46.30309743265952, 47.325227875863355, 43.178811919304636, 10.342174230083343, 0.16815230040059936, 0.15904656401084316, 0.9768849226736254, 4.852881893034905, 6.0192020958469765, 4.941877040170855, 5.362454162489984, 8.433020364853645, 23.65534382481729, 40.10949842391476, 55.364964931241936, 53.388004072250865, 56.013560218195764, 53.611590939183394, 51.78113060612833, 50.026599514868956, 55.35268791260258, 51.14492608654884, 48.91996160630257, 43.768987424912, 38.899721791667325, 38.3587484975015, 38.44324419575353, 39.016098514679946, 39.86346383248606, 45.38960095374815, 48.974274666078635, 51.488953251992505, 52.26550802107781, 49.93866782034598, 49.89071684498941, 51.53354667848157, 51.08434507923742, 49.799129501465835, 50.09237374028852, 48.02786165668119, 52.01418215228666, 54.52137293354158, 53.029056210671705, 50.05632715840494, 44.447192684296645, 38.28778889871413, 36.65834219224992, 35.98650293965494, 41.151146581096036, 40.32583675076885, 39.114581384966456, 39.8673116776251, 38.64799191874843, 38.800172036693944, 36.84956950526084, 37.50515445586174, 36.317064608297045, 38.93203819951704, 39.2578028094384, 40.17612772603189, 43.21896914512881, 48.549042670957505, 50.805441025764715, 52.17031601936587, 42.633378890252885, 45.76432851053054, 52.196964602316584, 51.6623612373106, 49.64799273398615, 50.05348344003001, 48.74235276252993, 47.21207926350255, 42.54305454992479, 38.935536953710745, 37.45420286732335, 38.117169718588556, 38.742850518995716, 39.560825517100675, 38.394218490969756, 37.663037700037805, 44.21636119965584, 51.063874229308105, 55.093874239152484, 54.56377767747449, 50.43152147723783, 48.65378956640921, 47.384467432575846, 51.2613106543018, 50.35590210268575, 52.10613819860643, 52.44422689560921, 52.746802453071844, 51.36604186027281, 50.521849739936094, 47.43772537477555, 47.62219444397957, 45.4752145274993, 46.08533136306271, 45.37515878677369, 42.472283224905695, 36.02934306667697, 37.89018215671663, 38.82075271298809, 38.51048930998772, 41.597994758236794, 50.39479240294426, 51.789571546739154, 56.310628767936464, 55.56975187793855, 54.514010644728145, 61.69581943942655, 57.51736164093018, 50.73009229475453, 45.43156246985159, 49.29725831554782, 56.22408167008431, 59.81215607735419, 54.394888262594904, 27.81279733104091, 7.248299833266967, 4.514299467686684, 11.742320156866505, 5.219550450001994, 1.6425014575642924, 0.2621623356976817, 0.1942810620511732, 15.311165144366605, 52.075622158665816, 51.61755208046206, 38.170227619909475, 32.44587156080431, 49.65115416434504, 61.593174934387214, 33.58696160777923, 5.287712908560231, 0.013417560764918885, 0.04322016791951272, 0.0448932005242715, 0.10004582754786938, 0.07130341904778635, 0.06846492539250082, 0.07700278378662563, 0.06423828424885869, 0.149430260663071, 0.009959606498840355, 0.03652156405751744, 0.04916577246941386, 0.06810302545707073, 0.012262533831920837, 0.04143037585421436, 0.04244076921754787, 0.2251692215401319, 0.1738504010943636, 0.07922047809247049, 0.1237859117287782, 0.16640537478510412, 0.150746782760947, 0.208811421067484, 0.13265704135260276, 0.1417220678300627, 0.21100732017188303, 0.12035831944235872, 0.17154962455313053, 0.1163276550810664, 0.09024839803215959, 0.0996567621346443, 0.08963591073669734, 0.2108453232194147, 0.16302573194186534, 0.13499475865354463, 1.538326247565208, 27.64522583253922, 62.24519837287165, 63.13654914979012, 50.74411869049073, 39.673495600300456, 53.07077453982446, 53.33786833670832, 50.75809409541469, 13.417339901770315, 0.5394007914489316, 0.3820210509002209, 4.7071962395022, 8.840744860710638, 18.57158337869952, 10.537809306575406, 8.037358628165338, 9.567794415258593, 20.387144588655044, 40.58042210917319, 57.45724739566926, 54.927769707095244, 56.26271309391145, 55.670964717865, 53.516261654515425, 52.54288627255348, 56.54441379731702, 54.44130166884392, 49.09896289148639, 45.00931932080177, 40.02614805775304, 40.28367519378662, 41.288731559630364, 42.19398321643953, 42.38646176553542, 47.9056013784101, 51.71011609415854, 52.82552050006006, 53.93389994098295, 52.46667462010538, 50.27679181868031, 52.74200931672127, 52.40667020120929, 52.23232476942001, 52.737298550144324, 50.66598115428802, 54.37619816872382, 56.4420634700406, 53.53527730511081, 52.345575363405295, 47.412245658136186, 39.703250700427645, 39.33432432913011, 39.1198177491465, 44.46056404421407, 42.82461404800416, 40.47440044341549, 41.9816025610893, 41.38402162059661, 40.86848881936843, 39.55176091963245, 41.52450130831811, 38.08377465894146, 41.42437104255923, 42.64796618492373, 42.498382676032286, 45.5802869796753, 52.426093778302594, 52.6999536637337, 54.66002871913295, 47.27249945363691, 48.06351600154754, 53.53903493573589, 54.27899006874331, 52.08573795134022, 52.36796425234888, 50.31778450935118, 49.27662664844144, 46.60852455323743, 41.789539783231675, 39.15730384088332, 39.88385623501193, 39.5499409398725, 41.205255677623136, 39.00444907526816, 38.82202748329409, 48.13977472243771, 53.32434792672434, 56.35861112225441, 57.0008364800484, 51.89885270211005, 52.97402927952429, 50.83149733081941, 54.54972774751725, 53.418775066252685, 55.86067407361923, 56.22050054611699, 56.03697676812449, 53.250713271479455, 54.466785307853456, 50.83338399087229, 49.96707754750406, 48.69657478024883, 49.177802531949936, 49.16330152942289, 46.660739144971295, 39.74662426979312, 41.4473129856971, 40.01545175429314, 39.28196460969987, 43.17176342010499, 52.325614421598374, 52.9958180458315, 60.65621483710505, 56.75081283815446, 55.15955825005808, 63.929264083985366, 60.25400715489542, 54.31799019536665, 48.26562396941647, 51.48537997276553, 57.22383106908491, 61.73495684900592, 57.04552796579177, 30.463011457074074, 8.425444306865815, 9.274780615683525, 20.676880267358598, 16.907307986290224, 2.980595365647347, 0.4004069465783335, 0.9100860393335743, 17.6261156605136, 56.943742459820164, 54.55201841169789, 44.672026864943966, 37.38987991886754, 57.92241696388491, 70.02145413429507, 42.24415817568379, 6.602686528236636, 0.12939179075821755, 0.09447012472176745, 0.16482692722591663, 0.18419104057454294, 0.18009104525610325, 0.13159878281576018, 0.16901008904941622, 0.16534256568599134, 0.30715109419918835, 0.06905167213370723, 0.1275140020034967, 0.16164775427070358, 0.13978388070339157, 0.09785975735153883, 0.1528287033039716, 0.171507076029816], [0.03126223447672542, 0.10745455661127645, 0.040040918355507236, 0.06050040720090751, 0.09053844658117141, 0.012892422814583106, 0.03992649929357633, 0.06293016613551206, 0.02533216235948907, 0.0486815512751139, 0.018734726153554458, 0.03588871797546744, 0.05246979860408653, 0.04140077804725978, 0.012969413693363388, 0.09089421781320726, 0.021200772757912358, 0.03869937582602424, 0.04501277918837244, 0.23690692960254608, 10.815632747065637, 43.88245767162692, 49.5783196726153, 39.06843862225933, 23.33883208613242, 27.08341298564788, 37.74643905701176, 43.6043930053711, 16.98584560425051, 0.6901771911690313, 0.12348875388382904, 0.6191276843028685, 3.417431938071405, 8.477292156988575, 4.092038177674817, 1.5712773439384278, 2.4280508343250524, 9.817290498364358, 22.64587087015952, 45.68390815488754, 52.17920803254651, 53.04517715207992, 55.30781992020146, 53.876248944190245, 55.11267023701822, 48.16337170139436, 46.09233671619047, 44.50445144407211, 38.215597675692656, 34.682275633658136, 33.678235161689024, 39.473964629634736, 43.9930881223371, 46.40635382744574, 48.32826422106836, 47.63640911348405, 50.230017554375436, 49.34719793258175, 49.49900150299073, 49.30433427133868, 48.73581417145268, 49.30234170729115, 49.352214644032145, 51.52342696343699, 52.920747803103545, 51.40166090380762, 52.04029729289394, 51.747002063259, 49.50177069633238, 45.240868599184104, 35.96771478652954, 36.59733364658971, 35.292592510100334, 38.0711446269866, 38.63828013020177, 37.33768101661436, 36.599659612101895, 36.02905673365439, 36.218279715507265, 35.194105717443655, 35.58748022202523, 35.65292104598015, 35.44736531472976, 36.6576361656189, 38.98136984917426, 39.267283178144886, 45.3812345381706, 44.920195225746404, 51.03915545248216, 43.69983211640389, 50.11347216944541, 52.78961512350267, 49.12960836964269, 49.11377768362723, 45.022365123994895, 45.18316661157916, 42.714583719930346, 39.103728186699655, 36.59400355431342, 37.46378129528415, 35.83457777577062, 36.85971275452645, 37.20557166684059, 37.73006316154234, 37.12761455966581, 42.91293405717419, 51.19406946243779, 53.06577744022493, 55.52012605051841, 51.40791708423246, 48.83495992229831, 47.05801248550416, 48.712095599020685, 50.682302136575025, 51.86084493514031, 48.12088851005801, 53.59745863945254, 53.50358063174833, 51.427783889155236, 49.38378187917894, 52.00934586986419, 49.69348438324467, 51.403182783434474, 52.078744365322976, 48.94369586821526, 46.55552156509892, 41.50008063162527, 36.42129767325617, 36.83419773655553, 36.39364888591152, 41.82703764207902, 48.977200754227184, 50.5229833049159, 55.63003086274671, 54.515010849122085, 50.29401494610695, 58.46850502875544, 52.91567617847074, 50.69171974735875, 48.15795098581622, 53.6139129823254, 59.323346384109996, 47.644599022403845, 24.10736756940042, 4.033185464720573, 3.2105440718512384, 5.958595102833164, 2.3431901104988593, 0.9332223236560823, 0.05104688221528646, 0.5784970161414916, 15.40224159917524, 46.557137581609915, 42.314007743712395, 30.976157496052405, 28.419032981318814, 47.04182486380301, 49.655935533585094, 28.58360386663868, 2.052134063936049, 0.04547450804121552, 0.04308091994795588, 0.018615582244350545, 0.03528124855590924, 0.06711975160625673, 0.08365285597861775, 0.03218351074704721, 0.08678632412826823, 0.03826131909004143, 0.04147697315220872, 0.06190357767345925, 0.08158091756124651, 0.016626823738577868, 0.062178668355749506, 0.05585326039562783, 0.05406258349877693, 0.012702839035961418, 0.02172258205621714, 0.033469630645648125, 0.04148995834252527, 0.04728337186538885, 0.01751464494924632, 0.05685195559635759, 0.134455080354406, 0.052523574145931395, 0.08434911498860007, 0.05306173942141956, 0.05948612211091865, 0.015534718479630689, 0.0290641596826214, 0.03380012097618273, 0.02562685148610223, 0.03743723064901368, 0.036599295168754556, 0.024782157195131146, 0.39425320743072423, 13.52078555091735, 48.845769974493216, 56.15474593254828, 42.183357515642726, 27.5555290714387, 33.45742141046832, 45.437175381568174, 48.09484004974366, 17.157168849822014, 0.7034361506662061, 0.13028192363919752, 0.45068027151207773, 4.4411443221953615, 5.2169106948760255, 5.346120432499917, 5.251495213277879, 4.451376805382391, 14.08152464897402, 28.689745164686634, 46.51460339946132, 52.13243376824164, 52.919233768217026, 56.00568409888975, 53.85010634699176, 56.33146047592164, 52.09264132284349, 48.4775221732355, 46.316923787516934, 39.85404622170233, 36.82524688782231, 35.91344487282538, 40.914639426815896, 44.46098766019268, 48.81206112523233, 50.394396243556855, 51.15153135791902, 51.68669562185965, 50.019786357879646, 50.520100362839244, 50.05764899715301, 50.56831805936752, 52.19465432628509, 51.04270911985829, 52.94074012387184, 52.672457848825765, 51.76099708003383, 53.526495118294996, 54.72364564095774, 51.825170978423095, 46.759794681302964, 37.326035499572754, 39.20030478508242, 36.44858560254497, 39.0873287570092, 39.03267837339832, 39.810154899474114, 39.245890571225075, 38.117761996484575, 37.253259843395604, 37.4484016818385, 35.80289679188883, 37.89897611064296, 37.96469150050994, 38.07198793657365, 40.01569886361399, 41.95686025004233, 48.62298719344601, 48.469367565647254, 53.24699094218593, 45.51231230458906, 51.078426222647394, 54.43129570253434, 50.698791780779445, 52.243048529471125, 46.78044596026021, 46.947291820280014, 44.47710467923073, 41.004834328928304, 38.20580743974255, 37.646885379668205, 37.12857161798785, 38.76127389169509, 39.16082220692789, 38.989340105364406, 39.83193974341116, 44.71455712472239, 51.702761650085456, 54.41752426085934, 56.481330317835656, 53.997658068133944, 51.264260276671386, 48.95442355063654, 51.80833224327334, 52.37648364036314, 54.16118560298797, 50.37275652731619, 55.63074865648824, 55.98908070595034, 54.17935794399631, 52.14637387183405, 53.6510774397081, 52.090240832298036, 52.91264418632754, 53.866831333406516, 50.60902049464565, 48.004782430587284, 42.22816667249126, 38.44275782185216, 38.1987589405429, 38.86789175771898, 45.07362657977689, 51.43330266398769, 53.32945093031853, 57.27788133005942, 55.36102294921876, 52.77625945306594, 61.04259183329921, 53.28197456175282, 52.30004841281522, 51.24619383965769, 55.32532938065068, 60.49113796603296, 50.85911473920269, 26.00131146369442, 5.783977066316913, 5.14761172956036, 7.396621809851739, 5.326179592840133, 0.5941958124599149, 0.022866433681619745, 0.4767521128298775, 16.156359430282347, 51.14518496298021, 45.41357840261152, 36.21763252442883, 30.067664000295824, 53.81610331996795, 57.850802329278764, 34.5934731729569, 3.3481888665306956, 0.0762469384578928, 0.09455213443406167, 0.009687960339379648, 0.04127096444849045, 0.010715558122272694, 0.05539428945931216, 0.037521071311446934, 0.01754517738346852, 0.029874983311240232, 0.06320139573466393, 0.07309775784491532, 0.08270000347927695, 0.017087669675088218, 0.0961864451246877, 0.02646112889652291, 0.060505287180985176, 0.14914527595523866, 0.13669691409074491, 0.11561592875589287, 0.1514835601612445, 0.22127648364872704, 0.14607698656618595, 0.10306220681917283, 0.22201025798436136, 0.16708135544773073, 0.21602562508515774, 0.11697535943840781, 0.0841902666575005, 0.14304075029588517, 0.11321678652518219, 0.08280415313258287, 0.1704197827606432, 0.08457390050734244, 0.10691083336789763, 0.16525874034531657, 0.5456548268275877, 16.104936176730742, 56.19178879645563, 61.777734218105195, 50.48748585485643, 36.36195221254903, 38.14322602364325, 48.53082718387727, 53.648865222930915, 21.236963349003947, 0.958120855352571, 0.3805245747489314, 2.343213889868029, 10.180894213338053, 15.518634992261088, 8.152004115043148, 4.611323706565365, 4.757069666539469, 13.167404513205252, 26.54860369620785, 47.84879761357462, 53.603816801501864, 53.84550540677963, 60.21550124691379, 57.00383317086005, 57.489030361175544, 53.7326588169221, 50.2902808497029, 48.45567849374587, 42.080846371189246, 38.25094607568557, 37.24246548068139, 43.366830733514604, 48.248440065691554, 51.62972711747693, 52.45790027802991, 51.90588551182901, 53.800284401063, 50.89744021815639, 50.90644205770185, 51.76834367936658, 50.73186912844258, 52.87695061775946, 51.87676583566974, 55.540557676746005, 53.94275665283204, 54.38372127471432, 53.796001172834835, 56.56001306349232, 55.65028205994637, 49.21539060531124, 39.30994679850917, 41.77808646232852, 37.80882827697262, 42.975397802168324, 42.81821273988293, 42.18527555465698, 40.77025305840277, 40.91895795637562, 39.39863551047541, 39.34786042859478, 38.89596416104225, 39.137954788823286, 40.40401743304345, 39.78231783836119, 41.95251426389141, 44.29576566142421, 51.45018062283916, 50.09214624281853, 55.128391096668864, 48.280121049573346, 53.11039440093502, 57.95318403551656, 52.50340761676912, 53.54003121775966, 47.737696478443766, 49.50381817356233, 46.74455627318352, 42.23707437515259, 41.235246119960664, 39.37443448651222, 39.12757619734734, 41.0246422982985, 41.814266404797955, 41.59953232734434, 42.14909168981737, 47.9567059393852, 56.630427452825735, 57.454835138013294, 58.89601984331685, 56.666544637372425, 53.150520247797814, 51.71177525674143, 54.81157341311055, 54.87804189805062, 54.42321561997937, 53.30535973272016, 57.220077360830004, 57.9545097966348, 57.01261143530569, 54.20254307408487, 57.170420154448486, 53.838825610376176, 55.67151777205929, 56.76801635373024, 52.52019143873646, 51.558896956905244, 46.0312654126075, 41.3000044515056, 41.512702818839784, 39.6489494077621, 46.66719536627493, 54.29730753744803, 54.317205721332186, 60.71791371991558, 56.57885612980012, 53.303806474131925, 64.16231955251386, 56.462506863378714, 54.62712003338722, 54.92294126941312, 59.900825177469564, 64.7295178136518, 51.77834180093581, 27.49866450986555, 5.813096252179915, 9.330661642935969, 19.137869688772387, 12.49335696620326, 2.2963104324956096, 0.23981227209010433, 0.7534367482989066, 19.72412282420743, 58.524167383870775, 52.764131484493134, 42.97563706674884, 38.64108462487498, 62.28879943970711, 65.85797586748677, 38.90158883986935, 4.2415966814564126, 0.22550155048168477, 0.12312921349920573, 0.12436622333142067, 0.1473421348078597, 0.167748112411749, 0.28267685263868303, 0.18377729180839755, 0.2788700085253485, 0.09775916234620156, 0.1557399599903053, 0.16479724897973, 0.16378529279703097, 0.08747944983864024, 0.1675348335336293, 0.16634669245010422, 0.11850681516431993], [0.031432930357573975, 0.047784630855124806, 0.06938099034971769, 0.06108957477995466, 0.027805274209728646, 0.03720519410806798, 0.006501767145950468, 0.021124933883848212, 0.08645276944603651, 0.05009182721316334, 0.03296662880588443, 0.08141483736014174, 0.027889777538216406, 0.046719293665861895, 0.06449075235474495, 0.06535819371140773, 0.06394395326835013, 0.03410746779052481, 0.050228738616551125, 0.10002294450157112, 6.506169255702726, 38.15958230726181, 49.87049310438095, 41.702251357416955, 20.053082204634144, 33.74280521946569, 37.0997892656634, 43.74455890347881, 19.768463257820375, 0.9258000961234494, 0.12141856980780441, 0.05001380881895462, 3.1679334034842834, 1.6748168848214613, 4.630073126285307, 6.498729009782115, 1.0096648443610439, 6.133384252748182, 15.681974253346844, 36.8220736903529, 50.18036034799392, 56.21676644971294, 53.007000723192775, 51.95784514950168, 49.783267436488984, 48.32890356740644, 41.20141175485427, 40.15147955186906, 35.44367044202743, 36.432499962468306, 42.51709238175423, 45.64581017340384, 46.71830777199038, 49.37604696519914, 49.27254738346223, 52.736263044418834, 50.677112840837054, 52.00346623697589, 48.03306271952968, 48.96492373558783, 50.58463119691419, 49.29759563938264, 49.71151944129698, 53.3093644726661, 49.594197427072835, 51.338373461077296, 50.96452843758368, 51.894224305306714, 47.92385608919206, 47.85519499932566, 42.234081606711115, 35.24912088148056, 38.106971556140536, 36.30263420843309, 35.69326262320242, 36.26628560404624, 36.24750529566119, 37.80867138216573, 38.519608820638354, 37.38423562818958, 36.82054004361553, 34.91720991749918, 36.17984833255891, 35.660279412423414, 37.37863448358352, 38.137052212992025, 46.015556320067375, 48.0693877896955, 52.201828341330256, 45.673611933185214, 49.93906005736321, 49.422848686095215, 47.93222642713978, 49.034428135041274, 46.137373370508996, 44.68987757159818, 40.95564780696746, 39.80497344847649, 36.83795536718061, 36.885529795000636, 36.75233002631895, 35.78845462491436, 37.36829119343912, 36.335123200570386, 37.213843945534, 40.253425875017726, 48.89224221629482, 51.488400197798214, 52.84824671283845, 52.429066934893214, 51.568396937462595, 51.2993380331224, 50.57994788692844, 52.97713579670076, 50.22196492841167, 48.46612768788492, 51.90834876029722, 50.19493587555424, 52.591586420612956, 51.955213239116055, 54.03072757105674, 53.745994875507975, 51.9105766665551, 52.43637038815407, 52.40728601332634, 49.05506372451783, 49.46218613655337, 44.70489632698798, 39.893732763105824, 36.2861131852673, 37.72072399816206, 46.34880873464769, 48.80195709966844, 53.81892742649202, 56.1011859678453, 45.72895265394642, 56.68545046160298, 56.04623748410133, 53.918230072144546, 51.77727491624894, 54.86923617701377, 56.70658026972125, 39.34194157200475, 16.337143432709478, 6.362383990518509, 2.9646994702277647, 8.445672950436993, 3.054608774762, 0.402475138825755, 0.24532383037430627, 0.5071769270204729, 16.86502483583266, 49.05735831106863, 45.93701085736675, 31.957393307839673, 36.1518386871584, 51.001622292303274, 41.48831744347849, 16.88223619614878, 0.6106768764795796, 0.06931468543987121, 0.013678548726133041, 0.011318536351374801, 0.05929392597247517, 0.059880879557421135, 0.07890762310595283, 0.046849628204419735, 0.037056990568676305, 0.03512672862158187, 0.01941682019781682, 0.05496655575810902, 0.0232432704163535, 0.05030105348616358, 0.018153071981824694, 0.035066173201607126, 0.024563293536043456, 0.05956138258859996, 0.10818798620734485, 0.04028107925888993, 0.05622649460189766, 0.019906559140391408, 0.05451520739663994, 0.05638166571096067, 0.028729130281135443, 0.021569115492785652, 0.1384267712672872, 0.06678066576921171, 0.04127106403992061, 0.05249119543981168, 0.08726325982640828, 0.04514432031541102, 0.05906160597899749, 0.10010614165014799, 0.014754233848033173, 0.10172844774300054, 0.13078178068803203, 8.435628741018235, 45.792899054865686, 56.78618477236841, 48.243395897649954, 26.7223293935099, 36.87522572855796, 42.17522644227551, 51.54817319685414, 22.72156673092996, 1.4685133291829018, 0.13726935030952578, 0.34011435604864554, 3.0569440559033425, 4.9977869949033185, 7.135513549850834, 8.551360234137505, 3.240145954393572, 8.416679770715776, 20.298275447660878, 39.138350948210686, 53.01606532066099, 56.61565972912697, 54.53391667335264, 55.277060693310155, 51.763597611458074, 50.25527369591498, 45.72065684103197, 40.994616554629424, 39.09081574409239, 38.5344785259616, 44.249069844522786, 46.97207727739888, 48.974741428129136, 51.30251123059181, 51.97013001288138, 53.61104965209962, 54.28564633092573, 53.583510691119784, 50.43818950653077, 51.510969515769716, 51.051044156474454, 48.67119312286378, 50.27377159364762, 53.84457972741897, 52.266790636124156, 53.24372753020256, 50.292814700834214, 53.48920514506679, 50.80846517316757, 49.80019246378253, 43.01906554929672, 38.14537548249768, 40.22972299206642, 37.04909655355638, 37.60459046210013, 37.90363980877785, 38.7277925399042, 39.770856672717684, 40.35294032865956, 38.76405877451743, 38.28543547661074, 37.173745555262414, 38.09878164722074, 36.463808321183734, 39.18775712290118, 39.80200813662621, 46.789667452535326, 50.052361642160726, 53.38825902631206, 46.32984015249437, 49.94926606455157, 51.82592799586635, 50.572369867755526, 50.09433884774485, 47.63278484344483, 46.85895612162929, 43.86129648454728, 40.29977260097381, 38.508481056459495, 39.21759067043182, 38.492756274438676, 37.273585565628544, 38.87142581324424, 38.25216201043899, 37.97899638452838, 43.132069033961145, 50.247954553173436, 51.845245668965006, 55.30790621234525, 53.102024062987304, 53.803594881488436, 53.072327798412694, 53.55435179125879, 54.55671741116432, 49.42862241498886, 47.74437627484722, 52.50696520651541, 51.213724459371264, 54.557019433667584, 53.78936452250327, 56.16206115291965, 54.552002722217196, 55.293244392641135, 55.19103134832075, 54.84587846263763, 51.296121689581106, 51.627514900699744, 44.551417904515425, 40.8689320471979, 39.329986187719534, 41.49067871032223, 49.0073206347804, 51.39960950420749, 56.83326105917654, 57.242219140452725, 47.1824889029226, 58.98523415288618, 58.954572985249186, 56.095690727233894, 54.94045465223251, 55.76639990652762, 59.30531917079803, 43.580266506441184, 19.876442186294064, 4.950739145278931, 5.3899279140657, 8.389060401147413, 4.593183234814675, 0.5642396908613944, 0.052551329511428074, 0.6979635249703162, 18.908575773239136, 55.00968056340372, 48.84722909619732, 35.43693573244157, 38.173208621240434, 57.988591271062056, 51.870188020890765, 22.664566847585863, 0.9868793670208225, 0.08531767229038863, 0.007874023097927773, 0.06038980708727914, 0.08522856860391556, 0.04150220042755527, 0.0825702588284208, 0.038300052495493044, 0.06678355392068624, 0.043037494253968044, 0.02858195904522173, 0.07617087358789099, 0.029346286882496173, 0.043325585448333336, 0.004216941034105877, 0.04216376714588654, 0.030720215778978124, 0.14736980590368473, 0.1777032717701889, 0.27872386959291273, 0.14435494348647135, 0.1160546136839736, 0.14508628166250645, 0.12864793470549968, 0.13212217408562862, 0.23617145455171987, 0.26926626901953454, 0.1737188178324892, 0.13105196457716728, 0.131663394671294, 0.16350590053104586, 0.13092117804673412, 0.19317576571577982, 0.23482887014265985, 0.12204694576681623, 0.12915742914042166, 0.24793971420055438, 9.9295546162513, 51.57995223999024, 63.56137321841333, 55.53128519365865, 31.669920836725545, 45.473794629496915, 48.32930364916402, 55.764281826634566, 25.447000149757635, 1.6584809484981722, 0.2575919164284583, 0.6737235837405728, 8.818944327292904, 6.599510388989603, 12.442855469642147, 13.609186949268466, 3.3634652726111876, 10.4581626384489, 19.3472340414601, 39.50237435679282, 54.33083988005116, 60.446364110515965, 56.9080763478433, 56.46228328827889, 53.23164270770166, 52.64953551753875, 46.41245311306369, 44.151908812984345, 40.71476328757502, 40.70595756653817, 47.38504794336135, 50.97810768312024, 50.23088439818352, 52.84076283054968, 52.62004713858328, 55.87166455484206, 54.746203191818736, 55.99326195255403, 52.1154655948762, 53.538352443325905, 52.95167176954208, 51.02477604343046, 51.58179183160105, 55.26546616708079, 54.08017296944895, 55.217923118222146, 52.631504381856615, 55.433892742280044, 51.99228748198479, 52.0079416613425, 46.87091935065485, 39.063759234643754, 41.56644321257069, 40.19264874919769, 39.18712169893327, 39.48562191378686, 40.60963984458677, 40.461158521713756, 42.07602185587729, 40.56716449799077, 41.031859459415564, 38.631333612626605, 40.68416880023095, 39.64051238952145, 42.05423701194025, 41.36963828917473, 49.847374654585316, 52.040199233639626, 56.26326222573557, 50.72322814695297, 52.92421517833587, 52.71593732218589, 53.02346291080598, 53.36989448916528, 51.92762720969416, 49.57084755743704, 45.90402764658774, 43.86891764979209, 40.335956465813425, 39.84764883595128, 40.11854733190229, 39.05719710934547, 40.35074380136306, 40.94251963400072, 40.85251692802676, 44.761915822182935, 52.07342955373949, 55.2137928624307, 57.44906140911964, 54.13345836823987, 56.13591855572116, 55.59019919364683, 53.74721473263156, 56.06097382883872, 51.33640835362097, 49.004119980719786, 53.434750879964525, 51.960935977197465, 55.42386324174943, 54.66338626800045, 58.39478015899659, 57.332143399023245, 57.3047338762591, 56.2131735586351, 57.566206916686035, 53.3252186929026, 55.02516215847385, 49.692605772326075, 45.11685109907582, 40.86141678594774, 42.92284588659964, 52.08059180167414, 55.07563129548104, 59.43542026704358, 58.8661039260126, 47.19201241770099, 59.161666285607126, 61.083345259389574, 57.83185335897631, 56.92138887220814, 59.36349576519382, 61.415303291813025, 43.95562556482131, 19.57501784447701, 9.560643934434461, 8.943176577168128, 16.133484167437402, 5.211469877150751, 2.085358745628788, 0.3991842089641479, 0.9816720528948693, 21.201528656867243, 61.82760323247602, 57.804588963908536, 45.910189690128455, 48.57684835310906, 68.52601128239786, 59.201497954706994, 25.45447030375081, 1.1976017178066316, 0.21083933241184682, 0.111980872198699, 0.11461442967336025, 0.33093037143830334, 0.17080039056318422, 0.161579679697752, 0.18496888028758188, 0.14659447895903743, 0.16357020595140997, 0.11378356135420262, 0.15717072111945, 0.12092146301461805, 0.143082456122483, 0.044023422599439664, 0.18863320140348327, 0.07871007967379787], [0.031909446622575485, 0.09213492785009647, 0.07378083248172077, 0.008157442113564861, 0.02739174186342186, 0.037366424972612056, 0.07714368267765931, 0.04340960231098918, 0.06618231279595245, 0.0382307828253796, 0.06324266489114493, 0.021363120195606065, 0.08039747259669727, 0.04712682945894138, 0.020994308231879148, 0.041320492032795184, 0.01950204556417321, 0.02541683614253998, 0.010917142668228236, 0.03059254722639678, 2.4600370276358823, 26.872799358060284, 45.58779439618511, 40.47855423342797, 35.849969156326786, 30.923066254585024, 35.01009164317962, 43.40881970620925, 30.62463075883927, 4.742562290160887, 0.1082763544494106, 0.13267855310151655, 1.5020415042677235, 5.457434356212617, 5.885159017578249, 7.094756201390298, 3.829725995179146, 5.427465486911036, 17.2092677316358, 37.08597860028667, 52.75064637584072, 53.28532426587997, 50.63717526774253, 48.411673422782656, 45.314695450567434, 43.48219940739293, 39.47037958329724, 39.15932778389224, 39.56566179952314, 42.9736876487732, 46.05971044109714, 48.557165899584376, 52.061717356404955, 51.60019167007939, 53.43611194241432, 50.561430377344934, 49.74777783116987, 47.21982986696305, 45.9569247307316, 47.537992923490464, 49.83260300851638, 50.9810886844512, 52.8928989748801, 51.850615393730905, 47.8085893969382, 49.45548280592888, 53.40732566771969, 50.76196155240459, 50.55620578027541, 49.32570334403746, 48.7553358078003, 41.89833848707138, 35.52217668102634, 36.945667574482584, 36.11417216639365, 36.539047225829094, 37.52418579593782, 37.50406795932401, 37.65227863865514, 39.05068597485943, 36.407702738238925, 35.654627277005105, 38.01126180156585, 36.510943443544456, 38.14774459408176, 40.5102312949396, 46.09017156785535, 46.45930974714218, 49.89587083939583, 44.9646278350584, 50.12616103695285, 50.62874217187205, 47.731887448218565, 46.73933952085434, 44.55259853793729, 43.168935391210745, 41.93124325044694, 38.68841194337414, 37.72192816580496, 37.51718044281006, 36.888848120166415, 39.095491209337794, 36.627971280005674, 36.655447483062744, 37.669897925469186, 38.57106247255879, 44.92241136489376, 50.64650658638247, 53.18309945444907, 51.507525674758426, 50.13388418382215, 52.91867679165256, 54.41031494448262, 51.98238349729969, 54.35044388617239, 52.445383994810044, 50.45912711851059, 49.94723035443214, 49.939868065618704, 51.59252735876268, 54.58180096841628, 56.10272745932303, 54.22023296356202, 53.758185602003536, 52.5199443294156, 53.78171590066726, 50.279317825071274, 48.407911869787405, 45.97759169916953, 42.01971230968353, 40.64779666162307, 46.434657650609175, 50.54246179519161, 52.44530162503643, 57.26387062380391, 48.29832869191324, 52.95258175942206, 54.58627247041272, 57.58789762373894, 55.78192464766964, 58.01844050807338, 50.79340719407605, 30.458010435104374, 9.829124289174235, 2.255136822500537, 3.5882136514109955, 3.212539577676404, 6.658925962063575, 0.20112872364059572, 0.10122823829372084, 0.9766645957866024, 15.422421213119263, 45.52070617675782, 40.13741393243113, 37.69822136048348, 39.0585817060163, 55.23481676655432, 39.34895869224302, 13.73996171259111, 0.16039863258840578, 0.03179637970583093, 0.0491273723122093, 0.028127938952116717, 0.019151282631942344, 0.04121853722139232, 0.02882059734885491, 0.0238046002754521, 0.06686171021072135, 0.04384241134469067, 0.02744864878965722, 0.035771835940859975, 0.06475732030887758, 0.04656072112641508, 0.017225387386016307, 0.025712553742191484, 0.061944888964776075, 0.061963355514190854, 0.05440540784489244, 0.06845244582021429, 0.05603772287647571, 0.06965850570028828, 0.006355626298294914, 0.10539830001371522, 0.04942026304742021, 0.08734578281761178, 0.03873026832157085, 0.025195030705823053, 0.06273602796418053, 0.025373088691623944, 0.04843547234251615, 0.033200442670814456, 0.08763750143829854, 0.0334221983118163, 0.06404465169555719, 0.00585880822449502, 0.036141021372449976, 3.6846441415048417, 32.601022874155355, 53.1340306035934, 45.45455148143154, 37.59704774425876, 34.37801737939158, 39.401490995960856, 48.527340196794086, 27.760368970132646, 3.8651067547259794, 0.08308130842182906, 0.11755023181678788, 1.4180859899328602, 5.0043363724985435, 8.115509402367378, 11.085254511525555, 7.785872432493395, 8.23023872990762, 18.342740535736084, 35.61725493400328, 55.812491678422504, 54.151709156651656, 54.47448099813154, 49.51917033041678, 51.260483034195445, 45.85498625232328, 42.01739026654152, 41.08444275394563, 41.721098346094934, 45.961729634192686, 48.96180545130084, 50.42492405060799, 52.50377631956532, 52.140906087813846, 54.75020793176467, 53.24995233166603, 51.02627438883628, 49.151773683486454, 48.1295177244371, 49.82198907483009, 52.15507761124642, 52.9006495783406, 53.98537712712442, 50.610275653100786, 50.340946105218705, 51.26008687480804, 53.99980752698837, 50.659517088244044, 53.98765994656471, 52.17484243454472, 49.762906412924494, 42.88421054040232, 37.29437804991199, 37.96604864058956, 38.944774135466545, 37.34725552220499, 38.80721661352342, 39.551572645864184, 39.66518802027549, 41.370309014474195, 38.44103982371669, 37.53473697170135, 40.83654111431491, 38.3324803844575, 41.68430651387861, 41.326770705561486, 47.51713375891409, 49.344711149892504, 53.61389729284472, 46.83740661990258, 50.527231231812515, 52.52311360451483, 49.323828451095096, 48.20974196157148, 48.41550165607084, 45.77918644874327, 43.39270660954137, 40.25968990018291, 39.987787277467795, 38.59993111702704, 38.82489081351988, 41.408532511803415, 39.162116589084754, 38.625289240191066, 39.09000381346672, 40.411728812802224, 46.19693063920545, 52.03378223603772, 54.517132851385306, 53.09233580866168, 52.446839194143976, 53.508118814037694, 56.32338431573684, 53.779229117978005, 55.05077915806925, 53.31414976427632, 51.578218552374075, 49.500652820833274, 50.968231155026345, 52.47297002423195, 55.65580083477882, 57.67235017591908, 56.094533628033055, 55.27611540209863, 54.78343825186453, 56.443906984021595, 52.526922225952156, 51.143066883087165, 47.26459980010987, 41.87146632902084, 42.32494723412299, 48.27852464491322, 52.63396763032483, 55.036772374183904, 56.55337641316076, 51.55604931616014, 54.377731815461196, 58.32812340028825, 59.927312943243216, 58.423970437818966, 59.386622059729795, 55.96432662779286, 32.54560762836088, 12.714900278276014, 1.920395132995421, 6.902771870936117, 7.036154520127082, 3.8717429147612665, 0.6310863168008867, 0.1030760347062061, 0.8827006023737692, 18.67117431855971, 50.855160990068995, 47.25164028906053, 42.34439042306716, 42.80093862164406, 61.06320388855473, 47.39711315401139, 17.54876259834536, 0.5133324128485496, 0.02440843460780959, 0.059962035081679785, 0.0240218551498988, 0.015604364490436931, 0.03351634668727075, 0.03961911417483803, 0.046219712408680114, 0.02131042100729481, 0.0832197328488673, 0.047409113706840623, 0.030410699020590515, 0.024529555023858146, 0.046688945092741525, 0.05073217329599204, 0.10067844763398172, 0.049698709194818814, 0.12654180578406782, 0.1433581098793976, 0.19303074527171352, 0.13579648498806263, 0.13999441698674234, 0.11468870955849848, 0.26373535935436526, 0.2194868716140909, 0.18169131099937424, 0.19166105667189245, 0.15714355564165502, 0.15381617531661065, 0.1714891648941463, 0.1018722807507842, 0.09207568627091185, 0.11687104124575855, 0.09601350077578137, 0.13957581122315701, 0.11272193969137247, 0.1555623654876986, 4.038435557196218, 35.72309617073306, 60.25056331388412, 52.2243074447878, 47.45487789953909, 40.86764550978138, 46.040730091833304, 53.970683928458925, 37.53303074067639, 6.172664338542569, 0.19985150185323533, 0.45795283610782317, 4.615082808079259, 12.840138616100436, 13.108920012750934, 17.429449981258763, 7.426275908946992, 9.829186066504448, 19.609301320968136, 40.97018018845589, 56.492720880816066, 59.039080450611735, 56.63101973072175, 53.32419495428763, 50.322259933717795, 46.27449943173317, 43.652916646772816, 44.436731723047075, 44.63136365336757, 48.275021968349336, 50.22445171110092, 52.783935531493164, 54.58281686229091, 54.26562263119606, 56.98366042106383, 55.84143092555385, 53.819127467370805, 51.099477583362216, 49.076558313062115, 51.75864365793044, 54.96728366421115, 54.6486303114122, 57.72484717830535, 54.18098572761782, 51.90688963859312, 53.58621712653868, 57.48380968647619, 53.054492781239176, 56.133270955854854, 55.63519662426364, 52.22585285863569, 44.945812225341804, 38.46661367724019, 40.50161777004119, 40.701380160547075, 38.83583030393047, 40.619210427807225, 41.32100089903801, 41.81005377923289, 42.157281598737164, 40.766668012065274, 38.559507170031154, 43.15195152836461, 40.74936251486502, 42.57827743407219, 43.56770315477925, 49.26411820996193, 51.003599166870124, 53.76832885126914, 49.92532783938993, 51.83434932462631, 53.94141127986293, 51.396765785832564, 51.81765963954311, 49.212546886936316, 47.91430904019264, 46.35183680442072, 43.32508887014082, 42.38670103011593, 41.148346008793006, 40.018381764811856, 44.77130597637546, 40.23810901949483, 41.36992462219731, 41.49025901671379, 42.94625851415819, 49.10670957257671, 54.90363144105481, 57.045575034233835, 53.54380061549526, 53.361284886637044, 56.42876271278628, 57.41727452124319, 55.186665750318966, 57.559554576873786, 56.751675759592366, 52.853141830813506, 53.54540094252556, 52.03827727225519, 54.27353797420379, 56.301426887512214, 59.49016086516842, 57.671177387237556, 56.13076848368491, 56.92012979138283, 59.02744670068065, 55.98302848877446, 53.371549729377996, 48.141594702197665, 45.755973862063506, 45.497481822967536, 52.503317402255156, 55.30607838784495, 56.90337342600669, 59.43349830565914, 50.0629206626646, 53.760829279499674, 59.18333738080917, 62.34355180494247, 60.38930146924911, 62.767940490476555, 57.340270550020286, 34.46576864488664, 12.980539856418488, 4.207570610507842, 10.589857197576954, 13.082693084593743, 12.694832451881902, 1.1314043667047256, 0.306077100216381, 1.3324937440695301, 20.756831899766002, 58.39368189534834, 52.90908267421108, 51.40712476545765, 50.617230015416304, 69.78105206643382, 53.965957472401286, 22.541398540619884, 0.732774560249621, 0.15048933125311328, 0.114259876521124, 0.3718500692517527, 0.19875052625373488, 0.10235208161776105, 0.09483377133766491, 0.14222437636025492, 0.10004854716000058, 0.18962107178184295, 0.20185788612692587, 0.1583748274753171, 0.11925715998175646, 0.15507193132033273, 0.11909194546000612, 0.19919116470602252, 0.14851116965855324], [0.034427719355951396, 0.07146745379413329, 0.044607380780601696, 0.05303134488302374, 0.08554826475559704, 0.02931582722662678, 0.039301563069344535, 0.030678749354856632, 0.021687974034237768, 0.052183814151513006, 0.0192603409936231, 0.04333543350859996, 0.09212516788994113, 0.030432567000389103, 0.04767417246776243, 0.007257103505018618, 0.0488094266714348, 0.10314553420269683, 0.07932597606052315, 0.037774228896465034, 0.6472047454407138, 17.177824051149432, 44.56729173660279, 42.220710246793686, 29.751550382183446, 29.32882085923226, 36.611301206773334, 44.4701660063959, 42.157363968510786, 10.981706880754041, 0.0918340468178353, 0.25004788091586483, 1.3490935823609753, 2.509390250329049, 7.458856586487063, 9.410719179338026, 5.703307149871703, 5.5623915887648065, 17.091869231193296, 32.265807313303796, 52.274458869811035, 51.454083381160615, 50.59163655004194, 47.885781641929384, 44.76872113443191, 45.428365738161155, 43.67508980535692, 43.54738135491648, 46.4400665990768, 46.10187984281971, 49.496801053324056, 52.785465255860366, 52.6836601380379, 50.865002216831336, 48.54079392648513, 46.15872283135691, 46.36913445688064, 44.770654862926854, 44.64409958931708, 48.7398777469512, 50.065717312597464, 50.45789549427648, 49.24498488826137, 48.311500010951875, 47.39275540074995, 48.106669918183364, 49.78717411718061, 52.505066779352006, 51.588401025341405, 51.60411011788153, 50.33456048657818, 47.356708818866366, 37.91389288440828, 35.851824437418294, 37.06906926247382, 36.914327836805775, 36.16240163003245, 37.1884975894805, 36.8323032317623, 35.58562494093372, 35.727736334646906, 34.49060509281774, 37.36616134643555, 38.22379935172297, 39.08250816406743, 40.29656410217285, 47.70972605674498, 47.01968308418028, 53.428067161190896, 46.86276866543678, 50.63181731008714, 51.59302942214474, 47.81242547496673, 48.21752786636353, 46.02209491114463, 44.4979206977352, 42.820111167046335, 38.97009303492885, 36.39728492306125, 37.360528822868105, 37.1134469586034, 36.977897690188506, 36.18995628049297, 37.10130330054991, 37.26062997694939, 36.69782869277462, 43.94126576762046, 48.90879069605182, 51.03780615714289, 49.90576697934059, 48.95651417393839, 54.96477334730087, 51.63469283811508, 50.98011201427829, 49.49898189113986, 49.12921613262546, 51.429352837224165, 52.54247834605556, 50.755018957199596, 54.02362415867468, 53.15484269972771, 54.967542540642526, 52.470695049532004, 53.59534055955949, 50.36476665927518, 50.27718797806771, 56.070250234296246, 52.153088969569055, 50.87393737608387, 47.93664693832398, 46.99547421547675, 48.94950097607028, 53.010421029983036, 52.27060710230182, 56.60483398745137, 52.9518678880507, 50.42526529681299, 53.53443791789394, 58.461946825827326, 57.46355848927652, 58.27843873731552, 42.83593793069163, 22.66581023893049, 5.685555973360616, 0.4800059946794664, 4.665737767373362, 7.7700142898867215, 3.109151538341276, 0.5218475720574779, 0.029231051936925902, 1.3752508884476078, 17.36188715504062, 41.46044508103402, 33.15681880520236, 28.24811177868997, 42.5722683629682, 52.74101303469751, 41.77936907737486, 11.951693334887105, 0.09407961140236548, 0.03984475388161598, 0.030747647472326795, 0.01587725266994488, 0.04341400731655379, 0.08234471488263338, 0.009512761776756135, 0.08445572378414293, 0.09167709072390873, 0.009302581724290167, 0.013778312526072466, 0.024167291196664015, 0.08176125465862213, 0.0853826365463676, 0.05001991070927151, 0.05758124065675563, 0.06365845528160853, 0.04418213686515247, 0.025436375215048754, 0.01244535496939094, 0.04207546785173397, 0.06649066318547533, 0.036578691234031034, 0.06633742261798152, 0.0552568111508604, 0.04555218935673756, 0.08319549382694306, 0.021656340348624417, 0.05556017430799623, 0.021684202966430498, 0.03178924934247569, 0.014228952256211591, 0.11051092567222734, 0.05163580081575821, 0.04325407114060175, 0.056991958164519844, 0.09813040089342864, 0.9460969521634041, 23.04792557993243, 51.753811297878144, 49.38495074549029, 37.28257956043367, 32.25222610658215, 40.48544191545056, 50.002123924993704, 45.88429027988065, 10.63201581278155, 0.28924005046006174, 0.0544561228654798, 0.6487891991292277, 4.117390907579853, 5.887087843110485, 10.192483836604703, 10.014936770162276, 6.924399820066268, 17.550182496347738, 36.23877802202779, 53.26748532633628, 54.28850966115152, 53.075085224643836, 50.229841047717684, 46.62300202154344, 47.15609527403309, 45.10522911625524, 45.45723830499957, 47.52427639499788, 48.61681730516496, 51.08103459881198, 52.88844316236435, 53.82207316737021, 52.54461996016964, 51.73405039695002, 49.12374050386491, 50.193755242132376, 47.33405713112124, 46.86220776650214, 49.423331137626406, 51.035829282576046, 52.508024246461936, 52.94438400576192, 50.55769235857072, 48.25511986209501, 50.21016251656317, 53.6689006897711, 55.66122155035696, 52.59707381648403, 53.930734588253884, 52.43545255353374, 48.97280377726401, 39.940797282803445, 36.58455456456831, 38.24820826130529, 37.8829885298206, 38.10509274082799, 37.82442754314792, 37.959251173080936, 37.45283396013322, 39.12728986432476, 37.29166376975275, 40.29177881056263, 39.79575587857155, 42.08440003856536, 42.255756624283336, 50.20975851243543, 50.2883824225395, 54.888192992056574, 47.84238846071305, 53.848776663503344, 52.90497987501083, 50.56788659864857, 47.82489076737435, 46.771659851074226, 47.025445045963416, 43.583726036933164, 40.70183907785724, 38.6460542678833, 38.07753024562713, 38.78349804109143, 38.04708480834961, 38.20725479433614, 39.24338417668497, 40.55510713208107, 38.71121268118582, 44.612406838324766, 49.66197598365046, 53.522341328282515, 52.447788407725675, 50.71631300833918, 56.78455698874689, 52.43538587324081, 53.31306719010877, 52.08153709288567, 51.569805068354455, 52.90973771002985, 54.915986907097604, 53.5967133891198, 56.728000333232266, 53.32424594509987, 55.572183747445386, 55.18579890651088, 54.431829144877774, 52.23723165450558, 52.425858436092255, 58.29602664516818, 55.541200945454264, 52.52670649559268, 49.598833668616514, 48.23074625384424, 49.58773336102886, 54.32267350535239, 55.4186817907518, 57.75083288069695, 52.07611637730753, 51.111315296542266, 55.69904496592861, 61.38227693496212, 61.36127264268937, 61.15078256976221, 45.91456313287058, 24.507423831570534, 6.507790175176437, 3.9833144891646604, 4.357185008064393, 8.916786870648785, 4.122390948957013, 0.3460779521734484, 0.03776118624955416, 1.4857354760169985, 18.17656343983066, 47.72292091000465, 40.43034438164004, 38.88602095265543, 49.47152529993365, 59.568255255299235, 47.16408906444427, 14.34382530950731, 0.06617930207041002, 0.07478971665184345, 0.033272186804923325, 0.0533147054844566, 0.04115331249551908, 0.08054229385790326, 0.04781613239057122, 0.03824444983394877, 0.031113439134412238, 0.03851986227316722, 0.04821354433173134, 0.011626668405839273, 0.08674736089643934, 0.042330146121281775, 0.034265768368758505, 0.006292434578250733, 0.00613265784434794, 0.12469486739005774, 0.1233015756212896, 0.21217330599263792, 0.1105578102531933, 0.21376725917141284, 0.20034034255771868, 0.15531062899578005, 0.15357701798840878, 0.09112117136077535, 0.19445251252862716, 0.1069064436840915, 0.1315146663616742, 0.13485582094759713, 0.14332293112191463, 0.1392016998462139, 0.2093055171351279, 0.23505967711248707, 0.2062692961865856, 0.2846483952335773, 0.1831980527288491, 1.4049098905055755, 26.133416891098026, 59.00706606526529, 57.858003800915135, 42.65898412273776, 40.751794384371856, 47.70738832412228, 55.38077992777671, 51.86451235125142, 13.87820270753676, 0.43874600061005165, 0.5309737629948125, 4.022430325708082, 8.808823631655786, 16.5195228592042, 18.627100606118482, 13.2123823319712, 8.60107921784924, 20.602531740742346, 39.708761630519746, 57.2558101530998, 55.4712180168398, 55.56504895610195, 52.1450912567877, 50.647087097167976, 50.09680209621307, 47.05237211719636, 47.76452156805223, 51.409995940423784, 51.782993731960175, 53.51049184799195, 54.79358934587049, 54.366859005343535, 54.440599564583074, 53.82038654819612, 51.77902037097562, 53.13610553741456, 49.815054324365434, 49.11319717284172, 52.923191439720895, 52.75157205520138, 52.86894898260794, 55.04101637871035, 53.718859918655895, 52.37687979975055, 53.07319071985061, 55.60364115622736, 57.16929051183886, 54.27075701375162, 55.47555223588021, 55.01232424089986, 51.30733966827393, 42.5219561207679, 38.775261063729566, 40.69327654377107, 39.904872294395204, 39.59290658274005, 40.44884227937268, 39.87519171930129, 38.75058151060535, 39.94875577188308, 37.940533622618645, 41.598249712298, 43.06548680028608, 44.645390049103774, 44.410577358738074, 52.03235057092483, 51.63509684224283, 57.57010575263732, 51.724318996552505, 57.58166497753513, 55.84822839306247, 51.86455941969349, 50.68024289223456, 50.23881543067194, 48.67289543151856, 45.116909934628396, 41.88988185697987, 41.156779104663485, 41.67466532799506, 40.62061071395874, 40.51104322556527, 40.37973796167682, 40.73677170661188, 42.41870364835186, 40.771104212730165, 48.889025872753514, 52.69401911766299, 56.16180619885845, 53.64666477326424, 52.01327216240668, 60.48834916084044, 54.771059251600704, 55.21446751010034, 53.83633882768693, 52.67093989156908, 56.161496331614835, 57.51578092575074, 54.20716362614786, 58.00714015960694, 55.89335526189497, 59.53836287221601, 58.30402828031971, 56.04972447118452, 53.3722714454897, 51.08219562038299, 59.56466236422139, 57.48218190285468, 55.26759993645453, 51.13453572796237, 50.87598877568399, 53.361265274786184, 59.9440340072878, 57.48238978847381, 58.808723572761785, 53.46570622536444, 51.712532274184696, 55.13953847269858, 62.291678459413596, 61.36273960913382, 63.55627413718932, 45.18226446643953, 26.11286171021, 7.927139536026986, 3.0372598863417104, 10.284590894176114, 17.566505439819828, 9.791569555959395, 1.2035090524342753, 0.24655349342332733, 2.3485985686702113, 23.407271562084077, 53.35103573337678, 46.33362131734049, 43.31238823552286, 56.64346933364869, 66.5049159142279, 55.754836759259625, 17.751490300701512, 0.3102055173968115, 0.1680848693415042, 0.08655667395120667, 0.17609900704795317, 0.11426293321194188, 0.1316645744466974, 0.11288759854411888, 0.19565727772010913, 0.10429737804036948, 0.18183748057532698, 0.17590046770149664, 0.11397091581696465, 0.22521504891976235, 0.13660979457199574, 0.09568402934218607, 0.11238814752188422, 0.21074554792815642], [0.009990803514336868, 0.08060369580503433, 0.03305740639447205, 0.08196178583368179, 0.058831476996983254, 0.040040167589341445, 0.008699174485950461, 0.04394371115091828, 0.01206237325189455, 0.06364638939680112, 0.05059232394541464, 0.06916048726247204, 0.005939668326097871, 0.0431624623466163, 0.08018661455641832, 0.06703738949351734, 0.04487316732505157, 0.03756050951778889, 0.1271146786729655, 0.09092320658026204, 0.1981939633767451, 10.717615658237088, 37.04265994410361, 43.85059233634703, 37.30103038972424, 26.31947255903675, 36.19226263415429, 43.29736163539272, 45.14909690426242, 19.895196999272994, 0.7072603390101464, 0.026431617274459814, 0.2513997043452917, 3.286416929575705, 4.093803979696767, 10.217918445987086, 12.381239937197778, 8.660268764342032, 19.267488333486742, 36.40553366753363, 56.699033629509714, 50.245514838926255, 51.02569387805078, 47.65480502959221, 50.03722913803593, 48.38663301160259, 48.710044199420565, 47.88561298001198, 48.08656777105024, 49.50105290259085, 53.25316083046698, 50.9336672290679, 49.45354123269358, 47.68896102905274, 48.89388176702684, 44.38056730454968, 40.49034095579579, 37.18779940758982, 39.70503145648588, 42.548177165369836, 46.18821121031239, 46.94216136009463, 46.78689825919367, 42.52523129986179, 41.39416486986222, 45.46917407743393, 49.848249343133745, 51.65846632372949, 52.06153692737703, 54.79709202243436, 52.60632276535035, 49.54383811643047, 41.192386381087765, 35.99851715949274, 38.64133565656601, 35.83548384328043, 35.87439767775997, 35.567307472229004, 37.71700166886853, 35.69298021255001, 38.028888933120236, 35.907639764970355, 37.09530599655644, 38.834469241480676, 39.60661918886247, 41.921378489463564, 46.71476979409495, 49.49957024666571, 52.54918167668005, 46.49097504154329, 49.554797218691924, 49.84317771850094, 48.046285029380556, 46.823670479559134, 44.02439648105253, 44.34458348058885, 40.803338250806256, 38.15951954933905, 35.72366099203787, 38.43733710627402, 36.500266751935406, 34.82544214494767, 37.56348794506442, 36.719805732850105, 36.352883692710634, 37.25140063993393, 46.14342166531471, 49.26079988479615, 51.44539140885877, 53.74206466059531, 51.07806536459154, 50.36972845754316, 49.09000419801282, 49.09088280893142, 47.75394685806767, 48.18012806677049, 48.74057985121205, 48.05829924921836, 50.303240360752234, 51.433204604733376, 48.108399683429354, 48.75593200806649, 49.434847216452326, 48.05658517345306, 52.626083666278475, 49.89567864325739, 50.27985911215506, 53.49157817902104, 52.43651159348027, 51.415165624310895, 49.54424604292839, 50.94532451322002, 51.84502601623536, 57.38032971659015, 52.26454311801542, 54.815648755719586, 57.04269601452736, 55.834013723558, 55.620197480724705, 59.14085026710265, 51.652367038111535, 35.90296037735478, 12.26370023142907, 2.0768878969454, 3.1123176265147428, 4.647734088282432, 5.495673543022526, 1.9072337424562824, 1.0024667435115384, 0.08431591273796174, 2.168145025930097, 18.924186806524954, 46.2152990987224, 39.297807062825854, 39.776312689627375, 47.84979389559838, 57.60564634876867, 34.80550473736179, 6.7441924060544665, 0.07240439464728679, 0.0642183123366727, 0.06247036399379854, 0.030506002273590817, 0.07853083808215396, 0.028734136665720614, 0.028189628182219404, 0.021026282826618805, 0.018002882359489318, 0.04765145029992827, 0.06776942480956355, 0.07090550531903583, 0.06351610465395836, 0.030350178074572357, 0.034902134624820565, 0.06767543348213358, 0.015241583553893913, 0.059435977825834874, 0.03955258709949352, 0.013460154295898976, 0.02091267390266782, 0.05035012907859299, 0.049158444838418115, 0.04342914904437719, 0.013652780401189963, 0.01059741395780997, 0.08415201588744119, 0.09239486148280483, 0.07820194121450186, 0.048171283091388406, 0.011879950480145073, 0.0601029952597474, 0.030195200402710228, 0.05753583462548353, 0.015082100327427109, 0.07092913913149988, 0.05705316092879061, 0.3285232006061462, 14.393584497513311, 45.042957567399554, 50.68573813284598, 40.30993153972011, 33.40476359090498, 45.42866383829425, 48.42073802025088, 52.588126890120975, 18.98384801803097, 0.6789252594594033, 0.04301856422135907, 0.44732449996855955, 4.93270016485645, 6.674664962676264, 10.464183476663406, 10.642920982453132, 5.817631492691656, 17.784606872066377, 41.4262027894297, 57.51349810631045, 52.96989117899249, 52.39038452025383, 50.01181217931932, 50.884508163698264, 50.2743128807314, 49.583693319751376, 49.921146592786236, 49.58765883599558, 51.71053186539681, 54.732286622447354, 53.912366128736934, 52.531028947522564, 50.20908386476579, 50.395004210933564, 47.75164834914669, 43.8982726681617, 40.56381479386361, 41.47015686958067, 45.60701793239963, 48.363083101088, 50.435471304001354, 48.77623027370822, 44.74344145867133, 44.88225021669942, 48.054078778912945, 51.550969846787, 54.52530314845424, 53.87062034299297, 55.21636201489357, 54.25611480589836, 51.331423021131954, 43.330011444707075, 37.741873418131185, 38.592168746456025, 36.99590136927944, 37.24909820864278, 37.73817070068852, 38.44168701479512, 37.421929605545536, 38.29418236209501, 39.03575351161342, 39.15772745686193, 39.547669887542725, 41.41993091952416, 43.38126113337856, 47.918796231669766, 49.8374314461985, 54.91357464944163, 48.15579368222145, 51.86357882715041, 51.982132465608665, 50.876855619492076, 49.53592669579291, 46.85089565092518, 45.81437010918894, 43.44094784029069, 41.44444965547131, 37.64418678898966, 38.330844756095644, 38.044307770267615, 37.62420231296171, 38.70083408970987, 38.313303916685044, 38.95171673067155, 38.74307017172537, 47.23023591503021, 50.140595359186975, 52.15729375039378, 52.99645739216959, 53.300437158153905, 53.49931701537102, 51.689606020527506, 51.938864800237845, 48.678904502622544, 49.85977326670001, 50.31896906514322, 51.2794320044979, 52.93173828432637, 54.1700933056493, 50.70671889089769, 50.14568659567064, 50.91835429591518, 51.102191863521455, 54.463294398400095, 50.65367275668729, 50.80837495865361, 55.00355382119456, 54.35511935141779, 52.64660158464986, 53.02902483171033, 54.04567572378344, 52.86403033041185, 58.81805489140173, 55.865635871887214, 54.59067729211623, 56.750216637888265, 56.16298683228032, 56.58355512926656, 60.2104845354634, 55.39063292164957, 38.07534940781132, 15.512344491097236, 3.220324747024044, 5.687536770297635, 6.157416614793963, 9.859789379181402, 5.44826042267584, 0.8578555742579123, 0.04342500067826721, 2.484533209954539, 22.026424677141254, 51.063038764461396, 40.039723380919426, 39.704537237844164, 54.091740039087114, 63.42622010938583, 42.94551718619562, 9.461070645240046, 0.09156954730109823, 0.06741786706111125, 0.025510051805946617, 0.010828521617147471, 0.061934975787035884, 0.028368946382655736, 0.00992309857880877, 0.10154593495591994, 0.029117058053792968, 0.010478150347367892, 0.05357705612456607, 0.025334642569143927, 0.07873965066767509, 0.06806075272540893, 0.036180869435831424, 0.08445495003533941, 0.03713265324251787, 0.18257427329738296, 0.17162365929013298, 0.0525469130145446, 0.21755249960528267, 0.17420244913908745, 0.14105721076409664, 0.13427783825224446, 0.10909251388042204, 0.11252218226511633, 0.20511507747634766, 0.18209323136796876, 0.1108217581866249, 0.11423067324945044, 0.11470604612822495, 0.1817779402218519, 0.17493035524122177, 0.2459954136922475, 0.1620677543143111, 0.14251832429680134, 0.2033108638058747, 0.3487091271146652, 17.045093005703343, 51.75616864235171, 59.59056569683937, 47.84192562103272, 36.399681491236535, 47.332021421001805, 54.343097286839644, 56.9408046045611, 24.327477255175193, 1.2650663621963993, 0.3272833639094907, 1.1711714392708195, 9.465243066510848, 8.717787381141417, 22.1017655634111, 23.440825477723156, 12.609170829096149, 21.88817289567763, 43.20920244339974, 59.486281641068004, 54.299986516275716, 54.52866069732174, 52.83249055185626, 53.77720125259892, 54.3547781052128, 53.022564688036525, 54.359732058740434, 51.97000449703586, 53.17920061849779, 55.84041895404939, 54.492017915171964, 54.89442171589021, 52.81211383881108, 53.59983559577696, 49.08761939694805, 45.30037487706831, 41.3856101805164, 43.458233725640085, 47.80594179707189, 50.71936068996307, 52.361782596957305, 50.373376261803415, 45.28378717360958, 46.31024791348366, 49.64336825955299, 54.28739178565241, 56.56086421781971, 55.73900607324416, 56.07899319741034, 56.510175428082874, 54.71052531273135, 45.72365745421379, 39.04738726154451, 41.92042535351169, 39.252487997854914, 38.139884164256436, 38.75128753723637, 41.58089714665567, 39.92061668826688, 40.52364187855875, 40.54702704952609, 42.040304753088186, 43.38780756919615, 44.30802699058287, 45.77196536525604, 49.92993270197223, 52.5011718657709, 57.07136069574664, 51.45352248222598, 53.57004519431822, 54.18618286809614, 51.813603908784934, 51.145455606522106, 49.76934694474744, 48.39972588323778, 45.24957626096664, 41.92361816283196, 38.83638335812477, 42.252069596321356, 40.45997788829189, 38.50299366058842, 41.27334802381454, 40.38562936167563, 40.61641770024454, 40.86903795119255, 50.46893304394138, 53.774875287086736, 54.76743105919131, 57.00464510148572, 56.6000408511008, 54.40577283982308, 55.72220263942596, 54.569461191854174, 51.45114552590155, 52.078995397014005, 53.27272169051632, 52.26386847034578, 53.996587261076904, 57.17927686629757, 53.146613567106186, 52.73202688463273, 53.675929577119895, 54.940446807492165, 55.349726523122484, 51.125420139681914, 51.32943830182476, 54.83334256756691, 56.17125911097373, 55.94931179477323, 54.56340505230812, 57.07153720240439, 56.363769039031006, 60.27053602280156, 54.74001761405699, 53.976512570534986, 57.73518654607958, 57.82318099852532, 57.79379460119433, 61.680620255008826, 56.11858952429987, 39.1005628339706, 15.637724034247862, 4.091700608691862, 5.047052944860151, 11.234654649611443, 10.54563835743935, 7.029509044462635, 2.066381092994444, 0.20647865269453297, 3.141875872688909, 25.438098330651563, 60.17550876063686, 52.29919725848783, 51.528459364368075, 61.48210910058791, 72.0307823919481, 50.81372899393882, 11.123978111051745, 0.24096569406890103, 0.14345592398556972, 0.20835605840529167, 0.07376650663753671, 0.22115127423838263, 0.07295306681865647, 0.07026269626353057, 0.15512981692389136, 0.18332827235421828, 0.11524157223081398, 0.2427744429798857, 0.14206320678274478, 0.13785850256681442, 0.1599702821864236, 0.12886771000921726, 0.18638232782963784, 0.11379124521608315], [0.03819522868481375, 0.009656164817692292, 0.03910192438671666, 0.04784297228099839, 0.04848016974245829, 0.03748206977522181, 0.03778759713074373, 0.03386226985903998, 0.022907507485680045, 0.018101941358538407, 0.013881653956618282, 0.07161799773213363, 0.053496908005927844, 0.058213416411871874, 0.0334125685866081, 0.05359328569724195, 0.08405577992239306, 0.026489966361212636, 0.02785576514959816, 0.03624203389570598, 0.053088556329209, 6.541234264450689, 30.371555512951268, 47.2761707921182, 39.2922882879934, 23.27610750352183, 34.01801440023607, 42.68493844616798, 51.295874580260254, 25.171855688095096, 1.6835457519177468, 0.21241114564961006, 0.19992529144210203, 4.3226853109175165, 5.097284288175645, 5.0586710053105515, 4.994679497134301, 3.919082735815356, 18.28655062183257, 38.663159724204775, 54.318582473262666, 51.315557033784934, 50.734450048015965, 51.26728442407424, 50.46719151158487, 52.46314448695029, 52.6627617497598, 51.32634747412897, 52.34026839656215, 51.45746054187898, 51.254693615821104, 49.702199889767556, 47.520961992202274, 44.999332966343054, 40.89372927142728, 36.64768119012156, 37.106516130508915, 34.561011637410815, 36.38790653597924, 37.993211054032855, 40.06438332219278, 41.442406100611535, 40.520009763779186, 39.24535320651147, 37.949590375346524, 41.90640288014566, 49.348574684512236, 49.983904515543294, 51.594088462091264, 50.955338324269945, 52.71325049861785, 49.47799721071797, 41.98096321475121, 36.335731167947095, 36.88479631177841, 36.23903689845916, 36.94079206835839, 34.986981038124334, 37.694808898433564, 35.616007620288485, 36.90604771337202, 37.49735286158901, 36.09951819142988, 35.678726319343816, 40.49588326484927, 41.70552261414067, 45.97313588665378, 49.86670801716466, 50.39212519122709, 46.85038966517295, 52.707861162001095, 50.41474942238101, 47.6267679276005, 48.460628524903335, 46.90928405331027, 44.500729114778586, 42.61510848999024, 40.20997385824881, 37.590348336004446, 37.432606297154585, 36.77737828223936, 37.32259558093163, 35.89664536137735, 37.25389134499335, 35.797342715724824, 40.37521939123831, 48.5717845732166, 49.85296403208087, 54.284638281791445, 52.249485138923895, 52.57400243513046, 51.3811900538783, 48.55275323314052, 44.25027793453586, 42.52675710185882, 42.63957231275497, 43.474954789684666, 45.46881714174825, 46.39808154875233, 45.67709499789823, 46.06767285254694, 43.89961411876064, 45.554501318162494, 47.91556419864778, 50.613578288785874, 52.12410265399564, 51.89429883033999, 51.60459256941273, 54.798013779424856, 52.24354274811284, 54.08083977237825, 51.52632559499433, 55.16418664686142, 50.12601983162665, 50.67218634390062, 54.981270836245635, 55.74883553289599, 56.96972031747141, 57.26952275922222, 55.724454079904866, 44.13364233509187, 21.358452881536177, 7.49227027739248, 2.029067340397066, 11.206799937832741, 1.6201984930423, 11.881592735167473, 4.04935224883018, 0.19352945318866163, 0.156357258317932, 1.9911418206268743, 22.240966558456424, 47.79119368522398, 42.31481967433807, 38.71036937159877, 47.198982469497196, 59.55759425317088, 29.97458027255151, 4.3497967335485646, 0.03529560504361026, 0.061144936123802784, 0.024476447893727212, 0.05024080067091892, 0.046232368181189226, 0.03597180404129528, 0.04567937910436623, 0.01780079219550375, 0.034356454026795206, 0.05369454719907334, 0.06072158827596615, 0.055814404416108326, 0.011151762840698564, 0.03372935743461694, 0.009542144121482007, 0.01281465627177949, 0.054680758997076945, 0.010967728411478382, 0.00522758050318507, 0.020495667347624417, 0.08645513665772254, 0.032789064946794705, 0.036273864848959836, 0.01123325927408352, 0.08326400507001147, 0.027850701308418668, 0.03233205902600481, 0.024113869970484127, 0.05774443270638586, 0.026624782514127514, 0.06302233417368223, 0.0502791318802103, 0.02511897732714011, 0.01383341340002634, 0.04144687355766374, 0.0801736523487395, 0.03313665435979924, 0.020179477963416327, 8.127425562950874, 38.057628139372795, 54.22421024691675, 46.8671577976596, 23.934912720034202, 35.83076523196313, 47.462165663319254, 54.85895564479213, 27.372132770476806, 1.8564437065393695, 0.11474082651998728, 0.2227137871687451, 3.2759172349206866, 5.276245859361464, 7.085383207567277, 6.995936007268968, 5.176534306618476, 17.802283033247917, 43.188900255387836, 55.09658851931172, 54.51255936776438, 51.97893181154805, 53.73751471119543, 51.41305146678802, 54.17290172269268, 53.2149177212869, 53.260036745379054, 54.02917039009833, 52.26979909404632, 53.4235329012717, 51.447752675702496, 51.31540798371839, 49.0769858514109, 44.14214211125528, 38.86578152256627, 39.451183503673924, 36.71974297492735, 38.84792297117172, 40.70127033418225, 42.6725947472357, 43.92175982075353, 42.58614178626768, 40.91114067262219, 39.83073165339809, 43.99616718292237, 51.39796210873512, 52.72088735334335, 54.213004035334436, 53.09673670799502, 53.98618905775009, 52.32995256300896, 43.99925801061815, 38.28394105357509, 37.70303803105509, 37.77852012265114, 39.49358040286649, 37.02085941068588, 39.229950058844786, 36.819104456132465, 38.22037120019236, 40.94514762201617, 37.72118291547222, 39.28328252607776, 42.54308985125634, 44.61028091369137, 48.57438510464084, 51.62982125436106, 53.48175264173939, 47.92884534405124, 54.669332581181685, 51.79507463209091, 49.451070139485026, 50.68933886866416, 47.76796148669335, 45.83505668947774, 44.04276101819931, 42.13362578422793, 39.275571146318995, 38.89669764426447, 37.78433307524651, 38.94551154105894, 38.59269434405912, 38.84402413522044, 38.852978906323834, 42.184785258385446, 50.79252466078728, 51.84089183807374, 55.03321870680779, 53.93788506907802, 52.450102606127345, 52.11839168302475, 51.66986080908006, 46.11779682097897, 44.130728014053844, 46.25636631442655, 47.27424490836359, 48.61824504790768, 48.963849006160615, 49.047105235438195, 48.76846398076704, 46.141687977698545, 48.362145654616825, 49.68325876420545, 50.83233671803629, 56.22775693093577, 52.3681446813768, 52.965443211217085, 55.00092583317911, 53.95794799250942, 56.29277413891208, 54.077811702605224, 57.075451727836366, 53.00420799563008, 53.35640938051286, 56.72544294787992, 57.85059836602981, 58.50827393993255, 58.90559434890748, 58.045324433234434, 46.0475314817121, 25.64049851509833, 8.69494741962802, 2.8964399330077635, 6.344425908980831, 7.403537929058076, 7.976648672934502, 3.364076917209933, 0.38176407436690024, 0.11319750409212806, 2.4112611288024537, 25.1345068793143, 50.58405853086903, 46.40409061985631, 47.69673908910444, 52.604926401569, 66.12836837768555, 36.736326756015906, 5.6455046515310965, 0.07266042123158133, 0.028526605362252846, 0.04764792629547658, 0.015134583095899753, 0.055140580290988575, 0.017363467073488622, 0.02591321132175865, 0.035454369105038144, 0.028418389697288795, 0.0683528850335748, 0.020849364396605282, 0.09125788741174246, 0.021720090355243415, 0.04700425156061688, 0.048497303298884825, 0.010441321628018013, 0.03059253765029773, 0.11927428204686412, 0.06445824724411772, 0.13850964665893586, 0.20075081246754817, 0.17757288360547635, 0.1780727253325524, 0.2000851127048654, 0.10570786848303773, 0.07597318459903041, 0.23123067773638234, 0.10217064135377446, 0.1425875480016393, 0.2974651994243745, 0.1289487314680892, 0.17981718414493147, 0.15089578686221955, 0.16570786705180524, 0.10700375217223361, 0.16754319921376246, 0.12115711166012673, 0.1307285988643285, 9.260850318016546, 43.74255849469093, 63.17952655976819, 52.719024227511504, 32.39408254623413, 45.53115537089687, 53.126699693741344, 60.28134607499646, 31.773087016997803, 2.550539835806816, 0.33446436567652615, 1.7428619174226638, 9.69042927988114, 10.695179700851442, 13.53341950524238, 9.985303263510428, 6.675402368268659, 20.49508233224192, 42.513256303725704, 58.176304140398585, 55.91499890050581, 55.540753795254616, 56.41025697031329, 54.624139032056256, 56.62708167106875, 56.113196265312936, 56.70825512178483, 55.89249626282723, 53.9124837998421, 54.97445767925632, 55.54254239605319, 52.864214681809955, 50.4352085051998, 46.48125933062646, 38.975058755567, 41.096037280175, 38.56065642449164, 40.408218291498, 42.62969970703126, 43.413946244024466, 44.74623418623402, 43.61641114757907, 42.348344172200854, 41.70822904955956, 45.12209138562603, 53.49949744439895, 55.769722154063565, 56.11105072882868, 54.14816725638605, 55.02404820534491, 53.860775193860455, 45.79866493901899, 40.691268290242846, 39.433242582505756, 40.45385114608273, 41.80114999894173, 38.193585334285615, 41.40042497265724, 39.66149706994334, 41.529212074895064, 44.06287885481312, 40.22006611670218, 40.811685054532944, 44.86359934653006, 47.30534145908971, 48.57587560530632, 54.87076590138098, 53.85790009652415, 51.23101034472066, 57.15913157309256, 53.342006437240116, 51.48687439580118, 52.8934794856656, 50.7957802280303, 49.31543850129651, 46.58087576589277, 44.46246247137747, 40.533224228889715, 41.53765693787606, 39.81481467523883, 41.290167147113436, 40.76373800154656, 42.400915699620406, 39.799737084296446, 45.36199923484556, 52.31183121281286, 55.03250091306625, 57.45315244120937, 54.7351146513416, 56.78064246331492, 54.7780724494688, 54.47166081397764, 48.71664554842057, 46.115604216052645, 47.586038035731164, 48.18694122375981, 50.198093383542954, 51.46604661018618, 51.70891977125599, 51.07629245327365, 48.84458934107135, 51.761546211857954, 52.24418209445093, 54.890989641989435, 58.097629239482266, 57.779768205458126, 55.86947587228591, 55.99952205534905, 56.532552549915934, 58.84704905171549, 55.80484697895666, 58.617586474264826, 54.836841321760616, 54.92612231162287, 57.73071896645331, 59.42442586345058, 60.46241837163126, 61.184962103443766, 58.967728614807136, 48.66525465442289, 24.182598629305442, 10.747564915687809, 5.257072333366641, 17.798962746897054, 10.382730557072549, 19.483563861539288, 7.80054945138193, 0.8631233786863666, 0.422667408542287, 2.9909911174927992, 31.045948228528424, 60.67562272471767, 55.4908416348119, 52.04938150221302, 59.683031651281546, 70.85385168752363, 42.407034597089215, 6.9092158348329615, 0.2334965513117852, 0.12524294201284647, 0.11166390332002794, 0.15652409694608183, 0.13709046877920628, 0.06871438660328427, 0.11383252969432263, 0.11305828293364857, 0.16194922519066643, 0.11291390600343866, 0.25088985750992454, 0.19297407008707526, 0.11899139641994431, 0.11827151125837719, 0.1722914428119698, 0.096508186731127, 0.15075885630663366], [0.04225170254827507, 0.03702591804246749, 0.06541607931496636, 0.04878855460593778, 0.010908914883921464, 0.04729900005904417, 0.02102192761676927, 0.021098576628813343, 0.07016947868490411, 0.046783200720505375, 0.01875637388307481, 0.06178980595582436, 0.08813048667845227, 0.03387112583544466, 0.04905071372406618, 0.06940814050575418, 0.03312193014989457, 0.047743407663919275, 0.04453826432807311, 0.032359615208641175, 0.014232437956267068, 3.3041896791227403, 22.361928532200476, 47.51146985638527, 42.04825539742747, 33.31008934205578, 31.620681362767375, 36.75207507225775, 48.708796885705766, 26.94173109146857, 4.337094137745519, 0.06724170514292295, 0.41634378173658926, 3.574338757222699, 5.194410998975077, 6.431380443034634, 7.484411318455973, 4.1664318115480485, 14.508146143728688, 37.292479622748594, 52.970832547833844, 51.29414089264409, 51.28442125935709, 50.698258338436005, 53.77758172250564, 53.32689746733635, 55.08862610786192, 52.91189501362463, 52.29750279457339, 50.532028290533255, 49.59575068566107, 46.434281103072635, 42.25674898393693, 38.07500816160633, 37.260637821689734, 36.28737618846279, 37.38038386068037, 38.39778000308622, 35.127519561398415, 34.15426969528198, 36.18140159114715, 36.05062192486179, 37.40929957359068, 37.96320099984446, 37.855347587216286, 37.34649850476173, 42.46254397976784, 48.90744532308271, 49.797795895607244, 50.82579028221869, 50.624984541246974, 49.79136320852464, 41.03189083837694, 36.78560349249071, 36.04148672473046, 35.54160418048982, 37.07516854809177, 35.03872102306735, 36.8071686836981, 36.73511474363266, 38.551591827023415, 37.22636415112404, 37.59282335158318, 37.10123269788681, 37.48423645573278, 40.70833452286259, 47.379391885572865, 50.04203404149702, 51.89950381555865, 45.92654597374701, 52.34368870335241, 50.7818950376203, 47.98829670875303, 47.125857722374704, 46.39121740095077, 43.52270572416244, 42.720294690901234, 38.977235671012636, 37.30825931795182, 36.78785885533979, 35.84175963555613, 35.740840973392615, 35.2329489492601, 36.64380588839131, 37.33675925962387, 41.86290771730485, 49.97474970356111, 53.203840947920284, 51.746762798678496, 51.31432148718065, 53.21793794631959, 50.05668801646079, 46.289788830664854, 39.31719533858761, 38.31813627673734, 38.63656605443647, 39.68614916647635, 39.1704124019992, 39.13188688216671, 36.51185343342443, 39.88304038201609, 38.33226073172785, 39.23823018227854, 42.75419181393039, 48.480240375764915, 47.05561983969904, 49.31901178052349, 50.29998871587938, 52.1799885842108, 51.65630117539437, 53.759934979100386, 56.808997277290594, 55.27512696481521, 54.10567229793918, 54.91481804078626, 55.153815900125814, 56.24507811761672, 60.06812603242936, 59.05488760240617, 54.66416681966474, 37.24718409199869, 16.485857156015214, 2.8701598077051105, 1.4479325303146917, 2.6666368447965194, 6.943812120345331, 7.079242737062517, 3.832059805431674, 0.5545817123305413, 0.08504090004510458, 2.174455874389218, 24.78853225708008, 49.125850739017615, 44.3675724921688, 36.50252211478449, 49.95194112100909, 50.68982132019536, 23.910690123035064, 2.7331842674363047, 0.023837580360592376, 0.01814399000948235, 0.02940670440664455, 0.04934605211019517, 0.01873023113265874, 0.0662085053420836, 0.029046252377391345, 0.05045560023356831, 0.01716893628209589, 0.09199974397497793, 0.022375620300731352, 0.028123202613524856, 0.01814300750171946, 0.08146208966331137, 0.01009821957502995, 0.047057908358833486, 0.04577315209673778, 0.05291748889571717, 0.013253222456231955, 0.02746489176887178, 0.03366110283100317, 0.04442697473531289, 0.0871808977136689, 0.0742850409099652, 0.015999270366474746, 0.010501591680240969, 0.025462224936833786, 0.017706534652520093, 0.07100606201997689, 0.030758841932120345, 0.024110164020150423, 0.03875548793603817, 0.03690680669200036, 0.041300106433130084, 0.03263911472693567, 0.011967482728763454, 0.03068193819584145, 0.09508163908556586, 4.162371177827159, 29.338005088990737, 53.48703215199133, 46.649842800632605, 34.55868567189863, 37.61336088180542, 43.44936916905065, 55.043173682305124, 29.617460235472652, 4.268837052006876, 0.10638102994210298, 0.32090004353273305, 1.8647056890110818, 4.746648419287897, 8.014784407231117, 6.604928162790115, 3.8838681867045746, 16.53428469934771, 39.149388497875584, 54.04901366080008, 53.09868220360049, 53.50924453427715, 53.9689306289919, 54.58771198026596, 54.14434294546805, 55.619734641044374, 54.7642304051307, 54.97741906873642, 51.46481890832224, 51.898950761364354, 48.9914938711351, 44.619788738989065, 41.02459130748626, 38.71225210928148, 38.90573870751166, 39.64053592374248, 39.29053498852638, 36.72535196427376, 37.772020755275605, 37.815002087623846, 40.29825072134695, 39.00476286488195, 40.342981430792044, 40.29747016968266, 39.548987803920625, 45.89449628706902, 51.6792352737919, 52.35887219828945, 53.620804586718165, 53.63065758059102, 52.11428496145433, 44.05459480900919, 37.01569364916894, 38.8201839693131, 36.83523324228103, 39.751103616529896, 37.032297042108354, 38.77333125760479, 38.184081431358095, 40.28560107754123, 38.233232651987386, 38.66275572007702, 39.594840311235004, 39.809919557263775, 43.18303238961005, 48.622563577467396, 51.98774537732525, 53.89115787321522, 47.798920754463445, 52.740448213392696, 52.70792391992385, 49.86604905897572, 49.62949091388334, 48.49595731304538, 45.38177582525438, 44.85925336037913, 41.148616652334894, 38.58159011410129, 39.24900101077172, 37.107084874183904, 38.11436914628552, 37.23834699200046, 38.12945458196825, 36.94043905504289, 44.76783860114313, 51.4934169092486, 54.718091564793745, 52.57136268000449, 52.05482967438237, 55.14490427509431, 51.89271419279037, 46.98425623678392, 43.39666428104524, 41.875043530617994, 40.41829878284086, 40.95813066728654, 41.26634659305696, 42.950094592186716, 40.52424592356528, 42.10852653749528, 40.85549792935772, 42.41830356659428, 43.863606760578776, 49.94194692181003, 50.83602374599826, 52.95120892986175, 53.335609051489065, 53.7729258691111, 53.26036622447353, 56.554921827008656, 56.929849424669825, 55.44130994427589, 55.114600043143, 58.01042710581134, 57.12526975139495, 59.01072171426589, 60.17719930218112, 60.450784621700166, 57.1662232183641, 40.50462230559319, 16.843481217661214, 4.676159014624934, 3.0482871397849056, 6.535229606013145, 7.012809063157728, 14.333360425887571, 5.7145216964906265, 0.15974506765844362, 0.13450999353681842, 2.7388903354444816, 26.675215844185125, 51.6996512105388, 47.027814157547496, 39.359027416475364, 54.94622838112616, 58.71944258289953, 28.8296914100647, 3.5529807161900306, 0.02027445945948843, 0.02958563573267912, 0.07511861351949554, 0.02001622462675216, 0.06376032965377935, 0.03788690893880783, 0.02954887500363252, 0.026202066688828414, 0.01872919308352134, 0.024652975618899352, 0.027584173573902058, 0.02982419934273968, 0.02864175029249201, 0.037097723463610295, 0.05266440025861225, 0.054665651743210135, 0.04774595107582789, 0.10475370597334639, 0.1593617785481676, 0.12781417823486751, 0.13938637300124093, 0.17179915471182716, 0.1489944485647063, 0.1383134821850446, 0.12233806683892205, 0.1421151628657695, 0.1361814135264966, 0.07341717054406482, 0.1522294080425655, 0.1631103080487059, 0.07488936936903386, 0.1112224221710236, 0.14010211362713768, 0.10663335632172324, 0.1342166891141284, 0.13150510558437917, 0.1424758830257962, 0.20094156836069402, 4.643036069408541, 34.30682636076404, 61.36441053882722, 55.23933925936299, 44.064518405545144, 43.20937502768732, 46.26394825596964, 59.45312584600141, 34.37489909510459, 5.247856724646784, 0.24470385073894457, 1.2244345295813777, 7.863167149405326, 12.684111633608419, 13.218289421450708, 16.549887887893185, 8.127492243243802, 16.160759349023145, 41.0833562574079, 54.91683021668465, 53.435374536821925, 55.59594546594928, 57.19455842048892, 56.577942217549975, 55.37736354335662, 56.80640066823652, 56.53662789252497, 56.545814083468535, 55.48809597569128, 55.26599568705405, 50.48072761104953, 45.88962862568517, 41.149004966981956, 40.024481050429806, 40.876949371830115, 42.09775963137227, 42.64698951475082, 38.314104080200195, 37.89159028760849, 40.59937500184582, 41.24083549745622, 40.6903543779927, 41.57174625704366, 41.413843401016734, 39.40738631832985, 46.86944453947006, 54.277876115614376, 54.052069187164314, 56.09475328076271, 55.866773359237186, 54.72091174894764, 45.55479941829559, 38.449312102410104, 40.32678204198038, 39.56020578261345, 41.47633852497224, 38.193514731622514, 40.54114349426762, 40.58209696123677, 42.532809319034705, 39.996600843244984, 40.82979071524836, 41.29532114151986, 41.453439727906265, 44.86053597542548, 50.28526021588234, 55.57110901801817, 55.22130027894051, 50.7077387071425, 56.82509860684795, 54.81901022695727, 51.07905380187496, 50.67378667093093, 51.064337068988436, 47.831299920235914, 48.17337766770394, 42.89507942814981, 42.50589401491227, 40.753508460137155, 38.39810948218069, 40.06349294416366, 38.25125202055901, 39.61098478686425, 38.32922873958465, 46.36080334263463, 53.09039423542639, 56.3472911619371, 53.72102898936118, 53.58836266302294, 56.518059392129224, 54.180464052384906, 49.49888383188556, 45.18170748987506, 43.18154973368491, 43.43497014814808, 42.8996293775497, 42.92102198446951, 44.775730409929835, 42.22965325078657, 44.74339831259943, 42.55777128281132, 42.82267247476886, 45.12038515460107, 51.62051346994216, 52.192504867430664, 54.49965084752729, 55.076702102538086, 56.25654712800057, 55.39767749847905, 58.05744847943706, 58.94637915395922, 56.4671980181048, 58.79252810632029, 58.847959041595466, 59.96701909649757, 60.54424293579594, 64.64779523111159, 61.87853913153372, 61.391502349607414, 40.89426663614089, 19.266113542741348, 4.664966531338231, 4.431676701191933, 10.170540136675681, 16.977865542134932, 18.680952787399292, 10.086250362857696, 1.4841768241697744, 0.24120918745475434, 3.439180990380626, 32.741098557749105, 61.12234538601291, 55.50783726476855, 48.95919707513625, 64.99986325540851, 64.14823432122508, 35.69491001867479, 4.7005046759882285, 0.17531465558755785, 0.18355786890512515, 0.11028144403450912, 0.09159745588417977, 0.4072388880435498, 0.14418565337696385, 0.11670971845066357, 0.16012331591017787, 0.10719998559403805, 0.2756217037958484, 0.09129247628152372, 0.20116062354176276, 0.11147786652849567, 0.2009979983971965, 0.11948497920867898, 0.11023677344764433, 0.0972015805722725], [0.045121835634833386, 0.034697987514758305, 0.030914149021789916, 0.08658776179917398, 0.0750601380282352, 0.033116939087067886, 0.06591824228845297, 0.02387255418955559, 0.04715518620345862, 0.060557829321271954, 0.04774526925757528, 0.06738777512744551, 0.0313099809066062, 0.018136706428542253, 0.022695477330876936, 0.01709179314334066, 0.03583821362905926, 0.061297402942493084, 0.056398722658594774, 0.02120247347310426, 0.058660543628878174, 0.9274897183622084, 15.215676023114113, 44.95040139844341, 52.97402535715411, 35.549727409116684, 27.94914480178587, 39.05570660867999, 45.18491206630584, 39.257677293592884, 7.487567355555873, 0.08171042472484612, 0.29114730295635044, 1.3619053916585062, 1.7105327618698922, 5.618525608893364, 5.176191589524669, 2.8602386626505085, 11.781049639947954, 34.21529785279305, 49.54648179392661, 55.565966790722264, 51.775823639285186, 54.45504173155754, 52.94216786661456, 51.43685240899363, 51.80015410146406, 50.42138215034239, 49.28127073472547, 47.22017503553822, 42.10414132764263, 40.08199084189631, 36.213219857984974, 34.84803107477004, 34.49887344914098, 35.87944969054192, 35.04083125822006, 35.230658285079464, 35.4146723593435, 35.39259333764353, 35.74438287365821, 36.25913120085193, 37.48711939780943, 37.34973053778372, 38.89951782841837, 40.86807697050033, 45.784054110127116, 48.05351787997831, 49.68035228790776, 52.75527869501422, 50.56958498493318, 47.79019740320022, 38.7620662104699, 35.63160296409361, 37.38679301354193, 35.16764540826121, 36.62653961489278, 37.36954635189426, 40.68350591967183, 41.359773528191354, 39.92655907907794, 41.02596413704657, 39.166431196274296, 37.4076247215271, 38.63007845417146, 40.25351216716152, 47.13488701851138, 47.01126960016067, 51.66663662079842, 44.342010405755815, 50.51461296696817, 52.60405563539075, 49.34070640994657, 49.628231833058024, 47.776888801205544, 45.53864317555582, 42.219921850389056, 41.67850925076393, 36.45395924968105, 37.9066639561807, 33.981100974544404, 35.98018007893717, 35.43422145228232, 37.97101436122772, 35.31670331954956, 42.4928129103876, 49.35286575748075, 52.65981997213056, 49.76747989654542, 49.4158511777078, 51.82769698481406, 50.34477041613672, 46.00183586920462, 39.8695788075847, 38.3064946820659, 37.48385990819624, 37.25438556363506, 36.92046634612545, 37.33966573592156, 37.2337225175673, 37.11755368017381, 35.754177031978486, 37.55774951750232, 36.69991539370629, 38.51948722716301, 42.6590782596219, 46.93454803959016, 46.744830839095584, 49.80716643794891, 50.629475655094275, 50.258737148777136, 51.2552898160873, 52.52911483087848, 52.35055677352413, 53.097089721310525, 50.799416265180035, 52.91293051935012, 53.70146420694167, 58.11630364387267, 52.47461349733415, 32.653000162493804, 9.703635900251328, 1.9488263106153858, 1.5104929862483856, 4.922543187295237, 6.747306277675014, 10.690541498122677, 1.903862342719109, 0.07142604674182593, 0.10351643567123722, 3.2803102895136806, 28.487244959800478, 41.37660441860076, 36.14217788942399, 36.75516982232371, 50.02441867705315, 44.01281764430385, 18.033445958168276, 1.3178010357003058, 0.04614851602743711, 0.07058330405984195, 0.027381874650957125, 0.04085923049358591, 0.025329040551197626, 0.01793317793447885, 0.00229458176275535, 0.07578938478423704, 0.13352983000297702, 0.05311263447266914, 0.01584662543234205, 0.038303936561269146, 0.12088896556487008, 0.08452504708041107, 0.02138419527440302, 0.032615833314916784, 0.07637160394581095, 0.11927740002471594, 0.04193341599837427, 0.013420392417409008, 0.0695806022192682, 0.03896414730397444, 0.0404745624250462, 0.0770788946219029, 0.04226909274415624, 0.032765994208955, 0.0503429546651821, 0.02429185709315202, 0.050729511140455166, 0.09882051587825823, 0.05286495824674926, 0.06192626919777644, 0.034567258440919464, 0.032953658937326366, 0.08213212548364555, 0.03120694208079048, 0.04125102317982143, 0.10895405880986683, 1.3647860048278686, 19.327677103780932, 52.39552282517957, 57.97721247519217, 40.96583027993479, 33.406497278521144, 43.929259392523, 51.72056136592742, 39.82682889507663, 8.334763030852042, 0.16992141192238178, 0.28593484071954606, 2.6178950215539625, 4.185321456001652, 6.752647074960894, 6.581871980620969, 5.332159246167829, 12.990021205717518, 35.73027410814839, 51.68455008537539, 56.34072903663882, 52.88654081283077, 54.64990900408838, 54.28921568778254, 53.777530731693396, 55.252702774540076, 51.74633133795954, 50.97978645755399, 50.183451175689704, 45.79099670533211, 42.32581800030124, 39.39565450914445, 36.42390212705059, 37.692788877794825, 37.67450671042166, 36.20602623108895, 36.65556515416792, 36.859842192742136, 38.81295504108552, 37.79020094102429, 38.22903963827318, 39.55688745744767, 38.15274561605146, 39.88316589786161, 43.01294665182791, 47.17717016896894, 51.07757899069017, 50.98221048232048, 52.325951745433194, 54.003094473192775, 48.90946534372146, 40.1088120091346, 37.39057417838804, 38.86192975505706, 37.103695946355025, 39.32755824058287, 38.380564720399924, 42.59801872314946, 44.548566341400154, 41.39179968064831, 43.389415740966804, 40.78225943350023, 39.214978371897054, 40.559304068165446, 42.83228228169103, 47.959714397307366, 49.727036337698664, 52.9368216760697, 46.963134273406, 51.94600351395146, 53.40436820060977, 50.30966520309449, 52.29673793238979, 49.23527702208489, 47.7259882034794, 44.83784506397863, 44.47897564980292, 38.71263650155837, 38.7208774012904, 37.04842975062709, 38.262615126948205, 36.067064500624134, 39.14370890586607, 36.86485890419253, 44.13048482710316, 50.71357911632907, 54.167826175689704, 51.40514396852063, 51.55993246263074, 53.23018750836773, 52.400735655138575, 48.567293459369296, 41.247221116096746, 39.81988237750146, 39.29437498892508, 39.424495697021484, 38.21189888062016, 39.462448550808816, 39.22411749439855, 38.32953076208792, 39.15433852903305, 39.55273758980536, 38.29855972720731, 40.41554527897989, 46.77889662404215, 50.277246813620295, 49.51601282242806, 51.806308300264426, 53.49386099846133, 52.199369015232215, 53.3559073171308, 54.39071093836139, 54.00053708784042, 55.14451988281743, 54.109779019509595, 54.44207437576787, 56.37033900906963, 59.617033850762155, 54.23986050390429, 34.56437703101866, 12.041657797751888, 3.719215176759228, 5.000328200478708, 8.530772693695562, 11.110242951300837, 8.092453220198232, 4.200234307396797, 0.2101724069084852, 0.05216558891979437, 3.9925685861418327, 31.415333517136116, 48.87268920098582, 43.181898824630245, 43.96873804830736, 57.04739501399379, 52.353565231446304, 22.508115268522694, 1.6310145513665293, 0.051828816668280674, 0.06587581633920632, 0.006270626449071232, 0.03361517969038218, 0.054439215304990934, 0.027506530562776233, 0.026482460614774498, 0.025310315447108402, 0.06894960623955534, 0.06498991992444762, 0.04659794916909549, 0.038956980551442796, 0.016664702955993916, 0.03150960426747559, 0.02875610806738898, 0.033613448331673304, 0.012650271997817103, 0.26057009855585717, 0.13593235834231301, 0.0700374664137921, 0.21408081895882086, 0.1381911532652955, 0.27282272495569726, 0.17623518683737324, 0.13960090826355642, 0.16612915412312554, 0.21600357707469695, 0.15239649181885107, 0.16001911263071722, 0.2333382315813534, 0.11267322416026747, 0.18831008083878026, 0.13428598942775882, 0.19370189958041717, 0.16920534953955682, 0.12346017880425339, 0.13680497845334394, 0.2042730549170125, 1.2954422999774258, 22.05507170769476, 57.88690774671493, 65.98987733164142, 47.64781144357497, 37.90144720385152, 50.03779003697057, 54.868847862366714, 47.276539494914395, 9.267342821244272, 0.22341699459620062, 0.6669649109244348, 4.944873730982504, 8.56759786605835, 15.08798816511708, 11.739055764290596, 6.707395670875427, 12.393092359265975, 36.90524754985687, 52.60762891461773, 57.67945751067131, 54.97582658644646, 57.15574264526368, 55.29069092965896, 55.363294001548525, 55.83128767628824, 53.728148091223936, 54.36203841240176, 52.843637927885986, 45.752824198815134, 43.65539950709189, 40.99563637087422, 37.36668302166847, 38.82879749421151, 39.44835155240951, 37.4727988243103, 39.58423814465923, 38.526492580290764, 39.944947150445756, 39.882746204253166, 39.10395176179948, 41.83611008428758, 40.31272818965297, 42.28131086595597, 45.67646741867066, 48.74615746159708, 52.915076055834376, 54.32443857192994, 55.5826956995072, 56.20482675490841, 50.91532622614215, 41.98459925190095, 39.393791383312596, 41.305648742183564, 39.11245153796288, 40.66225059570805, 40.56594856323735, 45.108723948078776, 47.196507453918464, 43.177599906921394, 45.236483389331454, 41.65192734810614, 40.512008128627656, 43.52136427356351, 46.11588270433488, 50.062861827112016, 53.393495390492106, 55.16620666750016, 50.08068507717502, 54.01738366773052, 56.232236277672556, 53.68539033397552, 55.21594232128513, 52.92975748738935, 50.25417150989656, 46.61918555536578, 47.439470829502234, 40.062967346560576, 42.39142748617357, 38.44077310254497, 40.12678430926415, 38.199304149996856, 41.71111591400639, 38.59716976842573, 46.667105151760964, 54.088884553601666, 57.045771152742454, 52.83362411683606, 52.27812628592215, 55.85291170304822, 54.36048907618369, 50.900448676078554, 43.116450155934984, 41.631119174342004, 41.04676838844053, 40.91874222601614, 39.44573533150458, 41.44360634588426, 41.23081384166595, 41.1001322346349, 41.381413244432025, 42.58164675005021, 40.394360557679214, 41.08221877005793, 48.17890428727674, 53.15854933954055, 50.13472357103902, 54.864599935470096, 55.98378942858789, 55.57481173546084, 56.05325068196943, 57.04950132677632, 57.483703782481534, 58.517444441395426, 56.80033668395012, 57.66839642678538, 58.97512228258195, 63.795844662574034, 56.509641985739435, 36.79986523043725, 11.82991256636958, 4.020304401074687, 6.372770426734802, 10.695388567063118, 14.591822066614705, 15.916867352301075, 5.016431491221152, 0.6414473801851273, 0.3630862072590859, 4.970483376133827, 39.21425273341518, 55.278786536185976, 49.04379867738294, 49.328307797831876, 63.48560871616487, 58.81117113174931, 26.01487894212046, 2.097678420043761, 0.1577762063712843, 0.2156216209574092, 0.0803601411321471, 0.07052348791471413, 0.1220964273858455, 0.11548550228678411, 0.1112402490370216, 0.17165062558506766, 0.21736588058692796, 0.23340624486727102, 0.076574923680915, 0.15903455175219045, 0.15754736058654326, 0.22169965529634109, 0.0906353030774382, 0.140715075897113, 0.19859237506264643], [0.03045545196190717, 0.07854862664375575, 0.034937539378241185, 0.010045757873975223, 0.058901800037992585, 0.08381289940687918, 0.04584035715989528, 0.016158922132284894, 0.04333711890203338, 0.05183345533066219, 0.05425892800333039, 0.03159626796390982, 0.023323610056972793, 0.026106610218243256, 0.07469169570193177, 0.0415086662096362, 0.050718885500945395, 0.07141074796597804, 0.05833721238999598, 0.06772394983037826, 0.023617722702422933, 0.44733059802843683, 11.544793517358842, 38.80275295626733, 50.65022499330583, 36.88984047982001, 33.31206229425246, 33.951326262566354, 42.053162282513036, 39.59312231309953, 10.595137688421435, 0.3125025860724911, 0.41959512017426953, 3.566768337641993, 3.950846334618907, 5.4614209551965045, 3.8250149834540585, 2.065676292104106, 9.692323784674368, 30.869037566646455, 51.00422282372752, 54.95443790189682, 53.519972216698434, 51.34295086706839, 53.35175352711832, 52.68407590927617, 50.938013215218824, 49.12176362929806, 43.509471647201046, 40.095075868791156, 37.7942370599316, 34.81120001885199, 36.885565096332186, 39.015176757689446, 41.81445467856623, 42.10945221685594, 41.36564923870949, 36.766638832707564, 36.3781790579519, 33.514625257061375, 36.251490423756266, 37.689046936650435, 36.375951151694025, 38.89059835864652, 44.45317037643925, 48.07041545068064, 48.95647887260684, 50.654884769070534, 51.903759587195616, 52.72449201153171, 48.96023650323191, 43.762327240359404, 37.43959203843148, 35.73036432266235, 34.955868797917525, 34.95520199498823, 34.74522575255364, 40.96978795143866, 47.10043684128792, 45.564554352914136, 43.48254065359793, 44.63964377680133, 42.238486428414625, 41.25637200570876, 41.55552725638113, 38.17040020419706, 46.99219511401269, 48.43494876738518, 53.68548054848948, 44.34034339843258, 47.737661177112216, 54.00872307439005, 49.21600249505813, 48.12589737676805, 44.979136682325795, 43.46459188768941, 44.403893639964444, 39.27197825524115, 37.15660087523922, 35.89606877296202, 35.838256958992254, 35.855511465380275, 35.58670751510128, 37.700280604823945, 37.30031259598271, 40.52131983541673, 49.363142367332216, 51.12368252969558, 52.07583004428495, 51.25097128652757, 52.113492642679525, 49.959636811287176, 46.79042446997858, 40.005653673602694, 37.99081448585757, 37.16760312357257, 37.32825163872012, 36.563107044466086, 38.57238823367704, 38.63873120277159, 36.822348256264966, 36.72033525282337, 37.58392741603237, 38.30575335410334, 36.397634014006584, 37.19824860172887, 39.70403125209194, 40.89970304119972, 44.51577532675959, 45.45702649701027, 46.467229012520086, 48.42200494581654, 50.66658519929456, 48.195739100056315, 48.68561567798738, 47.63651109510853, 51.091244528370524, 53.746351811193655, 55.38494940726988, 50.94560692387243, 26.932350743201475, 7.083354361595647, 3.12685368522521, 3.133564615441907, 7.152197841675052, 5.432590553837438, 11.163384202987919, 7.6284039789630524, 0.25531773845995626, 0.0968796780873691, 4.555617715081861, 27.84144436159442, 42.51448792795981, 29.390972775797692, 32.37298607826233, 48.92637468153431, 43.60398507887318, 11.578091498344175, 0.8438885656576004, 0.0426202291442502, 0.11072831078162117, 0.03686531537002133, 0.040676560658480854, 0.03827469881563898, 0.07518178512973171, 0.07859423185788816, 0.04160684037713274, 0.06704201666458, 0.060108151031477805, 0.02719249771607499, 0.023785168455252727, 0.03677335800603032, 0.07160348802684777, 0.0770609605035955, 0.0821761065913785, 0.044012475203001694, 0.03643852012652544, 0.02665350123518898, 0.03762305676636677, 0.0404121185983381, 0.07119954518613315, 0.08147441601801304, 0.0064631438656379625, 0.07471555934077309, 0.02121618644694888, 0.0388448559228451, 0.05246700621360252, 0.036484297710440816, 0.04400744583577879, 0.0925895627287607, 0.03756687187800004, 0.012199951151776458, 0.04104118786692139, 0.02828371718585972, 0.07986255936444768, 0.1094253944052804, 0.02581742351814624, 0.4839233086714822, 13.93378661524865, 46.19866824919178, 56.02260128144295, 42.896624841997706, 33.481375325110655, 37.98297366788311, 47.80552602583363, 45.933437578139774, 11.589777219680048, 0.2492618287402776, 0.303618724067365, 3.0785504319975456, 3.3479800003190197, 8.553547936101115, 5.631485610238967, 3.0105134892848233, 10.781450271606447, 33.36175087959536, 50.779518081295876, 56.92902964930381, 54.78285774107903, 53.97257843325215, 56.134020128557765, 55.50762545677924, 51.845175066301906, 51.47586038035732, 46.19671883121614, 42.31411757007722, 40.132679631633145, 37.40680102379092, 37.550147964108376, 39.71911276540449, 41.75972192518173, 43.58829167581374, 41.94980782847251, 37.014646376332934, 36.433625682707756, 36.089367097423924, 37.782164004541215, 40.07987668437343, 39.23959908946868, 39.93521575004824, 45.68750889070573, 49.599955466485795, 51.27180299451275, 51.80914025152884, 54.80333643574869, 54.47126465459024, 50.86397455584619, 46.75252260700349, 39.53430244999547, 37.400768418465894, 36.81392300513483, 36.46882503263412, 38.10936812431582, 42.24588009618944, 47.02294649616365, 48.29018192906534, 44.29469877673734, 43.99197024683799, 43.01300548738049, 43.186284034482895, 41.806527568447976, 41.19858372596003, 49.44480219194966, 51.259753473343395, 55.94825667719687, 46.411609803476644, 49.78311054168209, 54.1703914057824, 51.95578982753139, 49.03467524436213, 48.61650743792134, 45.977513251766084, 46.80971076411586, 43.019857868071526, 39.90978310185094, 38.56471999999016, 36.751376890367084, 38.06900693524269, 36.90900125811177, 39.07713843930153, 39.30667946415563, 43.00839278005785, 50.578006313693145, 52.79384343854843, 53.56447935104371, 51.85313355538153, 54.97644632093368, 53.548319185933764, 49.297379909023164, 41.92985080903576, 39.70014810562134, 40.188769525097264, 38.11445543842931, 37.37462582126741, 40.17300159700456, 40.446222136097575, 38.18039832576629, 36.88081510605351, 37.9728578752087, 38.20687432442942, 38.2766140660932, 40.142360041218424, 41.581359986336004, 43.93476640024493, 46.69827230515019, 48.005919917937256, 50.52351674725933, 52.874416766628144, 52.58373775789815, 51.511004817101266, 50.47764462809409, 49.979181981855824, 53.30944292006954, 56.34673418537263, 57.649270949825166, 54.587037332596324, 29.35690699085113, 9.99203012835595, 4.187176246796885, 7.69456014517815, 8.984231045169215, 13.158693909645082, 5.467058872022937, 2.998058493098905, 0.27720113194757895, 0.25007713015281385, 5.043855722873442, 32.96179856023481, 47.52251917316068, 34.09611271273705, 35.57080622642271, 55.97526611820344, 49.14292873874788, 17.283118117240168, 1.057889588898228, 0.098493886630862, 0.0684722951583324, 0.06722228481404244, 0.012143614003434779, 0.014818048972125738, 0.026324081512528564, 0.018426505998978694, 0.01837942798081185, 0.03700161007263007, 0.046289349800997207, 0.012712908304116179, 0.042563301150596915, 0.02482322716875182, 0.10472423457089933, 0.12441053385696105, 0.07153760446535964, 0.0691053212710446, 0.13117513619363308, 0.1594251493412641, 0.09039151091729442, 0.13512811923940338, 0.15861897969678526, 0.25259060334534417, 0.13345441630771085, 0.13555369640309967, 0.08968937601293288, 0.17152578389692694, 0.12650105756737534, 0.10301647903097254, 0.10969491945880075, 0.1325099677928994, 0.18977097986686617, 0.10377492905864794, 0.24895684913762156, 0.16710750968946567, 0.13136200036012358, 0.2627149302392237, 0.18062514643515312, 0.54809270246375, 17.212848855603127, 51.02754915914228, 63.15258772142472, 48.4101515431558, 43.017661340775035, 45.617274930400235, 53.576501415621856, 49.213194078014745, 14.452255310550814, 0.5305553564140874, 1.1999628620762979, 6.350506563340464, 9.519654185541215, 15.268160277797332, 10.526888447423136, 4.5808130598837336, 11.63955503894437, 34.25748294399631, 50.796399962517526, 58.282953385383856, 56.290369725996456, 55.36423144801971, 56.105606479029504, 58.56498749025407, 52.54605162528254, 53.686359159408084, 47.58067615570561, 43.25982847521382, 42.52577650931574, 39.05879743637578, 40.70545158078594, 44.105428726442405, 45.47978801112021, 47.0734352450217, 44.96443563891996, 39.70267803438249, 39.895811619297156, 37.62156648020591, 39.05105467765562, 42.6617140923777, 41.18296484793387, 42.98494092879757, 49.146513785085375, 52.58432219105383, 52.6143910807948, 54.476857954455966, 56.8887076839324, 56.488873035677024, 51.86930940997217, 47.90422462647962, 40.64168953126477, 38.32751858618952, 38.32946408179499, 37.999969297839755, 39.09249059615597, 45.81120475645989, 49.824107154723144, 50.17802653774139, 46.761889226974986, 47.511261970766135, 45.82744729134345, 45.570567346388295, 45.34914562779088, 42.00881596534483, 52.0700837719825, 52.870737583406516, 57.91535277520457, 49.52983133254513, 51.57537091162897, 57.703003498815725, 54.44212536658011, 50.6906371731912, 49.0022333206669, 47.55378046343404, 49.13723737962785, 44.534841968167214, 41.492718342811834, 39.41755310181649, 38.646630856298636, 39.984206153500466, 38.60306901316489, 41.27864714591734, 40.886417973426084, 45.842622941540135, 54.53097489572341, 56.095067070376494, 55.69096880574381, 53.24335098266602, 57.38905306785338, 56.228529637859715, 52.22002421655963, 43.69190892865581, 42.58951502461588, 41.58824766835859, 40.264875273550714, 40.06542667265862, 42.92319889991514, 41.953502701174834, 41.10925959002587, 40.25491245331303, 39.8602710231658, 41.08214032265448, 40.55473842928487, 40.69816773937595, 43.07747356353268, 45.44727548476189, 48.988787435716205, 49.3204552127469, 50.6598622568192, 55.04710389721779, 53.92356057320872, 53.41164027490924, 51.226915390260764, 52.30615554317352, 55.35287226400068, 58.90614740310177, 60.26771583864766, 55.85812453300723, 30.020509266084243, 11.555656521551072, 6.036178113952761, 9.674363251655333, 16.284679770469666, 13.5679167509079, 21.685409891989924, 14.552977854205718, 0.8639832357725791, 0.4403056636933358, 6.801580113749351, 37.48620940792946, 56.15342801617038, 41.81064997949908, 46.32020681135116, 62.93904212213332, 56.770091287551395, 20.596002955590528, 1.5873764671625632, 0.17084145287592567, 0.11856693774461748, 0.13826011650023923, 0.11894436628227273, 0.11956628412008287, 0.18080928332863316, 0.17512278120604255, 0.1931403264884026, 0.18949860496626747, 0.21635439937874196, 0.09771803874642619, 0.11907100827703554, 0.14538353909888577, 0.16525143186651892, 0.12169671335047293, 0.16609251979858647, 0.21760949654684913], [0.0780720510069401, 0.03135364025741095, 0.08796013170673002, 0.06779634513922277, 0.019301073888557094, 0.03249742293490037, 0.011211144230929355, 0.010410984546216506, 0.02913233384700312, 0.03334704891688401, 0.051757750521984794, 0.03429468052702085, 0.06957543112577931, 0.024952347457949674, 0.06774052031218045, 0.022890259016064868, 0.06029615283853585, 0.1274251970913141, 0.04820204535198789, 0.059398845544145, 0.03318800523336376, 0.18945233325564093, 5.379933714866639, 31.681685986057406, 53.98201565588675, 40.034192838976466, 28.90908214353746, 29.39891165302646, 42.91660931802566, 39.63605265463553, 19.55171504328328, 1.9085478590380762, 0.008991644830412922, 1.5402039597111365, 2.6928654889906607, 3.1433850046127074, 4.566741556890549, 2.30723594946246, 6.708559634224062, 25.510856336162938, 48.690769672393806, 59.05042786752025, 52.67289323191489, 53.307905350961995, 53.98771878211729, 48.96592393998177, 44.322167135054066, 40.7083188333819, 37.052724745965776, 36.69243935615786, 37.49328928609049, 40.636715965886275, 45.03705440029022, 46.594792335264145, 50.14635732097011, 50.47500487296812, 51.600897696710405, 47.0641980632659, 37.9742189376585, 37.120291494554095, 36.1209657115321, 36.673988526867284, 37.10220936805972, 44.72445326466715, 50.094009368650376, 51.41141191605599, 51.4755505131137, 51.21956094618767, 51.52096371496878, 48.64580362073837, 48.15735478555003, 39.6397828286694, 37.154114092549975, 34.92271692522111, 35.62465252414827, 34.792384409135394, 38.79185268955846, 46.970320055561686, 49.86558621929538, 48.30865237020677, 47.655369850897024, 45.8076746233048, 47.87530499119913, 41.87802060957878, 42.34322940149615, 40.76685236346337, 44.957312614687034, 47.31229189903506, 52.32623807845577, 42.92623873679869, 45.24903889625303, 51.63139020242999, 50.50406963594499, 49.02075083025041, 47.74193263822987, 44.91864588952834, 42.087373195155976, 39.95388623206846, 38.717712048561346, 35.94995821675947, 36.034524517674605, 36.13676501858619, 36.12857903203657, 36.04298507013629, 35.97605766788606, 37.323038808761105, 44.96711854011782, 49.43330180260443, 51.20191420278242, 50.20047033986738, 52.94767879670667, 50.10151678516019, 48.6943547187313, 39.361216099031516, 36.47503806698707, 38.21708817635813, 36.499176333027506, 37.88520074659778, 37.6712276089576, 42.83620465186335, 45.26179836642358, 43.63701928046442, 40.66405880835749, 38.774190256672526, 37.54566077263125, 36.97808596395677, 36.16587292763495, 35.04575775515649, 35.18891642170568, 36.87595136703984, 40.27242191376225, 40.12772960047568, 41.48781930246661, 40.135103656399636, 41.59196999765212, 46.226532766895915, 51.23628593260243, 55.196867835137155, 57.7146960842994, 47.91820395377375, 24.552611497140703, 6.498145066922711, 2.5802334037519272, 6.8895789788615325, 9.026547535773247, 16.56194721498797, 12.852135185272465, 2.7161256344087663, 0.21401459831864605, 0.2172840777183733, 6.000506118420632, 30.448918381044944, 38.29564148379911, 37.77528808962914, 38.06712419755998, 55.00627202372397, 34.76363735814249, 8.057885862165882, 0.4332876854365872, 0.10569722752176947, 0.05429951151111915, 0.05810032651248959, 0.07231159075613945, 0.037047655787318945, 0.0443878889294161, 0.08870398775944788, 0.02543504605250013, 0.05051679916739945, 0.02161097645218815, 0.03349497666462295, 0.020267277385198304, 0.05620266160657329, 0.026994182450336315, 0.06806085231683909, 0.07117822495920044, 0.07659249007701874, 0.06158652069467691, 0.08006742659715876, 0.06711795896051392, 0.05226395460927198, 0.05365571803263119, 0.07707598348779064, 0.05406849386711275, 0.03134282692635973, 0.07536424429065759, 0.05621475813489768, 0.00770204593502586, 0.043300760369147026, 0.0239158496485963, 0.030696248718267007, 0.08848320121967024, 0.057082731922667836, 0.01885349084923585, 0.024715754609074325, 0.05246904783792073, 0.032439230896172025, 0.0621894050780083, 0.21605119710007023, 7.4692116437419775, 38.481471615452925, 58.31342627925258, 43.183110837013494, 31.13629610307755, 31.84085184527982, 46.67695422326365, 45.754142115193034, 18.14541393710721, 1.8106847232387913, 0.13148391559239359, 2.525384205002939, 4.8347566204686325, 3.9648440480232243, 6.764011652238908, 3.923860182685237, 8.309422558353793, 26.814509014929495, 49.453439251069106, 57.85941585417717, 54.28143370536066, 54.29052968179026, 55.84421580837619, 51.322507473730276, 49.701470328915505, 43.93026351928712, 39.95431769278742, 37.71704089257025, 38.52069923954625, 41.80216981518654, 46.03159489170198, 48.809809684753425, 50.70694638836769, 52.440657538752404, 52.78876004680511, 48.273860946778335, 39.46596299448321, 38.335265267279844, 38.7287417534859, 38.27952446476106, 38.06678687372516, 44.903238819491484, 52.892671477410104, 51.8389698766893, 51.63550476874075, 51.67984716353878, 53.201256105976725, 52.53400994885353, 51.29348977919548, 41.91088614925262, 39.29978785976287, 37.96582506548974, 37.18691295193088, 35.68835181574668, 41.148455835157826, 46.7046893027521, 51.124455236619525, 50.434541702270515, 49.5510317433265, 48.049599432176166, 48.303365015214496, 44.25522404332315, 44.19083441457441, 42.59169194006151, 46.872770709376184, 49.89673376083375, 54.31157712013491, 46.18953304906046, 46.95694085090391, 52.98334883105371, 51.34251548397926, 52.77904433588828, 49.37438388024607, 46.08391146506033, 44.1916149662387, 41.20050176497429, 40.547772299858835, 37.9308492906632, 38.1016920458886, 39.35563848864648, 37.65744440017208, 37.347067248436716, 38.17089442283877, 38.83811704574093, 47.22734120584304, 52.19624680857505, 54.019321318595644, 51.44448534134896, 53.00527880268713, 51.439782419512355, 50.426414551273474, 42.95909250936201, 37.977062656033425, 39.52204896557716, 38.52239762583087, 37.74574479749126, 39.41625087491928, 42.55895583860336, 45.961105977335286, 44.649206515281435, 41.07236577618507, 39.81247694261613, 38.49396044208158, 38.4314888523471, 37.60765775557488, 35.73882095275387, 37.282301072151434, 40.02340239863242, 41.23409686550018, 43.23571374339443, 43.58595786556121, 43.29810688572545, 45.40692606279927, 49.34056128225019, 53.498752194066206, 57.70348202797675, 57.87854917587773, 49.67593177672356, 27.377916305295884, 8.615355664683927, 3.4989042243649884, 6.88368316619627, 6.058494439048152, 11.578455298177659, 15.118696401196143, 2.298921750437829, 0.1219329365619248, 0.20702266705132302, 6.998198234265851, 36.099847670524355, 50.282330205363614, 42.97845332853256, 42.141337163986705, 57.53915432960757, 45.46716974627587, 12.254981783128555, 0.5162676327651547, 0.08516600986401882, 0.05060934258865253, 0.0948183270051114, 0.032138564368529667, 0.014403927695727157, 0.03614763271123652, 0.03363735410535047, 0.024514880609668555, 0.0581412585902839, 0.02729309463663207, 0.011945879049298745, 0.04937843081631488, 0.060979687128095865, 0.06754624807546217, 0.05547712654656461, 0.025785067794664253, 0.04789449935478549, 0.15111877973521912, 0.24636051587520108, 0.18636602547860917, 0.1565465892875387, 0.1784866886033166, 0.1724558146370034, 0.17437930819728684, 0.09466664925698312, 0.1171032501564872, 0.1295008663568766, 0.11251515723885068, 0.12494376935665646, 0.15240960724411473, 0.15216557759671442, 0.12190033952074668, 0.15253590449931162, 0.1512789227549107, 0.21595876093112656, 0.14212941210116112, 0.17463702017501478, 0.11660716992111937, 0.3164164679906061, 8.329877718802422, 43.19580754926128, 66.41156350412678, 51.13137037523332, 42.15377499980312, 40.61513508519819, 53.079399831833385, 50.234402764228086, 22.38822606302077, 2.740679426539329, 0.16051251921922932, 4.101895829362254, 9.041148558739694, 10.821298610779548, 12.559398893387089, 6.200717130014974, 8.689289400654456, 27.559977039214107, 50.74759783283357, 60.712128223911414, 54.79989259473739, 56.84038800577964, 59.053593220249304, 54.52931573314052, 51.87763267947782, 45.46604794840659, 40.10941997651131, 39.80373790187221, 40.2543358648977, 45.276154241254254, 50.159795361180464, 51.52734933360931, 54.937948257692405, 54.66135448025119, 54.91105648779101, 51.68116115754651, 42.04755329316662, 41.82648458788472, 39.666796192046135, 41.36944217066611, 39.92975188839821, 47.81713231917351, 54.4912059845463, 55.172851162572066, 54.59649416708178, 53.457465325632405, 55.873841470287694, 54.71778169755013, 53.77620497057515, 43.20222454686319, 41.8579694532579, 39.0009581658148, 37.87432009173978, 37.088488917196955, 43.701565804020056, 50.42836789161929, 54.00030959037043, 52.41180066139468, 52.579391771747225, 50.85936577089372, 51.860331104647734, 47.260296960030836, 47.080197411198775, 44.52576952595865, 49.29484213552168, 53.72926596672305, 56.33138595088836, 49.9679365465718, 49.11127913382746, 54.64189167945616, 52.945176324536725, 54.42232916432043, 52.57722662341211, 49.32013357839277, 47.23372290211339, 43.79937010426676, 42.770300988228094, 38.92504853586997, 40.96064098419682, 41.34314267866073, 40.04713666054511, 40.02319451301329, 39.56548137049521, 39.99411406055574, 49.61094594770863, 53.69777717897969, 55.79880260652112, 51.466117212849284, 55.82488636816702, 53.44809478329074, 53.24570832713958, 44.83488367449853, 40.306879935726045, 41.59569624931582, 40.213507913774066, 39.552125700058475, 41.792673756999356, 46.96462477407148, 50.223565255441976, 48.01836559849401, 44.597823466024096, 42.05974401966218, 41.00541483971381, 41.47568741152364, 40.41563549349385, 37.88354550638507, 38.49077547750166, 40.71509276666949, 43.672740305623705, 44.9478244012402, 45.01369668591408, 43.87320480039043, 48.09165508516374, 51.5406971593057, 58.05800545600153, 61.51579049325759, 62.18731987860895, 50.89123110617361, 28.777959269862023, 9.51122599263345, 7.577392083983268, 12.393656199978246, 23.09317796461044, 25.768726679586596, 18.113207355622325, 5.796561010422246, 0.4129190316363689, 0.5639207531367579, 8.86102645627914, 42.367418658348825, 52.55015050211261, 50.88275486423124, 51.7491985905555, 67.93871479649698, 49.8332227430036, 15.684285509970882, 0.6992632390991335, 0.22255200472089554, 0.10679909944414132, 0.230498006567359, 0.10116454574369615, 0.13731387533968495, 0.12578864942394918, 0.255723673129274, 0.10288530179569799, 0.18724531055458132, 0.11071569331350828, 0.1058950697282149, 0.1850332929602554, 0.06550512171440548, 0.09388604396653753, 0.13389991175743843, 0.2188420707299825, 0.18723668440455393], [0.01834476824789759, 0.03356371773406863, 0.0022873676085333914, 0.045675759338924, 0.042480019732348384, 0.0919062965699742, 0.035994089539012605, 0.008061343086733213, 0.04440604904366117, 0.016377714928239584, 0.022058999992065856, 0.050257635453054984, 0.01128327140900036, 0.05296960202676635, 0.015781101932178344, 0.03155614027843601, 0.04126198589801788, 0.0395975066649337, 0.06828268839707298, 0.09273655967967165, 0.030913959415028655, 0.061488986210597146, 2.091202832037403, 20.44117327659361, 49.05320452105615, 44.11414423296529, 23.47541097671755, 25.65627624911647, 31.91017189333516, 44.7046099939654, 26.443854839571063, 3.4907922725523677, 0.058831067139943766, 1.964990765817704, 3.703179792050393, 4.639758438833298, 4.170415468754308, 1.060048853678088, 4.856959687125299, 22.330322073351955, 54.07678404162007, 50.55867687348397, 55.35923827079035, 52.83699735518425, 52.149237202059844, 46.65792680555775, 41.45602849221999, 37.929974602114775, 39.4892854075278, 40.79468157983596, 47.08819512398013, 46.81572375759002, 49.16978520731772, 51.483481545602125, 53.86188522461922, 50.27714483199581, 48.663332693038456, 50.74842545293993, 41.52082212509648, 35.71542793704618, 37.204873484949914, 36.42150948124547, 42.59401790557369, 47.54226438460812, 53.55811334425404, 51.23699588160361, 51.20023150597849, 51.940614177334695, 49.56819603520055, 46.763532700077185, 38.32432185449908, 34.55000154433712, 34.79421223363569, 35.20719858907884, 36.06849616573703, 35.97690097747311, 47.122951246077015, 50.007344599693056, 49.95830712779876, 49.52764264998898, 52.24685715090845, 51.10641233382687, 48.76392579847767, 45.65655354530581, 46.142005689682506, 44.63563511448522, 50.14893431817332, 46.420823451011415, 52.49621398987309, 42.58564756762597, 43.6426047355898, 47.38907621752831, 52.270395294312515, 49.624148645708644, 48.910669511364354, 44.27000745650261, 43.26377830197735, 39.50577505173222, 39.557220858912316, 36.63934223113522, 37.49572115559732, 34.86170053482056, 36.73700140368554, 35.19264267336938, 36.06141236520583, 38.23768061976279, 42.36597130375524, 47.773072335027884, 51.16965663048529, 51.32923826094597, 52.62882540302893, 51.18160417003017, 48.89705496449625, 40.45006213649627, 35.78196310227917, 36.49932146072388, 36.71072152353103, 37.22955303807413, 45.28812531502017, 51.293678052963756, 49.89341151329779, 49.569129559301565, 49.56206144825105, 47.048767459008005, 42.783915535096206, 40.20764004799628, 37.88352197216403, 39.17600570186492, 38.19347158555062, 35.7481954174657, 38.07040329902403, 39.48617104561099, 44.24874428779849, 43.17554850732127, 45.986118931924146, 50.16545926370929, 53.70425301213419, 55.19229042914606, 59.060049441552934, 46.13570636318576, 23.331183464296405, 5.608730469980548, 2.6146193521638073, 5.511408621265042, 3.017744378697488, 10.536305077614324, 10.285633264049407, 7.8711633912978645, 0.2948653115139854, 0.1238272191896554, 8.651856260914958, 35.95797554139168, 34.52734593422183, 26.637094328480384, 39.809119393748624, 61.08323543302475, 22.5117983741145, 5.838463200676826, 0.06396858682555538, 0.04480387084186078, 0.09387386316854147, 0.06666459578780398, 0.04755163287383415, 0.034957220177015955, 0.023614869024904988, 0.028773967492123766, 0.038479037447682315, 0.02197862779270978, 0.11392255268630483, 0.02516085169308128, 0.05707809709072594, 0.04626855434429261, 0.05509545005136921, 0.011445211862484294, 0.020345573486279578, 0.03385229156382623, 0.05494089181264562, 0.015570594377124743, 0.028055882637178706, 0.045532110192242174, 0.07288321492172058, 0.10435414515555867, 0.06987386833756201, 0.09032114574144925, 0.04619768355041743, 0.016509012822362206, 0.02906230000418521, 0.01615299261175096, 0.03085920902630014, 0.07778210971023768, 0.03468721631854292, 0.036534342404094436, 0.012442686110584727, 0.06969088823684762, 0.010515283586667671, 0.05583745600174993, 0.03822525933144554, 0.09714800038284833, 3.2791804017559176, 26.703994274139408, 58.317254512540764, 50.212300208307084, 30.156774367055586, 31.688787437254387, 43.237969106243504, 50.76672723216396, 28.959210034339662, 3.404817595597237, 0.060553669463843114, 0.7828054336770889, 5.2758854916018825, 4.312916648003363, 5.6442999935919245, 3.6407314913888134, 5.412668345435973, 24.536404263588693, 50.81826717622819, 55.52532319099673, 55.1851438706921, 56.237249066752774, 52.786842007790845, 50.20852688820132, 43.03784978005194, 40.03816227759085, 40.87677678754253, 42.351085908951305, 47.319309019273334, 48.615224822875, 50.53882968041205, 52.167939063041445, 53.91360167534121, 52.41611134621405, 51.032459966598026, 52.09346109820951, 42.19452842589348, 38.059656004751886, 38.57742063460812, 37.95189672900785, 43.7245979616719, 50.42768932157948, 54.18186826090659, 52.37578545847247, 53.88185793353666, 52.327928620000044, 51.62899755662488, 49.212480206643384, 41.4267126975521, 36.03367728571738, 37.173051295741914, 37.12257431399438, 38.73484103910385, 37.63197252827306, 47.49561563614876, 50.8774753539793, 52.2989462267968, 53.76710507177538, 54.15080308914185, 54.24379856355729, 49.75501068176762, 47.27456262034755, 47.52426462788736, 45.30178300796017, 50.93454976235667, 48.93945186368881, 54.535367950316406, 45.047436914136334, 44.08361250354398, 50.64600060063024, 53.30370057013727, 51.15283358481623, 50.12783588901643, 46.59485117081673, 46.25370694744972, 43.31358063605524, 40.77688578636416, 37.910794211972146, 38.36721689470353, 36.02695434324203, 39.02921492053617, 36.83219732776765, 38.2353271976594, 40.82454650632797, 45.41071115001556, 50.91568316182783, 53.64982620362313, 52.137878018040816, 54.926573384192686, 53.621608672603486, 49.928865817285356, 42.883759467832505, 37.59581219765448, 38.206721351992705, 38.84847994773619, 39.23409600411692, 45.110955776706824, 53.148751258850105, 52.01970484948928, 51.415071487426765, 51.26170289131903, 47.761230699477665, 44.327160312283425, 40.89196420484974, 39.20831426497429, 39.31414373459355, 38.49790634647493, 36.452417758203325, 39.09277692917855, 41.28809221329228, 45.129316391483435, 44.381555741833104, 47.86067455045639, 51.67876066700105, 53.65925165914721, 57.11858603262133, 59.736395497475904, 48.99039560748685, 25.344341916422692, 6.248124857102671, 2.965059102542939, 5.390660906991651, 7.647162224015883, 6.788977048089428, 16.36844688846219, 6.1915044630727465, 0.24081437638209713, 0.1967661899905051, 9.950864853397494, 40.82065943748721, 40.312955687122965, 34.28075044385849, 45.6259512132214, 69.17185306549072, 30.102104371593846, 7.2139006468557545, 0.10968340515729882, 0.03247582308587528, 0.020400827577818307, 0.02798022762421639, 0.017190666366068107, 0.03018433344550431, 0.02485719742253423, 0.021804089980920958, 0.02160630906150947, 0.021094548921551437, 0.03429512868845656, 0.04295450011869112, 0.0062558510070366245, 0.008979150893977814, 0.04004272249256892, 0.03827007930545557, 0.015790183904520687, 0.04675986951277141, 0.15061222707792637, 0.22085891976471872, 0.23009496771039503, 0.22689506441595095, 0.16628442482361872, 0.260430762484189, 0.1175223308945856, 0.2781587724964465, 0.10488263091012355, 0.10449552668198463, 0.08105368819087744, 0.14096108205135793, 0.14742453522499532, 0.14920895318350486, 0.10507256708919041, 0.06151248212723483, 0.14104954988485383, 0.20460231950686825, 0.12630282465608852, 0.1977348775272408, 0.11137197785560163, 0.18820043833505726, 3.2654719631518088, 30.405838989442397, 65.59807569749894, 56.70092813430294, 34.582816093198716, 36.966024675676906, 41.046533046230195, 55.864349334470695, 32.32351322327891, 4.613744789554227, 0.2438578138788862, 3.596766624719866, 7.899437796685004, 12.038033527712669, 12.69000989775504, 3.3170347059926684, 6.363671998823843, 23.821595445755992, 54.68094279689174, 55.81342128015334, 58.23023280789776, 57.137605605586884, 57.90450349930794, 52.53278616935977, 45.13249351132301, 41.828061380693995, 43.00159139017905, 44.539207566169004, 50.512451741003225, 51.63000168338899, 52.82650109260313, 54.66928943510979, 56.238955297777736, 54.18162507395591, 54.46659703408518, 54.84911441802979, 46.005036523265225, 39.533992582751864, 40.99747596248504, 39.77958394635109, 46.89966640164776, 51.82051120265838, 57.969877642969934, 54.79158501471243, 56.14817988487982, 54.11500753894929, 54.13282294427195, 52.3139218361147, 42.00893363645, 37.31615897147886, 37.741802815468084, 38.39943916566911, 41.100049864861276, 38.945931234667384, 50.53750784166398, 54.54766458080661, 54.33526431360553, 54.34129299656038, 56.023107267195186, 55.81682589746291, 51.35871095042075, 49.807331177496145, 50.6290755733367, 47.37520671659901, 52.94145791761337, 50.60374098439371, 56.08115442337529, 47.528222299391224, 45.80587033302554, 50.627855716213105, 56.71847681845389, 53.66458608258156, 52.89646048699656, 48.80897814227689, 49.4098303394933, 44.225931782876295, 43.57608918220767, 40.53686418840962, 41.79535273582705, 37.94751544152537, 41.508694156523674, 38.27724556769095, 40.594358290395434, 42.75456836146694, 47.37644618557346, 53.071912027174434, 55.9450795573573, 54.05360675627186, 57.12012752409905, 54.462921773233724, 51.71021023104268, 44.1155876651887, 40.16269360819171, 39.59415389645485, 40.28077263985911, 40.515769681622906, 49.14684326417985, 55.237444754569765, 53.128943289479906, 52.85550309765724, 54.186759456511474, 51.959312115946126, 47.02363683331398, 45.115011507465, 41.657697154629616, 42.51844952183385, 42.071722938168435, 39.44690419781593, 40.44925805061094, 43.73568650214903, 47.38955474668934, 47.10454748522851, 49.913537194651944, 55.14374325352331, 56.5740708381899, 59.04408147258144, 62.3116982367731, 50.900534968222345, 27.395468911816998, 8.004470534863012, 6.987270020669507, 10.396623592222891, 14.379152136464274, 22.165541341227872, 16.915637139351137, 13.045788484234965, 1.1122395434687216, 0.4537928867484293, 12.14461511181247, 48.133145916846495, 46.93046877461095, 38.63928425696589, 52.84257888793946, 74.74648244919317, 37.475571940022135, 9.110737289151839, 0.23405801715149036, 0.14227726707054725, 0.12477117740819532, 0.14180175629594635, 0.19830383570684543, 0.15238113941684847, 0.20915848954070002, 0.12619099114090204, 0.08662310909600028, 0.2076869418904666, 0.1836264644178652, 0.0968980948410688, 0.18750915123570353, 0.11265352037885498, 0.16974161108655317, 0.12433895060131628, 0.08309253927079902, 0.1315000953693544], [0.030571322760454593, 0.008281644118288833, 0.01818571881871791, 0.020896949948021964, 0.04275990995548425, 0.07618068717420101, 0.028508931713839693, 0.06824153415378063, 0.04602434466623011, 0.0633151980958158, 0.03064681306451319, 0.028069557306627115, 0.04778500623820771, 0.029660359948813438, 0.02292610043960233, 0.058654882239117745, 0.05072922385748356, 0.026208978717125235, 0.039687223221746185, 0.026156344646287542, 0.007484308425186863, 0.08417448524626032, 0.3444666241205508, 11.330376171296644, 38.49121086059078, 42.45456980120751, 28.497619628906254, 20.655024820758452, 30.79708953057566, 42.16351424494098, 33.70732738125709, 7.855937730881476, 0.13439446747783693, 4.035816394513653, 6.049153314482782, 0.6134392669604671, 4.10325444033069, 5.67063331604004, 2.691863323411634, 17.462880342237412, 35.21106996843892, 48.32435754037673, 56.58181359691005, 52.15253591537476, 51.29299556055377, 43.607844691122736, 41.41566730314686, 42.456044612392304, 44.482392034223004, 47.84658147442726, 50.37946770268102, 51.78989710346345, 50.60600419198313, 51.212096675749756, 51.58641238366404, 45.324662193175286, 47.256853119019546, 53.061215723714525, 38.8841970505253, 35.34713306734639, 37.19953121677522, 37.992516794512355, 42.63677174045194, 50.54785505417855, 54.613246610087735, 51.4916753768921, 50.39914623383553, 51.153214054722945, 47.536420053051366, 41.204475125958844, 35.18668459307763, 37.63130964771394, 37.53010465252785, 35.75557731813, 34.443309153279955, 40.53868809053975, 51.67535212732131, 50.59180913432952, 50.14097582909369, 47.46333060726043, 51.508882814838046, 51.19527755245086, 49.12947893142701, 47.76917742144677, 47.600084043318226, 47.40358898716588, 48.614997325405, 50.56030857947565, 51.65780736554054, 41.6397483887211, 42.87944878301313, 51.72555454315678, 51.82240178508144, 49.658379170202444, 47.1108115103937, 42.29623940683181, 41.298317832331506, 41.216269693067, 38.4141323643346, 38.06334303271386, 36.61570210610667, 36.929209309239546, 36.405368927986395, 36.58659811942808, 36.00825248226043, 37.36121523764826, 42.34112701108379, 48.443370096145145, 49.93211746215821, 51.152535484683135, 49.80613093222342, 50.63643393977996, 48.02782635534964, 39.34318888571955, 37.01401095236502, 35.425180389035134, 35.515159560788064, 38.398340902020855, 48.52197047202818, 52.509098975889145, 50.58516856162779, 51.54519611789335, 49.7160654683267, 49.96784633205783, 48.75070741099697, 47.73644916472897, 46.543519112371634, 47.045060819195164, 44.033763101024014, 42.61284920477098, 41.717419162873306, 42.45117302863829, 41.023783299230764, 46.026950805417954, 47.308094962950676, 50.214351607907204, 54.50528729346491, 57.635934891239295, 55.98568393338112, 42.538320249126805, 20.111947174995176, 4.43180319762999, 1.2284798415437823, 5.496190315292728, 3.4647266518685127, 11.954120301431226, 2.4285776576688214, 1.1851997961921077, 0.22013197893336897, 0.3841616537782454, 9.368150676450423, 41.97855880183559, 38.438988424116566, 31.68545734497809, 38.54595930345597, 46.109956003004505, 23.432121738310784, 3.4164753700456316, 0.02461883491055379, 0.03442142594365343, 0.016063132413452672, 0.04277209458391994, 0.04092281579130119, 0.06645543846271693, 0.08698320872480832, 0.030193991899009676, 0.06284332240841563, 0.028329266858617627, 0.07545354715999096, 0.011314335316720029, 0.031824615791500095, 0.030486984140870553, 0.05484267934075287, 0.0803239204950871, 0.041673041865109436, 0.03707302478893149, 0.04458539788761447, 0.024895528631825602, 0.02711519369885566, 0.03435988227025636, 0.059606367271513715, 0.054824132352106036, 0.0016298303929826005, 0.05218794336542488, 0.03427143741939818, 0.04175075382414845, 0.053222368906943075, 0.0766757408517503, 0.07267018119173665, 0.04832074684541553, 0.02963266778557051, 0.019528736067455144, 0.03388116158725273, 0.0874438803763159, 0.09496818912485916, 0.03748360578150999, 0.018000084223345886, 0.116016385896552, 0.5496419161077469, 15.566442801106362, 44.81987276384908, 49.45595349034956, 31.001278315821004, 25.191259653337543, 30.77090378730528, 48.32656975715391, 37.910025427418375, 8.657193626126936, 0.19883540879574516, 3.9149671889120534, 3.5840632934724135, 4.0930967273250705, 7.31716194460469, 4.404220600281993, 4.411333818589488, 17.701148640724924, 40.6647373783973, 50.57864173766106, 57.69274650081512, 53.30672471754013, 51.78650817563457, 45.22709323513893, 44.13441111964565, 43.75356466539445, 45.28644261821624, 49.47929551524501, 52.33144698604461, 51.98488596946963, 53.0831378506076, 53.07616387644122, 51.57699869525049, 47.19455803594282, 51.05160897777927, 54.19479639299455, 41.71531677246094, 37.05157941387546, 39.443334840959125, 40.201744725627286, 46.1283754533337, 49.538731190466116, 54.892915525744044, 52.27243884917229, 51.565094301777506, 53.23485120650261, 49.8727955356721, 43.41939049382364, 36.874264747865745, 39.83103367590135, 38.530481630756015, 36.759417749220326, 35.355201382790845, 40.199516819369414, 54.151748380353375, 52.46315233169064, 51.38812088197278, 49.760286269649384, 53.41771210393598, 53.78688558455437, 49.51244738794143, 48.827762373032115, 50.45443204141433, 49.11929645845967, 51.59972883039906, 52.071185958000925, 52.626742624467425, 45.487056163049516, 43.65897278631888, 51.523062183010964, 53.67749852518882, 50.66976231913413, 50.52980430664555, 44.360567139041045, 44.68312325016145, 43.121549237158995, 41.68039198844664, 39.277159706238784, 38.61833095550537, 38.27056969365766, 37.06664523770733, 36.67024658572289, 38.79635557051628, 38.57771873474121, 44.810623814982755, 51.47591137116956, 52.65127704989526, 51.794419596272135, 52.46033214753675, 51.89393012754379, 50.58805150370444, 41.41925234948435, 38.418945112536036, 37.853939456324426, 37.79238570121027, 39.54835237995271, 50.97440496567757, 54.61462336201822, 53.89918696495795, 55.756903848340436, 52.21422695344495, 53.08340457177932, 51.09381760320356, 49.54155921936036, 47.38043523603871, 46.344949122398134, 45.02119625768354, 44.67086192100279, 43.717843640235166, 43.205911574825166, 45.18238605991487, 48.06255502085532, 49.701788040899466, 52.555449624215406, 55.830938585342906, 59.2257813484438, 56.99360362945065, 44.538281886808335, 21.57085903229252, 4.867397604450103, 3.8668245077133183, 5.4886941755971606, 3.338512134167456, 11.791585126230794, 4.27080019827812, 2.819039066953044, 0.2895901832849749, 0.39100183834952695, 11.613291828863083, 45.80323057789957, 43.56560468673707, 33.67109644797541, 44.437461283899125, 54.690905617129424, 28.15052713117292, 4.4276724515422705, 0.03043447647454037, 0.09680714488269822, 0.05796303206513967, 0.026918002667145866, 0.03017236523690724, 0.036889638661617236, 0.04194968770588598, 0.00869581327518268, 0.09896280904931408, 0.02129743773219807, 0.057578386979237686, 0.02233603270724416, 0.05810106961777615, 0.038319917155369636, 0.044672666793508876, 0.04919370403513313, 0.033464957509310014, 0.03997265992145385, 0.11920590869962208, 0.09613632765268126, 0.1290595537472156, 0.15801157922514025, 0.16166027214738632, 0.1397644680353903, 0.18042982465797858, 0.12460897361198742, 0.11381309404368363, 0.128198555189996, 0.1300795538531196, 0.12653945389414026, 0.11612450388530571, 0.179731443584446, 0.1690118050863666, 0.11094107638083159, 0.20718881620034096, 0.11848474417122141, 0.17546362904531343, 0.14945489805071585, 0.14030932508889707, 0.2571605782835715, 0.733445285549087, 17.718691441320605, 51.32332724909629, 55.05512906659035, 38.495270513719134, 31.55923351164787, 41.123348743684836, 53.15887489626485, 43.143530199604655, 10.371416480310502, 0.4343671646089323, 5.585538966040458, 10.906701357133928, 7.992521524429322, 9.096622640086759, 11.564781915756965, 5.155376551612731, 19.543789894350116, 40.99632278565438, 52.96389387499902, 58.49527520518149, 55.70715642744496, 54.60464092992968, 46.76063799089002, 45.10440149614888, 47.012379630919426, 47.910559254307906, 53.32253971407491, 54.113913197671216, 54.35988503117716, 53.85975145524549, 53.622624566478116, 51.44550123522359, 49.49184317742625, 53.22170734405518, 56.125281087813846, 42.57640646349999, 39.26925220797139, 40.908100835738644, 43.18820207349716, 48.04009160687847, 52.57523405936457, 57.83217891570061, 53.84553286337084, 51.19199060624646, 56.94356987553259, 52.14298886637534, 46.23215744572301, 39.38902570355324, 43.60276914411976, 40.81504652577062, 39.11313403037287, 37.92344777814804, 44.35397363478138, 56.31118966687111, 55.08488024434736, 53.39917498250162, 51.15348862063501, 54.54027875777214, 56.81118988221692, 51.03042425647859, 49.75646195873138, 52.07021321019819, 51.92469719917544, 52.36712878750217, 56.230773233598285, 54.441062404263405, 50.18246273840628, 46.39487304995137, 55.55409769858084, 56.50018122888381, 54.727846499412294, 53.24186440437071, 46.37128391573506, 47.91332844764956, 45.85433906124484, 42.86490071204401, 42.81628685612833, 41.97107491954681, 39.82763298096196, 39.34634247133809, 39.71015014956075, 40.56997291503414, 39.53126261311193, 46.59499629851311, 52.84195523108206, 53.60970427913051, 54.643966613277314, 54.96514597246724, 53.48902079366869, 52.60292207041095, 42.689147149362874, 41.34416249490554, 40.427700704143895, 39.66054001162129, 41.50836075505903, 51.87536554951822, 58.00290399982084, 55.177059865766964, 56.579330736590975, 53.30126477826027, 55.600726835189334, 52.990758188309215, 51.88291218972976, 51.66324769296954, 49.829382742604906, 48.383985411736276, 46.72277927398682, 47.181123918102635, 46.671917899962395, 46.000827820070334, 50.089498642952215, 52.10392205945907, 54.83018898194837, 59.198532642856726, 62.09323398528561, 58.746106855330936, 45.504777431488044, 23.823613505209646, 6.425014926541237, 5.544220228349009, 13.62668562319971, 11.786600774334325, 19.434179259884743, 7.145784766443315, 3.0048907716428084, 0.6788403156303591, 0.8828477525422651, 13.425463130397182, 53.86974565444454, 50.56437607734434, 44.229995358374815, 53.008675575256355, 61.139788166169204, 34.100513612070394, 4.957119370660474, 0.11991042613742814, 0.18884864064954943, 0.1379993861360896, 0.15131705861178138, 0.10354742392777436, 0.13738639322259735, 0.13663642378824373, 0.1434994071361519, 0.17757726562840326, 0.1003799184916481, 0.15951472034137096, 0.25424892323151715, 0.26350746351865034, 0.1652049150077566, 0.11855900873460117, 0.1391305455998067, 0.18312142861466255, 0.11061862231262269], [0.09028190671796761, 0.014056290402227353, 0.06441500924167133, 0.05478511932456205, 0.12356732386134325, 0.03663170068795162, 0.0022717724524198043, 0.01840557456166754, 0.09030120447278024, 0.044874293474300254, 0.07148819179424355, 0.04364713170235196, 0.03600825450473255, 0.061285333227246046, 0.018634039217666275, 0.03137869324775473, 0.04774223554939513, 0.07379896578288848, 0.0351206305617046, 0.0010775913641179703, 0.01547527292953624, 0.031522792471092076, 0.13473713860636757, 3.3503258228302006, 33.341887997042754, 45.88008549905593, 29.82377886772156, 25.694701748509562, 39.62969057021603, 37.10253492478402, 38.5834453951928, 11.809324045335094, 2.2456206621662265, 14.001859349589195, 27.504495113126694, 5.360193406381915, 2.1683063334034336, 5.264261057299953, 2.3424850644603854, 8.597145080566406, 29.608883973090883, 57.41118308036559, 52.301523224000015, 52.65927084030644, 48.68182666840092, 45.11490952584052, 46.552450349253995, 48.75343345826673, 48.797061981693396, 52.69094005707772, 55.13380004513649, 53.6294847919095, 50.7639305822311, 51.58183105530278, 52.360515671391646, 51.24062015164284, 51.335365003155125, 46.19228263055125, 36.9631495783406, 35.31076485110868, 37.12521406912035, 40.73991744749008, 43.22253457961544, 50.60812619424636, 51.69270861533381, 51.2079389633671, 51.064286078176195, 51.02297175315119, 46.565609901182114, 39.370261084648874, 35.66116586808236, 36.388165412410615, 35.76065678750315, 34.70414676973897, 35.01459060176727, 39.08048422105851, 49.72768745114727, 48.612290889986106, 50.29093980789185, 46.01636825069305, 47.40389100966915, 48.53801296603296, 49.289637150303015, 49.5680195285428, 50.604517613687825, 48.89323849831858, 48.52455139160157, 49.257120701574514, 51.731077240359404, 39.69859092466293, 45.48231009514102, 53.7457359990766, 48.85296360138924, 48.97723213318856, 46.26532108552995, 43.611288532134026, 41.635931922543435, 38.848303441078436, 37.75154206060594, 36.212466762911895, 34.109766483306885, 36.743477236840036, 35.880308689609656, 36.49728575060445, 36.913025609908566, 37.835363111188336, 44.34347737220026, 48.6417047439083, 50.334438893102835, 50.43255306059315, 50.96195144038047, 50.26934716009325, 45.33343653525076, 38.47367394355036, 36.4332805141326, 35.72987010402065, 34.31467110110868, 38.0508973521571, 48.9030405013792, 52.18739009672596, 47.17023934087446, 49.29375171661378, 51.99066754310362, 51.15762279879663, 51.318694929922785, 48.4809503247661, 50.33872996607135, 49.75852512544202, 49.398922228044086, 48.87108102921517, 47.48782973135672, 44.22398236490066, 45.190003302789506, 45.336088057487245, 48.80985283082532, 52.79123898475401, 55.43929776837749, 57.419698546009684, 58.052776936561834, 39.488818645477295, 17.479766145829235, 2.8848579093333218, 2.99544055615702, 3.616867546112307, 10.427814279833148, 2.584010401079732, 2.7983595959601866, 0.7293820777727712, 0.007909555213465806, 0.8071539755309782, 10.53891247318637, 33.88452045379147, 25.083453309151437, 33.95525647747901, 44.00542789889921, 44.70409224110265, 14.063650408098775, 1.459026586624884, 0.07642449465610328, 0.01570017527668707, 0.05092268787144173, 0.024069057657353343, 0.060470828546151045, 0.013668571388529194, 0.03559179761777482, 0.02249518747351343, 0.09232474145509544, 0.05127373234098477, 0.014499663788404678, 0.10784379056384487, 0.10842893618128954, 0.026111878987942493, 0.026720441998012608, 0.010350364008768192, 0.03623600861418151, 0.06413048035615394, 0.10610526127199973, 0.024578877679643132, 0.08272227365523577, 0.009163815430515717, 0.05891520657666749, 0.04484374188787995, 0.03972339406309109, 0.03761221279179858, 0.08027714316643055, 0.025501138372947613, 0.007062669911031281, 0.04395898311368881, 0.01729318233687551, 0.09048210081434058, 0.024675002561942227, 0.034909121346690004, 0.056232221109131654, 0.06569619170360028, 0.02862904855470744, 0.11910771154948782, 0.031471273058184215, 0.008236656562545368, 0.0370161121170367, 5.786882562022056, 39.67836718405447, 50.63151528758388, 35.80722316618889, 26.282865078218524, 41.4318274682568, 42.173873224566066, 40.319411908426595, 13.628882150496207, 1.973085679834889, 13.768640122106, 21.347560459567656, 5.363439167699506, 5.006982011179771, 5.465721343794177, 5.319981757671603, 9.57024589661629, 32.66787575137231, 57.11621692103725, 54.38160319482127, 55.10948135006813, 50.77847865320022, 46.404796646487334, 46.93831743732576, 48.57718567694388, 52.14665628248646, 53.98914260248984, 56.061389600076986, 54.71897017571234, 52.43640961185579, 51.59828539817564, 53.059485958468535, 52.75732617224417, 53.36510135281471, 49.46968963069301, 38.157052378500666, 37.38525152206421, 38.48926928735549, 41.42422983723302, 45.25813487268264, 52.566899022748395, 52.80252364373977, 52.310352479257894, 52.504623551522535, 53.863058013300744, 48.76245098729288, 41.00193961974114, 37.49167719194966, 37.45064527757707, 37.09592965341384, 36.255553999254786, 35.445129563731534, 40.90965017195671, 52.11293174374489, 51.53436645384758, 52.360072443562174, 47.945323221145145, 48.469171447138635, 51.332191805685724, 51.577202658499445, 50.063108936432876, 52.4222537779039, 49.89916955271075, 51.71184585940454, 51.9167112535046, 53.09836449161653, 42.639121240185155, 48.973690232922955, 54.99486577126288, 48.9173649972485, 50.555778241926625, 49.001429234781575, 46.073015120721635, 43.09098612877631, 40.80339316398867, 39.413685644826586, 37.41940752152474, 36.53866283355221, 38.039334204889116, 37.29839063459827, 37.89129610984556, 38.79796374228693, 40.42328803770004, 44.913417370088645, 50.01882145481725, 50.950239243045935, 53.14428760159401, 53.43509604853969, 53.36277146493235, 48.01192114430089, 39.67360150429511, 37.89746992049679, 37.57478044879052, 36.907801012839045, 42.1529552244371, 50.709970535770545, 53.80027655632266, 49.667647730919626, 51.342264452288234, 53.445557009789255, 54.280500181259654, 54.53932562182027, 50.8235506088503, 51.54621985650832, 52.55240978733186, 51.487972659449426, 50.63262924071282, 48.17783348021969, 47.23679411795832, 46.02720575947916, 47.40920974362282, 50.94855262387184, 54.44427482543453, 57.17015343327677, 60.03160484375493, 59.185698647652906, 41.89596545311713, 19.258902265179543, 3.7686034556358092, 3.013974000369349, 7.726500986083862, 6.006855455137068, 4.448028572144048, 5.716190664998948, 0.7265486556195444, 0.03254232334814245, 1.088918601312945, 12.087342623741398, 40.90566504386164, 33.29250143420312, 39.328664348971465, 50.809222190610825, 49.75449685127505, 20.33198037455159, 2.1212707411858345, 0.048294278507631634, 0.12507585057568166, 0.07007333465040692, 0.010760440340926571, 0.06999893985208004, 0.0146374054395804, 0.03698312054057756, 0.055608548929974924, 0.08077093279890477, 0.07882831002315206, 0.007618387697279574, 0.045075326436950315, 0.05041705451965813, 0.032811465357700666, 0.017278919694945216, 0.06591517027587661, 0.03373363986611366, 0.025821646577828837, 0.24661736983445384, 0.12040779340050875, 0.12153579658197781, 0.07172770918376985, 0.23642512158520762, 0.09033826780655692, 0.10874755980987703, 0.13018391035016508, 0.20644132889086203, 0.11553168972773899, 0.1707241954582353, 0.17445167286261437, 0.19186662870549387, 0.2132231375623134, 0.13190607600394758, 0.1690943280775701, 0.12365609813000887, 0.18069505961912294, 0.10380988565063286, 0.13217613731901492, 0.16369363803777004, 0.09892803631843099, 0.3297762446586163, 6.919471361944753, 46.42805237923899, 58.906778904699514, 42.813905977433734, 35.9169985402015, 50.98530523238644, 46.27976325250442, 47.931489021547385, 15.200717083869444, 4.098897177365519, 16.388540210262423, 33.61393966982442, 10.860673323754343, 10.284650710321243, 12.857861845724045, 4.945097796378597, 11.499648997860572, 34.96303104585217, 57.593039851034845, 56.187862503913145, 57.96756736693844, 52.71596085640692, 50.73472069155786, 50.83948719886042, 51.49614295651836, 53.94663979930263, 56.73203252976941, 59.23464590503324, 56.60736391621252, 53.18129908653998, 52.34539493437737, 55.5688379656884, 54.88210547354914, 56.02728851379887, 49.80258118721747, 40.258811289264315, 39.32021164125012, 40.5514318712296, 44.18336622176632, 47.02817893797352, 55.71334592757687, 54.699515219657656, 54.29121217420025, 53.91763387187835, 54.4536453677762, 51.08663182104788, 42.92200649938276, 38.45306581066501, 39.12285366365987, 38.573125639269435, 38.33266865822577, 37.231667195597005, 43.26755946682346, 53.45613956451417, 54.54536607188564, 54.55618789119106, 49.52970189432944, 51.07462152358025, 53.26904250729469, 52.80703044706776, 52.24270336089596, 55.62929345715431, 53.50385127529022, 51.61225688072943, 55.2904438203381, 53.8392609934653, 43.99552783658428, 49.522441587140484, 55.571524789256436, 52.715384267991595, 53.73152917431247, 51.489875008983, 47.90975516842258, 46.39701466406546, 41.96645436748382, 40.704769088375954, 38.714181915406265, 37.70474818445022, 40.919044248519405, 39.31717572673675, 41.17863062889346, 40.303239976206136, 41.94430474312075, 49.19764972502186, 51.54529809951783, 53.46528260938583, 55.474912889542125, 56.262277710822325, 56.038855583437034, 50.10656879794214, 42.772779926176995, 39.82323208162862, 39.500248432159424, 38.48935557949928, 44.52054492888912, 53.711713360201934, 55.90544792913622, 50.040774960671705, 50.8276455633102, 55.14369226271107, 56.084311931364006, 57.35533245148198, 53.0840870641893, 53.60357361455118, 53.79162380772253, 53.19063040517992, 53.24164867401124, 51.66093741693805, 49.8548859934653, 48.901522544122514, 48.82144343468451, 54.75131404015326, 57.23794767933508, 58.59544077227193, 59.34209139116349, 63.00543608204011, 43.52122306823731, 21.432762184450706, 4.592816002907292, 8.453788334323514, 8.907941925910212, 19.680708069955152, 5.668481405704252, 8.706789055178243, 2.677856049230022, 0.1906727572842952, 1.8373488730961278, 15.906098484992983, 45.62615517647036, 37.6222332831352, 47.80404729227866, 57.63983764956075, 58.680434611535844, 22.513469303807906, 2.6817789096986098, 0.1402850247799389, 0.41307120734164793, 0.16990941498548756, 0.15524001101091986, 0.09496861047321752, 0.09505101089035312, 0.17839285815435071, 0.11543750687832795, 0.24411837570369246, 0.16523178937214036, 0.11860713437800446, 0.11460349759868077, 0.1525100566927464, 0.1411315519362688, 0.22341857273732463, 0.1284182079196457, 0.16511695279229074, 0.18154500352759517], [0.025337398570451527, 0.026801080412922368, 0.009229698992003838, 0.0780990402845125, 0.03178872265702775, 0.032367452288106564, 0.0240498288504539, 0.03459974439934858, 0.07020631985318276, 0.03519239384801157, 0.030967033986422806, 0.020327018836753506, 0.04351999558087799, 0.027869843930426626, 0.06276458006111846, 0.08629775155455836, 0.035338720471988765, 0.019225715734665434, 0.026807140168403427, 0.11518744811896356, 0.06500498887391822, 0.07001773198886264, 0.015522872845101503, 1.0656072199344635, 19.65976261323498, 41.77326979175691, 36.25560499006702, 31.926694877686042, 24.327783200048632, 36.9825456988427, 43.280970050442605, 19.333152732541485, 2.488628164414437, 14.187336467927503, 34.29452188553349, 34.703209323267785, 14.629391508717692, 4.442435272278325, 5.306461837983901, 6.628208410355353, 38.149635176504816, 48.73043267957626, 57.15383245098976, 53.51186859992243, 52.64757433245259, 47.784964961390344, 51.86022127828291, 50.42082517377792, 53.2589110251396, 53.49851292948569, 52.54952292288504, 49.173860549926765, 53.53006839752198, 50.445132101735766, 52.260750186058786, 47.39441064096267, 48.58358306269492, 39.82425974261376, 35.48562411339053, 36.78130065241168, 38.36709922359836, 39.21138155844904, 46.92729557714155, 48.63642523365636, 52.25632183013424, 50.541900896256976, 51.44579933535669, 50.027897819395996, 48.205847047990375, 38.06377057106265, 36.00034498399304, 34.48291332490983, 36.285403236266106, 38.36267086767381, 38.393845865803385, 34.471460004006666, 48.76536530833091, 47.92635071662165, 51.39934278303578, 49.96356702619984, 48.789240775569795, 46.22869791523103, 47.24222660064698, 46.185795030286236, 50.33748265235655, 45.57342675424392, 50.916793192586596, 42.44915693036972, 41.77478382664342, 40.145874484892815, 46.17093316970333, 53.49113495119157, 47.30975412553357, 49.86430360424904, 44.59490914498606, 42.498363064181426, 37.38310990795013, 37.787102268588164, 38.8123353065983, 38.0180984927762, 35.89454297096499, 36.023702698369185, 35.90851837588895, 35.94276851223361, 36.486597291884884, 38.27388801882344, 45.84123834486931, 51.60651453079716, 51.17602655964514, 50.99221252625989, 48.054678901549316, 47.4657154083252, 41.35167383378552, 36.60123640491117, 39.63931214424872, 35.712121378990915, 36.981270928536695, 36.77977092804448, 46.514991714108376, 50.44232368469239, 50.99850793038645, 50.51933157828547, 51.10840097550423, 50.87607899019795, 51.3587462517523, 52.95336623345652, 52.005309750956876, 52.136524800331365, 52.36711702039165, 51.82889330771662, 50.24400864878009, 50.3045621995003, 47.46745301831154, 49.89040305537563, 46.33035790535712, 51.94705470915764, 54.2882860860517, 57.88007497787476, 53.06612653117026, 36.66338636029151, 10.726156619287307, 3.6497708385990517, 2.2152296477748505, 10.118923706393089, 16.784578984783543, 3.926544064475644, 2.0573498356726865, 0.8695582721021868, 0.1859346566902053, 0.747382263502767, 15.599252447005242, 35.86700008761498, 35.278770077613096, 27.431013430318526, 48.28326286808137, 42.296588497777144, 10.998719180783919, 0.7566096393331405, 0.04457153935706423, 0.026723604025920073, 0.14943649661877464, 0.06170730977769821, 0.07523974734208277, 0.011804270569325216, 0.039153145025334055, 0.1154229665295251, 0.033355824454056646, 0.041626973167782834, 0.03843668044634885, 0.042886456189256524, 0.022230534739191496, 0.0553284710152976, 0.08546788681058154, 0.050413162793002786, 0.03456938050446972, 0.03003786701048094, 0.025994485589645566, 0.03148654502095475, 0.013719555497499964, 0.04771037012218468, 0.04761980320777624, 0.036823038807919914, 0.025874491322845704, 0.028505666264062448, 0.06452934020349095, 0.04303792326320564, 0.025080856792027914, 0.028453156682512457, 0.05697019743703066, 0.020492761959171584, 0.049859859620130835, 0.0637293950233969, 0.02087579634521277, 0.009090694253362957, 0.007172982262883096, 0.04389427166672484, 0.06436981771501803, 0.048487619947521925, 0.054296071776339126, 1.5868706039844023, 25.326897175081317, 48.81346141138385, 40.69402179410381, 34.247680940935695, 32.87213513928075, 41.08366220228134, 48.10106485120712, 20.79705776706819, 4.34561352575979, 14.446495309952768, 40.90804984492641, 24.206428989287346, 7.698557040383739, 5.004178497099108, 3.4601154154346836, 8.665418836378283, 37.048551344102435, 52.20786094665528, 57.17761378134451, 54.15824774772891, 53.22064830410866, 49.79563074727213, 53.67130510268673, 53.04473392425045, 53.931424925404215, 54.49302596430625, 53.94100335336501, 49.67591608724287, 53.8209709813518, 52.58549890210552, 54.817523648661954, 50.54909844552317, 51.05250720054873, 42.8130038322941, 36.80504668143488, 38.94224812907558, 38.72656483804026, 42.523093608117875, 48.47817720905427, 51.288990820607836, 52.994535430785156, 51.19545798147879, 54.37387612558181, 52.59610499105146, 48.26312149724653, 39.60811753426829, 37.82384310999225, 36.71176095162669, 37.12717917657668, 39.78634611252816, 39.45439984721523, 37.62361787980603, 50.342875911343484, 51.34531997865247, 52.84864679459603, 51.30304859530542, 49.80981796018539, 47.89261833313973, 48.197523778484715, 48.28593792453889, 51.529745901784594, 48.739960116724816, 52.24752787620791, 45.68774423291607, 42.77155222431306, 43.02547862452846, 49.13746879946802, 55.24180643020138, 50.04836082458497, 52.38306537751229, 45.555732942396595, 44.491911626631214, 40.41362723996563, 39.4668572948825, 40.23968188993393, 39.09101578497118, 37.97501517880348, 38.18754880659042, 37.9417299455212, 37.61884435530632, 37.888064076823575, 40.094369842160134, 46.67782106707173, 54.01789749822309, 53.117697854195875, 52.246045220282774, 51.23590938506588, 50.675155578121064, 44.827219363181825, 39.07071751932944, 41.32979485296434, 37.46194954841368, 38.4176742646002, 38.56295101104244, 48.74665560260896, 53.1452799612476, 52.963799738114886, 49.82740979040823, 52.681012538171586, 52.74721430193994, 52.892702856371486, 53.47186042416481, 53.69888720973846, 53.89302099904707, 53.16299338494578, 52.76101712257632, 52.75749875653175, 51.10838136365337, 49.065999292558246, 49.5696198555731, 49.56146524798486, 53.99476335894678, 57.418129597940755, 58.78714661444388, 55.63716565409015, 37.77728849841703, 12.834039330482485, 3.1003789123027556, 4.692836932597622, 7.891087070588143, 11.93429958435797, 5.52479959303333, 2.8779386032012204, 0.9298135388282038, 0.06075998460273109, 0.9417139486439767, 16.424894698204533, 39.36040416840584, 35.93317439479213, 33.3550436266007, 52.94516063505604, 50.95734657779817, 14.616502600331462, 0.9420144389713965, 0.06984110275704054, 0.0748626022569595, 0.03330277286530022, 0.019983826768434337, 0.012004743330180647, 0.04242054832678649, 0.06393051225571864, 0.060637824222325325, 0.050820166154974894, 0.0401930212824335, 0.021886837052842303, 0.023590873235896714, 0.04821777696751299, 0.03948662692921297, 0.0371184844463583, 0.03924216827257507, 0.017529401717887774, 0.042529899717098286, 0.16113288189855315, 0.1080259892548765, 0.11278444480511451, 0.14055606668754933, 0.205837115344982, 0.1193552805230983, 0.08060060847069948, 0.11997463962724132, 0.16865856194448087, 0.14902858544261227, 0.17087629455472195, 0.09005180454903072, 0.17481559527016458, 0.06326353312620232, 0.18016969184240988, 0.34354590900963355, 0.1271062823493154, 0.11686208567792371, 0.08189481442734119, 0.16227283605164097, 0.17585320007656852, 0.10141102687245417, 0.16629410817498164, 2.104288104080385, 28.80484123383799, 57.28243127945931, 47.52469216623614, 42.540708972561745, 35.15890636751729, 46.83610831537555, 53.40854160247311, 24.713687550637033, 4.633193862053656, 14.869221891126326, 41.62663590523505, 47.1628378283593, 29.71139119517419, 12.002465474990107, 9.229132071618112, 8.125169219509248, 42.25565856502902, 53.145884006254136, 60.29912617898757, 57.06090365686725, 56.61813082233552, 51.158309213576786, 56.63981368464809, 56.425938606262214, 57.700740291226296, 57.92352699464368, 54.74952936172486, 50.31869842160133, 55.69317317778065, 54.53532480424451, 56.81256271177723, 52.404034368453495, 53.587770385126916, 44.48774606950822, 38.746027638835294, 40.42643770094841, 41.359793140042214, 43.41724103496921, 50.90796001495854, 52.709218302080714, 54.533481290263516, 51.88098238360498, 55.697766273252434, 55.80854577402915, 52.337679632248424, 41.40362562671785, 40.32607601534936, 38.538934338477354, 39.081998255945024, 41.59435872108706, 41.309888824339836, 39.43376425773867, 52.60826433858564, 53.17303073021674, 55.83590430598105, 53.9786502622789, 50.97675838778096, 49.04084513264318, 48.77729715839509, 49.73513210973432, 52.34770128803869, 51.854361257245465, 55.043173682305124, 50.12821635892315, 48.14632900299565, 48.08357500260877, 52.14054915212816, 57.64073979470038, 53.216502358836514, 54.65832641047817, 51.30368009690316, 47.18966684033794, 41.73764290348176, 42.06344281473468, 43.24734749332551, 42.16109806491483, 39.19185599973125, 39.53689513667938, 39.46726129901025, 39.51036422483383, 40.064967755348455, 41.87371384712958, 49.182030846995694, 56.786031799931685, 54.71849556892149, 54.351314652350645, 51.991922701558764, 52.14107867210142, 46.714612899288056, 40.71019764869444, 42.54906362102878, 39.28519664272186, 41.327359061087336, 40.218861949059274, 50.59548831755116, 54.543106786666385, 56.09954641711328, 51.5772654164222, 53.116693727431766, 52.60435765789401, 53.50360024359919, 55.255397442848455, 56.757575004331535, 56.50685710291709, 55.709192137564386, 55.34424697199176, 56.25800624970467, 55.27420913019488, 49.84569980252174, 54.59002617866763, 49.889147896920484, 57.28155659091089, 59.09775910838958, 62.013849135368105, 55.910013568016794, 40.31291646342124, 13.302420339276715, 6.128207704713268, 6.654750108718873, 19.638711252520164, 22.544216763588693, 10.832775465903744, 10.26618124977235, 2.4171905267623166, 0.5491334175871265, 1.180898059279688, 22.0299175477797, 46.81218185732442, 46.172906121900006, 41.415075025250836, 60.78408802709272, 57.696496286699855, 18.268290027495354, 1.1097059374855411, 0.22766536582381497, 0.17371193836292914, 0.22406835319294086, 0.10155946406866274, 0.14669669040989491, 0.165729945705783, 0.1193429158640004, 0.17825087141846457, 0.171546483592641, 0.19785503075728494, 0.14772972933227016, 0.07427543416739472, 0.11373601027674253, 0.09236301520779248, 0.14923550579096043, 0.06363119404282301, 0.19347712938343326, 0.17282464000726902], [0.03615903976042906, 0.02652116720714877, 0.04417891929587049, 0.02402688068668208, 0.06306099097034143, 0.07811921904043806, 0.06432994283855924, 0.03707809246055061, 0.043302288714555964, 0.046477995121911655, 0.01871870725505775, 0.047576055756860205, 0.07201026539288222, 0.07977930858971612, 0.012032968882140855, 0.06128414962140303, 0.039467723709681345, 0.04734060629421184, 0.013466373014624321, 0.0396386877213034, 0.026851353017733465, 0.044201400146008506, 0.07578400684700859, 0.1253806463172359, 12.565833541654772, 39.67746896128501, 48.823718409384455, 32.05651944683444, 32.14777535007846, 34.2418562212298, 41.9055046573762, 20.864824556535293, 5.107650622244805, 3.6482310631582817, 21.80684058896957, 42.98481541295206, 36.421631074720814, 6.319462964611669, 1.943316361115825, 7.598336069814621, 30.406909796499438, 52.8881529069716, 56.32504347831973, 54.43188798043036, 52.43556237989857, 54.201025116828184, 52.02605908916843, 54.81788450671781, 50.81736110871839, 51.254391593317834, 52.74805368915681, 52.31722054942962, 50.87504740684263, 52.09291196638539, 49.63690811587919, 46.403635624916326, 40.3134891294664, 36.73229063710859, 36.0111040453757, 37.200860900263635, 38.504613599469586, 40.44224093037267, 45.27942942034814, 51.36610461819557, 52.24034993879257, 53.03462597631639, 51.811681947400494, 50.96654845822243, 48.67586074336883, 38.00123230103524, 37.471810387026885, 34.769866081976126, 35.52279641551357, 36.37588447140109, 37.72713707339379, 35.51776009221231, 42.63800728705622, 50.55628030530868, 51.23646636163035, 54.60640599650722, 51.73606649521859, 50.98009240242743, 48.09478905893142, 45.4869737932759, 46.52721381956532, 42.45435799321821, 44.51685790092715, 43.06999752598424, 45.74379098030829, 41.33311317813012, 47.51314078607867, 51.207021128746774, 46.9544069997726, 49.29325357560189, 43.15696431744484, 42.00977302366688, 40.31979237833331, 41.127310337558875, 37.984444556697724, 37.61178801136632, 36.07712538011613, 37.66220615756127, 36.49694842676963, 37.009060921207556, 33.89806832036665, 41.150165988552956, 45.38897337452058, 51.073040808400805, 50.45698158202633, 50.28420902067616, 49.73435548044021, 48.41885528256817, 43.37777806866554, 39.61890012987199, 36.29127894678424, 37.061157841836255, 35.856562660586455, 36.011759081194484, 38.97123052227882, 49.570482777011016, 47.279198861891224, 51.512287432147616, 54.93304137260684, 50.41367469295379, 45.65800482226957, 52.95346037034066, 49.9186441206163, 47.274641067751, 52.03841063284105, 53.75671471318891, 52.67427782858572, 52.61907439078055, 50.33211292759065, 49.89746724405597, 48.61488357667, 51.78568055552822, 56.12454760459162, 58.38852005620157, 53.193929118494836, 32.460296077113, 8.926854614288576, 0.7161183991739828, 2.673884649430552, 8.612663938153176, 13.627919208618904, 9.724312674614692, 3.427279538685276, 0.40235636455397455, 0.15466975048184395, 1.405475814977, 15.095343589782717, 28.930935628952522, 32.06337771108074, 36.681523399968306, 48.005653196765536, 37.417116857344105, 4.397151508638936, 0.18173120885847077, 0.008075423782781489, 0.0368710916729704, 0.030203686741691445, 0.06886737436176309, 0.025022904155775908, 0.027467651600618998, 0.024784198819449352, 0.03553003177887971, 0.019116077061382034, 0.12002304106229737, 0.019754551974455678, 0.04857714498235334, 0.01129483263338766, 0.08138595584539637, 0.025787998080974626, 0.07005747663037432, 0.03605872054674453, 0.04064651085965095, 0.0792552201798366, 0.08840653114020826, 0.043328477430247495, 0.03388590750194365, 0.018815107929009586, 0.013897691049703188, 0.04048892657362646, 0.03139260923489928, 0.022718287598822388, 0.02033697606454934, 0.011540904862716073, 0.07068542358014854, 0.037371913992589524, 0.04762176056242278, 0.0704268382621869, 0.09489967788179075, 0.03186828088796428, 0.05235440661049178, 0.03761216682652312, 0.04180865091902595, 0.0247594733316932, 0.0429875529821842, 0.017253408967066678, 0.3626409263139771, 15.325233705582159, 45.87488443620744, 53.77620104820498, 36.643637226473906, 31.74281220282278, 40.533863575227805, 49.04461453037877, 24.910821953127464, 5.179744766604516, 4.5876517122791665, 27.88547100559358, 46.547084546858265, 29.6353482046435, 8.853369009110237, 2.2589157810134273, 7.693086314585901, 31.73424574636644, 54.575595778803674, 55.62414730748823, 56.515078390798266, 53.23129361675632, 55.541236246785815, 54.31001209443616, 56.89826650004233, 52.90341484931208, 52.39690742185039, 52.88707817754438, 53.88975366469353, 53.20483330757388, 52.173465682614236, 49.774457793081964, 49.15018120119649, 43.198051144999845, 38.0664966183324, 37.401941207147416, 39.12490114088982, 40.211727157715835, 42.50971832583028, 46.72397951925955, 52.51286445125457, 53.49095844453382, 53.85987304872083, 53.19518427694998, 52.73226614921324, 50.906222404972205, 41.926865885334635, 38.34557325609269, 36.77697035574144, 38.70264622472948, 38.7160332741276, 39.49749492829846, 37.37089172486336, 44.35574262372909, 52.69384261100523, 52.47830052529612, 55.19450656829342, 53.610928058624275, 52.52463940651187, 47.68096723864156, 46.69595026200818, 47.1883685358109, 45.078631524116766, 46.055525272123276, 45.79954354993759, 48.12861950166764, 43.14917841265279, 50.22620893293812, 53.221189591192434, 49.18439211383943, 50.737497729639855, 45.32901994643673, 43.14775851465041, 41.07834346832768, 44.07399092951129, 40.30456573732438, 39.938083002644206, 38.08316276919457, 38.508253558989495, 38.05429412472633, 39.33270046787877, 37.347373193310155, 41.603858701644405, 47.1899845523219, 52.212277535469305, 52.359872402683386, 52.17435213827318, 51.13308052862845, 50.378204699485536, 45.051782900287265, 40.150651931762695, 38.5486618165047, 37.86453377815985, 36.482263072844475, 37.5665944622409, 40.890430558112364, 52.317428435048754, 49.66028151973602, 54.068703959065104, 56.31704968790854, 51.30731221168272, 47.01781603597826, 52.64931194243893, 52.569354426476266, 50.62591806534798, 53.02926409629084, 55.312248276126006, 53.95857164936682, 54.60722577187323, 52.92070465703165, 52.060097417523785, 49.710166223587535, 54.35827685940651, 58.607156891976636, 59.335113494626945, 54.79531126637613, 33.28850061662736, 9.892095981105681, 2.179469153765709, 4.298629904946973, 10.985299771831883, 19.927415347868397, 11.862020108007616, 4.054783260630024, 0.31092974627690934, 0.05666812513804725, 1.7110073686607423, 18.131528746697214, 37.67482834477579, 39.478977418714955, 41.52923953148627, 53.510272195262296, 45.359159438840805, 7.30647691795903, 0.35189933173598786, 0.04817933850591222, 0.04984332361228524, 0.04551607597198698, 0.036752868984495445, 0.03219897040135918, 0.03813801340818886, 0.02170841709049719, 0.007864076403840896, 0.0028552724172421283, 0.0279113429132849, 0.042906125496712424, 0.021973178992348335, 0.04746084762436729, 0.025577967415653893, 0.040585388534612236, 0.091751056512998, 0.07986926263378513, 0.00869742589026329, 0.12421698174289159, 0.0960087816741678, 0.1455682275756713, 0.10754470217732653, 0.19084027006981835, 0.1754897373217729, 0.1448982990076465, 0.1298813975506252, 0.22180490045537873, 0.10523418865857587, 0.09854898367437626, 0.1755062235339034, 0.2757883738846548, 0.20950842318275284, 0.16359323455441385, 0.13175462042131733, 0.1539272887091483, 0.1486733504721234, 0.07406451484008182, 0.19960119028485593, 0.236098921347049, 0.19442421324070425, 0.17782108077118475, 0.41239925630150304, 17.198942092157182, 53.53927027794623, 62.65532924282936, 42.21674473054948, 41.55568022881785, 44.3221906692751, 55.33055397772021, 28.699149047174764, 7.801357949933699, 4.291748596775917, 28.818806832836522, 49.68199183863979, 41.574284030545144, 14.098401627232953, 5.4675570130348214, 9.567672821783251, 35.322002441652366, 57.07145483263078, 57.72618470653411, 58.67278991207, 56.894089175808816, 58.94402573185583, 56.1277953270943, 59.45108229114164, 52.88169276329779, 53.964121803160644, 55.45998434866629, 56.267341490714784, 56.07629068436162, 55.960874942041215, 52.90983184691399, 51.04146965088383, 44.007589124864154, 39.865950615175315, 39.838262604128936, 42.156956042012865, 42.212045731083045, 46.2722558359946, 48.856238780483125, 54.60056166495047, 56.042295502078154, 54.84630207861624, 53.520203636538604, 55.681488437037316, 53.747438307731386, 43.47270334920576, 41.61990904038952, 38.98721418073101, 39.56939197355701, 40.675547430592204, 39.242823277750325, 39.255268958307084, 45.71234141626666, 54.100400632427586, 55.67087450335103, 57.739512920379646, 56.16738773161366, 53.745708542485396, 50.11888504028321, 47.27055003566127, 48.30690691548009, 46.65914666268134, 46.509786728889715, 47.41983936678979, 47.26993422354422, 47.758277154737904, 52.045600337366906, 54.072587105535696, 52.59001747254403, 53.473260710316325, 49.261580436460434, 46.543162176685954, 44.07903117518271, 44.46456878416, 42.524180104655606, 40.65496675429806, 39.21241314180436, 40.68737337666173, 39.864291452592425, 40.26277680550852, 38.35277472772906, 44.542235635942035, 49.99188261647379, 54.278452704029704, 54.83310722535657, 55.277021469608435, 52.12786812936106, 52.24329171642181, 48.96945015076668, 43.09729722238357, 40.58184985191592, 40.148314199139996, 39.73820686340332, 40.10092412271808, 43.15771741251792, 54.411091573776744, 50.96185338112616, 55.304689868803955, 58.123512960249386, 52.93061648645709, 47.539416743863015, 55.73939046552105, 55.17860135724468, 50.95527556634719, 54.63374491660826, 58.992694500953924, 56.95253249137633, 56.7005241301752, 55.133274447533395, 55.84589458280995, 53.058881913461995, 56.78350971591089, 61.35185110953547, 61.72058528469455, 56.351362582175966, 36.02897436388078, 11.794686740444554, 1.7952413712778401, 6.817356867174949, 17.94016218954517, 19.072322960822813, 18.734422537588305, 9.125016677764155, 1.681590695534983, 0.2767504883870002, 2.470346977633815, 22.327901970955637, 42.73394061673073, 43.35555784163937, 49.57132608659806, 60.972773644231985, 51.55987754944832, 9.529213001651149, 0.44797132332478806, 0.1623670648663275, 0.17663422671537246, 0.14680869246442474, 0.13058604522337838, 0.1822806777612817, 0.156998765023966, 0.13253612203463433, 0.1183848922711707, 0.28411237883471674, 0.18561380374575817, 0.15049950490074773, 0.1646475553993256, 0.1813983436553709, 0.1975792237827855, 0.08764592074458638, 0.19033046919972668, 0.12765791162007278, 0.07515259717981662], [0.06411662948648296, 0.006713353927367397, 0.0751456334405849, 0.08858949591916415, 0.015956334011148543, 0.017981144614637862, 0.03696696374625449, 0.02768693277762542, 0.05740219824797204, 0.03357594449734015, 0.07472852154845193, 0.016225631153511427, 0.016951466903030392, 0.03689542645588517, 0.09958546233153152, 0.07714162190114299, 0.04629839729938296, 0.06420289864763618, 0.033198427859573595, 0.014084384761630528, 0.08217724040150642, 0.035952464151646824, 0.044567253095127886, 0.06438458022931892, 5.105264840587493, 29.34990163772337, 48.80629131870885, 39.96123675377139, 30.770548812804687, 28.352872402437274, 43.71653356859761, 30.771953021326375, 8.20707272137365, 1.0598300589669136, 3.745476180507291, 26.851161603004705, 24.72691966641334, 12.279890794907848, 0.4781170976498435, 7.358094328834165, 30.311562861165694, 46.46280065659554, 51.530706882476814, 60.97324432865266, 53.94960118878273, 57.18918477335284, 51.00252443744291, 52.68713535801057, 49.90888918599775, 53.65417218977406, 54.50289857002997, 50.60304280250303, 45.62105609524635, 48.16980438847696, 44.26810510696904, 39.397035183445105, 36.49191602583855, 39.00535906514814, 38.14727390966108, 36.69016045908774, 37.631909770350305, 38.18749389340801, 45.314820966412945, 48.94642583785519, 51.911549414357836, 50.36779472904821, 50.98124165688792, 52.62937845722322, 47.49180701471145, 38.103123711001494, 35.90576487202799, 37.501263464650805, 38.101523383971184, 35.983835727937766, 34.281880086468114, 33.896267952457556, 37.185602880293324, 45.30288519397859, 49.568521591924856, 48.00126014217254, 49.40425272910826, 50.038688259740034, 52.42495629095262, 51.27727470090313, 51.17610892941875, 49.90216232115223, 51.18830357828448, 46.3564024433013, 46.322324891244214, 43.56075663720408, 48.29069968192808, 52.34424567991688, 46.08569614348873, 46.54209529199908, 39.95693783606253, 39.331394318611395, 38.23804540018882, 37.349350067877005, 35.70252333917926, 35.2653516492536, 35.4605209442877, 37.08661010188442, 35.38038692166729, 37.093999847289055, 36.55424641024682, 37.96462089784684, 45.31996711607903, 51.07486078816076, 48.83804682762393, 52.201506706976126, 51.742287374311886, 50.14145043588454, 48.96664957846365, 46.91081770004765, 41.939111525012606, 37.78276020480741, 36.5599456141072, 37.0165212692753, 36.15855378489341, 40.30134939378308, 45.444392542685236, 49.12259909414476, 46.99894551307925, 52.66753527425951, 47.49863586118145, 48.98405313491822, 47.23526047122094, 49.37381121420091, 50.49716626444171, 53.06040771545903, 55.20146093060894, 53.221472001844845, 53.002023235444106, 52.795345706324426, 49.28989994910456, 51.7779181849572, 55.15187824926069, 56.55177216376028, 47.914340419154016, 32.83272316378932, 10.030173217096637, 1.159040774068525, 3.738368110310647, 9.25083258459645, 23.556135316048902, 9.529737618661697, 1.407323006180025, 0.3445338866403026, 0.028445051472273566, 2.0708717165454744, 16.93280731478045, 33.595794785407286, 33.58532597941737, 37.32862034151631, 49.83865914806243, 27.409310956155103, 1.9764855167558117, 0.028514031944195592, 0.06164300818777373, 0.04883524766492267, 0.015266459386405206, 0.1523498983512963, 0.04752113491356854, 0.044579483688839024, 0.06628738175476752, 0.028573702532617797, 0.029248892209462585, 0.014337310605051537, 0.10844169920610805, 0.016685159418792013, 0.11007219477887116, 0.021980451081969568, 0.025430185224620566, 0.06594017538572512, 0.024334738864713622, 0.024299596496407064, 0.02278373832063329, 0.03555405629618514, 0.013213273843810444, 0.04691560752689839, 0.09019565287857287, 0.015331342245542235, 0.052167270482788165, 0.028460131913063028, 0.0878640029939913, 0.04137014602160743, 0.05541134640694626, 0.08821061181445276, 0.04239687620992622, 0.09262952187489118, 0.025741850859635783, 0.044992968154650544, 0.008914597452648224, 0.008293639139963255, 0.03170844047300277, 0.054586576147665905, 0.035530135200749484, 0.05601408906401165, 0.05959247809744651, 0.052392894867807634, 7.2082166421797975, 37.34734181434878, 55.261171171742106, 44.493919880159446, 34.490660006000155, 31.678971705898164, 49.41099920580464, 32.32178934158818, 11.08195677880318, 1.4766461185870634, 5.5491423126189945, 29.74104823604707, 24.592751072299098, 13.459279844837805, 2.1318741335022837, 7.141045072386342, 31.832522692218905, 47.513901725892104, 52.119642919109715, 60.25987109830303, 55.89354353566324, 58.40572749414752, 52.89224393906132, 52.107001120044345, 51.816082846733835, 54.3361193903031, 57.27530041048604, 50.45431044793899, 48.522205814238525, 49.90231137121878, 46.317849466877604, 42.70285583311512, 37.61608300670501, 39.57298878700503, 39.32043129397977, 38.82766785160188, 40.08321854376024, 39.74763624129757, 47.56746953533542, 51.755929377771196, 53.30390845575641, 50.48079429134246, 52.81435743454964, 53.500823205517186, 49.83700783021989, 40.69114277439733, 37.8882170492603, 38.397697633312596, 39.26985625297793, 37.09850665061705, 35.88942820026029, 36.49925870280112, 39.85822354593585, 47.44151438436201, 52.01732004842451, 50.449148608792214, 52.06237239222373, 51.9897222518921, 53.72286073623165, 53.36168104602445, 53.44733384347732, 51.319428413145005, 50.541838138334214, 48.71763790807417, 46.99854543132167, 44.342618373132524, 50.68253747878536, 53.63488197326661, 49.56268902747862, 46.78053617477418, 41.812234617048695, 41.52070837636148, 41.390042458811116, 39.314830149373705, 38.11218830846971, 37.6046649871334, 37.27784918200585, 38.74198759755781, 37.577730071160104, 37.787208172582815, 38.160068681163175, 40.7117626743932, 47.956576501169515, 52.67373261913177, 50.18884443467664, 53.28465746295068, 52.08786779834379, 51.77983230160129, 51.017488279650294, 48.7583677999435, 43.90270494645642, 39.269134536866225, 38.16809385053573, 38.484487918115434, 36.6274299929219, 43.42641545880226, 48.89516045970302, 51.71031613503733, 51.53750827235561, 54.55240672634494, 51.54307019325995, 51.84748926470357, 49.94311971049155, 49.16838492116621, 53.41958699687835, 55.05532126272879, 56.3913550684529, 54.65853821846747, 54.31130255422285, 53.24102893952401, 52.50891070212088, 53.92460392367456, 56.90655446821644, 59.16361962595294, 51.177885763106815, 35.96496520503875, 11.327951165937609, 0.8700355755225305, 4.466321035738915, 10.221105371752094, 25.76037399230465, 10.4353658230074, 3.599831221565124, 0.718117643508219, 0.06438792037266879, 2.2039945087125226, 19.74959077373628, 34.31323551362561, 37.439258636966834, 43.989710961618734, 56.70257160740515, 33.61398673826648, 2.838225095502792, 0.07826098361082616, 0.030852854326968233, 0.014398682866275552, 0.08256931654027394, 0.07999512321886518, 0.0878391970670031, 0.03236873548537974, 0.07349443817210775, 0.0587103929701111, 0.029686359057743705, 0.054226051340059894, 0.039019929996180924, 0.014453167997060284, 0.020595875478559927, 0.008422347656901806, 0.01082490951258449, 0.02573667785092708, 0.08548976628169899, 0.026858749596642393, 0.2392428082924697, 0.09136699365391847, 0.14834557209284077, 0.18902710849238982, 0.21898607993798874, 0.08173597375712088, 0.11015028978187232, 0.14307139381285638, 0.1627891946343645, 0.1111163649587862, 0.18607955456020372, 0.17172899637972155, 0.11930798991553246, 0.17174701476770063, 0.17779512571231013, 0.14525865144546957, 0.08948596434727793, 0.11877542091233116, 0.19201076048756802, 0.23316066772226365, 0.2187596396693299, 0.12763994685824842, 0.24748882549183987, 0.17407022236335665, 7.804719421171374, 41.83203081930838, 62.03619487823979, 53.59570141761534, 41.52231654813213, 38.59669123926471, 58.08075520300097, 38.59877794019638, 11.92675490533152, 1.6006942622123228, 5.928156529703449, 35.017818712419086, 28.60875802655374, 18.84408220168083, 5.349338246930031, 9.863284211004935, 35.081702355415594, 50.09041255520236, 52.533005822089414, 61.5399601382594, 56.424601078033454, 60.1224704711668, 53.663985959945194, 53.60118881348641, 52.04884021512924, 56.38134517977315, 60.05965371285716, 55.513599226551676, 50.01154153577743, 52.02207788344353, 48.52422975724744, 42.92317144332394, 38.900631781547304, 43.33854652220204, 43.20141261623752, 40.19758309087446, 41.06576442718506, 41.68227472612935, 49.034522271925404, 53.721711481771166, 56.161672838272594, 50.172594055052734, 53.15008486470869, 55.67064700588104, 50.97099642599783, 42.47895909893898, 39.405201558143865, 40.44715173782841, 41.728888173257154, 39.31262577733686, 37.307439542585804, 38.16188081618279, 41.30313842527328, 48.919741953572924, 54.065369944418634, 51.0992814648536, 55.54789643133841, 54.60967333086076, 56.15981363481092, 56.54253890437465, 54.056646593155406, 52.88369317208567, 51.97463681620937, 50.63898348039197, 45.403799933771936, 47.383471150552076, 53.36954539821994, 56.54360186669135, 52.57034678612986, 49.87194830371488, 43.384995229782604, 42.897056302716656, 42.18071776051676, 40.79483847464285, 38.21234995318998, 39.17852386351555, 37.888703423161665, 41.97515026215584, 40.21071910858154, 39.9487518495129, 40.278474130938136, 40.673962793042584, 49.76768778216455, 52.611237495176255, 51.68773504995531, 54.68174688277706, 53.90217581102925, 52.84053141070951, 52.60901743365873, 51.36725387265606, 46.884463294859856, 42.059489065600985, 40.45814221905124, 40.27428111722393, 39.18459177017212, 45.70541058817218, 51.52697278607277, 53.18844564499394, 53.254415988922126, 57.25789685403147, 52.50713386843282, 51.86903092168993, 50.02275559210008, 49.19392739572833, 51.44736828342561, 55.55928699431881, 58.66574925761069, 57.468155507118475, 57.72874209188647, 56.084641410458474, 55.08970868202948, 55.223751760298214, 60.1618157663653, 60.28877504410283, 52.05930117637881, 38.65528360489876, 14.41722756431949, 2.2842023209218056, 9.294800393043026, 18.42542213778342, 28.140795730775405, 16.858817685034968, 6.660547371833555, 1.5040237720935576, 0.18220350206378969, 3.134771970010573, 24.191155279836348, 45.45643421911424, 44.32930584876768, 50.15020124373898, 64.38279205752958, 39.245553247390255, 4.0465445672312095, 0.11692509640969577, 0.1757183226366197, 0.15472801912936474, 0.15887678360506413, 0.197800132896631, 0.1501676815772249, 0.12896154045818314, 0.11999376118183137, 0.1331138442600927, 0.09261400859442451, 0.16090182978059017, 0.14766931563856142, 0.17052524242429964, 0.19259234379616477, 0.1406340544382411, 0.16595987933537654, 0.12710883342210325, 0.14666678233733102, 0.15907936789576085], [0.027434979865868247, 0.057907682212610403, 0.061751716064229134, 0.051060192992970835, 0.036657468055284796, 0.03681462716251131, 0.031293289765955946, 0.04844464624540941, 0.008287922208828312, 0.07365582225423667, 0.10226067966751515, 0.07968885658849632, 0.06545252211752438, 0.01918793036302011, 0.02510245281061338, 0.03348007625449569, 0.033318956472700646, 0.06960542346801489, 0.024748010741126154, 0.043479959825955095, 0.07236879454144547, 0.013856735031661249, 0.07059268097603513, 0.061853019700896364, 1.133303406738466, 24.43899416154431, 50.869603157043464, 39.873352127690474, 32.545142827495454, 39.16986327017508, 47.708247323190015, 33.076159184978856, 6.446574234193371, 0.9247791767120362, 1.2957831784602136, 20.90808241598068, 20.64805280777716, 13.12035176061815, 2.796229748956619, 4.550078347806008, 24.082578189911384, 43.72781822758336, 55.89750512953728, 54.732925968785445, 54.60885355549475, 52.44701177843156, 52.4267448917512, 55.92057258852067, 55.94453042553317, 53.48592996597291, 50.079692717521425, 49.48647345266035, 45.451743064388154, 41.586204113498816, 38.33648120203326, 37.90882518214565, 37.29867304525068, 37.258123582409276, 35.97315119158837, 36.47822303156699, 39.36744874523532, 39.31141376495361, 42.787928119782485, 49.280705913420654, 52.603710466815585, 52.77074460060366, 49.40229938876245, 50.990729870334754, 48.7056903685293, 41.114566556869015, 37.16701476804672, 36.523138092410186, 37.624794590857725, 37.78918504714966, 36.32781974730953, 35.343096948439076, 37.70203390429097, 40.539558856718, 45.94305915217246, 46.00622107905727, 48.51849525205551, 47.39330453257407, 48.73875594908192, 49.48841894826582, 49.30482064524005, 48.7768147068639, 51.98631371221235, 50.91280806449152, 55.50027885744649, 40.54327334127119, 46.36227030907908, 51.992311016205825, 45.35688838651104, 46.2711654170867, 40.95406709178802, 38.02455471407983, 36.340669431994044, 37.77220118430353, 35.63546649871334, 35.564346082748905, 36.70965071647398, 36.173980466781124, 36.996850582861136, 35.426513994893725, 36.031084599033484, 35.60211850750831, 39.64445044917446, 49.39230126719321, 51.662423995233354, 49.62369365076865, 51.83741269573089, 51.042983685770345, 49.35701954749323, 50.66157241021433, 49.84213829040528, 44.497755958187966, 37.22967463154947, 35.13911408762778, 37.141652722512525, 36.52181625366211, 38.319003120545425, 44.641381386787664, 47.827252034218084, 49.705110288435414, 50.76953957157751, 52.343582799357755, 52.43754317683559, 51.02247753450948, 49.043983028781035, 50.30966912546466, 51.249896557100364, 55.35795173337383, 53.252337132730794, 53.1842290970587, 51.483799257586085, 55.239280423810406, 54.43759502903108, 54.698122778246486, 39.23321739319832, 24.353551210895663, 5.495593624730264, 3.1641760180073404, 3.956020676320599, 13.849984195924575, 27.053624545374227, 3.5312449018801417, 4.329484739611226, 0.1901653159650103, 0.40550333117285087, 2.335827821685422, 26.007583333599953, 40.80751557503977, 32.768531614734286, 42.2071780696992, 49.1348211996017, 20.15454411506653, 1.3469003645643112, 0.13146730680619517, 0.00785700397588493, 0.05130960440803921, 0.04431011568334314, 0.020599508650540825, 0.02312813314699358, 0.036066668708958936, 0.006993158923221693, 0.02296529349780852, 0.05894952731567526, 0.03549552334833049, 0.07718870566496927, 0.04899180539312863, 0.03422779722079154, 0.06299084412955469, 0.016211360850701892, 0.012921910496398568, 0.09434739743629772, 0.030380155095049453, 0.03612832346510503, 0.06480613543141274, 0.04112490595528676, 0.011906798031451482, 0.03817681959199329, 0.054880723267072634, 0.06879072726493882, 0.011590921785682442, 0.05070850884001102, 0.04810027057124723, 0.07758019191603507, 0.045727596678320444, 0.04746700314083888, 0.051641385596726215, 0.022535305582888188, 0.044491636386561784, 0.02740179293698842, 0.028794718898772716, 0.04275514871903485, 0.02488703080152552, 0.04130967104086473, 0.04190530440199279, 0.01894380303940946, 0.04133965955266068, 1.9062699425605036, 29.079185531985377, 57.38767239355273, 45.511727871433386, 34.35261218778549, 37.785035179507354, 51.81849902675998, 37.39683428118306, 7.510861331416716, 0.902205323500018, 1.2782164759212926, 25.311841157174882, 22.305136534475512, 12.403028703504994, 4.09900087502695, 6.458983632826037, 27.976387623817693, 46.54407216656593, 57.14619951863443, 56.41534428442679, 54.42443155473279, 53.23971494551628, 52.39450693130494, 55.343380128183675, 57.16383057255899, 55.517862842928984, 50.07897492377989, 50.776682207661295, 47.644261698569025, 44.52816609413394, 41.03168687512798, 40.64576879624398, 38.884459849326845, 38.65760957041095, 37.30484293353173, 37.92470685897335, 40.55856666257305, 41.338522126597745, 47.2362018400623, 52.11858387916319, 53.84031218867148, 54.196992920291045, 51.63285324650427, 54.50201995911137, 51.37418862312071, 42.50454079720282, 37.63381211988388, 38.397536816135535, 39.26205465870519, 38.666795761354514, 37.303815272546586, 37.88536156377485, 40.907186923488496, 44.1694418076546, 49.25279824964462, 49.39852214628651, 51.54257205224807, 49.10001408669257, 50.73513254042595, 50.754646332033225, 50.4913023210341, 51.13777952809488, 52.6348501636136, 53.40648235813264, 54.38201896605953, 41.84618273089009, 48.97086612639889, 53.62633512866113, 47.52843018501036, 49.58641152228079, 43.19041429027435, 39.8536539846851, 38.42280472478559, 38.660896516615345, 36.2295526073825, 38.98568053399363, 38.012250238849276, 37.09142285008585, 38.859964647600734, 37.79312310680267, 37.766972664863836, 37.61997792028612, 42.04379174017137, 51.79889109826858, 52.5429254962552, 52.18999847289055, 53.38491324455508, 53.19127759625835, 51.599646460625436, 52.35556956260435, 51.78679843102732, 45.70482223264633, 39.32893107014318, 37.189678222902366, 37.40267469036964, 38.378587845833074, 41.16146241464923, 46.859379737607895, 50.67869747838667, 50.92877603346302, 51.23009251010034, 53.493547208847545, 53.66934391760058, 50.02399506107454, 48.67732770981328, 50.38038553730134, 52.63518748744842, 54.93389252693423, 55.50525242282499, 53.41142062217959, 53.80387729214084, 57.453246578093506, 55.61775776647753, 56.60089592779837, 43.1321317918839, 28.13007197072429, 7.527501986872766, 1.8248768391147738, 6.682828395597397, 14.172780552218038, 30.501489908464496, 9.440667456196202, 5.036562565834292, 0.18068028944394282, 0.2977333301978727, 3.033066382331233, 29.2484240378103, 44.97691269843809, 36.05302241540725, 44.29240419018654, 55.52726476423202, 25.301678296058412, 2.1460574240453782, 0.09550394505382546, 0.019690957100641344, 0.05300413343995329, 0.026186932621884252, 0.04059979098758871, 0.039001080402804, 0.030728001147508625, 0.014745405642315747, 0.05680982459096178, 0.06111026298434985, 0.062760274646984, 0.06504751441459503, 0.05239513184454653, 0.05112450607421418, 0.0376515360849519, 0.02347430912777782, 0.017332766099923083, 0.04503942372637891, 0.06637027246817466, 0.2702677604411879, 0.2652968610486677, 0.17157980841734718, 0.18057892068980202, 0.11891127894482306, 0.14778893260705858, 0.1899742076714193, 0.18566730732638992, 0.24736733926880747, 0.13069686750250478, 0.195879933514422, 0.13212402801840537, 0.15122338138040037, 0.13932680200424888, 0.11828084987017418, 0.20989601770716332, 0.11382445512760071, 0.18919261412755137, 0.08864955721242775, 0.1263808736938142, 0.18813538214852735, 0.07371708630554138, 0.08729504481438669, 0.19358637352143565, 2.252384299232114, 35.3649837740006, 64.40527116098713, 52.32126843544745, 42.75736893376997, 51.03259724955405, 60.65998423484064, 41.723432156347464, 8.578171595450371, 1.1487461458290777, 1.772898570183785, 25.471724810138827, 25.871294698407574, 20.11338080129316, 8.093270053786616, 6.6283667760510605, 29.019324279600575, 49.87933020437918, 57.85018651716171, 57.52223714705437, 56.250369394979174, 53.20814771036948, 53.38098695201259, 59.83650222901375, 61.78827362675821, 59.163305836339156, 52.40256347963887, 54.64575913644607, 48.29304525929113, 46.13818530113467, 42.45347938229961, 42.32759875635947, 40.39328190588182, 40.598241436866026, 39.613883418421594, 39.046787138908144, 42.26706481749012, 44.31538535702614, 48.83912547942131, 53.81718589413551, 56.85938796689434, 55.95617594257478, 53.28623033338978, 57.19631564232611, 53.7859599051937, 44.63484671808059, 40.75806625427739, 38.35926625036424, 40.654672576535134, 41.489772642812426, 39.16096733462426, 40.43787141000071, 42.35773432639338, 45.438563900609175, 49.62485074996949, 52.26866945143669, 53.748367909462225, 51.14311002915906, 52.260805099241196, 53.529189786603375, 53.57246529671454, 53.932123107294885, 54.47865047762471, 55.91193160703106, 57.345993288101695, 44.16156568834859, 51.075806079372285, 55.11167787736463, 49.80549943062567, 51.126185001865515, 46.17114497769264, 42.88530095931023, 40.96813271122594, 42.27046159005935, 38.26810252281928, 39.84720560812181, 40.63901055243708, 40.68988761594219, 40.972168830133256, 39.971227030600275, 39.70453331547399, 39.22274074246807, 43.77208609734812, 52.305410292840776, 55.07709041718514, 54.118494526032485, 53.43058532284152, 54.76989038528935, 54.48221983448152, 56.245658628402225, 53.54486357781195, 49.4010873763792, 41.430548775580625, 38.60617945271154, 39.78028605061193, 39.17636655992077, 41.228483953783595, 49.78916668122815, 52.26291141202373, 52.917684431998964, 55.094497896009884, 57.80634226337556, 54.71853087025305, 52.07918759315245, 51.13491619786909, 53.054783036631925, 53.436464955729825, 57.18815318999752, 56.807891168902, 55.870574135934156, 56.27701013318954, 60.101030795804924, 56.93966711721113, 59.11869279799923, 44.22772430604504, 30.488575504672145, 7.744148219785384, 5.713290562552791, 10.52842503593814, 25.43393865708382, 32.83234269388261, 9.819607638543653, 10.575038483065944, 0.9587934805500893, 0.9021943531209423, 4.333484576594445, 34.20557821950605, 50.57882216668899, 44.17367012270036, 52.579003457100164, 61.262762315811656, 29.288557729413434, 2.6374075874205563, 0.2401347031756755, 0.09601907789587014, 0.1437598310651318, 0.10514231173381691, 0.11533490472262907, 0.16354619675586302, 0.1498480390516981, 0.11293752449414424, 0.17377625910505173, 0.1292085118832127, 0.18111106068376573, 0.1486576916349511, 0.13088353248613496, 0.1867009591191046, 0.18049891046699018, 0.14098930473048843, 0.24516125119501547, 0.12337335039891544, 0.22301407831330455], [0.04221971071655712, 0.05136307734515398, 0.020838562556872928, 0.005912782470395248, 0.012890972993186405, 0.019585388269455686, 0.046886228055002234, 0.07745649935978074, 0.011074973059998406, 0.003054569711938741, 0.0358222751697946, 0.011482528962885902, 0.06992943269471008, 0.04073472205369223, 0.030476737714883302, 0.00834183373127974, 0.014286448112538746, 0.03252230164024138, 0.026293955104906234, 0.030180156351097172, 0.04022919978465765, 0.010858721760732513, 0.01671773347733242, 0.09636154218066124, 0.43972656250961367, 16.925143003463745, 45.66224882679601, 48.835360004055886, 36.9811140337298, 48.44765332437331, 60.90383406608336, 36.61460776482859, 12.079690079535208, 0.693322564325025, 0.16325624779828135, 11.719411553875094, 18.51374214695346, 11.1136132478714, 3.0015900971428042, 6.230622751097526, 21.226337648207142, 37.48849222736974, 48.71385282085788, 49.50688154466691, 53.428404485025716, 58.41907924221408, 57.79889760478851, 53.24774795962919, 53.243884425009455, 51.420653020181966, 45.16956775419174, 41.52506612962292, 38.77880296399517, 38.09391398583689, 39.4513992340334, 37.308416212758715, 37.39455146174277, 36.775977996087846, 37.68839582320183, 38.97667477207799, 38.251024523089015, 37.57511777262534, 41.82309566005584, 48.57636590157786, 52.67818843164752, 50.25821155117404, 51.89711116975354, 50.81858488821214, 51.28310334297919, 48.23133460937008, 43.64782541028915, 38.267698518691525, 37.88331016417473, 37.2264818222292, 36.78226555547407, 36.26162582828153, 35.72144877526068, 35.872589465110536, 38.72270130342053, 42.99497827406853, 45.373884016467684, 45.36025770248906, 47.70470150055424, 47.8038158724385, 48.18974179606284, 48.81955285226145, 49.70866395581154, 46.57103453913043, 52.24878303466305, 42.343401985783736, 46.27239311895063, 51.36696361726331, 48.659559372932684, 47.6628968792577, 43.1564308751014, 40.75184145281392, 38.30137598899103, 37.32594920742897, 36.280006054909, 37.08028331879647, 36.253879147191206, 36.927836479679236, 35.80702704768027, 35.60492692455169, 36.125056743621826, 35.73336493584418, 37.08422137844948, 40.33277934597385, 48.35816444889192, 50.52659973021477, 49.27395551435409, 52.7171964030112, 53.433036804199226, 53.005396473792295, 52.403163602275235, 48.50364515858312, 41.89653419679211, 35.16684916711623, 37.99275998146304, 35.72068391307708, 36.85727696264944, 37.896763893865774, 39.97334511049333, 44.27972708978961, 45.46158821352067, 47.67116915795111, 47.9674885349889, 48.74894234441942, 52.734909826709384, 52.2861671447754, 51.19215926816387, 51.87301212741483, 52.29666340735651, 56.802058604455766, 54.355146808008996, 56.14146478714482, 54.70487709968321, 51.07890082943825, 32.17853065459959, 12.261360537621284, 1.8644833396519385, 0.5447230187635268, 4.017746525426065, 21.612132172430716, 9.681066582279822, 5.120329193530544, 3.381772935390473, 0.21769336785279939, 0.6719941862167851, 3.121924491659288, 31.021998236256263, 37.65036452201105, 31.88351154327393, 43.38487363630726, 44.30240623412594, 14.297520749030577, 0.3627442256096871, 0.006682274219084292, 0.03340257113919624, 0.05973854042108982, 0.09116962642198609, 0.02600340668352381, 0.07162612592501026, 0.03545945975929499, 0.0789264995124071, 0.02478457037209263, 0.024387265683241913, 0.05210617880126642, 0.0698151630199244, 0.07702927510704725, 0.017288551335373235, 0.03061420453201619, 0.016922474305536, 0.034099339597648194, 0.07935276615523523, 0.021383017414219437, 0.02619938921153305, 0.04450181769507547, 0.0842358488889952, 0.03301853892363368, 0.03086840782705094, 0.04697340503034573, 0.0435356390962918, 0.06655006564312405, 0.029737252193773468, 0.02471672371029854, 0.009287688975042153, 0.04134284647842569, 0.02337642415847269, 0.012948149965415079, 0.0071041755971588925, 0.047758292752288045, 0.03884697798639536, 0.06302294704402167, 0.020686963332756873, 0.13700799175327824, 0.010115563805635658, 0.001363644046397249, 0.03904796881420959, 0.07171185882461649, 0.7568819989119807, 22.19795580833189, 52.439029755130896, 50.19389644745858, 41.12943626219227, 47.913163708102324, 59.80717466723535, 37.485079765319824, 11.454238737783125, 0.8159506260868042, 0.37696747529891234, 13.657140866402658, 17.995306791797763, 13.10331984873741, 5.2705947045357, 7.587249980818841, 23.32993418939652, 41.16523965712517, 51.98163040222661, 54.62613944084414, 56.35853659722113, 58.49367487815119, 58.202795828542406, 56.53310168174006, 54.67661642259168, 54.16606503148233, 49.9401230196799, 44.99080573358844, 41.7098960568828, 41.142289869246945, 40.679097175598145, 39.40703330501434, 37.966080019550944, 39.5417510309527, 38.846950223368985, 39.38402075921336, 40.76172974801833, 39.312425736458074, 45.54933555664555, 50.49949615232406, 53.938112566548014, 52.25708669231784, 52.30371190655617, 53.18355052701889, 52.85721325105237, 51.2701516766702, 43.5871071200217, 40.01223541075184, 40.41262703557169, 38.9260212836727, 37.851801764580514, 37.29517429105697, 37.92513831969231, 37.40449859249977, 41.52804320858371, 45.34861218544745, 47.899380499316806, 47.71762963264219, 50.49943339440131, 50.82157765665362, 50.03649957718388, 50.8530350654356, 51.26479371901482, 49.3398944793209, 55.368750018458215, 45.843513319569254, 48.78920939660842, 53.00016403198243, 50.50213982982021, 49.33769402965423, 44.6424247372535, 42.67545023272115, 40.017385482788086, 38.60855248666579, 38.151384553601666, 38.24217173361009, 37.55594522722306, 38.541389742205226, 37.877881603856245, 37.58619062362179, 36.552826512244444, 37.44212196719262, 38.803611955335064, 42.99213847806377, 49.38458596506427, 52.918755239056004, 51.64509888618223, 55.06604894515007, 56.00707654030093, 55.16778346030943, 53.143742392140055, 50.84180531963226, 43.47084022337391, 36.35351911667855, 39.10898024036039, 38.43962384808449, 39.5565854349444, 39.849194249799176, 43.996269164546845, 46.11416862856957, 48.827409359716604, 50.110432332561864, 51.53541764905376, 52.65096718265165, 52.796322376497336, 53.276098851234686, 51.63552045822144, 53.2087831343374, 53.316675770667295, 58.2376225533024, 56.25874365529707, 58.69335097651328, 55.98047110342211, 54.63625131114837, 34.57415942222842, 15.25251982673522, 2.337955217207632, 3.0366597637053463, 5.385379435554628, 20.821388229247063, 19.245217115648334, 8.47167238112419, 6.133593609256129, 0.24636992343491126, 0.6428831515292968, 4.020689773944117, 32.29875914512142, 41.41957790620866, 37.14405321305798, 48.97819311388078, 50.79976535612538, 18.18602615787137, 0.5534899451078907, 0.0392408506013453, 0.02493989852918012, 0.035202391295423435, 0.08801633957773448, 0.032181400174815813, 0.0595049946869333, 0.047432211257757685, 0.0548734684144297, 0.042401522533186985, 0.0802502534802883, 0.05287905426455602, 0.052406757228797486, 0.07549519169955485, 0.03932836465537548, 0.058122615840646534, 0.04208417444099342, 0.029578511114983313, 0.02872737402456903, 0.01533273365273471, 0.16112299936432994, 0.15440606301830662, 0.18944621987400517, 0.08847855872684911, 0.11015134698320782, 0.19755890713103358, 0.13009216366035323, 0.19894037816313007, 0.18697259857529597, 0.08468306037567316, 0.10282426757077057, 0.12225965773987195, 0.21823951193401891, 0.2629858495727662, 0.09757239011026199, 0.12670746463681423, 0.13376914054876374, 0.13467361459568625, 0.08574916365286035, 0.1775842523502727, 0.20663177834883814, 0.12890532492629944, 0.15550109377551466, 0.25538218177614674, 1.350078832718634, 24.94473868800748, 59.37196024002568, 60.83564366063764, 49.923284284530155, 58.98814847392421, 66.6622108028781, 44.217447696193574, 15.968043496531827, 1.138606696359573, 0.36633576837278187, 15.718071826042669, 21.47356660135331, 15.739708600505708, 6.773748445895411, 8.165022951941337, 30.811347346152033, 46.9052989252152, 55.26664287813249, 55.52349536649643, 56.12553996424521, 58.801341672097486, 61.26657485961915, 57.961154291706706, 56.38546366845408, 54.488648599193944, 51.29355253711824, 46.80478426717943, 43.33689128198932, 41.343636897302446, 43.14906074154762, 40.808629528168716, 40.61031841462658, 41.334901778928696, 41.689503654356926, 42.787198558930434, 43.70604907312701, 41.390062070661976, 47.3104444626839, 52.13860757889287, 57.548662154905266, 52.559105273216005, 54.35450353930074, 54.88598862001973, 55.083817282030665, 53.87525658453665, 46.96177321095621, 41.42421807012251, 40.80292247956799, 41.877573459379136, 39.281403710765225, 40.21632025318761, 40.29096687993696, 39.09471458004367, 42.24641746090305, 47.27052650144024, 50.68942123843778, 50.558539590527936, 51.78993632716518, 53.00500031440489, 53.282017707824714, 53.797444605058246, 53.49308829153738, 51.11619472503663, 56.02411531632947, 47.52686908168178, 51.04176382864676, 54.48765231717018, 54.52845281170261, 53.14248723368491, 47.38865260154971, 44.29921342480568, 41.6463654272018, 40.8072566986084, 40.1872633349511, 41.005881601764315, 39.68074414037889, 40.36199708138743, 40.06856456879647, 38.721336318600564, 38.87411655918245, 39.40621352964832, 39.97060729611305, 44.529064316903394, 50.125745265714585, 55.47492465665264, 54.20524166476343, 57.639727823195926, 57.13664854726484, 56.535082478677076, 55.61220369031353, 53.52571848900088, 45.56324428127658, 38.61490280397477, 40.941488050645404, 39.87559964579921, 40.56547003407633, 41.77838848483178, 44.824132457856216, 48.49950313568116, 49.826354672831876, 51.325719894901404, 54.14279360924998, 53.81351455565422, 56.12472411124937, 52.69973008863388, 52.44488977616834, 53.409686934563425, 53.812922277758204, 60.55173074045489, 57.12228090532365, 60.407089417980565, 58.19768890257805, 55.2318436099637, 35.35150258771835, 14.970878939474783, 3.5552353435947053, 1.7737703169545822, 10.912495678470982, 29.556249687748572, 13.340992927551271, 15.209100169520225, 7.714179840780075, 0.7175675310915517, 1.1978390212020567, 5.225541380143935, 38.458168814259196, 48.41382288163709, 44.508185540476155, 55.857681305177756, 58.2587327495698, 21.60930806590665, 0.7139869587075326, 0.20704427073078774, 0.13861464666983775, 0.1863175474347607, 0.20674224822751938, 0.1424052037539021, 0.15819312674143624, 0.1455118894697197, 0.08192436243858069, 0.15459779950399555, 0.2008684529292007, 0.16301696789601158, 0.308077692865364, 0.25246856553900626, 0.1146459924958406, 0.13398775139883642, 0.09694548504006478, 0.10054932351434424, 0.15035074594761097, 0.14617812549394948], [0.039119609526448676, 0.11286985594779254, 0.11804309448287373, 0.0433817588453812, 0.016414671009706876, 0.021760737065285928, 0.024918720028513384, 0.07470907057605444, 0.017601241612987175, 0.055898547683271675, 0.0330668829020954, 0.027887207313230442, 0.05884343562948127, 0.027161283463600184, 0.01277335647178153, 0.021023783464765838, 0.010490119513574868, 0.05847278696995589, 0.05176286798931899, 0.027582493926128073, 0.04067908874863098, 0.021251979989991076, 0.022229487113955042, 0.040749235589417725, 0.13116680115701693, 9.687183518563549, 47.51118352336269, 49.1594889856154, 42.21428540445144, 67.49227846822431, 64.40679304061398, 44.70091904363325, 26.18930870486844, 3.3007036726320944, 0.13259808322595013, 2.9786079497106615, 16.684640915163104, 3.7070555840769126, 1.4602327154528711, 6.459593561387832, 17.73888772533786, 29.55012098435433, 45.10818266099499, 57.31594793258175, 57.066571481766246, 57.31177453071841, 54.72378684628395, 51.767288561790224, 47.687709792967766, 42.51124412782731, 40.11926512564383, 39.68516857393327, 39.14978857963316, 36.792063636164514, 38.7949788185858, 39.10965096565985, 40.19137790126186, 41.02520319723314, 41.93673064631801, 39.89079490784676, 41.60939316595755, 42.15000167969735, 45.80585464354485, 50.49012168761223, 51.33422751580515, 52.46308565139771, 48.70341931619952, 51.09637106618574, 51.63222566727669, 52.02778493204425, 49.53924502095869, 44.972962871674575, 39.9064883109062, 37.78217577165173, 37.02376588698357, 37.60855990071451, 37.220468828755045, 36.87468444147418, 37.49599179913921, 37.81354688828991, 39.91725521702921, 40.92575150151407, 41.942041535531324, 42.43425976845526, 45.37682971646709, 42.965940967682876, 46.66179818491782, 46.90014885317895, 52.673010903020064, 44.55978824246315, 44.07010386067052, 54.010276332978286, 50.3070842835211, 49.62246594890472, 46.572685856972974, 46.43112359508392, 44.82038659434165, 42.659082181992076, 35.736781320264264, 36.6715213560289, 36.40004627166256, 36.188222592876805, 36.93763848273985, 35.91300556736608, 35.10749193929857, 37.295903851909024, 36.478070059130275, 36.04325963604835, 38.9703126876585, 44.514979085614605, 48.23643369059409, 50.7638168334961, 51.21172012821321, 50.25136701522335, 54.00057238917197, 54.57156750463671, 45.52836656570435, 37.40036441433815, 36.30293623093636, 36.44560067884384, 36.42207822492046, 35.9469929049092, 37.345266880527625, 36.892644974493216, 40.150220471043745, 45.505883539876635, 47.72625100228095, 49.4915529220335, 50.695810779448486, 52.137772114046165, 51.903386962029245, 51.26410730423466, 51.946991951234885, 54.833118992467085, 56.42156124114991, 53.571367033066295, 54.699475995955936, 43.52456492762412, 24.191886801873487, 7.781391124571524, 0.871800396951937, 1.6765293671238808, 14.987386234344976, 14.215037226676943, 5.273544817201553, 9.172591105584177, 4.503732602442465, 0.06986786986911489, 0.2962807968499199, 6.468546861602414, 28.766372588373002, 40.36319340428999, 28.25666842922088, 42.69698404496716, 43.562137311504735, 7.046767963517097, 0.11438150830086201, 0.03368136202616077, 0.04208064277566249, 0.05602975173162357, 0.027270537177701632, 0.04833832090239852, 0.06010590639385966, 0.053835967029895515, 0.03910033092383416, 0.05151370938326563, 0.0624013624544586, 0.0222905270845419, 0.04926260598304291, 0.08402377276891664, 0.03797024015277144, 0.03837602543494394, 0.054473191304432775, 0.034966631567165736, 0.06436779524289793, 0.013811378796104223, 0.010872003810119726, 0.04125819759323232, 0.06392974233735474, 0.06415711340284155, 0.016801156621846943, 0.07554143276666442, 0.05986003047456184, 0.008031144858367981, 0.03636729310176546, 0.030931295984755122, 0.023101877398608674, 0.06640799463756623, 0.04847585283700497, 0.017748939534348827, 0.06293558620757635, 0.03647075327593954, 0.023016165566420364, 0.0527512631379068, 0.052136182634820866, 0.019664622828244202, 0.09950643270126275, 0.028747047162464553, 0.045809265481488365, 0.026818321221658302, 0.16993117188253712, 13.339850537238583, 52.51689272542154, 55.80123839839813, 44.570782646056145, 65.11435331836825, 71.09204938334804, 51.98062235309232, 24.729045591046734, 3.090827450636895, 0.1165184569394877, 5.175608627257809, 19.39094493466039, 4.9190346271761, 2.9826835374678335, 8.03022873978461, 22.5091625413587, 34.29568290710449, 50.217254161834724, 58.09214576598137, 56.96953988844349, 59.64523176993094, 58.62039881367838, 53.60813533106158, 50.79393279167914, 45.606723754636704, 41.65576342613467, 41.57744153853386, 41.281326124745036, 38.164151868512555, 38.85385359487226, 40.20179179406936, 40.05368701873287, 41.25113564152872, 43.10120390307519, 42.13302173922139, 42.27925946635585, 44.44310165220692, 47.504099722831484, 52.102239362655155, 53.18590002675211, 52.39876662531207, 50.046940926582586, 53.76431626658286, 54.15539226224346, 53.21263882421678, 50.85704372775171, 45.76438342371295, 42.60616156362718, 39.254217763100904, 40.62810244098787, 38.52463337682909, 38.20516417103429, 38.796798798345755, 39.65319733465872, 40.94132331109817, 43.84390469520323, 43.06971903770201, 44.34217122293288, 43.52128190378989, 47.21762157255604, 44.14906509460942, 48.68305829263503, 49.18295260398619, 53.454754967843336, 47.9591574207429, 46.026997873860026, 54.32816090122346, 51.377918797154585, 50.87858146236789, 50.605427603567804, 47.35751290475169, 46.02986904882616, 43.31909548851752, 38.39478331227457, 38.26776912135463, 38.40089436500303, 35.884999844335745, 37.97554862114691, 38.02123638891405, 37.3534450223369, 38.37366919363699, 40.21391584027199, 38.40958633730489, 40.902625206978094, 46.78134810539984, 50.7270210789096, 51.27319151355375, 53.742696162193056, 50.43375722823605, 55.32206204629714, 56.0742392847615, 47.69697443131478, 39.18377199480611, 37.92079233354138, 38.541931029289, 38.52974814753379, 38.37692083850984, 38.875301114974484, 40.39658454156692, 43.806132270443825, 48.044166949487504, 50.17991319779427, 50.57922224844656, 53.494939650258715, 53.306799242573405, 52.455507632224794, 51.50255995412027, 52.19874928074499, 55.40652244321762, 56.996792516400745, 54.754279352003536, 54.86268189645583, 45.03947842505671, 27.355525455167218, 9.405407309532166, 2.2922402379974245, 2.637845176842905, 9.16264985838244, 21.460061880850024, 9.855361023256856, 10.80451871118238, 2.4644072834522497, 0.07158524747337065, 0.4359976755034539, 6.749857289175834, 32.07734134889419, 42.798110592749815, 34.05983863338348, 49.33301856440883, 49.57220077514649, 10.437148540250718, 0.06046710535883904, 0.03538680398055623, 0.06893884270421921, 0.032146497208985596, 0.04228598881332625, 0.01616727440587936, 0.02436336757044398, 0.04214931106675537, 0.06160413305605612, 0.1023527327924967, 0.025290946829162782, 0.00952827409961291, 0.05712811497130221, 0.05925972397709566, 0.0235352820656713, 0.05662430107833878, 0.03631675428140067, 0.04672419662857729, 0.06057365286734797, 0.0699693841799613, 0.17302786781182214, 0.18065490129013217, 0.1678090010799708, 0.15804216145507752, 0.17624977315145154, 0.17255396582186225, 0.1176193712519542, 0.17195165217403444, 0.1343673479653174, 0.12333005877031435, 0.11198337730621138, 0.12562521988706243, 0.18577056065682443, 0.07982894342633025, 0.11236298919445085, 0.10144913208580787, 0.16528854116557107, 0.13478276680313772, 0.14122233335529605, 0.15351381573465564, 0.2414406992254719, 0.10356250819900345, 0.15262518438600725, 0.21301785664212322, 0.4663256255369033, 17.06313394731091, 60.48819226603354, 61.7700973633797, 53.59909819018457, 73.34799274321526, 70.41827247988793, 54.16544137462493, 33.12216858710013, 4.408206218673337, 0.4840332882538919, 4.3516206356786915, 19.98215006243798, 5.352438880551246, 3.928807272065071, 9.574197684564899, 23.055476142514138, 36.724845978521536, 50.72879399022749, 59.27719577666252, 58.39258755407026, 61.22025166788409, 59.853560616893155, 57.115887441942775, 52.32008780202558, 47.99816146973641, 43.84003723821333, 44.01871296667284, 43.65161441987561, 40.25934473160775, 41.470572640818936, 42.18151007929156, 42.88805054080102, 45.202433293865575, 45.66812453731414, 43.98833813205842, 44.70633975921139, 47.003805329722745, 48.659202437247004, 55.1552632547194, 55.225995356036776, 53.55527747061945, 49.88485682395197, 54.561561538327126, 56.02115784921954, 55.82828314073625, 52.81115285811886, 49.38684132791335, 44.24270776010329, 41.69554018205212, 41.15924627550187, 40.654684343645656, 41.19139402143417, 41.57637073147682, 41.74427955381332, 43.41183600887176, 45.44529076545469, 44.89927330324727, 46.97104569404356, 46.863674732946585, 49.97929180822065, 45.40958150740593, 50.52485035311792, 52.21259132508309, 56.497753281747144, 50.71651697158814, 47.984319425398304, 54.47736394020819, 55.33647283431023, 54.40410975487002, 52.819735004055886, 49.3965256598688, 49.47607524933354, 47.69178121320663, 40.44415896938693, 40.02960366587485, 40.63827314684468, 38.5458416323508, 40.73620688530707, 40.043288815406065, 38.93139885317895, 41.65625764477638, 41.91746004166142, 40.25707367927798, 41.949082189990634, 48.656170445103804, 52.74895975666662, 54.1675006189654, 54.192576331477014, 51.496994110845755, 54.82854943121634, 58.865201780872965, 50.6512487319208, 40.90669662721696, 40.06914507958197, 40.39735724849086, 40.55635052342569, 39.7241412439654, 41.257670310235795, 42.15512037277222, 45.81397002743137, 49.70593006380143, 51.804256900664306, 52.34045667033042, 56.00138910355107, 55.00117686487014, 53.02017988697175, 50.704730249220326, 52.5990899147526, 55.249302079600675, 58.10918846438008, 55.79993224913075, 54.81429946038031, 46.521247894533225, 27.705040016481956, 10.383696440727482, 1.7833217786204432, 4.9525517705948126, 24.479051366929088, 20.524415777575587, 12.488492246597046, 20.453677792702955, 8.767318091084881, 0.41694601877562465, 0.6236865203226767, 8.101621760476021, 37.646528443982525, 48.00746925415532, 39.18740803195585, 55.59885978698731, 56.14517534932783, 13.289352963047644, 0.19020452434497495, 0.15461787100761168, 0.14694225223314378, 0.1673421317771558, 0.12315271707672266, 0.11375583663222291, 0.16276585959619091, 0.20696003170263386, 0.11688242531231335, 0.20283138469582607, 0.09767673128554899, 0.15078108817819627, 0.15759187029494395, 0.22304663705008648, 0.12762844787850497, 0.19428879953920844, 0.15125829966798907, 0.21515744828408767, 0.31406638603056636, 0.12235991566652253], [0.015138873188275725, 0.08202632874130242, 0.025361097500389142, 0.016911073002002893, 0.021358307248221773, 0.052936725363495855, 0.04575233748783508, 0.0307998544491467, 0.07568933370132601, 0.04027083283290267, 0.039545569734107104, 0.013381568039016379, 0.03201421297666046, 0.12034788532483003, 0.02809522508253013, 0.03171876159256264, 0.05981440993867094, 0.05847108625476399, 0.05922959756947333, 0.04629974178369007, 0.05596228236813219, 0.02532795270634515, 0.0635357471483369, 0.0499204533445018, 0.044293518388463606, 6.330125927925111, 42.26608030257687, 46.362348756482525, 46.60469239757907, 61.262001375998224, 43.63391668565812, 36.129355661330685, 27.21013495998998, 4.07113268010078, 0.262693295916242, 0.46393849556484534, 7.221658604760324, 11.257686807263283, 2.4182539793752857, 1.7636330738182993, 9.337012940837491, 30.486104411463586, 47.05678086127005, 57.25511197120913, 57.97093276054629, 57.6457525837806, 50.7920539763666, 50.391666273916925, 46.20832512455602, 42.78758295120732, 41.14239185087143, 39.92676696469707, 38.57473381104008, 38.80273726678664, 37.15542416418753, 41.63005228965513, 45.1308931842927, 46.348263525193744, 42.30430379990609, 44.83540927210162, 45.40831458184027, 45.5514967826105, 48.38761360414567, 51.213457738199544, 53.20709259279313, 48.570235236998535, 50.572299265092425, 50.74566410433862, 51.515033091268236, 53.032421604279556, 51.27736491541709, 49.8399535302193, 43.22978704206405, 39.62419532960461, 39.174844680293916, 36.911174251187234, 35.748991658610684, 36.20549278874552, 36.39060120428763, 36.04868427399666, 36.7627086177949, 37.52602146517846, 39.30428681835052, 39.71020898511333, 40.063559624456595, 39.6316635224127, 46.05696478197652, 48.12057079807405, 51.12728326551376, 45.92391014099122, 42.14554194481143, 50.553762143658055, 50.654880846700365, 54.22619104385377, 47.568010822419204, 51.17342210585072, 48.678618169599964, 49.23694402940812, 44.058807434574256, 35.72214303478118, 35.04207857193486, 35.78248085514192, 37.22308504965998, 36.50299672157534, 36.77203601406467, 36.30174383040398, 36.89581424959245, 35.29281608520016, 35.70572791561004, 39.401800863204464, 43.23281903420725, 49.49898973588021, 51.178901656981445, 49.38330335001792, 48.94163662387479, 51.242781377607784, 49.7488643277076, 39.16084574114892, 35.05181781707272, 36.843176041879964, 36.71972728544666, 38.238476860907774, 36.229176059845955, 36.81941824574625, 35.09034333690521, 38.590423291729344, 41.80662562770229, 46.215530518562566, 49.96064878279164, 52.34410447459067, 55.29249129756805, 53.716506496552505, 48.951046389918176, 52.75436870513424, 52.72336629129226, 58.06665820460166, 48.14055135173183, 37.50437782656762, 15.030180273517487, 4.139973463550691, 2.149983471439731, 28.291689311304403, 26.010654549444876, 4.176752548063956, 5.7078830849739814, 7.033947696608882, 2.123266982455408, 0.07633110087725424, 0.3398340597989098, 7.467485800866158, 25.290856476752992, 42.92813716396209, 43.3064889907837, 46.85135849060551, 35.09366950681133, 3.622534880715032, 0.07968239846729464, 0.0680846776512842, 0.18541068319351445, 0.04780291737387738, 0.013612863389895329, 0.11454815540703074, 0.052138113176390055, 0.03405221369898608, 0.11709364341391672, 0.04664491418929351, 0.023255650397209872, 0.02877804116466113, 0.032579605016977556, 0.012706556477613989, 0.013927397066577068, 0.011719028923600432, 0.02192523146438743, 0.015748647574876106, 0.0780371863455061, 0.06509994547213278, 0.0061979792888216196, 0.036108075761266296, 0.12106426946458318, 0.016210627321514393, 0.038765113830806754, 0.02756117944485478, 0.04005786422039232, 0.046804053633804285, 0.06032903333224597, 0.038401329319082925, 0.06250011501833797, 0.02342748008818636, 0.010012912811831602, 0.0033856709975929513, 0.028816680724342025, 0.06106628953749615, 0.035768836706636414, 0.021902821477382414, 0.022559360743710594, 0.030288182409299962, 0.03998443469285004, 0.06684723114895244, 0.01929396267739996, 0.05528480017317399, 0.1322315101541819, 8.918070466287675, 47.44541714268346, 52.41914726072743, 53.24507682554184, 67.26368273458174, 52.177674385809134, 43.84694845445695, 33.37322381234939, 5.330093627975834, 0.13573695995634602, 0.6275306882396822, 15.799368831419176, 10.145415394536911, 3.0324216427341586, 2.9672943632448874, 12.270392775535585, 32.71117871807468, 48.015070807549264, 55.51296380258376, 58.4206638797637, 58.78819780965006, 55.122413404526256, 53.670242140370036, 47.493717208985366, 44.77854274934338, 41.355388318338704, 41.885916340735655, 40.39164627751997, 41.216575637940444, 40.232998171160304, 42.68649562712639, 46.91566967195081, 47.80412181731194, 44.4021717194588, 46.12314301152384, 46.06796310793969, 47.18234377522623, 49.79528557869696, 53.60135355303365, 55.989217988906375, 50.93113730030676, 52.25692587514078, 52.5177478021191, 52.904544491921705, 53.5169166903342, 52.941018612154075, 51.090173721313484, 44.582243811699655, 40.55570333234726, 40.486014581495716, 39.16801191145374, 38.46437792624197, 36.491880724507, 39.19191875765401, 38.71358571514007, 38.58890141210249, 38.47059096059492, 41.27161825856855, 42.01712746773997, 41.14547483382687, 42.51260126790693, 48.46192682943037, 50.166322185147195, 53.16419755258868, 48.5807236548393, 43.712764170862016, 52.14211025545674, 53.57770950563493, 54.66346863777407, 50.10587846079181, 53.39049477731028, 51.01227152732111, 51.56249377035326, 45.37242881713375, 37.78911052211639, 37.3925353634742, 38.02773967865975, 38.491901197741115, 39.06196278910483, 37.33889695136778, 38.79411589714789, 38.92804130431145, 36.13423508982505, 38.57561634432885, 41.112813257401996, 44.16875147050427, 49.85761988547541, 52.96606294570431, 49.739882100013, 49.890838438464755, 52.774023702067716, 51.36435916346889, 41.85843621530841, 36.832158104065925, 40.54572874499906, 37.81670047390846, 39.84431874367499, 37.49903163602276, 39.33794859916934, 39.066787304416785, 41.68409862825948, 45.38804377278974, 48.26730274385022, 51.64699339097547, 54.35278161879509, 57.29704603072136, 53.182997472824596, 51.11087599108296, 53.434786181296076, 54.863819383805804, 56.08994837730162, 53.22606117494645, 39.81876842437252, 19.41580295562744, 5.482407596803481, 4.841055946965372, 23.84638482524503, 31.131418635768277, 10.256948970979261, 9.896739086797162, 4.742968255473722, 1.812729381265179, 0.05059148507913755, 0.44593239563607406, 9.588200546080067, 29.60183547389123, 44.279750624010646, 42.61955645776565, 51.380291831108835, 42.86278263215096, 5.375079291482126, 0.2086676570076135, 0.012477345843498987, 0.028044916088542635, 0.03497410858530672, 0.03715132280523258, 0.0911957040549286, 0.01496197582568012, 0.039721693347899184, 0.06325740442280808, 0.06813692484772013, 0.023094505717557286, 0.04501209737011983, 0.03016185451058611, 0.07167665708449579, 0.03248173728465073, 0.06233508818812909, 0.03708309884513578, 0.006752656153102796, 0.05260320898566035, 0.06523417173734596, 0.09855200972167716, 0.12277606228787093, 0.20490470973234023, 0.08379114250982962, 0.20987478174990226, 0.11431265997910693, 0.10132970663929179, 0.1496979164620561, 0.24254282395685875, 0.13674701624099286, 0.14133018321327626, 0.14663878948457781, 0.20205326919113437, 0.1916599535052815, 0.1277002379778893, 0.1660530815922445, 0.18893502472389131, 0.1098267248861732, 0.2271493596415366, 0.10786033040213008, 0.11838677684746443, 0.17451056970223305, 0.21261648785683418, 0.14664174658396553, 0.2213714019425454, 11.165172803786493, 55.13604364087505, 59.33044979649206, 59.121038375362275, 68.09889654959402, 52.061662443222545, 48.10744654747748, 35.45005998303814, 6.152691629625136, 0.47183079464781674, 0.9037130458220359, 10.019831888137325, 17.131200798096195, 7.102405803818857, 2.686184957142799, 11.55423564295615, 34.72272703724523, 47.933238398644235, 60.08385865919052, 59.432917794873646, 61.44487404054212, 56.477529541138686, 55.08153054022021, 49.99508719290457, 47.60444571894985, 43.988263607025154, 44.51806599094022, 41.84483343555082, 42.91816257661389, 41.13020112437587, 44.74200587118826, 50.90195486622473, 50.35239942612187, 46.79671987410515, 48.86838636090679, 48.88300503453901, 49.149969393207186, 53.23122693646339, 55.60956001281739, 57.679955651683194, 53.38163414309102, 53.32191997958768, 54.697051971189445, 54.498128967900435, 56.119385765444854, 55.10726521092077, 54.5100490508541, 45.25120404458816, 42.64192181248819, 42.162019821905325, 41.22503619040213, 39.12326551252796, 38.716892273195334, 41.96830180383498, 39.694174335848906, 39.570898163703184, 40.65360961421844, 43.287061491320216, 43.586397171020515, 42.847924693938225, 45.01273570522186, 51.041002888833326, 53.67097954596243, 54.593881868547015, 52.507953643798835, 46.12497083602413, 50.275281706163966, 56.54052672847625, 58.56907067760345, 53.06391823676325, 55.475414952924176, 54.25605204797561, 53.08979411279002, 49.6967399504877, 39.14202620906215, 38.278802748649355, 40.32178886475102, 40.99995490043394, 41.81948707949731, 39.849088345804525, 40.95918186249272, 40.70707936440745, 37.560236300191576, 39.54284537223078, 43.57592052029025, 47.06372737884522, 52.24009890710154, 54.11944766198435, 50.48087666111608, 49.6714210510254, 53.98525553364908, 52.24007537288051, 44.522663008782175, 38.22378758461245, 42.036496131650864, 40.06221032911732, 42.62399265843053, 40.16026173868487, 40.898239997125444, 40.678348002895234, 42.4245636693893, 47.09389825021067, 50.164306086878625, 53.96678509250764, 56.97003018471503, 59.92990955229729, 54.6877912552126, 51.89642867734356, 54.496505106649096, 53.03090364702287, 58.612487393040816, 52.92778453519268, 43.23328579625776, 19.76823183798021, 5.675832417703444, 4.311116770390542, 38.474144627971036, 32.357435841714185, 6.308226354660527, 17.71256862148162, 16.417239212220718, 4.2509848744638505, 0.45650906680572423, 0.9129205646534121, 10.703798128712563, 35.31406356442359, 52.33200004023891, 52.30520632959182, 60.04791013656124, 46.84632216730426, 6.5869181098476535, 0.41824466038134794, 0.22464362393704154, 0.22588880792740854, 0.15215531201852908, 0.17479409884300925, 0.3209167748929993, 0.17997106056540244, 0.140082624350344, 0.17690091724357299, 0.12313613127316199, 0.0727213022389239, 0.12292649897356188, 0.16348518551357333, 0.1947599589343994, 0.1572081981407058, 0.15736068028115457, 0.12594066425076417, 0.11996884800253377, 0.14331214460394076, 0.17633912964693962], [0.045353822380063996, 0.029988506050299735, 0.06873607455242066, 0.0016924907592305494, 0.09361274209955046, 0.019583340899478045, 0.02538820743680962, 0.06725829860736286, 0.04744645666270968, 0.03747807845713631, 0.04453404701404995, 0.030578160095178795, 0.05527654557578987, 0.02882532794178734, 0.04192897268841344, 0.03920678267135255, 0.023093358500890677, 0.04682810113374745, 0.018148858498241154, 0.043942378157930034, 0.12945315440095242, 0.01757063831563198, 0.08235488853026783, 0.039501492865383625, 0.09303713427676309, 3.2100496080613907, 32.677801309093354, 47.24698835803617, 47.7140877323766, 50.96381456621232, 28.922708457516087, 31.255655788606216, 26.130033846824404, 6.937412773409198, 0.26466897538592743, 1.1855821047098407, 1.4291812719837313, 5.5017703771591195, 6.909106008468136, 2.3126081257097186, 4.015224686553402, 16.471603262809015, 35.93502183114329, 50.43687159015287, 59.56026538725823, 56.53518446030156, 52.85300847022764, 51.82849322595904, 46.89680699379214, 43.21240309746035, 40.905331642396995, 39.490438584358465, 40.36215005382415, 39.47391756119267, 44.13437974068427, 46.51081046750469, 51.32059335708619, 47.866346297725556, 45.599926287128085, 42.54320752236151, 45.6878815158721, 46.1669558863486, 50.715100995955936, 53.022580377517215, 52.82864662908739, 51.24835114325247, 54.05843127158381, 53.101847556329545, 52.65130842885664, 51.5869850497092, 54.61678458798317, 49.895117744322754, 47.46717060765913, 39.992352916348366, 39.123410640224336, 38.36721689470353, 36.79479752817462, 36.536744794537945, 38.83981150965537, 36.608947784669944, 37.17414171464982, 36.1311246502784, 37.53633729873165, 36.854280271837794, 39.60042968873055, 42.73429363004623, 47.85847410078972, 47.162029820103804, 54.32747056407314, 43.875754341002434, 40.45364326046359, 46.59058755443942, 45.51523447036744, 51.17996461929814, 49.25557136535645, 49.31860777639574, 49.49900150299073, 50.5471254933265, 46.94814689697758, 37.756437178580995, 35.97675192740656, 36.891558477955485, 34.35687188179263, 34.72661018371582, 34.982560526940134, 38.16869789554227, 38.15616200047155, 38.95237961123067, 41.32489581261912, 42.72274617225894, 46.12893242989817, 49.00093893851004, 49.29128454577539, 51.46355982749693, 51.633218026930294, 47.577353908169655, 49.329268778524096, 39.00950108805011, 36.00018416681598, 35.03355133918024, 38.979090952104144, 39.54145685318978, 38.35950551494476, 38.665442543645064, 37.05849063011908, 36.77971209249189, 36.4642946950851, 41.045356335178504, 45.65963652826125, 48.683195575591064, 48.59798600596767, 51.95671550689205, 48.50424135884931, 53.2671558472418, 48.40764122624552, 50.384908030110026, 48.1695572791561, 26.65062846675996, 9.8559993890024, 2.9079121303173805, 3.9955312013626103, 8.523212325188423, 11.818011114674231, 6.044354294576953, 6.3048094799441685, 4.461956908625941, 1.0324022726666544, 0.1787910859791502, 1.0776739014733223, 11.688845503714777, 29.693389477268344, 38.894269697127804, 52.845905057845584, 42.49003194993542, 26.797503579047422, 1.7639898869299122, 0.04095234081990296, 0.02110665119553526, 0.014014635328954507, 0.05391678164502787, 0.025352005951947747, 0.02483933225214001, 0.1323795489846699, 0.03213170788160736, 0.0717409625048599, 0.05314490209603983, 0.046383421567659226, 0.05278356523523408, 0.019362855049210693, 0.01909880369390932, 0.03892535261148888, 0.07539694092326588, 0.03542378304466125, 0.014496702858577333, 0.035234375466262145, 0.05247314640831563, 0.04385336640200788, 0.06102410107550602, 0.09178091862028645, 0.06863117413294893, 0.044695975018605116, 0.019623497313249017, 0.04385435082499058, 0.01912374177106446, 0.059847531750077204, 0.040248214086938294, 0.10580279443773533, 0.012174226876889026, 0.04393477856572117, 0.06549677135603083, 0.022404084297557993, 0.025552874205694086, 0.056271732093826424, 0.020437728117911086, 0.03256781109338326, 0.02717200869454011, 0.08541060641648308, 0.09656897580791866, 0.08742717965956658, 0.03453178857002528, 0.05170164607285012, 4.031417456365401, 40.22486709779309, 53.73399242278069, 52.6016394553646, 58.74790330086985, 35.23540827535814, 38.31109954464821, 30.89231291124898, 7.316982005873035, 0.34080398839808285, 0.6517181677683708, 2.6330331640858806, 10.803141959251898, 6.197654739502938, 3.882707900577976, 5.7987599892001, 18.967377985677413, 40.90453540125201, 52.11428888382451, 60.98675689389629, 56.846954053448094, 55.37594364535425, 52.40297532850697, 48.40752747751052, 45.509998106187396, 43.32111158678609, 41.40795200101791, 42.671214072935044, 40.919930704178356, 44.063961428980676, 48.16898853548112, 52.31301184623472, 49.86156186749859, 47.96112252819923, 45.78828242517287, 47.824361247401086, 47.68498766806818, 52.622271122470984, 54.05510117930751, 54.23172943053707, 52.56716966629029, 54.1573416802191, 54.329655324259114, 54.30910210455618, 54.156023763841205, 56.10602225026777, 53.028785567129816, 48.44007922757057, 42.78808893695955, 41.125776690821496, 40.65526485443115, 38.77270760074739, 38.0296028044916, 38.437544991893155, 38.16192003988451, 39.821737658592966, 38.22583898421257, 39.81627379694293, 38.80582417211225, 41.743573527182306, 44.82747431724302, 50.073236496217795, 48.98350792546427, 55.151533080685525, 46.88893087448613, 42.46528963888846, 48.17587229513353, 47.60224919165335, 52.82152360485446, 50.86800675238333, 50.661905811678984, 51.69116712385609, 52.66895909463206, 48.68521951859998, 38.534866840608665, 37.3334252449774, 38.83736395066784, 36.59371329892066, 38.841262786619126, 38.040059843371, 38.38491070655085, 38.191800655857215, 39.89514089399769, 42.56104646190521, 43.10865248403242, 47.724093698686175, 49.94903856708158, 51.353796220594845, 50.620042354829856, 51.62413381761121, 50.44640687204177, 51.38153522245346, 40.63125602660641, 37.98252259531329, 37.70604256660708, 40.948477714292466, 40.46640273063414, 39.58032361922726, 40.40501371506722, 38.92143995531144, 38.940173195254424, 39.70886361214423, 43.373459539105816, 47.325745628726104, 51.887360157505164, 53.01776370694561, 54.43121333276072, 49.245267298913774, 55.424459442015625, 52.686966696093165, 55.590975822940955, 49.84985751490439, 30.630227981075166, 12.437045458824405, 2.9820108509832814, 3.9182614895605274, 15.507171865432495, 17.825603485107422, 8.228422672517839, 3.9989588625969428, 2.9812903606122543, 0.5388943154004313, 0.013944359210830544, 1.394912749528885, 11.28273408259115, 35.54577758235317, 46.28842776821506, 58.37301492691041, 49.36713141779746, 31.26346914998947, 2.6225386175417134, 0.08429076973228686, 0.04967242471813675, 0.04792192530247474, 0.030300317242020564, 0.05851828110133929, 0.024957085711761348, 0.020132850021904996, 0.024966175344982938, 0.04088899300944421, 0.05212825745524419, 0.01875311992461643, 0.05183168949799673, 0.015150195010186685, 0.03413170298200942, 0.0378344472377531, 0.06008835148907477, 0.06024100599930652, 0.03997197427276162, 0.0327073808218683, 0.018325280886323705, 0.08867736620407912, 0.15574045028657685, 0.20231318750208427, 0.12930853232260675, 0.2338062806595718, 0.13260324665855977, 0.18754690404861205, 0.12174216534702048, 0.2029422989055034, 0.09728608007032065, 0.21085492996198518, 0.1307406417664982, 0.12631770208357804, 0.18272065737795445, 0.10252131810111385, 0.11749617665285066, 0.15647554229344093, 0.11184471539191662, 0.16754482332016193, 0.30672334134578705, 0.29741852934802737, 0.1292555496817635, 0.24121644996827651, 0.147038365624124, 0.207898918419115, 5.347536408132123, 45.01096279390397, 61.02026962464856, 61.28855189969463, 61.53520230324038, 42.06621985281668, 42.65700724817092, 36.70854460808539, 9.29135557143919, 0.9146163155955653, 1.611539370590641, 3.1327166480402795, 9.511733939570766, 11.157608512909183, 4.147222984221674, 5.109324984012112, 20.449875054820893, 42.603976803441206, 53.1239422675102, 63.67674189229166, 60.17682275464458, 57.13718591197845, 57.20811020943427, 51.03684517645067, 48.44404474381478, 45.80692545060189, 43.48267009181362, 45.19908358973842, 44.01394728691348, 47.370244918331025, 51.44638769088253, 55.81081682635892, 52.36801132079094, 51.896562037929414, 46.628485495044345, 50.13421758528679, 49.594570052239206, 53.92097180889499, 55.80611390452231, 55.73566421385735, 55.11407836791008, 57.284788623932876, 57.975898481184444, 55.48373037768949, 54.29839403398576, 57.06460245193974, 54.23816211761967, 51.31818894417056, 44.00921690848566, 42.81213306611584, 43.47536271618259, 40.92243317634829, 39.84895106284849, 41.06268928896996, 41.29822369544737, 41.417287242028024, 40.848316069572206, 41.63743811268961, 40.122587373179776, 43.32262169930243, 47.39606588117538, 51.38628913510231, 51.80876370399229, 58.1091296288275, 50.13293497024044, 43.66549176554526, 46.90268662668044, 48.14240663282333, 53.469605061315725, 51.91642492048202, 50.709950923919685, 54.0612239991465, 54.642001505820986, 50.70584027997909, 39.78853087271414, 39.78703644967849, 40.74423205467963, 38.499820463119015, 41.47845268249512, 40.28158457048478, 41.13717902091242, 40.519746964977635, 43.13908615419942, 45.01903895408877, 46.373115662605535, 50.10948704135034, 51.76781415939332, 54.896802594584805, 50.653115780122825, 53.16876711383943, 52.46685504913331, 52.26438230083835, 42.25735302894346, 38.95355632228237, 39.90233059852354, 42.13276286279002, 43.136795490018784, 42.6618552977039, 43.748579332905436, 40.70935826147757, 40.94587718286822, 40.15149524134975, 45.05175544369606, 48.91976548779396, 53.93931281182074, 52.394000945552705, 55.791722728360085, 49.50381817356233, 57.522264603645574, 51.24069075430594, 55.63735785022859, 51.353831521926395, 30.998448325741677, 11.729554803140703, 5.606824688373074, 5.786038762138737, 14.333009373757148, 19.526433406337617, 13.532071190495646, 16.274688513048236, 8.493165989075939, 3.4877820985932506, 0.6255956727170175, 2.003808747376165, 15.24522323762217, 40.780929750011815, 49.48080170539118, 62.87165188020276, 57.68256402784779, 35.688406728929095, 3.83924019432837, 0.2064609407417236, 0.13769370173254322, 0.146142425796678, 0.098326726245784, 0.26395623782469385, 0.14543606208697443, 0.27668347101538415, 0.2086120849895862, 0.29929762045221947, 0.2520272682511038, 0.07622764070308016, 0.15669971494184387, 0.13278473288782183, 0.09932916761646349, 0.2438826198058744, 0.15726268231388063, 0.20273499551319307, 0.12538295224188797, 0.22523789366166438, 0.11123731492027161], [0.02851610038159115, 0.03571600345293841, 0.06488223860581076, 0.03616850477673354, 0.0347262638200435, 0.009406728504766381, 0.04704893363880054, 0.03307847764282938, 0.041477926931674444, 0.03799065639595351, 0.08328378546021639, 0.10461656857402095, 0.02064079121356049, 0.013659283530057199, 0.045339550162034656, 0.11022997824775596, 0.03442697242022522, 0.013141861042728829, 0.07450771202603657, 0.036097239447577346, 0.02751263628353275, 0.027411786553960656, 0.030135533644727645, 0.058123722837697116, 0.1529647758410823, 2.2201647248960312, 17.195113858869, 39.44475081659133, 49.71632434475807, 48.12055118622319, 24.151704080643196, 29.79439247039057, 34.43641362651702, 10.105994593712593, 0.45892806603543224, 0.5209389304922474, 3.660830696744304, 4.004567116498947, 3.396371997171833, 5.049433823554747, 3.0912468990971966, 8.682527234477382, 26.52994498129814, 47.27599036309027, 56.45944349227413, 59.15402550851146, 54.39366840547132, 51.45603672150643, 48.16172038355182, 45.11225408123386, 43.733890056610115, 40.69220181434385, 39.85788229973086, 45.961337397175456, 49.21815587628273, 51.44908628156109, 53.28526543032739, 50.60069722513999, 47.532160359044234, 40.93836192161807, 45.0573605106723, 50.95213767020933, 53.72886588496547, 53.361657511803415, 52.108762264251716, 52.21305024239325, 53.02357273717081, 51.73224218430058, 50.65799128624701, 51.38295512045584, 51.24083195963214, 49.45958560512912, 45.73755441173431, 41.76089471386325, 41.016828936915246, 39.358937201961396, 38.47618426046064, 37.62609289538476, 39.24773016283589, 38.92293045597692, 35.84793344620736, 36.41089162518902, 37.35797143751575, 37.04765704370315, 38.73906150940926, 44.346179885248986, 49.56497969165925, 49.42682204707977, 52.88849023080642, 41.04169284143756, 40.065556110874304, 49.71042902238908, 42.98394072440363, 53.82797633447955, 48.50123290092715, 53.47815582829138, 50.281561420809844, 50.376514157941266, 46.25911197354717, 38.03845167160034, 37.41844654083252, 38.49112849081717, 36.158385122976, 35.66108742067891, 38.95443101083079, 44.30739548898513, 45.753000705472886, 45.77112205566899, 48.065806665728175, 49.930062140187914, 50.10688258755592, 51.411345235763065, 51.22344801502844, 49.25641859731367, 46.61045828173238, 51.52994594266338, 46.12315085626418, 38.45614487125028, 35.1453035877597, 36.686567568009906, 35.773416257673695, 42.05557846253918, 43.36830162232922, 42.24864144479075, 42.41176105314686, 37.772322777778875, 36.35879470456031, 37.20769759147398, 42.458468637158795, 46.62819131728142, 49.4212915051368, 54.202841174217966, 52.229104503508545, 47.96658246747909, 54.78493267490018, 46.21398510471467, 40.19004429540327, 25.017194671015588, 12.645592977923732, 2.04921385934276, 7.211596254379519, 22.844160410665697, 23.561591332958592, 7.858071990551488, 4.849918052073448, 1.5892648432523975, 0.2767914894127077, 0.06411966319466311, 1.9114775018345926, 15.986292323758526, 25.562878731758367, 31.728152344303748, 47.95722369224795, 41.15025228069675, 15.231587117718114, 0.5256390944123268, 0.022698262060481696, 0.02926759624613389, 0.039249162655323744, 0.047300976565888816, 0.05013510735044557, 0.024075291697837176, 0.01469304065986146, 0.05043173659472697, 0.014611739578897194, 0.11854014764990538, 0.04720224315420755, 0.11842980800617127, 0.06329317689843236, 0.05839071597062773, 0.031051207897103125, 0.01720231090251717, 0.05826775885878071, 0.04710177455337779, 0.026900648860441103, 0.057989634468310305, 0.03877067945957665, 0.025561525253579024, 0.043852504553093065, 0.04044009995977244, 0.056891795998859795, 0.016725206665033777, 0.021215246074021827, 0.061785240071795644, 0.02706316483747815, 0.051987749269051906, 0.026806887359388416, 0.07205170308870655, 0.009880129664745784, 0.0324851502063534, 0.024970555452690012, 0.017813635659554315, 0.034436552349718354, 0.018772385120692275, 0.021518298965548317, 0.03783296485761962, 0.05352357552657205, 0.07566977547661913, 0.037010983158383644, 0.03223427939378927, 0.1352994164992725, 3.1619206551582586, 23.917770001196093, 46.54717083900206, 56.35046435940651, 54.44697733848326, 30.17176174348401, 34.523643216779156, 38.63433814817859, 11.052973405007394, 0.8339829875096199, 0.15066778377419518, 1.8929498186034543, 4.933291952456198, 6.0045696939191515, 3.9419535859938595, 3.7756313623920565, 10.75920945213687, 28.49104181412728, 46.672431730454974, 57.5958796470396, 58.51248656549762, 56.666995709942235, 53.26545353858702, 49.19025213487687, 46.97559564344345, 45.32223032366845, 41.164247297471576, 41.79423878269811, 47.39580308237384, 50.22833093520134, 53.3157540136768, 54.60844170662665, 52.67135566280734, 50.35272498284617, 44.3146675632846, 47.656083722268384, 50.73993352151687, 53.749881944348736, 55.16526529865881, 54.88044631096625, 53.97773635002875, 54.89048757860738, 54.046613170254616, 53.84598001357048, 52.5300758115707, 54.378127974848596, 52.68684902498799, 47.68358345954649, 44.52178439786358, 42.57564552368657, 40.82962205333095, 39.594714795389486, 39.52934457409767, 40.938240328142726, 39.899753601320334, 37.97614482141311, 37.75284428750315, 38.630376554304554, 39.543692604188, 41.216002971895286, 46.14836385173183, 50.88059756063646, 50.85637300245224, 54.308349009483095, 43.75785966073313, 42.642345428466804, 49.26805626961493, 44.37353841720089, 53.40741195986348, 50.27892951042422, 55.30217955189367, 53.35472276133876, 50.85590231803156, 48.09474591285952, 40.294897094849624, 38.95703546462521, 40.24442403547226, 38.50617470279817, 36.94924869844991, 40.49758165113388, 45.64625340123331, 46.877614836538996, 48.00491971354331, 48.57567164205736, 51.70760185487809, 52.40105336712253, 52.56740108613045, 51.791281700134284, 50.15950510578771, 49.75775634088824, 52.214576044390284, 48.71855966506466, 39.47470203522713, 37.686340501231534, 38.901361342399355, 38.69221664244129, 42.29129722041469, 45.17751839853103, 44.43431162065075, 42.80954822417229, 39.35477556720857, 39.60232419352378, 39.692079790176884, 44.82974144720262, 49.15357012902537, 49.68809112425774, 55.50412670258553, 54.6392087782583, 53.53561462894563, 54.706324454276796, 49.409728357868815, 43.67769033678117, 28.86562816558346, 14.520193703712957, 4.407001560734165, 8.666117998861498, 7.5866047509254955, 16.036442768189215, 0.7013810125570143, 0.5508170949835931, 0.7546712530236092, 0.10305941059824922, 0.11752362558317762, 2.067156251399748, 18.617212310914073, 31.931411527818252, 38.604057450448316, 53.68328402119299, 46.29513109883955, 20.07740874444285, 0.6815526346045157, 0.038423691425592675, 0.05983115279025609, 0.010286677204402945, 0.02979207919129441, 0.048762687647174445, 0.03143367346286053, 0.032764132615298994, 0.014992467082676389, 0.04091787452418958, 0.029397208746823094, 0.015864351749299996, 0.035761562701795375, 0.02370787784457207, 0.05425315936126056, 0.05781287500154107, 0.02348208108976964, 0.05794722384082214, 0.05472807641772013, 0.054673756953449025, 0.03814120799483311, 0.13032418104910082, 0.15978527195270986, 0.16296570129211874, 0.1365691919120089, 0.1100553944706917, 0.07130732609620018, 0.08451400775342219, 0.21906903193842983, 0.09760672617102824, 0.24574818179732372, 0.20414576174751406, 0.18467353807101328, 0.15875946490033982, 0.19294105169753875, 0.11553958043335907, 0.2188954057712709, 0.2547751490267054, 0.18660706738310476, 0.1430008984020641, 0.16450676376060133, 0.12851206901212855, 0.22382830720274682, 0.14186387070484702, 0.16814597251434482, 0.3206145378851122, 3.5350334211703274, 27.4924652038082, 53.37165955574282, 65.10689297030049, 58.793493009382686, 33.99660610383557, 42.769587116856734, 45.369141870929354, 13.683439377815494, 1.066830263983819, 1.1794963022393565, 9.956091411652105, 8.424405859362695, 6.8054333521473795, 8.02417407112737, 4.60657665806432, 10.071943517654173, 28.877532559056437, 49.42635528502926, 58.166427612304695, 61.35609119169174, 59.04782341372583, 55.72447369175573, 51.623576841046734, 48.81439101311469, 48.124783423639116, 43.62465204731111, 42.71944353657384, 50.27698401481875, 52.60035291794808, 55.86082704605595, 55.93235538851831, 54.228246365824056, 53.315322552957845, 44.73550258144256, 49.196257283610684, 54.70139795734037, 57.376160237096975, 57.802004121964984, 56.83298649326448, 57.15160454473188, 58.62856518837714, 57.546096924812566, 54.69452988716864, 55.699315609470496, 56.275539244374926, 54.19380795571112, 49.97591072513212, 47.01570187845538, 45.727540600684385, 43.306924373872825, 42.528514323696015, 41.7205374471603, 43.600039174479825, 41.46656005613266, 39.10389292624689, 39.821239517581084, 40.43698887671194, 40.79459921006234, 43.12783287417504, 49.39818482245169, 53.3920794148599, 54.1129953630509, 54.10252655706098, 46.308914307625066, 44.62976332633726, 48.29880722107426, 44.01533972832465, 55.24328124138617, 53.07295930001044, 56.048375175845244, 54.17658875065466, 52.7980129180416, 50.726177769322554, 42.39199230747838, 41.47644442896689, 42.6521788104888, 39.953717570151056, 38.837752265314904, 43.174713042474565, 49.087988099744244, 49.13695104660527, 49.785420817713586, 52.11790530912338, 54.0960350344258, 55.576412062491144, 57.44555873255576, 52.37111391559724, 49.71792859415854, 52.345559673924605, 54.02831923577094, 49.966932419807684, 41.26332636802427, 40.50978806711013, 40.03732681274414, 39.693766409350985, 46.07248952311855, 47.42560917331327, 46.07521949275848, 46.34809094090616, 40.95192940004411, 41.66748346820955, 40.22066623933854, 46.5254448306176, 51.27596855163575, 53.193556493328465, 56.76219555639452, 55.733471608931026, 52.54481215630808, 58.37981239441903, 47.91858834605063, 47.22427391236829, 32.211808043141524, 17.92952472163785, 3.986677186143014, 14.332815216433618, 32.356394452433435, 31.198734352665564, 17.835262321656753, 9.718921376812844, 5.7699442967291805, 1.3316163588916103, 0.2953955056446214, 3.349866415223768, 22.594299547133907, 35.87331902596259, 44.641436299970074, 58.47600852289508, 53.44829090179936, 23.11835369756145, 1.1296738660143268, 0.22654005927183937, 0.09343424361319312, 0.11621916937010905, 0.08563649510183642, 0.1285606160038902, 0.1040182539051579, 0.12180798762147466, 0.15356983208367903, 0.130174947121451, 0.2494113384595802, 0.07839173183686311, 0.18928888073611647, 0.1647028056604247, 0.32709441598384614, 0.11273408984585155, 0.08402177327943426, 0.10063140217455165, 0.21956226998759856, 0.16982977248487935, 0.1717102272255767], [0.04033127333968878, 0.08366129826754333, 0.014386151583054134, 0.014605789948555251, 0.01145413104114273, 0.050036385430083166, 0.04017882567319659, 0.033720926637010235, 0.08657247834508458, 0.06717239716841329, 0.09370432025001896, 0.03249583713289711, 0.06946703734537286, 0.09445246639511279, 0.07277658314353998, 0.05855281251452624, 0.04644619481217477, 0.04017158997275176, 0.05991050417745306, 0.05706588181877329, 0.03339584871766067, 0.04354937888321377, 0.031384793222851814, 0.15012320251234118, 0.020264555857847297, 0.247770270873462, 8.944266015483487, 26.14736876180095, 43.08037219509002, 41.07874355008526, 33.72402098871047, 37.35496297959359, 30.5285934863552, 15.475615416803668, 1.4294804752834382, 0.15605102233108015, 0.17860745470370018, 8.429305880300461, 2.7797847217129124, 1.8864722694120102, 9.744570735962162, 18.449042650961108, 12.75074976105844, 37.126728104006865, 51.331171989440925, 56.33288429629419, 53.4787755627786, 52.466074497469016, 49.24237258972661, 48.91181876582485, 45.856778775492025, 48.037781330846975, 47.855771587740996, 51.05723757897654, 51.942716567747055, 54.758527278900154, 53.2588678790677, 51.142482449931485, 45.300947543113466, 39.44006358423541, 41.14406670293501, 46.698193857746745, 46.84223897995488, 48.814677346137266, 46.26499552880564, 44.438853725310295, 46.229921694724794, 45.61038332600748, 47.111093921046105, 49.227616633138354, 47.65673091334682, 46.44814668163177, 43.877229152187226, 40.65606501794631, 39.63615463626, 37.79998725460422, 38.661182849637925, 39.00408429484214, 35.95143302794426, 38.139103612592145, 36.29805288007183, 35.46282337557885, 37.42833091366676, 39.874670044068374, 43.03646518338112, 47.16312416138188, 51.59496315063969, 49.99676204496815, 50.97482858165618, 42.838742425364835, 40.13133425866404, 55.009582504149414, 49.3679472707933, 53.61223420789165, 46.663018042041415, 50.01465197532408, 47.53976191243818, 49.09250667018276, 42.22828434359643, 38.528520445669855, 35.59930616809476, 37.76681969242711, 35.499038619379846, 38.251773695791925, 44.12364421352264, 49.01840917525753, 50.415573120117195, 50.870583749586544, 49.93566328479398, 50.39392555913618, 52.303021569405836, 51.360589765733295, 51.61723044610793, 48.62770188239313, 50.82466848434941, 50.22607557235226, 45.26361050144319, 37.33921858572191, 35.23128586430704, 35.742374620129986, 39.29302177121563, 47.23968490477532, 49.11702148375973, 48.78405540220199, 46.931013984064904, 45.59005368140436, 40.758180003012384, 40.16605900179955, 40.25483008353941, 45.844941062311975, 46.708015472658225, 49.22665957481631, 51.37806784722113, 47.737002218923266, 46.852033138275154, 46.827836036682136, 28.969774938398793, 14.723230292720181, 2.5207634077918146, 3.0463404184387577, 24.977823880410966, 34.13829780394031, 17.87427813776078, 2.227885175135828, 0.35349806530341027, 0.39502536277136496, 0.145992839468583, 0.410701115165026, 7.546683847904206, 20.37069416815235, 28.619573962303903, 35.60553881429857, 44.63352487933251, 34.137611389160156, 8.17967104334985, 0.18875667945511881, 0.05022337600108116, 0.03164033717175405, 0.13049739352878065, 0.07854049845087914, 0.02799943536369791, 0.03116253387903975, 0.02244668644702723, 0.03473367955115053, 0.05460786573108166, 0.04816525780986394, 0.02509532244725814, 0.017526209046463334, 0.039205710148258556, 0.015868741433106123, 0.023735286555283015, 0.0699807835682746, 0.10956493732068809, 0.044747682123054425, 0.05633701044585436, 0.05692844181471775, 0.036863683602742614, 0.04644969200354911, 0.08461798886738478, 0.019709149773623195, 0.06575947056614584, 0.05886908808362581, 0.016136014188129096, 0.03908145451737989, 0.0748375818253525, 0.08617912283948354, 0.029099219696476098, 0.08290176805589469, 0.016738697473380356, 0.039693692834266735, 0.037384129264542175, 0.027460789368037256, 0.058869187675055966, 0.03755708893520698, 0.01813305601958306, 0.03430182046647515, 0.041050591596191933, 0.029218681532168583, 0.053448433792519, 0.07985172688119835, 0.02413441453339352, 0.24831290627198838, 11.894823870351239, 33.95460144166024, 51.81500027256628, 46.926628774212254, 32.77068891832906, 41.80293075499996, 36.74520307971586, 16.70920671955232, 1.5170216488261379, 0.1984269460362773, 0.6959554553031922, 5.078806492590136, 4.8153654029292445, 5.825041340243432, 9.12408805662586, 17.374385787594704, 17.254112189815892, 41.10825546326176, 52.863540034140314, 58.895957085394095, 56.01802387545186, 54.79645267609627, 50.60939311981202, 49.626447154629616, 45.156467037816206, 48.30981339177778, 49.10366189095282, 51.64312201161539, 53.31359671008203, 56.26859664916993, 54.36731007791335, 53.80101003954488, 47.799116872972064, 41.4760757261707, 44.09171612031999, 47.255131198513894, 50.18638903094877, 51.04796117351901, 48.55129411143642, 47.755241240224535, 48.58299862953925, 48.619158960157826, 48.94435090403403, 51.42181796412314, 49.756897341820505, 48.85534055771367, 46.16312765306043, 43.188260909049745, 42.294968558895974, 40.27586967714372, 39.76596547711281, 38.660590571741906, 38.02166000489266, 39.501044673304406, 38.98918321055751, 37.450527606471894, 39.37259097253123, 40.14807885692966, 45.82121856750981, 49.685121890037294, 52.199408238933934, 52.44694509813863, 53.368702088632894, 46.79868105919131, 41.87838539000481, 52.67537609223397, 50.50766252702283, 55.086853196544034, 48.506355516372196, 51.69648585780975, 50.82810448062036, 51.71976512478244, 44.09142586492723, 39.66119504744007, 36.87044435931791, 38.73207184576219, 37.557133705385276, 39.273900216625584, 45.66307644690237, 51.33255266374158, 51.29959690955378, 53.76619900426557, 52.849741135874105, 52.14812324893091, 52.403426401076786, 53.43064415839411, 50.432278494681086, 49.750409741555494, 53.10980604540918, 51.97462112672868, 47.66110043371878, 39.266447713298184, 37.04593904556767, 37.48587992883498, 41.25179459971767, 49.99125503724622, 50.10873002390708, 51.63893684264153, 48.36167104782597, 46.46032564101681, 42.23016708127914, 42.442724243287124, 42.566274981344904, 47.462271567313906, 48.189267189271995, 51.26341304471416, 53.517257936539195, 49.81638400785385, 51.36129579236431, 47.04124827538767, 33.7088571056243, 17.099476668142504, 5.266810107615687, 5.075488167424356, 18.899338591483332, 27.900425041875533, 22.692084235529748, 3.552145986787735, 0.6785632369499053, 0.5656240423840861, 0.1410127316992129, 0.3003519412971312, 7.683133790569921, 24.60583413800886, 31.58037704806174, 38.98866153532459, 50.270417967150294, 40.83993396451397, 10.396834419619653, 0.14175887069394513, 0.09510170292830276, 0.05985464104601453, 0.03319572739964051, 0.032073280270842296, 0.041703084003060095, 0.021683526893837318, 0.042634160453153234, 0.03346109642617164, 0.014682786572994965, 0.025294231431138132, 0.02946922101170546, 0.07966695413474115, 0.023696861500220916, 0.09305355154098043, 0.041508187404683525, 0.013840527484013189, 0.10458791688565286, 0.08769577774669855, 0.025730823023965763, 0.0819932337429735, 0.13249509036540985, 0.20580909184871182, 0.24699296742197008, 0.14358655729841802, 0.16695237688479886, 0.20757360684294857, 0.19386702217161658, 0.13747351274134653, 0.2005596582086817, 0.20823869373529189, 0.17102102388537702, 0.17320711706434527, 0.12918756703936285, 0.12597973473490248, 0.2693419278629365, 0.0996253525297488, 0.1560758742233438, 0.14853024524786781, 0.17819117784740465, 0.15778515427823991, 0.1629906451149333, 0.19548104685400763, 0.1342542580659351, 0.20029442324753732, 0.11807424361787497, 0.3696420506363915, 12.744630863589625, 37.45265353110529, 56.68190463896721, 52.0613133522772, 45.471421595542665, 49.2056631272839, 42.76820644255608, 21.467757571128107, 2.1840036588330425, 0.46791911906292366, 1.2653705910328896, 16.415174084324992, 6.310553300765253, 5.7528236412232925, 12.799226334018092, 26.20571990166941, 21.00204279345851, 44.33347925063103, 55.49611330032349, 60.781534564110544, 57.90004768679219, 56.88382825543804, 53.61797655782392, 53.40101457411244, 49.72100373237364, 51.401700127509336, 51.83680472835418, 55.33986176213911, 56.3576344520815, 57.42393470579579, 57.616126921869096, 55.48389511723673, 49.92247627627466, 43.455182121646025, 45.14808493275797, 48.597660449243364, 50.155319936813854, 52.9817485040234, 49.84837878134943, 49.5391861854061, 49.471360560386415, 50.37077965274934, 50.40658304768224, 53.190061661504934, 51.53633156130391, 52.157152545067575, 47.83440643741239, 45.399038176382746, 45.031531703087595, 42.28571568765948, 42.19466178647934, 41.55954768580776, 40.23519862082697, 41.715391297494214, 40.22862472841817, 38.98955583572388, 39.977059595046505, 43.36475579969345, 47.90458940690564, 51.2378901820029, 54.960360680857015, 55.86733425817182, 54.14353885958272, 49.06736819974838, 44.24272737195415, 53.74576737803798, 52.76943060659593, 58.20456481749012, 51.73932598483179, 54.72807791925246, 52.69288555268319, 53.970715307420306, 45.79821778881935, 43.017484834117276, 39.58389689845424, 40.237100970360544, 40.215473021230395, 41.622023197912405, 48.855893611907966, 52.62479320649178, 54.56683320383872, 55.309792872398134, 53.8916560142271, 54.05181423310311, 53.756244028768236, 54.17820476716565, 51.76852018602433, 51.046227485902854, 55.022898950884425, 54.94583222173876, 50.20662453866775, 40.76881354854953, 39.32077254018476, 39.01140343758368, 43.63526990336757, 51.58337646915067, 53.51115472855107, 54.44693027004119, 50.333548515073716, 48.65122041394634, 43.48031666971023, 44.05168441034133, 43.219639870428274, 50.042465502215975, 49.298650756959, 51.931443675871826, 54.29324396194951, 49.555950395522586, 49.73986641053231, 50.65322952885782, 35.21444320678711, 17.969470139472715, 5.314995934886317, 7.508685396563623, 34.33185500483359, 41.452600340689386, 22.016032357369703, 9.580922588225334, 3.1879357753261446, 1.9443122754173896, 0.7694226130843164, 0.8035967535068913, 10.476851751727443, 30.39407580129562, 39.20671393794399, 47.76864005673317, 55.88901319811421, 45.08324030906924, 12.627052914711738, 0.46093313263789304, 0.22793015645396328, 0.2275473729617173, 0.18843028003409987, 0.14370488723920238, 0.22882195940661818, 0.13439564725324032, 0.06774638854568044, 0.1900608522156554, 0.13955230764564008, 0.11411305577043565, 0.16864157011432035, 0.17640660667131025, 0.14517363100763292, 0.1859325422875343, 0.07374476506224564, 0.1641194756713606, 0.22743693372655302, 0.1906864702581398, 0.18624499890833132, 0.20459165556296227], [0.030743619765064893, 0.019495991554351586, 0.051431910345150586, 0.013295932815620496, 0.0474035787215877, 0.05611675250674448, 0.04818378947675229, 0.00950642335679262, 0.052190375694584464, 0.04740748960044115, 0.05314670240266189, 0.04841759185036344, 0.06693993544866962, 0.0530035435522516, 0.03903619021237378, 0.03660255104243275, 0.05234574981694741, 0.004578696849245218, 0.05375310696000534, 0.06106658065090738, 0.02032607846382645, 0.11777116391327112, 0.090056041015252, 0.1058218700270499, 0.07421150413011351, 0.07990534537501874, 1.9188563381471944, 16.718322307832782, 41.54130081976614, 46.32092068272252, 43.817526755794404, 21.803724265867665, 25.337766062828806, 18.097411970938406, 2.248914472518429, 0.11445176622439777, 0.4054121054228275, 1.683115516939471, 4.8230635446886865, 2.5221359922039897, 19.44840765768482, 21.676309993190152, 24.727974783989694, 27.47757980900426, 40.72763650648056, 55.77429563768449, 56.37294738523422, 55.69558151306645, 53.35690359915457, 51.02309726899671, 50.90965055650281, 50.21417902361963, 48.8436048261581, 51.365084801950765, 51.92546990609939, 51.38914462058775, 54.27028240696077, 52.65650556933496, 46.34279966354371, 38.73150310208721, 38.25671588220904, 38.53372935325869, 39.20931054699806, 38.34043887353713, 38.21753924892795, 37.45648176439347, 38.855402931090325, 39.18278747989286, 39.664956600435325, 40.92839125664004, 40.28982939258699, 41.197018700261275, 41.810877476969075, 41.01855477979107, 39.912034542329856, 37.953920672016764, 37.92540111849385, 38.16359096957792, 37.23742915738014, 35.71385898897725, 37.096741584039506, 36.114344750681234, 39.25759492381927, 41.97014924018614, 49.5788021241465, 47.32295682353359, 54.27917834251158, 47.77136610400292, 47.909064831272254, 43.05594759602701, 40.63445668066702, 53.88510173366916, 48.602328069748424, 49.142073662050315, 46.7735622006078, 47.577887350513095, 45.42937770966561, 42.279153562361195, 36.95940371482603, 36.61197585444297, 36.54406393727949, 37.69498932746149, 38.05560027399371, 42.23072013547344, 49.67521006061185, 52.86787425318072, 49.16075198881088, 51.01504856540311, 51.25187343166721, 50.92464577767157, 50.74205552378009, 50.117308247473936, 50.80359751178373, 51.245546648579264, 48.798760367978005, 49.04682674715596, 41.405131816864014, 37.02315399723668, 36.858147728827696, 35.15878477404195, 42.18730342003607, 50.660160356952304, 48.875866320825395, 50.88236654958418, 48.931650269416075, 47.48238548155754, 45.90846776962281, 44.87550766237321, 43.9517306512402, 46.92739755876603, 48.49050521850587, 52.70849266359883, 52.198776737336196, 54.36138337658298, 48.3763446346406, 37.0055268656823, 14.776184251231534, 9.435613482229172, 19.85334138716421, 27.135682490564164, 38.17531885639314, 17.78853904816412, 3.0889113728077184, 0.2045904451440419, 0.13783677631328184, 0.13114266938740207, 0.05791462679964401, 0.7955248834144685, 13.223308094086187, 22.766713211613318, 32.67575775423358, 34.92829845797631, 35.40720024416524, 21.78299650069206, 3.3149666363193147, 0.01909780011872851, 0.03382110795486839, 0.034617433369520216, 0.01870357127289378, 0.0757488587330426, 0.01255631801717344, 0.10080033988361398, 0.08296957449807275, 0.022211298271412813, 0.04171901480144551, 0.03539275265328827, 0.08072190317175082, 0.03057538111123347, 0.0652279664251593, 0.0045297141449766294, 0.0955774205466432, 0.012112049265734613, 0.01125877000196206, 0.07564345269554085, 0.03980055826926424, 0.08985825243496126, 0.019127543482388702, 0.0022490079103473335, 0.03324001494254316, 0.03209478435887685, 0.04638450941251171, 0.027468490466896086, 0.07057938935054887, 0.06232176591912585, 0.11190664593971546, 0.027191463497377215, 0.02955993348281951, 0.01019828693730937, 0.05209485602174556, 0.0332729528928476, 0.06506659766478885, 0.025908589896355427, 0.03545410097426465, 0.05104656045835826, 0.035362312149616985, 0.07831856277921508, 0.04002271993686596, 0.10782905869306096, 0.08130042212865046, 0.061539302865463885, 0.07069716770802775, 0.09711643756036797, 3.75169558871177, 21.59492277329968, 48.46756719773816, 51.06436452557964, 48.87634484998642, 29.143484946220156, 34.36332025835591, 23.111991613141953, 2.6035781252768735, 0.15057830470463923, 0.642935184221114, 3.1189682502900404, 6.3235750794410714, 5.420264015274664, 18.75242033312398, 26.55825664920192, 25.765941796764253, 32.563609346266716, 45.84015184833158, 57.383189124445764, 59.15172699959048, 58.15741400564871, 55.815307940206225, 51.957405844042384, 52.360531360872336, 53.33099634416642, 51.82044452236545, 54.81109488394953, 52.59069212021367, 52.97109142426522, 56.50131871623378, 55.40562422044816, 48.59270649571573, 40.10666255028018, 40.99879387886294, 41.39717332778439, 42.45150250773276, 41.773881681503795, 41.83908716324837, 39.82672691345215, 40.14208155293619, 41.204953655119866, 42.81089751951156, 43.35622072219849, 43.167939109186975, 43.58267091935681, 43.540780005916474, 42.02709028797765, 43.16636623874788, 39.178535630626065, 40.00881510396158, 40.210052305652255, 40.15286807091006, 38.546120120633034, 39.32847607520319, 37.44622084402269, 41.11340161292784, 43.771223175910215, 50.97750756048387, 48.45542746205484, 55.67985280867546, 51.28909672460249, 50.14856953774729, 45.253149540193625, 43.43708038330079, 54.6826764845079, 51.873200401183105, 50.993220575394176, 48.3796041242538, 49.16566671863679, 47.657793875663515, 46.43403791612195, 39.40637042445522, 38.706215581586285, 37.856363481090916, 38.25727678114368, 39.440345994887814, 44.07641495427778, 49.94788931262109, 55.07272481918336, 51.71275192691434, 50.688577928850734, 52.0540883464198, 52.970044151429214, 50.869712983408284, 52.61713673991542, 52.19383455091908, 51.8852577670928, 51.619881968344416, 50.87048569033223, 44.141322335889264, 38.81716374428042, 38.000306621674575, 37.52555862549813, 43.30871689704157, 53.28310028199227, 50.84851649499709, 52.89339319352181, 50.81783571550923, 49.329645326060636, 47.76436467324534, 46.324588098833644, 46.88591457182362, 48.83007264906361, 49.105634843149495, 52.436213493347175, 53.68836349056613, 54.631305202361084, 46.957842996043546, 39.959405006900916, 18.943731977093606, 12.71004536459523, 14.819764725623594, 16.780127094637965, 30.68665323718902, 27.10762969909176, 5.196486913388775, 0.25459468935526186, 0.22543735231363007, 0.07989143321831381, 0.11542537970648659, 1.258915840618072, 16.742397815950458, 28.555959001664196, 36.48920959041965, 41.32039685403147, 43.422112618723226, 27.104978176855273, 4.977751037766857, 0.07306986458359227, 0.03167306636309913, 0.007727217190192953, 0.053929996661721706, 0.006580097242183383, 0.04968417267645559, 0.035155031739944415, 0.01492611141950493, 0.025938633949525898, 0.0052692494618015425, 0.04476280469867972, 0.016933391058456995, 0.023244319956809766, 0.0891879867882498, 0.06376289987876531, 0.08514933212990723, 0.058960455559915116, 0.058379021638463584, 0.07577702012513915, 0.015172988998763745, 0.029693950989073323, 0.09835062818902154, 0.10556838685466398, 0.14195266029527112, 0.08688418419971582, 0.14621264541581755, 0.16066627306563241, 0.19128371240390887, 0.132556178216492, 0.17182428239574357, 0.16242473596526733, 0.16751863843491002, 0.09589480311279336, 0.14938676219073035, 0.09141078323967035, 0.12752093509921145, 0.18160508014261725, 0.07568426219926727, 0.17517956364299023, 0.1764657486590647, 0.22931129040737308, 0.20932655390952865, 0.268029649892161, 0.20535999578574013, 0.18427783833636394, 0.14384132749851675, 0.17848150984894845, 3.8076996803283696, 24.487537414796893, 56.11748733828145, 60.110299356522106, 58.374878052742254, 33.76471165687808, 39.150761327435895, 26.746098956754132, 3.634491981037202, 0.4217706873051582, 1.964134708527596, 5.278377177253847, 11.50018342079655, 6.250230679588934, 24.286180580815962, 26.18112664068899, 34.35529901135352, 34.473797736629365, 47.676813448629076, 58.712523521915564, 62.757918834686286, 60.69375976439446, 58.96670879856233, 54.52853518147623, 54.84797693067982, 56.21739010657034, 53.62376205382809, 56.81916798314741, 54.26257887194234, 54.414198090953214, 60.072648525238044, 57.993957073457786, 50.582889664557676, 42.0418893906378, 41.75281463130828, 42.05018912592242, 43.765876985365345, 41.573330894593276, 43.21756493660712, 41.89997803780341, 42.9523499550358, 43.49662588488671, 43.539065930151175, 44.932495778606786, 45.19922871743479, 45.859132197595414, 44.792294579167525, 45.18943063674435, 44.46679669041788, 42.31248586408554, 40.18225446824105, 43.261554318089644, 41.9985628897144, 39.89133619493054, 40.0126511819901, 38.95834945863293, 43.14365963782034, 44.87069883654195, 53.680440302818056, 50.672904137642156, 58.447186946868904, 52.33602831440588, 49.42044035080941, 48.069944766259965, 46.03527015255344, 55.37133878277194, 54.09434057051136, 52.33414557672317, 50.11984602097542, 51.273069920078406, 50.29793339390909, 47.41389697597873, 40.053541891036495, 40.043916394633634, 41.10942432957311, 40.30502465463454, 41.53288733574652, 44.607951025809015, 52.386101292025664, 57.021899607873735, 51.91772322500906, 52.85342424146591, 53.65449382412819, 52.468502444605676, 51.486835172099454, 52.891333949181345, 55.289965291177076, 54.63047365988455, 53.08773486844955, 53.667669065537, 46.67819761460828, 40.052384791835664, 40.28875466315977, 39.151843901603456, 45.13248566658267, 56.46627233874414, 52.537834259771536, 53.81086695578791, 51.24924152128158, 52.12141583042761, 50.498421422896854, 48.17875523721018, 48.553443570290845, 50.48655625312559, 51.86762671316824, 55.97517590368948, 54.64891664443478, 55.846898709574056, 49.40799467025265, 40.245208509506725, 19.61254119873047, 17.480680058079383, 26.283782912838845, 37.83139759494413, 44.822410537350564, 21.83206339036265, 4.557116060487686, 1.936853520812527, 0.34128705279961713, 0.39457202258129276, 0.2432752806212633, 2.19967671459721, 24.77543938544489, 34.55199410838466, 43.5977053642273, 47.20992588227796, 48.49417655698715, 31.076034768935177, 5.876837218961408, 0.12462394297002785, 0.18172678087026845, 0.13036314428092974, 0.20513809075759304, 0.2683945528922543, 0.16298846942522835, 0.2531840456950088, 0.14008659268579177, 0.18537778737804583, 0.1403996774986867, 0.1260085166582177, 0.17283580956920502, 0.12672078690581745, 0.13452516207771917, 0.060648453692274715, 0.19052090333594432, 0.09524135309601985, 0.20567185485795622, 0.18299997303514712, 0.11237232780624783, 0.21592154437976502], [0.06873040550178097, 0.04775255092329556, 0.07222516837740137, 0.031457397290655685, 0.013902057750871586, 0.03582615157469146, 0.039074019634074746, 0.03651077753954357, 0.02381222285029869, 0.06445244029765168, 0.03260585501970303, 0.06232413313081188, 0.025457431141647602, 0.060715892412249124, 0.06151196501788594, 0.035229468673107125, 0.01659719911854594, 0.018645139831689098, 0.10272512813248943, 0.04196166932102173, 0.061159794399094206, 0.017467279648107868, 0.024131340605597344, 0.03737493620945081, 0.09429737955572144, 0.040083727348716035, 0.21472318368333004, 6.458676707360053, 23.703339907430834, 45.00842894277265, 42.60782464858025, 24.42142390435742, 21.748879724933257, 27.57192457875898, 5.426184342753503, 0.45050459222928174, 0.3107893683256642, 2.6771850787824203, 6.192076148525362, 5.661071558152476, 15.869107592490414, 12.29070378888038, 6.0574594236189325, 12.795797201894946, 31.83649213083329, 50.87663204439225, 57.09544404860466, 57.43561160179877, 54.302539979257894, 52.87594649099535, 50.47316920372748, 53.63685884783345, 54.84176389632687, 54.703774913664795, 51.597971608561856, 55.71063949215797, 53.49004060991349, 50.44432017111009, 42.527157183616396, 37.504397438418486, 36.948166124282345, 36.852048443209746, 37.37889728238506, 37.47483453442974, 37.75368367472003, 38.15525985533191, 36.986942675805864, 38.6697296942434, 37.84351379640641, 37.853139292809274, 38.05656909942627, 39.78736985114313, 39.43305823110765, 39.516075195804724, 40.844181891410585, 37.37388449330484, 38.28077177847586, 37.42327105614447, 37.56568054999075, 36.50815463835193, 37.21570314899568, 37.664908670610004, 44.76990569022394, 48.46003624700731, 50.62196039384412, 51.88192375244633, 49.45671050779281, 46.645351686785304, 52.24297008206768, 44.34210846501012, 41.668722937184, 52.82331220565304, 46.00169466387841, 49.27055089704452, 42.17877618728146, 40.502092376832046, 38.07701641513456, 39.028281396435155, 36.109065240429295, 37.82081896258939, 36.948679954774924, 37.252294940333215, 39.318046492915, 48.79143338049612, 49.678367568600564, 46.31689240855556, 49.419216571315644, 51.612806012553555, 49.41446658103697, 49.42409207743984, 53.45927353828184, 50.513738278419744, 48.361647513604936, 50.600238307829834, 46.93329680350519, 40.609365278674716, 38.07460807984875, 35.51033896784629, 35.83777842983123, 36.73500491726783, 42.07413127345424, 50.595711892650975, 50.92674816808393, 49.48377878435197, 52.68886904562674, 51.87911141303278, 48.392669539297785, 50.25384987554243, 49.33553672605946, 49.397694526180146, 51.367736324187256, 53.51391999952255, 54.59144607667, 53.8667332741522, 43.821802139282234, 28.142670623717773, 17.002968711237756, 13.944842796171866, 22.65136414958585, 37.41839162765011, 35.202432909319484, 9.804674194705102, 1.1748123793832719, 0.19023009635988744, 0.16878323509327828, 0.1013786596576533, 0.16318437342922534, 3.8072294862039633, 12.238826520981329, 25.48169351393177, 32.04896103951239, 33.189013619576734, 32.48965894022296, 13.033347706640921, 1.430338984054904, 0.036455883509329254, 0.0305446035288755, 0.04559060866614023, 0.06083709518274954, 0.0028583348537194395, 0.04771609279897906, 0.056747610590630965, 0.028553454828779065, 0.06578997618729068, 0.06309460690845886, 0.015850398415369133, 0.04271056240184173, 0.07982817733840597, 0.02924421715790466, 0.03191462346172381, 0.06995684332064084, 0.03337033415934251, 0.06938943263864325, 0.04117623384621355, 0.07051853898672328, 0.054516628489739476, 0.02386441450536011, 0.0707976861045726, 0.02731147308593556, 0.019725379346299077, 0.04901849206597094, 0.02320342426819186, 0.016612283389775023, 0.04643877525062812, 0.03493698013405647, 0.05236252331204953, 0.02659420794506948, 0.06050619882561507, 0.10672083590179683, 0.04861734544617995, 0.05668074643659977, 0.0034729229059115418, 0.05122768279585627, 0.08113328472621019, 0.03817976136962253, 0.046835616456284646, 0.048246420995001836, 0.03886115827387379, 0.0381324899142548, 0.020113864447921515, 0.03633774126008634, 0.07143658811166402, 0.5779698863625526, 8.77281137051121, 33.25710204339797, 52.33460449403333, 47.661861373532204, 28.01259698406343, 27.037285912421446, 26.76177274796271, 6.400692309102705, 0.2650156454934228, 0.5131716263150016, 1.0968754969296919, 7.0138514330310215, 8.069362226993807, 18.177347913865123, 16.608280212648456, 10.654319390173882, 19.366200662428334, 34.71699645442348, 55.12189172929334, 57.996667431246856, 58.95408661134782, 56.305918001359515, 56.202339972219164, 51.91808800543509, 55.41461821525328, 56.23080069018949, 56.46740982609411, 51.84601837588895, 55.8446394243548, 55.843027330213985, 53.46066205732284, 44.65387413578649, 39.71504918990597, 39.472525119781494, 39.23597089705929, 37.82521201718239, 39.349452910884736, 38.318128431996996, 39.09891151612805, 39.621061355836936, 41.503273440945534, 38.72431339756135, 39.389974917134936, 39.55654228887251, 41.08445844342632, 41.937044435931796, 41.840828695604884, 42.82158597823113, 40.078943160272416, 40.252841441862046, 40.18205442736226, 39.56475965438351, 39.85561909214143, 39.025465134651434, 38.18182606850901, 44.53315534899312, 51.0292750020181, 52.37991571426392, 53.4326720237732, 53.18406043514129, 48.24668284385435, 52.38395575554141, 45.96856632540303, 44.63220304058444, 54.85768871922647, 49.5547579949902, 49.64358791228264, 46.22571691390007, 44.90734946343207, 40.552208500523726, 39.49625545932401, 39.034337535981216, 39.154769989752005, 38.79928165866483, 39.43609414562103, 41.924532075082105, 47.96405253871795, 52.669174824991536, 47.86163945351878, 50.084827100076986, 53.26808544897264, 51.221992815694506, 52.59304554231706, 53.05502622358261, 53.78583831171836, 50.31032023891326, 51.24432679145567, 50.175390704985595, 44.796699400871034, 39.67532734717093, 36.456018494021514, 36.78898457557925, 38.43371675860497, 44.93636715796686, 52.50908328640846, 52.78014259953653, 52.24610797820553, 55.161652795730106, 52.96843205728839, 49.955212377732806, 51.01298932106265, 51.2712146389869, 52.1045143373551, 53.924902023807654, 55.62031515182988, 56.55596517747449, 54.50644439266574, 45.28009230090726, 31.003741564289218, 19.102623270403956, 16.413382541748785, 26.508269963725922, 42.48019072317308, 41.207110958714644, 14.573467335393353, 1.3144686145167197, 0.01363242544504183, 0.23554936051368716, 0.11728662096204297, 0.2734891601627873, 4.6491819331722875, 17.256530331027125, 27.518809803070564, 36.24780731816446, 39.101355152745406, 40.70001517572711, 18.021508224548832, 2.1720445973257867, 0.006061073152288314, 0.054896998805023974, 0.037682532002368284, 0.047969487871253685, 0.013613097046712234, 0.07993641790122756, 0.04018590049517732, 0.017325909613000772, 0.046042320919373346, 0.05277431472354839, 0.030317230548168865, 0.07239710149024764, 0.02698897305245121, 0.07365420580871644, 0.0344883015890035, 0.043362897760685415, 0.05336076269046434, 0.01688336168656186, 0.01291193507401453, 0.04761794927499948, 0.058593545409460226, 0.17107740795660406, 0.15540324902582556, 0.1829767912145584, 0.13665795085891602, 0.07650737770863118, 0.09740877671227341, 0.17442464528064575, 0.1462416341828723, 0.1319023221731186, 0.13029732200647556, 0.1021180647395311, 0.15089816173478482, 0.20876334138935615, 0.2090079379418204, 0.23367443692780313, 0.12741210464868816, 0.18808193985492955, 0.28807504523184996, 0.15967556816195289, 0.1137458315239318, 0.19262128659794409, 0.1485196272692373, 0.16797328097445352, 0.11425929429430155, 0.1579671308037735, 0.18067106574533448, 0.6055492354977516, 9.857778183875546, 37.81410778722456, 59.28980227439635, 54.787533206324426, 36.425333792163485, 33.92936883434173, 36.2674819269488, 7.443660834143239, 0.53817376374237, 1.066243379346786, 5.471136175817059, 14.862271451180982, 12.705543464229955, 19.593509858654393, 16.211293205138176, 8.504481046430527, 19.048357279069965, 34.92927905051939, 53.94400396654683, 58.198983284734915, 60.57425298998433, 59.04000220760223, 58.81658008021694, 54.049825591425744, 58.14641960205571, 59.01613066273352, 56.74694145879438, 52.25987549751036, 58.85155977741365, 58.93610254410775, 55.349404888768355, 46.851868398727916, 41.92750130930255, 41.10927920187674, 40.48511635872626, 39.87917292502619, 42.54945585804601, 39.88699413114979, 40.80219291871594, 41.64861686768071, 43.006255088313935, 40.586227217028224, 41.06773737938174, 42.203698927356356, 43.33126660316221, 44.2008521479945, 44.92584343879454, 45.74461467804448, 40.75492443576936, 41.75426198590187, 42.72458968623992, 40.84114205452704, 41.79439959987518, 40.19486881071522, 40.03649134789744, 49.94752453219507, 52.64990029796478, 55.58519424930696, 56.77145627237136, 55.63346293664748, 50.69119414975567, 53.09661511451968, 47.1108115103937, 47.18393233514602, 54.38607077444754, 52.77329806358584, 52.90387768899241, 47.07970711492723, 44.17565091963738, 41.49436966065438, 41.59718282761113, 41.14324300519882, 41.48855670805901, 41.186895062846524, 41.94226118826097, 44.13070055746263, 51.77455671371953, 53.74720688789122, 46.86419248580933, 51.229233511032604, 54.649022548429436, 51.86809347521875, 54.25065878898867, 56.669666844029585, 55.090359795478086, 51.57841074851252, 53.5460755901952, 50.72334974042831, 45.37278575281943, 42.45262430560204, 39.057267712008574, 39.68008518218994, 41.06239118883687, 46.3187280777962, 51.95808833645236, 54.7506001687819, 51.92124159105363, 56.716394039892386, 55.60442563026182, 52.45571159547376, 55.210349021419404, 54.933512057027514, 52.99062090535318, 55.66113525821317, 56.17882536303613, 58.26840923678491, 54.84142265012188, 46.365055191901426, 36.45192746193179, 26.02338460183913, 18.909542637486613, 25.191118448011338, 46.63273734431113, 40.63520585336993, 14.113633171204599, 5.120433626636382, 0.37884212309314363, 0.6529220902631361, 0.38398367623167656, 0.8083172647222396, 8.47079965376085, 22.62934200225338, 35.32100223725842, 45.83022432942545, 45.65553765143118, 46.754436723647586, 18.714985232199393, 3.0454314091513237, 0.10935531268196721, 0.14238119455835513, 0.12639446409359095, 0.2284873934883264, 0.10409278659931115, 0.11676427923263082, 0.23737393680118749, 0.14055678681019815, 0.12108518366491604, 0.2048847454810335, 0.1401824762503947, 0.12331130493792797, 0.22990556013199592, 0.116989815517539, 0.18389663298524198, 0.16607653920448598, 0.11363084938737655, 0.1280847834723611, 0.13048515144375064, 0.12245782170324557, 0.15862322382388577], [0.03202822664001536, 0.020414507992926146, 0.07540144552026065, 0.03869707373181178, 0.019918793564542167, 0.033108083110663204, 0.05163595786378269, 0.04106301754232376, 0.026215390873051463, 0.015872388011625698, 0.052577962558115685, 0.019412936132040717, 0.033772311984531345, 0.02081890282551608, 0.06249434637626814, 0.024908956237918427, 0.020942380877151605, 0.026303929569680366, 0.18879173563853388, 0.024713540614973155, 0.061405815875097636, 0.044919952314587376, 0.03261880190562337, 0.038468250929708445, 0.03821815003550822, 0.04522151133466152, 0.06193273881029698, 1.6656013986756726, 14.07447320799674, 40.35618020642189, 45.81022024154664, 33.51425655426518, 34.81422024388468, 27.418042152158677, 8.019478503734835, 0.4566018247315961, 0.569149517724591, 1.6027522808121097, 5.003980907701678, 5.893956893874753, 6.017270328537111, 0.7529215694915864, 0.7012651187758292, 3.8444204195853207, 19.681853402045466, 38.97735726448798, 53.21645529039445, 57.213362263095, 57.29536725628761, 56.76222301298573, 55.89515170743389, 54.59376419744184, 54.19313723041166, 55.21984115723641, 54.9702803550228, 53.21118362488286, 52.577305070815555, 47.87837228467388, 39.44879870260916, 39.17871605965399, 38.669239397971864, 44.27344737514373, 45.94464378972208, 49.24477308027206, 45.00638931028305, 41.57577060884045, 38.693056029658166, 38.7709346894295, 37.55528234666394, 38.4038322202621, 38.4336853796436, 39.211087380686116, 42.075582550418, 37.962785228606194, 38.58893279106387, 38.923008903380364, 38.60739930983513, 38.39064521174277, 39.98672431515109, 38.023287788514175, 37.97376002034834, 41.47906849461217, 49.93566328479398, 49.92374320184031, 54.531680922354425, 50.90954465250815, 49.8258133857481, 48.06454758490286, 48.92001651948499, 43.57658340084938, 43.41695470194663, 54.10981824321132, 47.04164443477508, 46.93668573133407, 39.73024837432369, 36.19516518808181, 36.58346806803058, 38.453410979240175, 35.44061883803337, 37.20755638614778, 35.668088851436494, 36.56393858694261, 40.25867008393811, 46.040122124456595, 46.12237030459989, 49.637837717610026, 52.269575518946496, 50.99554654090635, 49.16496461437595, 48.967504655161214, 47.89131218387235, 45.49790151657597, 43.51451189287248, 41.79795718962147, 39.849731614512784, 36.700033064811464, 37.153831681897564, 35.400057608081454, 35.88234832209926, 36.853480108322636, 41.461013824709006, 48.925998133997766, 51.73437595367432, 52.41345590160739, 52.1597844554532, 52.65691741820305, 52.703550477181714, 51.38148815401139, 50.51515033168178, 50.495173700394176, 53.7570559593939, 53.332631972528276, 52.526981061504735, 45.20809327402423, 34.68338958678707, 17.15239336413722, 4.865831107862534, 0.647449587141314, 2.639755125968687, 4.9538677257876245, 4.487686676363792, 0.36289005810695313, 0.6022877234124369, 0.08727717198311322, 0.07946329732095042, 0.39566100124389897, 1.289799112466074, 5.82844203518283, 14.776239164413946, 30.470524757139145, 31.705541841445434, 34.731630817536384, 19.169872307008315, 4.299069700702544, 0.6215648244946235, 0.03949149541797177, 0.02554750201412507, 0.03515439971740689, 0.026981921213108207, 0.025198615997308688, 0.049597635384528875, 0.03502899495464179, 0.02475963037971768, 0.010227347525107044, 0.04122911306518701, 0.03752633050504712, 0.056259279334617246, 0.06670661571045076, 0.04592691360402011, 0.012241634953346466, 0.044194057193254276, 0.01997135485702705, 0.02983559490061335, 0.027840751741502075, 0.06777685586242907, 0.05709991527480945, 0.03713177990228419, 0.009382262529294578, 0.05021588749162132, 0.023926195666013707, 0.03924420606645365, 0.04927576737358205, 0.07475352665830044, 0.01360161530394708, 0.05485653404086348, 0.059163729329743696, 0.06456981262853069, 0.007330682419706137, 0.011275898770339066, 0.07427259198119564, 0.046718087077381155, 0.04880817028723898, 0.01287017179082238, 0.0460075558493695, 0.016830723785284548, 0.06649621732292638, 0.020397926019805095, 0.03519546203014832, 0.045443132910276615, 0.00592242943258175, 0.03373355942688162, 0.10637077202479686, 0.028977616645035245, 2.9712709111552087, 18.94725230432326, 47.76045407018354, 51.553899857305716, 36.18232334813764, 34.796216564793745, 34.32567334944202, 10.408312255336392, 0.5272516175623864, 0.14344342143064545, 0.45509180414580536, 3.3289239002812296, 6.361719639070573, 11.392034849812909, 1.0396008025253973, 1.2624448706065456, 6.9937409508612856, 24.258818126493885, 44.9036192893982, 56.07060324761176, 59.449089727094105, 57.74792248202909, 58.84381309632332, 57.29289224070888, 56.38376920453964, 54.6404404024924, 55.98603302432645, 56.077985148276056, 56.129207380356334, 54.63559235295942, 51.84213522941836, 40.58764319266043, 40.85251300565658, 40.66507862460229, 44.75729527011995, 45.95203745749689, 50.28506409737372, 45.65898541481265, 42.48768245020221, 39.56869771403652, 41.618261644917155, 39.58561881895989, 40.511294257256296, 39.74465916233678, 40.898294910307854, 41.66181564331055, 39.18512129014538, 39.96412361821821, 40.163144680761526, 39.913325002116544, 40.31496001828102, 40.24028201257029, 39.75044858071112, 39.49648687916417, 42.20164360538606, 53.79337318481938, 52.08524373269851, 56.720747870783654, 53.12308719081264, 51.54183464665567, 51.0877340070663, 49.708816928248254, 44.39002806140531, 45.61236020057432, 54.59811018359277, 49.0849051167888, 49.54535999605733, 42.31074433172903, 39.04640274663126, 38.412049585773104, 38.916227125352435, 38.04669257133238, 38.644065626205936, 36.361206962216286, 38.68940038065757, 42.85837781044745, 49.5017118607798, 48.86417765771189, 50.29765490562686, 53.6620718433011, 54.16875185505037, 50.879875844524754, 52.38980400946833, 50.86819110378143, 49.16699640212521, 47.855026337408255, 45.91133502221877, 42.37940149922525, 39.09216503943167, 38.56764216576853, 37.40221969542965, 38.92825703467093, 38.730922591301706, 44.34611320495606, 50.97722907220164, 54.08334616691836, 53.81654654779742, 51.61384151827905, 55.90345144271851, 54.67240771939678, 53.625213330791844, 52.99159365315592, 53.886643225146884, 54.83430354825912, 54.492959284013324, 53.89351129531861, 48.38838631106962, 38.153914482362815, 22.92899931630781, 8.842260856782238, 0.9194750290724539, 3.4939019766546067, 10.585716155267532, 8.586048695348925, 0.9351526200771333, 1.2146614540007807, 0.21964716785136731, 0.1497446784689542, 0.25728048636547984, 1.9017518624182672, 8.965962606091654, 20.12904674776139, 33.71099479736821, 37.85872082556448, 40.65949316947691, 27.387608481991677, 7.089668887276804, 0.9199422201321972, 0.031813530499235756, 0.04452195048572556, 0.10641338183514534, 0.011679191393927943, 0.02630468033584616, 0.01855905644685751, 0.03977531184171958, 0.04321953972741481, 0.02536526693391704, 0.058328655187881766, 0.051258544647885915, 0.04812652823485194, 0.09089265499384173, 0.08455034330367081, 0.023442943572937965, 0.04898253572924484, 0.05922422346268451, 0.07408729063407068, 0.05890966776097494, 0.11630828837834059, 0.04997775672123798, 0.1301767550889523, 0.10541752882061467, 0.23103648976933575, 0.11717363831497009, 0.12047182302922012, 0.13514753190740464, 0.1666059978907147, 0.1431295092427923, 0.15913559874940306, 0.150741450788994, 0.21714967525293752, 0.10801079007045877, 0.11414702410899824, 0.20737482234835627, 0.10997975860992748, 0.20956443953177623, 0.10778169913758194, 0.21892896042235438, 0.19469258916233817, 0.11104303502267408, 0.16458913353421997, 0.13535524898719403, 0.1552056749501536, 0.1087629811597928, 0.13103570819141405, 0.207868060397525, 0.12332013793169491, 2.928602142680076, 22.80989262365526, 54.724512484765825, 60.071063887688425, 46.37190757259246, 47.487053102062596, 36.893684402588875, 10.687420272058057, 0.8443138976731609, 1.035176246396957, 4.384895082442991, 11.494710733813625, 14.46089727263297, 9.202921813534154, 1.9257852050565907, 1.6374195367097857, 8.04604716839329, 24.884424401867776, 44.560207936071585, 57.4118616504054, 60.15571648074735, 59.74888432410456, 59.722522074176425, 59.844841188000096, 57.328687790901434, 53.914241021679295, 57.6352249422381, 58.166553128150206, 57.64935724196896, 58.36504467072026, 53.57399109871157, 42.84155084240822, 43.02760454916185, 43.30080155403384, 48.58680725097657, 49.07326352211737, 52.92653329910771, 48.49409026484336, 47.075721986832164, 42.63110783792312, 43.141945562055035, 42.16321222243771, 42.07018929143106, 41.248472352181714, 42.90110811110466, 46.24256741616034, 40.48041343688965, 42.00024166414815, 42.25184994359171, 42.10829511765511, 42.062179811539195, 43.17306172463202, 41.705546148361705, 41.776290016789595, 43.890988826751716, 53.926298387589, 53.0678209950847, 58.585352436188735, 56.871672830274036, 54.45736377469955, 52.882900853310865, 48.20830245171824, 47.86746809559484, 49.77965493356028, 57.62828234703311, 52.15664655931535, 50.86494338127875, 44.331576901097456, 38.510622670573575, 40.5961625806747, 40.37942417206303, 39.464888265056, 41.97866862820041, 38.56835603713989, 39.67599807247039, 44.56748393274123, 49.06231618696644, 50.79442308795068, 51.02594883211198, 55.00960996074062, 57.14304985538606, 52.201071323887, 53.133850174565474, 53.3530165303138, 50.935028291517696, 47.80922089853595, 46.88051739046651, 43.281950642985684, 40.09171439755348, 40.64229357627131, 40.16556086078767, 40.7733242742477, 41.048176519332394, 45.06464827445246, 53.7107406123992, 55.674996914402136, 54.9123038015058, 52.40802341891874, 56.2471491290677, 55.82114442702263, 55.67821325794343, 53.47246054680117, 55.623405979525664, 56.47581154300321, 55.758433572707645, 53.64819842000162, 49.747789598280384, 41.592997658637266, 24.270765666038763, 8.301566050898645, 1.1038674894840488, 4.214419559124978, 11.997656649158849, 7.3034968972206125, 1.8451393131286868, 1.6578283641607532, 0.6409138152676245, 0.5037560992904249, 1.1808932788910405, 3.194959269415948, 12.202015076914142, 26.893474171238562, 41.68995472692674, 44.73904840407833, 48.5613706804091, 30.600772942266158, 7.99425962471193, 1.0154835579376067, 0.13471619376251776, 0.1174633268026575, 0.17412351143936958, 0.1680735618837418, 0.12348623345455817, 0.12718844527919448, 0.16140191665580197, 0.09198338799779454, 0.1450967770670691, 0.15994808095837795, 0.08310136460368672, 0.1264598190544113, 0.19974061828707496, 0.21540872512325165, 0.13856757822776997, 0.13031639759579014, 0.32708899208134223, 0.17583499782748763, 0.17873418096813465, 0.1785920869799391, 0.1580670133473412], [0.06937010424031366, 0.044861250827389385, 0.052326750836425254, 0.03483413283022181, 0.05489398424904193, 0.011269523003589244, 0.04159729875203583, 0.019148423208764965, 0.04421122905407702, 0.03569176060057456, 0.040835014454299406, 0.06627913098782301, 0.07557705585514346, 0.02420960797838146, 0.06961248679867676, 0.09319720068766225, 0.02131710703965397, 0.0179616074573489, 0.041954931577727686, 0.08714274653503973, 0.05189899032214477, 0.013482141019325825, 0.01623190158317166, 0.09114410037234907, 0.09890074826656811, 0.05185174951029401, 0.07893686468202261, 0.1071650213411739, 5.077792559900592, 25.051270261887584, 44.64493505416378, 41.97907263232816, 22.48073712471993, 23.70283196049352, 18.41095643658792, 2.265805914517372, 0.24930037828462742, 0.025265076039959828, 2.958006435824979, 6.135383190647249, 6.284247434908345, 0.2715033683325014, 0.19433228268979058, 0.9744541563334005, 5.956452998422808, 20.837340508737874, 39.097342568059126, 53.794793082821755, 57.099036939682506, 54.88971094931326, 56.34686362358832, 52.14120811031711, 54.479144696266424, 54.343877838503936, 54.458869964845725, 51.17470472089706, 48.5630141535113, 41.186020374298096, 40.32264394144858, 40.40122078311059, 47.124108345277854, 53.39853171379336, 51.7644016973434, 52.31014067126859, 51.48673711284515, 51.22565630943545, 44.4239761752467, 39.9450255978492, 40.38899083291331, 39.06803854050175, 39.78425548922631, 39.026641845703125, 37.697444731189364, 37.88094497496082, 39.835611081892445, 37.28182254299041, 38.37647761068037, 39.768664067791356, 42.61763449638121, 41.83142285193167, 41.2692452246143, 46.496344766309186, 53.00052096766811, 49.67024041760353, 51.00423459083804, 46.24385395357686, 53.867462835004254, 42.30068345223704, 68.41348632689446, 54.14295050405688, 38.88388326091152, 54.94735802373579, 46.77220506052817, 48.77667742390787, 41.478950823507006, 42.570020844859464, 37.20714061490951, 36.981576873410134, 35.775714766594675, 36.49243770107147, 36.21474565998201, 37.01841185169835, 42.00378748678392, 48.90162060337682, 51.82559067203153, 51.92112784231863, 50.10184626425467, 48.714197989433046, 46.153294271038426, 40.64999318891957, 40.69191940369145, 39.8617026882787, 36.728415335378344, 36.46729138589675, 36.03734862419867, 35.53604618195565, 35.05924286380891, 35.65645902387558, 35.76061756380143, 37.64329641096054, 39.727392888838246, 48.94130714478032, 50.637845993042, 54.80483478115451, 51.23874525870047, 50.253285054237615, 51.36304516946116, 51.22520131449546, 51.37717746919202, 52.137199448001006, 52.38299085247902, 52.33692653717534, 48.40230680281117, 37.7743310313071, 16.027674309669003, 3.3162573412541425, 0.8034854562532517, 0.11732964445987057, 0.22990148454423875, 0.9364797907971567, 0.19679934627586798, 0.05094467459486858, 0.10020836842276397, 0.05894645530309889, 0.1900689574258943, 0.13174337425058888, 3.6879614860780783, 11.360417604446413, 24.839254386963386, 27.810869486101215, 30.608090123822613, 37.255860374819854, 11.793273706589977, 1.7785227587146146, 0.04003609200158427, 0.02684456547872434, 0.03950132815647991, 0.034593190517156355, 0.02132733048300349, 0.020342482321505106, 0.05070353692938244, 0.02631484249216174, 0.10170934151016897, 0.023465209918457176, 0.016114669063338832, 0.024331415958342054, 0.009845197013008499, 0.031389786200898315, 0.006763766343224674, 0.03283124574790559, 0.03847023509743233, 0.07956563900675505, 0.04184200638724912, 0.04387592769137794, 0.06100402957188988, 0.06176153731141841, 0.09571423618904046, 0.05641798976989043, 0.04824137247558083, 0.03790230347564624, 0.039012315082213575, 0.034071021157527165, 0.024230989492348125, 0.025526135821916887, 0.015353357697266246, 0.009106516841829065, 0.08227084102409501, 0.03884672517738035, 0.06047083620703029, 0.0046365470212373526, 0.07628725000446843, 0.05038197152316571, 0.019828540746182687, 0.038005794293337294, 0.04049130910707097, 0.05342271239046128, 0.05672873035373707, 0.05804824785539701, 0.022065605585192962, 0.04916769918054343, 0.011951102811332432, 0.027101959529963714, 0.04594905737547144, 0.5105643226735054, 9.786875459455675, 34.73942848943895, 52.53275086802822, 45.02755834210304, 28.810883645088445, 28.18551467310998, 17.4812017333123, 2.4853211160629027, 0.20565725322211945, 0.12045290831836963, 0.9252634055672154, 3.158557958179905, 8.061960714478648, 1.0127277251693512, 0.38637846708297735, 1.5424576065232678, 9.014186186175193, 24.485433063199444, 44.19853794959284, 56.132384500195904, 58.273414181124785, 56.01160687784995, 55.38236064295615, 53.33262020541776, 55.293832748166984, 55.829785408512244, 55.339759780514626, 52.97644153718026, 50.85390190924368, 42.42290842917658, 41.272932252576275, 42.073413479712706, 48.00539039796399, 53.380520189962084, 54.71678149315619, 55.56926550403718, 53.49180567649103, 53.14737058454945, 45.08632721439485, 40.89856163147957, 41.448858399544996, 40.21159771950015, 41.84426076950566, 41.44159024761569, 39.410320251218735, 39.97050139211839, 42.245585918426514, 39.33793290968865, 40.27328091282999, 40.809735636557306, 43.141890648872625, 43.51088762283326, 42.61859155470326, 47.38321619649088, 52.598615307961744, 52.170716101123446, 53.136293811182824, 49.66197206128029, 54.21925237101894, 46.207866207245864, 62.88985952254265, 49.88147181849326, 43.314698511554354, 55.51730586636452, 49.59368359658026, 48.74692624615085, 43.306104598506806, 43.247716196121715, 38.39264954290083, 36.80320708982406, 37.149375869381814, 37.416383374121885, 39.00445692000851, 39.17690392463438, 43.21418777588875, 50.25167688246697, 53.25006215803085, 53.73176451652281, 51.47254205519154, 50.919821262359626, 49.16538430798439, 43.23973417282105, 44.53631285698184, 41.87783233581051, 41.731790727184666, 38.24294051816387, 37.892464976156916, 35.95452777801022, 37.74999272438788, 38.353888680858, 38.34646755649198, 40.432372247019124, 44.53692866909889, 51.01516231413811, 52.74488049168741, 53.77105097616873, 51.28534693871775, 50.52520336643342, 52.573986745649776, 52.34448494449739, 54.40712213516236, 53.45179750073341, 53.62299326927432, 52.0415916750508, 50.273536251437285, 41.904194585738644, 20.134906768798828, 4.6153264853262135, 0.769433583463392, 1.8112425578217355, 1.260919681479854, 0.46233222369224797, 0.3238564687630823, 0.1590020236589255, 0.049531552640180436, 0.03963789865074139, 0.8441723246247539, 1.0613219079471405, 5.027238601638425, 13.945993031224898, 25.3040317181618, 31.953467015297186, 35.98019969078803, 42.36869342865483, 15.947368683353549, 2.7826615350861705, 0.11391702919237076, 0.04925134832099561, 0.022476841582946723, 0.057521838199106924, 0.04960451868452853, 0.008902218429401757, 0.025454129302693952, 0.05431448853003883, 0.11078906155401662, 0.026288286054266558, 0.029959557502860987, 0.030527958353500695, 0.09812811029053504, 0.03714362362159356, 0.048499233840454015, 0.08612523621488964, 0.057927301724351225, 0.055754653388454076, 0.09646133279367801, 0.03674168027036133, 0.06210912289398332, 0.12255209648320753, 0.22006517606637171, 0.1954667210098236, 0.26226232549355877, 0.17563255143261727, 0.09660246151108896, 0.14199070422159088, 0.1377270572007664, 0.10182122865151014, 0.15163466334342957, 0.24189900366529343, 0.09757317151994475, 0.19144068381959395, 0.18605690900116198, 0.13518352271808734, 0.2058014769347445, 0.18060331292931112, 0.15000628217333747, 0.13201473791512752, 0.12677252848422335, 0.09826850356353868, 0.19220445815834308, 0.2066167017384883, 0.06351089525607324, 0.18137670933238922, 0.25959140591083035, 0.1366911990748298, 0.18042450800778406, 0.624568808463312, 9.212221753212715, 38.7666985296434, 59.5471921274739, 53.98218824017433, 32.26314402395679, 34.9385162322752, 22.76482851274552, 3.165913873141812, 0.5028215026663196, 0.48484144972697385, 9.904413204039297, 12.610884904861452, 11.7201970085021, 3.7126042669819252, 2.01485107742971, 2.5224210994858898, 7.79594753057726, 24.934530719634026, 45.34230893658054, 56.73006742231308, 57.62293223411807, 55.24667016921505, 56.46502110265917, 52.134708742941584, 57.40006316092707, 57.52802656542871, 58.0989706900812, 55.07110880267236, 54.50569914233301, 44.14325998675439, 44.14939065133372, 45.07227728443761, 51.272646304099794, 56.452842143274125, 56.1069675414793, 58.78358117995724, 56.39501463982367, 55.387393043887236, 48.28409048818773, 42.75091271246634, 43.512629155189764, 42.59295102088682, 43.26074630983415, 42.65330060835808, 41.459358584496286, 42.703373585977864, 43.810945018645256, 41.25632101489652, 42.2622795258799, 43.900528031010786, 46.112823255600475, 45.30364613379202, 44.048311171993134, 49.55471877128848, 55.01520718297651, 53.27007016827984, 53.29683642233572, 52.297298831324426, 53.44354875626103, 48.261630996581054, 61.592747396038426, 51.23758031475929, 45.642731112818566, 57.697229769922075, 53.09490103875437, 51.2390668930546, 44.47748122676727, 45.82405051877422, 41.39235273484261, 39.80228270253828, 37.76137152025777, 39.83117880359773, 40.72911131766535, 40.971474570612756, 45.9251731441867, 52.075124017653934, 54.54515426389633, 54.62118940968668, 54.68481809862199, 52.88779989365609, 50.921515726274066, 44.40117543743503, 45.417649822850386, 43.57654417714765, 41.84724177083662, 40.188891118572606, 40.16855755159932, 38.88832730631675, 39.60193587887672, 39.379478654553814, 40.662674211686664, 41.05146738790697, 45.36034399463285, 52.115202796074655, 55.99755302552254, 57.80272191570651, 51.49162046370968, 51.049989038898104, 53.07828195633427, 53.8188882027903, 56.5514152280746, 55.54186382601338, 54.91645759151828, 55.3685970460215, 51.338946127122455, 44.92542766755627, 21.544908631232477, 6.721647602896537, 1.2363665022196308, 1.7649880075646986, 2.432628240316145, 1.6814399294314848, 0.5251051617726203, 0.40907808128864537, 0.35496484788675464, 0.15099024550328333, 1.7611786506829725, 3.1963379825315172, 12.011592830381087, 20.93498203062242, 36.64575922873713, 40.511027536084576, 42.60427098120413, 49.23330799225838, 19.812393803750318, 3.3947147957740293, 0.14353101592390768, 0.13053346094825577, 0.08293670932612113, 0.13852426361653114, 0.1779515608664482, 0.07269756883502969, 0.16329896486093923, 0.09256356170461064, 0.2136903286220566, 0.10529162227025918, 0.08175583075611823, 0.13541685777806467, 0.135209416489928, 0.1453559446118532, 0.19920667032560996, 0.20759714106398247, 0.1933845706404217, 0.12240280892940299, 0.14812116961806052, 0.06759690946989483, 0.1499716703209185, 0.35328782013347076], [0.023546846162888314, 0.02257893620539577, 0.011429754123392125, 0.030247629545028173, 0.005154881153195616, 0.01963820045573577, 0.05385834828860337, 0.006907712348977165, 0.020308464187227433, 0.05128914603002129, 0.08183279194899144, 0.07790758725135558, 0.03854987376760091, 0.04984933740249084, 0.018347801956077738, 0.07202790073689914, 0.0366290117193374, 0.016142834285875002, 0.02969606539174434, 0.062049724266774235, 0.04961054779649262, 0.033340916383050145, 0.03599764035654164, 0.0366884141769861, 0.04868793661796278, 0.008313025952497078, 0.00824071778615396, 0.07863969151531497, 0.7413939074162514, 15.058137947513213, 32.82641403136715, 37.83872458242601, 36.01782306548088, 34.50744382796749, 18.716209011693156, 5.306462818576444, 0.47588244981823435, 0.06046782165104824, 0.5320486149960949, 0.7849947903906146, 2.9951740801334386, 0.4666395990117904, 0.33666260900997347, 0.20465369336307052, 1.5542591603532916, 11.103501377567168, 26.709262017280828, 44.21865970857682, 56.71126750207717, 54.08779021232359, 53.9505543247346, 51.98957320182554, 55.799402729157485, 55.101950399337284, 52.100031068248136, 49.650393224531605, 41.113617343287316, 41.64349032986549, 43.03103270069246, 46.42940951931862, 52.110119404331336, 53.97959555349043, 51.298263303695194, 50.30284420136483, 54.34572919722527, 50.02912552125993, 48.87537602455386, 42.92880004452121, 40.42945008124075, 39.32344367427211, 40.95001528340001, 38.73939883324408, 38.82249816771477, 37.133878584830995, 40.16660028888334, 39.18350135126422, 38.740689293030776, 41.93322404738396, 48.66122638025592, 44.96102709924021, 42.235670166630904, 49.62248556075558, 53.089064551937966, 51.94585446388491, 48.385020917461766, 51.49392289500083, 51.14778157203428, 47.25284837907361, 50.71317511220133, 48.668788709948146, 41.88173509413197, 52.690084980380156, 49.83186168055381, 49.999056631518954, 46.112823255600475, 44.792545610858554, 40.74149031792918, 39.587568236935525, 37.14179000546856, 38.24008111030825, 35.808890173512125, 37.654945850372314, 44.17505471937118, 50.555362470688365, 48.66897698371641, 52.145314831887525, 50.1835649244247, 48.156181996868504, 38.922844163833126, 39.20540386630643, 37.090505015465524, 39.022452754359094, 36.63805177134853, 36.43137424222885, 34.95133061562815, 37.28417988746397, 35.49663812883439, 34.8782294027267, 36.691866690112704, 35.81330283995598, 38.83159414414437, 47.116479335292695, 48.455690260856386, 52.41102010973039, 51.188017245261904, 51.014420986175544, 50.45926047909645, 49.51047051337458, 50.82756319353658, 51.95078488319151, 52.2450920843309, 50.83218766796974, 42.00205772153793, 24.06013438778539, 5.87583750486374, 0.5186792162637557, 0.11438562985389464, 0.4252857438498928, 0.12451227033330549, 0.6699514280884498, 0.0683983983171563, 0.16610339824711123, 0.1410708777726658, 0.07888362923216435, 0.6788349836584061, 1.0216843961708009, 3.129838118630071, 18.65436500118625, 29.429470839038974, 26.869802667248635, 31.449566002815004, 30.226447428426436, 8.407188615491314, 0.44911472487353515, 0.03452471374804455, 0.05550933288290136, 0.021326491616726406, 0.009200246741754875, 0.029782363281194723, 0.024787590673734105, 0.01648957717172321, 0.01984324771910906, 0.036017585455650286, 0.027892585250458894, 0.06608736385861713, 0.05109617231233467, 0.10171812853866047, 0.02699312716422062, 0.03315306779357695, 0.018305561783152725, 0.018364404996616707, 0.03806484435054083, 0.06671969283131823, 0.04591245369444932, 0.010946269331109381, 0.06350704949469337, 0.06729461117497376, 0.04095078949185629, 0.024741301726129268, 0.016292568085895433, 0.039604592978233294, 0.08057054718055072, 0.020006407210002505, 0.014288532829302696, 0.058765156765378294, 0.040376778962391044, 0.05122262661555602, 0.02317903011346296, 0.045125884409513206, 0.0644011507111211, 0.06904044894561653, 0.0840162497855002, 0.06799501472062643, 0.039931494186842637, 0.03570736964203177, 0.044112993599546534, 0.0045992993475538835, 0.04929262513835584, 0.043621808666014866, 0.1306850237831954, 0.06191853554018083, 0.038930818648828615, 0.022386299566395824, 0.1035449801072959, 1.4618575572967532, 19.175936291294715, 42.38393183677427, 45.061412319060295, 36.72582264869444, 35.22104847815729, 23.66992915830305, 4.28906471498551, 0.5655360342033449, 0.06875587026438407, 0.2944365474245241, 1.032602803841714, 0.9552019377869945, 0.4883023591772203, 0.3773033895319508, 0.42484030968719916, 2.282005548477173, 13.171708333876825, 29.289353970558416, 48.74678111845448, 56.97861625302223, 54.0889512338946, 55.431696214983546, 52.8235593149739, 57.28585550861975, 57.136173940473995, 54.41926971558602, 52.99839896540488, 44.337283949698175, 43.19572125711749, 45.793491332761704, 49.351218362008375, 54.3795439504808, 55.00041200268654, 52.91653517753848, 53.20884981463033, 55.653906329985595, 53.12908449480611, 51.48769417116719, 43.22262087175923, 41.61048358486545, 40.61020466589159, 42.692179141506074, 40.33987883598574, 41.46526959634597, 39.074577131579005, 40.845131104992284, 40.86902226171186, 40.66070125948998, 44.1534306926112, 49.963598405161214, 46.19024692043182, 45.909922968956735, 52.01183657492361, 53.189100680812714, 52.2138504059084, 50.8729136374689, 51.58382754172049, 51.733607169120546, 47.143182831425825, 54.0548187686551, 53.098639057528594, 44.165405688747285, 54.46761685032999, 51.61731673825172, 51.16855444446687, 48.37217123277726, 45.618898791651574, 42.2504771140314, 40.72664022445679, 38.628964501042525, 39.91468606456634, 36.44727160853725, 38.90222426383726, 45.16098168588454, 51.50331697156353, 53.1016279035999, 53.404140703139774, 52.114167290349165, 49.7088247729886, 41.74329503890007, 39.566583556513635, 39.523617913646085, 40.10200669688564, 38.08489253444057, 38.50528824713923, 37.025523108820764, 36.212274566773445, 37.16333558482509, 37.00385201361872, 37.89465758108324, 38.13119219195458, 40.32578575995661, 49.378349396490286, 50.667754065605905, 53.168202292534616, 52.92668234917426, 51.209515756176366, 50.60592182220952, 51.07962254554995, 52.237019846516276, 52.1615416772904, 53.85320109705771, 53.58653483852264, 43.65287350070092, 27.010870710495983, 8.490175181819547, 1.3888425139650222, 1.1943479891746276, 1.4368882390760607, 1.2641401925394613, 0.43362130140585287, 0.356368841903825, 0.09236702950851572, 0.06003715383309511, 0.06544801752052962, 0.6091651705003555, 1.982723433644541, 4.096023550918026, 19.24526026172023, 36.21903673295052, 34.40153983331496, 37.44111784042851, 35.35100444670647, 11.205868374916816, 1.040246400140947, 0.05357299585856738, 0.033225723572315714, 0.014489129121835916, 0.052742924270851, 0.08019771517044114, 0.021514853485108867, 0.041477903949036714, 0.03721319206599747, 0.021856310364279537, 0.021632518844618913, 0.09257228744606819, 0.04233782998316231, 0.11310231000665696, 0.018962570278334524, 0.04038720924948012, 0.02682807352093439, 0.06183943313155925, 0.06390498237564199, 0.03437475203686664, 0.04862955305725337, 0.16758697347775584, 0.04576491282111214, 0.1836943857732319, 0.12426082495479815, 0.16659070677574606, 0.15342969928056965, 0.10825953115859341, 0.16082623222422215, 0.13043325664775987, 0.08230961273394286, 0.2035050824164383, 0.08680590533561285, 0.22191745409321403, 0.13502390063818426, 0.185854600502118, 0.16823205015351697, 0.11999010694243255, 0.21846192258019603, 0.11264841057240002, 0.08855697548677845, 0.09576909574529818, 0.14645469855637322, 0.10478413498569882, 0.19789115946379401, 0.08694011627906754, 0.21165133964630867, 0.19482357487563165, 0.14911503080398808, 0.08242974298134928, 0.2308864897537616, 1.2575672807232028, 21.65716882674925, 47.604057404302786, 53.23634562953826, 48.29479855875815, 46.52641365605016, 26.450617005748136, 7.094139898976973, 1.7181918025016787, 0.1717362895367607, 0.8996118400846759, 4.340132013443978, 7.595057948943108, 1.4209314243447397, 1.3619827358953416, 1.227539943591241, 4.004737984749579, 14.537380549215502, 31.97483804918105, 50.578614281069854, 56.90163189365018, 53.9603445606847, 54.048699871186294, 55.02621335368003, 60.093115452797186, 59.38914022138042, 56.257410049438484, 55.168344359244074, 45.350993064142045, 46.41513209189139, 47.1927890469951, 51.13274320479363, 56.165932532279726, 56.91413248738935, 53.55255534571987, 55.04492305940198, 58.92460999950286, 55.09509409627607, 54.29586018285444, 46.56985390570856, 42.52852609080654, 43.316534180794996, 45.747780030773534, 43.450353683963904, 43.60684056435862, 41.06784328337639, 42.56851073234312, 42.19603853840982, 42.717490196228034, 45.74869786539386, 51.111425122907086, 47.282830976670795, 46.17544781777167, 52.907839282866455, 55.53661177235266, 54.191756556111, 52.567593282268895, 51.57017377115066, 51.50962022043044, 47.69514660681448, 55.14550047536051, 55.52861013720113, 46.685108830851895, 56.16587369672714, 53.752537388955396, 54.17191720777943, 50.65299418664748, 47.3791330091415, 45.51662298940843, 43.058344164202296, 41.02193194050943, 42.18948425785188, 39.059036700956284, 40.72253742525655, 47.36791895281884, 53.92319971515287, 52.45773553848267, 55.62699494823333, 54.54050233287197, 51.691998666332616, 42.73304631633144, 42.05258569409771, 40.65725349610852, 42.14167448782152, 41.45049402790685, 40.473412006132065, 38.88698977808799, 39.72007374609671, 38.45693719002509, 39.43735714881651, 39.6436502856593, 38.510959994408395, 41.54628222988498, 50.88628499738632, 52.046741747087054, 55.929998044044744, 52.239302665956565, 52.39121214036019, 51.67198673371346, 51.0864866933515, 52.16506004333497, 53.47885008781187, 54.7634223968752, 53.001262295630674, 45.68328449803014, 28.36840694950473, 10.08166511212626, 1.0116060498741366, 0.4798641458394066, 1.7353712935601513, 2.066037395308095, 1.3230896164332668, 0.4733832565046126, 0.2741058609418331, 0.3684169228278822, 0.24454349321463417, 2.0510432773059417, 4.724630194325601, 7.158594737129827, 23.89474961065477, 42.7731054829013, 38.81221371312296, 42.20055710884833, 41.462621996479655, 12.372710743258077, 1.176164371352042, 0.23978909026951561, 0.18094857343502585, 0.10064985723264756, 0.18005601971620516, 0.1672526986728753, 0.21864916979064866, 0.0953075124491607, 0.1662294963194478, 0.11169981752191821, 0.13344752151639233, 0.2367991869968753, 0.10977183468639852, 0.23135702095685468, 0.06825128645305673, 0.12470909364281163, 0.1825825470469652, 0.2903525939872188, 0.15091403507657591, 0.1995193414510258, 0.11200771591956578, 0.16570749932960158, 0.1519526511190399], [0.11779840599985854, 0.06646489198770254, 0.07391529623419046, 0.0203710095205855, 0.05369547416546172, 0.037321329206949284, 0.034393593969364325, 0.04127928416334814, 0.052417459477099686, 0.0559683153105359, 0.055139500107015335, 0.05905510955339959, 0.03992732666853455, 0.036355426399818355, 0.020337939420114123, 0.04102313500498572, 0.011683085993413004, 0.07093014270668069, 0.032736714328489, 0.04361613961537519, 0.035080962528985356, 0.04175827297712526, 0.02824088329479339, 0.0345507454157116, 0.04759622302146689, 0.03543585659034791, 0.02451564286715321, 0.062059786831659663, 0.1176201756442747, 7.3489169632234885, 22.549576682429162, 42.234524834540586, 32.00850963592529, 25.85683684195242, 23.592105411714126, 16.613659743339785, 1.731126676163366, 0.19285048478313033, 0.04618705791090766, 0.1929462304519069, 0.2962853627339486, 0.35421539939218954, 0.24469033694796025, 0.689359683423273, 0.0500586019798873, 1.6732668131589892, 11.494618558114576, 28.598204889605125, 47.56917968873055, 56.52968529731997, 51.96136743791642, 56.032540567459606, 55.85416686150336, 53.173391588272594, 51.01253824849283, 45.74936859069332, 42.498935730226584, 41.30798647480626, 43.76291951825542, 49.6146761217425, 51.220635675614886, 54.647296705553615, 54.57326196855115, 51.506568616436375, 54.11621955133254, 53.08224355020831, 50.16037979433614, 49.89965592661212, 46.054352483441754, 44.495598654593195, 42.54972257921773, 43.36626198983962, 40.55988850132112, 39.69584918791248, 37.29648436269453, 38.76470204322569, 38.215566296731275, 43.65438361321726, 46.537329612239716, 49.69115449536232, 39.69838696141397, 49.56922761855587, 50.84407637196203, 50.723518402345725, 52.587844479468565, 55.01802344476023, 51.760922555000555, 53.62375420908774, 43.75468646326373, 36.59199530078519, 42.25648618513539, 53.054692822117964, 51.477064548000214, 50.95756623052782, 48.57427920064619, 49.024606520129794, 46.47815281344999, 42.59551625097952, 38.329719035856186, 36.63302721515779, 35.926678949786776, 39.580845294460175, 44.576038622087054, 48.34186307845577, 49.38566461686165, 51.21523064951743, 47.03212091999669, 42.71903168770575, 39.737234115600586, 38.45976521891933, 41.44723061592349, 42.469612090818345, 44.5810474887971, 45.662554771669456, 45.289662884127715, 44.05887019249701, 40.0552285102106, 36.207438284350985, 35.48731857730497, 38.19081614094396, 39.07782877645185, 45.006110822000814, 47.43329701885101, 49.75111184581634, 52.031675923255186, 51.5129267784857, 51.0663963133289, 52.377009237966234, 48.17598212149836, 47.11963684328141, 51.621952979795395, 43.05880700388263, 27.110510679983324, 9.523387301352717, 0.3698790475966469, 1.0719973738155057, 3.111253438457366, 1.5385890463667533, 0.9419790150657777, 0.057969988143492135, 0.09645502022918194, 0.048966030364916216, 0.12030855437079746, 0.07011479532886898, 0.38796638348890894, 0.5096509313631443, 5.984902439578887, 20.578926917045347, 26.901416970837502, 28.895946125830378, 30.797842625648748, 19.663683022222212, 4.039570347916696, 0.1120064671962492, 0.06845374816968557, 0.044952422951258, 0.03379431402971668, 0.030360956931666985, 0.06752353356850725, 0.01639195841797177, 0.014409924248954462, 0.02246164814418843, 0.023925862417766647, 0.11650623783709542, 0.013629567937084265, 0.07470374626498069, 0.04358303312572741, 0.013516888852351376, 0.03807607902995041, 0.032325470669856, 0.05851041337835693, 0.046359301289363254, 0.03391824024278791, 0.05520936732570972, 0.06385723977620084, 0.07031846746441818, 0.17453802629343926, 0.016418597210318814, 0.07643813102115547, 0.04719301179471997, 0.037986182442475716, 0.05990419161295699, 0.031695001375591086, 0.09916441274746772, 0.04479222247497209, 0.02796700494664331, 0.058973804641995704, 0.07312079410879843, 0.015021800589297089, 0.047372709208678816, 0.020312949632024093, 0.016653671289884275, 0.02922331636411048, 0.055713863036925756, 0.04552434589112959, 0.043098900031538746, 0.04468037363802714, 0.04051253357301316, 0.049553780681303436, 0.024519523102489692, 0.017820189541746533, 0.07598188735785023, 0.005279121462315802, 0.014593357299154085, 0.317354557975646, 10.652084619768205, 31.82360714481723, 48.06852879062776, 39.790947052740286, 34.25068547648768, 24.97645497322083, 15.55786555813205, 1.8005098498636678, 0.43382063748375066, 0.03862847055819246, 0.11068130362658732, 0.1568262879886935, 0.09724719344728416, 0.14705114397070101, 0.3182797470400411, 0.46040946557637186, 3.2450025841113064, 14.137857729388823, 32.98647419098885, 50.99146335355697, 56.866648274083296, 53.34321844962336, 58.13351500418879, 59.11510382929156, 54.92932296568348, 53.22144062288346, 47.45616443695561, 44.14895919061477, 43.240267615164484, 44.65991066348168, 50.43331792277675, 54.12595487410023, 55.40769130952897, 54.70057425960418, 51.995735245366255, 55.000510061940844, 54.30268510695427, 51.56740850017917, 49.46225673921647, 47.40080802671371, 45.20291574539677, 44.17507040885187, 43.65697629990117, 42.28198159125544, 42.60624001103063, 38.43663107964301, 41.43850334229008, 39.959605047779704, 44.01353543804538, 48.61419716188985, 51.463206814181426, 41.577468995125066, 50.454157475502264, 52.516849579349646, 52.62805661847515, 53.739060125043316, 57.16838052195888, 53.29967621834048, 53.78721114127867, 44.777067938158595, 40.646270859626036, 44.44610226538874, 53.36984742072321, 53.2921217333886, 51.75372892810453, 49.36924557532034, 50.03279293737104, 48.25167209871354, 43.89040831596621, 39.57176108514109, 38.18302239141157, 38.458831694818315, 40.30666812773674, 45.746156169522195, 51.11681053715368, 50.59480582514117, 53.581796615354484, 48.880804584872344, 45.794165980431345, 40.75338686666181, 41.081704939565356, 41.529945558117284, 43.9366412931873, 45.143633042612386, 46.805160814715975, 45.691564621463904, 45.52683684133714, 41.08795719762003, 37.666724727999785, 37.56955192935082, 39.29150381395894, 40.025712674663914, 46.220519773421756, 49.29613651767854, 52.12045092736521, 52.88870203879572, 51.11617903555594, 51.18029017602244, 52.592888647510165, 49.82339328335178, 49.59829238153274, 51.35508275801136, 47.46914748222598, 29.294894318426813, 11.37994610494183, 1.7867826574271726, 2.703825816992791, 4.379521435306919, 2.48257496664601, 1.2306720787479033, 0.6431418440995679, 0.1698917949632291, 0.07128376123164931, 0.0763310012858241, 0.03407194812391554, 1.0562144916865135, 0.4045711247430694, 6.623503037037389, 22.948124793268022, 33.1452517355642, 35.91507265644689, 37.47111220513621, 26.5122688201166, 5.777143807180467, 0.22788748535658085, 0.06516626570373774, 0.0306974821198251, 0.054957569546757214, 0.010769785655992887, 0.09152893698023212, 0.06159230848894485, 0.04715288410924616, 0.01035051052308371, 0.020634990012753877, 0.008449064015651183, 0.04623639397323132, 0.021877770402258443, 0.03482345356455734, 0.027673834589340036, 0.0697063478911596, 0.04252378250502291, 0.03016370652814306, 0.030032642290837346, 0.06579576781199825, 0.003414243204338897, 0.05594573486896773, 0.08795217205319675, 0.2878218684946337, 0.13012057020058557, 0.16115140590456226, 0.14804984683231, 0.1470425484641906, 0.1605376622249042, 0.13737880895214696, 0.18651723591310365, 0.08382314966330606, 0.13145209230001897, 0.1805072914688818, 0.16891970599610961, 0.11900841123274258, 0.14745675688309057, 0.07489260992095356, 0.11630623526270352, 0.1270928987932782, 0.24300780868338, 0.11807295659016218, 0.14244661846708867, 0.09242627874857957, 0.12075696861551655, 0.16546228990679787, 0.17910162738013655, 0.15309398423039144, 0.15616163010558776, 0.09717962449236263, 0.1527009504817186, 0.6287894013427919, 10.45249383295736, 37.43732490847188, 59.638375466869725, 46.73427966333205, 38.28164254465411, 32.72025312146833, 18.21850338289815, 2.553082267122884, 1.504108593348534, 0.3351202288702611, 0.5634758092703358, 1.1293081049957583, 1.2125531800331608, 1.120929186863284, 1.6465145325468433, 0.7664597527154031, 3.2851666740832792, 14.643681683847982, 33.37608714257517, 51.476778214977635, 56.097118469976614, 55.640684020134714, 59.43014467916181, 61.857762336730964, 56.81055838061918, 56.78168581378076, 49.83507802409511, 45.74693279881632, 44.79458524334816, 46.79012244747531, 53.94816952366983, 56.028779014464355, 58.28597753278671, 56.500189073624156, 53.160286949526885, 57.24667887533865, 57.216653131669574, 52.42095155100669, 53.51575959113337, 50.441480375105336, 47.83114302542902, 45.72142170321557, 48.310193861684496, 44.74492019222629, 44.28395932720554, 41.7043851267907, 44.111492710728804, 41.65374340549592, 46.418007189227694, 50.2635734311996, 53.38869048703102, 43.166617270438906, 53.106550478166156, 54.47852888414937, 53.656054927456765, 55.059396605337824, 58.088325377433534, 54.72553230101063, 54.88143867061984, 47.97368195749099, 45.19141927842171, 46.921208058634114, 54.690050540431855, 56.94567226594495, 54.725202821916156, 52.85256916476835, 54.169697146261896, 49.76565991678546, 46.14426889727193, 40.53614247229792, 40.90404510498047, 39.43396429861746, 42.47391885326755, 49.286573779198434, 52.323217853423095, 52.00598047625635, 54.85785345877371, 50.81368584786692, 47.36151764469762, 44.40979680707378, 42.46266557324318, 44.52798566510601, 46.345055026392785, 49.071757331971206, 49.85619214273269, 49.738991721983886, 48.02948551793253, 44.68686519130584, 41.530992830953295, 38.86236121577602, 41.95576198639409, 42.201298436810895, 48.19164806796659, 51.74822584275277, 53.45675929900139, 52.75769879741054, 50.526658565767356, 51.40625399927939, 52.186691914835286, 51.38504182138751, 51.23703510530534, 51.82947381850212, 47.40219262338454, 30.119751114999097, 12.251581088189157, 1.2947398279943776, 2.8104552049790663, 7.097248377338533, 3.369509399898591, 2.003824927153126, 1.0602718159075708, 0.24759699710674826, 0.34693639965788015, 0.213886339878363, 0.2766877611077601, 1.380481614220527, 1.1690969957459358, 8.227176339395585, 29.321931216024584, 38.86196505638861, 40.81976513708792, 44.200557970231586, 29.390221641909694, 6.159797003192287, 0.2533441733929419, 0.13744794072643404, 0.20029489822205038, 0.15185155815655185, 0.1096965205825625, 0.25375796812436274, 0.22479556981594334, 0.24697943830922728, 0.13363912010625487, 0.11401938619993388, 0.19133180740379518, 0.22265648379200892, 0.15927096648562342, 0.16188706481649032, 0.155777023324082, 0.21184650820589837, 0.1057327586796976, 0.3029066300199878, 0.2050099548913779, 0.16204077269761794, 0.21919448649690998, 0.2184321217599415, 0.2463134474331333], [0.01854963356538886, 0.010705982023219188, 0.017958179213887742, 0.033268291247828354, 0.09075765497982503, 0.044277170072159464, 0.027565561467781666, 0.050714920995937246, 0.012941546287507781, 0.02619529255635796, 0.014415684272535147, 0.036366856431648616, 0.03243261572694586, 0.03230624186295656, 0.07873139223985134, 0.056276378417087186, 0.029530314608447017, 0.04661046321533861, 0.03148492474499489, 0.0402900233354059, 0.021977685504562913, 0.033168642361077576, 0.003953761103818373, 0.08889836724847557, 0.019696273750835852, 0.050663416904787865, 0.04544892453498418, 0.027482827802398996, 0.129082536384944, 1.9630335031017183, 14.12338222226789, 33.74577053131596, 37.22572088241577, 25.988353913830174, 44.074693033772135, 19.53940860686764, 4.950548420029302, 0.8745426852856913, 0.25148075644768053, 0.09092831638671699, 0.05194999262570374, 0.07238613877205119, 0.03701578652966888, 0.11188181703008952, 0.2335076136214118, 0.5041080707263562, 2.6195710993582204, 14.016244642196165, 33.20076111824282, 49.72551445807181, 54.87033836303219, 60.627707050692656, 55.51607031976023, 54.25034107700471, 47.553537276483354, 45.218365961505526, 42.55071493887132, 43.54842470538232, 45.79083981052522, 48.15221255825412, 50.77708228941887, 52.64078470968431, 53.572759474477465, 53.383301150414255, 50.71044122019122, 53.02487496406802, 52.27992665383124, 51.28110685656148, 48.721830921788374, 48.02044837705551, 47.81809329986573, 46.68911357079783, 47.068842149549916, 44.337464378726104, 38.82409849474507, 38.15183954854166, 37.49414436278805, 40.18921667529691, 42.12685577331051, 42.776376739625015, 39.285078971616684, 42.54247796150946, 48.94591985210296, 51.35241554629419, 50.004869584114324, 48.78460453402612, 52.50714171317316, 53.1336619007972, 54.4306916575278, 43.997124241244414, 43.82894477536602, 53.194462560838275, 50.820577452259684, 52.315126003757605, 50.002516162010934, 51.018790506547504, 49.07507173476681, 42.930965192856334, 37.49567016478508, 37.236409341135335, 36.86439998688237, 37.1276302491465, 43.620321750640876, 50.23136292734454, 50.55726089785176, 51.27383478226201, 43.62898234398135, 41.66753053665161, 40.83194017410278, 42.898323228282315, 45.93202552487774, 47.340238786512806, 49.465296576100016, 48.95419997553672, 49.56134757687969, 49.19508449492916, 47.93435235177317, 41.871729127822384, 36.136462996082926, 37.94388724911598, 38.37717579257104, 44.052429660674065, 48.23559430337722, 49.599704434794766, 51.57897556981733, 51.59047988153274, 53.01592019296462, 52.15190833614719, 46.87220981044155, 49.68469827405868, 48.35959219163465, 30.14003565234523, 12.590672931363507, 2.229967708549192, 0.6664634604127176, 3.514641508940728, 4.371592364003582, 2.593398839235306, 1.0425275035442845, 0.4372566643982165, 0.4969602865317176, 0.08912671507606584, 0.048107425832460006, 0.1801427255474752, 0.2753732768037627, 2.440266320782323, 12.138295192872326, 25.199751584760605, 21.290027133880123, 30.84665652244322, 24.65395377528283, 8.533414410006616, 1.168257976251264, 0.03755138541061071, 0.019734331083694295, 0.1158208036494832, 0.014937967587743076, 0.017255718722158385, 0.08641546096412406, 0.06764747893377658, 0.034751165508022236, 0.06255935276708295, 0.058727277547962246, 0.034991835859874566, 0.014396122217388644, 0.028076662772124814, 0.07473543932240817, 0.03123502494887479, 0.04112978593536443, 0.03538660862813554, 0.043337321915333314, 0.02181685492095928, 0.0619760534215358, 0.026470408136505755, 0.036453462671488523, 0.0066175029215012355, 0.09799530128798178, 0.071725947181544, 0.036402429724412586, 0.15646945955532213, 0.08036163500359944, 0.05714129551403946, 0.02073199206572627, 0.05320541155073912, 0.05734976719043428, 0.012321413434561224, 0.002820857593061162, 0.04732914178842499, 0.062664168916883, 0.05410154673060583, 0.07164208353647301, 0.07750757444169253, 0.05903989504722338, 0.045991069637238986, 0.10727748304845826, 0.017756437619907722, 0.011625653339339601, 0.03167531291593707, 0.08988745570663484, 0.05078499505837118, 0.022311391489159678, 0.051368459112822056, 0.03672669942100202, 0.02518958382068142, 0.22200668801463422, 3.8450676106637527, 19.06786322593689, 40.96037818539528, 41.457381709929436, 30.369894389183294, 40.60226186629265, 21.757436375464163, 6.8664002226245024, 1.0111750181644195, 0.05271120440034617, 0.2427714705587395, 0.034698014327835654, 0.07955171918917088, 0.09931674167033165, 0.1196926809667099, 0.16164436816207825, 1.2179145697624454, 3.7643248852222198, 17.473792376056796, 37.16423772996472, 51.61394349990353, 57.97909521287488, 60.60406300329394, 57.22200716695478, 56.32835003637499, 50.73661519635109, 46.57260348719936, 44.45809295100551, 45.0103352146764, 46.978506042111306, 49.232499984002885, 52.00753373484458, 53.38991818889495, 55.94937847506616, 52.96931066820699, 51.57949332268008, 55.753157984825876, 54.7574721613238, 53.087279873509566, 50.838871386743364, 50.80019289447416, 50.488423301327614, 48.190086964638006, 48.29019761854603, 45.93266094884565, 39.928210396920484, 40.31323025303502, 39.00617099577381, 41.044450267668694, 44.77581277970345, 46.900290058505156, 42.18130219367243, 45.75681324928038, 50.43226672757057, 52.88326171136672, 53.129229622502486, 52.21014376609556, 53.1936506302126, 54.318139245433194, 54.672344961474025, 45.31557406148603, 46.40031337738038, 54.11787871391543, 52.16823324080437, 54.334287643432624, 51.471977233886726, 52.985361006952104, 52.2470336575662, 45.04316937538886, 39.32654234670824, 37.54803772895567, 38.808424703536495, 38.535102182819, 44.85773540312245, 51.19597573434153, 51.33439225535239, 52.517532071759625, 46.59176426549112, 43.21333662156136, 42.62676969651253, 44.43093053756222, 46.02409924230268, 49.56807444172521, 51.43873906904652, 51.72353452251804, 53.515210459309245, 50.748852991288715, 48.94447641987955, 43.3104976530998, 38.14996857796946, 40.668236132591005, 38.71549198704381, 46.5275276091791, 50.32508796261203, 51.09659464128556, 52.718828109002885, 51.658980154222064, 52.37138063676896, 51.174677264305856, 48.68312889529813, 49.705071064733694, 49.01932308750768, 32.76179102159316, 15.191250443458559, 2.856422196472845, 3.6164865859093207, 6.492089417672927, 8.059189559951905, 2.2335843789962033, 0.7353946422376941, 0.4531728151825167, 0.5856353008458691, 0.09232523941224621, 0.11271317564551869, 0.17688666800818137, 0.1601658491117339, 2.195378532332759, 12.296292185783388, 30.301962860168953, 28.965309319957612, 36.01310053179341, 30.714094138914543, 13.54243213130582, 1.7538637980338068, 0.018628305049553033, 0.007212666574970729, 0.06286289978532061, 0.00963735448632149, 0.015908242841701836, 0.09245222614657495, 0.07625776328026287, 0.07514207879261625, 0.09543489754921007, 0.07303015058559757, 0.016999002658731995, 0.036716196355560136, 0.05969017729043, 0.014691117779171516, 0.03735546991529484, 0.0742176941205417, 0.006959542506299312, 0.009570559280203476, 0.06463650824321855, 0.03476772832894518, 0.025396427560237148, 0.0575705498997723, 0.009507267011119234, 0.17080118729462548, 0.11934276264641555, 0.08731138546981158, 0.21916522193820248, 0.1985600308304833, 0.1205782019983857, 0.1654918762224336, 0.16695692744706908, 0.13618919697980728, 0.06225781289920692, 0.10981234541583447, 0.153617789187739, 0.15006764581607235, 0.08763721032488732, 0.2494773445951362, 0.23340783833015352, 0.08522433979857354, 0.11027554515749217, 0.25595353015007516, 0.13253694940959254, 0.08784999124585621, 0.14254109242991095, 0.09424887852923525, 0.15550054219220916, 0.20832495523556588, 0.19292528560805708, 0.24971267148371667, 0.09361919255987292, 0.33337768527769274, 3.1630208799915933, 21.282049032949633, 47.456854774105935, 52.601035410358065, 35.69385882346861, 49.76537358376288, 24.94087907575792, 8.569796354539934, 2.0016290127269687, 0.5555425704486909, 0.5426970532824916, 0.09610766064255469, 0.4432391675729906, 0.6134390218123313, 0.368452224159433, 0.9085462026057706, 1.815359207891649, 4.048191227259175, 17.326568172824, 35.49242158089915, 53.79355361384731, 56.83032712628765, 62.143746268364694, 59.36633948356875, 58.38652749215403, 53.186264807178134, 47.82504766218124, 47.724811492427705, 46.60129170263968, 48.50980327975366, 51.50188138408046, 54.90469048100134, 56.893606724277625, 57.03297638124036, 53.81000403435, 51.68524434489589, 57.552266813093624, 57.259050030862134, 54.579318108097205, 52.853122218962646, 52.4587945784292, 51.65867420934862, 50.233834020553104, 49.93602022047966, 48.52576732635499, 42.933801066490915, 43.06479646313576, 41.02000997912499, 43.357130712078465, 44.86842778421218, 48.32601670295962, 42.965944890053045, 46.887867912169426, 51.34491205215455, 55.48934328940607, 54.185492530945815, 53.5426042925927, 55.22693672487813, 56.737343418982725, 55.6178754375827, 48.55797783021004, 48.25967765623524, 54.211133064762244, 53.396562683966856, 54.24017821588824, 54.47830530904955, 55.08135403356245, 52.36315150414744, 46.77926924920852, 41.559767338537405, 40.155339164118615, 40.84549588541831, 39.613306830006266, 48.244215673015965, 53.40792971272623, 54.07178301965037, 57.06606549601401, 47.59417303146855, 44.918465460500414, 44.13756078289401, 46.52885337029734, 49.9757420632147, 50.805758737748675, 54.26814079284669, 52.49997162049817, 55.30746298451578, 53.16322480478595, 51.651264852093114, 45.90346282528293, 40.556915344730506, 42.62502424178585, 41.404343420459384, 47.99045401234781, 52.06008957278345, 54.42978166764783, 53.172234489071755, 50.537413704779844, 53.316675770667295, 53.40324248037031, 49.20565920491373, 49.644599883787095, 51.73226179615144, 33.6811847840586, 16.209013327475517, 3.144423697263964, 3.0581840151740662, 8.187551085026033, 10.446477897705572, 11.278962723670467, 1.6697700201503693, 2.1478786295460117, 0.9679444314491366, 0.18020937519688762, 0.19652085799363353, 0.2615395062152417, 0.5070793274189196, 3.4691106359804835, 16.119051806388363, 32.71193965788811, 34.53985829507151, 42.54356445804719, 35.918088959109404, 14.373040103143262, 2.155971214655907, 0.10003029128476497, 0.14644561275359125, 0.30294033788865615, 0.17220231614285902, 0.10165516377216387, 0.15513655849762503, 0.20467921941270753, 0.22162525283713497, 0.16022456209025077, 0.14516957074163422, 0.13780795608557042, 0.21812631478232725, 0.15191500555844079, 0.06726849523763503, 0.11200390080170286, 0.14906780914433543, 0.22885857840939877, 0.08498469983497936, 0.13747487637785175, 0.15525868823451383, 0.10354782229349499, 0.13749724614524073, 0.1056827714426383], [0.0382168936513124, 0.022686303427983678, 0.055303431431492495, 0.043298645966476014, 0.0490956754243422, 0.10072410647426883, 0.034829222206627174, 0.0646905480853973, 0.027942440337351257, 0.038099594098786195, 0.014862243626867572, 0.05564118810598889, 0.061875619294662634, 0.005665808651340945, 0.020277719163606246, 0.017559782849744927, 0.021601270118187514, 0.02589127630926669, 0.037469785555355975, 0.02180838390373655, 0.04286092247874026, 0.05939133788248705, 0.03792233667486618, 0.021034361223780343, 0.04626062916471593, 0.053315743533593994, 0.017283391733203205, 0.03586543273300894, 0.07185418263918932, 0.23988313522310029, 6.754504317237485, 26.690856295247233, 39.95428631382604, 33.14177651559153, 44.44294083502985, 23.707668242915986, 4.064812270864364, 1.1454129892010843, 0.13353641835912583, 0.05201825489019675, 0.07829263070297819, 0.02551603878307487, 0.1219640933578053, 0.1049897376628172, 0.3009459658736183, 0.6402623340968163, 0.6890346782822764, 2.915778688846096, 18.895773156996697, 37.39395918384675, 54.84526657289075, 58.452446845269975, 56.79721839966313, 54.91426106422178, 52.06899727544477, 51.09501784847629, 46.96411486594908, 44.65810637320242, 42.98752577074113, 45.5649701241524, 46.82656911111648, 52.22319349165886, 51.957370542710834, 53.81655439253777, 52.76295477344144, 51.79456472396851, 53.53452421003773, 50.3299948476976, 52.593943765086514, 52.85636209672498, 50.12041476465041, 51.1948892378038, 50.819149709516964, 47.93738826628655, 47.18826263181625, 41.39529843484202, 39.57485191283688, 38.26111285917221, 37.43455571513022, 38.4871276732414, 37.56982649526289, 38.02424876920639, 40.982688626935406, 45.24999203220491, 50.02268106706681, 48.635381883190526, 51.54425867142216, 50.54632925218152, 53.71945611892208, 48.476886749267585, 38.68121439410795, 50.04030035388086, 48.7222663048775, 52.1018785045993, 52.34106071533696, 51.23745872128395, 46.54387997042748, 42.60993880610312, 35.8334324436803, 37.30152068599578, 34.817526801939934, 36.6708976991715, 41.220392104118105, 46.169160258385446, 49.03598531599968, 47.54930503906743, 42.51539007309945, 40.59435044565509, 43.53853641017791, 45.644566782059215, 46.887389383008404, 49.00611254476732, 50.43910341878092, 51.19825855378182, 49.26943302154542, 50.83671800551876, 48.51439245285527, 46.82308604640346, 39.081084343694876, 38.112003957071614, 37.69886070682157, 41.83680434380808, 47.31821860036543, 49.34136929050569, 52.17272827702185, 50.30384440575877, 49.75411245899816, 49.574479672216604, 50.216740331342145, 47.25718259811402, 31.7190210665426, 15.3805342220491, 3.0913285334264082, 0.1427694172748635, 2.4005013319753834, 4.387848627182746, 5.042656948489528, 1.031756552477037, 1.0824213176965714, 0.14417351854424323, 0.19022277255933132, 0.09373432025313379, 0.15761335140034077, 0.08436477382577236, 0.35066651240471874, 3.150696057465769, 13.42405794128295, 20.98635527395433, 20.928361069771555, 31.0788647590145, 22.076330954028716, 4.00118260133651, 0.07079266822866856, 0.08555178109916949, 0.09359851584679658, 0.018859613806970658, 0.09031345421868948, 0.008874558824895611, 0.06902583198802126, 0.04847072387835191, 0.07295190236501156, 0.040143773320221135, 0.09932164463304705, 0.028854879783466462, 0.061066956033990274, 0.05805309336151808, 0.026535776503864798, 0.03925510749761616, 0.027766682530543017, 0.07791600655764341, 0.07417730596517363, 0.08170450286519143, 0.030954491211882526, 0.049310248991053914, 0.09875449442094374, 0.026992707731082078, 0.02836560049364644, 0.040464392607851375, 0.016608893450710083, 0.013136166136621708, 0.05517465971230019, 0.09106720812738904, 0.03568614517608958, 0.03603819705125305, 0.016380915260543267, 0.07980585353629244, 0.02053980741860165, 0.060696602318315744, 0.08633553501098387, 0.10356860625888072, 0.04479871507013037, 0.016036688015916418, 0.03294022558557411, 0.024335819048686855, 0.029470682324421023, 0.07468201235056886, 0.06137221525873869, 0.06055409464264109, 0.026370514101619204, 0.052972735326376655, 0.023899874800155242, 0.06273471029295076, 0.03649257146002304, 0.019111813782083414, 0.08179108612239361, 0.5608529693657353, 10.105547443512949, 33.67652893066406, 46.526350898127404, 36.641589749243956, 47.50380554506856, 33.31062670676939, 7.965554248902106, 0.4216011060822395, 0.45012779954460364, 0.09348528039070869, 0.07058194042333672, 0.10355591218197539, 0.09417274471132026, 0.11854320434072327, 0.33005323140851917, 0.6539805173393219, 1.4822337800456633, 4.981957779776666, 21.075004762218846, 39.633812981267134, 55.75707251025785, 58.68809107811221, 57.551003809898134, 55.987260726190385, 54.40961676259195, 52.01774366440312, 49.79865097230481, 45.57294038034255, 45.72832899708902, 46.49259105805428, 48.0097677630763, 53.46237613308815, 55.379944462930005, 55.10530402583461, 53.25308630543371, 52.17537979925833, 54.408667549010254, 53.87545270304526, 52.811019497533, 54.662578259744954, 53.15019076870334, 51.271128346843106, 52.31358058990971, 50.326025409083215, 48.49845978521532, 42.51438202396516, 40.087642977314616, 39.99854633885045, 39.20370940239199, 39.94461374898111, 38.961369683665616, 39.82521680093581, 44.7752675702495, 47.34944458930723, 51.72480537045387, 51.2831151100897, 53.242511595449145, 52.6758820779862, 54.454857380159446, 49.371665677716656, 43.04001492838706, 50.871458438134965, 50.82682186557401, 54.26703468445809, 54.6783697220587, 52.28051893172726, 50.33475268271662, 44.58626816349645, 38.22181463241577, 38.070301317399554, 37.47360291019563, 38.758183063999304, 43.63432461215604, 49.26518117227862, 50.69373584562733, 49.657469180322465, 43.74782623783235, 42.41367516979095, 45.144684237818566, 47.08543377537882, 48.209235975819254, 51.57387256622315, 52.239910633333274, 51.881637419423754, 50.339965512675626, 51.91897446109403, 51.73583115300825, 48.15438555132959, 40.04717196187666, 38.73371924123457, 39.33862324683897, 44.771455026442005, 50.1482008349511, 50.888893373550914, 53.92956179957236, 50.42621058802451, 50.55801007055467, 50.25008047780683, 51.78501375259892, 48.078664195153024, 33.963214966558645, 18.036993741989136, 3.590473181778385, 1.1860091527623515, 5.400454575015653, 7.906069053757576, 8.286245273005578, 4.298966738485522, 0.9150501665088439, 1.1010325964420073, 0.9787830434018566, 0.17572331752988601, 0.25144562365547307, 0.22718384891988772, 0.36079128362959434, 3.5974272989457656, 15.823961111807055, 27.41916983358322, 25.80438102445295, 38.018439738981186, 25.574181041409894, 5.937568747228192, 0.24763168556795967, 0.07142794663987814, 0.047414932144625534, 0.05641721985152653, 0.02988898548327627, 0.01295885987459652, 0.05507953457474228, 0.04014973348427204, 0.08001419880817975, 0.024498038166653247, 0.07249470875268021, 0.07625200995995153, 0.09217340078565384, 0.013951350720749508, 0.046025382715367505, 0.0875405989767563, 0.018523119262329513, 0.04648223924901217, 0.15331595054557248, 0.10708805248742143, 0.07941350926675143, 0.026032102421947548, 0.024402620000464302, 0.07823026348506251, 0.09159810705891541, 0.1550198986285156, 0.15555179347434353, 0.10119534247825224, 0.1662803032705861, 0.25798902576488836, 0.1273956644018331, 0.1682200991818982, 0.13223000862185033, 0.17543480881760198, 0.08328710262092852, 0.10690786860763066, 0.20443860651744952, 0.21696875592873943, 0.1611212220403456, 0.11690363828693667, 0.136595162292642, 0.13149088699250452, 0.13667946260782982, 0.15356013341055763, 0.13627858411881233, 0.21045794319962302, 0.08249548864701102, 0.1677156302837595, 0.18987562747732287, 0.11763563529858667, 0.18387433982664542, 0.13600633179228153, 0.15039683379713567, 1.0771041772057934, 11.276354347505878, 37.56172680085705, 54.5521713841346, 46.3018814979061, 54.363846625051195, 34.458269073117165, 10.993306309946123, 3.384387685406593, 0.9849573443493537, 0.7443631416366947, 0.31743459884197484, 0.30399950040924933, 0.20498620616572522, 0.5729987111783797, 1.4430010078414794, 3.134700631903064, 1.9720703988305985, 4.205310344696045, 21.990838973752915, 39.265482810235795, 56.73713945573377, 60.35690661399596, 58.52024893606863, 58.91614160230083, 56.666709376919655, 54.71977818396784, 51.66395764197073, 49.06503046712568, 46.508417821699574, 49.023927950089984, 50.6973954169981, 56.00326791886361, 57.289087541641734, 57.07626758083221, 52.749654016187115, 53.03581837684878, 55.7607203145181, 53.84651737828409, 55.98296180848153, 57.846468110238355, 53.91072265563473, 54.55277935151131, 54.72092351605816, 52.75106214707898, 51.79502364127867, 45.75593071599161, 43.312309788119414, 41.43989578370125, 40.27018616276403, 41.262463446586366, 40.106635093688965, 42.663330108888694, 45.88226633687174, 48.59202792567592, 54.38720826179751, 54.59694523965159, 54.83209525385211, 55.534780025482185, 57.33967827212427, 51.70983368350614, 45.57913380284464, 51.269684914619695, 53.65354853291666, 55.258515727135446, 56.094247295010476, 55.00994336220526, 50.131824939481675, 45.3962101474885, 40.449626753407145, 41.44250415986584, 39.254751205444336, 39.851014229559134, 45.069488479245095, 49.79729775459536, 53.24544160596786, 52.45271882703228, 45.9592624633543, 44.63527817879954, 47.813786537416526, 49.69110742692025, 50.57271503633069, 53.468498952927135, 53.86613315151584, 54.3579944487541, 51.67373611081032, 52.991989812543316, 54.03875666279947, 51.61502215170091, 41.97268701368763, 40.95805614225326, 41.37502370342132, 46.82061103082473, 51.95538190103347, 53.4267923908849, 56.282619122535955, 50.365194197623964, 49.59251080789874, 50.131981834288574, 52.51840676030805, 50.009631341503514, 34.34246893851988, 18.047178176141557, 4.569937798284716, 0.9230849579457314, 5.582098066806794, 10.506367587274122, 14.76395332044171, 7.197975823956152, 2.297375601145529, 2.0355466056254605, 1.158276034458991, 0.46367425651800254, 0.6443116910034611, 0.4974679270338628, 0.9290761332358084, 4.431714944301113, 17.97660493081616, 32.85925799800504, 32.2472466576484, 44.34132006860549, 29.930208459977184, 7.568311797034356, 0.3518273807581394, 0.2149206198631756, 0.21295880658491967, 0.1727936747333696, 0.2880152290867221, 0.09843554903542805, 0.22821203084482303, 0.15147824351105, 0.1618221312040283, 0.13252950303496855, 0.1858536658748504, 0.1193873719462464, 0.1757077965885401, 0.11250532833078217, 0.08511001649763315, 0.2714232048921047, 0.08849648518427726, 0.17735050360281623, 0.19950395840550625, 0.14858206343506614, 0.1168800351179896, 0.13925837503085214, 0.12928806245326996, 0.11642901617432795], [0.04493923474764151, 0.047458943895875454, 0.01463716699471397, 0.026462728105064844, 0.028297815118886294, 0.08819676094478177, 0.05464797809479698, 0.01335167624582086, 0.05871329644334413, 0.012820929574269443, 0.058317657995728724, 0.04952711699109885, 0.07747622612383097, 0.07606028113514185, 0.02845876444611819, 0.0926446827549127, 0.044089447887193774, 0.011044526810667688, 0.019096520751894965, 0.06437201638736072, 0.038580896498094645, 0.018890151986852288, 0.07065944553863618, 0.07620818206980344, 0.015720057173541958, 0.07179520152989896, 0.05680740375312106, 0.04667005719496839, 0.06471939129574646, 0.14647803359454678, 1.710348655619929, 10.31891751673914, 35.3612575223369, 35.9566419355331, 37.10224466939127, 17.973861232880626, 6.775549794397047, 3.61120437902789, 0.26944694319559687, 0.052947833638397925, 0.0283849403832949, 0.052444391298077764, 0.102430391125381, 0.10636181645696202, 0.05414393054501665, 0.5549348482201176, 1.030951485999169, 1.05204219298978, 4.966310954863026, 23.206324615786155, 47.242257979608354, 59.35901641845704, 57.20990665497319, 56.00660585588025, 54.88327826223066, 52.8133572301557, 52.24798679351807, 50.24895475756738, 49.935161221411924, 43.75446288816391, 42.08431766879174, 46.777814049874586, 52.63848620076334, 53.3991632153911, 54.53171230131581, 50.92493211069415, 51.61612826008951, 53.66764160894579, 53.234204015424176, 52.92867099085162, 53.825901400658395, 52.375102966062485, 53.63971825568907, 52.31228620775285, 52.15498739673246, 48.725074721920876, 41.72327526154057, 38.43239884222708, 38.71292675695112, 37.90761709213257, 37.924557808906805, 38.346534236784905, 37.45935686172978, 40.88132673694242, 42.78067957970404, 44.92207011868877, 49.5417514154988, 49.96539092832997, 51.74819838616156, 49.42644157717305, 36.86994621830602, 49.089031450210086, 50.15686142829157, 52.798252182622115, 49.80730372090494, 50.24027455237604, 47.23076543500347, 40.11524861858737, 39.66255610988986, 35.4693619666561, 36.37018918991089, 38.69484070808657, 39.24078364526072, 44.601926265224336, 45.62473135609781, 43.07369632105674, 40.14897707969912, 40.692907840974875, 41.452619952540246, 44.63459568638956, 45.428224532834946, 48.23848116782404, 47.922632309698294, 51.21170051636235, 49.295450102898386, 50.42180184395083, 49.22608690877115, 48.27441400097263, 40.6422661196801, 36.85650033335532, 37.89984295445104, 42.75916930167906, 47.09938956845192, 48.39201450347901, 50.947317077267556, 49.70386297472062, 49.27455171462029, 51.064180174181544, 46.65512623325471, 34.64307938852618, 16.50562786286877, 4.48377852478335, 0.5221848958922971, 1.1221490439868744, 7.470208906358288, 7.57756466827085, 7.975855373567152, 1.3650329915746566, 0.41676562039121506, 0.5927252300804662, 1.1392030191998328, 0.13942829333245754, 0.044819265378699194, 0.15733644125923035, 1.5518978935095573, 7.389334536367848, 16.331921777417584, 22.242880675100512, 24.006919591657578, 29.683869884860133, 15.892098565255443, 1.97979231995921, 0.05218977814600353, 0.03363815466723135, 0.0793075516459442, 0.11595588027229232, 0.023936129911171816, 0.01806226566493992, 0.013795559080467831, 0.08831436310203807, 0.010403044044881338, 0.044129043141560215, 0.18371104052470577, 0.04702799645582995, 0.05454438768567578, 0.013168684653787604, 0.04236105776902649, 0.04171698849888579, 0.020900115806369052, 0.04109393685094772, 0.03694919816729042, 0.014897887782764532, 0.05143165753613557, 0.03821437705248114, 0.004938242021918057, 0.09103563764402944, 0.12047246654307651, 0.04981690507021643, 0.02448020938543543, 0.010852032855543639, 0.003268912015858317, 0.014289387974948173, 0.07003899858964067, 0.004684919727996233, 0.07452497964784985, 0.013391503241784392, 0.03057536004381555, 0.052299930098196196, 0.038619082150680405, 0.07723686195188954, 0.03779400162579071, 0.05476451155939891, 0.029810465301477143, 0.04473589586033937, 0.020029004888548967, 0.037524196950177995, 0.03394883396404405, 0.006190702411150861, 0.011743628964458984, 0.028893695543369943, 0.006636848078004175, 0.045079271789760365, 0.08010448993093545, 0.06792585996370162, 0.09507852876859327, 0.2710772089419827, 3.536384922842826, 19.47181244050303, 42.76877126386089, 41.73453638630529, 44.32496378498693, 25.47362912085749, 8.817507759217294, 4.268031985529007, 0.32520870587998824, 0.12154485940212205, 0.07148927197821679, 0.08163986802701989, 0.1128085689138501, 0.11011300428259758, 0.10129592216183102, 0.690534126854712, 0.8993601342362743, 1.8076626595950898, 6.360842008744517, 24.543544938487393, 49.28167866122339, 58.92646920296454, 58.851351891794515, 57.541244952909416, 56.67360098131242, 54.67381192791847, 53.95803036228303, 52.35005863251225, 50.79391710219845, 45.41429619635306, 45.27054132953767, 49.40845358756281, 54.55798825910015, 56.71455444828157, 54.431507510523645, 50.89130955357706, 53.49000923095211, 54.3223754052193, 53.44964804187898, 56.3243099950975, 54.67809515614664, 54.86530596210111, 55.688533013866795, 53.47339799327236, 52.88686636955508, 49.7220157038781, 43.22327198520784, 40.59403273367113, 40.3153169539667, 40.86024399726622, 39.78027820587158, 39.045806546365064, 39.256928120889974, 42.82585743934878, 44.74312766905754, 47.83364549759896, 51.217164378012384, 54.28495207140523, 53.48654970046013, 51.607334306163175, 39.238744012771114, 49.919667859231275, 50.63031896468132, 54.18153093707178, 50.902174518954375, 53.42201886638519, 49.28503621009089, 41.055883976721, 40.082175193294404, 37.63009763533069, 36.73022747039795, 40.41223087618428, 41.546933343333585, 46.0742663568066, 46.21536577901533, 45.42275674881474, 42.552205439536806, 42.38363765901135, 42.702287089440134, 47.520020623360914, 46.051085149088216, 49.30813112566548, 50.04190068091116, 51.873274926216375, 50.73082970034692, 52.385497247019124, 51.479378746401885, 50.24157285690308, 42.07428032352079, 38.65390293059811, 39.37214382233159, 44.15084585066765, 47.577636318822066, 50.735214910199566, 51.55773201296407, 51.03635488017913, 49.274755677869244, 51.51890054825814, 47.64889401774253, 36.26288098673667, 18.002253309372936, 6.098348171480241, 1.2137078277526365, 3.4887344991007163, 7.662643328789742, 9.739156884531821, 7.08324404493455, 3.7458100722682093, 1.0583355133571932, 0.9446375853111668, 2.47942358736069, 0.462588801859848, 0.11869090609252454, 0.10703905350378445, 1.9099958265020003, 7.1507578415255395, 21.112483009215325, 27.806805910602694, 28.960535795457904, 34.247378918432425, 19.58582397430174, 3.1910766132416266, 0.07286001777937336, 0.018212842161677057, 0.02417776553380874, 0.15277913741527066, 0.0288907173765643, 0.01647004767531349, 0.05429678806854833, 0.02877250426418839, 0.06136937307253961, 0.048245708533232255, 0.061535426460567026, 0.037873356843427304, 0.023570537431946686, 0.049750964052133986, 0.02419191326255039, 0.05129746574487898, 0.07618081740914814, 0.05553078334478121, 0.033320189874258735, 0.035693537924558885, 0.040011665288118586, 0.055758901345994205, 0.008638919755485992, 0.0261747709760863, 0.27440181602874114, 0.1419722568243742, 0.06563770089058146, 0.21185698828870253, 0.14481850328945345, 0.2626696084776233, 0.26134032335492874, 0.14273647549411944, 0.15824025647053797, 0.08980418194926555, 0.1134844040197711, 0.21199850005007562, 0.1244583300825569, 0.15794076205741975, 0.11527315037505281, 0.23914831900788894, 0.17969413510253354, 0.23193532540913553, 0.0763561672741367, 0.15304875439934193, 0.13546608658807893, 0.09560599562621887, 0.1937807606713426, 0.150632313903301, 0.08652932461230986, 0.1426175786482711, 0.14267364096256996, 0.23313137252003918, 0.17800295004440894, 0.36885913942129384, 4.019942807574426, 21.353636210964574, 49.20413732528687, 47.438831483164144, 47.77629260093936, 32.89156067755915, 17.342781289931267, 5.098891969650023, 0.536673641012561, 0.59233152217442, 0.24662355982488204, 0.3434449079776964, 0.39923446433198073, 0.38586843638650836, 0.40509758036463495, 2.2113751836361426, 3.116508924191998, 2.0969218928967757, 6.460541304080717, 26.107435111076605, 49.36195388917, 60.66576973084481, 60.211531808299405, 60.07934008875201, 58.42182490133471, 56.86301615930373, 56.529912794789965, 53.25719302700412, 55.33349183297927, 48.379796320392245, 46.75322863363451, 52.2722819543654, 56.446723245805316, 58.654617571061664, 56.25374263332736, 51.250363319150864, 54.10476623042938, 54.9387994120198, 55.143452998130556, 57.151094636609486, 56.63631493045438, 55.303175833917436, 56.727859127906065, 56.49063025751422, 55.661358833312995, 53.06172170946675, 46.82714962190198, 41.77523097684307, 41.26213004512172, 42.92104551869054, 41.17331973968014, 42.04297588717553, 40.42124056047009, 44.733070711935724, 46.625131868547015, 49.36590371593353, 53.339319613672075, 56.75249161258821, 54.41079347364364, 53.427533718847464, 43.77194489202192, 52.07297848116968, 54.00948401420347, 56.42495016897879, 52.54942486363073, 54.41331163529427, 49.50142945012739, 43.3023508902519, 43.74128372438493, 38.94051836382958, 39.34802124577184, 42.37471426686933, 43.13028043316257, 47.441734037091656, 49.76761325713127, 47.07940509242397, 43.25202295857091, 43.37383216427219, 44.17878489340506, 49.81090053435295, 48.363341977519376, 51.76154228948778, 50.68740906253938, 53.025361337969386, 52.6265190493676, 53.6999148707236, 52.887627309368504, 53.02647136872815, 44.03715595122307, 41.40385704655802, 41.168259882157855, 46.76743545839864, 50.859656026286466, 52.785202457058816, 53.53104506769488, 50.49539727549399, 49.37175196986045, 52.357860226784986, 47.08988566552439, 37.028033425731046, 19.19482054248933, 6.21699006326737, 1.329692681470225, 4.971076144326118, 11.949828247870169, 15.485065387141322, 18.230415621111472, 6.9321210057504725, 1.1503729488580459, 1.016780146427693, 4.168132649314019, 1.5902092764454505, 0.29524924413811776, 0.35990780039179715, 2.4365322243782783, 9.521562418630047, 24.279245830351307, 34.11358687185472, 37.4398156135313, 41.72309875488281, 21.875199656332693, 3.0680887353035713, 0.1798678378784849, 0.11699062757073872, 0.16067420973652796, 0.22409781693450867, 0.12979141286303922, 0.06820894477348174, 0.09295193763870387, 0.18155434980027138, 0.12249087073629904, 0.17370469117116544, 0.26382048704451133, 0.12471627188666214, 0.10684932416845715, 0.14121019852257546, 0.09069817591338389, 0.07069779590012566, 0.2188545273196313, 0.2718883121926939, 0.09435885045076571, 0.10280715316654214, 0.11769585747031436, 0.10932847662197967, 0.11470225399299977, 0.12910896641833167], [0.029034230542639573, 0.03720362745826283, 0.1402819297847248, 0.04043025956038506, 0.028295853933800134, 0.02061309521987794, 0.12261687687808469, 0.004656857927329838, 0.0864074323626776, 0.04703086162466676, 0.026646447480626168, 0.01961924552526926, 0.040335383401402546, 0.032745405595989964, 0.038250291254371405, 0.0673032986120351, 0.016488642544455586, 0.016320133844630855, 0.036063068095714815, 0.016436766900662935, 0.03343036863952875, 0.024049926526664246, 0.055360052989976066, 0.062363774350453774, 0.044695890748933445, 0.034013901641892816, 0.0061288183074324366, 0.028934587401548223, 0.009750439597654247, 0.06629691188854557, 0.5742128073207794, 6.537789933143124, 27.766864415138002, 39.00506488738522, 34.473727133966264, 26.983447459436235, 10.675656103318738, 5.753083498247209, 1.9176699437441367, 0.1005315962397764, 0.020838801959349264, 0.06218776948028996, 0.24415458101899395, 0.12730250044936134, 0.1006640758245222, 0.19589153208559562, 0.6139446398423565, 1.8059149985351872, 0.4522216097722131, 8.559365791659202, 31.308354793056367, 49.07892350227603, 60.236419247042754, 58.28466746114916, 57.400796644149295, 56.408735090686434, 56.38594611998528, 53.66086375328803, 54.31536612972137, 51.368042269060695, 44.68218580369027, 41.71240245142291, 49.211550604912546, 55.63412973957678, 56.025982364531494, 52.74388813203382, 52.755353220047496, 51.67270060508482, 51.38566547824491, 52.853463465167636, 51.529134012037716, 53.152869747531035, 51.361197733110004, 52.29564359111171, 52.33421225701609, 51.42887038569297, 47.21743329878777, 42.29871834478071, 39.854826773366625, 38.7222384637402, 39.315610701038, 37.79415469015799, 37.359230518341064, 39.04759906953381, 39.60019042415004, 40.9168202646317, 47.70227355341758, 50.086145016454886, 52.009942070130386, 49.445865154266365, 36.446036061932965, 48.45305835047076, 52.29381184424124, 52.13901158302061, 49.6174531598245, 48.366566165801025, 43.773917844218595, 38.71508406054589, 37.77184032624768, 36.49834479055097, 39.724003961009366, 36.38587082585981, 35.927075109174176, 40.1353076196486, 42.65142571541571, 40.27528132161787, 37.6947618299915, 37.57813015291768, 38.50187970745949, 39.09303972798009, 42.182039599264826, 45.805666369776574, 48.16938469486852, 47.819819142741544, 51.45840975546068, 49.67243302252985, 48.248957818554295, 49.04220619509297, 45.204425857913115, 39.068607284176736, 38.00941044284452, 43.878143064437374, 48.4857395387465, 49.59589581335745, 50.58951062540854, 52.542219469624186, 49.54378320324806, 49.636821823735396, 35.86374059800179, 18.509370665396414, 4.307787168410517, 1.065007342446235, 1.2181477056395624, 2.3998453155640633, 5.2676798932013975, 7.603875927386746, 3.0064685450446222, 2.971158633309026, 0.8984402158567983, 1.3512067592913106, 1.5189232629153038, 0.20177703320739732, 0.29979242132075373, 0.23228104556760482, 2.1064500654897382, 6.306470603712144, 15.272384670472915, 22.507626933436242, 26.046271631794593, 26.331629945385842, 8.049920508938452, 0.17721761799147054, 0.051284365641373786, 0.05870055640116335, 0.04870922620137853, 0.08159888232307089, 0.015274549274885607, 0.0719566239164241, 0.014912296939010342, 0.07234378177071772, 0.085439441965953, 0.03788336961259765, 0.06135945989479942, 0.07285311532717559, 0.00874506315261486, 0.09298426654910849, 0.0380293476665693, 0.02310249601460753, 0.00704336928338894, 0.059025285750507354, 0.01351387046592971, 0.04950350999171215, 0.010277826973657695, 0.06671937873526927, 0.01455584005828226, 0.09886998983640825, 0.0207285963810019, 0.05130177881989268, 0.1032668365646274, 0.04326521388946041, 0.03175989859887669, 0.018959678296420365, 0.05506735760718585, 0.1149531784317186, 0.030085192092003363, 0.05118233805161811, 0.019946962617517962, 0.08878294078092422, 0.0581141084342474, 0.021629109753355868, 0.03416883526369929, 0.003896078274157199, 0.039892117267534624, 0.08113642568669974, 0.03572217046072887, 0.0722718154711108, 0.043105250900431026, 0.027244639575421333, 0.060818080880468896, 0.04189575511601664, 0.06464213898946201, 0.04776271307961114, 0.03585555402922534, 0.0012820838122523481, 0.04764230321011236, 0.09765453771838258, 1.2355268698546196, 8.765411819181136, 33.88758774726622, 41.83426264793643, 40.13871615932834, 32.65570855909778, 16.10554120232982, 8.467184209054517, 2.1726336882960413, 0.05614018713634822, 0.036915203015650475, 0.09233313777874555, 0.06498526977074724, 0.17953209218478974, 0.1401903516342563, 0.3683940934077386, 0.7877216343918155, 1.2684487935996827, 0.9387144999157999, 11.861398412335305, 33.55467265652072, 53.28392790209863, 61.467074655717425, 58.00111539902226, 56.79364904280632, 58.21828526835288, 56.40676213848976, 53.798852735950106, 55.502781329616425, 53.06708751186248, 46.190537175824566, 43.450373295814764, 52.0395794991524, 55.76047320519724, 56.715950812062914, 52.51736340984222, 53.3219592032894, 52.82289643441477, 52.501305226356756, 54.09581145932598, 54.87210342960974, 53.82938054300124, 54.19796959046395, 55.37620644415579, 53.35911189356158, 53.864854458839666, 50.188016814570275, 43.45780226492113, 40.515036198400686, 40.705639854554214, 40.544634403720984, 38.83481441005584, 39.55006253334784, 40.81352464614376, 42.31890286168745, 42.41160023596979, 48.82730737809212, 52.30643795382593, 53.18021651237242, 51.579552158232666, 40.58745099652199, 48.8614006196299, 54.357982681643584, 53.46714965758785, 50.83346243827574, 50.11521370180192, 45.47620296478272, 40.16568245426301, 38.40657787938272, 37.51504275106615, 41.452976888225926, 38.04347230542091, 39.000534549836196, 41.409921030844416, 43.645977973937995, 43.05723021107335, 39.797383662193056, 40.493286655795195, 40.12908281818513, 41.62073273812571, 44.3926638941611, 47.37112352924962, 49.84898282635597, 50.48566979746665, 51.75367793729229, 51.27363081901304, 50.17186057183051, 51.037508057009795, 45.29877847240817, 40.062563342432824, 40.32048663785381, 44.349102051027366, 49.656453286447835, 51.1777171011894, 52.147738856654016, 52.17152018700877, 49.58573687461115, 51.58558868592786, 38.924271906575854, 21.23863623988244, 5.849857686027404, 3.061807549768879, 2.1917731386999932, 6.368321478366853, 8.118770853165659, 7.950263869377875, 7.166181581635629, 7.139721762749457, 1.2669532673974193, 1.464685341042857, 2.7206552365133843, 0.6853058525631506, 0.15689898973270772, 0.3361493301007056, 3.805316595300552, 10.669106725723514, 20.317765705047115, 28.447736886239824, 31.039209596572388, 32.469492073981996, 10.560902260964918, 0.6599549612691326, 0.06426922270968076, 0.05389227449233013, 0.04443916319418819, 0.006938228982635924, 0.0341294621748309, 0.026483153924345974, 0.05321447054044374, 0.05954607232143322, 0.03967261392503016, 0.06378931842083413, 0.04512942373572339, 0.030980720147190076, 0.06923555621817228, 0.01690360939040059, 0.03588976751592371, 0.011482888066600408, 0.05936012363001224, 0.026873709378583778, 0.04823365030930408, 0.0499643731652008, 0.041209773175538554, 0.03906976018521575, 0.028116219722095038, 0.1139943887509646, 0.1078966276479825, 0.14626504582983835, 0.22335299561100624, 0.13247244480636813, 0.18245310883127874, 0.0935205587396218, 0.14507079136467751, 0.1911153415999105, 0.1236171578808177, 0.07462126923905266, 0.0985643130937411, 0.175124435955959, 0.15609720211115577, 0.1431727319234802, 0.13486642360446915, 0.17984508506713376, 0.13814410014498618, 0.25336292722532827, 0.13897170492958638, 0.23673825236337803, 0.2147738680604004, 0.0916098282041569, 0.1201249001127097, 0.20767946487232564, 0.17781142806333883, 0.1694205589592457, 0.12177866177573321, 0.14441563297183285, 0.18234060115871892, 0.15449119070845266, 1.2209822309594, 10.915873819781888, 39.47097186119326, 51.66747993038547, 47.01507429922781, 39.81821144780805, 21.07820933864963, 10.401751110630652, 3.375824170727884, 0.1988713383193939, 0.21944717293785465, 0.2960214607657925, 0.3786305908954913, 0.4034771205436799, 0.6190204319934691, 0.6680990887745735, 2.27452828518806, 4.985680599366465, 1.0629284862549075, 10.520155699022355, 35.22639859107233, 52.4534523102545, 64.50278520584106, 61.17026890477827, 59.52714881589336, 61.45253835185882, 60.61853262685961, 56.97473702892181, 59.23018617014731, 56.0382789950217, 48.58961174564977, 45.32823939477244, 53.235063014491914, 58.9431510433074, 58.920342460755386, 53.62513096101823, 53.524820266231416, 53.17898096576814, 52.96487054517193, 55.500322003518384, 54.53978453913043, 55.7783749026637, 54.77822149953535, 56.097522474104366, 55.67436149043422, 54.62270736694337, 51.70431490867369, 46.92254950923305, 43.943101436861106, 42.54553741024387, 43.82389276258407, 41.1654200861531, 41.772367646617276, 42.341228992708274, 44.41387214968282, 44.39758254635719, 52.67146548917217, 55.268823715948294, 55.675695096292806, 54.314479674062426, 44.749846689162716, 49.86392705671249, 55.38046613816292, 56.02875155787314, 53.689104818528705, 51.10600048495878, 48.79632849847117, 42.23330497741699, 39.846876129027336, 38.843239661185976, 42.649299790782315, 38.73752394030171, 39.99719704351118, 42.795184504601266, 47.496466790476155, 44.10652306772048, 40.97553030137093, 40.49307092543572, 41.737819410139515, 43.45933198928834, 46.18942714506581, 51.285801933657744, 51.416624746014996, 53.253686428070075, 53.829859072162265, 51.65320250295824, 51.848881706114746, 54.46176859640307, 49.32915895215927, 41.58042253986482, 41.51447573015767, 46.70657596280498, 52.01441357212683, 52.79064278448782, 52.959006601764315, 52.814243685814645, 50.26315373759116, 52.86162591749623, 37.44129434708626, 21.36490910283981, 5.940894426838045, 2.082391472593431, 2.892476623096774, 8.810488677793934, 10.770063630996212, 16.063226672910876, 12.313471186545588, 10.872506133971676, 1.7208943155504044, 4.44843404716061, 5.757369177956735, 0.8598375356485768, 0.8485648889214763, 0.8371521400347833, 4.566679779560336, 10.310619742639604, 25.09529886707183, 34.96995795157648, 38.23479767768614, 36.20468085811984, 11.396182756270132, 0.6919819717445682, 0.2744310193004147, 0.178015667103952, 0.17234712208230651, 0.10941467683521972, 0.05272277998888204, 0.24231953997044797, 0.13855938108698015, 0.2143502520817903, 0.19969567956943668, 0.21709638617692456, 0.16887994603283946, 0.17582197433277486, 0.14048822194097504, 0.2226032560030299, 0.1122057190044753, 0.0963174001944642, 0.12316727274728399, 0.18607759337511756, 0.07522565898515525, 0.13755632684596125, 0.09826697904856936, 0.17102024247569425, 0.14317547451824914, 0.2640788118925787], [0.09811297239315125, 0.013570213359930824, 0.0016689161988793903, 0.13640239924913453, 0.02286952867683384, 0.04029231010785988, 0.050504392373465726, 0.08615516727009127, 0.051902564122311534, 0.1116083772672761, 0.023920239332402428, 0.05502347226044344, 0.03743105598034398, 0.06882442747272792, 0.027468266386178233, 0.036877373593949506, 0.05519074755871008, 0.029155425652260744, 0.02877383342673702, 0.0529757307301606, 0.036495271919956135, 0.029613069341247602, 0.02441541749923941, 0.02171633460919463, 0.021345810438956947, 0.060434316795679836, 0.02838354610327271, 0.10113554165488291, 0.01211524002193924, 0.008836246767802345, 0.13088218417138825, 4.5595474396982505, 19.22479529534617, 38.31473950416812, 45.1234132243741, 27.37738286295245, 23.85842650167404, 13.5824393264709, 3.2926885543331026, 0.3054105424352231, 0.12499331226271969, 0.021883368589765122, 0.024601944587043217, 0.11341279778148859, 0.03137953977491106, 0.2516025644276412, 0.6875767823188537, 0.26691885304547125, 0.1661270703639715, 2.2697714307615837, 15.639594024227513, 35.82531313742361, 50.85567089819139, 57.07349838749055, 54.799618028825336, 55.96719388038882, 56.06353513656124, 56.47525456643874, 55.71111017657865, 54.565856533665816, 51.14896612782633, 42.86024485864947, 45.530363052122055, 52.58106270144063, 54.18000905744491, 54.26921159990373, 57.04486900760282, 54.44717737936205, 52.09287274268366, 49.822075366973884, 51.493307082883774, 49.334689494102236, 50.63390401101882, 51.35896198211178, 55.103076119576734, 53.58631518579299, 50.460680377098825, 49.274128098641675, 44.28380635476882, 39.34515007080571, 38.83872501311764, 38.58836012501871, 38.94718247075235, 37.32219549917406, 38.8840126991272, 40.270900034135394, 47.409233277843846, 51.25563106229229, 52.40940801558956, 50.0880983568007, 37.3407639995698, 55.471888742139264, 51.97716282260034, 50.80904960632325, 49.975110561616965, 47.70472503477528, 42.39390642412248, 39.67628832786314, 35.57899221297234, 40.61065966083158, 38.943719017890196, 36.31420520044143, 35.92621611010644, 38.103017807006836, 38.275115720687374, 38.415885663801625, 38.150937403402025, 38.38407131933397, 38.56554762009652, 37.809616673377256, 39.36071403564946, 43.241675746056345, 45.405313968658454, 50.22560096556141, 50.17926600671584, 50.251237577007664, 50.256976004569765, 49.253661171082534, 45.70339056753343, 41.65667341601464, 39.94807720184326, 45.86343503767445, 47.34809921633813, 50.24826834278722, 51.298373130060014, 51.49888861563898, 47.48499778009231, 38.01309354843632, 21.663128868226085, 7.8699361797302005, 0.9445213850948119, 1.9126906173844493, 1.8454642569826496, 4.577715858336418, 8.098267153386148, 7.477826149232927, 6.682901449741856, 4.724310030860286, 1.2992305741194756, 0.6441476256135972, 2.1555706426020596, 0.3657709777114853, 0.028857813900216456, 1.760578773194744, 9.425263327936973, 14.192709134471032, 16.919520285821733, 23.528543403071744, 32.34069320463365, 16.75729693905, 2.668281053343127, 0.1234630975992449, 0.022827617921716264, 0.028078325182920503, 0.02874778069165205, 0.04992213490749559, 0.07267891459407345, 0.04640800532914939, 0.04838756503417127, 0.02105385241579385, 0.05980839614846534, 0.07109070707473063, 0.04336539903775819, 0.012058992888928663, 0.020958403606087934, 0.03685454034336633, 0.09126910293895392, 0.06108923004038873, 0.04127694376473946, 0.07464653481879542, 0.10656413261688526, 0.03908399409884888, 0.03005997822319548, 0.05646564809965992, 0.04215057128139081, 0.05462363565100297, 0.09026725911685536, 0.022922833074605273, 0.06328119145285699, 0.08293014395261004, 0.021484064411432035, 0.02404883868181177, 0.04486761701804015, 0.07543693071291332, 0.05210676102808887, 0.06142612869640993, 0.0695933805658452, 0.07598559522340376, 0.01445300424576647, 0.03348414801181324, 0.01898531925924603, 0.012806140246891208, 0.018110766691426118, 0.022688879398629073, 0.05795837042012042, 0.03285773706832721, 0.019159506585809494, 0.03807960686484172, 0.040802367617406195, 0.04757292628768952, 0.05174181206272014, 0.07525129228710167, 0.06142388788923141, 0.021223192321016424, 0.02039015214259346, 0.07287582217325127, 0.2711497727901705, 7.3609385375053655, 25.03889322280884, 44.68996386374197, 47.10506131572109, 32.95554237980997, 27.01842127307769, 18.425314272603682, 3.85035986861875, 0.35595104819343937, 0.043313910268367305, 0.04833409209705649, 0.09371702964868277, 0.05665081921183775, 0.0046443898463621736, 0.21202220281045284, 0.15077566427569236, 0.9935915229781982, 0.8615489147843853, 2.123507227628462, 17.65825556170556, 36.28230848620015, 53.72080541426136, 59.76137315073321, 55.728447052740286, 58.1132520398786, 57.94706906041792, 56.463911071900405, 56.70977700141169, 55.42428685772804, 53.001419190437566, 44.52684817775604, 47.1873212629749, 54.41781451625209, 56.001667591833304, 57.53192147900982, 55.75218523702314, 55.81454700039279, 52.5044156659034, 50.37085810015279, 51.34322543298045, 51.757302207331506, 49.920377808232466, 53.0979291085274, 56.328577533844985, 54.60506846827846, 53.62301288112518, 49.81040239334107, 45.49996860565678, 40.966606909228915, 39.96456292367751, 41.53886110551896, 41.19521440998201, 39.142685167251095, 40.65244859264743, 41.81447429041709, 50.22566372348417, 54.511319898789935, 55.07478798589399, 51.0528798257151, 40.572192976551676, 53.701730928113385, 54.21027014332434, 52.24073825343963, 50.1475340320218, 49.591090909896366, 43.94552153925742, 42.04104608105075, 37.85661843515212, 41.99692726135254, 39.93414886536137, 37.366267250430205, 38.29169950177593, 39.005908196972264, 39.76842480321085, 40.17477058595227, 38.913697196591286, 39.51297260099842, 39.390657409544914, 39.3663465592169, 41.51760970392535, 45.36747878597629, 46.95661921654978, 52.24566082800589, 51.059614535300966, 50.71901159901773, 51.86558315830847, 50.92567736102689, 47.47432108848326, 42.995288141312145, 41.115135300544004, 47.61175309458087, 49.705196580579205, 50.24539716782109, 52.14943724293863, 51.23083383806291, 49.56364608580067, 40.19483350938366, 23.910199826763524, 9.49877933148415, 2.2715347813021753, 3.1487799796365925, 2.562691338600651, 4.1689082980155945, 8.774042994745317, 10.2294639425893, 8.994131107484142, 7.7777011548319175, 2.854771123778436, 2.892924999037097, 0.17902295015031294, 0.2670295987158053, 0.08321623948793258, 1.6293671558941565, 8.10743373247885, 12.386974442389704, 20.644738404981553, 27.133485963267667, 34.278632363965436, 21.25598096078442, 4.336319959932759, 0.10047790879804282, 0.048804795669932524, 0.040897695768264034, 0.053988705809798934, 0.04252245334247428, 0.06984336271641717, 0.03752801589848053, 0.044917542968065514, 0.08207826950256863, 0.023198381494430285, 0.03546962957648981, 0.018937251072437055, 0.014105780639745777, 0.019707590784697283, 0.0036937714509305457, 0.03405941875591394, 0.037363808782350634, 0.030177314164898092, 0.038706891148561434, 0.10425546537003211, 0.07514849094854248, 0.03653066135161827, 0.04759399753604685, 0.026227027748621283, 0.06485254503786564, 0.19111134262094576, 0.1533082590228127, 0.2811939515654118, 0.17870735256902634, 0.20495550136172003, 0.0761361008570079, 0.08787111995080787, 0.2164988529177443, 0.10885155624559811, 0.1728392569648643, 0.14083912085381248, 0.19114929461671462, 0.08824896217594225, 0.1388366742720527, 0.11436793322284376, 0.1839247024467876, 0.13424929381618578, 0.10885537902434027, 0.10395168086453792, 0.18741910526108357, 0.18063862958262045, 0.22400712744603235, 0.14178614342404952, 0.1641555584125942, 0.11345988154531488, 0.1341428995252617, 0.09700224449437472, 0.2836384462012399, 0.10489488065603281, 0.1282597119889913, 0.40181425009523675, 7.777806078234027, 28.177562067585608, 51.644824320270175, 57.14466979426723, 39.046265463675226, 34.27338815504505, 20.17750959242544, 5.058237093110239, 0.8139583684744374, 0.1213003930846049, 0.17609100909002368, 0.18415023873169578, 0.2987004702370013, 0.31510569155216217, 0.6020322177679308, 1.6995995227367648, 1.697775620606638, 1.1112877558315954, 3.334856975463129, 18.224432045413604, 39.44653549501973, 53.68056974103374, 62.97517107379053, 56.53852631968837, 60.413165169377486, 59.1729627117034, 60.317388734509876, 59.14592973647579, 57.99304316120764, 55.31737481394122, 48.598456690388346, 49.541696502316384, 57.68214825660952, 57.531854798716886, 59.16496892129222, 58.32325181653423, 57.22668263220019, 53.720197446884654, 50.32539390748548, 51.92862349171793, 50.75012383922454, 50.30143999284314, 53.787642601997625, 58.90823410403345, 58.616146964411584, 55.5918897351911, 53.82394413794241, 48.68769453417871, 43.33665593977898, 42.96342280603225, 43.42699204721759, 43.23944783979847, 41.396020150953724, 42.88843885544808, 44.06305536147087, 51.544666597920084, 57.723560640888834, 56.81862669606363, 54.09176749567832, 43.206146917035504, 54.83530375265307, 56.125551731355735, 54.08914343003304, 53.77724439867082, 51.775043087620894, 45.67090549776631, 43.055924061805975, 40.132675709262976, 44.24374718819895, 41.78485647324593, 38.984617571676935, 40.34804128831433, 41.473906655465406, 40.6571436697437, 42.37636558471188, 41.19512419546805, 41.05501321054275, 42.65430081275202, 40.426665198418405, 42.7180471727925, 46.01960812845538, 47.43755671285814, 54.87764966103339, 52.27188187260782, 50.57466053193616, 54.604507569343816, 52.56102723460044, 49.96216674004832, 44.74679900753883, 43.375099089837846, 50.52992197775072, 53.11554447297127, 52.86004520231678, 52.91220488086824, 51.23822358346755, 48.22849481336532, 39.54802682322841, 23.902525709521388, 10.049385966793185, 1.9162882888509383, 3.9952348172664647, 4.506328230903995, 9.480555019071026, 13.710143854541164, 17.67920101842573, 15.130534114376193, 12.015677978915553, 2.4286095269264716, 4.5122250241618005, 6.804311063981826, 1.0035960796859957, 0.2688130820470472, 2.479526794725849, 10.50976828221352, 19.460494441370813, 25.992882290194114, 35.27040366203555, 43.163887300798976, 24.031095120214648, 4.297339445160282, 0.19935844766516841, 0.12676211734933238, 0.07580040112858819, 0.1695396090226789, 0.15910225860293836, 0.1555175493441282, 0.1762981899082661, 0.12362128709472957, 0.1291643086099817, 0.11597808916121723, 0.1678287048613833, 0.08385116549869699, 0.07859996985644102, 0.17293661141828184, 0.11328929674721534, 0.18175399231333889, 0.1908919656829488, 0.08767088755003868, 0.22528638702727136, 0.23793794605280125, 0.08847557864482365, 0.13403808337546166, 0.2416625889318605, 0.14049925360708468, 0.2539072173737711], [0.09601248187884208, 0.0492518462781464, 0.07460897352786795, 0.015485739605801721, 0.0481516482578891, 0.04359116131860403, 0.030408303080607327, 0.011895432159484876, 0.07754970161664872, 0.06246897737465559, 0.05068012911285605, 0.022825461384209416, 0.05600710234214222, 0.02600673533555481, 0.01977477861087649, 0.06027510840325587, 0.05611391798142464, 0.0387861697574056, 0.06601922033775239, 0.049072746412768486, 0.051766947407515786, 0.04790117964148522, 0.026042885109481793, 0.05904628422051188, 0.030160552161114833, 0.018150084238920002, 0.04860226500539049, 0.05467447707609785, 0.03769596535412054, 0.07912447195379965, 0.0874157649494948, 1.0390640506821296, 8.475698694106072, 29.663410802041334, 38.83587345000237, 32.998876725473714, 20.522703662995372, 18.893419734893307, 11.250697143616216, 1.6561541249675136, 0.0709654363773523, 0.03180109114656526, 0.010641623934310292, 0.07207369747301264, 0.08050841744989157, 0.045833393420663573, 0.1428259698854339, 0.6060231068441945, 0.5900137691247849, 0.5337613424466503, 2.4187173093518903, 15.052509346315938, 34.219424186214326, 45.20685772741995, 54.84651780897572, 55.93333990343156, 56.59914262833134, 56.05216026306153, 56.28108939816875, 57.277999001164595, 52.676470433512044, 45.46370629341372, 42.227523403783, 46.81573944707071, 54.07306563469672, 54.12198543548585, 55.22272409931306, 54.802916742140255, 53.7064613065412, 53.880591007971, 51.36327658930133, 50.02355967798541, 50.4658696728368, 50.904316133068455, 52.25760836755076, 54.40012070440478, 51.45576215559437, 53.531841308839866, 51.29876928944742, 49.62629810456307, 44.20077370059106, 37.633816042254054, 39.94099340131206, 38.199676775163226, 38.096079134172015, 42.991777620007916, 50.45873095912319, 50.696206938835886, 52.84096287142847, 50.71569719622212, 37.541981589409616, 52.11531654480965, 52.525678834607525, 51.498990597263465, 49.18148955991192, 48.54910150651009, 43.14524819774013, 42.420974700681626, 38.25183645371468, 36.28459522801061, 35.16200896232359, 37.656903113088305, 36.09157931420111, 38.73940667798443, 38.97225033852362, 36.24322598980319, 37.36114463498516, 37.3455963596221, 38.56241756869901, 40.392093427719615, 40.90846561616467, 43.14023933103008, 47.74350550866897, 49.23934844232375, 48.96459817886353, 49.60577626382151, 50.23016660444198, 47.91478756935366, 47.34440042126564, 45.455253585692375, 44.64864169397662, 47.40497750620688, 48.11821345360049, 49.47997016291465, 49.905935641258, 50.2259422117664, 42.11024061326058, 26.985494936666182, 11.974976524229973, 2.360961634305216, 0.8228751416167905, 4.172704171749854, 2.7494584264293795, 3.933065495183391, 10.19201119099894, 3.7763219446905203, 4.692681508679544, 7.718968074167929, 3.644196660287919, 1.6540333484449696, 0.2296161934012367, 0.3304733233826776, 0.22915621888974022, 4.933179674610015, 17.47364724836042, 43.059434583110196, 30.993145281268706, 27.21752666657971, 25.783290440036406, 8.920796513557434, 0.13595102024414848, 0.04125986000402801, 0.005204075968058239, 0.03580848558715755, 0.026228669091999054, 0.037349502090364695, 0.009670082720056658, 0.03956989685614263, 0.08184946202222379, 0.05745396280901567, 0.07410500258688005, 0.036280522153021834, 0.0680008982758849, 0.09093346449756816, 0.048651099280123754, 0.06813322464304586, 0.029161975704013344, 0.017074554249824538, 0.027802156231876825, 0.018734071148379196, 0.013759150751866402, 0.07065474941966034, 0.01796846011383159, 0.03791627691938512, 0.04230697579201191, 0.04092685690510177, 0.03854944858880293, 0.03701295583478866, 0.028803925360402757, 0.015205799586950772, 0.019686638279968215, 0.05909992952740962, 0.05013109688016196, 0.04833729051414037, 0.06264430808744605, 0.08638492469946224, 0.0793683483836151, 0.05137502448633314, 0.02692713443520329, 0.0367235278169955, 0.002023887706943037, 0.04030572047697441, 0.05752984381791565, 0.043214958521627614, 0.0390184591073663, 0.022887711773716637, 0.015070174253665873, 0.037289099887974804, 0.04484546175526996, 0.07326625122298157, 0.03491203248080227, 0.08159579498873604, 0.029540857893504927, 0.07722975265595221, 0.029846036679021297, 0.03562391585400028, 0.15414219169366747, 2.79733830882657, 12.957943081855776, 36.101593125251036, 47.304313798104566, 38.12208052604429, 29.03204256488431, 22.23839936717864, 11.599382123639508, 1.9716405315745262, 0.19260398833261383, 0.07011194548179066, 0.023351993614567385, 0.08582674537695224, 0.07661158864897105, 0.08683805038491565, 0.2396330075158227, 0.37246698453541727, 2.6226212324634677, 1.4881293475627901, 3.5549340565358443, 19.371319355503207, 37.436367850149836, 47.041295343829745, 55.55573724931287, 56.320575898693455, 57.74718507643669, 56.19793122814548, 57.501742762904016, 57.49248204692718, 54.97628942612679, 47.36240410035657, 44.60677039238715, 49.75601480853174, 55.693969418925626, 55.50976314852315, 56.8459616937945, 54.09149685213643, 54.98352619909472, 53.98509079410184, 51.587290994582645, 50.123725245075846, 52.75788314880864, 52.02665921180479, 53.0335630139997, 55.64141750335694, 52.96123843039236, 55.038164815595074, 52.790729076631614, 51.34386085694837, 45.484918471305605, 39.08765039136333, 40.59021234512329, 39.69362128165461, 39.633526648244555, 43.98076403525568, 52.75704376159176, 53.557909381005075, 54.056289657469726, 52.56423181103122, 42.00128893698416, 52.61372820023568, 54.32934153464533, 53.03758344342632, 51.49534279300321, 51.65494795768492, 44.25141149951566, 43.7052724438329, 39.98532402899958, 37.606630094589725, 36.19451015226303, 38.919988678347686, 36.96568342947191, 41.21505375831358, 40.23066828327794, 37.33876751315209, 38.57471812155939, 39.45731809062343, 39.51572218248921, 40.927728376080914, 43.39035710980816, 45.0688648223877, 49.13855529600575, 51.3070180339198, 51.40365739022532, 50.129055746140025, 52.66538973777525, 49.487497191275324, 48.87785104013259, 44.9024151217553, 47.19572690225417, 48.8483077479947, 49.780000102135446, 51.09320963582685, 53.082114111992624, 50.25199067208075, 45.71645990494759, 28.814001929375436, 13.758811643046718, 3.4823957037541176, 2.486216151906598, 3.6951153989761107, 5.84154079037328, 7.260920549592665, 7.634041895789485, 9.703037738800049, 10.332872329219695, 6.9962002769593274, 5.100910519399951, 2.059565484523773, 0.2829763930170767, 0.11202306832156836, 0.3833516230506282, 5.431299113458203, 18.71015679451727, 40.22666354333201, 30.6628954410553, 30.998185526940134, 33.90506975112423, 12.236429952806043, 0.7206555395837754, 0.04998079425985775, 0.01994362055894829, 0.06358214909391058, 0.03316262090999273, 0.03812007162900221, 0.04284504147606992, 0.026459428181331006, 0.022275461965510925, 0.027710650859761144, 0.052942436548971364, 0.0684977982253317, 0.033745728733558814, 0.021025118372973897, 0.026595347500856847, 0.061541578146598996, 0.02349289633604067, 0.07159068669763304, 0.023656592088481112, 0.037713566224180886, 0.04248428301164701, 0.08191847122244297, 0.04246184429634483, 0.027447334948867082, 0.06139525535306143, 0.03642976757199053, 0.18184982991266638, 0.18198875229685538, 0.0944009623039634, 0.09040771367689295, 0.1264284094495158, 0.1320538083992658, 0.24072371753713778, 0.12569520201894546, 0.21263760124002734, 0.18556944725494232, 0.22873880822331677, 0.13910460586269058, 0.20685749849484814, 0.12656615205830143, 0.1216462587997798, 0.1034648702930539, 0.20477551666478958, 0.20170037844969382, 0.19465164942366464, 0.1899128440286844, 0.10445513086573732, 0.11538923567821903, 0.13368335402300283, 0.22760993170161403, 0.13893266508896507, 0.17674489577691402, 0.1502972730104962, 0.1693356917389939, 0.08126512079709962, 0.12600408867001534, 0.24849235470737183, 2.5414862700047034, 13.004554567798493, 41.68774643251973, 53.48196837209887, 44.5470287722926, 29.7507776752595, 28.01870607560681, 15.465167203257161, 2.9808706670038165, 0.3771221944161, 0.1902551780785284, 0.19403663403805227, 0.19087892686647756, 0.20306710995012717, 0.35301132367983945, 0.7435083713742995, 1.4551012746749388, 1.727851497069482, 1.8328751647664656, 3.3220788740342666, 17.341286866895615, 37.527955193673414, 48.312531594307195, 56.8164340911373, 56.13515761590774, 59.017864350349676, 56.826930353718424, 59.42555158369003, 61.21017902128158, 57.53228233706567, 49.816638961915054, 46.91010775104646, 51.60277651202295, 58.151703034677816, 56.406385590953214, 59.39718892497402, 57.298018778524096, 56.55867945763373, 55.52855130164854, 53.25113688745807, 52.85232990018783, 53.26778734883955, 52.76223697969991, 53.93499820463119, 57.99172132245956, 54.571795002106704, 59.270206113015455, 54.957505195371574, 53.98991530941379, 48.77667742390787, 40.16087755080193, 43.23644330424648, 41.90136263447423, 41.187514797333755, 47.10850123436221, 54.69118410541166, 55.53540368233958, 56.695040656674294, 52.47580197549636, 45.48826425306259, 54.246858012291696, 54.40561986738636, 54.574928975874386, 52.562494201044885, 53.458053681158255, 46.535815577353205, 47.09327851572345, 42.029486856152936, 38.02733175216183, 38.91408158886818, 41.24414597788165, 38.463895474710775, 43.342990567607266, 42.67269280649001, 38.98897924730855, 40.80753518689064, 41.508066577296105, 41.82959502743137, 43.376668037906775, 44.756369590759284, 47.50946944759738, 52.427462685492735, 52.94192075729371, 52.34304543464415, 51.14407885459162, 53.774412447406405, 52.804371080090924, 50.957409335720925, 50.21780329365885, 49.23004850264519, 51.3215543377784, 50.5531894776129, 52.788054020174094, 52.24803386196014, 51.706425143826394, 43.60964113666166, 29.019702788322206, 13.734852825441669, 3.5209832460649553, 2.020767727686513, 8.376329368160617, 7.440820057545939, 10.026465596691256, 20.664846435669933, 12.02352369985273, 15.684497317960187, 16.38752235520271, 12.160623285078234, 5.4662572376189695, 0.9285502904845823, 0.6634014989099195, 0.7614755233930004, 6.407655496751109, 23.095554920934863, 47.79550829241353, 37.755440896557225, 38.01985179224322, 36.0496844783906, 13.7006389710211, 0.9122990528422018, 0.12243254846262357, 0.18838043835374618, 0.10745612709152122, 0.17535551871743896, 0.07085130459839298, 0.11918841891231076, 0.15921058343543162, 0.22108399639687232, 0.12231267102423216, 0.14365654709118028, 0.19160003010784427, 0.12747687738268607, 0.12076468312091405, 0.18089578997704292, 0.21017619138283117, 0.10744157142095989, 0.18423907428739533, 0.14191761943361453, 0.17748749544543607, 0.13629698555075354, 0.21525592122587467, 0.11229384975928454, 0.11684199119166983, 0.1642078515743056, 0.14357829887059428], [0.0482729391285008, 0.04460878272150313, 0.044827899189605835, 0.118672588930255, 0.05087636253466049, 0.02864491232039948, 0.08709079811289426, 0.01569619640753034, 0.014007943550935917, 0.0014163798632873825, 0.020724796584897467, 0.024569412663338647, 0.03485817266928573, 0.013994927717102392, 0.04481410577652916, 0.05566271900710079, 0.03225156233736104, 0.026863945587988824, 0.06678646505479852, 0.016430756940896955, 0.03409234138445989, 0.0317856889488476, 0.06930150106669435, 0.0738363202300764, 0.023497358798199607, 0.04054646360717955, 0.1337746257383016, 0.0803764281614173, 0.03921542031269881, 0.03917381407753114, 0.09277684824360956, 0.4127728620604162, 3.8888657766003765, 17.142769828919445, 34.28071906489711, 29.227358948799875, 25.435829239506877, 31.481825536297215, 9.835590316403298, 3.921965923040144, 0.3673128981984431, 0.030433560999470855, 0.09317592642600499, 0.06875377118347153, 0.10009094246573026, 0.08864100767119278, 0.06570740723081174, 0.5980655983571084, 3.454958724398767, 0.8094399818970311, 0.16985126891203467, 2.3346390983750744, 12.794595976029674, 28.267015641735448, 43.987604648836204, 51.6754109628739, 55.715969993222146, 55.91057054458126, 53.88065768826393, 57.7985014454011, 53.794667566976244, 51.57232323000508, 44.4747002663151, 41.92662662075412, 45.6199578315981, 52.058740277444166, 55.45450087516539, 53.727736242355846, 55.01296358723795, 53.87201670677432, 53.26462199611049, 50.71425768636888, 52.958720268741736, 51.79619642996019, 49.98125691567698, 50.987964599363266, 52.85926857302266, 52.15230841790476, 52.00438014922604, 52.92942016355453, 50.717332824583984, 42.54959706337222, 36.77331078437067, 37.3539549304593, 39.8818636709644, 46.540326303051366, 51.36434739635837, 52.126130519374726, 53.56676217048399, 50.5833250476468, 39.294794682533514, 54.130316549731845, 52.28173094411051, 51.64001941680909, 48.14002967649891, 46.7476902469512, 44.31344770616101, 42.751167666527536, 37.67535394237888, 36.82701587677002, 35.11743122531522, 37.52318559154388, 36.00547152180826, 37.99094392407326, 38.224375940138295, 37.04602926008163, 38.42660942385274, 42.31454903079618, 45.4249297418902, 43.94827896548856, 47.695068159411036, 47.760932599344564, 47.82373366817352, 49.16770242875623, 49.704157152483546, 50.99310682665918, 51.036919701483946, 49.48033886571085, 47.03609820335142, 46.906267750647764, 48.1258620754365, 49.03407512172576, 49.94925429744106, 51.67337525275446, 51.176316815037886, 47.56658307967648, 34.51130344021705, 17.33145348487362, 5.456548881146216, 0.724218522589053, 2.688134620266576, 2.6801136184123258, 3.0938111485973483, 4.281162119680836, 4.74999027867471, 11.317038151525683, 7.79447271939247, 3.1391709081588255, 3.44741330992791, 2.0337746749001164, 0.11664920516552464, 0.25422132874448455, 1.6090633744193663, 8.540919865331343, 19.123145111145515, 22.040890378336755, 36.25421647102603, 28.727756854026552, 16.00137089529345, 2.943505188149791, 0.14070041297424224, 0.08988756295894423, 0.0443222964813392, 0.02744037504007499, 0.029154747664447755, 0.002421194789818518, 0.09299760413987022, 0.014990354595225186, 0.043327933507821256, 0.004038806918317512, 0.05190547142598418, 0.016067234814287196, 0.09254136813744422, 0.10690449015988458, 0.08468798632102628, 0.030386931142739715, 0.04404218409270529, 0.02300959636246966, 0.028366958384492227, 0.022403482918537432, 0.041459632752042626, 0.06638215449188026, 0.0646542355177864, 0.04245164766607266, 0.055802104874484004, 0.02493326612297566, 0.06779673584406415, 0.026886259814003305, 0.026722694296509992, 0.08777378848002804, 0.029846802766945575, 0.040351241421435154, 0.04252529169823374, 0.012619692640709541, 0.03747728172569506, 0.06874476965036123, 0.027192832879541863, 0.012117359212659782, 0.03240230928866133, 0.0354330450476658, 0.034285782415780335, 0.11584964685983236, 0.05101230100638444, 0.0561159864188202, 0.011902299180116144, 0.11423930706035708, 0.013413033185286388, 0.018198407149963805, 0.0239628299905528, 0.05552848508100837, 0.04984313592074379, 0.09057072952630059, 0.02354959833375629, 0.04164712894107065, 0.02782301106039555, 0.0211967354745514, 0.08378336671739818, 0.5760128075076688, 6.034985223124105, 24.466874368729133, 40.79938450167256, 36.208956241607666, 25.347397442786928, 34.84923132004277, 14.762635404063811, 5.194002091884613, 0.3925079978521793, 0.0249440296583118, 0.0406903310889198, 0.07644475002082125, 0.029427746926704725, 0.03843465797422874, 0.05286080605019966, 0.20216617522941482, 3.3198485162950333, 2.283813515978475, 1.1128074291252321, 4.085027186139937, 16.75945424264477, 31.128761229976533, 46.5194239924031, 53.12622508695049, 58.86576267980761, 54.772271263983946, 55.95770566694198, 57.541303788461995, 55.213820319021906, 53.45542177077263, 46.00644073178692, 43.31007011475102, 49.05056868830035, 54.18015418514129, 56.59688334311209, 55.963655902493386, 55.14664972982099, 53.90120306322652, 54.612866140181026, 50.43203923010057, 52.073927694751376, 52.10198048622378, 51.00355209842805, 52.93933591535015, 55.232914417020744, 54.19996215451149, 54.609818458557136, 54.80253234986336, 52.12393006970806, 44.25083491110033, 38.78383536492625, 39.49124267024379, 41.29374434871059, 48.41583897990566, 53.6354350274609, 53.286175420207364, 55.08049111212454, 51.96748633538523, 40.38982237538984, 55.49853340271981, 53.29303956800892, 52.8912829583691, 50.470360786684104, 49.58788633346558, 47.47370919873638, 44.06880163377331, 39.11209852464738, 38.47619994994133, 37.907962260707734, 39.043257005753055, 38.61062349811677, 41.1505425360895, 41.14764782690233, 39.665509654629616, 39.94868909159015, 43.437217666256814, 45.64848130749118, 46.09023040340793, 47.6490116888477, 48.495557231287805, 49.26977034538023, 51.041642235171416, 51.70771168124292, 49.79830188135947, 51.50086549020583, 49.950062305696555, 49.78449121598275, 49.22635362994287, 50.39594950214509, 51.55268000018213, 51.25548201222574, 53.525357630945024, 52.12686792496712, 47.833112055255526, 36.6386362045042, 19.034513273546775, 7.202851820376612, 2.1028299629688263, 3.561657979603737, 4.16952165865129, 6.499535056852526, 6.8907728502827315, 8.344866075823385, 7.826143897348835, 8.475444720637414, 7.7726868948628836, 4.155769338530879, 1.3884995517230805, 0.19179945811629298, 0.11452625295327556, 1.3566440223686158, 8.89157779755131, 22.144119316531768, 30.341390525141072, 39.400463334975704, 33.39571468291744, 20.904458145941458, 5.345010401741152, 0.18818438113216432, 0.07390725997186477, 0.12146036756495315, 0.014628989963732181, 0.022638269715131294, 0.010147374649081501, 0.008849823761040406, 0.044458077905038675, 0.028969634008864244, 0.03290667476493024, 0.056114676408469684, 0.058681247155031854, 0.12200494882680717, 0.02146460769337512, 0.02846076585082037, 0.03942050588046832, 0.01672578889185623, 0.05316575500933875, 0.01060369587878907, 0.0499753626964746, 0.047576155348290364, 0.04738159582860047, 0.03026326923000236, 0.09617728271311331, 0.04493496763790327, 0.007363760659861709, 0.16041853555267857, 0.10885147197592644, 0.08028977595630192, 0.22975937523428472, 0.06905774721094678, 0.1251835242334393, 0.17731739328272883, 0.06211095767456198, 0.12277387893728672, 0.1478524566177399, 0.07783184413828197, 0.15820130856046755, 0.10384520230394217, 0.1527187390433204, 0.1286729551371067, 0.2776318265786094, 0.0723344891241962, 0.13174098405626514, 0.102856021915232, 0.1834385430500392, 0.12191359284183673, 0.18327181167419881, 0.18473275666756017, 0.11801519356067143, 0.15860580298448765, 0.19750050058768642, 0.24405780879239886, 0.2427423898611338, 0.09264411584984872, 0.1743057637565559, 0.17071768371087892, 0.7586566875538518, 7.061159139679325, 27.150157997685096, 47.85739152662216, 44.23519642122331, 35.17783964833906, 44.135576063586825, 16.61035906883978, 6.457365164833685, 0.7722780372827285, 0.22858997266138756, 0.35107514370352993, 0.2428483551428203, 0.19086112298311728, 0.34867603211633624, 0.2560322686669327, 2.182817877300324, 7.99151788796148, 1.5404028974233137, 0.7659602633887722, 3.01854282617569, 14.794957695468781, 30.285241796124367, 46.55093631436748, 54.956026461816606, 58.24232939750918, 56.263681919344016, 55.78777290159657, 59.86752033233643, 58.07826057557137, 57.18736871596306, 48.11029811059275, 45.08512696912212, 49.937495031664454, 55.926997430862926, 60.31475682412425, 58.30248286647182, 57.957643770402484, 54.81040062442903, 56.399980360461825, 51.38905048370362, 53.285532151499105, 52.65319508890952, 50.48754076803885, 55.97958464776316, 55.95469720901982, 55.34986380607852, 55.95250068172332, 56.336049649023245, 55.27493084630659, 46.805819772904925, 41.07500945368121, 41.424414188631125, 43.57447708806684, 50.51836667522308, 56.73344458303144, 56.24382295916158, 57.0747103998738, 52.193254040133574, 45.289627582796165, 55.575823706965295, 57.02201727897891, 53.68021280534806, 52.88232426489554, 51.04227765913933, 49.105936865652765, 45.769811984031435, 41.888814972293, 38.688992454159646, 38.95119505543863, 41.27862361169631, 40.30736630962741, 42.03801016653738, 42.5257961211666, 41.48400675865912, 41.44216683603103, 46.45923914447908, 49.14503897390058, 47.84516157642488, 50.80586464174333, 50.95230240975657, 52.421736025041156, 52.936350991649014, 51.61759522653396, 50.011608216070364, 53.4359589699776, 52.262781973808046, 51.002069442502915, 51.10935018908594, 53.00354903744113, 54.14310739886377, 53.53981940977035, 55.089865576836374, 52.54775001156715, 48.80120400459536, 37.09552172691592, 18.926279391011885, 7.235646757387347, 1.9411477807068058, 6.5689281590523265, 6.907193362712861, 8.200003139434322, 11.919902524640484, 13.515998298122039, 18.591167772969893, 16.26641329257719, 12.120617070505697, 9.887703907105232, 4.4577290838764565, 0.43514315038919454, 0.39883907103250105, 2.518472988759318, 11.602258201568358, 26.62297183467496, 33.06160719163957, 46.49988274420462, 40.532012216506466, 23.573205471038822, 5.32348100216158, 0.29987687485352643, 0.27983417614333095, 0.23423677610774196, 0.18179995758879572, 0.2090033567360332, 0.1543738260384529, 0.11457974121214883, 0.11890099804487922, 0.19662981101822471, 0.15695658422285513, 0.15383099145706625, 0.07244715767522013, 0.19140970322393602, 0.16183014448371627, 0.25274860131884774, 0.28134719979378486, 0.14973868766138632, 0.1446116901934147, 0.11063766725842031, 0.12899351696814262, 0.11738671801022946, 0.17733865988350686, 0.1603087551531292, 0.15008632303966632, 0.14244219047888634, 0.1116561275275965], [0.013088771149576192, 0.027143259329961675, 0.03657361207109305, 0.06688522910999675, 0.08152144615568462, 0.024239784181718866, 0.02010030086122213, 0.02231276661698376, 0.07224885581602013, 0.04033105117419074, 0.05623343918893126, 0.012585571084562088, 0.09940684127110629, 0.08587109420688883, 0.03613208495681325, 0.05443554191339401, 0.10872988616146388, 0.01921982834896734, 0.07043798484148518, 0.0705916007920619, 0.056946023532579985, 0.019252840992844394, 0.04643127908028903, 0.04427644994951064, 0.04716152175059242, 0.018330794804158713, 0.05497434304185933, 0.044273956333317106, 0.018824967480595076, 0.05986759942325373, 0.07998159410612238, 0.08289295038388622, 1.17719718044804, 8.059856853177472, 24.967655135739236, 33.3825159072876, 27.705187105363418, 23.367279075807144, 14.17095272771774, 6.962781192794924, 2.1740165689299187, 0.23257188318717867, 0.024427567653718497, 0.14779222678513299, 0.09801961691869844, 0.04382668739004482, 0.118962453618165, 0.32649263859756533, 4.356765314455956, 3.1757590222743253, 0.36194256056220303, 0.8621107330245357, 1.4804297349145337, 9.059886701645391, 21.765216396700954, 38.575196650720414, 49.52283382415772, 52.83502832535775, 57.707427932370095, 58.06825068689162, 54.89152308433287, 53.33633076760077, 48.83510897236486, 44.60973178186725, 42.56738501210367, 43.06357268364199, 45.95746601781538, 49.03374564263129, 51.88139423247307, 53.27044279344621, 53.55286913533365, 56.36032127564954, 52.18286760391728, 50.270719989653564, 50.81752192589545, 48.50808135924801, 51.89545985191099, 53.28398281528104, 54.81885333215037, 52.018041764536214, 52.85755449725736, 48.01461581260928, 40.315932766083755, 38.25634325704267, 40.33071617926321, 48.40368747711182, 52.43205578096452, 51.98825528544765, 53.71116422837781, 51.61994472626717, 38.41233984116585, 53.59318717833489, 53.16671571423931, 50.126957278097834, 49.26554595270465, 47.75330751172958, 44.38353653877012, 41.6898762795233, 39.54910155265562, 35.67465097673478, 37.72201445794875, 36.82018310792985, 36.62284866456063, 36.626672975478634, 38.02520582752843, 36.66256266255533, 39.81818791358702, 44.977191186720326, 46.476521107458304, 49.451838924038796, 48.93092855330437, 47.93276379185338, 51.65427723238545, 50.91174117980465, 51.21503060863864, 49.57883742547805, 48.4690067075914, 48.91807494624969, 48.32988808231969, 47.03752986846432, 47.9056288350013, 50.42380225273871, 53.91357029637983, 51.70052197671706, 49.41913420154203, 42.317000512153875, 24.99865362721105, 11.044698184536351, 3.532058548542761, 1.3569584248527404, 2.5581198161648167, 3.312354582932688, 6.945120721094071, 7.020819523642141, 5.996103257902208, 6.7817863629710295, 6.315645517841463, 6.089638548512613, 2.55220684313005, 0.6767239517742588, 0.1365487373644306, 0.6828978237125182, 6.960569466314008, 14.124226512447482, 25.427100004688388, 31.05146504217579, 29.97606488966173, 25.526018258064028, 13.239746747478364, 0.7988349961176996, 0.06358207248511814, 0.07737183132238927, 0.05223532973398125, 0.03172451874331361, 0.04124354999212008, 0.023915857309475545, 0.04514746510634019, 0.03227621504676438, 0.10787461794191792, 0.05610151884837016, 0.04631611691307157, 0.03262940073205579, 0.06877378906093298, 0.011209424363539345, 0.03950795864746456, 0.03084246234427537, 0.040833060930092493, 0.03704539582794232, 0.030473918511321953, 0.00952029912432115, 0.05201681081445948, 0.047182646625104456, 0.031496812514359915, 0.05512487931898045, 0.03886921751883723, 0.009347521399538363, 0.02819166597609799, 0.04480600822716952, 0.05688364865378507, 0.043826756337958, 0.056749602419234095, 0.02232597971845779, 0.016696487943972313, 0.011194825600532275, 0.004994330191684346, 0.0203220430956853, 0.027804395123835535, 0.04354707295856169, 0.07580979336653987, 0.04199519332858824, 0.025252688398224213, 0.10612647424662307, 0.10239972462577206, 0.027861618061339664, 0.04966893135720203, 0.048495656209847623, 0.04610118328503544, 0.10363102710295109, 0.022480507313664404, 0.06076403720785053, 0.030819799548255342, 0.055830978728350134, 0.051892673927209074, 0.02864586609986521, 0.044651679814823216, 0.07486016609736028, 0.06437103579481764, 0.26618080393921945, 2.8811625463347283, 11.889892470452095, 33.06976179922781, 41.339216386118245, 34.34239441348661, 32.50443254747699, 20.30495720524942, 9.92896528013291, 2.7882151209538986, 0.15261058275017048, 0.05701511317203122, 0.08708168166659533, 0.17708462512781545, 0.06580478466686702, 0.29065326817574044, 0.29890584308774243, 5.145339696638046, 7.645015706939082, 2.5982405149167587, 1.7155855100962425, 3.771135835878311, 12.17309348044857, 25.27453745565107, 40.685333744172134, 49.67778313544489, 54.6464337841157, 58.53398115404191, 57.08206092157672, 56.29323697859242, 54.35403285488006, 50.12830657343711, 45.1790088991965, 44.16912409567064, 45.71679330641224, 48.242717327610144, 51.66380074716384, 54.893735301110056, 54.74103350793162, 56.091380042414514, 56.520746215697265, 54.41796748868881, 51.870870513300744, 50.449183910123764, 49.1383630998673, 53.3661800046121, 52.93577048086351, 55.8475733572437, 54.41060519987538, 55.819100872162856, 49.8770316954582, 41.024850183917636, 40.36842976847003, 42.511628520104196, 49.73089594994822, 54.081624246412716, 55.02384031972578, 53.68536679975448, 49.824891628757605, 42.14951530579598, 55.40732260673277, 54.041204221787, 53.32051184869582, 51.15113519853162, 48.474592162716775, 45.77660945154006, 44.24052299991731, 40.019291754691835, 37.63238829951133, 39.572875038270034, 39.102661302012784, 38.39693669349917, 37.75002802571943, 39.75576339229461, 38.641520007964104, 41.424539704476636, 46.244489377544774, 47.69925725075507, 50.5979476436492, 50.24974707634219, 50.99783720508699, 52.71740821100051, 52.82385349273682, 51.61522611494988, 49.532580914035925, 50.13831646211686, 52.49726518507927, 50.14856561537712, 48.43900057577318, 49.99429095175959, 51.58112895104193, 54.973496698564105, 51.85682450571368, 50.284412983925115, 42.875306760111165, 28.0713285938386, 11.958319198700691, 4.477544897986997, 2.5276052471130126, 5.017989652772104, 4.7929794557632945, 5.185913674293026, 7.567283155456667, 8.297628971838183, 8.210165510254523, 6.976626669206928, 3.519617035504311, 1.4176683800835765, 0.31692131993270695, 0.17638350145951395, 0.5596291285849387, 6.115628173274379, 14.863618785335174, 25.222895529962358, 32.73525226500727, 36.12053817318332, 31.824799545349617, 16.651536110908754, 1.6651970268257204, 0.11073374234500433, 0.014943646214481805, 0.07123294661963178, 0.04967375388068538, 0.034826674964278936, 0.06445964152413992, 0.03794367222355739, 0.07222978022670554, 0.02126288716681302, 0.061547473193176334, 0.013901678537349067, 0.04955122194763634, 0.04168162204986138, 0.05331190926353297, 0.0074051083403549375, 0.026436568117670478, 0.08198761831848853, 0.007754553601356044, 0.07058593174142223, 0.03981676102886277, 0.03780778354754852, 0.044249625380841956, 0.11442306090987499, 0.05322697692580762, 0.023127409193905133, 0.03522090381011367, 0.07665831235147293, 0.18913462127168335, 0.12704423688832792, 0.15433947465592815, 0.21271064006272825, 0.1641559874218318, 0.06160439735639, 0.15423761560551583, 0.2526751028433923, 0.11013967180324179, 0.09893551333657197, 0.10260419349276251, 0.1592843883460568, 0.1815930678839645, 0.13202534057199955, 0.22359529389969765, 0.19228799238560662, 0.09445143983729425, 0.18220042239033407, 0.13860845667940958, 0.14838997454893205, 0.18735167420198842, 0.12765341468395727, 0.2056804197209497, 0.13040270506133958, 0.12602054423862888, 0.23287191386184386, 0.11624923066025782, 0.18455591293111925, 0.14892704814912813, 0.1644115237098548, 0.3289500647975553, 2.7315496196669917, 12.311362912577968, 38.503829125435125, 48.7182850991526, 41.85157206750686, 36.951782549581225, 27.09316203671117, 12.245504356199696, 3.029115574975168, 0.3763890789160806, 0.27883528942062014, 0.4708632562429675, 0.24216259919827987, 0.07975055730991787, 0.6108363453418978, 0.841525215054712, 10.659119390672254, 7.1022793073808, 1.6836418499869688, 1.7925348132848742, 2.28756036008558, 10.213974502778823, 23.734124629728257, 41.6390266726094, 50.05386390993672, 53.93644555922478, 59.942343465743534, 61.111849123431796, 57.809578218767726, 59.106027464712824, 52.8116156977992, 47.33832074749855, 46.41683832291634, 46.87398272175943, 50.19540655997492, 51.402649341091035, 55.80607860319076, 56.95054384969897, 57.13354203008837, 59.041112238360995, 54.23237269924533, 51.78371152570171, 50.306715580724905, 49.048713407208844, 54.01851331034015, 55.36136027305357, 58.04503025547151, 55.327565131648896, 57.92233459411129, 52.45283649813745, 43.394887447357185, 42.6202154159546, 44.23570632934571, 52.37974705234651, 56.295386437446844, 55.253204837922134, 55.201307958172215, 50.94340255183559, 46.048555220327074, 56.603488614482266, 56.3428706507529, 53.91921850942797, 54.20541817142118, 51.957762779728064, 49.352018525523526, 46.10833998649351, 41.97914715736143, 39.81757602384014, 41.60802033639724, 41.0826188518155, 40.41638858856694, 39.49500030086887, 41.44385345520512, 40.0420375793211, 43.7592246455531, 48.07003105840376, 49.77135912064583, 52.435578069379254, 52.21789436955606, 52.51518649439658, 54.63744763405093, 54.735310769850216, 55.645708576325454, 51.15434761970274, 50.28202818286035, 54.25606381508612, 52.804971202727295, 50.55453092821183, 51.24114574924592, 54.08819421645134, 55.73906883116692, 52.59175116016019, 49.41017943043863, 44.705771015536406, 28.3235546465843, 12.73596634787898, 5.553890832008855, 3.194805071238549, 6.3301803508112515, 6.469672581841869, 14.260147425436205, 16.62775674173909, 15.127307964909463, 15.876726796550138, 16.642720583946474, 12.099326445210366, 5.919588602358296, 1.4700140034960163, 0.5154381127607438, 1.0938655681187108, 8.116337022473736, 19.540310752007272, 34.77804030141523, 41.326327477732015, 42.18849974293863, 37.180107639681914, 18.768458904758578, 1.8406967386122675, 0.2611918861587202, 0.22502751059589848, 0.1744533582560478, 0.12314291115129188, 0.16731974668800834, 0.19185495352552784, 0.22350920093876703, 0.11005881888371323, 0.2956921655324198, 0.2160959672783652, 0.07819196674972773, 0.1572092553420413, 0.12173130222025419, 0.14100883997255756, 0.22908664278445706, 0.09881103170975562, 0.11725724915102606, 0.12611774547446158, 0.13088981440711406, 0.11506972338763938, 0.11834254293071649, 0.13853730243300239, 0.2316725878946243, 0.15199245704758554, 0.13727685797118372, 0.15892052722554054], [0.0893657957954753, 0.013161292862928203, 0.06375042796735803, 0.051799781935950445, 0.08112669637006137, 0.03508118086404378, 0.0072195680695585915, 0.03583919805204196, 0.028591152100313096, 0.020983073552469575, 0.05960537901809139, 0.05789098915674033, 0.0031940731259378335, 0.05384643945182043, 0.06326593098140533, 0.09306359495366774, 0.03787655526051118, 0.08607298135757448, 0.02601998674142505, 0.060859093397495255, 0.06568773409291621, 0.05984454400717251, 0.040145225056837645, 0.02914289628425914, 0.03164094621165386, 0.07508872842956936, 0.020385741391369415, 0.06376159369885441, 0.04295666814751683, 0.019926333784936898, 0.052292809310940006, 0.025735798765033967, 0.18337068298170645, 2.865255374100901, 12.118800032523371, 27.47263958377223, 31.738126931651948, 22.690756513226418, 16.59517753508783, 10.000454398893542, 5.06287137346883, 0.7482684740135748, 0.11389660528830944, 0.0959575916790674, 0.0779988130013789, 0.10744694935818834, 0.03143252624619392, 0.0485658451854702, 2.342664512895769, 9.708319210237073, 5.2576391158565405, 1.665891654068424, 0.7637475563153144, 0.890227385586308, 5.4383481029541265, 17.309315627621068, 31.915441597661665, 41.71016277805452, 51.21588960770638, 56.26816911082114, 55.843811804248446, 53.16826897282755, 53.09024910773001, 52.23135594398745, 52.036990734838675, 48.32881335289248, 46.03007693444529, 43.41502489582185, 46.15626742762905, 50.863613697790335, 52.14593064400458, 53.36164966706307, 55.40369833669355, 51.46643884720341, 49.80507189227689, 50.34106769869405, 51.29117165842364, 52.817059947598366, 53.253757030733176, 56.23637437820435, 53.06327496805499, 49.13018888042819, 43.738059536103286, 37.185579346072295, 42.808877498872825, 48.51481999120405, 53.033335516529704, 54.21106638446931, 50.139650067975445, 49.92619860556818, 38.94164800643921, 56.54280954791654, 52.44552912250642, 50.07134591379474, 46.729980745623195, 47.913571634600245, 42.76170707518055, 40.297125001107496, 37.50941807223905, 38.37337501587407, 37.36639668864589, 39.08958411985828, 37.04126750269244, 38.62858010876564, 37.22830964672951, 36.96957834305302, 42.16362799367597, 48.25342539818057, 50.95483233851772, 50.86854019472676, 48.74624767611104, 50.40274696965372, 47.95053605110415, 46.18994097555838, 45.4281460854315, 46.04673131819695, 46.17966828807708, 46.689709771064024, 49.4740120826229, 51.913867535129675, 52.557355896119155, 52.37024707178916, 53.38354041499477, 52.36388106499949, 46.659276100897024, 34.8750130591854, 17.166786501484534, 4.960512220859528, 1.6894777239330354, 2.8726009928411056, 3.427924523430486, 3.386189769352636, 3.6417834220394014, 4.218337026334578, 6.267215032731333, 4.638371880977385, 4.19961114083567, 3.62260107071169, 1.0879776001937929, 0.28440606630136894, 0.3872641566539965, 3.572959553810858, 13.19328921456491, 22.000933193391372, 33.54075216477917, 30.186786382429062, 30.797562176181426, 19.56877931471794, 5.9862836041758145, 0.9332882685046043, 0.07520171107664224, 0.039468608541233886, 0.03782053508104817, 0.03758710426008029, 0.031586406497104515, 0.055379465657977335, 0.02189436195147855, 0.03934459039761175, 0.010928030692852073, 0.01814439603608222, 0.0872784743325845, 0.12732107042064592, 0.025678775010390148, 0.040804198567545226, 0.0724655514462821, 0.03566639542940163, 0.014695080368959857, 0.044870440052041126, 0.05982877791769082, 0.0413820969932262, 0.025424470208705436, 0.018531835427688017, 0.03967657843003831, 0.043761899334288416, 0.011929569037390814, 0.05766359510861578, 0.00760452916672934, 0.04472464968961093, 0.06765952949682552, 0.034761649421266014, 0.03963529012135921, 0.006409318049273064, 0.05313656322898404, 0.049134772721557855, 0.03627523614634429, 0.017320755756490173, 0.025349085241736426, 0.01698324997578898, 0.029264436133446235, 0.08796577777473197, 0.05399040652499084, 0.044121232875172174, 0.0634017660312595, 0.059549975539407426, 0.06572380151239134, 0.02885451972214205, 0.037553400221851566, 0.015474308616361551, 0.02171103519597842, 0.016035248728228674, 0.03554703126991949, 0.09179113057231711, 0.052131325637380925, 0.04159257581998264, 0.04324751342796991, 0.048894079387067794, 0.06724517552121993, 0.0184245026790567, 0.31432670270723684, 5.9646831116368695, 19.022665754441295, 32.7526322872408, 37.13155654168899, 29.090140711876657, 24.59416312556113, 17.99188844619259, 7.279888151153442, 1.1853068033533714, 0.023836613174587972, 0.05211861240827749, 0.561865737601634, 0.3854500910928173, 0.17277694337310331, 0.6345161843684413, 4.033640214512426, 12.615542719441077, 8.918824541953303, 4.978397248252746, 1.9173693921296828, 2.9069827737346774, 7.54171028252571, 21.011017176412768, 35.39917899716285, 46.072014916327696, 53.73008574208906, 59.258654732857984, 57.01534140494562, 56.32485912692163, 54.75210635892807, 53.70591217471708, 52.13643066344723, 50.15158976277998, 46.75655088117046, 45.94736591462166, 49.46408848608694, 52.28317437633392, 53.41261302271197, 55.53978889219223, 54.964373265543294, 50.26260460576704, 49.380989151616255, 51.26921030782884, 52.08261574468305, 54.22045261629167, 53.53466541536393, 57.62437174397131, 55.97113194004182, 51.498315949593824, 45.31016119064824, 39.43453696466262, 43.674701490709865, 50.75073572897142, 54.435782894011474, 54.404227425975186, 52.23512926409322, 50.92800332653908, 40.929775853310865, 56.46178906963718, 54.50110212449105, 52.092951190087106, 47.78652606471893, 48.3857387112033, 45.87510016656692, 40.87039509127217, 39.41699220288185, 39.768930788963075, 40.6454118605583, 40.71275895641696, 39.08963511067052, 40.28515784971176, 39.23143663714009, 39.05977018417851, 42.142066724838756, 50.00736028917375, 51.730182939960116, 51.085588470582046, 48.9340978284036, 51.19360270038728, 50.82673557343022, 46.81169940579323, 48.67377404243716, 49.10646246325586, 48.89575273759904, 48.67618630009313, 50.73378324508668, 51.25565067414315, 53.429314474905695, 52.43852376937867, 53.94039146361813, 51.08765163729268, 49.43892648143154, 36.53621527456468, 20.450420264274847, 7.3081047015805405, 2.7512793867818774, 3.4233713871048344, 5.153311914013279, 6.668303858849311, 4.907656811898755, 6.077990579989649, 7.474030275498667, 7.694746948057606, 7.258632827189661, 2.356433503089413, 0.8440079527997202, 0.18858093888528887, 0.1670574381827347, 3.7248825113619533, 13.861897414730443, 23.785497873060166, 37.02005924717073, 36.524463853528424, 34.76787744029876, 23.737299788382746, 9.420540794249504, 0.8650449110615639, 0.048300208028165564, 0.04978803504678992, 0.021883046832836924, 0.003438306265443023, 0.05831868838398688, 0.033718923317088235, 0.03804240946567828, 0.01874282178769429, 0.0724807276480621, 0.04871253953165105, 0.04951770560094907, 0.06512275957051786, 0.029376505220669414, 0.006479391154097093, 0.037411857816961505, 0.03080198800401582, 0.06732410556005855, 0.03636862226431409, 0.07847708935338644, 0.040275697491221854, 0.010090421757570679, 0.058468439420985605, 0.053635608224618825, 0.038268137272567525, 0.11007387251142534, 0.03986551486436398, 0.18219009552511478, 0.08917054296621392, 0.14924060793653612, 0.2042946892399942, 0.20244225799556703, 0.15928069580226176, 0.086955591255138, 0.1433514908797318, 0.11043962586911456, 0.1018273956593006, 0.15991844867746677, 0.22609096320886768, 0.14507848288743727, 0.17332023760724455, 0.22940078479868753, 0.14706514805795687, 0.20753104299787553, 0.3073107162790914, 0.17212658069066464, 0.09909801590707033, 0.14193715467568369, 0.21387769840657714, 0.12944636686194327, 0.059483042437463045, 0.175282004920225, 0.2606954918273034, 0.14231897289714507, 0.13055529445409775, 0.1158727061063532, 0.16587073734450727, 0.1642182550483173, 0.14357964718534102, 0.4144197978800343, 6.434937542484653, 19.691516160964966, 41.06935339589273, 46.66359070808657, 37.07316029456354, 28.45437353657138, 18.089384840380763, 7.868051480862403, 1.2765888148738493, 0.27885502384554955, 0.3426857454882514, 0.8086931381014086, 0.3885139831371846, 0.14024911057804862, 0.43308387540521165, 9.765508347941983, 23.37761648239628, 13.21693326196363, 4.6154716130225895, 2.2495891201880673, 2.1730560785339725, 6.318975610117759, 19.89126286199016, 33.629633072883856, 44.83957875159479, 54.30145740509034, 60.210084453705825, 59.9274423814589, 57.30918576640468, 58.25037025636243, 55.9979844862415, 56.3364105070791, 52.386222885501006, 50.258976413357644, 48.03178010448333, 50.93997832267515, 54.82353271976594, 54.9403997390501, 56.06309190873177, 57.700967788696296, 52.242083626408736, 48.6111573250063, 51.85305118560792, 51.837028303454005, 54.06390297797419, 55.9890297151381, 59.871132835265136, 56.818481568367254, 54.219013106438425, 48.679524237109774, 40.734877201818655, 47.06485702145485, 52.73114435134396, 57.43143035519508, 57.51506705437937, 51.77870265899166, 50.841330712841405, 46.024240447628884, 58.228742307232274, 56.5273436423271, 53.737275446614916, 49.83649399972732, 52.0471457512148, 48.11628756984588, 42.58920123500209, 42.01813551687425, 43.32497512140582, 41.04160654929377, 43.37729953950451, 39.92040488027757, 42.29117562693935, 41.774921109599454, 41.45655016745291, 45.28954913539272, 53.04703243317143, 53.98878174443399, 52.818624973297126, 49.630757839449, 52.91780210310414, 52.132135668108546, 49.13755901398198, 48.15218902403309, 49.60229712147867, 50.967446680991884, 50.2176542435923, 53.85584869692403, 53.508777772226644, 54.58524480942757, 55.4541870855516, 54.088955156264774, 53.247540074010054, 47.1103016022713, 37.415685192231216, 19.625587001923595, 6.6144149053481325, 3.658667999890543, 6.798017621040345, 8.902083866057858, 8.55004329835215, 9.162164465073618, 10.778870332625605, 13.412913507030858, 12.779037894741183, 10.56143472271581, 7.477169642525335, 3.712653296609079, 0.7563353798562481, 0.6560552672993752, 5.136541820341542, 17.329853157843313, 31.035644162085752, 41.751739901881066, 39.83778799733808, 41.35851052499587, 27.830067526909616, 9.895311344054438, 1.2071600436202943, 0.20832808087429694, 0.12592531950964084, 0.181281668464503, 0.11067204928446202, 0.1277137900732698, 0.08657173523979803, 0.18811359460796082, 0.18070088188734748, 0.1561922583008005, 0.15701074663910175, 0.1730469740446537, 0.2379015568763979, 0.13755631152420275, 0.14144028536975384, 0.14602034202506467, 0.10812635443383649, 0.1627216869664769, 0.09542579642466961, 0.158742212600285, 0.1214011183248893, 0.09600096757734015, 0.09626551305935269, 0.14605889156941446, 0.20646993461395466, 0.3040491122632258, 0.16786665685715216], [0.06498348478588366, 0.030972174436394728, 0.036792529356335445, 0.06921155468350457, 0.06500056854659511, 0.03929152348709684, 0.06899681257744951, 0.01757471007294953, 0.038144471529390545, 0.03125625707569622, 0.054545437226132046, 0.048496188640955, 0.01680562866010493, 0.0485296743441253, 0.038218919953872124, 0.021680161852629918, 0.05038560661036642, 0.08421753172672565, 0.03756618622930781, 0.013510744827198646, 0.009850641025320418, 0.04798026672834831, 0.006426918919333407, 0.007116460774634635, 0.01790703709928259, 0.048592700397655855, 0.04291481676421339, 0.03846296492303091, 0.0350624461838555, 0.032933265676782016, 0.06160354699879404, 0.02451377552783778, 0.07728704071092991, 1.172777404708247, 3.734871562450163, 13.855124462035395, 26.03000948506017, 25.453164154483428, 21.809558791498986, 16.358155569722577, 8.019571169730156, 3.965982515965739, 0.17272391476698462, 0.11287446013621746, 0.3823751980258573, 0.4917305413513415, 0.18371382908475015, 0.3848406528272937, 2.0387904057579656, 5.858250087307346, 6.605125261891273, 3.68743343699363, 2.3829237203444205, 0.8415053580557147, 0.8972948224794481, 4.0910938670558314, 11.890766178407977, 22.25588725459191, 37.17045860905802, 49.18658079639558, 55.749412121311316, 57.48993642868535, 52.8215039930036, 52.06185071699081, 54.044424487698464, 53.54806030950239, 53.857617685871745, 48.78340428875339, 45.03825856793312, 47.859462538073146, 51.622431508956424, 53.88299149851645, 55.4124334550673, 51.88048816496327, 51.338291091303674, 50.097559113656324, 52.44192838668824, 54.3058269254623, 54.68805405401415, 52.75905201511999, 52.380021618258574, 47.52214654799431, 42.73857293590423, 39.458600705669774, 41.9749580660174, 50.92951343905542, 54.61590597706457, 51.77676500812654, 50.86184078647245, 51.030106544494636, 38.762889908206084, 54.508844883211204, 53.298974114079634, 49.892156354842655, 45.47863091191938, 43.71246607072892, 40.176943579027736, 37.81479027963454, 37.974705311559866, 36.34977325316399, 39.393434447626916, 38.728157320330226, 40.40928909855504, 39.19620983062252, 37.76982422797911, 36.934916357840265, 43.091884351545765, 48.81724257622996, 50.42863853516118, 47.98172673871441, 49.78380872357277, 44.63728643232777, 48.109290061458466, 49.57833536209599, 48.73734781819005, 49.24682840224236, 49.416839614991225, 47.87382625764417, 48.103033881033625, 49.30810366907428, 52.60805645296651, 50.95375368672033, 54.01706595574656, 48.31140195169757, 44.069158569459, 26.680862096048173, 13.70987811396199, 3.009354183750768, 1.3264308629497406, 1.3852009609822304, 4.078999974073903, 5.857873539770804, 3.2146743276426872, 4.2936543783833905, 5.355048727604651, 5.61121529148471, 5.973438822454022, 1.08877286074623, 0.5560909055413739, 0.6902578449056995, 1.4764227886353771, 10.706180968592244, 23.158452087833037, 29.264260607381022, 27.437481418732677, 27.93508702708829, 30.307828764761652, 15.351904842161364, 3.2948497802980485, 0.09775818941453773, 0.058251621216655745, 0.028872926899742697, 0.08831570375590556, 0.03710287157446146, 0.04184495199531798, 0.07664065402481826, 0.029016643079117905, 0.03644075710326433, 0.03590810766083098, 0.04890286641555929, 0.03855908214445076, 0.059453938757219625, 0.0574057528959407, 0.030267237565450134, 0.04832903591675624, 0.02192697431441517, 0.03965142776348418, 0.018552856880330273, 0.03836462604663065, 0.04684776278032411, 0.08257796567293905, 0.024003210485041625, 0.055636365582505544, 0.012034637038595976, 0.016390680966358033, 0.0159080398284019, 0.013876427321754878, 0.01503423036586854, 0.0016558886343245247, 0.03714219486761478, 0.014616620516584767, 0.08023123151712841, 0.016547221457585692, 0.028253466288949695, 0.056649750519183376, 0.06863953981308207, 0.01756064661387955, 0.023779974379126104, 0.024118719307044824, 0.01779128504436343, 0.03513996662091344, 0.02082542989463095, 0.05913845225868206, 0.021851679362777262, 0.05570602212702075, 0.05242320896697141, 0.04788553229563179, 0.06817982577147984, 0.01799444581622318, 0.05802449529930469, 0.03901407708443942, 0.022279748227447275, 0.046828962982662266, 0.030938838120369665, 0.010654689563858894, 0.05074050833260821, 0.07517898124792884, 0.04277027512509977, 0.10844357612152254, 2.2853344150127906, 8.092764558330659, 25.10751901134368, 39.17123217736521, 29.801133063531694, 24.858073919050156, 17.979491795262984, 11.662778412142108, 3.6767653255693378, 0.2713982610692901, 0.13785828806219563, 0.14096589308352242, 0.7796875171123013, 1.0014275605640104, 2.3883086442947388, 8.876905191329218, 8.016540158179499, 8.36320903993422, 7.464766127447929, 3.0629727388581927, 1.913183855433618, 1.6532856466308719, 4.941847132098291, 14.913026921210752, 25.93635701364087, 41.47743286625032, 50.93149031362226, 57.98886583697412, 58.342836210804606, 55.358834266662605, 53.19126190677766, 57.41214013868763, 56.91153587833528, 56.63737004803073, 48.62729395589521, 47.66260270149478, 48.66332877066828, 55.142029177758005, 55.355092325518214, 57.56649717207878, 51.96611350582492, 51.167828805984996, 50.623254776000984, 53.09391652384112, 55.76706670945691, 56.549222623148275, 54.63206614217451, 55.28149297160488, 50.10562350673061, 44.5705629933265, 41.00384589164488, 43.33735019929948, 50.538111886670514, 56.2907031274611, 53.86277952501851, 50.643666790377715, 51.730457505872174, 42.81063079833985, 55.50320886796521, 55.61802841001942, 52.46010072769658, 48.684246770797245, 45.1119089126587, 42.040022342435776, 39.033262806554, 39.9818644985076, 38.5866185926622, 41.16983275259695, 39.85920413847893, 43.67315999923214, 40.871332537743356, 39.54271201164492, 39.41345814735659, 44.4318679840334, 49.54927844385947, 52.24441351429109, 50.13361354028025, 50.48881946071502, 46.82116016264885, 48.61316557853453, 49.86465661756454, 49.9645358516324, 50.613962681062766, 51.42637968063355, 49.871242277083866, 51.13296677989345, 51.41748766745291, 53.413428875707815, 53.05654025846913, 55.287188253095074, 50.91958199777911, 45.13931843542284, 27.474143812733313, 17.29313781184535, 5.180372345832087, 2.516407125419186, 3.327940856256793, 5.437599910843757, 6.622245917397161, 6.530859105048641, 6.471728884404706, 8.31303310009741, 4.916767987512774, 4.583004193921243, 1.0354429675686745, 0.27495958932465125, 0.2450416648700353, 1.6368881781255047, 10.11616922193958, 23.41299822253566, 30.7313996361148, 33.84242557710217, 30.476622081572014, 34.550189818105395, 19.2239127620574, 4.671343324645873, 0.18235121913734945, 0.06443694999982273, 0.05903315347348971, 0.040921904146671295, 0.04473366271404009, 0.00874554961844678, 0.03517875748295938, 0.05054071260195586, 0.031633543887085495, 0.02861011852209847, 0.05169171374291182, 0.03792413315104862, 0.011638249740034584, 0.08055560080514801, 0.08644140070124019, 0.03135813910874628, 0.010211903192553549, 0.011721747578121723, 0.00528253055357885, 0.04413180871896687, 0.05358516516524458, 0.07127586286514997, 0.011253271405885537, 0.0541753861151876, 0.018949441446532166, 0.10265708420305483, 0.013324498319097105, 0.13117412495757305, 0.14326207309720979, 0.12792964300681509, 0.17798768957295727, 0.2694387000895316, 0.09435708844853986, 0.16153633444299623, 0.08829278240521109, 0.10717167864523588, 0.16796054859315196, 0.11337135242478502, 0.11884371765078076, 0.11977889650170842, 0.18536407440420122, 0.11789237434465079, 0.1047705292641636, 0.15373760533909644, 0.15796074163048499, 0.18558933489745666, 0.14257665423135604, 0.10742702341127781, 0.14881118501145996, 0.13182372155208744, 0.12287877169587921, 0.0758077402509028, 0.16179058370330643, 0.14695035744338267, 0.10479365745859762, 0.14351284431834377, 0.13083798089815726, 0.13819962619773804, 0.20873871932346977, 0.1797526335764316, 2.5559884982724346, 9.308036431189507, 25.892938337018414, 46.93876066515523, 39.128729374178, 35.39913585109096, 24.877642623839844, 13.781645721004857, 4.7636082576167205, 0.6183378170094183, 0.4130850888548359, 2.2783268555518124, 2.944767455900869, 1.0822676098154438, 1.6720878957740724, 14.128934337246804, 16.55601070773217, 15.09238612267279, 8.62433789237853, 5.545090504230992, 2.332832846910723, 1.4698012149141682, 4.8021386804119235, 13.799445436846826, 25.476443421456125, 41.07390726766279, 52.11176679980371, 59.70339659721621, 63.41785369380828, 57.241097342583444, 55.80270928721274, 59.03396960227721, 57.77370422117172, 59.38869307118078, 53.01737539229855, 50.56709427987376, 50.35910275674636, 56.44862167296871, 58.08379111751434, 58.24168612880092, 52.14770747769264, 51.35255675162039, 51.17496751969861, 52.275278645177046, 58.144587855185236, 57.44603726171679, 56.64683472725653, 57.17144781543363, 52.74545708010274, 46.71039635135282, 42.96643126395441, 45.16863423009073, 54.30632506647418, 59.22506747707244, 54.76121410246819, 51.28923008518835, 51.02388566540134, 46.095266726709184, 57.60937652280254, 57.1489530224954, 54.593222910358065, 49.98097450502458, 47.88184750464655, 43.987479132990686, 39.50781076185165, 43.09028794688564, 40.260901912566155, 42.34498662333335, 42.35237636873799, 45.108512140089466, 43.330121271071896, 42.08996588183988, 41.20289048840923, 46.07285822591474, 52.61408513592136, 52.86265750085154, 49.71128802145682, 51.337934155617994, 48.31692857127036, 51.385335999150435, 49.51096080964612, 50.4527493446104, 51.427285748143355, 52.289010863150324, 51.24257349198865, 52.63230454537177, 52.798624807788485, 55.71756247551211, 52.60223957800096, 56.4577058822878, 51.31273292726087, 47.267251322346354, 27.209964336887484, 16.116227699864297, 4.50172140713661, 4.248022504391209, 6.156623805722883, 11.010126413837558, 13.39326439365264, 9.945625547439823, 10.759826244846469, 16.717708456900812, 16.33460860098562, 13.75939509560985, 3.781144008521111, 0.7721075367543005, 1.1941065182608943, 2.2101680742156122, 14.372246803775912, 28.17608725640082, 38.20885904373662, 37.19182375938662, 37.819924662190104, 39.35718390249437, 22.07880400842236, 5.264913641637372, 0.2960298570894426, 0.26878081442367646, 0.21226548169168735, 0.15509757994403764, 0.09802403724602154, 0.11291148516559794, 0.19182426404328118, 0.16643044118198658, 0.15411455124135942, 0.10070662434783675, 0.14803924417543798, 0.15610014388878501, 0.18980600540676426, 0.2985249135282732, 0.11645043599269084, 0.07531801088442726, 0.11270562967946453, 0.0698714321779628, 0.1398514803018301, 0.265522213472474, 0.15221931100372346, 0.17289697402907958, 0.1341907187334953, 0.1347974910130424, 0.08754055301148085, 0.19645305921233472, 0.0708199332978937], [0.09005044857340475, 0.020013600775611498, 0.041692171080578724, 0.027372152995198008, 0.018745616093398105, 0.11138264946038685, 0.05625031993634278, 0.020191206769537062, 0.021939262364720626, 0.0582258232058056, 0.02990745011747124, 0.04525161859008574, 0.03295324908028687, 0.042591719182148095, 0.09928953022726121, 0.016279738028383544, 0.03689004851865672, 0.008561874292941104, 0.0279598267027928, 0.046566964742997964, 0.12442829943592511, 0.00587605046964581, 0.02273897580321758, 0.03963412566771431, 0.022484877845272425, 0.04218386163214042, 0.03312580272435181, 0.06065465900446139, 0.03333320953853188, 0.039841543973213246, 0.013793002262020545, 0.06897383760060034, 0.076227288302635, 0.24647195102466693, 1.6358067071245563, 7.156884583734698, 23.338667346585183, 31.862791622838667, 24.5505287185792, 22.389846001901937, 9.410503448978547, 6.72048314925163, 2.004278328630232, 0.13241403826302098, 0.03298380832758642, 0.9262496978044511, 0.4226466628812975, 4.057960380469599, 4.925631563509665, 7.3833695919282984, 5.481596646770354, 8.353942440402124, 2.0790581933913694, 1.6854905120788084, 0.3696626124362792, 0.3032834227046659, 1.3044682866142643, 6.512723045964395, 14.473758724427993, 28.78740433723696, 40.6214108774739, 51.87950365005001, 59.01205924249465, 57.686066704411665, 55.34092864682598, 57.430253644143384, 56.398587919050655, 53.77801710559476, 48.28539271508494, 45.273526253238806, 51.66043535355599, 52.28348032120736, 54.284226432923354, 54.49428896750174, 50.36182880401612, 49.77602674115089, 53.16258545844786, 54.62440967559815, 51.873702464565156, 52.738032033366544, 49.520029329484515, 46.68389289609848, 42.31281534318001, 39.49713799261278, 40.871814989274554, 49.805530809587054, 52.407207565922896, 54.43470816458426, 51.656732636113325, 53.197121927815104, 41.140983719979566, 53.358594140698834, 52.39750362211659, 50.82092262083485, 46.7931701290992, 40.364534854888916, 38.06285273644232, 37.166665677101385, 37.447797636831964, 39.19220901304676, 41.141521084693174, 42.07897540061705, 42.02528992006856, 39.22254854632963, 37.08908903983332, 36.336625468346384, 41.55428778740668, 49.29050007174092, 48.739814989028446, 50.789233792212706, 47.14748567150485, 49.30436565030006, 51.40242576599122, 50.10979298622378, 51.213112569624386, 50.25372435969692, 50.41827171079574, 46.638020776933246, 45.533657843066806, 48.05840123084284, 49.597547131199995, 53.13821185019709, 52.19079079166536, 46.535388039004424, 36.6197499921245, 19.632584510311005, 11.797489273932673, 3.8889447143000946, 1.5483981587233082, 2.651882604245217, 3.6717238541572326, 4.725582349684931, 4.306691356243626, 4.127572890250914, 2.8472619912316723, 3.75515757068511, 4.570879657422343, 0.9011133724162657, 0.15748549132577835, 1.3691107856650508, 8.380213495223753, 21.200926573045795, 26.355732910094726, 28.645549858770064, 27.622013245859456, 33.72078111094813, 21.136399661341024, 5.2068694272348965, 0.5252436704693303, 0.03990259735033878, 0.0726901454430434, 0.01872746555525209, 0.09238830377017299, 0.0055511511445436035, 0.03005639293170985, 0.03933275433918161, 0.015583632235986092, 0.03976079064511484, 0.03866766744683828, 0.028795597984665827, 0.02067433437332511, 0.021562839317465984, 0.034947613434445475, 0.0829412522275121, 0.03352134158053706, 0.03022038937366057, 0.09874682588082168, 0.07856290652266434, 0.08232666585113733, 0.041610831695218245, 0.06885049744479119, 0.011177037038930483, 0.03363965619956294, 0.035450538665416746, 0.01398495325232826, 0.05138402601944343, 0.08423721252550041, 0.006557082045718187, 0.08358167874957285, 0.022196721533433567, 0.044741790906916705, 0.061696642003352606, 0.04681130082556798, 0.03849563091212223, 0.02588161019488208, 0.0435571699974037, 0.039431089385142254, 0.016174659493469423, 0.03186579301743017, 0.049466082766171426, 0.07835438505055443, 0.01785737544959111, 0.02048818841426363, 0.02502842764970997, 0.015311402892093024, 0.023904191705608563, 0.06624493282288313, 0.01380696325683065, 0.014718941134971478, 0.04711177583122927, 0.09690528074579854, 0.0451473425322723, 0.04426068002958933, 0.03593489009466383, 0.044074398089921286, 0.04551624451133032, 0.026613287364823685, 0.033431896984937697, 0.10823286363794919, 0.5723187928238224, 4.036395924706613, 11.08588699371584, 31.464849518191432, 38.19833924693447, 30.73431984070809, 26.235467157056256, 15.60254429617236, 10.457446805892452, 2.177390297574382, 0.08790331862626538, 0.12570960447192192, 0.7390384628407417, 1.576665577388579, 5.342561371864812, 5.815233453627556, 8.01310759398245, 10.237987252973742, 9.582745509762919, 4.600769589024206, 4.383600209989856, 2.4063763070491055, 1.0853471606969833, 3.51368984387767, 8.16303332967143, 18.72089820523416, 33.046866924532004, 45.38489410954137, 55.74755684021981, 59.93693059490573, 57.49935796183925, 57.39695272138042, 56.93955729084631, 57.83583456470121, 55.621248675930886, 48.146427062249955, 47.771448473776545, 53.99706186786775, 54.12178147223688, 55.933794898371545, 54.76135138542422, 50.728311538696296, 51.04129706659625, 54.55358735976681, 55.348742008209236, 53.96544756427888, 53.24353925643429, 52.27037176009148, 49.217328256176366, 43.150700292279645, 41.69723464596657, 42.11797160487021, 52.139839203126975, 54.5763292620259, 55.749392509460456, 53.92647097187658, 52.57127246549053, 43.24111876949188, 54.18470805691135, 54.89181726209579, 52.7706112400178, 48.661606850162634, 42.19071195971581, 39.2489343304788, 37.55778874120405, 38.112392271718676, 40.24616949019894, 41.84217799094416, 42.98697271654683, 44.711799698491255, 43.54545939353205, 38.48766503795501, 38.4414908962865, 44.28777187101303, 50.670797824859626, 51.89474990290981, 52.097305020978375, 47.49693747489683, 50.17703810045796, 51.521579527085834, 50.551334196521395, 53.24603780623406, 51.107843998939764, 51.57758312840616, 48.98471601547734, 48.15347948381978, 49.86566074432866, 50.78315804081579, 52.99481391906739, 52.645342503824544, 49.43865583788965, 38.69944949303904, 22.820675219258955, 11.547751965061313, 4.046326140242239, 2.4396282001849148, 3.798789771333818, 4.8592346618252416, 7.309875651713341, 5.3397485421549895, 7.191859868264968, 5.447087633994318, 3.364682923401556, 0.561220568995322, 0.11874030344188215, 0.10109703041492932, 1.3311809758024833, 7.10244502752058, 22.2981252977925, 31.5159736910174, 33.28850061662736, 32.110830545425415, 36.836825724570986, 27.25015490285812, 8.006261587142944, 1.0973481425354559, 0.08258811633793578, 0.07780875424824416, 0.046613811019567714, 0.08335539935937814, 0.03771079681633461, 0.010171687406968447, 0.02577942938754155, 0.024399697375033173, 0.035058745979181224, 0.03399036359041929, 0.05620203341447538, 0.05069602543728487, 0.0036761617229785775, 0.06910555109742188, 0.045341557312396266, 0.030103606930483254, 0.02782431724030645, 0.029178597896750418, 0.046339911603999716, 0.012033969584491946, 0.029401956576733824, 0.059112788313218666, 0.01687672544991778, 0.04753267602814783, 0.044102276029485854, 0.030464507121172164, 0.026476199761213317, 0.21524346463622587, 0.06530792302181644, 0.1645542918554237, 0.15058850899579065, 0.11367878350879877, 0.24009848253861552, 0.19544461171232885, 0.15285730902706424, 0.1223850203678012, 0.15684464345535926, 0.11691260917653, 0.2012565377498827, 0.13638939107618026, 0.14569817140938776, 0.24086024972700307, 0.1280074315746465, 0.1448326146290187, 0.1004449593564195, 0.11166585684423486, 0.09702834510995496, 0.23880911059677604, 0.1292358612221095, 0.16962314324994243, 0.10391207411885263, 0.19878942819852985, 0.20892158451099552, 0.08565849714702176, 0.16938631482903035, 0.11347527991259292, 0.11430037958968071, 0.12709470676077952, 0.15148322308255782, 0.23180095358721672, 0.5930564252118911, 4.546329052217545, 14.785682270603797, 36.76891772977768, 46.558192699186264, 39.70450978125296, 33.89487158867621, 15.690453437066848, 9.928157271877412, 2.6258966567054873, 0.2643508343927322, 0.49123764038085943, 2.213840393289443, 8.516420741235057, 11.48936846563893, 10.404191805470376, 14.094902873039247, 15.785573855523142, 17.088703878464237, 5.487675339944902, 4.760002618835819, 1.5246304340900914, 0.6183768568500396, 1.5604943806125273, 7.24350130365741, 16.443210205724164, 32.52924546118706, 43.49309182936146, 55.26064557413901, 60.738208063187145, 60.26704119097803, 58.40486849507978, 60.643455366934504, 61.07782648455713, 57.23272308226555, 51.578183251042525, 50.30305600935414, 57.41348551165674, 56.928766850502264, 57.78443190359301, 57.3055693411058, 51.171664884013516, 52.93646474038401, 55.85481797495196, 56.300516897632235, 57.34846830368043, 56.46480144992952, 53.77966057869696, 51.749418243285156, 45.88712615351523, 43.078277649418006, 45.32664299011231, 54.30474827366491, 56.415865959659705, 58.124497475162634, 55.34956962831559, 53.4648197697055, 46.69943724909137, 56.12339050539079, 57.9675163761262, 55.167767770828746, 50.62395688026182, 44.810533600468794, 40.47860130187004, 40.88772804506364, 40.8163252184468, 42.578179374817886, 43.699075098960634, 45.49868599061043, 47.25281700011223, 45.21924065005395, 41.005222643575365, 38.9749881529039, 45.4557752609253, 53.807560397732644, 54.88631025437386, 53.786626708122995, 49.577546965691354, 51.5397910917959, 50.1176259594579, 51.24106337947231, 54.73991955480268, 53.021835127184474, 53.996300928054325, 50.08052033762778, 48.57896251063193, 51.29208164830362, 53.45046389487482, 56.1364519980646, 55.5860532483747, 49.67347245062552, 41.13766147244362, 21.052484473874493, 14.599040208324311, 6.2219405847211045, 4.363000412141123, 7.578051042172217, 8.103832016068122, 13.154640140071994, 10.155730247497559, 11.107356086854013, 11.454844743974748, 10.50601065158844, 10.013565901787052, 2.970957611837695, 0.5430717622080158, 2.4418100185932654, 11.116123564781683, 25.740999444838494, 35.13442293290169, 38.28920879671651, 38.88128272948727, 42.75679234535464, 29.51802226804918, 8.800229718608241, 1.1210488191535397, 0.2291845488211801, 0.11327963637849016, 0.22386057482611751, 0.11718020368848117, 0.07771851675164315, 0.11291436565619324, 0.12208471390148326, 0.08803055816960913, 0.13575111726118674, 0.15183314140285217, 0.10527853748851246, 0.10785804746011574, 0.14584417244599712, 0.13542621937249938, 0.1757566576763507, 0.1264319870801222, 0.12983581531913052, 0.1429539372123057, 0.14251222623692406, 0.10835518489681906, 0.11472362018520794, 0.14948630765561136, 0.07742122101086764, 0.14053452429511856, 0.2045376463643005, 0.10296213275362408, 0.1751267648632488], [0.01960113712195908, 0.040900917167985634, 0.041606909325045925, 0.03731144667272607, 0.04197706002742053, 0.02866405877284706, 0.025764551960052024, 0.06217512136866009, 0.05100785386598399, 0.02057160581311872, 0.01457188481224641, 0.03470508914981638, 0.08270891308183632, 0.01904092383601012, 0.030641647716683727, 0.015545596928155471, 0.027771981943759228, 0.05358017410241789, 0.032343462244757724, 0.031508585370536295, 0.02675677371782161, 0.01762745139609662, 0.08920808127450366, 0.03754406544049421, 0.0729594789745827, 0.00747161865752611, 0.01929207427066661, 0.045808947554999785, 0.1535596277925276, 0.027117536012684147, 0.005167251079147983, 0.042227072821509455, 0.07037906501922878, 0.05918540961800083, 1.1057807481096638, 3.5977310374859846, 13.141996379821533, 25.820405867791948, 24.62128435411761, 14.837775268862325, 13.122810106123648, 10.744390737625862, 6.293848416497631, 1.4737729824358419, 0.07932921661244285, 0.3126164267380392, 0.7526259208398481, 3.1622241485503415, 6.005518907500852, 6.978049999283207, 6.94741677853369, 7.56138930397649, 3.7925431516862687, 3.3214409985849938, 3.177457653707074, 1.2830272629376382, 1.884141768659315, 0.5539915181936756, 5.028884526221983, 11.139166508951496, 25.377466332527902, 36.51305760106733, 48.9348626905872, 53.74020937950381, 52.97242895249398, 56.333962948091575, 57.59215731774607, 53.24737141209265, 52.83838195185508, 48.014411849360314, 51.641808017607666, 52.64205163524997, 56.15088239792855, 56.18071986782936, 51.905065736462994, 50.30472301667737, 54.23142348566363, 51.628260151032485, 52.52905599532589, 49.8710383138349, 46.91518722041961, 42.99275036781065, 38.71413092459402, 41.42459854002922, 40.06957654030093, 45.32987110076412, 53.49367664706323, 51.55189944851784, 52.67567026999689, 54.93157832853256, 41.21674429985785, 52.36710917565131, 53.7472382668526, 49.97849556707567, 46.45590512983261, 38.06142107132943, 39.07994293397473, 37.03649790056291, 39.68595304796773, 39.15450719095046, 41.09753170321065, 41.25827043287216, 44.82774103841474, 40.96153528459611, 39.1231321519421, 37.071281479251006, 38.37802694689843, 46.576659217957534, 49.79867058415567, 51.65676009270453, 50.272132042915594, 49.12254025859218, 47.26363881941765, 49.934568943515906, 50.60638466188985, 48.19917117395709, 48.495980847266416, 46.18658342669087, 45.09695291519166, 48.33386536567442, 48.628788378930864, 52.043799969457815, 48.91852209644933, 42.54212887056413, 27.902705900130737, 16.824767589569092, 5.204867057261929, 2.2655659144924534, 2.229008198745789, 1.5458130716316163, 3.8829312305296626, 5.235522831639936, 5.547872935571979, 7.078004248680608, 4.998296412729449, 2.065483360521255, 0.4617109876726905, 0.10340853218710232, 1.0957174171363155, 5.607002665919643, 19.377577497113137, 23.572777932690038, 31.452209680311142, 22.839057407071515, 30.577987893935177, 27.527878322908958, 10.426451256198268, 1.578313708305359, 0.05222058254143885, 0.0269763000429638, 0.04076146235268924, 0.06846287227686375, 0.012214665785582076, 0.11958691486788374, 0.028913299733352278, 0.06541041026432669, 0.07483013545072849, 0.03485890811369304, 0.09866740554571153, 0.0388502951471075, 0.04125890239412266, 0.03740288309692856, 0.044357065381782676, 0.016177327394665732, 0.06250950342585003, 0.037869285086109754, 0.05298579329504602, 0.046593915716174154, 0.04070982802659273, 0.04731663540306111, 0.006034781014727008, 0.03777054018310962, 0.03973421888546117, 0.048343522639404383, 0.066796860867931, 0.0042438249745886895, 0.06867356943867861, 0.07963385913641223, 0.08999391128459285, 0.05036744266568173, 0.004270388594558162, 0.009805849779607549, 0.007872776768635958, 0.052950897990095044, 0.033508647503631736, 0.04663687409652818, 0.012333849914402012, 0.03593900781725684, 0.02974897525423477, 0.051988009738946156, 0.06573971315857864, 0.10535069531010044, 0.06131791877710532, 0.03188273122143601, 0.011650580882785783, 0.029438512377260678, 0.046461390166152874, 0.06309433111680612, 0.06824623027275648, 0.07272678742846174, 0.009480816867923545, 0.04961140964540744, 0.05372293458710756, 0.02723311186738072, 0.04881762764266422, 0.028355647096290227, 0.008063641350506055, 0.04563247537120216, 0.04381441083105822, 0.037395160930651816, 1.8974533124316124, 6.510619184663219, 20.704736940322384, 34.477755408133234, 29.08899537978634, 21.484264865998302, 14.934621530194438, 14.266108447505584, 6.265598525924068, 1.3297593617631545, 0.060831487419143807, 0.054588793972206694, 0.7540944807471768, 4.042323851777661, 5.913342227858882, 8.315210996135589, 7.871825291264442, 10.633954444239217, 6.581150754805535, 4.305006207958344, 4.895101795273443, 2.5571831051380407, 1.9013120666626964, 1.7474622447644512, 5.793556965166523, 16.662905100853212, 28.468629390962665, 40.332869560487815, 50.55872394192604, 55.825717910643554, 54.53965510091474, 58.6022460845209, 58.730515433895974, 54.92502012560445, 53.461187654925936, 50.80038901298277, 53.93388817387243, 55.47312821111372, 56.71953978077058, 57.3098486469638, 49.87337996882778, 52.62798209344187, 55.57030100976267, 55.06033797417918, 53.78509698375579, 50.59587270982804, 49.72042714395831, 46.10119735040973, 40.55478549772694, 42.89717397382183, 42.356208524396344, 48.18882003907235, 55.002130000822014, 53.63646661081622, 52.83960573134884, 53.72830498603083, 44.730179925118726, 54.45224115925451, 55.67226302239203, 53.230030613560835, 48.90571948020689, 40.170259860254106, 39.80687972038023, 40.569113915966405, 40.18680049527077, 40.76136104522213, 42.505136997469016, 43.74131902571648, 45.16523353515133, 42.87170994666315, 40.63293087866999, 38.85420660818777, 41.144745272974816, 49.83331295751756, 52.41139273489676, 52.460551800266394, 51.615139822806086, 48.91934971655569, 48.21115009246334, 51.31109337652884, 49.36986923217774, 51.555578631739465, 49.95228628958426, 48.223854649451475, 46.5883949495131, 48.53605570331697, 49.596464557032434, 52.51968545298423, 50.78141650845928, 45.67057601867184, 28.603353000456288, 18.382378047512425, 6.33259702113367, 4.097100731826598, 2.8395949832854734, 5.0685058582213625, 5.311838426897603, 6.747812753723514, 7.213280912368529, 6.727506153045162, 4.221508262618896, 1.455198966207043, 0.16094234051002612, 0.17131887887033725, 0.8183378173458962, 4.9888567386134985, 21.641008661639308, 27.40910307053597, 31.913558859978956, 29.028428100770522, 33.62199229578818, 33.071950481783965, 14.199414426280608, 2.6460228283559126, 0.0522426956693732, 0.07126228778713173, 0.036919569716818874, 0.02031094439688229, 0.03774880626869779, 0.06716221585989961, 0.03346006220747386, 0.0293234727841111, 0.11802319917948016, 0.06344161409464094, 0.03363084235799409, 0.021557432651940375, 0.04154436207646805, 0.026837126764979576, 0.061088237956526785, 0.031593502386503165, 0.013258898210140967, 0.004930524643690836, 0.06638268309254801, 0.04820894780418566, 0.015061945511749195, 0.003753373570244519, 0.02217015551943933, 0.044724431354552514, 0.023731218628405083, 0.06686338794327552, 0.008877541779750779, 0.040909033869543386, 0.1908432118474476, 0.22195454807050768, 0.15034541397565795, 0.13606789461787672, 0.06649675358447336, 0.12586697425332763, 0.11661528279223751, 0.23060199534220083, 0.21583067103018685, 0.19517343190889205, 0.13152503919216896, 0.15189488808954918, 0.28543731257800137, 0.15216453571713742, 0.1867483186745836, 0.18776245054698762, 0.10749831555351134, 0.1042926359561182, 0.15411376983167666, 0.13473857885166524, 0.14353607210420793, 0.09992839392995644, 0.2889809595240701, 0.11417051236475668, 0.1990947142363556, 0.16417530815928214, 0.17919790931046012, 0.11822779062053851, 0.2657742257560453, 0.10679131599083062, 0.09083538226062253, 0.1491587437809475, 0.14246207812140066, 0.07732712243112826, 1.9975662952469242, 7.8316621818850125, 25.752754788244925, 42.032801258948545, 38.25939486103673, 25.737155522069624, 22.03960776329041, 17.474745512008667, 9.167901912043172, 2.1391288022841177, 0.23698801234845193, 1.0198755093639897, 4.421935004572715, 12.769655585289003, 16.43544391278298, 18.83442924868676, 16.54808948116918, 17.51956839715281, 11.931634333825881, 9.438814136289782, 6.871147271125548, 3.156699490162634, 3.030260661917348, 1.5489749922867746, 6.480275729010183, 12.767773828198834, 28.5804130185035, 39.10676410121303, 49.61732764397898, 53.671595358079486, 55.15607910771524, 60.452169218371, 60.68334979395713, 58.0703648444145, 56.35560266433224, 52.214736861567346, 56.41719956551829, 58.23164486115979, 59.77347758508498, 58.952898133185606, 52.333651358081454, 52.5830356536373, 56.44650751544584, 54.86664349032987, 55.76850229693998, 53.08939010866227, 51.69136716473488, 46.73972391313123, 41.741706478980284, 44.53464977202877, 44.13101434707642, 49.36152635082122, 58.0133649610704, 55.508056917498195, 54.423411738487985, 55.1888426657646, 47.75568054568383, 57.09032535552979, 57.591957276867284, 55.34000296746531, 51.3149098427065, 41.96020995416949, 42.25228140431066, 41.26426381449546, 44.26468872254895, 43.24355063899871, 44.44570218363116, 45.588833824280776, 47.95544685855989, 45.28995313952046, 43.08222747618153, 40.902213358110004, 43.85342428761144, 53.279326961886504, 54.21810703892862, 54.20912481123402, 52.733019244286325, 51.56050905104607, 50.412384233167096, 51.33313317452708, 51.83470233794182, 51.93904915163594, 52.16922952282814, 49.84100472542548, 48.86633496130667, 52.3235002640755, 51.48198712256647, 54.25755039338143, 51.60289810549829, 46.55474101343463, 30.16086539914531, 21.551823769846273, 8.095609257298133, 5.653167982255259, 5.041580257877227, 7.748806034365009, 9.857869378982052, 11.229172156703088, 14.817217146196674, 14.168770909309389, 9.718930202145732, 5.765629199243361, 1.2427273608984486, 0.47724259296251886, 1.7778604910258324, 6.995873249346211, 24.536045366717925, 32.29223624352486, 42.255478136001095, 31.849732091349942, 40.44017384129186, 37.32865564284786, 15.705205471284929, 2.90208863635217, 0.17979554982194978, 0.14022335470203431, 0.11371766247095601, 0.15731580285055025, 0.12288509192125452, 0.19905493895132698, 0.17990673982327987, 0.1461317771745305, 0.17117266332910908, 0.1807409942510628, 0.09451607467546579, 0.11915505578320836, 0.13792899797760672, 0.07289326599528713, 0.14361110275551198, 0.08980090309294964, 0.12852167575469903, 0.10389055470905958, 0.188053242201286, 0.1830041558752137, 0.1341493040203087, 0.0822324830017263, 0.12362867218231964, 0.12783209703141643, 0.13894650063687755, 0.18498371174979597, 0.10084059780403491, 0.10077956357910749], [0.03931381281525378, 0.005670705389591956, 0.013351986511430193, 0.0077145671633432715, 0.03825393400245136, 0.05080011763399647, 0.052263567734870224, 0.0866188343253828, 0.04497322989928146, 0.026275515368568803, 0.057419155604175987, 0.020022464412895423, 0.008630781028900416, 0.08306884417130102, 0.009989924428443755, 0.02691416265142541, 0.025336243692905675, 0.09070919991861429, 0.08065968151054076, 0.04482634020067992, 0.023728998888644482, 0.046921311051494656, 0.03468011851392446, 0.04923731359022279, 0.02032679092559603, 0.06825068124359654, 0.058237096189611384, 0.03725864789298466, 0.03194405464455485, 0.06614425354787419, 0.04307854890583023, 0.03022314345974836, 0.07753254890802407, 0.10616701561957599, 0.04386862304301993, 2.4822452424034, 9.403859934499188, 22.895855288351736, 27.112344388038885, 19.198858622581728, 20.986474906244588, 13.800018102891984, 13.975467681884767, 7.351469445613123, 0.6007925649323772, 0.18617503975908603, 0.496114433532761, 1.8582742276691624, 2.830027096694516, 3.9881500361427187, 6.351346931149883, 7.109748971077704, 5.16821397889045, 4.212422582410997, 4.330153503725606, 1.7981956514620014, 3.0948500863967405, 1.325986531953658, 0.9018346595187342, 5.035070594279997, 11.141879808518196, 20.87976290333656, 37.28588611848893, 48.80534602749733, 53.559709748914166, 56.7560492023345, 56.9724149857798, 54.18555921123874, 52.138195730024776, 49.41786727597637, 50.75715272657333, 52.095324224041356, 55.10031477097542, 55.11294088056011, 51.9467919103561, 54.91086036928239, 54.090916341350926, 53.529754607908195, 51.226307422884055, 48.48408037616361, 43.24858303992979, 42.06686312152494, 39.88591155698223, 40.10123398996169, 41.602042644254624, 45.92897392088368, 51.028184583110196, 54.46038007736207, 54.41343715113979, 52.570531137527965, 40.14458010273595, 53.50453769007037, 54.54313816562776, 51.39531843123898, 45.87356651982954, 39.005692466612786, 39.07365929695868, 38.795727991288715, 43.0060903487667, 46.41571652504706, 48.451787502534934, 48.19366416623516, 45.91225285683909, 43.830341139147365, 38.706497992238695, 39.15016120479953, 37.03900037273284, 42.36479459270355, 48.60896864245015, 49.84866903674219, 52.42211649494787, 50.383892136235396, 47.687890221995694, 50.937369946510564, 52.829803728288226, 51.41786421498945, 48.02201340275426, 46.937874209496286, 46.233036056641616, 48.038797224721606, 48.78697756798037, 52.41520920107442, 44.294957653168716, 35.91749275884321, 18.613605691540627, 10.311298312679416, 1.7563310914462613, 1.8154643764418943, 2.466960256138156, 3.909130947243783, 3.732947639880642, 5.6255005636522855, 3.1188167487421348, 5.728590257706181, 3.7048561150027863, 0.9063200736718794, 0.1923240138398063, 0.5798637782854419, 5.0233387850946, 13.264624380296278, 22.857119921715032, 29.608352491932532, 24.811562453546834, 22.114407362476474, 30.219257723900583, 18.15051497951631, 3.6891967875342218, 0.10016099354552646, 0.07973459969845512, 0.02466004661044046, 0.050893101555806015, 0.04187480644172719, 0.018857491743420402, 0.0812553301934273, 0.049245181313205155, 0.025278771776826154, 0.04562726980375667, 0.023820613428289374, 0.046039712389991175, 0.039031923102635535, 0.021912152428300153, 0.036699618212878704, 0.029439787913654602, 0.046166971085533026, 0.047610192634766145, 0.06627126326484066, 0.028577155673936493, 0.06284713752627855, 0.043945641692487464, 0.05939946224492404, 0.03674642618505224, 0.015716016059741378, 0.06403024541214108, 0.10864309606052215, 0.03847627953115491, 0.03783750009813136, 0.05337880789152077, 0.029245500355177832, 0.03275707311507675, 0.05067951624251662, 0.036168443489699595, 0.019404403827784043, 0.045601797380274346, 0.08038777392357588, 0.037105874639124646, 0.04276357951664156, 0.10260292944768745, 0.13114389512808095, 0.03197814747240515, 0.004771967904807459, 0.0644742967861314, 0.04801081831476862, 0.025776083498532255, 0.09807489782331452, 0.09914159098820341, 0.011861341246854396, 0.01728753243843394, 0.08171251614487941, 0.048801068652180896, 0.020760354555902943, 0.03508404220244096, 0.03395824918463346, 0.05548153155212922, 0.015105227564251231, 0.033584122485931844, 0.14433485666109672, 0.08021108340471983, 0.002228985963043787, 0.06000144264450478, 0.04750381366560056, 0.1526694183027552, 4.028621787025083, 13.400862024676416, 30.088838915671076, 34.96891460111065, 21.141310468796764, 18.7870587841157, 20.442359793570734, 19.129326766537083, 6.790294964467326, 0.5855202650831592, 0.19057711886782802, 0.43806948368587806, 1.3232881864232402, 2.256214248557245, 5.838700504072252, 10.614429866113971, 9.408680527440964, 9.299918105525355, 6.1779659121267265, 4.5967506304863965, 4.657645427411603, 4.8783714155997, 2.885872087171001, 2.1473020411306813, 7.592269143750591, 14.578981207263086, 25.471614983774003, 39.49957378448979, 50.35828298138034, 56.10761081018756, 57.55356903999083, 57.46928122735793, 56.125536041875044, 53.768548503998794, 52.25344673279793, 51.62206280616022, 54.9911081406378, 56.60311991168607, 54.37813581958894, 52.87264385531026, 54.39681414634951, 57.35297902937859, 54.46455347922541, 52.40222223343388, 50.250519783266135, 44.301166765151486, 43.889976855247255, 41.89979368640531, 42.91374991017003, 44.03936032325991, 49.32322048371839, 54.2269794402584, 54.04833116839009, 57.62069648311984, 53.39879843496507, 43.286959509695734, 54.98078446234427, 55.64166461267779, 52.70907709675451, 47.999381326860004, 40.83748640552644, 40.77297126093219, 39.8059344291687, 43.860504165772475, 46.54044789652671, 48.68339953884002, 48.88411898766795, 47.03385068524269, 45.07950229029502, 41.12507458656065, 39.852477273633404, 38.32476115995838, 43.63693691069081, 50.707938748021284, 50.74677021272721, 53.96775784031038, 51.02838854635916, 48.38899035607615, 52.18264795118763, 53.10504821039016, 51.812999863778394, 49.74906436858639, 48.75154679821384, 48.807864189147956, 49.39276802924372, 49.82078882955736, 52.959041903095866, 47.559699320024066, 36.63639653113581, 20.681491013496153, 10.792255420838634, 3.1827518728471573, 3.058213678098494, 5.4469390742240416, 5.8759404670807625, 5.659032415959143, 7.47963632306745, 7.039033539833562, 6.61651925694558, 1.538081344577574, 0.7167443849386708, 0.27285149921813323, 0.3544324167793797, 4.793668322024807, 14.606642742310802, 22.41574541214974, 31.23630673654618, 32.304311260100334, 23.209142838754964, 33.43273401260376, 23.249545212714906, 5.295593440532684, 0.22769401751218304, 0.09714737219075043, 0.02828972523040589, 0.0297373651917423, 0.052605020783601276, 0.020456116143313628, 0.07647037566188844, 0.055181002920313235, 0.07491756906552662, 0.12028495120185038, 0.03759714001188836, 0.0418627099134028, 0.03920021729784147, 0.016197199715421568, 0.013310293133761133, 0.057647216148794665, 0.05277193985098312, 0.02396179768707483, 0.03420194941422632, 0.016648722361893426, 0.023963833565733606, 0.009066642922980171, 0.032128034490010435, 0.028656983950866327, 0.042954331579347776, 0.05913786620141999, 0.03285632363610691, 0.028475331097480752, 0.040268795039024086, 0.12908610635467116, 0.14540474441262985, 0.11109533584526471, 0.1240743974584245, 0.17283063081483688, 0.2150256964828699, 0.11906633514069742, 0.1609065795257207, 0.094070004659795, 0.11810933044480702, 0.23308692409867243, 0.33115713346389036, 0.19165296678341207, 0.17330160634892602, 0.1750908046960831, 0.23434738388224957, 0.1407872413795802, 0.29726298285588143, 0.24636322782645304, 0.11678605911231811, 0.1125246107638363, 0.20695068542995762, 0.08876662310813704, 0.13180078487963448, 0.15742489377096777, 0.11691601826779305, 0.1360293603952854, 0.09846895046892667, 0.12717788858759788, 0.18856169475663095, 0.11924133260524082, 0.1950320120780699, 0.09479935100722699, 0.2491714610087295, 0.23113549897266975, 5.5215013700146836, 16.096181446506133, 34.05605746853736, 43.3111644560291, 29.933946478751402, 31.54225160998683, 22.862913262459543, 20.063270561156735, 9.3031491579548, 0.9420292091465766, 0.6356410465894208, 1.4270038662418243, 5.594152981235135, 11.369355705476577, 12.622147990811257, 16.472589738907352, 18.24648557170745, 13.636815144169717, 11.538732474850072, 11.551393885766307, 6.62782843074491, 9.036232848321239, 3.6330027061124004, 2.315071129029797, 7.976057375631026, 14.306963855220427, 22.266744375228885, 39.62055929245488, 49.88970879585513, 55.480368906451815, 58.70795396066482, 59.665259392030784, 58.971439176990145, 57.3901121077999, 53.847580340600786, 55.26829027360486, 58.43256042849634, 58.42532365552841, 57.782823731822354, 52.49824577762235, 53.782080681093284, 58.00812859689036, 56.011810841098914, 53.62187931614538, 52.43134190959316, 45.366874740969756, 44.62897492993263, 43.71653356859761, 44.64462126455, 46.13738121524934, 51.291610963882945, 56.51651790065151, 57.02948154941682, 59.58841623798494, 52.911424329203946, 46.05618030794206, 58.396839403337054, 58.386158789357836, 55.4579564832872, 49.182026924625525, 41.9763897311303, 43.28632800809799, 41.35294075935118, 46.59456483779415, 50.25299479884487, 51.901798402109456, 53.188653530613074, 50.663972900759795, 48.24152492707776, 41.851721117573405, 43.530985847596206, 40.20526309167185, 44.8233401390814, 52.381088502945445, 53.64213835808539, 55.49150843774119, 51.340801408213956, 49.243639515292266, 52.62717800755655, 55.12495510039791, 55.557831794984885, 52.31989952825731, 50.29622324051396, 48.926033435329316, 51.181827745129986, 51.67010007366058, 55.49814116570258, 47.87766233567269, 38.1496940120574, 20.496178634705085, 13.177044718496262, 2.896363937085675, 4.190086155168472, 6.00546105254081, 9.836794484046198, 10.411533501840408, 12.238528420848231, 6.923788420615658, 11.356586429380602, 8.64400367582998, 2.976134405020745, 0.6334589830329341, 0.9042200734538417, 6.711598980811335, 16.72376459644687, 29.492207188760084, 40.27330052468085, 33.34508865110336, 30.421622607015795, 40.474247470978774, 26.137274542162498, 5.651232782871493, 0.3835297844582989, 0.1860042021519715, 0.1670623258236916, 0.09882452251810221, 0.08388836672830005, 0.13840539741419977, 0.16852098787503858, 0.19820251291798008, 0.20619694684301654, 0.25141294234462325, 0.18155370628641498, 0.15816013899541673, 0.2046110988744805, 0.1577892145442386, 0.13357067781109966, 0.16610116127037233, 0.13010800635862735, 0.14103108716587867, 0.13950801244185818, 0.09052556098228501, 0.17236769920395267, 0.14210731812542485, 0.1228439070344452, 0.11259267767590862, 0.12384931316539166, 0.1814510505045614, 0.1614847307604167, 0.09608169026192158, 0.12516989552926633], [0.028459576499317924, 0.06923924110108806, 0.048502026230938015, 0.05433246861362169, 0.03204685981355367, 0.013348616682173265, 0.046161133495550004, 0.007797578056793541, 0.06360698566441575, 0.015635221554417045, 0.04823541614196954, 0.10476643069376869, 0.01921964831830513, 0.0697462763937731, 0.024043399457549377, 0.11466398790118196, 0.0432256760916883, 0.072673000395298, 0.04167146372398542, 0.03003907551418149, 0.023911942600182468, 0.05478610374754476, 0.05331886151144582, 0.0395389469040017, 0.05344128236174584, 0.04888796217499241, 0.07932003121823072, 0.03871277853425953, 0.02815815345985034, 0.03090236467429467, 0.07756640999427727, 0.03090187820846275, 0.05047284870318348, 0.08729645441616736, 0.1362674452003933, 0.5482421202525016, 3.9909322223355694, 16.79672460402212, 29.68802759724279, 27.769441412341212, 12.603066640515483, 10.416262899675678, 12.514749573123071, 15.894736359196326, 5.1363628622024295, 0.5398049794377819, 0.07451803889125586, 0.9886928503551792, 1.54331341866524, 6.292929601284766, 6.705095200769364, 5.480910722286471, 8.151544217140444, 2.8308713868741067, 3.7354564859021098, 3.752110379357492, 2.7389261270723035, 1.7887943430292992, 1.5239719661974138, 2.7875546918761347, 4.6788428964153415, 13.152102366570505, 24.98236402388542, 37.97405812048143, 48.77552424707721, 56.275382349568034, 57.14656429906046, 55.322822986110566, 54.45645770718975, 53.33145133910641, 52.06135257597893, 55.04453082238474, 53.966385010750066, 57.51161144625757, 53.52220404532648, 53.658031802023615, 56.57292550609958, 55.95377152965915, 51.98604699104063, 49.49509874466927, 42.52198357735911, 43.49886948062528, 42.13728143322853, 43.13986278349354, 40.62341913100212, 45.94651868266445, 51.15122541304558, 54.50360851903116, 55.423835785158225, 56.24694124344857, 42.57867751582977, 51.97661369077621, 54.25105494837607, 50.956322839183194, 46.40833854675294, 39.25781457654892, 41.297192112092056, 44.81061597024241, 49.848233653653054, 52.02329381819695, 52.764182475305375, 49.99044702899072, 50.83568642216345, 49.54064922948038, 44.22201725744432, 38.77266837704567, 38.674354168676565, 39.938494851512296, 47.619338958494126, 49.5810967106973, 49.96893282859556, 53.06521654129029, 48.25807340683476, 50.713324162267874, 51.048937843691924, 50.4546909178457, 49.552443796588534, 49.7347241832364, 50.07414648609777, 49.71582228137601, 49.813732485617365, 46.20814077315792, 37.315884405566806, 23.44174527352856, 10.045090971454497, 2.472190736762939, 1.1915936272951866, 1.8308300164438065, 3.6912648572075755, 3.678308042787737, 3.3426610212172236, 7.058206085235843, 9.700036145025685, 5.055779728197283, 1.4146360202181725, 0.5866089066670788, 0.2814106318739153, 3.0987275944602106, 8.789883486686215, 20.08273728432194, 36.54660955552132, 25.04485130310059, 17.014910367227372, 30.33298880823197, 30.74102709370275, 9.415159302373088, 0.5571826114769906, 0.04926621042672665, 0.010956395098248558, 0.04692718694587389, 0.022274646081871564, 0.12662915512919426, 0.04481619719656245, 0.005840496807884906, 0.06571859211450623, 0.016533703836161765, 0.059039814607991334, 0.026681484511843132, 0.06710625313703092, 0.013397802399741787, 0.07540310793105634, 0.08522296084030982, 0.06412037182599306, 0.020956300694735783, 0.08312373437107572, 0.017688937612899372, 0.04408010161451755, 0.08836379109491264, 0.09882688972978823, 0.058567529063551664, 0.029097775620738828, 0.05666726328913243, 0.055742721569033406, 0.052072153006109505, 0.04656041086080574, 0.03032234226984363, 0.07999904558903749, 0.05560583314828335, 0.057388144365001115, 0.010613595649990584, 0.034125811765871705, 0.01596897829233879, 0.05208902226220216, 0.05101004104700781, 0.01171925396192819, 0.08305223538510262, 0.05660877630655324, 0.053581330895183556, 0.03107578016727442, 0.0334121395773705, 0.04528639132096883, 0.040032073870421424, 0.08102072342749565, 0.041973126165929346, 0.046888687197239175, 0.037868384932798725, 0.09120609220718184, 0.03077756895142938, 0.06214803633009715, 0.020510088952799, 0.0187646227347995, 0.06846011436033635, 0.03663911258861904, 0.06304822794552292, 0.029041722882539037, 0.08087594047068589, 0.00482637929962948, 0.016686770118652813, 0.020284901237896374, 0.053317842614506526, 0.07278818171471357, 1.2012183882536427, 7.604737868232112, 21.953478397861605, 35.49000147850283, 31.78382254415943, 18.480035258877663, 12.710574884568492, 21.042376525940437, 21.43272884430424, 5.045681586188655, 0.5521081063535906, 0.11672114082161458, 0.7922447400708353, 1.3872279683428428, 5.128574996225296, 7.644896074648827, 8.588708062325756, 9.865187541131052, 6.079721325828183, 5.18754538028471, 5.145445110336428, 2.93755887496856, 2.9926164496329526, 2.7557754035918944, 2.9884781039530233, 6.756217902706516, 15.951465598998533, 28.216730856126357, 40.33749795729115, 49.98854075708697, 57.172828489734286, 58.492290281480365, 57.33907422711773, 56.271012829196074, 54.30557589377127, 53.94468253658664, 56.43255956711308, 56.89379892041607, 56.989732250090576, 53.62508781494633, 53.58410689138598, 57.917262969478486, 55.852225288268066, 53.65169325182515, 50.17932091989825, 44.335593408153905, 44.798389942415305, 44.26161750670403, 44.4367709467488, 42.91729965517598, 47.153220176696784, 53.728952177109264, 56.23173029192033, 56.39793680560205, 55.45026471537929, 45.3716992562817, 54.65549053684358, 55.728039126242365, 53.76144509161673, 48.64970637905983, 41.431278336432676, 41.68553813811272, 46.52955547455819, 51.79892247722995, 53.435837376502256, 54.90914237114691, 51.184024272426484, 52.68311492858395, 50.72492261086741, 45.46679319873933, 39.6651291847229, 39.88405235352055, 41.78406023210095, 48.6933349024865, 51.62317283691899, 52.43647629214872, 53.667284673260106, 49.04084121027301, 50.921158790588386, 51.421582621912805, 52.83131384080457, 50.75966304348361, 50.66738928517988, 51.93564845669655, 50.144270620038434, 52.30616338791386, 50.16178008048765, 40.54412449559858, 25.683224893385365, 11.442978593610949, 2.8658177439243566, 2.215641986939215, 2.672592228458774, 6.032342035924235, 8.310104070171233, 8.940318149905051, 7.710467807708248, 6.507872544950055, 4.349861452656408, 0.5521194444548699, 0.2588664109428083, 0.2181381891451536, 3.005042273190714, 11.147224037877976, 22.66100141309923, 36.53004538628363, 31.910811239673247, 20.089095446371264, 31.55238897569718, 35.2119799583189, 11.480175410547565, 0.9471292709631305, 0.08542275657096217, 0.018859600400431983, 0.03982792676035916, 0.0522351956685945, 0.035379767462971716, 0.032392606785100315, 0.08871896477836756, 0.023461954044778983, 0.04440683045334393, 0.0892946185664304, 0.06186784733267081, 0.020087968760861025, 0.035807485842416366, 0.022963366786678954, 0.04144518816423032, 0.013630758246196615, 0.038531813244785995, 0.0767189635324382, 0.045523131641769604, 0.08333421702827178, 0.03598226497190134, 0.06795516282680535, 0.03565890308950217, 0.020370752881130865, 0.02159203109782069, 0.018516023372930866, 0.02203820070492164, 0.03331868451148753, 0.028350721150937102, 0.09540227752539421, 0.16698872009592672, 0.11486813501124421, 0.08851615832217279, 0.20179621604902132, 0.07816256429519385, 0.1756628578709018, 0.17747857818199744, 0.13264737332299834, 0.12384130754658293, 0.16129319345758808, 0.22697758740715443, 0.12191266587544834, 0.15837862727142152, 0.13087073881779948, 0.14387302821682346, 0.12468999507085932, 0.16482562487644536, 0.1545576871402802, 0.1676555689904959, 0.23409331848304119, 0.11927206805276296, 0.16313911295465885, 0.12365445870185092, 0.08824115573999383, 0.15236528139681588, 0.10753762352490619, 0.1415803722075878, 0.11634273935229549, 0.17186925175689882, 0.13078577966699678, 0.12661979353475955, 0.1403356019046999, 0.19910392261320548, 0.2861363524871488, 1.0496559210361973, 8.589143445414882, 26.310207920689738, 44.293627969680294, 41.284648372280984, 23.82681808164043, 17.9344198396129, 21.47855389502741, 21.020860364360196, 7.548505298552975, 0.9312320885158355, 0.3373920166444394, 1.8326113853723773, 5.860521629933388, 15.295481547232598, 18.187008711599535, 17.107972521935743, 20.564055250537013, 10.678759678717583, 9.645605414144455, 12.029039532907548, 5.569472937814651, 3.87546377316598, 4.08140512243394, 4.8792166863718345, 6.866647331945359, 15.145455791104226, 27.191486051005704, 39.99377281435075, 49.644474367941584, 57.38218107531148, 60.70628389235466, 59.35636097385038, 58.543704709699085, 57.234339098776545, 56.01098322099256, 59.81110095977784, 59.064505254068685, 59.062379329435295, 54.69870328903199, 54.139392914310584, 59.410175892614554, 58.801553480086795, 55.655302693766934, 54.29135337952645, 45.80802371425014, 47.54732031976023, 46.31340542147237, 46.2840582478431, 45.40680054695376, 50.45605590266567, 56.873728152244325, 58.01714220354634, 59.40959145945888, 55.6115564992351, 48.530066244063846, 58.85938098353725, 57.61821362280077, 55.369142255475445, 50.553279692126864, 43.28208400357155, 45.48292590725807, 49.336580076525294, 54.011315761073945, 56.10881497783046, 58.43398424886889, 53.43662185053672, 55.318116141903786, 53.33784088011711, 48.22010094119657, 41.05004748990459, 41.42503000074818, 43.91493097428353, 50.62001882060882, 53.76304149627686, 55.4592743996651, 55.45546577822778, 48.248224335332075, 52.17949828793926, 52.637262421269575, 54.09110069274903, 52.658874680919034, 53.79589526884018, 54.611787488383634, 53.11889025472826, 52.53455908067765, 49.15715909773304, 39.56024892868535, 25.937465083214548, 11.937454150569055, 3.636085443919705, 3.199710975731573, 4.206616984259698, 8.325840619302566, 10.284936062751278, 12.048309156971595, 15.476314579286884, 20.288665640738703, 10.423393768648948, 3.0888079202944234, 1.3499437560958247, 0.6288816996159092, 4.125505310873832, 11.94471053538784, 28.036862727134462, 46.64031144111387, 32.67359848945372, 24.985170479743715, 40.81980436078964, 39.72046206074376, 12.015306334341727, 0.9443926823235328, 0.19791170594192323, 0.13257197494949066, 0.2529688669188369, 0.1227840219414042, 0.27397694366593517, 0.1506228450565569, 0.2532350211854904, 0.17815345567801308, 0.1017467495835116, 0.15513582305321771, 0.1063810146203445, 0.2093203332755835, 0.09279871239296852, 0.13083044259298232, 0.17818432902136158, 0.1290527355646895, 0.06823653926051433, 0.1974214403139007, 0.09339328855276109, 0.10330376966345696, 0.1640475859805461, 0.21755668244534926, 0.13001933934227114, 0.15813200824683712, 0.13862449856054399, 0.17898751092293572, 0.10715139263700094, 0.13139843550180236, 0.2394896111781559], [0.0036828063387093287, 0.01803723948767349, 0.015597271473868, 0.023243151672725237, 0.05707120612984704, 0.03139360706442066, 0.05976444951468899, 0.04770644392157274, 0.057195672434904886, 0.05487644466601553, 0.040391196737126, 0.00971000643462063, 0.03638815750638324, 0.0724905182517344, 0.006267693289931143, 0.03103972998477759, 0.031376393068762075, 0.03310002003526015, 0.05471633612028053, 0.05710112952416944, 0.08346572368135376, 0.05469750567910172, 0.03812742990351493, 0.03942283095731851, 0.037369355258922425, 0.029998988048323703, 0.04316755683131276, 0.07699588133442788, 0.08359343053833132, 0.04575011583285467, 0.0418009823789039, 0.05965917371213437, 0.08588296856971518, 0.02807101670412287, 0.06890426149531718, 0.17428635108855464, 2.5763620243918512, 9.868055774319558, 20.87462655959591, 29.608630980214766, 18.504399061203003, 21.87277759275129, 20.1081326700026, 16.820341194829634, 11.991229845631509, 5.5108075180361356, 0.2807400597920341, 0.7802581606853394, 0.34648480614827526, 1.7970489710569384, 7.928594245064644, 7.576406098181202, 8.310638493107211, 4.208244277584938, 3.036975269356082, 2.221759903815485, 2.7170638163243575, 2.840534881238015, 1.2275566136644733, 1.8968205850931907, 2.7886441301914955, 7.64375368433614, 16.228949754468857, 25.3732439010374, 37.72672130215553, 51.00076721560571, 57.87709005417363, 56.89618372148084, 56.67156527119299, 53.79442045765539, 54.3692006603364, 55.76203430852583, 57.73422556538736, 54.01481059289748, 55.0483629780431, 53.32371250275643, 56.01104990128548, 54.99468926460513, 53.96785589956469, 50.08130481166225, 44.28523409751154, 45.236322572154386, 43.227770943795484, 43.9219912405937, 44.79351051392094, 49.331606511146795, 53.47746941351122, 55.9687981297893, 56.12401023987801, 55.23624058692686, 42.82436301631313, 52.9580730776633, 54.49905072489093, 50.621097472406205, 45.365148898093935, 43.0332370727293, 47.16096293541693, 49.576244738794145, 52.66996714376634, 51.781797409057624, 53.48472972070017, 53.48901294892835, 51.211849566428896, 49.47853849780176, 49.644650874599336, 45.44523585227228, 41.62734193186606, 39.554671318300315, 44.54247490052254, 49.01218437379407, 48.64790601115073, 52.631488692375925, 52.315533930255526, 50.48617186084871, 50.50098273061937, 52.48787895325692, 53.144154241008145, 50.58001848959154, 50.04809018104307, 50.61917551102177, 46.05789438370736, 36.2877841149607, 25.339868453241166, 12.126447673766846, 2.491066898069074, 0.4927060777141202, 2.343107495577105, 2.8207153899054376, 5.197595963554998, 7.43137106780083, 5.560754979810407, 4.280583570080419, 4.563579636235391, 3.1890345292706646, 0.6481918344093908, 0.25177225290286925, 1.70671274104426, 9.522639109242348, 27.648038171952773, 30.700361920941262, 31.17554530020683, 26.089782484116096, 27.80358760587631, 31.759097883778235, 16.380279698679526, 2.301792189959557, 0.11026840521803788, 0.08160864228322622, 0.030477812153197108, 0.07330873079838292, 0.078016800745841, 0.06355628596558686, 0.09430191479623319, 0.05512941838993181, 0.005124247691128403, 0.055790356916165164, 0.06467619159769628, 0.0812383613459045, 0.06988258641814032, 0.013658693642355503, 0.05616298208253519, 0.030696488120743347, 0.08948913595128445, 0.055631420484954314, 0.07887905568725641, 0.11321677886430295, 0.020939442929961992, 0.018044038518001477, 0.03855706350277028, 0.04464141806707748, 0.01082593702801293, 0.04468222374036428, 0.08118966113655798, 0.017817845312698234, 0.06181641985031386, 0.040733588243564295, 0.04371486536617722, 0.029184379945358926, 0.011427898275395556, 0.009015352378839688, 0.1327124754748037, 0.04608469707290492, 0.04164550483467118, 0.015016343170446495, 0.040237841256443536, 0.043551822703692226, 0.04698089737024519, 0.02131886138100057, 0.04488866528375976, 0.01568033934510764, 0.029348401285167185, 0.04564879304398933, 0.05222252074388727, 0.0181393992275961, 0.027799457687163548, 0.03493342165564818, 0.038765374300701004, 0.05542882470293872, 0.030911529001088876, 0.02582310214488497, 0.02164946853994362, 0.016099937192554918, 0.04330880046191235, 0.07626126430207684, 0.023460094366342794, 0.048148698819380616, 0.042031819992248094, 0.046157674608571876, 0.0439151858670577, 0.09064510900286898, 0.03364635180802115, 0.1583990664972413, 3.920278568421641, 15.679397256143632, 30.219783321503673, 38.20758035106044, 23.117537844565607, 17.298348680619274, 23.073215061618438, 25.857374206666027, 14.63596442053395, 5.000915085115741, 0.2725978934716794, 0.29061438155270397, 0.18706563229282058, 1.7713895608340542, 4.850618195149207, 7.90356707188391, 9.31479859736658, 7.993006427441874, 6.706312116115325, 6.0642260024624495, 4.192353285128071, 4.331188028858555, 2.7576333813128935, 2.1433453502193576, 4.775705827820686, 9.63220267526565, 18.433637542109338, 28.53873979660773, 40.53402831477504, 53.23832642647528, 57.73283312397619, 60.06199536785003, 58.38347588815997, 56.00602926746492, 56.02167952445246, 57.16858448520784, 57.83448134699176, 54.380657903609745, 53.90213266495736, 54.62427239264212, 57.02848134502288, 57.51897765744118, 55.90383191262522, 52.11737186677995, 46.32961657739455, 47.62428898965159, 44.946326055834376, 45.72193945607832, 44.60882179198727, 50.63187614563973, 55.452076850398896, 57.47198374040666, 56.9123125076294, 55.19291800837363, 45.689623048228604, 53.799817639012495, 55.353593980112386, 54.82885537608978, 47.280124541251894, 43.95588051888251, 48.69911255375032, 51.66350264703074, 54.134046723765714, 53.633642504292155, 55.736456532632154, 53.702334973119925, 53.366027032175374, 51.55442937727898, 49.83905530744984, 46.85613985984556, 42.90685830577728, 41.93227483380226, 45.84176786484257, 51.70858636979134, 50.78651558968329, 55.13306656191426, 52.11046849527667, 51.25295600583477, 52.754717796079575, 53.95888936135077, 53.229316742189475, 53.95962676694317, 52.693014990898874, 51.129875952197665, 48.89616458646713, 37.51363462017429, 27.608543826687722, 14.728002836627347, 3.8801500249293546, 1.2658808668774943, 2.5872951409509106, 3.942271297977817, 6.703183535606631, 7.142011446337547, 8.796539748868636, 6.459832825968343, 5.16539232384774, 3.2533699802813993, 0.15864757009811942, 0.10182967860131495, 1.1721987325337626, 8.356153676586768, 22.891889772107525, 34.368270289513376, 37.23224770638251, 23.695116658364576, 26.64314066210101, 35.64912419165335, 20.102608011614894, 3.8152093031714043, 0.28158294036984444, 0.053696822480208455, 0.1117856500129546, 0.008687439934170295, 0.013659555491270318, 0.07391636109640522, 0.07274868222133768, 0.018309034076669527, 0.03462780236957535, 0.03159904503263533, 0.06570870191940377, 0.006422166780178105, 0.06742219545788343, 0.039102081434741136, 0.057972903108044024, 0.02443604633182047, 0.03624469605124286, 0.07026447358751489, 0.0769175871485664, 0.01471467306762333, 0.04868309111184171, 0.049125215774702455, 0.05587608215489215, 0.06776670519743236, 0.11384882438447207, 0.015111008655249834, 0.041182990741705706, 0.006158539646064803, 0.058650442759596536, 0.011586807893529054, 0.06604940420196903, 0.15980606357897484, 0.1854341561275144, 0.11595457026194181, 0.19890454057003223, 0.11233953924308862, 0.20295012832408954, 0.11427837754449538, 0.15132312602814169, 0.14054221581787835, 0.14001526990004126, 0.11349365070101716, 0.13519060137050767, 0.12024192004314355, 0.1872581042229168, 0.11347551739984944, 0.09703168525330483, 0.19300452974294463, 0.233006990484653, 0.09397926920604321, 0.1810570055198285, 0.15711430640470597, 0.20960576231441191, 0.10821420173611372, 0.13247028443842165, 0.09148114841551551, 0.16191105869027878, 0.23345221014272785, 0.17102572766523208, 0.18295066761634043, 0.15377275345306243, 0.17951831792391118, 0.13225440086135942, 0.1917689678169066, 0.13769434524639962, 0.28324440121650696, 4.020652756575616, 17.48222939429745, 33.96939269958004, 45.32480732087166, 31.581587099259902, 31.886959306655395, 29.953330832142985, 24.984168314164688, 17.67568265238116, 6.620151862021416, 0.8552438273064552, 1.4686026856783898, 1.461969344846664, 7.036517339368021, 17.42414105323053, 15.14419572968637, 17.836629267661802, 13.206714507072205, 11.262142619779034, 6.721469135053697, 8.495556673695965, 6.091662491521528, 3.601049362651764, 4.071530310376998, 4.245056211948395, 9.455023331026878, 18.625974885879025, 26.466286874586537, 42.12636939940914, 53.52281985744354, 61.307402810742786, 61.64961391879667, 62.70857934028872, 58.675492425118726, 59.394717831765455, 58.51960958973054, 60.40001346218971, 55.507092014435806, 55.997741299290816, 52.87821754332512, 59.08907498082807, 57.929026157625266, 58.95388264809886, 54.159106746796645, 49.254218147647, 50.08109692604312, 46.011579036712654, 47.734366386167466, 49.17489213328208, 53.41471933549451, 58.818525575822406, 59.7664055516643, 59.71394777297974, 57.81126876031199, 50.667393207550056, 56.4468252274298, 59.155727817166245, 57.61522085435929, 49.81694490678849, 46.18080185305688, 52.908200140922304, 54.40726726285873, 56.4140106785682, 56.074082389954604, 57.59955098552089, 57.765098541013664, 55.567425912426366, 52.3867759396953, 53.35141228091333, 49.49689911257837, 45.791439933161584, 45.31052597107426, 49.19912061383648, 53.11543464660645, 51.70565243690245, 56.057961448546386, 53.29757775029829, 51.01022405009116, 52.1604081123106, 55.26154379690848, 56.63550299982871, 54.8768965659603, 53.0618001568702, 52.95236995143276, 49.605999838921335, 38.31918747194352, 27.777747031181093, 14.139915993136746, 3.402018249034882, 1.078433492972005, 4.476309351382717, 7.062916851812794, 10.518174902085336, 13.716926613161641, 12.941133764482315, 12.925878686289634, 11.338434680815666, 5.595653778122318, 1.7100102286184988, 0.5515993013978004, 2.2936986242571185, 11.596673727035524, 32.09616480335113, 37.57724369725874, 40.46135464022237, 34.896821437343476, 37.47868237956878, 41.166157491745494, 22.011103899248187, 3.612822847020242, 0.33470565272915753, 0.24728357521516664, 0.22835314424047548, 0.14178269602839025, 0.2589425294389648, 0.1628497002586242, 0.17616682115101046, 0.1767712338797508, 0.0977781919702407, 0.15375783006029745, 0.15023577147193495, 0.22660379778713952, 0.16367466970076486, 0.15716802448995654, 0.12628962496115317, 0.11523099255657966, 0.2651805689017619, 0.14930829946552554, 0.17407347057615558, 0.2671563709455152, 0.1726630414205213, 0.16506735626007282, 0.2145937607894021, 0.1595678102345236, 0.23896059682292325, 0.0934178110272173, 0.17893071316422957, 0.07643082254235783, 0.156231650541867, 0.09144860500049207], [0.05239818087448517, 0.037231551363102855, 0.04847241310222496, 0.021867257760717504, 0.035297914798701965, 0.040154854782045855, 0.0038109050975406486, 0.043451040006813504, 0.006922792310961673, 0.027080811672813954, 0.06554538729570566, 0.05092249251902104, 0.05487073731097964, 0.011014428173732615, 0.08681301463155017, 0.03498257768730964, 0.02863628617037208, 0.08549352011252796, 0.05453107690799141, 0.011553723428909098, 0.032086334409072034, 0.029659643656604236, 0.02690948759986749, 0.03637292384800892, 0.029985206126565897, 0.08297928083207338, 0.021210626563838413, 0.02973802594257699, 0.05792616791422329, 0.008990618272594387, 0.014912907894129955, 0.029967791032827193, 0.03636480714645117, 0.025066417949875037, 0.08556003952699323, 0.06676599518546174, 0.30498288151237274, 4.2012413759385385, 13.830577288904498, 18.889377732430738, 23.171307656072802, 26.196586662723174, 12.85107320354831, 20.025696216091035, 17.403293655764674, 12.744755398842598, 3.7657619435941023, 0.26735457321328504, 0.16008542520144295, 2.1192289023630084, 2.087053454691364, 6.342728503288762, 5.4520209950785485, 6.403447774148757, 3.8522835460401352, 4.5669043352527, 2.1832498283155504, 4.083142242124004, 2.1930515862280324, 1.0698811325334734, 3.041595576270934, 3.8583117386987134, 10.510469405881821, 19.666542430077833, 26.352206699309814, 38.235244827885786, 48.854222682214555, 56.21646442720967, 57.24286633153116, 56.90873530603225, 55.83721045524844, 57.995118095028786, 55.76528987576885, 54.058380280771566, 54.20515145024946, 56.251475503367764, 56.796586898065385, 57.01552183397355, 54.25056072973437, 50.42051922890448, 46.29069882054483, 45.4476991007405, 44.967173453300234, 46.38890712491928, 46.534885975622366, 52.37289467165547, 52.71129715827204, 56.51796133287492, 54.91774020656463, 49.44104063895441, 42.543384029019265, 51.602160699905895, 53.73270980773434, 50.07333063310193, 49.95369442047612, 45.70233544995708, 49.38382894762101, 51.91164747361214, 54.764089199804495, 54.43073088122953, 53.64305227033554, 52.29987190615747, 55.1225349980016, 48.731601545887614, 49.084669774578465, 48.12889014520953, 48.56372018014231, 45.17612987949003, 46.06961834815241, 47.53912648847027, 51.99127551048033, 51.21663485803912, 51.3665400012847, 50.76140065346995, 53.457033864913456, 50.573017058833955, 51.63845046874016, 51.17126480225594, 49.18620817122921, 40.76075307784542, 31.533873427298765, 21.357234985597675, 12.81721334303579, 3.7078228977418717, 0.8454879733823961, 0.6597455434741513, 2.6256698946799, 2.7193177082846245, 5.34965988128416, 7.610075233444092, 8.579876845882787, 5.626162953915135, 2.4907131493091583, 3.5807606577873234, 0.21872456816415634, 1.0452981677747544, 8.426131702238514, 17.9399739157769, 24.933252026957852, 19.133702170464304, 32.266742798589895, 56.08036994934083, 36.06778621673584, 24.909641319705596, 6.536330321142751, 0.34947616498797174, 0.024189411985477614, 0.05580558291366024, 0.05149546499934889, 0.02885965634167435, 0.06422297015125233, 0.04799813189874253, 0.03793811425566673, 0.07171845484164453, 0.04588411993256981, 0.024231634921424335, 0.1037025643933204, 0.08925468240293766, 0.10413771765607019, 0.056714936940660404, 0.08513407165845556, 0.04318484743576377, 0.06066404358153382, 0.06470495053837377, 0.04375267180524046, 0.06853899077302025, 0.044807643824887854, 0.051354830408649105, 0.016707578981896083, 0.013332029921002688, 0.043874422328606735, 0.04406351581095688, 0.033766765507959554, 0.04363262965794533, 0.040445730706015905, 0.038772039265642246, 0.01784260527441098, 0.03167106687361675, 0.04192831002235894, 0.07235970107778426, 0.02238440541400304, 0.030920630125629327, 0.016423634238420956, 0.05292433772176024, 0.03940558248770334, 0.04594263372822635, 0.07971010786751587, 0.028619663977635004, 0.053905665709246556, 0.050884540523252184, 0.00757886617887585, 0.04840880865231157, 0.03961547908763732, 0.055356475359369675, 0.030071950262232177, 0.02610337158154336, 0.07775089928820249, 0.05619696574285627, 0.021582728875200116, 0.019068638981890776, 0.04024479350435638, 0.06368979593859085, 0.0441751807868, 0.08531253950129594, 0.07433652967935608, 0.049098092431743304, 0.021430292700026787, 0.010075734894452317, 0.04478381849044273, 0.05463479755205974, 0.08177807028856009, 0.10717997537745584, 0.5997316250877996, 7.041136420542195, 20.83019002791374, 28.990418372615693, 31.73284349902984, 29.946943252317368, 14.684600830078127, 21.433175994503884, 27.038754840050977, 13.01499395601211, 3.9086887000068544, 0.7411789125011814, 0.04176488048547218, 0.3239257843984712, 1.2121686651822061, 4.839219787428457, 7.275508334559779, 5.870667330680355, 7.855926944363502, 14.440391121372102, 6.379038374270163, 4.993385114977437, 2.882135048989327, 2.3385403858077143, 3.555371645958193, 3.753367989293991, 10.587443959328438, 20.930941989344937, 28.339226476607788, 41.997896086785104, 51.89200032141901, 57.7342059535365, 57.52245287741385, 57.92043224457772, 57.27603389370827, 57.859604127945445, 56.7077922821045, 54.18816366503316, 54.28586990602555, 56.69139285241404, 56.36808364622055, 57.935682419807684, 56.18682307581748, 52.31767162199944, 47.5131368637085, 46.28034768566009, 46.0025889642777, 47.94509964604532, 46.93142975530317, 52.14088647596298, 54.472492356454175, 58.42493141851118, 55.97539163404896, 52.24858299378426, 44.85333058141893, 53.664342895630874, 55.93472842247256, 52.33066643438032, 50.64971508518342, 48.09639723070207, 51.31643564470353, 52.6982395879684, 55.59327040949176, 56.40085112664008, 55.018619645026426, 54.7633517942121, 55.91953708279518, 51.4560131872854, 51.30558244643673, 51.60988776914535, 49.911517174013206, 46.655996999432965, 46.532752206248624, 49.17416257243003, 53.05097441519461, 53.58741737181141, 52.00419579782794, 51.400739146817116, 52.42628989681121, 51.830258292536584, 53.286920670540106, 54.388271224114206, 50.73277911832256, 43.699467335977864, 35.465490587296024, 24.86655996691796, 15.241870591717383, 5.875477137104158, 1.5467754006385805, 1.588322003522227, 3.3556006752675582, 4.56207932964448, 7.3225252955190605, 9.22277489016133, 10.569814866588963, 4.19349959781093, 1.5449398539720045, 0.07347011488051185, 0.21754273964512735, 0.773802184529843, 8.200492945409591, 22.044294995646325, 36.43097416047127, 22.75080603937949, 36.7360011992916, 54.08575450220416, 37.38904053165067, 31.123181658406413, 9.730909120651985, 0.6942683458328248, 0.012998826681606233, 0.11199673021873159, 0.029800885371984016, 0.048387201142407237, 0.07597565906302584, 0.060799441961271156, 0.04264781980084316, 0.020625502013811664, 0.02893736638549355, 0.028384285378119642, 0.03527026285507506, 0.04159068741324929, 0.041125472860350724, 0.05336559287482693, 0.06479991479746758, 0.06156788560591879, 0.003141537210115442, 0.015838964553099247, 0.019513372174133698, 0.0738831205413707, 0.04385971727090017, 0.09406429730475911, 0.033083146948727875, 0.027777708450993224, 0.03237065453563006, 0.035467101486339685, 0.07233138646810286, 0.024355639658507802, 0.037202359582748146, 0.02690782901951142, 0.1534950159369938, 0.10260721187918417, 0.1642120957014061, 0.14816970894894294, 0.17956557022708078, 0.1196482785106186, 0.08203896919205304, 0.168435369888621, 0.09499061251840285, 0.14131685328339377, 0.19936339659315927, 0.17264778094906963, 0.11330595915956844, 0.10596070814156726, 0.15057763054726586, 0.14434905993121286, 0.06140999105428496, 0.11073697523604478, 0.2018376460839664, 0.10519806761294605, 0.25392011829441596, 0.14273100562634009, 0.10006897872494114, 0.14148197587459319, 0.16277151332507211, 0.1674087661048097, 0.12818822066389746, 0.14275967263646666, 0.1867133850652364, 0.18865661305044928, 0.16380490464789255, 0.06442072425758646, 0.10450822075888996, 0.12520271473594252, 0.1803861423245361, 0.2829594471521916, 0.5681567290617574, 7.907309013028299, 23.895512511653287, 33.646573789658085, 37.66211202067714, 40.963292506433305, 23.087270875130933, 30.347085806631274, 26.00542995237535, 16.6291864456669, 5.26275682833887, 0.8118416368961335, 0.19910923926339996, 3.6610746191393946, 6.681938998160824, 13.539614888929552, 16.90845527956563, 14.449689099865576, 11.181188821792604, 15.016066605044951, 7.854286903335203, 10.105017923539686, 6.396680214712697, 2.308757829089319, 6.265197463573949, 5.900645025314824, 13.044358780307155, 22.377492497044226, 28.708321509822724, 41.68812690242645, 52.49623752409413, 59.99366375707812, 59.128824280154326, 59.63565334197014, 60.4397000035932, 60.52328178959509, 58.54220244192309, 54.68431211286976, 53.66401733890657, 56.633047596100845, 56.593200237520286, 61.01394676393079, 58.634005515806145, 56.763693901800345, 50.109894967848255, 47.369727165468284, 48.626105477733, 50.78463285200058, 51.7659039651194, 54.42889521198889, 57.30023491767145, 60.26402096594534, 58.33830195088541, 54.58458585123862, 49.16977344020721, 56.02732773750059, 57.08608919574369, 53.888808373482, 52.66260877732308, 49.57058868100567, 54.10793942789878, 56.596910799703295, 58.24106247194352, 58.41131687164307, 56.26315632174092, 55.44103145599366, 58.35401104342554, 53.35376570301672, 53.924368581464215, 53.200597147787775, 52.42594472823605, 48.860082703252, 50.68240411819951, 52.15406171737179, 56.369460398151034, 54.81558599779683, 53.03661854036393, 49.88484113447128, 53.225257089061124, 51.74956337098153, 54.81312274932862, 55.95597982406617, 51.972934507554584, 44.48204294327767, 34.6888259918459, 22.54806656991282, 14.793612322499676, 5.384961703131276, 1.8836911863857702, 1.326782895672706, 4.807225013932874, 6.292878120176255, 13.067282092186714, 16.129422553123966, 15.573652117483078, 10.628460184220346, 6.549232957824585, 5.5847495890432794, 0.39532425963590223, 1.727312906615196, 11.089672080932125, 21.92762605605587, 32.76970440341581, 28.23141621005151, 39.065857702685946, 62.317907348755874, 47.71781790641047, 34.79901321472661, 10.901589528206857, 0.7384807508318656, 0.09575494610133672, 0.2969452095848899, 0.14901004611484467, 0.14024132712473794, 0.31702799001528376, 0.11301554288835296, 0.11717454229872074, 0.16365182495886282, 0.2328763724935632, 0.1965675280699807, 0.19780692043564013, 0.1823571180143664, 0.15894167125225067, 0.13880428407461415, 0.20372288121331125, 0.13223872670242864, 0.13991134241223335, 0.22256371054437854, 0.1396870778332795, 0.12451488269312729, 0.21049797895454594, 0.23031066742635545, 0.09497401905396292, 0.10191718882490551, 0.10624878784461368, 0.09658293392989906, 0.2056309917280751, 0.1364449477724491, 0.11605654422554279, 0.10081366981349646], [0.08232491917066997, 0.056385496150582075, 0.03286911730444239, 0.07922185705073419, 0.05116171496469648, 0.0760699874691425, 0.04437733606825914, 0.06195590913956685, 0.04867493227544812, 0.023669759224679683, 0.009533245052631584, 0.045843157211258534, 0.04591975068192809, 0.010492324889186892, 0.05642100049543285, 0.030860653102037408, 0.053515815055899085, 0.023026057676742637, 0.022308840416371826, 0.028920625449128212, 0.02653452011966898, 0.058175031576425805, 0.03155533971655513, 0.04744290584518064, 0.026455816076768023, 0.011960194359773831, 0.026073530541672826, 0.04558934845150479, 0.11375606645860019, 0.10249524812905059, 0.022275134462923295, 0.04070222077350463, 0.03438607481638751, 0.05465473499028914, 0.039908270231418075, 0.033681166673740076, 0.06407102810279017, 1.4676260155054832, 8.691492792098753, 13.646054287110607, 25.079248528326712, 28.8350042604631, 19.3107501153023, 18.239121321708925, 14.22138067983812, 24.590935014909316, 11.117388529162254, 3.8797977470582534, 0.5843278032637412, 0.2864100910242527, 1.0948721463641813, 4.138763902648803, 5.27951515490009, 5.201610019130092, 5.161972507353752, 16.713584084664625, 4.419836046234254, 3.063866794109345, 2.8786475716098665, 2.9493561387062077, 1.3155221386301903, 1.6438029490170942, 2.766210133990934, 10.323441970732905, 17.732984558228527, 28.957839165964437, 34.934990021490286, 49.152919015576764, 52.69023795281687, 59.76364420306299, 56.58293147240916, 60.1685034075091, 54.810051533483694, 56.79628487556212, 51.42383798476189, 55.37809310420867, 57.48884600977744, 56.497965089736454, 55.348781231910955, 52.5446827180924, 46.33961077659361, 46.904341866893155, 48.44300923808929, 49.50790136091171, 47.92550348466443, 53.72308823370165, 51.93803325776131, 57.192777664430686, 53.00943259269961, 57.83667002954791, 43.563831775419175, 50.660940908616595, 56.58075063459335, 52.67011227146272, 51.73689411532495, 50.14216822962607, 50.358612460474816, 52.571213629937944, 52.74441765200708, 52.40710950666859, 52.70149123284125, 55.04105560241207, 53.66570788045084, 53.520399755047215, 49.745985308001124, 49.5695923989819, 48.909398663428526, 49.89635329092703, 48.074255451079345, 49.00237844836328, 48.65931226361183, 50.51396185351957, 50.201494078482355, 53.9681932233995, 53.336911278386275, 51.18802901237242, 47.33191943937733, 43.29643203366188, 35.329474556830625, 27.756326967670073, 18.24203956511713, 10.835717243532981, 2.8747815855087775, 0.5796406321948575, 0.5530900472114163, 3.651468489439257, 1.952909375390699, 4.520594871813252, 5.062325673718607, 5.390009793543047, 9.326886361645116, 3.893251967045569, 1.968406292219316, 0.7143905338260436, 0.9612604062403403, 6.314761513663877, 16.72691818206541, 23.785070334711385, 14.67659527255643, 21.520572285498343, 19.717611689721387, 39.1467369756391, 36.51047668149395, 13.224766235197745, 2.714918770136372, 0.25381461266548405, 0.055579606128195604, 0.03288938033003961, 0.012524737957714787, 0.02876216590765023, 0.04158257837257078, 0.06346583779480669, 0.09162302789909225, 0.01042972018401469, 0.021345952165222937, 0.019626366312525446, 0.01748490158558613, 0.020065407471490965, 0.035998260887760314, 0.01744785931922736, 0.008242939441134373, 0.025937092197578282, 0.027331370304548935, 0.028313489277817072, 0.024886119156895627, 0.07655003348425513, 0.11365434530401423, 0.09718563828256824, 0.05079817560110843, 0.09523240518906424, 0.011919859830560464, 0.049226423650379145, 0.010821596182311976, 0.01319851707516899, 0.048277041529335325, 0.01871801969114571, 0.07892394077874, 0.05550188267783773, 0.03736517624929547, 0.00727663156501348, 0.024807551094601234, 0.015128449604455984, 0.13371556035933957, 0.06857059189989682, 0.06119964629291527, 0.05277780042360387, 0.004897341066445675, 0.04333082165929579, 0.01381750271144894, 0.03756243239847883, 0.038354915882190393, 0.0350156458725612, 0.0821750340682845, 0.03365452979661284, 0.0058296959257624565, 0.04951355723483909, 0.03420838455279027, 0.0753501789163678, 0.02437977334334245, 0.010863685052871946, 0.08450129069387914, 0.06492318600536355, 0.0463227627258147, 0.06722915662272323, 0.07004439184862761, 0.01083500367859679, 0.021811591896919474, 0.05933432178872247, 0.015059490199951876, 0.06262971028204888, 0.052296237554401166, 0.07517464519027742, 0.0025424133608823703, 2.3391763000719012, 11.709314392459008, 19.69981001269433, 33.350446608758745, 36.7120433622791, 21.410865552963752, 16.72776737520772, 18.467222836709794, 32.634221815293834, 12.265903622873369, 2.7211063090832006, 0.37103945629731305, 0.05383533117691836, 0.4277902078484336, 1.8413088735072844, 4.66172126031691, 6.049929453480629, 9.45875350506075, 18.260713969507528, 9.33935949879308, 4.802050917379318, 4.344632442920439, 4.411142112747315, 3.3615281120423353, 4.092765532193646, 4.244169756289452, 10.810071806753836, 20.367042441521924, 31.85115395053741, 40.64574918439312, 52.33169801773564, 56.979004567669286, 59.98542677971625, 57.16823931663268, 59.525752452112016, 56.131702007785925, 56.7362412329643, 52.294572784054665, 55.0731013667199, 59.58362702400454, 59.04194378083753, 57.759113004130704, 54.188881458774695, 48.509713065239694, 48.99816190042804, 49.41188173909342, 49.074063685632524, 50.96312030669182, 55.875637915826616, 54.110704698870265, 58.26410247433571, 54.07204581845192, 56.265129273937596, 46.21857035544611, 52.067153761463786, 58.42398220492948, 53.41223255280526, 54.72536756146339, 50.727370169854936, 53.42004591418851, 53.45004027889621, 55.14716748268374, 54.18406478820309, 53.75750703196372, 54.1347998188388, 54.5700103236783, 53.48037981217908, 52.96702392639653, 49.65202100815312, 51.30777897373323, 51.31062661447833, 50.02969426493491, 51.84699896843203, 51.02855720827657, 52.302256707222234, 51.50021045438705, 54.41846170733052, 55.64894845408779, 52.36794071812784, 49.2482679120956, 46.123805892082956, 40.0618730052825, 31.118961188101004, 20.61578150718443, 12.890401828673578, 4.684334214656584, 1.623471220654826, 1.2550183529815366, 3.98958832025528, 4.75539481447589, 6.037272945527108, 7.390435251497454, 8.86372700814278, 7.434758034444625, 2.473254189375908, 0.46340943524433725, 0.09312913377558993, 0.8837651581533494, 5.777405625389469, 19.086421920407204, 26.868476906130393, 18.19162141892218, 24.159572355208862, 26.601618451456872, 48.53557717415595, 41.32271105243314, 16.956965192671746, 3.3416826350073663, 0.18563773633251268, 0.017576962371446916, 0.05625154184658201, 0.05785707444433243, 0.03602705430239439, 0.01098146245274092, 0.04519177180144095, 0.08865442187074693, 0.028394531804106893, 0.05689716244476938, 0.010326293526187299, 0.07269353155166873, 0.010375656401588312, 0.09081469788666695, 0.024330782020584713, 0.02379063832303209, 0.04650163659525495, 0.02290189397641488, 0.04682489888622396, 0.03033999676605867, 0.04803793782728815, 0.037159772755037394, 0.11974705788757532, 0.0727077731261811, 0.09292300249780379, 0.04688981334648786, 0.032607272282362945, 0.016460126836694056, 0.048820527285457625, 0.037096467079414476, 0.016982539429239208, 0.23474244010304254, 0.1332512038249162, 0.09068632453319528, 0.28757662842831305, 0.11756861792697061, 0.26984331708761955, 0.14998893794273177, 0.18676858936106006, 0.12271954032081751, 0.17990016678888954, 0.10486275092848849, 0.17879972745093609, 0.17376580966576455, 0.10882235297392454, 0.1423040188608631, 0.11249757552098845, 0.1538862723616823, 0.11618915404523573, 0.1500651483694392, 0.15701796318734848, 0.060656846185485204, 0.184902751577958, 0.08385226100442872, 0.11579410548532203, 0.21187755008859022, 0.15227541928329777, 0.1660066413422746, 0.15500511313157697, 0.19608432577262003, 0.23407410499790024, 0.147063952960795, 0.13654429405446977, 0.13702855355316593, 0.1588018602060695, 0.1720899004008501, 0.12054787257746344, 0.22028743349496396, 2.193853465780135, 12.85020047618497, 25.733342978262133, 43.09593615993377, 43.125597123176824, 32.19767966578084, 28.90478518701369, 24.505790164393765, 34.33917022520496, 14.895779278970535, 5.139881718543268, 1.3055452223747008, 0.638259964123849, 3.4714292470485937, 10.342077151421579, 13.572077405068184, 13.534845286800017, 14.571566947044866, 29.587503133281587, 15.59563994407654, 7.11319036060764, 8.747063952107585, 6.219074312717685, 4.149027764797211, 5.473985287450976, 4.395055982374377, 12.31695229007352, 20.351141152843354, 32.52150466365199, 39.7502524622025, 55.33188758357879, 59.132876088542325, 62.51159791023501, 59.48193565491707, 61.450177085015085, 57.417435338420255, 56.68341082911338, 53.869918238732126, 56.112094079294515, 59.74319296498453, 61.27939708771245, 59.148349838872115, 58.666988726585146, 49.76620512623941, 50.35805548391035, 52.38049230267925, 52.08686367157967, 52.18900219086678, 58.47424345631754, 56.051548373314645, 59.32773943870299, 53.68455094675864, 57.513529485271825, 47.805231848070704, 54.095215259059785, 59.09628037483462, 56.82299621643559, 58.06776039062008, 53.73595360786685, 54.65493748264929, 55.72936880973078, 56.179449019893525, 55.43404179234659, 56.36811502518193, 58.25889748911704, 55.13237622476394, 54.58671177587202, 54.72865058529762, 53.00258805674892, 53.67812610441639, 53.62687641574491, 52.50034032329437, 53.83755084007017, 52.76418639767555, 54.32199885768276, 51.37876210674163, 54.49399871210898, 55.03649780827185, 53.37333048543623, 49.38887703803278, 45.59531750217561, 38.073207793697236, 29.275437401187038, 20.99383523387294, 12.37074367461666, 4.199748914087973, 1.275503053780525, 1.8750323090822467, 8.65971080718502, 7.2000659569617245, 11.23187368915927, 12.396546986795242, 13.157741754285752, 16.812427813006988, 8.087276672163318, 4.169857511597296, 1.2490076884146661, 2.1164423035037134, 7.338150057100481, 20.762195740976644, 29.989297005438036, 23.313976026350453, 30.98647136842051, 30.061870659551314, 49.02609702079527, 46.639593647372344, 20.042489843983805, 3.626523686032142, 0.3116782141789314, 0.09810334266794306, 0.1539135604135452, 0.13543188842313905, 0.15987442926533763, 0.0955532045073567, 0.08145088945785839, 0.20715808075281883, 0.16238597191629872, 0.1965104545196218, 0.11390705472759663, 0.21885975203927488, 0.07868364197953094, 0.11237333138142863, 0.19451573010413878, 0.12480991847452619, 0.08141246248757647, 0.07108128419326198, 0.1360112653985139, 0.16928627906787783, 0.2301496051011547, 0.16035646710905338, 0.19068872255663719, 0.1360352133070269, 0.21774362322063218, 0.15286595049885013, 0.14014982558306188, 0.12597823320257087, 0.14134571947638067, 0.18268626003015428, 0.11649292322897142], [0.05684029573815004, 0.02821657340973616, 0.04644199665034971, 0.049686827171113224, 0.09296287737426259, 0.03727760090823135, 0.030283742929778756, 0.011961886456476585, 0.0072370669541640155, 0.011576777887380412, 0.06407616472232246, 0.038624406461754156, 0.040731106118689624, 0.058066407969642075, 0.038241274399502624, 0.041992063859417554, 0.04466826944882351, 0.03839854458947817, 0.02627754933200777, 0.05897701838083806, 0.053508372511714704, 0.08347200560233287, 0.026022068585359284, 0.05112877318395242, 0.006177151273380244, 0.02401150147160215, 0.01251718050034176, 0.07953131826774729, 0.030000533630710938, 0.05564745470520951, 0.05019644034966346, 0.011482490658489688, 0.062132343018968264, 0.02481319141694375, 0.19958101152893037, 0.03968985473376609, 0.14939560284537656, 0.13434078003610336, 1.599444129293965, 13.013742719927142, 21.473415590101673, 32.70555403924758, 27.58448204686565, 23.96343227355711, 30.97040730137979, 22.62699838607542, 38.807961863856164, 18.990986731744584, 2.656471041902419, 0.565928700229814, 0.11452413855060456, 0.34817084309554874, 3.240856638839168, 2.6126236011905055, 8.948456087420064, 15.369175038030072, 7.707609380445174, 3.0486654033583984, 1.3480725403754943, 3.517064553114676, 3.83370352368201, 1.4598295693435979, 1.185239019893831, 2.4461454633743536, 7.347597085660504, 14.755865393146394, 24.280167587341804, 32.35432147979736, 45.64678292120657, 52.348038611873505, 57.31507324403333, 57.109564581225, 56.41532467257593, 57.951599397966945, 60.1724140105709, 57.567313025074625, 57.595303058624275, 57.24187397187757, 53.883768127810576, 52.87196528527045, 48.418094342754735, 49.09085535234021, 49.68525917299333, 51.44385383975122, 51.29731016774332, 56.28567464890019, 55.2302707395246, 59.79880432928763, 53.20868507508309, 55.808192760713645, 42.83835803308795, 47.56830500018212, 58.5510277748108, 50.299172862883545, 55.94587579850228, 50.070157435632524, 51.23090051835584, 50.0560918161946, 50.60204652047927, 49.71998391612884, 50.412631342487956, 51.467917580758375, 55.11712997190414, 53.60479347167477, 52.687237339635054, 52.20333060910625, 51.5844355090972, 50.50604258814166, 49.49561649753202, 49.72865235420966, 49.59671558872346, 51.13062904727075, 51.97983787905786, 51.75576463822396, 49.727942405208466, 42.89382426969467, 34.44512521066974, 28.920443288741577, 23.255573895669755, 14.232737902672062, 7.03398839119942, 1.7367773406928586, 0.3491879014238235, 1.7767889485243828, 1.4099844569160094, 2.889543180504153, 2.94982192016417, 3.3289302741327598, 5.050376663284918, 8.927007586725297, 9.120421621107287, 1.8473684451272412, 0.19509296203332563, 0.5848552394778498, 3.460206120244919, 13.505073516599595, 25.521389861260694, 20.4633483963628, 17.177480843759355, 13.27498237932882, 23.634231667364798, 25.926833498862486, 19.033093375544397, 6.488539672666981, 0.545592743062204, 0.07575512533226321, 0.09938521460900385, 0.04108477443937333, 0.031900736202876416, 0.03507441630767238, 0.058290090321773486, 0.03765674931327662, 0.022622218257897807, 0.04675343437420745, 0.07026330147299074, 0.08323310874402524, 0.015557542154114815, 0.05771657008857978, 0.026894972148922183, 0.053752214467573556, 0.049622253619975625, 0.08889523394886525, 0.02443003062639506, 0.04278765382966207, 0.010664054988733223, 0.06599006303135427, 0.03369400247691139, 0.04682113739451574, 0.04551915181500297, 0.05958984275498699, 0.055803667693849535, 0.04825627288570808, 0.017700831127923825, 0.02788231201139429, 0.033561017274135546, 0.0591686514446572, 0.03309015665323504, 0.05555555862825244, 0.06995004812075246, 0.18256998320500697, 0.09884851639189067, 0.04489783918665302, 0.04212306489446952, 0.01645161176941568, 0.031000960190149567, 0.003955105588125486, 0.015186780496620604, 0.031836915333124424, 0.07516210433095694, 0.04367933037780947, 0.025883240046940988, 0.018777567705500032, 0.006014562517990389, 0.02658005255544859, 0.023910211241473595, 0.02304354937927377, 0.05401297164480052, 0.0022531316180022494, 0.11934812526188551, 0.028028686515866753, 0.02082278306085256, 0.007454753710678028, 0.04318206270615901, 0.17817764873466185, 0.043003552728482795, 0.03696882150947087, 0.05905713202551969, 0.03870054027966915, 0.08355383145352525, 0.059895703358755964, 0.09851300818545204, 0.023671291400528243, 0.09504408545551762, 0.18872988169952748, 3.7679707282973878, 17.34306173939859, 28.917109274095107, 38.01540774683799, 31.801549696153213, 25.72140916701286, 24.63987638873439, 26.87846326058911, 36.18188404267834, 20.64540324672576, 4.83935805097703, 0.16513703961766538, 0.03680656408710826, 0.44554028119291034, 1.4164404330715057, 2.9202151346591214, 7.865833870826229, 12.035888971820956, 9.374151902814067, 5.873699322823556, 5.134785579096887, 4.39662738192466, 4.4507894304490865, 3.2741519231950087, 2.414983948392253, 3.3837522614386777, 9.876173119391165, 18.814923301819835, 28.05898685609141, 37.366839916475364, 48.54069194486065, 55.134596286281464, 59.520155229876124, 59.028952890826815, 56.91989444917249, 57.31637547093054, 57.337171877584154, 57.13802529919533, 59.12719649653281, 58.45303912316599, 56.95317968245476, 54.21898957221739, 51.62723641241751, 50.312222588446836, 50.50757623487904, 52.61174348092849, 52.40464625820037, 58.363052106672725, 57.581147224672385, 60.11883051164689, 53.690932643029, 55.42205895147016, 44.33439316288118, 51.16249438255064, 58.292331772465865, 53.04607145247921, 57.81244939373386, 51.623949466213105, 52.908823797779704, 52.22291500337663, 52.4629444460715, 51.11161339667536, 52.136740530690844, 53.36525040288126, 55.97869034736387, 52.93136565916, 54.62952444630285, 52.2929253885823, 52.55986229065926, 52.01148748397828, 52.555073076678866, 52.275066837187744, 49.553263571954545, 53.183303417698035, 52.322186270067775, 51.541795422953946, 50.4240728962806, 45.640205106427594, 38.449723951278195, 33.63554408473353, 25.867093839953025, 17.06334379411513, 8.574664015923778, 3.3377421238730034, 0.8014083773859086, 1.8738834223439618, 2.095446836563849, 3.6183126943726696, 3.7674228222139425, 6.674895401923887, 6.441697257180368, 7.934326789071483, 4.063100401432284, 0.7707440228231492, 0.2862286814037831, 0.5143611770003073, 4.65145641757596, 13.354882040331441, 28.74927889916205, 24.80664772372092, 20.598505427760465, 19.0809109903151, 25.879313984224876, 31.350116268281017, 24.200829805866366, 8.753951634130171, 0.6025678051575538, 0.020274359868058277, 0.12269763020618309, 0.025301298592239622, 0.03506257641880262, 0.05108789090187319, 0.02147638246477131, 0.03585870265059414, 0.0390753181531064, 0.005910285981372, 0.041355176663566987, 0.031611181780575745, 0.05190668950578378, 0.014337172709225167, 0.08782479461402663, 0.07175269131098064, 0.03841329178202056, 0.047485883377732775, 0.025205886171710108, 0.03150438337827162, 0.0236123122064577, 0.048830551545946836, 0.10604420406443459, 0.038820877370815125, 0.011953615579724073, 0.09562271166472666, 0.022573387813604167, 0.019937920864791642, 0.014783320291298292, 0.017362848457489765, 0.0341215867909693, 0.06098554770071661, 0.12058353397033869, 0.16418252470752887, 0.25845388791734175, 0.2939026760718515, 0.22994662244473735, 0.1381275986110972, 0.14051485115722304, 0.12304943310277117, 0.3996977330215516, 0.1491387488861238, 0.17017472655542437, 0.16432417436472832, 0.12858312366710556, 0.19239237952616908, 0.1314666479705803, 0.1421640086318216, 0.16607612551700685, 0.07110695579960462, 0.18493573932397753, 0.1682626783487297, 0.13110035069046483, 0.12961728107785025, 0.16331767272805015, 0.0759628194294149, 0.08579313709971406, 0.09102325000229383, 0.10418048834488278, 0.25437728892410955, 0.24533365162149554, 0.18709554036538448, 0.18683332379066175, 0.07896989839331758, 0.19256130191347293, 0.14244986667988763, 0.3007217472599399, 0.15855767734108434, 0.2568882953135237, 0.22300652468637114, 3.7840691160771156, 20.293031238740493, 35.67955393945017, 45.669301248365834, 39.558146538272986, 35.58511111044115, 40.757862291028424, 33.12007796379828, 47.398662490229455, 24.407071951896917, 4.166934365226377, 1.149248331785202, 0.5866431048320186, 2.7302331741779082, 7.141724623018696, 9.395185612863111, 20.09298251521203, 27.847147487824966, 22.624945025290213, 9.558751390826318, 7.416056663759294, 8.83722061111081, 9.357177845893368, 3.567178225325, 2.6073212921619415, 3.281996418391505, 8.685061085608698, 16.995535819761216, 26.860438008462232, 35.800657118520434, 49.35274808637558, 56.454873931023386, 60.142054865437174, 58.483790505316954, 58.376556827176, 56.730702846281, 60.22713891921505, 57.14187314433437, 61.10144307536464, 60.75253648142661, 58.78809975039575, 57.040852500546364, 54.29525221547773, 53.40454078489735, 52.95778674464072, 55.795358765509825, 55.64362579776395, 59.981743674124445, 60.92437551867578, 62.49733617228847, 55.79819463914441, 55.1983348015816, 46.754530860531716, 53.510519304583156, 61.16908434898623, 55.50029062455701, 61.207570645116995, 53.47758708461639, 56.254895810158025, 54.55994159944596, 55.398132493419034, 54.479427106918834, 54.23644804185437, 55.77806111304991, 58.31099048737557, 55.70721134062737, 55.88846014391992, 54.005895045495805, 54.66127995521792, 52.24960281002907, 53.94207808279223, 54.95557146687662, 52.160502249194735, 54.72439089129048, 53.82478744752946, 50.8161961647772, 50.55420144911736, 44.08095313656715, 37.23257326310681, 31.382246363547544, 26.21733011737947, 17.152928767665742, 8.523184868597216, 2.3094214450928474, 0.7180203809853524, 4.317667618874581, 3.365382085884771, 7.515919718050188, 9.143255699065424, 9.395337604707288, 12.60372559870443, 16.520066107473067, 16.352260247353588, 4.582343274547208, 0.4359192281000076, 1.0424497915852455, 4.9262934634762425, 17.495830212869954, 32.53422491012081, 28.741292953491214, 26.028087523675737, 22.98162575690977, 33.44606614881946, 37.743528658343905, 25.213774058126635, 10.418147598543475, 0.8295231913366626, 0.16007564991952913, 0.26912304122121106, 0.18731381413677048, 0.14368431011755622, 0.15625322357781474, 0.10106680058543721, 0.1653783726355722, 0.10243220675376155, 0.23532504996945783, 0.1300739154459969, 0.1045740353724649, 0.16495754521700645, 0.1535572069546869, 0.11094798649390859, 0.2005185958959403, 0.13041444152833956, 0.10668394110736348, 0.09593769637567383, 0.10727904586782379, 0.1548248219994768, 0.15644793248464986, 0.22980267452376507, 0.0908108751079248, 0.09479943527689866, 0.1487311594668896, 0.12815609859723237, 0.1243677325246315, 0.13510833884919846, 0.14590567398455837, 0.10868535347042546, 0.18010063667691525], [0.000743370364943985, 0.0504561364951153, 0.034854441821094484, 0.045722368128237226, 0.01653456568507658, 0.07448127433176964, 0.039680849370216174, 0.045018455899891355, 0.033096630096195206, 0.023417813973801754, 0.06379584932038862, 0.05029227028811171, 0.034383814857010885, 0.053767789035074176, 0.00995866229547368, 0.015604920861791941, 0.02877203120489515, 0.07837892284676914, 0.024116097371123975, 0.03861281555145979, 0.03856948944890211, 0.06448869923910787, 0.05284993526255412, 0.07197347785075826, 0.03737718467750857, 0.027797806767686725, 0.0927991030978099, 0.03438203370258693, 0.0557489307116597, 0.03804530527803206, 0.027740940061067382, 0.045737594125732306, 0.1715139095341006, 0.033884467256646005, 0.047835966406930844, 0.02454439414695146, 0.08457023094618514, 0.05556207803648807, 0.3151692462063605, 4.59819455300608, 13.592117774871088, 28.867559932893325, 36.053136164142245, 24.367599179667813, 30.053025714812744, 56.483060083081654, 50.290739767013065, 17.321629908777055, 10.285312610287821, 4.537342902152769, 0.4396541518790107, 0.4095633213798846, 1.0052679286849115, 3.3209467799432817, 5.510543248345775, 8.397931821884649, 3.35221910188275, 5.177738964557648, 3.9015085562582943, 2.024288545212438, 4.283492007563192, 3.9448934024380105, 0.9278050401518423, 0.291225474568144, 2.834129160450351, 5.641913721638342, 11.697578660903439, 19.10826756108192, 27.938626966168805, 36.64885397880308, 47.36613427439044, 51.98791403924265, 55.77292280812418, 57.67594698936709, 57.19312283300585, 58.51451050850653, 58.94751271893902, 57.799631088010734, 55.53672159871748, 52.787853979295306, 49.54410875997236, 52.43057704740956, 52.37967644968341, 53.636800012280865, 54.18026793387629, 55.128869625829886, 57.19074195431125, 57.68547050414547, 50.46932528095861, 57.78821306843912, 43.74697508350496, 46.25472676369452, 58.59859435789047, 52.60464399091659, 54.01856430115239, 53.78944689227689, 53.29416528824837, 51.537963267295595, 50.15903049899686, 44.83511117196853, 47.00170686168056, 50.675849837641564, 52.38097867658062, 52.98376460229197, 52.005827503819624, 52.67642336506998, 50.817008095402876, 52.22875933493338, 50.52601137468892, 51.23559951782227, 51.86853670304822, 53.6368666925738, 51.56283501655825, 46.57681219039425, 38.47641568030081, 31.549619782355528, 22.65149554898662, 15.91991013096225, 9.462602330792336, 4.090960751618109, 0.5224229347321295, 0.8702400290677625, 0.3833318273386648, 1.8920891034987666, 1.6772759657713676, 1.8646026042199906, 3.518630804554109, 4.6978659014548025, 4.424690469618767, 8.530537351485222, 2.2138975128050777, 0.7724038595634123, 0.6347625582448898, 3.4812292889241254, 11.390671826178028, 22.010988189328103, 21.654042697721913, 15.357738387200142, 9.971101341709014, 22.066193588318367, 26.37417393345987, 20.074894505162394, 7.833517953272789, 1.1231148050677393, 0.016471472598852652, 0.1028368926997627, 0.03352453999762093, 0.08989251954781433, 0.06146776174465495, 0.04713769258570768, 0.1077540740070324, 0.06949853121994004, 0.01625681284724945, 0.05961842932588151, 0.032889161994981195, 0.03950988535859412, 0.026957360434255777, 0.03135054143175724, 0.018268843188941963, 0.04747759813683168, 0.028770705872786143, 0.05069905914546502, 0.05680311749118471, 0.05586474022317318, 0.05621189296606088, 0.07316846776032641, 0.025912324574986295, 0.02268000043958666, 0.057421530476741256, 0.04276146511397055, 0.013030189363616369, 0.022641686467273582, 0.06315780150133275, 0.042239717102699706, 0.03754057590999911, 0.0762464558225005, 0.021276870186650948, 0.024070053571654905, 0.047227773034284194, 0.07474170592162879, 0.02586210751154971, 0.03520718317538981, 0.04557832061583477, 0.03868195881706573, 0.11580185829511574, 0.03781139948255113, 0.05938959503245931, 0.05142254108983663, 0.06321402852453532, 0.04608602623545355, 0.05220170613498457, 0.02564285697806026, 0.017736009885406783, 0.07858486260257422, 0.04120030432879444, 0.05131369148711524, 0.07206605191552831, 0.046295945818025264, 0.02983998649963929, 0.029758716062191996, 0.05556975423748936, 0.07894242648035288, 0.07287252033429761, 0.01737493349449529, 0.049729594029486186, 0.042167383080889145, 0.019020137955404578, 0.018574811045020338, 0.07554663450367029, 0.026223850398955327, 0.032645603491654324, 0.06274994395132508, 0.054759807779543826, 0.06905627632213217, 0.37749981447573633, 7.823653682585686, 19.390821379999963, 35.76736011812764, 40.41223872092463, 31.335440720281294, 37.641343070614724, 44.747081418191236, 59.21658339038972, 25.5329079012717, 12.829090279917564, 5.7872100799314445, 0.6630122036703172, 0.18277356341000528, 0.10173993906186474, 2.385501698140175, 3.17180821491826, 5.9963694887776535, 7.851838363755134, 6.079228578075287, 7.084001062377808, 6.983674678110308, 5.251341750544887, 2.822237759828568, 2.492908205716841, 1.615601107478142, 3.710067228924844, 7.9784936578043055, 13.228484642121101, 22.83831607910895, 31.058550803892075, 41.33057148225846, 50.052844093691924, 54.565734940190474, 54.85831237608387, 57.11675428575086, 57.82549519692698, 58.41466657577023, 60.077782907793605, 58.9844810578131, 58.11106335732245, 54.574042520215436, 51.077120073380016, 53.842057643398164, 52.24424485237368, 54.80290497502973, 56.28135611934047, 57.65306780415197, 56.8541084566424, 58.856737306041104, 52.31566336847121, 56.14128828048707, 44.63519188665575, 48.66481927133376, 59.464688993269405, 55.461082612314534, 55.221719972548954, 54.910978040387555, 54.385172551678075, 53.405944993419034, 52.041501460536836, 47.27604919864286, 49.497440399662146, 50.220090035469305, 54.5074995102421, 54.84680806436847, 53.17858480638074, 53.189845931145456, 51.75323078709265, 54.11088120552802, 52.47721010638822, 52.27725159737372, 53.9113933809342, 54.57918082514117, 52.77953070978965, 48.03986410940848, 41.06123408963604, 33.49557822750461, 25.48285257431769, 20.55020732264365, 13.106815661153487, 5.208308937088137, 1.924591211061324, 1.0419656240171002, 2.4038010258828444, 3.945267253345059, 3.351621921024015, 4.313227986135791, 5.391976862184463, 6.292438324420683, 6.493032257403097, 4.1685126289244625, 3.075548593075045, 0.38590431994488167, 0.45133497025216784, 3.4456707969788587, 11.693682766729786, 23.640621208375503, 26.204509850471254, 16.914789907393917, 14.137507657850943, 24.12554579396402, 31.314048113361483, 24.64059614366101, 10.533350552282027, 1.6305405574460186, 0.06429209043422053, 0.10671088441966042, 0.009324980219976317, 0.050627763172791856, 0.01674373258626269, 0.012381614538870994, 0.02604756973713877, 0.03086930989558178, 0.004772807249889499, 0.02785010759027735, 0.03760715278105871, 0.0723516877980963, 0.05187993005458867, 0.06707393954838477, 0.043067409987411195, 0.025883559888649373, 0.0591288301943531, 0.027134920462905884, 0.05918159833057754, 0.030075748143116796, 0.023977975548815825, 0.06562618658907952, 0.039635925974336364, 0.08117014121624731, 0.03131465404294431, 0.07209435120345124, 0.02888604424022619, 0.016355073199637474, 0.06847389628209415, 0.07063175912105268, 0.02957266586412105, 0.06747334714858763, 0.1054973551823247, 0.1840635482221842, 0.1503593261323629, 0.1086589081152793, 0.1667474023997784, 0.10512484492914331, 0.11220086200703537, 0.2049275391524838, 0.22332613656838096, 0.11213461838422284, 0.16744020635322218, 0.26760330664054044, 0.20240292704153448, 0.09565483373139175, 0.129466361756767, 0.1474426761870423, 0.12618490074190403, 0.21118744276463988, 0.08837791775623638, 0.1080434024333954, 0.23662192957295528, 0.1788180369523264, 0.1711449615897671, 0.18894959571621112, 0.16842095211388605, 0.16594411324589484, 0.2114835051038573, 0.11431365589340849, 0.15102442834646473, 0.14344905983776818, 0.10098365706301506, 0.21342334698044488, 0.32037990047566356, 0.15958564476140086, 0.15044410142206377, 0.16201359189806447, 0.1598263036219343, 0.19923031179895326, 0.6011577743676402, 7.660421306087126, 22.464665212938865, 42.21886281044253, 47.403381101546756, 37.00886088032877, 39.92465672954437, 66.34129816485991, 61.4069329538653, 25.22792596970835, 14.463220296367524, 6.947889914435725, 0.7016082035918391, 0.8762737988464294, 3.2309173528225195, 6.856248638322277, 13.897342893385119, 19.41967433498752, 11.338102259943563, 12.32175229057189, 9.837915301322937, 8.618622999037466, 10.140990960982538, 9.016998525588743, 3.1385320521170095, 1.1681296412021884, 4.6208888965268295, 7.653510580139776, 13.793693280989125, 21.997954153245498, 31.235820362644812, 40.27613247594526, 50.91384749258719, 54.10183229754048, 55.22251621369393, 58.4776206170359, 57.46730043042091, 58.10250866797663, 61.62210241440804, 60.52128922554755, 61.45036535878336, 56.03066175214706, 53.992468772395966, 55.84122696230489, 56.30680837938863, 57.364628468790364, 58.74093324907365, 58.72396507570821, 61.02990688816194, 59.689201539562596, 52.28279782879738, 56.76343502536897, 47.00634702559441, 49.76697391079318, 60.102917455857806, 57.25388426934519, 56.74972634161673, 57.3156302205978, 55.17103902755245, 56.943738537449995, 54.590210530065725, 50.38780273929719, 51.29747098492038, 53.355628828848566, 56.7323031733113, 58.399228126771995, 54.58551153059929, 55.40806393469534, 52.7404050673208, 54.77743702550089, 52.52944430997295, 53.38991034415461, 54.11083805945612, 55.26195564577657, 53.54005867435087, 47.870696206246656, 41.162148829429384, 34.15733698875674, 24.80918941959258, 18.471449190570464, 12.427029686589396, 5.708435158575735, 1.2744791925914827, 2.213865153251156, 2.589215876594667, 5.346695059730161, 5.314785597785827, 6.131010238201388, 8.83917885441934, 10.679591221194114, 14.680532351616892, 16.410821234026265, 5.666754582235891, 1.317930841638196, 1.3304748265973985, 4.485254806856956, 15.11789623768099, 27.254412635680172, 29.827614945750085, 22.095060271601525, 18.16441389822191, 31.468675790294526, 37.255091590266076, 27.075946754024876, 11.23455168739442, 2.0595493047468127, 0.1332350240479554, 0.2591183619393457, 0.1662747721157728, 0.11741862557227574, 0.18155750608251942, 0.12433608543247947, 0.2713283019200448, 0.19054077565670016, 0.10867180903592419, 0.08569451860122143, 0.13121097378673094, 0.14062486138314972, 0.10866368084304756, 0.1823592630605544, 0.15438219171858605, 0.15921467434494727, 0.15920428619269403, 0.11409962624912301, 0.21490663109767824, 0.22507577413512816, 0.17660816440418844, 0.17512658100214698, 0.24176493827854437, 0.1257126611627398, 0.27505188759776855, 0.2608075858123841, 0.11912720082628152, 0.08670253709198968, 0.09586279595931692, 0.1498680799117973, 0.209832463052965, 0.19916246705237897], [0.031190293074976054, 0.012716484019502759, 0.015778147705620336, 0.034781226798171, 0.021130001555467327, 0.031722337307949225, 0.0059893639709409936, 0.04499221355804513, 0.026355772654736237, 0.043676921031287605, 0.009153394719525691, 0.04061318220450513, 0.005575313078870456, 0.06222052739993219, 0.06927058941894962, 0.0487555208946428, 0.09218542836606504, 0.04131020730241172, 0.00942721561108145, 0.04546039670165028, 0.0731563865537605, 0.06784732062970439, 0.01777926512483147, 0.11772343663558846, 0.011729662223989445, 0.034051459102380666, 0.05650034039131096, 0.0027928893987630168, 0.041568440219928185, 0.038367571654699506, 0.019077573482307698, 0.07664754881613678, 0.027523053164083152, 0.03800163826634807, 0.06937912109518243, 0.05431152760021148, 0.051570380737464276, 0.06089252547451085, 0.0550145703187633, 0.49914970453227725, 7.5688820115981565, 20.616063917836836, 31.956640212766587, 31.17701815020654, 26.164923329507154, 30.811686631171938, 19.65865062129113, 20.90036319148156, 27.010798146647794, 14.4030079918523, 5.667544939825612, 0.7287334770925584, 0.13793589276892526, 0.6765400293853976, 1.9804957725348014, 2.6494848103292528, 5.893918160469302, 3.6166986390467617, 5.294652561987601, 3.898092416986343, 2.11509570479393, 1.0070950790278375, 1.0610309171099817, 2.3496438803211337, 0.7233120873570443, 1.8004030878505402, 2.1318211815049573, 6.681303083896638, 12.861941110703254, 21.585328655858195, 30.047301015546246, 40.331928191646455, 46.50564470598775, 53.88441924125918, 57.01345082252257, 59.06758039228378, 59.07492306924636, 57.83945883474043, 54.44611049467518, 54.87725350164599, 52.204448484605365, 53.59493263306157, 53.4069844215147, 54.98122376780356, 53.71260766060122, 56.81118988221692, 57.0736042914852, 56.1264342646445, 52.273195866615545, 58.72850325799758, 44.112634120448945, 45.422929333102324, 59.85460004498882, 57.16255187988282, 60.16159219126548, 56.081268172110285, 55.284815219140825, 52.74648866345806, 52.67827864616148, 47.84427904313611, 48.6117103792006, 46.020957423794655, 51.929447189454116, 51.48191651990337, 55.20205713087513, 52.86448532535184, 51.923975483063735, 50.24469898593042, 52.62511484084591, 53.903772215689386, 52.70600195853941, 49.69719102305751, 42.86364947595904, 34.44358764156219, 24.09329410522215, 17.567686073241696, 8.63458018149099, 8.799728635818727, 2.6078348775063795, 0.35752125264656165, 1.1015627292856094, 1.180961920369056, 2.078700767409417, 3.0022971043663644, 1.8976176842566461, 2.6755700428639693, 2.366586558280453, 6.942553039520019, 4.320363758071776, 2.4053636001002405, 2.478661176658446, 0.643877411080945, 3.8170528171523928, 11.29691541194916, 18.110879428925053, 18.129030196897446, 11.581027392418155, 17.95585951497478, 26.002611729406542, 26.774704802420835, 20.32528292748236, 6.558987402146863, 0.8201693803552659, 0.06949840098499291, 0.04856543915887033, 0.035930998368008484, 0.08400225335912359, 0.024244618196521076, 0.038510136786968484, 0.043565321172918045, 0.04694921963457619, 0.05054366204046434, 0.03831049044346137, 0.03000684811042682, 0.032876379817964575, 0.06646970301986703, 0.06406490706027516, 0.03672218333268839, 0.05093462735174164, 0.13739036155804513, 0.03751429143331705, 0.11218462094304063, 0.12313852912836498, 0.03231940325349569, 0.047328348887423356, 0.0066332014994846, 0.025563633910590605, 0.02512807079080132, 0.04010082260074635, 0.07809832016186369, 0.028491945629338586, 0.028374521587524685, 0.004784307187242855, 0.07904705876905112, 0.018807487269382805, 0.02961646694119179, 0.03406739756164532, 0.032737177811683185, 0.05267635506067065, 0.006745574627852729, 0.03623870141323536, 0.05379699996762699, 0.01052034647023726, 0.05574564802490416, 0.00420368867062573, 0.04725766578508962, 0.04695396171882749, 0.018757689639084765, 0.024072072213335384, 0.06589371981399675, 0.07539109567240362, 0.021341483957404574, 0.04143234470017976, 0.09081924078805793, 0.03575901545944714, 0.06937843927692983, 0.011885640598202666, 0.03044644085269782, 0.03483530877518558, 0.03145366835768425, 0.045691444989173643, 0.019260679987529596, 0.03527984278456819, 0.057650008539278666, 0.023183898602221763, 0.00786707659567436, 0.029556150923693375, 0.10985656401082394, 0.040412628046807744, 0.09418713184253824, 0.03676311158004307, 0.0657375757732699, 0.03583106602872572, 0.016892119986756195, 0.03636819708551611, 1.156340467353021, 10.680055041466991, 27.06714887772837, 39.501601649868874, 35.074351833712676, 30.979981806970414, 46.18548516304263, 28.94871573294363, 22.30223201936291, 27.493383038428526, 15.092186081794003, 5.13450611022211, 0.5638073721239644, 0.03505034199465187, 0.2043566657530685, 1.793263148396246, 3.3310713979505726, 6.1105423300497, 6.358653816484637, 5.922339654737904, 4.321305617209404, 5.411162155289804, 2.890474743420078, 3.5552708900743917, 2.0975695742714793, 2.381725191108642, 3.165994036582209, 3.5969781875610356, 7.9577413778151245, 15.951349889078449, 25.082074596035866, 33.87392220958587, 42.0605206489563, 50.19811691776399, 55.62026808338781, 55.3034935459014, 57.75699100186748, 60.85349828966203, 58.57606426362069, 56.50412713327716, 55.38929539342081, 53.69898919136294, 55.81305649972732, 54.82923976836666, 57.09234929853871, 55.32196006467266, 58.259866314549605, 58.94958765276017, 57.01957364236155, 50.998272588176114, 58.60820024244247, 46.12743800686252, 48.05027015747563, 58.994832192697835, 58.33044152106009, 58.585407349371145, 55.90741303659255, 56.74554901738321, 54.48444381836922, 54.000082092900435, 49.77060210320258, 48.990909437979425, 51.44123761884628, 52.79132135452763, 53.44969903269122, 56.067006434163744, 54.08312651418871, 53.00121914955878, 50.95896651667934, 54.30371669030959, 54.45142922862884, 54.260033253700506, 52.206962723885816, 44.49249213741672, 36.813009092884684, 27.27219077848619, 21.02792847541071, 13.000695936141476, 12.031188011169435, 4.056433843028161, 1.7720416548752018, 1.1355320484407487, 3.804211467504502, 4.666231986015074, 4.0232599069995265, 4.6122082010392225, 5.3066844324911795, 5.5632339177593115, 6.361835839286928, 2.6948497180015814, 1.4294400258410362, 0.46941682095489196, 0.6227794722203286, 3.1138914775463844, 11.058075428009035, 22.414745207755796, 23.572928943941672, 17.05720332361037, 17.241248776835782, 25.33103135324294, 30.909855711844664, 24.44628780887973, 10.680212916866427, 1.7442517847784105, 0.12646449219074943, 0.018864648919852994, 0.023838922929679675, 0.044794796530397675, 0.04097668709413659, 0.05321412197043819, 0.017847764876581008, 0.09948015588545993, 0.050441787668293527, 0.040089695173646175, 0.06188236469883592, 0.03653321625484574, 0.07891433403616951, 0.05897540576575745, 0.00810800071415161, 0.03327655350609172, 0.09471372535993015, 0.04564148073475208, 0.010200412831299249, 0.03189111030810783, 0.05847083344574898, 0.02741289163579143, 0.052987065001000325, 0.027601454602254015, 0.0221561188734467, 0.04329451292212452, 0.05188933378385921, 0.02545168356699569, 0.02784158869255935, 0.04593413781314608, 0.0574742986129657, 0.03185509268434779, 0.04037676364063256, 0.10264943098469127, 0.29717013299945866, 0.13874426874662601, 0.1294048448964473, 0.08678918929710504, 0.13428928360583323, 0.13889255272524972, 0.11984206045106535, 0.15441490367295282, 0.16187502191432063, 0.15097991863806404, 0.14211104131273686, 0.09053340572262965, 0.22741847100757787, 0.1701152934542587, 0.14097986652726127, 0.21707087544904602, 0.13051947218275842, 0.1682151962191828, 0.19431679239196165, 0.15438263604958213, 0.1430480587746828, 0.17561460965343062, 0.21280686070601787, 0.20743836168079607, 0.1339426288200963, 0.17952447727082238, 0.1312777613319697, 0.08323944429115904, 0.1546039128856313, 0.08282769501449601, 0.21363207529629433, 0.18581389058982173, 0.21103774918423546, 0.18662582121549115, 0.1452405104834226, 0.11925762729539026, 0.06268016100230236, 0.19805117990941773, 1.0985899404171975, 12.028560023153982, 30.089550825857348, 45.06352647658318, 44.27409456622216, 37.962832297048266, 44.483086293743504, 31.320270953639863, 29.976123725214315, 34.2232681089832, 19.129305193501136, 7.24861313258448, 1.1922882545378901, 0.6041705836692165, 2.412952405791129, 5.594842828089192, 9.198006103115699, 13.17634947838322, 12.594470766282852, 11.036138592227813, 10.653801637311137, 7.162543583300806, 3.733525944332923, 4.822566874565617, 4.654183935734534, 2.4391555545791506, 3.5127837763678644, 3.4611325350499924, 7.457629374919399, 15.207473366491257, 24.052083723006714, 32.75415416686766, 41.16932284447455, 49.310963076929895, 55.73265183356501, 57.04972097950598, 57.7351983131901, 62.552861244447776, 61.562097995511955, 58.54017849891417, 58.27501058578492, 55.96105929343931, 57.603418442510794, 58.00293537878222, 59.38826945520217, 57.956769081854056, 61.46748258221535, 59.24443614098334, 57.83845863034649, 53.219569652311264, 58.4363337486021, 48.66552137559461, 51.92812535070604, 58.72230591312532, 59.107808220771055, 61.306928203951934, 59.46554799233714, 58.49795026163901, 57.193471923951186, 56.810417175292976, 52.886925205107666, 52.099976155065725, 52.858899870226466, 56.174526445327274, 55.47754479992775, 59.29321473644626, 54.52604447641681, 53.490660344400716, 49.79172014421033, 55.22343797068442, 54.776315227631606, 54.484133951125614, 51.620791958224395, 44.295659757429554, 36.6742277914478, 26.432244623861006, 20.35686977448002, 10.715414227977877, 12.262621579631684, 3.822555167059745, 1.9549561171762406, 2.09953173995018, 3.3218136237513636, 8.683701003751448, 7.025519503701118, 7.326054448081601, 7.37331900865801, 8.828684553023308, 14.35286343097687, 10.493534572662847, 6.535656654065655, 3.8157527965884057, 1.322588901365957, 4.646533352713432, 13.414868808561756, 23.402904002897202, 26.496079237230365, 20.040356074610067, 25.846307239224835, 35.59654481949345, 36.293408793787805, 27.55510545546009, 10.191934704780579, 1.8468430926722867, 0.26154018037261506, 0.13329615786431298, 0.11889833971978196, 0.18459257789917533, 0.1378584412797805, 0.12748273795530682, 0.16643353617720066, 0.11677053817097219, 0.2523727126179203, 0.1933718995461541, 0.21169402606544957, 0.1672592870290241, 0.1816914795387176, 0.14036371733152098, 0.09948225496637245, 0.14627301314425084, 0.27655504403575776, 0.11056164069281471, 0.13822365071504347, 0.17163214754433403, 0.13024165805789734, 0.09250444269949391, 0.14343464206303322, 0.0696385720924985, 0.16207650303840637, 0.1284578299870895, 0.13090928836214927, 0.15234504135385638, 0.10303828189329756, 0.15967276428015004, 0.14369900368394392, 0.11215717201271366, 0.19050437115853835], [0.030740833120240323, 0.027859160834322536, 0.03796071767987263, 0.07398533199222819, 0.014102088095950744, 0.05410693615915314, 0.042779747802283496, 0.08926606646949246, 0.05211860857783787, 0.03172937765597336, 0.022762178691224228, 0.05352316949997218, 0.04278923197078609, 0.06822732322278523, 0.07810195907950401, 0.014209479258786288, 0.011278865445825842, 0.014063307767613761, 0.10687180884903479, 0.032829414797766555, 0.05869158934200964, 0.030427598920200142, 0.024781312583194628, 0.02046652153254517, 0.04656252909391638, 0.03484498063522962, 0.0275415675939932, 0.08535811407191139, 0.005628531770555363, 0.02147124009957958, 0.032133473714272824, 0.031956019022712306, 0.02569964899110698, 0.00843568333244372, 0.07812504130866259, 0.021161715680312727, 0.04056242504908193, 0.007804830994216666, 0.04304019471390113, 0.06875202450300417, 0.5512545005448404, 7.496033791572818, 21.817303511404223, 34.868529381290564, 32.82913027271148, 15.926698773137986, 20.68392876655825, 22.99414400131472, 19.59404133981274, 21.42529203045753, 12.363652029345113, 4.8099432164622895, 0.8870687744309826, 0.6053874990151775, 1.174646046373152, 2.0502901822328568, 5.826166079890344, 4.122710131829785, 6.349599024941845, 5.631032576484065, 4.906507067141995, 2.145527168627708, 3.0879369089680337, 0.8798951883950542, 2.4436584355369693, 1.2141027613993616, 0.6551594960112727, 1.2704205200556786, 2.43026991525004, 7.6601624296557524, 12.643868115640457, 21.45349975555174, 28.839867999476773, 36.938360198851555, 46.02658210262176, 58.699685604341575, 61.47307195971089, 61.06891485952563, 57.77640673422045, 56.33470035368397, 56.927464623605054, 57.09229438535629, 56.70766284388881, 56.77448826451456, 57.20286207814371, 58.949136580190356, 54.78221055000059, 57.81632861783428, 55.229223466688595, 57.2254196290047, 47.77027568509502, 42.77416060047765, 61.576916710022964, 55.117212341677764, 57.066791134495894, 55.133666684550626, 57.745988753534135, 55.61867560109785, 53.920281471744666, 51.55425287062123, 48.14903543841455, 47.45005338422714, 49.61146370057137, 51.43689163269536, 53.25745974817584, 55.03293237378521, 52.15810175864927, 54.91649289284983, 53.5127942792831, 52.53207229798841, 48.17063200858332, 42.490985085887296, 32.556333349597075, 23.589094992606874, 13.32052109702941, 8.926941887024912, 5.323311359651628, 2.901990822245998, 0.8527427034512644, 1.2659275675973585, 1.188590685206075, 3.179880697881022, 4.29557781065664, 3.1506779165037218, 3.7222214283481723, 4.884745757425986, 6.322562127344071, 5.156075223799675, 2.584042270337382, 0.7381390756176365, 1.5902643122019309, 1.562923430915802, 9.22646289871585, 14.168476731546464, 15.404702886458367, 12.818203741504302, 13.990066743666127, 24.11494362738825, 30.37165161102049, 19.34165054751981, 5.038267816266706, 1.1920610022160316, 0.0816806928525048, 0.018317455298177177, 0.011616817472742931, 0.03882752318355826, 0.13666293043042385, 0.09326692234965102, 0.00546575915406368, 0.018863019067794085, 0.01774965582655803, 0.03311949782073498, 0.006017099705434615, 0.08241122663621941, 0.02367873585993244, 0.09647152176307094, 0.01656017791960509, 0.06467197045323349, 0.06107761997789626, 0.07616984703007244, 0.0359677974014513, 0.06478980243686708, 0.09666120513312279, 0.025467323251969876, 0.0981182583998288, 0.04386593024396608, 0.03912996320474533, 0.025756576984760263, 0.05648476965424996, 0.038006568042140816, 0.025488815848685564, 0.025890018009851058, 0.006010717235415453, 0.019865132935885942, 0.014604862982166872, 0.06100299152275247, 0.029036697345755758, 0.035337575170541966, 0.0595732722731848, 0.02069071333314623, 0.05045025677029645, 0.016711558808662718, 0.024716844369146614, 0.02948539887344645, 0.04889020298217093, 0.06263390078299469, 0.01209721397308092, 0.024670949956822782, 0.035839975631285104, 0.022341816671072476, 0.11196459283030803, 0.011002637122968032, 0.016414487148605047, 0.006183413084551332, 0.07242306421000151, 0.03642802855240242, 0.033857906988311204, 0.019583042125187574, 0.037877225587444927, 0.026453579100029125, 0.04465436878343744, 0.04570125091460444, 0.04458971862350741, 0.06138521194037411, 0.046010497626998735, 0.11694021132444182, 0.05872897060227491, 0.012308066267700446, 0.07166931796218119, 0.0412174953418153, 0.04692973418822212, 0.01224699948403624, 0.07456553634256124, 0.016664651245059028, 0.03410736436865503, 0.09591020914095064, 1.5630159743370549, 11.619492115512973, 29.365157696508593, 40.98053916808098, 35.86038697150446, 19.809663834110385, 24.01632739651588, 20.33254715704149, 26.22631822862933, 29.874628474635465, 18.063350108362016, 5.604761031366164, 0.9786797134626297, 0.3818694267782473, 0.3380294017974408, 0.5349389115168203, 2.719736666448655, 4.709162817847345, 6.981165341792568, 6.20065241090713, 3.914719589294926, 4.7884157780678045, 3.703694603135509, 3.1561648220785203, 2.9875676237767745, 2.1462233893332945, 1.389070869453492, 2.3119837334079127, 4.384931364367086, 10.656179574228103, 15.486943221861317, 25.93520775918038, 31.27287695484777, 40.39877322412307, 49.59164004172049, 58.27939187326739, 62.206712076740885, 61.55700675902828, 59.72571096112652, 58.40075000639885, 58.17770050417993, 58.30487158990676, 58.939581686450595, 57.59454604118102, 59.39349405227169, 61.904564057627034, 55.423329799406, 56.457152828093506, 54.65316849370157, 57.586513027068115, 48.96401374570785, 46.552536641397786, 60.160843018562566, 54.184213838269635, 57.9652492461666, 55.625582894971295, 58.97988011760097, 57.695943232505556, 55.88968000104351, 53.56535403959213, 50.93900165250225, 49.40957538543209, 53.264316051237046, 52.975821802693034, 55.62903065835276, 55.001827978318744, 54.784858149866906, 54.398061460064305, 54.4329587874874, 51.94785487267279, 49.955734052965724, 44.48972686644524, 34.57574405977803, 25.87934144081608, 17.292123879155806, 10.312437761214472, 7.372587976917145, 2.8859407286490164, 2.351350111346091, 3.986774264804779, 3.6044267685182634, 5.196610468049204, 6.985916312663787, 5.118253279116846, 5.014231531850753, 7.6523417138284255, 7.636102611018766, 2.8253001503406034, 1.6875249964575616, 0.6496090970693097, 0.7568907016708005, 2.4265826421399272, 10.125720193309169, 17.267993457855717, 18.571846177501065, 16.77608116980522, 14.812226910744945, 24.147471843227265, 35.14036140134258, 23.393433440116144, 9.157260521765679, 1.6737240144321996, 0.0950467284588564, 0.05671265399864605, 0.0343816161846682, 0.004879844097060062, 0.14446087812464084, 0.07770029918080376, 0.021741261195030906, 0.049155407299798344, 0.03573397587564203, 0.03275646407517695, 0.019332297717130954, 0.006954481059144582, 0.07471215024951004, 0.022969213952761025, 0.08326421191375102, 0.029004701683598182, 0.020755378814834743, 0.033232966933639786, 0.0656240721864085, 0.022596131048856244, 0.1065610069781542, 0.0496422753278767, 0.04233111905294561, 0.055814664886002584, 0.020796686275711945, 0.02658536154476385, 0.10866905878027601, 0.04802953767319841, 0.02235433454775522, 0.10989814726335388, 0.06162960164909882, 0.026347711494552995, 0.030424147694101258, 0.035697805034297134, 0.1500161647075607, 0.14195157245041864, 0.1069782491052343, 0.14722755869790433, 0.10871643365751352, 0.1618391689994643, 0.09348410827618453, 0.2630354920702596, 0.14339319670632963, 0.20435327964444316, 0.09235069651397006, 0.10989424787581929, 0.15765072116928716, 0.11368537186494759, 0.18206390552222732, 0.10113114431019753, 0.08427859659517005, 0.05721491656356281, 0.1946926810928891, 0.13360505983714135, 0.1856199324491524, 0.09850962973770597, 0.10568106306656715, 0.0657755890560727, 0.14632742070863325, 0.16785951691769785, 0.12171788802070004, 0.1857578282755229, 0.11563743284392743, 0.18149137737289553, 0.17590408363649923, 0.19036699627195636, 0.2307346664489277, 0.11047828266577375, 0.20520023581001068, 0.1369718477250107, 0.2672510287694393, 0.14331130190722405, 0.10665121383123821, 0.1864871746229549, 1.599616713581547, 11.849629340633271, 31.037579851765788, 47.47223046518142, 45.36272095095727, 27.495324611663822, 32.05306383871263, 34.929161379414225, 30.608998152517504, 29.863306553133075, 17.571949689619004, 6.6810662707974835, 1.3903180605942205, 1.1088932714154645, 3.1248361160678253, 7.953899416231341, 14.325065593565665, 11.708612288198164, 14.770894935054166, 11.881434859768039, 10.80200251071684, 5.7339786137304, 6.073017014611152, 3.154410787167088, 4.837737621799593, 3.190228645839999, 1.5343720081352419, 2.593497633934021, 3.64284981643, 9.612789884690317, 15.531834748483474, 23.44748370109066, 30.186904053534235, 39.448257415525376, 47.27906550130537, 59.482641681548095, 64.42974675086238, 64.65604789795415, 62.616050627923784, 60.948380424130356, 61.96539609662948, 60.818899062372026, 61.07945034580847, 60.04078318995815, 61.50295649805377, 62.26706558658231, 57.94340556667697, 56.04066379608647, 56.957019682853456, 57.00983047485352, 53.32235536267681, 49.72872295687276, 59.049309992021136, 54.51708970531341, 57.68893003463746, 56.105025968244, 61.60898600855182, 62.69756924721503, 58.93056807979461, 55.207328796386726, 53.31613448358352, 52.11017039514358, 55.420878318048295, 55.35166025161744, 56.211588921085486, 56.85656386037027, 54.69860915214785, 56.50742976896225, 55.542911098849395, 53.43064023602394, 50.373038937968595, 44.45447260333646, 34.77444741033739, 26.38643526261853, 15.823712041301114, 11.846225703916243, 8.84278743497787, 4.062530677164755, 2.687662955253355, 3.3107498432359392, 4.434993555468898, 6.61040771392084, 8.700626031044992, 8.986450126094203, 9.357209224854747, 11.848069217897232, 14.77942216780878, 9.69521653267645, 5.521259653952814, 2.7005734366755334, 2.3388178934974055, 2.41505945401807, 11.65185853358238, 19.32136404898859, 23.595804206786617, 21.326809160171017, 21.642473666898667, 34.0421526662765, 42.49479370732462, 26.86524683429349, 9.51033071164162, 1.8291473196398829, 0.37956172480217876, 0.1741867596583982, 0.09569490779071085, 0.20858934749999355, 0.28776318615963387, 0.20213801383731828, 0.057183840206914374, 0.16547324496411508, 0.17048577357444072, 0.13413255733828391, 0.1253676534660401, 0.16078783589745724, 0.27698215337530263, 0.15610447994643645, 0.21663613587377534, 0.10602142060956649, 0.08358480438830392, 0.09864159604354251, 0.14920990313253096, 0.21588774458054574, 0.19734951997956923, 0.11754641669892496, 0.12391834534824857, 0.15601415818016376, 0.1654436280049624, 0.10049685415241028, 0.2596909360539529, 0.2090562780898425, 0.10721628028418749, 0.2102170391909538, 0.12964625452314654, 0.15104155807245165, 0.17235965528074773, 0.12207824045852309], [0.04148050098710003, 0.051025504531759414, 0.0179082915682586, 0.028980585235741832, 0.02886992766551914, 0.04754637368023396, 0.035852991465118625, 0.0451066977374496, 0.032533769976467855, 0.04031536169350147, 0.12148501261347726, 0.05368667947609098, 0.06089352904969166, 0.04684634168722457, 0.015049553081964054, 0.03035958371906271, 0.021017440256752798, 0.05905902043225304, 0.08115272037684917, 0.06156161134581893, 0.05040597305783341, 0.05622574000529224, 0.054482970416786215, 0.054908815711256, 0.16604344420615705, 0.03837635485275138, 0.07039686890258905, 0.039066592411648844, 0.0186642901145763, 0.04720433074380121, 0.03449228524620976, 0.005285339702236196, 0.11665141915962582, 0.038051361203073494, 0.05658100561929807, 0.03710878577323691, 0.07320543916355218, 0.03202553384096152, 0.013107000211734447, 0.02580641483467433, 0.08083825660569054, 1.1049892873533311, 7.0822026556538, 20.795222097827544, 34.096787360406694, 33.98748659318493, 21.804071395627915, 20.569068039617232, 18.58394668948266, 13.605112587251972, 11.701622624551097, 7.1112066218929915, 4.842334639641547, 0.7691650236806562, 0.4522805066118318, 0.6219500135029516, 1.5341561552016967, 3.4584251190385515, 4.423046506220295, 2.3463125623041585, 4.539494322192285, 5.361261271661328, 3.615170630716509, 1.011337367517333, 3.019212080586341, 0.8662787416288931, 1.9862234135789258, 0.7317254488025943, 1.3158724553162053, 1.5425892510721761, 3.4895496166521505, 8.520563744729566, 14.474180379221517, 22.087605807089037, 33.22102016018283, 46.527096148460146, 55.74564272357572, 62.50113302661527, 59.63446486380793, 58.63077348278415, 59.171735009839466, 58.75841917530183, 58.05912333150064, 59.13510007243003, 57.873120615559245, 57.38167508955925, 53.706488763132405, 59.09777479787027, 56.892712423878336, 58.41173656525151, 48.53875821636569, 45.386008062670314, 58.393183754336455, 62.764983023366625, 62.99986239402526, 56.80176834906302, 58.080551239752005, 56.04681407251666, 54.77773120326381, 52.36614427258892, 50.40654382398052, 49.89142287162043, 51.844174861907966, 54.173372407113355, 53.86069674645701, 54.15298784932783, 54.5004431663021, 55.19999004179432, 52.10481635985836, 46.483028319574174, 35.383850374529445, 29.290820937002863, 18.154351057544833, 11.37378013903095, 5.831674068204819, 4.172531587462272, 2.9438738909459885, 1.0322969815423413, 2.198822863640324, 5.901710929409151, 1.423969912913538, 9.482631914077267, 5.321146701612781, 3.1772835985306775, 4.7224611236203105, 4.6402958035469055, 4.286445062006674, 2.963192544637188, 1.0928257723008434, 0.682603094366289, 2.583303393856172, 8.715248627047385, 13.86843796699278, 15.873075069919711, 17.976801049324777, 19.707888134064216, 26.889430207590905, 35.05850938058669, 19.508053179710142, 7.152376309517892, 0.6505336119763313, 0.058865759431594805, 0.009181057196861554, 0.019296297330349203, 0.038415007818970955, 0.025416091122033618, 0.01587347298364846, 0.07107467285447544, 0.049986049623018315, 0.06839918738771832, 0.04487943009383256, 0.032641811356429136, 0.01883421799228076, 0.02303811015501138, 0.0681861536577344, 0.026727091641195362, 0.08587465651573674, 0.03648802855863206, 0.007154006743803621, 0.0348630181754068, 0.01592357800672612, 0.030017868285217596, 0.06829169759106252, 0.1341276850190855, 0.05578346212484664, 0.023963707161226103, 0.06328408726521077, 0.05857505587740772, 0.052561330789279555, 0.024214556906372312, 0.09489809974066674, 0.029555718084016157, 0.011894838441343559, 0.02124872220109307, 0.05855268611001873, 0.017290899394861153, 0.02765899355102691, 0.07598313608116682, 0.04257080115137562, 0.022185875643645565, 0.08649280520095941, 0.030834910632561774, 0.033192325969256704, 0.014203724980865036, 0.0706699179605611, 0.043751786973687916, 0.05517394725053061, 0.02054388109113901, 0.07847400967993083, 0.035108568507336804, 0.057948166128969004, 0.05152941035527376, 0.02972663421514294, 0.05710990889178169, 0.07769894320517778, 0.02014028682042995, 0.059849818522531184, 0.0643829484620402, 0.0550506875339535, 0.08978237908694053, 0.12659999782279616, 0.02409223947794207, 0.08137650998129, 0.034161760441718564, 0.036760767350994775, 0.04571320954710246, 0.04686106589712924, 0.070437379632025, 0.035320031757075945, 0.06804476447042919, 0.07307125886361446, 0.018529345641934106, 0.05967658689065326, 0.045303138002993605, 0.06877906740673127, 0.03915970656840552, 0.03828230223828747, 2.235194511951939, 10.746608837958306, 28.64801899079354, 39.403522783710116, 36.980223655700684, 25.846471978772072, 23.785082101821903, 19.379742645448257, 17.473933581382997, 17.398643685925393, 15.516230579345459, 5.323867845919825, 0.7348876758929223, 0.3578781883322424, 0.5028169980693249, 1.163766739829894, 2.2895664072805837, 3.8577751094295136, 4.452883485824832, 5.59371171459075, 5.530648827552796, 4.7782293827302995, 3.0971169712082034, 3.695752048684705, 1.926504592261007, 3.7249224705080834, 1.3475056353115267, 2.1318998740565394, 2.59587949322116, 5.546451566680785, 10.860117327782417, 17.965724275958156, 25.339362467488936, 34.758067592497795, 47.612690541052054, 59.01266720987136, 63.09834134194159, 61.17119458413894, 59.09171473595404, 61.68312664954894, 61.45032613508163, 59.57919474570983, 59.782067575762355, 59.763848166311945, 57.5586171304026, 54.60415455602831, 58.90936766901324, 55.87472400357647, 57.49221532575546, 50.7212826513475, 48.37276743304346, 58.88369967860561, 61.70788465007659, 60.941571189511215, 57.846715219559215, 58.27261009523946, 56.91981992413921, 56.936572367145175, 54.06803715613581, 53.381410567991196, 51.41395361192765, 52.517688966566524, 54.4533198110519, 55.36605142777967, 56.17441661896245, 55.99050844869306, 56.542927219021706, 54.10753542377103, 48.472572142078036, 39.191334324498335, 31.73298666554113, 22.77784097579218, 14.340567781079201, 7.64475045665618, 5.786365299455582, 3.601201109347805, 2.1034634257516553, 2.955212482521611, 5.808105036135643, 7.372950305861812, 6.89269922433361, 8.840890968999556, 8.836074298427953, 8.327492917737654, 6.649145532038904, 4.679745041554974, 1.6320751847759372, 0.4995207055922478, 0.44700510259116855, 2.451702971612254, 8.66516976587234, 16.10474201940721, 19.843868863198068, 17.50829354409249, 19.141480230516006, 25.101270675659183, 36.3527189531634, 24.585912419903664, 11.487510242769796, 1.3317448165147536, 0.1729159117225678, 0.04334126343770374, 0.03961661672820488, 0.04711573267535818, 0.038789103874155594, 0.03049038174081474, 0.036914191779590426, 0.039055357732239275, 0.02423293727089561, 0.009246834463650181, 0.03921383068025593, 0.07174161367959554, 0.027784970964515404, 0.044644604992842486, 0.023784235743204915, 0.04437379291160934, 0.09891793161870972, 0.046163121493713516, 0.036473989997419624, 0.08368865526731938, 0.039346639682809194, 0.02579865627922118, 0.03220245610141466, 0.06108521957010512, 0.027558519204537717, 0.07976626211236562, 0.037823905867915, 0.04946691397156927, 0.0420430968064935, 0.09037386791239824, 0.014751699054613711, 0.05399901735325975, 0.011943122090381241, 0.030494849948633104, 0.006110734323174843, 0.10738054485691172, 0.11541028011349902, 0.2144709875386569, 0.07631878984431106, 0.2469986977596437, 0.1479576558115021, 0.16911691234957787, 0.13425643375564006, 0.134336888309448, 0.22514850652265936, 0.1660150529876832, 0.19977800337777984, 0.20892847930231404, 0.10303666544777733, 0.17682905819627548, 0.10458324374931474, 0.1047822887138013, 0.17992227608638425, 0.18049301158997322, 0.15512089966045273, 0.14787913179926335, 0.2928849129426864, 0.18555196512851024, 0.25054775328645784, 0.3337960918584178, 0.08620873979863622, 0.18667812969896103, 0.14261855924081418, 0.13905551494850268, 0.1086542349789412, 0.13312081566020367, 0.15692088452558364, 0.15297196174581207, 0.14418972896472101, 0.2514758994502406, 0.1181539627272756, 0.19743064869075053, 0.09710508413733014, 0.15971972546990842, 0.12385688977496279, 0.13669286914650472, 2.1426074543306908, 11.353743691598217, 31.062547699097667, 45.24320240943663, 46.45576000213624, 35.37902585921749, 31.826886246281287, 28.964728809172108, 24.278243664772283, 19.84381591120074, 12.6203211469035, 7.686694812390113, 1.287517396192397, 0.730739892009766, 1.6054964690439164, 4.750613935532109, 8.302016142875917, 11.57824250959581, 9.481330667772601, 10.846894037338997, 12.0516166956194, 9.095908768715399, 5.549562006227432, 5.369231037555203, 2.7915868884132755, 4.80563743460563, 1.6033481133560983, 2.323703040038386, 2.43308691247817, 4.533996139803241, 10.468526521036702, 16.784704500629058, 25.037394877403017, 35.76538716593097, 49.056287504011586, 59.80372298148371, 67.67314680161016, 64.07090479327788, 61.11287678441694, 63.705579157798525, 63.08096131970806, 60.32757905221755, 62.01544161765807, 61.45130280525454, 59.03344008230395, 54.478128802391794, 60.81701240231914, 57.800380260713645, 57.738555862057595, 52.818307261313166, 53.45238977862943, 57.51158791203653, 61.849309629009625, 61.89862558918615, 59.30483279689666, 59.64512194356611, 60.840829034005445, 58.64911840808008, 57.25706138918477, 54.110775301533366, 53.65033218937536, 56.01053607079291, 58.934160970872455, 56.044472417523785, 57.57609521189044, 56.891610237859915, 57.812680813574026, 53.71943650707122, 49.56146524798486, 38.04442544137278, 33.4764527505444, 20.329385726682602, 13.78504543535171, 7.523230035458842, 6.938543396611368, 4.67705870828321, 3.199890914463228, 5.291643613769162, 10.005793725290607, 6.826658277742325, 17.22250573096737, 12.1532678604126, 8.162937231602209, 10.344762013804528, 11.017422022358065, 10.859317164267264, 7.874824923853721, 2.28453008397933, 1.1279606482675, 4.03303322772826, 10.68784486862921, 19.629870230151763, 24.427613404489335, 27.239572348133212, 29.73716508957648, 36.42687136127103, 44.71710274296422, 28.642021686800067, 11.551995969587757, 1.4420665031479252, 0.24656051078871374, 0.2166485618199072, 0.2024543315412537, 0.20627563939459864, 0.15597815204772258, 0.17263419054929288, 0.1556280651880849, 0.1727548187538501, 0.09766094221342957, 0.1574336884603385, 0.13508040728347917, 0.15471441340782952, 0.09120462897924647, 0.1468907251593567, 0.0664262964780773, 0.09930945617417175, 0.18404968203075472, 0.1745139098455829, 0.08992501699756231, 0.18230508532254927, 0.08860412819851791, 0.09279170268846136, 0.2523905471447976, 0.26284185568651847, 0.17312473196896816, 0.20965158969404238, 0.15187336101887688, 0.17815143320589297, 0.12044901659171428, 0.2660020296612094, 0.17557322558376098, 0.09602804878546346, 0.12354152968093274, 0.10554212536061965, 0.12691115975500117], [0.054213690511401624, 0.017868780583563833, 0.04309513087895128, 0.024157330138428558, 0.04419839708134533, 0.038097280513254866, 0.04288660940684138, 0.030937911153981285, 0.038104696244361906, 0.009606613293139925, 0.045607876287953514, 0.034910155565387783, 0.09370242801284598, 0.019689507279244643, 0.05099179283265145, 0.03715180544062488, 0.05041378332422145, 0.0514599415023, 0.01826807327057806, 0.043541269842535264, 0.05081729332525885, 0.051440241551327134, 0.04220616245161622, 0.09098610239884547, 0.022865995096283096, 0.03984332895807682, 0.015663238347417886, 0.021284264850340063, 0.05816639393507954, 0.050175200561962785, 0.0362661273609246, 0.033934420019748716, 0.04818134565627383, 0.05346922924922359, 0.07609484702228539, 0.039415641222149134, 0.05320734209230831, 0.08070028417052762, 0.11812317365359877, 0.046406710640557354, 0.07159581182584648, 0.07212821228970444, 1.1738002853047464, 8.056218364546377, 17.794687363409228, 34.67865136361892, 36.70942321900399, 21.603444122499038, 20.776177029455862, 18.350381312831757, 18.572922868113366, 11.774179608591142, 9.993691252123925, 7.290039735455667, 1.4932739037659861, 0.45104155857716843, 0.5019474576317495, 1.4769389480352404, 3.2457184166677537, 3.928638610147661, 1.3100325364258982, 4.802581417945124, 3.478285795257938, 5.025449510543577, 3.374534691533735, 2.4289365545395882, 1.721458769133014, 1.0618731235304186, 1.2729207858923943, 1.4202679309152788, 0.566829435767666, 1.9250253684097722, 4.3126327664621416, 9.005323590770844, 15.657448653251896, 29.064694335383756, 43.01560209643456, 55.45005682976016, 62.96921299349878, 63.859257621149865, 62.118341076758604, 62.05859161192372, 62.896127470078014, 57.63666052972117, 57.215707840458045, 57.51877761656239, 55.65719719856016, 53.58518946555353, 55.355876799552675, 55.53882398912984, 57.00780653184461, 47.541715252783995, 62.44785155019453, 51.33879707705591, 53.130261205857806, 59.07915530666229, 56.1932243839387, 57.865648500380985, 57.32009387785389, 55.17767567788401, 55.42767578555692, 54.38671012078562, 53.75181567284369, 52.92884749750937, 54.8567355832746, 56.230722242786044, 56.89074731642201, 51.77299561039094, 44.361245709080855, 31.599151472891535, 22.96588920777844, 14.411021394114341, 8.327720415207649, 4.3915513446254115, 2.9595783256715347, 0.7375004034369224, 1.1490794247196567, 1.2672571285117058, 1.8183844584611155, 6.418603322198314, 6.04406992273946, 4.000326544046402, 8.871549194858922, 10.920964075673012, 8.551052328078978, 6.472742326797978, 4.499390538661711, 0.07828704592201018, 0.6682862593762336, 2.8106925083744914, 8.173440848627399, 13.235179147412701, 11.883571570919408, 16.699934236464962, 20.358903523414366, 32.75021806839974, 31.801155497950894, 18.87899914095479, 6.1612360227492555, 0.9319337024804085, 0.11457918962884335, 0.05424058785842312, 0.0196631366176711, 0.07289176446295555, 0.039429381009071104, 0.09350546680751348, 0.021747064311057333, 0.05314135510895041, 0.09873194079245291, 0.010691696398651168, 0.03409169404016387, 0.01579145273764528, 0.08445514921819972, 0.05181290502209337, 0.048924845478106896, 0.030932893278077248, 0.032292720411093004, 0.06499133718710753, 0.04264201285437711, 0.06048632267441961, 0.01939328023112349, 0.024500072130092213, 0.030353692502924995, 0.050681806845410224, 0.04873391721517809, 0.06427732791991965, 0.035585343327012756, 0.0432614523977522, 0.02660950289047774, 0.03205895251143844, 0.02891775644985178, 0.005462239458856564, 0.028569847195138855, 0.00960239023345733, 0.0024768297706971006, 0.066570351651359, 0.03948946528497242, 0.061926977829106396, 0.014466000927401888, 0.06579424329702893, 0.055647458535649126, 0.03909180436523692, 0.033725147781473015, 0.026355136801759084, 0.017952556128523523, 0.05027935404570834, 0.0316975447874997, 0.027992596113753897, 0.051145910570818576, 0.08069994709184093, 0.03383921444295876, 0.022543751702253378, 0.04776054122034581, 0.025334745991013707, 0.0400288486402602, 0.04413108476587842, 0.04396974664902495, 0.019292373044957078, 0.041989650682456074, 0.02548542590962062, 0.03978561572430115, 0.060040176049956394, 0.011691125128568422, 0.04427437385123584, 0.05432561212669938, 0.08104719176527955, 0.08428020537981103, 0.028054089991435893, 0.04247859863924884, 0.026918410608965545, 0.06994605680266697, 0.0046324905856782875, 0.045301881618797786, 0.01368646049917105, 0.027570975794186516, 0.050072406884282834, 0.03964685421857623, 0.08039413245334741, 2.2496401110003075, 12.193726128147496, 25.535690822908958, 37.01581132027411, 40.07551500874181, 27.65220569026086, 21.888837737421838, 17.903805740417972, 16.78226674756696, 18.034428511896444, 17.400816679000854, 7.2899970796800435, 1.102435211500814, 0.0874939748656846, 0.20174752350055403, 0.38223904887995414, 2.0384562688489116, 3.2340390691834116, 3.9254399172721373, 7.123592486304622, 5.099729395681813, 6.268005880617327, 5.482993991144243, 2.2434138386480273, 3.0034635191963566, 1.8632408063257895, 2.9618569775935146, 2.2740024424368337, 1.6148980226247542, 2.242761254310608, 5.455888942364724, 10.464781638114683, 18.994940480878277, 32.038809945506436, 47.39683074335898, 58.97310618431338, 63.99349681792721, 62.72167221192391, 63.56027103239491, 63.1255155224954, 63.119635889607096, 58.280494059285815, 58.391477523311494, 57.05718917231406, 56.829138648125436, 56.5014010860074, 57.89798844245173, 55.14453164992794, 57.418106063719726, 47.30177994697325, 61.52461974851547, 52.41189087590864, 54.88634555570541, 59.25177489557574, 57.97419225015948, 57.826091397193174, 59.38712412311185, 55.214710697051025, 56.2096316583695, 54.167524153186434, 55.705379593756895, 54.915037693515906, 57.862620430607954, 57.21293472474622, 58.247420633992846, 52.27176420150265, 47.66506987233316, 34.19731378555298, 26.675037376342285, 17.288136789875647, 12.075835370248365, 5.911551175578948, 3.6020213750100907, 1.3699690492883807, 2.1398838585422886, 2.2953170922494706, 2.434485482592737, 4.727624433655893, 7.8137271442720975, 6.644743652113023, 10.618561102497964, 13.01638541683074, 8.772364220311566, 6.692829949240531, 1.5579852894429238, 0.5278054072010903, 0.34159023975653036, 2.8089431312776383, 9.216457912998816, 17.39549598386211, 15.982048319232081, 19.057406187057495, 20.16105721073766, 33.509153550670995, 36.54267149586832, 27.824484032969323, 9.141131735617115, 1.7134632626848838, 0.1890241513930021, 0.06411843362354464, 0.12409244648992054, 0.028168593323038473, 0.021410510394602053, 0.03266588183901003, 0.13073437516727757, 0.023023975832808404, 0.05617640394296858, 0.034668929799790346, 0.058811803859087734, 0.05278314388687572, 0.06834038247865054, 0.04690351482901362, 0.06101741312792706, 0.04201348367778044, 0.021343447057710543, 0.05274473989923155, 0.030931498998055057, 0.04476360526056059, 0.07924843264082748, 0.037537691588964195, 0.05702062517464642, 0.03804002693223377, 0.0313965124528735, 0.020580756733374252, 0.01889356682377477, 0.022271194855772683, 0.04594599685421394, 0.019133882859962124, 0.04016888568237905, 0.05940787005989302, 0.04293585353861413, 0.02404455625031504, 0.05067699581324574, 0.04756183716498556, 0.17330254097619366, 0.13851756800807294, 0.12453210434966511, 0.09328045146239382, 0.2885133700986063, 0.13550292009547835, 0.15909855073738485, 0.07701445130571243, 0.1648555942360432, 0.12191673380232627, 0.16789622785102937, 0.13656079558835876, 0.1917262813977657, 0.11787421806084535, 0.1555487444444049, 0.09599069433827555, 0.1994891882303261, 0.1271561776558238, 0.09126354114062364, 0.14148497893925638, 0.10446866763935936, 0.14030797677415033, 0.11498268047768263, 0.21010358156936787, 0.09397878657065092, 0.15081510248203434, 0.10244479357835748, 0.20880258041283778, 0.19796838112656148, 0.15563194159298174, 0.20325291691528213, 0.13120721995590195, 0.23165360423586062, 0.10423812113942639, 0.23790581632525692, 0.21406250945743055, 0.1016730672469543, 0.2197451351751243, 0.17727083045869105, 0.1224639121022436, 0.1848936044881421, 0.20993004733275986, 2.1739560173403834, 12.502058744430544, 28.408334716673824, 45.410126716859885, 50.566611828342566, 34.16001596758443, 32.11482155707575, 28.847789226039765, 29.546477102464248, 18.894841594080773, 16.01085126399994, 9.428063900240007, 2.1372286590837666, 0.8107290933689764, 1.9480944208560453, 4.156315038281103, 10.204041100317433, 11.683203174221902, 5.914161512928625, 11.04841463027462, 9.07282954262149, 11.2287171617631, 8.42479907697247, 6.118551809941569, 3.595986563351847, 3.8775585639861325, 2.902968227863312, 3.518885268319038, 2.043318414399701, 2.913429189112879, 5.848285796180849, 11.279565788084462, 18.083295360688243, 32.83293497177863, 47.657895857288, 57.085065457128714, 66.1396255800801, 65.34524363856163, 64.09210128168907, 64.25534640589069, 66.05758528555593, 58.04632463762837, 58.331143625320934, 58.58856093498969, 57.21229145603796, 56.28348988871421, 57.12901169253934, 55.30106559876473, 59.7212786828318, 51.03174217285649, 62.58567971567955, 53.5823888932505, 54.81055751923592, 59.93661680529195, 58.77758387596377, 59.44252760179582, 61.73047750226913, 58.591290904629616, 58.934945444906916, 57.632212561945764, 58.10544652323569, 54.56868848493023, 58.7431219316298, 57.54746975437288, 59.72260052157987, 52.9902365130763, 46.73976705920312, 32.77918084975212, 26.418094673464378, 17.007332348054458, 11.814210337977256, 7.604185794630359, 4.809076372654208, 1.7215042441121995, 3.3647589193236445, 3.421958843546529, 6.901564761515587, 14.01410596985971, 12.757042223407378, 10.895350998447789, 16.709591111829205, 21.31750725930737, 15.993103519562753, 12.742195071712619, 8.183905732247139, 1.5943390419406276, 1.1982669272730428, 4.3789963280001, 10.637357100363701, 18.90942300519636, 17.80938252325981, 26.35806279797708, 30.94239765597928, 44.40139116779451, 42.42356738736553, 31.05723680988435, 9.554350491492979, 1.7772782642033793, 0.23128851737466552, 0.14880641994457092, 0.25379820306214596, 0.12103348039090635, 0.10197453816691715, 0.12530006152848083, 0.2621137044362484, 0.24419357489433982, 0.232392112994867, 0.23407456465065482, 0.12344370025300211, 0.21564469552568852, 0.16152732524900668, 0.1812100086000658, 0.15657776906605692, 0.10327699489050335, 0.13032813406279012, 0.20756511858874754, 0.12854276615525448, 0.17540886908048586, 0.15037397373347514, 0.08207372660117765, 0.1776071124139332, 0.13250316493213177, 0.08997531833067056, 0.30736516980874923, 0.1248690528014014, 0.2378319501275978, 0.14386752770552713, 0.09578555131391173, 0.0901747003738438, 0.150803228119208, 0.12994024842496843, 0.08869207509222532, 0.13636323683444532, 0.1628401088378122], [0.07251436656881725, 0.009821167707653537, 0.07572163962909291, 0.07074245882611122, 0.0974167057222897, 0.018481767751396667, 0.015261836045782174, 0.03482381362588175, 0.05021523631688568, 0.03263423091641838, 0.0595265255880452, 0.04275131444897383, 0.018356071875220346, 0.06269314619261893, 0.005760447801871887, 0.09224529813734755, 0.08404600464047925, 0.032563785301341165, 0.055591243003765424, 0.011056335098410567, 0.1349891355681804, 0.007603247884675981, 0.04082940286025405, 0.005716194254120873, 0.03467005594903904, 0.061106834740888696, 0.04208096070215107, 0.0249775517506585, 0.02628842778053255, 0.051867515599775704, 0.023456811679587252, 0.07321274764234982, 0.03382612583077243, 0.11774544634165303, 0.06602192462812509, 0.05633283143622741, 0.017315492732450366, 0.06944316604565229, 0.027792767824364767, 0.042351734478988, 0.06336729973554611, 0.06078705431953554, 0.08173154576891854, 0.7997196131656248, 6.956742213618371, 19.395337989253385, 34.107785686369866, 36.316511554102746, 21.144509161672286, 7.8420549919528355, 16.872145898880497, 27.30667429585611, 12.220487479240665, 13.95098130549154, 9.246815096947456, 3.210427381338612, 0.3633988937062602, 0.28050205159571867, 0.5737644313804565, 0.811123475432396, 4.036506731663981, 3.6839214448005926, 2.761284617647048, 2.781401228520178, 3.842579111937554, 1.0458658082831291, 3.328070539620615, 0.3343978692446986, 3.2340466687756204, 1.261720457865346, 1.0453248889215532, 0.5168362538660727, 0.4229423115330358, 1.585482452665606, 6.210036681544397, 12.248981537357455, 23.193369027106996, 35.12269896845664, 50.26557776235765, 58.57374614284885, 63.77193781637377, 59.59622959936819, 58.900397208429155, 59.43296486331571, 59.09153822929629, 56.28378406647713, 56.28611003198932, 54.20215868180799, 57.00813208856891, 58.516338333006836, 59.98566212192659, 55.92249847227528, 63.34401899768461, 51.848614984943026, 56.280869745439105, 55.32383103524485, 58.10348926051971, 58.25584196275281, 55.29540954097625, 55.51703522282263, 57.64217930455362, 56.85828578087592, 59.02170435074837, 58.03798175627186, 58.236779243715354, 52.6018669528346, 50.61372341648225, 40.96708543838994, 31.584162135278028, 19.402349225936398, 12.294370224398952, 5.588602337145037, 3.706845246976422, 0.6682652992106254, 1.2169776135875334, 1.2600052789334328, 2.3286427749741465, 3.5239233076572423, 1.7567341149814668, 1.981753505045368, 11.574754541920079, 5.546851648438362, 8.005997807748857, 13.769993339815448, 9.439155382494773, 6.626248205861738, 1.503756192903365, 1.0969063855947987, 2.341759425978507, 9.125013735986526, 14.107490739514752, 14.853777558572832, 20.365094984731368, 25.798015017663282, 29.567249974896832, 26.7053553365892, 16.01900096862547, 4.559097838017249, 1.380907559106427, 0.08365973544817779, 0.018744501435468276, 0.041525091134732774, 0.13053194409416569, 0.03748797631311802, 0.00818612923349945, 0.09500824020154054, 0.1428262763206036, 0.08041981938144854, 0.03284032388980831, 0.05200902353070917, 0.02062008385696719, 0.08218203611191242, 0.10048369276187114, 0.029447688195373745, 0.012101233061853678, 0.018231291474113544, 0.04636805001345854, 0.036075490211407026, 0.04658948006709257, 0.02006202519330527, 0.07725425214777071, 0.01564562790125849, 0.030387348660658446, 0.11897703993224329, 0.038037188576474305, 0.0687014856826394, 0.05305300984952239, 0.0668238501455034, 0.023184413796350844, 0.09504287503659727, 0.05306464289465258, 0.043497487917662635, 0.0684998053756933, 0.047772844592409755, 0.040419982490880836, 0.014327884850753172, 0.034594358801240885, 0.025286476706124605, 0.022470207261522452, 0.03451320710742185, 0.01899582807034735, 0.09494415694667448, 0.10382331517194548, 0.06047509565588929, 0.03195902591781511, 0.007583083971703966, 0.11607144463567004, 0.024465006370578083, 0.0798151538436932, 0.04763358512953405, 0.010524520691814683, 0.015157445074780094, 0.06665587770722567, 0.0913019068238716, 0.012767358960944318, 0.06035847409117607, 0.021282238547780344, 0.06670265503588223, 0.022475200239568952, 0.03294680628084368, 0.06712114588627893, 0.016391177008289005, 0.06162763280313342, 0.02033117869418235, 0.030041762567575903, 0.059610412215753916, 0.021219227816008275, 0.015097144379040167, 0.068500395263395, 0.06038133798527622, 0.025640629577420415, 0.05612345194564231, 0.02528114473417161, 0.03901264066958139, 0.04256792066078033, 0.04407293103154629, 0.0682178313934034, 0.015695195705179247, 0.10853751382279782, 1.92586463305258, 9.443576874271516, 26.40683747106983, 40.65282906255415, 38.68379531368133, 24.98678453506962, 11.528305834339513, 15.463102075361437, 16.427966894642, 14.116567104093491, 16.033996189794234, 9.683806357845183, 3.2075103636710875, 0.1677133933070206, 0.2643079334689725, 0.3963650973333467, 0.8258866638906541, 3.690506123727368, 4.415886219470732, 5.3757843375206, 4.948573506647541, 4.365355305133328, 5.344351933848474, 5.629871064616788, 2.7250509877358717, 4.1823473188184925, 3.362590829210897, 2.3132759092315553, 1.3876095414161684, 1.7976706667292504, 2.9479102550014376, 7.180773779269188, 16.712064166222852, 26.7771327495575, 38.54148780145953, 54.1816407634366, 61.526659381005075, 62.69281141219601, 59.34040084961922, 59.62645538391606, 59.24174539504513, 56.96111463731336, 58.3216554118741, 57.00031088244531, 55.801132494403475, 56.917337063820135, 59.28023561354607, 60.5816545024995, 54.30973360615393, 62.690603117788996, 53.71665946898922, 55.59191719178231, 57.640108293102635, 57.919581090250325, 59.11253859919887, 56.008280707943825, 56.498749563770915, 57.841757343661406, 58.946853760750066, 58.142093227755645, 59.127059213576786, 59.21277084658223, 55.581777864886874, 52.60569910849295, 44.80881167996315, 35.064765561011534, 22.76960792080049, 15.372390400978828, 7.036347206561797, 5.224910368842464, 1.5081881034758784, 1.0859651791472589, 2.7773606969464213, 3.215529649488388, 3.5398773031850017, 4.737483311084009, 5.436561953636908, 6.258354398512072, 6.77828662818478, 6.230429574366539, 6.2744527862918, 3.9798377983031736, 2.8330745331702696, 1.0297709751513697, 0.6392365730097217, 2.439545830411296, 7.3210524455193555, 16.54371996079722, 17.789525524262462, 19.773674126594297, 28.075802057020127, 33.3223428264741, 32.820869761128584, 22.906255452863633, 8.252645269516977, 2.197944497869861, 0.1597586120929449, 0.030314802049448898, 0.03451346757731611, 0.08160353247677127, 0.008974039172303052, 0.04375023181520162, 0.034042197099376115, 0.03143706340192547, 0.08320172212176746, 0.03450372676935888, 0.02486897219393042, 0.0626257955727558, 0.059444994680703654, 0.05579991003258094, 0.03165464386373999, 0.04194513331317613, 0.04468348778543934, 0.005628231559850035, 0.06583326015501254, 0.07763642276967726, 0.08402196480141533, 0.04867572900688937, 0.07516089391203658, 0.05335002213776593, 0.06599811461543845, 0.05144900176674128, 0.08862590041732596, 0.03761243878773624, 0.06609344659673591, 0.038923483356953635, 0.06912361545067641, 0.14359417221238538, 0.01576287670045971, 0.07218807440010772, 0.028415110840972875, 0.06277081984726172, 0.028799409272089124, 0.12845587646288256, 0.16165376040002993, 0.2281934302300215, 0.22677484989887287, 0.23020784310515852, 0.1384290082440261, 0.1995326560591498, 0.17035403709498145, 0.09811889425280595, 0.1665511306735777, 0.2296039513162067, 0.10241624148141953, 0.16847981830998776, 0.14115851823120348, 0.14107570412658876, 0.13113419645495955, 0.27359098856968267, 0.13193458979648928, 0.18008551410128995, 0.13936656196751904, 0.19253134787563356, 0.1815066378443472, 0.13376253687085646, 0.0869097179102321, 0.17571467605810012, 0.17406629999318432, 0.175403920152495, 0.13265129569317066, 0.14789063843988604, 0.20201122628584986, 0.12499554923945859, 0.10598019741836096, 0.10548391800013282, 0.19261753276711513, 0.11884716504644002, 0.1577949602036707, 0.12839557002148322, 0.17794630550328763, 0.14537307433784008, 0.23468366583749173, 0.16706670784661848, 0.1902915672549317, 0.23904063768925207, 1.6513872194674708, 9.790379116612097, 27.421095717337828, 45.701778473392615, 48.389049191628736, 31.40722597798994, 16.90406026378755, 25.663707179407922, 38.42340092505179, 21.01767343859519, 20.24550780173271, 12.421087295778337, 4.16032713267111, 0.4506485861155295, 0.9647994260153464, 2.3038533954851093, 5.177465869534401, 11.314309162478294, 11.699292736668742, 8.486904905688379, 7.593177172445483, 7.540552693028604, 6.465282469026505, 8.642035626596021, 3.6187316525367, 8.60851603169595, 3.3349675372723615, 3.593056307684991, 1.7901859264219961, 1.166283920887978, 1.9217908839064262, 7.32375446827181, 14.759952502865946, 25.114896989637806, 36.87058164227393, 52.75207411858344, 61.626566071664136, 63.59680006580969, 60.17669723879907, 58.332889080047615, 58.88543336622177, 59.075982109192886, 58.64658847931893, 58.115134777561316, 55.02543672438591, 56.66317139902423, 59.25519912473617, 60.58435701554822, 57.00464510148572, 64.73724880526143, 54.76609745333272, 57.64736860029159, 58.22420020257273, 57.49332143414406, 57.79272771650746, 57.428343449869466, 55.718288113993985, 59.9795824481595, 59.533777621484575, 61.288406771998254, 60.66525197798207, 60.693587180106874, 54.71908000207717, 54.10005546385243, 44.66333489264212, 34.58699341743223, 21.25205662942702, 15.605365460918797, 7.5270038458608814, 6.173459599095007, 1.6783628300313027, 2.6998502496750127, 3.4319508364123688, 5.584993756586506, 7.738798597166616, 8.428697912923752, 10.313972388544391, 20.68218331183157, 16.72428038812453, 18.537970627507857, 24.327777316493375, 17.51641285034918, 12.216054220353405, 3.0484437894436622, 2.095042096991693, 3.4918929876819735, 11.372297483105815, 19.502932525450184, 20.858078079838908, 31.193656844477502, 38.3790938315853, 39.90910845418131, 39.19937126098141, 26.339445267954183, 9.79838957709651, 1.9637532580283381, 0.18185899232424077, 0.12904360379663207, 0.22072591157930516, 0.23792026474350886, 0.1303075875846609, 0.0812597122163542, 0.11536864323481438, 0.1935920732155923, 0.11427759613481261, 0.1298496661888015, 0.1111316484128756, 0.13203292484244994, 0.20182632330444553, 0.20692987848193417, 0.24560172110795978, 0.11019485311642771, 0.17967674490665236, 0.13573558099808233, 0.1339320874502582, 0.17891131581798678, 0.33021018750244574, 0.16620881194549222, 0.2003248982251652, 0.09585175663232805, 0.27307056972096044, 0.13159165819806437, 0.263924154062425, 0.1682396650674843, 0.1419904897169721, 0.19843944859120155, 0.2465498162012908, 0.37165392009961995, 0.171167423287707, 0.1286792370580858, 0.14041654675477935, 0.16512803042367583, 0.11854914918301568], [0.06488724115995631, 0.017259168033037457, 0.07171534452467196, 0.05867146038179917, 0.020236576411632762, 0.023200913415020032, 0.051418530619553024, 0.049777279172333024, 0.004698901790224257, 0.04742324419860398, 0.051276689440372496, 0.03796991456540362, 0.051125256840379975, 0.06680574748785266, 0.09826482634150213, 0.013357948590700906, 0.019788522228238084, 0.09163137059658767, 0.05802466383864803, 0.047203756177858006, 0.10365594794312794, 0.06058691001887764, 0.04340328591605348, 0.048735426408388925, 0.09056185822813742, 0.029780739174795248, 0.027833675004301534, 0.029416968069610097, 0.02232418324227535, 0.0500717748617453, 0.011348417610861363, 0.034982167830270146, 0.015649443019121405, 0.029813397503007325, 0.07934341222167977, 0.044489273005315376, 0.007774428316136643, 0.07898114456404602, 0.07381310010509146, 0.040481725347138224, 0.03850769679692965, 0.036372341621186466, 0.04672218947821567, 0.05705371634253571, 0.5748058206612064, 4.908889907021677, 14.647182399226775, 29.18710562490648, 31.356817637720418, 30.459336196222615, 23.466895511073453, 28.326951419153524, 35.291235370020715, 22.667451750847604, 14.515282896257217, 9.009472477820612, 4.1359956898996915, 0.6387951837912683, 0.40100526124719654, 0.7814721342536711, 2.4533655662690443, 4.27444358987193, 5.670661753223789, 5.150133813581159, 3.1667674789505624, 3.2385573944737835, 3.056218907717736, 2.424491773689947, 3.1662127087193155, 2.6075348161881973, 0.22474168319134946, 1.6182842538241418, 1.7286623245285404, 1.0618704269009254, 1.1123498601298178, 4.52553411645274, 11.758139075771457, 18.721427725207423, 31.252543387874482, 43.04400005648213, 54.7202096446868, 56.771946568642896, 62.063337679832216, 59.118900683618364, 56.3791133511451, 59.05180069708056, 59.16915016789591, 56.47266187975484, 61.59142555729036, 57.42582528821884, 57.77550458908082, 52.986141558616396, 61.89573087999898, 58.028885779842255, 55.92783289570963, 58.66440780701176, 61.97273877359206, 55.86238030464419, 58.11145559433968, 57.61020022053873, 58.885547114956765, 57.3514610721219, 60.465583724360314, 56.04466069129206, 53.61685475995464, 47.68801573784121, 38.09111341353386, 27.300873110371253, 17.070125572143063, 9.094688911591808, 3.5696946709386768, 1.4326210680507845, 1.2568455646114967, 0.2841273022274817, 1.058789405130571, 2.053987751564672, 2.150479651266529, 1.9475916220295815, 2.698822588689866, 2.076376517934184, 3.0912177264690404, 3.523474196272512, 4.269732332998707, 5.503807558167366, 2.486513271447151, 2.004672649406618, 0.5225716783635078, 1.4463491185057549, 8.219447308971036, 16.966367113974787, 18.449123059549642, 17.24831884907138, 26.58057885785257, 25.126434641499674, 26.25279030492229, 19.69586410830098, 8.716916614963163, 1.6888293071139244, 0.17584552387556723, 0.0769540605946414, 0.0406578298087322, 0.05818690976969177, 0.01364078346429573, 0.016822448120482506, 0.06250972942178769, 0.13663129099915106, 0.0883444550357038, 0.044472583779884924, 0.040198491150212866, 0.03351904331676422, 0.034508675697349736, 0.03536238492796979, 0.0751164761341868, 0.022215511754996354, 0.04602670421703689, 0.08122500077250504, 0.06505050981837897, 0.11443645978767066, 0.06552597462770439, 0.01780799725243161, 0.018744714024867264, 0.03686820735193549, 0.03393569172570302, 0.09158008101005709, 0.021766446335541628, 0.029184217151675015, 0.04991583766475801, 0.03610677724223464, 0.049479699979025515, 0.025633110424443602, 0.024175787111744288, 0.03158101323811758, 0.07064754053229286, 0.0781090070884074, 0.037110612892936316, 0.015702913083406468, 0.04984573295880711, 0.03271138363127266, 0.03221930620530921, 0.04132372492383565, 0.009746109285662252, 0.019636009444272327, 0.07250263010181728, 0.05935048241348517, 0.0354268167528414, 0.033261890583220995, 0.03305375215507323, 0.027255947033183712, 0.040341324413255344, 0.04265811985298511, 0.049307797509696216, 0.04427857967394014, 0.04628021803293978, 0.031582813544739644, 0.06784033390783495, 0.0700622876625388, 0.07448583255491911, 0.02859874977730215, 0.044805820535628066, 0.0363051786928648, 0.07557078925592285, 0.024890750158397902, 0.038836708577770385, 0.03287076439347959, 0.052538574147488804, 0.020923067800580494, 0.06898310726448413, 0.06853668484836817, 0.05638901249415452, 0.022955619722544666, 0.014896373801504173, 0.0809726054449716, 0.06312929536967028, 0.017674795629817153, 0.027387001694390373, 0.025924444085948413, 0.025495861942369132, 0.06912644231511701, 0.008288957385135996, 0.10172167552574989, 1.5727353624759184, 8.055277976297564, 22.040582472278228, 36.55269707402876, 35.81946096112652, 29.23780029819858, 22.465359472459365, 24.587349968571818, 27.7513220233302, 29.857989780364502, 18.644286471028483, 10.439350951102472, 4.259906305420784, 0.35913009857458456, 0.11527296651395098, 0.4012723194976007, 1.228935694502246, 2.3385389149188995, 4.305792152881622, 5.561238411934146, 4.647875293608635, 9.103351466117367, 7.597741830733515, 4.275524202854403, 5.704987395194269, 5.067841506773426, 3.2582587244049197, 2.7420620620250706, 1.9426201404102388, 2.1585813068574478, 3.3532227383505915, 6.228502219723118, 13.412631096378451, 21.881222455732285, 34.992076196978175, 46.66243753125591, 56.48964574260097, 58.85024970577609, 62.17554100098149, 60.00228904908704, 57.67154216766358, 58.620332133385446, 58.41083834248205, 57.61658191680909, 62.96348633304719, 60.52563913406865, 59.090298760321836, 52.19690184439383, 61.952966105553415, 58.92220558658723, 57.16021806963029, 58.018542489697865, 62.30129611107611, 58.52553236869074, 58.262631585521085, 57.66422694729221, 56.6304745212678, 58.03269440127958, 60.38073109042261, 58.41405076365317, 56.56860697653986, 48.7645729895561, 42.29588247114613, 31.026934539118123, 20.63053354140251, 11.838252505948468, 5.475492458189688, 2.3401438997637842, 2.2221374319445704, 0.2790088236572281, 3.168536958194548, 3.5706681541858183, 3.205336144854946, 3.892713131443147, 3.209657861340431, 5.3841311412472885, 3.9450453942821877, 5.1444963870509985, 6.045660934140606, 5.733442229609336, 2.4144053987918364, 0.8004106244733258, 0.5340816897730674, 1.5904210844347555, 7.186079765519789, 19.528292609799294, 21.5718964992031, 16.45158838841223, 31.145064561597763, 30.376876208090014, 31.096617406414403, 24.595641859116096, 11.214671154176036, 2.59162298613979, 0.2508149034674129, 0.06934362058077129, 0.010154616095185762, 0.017087686912066514, 0.022484094520369848, 0.034644081737966306, 0.04797126519523802, 0.01952747010716027, 0.06999459613354937, 0.05294612143188716, 0.08384287642735629, 0.035951134989098195, 0.06470541785200758, 0.008410803669492805, 0.0937053468078375, 0.015942807771235464, 0.005870992374125749, 0.05535875447094441, 0.010924810250740378, 0.056956254636808756, 0.03323871259307189, 0.057823071631813244, 0.05515804326522255, 0.07537540619171436, 0.012805636544080993, 0.008461458360656135, 0.05116805051183028, 0.054030936406624895, 0.02829366100711688, 0.028584785909662326, 0.060639498124439875, 0.047662091261196526, 0.0556053773259684, 0.058390482313810825, 0.10957930146926835, 0.07192611829527924, 0.0617968654560466, 0.015219468510739747, 0.21986628431947003, 0.12033537510902652, 0.110758310784736, 0.13234260822496108, 0.09568439706438973, 0.10575944918297953, 0.19703988256233354, 0.15193898411047074, 0.12104045945189654, 0.14764541369532386, 0.11914455271776646, 0.09515988730615187, 0.08767144679422341, 0.2944051991066625, 0.19175166955157635, 0.1426927471954015, 0.1404951780193275, 0.15029975513537086, 0.15866244752560893, 0.1989536621277371, 0.15389105275032983, 0.10118502327391218, 0.12514135875408688, 0.15043110857086797, 0.1391527008625769, 0.14612419290408013, 0.14581282412813557, 0.11756103365652024, 0.14618324296128365, 0.12838554193055438, 0.09241849529526888, 0.21237651847543257, 0.10504614471668199, 0.12305242850655511, 0.14339877382641839, 0.23672722069726837, 0.11107632154298407, 0.172174645047034, 0.1771834657918061, 0.12558373622596264, 0.10641066988389339, 0.2048095922556616, 0.16947014016970513, 0.18679884983406914, 1.2175334869853913, 8.00482403847479, 24.647626992194887, 42.46197131372268, 46.83858725332445, 41.77446611465947, 34.133512512330086, 41.365919882251376, 47.42742915307322, 33.35844824391027, 20.878594037025206, 12.816500452256973, 5.184383459629552, 1.2282881357016102, 0.853071079379128, 1.6918986843478296, 5.6385208714392885, 12.412228622744161, 14.847763584506128, 12.02524365917329, 11.598930070477149, 7.348263888589798, 9.34332109266712, 6.573190794837091, 8.13767618709995, 7.858804493181168, 4.665110188145792, 4.218520887436406, 3.5302103767471933, 2.409045970247638, 2.2015800447233262, 5.781812898574337, 14.173259081379062, 20.321503723821333, 33.98308961622177, 44.58782534445486, 55.98942587452551, 57.11537753382037, 63.11479568481446, 60.0245249655939, 56.28873802000477, 58.85052427168816, 58.47041130065919, 57.49265463121476, 61.731948391083755, 59.81239926430487, 60.26172637939454, 53.438033903798754, 62.60300090236049, 59.56841999484647, 57.0034723128042, 58.2361634315983, 63.36913785626812, 58.304938270199685, 57.32268264216762, 58.2971013745954, 57.91673344950522, 58.85641959405715, 60.56241135443411, 58.786656318172334, 56.5306737346034, 50.797898307923354, 41.54298351657006, 30.4744843898281, 19.471075034910633, 11.098897495577413, 5.529799144114218, 3.0480733706105143, 3.5913530184376627, 0.9206608106051722, 3.0530535549886766, 3.8379212973579286, 5.601486342568552, 7.147974919888282, 6.6212319847076175, 7.410890902242354, 8.155610244120322, 10.72633900950032, 11.300381806588943, 11.801016465310129, 7.445313622874599, 4.589380987228886, 1.467140744770727, 2.482039563117489, 11.118933943010147, 22.421307333054084, 24.680839661628973, 26.321255276280066, 39.1267878009427, 36.180432765714585, 37.72134765501946, 27.735473686648955, 12.660600946795556, 2.3450444109978217, 0.3837948815236169, 0.22091433856516118, 0.08964003228972997, 0.15733664044209067, 0.08645882920151757, 0.09449516813601218, 0.23365804264622353, 0.2941762001043366, 0.23038220471672474, 0.19822586327791217, 0.1578604453994382, 0.06588863299017952, 0.16583064030255043, 0.19699978552037672, 0.22134713227710417, 0.059120158079050245, 0.14604902435694972, 0.13260381356362375, 0.28431946772240824, 0.2861077927293316, 0.1702485927530835, 0.18054887472141176, 0.15539448497997177, 0.17339007418242194, 0.15525416831576055, 0.13515946755726493, 0.14176257855949864, 0.16105238137946976, 0.09061684801934228, 0.11546414375545518, 0.16433742768581838, 0.17986098905244183, 0.1757280213097411, 0.12042205029677962, 0.32055824574443603, 0.2306215918713039, 0.19444266063792093, 0.1090326211265018], [0.014388206613911016, 0.050700422781970234, 0.03045659917857378, 0.01277659415087152, 0.04318487424884112, 0.07602671116229988, 0.024793872594713204, 0.02345516650576986, 0.07633745940702577, 0.03953792034618316, 0.027986088196837136, 0.02965455108712758, 0.0673107603084176, 0.02853314392268658, 0.09384872016286659, 0.05323126318774397, 0.00746998114458796, 0.03308328101411462, 0.04994380370443387, 0.03338530734782258, 0.039446369008792025, 0.057119645869299296, 0.05944034069656365, 0.06776673584094933, 0.002258825327096988, 0.021290512297362573, 0.06641326532248529, 0.007076481518696153, 0.09169582157365738, 0.061862124655876434, 0.053849691495059006, 0.023924224904828498, 0.06520191943573375, 0.04018708027058071, 0.05268602692071469, 0.029111036602708123, 0.11298873747188239, 0.043764006076080185, 0.034219354931865974, 0.06863418485849135, 0.05286115462020521, 0.026018630765799074, 0.052927903861047766, 0.09602382764100068, 0.05555737042619337, 0.4733259837713934, 4.602015922146459, 15.383416183533209, 28.893624082688365, 37.892127652322095, 32.98788232188071, 18.881195668251284, 12.087028834127612, 14.59701822650048, 18.217862075374974, 16.786783356820386, 11.708853513963762, 5.083293684067265, 1.9038969086062525, 0.18918357429004487, 1.1701214698053177, 0.7586843280061599, 1.7289772173089368, 3.4374232782471568, 2.9129256548420077, 9.883539330574775, 6.098487905917629, 3.979564948428062, 2.2369676684179614, 5.706258733426371, 5.137741575317999, 2.166760919555541, 2.029823254673712, 2.984022536585408, 1.9230424877135985, 0.9396872477185343, 2.1654638407691835, 6.699219980547506, 14.600868032824609, 24.732969922404138, 35.75211778763802, 50.10066955320297, 57.48529234240132, 59.40057393043273, 58.92359802799841, 59.20913088706232, 60.34922269082839, 58.9401190511642, 60.93959039257419, 52.87039241483135, 48.259814939191266, 46.53159118467762, 57.663085537572066, 58.98418295768, 57.452838651595584, 55.845349373355994, 51.83726364566434, 58.561696621679495, 62.18351517954181, 59.72884101252402, 58.3731718217173, 61.87404801768642, 54.53067287322014, 60.460927870965776, 48.11259269714356, 33.72307569749894, 21.61290095698449, 14.409974121278333, 6.3218458044913515, 3.2036318750150743, 1.2154470312018548, 1.1288882888132528, 1.2212756732779166, 1.9084847333931156, 2.569797202464073, 3.9516945471686706, 1.6420989243253585, 3.80917914932774, 2.287136253810698, 4.77201585808108, 2.5797573260722624, 2.589638266832598, 2.4685520029837087, 2.0410517747363737, 1.5107041813673512, 0.665908445033335, 4.375629953799709, 10.661253160045995, 15.772316244340713, 15.967733629288213, 15.77113070795613, 24.236782250865815, 28.346990808363888, 32.51560738009791, 22.0332613683516, 6.614925303766805, 1.613680249260318, 0.16045423524995006, 0.11850609504167112, 0.03769128838734281, 0.05804313038806281, 0.05285134486433479, 0.012553195251272091, 0.038266122461326664, 0.03415485415908118, 0.03668813072445412, 0.00877720820191767, 0.05094935156164631, 0.10606265146165125, 0.016017478361215084, 0.05210150183448869, 0.07917830495223885, 0.06127847290988411, 0.03969485728791164, 0.1341894317057825, 0.039955411451838674, 0.06371595401076541, 0.06298756527323877, 0.059396689006638144, 0.01848809372243141, 0.004438245162037352, 0.03725138537946247, 0.17090526800001823, 0.024059935465394974, 0.015141840821372406, 0.07431946124040312, 0.05958367574719652, 0.06218572402553213, 0.012642149550599918, 0.0025893008146780517, 0.022798198230204084, 0.08349377016026167, 0.05695130187837828, 0.04871715138095522, 0.07319989268698039, 0.05666975307488634, 0.016585386042753537, 0.09876515836484971, 0.04745866810422271, 0.08570171216683042, 0.05944828885877806, 0.07368892491344484, 0.03826981883556132, 0.025497371135579965, 0.05165956103272977, 0.005947370382566606, 0.040083482200580264, 0.011627667192970554, 0.02088595850152835, 0.006942518596206942, 0.0970256867848577, 0.09953595772986451, 0.029624459153461843, 0.010425426261199099, 0.019712156668725996, 0.18125218940117668, 0.11668810711031961, 0.013919217162765564, 0.04686409577486977, 0.06974357976427964, 0.03562605706974864, 0.04930836824519981, 0.012245130229500995, 0.01703200189607038, 0.04339156094037237, 0.07553313603444446, 0.04759965509536767, 0.06337654641679218, 0.0554175632104518, 0.02252788985178115, 0.021028291892200228, 0.05224284888695806, 0.1288111420768884, 0.05850577088553579, 0.05186555441468955, 0.02497350489119849, 0.028494376043278365, 0.04979616707010616, 0.08087951044041304, 0.054496059028972546, 0.04041713264380251, 1.0921578662049387, 7.341259025758313, 20.517267257936542, 36.05220264004123, 43.48527454560803, 37.72009249656431, 24.242901148334628, 21.03179201003044, 19.53848881106223, 26.276738336009366, 20.991450432808172, 14.32874869915747, 7.3558678934651045, 1.0950089390239408, 0.16758790810502347, 0.2880915008004635, 1.0227226598128196, 3.0947287380695347, 3.619811039778494, 8.786825018544352, 16.562257082231586, 9.169836621130667, 5.635694803730135, 5.296722592846041, 7.618983426401693, 4.64042131939242, 4.163596918506007, 3.9879906898544686, 2.869828857721821, 2.2799195829899084, 2.37195358641686, 3.2855101266214928, 8.931022132596663, 17.479113071195542, 29.36078033139629, 38.25093823094522, 51.90990201888546, 58.37110865500666, 60.75600777902911, 58.184541117760446, 61.166228863500784, 59.615249172333755, 60.783597730821185, 61.684028794688565, 56.44190265286354, 52.776302599137836, 48.57886052900746, 59.552353966620664, 60.57336653432539, 58.859118184735706, 60.449125459117276, 55.96239682166807, 59.84510006443147, 61.98870282019339, 59.50204956916071, 59.597280794574374, 62.11618377316383, 59.01558153090939, 60.61220584377166, 50.00438713258313, 38.24583130498087, 25.85078070240636, 18.611107141740863, 8.777276008359848, 4.666639422216724, 2.597892894860237, 2.06813145068384, 1.2192762450825785, 2.607009218585107, 2.469829224771069, 3.466412290450066, 3.486521056582851, 5.163205602476674, 5.044344057959895, 6.404257253293069, 5.712830174353815, 4.219527465681876, 2.560286190240614, 2.033378147790509, 0.517538664562087, 0.42274603980683517, 2.574053954693579, 9.465808868408203, 18.40582205403236, 25.054051222339755, 20.592706203460693, 24.119034659477975, 31.867219978763213, 35.42059906067387, 28.118230335174072, 10.406691335862684, 3.035152347818498, 0.17262882793382292, 0.10816856587846434, 0.041716050041178544, 0.09088509370602908, 0.01734564595315005, 0.04998633690598992, 0.012281550049421289, 0.07852677781615527, 0.036013425598221446, 0.05688169129913854, 0.07240520670048653, 0.07333837074017333, 0.005561930001638229, 0.026439266662383755, 0.02292544351920726, 0.02423629273600396, 0.09396164918378477, 0.06584822951305298, 0.04057161810417329, 0.04723102507752277, 0.10856404344761565, 0.0566166440295356, 0.008767635933303786, 0.04179773416610495, 0.04967271200110836, 0.05898594330515593, 0.032824075164934324, 0.022129640959563757, 0.11346822424281029, 0.006673533155868251, 0.023522653106239536, 0.0809373117743, 0.05721924879077462, 0.03592368222833161, 0.02969243030454363, 0.07697824599041093, 0.062198203597818656, 0.037360139221193335, 0.011592519079004566, 0.09445743830574137, 0.2341340896823714, 0.167810395359993, 0.22042748968928094, 0.21822412888849937, 0.13297286876026662, 0.11916471615193353, 0.19763859559691724, 0.21012903101021246, 0.08373051431150207, 0.16214503726411253, 0.154676629951404, 0.2800750341867247, 0.2593212220216951, 0.19624362609559493, 0.20950967956694866, 0.09195481291821889, 0.1682914219676487, 0.14321858994662762, 0.181798578630532, 0.28846302280022257, 0.1191780077774198, 0.1144507320057, 0.13537771068513393, 0.1108266075231856, 0.15147413727977585, 0.16715773441378148, 0.11119282819450864, 0.2464998979121447, 0.23591777219647364, 0.1589049143536437, 0.2326959741091536, 0.14548011214262055, 0.11319462360153276, 0.1797904017110986, 0.18899010644564707, 0.20223474009863793, 0.12408589643816795, 0.1026064457912599, 0.1589180144571489, 0.17535498245589196, 0.20877408194205455, 0.210810374288309, 0.22530959949137705, 0.18387395678268326, 1.2675194370169796, 8.240824226410158, 22.636282636273293, 40.95143125903222, 50.93251797460741, 47.22354435151624, 29.33642633499638, 23.771249863409228, 21.67111481389692, 30.327091524677893, 23.991188926081506, 16.915823451934322, 7.1252928337743215, 2.3478011017845524, 0.5339576448163679, 2.797390280231353, 5.063570045655774, 7.364967301968606, 10.266846091516557, 6.939193039171158, 18.892466598941436, 13.243143520047589, 10.731910736330095, 8.559066710933562, 13.781852626031446, 12.744772068915829, 7.083863289125505, 7.810236234818736, 5.568400659868795, 4.303847637868697, 2.226174041148155, 3.263006018054101, 8.568679459633367, 16.245848305763737, 28.086086511611942, 36.85323692137195, 52.801013531223425, 57.89024568373158, 60.886344217485004, 57.563531860228515, 60.92919611161756, 62.22653965796194, 60.69536009142476, 61.06667126378706, 58.917992961022165, 52.524247169494636, 50.28659382174092, 61.14569917801888, 64.90438099830382, 61.214701514090265, 60.93811165901923, 56.77325271791028, 58.82165170484974, 62.645821417531664, 60.391737261126124, 59.55916712360998, 62.85330695490684, 58.84561346423242, 64.35795953196865, 51.44483443229429, 37.581138610839844, 24.783923472127608, 17.209997292487852, 7.6659979358796155, 5.267789229269951, 3.027925871072277, 2.689784467220307, 3.0675709824408255, 4.34341944994465, 4.565881577230269, 8.106311444313295, 4.6236497548318685, 10.181154070361968, 7.160901581087421, 11.279051957591888, 7.601222934261446, 8.55079835461032, 6.425005120615806, 5.841747205103598, 3.4757350289052535, 1.6026082562823452, 5.895507210685361, 13.086557599806017, 21.657208050450972, 23.06254033119448, 24.979553645656956, 32.50832549987301, 39.38778623457878, 44.03671664576377, 32.879856324964955, 10.848945436939117, 2.5443949526356113, 0.3271702586883499, 0.2577642249243875, 0.08959765996663802, 0.24167935093564374, 0.15613608873419224, 0.12253788555221212, 0.1674783268883344, 0.16804429732503431, 0.15822683461010456, 0.1507821300577733, 0.18441064733891718, 0.2513265582702814, 0.14828957106557586, 0.046311497402888153, 0.22162600360330076, 0.19001831901409935, 0.133152945387748, 0.2617069730354894, 0.11792035953652476, 0.2731058710525113, 0.2199388175241409, 0.26134868903506187, 0.12616275314001307, 0.11769955767498863, 0.14900166511295304, 0.18434151556463013, 0.09615103654082745, 0.1399649838886915, 0.2533222632783075, 0.12721570268754037, 0.3285433027532793, 0.2678061054358559, 0.1012635626079094, 0.10635938795824205, 0.20085185946476078, 0.24486092940693904, 0.1717205387690375, 0.08437422735075797, 0.16033487875134717], [0.04841197642587847, 0.042763571855762315, 0.002097487449645996, 0.01996896849314292, 0.0845961400397843, 0.04510485529599171, 0.06479421510331093, 0.002523383497440767, 0.04203242520170827, 0.004722560021740895, 0.03908733807263836, 0.05604212788204032, 0.06205312569715804, 0.06366190650770742, 0.05266692068788314, 0.026996306429106384, 0.09649433586145602, 0.12889743422067937, 0.011534279159780954, 0.06684849519402751, 0.07469001030849834, 0.05942226485199025, 0.030567314205390793, 0.06819502495589756, 0.06288548022688878, 0.058221739957169186, 0.04646758398702068, 0.023046372413274743, 0.03635308217077005, 0.030908104588067344, 0.006511906798433272, 0.004685511052112786, 0.0399330263626912, 0.06071909849021224, 0.05582033776708188, 0.02242879637877547, 0.01708675036957908, 0.0771033941137214, 0.029972749536917098, 0.028326778988083525, 0.026650793114376646, 0.023432599470740365, 0.07359334012313236, 0.0643224198551428, 0.01297371814988794, 0.07608798287448383, 0.3112659975886345, 3.3509472733543766, 14.22529422467755, 24.73989094457319, 34.10502826013873, 25.934791987942113, 18.342207093392652, 24.841872569053407, 16.309898649492574, 13.560049456934776, 19.007898030742524, 11.898975699178635, 7.390618132006738, 1.62042623566043, 0.45401876011202413, 0.8954233616109818, 1.694142892956734, 2.637602235040357, 8.569814985798253, 21.525259517854263, 11.786371315679244, 2.8943640185940653, 5.976257535719103, 3.5056771770600355, 1.859534043938883, 1.8159114040674704, 1.7940336489869704, 1.4848301439516007, 2.0412955745573966, 1.5462299460364928, 0.557870987442232, 1.3473858804472032, 3.878386674388763, 9.37393028889933, 18.406373147041567, 31.17007359381645, 42.8702155236275, 48.49688299240605, 51.85580861183905, 55.01261449629261, 58.67853618437245, 56.56179774192072, 60.44437939120878, 49.74658150826731, 37.22812137296123, 34.57035864553144, 44.8354837971349, 58.70572213203677, 51.554095975814334, 46.96783327287244, 54.718715221651145, 64.06460546678113, 62.0502055844953, 63.740056791613185, 59.41856584241314, 62.40882788935016, 50.943218200437485, 35.191336524102, 29.857189616849347, 18.985473840467392, 11.74630528496158, 4.247248326578449, 1.9831813703621588, 0.8170238233381703, 0.9071646702866402, 1.0889404194970285, 1.5286663078492688, 1.2039314426722065, 3.3211210802678144, 3.175206703524436, 4.056497581543462, 2.769550032192661, 2.405943620589472, 5.591256801159152, 3.834417885349643, 2.8456744119044277, 4.255387734982276, 2.549210887762808, 1.1077478167510804, 3.0562895103808376, 8.911531875210425, 12.552252334933128, 17.111294769471694, 18.770700539312056, 15.417695737654164, 22.608525983748898, 34.333039560625636, 24.40616588438711, 10.229080530904955, 1.2038222291777212, 0.19966065402953856, 0.00971934696163742, 0.03953371452347886, 0.02277436715009953, 0.0451967743555865, 0.02302458870314783, 0.055644470792744434, 0.017936665549754136, 0.08655872706684374, 0.10636544005284387, 0.07429474724396583, 0.052521494217216975, 0.05119713503987559, 0.04204629139313775, 0.01563899741027384, 0.03781369774632397, 0.034407176708261815, 0.02354030760245458, 0.04165860493817637, 0.047572635174278295, 0.053186067830651045, 0.030473820835111604, 0.01744469154566046, 0.015341942029584561, 0.025390792983554067, 0.022818036077003327, 0.039952534791683, 0.06197964637390068, 0.05557038626002689, 0.08773926089728072, 0.048489627097883535, 0.023484622586458444, 0.05085079051974801, 0.051798912426156384, 0.010785747097895272, 0.05323266129820578, 0.061113124322747035, 0.0784360423624035, 0.057847134453514894, 0.06780418987956739, 0.02666134214509399, 0.01620797282685676, 0.019826462732688076, 0.038529032345620856, 0.05541505427249978, 0.06953016299033357, 0.00744452404286412, 0.04162026223756614, 0.01071553226680525, 0.018670399665772434, 0.10618710244495062, 0.02311357939165206, 0.04887263658606718, 0.05647254672141806, 0.043882542860604105, 0.07504964262367257, 0.03890126297670988, 0.05697341117587301, 0.04551219956709012, 0.02709132814479451, 0.04553724298133485, 0.016684661461641232, 0.03795784485015658, 0.053159473088359645, 0.02342397715115259, 0.052484258513657324, 0.050087598407821315, 0.08621340527409509, 0.07739256932249955, 0.1132131016422664, 0.02548784866268116, 0.04670462308211192, 0.06737352589205389, 0.1131950066454949, 0.1238310649510353, 0.03386348793883959, 0.027354255266067003, 0.02190772827053743, 0.038970318142204516, 0.018389818048284903, 0.02350307572933455, 0.03426091903219781, 0.12301418539737502, 0.0775924569837028, 0.021139552756663293, 0.04656640166837362, 0.825729217500456, 5.740362761482116, 19.372013615023707, 33.052664187646684, 40.340431890180035, 30.100782532845777, 17.97579300019049, 17.483408066534228, 18.057882324341808, 19.571672062720022, 22.977428820825395, 13.386723841390303, 7.707985927981715, 2.008404171755237, 0.7817391618605584, 0.1929492181948116, 0.5578480660915375, 2.5055605461520534, 8.551487711168106, 10.483067727858021, 8.000795764307822, 7.835157013708546, 5.990122133685697, 6.010562094949908, 4.154374445638349, 5.017439050059165, 4.837570430770998, 4.103502775392225, 3.3948787998768593, 2.157282266886004, 1.4937660386485438, 2.5023491055734697, 5.518882207332119, 10.86186376310164, 20.52287820846804, 34.00590212114396, 45.703633754484116, 52.64739782579484, 54.62248771421371, 56.76997361644622, 60.572264348306966, 59.03455795780305, 62.704562833232266, 54.21277261549427, 41.20223545259045, 40.922072318292436, 49.513647633214156, 61.893134270944905, 55.41600673429428, 52.223173879808, 57.7515898981402, 63.524620609898726, 62.9499973020246, 61.76779493208855, 60.53836330290764, 61.7389968902834, 54.690623206477014, 43.15042180399741, 33.639474299646196, 20.519538310266313, 14.302164835314597, 6.256874684364566, 3.4133311000562485, 1.4689644017527181, 2.0985621790732107, 2.462080337347523, 2.193772812043467, 1.5984286031415387, 3.2092163495479094, 5.761289586943965, 8.393477970553983, 5.194831182879787, 4.77893638995386, 5.337637816706012, 3.783523906623164, 1.861699805144341, 0.7347868587220869, 0.5119688682738812, 0.6034195110682519, 2.7520479261875157, 8.6773673565157, 17.502496280977805, 20.69873571395874, 16.30606943561185, 14.054754472547963, 25.978408744258267, 37.33770062846523, 30.085418608880815, 13.685991860205128, 2.276314434505278, 0.3322289211134757, 0.030975943588982188, 0.007829272550635882, 0.011699136493036584, 0.053600103879768046, 0.07854766137297116, 0.02400093137346689, 0.011955678271460197, 0.004205227549743629, 0.01972011632225927, 0.10508474788718647, 0.045529302479999686, 0.05486631315321692, 0.036350308932484164, 0.052941019286311446, 0.038617515500875256, 0.050820813499270916, 0.01067536914976494, 0.019518221510694395, 0.010853063243801796, 0.03776845259351596, 0.016019047883849953, 0.04653275891717884, 0.010202015870280806, 0.018130614114324414, 0.08772764700434862, 0.04039193984241255, 0.020541192122524785, 0.07731150189835219, 0.04742826973538726, 0.06288382164653271, 0.036343000453686526, 0.09945829173610096, 0.030029528143425143, 0.10491061610199752, 0.05379401988560154, 0.09735004075111882, 0.10042018407294828, 0.011773943063622762, 0.05428897014128105, 0.20672919408928966, 0.2038090661047928, 0.17829400216860158, 0.12309323034940228, 0.22492549832790132, 0.14323869209376075, 0.2817085175023925, 0.1906684671919192, 0.18168726605513405, 0.13130520260141743, 0.1630475041606734, 0.1817771741339276, 0.24544934621982037, 0.21936661113173733, 0.1867046669846581, 0.12328338103308795, 0.1316936551443031, 0.2513272630711717, 0.1336285174493828, 0.2717336543625401, 0.18852763448751744, 0.13466036127459619, 0.09687138901602838, 0.19218567368243972, 0.13840342090735513, 0.1681095833379415, 0.2060328201661187, 0.28661616867588413, 0.13995991238663275, 0.19065715973415684, 0.14885964773354993, 0.14186747131809113, 0.25002358060690666, 0.23924974904906368, 0.1567826516205265, 0.3766393445191845, 0.10934813443811671, 0.2144732245153958, 0.1747363358135185, 0.1328329657835345, 0.14831289078199095, 0.07822489320871331, 0.2274119286167045, 0.2419680435090296, 0.10194660660119788, 0.09520593685128036, 0.5877264757310191, 5.168512569319818, 20.751256250566055, 36.159502998475105, 46.83979534333753, 39.426864808605565, 27.267370185544415, 36.38028144836426, 24.24253832909369, 24.393131848304506, 27.78057113770516, 18.190884013329786, 9.37300951250138, 2.2807861816498542, 0.7028725551020715, 2.284433005317565, 4.476726593509797, 6.29144988713726, 15.166623842331672, 34.7036329392464, 23.252571321302845, 9.202387390598174, 10.00265484856021, 8.525583397957588, 6.953078229581156, 7.998298685396872, 7.508742270931122, 5.110739979051775, 5.330975670968333, 4.303931968827402, 1.1606710091713937, 2.621003254767387, 4.2497351092676965, 10.770624529930855, 20.142323970794678, 32.25340870118911, 44.24202526769331, 51.62458096781085, 54.17555716729934, 57.26298416814497, 61.16254183553881, 59.75042581558228, 63.11413672662551, 57.749711082827666, 45.8298477818889, 42.78492358423049, 50.4874348640442, 64.93320257433, 58.51943700544296, 54.11811405612577, 60.10936191005092, 63.258978089978626, 63.21206654271772, 62.47542581250591, 61.36507734175652, 62.56225532101047, 54.00998607758553, 42.260090843323745, 34.71389778198735, 20.70756300803154, 13.910364181764665, 6.590543850775688, 3.4424946577318254, 2.242803910086232, 2.303336132918635, 2.8970032834237625, 3.8619198289609726, 3.131482082028543, 8.93527005949328, 9.710074470889184, 11.186479118562515, 8.748767241354912, 10.257761882197473, 13.566221306400916, 9.179887694697227, 7.4965456608803045, 7.411346877774886, 4.07869476464487, 1.8585033186020392, 3.766120840464869, 11.09934856814723, 17.833830656543856, 24.985548988465343, 26.63233845464645, 22.124717312474406, 32.292228398784516, 43.94506262194726, 33.60737754452613, 16.00316047668457, 2.581892321186681, 0.5598998947008964, 0.2522407769556007, 0.1698611361244994, 0.14057659784392004, 0.18762368138038343, 0.13325026919764857, 0.17543609584531478, 0.09980862374387442, 0.1498134425210376, 0.2073426160120195, 0.20895291750709857, 0.16678141670361643, 0.15351556241512299, 0.1486582432182566, 0.19712091934296394, 0.16137557855296522, 0.19564417761660394, 0.0605952603772523, 0.3635557272261189, 0.0977896832891049, 0.13459725095139397, 0.2299848042668835, 0.15110051619910425, 0.08886665120841035, 0.1299379348394371, 0.15757991932332516, 0.16805350570188415, 0.12611734710874098, 0.23605936056663915, 0.16392369424143147, 0.14575621023053123, 0.1000730696344568, 0.19107570421070824, 0.1253725947331517, 0.2093036325588342, 0.19883605230960155, 0.16800467525759052, 0.2085254098018331, 0.2149415800287839, 0.10570442108737846], [0.05737048986878607, 0.05929526279590303, 0.04387921803901273, 0.08551667128959972, 0.012912955886173635, 0.0453521944432249, 0.010272074610956255, 0.11190065513214759, 0.02053285134024918, 0.052190038615897785, 0.02803308386055212, 0.061980477579298525, 0.047276496226268436, 0.03090734041536287, 0.04486126997958749, 0.026711723917434295, 0.024978693221665682, 0.055689616354122284, 0.022241263800571044, 0.055408979195260236, 0.0502281793723664, 0.050631869404066, 0.038062258803796385, 0.08001270493672741, 0.026392922173404408, 0.022297730226249948, 0.026905706955961166, 0.10143148142003244, 0.038968667222727696, 0.0371567658599346, 0.008759578603560166, 0.03537390689035097, 0.010116660268977284, 0.04299542070516656, 0.011799119585644335, 0.00937529017157372, 0.11064016470505346, 0.03527917245763444, 0.05900676557493787, 0.010801849308453742, 0.08761682472522221, 0.05226509608027916, 0.082252508540067, 0.06825818124437524, 0.02479091166488586, 0.09483710382013552, 0.06745647023161573, 0.18258170435024848, 2.106059544509457, 9.684283906413663, 23.124972697227236, 36.13872228130218, 33.79647501053349, 24.002930541192335, 26.140277116529404, 23.3787755427822, 19.05796708599214, 26.32860972035316, 13.58933779501146, 9.01925192725274, 3.054101318120957, 0.5882711336016655, 0.5711640225302789, 1.8788189897614143, 12.103893064683485, 12.145721220201063, 5.525242820862801, 6.112560879799628, 5.174332386062992, 6.2796837572128545, 3.391907359323194, 4.016188609023248, 3.5155147266003395, 3.2755330877919353, 2.246687056556825, 1.625522007384608, 1.4325031517974793, 0.5485745411246055, 1.161211560810766, 1.979193913359796, 5.006685872231761, 10.323221337410713, 19.205038316788215, 25.48692595574164, 33.57617901217553, 38.10425727598129, 43.723962537703976, 46.051763719128026, 54.71025859155963, 50.87009737568518, 32.17158413702442, 26.370561430531165, 36.65821275403423, 49.28799367720082, 53.84398744952295, 62.818021312836684, 60.256121312418294, 61.30270773364652, 62.42855741131691, 57.439698711518325, 53.16569589799451, 46.057309950551684, 38.05333706640428, 25.65839040663935, 11.417954852504115, 7.257862571747073, 3.078462914113076, 1.4337817218995865, 1.3230267359364418, 0.573129375134745, 1.5409875757271245, 2.419658187896975, 2.0938146402758937, 1.6811826464629944, 1.291172554896724, 3.085229983252864, 5.313281368824744, 3.217777167597125, 5.217701542762018, 3.348374933965745, 3.5243564844131474, 1.4669551676319492, 0.3647897110110329, 0.7852266392400189, 3.277121157415452, 9.201401895092381, 14.686836581076346, 25.391059306360063, 19.735952692647135, 26.594679778622044, 25.200592933162568, 31.683229438720215, 24.47220486979331, 12.17391521699967, 2.9238847571034587, 0.21453964433843092, 0.013591600619556924, 0.054819509011483004, 0.01539580567154072, 0.046493979546451764, 0.013656260355586007, 0.01439564724287559, 0.04854669681780281, 0.027355779781036323, 0.044905009769624284, 0.0600436311064949, 0.0745682482938132, 0.03628953517745099, 0.06725184048616117, 0.06002210786626224, 0.05656977860076774, 0.02979666039708161, 0.06844801783201195, 0.039733625167319854, 0.034248313055403774, 0.09924447659643428, 0.11358472323345561, 0.027652041303114067, 0.06907000461773527, 0.05638008756983665, 0.007863183911409109, 0.06971519620668504, 0.01801405383664514, 0.023113903063800068, 0.039303432323879776, 0.014687246162324183, 0.0745619127466794, 0.04477301665071038, 0.04057653638864717, 0.13161615768988288, 0.02966454853453944, 0.02405973245209504, 0.05934998062589477, 0.046254906487921556, 0.03856585819214102, 0.09158774955017913, 0.09061076528122348, 0.11334053270759122, 0.029754856894273433, 0.015258818616970413, 0.033050166863587596, 0.04085960587666881, 0.020448457179290634, 0.046973263304079735, 0.024846510495990518, 0.009885306503894109, 0.020228683790792863, 0.029343674522674376, 0.0366088597764892, 0.04002276590214141, 0.04624229285024828, 0.004785150362764516, 0.03099176521983839, 0.006063052531962674, 0.053768689188385205, 0.08061538630675885, 0.05661865501033683, 0.023356141980677363, 0.04246621099751323, 0.0720722419059565, 0.030913189496664755, 0.06955087800780613, 0.0075357416532032435, 0.014071773996786966, 0.047065684151264935, 0.037976246282097795, 0.002416799839157912, 0.0407534912078371, 0.0226284637897005, 0.031547470078352964, 0.03469254446005629, 0.044108561780904575, 0.04877222544183174, 0.009855114978798216, 0.07455267372631258, 0.05372019199233863, 0.03535466659213266, 0.06519431218264565, 0.042095715555572705, 0.045635420979271014, 0.04631356584028371, 0.08397781515433904, 0.05318304561378975, 0.5584747260135989, 4.341742146399714, 13.842917065466604, 30.24782434586556, 41.94290445696923, 38.92584477701495, 26.891316867643788, 18.926410790412657, 22.470544845827167, 26.565163943075365, 26.606350791069772, 18.296140816903886, 9.308311977694112, 2.3952022098725845, 0.8504467072986788, 0.19440260956123953, 0.17184803112139627, 1.4158935075806034, 2.532800916702517, 3.738792952029936, 4.557976530444238, 5.3406021479637396, 6.018863301123343, 5.422970450693562, 5.856983652037959, 5.962136512802494, 5.415788590908051, 3.1454231662134973, 3.1872724044707517, 1.8325885865957507, 1.280104729437059, 1.5259932125768356, 3.0527610932627036, 6.80210227927854, 14.40454948333002, 22.859875386761082, 28.438189837240405, 36.80325023589596, 40.00559091567993, 46.720606280911355, 50.17113493334863, 57.08853283236104, 55.06529192770682, 35.81952764141944, 29.612888713036817, 40.31511691308791, 55.58399008166406, 57.84105523940056, 64.6332157811811, 60.79719658820861, 63.4975484109694, 62.17037523946455, 60.534256581337225, 54.348333651019686, 49.36501333790441, 40.80613490073912, 28.764036816935388, 14.539963429973973, 9.210453744857542, 4.317797057090267, 2.5971684821190375, 1.5769401433006411, 1.4647777618900424, 1.7775941375763187, 3.392346419634358, 2.605349075409674, 3.4093383723689668, 3.252077804457757, 5.548135734373524, 5.229623096604501, 4.874919729848062, 3.4497368239587356, 3.052603953307675, 1.2774251377390278, 0.5550038574203369, 0.2550093421051579, 0.776284983561885, 3.2519814612403994, 9.85281736620011, 18.181725278977428, 22.649875610105454, 21.72175849637678, 24.13470845068655, 21.99004665497811, 32.62898152874362, 30.366299536920366, 15.846775577914332, 4.3020335416640005, 0.49514508716041045, 0.030007296271862525, 0.029737535646305453, 0.01167212519043636, 0.0761114404867253, 0.03066598633003812, 0.056076057916206706, 0.054924823118433844, 0.01028005245907773, 0.03729028349381782, 0.030094185964234417, 0.06834993559506632, 0.02688632301625706, 0.029733931202621713, 0.004663195389683449, 0.056469516843677535, 0.011809483797649943, 0.0988952707379095, 0.008013604796536627, 0.028365205958365437, 0.04627378672481545, 0.09875411137698159, 0.054338696908446095, 0.05302510509688047, 0.11189311682697266, 0.02515623026767806, 0.04372829871792947, 0.09757213730124698, 0.010064301989792336, 0.024445118728063764, 0.013681550833186316, 0.03479339227440857, 0.057713325706220446, 0.038479615844065146, 0.07005035201267851, 0.026158476285936854, 0.0494319650404636, 0.016736334092133952, 0.047619948764481855, 0.024049229386653152, 0.050400545324889884, 0.20504088952176033, 0.24720808491110804, 0.16003996554401614, 0.11154948808853665, 0.10688433438659677, 0.13664736352380247, 0.1878242125554431, 0.2926875380498748, 0.10390040659976583, 0.10291466594583566, 0.15519124185366018, 0.23603910520192117, 0.15777288154969293, 0.07605917030765165, 0.16222950611864367, 0.08252135943621397, 0.10841830288090053, 0.10797745758487333, 0.08330103776027119, 0.1591486375658743, 0.15847397457447746, 0.1011779752650088, 0.13396214874040696, 0.19656749742646373, 0.16257354088367956, 0.09855089123330771, 0.09542568151148097, 0.15140716587343525, 0.13835123499795315, 0.0918696775671936, 0.11918877131275593, 0.12342472425511769, 0.12337159605756884, 0.18455761364631115, 0.11527895732151887, 0.12580949467636887, 0.32723485522212525, 0.09363878142809676, 0.22942888490375013, 0.14411877390117417, 0.18084387985929368, 0.13228653058890374, 0.13926379893335605, 0.14774773239849076, 0.13517613763049727, 0.23222997814657229, 0.1647964982135642, 0.5986499089387156, 3.610768750790627, 15.353139408173101, 33.51581373522359, 49.82849236457579, 47.52102475012503, 35.95129574498823, 36.01584619091403, 34.213132704457934, 31.285446190064956, 37.296241175743845, 20.420992682057044, 12.515056498589056, 4.128574565533669, 1.130194560654702, 1.1828669665321228, 3.360272463290922, 16.642916702455093, 22.36966540736537, 9.894195429740414, 12.894369306102877, 13.744669537390433, 13.42232817603696, 9.78435435602742, 9.667287295864476, 8.522517085075378, 8.525882478683226, 6.3749645025499415, 5.164841721134802, 4.2845397706954715, 1.2196329356201234, 2.023489239715761, 2.691162690039604, 6.4148334341664475, 12.0235844965904, 20.838299528245006, 27.285819053649906, 36.795232911263746, 40.58273630757486, 47.72298759029758, 49.53838602189095, 59.59646101920836, 61.3430336213881, 42.787559416986284, 36.86830274520382, 44.38634103344333, 58.19130720630769, 61.56993489111624, 65.92300092020344, 63.802402865502145, 63.23103120250087, 63.405529606726866, 60.258831670207364, 53.998301336842204, 48.675084114074714, 41.85443932010282, 29.283558668628817, 14.46011083741342, 9.402339035464871, 4.127548375437337, 2.8208695880828367, 3.050475822341058, 1.866075699367831, 3.9121994664592132, 5.955353263885745, 4.976954306325605, 7.286522840299915, 5.746321822366407, 9.277634139983885, 10.248899286793126, 7.602468777087427, 10.964929922934502, 8.783036989550437, 7.72802580748835, 4.291033254515741, 1.3519126633482597, 1.2719155559616706, 4.704053440401632, 12.297508120536806, 21.035486882732762, 32.41109386567147, 29.06625347752725, 36.291714329873365, 32.84752030526438, 41.59961077474779, 35.06447138324861, 19.06946159178211, 4.150393239913448, 0.6829474662100116, 0.11181927361195126, 0.1532916502366143, 0.15469395886025122, 0.25138194642720685, 0.15900971518168527, 0.14556442777956688, 0.24957771743497542, 0.10015871826439135, 0.11143137265237109, 0.13216751116898753, 0.1778775567729627, 0.19882943330993577, 0.1605141280038703, 0.1739460088673138, 0.1673673820351401, 0.12562888944821973, 0.1602368961058317, 0.16512179446797218, 0.11852416705580489, 0.13482254208816638, 0.18501233279464707, 0.2058071153418672, 0.12383560785242628, 0.2578664210534865, 0.1560281622674196, 0.18633126040860531, 0.248721108561562, 0.08605509320454252, 0.1424638401236265, 0.18999843137158504, 0.20221592497921761, 0.20785754967120387, 0.11058014171618609, 0.22983368576293994, 0.15709357606547494, 0.16845501238299956, 0.14608647073468856, 0.12752069761195492, 0.07342091671401456, 0.20248330498654998], [0.044118428993369305, 0.013712982463109638, 0.07358089885524205, 0.08973713393413252, 0.06445833917466864, 0.061818982414420576, 0.050084043759852655, 0.038796485131306034, 0.07926931619764337, 0.0712143000395548, 0.07414999493067304, 0.10968464621973616, 0.05645535187795759, 0.06057863626929541, 0.019301506728234313, 0.0055871079600746595, 0.030613513137664528, 0.07009938163983245, 0.03274059073338586, 0.025131479882064368, 0.04175508605136026, 0.014735796984525458, 0.08420054755744436, 0.08217229913439482, 0.023498858415311383, 0.05517662855826559, 0.02482657880342055, 0.040057109623786905, 0.0939779591956927, 0.0384508645642669, 0.022468225009018378, 0.04894572903492278, 0.04947963486155195, 0.038683996610944314, 0.023595408476408453, 0.029489037791086786, 0.05327769577683461, 0.1009068873921229, 0.05770349296771231, 0.047363569779742154, 0.050366638273361235, 0.03525097276114168, 0.039466306447021426, 0.01727979495039871, 0.09952144036369939, 0.028243112610653046, 0.10499537606993992, 0.04370744580463056, 0.04174163354740989, 0.9587950127259378, 7.1684869547044086, 17.52441644668579, 28.887875849200835, 35.28180991449664, 33.34623790556385, 18.685759652045466, 22.98776818859962, 22.283247747728904, 30.299721225615475, 20.655956383674376, 11.162195724825706, 5.310842635170107, 1.4606733692269174, 1.0108218209878093, 1.1312893922290495, 0.5166935163640207, 2.4977241408440376, 8.921513326706426, 3.413071733328604, 3.5908764504617263, 3.473893476109351, 2.6522574357448088, 3.133930866756747, 4.394292100783318, 1.8733252200388142, 1.8497468723404793, 1.7864257217414918, 1.8863685717505796, 1.0577221527214975, 0.8981939032673837, 0.6592501603787946, 1.4726461590297761, 3.709903960266421, 8.943878681428972, 12.780472501631706, 17.27807394919857, 23.73998857313587, 25.59681115611907, 31.986265874678093, 37.959765003573516, 29.8715768706414, 27.39372737946049, 28.84769508915563, 42.3426841920422, 46.56791625484344, 52.624479416877996, 53.90932236948321, 54.74627379448184, 48.73568865560716, 39.7485815325091, 31.542337902130622, 24.62064108540935, 13.899637479935924, 7.608006673474466, 3.294384979432629, 1.745642755300768, 0.2892910719158188, 0.6270042939051506, 1.271809651967018, 1.70705987080451, 0.7899138715959365, 1.8409763300611128, 2.2483378841030985, 2.412554285218639, 2.4282820090170834, 4.943842147627185, 6.590577190922153, 5.397827077296473, 1.5763991013649972, 1.7015159682881449, 0.7493582187641052, 0.6489432134455251, 1.622465132705627, 4.728974709587713, 9.515240538504816, 14.71843715636961, 26.460279764667636, 24.669792306038644, 19.512146172984956, 23.416500899099535, 29.779732611871538, 28.203869404331332, 13.969652768104309, 2.613485787184008, 0.48343518808964764, 0.1367339927462801, 0.08313170934636747, 0.05425339301807746, 0.03709453270740567, 0.006488473605244391, 0.020747001643382737, 0.026578434194708546, 0.07525701496389604, 0.03641856736653755, 0.005880381260442758, 0.051342247414492795, 0.019370374202187506, 0.058691133519694696, 0.059106364665973576, 0.04179288865998388, 0.0793545511400988, 0.050917248647179336, 0.07339752804968627, 0.030171145241887822, 0.06992920286833279, 0.08865010879573323, 0.008940773719410983, 0.044097821228206165, 0.04109936458389125, 0.02303674651850616, 0.12912520748232642, 0.04427992032780763, 0.10881927330046894, 0.015405096402842433, 0.03141963490164809, 0.02310704849209757, 0.02770042741641162, 0.0518537336780179, 0.03186931127622243, 0.06206756645453073, 0.017529869031521584, 0.043087228682012334, 0.11046905130628618, 0.10232561327997716, 0.034368573537757324, 0.06502250930474651, 0.04815681552093837, 0.01679898859302123, 0.06103052472275111, 0.05725973270713322, 0.062071546281297366, 0.02096363215617115, 0.00611202949057183, 0.06578445269335663, 0.037145316675906224, 0.010519877241383637, 0.07592396344989538, 0.005390619335230441, 0.03290157261935454, 0.08080798081092297, 0.03276179604712994, 0.011364630904168853, 0.06507053535671965, 0.0201693790093545, 0.02436402449083905, 0.09133198343577886, 0.07717781189468599, 0.03826329559688607, 0.09731927466007972, 0.09083477705116234, 0.08902855623032778, 0.04230647400442151, 0.00856970179630744, 0.03145200403166875, 0.0412072948811035, 0.07651376688191969, 0.01805327370792868, 0.034038730551518744, 0.053758182292503696, 0.032299412189111594, 0.05630139501825456, 0.06768323225720276, 0.008490027694572366, 0.058078807102696556, 0.015425476256848104, 0.05028396206457288, 0.023974884384041353, 0.03418464731845645, 0.012473663833412914, 0.024723183746720036, 0.0481265205739727, 0.06742480015682598, 0.05547623788457244, 0.03354587937675176, 0.21759595211234786, 2.0731996432427438, 11.01400367675289, 24.622829767965502, 36.617773117557654, 37.50719016598117, 37.188379918375325, 20.355704830538844, 20.020826593522106, 28.211204236553563, 29.649555029407626, 28.40346705528998, 15.492209984410195, 5.686263470880448, 1.5125204839052693, 0.5318969295870873, 0.24419124598705003, 0.2842055964133432, 1.1555202016907355, 2.120712293732551, 3.1162650017969074, 6.594274515105832, 4.543622126502376, 6.762408383430974, 6.119706457661045, 7.151939945836221, 4.9567241918656135, 4.454527939519575, 4.244811554108897, 3.7717268880336516, 2.2021767352857897, 2.4415852177527646, 1.5557017345582287, 4.502152867855565, 7.6762735651385405, 12.687133819826188, 14.915228351469963, 21.79625411187449, 28.651323587663715, 29.728233852694114, 36.99959231961158, 43.1854054235643, 33.04745920242802, 30.526202801735174, 33.29240337494881, 47.96103623605544, 53.515241838270626, 58.49685984273111, 58.00403756480063, 57.933305463483265, 53.2288029116969, 43.19442687496063, 34.54078397443218, 28.416501091372584, 18.00058041849444, 10.972836440609349, 5.114200490136301, 2.3224074321408428, 1.6434744505151626, 1.5135276750210793, 2.7767495426439472, 2.7930138957115913, 3.417913163861921, 3.4839085128999527, 4.210707526053152, 4.211927873473014, 4.241535884718742, 5.579923602842516, 5.22027853996523, 4.305853930211836, 2.0245541632175446, 1.7820424730739288, 0.48028426845708205, 0.41190715206246226, 0.9501670853745554, 4.722715587385239, 11.058343129773295, 18.504828560736872, 26.38164016508287, 26.463778518861343, 19.700712157833962, 26.151130314796205, 32.78860826646128, 32.83493145819634, 18.007938784937707, 4.590828341822471, 0.5508203431963921, 0.02487738192411921, 0.101761749585069, 0.10823149234056474, 0.018230314712010084, 0.033190862741321325, 0.026714133263956157, 0.02842686646017096, 0.030374802055678544, 0.010009270063751649, 0.026453816587285652, 0.026294175355184465, 0.009636249404490716, 0.041186821181327105, 0.041779562560541016, 0.04916563457358749, 0.009595102822077612, 0.04013110988683278, 0.07200409838509175, 0.042619432412808946, 0.029379699807313663, 0.09723801571395128, 0.03136463744956399, 0.09664765303774227, 0.03934548289004353, 0.024044640519986712, 0.05269492120151559, 0.025866650412940694, 0.022133182200993744, 0.026014457501831557, 0.028609252842744032, 0.017366184770400007, 0.037277853717246366, 0.01054557278797391, 0.01599076583290533, 0.08464824167951461, 0.028781613049608086, 0.07835921140447741, 0.08359896169314462, 0.040682831088141094, 0.07419797501737073, 0.10437311349256385, 0.16819563033359666, 0.15277860115372366, 0.15082328430106565, 0.2408144223473726, 0.15800489893844052, 0.1352736146579827, 0.11382307616933701, 0.1281500541635098, 0.34622283472168836, 0.15532178323595755, 0.17154286765763838, 0.29731366723295183, 0.09830752042152228, 0.16166551218878839, 0.18853236891088948, 0.09118150844569169, 0.1967401276793211, 0.1964205924061037, 0.2267149571449526, 0.1463316341922168, 0.15774945458096845, 0.13616327256444963, 0.2220568667736746, 0.20948735576483513, 0.2062847558408976, 0.15711798362674254, 0.07057526779751624, 0.1225173697175999, 0.1593013342109419, 0.09847786773236529, 0.13897443220259684, 0.11482053030762943, 0.13772359448334864, 0.08540510590518675, 0.1381636660305723, 0.2009026051288651, 0.14405969320045364, 0.16976514530758705, 0.16590545644923566, 0.15484743691500158, 0.13108084609191265, 0.13559998343548468, 0.13678579561171994, 0.14256620479206886, 0.30705450583369504, 0.18417268510787718, 0.16581260659281286, 0.11050724078931155, 0.36547419524961905, 1.6694364961116546, 10.927981195911284, 25.128639013536517, 43.11329264794627, 47.19086708561067, 47.05971479415894, 27.64668299305824, 32.59606695944263, 35.2625746111716, 40.4903252663151, 30.451987635704782, 15.581460575903616, 6.6641079033574755, 2.108672333340491, 1.6011510957633297, 2.2621703676639067, 1.957284289021646, 5.701861266166934, 15.13036447186624, 10.67545312066232, 9.978617583551715, 9.01144641060983, 11.871245522652904, 13.111667633056642, 12.624333731589779, 6.9132210650751675, 6.711489644742782, 6.082445902209129, 6.369731080147528, 3.4771223222055747, 2.451487486400912, 1.6663699380813108, 1.7983717903975518, 4.831843280023144, 10.66929009652907, 15.561199572778518, 20.291872178354573, 26.87412315799344, 28.475928921853345, 37.536368677693034, 47.462110750136844, 38.252773900185865, 38.54324502329673, 37.70155929750012, 52.99226437845538, 58.00216659422844, 61.54184287594211, 61.447180394203436, 60.22378137034755, 53.02992305447979, 42.1012544631958, 34.54475733541673, 25.84175728982495, 16.24566395436564, 8.89107475357671, 4.258396192904442, 2.7697260485541437, 1.9752678659654435, 2.467728550395658, 3.1508348113106144, 4.166935836115192, 4.5690307501823675, 5.586317066223391, 5.809187120006931, 4.51097329778056, 7.802616050166469, 13.09073688522462, 13.112231473768912, 11.706270633205293, 6.940016246611073, 5.696206188970997, 2.8800934553146367, 1.1134493495187452, 2.487235477855129, 6.589682890522865, 14.372297794588151, 22.236732359855406, 34.66537414058563, 33.892831956186605, 28.71142214344394, 33.70041616501347, 40.680501384119836, 37.98229117547312, 19.84760295960211, 4.899239405508965, 0.7337349893585329, 0.23230048887912305, 0.23981101570590851, 0.2213958707908469, 0.11970636329703754, 0.1736988995464579, 0.20923404113179256, 0.08379634424683549, 0.20085369807577905, 0.15652379051091211, 0.0860724144525105, 0.172841708446222, 0.13115013108378457, 0.1571162982333091, 0.15212431610111268, 0.20699205417786876, 0.20511326950884637, 0.14650193553778434, 0.17654958932149797, 0.09995110843691135, 0.1853766535679179, 0.26228898535332373, 0.12666876187487958, 0.13260462561682348, 0.10001544450079242, 0.18298866557738475, 0.19943344767295546, 0.09270550247522132, 0.23987179712182094, 0.09854993362340236, 0.11584864328465155, 0.0917975350673641, 0.19245882999272118, 0.09018675093689273, 0.10450352463991412, 0.267123582382356, 0.13165878282198984, 0.22613337383635584, 0.36771742326598017, 0.1523408431920313, 0.21682588053086113, 0.1942431560206798], [0.06802965721656239, 0.07560854206883139, 0.02515403925621462, 0.06849638096267177, 0.06738422047947684, 0.07478472941945638, 0.04353801396885707, 0.03397089346582371, 0.1066836040286768, 0.052045853207668955, 0.047839394650392, 0.11296430692797708, 0.03881873232462714, 0.05275631548776742, 0.022368407582924254, 0.05032255757419814, 0.05662504418362534, 0.02691779582340631, 0.0289724359754473, 0.055203162013523044, 0.004243334199512197, 0.07164836545745212, 0.0331336934299719, 0.07169237720870203, 0.09114708811525377, 0.04490039025944087, 0.026087433122278705, 0.07379209397420769, 0.062006325385863745, 0.010233613166717753, 0.033148681940210444, 0.04162668205437161, 0.0197899567278763, 0.040076116265188304, 0.07359384574116239, 0.04799741943697295, 0.031121712883994467, 0.020444584604833397, 0.038097096652153044, 0.02921525520392724, 0.04771996537343629, 0.014874085430957138, 0.040378782282313036, 0.04771825699736515, 0.0383416204262645, 0.11418104607371554, 0.05321712120466175, 0.09850771451789526, 0.036801032932294954, 0.10077740321116102, 0.3392086562610442, 3.198162865254187, 15.471130186511626, 32.203123915580015, 37.135306327573716, 33.68906482573479, 36.524601136484456, 42.83583987143732, 31.879653892209454, 18.93805434626918, 17.241995988353608, 10.884210486565868, 7.4793083148617905, 2.5807303190231323, 0.7231695950031282, 0.11116392369712554, 2.10017500865844, 1.2324315069183227, 2.201837205117749, 4.888016033557154, 3.986226849017605, 4.911767946135614, 4.269934335062581, 4.525554708896145, 2.081367243682185, 2.7520062510044347, 2.003685805586077, 2.156177874534361, 1.3375080040385647, 3.174546764742944, 1.2953864062024703, 3.434298865256771, 1.7914038223605004, 0.7586408754990948, 1.0047887253665155, 3.984943743674986, 5.677136115489468, 8.223072069306529, 10.953990432523913, 17.164891996691306, 19.4807005313135, 18.053518687525106, 17.327570338403028, 31.947020599918982, 38.54777143847558, 40.33713317686512, 37.2695259125002, 30.80589525161251, 23.461502252086518, 18.145370791035315, 10.782607370807279, 4.940454690687118, 1.8756174776823291, 0.8910398677952829, 0.4716050132147728, 0.5448297194896207, 1.947440978500151, 2.0531592734398383, 2.755142676253473, 2.7234582602977757, 3.2894244069053284, 3.6632363354006126, 3.0982174411896737, 2.447723972220575, 3.402530608638641, 2.701704550173975, 2.6548736566497437, 3.2871528642792858, 1.6625626649587386, 1.3461987505997381, 0.33002301690078556, 3.556532422381063, 8.78296148392462, 12.28110476847618, 15.202344867490954, 22.03487934604768, 27.16361172737614, 24.177850600211855, 27.59527444839478, 31.432658626187234, 25.375334524339248, 14.559269335962112, 4.140285782275662, 0.3635421215045837, 0.06465659506859318, 0.041391638618323116, 0.05239859456196428, 0.03251671302883375, 0.04237768953786262, 0.06319415620377948, 0.03184516418484911, 0.07023297971294773, 0.06163989020992191, 0.03049243677167162, 0.03391248309203694, 0.010665751873485504, 0.03181667529016493, 0.02561259650505118, 0.016847719445884708, 0.0353534025470576, 0.04206474645123367, 0.023014903436565114, 0.03144568380629344, 0.06506452156651406, 0.05085996825308089, 0.01800799216594427, 0.061320680524072343, 0.031177315545538743, 0.03134514051189106, 0.032123284744879896, 0.03242667854553269, 0.030673051575919798, 0.04762177588418127, 0.0430181581947592, 0.027705318887808153, 0.023516698687848066, 0.06801134005429284, 0.04996912674077096, 0.05240458153909253, 0.036926778604186354, 0.04814712833913584, 0.03490188181580555, 0.056232849301229564, 0.01513870560654229, 0.03531125238946369, 0.04652147827249381, 0.03671896193296679, 0.08696167399325679, 0.036904841676474585, 0.009883550247327696, 0.059483559546811934, 0.12963136177389853, 0.015429243494215754, 0.039928383869870056, 0.10826091011685711, 0.04750775518797098, 0.053007967710014314, 0.10000915491893407, 0.07927207411417077, 0.05122950991555568, 0.03565483133218462, 0.023469611093582168, 0.020004277485573006, 0.04095200374121628, 0.016676581149259885, 0.015095820004541068, 0.016441685185136817, 0.04986536013142717, 0.04709324799478055, 0.06655431743110381, 0.035800928129784526, 0.06215520691306842, 0.026668252258171, 0.02083993193903758, 0.09036208548012281, 0.038731199118398854, 0.023645750029132735, 0.044757706383543636, 0.054931143343809156, 0.025393338310682488, 0.03858894425173921, 0.046208933551585486, 0.0269040311386268, 0.03059606165474942, 0.05547768579074933, 0.007493613999442108, 0.02659311626977738, 0.06318087606961209, 0.051590149636350335, 0.029399775141369433, 0.013508772150793625, 0.013363364832325569, 0.02391584007249725, 0.082983149576091, 0.05813310358432993, 0.10336288100769443, 1.1613993442827657, 6.416954455837128, 21.066446150502852, 39.45693369834654, 41.72185144116802, 32.52557412270577, 35.197957484952866, 38.65430693472586, 37.008335282725675, 26.062737741777976, 23.353003609564997, 17.184774491094775, 10.204799098353233, 4.054234373954035, 0.7943250058639435, 0.16732884781254878, 0.4493159608494851, 0.20711444438465182, 1.073047098132872, 2.086860523108513, 3.048151327717689, 3.1455503980959616, 6.288582144245026, 6.567357249798314, 5.732683250980993, 5.445660381547866, 5.075126819072231, 3.534441878718715, 3.3861108316529185, 3.6457141272483335, 5.3961796818241, 9.617791887252562, 2.6230931426248243, 2.373621084036366, 2.117971537574645, 5.6143272019201715, 8.175284852904658, 12.241334876706524, 14.30151274127345, 20.196234987628078, 23.491571141827492, 21.919746014379687, 22.249413382622507, 36.82246200499996, 42.743934815929784, 47.155095069639145, 43.99565727479997, 36.91412779592699, 29.255264651390817, 21.87728831844945, 15.568837408096561, 8.695655407444123, 3.446824218957655, 1.5372312934167924, 1.2620098552396222, 2.0662249336319585, 3.6397710009928677, 2.247377884003424, 3.7605008194523477, 3.4585150884043787, 5.979811693391492, 5.8593954193976625, 3.996994245436884, 3.9366777529639587, 3.0429632577203938, 4.7116393043148905, 4.427991634415043, 2.8825400337096188, 0.99462034841699, 0.6502490562777365, 0.6994896334025168, 2.9131960532357617, 7.8024699418775505, 17.658777236938477, 21.009263876945745, 22.463466928851222, 29.30108577974381, 27.389085254361554, 29.701395034790043, 33.73054389030703, 30.660693030203547, 18.18871298143941, 5.851382017135621, 0.420901054937032, 0.05042263930062613, 0.00966966615974783, 0.04200514098028502, 0.03948149414012029, 0.05183183122426272, 0.03725046990439296, 0.05649269100338702, 0.03795513289890463, 0.016630615873803056, 0.03176948618924907, 0.032936709242001656, 0.04730164306238294, 0.04404174359214883, 0.05563778667560509, 0.04754132133037333, 0.034422797241037896, 0.05759325674584797, 0.02405500952004185, 0.06210110195341611, 0.10668359636779755, 0.05499478992855838, 0.04984266477667036, 0.019786555297492493, 0.01656677202141333, 0.059769747012685386, 0.01190504369010488, 0.06675500948462756, 0.014133050497020445, 0.056952052644544074, 0.03154265713096867, 0.06744503253890623, 0.03268927050333831, 0.02802917298169867, 0.04631686384879774, 0.0889806297697848, 0.04287933540200034, 0.03657494123364168, 0.051155111286789186, 0.04199721963114796, 0.09301622007643023, 0.06645184551035205, 0.06305285511658558, 0.1770389969310453, 0.20577204383669362, 0.14765958632192305, 0.11126719234931855, 0.1986025027450054, 0.3552073300365479, 0.1892037683677289, 0.14396247664286246, 0.18208088203062936, 0.1073124243186847, 0.13250406891588243, 0.1605099758073207, 0.20892359166135713, 0.19403525507978855, 0.11559965704838115, 0.14075505036500194, 0.10722247027461568, 0.15594191608890412, 0.13406895671881017, 0.12334459911911719, 0.08642293798226504, 0.19184661848891169, 0.24861463766184547, 0.1870712553781848, 0.1281780623380215, 0.2682052066008891, 0.16377498125357015, 0.20959388795158557, 0.1688757478710144, 0.11847651638691464, 0.06995251492386864, 0.10672947737358271, 0.09807605461608018, 0.10431436987053003, 0.152237880975008, 0.15512002632021904, 0.14222452957783976, 0.2138676013677351, 0.14994367746816528, 0.08230389771802772, 0.14543057689743658, 0.19176591878696797, 0.1401559696082146, 0.10149315915881627, 0.21172537438331113, 0.17974170916263135, 0.146094529979652, 0.2530428403688054, 0.2005144130558737, 0.22792514623893848, 0.850308076027901, 6.144123702279984, 23.02420896868552, 43.82655605193108, 48.69666107239262, 43.501128765844534, 49.19439023540866, 54.60710025602772, 41.6211171304026, 27.76272631460621, 25.66670387021957, 16.13977466860125, 9.830099978754598, 3.584507501894428, 1.2647906931177264, 0.437257185338005, 3.4283118574850024, 3.294007206155408, 4.438404546629998, 10.751983465686923, 11.439230768911301, 12.977166618070296, 12.111330859122738, 13.65772137718816, 10.021397894428624, 10.33327829453253, 6.980186220138305, 5.241612801628729, 4.280470801937965, 5.960478821108419, 7.086009315906033, 8.763738928302642, 3.1371126444109025, 2.0434754317806614, 1.5196173998617357, 5.076542794704437, 7.020231658412564, 9.812509129124305, 14.007426173456254, 20.79855219010384, 24.238961127496538, 25.369737302103353, 25.687090389190185, 39.109803938096576, 46.8383676005948, 49.69117802958335, 45.041000304683564, 36.19281961071876, 28.217095636552383, 21.922034717375233, 12.701002340162955, 7.210939747671928, 2.6440729200839996, 1.4955626067615326, 1.4720589066705396, 1.2481276066072526, 5.089457198496788, 4.935213423544361, 6.618100952717566, 6.198649550637891, 9.578294600209883, 11.050508195354093, 8.42653178399609, 8.99990777815542, 9.378810697986234, 9.993822651524699, 7.063961182871173, 6.794183994493177, 3.870618420262491, 2.6881787469310146, 0.7854963021893656, 4.952634630664702, 11.03315661030431, 18.348798636467226, 23.677134552309592, 31.168463460860718, 36.483294656199796, 35.083749832645545, 38.440965298683416, 42.22072985864455, 37.58778702828192, 19.713573609628988, 6.419961442870479, 0.6571738169558587, 0.10093765348316201, 0.12997662227961326, 0.1830761068530621, 0.1639769986392029, 0.2061951848407907, 0.19921499004046764, 0.19180955515513498, 0.14317046430322433, 0.17730565681572885, 0.13022278165144305, 0.18748141885284456, 0.09459849807523912, 0.15296544999845568, 0.21576313271878228, 0.15363669623771023, 0.14016474897582687, 0.10597967647857244, 0.14271082687041453, 0.18736995305986176, 0.15377270748778699, 0.11743840596248066, 0.1823533028965035, 0.16116536402654263, 0.11867904705145668, 0.15834119621544115, 0.13016639758021603, 0.16906106453989783, 0.10739217407160229, 0.23941300238572785, 0.15795585398952808, 0.12631857542381172, 0.1964485086500645, 0.1905375274439012, 0.15007274796164807, 0.17447200483612477, 0.11349885243802302, 0.119221429640968, 0.14193614343962363, 0.20576194679785162, 0.1947478241016788, 0.10974821619569294, 0.16237414351874785], [0.04796531269206636, 0.020427018208729646, 0.0785027303162121, 0.0066283191253821705, 0.08585975610560949, 0.019555855579974673, 0.07304460666472874, 0.05846886459978358, 0.07764211480295466, 0.00425424664318862, 0.011939941867885571, 0.04318112041801215, 0.0962706152049284, 0.012225677341883703, 0.024197036475544016, 0.0167558865711814, 0.06971538006778687, 0.03319987576575049, 0.022992217657907356, 0.023391784221354513, 0.006140400599237652, 0.029346622045963045, 0.06065524123128384, 0.02274536689172589, 0.04876575965975081, 0.07511613139462087, 0.015094917936010227, 0.030388792736395717, 0.049185568181377266, 0.02389632781306582, 0.04086464673521058, 0.025288250199669314, 0.0382699414096292, 0.08276495241349743, 0.02985672743600463, 0.014567265302062997, 0.04752689206431951, 0.043015779491754315, 0.033040904860583045, 0.017391747209213434, 0.017753239202823852, 0.021908356462635344, 0.03966936571223121, 0.03947321272965881, 0.010420358589579983, 0.037349954082240025, 0.018068641431689743, 0.06111763658062105, 0.0382517583127464, 0.04771205934605772, 0.05691779319257025, 0.09821306178045851, 1.9875779796031214, 14.737627352437666, 30.856219260923325, 43.19570164526663, 36.697338396503085, 35.021901899768466, 23.225363800602576, 23.481820129579116, 23.081440271869784, 16.76360999384234, 14.760371215881841, 11.671234061641078, 5.422242851026597, 2.062111347913742, 0.5029578969603585, 0.44389239542426606, 1.5171700860223465, 3.235850959054886, 1.3715305203391661, 2.2648111033824185, 3.5402661081283324, 4.527177589554941, 5.742265601311961, 3.186296960038524, 5.426491758515758, 2.2886341089202515, 3.363297591286321, 2.9300600386434987, 1.2033554671272155, 10.940510226834206, 3.578064028293856, 0.5735341759939347, 0.4906959549313592, 0.6525705478364422, 2.3382837157095633, 1.0259647439083746, 1.2431691178391058, 2.8907672051460516, 5.822616334884398, 6.191974657197153, 6.391887568658398, 13.969453707818063, 20.628425267434892, 17.563020413921727, 14.084627243780321, 9.194428901518545, 7.0292864499553565, 3.0793709428079667, 1.4499003344005155, 1.8279491581263083, 0.1314447072124289, 0.48440959064229844, 1.762807169748891, 3.7343096829229787, 4.464948696474876, 2.389752321666287, 3.657571207131109, 2.377297570628505, 4.169869769004084, 3.3672072137555773, 3.8908409351302735, 3.2286764537134482, 2.094528021350984, 4.038222523466233, 4.4954005076039225, 1.9788796334497392, 0.8779573536688282, 1.5024573980800568, 4.373347624655693, 16.304118056451124, 24.596620490474088, 15.596940209788663, 16.199373122184507, 25.363375217683856, 24.205899469314087, 27.92136657622553, 29.949961516164965, 26.26690495398737, 12.88727766083133, 4.022520785370181, 0.24913703301741233, 0.022567362532079704, 0.09833602655318477, 0.040314840753712965, 0.10589788893177625, 0.052764627541745865, 0.08911726155108021, 0.023761731910429174, 0.0431384991163448, 0.007809878077222816, 0.040911079324301214, 0.006756007787771524, 0.011399114436860527, 0.02409076475868783, 0.031217604109476653, 0.04175142032064257, 0.012082676497107793, 0.04361143200508049, 0.0619198378896521, 0.054506485485622, 0.07228985684172762, 0.08159600183247559, 0.09082233578327203, 0.0854552616815894, 0.048978433328410315, 0.04461474288555403, 0.013743853891238332, 0.014931946136658231, 0.02434483973399526, 0.0600103062817887, 0.045843658998848937, 0.05114332119363451, 0.029261791214887655, 0.01798945092295687, 0.02804241864190948, 0.030509185368916204, 0.008044546608993364, 0.022485868013914556, 0.06727639360413437, 0.09228845187012227, 0.07163990784676806, 0.02760124392807484, 0.10177350903470671, 0.06662813000260823, 0.0907900068728674, 0.06882857200839827, 0.03353741793562809, 0.06177798521915271, 0.09340772164925452, 0.08592935519353037, 0.03225584476885777, 0.05959885577941614, 0.019171331152920763, 0.05687503399507654, 0.05579678056341025, 0.03168792655361036, 0.07234640179141875, 0.07962765382422556, 0.025003175476505875, 0.044989290932614, 0.030382476341460022, 0.02188354478998771, 0.05296401724579835, 0.04341775731694314, 0.04732400899933231, 0.04873188708217875, 0.048383217485200976, 0.0761484501943473, 0.0744633861787377, 0.04129592359306351, 0.08852524412495476, 0.008193880128073356, 0.030750185138575976, 0.01968517888247246, 0.0400635868971867, 0.026166570004856875, 0.009209568116573558, 0.07166830672612114, 0.02865032281636471, 0.009088456319014152, 0.044438197923403595, 0.07954250315144178, 0.06415383454652564, 0.042086315656741785, 0.004472082786847868, 0.026352846198865486, 0.11362596940729888, 0.025433705398632635, 0.027892671435350375, 0.0431793047896316, 0.03273457311274063, 0.05444876459096709, 0.0342416251078248, 0.02393024252547372, 0.035987125799780896, 0.44568102686635913, 4.643158153180154, 19.749025952431467, 39.002550648104766, 50.5568725832047, 39.69829282452984, 40.70359237732426, 22.605823470700173, 17.889755810460738, 21.059083861689416, 18.78101441168016, 21.825932725783318, 16.562292383563136, 8.58101237204767, 1.6552346968843092, 0.3655482606301385, 0.1357532776291332, 0.5187568669357608, 0.4187523621705271, 1.8858889394229459, 1.308284752791928, 3.1111992607193613, 3.3986665837226377, 4.525735628220343, 5.054820708690151, 5.170252630787512, 4.408692102278433, 5.692540734044968, 3.726607618793365, 11.54230183170688, 17.39212666788409, 5.035693760841124, 3.3738541603088383, 2.6380780675718865, 2.0333934695489946, 2.20085661257467, 2.3010084513695013, 2.4077106483521002, 4.081877768039703, 7.934353755366418, 7.913840249661477, 8.90660341708891, 17.57412072150938, 25.98925409778472, 21.785757849293372, 19.05762976215732, 11.965992335350284, 9.784381812618626, 4.617328365002909, 3.4965566858168575, 2.305174498788772, 1.6114409436141293, 3.688075725109347, 3.5552733415557496, 5.252035029472844, 5.449246898774178, 4.168245417456474, 5.698324268864048, 4.029476863722648, 8.443687250537257, 5.3346891749289735, 3.627111060965446, 4.572995285834036, 1.932900384549172, 2.3021121082767366, 0.936195296385596, 0.7155416268975504, 0.7476831828394245, 2.0797843221695196, 5.231214108005648, 13.358117995723603, 25.540111334093158, 21.013041119421683, 20.704385888191965, 29.084796482516875, 27.249305709715816, 33.961293005174205, 34.67036339544481, 32.331265787924494, 17.121006558018347, 5.835142424029689, 0.62835922765155, 0.020796360688344128, 0.06400912053762906, 0.02241347270507005, 0.06552089546476642, 0.025760842179278695, 0.03337665821515745, 0.03425503547693934, 0.039513658341621204, 0.009520691744382343, 0.03978784504016081, 0.00994022255913625, 0.06322664599264823, 0.038838133501309546, 0.03839751803165963, 0.019916878344731468, 0.023735774936334744, 0.0564007489611545, 0.02278684863760587, 0.04622069300122319, 0.05368424331649177, 0.025401889767137267, 0.05480866120647519, 0.04071884871190114, 0.043446723101360184, 0.016342643423066024, 0.05418654801624437, 0.05151550585944807, 0.021577689931878162, 0.057778106101097605, 0.04906935647370354, 0.06898408785702721, 0.06099473692536835, 0.034790396870624636, 0.048982754064303254, 0.023111007251446287, 0.05493046152555654, 0.008002758427943674, 0.029199740008240747, 0.07431329423261267, 0.04824848177151815, 0.06111636487466674, 0.09199602844854517, 0.03103698930522848, 0.1160380585239299, 0.16717707047299032, 0.41460969575470497, 0.09860389685678868, 0.17885618813095555, 0.21318474123554848, 0.1934617616596722, 0.10968927339079881, 0.13580230725628717, 0.15190852445460137, 0.1568298119931452, 0.13804345151349423, 0.18468630109583178, 0.20648481204144417, 0.12272101887051137, 0.2045188006013632, 0.15988910750996682, 0.19634022978284668, 0.16913785719342772, 0.13887101033281896, 0.10692588699560975, 0.15986253958075278, 0.21284841331503085, 0.14999217083377225, 0.16771547706617465, 0.1798041606502187, 0.13201366539203352, 0.13216729666436874, 0.1447090293250738, 0.0999625001643454, 0.16454820911730492, 0.12188874094957307, 0.17553145847012921, 0.20218704346447222, 0.10085622599769024, 0.06938220842951728, 0.1944032837186129, 0.2356422563353854, 0.1603293169530169, 0.14281948878159448, 0.13884119419080598, 0.10188964030314838, 0.3053897354871996, 0.12276743613784352, 0.13409146438202552, 0.1811913773417473, 0.15605888239318327, 0.13651942684044763, 0.18734513181111506, 0.19355959108760282, 0.10672214591214735, 0.5180409118052453, 4.285976338771082, 20.39574242407276, 42.0634114357733, 57.02916383743287, 49.04192770681074, 47.164485223831676, 32.67299836681735, 32.6237706599697, 30.563786952726304, 22.96953897322378, 19.94980227562689, 14.494410003385237, 6.725514079293897, 2.9734360594903273, 0.7420720484468245, 0.9299263682576918, 2.5628573038885674, 5.663800547199865, 5.680698117902202, 6.5625185158944905, 9.524126668130199, 10.171310882414542, 15.207349811830829, 9.924215289854235, 11.357546429480276, 9.223536810567303, 10.709476740129533, 7.214844467178469, 7.66239720006143, 21.17667651945545, 6.939905929949976, 3.260267713377553, 2.0197280544427136, 1.35717403263815, 3.4148429286095405, 1.3689020420274427, 1.8473792316452151, 3.905093602595791, 8.336363357882346, 8.249220059764001, 9.12303097786442, 18.02842140197754, 26.1933526685161, 21.95574356663612, 18.467118893900228, 12.697323156941323, 9.654102248530235, 4.150915405442638, 2.641544462211671, 3.0662466922113976, 0.9293878390904396, 2.1092351934602185, 4.5646234769974985, 8.618456298305142, 10.229293319486803, 6.268819772428082, 9.911619578638385, 7.981858561115881, 11.983823430153633, 9.61210641168779, 10.843245252486199, 10.651988521698984, 7.428139525075113, 8.49846903354891, 7.773825362805398, 4.803305585538188, 1.9270162164203584, 2.608638963391704, 6.1912759850102095, 18.89182136904809, 30.13185358816578, 22.373221035926573, 23.60427652635882, 34.14955108396469, 34.748100849889944, 38.73068724909137, 41.968780332996005, 38.351633318008915, 19.220306142683953, 5.776104869381075, 0.6429257460178868, 0.13033458452311256, 0.13895477438645978, 0.1312233384458288, 0.16158568582707838, 0.15989908197474095, 0.17738825641572478, 0.21467070666051682, 0.12575776841972144, 0.07115315090143873, 0.10914961807429792, 0.08565586180456224, 0.16846610533614315, 0.20460017446068027, 0.21664229522068656, 0.12324846274549923, 0.09473787245130348, 0.20313270239820405, 0.10620497527622408, 0.11795513992828709, 0.16074493497369752, 0.3134544043531341, 0.2082072688086379, 0.24208240511436618, 0.15156792176346626, 0.13109077459141133, 0.1411526499977035, 0.12085882000504963, 0.11197038445501559, 0.128119770707863, 0.1143147667208987, 0.17775067729094338, 0.14148102592556708, 0.13970264473990088, 0.15388739085005176, 0.07812147133893545, 0.14249765524460425, 0.1031302277659697, 0.13178068273250135, 0.14727396830435724, 0.11865689944956573, 0.13839736881275333, 0.32352613165013255, 0.15651533290022807], [0.10341606283139798, 0.05006058231717156, 0.07000178969915836, 0.026615897809425672, 0.020787899247220448, 0.016564209457306613, 0.03804689874091456, 0.042348455622672074, 0.05720098142422015, 0.01271585965784447, 0.06628001964981518, 0.06876475688430571, 0.08316770015705018, 0.026002058368777076, 0.032071298018338225, 0.03189253523164699, 0.010971807829675176, 0.08019470444489872, 0.06889628652002543, 0.043465699099244616, 0.06101101629375931, 0.03544562421138248, 0.09114312744068523, 0.06959531110741439, 0.06685301511278076, 0.05701721608338337, 0.053203879374890566, 0.05775645262591782, 0.022982176160439852, 0.021651046681067636, 0.04069753614584765, 0.016028523433863396, 0.10894460528488122, 0.06067301830156677, 0.09350324515253307, 0.010977306425751699, 0.0539661483508685, 0.059209097056619586, 0.022614959574815248, 0.0370561478719596, 0.05387816698320451, 0.05878738863694091, 0.02824227949003539, 0.011845257230884126, 0.020751215126966278, 0.06915316346191591, 0.015897463026997304, 0.020548188420493278, 0.022671659657311057, 0.025895727280106758, 0.0747224847756086, 0.05802593937504196, 0.006169872959294627, 2.03878550279525, 11.27718294820478, 27.174204088026478, 37.186332441145375, 37.40435738717356, 39.751354648220925, 35.54858599939654, 29.145293158869592, 31.18007367657077, 26.30164734778866, 19.265589906323342, 15.163975261872816, 8.768673269979416, 4.191292774292731, 0.5947693365235484, 0.2228788331511521, 0.16903301040011068, 0.9016307575568077, 0.4454348368510124, 4.152593689580118, 3.0572933919968146, 3.0559678760267075, 3.3783778788581973, 4.2062840730913225, 3.010260496408709, 3.3009233253617443, 4.09873194752201, 19.28228939733198, 14.686683608639626, 3.7638056614706596, 4.13936794765534, 2.848358048546699, 1.9818700729839265, 0.9182786448828636, 2.390108031611289, 0.6187567751734488, 0.27221518658822585, 0.9611802427999435, 1.211350851001278, 1.169016954879607, 2.774772913225236, 2.742745044731325, 2.512851251709846, 2.0504610504834884, 1.0417567578054245, 0.612386355717336, 0.06458309659313771, 2.9678724225490325, 1.3926986941406805, 3.0698476731777196, 4.520137425391905, 2.3172514765493335, 4.682277912093747, 3.612622315845182, 2.9221716619306997, 2.7990854795902007, 2.495410432738643, 7.8598610816463355, 4.152955528228514, 1.603538838605727, 1.872931266984632, 0.6715579451091829, 1.8414694455362137, 1.2204006170072865, 1.3444400578737261, 2.304730535514893, 4.489917034103025, 10.179039912839091, 40.71984667931834, 28.87921133349019, 17.436023873667565, 18.578129814517116, 18.251802344476026, 32.07018694569988, 28.673002527606105, 28.36482582553741, 12.873123788064527, 3.285852353419027, 0.43794657253930647, 0.021230504630253683, 0.02060945821745742, 0.03142622900345633, 0.018198805515684428, 0.02886088974323244, 0.044025743845850236, 0.00986382635610719, 0.03866981249302626, 0.005639003713675325, 0.017883093021209204, 0.04661663788400831, 0.03344353003006789, 0.06010721640421018, 0.0539454946204299, 0.09036778517427946, 0.01466764292995175, 0.07504221923168629, 0.020990885734077425, 0.004529998076313566, 0.037406579471163215, 0.07213579656015481, 0.03442344458533391, 0.04767110045518606, 0.014139885916524838, 0.0021253311546564463, 0.08347838711474212, 0.0629295992304481, 0.028155682826294538, 0.05139577397776227, 0.009065308972382018, 0.016182850888599793, 0.0025269161203816054, 0.019699943311993155, 0.01978986862776501, 0.030597955807142203, 0.08983776724386601, 0.04012116989601524, 0.05534349016905312, 0.02619692240841687, 0.027263795603967966, 0.033538996076752106, 0.02200223479209648, 0.055860231795738784, 0.04346703592267248, 0.03905973592472654, 0.029476717182044542, 0.03196230094369141, 0.014397242620977906, 0.005802577849657786, 0.027354896864703587, 0.06237886245212248, 0.08016583059103259, 0.032655934187313246, 0.026818771298313816, 0.04889369634310565, 0.01150547999948744, 0.03128571890204424, 0.014556942267283319, 0.05018260863219058, 0.13855908997356892, 0.004669002336149495, 0.08306213324108432, 0.10339373136840521, 0.03337199273969858, 0.01866675691769248, 0.04757512879047183, 0.07566979845925685, 0.07260778333030402, 0.027697386047352227, 0.06556322948346216, 0.016285680955456152, 0.019568294932645176, 0.04592442764870582, 0.03789167783613648, 0.028731574101613897, 0.029487628189306107, 0.04335656987443086, 0.017815311476888678, 0.037253618525761756, 0.01545682265948985, 0.06433940402442409, 0.04828857881347499, 0.043063866830761396, 0.053491962908376614, 0.03525466147449709, 0.02933303547662593, 0.03411320578907767, 0.052723848681536414, 0.012816264098810573, 0.04169793206176931, 0.03849343990065879, 0.023296440748738188, 0.05172889582031677, 0.06924726204165528, 0.12861399701045406, 0.0361412397075084, 0.14666567917072004, 3.768562515897136, 16.067780544680936, 33.38757184243972, 43.74733594156081, 41.564795817098315, 39.22500002768732, 30.51788345459969, 22.416488701297393, 19.875836180102443, 17.074618647175452, 19.10324888844644, 18.06905911814782, 14.679878296390658, 5.929885804653169, 0.9691265357598182, 0.4218316985474479, 0.06406451635543378, 0.13490060644765056, 0.3297267247351908, 0.11345478706061841, 1.4921332294902494, 2.9116962369411223, 3.2777803607525366, 3.5666423315002076, 3.7772944473451187, 5.824098500513262, 3.2752776434344635, 12.437245499703193, 14.978188276290895, 7.074263288128761, 5.146893935818826, 3.415516840834772, 4.642453597437951, 2.4754249761181497, 3.24968540380078, 2.162999611708426, 0.893732391057476, 1.4162039876945558, 2.1765553230239503, 2.436669997630581, 3.970183619568425, 4.993286565426858, 3.558312688143023, 2.9168725398279007, 2.011602619482625, 1.4016220862826994, 1.0853938614168475, 5.322106701712455, 4.641228347055374, 5.419919827292043, 11.767204653832222, 7.96096311461541, 8.809029556089833, 6.523219798841785, 4.676646859415116, 6.1353459281306115, 3.8607818513147296, 5.163727277709592, 3.308779342520622, 2.708638074897951, 2.504859422483752, 1.0411614155577076, 0.6621371473996871, 0.4883700813497267, 1.3782300511675498, 3.6847527421289876, 6.9001071107003, 13.48380740611784, 36.99388527101086, 36.35577447952763, 19.545490241819813, 14.340051008808999, 22.068311668211415, 35.95610849318966, 33.515998086621686, 33.99212283472861, 16.79975659616532, 5.595425790356052, 0.6468165533677225, 0.03563428485405541, 0.004135596381890918, 0.041813894790867646, 0.03171052614737663, 0.01087836521272097, 0.04751139410561131, 0.01587137007229631, 0.03171072341501713, 0.03755596661639791, 0.030735914835766442, 0.014365763110559315, 0.02817585583656065, 0.01789745908500927, 0.06680523420894338, 0.03469633659528148, 0.04761214998941268, 0.03721403093227456, 0.03135031543581957, 0.13146726084091973, 0.051420334756614706, 0.02148803849253924, 0.047622752646284724, 0.05776113725357479, 0.037348590445734804, 0.026952769652369524, 0.04148018306061145, 0.07803838910354723, 0.036230760911900195, 0.03885674560742994, 0.04046217095287096, 0.01047676851627447, 0.08252979406426031, 0.03724467444924578, 0.0367222216370846, 0.005914451584460275, 0.04165296270061405, 0.054402726537157456, 0.05664853626982339, 0.012540256983840899, 0.050822981528096625, 0.06281155657263533, 0.04072126571930224, 0.07450850875747782, 0.004012081701676512, 0.17720451788796535, 0.17464235214696777, 0.14675797744383737, 0.12465806452617531, 0.11550866112473512, 0.12183976494857382, 0.12952671416344183, 0.1780182258376191, 0.17141661636771696, 0.11965292866431898, 0.13386678611559252, 0.17314020694503862, 0.13518957481268915, 0.12347409096095832, 0.168126069550072, 0.18544169443268932, 0.10737938806414606, 0.17970072345868235, 0.3070344343300789, 0.14750529621397296, 0.09415920793769822, 0.1649534389857323, 0.2147185258687504, 0.13993987152653356, 0.1157205074184364, 0.14419308442982937, 0.16065654374899405, 0.16271201893687248, 0.08917376819637515, 0.11747449636459352, 0.14661628182136244, 0.18440246551988587, 0.18608168428463323, 0.15211912202498606, 0.18210761849918675, 0.10837367059843195, 0.22667190300360804, 0.15975144150997364, 0.15475365243131115, 0.09758476243023911, 0.16287217727832257, 0.1401523689949705, 0.13126302180030655, 0.13343598423225264, 0.1388572513936989, 0.11878923347760593, 0.11449347205099561, 0.10382375184206233, 0.18794309407953294, 0.21090380637155426, 0.1945560569724729, 0.13344799649090539, 0.16826935863542944, 3.1663360182316076, 17.451515274663127, 37.68146107273717, 50.532773540865996, 50.37937356579689, 50.3081472458378, 44.92953831149686, 38.79160558023761, 39.56194339259979, 34.7197421135441, 26.717848085588027, 19.21795468176565, 12.795916834185201, 5.651375459086511, 1.1742656990405054, 0.7471060428407885, 0.6201607385470022, 2.4879265504498638, 2.9158098226593387, 7.954612797306431, 5.551983579512566, 6.1242431690616, 10.913982256766289, 10.223924575313445, 10.240119061162396, 10.431811175038739, 10.68520805528087, 30.810196130506455, 20.87561695806442, 7.208742730079159, 9.70804758610264, 7.104369440386373, 5.926973935096495, 2.7535234728167137, 4.801190937719038, 1.794038429375618, 0.6845335746484419, 1.70520716376843, 1.9979506875238113, 1.3919164264394392, 4.623119744562334, 4.34289385234156, 3.482617807965125, 2.8475078748118494, 1.5932743635869797, 1.1664737881191316, 1.050392100887914, 5.667711640557935, 3.250868243555869, 7.505522495315922, 11.408690214157106, 5.7898817043150625, 13.296884894371034, 11.311901807785036, 7.876409561403337, 10.259288664787046, 9.029057852683529, 14.182661002682103, 11.459175040644984, 4.814000418109279, 6.0646167685908665, 4.418972144203802, 3.897909046180787, 2.682614129397177, 1.934243918907258, 3.654918214005809, 7.176094391653615, 14.429814450202452, 45.00842109803231, 35.623173790593306, 26.17138151199587, 24.64790548047712, 26.874703668778945, 43.60127864345428, 43.578003298851755, 41.35323101474393, 19.212582995814664, 5.707878672307538, 0.6197934453525852, 0.13014061106068472, 0.1084355858244723, 0.11354653375043024, 0.1317856163387337, 0.14053294615399453, 0.2130642815703346, 0.1163984033008737, 0.19917454059806564, 0.17261113130277203, 0.08194398961120075, 0.1491273494978105, 0.13618752690813235, 0.20440410191733993, 0.17971374695339512, 0.15537338691853708, 0.16446917948703613, 0.29916153259335027, 0.1328730168602159, 0.2718838382392161, 0.17366687707122297, 0.10821158937629193, 0.1202664655002375, 0.16834992044154676, 0.1915832068170271, 0.12322986979157695, 0.21932778579573478, 0.1739162999776102, 0.14497064835121556, 0.11774424358361191, 0.16403986381426935, 0.08979609972166439, 0.17929763863644294, 0.131813011642906, 0.09608463970043006, 0.08423577994108201, 0.2912915419907339, 0.1647867995404428, 0.1726709014826244, 0.09500973407299289, 0.11853651639314429, 0.15168937734298168, 0.1677279949428574, 0.17339744394825352, 0.103730411689368], [0.013475990290903758, 0.06692013207582698, 0.04470630571426404, 0.06977345719332657, 0.021041527976311987, 0.04296410686126159, 0.05300969523828357, 0.023750426367886608, 0.06574319119775487, 0.09498285204772988, 0.03434296704888825, 0.050927154164040284, 0.04902310391527511, 0.0156266949958198, 0.019544674526719798, 0.018454851252177072, 0.06067333239761572, 0.028313223062263384, 0.023179328887753432, 0.034405123592624744, 0.07579117742997986, 0.03654700583748279, 0.03955555952063972, 0.02229446286125289, 0.014255026058714478, 0.014467026527610519, 0.009282478619547141, 0.033438864554609024, 0.042642353763503414, 0.08708754990009532, 0.07250800803904572, 0.04903324308895296, 0.05842932297157184, 0.06651942212615283, 0.0712588097479555, 0.019651773618534207, 0.03796968473902634, 0.031893381758803324, 0.06664100794061538, 0.011189653549433477, 0.01144995203151578, 0.03954254751724582, 0.05586377878282821, 0.04343643837097672, 0.0859066330256962, 0.0820091453891608, 0.04575023457648293, 0.14544657281329557, 0.053703081418549826, 0.057646848426591006, 0.09266414904906865, 0.04878059112196488, 0.01030821193595447, 0.07302771442599836, 1.6752927173529903, 8.250590928139227, 27.108459280383205, 37.20228079826602, 40.64132867320892, 43.666554727861964, 57.5429472615642, 47.744388041957734, 49.067266218123905, 43.759758087896536, 41.22429094006939, 20.330034878946122, 13.938747432924087, 8.904444152309049, 4.432450388708423, 0.9421314359191926, 0.48590183798824593, 0.24589009192441744, 0.35768688085579103, 1.3503276580764403, 2.4655582539496885, 2.2706958843815714, 2.2779152518318546, 3.4173380463354053, 4.87915490904162, 2.172598877260762, 13.348722938568363, 19.748015942112094, 7.72836018954554, 4.902128231140876, 4.084971537513118, 6.274514073325742, 0.8529166973406269, 1.7686955053960125, 2.578567377021236, 0.3628890775144101, 0.8808562303743056, 0.5487675339944902, 0.9605630823681433, 0.05755083845748056, 0.3894737380887232, 0.15720306535161313, 0.9757075987515912, 0.06108180281796283, 0.7152138025529924, 1.2728097337868907, 4.199186053968245, 6.0664240006477606, 3.751035895078413, 15.009211282576285, 11.635877816907822, 5.0412689197448, 3.7468722991404997, 4.122326720145441, 4.7429358959198, 2.5714566101950984, 3.879220423198516, 1.655983501865018, 2.0276636221716484, 3.086568246926031, 0.42529070809964215, 1.014392955168601, 1.6032397578800879, 3.086838645319785, 5.715463065331982, 8.520774572126328, 22.42901675162777, 56.47372876444171, 20.957333657049364, 14.99919354915619, 26.818441191027244, 34.13257114348873, 27.939764453518777, 23.210684330232684, 9.82086181640625, 1.6654491616833595, 0.26994937429985694, 0.03683368359962779, 0.04134058268860944, 0.03493384300400654, 0.029440607627733584, 0.06812914905528869, 0.017811247380450368, 0.01949726134508608, 0.08308618074102748, 0.09444065331932038, 0.011318822676736501, 0.022728581905304905, 0.05916690859462946, 0.07539400680651588, 0.07147955798333691, 0.01849740360593123, 0.057398819800225966, 0.03552499858121719, 0.015162087567601235, 0.05877966647066417, 0.03516828506103447, 0.007755980918919969, 0.024382194181183175, 0.042301276097855264, 0.016023465338343337, 0.04531388621657126, 0.060307475618056716, 0.04474062262283218, 0.04701493082628135, 0.07618647879890858, 0.028400359817990856, 0.07050953745361298, 0.013583730981354753, 0.024915416274339925, 0.06622988685605026, 0.04447943643636761, 0.029773254495775028, 0.06664615605146655, 0.01981080006507616, 0.049663300610958576, 0.010385784083947299, 0.050906312742060235, 0.07231613365753044, 0.027288783476838184, 0.09456632238241935, 0.018547802615249832, 0.06729508614948682, 0.0688586792638225, 0.04069692710594785, 0.07543024276533435, 0.03111126535992709, 0.013968839550450926, 0.0723121193568072, 0.014090019338313612, 0.05175116982671523, 0.05069988652042324, 0.0069581386501780685, 0.04703519385187857, 0.0451737572439015, 0.048408743534838004, 0.03404213964278179, 0.06268507545633663, 0.054857641037914066, 0.021632302424780304, 0.027171932085747683, 0.03994820639491081, 0.06052580301559741, 0.040569813967111616, 0.06060291742605548, 0.012993996497243645, 0.017989177046523943, 0.036840271955776605, 0.012015436959993697, 0.019481704014563755, 0.008659395370482197, 0.028618625928497607, 0.06947560220836632, 0.0562474049717909, 0.027781366520831664, 0.03511768878407536, 0.024947184025340026, 0.030615690742589297, 0.039174476743585644, 0.05080204817556566, 0.06912944537978019, 0.024267455277543877, 0.018844546772719874, 0.06692891910431847, 0.02779070130218902, 0.030759144536850434, 0.04314529048579355, 0.0699905205457922, 0.03926878216706457, 0.05130139577593054, 0.027687986148521308, 0.017816512319709987, 0.03541532543397719, 0.0075222925008875475, 0.027870253787466118, 0.14907946900254296, 2.9434208571910863, 12.380368190426982, 31.061314113678474, 42.73853763457268, 45.76557582424533, 45.134168363386586, 52.44576446471676, 44.59123780650478, 39.6394847285363, 32.32082443852579, 25.22021066757941, 21.105585521267308, 19.265778180091612, 10.713432450448314, 2.9828801462727212, 0.8844063431024553, 0.2958504699410931, 0.28574760883085193, 0.0974176173669196, 0.33618444757115457, 0.5153784191896839, 1.2884058130364264, 1.255200252898278, 2.6290338173989327, 3.3085675345313166, 1.7309461245613715, 7.479809887947575, 14.706305265426638, 6.008431757650068, 4.613299600539669, 4.639511819808714, 6.698860593380467, 6.2762413870903755, 4.51659111245986, 4.289734949988704, 2.367530868899438, 1.842605094275167, 0.6205057845480981, 1.1483485155528592, 0.7302477571272081, 0.9031938220704756, 0.5231314128445042, 1.3246482682804908, 1.3627380373016482, 1.7698365473939528, 4.392269628663217, 5.060069330276982, 9.650505435082222, 8.209178543859913, 9.427340222943215, 17.65974017881578, 4.313085800217045, 5.456898462387824, 2.367095976106582, 3.515079098363077, 2.9296655952930455, 3.2362279968876995, 1.9306895160867323, 0.9296592793637707, 0.6485885453801001, 0.3004298064737551, 0.8858926762496272, 2.60273628657864, 6.29532273738615, 11.006691398159152, 16.122818262346332, 23.42942314763223, 57.54883866156302, 28.486105511265418, 15.281244324099633, 25.834583274779785, 33.54625525013093, 37.25863741290185, 29.969136022752334, 15.060363892586002, 3.178145294227908, 0.47435306252971776, 0.03206937513764828, 0.08672154373339108, 0.02289962827137882, 0.03236714585293685, 0.040277421189051484, 0.03555009562161661, 0.03686131256061696, 0.01955395951236208, 0.0876629432182639, 0.0010303442081015918, 0.07108791085380702, 0.0640260587416349, 0.042764962305344885, 0.02738620304772931, 0.026829289685514186, 0.07243385072797537, 0.030748474847285018, 0.018141188042899294, 0.046141965975684505, 0.04484364995732904, 0.07308823537201652, 0.03406188938946974, 0.06562673051150576, 0.029553176587327357, 0.03468626636951681, 0.05925183710191519, 0.04526375725324597, 0.01995195942600408, 0.08230775114028685, 0.0027627711308248824, 0.033383445754166574, 0.061386269141709617, 0.029072176792748997, 0.052404420660628434, 0.07051161355188779, 0.0870150090345452, 0.022413124135064504, 0.04536198887733683, 0.033895046930880315, 0.032878965364709016, 0.05573134133291822, 0.08704616583042568, 0.0575575034224218, 0.028442215031733917, 0.039703498759697524, 0.12840815684607915, 0.1852061070742146, 0.23153761852412458, 0.18068746002691408, 0.1388966436347654, 0.2057603686567276, 0.2056326158344746, 0.15967826479144637, 0.10707095340495149, 0.1473027425667932, 0.20346593532350757, 0.14890450984239578, 0.25387062901450747, 0.11941955529994543, 0.1740242417661413, 0.16332085965381515, 0.28526454442931765, 0.1071261883442921, 0.11935468297451736, 0.17802133615459168, 0.1662923308509973, 0.11457204968938905, 0.13853730243300239, 0.1683317794794998, 0.10141432105052857, 0.09395903682396298, 0.23438211830873645, 0.1208946269546305, 0.10391751334311501, 0.13069571837061836, 0.21630414401090917, 0.26273693228440903, 0.11990883267454563, 0.1311812955405443, 0.20323776369613988, 0.043986749970504356, 0.1490984679830651, 0.1171974636494152, 0.16660359237463246, 0.09407008892946667, 0.11209113523364068, 0.21618520119978538, 0.14444854410905994, 0.15163310052406404, 0.17871482958716733, 0.17807912982759938, 0.1453293000738467, 0.24030842127338534, 0.12219637121644714, 0.15184578185360278, 0.14771359552058483, 0.1008077173103248, 0.07915998012909005, 0.23267109157337298, 2.8546134935271357, 11.985186453788511, 35.56208287515948, 49.45790683069537, 54.40857341212612, 52.37799767524966, 63.68574373183712, 55.33524121007612, 55.50799415957544, 52.03919118450534, 52.41893545273812, 26.727022509421072, 20.14482448177953, 11.374604817359678, 5.536954527901066, 1.4889350269109973, 0.8572552064734121, 0.6843006839194606, 1.7533841657061733, 3.1693493791164893, 5.92035444513444, 6.667925350127682, 6.996073780521271, 7.7615292226114585, 13.21729313942694, 5.831816254123565, 28.78471359129875, 35.08463236593431, 15.138980938542275, 13.148384940239692, 11.413301940887205, 12.210533484335869, 8.43078951681814, 8.67901377139553, 6.118730768080681, 3.150676690763043, 2.04703486013797, 1.5543568518853959, 2.3566960567428223, 0.5047425753887623, 1.079539601360598, 0.5629642463980183, 1.7678518280867608, 1.4960073054798189, 2.432532877691331, 4.647583077030798, 7.759205218284362, 11.888596127110144, 12.059853672981264, 30.13611916572817, 21.25338435173035, 10.760306735192577, 12.625987010617411, 11.152986980253651, 12.162929638739556, 7.4327282078804515, 9.313078638046019, 5.224842217660719, 4.592815022314749, 5.078642733635442, 1.006393894072502, 1.9488171175602946, 2.653941358289411, 4.542404230563871, 9.114570425402734, 14.288278664312056, 30.543480842344223, 62.944988435314556, 26.2854048129051, 20.744219518476918, 35.804418671515684, 44.47961891851118, 45.012935746100645, 38.65311845656365, 17.902421143747148, 3.2972279623631513, 0.5851324407323715, 0.1169048410449778, 0.20158564912215357, 0.16979114633173714, 0.12873536065941857, 0.15417171672226923, 0.11890048476596994, 0.21076997081118248, 0.30443669146587776, 0.2305000137177206, 0.14405076061525654, 0.16320556342121095, 0.10218522766785276, 0.13659283338535216, 0.16971407788655452, 0.1272023038097447, 0.16113064492181425, 0.1084660837847379, 0.10966939340916373, 0.10801391570918983, 0.12467689496735412, 0.2200262434780598, 0.12527498747071913, 0.10395506697316324, 0.1322952946347575, 0.14419463192743642, 0.13114525876458616, 0.12030184344058076, 0.25269488323359723, 0.21072005252203635, 0.09194667706446302, 0.175163812875267, 0.10535392054026166, 0.1591507519685453, 0.16968709626986136, 0.1814235939133552, 0.1163357985957015, 0.10933225343544638, 0.08234190333995127, 0.12923359360185363, 0.1477016139054491, 0.1125719856410738, 0.14220157758362834, 0.12126994108961475, 0.12536579953326335, 0.10384751588947351], [0.016804816606905193, 0.014159142494111533, 0.0744043974085681, 0.05298067582771183, 0.016970310750747883, 0.026673469316935348, 0.02888020473502336, 0.039629391244342255, 0.060911401880965124, 0.007666777641016751, 0.16079378073974965, 0.025878015327297395, 0.04015094007275278, 0.03970034247744949, 0.05184124644485213, 0.048413700123708096, 0.03224048087553632, 0.1058799088481934, 0.07982602463133874, 0.04346735384916106, 0.0018105909933388655, 0.03959051228218502, 0.040641841553752465, 0.04234508483580524, 0.007540119845690507, 0.04450147295550955, 0.09040996597539033, 0.026590289405336785, 0.0816417832468306, 0.04923250638849793, 0.05502906087185106, 0.028768357813298225, 0.07384810266235182, 0.02042844887792824, 0.035264099677724224, 0.07889225538219176, 0.08327080026989983, 0.00687953228348746, 0.06587654412273439, 0.03820573941113488, 0.02519786140070327, 0.05054623609588993, 0.039522380252639135, 0.07352140446704242, 0.04203090451717858, 0.08567993228714313, 0.03981035653381579, 0.04085845674478239, 0.04440250588701137, 0.05973927969593675, 0.050787994292594736, 0.10954156397811829, 0.05191304037467607, 0.015448365048805793, 0.056269280612468726, 0.45389615540062234, 6.9175332207833575, 21.33658959019569, 35.5167128193763, 34.84691319927093, 34.257930094195956, 28.919133217104022, 20.755104095705097, 26.22713408162517, 36.096745075718054, 42.723926805680804, 31.274381183808853, 20.78822066706996, 15.530288354043039, 10.627282492576107, 4.077541587814208, 1.724162385348351, 0.4534486681222916, 0.3569016713769205, 0.6071748740730748, 1.144725471254318, 0.5954865786817767, 1.6944970094388532, 1.782084761127349, 0.5523118244544153, 4.331386108552256, 7.809443916043929, 6.8116640371661035, 2.1242093318893067, 1.5485522343266396, 3.4614904513282165, 3.5360382833788475, 3.338475361947091, 3.7578120346992248, 2.362314852014665, 1.7319170337530876, 0.3633048793961925, 1.0898219721932565, 0.5792242480862526, 0.8270721389882026, 0.47160651474710436, 1.076677619449554, 1.971557916652772, 1.7310097405026037, 5.699974115817778, 6.513793853021438, 12.301414801228432, 5.808236435536416, 10.575233620982017, 18.745469893178633, 6.743700148597841, 4.581564684068003, 1.9887033321203726, 3.4927789530446454, 1.232502722451764, 1.8725049543765284, 0.3868540851098876, 0.5637447980623091, 1.139970700586996, 3.0549051588581455, 3.793719372441692, 6.8949344850355585, 11.455529197569817, 13.55590056988501, 13.693708142926617, 42.566451488002656, 52.03340176613101, 21.416974644507132, 22.791814419531054, 28.153617958868708, 36.191203594207764, 21.52113514561807, 8.69144082069397, 1.824294367144185, 0.08376069817571871, 0.07838617769941207, 0.054852232457168644, 0.06291085305894095, 0.013507717822287834, 0.02880390620820465, 0.07132716777343905, 0.025277682016753865, 0.010671926542155204, 0.01358358733986895, 0.03355845471002883, 0.025409998807815776, 0.05919994996680368, 0.04622463835403324, 0.0147016026500252, 0.06732207542705922, 0.013658610330293737, 0.05754425776221099, 0.008420863361548512, 0.014349984572148852, 0.10342452044208204, 0.03384450428007591, 0.026085600256919864, 0.03896187202283933, 0.09792089116789642, 0.07993096335520668, 0.08628835165572744, 0.09369952453961296, 0.024401829014682484, 0.019445102248761444, 0.012085621147566747, 0.08379358633030808, 0.05884189579275347, 0.0560437711406379, 0.06101331838797178, 0.032929178597705985, 0.01757388844365074, 0.062211590984295455, 0.05461635398528269, 0.02789907593039736, 0.021110830205162207, 0.028132416736034137, 0.03636067410209968, 0.028547002453236815, 0.05895003293370528, 0.06704490481605453, 0.028420889059141762, 0.020527590231429187, 0.03709214251308191, 0.04491667345827145, 0.05118750148422776, 0.0894937094961924, 0.019516687419626023, 0.08105701301246881, 0.018914802781035824, 0.02828572816666096, 0.04435221221478236, 0.10239352697446462, 0.014596772136076566, 0.08660856108631819, 0.014844832363568488, 0.03654465394755525, 0.0398994334072115, 0.07186275516306201, 0.10375930086499262, 0.06255300955906992, 0.042413109613041726, 0.0335334112957841, 0.03564697893096074, 0.01331633277943418, 0.05214257563854899, 0.04666181408890313, 0.0513705083980195, 0.028899146258951198, 0.02434800750756216, 0.09122384246438743, 0.05085273638307568, 0.09796575327674228, 0.0649283877423694, 0.014298608800726793, 0.028641846053482547, 0.024634488002066652, 0.039031344706252705, 0.09732501265863258, 0.057544545045182596, 0.05621416441675636, 0.08089726835849785, 0.017833389236681887, 0.03390201450055165, 0.012303248532266628, 0.14877337091151746, 0.04414351837288949, 0.06294882420690791, 0.04480839842149327, 0.04023635121543081, 0.06417720788909544, 0.02589917467576602, 0.03965141627216532, 0.015709759994229723, 0.06969226719511133, 0.01174715584174039, 0.08571338734679645, 0.8447219467451497, 10.931517212621628, 26.577505680822558, 40.732896404881636, 40.80044746398926, 40.87894193587765, 34.54827177909113, 29.813959213995165, 32.989443425209295, 40.62756507627426, 36.082518639103064, 27.050121868810347, 28.2727893706291, 21.843051910400394, 13.815536960478752, 3.5109199150916073, 1.6780316348998778, 0.2553002716552827, 0.3982076613653091, 0.2688109063573422, 0.4046151288334401, 0.6377184931789676, 0.351536114129328, 0.7677512543816721, 0.33786950392588494, 1.818494775122212, 6.8022253436426965, 3.0811269389044855, 1.9847310743024273, 2.3954797175622757, 4.897760671954002, 5.59179759794666, 3.781413426322322, 2.776851769416563, 2.636719946899722, 3.1180227139303764, 2.5578114198100184, 1.849552469868814, 3.6857968280392313, 2.6508394989275166, 2.1010857339828246, 3.4304037065275255, 2.7536048619977893, 4.769159392003091, 5.80370266591349, 5.450457930564881, 10.92946679361405, 2.1273298225095196, 4.781164786508007, 8.448812807759932, 4.4777498418285, 4.398222315695978, 2.171882064111771, 0.44310301842708744, 1.1640127459841392, 0.5053587245845026, 0.17567779658542526, 0.08727180170676402, 0.7009865079195269, 2.44137046798583, 5.706580858076773, 10.811934932585686, 12.407922840887501, 17.51507728330551, 14.472414332051432, 36.5571254299533, 63.85324855004588, 18.7040182851976, 16.350122555609673, 31.958550407040505, 41.434271104874156, 27.75888239183734, 11.664346379618491, 2.758580633709508, 0.19023893701453365, 0.06812613832974626, 0.034165165702541994, 0.03367249455843722, 0.052741733004128745, 0.0449228749400185, 0.07997546540272814, 0.03173260097091477, 0.04806648992422608, 0.03916644048125994, 0.02073409306185861, 0.0698911742637715, 0.014819566783825717, 0.06649155950834675, 0.019376790188553355, 0.02034934646930666, 0.03517337571529131, 0.03152081404902762, 0.03399653825908899, 0.024710397739263795, 0.008804504872269688, 0.006995878056547935, 0.03386958982915648, 0.0505156270528753, 0.09839738253504039, 0.07232662906209308, 0.058433475168121446, 0.0676241975217577, 0.04152950763161625, 0.02549350813722178, 0.0032681763320485313, 0.03593096772449152, 0.059143052616667365, 0.02890570780202266, 0.009781487226005523, 0.020878408705034567, 0.05312227951963583, 0.06012871666180511, 0.06883166700361237, 0.03432122930403679, 0.06420005263099748, 0.08920541528852717, 0.02968705236731518, 0.03689235061286919, 0.009286710297718886, 0.03697511492176883, 0.052895318311188495, 0.18585345137023157, 0.14817637391388416, 0.15658208980194985, 0.09971875396947708, 0.12901037090247677, 0.1245285420408172, 0.1530996839245481, 0.12638150188591213, 0.20910167646023536, 0.15700400506536807, 0.3077532086641558, 0.13421630607016627, 0.18565984563000743, 0.10578094561013485, 0.14042299721510182, 0.13152313929411674, 0.16890387861959397, 0.28016745503390994, 0.177839451559609, 0.22706007975484097, 0.09153616885023733, 0.1515273344252379, 0.15322631825843167, 0.12599535526767855, 0.10795132632577613, 0.19553387627726604, 0.1520106746184249, 0.10435157110013309, 0.21173003219789077, 0.15291349391543096, 0.3135006454202437, 0.19150633755470478, 0.16185138044097733, 0.2017493927550893, 0.18585244013417154, 0.1938684777386727, 0.21453460347988915, 0.14744030131447702, 0.14541053603733742, 0.18635932987015094, 0.09147135015096396, 0.13338444183670706, 0.15388899963469277, 0.2960393259361867, 0.12917720953062659, 0.21389389350529642, 0.22661271505057815, 0.10030360847351052, 0.13136439055444735, 0.16210814246967917, 0.17316231624253337, 0.145477001825648, 0.19442147064593532, 0.10086683631544152, 0.171405952423811, 1.1356089023813125, 11.102011857494231, 31.582467671363588, 47.23636265723936, 47.73967335301061, 44.49550451770906, 38.33937591122043, 30.66236984345221, 34.60667979332709, 44.53346129386656, 53.93580229051652, 39.2578734121015, 31.654584369351788, 20.19715870580366, 13.672958804715066, 5.185134103221278, 3.072666631590936, 0.4670364325565677, 1.0001361201847754, 1.1476913959749284, 2.0763635250829884, 1.8034528532335836, 5.1974130830457135, 5.53335722415678, 4.437823055251952, 8.702626439832873, 20.375300991919733, 16.12628955994883, 9.463962412649586, 7.649685778925496, 12.83106029033661, 12.376830212531551, 8.83673914017216, 8.853342533111572, 6.345954652755491, 5.087756360730817, 2.9956778595524454, 3.580368175621956, 3.16035587460764, 4.044935660016153, 2.81809353059338, 3.9498024938567995, 4.688869945464596, 6.953431733192937, 12.687333860704976, 17.317238815369144, 24.033903537258027, 11.472617003225512, 23.076105848435436, 26.85734521958136, 15.26876824517404, 12.639911424729133, 6.332605356170285, 10.316988691206902, 4.342060838976215, 4.331536139211347, 1.8921926785861294, 1.3261881662953285, 1.8223282790953115, 4.374651322441717, 5.29480847620195, 10.411729620349023, 15.92566522859758, 20.06826177720101, 21.18479778689723, 48.024198162940245, 61.24086372313961, 26.395048787516934, 30.38947682226858, 40.909203021757065, 48.66381122219948, 35.95422967787712, 14.816970036875817, 3.2750697578153307, 0.27113399137893035, 0.19461279344414512, 0.15188491362477505, 0.13493544812644684, 0.19310844190899404, 0.13224205152402002, 0.25096764607775596, 0.11690663369072062, 0.1548160119883476, 0.08175882615990217, 0.20757340766008825, 0.18686816546945803, 0.17317673401726832, 0.18876257833213578, 0.15111350905030005, 0.18981293084159975, 0.11331234833285694, 0.14463998948133763, 0.09838635086893074, 0.08500434232935791, 0.1791940635490802, 0.07293435129066629, 0.09651254577141616, 0.10353436978954463, 0.2455847599213162, 0.24537100606868345, 0.19841113398152016, 0.1953328854494518, 0.09099998391203343, 0.12833381567390698, 0.1304991555310065, 0.2049895309873166, 0.13159197995499258, 0.13502082096472864, 0.1334662753487787, 0.146915408512277, 0.08007259769064766, 0.18709448316404897, 0.18379601499726697, 0.21246625801488278, 0.2441880743830435, 0.26109949595505194, 0.13092186752586596, 0.19758313083119933, 0.15893096134306925, 0.14240900355000652, 0.17137605967300554], [0.029998204723421126, 0.008770043364605837, 0.05432207663092883, 0.019135171802894726, 0.079926903089208, 0.0483782647267705, 0.05025505756718978, 0.021160089658693444, 0.045003000076019, 0.03442035342055944, 0.017613177262847463, 0.03600929638430957, 0.047194532479249665, 0.02863377340198044, 0.02673143535972603, 0.0352854467177343, 0.08452430397512452, 0.0493229890332347, 0.04689512999668237, 0.08627709782411976, 0.01724412015098478, 0.017662021113679777, 0.026709862323778293, 0.01787473308673549, 0.02836122421637899, 0.040759987633434996, 0.04028281444803842, 0.003596503421806941, 0.0802517396908614, 0.030477967286001773, 0.020019603074498234, 0.0344889106289033, 0.009935066787405841, 0.05892026275696774, 0.027147279376344337, 0.02667778430716886, 0.02472649516177274, 0.025956772996353048, 0.03773490943375134, 0.012403133948664031, 0.05537624808869535, 0.04358739599645619, 0.07274286761399239, 0.040638286905783805, 0.049162922622335535, 0.006679494756334011, 0.07178143492989963, 0.06367363148338853, 0.021667281999402953, 0.05064588115220109, 0.0334756023010179, 0.019672425433753, 0.01250007950265201, 0.021378194890736092, 0.028754708041707357, 0.04440791829819641, 0.3248066935808428, 4.248368163262644, 14.89947219048777, 30.56981759686624, 44.85974365665067, 38.74226608584004, 30.948914674020585, 19.852211744554584, 16.147989092334626, 13.113162056092294, 19.793107509613037, 32.90794441776891, 24.2212986946106, 18.51398729508923, 15.255724403166003, 12.37250089645386, 7.273991848191908, 3.287335009344163, 1.60739416076291, 0.7132685520956594, 0.31080251439444484, 0.2958346885298529, 0.3417416800174021, 0.14201491259999816, 1.5269251432149642, 6.869776402750324, 1.3725842896007723, 2.0864003800576736, 1.9068639364934739, 4.098839567553613, 4.143980654977983, 3.317562755077116, 1.7322474934401053, 2.3342907428741455, 3.151716118858707, 1.759727864015487, 1.2399721410005324, 4.869548534193347, 2.640804114841646, 2.165628090020149, 3.424047260515152, 1.748786902716083, 3.4934788509722683, 4.862422568182792, 3.2369538805177136, 8.690614181180155, 3.9783156735281793, 2.2065251729180737, 13.40480596788468, 1.4777550461792177, 1.925365266300017, 1.3597583842854346, 0.17264111598412837, 0.9487001189301092, 1.5479773619482595, 1.9488331747631875, 3.1018740707828156, 4.879554010206654, 7.4896285610814255, 9.21694036453001, 14.315084142069663, 15.975959820132102, 16.413696331362573, 19.531057880770778, 33.408387860944195, 36.2638262779482, 33.618830865429295, 40.05987651886479, 31.000276150241977, 21.156070347755186, 8.678626437341014, 1.9129139473361356, 0.09671368215593601, 0.02377245522614929, 0.04671908299168272, 0.04409830003315884, 0.018861597974694545, 0.021391557379355355, 0.07910562619086235, 0.03220911723591628, 0.031635945572728114, 0.010632663578425926, 0.051835343737395546, 0.07229584764929549, 0.006527189294912763, 0.01316651279452227, 0.10444303433741293, 0.053144427121526776, 0.05846300785760245, 0.032063512649807724, 0.17515206108650855, 0.10294809036197201, 0.05943481720262959, 0.03350176420363207, 0.043339398013608116, 0.026526748157677152, 0.01714382966559741, 0.028291081206031868, 0.023324592564735683, 0.14844804401359252, 0.0670663016517797, 0.03366192637552177, 0.007485155431148146, 0.04148722340863559, 0.03987701384410743, 0.02635463501416868, 0.018067584230354237, 0.036486967526856935, 0.04894253061783891, 0.026019168942565882, 0.020278584842960683, 0.025161317091495283, 0.08972329072534077, 0.06574587250548987, 0.04040238928169974, 0.03424488864238224, 0.012574887988457998, 0.038305805815804395, 0.0428850197743985, 0.016659300120907928, 0.04251837009383787, 0.02669147621359556, 0.06780629662135917, 0.04122537455611652, 0.05381027244091515, 0.06350871573592867, 0.03995484837721433, 0.013141394686704923, 0.06135585162067606, 0.036982726005296555, 0.03745324954751038, 0.0837275495512351, 0.04541978638078417, 0.016110581984262795, 0.06761809180100119, 0.06578354870960598, 0.026284700762780926, 0.01145443173065301, 0.030723778087826028, 0.050200270789284865, 0.03329915693029761, 0.03984240965256768, 0.02490404369910398, 0.014222500838279245, 0.030814287545640143, 0.07208299011953416, 0.02693863916060617, 0.05908727758534013, 0.06831212915600308, 0.022483184790959763, 0.008777360461892621, 0.0790231108605381, 0.040807803011228966, 0.05088522234150479, 0.031031689892012267, 0.005606456947017221, 0.04746105446810684, 0.003226103740856953, 0.10471079738870745, 0.05144053266473836, 0.07752280426962722, 0.003204803144927287, 0.0327198374115171, 0.022442164613054167, 0.04321525729591808, 0.042992076731377074, 0.07488848070704168, 0.028358540993424195, 0.024119709475686955, 0.029217894376826384, 0.02583192173211325, 0.011896810160138676, 0.02943715831685451, 0.042269870323399385, 0.009583495632414857, 0.04720819182693959, 0.4592589547316875, 6.056535705443352, 20.19013177963995, 34.222667986346835, 48.81742692762806, 38.75416655694285, 28.580515000127978, 22.42576510675492, 21.572451514582482, 22.241670623902355, 23.86966605340281, 30.858129455197243, 26.253523788144513, 24.44591518371336, 22.59789832176701, 14.501983119595437, 9.196681322589997, 2.105089983632488, 1.7652896623457632, 0.8047886024559698, 0.08237824655107914, 0.08834956484215875, 0.2526016962984877, 0.11913117682260853, 0.48095634207129484, 0.17515356261884013, 0.6936177226804918, 0.891921297917443, 1.3836284582653355, 1.3027366827572546, 1.9669819815504936, 1.218449482994695, 0.9099338636282952, 0.6747283846620591, 1.0371891577397625, 2.1115628750093522, 1.206263659461852, 3.449322523609285, 3.857479460777775, 1.693200420948767, 3.8137460139489945, 3.0805351513047374, 3.6425965784057497, 3.353766476915729, 3.6631019942222105, 3.298235276053029, 2.1900852937852187, 2.5184114565772395, 1.604482046058101, 1.7336664108499404, 1.1292388506474034, 0.633122762364726, 0.2476152759646216, 0.4424892287821539, 0.3287545285157619, 1.2140342424954138, 2.3794315851503804, 7.411335110664369, 11.743493926140571, 12.974748476859062, 17.29617960991398, 17.209628589691654, 17.200536535632228, 12.177469864968332, 35.20313109121015, 44.40869462105536, 31.585179990337743, 39.69768093478295, 34.137077946816724, 27.5243442673837, 11.975771784782411, 2.852176475909449, 0.27199053896530984, 0.10161566427878796, 0.04206403015902446, 0.03439505336686008, 0.04389374689649671, 0.056820473213109284, 0.01447890855131611, 0.03159006456694296, 0.02269941502280774, 0.03608963219448924, 0.014826188656321217, 0.10954809104723316, 0.020305704355480212, 0.09644035730631122, 0.12599298805599252, 0.05262941302311036, 0.04611121520640389, 0.03526497684839753, 0.04195139608195713, 0.08259560867783525, 0.06157275026423797, 0.031055226028265975, 0.0415666897090212, 0.10398035553554374, 0.048090843859338955, 0.07997407878358519, 0.06126879338896083, 0.051458447630847656, 0.05625044251041067, 0.08218631854340916, 0.059975001119798234, 0.0637187272490513, 0.0755962310358882, 0.14341530600382438, 0.037859613226065715, 0.04248340967141333, 0.0546138680299684, 0.06092542128997946, 0.027436010254126404, 0.06918870228072328, 0.021993014923927766, 0.10511109365090247, 0.030199176399037245, 0.022234079811061104, 0.030647782165737405, 0.11033546855492939, 0.09773599584737132, 0.04189900715925521, 0.10052414220427314, 0.11481060946900999, 0.3352206476753758, 0.2756390173829371, 0.1977569255377016, 0.1775520919792114, 0.16513100284482204, 0.13058748546867602, 0.15317765635348138, 0.10510969937088029, 0.132550846244539, 0.2558068702778509, 0.10023040877234551, 0.06799619449602981, 0.1089754939499882, 0.16357395978223893, 0.16534156977168976, 0.20085302391840568, 0.14730320221954776, 0.10005281426973882, 0.08167873166741864, 0.15697973539992688, 0.10982197514104267, 0.08371942901923772, 0.12534798032814456, 0.18425620401338225, 0.18123113730501744, 0.0986710521242311, 0.20629103776187668, 0.1623198585284333, 0.10845888255824966, 0.11394954962475647, 0.0881879585945318, 0.23708435556580945, 0.13143202079640282, 0.07442407820734286, 0.08824462611829081, 0.1310436448623096, 0.1928821242144031, 0.1404885896631787, 0.2313003610939749, 0.21263162575421796, 0.20944325974391353, 0.12527445120917213, 0.1952743410102783, 0.10990459006279708, 0.129635100282969, 0.15952697774815947, 0.15096867246733559, 0.12012134546474104, 0.12937106041898652, 0.12303405005725161, 0.16630841869740717, 0.1280376230997424, 0.11191168679825722, 0.0949408857512378, 0.5890398568684055, 6.249711455837374, 21.738483482791533, 40.02710903844526, 56.1463834393409, 49.457898985955026, 41.30615472793579, 32.43946633031292, 26.208700903000373, 22.03754851894994, 28.891784491077548, 43.34027236507785, 35.06208265981367, 26.26354152156461, 21.162757988898985, 16.48795170168723, 10.28593626714522, 4.38030198697121, 2.0360779642097415, 1.3969458855928913, 0.5991936475038528, 1.1575929291786686, 1.0464118757555563, 0.9161801768406745, 3.3680564068978835, 13.273707609022818, 5.980214716926699, 5.040505038153741, 6.975002317659317, 10.451011177032225, 10.48112125166001, 8.276604087122026, 9.652284229955367, 7.2169301875175975, 8.413493825543313, 7.33472582794005, 4.8542753150386195, 11.797152930690396, 7.646629762264991, 6.331954733017953, 7.1829850154538315, 8.783628286853913, 9.594601854201287, 14.451623808953071, 10.54870859269173, 14.669286916332862, 11.62746629407329, 6.074285411065625, 23.345455008168376, 7.706946009589781, 3.985376184986484, 4.058511963775081, 1.2281615166894853, 1.8934864478726543, 2.0294201085644383, 3.2228772294136787, 4.069721607431289, 7.455872153082202, 10.410673522180128, 13.877130919887176, 20.768183239044685, 25.40787450728878, 24.022377652506677, 27.396220045704997, 41.22893894872358, 44.30964300709386, 41.309888824339836, 50.94572067260743, 41.36761042379564, 32.194745732891946, 14.289133741009621, 3.157359919240398, 0.25649172223864064, 0.17195053368566499, 0.15803810118907885, 0.2039987035095692, 0.2206615601936656, 0.18594673023589198, 0.1883233648033873, 0.13812436572005674, 0.11430895977443266, 0.08776215160445822, 0.1069712317398479, 0.23132254700026206, 0.13225354284288424, 0.1376416383972091, 0.29345705804805605, 0.11169000393560818, 0.2912468637429899, 0.11887164155562079, 0.3071817070726426, 0.13433255225179658, 0.24240072996866321, 0.14264405464693425, 0.13738588760456732, 0.2534535401050122, 0.11224970011220825, 0.1296671534017209, 0.1627198789989756, 0.19401259419898834, 0.23625402350819882, 0.20080725782580916, 0.12296500255263622, 0.21704807667241943, 0.1393142994493246, 0.24151122527978114, 0.15468507224032957, 0.12406155782481357, 0.18152586665124665, 0.14733782939372525, 0.11694440948626689, 0.14456947874878684, 0.1021648114246707, 0.220159113767647, 0.2071490715588293, 0.14609171077609062, 0.0769621504831218, 0.11839839840127576, 0.14605165969940925, 0.14429465236683048], [0.04488558944074377, 0.0665769400075078, 0.06380559395878546, 0.022165717955137935, 0.031733345991421136, 0.06297963626322246, 0.04364123665577462, 0.062164078211231585, 0.05164448059194031, 0.035361354539711634, 0.007403663785812716, 0.07124370249408869, 0.00930831110435388, 0.045470685262473366, 0.04539555501973918, 0.03480372680050712, 0.1023589993917173, 0.027960485538407683, 0.042565676023162184, 0.06292259718682017, 0.08262978386013739, 0.07070226985360346, 0.04764675801139205, 0.03596684745242519, 0.056224234642521034, 0.02700184524479893, 0.025687253688492125, 0.06503206242116229, 0.046745865425515565, 0.05546906730160118, 0.05239906187559809, 0.05051607138387138, 0.019655450840570757, 0.07713917808066453, 0.030774521836710554, 0.056566836823138504, 0.07535580966261125, 0.05203823063282236, 0.02221684283276479, 0.05958576333679019, 0.04551249451094097, 0.023816692973336866, 0.01566248183559266, 0.08170332308978805, 0.011920346296392383, 0.07304639931047156, 0.03712081335364811, 0.05267372354865075, 0.05299735356182341, 0.03279350825675553, 0.039791070270322026, 0.03260264128086067, 0.06671121989887568, 0.0075798606567625566, 0.06186656796583726, 0.061954756177240805, 0.02196038532401285, 0.06653039250522852, 1.4229698310936651, 8.570989735664861, 21.530297802340602, 38.73566081446987, 42.401578580179525, 42.30000095982706, 32.76074767112732, 21.214148882896673, 17.195666913063295, 18.076846984124955, 37.620589810033, 44.721660537104455, 25.56503015179788, 24.224120839949578, 19.172945484038323, 13.885042340524736, 10.53290242148984, 7.23094089377311, 5.354735918583409, 2.2183947553557735, 1.823228463049858, 0.6447551639810686, 0.3219163357730835, 0.6331412097619427, 0.6625608859523651, 0.4503046126375276, 0.3752123678643858, 0.6297960408752965, 1.985415160175293, 1.323293947404431, 0.8001359972742297, 0.548012784171489, 0.844175266402383, 1.9556609180665787, 0.17918388990144576, 3.54802185969968, 4.159476958936261, 1.368548415841595, 4.016236167761588, 2.612059025033828, 3.7684396966811153, 2.9826752024312175, 2.5196398938855817, 4.097119363084916, 0.23731658745917583, 1.3646134205402867, 0.08659574443534498, 1.0186804122021123, 1.1963730353501536, 0.8428577177466885, 0.5185842826481789, 1.6167834569369595, 2.964838469220746, 5.922749052124639, 9.788605224701667, 14.410349688222333, 10.704454145123883, 11.155106040739245, 15.595329096240384, 15.6757112087742, 15.2655646493358, 17.183876268325314, 23.72051400523032, 32.69760339490829, 35.650293057964696, 31.18718493369318, 16.99561426716466, 4.776295654235348, 1.0098213101586988, 0.03189460366904255, 0.09000091332822077, 0.012629954388455279, 0.007856025777366615, 0.017502904651806723, 0.0802507744200768, 0.1336149117278476, 0.017673129388581843, 0.029442854180571534, 0.04954670585932271, 0.025707880605853377, 0.025772398615616466, 0.022656935447406386, 0.03594109923729012, 0.0320947575457995, 0.051731025544746276, 0.01619065923976802, 0.027881994084905715, 0.015596098401733946, 0.0482872381596075, 0.06123186795101051, 0.1101572305384663, 0.07524921618882688, 0.05932500615956322, 0.037771570571367784, 0.04183957405808953, 0.0357886094359621, 0.13182591256355086, 0.10980571875528944, 0.0698599408590986, 0.06082907424218232, 0.07340034725324762, 0.046480435111950484, 0.019056557775324872, 0.04124264983880905, 0.03205770187290206, 0.05277457902388227, 0.08246141305613904, 0.12821060575304494, 0.025002522386550426, 0.022548641258430098, 0.05473620461059674, 0.04976130240867215, 0.023877713791725617, 0.08108014120690285, 0.0641770048757955, 0.02898128620619255, 0.0349839681368922, 0.06774694778986516, 0.06208240174718442, 0.015417197719216348, 0.01882058354244838, 0.06088087327718254, 0.018539507798249685, 0.048273237902791276, 0.011759860452354677, 0.09200535173858367, 0.09431516811732324, 0.056461794677400784, 0.04013577153185203, 0.010186808067373931, 0.048528191963991815, 0.03353083340991889, 0.04208001075312496, 0.014231017820777432, 0.0645303667613095, 0.016620151112757383, 0.02915961806842637, 0.010385872184058592, 0.10636042217693983, 0.07953770744103579, 0.07516622588398957, 0.052742889796894406, 0.03564751519250774, 0.02872202290041793, 0.10675656624258527, 0.041369138615987, 0.047051626437854384, 0.021328667306431362, 0.03103690886599643, 0.02607228564879587, 0.042908029225204265, 0.01255463932700936, 0.017692802526477366, 0.02215948008421448, 0.03940895710500979, 0.06470030804555263, 0.020910387130213842, 0.03407506227132774, 0.06833665929133854, 0.03093279751708671, 0.023874704981403008, 0.06766703715848346, 0.05403077169772118, 0.06543491741702442, 0.041631240277521075, 0.04250063132795115, 0.050245703633634314, 0.05203885116404103, 0.041622150644299485, 0.02165165763618725, 0.07158862592111673, 0.06689022400326307, 0.043706442229449756, 0.046700091672039805, 0.046383498176451654, 0.14056008098827255, 2.444244584729595, 12.448532119874033, 30.475972929308494, 44.30905465156802, 49.128914110122196, 42.97433091748146, 30.78655600547791, 17.919991400934038, 20.05266643339588, 23.66617545004814, 33.00971031188965, 32.3239819465145, 27.32409550297645, 28.7928250528151, 25.57400453475214, 23.761371374130253, 10.727451001444171, 7.909508972398697, 4.973285419325675, 2.1633930744663363, 0.9352569918959373, 0.5042106652211759, 0.33082333363352284, 0.2369388754689886, 0.11385885247540091, 0.08721202386603241, 0.2584906601377072, 0.33814839057384, 0.1561195259132693, 0.5498565433006133, 0.5575320088574963, 0.5103575402209836, 0.42030506917545873, 0.5748719493708303, 0.6208917702878676, 0.8883602148102177, 0.9360631002533821, 0.3304287370654845, 1.0046939756120405, 1.321083446664195, 0.7114007684492296, 0.4452363281480728, 0.1704976172937501, 0.15592726848779187, 0.23168605572033316, 0.1425627420746511, 0.5779302949386259, 0.21019189618527892, 0.058587133253534, 0.33989280342094363, 0.466761406991751, 1.0069733016913938, 3.8534889394237153, 7.2674880681499365, 13.102319644343469, 16.540884087162635, 17.30512849746212, 15.824750488804234, 16.762986336984945, 17.207632103273948, 11.620028499634037, 16.739554097575528, 28.780061660274384, 34.62620927441505, 39.06042914236746, 36.31170665064166, 21.574304834488903, 7.820846736431123, 1.395579184735975, 0.14671008162681135, 0.06183030902438107, 0.013931092483201816, 0.026535274716274395, 0.009729411441742653, 0.05530554200372389, 0.029235043255011403, 0.047899750887506434, 0.013639038699048181, 0.02857425220070347, 0.032043310911244446, 0.04110072822039647, 0.03632853671367611, 0.04291588162642814, 0.014019193552103976, 0.011903975955060413, 0.0328605447805697, 0.010999519145116212, 0.013120447927635285, 0.02569221410780184, 0.0547574405678578, 0.05303649682431452, 0.008320310491047079, 0.06570978210337701, 0.04464367802645411, 0.05217042293459658, 0.06949977994325661, 0.06306428131797621, 0.03714850360167123, 0.05957746660457023, 0.06487148273135386, 0.07680548550260645, 0.06532152108247243, 0.020560139392112053, 0.04871336307616965, 0.028051537003428228, 0.024875618006673553, 0.02232699286973765, 0.051269212422231515, 0.034131584238381155, 0.026768969837576154, 0.025393215736614603, 0.03660759573141414, 0.029117151899563692, 0.08462889795942653, 0.018152828748908736, 0.08184907897826164, 0.0446477574446509, 0.0460997277179793, 0.2544264104818144, 0.13487891083763492, 0.23392759834326085, 0.1830324704848951, 0.06783003002525338, 0.13514903343973622, 0.15377425498539402, 0.2364318478371828, 0.22022634564388185, 0.18876368149874673, 0.16989804624069124, 0.1550360937272349, 0.09688381496216021, 0.14072809939182576, 0.2451299181989124, 0.13258101478699716, 0.1504291627075403, 0.1649793174358145, 0.09900462212822131, 0.21332997618423355, 0.20603406122855603, 0.1694059726451674, 0.279283665360943, 0.1273790556156347, 0.11353773140018025, 0.09458528305854529, 0.23709917170626504, 0.20003741607069972, 0.12774374411110917, 0.1088245822897842, 0.16953233118739822, 0.13328212313354015, 0.11521731788713126, 0.20148929058303758, 0.061970675484307354, 0.15518339711331552, 0.13945915135404757, 0.11401039232770283, 0.0924207552546455, 0.1103712831653895, 0.18843201139280874, 0.17058858257387916, 0.24817194609392076, 0.14623162907458123, 0.2298313721774086, 0.15175714548076355, 0.08412349443402022, 0.1871053156472983, 0.1428096675344052, 0.11815154188943487, 0.12417629481323304, 0.16025503706787864, 0.24431440228175735, 0.138707006229989, 0.1681183014185198, 0.11586838537046026, 0.16400906707971327, 0.2218074898325628, 2.2768650372182173, 12.907941687491633, 32.13763013962777, 49.49480064453618, 58.74522432204216, 53.58981786235687, 43.04147012772099, 30.11785661020587, 26.952190091533048, 26.442721274591264, 48.03636927758494, 56.433140077898585, 36.170571927101385, 33.99695519478091, 25.648696268758467, 20.454689764207412, 13.896275028105705, 10.309470488179116, 6.841515725658787, 3.2818360915107117, 2.568521941861799, 1.0963169269023405, 0.6839677114640513, 1.028715489852813, 1.957153379917145, 1.1590748496593968, 1.6052885834247836, 2.513703141481646, 5.3776768811287425, 4.094707595725214, 2.141214522623247, 3.379736980122905, 3.1266244717182654, 5.275443244364954, 3.3103343171458093, 9.218684838664148, 9.215392989497031, 6.8929041681751135, 10.708000948352199, 7.212818562984467, 9.601224776237242, 6.805954537084026, 6.186463727105049, 8.367049040332917, 1.770475035713565, 2.8899594420386903, 1.2783532685810521, 2.024094755611112, 1.8970239354718117, 1.8593598661884185, 1.220802292227745, 2.3682766095284493, 4.920076997049393, 8.653058467372771, 13.393638980004097, 19.511447991094283, 17.852789432771747, 18.93216294627036, 24.386775647440267, 23.318843687734297, 23.285707504518573, 27.59186983108521, 33.995719648176625, 42.54154051503828, 46.247874383003484, 42.010412370004964, 24.78122684263414, 9.056223207904447, 1.5781631873499964, 0.2680836131255473, 0.16969556920230391, 0.19230066347987423, 0.18460360956528496, 0.08426377279383522, 0.1293979041398533, 0.39610588382328715, 0.1261168491515902, 0.08675172759760773, 0.20115967359273665, 0.10891327994965738, 0.10180495694399842, 0.07962811347698012, 0.10661484763747263, 0.18949736390383015, 0.1508055263829808, 0.10785298361893624, 0.1746739609347236, 0.13548107126787787, 0.14654777823917328, 0.19780687447036469, 0.27335739303981105, 0.13357864512551215, 0.2025782539238853, 0.10855225335446098, 0.2003736673824249, 0.10916173758526003, 0.3246182972385038, 0.20226392804855303, 0.2844544524146665, 0.21156919969906732, 0.2785854528267538, 0.21679335243759618, 0.12814190298799547, 0.20132671140374678, 0.12422422893465528, 0.15747335649305777, 0.16127083901195757, 0.22733660685198925, 0.14209584212831913, 0.056345923878853364, 0.20887077755985722, 0.13303902811340748, 0.07439908841925283, 0.24345561771863894, 0.17128406783505795, 0.2485813894459317, 0.16807958333482667, 0.18049195438863772], [0.07387417263441509, 0.04846088347896453, 0.05425434296710357, 0.06697608713781641, 0.05104237761829169, 0.03321627004733009, 0.01744906016204867, 0.018738688743342797, 0.046782392497745254, 0.01616661748548429, 0.0327600531971022, 0.05230969005835153, 0.04900906918450229, 0.04918292134759888, 0.07831352192067331, 0.010710607279062031, 0.05758269239337214, 0.02472623086143886, 0.025425132874759938, 0.01197520106460058, 0.03469257893401288, 0.02642534876001939, 0.10248558009944617, 0.029410368222142422, 0.15574898450605332, 0.05193780033638881, 0.06426921504880152, 0.06691185832624474, 0.033435662307085535, 0.04914517619556958, 0.022431086981669072, 0.06014748198551036, 0.009420278684927091, 0.01885922884778871, 0.004640839507638087, 0.06228787801979531, 0.08721514950476347, 0.07076494350668884, 0.03264052815915596, 0.01866158390898378, 0.04045683515047835, 0.018784460581598744, 0.08985131167836728, 0.05599158906167554, 0.027894494724610162, 0.05847607348715106, 0.03381554232609849, 0.06868392694741488, 0.030289975055042776, 0.04685962565183159, 0.015858498837558493, 0.08623011365172364, 0.05412866624312536, 0.07451594747122257, 0.030022403525729335, 0.10067332250576827, 0.049177252296959205, 0.009835141151392413, 0.043571162593340686, 0.16061888286663642, 4.02791379920898, 13.652034921030845, 27.36556672280835, 38.48668052304176, 38.209133609648674, 44.995394906690045, 28.077253333983887, 19.851409619854344, 22.354740788859708, 41.53232643681188, 60.717921564655924, 49.46337069234541, 40.076417153881444, 19.75762574903427, 26.189791156399636, 20.9922819752847, 17.083749924936605, 14.075821522743473, 11.658796225824664, 7.271554095129813, 4.878719035656222, 2.1546037783545833, 1.6799239333598845, 0.9439178916715807, 0.6010032084680373, 0.4126275811464556, 0.4593282397235594, 0.1968636363744736, 0.6310494832934872, 0.05674751482964043, 0.16557591606772717, 0.11790246372261357, 0.24097084217975218, 0.2720503244669207, 0.5179913305947857, 0.2075458744600896, 1.1418425291776657, 0.738511087913667, 0.72218170930301, 0.3467945201743034, 0.5651235111778783, 0.12349777839957707, 0.4199335778192167, 1.3347411396041995, 0.6409789633847053, 1.6061823935278001, 3.04096530041387, 3.6395989070015573, 6.270493153602847, 10.609583777766074, 12.241729074908841, 15.892684959596204, 17.270858749266594, 17.089327535321637, 17.253259074303415, 13.237420781966179, 13.752612336989372, 16.845042320989794, 26.174666497015185, 27.69448491834825, 30.696704310755578, 34.58322794206681, 26.39343277100594, 14.080326364886377, 3.4662134753119562, 0.48398428927025494, 0.11363991986840002, 0.030671117203910987, 0.014478795553347277, 0.03557763265205487, 0.029160340106295004, 0.029491496933323723, 0.10747071340559952, 0.022448080727049423, 0.012047672982237512, 0.02445497827964925, 0.03371894246928635, 0.018950479495669567, 0.017218525153434566, 0.01774091093290237, 0.055149953376742146, 0.12942120853450992, 0.055585248365757935, 0.03629870908034425, 0.03334307292055699, 0.013681094053261464, 0.027517654159436786, 0.021749670925219695, 0.0035336818179911786, 0.06896829878490779, 0.1482748468556712, 0.0034926877349555014, 0.11561035929668335, 0.03866292153214736, 0.049815928308112975, 0.05005520437994311, 0.0606712524689013, 0.04263203838960298, 0.03870474610237345, 0.0890668070003871, 0.040439770541965, 0.017062589871667085, 0.030124339184934096, 0.05988886602403176, 0.07728785276412964, 0.006883260737653943, 0.06744119443840559, 0.019363628798014215, 0.03370459747290419, 0.014809690952871837, 0.04922140577447511, 0.02891188630113198, 0.038367705720086256, 0.02954520352725541, 0.06258089515951372, 0.007457639468127802, 0.06714175365144207, 0.0391534935953396, 0.06281589646072638, 0.013718160259867869, 0.086546745451708, 0.03597779484886316, 0.015718173554858134, 0.023982964696422703, 0.05261040255126934, 0.006996720753264644, 0.017854634770041993, 0.031735401022278016, 0.04338642049040045, 0.03077513087661036, 0.0007041343339932932, 0.06206680802748569, 0.01251641441241748, 0.11389876565625591, 0.05572369960587352, 0.05887210263960785, 0.025726483135874716, 0.035698678374530814, 0.014014153651172116, 0.0229657014396282, 0.05720183944269534, 0.038658236904490384, 0.06728567858977665, 0.056666282696589354, 0.06825219043680737, 0.0626680146782629, 0.042223430073429505, 0.023960183156774412, 0.029878338776348583, 0.03109017878981127, 0.012085767661882265, 0.08722501671722821, 0.004719561745127243, 0.014717475034206387, 0.025975754739896908, 0.04293919751240362, 0.027145488645821333, 0.07023180759842358, 0.03835738268530658, 0.029895286556453477, 0.02121484387786158, 0.008061888924379262, 0.04216524952602002, 0.018575619267780456, 0.03357985920663323, 0.031248722600960926, 0.023673582003421845, 0.019367938042588292, 0.0757985242131737, 0.021160652733317787, 0.03488512747290154, 0.04733468060411754, 0.033045604809998505, 0.07625036287091433, 0.040711076749909314, 0.5145847521001293, 5.376412407044442, 17.61477020479018, 33.54784773242089, 45.30423841168804, 42.562921354847575, 43.97823802886471, 26.757560122397642, 18.612483893671346, 30.603255802585235, 47.373218074921645, 51.663545793102635, 44.73090948597078, 31.995155926673647, 24.214495343546716, 38.79464541712115, 27.63607494292721, 23.82803793876402, 15.084694354764878, 13.385460838194817, 7.656928435448678, 5.255765203506717, 2.5165037137846795, 2.0549976393099754, 0.8484410891129125, 0.6952067728965514, 0.23299525401765303, 0.32910064703995184, 0.12537315397733642, 0.1417150198211593, 0.07684665506765728, 0.24148041322346658, 0.1336092886424834, 0.04453743695311489, 0.17366208136081698, 0.2761738693281528, 0.21170959297207095, 0.37086760745413844, 0.14446637863593717, 0.4318723839617545, 0.07544445369632975, 0.4611534595249161, 0.18662978955093892, 0.4190275715964456, 0.04988541631328483, 0.8970003382813547, 0.8392113230882153, 3.1652786943220326, 3.464630553799291, 8.864190828415657, 12.294889938446785, 16.856021035102106, 21.32776817967815, 24.95656463407701, 21.858574690357333, 17.800408140305553, 14.19088327115582, 15.209201170552163, 18.96761921144301, 25.594104720700173, 31.707344170539614, 33.639187966623616, 37.90854277149324, 31.846994276969667, 18.165233673587924, 5.433668715338554, 0.6801217049360276, 0.14779233403744238, 0.041559768104625326, 0.011259006531608683, 0.056928208157900846, 0.016767182537624915, 0.06082340136110302, 0.047669189065814986, 0.06656926380650652, 0.09459567887167777, 0.024310178085861188, 0.014622606536103113, 0.018796696920969316, 0.05012473451995081, 0.061654572284990744, 0.034436073544765675, 0.0846422968372222, 0.05652581664523291, 0.03861334415212755, 0.0290100738751672, 0.09579007889354423, 0.06813634262089768, 0.05626952193016487, 0.06258546870442168, 0.02990682384059314, 0.02713310674974515, 0.08202813670880373, 0.06595581890113893, 0.05427807254055816, 0.06216720768040227, 0.026968348050309766, 0.045953381941804004, 0.07106000993160472, 0.031181852701270295, 0.03456520532528239, 0.055439117094201434, 0.042427588674810626, 0.02889184161059318, 0.024039973129308032, 0.05079609184195438, 0.06647230005793034, 0.04282102461964373, 0.02149882692573292, 0.038007552465123516, 0.010045815330569544, 0.028619983819343393, 0.05706553707920736, 0.06600781328855984, 0.03966740069670543, 0.0895472590420996, 0.038931653684666084, 0.28541246068573767, 0.17912893075375788, 0.11028188070462597, 0.149620296433568, 0.11651697072891459, 0.23277603029724092, 0.09908113899009843, 0.1262784477383379, 0.16768363845204154, 0.1005643848029356, 0.13568763921578086, 0.19145591364752865, 0.09699043141858232, 0.1382562094518254, 0.16826399601995948, 0.13533454929147998, 0.1343070874891935, 0.1530443110893811, 0.1242794638739959, 0.13178186250790475, 0.14203119962926836, 0.18896220552344478, 0.20324850424883828, 0.18282518241434328, 0.2538712418848469, 0.17299837342673735, 0.14665608774990807, 0.1555850416902573, 0.153716798391073, 0.1975386364445571, 0.1008995482698083, 0.19542003561171795, 0.12688777109067287, 0.11204579048940252, 0.15750338713968956, 0.13385537140552076, 0.1818592681158935, 0.24963667556162805, 0.12727348869966884, 0.12341540096507919, 0.16238689122180786, 0.21928312286974924, 0.16226788712365015, 0.18556826747953895, 0.13140615766807912, 0.12656115716503513, 0.1098714490991927, 0.21949607999094073, 0.11760072467187721, 0.09048861256169696, 0.17252362874006072, 0.1457251530260809, 0.17452952271747976, 0.11042346907479149, 0.24696448427294534, 0.1430151476374557, 0.09647876895483463, 0.12167661120333981, 0.21164655925766115, 0.7169675310292553, 6.858235318814555, 20.233291579831032, 37.447421089295425, 55.536066562898704, 52.09312377437469, 58.840781104180124, 38.62516372434555, 29.161194447548162, 31.58299326896668, 51.03154997671805, 68.49492257641208, 61.892028162556315, 48.09849569874425, 28.058221993907807, 37.837912651800345, 28.126037813002064, 22.996413092459402, 18.177995104943555, 15.740816670079386, 9.348546670329187, 6.449259586872594, 3.369464782937881, 2.9019650816917424, 1.4819586012632617, 1.0902531877640755, 1.1173620363396983, 1.0283901782766467, 0.8023391435703924, 1.2200001675275065, 0.5192510855774726, 0.8557246240877336, 0.6202756517356443, 0.7850916851912776, 1.3476056557509208, 2.3144562975052865, 1.3725605102316027, 2.3587349537880193, 2.6383501820025907, 2.3870093591751593, 1.2297427221652002, 1.4940776219291072, 0.5946033712356322, 1.0481588013710514, 2.1672798981589656, 1.3704815314662073, 2.186393608008662, 4.257168491040507, 5.142158654428298, 9.302541190578092, 14.312261996730683, 16.952181862246608, 22.639065557910552, 25.711391433592766, 25.492782054408906, 24.13670885947443, 20.873710686160674, 23.355309963226322, 27.04446581102187, 38.181586803928504, 39.6980574823195, 42.28226007953767, 43.45305619701263, 35.64546854265275, 19.127324396564116, 5.480554276897061, 0.7968603278840742, 0.2514255521518569, 0.16084935275777695, 0.10191325879385395, 0.10157908358040357, 0.16033049672842026, 0.21213484837883906, 0.18331629073908254, 0.13095246507756172, 0.10510647414071907, 0.14556245127272222, 0.14122184305902452, 0.11370189638147432, 0.12082023981718287, 0.13142112702611955, 0.19883289602735352, 0.22788020752130017, 0.13494692412355255, 0.17169069198350753, 0.1520567931114666, 0.2073970235764019, 0.15151242635423137, 0.1385470930366747, 0.09237997639443606, 0.16301505267620087, 0.2223870966343149, 0.13012263863798113, 0.18008382870785652, 0.20215466858879214, 0.23511454432962403, 0.17011029856099238, 0.22703639231622222, 0.18332251137302769, 0.15001417287895757, 0.23437390584618817, 0.15475642566959705, 0.2223376379979234, 0.2001044027987988, 0.11138561422065382, 0.1713620402639912, 0.14010058145128912, 0.09792431558091795, 0.13361431417926667, 0.07934204858517455, 0.09535337813318738, 0.1515215887658058, 0.13068839457006226, 0.2053036883233055, 0.1945424512509377, 0.15809548117460745, 0.1022192036672946], [0.03967595789881964, 0.048977487209823825, 0.04610010693150182, 0.008659164586495008, 0.02404237289973084, 0.030588299268856648, 0.07175299774615035, 0.0626662948108729, 0.010316328637512221, 0.029892250933053515, 0.04816171082277452, 0.010211132316579743, 0.0740006001245591, 0.02933612472618059, 0.0578950647444975, 0.06671967750955975, 0.039438742603505814, 0.03452854801810557, 0.04815369754308655, 0.03548734919017842, 0.06370352040375434, 0.0665134389794642, 0.0538221468037415, 0.060140234793746666, 0.029151484129890323, 0.06718530574993742, 0.036855279618213256, 0.016934143739842603, 0.024716302361940185, 0.04895363889274098, 0.14903295214378065, 0.05559606935768839, 0.04144839041175381, 0.060281459272148154, 0.05151637153880251, 0.038177290736066724, 0.034900142796217434, 0.09710114644539934, 0.09328950662165882, 0.017400294835228595, 0.010337989773571251, 0.04816409718665866, 0.0510114889531847, 0.06203722171184998, 0.020802799657347704, 0.032584917836732445, 0.0993966599625926, 0.03917499768337415, 0.0626292314770962, 0.017922567616727565, 0.027517657989876407, 0.06188232639443971, 0.10439209715132752, 0.0367256039152703, 0.06776690438029266, 0.062142455379568765, 0.013451341411940033, 0.03333937654632234, 0.004974227565746274, 0.008038453337165618, 0.10156127969704329, 0.5537210585128877, 6.40480246274702, 18.74643087387085, 36.84934985253119, 41.807115923973825, 42.640760790917184, 36.16091112936697, 22.368104304036788, 15.207459638195655, 30.11334784569279, 44.6103475939843, 68.57101655775502, 51.252340193717714, 16.347278837234743, 22.4574343235262, 29.405118803824152, 28.981912712897028, 20.228880874572262, 19.799497050623742, 14.686211943626406, 14.271343831093082, 10.936176007793797, 8.466693912782977, 7.768537517516845, 4.92972896945092, 4.216711694194425, 2.9564095408685747, 1.4836008486247834, 1.2890170899129685, 0.5417546425615588, 0.6526279125002123, 0.8391246632222207, 0.47011221428551986, 0.7539161354784043, 0.6337246010380407, 1.05967206099341, 1.1184625063211688, 0.7498732749973575, 1.4211247236497941, 1.4037238638247214, 2.920573296085481, 3.277502117618438, 4.512492235629789, 7.006302341338127, 10.005232826355966, 11.56193917797458, 14.6510253414031, 16.935747131224602, 13.715463569087367, 17.05775441661958, 15.453025506388759, 13.778942227363588, 12.725699543952944, 13.406572015054765, 18.011410082540205, 23.877779476104244, 29.790019027648437, 30.50015434142082, 29.405740499496464, 26.22335291677906, 14.628530548464868, 6.540251710722524, 1.598150237433372, 0.04201905313698996, 0.0341797711688184, 0.08003168093461184, 0.042771811131387956, 0.061791031696503206, 0.04087498126130912, 0.020121105894025777, 0.025244280583255237, 0.0475322240362725, 0.03143406608292172, 0.04278768830361866, 0.04303731422330584, 0.012662865525682368, 0.018191343819301938, 0.05087464266727048, 0.03338899989161761, 0.010513462212627694, 0.019713514559571783, 0.037090047262609005, 0.036397304596199144, 0.022165656668103995, 0.046317706545514446, 0.0053402878374101655, 0.019028561092132044, 0.04785894138378002, 0.06332945116164704, 0.07141960394238273, 0.019823411787529627, 0.022192404627980247, 0.12308948417945255, 0.06029139160208645, 0.04864302471340184, 0.010411124357262687, 0.03797741839662194, 0.08800577522525865, 0.08160513360053301, 0.011060634766885591, 0.0337986845613247, 0.022455515610354564, 0.03964573573020678, 0.052156334577669064, 0.02097475383761189, 0.031529091629049474, 0.037990920696287386, 0.01956054786851089, 0.047809160990460266, 0.10241889214563756, 0.06380629492923617, 0.02073161476742356, 0.10255272770600934, 0.052698050670686274, 0.03039814475473137, 0.08885252454708661, 0.04321711122869484, 0.058551559960770036, 0.018846023407193924, 0.030878931959910743, 0.00016232541266588435, 0.08203188287875346, 0.0623113586146745, 0.023380402070019516, 0.040079065703696785, 0.013663408913529448, 0.018820811453605854, 0.05018237880581329, 0.023369201864566536, 0.011180795657808983, 0.07964684432672878, 0.05125930690537057, 0.01957387588317356, 0.019852249252219355, 0.015753844523832442, 0.10114609834647949, 0.07176943033212616, 0.055430739922749425, 0.03500270281708048, 0.023810190802079537, 0.04253488311904573, 0.045680945754171386, 0.03125449698869019, 0.03410028571623468, 0.024165540685757034, 0.13874644443633097, 0.02464272536247248, 0.029859966072704525, 0.024993197181292122, 0.004886958181046911, 0.03557584383675168, 0.024631812439991102, 0.06659017800683938, 0.029481713990530664, 0.02473532624031988, 0.00976482577126233, 0.057964882167476806, 0.053668193774478096, 0.03316771156424957, 0.024235896285503142, 0.03214517570731621, 0.046770368747773676, 0.02342074809055175, 0.02002376101670727, 0.06547083927979393, 0.018228003041698568, 0.022259724604326393, 0.046677614652341416, 0.0408897974017647, 0.07681514587133162, 0.03481494615815821, 0.03180220197405546, 0.02861992253230945, 0.08154553962090323, 0.0812847326479612, 0.09111121987863895, 1.3276181153712736, 9.597441650206044, 24.64998237548336, 41.98860399184689, 47.96441339677381, 44.463454831031065, 36.94716984225858, 22.865909953271192, 21.123657841836255, 38.24032429725894, 52.56792276136337, 60.587753788117446, 35.944333537932366, 19.937009465309885, 32.8971069089828, 33.766947407876295, 37.41157454829062, 32.37012667040671, 25.403795242309574, 24.68929825290557, 14.73365399145311, 11.080034817418746, 8.184929961158383, 6.359590772659549, 5.489683593473127, 3.0284377403797644, 2.7909735277775796, 2.0751103278129333, 0.9217424654672224, 0.716495130571627, 0.7025961505789912, 0.6960692653252233, 0.6103679285414758, 0.9068856304211002, 0.5722972810749085, 1.0634322656739144, 1.2404288519774715, 0.9757772208221498, 1.1520895986787736, 1.5334314973123613, 2.1822172643676883, 3.1520453528050454, 4.627581930929615, 7.209138399170292, 10.263278695844836, 12.197018957907154, 18.36026176329582, 19.338257697320756, 21.047848232330818, 20.479690951685754, 17.496610764534243, 15.941608682755502, 12.335331536108448, 12.615791789947018, 17.863601446151733, 25.452430671261205, 31.993002545449045, 34.69182660502773, 33.93804511716289, 31.130953834902858, 20.647911602450957, 10.3278350253259, 2.643218823978978, 0.24280655738567156, 0.06127202244956167, 0.0424860718269502, 0.03677414707659233, 0.02751083597691069, 0.08124834347155788, 0.03819724732649423, 0.06372941417559501, 0.03229112311777088, 0.06292144422449412, 0.01700262433939403, 0.018144959110706564, 0.048260080342691754, 0.13174375729455104, 0.0505178295556576, 0.056403951208677985, 0.08223773836488686, 0.05759904070967629, 0.03252214842265652, 0.044005067132773905, 0.014035001776421504, 0.026470266410239765, 0.0151975181764893, 0.016275583916614135, 0.09892948422460787, 0.01876305608499435, 0.06994566609782558, 0.039699595541723316, 0.011117057142508848, 0.019592139419288408, 0.028660912066698078, 0.022548051370728402, 0.06921143210943669, 0.031432440061302434, 0.08054970192813105, 0.026540807786307512, 0.02559468345416169, 0.02502214955917049, 0.03225322474815673, 0.03625870779937795, 0.031721734013708855, 0.02946785737520024, 0.028336150158617287, 0.030726848185182582, 0.05263795107302647, 0.038300925835726723, 0.041268723641311934, 0.09939034739809652, 0.06995524219687908, 0.05968065098709157, 0.07448004093021154, 0.04000462494009445, 0.17367574836938612, 0.1694010850042105, 0.13658432980939267, 0.10421045004360138, 0.1002408582116327, 0.11770135798161069, 0.15095911169004056, 0.1786526845347497, 0.1886491666758253, 0.07148623827003664, 0.11200390080170286, 0.10990372438344265, 0.20419145123131816, 0.1587013341486454, 0.20815237094798397, 0.11072282559208332, 0.10760580535016714, 0.08617807329902727, 0.10691094828108627, 0.09088792057046968, 0.19252961651692468, 0.24470867709286753, 0.12692712502734316, 0.1909891669187815, 0.14781007663376872, 0.11671523428371838, 0.11494210846121274, 0.25109544486528446, 0.1330578738763448, 0.12040231587185014, 0.24439871791870366, 0.20714473550117787, 0.21553243300126446, 0.13685177110375898, 0.1776592983233352, 0.14245021908033279, 0.1326325112172673, 0.21595896011398685, 0.19274666454763184, 0.17174644786263668, 0.10092523519790943, 0.10769415060959517, 0.199816721461473, 0.13750127576772245, 0.07248019904739435, 0.10344610113890902, 0.12857032999877008, 0.08687791760049521, 0.07862243921526017, 0.09001422793634477, 0.10568744457897641, 0.1634468811173593, 0.1571111960877334, 0.16557180983645303, 0.16833940971522562, 0.14450570958996975, 0.1506196428090334, 0.11240733036350821, 0.17491802122564087, 0.10794618587580421, 0.2625899046899811, 1.3518543180919464, 10.502212816669095, 26.57759197296635, 49.20073663034747, 54.367129648885424, 56.01415641846196, 48.15998277356548, 33.60654207967943, 26.77282794829338, 40.770480555872766, 52.06784409861411, 78.61564959249189, 64.26285774477067, 24.875053859526112, 32.15355496252737, 40.36724521267799, 39.69643754343833, 29.690194706762995, 25.918551414243638, 21.928959661914458, 17.944829810050226, 14.599304968310943, 10.894138986064542, 9.763086284360579, 6.5068566510754255, 5.901982063247312, 3.4936497192229, 2.6293559420493344, 1.924768943459757, 1.0323295862443986, 1.3821721557647952, 1.545638648733016, 0.9650986293150533, 1.43458065967406, 0.9916356698639932, 2.0029557544377545, 1.8883362532623353, 1.6351918756000459, 1.875931757592386, 1.852808282259972, 3.5698726484852457, 4.954104048590507, 6.861811539819164, 9.711301192160576, 13.310067980520188, 16.230192165220938, 21.50561824921639, 22.773383202091342, 21.03648316475653, 25.88933760120023, 23.78383086573693, 22.172674171386227, 20.65779401410011, 22.08910023012469, 27.11202471486984, 36.65880503193025, 40.82569183841829, 42.88588147009573, 39.62947483985655, 34.98893045609997, 21.457475077721384, 9.213683816694445, 2.697165877588334, 0.3766929093868502, 0.13800465682100865, 0.20912502682016743, 0.13776390602992428, 0.09877674927514407, 0.1307852127619328, 0.1613503589384979, 0.19691822779995782, 0.09448341634725371, 0.19346441232389022, 0.13668796618378934, 0.12679888956969784, 0.13583676589112129, 0.17650935438371476, 0.17061593191277596, 0.23507585688944788, 0.21806849046580254, 0.07817763324466445, 0.115332851606992, 0.07125572241362065, 0.14477475966897704, 0.10078757685879547, 0.09985435919295396, 0.14829445870653277, 0.16624587527926893, 0.10327655822038652, 0.13054987055159387, 0.08635443440007587, 0.10867332589001426, 0.1916021445105153, 0.14893630249125345, 0.18127056018960092, 0.18735355877828214, 0.1624209208474044, 0.19467579651503794, 0.26444163113351793, 0.16493784143559395, 0.09971513037359524, 0.10433180603168665, 0.1482286211103201, 0.21128226912790732, 0.2907233192555366, 0.3044787037276453, 0.07429548268837315, 0.08844324973441901, 0.1577169264877035, 0.17446158604035455, 0.18219931922372312, 0.1376903156239179, 0.2111125653309207, 0.17498770458323343, 0.12910397152506536], [0.002636444429123414, 0.02890576717383679, 0.03728141219565465, 0.0738790066492173, 0.07112144252225276, 0.02427079159045412, 0.02419142105105904, 0.03380841004752344, 0.03963528629091959, 0.05594428313235122, 0.03791168422227906, 0.020393040294067997, 0.032403136663619554, 0.04611345601358241, 0.0537715505267824, 0.04626282017617937, 0.05895883911439489, 0.02216999272575542, 0.027602385399082018, 0.07253541866497648, 0.030201147160222454, 0.04390348387401431, 0.01838020172961537, 0.05630499563149868, 0.012153177653559515, 0.021526739339254076, 0.025397984633943247, 0.06216491707750867, 0.062408280228414846, 0.03845306706704921, 0.05948095484786938, 0.041599711928997314, 0.021683237695645903, 0.006052719442278988, 0.011662046346182545, 0.03073899833966167, 0.08998935306144339, 0.02289728595755033, 0.01549242755338069, 0.04026480755137821, 0.07147862335606929, 0.02503788117469559, 0.04101892152140218, 0.01930578532929142, 0.025089124795950712, 0.01208244667073051, 0.03553167503747729, 0.04075794217867717, 0.020521909689470645, 0.06015329659285565, 0.04162663608909615, 0.058344195281425794, 0.022527081629021034, 0.09316294889656768, 0.13372228661131474, 0.09718797485073728, 0.04555120876419448, 0.04322319779725325, 0.04260055600635467, 0.027575036060185205, 0.015073382246848798, 0.040095831537919666, 0.14655471899576727, 0.9114674490786369, 6.6747742987448175, 23.006626944388113, 35.29093726988762, 44.01610459050825, 43.80442996178904, 40.03909580169186, 31.238642507983794, 23.797286556613063, 49.15936346976988, 64.46383999240014, 47.96530377480292, 20.87795469068712, 27.33384063166957, 25.743164593173613, 30.231799502526563, 24.000208416292747, 20.836695278844527, 28.011739946180775, 22.40610618745127, 25.249944194670647, 21.223931274106427, 18.00586973467181, 16.03891484199032, 15.125112418205509, 11.670428995163212, 8.099002597793456, 7.725859678560688, 7.932951017733544, 8.610341895011164, 8.063165372417819, 6.8171818314060095, 6.752755430436904, 8.6088562973084, 8.298584068975142, 10.350326876486502, 9.789761343309957, 10.353277479448627, 10.852816816299192, 14.303135621932245, 16.463568287511027, 26.867631635358258, 24.37390438971981, 26.834330712595296, 20.977059256645944, 30.756928382381318, 26.23516513455299, 27.353383841053134, 29.04713192293721, 27.52088473689172, 38.350240876597745, 35.93949333313973, 35.882293408916844, 34.412859793632265, 26.85257169508165, 21.787279728920232, 14.176509745659368, 6.748406502508349, 2.051556004631904, 0.3764521126304904, 0.08599464120643754, 0.03972393798551733, 0.060956206533216664, 0.03737444974361889, 0.015046027162292553, 0.04529285710304976, 0.04520016429465144, 0.08415373958527081, 0.06100357758001455, 0.046705121039262706, 0.01239490807957707, 0.0799133739764652, 0.05207493007483502, 0.048435353598887884, 0.06506119674492268, 0.041967629485072634, 0.020852645168141015, 0.07929937748779213, 0.033745518059379635, 0.06478630141505311, 0.04785802973915012, 0.09098554315466074, 0.01735526801747901, 0.02806509101402856, 0.03937536797996971, 0.0517396210512567, 0.03945876431140689, 0.02712999260233295, 0.03097939098464145, 0.03295802180805514, 0.055591338764755964, 0.03306549628295245, 0.017333986094942497, 0.02307168204307316, 0.05404543079015228, 0.08613350230359262, 0.004891908545452621, 0.011202060343367199, 0.04272552792944255, 0.0919306888094833, 0.048182502449039495, 0.008453198017612582, 0.003955880055136438, 0.032716830516414296, 0.031493539403703426, 0.0886133978624017, 0.027004695091877255, 0.07378401174660652, 0.033808613060823375, 0.02291632132724889, 0.046670570473877654, 0.039282376397280924, 0.0841756267172675, 0.09354540297100622, 0.015545492548675788, 0.0667078031467334, 0.06964650876339405, 0.02199182365720551, 0.05514210863639751, 0.04929962718198377, 0.08271610664744532, 0.04351077188226966, 0.07702661678195, 0.025299808551226894, 0.03199208452696762, 0.04332234106597401, 0.0484154544650547, 0.03109500514373424, 0.07840297800759155, 0.019401274358613357, 0.024779468226516922, 0.025479689826287573, 0.029443991821139093, 0.058237525198848984, 0.055360164072725086, 0.039427634328603745, 0.08916825236332032, 0.02060528878392952, 0.033169297366252834, 0.005843090015508596, 0.01693011986302032, 0.025414495743931304, 0.054814046804582885, 0.0023745848034929127, 0.04984326615569092, 0.039968856294909795, 0.06428265989187264, 0.04037413978949189, 0.03198745735590497, 0.035440874466251944, 0.06730914386289735, 0.04639089092492096, 0.05022675444882724, 0.0064516252548914525, 0.03249172707118335, 0.024445478789388173, 0.05558963804956406, 0.05466655572696079, 0.01988339647200079, 0.022305258955325813, 0.02978172742821757, 0.0352051951772263, 0.038562763196926926, 0.03346147563969416, 0.007554563954697863, 0.012474918302388923, 0.03892280153870102, 0.08529428362606034, 0.023258584513959867, 0.06018656779140715, 0.03472237209338815, 0.03234897807781254, 0.06473634482151078, 0.028619215816199303, 0.030141091612618298, 0.14396970851286767, 1.9050128229202765, 10.435641369512005, 29.441255600221698, 44.02883660408759, 49.18593360531715, 45.84987932635892, 35.84430133142779, 28.905502980755223, 28.415092960480724, 57.52774807714648, 61.77640845698696, 31.272267026285974, 16.959965805853567, 26.016269422346546, 29.192765605065134, 33.19304581611387, 32.50810976951353, 25.998946274480513, 35.59061027342273, 32.10499994216427, 29.889580549732333, 27.440497721395186, 21.32230039565794, 18.308525700722974, 16.212263011163284, 14.662964055615088, 9.212965042360368, 7.380039989948274, 7.707557899336662, 9.651958673231064, 11.116669754828177, 10.546869981673456, 9.04248804815354, 8.856253912371974, 9.067088173281762, 10.021347884208927, 10.246790032232962, 13.583779796477288, 15.05776139997667, 18.464257524859523, 23.702533860360425, 28.049188775400964, 28.807039722319576, 32.324676206035, 26.461623176451653, 30.5410901577242, 23.880511406929266, 27.258891982416955, 28.893994746669648, 24.229859267511678, 34.71131294004379, 32.67609311688331, 35.62497023613223, 36.95726602308212, 33.81245866898568, 27.84246417783922, 19.05374465450164, 10.49741771913344, 3.7054724174161113, 0.6621966571096451, 0.03499528325553383, 0.03796265971276068, 0.021273574093356732, 0.05122873999719178, 0.03802638290630233, 0.009224941585994056, 0.02800412956745394, 0.02304234279079303, 0.05630230666288445, 0.04036625674475105, 0.05194160013249324, 0.06359074076998138, 0.06266015078572017, 0.05998670694328124, 0.022814536970409176, 0.012335996875809807, 0.05303409896911152, 0.00967234172182338, 0.023181556288393277, 0.11793329876156584, 0.05383866748982861, 0.12205024760576988, 0.012640959241487568, 0.04957129345125249, 0.05439893057149264, 0.035272967145447774, 0.0218239986908532, 0.0595262919312283, 0.05154719508643593, 0.06698749418700896, 0.05125300583219336, 0.025694855195920796, 0.0038462468881099937, 0.008764911533123063, 0.04068715565447365, 0.01500582574085603, 0.07081156761776056, 0.06724953456150909, 0.0537819501703545, 0.04218971837432154, 0.061913804947248394, 0.0676305330688915, 0.009163450581141779, 0.05565322334727934, 0.007527273987615182, 0.08083038888270817, 0.08382440604750188, 0.0334182606198855, 0.03830794320111314, 0.06353460950776935, 0.04391479133177669, 0.01834340269617256, 0.016558145871385932, 0.14373775241115402, 0.14807186419925383, 0.19537816124577678, 0.24329858501591992, 0.26009190647352126, 0.2262904831478673, 0.21958414945871602, 0.12330755110709898, 0.24759005635015427, 0.13768524412185917, 0.11113914841365431, 0.13388265945738362, 0.3077333823086754, 0.2360596210365334, 0.16644400093824635, 0.13946102060858281, 0.1409033956306596, 0.19634890189814955, 0.14071971838993413, 0.16332469009343656, 0.2345210100494085, 0.18716980492876423, 0.13100970716726396, 0.20160185954263135, 0.16102866329733403, 0.11270605868870213, 0.16153585946848317, 0.1193963581575982, 0.18722229727333595, 0.15534850438275646, 0.1150154460582041, 0.12182415207667698, 0.10482582549053816, 0.19153970834468642, 0.13083415045853586, 0.19828456093467053, 0.2598205274872242, 0.14252330386830916, 0.10311933399568643, 0.10545876733357869, 0.13277466649249678, 0.10213376954197885, 0.17549534508537862, 0.24245406500995162, 0.15948335670175093, 0.09260941972775806, 0.10310044226747367, 0.2181255027291275, 0.18300152053275417, 0.15565380574234072, 0.21056338754152099, 0.14288384016723404, 0.13982854362937713, 0.19432420812306866, 0.1905240136529169, 0.20602112966439418, 0.17625610103770611, 0.1370678845071985, 0.11437127336619363, 0.09829039069553537, 0.134991142718542, 0.18718606131451745, 0.25622664049508115, 2.150766229437244, 11.531996784671662, 32.66894459724426, 51.317106370002996, 57.03118778044178, 57.2352804676179, 51.33623184696321, 42.07632780075073, 32.33871436888172, 58.73981537357454, 74.33793621678507, 60.993130745426306, 31.121094957474742, 38.99642782826578, 37.31936747027982, 43.289846374142556, 35.09973349109773, 30.13686049369074, 39.313884858162176, 31.598610185807754, 34.3819672061551, 29.093000119732274, 24.709055231463527, 22.686453673147387, 20.449180795300393, 16.28567114953072, 11.826701125790997, 11.943299462718349, 11.045613077379043, 11.630621840876918, 12.383101101844543, 9.642648927627071, 9.461230481824568, 11.489528302223453, 11.64977869679851, 13.894855130103327, 12.97622819100657, 14.05203038646329, 15.555243453671856, 20.0758005726722, 24.87090595306889, 34.7236801731971, 34.925843054248446, 38.77380978676581, 29.294535421556045, 40.16244649887085, 37.83330778921805, 36.95172371402864, 38.124504550810784, 38.79955622457689, 48.51259208494618, 46.54901435298305, 46.59984042567592, 45.19188211810204, 38.6907143746653, 30.566967994936054, 19.499522024585357, 10.506995166501692, 3.521311499418751, 0.7669711317266188, 0.1758636495158557, 0.14046254267375316, 0.29148315590235496, 0.1025643339380622, 0.1517647757164894, 0.11919255578710188, 0.1687513964791452, 0.18266995767912558, 0.30368200292991054, 0.15363756957794392, 0.1183956481456276, 0.15757463331664764, 0.10610751357049712, 0.2429063786422053, 0.1041264255200663, 0.05773291840488392, 0.1433521343935882, 0.16738564557125493, 0.1368045800876233, 0.2590959308849227, 0.10722027926315224, 0.22673597859759487, 0.05902413278818131, 0.0902510486963776, 0.11377896482665693, 0.10339112666946265, 0.09005686072933097, 0.20740520539543322, 0.12423364415524468, 0.12246157553407455, 0.14246684318828967, 0.1328286144041246, 0.1890187121687397, 0.15361939797237997, 0.0898584746004593, 0.11239100502984178, 0.07797591463332215, 0.13385930909745156, 0.16522906209912994, 0.17863845062111655, 0.13822930444392467, 0.13247118842217231, 0.13373163288399098, 0.12256412406361873, 0.1422814499106138, 0.24468065359659735, 0.22878201558224617, 0.173834006812784, 0.10710862194818836, 0.2032709353032612, 0.18403475863798974, 0.176063506533542, 0.2069549602005751], [0.060794945025155624, 0.010641843226978616, 0.013967831187220591, 0.06687542318456596, 0.035182699005329804, 0.041730931299107696, 0.008629971848530395, 0.00779029208182868, 0.02395154551542815, 0.07716821281299477, 0.05180950359170956, 0.035548957981049054, 0.010717134348176902, 0.03992073448194612, 0.03321711657448642, 0.04098720931177659, 0.028868759381434614, 0.07877109091608755, 0.04870652574144545, 0.06892249438791506, 0.02120935868832373, 0.020809223304592797, 0.0609644802827989, 0.055310207479182756, 0.03360346620601993, 0.04816839493991387, 0.03757322274689232, 0.04054872356655617, 0.01612966714967643, 0.02890901538663574, 0.03353064954881707, 0.015000218934860202, 0.04982809378435055, 0.041879169312455965, 0.019444359143474893, 0.02598592455709173, 0.041309123287998864, 0.04315329227416266, 0.028662170366113706, 0.04674362078789742, 0.07751253103056262, 0.03189360775474099, 0.09529423614543292, 0.0696263989553817, 0.026228266895838806, 0.06399252324274952, 0.05874273720227423, 0.058867663160086646, 0.04292549986031748, 0.008871880389990346, 0.03921642005744, 0.03167630691501883, 0.0057154827499611965, 0.029518947778870503, 0.05379917948777157, 0.06812433036224497, 0.04606112071703519, 0.07083719325882774, 0.027818977607474215, 0.019316315207810655, 0.09232517046433303, 0.03400667743276685, 0.12050461159237932, 0.02607322410650311, 0.1496374721248304, 2.3134632024072834, 10.643925109217244, 24.906250430691628, 34.44756492491692, 39.159084596941554, 50.0888632189843, 44.64606077440324, 37.30095978706114, 56.34724017112487, 65.23632726361676, 40.4174280166626, 24.382421816548995, 25.767369539506976, 26.41836923937644, 29.52217213569149, 30.779864441963937, 18.03523063659668, 22.39110508272725, 26.289291881745864, 21.8930797807632, 29.100970375922422, 24.00671955077879, 27.41157416374453, 20.188121564926643, 20.707774816020844, 22.125650836575417, 22.133913309343402, 21.01774992481355, 17.543710585563414, 18.193661051411784, 19.913379146206765, 22.117325605884677, 20.373732043850808, 26.440632612474506, 38.70934955535397, 21.822722265797278, 22.152832861869566, 15.090017991681254, 16.94315452729502, 28.181325581765947, 32.599216622691, 18.798078683114824, 24.24824341650932, 32.564203585347826, 28.193985031497096, 19.497923658740138, 25.43642543977307, 29.000632224544404, 39.33978426840998, 38.97361140097342, 31.20675756085304, 21.668486825881466, 12.278503256459391, 6.986502707004548, 1.985553546297935, 0.441097553458906, 0.0349879211505815, 0.024777598971981677, 0.022238597814594547, 0.1013099875361208, 0.04985881774055381, 0.07714873885795956, 0.05064944346104899, 0.023839574104415315, 0.07392037539712845, 0.024819029006926764, 0.010555347112277824, 0.0016005339937457336, 0.03475759298570695, 0.022845649716234016, 0.028033700561331167, 0.034843429307182955, 0.02598698941930648, 0.04087475909581108, 0.049302235711365945, 0.07380949183096809, 0.014581533689652721, 0.01999205072230149, 0.06806020880298269, 0.07162785728371913, 0.0388648469872292, 0.07675529908268683, 0.02189666787613063, 0.0358104812462003, 0.02117399032407951, 0.01225375925235811, 0.037091548794940594, 0.04775622048445287, 0.045445837200649326, 0.12699429561654407, 0.03362497029405448, 0.053178403120968616, 0.04977456339064145, 0.07296515568610161, 0.037146906308349104, 0.03321312525640092, 0.0299286516007757, 0.05599427036941052, 0.056533144276228645, 0.04649598669681338, 0.02190903445044833, 0.06491188620848042, 0.013462451602061911, 0.07506878716090033, 0.0693164397812178, 0.06864588302109512, 0.017466664862548633, 0.05385279798159196, 0.06745413366344667, 0.04292379148424633, 0.03652288555918682, 0.03227716116535087, 0.023476597815451604, 0.00797993331704469, 0.09866330697531663, 0.009794976119132293, 0.09576266060673422, 0.04745905880906409, 0.010363516780818182, 0.02548454299328789, 0.04731023856889337, 0.005278211254100766, 0.019124661076573596, 0.0170953975870244, 0.04165673951408075, 0.03794445363324016, 0.06375387153257767, 0.0620525626225337, 0.07827694888316816, 0.02995404933068541, 0.008411495063844468, 0.03891251680831756, 0.04814492583635354, 0.04374250581848525, 0.11232470778087456, 0.02409841606183158, 0.02295341338932274, 0.040594493489592307, 0.0821080090357892, 0.04851028848920138, 0.023761616997240533, 0.04820008799734135, 0.0708216340130856, 0.07640494409227565, 0.062435430384451346, 0.016515396249991272, 0.043006406406000744, 0.049617676244628046, 0.021184491474301587, 0.015559167218124195, 0.05318805965925417, 0.05699389253652865, 0.05120993253865069, 0.030230421295029022, 0.09072892668266451, 0.036124983321755164, 0.026404430729246912, 0.06165772473679916, 0.009386632103292693, 0.0545496890141118, 0.0037603612497238625, 0.040790029771385655, 0.062139279945122625, 0.030505121272477894, 0.017613491358896418, 0.0717177500407542, 0.04155305334396901, 0.04134673054420179, 0.06489635760625524, 0.026368583560050018, 0.01931966109681995, 0.023267509438277736, 0.030402718299639322, 0.06024895416152093, 0.07617432098355024, 0.34480762517740654, 3.7971301184546564, 14.211416879007894, 30.67656097873565, 42.67739965069679, 47.58291190670383, 52.47089901278096, 39.06594007245956, 41.63696742826893, 61.99410000155049, 67.48326486156833, 32.86442964307724, 24.895840460254302, 26.907394662980114, 26.635796023953347, 25.61131411983121, 27.260764914174235, 27.108265123059674, 24.782572215603246, 33.35004652700117, 30.71353912353516, 37.4660837265753, 31.230203528558057, 38.636522908364576, 30.322578837794644, 27.373903720609604, 31.10636253510752, 32.06327376827117, 30.91093436364205, 27.00023324258866, 25.394785558023763, 26.328182182004376, 31.37499978465419, 32.68030966481855, 33.22814710678593, 38.775672912597656, 25.52808338595975, 26.299843057509392, 23.81082069489264, 23.99744118413618, 37.71599754210442, 37.595329746123284, 24.30490989838877, 25.33676781961995, 32.223479055589245, 32.759951429982344, 25.782751114137714, 29.248788818236324, 34.767210637369466, 45.24589707774501, 44.68351940954886, 38.08309608890165, 28.41456344050746, 16.646431146129487, 10.94027586521641, 4.04498910230975, 0.7477862063434817, 0.12883345055724346, 0.04251532489433885, 0.05898026659363701, 0.06575681224104858, 0.01417306231169571, 0.024492796210031358, 0.03284218931390393, 0.05933866550725314, 0.043053781283238245, 0.01882793415608185, 0.049199591420831225, 0.01647952609815665, 0.03102590018252452, 0.06114850226309031, 0.022257006907415007, 0.07749591458348498, 0.01224117051254237, 0.06726802026312198, 0.02420062368224946, 0.06807623536235864, 0.03341217405132709, 0.023398479829812725, 0.033036637750844804, 0.04379983600829879, 0.04029759228409779, 0.03690615551726472, 0.031234684039748488, 0.017300469748255227, 0.05083975885363837, 0.012535949654486633, 0.02497036010026932, 0.04508517066677732, 0.010944200893713823, 0.02593689301471797, 0.027392113416065133, 0.05302742251285142, 0.024968701519913254, 0.0903486789414479, 0.04218503374666457, 0.030691807323525992, 0.12251445092260839, 0.03506447248641522, 0.06956721866323103, 0.032443708680089445, 0.024121377632142078, 0.007192698493224359, 0.004122018431042952, 0.06104110439698543, 0.04739002662620718, 0.03152485133238858, 0.03966808251495804, 0.08423482233117666, 0.16310428659762108, 0.030428692510712053, 0.02474100486705861, 0.2066123503590784, 0.12684942839006264, 0.08197481698927381, 0.22037979305511524, 0.2769936446941668, 0.24794463248502827, 0.1347356523957945, 0.0576377013367751, 0.11243015978365176, 0.18931057634613208, 0.2566322074421952, 0.09770749737658808, 0.15044583278077264, 0.13292106589482677, 0.10942587704067269, 0.14045454471582366, 0.1423425837269714, 0.184545019160836, 0.21269697305415908, 0.14597019390954127, 0.14075580113116773, 0.19470526025660578, 0.27026760722360305, 0.2856205914530062, 0.15057153248738858, 0.2604036123281525, 0.09727188446108373, 0.132670080169074, 0.09699361834434733, 0.07259441509602532, 0.13405222535854386, 0.12102676179981041, 0.21017741712351, 0.13726441670329342, 0.1302091146428739, 0.1386981655753428, 0.11961220343026424, 0.14932702265439496, 0.1450301274176567, 0.10343836365087379, 0.1374745852644405, 0.15909352520060155, 0.22651217367139556, 0.271218444911703, 0.1225850765683478, 0.1990493618312382, 0.1389996977823396, 0.12093141449675446, 0.11001470754103315, 0.13346230701333092, 0.09122596452793769, 0.16300146227642415, 0.08349133400066246, 0.06772378895191417, 0.1511161290710011, 0.15305514357263042, 0.17076378688216212, 0.16993815860440656, 0.09472207571830481, 0.11473811456873534, 0.15452773310244083, 0.10396097351105944, 0.15949202881705377, 0.16931319939753703, 0.5338603210064673, 4.338111992805235, 15.673754926650757, 35.23077595618464, 50.480543259651434, 56.094568929364605, 64.22473230669576, 56.88513440470542, 50.44623428775419, 65.21783721062445, 74.69956305719192, 52.524019672024636, 37.28390924392208, 39.32254545150265, 39.62322650417205, 40.355227070470015, 45.41847352058657, 26.017828564490042, 32.6147452862032, 39.256245628479995, 32.82893023183269, 40.306895625206735, 36.3082863438514, 38.89682316010998, 29.302084022952666, 31.920989790270408, 33.131111591093, 32.12575908630125, 29.672041977605513, 26.486914619322746, 25.737920384253226, 30.15353252810817, 31.86558435040136, 29.539507050668043, 34.56497323128485, 50.427963887491536, 30.211038397204494, 32.40329031021365, 23.120593370929843, 27.227407117043775, 41.410634902215776, 44.111257368518466, 29.068516685116677, 35.3094155557694, 44.08278096106745, 39.91366624832153, 30.888990663713027, 35.89204049879505, 40.63355845789756, 52.26031480296966, 50.851862276754076, 40.725004596094934, 30.055994949033185, 17.41549026581549, 10.30748773005701, 3.7934254398269043, 0.6997129020671691, 0.32378531451667514, 0.15831530244360048, 0.14367018345623248, 0.1621669933440224, 0.1586384230083035, 0.1512191832185753, 0.09355458836521834, 0.15650446977346175, 0.16709833195613277, 0.14879500523449915, 0.1571842502321928, 0.151263692926976, 0.2170227038403673, 0.14607614386946927, 0.09315005563680204, 0.14975215548709517, 0.13995674078262624, 0.12967104512837627, 0.09256880174601272, 0.19613709390884448, 0.12287068180739881, 0.1367897945906847, 0.16145500654895462, 0.13670753206937544, 0.15769972015292416, 0.12702058009322614, 0.14781000002497627, 0.15290635397597668, 0.17229810777691104, 0.08787111995080787, 0.1191079413758651, 0.1171270525082946, 0.11728693505809193, 0.23340394660349817, 0.14338294644990277, 0.18135147439616342, 0.10444881064036202, 0.19142191466544906, 0.09578040320306055, 0.10226596567419269, 0.4556986377123864, 0.14172560715627286, 0.14826093469896626, 0.24224732852270528, 0.08703298911812805, 0.16884429230084344, 0.07234051823616028, 0.1345516687198993, 0.18998652636524171, 0.13960406454580446, 0.16021245790104713, 0.2059709509053538, 0.3290734355968814, 0.34005153683885453, 0.1560947046645226], [0.028382935148153095, 0.018664449077820586, 0.03531294161333673, 0.048158282579313365, 0.04778308718795738, 0.01900306951645161, 0.025426473528627428, 0.03625647848351829, 0.06338769299609047, 0.04928384194030397, 0.030616020160396735, 0.019706644666110797, 0.016928195067110564, 0.03285946842703608, 0.060387079814268704, 0.03666676836268556, 0.06135965141678049, 0.03868710309747727, 0.02915948208781981, 0.006408576380401369, 0.05884631612007657, 0.036757446359843016, 0.03833996567634806, 0.06848036972505432, 0.07371526301628159, 0.013203163398429753, 0.009359616012642942, 0.06474390610932343, 0.04921650281175972, 0.08453028712181315, 0.12333116193692531, 0.042733334365390965, 0.011072602017872758, 0.06177382919216349, 0.07470087343526464, 0.03942785649410179, 0.08395347654098466, 0.02224603078267988, 0.03918967975844299, 0.031996491447752046, 0.014636894075890944, 0.007042663524888697, 0.041206092123062386, 0.014556166603259984, 0.010515653224091136, 0.11926528051375382, 0.015651144691923215, 0.04769109151957016, 0.057801084908386396, 0.03825104585097682, 0.013149797713624374, 0.04980098193271026, 0.024404780368410775, 0.09962365947543614, 0.06860978495810302, 0.0886006348375832, 0.01040371532942499, 0.03697841676072248, 0.06552561456637998, 0.011695526303693412, 0.06922559707515663, 0.011108303630364039, 0.029627625011808933, 0.05576440568773016, 0.02908554311180788, 0.11083333377516079, 0.13316183200766965, 2.8983177677277596, 8.366669551018747, 26.717224428730628, 34.154940420581454, 48.7828080884872, 42.768229976777114, 40.62435657747331, 54.53758016709359, 49.63422521468132, 40.92021311483076, 36.51731729507446, 30.710091360153694, 37.51363069780412, 29.07409037313154, 24.520408838025986, 46.88429463294245, 28.133760959871356, 27.275834660376272, 25.346316829804454, 21.731060397240427, 14.854744422820309, 25.304478868361443, 19.305037183146325, 27.27322824539677, 20.691261637595392, 21.63046140824595, 24.674508956170854, 20.648958875286965, 23.67321414332236, 24.432704640973, 19.698741166822373, 35.54101582496397, 77.12263861010152, 42.92787828753072, 21.184536949280773, 15.916307433958977, 18.969598047194943, 17.499672174453735, 34.253121268364694, 31.758858619197724, 32.22218467343238, 30.448349637369958, 27.52257723962107, 35.62980651855469, 35.692168281924346, 30.175295799009263, 28.74885528318344, 19.98100276916258, 11.452969851032382, 5.205759396476131, 1.5168039572815744, 0.26169422533242936, 0.052228262572879755, 0.06850677677580426, 0.056862765096969185, 0.05927414558227024, 0.02711057993433168, 0.05764344316576758, 0.014416910013213996, 0.04922721655138078, 0.01657042817603196, 0.04509311882899173, 0.03093040732276296, 0.05316655940165924, 0.02178817258907422, 0.06722860503941774, 0.05874730308630294, 0.027077528986058412, 0.06793734362168659, 0.041930868756026037, 0.0329513568431139, 0.04937665349233055, 0.041001408751453125, 0.050762950878350005, 0.027772621627176003, 0.048807021155352556, 0.042067385624132814, 0.024372062668384566, 0.031123503614517472, 0.026721481962369818, 0.04571027926079208, 0.02565072661626243, 0.024446254453411507, 0.028795463919279077, 0.007082130459527816, 0.010577710176397477, 0.04427797446447996, 0.016479851685524467, 0.041597497934896144, 0.01414462704316623, 0.02325184868588563, 0.011757372581820575, 0.09166617397098772, 0.022424874008603157, 0.00545019751429678, 0.026096070763624968, 0.04342559439640853, 0.0590161846259669, 0.046259162106340936, 0.07506139441243104, 0.046526243339382836, 0.04847455431797332, 0.038203322403733773, 0.0465226580478972, 0.038028022334460294, 0.013129411156349366, 0.06918133251489171, 0.020537777285602306, 0.035992737393826246, 0.03279323246510279, 0.03797538060274336, 0.04573502390074634, 0.02993508673933966, 0.05980821611780313, 0.04118628491978011, 0.006007899947073912, 0.05482600926752052, 0.10820510061157328, 0.06723998144509331, 0.016757750080057213, 0.04414770121295606, 0.036144564529099775, 0.047502576433602846, 0.039186186397508274, 0.029962595041480758, 0.04087331885051343, 0.017056378813820983, 0.038587481023803834, 0.049981951052623416, 0.016115165105269804, 0.017715028652380553, 0.03620705049064371, 0.00859379526152606, 0.0214969806538354, 0.037545858086237026, 0.02661462801869118, 0.021430076280188178, 0.05442196300493614, 0.01295897095734554, 0.09651235424943509, 0.03895035006045815, 0.0838309790818922, 0.035461390300864176, 0.05028728688616426, 0.027704501088948983, 0.06668845942664532, 0.03731230852164088, 0.04933890450986163, 0.08461539182932147, 0.038656823472270084, 0.02861049198996156, 0.055232744498719136, 0.05454107818584289, 0.014176714635874717, 0.06391897497157897, 0.04046076518152991, 0.0237177986831915, 0.006189635154911347, 0.0319560362596906, 0.06004666098423543, 0.01551061831114273, 0.06508538980157146, 0.03898390088110201, 0.06340912047533259, 0.06959156493746466, 0.029163724299700513, 0.0978503727744664, 0.060699701143969456, 0.008196698374024803, 0.030567201207421964, 0.032808810863043034, 0.04350605661109571, 0.03322976085567667, 0.03354161226701352, 0.0835252563739496, 0.343749872258594, 3.63820156262767, 12.046305806406084, 30.339143007032334, 42.260847860767, 55.30931826560728, 46.54945758081252, 48.65708043498378, 61.39826451578448, 52.99056599217077, 44.70102102525773, 38.27600609871649, 27.877989084489887, 33.842680531163374, 31.451850783440378, 16.6545759477923, 37.124005979107274, 28.160478184300086, 23.094911652226603, 27.389199003096554, 26.241839047401186, 22.26871536624047, 22.71628525949294, 28.761546111875965, 31.710466377196777, 24.89085512776529, 24.597250030886745, 23.433406314542218, 26.312302466361757, 29.359844846110192, 29.587456064839518, 24.86294354161909, 42.26118518460182, 82.60477850514074, 40.07262422192482, 24.494268202012588, 14.456695433585876, 17.312282900656424, 23.026544740123136, 37.12435507005261, 30.434825305015814, 34.84304574228103, 35.385956687311975, 31.847243347475608, 35.41625307452294, 37.17049391038957, 35.004929804032855, 34.57311999413275, 25.10222185042597, 16.434816333555407, 8.167188100276455, 2.8096959812025872, 0.8117446808084365, 0.13625865051102254, 0.07089556149777866, 0.047121091460388516, 0.029249962817336765, 0.05511909535515213, 0.03463305007185667, 0.04815168273184569, 0.006270821801491923, 0.05564935460326172, 0.037270744421309045, 0.042948467176287405, 0.05439799977466465, 0.006211841171006522, 0.03680603548644051, 0.030946960567586848, 0.011985215748990736, 0.04067593629682257, 0.0020072017134460172, 0.07374940755506677, 0.010480983915077824, 0.03933426736283206, 0.019479984147173744, 0.04459183685661805, 0.04803193935884103, 0.012731290583859288, 0.028150584511158448, 0.03976051102302248, 0.05649094815335928, 0.04525514642497705, 0.020360228748271064, 0.030329434328802654, 0.042261565930300185, 0.036684951459568356, 0.016260319614722844, 0.095608240263837, 0.02428456202089306, 0.029942701653307004, 0.050491575722492514, 0.06199099213605928, 0.06343111485963868, 0.020145561335788622, 0.041944972434712034, 0.08200513874931682, 0.0280520694345356, 0.010961174529286162, 0.06155102018026575, 0.05420539377918167, 0.03106635920102558, 0.05481383229996409, 0.07643837616929124, 0.02611946134317306, 0.034035183564429326, 0.04847298766816816, 0.057862448551121264, 0.033757181748026804, 0.06340197670543868, 0.015818127919168725, 0.19447892724025637, 0.11879553838122277, 0.11133126028242613, 0.11346660779729006, 0.2274094771353468, 0.10452841483657399, 0.11900824269339924, 0.1178388477813813, 0.2745417036837147, 0.15992004214034927, 0.18009581032299227, 0.09998545215855684, 0.07908703323694007, 0.1282566476372942, 0.1925992385874833, 0.12873243420354782, 0.1638058852404356, 0.20410721220316427, 0.16732025230603834, 0.14546033175241563, 0.11988264778929374, 0.07567703032926207, 0.1925223540034025, 0.12025316621387198, 0.17453951250401237, 0.13018032505867944, 0.11547029544148715, 0.1755507332423041, 0.22488985991766378, 0.16171422005901415, 0.23747922792550058, 0.1629630812714177, 0.1458524002303039, 0.2028941426185831, 0.1495528194091974, 0.19702446887329703, 0.20995093088957573, 0.09579756357256444, 0.19779976517442735, 0.21512818372538015, 0.07387516088783741, 0.10845659961623531, 0.14118732313715643, 0.14266404954175796, 0.07315156786071678, 0.1955314707611838, 0.11396382184278582, 0.17079041609841009, 0.08963011145111054, 0.09872141474437329, 0.1317159942681751, 0.13993360492731297, 0.12725478083255792, 0.15671865263533208, 0.13500952882872475, 0.15586757491673195, 0.06715956519568159, 0.1619051598132618, 0.14483465242289728, 0.09108115092761095, 0.11249510105699302, 0.11476674327446569, 0.16806487444668047, 0.18502515710649953, 0.08627036391126533, 0.2943273645735556, 0.5209497782972552, 4.3401790818860455, 14.857164525216627, 35.13829431226177, 47.97813777000674, 63.88950693991877, 58.74740515985797, 56.338473673789736, 65.3900174940786, 63.11268152729158, 54.33076143264771, 48.79537928488947, 41.31292866122338, 49.232660801179954, 40.641387508761504, 32.96094740590742, 60.94629372319868, 39.87932589746291, 38.64824687280963, 37.62259414119106, 35.099066688168435, 24.60586747815532, 36.811389154003514, 31.32821571442389, 43.17157122396654, 32.53808648355546, 32.08553910255432, 38.163363472107925, 31.616798216296782, 35.41070684309929, 35.28843872008785, 29.481124531838205, 45.977226918743504, 89.02287437069802, 53.61563098046088, 31.198183259656354, 25.529536624108594, 29.045976784921464, 31.027881791514737, 45.42393738223661, 42.616708817020545, 43.784367038357644, 41.50234776158487, 39.04834824223673, 50.29269310735887, 47.650396285518525, 44.3916166213251, 38.72023021021197, 27.247009161979925, 15.004724091099156, 7.3434222129083455, 2.466006384741876, 0.7944860681891442, 0.2720966881080982, 0.17737667316630965, 0.21796511456130013, 0.13830278759762166, 0.13807993262044846, 0.1266795407319742, 0.13177947231358098, 0.11279272621557598, 0.13609055549867694, 0.1276338258157334, 0.11275455205430908, 0.14545061775753576, 0.11814015782288007, 0.1332968933087203, 0.15368512831628323, 0.1265922756565194, 0.23144640809585973, 0.14972036283823753, 0.1478878039145662, 0.15967230462739546, 0.09533011970380623, 0.12970469171001067, 0.15838440357437059, 0.16977812283702437, 0.14072567855398502, 0.11810332431548065, 0.07803582270900089, 0.15535028170674078, 0.17795937496327585, 0.12595250797007354, 0.16651274966857127, 0.14683956580777324, 0.15733763635639222, 0.12437652721400223, 0.17562470669227262, 0.09085150841142862, 0.12462478566674456, 0.09318056891882613, 0.16443574741002054, 0.2653078007842264, 0.14384155732489404, 0.10979556042941348, 0.17210258681687618, 0.156482896737514, 0.17302541633046445, 0.21290358696733752, 0.17028600848730535, 0.20291084333533244, 0.1389111073747758, 0.20751916863504918, 0.11883045666881147, 0.25252023050861977, 0.16002985318341564, 0.1875918887315258, 0.1524562619987034, 0.2402617511970382, 0.1396018888560995], [0.03750603683593293, 0.08491155375996906, 0.07892986263839469, 0.09465422331085128, 0.05382501197257831, 0.07195909071954028, 0.058890228279896324, 0.03502449035764702, 0.013846260694516523, 0.04733236701858621, 0.031667412634217934, 0.040080590218666105, 0.0806744899901171, 0.027120351385805878, 0.016514714431738662, 0.06282027848365326, 0.042601708968680714, 0.03839542661162634, 0.028689349250447367, 0.013266138698635323, 0.04723140812148491, 0.03865375145969372, 0.06848600047129778, 0.013571960040398184, 0.07075791081954395, 0.02889301180989752, 0.07483450981277613, 0.010413351757902532, 0.027542745454176783, 0.06497869673635691, 0.023872688254942338, 0.07237079403092785, 0.06453442702730817, 0.05787935228117051, 0.107575353355177, 0.02990343964718763, 0.06189996939933589, 0.0388490425933513, 0.04877660746475862, 0.06080273613934556, 0.019199419766664505, 0.023968290282233108, 0.06276255375855873, 0.037032016102344766, 0.03986259606937247, 0.014781719167536546, 0.06712264741861051, 0.026112974493674217, 0.045293309094925086, 0.045315146431206696, 0.04247465711687842, 0.014122798325373762, 0.04199330109141527, 0.036086341846854456, 0.05694940964120531, 0.03444387615027447, 0.03574244114720533, 0.011672223824256612, 0.011307358170949645, 0.051448913666629986, 0.061016700666157477, 0.022126431051161022, 0.017934430488235047, 0.040402282029390335, 0.020848776424123396, 0.0436769555052442, 0.045965129900122845, 0.020587657270352208, 0.05924732484404118, 1.903453435628645, 7.7170794529299584, 19.975813473424605, 30.38209688278937, 36.92401216876122, 42.12760102364325, 51.94317156268705, 45.72394378723637, 50.33706688111829, 56.56663794671336, 48.895509550648356, 40.50875256138463, 55.96888834430326, 47.53200738660751, 40.67715560236285, 33.965905712496856, 37.223520432749105, 36.58287971250473, 32.03698015982105, 37.144433682964696, 24.810734833440474, 35.02136845742503, 32.059729906820486, 31.542259454727176, 31.408175191571637, 27.561489112915535, 26.498309104673325, 28.546525701399776, 32.004734354634444, 29.294362837268462, 75.22834562486219, 50.66025449383644, 24.69149870257224, 32.2222395866148, 34.04156431075066, 38.488069042082756, 44.35063569776474, 40.12056343017086, 32.99376587713919, 38.255178313101496, 38.60849365111321, 34.199180833755, 27.38784186301693, 16.48759476600155, 8.516035368365626, 3.0772420763969426, 1.1933184895784625, 0.17976363459902425, 0.08232622152014125, 0.061501006130129106, 0.04312058031979588, 0.056781414220289844, 0.03096804905292248, 0.05205590811167514, 0.04532030603337673, 0.051337704513101816, 0.04759633027377629, 0.02428406980940171, 0.025709882010555556, 0.022426312338680993, 0.048731783660308975, 0.06647550230545383, 0.0075774436493614514, 0.025457565207034353, 0.003965790360046912, 0.04949142112426701, 0.03638480587171451, 0.03873370039547163, 0.1872106220933699, 0.06468929170120148, 0.04812176316796292, 0.026134107029065493, 0.06149889555789771, 0.05825206171721221, 0.07055272182990467, 0.03867156683437286, 0.015660913270567695, 0.057148186474918365, 0.05873544021479546, 0.05089334287350217, 0.022791224914873322, 0.045282005467602325, 0.07206327101636319, 0.10020254615453944, 0.04178935699465294, 0.027030293919867086, 0.038372348212907394, 0.04821796082861481, 0.039526390722922744, 0.054358232150515245, 0.021111979337048628, 0.023034875348751104, 0.02725728960227101, 0.01184724810187735, 0.03592507267791418, 0.011714864278122062, 0.04478187645755468, 0.03871185539831077, 0.05091266744139214, 0.008083001349962527, 0.04928625128682583, 0.04640295680972838, 0.1140904408549109, 0.03235347501392807, 0.04156578572527055, 0.05295249528341717, 0.04661098415512712, 0.053454405447888764, 0.039786289881674514, 0.07619276838076693, 0.0024725095136091113, 0.04112867510787422, 0.07382262257799026, 0.018308342682317864, 0.036408374566705, 0.05388903010997081, 0.01738897780136716, 0.022886807789965984, 0.05155578293206711, 0.06557981528702282, 0.04398597239126121, 0.026963314852647247, 0.016948632377710555, 0.036977045463338014, 0.02945253561671463, 0.09440182798331785, 0.02949643053955609, 0.02846682560630143, 0.016901485411630526, 0.03021657042535803, 0.014430721620878866, 0.05518825777295617, 0.02331502221134161, 0.033400027727287625, 0.03826380121491609, 0.02945671462634158, 0.08162035576758847, 0.03925221934614163, 0.040890655420239896, 0.07737740078159878, 0.037678705393186504, 0.04145208678598847, 0.0636651432291875, 0.0380389046134247, 0.06076707091603068, 0.06741837267914126, 0.03734416628797208, 0.056988437990507776, 0.03864601397165849, 0.0538500668781419, 0.06986868958319388, 0.01473731671144525, 0.015621545927358732, 0.015592250725134246, 0.004762466020521618, 0.01885986661598567, 0.06722985376273433, 0.04625631225926261, 0.040144535577705795, 0.023192091912571943, 0.06897543106348285, 0.012642433003131903, 0.05387912842354948, 0.0378716369760373, 0.006141269151421805, 0.04383837023089009, 0.03715805671808701, 0.04354866259100457, 0.009675436717037474, 0.038244717964722265, 0.029368196997130593, 0.04434769995690835, 0.009953435660610277, 0.028303009195012913, 0.00540942392094181, 0.05305682113694568, 2.643399007858769, 9.354058581013835, 24.82579477371708, 38.01592157733056, 44.09922745919997, 51.4578684683769, 60.07634339794036, 52.92449758898828, 55.87969364658479, 57.98877954483033, 53.003278393899244, 42.07703774975192, 49.75167666712115, 54.15508631737002, 40.88140126197569, 33.405089147629276, 34.01930093765259, 36.606735567892756, 24.073154695572395, 31.316060289259884, 23.44628541700302, 38.17118467823152, 30.61559165677717, 30.611784996524936, 31.81307165853439, 23.43413979776444, 28.01991024324971, 28.85042113642539, 27.48262397704586, 33.50625099674348, 80.62224003576463, 50.60730641888034, 24.74282487746208, 27.10424077126288, 32.003512536325765, 38.20041810312579, 48.49107396218085, 46.755884078241166, 39.60705457195159, 43.21278356736706, 43.28650451475575, 40.9638887066995, 33.48874153629426, 21.557901482428274, 12.762249169811128, 5.634742648370805, 2.090126141425102, 0.4292626594824176, 0.1877388397171613, 0.03160266862851718, 0.05883300917283182, 0.04487330139043831, 0.018514533331918142, 0.020229876972734928, 0.02436781279562462, 0.02809773785092177, 0.04298759128658041, 0.0453365164538545, 0.06229430932791964, 0.028399858030400453, 0.008387422666043766, 0.0296056057296453, 0.07155890170965465, 0.015445816848847656, 0.033503166144533504, 0.016541322580568733, 0.04358525861114745, 0.04508224421090657, 0.06480547659579786, 0.048209307865510066, 0.005379423917826987, 0.03743714637934201, 0.08495557317209822, 0.012562333722598852, 0.01684490407276298, 0.00986384072025577, 0.023450003073160208, 0.05223777738489932, 0.025382390914244518, 0.025396749317165346, 0.02328895990015759, 0.09316370732361272, 0.06519110227424292, 0.08283165568906455, 0.05312163600577943, 0.0551201104216518, 0.03290059585725108, 0.0496101149568154, 0.03747308739430962, 0.0949037304869102, 0.02510988194825909, 0.008477622815858453, 0.02631476013770988, 0.032062271587370385, 0.03511065226649085, 0.05515341609415989, 0.11091191907443347, 0.019569242966451475, 0.055341073161652016, 0.018413049664588708, 0.017183769659529773, 0.09720151162435932, 0.029180718045080864, 0.024386829013125073, 0.059314334554778, 0.06908843669319345, 0.07321549789799799, 0.227117000087615, 0.1670041950719972, 0.1853064799140538, 0.2458956384009892, 0.14750606230189725, 0.1448856585568959, 0.15554918877540097, 0.10226606526562285, 0.10350023291163868, 0.12559806973102594, 0.10303692591767158, 0.11479226932410272, 0.21498572201498095, 0.14520143999928428, 0.23957858462968182, 0.13075633124718744, 0.14357883513214129, 0.15413580252037895, 0.1413221699335883, 0.12903608081321563, 0.11738075018529931, 0.12568371070008125, 0.12264477780028699, 0.1461176351914483, 0.19452801815444426, 0.2004040044642264, 0.20726072121291392, 0.12445586327944072, 0.2348983543173921, 0.20121143049290105, 0.09457157774557991, 0.19835234439421087, 0.17369274019954667, 0.25531939320987274, 0.23254442659597244, 0.12606065660234422, 0.14265960623179713, 0.17211539580697016, 0.13662180683064845, 0.15431733471491646, 0.12926803691492927, 0.17666824101921053, 0.22808614727710524, 0.17448988532827747, 0.12397673656983722, 0.070450947049164, 0.1690979593343312, 0.09712635073810817, 0.0744435751450158, 0.11161703406082046, 0.17752806746190597, 0.11814559704714245, 0.16965528829924523, 0.14884025038730714, 0.17789050365888304, 0.24461581191468626, 0.2074368601484645, 0.10153268929570915, 0.1309482209504612, 0.23034549378339322, 0.15666320319137267, 0.12341481873825674, 0.1475103677160317, 0.10162263567889891, 0.11268104591797437, 0.12623127204396073, 0.09312077575633604, 0.1555636371936529, 0.23276990159384667, 2.897311189482289, 11.157533987875908, 28.409823256154215, 42.419511656607355, 53.22981096083119, 61.04876564395044, 68.54117516548403, 64.2062657879245, 66.099287925228, 70.28830866659843, 63.34080265414331, 53.219585341791955, 68.10523509979248, 61.38405769102035, 53.047918888830374, 46.85892866503808, 49.1419481462048, 49.62008899258029, 43.06102706540016, 52.27974622480331, 36.06063181354154, 50.20474964572538, 44.142993265582675, 46.199146778352805, 43.85597775059362, 37.80420772490963, 41.058904201753684, 40.9872228868546, 42.9905616852545, 40.818761010323804, 81.98505186265515, 59.9303763143478, 35.08356155887727, 42.39291798683905, 45.24447717974263, 51.645447977127574, 59.18101141529699, 53.27100761475102, 47.69589577951739, 53.70897946819183, 52.03956380967171, 44.15340715839017, 35.91672005191926, 22.053716528800226, 11.676698903883658, 4.679916154953742, 1.6074550800746488, 0.3555446845148841, 0.28760475917689265, 0.12514807734518282, 0.15823273348712152, 0.2275251104466377, 0.09860750513091203, 0.15976486337040702, 0.08834909752852495, 0.1803061933887582, 0.18650211333747835, 0.12125644262038893, 0.16041743238606762, 0.0928825377336433, 0.09705024756371014, 0.16556413363545172, 0.14588980064276727, 0.10898605830246404, 0.11507926118229667, 0.1406429870234382, 0.1628624479616842, 0.11118839254542706, 0.317166100346273, 0.2801747175474321, 0.16647393965432722, 0.12844158892309473, 0.2057132848929013, 0.1504531259378118, 0.28530336976532017, 0.12219948153341971, 0.11241454691175493, 0.20276983719198935, 0.11863495869141434, 0.21358085465767693, 0.15245644585980525, 0.15706336155774134, 0.15222067464022868, 0.21301278514006447, 0.11505001194534764, 0.09131336749921884, 0.10340703831564996, 0.14490867183814127, 0.1264153936156823, 0.13502838991342053, 0.09677511474658405, 0.1627479944257967, 0.07358031662841959, 0.12685354228221601, 0.28718855892938955, 0.1384004944514844, 0.34962978093854846, 0.1651600988641862, 0.12543627962229714, 0.07759211990501612, 0.18605667917478472, 0.1647464573503502, 0.18253820587790784, 0.1546222223870216, 0.23552360463767286, 0.2200880820953077, 0.22710567730809414], [0.06568529027243776, 0.003648150436234691, 0.07603190523842651, 0.03397471624456587, 0.07465187445162766, 0.02110428015340961, 0.13215246520215465, 0.06099465265569668, 0.021827712302066146, 0.07126516827772703, 0.016799473143633337, 0.07438935144173522, 0.06758991508714615, 0.03549510583041176, 0.04373222491854141, 0.011024244632872363, 0.061670008956664996, 0.06113182835941834, 0.04796427464292896, 0.03995916911310727, 0.0758103526107246, 0.047128127977973035, 0.03242069539884406, 0.06423084553511393, 0.00406511725046702, 0.07740949986562615, 0.08293945192089004, 0.08714096155017616, 0.032657791950529626, 0.01456447578440871, 0.04002579194944232, 0.04721378809922645, 0.018404243483899102, 0.0381755861904352, 0.02365352582156418, 0.021010736987415343, 0.018608700859570698, 0.025906780013634313, 0.0439052535371194, 0.02995415849821462, 0.009135764163558283, 0.011409559088098186, 0.014246107837665948, 0.01000973929260527, 0.05761437395948076, 0.02706736682974283, 0.03758343469892298, 0.056038393203409455, 0.1173279514055579, 0.04550308312079118, 0.040090078217608315, 0.029267986950975274, 0.028783737028378154, 0.04428904443498581, 0.01708043972030282, 0.06969536219032542, 0.07646823061570045, 0.024018432652097077, 0.05100212352831037, 0.010607510996651987, 0.037557065952569246, 0.028265223823367592, 0.044345275288628, 0.03233762848521433, 0.027727370728708567, 0.004804968578560699, 0.05043820237680789, 0.034804987015142556, 0.04959519922492966, 0.017536616350914684, 0.11761567104727992, 0.5948305622704568, 4.1907152052848575, 10.368218768027521, 18.505665986768662, 27.467183566862538, 32.70974901414687, 39.29874843166721, 47.80217632170647, 52.8576760907327, 57.25590036761377, 56.550203215691354, 47.32101132792812, 51.51352690112207, 47.78901676977835, 51.24562509598271, 53.03497506726173, 48.153412803526855, 51.38327283243979, 52.010299005816066, 40.779090158401, 41.21156284886022, 38.62656401049706, 37.020831954094675, 40.40607667738392, 43.90154392488542, 42.4747896194458, 40.03741702725811, 33.728276760347434, 59.88546909824495, 52.338550398426676, 39.68140702093802, 45.52993943614345, 42.7881242382911, 44.84397572855796, 36.94314941283196, 34.211489231355735, 28.083974315274148, 23.68765631029683, 14.761457712419572, 8.356394902352365, 3.623282337380994, 1.2407175139073403, 0.22539296517929724, 0.10855622935078799, 0.05033488392889981, 0.03347919142294315, 0.012392266033848208, 0.06446966961506875, 0.05070686175097382, 0.060912018581744165, 0.05217503478390075, 0.011137664907671993, 0.06173521069990051, 0.046241028805173216, 0.08489292250165055, 0.0760903041208944, 0.01853479635751536, 0.017510444872201453, 0.016413613808371367, 0.09126764737189778, 0.03289673860455233, 0.0043001793599086666, 0.041106833941152984, 0.02392887697374869, 0.056021317103577245, 0.04883385338490048, 0.07668294973911778, 0.03776216301165762, 0.09266702187878471, 0.017958974030109185, 0.03863934900671725, 0.0412101753716988, 0.02760959811688912, 0.08312010311431463, 0.04124474125884233, 0.07378758937721291, 0.03272466376544007, 0.03547174780960045, 0.03994610348355867, 0.024735475627465114, 0.014202934952693121, 0.02148468302743089, 0.03895961589390232, 0.042221055200864235, 0.008124380631582632, 0.014179690887460546, 0.05089472183176587, 0.020510782262370474, 0.08969902105989958, 0.03251165301809388, 0.016027968020118293, 0.053565243048773664, 0.019629287022736766, 0.05590074252517474, 0.055552475124357216, 0.04783605450704213, 0.033874933292428334, 0.02487197334337379, 0.04451554216023895, 0.06634600280273346, 0.0652422846084641, 0.018469424159716696, 0.04472366143618861, 0.04857182067127959, 0.06193275413205547, 0.04519519621446248, 0.07092596752749336, 0.05026028228683337, 0.10681583846528685, 0.10144242881647042, 0.05315704458963968, 0.10215044727609043, 0.08354980183104355, 0.03523815994060809, 0.06334438221529126, 0.09932152971985841, 0.09526140161699827, 0.029864394060906865, 0.01783968456419966, 0.019068658134088885, 0.04920812180986808, 0.039974651750056975, 0.020718790455571106, 0.06470023909763944, 0.028522566163672075, 0.04023693727269288, 0.03182727603181716, 0.05384392668342879, 0.06050924019467446, 0.04369468661025167, 0.07828577421605587, 0.006762934180216925, 0.06520256294959015, 0.05952326205348777, 0.03355919015443614, 0.008738662488007498, 0.06981946843405885, 0.007653994985195178, 0.06918231310743479, 0.0841611093511024, 0.05565262196825878, 0.043635713161840554, 0.01234568884566186, 0.01243172434999818, 0.030570395794066212, 0.08722022100682221, 0.07491927744159776, 0.012093999276628659, 0.041825497192480875, 0.10393948474478337, 0.03967119666237024, 0.04768574422585869, 0.046638065363250436, 0.1268174748627409, 0.04843876269015093, 0.04124544605973267, 0.03120164458279408, 0.03585561531625929, 0.060778037464666756, 0.04309776622141081, 0.03209401635573276, 0.0698904388193642, 0.07746951519361428, 0.020642989885903174, 0.03646638274433152, 0.012209918913281253, 0.02223188496915804, 0.01601166279625989, 0.043414221821172584, 0.06365472443341728, 0.017674717105804913, 0.0905682780449429, 0.04205159272157377, 0.03176163378802519, 0.017133795829009146, 0.09051554821311467, 0.6760553715209807, 5.621905711389357, 13.455088792308686, 24.016854955304055, 36.03135916494554, 41.9943541865195, 48.08738754641626, 56.13663242709253, 59.40372359368109, 62.563200612222, 62.6757961703885, 51.93017675030617, 57.73760272610573, 49.77268488176408, 54.75938627796789, 55.2636657991717, 49.22183505950436, 52.982062293637185, 47.833135589476555, 43.94084607401202, 45.58988501948696, 41.461370760394686, 42.61699907241329, 42.36792856647123, 46.780810740686235, 43.910659513165875, 39.854830695736794, 34.36466563132502, 65.86335735936319, 57.1687609918656, 43.230783324087824, 50.002563230453006, 48.0916746970146, 51.66348303517988, 43.27275660730178, 39.74895415767547, 33.86652854181106, 30.086091295365367, 20.576275394808864, 11.635405171302057, 5.786083869395718, 2.3478614082259517, 0.57603070332158, 0.15343477078262838, 0.04279392808976193, 0.06983449907913324, 0.022247066916597467, 0.030593663799546422, 0.04062692965230635, 0.0707104746552725, 0.014640813573233545, 0.055816744814717004, 0.02108038204061168, 0.012996636627752696, 0.012608126628272718, 0.050571926854430675, 0.03330702082284036, 0.06421576892476409, 0.04656104288334328, 0.04127110234431682, 0.057772153597925945, 0.024917595794484503, 0.08206940586528472, 0.031692925277316285, 0.019412238992029623, 0.07888700767991044, 0.07030698380643322, 0.052711801948927106, 0.011683140577177608, 0.04714204779555721, 0.014236992348976915, 0.05214490837627842, 0.06244275418500747, 0.04445620482006381, 0.031064750416384592, 0.06547927390784025, 0.05618879924558344, 0.007399146261084224, 0.03405993969570245, 0.059636221717922926, 0.02143895523923059, 0.036881544942697214, 0.09028689395035468, 0.04747451463293645, 0.03419869737098775, 0.029080092396226623, 0.05440173828373513, 0.07116354671457122, 0.021702175389134118, 0.039806522263754765, 0.05469591987709846, 0.07028923354922764, 0.04666738737855227, 0.025284042461745204, 0.07346561028351707, 0.056682569725859555, 0.01920041376574626, 0.003507622379636873, 0.029401558211013198, 0.027411830604016304, 0.05442316959341688, 0.03721853169882971, 0.003080181228259819, 0.08221530731046393, 0.06334597184773415, 0.1476619765162468, 0.19443697626552275, 0.15514366779356234, 0.24535015315538455, 0.2695301097006567, 0.18246144386789492, 0.2662160133402194, 0.1758672807726168, 0.2204768257516046, 0.13437413550432653, 0.19266878404924948, 0.14840636883051167, 0.13503298644096623, 0.10958376010098766, 0.1414716490093739, 0.10420134891906094, 0.0969176377440172, 0.13093083075458004, 0.2737170866420192, 0.16180610464465234, 0.16285918442712677, 0.12031799257402459, 0.179663859307766, 0.18230554497530385, 0.14275715986807502, 0.26531052805723687, 0.09993752569801385, 0.14377890665444637, 0.1466405974520791, 0.09888352661003029, 0.16909627394089777, 0.2413570883894159, 0.10052366722976008, 0.2536424880306567, 0.25497578745407445, 0.1072203788545824, 0.1144019092222856, 0.09012370190072445, 0.11917091380324095, 0.11329608428622447, 0.17274387901829136, 0.11969366155925298, 0.0858202259687166, 0.08058612174805134, 0.14915083775356894, 0.13416534590144313, 0.10002260742288444, 0.16770036981230782, 0.3181674385503415, 0.15190498512839118, 0.1364779201967101, 0.054542215826410445, 0.1975605772027085, 0.21152061440290945, 0.11623524955563969, 0.12547554928929577, 0.19724283457523395, 0.11848062261818879, 0.1908452343195677, 0.09685635071007476, 0.12390398886054756, 0.121300017701522, 0.11397061704267418, 0.15523546044864964, 0.14196945294257135, 0.11612490225102633, 0.16998158046795478, 0.15369484231116312, 0.20492946969405298, 0.09268846467978532, 0.12804569766646431, 0.9196161731116234, 6.431730024276241, 14.310038012842979, 27.22136470579332, 38.86368697689426, 45.6402757090907, 53.25749504950739, 62.90633347726638, 66.80765228886759, 72.41534725312265, 71.87543299890334, 64.69275343802668, 68.3204241721861, 63.7169736431491, 66.58475968145555, 65.8097150248866, 63.18320574298982, 65.01160290933424, 64.5693439052951, 53.97133504190753, 55.16726570744669, 52.2212048499815, 52.92670980576546, 53.171485316368845, 59.13793202369445, 54.963141641309186, 53.7062494985519, 47.28979710609683, 68.97853512917796, 64.14307640444848, 54.05507372271631, 60.05025179155412, 58.983327880982436, 58.014141590364524, 50.76483272737073, 47.69169884343302, 39.039671959415564, 31.94573210131738, 20.69090077953954, 11.300713246868504, 5.249004508218458, 2.2717912062521908, 0.5319309438909254, 0.2019490046246398, 0.10512902010833064, 0.24131219563705308, 0.11362609198136676, 0.2217876787988409, 0.16378199861895654, 0.25599217162497584, 0.16341435302409435, 0.08951782594404875, 0.13137244979941076, 0.0684752292750824, 0.19367174635971748, 0.2577627233920559, 0.10325434167058238, 0.15654176293361574, 0.1353406933166327, 0.21369144711042606, 0.0970552501178557, 0.10008633827730533, 0.16042371430704672, 0.15095359585698576, 0.13639610200639696, 0.1653126882569444, 0.15464695170521736, 0.18516286907176818, 0.1462711438897156, 0.14536404982209206, 0.1199810058178921, 0.1925636767860382, 0.14440202725029763, 0.20495141045220439, 0.11353651332038064, 0.20191768695029522, 0.19579497436361928, 0.10421439539641143, 0.15516421427169155, 0.19293645516999308, 0.11673296155828623, 0.10279248258279217, 0.27389638185981785, 0.14702514294655095, 0.12054672344557701, 0.1642962121554921, 0.23706017783091915, 0.21404996093723083, 0.3126939241924594, 0.1290024801968567, 0.2521522171915539, 0.15031383583141913, 0.1181943585435229, 0.11358666143590405, 0.2671237968869748, 0.19091024454082214, 0.13112342525874415, 0.11536814527766359, 0.11543409012618566, 0.25577915321675043, 0.1045546533479806, 0.09693249984974824, 0.16157943454961624, 0.1772161624244144, 0.2381166590437774], [0.005754791678965933, 0.0769478859259717, 0.028728212890846115, 0.04000287825962709, 0.00541670271383238, 0.07870078702727634, 0.03508187034317563, 0.027165491201524294, 0.03995123244221172, 0.03860635743025811, 0.03755350747416097, 0.004451900200482699, 0.017478876304061666, 0.047084614183873906, 0.013856997416775315, 0.048714906743337075, 0.08697085172658967, 0.017153470882124478, 0.015005911925747512, 0.06703976436608261, 0.0790124239339944, 0.008164640467223382, 0.029566943187326677, 0.028253625252193985, 0.03725087593099283, 0.00853927852961445, 0.09536211153552418, 0.09201754019745896, 0.058564541320646965, 0.02623240568584973, 0.055560595656354586, 0.021749839464563037, 0.04235782870842565, 0.07550314369220888, 0.026947684743772113, 0.09571535467740991, 0.046988048801018346, 0.015812894581035984, 0.11862357462485952, 0.1332757799255271, 0.01801153915303369, 0.0355019316738171, 0.04559743450954557, 0.0417549328337754, 0.017716616369603623, 0.016673128007941188, 0.04701103526918639, 0.020642444048257127, 0.042105651715950626, 0.030866845007685405, 0.010517958191133315, 0.026797772828309287, 0.01658651027678242, 0.04148133602293749, 0.02587879865219997, 0.01723617964964961, 0.010726890477892614, 0.04382897416249879, 0.15000393794428918, 0.03960576509275744, 0.026922832851508455, 0.026291333168985385, 0.03548677462423521, 0.02923579593639701, 0.06907984884756227, 0.017002576458898765, 0.09236112297061952, 0.08780227928993203, 0.03810340155576987, 0.03948508326204554, 0.08660037160640763, 0.0935644785603208, 0.0433797899994158, 0.27660168346858793, 1.4532187821403628, 2.8396204786915935, 5.082560200845042, 8.427789884228861, 14.343447781378224, 18.679274012965543, 18.64923454100086, 32.68073916435242, 38.46859447417721, 44.78463419022099, 43.7473084849696, 46.288133590452134, 47.25900650024415, 55.42813078049691, 52.75019138090072, 50.13807327516618, 50.98369706061579, 48.908327856371486, 49.08934916219404, 47.050159900419175, 45.36825933764058, 48.73447664322392, 52.06011702937465, 54.02139233004663, 49.64985193744783, 45.242543451247684, 51.879315376281745, 39.677245386185184, 36.5508770942688, 31.81413854322126, 23.90189616910873, 17.822677396958877, 12.231133772480874, 6.8803020831077335, 2.961939592515269, 0.3346430480239853, 0.24827844763715423, 0.10821263891674819, 0.033367465160066084, 0.053216259355746934, 0.047700204135429476, 0.02078918627493324, 0.06231496305835824, 0.010786984329892984, 0.08306820065744462, 0.03305074909041005, 0.04576052313730602, 0.05815589470007728, 0.043476428160624164, 0.04838482243940235, 0.00968395178431585, 0.08997631424497213, 0.03772588491800331, 0.08258650755329479, 0.1779844720036753, 0.010219280619264371, 0.019420826837660807, 0.07943844542868676, 0.04085643810310191, 0.011576467621771079, 0.04008334430475389, 0.061864913215920816, 0.01848405069341102, 0.046032568620097254, 0.030362810864443743, 0.060347365816274, 0.031569663645519365, 0.0811664869768485, 0.052140576149066614, 0.023832439910620454, 0.027051775025263913, 0.023687369670839082, 0.06781418732697926, 0.03248207436333741, 0.01821314476640715, 0.03570638138860945, 0.04529004172992803, 0.05923369613986823, 0.07621150689139482, 0.020241877740068782, 0.06096709264262069, 0.06553914367912278, 0.07100432300038877, 0.019701454420423797, 0.032685600942181, 0.0145147193313366, 0.07565263808975298, 0.042045192056966406, 0.06936569923474904, 0.04829340899783758, 0.024883958788949157, 0.03568223429723613, 0.09601360036721153, 0.05080849097500886, 0.041144609736699256, 0.10196329199618871, 0.029417174913349654, 0.06389406179228137, 0.034565733925950144, 0.010798207517983693, 0.03411263122313446, 0.0659687198217838, 0.019763884840593226, 0.01500362994134306, 0.056336424388592286, 0.0597603164703375, 0.05781762857711124, 0.034228482869483774, 0.052839432197112235, 0.031166896749768528, 0.02609422832216707, 0.04761864641501058, 0.01865082037364764, 0.05817134669351001, 0.021204239305769725, 0.0742273391675084, 0.05513687242543506, 0.022680306874756372, 0.016272069488261497, 0.03956512029793474, 0.076186555407701, 0.02024454947170471, 0.08323077217585619, 0.07866109601191937, 0.031637860792538816, 0.024463288418407884, 0.046196856175459204, 0.032743674237281084, 0.10627633636637081, 0.07295968581832225, 0.023662692063578197, 0.04007878608160442, 0.04026918957430509, 0.015659133073753648, 0.018603487631245967, 0.03654544684855688, 0.0820727689912723, 0.06636736899494164, 0.010915915012329577, 0.020481569414597847, 0.024616232126831047, 0.05155214401442678, 0.03000542701732728, 0.03479230059911648, 0.061025598777397994, 0.023931267168072444, 0.049281777333348036, 0.05957671966884406, 0.019072519217227257, 0.03684793283501941, 0.029035686109695705, 0.01284504219168617, 0.007912549659639837, 0.054150373344459844, 0.06956518853023168, 0.11112567292706621, 0.055100195966060125, 0.04008345538750291, 0.034898668076963194, 0.0373244471848011, 0.08527716156095268, 0.039416610323373354, 0.07730246972172491, 0.045627875013216856, 0.030537873446460695, 0.04568038650998666, 0.049980315454905076, 0.04748827740249615, 0.08313355561826499, 0.06193158584797095, 0.0625861007269592, 0.0566580051165675, 0.0817335452584009, 0.11220950347882126, 0.010764132884721602, 0.3020749649693889, 2.3646685192661905, 4.994119578792203, 8.857882676586028, 14.080438152436288, 20.523425379107078, 27.238028895470407, 29.33553399578218, 41.51780582243397, 45.77179670333863, 52.86349688806842, 52.07990930926416, 53.28457117080689, 55.06287967005084, 58.60798843445317, 60.53007925710371, 57.803463243669086, 56.20696052428215, 53.7308309924218, 54.62808493644961, 52.58796999531408, 50.926614807498076, 56.24011239697857, 59.08466231438422, 59.312814820197325, 53.86192444832095, 50.61249963698849, 58.379047532235425, 47.044629358476215, 41.86024835032802, 38.744686188236365, 31.243949474826938, 23.36051690963007, 17.616182258052213, 9.647698979223929, 4.652660585218861, 0.9569362382734976, 0.42551768462984796, 0.13041827196796096, 0.02221194944614845, 0.030487344202194965, 0.009029661943655341, 0.10430683922623435, 0.021915032918895447, 0.020763614260020758, 0.09215161324508729, 0.09514098025618062, 0.029384294419639537, 0.01586107480820389, 0.014012984409477684, 0.03686088355137937, 0.1010781616693543, 0.06581892664994925, 0.05432435574250356, 0.003771288296951342, 0.02482632982484516, 0.00851884504945408, 0.02046460822795428, 0.06816222107097988, 0.014935590799957996, 0.0467766736513905, 0.025599866038969448, 0.087352731235085, 0.024758753209044377, 0.023635398266055895, 0.03964465171579392, 0.02393385079959708, 0.013946494680919476, 0.11785172571938847, 0.03533936781628478, 0.052262004915504694, 0.027339925591443336, 0.003396740249891375, 0.029615275674469532, 0.017540529144987944, 0.04695876509011273, 0.053605014503362684, 0.016033361279105228, 0.020459488845400272, 0.029684514701066, 0.05189029139376456, 0.0247064791995311, 0.03764377178383931, 0.04315332291767963, 0.026705962936243704, 0.046898849353554754, 0.07085720347540994, 0.025778653723518216, 0.015336396510622676, 0.05334151473136679, 0.03179537804586993, 0.012454920534735486, 0.0411883227136587, 0.046677507400032014, 0.011464648470733196, 0.027905057161866177, 0.020329269220031077, 0.05953454652861242, 0.011152730026702968, 0.016259722066141905, 0.024120714966087572, 0.03896995425044049, 0.03054067349782394, 0.11148324446572412, 0.13558650028801736, 0.1785065915675894, 0.2328819802571689, 0.17251849595096805, 0.11317154903325344, 0.11470010894681178, 0.08282401013158022, 0.10260296775208366, 0.1545403429096745, 0.09708993091818788, 0.11608308151123986, 0.10826056537729119, 0.12001112839507481, 0.10907948272483003, 0.0892095368415598, 0.23553854335219632, 0.11262037175437135, 0.13743206738464295, 0.26664321461031515, 0.20468104270196733, 0.19196736926753677, 0.1264288384587534, 0.2227300588762568, 0.17274835297176916, 0.12834133099644415, 0.25111194639917345, 0.20390315702365291, 0.1374756577875345, 0.13709485080213318, 0.16612533900526263, 0.11162115561385309, 0.2097560994086727, 0.11731298204751746, 0.16135543044055664, 0.1442575583895368, 0.16466604876181773, 0.15864111963779698, 0.15796089484806985, 0.16919883779220043, 0.11877633255696106, 0.14189368684686002, 0.16836047713314334, 0.09763532423324163, 0.12719630534129758, 0.1284904806544223, 0.11315543820420582, 0.10085447165634363, 0.18991181747086588, 0.11448075499145255, 0.11096957485161482, 0.1657736893262594, 0.13657245544656632, 0.2045504247108775, 0.1410601218982089, 0.09067006814744204, 0.07948630294131656, 0.247095791743167, 0.23076898718793548, 0.14755982635242326, 0.16097658464024145, 0.16138690133248607, 0.11761688912707953, 0.1392944118068103, 0.20085196671707017, 0.11412122992858773, 0.1935410824033522, 0.16137275934940384, 0.10009455073985363, 0.10435977590180213, 0.2825510303579992, 0.21834497159767538, 0.10999478159412263, 0.5593578108856755, 2.0520163928308794, 5.56409978097485, 9.015215808345426, 13.294087263845629, 20.774919909815637, 27.15886958183781, 29.23042428108954, 44.15943584134502, 49.30968438425372, 58.26287477247177, 58.76711899234403, 60.812658571427875, 62.65055571832965, 67.91594151527651, 68.13277013840215, 67.13357771596601, 67.4329016285558, 65.14660304592502, 65.21217330809563, 63.10627629680019, 63.61375647206461, 65.56582596994215, 67.49107037821125, 69.48396390484226, 64.76108112642842, 58.1043404148471, 65.28669441899946, 56.44683699454031, 49.634790035986136, 43.313309992513354, 33.389329064276914, 24.214326681629306, 16.10316228482031, 9.639800306289427, 4.078815132379532, 0.8842835238864346, 0.41390244338300924, 0.41166868421339226, 0.19281404964145155, 0.15993211568603594, 0.08131340731896701, 0.17818039132943078, 0.13184158672248164, 0.13371782797959544, 0.24472280375419125, 0.25336700281308544, 0.16757554344592557, 0.09460957570662422, 0.1463381152960562, 0.11889969569540794, 0.1778526589154236, 0.19608578133967616, 0.1485178959105284, 0.20202248777833678, 0.27335249007709567, 0.0770731489624708, 0.15906986840549978, 0.1571942400187254, 0.14484395273029804, 0.11214681450397739, 0.16011533327400684, 0.2850436353154721, 0.19068043348529648, 0.10273440545725246, 0.10249767662777055, 0.08723508311255325, 0.11021300173935392, 0.2967972933284698, 0.12761848107461007, 0.11467921772911666, 0.09538862583858353, 0.12332589125200627, 0.31670739754073085, 0.14334568393326577, 0.15960757019779376, 0.11690428180079307, 0.16270271862947172, 0.15024280415907984, 0.17995135678398996, 0.1349793296427496, 0.13097622912497292, 0.14179162861358735, 0.2099697000437206, 0.09528144247709744, 0.19499087315653602, 0.11819694792070698, 0.17308206087158573, 0.23793652112926209, 0.18662117872267, 0.2433743051463558, 0.0691490265871248, 0.19324528053402903, 0.2737138997162542, 0.14214202190839476, 0.14080383484402012, 0.15815071611394807, 0.18108816997658822, 0.16659685080089878, 0.09389968033158973, 0.13720014192644628, 0.12293891725881446, 0.12373698169305442], [0.012611132565765612, 0.011049985187128188, 0.09707902948702536, 0.04722365531169119, 0.0801953249761174, 0.01942066978963633, 0.015806383791289503, 0.08237607852225343, 0.05844353773300687, 0.07888878500389476, 0.10028571265959933, 0.03843817814824082, 0.011185564555137629, 0.012520462229487397, 0.03799049551748941, 0.03211527338041173, 0.07889259246087844, 0.011679495913877843, 0.11951638115269524, 0.0553174814840238, 0.1216422291772981, 0.036152401608565164, 0.01579044341680504, 0.09721105707989586, 0.04265922301959607, 0.11105406668878372, 0.043557916933129874, 0.008158418875668318, 0.029901018809346907, 0.06114135849319639, 0.04371127241381234, 0.038583298183737263, 0.026897906265672178, 0.035282478127027714, 0.11942317123494803, 0.03756163183659796, 0.02596205325737115, 0.028409311555386074, 0.04461074773702891, 0.01823879339011206, 0.06398170608125868, 0.01225608624442811, 0.08506421976151966, 0.06382409498215684, 0.03218488970531091, 0.044653583543315056, 0.023520333775048776, 0.08437493981252756, 0.03381474942509686, 0.03541078636302583, 0.011596156081425087, 0.033879840085583354, 0.0708588582253264, 0.048741183559139895, 0.03195379736773189, 0.05203672910049077, 0.06427097705102737, 0.01667904986759588, 0.04689128040486286, 0.033369223331852306, 0.04396467514696621, 0.049204670583769206, 0.056946847077098586, 0.052556492944037726, 0.0236483030171404, 0.007804845837170199, 0.09917370539398924, 0.04782113111427715, 0.1535144745702705, 0.013009748222576755, 0.01265928119180664, 0.04383560465348344, 0.023268978411872542, 0.07271259948010407, 0.05939560116178567, 0.007226985237080485, 0.05960422222532573, 0.08383758275979951, 0.401809684211208, 1.2321942035228977, 2.0329837044400554, 2.5160781366209832, 3.1463324206490673, 6.895817508620601, 9.495402170765786, 11.558584570884706, 15.347659857042375, 20.812180465267552, 21.00254289565548, 21.17676281159924, 20.45682353358115, 23.657595265296198, 21.872922720447665, 24.626885498723677, 28.115233644362423, 24.361913704103042, 24.79182508683974, 26.862826731897172, 24.52463323070157, 25.9696481304784, 22.15582759149613, 18.061328126538186, 13.173438099122817, 8.559270674182523, 3.5007229783842644, 1.4669883852043462, 0.39117742570177205, 0.08234079251246107, 0.050484006773800626, 0.0669235028626938, 0.08004958440940227, 0.02981171402479372, 0.013625423401413907, 0.04445527019279619, 0.0619823889686696, 0.011170649780861793, 0.05114003850687897, 0.08930143674895649, 0.048439720300056284, 0.06404057993823964, 0.06433232537200374, 0.02455305860137507, 0.01813569327726239, 0.04146160542844765, 0.0748384781482239, 0.032263130265017675, 0.006047856699179618, 0.021869937153232676, 0.05385315804291637, 0.04222065683514361, 0.038310011638508695, 0.06254116200932092, 0.02603779062478533, 0.09254506068123926, 0.07245403714478016, 0.05787054610048091, 0.02873546008260981, 0.03924187715916384, 0.08450651541352273, 0.018403578902624788, 0.0059304024926536995, 0.06093747568346801, 0.06155965399117239, 0.03505046456871975, 0.06105457222269428, 0.054323355997762376, 0.07608091188294273, 0.05993753942030092, 0.03993633586252409, 0.03650186027610495, 0.045517742213222294, 0.08808960822681267, 0.04362612174102857, 0.03710048138013771, 0.11615403657478672, 0.06311825987312102, 0.030629779099516814, 0.06205544694356861, 0.020736165329693787, 0.029603357261587537, 0.02755425975567872, 0.06113316901328583, 0.03208225307565543, 0.011046509063171764, 0.05243014206268615, 0.023280565491727283, 0.00443118614062006, 0.020593186509945703, 0.05158099105521556, 0.03944282585214223, 0.027128205702249563, 0.034190274234260284, 0.000877005365891232, 0.06621949870379702, 0.0741464249609459, 0.01371297384462049, 0.042453225807196675, 0.03634307323203933, 0.028944751473083615, 0.01788433599886635, 0.029044969180118174, 0.06055085409072138, 0.02524109557271004, 0.04196906206949104, 0.06646201149710725, 0.024195291710296468, 0.04018174063774847, 0.07054008137915405, 0.0269483091054304, 0.007799611541427553, 0.06888656486426631, 0.026722454894033652, 0.04489310476328096, 0.015157638511980976, 0.10416101438984757, 0.03842752952609332, 0.09405664408639555, 0.04677315347737843, 0.02448228931414985, 0.022469860606736714, 0.02142210705055585, 0.022666990351412567, 0.020789902567142443, 0.03442681537220075, 0.034022010682571324, 0.018656253852250598, 0.054017832472680084, 0.04311545519158245, 0.0387478155654765, 0.03672711310848113, 0.07811088400382189, 0.05662319791172782, 0.011404534508924813, 0.011699630619747745, 0.03884262277654583, 0.04155969915671214, 0.0711898694956495, 0.045482820095193964, 0.01688980640122487, 0.0409841870949153, 0.0743398774835852, 0.059392590436243245, 0.05840110029244135, 0.08829017004538929, 0.03294378789442201, 0.04892858015673776, 0.040670282567941377, 0.046301848525481845, 0.03992327406341511, 0.03159286844874582, 0.01971544893158059, 0.06309984694986094, 0.02889672159067085, 0.07421904243528843, 0.02870240913433654, 0.044477624638426694, 0.012366029437661413, 0.04804361070836744, 0.006809209721283086, 0.08843926607721275, 0.08303037123574365, 0.022562695141401024, 0.05844556403556659, 0.04646968306793321, 0.07412236980012349, 0.01892368940095748, 0.05407224003706248, 0.06066927213161703, 0.04675803473219276, 0.0897438218817115, 0.08224126236933856, 0.04023895974481299, 0.22440756160405376, 0.3428253573515723, 1.0560334497882475, 2.0904056102998796, 3.0846055909510586, 4.546099103266194, 5.912386640425652, 10.86222069878732, 14.48429911367355, 18.37498830210778, 22.590991027893562, 28.54369571132045, 27.400177717208866, 28.06841427280057, 28.31671795537395, 32.77393467964665, 30.522831524572066, 32.59401555984251, 36.79287164442001, 32.408426653954294, 35.119474780175, 35.28758756576046, 33.435079589966804, 32.5464254425418, 29.87059823928341, 22.86267988143429, 16.94909691810608, 11.823168050858284, 5.259839075226938, 2.2036645393217764, 0.5496422838299506, 0.1921606838943497, 0.08513079280213964, 0.05491921535482811, 0.07814599381339166, 0.07519274784792816, 0.08086281738454297, 0.036870708629008264, 0.03839008697879411, 0.0798138285115842, 0.07359593716119567, 0.04698555518482481, 0.03533219723331352, 0.03020677982168573, 0.04311652388423682, 0.09317924358671711, 0.057108231159227515, 0.02104400435552722, 0.06608141135544547, 0.05142026580870152, 0.036617010952003544, 0.030983135239371372, 0.04140145603507277, 0.07350525533359858, 0.02607999440853394, 0.027231809517909444, 0.03912108041526329, 0.05519618295253285, 0.02657114869854864, 0.07839654286902759, 0.05486589946573781, 0.04717737977062503, 0.06700348244198868, 0.05055058747529984, 0.0366551966045893, 0.0353467452429956, 0.09046174585819246, 0.05626828852860678, 0.05364952421176338, 0.05757193268847562, 0.03830378334368429, 0.03294968294099935, 0.04641722136687848, 0.03059302794656927, 0.03396270398591315, 0.04013481392194668, 0.032140188474929145, 0.028817071429183407, 0.06895439428908211, 0.03570121412556018, 0.10786572366111702, 0.04388375710996409, 0.058015627831581144, 0.07558562071813692, 0.0056018029628772175, 0.03448008529601559, 0.013981070144162064, 0.03880300453954166, 0.044838666555381594, 0.05448888078512204, 0.030026032867270614, 0.04722734785548622, 0.08900211853606087, 0.055915340330571904, 0.05326996978011824, 0.022574395219224597, 0.039763946927362875, 0.01650383406799407, 0.059248807224174665, 0.033805158004284866, 0.12246879208232127, 0.1675957375236096, 0.19426995377627113, 0.2673726222447811, 0.2034128760738719, 0.26420736144627294, 0.14665259438897335, 0.25402680369875125, 0.20950869897440558, 0.21713662111470777, 0.19031346204780764, 0.191077527499968, 0.21606201426156108, 0.1472533452174356, 0.2017682078745096, 0.14726336564748518, 0.12551341701539295, 0.13208612198791198, 0.26374485884462634, 0.10959661505635708, 0.19629961180110134, 0.1621790362461921, 0.1286398448170193, 0.22454631544889944, 0.18238028451319666, 0.24683576617990774, 0.07238510455335341, 0.05496842884308389, 0.12870335350594214, 0.06382679544208993, 0.24755780404854208, 0.10362040912432056, 0.13851660273728833, 0.15329430090083232, 0.19763646587248773, 0.12320100359859006, 0.1914103773813094, 0.10966733263264741, 0.12374978302226913, 0.1588547662381203, 0.15946999612835147, 0.1289910808085434, 0.1654403491486465, 0.12442352670815685, 0.15961590523440994, 0.12540493130443559, 0.20330625195657054, 0.20151348363968635, 0.2758937262960019, 0.12016670553073769, 0.16818636066971288, 0.3069776825366482, 0.11943991025609356, 0.14832260477687084, 0.14654716536883386, 0.12274219354073848, 0.12843773550083562, 0.24609287539797448, 0.12668490334744417, 0.16127189621329308, 0.10154611881702177, 0.1540129986261168, 0.20875895936642924, 0.16877879178331745, 0.28166341024541086, 0.11648571434160394, 0.17511875158356083, 0.11755829106175131, 0.22522919090284457, 0.14686060258217398, 0.08980088777119115, 0.14566766578824292, 0.23428742984129539, 0.23633285395560727, 0.12961977852448342, 0.131813547904453, 0.30832599728338184, 0.4498199854166277, 1.029405581855005, 1.9907721372381335, 2.8690353132063344, 3.7279931960567354, 5.450493231896432, 9.727128936398415, 13.463592490842267, 17.501468619992657, 23.160491720322643, 28.15655581412777, 27.588063170832974, 29.865414827100693, 30.175780211725545, 34.94554119725382, 31.034942057824907, 34.825708866119385, 38.941314604974565, 35.5498960710341, 38.23144405118881, 38.800293630169286, 36.35590391774332, 36.5867236352736, 32.27946892861397, 24.093625545501713, 17.772178842175393, 11.762148718680105, 4.918953728291297, 1.9759407975981313, 0.5800654126271125, 0.2866830634734323, 0.26130563489371733, 0.12888894596647832, 0.27206077390620786, 0.11146521075598656, 0.1604945314747672, 0.11604277762554346, 0.1721008554581673, 0.12276587331847799, 0.17691744942097895, 0.13240489117320509, 0.1544483663934854, 0.2767184352682483, 0.12820555723362392, 0.2883749839759642, 0.16763816347285626, 0.16529280061443008, 0.12625426234256837, 0.14172625067012926, 0.21478736652962624, 0.08055075912946656, 0.1509498267043983, 0.1718897369479941, 0.14564048498868942, 0.17060197379079559, 0.17111848559110396, 0.14439678720889554, 0.17604395596971437, 0.16497960854922572, 0.15152701266830967, 0.19252212417702522, 0.16436638580935617, 0.09446103891898548, 0.11118700592628411, 0.15815293776892847, 0.18783737394598224, 0.17758187747770743, 0.1250996605883683, 0.17069241813113614, 0.2574023249889574, 0.1307785018317161, 0.1070513568758484, 0.13461120907337437, 0.09822001785881097, 0.2032763898492821, 0.21175732024975363, 0.16104352540306507, 0.23308837966572857, 0.12212551574433043, 0.2559560429184668, 0.1486293617035112, 0.11761108984149272, 0.2744618466784877, 0.12090316117410699, 0.1993927530824177, 0.13560626535646378, 0.1872271236272589, 0.08276023331188387, 0.14503293129945957, 0.14159102082973526, 0.17822620338730275, 0.25141542446949794, 0.15870819829644697, 0.21716787750201844, 0.18954141395947627, 0.15529141551063907, 0.09796409852682583, 0.17820608591841114, 0.2033914715772675], [0.024958472330904296, 0.037779173994016264, 0.01417303741383817, 0.03204305235657, 0.07162742061360229, 0.04464750846607551, 0.03177933041907607, 0.030001788099686948, 0.028395112115709532, 0.08330450813856818, 0.038186407182365656, 0.051313733621951074, 0.06531435049950116, 0.006230639532253507, 0.04395862688280402, 0.02443301453886013, 0.06459687085401628, 0.009853899771828326, 0.045008389504566315, 0.0227890377338495, 0.023962100291804924, 0.07715718114688512, 0.05765462804946208, 0.019761266735111995, 0.05789036096464242, 0.022371588763029828, 0.03849849991139866, 0.09957584026720255, 0.0634508224714908, 0.0025200761522301625, 0.023311212839138125, 0.030372928970703678, 0.07825712252768778, 0.04678017850364408, 0.04029774933212227, 0.030526370636277625, 0.03137998793634676, 0.05106904513893589, 0.019186118565079187, 0.11204991970331439, 0.02547356878377257, 0.04714533048231275, 0.011204574069368744, 0.030722780258304654, 0.03387387226065321, 0.052149160164258176, 0.05043264440891724, 0.05687463179891629, 0.040842705977059184, 0.01314709629608138, 0.06505993269984761, 0.030235266801150098, 0.06576192204750354, 0.02436549154921405, 0.026751719452741168, 0.027083109936586795, 0.0430679117750016, 0.09406856441449735, 0.07426689228703899, 0.03864761126498061, 0.03934289351285946, 0.009635360742498551, 0.04569442890163872, 0.10450245211682013, 0.02976719090985435, 0.036378592898648594, 0.022312469757913102, 0.0672474967676305, 0.043332821148778164, 0.04000723346947663, 0.015328905128333119, 0.06607692208020918, 0.03397120756187266, 0.02715515667542575, 0.057142655320105054, 0.025890552356178244, 0.06329968481534912, 0.04978464510772498, 0.03460233760697227, 0.04134919734731798, 0.07735751313908447, 0.01364969977012445, 0.0453667079789504, 0.07153752785656722, 0.09671777306545166, 0.24689492348942066, 0.8028597769237334, 0.6695594362193539, 0.7318230177606306, 1.0237215771790475, 0.9710853919386865, 0.9487850014721194, 1.5700693764994222, 2.0907944152432103, 2.7747569785964106, 3.179577204488939, 2.5877074801152755, 3.1485554239442273, 4.045896395560234, 3.529256750499049, 1.54997433866224, 1.4315242752913506, 0.1512054549229722, 0.09500035715679969, 0.02249448267262309, 0.029471689730041453, 0.03974954830482602, 0.049073930018611496, 0.009266069016209053, 0.05992211807038515, 0.04745619364022728, 0.03932019049722341, 0.022285244908303987, 0.023928691197427052, 0.03699502171648126, 0.038059355330563364, 0.03802473198682551, 0.04523516685191182, 0.05699755060636709, 0.003498242111809011, 0.15120542427945524, 0.015739296514150358, 0.09410582693113435, 0.032638674226379207, 0.013070106374911003, 0.1281857921651775, 0.07929132590370794, 0.04832276165665639, 0.028804963409540155, 0.03727685397250518, 0.04126094401844087, 0.02037467525130318, 0.017872490364337162, 0.0077443957542850375, 0.025522364754109614, 0.015168217228605382, 0.0268133991067448, 0.03193185469436069, 0.04684317774409729, 0.03234839585099009, 0.0810247224064604, 0.029911975781883926, 0.05802267967092414, 0.06713658255795318, 0.021327592868117556, 0.112619161335451, 0.02898854680449492, 0.02059602295048535, 0.031375540795946316, 0.0651945726525399, 0.02286056736333957, 0.04180492390127432, 0.03488045050612381, 0.02677548924581178, 0.01906782884391085, 0.05373007835700147, 0.02755325043483848, 0.033235924033027504, 0.046596072253681, 0.02509201677786487, 0.028932704740474303, 0.0231435104468537, 0.027261727166572408, 0.014767888407673568, 0.019820621312265436, 0.02231383530963813, 0.06156062309239661, 0.08835696525150731, 0.0720656918542039, 0.03657457734187765, 0.019716042649721908, 0.08588653853944234, 0.027474960079416636, 0.08426674521498143, 0.06817673077626575, 0.052603254950935804, 0.041851659095095056, 0.038874511186394005, 0.029171770138125268, 0.026038321140672893, 0.0104076903681421, 0.0449309993024555, 0.03398369862547806, 0.07911756950160188, 0.004522195949609722, 0.05711202712489232, 0.09615229292502327, 0.01495547365442279, 0.070635681491225, 0.042418621615656925, 0.024326283169249376, 0.04606328108498166, 0.03889048411961525, 0.013192561699167616, 0.016988158684163805, 0.03673382403869783, 0.01074147966480063, 0.05221247350076034, 0.060220700838873466, 0.008291128286791426, 0.0323572211838778, 0.07127852885112648, 0.03884686307320672, 0.022425429422348257, 0.041687976749193285, 0.03702653857368616, 0.011359155290730057, 0.019446427580870448, 0.036794509693619706, 0.0811953531698354, 0.026553798722283497, 0.06550253999810066, 0.05540017684501025, 0.02886452099999353, 0.015971318690947468, 0.028173649503338723, 0.05161923799483527, 0.03222952198777949, 0.06400118386673351, 0.026129991221692295, 0.037719250596579046, 0.059431760511811704, 0.06861712408041762, 0.03306864107388162, 0.04715455801136071, 0.0436852598983434, 0.040357320329114314, 0.0382348622435764, 0.01644021812676182, 0.018197654468578198, 0.008212141748968392, 0.10877863999696509, 0.05777350191267268, 0.03184006970015264, 0.007163473196522965, 0.06725479758554889, 0.04581935102901152, 0.0463806598206922, 0.04102210461672756, 0.04056114568224838, 0.04368403415766455, 0.028642545108713453, 0.09184910810642666, 0.02182944557599483, 0.07560056709353963, 0.09625002276152374, 0.032388695906246864, 0.027427520084705566, 0.0348271690909901, 0.03680549156401427, 0.02212726991743811, 0.015038830723853843, 0.03388597261941722, 0.03715414200879393, 0.07366534472713548, 0.10010461713517867, 0.15945744760815175, 0.04631309086577066, 0.017703836107806816, 0.04490278811464387, 0.3392043661686682, 0.5346988502048677, 1.2224791054764104, 1.535752927584033, 1.9878750991436744, 2.116867390371138, 1.9140763172218878, 2.2170479114978545, 3.017378862827055, 3.695125204901542, 5.034397907795445, 4.654650207488768, 4.848322137709587, 5.5731604560729, 5.63196708117762, 5.320387722984438, 2.4938667349277006, 1.9374863707250165, 0.4165299717457064, 0.018764749139307008, 0.054881029702242345, 0.048141945754328085, 0.05139672392678838, 0.018413752550259233, 0.02639803197985936, 0.050316248840141686, 0.04897248465567828, 0.05347248512290178, 0.061772614942803505, 0.03669527832478766, 0.026745918251934554, 0.025466725703388936, 0.012284742720845726, 0.03454291599712545, 0.042157960199420495, 0.055739143938427015, 0.10160025058975143, 0.0710592208610427, 0.047418854514797854, 0.0431925121454462, 0.014745474590228931, 0.04215641653225307, 0.055999173332125916, 0.018278815738496282, 0.04505700161380153, 0.006066905954221805, 0.08912292294084065, 0.0292408770145548, 0.02363793018664564, 0.03843807855681066, 0.01712056549055682, 0.060942880433773806, 0.032124491333360636, 0.02594696707092226, 0.1343397688000433, 0.06743928687947412, 0.05963837059455053, 0.05012992093519819, 0.06968855166867857, 0.07908097348145901, 0.05044071131475991, 0.06794406987366176, 0.025709791995224454, 0.06150209397498158, 0.04222429958322356, 0.03240517445749814, 0.019684018259267175, 0.04612177189800047, 0.014707672939215218, 0.009155904615087616, 0.05051053639861846, 0.032406645346312754, 0.05105364294121823, 0.05631694277267783, 0.023234458490004464, 0.027895758769685225, 0.0043446105442971235, 0.03653478673509052, 0.03737794310455361, 0.01511666717218055, 0.0476731114359873, 0.019735675568001407, 0.03944211722081227, 0.11894119467826621, 0.049404044966063196, 0.010545137075466976, 0.060505160776477676, 0.06599092104982945, 0.035067785816687735, 0.06793938141556517, 0.06787768835502286, 0.05586541438054654, 0.09190920004320723, 0.11914546436239636, 0.13194163780539267, 0.15462793740293673, 0.11280822417428417, 0.1614426725333737, 0.11021268764330495, 0.2060043983041279, 0.1112828971517663, 0.14662408059643162, 0.1412647899480597, 0.24433592935242962, 0.17648574355388844, 0.15621985278783307, 0.13521078012643323, 0.05076336839626874, 0.15153848866541542, 0.06545689647957202, 0.13901639849908892, 0.0751708836985692, 0.13591718980141226, 0.25873709530118977, 0.14373864107314618, 0.1098295517506138, 0.2278088694137912, 0.16810288772948329, 0.085490019090714, 0.17169783192296184, 0.2035643929435361, 0.1433989730092787, 0.10856469462235128, 0.12356238259423165, 0.26303717746369304, 0.27973783292597343, 0.23331102013828295, 0.17613300603003273, 0.1233246808330859, 0.18157492692191757, 0.10717146414061708, 0.17268956338445987, 0.12318204292246412, 0.19229641935277372, 0.2827039721512026, 0.140511694874975, 0.15046614943252457, 0.22177211189221954, 0.12912750574609927, 0.20530235533031727, 0.1634821211618762, 0.20915268259423397, 0.1405127520763105, 0.13548320099230737, 0.17838029431239252, 0.21749887345058305, 0.1113996949167021, 0.20230448474326443, 0.16532283126106187, 0.24089777271353432, 0.23736327285728148, 0.13716474866434453, 0.14553292624412045, 0.15606035328199788, 0.12409032442637029, 0.2088645262823951, 0.13663576495262886, 0.1213331816477641, 0.1490157764525183, 0.13834003479250018, 0.14319225184379086, 0.18376396187851507, 0.08562487354802509, 0.2189398082273622, 0.09833752042463711, 0.10483372385703749, 0.09990774019951783, 0.08084642310296336, 0.08412930138048627, 0.13963360489616472, 0.16004934246020933, 0.20991469493075726, 0.32477951278128936, 0.1265911495072707, 0.15106892273310693, 0.17589496719020029, 0.3077897357363855, 0.4863272619343573, 1.0934290818629728, 1.1762567921992273, 1.576514320988809, 1.7114960714693994, 1.4792870994537108, 1.7372393223547167, 2.8221291592044215, 3.1958275841128443, 4.268045713824611, 4.362730749191777, 4.568297266960144, 5.151407112998347, 5.623636947524163, 5.024532656515799, 2.993923579492877, 2.1801992049140315, 0.5193211366572689, 0.14146910559746528, 0.14288647550969355, 0.09875787286868981, 0.17567652487947097, 0.1463413175435797, 0.08721552488784637, 0.20318229893042197, 0.19267019365103016, 0.16510353093185734, 0.17060459381149662, 0.1634435869392849, 0.13763872726309684, 0.17678479363601055, 0.13188641818781055, 0.2264740071710079, 0.18119009031403452, 0.1542653479883748, 0.19955081234295524, 0.19618528083928172, 0.15177459696367865, 0.19283202206415517, 0.086288558499467, 0.23896194513767, 0.18998789000174693, 0.1186990266245219, 0.1588722330427939, 0.09290005050359235, 0.18104500858293426, 0.1403606989450993, 0.12249395040975464, 0.10586202069516144, 0.14386090870586135, 0.16186379106535068, 0.23497663318149506, 0.12697977058949972, 0.15248992390209629, 0.09509991028255994, 0.2119766665442336, 0.10058454823710265, 0.18177562663632055, 0.21123696268806536, 0.1034029474061343, 0.21126092591833687, 0.16275294335378757, 0.1828117452321514, 0.13586937059317866, 0.19591526548948981, 0.13552446248790911, 0.1328135071502578, 0.08743513931309985, 0.12134652689940507, 0.15199300863089102, 0.13971882451686168, 0.10611379549147622, 0.10979881630309167, 0.2728489558062246, 0.11597776740428903, 0.08998634233590096, 0.15535271786634, 0.11199973328339477, 0.21024788189078533, 0.1921466185200599, 0.11454876827737016, 0.13614494774130084, 0.29214854922986805, 0.22029630479312715, 0.11970262478796706, 0.17055461423531657, 0.2618292713117215, 0.14629666993935264, 0.18709383965019258, 0.15810467422969882, 0.1491730236598561], [0.029940704079044443, 0.0380388165133134, 0.01812156470071885, 0.04556959870481684, 0.06325181581140046, 0.02998046595753441, 0.047281847350419536, 0.03315478383052734, 0.1276695638174011, 0.0385279828051646, 0.043613335733572324, 0.07303037275109561, 0.04897295963019133, 0.03364626753834948, 0.06425498879604763, 0.056085879163395976, 0.07572557732102371, 0.04678560623658761, 0.02073590294457972, 0.04436710113359075, 0.05458768697515611, 0.05025516481949918, 0.061570321765518, 0.04975891987522764, 0.06268998224949164, 0.021776453359052542, 0.024153229652813846, 0.01648690160964766, 0.10139711471574922, 0.007982729537968315, 0.010139549060934975, 0.024030657500148784, 0.012191496413922118, 0.032461209958719636, 0.018157113095625274, 0.08680410502899079, 0.05052447919884036, 0.13235052957409812, 0.032691879032720486, 0.016810183052814776, 0.032098055554313526, 0.02247022641372056, 0.02743195381856734, 0.031211699486800262, 0.030234791826637044, 0.04740513004963437, 0.04614710642565643, 0.04141509240012496, 0.0020237450230671393, 0.06642655694797155, 0.04879077626091819, 0.03695640322421828, 0.05580614215784496, 0.014786709272753329, 0.04352753771649253, 0.02442758106025717, 0.036931344488215063, 0.04900677475116907, 0.04507594696816899, 0.07704808256558834, 0.027340749135961937, 0.06008725598334305, 0.03061816520658472, 0.01390539597900164, 0.06949369720513783, 0.036873953011367595, 0.0451249880866418, 0.03830914595915425, 0.049577870316082434, 0.1088159025136021, 0.09817938455530713, 0.03751228428295544, 0.04785570466229993, 0.053653201433799924, 0.011922252897713936, 0.015540951562504617, 0.05804455531160197, 0.037982091532960054, 0.03415904466002699, 0.08677969746772321, 0.0407323012158515, 0.05182940272554275, 0.05618884904129852, 0.06177055416628719, 0.06438663334495599, 0.027243030790780342, 0.0521639303394383, 0.07324734417301032, 0.0511984795241827, 0.053908791347977617, 0.12188193808880546, 0.07284759949412077, 0.06923262976230153, 0.006746996199757222, 0.05740423987229025, 0.042511387202408046, 0.026236004383874037, 0.07218530116182181, 0.058659015283469236, 0.03769486984838882, 0.02913235874486066, 0.06735435071130914, 0.06015983515328938, 0.009461221296430357, 0.04574911225767386, 0.0471864847256051, 0.11470577799745145, 0.014451870435638534, 0.0229425426016772, 0.03913447929305896, 0.007029432228826468, 0.13403244496833894, 0.05560356169758786, 0.02960574554069148, 0.03329315463141088, 0.018590609693238815, 0.03653860568339306, 0.04433599796386496, 0.020926626278988777, 0.031199085849126985, 0.04749135324551214, 0.02262007895736925, 0.03292526005797329, 0.012294023876048386, 0.044031137104837165, 0.052341635924794024, 0.04233598371126479, 0.10162983690538716, 0.026531886692429264, 0.04111499660798619, 0.029537764813510642, 0.005705333042574386, 0.029884092096659928, 0.03193249054733784, 0.029391390309038184, 0.019195533785668593, 0.035821080072632724, 0.03307989107504968, 0.026619236037555723, 0.1052183919255772, 0.027024167131692655, 0.013094163450953222, 0.03511532540282896, 0.025531404591616125, 0.012663557877643936, 0.04052358822176053, 0.0710739144274304, 0.031236700766209154, 0.09715258158863553, 0.05226584684644496, 0.04449247525283887, 0.060045783813562126, 0.07956403022211406, 0.02660824650628192, 0.017619819245150974, 0.020530327080538677, 0.030090686857640266, 0.018593616588341615, 0.08619428371950504, 0.04078874274367287, 0.06290974606189036, 0.013323915134664747, 0.020301324247773138, 0.03697038815927602, 0.042367998525620475, 0.05354367001282592, 0.029187248944635355, 0.009509847769814153, 0.01806412151293649, 0.09560599562621887, 0.05907508912646483, 0.02027322414271053, 0.07600984190620723, 0.018418891085011345, 0.08579289961245753, 0.05706907257497792, 0.0982260546316543, 0.029560496557443857, 0.018785833794203018, 0.07575119530121166, 0.0486900165466772, 0.026334427529945973, 0.0195321106847616, 0.024903373372170235, 0.1897087428838976, 0.05433908761328748, 0.03748882284027435, 0.05787301290359709, 0.03132902776762363, 0.03598509566678155, 0.01170738438715137, 0.05986818931095543, 0.031045215174315438, 0.04680693412439958, 0.013430375500672288, 0.060449833906586134, 0.0101080006026032, 0.03972826638228951, 0.046979265602966475, 0.0633448533593647, 0.02810955667237361, 0.03533850213693034, 0.004904795580753876, 0.04928076226684836, 0.060260250127964446, 0.05950187287864186, 0.026656443012818217, 0.020046555962894234, 0.1070881367570931, 0.03234294130496922, 0.017282650543136463, 0.06595355128088305, 0.011528047992126837, 0.02758106517214929, 0.018248530367629665, 0.07350648873515668, 0.02685970529132793, 0.04887204286792586, 0.048898101348670266, 0.05493107056545635, 0.0465707300651458, 0.018688546373478828, 0.0314076283886548, 0.031871866179449905, 0.05286640232248653, 0.04273154555008777, 0.08302150759845973, 0.014771515833995035, 0.03704795456160942, 0.028786496860125375, 0.06948331671376383, 0.005797820443648004, 0.03431297470665267, 0.012302376149642852, 0.043396245568029346, 0.06382173926178968, 0.01839273109761698, 0.011731118748655484, 0.021797804229502237, 0.05095008700605362, 0.03576253563345921, 0.06287276699778534, 0.042599556261613485, 0.056446059231436065, 0.032788831289977796, 0.04523819289921273, 0.016206254874686563, 0.02711782521087556, 0.01238035911228508, 0.039366025537733114, 0.06878485137055959, 0.13838846687107317, 0.0540638858482482, 0.01688642795347879, 0.09504212427043146, 0.05513565817607507, 0.006964376521101523, 0.003691726714380146, 0.0418182346789587, 0.05503412854347018, 0.043160436044056574, 0.07486745925439943, 0.036087042817305175, 0.04439378397599344, 0.06861662612326684, 0.03653825328294789, 0.027945435741135193, 0.02534158907139734, 0.06665827556242866, 0.0948646063766172, 0.0618249808828677, 0.07186192012722455, 0.06910075538701589, 0.1136573636904359, 0.10323317466123451, 0.058057808632692026, 0.012489134021433852, 0.05611310592822491, 0.0575202064318282, 0.07525428769088562, 0.06380843231454492, 0.05179973980111461, 0.07907402506398578, 0.01597789459816751, 0.04871724331150613, 0.024574156662809755, 0.03658767744538285, 0.10489740108530368, 0.0696048872064679, 0.016437858575955033, 0.029040410956968705, 0.08545088731954176, 0.04677865398867477, 0.020895699309485576, 0.044876392555212787, 0.04453443771889133, 0.026376943494523727, 0.048933755080666275, 0.02847491166434221, 0.03433141827342972, 0.02745282013840493, 0.059529589939742326, 0.06035507649123188, 0.056280427191767006, 0.007819287552152792, 0.04012928276713337, 0.028876994826620626, 0.019784617095044064, 0.06806514240921506, 0.03896828417876556, 0.04078991102775739, 0.018169653954945745, 0.020489400748403806, 0.05896955668445557, 0.04147614577725049, 0.06766919752642994, 0.031653435360039436, 0.02968298635565706, 0.025931141609626434, 0.019453163408944686, 0.0425049712160422, 0.03186988967260526, 0.022531256808208364, 0.025532243457893213, 0.026536810722562577, 0.004281699403955211, 0.02233701521500705, 0.10373221199599006, 0.08599480208490165, 0.06223274267188484, 0.046227281357372, 0.024317195451247598, 0.08070353238332657, 0.01379963945627453, 0.01684438504819428, 0.022004611579881563, 0.023262535612429344, 0.015399852531000733, 0.02889497299498368, 0.019911877705805728, 0.04227024570648228, 0.04232493672339667, 0.03161229260806595, 0.014913221032569006, 0.0431773895698209, 0.05114425582090213, 0.020590346238966432, 0.07245696360065092, 0.017499639202029477, 0.07038501752240044, 0.0786268288990663, 0.04157258092515892, 0.14475779848233347, 0.16170527215205854, 0.06471472582028759, 0.1376364443210825, 0.22558873128746787, 0.08171243953608698, 0.10551617796262426, 0.08388209246820019, 0.37602304210585935, 0.11242435283718571, 0.15147399938394948, 0.15090217603550804, 0.1344847892441096, 0.06166995150007068, 0.24271998945022785, 0.14323380445280384, 0.2186406202494137, 0.08217449780673751, 0.10930604556755674, 0.13816418697036084, 0.21902030874644557, 0.141209585652236, 0.25927878075069, 0.1744678066742997, 0.1667458855456883, 0.19741989281629363, 0.09925455831351782, 0.1294257744185386, 0.14716097033552586, 0.23642210319878595, 0.06599871982489863, 0.09685440484674708, 0.15678876500216224, 0.2253837414806889, 0.17361826113154813, 0.20333913245028068, 0.14592767602974369, 0.27027048771419837, 0.08172362441978148, 0.16234235086989018, 0.11528946038696075, 0.10494677545202356, 0.08780492995415004, 0.21151804034748387, 0.16061776437826697, 0.1051667575994807, 0.2990928298283008, 0.16910025759810404, 0.1274757205899204, 0.11406676873805062, 0.13543317545085184, 0.12358887391465327, 0.111860282298538, 0.1250182254420173, 0.19797919828805233, 0.1331458207700522, 0.11206614544555066, 0.15572362699575965, 0.13035289402450287, 0.1723693692756276, 0.1321854223046572, 0.13352892601922636, 0.12388708130005868, 0.07806248256876584, 0.17562525827557812, 0.25583968948452707, 0.13811883456524343, 0.13130036092573596, 0.13130226082378818, 0.21105193713259315, 0.23765493785181355, 0.1165537506101593, 0.18526200084917008, 0.15643314698771124, 0.10795143357808552, 0.2308116582853179, 0.2563709408164986, 0.12564696912323275, 0.22030385842006053, 0.20210874927861078, 0.10106028117720159, 0.14042076023836292, 0.17800325647957865, 0.10913905372182209, 0.18055771537605794, 0.1310259482312587, 0.2838179559236573, 0.2829353000608183, 0.10296819250910513, 0.15267707918199802, 0.20773802463325763, 0.13144314439306337, 0.26157707516704837, 0.1532097860810257, 0.1352806626668861, 0.19009763975777935, 0.09823546985224371, 0.17630663219719164, 0.22095152447300576, 0.11956394755191381, 0.10281512048095466, 0.17400622337816224, 0.19778845771666498, 0.16067508307676162, 0.1326613774102542, 0.1561059048699756, 0.16785233101296812, 0.08904284377011562, 0.13235146420136576, 0.12430692046520211, 0.12495601144168647, 0.19705235447374084, 0.12019409317403071, 0.10412146127031696, 0.12889847610025637, 0.20358801909512092, 0.09988406042177832, 0.19039154172905032, 0.12941652007641333, 0.12440058237482464, 0.09760850349501257, 0.10078864172101022, 0.1429752191348422, 0.08827635748011452, 0.15336049089749015, 0.13986896242826216, 0.1281665173930026, 0.16602608465379284, 0.09308217258583154, 0.20250406596929799, 0.18622721034672954, 0.07325400913795156, 0.13328632129536522, 0.09251104637740121, 0.1153937939013685, 0.08566395935392188, 0.11185553255340747, 0.11586336749455622, 0.07637571783796435, 0.21807071212078297, 0.08970652106067828, 0.18904952422505428, 0.11416859714494598, 0.13185362962465133, 0.1442524562439611, 0.14971506150980152, 0.18632430433025285, 0.12270915982944351, 0.1737505338725544, 0.0909711100581673, 0.11665087523719958, 0.17129992585509055, 0.18098580530814587, 0.08066877497420197, 0.19705331974452545, 0.15520285574659226, 0.12530181586982744, 0.13521917645008336, 0.2042353787128964, 0.14026844663725746, 0.09493281118451588, 0.2026419005086345, 0.0561273513331769, 0.17776526360502168, 0.1604983772361471, 0.08006569523844989, 0.1338347942838746, 0.10667677052439221, 0.1843976391659629, 0.18417968715150512, 0.14334038260482973, 0.17897631071748274, 0.1437162559839987, 0.1503749849695352, 0.1596355477287885, 0.0925153594524149], [0.07494594496224197, 0.08088402269828705, 0.014326034748416035, 0.022953779196306583, 0.01638649812629146, 0.03895432988722478, 0.052817476117202354, 0.02094558695511472, 0.01649693353101611, 0.08101650994391212, 0.03235170535082298, 0.07710712496191263, 0.06546151598975544, 0.037343423182685534, 0.022167709783741066, 0.02120268989294287, 0.054993529713922934, 0.03324065079552031, 0.0365040359658099, 0.06986462931719518, 0.04910151684476484, 0.08537581070296227, 0.0131260882499778, 0.0316766229262876, 0.01098019170439652, 0.03559305017153102, 0.02110447359061049, 0.031249218642891898, 0.017810228483511076, 0.06303656425687575, 0.042375624930906686, 0.010906229745746862, 0.026668805756696293, 0.03154254413299984, 0.011685695480405083, 0.047279510782250476, 0.021068398510256124, 0.04948168031630978, 0.007258687391802068, 0.11489652622971805, 0.018760332642423532, 0.04566257879618676, 0.05556884642329909, 0.0538106210109207, 0.05954153325048186, 0.04774300929819865, 0.04015172531287517, 0.01745223176605519, 0.036391309958191655, 0.0561814907667858, 0.04369887328075786, 0.03412596115301694, 0.03411656891506526, 0.019977351410254356, 0.05382600788687987, 0.014789602212277392, 0.0375043131381033, 0.08911942957990593, 0.014913108034600175, 0.011011190494642624, 0.026078389454332572, 0.007924509249747762, 0.06282066152761541, 0.03597221006789515, 0.02000631336423178, 0.024388209886608586, 0.018848298688329036, 0.06538434795314266, 0.08047337658823499, 0.014130620083080666, 0.017639567076619116, 0.02380959516871841, 0.05109842078039243, 0.010249810180656854, 0.00810572064496697, 0.021380353343462753, 0.04402354134306793, 0.056920535787339174, 0.05442745202491361, 0.03285786347283471, 0.0553707437469594, 0.026490234491986134, 0.022253314363619974, 0.036517783413611116, 0.03598469730106092, 0.03793460174253391, 0.0901169296834738, 0.02499261686968948, 0.0514070546224473, 0.020878874103448564, 0.04516169901997332, 0.03861844629770325, 0.03744257794272515, 0.05298087501057214, 0.08065733728149245, 0.016784030726299654, 0.10184238799997877, 0.04570380581783191, 0.05062988523634211, 0.017164217180482323, 0.03686188329612056, 0.0714876095674211, 0.02015959798178125, 0.055406274904887524, 0.06859688403745813, 0.05263182236963222, 0.037725279708543134, 0.03245958202188054, 0.003740880112614363, 0.12419664210850194, 0.10744297336186133, 0.05120678774772152, 0.03365130456645162, 0.03566248072010856, 0.028709198588565476, 0.06040824299317695, 0.08135652274734552, 0.023162053605060906, 0.01608268680771993, 0.05096376550594165, 0.04941156794947963, 0.02254528196288213, 0.0878119396586572, 0.12479259722655821, 0.02980352454488316, 0.056367795689091574, 0.041631301564555016, 0.019123624942656008, 0.014169052799022006, 0.020988405524422566, 0.04536399219725882, 0.045649187579270334, 0.06972137853623399, 0.009596000102558925, 0.03606664189588159, 0.027937359259193464, 0.037374373134826465, 0.051443416985773274, 0.06270944854364761, 0.07432904500033587, 0.011990223091185815, 0.05225529015484837, 0.11307639325217855, 0.07428507155348217, 0.032024246813248725, 0.025684141456299735, 0.04534339209297492, 0.06310944603155218, 0.04738162264167782, 0.030575639665907914, 0.053781383265290535, 0.08891391883333845, 0.04339937120676041, 0.03998495180219893, 0.04685865655060738, 0.03797406676195322, 0.07276561276446428, 0.11197224604867159, 0.08762680685087558, 0.1118710381729949, 0.015624554737681344, 0.04180553677161375, 0.030724752934709675, 0.01182435930991966, 0.025798815242465467, 0.0879165106603215, 0.05317606272235994, 0.010872331312707356, 0.06732883232255137, 0.013263868205549737, 0.04400798592776541, 0.03770001412880036, 0.02679558947772509, 0.04392013479504855, 0.035054796795931556, 0.0604775318154885, 0.01599096788859536, 0.07760375678058594, 0.034236319948949163, 0.026668815332795345, 0.036669181539647044, 0.04163758731597374, 0.0076193151424729065, 0.037272774554308385, 0.03778731367821175, 0.06097708625959293, 0.06521292045832643, 0.03916660135972404, 0.020626302575692534, 0.0975765269850531, 0.05911324796597323, 0.06206939740466976, 0.05140982403029358, 0.04847472285731666, 0.030254099157548724, 0.05820990006829943, 0.05800848789212685, 0.008912113412553746, 0.07506474221666014, 0.02171150442483204, 0.024479242199431026, 0.010333383669926515, 0.0324612942283913, 0.02520785884811513, 0.03166492284846402, 0.020676582841382875, 0.039090283680707216, 0.057887308104264165, 0.032037705062858524, 0.022583482937226375, 0.03869587097377066, 0.022722119953663602, 0.020098481402401964, 0.028132466531749216, 0.07349354184923634, 0.03308159179024158, 0.03541642477014854, 0.014089864205508945, 0.03558496411349024, 0.09045931735947248, 0.026915022585120414, 0.011678200267675904, 0.030012250945512808, 0.008378831947582864, 0.046598209638989745, 0.03220240630569958, 0.06554904919598373, 0.06975711653790168, 0.045100113211740414, 0.03407149613204022, 0.010058013365543898, 0.050866851553080544, 0.030007755924617092, 0.06561143939653713, 0.04729057692231671, 0.0709898132951029, 0.028588436318621523, 0.03449887743279819, 0.00987296291221414, 0.016770714202955846, 0.05392173823389796, 0.04302507213827583, 0.027680602976151054, 0.014236802742215655, 0.09329213430323909, 0.03751390455891529, 0.03424842796859241, 0.054559770731195334, 0.019142281098832047, 0.05155702399450445, 0.03444631230987368, 0.07578731634684148, 0.05202049569737527, 0.00816097665172551, 0.02881103465634008, 0.03272100569560163, 0.09006134234368803, 0.06590207783325065, 0.06499482288716302, 0.02702869088088553, 0.04148292565538038, 0.029032213816178903, 0.028820664381548285, 0.0524806387482151, 0.06373234063146577, 0.05614919633033776, 0.05642890652281143, 0.054414635373940395, 0.0478244329532308, 0.03355452084853765, 0.08479573658757633, 0.02178980435635294, 0.02883870958260471, 0.0183083848171537, 0.02500182333131952, 0.03781064871638533, 0.03930074335526555, 0.02558126350894811, 0.03166714833388406, 0.06271375012734244, 0.048150828543810115, 0.020462354014237082, 0.03013117843487811, 0.07411927480490939, 0.04222819514031853, 0.011434184026814277, 0.03933134090696131, 0.05436739073165002, 0.020865867845714096, 0.056705755376887906, 0.009805462905205786, 0.07300761993974447, 0.04025883972644806, 0.034162695068986185, 0.016483797038334514, 0.08746827261582499, 0.05072678769788435, 0.07209437418608897, 0.059797571326095256, 0.09729390948890679, 0.07048945062823835, 0.035833984823717226, 0.04409599027806713, 0.022053156656423406, 0.025847454164778034, 0.04701058327731106, 0.1229531511724476, 0.018110182549383853, 0.023416862109555833, 0.08163476588144418, 0.02132576957885777, 0.06640928166527903, 0.05834804870368493, 0.024081816851732232, 0.034274195335925586, 0.018389356480310523, 0.010328831192436478, 0.023992044753545237, 0.1021066270468216, 0.0799220537526473, 0.026247671902960828, 0.03677694712795558, 0.05342348230882518, 0.022563127981078242, 0.030169201293779962, 0.006970552626186081, 0.025601459501851952, 0.09864105212111628, 0.06404989173695927, 0.031669517460789894, 0.012921245915124254, 0.02888863361741026, 0.022775479892809546, 0.02007673025101183, 0.12713480380273637, 0.07880236262515669, 0.02546860261880342, 0.07105401912403685, 0.08716870925479359, 0.04653707582263216, 0.03976644820443565, 0.025910055039510615, 0.026689528435048078, 0.06332354079331122, 0.030872186555737452, 0.040361464864784674, 0.05969783433923318, 0.025036345168407408, 0.029971546778875976, 0.03362734133618013, 0.016563826413344473, 0.03466081692867222, 0.3077226570777355, 0.2803966991843716, 0.22519600397396475, 0.1550411958728106, 0.09274745344995491, 0.13092735271540382, 0.0592324550774309, 0.10096381538577619, 0.14763350868898054, 0.24043979003064095, 0.13526238380901276, 0.14465678212863786, 0.15501092007804304, 0.19501632259738064, 0.13407007520717962, 0.27048269406922404, 0.17623059030982757, 0.10848303731050223, 0.08842827271549933, 0.13704470268660976, 0.14180112810384843, 0.13155716891971328, 0.10871473294232162, 0.16772110015153888, 0.15683733497656163, 0.16294394439506918, 0.11925675395515659, 0.10442187498894431, 0.08815116339152859, 0.11738314804050232, 0.23420705189627988, 0.10077677501906311, 0.12862895104673602, 0.10893198781676831, 0.13756794073889334, 0.15468973005490919, 0.0637612527897281, 0.12435142251272356, 0.12194688702302596, 0.263795298073561, 0.10999723307548032, 0.14801244641984665, 0.11403038722252655, 0.1990270227073662, 0.08773933750607314, 0.2083252616707356, 0.10956967174406014, 0.08939019569586362, 0.1610139237656709, 0.1254673751311437, 0.137947338122514, 0.1318728277880338, 0.2818799373363295, 0.10065794712112797, 0.14339262980126566, 0.20796446490191645, 0.12554092723275387, 0.22441223474039187, 0.13350454910147574, 0.12297585801852327, 0.1287273473797306, 0.08966967989239963, 0.0987703830844933, 0.16211819354324572, 0.10508950529319626, 0.11631958051434449, 0.12049315091703208, 0.11012952113824506, 0.17324667784475511, 0.139413982810032, 0.12684049580486553, 0.1334259331586861, 0.14588771688361324, 0.12961698996443904, 0.10696629813361554, 0.17685950253038638, 0.2587234589361376, 0.1094832570262013, 0.19220937644281696, 0.14563876895173905, 0.15119698199052967, 0.16294844899206393, 0.24946930067193127, 0.13698660257843234, 0.19300718040716267, 0.13633573427796364, 0.23305718456545185, 0.09039633727121739, 0.19411290575179363, 0.1103713904176989, 0.15264658888261165, 0.10614929600588738, 0.11376629373238933, 0.1680421829223633, 0.11232016487948357, 0.14400284947647204, 0.11235957244230856, 0.16954633527465407, 0.17649007961153987, 0.13029932915683717, 0.17324503841659716, 0.21665118184060822, 0.11610924341385404, 0.18911545375181785, 0.19779670082273024, 0.15283044998443898, 0.11550292312618225, 0.14608480066301363, 0.09909334277073223, 0.1524452150108353, 0.15010477043688297, 0.1275386317302623, 0.06786493299108359, 0.22552752086231787, 0.14304979013339167, 0.1732490220738034, 0.2631891386643533, 0.12568957893358124, 0.08658500388264657, 0.23229754710149383, 0.14123895746325293, 0.1217707863918716, 0.2637425912243705, 0.18364846646305055, 0.13519774130996198, 0.13540541242447593, 0.08876813230134788, 0.08275545292323636, 0.13819322170269105, 0.19064989722063466, 0.259608842071987, 0.09363137335786897, 0.14480097519774593, 0.2312583947974828, 0.15501727860781456, 0.15651373943734556, 0.11833317367540253, 0.19334099555928863, 0.168473168666805, 0.16236962359999457, 0.07872790653979586, 0.10274202803209906, 0.1644756912343925, 0.12019970093763645, 0.1055047632525525, 0.1172539473120724, 0.14791311545958444, 0.14521849311647878, 0.19322743068539328, 0.12161734664151747, 0.14703638911727937, 0.23430491196772746, 0.12206428233654269, 0.1686172238400867, 0.14084169490923806, 0.1232148468073818, 0.13917330862774005, 0.13761156178530187, 0.1900875886842128, 0.27763541187009505, 0.10337046527814481, 0.21416547167445385, 0.15651344832393432, 0.16742955773107468, 0.10375012313165974, 0.2859300909744155, 0.18290286372986533, 0.27835421684768896, 0.1896808572834538, 0.09563615650779779, 0.282040172286572, 0.14056712899717594, 0.13811160269523823, 0.11973902162524963, 0.1473602451263897, 0.1611567991635492], [0.052404742417556625, 0.06410488535860373, 0.047545082822081544, 0.021954599444964723, 0.027727142817551093, 0.10194484459897203, 0.08739601520280685, 0.10464378767797064, 0.10229502338916065, 0.025722876776971167, 0.03919742490735747, 0.04181715832542508, 0.0541126205315513, 0.014313340671510707, 0.051128187126690344, 0.04970124494584818, 0.021240994289156892, 0.024806712228324146, 0.033221310905871854, 0.08100312638787494, 0.006430929868421968, 0.036556620240932515, 0.08487507265301482, 0.024007820419125983, 0.05883990779458996, 0.03338514646935848, 0.020875805921311823, 0.024283575682690548, 0.07701368521778815, 0.02758548549947239, 0.04667147445762831, 0.03460584628966547, 0.022668221837750847, 0.02531921738878854, 0.023199655115604404, 0.037141650945188544, 0.028263595886528495, 0.0203786512476302, 0.08550776168704034, 0.02710995365745358, 0.03988490454972752, 0.018016009276071866, 0.08026748279770536, 0.05503132083122769, 0.02349875882388123, 0.036813160104136315, 0.023388545584654617, 0.03396565725486125, 0.006437837587474215, 0.037202325108791554, 0.04351897285349908, 0.055502779000709136, 0.0315896604555629, 0.016714852986737125, 0.050921270608781814, 0.03719538818263719, 0.03694321885104141, 0.043449339291621605, 0.03592002032805355, 0.03454687284125436, 0.08493827490676796, 0.06903862565635674, 0.08860652605372091, 0.03945000409599274, 0.014884049362022311, 0.027985814320404204, 0.016385343248745608, 0.05502158385371009, 0.06767077566755396, 0.034731423422213525, 0.04678547217120086, 0.03641069581311557, 0.03609658827284171, 0.016203016237986666, 0.07264461683770342, 0.01445468293593055, 0.04476156363624238, 0.05580637581466187, 0.03623924916610122, 0.021564963296236053, 0.05121871573670257, 0.034931770736171354, 0.04430302937004355, 0.039541961459983746, 0.04901659982879797, 0.026833551049592997, 0.03580683083724111, 0.057758498080675645, 0.049577621337507045, 0.01692357172648753, 0.04465987695561302, 0.055092998570011514, 0.009694816826301958, 0.026588370355086464, 0.06296778871347347, 0.060011240909056324, 0.06918759145323308, 0.07488858795935109, 0.00865910234185116, 0.013118437904443954, 0.08891218747462958, 0.08063644606379733, 0.0479765780149929, 0.02072841443511988, 0.08289621391844365, 0.08443675544713775, 0.03785873222495279, 0.0560418022946725, 0.036427296938434724, 0.020750177077828877, 0.005484623111589182, 0.026673643601938125, 0.05035909230730707, 0.03162489092398075, 0.04407703343238081, 0.062266186240219304, 0.10588766165798712, 0.03389938298853175, 0.03617950962976583, 0.037402434935492855, 0.05645623670951013, 0.015458980154606606, 0.08112621373466908, 0.039156270664065115, 0.022664335856754935, 0.04104075502724417, 0.028252479950747186, 0.030940916133864276, 0.024973803665488962, 0.03764082234533083, 0.03672574181109667, 0.012165580617053615, 0.06431920994674006, 0.023168821991871924, 0.04524723656715886, 0.0668593046946391, 0.04986092065190596, 0.016678693636711088, 0.020358298206701875, 0.0581314679866116, 0.016116287424078873, 0.02211161682592525, 0.07119544661573826, 0.04025580984870753, 0.009728003755181788, 0.025736413550593203, 0.074065656311089, 0.020849483140233546, 0.02866472335412137, 0.04202188383187017, 0.015835648349997018, 0.03590571363606761, 0.10009490314029879, 0.08921871457489268, 0.012025047533003794, 0.019572081322210933, 0.08310241414414299, 0.0505934615859822, 0.03131782947739046, 0.040024753900304924, 0.07027607981956775, 0.05857587942192632, 0.07321414192237201, 0.03424166341222102, 0.0071719705480180924, 0.042216309286173315, 0.0652350374167004, 0.015011038011570853, 0.058542493310186176, 0.02835847970639025, 0.02962259372936622, 0.06289346286305977, 0.02873767216149117, 0.020611465367819035, 0.019669156153536132, 0.02976047997963765, 0.011297391367054755, 0.020664459499981136, 0.030306309964808247, 0.026040565778291034, 0.02010546620905159, 0.05719845716450965, 0.12719484977424145, 0.06339596674567269, 0.048410601298054384, 0.08981375038743981, 0.020250839053563053, 0.015045161482938116, 0.06260189362951825, 0.02594440259159573, 0.012627559406081996, 0.0516473610825356, 0.05523736783934217, 0.02218257763513154, 0.06845882733262355, 0.04113360871410659, 0.018851705864372275, 0.025458206805670937, 0.0978929672630564, 0.06976290050172998, 0.05917919664493492, 0.03187112307416336, 0.0340567987352129, 0.011970661036039313, 0.05976091784935805, 0.029263484269200318, 0.046922345270192435, 0.06051377160474659, 0.0381800792961111, 0.04192493540505248, 0.014254422764474107, 0.03341718043591226, 0.011644844799452733, 0.022893304215563882, 0.013465856862885338, 0.10482756451012627, 0.0611070683977056, 0.06208986727400653, 0.0518073087498065, 0.042059560035986286, 0.08754701113268253, 0.02351121924396965, 0.025676886603656798, 0.04007043572322976, 0.0330228749812851, 0.021038046106696132, 0.03485251510996492, 0.052246725291854916, 0.017547083027180166, 0.0381675690803076, 0.08541554768359469, 0.03687226378749456, 0.03825120672944092, 0.023836245452384316, 0.04279174090873811, 0.0357447432414178, 0.05090801728769176, 0.01822546537544939, 0.06944374827247474, 0.028425219371133757, 0.02293650965927349, 0.024885864432660804, 0.048604804586859486, 0.027177246820722378, 0.022084811409454674, 0.020368178825705283, 0.0730752578425792, 0.020810525654064074, 0.11441944497487239, 0.07178156516484677, 0.03953951763950529, 0.07231960403582743, 0.059487286564563556, 0.04288320031557833, 0.0214959598416763, 0.044233545195311315, 0.029939062735666672, 0.06178489533222972, 0.02729943018376587, 0.043146313213172464, 0.022177988768465096, 0.026058285391979644, 0.07178928733112351, 0.03639648488212017, 0.025091961236490358, 0.023337663939943718, 0.027043731102058967, 0.03880246444755504, 0.00857679289765656, 0.03551572508689377, 0.005540568597479574, 0.019053884128469135, 0.01672191248695937, 0.023105943410266793, 0.03223419129367798, 0.04878517232775208, 0.005085918397056841, 0.053230489438940445, 0.03407530358902389, 0.046583190485234224, 0.07259481346174594, 0.06570796647499647, 0.047587815206497915, 0.0399660294304692, 0.04010767142678942, 0.0313796546880997, 0.055902902893121206, 0.03968630391623705, 0.026127340557474284, 0.028111722785979513, 0.06948737697976251, 0.04269902128726245, 0.08261399478801797, 0.02483666626616351, 0.04085911941083689, 0.03183171934177799, 0.02056909304472708, 0.03043709649524141, 0.06240636500860415, 0.06451997860905624, 0.05149311693986097, 0.03899218612200311, 0.036891055924277154, 0.05778630707232703, 0.02021151959084936, 0.032202287562071316, 0.1302124088209483, 0.0583211436957842, 0.01554010216251857, 0.04338172437142461, 0.05058042276951094, 0.017413427497470574, 0.04607938042271041, 0.0850720645018643, 0.06848829107419138, 0.06660599006159652, 0.02922994877031494, 0.0714333628815028, 0.03639753059213681, 0.02644905918127587, 0.016084630755827795, 0.005346424201683652, 0.051746021715864066, 0.03467550283418067, 0.05912079010158778, 0.06290896465220759, 0.01782392230515759, 0.023436749752070156, 0.04299213035753177, 0.0609212959065072, 0.1345805961999201, 0.03789569979773895, 0.044050438690089413, 0.07376796220459285, 0.019098629408906546, 0.05304222716198814, 0.07986525599394115, 0.009379975756840601, 0.07136066113748858, 0.028236443815272183, 0.04533127641245242, 0.07484700470682114, 0.07584229847716709, 0.017155077751545657, 0.038567463146342386, 0.017986721734726624, 0.017687907224641215, 0.05595390136624056, 0.008177099929701897, 0.006530176559012504, 0.02559019800936503, 0.006728872474688556, 0.11504747619431828, 0.1733200690679012, 0.1267352200023109, 0.07779176241808361, 0.09474884283037917, 0.19374017333311422, 0.21620954747401902, 0.1422832578781151, 0.1839239516806218, 0.16257323444850985, 0.1434945961039874, 0.1360492786813167, 0.12700695138905319, 0.0908745370144325, 0.1356657444229049, 0.1307533894695582, 0.14346035197377205, 0.11218935536641268, 0.17886397158426626, 0.10968260842585757, 0.10931361451624863, 0.11146585426984296, 0.191892599086127, 0.1708748389876658, 0.1233793565282418, 0.13977914628001953, 0.1548229221014246, 0.15546530214769227, 0.20392865242977298, 0.10564506459500521, 0.1534439025506858, 0.11219092584665745, 0.16916528314111695, 0.0992846425863043, 0.10080697420503824, 0.12097287517521652, 0.16431202421024924, 0.11565686849456643, 0.09100032099072011, 0.13822121455544426, 0.1684245374053717, 0.2383417203541725, 0.20116535796513482, 0.08557543789427127, 0.10633017702568924, 0.1106205375324334, 0.19732322784200793, 0.14454194554878821, 0.1340735072810804, 0.13758344635848077, 0.14986023517145267, 0.10100091702394909, 0.09289978237281885, 0.0811684558228139, 0.18338666357580694, 0.11803551787330259, 0.17202656025127058, 0.10848738868991215, 0.12038624334719875, 0.11029164066478131, 0.18184541724622252, 0.11286624001278994, 0.1665230305685151, 0.17151082986064498, 0.1312589155690324, 0.12462064879195345, 0.12282529875876443, 0.23622293566023153, 0.11802455515510614, 0.0975503804041974, 0.09080420248210432, 0.12173024501891867, 0.17112381756305697, 0.11238369655104415, 0.1251611161616541, 0.11375667166806037, 0.13243774102339823, 0.13463978415295003, 0.20227494439290417, 0.07439069975648196, 0.17440166264291734, 0.17783752101803982, 0.08450019518814741, 0.10404865227399335, 0.12377236729427693, 0.11795931510747441, 0.22450082514795566, 0.1806964998644206, 0.09243634514390461, 0.11980469068211895, 0.11919056395849875, 0.17357369013611348, 0.06434947041974914, 0.12203950705307147, 0.15479518971856565, 0.1290405700884519, 0.16400820906123809, 0.2908118483760665, 0.1629327288678577, 0.21007958769557938, 0.21832868456840518, 0.26848813819308437, 0.08768466181091725, 0.09764895293741457, 0.20478075670619167, 0.19037139361664174, 0.1761930979668133, 0.15626057802188784, 0.1511253987348849, 0.15222701784824172, 0.18010059071163978, 0.11765483346196914, 0.12804523035283052, 0.07583253851701176, 0.18944594408235244, 0.12146757645232063, 0.20460054218288393, 0.07537031936789713, 0.1940601376155692, 0.09158558152135342, 0.10216396872795398, 0.09372549492024607, 0.1511537286663248, 0.2579874629455228, 0.11983862837716458, 0.10993485053580616, 0.15422655329588922, 0.19543900394872313, 0.10691738341965022, 0.1976644893687579, 0.1884812555245815, 0.11948101853411044, 0.14593317654104004, 0.18071241917148714, 0.2235551049271899, 0.11851660576799225, 0.21360754516095887, 0.09553059725271118, 0.1015834043162965, 0.15363465844383165, 0.11768986666274649, 0.13517069840623488, 0.12053486440450915, 0.1567241684683869, 0.13275615780824615, 0.08446343828954044, 0.25348867289721966, 0.1449486922713057, 0.14471782401444452, 0.3682583732710731, 0.22796214828568123, 0.10145027355681505, 0.19277974422420227, 0.1627096593860657, 0.21901425665184376, 0.18662179159300943, 0.2667105690606179, 0.11936696336394358, 0.10587682151385855, 0.11841835499170328, 0.17684195911692036, 0.14347283920693782, 0.16648572208660264, 0.22840237305048974, 0.09568137867796807, 0.17472450741596762, 0.11554702680798308, 0.12186260969047585, 0.1921554591747061, 0.10358855518842898, 0.12936582037758443, 0.12484384084781333, 0.11655388084510643, 0.08183066222456195, 0.17938900228229263, 0.12140892476083771], [0.041306369201911074, 0.05326224761384149, 0.03575317786946412, 0.06296819090963372, 0.006310673695312994, 0.014535626828400119, 0.02407705753050264, 0.03792051338560639, 0.06688806363531659, 0.17873856299106153, 0.04528973529475831, 0.025659858384319854, 0.008569042003082653, 0.05666576941768008, 0.062277080010502577, 0.022585511155005907, 0.03657314475745924, 0.0826024191994821, 0.023125779341846224, 0.10243406834741754, 0.018418996422100934, 0.027684058032689557, 0.03668024384927365, 0.05139873873802924, 0.028635665639153415, 0.05536368807717677, 0.03857708521067135, 0.031121326009592706, 0.06482956240013724, 0.056129634275191256, 0.03610871161424345, 0.06630637307441042, 0.055728196541989045, 0.05567451293069509, 0.039576136642285896, 0.07837869302039185, 0.012296892875324816, 0.04641583091729591, 0.044583884863964016, 0.07117492312024679, 0.022213290100015944, 0.03490493467618381, 0.04094770598796107, 0.03197080451965092, 0.01545533357608703, 0.06090577113472166, 0.0855447484120246, 0.02961786313643379, 0.0058299166548456405, 0.015397860702397603, 0.039663922657529195, 0.022411814124713984, 0.017828966994138978, 0.010303167246973083, 0.02053112189676012, 0.026630930369719866, 0.038875690961797396, 0.007226076465280306, 0.025915046102337302, 0.02838595353457476, 0.11077792263559758, 0.053547515774205814, 0.02274615404706809, 0.03430039171249636, 0.021339436587426933, 0.03518277178368261, 0.030421790058514288, 0.05533882086315463, 0.05089103694885008, 0.03117683482536626, 0.05271392018203774, 0.027562077682946, 0.04050940027340286, 0.03796795721075708, 0.04248445155099035, 0.02892835910672382, 0.03868791515067701, 0.017593044472197374, 0.03256440200212021, 0.044979396907071915, 0.004558839371442916, 0.049276318956887534, 0.02391909786139525, 0.030684692281929236, 0.01590747771138746, 0.09618053858679149, 0.03694130363123071, 0.021992080296660145, 0.04702609272733812, 0.0406812223035001, 0.025507420293926716, 0.06043096516101111, 0.04823916231191928, 0.03970767393888485, 0.04149300354202429, 0.04416648568885942, 0.05592624942261366, 0.041841906795818964, 0.008525444896921756, 0.05063163191680947, 0.01948414783504221, 0.05813752774209265, 0.035133700021692825, 0.01999328603907939, 0.0847138877537462, 0.07479360837849879, 0.10559919891097855, 0.06698683535139408, 0.030379025115361138, 0.038411376562209866, 0.051507358514373346, 0.04576770904203577, 0.05995493727706133, 0.01521835576802973, 0.05753327206137681, 0.009198700201757734, 0.042932498073505784, 0.07044214469891402, 0.05871212049838036, 0.08453465382298155, 0.05983194952169734, 0.02598977223369143, 0.06341252573615601, 0.03457036492745242, 0.036414805874829335, 0.021579202955528613, 0.03305676671105527, 0.03100050819827424, 0.03988012799151963, 0.024455018499265277, 0.008177429347509339, 0.04119456249980196, 0.030008929954361052, 0.03896644556774728, 0.10845315222057605, 0.028375473451770605, 0.053834722137018565, 0.061294905495859926, 0.012855384378663957, 0.07532403999639135, 0.024113739735537, 0.021804938423297098, 0.09100878626228341, 0.010499844042163704, 0.013380977193704777, 0.04903099079045558, 0.06299588881853609, 0.06173901432644456, 0.0201107828592461, 0.0602547113122719, 0.02655457630152664, 0.04249442601576448, 0.03658599971282867, 0.09106807380674348, 0.060988374565157204, 0.02588264824401948, 0.055664446535370046, 0.025351496503478097, 0.04916884831242985, 0.067511031013583, 0.014710653978850574, 0.0233312709362156, 0.00938161135455894, 0.07624647880513823, 0.03148202127176187, 0.04139297544175098, 0.023210506751051834, 0.053051362760485186, 0.06530778512599007, 0.026118218365515915, 0.08523399250641947, 0.03396291082965271, 0.038489356652022376, 0.0364602578713769, 0.011216422576727647, 0.02720647882069311, 0.030843785761164564, 0.02561373989127817, 0.07052209363469193, 0.019629666236259287, 0.03552810889818976, 0.037114477806514314, 0.03613993735803712, 0.07537166768264386, 0.03876198053119644, 0.07974796793273381, 0.08352810622102792, 0.02193752717557213, 0.032503601434009696, 0.0912251984400134, 0.05527227846605163, 0.015951057580570062, 0.047249595048807325, 0.059771072344794396, 0.01494879432533297, 0.022999865130611488, 0.013608582873618411, 0.06065162146584161, 0.01733918017106912, 0.04928782559751023, 0.0518911762253171, 0.04677171706252041, 0.03090138025131197, 0.01983436492962703, 0.027258877319494085, 0.05697506975622908, 0.0029158989397523507, 0.03707169945682249, 0.0263241236473644, 0.07126867696042023, 0.06018642989558078, 0.016625360510642492, 0.0832713288705676, 0.03393836920299838, 0.05889119355068092, 0.024024132346253724, 0.007633840169517264, 0.030476971371700207, 0.028308394793120605, 0.022735700777341283, 0.06543818095158185, 0.022955286474297606, 0.10701930375709649, 0.1117049886154071, 0.03600083877362552, 0.05216796762279926, 0.016413161816496043, 0.021934692650252295, 0.07372540602039906, 0.053655093670972896, 0.019285340357812184, 0.05604697721860102, 0.015640894435496343, 0.01918975748271952, 0.034483678248380466, 0.019831436558536465, 0.02614472692291583, 0.07683088897817558, 0.007851357907882982, 0.04669674769825032, 0.015473506139260868, 0.025836725103398486, 0.006308769488016204, 0.013705244975074405, 0.030614748454442432, 0.03352790695404814, 0.07599879491833911, 0.054474780936875654, 0.03706940502348927, 0.035788751162228086, 0.04971185526359947, 0.06233629860704946, 0.030060236777869925, 0.04711307818070055, 0.06544895980867647, 0.06648533121352235, 0.029659206986487396, 0.08931834430944535, 0.040276471240025376, 0.03926372981720394, 0.026141195257584897, 0.10813948518085865, 0.02509352214063608, 0.046895907575925516, 0.04852120141168276, 0.047476594561650876, 0.041086080619284225, 0.04992069849263757, 0.01574845892572475, 0.0507822601244815, 0.038342378853309544, 0.0707588684294493, 0.051916177504726, 0.030324328352787325, 0.026223861890274192, 0.05629030972599022, 0.0359312703292216, 0.05040661274125019, 0.06734547175226674, 0.037629955388124914, 0.029628653484847278, 0.010457652707343862, 0.021487923579350598, 0.07750314645349018, 0.01048955069329109, 0.03237337414776126, 0.019510683205519474, 0.03829608416004527, 0.0461260007033425, 0.018097080530658848, 0.020597260182483063, 0.11565042569512322, 0.023581595911133676, 0.015553710756883507, 0.006554020566850781, 0.0668809083741038, 0.060118068039657614, 0.008089112816378474, 0.022632374668553955, 0.01737457343317088, 0.021382490728771495, 0.02349990987098746, 0.029305331822064136, 0.01867775985550496, 0.037834159954781496, 0.0032328697336432076, 0.0414039496512663, 0.05235400058389191, 0.04970025286198624, 0.11835957306527323, 0.04804141203602476, 0.06308147233099708, 0.03375951065531662, 0.03557322764649026, 0.04337292585161425, 0.040619751408455834, 0.05946087185293437, 0.02237697436113752, 0.06112135976793305, 0.018608015210878466, 0.03565333746073227, 0.049165098312040495, 0.0336821204532058, 0.05910723034532801, 0.04322805862513281, 0.04901243231048988, 0.040475474069676096, 0.050132943152059475, 0.03804735456322951, 0.11310457762691284, 0.05538708823282392, 0.03217877632367515, 0.04831629204413584, 0.0033825195033944425, 0.10282980638646311, 0.051387121014657526, 0.03287213569086406, 0.02119662630702219, 0.030428263501474456, 0.07259692786441696, 0.02616887018384953, 0.06536380147501346, 0.045407754969933344, 0.032271940276146896, 0.07380908580436822, 0.010704258325389557, 0.02129485218545362, 0.030491820070892576, 0.006417555888483842, 0.08683046611446528, 0.04233042574337414, 0.030078507974864017, 0.12833404550028424, 0.1403979921052533, 0.15852504199550999, 0.09970507930002867, 0.22068671852109895, 0.1238086415574916, 0.1528615071888893, 0.11590803042054178, 0.20774989899608398, 0.25808677858402657, 0.16217083910540228, 0.11852602098858166, 0.11616536701518683, 0.21136963379479226, 0.11976352111706812, 0.19801226264286428, 0.1379529765296367, 0.14547062797411797, 0.08196305753963609, 0.14629912142071033, 0.13222357348328637, 0.1713294662054508, 0.1700896295087953, 0.16798791325380727, 0.1291627151470992, 0.18727016244684497, 0.16252550717082717, 0.12092392215685499, 0.1021138052906721, 0.20715858637084886, 0.13487465138877594, 0.15873151801286206, 0.13339539689402427, 0.10743206426981958, 0.13382854300641245, 0.13803119410670575, 0.14090111268864525, 0.11288088761390218, 0.1922905664410322, 0.14366348784777427, 0.07976023300040154, 0.143253339694873, 0.1025627941013344, 0.09570462178559073, 0.16610698353859688, 0.15386805479084292, 0.1159074635154778, 0.29628566916911836, 0.092857034666644, 0.1971046629572107, 0.06743999168036446, 0.12723006683612062, 0.13673298151022004, 0.24805672647010898, 0.11339030544003172, 0.1462472113029611, 0.08432902050234618, 0.1448874512026387, 0.09467633260834603, 0.11807130184024574, 0.12151017094091063, 0.11871172070142724, 0.07248622049847919, 0.20591891821353667, 0.1476742339230353, 0.11734821443115512, 0.12041552322766474, 0.14598490279768744, 0.28283037665870886, 0.19803141484097128, 0.1593319777279131, 0.1334200802469446, 0.15144698712373936, 0.1770241961123482, 0.12078012745346754, 0.22771427287690102, 0.1434415521761102, 0.18509914587822654, 0.2156440979771076, 0.199800725545614, 0.15583008257371767, 0.17415646854187214, 0.16482352579553283, 0.09168580114360779, 0.07782849633405287, 0.28944468786639554, 0.17685216340807178, 0.18600954944568296, 0.12294591164156315, 0.11856358994038836, 0.10065551096152875, 0.15721307045990424, 0.20069185434089554, 0.25895895436406136, 0.18021210246989805, 0.21045167660040243, 0.10821217926399362, 0.10785168126946497, 0.21114699332223785, 0.17381900681122658, 0.16177792793079732, 0.15303778402026624, 0.15028060293726384, 0.10687704889043685, 0.14332182795530365, 0.1822594877692961, 0.2030926206780057, 0.25698566508869974, 0.07457324318707952, 0.1243561186316994, 0.12152209892989167, 0.19568068936707514, 0.1832330476252302, 0.252285776960273, 0.09599725971178663, 0.19566228793513393, 0.10499953592736876, 0.17843061096725926, 0.14025995838305644, 0.16721166700365084, 0.09930044698018221, 0.11808729775610471, 0.15888504203288786, 0.17826594802881443, 0.0731785264947722, 0.11597179957935888, 0.08630680671382336, 0.14304274212448828, 0.15070230369606327, 0.11337140605093972, 0.08352990652764998, 0.1861872358788406, 0.09629330672924558, 0.28654939645240385, 0.18004336394369605, 0.10526700786525205, 0.09898668034903466, 0.11290472827010578, 0.10492232192548052, 0.18870374277955104, 0.11686275217441783, 0.08173375210214047, 0.1582183003906281, 0.1323440637920172, 0.17766309811943964, 0.11699757598821195, 0.11550632455656606, 0.14095040278569346, 0.15884174274340754, 0.26996301066490913, 0.1377087170558591, 0.07091074536043791, 0.13521552987156377, 0.21883640167934282, 0.1630078054844372, 0.1347953459668544, 0.12378086320935719, 0.1922854642954565, 0.1331817043284255, 0.10342445149416886, 0.13816550464159058, 0.11743066847444543, 0.10363720943250003, 0.17589565666933216, 0.10280461741551276, 0.10502955891312131, 0.12771896882763795, 0.19845595012509054, 0.15351701798217912, 0.12144572762472015, 0.12335435907927253, 0.20318554714322093, 0.08144953348223241, 0.21651610521779907, 0.09350775741040708, 0.10580359883005581], [0.022266841561142958, 0.0890634208917618, 0.03379409952509788, 0.02445710034319951, 0.09309934061621467, 0.0606787333174819, 0.03696569204030018, 0.010442145172536615, 0.02489989150255438, 0.04002799828266425, 0.03409682299881693, 0.018194011720498244, 0.03985231899986825, 0.009448295477927934, 0.03535240663275604, 0.04603659441213935, 0.038291809389427785, 0.0064050643460734965, 0.04575487706930407, 0.04321351444589035, 0.03476327735810511, 0.020388941723673094, 0.08938774421450593, 0.024816324716554056, 0.041186560711432854, 0.03974518160365763, 0.010030956097668218, 0.07709635376569725, 0.07497270441343708, 0.03328955018772714, 0.02354344473250451, 0.08231284562498331, 0.012782957468692575, 0.029606438850262956, 0.0259796196534749, 0.09436875596762666, 0.04402593919827093, 0.019632586946470604, 0.03839312451741388, 0.05963919030862951, 0.02645810667966162, 0.02999326728674914, 0.047915827242597464, 0.035983709047638604, 0.07142700435173127, 0.09875415734225705, 0.03603107626399687, 0.05824885180880947, 0.008941151017713691, 0.003229653840178564, 0.033788043600056446, 0.01824100355377361, 0.04589336661381587, 0.044799228349039634, 0.025827959142324906, 0.063486150616119, 0.07801600401439975, 0.013238114244755239, 0.018355847794502493, 0.008632843720636541, 0.02527985770645882, 0.07479743881812019, 0.10602852224462456, 0.056240054358157425, 0.04137146369283719, 0.09648485935383266, 0.04932822907463678, 0.035867937840521336, 0.02103569804720821, 0.035965192702508746, 0.06606298694086653, 0.04466431643513422, 0.05225535910276156, 0.019999165763898243, 0.021289627465810028, 0.059871946972224026, 0.03343642456457019, 0.032707798339787035, 0.026083234960453647, 0.03552842682467834, 0.04399825661112705, 0.13590985067909764, 0.0677914115329904, 0.08298569298799961, 0.06916195815128666, 0.07059016054676426, 0.01892600873214824, 0.021161008964202577, 0.03799205833685495, 0.021366293714832396, 0.01851403345954755, 0.011904937395405386, 0.03549735429846952, 0.042228509236367485, 0.0466432671002563, 0.04501258383595175, 0.027337506668822422, 0.020021700240190954, 0.05354406454810693, 0.02475692417412516, 0.037309458674562555, 0.01075642029454391, 0.05832352239878909, 0.008587394596918697, 0.018269697376977534, 0.010365771952145284, 0.02995084516794211, 0.0405177123273813, 0.053942732873462865, 0.02600064302133697, 0.03294532390071019, 0.03517362086342708, 0.012235894081963888, 0.01306299324853406, 0.045017249311410615, 0.017198026555800633, 0.04791748199251391, 0.060155847665643504, 0.05237784124009552, 0.011261568138105495, 0.025775420832477754, 0.08312458472867167, 0.08517121926190392, 0.058036664605981884, 0.024624323930531263, 0.031195184546372587, 0.018113932549773205, 0.04734391962448436, 0.026669792094898802, 0.045028970456652107, 0.0002965456030412292, 0.019398142974222862, 0.01654070587978969, 0.10635808560877077, 0.010692732532568758, 0.02950667888076315, 0.021668549874917637, 0.024574382658747417, 0.07233742324094619, 0.03184996564091454, 0.045511533070596, 0.09518807934176537, 0.03629819197099536, 0.07252357494566711, 0.01762248140068785, 0.07725027615144368, 0.03313029199958809, 0.017245566141941858, 0.035612769274702, 0.03361342917947519, 0.01788518444124249, 0.08334854287245581, 0.049804735763539235, 0.06114842182385826, 0.06421049823984504, 0.031140257957421487, 0.019858042792146726, 0.031179428032989946, 0.0434810706534453, 0.019433191496758692, 0.012103789880300963, 0.01855178627245609, 0.019358294910841414, 0.0388042111280224, 0.04541913903648815, 0.0698623923404563, 0.019792572918137716, 0.03152669951950591, 0.054195936423756426, 0.06177406284898039, 0.001721543566447743, 0.020074393682842775, 0.03914561055059876, 0.051079521391300425, 0.04385957171419456, 0.016747584093302008, 0.0012146114562300125, 0.06806397795557015, 0.01805601438747779, 0.066184128424333, 0.0159553237326984, 0.03231934579690138, 0.013450062045106485, 0.008270992623311619, 0.04054442964374058, 0.02884895026293253, 0.032088632672844876, 0.05866058193327439, 0.03117430481999632, 0.03809615436400618, 0.09803043408018929, 0.05098825733688089, 0.013406918846040726, 0.02336279353907993, 0.07919180342146466, 0.06480143165155765, 0.06561484082692093, 0.05648664656966444, 0.02250422922623975, 0.012738377854768789, 0.04453582433803428, 0.03149338427089876, 0.006468569204556726, 0.034583974479427265, 0.053095799690533074, 0.02639770639249154, 0.01607544153117605, 0.0033959887655181514, 0.09439433564341838, 0.04749598041657479, 0.02284197057897766, 0.06302492355086631, 0.04673023340142062, 0.01720643628598942, 0.06041633671209697, 0.03545533054538312, 0.0444769811245703, 0.04707808711475903, 0.02348499796954134, 0.03546449678739713, 0.04312649068813171, 0.0263237482642815, 0.057827568567928776, 0.030796564101511915, 0.051619207351318294, 0.0796361803828228, 0.019107370472122586, 0.04345756707592838, 0.03473339992905817, 0.04052777872270635, 0.015275449428196638, 0.08526188576774252, 0.055649955982282284, 0.02974804828784639, 0.049866746750570116, 0.017973010676101814, 0.008048367472515713, 0.03330180759451563, 0.039946995975990454, 0.06190694462988646, 0.0312117780108125, 0.03610943556733189, 0.015222838339996676, 0.024136687899308822, 0.04659799130393132, 0.06571933521979278, 0.04908133042796005, 0.02679854083145338, 0.07685495946075648, 0.012442874759736081, 0.014970236168723675, 0.03746778223543398, 0.029973808653472416, 0.026315666036680344, 0.0431574521315915, 0.05908258146636429, 0.020008617373664054, 0.044407048788402355, 0.03865803389119045, 0.004085484655543922, 0.08124601456426805, 0.030846557084230647, 0.07360204288195218, 0.026019659238837423, 0.014278732649531337, 0.03735956848568974, 0.03341886965978531, 0.016202633194024527, 0.031114172663599737, 0.01762690747367038, 0.007698520494159312, 0.04517273068608296, 0.06648483325637157, 0.032187720400191126, 0.06712290788850478, 0.05091844757478084, 0.033240263921118555, 0.08841062971060315, 0.02773672274704422, 0.01170335763749937, 0.03714400283511608, 0.021462165788116477, 0.03893467590152737, 0.0343886143978565, 0.04822737604920422, 0.04882805409931368, 0.028912190821081884, 0.029216335387900475, 0.02040158025920391, 0.0722662843162975, 0.04471402021966154, 0.0323561295085857, 0.04178603600350119, 0.0691968304735999, 0.05469149954977536, 0.04644526018490715, 0.023872238178286823, 0.05499168344202542, 0.023555589141324166, 0.006805258144008657, 0.01330208833209209, 0.017224063969127113, 0.03779874754048163, 0.04032398784352888, 0.06078754078536745, 0.028166034589371378, 0.037819707706089944, 0.04513355294963525, 0.0261185554442026, 0.06126893894566644, 0.007724215561944632, 0.019278688799409617, 0.02505336572686511, 0.02467864147958256, 0.10326992389896225, 0.016866796950419104, 0.03684665729862548, 0.03314749067348819, 0.04298636171546194, 0.020116082272462307, 0.055384927864877455, 0.026760355178867618, 0.026412072456291607, 0.020571826063396952, 0.04347710231799753, 0.062304957950067144, 0.018132862582382177, 0.07393393515338821, 0.024096408911469965, 0.04019391760530491, 0.025279941976130493, 0.12647204581768284, 0.02677953035961236, 0.029741595912304138, 0.02628446710596402, 0.09151412083977654, 0.01905217383717818, 0.04841394527184387, 0.027381577791886467, 0.021003372967243198, 0.025960660892568772, 0.05429165144901603, 0.0062799214896175175, 0.04475799749695486, 0.07004692759965697, 0.046932974740141825, 0.06496583412010824, 0.02556600303749644, 0.040605218720532237, 0.06417183761274622, 0.0504955287361818, 0.0033696805879909306, 0.13199045292792783, 0.23971700139584082, 0.15805147708423678, 0.13899539236820516, 0.2099947204753276, 0.2598063395388665, 0.13424604560338682, 0.07075436383245454, 0.09087659779094881, 0.1712908400523086, 0.15548928069972223, 0.10516744707861256, 0.08812563734189158, 0.10537491901026619, 0.13282558069594447, 0.12439839902424044, 0.1764671276173284, 0.10768896419434779, 0.13424858901529543, 0.13987386539097757, 0.09740366690581846, 0.20546306525507282, 0.13806490197537408, 0.1136424556194294, 0.2953837998211384, 0.10684105807975416, 0.09398628657142963, 0.1810579707906131, 0.19407133782102218, 0.16788940966850327, 0.18830070392258708, 0.17497897118089661, 0.16423638068860577, 0.09882268390708393, 0.12596953044375106, 0.2478899797725101, 0.1436010670037039, 0.08450460785459127, 0.2035033663794879, 0.1051561089773332, 0.11315619663125086, 0.15773882128057942, 0.1803685682675531, 0.12369301590707996, 0.1355247842448373, 0.20156271244970062, 0.15161178795801056, 0.18486099978608472, 0.10212779405616945, 0.16947666723882, 0.15494764121549745, 0.12094764789986996, 0.21080288194840957, 0.17819951288402083, 0.09258199378006882, 0.1996722372789537, 0.22424122859393397, 0.14138287474070826, 0.15416065441264262, 0.13930628616963664, 0.15003677247272384, 0.13238489627838135, 0.1835320364203184, 0.1745904726727355, 0.12273172111881357, 0.21971158052404083, 0.08914158484267612, 0.10935008030144439, 0.15116931089470464, 0.1491423648211264, 0.1714024130976008, 0.1301340533480529, 0.08600908962468948, 0.14101628634718158, 0.08601616061623059, 0.19050149066794306, 0.09789468330000678, 0.14351722634127065, 0.1163573103446153, 0.1431182017850299, 0.15857937295109997, 0.23467595899297347, 0.21866974691229485, 0.19930993897780297, 0.13048757228159136, 0.22073314344931036, 0.16386793836230235, 0.07327287022264735, 0.08969253229518091, 0.12162586553923546, 0.1493089736228989, 0.058660627898549846, 0.21131107403386026, 0.13244589219891256, 0.15001166011056594, 0.15077586345855268, 0.20203901995574275, 0.1092862958208688, 0.11774906227665564, 0.12226726499296005, 0.19443020404827213, 0.1558656903404382, 0.06756731549337988, 0.15182589421108847, 0.09704981089359331, 0.10462622894274612, 0.14443322235057432, 0.2529465737602403, 0.21571802546180066, 0.094730916372951, 0.2190328266231283, 0.1058184685966661, 0.13029762844164527, 0.15757095609461108, 0.1253851202707137, 0.1308464231870828, 0.18605127059403928, 0.14023726685873925, 0.18201740398522348, 0.1370714085116502, 0.12914966100886946, 0.17626854230559644, 0.21864317898308078, 0.12337122833536518, 0.13381907415966834, 0.1046426538678427, 0.13657807853193055, 0.125826662706752, 0.2816077003315572, 0.13981876834746332, 0.10905027179227722, 0.13511336438598173, 0.07538980098381158, 0.19557336044888343, 0.13314539176081458, 0.11996563809413104, 0.18740107155134603, 0.15870683465994176, 0.14233771140777296, 0.154902886358961, 0.1421266541846337, 0.12680586863068805, 0.13123662241043585, 0.1938189731370057, 0.13772500408512933, 0.1731647217586156, 0.1432864500149604, 0.13000112177143175, 0.14091153148441546, 0.18710772116338054, 0.06512796896840296, 0.2271231594345262, 0.22652337387684854, 0.10456003128520905, 0.12866146381824248, 0.24025571442419486, 0.20529031242814758, 0.12164556932064796, 0.14203619452253466, 0.1327649371758584, 0.09014942713322179, 0.10400641784672776, 0.09109679444302475, 0.12345365939601777, 0.12305510215341084, 0.11667958055172237, 0.17732663230309564, 0.12249153723279316, 0.15432830509399215, 0.1603844446400481, 0.09439544647090858, 0.17493372602808863, 0.09021086738474908, 0.1684825455829982, 0.15278734987781895, 0.11007547363518708], [0.023124624464300372, 0.00406276200890481, 0.12742110618179844, 0.06464760885724137, 0.06058042891503823, 0.0330218714061043, 0.016189896982283365, 0.021104002446537058, 0.11907087804208841, 0.07329537788586271, 0.050917014990362434, 0.03672681816463028, 0.03905330844704182, 0.031179452930847486, 0.03675383808571966, 0.050900172547347126, 0.006470081749402228, 0.062985458531447, 0.007268413356805762, 0.05025359433925441, 0.018798671512594147, 0.036866744124000116, 0.03156849536143484, 0.03944970915214189, 0.05003262776881457, 0.03343292354275623, 0.01801984354613289, 0.03428336540837923, 0.022598580614994132, 0.00885594001550588, 0.09291060719518893, 0.034572031168687734, 0.0333919148561695, 0.027263948821552822, 0.07216693803427682, 0.01654114254990653, 0.0680674789773841, 0.005803015956189484, 0.02249969973138744, 0.06667447066114796, 0.09790752293361772, 0.04617725964635611, 0.05901500868100313, 0.013235424318531109, 0.07564755126593575, 0.056400469339062134, 0.010372750055525574, 0.055689827028301456, 0.0496630018366681, 0.08444055524324218, 0.015989678945662757, 0.018404502038573547, 0.04233188514086989, 0.06835679208198864, 0.043205547131477826, 0.0390325436338542, 0.025718674784706488, 0.016751987183646812, 0.029663060408746524, 0.04152909394413714, 0.05563538882040209, 0.042421509767131466, 0.01458162657781354, 0.027248357017073902, 0.06900857202708721, 0.04466402149128337, 0.026288948720321063, 0.03682603421170385, 0.11040999358820339, 0.036137221576345545, 0.0315870653327194, 0.025764063579000296, 0.03050128125675744, 0.0410860040104918, 0.03531012240977537, 0.04386341747557444, 0.028559108557660254, 0.062003690043404225, 0.020908155899134376, 0.01095782002178772, 0.02370651803850647, 0.017008996275704236, 0.0075966293638151505, 0.03017856671865429, 0.05091754742146981, 0.04545871513865648, 0.08199363210869413, 0.02164032145012771, 0.021155209678615776, 0.016082849601403843, 0.024653645945833098, 0.050491414844028415, 0.06958675390530018, 0.020883980079463894, 0.06115527448034095, 0.06254780399162443, 0.08384486825595941, 0.030183031096033035, 0.06328065136087037, 0.03170011501248566, 0.029709106123435403, 0.032702558298384955, 0.03691639811281235, 0.017115520801575437, 0.015729269380831433, 0.03060528726857757, 0.050346267995454615, 0.042168321538596384, 0.03375528568041421, 0.0860975421364269, 0.07323940750211477, 0.014086635144908103, 0.02052983678426714, 0.036170274439838626, 0.04755921714428452, 0.03580259820145946, 0.04197992136581771, 0.06990691737061547, 0.041884531927925926, 0.1195382453020542, 0.012470003848354663, 0.03807980604770203, 0.02639448307755013, 0.03824128206038187, 0.05369229873101558, 0.10099111875939755, 0.04876406660543815, 0.07413843466389565, 0.028504942310974005, 0.01641604996797058, 0.04270006699727909, 0.04302786835919946, 0.006724408576114765, 0.036787327619329575, 0.06524939390440142, 0.03196380439124281, 0.04543636835390522, 0.05885711795980892, 0.062167697976673805, 0.07670509734100874, 0.08807493764306269, 0.0721459778686685, 0.04564871260475728, 0.08162157384738808, 0.028656587500365514, 0.028313006642424775, 0.017792167960696163, 0.04255567857575032, 0.057660377539333806, 0.05098327010449383, 0.1490466497958668, 0.046388711404776385, 0.029637227923939788, 0.042500367027617274, 0.0792724724798914, 0.0897061839819916, 0.02142895970703854, 0.028943899200267853, 0.027802213688471147, 0.04338319142979961, 0.05072639316260334, 0.022493620823708274, 0.034087384795589794, 0.07172614636440432, 0.01899897477649633, 0.013892822560944386, 0.006261958643012951, 0.047986709527791514, 0.04403330513366288, 0.053893193797839266, 0.013028769228126735, 0.06722357950263447, 0.04019297148671843, 0.013669272358979911, 0.03231320943262789, 0.022361805820236766, 0.05558737425974781, 0.013613708001831848, 0.019693969741403576, 0.02195787638606083, 0.07949356545483874, 0.013869351542164243, 0.06212886881023165, 0.06955421815115599, 0.06838858473084627, 0.02236605760821652, 0.0320906053492499, 0.0157276883668777, 0.046500816881175966, 0.037814551934359536, 0.034463196887724826, 0.042558846349317225, 0.07286504331615663, 0.04578533289473384, 0.07070721112071507, 0.017914203851814234, 0.049074853154560255, 0.04798639926218218, 0.054990220214090044, 0.08396475335523006, 0.02240625998726295, 0.055714230759129416, 0.027752994454555938, 0.002180456447662906, 0.0587311884268157, 0.021234532337515585, 0.060309344872591965, 0.04654630335168012, 0.0256311952046329, 0.06234782056943063, 0.09324731049878944, 0.058467244323823726, 0.030785042139130737, 0.052608284318158706, 0.048810981829921087, 0.027341350514982498, 0.04541962167188045, 0.02950292696515399, 0.05749708972871304, 0.04589433571504009, 0.014722103162878945, 0.055867030826066776, 0.03758714639491612, 0.030804979577360135, 0.028164552209237893, 0.0419942012447263, 0.021994947380716764, 0.05336237530554495, 0.013040484627708794, 0.07751632316578781, 0.0909476294632881, 0.037778718171701316, 0.04485114612766812, 0.07294873076100504, 0.03792634714514979, 0.039775978338213704, 0.03989349239535871, 0.053159201127146526, 0.024849465680158427, 0.019070981295719262, 0.04293288111746792, 0.05821292994603996, 0.02940274181685621, 0.0378101775723119, 0.018266362979287104, 0.02873652877526418, 0.056799310034201037, 0.034547378459284385, 0.019548204276830922, 0.013037368565076783, 0.019405194813565865, 0.030619352642867356, 0.04723398983778973, 0.05946169922789259, 0.016494759756530968, 0.0449267398535965, 0.020685369869874373, 0.019853122592453035, 0.0652702238350626, 0.06005948146564826, 0.050398511361450925, 0.007825362629392336, 0.03718308864101287, 0.015245626582914304, 0.0794844490085398, 0.0025793785396437613, 0.038582091595256524, 0.031723360035328135, 0.017199187179005915, 0.02848015936662353, 0.03823308491959207, 0.03164248604838166, 0.038361446781744885, 0.043080770560810645, 0.05447333686113839, 0.024295151271226428, 0.020107739574966893, 0.007190030113223099, 0.03546032926908905, 0.03346942380190857, 0.049855002622690894, 0.014107453584250425, 0.034642997723553455, 0.04048979991386014, 0.059432262299402114, 0.05914278448589387, 0.014607725278173965, 0.01980173149927249, 0.0009370122549420734, 0.06244824320498494, 0.05638059318786668, 0.04576432293341045, 0.045909067585824, 0.025181367527693514, 0.037877497548658046, 0.03053963736390635, 0.00968430226954121, 0.05029670976763291, 0.023929359609140985, 0.05522246359877529, 0.047842091279885465, 0.04564122409529744, 0.04369369835682935, 0.09696139668625209, 0.0434399240710322, 0.033837237936114116, 0.013969280051007388, 0.10331660163618865, 0.06178640069500093, 0.029762870173961408, 0.024160099546274832, 0.03612407167712527, 0.08689750646871906, 0.04757805524634258, 0.05519150215531549, 0.05904834882746782, 0.022679446941061367, 0.07103296702787762, 0.07077945321197472, 0.04321541051350294, 0.013997131177494604, 0.03443502400430941, 0.042081002836986896, 0.02024726908383591, 0.014802551971027448, 0.03174293932745294, 0.05464619694037303, 0.08217705654040461, 0.03370776907691071, 0.030492858120029977, 0.029135409690019105, 0.02199094265609259, 0.04138193228432248, 0.02035710885519943, 0.04976348192881673, 0.08097919380112041, 0.101238182114978, 0.03579540080541084, 0.03671098695767503, 0.07378739785523185, 0.079872602777135, 0.01540131958937573, 0.034608232653549606, 0.022736558795816476, 0.03387482604011893, 0.005487969958208381, 0.034969385653253526, 0.005447250469813063, 0.032013038946916504, 0.06080881504702473, 0.015622273710886798, 0.039054411613652786, 0.06927241270820941, 0.06264085686134716, 0.30533558839271147, 0.2630526217962465, 0.1297898040783982, 0.11166635480138565, 0.16201582887480337, 0.1130414289993144, 0.19868424432652615, 0.10071381791344575, 0.12308750767260791, 0.17177745910181155, 0.13608741453818737, 0.18732457001122738, 0.10835019000355275, 0.11581860497714051, 0.12398712472209047, 0.18821150064468387, 0.10141152482960494, 0.13336654602279588, 0.15849571614976854, 0.15770230953010822, 0.17073977768661516, 0.1611983058072867, 0.17719150971501105, 0.12771029671233508, 0.08100754671519803, 0.13402813955420448, 0.22517012552388255, 0.07516596541409531, 0.24117200154690976, 0.24128784936281944, 0.13824419719317269, 0.11826463178881716, 0.2196392158587133, 0.14524006615242652, 0.15188512812939384, 0.10256813373416664, 0.1125763523422422, 0.18055986042224592, 0.19603598562459792, 0.09215335992555465, 0.11297736872708607, 0.13092911471762966, 0.18783043318938827, 0.13946154154837132, 0.15387986786663532, 0.18773251183090672, 0.12291693053538762, 0.1727124234481204, 0.20318733978896372, 0.10239897385960627, 0.09156508866937892, 0.23372222549251973, 0.13434781272324825, 0.13151759281754494, 0.2555746383844845, 0.22611500304793158, 0.12706221697191078, 0.1944614297920658, 0.1542039996673984, 0.13490828264865184, 0.1342862039323776, 0.13094310348312702, 0.18803585200540482, 0.18745921762479892, 0.07441076359921887, 0.20611696726372167, 0.2059601184221045, 0.11596638333773422, 0.10606724798919694, 0.12622615457662653, 0.13335153069947997, 0.08941228201072063, 0.2084367274637184, 0.12001589346196383, 0.1574692655835421, 0.16481041037026914, 0.10250255660784822, 0.10732255966192293, 0.1787212494039728, 0.16781503785281413, 0.08278609644020758, 0.14849921868693444, 0.19869218099742167, 0.17200397597926279, 0.19885129745929472, 0.12315137642285517, 0.13449900783598423, 0.1790377662907685, 0.2111642149787757, 0.09246392430917871, 0.1229952630256453, 0.10917199550256615, 0.11427817070075583, 0.15780663538363673, 0.16460361259598888, 0.12882663237471736, 0.14055646505326996, 0.13521860954501938, 0.10394752100710908, 0.11181185788084423, 0.14911644040576874, 0.08139586902313656, 0.13931747105333114, 0.07661548803650564, 0.1366411582116158, 0.08980427387981646, 0.14681529614233202, 0.14707167512707173, 0.14047715963134844, 0.09180740227982884, 0.14320755828051798, 0.178612434275208, 0.19232215990702953, 0.11769075532473865, 0.15191059289199693, 0.12635918574467783, 0.1730905031605113, 0.25067212000008554, 0.15450626731880251, 0.1481692033309129, 0.0873610356281842, 0.1882208162738431, 0.122907477010402, 0.13641752182475983, 0.18846956502285697, 0.2365689928973875, 0.11587828322644196, 0.16585628892625534, 0.1198419608596352, 0.19856309518218043, 0.17839380810337682, 0.1719085673891729, 0.1992249338617248, 0.1095908540751665, 0.23702363543693097, 0.12070401661819029, 0.15025932101472733, 0.14637749221536422, 0.1114225703021211, 0.20907817288271843, 0.21968196356488814, 0.1544511243100128, 0.08665104832259879, 0.17299973706324256, 0.15324956136605433, 0.15216269710611913, 0.07633660138855058, 0.11558334703647322, 0.19257072479494158, 0.12996255690532346, 0.09211621998298554, 0.08389228909847238, 0.23053882373196466, 0.18447086184976563, 0.20774393883203307, 0.17563043702994624, 0.1613135254310985, 0.13123504426931182, 0.41169583436942875, 0.10734629306581714, 0.14925706350514967, 0.16413441438588405, 0.2061810428577085, 0.13115480422012268, 0.15626243195466458, 0.1258292597448153, 0.14066855903835068, 0.14710774254654685, 0.10760274865934927, 0.09311617922879036, 0.14976902474318782, 0.10385948218285077, 0.14650461684551933, 0.11102324697158991], [0.047443407632771044, 0.08889500412248796, 0.01911467320526079, 0.02649079948183029, 0.012938812311228006, 0.020572927314788103, 0.03003841859378642, 0.011688236019483978, 0.05069299938998396, 0.05134127448282896, 0.07232834509904347, 0.034384753314718124, 0.08317836410095615, 0.019963119411841035, 0.06446570894050022, 0.014950726782121967, 0.039072790062956275, 0.011607377354295985, 0.014700261038547803, 0.045950562738242655, 0.06159685522077545, 0.030394741409127752, 0.002982210313465687, 0.03408931150671936, 0.032722304214633284, 0.031124715948657646, 0.0867049579298304, 0.03322912500269952, 0.06737624550418508, 0.04171086745637079, 0.020123415649117484, 0.018873640876864235, 0.025093317212116335, 0.04416434830355068, 0.03804668040585615, 0.032054790738789786, 0.07464255116158917, 0.06579631173442449, 0.017979265784003565, 0.041307487690280524, 0.09421283409239785, 0.01412321488568259, 0.03986740710153695, 0.03252780598197733, 0.08107003650718159, 0.04380950020746358, 0.020286783898970293, 0.08304826704965484, 0.06809704997126134, 0.048007535628013076, 0.0035713070293798325, 0.0770079318974768, 0.054267902723363334, 0.0431879845658137, 0.028339771839279323, 0.013678656936052346, 0.07495183617837968, 0.044418685663972175, 0.044072505852748314, 0.027641074754477992, 0.012259097927580438, 0.034669692057275006, 0.0496599757893672, 0.05883353394305995, 0.06452230751634606, 0.06734813773824323, 0.03064487677728457, 0.024190256597414136, 0.04800549400369487, 0.015112368461315431, 0.026910523733785077, 0.031498425129440524, 0.03620762505658692, 0.030556475976482037, 0.05434628117889647, 0.0180323020510015, 0.035244135426417474, 0.05002081086258254, 0.027688440055616444, 0.015257805465690553, 0.055247185256091826, 0.01666665264976121, 0.015546486547757542, 0.0075107422890141615, 0.06824646009913377, 0.06268930809211827, 0.02499463934180958, 0.043585664637747316, 0.030857414465337515, 0.033253130367806846, 0.043568370202856685, 0.017456703804313176, 0.03227587030719846, 0.08961491226669281, 0.0894515976429947, 0.04355834977280709, 0.03009539446793497, 0.048109138038970774, 0.012308459845371546, 0.10672386960997697, 0.0377264901274635, 0.022992104659938527, 0.013484883614094749, 0.014690932960459783, 0.05236323194337949, 0.02967473941915218, 0.03234801280702795, 0.03560291738399575, 0.01790220116926057, 0.01160924469361142, 0.03349460894241929, 0.02806178342941548, 0.04570364876980743, 0.04737017345764945, 0.013344246150565245, 0.011041699946227094, 0.03454452861220606, 0.02187838710303749, 0.043637750955719146, 0.031965811541604425, 0.031347454097422386, 0.05577670522935449, 0.05551923456932268, 0.07752704839672774, 0.03397886461067585, 0.011646932389046396, 0.016722638355267626, 0.03970428016938029, 0.02302535862151173, 0.03159237049159504, 0.09835501021194844, 0.0365399195241832, 0.09581329135764992, 0.029283262744185426, 0.05898117440782728, 0.02962210151787487, 0.024949283106252555, 0.04487964842889098, 0.026944953640322053, 0.035916465680084886, 0.07177914432700604, 0.023066671828048366, 0.023857952553718805, 0.03228001484286881, 0.02073111872549259, 0.023610027349223534, 0.035045128766327135, 0.05729302305788283, 0.0477953139512289, 0.007533426152452106, 0.02413677025376068, 0.06009836808868474, 0.040774727165098154, 0.0626880402166036, 0.06955564307469515, 0.12778678293069526, 0.057595110678624724, 0.002952544755610307, 0.026216059284765395, 0.048465047166832996, 0.018496604959270167, 0.052637931920828364, 0.006489298107372898, 0.04756560631757302, 0.05070578922787982, 0.07610193333558499, 0.048437073466277895, 0.03170521715806136, 0.05981051055113635, 0.04778813953781801, 0.05342551627226415, 0.02049094441557123, 0.0774909962990111, 0.029557658201684395, 0.041480006860388864, 0.046811840917554595, 0.028082691884088903, 0.01523628509828761, 0.045611702897135294, 0.052438163003253366, 0.04788036503258252, 0.02782341900221523, 0.08841390856691907, 0.06865295401263623, 0.037826817002027266, 0.04234524571426934, 0.031014282459152803, 0.037990480195730925, 0.042607711267567454, 0.028411975626142758, 0.0256374234994573, 0.030787574059720484, 0.0412980686392515, 0.030767134833900683, 0.0224023491084095, 0.06024715002445925, 0.0433575619582928, 0.023102754569281975, 0.0894656630172845, 0.038060918149928895, 0.053960567400340116, 0.029656412680783582, 0.08192512086562573, 0.03527307439775717, 0.02554332875015755, 0.043797319409467524, 0.03865194349219242, 0.028300444715686386, 0.01568613863069444, 0.03525302204633913, 0.03916383195187777, 0.006132182391029933, 0.05853728774274069, 0.013864817259262406, 0.019828155787000735, 0.03928712997285109, 0.05632851070033447, 0.013125347059911058, 0.020595975069990082, 0.12844979372476378, 0.029385795951971126, 0.0536552737016351, 0.06547354357016665, 0.014184500004405217, 0.034915579467891686, 0.051557058468461044, 0.0376256921088263, 0.03860999251745882, 0.06218113898930531, 0.048933333732307925, 0.0415384823516492, 0.06580700632184744, 0.047570892324250554, 0.02786267334745536, 0.03008750184709507, 0.03775263287787957, 0.008971215180692174, 0.032814246256865805, 0.06714546151699559, 0.029365034969223124, 0.06936600566991875, 0.031164669349128683, 0.039903792447500655, 0.0380491778524893, 0.035151159165487174, 0.021069930686104684, 0.043871266046358694, 0.03185898824144275, 0.048609358979569334, 0.015841233130965023, 0.10483332549131687, 0.0030674756600356273, 0.010390108650279863, 0.024542743227474635, 0.04183080235135652, 0.017548777996712638, 0.08763112758676853, 0.032415079974359086, 0.0397009170433927, 0.03437045811405105, 0.02122459426191786, 0.02799418000053735, 0.014667454280800398, 0.053533542330466935, 0.03456971375271678, 0.06482106648505696, 0.031035558636029883, 0.04126421138343792, 0.021955863490039786, 0.013091083777497613, 0.04923458631721236, 0.017349734947445895, 0.01253918158791719, 0.035621495016159556, 0.05464059683764654, 0.08913732539381712, 0.039985794498915636, 0.029486846779623342, 0.012493712354391333, 0.02943876901671531, 0.037006627948534106, 0.060666820650259336, 0.03738883687483688, 0.024845238790036212, 0.07854671142394505, 0.016377408493069873, 0.05179870558241683, 0.028946749047346176, 0.04385772161185742, 0.06469355881093972, 0.05305795494707362, 0.049021269134696455, 0.03701819970663037, 0.016477794739447774, 0.028486408728865847, 0.03292018089503531, 0.03424521039931044, 0.06998964720555852, 0.02931651287531901, 0.03305958591461663, 0.04432456027115545, 0.023428426206772848, 0.03172697788555055, 0.032666747518364465, 0.021651289913983598, 0.056265641694828394, 0.017813206650316715, 0.02404755356931879, 0.029421170061874776, 0.0391878028430285, 0.08791934518564133, 0.0244596763138449, 0.03619975350316494, 0.05992840382180387, 0.039625047525811585, 0.04424499437933968, 0.041618595996330825, 0.02868419539393677, 0.020083651855407704, 0.0201189800000359, 0.09224846208047482, 0.04755888006559784, 0.03557362984265051, 0.0916817025732129, 0.018463138408297976, 0.02142974877760055, 0.07047471109657519, 0.051768376161494566, 0.061265257893190275, 0.05376979618543579, 0.044755446424167004, 0.0651243606942796, 0.023010404585229776, 0.02977721900078318, 0.011958433315157892, 0.03764212852524173, 0.01642244105647889, 0.07279441000953799, 0.024389002787610217, 0.016928062916943626, 0.052823083880808086, 0.045631705452838255, 0.03141104897123671, 0.008013365872865243, 0.042159844775714224, 0.07276824044604456, 0.09930073809359344, 0.03660602908160898, 0.03534282670326291, 0.05008812700848907, 0.08575719991518606, 0.05959796328698436, 0.1384007855648956, 0.158448908177595, 0.173531080325765, 0.11393645718213051, 0.13706036152378206, 0.0906931120722044, 0.16112273889443568, 0.22346081482546948, 0.1626139596825646, 0.15427869324001575, 0.1970941369091311, 0.12090765044934328, 0.20300629789069777, 0.13286330286533604, 0.11307506025919031, 0.1578615179225322, 0.0815539972315873, 0.12921984998449204, 0.1373391715629447, 0.2051176974970487, 0.17998805239556298, 0.080576108978881, 0.352719015171451, 0.15551814689270912, 0.12506769940016732, 0.19629035745897602, 0.22690445665390263, 0.09278459339252404, 0.14887887654044937, 0.25825522599681733, 0.09659814077519602, 0.18538593855356017, 0.08603583375412611, 0.09754776804437561, 0.11930117173300636, 0.0741078754165961, 0.07442793929048123, 0.17149077367878732, 0.13410548379103984, 0.15619173736101197, 0.23574987636698833, 0.10884325951337816, 0.08206029707986502, 0.2860287324555459, 0.10930131114418469, 0.17797652001102127, 0.1149682320594307, 0.1429396726551556, 0.0985678217764343, 0.17363450219554288, 0.10365584069081854, 0.26106765734091886, 0.12888044239051882, 0.1713679084974912, 0.12846249546254837, 0.23382413050820752, 0.1406230687374069, 0.1232314019674255, 0.13320303221623744, 0.10431747252662336, 0.1231788713184576, 0.1105736835949844, 0.13305865528602756, 0.18637328799213135, 0.15488805489674692, 0.1436335338099349, 0.1629637094635156, 0.1380014392517267, 0.15542975566800565, 0.09296587277804652, 0.2095783057232057, 0.12663341457805327, 0.10135661930807176, 0.1976885751730973, 0.18355550935431836, 0.05214390480109761, 0.1796892014963012, 0.10847777428646242, 0.11039772085965642, 0.1219500816096702, 0.24488841664166222, 0.12596135628559899, 0.10352559808281162, 0.15224987791190225, 0.18501204168123586, 0.12074736187294607, 0.10351447448615106, 0.2015022527907164, 0.14263368181643948, 0.30422077724529856, 0.13790455977282218, 0.20547687015946836, 0.08039676013492769, 0.19697409093139634, 0.19299907519692377, 0.15702180894872836, 0.07634768668081492, 0.14994517900049686, 0.16652828593167568, 0.17817820031796733, 0.18288536628167476, 0.1274353094519146, 0.19122155202973276, 0.09401630955718218, 0.21546120214606487, 0.10969214622051486, 0.07522765081375837, 0.15473376478879683, 0.22700194900314655, 0.09417613848082482, 0.16733952707821326, 0.08555881378631439, 0.15562861677139037, 0.24121275742448148, 0.12172154226009885, 0.14877082749960885, 0.10409983460821452, 0.16137711072881378, 0.10706845595831833, 0.16688649332331074, 0.2112927185671945, 0.13056220456717477, 0.3718627250242618, 0.18907434547380095, 0.13133532517860014, 0.10806025636772956, 0.08510748074660379, 0.15089158870039449, 0.10800740396183346, 0.17019772451491127, 0.1454146116250946, 0.16573690178413547, 0.2233711212512947, 0.11097209528088571, 0.16902672847913158, 0.0920358190553323, 0.13107923730727167, 0.0907969706120991, 0.12802880542773393, 0.14035555083424817, 0.12652863673264944, 0.08399104549279136, 0.0873027439980257, 0.1228818130649386, 0.15862955171014034, 0.18215769000591772, 0.1624164468939266, 0.08868495813540875, 0.08119463304718656, 0.1697276223210558, 0.14704608779040076, 0.16215639068715035, 0.133676260048824, 0.1197017361259749, 0.15985233528960138, 0.22289731119188572, 0.11968420037338812, 0.11045660237751662, 0.16286569617448315, 0.1924061997523231, 0.11016692921158769, 0.1852584615229599, 0.0906758597721496, 0.1556661704014386, 0.17114076342794204, 0.14152818629818578, 0.136554145945176, 0.09273668225373953, 0.12518736233393993, 0.14421373816026797, 0.18464087208192195, 0.09936586322803652, 0.17960471732001151, 0.16300685553541108, 0.10717904075018822, 0.17352769421713968], [0.0496494344195291, 0.03765894798561931, 0.03024811218042047, 0.029071738207412344, 0.05776498301495468, 0.02858186711467082, 0.06487560428438649, 0.060269473826572786, 0.03822095391731109, 0.049180500509758154, 0.07892610880756572, 0.004875343330504914, 0.028385229581486315, 0.02039712545792422, 0.03164954363338409, 0.04632768867116782, 0.033381266234021996, 0.039704858565763126, 0.02093455337378527, 0.0012045809712764178, 0.03855372718986004, 0.020947599851135767, 0.02777124841457173, 0.060745785163054546, 0.06561920752808933, 0.06532932751842084, 0.04899417260481466, 0.007242846608747759, 0.05933371657926229, 0.024419023858142958, 0.07475474473810004, 0.05325978847160455, 0.018364834005854303, 0.01502017935572733, 0.01915941465525858, 0.09000387808848774, 0.06366498618116302, 0.06436790249520732, 0.06305455583177748, 0.018010010807624748, 0.07473985964973127, 0.03815758695465423, 0.0797570767181535, 0.030158776752350312, 0.01577349850952986, 0.07899802148101792, 0.08879175845293269, 0.041950430811172536, 0.06211979832920817, 0.057907816277997154, 0.0409220113989807, 0.030769500130366896, 0.04121025964137047, 0.10054159368718825, 0.03698205567836281, 0.0369987870386291, 0.006458921284760319, 0.07184420051353593, 0.08611176072830155, 0.021058841563400724, 0.02206715308280001, 0.0611230336700476, 0.04628960261001222, 0.1045952253644505, 0.03747916247154917, 0.058507555870399366, 0.0100974592327651, 0.030704294556691766, 0.055013271799731644, 0.021610934317352313, 0.02170044019998562, 0.036506096742326216, 0.07108663148697346, 0.02520884135587802, 0.04412603241601779, 0.027536794866224932, 0.03609492969248564, 0.03594890950367816, 0.07126361311924073, 0.08936643164845244, 0.013021803573675215, 0.009952347815757798, 0.016974683197575714, 0.027965281248813676, 0.028687453182834773, 0.02530135221839432, 0.05237550850236609, 0.046981935419382594, 0.009814792898513619, 0.03089108594482945, 0.04546092913275765, 0.05341381427922076, 0.024097538891158277, 0.07370787792869153, 0.054060668278966224, 0.03110423650322182, 0.05886230820549592, 0.05285047535454074, 0.04120085208166031, 0.0781781618453322, 0.06175607893495791, 0.011212056833169153, 0.028893762576063315, 0.010739844067082291, 0.0054747314800718625, 0.03224340350096745, 0.04571674121243339, 0.027612859736226743, 0.06506167938031497, 0.044487825099138484, 0.12613695129872332, 0.018468828526355566, 0.03401243075307819, 0.022704107311343955, 0.04511837291741564, 0.03482436520918723, 0.06855056636155614, 0.018341977772633397, 0.012697346185544326, 0.033196704161743966, 0.040038666057009856, 0.05975702995314233, 0.0440558587621537, 0.056049206534460674, 0.006390866342811816, 0.024700312191740643, 0.013807398969337586, 0.016003254023681007, 0.07904015631685335, 0.028879306496932145, 0.01566073323990549, 0.06720569901048176, 0.05539148940794891, 0.03189655910846928, 0.03528794799480708, 0.10192081242078736, 0.018382149508162852, 0.05213779141946186, 0.011530320400432234, 0.031185623769077565, 0.025769998845193657, 0.08163871889513347, 0.03167117795636577, 0.0714717515473885, 0.04061517020266864, 0.009340219624010066, 0.022427061189626975, 0.030029936085244822, 0.014522624401105268, 0.042183229609602885, 0.09988105735711514, 0.038931872019724506, 0.06672457281139589, 0.09218947331030523, 0.10111776075416035, 0.02995178554086916, 0.03307865001261234, 0.07041274224438014, 0.0363647228767795, 0.03237671812155074, 0.0588194226034947, 0.026178656957082214, 0.05745368701736293, 0.01644473038463583, 0.012325192163247737, 0.05030544700040933, 0.0628021719955629, 0.018404634188740485, 0.06187750770139599, 0.08288938041415908, 0.03351846492038139, 0.031629181016356714, 0.025121036188436613, 0.014253114669343397, 0.022768996873750322, 0.010018294579499673, 0.009529209684490437, 0.048187853573190595, 0.03935363023511825, 0.0218667559731271, 0.0495856844129101, 0.043022632148237004, 0.051879052883915366, 0.07580128212970111, 0.06318601268914438, 0.06239785760220501, 0.03268905982915913, 0.030728288430480227, 0.00959663787075589, 0.058620228251862916, 0.05064836710751538, 0.03458349950491421, 0.009353148315342204, 0.015929096712610655, 0.04673743079746923, 0.03888031430242043, 0.02574244649299691, 0.03839418937962863, 0.027888459866986643, 0.04163942209655239, 0.025820579800394275, 0.021846468049672343, 0.031131304304806456, 0.004433915807655262, 0.0481145657719143, 0.04443744332679818, 0.04323660433592816, 0.037696049623792215, 0.06960884788103643, 0.01740405058127738, 0.04029939259071985, 0.022506245952700416, 0.054850776890112515, 0.04683404980647949, 0.052556163526230285, 0.03620031274734967, 0.06247170464766603, 0.012330792265974227, 0.039827103215840556, 0.03335067634320548, 0.024163818903147213, 0.004558582253183329, 0.08116010546443925, 0.04762446102235587, 0.02710475575088734, 0.026138134736327395, 0.07476645056158304, 0.08435336677657981, 0.006575508375516943, 0.02012226268679144, 0.0009570362371666688, 0.021721429093891097, 0.02655807540812079, 0.05530620466977839, 0.03669000380942899, 0.03931000152783048, 0.08718888034983989, 0.02172581303203779, 0.059603613185425924, 0.03386988477300733, 0.04053684154285058, 0.017815405322659402, 0.04414600432820378, 0.027222991845900976, 0.018887987788466197, 0.036653017084444725, 0.0077459839503130614, 0.014643762054132118, 0.009966309768177811, 0.1151152213494624, 0.06207999623110218, 0.017986016933836283, 0.008919587557865007, 0.046167174098832954, 0.0422341859478864, 0.0029913892438109485, 0.02887943098621984, 0.06954105676061685, 0.05512819647969258, 0.059602161448809414, 0.030475628802612908, 0.027525788097972834, 0.03343669269534369, 0.05789920544972824, 0.046426119478119, 0.01974953601377145, 0.02610507229673526, 0.08530171467892586, 0.04401868817606761, 0.06136027194799916, 0.0027275885429023016, 0.08274600705912999, 0.053757626878758596, 0.010661637023722213, 0.05125864806975569, 0.055645654398587444, 0.08336765676616661, 0.08648310652783803, 0.017572145593623002, 0.03193373352499499, 0.005182064346773851, 0.00244028163104949, 0.03890550710381039, 0.045635578027295495, 0.025026443481986082, 0.054422043444168185, 0.09414362570931835, 0.0487799859125047, 0.010032467206098862, 0.03183285315190593, 0.03924954952972551, 0.0947600890011076, 0.020493943649794788, 0.014537015362762877, 0.02891661114840498, 0.03157831277818449, 0.01305244804825634, 0.031392777774242625, 0.012693695776585131, 0.04469102992105388, 0.028575499008800236, 0.04215945407087284, 0.04639084879008513, 0.015491773505815336, 0.02700238533678555, 0.018707953295820666, 0.04897953266458166, 0.07226319698196265, 0.01520337204584071, 0.032388140492501764, 0.009618622678962928, 0.07825321547927395, 0.0466774499434377, 0.031295264357580774, 0.009485349235605569, 0.04482029193651773, 0.010461464952377063, 0.04395683806750082, 0.01817143702458951, 0.053206319364929394, 0.05932782536312457, 0.023226483514712706, 0.020302053946521015, 0.01794364652596414, 0.03468838843306707, 0.0766621198084566, 0.07864090959511458, 0.04218421786302521, 0.019070224783894037, 0.06305135358425398, 0.060602679938798955, 0.05156352808098159, 0.03972288844506106, 0.045556778223404, 0.05320740337934225, 0.1361114543772513, 0.020233383740208322, 0.036036503996940396, 0.02810822559460517, 0.02650663834966479, 0.021874238736927513, 0.00825683436086101, 0.12558180568439345, 0.03410927575802611, 0.04385138989516324, 0.06743163366111056, 0.03131539331779125, 0.036674260702585025, 0.038308046622982914, 0.058320178424999605, 0.05238972326380111, 0.029162975448754527, 0.1433154234602567, 0.10275216337533728, 0.1677668509223769, 0.07416637389049416, 0.07804785795029133, 0.2437257709642572, 0.10622612696381346, 0.1127487910731185, 0.12512733168419332, 0.11747130943882851, 0.1550080855527232, 0.09143262440639158, 0.11172188085413749, 0.12753877728696794, 0.14726036258282202, 0.1516515785647977, 0.12815695661570758, 0.11295374257550125, 0.1615298686609153, 0.1010413128401964, 0.2663834801604671, 0.10571663252889149, 0.17568110608525817, 0.16892085512799604, 0.09364217519760133, 0.11996848794120936, 0.1318336653733446, 0.21976284712793367, 0.12555377452724403, 0.15750639020435273, 0.1344697739207937, 0.12279703777523772, 0.09102419995131994, 0.09610581437065717, 0.14654805403082602, 0.24608639429413506, 0.2808832875903576, 0.16078688594843113, 0.1937804389144144, 0.10489704868485851, 0.2268257028152866, 0.08859215424426141, 0.12582591960146544, 0.07278398355288852, 0.1471976659470989, 0.11474477953367657, 0.2586147050944067, 0.0987637411021898, 0.11684294880157518, 0.20435064430198363, 0.24126632229214717, 0.11769601068789921, 0.12755494174217025, 0.14542644002264546, 0.1352980068974918, 0.12016512738961367, 0.09755483903591672, 0.2064288110141793, 0.15375081269491106, 0.13586491196145936, 0.1310375621241908, 0.23598224615618107, 0.09359608734807662, 0.19606494374813574, 0.129328511895672, 0.1619710586965084, 0.11621034403722133, 0.12553154265568142, 0.20192458174161373, 0.1307542321662749, 0.11832563537022761, 0.11824183301219057, 0.13686424301516625, 0.1360656729628963, 0.19392279337250418, 0.1501246887229143, 0.1550918649281225, 0.11427895977131783, 0.12437782190259426, 0.167444649663183, 0.11154587215353405, 0.19169025994356603, 0.18738090811717897, 0.20173954086438303, 0.07557114931724726, 0.10782083090875419, 0.12832508227157016, 0.11000757526245811, 0.16853946591577224, 0.12722491872526948, 0.14162333441838143, 0.2103430912980149, 0.14073153146572653, 0.20116998513619747, 0.12989105025847114, 0.1541968903714611, 0.17040069184957013, 0.11445498379367976, 0.07200928480033914, 0.12022291340174214, 0.19040312497846543, 0.21931336802099982, 0.09525233879685403, 0.1569914105798929, 0.17236454292170464, 0.12057544408185829, 0.2015311036619448, 0.09234733338798247, 0.09376764507783998, 0.1255302709497271, 0.31277948089184304, 0.209314480363842, 0.18378207219704507, 0.09821730590755902, 0.17828327693766166, 0.21411504776727772, 0.13105185732485788, 0.11584770099650468, 0.10072815141850903, 0.1287181083593638, 0.19927290628754324, 0.15646185996311326, 0.12082369487372138, 0.12834544488859753, 0.10536485261494115, 0.09206980271565338, 0.09552057682266159, 0.10296599383676246, 0.17104792889327775, 0.08298856581771567, 0.13880195516732433, 0.19691128704336383, 0.10242948714163035, 0.16096161528220101, 0.13523852783105067, 0.22071973691063546, 0.10456666560663332, 0.13656569855107417, 0.1492171196807777, 0.15062397886668483, 0.10591662744240415, 0.18876322184599217, 0.08018985510833802, 0.11582593643857587, 0.217201340222551, 0.122568896791387, 0.16107283592704805, 0.13586884965339016, 0.1285498601294333, 0.1468527884853463, 0.23005655606187161, 0.15716295298789779, 0.17589967097005538, 0.1280736522148213, 0.23079397697602552, 0.11705016026333456, 0.15108660404239932, 0.28330982512524056, 0.16641413883095788, 0.2587380146066989, 0.14169730786834994, 0.08670775415075403, 0.1898021290018674, 0.11409931215307406, 0.10491038627562024, 0.11452243783541265, 0.13565391602535404, 0.11360925336879109, 0.14891486735113207, 0.2523318648097977, 0.106408417585396, 0.07840041927392445, 0.08138338178997079, 0.23826546396218964, 0.06397784882855993, 0.14486593945372492], [0.028825452431075038, 0.046045408253708196, 0.010447848697132882, 0.0651735435390184, 0.029718915879305814, 0.037829180383273674, 0.03991615710659854, 0.03515410094311641, 0.02896700058162453, 0.07716449728656201, 0.04208802403281293, 0.01819845120001945, 0.079464546044267, 0.055114307305625374, 0.042743113477744406, 0.03135948742349302, 0.047910043278769146, 0.04061920365558998, 0.06534687859276611, 0.05285013061497481, 0.06988683054524084, 0.061555796738473646, 0.005892832104432127, 0.031558024854729735, 0.05427025461329087, 0.021060109438915408, 0.0694776936283996, 0.036228857183408354, 0.07241512753910596, 0.04732656007212016, 0.06216677101028543, 0.05163870045855161, 0.017321902973156784, 0.00977527616815942, 0.01560590145433502, 0.013877235544514994, 0.033458533862064925, 0.031011823316915866, 0.04471441092450292, 0.04805212577564582, 0.012595123243367961, 0.022755588419855605, 0.03620532296237446, 0.024711608158184156, 0.03566508158861149, 0.032283048551048965, 0.0614378460112118, 0.033230262643267075, 0.01931138734723772, 0.0747651711947495, 0.04556696336235731, 0.041386042346036246, 0.04977956211434738, 0.01901751410426392, 0.01784888911060989, 0.01293886881021242, 0.03133630177246467, 0.07830301885523143, 0.10438357059273029, 0.03648050557521563, 0.11609228988808971, 0.02307973745759697, 0.011560166228352296, 0.05970765175598283, 0.10383484479520591, 0.0621095135988247, 0.025192839694359613, 0.04249678939701088, 0.05024361221360103, 0.07435686931374573, 0.018055838187255206, 0.03819872970662771, 0.03640293151200299, 0.042786094840736165, 0.02849389532310588, 0.024861343873424396, 0.0513094780035317, 0.09617124594026998, 0.06764469803461144, 0.036785320468967965, 0.019067024451590354, 0.025892731876322822, 0.041837157050688425, 0.024967895212372946, 0.026501139753588268, 0.012136404158457393, 0.06865400355309248, 0.0604547483606204, 0.026699405223611864, 0.0693727089392562, 0.09974202005973748, 0.00804715705359535, 0.019643480716753873, 0.03134239791712213, 0.034184256613615065, 0.04685330159601666, 0.03343352492177679, 0.028665769064138015, 0.015261559296519527, 0.014595185376463399, 0.05383634241297842, 0.04994761116141754, 0.0387602721551253, 0.04265619697229516, 0.015202903774596993, 0.03858760359787172, 0.040177419901855534, 0.08086865497452599, 0.03726600999793699, 0.044611107798353325, 0.013302126636488304, 0.03817450600646196, 0.04920097420953455, 0.0073906273633662254, 0.030805875900231545, 0.09423800008071047, 0.05347590187504407, 0.0469032964939552, 0.02326397394250718, 0.013050848839714402, 0.023459033334567666, 0.010444066138006749, 0.011418380590546276, 0.07110344711691141, 0.057927424298419114, 0.04497791069649881, 0.028135358513663375, 0.048721954752240455, 0.03189620287758449, 0.0422371928429892, 0.02960145161787589, 0.03321137857593356, 0.02311874473948152, 0.05843407271670238, 0.029789853705874378, 0.04201673189057939, 0.053146518541560064, 0.03316334869352079, 0.047456469431880026, 0.07915135397906266, 0.04432169510231865, 0.02920881431970385, 0.06734498911687443, 0.052435140786392075, 0.014912127442057095, 0.06491534126501891, 0.054942990893558155, 0.045551128324962435, 0.11295483808123297, 0.042517060083487344, 0.03000983010767208, 0.04763237854105331, 0.06434210065391756, 0.012546898008534505, 0.021772940845919714, 0.023191482872672142, 0.04546811120704778, 0.056577795710895336, 0.03601225731413692, 0.021924789048611157, 0.030155631961421143, 0.007212668011385588, 0.042977793022028865, 0.0892207217252543, 0.03444732354593373, 0.0617562742873786, 0.04696181412005136, 0.010190509229658112, 0.030589412011566664, 0.007289800616431862, 0.010179536935362605, 0.02974864775164714, 0.08292455917164203, 0.02063691289344382, 0.016477685571918567, 0.015524233608777005, 0.046375255070386395, 0.04095880277154427, 0.05839716643095017, 0.019419323390109405, 0.04981674419175233, 0.028360444721916032, 0.03798221793746756, 0.036121068612462094, 0.029632022356494304, 0.040740659235105406, 0.11307774922780453, 0.011540155054160185, 0.020563337809195923, 0.01659072376036596, 0.04084234208529515, 0.0867036862238761, 0.046357244343286565, 0.04685838458939426, 0.02433627295578199, 0.10515628517755579, 0.04911036516029028, 0.10302721192279171, 0.04554059078556396, 0.026361261674713705, 0.09443836271642678, 0.0493981575803651, 0.051488083742198446, 0.08506249606369004, 0.017435199716278625, 0.06843697084414382, 0.07185516323173238, 0.07039816359118109, 0.023518851394915295, 0.042802964096828815, 0.03282457695252473, 0.028539000664867704, 0.08392664814187635, 0.02869907473664611, 0.05380598234853918, 0.016364086224066637, 0.016013394154968764, 0.05210854984339207, 0.06771730784807475, 0.08713710046703778, 0.03030219032699543, 0.04082023278780041, 0.007968487005846035, 0.05554759897471917, 0.048120847692893404, 0.02302365599110002, 0.05367888453146143, 0.04082041664890224, 0.044211317154188315, 0.03576221004609139, 0.017436159241403786, 0.06623657480362924, 0.022627705362655466, 0.035037387447852286, 0.09306893458649998, 0.01796489205932425, 0.08893383711936975, 0.04360307781626621, 0.05242757949857943, 0.030052528018131856, 0.052297176012108405, 0.038369111491427306, 0.046999329445703376, 0.04277549601430374, 0.04981974725641551, 0.031175034518744198, 0.027226818455082756, 0.05070702262943791, 0.060307353043988834, 0.029238919659908262, 0.04776405756391826, 0.010432954990274964, 0.009679385900287139, 0.07880852963294714, 0.03106630749009069, 0.04443805619713761, 0.02203997611368616, 0.03705206462332318, 0.014893253908432541, 0.022117668920527064, 0.06202397222119955, 0.03638276807783592, 0.028765818231829235, 0.006560793262906373, 0.041746616949357336, 0.08532925553980374, 0.09226576034580508, 0.01866907241844362, 0.014992583911084842, 0.03397796445736482, 0.06752960098486754, 0.012404900738939404, 0.053712036986384666, 0.05115300071455779, 0.07946617015066647, 0.026067884473670876, 0.029041424108248566, 0.07287432064091967, 0.0783957921028618, 0.01829440562775539, 0.043028622955804875, 0.026507163119892922, 0.04145004516167026, 0.018271807949208928, 0.034293079403259104, 0.031274202685322494, 0.0271085076664965, 0.013759588379593147, 0.015567714844139354, 0.05721652917864342, 0.024259765670003913, 0.06470286677921973, 0.06203484300884509, 0.02519450018993549, 0.019335383136245995, 0.05923504828505459, 0.08744303001871995, 0.019405696601156267, 0.042738241158545985, 0.034612664472191565, 0.04716093186289073, 0.024189580524820956, 0.02433539195466907, 0.08812187585018336, 0.022860908272465872, 0.06232077000482429, 0.03337411097280922, 0.013313297156034219, 0.023745343374509006, 0.020457684708338593, 0.022913348906102683, 0.03910388557180282, 0.03906771473045792, 0.05926075436535382, 0.059834688286026644, 0.0031449103910070396, 0.05895114759163511, 0.029804468748249838, 0.00801784317797771, 0.05994875494751239, 0.023525508698977293, 0.023608163840347723, 0.036952266349427165, 0.03695991573735111, 0.04154327806205519, 0.044438971672207124, 0.032021712977439165, 0.01527832608835231, 0.02881341527456478, 0.024887122732076435, 0.01897820996330871, 0.005145771410166016, 0.018544784228828166, 0.02508084913114867, 0.035768120414427215, 0.018414131763781753, 0.055672996076605016, 0.0775092521742467, 0.05021921614365232, 0.05256480882845579, 0.020678118847671057, 0.05038196003184684, 0.0880428155763976, 0.026176479352157445, 0.043733006328224175, 0.03892370169201205, 0.019640893254789616, 0.05098349993087111, 0.03713102913611839, 0.039906753377328, 0.01516490198311306, 0.0540272859976657, 0.10595473265575786, 0.12776347853603864, 0.10295275583743088, 0.17043377152614056, 0.14076441195943665, 0.13633829301163075, 0.10826978141502028, 0.1758387363365581, 0.11216991205489445, 0.1411587174140638, 0.20378976068910093, 0.1238942442221507, 0.25109821810357036, 0.17329458898353964, 0.14382917734403766, 0.15683091515975614, 0.21551465976142117, 0.1484394331853236, 0.1165713093453838, 0.19654636872151207, 0.21807006860692657, 0.1663582144124854, 0.15544477099132153, 0.10153215303416215, 0.23996389621207792, 0.1302434966689156, 0.19080596465256908, 0.09694676440689834, 0.15115814133276864, 0.16788136574529833, 0.20346987301543837, 0.2124530353373097, 0.15336061347155802, 0.12975526883477165, 0.12854344031262782, 0.10802616545509909, 0.1443504235677181, 0.19530188953203542, 0.08518788167425702, 0.13698533087247802, 0.13877796129353587, 0.25124792700573323, 0.1015507766316014, 0.3293781240861262, 0.11599779294262971, 0.10954899503098381, 0.14116417196008468, 0.22461201514928575, 0.16444756048581294, 0.11945202210617643, 0.12109587059145975, 0.15658081809599556, 0.14291819154975877, 0.12433676725073207, 0.1472978549258363, 0.1357473481085993, 0.0936901169799028, 0.16061736601254634, 0.18058806777961794, 0.15842044035032873, 0.17875912479094921, 0.1591817478859617, 0.12472601652505899, 0.19731352916888653, 0.15861136478281793, 0.15426455125693353, 0.0789025362821356, 0.14504249207675457, 0.14659758927601, 0.11541692975668177, 0.11183479455329719, 0.1476717671199191, 0.12749004643410444, 0.12297223442264142, 0.11194667403375912, 0.10579752375281627, 0.135468170347233, 0.17513905291355428, 0.10059079951456479, 0.15406532243134516, 0.10274971189397959, 0.11467478208003506, 0.18949184807077532, 0.07431555419198929, 0.11027192156161032, 0.11318893156825535, 0.19565303359300862, 0.15062183382049685, 0.12034515039094033, 0.19189468284528102, 0.17468422651290896, 0.1315341556384679, 0.14965136895977682, 0.1690521472764592, 0.23713900827832762, 0.12943179586962347, 0.2435214246713346, 0.2845839212738699, 0.1364747485927036, 0.1947141775200444, 0.16525972093785965, 0.14200093915625928, 0.22892573367684121, 0.13284980439611022, 0.0928184314961395, 0.10832123954089419, 0.1655598128995588, 0.13559863512073794, 0.13447849200137202, 0.14291587796422744, 0.10402872632708281, 0.12442929535022668, 0.12350070485544783, 0.16236542543816954, 0.13955714932132152, 0.17780650977886495, 0.21684855673341982, 0.13103832821211508, 0.13238845092635002, 0.13807205723658686, 0.18524496305373409, 0.13335065735924628, 0.08022062119937713, 0.2794475162461881, 0.18658432989351212, 0.09408949393658869, 0.09718433593309696, 0.21153775945065484, 0.10632331287788768, 0.14413771159466238, 0.06036582470480954, 0.14617090894570275, 0.13487573923362842, 0.12024927448721663, 0.2785186499597565, 0.1999571300562351, 0.19904919329189485, 0.22261931320592282, 0.12954039649376947, 0.16312388312672416, 0.14708472926530147, 0.11971688934511716, 0.19638860057438576, 0.19294811502820064, 0.10154625671284814, 0.14895272741635002, 0.08329556789249183, 0.14738641468988312, 0.285361010220743, 0.21897391446175116, 0.13012086131399678, 0.12184922613443867, 0.15461993944500724, 0.10389344286053412, 0.15979388278097878, 0.08496697256041151, 0.1661768047920158, 0.14011749667265724, 0.11137108919360947, 0.12000808702601541, 0.1212935749020788, 0.21094018022619912, 0.14399583211108563, 0.17862279178394427, 0.11768268841889598, 0.13673978437098766, 0.1547122990051585, 0.12734319503989913, 0.13696771085021958, 0.13813339023580476, 0.1164949763446085, 0.21474903148989524, 0.18455867084764666, 0.11466844653290127, 0.08995934539744932, 0.09931879478596872], [0.04531380194689959, 0.020188628883671858, 0.048322853587207296, 0.05539231678290714, 0.026143319236354965, 0.0133827171709028, 0.01121480134315789, 0.0904939521945292, 0.04946837719950465, 0.019389329132654013, 0.04432699643075467, 0.11248572414079983, 0.04212878757126389, 0.06477072684755249, 0.025119067342471213, 0.04355294885294091, 0.04826279229394371, 0.04368635923451474, 0.03263808433867751, 0.06751319138152946, 0.014032350154593589, 0.009511174059533065, 0.025189539770625775, 0.09287522159396641, 0.052297926778274204, 0.006804222967700974, 0.0697416415618312, 0.029569946251989856, 0.07008361555035077, 0.03423065089830949, 0.04458517955255605, 0.0162364540606617, 0.04114033496608177, 0.039001302568302046, 0.013813317956162557, 0.04326853871105179, 0.01271672246436919, 0.0643339801219202, 0.012399687510614675, 0.045182042484802586, 0.005143940938831938, 0.03277052944946674, 0.05915395404782988, 0.033295410760347886, 0.02687401198331387, 0.05002035120982797, 0.03653158448756703, 0.04175635009643532, 0.03876390724232601, 0.07494556957915907, 0.037543042713115295, 0.04878284342046227, 0.08960429428806228, 0.02642851653358629, 0.07817248513381328, 0.06442946532080251, 0.06123871677705358, 0.08094906356305846, 0.016751556259189403, 0.04664645019558169, 0.06795224403181384, 0.04234331517270015, 0.039138865146425464, 0.01703359344373307, 0.028843805982520985, 0.019164528292153152, 0.060237244507598306, 0.020006192705383705, 0.07722433641432755, 0.09141531081930285, 0.06827158778305016, 0.01927899714979914, 0.04859679130717151, 0.02397828964486478, 0.045418824940439195, 0.02671003852400088, 0.02653469057423213, 0.014457357540396194, 0.021562266666742585, 0.03286221868268425, 0.06690788232991773, 0.06161198928771962, 0.07353158577555612, 0.05454025847176391, 0.050363589243422595, 0.1266133737179541, 0.013205389841459693, 0.022427390607434417, 0.057207826419823596, 0.017960766675852, 0.03790661272022032, 0.07622876685232886, 0.0715684854695874, 0.05575652264298932, 0.024727113777771596, 0.09169205242106993, 0.11662801517353905, 0.06623368665215469, 0.06443456746637821, 0.04022296382895401, 0.03640238758957675, 0.04269947710957739, 0.011033853290662652, 0.035415823391127976, 0.07418913436272452, 0.02378506694860276, 0.12999093280203883, 0.03786359305283235, 0.0919323358985205, 0.006410663491190081, 0.06959953225187718, 0.03022349969063315, 0.03823839773934695, 0.05715631466779498, 0.009917970577765618, 0.04462981566546425, 0.005061467264538571, 0.08539094860034604, 0.048448380924040274, 0.03344236557642299, 0.01824286131698999, 0.01836293219258228, 0.018569459920869242, 0.012078401726490308, 0.021466063260431253, 0.03382450172437295, 0.06356385874471839, 0.05327081247683495, 0.05647651122642621, 0.09358120992058709, 0.025321504161242517, 0.05536405196894081, 0.040369141065785964, 0.024578314605018785, 0.0449831890422971, 0.0643868325278163, 0.05285707903244803, 0.07349413939781728, 0.052806157168121114, 0.026212150321131753, 0.037426880801156644, 0.0070943423798458, 0.05997756368390495, 0.02171898144297302, 0.061350017861132665, 0.05409518437039468, 0.012267996996430861, 0.06546487145486378, 0.029904033365328948, 0.05901937921261115, 0.044289163178614074, 0.021234934533675833, 0.0715865268402042, 0.041211531347324776, 0.08251814952781124, 0.048799885046337886, 0.028834024954947735, 0.05821371135572272, 0.01886931439531186, 0.019926841318186735, 0.02875591654540791, 0.03182777207374814, 0.0598285595826324, 0.019407847393003684, 0.02710929099139908, 0.026866705419736046, 0.06358967590776664, 0.051722456851313194, 0.06962369466500898, 0.05660247140293641, 0.04967951103143635, 0.03296219315680285, 0.015686948768674366, 0.06515812984998189, 0.009823781982695144, 0.05501397660062198, 0.07946510528845173, 0.021224255268011364, 0.023125921068112218, 0.04851580049181658, 0.029966249280879577, 0.04171637562854637, 0.012160043716580879, 0.008097005437218375, 0.023849493027814937, 0.08012740362075069, 0.0533595024758289, 0.018598226522425973, 0.02430714437768104, 0.1206563429666623, 0.011919274730908294, 0.013649632737431075, 0.05276721308849031, 0.07887763076371725, 0.013598485834776394, 0.013358947377832187, 0.013973514602008848, 0.02943122688110077, 0.04741618852882136, 0.021856911743300098, 0.06164545966913143, 0.043809362311637214, 0.05108293814344272, 0.013158360661398019, 0.027567746733585675, 0.011754052548278725, 0.006793313396854267, 0.06601787968388488, 0.03933018028375603, 0.07719579197826885, 0.07610004875929126, 0.05262485863040051, 0.05675778423826541, 0.08224166073505917, 0.040316660212533134, 0.023534360844942353, 0.03182644865685894, 0.013069496377401296, 0.011634828199842765, 0.024733395698750694, 0.05841065723929675, 0.021846332069065784, 0.016424208804364168, 0.018260314715124907, 0.013810726663758679, 0.026403291173459544, 0.03359539546973763, 0.09500745879185778, 0.022880744204045306, 0.06503249143039988, 0.10912047608965829, 0.03463373955098852, 0.015496795212158994, 0.053864752783650355, 0.026496660054451036, 0.056618662671216076, 0.027506586104150743, 0.014596979937426027, 0.03823351775926929, 0.05163012027379967, 0.05717680751976948, 0.04167465831062967, 0.03042081712685045, 0.023963462013090332, 0.036049619422204075, 0.011647779873812632, 0.03561705170619873, 0.01945303125877775, 0.025526425020108302, 0.017875537479055986, 0.0860073199615844, 0.019026458180779894, 0.10374209453021327, 0.03189586962933742, 0.0385956168775597, 0.017968565450921174, 0.042796046322872566, 0.07707147889079587, 0.006755247445506675, 0.06278272102316541, 0.018722673675285715, 0.07411902199589437, 0.03905399792617367, 0.11815731819238394, 0.025760248461137378, 0.0692044530484465, 0.03088936607743944, 0.025440418244069143, 0.011316951506981447, 0.04119028006830523, 0.10407483715924526, 0.0717590038754767, 0.11153605856722403, 0.03723751535759338, 0.03716530007941108, 0.026803012869711366, 0.02415992526127206, 0.020212456133336793, 0.010384496098624603, 0.03705580313239367, 0.06147808094899501, 0.041340751227952784, 0.017808928049259612, 0.030679354564316814, 0.020262033513356602, 0.06081659083945617, 0.06447033611156287, 0.02455551965883182, 0.04971272860383315, 0.0749232227944078, 0.010203894700915104, 0.025564419150712992, 0.0901723025186408, 0.035957198575018876, 0.009771047362817392, 0.01354769612061641, 0.026361832410217296, 0.07540673918781743, 0.04686982611254339, 0.04254434813535021, 0.05488710860992151, 0.0011897096485500374, 0.02967815042563504, 0.04477958968510071, 0.02666202013290698, 0.08503045826669663, 0.038344581356091846, 0.023421753580952366, 0.027539368921650514, 0.004459483992128123, 0.016820282006876606, 0.0573133320487555, 0.04378208192065359, 0.06531205223572832, 0.03183839005237866, 0.050516105857827974, 0.0691528034005915, 0.07103401656833387, 0.03727645560678455, 0.0496561645019439, 0.033809379148747654, 0.027944865005631602, 0.09851673903364329, 0.054347407328145164, 0.07727373376368515, 0.028178410739788128, 0.024858771733218626, 0.04552776264327188, 0.028393091558809244, 0.04487566477168472, 0.04019357669617861, 0.03849874122909481, 0.03053433220503071, 0.02105134730828145, 0.036978592960945064, 0.08509200577053332, 0.037220466070838516, 0.014836169824364686, 0.03857156554717691, 0.040406204399562655, 0.038528798688803954, 0.04434598008951834, 0.11645562240793822, 0.031388681119067535, 0.016315058512132496, 0.030404788652254693, 0.07621981128449402, 0.03757979578128265, 0.07451450722592493, 0.0611637857171797, 0.021998320082803408, 0.02598250588972963, 0.1468623799061583, 0.10917458487975021, 0.12344140198922927, 0.09494148329981873, 0.08665542268464643, 0.12999525353793176, 0.14559599060204723, 0.1552140099867698, 0.12303265577722942, 0.20240102714348226, 0.13657775677500233, 0.1452477576751863, 0.10566923466901626, 0.17170538554989523, 0.08684942679059121, 0.1361672408998974, 0.14940778364337262, 0.10464125958782051, 0.23010031500410652, 0.14207423844885442, 0.09736574555356657, 0.0962423925257979, 0.11592391142321211, 0.26637450160999454, 0.15130762040855425, 0.1306608613700636, 0.15676824916755, 0.09852798520437173, 0.1387512861120124, 0.149422814288447, 0.09163297172034941, 0.25901282566689676, 0.20476851462116166, 0.2295638083089744, 0.21400774949260298, 0.1537719567216212, 0.08581785875703059, 0.15979457226011062, 0.11913319929472863, 0.07630681589005456, 0.18639158217176316, 0.09767476243958359, 0.22204902203332996, 0.11563713406963695, 0.17844934947788718, 0.11396107924801689, 0.13983202166855335, 0.08424848167886657, 0.13220494222496787, 0.12290036005358543, 0.1308131290058936, 0.16899187147857683, 0.2376668275363984, 0.11811082431625937, 0.3083718093412538, 0.13493203137430454, 0.20440782510465194, 0.11318923800342506, 0.2013439483820431, 0.12438978053509228, 0.1307784099011652, 0.11104632920074849, 0.12022646804971081, 0.08580099716181717, 0.11872661345067526, 0.16851369471799943, 0.19319804355261788, 0.11934469318798474, 0.2238191447911724, 0.25690579276171427, 0.14865209919310388, 0.11583701406996097, 0.11646810198022474, 0.10471010790957559, 0.1467951939951989, 0.11435838776730722, 0.1467957455785044, 0.13847434532738503, 0.12524216826404297, 0.08306060872611501, 0.20733354553099603, 0.18081507495334073, 0.1277736904880693, 0.11388712111980685, 0.13118040687855215, 0.16539415404681237, 0.16313508333217713, 0.11451100780358238, 0.11847209605959155, 0.15802752917572377, 0.1298347734395535, 0.11754904438050524, 0.13798559655345258, 0.17961026379658332, 0.280902041422744, 0.2551544698015336, 0.30302653810189617, 0.09129845942821234, 0.13213187275875, 0.12266338607596776, 0.1554362061283281, 0.08658818314753233, 0.061454879976208174, 0.15198353978414691, 0.2015785857914917, 0.11486258853467242, 0.2541749804250656, 0.15801677330126687, 0.15714721754193306, 0.12241496674476132, 0.15448717640772944, 0.13541207738941716, 0.2675789144010313, 0.12990447211890452, 0.0487924425021535, 0.10660556265183034, 0.11744916949781681, 0.23215157670840142, 0.10044179541329223, 0.14300166448998836, 0.1783225312829018, 0.19606538807913182, 0.13588748091170866, 0.1502147653410512, 0.13066452327034167, 0.1068321331554363, 0.12977105024601185, 0.10444661962889856, 0.1229694382017178, 0.1981682075007308, 0.16790044133461293, 0.12586688998365594, 0.15560947989504184, 0.11783563787297857, 0.15332558793165993, 0.12387166761102215, 0.13127537113764595, 0.13177000346683687, 0.13993863046409624, 0.15228064400294136, 0.17310898120124496, 0.18023035068425441, 0.09367386059414956, 0.14388261963763546, 0.0974810264644123, 0.12961378771691554, 0.20777104302279412, 0.18325895671882939, 0.11125673524915211, 0.18121731707886343, 0.12544018667071097, 0.12430977031228044, 0.1156810079250605, 0.14208868686710635, 0.18000577967013084, 0.11461232293156848, 0.12635953048424375, 0.2588229584357431, 0.08675355854774676, 0.18318458490314024, 0.07250905757950199, 0.16525397527842753, 0.13769247599186438, 0.11556339044604572, 0.1313171688947947, 0.11119043033930565, 0.19409818154188896, 0.10940529991902652, 0.12279463992003473, 0.1337780271686854, 0.14486983118038024, 0.16286888310024816, 0.21523733593283162, 0.11248760871709355, 0.16108996565303496, 0.11033472544964283], [0.03176372712327829, 0.04008642780864912, 0.046510446606384176, 0.012073518873582925, 0.041193535941983425, 0.02997538487937662, 0.043451714164186875, 0.04269874932604932, 0.0050207664495364075, 0.038601757072272806, 0.015488004353227875, 0.04102321161377815, 0.08680669440617485, 0.06816974405439631, 0.0449679745361209, 0.07139306665668566, 0.10828157150817495, 0.030312040302481864, 0.015087069365225974, 0.021053785383100473, 0.02683342081464587, 0.014316345651393697, 0.022149201099490447, 0.02557550635819714, 0.046068302791325316, 0.032330028893005465, 0.05679603883876436, 0.02484138536777708, 0.030377805120341723, 0.0327015815362815, 0.017743822067014633, 0.035807007037463694, 0.05318949990455182, 0.06920318900337143, 0.04344253260041437, 0.04243176385399796, 0.040257280737522154, 0.021200021991746563, 0.1007509118907394, 0.03556896053675202, 0.04575300781476883, 0.012200383991453678, 0.01435801987686465, 0.03133001985148557, 0.02081707953625629, 0.02317387051129293, 0.052394051660573294, 0.11393238925525259, 0.03857903107399902, 0.044919105787431045, 0.04107431350876728, 0.06744246614435989, 0.04576691997147376, 0.03129719489914996, 0.024363976610343785, 0.00852463284372202, 0.0784435423631822, 0.06707598500314259, 0.04883647723604114, 0.01392523191058107, 0.0472736617009486, 0.03055050432111227, 0.10125571020668554, 0.05248638057720758, 0.050881047162317464, 0.03568273225438691, 0.02520978938968432, 0.005426338184700018, 0.06396427375054167, 0.03592225347435282, 0.04320156347427157, 0.059358392271303365, 0.061034945050074216, 0.026480283009849732, 0.0391881782261114, 0.023099284190984986, 0.043437204458901, 0.05898683579758771, 0.033840306118250854, 0.018800638443339738, 0.05142549435878473, 0.08603944968912872, 0.0513358773934024, 0.002299810791643517, 0.08500883926547344, 0.02547279886540867, 0.03164233666123643, 0.0359519585336168, 0.07972757467218945, 0.03459537386774056, 0.055886332411319024, 0.08377094843214558, 0.024402786624587836, 0.03740328529308881, 0.01669391388854673, 0.03332801163196564, 0.027148547251859022, 0.037659158659798485, 0.04087227314049679, 0.02367519270328264, 0.011470599058685044, 0.01843559371698047, 0.004298011809887906, 0.03449864760642091, 0.03914193715900183, 0.12854330241680145, 0.03806759077574938, 0.04297691585135557, 0.014425517968653191, 0.03585306807391105, 0.06494858948093268, 0.04669470607393211, 0.027468591973546053, 0.033904075277067965, 0.04801044293168572, 0.025532549893062924, 0.012378790547260115, 0.009738488626035472, 0.027395195004740552, 0.0316279610213373, 0.010477046223147022, 0.031076745438059012, 0.09638707589117751, 0.028901687755639997, 0.017029427840644797, 0.022763017557501312, 0.03305282135824523, 0.02519273244205021, 0.03290576312030035, 0.03650926834633274, 0.03606933469493543, 0.04458703731577243, 0.05253585836579723, 0.03115266858179483, 0.03348548100480149, 0.039672939512397976, 0.06215734429837716, 0.05464538105673367, 0.006935633380987472, 0.02300213849652679, 0.03222024083257683, 0.03151114027376377, 0.05127996829668841, 0.09423048475817328, 0.01792987418030539, 0.032375519193949244, 0.0735752527872401, 0.058946922616732705, 0.011295053841275795, 0.06592947313742292, 0.05760850572598077, 0.07620612895416637, 0.03963423675046333, 0.0718291775293408, 0.030303054091130054, 0.061878572563610734, 0.01782402764224718, 0.041749079922033895, 0.057350724800339634, 0.07409751024698058, 0.015416864470969287, 0.022355223209747387, 0.009856886557123114, 0.04076384488613375, 0.020440011059925444, 0.03303288008957621, 0.053480111528188, 0.04081003615752824, 0.02925852001945098, 0.08400392343079852, 0.052559296825840596, 0.06226054017221736, 0.07106940983043564, 0.11723874812765468, 0.03562036503647124, 0.04688687922973787, 0.03792601389690273, 0.027941024989911148, 0.015832805206188034, 0.029595751923719243, 0.02449143640396576, 0.046354245109063004, 0.06181818568297933, 0.06257089771210186, 0.053666316859063604, 0.03746874750621858, 0.04420834856348173, 0.025122351944446567, 0.019040220950339592, 0.06306859056255029, 0.020150192337290897, 0.03511368214423138, 0.04378189805955176, 0.023849751582489382, 0.038187709531836936, 0.053703292092729005, 0.0262035318319836, 0.04761426056164408, 0.013333641578473393, 0.016531480265961542, 0.0511965106782173, 0.03298258641734719, 0.05629301784680255, 0.018633275044961803, 0.026821839480450558, 0.03105513792815468, 0.013886953369834492, 0.033167585159742066, 0.05234499522034199, 0.05471824750965161, 0.012970460360989937, 0.06425038843806233, 0.04525979274823781, 0.04438686620203718, 0.03943315782253781, 0.06235663441099948, 0.05459039126552882, 0.021637735903383266, 0.03869112505907974, 0.058960221903098214, 0.07892862157595736, 0.033993152150463675, 0.04302347484495371, 0.030974208399833694, 0.07023030606609199, 0.04323884514310668, 0.01048206409905106, 0.03887376808110745, 0.026184921641083016, 0.039088904722443515, 0.022102084776927388, 0.02621345650104265, 0.0721953215918714, 0.03438361567415057, 0.08225109127740707, 0.05883895018468461, 0.029443647081573165, 0.0031500381526477156, 0.08403632894999559, 0.0509131615681033, 0.06701171022629546, 0.041409699141138026, 0.004931250511999092, 0.010121483750070536, 0.0191047600275206, 0.02748322425289981, 0.020817144653729854, 0.10676591251526149, 0.03741538948229244, 0.01884508111904706, 0.07673705086833046, 0.003105614150333549, 0.0669398588398772, 0.055906040023171136, 0.036162203703556335, 0.021744900112671238, 0.020396179339337735, 0.009117227708620411, 0.018761841835634365, 0.039345061541685176, 0.10362101433378074, 0.040291295041360205, 0.04507590483333315, 0.04977765838585554, 0.032529659914754094, 0.02974539379318876, 0.022944649343468973, 0.04960579805136208, 0.040369792240521604, 0.044192383291139725, 0.023483237882535306, 0.07130257635106964, 0.04010623501193139, 0.111335925757885, 0.04192638714166899, 0.043798472371793566, 0.027636244570115404, 0.051584526550986116, 0.06421865707623862, 0.015042564444874805, 0.08137803449625931, 0.02791850008971749, 0.0717323899809872, 0.023791115212764953, 0.04494536345103576, 0.014369470976112832, 0.06711788235172149, 0.028661049962524447, 0.04640206048685697, 0.045873233823165785, 0.05974912775620338, 0.01609436964856521, 0.02796597647360496, 0.058879526031594125, 0.00342787430253661, 0.03848017125781025, 0.02886738233839072, 0.003585155744428536, 0.050525590026330565, 0.08884048164491692, 0.06635580872816425, 0.03298860786843204, 0.028964116260589614, 0.02337984091061498, 0.017544725391593192, 0.018611012529882214, 0.014345862061506318, 0.03499535986432626, 0.046314519619749445, 0.08362893105274247, 0.026087768285745577, 0.07644955339210649, 0.01802959393018917, 0.017670367641614813, 0.03672367337370112, 0.0892714597284794, 0.004446403040821034, 0.03139990622237806, 0.06015405501990069, 0.05990889539281207, 0.028616978839460402, 0.048254457257327535, 0.04970975618268694, 0.029261630336423556, 0.027298325101935098, 0.060413502186777136, 0.03414336284021697, 0.024303942130157546, 0.031635585511403705, 0.06492257313502413, 0.06930887083252592, 0.016316912444909255, 0.008640060268883264, 0.010400013209530904, 0.04166019074017963, 0.010223860867441663, 0.022309790365397934, 0.020946393262655027, 0.062005612924094164, 0.018912131049399896, 0.011526626899027297, 0.03778109687470621, 0.010924890689972428, 0.02929973938021689, 0.0368478600566666, 0.0493620939913296, 0.061322055651896426, 0.027424432750370716, 0.04601535079399905, 0.062270120101710486, 0.05218054678651595, 0.0215034234532786, 0.12809825129806995, 0.11782105921977952, 0.09556990522410601, 0.10694556013350526, 0.1300053199332568, 0.11165070362509259, 0.1368797639565122, 0.18531162802490497, 0.16560518062643467, 0.13702587224543095, 0.12273555921931421, 0.14182418735036928, 0.19158195043283124, 0.21257852053930684, 0.14554222655152121, 0.1468292849078294, 0.13530421220967848, 0.15364337652440996, 0.15910538424166942, 0.21768788266326153, 0.19230447859773714, 0.11604755801419098, 0.08359268743304477, 0.14796603681339374, 0.16622065566480163, 0.08064314933313478, 0.17968564684833252, 0.09767618736312275, 0.12606370563228286, 0.12002729285027712, 0.10992901294582313, 0.16784941987885585, 0.17295191785500896, 0.12783087129073759, 0.06498437344787583, 0.1548909507091007, 0.15136732930137267, 0.09677563568637257, 0.27209255123330706, 0.12352473703363251, 0.1597926723620584, 0.1581823249017039, 0.13666398763175935, 0.12144835530630044, 0.13331155623159102, 0.15888453641485784, 0.23717522891538761, 0.26692979278103, 0.14342555626025125, 0.09469434333544585, 0.0950503826982552, 0.13600866069957135, 0.11371272886472364, 0.16892364368804041, 0.10434452309122971, 0.15425384134775208, 0.10166728328312598, 0.13736232274001645, 0.1050624164241937, 0.1876022309185036, 0.14491414170592062, 0.06934612568828367, 0.18823436070834437, 0.11790668486707634, 0.12749455103109922, 0.17386777596848627, 0.16878352620668952, 0.17693897649165125, 0.12907299092940747, 0.13839433510457316, 0.1990793005473191, 0.21924023726774802, 0.1577744290473, 0.1936975788445242, 0.11685822459478533, 0.14136097994783234, 0.1938140548525318, 0.18810291534229634, 0.18347226624046603, 0.1306085835301107, 0.1910730688682487, 0.19984172657132152, 0.08269608110910462, 0.14027598494243237, 0.2006270739460184, 0.09226529303217128, 0.13000369582685734, 0.1665381684658989, 0.16483008350816467, 0.1021339763857184, 0.17944192363610192, 0.139042399523239, 0.1209772035719887, 0.14474652166808807, 0.10650852229446174, 0.16200711079422506, 0.09627757128328086, 0.1416613936664597, 0.1497705415972779, 0.18257234275581377, 0.14958779898382005, 0.14581549011411207, 0.16527875056189878, 0.12101270408639986, 0.20535762091317486, 0.20960585424496284, 0.13938277238799682, 0.24269910589341195, 0.10906337955666166, 0.11834245866104481, 0.11832872270456246, 0.10610977352987375, 0.1241735139140679, 0.12010913402322801, 0.16911248436137555, 0.20017099116117726, 0.10096354725500269, 0.1228266547343904, 0.15344129785174324, 0.07660241857651742, 0.14292323240830054, 0.13580017753185766, 0.19261923348230703, 0.1589206651213669, 0.1801968113549294, 0.07754059283122902, 0.11614802278458111, 0.08028782243209501, 0.11529270093888046, 0.1026169182131848, 0.20991569084505882, 0.13960312991853685, 0.15139000550393136, 0.15675691106627065, 0.11608215454485148, 0.21936130980330132, 0.13401808848063793, 0.14878224220968064, 0.14954212482177442, 0.19207906488689686, 0.09401581926091064, 0.09725299273287097, 0.11492421264730154, 0.20836897464769505, 0.15798665072408416, 0.11458626062038446, 0.20851476117968562, 0.11434492760247762, 0.12801176763229793, 0.10937793525837122, 0.10618044514088862, 0.20006779911777667, 0.09830533707093808, 0.11826444026683608, 0.1098478076258494, 0.12340062312901982, 0.09687715765809822, 0.1728030363278043, 0.2108355326157424, 0.1254381335550739, 0.09520353899607736, 0.15439285566249203, 0.12930886940129344, 0.13199504945547352, 0.08893081107206884, 0.25213697204186075, 0.15907481733349063, 0.1480238917734354, 0.1372499682850415, 0.1648300681864062, 0.16198055818676949, 0.11924643475081652, 0.16078118625427448, 0.2914648617227232, 0.06787109999887406, 0.08727051467905123], [0.07366522215306759, 0.04413802169203278, 0.10530368049418735, 0.005149529071434612, 0.044397564619899764, 0.05033499118120921, 0.1258063154114831, 0.0717045426849396, 0.03031655830601531, 0.019850255508396416, 0.06506318091264655, 0.01280816463423112, 0.010544804784829819, 0.031866267991943226, 0.04246478224353444, 0.023127054878240152, 0.038534739700656746, 0.0819864155604474, 0.043044737615292115, 0.0105053378501907, 0.038052330304297714, 0.02184869353509238, 0.020231208050503366, 0.07820099126547575, 0.0642156999768509, 0.014912326624917408, 0.005670488012143441, 0.023903709070216266, 0.06937696838811522, 0.024874863410068136, 0.06501611247057877, 0.0152527310908021, 0.0075740723836896645, 0.0630726546589886, 0.021616607198431607, 0.07054600323880873, 0.034604114930956595, 0.020134707785121376, 0.0070472131295490174, 0.034984213285027974, 0.051371006355170286, 0.014101301898218453, 0.050690551739065885, 0.0857147739659394, 0.02269420370970282, 0.05470798576190587, 0.01569605755409406, 0.013430573725922695, 0.0363618423861842, 0.015163694437022413, 0.021867250099838264, 0.03316164414788927, 0.03210689620895973, 0.02930632390592608, 0.07295041615443845, 0.012459111993291206, 0.07163835268828177, 0.02269983254072647, 0.03669157812011339, 0.06736665408337308, 0.011532906904786585, 0.047189721447085185, 0.010176468753225861, 0.04296352080399952, 0.049679936210234324, 0.01796825135487222, 0.07623153242973552, 0.017748546914287636, 0.06265359307308832, 0.027664055476986596, 0.07071458088654665, 0.05264381547608683, 0.01612422984063385, 0.017331611222377228, 0.030276260165978345, 0.04288089056048663, 0.03438109141444007, 0.0245936191265261, 0.056325771936005166, 0.051169349030861934, 0.0020817460186193667, 0.08252287629030405, 0.04057767402921473, 0.03335151137904294, 0.008567111461513467, 0.007402749268353106, 0.02296654988200434, 0.10876939331571903, 0.03740732257644977, 0.07239167758774373, 0.061601141482711806, 0.024615452632368095, 0.06382140984398223, 0.03943290118308317, 0.021903196860465313, 0.02805107926589347, 0.08410922221599088, 0.08491151545557284, 0.06325876422887368, 0.035810734055215315, 0.033693952681196314, 0.01401307155197907, 0.048983757639484066, 0.07064138118538164, 0.03710828015520688, 0.013033405975288442, 0.04972302482553548, 0.0463311207450686, 0.08111776378486427, 0.05397670121202546, 0.034097681017292124, 0.011119782500299475, 0.05723159046723478, 0.03195750714850522, 0.042546485520658955, 0.010478910689632739, 0.048853545674994114, 0.03322868450214306, 0.015253309487184931, 0.07486566660865661, 0.02870751894079149, 0.031407636049534046, 0.022893518720182682, 0.05143779773084868, 0.05893624335106823, 0.029013933043085763, 0.009045835974956713, 0.07284799019896215, 0.028985748668351484, 0.04416336005012836, 0.055472824962869774, 0.02004256081436911, 0.04923379724665035, 0.034561957112483443, 0.04281524448625503, 0.014782790733020634, 0.007120499973215404, 0.023562047262525847, 0.033164275659909176, 0.036489652665031534, 0.056384243596825874, 0.021247031062000224, 0.00537641414989447, 0.026072793182045705, 0.026888333997058294, 0.02749871646594857, 0.04983092064879114, 0.030699908703325257, 0.03282256980216311, 0.03135899329678186, 0.018219961033713435, 0.017326717835760886, 0.03624994375352417, 0.05332131682324314, 0.017142914190527894, 0.009435125468899647, 0.04241071558827835, 0.07034024734410547, 0.010010648064405448, 0.07127718819725899, 0.06255549934482382, 0.038222095388318264, 0.041362010167851564, 0.030028137693842574, 0.007273339780963838, 0.09686159841235607, 0.06386919457825922, 0.04286200266271349, 0.016866722256846486, 0.09073847979908028, 0.008794786089340286, 0.048051907440587405, 0.03804937703534961, 0.022041931553112886, 0.01911909736302351, 0.05680192622446245, 0.04877403723977266, 0.019463128297619765, 0.07032737706697757, 0.02415711754902957, 0.07158653450108345, 0.05803828871238136, 0.07497724731482806, 0.05253923298310369, 0.11389572428719652, 0.005806133934041305, 0.023869083811258598, 0.029177927569816672, 0.03308884664288452, 0.026171068856192213, 0.04349081529184215, 0.0339019340613196, 0.02469361658328243, 0.022785917840777867, 0.05518271129638438, 0.031453794762191754, 0.011379914358258249, 0.010011613335190041, 0.00844935895950203, 0.004517477326801107, 0.048868825298643885, 0.04338719806964359, 0.021179709170434265, 0.05061962731903599, 0.09993215542166464, 0.06007951849530782, 0.07768746720807207, 0.023473920338156245, 0.05835272567046266, 0.056712094754461324, 0.028196833239147262, 0.08676439869187533, 0.054869660957446026, 0.03264689051936711, 0.06154084270219169, 0.021971242705119715, 0.06060886992922714, 0.023564165495636485, 0.06109085031634858, 0.06172920074013453, 0.013500896766932021, 0.1204914348800817, 0.018592735587228692, 0.025132420254991423, 0.03462895150146177, 0.031054482922979423, 0.030239733093748652, 0.02748040504933846, 0.029342670947493567, 0.018465708633283937, 0.015958313390822904, 0.06291474478559629, 0.05465091221154698, 0.02355025716937117, 0.0501501111824426, 0.032369850143309564, 0.07590836589975704, 0.0497138662444007, 0.06401288202933728, 0.10665889003223951, 0.1080553227614972, 0.033100602262082605, 0.021491771255950295, 0.04550640794238256, 0.11098346402568203, 0.01906913885426137, 0.02284456187138154, 0.040074993946379235, 0.06357484444555256, 0.0031141859559988185, 0.05680908531611485, 0.0538811547261092, 0.022081260591925635, 0.023656412057818908, 0.039221100854657354, 0.013676074262137615, 0.05798642455990757, 0.060195887251006025, 0.025056412841583935, 0.09017050987289799, 0.011427545874950387, 0.03798777973579784, 0.014406369600985802, 0.05119891236385992, 0.05994824166860312, 0.03647875506430864, 0.013040943322853457, 0.1388142125741128, 0.04270176005159174, 0.08215015919338312, 0.06206990685313941, 0.0437638835020123, 0.05211937083532253, 0.06617053802455626, 0.04334757217176018, 0.030197835745169755, 0.04922434755210434, 0.024002699121352167, 0.035894371704348636, 0.05476366120180296, 0.04936354955838573, 0.07114440983822269, 0.029346823144043167, 0.06567160794211012, 0.0199862361149562, 0.07512974477703534, 0.037268702796990835, 0.05572967509168291, 0.03912766111053286, 0.07337344224534689, 0.11201980478701093, 0.036182662081574245, 0.05540362424066952, 0.07109262229454133, 0.025561063685604644, 0.016400107678266305, 0.027234352929818056, 0.03933823952871946, 0.008534647528112175, 0.02203959690016364, 0.08033648433704531, 0.046053383228999954, 0.012707760193265014, 0.10341446936851549, 0.07475995413598514, 0.07181292880446681, 0.03785214386880398, 0.0852216125255631, 0.03915012280847277, 0.05712439178399021, 0.027475888961024826, 0.05994619621384529, 0.009322351580786129, 0.07381050306702815, 0.06447284887995451, 0.06737339565710676, 0.020778365283002777, 0.03499993723967383, 0.0373510419270925, 0.033647535413864164, 0.03767590917226288, 0.05249478073129731, 0.01422888043546869, 0.028525973339715315, 0.06719073731332056, 0.016680478621574662, 0.06952163643173634, 0.011864638297758516, 0.0763529803483717, 0.047770779985453815, 0.016853825166641224, 0.06265757289985496, 0.02354622946210927, 0.028370807976311738, 0.07699139205919159, 0.029836385886395173, 0.04187909270366354, 0.00829566065447345, 0.03276045539326245, 0.032610164264277104, 0.13828699086462298, 0.054468874398979454, 0.06430229472537195, 0.05522264745987712, 0.019328300653386022, 0.02274681096746316, 0.09477668246554752, 0.018035383639676918, 0.02256716334921939, 0.06690432002106983, 0.023276622054137053, 0.0104415160228288, 0.15282612924854602, 0.11607712134718896, 0.15398206399573436, 0.1043220077671351, 0.1866922257167678, 0.1681635618930863, 0.1789021227628954, 0.19821869269494088, 0.1585401645711353, 0.0832474192664508, 0.08837054032952556, 0.13856247608219424, 0.07348914450455098, 0.11937249451875688, 0.1363402388749584, 0.08747226393391049, 0.15352201287544545, 0.19251328352237904, 0.14292076560518435, 0.10937127795430923, 0.09731719856180492, 0.12293121041429621, 0.11478426370529399, 0.18259235297239598, 0.2130225451002198, 0.1221922113590183, 0.1495586876426974, 0.14494182812350412, 0.28222590264293457, 0.13133117298205055, 0.24823338634544806, 0.08192377255087899, 0.13008407377187284, 0.16922042614990668, 0.10000116462188383, 0.1710372189840963, 0.1500929267175736, 0.10420268957292843, 0.178344655902155, 0.11822447345982637, 0.24703697151234075, 0.17282799547237737, 0.13193409950021776, 0.2108312578451249, 0.05132797519646345, 0.2810044520564618, 0.09628894002807718, 0.1141266308484539, 0.20004693088271927, 0.10994358393814295, 0.1624024887719462, 0.12276976504513334, 0.1062975263583564, 0.09518816361143705, 0.18024343546600113, 0.14864656803829057, 0.12910173454832646, 0.187363303416679, 0.10619698497917383, 0.23158620382028244, 0.16741710114142588, 0.22454058511122582, 0.15883573661408118, 0.30077791682654814, 0.13964543329371562, 0.07831112406547032, 0.16830118192780405, 0.2223852120580212, 0.27936741409282534, 0.09536833216946933, 0.15716387229340692, 0.1610991893516433, 0.13253059087982103, 0.15160159898861764, 0.17557900188671005, 0.13998283373732723, 0.24326820196884297, 0.13484776170263368, 0.1331970107651526, 0.12212100348645642, 0.16102659485993848, 0.19033613825036635, 0.10443829225316163, 0.16746453730569733, 0.13462078517242787, 0.11318461083236242, 0.15407105276901878, 0.28753734343955595, 0.26321337768627756, 0.07165863869651672, 0.18130898715988283, 0.23440828787222986, 0.1996861800791756, 0.1452236871926054, 0.12199780122647363, 0.14273805363524344, 0.15417974532371567, 0.22631778652148865, 0.1119666995720998, 0.18624996315808068, 0.151849290536296, 0.12333713742273471, 0.12377749242249036, 0.1760090989691596, 0.11264877829460368, 0.159705797991445, 0.26592866908158025, 0.1865532573673033, 0.2357631296880784, 0.1229460801809065, 0.07005530094066936, 0.09849456078823536, 0.14257049488444484, 0.22099039577428373, 0.11254442945843744, 0.075289543057161, 0.11430004251099403, 0.1045947427290582, 0.19037513212571222, 0.17059874089975513, 0.0724662332645347, 0.10734203361695814, 0.10881575695689648, 0.15984001659577893, 0.19421160851995792, 0.15582041454411324, 0.10114124900991879, 0.23593943716297228, 0.1941149435456722, 0.13330236317649966, 0.14796099595485196, 0.13721112762728047, 0.13930214929484552, 0.1681500327803435, 0.08219351976989739, 0.21165368387535696, 0.12940073866517315, 0.1302769440676897, 0.1260613690641138, 0.15877979687385022, 0.11209511889084695, 0.21330472592624927, 0.207999567050607, 0.11383619925547993, 0.1422308727858528, 0.14421715491241024, 0.14424125603850813, 0.2212315755746057, 0.17635262811616545, 0.12691140490313693, 0.17495883839024653, 0.0607409434873731, 0.10775615776618643, 0.11064996296960501, 0.13491848693980327, 0.13720637788214993, 0.16787506850256076, 0.13453527443831967, 0.1509647194536463, 0.18398687814272222, 0.11384797402687612, 0.16869139647291553, 0.25847304011544875, 0.06565348230182164, 0.13793282841722812, 0.14103379911713063, 0.16651323996484282, 0.19633629209091588, 0.22918035065935505, 0.16279694744415824, 0.1897007602477266, 0.09661301820268554, 0.139307496588557, 0.1781935833634869, 0.11811892952649825, 0.09820451990010277], [0.004270251656341697, 0.023661732538453033, 0.0415882742362878, 0.037905325692507534, 0.03628269401228717, 0.013728206545384902, 0.048681555105553526, 0.03292384662575299, 0.08105014120378802, 0.03941740322437498, 0.038404477940451716, 0.07323777573483606, 0.05213413718006304, 0.020571979280981808, 0.038097675048535874, 0.04783012881694783, 0.014338725952491646, 0.03985773141105329, 0.0171243020844075, 0.04569613344727024, 0.08901070638169205, 0.005574315728154034, 0.05329411304105194, 0.0751428372196613, 0.02040769172561986, 0.018457704929695017, 0.05268217349845556, 0.03280322225163541, 0.01961353817023337, 0.035434182688233354, 0.13507109165431994, 0.08713940639168986, 0.041052127602480115, 0.016325241735865994, 0.05138950354810204, 0.08394712567209237, 0.0533857409872355, 0.011170043613791708, 0.03414655742686122, 0.06000300929430993, 0.06355994403542531, 0.04147791544035558, 0.02138611240943353, 0.0838686169816121, 0.06214490686092646, 0.011123492281072804, 0.06881391674640679, 0.04373991261086157, 0.040180503405750766, 0.026556135290452552, 0.045522664328135794, 0.018355987605548674, 0.07405492341926984, 0.011953265094498714, 0.058051902094795826, 0.059763928574900475, 0.05687049492412517, 0.042260225276432695, 0.021019983668661407, 0.015642959042452276, 0.03307690333214498, 0.011645787087599597, 0.019333743708088033, 0.03275208205225007, 0.05548260790566283, 0.0365387205965817, 0.03700573545610232, 0.016961305387197964, 0.043023344610006585, 0.10626446200354446, 0.04586191487408454, 0.02578934639572136, 0.029773428780777805, 0.047924905384500185, 0.022706677536329916, 0.05178673545859995, 0.013418611262985056, 0.03998892396808632, 0.05510593396461299, 0.029949809034024517, 0.06474732286146571, 0.024300686256479354, 0.00463952997609252, 0.02620757103056437, 0.00907349940990248, 0.007515515016782428, 0.03945380389209717, 0.018150689448380185, 0.027662364337893746, 0.07855388200691632, 0.04752694569047421, 0.0037427524793817997, 0.047674517207328355, 0.01711864835552631, 0.027008898999361743, 0.06878977731591271, 0.03479704268336777, 0.028690324097331014, 0.06987831164752284, 0.016123448430951086, 0.015053185296335049, 0.019808842710429625, 0.0332652920136048, 0.02902597211481583, 0.02665852677197226, 0.041989711969490015, 0.01554135663149458, 0.05511716098314332, 0.03470057306150275, 0.007609699302608328, 0.060443938860008796, 0.02778963260953465, 0.02008989355677078, 0.02406410489892287, 0.025830035240599708, 0.017155811280733155, 0.028157316508793065, 0.08687026438213165, 0.02106256858115235, 0.01805177600603671, 0.04520152410071704, 0.01978078090976323, 0.027773864604833148, 0.043363525952783324, 0.01295139147494469, 0.051767552616975965, 0.0016697011995993015, 0.03396839218875093, 0.030941059775350076, 0.053284322437379635, 0.050489714128836516, 0.10728156629709468, 0.025938350496993914, 0.07730325879228693, 0.03261546942315275, 0.029149415692494764, 0.018653630001109936, 0.025260067740154844, 0.035146443894313234, 0.017134996671830455, 0.022395613280335264, 0.03410638377611195, 0.028742801120144226, 0.02806709050351093, 0.0866998940886509, 0.030250414274632934, 0.03770661014582842, 0.04227568110030505, 0.03654008423308692, 0.07741850905961568, 0.015844373133844666, 0.052254811349895694, 0.04160705871219116, 0.07261516075701484, 0.05125209035712385, 0.02232576521383899, 0.01978930746836047, 0.06544029535425287, 0.0295691667575269, 0.01019112976087678, 0.020915113892706654, 0.06531528512676878, 0.03727237618858776, 0.07465542909959633, 0.019771377180492686, 0.040939505016731645, 0.033915198873728514, 0.04665481970615445, 0.031482059576158086, 0.04932095506979574, 0.02856701650025864, 0.0867702286209791, 0.02571340984544687, 0.026439732060797756, 0.014689183407162708, 0.027070408198802222, 0.015662851473016125, 0.026292507198729345, 0.07583709674016123, 0.02520165736636808, 0.034971059555368084, 0.034759002587487625, 0.058112687341147856, 0.034511617474978974, 0.04416969559726216, 0.00524296690033929, 0.01812573796468637, 0.05421137309543068, 0.013198820637508988, 0.03583598048275998, 0.03537741174260455, 0.03256037621007812, 0.006448212811993736, 0.005143351051130242, 0.04832417125843706, 0.048543383487530296, 0.01931091620316429, 0.05962197248253131, 0.06569602316425693, 0.04317887194995438, 0.02361116115935147, 0.03976722961411842, 0.0322590546772605, 0.018657100379406925, 0.018757676232546087, 0.028862454477817785, 0.030521180390590624, 0.004579614239534544, 0.02275808778170857, 0.034233290071208636, 0.019972613156442682, 0.0259460975611282, 0.04369146904096969, 0.000998447179764269, 0.0069753124262206265, 0.028806057000052065, 0.02284748449681267, 0.03440060367387149, 0.01874115171601936, 0.06885728498380031, 0.014421409822159238, 0.06851220833918742, 0.020730632259660674, 0.05303241357567811, 0.05692471096652651, 0.049144923386554566, 0.04406561489186941, 0.053544367152837016, 0.0908089062619594, 0.03536094085223252, 0.06705995844376665, 0.09306599280887073, 0.024186131213941885, 0.007242035034352974, 0.017705149948596954, 0.060433665620944196, 0.014307688857849329, 0.023232112345736355, 0.04144534904269442, 0.04465050386985944, 0.06516082647947535, 0.015624387155947907, 0.008822605614700626, 0.059793855799662496, 0.051358519122004516, 0.059617510020372376, 0.01234186415169989, 0.03004628631676878, 0.03348930378354365, 0.04297042708663691, 0.03222613587915417, 0.048427677397886594, 0.029426220496515595, 0.02844046643604675, 0.01578752462181353, 0.04502668751463775, 0.09410904450041634, 0.02274514089578823, 0.032994158175443454, 0.024049554974020972, 0.0036608986180996705, 0.02228733824355708, 0.037325439268663045, 0.014689977265774243, 0.0499376520184019, 0.039833538354404514, 0.009994290172002249, 0.02661389448950368, 0.06818158777370568, 0.037456620334377216, 0.027338613665873007, 0.016372733441511952, 0.06953787749573108, 0.05782779839430606, 0.029320762748078957, 0.033553540255994566, 0.08630517494654463, 0.06867858731458265, 0.05183518285893145, 0.04334551905612311, 0.015886885267982803, 0.029432040849520318, 0.03316101595579136, 0.027528601555874752, 0.015569720079281158, 0.03616441386721788, 0.010346767225963695, 0.013136828802676212, 0.05914877146302212, 0.08448321867974536, 0.005127007522875624, 0.09707451722915135, 0.01720599578543296, 0.037928442395622694, 0.0656302468550782, 0.043971918508290284, 0.02998567727063933, 0.006203975363243973, 0.004000159218952421, 0.04065335202481478, 0.01847039326094091, 0.02977282165609781, 0.04362118430435658, 0.03955035778363386, 0.045695807859902425, 0.0770898113748239, 0.056426868728932836, 0.101520600428264, 0.04137668075160154, 0.04045115843895943, 0.07032878666875825, 0.0588747073385504, 0.03387107220928996, 0.012704571352280196, 0.023093471498859507, 0.060068885194918806, 0.043711885284151764, 0.10734171186002994, 0.06611170247197151, 0.008643872513916464, 0.025219666178248105, 0.04020199217202683, 0.04986342192897874, 0.014315314305525635, 0.04444141166224595, 0.10260635386070899, 0.04240929449517881, 0.06800112044138294, 0.020046937091636564, 0.04826339367296427, 0.02151664613085168, 0.03680282174759815, 0.04247626973195903, 0.05826774736746185, 0.03646817922051396, 0.017916862176911488, 0.03488275643077589, 0.04446442877393096, 0.014211125390213585, 0.042802320582972425, 0.014464819236778685, 0.07638604470318364, 0.08946324984032301, 0.046623586301481536, 0.06460332131433873, 0.05357109213007554, 0.049154177728679874, 0.06570461867076736, 0.04426895760961118, 0.01135039507531591, 0.08672095384568938, 0.10377282231685617, 0.15253392799246698, 0.13572286393853927, 0.19819716562426862, 0.08914386012381123, 0.15527529702071222, 0.07218430524752026, 0.16928963453298615, 0.10980872948083187, 0.12713220676467304, 0.19419806408545665, 0.14823740047793235, 0.16365210075051556, 0.11426327795150781, 0.07835598617431619, 0.0802723934213, 0.08399794794498913, 0.132103129139831, 0.07423252558275577, 0.15680336663799901, 0.15246715576898667, 0.1660363808754952, 0.12671858057259552, 0.13080496250862075, 0.24707158336475973, 0.17270162160838806, 0.12233435897336853, 0.133470228362468, 0.1291580420107611, 0.128340695143467, 0.08562799918675616, 0.237198242196633, 0.15143580224004485, 0.10457629533184153, 0.2079868806345809, 0.18611788959993472, 0.12607131288537096, 0.34936915782670824, 0.1437634316783759, 0.14074368162020562, 0.1405744068324566, 0.1823422405868769, 0.09998864674520108, 0.13250385441126364, 0.18632108676097087, 0.09084691954476219, 0.24768695115081726, 0.16070653864693257, 0.13336616297883372, 0.11883505319635715, 0.1854294523476593, 0.15191632322967052, 0.18424278215294887, 0.2034590864974645, 0.1293713974976732, 0.22649879777623763, 0.12517326631613318, 0.17405821010470393, 0.09750289061377126, 0.07911524825519131, 0.11886947352679507, 0.09379508634728771, 0.1196144710505201, 0.12084753552992498, 0.11665796921137842, 0.13721334928226087, 0.1275259759577532, 0.11011585412967591, 0.11318160010681999, 0.1901237939995143, 0.3085125550147026, 0.13337051435824365, 0.14550784452547952, 0.11815554086839962, 0.12499779387707673, 0.07155039047281589, 0.09680117705776807, 0.18596225117723789, 0.12801969664231425, 0.17179052856179977, 0.18845035153771603, 0.20864695731189944, 0.11054301709537545, 0.13707716949284077, 0.08952192451444366, 0.11052155131173712, 0.09735098303926569, 0.07356701734205408, 0.12629578430806437, 0.12620754630094574, 0.13036441598688403, 0.11177945236164717, 0.10061754364400141, 0.1746653194629377, 0.16421482297441653, 0.12670777873286318, 0.2960764045917219, 0.11206627568049778, 0.11788969303691581, 0.1774189918632469, 0.18300997814343822, 0.12404137906888801, 0.14886677235124574, 0.14451453492285746, 0.22379452272528605, 0.08384272320977143, 0.1259644206372961, 0.10028770448820246, 0.19861662940632915, 0.09549631481809963, 0.10460168348565217, 0.12436986224906099, 0.12908740870414243, 0.1340874347595438, 0.14996477552959997, 0.09072648286218606, 0.13024257736340647, 0.16710433808545913, 0.14387667479534305, 0.24495151164310597, 0.10501568506081259, 0.07864425739934368, 0.09788150658770915, 0.13769429928112414, 0.10223844013507329, 0.15111691048068387, 0.16308035401086654, 0.163595732001047, 0.16833006344254942, 0.2210025612505213, 0.2459511184884656, 0.1967025280839974, 0.20212698217120864, 0.1318531393283798, 0.14287933557023927, 0.23627187335683456, 0.16243467978652448, 0.12068249720839724, 0.10562700024175067, 0.10462979891247327, 0.12395343217518061, 0.1084550214751113, 0.18674957505877943, 0.18935508605453277, 0.21134343358778188, 0.14758184371936708, 0.09931466557205686, 0.14413666971508535, 0.06821070677570759, 0.14537897321485704, 0.19315486683720545, 0.11974510436336841, 0.15386633875389255, 0.08214465102120753, 0.21934085525572303, 0.08841540243837143, 0.15644114494564074, 0.10384710220199439, 0.2194960953126992, 0.15216810568686456, 0.09706330170193989, 0.08411211802834466, 0.21787788779024156, 0.07808790136609348, 0.1452708628869826, 0.15365037856803787, 0.18247480444129438, 0.1708485468501045, 0.17861480914777328, 0.18186855310153577, 0.14726574052005045, 0.230623108725394, 0.13795008071728293, 0.16644620727146828, 0.08035102468584815, 0.16620924095472983, 0.24878213512561015], [0.04296316840355435, 0.018232959630568663, 0.05263838391270369, 0.08980909257286018, 0.08990556602516482, 0.05196600769376082, 0.02833471182853945, 0.07739818474698452, 0.02952120582302732, 0.012253068815616351, 0.010666391556902279, 0.004949264590733595, 0.018670621831270478, 0.047962550945099325, 0.052366717643434965, 0.09691196103249827, 0.05308100653271522, 0.06444108687461385, 0.045691035132134156, 0.018144158548825694, 0.05614790930262497, 0.0538742637652303, 0.031091201517190185, 0.02675629108242931, 0.04472145127252706, 0.061520529880879395, 0.04023867246184138, 0.03430178599251855, 0.06705389102740635, 0.06667785676977327, 0.06259573045216742, 0.03451880721014834, 0.023356061541445317, 0.053177694489638654, 0.026777170808805574, 0.04572290438978423, 0.06563739445541175, 0.008940243203523419, 0.1020885703544463, 0.015773810690359002, 0.06344878467761221, 0.05103385105969445, 0.0886070240108717, 0.05910845225556724, 0.008752349606384675, 0.027312227682540977, 0.0656743965021545, 0.02758190595364619, 0.04508441223973229, 0.03174537740227196, 0.024641725617731293, 0.05997431930154563, 0.04560688420409157, 0.0027143536558029272, 0.02638642574780651, 0.029253134421343287, 0.016603375702435454, 0.09342302042510241, 0.033794578330050555, 0.039325660365002776, 0.025776435898977424, 0.013546661901918632, 0.01875442610452733, 0.019812376290980368, 0.049805287346844716, 0.05473545767487057, 0.08216175776455673, 0.05181244153889918, 0.014538269831738887, 0.026350300871737065, 0.02427404363369269, 0.04257517934386288, 0.02641385361071556, 0.020327512963464665, 0.06484502205444921, 0.07318005867062077, 0.04828591665793811, 0.016543042447958744, 0.01530624041709328, 0.04209383864015822, 0.06108007528969358, 0.03950413203828278, 0.017394418940849362, 0.022244563724304882, 0.04431424872769464, 0.023583388556876493, 0.03743781670627575, 0.05175321528147306, 0.023812630792118372, 0.08871064506350987, 0.04359848128872053, 0.05858529847295535, 0.05373141134998972, 0.04110435564671794, 0.0315441835611578, 0.007434498345960053, 0.007416883111751128, 0.07064990008309965, 0.06294044320501628, 0.05545054329559208, 0.10016500018537046, 0.013393202999366388, 0.10409128506697955, 0.127419987693429, 0.039045333471750064, 0.051645495658439976, 0.1097995364257405, 0.030282383123713157, 0.042988617844398946, 0.016347174833138144, 0.00798660737928003, 0.005645481944685021, 0.02827688368157514, 0.04045709945081223, 0.06083920958542055, 0.025824205311495933, 0.030444510311128634, 0.04853591029982894, 0.0015191992767335427, 0.01657869809517457, 0.0030818812252442927, 0.017289842193525647, 0.03613219220912264, 0.011790547061771637, 0.03793809510346863, 0.0061295504002050775, 0.06294012910896732, 0.06831553058638688, 0.03041212968978911, 0.019452860804214593, 0.015323515699785805, 0.06665581642019172, 0.02075239490236967, 0.036457963438043674, 0.04613607092910717, 0.04428145250365619, 0.04073055453538414, 0.02615672194459025, 0.08983788215705464, 0.02560167209125094, 0.01954251990443276, 0.05186131794846827, 0.0429861931761186, 0.0494437244901013, 0.007366708661955331, 0.012556312271514007, 0.028542681717343872, 0.019183454494322502, 0.012384506520785153, 0.019938633326561223, 0.08774065517730291, 0.024090464069177548, 0.050052404328579866, 0.02023487952688048, 0.04316099911868092, 0.11829303066817023, 0.09507079128055804, 0.009444702525563058, 0.05065501675069813, 0.025577186005971125, 0.03154726898027284, 0.04930676329099844, 0.05634189808681127, 0.043975787252307906, 0.06359498106664227, 0.09330855156745642, 0.09226427413523199, 0.05063966051825593, 0.05478207795550266, 0.002109798961394136, 0.048599396006114064, 0.013985792118605348, 0.14066903401286374, 0.0443275748271375, 0.016391749659012404, 0.028019499206434817, 0.05297064773678299, 0.010788496395933532, 0.08932087239959548, 0.01745704662865929, 0.08322842028592864, 0.045444167128974394, 0.07179907793479581, 0.05911625486107604, 0.0113437712876006, 0.0043689357511128395, 0.022084346011040673, 0.04462819155906478, 0.036059865848191326, 0.02482795010080501, 0.04167692210044592, 0.10934172228219048, 0.007721160786346563, 0.006852762777388337, 0.07996292454340766, 0.07239058208201202, 0.029201044272931836, 0.027818494972081918, 0.03942057865882113, 0.05091400809525963, 0.010133017203770578, 0.06576392919786515, 0.01289484844047336, 0.01122082949751207, 0.08066892819178682, 0.06488060683853204, 0.010506296417705957, 0.045260995506278934, 0.00299060017324894, 0.06359906048483907, 0.04180403906972178, 0.022637312105225942, 0.04273111271041055, 0.029509136107780283, 0.01719976557538875, 0.041989466821354245, 0.07692150951873872, 0.07104148592559562, 0.026737592791417436, 0.05456064024098939, 0.011244555240527037, 0.033797137063717654, 0.07096387355798675, 0.020756104683142998, 0.009730456194149391, 0.02760550337693384, 0.01122111582287377, 0.05022761246730244, 0.06640440168520136, 0.044751619814985225, 0.030550356849186847, 0.08666222554541404, 0.026487062887979612, 0.06156086824053238, 0.04013463006084485, 0.08297748818633058, 0.02446912217795128, 0.07550120548976046, 0.01461645101963152, 0.028387991328453346, 0.020877370655897166, 0.06149222293207723, 0.026333749542132984, 0.03622107756053729, 0.014392892199177897, 0.06176334527891971, 0.06770858210661719, 0.05965279219972511, 0.03374827980634666, 0.024053745474966786, 0.08928672786081031, 0.029985909012236425, 0.05923497167626216, 0.037824158676930016, 0.013007621370976972, 0.04443507994555178, 0.03425276019580422, 0.00758965652728934, 0.03130380432271669, 0.02341272714998453, 0.04973574188507853, 0.03532091275818887, 0.03546632773753616, 0.021852449281141165, 0.0037875288821411354, 0.06180937184141048, 0.015549652406104631, 0.050657253727437034, 0.030622007137524988, 0.029904234463409073, 0.057945791256403735, 0.029427969092202765, 0.06207838361602157, 0.018258412901852882, 0.012014656507920836, 0.08966241737887745, 0.023482060022351724, 0.058201886788611455, 0.03884877063213818, 0.11503182501802522, 0.060032473035877755, 0.029846362266389113, 0.05478346840508523, 0.03155525161644384, 0.054304176986578016, 0.029003564043030627, 0.0606530502198204, 0.06320132678675075, 0.05615421037580218, 0.1060332183636004, 0.01743549082968985, 0.0061329130473877155, 0.014025138394396394, 0.042713431401118156, 0.032987370636434324, 0.01648769068020967, 0.08627034858950684, 0.015001639070349836, 0.03918953037129776, 0.008570776234621243, 0.04992032693999429, 0.02748756414099086, 0.006490903540379218, 0.09740668529224011, 0.044607675724452546, 0.036019175088093165, 0.011939733108926204, 0.0068543629435401775, 0.0270279516060386, 0.02334622114205793, 0.025538975455527826, 0.0419336726378289, 0.07560613655274914, 0.012061673239053739, 0.03632717307717089, 0.04446931641488787, 0.014632842428381405, 0.03364982218631814, 0.037567683931199775, 0.09542636332973357, 0.02531910439081971, 0.09406045920425847, 0.059115653482055476, 0.03029239206244388, 0.029811026460881677, 0.053106540243231484, 0.03043434240915362, 0.038104068052264, 0.042213061073374365, 0.02575029314856135, 0.06914538766948447, 0.022948414665616812, 0.01992057471896612, 0.016538394209478172, 0.012287735251799948, 0.0328934597482364, 0.03175211514556601, 0.028443157319880785, 0.041156250442708694, 0.05654768845547111, 0.022909708073242538, 0.022379400944637678, 0.014616814911395553, 0.04163693231079848, 0.039204170311530756, 0.03452009806830076, 0.024910333280962323, 0.010167395399372664, 0.06297662936811967, 0.02441683667711914, 0.1031674902826067, 0.05210883329592405, 0.16068197786808014, 0.19649808986052392, 0.14229438147477566, 0.2423126911444049, 0.14681466795023412, 0.15295536828137216, 0.12424801596470418, 0.22036365924342988, 0.15151055709969613, 0.14469490266375004, 0.11309615065974575, 0.10394586625719264, 0.13897461606369865, 0.12613890482293022, 0.13376552461376115, 0.2356022512239795, 0.08914892396499073, 0.16696616646743592, 0.14314276256388234, 0.14070785934886626, 0.17221910879015925, 0.1627570342633032, 0.15689684468651974, 0.0950941033360939, 0.09649097273546843, 0.12531686949753953, 0.10487313141986247, 0.14514303345593715, 0.16000930670528643, 0.18878831888639158, 0.11504428160767402, 0.11926267581481127, 0.17582865461947458, 0.1304598705422494, 0.10023150427807724, 0.14869811043383616, 0.1965462308256857, 0.10059444609308436, 0.12543368258423385, 0.12084565095363126, 0.15834845872896333, 0.18630440136598003, 0.1986618132721032, 0.163762892386125, 0.08785805049081964, 0.1128501598272593, 0.1675744709228316, 0.24026892178000944, 0.14691562301689579, 0.13473367588894983, 0.09400540046514043, 0.10500839956465269, 0.12473905534153024, 0.0779575974710526, 0.12457050833730929, 0.1113972281135859, 0.17142148868691537, 0.18237167368492774, 0.13141600955878535, 0.15931391337465856, 0.12444947410615222, 0.1995391218412307, 0.15101056215503525, 0.1726928269190173, 0.07470374626498069, 0.11185393909052496, 0.15877140055020011, 0.2995292241534879, 0.20893376530899158, 0.11436690666502523, 0.21459802023826108, 0.16273003732485158, 0.1406706427975047, 0.13244843561082117, 0.23677784378730485, 0.1648214113928618, 0.190059703083769, 0.1420848104622095, 0.08657169693540182, 0.133868946483539, 0.1794050901287025, 0.11338125028076673, 0.14949600632873275, 0.14468076068066782, 0.18016056007435247, 0.13069222500968364, 0.15884237093550546, 0.08288434721649655, 0.17608183135669078, 0.12466862121777189, 0.1665751245473662, 0.15545633891897817, 0.21879641188969537, 0.09934298018173826, 0.20426804470198773, 0.09320250967697752, 0.166280395201137, 0.16203563990852526, 0.12226115927220353, 0.16719298978005687, 0.18806010634908754, 0.12238998461755053, 0.14288739481520268, 0.25783013912939257, 0.15815232489858905, 0.17570444112343175, 0.2340309282824878, 0.13199128030288604, 0.12469055431504404, 0.08403475080887157, 0.15375162474811077, 0.11661601057576558, 0.15110561834467998, 0.256239005154179, 0.08981974885588692, 0.17263282691278767, 0.12415197918251639, 0.14433278822370116, 0.10620121378451587, 0.1444517770001004, 0.2070684637874365, 0.11802060980229609, 0.16764274467864346, 0.03957350129982637, 0.19047325266705406, 0.08916890353805597, 0.10875044030047233, 0.32342378230344865, 0.10307130794371329, 0.16581744826849432, 0.08927424828852377, 0.1280502405678553, 0.08798388809326195, 0.07324108523466895, 0.12049071475743287, 0.1626648432424953, 0.12534752067539, 0.09760076600697734, 0.21668369461211467, 0.15538886189460754, 0.06981631981269007, 0.2577893832518209, 0.13026556000113487, 0.12909483975700795, 0.13189896670801024, 0.2270863412488853, 0.20435327964444316, 0.14509332967140984, 0.2113502058050325, 0.09701443295325003, 0.2059258436483722, 0.15053891246357273, 0.13175701061564107, 0.19313018348428512, 0.17111476240379198, 0.1643086381016239, 0.18820497357556898, 0.10203717351560632, 0.11724436355213966, 0.2165786946012128, 0.09867340401415864, 0.15553667089871823, 0.11156048145025008, 0.10412490100509698, 0.12037805386728818, 0.14800539841094326, 0.11861310986381386, 0.11788256075834075, 0.17485163204612272, 0.14768511237156007, 0.19173824769114295, 0.10195678024883233, 0.23397573930842264, 0.15423075145771428, 0.14947475504971322, 0.22913412491400398], [0.03623705432419816, 0.03566718833040326, 0.02251594845626143, 0.031807319441389655, 0.04960604319949785, 0.036031953434670166, 0.028564101535706755, 0.03370781121174655, 0.038042256248093424, 0.06544535153455312, 0.023704173809458173, 0.00941395175628244, 0.03866211713982686, 0.04754158180026759, 0.04982746559225264, 0.05237039869591113, 0.05770407136409514, 0.07686762289414484, 0.1269711597612308, 0.017839255554962064, 0.05143027091699262, 0.04434456665729804, 0.05920997422729289, 0.029315710398218328, 0.021576971724449147, 0.041429383770352414, 0.03258933816405554, 0.04451169256841944, 0.05222577278712585, 0.04965473957840474, 0.014637642926836928, 0.02840018361776827, 0.010678083973846609, 0.08979609972166439, 0.03255112186795281, 0.026034098080990296, 0.08093413250941424, 0.01871025730525294, 0.11970027289803951, 0.06398707635760789, 0.03701156538520609, 0.012972571890831236, 0.026159318982653564, 0.0274765286444416, 0.011775804657278763, 0.08623022856491228, 0.01445398866874917, 0.03773607388739625, 0.06103636614317375, 0.0008175070275507507, 0.038519348994257956, 0.016032830763217664, 0.021694414918461156, 0.008015152772948628, 0.02644894809852685, 0.06336611229926348, 0.017431727422761823, 0.06074128822693902, 0.041894299548960505, 0.035364974305153854, 0.0891040848387826, 0.02261474315497664, 0.05470589817231221, 0.042022814628698175, 0.08967399296741332, 0.04715526664269067, 0.03868950095268027, 0.03936808631424943, 0.03274529451324094, 0.06291856373389883, 0.015034301229001535, 0.04814624733802292, 0.026235533239800605, 0.07237228024150096, 0.06671658251434565, 0.041416800776196104, 0.029725136513250972, 0.025673006368320317, 0.06735016787124258, 0.018598998356009686, 0.058860025263481566, 0.03730551332175251, 0.05151329952622614, 0.04589191487719936, 0.02822859332926812, 0.014966646089188516, 0.02312245835069447, 0.02699257941135476, 0.0417084006532546, 0.036033638828103585, 0.06775052542047155, 0.04389352090055904, 0.061669675708417936, 0.06403828933534604, 0.05773800522870114, 0.054043458113747264, 0.031463054849976496, 0.06646420250857069, 0.04293433668452405, 0.10296228597120893, 0.05150907455132373, 0.00946159955234297, 0.03061376594667954, 0.0719004083845404, 0.029867171129632383, 0.050616647237010544, 0.03878966311834032, 0.06306317049048601, 0.04817936148854995, 0.038047580559167175, 0.013111272109522214, 0.12084795687828334, 0.09772894017758871, 0.018480831208909233, 0.030182130942722003, 0.03562131881593697, 0.04184179954350956, 0.025285475046163606, 0.0038823193350371217, 0.03345736940842002, 0.011484196161731117, 0.021947373320618947, 0.011307413712324155, 0.05078055557884997, 0.04056681856332768, 0.02365695789546496, 0.03853438730021158, 0.024236359768697334, 0.03063515512152545, 0.03242511955660678, 0.024703263545468934, 0.05380140114275198, 0.06382442056952466, 0.017161593329341664, 0.004897039898130442, 0.041511470091439066, 0.018825706755442005, 0.040636835169167294, 0.03888356251521938, 0.03304801032608075, 0.05090590288502075, 0.02952565487864758, 0.041844258685746503, 0.018358714878559113, 0.07659462746232748, 0.028364842066601403, 0.04376371113222934, 0.048846888370932116, 0.08949295106914737, 0.020171960725659327, 0.035991274165890874, 0.05400406204224114, 0.04080495699459026, 0.037949168904414105, 0.040549443689204996, 0.004878701189638026, 0.09495133519052498, 0.045505155388626366, 0.057508109903503815, 0.022146052478121656, 0.032126979203894734, 0.010268534327136173, 0.008942435172596767, 0.05468093902773915, 0.044306974722853595, 0.03308112064616815, 0.05444839686876344, 0.04367581786467664, 0.03701048137079324, 0.03956256156426765, 0.05368654541070423, 0.018509728045413093, 0.015353277258034197, 0.06244176210114553, 0.02441282620683553, 0.017235162667930126, 0.024026654690744418, 0.014804609874714048, 0.05881273465591574, 0.02233583927004328, 0.009694237472309221, 0.023057710514554096, 0.019922721680373918, 0.005418120934102204, 0.03963140605558311, 0.07158116422473423, 0.01271957518427723, 0.031165379895678455, 0.07247125114043874, 0.034976065939953255, 0.07355216289720229, 0.0026957053999086063, 0.05519932008258278, 0.05332602060309822, 0.05198367368129473, 0.05467309428739452, 0.017367738013666485, 0.013970876386719606, 0.031720615525339405, 0.06320347949381798, 0.015497362117222963, 0.07991861401786728, 0.03097018835345103, 0.058689195317246264, 0.020758657671150663, 0.0928078901263014, 0.044294847551012234, 0.010533949318942765, 0.025927010480494752, 0.11812544127385463, 0.023627427121203755, 0.008631417839487475, 0.045731346678709796, 0.00955852403891303, 0.11805401889667397, 0.034048486681234454, 0.014840520246164694, 0.010824206626913961, 0.047546224293088725, 0.041170212395128705, 0.02760260947979987, 0.04786271436680709, 0.05715501997920294, 0.006827730854462472, 0.036324403669324615, 0.03179837344965387, 0.046234857966943134, 0.04016377970636372, 0.0320759117828622, 0.02558634650232571, 0.06475499140158777, 0.013917241613530825, 0.07141239505501525, 0.009701894521112404, 0.034501604705808625, 0.02216392339417531, 0.04668499590949186, 0.05008818829552301, 0.10535644863041178, 0.03932194100813039, 0.056515957093647415, 0.026790050662032543, 0.04143787202455344, 0.0381493323572701, 0.022581973744015542, 0.09113973367118067, 0.0747157202192372, 0.00216057957826002, 0.0032191081610958906, 0.05024406803591598, 0.029640698302236777, 0.01135890152410514, 0.04005017652807217, 0.052126721448956, 0.06301165107757815, 0.03404648336131246, 0.13017658654960895, 0.021386294355315548, 0.04881913300543543, 0.038831962663079464, 0.020327015006313884, 0.05216656951233745, 0.01577356649983314, 0.04905731357153385, 0.03777515969329304, 0.040871169973885825, 0.056014786204022754, 0.05353775198361086, 0.07233990536582086, 0.07484983923214097, 0.06768842633332937, 0.07342990292536636, 0.03281420412202997, 0.029532990170522567, 0.05571495471221786, 0.13562789967944547, 0.025738231094193556, 0.03635086817666888, 0.0866978333121346, 0.03323024349106896, 0.009613052262143503, 0.01671464231255795, 0.014944682348399393, 0.07918673958028517, 0.0413684951021306, 0.06145311031310309, 0.06325946519932439, 0.051562938193279895, 0.04941652836878935, 0.017582725267857313, 0.01348939587196876, 0.025061788863592574, 0.03518019389781741, 0.04680711415506179, 0.014166922116982601, 0.046300557667329434, 0.01701785608254854, 0.0475729224572499, 0.06119422239041137, 0.06934401128561267, 0.027346362645227103, 0.08541074431230945, 0.028026045427747795, 0.04796082341683008, 0.029375991941760146, 0.06847842386172664, 0.022545977187673413, 0.04383788376505818, 0.07536638933684557, 0.022730872508198507, 0.0674725197736294, 0.0360652131419028, 0.03800638035059937, 0.03696936160145748, 0.02375822322773597, 0.0709281049128021, 0.03354322488209413, 0.026581274465687817, 0.036271922816071785, 0.02120296568459561, 0.02252182052020104, 0.04971367472241964, 0.027220613142896085, 0.05769086017784092, 0.049776034279456066, 0.01930631392995917, 0.05028438341293124, 0.1285361318338302, 0.06765361529805007, 0.04527562778563269, 0.031030155800943895, 0.056670170592805075, 0.05743532772025755, 0.04776897967883176, 0.04814316383412769, 0.03713400538770422, 0.05254209432150087, 0.029408935637724017, 0.03921818972054509, 0.010547465982756788, 0.003572260330040609, 0.05519077820222705, 0.0727525509653553, 0.06268386503741627, 0.03960518669637461, 0.05999863876270191, 0.021464385527877078, 0.017318166379306107, 0.05284381805047874, 0.057815257534985585, 0.030065275721191883, 0.037641297319843885, 0.09318977729567597, 0.09239454738675587, 0.17388289854411157, 0.19409295682224537, 0.17256009452525647, 0.12441970392941468, 0.18632217460582334, 0.1599660074158061, 0.16779472120106223, 0.15584764130894216, 0.12185256627778854, 0.08932350774205501, 0.14949481123157088, 0.1274440964804061, 0.1312036346644163, 0.12706977825972343, 0.21644288253399635, 0.12994653034594753, 0.23133877274249834, 0.168046748806392, 0.18394995270477188, 0.09852728806436063, 0.1332983641975349, 0.09665262494837085, 0.1529492242562194, 0.13670934003687676, 0.10167695897360964, 0.1272126459967225, 0.2276148653078464, 0.21382882199700803, 0.07258095493119571, 0.11199637781828643, 0.14903347308356918, 0.15828024626018541, 0.11445832393702962, 0.1555116811106282, 0.1262531208715612, 0.09539714473630152, 0.21188844385887348, 0.1575532901070772, 0.10279760005012636, 0.0770401458946928, 0.2235717290351468, 0.14564802329386436, 0.08893354600595851, 0.16909500223494348, 0.11148831596778286, 0.14206126091941712, 0.16599043092179686, 0.11028396446378001, 0.18177683705524092, 0.16212485850818698, 0.12923762322433535, 0.08609192671194192, 0.13399452361608707, 0.09500031119152423, 0.17906332298392252, 0.17851040668545232, 0.11237583648894103, 0.18443070352077487, 0.15790107870294204, 0.11294808884662007, 0.20923103806712937, 0.23066060106840827, 0.17325792401548357, 0.09363104394006153, 0.1501435038423346, 0.08949035403108405, 0.09734860050582117, 0.14063483584792386, 0.17252926714718345, 0.11942174631140887, 0.0794247247939629, 0.15707563428628832, 0.17589669854890916, 0.12594701511965645, 0.09469368449983098, 0.1462066392864912, 0.1472559192728612, 0.09637824289741055, 0.3125374890383213, 0.14570073014305485, 0.09502968300254115, 0.11277630129047941, 0.0607314593188705, 0.11694337526756911, 0.10205108567231125, 0.06494216200324797, 0.1103629251461356, 0.06857482070523886, 0.22313600886733304, 0.1374764238754588, 0.1129058774019922, 0.14392126111253617, 0.13291588714045863, 0.15244365219146977, 0.14239807913620628, 0.10029721930022202, 0.15128705860866656, 0.24088695555204348, 0.09202507850263389, 0.07053841896835836, 0.15993254469527354, 0.15249927017477252, 0.09270455252619521, 0.08899241986293947, 0.1495227734408071, 0.19802327898721542, 0.13937313500190937, 0.12144121536684614, 0.10762286612824087, 0.14102218522419854, 0.15827070080464886, 0.12563360088895406, 0.12443717073408828, 0.252042421470246, 0.13591948806518508, 0.256236354489961, 0.15161828438360847, 0.14679237479163756, 0.15627684972939954, 0.10306682632935625, 0.12815652760646998, 0.14791054140415885, 0.09013091078809193, 0.2943451991004329, 0.13617986602888954, 0.1857079099863768, 0.251529295778563, 0.22325151960455605, 0.06142662665356071, 0.10281941057333063, 0.19506729808786225, 0.0812930217193019, 0.11202247077298742, 0.15759422984575072, 0.07124626888863503, 0.10478001343266619, 0.11538719788434044, 0.12905124935411638, 0.09013864061524791, 0.151308968723301, 0.13762702143961383, 0.06472560426881237, 0.1413328951645282, 0.1886253106978632, 0.21556718274950984, 0.11597441960005991, 0.2801327665726985, 0.1137035204878738, 0.11468562988504288, 0.19055136299181372, 0.1783655088154539, 0.11929328102738627, 0.16107380119783266, 0.2461105107419914, 0.17148459901011762, 0.13943069884853979, 0.16871431782361002, 0.10126052889972927, 0.15209817718113625, 0.09756418530859294, 0.23919250695936142, 0.17062255091244177, 0.09582598543455524, 0.13251556023474664, 0.12553279903987724, 0.11310782583971178, 0.13328693416570464, 0.18713232790750844, 0.09093715704136318, 0.08348712817795816, 0.11133266222332755, 0.12654123887900384, 0.08361688815057279, 0.12237678492261518], [0.0031548932348678432, 0.03522439334060877, 0.08969535915962151, 0.017419027600197062, 0.03895511512734717, 0.04190176890622224, 0.03566966279439869, 0.008397562797331523, 0.023496085177025488, 0.014081180598887225, 0.05255209942979198, 0.03067855017199632, 0.02547736283421757, 0.02738981515229229, 0.0485030068234811, 0.04993029374388918, 0.017451013686255585, 0.016131316153933446, 0.0300932704891649, 0.024212113085893855, 0.0310254137166926, 0.04538269623393013, 0.04630418126321128, 0.05405214938124823, 0.07321491567117554, 0.07109686642164184, 0.01330992732677729, 0.057338049875632416, 0.006529928538047018, 0.026537243562239795, 0.0021433773133227784, 0.06403559653629219, 0.057036096320277264, 0.03406199664177914, 0.030566435119497682, 0.040506033316975644, 0.02757504755150407, 0.01461721902277561, 0.06948907769495441, 0.060295754472815224, 0.005272367439653364, 0.04416042210293874, 0.06374137663853265, 0.0328257528974885, 0.013648842709259161, 0.01365463241874691, 0.027969862454600876, 0.012475647043526895, 0.03777096153146798, 0.009362655466482525, 0.0065692269333427955, 0.07345406533849817, 0.04380015010434774, 0.020057974503405636, 0.06986791583439035, 0.04686170558054601, 0.06495779785778254, 0.018516199573153452, 0.01817300367439466, 0.014007572955902547, 0.01208534631352391, 0.06990752258007565, 0.010247537772351456, 0.029969386410929506, 0.029000009395061966, 0.028775262180715803, 0.028744792948747357, 0.025463916075926636, 0.03878412430264777, 0.03633067026854523, 0.02817708540767912, 0.05764996640444283, 0.10419672940887752, 0.04177059933182694, 0.011009175683401767, 0.03744893647249668, 0.02162401335343959, 0.0322518955856081, 0.031434282502760334, 0.04743877663126877, 0.04879663683353894, 0.03973519947800425, 0.046975094254218766, 0.033689298697056315, 0.036064186584084265, 0.006911881303700108, 0.07263084257682485, 0.03098318503508645, 0.055380599468105265, 0.05570642815362062, 0.03320411223197176, 0.03589563191898408, 0.028649510763164972, 0.014735686859386343, 0.05047209410657806, 0.046016745074021245, 0.02752648715320374, 0.029569693442974842, 0.004999167079316272, 0.04501221228330847, 0.03540130219452324, 0.07413727021025074, 0.035315504177443446, 0.05484675492851004, 0.06024972407988483, 0.030663260972247492, 0.0495568526938798, 0.01548322109175065, 0.023398292138271277, 0.017176461180732135, 0.052501100956672625, 0.06420595916889368, 0.06530847460512193, 0.009689011795055723, 0.004924387800612397, 0.0888824632631675, 0.06094960285530937, 0.01621264404797506, 0.030622600855666305, 0.024286235923007615, 0.04492996508375772, 0.0772571862645207, 0.04407627117489615, 0.05832726856873882, 0.043595137314931046, 0.11073437819798147, 0.01968638355573339, 0.03176893077550396, 0.022050262759289434, 0.014796704804945379, 0.017324329556656942, 0.04726841016822765, 0.06767838292064206, 0.025862745279746673, 0.08037053694527957, 0.024484729304188685, 0.05441408762107453, 0.07112790064345445, 0.03187539976000065, 0.0055065677001801955, 0.044972153545747844, 0.03314666712896959, 0.025764818175605712, 0.04447326176769791, 0.008675577062662811, 0.019963061955246716, 0.039634064380680366, 0.09219492019544687, 0.0383018872760717, 0.03395377906159528, 0.0496920480603172, 0.12880228610048372, 0.1039176895433376, 0.020058685049955404, 0.05221936446163924, 0.05851026016077208, 0.04591361814809423, 0.02714212743505355, 0.03978070893114613, 0.048011189867411895, 0.05041505119973614, 0.03475833992143312, 0.0839317043221766, 0.006143512831430041, 0.03141753199029594, 0.035646285621389266, 0.024864806590842146, 0.08180865251849737, 0.03592129203400785, 0.08766271339188661, 0.016880657396189148, 0.03450250868955928, 0.03640177471923732, 0.06295591435064712, 0.01618232611837166, 0.050013544518620744, 0.0437775926454173, 0.009946829109873262, 0.01398899245090903, 0.04817211046634663, 0.00904768224685423, 0.05003959916892552, 0.031962860187876134, 0.06410350640034003, 0.012739224381925119, 0.035674761109534776, 0.02544002179356833, 0.041420160071744073, 0.04103653771322101, 0.0684848053741359, 0.01862419498783927, 0.045886081117655964, 0.060709495578081384, 0.008025814801634801, 0.02114994856979578, 0.04607741540718464, 0.09206055603440731, 0.0676103466520867, 0.1311742934969164, 0.014114083117625166, 0.056186332442467256, 0.1193597927809723, 0.02046120105191104, 0.034824989570845524, 0.03820320749054513, 0.03456202606039663, 0.026180024424027053, 0.019427304111060598, 0.02426834202431623, 0.02157755012083198, 0.01700261476329498, 0.01697093702762598, 0.042345452558008895, 0.02440903598683015, 0.03771966045361854, 0.03571301571003372, 0.04803511096284755, 0.015842021243917127, 0.02454038367666785, 0.03160684763814413, 0.03158149012785045, 0.04643639654762322, 0.010711018093711427, 0.04122575760007866, 0.07254265819586093, 0.04204380543782346, 0.02058184649344654, 0.021368448337119435, 0.07818064397020687, 0.044225884316068505, 0.09311776503079361, 0.060455491465906945, 0.01783941068776673, 0.0082959201667578, 0.016667022287184675, 0.03656692029307446, 0.014439383202472763, 0.023654383840039376, 0.009811704606568862, 0.03392468304223111, 0.04493250849566633, 0.016230815653538993, 0.04893805666436111, 0.056382247937783125, 0.013908331053361539, 0.05675599159252259, 0.031768630085993683, 0.014643823341166061, 0.012216613564129558, 0.043103825976891864, 0.03274128021251771, 0.022017098813047333, 0.0362323543747827, 0.022738625317992225, 0.022080073155643, 0.030089430473444444, 0.014529029853762159, 0.02160873756022944, 0.015506863522703852, 0.05458146634121096, 0.04033040382989472, 0.07295197897380398, 0.027654146129686027, 0.11723039776928003, 0.03466521044291797, 0.050784723097158056, 0.046484368973441666, 0.04183248774478993, 0.056482410103443174, 0.03707809629099023, 0.0260285860783751, 0.056016031096899704, 0.035344266948560556, 0.013878665256103682, 0.03817199323807032, 0.0267322531585852, 0.07386017620803849, 0.05283794981697875, 0.012688813881287652, 0.06674258353849573, 0.04167338277423575, 0.10247194373439397, 0.021573987811984077, 0.00954437631017138, 0.026392140763721643, 0.023202499217023293, 0.010541621689504434, 0.015091302958617528, 0.00892042929697181, 0.01685938313453188, 0.049355678004963745, 0.031677636077567455, 0.02341187679238858, 0.07955325136501944, 0.016101620670768525, 0.07358220886559257, 0.052180297807940555, 0.03981971429781087, 0.029841901719449993, 0.005843989690014672, 0.06006126645051184, 0.02903287648223341, 0.04774929121917775, 0.03161878137278461, 0.04368452062349647, 0.05414044484496117, 0.028300170839253454, 0.046902714267132745, 0.06938838309818698, 0.016417649176512516, 0.04223560321054632, 0.047761161751564474, 0.13024617797665058, 0.033622698843358986, 0.03311703867849804, 0.03717012260289442, 0.02526672121377722, 0.036806847539640246, 0.07167003042395077, 0.050907714682961666, 0.03717773368642215, 0.0282953827897267, 0.01990582944164353, 0.05522766150534154, 0.026512686613826986, 0.033951695302441236, 0.01448847507427056, 0.13518412026666826, 0.06229903609041245, 0.02759236496903243, 0.021590587022083423, 0.061605178766072764, 0.0839135020730957, 0.03771583767487638, 0.04061951392119931, 0.04460017955411346, 0.019946024159810716, 0.013149764197277687, 0.06640665398369874, 0.05053106372454955, 0.013835686765941642, 0.019460081182900938, 0.022040207855283253, 0.054069485950974695, 0.06658856156131913, 0.06946830139044793, 0.07314890953561953, 0.02387411700892112, 0.049278950468907436, 0.006156614371350096, 0.030370826059351527, 0.01219517459356857, 0.1499518746089551, 0.11915422074737088, 0.1863315821655335, 0.18544324193029635, 0.0814265891489002, 0.12712257703946483, 0.05176900052315286, 0.21777043629798198, 0.14444328874589937, 0.15254885138523194, 0.22814204105206076, 0.16781779576934155, 0.10928442656633355, 0.16568263211557943, 0.1162669119695502, 0.16323410785726963, 0.12965239854829927, 0.17403856761032538, 0.07938871866152172, 0.16335671256867149, 0.12334110575818247, 0.15583713058262103, 0.20418303958590955, 0.0956695349586587, 0.15126436708434937, 0.16379373508595652, 0.1604154099139475, 0.09155284658434892, 0.1293819388675113, 0.10461599400807774, 0.16954382250626243, 0.0943400736357416, 0.11502934289315056, 0.12571139711766474, 0.08309768738165017, 0.11931031116194303, 0.1397175374891489, 0.0683885540873293, 0.2301979452491768, 0.11174268780216096, 0.22518365463662535, 0.10036902472136483, 0.11231664087503188, 0.08765627825332266, 0.16251530287967575, 0.10748490901483644, 0.09179421790665196, 0.12809278909116983, 0.16257577786041846, 0.1427999841830423, 0.14394606703952437, 0.09269099276993545, 0.28304950844857, 0.09127635013071761, 0.22095512508624987, 0.14490268103057338, 0.2089069062663663, 0.07390235700914938, 0.14614910608337772, 0.12848856543461162, 0.06947518852088722, 0.1426715725251744, 0.08498319830264776, 0.11725966232798754, 0.12068271171301605, 0.12455138678271925, 0.07304436917747222, 0.19531906522329778, 0.10447851953006561, 0.12722320268831908, 0.09034447311874359, 0.08047477086825718, 0.15571244211206514, 0.06622162842822653, 0.12978042716220503, 0.22984493193366837, 0.16165156938856648, 0.09395267829419145, 0.09853253576664195, 0.1721483529094727, 0.15329822327100462, 0.0581868255000201, 0.14815587340103042, 0.12212257396670119, 0.07631241599278105, 0.20614810107696444, 0.20098420881455947, 0.2157431225022001, 0.10152016375814715, 0.17456719892159586, 0.2374733750137591, 0.07675775056404453, 0.138419003135735, 0.13378254708743867, 0.1214620223148696, 0.21243055831761132, 0.17098521693579613, 0.15772270279065256, 0.11519226681200728, 0.06330000657227731, 0.12106502789162821, 0.1764560499859433, 0.11104379344971911, 0.14957480613262425, 0.18015674495648953, 0.25540206941866106, 0.19511349318969637, 0.07651064890406786, 0.0839661552961315, 0.1019673522621874, 0.1604709053231824, 0.09905504603539744, 0.15322311601090818, 0.1117206474525794, 0.11364470791792679, 0.1687629950503188, 0.13940575502572522, 0.18658086717609437, 0.13433452875864121, 0.12482517128509861, 0.14760413687796364, 0.24497192022540878, 0.10735026906214415, 0.17511424698656605, 0.1556149497628212, 0.1535235297295355, 0.1468182992069952, 0.10407947199118715, 0.16295175849189683, 0.20501927052053714, 0.08448053737201038, 0.14352925392168184, 0.2818252080150189, 0.0859143092266975, 0.21794895010609783, 0.1484456231757518, 0.2182036436974041, 0.20907497063519495, 0.2023803274477682, 0.08667442932604782, 0.22548196927434017, 0.09357790808163344, 0.1418910208608835, 0.2067712063510572, 0.14399143476640025, 0.12678696924159605, 0.12346436164431995, 0.18426600993881304, 0.20708390811999, 0.12160323530195222, 0.162525154770382, 0.2642567281521136, 0.1636773050432244, 0.09166169235663069, 0.1285802278547518, 0.12949535052382177, 0.19006843648610577, 0.12289371041040267, 0.1676325863527675, 0.14840443828894248, 0.18696282329338212, 0.15029364175373508, 0.16433348999388758, 0.22386917033262793, 0.1465476709868639, 0.10167512036259137, 0.09763960666473835, 0.24725614926747738, 0.1656617792022805, 0.22330834800677918, 0.09976055938750507, 0.10270490341128842, 0.11853352098936036, 0.16765788257602723, 0.14575501513336936, 0.1163230891970377], [0.04733059735548112, 0.05286585840006029, 0.05908754954655325, 0.07930434939842071, 0.0591665753463824, 0.07963645617447554, 0.07050872540041324, 0.03392854029492986, 0.009544812022678314, 0.0732361899328328, 0.04289215205297355, 0.08629709271894348, 0.05646944023488511, 0.021602200915015513, 0.02212702859974196, 0.05124046880331251, 0.05721698883139799, 0.036157825511069074, 0.08031320292502642, 0.04341718658143955, 0.028740608193460974, 0.039795191823354656, 0.05877158807350263, 0.022408876177524368, 0.04677698391699984, 0.02795025634939873, 0.042097941040992744, 0.02480033454635451, 0.025302543485116576, 0.023099092669003916, 0.038331109699943376, 0.04249200900836338, 0.04051299705620735, 0.04570597384665762, 0.011819312705718463, 0.04229384121455012, 0.05816746262773391, 0.02219342927057897, 0.011248234377783394, 0.039693865204049696, 0.052380729391570055, 0.03287760938908304, 0.04648662127193905, 0.024895639714574622, 0.03793142630808777, 0.036942525541469935, 0.033168607887120984, 0.07324265571491373, 0.024862904777570118, 0.07907041678986243, 0.13206526907461305, 0.058840834760978344, 0.10153897887756748, 0.026964057957933798, 0.045716683755839066, 0.05088328796949598, 0.05258411807458728, 0.010707978639871845, 0.00730073364872125, 0.029482788428844466, 0.04906849845522835, 0.03761304399719642, 0.04150792693478927, 0.0155460134884643, 0.0724674130399381, 0.009476276839362278, 0.04996778608690347, 0.049245560526727676, 0.033896042845181884, 0.057547440857536374, 0.0213182580867602, 0.0562273258072955, 0.029547174288440618, 0.05008769033837223, 0.0683003926890031, 0.08630289200453028, 0.076423192306632, 0.039985216102532806, 0.0265697812316038, 0.013867236181883322, 0.014479479286819698, 0.03147045908976467, 0.016829396537955732, 0.03414460390265431, 0.04596453235154191, 0.06597592104827205, 0.051888969892095176, 0.030393835510157292, 0.028274198543400537, 0.042995999101549394, 0.03811139568325974, 0.011480330290543217, 0.015387617149240067, 0.01800704221691816, 0.06135596270342508, 0.12079037770989443, 0.03541169034677648, 0.05381866493412564, 0.011025911831717578, 0.036386698108887484, 0.039640403758253784, 0.016412872618304628, 0.045274080288025646, 0.04754111448663378, 0.022241641098873752, 0.015810850083888058, 0.08777655405743469, 0.017420778111104044, 0.07298485180663486, 0.08643457485783486, 0.010691437843976723, 0.031844629838521925, 0.02966612859088327, 0.038250942429107045, 0.03600616691513889, 0.012290922177564955, 0.05616526885498917, 0.048215386773189234, 0.015267817277250992, 0.0597444967547011, 0.011456336416754753, 0.021559435971862367, 0.06617881943501773, 0.03769833256580657, 0.038451308895262985, 0.05627907504658065, 0.0027209151988743896, 0.028460070626029087, 0.03197479775295623, 0.0596361642613286, 0.004203116498707284, 0.02527592192974783, 0.0060639747103015266, 0.011411171703178798, 0.03511291988674672, 0.008991439901893179, 0.031144159260175885, 0.049010689460462144, 0.04963302481619101, 0.019319234002802162, 0.06663628883900181, 0.03537272711494758, 0.025390766170476715, 0.07110275763777957, 0.05807976088216228, 0.017310461450007655, 0.06283456985388072, 0.02782194236774118, 0.02066362446414367, 0.05498676898799116, 0.0629398035215995, 0.045381673506551215, 0.079961767750642, 0.027906307800402565, 0.030032437362317598, 0.021338318099057483, 0.006265807277222555, 0.015066591835009958, 0.06179505365810568, 0.015303380993915903, 0.0638469435544985, 0.04943973700245542, 0.02623158980221037, 0.018352241435598944, 0.02845489187166095, 0.02143180572367724, 0.03238679600819465, 0.034493733152386644, 0.04855759058808608, 0.04184869433482809, 0.023329179516182314, 0.0644662605238057, 0.01167216636766229, 0.024423216274308584, 0.02089964849273524, 0.06990936885197317, 0.03701573290351418, 0.03942275434852608, 0.09695833233455498, 0.08767336967491335, 0.010899578187344296, 0.06427329829743793, 0.0845149040762936, 0.04700645023295957, 0.04360750580446855, 0.033192655387064146, 0.07424295203940523, 0.04702692393273596, 0.013429744435744661, 0.09735610050659987, 0.027165816788892114, 0.1304665661507076, 0.03917832250496553, 0.04630078749370672, 0.05582556631716509, 0.028395485583572622, 0.07979043984725591, 0.07755225268943657, 0.030567072887694648, 0.06486830346646809, 0.033095852516952066, 0.06813416693119273, 0.040902736626805804, 0.010935481855525606, 0.03448325690002211, 0.06448817063844012, 0.027216487759423834, 0.03722678246577421, 0.05759227232286527, 0.07234571231228691, 0.01422889479961727, 0.03307004301478306, 0.08605988125406927, 0.013589445997269885, 0.02057633066039172, 0.012038565154427723, 0.030144387705912514, 0.011392677383076762, 0.01594165480890942, 0.05342005406536403, 0.0866556142066275, 0.040887644694697474, 0.03042865229109603, 0.04232371098271782, 0.04476733227831222, 0.093429570476855, 0.06759631192131389, 0.018133686126900778, 0.03571927847881471, 0.03354605557697435, 0.022466399804538777, 0.01648026537300358, 0.0160094095401526, 0.06994477743583341, 0.04165208552994075, 0.030085408511841973, 0.036720674139477556, 0.054807144352385116, 0.032604974018590104, 0.06729253507669895, 0.0490581639291298, 0.040370148471406395, 0.019864135106364568, 0.032962507252851804, 0.0356838584036356, 0.059494656330395135, 0.047292036319812464, 0.04713647450590807, 0.04526489872425314, 0.031366686734761444, 0.003182668470770061, 0.030940979336118026, 0.047380707166608305, 0.009796440304677573, 0.023576212228245796, 0.02473403538216747, 0.03539603534004381, 0.0401222730626262, 0.007667339279226238, 0.01726482942279789, 0.010723362643001302, 0.028121346765528285, 0.07706116734733505, 0.01607964543866054, 0.025174085861973228, 0.05169588892209915, 0.02912932695190032, 0.02506691782224563, 0.00810559519806937, 0.0166199212863801, 0.06154327503135128, 0.04889725099107431, 0.03805793423746382, 0.012496635937432369, 0.028785027886530565, 0.01758860882311579, 0.05756488851001186, 0.06799766538484443, 0.015111251888165792, 0.04768439974155157, 0.06888607456799477, 0.018381088476387725, 0.09036973103760712, 0.03180535442586387, 0.033686874028775966, 0.01450763589086672, 0.04140108065198987, 0.04153876197374156, 0.008248685100566476, 0.054280631274225256, 0.0774959375661227, 0.04382431634791917, 0.045526192163027106, 0.004703508851478898, 0.016618551904215448, 0.054365525307554396, 0.018853383596926447, 0.03842101394829731, 0.06313812836343724, 0.030709486717598575, 0.028442837478172396, 0.04877088861840387, 0.019026494569956295, 0.025298586640987667, 0.07262168782612971, 0.06300182216950963, 0.04306684308234723, 0.049539194367225134, 0.03420897061005235, 0.05022614540892744, 0.09603473673304243, 0.03347701190279857, 0.017711052656053536, 0.026120512798849135, 0.03364551294174406, 0.03371660590111729, 0.07950993675378062, 0.0032692048050868778, 0.013562128259499949, 0.04211048190031321, 0.017848705249508063, 0.05522926262910328, 0.03574230708181858, 0.05766785072703516, 0.02393436982416578, 0.014498213009398072, 0.04310900856169962, 0.024464816763816823, 0.050858819121194464, 0.02726651521609916, 0.0749598571189469, 0.03765058996636541, 0.0020252185453089977, 0.011073483976595586, 0.013515365294991963, 0.047352947970672, 0.04816605837174481, 0.07738264082300086, 0.017737490350320455, 0.0308774036145018, 0.030909933622986562, 0.02793774996403485, 0.02350808019869991, 0.044637399935914625, 0.01925875136118022, 0.01452330813457769, 0.025951718731272607, 0.1655486433376228, 0.03731304396604819, 0.02690954505646181, 0.038067081327279734, 0.04123951653919874, 0.15024821273982525, 0.19865743124917631, 0.1800548092972848, 0.15865549144725646, 0.14831693572623117, 0.2443857863545418, 0.2198017950380041, 0.1484282636233876, 0.15148959693408784, 0.207422488339005, 0.11035429133522896, 0.2052218241677169, 0.13163036095999903, 0.1734130261766334, 0.09752054894042593, 0.23671415123728015, 0.17341822025276002, 0.16498287208378315, 0.16243284117550622, 0.1232203396577989, 0.23733938623580242, 0.239713094347427, 0.10444785303045666, 0.20739287137985232, 0.14229211385451979, 0.23181714868593603, 0.1073085785573048, 0.1168891822078055, 0.11992628415746075, 0.18161848668129216, 0.1743659169803704, 0.12369805676562172, 0.15079503097841818, 0.31011511902174643, 0.10238762043656842, 0.12502407835375878, 0.20751679376248391, 0.1286472758698848, 0.08274967662028729, 0.08897695254774825, 0.1537169975739333, 0.20321058289658642, 0.09899317677463255, 0.17551935428092558, 0.15905468454284055, 0.08315293764274928, 0.10873462824571518, 0.17465347574362833, 0.1083741991990997, 0.16489109475045435, 0.332484120322812, 0.07979621615020499, 0.14130154684666665, 0.14161850806445847, 0.14735304389990148, 0.11422393933659601, 0.18427377807036524, 0.11929178715593393, 0.14639347280946471, 0.16896292867679752, 0.16973862334364848, 0.11636031340927848, 0.1373312961790831, 0.18543427870158227, 0.1572094851684186, 0.08732758056853088, 0.16551075262888787, 0.10498722489442557, 0.13905637296697787, 0.17953025357377145, 0.13262702602772944, 0.22090638657250714, 0.1298935170615873, 0.1363758006764035, 0.1956418793528311, 0.19495141962843557, 0.18786535147697697, 0.14370622023219062, 0.15020606258223135, 0.16292287697715147, 0.14953095525983842, 0.08654913564603176, 0.09744046976970089, 0.08039905839870054, 0.18613535640460832, 0.1025465070720642, 0.11910034178365624, 0.08146756719196997, 0.1632740670034001, 0.22647845048096873, 0.1115676596941006, 0.12812686468204185, 0.09795669045659805, 0.14125866124466543, 0.13264412511019938, 0.27356769949678456, 0.20750741684629073, 0.13895992249731096, 0.09108729495276367, 0.1247554955883853, 0.14062886036211444, 0.15059267651409874, 0.08706102027527748, 0.11913768856996491, 0.233004339820435, 0.11731883495925896, 0.22840793484882002, 0.07669711470483773, 0.18660665369562565, 0.15188319758782465, 0.09531085259251057, 0.10665910453685831, 0.10514054973159107, 0.14922514828222413, 0.18364566258124768, 0.16870487962038289, 0.17644725529657257, 0.16764963946996198, 0.07027001240320745, 0.1056911830880469, 0.12238284467809624, 0.2264902942002781, 0.1477524821436213, 0.11196685278968466, 0.09707278587044248, 0.15562693137795697, 0.09077430207041964, 0.1444679414553027, 0.137387802824378, 0.2108244396625988, 0.09969654508055219, 0.14052171530502458, 0.10224845290424363, 0.09477161096348878, 0.10757022822696356, 0.1902906173059056, 0.21989371026715926, 0.12078119997656155, 0.11476494296784363, 0.09610111825168134, 0.11356967726662276, 0.11133774138626554, 0.08482795824567158, 0.15056783994359357, 0.12635779146465564, 0.11983950937827749, 0.1308938287078373, 0.26228150833518277, 0.1525391067468351, 0.13467723053068886, 0.18624994783632218, 0.16013747321501856, 0.1262538946203647, 0.14962109316500927, 0.12596036803217667, 0.0934704106240984, 0.1308242066372787, 0.09938460173866442, 0.09475900881713438, 0.1775918212989646, 0.18737448830037348, 0.1611028972171968, 0.15398385664147718, 0.14490281892639978, 0.16078271843012304, 0.10416951030492784, 0.0753076916800872, 0.14037333939584995, 0.11325346681499675, 0.26990543149652024, 0.08994376316906945, 0.2196318614146402, 0.23098081049899902, 0.06327912301546143, 0.12273732888241931, 0.1821564336217219], [0.02683235595243112, 0.04063116994896724, 0.044232549281009746, 0.07903976561201197, 0.037831884673646385, 0.021737084100623767, 0.00921810903931938, 0.041879686421804854, 0.06768801264585027, 0.018407905384177164, 0.027093249110264644, 0.034632406558000275, 0.04589368454030445, 0.006487442259376328, 0.06058523994720271, 0.043158172254240325, 0.01733117263704058, 0.07966304708632731, 0.05223154142919568, 0.041862388156474604, 0.03233244206996695, 0.061868471694329095, 0.030436972005953713, 0.06249988902240031, 0.025525434851466168, 0.07041227493074632, 0.008264897436264062, 0.027955331681897084, 0.041494114369514494, 0.016352889849053278, 0.03393809341134564, 0.04587623305738934, 0.04091685179681067, 0.042187979354733424, 0.03715978041591664, 0.08518925297164148, 0.04022035529957183, 0.04423430745279597, 0.03670352526129254, 0.04751271177684108, 0.050805231270891045, 0.021106204949319366, 0.008417169860143577, 0.049748972223530856, 0.0505343119373485, 0.018756607539891716, 0.018653524664020347, 0.022947966504181107, 0.009083954594849099, 0.056425907288587866, 0.02627976907176837, 0.005926374785391795, 0.030869240947668592, 0.04427339325869276, 0.05293370697707419, 0.037544272284233765, 0.023670450619031346, 0.022119411770554803, 0.03681608272956745, 0.043076871173276056, 0.07739286809679001, 0.031121517531573776, 0.03068057455933623, 0.04796885584871616, 0.038898907256342714, 0.026079322166380384, 0.06718408000925857, 0.014755097612167799, 0.017303558997809887, 0.03544936272045297, 0.053285578821575454, 0.034879864448861736, 0.06978463441614183, 0.03935323569983725, 0.012017854925004706, 0.08759363524375424, 0.01019622520318315, 0.041541439451036916, 0.0136044823880037, 0.0640397487328418, 0.02293585273887842, 0.05001311933982277, 0.07899559298229795, 0.003926973163728573, 0.032905020015013796, 0.05696539406574542, 0.026165851797427864, 0.0195552695227126, 0.09483240770115968, 0.033705363560828476, 0.057034288352775964, 0.03848847565090945, 0.05362421266674515, 0.0442802727282528, 0.02201298875133357, 0.0727860749729218, 0.022745102591392015, 0.03950996196738655, 0.037256219394264684, 0.06491081368538641, 0.04333842125150465, 0.01075963307577636, 0.035227856058026516, 0.036333887837827206, 0.09595199923722014, 0.01234988030421758, 0.03698353422805667, 0.05667981947021139, 0.028852805600411473, 0.039062298488833254, 0.028314485192118634, 0.021354513197776773, 0.0976143257632371, 0.06893831410355146, 0.09168346457543874, 0.03739084019475887, 0.04628258141418619, 0.008807891938504914, 0.028218277955367684, 0.05231141758662078, 0.053351171269652345, 0.08312133651587271, 0.013934474761387514, 0.03804167019083135, 0.050719326001501856, 0.017894053824185845, 0.028014441110914754, 0.025813556689348434, 0.05080536150583818, 0.013774955145744307, 0.081573203055849, 0.03776635734304305, 0.03351552314275215, 0.018558600624542565, 0.0443016427509006, 0.034442087334971276, 0.034441064607592366, 0.07529319729655981, 0.03482842547518592, 0.05982721126788567, 0.06576168456024702, 0.03154567743261014, 0.017469675588091056, 0.02122525501275255, 0.017903338809828126, 0.05333795625295851, 0.0800937417173578, 0.010132127584168508, 0.06345982017416148, 0.04642341135730667, 0.04968306567940501, 0.06997340614156378, 0.00788642558261692, 0.04000226155884805, 0.028475053390608202, 0.03416170298512425, 0.027182504099102753, 0.08622120404916425, 0.06727750443162457, 0.0336778418521487, 0.06412275435943758, 0.03500015940517187, 0.023158606209401644, 0.02029207182086764, 0.030747729826778657, 0.037237025061321836, 0.0045209467474881925, 0.044472530153730226, 0.03493388130840275, 0.04410134906309747, 0.021449795383359158, 0.009534997478758377, 0.09455217273845788, 0.02359204151998124, 0.05074495547300866, 0.040804497341835694, 0.07989019981675571, 0.007614131121250291, 0.0472262523497545, 0.021955258280579603, 0.02360804892715908, 0.052794665849256905, 0.02298334252930457, 0.04776496537810853, 0.028188775909403642, 0.023298045702939554, 0.05402064784580181, 0.027771727219524405, 0.024297627650441665, 0.061422558726682785, 0.015443983983488814, 0.029816915761799585, 0.035420266701088804, 0.044298804395141146, 0.04712658431080561, 0.0827353967413787, 0.03050557134913341, 0.047907645423566146, 0.0722433553047238, 0.04682460011193349, 0.029817517140820145, 0.05846354794958907, 0.028090906261857, 0.03313262856775715, 0.04565300269713325, 0.043572591347319466, 0.11254800708904383, 0.05462801384349024, 0.039456738008847164, 0.041670789566612056, 0.038713349269763116, 0.04333178309964077, 0.04108470166102052, 0.033813240231886026, 0.05056104457546627, 0.05015770311377222, 0.051975116479180516, 0.07710254375612544, 0.03295034560705385, 0.04630880460383431, 0.01572943025929553, 0.05435597219113862, 0.07455747709759782, 0.025959634334750237, 0.046687037533810066, 0.038420960322142615, 0.04060957393038177, 0.04017471944192245, 0.08105204876271949, 0.020976058102302977, 0.03757443699625231, 0.037136445377743056, 0.059348992372472445, 0.021633319406499787, 0.06605803035199642, 0.024026576166732178, 0.01557795839729689, 0.044904714825773434, 0.026050563225702896, 0.03850810282352952, 0.02109343809406123, 0.04168731791357841, 0.05550672052307956, 0.043340064510102236, 0.05127249510898706, 0.05659667594778923, 0.008102502118075087, 0.027468593888765866, 0.07513271719818154, 0.0901257167119653, 0.0832878840306113, 0.012911586504008983, 0.04457053578188343, 0.08253159437088237, 0.027076810778629397, 0.038301822158598134, 0.0071185962447235665, 0.02918780818882008, 0.03362166845510083, 0.016779556772821856, 0.028096701717004183, 0.009524382372957566, 0.049792800113678946, 0.037714144620563717, 0.05888393486759836, 0.0562616159027863, 0.04766578763543118, 0.024604740807966843, 0.04818981092783713, 0.015772520789816495, 0.029935433394125396, 0.021348154668005246, 0.058633194289981365, 0.05052352541937463, 0.03004778593388056, 0.04876876655485361, 0.05327419092458102, 0.006160612871509887, 0.05962904730451204, 0.035640321626898744, 0.032353329457222454, 0.01680631239357735, 0.10847137745229468, 0.04700028705560873, 0.060519394690110806, 0.010593119077384474, 0.0433224291660853, 0.029095806774773428, 0.0860080554059917, 0.03561587193079534, 0.04183516139164568, 0.03265432923311188, 0.04030603457302336, 0.04730180777128666, 0.04324997257020685, 0.02295510261319578, 0.02939346066165355, 0.035360274355738394, 0.025823828013193224, 0.08598732506676067, 0.01713039439862534, 0.033096300678387765, 0.09878344488360229, 0.06526990973901364, 0.0827031827441627, 0.017916172697779634, 0.05540131831601743, 0.006072171851091328, 0.05910254954811066, 0.012590437658101082, 0.030815949956435832, 0.014034127478577919, 0.03922207378632119, 0.01620199542582756, 0.06891650358034719, 0.03537784841272139, 0.08249490642018857, 0.0007212701048927322, 0.06798120215535164, 0.025874770944938067, 0.026960876777828224, 0.023731737652973785, 0.0868175498720619, 0.01933821383112621, 0.04476099673117842, 0.079498085373592, 0.04636352243382604, 0.09086237153819493, 0.039474082239452875, 0.045301318544173436, 0.049817295775057814, 0.04897356483965151, 0.05675438280788161, 0.020449163895400784, 0.03965461851968881, 0.0078099776686529725, 0.045228750865545966, 0.0246119458648947, 0.015887906080141904, 0.03663923516268692, 0.04885809623726434, 0.05963934352621437, 0.04300278281011889, 0.016656320038882476, 0.06770393961379606, 0.02481158454752257, 0.039299471649311246, 0.017120787656054865, 0.03092290349154463, 0.04816777057825558, 0.08235191610912163, 0.012461175642637237, 0.114339733526351, 0.14321112825024512, 0.1064494722372582, 0.16929309725040392, 0.1890096723312332, 0.19579307446556707, 0.04971008177005476, 0.1394305915962304, 0.12245790597291724, 0.12144723681793099, 0.11108630366863743, 0.10705475064535296, 0.12618214282537663, 0.10908993982499647, 0.15445765137912768, 0.10231598355476895, 0.1445842029586915, 0.2036844848865463, 0.1565058946970009, 0.13447375757799995, 0.06844621752538989, 0.11351170739339245, 0.12360057973813628, 0.11545664375467647, 0.11183025931278545, 0.15022553653726656, 0.16915328620422274, 0.16444054312042652, 0.12823734222160232, 0.21999327105379876, 0.1940790599872989, 0.2650288528492374, 0.11870975951634108, 0.0742708146572113, 0.14009341086831786, 0.1339201671221564, 0.11072190628657419, 0.14944224227820674, 0.15158158877203542, 0.13024827705756312, 0.2325757902355925, 0.17250312822720698, 0.15055423422205835, 0.1516587031824935, 0.1651064420659696, 0.12049951710768285, 0.27425598353147507, 0.11503072185141426, 0.13581644923936936, 0.11199601775696201, 0.1636103336368838, 0.08559377037829931, 0.15365112933420366, 0.1312349676605194, 0.11148471535453874, 0.18135225580584619, 0.1490584628716592, 0.15462321830132317, 0.16674818380946116, 0.14662274760344338, 0.26668611553407484, 0.09567608501041129, 0.10388394337027304, 0.10295847085334602, 0.10839239378730137, 0.1067915611389664, 0.23248027439319321, 0.1339557289236015, 0.08191855549211464, 0.18396873718067525, 0.17323966047936873, 0.11242010104920595, 0.1604322485265232, 0.19278308436755212, 0.13939222591298242, 0.13372046332205498, 0.1272189279177016, 0.1940680129994308, 0.0786960372821458, 0.11302499641333857, 0.13235656634694146, 0.09175123271322058, 0.1142403489399341, 0.19907821270246662, 0.1613186122549157, 0.11090377555979837, 0.09170553556853726, 0.10968616307382623, 0.11771486411171576, 0.1315754784211036, 0.09352792850545338, 0.15463334598368214, 0.16245729470204923, 0.10251837632348461, 0.10350093771252902, 0.13635977411702757, 0.12340060780726134, 0.21215220793120323, 0.2041493470389997, 0.14695228798495186, 0.1811380269787004, 0.12821136418008997, 0.15380672179162502, 0.08169172451861444, 0.2758490174047409, 0.04903573670514649, 0.14493902424170127, 0.14531528066483237, 0.3170459164727119, 0.13013258245923828, 0.12007023207843305, 0.13375627027163584, 0.1853715207788252, 0.27855407386537523, 0.13381703636578976, 0.10289463274661573, 0.22473072813403225, 0.09148932257366758, 0.2865621747989809, 0.09354097498280388, 0.13822683764080848, 0.2172882299149229, 0.05798035331310765, 0.1704916724514577, 0.11322086211293937, 0.16773786215532213, 0.29027080644042264, 0.18839091843655034, 0.11575410037391609, 0.08766542534313856, 0.15631133900775065, 0.13837921252894786, 0.20917253959323132, 0.1552035452257241, 0.1841427617135548, 0.12335923905935019, 0.11484411815481801, 0.20988299421245055, 0.1613325550551376, 0.1387832319784549, 0.13962097976717258, 0.11092927096591843, 0.17322567171387135, 0.17712250051479186, 0.09836940500404566, 0.12995797569953627, 0.25850304011856357, 0.12176091151852762, 0.3026090201831633, 0.15881541996232926, 0.1692257274783427, 0.3385789626308026, 0.1624406246288169, 0.1548517576508945, 0.1629062222256776, 0.13108190329324815, 0.1519281822707384, 0.19489903453617327, 0.1316291045758032, 0.13710010616529372, 0.12711087887686107, 0.08781306580790589, 0.15148490847599122, 0.10700751366394182, 0.16447728469727502, 0.09733268119875463, 0.08933830089987287, 0.05585835104988468, 0.12830005417908394, 0.09478439697094503, 0.10505359875218523, 0.11383933255509024, 0.2506124570725426, 0.11363454959205083, 0.15836238620742676, 0.17267833253548992], [0.07590245936186084, 0.026801564963534478, 0.0035412215595809564, 0.02864078885214704, 0.034877887942017086, 0.01673805395952396, 0.013256846052113802, 0.02144673677732147, 0.055342019280238505, 0.0762790298810409, 0.01937016927366776, 0.036254662855137745, 0.06214533203972444, 0.049422940524715575, 0.02925339297601773, 0.054318954822637384, 0.08363800153376595, 0.06749894980701708, 0.029741450355598525, 0.04404917081457473, 0.04744741044217541, 0.034961219155980695, 0.08361645148045595, 0.07012630963037092, 0.00363129458668071, 0.026061866853025653, 0.02453347356359084, 0.09140336750856332, 0.034333367967197014, 0.02942855897990446, 0.04367299100023605, 0.035681579292060873, 0.03136306505409941, 0.022526840311324885, 0.03877857782607598, 0.021327613935535474, 0.044453918047609835, 0.03038157235770937, 0.020634503546921958, 0.08707116327939496, 0.07359766851990454, 0.034482092446377205, 0.06669404420761332, 0.16367989442040845, 0.0124784758231873, 0.024240686250249707, 0.060380989415270675, 0.02772629245995514, 0.004769865472260262, 0.05727650237179572, 0.04273603099488443, 0.02412329859761221, 0.036332348001099406, 0.007119802354399356, 0.02688127641205586, 0.061109359000599196, 0.04931469230101474, 0.03520522582074327, 0.03277873425113578, 0.08660764944168829, 0.07205413924830575, 0.020494148578314532, 0.036873501019492265, 0.034506377433576894, 0.04911909473218745, 0.0695989653468132, 0.02896983702216418, 0.04338054842646084, 0.038301278236171896, 0.043448554051499215, 0.0157503645694364, 0.0440783204600936, 0.039996795521508303, 0.0584292080583832, 0.025939671998663295, 0.03486699417173382, 0.013566616577126328, 0.030102668472776012, 0.04387716492337566, 0.068563214473186, 0.037574705127025806, 0.036994079428334395, 0.05566372641272122, 0.020414320301384698, 0.02403346712761108, 0.06582334697727235, 0.053712381725950595, 0.0794303095749309, 0.02395220435104303, 0.0049086016013226924, 0.025559872418882388, 0.0423003874358631, 0.022800410309085445, 0.05357952292768225, 0.030010996476536798, 0.02094384218986717, 0.04752160222720235, 0.0466582824235722, 0.053724589337024, 0.056281622288928884, 0.04754110299531491, 0.025459407648492246, 0.051083148817621896, 0.03537013007688426, 0.026152837878814148, 0.04469235525316289, 0.05889755974133169, 0.0220997960892536, 0.02677462165123753, 0.03991172145751696, 0.032010024390934456, 0.0608404889522541, 0.02439931241585122, 0.08741928895394649, 0.019906312077035828, 0.059179476267027284, 0.013923089737222802, 0.015140680198167122, 0.0732454059705619, 0.043582332155276696, 0.07700834558495591, 0.06797950910103899, 0.007573994338482379, 0.01935344940472034, 0.01686817590868281, 0.03163377179824297, 0.03390062022052946, 0.03452655618950244, 0.012173380349732697, 0.029895776852725015, 0.022414801867618676, 0.02385622311022974, 0.07012928205151713, 0.08442616045114495, 0.05314822308719159, 0.03513450824445294, 0.03612703260695262, 0.1360285330203272, 0.05266684790953033, 0.03564759563173979, 0.05798024606079825, 0.05028497330063293, 0.02323745580900821, 0.017029569566910787, 0.040483655888707414, 0.050370326986716646, 0.04212768823509255, 0.020692973292522857, 0.04764746281228239, 0.027954670931062395, 0.08854097957091947, 0.06752585481491781, 0.019258854783049995, 0.014211830191103923, 0.01613067072485724, 0.054707242656619325, 0.009295342193405715, 0.04189366752642297, 0.07709927256068877, 0.021786272691022006, 0.014421519947298353, 0.022755912092003613, 0.06060728029678426, 0.01431270769136327, 0.0427153542818081, 0.0376948123917945, 0.022838408270129756, 0.005247574919203838, 0.01194594608199212, 0.057401232977187445, 0.022977788391853535, 0.07443848066031933, 0.03963724747600575, 0.041018323972821236, 0.07975014362243876, 0.06085389549092901, 0.10585622140957464, 0.06450140863777169, 0.019907999385689056, 0.04538214848106427, 0.04608736305888142, 0.09624413920626526, 0.1479314709262502, 0.04206304573604176, 0.08125370608702784, 0.03486037517206804, 0.027146697149521885, 0.017114069064958923, 0.012232970498922852, 0.024080439808688337, 0.06374832505600588, 0.07336064091613216, 0.007973203234629887, 0.012294521833199167, 0.0828319161589588, 0.029956742129739256, 0.08426430139450297, 0.03537196868790254, 0.014675157294879037, 0.018273001131150993, 0.04154961360918899, 0.03299854785924958, 0.015815330740635195, 0.028980577574862592, 0.024150115505401647, 0.005447299786723189, 0.041515013248088865, 0.041422764770686626, 0.04013120947826294, 0.03902491722856799, 0.03647896573848782, 0.020247125442350106, 0.007394091996003784, 0.031971695096862894, 0.0314469114621921, 0.0993002477973219, 0.04225600030153029, 0.03511553990744776, 0.03812004481592486, 0.03405189960293713, 0.028296453397600885, 0.02588874055823732, 0.029230163274933735, 0.01962539529608142, 0.04440299235284329, 0.06433732026527006, 0.03609099200055484, 0.07724928789802137, 0.04219092496280228, 0.02588557278467042, 0.034527609560398326, 0.04772497175802146, 0.09763275017781604, 0.033387027215212584, 0.04872218457861774, 0.026599425003833832, 0.031457037229331276, 0.025071349640887593, 0.04286138979237407, 0.04769478406336519, 0.013897990781603562, 0.09445857977674854, 0.016321964794769883, 0.025103803040579926, 0.045078804476126555, 0.008895926932323604, 0.05074744525876257, 0.036110527242623994, 0.024686013160633947, 0.018277764282820207, 0.011558507647996229, 0.015560594056883167, 0.03509420818919617, 0.03168803380591975, 0.04252559813340345, 0.010917693293923813, 0.02508224149595105, 0.05102959544127507, 0.043389492502976815, 0.06087359161146226, 0.022074764166327736, 0.0441804591325983, 0.0425069400620076, 0.02387868097773002, 0.03209236735147575, 0.01747205812153557, 0.03754360578773964, 0.023343526427784277, 0.04045035404663894, 0.06415190017451683, 0.04021661679050134, 0.007354222386399465, 0.04496694797830236, 0.07724539617136603, 0.055210110430996266, 0.09550314066150496, 0.051132615114892685, 0.017942566341990908, 0.05604962022193978, 0.05650490627533967, 0.039549304412737976, 0.02275606722480828, 0.037972592042698976, 0.07955500570636603, 0.01474768092345086, 0.034881159137453766, 0.04077116485625025, 0.03797296742578188, 0.010567639950632809, 0.03132170205184769, 0.03608693556499577, 0.046550156773939255, 0.06516022893089442, 0.043987427958317345, 0.07100167233617076, 0.030035913486274022, 0.023206126643344763, 0.02447087651929788, 0.02041905472475675, 0.02583563725854601, 0.0867229993004472, 0.08068111665066212, 0.004667474948350461, 0.0429749355140713, 0.07202754833645399, 0.1079320821971182, 0.060707365853651885, 0.034097481834431814, 0.03909431330318894, 0.03014292447797714, 0.04509136065720551, 0.072416138775166, 0.032621713039735635, 0.027232493251381863, 0.014994274092567785, 0.041935645314233924, 0.02289200761175204, 0.012763829210833197, 0.022567374023398565, 0.02404725287980851, 0.038603235621966665, 0.0203951527815192, 0.016857872026101235, 0.007974417005184918, 0.05814147692534232, 0.02817571985595409, 0.02258641896919618, 0.01555972837752873, 0.08646638282845098, 0.03296903049152705, 0.04889599460687849, 0.0481870491808701, 0.027017620910379677, 0.023128136977433197, 0.03888579949195828, 0.020155901607546597, 0.028099250874572226, 0.016754534425995043, 0.032469759499954606, 0.04908200841577304, 0.03968168440605364, 0.08725564491244094, 0.011343068401930074, 0.10913043523267393, 0.0245373499684877, 0.027193409360704884, 0.06284056449188821, 0.025793027448197527, 0.044270133554574945, 0.06141130872551472, 0.04596056018565451, 0.09841477273092156, 0.22693552918011145, 0.2212575765987558, 0.08358712563471449, 0.15964477142739683, 0.10248776345003037, 0.16759103374375453, 0.15549874954646634, 0.12442327389914183, 0.27071969102947946, 0.1706173874798321, 0.207820670198529, 0.19261747148008118, 0.13078679090305684, 0.1886486457360368, 0.11590403144157703, 0.22765428819242986, 0.12105227252768895, 0.2066932645656409, 0.24601421348990934, 0.14806064867204236, 0.13864991735787163, 0.10857868338784865, 0.194658191814538, 0.1472324616606197, 0.12495412686539274, 0.10561429850396611, 0.11673935073157472, 0.10834799899208931, 0.13004713301216403, 0.10059874384633957, 0.12036612587830714, 0.10914457721575614, 0.1344554174330927, 0.0915163501556362, 0.13541339506064692, 0.15355162983459814, 0.11042095630639985, 0.1565612828539264, 0.11500349508658533, 0.2584421820938587, 0.2822290895686996, 0.16335472074006835, 0.1060923143860794, 0.17100898098320733, 0.10080253855595667, 0.11686662091843544, 0.1460664145528309, 0.10500084593771927, 0.1669391388854673, 0.2339832316483221, 0.13413603537746016, 0.19346635818721789, 0.1369571388368645, 0.13584536139763173, 0.08929757566581811, 0.1125421311946646, 0.1888418684322988, 0.11851554856665673, 0.0964067260464353, 0.1674439295405342, 0.2643956045710272, 0.07343899638902757, 0.11178086962430708, 0.16914237711218097, 0.1272648548887622, 0.1481466343806636, 0.095852070728377, 0.14945252317815058, 0.11222605863886495, 0.14769070481340732, 0.2060602767573249, 0.14208422823538705, 0.1454643000878634, 0.17810500827768158, 0.11617511931446292, 0.13684040235896267, 0.10691063418503731, 0.12847185705698308, 0.13670799172213002, 0.19222028553485873, 0.09371575794272846, 0.07269780632228622, 0.1603335610801174, 0.16134412298279424, 0.10164895845997719, 0.1938760466873646, 0.13007658143197337, 0.25463973532520956, 0.17633699992251012, 0.12558552121082622, 0.21010762651360806, 0.12554370047103974, 0.084483333592934, 0.1207983909895824, 0.12765018945379605, 0.06766820927300761, 0.11467125807558337, 0.1881015670275496, 0.24286214472545734, 0.18164919148529732, 0.12473354716935467, 0.11319532074154386, 0.15769288664863956, 0.18925765499232278, 0.10758938042507057, 0.09849455312735612, 0.1616983007519476, 0.25428564948660715, 0.09849832994082282, 0.18876674585044387, 0.0894247156177317, 0.20840597669443778, 0.11857194029876303, 0.14029846196213078, 0.14664010715580758, 0.15401747257959458, 0.10404341989347052, 0.1759925974352706, 0.2668990573335079, 0.10912059100284692, 0.1461816188548842, 0.1627053080066558, 0.1590064056818524, 0.32342344522476196, 0.15934593584989348, 0.1578135914619892, 0.11219472564276188, 0.14692809492830308, 0.135671520725854, 0.14704835541065664, 0.1362199477490879, 0.14899455581701573, 0.1079210581918878, 0.10800823133679167, 0.16247652350894867, 0.18447731231008807, 0.10533596343931653, 0.26013600249444285, 0.09977604202445477, 0.10320149692556552, 0.1652248486155464, 0.12478335054531214, 0.08331939322693695, 0.1783008816381616, 0.1847489977315549, 0.10212816177837311, 0.14562261981829522, 0.1098466967983592, 0.1652019579083689, 0.11779719558093818, 0.19862462736425862, 0.15478624181161005, 0.20306372384150184, 0.15270067469006585, 0.10809345095748864, 0.19738633816521015, 0.1052844670090464, 0.2096016254396208, 0.1219131944761161, 0.10035874382142099, 0.12663952795968902, 0.09706715512419901, 0.22782036073265538, 0.14828656800091267, 0.13809185294855025, 0.22613777118104122, 0.10835511594890587, 0.167347218600973, 0.09065794097560068, 0.13570081592807848, 0.14389006601225945, 0.17372758187834295, 0.15431094554162797, 0.11155263670990545, 0.1994772679022243, 0.30505890807797836], [0.04911048390391854, 0.039567981636331934, 0.02583146016413887, 0.02484629982181134, 0.051684512516423586, 0.10045411410711466, 0.13484693432767547, 0.0434367026713106, 0.02243165580195285, 0.01986796363076616, 0.07138866931200027, 0.046294884786250136, 0.0182818973271717, 0.056890332770924416, 0.027789979264320388, 0.050094018224626786, 0.02347327873951966, 0.05024427871009515, 0.038124392364895156, 0.04373795908665465, 0.0784594540093695, 0.023429642371352644, 0.08161459478639788, 0.011142223130821461, 0.021033007163374175, 0.035945695764835806, 0.025874573677297563, 0.028633890230388894, 0.03740394795914331, 0.08506054253948313, 0.0158284327593602, 0.05710871762505943, 0.064436390755638, 0.006569501767385632, 0.024415415584019596, 0.01764422489119874, 0.03380014778926008, 0.08085236028437653, 0.08768336712232522, 0.022815255177838188, 0.08498932700604202, 0.041125518825626185, 0.03183798977143822, 0.10971739647849914, 0.06914256846592312, 0.048764790558526595, 0.03435891316903215, 0.1353650855561418, 0.030948984954926758, 0.10202042683358155, 0.10205761274142612, 0.027102426843597528, 0.013982212572779148, 0.028205357882524693, 0.04571836531883286, 0.06804697846453037, 0.016734150741549752, 0.051935444616021655, 0.058295242263064276, 0.013499685390401753, 0.02968629585548995, 0.009526583918129966, 0.056828417544884074, 0.05317143938173691, 0.03480521301108022, 0.06086603032364961, 0.021349144836647377, 0.01738536186636456, 0.010786413594389395, 0.023436558230089086, 0.023167519642400648, 0.013440975284714614, 0.03439418768750564, 0.059125187446273146, 0.04171456383060544, 0.03867023384138461, 0.05682441473547971, 0.07162520661950111, 0.07414026561403468, 0.037011584537404205, 0.08955322686702975, 0.012569830850547841, 0.05770327846309351, 0.031752996146678925, 0.02500980788271033, 0.029443445983493043, 0.009810351503772602, 0.06774725422503487, 0.12408537549837945, 0.031684055894372926, 0.03435002654911049, 0.015724275445175028, 0.015284616627820559, 0.047314988314023906, 0.06926801536352405, 0.03804936171359113, 0.05814247283964388, 0.016581722227255666, 0.025198518321098342, 0.007390343910834242, 0.05301919472854465, 0.039297912660385334, 0.009607555581286792, 0.020958991578569817, 0.04269828201241551, 0.04289471844751989, 0.027320758071577838, 0.008115090857890826, 0.05322531834545155, 0.030422807040233767, 0.09130474901007068, 0.014771986978068469, 0.008517458430311133, 0.034814616740350766, 0.017899268967730385, 0.02504919054767778, 0.10195312600943351, 0.0861904456190044, 0.034744439256047054, 0.02138701064752475, 0.05476127866835845, 0.055072712561776566, 0.04027789999400416, 0.02843115655254693, 0.032849267966324286, 0.03385772695764899, 0.036694508406423756, 0.034239269387457645, 0.06313073178452831, 0.03327855299557409, 0.06529411045654167, 0.03246055112310475, 0.05682261825929727, 0.046733883810379816, 0.03245678197051729, 0.07707140228200345, 0.04254900978036946, 0.03259558944151767, 0.03709417264608126, 0.054501743401370706, 0.04022013313407379, 0.07314863374396678, 0.02851645852769575, 0.020316929458790732, 0.013247375290149884, 0.032831295543620666, 0.04326846210225936, 0.07000526007745536, 0.024104772676383297, 0.07328390188875698, 0.02796531380755046, 0.05384384241375712, 0.05780284691061224, 0.042598617803906245, 0.009149008866159186, 0.00474898430946914, 0.022528849376906312, 0.03351649224397636, 0.01639663155430988, 0.04723326588470129, 0.051643821756325425, 0.018371502801235166, 0.01924963491488128, 0.006903633409585323, 0.05699601843051853, 0.054811648949379885, 0.06777651878374238, 0.05815543121688309, 0.04775367707254426, 0.007181541859022072, 0.07474622584038204, 0.07867260265254206, 0.009041560246729323, 0.0965589936822653, 0.03503043136949982, 0.07118521934194912, 0.053984779609187, 0.11673077054682279, 0.054450112905713825, 0.05234107285016968, 0.04217060065017112, 0.052463125978266044, 0.0242288731744573, 0.07110631228574822, 0.05158345402789213, 0.04269958819232641, 0.02463469867624583, 0.047862733519005204, 0.07400823036028494, 0.06957559966512265, 0.022743103101909645, 0.027033593843600927, 0.050934336238330415, 0.0228413155738024, 0.04956429523806419, 0.04496882106327722, 0.029064561878781647, 0.06262514822845978, 0.04992318061751224, 0.02642382232983026, 0.050973728479396914, 0.035920966446640036, 0.018730495432992617, 0.06360277218083221, 0.044097009175006426, 0.0929021189409879, 0.06332742485908732, 0.03447968693029496, 0.03336159309612648, 0.021772412245251963, 0.021363237024014516, 0.01130055626779194, 0.05135078163396928, 0.03478420304975683, 0.030026011799852696, 0.044937679589155226, 0.013674784361595109, 0.028975260924668084, 0.027590009248665268, 0.05113808498267205, 0.021580903670720516, 0.009024362530439131, 0.02003458200863773, 0.01218008170385034, 0.0432287902391005, 0.08892049952860802, 0.08134663255224306, 0.019191601839397224, 0.01858180542776902, 0.058912563573328726, 0.0868684487537511, 0.09121972857223404, 0.08119061874646334, 0.023821844914627653, 0.06093726500928883, 0.03316560099201818, 0.06354842207304413, 0.07310689727385199, 0.0051693994769706365, 0.07286112860686357, 0.05525175497056015, 0.0539006440029029, 0.03488467165058659, 0.04510559457083864, 0.012785419483759232, 0.044399215539376584, 0.08662178376389128, 0.055114142596721656, 0.04964726639070338, 0.04939654113484487, 0.005120418687921859, 0.036911782433068564, 0.011904297711988612, 0.04104823587582477, 0.05605384519684219, 0.04717872808537176, 0.036011498887091875, 0.031248178678534688, 0.05887108757310818, 0.047268525081416296, 0.0568983652028105, 0.03583915591720612, 0.05649704238279693, 0.0882860025270812, 0.05082938602314361, 0.047715740398533886, 0.08736666637442767, 0.012061708670620237, 0.026408588671455943, 0.036900735445200436, 0.028625938237734863, 0.11208054023764788, 0.03170130627920791, 0.012827888525451624, 0.048790573247618256, 0.05577612683297165, 0.005497606865490877, 0.004954537190872455, 0.04554953486207993, 0.03183705897461022, 0.048825472383008856, 0.045352765178728494, 0.03407411998318088, 0.003301195679194925, 0.058070100513437105, 0.038294969502115445, 0.1131228105195107, 0.03017359672324552, 0.016704300125580163, 0.060222079797137174, 0.029676382677749764, 0.02494146517898527, 0.05145490064375824, 0.0315805516701432, 0.083650465784294, 0.03585498712416138, 0.024381487465073026, 0.046302488208898616, 0.03506475210850758, 0.016923853263799703, 0.060037824160028855, 0.041157146765580105, 0.07513876929278336, 0.0582111832655726, 0.0439814065072325, 0.029795568721789508, 0.027143234432104136, 0.06599744811894433, 0.08004769983310854, 0.035993537955707124, 0.046804520947438095, 0.03080959908754355, 0.02385302852358549, 0.06988847763427804, 0.010031231889320959, 0.02962802720796918, 0.05748138492626529, 0.048864481580113216, 0.024855224746129206, 0.0322850595318502, 0.025718891204545097, 0.007056215141464266, 0.04328276113336606, 0.05255035657976424, 0.03617803874095121, 0.0506539901928796, 0.03993757692496142, 0.019600439981947985, 0.05483250569311842, 0.02018021340782364, 0.018579443961742426, 0.04229419744543491, 0.008417295307041177, 0.05000706341478133, 0.010690956166194332, 0.08429358893584821, 0.048745500464593215, 0.03778522608861808, 0.05550904176949013, 0.06940901384598787, 0.019250548474730986, 0.07599663455039263, 0.03848938729553934, 0.0728757915297343, 0.0426842664338408, 0.02245170623815108, 0.012358713297984533, 0.08462405628374509, 0.0401462899190524, 0.04511997021073776, 0.024096215474269083, 0.0645127927043265, 0.12590187721915785, 0.2364493299636149, 0.28696216462600616, 0.10224180326106087, 0.1582758948807755, 0.19608944323995423, 0.2666064730334667, 0.09696211680890092, 0.18172811386325669, 0.12045318411002237, 0.20049575115403823, 0.09919277332242459, 0.18454472804742475, 0.17405748998205509, 0.10704904329031707, 0.13601417653262615, 0.12061778576143327, 0.14454370755101406, 0.13060175002582614, 0.14423171058297157, 0.17886052418860698, 0.1424939780225677, 0.11637811729263876, 0.06863911846472372, 0.11194002439057636, 0.23566591313048718, 0.141609406939918, 0.19721502558358256, 0.08892495816032733, 0.17912123923099812, 0.18939450893911625, 0.12921611147542156, 0.16912209110394602, 0.060112827998255534, 0.09113919740963368, 0.1654575861269428, 0.08084701299066506, 0.13911874784577277, 0.21256592605383168, 0.10836676048535494, 0.17230838867685488, 0.21221809149269136, 0.10257077673750539, 0.17692118793004946, 0.15851249347531027, 0.18673056075649877, 0.1471921347922856, 0.24187133256946844, 0.12924084079361733, 0.2497060524840509, 0.19010730778738377, 0.09864073802506733, 0.0967680514159222, 0.2066452614963055, 0.12627832516427004, 0.2243457689520813, 0.10866323651205148, 0.09644231849139738, 0.1562412266409205, 0.11846302557856807, 0.10495986789464952, 0.21191741730416977, 0.15439572083132883, 0.11746991515880632, 0.11680291304665229, 0.13298958479877443, 0.1716018104625325, 0.1067251796203275, 0.07675683891941464, 0.16040713616436528, 0.13199052953672025, 0.11120461062678408, 0.15102962242259135, 0.14520776788553885, 0.13440413550744135, 0.13321961035891888, 0.16249964404250347, 0.24911786549754683, 0.1964950255088268, 0.16105581345337053, 0.11350211597258046, 0.1221404544588539, 0.25331323876255946, 0.31747259680301915, 0.18508601513120437, 0.11757143713053196, 0.1340564541638859, 0.1946716902837638, 0.26744665698178355, 0.14013156204694702, 0.1143505966531173, 0.07496759460698213, 0.08598664324850806, 0.1074486960386557, 0.14619626645599643, 0.13792046375813025, 0.1931836564213999, 0.06975496383083445, 0.12109324290987947, 0.2242761468815227, 0.1143253080907368, 0.0737141368670329, 0.092669113298818, 0.09402465991555684, 0.15657131860573448, 0.16799067117033467, 0.08007226827284021, 0.12706534261064184, 0.17808291430194534, 0.09775103415332495, 0.32184931840146747, 0.159298560972656, 0.1053146968385385, 0.13511747061725587, 0.11005337199857158, 0.10386898167311184, 0.2126961916444763, 0.21888206051962994, 0.13689133188416883, 0.12815429062973108, 0.10899640048944181, 0.13732461589238337, 0.16611856678801198, 0.13017324640625907, 0.10618814432452764, 0.09651640685455454, 0.16055313720097467, 0.15732910213691575, 0.19036230781385977, 0.09552623821242202, 0.13553946248946652, 0.14184402902760815, 0.17684465574641384, 0.1775693136357492, 0.11557939402278393, 0.18371606606148905, 0.1423721700426071, 0.2258880111959673, 0.12541754111166925, 0.18128543761709046, 0.1479049642840701, 0.13319363997828576, 0.1304314180367416, 0.09226265768971174, 0.11972694041868372, 0.05928716524654339, 0.1863644013722097, 0.23892630672743245, 0.09064065037114967, 0.24712384588295416, 0.14965636385304315, 0.1612733671021077, 0.1606345570255672, 0.17565023274190966, 0.10347201789338743, 0.18181183195162207, 0.07079782400039897, 0.13158214338604482, 0.13432239392592063, 0.1562877434996828, 0.18786176618549133, 0.13179658671780942, 0.21205702916749064, 0.11622960348763775, 0.1511571147749501, 0.14609641455594571, 0.15471193128295485, 0.16054368367598904, 0.11411588263487625, 0.15213744684813485, 0.16616801010264506, 0.1550171407119882, 0.11713980021135462, 0.29922088908572353, 0.17936664783666212, 0.1880548356641685], [0.03947722319994242, 0.0037895310050507468, 0.061537334019498485, 0.06689829090910573, 0.03704319715559964, 0.037709854528187745, 0.021487506061431863, 0.034562435917436116, 0.07918313130616181, 0.03785082619757422, 0.08093446958810091, 0.017748826536379995, 0.02959776098930067, 0.0360748237149129, 0.02771967346028936, 0.014932202776112865, 0.006787573004276642, 0.027699239980128985, 0.04129927905817186, 0.04360406606968853, 0.013051177299911938, 0.065149488378196, 0.017375414214667775, 0.1107283873904136, 0.038258997843630856, 0.06256692937665409, 0.03434552961299497, 0.036306097998373935, 0.035031051900718486, 0.03939436696049187, 0.01926793867061215, 0.045104759535001177, 0.06630095683278577, 0.06572696545551862, 0.009324101134083204, 0.05562131195479343, 0.03643471649998138, 0.014704276296880939, 0.05620562636684026, 0.03392976603560871, 0.09248555863216039, 0.08716716175718654, 0.035417301940821835, 0.02010090798590212, 0.040658795079516794, 0.0083397863613021, 0.0062822762523747746, 0.07129974948662905, 0.032178236231688535, 0.026455821822427457, 0.026045888174144972, 0.03202854839694356, 0.07079352624714375, 0.04410940447762128, 0.11054274896460195, 0.030579117705084147, 0.059901138752578735, 0.05509785939789107, 0.04384784673851344, 0.025547662892589168, 0.09551588070368576, 0.06073713986082904, 0.03956582126838546, 0.027954184465230476, 0.06105342309080786, 0.047532997785076025, 0.016211694098948952, 0.009397360207062335, 0.02725908033279402, 0.05692590223324876, 0.05072029127228645, 0.04687289046424051, 0.017958265398779226, 0.029777948699531057, 0.02710505835561743, 0.0429578977186353, 0.04480272554041398, 0.036514584996527245, 0.04032592987641692, 0.08081394097497387, 0.04105156452785577, 0.04141757452499963, 0.03354622794675731, 0.05758255066710615, 0.044975949511412656, 0.03935405541391623, 0.09076078827943533, 0.03532051822290786, 0.025407943776958895, 0.028867612164768002, 0.022051023101554285, 0.03178682084375572, 0.06417145839922371, 0.12797565424754737, 0.08300030994559489, 0.043684401879868204, 0.030795466680560383, 0.02280758089205671, 0.01720184933454279, 0.03397934341562852, 0.051818298281080304, 0.011740101129567672, 0.039757121083957535, 0.055237911761768406, 0.12997856814294093, 0.06100155510789445, 0.014236745285621334, 0.03412491161256068, 0.12876765892630623, 0.031256783761144165, 0.02045614870205041, 0.01772999226476156, 0.02556047762834257, 0.08389526151961858, 0.018924248645142205, 0.05688964712223219, 0.06959853633757561, 0.023920331262953343, 0.058376642935458696, 0.1410119043242547, 0.044248200457302794, 0.017494510243376418, 0.04175367261913996, 0.013145570823502158, 0.04327071823119637, 0.03164095770297272, 0.10740884414483463, 0.026714811251769145, 0.08521189853068321, 0.009814331330539239, 0.026702046311730822, 0.015928505867299055, 0.07300254843768574, 0.02525865239271474, 0.035184185215902906, 0.04807475984336869, 0.06156695097865117, 0.06092112353672424, 0.05815885946034424, 0.07664550336137896, 0.02943115218752815, 0.06373470784315179, 0.09110345940796599, 0.032250424696793484, 0.03443544152222815, 0.04426213942708508, 0.026050994150160302, 0.057291146142468344, 0.013073665810929192, 0.02542208001438168, 0.03938251941074287, 0.0472352194089082, 0.03645544683921241, 0.07791392279848938, 0.009469272880514544, 0.02485468848458221, 0.03035917769246284, 0.03882052497036996, 0.03326620365823469, 0.06315245037718166, 0.017252309630895336, 0.028105887111216307, 0.020543630197343808, 0.03955408863182511, 0.04643686386125703, 0.009435519046570745, 0.06178279625131719, 0.05250349498143601, 0.06130591034889222, 0.027173079302414294, 0.12311501022908958, 0.031478776889402545, 0.022493132442656546, 0.03834919703583564, 0.060749600280917464, 0.044219805408389344, 0.035106354513235634, 0.02799112330971947, 0.10728396415229767, 0.08827015982880708, 0.009470743769329161, 0.014254548211371707, 0.0166477513454494, 0.003781728878346903, 0.019442779087131063, 0.0602868372093766, 0.06074508802304345, 0.014213923526357019, 0.03572497817297136, 0.03750802483409643, 0.022663707664657026, 0.09338954238281136, 0.042258773539816184, 0.01627199670990869, 0.03824966689271312, 0.12351209658288187, 0.030412455277156927, 0.0737997931578467, 0.013104196329931579, 0.02092761261719129, 0.017663700761453762, 0.07324339115932103, 0.07352763276186682, 0.0354815116001954, 0.001082302804852295, 0.04774432313898879, 0.029668597309219263, 0.05742556009922297, 0.010904754068882716, 0.06660783633349404, 0.015856446679531327, 0.04829682958041949, 0.06958227995182238, 0.03885087737392995, 0.04254137571420401, 0.0455158461456097, 0.04530603764578701, 0.023679231901863412, 0.04514193395152689, 0.09388392190298728, 0.025181227716647332, 0.05528560456549449, 0.012495359443428536, 0.06495222073769377, 0.0341516365897992, 0.023251620774728157, 0.04891453010420646, 0.01877523879821022, 0.06293682727001368, 0.04727028708364214, 0.03239958967653013, 0.0031187748226652583, 0.06261865180286189, 0.08042304461160976, 0.07608009216886374, 0.025562886974864432, 0.02579723135568202, 0.12485346291214229, 0.017721473367043564, 0.06975671817218104, 0.038668548447951194, 0.0021442729179867574, 0.06703243290464725, 0.029788449849753134, 0.020673235037153768, 0.056214899861163674, 0.028261328266272624, 0.04091502084667164, 0.03908361105488674, 0.04002373883380525, 0.018455634577079646, 0.010808677067078892, 0.008615805925200544, 0.08717585685512713, 0.035053184180850946, 0.03853400425624944, 0.03225641167392174, 0.047939250380882335, 0.008037889304931366, 0.053604581663685466, 0.02842719204753878, 0.05439031208234449, 0.020416605158618862, 0.039267625374298905, 0.09521732091783516, 0.015907536125591686, 0.028864070923338016, 0.031239119688830072, 0.06605400072951471, 0.005633281036880949, 0.09409288004521402, 0.02640789727710428, 0.05937602378488068, 0.057364625465725703, 0.04887722545273362, 0.053032421236557346, 0.015045278311346569, 0.06530738676026945, 0.05445870841222425, 0.004589854919862363, 0.07979661451592561, 0.04379252369906153, 0.02357098176294277, 0.036374628393640446, 0.020391071448102593, 0.025227585612165353, 0.02682886642193602, 0.02968003308670896, 0.030838739156963366, 0.021056441792977915, 0.04379373028754227, 0.026807214861976045, 0.06400691420440713, 0.10018304155598726, 0.08967596181337872, 0.04261794620223584, 0.026622041834578402, 0.07799361126437303, 0.04311511045201652, 0.03830749120923781, 0.026376093136927774, 0.021587970831822005, 0.07919497502547118, 0.027952374582509362, 0.050481202891997756, 0.010372761546844437, 0.07896254394924448, 0.04080040643232004, 0.0368278689922825, 0.03268183562003317, 0.028459350503380262, 0.017573170236221725, 0.03427436004482931, 0.03778992220759392, 0.062700247827677, 0.052785909464282375, 0.04314702184450242, 0.04558869727676915, 0.11139699828720863, 0.023309109927785975, 0.008179758254799151, 0.039735751061309735, 0.057498242691039085, 0.04792125880598061, 0.015028805505754727, 0.06160240552778687, 0.04250945283039924, 0.026615823115853053, 0.008090553061676123, 0.006171967252157629, 0.03815370671931775, 0.05655371373699558, 0.03708059373762339, 0.023744525575649836, 0.017637529282740528, 0.03003724647926227, 0.021726625085237528, 0.07240712958117647, 0.020910687819724123, 0.019321725703775883, 0.022659614839921557, 0.07054553592517492, 0.08043703337710711, 0.00476466948091383, 0.037030958901009256, 0.09323525993574051, 0.08536440365376972, 0.035443000360241825, 0.06424012669031659, 0.05419407483010043, 0.023602354978661866, 0.0662182959457559, 0.08938411295774484, 0.12850089945019255, 0.23839191443497137, 0.1467413226923635, 0.050117134927741946, 0.15777979166276995, 0.10166031188301503, 0.0785549162256141, 0.210037927834257, 0.15138033747432694, 0.33462766497846574, 0.14565409071022464, 0.05734323246044017, 0.10841533812063356, 0.08299782782072022, 0.21566721851066237, 0.11155795336009995, 0.1638858648197305, 0.10056461462931288, 0.2283868827526608, 0.10602327454234324, 0.167694348361223, 0.16994300028008802, 0.16195549178988705, 0.10960285867293997, 0.12643393294344987, 0.13487390062261012, 0.1451653266145337, 0.12480538323401444, 0.15974505233668512, 0.11968789291718315, 0.13171738854819728, 0.17818731676426627, 0.21062029255253656, 0.1667615597046191, 0.1703299359688836, 0.18603381911112418, 0.17607345035479915, 0.21547747385357657, 0.15927142613837797, 0.17871152008733443, 0.22498465563741424, 0.12567450998411064, 0.1940775890984843, 0.2453281664319577, 0.11321805057025726, 0.09659465507514055, 0.1549205370247364, 0.08154328732240586, 0.08725002182707672, 0.13343575440587538, 0.14262257354153743, 0.13090925771863232, 0.14085759889454613, 0.13568465147287617, 0.10582003907691087, 0.24652943826250492, 0.11412983309597739, 0.3128656504615661, 0.12088402429775846, 0.13912941178967878, 0.180413905350912, 0.08528132141838152, 0.17910398693094332, 0.23024466129079943, 0.13669627057688852, 0.16597734614005014, 0.13324913538752065, 0.15409184439528376, 0.12003567385216875, 0.1305669696340638, 0.21187437848458368, 0.17935062127728618, 0.11342335447308519, 0.15963015446980156, 0.15280826407815182, 0.17947301148406922, 0.14244470324727798, 0.09632486955172594, 0.2349960918147718, 0.19232945306406868, 0.15632157394241902, 0.10244903770545799, 0.15321225288414186, 0.14295171555732528, 0.11565101558282492, 0.14645570979243325, 0.06078636100996406, 0.14975184905192546, 0.1308965100155723, 0.14752906026138415, 0.1451199895311748, 0.1495902657869362, 0.22978637217273637, 0.2508284938671897, 0.17367294448758328, 0.13876527487750978, 0.17774249547191207, 0.14768727273950655, 0.1318856061346108, 0.14749133809199258, 0.08712563979169054, 0.22428845025358662, 0.1866039570661322, 0.2556669366576018, 0.14220317104651084, 0.22683843519658814, 0.11699516281125047, 0.24495396312446366, 0.11342473343134889, 0.11664801006836277, 0.11142236345838155, 0.1795252127152297, 0.22310512020222603, 0.12469796238527184, 0.2085553331961555, 0.15777861188736655, 0.17721591727627864, 0.20654985290621558, 0.22974912497785785, 0.15615320313842068, 0.13096545792875752, 0.23296772081765438, 0.09521110794476925, 0.12613905037963583, 0.15501760036474274, 0.3945458530177994, 0.1420895755290985, 0.12550391752513188, 0.13592655139584697, 0.18241157154402426, 0.10279512558613094, 0.14138449884710774, 0.14228154184116473, 0.10824247804139892, 0.17880297566373504, 0.1383373381630067, 0.11798294891993846, 0.18444634703618867, 0.1339099475092465, 0.14634252796250005, 0.14947650173018057, 0.17508706618701259, 0.18707536160945895, 0.1160362352346701, 0.12591587364553444, 0.1470262614349204, 0.14975365701942675, 0.1342862039323776, 0.10607330008379875, 0.17325340409673032, 0.08122694663583271, 0.106280917572158, 0.09946293422892209, 0.14796867215585324, 0.10277722977221974, 0.1653894349451988, 0.09654341145388542, 0.062377491154738014, 0.14507374846406523, 0.14529430517746558, 0.22037931808060218, 0.1888365517821043, 0.11122275924971027, 0.09132596198469402, 0.09425115381037036, 0.13428531527038545, 0.149162482290018, 0.16229572675881848, 0.15211449485392342, 0.23210553482415217, 0.12987983473125966, 0.14203132220333622, 0.16539332667185416, 0.12092323267772315, 0.1823968626558781], [0.04053915512838191, 0.012760876899495, 0.033172112739374565, 0.08860500919963084, 0.013078244143886673, 0.04409557659058802, 0.06532632445375766, 0.03193327387224042, 0.01762953132481104, 0.05349714549318437, 0.06169547371926808, 0.030959631661854448, 0.05931223930430509, 0.030554731211234486, 0.035671738892673485, 0.038686432770543525, 0.05182919971224281, 0.013028028038059993, 0.026726017202881557, 0.006306230385352167, 0.026944386735258084, 0.02831094778112827, 0.07656031438419897, 0.02318238940901093, 0.017791677664424625, 0.01760962453009861, 0.08241439824022594, 0.06902744843354149, 0.08872076508498962, 0.02523793354480257, 0.042284571550666325, 0.06962339589071852, 0.013425099070093805, 0.005970361638784168, 0.02528624879496713, 0.02203463073519449, 0.04278989080640097, 0.05848003799215921, 0.026746826066124826, 0.05416543846349082, 0.01810823285561656, 0.04494319542221004, 0.03921136770757937, 0.02969571299129917, 0.023395670202350425, 0.021292869932949546, 0.030110005679870808, 0.010898835082057743, 0.04062579201173879, 0.03735540096738166, 0.019977832130426844, 0.03298497661167095, 0.052727522073133345, 0.07544066922198381, 0.03909787561203684, 0.052845917131391265, 0.05273393805949919, 0.01168153753819605, 0.017211714631787712, 0.015053464918427411, 0.09615177198523477, 0.055713602567031506, 0.036268011937218333, 0.013720884660048591, 0.013280479864577853, 0.034329257905483246, 0.052184281465146816, 0.014001165588025846, 0.024166270384504914, 0.05038717326017157, 0.03269368700022179, 0.03923821525888578, 0.05047742224809143, 0.03302780475707785, 0.07183938182049221, 0.03696204163134098, 0.00900390223720141, 0.07731727820130126, 0.009039421903810674, 0.0411635167866705, 0.018493707231696577, 0.015607774539309886, 0.04411860902403151, 0.0495363789941034, 0.083726852411224, 0.04099801881238818, 0.06533426112465321, 0.041528806661165533, 0.026574741650913513, 0.0363342976948667, 0.07596623618155718, 0.03389654463277229, 0.019413311515123616, 0.015464272864553479, 0.015916955176620715, 0.0145348358426183, 0.01585214318061668, 0.03680418538410337, 0.01878795202731365, 0.11748740494611765, 0.026299915268957138, 0.021249924959134192, 0.05050356116806788, 0.021488197455783526, 0.049091350858009634, 0.09204648299923829, 0.020997723068801627, 0.03927679544675254, 0.045216351732491486, 0.031181417946373264, 0.03970042674712116, 0.023107701582053018, 0.04053180068430882, 0.018809015614791744, 0.09022487147200493, 0.01420761670752038, 0.003339837154095632, 0.007197722593592781, 0.017604715821723786, 0.02145736816249067, 0.04346852596368521, 0.08519610945856379, 0.10695633899059989, 0.022309962735180894, 0.0238549628955943, 0.03167111283889221, 0.04267060708615088, 0.01401302654431352, 0.03423237459613912, 0.07292325833752271, 0.040749070880514, 0.013736163326088461, 0.04520067757356071, 0.042086648904988845, 0.04260979885716112, 0.011623494886612941, 0.04482671941420244, 0.04538721615268339, 0.008946689833406239, 0.04930439607931241, 0.06085338987289898, 0.06245103176502932, 0.018510689485758063, 0.021281939773489873, 0.06851076809388977, 0.05678139889853136, 0.02970504968787634, 0.07620989044587459, 0.08173840225584085, 0.04968838999047876, 0.009060179056119054, 0.03149980791814385, 0.03415005461823556, 0.04181919611930367, 0.04994743879163458, 0.12517405538669518, 0.007091995756772738, 0.02745000859572282, 0.05063948048759372, 0.012585263691782471, 0.02195863672832568, 0.056865557487453186, 0.017086796334854538, 0.01128048284895598, 0.00948290828795683, 0.049973290428639426, 0.018228826586217172, 0.0450844505441285, 0.05813683443252118, 0.04696651406946683, 0.015311456518247725, 0.031140311583576184, 0.011319114747757634, 0.04672228906964583, 0.05600981812383379, 0.024169715864944364, 0.01818902640333099, 0.06315603183822767, 0.023831894072974404, 0.032516655572239435, 0.01563527613818165, 0.03976231899052378, 0.05515824244808286, 0.023420139050651944, 0.013253704134014346, 0.013480656723972532, 0.04206475028167329, 0.04323313395763117, 0.030227452704322436, 0.045833167424725915, 0.04710049135610462, 0.024670662673851176, 0.04794611835912351, 0.06160335164637335, 0.04138886538003722, 0.03599593964134974, 0.032237420354278824, 0.019539966916425094, 0.04873898871723683, 0.029926207780297247, 0.03975420228896603, 0.01751008481087704, 0.046764699697133996, 0.04357142306323494, 0.029499016086300536, 0.016193422901954864, 0.010334314466754516, 0.027166808872754057, 0.027661942989535393, 0.037229938748022245, 0.06942053580836904, 0.03191565576520178, 0.02651885170639763, 0.0255443936123723, 0.06303270317373738, 0.04348930609863132, 0.022183495025420864, 0.06985720592520892, 0.06790525219853848, 0.06494025444431652, 0.05398697062065044, 0.038499695008560535, 0.03960120303916835, 0.046813020692957986, 0.06522734589394062, 0.05543357827850888, 0.07395876406301415, 0.0688721547504106, 0.055774510387451424, 0.016653395498231534, 0.023048860283808845, 0.07085626884814232, 0.03223051407164143, 0.02505760027786657, 0.022254459665066773, 0.04307072714812333, 0.02023924814326869, 0.038466699601661776, 0.07242156267766992, 0.031036273013019276, 0.04419368947105062, 0.043193197794138424, 0.04946090784224291, 0.05969478530929454, 0.029921281834944125, 0.028116074165389426, 0.04968663564913216, 0.004670726512784078, 0.0468158322356401, 0.032937594073554205, 0.02759302763508693, 0.02459001851328198, 0.014098806366805109, 0.018675180054419947, 0.08415920179217093, 0.03697139939533607, 0.023031956553759596, 0.07432386624596773, 0.015373884065587436, 0.032063845898054784, 0.04150878495326446, 0.05728929604013121, 0.0406134273526409, 0.06909235140248653, 0.07991631575409444, 0.017862998534955325, 0.05388251070173518, 0.03759189614004666, 0.01960203344483049, 0.05793049631099548, 0.022173009196957274, 0.03570777566863164, 0.023173251895294077, 0.11210221286502578, 0.04442089582763372, 0.03665743741176782, 0.0069700163646390844, 0.07302836560073399, 0.051037807903823354, 0.07827723999657939, 0.03695480593089615, 0.06771700141290504, 0.05295719140239301, 0.007312334135114666, 0.051287479788785985, 0.05432315298446244, 0.09635480826780682, 0.02564320937850543, 0.016134752058273843, 0.009333534549260813, 0.024974615718688697, 0.06802019603069752, 0.020133752090435837, 0.05171362768798586, 0.06985673095069586, 0.039230450957773194, 0.0635390911221264, 0.022856815447730404, 0.06276274911097943, 0.02446707672319345, 0.04225887313124634, 0.0424402367864405, 0.05755990510806442, 0.03015767741617897, 0.04392912483683998, 0.04408466749854627, 0.05590853363936467, 0.04355206019094875, 0.0106328378634287, 0.0243991113177711, 0.0230898728008352, 0.029282906513300636, 0.03610874225776042, 0.0441662137276463, 0.010264339995750738, 0.042918118603167035, 0.06085520550127953, 0.05897242185329238, 0.02898068482717199, 0.03248619974680966, 0.062121414774728406, 0.010809685430309225, 0.047768995000590245, 0.020178436083839308, 0.057386504936843157, 0.05269705092594509, 0.03753929654316556, 0.017360994524713007, 0.03688264427886855, 0.05458330112178961, 0.036871087842530785, 0.025403678582440463, 0.041666560761270025, 0.06847012712950669, 0.01198466512329516, 0.034873103722929955, 0.11584453705337741, 0.06160186160536063, 0.020782860303898493, 0.06586086996380361, 0.03564751136206812, 0.13780101532897643, 0.03387924253700241, 0.02834967735614027, 0.040953306090687557, 0.035906414606518326, 0.06712909787893295, 0.033283038440370755, 0.01939743242767309, 0.05781200549174702, 0.0601987639111617, 0.009762103286301418, 0.1516623191174961, 0.13815566807264282, 0.12399857007567922, 0.1893236458061203, 0.06798913882624719, 0.09054744045340246, 0.13471106097342508, 0.11088463868344985, 0.0849264694918548, 0.2171702523745837, 0.14355130193214263, 0.10927593065125328, 0.1816685735097816, 0.2454072879927774, 0.1382131859539978, 0.10363444385509338, 0.16180676348026723, 0.11655054070175656, 0.1490911595042675, 0.10396707157093672, 0.23747881423802147, 0.10659928073085125, 0.11697049478008864, 0.08189497530580529, 0.0885762962242288, 0.14439894757684202, 0.12840641782649104, 0.18557189873630003, 0.11072490935123737, 0.08781371698264154, 0.08375832330315344, 0.1306750186749043, 0.12107635067114908, 0.11900049754448476, 0.16206527218943642, 0.17125627416516506, 0.09994564623001123, 0.16352909767339308, 0.11488267536004705, 0.10266554947461813, 0.10526857068461758, 0.2176152881715567, 0.1823779862494238, 0.1007517162830599, 0.234388446194991, 0.09584895275052517, 0.14090816069754863, 0.0855727029603816, 0.152981078192111, 0.1475263483101322, 0.1350076595741895, 0.1635924225012141, 0.12337020943842589, 0.1430696624541475, 0.13256227627636927, 0.14334929986826836, 0.16510460345495134, 0.12583857537397455, 0.1315740688193229, 0.0894084285884615, 0.11539590830403952, 0.1738121579851835, 0.1185241517340464, 0.15149736506564004, 0.12945813397246023, 0.0891514060898654, 0.18118678081420161, 0.11107235320753629, 0.06700249418856637, 0.15838919928477657, 0.1254719410151724, 0.056454535994318225, 0.17324969623117678, 0.30221908142970455, 0.13893703179013345, 0.08530291743696698, 0.19721436674796766, 0.20895510851856203, 0.14802001536853854, 0.16195086461882438, 0.06898849286259183, 0.20722292243472992, 0.11138416631447692, 0.13926546900503098, 0.1720076991665748, 0.16028293799008095, 0.1339698862284422, 0.13534479954790685, 0.13829554040585795, 0.07992947714463358, 0.20020187982628423, 0.1017236443717153, 0.08505777696207648, 0.12424968603637912, 0.09883036776896446, 0.12610547274591463, 0.14940415238661153, 0.20577440338750042, 0.10552009267191734, 0.23478299679775394, 0.08789187327267663, 0.21604183550563552, 0.16057198296391195, 0.1591495875149004, 0.0822876413322745, 0.2196981893071244, 0.14589300289029075, 0.09063410798027631, 0.2418165266393654, 0.09050119172541365, 0.2193923823295101, 0.11893335759880082, 0.10112336851776609, 0.07930272529202123, 0.21647908784929784, 0.07040027033297286, 0.07734417554832275, 0.10846863485752575, 0.20494687521169264, 0.13596948296312364, 0.13531050945241607, 0.1571577435900127, 0.22847363454920633, 0.1025654447655524, 0.1002176074431308, 0.11427929685000451, 0.13762905923349245, 0.18672933501581992, 0.1023982460760782, 0.18464183735270656, 0.16557036959115537, 0.12360132284342282, 0.14131743551021622, 0.07123156000048884, 0.10907542245883135, 0.0893772871143395, 0.1173477088131251, 0.12799731155316676, 0.06454764204400201, 0.15385565948822807, 0.12497566159694426, 0.24286223665600826, 0.16102682468631577, 0.11155917910077881, 0.1969556128906627, 0.07924756696147305, 0.16806683563176664, 0.21611401630986124, 0.15216937739281886, 0.06751335225999355, 0.17558304683095025, 0.14211562251852405, 0.14305544386227287, 0.17101353154547755, 0.13854530039093188, 0.31202273924023877, 0.2737441448675048, 0.22473569238378158, 0.15103123120723233, 0.1481596119101009, 0.19014078582967484, 0.21217721304105175, 0.09039348742413907, 0.11179083642820198, 0.1655170805151424, 0.4790086094890872, 0.1908974202289697, 0.15296768697519458, 0.11111609682801271, 0.10823087180934607, 0.08838156433475595, 0.18213314454882376, 0.1291313055422037, 0.12087815606425847, 0.1533544847681638, 0.15391913753363395], [0.03148763095058742, 0.06124069711433784, 0.035313228896308335, 0.015597694737446165, 0.034549259205138495, 0.054579528138762524, 0.02169251693562875, 0.1012387720026797, 0.017208690499706615, 0.04295166559337128, 0.01812770681065177, 0.003308455559289864, 0.020942137644235647, 0.05550385152380313, 0.04000071789168062, 0.032945936771049615, 0.032800272813126925, 0.0029252658010415376, 0.07444968086577232, 0.05245357669228989, 0.07016682035980687, 0.026292758092524546, 0.042357135398854176, 0.06095614524618272, 0.07150889148995762, 0.03804304531865543, 0.06480037445022215, 0.019917533349906726, 0.06849640394530951, 0.07031266817883139, 0.080346918454574, 0.033027548117623214, 0.09546726476401092, 0.09815726759693316, 0.037685263105818344, 0.04533563162230196, 0.03769414972574, 0.013841573194029832, 0.06082133675414709, 0.08232610660695261, 0.06643917441608445, 0.07338522467762232, 0.06952103122227615, 0.04937308735304302, 0.0647453693372588, 0.0437851807463073, 0.11662845950453513, 0.04814222920686007, 0.007780609209270728, 0.04204453705179115, 0.04248347478888689, 0.10164293700889235, 0.006604175385643518, 0.04239132207247519, 0.00456091451210781, 0.03416392847054428, 0.006763660527330133, 0.041543653445138086, 0.010889482106112186, 0.08124684193922628, 0.03163571766157064, 0.022810882731010357, 0.016822986297249314, 0.05242454579039928, 0.005587842446872064, 0.03956287182987698, 0.030099977588941975, 0.09360651380472607, 0.07473734688133964, 0.04897187944621809, 0.027458826267731287, 0.04557407648873426, 0.029891299068807598, 0.02830286938396673, 0.12869429834667714, 0.044225623846174254, 0.040855606897704067, 0.019245528683607138, 0.02359167954343702, 0.0861780809599065, 0.04988545461768105, 0.017855324249173847, 0.03460119996640471, 0.07247185634989893, 0.04551942377621609, 0.02271496277723101, 0.05120446267087133, 0.05974843061619228, 0.04144792692855962, 0.020239420513051654, 0.010482847423953636, 0.05648810979759982, 0.03239250719367016, 0.01318070170048985, 0.058264648541808135, 0.029089277790438746, 0.049684720429321455, 0.019574304892411156, 0.04059011912754467, 0.03671684369985615, 0.014828021521680059, 0.02225168834200069, 0.04374608727953127, 0.011504545372219817, 0.03566156907547866, 0.02846819690368589, 0.029350439079045772, 0.06136487230598446, 0.01813838990675586, 0.05095317434038847, 0.013688566283352915, 0.08248212041273233, 0.0347787561646152, 0.025699143373076955, 0.11615887825046817, 0.02126855047179326, 0.012764735109803658, 0.05451642164599992, 0.08289473536874979, 0.04722300796739517, 0.045433032040994976, 0.029344542117248622, 0.044864560327222275, 0.015626861619943335, 0.005788348724074181, 0.0800793699078983, 0.027990887737682754, 0.03933718232738395, 0.05485762571615558, 0.051594003058609464, 0.02047396216150974, 0.03912924691253612, 0.05263456879484077, 0.04004440405556271, 0.0269699108696753, 0.0157103106199253, 0.015605548096279946, 0.032133508188229416, 0.039854548315727906, 0.040275831556608604, 0.02726161991426301, 0.031709727500715566, 0.0935587329008887, 0.07430304397618578, 0.05291546259315745, 0.04064622740711897, 0.004722223900664117, 0.012548275051578399, 0.021455023933442372, 0.07069825555288023, 0.03609254715904113, 0.12768830998890823, 0.04819899249160963, 0.0859966177132822, 0.02218277298755223, 0.04384182911786822, 0.05778393219976176, 0.05187991090239056, 0.03510950696504405, 0.10493843275452815, 0.013032723199425927, 0.031263255288884524, 0.026568159040424134, 0.03285971357517185, 0.017063175928929163, 0.06522887806978918, 0.00471602481294183, 0.03543848044148857, 0.020251737291654272, 0.04042799960100844, 0.04242557003313015, 0.0245605088064387, 0.04453658276507932, 0.004543335667075289, 0.06615907734920902, 0.026043737382297556, 0.007019332795959688, 0.10931412013427866, 0.06746017043629, 0.081716415532414, 0.02581583580092317, 0.016838750471511198, 0.024969726162511977, 0.03271683434685392, 0.051985757440448775, 0.09270691973788124, 0.0103649158488899, 0.07863674207680649, 0.04055380655993377, 0.03223157510341656, 0.020040078689494444, 0.05963706824507925, 0.036017194750808904, 0.044146341406890464, 0.035400658680666844, 0.055173437802060965, 0.01693703189131714, 0.019041262829916614, 0.04215373905495771, 0.0493978894495916, 0.01144532390284322, 0.01910886051313531, 0.009322280717653134, 0.038912267829742164, 0.02834424004709769, 0.01790245206305577, 0.010796664808426174, 0.039497260229601976, 0.0508553525733371, 0.07516672384114036, 0.042953190108340596, 0.09107939658626434, 0.013697657831794312, 0.022371835826385408, 0.06051990413858045, 0.07822429566013236, 0.032974657407330896, 0.03808391227897617, 0.021889981843771476, 0.025116700130785187, 0.04825968580741075, 0.04143553928682401, 0.11971914164361455, 0.10745703107527188, 0.06288108288220341, 0.04514519748608432, 0.04246279424537094, 0.020355942486334714, 0.047944463609207066, 0.09652032156384761, 0.01498657012087924, 0.019719823293628234, 0.0698390189978865, 0.01941881202641995, 0.014774863638224141, 0.10851211800810792, 0.02800839093153275, 0.03305547202246324, 0.024105665168815085, 0.03738072783415837, 0.00881061538107573, 0.07739879761732395, 0.05016782313525196, 0.04593214598454295, 0.041958516869213314, 0.0069333317655799614, 0.056125183304351185, 0.017593216841980334, 0.05058963880724004, 0.03171688659236797, 0.045039170917363903, 0.02862350207813565, 0.03222703220202558, 0.03651804771394499, 0.03694881512332828, 0.048726382740442796, 0.07545733929521616, 0.045580442679385026, 0.03359609644018835, 0.036369411334876096, 0.016801675646415642, 0.02559845260674915, 0.029490359292756167, 0.018929523160500873, 0.06207840276821967, 0.03683720377363986, 0.04121039370675722, 0.025034094785129832, 0.041769116951693455, 0.021816508266173547, 0.055043298615923816, 0.0433905458738727, 0.021168187208053087, 0.05577876217543118, 0.029441153465379632, 0.03418894124127204, 0.03757792269630778, 0.023255954917159774, 0.03408115267032578, 0.025363089328992273, 0.0398315848301976, 0.0496493463194178, 0.03928146092221141, 0.04904003445840171, 0.013665706219692385, 0.02919414373595388, 0.028824648038754543, 0.001197653980324826, 0.04447879292251122, 0.08686066530044041, 0.11195176851845558, 0.01907337723570245, 0.03926503982755446, 0.11889146791110117, 0.12517073822598304, 0.04994754221350436, 0.03456235547820407, 0.023961255679868405, 0.02412583626386139, 0.02582286657284825, 0.040923624014061306, 0.03469264405148645, 0.0488962282636954, 0.08230393602242393, 0.056971277621003895, 0.05831998690301853, 0.06444275694628877, 0.02165910975647069, 0.01114974132618837, 0.041436198122438886, 0.010216087947839932, 0.03727975361529858, 0.03021456902065585, 0.033964488970776724, 0.009919950915049883, 0.03497939076154463, 0.011974762479263929, 0.012681481462242383, 0.05448170637171115, 0.04613835387112153, 0.043452269577931975, 0.02222694944770586, 0.07137747676742655, 0.03648231354271693, 0.023771137554919528, 0.044818763591108784, 0.011042673835500835, 0.12132686908326804, 0.06368104338405595, 0.06732227460991952, 0.04180942083738985, 0.02548545655313759, 0.02909018368940921, 0.008103990243868002, 0.056688376672325604, 0.11248806836984812, 0.034553112627397624, 0.04749561269437114, 0.00264514000586895, 0.03068123531017092, 0.03939137155670793, 0.07910956388279315, 0.018642952650665276, 0.02975542188411759, 0.021660921554411613, 0.06654754521385317, 0.04552926034516385, 0.01587581050942742, 0.07149092672813324, 0.022887106564256455, 0.07558000529365194, 0.013879524232188781, 0.10766307808338635, 0.14155582675049383, 0.28218545320053257, 0.12694416282277915, 0.10967952875240196, 0.09271366897249415, 0.14592858001349435, 0.19909215550268852, 0.12203351624550358, 0.1541507565566609, 0.09205694009940471, 0.14258863584649178, 0.14591967807181422, 0.10992797106624612, 0.08274295802919135, 0.160198254630931, 0.1517484580437022, 0.1477493871484072, 0.08087026375916698, 0.21471132464226217, 0.1258132944724733, 0.1203450891039064, 0.16447083423695258, 0.1963539427566913, 0.18771394185962217, 0.1997793210490096, 0.10827479163004507, 0.10109153756451222, 0.11286944992119267, 0.14063379396834683, 0.21427137566910637, 0.15173851422244503, 0.17472925716109816, 0.2551862624503913, 0.17291851642151035, 0.25914787164618897, 0.0845532391160246, 0.09095006562288731, 0.17970901253002305, 0.18564786401487168, 0.11551773926663784, 0.17764100414370337, 0.10718148457066667, 0.12382546484830881, 0.16228742236571927, 0.12631964794690573, 0.24440553610122975, 0.25187452564076074, 0.1289360297303046, 0.18658817565489202, 0.09671637878542948, 0.2708956461039282, 0.10415136168200163, 0.18660786411454602, 0.11918104148559994, 0.1302415967708634, 0.19781202258121586, 0.1295046048659471, 0.10165328685674938, 0.22548026855914827, 0.17030701461818912, 0.08397536367298135, 0.11159186041162861, 0.1384846875143628, 0.10428196435133297, 0.2984600105593282, 0.10069288073047515, 0.21864066621468914, 0.1463491929274413, 0.1034197706969515, 0.07562037812726152, 0.15701364245145552, 0.11443750166724767, 0.18038971229426323, 0.25882056824141936, 0.15570436754534323, 0.21179122730128228, 0.11900252001660487, 0.13233136205423263, 0.1735547371208668, 0.22117172878596092, 0.190487164823759, 0.12141398094113796, 0.20707413283807619, 0.09126964686138016, 0.06285345775165385, 0.17498019692157546, 0.11435428919691233, 0.08297366540758841, 0.15695102242452486, 0.1864036710392083, 0.15031997985657186, 0.09858852147214836, 0.12796543463463747, 0.17614656578629248, 0.21557718785780094, 0.09420312775839722, 0.1629240873960718, 0.10596846095136098, 0.17171814857471376, 0.1319335019516368, 0.1512090708579748, 0.12665349374254867, 0.07554941540283543, 0.16371787705969426, 0.1435877677173384, 0.0831913646130312, 0.2551221562128875, 0.1753248139134338, 0.21567979767437906, 0.1664115800972908, 0.14321714970132998, 0.09996610077758951, 0.22324297006332108, 0.19412625100343459, 0.08117397165586872, 0.08113244202949348, 0.22259977796385366, 0.23980899323378843, 0.1096417376350972, 0.12512766110200074, 0.10287846063053417, 0.1268809758907845, 0.07363957352936268, 0.10391291681556933, 0.2989285499338181, 0.11960599811807757, 0.30180395370529545, 0.1696494507092622, 0.3081997459934604, 0.08771221033267437, 0.1116190795155783, 0.11214473840570259, 0.18108076956723967, 0.17341946131519734, 0.19256477995264917, 0.15992934244775003, 0.10824035597784866, 0.09227988700712882, 0.19365380458053083, 0.11722076038319258, 0.09464107724207063, 0.21786621261027553, 0.1341584511101246, 0.12485204564948237, 0.10648217653074574, 0.1579264515349942, 0.15025164481372605, 0.09881794948371188, 0.18840365081785188, 0.134220841310678, 0.1944540753479927, 0.18271149496638006, 0.1532091272454108, 0.0736105464579117, 0.1033619080760306, 0.1086623784935763, 0.14584616427460026, 0.18345253181553658, 0.24714713495585228, 0.12375807209360985, 0.11326970021811225, 0.11737424609882217, 0.1240261645627118, 0.08602431945262418, 0.19525512752513732, 0.15429263604023766, 0.12232364140330784, 0.13578738386352218, 0.18633853824388596, 0.23905453452419853, 0.09209613315761091, 0.12060488484078839, 0.11890595463374931, 0.2677433168695819, 0.07379231613970573], [0.037191707130161025, 0.03851472948407454, 0.04727694821814376, 0.014429903822019698, 0.03824768272498923, 0.029555354192252123, 0.06316709414785428, 0.016607152515902154, 0.05952174136895807, 0.039493261250637235, 0.03182925828432124, 0.026929174144301685, 0.02433944072934889, 0.003898495999765733, 0.022584312227404407, 0.03281837547077768, 0.02579316917446352, 0.046116156473515496, 0.04570673993458191, 0.0871717889282492, 0.05647999309604207, 0.030043139610619798, 0.07027512987054164, 0.01325359209365542, 0.04193612028874698, 0.028777378498606627, 0.009108186913503995, 0.04066922536660587, 0.031504735778716784, 0.03894598335928975, 0.07965330244793047, 0.04482489612494265, 0.07816049585779829, 0.010620839011314656, 0.0283740772565286, 0.01661388068309715, 0.09869672373057374, 0.0810050186250479, 0.009112839940034095, 0.04786316635868242, 0.03752925696091787, 0.02883127086885995, 0.02655908089852141, 0.054273793939501054, 0.045975989196449525, 0.042905570082967324, 0.041207574503195864, 0.03050724716646777, 0.024056641287320567, 0.05328679307093544, 0.08772571646277944, 0.05120076246619706, 0.032029990557461016, 0.07145492059569206, 0.015164460524946693, 0.06486490969696353, 0.028305498980766827, 0.04861990801028667, 0.049586825883917274, 0.0038900589776946414, 0.025544732606278795, 0.033294342067693515, 0.025274814932697245, 0.01551617532142348, 0.06394597574047024, 0.025772132400062778, 0.05503656087262977, 0.009829526684517342, 0.0063709911492262645, 0.023575536155652617, 0.01829093907989802, 0.03876667281973266, 0.051243142450168255, 0.04545407647627496, 0.016281622604677276, 0.05325787708223347, 0.016325883334502578, 0.03644940240548984, 0.013604697850232404, 0.03049297303321862, 0.07124934856209063, 0.04641153699448032, 0.05724189434981635, 0.10371626204540653, 0.06336136638457257, 0.04212879906258276, 0.027211240057142514, 0.0424028670174941, 0.02040476526974911, 0.03900282325283174, 0.020734468444941506, 0.02990494117951922, 0.07678130776771615, 0.043255258576884385, 0.019879294071166266, 0.024236281244685094, 0.018840622487327745, 0.05581925758310864, 0.060611930450484644, 0.03249345076901298, 0.06001241302358047, 0.03225776381910809, 0.027707896773673357, 0.08228562652103363, 0.05448021250025881, 0.05115843610838056, 0.05021857262979593, 0.0987925383472635, 0.02513732704814644, 0.07382577886023829, 0.08187025364848875, 0.06061353157424639, 0.04368308803907806, 0.018051168881356716, 0.09335617925370894, 0.0285590453554065, 0.02559244456220298, 0.05038856370975414, 0.06127959139825356, 0.008607249680696236, 0.03794494775995132, 0.04138941313290308, 0.06679996352402434, 0.02511167842444153, 0.03080149770774428, 0.03941723085459202, 0.05560163115601867, 0.022737730910340627, 0.03936289606856243, 0.0709945936837504, 0.05770756855546948, 0.15483078216352772, 0.032854829764654564, 0.023187976105198748, 0.034137471624079256, 0.03122865875822402, 0.054013465771511684, 0.026710760561869513, 0.0481341278270608, 0.018955886161195177, 0.03019067665351735, 0.025122541551207824, 0.05468237544259718, 0.05633238710523133, 0.018252100337356813, 0.08876060931793145, 0.07073719580207141, 0.05710399469300624, 0.055065304491548776, 0.022507578945688667, 0.02783958728785717, 0.015386816587359195, 0.027377396867039706, 0.07855382838076161, 0.039771649941441514, 0.0524847564708081, 0.07057877648020945, 0.02571972049472313, 0.015216071868405468, 0.04848090901730522, 0.07573796496275934, 0.07370703523197482, 0.07116289553983558, 0.02024151001786513, 0.03462472652655936, 0.043161864798035354, 0.049922019994306954, 0.06435470280027197, 0.07332162405814856, 0.035095112172946814, 0.013139886451103996, 0.023642231770340475, 0.011360486368498495, 0.03728418160350092, 0.004583336469236641, 0.02876747106652587, 0.0261821981985122, 0.05494410172104836, 0.030296122910635128, 0.016166410641744733, 0.05400265627090008, 0.010445393385335563, 0.013180804164749722, 0.02936119686872248, 0.06180777837852798, 0.04214334324182522, 0.01679882962977694, 0.029072140403572592, 0.015706211091920493, 0.0918946443726459, 0.020637002908774925, 0.06467566299702852, 0.07375711439958504, 0.01705415907406038, 0.01048425128007488, 0.0747073468782248, 0.047780547606488394, 0.033310261374760064, 0.03784859305127494, 0.09028950631017647, 0.026492258879326047, 0.032213284754224365, 0.013067561047782582, 0.05617715087869475, 0.03159583895467222, 0.0325470577715145, 0.06439891373438221, 0.033676064528164365, 0.03264223653522711, 0.10543834342951737, 0.031605102872896584, 0.015217665331287971, 0.03814730605471038, 0.04168177143700662, 0.06403032202093352, 0.0617371948676244, 0.06323080968051668, 0.02910823655134488, 0.010384936599181065, 0.06793662349903776, 0.04057085584668864, 0.0989914683985614, 0.11469516767970017, 0.015273615605227891, 0.05817494347631451, 0.039619907075839664, 0.0757440630226366, 0.04964372323405358, 0.09008916665709789, 0.051765311809797446, 0.032136917279492465, 0.04460907766535398, 0.0670327470006962, 0.06468493266091233, 0.060618499654435345, 0.05976441121029277, 0.02384922489704144, 0.050591956223210985, 0.016879795547274333, 0.06704675108795205, 0.022330612635179874, 0.045441003185847116, 0.03054758169568114, 0.04495174879388464, 0.02410213350348415, 0.07736825369178288, 0.02435855462305969, 0.056188646027998584, 0.08407611955678271, 0.07674375413766793, 0.04428933171795742, 0.026393542704623074, 0.06730656980747177, 0.03577611454191708, 0.03961670099787655, 0.11621120971657577, 0.03321059716625079, 0.008826461909789472, 0.03464038536373166, 0.09419162111777453, 0.04316542710688326, 0.031820160990220406, 0.05400495070423331, 0.027742765265546983, 0.036109002727654674, 0.0358791878416894, 0.028912376597403523, 0.019436445455217076, 0.03160390203007527, 0.07926029934277458, 0.040347748060500434, 0.026734254563287384, 0.029896485484054977, 0.028906558159618612, 0.047564223528869694, 0.03208974350033508, 0.04346563015133143, 0.045443489141161406, 0.012792862985553521, 0.030528013894875205, 0.024300318534275698, 0.010256493340186294, 0.05983207975664447, 0.038011827235741, 0.007841604172192033, 0.02895823270533114, 0.04291450649860405, 0.05531162857228229, 0.04848377418614203, 0.027549446808294426, 0.04450637591822494, 0.014716593075483559, 0.055342662794094895, 0.035847268788324255, 0.03949878091413168, 0.10647888235267132, 0.009046759110905472, 0.026360489841129993, 0.05553738702268851, 0.03013017102925768, 0.04352529307887439, 0.04022181852750721, 0.09977909871527266, 0.03631061025624795, 0.03884223973258369, 0.04855161893271631, 0.01738569511461162, 0.04936783582032208, 0.01870056437779098, 0.062303149982565836, 0.023979952055660468, 0.0530783367162991, 0.017560006930462776, 0.06829256327041695, 0.02752179294944771, 0.014487199537876635, 0.021634813277952133, 0.01918809507192383, 0.06679453962152043, 0.09948530399631109, 0.042720195957489555, 0.09674300034079822, 0.0662021161687951, 0.06496748887002468, 0.0652736252654464, 0.08208931649043676, 0.0534995318570685, 0.09440391940335113, 0.04053472714017957, 0.07667507435525618, 0.0797326998004029, 0.022822372134654753, 0.028566639201955932, 0.10531855792167688, 0.021302737145414277, 0.05929216397024932, 0.08769778489706018, 0.06887187129787861, 0.026768096497342474, 0.03158054209404415, 0.06386130004219952, 0.03158184635873524, 0.02838119421334517, 0.06636249667574322, 0.09098856154108241, 0.0501095736399293, 0.0700537151386661, 0.0028753197412081668, 0.03703160241486565, 0.09525679742857333, 0.1053738464871722, 0.08869236620563654, 0.07318987991781005, 0.15839053227776484, 0.12855578964996722, 0.15110048555558728, 0.10395680599275137, 0.13265952347747742, 0.12181319701935976, 0.0964189298270691, 0.11350714917024297, 0.2270555904796047, 0.17378914470393814, 0.14938742102634522, 0.0703662024029801, 0.10427244187843415, 0.1831683131956285, 0.12515138684501573, 0.1608423966794245, 0.10423652767654389, 0.12881259764394454, 0.13716850249517348, 0.10365812363283289, 0.15517590477341606, 0.14626394266322737, 0.15477560851122105, 0.12477953542744923, 0.12487839907407762, 0.16820192757633426, 0.23523509592538883, 0.13804991729557514, 0.08639171223847136, 0.19434444816602817, 0.136165019244917, 0.16034874494277662, 0.14134913622852296, 0.19550199169785748, 0.14437037249726636, 0.1613708900948686, 0.18615694476231454, 0.17116403717908169, 0.14104427919993479, 0.12908140257481607, 0.10155997734757201, 0.10733831809052538, 0.15516827453769025, 0.24083844686467804, 0.21349264729407527, 0.20462052175594916, 0.13523261363227523, 0.10147313362047558, 0.15698025633971538, 0.16073954171471058, 0.23439884966900273, 0.22171575846450947, 0.2507782384993569, 0.12108278580971303, 0.13998314017249694, 0.20624232989165092, 0.24764288577341267, 0.16869467532923146, 0.10847746019041347, 0.0791671660338198, 0.15348209969459042, 0.0799696431345036, 0.12527144814450897, 0.17205605463635537, 0.08587990421801807, 0.12565584042139594, 0.16934010440543776, 0.08719735328228244, 0.14007562230671608, 0.13590208254754543, 0.14945958650881244, 0.19785086323897685, 0.18383035105803322, 0.16655119196061166, 0.15243378497900503, 0.15113019444529088, 0.13718869657285754, 0.062284354015343615, 0.22808582552017706, 0.14284047959071977, 0.07265626137415249, 0.161000486583479, 0.12432856244906304, 0.09484092659887769, 0.12404078918118631, 0.14946003083980855, 0.13893206754038412, 0.14229154694945584, 0.1479910878885177, 0.11237426600869625, 0.1782849470093366, 0.10303822060626361, 0.2791445131503767, 0.09645343442717869, 0.15129306473799292, 0.07439315123783966, 0.12564822550742857, 0.18951619434500896, 0.0981678702538052, 0.23441918164251313, 0.08720992478511988, 0.10532771267237202, 0.16618653410865417, 0.27777116265027757, 0.09916612112353887, 0.21968518113417013, 0.12987214320849988, 0.10435874934398359, 0.15455871369809876, 0.14604165459111815, 0.2560688570261963, 0.1596391483420326, 0.11430973352323617, 0.12464405277804022, 0.06550821670961958, 0.18421439093447503, 0.1436943305476058, 0.1983134424494159, 0.26606307154701603, 0.12529308246749063, 0.1513737644399366, 0.2020085296563564, 0.2073250419550365, 0.07261240284048742, 0.08802796879242505, 0.09512018862991564, 0.10581665296828556, 0.1620328053832054, 0.2012947502155458, 0.11428821411344314, 0.22840269480741796, 0.10852955416926455, 0.13522706715570343, 0.13065865503684168, 0.16084382160296365, 0.07561022746226481, 0.1172759953225332, 0.15939599203486599, 0.09560188173406547, 0.1443762713742833, 0.2798583845217382, 0.1290775568134362, 0.17258690760260628, 0.19087880429240967, 0.27377512546316274, 0.1520344386658361, 0.11638383996943313, 0.18230563690585477, 0.1491904751427712, 0.10484992661663603, 0.1483735189803185, 0.10248157345960218, 0.3753442269179129, 0.14458357476659361, 0.13849749650445678, 0.19362674635504523, 0.16728170276168855, 0.18328553996980193, 0.18499046864528812, 0.18853057626514666, 0.19985890226258388, 0.23401333890374632, 0.1847007954793592, 0.20236538873324472, 0.14670429000210378, 0.1616942558077074, 0.2129596186381194, 0.13528545837729208, 0.09284561229569298, 0.14751747701196902, 0.13363849191415694, 0.09618171836219488, 0.1691967387112879, 0.14556458099715172, 0.19408357990605218], [0.03396120245358156, 0.05772325803615874, 0.038273331348694144, 0.03770024395517765, 0.031250337131261345, 0.001913411244693693, 0.039903880547611945, 0.025752292638043725, 0.015264839110445353, 0.023872004521469918, 0.044205609799152425, 0.04017987521365285, 0.025868626919785337, 0.055751186840596705, 0.03803599730975205, 0.019002868418371486, 0.058745977754193934, 0.006385636356313743, 0.1240843489405609, 0.013910978844749832, 0.0526055264016313, 0.12504280920350744, 0.020137431227692196, 0.0394852364796304, 0.04725440991141143, 0.03129110833059155, 0.04575369729390068, 0.038605993538494074, 0.01253909923346533, 0.01567320419370287, 0.009593858886810561, 0.05415195148558386, 0.020212482946414142, 0.040549520297997424, 0.06125658960832704, 0.026467148432387944, 0.013275508911559179, 0.03860116718457111, 0.07723587369846721, 0.057494308829547904, 0.04536147176798794, 0.018993298064977415, 0.018761920359646602, 0.04160311718982074, 0.04803303103413313, 0.021580873027203545, 0.008794269937601303, 0.0694846726893898, 0.024530346009639964, 0.03475069053350918, 0.0661632065631209, 0.054138265324816595, 0.056211824018147685, 0.04943539711436437, 0.05741335248814956, 0.021384752603367935, 0.06340590290605061, 0.06030906908093922, 0.02803748503567711, 0.05732743189700189, 0.04815351368198472, 0.029795440402062192, 0.02765177508756038, 0.06954274215405026, 0.020366275097213445, 0.09371704497044125, 0.009926582363644436, 0.018815429685937784, 0.04295915793327074, 0.05470713923474955, 0.03918511004397466, 0.01184223692924265, 0.05492489206634703, 0.025423629427208536, 0.04254602203746477, 0.019862254360510458, 0.06577529794266147, 0.06348837610153903, 0.03066599016047774, 0.0320186773540392, 0.040190286348543824, 0.03791830705238446, 0.010809898977318119, 0.08365661747032598, 0.06572236892797294, 0.020036916661586975, 0.04918628447358647, 0.05821847259217213, 0.022403293311776176, 0.10469131577279299, 0.053859673620712374, 0.0050776685877222455, 0.05558011557666525, 0.03606244373405653, 0.02931586170058337, 0.01861870022220237, 0.03170449512019273, 0.12023370758059526, 0.02904488108000688, 0.0774811520691841, 0.0411421659162208, 0.049287281675083984, 0.06178131004074409, 0.054044124610241384, 0.11933436632276544, 0.018575996566083164, 0.03127162096901767, 0.05192144052876581, 0.042150578942270055, 0.046805233409207676, 0.062020187746853604, 0.015488694789969634, 0.008447208167654614, 0.022062439726845875, 0.03224378271448997, 0.05881086540138049, 0.03006950452653391, 0.023296276039834467, 0.04009718368310602, 0.011163507926187689, 0.062454670682669654, 0.07373340397832856, 0.07206428225242323, 0.030045631311593518, 0.06157721272639691, 0.08562216159677313, 0.04418617797895305, 0.06513652617051717, 0.0316788790552246, 0.03502771558780824, 0.02596776061240704, 0.054536864702259345, 0.03524736831745794, 0.029217317895663363, 0.02670595336014465, 0.07591008193670742, 0.025934305552753712, 0.07483299295868605, 0.052801602775411266, 0.011918574718067483, 0.020090312989909324, 0.07590567693114281, 0.08427724828042331, 0.04560044906552761, 0.041475908289993965, 0.045015709474682815, 0.02461431690702035, 0.023748453691481583, 0.02132229345490135, 0.009662011983774362, 0.00876266689550492, 0.05820159567520023, 0.029772455849113966, 0.011437405426535877, 0.016802495360494624, 0.04091872105134591, 0.05155367235983572, 0.020512525112398212, 0.012397141225876348, 0.00933259992199319, 0.07799275324589784, 0.05093454308206997, 0.07602180053870525, 0.03422991545390218, 0.056397420309123494, 0.029930714292511828, 0.04762413926542767, 0.02320975406966623, 0.0550088246593312, 0.041339602096066366, 0.023229030757060936, 0.06434757818257617, 0.04489821073929629, 0.053636948878486315, 0.04484261956907088, 0.004237367810996911, 0.09123622244524379, 0.017821608719626264, 0.029962631430657163, 0.02775904463393794, 0.025935669189258933, 0.019202363459513556, 0.06935272936619098, 0.022993119726438197, 0.004434763292421497, 0.013850140929853004, 0.004910693978965884, 0.04565003793686629, 0.01408000561153336, 0.05582922055656391, 0.026190542811227423, 0.013440074173793679, 0.06614074486518098, 0.006231342417924035, 0.10630528682902937, 0.09807397085692614, 0.01979310343402528, 0.03766777714894664, 0.01691534585740057, 0.05476938387859733, 0.0342875482484458, 0.056251829129553614, 0.017849431117816318, 0.014893956794103068, 0.031004078168001388, 0.06900946834995862, 0.06136620146853309, 0.060454874765127904, 0.018171655359647928, 0.014084430726905985, 0.03541549780376015, 0.05717243698816146, 0.03446770914559884, 0.015534550897897252, 0.03884259596346848, 0.012700472781885297, 0.04217171913854057, 0.04633749459659861, 0.015800821035349324, 0.031972434371709824, 0.055149842293993126, 0.006013499092190497, 0.030723576989745906, 0.08066148947804205, 0.020578862580981468, 0.0414504282056324, 0.033132923511607994, 0.09196515510519666, 0.07115423874629122, 0.03689244637385972, 0.044447019425851685, 0.0201763408333664, 0.039436858027212085, 0.01885406349995925, 0.07859034013123282, 0.024210529199110407, 0.033622108955657294, 0.028605843751480984, 0.03906103827419781, 0.03473374083818447, 0.0470953700583308, 0.05770485660421753, 0.016072580192778862, 0.06305159107151051, 0.03814335687146072, 0.03358682294586494, 0.036455289791187936, 0.06305877697624027, 0.07267765820987764, 0.04179687997806938, 0.03561606728321603, 0.05560379152396514, 0.027648048069808754, 0.045706916134804494, 0.07795722208796971, 0.04697405620508137, 0.0026209708894678065, 0.024208669520674214, 0.04893994507109446, 0.03065580119108481, 0.007055247476654909, 0.06602423821365641, 0.0849338622403241, 0.04184996987122201, 0.028765427526987852, 0.041926712729036815, 0.04518369723471903, 0.008208251937532858, 0.01243478487125568, 0.023105027935197277, 0.039894863692743164, 0.040230276138191266, 0.03903139067152816, 0.004981359844321325, 0.015375094484507799, 0.12341278094437816, 0.05683592520654202, 0.08343999078797718, 0.07083959877490997, 0.023802863171083793, 0.03543786374070952, 0.05045328664803698, 0.026381218265141212, 0.010570569279333277, 0.026462747257262952, 0.014201357769179008, 0.05935640810357948, 0.01649318353062676, 0.0649163065358035, 0.10264604487606596, 0.06928545152468067, 0.07035248942913548, 0.03832644805492413, 0.019983053019630815, 0.012352831657945871, 0.04172037077707149, 0.017048792628150795, 0.13436391589141664, 0.05865163019587917, 0.025708204278001384, 0.037860574666410685, 0.07132003549486399, 0.02760102750823623, 0.026299953573353352, 0.05009855346513852, 0.050604182986482504, 0.009984662362013855, 0.03732337849214673, 0.03924665371737173, 0.01932318701649145, 0.04586173867386195, 0.013177813549015312, 0.00990698391932153, 0.07046171824537939, 0.052861725355708794, 0.0251579558807275, 0.04724452737718821, 0.08521028208516299, 0.007196249310753399, 0.0025751011355990366, 0.07491091176146462, 0.03555241686802718, 0.0499149413418866, 0.04246888847480859, 0.0324815534235489, 0.0026837726228780326, 0.028352211191949826, 0.012350926971844128, 0.008752099670199378, 0.05353899304604819, 0.0262436039760829, 0.043779553830503457, 0.10588066727523843, 0.04280922686560981, 0.038478363290308945, 0.009841466164817254, 0.03074885789124716, 0.024214024475264936, 0.03422694686319559, 0.021342282604065635, 0.05969487340940584, 0.03625315749236653, 0.012138686142861845, 0.07857636668749395, 0.018685535647936406, 0.03865372847705599, 0.048836645775384484, 0.0368581677696878, 0.013396462703484201, 0.02147684786318531, 0.0299822356206395, 0.023980974783039382, 0.12467900937002514, 0.2475209398976257, 0.06380394686974826, 0.12076115145558312, 0.09649923882417141, 0.12297830183900173, 0.18897162840491344, 0.10441045261799328, 0.06262580706407467, 0.09377306131946464, 0.12757058525758405, 0.0895472207377034, 0.11931154456350113, 0.13633055552359552, 0.09404415685322978, 0.09978259207620736, 0.1724462385379499, 0.12461822029323348, 0.365410395447285, 0.1521365428643842, 0.10613273318496444, 0.179966218889721, 0.11364385756033082, 0.12951369066872906, 0.24008345189354113, 0.12357866196262261, 0.1444941263405546, 0.10583317748481229, 0.14943338630180206, 0.11992001755824012, 0.1294190941318389, 0.22205093725314065, 0.1237937334864851, 0.10910840254397162, 0.14957952523423781, 0.20904800434026027, 0.10479567226983848, 0.07222543650817487, 0.15826590509424288, 0.2592140922863638, 0.09957730349513794, 0.2041247556166303, 0.11751531352919918, 0.1144906605083135, 0.18308847151216, 0.1245403704383681, 0.08984185815338167, 0.12275324052860662, 0.15769481719020875, 0.06143727144526859, 0.15430699252793867, 0.12662889465930002, 0.18539479452996485, 0.29168672078559477, 0.18674186821426117, 0.16229994024240202, 0.14484004568188422, 0.12339883814415625, 0.25106582790613174, 0.12028131994508928, 0.19499631238079843, 0.15994950588191711, 0.1972593973961569, 0.11436748889184768, 0.12162680782738233, 0.12386979069560768, 0.11018032808938336, 0.16508011928489133, 0.10688720721631281, 0.13653816535107552, 0.11668478994960747, 0.12046180259917053, 0.20697501638243276, 0.1167252776964057, 0.11045700840411649, 0.13048794000379502, 0.18172082070621753, 0.16407557883329932, 0.13635520823299885, 0.17330261758498608, 0.22107218332107992, 0.1736457636880298, 0.17547634610485646, 0.18258438565798346, 0.16120993502197728, 0.1262271351691696, 0.12737129514496173, 0.11416479734884155, 0.1268403272655222, 0.17095633542105076, 0.17095371540034973, 0.15312164000445797, 0.07608550841048842, 0.11439943475829017, 0.11970053336793378, 0.16504742265228303, 0.17266627431156176, 0.2573599450049862, 0.08985233057530657, 0.22908601459235917, 0.19566616434003078, 0.17106079917040565, 0.16306457259962637, 0.16345282595965172, 0.19003603096690871, 0.16176361740837175, 0.07308406019282919, 0.22887806768619248, 0.13592984557392138, 0.1272551868591578, 0.18584811939827858, 0.07139590884288473, 0.1359801928723051, 0.20029462243039764, 0.15019090936308907, 0.2147549303669122, 0.13797905416257922, 0.10676647942032545, 0.14014184294689086, 0.13077120867467698, 0.16788732590934924, 0.2751076587986562, 0.10676518473173342, 0.11708247385198071, 0.15535650234068596, 0.13452243480470874, 0.17933810340060344, 0.18728289482814653, 0.07296461176367537, 0.17713282738001118, 0.056674215537045276, 0.09157523933437564, 0.10531312635829372, 0.15240691061462128, 0.12059638126482888, 0.20910075715472623, 0.12389551592810501, 0.2858275577666298, 0.227933649814898, 0.15166968888332769, 0.10362304446678008, 0.19356454001559367, 0.16939874077516218, 0.12899144853074707, 0.20106627215300837, 0.14069383993985193, 0.1169352470746925, 0.09679349319588754, 0.1465561745628234, 0.0910992918896579, 0.1074798375127777, 0.12903382851471826, 0.04107446289591251, 0.1213139221973477, 0.10709952848452715, 0.12764206126091943, 0.18629148512357668, 0.07291898356690522, 0.1615359360772756, 0.09928712471117897, 0.13153887474008147, 0.15922310131211437, 0.12455231374910763, 0.14367283412045048, 0.19169217516337672, 0.16820854657600004, 0.0952048336846694, 0.10413060069925363, 0.10748858623687299, 0.08290749073268906, 0.19627007145074107, 0.14296720585515424, 0.09877137133791562, 0.137059350287722, 0.08902041271569268, 0.14223658780176796], [0.01280641986898357, 0.08610416113609269, 0.02494334592483938, 0.021748184714646592, 0.03450294919011574, 0.045933747108304696, 0.09383794896665121, 0.01007941690453839, 0.03923045478821282, 0.025559182939750534, 0.07028549504015716, 0.06203397349905103, 0.05661294765530094, 0.032555480908241965, 0.03551929888706054, 0.046937057988778244, 0.06375371448455319, 0.09612253807004421, 0.05418215450199862, 0.08626562948789328, 0.03907912944052969, 0.09276089829302604, 0.06780052797928934, 0.06989286731808417, 0.06066988883239608, 0.025476146669637774, 0.029983396243844784, 0.021747602487824137, 0.05685178322657462, 0.0322405842974061, 0.06914129675996881, 0.02144097771135069, 0.03801235966684838, 0.02789792488329113, 0.01624812541018811, 0.021544357446292718, 0.03599056936500054, 0.03612835793906162, 0.12836697962014906, 0.014005632838234307, 0.04369581275950036, 0.04250525849901381, 0.014111234228156749, 0.00869117940085069, 0.03457867698143086, 0.08542479436484077, 0.06272983797375234, 0.07377458120425863, 0.03701605466044238, 0.029989572827734297, 0.05610355281180913, 0.05789580018890481, 0.06109433601640406, 0.04693604675271819, 0.03744197656370459, 0.03152621879933342, 0.028726067844658133, 0.008754893975903191, 0.021439897527377454, 0.025660714487575238, 0.031774287645314495, 0.0713205028084978, 0.04775116813459224, 0.055232388267834345, 0.05300639722976954, 0.026031225251274246, 0.0575097531621014, 0.0241488897647228, 0.07293396058582491, 0.021532301137584354, 0.040941389593025374, 0.040839836977782755, 0.011298024347202193, 0.018464770175576694, 0.021156967850402, 0.03764680166157984, 0.009294352024763582, 0.025941679149024913, 0.023873452427646807, 0.023847054952995914, 0.010040389512845827, 0.027703200654697516, 0.06841257860463473, 0.06449765480694271, 0.034530440255278544, 0.030555520281796495, 0.01992409297775838, 0.026410375571539326, 0.0128094679413123, 0.017211793155799952, 0.03711348572265237, 0.03171673529000292, 0.040058189807760144, 0.01779097860919372, 0.006344254680668876, 0.050389433219548196, 0.09470898327567885, 0.035143812382293325, 0.047059226030063246, 0.04537384025752545, 0.02670450162352814, 0.05894504953175784, 0.04789156140759588, 0.036686832205422466, 0.021941300158599214, 0.029130702079724402, 0.05987693420461109, 0.0070272675516354225, 0.02496493045210598, 0.008767257677391171, 0.07108170554162034, 0.06107048386888159, 0.022555765876125906, 0.07970477589556287, 0.04514365764935652, 0.02497172565199435, 0.012887896192560514, 0.06424284630244778, 0.03243041322416356, 0.03985504627287869, 0.03700745532349233, 0.04072275576031497, 0.04904761106797284, 0.015035950233258549, 0.017115585919049, 0.006409646509470599, 0.017260305673605012, 0.08428533050802448, 0.0307154334751108, 0.051993548554638704, 0.03663681049440657, 0.04921116317892748, 0.0621093871943172, 0.03921603701347786, 0.0186656326836636, 0.06766079354190058, 0.10474744703500502, 0.10335362666556913, 0.019531878943164504, 0.024435580933406472, 0.045065432411408236, 0.02039936051944331, 0.03220991779779715, 0.022186009709032315, 0.028470506658777598, 0.03390249713594395, 0.02695355106205229, 0.029971730639977805, 0.03283629809776622, 0.06797196313498483, 0.10094676226858171, 0.04889596396336152, 0.050004784303206595, 0.07058871264058737, 0.008538144719486516, 0.09412069669774464, 0.05013446000614955, 0.08353832583393782, 0.019384847518296975, 0.08486715130387776, 0.05856853646917209, 0.008585213161554308, 0.020424765910232262, 0.026875333484983253, 0.04013489436117872, 0.0218350954744364, 0.03420744992552265, 0.06562671518974728, 0.015516318005299377, 0.02685028240985928, 0.056547558220523986, 0.03523258665095895, 0.020137542310441216, 0.04478560347530631, 0.05185261518964845, 0.025279187379525076, 0.0067493069124588325, 0.12337956337198136, 0.0711112305702221, 0.0365363763675334, 0.060294521071257136, 0.05167403243361943, 0.018417531278945746, 0.0371074604411279, 0.010298017220902107, 0.06268780655978669, 0.0067343873501334705, 0.024108809959744255, 0.04796114134331865, 0.039242195085652416, 0.031692074919720335, 0.02253086227292736, 0.06573504768311977, 0.1058235707422418, 0.007083823513840476, 0.05793916459585871, 0.03541010454477322, 0.05233187596463869, 0.04205447321216907, 0.07132482354439075, 0.0463844366341589, 0.08024475296899196, 0.05316665133221015, 0.021712958076668364, 0.04869480076576433, 0.01023567107040435, 0.006240127531195721, 0.04373624304970426, 0.01904559314190861, 0.03135516477238027, 0.010790124332772629, 0.0681496802116594, 0.03487174008642474, 0.030522837055726882, 0.042658740384203774, 0.021572817612679738, 0.0468773988916749, 0.028507043307106343, 0.10428648427008622, 0.020882612612519055, 0.03518841019080531, 0.10929265435064033, 0.08031063653048008, 0.0466549537715412, 0.03561230196106819, 0.03229966882856623, 0.02112910714781573, 0.01643781835633901, 0.0712235160772839, 0.04069751699364955, 0.05391988047068158, 0.05729134532532865, 0.026340251713390314, 0.016725149208439455, 0.034773458666618795, 0.015597233169471786, 0.09240896516149083, 0.038930546687615496, 0.03221786212957194, 0.058311111774415746, 0.019507436907940337, 0.027313240833820838, 0.015427992855679366, 0.029438014420109893, 0.024418943418910908, 0.06257450598622523, 0.014311915747971546, 0.02349751393100427, 0.004816758192910423, 0.047607411735601006, 0.04141079081643013, 0.023506662936039993, 0.012323628386272299, 0.020220132334338083, 0.03406632503855132, 0.0909302162847692, 0.04945529241775794, 0.017131999352826707, 0.06478011908550417, 0.11272712610661985, 0.026075890092479608, 0.027984372159886747, 0.01215283865965302, 0.061760633327667756, 0.02725807292717359, 0.031652046825676676, 0.025203135916061943, 0.09220458056417205, 0.04720601613723463, 0.023546007296611226, 0.08099489094268891, 0.05847657144430184, 0.09813469098580462, 0.046245962411405585, 0.012341756899390492, 0.05120815138422674, 0.0724101403067189, 0.015545158342818822, 0.03661277448578227, 0.0066835985935833914, 0.026399587138345646, 0.071347453781674, 0.009768457028023418, 0.07994695161018642, 0.0803273908733841, 0.04801166867236457, 0.052753285610026894, 0.03188927361230937, 0.03888006915428466, 0.010772436320210898, 0.03270363848235819, 0.023547748231419155, 0.02770405101229347, 0.007569488783877704, 0.06792234362012918, 0.1037904576608731, 0.06504857927680978, 0.033671969788209084, 0.020932031029294577, 0.021239626822212053, 0.05244393930620244, 0.02869453758091456, 0.027962057933872266, 0.05592084467230786, 0.046042677150258136, 0.038648285422353976, 0.047039028121939594, 0.05297719012765635, 0.006185582549791904, 0.023069703621008707, 0.052578345602077824, 0.049137886868970054, 0.10668326694999011, 0.10941715896009438, 0.08019640516009062, 0.052792785103402795, 0.045538936035647515, 0.042365933918664535, 0.04411718410049235, 0.045634815769810835, 0.11279746829982727, 0.05807132242367633, 0.06023054506870047, 0.05866539679587849, 0.04886321370459853, 0.05891974181717923, 0.0961961284760506, 0.016028637389442133, 0.005934455097773143, 0.06562570395368723, 0.028387713621580796, 0.002694275927722394, 0.04624811128803319, 0.016803537240071643, 0.010273251513529931, 0.0569352868103212, 0.02010341883907395, 0.015463060530413304, 0.05445882715585251, 0.04497430625281507, 0.013544558032956577, 0.029109810862029274, 0.08839685544972459, 0.11134670461497961, 0.026664065587664806, 0.03988688488701179, 0.08595937817928292, 0.007877664888397822, 0.016590534153604702, 0.051114776757575815, 0.04013744543396658, 0.019121903160046187, 0.07342169812369732, 0.20268314668247778, 0.16234109448569436, 0.10075988278033272, 0.09502971364605813, 0.19300276774071878, 0.10856153067922401, 0.08971471820146808, 0.1350215104438605, 0.1411911842202948, 0.2906540342636647, 0.1677445730855388, 0.13918571925211337, 0.09347630184023611, 0.1677252217045715, 0.14707662405506258, 0.14448813553298676, 0.16571794876888876, 0.13566163819163077, 0.20368048590758156, 0.16121240182509347, 0.13784518795869044, 0.1344495491995927, 0.182761060855081, 0.09853704802451596, 0.1296594925224781, 0.08422505471014208, 0.11911014004820779, 0.12103577865467918, 0.18613512657823103, 0.23644127071865145, 0.10809616290874059, 0.14494043384348193, 0.0982717287936999, 0.1239259219578197, 0.14706398360431194, 0.2080072126080913, 0.07845131815561364, 0.31380410816880966, 0.08163633636168896, 0.2729396606164594, 0.12705540645026392, 0.28857199114657217, 0.11126736088866189, 0.1491940144689814, 0.18753168954243585, 0.15194995448954646, 0.23155948267348353, 0.12989943126036277, 0.12981436485725065, 0.16108261120896186, 0.1120388803763255, 0.14700865673442043, 0.17677284266439178, 0.12630377460511463, 0.11095321121355219, 0.10573752374658663, 0.10716125984946567, 0.13667236863365098, 0.1819890587320251, 0.1729855337931264, 0.14875585814156841, 0.09548295424470017, 0.22363756663135945, 0.0987415322132649, 0.14719855460909106, 0.11997971879017931, 0.10378891016326605, 0.13861274677178553, 0.15781650259610147, 0.09604979036075455, 0.17451101403322913, 0.12899786834755253, 0.13669705198657128, 0.07231738238084702, 0.24477957086938046, 0.1094240154470167, 0.09758435640363924, 0.06956230037875714, 0.2166835567162883, 0.16274296888901343, 0.09246800755781513, 0.16049542013675938, 0.1669194351040548, 0.10803183450573876, 0.08516606349017351, 0.0466084752171751, 0.2032641171207351, 0.1331748708241409, 0.16318469518615356, 0.11173881139726409, 0.20154210468453748, 0.17528568214226156, 0.15367438776358483, 0.14688398358562302, 0.17751486010609135, 0.24196919264091601, 0.08660330572315762, 0.24685594493583327, 0.14517091905638096, 0.07584839653704437, 0.11001260846012062, 0.16341233055197424, 0.0892796568692692, 0.0977169125971775, 0.12683779917537205, 0.16731110521622244, 0.1075985504975242, 0.1714935469170732, 0.10090789096730371, 0.2144946290120002, 0.08840081612429312, 0.10285039116898853, 0.1620178207034065, 0.10974260077120797, 0.18528959533620268, 0.1010869333760873, 0.1654639753002313, 0.09671314589438901, 0.22632190807452127, 0.14819727279245853, 0.11656236909930745, 0.13097834352764393, 0.10596700538430484, 0.09021104358497167, 0.1223049488579554, 0.11928152923862781, 0.1808676132631879, 0.09568293383645435, 0.19029708308798654, 0.10273134876643458, 0.22453191299592296, 0.08798415622403545, 0.07873215832777562, 0.10720071337756612, 0.1910363579349172, 0.3349710868731622, 0.21199551230717092, 0.2837898251750777, 0.29289741549761067, 0.184413512507754, 0.07368569968328362, 0.1338973836672883, 0.11609369948987039, 0.19744595512747767, 0.1237914045791953, 0.1757443083390113, 0.17648960463702681, 0.12354041885344252, 0.19006109736379118, 0.1668384136451829, 0.20437604777755278, 0.13337947758695773, 0.20474041451609906, 0.10764437787715467, 0.18334791484859683, 0.12839737032810528, 0.13380436527152217, 0.0938617513184586, 0.12190757139075188, 0.2541145054443229, 0.0785091731156553, 0.1663885974595624, 0.13622483539004482, 0.20534928587655868, 0.12429815641934834, 0.24857630262211447, 0.2005228247012823, 0.1246316804580631, 0.08213046307284987, 0.1474214555515397, 0.15573453608780138, 0.1308869952035527, 0.21670255569681046, 0.1627300066813346, 0.06336518916331473], [0.0818049906182193, 0.03423903956108036, 0.06032991816379851, 0.03528156648239782, 0.022026987092929984, 0.03168513224790654, 0.047252927531277945, 0.05532421539687822, 0.02171701068178781, 0.05593512455121644, 0.019511209890967416, 0.07722003866107234, 0.029874303408207434, 0.01273398434052304, 0.06950336523474225, 0.019067376852035522, 0.047870965133751595, 0.07978015894731207, 0.03414590242168596, 0.03392079897645501, 0.06219116324979452, 0.03923158859834075, 0.04116252470280855, 0.07543605737267964, 0.028278546092370828, 0.0171805884794242, 0.09430536985277169, 0.022480785020536954, 0.037972503942587686, 0.035450860422344944, 0.06222303633788421, 0.01639812734098204, 0.028118037265695395, 0.04504474037657342, 0.01836363890869243, 0.025082452170130227, 0.038445984584189234, 0.034055151646175695, 0.037161875666389545, 0.05871922596387806, 0.012094381362980893, 0.0448785605840385, 0.009990229906003562, 0.036082565033387755, 0.061358678485116655, 0.03094685906093688, 0.03963142903822084, 0.071631197427069, 0.089236740623751, 0.02183574664917204, 0.012758087381840715, 0.026363104116171602, 0.028280038048603365, 0.021005148376007716, 0.05368385261165039, 0.019605055661691774, 0.030225857326220122, 0.06367656943057814, 0.05814896160436254, 0.1634263499609886, 0.02965230644950944, 0.11603948344746906, 0.04156509241569908, 0.07108167489810337, 0.07646964021748112, 0.026608805750466646, 0.011590597155924526, 0.02847701840613398, 0.042275861130967256, 0.062350141815841205, 0.038061898742471977, 0.057837194462697354, 0.016268807868923874, 0.03943830593338898, 0.03626841030293896, 0.046393928463540735, 0.054767560589337544, 0.03497318544935796, 0.021270929174798153, 0.06772316075981626, 0.0462779121082877, 0.12161598300501225, 0.03645994760576756, 0.010187384548536953, 0.02552896268635748, 0.0373303881966539, 0.03872149661483784, 0.03324598659791293, 0.0722662843162975, 0.038595804569101146, 0.044997024590209614, 0.019003621099757093, 0.08140936749236238, 0.04550856831032903, 0.013035899591481975, 0.0694457630837156, 0.010120694679508527, 0.03976423421033448, 0.05738283920612547, 0.015391029113332833, 0.023176963591287215, 0.03579039442082567, 0.08044868557443542, 0.09556536998359427, 0.06035628691015225, 0.024217106063940355, 0.017608915898768653, 0.11853807921250982, 0.072288385952913, 0.06328958011562787, 0.022429709938625177, 0.030523038153807004, 0.04303773174122457, 0.07527157063445739, 0.0393729318203705, 0.042005386128420794, 0.036386858987351584, 0.042210601931137424, 0.05924011978711333, 0.08108692874591197, 0.041822275792759274, 0.04634410976582477, 0.07652222449260374, 0.0224908150266856, 0.060295176076432394, 0.019508126387072187, 0.029393747944625157, 0.042181567198807196, 0.031138151215629715, 0.10537396140036084, 0.005688834860320053, 0.01873135345146781, 0.03600370394246232, 0.011915363852054843, 0.05272079965159778, 0.06079754972409818, 0.13583970766875053, 0.028239895041371067, 0.02577849667549374, 0.021162182993946538, 0.06161935139267195, 0.03644909597032013, 0.02806841966605956, 0.012347005559281718, 0.011851559261671238, 0.06488194749239953, 0.033042628558412675, 0.025460476341146617, 0.026836245763866652, 0.028907554073920174, 0.026020080587195776, 0.05939840121314891, 0.04194552784845714, 0.015265264289243328, 0.012558374963250133, 0.04491195435665789, 0.024638264815533356, 0.03248510424107794, 0.0332200123868402, 0.02079117810353637, 0.026197991101071242, 0.04987194848757598, 0.0644072181274814, 0.09893958892432914, 0.06239866582496513, 0.07061678976301225, 0.04213581642796917, 0.04543142708679361, 0.022803744706775875, 0.019024090969093868, 0.0406813295558095, 0.021196833150761745, 0.04122317971421346, 0.053553885795296206, 0.01728728154463874, 0.038712686603708614, 0.04761922098095379, 0.032433780180590774, 0.001993905419611462, 0.02586426213383675, 0.02551342067759364, 0.0996601099388734, 0.04506615636449668, 0.010826471374340115, 0.038102459267623005, 0.07009771156815753, 0.01706822636356998, 0.05528443628140996, 0.015986553306931692, 0.029356355193041028, 0.03139958255023005, 0.01936148183660642, 0.0327552191823, 0.026641921816213478, 0.0583561156095276, 0.0544840237876821, 0.06671783889854146, 0.048352378615809065, 0.10400772019619904, 0.04027961220051493, 0.012517145068775262, 0.0172255999754153, 0.05716885552711545, 0.018669664221365127, 0.038249402592379245, 0.022965931266005483, 0.05214465173682378, 0.049630481404282396, 0.017663712252772624, 0.06400151328454096, 0.012595603963540447, 0.041181960353447546, 0.06846640394219468, 0.021972495258875915, 0.040353060880255316, 0.026775087049651532, 0.0258658996467749, 0.07174023472133183, 0.040020203338034695, 0.0355838111511642, 0.023647764840373592, 0.02620691794060892, 0.03861105737967357, 0.038040731733124104, 0.0037019855892961666, 0.05008624243219534, 0.022032238625650926, 0.04478446583473875, 0.013512548006650422, 0.04789423122401199, 0.04590144118053779, 0.041601382000672246, 0.014186068569430181, 0.0913150069273768, 0.030103005551462694, 0.0612751787318097, 0.039633930315293615, 0.03158609240105556, 0.06555065031974547, 0.041570286491825696, 0.018701182993789835, 0.1065818752132116, 0.023717317963019017, 0.06485043063519463, 0.006323455393524661, 0.0720507301570427, 0.048284694747698885, 0.04598967918765642, 0.006502814771186922, 0.022789049225168365, 0.03202767505670988, 0.0791263412083349, 0.025229518068954352, 0.06649066318547533, 0.059709095831720106, 0.026503407373844136, 0.015797343953782995, 0.07128609013893912, 0.028896457290336974, 0.04208528909892325, 0.041535927448421724, 0.0240248620450016, 0.13794269562969286, 0.06597612023113236, 0.029847701005036795, 0.019366670167073607, 0.08373960777516327, 0.017259037798090328, 0.108964002631124, 0.031584818779881445, 0.013019574257815558, 0.022456482796358968, 0.010718407011741113, 0.0255339058686889, 0.004499363177831495, 0.05578463806981041, 0.005290122006103517, 0.02463447268030817, 0.09264699634044402, 0.05484834456095292, 0.02912200123612439, 0.03753492601155754, 0.013131860722487253, 0.002580875762730777, 0.08063662992489916, 0.013400286439836267, 0.01908235578617502, 0.050360130356444474, 0.09000222333857129, 0.03262588821892296, 0.04215434043397827, 0.08897086214875022, 0.040110115247267875, 0.048633666949406754, 0.032887342536161025, 0.06441593620805972, 0.032137763806648796, 0.03929395581625643, 0.097434226153118, 0.03527891581817981, 0.01923059188430348, 0.037304207141841614, 0.018551106369423292, 0.010422378188870367, 0.019477274111141602, 0.01887294948251257, 0.0356886541140416, 0.007817895666155364, 0.027654803050081098, 0.07201450185910349, 0.04649237076181077, 0.03864332117260464, 0.04389621369961289, 0.03572916867391717, 0.1133194116635188, 0.010326015819314747, 0.04931806308788158, 0.023076062150780233, 0.05834499967374629, 0.02817218819062316, 0.11577878372683642, 0.04175291419209492, 0.038023383672078775, 0.045517799669816617, 0.009894858662699981, 0.04807908824014087, 0.043484878110428976, 0.0906338551712613, 0.0580926503114883, 0.01741054892209509, 0.017158942665123654, 0.05279314516472721, 0.022982348530222813, 0.03844128080433415, 0.013862240331007109, 0.00799584400562209, 0.048656327830206965, 0.0479605054903415, 0.02069135110134319, 0.10001285512360836, 0.007297248906275679, 0.11094761877170495, 0.056453808210790164, 0.015187000746898835, 0.05906338330298182, 0.047398124175566825, 0.05098940263832769, 0.04282948223032779, 0.06034002286351978, 0.07373783962741014, 0.025631375235295104, 0.05816953106512947, 0.11955016563015601, 0.1393276447009656, 0.19655226759852903, 0.08430858127652638, 0.1156856963831571, 0.1360382929804825, 0.11530722596592481, 0.08089416570240453, 0.17222865424569578, 0.13551182203715847, 0.17852537604349275, 0.12810066447503146, 0.14158242532322485, 0.12885698477827734, 0.11398668956732559, 0.1748574083490718, 0.10502627239592614, 0.1779917958042314, 0.15679020524745987, 0.11860669770788763, 0.28371680167413527, 0.12093719079970353, 0.19530576593693227, 0.18162191875519293, 0.15185837633907795, 0.09394614356419734, 0.1639412070113805, 0.1378699479204032, 0.1147930890381817, 0.13897692964922997, 0.1469662001416568, 0.11736613322770405, 0.11186200599636763, 0.13542405900455293, 0.09667724701425723, 0.1558998885053781, 0.18057170414155532, 0.12744125429420702, 0.09135344155853795, 0.10436052666796793, 0.12122900135094121, 0.17746673446268807, 0.08691334916699318, 0.15181660922544618, 0.14399901903685064, 0.14218139882770278, 0.2114015336959593, 0.09728556679141137, 0.12577169589818488, 0.13205993710266006, 0.06330813859559356, 0.1588245210868697, 0.09535600581476766, 0.09850325588617595, 0.24062999434048132, 0.13621977920974457, 0.1438811947140963, 0.18980785933954103, 0.10727375986114626, 0.18791698580307348, 0.18559955451036655, 0.22658904293371787, 0.12119040584131596, 0.12791825894026027, 0.15442880050789926, 0.22167336315877978, 0.15824807056736562, 0.27313605491672793, 0.1567699498827419, 0.15368918858228192, 0.13501973311987617, 0.10809192644251932, 0.17305129478054662, 0.17463225510812577, 0.1051778888570205, 0.1430371956479165, 0.209112708126345, 0.22011147842051523, 0.09287404181856303, 0.22859815448041887, 0.0911639726931049, 0.1977966395356963, 0.10782356584264387, 0.13376829785204705, 0.16533544106829554, 0.06640558912148399, 0.2599741127942839, 0.17948021271055747, 0.13084150490260896, 0.18134814957457204, 0.28775445275729705, 0.14081489715364673, 0.24306034699322718, 0.14780780901351284, 0.14547321735130203, 0.10321815933791861, 0.07070764012995266, 0.18741352814099482, 0.28242811921142763, 0.1441769659399025, 0.10256692331524626, 0.13897245569575217, 0.25615242189697685, 0.15960136488560708, 0.1760777864124506, 0.11367995562332292, 0.09099307379895642, 0.22219903737066254, 0.19418125611639794, 0.1506673547649576, 0.09730878691639631, 0.15306288106066568, 0.2666067181816024, 0.1557246229100612, 0.08741280018922784, 0.1406906836576039, 0.1713097777457968, 0.07400442290330127, 0.22322950223761223, 0.12751898157500452, 0.09656702994459099, 0.13066977863350224, 0.2784960656877487, 0.19152512203060812, 0.1418835744862595, 0.17607890490082004, 0.14573456058579107, 0.12179677209426319, 0.10047025557967926, 0.2300712343065008, 0.08937912572535778, 0.09929165995169072, 0.09841208376230733, 0.20481346866055844, 0.220503531576645, 0.08481448275908347, 0.2183216365595018, 0.10281839167639133, 0.13545097933421213, 0.19939224746438766, 0.17784438516584136, 0.10922726874630298, 0.1547486115727694, 0.18390879846147953, 0.2038621866414624, 0.2287858307001091, 0.11552289503836825, 0.1316636091759128, 0.08812274152953779, 0.09297041567943751, 0.1676246037165965, 0.12815157867847912, 0.11602652123979024, 0.08298468941281881, 0.10856746019975794, 0.2207130719456942, 0.13241727115406146, 0.22845201554798314, 0.08974844905277414, 0.1969099540503756, 0.11385737392570704, 0.19544039822874532, 0.105671372054325, 0.2777765865527815, 0.1341390844073988, 0.2733487515680252, 0.12212967560175927, 0.07925816961834509, 0.09477192505953774, 0.12339722169863603, 0.15595766685662732, 0.168459854058681, 0.09483498175658527, 0.20978766223115308, 0.17696539120328042, 0.1491874873998665], [0.019366549508225535, 0.07987454864046267, 0.03653839117877426, 0.012653362204981668, 0.045353627027643305, 0.04885238505178883, 0.03265131850756946, 0.06329595013671825, 0.022767763472192233, 0.04608396928937686, 0.05036349348243206, 0.03649562048996168, 0.013925616869763022, 0.03941389454168178, 0.04752055651718571, 0.04777284842284937, 0.016735656104320963, 0.05832910334931747, 0.042783831050919915, 0.030624404992727988, 0.027522524563415397, 0.0308546201596337, 0.04433859500192827, 0.01642378171034638, 0.03430741673876201, 0.03211337922801895, 0.03403956175691659, 0.09849300562974908, 0.006403538873494273, 0.07389787539479233, 0.03344855939729079, 0.07527934642688883, 0.012008219454137069, 0.04448328985862675, 0.01905081403111258, 0.007097665286217366, 0.010727250539217024, 0.017893908267480232, 0.02509526307544401, 0.03849111099336897, 0.04589444679778911, 0.04398997137022596, 0.018764113286329855, 0.06541525960088738, 0.007767057592695159, 0.049902557530590606, 0.04277771000840491, 0.08993044856094545, 0.06177823036728848, 0.06463905165512716, 0.04622331302192423, 0.07445913439075794, 0.025795861973517367, 0.03301991022101814, 0.04359133368838699, 0.01822611271974541, 0.03533998834750345, 0.03940403882053591, 0.05020260735745392, 0.03684162410096296, 0.03524721126943346, 0.033324556575427135, 0.10220436454420129, 0.02353271375590515, 0.05484284788009621, 0.03241568135337965, 0.04601478771937471, 0.06871827832993961, 0.01973792403605917, 0.02743600067802735, 0.03549719342000542, 0.04863353671445962, 0.06577846188578876, 0.05959674903762437, 0.017521652738533674, 0.06312555303016017, 0.05935116040129816, 0.02541173208174446, 0.05930939711810601, 0.01852829418625803, 0.025169138849202185, 0.07159166729017612, 0.011130486663821484, 0.05166590424074281, 0.04054845543578267, 0.05377908500151769, 0.0321353851036439, 0.016993831565243103, 0.05546103103927547, 0.044337752305211565, 0.009392912109051983, 0.019580927722516562, 0.04960042011413363, 0.02814848926068554, 0.01414199265831661, 0.04108297413275127, 0.020291734742180958, 0.10402336371161285, 0.04079395980243722, 0.009007115976043768, 0.07330234928597366, 0.040390250618539514, 0.07463461449069363, 0.07930799597694028, 0.007372326480465071, 0.04387673974457768, 0.053292416156299656, 0.04594603132817053, 0.01502737579416604, 0.03317033924582986, 0.05601115494726166, 0.034470784988614826, 0.0834670183699458, 0.013157975702216069, 0.022592534266051748, 0.058913662909500064, 0.03198807405668401, 0.00840445280060052, 0.06512795364664448, 0.015361131574477882, 0.05267659254792718, 0.027923872281286507, 0.041458560228948636, 0.015331954158271755, 0.11609339305470068, 0.07706370309836443, 0.07239467299152767, 0.042469757984602646, 0.09288203211561327, 0.03858021851028166, 0.01652213973894475, 0.027158113774813475, 0.007184136981865572, 0.034640737764176824, 0.08299542230463798, 0.0364774756974751, 0.017496381413131472, 0.012431722434778369, 0.042601521277139266, 0.021179333787351366, 0.08954007313736985, 0.0094450501379587, 0.005849570640543055, 0.009270811100460349, 0.03372973281769984, 0.05983637367946006, 0.026671707314709504, 0.0024629908711499265, 0.04454063920063838, 0.015781612338257894, 0.061690957630954446, 0.02876042305762249, 0.029921212887030937, 0.0331871893497244, 0.038253378588706255, 0.02870702864451995, 0.03602294424068063, 0.026988630228105093, 0.028401457238942388, 0.019225476332189097, 0.025804626019371134, 0.03176936553040099, 0.04534923734383718, 0.019360757883517973, 0.013329583227694517, 0.022013980835195512, 0.05972434864229253, 0.04442457688010989, 0.04193334705046108, 0.029035117289411928, 0.05277480118938031, 0.08298704130274635, 0.07767488804435538, 0.025714235305185282, 0.03000722923916915, 0.07418362619054895, 0.028735778009098385, 0.03931233809599954, 0.07079158804469532, 0.05485503250853189, 0.029358402563018665, 0.054895738590388536, 0.032131196517917904, 0.07533156297980778, 0.08366778703226198, 0.08936516760337739, 0.05368805843435469, 0.013458063833475595, 0.008701210364609236, 0.02347680465919116, 0.03563273735644837, 0.05278960583851703, 0.005465022273241513, 0.028903290794621554, 0.03946039990912523, 0.023612049821343635, 0.012779173951956534, 0.048219937335459456, 0.022801360258111553, 0.06407369025832703, 0.05506489080406966, 0.03523573527232774, 0.03840186558062992, 0.02671216824843038, 0.02552393331913458, 0.045018229903953697, 0.03128620728309597, 0.0915550452566916, 0.015629052631406775, 0.020623542743945317, 0.03218193643636281, 0.0677790085694963, 0.042075368260303815, 0.04582648713802619, 0.02443094035580514, 0.07145432304711112, 0.02575550254644646, 0.008283656056699975, 0.02875539943605902, 0.019893359445456057, 0.07713458155311885, 0.06260324194426499, 0.03492569948937144, 0.02907614895863639, 0.06979722124073776, 0.019157547315943147, 0.00559286558963058, 0.03585273482566399, 0.025698817785709135, 0.04170485749660481, 0.01476728032538367, 0.03423472648606666, 0.059127501031804475, 0.09843560266158274, 0.05471954985912289, 0.014431435997868258, 0.04371057144336162, 0.025081178548956112, 0.07240631752797673, 0.05450541679296763, 0.05776795543610089, 0.03477631617457636, 0.023989853742081794, 0.010098933952019341, 0.03585641587814016, 0.020962774137695952, 0.03998001436552694, 0.04333373279340806, 0.012204993925538036, 0.05186027223845163, 0.042093179804543336, 0.013756454122372934, 0.06194841296922776, 0.021127295349874807, 0.050637201376018987, 0.02193533999454831, 0.04384127753456274, 0.03238108865315876, 0.032965571604548924, 0.05731577586923396, 0.04280374550651159, 0.02053986870563559, 0.01889230660913933, 0.040869005775499734, 0.07030833212117996, 0.01498660746766555, 0.0032411872938786063, 0.0326235669725124, 0.030736479825610598, 0.030589080678539413, 0.023202112342621532, 0.030869518654541146, 0.037982148989554376, 0.06928045663141436, 0.03794538443006816, 0.05775334230894524, 0.062335344827583725, 0.06362172519607891, 0.07089239755465139, 0.002543585954211472, 0.02782415061618292, 0.020888517235195445, 0.04957374110217056, 0.06075399379516321, 0.048445377859377095, 0.035108346341838764, 0.028506801989410194, 0.06731901873624133, 0.04284523299805099, 0.03683838737948287, 0.04504664793550488, 0.0333228865037522, 0.01553545583925781, 0.009005399939093378, 0.0364547458687617, 0.03757880752786033, 0.015645111749519505, 0.03188359307035083, 0.024717365308935126, 0.04091418581083417, 0.0745327937446775, 0.031854238496312214, 0.01837563201514704, 0.006409147115904959, 0.018628573180326534, 0.04214581387538103, 0.011646728418136557, 0.0676434722939326, 0.043891973402952, 0.045459048386903546, 0.020404880182937752, 0.0534899021318603, 0.04004521610876245, 0.06824613834220557, 0.027836764253856196, 0.021290598482254054, 0.0621269804034983, 0.05145345273758135, 0.025323574513857885, 0.010287763134035613, 0.07230597533165448, 0.0784402481851078, 0.080296088520798, 0.0472765268697854, 0.03076341930746792, 0.01221803848766872, 0.06400158989333338, 0.04194270098401655, 0.021854398974908457, 0.0409001587409406, 0.06958565839956846, 0.03191500267524633, 0.02692989426695051, 0.050596372720094464, 0.04076502849197677, 0.02145430189557374, 0.030396813676962932, 0.024000667073133013, 0.009964271974299225, 0.03529374728039388, 0.01774369566250713, 0.01801165023578271, 0.0812416018978242, 0.03577334513407081, 0.07360545963409447, 0.014429162631952956, 0.014225584342174474, 0.035504743216499206, 0.0897939699972349, 0.01106593226488199, 0.037049804663946556, 0.03505586548858593, 0.15728820836351765, 0.1522018135555329, 0.13839318597268674, 0.13339187288957258, 0.15991837206867435, 0.08320170680000898, 0.13118570820698816, 0.10024114166416469, 0.19648100609981245, 0.21315250425569474, 0.13362251132005645, 0.11024100991386561, 0.09361787488864315, 0.09127802020239253, 0.09641758151232235, 0.12752433652959524, 0.12060358249131711, 0.2298493752436292, 0.14529841140873972, 0.11802226455221254, 0.18169342540204528, 0.14751991317156823, 0.17449235213139366, 0.19598042892832912, 0.16829298478701424, 0.08479251135741511, 0.07485670337994253, 0.30609775394681965, 0.10122466066311445, 0.17255968083777737, 0.09003858953233689, 0.213397667713223, 0.15474165549441693, 0.09627898854594077, 0.08290195957787576, 0.22873134652693428, 0.059903080785466786, 0.1311298910408251, 0.14490563812996113, 0.13818405929111666, 0.15649572104936646, 0.10802967413779228, 0.1085219392552972, 0.1870523023629381, 0.1261773088105744, 0.11880863848472796, 0.1269664559813757, 0.15140791663960104, 0.19386999459276277, 0.10365983200890404, 0.2348075269330894, 0.23830431994170914, 0.20541553716025046, 0.10810066750573535, 0.11593702684847579, 0.13718816031131054, 0.16309432745460542, 0.18156676042464473, 0.12851334071808285, 0.1605216663090452, 0.17232133556277524, 0.2220746246917594, 0.16359778511668407, 0.11858919259881782, 0.15084796765398595, 0.23056241924003248, 0.15876848941608784, 0.10065728062463385, 0.10974013396809179, 0.10634800389168725, 0.15179932628187442, 0.15478593537644034, 0.1298877714021552, 0.1975362156067164, 0.13662697026325812, 0.1326941506516549, 0.21896752528846267, 0.13076253655937412, 0.11436368909574325, 0.17825969675135228, 0.12122612086034591, 0.14410890668870943, 0.07695913209670013, 0.12664429302657806, 0.12986705638468266, 0.11558892415656198, 0.13086137722336477, 0.09169906978645632, 0.14422643989805253, 0.1274803401001038, 0.08731927617543167, 0.06483100264543487, 0.15000452017111165, 0.09641287773246728, 0.08736464390230757, 0.13104007489258243, 0.11306210571239073, 0.22019841407816257, 0.1804057235318807, 0.09768517357447455, 0.22048634056362415, 0.1951897802251962, 0.21455303555534733, 0.1814288033112403, 0.1247996299137031, 0.10976340771923143, 0.16918457323505035, 0.2789799881077582, 0.10545369583151995, 0.1509024365054023, 0.07615459421950002, 0.13881978969420158, 0.09457042095281425, 0.11265985592598877, 0.24026994833782797, 0.10477975296277194, 0.14777469869342544, 0.1114992403815831, 0.16697163633521528, 0.09732768630548831, 0.17278181569230172, 0.08442899497646479, 0.15002653753805548, 0.1003594639440698, 0.21465553811961607, 0.11368185552137514, 0.16428591593378977, 0.22711937496018028, 0.1350612244418552, 0.08235319547595517, 0.15382032751316024, 0.12702149173785604, 0.07102154465692659, 0.14424317125831881, 0.1650176524755455, 0.08683898501218328, 0.10095931844966066, 0.2633212735095332, 0.1622958186893694, 0.1179309621933968, 0.14059098497513803, 0.12491728569711409, 0.08728221284165498, 0.13238074408183176, 0.14256324769268114, 0.1420187123961026, 0.1637759618461132, 0.10841219716014401, 0.07782088908096475, 0.13188094832003117, 0.16933743841946128, 0.1931163939016481, 0.15462324894484014, 0.1527779269963503, 0.15349025087010476, 0.09623576586525287, 0.12053332456778135, 0.15417000068531883, 0.20977926590750295, 0.1855682981230559, 0.16978717799628937, 0.10438229888677598, 0.13936642407169267, 0.20567749326507892, 0.06483519314638068, 0.11598664636333143, 0.1676028621413054, 0.1079616685127539, 0.13560385984038154, 0.21506890384179933, 0.20153848874953487, 0.11980210896581413, 0.335149095063248, 0.0637157931323013, 0.10638546559118456, 0.1832784306738646], [0.03195354264349707, 0.03242862057842074, 0.04954066142560013, 0.03427378164844648, 0.002168687182523671, 0.018333746157887004, 0.10050419327472487, 0.05667372907121336, 0.031495040936035015, 0.04741698909070223, 0.044999238584310784, 0.042119422146389564, 0.013561070100554537, 0.06521537193968412, 0.009387260295390602, 0.028145467043824257, 0.03795854965104692, 0.06792881706308934, 0.01595416598232283, 0.07107163914629529, 0.024283675274120706, 0.0408867368805072, 0.06782180224094661, 0.025102885650290598, 0.03127500516242318, 0.04655775636614812, 0.04668765806502873, 0.02395970818226136, 0.03576281142511195, 0.07102437152136719, 0.019385563810506178, 0.07236489515391088, 0.042763732734226415, 0.027834324263817364, 0.02822155489646379, 0.09642755597709649, 0.01743996286794784, 0.03814748225493297, 0.030261087794637972, 0.005763289030461062, 0.0291094756985624, 0.03288578354723511, 0.01580719392926943, 0.033232721785504016, 0.00939451514803354, 0.037618575152009726, 0.012838336049518999, 0.050502412036181464, 0.010194330093180461, 0.024799995552448016, 0.03883971547287318, 0.04043786298303355, 0.04635244480244095, 0.09408072989073493, 0.00878969160464382, 0.04294577820767318, 0.04530616021985489, 0.03805094368515476, 0.02518086765532292, 0.038454756290922244, 0.015775557370826362, 0.07403957867814649, 0.045741665883049856, 0.05747591122804631, 0.021191677379031337, 0.02159036294136557, 0.06722720309851632, 0.04221556235044714, 0.03351967150886213, 0.07307642995710335, 0.08697419186993953, 0.02340504903376343, 0.07773337885737419, 0.11571794102389006, 0.05285550472176364, 0.009380404766078198, 0.04408283654840724, 0.028720693737869302, 0.04301117147288976, 0.08681083894184521, 0.027529695146386663, 0.008558237290520583, 0.018547151440514192, 0.012515552563502664, 0.052296915542214155, 0.01603105439684324, 0.008154607588245023, 0.02774682744676548, 0.020784411631945162, 0.044386950471708854, 0.03587326981247433, 0.02662753276977568, 0.04181252732392281, 0.008092646396929219, 0.019356352877953363, 0.06231209788952143, 0.03361501881191808, 0.02297983001617174, 0.043389515485614545, 0.02233207011745582, 0.03816578792588365, 0.054740138472087925, 0.01637606209354295, 0.019183429596464963, 0.06710490482228418, 0.027463842228415514, 0.0289384312477083, 0.00686011195460695, 0.07253908056525454, 0.04597317765376741, 0.04714655239255198, 0.04150748260379319, 0.03278916070778524, 0.020572735792807034, 0.0846240409619866, 0.0036362262776932653, 0.012685103142904419, 0.04315147664578211, 0.0348819520384554, 0.04829184617847205, 0.06290835561230779, 0.036191089048741326, 0.018642927752807736, 0.032029241706515034, 0.04595188807035166, 0.027622705881273555, 0.02965023609689407, 0.06336425836648672, 0.04716717164903399, 0.03392182936471316, 0.007028738919254994, 0.10445143066106305, 0.03958488153594156, 0.03988302380387341, 0.04130586741432067, 0.056512168788861845, 0.03543955296458256, 0.03625673895341255, 0.05380056610691452, 0.09055115597983522, 0.04081818350260297, 0.04568129432417693, 0.034632801093281276, 0.020780820594800097, 0.006429368485471295, 0.02392873907792232, 0.05233213260409333, 0.091778474799808, 0.04106368403881788, 0.026620967396264596, 0.03240739611247855, 0.06027528077303883, 0.04433118693170048, 0.0700621267840747, 0.02522306377819229, 0.06627533885259783, 0.007079854699587751, 0.03237168875432784, 0.09110717493439875, 0.014112091289022037, 0.03198761440392944, 0.047220257711747, 0.011143740942521442, 0.03275270641390835, 0.056506472925144824, 0.08569605077706999, 0.05452940300587685, 0.015141141766141501, 0.03741515965591516, 0.06523532853011163, 0.011189244650003892, 0.023165016450108062, 0.05512043983945924, 0.027886883641082435, 0.03369887862654944, 0.05129997085239138, 0.02818158234379465, 0.04722578503612069, 0.011965976408382338, 0.08210612445949547, 0.05934567521176031, 0.03615047872787522, 0.08038006707905762, 0.011954280160998386, 0.09840092952212981, 0.06204521966977947, 0.013235616798122084, 0.027385841071185087, 0.026957442788707636, 0.021099785132513895, 0.006408581647255849, 0.05878909701301206, 0.05015318702545859, 0.05264256292233064, 0.0429689408760638, 0.04547962550854972, 0.017499394053893707, 0.04153516902137668, 0.05518857569944474, 0.025985204434442907, 0.03647688964021303, 0.03440068411310354, 0.11332106641343526, 0.1101813393254434, 0.07166023215939922, 0.014499500037110863, 0.026525600941010544, 0.03502515685414115, 0.07055197872461812, 0.05920277683124427, 0.04732796584346122, 0.07420565121837201, 0.03322866151950533, 0.047249729114194075, 0.03631533318830114, 0.02354075001823085, 0.10978034592323727, 0.06006767477599844, 0.03674644533725035, 0.015491413444490924, 0.09441857466534262, 0.034474305162626895, 0.05662921553237304, 0.03318571463047016, 0.020202548701256033, 0.033098338472266356, 0.018804097330317866, 0.03188129289135818, 0.0337490190811936, 0.08569351502604063, 0.01307184347927931, 0.011167047252397866, 0.04055052387317823, 0.07362497955440514, 0.03264333587139845, 0.02458186925298745, 0.019448953755800764, 0.03961299313232303, 0.04991094236292186, 0.026901830551064303, 0.08110452578553269, 0.04456282127648593, 0.05054769166294606, 0.07646829956361363, 0.022296956477446422, 0.09041542818229045, 0.0702011717423316, 0.011245556900488033, 0.1309370360667667, 0.03786071639267668, 0.0919955687957906, 0.05287102949354918, 0.0311817109750043, 0.046256519103002165, 0.0843447712700694, 0.050114752394297434, 0.055698878357126835, 0.02716217978647159, 0.02092655350063597, 0.021658923980149052, 0.054755713039588545, 0.04237555981343312, 0.004150007932161492, 0.016565992526950377, 0.0222015957678518, 0.023640149926406243, 0.04022561449317202, 0.03736487364456539, 0.024739246695272388, 0.0565164550507982, 0.08106527144029256, 0.04267541045743612, 0.042614797580867045, 0.011585792827029383, 0.050040457187400716, 0.06972029069138151, 0.013662681130001382, 0.03311185226325066, 0.006553384713873628, 0.02215873889414774, 0.05513528279299217, 0.05684971095873945, 0.046993254368463834, 0.013961338592062314, 0.053921768877414934, 0.06907611033849179, 0.03183181701798833, 0.060281298393684055, 0.10129365454157514, 0.03469183199828671, 0.01682275264043241, 0.04276040408219542, 0.015111878165043892, 0.07119207582887142, 0.06709336753814452, 0.03850303132147078, 0.03621590646704839, 0.049958681131923394, 0.04791360941805667, 0.04771132773209003, 0.031659895396460934, 0.04435526124472099, 0.06332333011913203, 0.04317046796542503, 0.022333067946977193, 0.008285479345959763, 0.013243299702392712, 0.03626655253972258, 0.029308137619086815, 0.024916682234634797, 0.035253447225137104, 0.07006663138106947, 0.020435079368912888, 0.025169820667454795, 0.074341417320313, 0.02726105109397923, 0.024067220961554878, 0.022173966806862625, 0.00876348469436409, 0.035008414002556, 0.03357647692844753, 0.048137023639414585, 0.009010941627615643, 0.032295631545205275, 0.014838159737748005, 0.05768313418112456, 0.06600813504548804, 0.054246877440281456, 0.04225776996463538, 0.02958309806642994, 0.08193992934520207, 0.08449734534106909, 0.03163294825372437, 0.09156298192758715, 0.0239792415091107, 0.054395184401542916, 0.030313838693884113, 0.03157828213466752, 0.02341171208348486, 0.035611420959955266, 0.023321240930066958, 0.033293863262740836, 0.019959321530956416, 0.06016046334538729, 0.050019286347613226, 0.016292083535283323, 0.02278226360137905, 0.02268223741632556, 0.051234853378827536, 0.015621082444164543, 0.11666816584165059, 0.015887027951858698, 0.1497506233112466, 0.28594400313112045, 0.13747919711374468, 0.2974725232249306, 0.12577209426390548, 0.11419483565635259, 0.23955008615889858, 0.08571543280155429, 0.17813867018107446, 0.12983652012002084, 0.13375355832038388, 0.1279511777383666, 0.11357404396779115, 0.20962790225542363, 0.11123576742266456, 0.15009637411323287, 0.1242657355783928, 0.23199537138064064, 0.15846174781120595, 0.15028633327493746, 0.10136502329260112, 0.1369723686647992, 0.17484427760204962, 0.0818705294401415, 0.1727269025098893, 0.12459028106663497, 0.17101140182104804, 0.1079468830158153, 0.14975688991046723, 0.1655766208686175, 0.10791434726167111, 0.1301286141237905, 0.2470225537376058, 0.11271923540099976, 0.1390902800185065, 0.19023683793362112, 0.1262498956414, 0.2438197699525664, 0.12587619029105673, 0.09598008402052427, 0.16653804589183102, 0.1738544460386038, 0.1143382856201741, 0.19140182784007442, 0.16451719787813004, 0.1289251512817798, 0.12336012006046311, 0.18761481008222028, 0.11252327777084806, 0.11464442967647508, 0.12219210410670889, 0.10861963844828068, 0.1154465543767137, 0.17059412905045096, 0.17708471705836637, 0.1595821667222246, 0.12364115941548541, 0.12041412894764256, 0.19389898335981756, 0.13588440123825304, 0.12069151406326603, 0.20055728333611644, 0.1552201846554395, 0.10990710283118872, 0.20949775923884686, 0.14318062262910028, 0.1854114492814387, 0.15269600155372776, 0.14119814029864727, 0.1461411540907237, 0.1710018870090285, 0.07998350166505383, 0.18405538172491137, 0.1951490243476245, 0.24606885088066904, 0.08883914865192868, 0.11374409250434368, 0.10460115488498442, 0.16103099220462386, 0.21117466441806287, 0.09270832933966192, 0.13466360948739514, 0.10190921384961375, 0.10599045533566706, 0.19109131708260507, 0.11319651583870573, 0.08215414285058938, 0.06755367146744844, 0.07693610349369627, 0.19463874850301974, 0.11913518346245251, 0.14041495329189685, 0.14077028019293664, 0.0887342022671815, 0.10833465374044834, 0.1691819532143493, 0.12067108249832546, 0.10070359830053584, 0.18376690365614431, 0.1522875081507429, 0.09161801002318821, 0.13540049414000205, 0.11777941468021563, 0.10882356339284491, 0.19034784407384936, 0.12413778357327947, 0.23528381911737306, 0.12377473450596295, 0.17094715768771787, 0.1263897832963736, 0.35138574639155024, 0.20374033269622635, 0.22463616224065905, 0.13197615772726076, 0.16666546163539733, 0.1141796441328141, 0.13547158709937526, 0.12715102954497262, 0.15678027674796122, 0.1443431610541959, 0.10320058528093562, 0.10677150495710874, 0.17278858790955237, 0.12985467640382628, 0.15080612393156176, 0.19622439728869548, 0.10255059798157985, 0.14414762477240256, 0.14174924862961616, 0.12238594733418957, 0.09273723383704502, 0.2629962990120534, 0.20260281470273772, 0.1602114313432286, 0.20970124751329425, 0.14114226184545026, 0.10160303148891657, 0.09115503244702855, 0.11343588767152642, 0.13609014181119783, 0.08558553493311329, 0.16115097689532465, 0.1013197934615516, 0.14947450990157743, 0.189515091178398, 0.11838436367050295, 0.08725605859992006, 0.1644599711101863, 0.15185189523523854, 0.12260815113662712, 0.12484437710936032, 0.16434136537774918, 0.11766842386174588, 0.12414228050939499, 0.1177027369398744, 0.14490626632205902, 0.18643040750776568, 0.2228992417334549, 0.13168559589933965, 0.11222651829161953, 0.15733345351632566, 0.21489920004481272, 0.05705071327787253, 0.13047560598821412, 0.09054311205663028, 0.11322114556547135, 0.1281560449710777, 0.13161370620852517, 0.16633739214270346, 0.12039090882265761, 0.09546814576512384, 0.08776621953133615, 0.2085029634256517, 0.07744864695855687, 0.20515534305764785, 0.16998764788431509], [0.046887457626120704, 0.021124041391416423, 0.02503343020385552, 0.0751231181164903, 0.06463917422919505, 0.01629436456207787, 0.036932635346367475, 0.04693845609924005, 0.016184474994999268, 0.03465128679489417, 0.04385446573817923, 0.044690221698293765, 0.01547856423478093, 0.056938075370365576, 0.048632793609173074, 0.06079215646511125, 0.07355677474650645, 0.07888775844607623, 0.024105935214808392, 0.029533260216515873, 0.06223752689097197, 0.08875258071648498, 0.04237459071220891, 0.07186521430529895, 0.01770495076573664, 0.030400657523123008, 0.03697267110129038, 0.016149715670654853, 0.10438281982656449, 0.08330923490106099, 0.023129546579213876, 0.06806591615801857, 0.015535078540955101, 0.07044783673219143, 0.06054697002494528, 0.0675718660556501, 0.03781408079028611, 0.05753522941602334, 0.03280139896237562, 0.06886285444300982, 0.04861111332091594, 0.019369751755749027, 0.07559556453939408, 0.017269073549898404, 0.04530634408095672, 0.05385782351837524, 0.020613321215815602, 0.03924093487101697, 0.011454316817464368, 0.013588656926707876, 0.036032497357096405, 0.05139870426407264, 0.037664950284506046, 0.05584781734092582, 0.031458513863805326, 0.07970269213640883, 0.03729912031802439, 0.03703606104658496, 0.04731594209348963, 0.02353609794931066, 0.030451713452836683, 0.02182613607616194, 0.07168382766746706, 0.004126072472577254, 0.033037679630421826, 0.012135549970421822, 0.03806645696562144, 0.041143652126793905, 0.026404365611773346, 0.008072539461746572, 0.04231595434248448, 0.03416306662162946, 0.054207623095041325, 0.046101922559882366, 0.12708270216300604, 0.017420282069173072, 0.026563217773312525, 0.07602946141794806, 0.044341038822406725, 0.0776219666905461, 0.02129901012766265, 0.04489949010612984, 0.06707927152033775, 0.06229858026809751, 0.0072079211390847645, 0.046946791135856224, 0.03061130297400298, 0.030527931540423346, 0.07351174409831725, 0.04059355120144544, 0.03747533969280701, 0.06828399074654426, 0.09886316399300292, 0.04644154465847439, 0.08083622647269119, 0.04568402925806661, 0.07337147339938149, 0.014149873787837644, 0.029469044811482874, 0.08166344055245, 0.010229437987530425, 0.05538070288997504, 0.003912640855677667, 0.0394446644631605, 0.01434134693080259, 0.021418414506760818, 0.026450212143601912, 0.07491628203781382, 0.019794970773340716, 0.05847973538742912, 0.03091872448191768, 0.03585370775732783, 0.04845064854429615, 0.04834015568297717, 0.07366598824099188, 0.0688066695546431, 0.013825109964537044, 0.027686779560040564, 0.07919923447433018, 0.008112378906638873, 0.03852074327428014, 0.016595603740443627, 0.031153587887303966, 0.018954578066064466, 0.03650852524104618, 0.06456151589631073, 0.11440103588205193, 0.05541971208707941, 0.09905566656661612, 0.02618801855151692, 0.006394200740502246, 0.0526290069965105, 0.03528185759580905, 0.04968618748769645, 0.033184086693631064, 0.026136922402187224, 0.0610737435729994, 0.06473821407604603, 0.00507951821125443, 0.04114170243302661, 0.01993056259027893, 0.06731696562060425, 0.01733507968545441, 0.02472680734260188, 0.031237215960338235, 0.021061411788386684, 0.11820183556166389, 0.02595907509056551, 0.02552756457589567, 0.02095582572022273, 0.019294908795986446, 0.037712987827798056, 0.054941355295839815, 0.03266799624168104, 0.07216807950528399, 0.044567130521060004, 0.03554628816463294, 0.027255048795092492, 0.03316455145156191, 0.04602615646417103, 0.03182738711456618, 0.012319593975741056, 0.05988023221312512, 0.006630277916443565, 0.05781933312274276, 0.05256755908410396, 0.024795728442709775, 0.04388064296255189, 0.06152929775717278, 0.11523412585618997, 0.036819001524558956, 0.03409556661462111, 0.060088627280727516, 0.04040958284730873, 0.0427300823221524, 0.07665225259599186, 0.031898106606076324, 0.04169278395091815, 0.050645896473959576, 0.029510070735047904, 0.11690242786801631, 0.043788681768121264, 0.03724707230444878, 0.033687858451758666, 0.07766451521386063, 0.05846490775565467, 0.04452768848427842, 0.04884947774811618, 0.02000928961581761, 0.07909523037772986, 0.0416951741452419, 0.03216212923308054, 0.04727047860562321, 0.09869702250486422, 0.036311966231873924, 0.05601181761331617, 0.06573029793798923, 0.040958281831755754, 0.06652185828575204, 0.03240088053468255, 0.03482569437173586, 0.035036027641786684, 0.015587625469291403, 0.029704814115839622, 0.05136421115528192, 0.0019131167796477978, 0.012102194502198649, 0.07298751779261135, 0.08290054231521585, 0.06963855677074002, 0.02149545039320665, 0.057916476901981144, 0.04928168540279712, 0.027530545503982616, 0.04127841082311446, 0.08470310889665159, 0.016249065783115167, 0.07266190744215444, 0.05474298448872663, 0.03735313334712579, 0.10143579449504615, 0.030251080771127058, 0.022855101325999827, 0.013637333195806753, 0.03558180017036296, 0.02797186768974268, 0.029639453409359823, 0.0263309245929122, 0.05118390853186289, 0.025729187426247427, 0.022481518549724452, 0.12161671844941956, 0.05711711011826993, 0.03568356345978475, 0.04883691007571836, 0.015286901485054724, 0.029856352052921732, 0.025374505954283862, 0.006614638231469379, 0.0033041348233969225, 0.028374119391364437, 0.029170006220679612, 0.1318883946946552, 0.04635044531295857, 0.06958066350630215, 0.05623203724802983, 0.05938415580819692, 0.01778229883301162, 0.09322335492939719, 0.056357288793210066, 0.02858785792223869, 0.029962775072142966, 0.0725984370576278, 0.045334275646675984, 0.08450827741574857, 0.07257340896514154, 0.015273277568931301, 0.022764086250155684, 0.012915299157612027, 0.061596506650769905, 0.04752711806025717, 0.012749569441732621, 0.04809327235805893, 0.00951936832749315, 0.010339396502522212, 0.04533110404266946, 0.10591943132420702, 0.07964123656312305, 0.054878865503856254, 0.10567092006244969, 0.01547882183184547, 0.02109702338554686, 0.028199041487589, 0.015231853279645647, 0.04373060847302118, 0.06338455969648016, 0.06021341917315318, 0.021427833557789846, 0.06766755043739273, 0.024522560641109466, 0.02958165207547286, 0.0508940821483491, 0.012173996092901837, 0.038417880648687, 0.030771867342052922, 0.014367527985614876, 0.033818713930105014, 0.015905001332172226, 0.03871840161962375, 0.03353565210296262, 0.03131498729119138, 0.06785872767889692, 0.02140817765687262, 0.03864840033554262, 0.058514963940627156, 0.05581811228166184, 0.04622737328792292, 0.027389493395364093, 0.07300188194119162, 0.009632267662504268, 0.05295464032960515, 0.04430941471289243, 0.09868016857053004, 0.018591347052865935, 0.02904766006395221, 0.057021969658953536, 0.02189469519972561, 0.04243188642806584, 0.03201435853336607, 0.03660781406647256, 0.026958787273014748, 0.06175001917947685, 0.050224797094180706, 0.04315618808651644, 0.02276933778287663, 0.0342525954869005, 0.04655415192246438, 0.015516482714203098, 0.019745854961295283, 0.026990273486702677, 0.06712297683641796, 0.011929135240103689, 0.018744771481461583, 0.0622362436936988, 0.018162749587528167, 0.037563807526302916, 0.03458855951565408, 0.010179609713715412, 0.069789499074461, 0.023342735442002455, 0.014185229703153094, 0.05068311302532112, 0.07544029383890091, 0.0896219602755962, 0.03789092323953106, 0.040248470726392926, 0.040338175791886546, 0.08570975609003537, 0.053677520894956206, 0.07044035971405045, 0.06735660300980653, 0.08994010126879139, 0.03215049235751072, 0.05090630891162062, 0.017382372208240054, 0.16208814757485546, 0.025244052672097762, 0.04346815058060231, 0.06745954990507134, 0.03358603387530293, 0.02615076178053935, 0.06500189387870413, 0.1423034825993161, 0.10643638745551148, 0.12400510480567334, 0.12676201775790225, 0.277388517053858, 0.14908408085184713, 0.08978293833112524, 0.1530135603201005, 0.19037646511870046, 0.10596186493433292, 0.21149550204075154, 0.10780308065154862, 0.1256492520652471, 0.23753844652204748, 0.12473461969244866, 0.10466071822109724, 0.1466453012319342, 0.19401947366854838, 0.14803161393971215, 0.16926655996470683, 0.25033853467433687, 0.20918887258777696, 0.27890681138923096, 0.17872267432751196, 0.1456662868299792, 0.18024011064440976, 0.18444115296006205, 0.17583394062615212, 0.1100160405340214, 0.25073671653386087, 0.14737644022510898, 0.15104256930851168, 0.14453042358640703, 0.19290165945647225, 0.11473219270908064, 0.18248649494301888, 0.18753804807220736, 0.249940705215258, 0.17535201003474576, 0.18092726086897237, 0.16978000741331808, 0.18607345650032645, 0.1724774642817436, 0.21320671263721683, 0.24035576550710588, 0.1756527455103013, 0.10082567441126994, 0.11513589040165949, 0.1447165523084902, 0.1707444048576778, 0.06679547424878805, 0.1482606895508305, 0.13524048901613683, 0.14746516852849914, 0.12800594536407342, 0.22083624356216003, 0.1652954206351311, 0.1675817027928368, 0.1450410671532154, 0.1243034654086636, 0.116655211294851, 0.08063039396919551, 0.2291926693531775, 0.18651190394115064, 0.10129814381681143, 0.2542845922852716, 0.2461612870496127, 0.24514775272578965, 0.24880079702744562, 0.2355264085194757, 0.19474001000485114, 0.12753306993193206, 0.27223682091120754, 0.24018456017778766, 0.2170090521535566, 0.17193435390870418, 0.1306209481892086, 0.19390782401446374, 0.12470636636980119, 0.1656465646961043, 0.134377368395367, 0.1281986241379092, 0.1884150348844067, 0.2200673211125597, 0.10401171151428454, 0.0886265515920616, 0.1332254479489019, 0.06953709608604831, 0.17868735767420263, 0.11138902331191687, 0.2206660341471434, 0.29719642513701994, 0.2554738212136492, 0.21768245876075762, 0.1194721165924303, 0.13173957445448445, 0.16780970588086114, 0.14062959580652176, 0.20533900497661484, 0.14177626088982628, 0.15047774800369818, 0.08915192702965391, 0.14438987709581852, 0.18475034604630164, 0.28725349254185156, 0.13255481457998677, 0.09963899655568023, 0.1771218263574185, 0.14860228815626714, 0.11464577033034257, 0.14541882510867812, 0.09423115891554663, 0.21328174328852087, 0.088309375869651, 0.18185140805379038, 0.23616796119078515, 0.0913224686237593, 0.10433244954554305, 0.27509399179008703, 0.188307169704668, 0.13825688360919877, 0.10025053390211637, 0.21107010873815707, 0.1529361394744727, 0.16992069179973296, 0.18671972827324945, 0.2190768153917405, 0.26545191724454203, 0.22018301571088456, 0.20916608913290888, 0.0904466309434464, 0.19778792145511798, 0.19901240574977092, 0.17611203054266591, 0.14106632721039558, 0.15873556295710226, 0.09154796660427125, 0.2116907012438582, 0.1406968430045151, 0.08854938355544884, 0.14218804847088554, 0.12189494626175974, 0.19204799236068804, 0.13084326690483478, 0.16624351572846213, 0.15187040391948917, 0.17458507941374857, 0.10863451587577021, 0.08801135234534742, 0.11627264230722383, 0.08854006792628959, 0.145618605517572, 0.18908252729283226, 0.12707996722911635, 0.1983483607370046, 0.17730443107505, 0.15351767681779402, 0.2584522638109423, 0.05772735277611402, 0.20337406605962785, 0.09268269603771549, 0.13116438031917618, 0.13806586724615869, 0.1309870769299807, 0.21577751985000027, 0.15899944960349993, 0.17398877189524714, 0.210528775689102, 0.10000582243646346, 0.26607735142592465, 0.11846352353571885, 0.10811181408503365, 0.22188923141408354, 0.12852885399854955, 0.07745519701030947, 0.14381967785377658], [0.10124566679399821, 0.04610373435782329, 0.05559541435251313, 0.041361355162676305, 0.03528888645251432, 0.08993175091041673, 0.020764838085479794, 0.0150438342356093, 0.03635676322324622, 0.023848723109451034, 0.03857701243231854, 0.011784370477882125, 0.056519561537331155, 0.054253124887303966, 0.062207886949181564, 0.026304055974187873, 0.004609979092023306, 0.01011622264125054, 0.03047972928822762, 0.02282435055671921, 0.029684696646948016, 0.006010944667767974, 0.06709787979601853, 0.06677325003810468, 0.04115261152506836, 0.033513347453047196, 0.031041354091177066, 0.06948485655049164, 0.056890053148832054, 0.07627413457920475, 0.09904686421636613, 0.012326959911133013, 0.018071970083720742, 0.040820408988023, 0.03377955151541579, 0.06938551792935019, 0.02783671828858074, 0.012364311485491213, 0.04977930164445312, 0.01652104997887246, 0.018757373627815998, 0.06502345159289337, 0.02435904683455104, 0.0230598230020053, 0.033188154620508996, 0.08431041222666541, 0.04940095380128873, 0.036684890172534415, 0.06058337452310709, 0.029409916230267095, 0.005409258254428184, 0.07186423371275587, 0.05120151323236285, 0.036288543093589046, 0.0738225229865601, 0.03936681460829512, 0.036814638653830174, 0.03996326385306255, 0.05591112684698836, 0.014495377526468328, 0.025128277634540876, 0.03039003188361324, 0.07957012062111209, 0.04465456030541851, 0.04131296521893913, 0.03141187251575532, 0.018670074078404618, 0.05382040395371376, 0.023393808608694423, 0.03604681170996159, 0.008840392261082608, 0.055666714155625914, 0.07730408616724514, 0.038306851525821035, 0.11678301008237947, 0.04407779185942585, 0.07911900974689953, 0.06216119772063629, 0.008945012100852065, 0.04145554184252697, 0.053450712904093735, 0.05157622215788692, 0.05072408723795126, 0.026955393503510186, 0.0872644242800532, 0.06897742289208597, 0.07786262555107956, 0.004614957705921224, 0.037511058542276585, 0.028304152581239903, 0.055957191713875344, 0.06572834441378232, 0.038063695218654416, 0.06077456325593014, 0.03289188543755201, 0.10488008749821495, 0.04085211353676935, 0.010670451822900965, 0.03734937185541757, 0.031389110128305135, 0.005555023719000841, 0.09987793937926331, 0.009372703667219368, 0.04205283761445073, 0.03502203121541008, 0.04137233320263125, 0.03743403223192981, 0.014445728325705617, 0.0158875833656038, 0.019840742611596664, 0.12368330957307933, 0.029409782164880348, 0.02938744112578852, 0.013092059581991167, 0.018537222941015518, 0.06316617867278476, 0.03449101737069507, 0.04259606673111839, 0.05349947440047419, 0.01861275729512976, 0.01672387558726534, 0.0257723871242976, 0.029310899366053845, 0.08116203600600844, 0.01251414870738142, 0.0643185357893667, 0.04569422588833878, 0.04381392053478668, 0.05246258971671905, 0.06755378638063708, 0.012027050852925788, 0.04851307704924576, 0.04608627904446856, 0.0676721622866969, 0.051049896771268505, 0.06120901937866884, 0.056242306656654806, 0.05863582580200127, 0.03898563990069013, 0.011836186749860646, 0.05469729500492254, 0.03041447966449684, 0.08559203901959044, 0.004694564774962924, 0.018954798316342697, 0.06514514465966532, 0.05611105281258783, 0.02429393127620701, 0.029079063923188278, 0.0270989143304647, 0.009878510346395836, 0.03639822007126866, 0.004062812762229794, 0.03286904452608959, 0.031238807508000926, 0.05497394850657833, 0.047048512290442185, 0.0251793431403536, 0.04937145558576431, 0.03486572629621914, 0.0011513505488701707, 0.016322393804007483, 0.028909771898460966, 0.0232589484057239, 0.0989361108851529, 0.04097858316174919, 0.05306202287395155, 0.04953117725709754, 0.009804517744229206, 0.02041167921326574, 0.05306137552965553, 0.03370879563472925, 0.05693074773936983, 0.03168889757005438, 0.05925534195416878, 0.0997301763404281, 0.06647768565603802, 0.026088949976368778, 0.03127315122964642, 0.04302058669347917, 0.031076756929377877, 0.05546165923137338, 0.08610789198428394, 0.023430349087462794, 0.027150332236722596, 0.03530557567794477, 0.033265644414049965, 0.03704316651208266, 0.024084011693635297, 0.09120449874429934, 0.005181612833703478, 0.036400391930533994, 0.012361233727255417, 0.036465045920903646, 0.03564395671409946, 0.011353132882035308, 0.028784591216413725, 0.04329830505734971, 0.02133191551923031, 0.05336108061695292, 0.01542754086380404, 0.09704396564273104, 0.030151761302183715, 0.11606752992637696, 0.027586037082777872, 0.004501630798087366, 0.01537407271473879, 0.024915441172197465, 0.08665255751580962, 0.04285071818758884, 0.030243873798979387, 0.057364035578024004, 0.0531698459188544, 0.014162050755394083, 0.04668392338639787, 0.03517418010761181, 0.016446180206032533, 0.0487067862113397, 0.050485952637128295, 0.049132240800968105, 0.011041228802153661, 0.06384829953012448, 0.10819433707623713, 0.03192483732897428, 0.04354158776902384, 0.04186960470472132, 0.09111598494552797, 0.04906831842456614, 0.01949269163061775, 0.007468583991736054, 0.03337212297464571, 0.035325666333759026, 0.03872799687087536, 0.09500967278595894, 0.03613070599854954, 0.06014974194488699, 0.024691609432920817, 0.032471421910750295, 0.009583332838730948, 0.021441006439647848, 0.021691185857860312, 0.028153897841430964, 0.06194478171246667, 0.05118411154516282, 0.08607020045840934, 0.04662633272669008, 0.008910479730055218, 0.043191163830699465, 0.06597700123224529, 0.035752902077811385, 0.052481588697241205, 0.08866416650914377, 0.11808409550858122, 0.060705408499005346, 0.01844835099613955, 0.019640885593910373, 0.03263238081408124, 0.05912710266608385, 0.10419140509780377, 0.024869933634275393, 0.005631213557095297, 0.03957207637628721, 0.054979923992387714, 0.06392129621798955, 0.04937384194964844, 0.046207397545297305, 0.028925742916462403, 0.060099061398256215, 0.030919913833420125, 0.11906606700992393, 0.06491442962038903, 0.02652499573155036, 0.07667289100467198, 0.020673752146502657, 0.07456362878362979, 0.030996694995631135, 0.032729034297048085, 0.03555209511109898, 0.020962121047740503, 0.020764612089542132, 0.01982087795172007, 0.05363641644737894, 0.06843842641119996, 0.03148800250323069, 0.017187387509752187, 0.042185466586341785, 0.051280788010767395, 0.016485367518579288, 0.04702771683373759, 0.009545370309253134, 0.023730820262684457, 0.012994419760821808, 0.00506284334997256, 0.0411544080012508, 0.08566109418508508, 0.04220181490264593, 0.055952798199629596, 0.04855051193566573, 0.016709911719625516, 0.005006104484275585, 0.0053469858398931406, 0.046035150336402084, 0.06553735103337996, 0.09790038299416343, 0.08488598940593582, 0.024220166585197853, 0.07699061831038806, 0.054873230927173174, 0.08364260572219089, 0.00812245104762335, 0.03982064126419925, 0.08563759060756815, 0.040863126050680876, 0.0304364146769888, 0.08832153368500933, 0.013880701134762457, 0.09981441536858197, 0.016424633983162143, 0.07575096547483437, 0.02412275850562559, 0.09731220366853861, 0.04882002932830684, 0.04474542599411742, 0.038856688150835615, 0.04302792581579378, 0.01921832873185556, 0.0343667617398164, 0.03334863471888727, 0.04599720983195209, 0.04894127423364309, 0.06721892168805485, 0.0324771139440277, 0.01742601240684669, 0.03952246069187119, 0.0340809419961466, 0.045430967434039043, 0.0545439088807231, 0.023868400077786178, 0.042926051443622965, 0.031341641405296904, 0.0333186615288498, 0.02331368538791374, 0.09423470590263607, 0.07197192269227198, 0.015028083467886094, 0.014336841376197916, 0.09464473148146946, 0.02466463930754652, 0.03013478862422128, 0.047275048320091544, 0.025205855528193138, 0.031115716330767162, 0.17811950266120896, 0.07077281889055045, 0.14343615891712327, 0.11264932221702992, 0.2261343850724159, 0.1908926091968052, 0.17327637141270025, 0.20348694145439133, 0.2196644354731806, 0.1524403120481199, 0.15732164044053326, 0.17704236771791212, 0.25444718678632094, 0.1288811012261337, 0.10577736797952846, 0.1481572676810526, 0.1868931399357896, 0.1252638485523001, 0.1511363384704436, 0.10418937496480443, 0.07507937449601389, 0.15185379513329075, 0.11885116402540477, 0.18939826276994523, 0.11580529036901652, 0.287477680512013, 0.13574872706686297, 0.20979855600143635, 0.15507511824609774, 0.13666208773370714, 0.12258491568988371, 0.10834012360822771, 0.1680551604518006, 0.14033679700186177, 0.14107119952959402, 0.14375287498677933, 0.23670927891808174, 0.06054683595955853, 0.14386155221971775, 0.1259797730392987, 0.07263261223992995, 0.19741612366370617, 0.0984722140034841, 0.2258067599107181, 0.14139001468016257, 0.1654221162560486, 0.20943529242950104, 0.12678015105906995, 0.19687621553819026, 0.13186159693906385, 0.17026759173360564, 0.1519059503991758, 0.14397212935070838, 0.11762956788222637, 0.17297249497665515, 0.0954744736513784, 0.16710220836102965, 0.13780394178484717, 0.11077452886609301, 0.11879828863687093, 0.10862772067588185, 0.15769216652599075, 0.1435032222540148, 0.1567654912510226, 0.11225619653780615, 0.1145573637838806, 0.19150246114980793, 0.15781944437373072, 0.19252578607730328, 0.1676049918657349, 0.08708618626359009, 0.20637754441028644, 0.1842743756189462, 0.1779493238897093, 0.1966370582099884, 0.21122835185979644, 0.20370628774887134, 0.18640342589107253, 0.1341319444679445, 0.10787216646056022, 0.11386180957478863, 0.16754361290124156, 0.2111978615604101, 0.08839281050548439, 0.2264946915449635, 0.10958143885457709, 0.16880883775170774, 0.13671477926113915, 0.11080830568267454, 0.12264112356088816, 0.10021767639104398, 0.15892340771613583, 0.08723753459391095, 0.2261616118372448, 0.13503367592009807, 0.23225228662692735, 0.17961132099791882, 0.10444306498092991, 0.20018350903786, 0.11536301248857092, 0.13593744516613024, 0.26806899616795204, 0.06890305873727606, 0.1310193445533514, 0.14114267553292936, 0.1055107617209996, 0.1463472777076306, 0.14456097517282734, 0.11851410832135909, 0.0916207832614741, 0.2202316316505594, 0.1315227409283961, 0.10515204871133452, 0.10057327142285724, 0.11258428901313774, 0.13665094881528808, 0.2503249749180771, 0.1621141792425225, 0.10960426827472065, 0.14225347237961908, 0.08699561934918167, 0.1625646542637579, 0.08350042746432366, 0.1148335538023422, 0.15552997529026003, 0.17547456878087214, 0.1533031415554785, 0.33230957485014395, 0.1576222533420209, 0.08583927857539347, 0.20698302966212073, 0.13061086647212505, 0.23071451833651913, 0.09550363861865575, 0.1528028401756479, 0.20902191138555928, 0.12267385849789267, 0.1901236867472049, 0.24142954498529437, 0.1385727263386211, 0.2957267620630803, 0.09245545137673618, 0.19004677151960714, 0.08743215157019515, 0.17918287866538574, 0.1381120470262343, 0.1750454063256902, 0.09971854712573752, 0.09527263246596822, 0.09284347491038424, 0.04691712438098846, 0.08702717451078278, 0.15306171660702075, 0.23360847675752258, 0.22796847617193577, 0.12419495671506851, 0.19167329875692246, 0.12198872308457091, 0.11152056060851583, 0.13435368095674824, 0.08054292971088041, 0.09318676657013356, 0.09432908793490741, 0.058486634009187265, 0.21639973646210087, 0.17854552415590133, 0.27824457434396593, 0.13040760802405496, 0.13998352321645907, 0.13991106662058062, 0.15463470962018738, 0.164166406217602, 0.13815811955400054, 0.12346710423908888, 0.15228223746582387, 0.25689292248458634], [0.09022199098140964, 0.04402584343728039, 0.0936593891932599, 0.027323692188327833, 0.06008593448167367, 0.008613864849922399, 0.0272896989519077, 0.06808163628222481, 0.025878946124125394, 0.03835564749615808, 0.0025095953512185767, 0.05535108210038274, 0.024225571335503654, 0.04406509778252052, 0.0030381186919722467, 0.022898588307021607, 0.07298384823145405, 0.044417053896693454, 0.04147419225304358, 0.03226580774231303, 0.08466833616576849, 0.033075018755851254, 0.02656599292681823, 0.05252203430920359, 0.028557769819012577, 0.13938326268426834, 0.026043838888947523, 0.03798660762127369, 0.008872356322113304, 0.005989945240153541, 0.03491211675047394, 0.03973164866047521, 0.06579150070226, 0.027118710042428107, 0.06695481287615915, 0.06662469792870745, 0.03121876856312156, 0.06922657766769971, 0.0409583431187897, 0.01326671230696863, 0.013470350926171147, 0.036534625856626424, 0.06644342620406421, 0.0257393131933866, 0.021331354359825774, 0.03994450235979692, 0.08086441084742546, 0.030125754532374205, 0.003970677761601344, 0.04578213447764997, 0.08631938587754004, 0.02450135341214557, 0.07974806752416395, 0.010801445197073684, 0.09725781142591469, 0.013478555727840192, 0.02147394247473248, 0.04328612808979327, 0.07326941516610884, 0.020169986134034493, 0.027700594040535154, 0.012713151537032138, 0.0180980209035859, 0.04866514167177582, 0.035811791256550825, 0.04507750595709489, 0.016367253997633537, 0.03787193575032777, 0.013196249454913121, 0.024602109295946938, 0.015002458784428817, 0.09572858501586223, 0.022463253098389795, 0.029626847432565787, 0.02458782750181854, 0.02063417412911452, 0.025187065306630348, 0.025943992734556238, 0.026042172647712213, 0.04118621214142731, 0.028816764994013696, 0.0810252586680074, 0.08193250595321579, 0.04117764727843385, 0.023788137045959314, 0.05245688236168316, 0.036215691962429596, 0.08519492202228116, 0.05793812654672131, 0.015241234983888366, 0.015667916271805523, 0.011970540377191238, 0.03842403233471898, 0.03236264891682133, 0.007059654876244285, 0.03926461464875648, 0.07523561046729166, 0.07231375112408593, 0.03873774150927221, 0.016130576879086516, 0.059769758504004254, 0.046609467301037044, 0.04589125604158448, 0.0734834601321528, 0.03842985077250389, 0.04338539010214229, 0.054494768170820135, 0.03665233526619212, 0.03606196109866423, 0.016616878002100897, 0.044495168051892714, 0.02953614453755079, 0.03526449038256561, 0.03540616685284242, 0.04337206783313905, 0.07147128423375469, 0.027148313595042117, 0.02524060910687812, 0.02713759410976162, 0.03188307979144156, 0.047190276860830285, 0.10876759300909697, 0.04306338036492948, 0.08583812944350705, 0.021626974283266934, 0.08417661497068983, 0.04632372033572005, 0.06657354623800324, 0.009602700499066663, 0.04609250733929296, 0.0225985576323564, 0.05637072597540194, 0.019011599905488473, 0.03177918869281008, 0.029954710081520102, 0.10893925799116974, 0.03115742024214518, 0.0560066350285084, 0.02632396085368049, 0.014125813838965712, 0.05245069237125497, 0.042269154031190186, 0.06017305016998322, 0.01527275279870317, 0.07386032176474411, 0.017978735268115997, 0.04600318531776148, 0.09737370520709984, 0.04520968676755025, 0.05752315203989706, 0.030463218178239562, 0.06979022685798907, 0.059093203275434436, 0.060449657706363555, 0.035348622158410094, 0.055611513690241886, 0.03391378927194784, 0.04206847346898529, 0.03386443405742607, 0.04111205866079658, 0.03244794514631072, 0.0022793366130621686, 0.019998606519713517, 0.07384502298889623, 0.040327730183038986, 0.022578729361656214, 0.07810535284900859, 0.034059824782513806, 0.023552622465837388, 0.04288310072414818, 0.0598164783760665, 0.026483973638424953, 0.02517283522343684, 0.04238331262322684, 0.04486940200290373, 0.008730530464691261, 0.09570163404268604, 0.04442019485718301, 0.06091859161613449, 0.027513500047667373, 0.02753321532039873, 0.02879012045600722, 0.028420511760839054, 0.017211253063813332, 0.044815611139300375, 0.05273772636428476, 0.01586575369020143, 0.04501264895342531, 0.0773168568529429, 0.05736549880595938, 0.020180648162720666, 0.028575525821877584, 0.020413669126649058, 0.024061138223436092, 0.03302600445045579, 0.07182689458732644, 0.11082249363103222, 0.01759819258304854, 0.009262365938705063, 0.0611340040491233, 0.014363687012284515, 0.025315545912411426, 0.04040053151848336, 0.008967453688983957, 0.0793862441975263, 0.03845756400316473, 0.035649078011873274, 0.039870421657519, 0.0775326791429712, 0.0332015075330292, 0.05850195576767287, 0.033111775654458234, 0.03210936684251553, 0.07996119318469878, 0.022531375551836628, 0.03693815500986192, 0.009859261429688383, 0.050074153564750194, 0.06357849485451175, 0.015005630388435338, 0.04488668494647549, 0.025411674625150142, 0.026951214493883234, 0.04684376763179899, 0.08549664575125902, 0.022781214060922785, 0.05101382552135376, 0.04250023296223052, 0.05276428663261956, 0.05786263241222309, 0.029149205018315586, 0.01442828450366975, 0.03456408683691294, 0.09480306653365975, 0.06930805111844694, 0.028487096292777892, 0.032129264061128905, 0.03748897988829882, 0.014806044374352262, 0.030971092337201682, 0.03350317763585237, 0.03390305254968905, 0.0406312886925955, 0.016759814687013146, 0.027101819718917532, 0.04367822338075888, 0.017714927145730586, 0.02957268693153897, 0.04391236666349634, 0.00417253666279477, 0.049995706161303874, 0.05590775606012153, 0.040145964331684575, 0.028600797147279786, 0.05381835466851631, 0.032069553253090674, 0.04835919679833516, 0.053289045369432825, 0.0037100788294112375, 0.04073394064400946, 0.04279109739488171, 0.0357426135169883, 0.05217540633654402, 0.008753484374122515, 0.07788385384746137, 0.07810686204221942, 0.017534072939006072, 0.011754229706111214, 0.018038951694184256, 0.03341384795344165, 0.021934501128271226, 0.05740115636839502, 0.043177289978390744, 0.059322788335022435, 0.020118194759913513, 0.05438017290866664, 0.06191416883901243, 0.06227784992886647, 0.06358427881834007, 0.08331062152020394, 0.018786427512344335, 0.035831893403683944, 0.07202086038887501, 0.02550910568736013, 0.0699913632425089, 0.014550834631306991, 0.01729766395123255, 0.04711675540273709, 0.03126116769929086, 0.04684793131966745, 0.0382663254746266, 0.07612398900692502, 0.038964055373423526, 0.04971283968658217, 0.03797122840619376, 0.046510128679895596, 0.01672431225738218, 0.06332873869987746, 0.06590675096958876, 0.022549939777461753, 0.03371010947551939, 0.0918926755266805, 0.05773399858885716, 0.09931576107778858, 0.017038488745569222, 0.04761342169536699, 0.05563070802318473, 0.06699646507660229, 0.02396009888710274, 0.032786755191703, 0.08040959976853863, 0.044274178498815146, 0.04456722245161091, 0.0694574152810439, 0.05362071547537081, 0.02571007544775644, 0.013922877147823814, 0.022619621219834494, 0.04838491053951364, 0.02500781413888739, 0.026712740899153778, 0.045220484776842984, 0.046938670603858854, 0.03188659613501401, 0.03035858971998096, 0.04817335918966321, 0.055898831135803656, 0.02314417502812801, 0.029364895158176942, 0.11534724639908922, 0.01989986544715301, 0.06453271865123703, 0.03246980929566968, 0.05340988041772958, 0.030395520903590708, 0.029268806665054256, 0.0373167326794036, 0.016833826441377882, 0.02189493460220195, 0.033224605083946264, 0.048081493756223115, 0.014721060325692018, 0.0050602788706460315, 0.046325444033549684, 0.009166996610621292, 0.029752300075826146, 0.033598651343415824, 0.05057874886739639, 0.03329002133180057, 0.12126915201905275, 0.05439740988696295, 0.0335088390256128, 0.19180290551195223, 0.160058734698161, 0.2763487212359905, 0.15995439352287402, 0.11342677888610672, 0.09352331665614921, 0.1527443876670253, 0.12887909407577208, 0.10429850418961818, 0.1695599409961893, 0.11001948792968066, 0.17573263315904528, 0.15480573108840376, 0.12320396069797779, 0.15437862174885889, 0.108620626701703, 0.1544581569971577, 0.20145437229544888, 0.15748863228626792, 0.1665508395601665, 0.2217749157740224, 0.11362138820151169, 0.18901002473167836, 0.1483296527857742, 0.21191718747779248, 0.1566345361812461, 0.08392025130770861, 0.16060475620531267, 0.17748922680414495, 0.1390991359949112, 0.1670352829199645, 0.22126509958217222, 0.1262972015707243, 0.15444583830333528, 0.15083508205509957, 0.14018002476903701, 0.19111509645177474, 0.22730106037230263, 0.1479745863546287, 0.10364494692053526, 0.1400872055561312, 0.13073057537117314, 0.23072130587552828, 0.15566474547789944, 0.12849395869359856, 0.14552417752002517, 0.10645220717114788, 0.11879337801327629, 0.14668406528090278, 0.11435220543775829, 0.16261541524962073, 0.13654922766070213, 0.18399567283209295, 0.1148813576888173, 0.17981621887414687, 0.09903541886277738, 0.11491226933656201, 0.19829903999643944, 0.24895376946416595, 0.14804770178612203, 0.1447159087946338, 0.12283698926048896, 0.06540786685241808, 0.2386675222266105, 0.15022984195140102, 0.12631680576070664, 0.08799919452998908, 0.137453303341904, 0.09987382548710994, 0.19829953029271097, 0.09424470335004792, 0.2359330173461668, 0.13991561718285084, 0.16785801538536627, 0.24841534754922315, 0.12266985185804868, 0.15332941837128133, 0.09552352626117007, 0.19380616414691174, 0.11738526244317332, 0.14367041328260977, 0.1826794418476282, 0.10563867542171672, 0.22670810831890953, 0.16053441401210525, 0.243193079386988, 0.10259921392125469, 0.19947544461296451, 0.14035988689189957, 0.17172642232429597, 0.14484718562133853, 0.08239583592982062, 0.07290222156312197, 0.17290616708417095, 0.06759533132877081, 0.16854139645734142, 0.2096694548644366, 0.19831823815982189, 0.10656951821499294, 0.18599102543967386, 0.1356264594341478, 0.256657473021938, 0.12632153252319944, 0.29484937688516033, 0.09493610536259028, 0.12102129193203104, 0.1633172130752956, 0.13646272101229237, 0.13867829325458697, 0.10126317190306802, 0.12945614214385712, 0.13926689392857014, 0.11541383476146769, 0.15554826946989184, 0.24378010191984717, 0.1815269851396161, 0.13121400749491108, 0.13136865000330633, 0.15852516456957788, 0.17675563632961244, 0.16819071204912278, 0.2376330737024546, 0.15296975541259014, 0.1407820319816951, 0.10776491415116096, 0.338774498912596, 0.14745727782287907, 0.14933255380920826, 0.14617558208204087, 0.0907287121780457, 0.16276682486697552, 0.1227864734227619, 0.08229384664446115, 0.13390236323879612, 0.22732264873000885, 0.13785101022691498, 0.12936451802811316, 0.20511385173566882, 0.10061196652391266, 0.09322386820830646, 0.09574419022687981, 0.10231519448420695, 0.20234588413469254, 0.19129258370207203, 0.197245423952418, 0.16565994059126224, 0.13032483988471572, 0.25993678899061295, 0.08092747520535223, 0.16083262139751067, 0.19988934659669477, 0.2777200492639696, 0.13874860480427742, 0.2134027698587987, 0.19426947880175807, 0.1532177533954382, 0.14376252769462525, 0.09143211112748231, 0.13518347675281187, 0.10914586424346893, 0.11005803747403045, 0.13566467189981093, 0.10863489891973235, 0.11704909540111981, 0.20310046541835033, 0.09824167516443039, 0.11889237189485181, 0.12635832006532338, 0.11997711409123675, 0.09281896009680726, 0.15755460777830693, 0.17595205606231767, 0.10895280242567101, 0.2531776565217203, 0.1594880758033645, 0.12497885618358852], [0.026786296831203565, 0.04972458764490101, 0.028260428112961596, 0.011846085563452255, 0.040881849239550294, 0.06400240960741235, 0.13773571399431075, 0.06326491974534527, 0.03178098899943214, 0.040392215634065295, 0.08441320590434537, 0.013919428794554645, 0.1356138189833972, 0.0478574360210088, 0.03255249699577689, 0.05633868051752929, 0.07056523970658742, 0.018438257787737156, 0.030114594546537247, 0.04342309311933575, 0.0382083747535944, 0.03698790092922507, 0.056006041310367086, 0.07782471185970692, 0.06229032567071338, 0.05963318800974277, 0.024664039843745773, 0.08201029452104723, 0.04213436086091303, 0.07056788270992619, 0.032273070255835215, 0.01579749908658766, 0.030721774767904036, 0.04853031019710245, 0.01969398123272244, 0.03148849279950223, 0.02175568663064511, 0.09211097228070421, 0.046308900364824844, 0.07820723488205865, 0.07360376657978182, 0.0340973899038809, 0.07663080979499125, 0.07228482364406509, 0.03875810412629958, 0.03370008521503018, 0.09247310204251159, 0.03269623424257002, 0.009253147985756157, 0.022345049562112942, 0.030384946975015828, 0.06413631411569734, 0.03878245040053322, 0.0632532024305434, 0.06992565588124337, 0.03436426046274362, 0.045758389582436894, 0.02777389907878974, 0.0707307683243867, 0.11716725680256083, 0.04247397529862581, 0.06750816584474618, 0.005377838594628679, 0.06286942302399585, 0.049378174176860246, 0.021754284689743674, 0.03315929225796173, 0.05368437738187852, 0.0652397795009517, 0.031032342981967716, 0.05030604454899027, 0.038876257866861365, 0.04381801527474196, 0.05314909642742527, 0.07442978556237875, 0.052696748321214994, 0.022758700652047995, 0.00715909835567037, 0.02119236302772357, 0.05112816797449224, 0.10784643356718364, 0.04599296570485158, 0.023229923249492725, 0.039995868555119926, 0.008597280961581537, 0.06212590404996469, 0.04303518449887634, 0.023567609060856125, 0.012454139125052721, 0.0302666591690673, 0.06475847710164324, 0.06000172992747638, 0.08790603057751734, 0.05432219154411747, 0.08693722046671376, 0.012805629840811655, 0.021518756703083074, 0.050385349970911784, 0.03748747835596723, 0.0035015501752270447, 0.008067249624629416, 0.09411981569663172, 0.07129090883198284, 0.056795510238096605, 0.04772474193164418, 0.03900411411098415, 0.05043542530808238, 0.14107340586281594, 0.009325116200582876, 0.024765370293490352, 0.027665915155422785, 0.044862028406632525, 0.012592811573056445, 0.03610275528063217, 0.04823602901230897, 0.04956201995692907, 0.03705202631892697, 0.026780468817319603, 0.01724961300140187, 0.08833890855913201, 0.03914368766990881, 0.014067148740944124, 0.03350934464364283, 0.02579680234644442, 0.036908055415316936, 0.0913150605535315, 0.013193898522595485, 0.02725755964826432, 0.08118771527323031, 0.007840208455754985, 0.04687808070992751, 0.12406399398441277, 0.042069078678445476, 0.01690117514602119, 0.019067788624294826, 0.03704239276327914, 0.040741754740837126, 0.03206578410050321, 0.01593202508370122, 0.03167275418226998, 0.024950288596653172, 0.04403148184440309, 0.055109752912915526, 0.05538354507617413, 0.034009600058197975, 0.036363818893028844, 0.042352661445376374, 0.029896437603559707, 0.023723023402835094, 0.023640536800808003, 0.0159833874485846, 0.037754153562409264, 0.07106351095341867, 0.10010433368264668, 0.08003656857556875, 0.016787560476410775, 0.07468378967455319, 0.029837504374764623, 0.024485775014205326, 0.02951910291167517, 0.06449550976075473, 0.06594860235289221, 0.015032763307493542, 0.007884685126613946, 0.0476049947281999, 0.004287341162712584, 0.019358760309255412, 0.02251341270523206, 0.03282435478702669, 0.012928841676893494, 0.011805066343156562, 0.07032539289925369, 0.11443164875550617, 0.04982259327305421, 0.05141597954676517, 0.006786406635411925, 0.048333306856934106, 0.02309517221405141, 0.029128120363419576, 0.05296693604078986, 0.03857556452614166, 0.07273299274064841, 0.008276464406310791, 0.041613206567783514, 0.029960214423256058, 0.08497350729040562, 0.043219359696752606, 0.043652233847927664, 0.017127178744563175, 0.027454831119206165, 0.06304013805704252, 0.06158575843719225, 0.13081469182525912, 0.026226621722021413, 0.052265892811720414, 0.024875164099578417, 0.04975750261256772, 0.04633821854968706, 0.0698634495417918, 0.02169205153721475, 0.018454613764920545, 0.014264015142896004, 0.023245888521834727, 0.014586906838831643, 0.023136374337839025, 0.03191736222605311, 0.08314573641626105, 0.036985847813588, 0.01222882500564259, 0.03034445348255817, 0.04446784169563363, 0.052579054233407786, 0.021391249028965834, 0.0395520470075069, 0.024790461588230346, 0.012993032184068956, 0.04200004649558856, 0.05025572406368391, 0.14021255286230197, 0.04450309706190902, 0.06724823987291706, 0.015769477505537293, 0.11404254503788487, 0.052131792951014735, 0.05296626954429573, 0.03218831794877206, 0.03657034853653562, 0.12527514068830398, 0.002695598865806636, 0.0444163452653635, 0.03034485567871842, 0.007986962652554917, 0.04095117636625806, 0.028666209564694477, 0.024627261877720876, 0.03433787256419178, 0.06575907220042522, 0.025732247947504925, 0.04690119358260305, 0.05396132582738515, 0.04204744818590341, 0.01665182501798676, 0.05829792357079926, 0.028019518358632926, 0.04827034209043749, 0.06257708004165081, 0.05780627132363378, 0.12263284215042669, 0.06077966923194547, 0.02312691123675435, 0.05672976840287448, 0.025011433904329618, 0.050835380661151106, 0.043325056847665584, 0.025221903154987003, 0.03991159888344907, 0.025893528607764074, 0.018576061683556726, 0.041032791543271274, 0.03352322998727041, 0.03725415478730875, 0.06223504476609731, 0.039259899377582536, 0.04280432390289442, 0.024796492615414244, 0.08151170151728777, 0.061302447631474466, 0.06520840820045241, 0.044222375633375305, 0.00417974028330777, 0.08623239659373799, 0.04843549149471426, 0.013022174168708585, 0.03873527853659565, 0.050035734255347526, 0.03332203997659587, 0.06027881626880938, 0.06780158518062485, 0.02431654619173177, 0.09568232862699418, 0.040093276634692185, 0.04190800103148626, 0.006412071656555899, 0.10408326412641233, 0.02502477149509134, 0.009069994557648897, 0.06619571933462735, 0.0521572002570235, 0.019877871062846917, 0.06607933525717066, 0.025551778699962363, 0.03483654600718329, 0.08487054507338232, 0.040987531068704786, 0.03741414075897586, 0.01935891161162046, 0.03263469823005219, 0.05515619699332503, 0.025260427801479256, 0.03484152940913074, 0.0867895570193087, 0.02858848228389698, 0.039665692320634285, 0.0386491127973122, 0.07575468866214638, 0.0152424578517375, 0.0733110903491897, 0.11520164372820048, 0.023887492904079058, 0.014074710986366677, 0.0385219881671571, 0.018535870795829162, 0.05271139592232724, 0.02450477016428786, 0.0641867954794678, 0.11342021351259564, 0.03231096862544937, 0.046879720138085466, 0.0035139777971762085, 0.03206100754229532, 0.01940856751565251, 0.030536523216494152, 0.018775127715461196, 0.025877735705205032, 0.018534999370815295, 0.05822191998783139, 0.01930377434849018, 0.0791649290570809, 0.05387585339767318, 0.06829031863279882, 0.03478847015949507, 0.024745580327186375, 0.07827704847459832, 0.06068201983467706, 0.02988828259760574, 0.03497341144529562, 0.06481020335829066, 0.027056482635558616, 0.024140723267449968, 0.008032113480787244, 0.05320216333794017, 0.03230088307792622, 0.05095573307405557, 0.015301500248061794, 0.026986205559824745, 0.034271671076215086, 0.012031602372805919, 0.03829806449732954, 0.0773225105818241, 0.06489542297898762, 0.036466041835205215, 0.015383991638138412, 0.13508270554725202, 0.1105428102516359, 0.14153141918922627, 0.2040443776716148, 0.15227745707717635, 0.22162356744370154, 0.2049748220991704, 0.15325858588180236, 0.1511347450075611, 0.14142551519457372, 0.20372384648409583, 0.13293038152398604, 0.25152313643165175, 0.1300497377111066, 0.18233081055504663, 0.12358880496674007, 0.4015416147247438, 0.16281904141989448, 0.15162170113575074, 0.08799403875825867, 0.10791402550474291, 0.1280094846902836, 0.20315335612864266, 0.2352733390345689, 0.20096433649380363, 0.13673701113270176, 0.18326847153084894, 0.17371025296949572, 0.08768594117775079, 0.1555197709991086, 0.13924836992256104, 0.14644653205910038, 0.10443538111904938, 0.19750877433726866, 0.09785831710624118, 0.23630311442238672, 0.18145641312003138, 0.2512716757313859, 0.05809556910647981, 0.18708777223383227, 0.1640497157049756, 0.11012805791030969, 0.2026116860009009, 0.20670509296319178, 0.14608188952890136, 0.11296495044183348, 0.25261879538095766, 0.12707037580830435, 0.1932997953507208, 0.13794217468990436, 0.1622666460612128, 0.16561215202654564, 0.11200089773703968, 0.16708513992207666, 0.21087786663443814, 0.107936556150596, 0.17918637202632043, 0.058936086303043755, 0.1337483489224988, 0.17527546252935164, 0.11523023412953462, 0.17048977255340547, 0.1337194674077534, 0.11605878886316093, 0.12360342192433535, 0.13480924280180087, 0.11764898821110688, 0.2178505997383787, 0.20076224249937843, 0.16843745364777504, 0.16079964897324964, 0.26995694324854885, 0.20418971987260928, 0.2163961971358907, 0.19282256853916954, 0.1832387013541114, 0.1303098245613998, 0.11870006850409894, 0.1027224927900299, 0.13820652098905656, 0.24350227247322762, 0.16051399010804393, 0.1940272264783421, 0.23477303765473828, 0.1341069240363375, 0.17498906821973864, 0.2300301566720009, 0.12285699181619192, 0.1030038539019804, 0.19901265089790668, 0.25477229917962707, 0.23306026423890747, 0.24353078626576932, 0.0882940004850107, 0.14734457096745893, 0.09811871039170413, 0.11039359930662379, 0.1806230320324821, 0.15413431630980584, 0.17419213759562663, 0.13091388488969496, 0.21403218769738752, 0.18949472856137062, 0.21786533927004184, 0.1527518340416493, 0.09493941486242319, 0.09736125627833028, 0.25549718689533973, 0.11559282354409657, 0.22877044765458954, 0.18840008084812473, 0.22298758699288293, 0.07090964985470619, 0.18360777187251276, 0.10388587391184223, 0.09655193801248267, 0.28544105108707185, 0.13804332893942634, 0.19477457589199468, 0.10291199229897992, 0.18380649508007113, 0.12789956639490782, 0.13528361976627382, 0.12973308292848448, 0.15103932109571275, 0.20249271254626014, 0.14957741083156678, 0.1057801871830898, 0.1531943264267137, 0.10645569287120335, 0.15376622638394757, 0.2314980577437147, 0.15935787149975378, 0.13229224560481886, 0.1490171400890235, 0.11538969533097361, 0.1071943931521908, 0.12149197635270896, 0.11985709109613973, 0.21555123279892632, 0.12916233210313705, 0.10526234238979318, 0.08603253191517246, 0.16224069100233818, 0.17153191260032116, 0.07510680810458238, 0.0693977293708632, 0.1031415199019736, 0.13419142353438562, 0.13610066785927744, 0.07996503894607868, 0.15919660999169274, 0.34338855454998635, 0.2239967546155376, 0.19563257904543033, 0.16871756603640897, 0.14343865636375644, 0.16296970027108348, 0.10114606004208328, 0.1418157603832022, 0.15224753368285396, 0.11452724886757713, 0.06623137306662337, 0.11451635509729387, 0.08222775623923348, 0.11824734118436614, 0.17693807250790058, 0.0655328464363852, 0.0936452472101777, 0.13452116309875442, 0.11895077077731972, 0.15282300360981496, 0.22278831220201908, 0.22028812297409583, 0.22872164785381288, 0.13527569841713677], [0.026850870382341168, 0.02315111003906256, 0.060957374817301194, 0.04605054870368012, 0.0349145260969958, 0.07933327687844154, 0.05317590950477508, 0.06150856741794175, 0.003080006703854569, 0.046888553131852424, 0.022057140313629663, 0.05622832172159707, 0.1366609692453377, 0.028669949988984776, 0.06037849962951676, 0.06165004470535825, 0.012659767657638559, 0.06837910822322292, 0.02729461532116177, 0.0624267046429938, 0.0615729341253398, 0.029280776788871136, 0.05417970302064092, 0.01170913681327816, 0.038776478745163455, 0.017687085595342423, 0.03577525269300227, 0.022885084092136354, 0.02249781515509371, 0.03456361186239989, 0.0394461851476902, 0.01423930018884881, 0.026247160539271373, 0.026355437491269364, 0.01407157577153656, 0.04149052524758924, 0.06683092879792375, 0.031527898447107405, 0.03924444355371018, 0.02227632381442574, 0.03181827641392668, 0.05260287956785291, 0.04848633675024875, 0.041135654168864416, 0.023306271572026516, 0.03558443551282248, 0.02410100926945527, 0.04669399361216253, 0.01976551469265213, 0.01513088480644529, 0.03024786511706489, 0.09888774775449308, 0.04613934212454385, 0.07176625872811965, 0.04828611584079843, 0.01623190158317166, 0.03015368035243404, 0.030644254330846093, 0.04335093146730815, 0.03563852898115593, 0.01702671205895322, 0.03716805416549887, 0.030983901327295654, 0.04054449476121415, 0.07791607550555661, 0.030148675883068677, 0.11393084175764553, 0.048293945259384574, 0.057247364217595714, 0.0367728523880003, 0.02197620503964924, 0.04606827214780835, 0.008703297954202901, 0.03208429278475383, 0.04399289782609671, 0.031601167096185594, 0.02259824928196688, 0.06758902642515398, 0.06505683770463352, 0.02274336931746333, 0.022619081127847877, 0.025837734424238725, 0.016483917697182587, 0.041044328827410936, 0.01886485576359255, 0.08182090992528586, 0.07692767652652918, 0.027322631156552705, 0.043677215975138454, 0.02166096751968707, 0.06306670215581694, 0.01749012055957029, 0.10154752841880245, 0.05650408273082107, 0.02967238561400483, 0.1360258517125922, 0.07812947695774418, 0.023296873588415406, 0.0618461364008967, 0.022612188251749165, 0.054776351448268666, 0.04791546718127305, 0.021992957467333447, 0.014932721800681566, 0.03027634635086983, 0.05044862117257811, 0.006593724509941475, 0.12216309235701639, 0.01025185180497506, 0.06790469295435375, 0.09095710597091144, 0.013467814217531874, 0.035760099473859996, 0.039667795231986436, 0.09474564058285567, 0.02504616450037687, 0.021948160475961143, 0.009722978218398508, 0.03603583750044627, 0.07883032483439292, 0.026095400436691223, 0.02293694249895071, 0.016534201793312546, 0.022024776929268436, 0.058876082466374484, 0.09649888642372624, 0.02220967416501334, 0.019372662889861295, 0.018514688464722807, 0.045819059915600285, 0.03273235911863946, 0.010581460176786829, 0.015905213921571213, 0.11271478443015968, 0.02465524323915522, 0.03639697517839171, 0.0021521791847678084, 0.10596690579287468, 0.028823226945655003, 0.12020586794542691, 0.020191656846192577, 0.020447260166908947, 0.06574538220921833, 0.0177845319793109, 0.013142039158171224, 0.008926173041184104, 0.02474595379504946, 0.014178858724452797, 0.04503493062070301, 0.021370474639679157, 0.05985382133193555, 0.05597482322745266, 0.04950323036961979, 0.014393296310557954, 0.02626370420799621, 0.036534120238596396, 0.01004901853570294, 0.010893351807739707, 0.047171365980419426, 0.01773575516117196, 0.0286420165080457, 0.0740045378164899, 0.011391042742968328, 0.046433313043728, 0.023353680923220613, 0.017689364706917156, 0.039327483654262564, 0.036200412338779825, 0.02217630337503168, 0.10244126191302654, 0.017079711936774756, 0.10782249331954988, 0.014117634892764111, 0.058816454012788115, 0.08079036078866451, 0.087573119409142, 0.0395410230022765, 0.018760121968244354, 0.030628534206639857, 0.04225126587815824, 0.0906666437344205, 0.061391769653005954, 0.031976797242438605, 0.010019664919274229, 0.030062715072304975, 0.02997701473143553, 0.06345043176664941, 0.0983922650677062, 0.018139797593316725, 0.019416527169185783, 0.07289686660853124, 0.04683833223797622, 0.025209170773685462, 0.0410808329170029, 0.02731237323924659, 0.056220974938403216, 0.05820989240742019, 0.029386694190062346, 0.03016489204920588, 0.046333710122252666, 0.03452024362500637, 0.03199939109054545, 0.02446434561974339, 0.09283571443971127, 0.04611270524741662, 0.029284396554313363, 0.02076408540409419, 0.007742728555439822, 0.05347057756397033, 0.013477820283432883, 0.06668506565714075, 0.015025209680560135, 0.046006954470348936, 0.0260280134276517, 0.03035217756405473, 0.048408571165055043, 0.030314001487568024, 0.053900069436959686, 0.04104856146319259, 0.09730784462824946, 0.035771157953046986, 0.04483622273490314, 0.027287611362314033, 0.03313114235718404, 0.0492155873366902, 0.02818546640957075, 0.06891215220093727, 0.006005027596162813, 0.023585778751200246, 0.014212837596724351, 0.03541232619975363, 0.05207048676487419, 0.01834622381495372, 0.03943358300133579, 0.06536281322159114, 0.01718398607936838, 0.030334297071902022, 0.02177975902844581, 0.020838328900056022, 0.030557908560900442, 0.10638528939096198, 0.056030448871634664, 0.03874221163231038, 0.027511368408018065, 0.07017027541634537, 0.035868611997894706, 0.008618045774769158, 0.004742001418039324, 0.010977067980885265, 0.018743486368968602, 0.023079639781386625, 0.07722920873352597, 0.054125398878128304, 0.026451807521704226, 0.02797796000396052, 0.033095818042995474, 0.047644172464647604, 0.034562447408754984, 0.033400089014321566, 0.019938068336717064, 0.007946021956271462, 0.040440697508353385, 0.0570449254836046, 0.02605848840527958, 0.022691677534772504, 0.09872943568494051, 0.045467735823964885, 0.009919160886877968, 0.013991327103858274, 0.028334579678372513, 0.08330990905843436, 0.030552373575647513, 0.014087112992250872, 0.03850123867572796, 0.02444606867708987, 0.008942588390181623, 0.03245904576033354, 0.015209407861074133, 0.09729545698651383, 0.027583637312355063, 0.025154087136709885, 0.07373615423397673, 0.007682327789464786, 0.054990009539910865, 0.030424354537840814, 0.04269726311547622, 0.04740176309320716, 0.0098764457394399, 0.07533285000752057, 0.017821208438685825, 0.006598131909530851, 0.03294411731222945, 0.06013269648857175, 0.02459659920855155, 0.026851624978946585, 0.07217050800400396, 0.058016811437424154, 0.027400502078836004, 0.02566443575966743, 0.05501525979789515, 0.0774868977286162, 0.01582143646139171, 0.028801952683997732, 0.04862710540633529, 0.01513929262141427, 0.04878210797605496, 0.03946478576249173, 0.08895901842944084, 0.06295288447290659, 0.018528937700114424, 0.028718512302504915, 0.06365136513786931, 0.0226018862843874, 0.010200699156660949, 0.055171311908071084, 0.018203007507949107, 0.05089295982954003, 0.0165320816449821, 0.03373183572905199, 0.07523842200997376, 0.02695685481622575, 0.04889688709931028, 0.047550613976894855, 0.049267095258279194, 0.04698958097686691, 0.038164520050368966, 0.15212785542732285, 0.010302704721388799, 0.02071586974535979, 0.03284846357400379, 0.04549667479530458, 0.042963942152357874, 0.0822632490927654, 0.037413466601602496, 0.0445305306704775, 0.062198613454858144, 0.018835857420438723, 0.009127572768427914, 0.035017277639839924, 0.035100275605556466, 0.00999423846106736, 0.04499674496811725, 0.027742914652692217, 0.024185744339540124, 0.04415975943688424, 0.07930922171761913, 0.03668934880425373, 0.026875122810804078, 0.030577150774338556, 0.03999057488756315, 0.041968161916180004, 0.03331467021076429, 0.1253912259914702, 0.12897988060309043, 0.18878261919223494, 0.11146144926427834, 0.16383372487560396, 0.13344320078049937, 0.12709525068320576, 0.1607569931976257, 0.09320820171025493, 0.16824470592602608, 0.16445523668681422, 0.2093343986498733, 0.2314543294449968, 0.10999738629306517, 0.21138325483808595, 0.16479312742669738, 0.08777398766288835, 0.14589556162395786, 0.08930311448151067, 0.15196449483834928, 0.11015284851553941, 0.16657725427179568, 0.08109870351730816, 0.15861965385415863, 0.15841233514008984, 0.09044792563203843, 0.2184955844835889, 0.21319857678346096, 0.14609531138933476, 0.10077930310921324, 0.11292328291963186, 0.10265302393705615, 0.11335090553808598, 0.10379811087923665, 0.09197730525967576, 0.21685600310804384, 0.23786892153082356, 0.12545022242251905, 0.13984201145508598, 0.10399743163537595, 0.130426729578645, 0.1929509955187959, 0.1517696480356878, 0.1381697640904496, 0.0913429614757338, 0.17742093772657458, 0.11866884276030526, 0.1684007733579605, 0.11651032874661109, 0.19635956584205552, 0.15060669592311307, 0.19850641999754215, 0.16421705995115543, 0.13921878360692533, 0.10239638448242219, 0.1836956881227032, 0.12786982686168727, 0.21852953750039303, 0.1563477894711879, 0.17378709158830105, 0.1614050576162915, 0.15731335136919253, 0.07740150190769665, 0.16761919513585108, 0.19713477021263492, 0.17631280686586134, 0.21611398566634427, 0.18543751159262273, 0.1668163656347221, 0.09410148321260368, 0.0913596238880869, 0.2277820103711659, 0.10403181366141766, 0.0725599947655874, 0.12401325598118768, 0.261816002668873, 0.14929199711449687, 0.1312807184313574, 0.13133223018338605, 0.1320577614129551, 0.18747426359163177, 0.07372051071856292, 0.10564212281737598, 0.1170106301264417, 0.08903350515831863, 0.19928344765738135, 0.19975108304812064, 0.11760769607198816, 0.10263277623321741, 0.11614019336599497, 0.0992039428843606, 0.08285736559980339, 0.17750876204621407, 0.09274951422647124, 0.1935318127394684, 0.30925293302824425, 0.13187811379471134, 0.14243820682168007, 0.1275312159991553, 0.09885970893646441, 0.10709782776933525, 0.1364501418485757, 0.10559098644843025, 0.109237902046692, 0.1466931051184093, 0.1846917403200942, 0.03742439867628198, 0.22755975294257366, 0.08038977341305825, 0.14962294709778604, 0.18180901274806072, 0.10694501621107902, 0.20131287585583427, 0.1571432492064853, 0.16971905745806234, 0.08450656903967743, 0.12928331270813942, 0.09882124366178628, 0.11294668690571863, 0.21919143746697137, 0.11598247884502334, 0.1894170319240901, 0.10097965808405031, 0.09136086495052423, 0.2345530478464019, 0.17125725475770814, 0.20229604245433885, 0.22551612147400457, 0.07464229069169491, 0.11917185609138782, 0.200374617331451, 0.20613317768419945, 0.19152408015103112, 0.1719539197942903, 0.12068049771891487, 0.16601332162897434, 0.11579340068443168, 0.2424368280316553, 0.10912888007418764, 0.12632937726354407, 0.15062554168605036, 0.20523521538463332, 0.16830775496219436, 0.16681961384752106, 0.09414940967314667, 0.10034509979548956, 0.10609774594946254, 0.11004784084375828, 0.11583726687897598, 0.08805161792664759, 0.25110552658236795, 0.12226275273508604, 0.10896103787085704, 0.06050740924453544, 0.23282711304003195, 0.201865746189029, 0.2355051112751807, 0.07246188954600404, 0.14941820243914283, 0.1275487211082251, 0.07863847343551536, 0.11070985572352526, 0.15189971444347214, 0.10292868535484999, 0.15372364721711607, 0.08896848727618495, 0.12253417768665861, 0.07995648174396447, 0.17226214760974531, 0.18291813952307548, 0.06813159287576714, 0.2763328172506825, 0.06226638925351924, 0.21131052245055476, 0.18685941674536277, 0.1413024814739343], [0.004076552549151764, 0.00959471786289566, 0.04037364949322036, 0.065541832647737, 0.021527392429209525, 0.03602423509883304, 0.07984641023100385, 0.03529389666753911, 0.019271158155113943, 0.023850850918660724, 0.05491159661042114, 0.026326573213502288, 0.06391586082416677, 0.020050189134875135, 0.011283132555564086, 0.06808408776358252, 0.05577704230804117, 0.06261280272156, 0.06741074244341544, 0.0564339129073966, 0.022616983962155158, 0.014110091799539665, 0.05181271733055192, 0.023586144558184093, 0.035670800434966246, 0.034395700711156094, 0.06446533355741732, 0.09509404204905995, 0.0749373417948523, 0.06367259726469075, 0.021704347248399453, 0.03844836711763375, 0.018930785290356127, 0.0590076657282489, 0.003320945665285352, 0.05154523390134977, 0.02216251187717482, 0.07831464806992201, 0.028120201464081486, 0.02639626423197408, 0.012493735337029062, 0.02064908986100026, 0.039364746170899564, 0.0413278503073079, 0.06410789225370654, 0.07240260966242322, 0.04834255353818017, 0.026735047464289015, 0.05616230792516182, 0.03548048887281649, 0.03621664957233495, 0.04344923970019145, 0.030513590374480815, 0.016082248222383282, 0.06793569653264939, 0.05071417022977145, 0.06166184245939217, 0.040107483735247966, 0.04670559218333614, 0.08816876043114932, 0.021539946695068674, 0.07329195347284118, 0.04466481439228501, 0.07505097561666081, 0.026603416321919333, 0.05714788770062789, 0.06814419502212156, 0.04607498690846466, 0.028254310900886214, 0.04352909670541844, 0.018145836281379866, 0.034160320196420915, 0.045652075730744875, 0.08187131084982427, 0.03353103259277921, 0.029843550723707004, 0.03508207335647556, 0.037325895090977994, 0.04516046944885485, 0.05226713770459737, 0.011369377776469675, 0.023013447869508978, 0.03876696776358351, 0.021739504938464493, 0.0381118898099709, 0.04398599154345932, 0.027842770383182554, 0.045338592552129305, 0.10353405569349566, 0.04832693300540409, 0.06720248910207903, 0.07435331466577708, 0.04333565184365838, 0.030283379038014722, 0.02263853784590479, 0.04529885174105725, 0.11143074446027318, 0.015214509049039936, 0.03027782298534388, 0.04215514865673838, 0.017869272795055183, 0.08815549944918002, 0.015788077162728918, 0.019578481986818295, 0.02963695979316629, 0.00804513841191487, 0.011039955180979544, 0.02529143712543432, 0.006244267278816552, 0.025739767100481738, 0.03426509804182476, 0.05028438341293124, 0.036816209134074955, 0.06589650071316189, 0.02447559562091145, 0.04740283944674077, 0.09200191200380364, 0.0415533023225444, 0.026302039247727203, 0.007431692070132423, 0.04798539568700137, 0.05398064273439589, 0.024798840674902164, 0.02239751317838748, 0.03827059641480446, 0.09690977768191407, 0.01230052125925619, 0.01329818319889807, 0.04360647158577077, 0.0653086125009483, 0.03264528939560537, 0.06016850726859224, 0.030858343346945705, 0.02848722844294483, 0.04958537414730076, 0.013806956553561314, 0.051287322740761504, 0.0732666342669437, 0.03403033422786863, 0.03224538766869134, 0.05633778802509751, 0.06960854910674595, 0.04012221177559226, 0.0213712522189223, 0.054083991825820944, 0.030129849272329482, 0.03392678978402288, 0.02038196457790271, 0.04225960857565365, 0.01444350092506577, 0.05330396493175819, 0.07908734733298903, 0.041273373795012315, 0.03988377457003921, 0.024306339985360543, 0.042695481961052266, 0.0572127485347371, 0.09471513496171083, 0.006779759386253934, 0.05673134271355887, 0.006101283192213986, 0.02851542239377816, 0.024326367438921047, 0.02600703985550471, 0.045704644684109, 0.015344543855697399, 0.025507833981405825, 0.05466879653413931, 0.05837891821659381, 0.050132560108097336, 0.021056254101436467, 0.07792592739626285, 0.04297301263338135, 0.024323115395682476, 0.032296098858839085, 0.042567556769016295, 0.06482125034615879, 0.01788688132599477, 0.029350008154588363, 0.041309146270636594, 0.030439383267695387, 0.0757833480113937, 0.05856937150500956, 0.07809043711712284, 0.023355958119575537, 0.05384251708164812, 0.04375027395003746, 0.05138988659206418, 0.027647697584583398, 0.03213866779039944, 0.012916010661771702, 0.028631243396610506, 0.02421624038458592, 0.024491424912646897, 0.03612876013522187, 0.05994068421123009, 0.0350988315298192, 0.05140227423379979, 0.038621296144781575, 0.017152940366236914, 0.026585968669443846, 0.02242458481041174, 0.06758962397373493, 0.08013857318268669, 0.03020017422855862, 0.025759537914587606, 0.007336171439683606, 0.0574538249131893, 0.042887524881910895, 0.04923391215983899, 0.016850038777075468, 0.07173354677375286, 0.02405824241108231, 0.05085018914072745, 0.029424874096988674, 0.030260639633202267, 0.056258187659325144, 0.054172379220084804, 0.03569980069333988, 0.06525225907323823, 0.011353270777861678, 0.06915006080582257, 0.0337464603475265, 0.07233051312786919, 0.007158144097399688, 0.07239124857850614, 0.019721112236560836, 0.07266441254966682, 0.07282843963513452, 0.03468185370307296, 0.017004238869694453, 0.08204666837569206, 0.04522247277500649, 0.05290996208186111, 0.016858599809629303, 0.12140860300390952, 0.038132428627220855, 0.010084271986758517, 0.038390688357814666, 0.04858836434000442, 0.07317173895576308, 0.09529300274387484, 0.02604579432837425, 0.025472134284134355, 0.04237719924159108, 0.049758762827203165, 0.02916836104686222, 0.07221985172720687, 0.025167943752040307, 0.05496642169272227, 0.025481503539448305, 0.03154645884229291, 0.00758526636467826, 0.06891699387661873, 0.01989577453763735, 0.04372714575560343, 0.039446353687033545, 0.031926534213726564, 0.05035012141771374, 0.015783297731691313, 0.0653899020905937, 0.05291785278748121, 0.019683060649361823, 0.07758353972026417, 0.04946193056962183, 0.023185317780101494, 0.01791126973506424, 0.038461126312012636, 0.05664713049848234, 0.017319346154709498, 0.037658089967144114, 0.04085602824606242, 0.02122149160582452, 0.039139439712368676, 0.05510428304513616, 0.0029653786435618157, 0.01853687054057035, 0.027252076373946284, 0.04772102640521142, 0.06442478452358516, 0.05232891120437173, 0.06387569100385712, 0.017872938525772864, 0.03975764968462529, 0.05820357984292412, 0.0358676812010667, 0.014993310737003003, 0.022734193499350262, 0.030303540556961973, 0.034896143817252694, 0.04973974086404328, 0.07115236949175596, 0.058999024256463015, 0.05055345647457627, 0.05006329809886314, 0.02298556226906517, 0.035359741924631025, 0.04079154279503611, 0.02733086468651891, 0.042523123669408025, 0.036189514738056934, 0.03564944190363731, 0.017780096330229315, 0.08333010313611838, 0.07463279120143383, 0.034091835766429865, 0.0855916406538698, 0.06697479244922439, 0.030866919701258023, 0.015603967082326212, 0.025084819381816253, 0.05130644812579117, 0.03156819084148494, 0.02568869776422939, 0.025156216861139384, 0.07750059538070234, 0.03503813821401808, 0.023222222150633895, 0.01500082510193029, 0.008879756731461854, 0.05914979802084066, 0.11860835245780407, 0.030568516963431915, 0.014538445074351565, 0.03594448534591544, 0.026277675736515273, 0.02656454693586115, 0.045479705947781765, 0.04570310867782082, 0.025498882244010607, 0.05824183444342306, 0.04014589538377139, 0.05608734622177097, 0.01573251376319076, 0.043113049675500205, 0.020783189721705935, 0.05309470035436173, 0.041459732343472784, 0.04667715883002647, 0.04108341846374735, 0.04764458615212672, 0.028470803517848257, 0.026209930581371152, 0.016653002878170342, 0.1081376848742366, 0.03776734559646538, 0.0574091351741264, 0.03699991318787779, 0.04486059582221412, 0.046975856511703426, 0.043172494267984744, 0.008440853468322707, 0.17969880823887166, 0.05923825053257808, 0.18798375802655376, 0.18758739945628952, 0.1204271141379591, 0.15847071103992003, 0.19613168532809905, 0.14261646015990165, 0.10145118520144494, 0.13171168885404064, 0.20484687009405708, 0.12541902732224236, 0.16573936858725163, 0.13730207758565105, 0.1880746313761319, 0.14819016349652123, 0.1549267270151646, 0.19147285951241372, 0.1556495616152402, 0.14085139358235946, 0.09761359797970903, 0.20310143068913492, 0.19816957113723602, 0.06658239455352868, 0.28326358405813096, 0.09269331401634602, 0.194329708634365, 0.16374838268083913, 0.16235443973733535, 0.19297122023999694, 0.12594313105388036, 0.2191206815862848, 0.1025255698890936, 0.25346438791001996, 0.08189965610302265, 0.1622661251214243, 0.14332526002920445, 0.191534299763941, 0.12753480895152017, 0.10620152788056482, 0.2183577193007354, 0.1413624048713715, 0.11245158726289389, 0.12495164474051808, 0.1333465204844552, 0.1100570415597289, 0.1123482496627877, 0.20043713010607228, 0.1176999100754338, 0.10211313879417797, 0.13636706727406672, 0.17044477254873322, 0.14261187895411445, 0.09062367386274761, 0.24009642942297846, 0.1635785869533016, 0.2254467905168572, 0.22213525289008695, 0.16346367376465953, 0.23509272614554053, 0.10118487771720656, 0.12307564863154005, 0.17191449690970684, 0.18720116856838429, 0.2607915286094912, 0.2304374243343069, 0.3830725831850883, 0.10726991409976637, 0.08503657930921163, 0.12628967858730786, 0.0897394934849393, 0.18807340563545305, 0.16892235666032762, 0.21486638083813653, 0.09261575527489187, 0.16250644690327107, 0.07721692068322052, 0.13472852777809868, 0.1333240434647568, 0.19497555139805042, 0.11600973625336924, 0.0930584851472128, 0.10711010049788222, 0.09366678960260846, 0.16117248864423844, 0.10090590679957982, 0.10789112713668617, 0.18438856868493944, 0.15147297282613095, 0.14010010647677607, 0.195183620878285, 0.11480307116383508, 0.14476214986174338, 0.07472941787132333, 0.08349655105942681, 0.14237874307699744, 0.16959625356380018, 0.12137632005878034, 0.15433950529944512, 0.14194751218441995, 0.07305745395921892, 0.1568323554050538, 0.09064520859429914, 0.14831639946468417, 0.14917964265952188, 0.2107273456790755, 0.09899547503840539, 0.07116540830822722, 0.09899902968637406, 0.15383214058895267, 0.12393847813889866, 0.2132575349101136, 0.1697950074148755, 0.22796453848000497, 0.3220899619402424, 0.15804087442736472, 0.17991942623930593, 0.14182250195693585, 0.1509891116931554, 0.0855504940714567, 0.14211257348858541, 0.11234709287002204, 0.11627322453404627, 0.16834023709018386, 0.12611948449404972, 0.1310011423042705, 0.10327489580959083, 0.13601635222233113, 0.12688611634075642, 0.2735323062346828, 0.14271709346963515, 0.21743498171769807, 0.08728193705000224, 0.21144466444609628, 0.11074048391873799, 0.17016931797467894, 0.14405577083028134, 0.13316793006754693, 0.10702756218492024, 0.12697993912884306, 0.15813168648990894, 0.16085025674152761, 0.21882589095302168, 0.054880807536744305, 0.11907654709272808, 0.26111150821370466, 0.13365393624671046, 0.10195721691894917, 0.15674636969643255, 0.10427028917136694, 0.16704026249147233, 0.18465159731286188, 0.12075493848251721, 0.13014962025467428, 0.1390750808340888, 0.13406716407306735, 0.12211741819497078, 0.1120763037714266, 0.07916879780109852, 0.1397135844754596, 0.0855802948917112, 0.15311166553968383, 0.11001031785722702, 0.14451189958039792, 0.13811871199117554, 0.06919996377321021, 0.15755557304909154, 0.1676951757361812, 0.11243329308326207, 0.16808745871868827, 0.1741445788572873, 0.18219600972389022, 0.12112361829607718, 0.10152689767100158, 0.16655768838620957, 0.10873498830703959], [0.09800408065559403, 0.01787663490000752, 0.035467775643713055, 0.023492028741466425, 0.07786486252781846, 0.07930576666108063, 0.018911081508943633, 0.0680344912313646, 0.04258085988582142, 0.058957724456465056, 0.042399726057004546, 0.05936462439656739, 0.023074183320145936, 0.009557626758431716, 0.01687880729385201, 0.053284862529366255, 0.057794898748397834, 0.09648341910853502, 0.08367226098573978, 0.027562330491961013, 0.09809049537345287, 0.024690140459326007, 0.018802298938915617, 0.04727517472459905, 0.04771498197148885, 0.08912770332948816, 0.07447674675213714, 0.017534251054448467, 0.03433729416780895, 0.019730755368307717, 0.005487543342995548, 0.08844915627231521, 0.060598680959834214, 0.015733270275015986, 0.050827987912681796, 0.0160802832068575, 0.058758671831099264, 0.010230589034636656, 0.015753469140749547, 0.01871859617230873, 0.04687515808449638, 0.05937822628766299, 0.02148191936524405, 0.04132842870369073, 0.06395770071615135, 0.03860447285396438, 0.04810507394253247, 0.013909789493247388, 0.026232689138381716, 0.05428148929270045, 0.05682549491945294, 0.07776357804334934, 0.025929065511351632, 0.007997572012696295, 0.0337024869006728, 0.0497516994965413, 0.027248054412343813, 0.011555453830008066, 0.0494917965073499, 0.005683401860522047, 0.07630759729973732, 0.08753529764832028, 0.07653454318642616, 0.052009414235550555, 0.057433220978465774, 0.0548179155486005, 0.03735748089609608, 0.026267057757884748, 0.03597509821936969, 0.02494530902514535, 0.02523445550562634, 0.03257418494491327, 0.03492235168514233, 0.04501139639966911, 0.04161530564869604, 0.03519826208151156, 0.012937998342808458, 0.0882879177468919, 0.03620573281941395, 0.07035693273909631, 0.12993336895540838, 0.02171040891910032, 0.03405186895942015, 0.014369334995506272, 0.05972946610962672, 0.00605165841050386, 0.030755599464980826, 0.03709713740634822, 0.012120173628171606, 0.022008260073620948, 0.042306171399691415, 0.06821508113775523, 0.03214922065155641, 0.024633957486179088, 0.05555869192786275, 0.06527318859532957, 0.1299138796786147, 0.0038077471394752788, 0.012660983822218353, 0.07092933065348095, 0.024976573073335236, 0.03986695894010125, 0.023380584015901533, 0.016018951165249512, 0.05709989995305097, 0.035934870942465724, 0.03297109892892261, 0.06421311443010647, 0.04277055091675251, 0.09998795726606924, 0.0474949806718336, 0.008748477031927436, 0.050152011080494815, 0.012311592187371947, 0.04295401748329882, 0.040363544793499094, 0.04232051256563395, 0.02651613975514568, 0.08151547066987523, 0.03412465880354566, 0.0433969886733159, 0.029809975005205602, 0.049932649464256344, 0.022977359382615938, 0.013129233998516876, 0.022324690775525187, 0.1277370714852887, 0.0103745982426429, 0.05216440148351174, 0.04111731785439676, 0.03373974558687018, 0.045461538172657454, 0.011621084582481173, 0.035023685965326526, 0.022248507161895116, 0.03484059095142349, 0.0265881979853035, 0.015015512922658555, 0.004248858651056165, 0.04117909901505036, 0.0187067064877239, 0.02044238018683128, 0.008871557675452243, 0.11917914924842697, 0.043370508844213146, 0.0632579789887513, 0.06252980092540383, 0.017216395429005067, 0.03185597751590033, 0.06874774207150744, 0.09088147777102648, 0.018550459025127274, 0.017692622495815158, 0.02120823828473447, 0.04504153812904993, 0.005038744617899459, 0.014001054505276826, 0.06172584144458656, 0.06944082181660399, 0.025511304359702815, 0.06216934889615063, 0.028320137005780014, 0.06707979246012627, 0.0458032938261186, 0.08044654818912668, 0.048444144457819006, 0.01260052990889357, 0.07376103676975736, 0.065500846943788, 0.02290951846648128, 0.036286761939165094, 0.0411302111141624, 0.012954318888425347, 0.0595294060786405, 0.017158582603799242, 0.08086264118432038, 0.07785536303755738, 0.013002232900039564, 0.008782375464966942, 0.018077332699190707, 0.07000719061902455, 0.0504104623330697, 0.0731509626512566, 0.049359021978753234, 0.007417176140382165, 0.03479592419499832, 0.021450017548857198, 0.03669214119473773, 0.021214430190382466, 0.04933289838053527, 0.011795934575099138, 0.09550681788354151, 0.050352603542588414, 0.06006132773754578, 0.05977414818781038, 0.04847333623817371, 0.017295597429056803, 0.043996847009346376, 0.018273968317155397, 0.027414983055824717, 0.06710442984777112, 0.039908538362191576, 0.03927188865359753, 0.06409137156761943, 0.034162924895363475, 0.03841560153711227, 0.0329933614440022, 0.08537255482928408, 0.06541704458575096, 0.02128830213370102, 0.08232308822053094, 0.04235913871877617, 0.0514130492604548, 0.015211825826085143, 0.015774817138369528, 0.03427533297649315, 0.03715095891346855, 0.0185608261099626, 0.06831293354832357, 0.03406863862408265, 0.041852241321917505, 0.045548508304261395, 0.021595913248376983, 0.0683553365149325, 0.0425512888919442, 0.029509272088386843, 0.029423154229598663, 0.051705664204012965, 0.06610326784392519, 0.055936932518717744, 0.06560293582057761, 0.03367107346533768, 0.00984445965338138, 0.07751672153150843, 0.015310498908342374, 0.013276257762505163, 0.12299884065625169, 0.04287685327712567, 0.026478566972899343, 0.015377544050645685, 0.03814186300000837, 0.01465785998715869, 0.06547840056760658, 0.042696098661831314, 0.04674561261650055, 0.008692934699807196, 0.037233003099719365, 0.06775704482870717, 0.04615058446483267, 0.02699318079037532, 0.04120136153012995, 0.03971945637116029, 0.01667296521425728, 0.1488324362904795, 0.021080991080511483, 0.04179601046827532, 0.0520339405404464, 0.06811821698060921, 0.06084275274207035, 0.05072261251869702, 0.029102284048173218, 0.03228896274982441, 0.05622857453061208, 0.023379680032150883, 0.016422555969667532, 0.03746425823098229, 0.030368734639318242, 0.045685511638200095, 0.07338108780283122, 0.06848263734531018, 0.030756195098341956, 0.05648335239159004, 0.12831458686700753, 0.024138357970983754, 0.020154179824936776, 0.0667490186770597, 0.05133139960948498, 0.05438381565674659, 0.05546857317489001, 0.0583002409867702, 0.057385279196164304, 0.03411735415518765, 0.017996623421147946, 0.05236619287320683, 0.03036250634449384, 0.09041453185941904, 0.03700359807079358, 0.025906398884891987, 0.01577079804959677, 0.021088447031234542, 0.03129379921442559, 0.0074280890628635405, 0.053580618433413975, 0.04757204145613698, 0.009559108180955294, 0.08971129378844654, 0.01790097351336191, 0.05581763730714879, 0.04624270653772739, 0.010782331303362886, 0.032217061567691066, 0.01574624301640377, 0.018957065936598568, 0.02720464404011446, 0.019976192702268882, 0.0649741844784829, 0.0483552476150855, 0.026243720804491354, 0.04413635928123709, 0.02756388948088692, 0.02577091623548298, 0.06436856133082221, 0.025172808410359487, 0.04355719298004143, 0.03750804015585492, 0.05745259534207083, 0.034792020977024114, 0.0549774878327885, 0.02301626324263071, 0.017357573942131093, 0.019456804241804827, 0.07125062026804493, 0.055064768230001775, 0.08506827236663911, 0.029720007554597916, 0.02796222647321561, 0.011899276963254858, 0.03448609525578157, 0.035522999091734814, 0.05655886950872599, 0.019407473925140598, 0.07677888692987543, 0.035663311925506404, 0.07095613606995152, 0.022805161969435793, 0.009615473099984229, 0.02517098129066008, 0.025119055851152348, 0.06543313243216084, 0.07806468124110853, 0.03050212969913358, 0.06367238276007195, 0.025006243658642617, 0.06175364660579832, 0.020990606111985062, 0.02662015725828467, 0.048761814306940765, 0.05700805367180898, 0.014558394961509735, 0.0390353896504929, 0.03712684629605182, 0.0713204491823431, 0.3010265889667696, 0.1057466631755233, 0.08190263618504809, 0.1720056613726962, 0.23574057605958756, 0.15688775888373777, 0.3014910833970193, 0.15366219164383027, 0.1625072742782293, 0.09314842386952332, 0.11903734637364266, 0.14463504055334678, 0.0935328008246518, 0.12930588165838874, 0.09274708572775127, 0.12062713203410949, 0.15131711989881533, 0.1724371067698925, 0.13162043246050037, 0.15319475543595132, 0.1453802142772944, 0.11344760115588866, 0.12514771728385843, 0.1728584091629713, 0.14649337067479087, 0.210935507089861, 0.18677108680769322, 0.25211654813779943, 0.16448741237963402, 0.1184978059703304, 0.1878441308414744, 0.14795859043876972, 0.1453146218292175, 0.07743202285059998, 0.14994548543566658, 0.13004688786402827, 0.16272455213531373, 0.11655782619791648, 0.09724144778785207, 0.17384186687488712, 0.17563339412933396, 0.22299308750417926, 0.15570672709615002, 0.24486909590421185, 0.1466343155311, 0.20190618030967253, 0.13699375783964512, 0.3022897147363232, 0.1401953618492811, 0.17190374103524994, 0.14246282888756645, 0.14984472955186523, 0.13305664813566592, 0.1871330173866403, 0.13737896216973183, 0.1377566435164021, 0.12372694594124634, 0.17619378744594513, 0.0836727129776151, 0.12071409067439458, 0.19109024455951107, 0.18677920733969058, 0.12338997450687232, 0.16647179460813924, 0.16999584502510487, 0.13215339982942229, 0.14481767591449524, 0.176148128605658, 0.16394203438633875, 0.07731067452339396, 0.1599925140579862, 0.16712116137627633, 0.1961602604076747, 0.19174284421868865, 0.17549980371709795, 0.11012742205733254, 0.07955559559406773, 0.22858283272193325, 0.13824891629478625, 0.193871327585751, 0.263551498252538, 0.12857014613766826, 0.1376880939689375, 0.13953274176005395, 0.12506199204513144, 0.16039800439630786, 0.12933899197847615, 0.0812678021048346, 0.13901186325857717, 0.17870618811538144, 0.15948364781516214, 0.09612342673203639, 0.21149165627937164, 0.19776840153480732, 0.07080938426717635, 0.1695290676528408, 0.36152850536088793, 0.09980532190492077, 0.07384355976096085, 0.19545590384833275, 0.22602678036257146, 0.12930968145449317, 0.14271787487931792, 0.10575943386122104, 0.17914426783400197, 0.13909355887482244, 0.1207210237701093, 0.22444430318090225, 0.18070198505395846, 0.20533577208557438, 0.1206776019065611, 0.10133562083806723, 0.15615911733719612, 0.07369175177788542, 0.19894601657025276, 0.07363258680749325, 0.1562942552470392, 0.2720607432626909, 0.13995435058830247, 0.10537078979635432, 0.10430621103413644, 0.17983020763964425, 0.11521639858162212, 0.07573566669898649, 0.08653670203902068, 0.1916219555442372, 0.23202685759432856, 0.11305092848957547, 0.144541087530313, 0.13476378314437407, 0.14803875387916643, 0.13674130122507774, 0.07862489835749711, 0.13086949775536216, 0.1331140894082285, 0.1174128722519644, 0.15220173694674047, 0.11809988458070064, 0.10240222207240521, 0.1936041314395205, 0.11690229763306918, 0.12829641526144359, 0.19165574002169794, 0.26560620735249213, 0.06894743054985039, 0.21697672324315195, 0.18860117892824835, 0.20879752423253753, 0.23229740920566747, 0.1249164813047936, 0.1680775455409481, 0.13972397262771286, 0.08765641614914903, 0.17252629472603723, 0.1088094597141589, 0.20338024072829755, 0.1455507454492392, 0.111871199051459, 0.0794334581962997, 0.07909067981545964, 0.1683586232003666, 0.0991894638225917, 0.1231464964427775, 0.1928030026535834, 0.17082890435572595, 0.22706369568984355, 0.11563917186351554, 0.2002763435725243, 0.13944058138276302, 0.12412352667700861, 0.15721904594571362, 0.1342502284434534, 0.2145723409710392, 0.17214297497224423, 0.1615740566123878, 0.1729579699496108], [0.024126399338485736, 0.018956125563671513, 0.05747004682498594, 0.02882783879495917, 0.009930825533135044, 0.010621022872416484, 0.047272290403564135, 0.03350436507213501, 0.01275103841532743, 0.055229228155146685, 0.01675581187760878, 0.029216442640209873, 0.04432815705395995, 0.032626213806290785, 0.04956027327646172, 0.02465911581361246, 0.04504355677073041, 0.026535793740843094, 0.08601990678618032, 0.07869099642360404, 0.052727794034346465, 0.06977255320957593, 0.04169125560550921, 0.0037961557503759626, 0.012715147196074889, 0.015292902826331558, 0.0585727269701179, 0.048297522889990965, 0.018843625551990924, 0.05013030397916033, 0.051116435337931886, 0.09952452769803424, 0.04609613859605405, 0.027463131681865746, 0.03048538876276824, 0.04535180756882314, 0.05620339322054098, 0.027072871171478784, 0.04808559615705763, 0.05020086450742618, 0.017669205103189718, 0.014603649690416793, 0.05855736307679646, 0.04131573462678541, 0.03733872706370969, 0.050731824725986495, 0.05794305632251406, 0.1126178743077382, 0.02571193129575301, 0.051483751514986645, 0.03992810807821732, 0.032264608814711535, 0.0418116310010514, 0.04528504683666172, 0.006660946810077275, 0.04560727490893295, 0.02860254957340658, 0.04342533009607465, 0.03719493619076187, 0.0378239939680263, 0.0022864899590551374, 0.045439689345056974, 0.052427897425068, 0.014476853520459226, 0.024971116612094547, 0.024723151187983253, 0.024736122971761133, 0.08512802722473299, 0.023693563491706888, 0.071545219379327, 0.02670659495878124, 0.035211300897982814, 0.0644783953565263, 0.09324989987597351, 0.013554502811823643, 0.03121766922695022, 0.04954135473517161, 0.03129805866328459, 0.02333769266824088, 0.017636669349045526, 0.014498441878165451, 0.02847524108214965, 0.005740530952255452, 0.07464084278551802, 0.019788060660263704, 0.03150476450701395, 0.04040957135598987, 0.044882371871461796, 0.04864517742046907, 0.022833308039773858, 0.016379992124594508, 0.10696740896110574, 0.04048604608303116, 0.05114408728155879, 0.06496771869640197, 0.04120814140825983, 0.009837390577060082, 0.05371792820252238, 0.028990787611673438, 0.02846893617853282, 0.02725460446409641, 0.032208906561737104, 0.019059049476298596, 0.025826808095218676, 0.03147947977507307, 0.03183590218184456, 0.09039614574923631, 0.013102276322071352, 0.025382251103198337, 0.025548360032600262, 0.01696347341602368, 0.04985122963966382, 0.07423840913801424, 0.015534632294739207, 0.012541834167355012, 0.039696757185963855, 0.05627440574068216, 0.024884533354892366, 0.03247458202343795, 0.012124520219531993, 0.0056954859399176655, 0.10670809585961605, 0.06837337022467006, 0.02898205229411683, 0.048713489480677157, 0.055267574686196544, 0.06347579693782233, 0.04315896898568158, 0.07564333012147297, 0.07117757378446479, 0.04923693437670027, 0.059098765073764714, 0.04919048646585115, 0.01866402389902261, 0.009422829757714945, 0.06802483852351866, 0.023218588978652994, 0.0711771984013819, 0.007226077422890212, 0.05117325607927577, 0.07081627139761563, 0.039882131311441624, 0.06202752303872859, 0.0647640159173358, 0.03437558707270411, 0.026428179454899607, 0.0581461807051974, 0.0454197021111125, 0.04057696922832439, 0.012646938557736577, 0.047101962244919235, 0.022691656467354587, 0.0218473375594664, 0.021298625168480703, 0.011620952432314235, 0.05598519988838704, 0.03926767900045361, 0.059544589941299735, 0.05719867166912845, 0.013836876117444087, 0.08623844102746056, 0.04442605926024337, 0.029841959176044312, 0.026875948270542488, 0.04481675261030755, 0.0548071405219455, 0.09118494818047171, 0.017926149077773575, 0.016355228332442143, 0.03326017837671023, 0.07661855238820277, 0.031009856386170275, 0.054000350346248, 0.07374612869875086, 0.050015229912054156, 0.020218847221845103, 0.044548591193292415, 0.019270401643288713, 0.06273853690213253, 0.02336559933610261, 0.030291917087930827, 0.03296633769247321, 0.0352540907389935, 0.04690714608577471, 0.05322059541339836, 0.1110499834401473, 0.07560763042420149, 0.03261672580734857, 0.03387918508040809, 0.04646786360911304, 0.08143942112163191, 0.04613143992760489, 0.0285543913712665, 0.032675300890039054, 0.1540579067002381, 0.042694409437958276, 0.059774213305283944, 0.0675979053841964, 0.04056221054446313, 0.10130317701447396, 0.043185705454238964, 0.006919669066255372, 0.04414454876114765, 0.038411675336500334, 0.04727353912688071, 0.025558144890613137, 0.023830645349657825, 0.023068554489122286, 0.05718031237202306, 0.014632718896703615, 0.04009095538828162, 0.006496374844573439, 0.04699083736106273, 0.0641595916972766, 0.051367811768526034, 0.023491050064143155, 0.03753167779875859, 0.0062693877806586605, 0.05367344530719904, 0.04883179260838417, 0.020446909681683587, 0.02505612364339252, 0.05163970786417204, 0.08930150569686968, 0.05851054361330406, 0.05968089613522734, 0.0676306939473556, 0.020883675559513995, 0.03274153302153272, 0.037556081529586546, 0.01998179088977556, 0.03201935725707201, 0.03425064579313321, 0.058426630172518, 0.09047640878106318, 0.03165910441067911, 0.04245326794203251, 0.030969165626072118, 0.01685960338481011, 0.027563420252033302, 0.031017773904867714, 0.02598365693683586, 0.057594662517189026, 0.0697948846725687, 0.016781385807741075, 0.019928781435854977, 0.0600701722226316, 0.03715826739226619, 0.03548591277532039, 0.02896298819612111, 0.04451371121009992, 0.008483618411475853, 0.021560795777927966, 0.04364591745299198, 0.0663635845205957, 0.01802564283171969, 0.05542183032019004, 0.03830588242459682, 0.022781464954717986, 0.05517657876255051, 0.06822971341710898, 0.053327870705435355, 0.021675479140192754, 0.012915454290416694, 0.02807680832883043, 0.010347237412427223, 0.01007351802752143, 0.051988231904444196, 0.025762912531894062, 0.05574606937326251, 0.09601838841673829, 0.01738220558411652, 0.019038738570206108, 0.05945571608120396, 0.06961495360179294, 0.07607844507982654, 0.057603028197322166, 0.023722720798105005, 0.00693039094556063, 0.023629995430969906, 0.08468664566715879, 0.01631012682111994, 0.07888444128536409, 0.09233833185487217, 0.04973302227294734, 0.05892797726236525, 0.036925008941081264, 0.011856585756064424, 0.03158587023555752, 0.049271481111645705, 0.04210763588367451, 0.03610680788575161, 0.04621618840422842, 0.0632948316483488, 0.06855403673985312, 0.021304451267144853, 0.0378750920325758, 0.0253549687969949, 0.09313760670803248, 0.025734977135735176, 0.06819145498617042, 0.040213020007696845, 0.04721506746606, 0.02194279211483175, 0.0709567029750155, 0.04489374827713736, 0.0256493074383827, 0.04139362661648662, 0.026986178746747396, 0.03789430934815638, 0.04848189344028792, 0.049363204818819804, 0.06198529244190263, 0.023394417648594228, 0.0914299967248113, 0.07586655282084981, 0.051495725469243143, 0.01832363188206669, 0.021113526834655675, 0.029624072279060082, 0.018228456948793704, 0.017331986605460127, 0.022030896056563627, 0.031611095595684265, 0.01857820098408528, 0.05166329188092102, 0.04683355567976833, 0.03572390181943774, 0.03903149026295832, 0.055153596124822096, 0.048555096971892545, 0.04964173523589008, 0.049871312634598826, 0.044110212700381395, 0.024369871656921123, 0.03691247574264004, 0.015124174833838499, 0.07937293725028154, 0.02759794017390138, 0.03656142361221775, 0.04031413595282263, 0.036612556150723854, 0.04094168453687622, 0.01581977596581583, 0.07206861064919541, 0.0165435710486265, 0.026438807009629188, 0.016734156487209183, 0.032380770726670186, 0.03610085921301957, 0.05826393224959893, 0.046379755836941546, 0.15590258513487157, 0.06280942301776621, 0.1706007020848413, 0.08124873417639926, 0.10928773606616644, 0.07218269646287927, 0.23570567309375734, 0.19738304398713574, 0.26350596198631876, 0.20389440829955763, 0.1814647021913721, 0.10255943863622605, 0.2525985093727227, 0.12627589666555006, 0.12841205623361374, 0.1374306271393453, 0.12280764043210976, 0.1550425748310743, 0.5311011174513448, 0.13801199594332328, 0.12088895790399083, 0.22008497177833514, 0.1906448257185759, 0.16601266279335947, 0.12024424895043336, 0.09140032613950391, 0.14471053085740537, 0.1804054017749525, 0.12520896601340464, 0.1585129071627894, 0.13431871670388407, 0.16158157959580421, 0.15359505169814633, 0.13546361978496277, 0.10083888176708453, 0.15727550662573309, 0.1789809225667869, 0.14864174168436758, 0.20889932199591593, 0.15181948971604148, 0.093293298756884, 0.12150457849906338, 0.13693188857888022, 0.11569854367764727, 0.1785798295731506, 0.18007947732844662, 0.12073091396521177, 0.22075073282805183, 0.11067836184895809, 0.11900029836162446, 0.13699691412189316, 0.0850383106679205, 0.17674169352939054, 0.19710492342710498, 0.18116955915766378, 0.16875706552978487, 0.1653888220748594, 0.20455407128939707, 0.167007596502381, 0.06415918567067673, 0.11977463705284942, 0.14174926395137466, 0.13948066310296137, 0.13669067813504127, 0.11882358486013067, 0.13172639774218683, 0.1115215028966627, 0.1457900100297505, 0.174660753578909, 0.09352822727974384, 0.15649435741286125, 0.16770421557368773, 0.13187180123021527, 0.16120729967951775, 0.10777190853390964, 0.17409066158917644, 0.13212706172658553, 0.11938867429571769, 0.20542938802992144, 0.09326732071537165, 0.25937671743093, 0.12273664706416669, 0.10101061569707048, 0.16034434759809127, 0.12708367509466986, 0.20221472988205574, 0.11561636542600971, 0.1468348160626427, 0.15438450530411738, 0.10103183633257305, 0.10002058495076434, 0.1996132485087841, 0.17664018687942337, 0.1134900424268938, 0.21579714702262034, 0.26000444987608545, 0.08466386221229069, 0.12874562623760394, 0.1368620826472198, 0.15006828932992874, 0.17672218893083835, 0.12571403246012428, 0.11179317299637104, 0.10688504684836635, 0.2204028369798776, 0.13936686840268875, 0.22370914988700422, 0.16784522171703078, 0.06857279823311875, 0.08119834857361932, 0.09433046689317112, 0.17058564079624994, 0.19159327321235212, 0.18749422784293854, 0.15407641538448874, 0.09521946596402316, 0.16057801973675528, 0.2814260762064688, 0.15340276362915195, 0.1082728993928721, 0.18352656655253904, 0.14487736948555516, 0.17278777585635263, 0.12131507899011336, 0.1709738481909998, 0.13686382932768715, 0.25475112450939996, 0.17633036560108586, 0.15512701304208848, 0.14394286479200089, 0.1573052921242291, 0.15021318719992716, 0.23147997806870171, 0.14161096975928353, 0.1761877506731018, 0.1053376947980254, 0.13745834420044578, 0.11711499428436642, 0.13965720040423257, 0.15596094571294325, 0.15186873384781424, 0.13063076943639787, 0.2361225628203923, 0.26348613563083834, 0.19190979009914785, 0.07509840412005302, 0.145843789402035, 0.15422713552271167, 0.07796984721696185, 0.1776756772831563, 0.10025322287073059, 0.11605791552292725, 0.18838537195997854, 0.18239444181803735, 0.11302175586141887, 0.1629904612538315, 0.1901587276088615, 0.17235565630178298, 0.12770391519992583, 0.13069211775737424, 0.18881301756107038, 0.1435497544345356, 0.10494308290822853, 0.11962685103137648, 0.09208019852878586, 0.16562915917846466, 0.15598766685974214, 0.08972532085834012, 0.1455600304348815, 0.14412366154213108, 0.24559090394646893, 0.13246027933013055, 0.16372371464967728, 0.15783191628513799, 0.14911762018117214, 0.1715269023852964], [0.05690468159774619, 0.040693904889086564, 0.08038542969452758, 0.06717274190797921, 0.006506106555236564, 0.03428077220075554, 0.016870403309322653, 0.025282305357376897, 0.00867046534098805, 0.06782875831929908, 0.040534018508849606, 0.057291230412140015, 0.020209951025824395, 0.019579347666172732, 0.06696183024154556, 0.05337022004588958, 0.047818350215112014, 0.07010883516481808, 0.03783489539918881, 0.025498108495207086, 0.06536176368113487, 0.021726977485682697, 0.05640804211819365, 0.012954676076920043, 0.06189409350495666, 0.02450241252870089, 0.029750821526132287, 0.04808623584047441, 0.045348727895367535, 0.036910809501404726, 0.029216170678996754, 0.020528731702436364, 0.048058970771249265, 0.020458289917798776, 0.014294654829427602, 0.08216050904124014, 0.0738296629260144, 0.15973824947591753, 0.021685489994143287, 0.025699269777584462, 0.10804341009427464, 0.017448592848414858, 0.04382597109783561, 0.023955640255383426, 0.02323532033891928, 0.06630310187897374, 0.04676774489663301, 0.043834248677857464, 0.05106466694644863, 0.05630842387495984, 0.021349156327966242, 0.012001023015698359, 0.014234528418690448, 0.025811070734034144, 0.036130575763602416, 0.04817016843345858, 0.026308658247392987, 0.015607464273700552, 0.013252361564927045, 0.03851246952469792, 0.013471538362453782, 0.04145460721525935, 0.04474227737274863, 0.041301018077759974, 0.03360237453072783, 0.05028289337191851, 0.04446117290025277, 0.02634534428286697, 0.010686067567627517, 0.03904636769044784, 0.03581243477040722, 0.031195025583128297, 0.058893043653018055, 0.05152017133490694, 0.03930600254886574, 0.041298172061121276, 0.05891173236793088, 0.01061097658689945, 0.027495108191825213, 0.06302000909683204, 0.05522062881819664, 0.039797961231200926, 0.053352224640548236, 0.025346300512131666, 0.042389123400132504, 0.054038417255205494, 0.06183235830957852, 0.12306359806849111, 0.01514098950616655, 0.05247139972784827, 0.06589678416569388, 0.06286452389172008, 0.006250610486829594, 0.06167036901798941, 0.038197783588041226, 0.038110936030505166, 0.11773411590125292, 0.0593288863948997, 0.048927653190349384, 0.07272504074799438, 0.08089266417007293, 0.031715904084605076, 0.055995373536021485, 0.035588886483662555, 0.018110655608677098, 0.032799533538279996, 0.0363101008077783, 0.05389793205165094, 0.03377123946143735, 0.0439489588531996, 0.030524503296962192, 0.03458964736050656, 0.05433479369047189, 0.0488926123286928, 0.032164829693013625, 0.041743552597660216, 0.06587853595133751, 0.10186963774744542, 0.03672529748010059, 0.02865162899627561, 0.025218744957519156, 0.0339571115440659, 0.07186269387602806, 0.03337401138137906, 0.029206085131473603, 0.021425562107094356, 0.0158828403237426, 0.09431342143685588, 0.041999291898983146, 0.04617377011586101, 0.006111766147847858, 0.03577298890318602, 0.052242653534537366, 0.04947379344112931, 0.021160294587213187, 0.019791996436974695, 0.05477954220447329, 0.041868811803719694, 0.06950403939211561, 0.013491323540708231, 0.08942666148105938, 0.0737914351385928, 0.031340850419515086, 0.029841913210768855, 0.022731441328482285, 0.020520109382848588, 0.0064765092270869405, 0.05969955420662319, 0.012779780119026621, 0.0013935926976808978, 0.03428265294660965, 0.029633866713172006, 0.06660175359537525, 0.031617785458483046, 0.037398474260924325, 0.07053648842678917, 0.04025203303524083, 0.053035634975399704, 0.018344350729978854, 0.00243235309983814, 0.05811664418527677, 0.05301821796644119, 0.024302957707174846, 0.03197002502518796, 0.018543772992768118, 0.028240167002584186, 0.05102134467433057, 0.045419614011001204, 0.02513728299809079, 0.02356489710960417, 0.018025868827657356, 0.12105828631789455, 0.051566592432678714, 0.056107712669237975, 0.02236768937549524, 0.011236925004801203, 0.02520242153907255, 0.10084970658945461, 0.07211996152275993, 0.04150050354280299, 0.00348348917360718, 0.010219697179573198, 0.026449147281387163, 0.05296282597907609, 0.04399133500673118, 0.05431237795780744, 0.01476897529491614, 0.058773813558922666, 0.010161081877266689, 0.08959090307114587, 0.008415442331874324, 0.04030631802555534, 0.029053543619210684, 0.07337073029409494, 0.06090878952114333, 0.049320380503852526, 0.0056378751704018685, 0.03089651559299279, 0.09165199368350929, 0.04242152125845033, 0.04647852372257941, 0.029652028742636886, 0.03283524855730995, 0.01185493675180741, 0.03415912126881942, 0.010534408971697334, 0.02795769506314349, 0.04347921672066854, 0.04485917089867496, 0.021755487447784796, 0.022334358805129607, 0.008229938929059334, 0.010263127661610564, 0.06406045608943509, 0.022154575206279274, 0.029357923758065993, 0.073673564850563, 0.010662266173430029, 0.009110091599605737, 0.01860237488853595, 0.022164210677146915, 0.03304883387059935, 0.04686670047381232, 0.008364664109033203, 0.03836296746627458, 0.052448129807148254, 0.020650784830532728, 0.017879599660274484, 0.03692567926801501, 0.01799652382971779, 0.017711431869576057, 0.02998830112177999, 0.039495509718695, 0.02849047857096359, 0.07559759467239342, 0.06529028001692026, 0.03177445618465784, 0.0625173558270739, 0.0038947342686550396, 0.05012856879001183, 0.04113539369897016, 0.024508265440442392, 0.015963580245302332, 0.0023355775216083617, 0.040318150253545855, 0.0253960789902316, 0.01187378251474471, 0.009472686759827119, 0.06584520346575207, 0.05682572091539061, 0.06535803283294363, 0.10275515877912123, 0.030008412845012163, 0.03462746912132829, 0.029238174639401898, 0.02296365981530999, 0.03008297043702295, 0.06701830624332351, 0.02676054287040907, 0.05662515143593473, 0.039979129533974395, 0.06182000514179949, 0.03347536481376137, 0.026943812169314876, 0.011115350681657513, 0.03272953225419887, 0.035877889322657744, 0.041205123021838166, 0.04535453484183358, 0.021894022957572055, 0.03488156133361402, 0.018306680271522175, 0.024133991269815355, 0.03416113608006028, 0.050693014711742444, 0.04958329804902596, 0.04585356068527026, 0.01966715857927357, 0.049822819268991875, 0.02957692339776024, 0.02044262341974724, 0.03184198108952373, 0.030016167570025693, 0.052441277150665565, 0.024531981607358304, 0.10910831827429995, 0.018803607034046325, 0.06686209325468348, 0.02500936355171425, 0.0401372883859421, 0.01826277768780147, 0.023845472981432275, 0.044149229558365005, 0.054136250513575734, 0.02354342941074602, 0.03993010373726007, 0.03685083630825243, 0.009255616704092152, 0.06500297406267735, 0.006959596132454012, 0.07833563121816806, 0.04337122130598273, 0.015272477964660334, 0.030015001201160976, 0.049429521219985145, 0.01536868041336176, 0.04547897050337446, 0.02476552734151483, 0.05650441214862851, 0.03497940991374274, 0.02322015945889777, 0.03644379847232373, 0.03771327894120928, 0.03749992728473679, 0.03763436805456877, 0.04264156086250179, 0.013273333221854222, 0.03948903627573483, 0.07571843738156943, 0.026204908875027494, 0.08391489635311788, 0.02894924840919914, 0.04713941245309768, 0.039117177197289084, 0.01749528782261956, 0.020097064139742046, 0.03942316037512595, 0.01893041373771285, 0.037668336393131364, 0.04010055446997285, 0.07186427201715208, 0.07759529916990189, 0.02934087255609132, 0.019449348291081768, 0.02115147691520472, 0.023929374930899472, 0.1298659378963132, 0.04388109878486684, 0.05338447694216044, 0.03472528322750042, 0.04949981744791712, 0.014819110003900866, 0.049581903769003774, 0.04767675035362763, 0.04133792436351219, 0.025500874072613738, 0.026853756618595896, 0.07380939990041718, 0.05185261135920883, 0.05368017155917422, 0.034286521690627264, 0.07047658801198968, 0.188758609996688, 0.1578046435550336, 0.19452322244403825, 0.15465260543409856, 0.1239738867227589, 0.07887996733188629, 0.22902653552591803, 0.20678375487125691, 0.15674721239314926, 0.20277337651819954, 0.09172965967727285, 0.11548765499385134, 0.07072318405393632, 0.1719810699503268, 0.12275926197969145, 0.1262751535602635, 0.08935222071745703, 0.12559832254004094, 0.1191401017469264, 0.1287861369670399, 0.1599712321354497, 0.1277447706689277, 0.16451938888959347, 0.12926069779261468, 0.1971129826720684, 0.17603385893087234, 0.15538907639922636, 0.17851953845350974, 0.10533867539056849, 0.12310074567193947, 0.10339347089851096, 0.13780080082435764, 0.13793963127799574, 0.12146671843384543, 0.09400157002551902, 0.16583771895497076, 0.11532198848022569, 0.19588998458798856, 0.0677665519798475, 0.11864363080671719, 0.2701177297820968, 0.10931160736588702, 0.1433179515504068, 0.11827434578369703, 0.09443484637285433, 0.14303405468742694, 0.12867646381979989, 0.1519440556125295, 0.0767465043933161, 0.2400543099089015, 0.11573136288432345, 0.10781558320647287, 0.12728190800595668, 0.16181568074370586, 0.08992491740613215, 0.13515626530974142, 0.11974849813287297, 0.11340499900641943, 0.13868089795352953, 0.1310649267848461, 0.09997791385338192, 0.19502173117812605, 0.10826798110839822, 0.1572822941647422, 0.15160550603703146, 0.15001674693438316, 0.1659208394947552, 0.16062714129446015, 0.12646767911651444, 0.1754982715412494, 0.15191747236155695, 0.12158391456450186, 0.15112478586454547, 0.19870895832296342, 0.1517804958406956, 0.1609200167079126, 0.09363539531947145, 0.06571461611817922, 0.11402852562887054, 0.10581604009794612, 0.14078984607852277, 0.14550203757901348, 0.11888090355862534, 0.14670422871506986, 0.1311529962526214, 0.24359694561891018, 0.12960369067807354, 0.14622275777641805, 0.11376597963634039, 0.21411947575548004, 0.13545513153076172, 0.20211379013715253, 0.16605420008061395, 0.2053836679026004, 0.12524423670143853, 0.08189100697035752, 0.2285050594758603, 0.11907712165867129, 0.1811773119674575, 0.14686469349168962, 0.1211877092118225, 0.12865060069147619, 0.11182815257099368, 0.18950281844985103, 0.13945248638910634, 0.13432351241429008, 0.16152930175585134, 0.1276151562530187, 0.13372861449756931, 0.14909819219141238, 0.0973609881475568, 0.1491107560333706, 0.20077693606576613, 0.1157304205961766, 0.14810396328328118, 0.13533192927077894, 0.15246050612580392, 0.2972661391381295, 0.11483275707090095, 0.11158525673372131, 0.1299643189075493, 0.08305296316863069, 0.1781517243193042, 0.10596712795837272, 0.1781800542507441, 0.14724200711615626, 0.0675078287660595, 0.1009442724828278, 0.07502172637971179, 0.0952841008021947, 0.12585795739845884, 0.14435131222971026, 0.1371867047442544, 0.18983681746307882, 0.14809780393636998, 0.09722124604928879, 0.17496220917711336, 0.1406076397266119, 0.13496534087725226, 0.09621947117510343, 0.17339347561280574, 0.1633912018470226, 0.18163903315942134, 0.1139604740385567, 0.20318413754144024, 0.12366681570006956, 0.11361959555576887, 0.17097219344108336, 0.11356624519272197, 0.07981084842955874, 0.12555070251466768, 0.09270022412942303, 0.0982186082570303, 0.12455754612963046, 0.17736835345145197, 0.18255956440923676, 0.11190961069998243, 0.09086455488877912, 0.10667173732672969, 0.1315684150904417, 0.25633588463308354, 0.15432959212170494, 0.12163453765453831, 0.14028931487231486, 0.1438173183029698, 0.06573557628378754, 0.13872176108341064, 0.13084956414757237, 0.1681704720061633, 0.20349386688922683, 0.07481768652195893, 0.15138367761767682, 0.11656408513625784, 0.15930007782674607, 0.07697132821645468, 0.11185337984634024], [0.03499973805681352, 0.03579878308359654, 0.08747312195238569, 0.022467562342963876, 0.030633799145899476, 0.022405859706322515, 0.023936865355579123, 0.04057383592871409, 0.06076894400100555, 0.06305657064301834, 0.035951203937011386, 0.07592980103987841, 0.0375546757582455, 0.03240396403857777, 0.10557712791788001, 0.05665092646414715, 0.049403470400119984, 0.051687025284815225, 0.05053358032338081, 0.0344150674138819, 0.01863369830853997, 0.09495321210593947, 0.02680184650084665, 0.02689438609166011, 0.08337386207835329, 0.041358719820216786, 0.029416142609871687, 0.031705052449157646, 0.022545147897495378, 0.07116946091334667, 0.013413275460592441, 0.007442254986193392, 0.03659178367665699, 0.07210580421791923, 0.012163597406939635, 0.05940208226562508, 0.04795268756307421, 0.03806808107202092, 0.0321892908804359, 0.11820971094552549, 0.11188082111578797, 0.014055902570215686, 0.012294426072208632, 0.030587887496597348, 0.00998746432859691, 0.027263923923695282, 0.059433748509975216, 0.0505179712819236, 0.0476472674598617, 0.013282470735571077, 0.06484915892924033, 0.021118715165122863, 0.013984729171610408, 0.01601769956910322, 0.023112863099442858, 0.05217651333359461, 0.05352877726357791, 0.019554876902651404, 0.028833752993734616, 0.053835273720324046, 0.02655211524406989, 0.027888339208138567, 0.0363173671517401, 0.06030192148060568, 0.016902940978686658, 0.010458546157385553, 0.009076284139507241, 0.05989533180611269, 0.025066117260364756, 0.01929558103814, 0.03752998091400631, 0.045712171497965054, 0.05106440647655437, 0.061133965744727084, 0.055790096446270906, 0.05336303414115983, 0.02954406014102842, 0.0035825917439069603, 0.03662230461956032, 0.0439726731048957, 0.10417178558606295, 0.020016431470491716, 0.01823092949756932, 0.03351595598242937, 0.023037413015000285, 0.034985588412852056, 0.04269460095993934, 0.07707917807443489, 0.06198300949988827, 0.02075395580651539, 0.024568370783761628, 0.0208363025974963, 0.10070969636041312, 0.017920347876966964, 0.04454159681054373, 0.02444623721643321, 0.060986367414795586, 0.0344076210392579, 0.04728239893372502, 0.04034233947975501, 0.06517192709349817, 0.006447468270292326, 0.03813736223345322, 0.06806673587209756, 0.02497202634150463, 0.028128178354593057, 0.052299933928635814, 0.0667343097889135, 0.020835766335949305, 0.010775129119264744, 0.05724694286923736, 0.026122722962510683, 0.052345619582000284, 0.03835192047840646, 0.04798430018126965, 0.03308374066686919, 0.047036703045089404, 0.026565184704058116, 0.059778342519195816, 0.06898103116620934, 0.0496636989766792, 0.006231983058950714, 0.022749078587719032, 0.01412793973295559, 0.04747430012831765, 0.03860337734823266, 0.039155052584265514, 0.019444828372328513, 0.00432198605267331, 0.09903095257017883, 0.050884471575339, 0.05131018280442204, 0.0666826065149038, 0.051454697630458304, 0.0712543894206324, 0.008487040909277576, 0.057530081305172176, 0.01901882986027387, 0.0783258865797712, 0.08020313141206581, 0.08869179163969333, 0.0476611030077742, 0.04940403730518395, 0.04517433947072395, 0.030024732433019147, 0.023595575100531983, 0.047455044508340864, 0.01978754929657425, 0.039897273039265026, 0.02556310339470304, 0.05793109769001604, 0.06009372942630322, 0.007778546517534603, 0.031992482892688245, 0.06077760079454991, 0.027011411767753384, 0.03675261234504081, 0.05790527286608854, 0.01109895256963829, 0.010363558915654018, 0.014150456014660098, 0.027051621807679057, 0.10990090517988128, 0.04696284450830952, 0.005688526031125578, 0.017186180921271443, 0.035311286863420284, 0.018793914106584365, 0.055281498334220344, 0.04376158906867908, 0.028355708383324168, 0.06373551989635153, 0.051101086766368924, 0.05171081231486413, 0.0166988838839555, 0.06903259654439266, 0.04820551573028488, 0.05750436373355408, 0.0704169940323599, 0.08158884657126281, 0.0063373244577838534, 0.0778130749841371, 0.06507818091420398, 0.029610510607580506, 0.044830741375804915, 0.022773892175586476, 0.07244956319130237, 0.01953364094539035, 0.010697130834864033, 0.008684483792392478, 0.026367409530306057, 0.06749954735559803, 0.004181418494666897, 0.05306422537673385, 0.014510668641436967, 0.009200755232614617, 0.06253299934248771, 0.0362875510097271, 0.03878982399680442, 0.11091754982067693, 0.03536067272145902, 0.025265696571178498, 0.06108013657672752, 0.02152253926220921, 0.016197816416200612, 0.060679231274632685, 0.07026101087009715, 0.0922270346012327, 0.024419418393423962, 0.02250778578942822, 0.0751086543764799, 0.060943581404224526, 0.024710376671845877, 0.033198232507152904, 0.04003776590369883, 0.03369562658331087, 0.03686765959906963, 0.03477283430496051, 0.023720075879546425, 0.028132903201866056, 0.03754277841278142, 0.011139386690281814, 0.03144758753478527, 0.0847151211553043, 0.03844768529938113, 0.04630294786165318, 0.03246829244157961, 0.020912574311237664, 0.02499701421437485, 0.0597732748475767, 0.0514034386874447, 0.05934484017592284, 0.0918971341583998, 0.020033482672466386, 0.04415075790377394, 0.04547569164705854, 0.014211882859648717, 0.02906830421829176, 0.0254174662498577, 0.01474944579850642, 0.021339852190125855, 0.07536452774318957, 0.013109607783506715, 0.03603877544763588, 0.011545412332540559, 0.05740593675704253, 0.0581063058287386, 0.015352017043398754, 0.03446145786813671, 0.0186166834957417, 0.04112543072551489, 0.012709956950387888, 0.038286036916918335, 0.06947440711120445, 0.02086894943438951, 0.049822535816459894, 0.05494729247725299, 0.016689273310945402, 0.0348832582183663, 0.02865059477757783, 0.04257776106016771, 0.05871927959003276, 0.020853139294852174, 0.042081665503041404, 0.10446662984548077, 0.027084211187977946, 0.045360403075333566, 0.012668249208570249, 0.038019940106859135, 0.11220450092467571, 0.04969284862219807, 0.0699310644619888, 0.04516070310567175, 0.0649375501539438, 0.018764929169969215, 0.04355051652378133, 0.09754278081198854, 0.0583862190345122, 0.044385671104875304, 0.06978500213834547, 0.025607115145952954, 0.07728900955689531, 0.05201166270360832, 0.039581120044233344, 0.028379709917991876, 0.010324337129150669, 0.05111265852446518, 0.06515982290429455, 0.07485278100977022, 0.04078079458145846, 0.07690896865941825, 0.02568976262644414, 0.060401869141646934, 0.03126038054394866, 0.04757070080226949, 0.03276057796733033, 0.042941135714852044, 0.011020838414439032, 0.05673327325512806, 0.015424307972763576, 0.016265398777660825, 0.06007013774867501, 0.03830788957495843, 0.03268835502826879, 0.02879557117158848, 0.01809096523380328, 0.013870438429406814, 0.057959691921789805, 0.033779739206957246, 0.03923787434975948, 0.006467855306372288, 0.026845643747477766, 0.04764496153520961, 0.10665256214598495, 0.07048781886095963, 0.02135739560359188, 0.03656767488967988, 0.03787227282901445, 0.05941427455494001, 0.027459148024659485, 0.012598805253454035, 0.02093821144362371, 0.02853172666002666, 0.05696886444404241, 0.05921047218444367, 0.046117175370454795, 0.019987762545145327, 0.08379863484972909, 0.02627610908671012, 0.010966278590081681, 0.016478210342146696, 0.06865912102042668, 0.05050852541781722, 0.07119585264233813, 0.025329341240707907, 0.0801751385593126, 0.0586300686512503, 0.02343886415474117, 0.056522120270998254, 0.02563682212043674, 0.012737278518597446, 0.036354108728588595, 0.05331858571979308, 0.013750373299473958, 0.05691254549028893, 0.030425859900612025, 0.016818652154817697, 0.028188919550889445, 0.035497990151446675, 0.0703663096552895, 0.07078310745137353, 0.04950022730495661, 0.15042847322840847, 0.05433720686743337, 0.2519491119610687, 0.1494070328772068, 0.1129794524862401, 0.2790177409206667, 0.1766330469399691, 0.14537220099760642, 0.1740626840581817, 0.17890049865649593, 0.20316826419964915, 0.13161922204158, 0.16080093600096243, 0.10236326650145555, 0.14251179722768648, 0.19674473952862526, 0.14772159347851432, 0.09402469055907381, 0.13929191436017715, 0.20274950521847895, 0.19205516294365932, 0.18346126521787337, 0.13254487075872962, 0.16197911794147185, 0.12317176968339952, 0.2556381930386828, 0.17934320554617914, 0.10290762559781153, 0.12163850598998609, 0.233621837330922, 0.10198923173330485, 0.2823536248216706, 0.15035238537576892, 0.18060132110070798, 0.12997556507827776, 0.13787318081144365, 0.11071070608112121, 0.11152583129343488, 0.14827103173780828, 0.15703506226981842, 0.22773553947767905, 0.1528455265947888, 0.1843835125046392, 0.09950490052541418, 0.15190823334119014, 0.09880300310830917, 0.1711740422873728, 0.16957435877092425, 0.19726123600717516, 0.22310852163260986, 0.16446407734146043, 0.09152706772569688, 0.06507878612366415, 0.17505516628584555, 0.13105525875524168, 0.19739079679692947, 0.23789440161518513, 0.14700695601922853, 0.12335851127582213, 0.16771501741342007, 0.0894585767039849, 0.15152845291360734, 0.25957096668501056, 0.11826599542532237, 0.1119863497273576, 0.1885483341832315, 0.06590911818127479, 0.15503912743541504, 0.09172643444711163, 0.10360324875481668, 0.13997436080488468, 0.1230063789614266, 0.178009798870452, 0.22554258215090922, 0.13178212297779898, 0.15993069076249677, 0.1443810977282063, 0.19238436624648111, 0.11965153438429679, 0.12717039624769844, 0.17149039063482516, 0.12174801059788275, 0.1604273455638078, 0.08780966437752209, 0.16319489947730498, 0.12166571743305653, 0.15201692589588706, 0.2652325403065451, 0.2115303590413063, 0.09126579343912103, 0.18825141382553887, 0.07851229109350713, 0.20948724851252573, 0.20622167616121231, 0.14132285941272013, 0.11310500663615043, 0.15772227378141496, 0.16196105358821733, 0.14437449405029898, 0.09884586572767266, 0.23044698511160192, 0.10671109126339998, 0.11197021591567224, 0.1728187870955275, 0.15266276865957246, 0.21347472083664712, 0.1416728543418069, 0.1763646250530597, 0.10720404586003673, 0.12191936148390656, 0.126399481969495, 0.1649748281605782, 0.13123099932507162, 0.2241137668850922, 0.18604930940895312, 0.09892391476539836, 0.17127461431007232, 0.11870089587905716, 0.12462567432873672, 0.14380928970152332, 0.2608464417919036, 0.09717518884328105, 0.15644834617212897, 0.0691586180079368, 0.09583313303488879, 0.14724435134520455, 0.11510962890761514, 0.12260334010446265, 0.08279973280525978, 0.10743610155318054, 0.12856204092742937, 0.14308847757356782, 0.20859374484467894, 0.20087799838473722, 0.1998710370953045, 0.11532041799998093, 0.13787465170025826, 0.15820719211572604, 0.18225349696172824, 0.13916030045478575, 0.2173663708831995, 0.06988674627556916, 0.17294342960080794, 0.13555421734288817, 0.0650499275915565, 0.06926912619101425, 0.124479535396301, 0.11516912329581477, 0.1783864996245792, 0.1066945744077525, 0.13081599417473042, 0.16853828614036884, 0.14575015813592943, 0.08296461790920266, 0.12283604697234209, 0.15046202787949195, 0.2444327322225417, 0.17375736737683897, 0.18696506027012103, 0.15693881098301182, 0.17181279107687936, 0.07865741878988282, 0.26973643250042395, 0.1650993021265153, 0.10139486241725185, 0.15201778391436224, 0.19748577637778175, 0.1209169430958648, 0.18022296559666434, 0.13761474871106688, 0.07795919093393511, 0.15873579278347955, 0.18802806855209414, 0.1781629092029987, 0.18343903334631076, 0.18767245053764314], [0.13973698080066713, 0.020598512736239263, 0.027757489475451654, 0.041354012209922075, 0.051192377633865804, 0.019679705184253476, 0.0888172998243282, 0.02284404667725246, 0.06558467228446277, 0.016431270219806223, 0.04014779145138399, 0.028374161526200273, 0.02000691665847215, 0.013262690345366156, 0.029362796077264414, 0.025777449050257285, 0.04078997614523096, 0.048028645180766626, 0.021891864504845395, 0.023603201505818197, 0.01999347947628027, 0.016681068509276357, 0.021214470409998493, 0.061831075112305345, 0.03606641973038355, 0.011505483829927061, 0.04915695096696577, 0.02942237665035552, 0.059218891490731514, 0.0653713780845846, 0.03112748535650392, 0.018959597857188315, 0.028725422415581923, 0.02583433107863511, 0.026699901265542836, 0.00910531695661766, 0.06942440455238666, 0.010480678437518017, 0.07558987250611668, 0.033054445464644706, 0.03706829036555944, 0.03401375225474758, 0.034668450994837674, 0.03655947008801084, 0.01397032576102403, 0.026120463003134056, 0.04459994972773618, 0.031480044764917225, 0.051418097779875806, 0.05058289723350637, 0.0478849079339735, 0.03813830835203971, 0.0017849040652377411, 0.020103725274243665, 0.0058933688447840755, 0.021702305624081243, 0.009115211939769647, 0.0764314966997312, 0.03334964595494732, 0.058087272374259855, 0.02833757891259607, 0.031837397968516715, 0.007640547748099292, 0.026184977182457526, 0.011650239973659477, 0.03987531312891553, 0.05457355648339276, 0.003981487262212942, 0.03989404014822456, 0.0539456746510921, 0.04371409161737369, 0.026228339674191612, 0.005394716948015435, 0.05357472338683663, 0.028759082403754996, 0.02903252982744767, 0.0720244916456361, 0.06589005025283945, 0.06890299745024213, 0.0138425518713531, 0.0806993878476562, 0.1453550712716195, 0.034256418265642664, 0.06614071422166402, 0.027671693373591672, 0.05156118385193329, 0.05999651669915165, 0.0499553716320905, 0.039205449678364306, 0.03441765296062635, 0.021428465580327377, 0.030562131620583036, 0.02181275443534457, 0.043206650298088796, 0.024691802870121696, 0.020481661345148762, 0.047421780970668605, 0.043258614041992736, 0.021922649748082605, 0.04744290967562026, 0.05854139014357521, 0.024329832071558605, 0.05376131559211401, 0.08683651054818785, 0.02436396320380511, 0.018439464376217896, 0.07948800365650847, 0.03501912774217706, 0.051498402946538506, 0.06863592387807947, 0.056039795144310886, 0.015634320443496108, 0.03664360186385532, 0.01208877168415535, 0.040736970521749995, 0.01948497137956081, 0.039788166797089006, 0.05373955869506444, 0.058805629190418034, 0.05929517086535212, 0.061581962471527446, 0.08497915335840757, 0.0172930195431916, 0.05526955502348081, 0.04044342478136382, 0.052396499311491374, 0.06520946540178792, 0.04865541235513745, 0.03444906639596147, 0.037008742351205125, 0.04718880214157605, 0.028237820858316078, 0.017111719090251193, 0.01950258757137964, 0.022925899341522206, 0.022553467612353065, 0.059711374943294836, 0.037642906104484876, 0.1019497245790497, 0.015392601508797418, 0.028111828123069102, 0.04922334780736316, 0.0344334113892288, 0.014297045981361261, 0.028304520303443558, 0.0761475921758721, 0.024623647857938084, 0.04774875112719113, 0.008972128740541877, 0.013054516485651896, 0.08254238088885624, 0.06442192701562759, 0.028210440875902295, 0.02902332145059782, 0.048678471601658294, 0.05070588881930998, 0.02608600628351973, 0.061698105231287985, 0.039444250775681394, 0.034089732855077715, 0.02356964685473471, 0.03430194304054303, 0.07414187439867566, 0.03871435284494393, 0.05196640605948145, 0.06718180472812346, 0.06358134853202971, 0.008048474724825111, 0.014147057457106009, 0.08153600182624594, 0.031895260589437625, 0.009354547383413922, 0.05417673826037396, 0.03681046347464285, 0.043272457250784484, 0.0160482291304957, 0.013418662973919944, 0.027530210340515743, 0.03553126134999818, 0.04065017659036864, 0.045956553545810526, 0.017106279865988804, 0.0664200681832529, 0.03860830329358578, 0.06492939131755023, 0.11173321895541684, 0.004360699348316919, 0.046778071761852315, 0.0480343142314063, 0.017808966353655826, 0.039048914932796074, 0.04695303475243911, 0.019638437942992297, 0.024090460238737926, 0.06639834959059954, 0.04994684890393288, 0.022274132802962296, 0.05006025672980374, 0.013965492703831725, 0.05534522535820162, 0.08514380863597316, 0.04356508751610114, 0.02067170860696464, 0.007827806928675742, 0.04399318893950793, 0.038606545121799556, 0.03275152280806534, 0.03265434455487036, 0.016903664931775104, 0.044446441029468854, 0.03791197533569029, 0.025616269896648107, 0.04590094705382663, 0.03181192171459477, 0.03012713349063791, 0.05515613953673071, 0.02949965193927769, 0.044313850361974015, 0.02115021670056928, 0.0646946849601884, 0.018667827525566665, 0.053533699378491416, 0.018351889035153775, 0.029870624270951076, 0.0265277230045608, 0.06055135204787217, 0.042582687005520835, 0.02243354803912582, 0.018847722207166014, 0.05590154308705561, 0.01926365049345599, 0.02480958697326001, 0.030105273171718565, 0.0573709610128595, 0.07518977542678196, 0.02026519362604426, 0.01646830291006594, 0.022529971695715384, 0.013651086389267398, 0.05463749801199283, 0.01062480734676243, 0.01966081920170015, 0.05676960114449744, 0.017169953263815374, 0.06277641611954858, 0.08113752119243145, 0.02223557176729364, 0.021167637539967414, 0.03685447139545314, 0.0032670461129577413, 0.013185554867490165, 0.017231776559304808, 0.03848983162653543, 0.06223153991384372, 0.0840227308893396, 0.019135692742683234, 0.022227125647928447, 0.05393046014491589, 0.02777122351671419, 0.025622601613342285, 0.017849532624466286, 0.04004441554688158, 0.04678563304966496, 0.10933164056510696, 0.0316181531806867, 0.05545691331668247, 0.014204240174994115, 0.04758913670816729, 0.06549915388947533, 0.04456819538327475, 0.06305092457501639, 0.02351662782471507, 0.037221504119975914, 0.06520749655582252, 0.10331110112489232, 0.007234377027939886, 0.04445123290943523, 0.023502188982562195, 0.010674212356999276, 0.04615703875559472, 0.016321415126684214, 0.011256160514969981, 0.07994486019015312, 0.050516952384984305, 0.044267253063979654, 0.11145407949844677, 0.08939669212146152, 0.005985970680241383, 0.02041416708379984, 0.025981504229768634, 0.02000096415530049, 0.03423213327844297, 0.07018391178139756, 0.05252867246106748, 0.012716019578698664, 0.06672470304634302, 0.07863715576428561, 0.0722247087246468, 0.049626321546853557, 0.061204327090132626, 0.02675270770616349, 0.04437595327955581, 0.0381106564084128, 0.011845615376988727, 0.03465831182115982, 0.07781960205325196, 0.07689198449013696, 0.042817381871563774, 0.025759608777720603, 0.011923908605240287, 0.03135270754536314, 0.028825657359594782, 0.08308091771698768, 0.06792505557138113, 0.03875289089797485, 0.042384641785775466, 0.04346857192896066, 0.05658029698796811, 0.02239664366859342, 0.025094426124386733, 0.026981718199808272, 0.06354440011144166, 0.02263589292734621, 0.05499139615905382, 0.01436659431595716, 0.04498477867473999, 0.10655444926552235, 0.04365468532928536, 0.028542143540577065, 0.05955960526461563, 0.06794799224383409, 0.06122027704071614, 0.00784204754557821, 0.023512140464698596, 0.0357613711798143, 0.006445341418692542, 0.04604439318720852, 0.007501692875408598, 0.012270974205626596, 0.08618790986797503, 0.04944390835120313, 0.024359531385163148, 0.05263446920341062, 0.07501111606196051, 0.0031710821091227477, 0.02281556544344752, 0.07204655497785538, 0.0382883926372855, 0.03529248323531882, 0.04690498571782824, 0.019582028973907716, 0.034116082449233344, 0.2815053816283903, 0.12985513605658086, 0.08031592253715762, 0.10897321100797384, 0.11860579372413697, 0.061416433853728164, 0.1561637138647418, 0.07943109864549291, 0.2875393046246421, 0.19555688955851142, 0.0961928189762177, 0.11047735569938538, 0.12386619008236355, 0.10437273044860172, 0.11195240437143272, 0.18592515719994424, 0.10321940040035595, 0.14113168983209518, 0.2599624069708009, 0.11490836994902742, 0.14778827377144368, 0.207609873445284, 0.10008505891047179, 0.13957876832254473, 0.18739207767911498, 0.12792025842974264, 0.11172883693248996, 0.18165849179269808, 0.13955641387691423, 0.162115236443858, 0.10591244460233759, 0.09062935057426653, 0.10115126943996838, 0.16846835763464052, 0.11948245111852886, 0.06345087992808511, 0.16222657966277293, 0.2379724659746693, 0.14330259914840424, 0.12284413686082249, 0.13815199085060628, 0.17052613108629183, 0.2503672476497389, 0.13160417607474711, 0.16320833665949686, 0.14956521471181225, 0.12059638126482888, 0.10362587899209992, 0.1476251276870889, 0.18002767446300677, 0.12320044435440533, 0.08824530793654342, 0.07535802365671243, 0.12007716517414778, 0.1086709356956905, 0.1440024357889929, 0.12269473439382932, 0.21901894510994036, 0.11790948874887922, 0.200186695963625, 0.10615855800889193, 0.14392795672099437, 0.10034464780361423, 0.11881678966024231, 0.04732261854974974, 0.1323056521434938, 0.2695504569959256, 0.0893291614709362, 0.21134252960403122, 0.2692993640178635, 0.12509635108853542, 0.11847672323065421, 0.11111608150625422, 0.15309366247346326, 0.07129576582942279, 0.20233863694292886, 0.1593861861094352, 0.12710222974419594, 0.17198942030870146, 0.09117246860818518, 0.10762121137832442, 0.3816619395248352, 0.13533810393944865, 0.1865415668655788, 0.15923433216108432, 0.20969634455057884, 0.13337587697371361, 0.1770666833486288, 0.12370186422260539, 0.10498090466905026, 0.07576673156431607, 0.17691188762264867, 0.09689905245097415, 0.10353482178141994, 0.12334190248962372, 0.11122451359105688, 0.21295702926093535, 0.1848871999930951, 0.15289316194192057, 0.17327404250541042, 0.1541013592073033, 0.1971126455933817, 0.14914156808968515, 0.28022573900318914, 0.12901489082123005, 0.14570794669130158, 0.21024996564993936, 0.1373584616568781, 0.10543671932311789, 0.20649823390187758, 0.1611602772027254, 0.06811791820631874, 0.11042702372276014, 0.17320518652277608, 0.08839597444861166, 0.13247553980158222, 0.12387239539455022, 0.10791890548482057, 0.24082537740468982, 0.13888745057967403, 0.1288630062293622, 0.22684416553426176, 0.13054922703773747, 0.15130072561723573, 0.22847000329244524, 0.11083914072162683, 0.17608722461567772, 0.07547557218781403, 0.1527530291388112, 0.10046516875586203, 0.18384935003855538, 0.14329686881073062, 0.13945705227313504, 0.10881316757971242, 0.10744293505746512, 0.07995907878202778, 0.1728240118151711, 0.24821346805941677, 0.17578123377696162, 0.17340593220245454, 0.09867322781393606, 0.20662854545779769, 0.11242162556417527, 0.07530399147541293, 0.11183484051857265, 0.21372768306924453, 0.08445965381519449, 0.24483407036431376, 0.1044799138100878, 0.14028838024504725, 0.17099255605811076, 0.1746241039326114, 0.13203471748819276, 0.15829195208366842, 0.17660868534397695, 0.18942029545864753, 0.07473080449046628, 0.11845659044000412, 0.14360538773959683, 0.16309227433896836, 0.19287814055719685, 0.09481821975280201, 0.13521117849215386, 0.143798457218274, 0.1755969436658967, 0.08703642885290808, 0.15694015929775854, 0.1852548609097158, 0.09630511214415874, 0.21175062464129543, 0.159331027778887, 0.10851720483192515, 0.09973414467587587, 0.15090729350284224, 0.1041165123423261, 0.09747889673998279], [0.03925015090874607, 0.03121996366028344, 0.021322391131111694, 0.020225546660742933, 0.04984499368396017, 0.010431822137756935, 0.023138278066330863, 0.07522848584959585, 0.01573476893451786, 0.05617011436111024, 0.04714543773462215, 0.020337564037031224, 0.050084315721065774, 0.022831260669796218, 0.03205100626444384, 0.01880040287130302, 0.0017696790253525722, 0.05442904931823573, 0.06181058609077047, 0.04734753555948696, 0.012865899893034612, 0.04321953972741481, 0.03065069329984967, 0.03809196003262074, 0.03841707625636651, 0.05220321915863503, 0.039200163671686765, 0.011785460237954414, 0.018243970229260383, 0.010283281519678573, 0.06162526942188702, 0.01501956935821762, 0.04125961868633186, 0.02235148661589671, 0.042813639532053666, 0.03236015913106742, 0.061497872830518795, 0.009517729856945094, 0.08188113975789278, 0.004815976783227657, 0.010646578607960575, 0.020564781884933193, 0.04409988200472247, 0.013320007128641011, 0.030928028619758068, 0.03523751642675169, 0.02704436695503612, 0.035645734038083784, 0.020954532946850506, 0.12365930037753237, 0.06235099600387677, 0.0631959680017204, 0.026157135632069364, 0.02917557567988913, 0.04413420657416986, 0.028999005819881157, 0.05395601300763027, 0.07352047750065405, 0.03584334258771232, 0.04320965719319159, 0.005900160214232822, 0.0037149535426344244, 0.027569225283279538, 0.02469844676764502, 0.022684667830265338, 0.06984403687379054, 0.06068594220484938, 0.0071459072792241654, 0.05077599735570051, 0.04449848521260485, 0.05594754283646903, 0.06312907320417224, 0.01855460739123725, 0.046568389666537126, 0.007894979433096465, 0.03995255777432073, 0.03515100977834194, 0.0361776978318249, 0.05958347273389659, 0.05364365214782377, 0.036019075496663014, 0.019129596598025773, 0.08001615999326592, 0.050585482780250816, 0.0703914909653606, 0.051988626439725204, 0.05943364508810544, 0.03657823924215571, 0.06648451149944337, 0.02120927058821244, 0.024735027466029413, 0.06589217997726894, 0.01652645281395845, 0.022432372094162052, 0.015751452414288877, 0.034295270414722544, 0.04586380711125751, 0.036588577598693876, 0.04090746338929861, 0.03710990426160636, 0.023481293934427445, 0.027457882064364614, 0.07373668283464448, 0.02700489235951776, 0.05637500074601943, 0.039761242636990164, 0.056039461896063826, 0.02842277172021568, 0.0359730604254911, 0.026612843033827605, 0.034637956865011685, 0.026546143588700125, 0.01776123907597315, 0.049869087149178794, 0.003197340012129937, 0.06345070755830215, 0.03798458131871397, 0.052659324926113894, 0.0863859206137638, 0.03757961958106007, 0.020852645168141015, 0.03124085870841819, 0.0353389771114434, 0.01935473260199351, 0.0367405119862768, 0.049108461431798436, 0.019799398761543057, 0.020874472928323576, 0.02291891453487258, 0.026774282657331037, 0.08055577700537059, 0.07016532648835452, 0.040304073387937206, 0.032396322311533075, 0.030160994576891104, 0.018431652194610047, 0.036547863855957985, 0.0416059019194255, 0.0416691501384541, 0.04043808131809196, 0.0789733381280976, 0.04228579729134518, 0.05381924333050848, 0.045901184541083155, 0.049195937181432406, 0.0592289119207811, 0.07121502016220363, 0.019482219208692832, 0.057288120095167434, 0.03813361606350349, 0.021144769815427643, 0.09647525261126219, 0.07347306431902033, 0.0476296934028787, 0.05290804303161079, 0.01887072974275197, 0.056204956039906516, 0.058507494583365426, 0.05062940643138943, 0.046057366886206215, 0.04780403203180721, 0.14900313600176765, 0.1476597548612664, 0.026534836130937742, 0.06852549996467368, 0.016916669274289763, 0.027638786066804203, 0.04347103873207685, 0.029744267643940066, 0.012910762001880476, 0.07106092923711385, 0.034489902712765245, 0.036060210587757255, 0.01074462254050999, 0.05258554682856607, 0.024732635356485847, 0.07043263754777371, 0.06688488437043083, 0.05451615351522642, 0.04963898498024191, 0.05355863170998712, 0.02291424331375428, 0.05161906179461268, 0.04339460230943176, 0.04435551022329638, 0.05304927517089152, 0.027984056148617983, 0.028759593767444455, 0.012851629590225077, 0.009748042700061155, 0.04474582819027766, 0.01672125939700392, 0.023350511234433904, 0.035082329995930195, 0.05509094545437444, 0.04052605502487671, 0.040856936060252695, 0.01626831374221271, 0.07665553145230779, 0.021802063678361235, 0.03477218313022487, 0.11002010846089934, 0.02427413173380398, 0.03260915685865668, 0.036517649348224365, 0.07879447958041584, 0.023230993857366905, 0.06249876287315161, 0.032876088704553344, 0.009558809406664825, 0.051698528094998294, 0.06567880150771911, 0.05265629121793374, 0.06676060958735405, 0.04132103595522143, 0.011815308938704193, 0.0455969212306363, 0.03760951233186549, 0.014508552323546142, 0.02055431520866771, 0.03888043304604869, 0.08274745496530687, 0.060911647029100895, 0.02330990857444704, 0.02386428235519317, 0.055943513213987314, 0.07136675919736586, 0.03242484376495404, 0.02002876357085282, 0.08617412028533798, 0.03083110126035829, 0.031613985662378614, 0.061965186464329886, 0.016890706554535898, 0.010638896661299852, 0.003971417754655704, 0.04854576219053519, 0.06499274678888821, 0.023639385753701773, 0.03311089082290569, 0.01940958258215218, 0.024251694933721618, 0.05055211582070878, 0.05440049339085818, 0.04337611660781888, 0.04205247755312631, 0.026632652152329687, 0.027302394944032835, 0.03423834242106926, 0.07763889723367269, 0.016081763671771172, 0.03704590527641197, 0.024134514124823675, 0.044046389915409594, 0.01804655894727236, 0.026418272022818847, 0.039929540662635724, 0.06498343882060821, 0.012288281089445997, 0.04600073000596416, 0.09352086517479151, 0.011828476074902762, 0.019353395778565638, 0.06421066677918838, 0.05268359842199472, 0.01601346023005223, 0.024010836890327836, 0.060242955693073814, 0.07987476314508146, 0.01703025904604264, 0.037490979377781196, 0.02057949843395862, 0.04298403280817213, 0.01828574883421102, 0.017088098684325814, 0.04775496793069667, 0.06015892733909911, 0.10786989884030436, 0.05554709718712876, 0.08153289150927337, 0.026232767662393953, 0.026447431244436773, 0.0221129862080899, 0.03276438159387439, 0.04052072688336334, 0.020637684727027532, 0.042618229654767824, 0.025149435067789692, 0.016486141267382813, 0.026818189071491364, 0.020280350675626148, 0.034846922668117675, 0.033589289748981115, 0.02060959611328379, 0.057074672677704406, 0.026936337066393708, 0.06412707892577015, 0.013093689434050072, 0.019525133538991213, 0.007146800250460905, 0.05378623643229085, 0.02699181906908991, 0.015818337635737995, 0.023063484902283358, 0.03525067398685121, 0.04300121232987412, 0.044579544975872964, 0.03286850443410297, 0.026961208110855475, 0.06583095423036045, 0.04661974820098089, 0.005342063724979638, 0.11465013703151096, 0.028024354288654945, 0.028086112466670816, 0.06537070392721123, 0.0252892499444105, 0.06502313749684442, 0.033878514753474344, 0.02220348417458515, 0.011795120606679591, 0.04080986378774528, 0.06890380950344187, 0.09646423626691104, 0.06156323545221841, 0.014013914248695778, 0.05759963825825722, 0.06507103331387043, 0.023616945123179786, 0.06331666132375117, 0.09603173366837925, 0.06465848730576616, 0.026561792849773364, 0.05115563988745694, 0.007771515745609518, 0.020538757878145384, 0.05625380946683788, 0.07067821469278106, 0.061500182585610505, 0.07063335258393519, 0.00940316332308876, 0.029792693976853645, 0.03923590167335445, 0.015628945379097377, 0.031722668640976476, 0.06160321758098661, 0.05099211075914003, 0.04616873691819849, 0.018798412957919702, 0.019075290540293343, 0.05162792160145698, 0.05932785600664155, 0.10067587357855613, 0.1277759657692044, 0.18014909939900522, 0.13430376266760213, 0.16580525214873976, 0.12135165202761851, 0.11741768328412888, 0.21908348035668174, 0.164424056908296, 0.17932092770934108, 0.12712668327073898, 0.12438834028979465, 0.06479335708483573, 0.12144324549984549, 0.13467716924365492, 0.11900960632990445, 0.12120093188939557, 0.1689308908798041, 0.23342167387806603, 0.22245477284154586, 0.14682542382469102, 0.12049306664736041, 0.15562991912086166, 0.0873037092688103, 0.155873918124745, 0.16863813804041955, 0.10010454818726548, 0.10064643281962603, 0.12178878179721295, 0.12017684087397591, 0.19302912116531404, 0.10027811306739047, 0.11443567837798789, 0.15084373884864394, 0.27017763785777554, 0.22882202069365212, 0.2293275621148848, 0.12552961211411223, 0.17987834860480603, 0.12824239074102334, 0.10538189041037714, 0.12714136917624744, 0.10911545821375425, 0.16335993013795347, 0.15595592017615997, 0.251606946450568, 0.10415094033364328, 0.23782125554017483, 0.13570663819630302, 0.25490808060332654, 0.12967570294295588, 0.08094786080501734, 0.11091041754210189, 0.19218535192551153, 0.11472616359711656, 0.10184925214778032, 0.1420968533643792, 0.18095294013619426, 0.09927050826410133, 0.0794982998782108, 0.08366926558195584, 0.10799690089639156, 0.14368536731889173, 0.1368056372889588, 0.16737786211794423, 0.1373658007791927, 0.17840814926931936, 0.09862469614393289, 0.14964632810123507, 0.0841902130313458, 0.13641548403088125, 0.14310956031324404, 0.09291384774710863, 0.17188255104326433, 0.09606041600026431, 0.07906832536982913, 0.12453330710770623, 0.1395171442099156, 0.22574774049703153, 0.10986494501271557, 0.17328116712310623, 0.09192695796129205, 0.16424387302850524, 0.3031434737626584, 0.1806332363236335, 0.14262537742334028, 0.15782154345464322, 0.12269651937869289, 0.147688391227876, 0.1271550361848166, 0.12067042366271058, 0.08531038679422871, 0.20986362750972473, 0.11494398537662723, 0.09533316873374487, 0.13712914089762396, 0.05819602238555109, 0.17236175436166026, 0.14816563336118577, 0.10586867799922343, 0.16171961331800108, 0.24990543452722414, 0.19513672097556053, 0.11287794583627295, 0.12440409105751785, 0.09975052363569699, 0.14885621565964915, 0.13516058604563438, 0.17410397619730042, 0.10141645843583731, 0.15124178281234157, 0.13394691891247226, 0.13603262392984283, 0.1617759207804357, 0.06654739199626832, 0.18168279210165625, 0.18834248635797732, 0.09668637878231465, 0.1436731558773787, 0.06850333704102425, 0.10935338214039804, 0.14259455004526725, 0.17220801583701567, 0.20256827945911116, 0.11323105108233229, 0.18247949289939097, 0.11531936845952466, 0.1225042696140947, 0.1300626079882345, 0.13911412067471013, 0.25432075163529766, 0.16730840858672896, 0.2158972900360823, 0.20040276340178906, 0.12685679049501497, 0.06733109228192799, 0.20661113994015803, 0.1120321158199541, 0.10052901452347156, 0.22258857775840069, 0.11664778790286473, 0.2240992725015648, 0.13178966128297392, 0.13118241402891376, 0.12440262782958247, 0.23369147472323912, 0.1753518721389194, 0.12956351702732424, 0.24715802872613554, 0.15393832037525793, 0.14556307946482014, 0.23630352810986582, 0.15576153302625304, 0.16623328079379376, 0.14599703763040806, 0.105169101828529, 0.1227966930356718, 0.17106187169349965, 0.1595927234138212, 0.13893344649864783, 0.18989192982835157, 0.2403420065679858, 0.15120049067322286, 0.16954979799207182, 0.2311919749744477, 0.10797019507135115, 0.08518904612790193, 0.12550967850632247, 0.14265652655834152, 0.12639113927199958, 0.22089635082069906, 0.1065174625405381, 0.11683673582850926, 0.12240280892940299, 0.2191711667804949, 0.17790700519277206]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.012886798771608983, 0.03835863523906277, 0.04230190812039279, 0.025197049347503532, 0.05341549201177494, 0.08948910530776748, 0.01701692720094035, 0.00758055923318851, 0.08255345085936208, 0.06869632225002974, 0.04114587378177432, 0.023881846836077112, 0.026097980237776236, 0.018904648285599488, 0.031720494866491325, 0.04247025594175343, 0.03904807223607937, 0.02309716404265454, 0.026686988853579088, 0.07991361146372172, 0.04232821174927297, 0.09814926963900367, 0.010626774277508019, 0.042933677848909176, 0.0879449325223123, 0.02802262484516588, 0.09037520090538649, 0.0033373473683417205, 0.030134288751850688, 0.016231346169426557, 0.0607722649921573, 0.023413014432956136, 0.03934066802743943, 0.023080982350473924, 0.034659372852934946, 0.10146146610138879, 0.06758091355403585, 0.015026399032062581, 0.04717693160918932, 0.032323743141586744, 0.05051992480613051, 0.03593677084051794, 0.028858794492759535, 0.03916766239149917, 0.02619119207074325, 0.09012486635436935, 0.05854558064452103, 0.03636062813682422, 0.057544882123869275, 0.031380880428778554, 0.0643133646958778, 0.0744637462400621, 0.016990893618053487, 0.01587894763947735, 0.02898598615560801, 0.044013298747520295, 0.01839593142992066, 0.054989553717595924, 0.04731413412598833, 0.033170009828022415, 0.021017108923725544, 0.050486519542192264, 0.001315710882584925, 0.06079985181831064, 0.04694622040035264, 0.04890936667159681, 0.04204867775702188, 0.046720990550614176, 0.020133991492912173, 0.024076632351704666, 0.030311119081752918, 0.04421260035146148, 0.05115758958122423, 0.046134006322151234, 0.010278298117731129, 0.06528746081335891, 0.03059412919796042, 0.03472899492349356, 0.05783146795546336, 0.04833973433461882, 0.07635183887736452, 0.025037335337049542, 0.024739623993575096, 0.012110654985712422, 0.01887475361957425, 0.043150695236099344, 0.0790978657201894, 0.023374824949930754, 0.018300946103408933, 0.013371572506824329, 0.05660339070844555, 0.010302614706057695, 0.02102029010383112, 0.07539544705181353, 0.06190576102404345, 0.04715540453851704, 0.042923653588419965, 0.024079415166089614, 0.07193626896027597, 0.02890977381368078, 0.04778234025223121, 0.051212035450002844, 0.025136095561808156, 0.019187346220977845, 0.04997368496392043, 0.033563415129338546, 0.0644229152690499, 0.027599594923817826, 0.008530457984776267, 0.025404195691789352, 0.06905456028518177, 0.080767753534019, 0.00979726289158627, 0.017669777753913117, 0.06759549986811415, 0.05783143348150677, 0.018993324878054763, 0.015257784398272635, 0.04962540990222366, 0.04033055321703996, 0.02507300822124366, 0.02834514977650777, 0.037452935451461423, 0.025791548898503668, 0.06592878365829107, 0.029965674714936368, 0.03287565969531575, 0.0958988557179128, 0.027702336890562892, 0.024950083668133425, 0.08289354793246716, 0.04310121744750969, 0.049577621337507045, 0.016296172529579173, 0.03930781434680666, 0.03976563615123591, 0.01882140325652736, 0.04469091883830486, 0.05707046302456049, 0.05100116591840502, 0.061356031651338266, 0.046373519881237904, 0.03724671607356399, 0.008473791418627145, 0.048574260661318425, 0.07290088090925448, 0.021764410456882852, 0.12352573294793406, 0.032017826996443254, 0.05476305216190316, 0.017498166397995046, 0.030548407155419552, 0.08950226669830662, 0.0528861022734594, 0.03596962835159033, 0.028434167278089353, 0.06789471082870038, 0.019251013873144984, 0.07824972977921849, 0.029109236296086066, 0.03446995378321698, 0.06218739026676744, 0.03332246132495423, 0.09102699617224355, 0.08152947475713107, 0.03600683341163301, 0.05036201876317782, 0.05526953587128271, 0.04975879347072013, 0.02516103746940292, 0.02369523164816201, 0.12259669812215913, 0.05297974886132344, 0.026681676033824205, 0.041955843222357576, 0.038146758301844524, 0.040214261070134184, 0.022779325654189435, 0.058955732627861926, 0.026692326571191513, 0.06326682347383711, 0.013922888639142678, 0.018866784389941924, 0.011509365980483351, 0.026731098281039346, 0.021986001388980977, 0.010569736158715622, 0.01918113133269212, 0.01105167153817151, 0.0482232736483697, 0.04728836675865516, 0.04129242257124955, 0.023487135354850083, 0.07487823811149405, 0.02488274262436936, 0.04506760427067357, 0.007409807810965445, 0.05410177655698312, 0.018163146038028984, 0.06238346281010778, 0.009457532583074945, 0.057665839746233925, 0.025487952084550937, 0.05457546021188459, 0.014716017551930442, 0.010720148904158944, 0.017433893536367727, 0.04099318096714635, 0.009307802613494138, 0.01804689411073923, 0.03146945168414424, 0.06626275968888114, 0.058236785924002055, 0.06290108160746676, 0.0546616182902888, 0.032124431961546504, 0.035332748816619, 0.0470655347641197, 0.04579928335583499, 0.02430554133869948, 0.06743730271175023, 0.05193113537144758, 0.038037445215928944, 0.06163180032144151, 0.06883192747350662, 0.08307958472399943, 0.08043982959803074, 0.07800206887505709, 0.021409619817390077, 0.026881946738989606, 0.01294536523581032, 0.05465308790125194, 0.04737554756443828, 0.011093050819791613, 0.07412736469338979, 0.05133485083558387, 0.01962479200184105, 0.020741485810327916, 0.05659962921673733, 0.06687864075384795, 0.03825611735303556, 0.030697637252629768, 0.03838921746900005, 0.038204590279248454, 0.03981271991506219, 0.010779782145794843, 0.005959254321492007, 0.025062813506191297, 0.0534694284320839, 0.042857727892096006, 0.018817817965041728, 0.03607688449142921, 0.021817253286679907, 0.012085339610254573, 0.03614894655202666, 0.04164275840946263, 0.007295503183418224, 0.03169558743285316, 0.05062356884140642, 0.024169001487954974, 0.026890519262862303, 0.04991004604005045, 0.08964638315862225, 0.03417995886035985, 0.020635060875886874, 0.04052002591291263, 0.0124434148517227, 0.06429744538881126, 0.05853830663967998, 0.025769684749144702, 0.04260270105254266, 0.02170573578276221, 0.06276178384019483, 0.04017388440608498, 0.05367104745199604, 0.01152348115048822, 0.06685018058746092, 0.036340273180676085, 0.03258699010456762, 0.02219006614459138, 0.05957279346823212, 0.0645106476581385, 0.053550059186114427, 0.07933138464126857, 0.06040748073569229, 0.03743284096520755, 0.017714839045619293, 0.12657012805462847, 0.0655910308142343, 0.027779462792339827, 0.01946293294519907, 0.04841877545620646, 0.032703921934890176, 0.059649030708016894, 0.05728771789900719, 0.04476520255388272, 0.0910459568483695, 0.010233008914867477, 0.1039199265200765, 0.0250089785925323, 0.018470230467257, 0.00919004628104308, 0.05760012089364952, 0.13245320067771021, 0.03528892858735016, 0.0423551359093718, 0.0907681733670254, 0.016427612149967782, 0.0660151447499952, 0.06151875255689506, 0.047963646450831045, 0.06539966205074903, 0.013928628552915349, 0.05464432768583779, 0.04032548937586047, 0.03245251869121867, 0.03529206571740008, 0.02776614818421583, 0.031655921315353726, 0.030857554276383696, 0.029023426787687406, 0.055496543045005495, 0.019558534972489845, 0.01885131132909127, 0.028328655903498014, 0.03343213447219422, 0.06587230765651311, 0.0394377198761269, 0.058563962924264135, 0.047261120841628125, 0.053491533899139014, 0.021191347961223895, 0.04706124084130411, 0.01572818440880867, 0.04930996936896155, 0.059526552401122555, 0.04716056797112669, 0.013480888465569626, 0.01302046962307706, 0.016388313754672007, 0.029395908312571627, 0.025228928181252656, 0.06131693435412261, 0.05618001604753156, 0.010939821743616655, 0.023494759844916484, 0.04664130974560977, 0.06783795903526968, 0.004824200258289855, 0.035907226659718065, 0.037746090487006216, 0.010605660894314849, 0.12476735462945317, 0.11249324712421625, 0.15084969901269482, 0.10492125706326579, 0.14160010663251724, 0.15021989813014386, 0.12049744867028729, 0.08808537176059139, 0.14878447918641954, 0.1179896138848797, 0.17064383283497828, 0.08191696969011138, 0.11841224161006751, 0.1425859698605153, 0.14765030133628076, 0.17600928283026143, 0.11883912112323508, 0.16617845954193225, 0.07055528822445101, 0.17751251587704306, 0.1642928873339007, 0.17329173913646131, 0.11358745050646606, 0.18335013650357726, 0.2778737265015802, 0.07853227066657237, 0.19677348314754425, 0.13932902365922928, 0.13459864523141615, 0.07619117491788442, 0.10175997992196392, 0.1696883066887817, 0.09940300317060563, 0.1771203248250869, 0.11510156966265171, 0.22634245455265048, 0.18987073983636596, 0.20649958221662432, 0.10114589150273993, 0.14059001970435345, 0.16014501152019348, 0.12208623075557333, 0.13923782855272293, 0.1297613975381659, 0.1461111081223334, 0.21460070154599606, 0.18321813955422372, 0.1998934987932444, 0.23117145913983547, 0.19913525560930853, 0.22950298092778654, 0.25625218186647664, 0.12156041098698495, 0.09593011976610269, 0.09298686358717181, 0.15288058277820388, 0.27330732153308007, 0.09750814597693183, 0.15535063410718597, 0.17019827609821675, 0.11946194294479587, 0.13203257244200478, 0.17853775602434913, 0.12178006371663463, 0.12396557466878046, 0.1244626967837253, 0.08686177612793061, 0.17474942059526521, 0.11932115896695084, 0.22600105513007412, 0.10807993716650433, 0.12514053137912867, 0.1636103183151253, 0.1349197126804821, 0.09458169010618041, 0.20582444425071442, 0.12416062831518151, 0.11887652153569846, 0.15905905124400893, 0.18874354870809665, 0.1389575323029872, 0.10983351242518234, 0.08964768550809353, 0.07254591406953913, 0.14762862104802363, 0.19907926990380212, 0.21497537982800316, 0.0888263396618347, 0.09049546904861928, 0.10871664816213232, 0.09086618665605785, 0.13289501890540123, 0.14887132291351596, 0.11830749440818064, 0.1404536560538315, 0.08843681459585506, 0.2092266254006855, 0.11011448283229144, 0.14259234371204532, 0.11559527502545427, 0.18573391101052686, 0.13416744498235567, 0.15153617507988407, 0.172369507171454, 0.13369556546451586, 0.261000425464684, 0.19435255337626706, 0.09561354925315227, 0.11602456005470407, 0.19260608741352636, 0.1514696020392641, 0.27240931326823853, 0.1581626211202914, 0.12363208893446193, 0.12465757422990377, 0.13537289965296948, 0.09053447824572364, 0.10624027660777492, 0.11847589585569598, 0.18084938037059, 0.24269812530086887, 0.09764943557280688, 0.18634399278990685, 0.15950327498778222, 0.19802536274636948, 0.08916380139248026, 0.09449788774814337, 0.299207589799358, 0.16252826508735457, 0.1503010881283591, 0.2560959918604743, 0.13610563210902676, 0.09761008163613659, 0.21672120227688746, 0.1372501674679018, 0.17664760261053042, 0.09177582413558999, 0.1602651800719961, 0.17874838423825082, 0.13103279705730178, 0.10898814206161808, 0.07612542925222267, 0.13932876318933504, 0.12170776033834105, 0.12001981583213615, 0.17668964551581492, 0.24330523465910267, 0.164305359245308, 0.18248232742471082, 0.1396206426884859, 0.18316210788344184, 0.2667129286114247, 0.1342191559172446, 0.2762453606532466, 0.10917346639138077, 0.11385273909376514, 0.14089427918436068, 0.05960966528002774, 0.17062791352791173, 0.20528450548168153, 0.09602506104255877, 0.16294196788822451, 0.10547526886746769, 0.11415253994205307, 0.13863626567106094, 0.1565082389260492, 0.0962268945670897, 0.07317195346038188, 0.12324208889396922, 0.10215981653140438, 0.14056847731192268, 0.20784726877126003, 0.138595188036561, 0.16779986931191337, 0.17544119799089047, 0.09469874834101047], [0.024289024483051994, 0.03982978069313592, 0.05365793202673236, 0.043257740701759057, 0.02341938828448615, 0.04714707716278011, 0.01676670564789205, 0.02213421450447171, 0.058334929447981625, 0.055426867348292184, 0.009634829269001081, 0.10952341535519208, 0.035804781552043655, 0.00485069445154119, 0.03547180526619477, 0.0232367739907556, 0.04091898918211941, 0.016127740438546867, 0.022289127058860277, 0.10780958473802575, 0.05462173958339038, 0.0975876046164382, 0.03369763373367248, 0.05782199527827963, 0.05446867521611914, 0.08438114512471423, 0.009035978338591034, 0.02271611190911743, 0.03728966296259915, 0.03193764057340882, 0.05643995351067955, 0.06201425056544043, 0.016243567187038642, 0.04913886746151313, 0.03520680013142767, 0.028684065158989643, 0.04751230575024121, 0.0342047379742707, 0.006897806353311265, 0.004377612175660268, 0.034109612836712794, 0.06237397481116557, 0.03643164448740502, 0.06742972610217911, 0.08122139249838169, 0.013896938368317582, 0.027586192215582537, 0.019380099688386245, 0.003370371982342594, 0.024651453019149845, 0.0233676026560246, 0.033377600503304315, 0.06214173142648032, 0.04142650711019674, 0.07510874630703081, 0.07442411651173908, 0.04532824270427228, 0.012297243360550174, 0.029392560508342522, 0.022549686968446742, 0.059218462481493914, 0.03572217046072887, 0.008478549782246833, 0.060775160804511084, 0.028395437703077352, 0.05864922851023655, 0.020384733985748985, 0.00857960635555848, 0.06669716984634438, 0.03924819355409953, 0.03281614615491802, 0.029765382942353046, 0.01948111412686206, 0.0036253775150755486, 0.029027146144559788, 0.02080705144532746, 0.028279120658314037, 0.01813656087183664, 0.049416336846808274, 0.03061125126306809, 0.015057609454097768, 0.035730045844590476, 0.031110045364907676, 0.04404042592091907, 0.04690480568716603, 0.0321728965988563, 0.022416835831057642, 0.03464566370952995, 0.01758618990049487, 0.01822232824539946, 0.03714108787056419, 0.04430291062641529, 0.08845885494543661, 0.0551328351420741, 0.002639357957260443, 0.015272084386989236, 0.0562721036464697, 0.058351584199455485, 0.05808788141415966, 0.028027772956017046, 0.025471130708953547, 0.018876529028338772, 0.03276427817200461, 0.07531293938236852, 0.09343582941519638, 0.04496722760039472, 0.03901470910697695, 0.02193688940737517, 0.04068223736999978, 0.04991726641873679, 0.03936840041029838, 0.059421425985713164, 0.02149806849868788, 0.028454238781705502, 0.06500589285766886, 0.041262043354612206, 0.07227419800455533, 0.08912077023377342, 0.02336560699698185, 0.0028824745236159938, 0.09031566055191141, 0.00492037397869412, 0.022830756966986006, 0.06866089834441101, 0.03450209883251979, 0.0387699555064882, 0.07030083978128049, 0.02574930489513903, 0.018658213122116945, 0.00298514059977606, 0.02573157187491175, 0.027774381714182037, 0.051992598605612596, 0.11214456986635925, 0.07244064592786374, 0.053795146034850236, 0.023648065529883872, 0.053810364371466066, 0.03833262272359383, 0.0194337832996802, 0.05711730930113024, 0.037384290143006274, 0.02248071990306339, 0.0542350375514117, 0.023703367501917868, 0.024042273308300686, 0.031905311663004185, 0.035914768795332605, 0.08568292769092707, 0.0343044979437705, 0.03398267589809914, 0.02093619280194323, 0.08084972494191701, 0.07050487197815411, 0.058082304294070894, 0.024761892254314116, 0.06776501980399893, 0.018772364053274357, 0.03601022335069795, 0.08573695987222657, 0.042471075655832406, 0.08295418379167396, 0.01753977071794291, 0.08798437072865425, 0.013789482088008476, 0.07559265340528182, 0.09505110282090404, 0.05593438910680914, 0.03834799427779452, 0.126817635741205, 0.03307030731511693, 0.04768613876113969, 0.04477591246306416, 0.07379434627270506, 0.051701374111637, 0.03960918950577898, 0.030294088947196162, 0.055356770303220525, 0.07428679525131181, 0.02269935948143323, 0.041381840353771564, 0.023106106203950705, 0.027630516147661596, 0.02566113200549397, 0.024736889059685414, 0.029985261667940407, 0.02406451858640198, 0.08224988085848671, 0.02779667678799841, 0.022468200111160838, 0.016088736987101938, 0.09688676440066869, 0.02198619865662148, 0.044981308296443, 0.025596759552436493, 0.03585500244591986, 0.048807093933705366, 0.07065000733540905, 0.058155584434467944, 0.05244897250386496, 0.021198288717817877, 0.04734341017601471, 0.08733444471633242, 0.03286635938791498, 0.07956492654498547, 0.025904868624263236, 0.033518870946981257, 0.03591044039856042, 0.06746429965020188, 0.047882084899972525, 0.04045801492588174, 0.03381089600283773, 0.053274972334263794, 0.053959854938570535, 0.015373914709104406, 0.06760518321947706, 0.020369322211932273, 0.09654839102539325, 0.05055040744463763, 0.02501310397600455, 0.04177440678881061, 0.004064979354640649, 0.02154244797214145, 0.06252188723714602, 0.03159046101744377, 0.051495476490667755, 0.037810012863408175, 0.05042710942366431, 0.08296986561148398, 0.052966005243961854, 0.025649405114593047, 0.06590973871249346, 0.0354207148625245, 0.004192840386812966, 0.05646501990756201, 0.021592044504359368, 0.03690149387224548, 0.05847713068848657, 0.045623155911603284, 0.036029973097385905, 0.05711276639973926, 0.02228356143009038, 0.004012970124266201, 0.0054856568514820075, 0.055102053729276505, 0.011069218782077153, 0.029102412367900534, 0.060882271387644356, 0.023801681480460593, 0.05365604745043863, 0.059925190082961516, 0.034878857043241306, 0.042904819316801526, 0.039682963772887186, 0.10159435171273448, 0.021401832533639767, 0.059069979320009874, 0.01893215467252078, 0.025750055661304824, 0.04159426504385568, 0.04094503617154495, 0.09019517790405981, 0.0392801164379043, 0.013981547033894929, 0.0811476948400659, 0.055439105602882566, 0.042627675518874204, 0.09615629956486726, 0.07392730083196394, 0.016376483441901304, 0.04272302282193015, 0.052504506217496055, 0.011205673405540087, 0.023222296844206514, 0.017938220708240426, 0.06451388821005821, 0.058424144217203704, 0.015839699997506555, 0.0447473565356866, 0.0696222850632283, 0.035437848418951035, 0.013094781109342172, 0.0349973363711709, 0.03236757869261407, 0.07389542391343464, 0.06377905667308839, 0.004728494809129306, 0.04979869132981666, 0.04710775003918717, 0.043789788765171846, 0.029537178756248568, 0.07235963212987108, 0.021077742867712534, 0.03805028101910026, 0.05859542615531434, 0.08783303005921264, 0.05880048491000649, 0.01845989977159808, 0.0231968627251204, 0.06376453164604402, 0.03399555766654592, 0.014760960100008356, 0.07476930806954062, 0.031231349642058055, 0.023982346080423846, 0.026303519712640878, 0.027333172526390805, 0.04115240468132881, 0.02169510631281282, 0.0534307333310285, 0.024615220890771, 0.020994268012263125, 0.04412308297750931, 0.009852956526071556, 0.016807086142380873, 0.0281560697006963, 0.02779083153713615, 0.06917898062496416, 0.03352194295955762, 0.04950285115609727, 0.03995839536430375, 0.020870879975958698, 0.027807292851409125, 0.03364463960151038, 0.06681167700838658, 0.024388736572056532, 0.05335329333320261, 0.047616911225862084, 0.06420823061958918, 0.02739628476481284, 0.06631451658904552, 0.005820985506063388, 0.009291129667432079, 0.01628376956608507, 0.023867821681403348, 0.014714807133010079, 0.03615026805369604, 0.09507443785907761, 0.02877864828934112, 0.05664434576887758, 0.08511147206468929, 0.0010669120984535005, 0.11596231541085629, 0.01495088287253654, 0.021427155569976857, 0.04062986759949596, 0.030213481175803372, 0.0045676149086155485, 0.03769393905156082, 0.02472322779677568, 0.013921412004668628, 0.012936090783876999, 0.10033941542309138, 0.1297900339047755, 0.2638532756076705, 0.17235530390133783, 0.12357866196262261, 0.22019426188161298, 0.11360889330746667, 0.07394898112022108, 0.1464461949804137, 0.11771651120075297, 0.14082410553049657, 0.16378319371611844, 0.2113414724026957, 0.11114321634053223, 0.13351096891828124, 0.2178014015718814, 0.10928604301185378, 0.12648006675825005, 0.1483601277634021, 0.2271196660735915, 0.20386129797947025, 0.2551032951281917, 0.19089637834939266, 0.28326713870609965, 0.08997669728893427, 0.27459364444498097, 0.18584989672226293, 0.1411245498926409, 0.15114416788902976, 0.14143463164087267, 0.1707531689035316, 0.18798495312371563, 0.14855788570017586, 0.17945180617032513, 0.11838281617289591, 0.11406749652157869, 0.09540295934364681, 0.10916682440907725, 0.09167777254216133, 0.12271652959527508, 0.07939111651672472, 0.17348598839054186, 0.19465629191648579, 0.15479037868640116, 0.2671000175178051, 0.1134965388524917, 0.08496430657443502, 0.12762546013560028, 0.07483005118105682, 0.06482064513669861, 0.09853359296797745, 0.13150971743368334, 0.1723130464914345, 0.12306455567839647, 0.12510832504279193, 0.1638320701256875, 0.15438752369053904, 0.07824567717409904, 0.07951713798026885, 0.07224094978864155, 0.27967859900766806, 0.12227945345183536, 0.1276578426721596, 0.10067277858334203, 0.15845160480708848, 0.10785017973713337, 0.15352605781968565, 0.11416649806403345, 0.14056795637213415, 0.1205105487737925, 0.128793460767596, 0.07768295495019806, 0.1482225383722013, 0.10867799136547313, 0.15501571578844903, 0.10084570761048987, 0.14777353423978054, 0.1515636163493318, 0.19789356497987626, 0.14681161892029548, 0.1619884335706311, 0.11727907499598882, 0.09319442744937637, 0.12110442779357396, 0.159827713223715, 0.32036623346709436, 0.1283639382510897, 0.13487886487235948, 0.22840401247864772, 0.20654465883008896, 0.11571581129946056, 0.17811101440700794, 0.19326185867671045, 0.18980637312896792, 0.139864886840505, 0.07140840373692975, 0.12332804395907349, 0.17652945653084787, 0.0850258157738755, 0.14521427963289524, 0.14483158807120017, 0.14253654186764073, 0.09670333996895822, 0.17251700974039494, 0.17618889980498822, 0.11055652322548051, 0.17044740789119275, 0.08012743426426765, 0.14273570940619515, 0.2002536673699656, 0.11491454461769712, 0.22188152456956528, 0.1085337523310896, 0.1023015121538793, 0.11957136328302084, 0.14784775283788482, 0.15929753441483746, 0.16921714729359075, 0.12652628484272188, 0.14359742042518434, 0.20278281472142667, 0.1139240695403949, 0.18007295025933176, 0.11385213388430496, 0.12582434912122067, 0.11307300714355324, 0.18460684245632542, 0.18350857880807694, 0.07397744894748734, 0.0799521380254338, 0.11822673341920299, 0.11308627578640178, 0.08725943704766613, 0.17277452253526257, 0.07509772230180041, 0.08415287390591637, 0.12783968896274606, 0.16406097719746252, 0.15265467877109207, 0.09824730591067384, 0.25302981687409265, 0.11105875514688031, 0.09384962414661724, 0.1146715491889946, 0.07403806948493566, 0.11096359170492619, 0.13803551484259868, 0.14987494405959884, 0.14079306364780472, 0.16782651384991987, 0.17251271964801898, 0.24811107274745745, 0.25901999624986805, 0.15039939253080278, 0.2705909269711664, 0.1890570472084707, 0.1316686040691791, 0.1360939722508192, 0.09954420083592977, 0.12937006450468494, 0.30351242170699183, 0.24259294142886517, 0.11569852835588879, 0.12482344758726897, 0.10991424277064302, 0.14886738522158516, 0.1638532907611901, 0.1642060129632873, 0.0896180762098201, 0.10497706656854962, 0.1510534171135195, 0.1514194692454992, 0.2095506346273807, 0.1733821375115264, 0.22580178033921028, 0.08416771302900969], [0.015867631563225824, 0.01941954555560745, 0.023786576141813592, 0.04638793382553324, 0.07046137350581347, 0.04062851545430961, 0.030885719498919866, 0.043555944256724856, 0.017717692723137238, 0.042160419341657436, 0.03695446502176985, 0.006562149717337302, 0.0741818795100816, 0.044469986741821614, 0.10340161441314606, 0.027159914081435532, 0.03431739120353614, 0.05525676135514533, 0.03230534937052477, 0.06713907234370708, 0.01779549086706773, 0.03852267764628895, 0.0368972574060242, 0.048991410857847625, 0.031542159173817884, 0.05665157380844316, 0.02717968298032159, 0.024002385025303212, 0.01991942750229951, 0.05276145593773934, 0.025580018616071152, 0.02919706061572558, 0.011425842286928767, 0.07664100642526343, 0.0346201146772552, 0.01580193760849896, 0.0045392332662407674, 0.08425258024926148, 0.033521579067793586, 0.05792142582997199, 0.06166425946679327, 0.0037451101149687726, 0.11137724087964143, 0.04448233990960064, 0.06003223171818161, 0.08187472760196655, 0.039572976529598236, 0.03615799021997279, 0.044950978875520735, 0.031133215694177537, 0.07429791884797235, 0.02218231141957785, 0.07038118708277903, 0.058403758617538604, 0.0370878447598267, 0.07633650179712043, 0.11472730506812373, 0.03904045732211202, 0.031479761312385245, 0.03095027006741974, 0.03100755620717762, 0.02819915448555783, 0.07290906272828579, 0.015355258552928366, 0.05747982210689976, 0.051376357479321386, 0.031614786224259485, 0.05817967406924694, 0.022870846348063602, 0.0149629027920685, 0.012253268956086569, 0.03539286756647691, 0.09479279329459514, 0.02143696724106708, 0.020889009446686795, 0.07228125367433795, 0.053701545412261645, 0.010556458897377935, 0.04055778255626079, 0.05336470804327438, 0.06914580901784283, 0.03351253156940784, 0.06595337508066047, 0.02650634149059413, 0.014676612861935171, 0.020564075168823043, 0.03487298114886207, 0.04603647566851109, 0.0303753670455227, 0.04673215628211056, 0.040289387482428746, 0.04392552805403548, 0.05766521921501525, 0.026667015026173285, 0.038534295369660666, 0.02045977421315207, 0.09186681239835678, 0.03110932332703904, 0.050362248589555104, 0.0254714448050025, 0.07425573038598222, 0.06594458805216898, 0.028002668254738374, 0.06408444613278394, 0.047290733970341184, 0.08379868081500454, 0.05244027740592438, 0.07014797459686957, 0.04127385643040461, 0.016523838538916844, 0.08319682681993132, 0.02886184543791798, 0.01908613259964172, 0.020595210897285613, 0.06300764443773417, 0.040427379069789764, 0.01830647342778262, 0.020245752229745832, 0.03245901511681657, 0.010618093543716017, 0.06531391382938431, 0.027886245872885473, 0.04720739126505871, 0.030862616202343377, 0.03745933228562917, 0.03613121927745881, 0.040022022796854864, 0.02812338072896725, 0.01721405886083601, 0.08014313140583616, 0.02132533673918055, 0.04013400186874694, 0.0912139752519227, 0.05770702080260362, 0.04745643112748381, 0.020624858499955268, 0.04762449549631246, 0.018593019039760676, 0.04961509835876284, 0.023001504558769446, 0.032817961783298565, 0.06997539030928766, 0.018001647042711417, 0.05534177030166311, 0.0059927630073000355, 0.03469175921993391, 0.07163261468972891, 0.03677359932372647, 0.035816602288715305, 0.01757957090082909, 0.022370163839490666, 0.02381171914748848, 0.047245768439625545, 0.003240606264068535, 0.014416300015704287, 0.0686178365421872, 0.036096354616024805, 0.044990026377021305, 0.029586769542807055, 0.06006195592964369, 0.04365774585054286, 0.03427108118851339, 0.04804973558132206, 0.03327505963463937, 0.016552541938219822, 0.030636603027702342, 0.07961893574364724, 0.04505256213428033, 0.11677891151198458, 0.03906665752912241, 0.06264061171321139, 0.05646525356437891, 0.16361385764133546, 0.08505539442863196, 0.036513328612331426, 0.031022316806258696, 0.06569996851706697, 0.007931553428211521, 0.04103628873464562, 0.026319201532450896, 0.01929634329562466, 0.02544680358691802, 0.022790033648151065, 0.05439039252157654, 0.020153329467340823, 0.03336586786674396, 0.07824899433481117, 0.0539379065195399, 0.04870431174734428, 0.04593767713935626, 0.050412622701016166, 0.07588703035106582, 0.02507956210343588, 0.029686761253903952, 0.09091473364781949, 0.025331432660741192, 0.009289289141193995, 0.05269198325432597, 0.05954688437463296, 0.01592080381083032, 0.052587611435522, 0.04107998255940695, 0.028212001780048016, 0.050833362019470626, 0.047934305283331105, 0.026315158503430507, 0.02508096021389769, 0.03181301722032649, 0.028208514164772727, 0.06535303793967732, 0.01125524216707075, 0.029086244082258596, 0.058208961610592184, 0.06794135792240982, 0.014522869549241039, 0.10197590180342236, 0.06178026433072745, 0.017304585555628423, 0.07930890762157018, 0.03494703886850226, 0.037900771299797686, 0.04344821314237291, 0.036281690437106356, 0.026176400828145208, 0.048288410274131645, 0.029693571775550806, 0.03689727272778269, 0.039093014784157276, 0.056712830198868636, 0.050879878878232934, 0.026339790145415935, 0.021347084060131062, 0.08422604296356441, 0.035193106309781154, 0.03929362639844899, 0.07833673438477902, 0.034360357244769414, 0.03837352415787117, 0.059570767165672396, 0.07439516604908052, 0.04693703117570089, 0.03818039722259968, 0.01179440814491001, 0.024209625215359756, 0.03489356976182711, 0.09014044858274922, 0.014134823990565155, 0.042356078197518666, 0.04589782141509556, 0.052204471712391225, 0.05719826564252858, 0.07008958337528091, 0.03444733886769222, 0.03616377801424073, 0.057547774105783434, 0.09201285940024162, 0.05930096249005968, 0.037971251388831485, 0.050302976366853526, 0.05743852613734142, 0.018770320513736338, 0.030499417747881626, 0.07042994857915948, 0.08642983277358356, 0.03976487389375125, 0.06322874124312113, 0.03187691661409073, 0.053449364589347, 0.028051155874685898, 0.021806529970959793, 0.019369847516739563, 0.04336271773002321, 0.09878926715182682, 0.038338096421812816, 0.06956382489372646, 0.029909459183052666, 0.050097944425238725, 0.028396424041279865, 0.05068448432270558, 0.024613753832396, 0.03176215664303351, 0.11630962903220808, 0.029882964032191425, 0.10129107282527032, 0.020474797197347207, 0.02257978081733229, 0.06745211119132657, 0.0317604540126218, 0.028110207847109245, 0.042077655032757795, 0.051303594448273225, 0.08032576676698462, 0.048948835521455736, 0.011693696311164287, 0.04305840462386128, 0.04134827421136922, 0.09045259876837654, 0.018998246992968263, 0.00955288275896061, 0.043839879424100926, 0.030769038562392517, 0.020004857797175646, 0.0665115237596535, 0.031808169798985604, 0.004350784255356919, 0.03950926865781507, 0.053186596431318796, 0.0829279376193881, 0.0407166577004377, 0.05382965063495983, 0.02392753248944158, 0.03529185504322091, 0.02511629793462494, 0.09271663373276111, 0.008593815371334072, 0.04624775888758802, 0.0321951246399793, 0.12826619309283074, 0.04495913771191432, 0.1162239574196358, 0.024070241263196356, 0.026235563883317575, 0.03062821244971166, 0.02795556342349418, 0.02799227052638608, 0.050258420693177375, 0.08066802420803616, 0.10664425009200651, 0.056701392506159125, 0.024179583077409098, 0.04712166219589211, 0.0752585088353484, 0.02023734058433723, 0.04651858629057965, 0.01987988395886796, 0.019962073701824394, 0.0333404797129333, 0.01922259009593437, 0.05119213631616966, 0.012660020466653571, 0.05328360614517043, 0.05578148944844162, 0.04229266143914673, 0.03223372781048379, 0.03363880584196698, 0.03277733231023435, 0.03066831332210812, 0.03495319438497386, 0.11301871449235948, 0.015657408418314114, 0.03944013688352801, 0.02065715293640331, 0.09261714955491405, 0.15758494486010846, 0.12620029910918207, 0.13366401796379399, 0.1153343378175651, 0.1578493524462946, 0.08339556534924815, 0.10945269777890175, 0.18284620386698555, 0.0984708350452204, 0.19903428522088837, 0.09910792908481053, 0.1750103961075506, 0.11296158731584588, 0.16388621722017566, 0.20778728408678887, 0.1191098029695211, 0.2130864368331048, 0.17199508935934113, 0.18181296576175, 0.09038512940488516, 0.14531638383144332, 0.16230452144818922, 0.1559075340628624, 0.13193930889810287, 0.20942608405265117, 0.12456311558883999, 0.17894013604569822, 0.14255865116513547, 0.1274069948422332, 0.12436115949024117, 0.23523860460808202, 0.181720330409946, 0.1917104386994916, 0.10939550165447498, 0.11857233866448365, 0.1477918897064463, 0.13521065755236533, 0.08849799437748809, 0.18515320104216376, 0.2427153469574067, 0.12825107817808468, 0.17554927767524797, 0.22514107546979384, 0.21377240728226402, 0.23320733779861083, 0.18729098471662692, 0.13563684758640107, 0.10126016883840484, 0.17438281687998003, 0.15795027686943933, 0.16160626294872454, 0.16552395998470246, 0.24586542389325558, 0.14918411661299968, 0.10149628479754734, 0.15835195208989805, 0.11617498141863655, 0.13378271562678198, 0.1484422064236095, 0.1286681441049422, 0.1402448817727066, 0.13331379320832992, 0.1236872779085271, 0.22881226073349678, 0.09330387843111831, 0.09835838099881526, 0.17968327197576725, 0.11647827562785919, 0.17388038577571993, 0.14392852362605835, 0.2008885550763338, 0.26184774935245514, 0.13266611183362623, 0.1976788764999759, 0.13570651562223512, 0.1424126348067676, 0.10838677836281639, 0.11635697326592861, 0.191542282400112, 0.2405307706325285, 0.1303132413135421, 0.1561069620713111, 0.1704016724421132, 0.14548993338980984, 0.19833063346243676, 0.16743519613819738, 0.10957201597310844, 0.15421043480596236, 0.18855447820838422, 0.16470700382224976, 0.14903892762959003, 0.10335149694113963, 0.09366322729376056, 0.1308333690488531, 0.10448020492349902, 0.30104567987784264, 0.10340727580290648, 0.1104192479303287, 0.14286750717268837, 0.15232017413983423, 0.11045591289838476, 0.13350038158316768, 0.1864520265089889, 0.17909742921831148, 0.18090286862946328, 0.17702375178135213, 0.19899138429712868, 0.14281291574720414, 0.19404716008613188, 0.2299584048770128, 0.1657438731842464, 0.10336237538966442, 0.06946440200291334, 0.12705966589912293, 0.30296666066973443, 0.14884130758864267, 0.17883159670858614, 0.12902383872818562, 0.09953966559541803, 0.2718376891026574, 0.10681151006851466, 0.19401159828468678, 0.17296291887760165, 0.1428000914353517, 0.09191326030920591, 0.13939432499389495, 0.13900067837488267, 0.06909768337443953, 0.1785988132319143, 0.13129849167120072, 0.18834927389698644, 0.19204990758049875, 0.138842205426866, 0.16206400048348213, 0.11144411269455187, 0.05550541817360828, 0.23575810415129508, 0.09940330960577536, 0.09221206524319227, 0.10412517679674972, 0.22245576875584744, 0.13891895211512043, 0.15360747764427818, 0.14912080710693715, 0.08313691874425258, 0.19182558171451095, 0.10993676575561685, 0.15429603747062146, 0.09972765591115722, 0.12355335041760437, 0.23611002962195107, 0.1915196215193118, 0.10329009499400855, 0.27911696462861957, 0.17079409332044665, 0.09168428428951772, 0.12734228339526923, 0.07746673429444914, 0.10296273030220501, 0.07621651710641962, 0.11231760614581647, 0.17651084059428784, 0.17335206089961916, 0.1033040454551097, 0.15251486772491088, 0.22648650972593218, 0.08881840299093917, 0.14702727267098042, 0.14010548441400453, 0.14214652650538953, 0.11936098021725494, 0.27268323566644426, 0.2836857291479265, 0.14663039316092769, 0.1479489224091653], [0.037150572039066784, 0.05389899308342607, 0.013897432495028743, 0.04748997811768805, 0.018823854737885056, 0.053248622740108165, 0.04814121797080002, 0.03171867157723154, 0.04554670799763934, 0.01030180839851739, 0.028525297267122135, 0.018570775676879193, 0.01164105362183745, 0.034387691261907744, 0.052485242936640024, 0.048872923869038784, 0.014611665842934482, 0.005210917133222064, 0.008753862630035128, 0.03749641477160397, 0.02861864699591552, 0.07250851365707575, 0.010180175661169475, 0.029726722315254233, 0.06846027523880044, 0.02575492798050325, 0.016984171196517926, 0.06206381645414138, 0.04503809839426991, 0.008980019446161967, 0.034595906298847935, 0.037158493388203845, 0.03015434493370835, 0.04192950128908119, 0.020021292298371275, 0.024883242496739955, 0.03442198901827778, 0.03382787251123979, 0.020540851213398482, 0.048303720541298396, 0.032750994207397584, 0.12134696356952192, 0.05543552031139693, 0.010722677951918976, 0.07795658623499256, 0.04021035402172035, 0.06689900337087532, 0.03789241711098341, 0.010528646075286934, 0.06030210151126789, 0.0700640956300401, 0.03325173991822428, 0.02452629148930071, 0.07301808470079015, 0.06410131538887659, 0.038526508085910356, 0.015233355769587141, 0.03194711133537274, 0.017970886697331746, 0.024224652029994517, 0.030352681266864946, 0.06441831108062498, 0.05608337405588358, 0.03602942151408042, 0.04749232234673635, 0.024244869090316278, 0.02176730435401682, 0.0234369546805899, 0.0932305331732477, 0.026905465638265017, 0.009808359675169473, 0.027715297183021907, 0.021806012861610904, 0.04142181482166052, 0.024881652864297072, 0.04764034968590544, 0.05496011295866582, 0.012219619501622455, 0.02984063767437493, 0.08297872158788866, 0.06467630651088492, 0.08402661495511571, 0.022617606408593637, 0.01944031036879507, 0.010690403625278944, 0.02857625552062546, 0.0387762374274673, 0.018466147218620586, 0.05930634808816737, 0.013484202753452044, 0.06725089053713507, 0.0299714433570062, 0.03387026781696947, 0.03694878064937169, 0.010998301065316605, 0.03961989175408118, 0.048159523641750704, 0.046384126368549564, 0.025573635188442086, 0.06116159087527664, 0.05119912686847872, 0.03610853924446049, 0.02615745355855794, 0.03432660724126524, 0.029587799931065212, 0.06493081624108939, 0.04967312568858747, 0.01366971094431656, 0.0146372617980946, 0.055942773939140385, 0.03476002148442692, 0.05482251590658581, 0.037685726589012536, 0.00876237482448379, 0.026306430846753142, 0.05120407196602995, 0.0308842581862043, 0.04493302943545484, 0.043348690660129634, 0.014698833242178926, 0.0235591035696768, 0.0691316287303644, 0.06698053044777724, 0.017434270834670435, 0.01647162964687713, 0.027557249413803223, 0.06665095942275179, 0.042670361938015114, 0.06945360782406024, 0.04728960016021325, 0.0774046964943409, 0.00662306088939189, 0.015792907347091507, 0.006501182525103251, 0.01747826917938167, 0.030122711248095, 0.09734930530671151, 0.02813048619446495, 0.02839190412252661, 0.043727256838352456, 0.03377207066683519, 0.021909189583252997, 0.03936352426066034, 0.023606591444883137, 0.049810443118575125, 0.028553895329335527, 0.0409664674812267, 0.035042830502554294, 0.03700682713139442, 0.02118160332282705, 0.06334710565786209, 0.00810104750862886, 0.060523949082820654, 0.06438603579637504, 0.04601433189705976, 0.009155444962333047, 0.07667947169994155, 0.023857592492394393, 0.04396054210261472, 0.09201481292444853, 0.07834673183219087, 0.030060830496011243, 0.026070718998990716, 0.06253889055862542, 0.006585221891591867, 0.12978629539570502, 0.037327136153415326, 0.020856628825347272, 0.02730302888179018, 0.09289143201444419, 0.03470252275527005, 0.017972572090765162, 0.05769329250700051, 0.015473663187285346, 0.018481829038430608, 0.05118293560019905, 0.02308593319368459, 0.0656809848583033, 0.05016353304287599, 0.004467546588726222, 0.008481653395950074, 0.056815700485341014, 0.011936929227123338, 0.03927157838798819, 0.05032715793218344, 0.032930473286298015, 0.013685552684980775, 0.019216290937976974, 0.03427973415161814, 0.02795952026762309, 0.06900619715452194, 0.07691554169380858, 0.03319319547905076, 0.021729608997702602, 0.02746585703965637, 0.007468702735364318, 0.012179541611863721, 0.07661749518686727, 0.006188623918851297, 0.020051305708024773, 0.029212822874767647, 0.027188221030237696, 0.023583505385284944, 0.04004657974526767, 0.03391087047695633, 0.020163903395915707, 0.03761013669352378, 0.025480116920305357, 0.004524711112026125, 0.10966148738178516, 0.00875037118432022, 0.054634663486672994, 0.05326669092380232, 0.06244178125334363, 0.02952319382119083, 0.11270672518519625, 0.014942482718446804, 0.06444357666036775, 0.01949439426102946, 0.006376705686336444, 0.03859506146381459, 0.047666277931702715, 0.044702241617825725, 0.03833847563533533, 0.04034161935710619, 0.0222947329072462, 0.03231767189478682, 0.029614852410891367, 0.003570286456623205, 0.051374698898965315, 0.03786848452422888, 0.022687766655919053, 0.044080710654417356, 0.0509700742399981, 0.05017639565912466, 0.028276824309761008, 0.024079177678833087, 0.01017281738665676, 0.036609124076823076, 0.014244183999366097, 0.03763207362123555, 0.07160557178600181, 0.07578429029954058, 0.06948956033034671, 0.07642513050908044, 0.05629688276038055, 0.018080850957982966, 0.09887099341158906, 0.07313380228175272, 0.01259591422914978, 0.018797637293896368, 0.026357791296416716, 0.05142624512495053, 0.026130697937802445, 0.06449134224244664, 0.023525499122878237, 0.05531488061552087, 0.05730613465270689, 0.006947622657002461, 0.017870458316118006, 0.0471979568922712, 0.07459116964450768, 0.037874414044762814, 0.005578688174981865, 0.06032274758082725, 0.05006676847716013, 0.03945047524006617, 0.01522249551565056, 0.05771059843321001, 0.053075463886583046, 0.028314615427065763, 0.006652846387887915, 0.03423457709892142, 0.03041302984310014, 0.06085343200773482, 0.08577510338997649, 0.038132968719207475, 0.023778162581185182, 0.05798986046424797, 0.02227640808409741, 0.03752372197566494, 0.007211033371277154, 0.06698416170453833, 0.024205273835949843, 0.007643384188638941, 0.052678369871911504, 0.02450216738056512, 0.052138385137603174, 0.04113551627303805, 0.02215348544620699, 0.02009931452301962, 0.059047969613945296, 0.03962117878179397, 0.049213576355888966, 0.033027360426081766, 0.04636722646893994, 0.05031863903446544, 0.07064082960207617, 0.0276894704438746, 0.03016453581832109, 0.016214748874547023, 0.02124527672065362, 0.06272973838232218, 0.03993733560726528, 0.08706550188963452, 0.04217281464427229, 0.03452345736384873, 0.020736891198002046, 0.020383805104140795, 0.02153087046838576, 0.005695868505074853, 0.056108241269905726, 0.022314394553822857, 0.013609781801219911, 0.07672670102047344, 0.031725784703608484, 0.05272171129622767, 0.060430003720666134, 0.03149458511372007, 0.0526527940265594, 0.04124059672317198, 0.029960453825732394, 0.016295689894186876, 0.05041813087319175, 0.04141975404514421, 0.03761834532563244, 0.03599466027451619, 0.007855301824278169, 0.07372115423241932, 0.07151703500459272, 0.020132225660246708, 0.025981931323786418, 0.00722589451939829, 0.044324100618400884, 0.014416769244557908, 0.03535632900292835, 0.05947772578726854, 0.03678685264481652, 0.021707539919823892, 0.03588627415498899, 0.03314374833397808, 0.022049527314882127, 0.042253908881497, 0.01506296440868849, 0.060706136282533414, 0.05010458257710261, 0.08931116606559485, 0.027946481451151833, 0.008697556125210419, 0.0282241155453507, 0.03371250733072239, 0.03898011257631644, 0.1533865225651572, 0.16310278506528947, 0.07459516862347242, 0.09330720325270969, 0.12059863356332626, 0.13099521278373658, 0.11973197361634624, 0.08205013109310981, 0.16412417945121566, 0.09803173642966057, 0.11955959617250389, 0.11949952721836106, 0.08951637803787187, 0.10631171430671409, 0.1289048652735449, 0.13291424771230068, 0.06910038766481223, 0.0964863685470435, 0.08601316521244665, 0.16941415446419872, 0.13065818006232863, 0.19727432078892188, 0.10564791444208353, 0.11003428108749852, 0.14343162367661155, 0.18407776681405885, 0.1253459961604207, 0.11626885017199863, 0.17776725543362482, 0.1577558897195324, 0.08275920675406534, 0.09023230252487045, 0.08226587677434569, 0.16962416980776096, 0.11217952645834416, 0.08366826200677503, 0.12305104954829141, 0.2140332908639985, 0.09770448665104567, 0.17212749999617377, 0.23371891599268685, 0.23860847216940698, 0.08537862224564438, 0.21072633444301545, 0.1540540915823752, 0.1390485895136672, 0.20549298864939522, 0.13323376766375958, 0.12682643809145497, 0.13131127001777773, 0.1348071896861638, 0.13311157663983683, 0.08218886195531777, 0.210978070934934, 0.11201972051733926, 0.11353563231926773, 0.12396823299387771, 0.194019902677786, 0.1529934428512089, 0.16866262221047956, 0.11116265199117123, 0.1507368542614483, 0.16263303527187917, 0.08338466391808565, 0.15246922420638223, 0.2154980050099473, 0.17359011506121005, 0.14927623102501517, 0.1995938511625413, 0.1570874626838392, 0.11849456541841069, 0.18622137275674652, 0.1389208213696557, 0.17356674937951952, 0.08530091028660537, 0.13483843075171595, 0.14976612893083405, 0.10053963250210209, 0.13559803757215702, 0.20605388758403642, 0.18690383452321255, 0.2045953481067573, 0.1410166693911437, 0.11632709583688168, 0.10923327487562934, 0.12419644292564162, 0.15647194168019682, 0.07059840365282952, 0.10173456878551554, 0.20630488863154767, 0.12415905783493673, 0.06611438377970649, 0.14984073057290048, 0.12312456334550535, 0.12721527367830276, 0.1456051836571386, 0.11636583690321255, 0.1398839471080611, 0.13031826685032538, 0.23271383927954783, 0.08318660720702141, 0.12061906512826683, 0.18730656694500677, 0.12134631239478627, 0.17172622314143568, 0.11248131147435597, 0.10193588137025796, 0.12372449445988863, 0.1751922347372578, 0.20565127773631006, 0.12524831995007493, 0.16652882219322268, 0.13908439646324805, 0.08078291441404051, 0.14446526014756772, 0.15996721783472648, 0.09307930741699473, 0.1803269390497477, 0.12837561343105572, 0.16438912329894884, 0.21777124835118172, 0.10813602246344091, 0.12639066429748652, 0.10114401458732544, 0.19960353451390422, 0.0712144072918642, 0.1664926168779212, 0.20177059806883338, 0.1686704669508242, 0.1479541624505674, 0.2131132652322131, 0.12424621565808212, 0.14161003513201592, 0.11764262968133535, 0.19046197585280866, 0.09171649828673371, 0.19992918316875735, 0.12311513280315746, 0.1725901864589222, 0.20009386142896068, 0.07949812367798821, 0.1697589093518834, 0.11808060980852574, 0.10291726298389897, 0.11394552000227476, 0.0754921579913747, 0.09653988744943373, 0.12385637649605352, 0.09401939689151703, 0.12751722723365794, 0.15696528698167495, 0.11649938901105236, 0.2099292659230771, 0.21703997146218054, 0.38045075451654775, 0.06463652356497704, 0.1860980019574204, 0.18472445227446097, 0.15430650223166714, 0.18296013646308454, 0.25077583298327466, 0.0807207004137097, 0.09019309414490577, 0.2547284942721167, 0.1358041611890639, 0.2982172219743652, 0.13904106653025075, 0.17411416516669337, 0.18611061176465404, 0.15171805967486676, 0.15075096560101356, 0.1328758820290527, 0.22305486483439324, 0.1681431226672665, 0.11582467239350082, 0.14076153146884135], [0.04656089349619804, 0.03441854545305814, 0.05291921642398643, 0.026122309275031574, 0.08881578297023812, 0.0411480533019189, 0.022713072455277847, 0.03598672743406027, 0.05103554411400711, 0.050292423505696564, 0.09034615085129777, 0.0060609716456383475, 0.038262717200503234, 0.08459803227695727, 0.04051628740384214, 0.05063258186583558, 0.03131749431392358, 0.05271629888504263, 0.04770829019347026, 0.07469803890994481, 0.06050968835611017, 0.06345638810026069, 0.09212496870708081, 0.012607839345301112, 0.05437512438924563, 0.08974917683630221, 0.03327199145250263, 0.03726470764846571, 0.1370795137218891, 0.04364601704442213, 0.039085840370746396, 0.04721497936594871, 0.008343452092019782, 0.0599237728203016, 0.007884707630446722, 0.046767369513550115, 0.04640563045658412, 0.056951336352334875, 0.04874694837077011, 0.02687703994583459, 0.021753855680506078, 0.03973934784411423, 0.05985159584651551, 0.028366621305805542, 0.01127359763373651, 0.04154966340490407, 0.024801853315664396, 0.03891020705322585, 0.029540710421579502, 0.050125427829522284, 0.014894539978535426, 0.04927114403295902, 0.08273160460615352, 0.006407713573876649, 0.02348895864410987, 0.01348558362693556, 0.012731367192651718, 0.05607188273701937, 0.03995171507760402, 0.05044066534948446, 0.03928954314981257, 0.06291246950446118, 0.11547639350136442, 0.03478893747312888, 0.05238723730848682, 0.05121266747254038, 0.038202682720316995, 0.07269950703747811, 0.031052104219974532, 0.11241555048693573, 0.04772055526113799, 0.012593186956139342, 0.03310918627727417, 0.019534671333648508, 0.01486804003962466, 0.005082139668370327, 0.050808663344791824, 0.012911841228243806, 0.08681126795108281, 0.061803675977693456, 0.0678222848763389, 0.1506492444464276, 0.05218736113860242, 0.029444790467800155, 0.05084132550344352, 0.024551340649204872, 0.03095365809126487, 0.023246013011122425, 0.11027073412532769, 0.07938725543358634, 0.03782720770686865, 0.04967459274696247, 0.07778339673795047, 0.05548620468846733, 0.1436021242050394, 0.030405010817752733, 0.060822118163829854, 0.042412420133909876, 0.018993445536902836, 0.033506054296008045, 0.05551705887961773, 0.01844881256411393, 0.033020423499927405, 0.04804547996290269, 0.0827472787650843, 0.03411351988512663, 0.11192702387850131, 0.04786603152751923, 0.03433512230854362, 0.025051642029035478, 0.058094569361738624, 0.018725188358897166, 0.01543932425368938, 0.015828014283831564, 0.0925426168607608, 0.03778172889724374, 0.033828776494990435, 0.026049873746571042, 0.02603929215711692, 0.019015167959995808, 0.03804052871982417, 0.03518035477628151, 0.04325181884210437, 0.06133773747170645, 0.042508188785324176, 0.07096401911469237, 0.051794074580914555, 0.04794009690803867, 0.027023489143879666, 0.02857821670571162, 0.01733565616661743, 0.013883750164701093, 0.043078863001879186, 0.03712627173010861, 0.0802334301894711, 0.04182349387255888, 0.029308313819309397, 0.07314596009711105, 0.05783652413576361, 0.019048939030917904, 0.06574057883793308, 0.027594058023345087, 0.025243052927356575, 0.05852668508586865, 0.007824544351728214, 0.05372463913273908, 0.11206301980681958, 0.03942319484908254, 0.02054687649492295, 0.017439495554314028, 0.08966145210809286, 0.05620127115699072, 0.0682887404916748, 0.023073842411019632, 0.0241502859599648, 0.014613604045382913, 0.06337074713120538, 0.037733224040317925, 0.03887659877598767, 0.04971660500873001, 0.0692120066753799, 0.06345349611834654, 0.02249365721288468, 0.03235402276679393, 0.0076640010510961865, 0.06120403214628178, 0.06201675184251321, 0.047113292685319344, 0.05692502123213584, 0.04091366870148529, 0.03752421227193648, 0.0611275612496801, 0.06920596990253657, 0.03402856073432392, 0.08394641321032278, 0.051825319476906336, 0.03301986425574268, 0.027977444809831442, 0.035013401234943065, 0.03723606362097687, 0.07284909336557312, 0.033756526742851546, 0.04055294471101896, 0.03779325469006454, 0.05799557164972348, 0.01883765772706078, 0.07692720921289536, 0.040727091817966396, 0.03507008408046058, 0.0809045078893823, 0.031361753128529075, 0.043987585006341826, 0.009080368345753561, 0.022398733173406894, 0.013505066200459917, 0.09564805385326186, 0.028333681440281294, 0.03734206337661993, 0.042043617746282014, 0.04623885694590788, 0.012149255283387199, 0.05213433636292335, 0.03488217420395344, 0.04617833599988972, 0.07503675702478617, 0.030838128201843753, 0.020063626317067013, 0.047442361922754396, 0.04796210278366362, 0.027537043844800324, 0.014948778045964579, 0.06399777477547046, 0.01831074245274067, 0.03836012911051512, 0.06804307141611654, 0.01738203895999299, 0.015654625603929162, 0.02829142211515817, 0.060351529504142465, 0.02825396424610048, 0.06250227921672406, 0.06526738930974277, 0.017578054046739015, 0.0555793724713787, 0.038046684236295765, 0.049422473211081765, 0.041422837549039436, 0.012585015670816987, 0.010767001883998033, 0.025534978391782894, 0.06357995808244714, 0.07514873609667824, 0.04708587822894897, 0.017762347988243547, 0.01855607444961225, 0.038255531295773484, 0.05400731025504009, 0.035088994960871436, 0.04191015756899311, 0.010096513114178614, 0.027048666623511144, 0.048080375267853664, 0.03433760060297866, 0.08070001603975412, 0.022573433778879624, 0.03687279238816231, 0.04908370530052532, 0.11344141882633972, 0.022940387979390162, 0.007989856070883932, 0.039172500236741, 0.07320160106305154, 0.0373635329906979, 0.0502657981198882, 0.013044712475440916, 0.07778872870990346, 0.08746130121571404, 0.04816502798348666, 0.04662407659775308, 0.037678088692407456, 0.07679616987344719, 0.04881487355657643, 0.021208690276609796, 0.04785783055628981, 0.016076228686518246, 0.09459667478597934, 0.049731256440281875, 0.03576706704353133, 0.07770547793517191, 0.007805959058685169, 0.03349397691988176, 0.0529505494200895, 0.05299671770884626, 0.039061888631793766, 0.01779958177658339, 0.051247279324959365, 0.06471794338956957, 0.03507137110817336, 0.05984478915530828, 0.018978447450565237, 0.07084808702911101, 0.030885110459020062, 0.07540848586828479, 0.022638850026733937, 0.04186639096587897, 0.015594400559371759, 0.0689389116521324, 0.05089118633599532, 0.04093179817221338, 0.029507473696984594, 0.11571906717313875, 0.022301681324719422, 0.024933756419247197, 0.06662652121796724, 0.038855052553117275, 0.05858137610278303, 0.042671763878916545, 0.049327727287046375, 0.047556715867211746, 0.010674485275822302, 0.07057491539707107, 0.04353574251816158, 0.06572478976581367, 0.02539593917918542, 0.03669206075550568, 0.0203707586267903, 0.08058293482228633, 0.024218801033472823, 0.058235816822777835, 0.01959996117699531, 0.04583258136746384, 0.036142940422700304, 0.05498560836478587, 0.033679017797112465, 0.008918590685953538, 0.05530346973588871, 0.08459298375753627, 0.06268801723396586, 0.061852517913305954, 0.039153328886435884, 0.034040695567044525, 0.02928111195233801, 0.038733830630418756, 0.06057394781119882, 0.052234598120013555, 0.00490827888678459, 0.06518239951542308, 0.016786600951285615, 0.021936282282695178, 0.06480427383775673, 0.017133410869827195, 0.0256599024343755, 0.018790633335048636, 0.028057914685397863, 0.018523310784310586, 0.01623539302888657, 0.020552601086937135, 0.04879472927460748, 0.014734506126373045, 0.05731891682972351, 0.03681159345433116, 0.015724558897707012, 0.035913623493885806, 0.03247663513907502, 0.08475086681785123, 0.006128132658740205, 0.0544767574437203, 0.031531108355510144, 0.051905023264548475, 0.04553337423731724, 0.06966395258542991, 0.042656794520876104, 0.10928642605581593, 0.1619238983238897, 0.08378328244772651, 0.1241719893990986, 0.20133484725750264, 0.16800082949621065, 0.08665114791402895, 0.0999834756517122, 0.25276409161667673, 0.10282779157522226, 0.17954946705891242, 0.11397963389754297, 0.13426659208151603, 0.15342894851440383, 0.08511783059446082, 0.1641457524871634, 0.12944534030412475, 0.09928328661067833, 0.18815678664513175, 0.20774996028311793, 0.09014187350628838, 0.14369927947559666, 0.18757776207020208, 0.11516504770805759, 0.2850898150955477, 0.13114649982702348, 0.10004702264503126, 0.15266957152034008, 0.24417623066373412, 0.08075505945711367, 0.142010806368724, 0.18705473852253732, 0.15458189551868748, 0.12475502061387225, 0.081692720432916, 0.1358000396360313, 0.1264369436689923, 0.1451339323313967, 0.16495322448111352, 0.11644742526714841, 0.20289852464151, 0.21173274414914273, 0.08326703877819162, 0.12917509512795558, 0.11001610948193459, 0.16511897526441083, 0.050696408481247006, 0.10390268188090095, 0.20169205873483614, 0.1115815335464093, 0.10895687035254895, 0.15835535352028188, 0.15930582348617817, 0.09488304611295463, 0.1455670478002679, 0.18602856374796362, 0.07640110599177499, 0.1223160801154952, 0.13134758258538862, 0.19216111290358728, 0.12541353447182527, 0.11355070126873833, 0.2755617650766527, 0.13010524844209995, 0.1917715418723322, 0.2444307097504216, 0.1360426903251679, 0.1706059268044849, 0.09878930545622304, 0.23395713869362111, 0.11908990766612754, 0.22844269991882388, 0.09669240023339949, 0.0937112533457337, 0.10822905618096552, 0.28910246106886095, 0.15872577235342997, 0.10565981178754762, 0.22194682590423093, 0.13904894191411235, 0.21928067138839155, 0.1662757220647989, 0.12359475746991173, 0.12566488791978167, 0.17151827623526897, 0.1549203531636346, 0.12301137385469292, 0.13441731221973896, 0.18292884943225693, 0.20144015370357424, 0.14050581131971654, 0.15104161935948557, 0.24962602693948055, 0.1287764382939185, 0.23318473820484456, 0.22785371620087858, 0.24650354449066425, 0.12398077385319818, 0.10099181589940864, 0.11726441207311808, 0.35605575709093007, 0.1873937630725484, 0.1709493793426983, 0.12132753557976216, 0.24662772734319013, 0.1608103588824311, 0.1954707659540638, 0.1281143468053591, 0.20415334601796445, 0.17050469594617046, 0.12250483651915867, 0.1618539544964029, 0.11394006545625388, 0.1557396382333771, 0.23180093826545825, 0.17452123364613903, 0.12972111663510724, 0.2690037153661251, 0.10234619040162334, 0.1999835447678643, 0.09223431243651337, 0.21872519635625426, 0.1548690405944663, 0.10990614522128336, 0.1317653916175327, 0.10931016712058937, 0.09151162339314338, 0.1083337497566977, 0.1471864810634044, 0.15747369357174443, 0.20744925545107937, 0.090338459328538, 0.19275896791969577, 0.14007353854756202, 0.18118641309199796, 0.15631664033618667, 0.19100618939245903, 0.18646334928850974, 0.14234273694455624, 0.2646530407571024, 0.14599702230864955, 0.103985411715844, 0.1884347233440607, 0.20518753407222612, 0.1290512187105994, 0.11666767554537905, 0.4168521270396248, 0.14883919318597164, 0.17787305217596794, 0.08994366357763929, 0.21312239700027052, 0.11617926385013327, 0.1868337221563824, 0.14080697580450965, 0.1102470773302259, 0.07911308788724485, 0.17638481913074372, 0.12903755170203027, 0.14842000519556386, 0.12114976487693288, 0.1939973950145706, 0.09184726183452914, 0.1407835181922682, 0.13189841512470477, 0.14047075513630145, 0.15472429594205273, 0.18093846107442535, 0.14474639909402018, 0.1883011942188586, 0.12336797246168699, 0.1126466332484157, 0.17829568756203498, 0.23489512142635163, 0.17047157030432455, 0.17892967128465254, 0.09914012009938879], [0.021808288142746015, 0.012961915607804493, 0.03295960377961878, 0.05582228363040955, 0.023507180045388883, 0.08652719488788037, 0.035041018704613375, 0.016124091944807482, 0.08284053464810695, 0.040765978441002874, 0.059202945370587616, 0.02108721362967645, 0.03805753204130358, 0.08315331302583219, 0.033584268042637457, 0.01439325609094193, 0.020895806561794975, 0.04672285980514942, 0.05835873946066826, 0.01247992181414438, 0.020982615814934817, 0.07640719639077302, 0.06038076724977263, 0.00802874460914022, 0.03071170262691956, 0.008761448815705316, 0.03168851452609224, 0.0807497504677984, 0.04688741549128487, 0.01495192283689375, 0.05004389692218073, 0.046014435318929535, 0.020644569942247004, 0.02070890792134789, 0.049842415798094966, 0.0596220605826426, 0.004735031454343229, 0.03503200951062384, 0.008097238136425374, 0.046879168554779985, 0.03235585754737258, 0.06027296335706788, 0.12564317698800756, 0.044155431040112054, 0.025624024621661634, 0.06662599261729948, 0.033909365114185124, 0.03524251515045762, 0.05466801895489616, 0.013289662385960261, 0.0777243773242639, 0.047648401269989635, 0.007269241210568937, 0.044786285293558915, 0.047976968719834284, 0.014775202632130635, 0.09741494372006386, 0.05028662422010976, 0.036144403650635676, 0.03684838099645511, 0.06072395548765218, 0.03462382637324833, 0.02687130577772135, 0.034749422657994494, 0.05109604590782716, 0.038074979693779064, 0.03718198930484153, 0.026393571432920235, 0.05439499287956184, 0.05534024578669379, 0.0257787762975861, 0.04757847276426131, 0.062470762359519164, 0.03214522550303129, 0.08153777915023028, 0.022941627126607685, 0.036996588366286415, 0.04275568881102147, 0.03862935538974501, 0.02123861367093219, 0.038563196036604144, 0.03572835279027781, 0.04792283694710463, 0.022909865121267015, 0.036885015320994204, 0.024316498311236504, 0.04110139088645097, 0.02847988932063022, 0.041890055421859994, 0.037853032530796145, 0.03025570985740952, 0.04229813130692609, 0.07954570539896527, 0.05299733057918568, 0.04780816890659833, 0.05192376943605562, 0.010737022948301127, 0.03921045606294948, 0.012963278286699808, 0.018649180945489677, 0.027870634916208448, 0.037248416788755886, 0.027043041622927113, 0.0064254959110140565, 0.01700887944729578, 0.019621174151618636, 0.05765243703799863, 0.04781070465762769, 0.014552656005346968, 0.06546661813533114, 0.06999584485686595, 0.022998545544161912, 0.03466279726595648, 0.03992399418606393, 0.07879225026455619, 0.04982602151651537, 0.06822536969857831, 0.0962961029501692, 0.052743812932843165, 0.05907208606180164, 0.09741292124794376, 0.058151799960122, 0.09861985446825143, 0.033249640837311745, 0.03253327201931708, 0.02547340024442923, 0.03646586946542225, 0.04468107460847786, 0.021343042946330482, 0.01734688126992795, 0.036416556385736314, 0.09101722089032974, 0.05207735091267575, 0.03496038412014323, 0.04096487401834419, 0.05371836870307884, 0.01436943841737605, 0.0196873335047595, 0.023620091829328768, 0.01990948942670178, 0.04859942281919141, 0.029140599935706106, 0.05851401782204067, 0.0254491976116814, 0.007297411699959588, 0.01758631630500238, 0.027733463042926405, 0.02126554932234989, 0.05715128530057208, 0.008083550060438293, 0.052049541921024366, 0.01090488717665956, 0.01064642922081534, 0.01950345899639351, 0.04553200293993277, 0.04399010160517308, 0.03589447895665804, 0.04588675144458971, 0.02486691716307354, 0.062067168088810104, 0.016256602173070275, 0.023546091566282897, 0.09060608448400613, 0.035470299903423555, 0.033738826281361045, 0.010496167777737063, 0.02043768406785544, 0.05351393047960536, 0.031156489445317178, 0.07623884856941239, 0.03158593152259146, 0.049816682904718385, 0.07195290838999134, 0.04767922864806268, 0.04853023741874964, 0.07786406579637721, 0.048253051485986485, 0.03760735579435864, 0.015260268438367114, 0.05080931068908784, 0.02949006626412513, 0.08346724053544384, 0.0773471403085897, 0.03396642334278553, 0.023771943862459833, 0.05651074769576231, 0.023858590321915767, 0.03650905767215356, 0.0691787891029831, 0.043508611514323184, 0.03619545191947011, 0.010292244748392654, 0.024141642572959105, 0.045266913535494, 0.04591265670774926, 0.021551870853610097, 0.05685694282874466, 0.020984841300354853, 0.07134768360805127, 0.030126187372051423, 0.028046308453345013, 0.005011041442142619, 0.03255995486171977, 0.02245968121344284, 0.05062212859610877, 0.06754738954646934, 0.09565268102432452, 0.03507177713477323, 0.02440506573616257, 0.021861636590573098, 0.0334083627639038, 0.07788449736131776, 0.037664915810549454, 0.010169102817833906, 0.04118464549162215, 0.031397943122072086, 0.04386709469761099, 0.032954915321522185, 0.05491510912355396, 0.04536512983782638, 0.025856448037009087, 0.014164729190299348, 0.018563923020396503, 0.0923921188880359, 0.01530080502327051, 0.06549140107968161, 0.02379950962119526, 0.05767112958335108, 0.0170656886973208, 0.05514870465342557, 0.013726830459950913, 0.03750978683632228, 0.014423295356062873, 0.046723465014609604, 0.058594751997940966, 0.019303887346459013, 0.03644444964705937, 0.0524445943113777, 0.030087794875726107, 0.02059432798095288, 0.02242210460075688, 0.03281315841201333, 0.008097053317713642, 0.0389196299346945, 0.02361572704338018, 0.07003355170449904, 0.056124788769070184, 0.029364496792456316, 0.05755194545453114, 0.03907589654948923, 0.06430472322409192, 0.04680259423630853, 0.03363767586227867, 0.008651950911078002, 0.06884552553416261, 0.009164987545039867, 0.023021733110410073, 0.02054952715914096, 0.03397381992169446, 0.0070172734558582315, 0.01732962705465334, 0.05590473767369986, 0.052338498794744094, 0.027729314676816427, 0.012718765046297303, 0.015542943391107745, 0.018808487014123992, 0.03810946514169055, 0.07497229838683721, 0.007849210946475187, 0.040230858365013715, 0.01649930074270214, 0.03412260951834821, 0.016252147371790582, 0.08231279965970786, 0.026913436783117153, 0.05722269235599426, 0.0530081439102369, 0.012066049516321191, 0.02951795952544818, 0.07415915734224743, 0.0334958806483736, 0.02210891445077235, 0.037208384864272616, 0.03634232246587354, 0.091524800105441, 0.03069562818704834, 0.023384910497453906, 0.02834793642133234, 0.07875528652220964, 0.13306254701268289, 0.03872917664627876, 0.018553504224626288, 0.05758055883850302, 0.06891585240561156, 0.07199888132632741, 0.04609218941280439, 0.07288730583123623, 0.07630661670719424, 0.004281548101590166, 0.003111600409254372, 0.02492955634220233, 0.05978619492041969, 0.07513744396067436, 0.040196043499294794, 0.005348252278992967, 0.06270576366073181, 0.05740372659338098, 0.037041009974575816, 0.028135387241960536, 0.022816061485378493, 0.03579563829266737, 0.009488630007141301, 0.03690509831592922, 0.0348625700139711, 0.05420279291067874, 0.042235894323957544, 0.003445348289284495, 0.03786357007019463, 0.029635808746060057, 0.023394388920297066, 0.019742589511518038, 0.011908070695015692, 0.03707218209221479, 0.011468549773487593, 0.03679326097030313, 0.07585105486214161, 0.004706119774885837, 0.012613111945439973, 0.019180405464383866, 0.04616646163706337, 0.06216596661796493, 0.013418319191963924, 0.039085116417657946, 0.08111184958608882, 0.07400842954314525, 0.045467663045612075, 0.045196916081852494, 0.022636563254279957, 0.03777517884549114, 0.07581507171233816, 0.006556328885527629, 0.07135611823609761, 0.022597314654699257, 0.07546051089922268, 0.08932195258356872, 0.017691262689749562, 0.03076456843935434, 0.029189552954067628, 0.07690406569670286, 0.05155567184931809, 0.015841123963435812, 0.09627778578789965, 0.1460187179186652, 0.20876586947950626, 0.19477969335932888, 0.12617472709426958, 0.21427088537283484, 0.1397677009264308, 0.090135361758932, 0.24850413713964725, 0.07412347296673445, 0.16214209548648328, 0.19413374334333405, 0.16363446540649862, 0.13811618390102542, 0.12039834753640237, 0.1160947413694474, 0.11183280272469406, 0.20089168071506486, 0.20922584399100275, 0.13945440160891703, 0.12400484433577907, 0.1832364643773725, 0.13547221529147319, 0.23342740421573963, 0.09432978507491852, 0.16868859259111268, 0.09043302522191117, 0.15632457700708222, 0.13994488174155836, 0.09708297483983541, 0.24610769153843004, 0.18657441671577193, 0.08735252439134544, 0.14043606667509004, 0.15378006193186008, 0.12308268131868494, 0.14908706859475182, 0.09460313290718103, 0.10606236800911928, 0.13752519303271848, 0.12742233958335655, 0.11681835737920578, 0.19382048999109577, 0.18547477410925975, 0.1823776951360126, 0.19336258391699485, 0.11546850279574433, 0.2689491392623994, 0.15501231435806523, 0.06927089585411934, 0.1347882366709171, 0.10954188573504649, 0.12392573809671788, 0.15147111889335418, 0.18337322639361506, 0.09523910079752246, 0.23567902855575087, 0.17596370059876673, 0.208585700921474, 0.14200138348725536, 0.15261551635640283, 0.1279987671202229, 0.10452838419305702, 0.09998978821620827, 0.07324377420328318, 0.12820295253468136, 0.04595311764147013, 0.09271674098507052, 0.11972078873265175, 0.21533524196955467, 0.09828512001061633, 0.1325601159084228, 0.1222977552923464, 0.06612841851047932, 0.19186537232129805, 0.06421210702448603, 0.14301084222332125, 0.1375759693403398, 0.18481440631852997, 0.129341259598732, 0.08204951822277039, 0.12503494914140434, 0.10463777388776503, 0.21022358158182716, 0.19151352345943454, 0.17165627931394886, 0.20213186981216555, 0.09184813517476283, 0.0985642594675864, 0.14277491778615983, 0.12530652731056177, 0.16266605366141568, 0.1674358243302953, 0.1956774258325177, 0.09999876676668083, 0.1335570874113229, 0.12287939988797712, 0.1818806572907394, 0.11847339840906283, 0.13221272567827858, 0.07788804434840718, 0.12666801876959302, 0.07673961726287681, 0.20821469986150343, 0.13591593341721644, 0.09267916437238456, 0.11501844146198804, 0.1317160095899336, 0.13483766466379166, 0.15943869377576536, 0.15955461820046749, 0.14183858980334577, 0.17303808742473203, 0.3478503119080298, 0.292804412423603, 0.17231119255865776, 0.11814845455510002, 0.1535903938835667, 0.2226145481390338, 0.19968302379692757, 0.1595118245290172, 0.29657929534873656, 0.2745012848848297, 0.11084859424661245, 0.12249231098159669, 0.13420866051268193, 0.19414788532641628, 0.14548231847584248, 0.16917700428635846, 0.05016989157264752, 0.19470398855065146, 0.12117165200892957, 0.07697591708312113, 0.15989512896105168, 0.11645022148807203, 0.1693420962340409, 0.11537563761756306, 0.13249501375661743, 0.15706199792123612, 0.12297428753827849, 0.10539600174994239, 0.11739809441590503, 0.2186111105425704, 0.14007168461478528, 0.20959569591908686, 0.11626751717901039, 0.18481558609393337, 0.11959291333633086, 0.13720018789172173, 0.12797858836429735, 0.17315287803930624, 0.1374365873033962, 0.0740641701005159, 0.08008118553627884, 0.13270643870196036, 0.1760558456542992, 0.11831932280573154, 0.14983786540406366, 0.24549546471286207, 0.14988985213060535, 0.11777632734588078, 0.08464382135219152, 0.27760881329736403, 0.17515032972779968, 0.19117809952266757, 0.1237750639237704, 0.16618167711121423, 0.14790913180237816, 0.13617061168676423, 0.17123868478642357, 0.12620663465631585, 0.21766932801373545, 0.13943702673479436, 0.1498361187235963, 0.2652320806537905, 0.1757098956694526], [0.04529514004506412, 0.017322536910914125, 0.011390285273533196, 0.01984322473647133, 0.06786831143882967, 0.07087661614341122, 0.04820834259472547, 0.08755055811977194, 0.04799963343107412, 0.029957063886667454, 0.020035200624636585, 0.0022344606188726764, 0.048821400625691305, 0.06277512526139617, 0.06348946011595188, 0.007167123605482161, 0.028556783480810064, 0.03213709731015467, 0.09337271909199416, 0.03898047263764086, 0.026902020157825564, 0.058586056900000384, 0.03135010859208002, 0.020253683154981945, 0.045987062997394995, 0.016595218781261675, 0.012946601510198127, 0.01935487624347931, 0.027836088181263017, 0.11098788435300512, 0.02351663165515469, 0.0007508602509680656, 0.024585678625190933, 0.06246102921244118, 0.008788667919655001, 0.04239968009172909, 0.03156432592790694, 0.061265748189461816, 0.028781059551082795, 0.03809815002304893, 0.03102529688828415, 0.03132922503526413, 0.08937749395807905, 0.05225838131962284, 0.038892839839982415, 0.015874793527707938, 0.027163227411708044, 0.032078411144715165, 0.04894209777816169, 0.03424901019541487, 0.038226718728941296, 0.051543035229007085, 0.0446810822693571, 0.05821739240819889, 0.04346588296034644, 0.05214488539364069, 0.013313720419612384, 0.07308526295087031, 0.03380996137557011, 0.06037198022128113, 0.056550178241225026, 0.050449869895894686, 0.035729126539081335, 0.010623206223000684, 0.027155436297518112, 0.0720593716288286, 0.011477901791823248, 0.012161496410807295, 0.0652886405887623, 0.04167850024156994, 0.01531947745881494, 0.03650683984761277, 0.043694292074970664, 0.041062730259352156, 0.051984577665045384, 0.019054927923265966, 0.021228246586096865, 0.006665147365927096, 0.08210461526628464, 0.03014611523418177, 0.08224142324780265, 0.04149921268465058, 0.04820182701692947, 0.01838336567274265, 0.03144641542026112, 0.04903763277275909, 0.02541093535030321, 0.04551653179430193, 0.03901583908666526, 0.02374062618811525, 0.008421950248791086, 0.041360861035965146, 0.033640280561221224, 0.04346904690347372, 0.03523106979686887, 0.027920334870296142, 0.012063125933280155, 0.04638069812508841, 0.0610991049137327, 0.0763480237595016, 0.09675240023962914, 0.01353056830984931, 0.09209794878599145, 0.04997915100126017, 0.02960174847694655, 0.03798052871359452, 0.08828202653075419, 0.018710161544262402, 0.008873142519845598, 0.05457343007888525, 0.03150439103915086, 0.011360643416522972, 0.03658451350225556, 0.019154816212493087, 0.04795030119919008, 0.07112593179748905, 0.04381621879855952, 0.024911436447573286, 0.0594528240992898, 0.037470409917014266, 0.09208290281915858, 0.03291016046498572, 0.058844795435546875, 0.05823571723134768, 0.027274250788914583, 0.04872049918518432, 0.04476539790630341, 0.07273061786808314, 0.06586295372295765, 0.06720560707993085, 0.012879651171275446, 0.09191921281237757, 0.014634739453603905, 0.022269381142611948, 0.0264717047403176, 0.01996877888638166, 0.06581797670092314, 0.06392809524831754, 0.025607879318657423, 0.0756483096929808, 0.00901169813944087, 0.00409131171181798, 0.08059979641749974, 0.09403112569763776, 0.034274923119453654, 0.03471804369661597, 0.033575239696449814, 0.05479360374832346, 0.07711307746508429, 0.09965794957092694, 0.06635203957557678, 0.016520335601883072, 0.08937609967805686, 0.035541722280604225, 0.045774711085663694, 0.07841998515951057, 0.019511102638658018, 0.024230029967222965, 0.08145349415680093, 0.005676816377202951, 0.03043889871708328, 0.0984821118594658, 0.009652523027222243, 0.018137646801469308, 0.06055078897324782, 0.020300684564356363, 0.0665873204988818, 0.08158316219886465, 0.0476993844213505, 0.0669475733452747, 0.061459733143208496, 0.024254703744044228, 0.03481264023350612, 0.06573293328044877, 0.0442273513744435, 0.06951554603273831, 0.10136857794056978, 0.017057453252134785, 0.035184173724584045, 0.018947139352319703, 0.008210805883150428, 0.06532199605698548, 0.0010539959757513697, 0.04395060211179718, 0.031954519405600526, 0.03515609277171954, 0.030728324819656632, 0.015650454255181457, 0.06210346533466251, 0.03819643144285487, 0.07758952286695281, 0.0346597942012933, 0.008649110640098732, 0.037067263807740905, 0.024992358315015034, 0.06332136127316663, 0.04369927164647849, 0.03031022467410132, 0.07245884051606541, 0.04786091022974542, 0.03260694286455551, 0.05892750611829181, 0.020401620478819937, 0.006076910583707955, 0.019919942696428588, 0.012900690818505903, 0.021490043727681044, 0.03500008662681907, 0.016573023298875462, 0.039542762021864616, 0.07579556711378597, 0.039805465062419255, 0.04513325800578441, 0.015835996920002565, 0.006155491094931119, 0.026881563695027467, 0.020133503111860445, 0.017336768909327446, 0.020276493422927398, 0.01494082318048083, 0.04365865749517276, 0.013692354588138481, 0.024165684327242837, 0.024651184888376344, 0.035162573875558954, 0.040793975124195705, 0.02801407147349129, 0.05661963943331953, 0.011835104650667599, 0.046315408281741605, 0.07566604462842788, 0.01527921187751476, 0.03097924542793584, 0.036418559705658306, 0.0380151022616173, 0.040135568518552094, 0.0870065437629819, 0.03387426296549459, 0.03278339206571541, 0.038189494516700506, 0.05156883707029685, 0.03633073155557917, 0.03430377782112168, 0.11772909036446964, 0.042430798583213365, 0.03648630486080243, 0.19012691963824535, 0.01789513017771946, 0.004257273169294481, 0.0311776832677424, 0.06069289445276223, 0.0646631297985873, 0.008011973986867815, 0.03835288957963067, 0.04988106493387492, 0.04453246887292593, 0.03641387507800133, 0.06747691711831479, 0.013042529124856718, 0.07931684429246573, 0.10490192866493618, 0.11412404913214907, 0.004962695069656137, 0.026373959582058654, 0.03253743953762516, 0.10389947197249821, 0.013452313385993965, 0.05752452716772115, 0.030296295280418092, 0.05554510535852564, 0.06980373298809414, 0.020389592898408734, 0.06348636512073778, 0.05334589675429368, 0.039159986190497875, 0.011722070292659826, 0.008709585620841433, 0.0390665311246149, 0.08592768512185543, 0.03359562912655454, 0.042771998822929404, 0.05993269774461946, 0.04797635967993448, 0.04383681124196418, 0.05454624544889216, 0.005379831380841713, 0.09930362624506797, 0.050223471762071696, 0.025632633534710736, 0.03468088077140912, 0.07894152249660223, 0.11772350558350164, 0.0207557465370384, 0.019280065842453512, 0.09082037459818587, 0.02017465160949336, 0.06990711655347578, 0.03492734274796901, 0.03427006612201372, 0.03473768619099452, 0.030187861280395623, 0.08867670736846425, 0.02195109842315076, 0.03893898897654107, 0.0618968207779671, 0.03982673932407652, 0.029668518785207026, 0.0709346013384, 0.037237503866274516, 0.02946731536799381, 0.07395004598243583, 0.02325593959540129, 0.03981631286742707, 0.08819075481545541, 0.034341863882277286, 0.04775351619408016, 0.06790561225986289, 0.020028522253156673, 0.025069641264816447, 0.01600290449606555, 0.07875741624663915, 0.038652678936599724, 0.009373504229100242, 0.029855522762743697, 0.08471101492403016, 0.023148989890732115, 0.042187312858239304, 0.03685594228426776, 0.06138877041878239, 0.03207962539407515, 0.009606205351320247, 0.04119845039601769, 0.030735815244336284, 0.040077813149940585, 0.08317641823762849, 0.034405364910320896, 0.017117206195008852, 0.00972295523576078, 0.0308718015965555, 0.02102626942008013, 0.09989942814553938, 0.014588637239930612, 0.10230159642355097, 0.068835788556645, 0.03001209198226852, 0.026374375184757576, 0.039266146824605046, 0.035243691095421394, 0.05108448181061014, 0.03818600881664503, 0.06421720917006174, 0.059174381782330816, 0.27853691349587134, 0.11257304284240931, 0.28655647510482424, 0.15700582835462787, 0.14651437680567467, 0.1285427355117375, 0.09668738235749545, 0.1930422519123362, 0.1334376543039276, 0.11870932284622424, 0.10448723761064392, 0.1311087929793904, 0.14474204771461027, 0.19262067372760466, 0.1296520308260956, 0.13872910020572526, 0.14747855974541557, 0.1357230477996411, 0.21705233612127844, 0.2811715817980228, 0.12719817459583282, 0.27038567669449315, 0.09632398088973376, 0.1712065090936038, 0.11916805629528339, 0.1096280093394941, 0.08163717905840567, 0.2109480709318192, 0.1444984164329306, 0.18665278751042583, 0.09781866439528043, 0.14048290529078053, 0.10566878267714094, 0.15362967887232382, 0.16044039970203755, 0.08105787869182327, 0.18504973320711046, 0.14980768153984703, 0.13761902348168437, 0.12476616719317053, 0.1214465243561614, 0.09727812041678736, 0.23607862001705557, 0.11230458265110371, 0.2063592655524131, 0.11103039457192344, 0.06901255568429347, 0.09466671054401705, 0.1544611447400624, 0.14010470300432176, 0.13541357892174877, 0.13330012619976075, 0.1034942574258293, 0.10967965898734909, 0.1385603003924893, 0.1319588594619305, 0.1534108994829078, 0.18716482535725643, 0.09709269649559453, 0.11334430952105792, 0.2513886267139066, 0.1527396838871702, 0.09086568869890706, 0.0973964426966925, 0.230461785930299, 0.2613218453141951, 0.17766990098020724, 0.16901175912109115, 0.2216963304747497, 0.0892912018142881, 0.304485384014345, 0.12178233133689051, 0.08283997540392223, 0.1582541686272429, 0.11210406679780253, 0.10842292239108395, 0.17721501329252798, 0.10510853491723539, 0.11390605881329506, 0.12304757916999441, 0.1310733231084962, 0.11503623768446908, 0.10981885716319086, 0.19260234890445588, 0.1792447632479091, 0.19935480108664883, 0.1348534767185488, 0.12946777135854767, 0.1349242785645108, 0.18624038705902715, 0.1536492907231854, 0.12788702553558734, 0.11478396493100351, 0.15874133926005135, 0.14760599081074038, 0.2057308742716428, 0.1138862707622109, 0.13764998875558376, 0.25958518527688523, 0.11284261386120513, 0.16009745278185414, 0.12298430796832809, 0.14785840146003232, 0.11499294605586799, 0.16597463418879818, 0.1800568317694049, 0.13554485574845346, 0.1573507671034144, 0.12157292886366769, 0.10431562625472585, 0.24806539858541182, 0.11541674589557994, 0.11767205511850697, 0.13408777183823048, 0.1842104838860612, 0.1880724097211515, 0.1313620922906745, 0.21104337226959968, 0.2308189207988401, 0.11870068137443836, 0.15442605791313035, 0.18073219956169206, 0.07542603694263005, 0.1037362646011095, 0.17343348072421166, 0.13421921720427854, 0.08158952072863618, 0.24813404006342737, 0.21960144772404627, 0.1671638937606927, 0.10402301897204692, 0.21739902155053234, 0.18793097456857083, 0.13688095905367406, 0.1595734486416463, 0.07122137103109591, 0.15294505673791134, 0.17616896619719846, 0.1026950898249784, 0.23226739388079415, 0.20635217157823427, 0.08499178614827894, 0.14492502015444542, 0.1791289001102409, 0.1699288429752473, 0.09219649067569165, 0.11862437901718002, 0.0884315592326945, 0.11975286483404138, 0.2513769821774575, 0.20454380571121172, 0.1456630999042142, 0.2385774609302321, 0.11416521103632067, 0.1164315136209611, 0.19863473972485912, 0.0922797414504232, 0.11058262384106075, 0.18298423758918242, 0.08101494712454659, 0.10021880254029267, 0.27371184660061715, 0.1253344358936433, 0.15423473511492053, 0.21679595713653874, 0.10977304510531888, 0.16406519068104608, 0.2055052613779422, 0.14473069429157243, 0.11371301231725563, 0.27627842500805855, 0.13395183719694614, 0.18512841043693407, 0.2701405285587234, 0.17713091216020047, 0.2305736807325194], [0.06851574766539759, 0.006002558399021867, 0.026190736248428305, 0.02096161542971048, 0.02717526265299849, 0.043756452449146784, 0.03690241700819424, 0.010907225660048427, 0.01383191186769475, 0.05092789726932684, 0.05766786604879364, 0.05836502138164736, 0.08515328514359652, 0.028750848873788794, 0.04371625581575979, 0.06102352267912319, 0.1101726059231066, 0.05254137036841243, 0.03886433370831994, 0.030219663505352316, 0.006719125921071898, 0.007866459416090361, 0.04016852945149426, 0.018749413974282723, 0.025172582414421826, 0.019279370617662227, 0.004855428874913243, 0.06279150422121729, 0.017046773986470316, 0.07215337827801704, 0.05527145492153303, 0.028154005093740362, 0.04926465909867998, 0.05143393281727068, 0.042488936995787006, 0.05981859277873751, 0.047756879320067745, 0.0371647484961056, 0.02584235393442214, 0.02835896425700236, 0.016118139441635822, 0.056549477270774307, 0.011817418553325678, 0.04515801413705753, 0.10540453596941887, 0.06167532943729913, 0.047818457467421416, 0.012518768217564832, 0.015604100190103056, 0.06325459671056559, 0.08165933432117586, 0.04724053222866309, 0.05702680367375574, 0.030212040930505724, 0.06234448808696001, 0.05177372345520605, 0.09345318130668133, 0.054390622347953825, 0.10671941097825767, 0.023735397638032035, 0.0568707324113817, 0.022666817981629603, 0.06528085713545162, 0.027768293230403817, 0.0590943064420454, 0.01672360937171165, 0.08027834592447167, 0.030109691583821853, 0.04776115026024561, 0.057245123410417195, 0.018906573081509243, 0.060549877328617926, 0.013440579791823703, 0.08807462354701373, 0.05015477665790147, 0.03334067889579362, 0.025407294517443068, 0.004147097276854179, 0.015387513727370291, 0.03776569084654893, 0.032319571792839036, 0.017496335447856018, 0.02226296324102629, 0.07932487289391218, 0.016140907574745438, 0.01928028226229212, 0.011901942949231354, 0.08483440104511478, 0.041746061535612236, 0.04447970839758073, 0.006148148142176891, 0.06585131684738783, 0.00275162335451422, 0.06719136550541847, 0.052037299835994366, 0.008944459559936679, 0.037584940061694196, 0.053627503014379935, 0.029128445950787396, 0.0388075934062081, 0.0340983743268636, 0.015005975128001264, 0.006508529308297101, 0.01661599125532854, 0.043089860194032235, 0.04281638595726221, 0.04642463709798552, 0.0665775835213642, 0.017308544314977144, 0.0851502054701409, 0.04403373414290048, 0.04926678882310948, 0.043411157469475464, 0.04976400669904486, 0.018482844104930278, 0.03023986332869578, 0.0425934735234947, 0.03697055286817974, 0.047101222970072305, 0.024264015542763858, 0.07830835848806367, 0.04221673063453167, 0.021433351306064476, 0.032184437713435585, 0.03948352810355925, 0.09551355179639594, 0.032184770961682645, 0.022072069452054078, 0.030514773980323828, 0.05818389521370973, 0.010690222637006834, 0.059169999759403936, 0.07054761968432896, 0.01415427400535273, 0.036131475916913444, 0.05657526762074521, 0.054290387403940966, 0.02961341982647296, 0.07821977574137912, 0.027266833142587737, 0.023594646218923793, 0.046935066160175114, 0.0660113143103738, 0.0519753463055578, 0.025123970305186608, 0.06658034909877085, 0.07785913985102408, 0.06786071950750006, 0.01015066403910638, 0.03619050682191888, 0.03410831431768114, 0.0028949284798375544, 0.06427032587629172, 0.021135450355828773, 0.04401713301758132, 0.05468769209279169, 0.027885542987214944, 0.028317436545846925, 0.0098867189785045, 0.048451851302337264, 0.027265806584769202, 0.0339161986184697, 0.016006718656318565, 0.012537065270026366, 0.018746795868801496, 0.0571113070022435, 0.04577413651972048, 0.04229081133680959, 0.006713515284636449, 0.044889063649480386, 0.03921850764703366, 0.06075307065921445, 0.0331116798934677, 0.0553048103897562, 0.040303621396061876, 0.02605295342002665, 0.053448177153064366, 0.0457661040878344, 0.068077982042826, 0.037274766382911516, 0.057191834334404244, 0.046557503557133104, 0.08509963600625915, 0.022599643561989072, 0.022478820005011176, 0.029701439498533166, 0.09230296923628739, 0.020454924876591372, 0.02195883399596618, 0.009668418394041159, 0.045263404852800795, 0.016952648593653596, 0.036418904445224234, 0.0352360685205748, 0.028086225464639646, 0.05343999916447267, 0.11695482062115786, 0.05934340376106482, 0.03894135235778747, 0.03130837212196522, 0.06553909005296808, 0.016041658968935092, 0.02552980538307419, 0.02005042279169204, 0.06717738440080036, 0.048141784875863985, 0.017240776177195292, 0.018111063550496777, 0.06052746925683272, 0.0026790197655153013, 0.04366567103011955, 0.04921752936957825, 0.04218981413531207, 0.05064087093717629, 0.034630770960281936, 0.08211344059917235, 0.06604817080041094, 0.03758710426008029, 0.025464350830823667, 0.030747816011670138, 0.03643840904377642, 0.027022257657541383, 0.05802654458450214, 0.004665756038570356, 0.04004837239101049, 0.05554689417382883, 0.03392321981429573, 0.04156636412165338, 0.019005503760831013, 0.026353374799533237, 0.034534941021833694, 0.010402781659767274, 0.046332423094539874, 0.049463945380862684, 0.006341392384661783, 0.028131116301782673, 0.03425133144182544, 0.047436689041675105, 0.03928204697947349, 0.04739521304145456, 0.13674010612791584, 0.0390562042593956, 0.03607808341903072, 0.06282843348960723, 0.07888514608625444, 0.11672968270197032, 0.02597426469888418, 0.07064704257514208, 0.030000483834995862, 0.020395938021641587, 0.05089013296509943, 0.02786990713268038, 0.032687382096604954, 0.048733997654410145, 0.024952642401800524, 0.054647886164246075, 0.10752492944800085, 0.023762241358898824, 0.023199743215715694, 0.08912123754740724, 0.01869528986243231, 0.048240763435681025, 0.05175095532209643, 0.030454955919976198, 0.07679544208991913, 0.060966437637445435, 0.053656016806921655, 0.06284350626951744, 0.039201171077307195, 0.0549131824124244, 0.1346638699572894, 0.040241962809476166, 0.04454448496201827, 0.002781833074198315, 0.026652377001160098, 0.07899040656705057, 0.06278014313730021, 0.004282065689744007, 0.07182618212555686, 0.06052956833774525, 0.030618630604998722, 0.016737084858299747, 0.035238657897758874, 0.04872918662224566, 0.03127212850226751, 0.04050191559438263, 0.0432040915644217, 0.04293129914590428, 0.12101857231989985, 0.05642275100633983, 0.04855359927000058, 0.012918247638510601, 0.011304350318236938, 0.03516222147511379, 0.036582874074097604, 0.03389521930066328, 0.043423112271533865, 0.019236864229183526, 0.0764171785164264, 0.03720114916382778, 0.028496932861725652, 0.04442429342757791, 0.03488326970968516, 0.04745574164835196, 0.04993664078234185, 0.023126053218279156, 0.046261119460987474, 0.028228987864549124, 0.0784883202023564, 0.057546808834998846, 0.05975962699120564, 0.0898114751063047, 0.012877116377855982, 0.028640491993076382, 0.03283755065152242, 0.06244877180565269, 0.04472980929178096, 0.04033246460641104, 0.03966606770371718, 0.028314454548601663, 0.054061442027769746, 0.05510368549655523, 0.006396009186808501, 0.011442806346402054, 0.015215178418363777, 0.029037346605271585, 0.08046359364544192, 0.02515071826506286, 0.03126707232196725, 0.03295994085830546, 0.08281058061026758, 0.03125044438357075, 0.04912556817514762, 0.05429183914055748, 0.009212676518326326, 0.07629890986267598, 0.04428885674344436, 0.0242233247826657, 0.04030529529817643, 0.026543119456619028, 0.06185776561558728, 0.021969469211575006, 0.051254131981442054, 0.029493107633184523, 0.033534422531844146, 0.07045046441377172, 0.03135822912407739, 0.051106142946669174, 0.024957315538138635, 0.030150750066123666, 0.003157702144122713, 0.041058436336536566, 0.1135164418167645, 0.14522780874563804, 0.14740322265894185, 0.11613971839148192, 0.2205467695790914, 0.13854053532404287, 0.12025561003435044, 0.11558862538227152, 0.13001233729864323, 0.1163976142303117, 0.1802857388411799, 0.09227522919254919, 0.3067914005969801, 0.12499777855531824, 0.17884717893696603, 0.1820689923460445, 0.19893196651772146, 0.12904836886352108, 0.11657749167493275, 0.1695347979905144, 0.19384192513121715, 0.16975271936145522, 0.14135613827215088, 0.0753468694165349, 0.12785949999646795, 0.10868693161154948, 0.11521216211540085, 0.17000378169600042, 0.169963255644806, 0.1801762801985587, 0.12594354474135946, 0.10953087705157458, 0.13798898266207787, 0.1327750648582174, 0.18310800675422917, 0.1665489396621143, 0.12255475480830479, 0.18792038723345728, 0.17449754620752028, 0.22102425686053692, 0.25972148764037317, 0.17645727572662218, 0.1381872308951232, 0.14576780880170484, 0.15875419421542078, 0.16034990939642155, 0.11325665374076176, 0.08443677076889623, 0.07562741081440642, 0.16524153401053723, 0.18386559110255013, 0.1630520853664606, 0.12629273527812573, 0.12916289900820102, 0.12942883877023575, 0.11559426378939422, 0.27217099863675337, 0.15713446983887305, 0.14859687957552173, 0.12400406292609631, 0.143759080298966, 0.13451072898122574, 0.21761908796766113, 0.13389051951948674, 0.22678283253504386, 0.10978898739502316, 0.11800177936111728, 0.11161292016866708, 0.2582270646047208, 0.17230173903367213, 0.10240484209310624, 0.19737644030922846, 0.1588275241515329, 0.1716335571461147, 0.13959128619922748, 0.22080852650105956, 0.10875715889156827, 0.11489979742515473, 0.11698751725376615, 0.14837168036930024, 0.30254905082045064, 0.1371864749178771, 0.21043405657814396, 0.2634858598391856, 0.1357941714025313, 0.14893631781301192, 0.15135436709369385, 0.16655940442315995, 0.18789892144981893, 0.18077244982123378, 0.19852460692486457, 0.17040980829586908, 0.12426771974611668, 0.16912089600678415, 0.2778224598976874, 0.08485277949441826, 0.09096814529790033, 0.26826385829237204, 0.1155577673606815, 0.19704778858971214, 0.09949150164761852, 0.06429162312058673, 0.12727996980350825, 0.11789893971816187, 0.07999497766215956, 0.0746161747543562, 0.17882946698415667, 0.1830495082803311, 0.10038512022865397, 0.15717491928127506, 0.14822597044610208, 0.09529414421488201, 0.29672782447549606, 0.17056250494093667, 0.11564223621521266, 0.12294897599326027, 0.10712899222609498, 0.12905124935411638, 0.10309170886513688, 0.09328899334274954, 0.24673194594440923, 0.10948367837455966, 0.12737631302086577, 0.0747355159312006, 0.13865609202654133, 0.14575869235540592, 0.09276835232852929, 0.10774514908271451, 0.2041706442832947, 0.10698338189432699, 0.13601895692127366, 0.16066444977637262, 0.21963799011803445, 0.19819862119132475, 0.17566760761603234, 0.21250560429067383, 0.15816153327543891, 0.11962661354411995, 0.26777475711799437, 0.1425256940626329, 0.10838732994612187, 0.09812284726649524, 0.16624766792501175, 0.12589616986412194, 0.13787123494811598, 0.1832117657026937, 0.12837500822159553, 0.17231131513272563, 0.11317711083158372, 0.151937666439241, 0.1506468236085869, 0.1404954078457048, 0.17333560533100562, 0.07136839862552381, 0.2233866881579161, 0.20203488308095163, 0.116526922211051, 0.09981223201799778, 0.07019620749258226, 0.160240282214457, 0.11680757852211116, 0.0695353570664602, 0.21559549735919123, 0.07605599870364513, 0.1558950774732136, 0.10624865760966655, 0.20676593566613816, 0.10195323326174291, 0.10969041486180599, 0.1086702921818341, 0.10129766884229838, 0.13165571847029273, 0.16376925091589653, 0.2095015590349513, 0.19914544457870148, 0.1251166983838043], [0.06610434802789843, 0.07726156062656835, 0.040955412832479325, 0.015638194933173158, 0.021554234234856504, 0.02771254884259355, 0.05852973411580729, 0.035255841249900485, 0.02361230837601808, 0.021992262242542162, 0.018442599591048017, 0.06781810969715157, 0.04365819784241819, 0.07971239847040947, 0.012983831468098348, 0.007052925751439386, 0.03883326118211112, 0.03693349719528229, 0.013480540853173984, 0.0623224898722143, 0.08570329796883368, 0.022519545239065925, 0.09844615169230009, 0.03018248334316717, 0.03160669442055927, 0.02165899675850186, 0.02272446609793171, 0.10843312668223536, 0.11863304347160364, 0.06478601796252113, 0.0812450722761212, 0.11647051515718622, 0.03894409878299602, 0.004372779597272916, 0.014118866379102393, 0.06421326381725169, 0.06022166227921844, 0.06988057160689946, 0.030257142441827926, 0.03645938453114322, 0.0243743417799593, 0.09007425858609139, 0.057746501143781416, 0.03738368876398571, 0.02281711102583476, 0.018589629100695736, 0.07973899704314048, 0.059818079499828244, 0.09855806181627898, 0.01757511801476921, 0.0484904085075663, 0.05716033662939745, 0.07995762321497164, 0.043458555329350695, 0.017139263781568697, 0.047618768989078464, 0.020755256240766858, 0.01917419440653776, 0.015028204126734168, 0.09987120546640889, 0.07355891979269444, 0.019748383051445408, 0.028910752491004048, 0.023140380977683013, 0.032734140273063414, 0.05570994449719306, 0.02965122435031639, 0.026749199023470286, 0.01754524441616189, 0.04717145791097034, 0.06739785684452904, 0.04481308304915025, 0.12703341972683707, 0.02651439498989813, 0.029880263572258335, 0.02471511492565755, 0.03509751385858944, 0.011662402577067335, 0.01678528328005585, 0.04461179344704555, 0.034355251268754085, 0.03855686815034959, 0.02966013012243615, 0.01461792956932538, 0.027520300993215174, 0.05200517393888966, 0.06371595784120503, 0.05023677870931645, 0.04361869068816305, 0.091161735716366, 0.035091258750687686, 0.049453760241909374, 0.009439677946389684, 0.02741136712082211, 0.09298667206519073, 0.05331190543309335, 0.013970304693606113, 0.046734944842154943, 0.028380594749544418, 0.06922137593069384, 0.06275102796573793, 0.0846852130827404, 0.015495569471480146, 0.025741287785011436, 0.01974106499654872, 0.022174074059172023, 0.028597455088710113, 0.05488634635243685, 0.01606505050609309, 0.031128590438334696, 0.03075850293821385, 0.05897103140370981, 0.028928698100630316, 0.03932819994647176, 0.03918728573367961, 0.08928285911679269, 0.02297490407081862, 0.05834537122638957, 0.05685778552546136, 0.01620830607510382, 0.03617967816910917, 0.0354388443332526, 0.04455964201160016, 0.04837109414379924, 0.06052801700969858, 0.028595520716701305, 0.06553830864328532, 0.005351721220875099, 0.0321899535464904, 0.050141814450222644, 0.03552845746819531, 0.037422004651518605, 0.015379150920066864, 0.01857328078439159, 0.07530096542811202, 0.04500628276277454, 0.08662264178236646, 0.027602743545186617, 0.057223918096673106, 0.053932681799896305, 0.06522163087802549, 0.05534281218124013, 0.023227709255391554, 0.016138548023938652, 0.04960817675436697, 0.054906973269798105, 0.009228064351895405, 0.026171289106470444, 0.0562820015024514, 0.024237401648274353, 0.07031828360331636, 0.027764236794844754, 0.06035745136379715, 0.027319319741500002, 0.03834026062019891, 0.02712901009457006, 0.038486269317687526, 0.028223879973313985, 0.07627093233168125, 0.04040377590084269, 0.032599174733003305, 0.05652975433716371, 0.016638271007386428, 0.020479001104831696, 0.04285407748313681, 0.034730377712196885, 0.030995815909738024, 0.07549418812437404, 0.08824391365652123, 0.0424435654384715, 0.022897481309971022, 0.06902034679848341, 0.028150404480496244, 0.01943525993415425, 0.055632941169484015, 0.01813762573405139, 0.051233650620786414, 0.049417922648811535, 0.05361357936635614, 0.041774445093206825, 0.023231840384523236, 0.05053933747413178, 0.05986972531724361, 0.06562990977639152, 0.07556074584323554, 0.052281072843940034, 0.051403262487222115, 0.0549485833354054, 0.03858361994066546, 0.01267430417600178, 0.048719618184071396, 0.012198098176609606, 0.03280106571412856, 0.037944196993785526, 0.10370287082849011, 0.03295289284940208, 0.04361839957475182, 0.035474827483056054, 0.04678585521516301, 0.022360988021377596, 0.02872669220631642, 0.02721421056306891, 0.02483231297153379, 0.016098924041275057, 0.006454665666340941, 0.04661243206130401, 0.01417320212274189, 0.09863257152779449, 0.0458423643102569, 0.025178159534510587, 0.01724240794447401, 0.030301301665003263, 0.038260081858043714, 0.05274055705916497, 0.06588023666652941, 0.08223164030500958, 0.02193231203202759, 0.045363417631315614, 0.1081006751666146, 0.026267262686404492, 0.016006402645049798, 0.03705584143678989, 0.036148574999383384, 0.01364724254310732, 0.055282256761265386, 0.09022465696738613, 0.042322086876318346, 0.04652552704717364, 0.02590313726555436, 0.08859221553129536, 0.01826149257530849, 0.020721789689794667, 0.04512251745308599, 0.025331210495243152, 0.04669947114082114, 0.04096073331311345, 0.058279437869186365, 0.024211151645548885, 0.04291905706087428, 0.03841340286476958, 0.013511810647023302, 0.04827303871993096, 0.0913587658696117, 0.0503721272933387, 0.02964570277160214, 0.059250825865855145, 0.012299245722862262, 0.0583067374123681, 0.05343185181939795, 0.04263089308815618, 0.013397362856795231, 0.03548613494081843, 0.04657788149591896, 0.030762720252237016, 0.018647489806396828, 0.0286122712291657, 0.029268151659878994, 0.0025875582040527896, 0.08077497008226572, 0.041776030895210085, 0.06388573441654444, 0.04257896764864845, 0.0497434142556402, 0.05842878287958522, 0.05806046312734966, 0.024361527044205897, 0.023318965648931843, 0.02368244755592558, 0.02036180688939508, 0.0347542375205986, 0.024740570112161582, 0.020050671770267432, 0.00944207005593325, 0.01594515104267386, 0.034024067628648014, 0.014921844309766688, 0.06599500429846587, 0.012603588514931261, 0.02467192863414605, 0.06054954024993124, 0.01602951934816496, 0.05718899980908441, 0.04729430394006833, 0.0626799694803213, 0.010857677008325775, 0.07088234648108482, 0.051979398910677245, 0.07537713755042323, 0.04251120717174584, 0.03626039319281136, 0.014847359496108709, 0.05902834627176485, 0.05230937213186295, 0.060071566502653787, 0.051903866471782814, 0.06583791030871292, 0.0406151280678328, 0.05212553784311299, 0.02277161306401174, 0.061589470133185394, 0.08259982216141878, 0.047245573087204853, 0.018919634880618225, 0.01909528351989725, 0.024012139239799113, 0.01684903137145504, 0.04211887439352371, 0.033423117617325436, 0.019709061673511902, 0.015451342258001528, 0.020823972412355004, 0.039274156273853396, 0.0436290635186578, 0.056775297008214466, 0.029468554515211336, 0.03848025552748192, 0.036410722626192916, 0.03828344753973427, 0.017074414438778357, 0.028688064137954387, 0.01643047540358478, 0.022741749041503476, 0.08613295072028715, 0.02196158999727378, 0.06171545712277294, 0.03235906362533569, 0.059939408674836166, 0.0226109778328288, 0.028796668592540008, 0.049173153726564306, 0.06677320407282922, 0.021269297407519434, 0.09100083426962938, 0.013521441329841413, 0.03702632789950698, 0.0380917914932774, 0.03075170582310567, 0.045921570140748255, 0.013179258582362486, 0.023769195522031477, 0.014301182856152376, 0.03431484013074829, 0.03509073781089918, 0.06487393421271155, 0.0381621643300018, 0.024034043608774102, 0.022766357700851177, 0.018456664965337804, 0.01908304335008706, 0.07825149944232357, 0.0650134158410853, 0.01785962583286868, 0.09774060769667549, 0.11854066858969389, 0.23692283358785415, 0.08370103524817575, 0.10739920675874719, 0.13475278212178138, 0.1639208903596286, 0.14525716523489646, 0.1618521618506601, 0.13478858907136226, 0.18546098452662269, 0.2168273207761588, 0.15618951570603157, 0.12898153535300685, 0.253115174390616, 0.08076335618933363, 0.19299671564611698, 0.1181886128840908, 0.21016736604994346, 0.2035672734341314, 0.2007088155275391, 0.20693214610219005, 0.12979009519180945, 0.14433497923516458, 0.13555840018295473, 0.14269496885038194, 0.12157288289839223, 0.21035648251493133, 0.20723433714480172, 0.14141736401905938, 0.17339486989282793, 0.23997025474184946, 0.11156772864201378, 0.13243545808138388, 0.09088777501376406, 0.0739468360740331, 0.15677450044501215, 0.13065424237039783, 0.23224834893499655, 0.11081778219029789, 0.17732513077076406, 0.16654239727124093, 0.21320884236164633, 0.17352983926332768, 0.1385704893618822, 0.11186408975552167, 0.08258291460092991, 0.13555198036614927, 0.2408780842538803, 0.22930588182662764, 0.13751043817929684, 0.13745365574234916, 0.17147828644562155, 0.2755218978610731, 0.22805657628322804, 0.11882789793514437, 0.16808212674673528, 0.06804871748411848, 0.1394529460418609, 0.29415830429042544, 0.2280181952782216, 0.13080084095558814, 0.14778894792881705, 0.11269976144596455, 0.15785589483716797, 0.16427254003863181, 0.21222000671250207, 0.09221784154614134, 0.1666417588750201, 0.1895346877075011, 0.11671629914593314, 0.15484546040815694, 0.28470661791582264, 0.20301402005697453, 0.08793397746499508, 0.11108628834687895, 0.17024194310990073, 0.11972716258418177, 0.17719848111512201, 0.10148735987322946, 0.10802171448425901, 0.08795171240044218, 0.11632426897244108, 0.1696096447807166, 0.217880645706769, 0.2142369783213062, 0.12920835866562783, 0.21120035900704323, 0.12381057975994003, 0.12789835597598745, 0.08187984506930075, 0.1326165306231668, 0.1092892146158603, 0.0966349512999577, 0.18255806287690518, 0.16886448637852747, 0.08264314443353685, 0.18757863541043576, 0.13241511078611498, 0.17188659598750455, 0.12324399645290068, 0.1665979999327852, 0.12220564854121017, 0.17780405829750723, 0.11286764961457062, 0.10679383642010151, 0.10271234212503319, 0.1758831387926494, 0.13576407946886557, 0.21621665676995633, 0.17781012571386753, 0.21291500167740932, 0.09957815385273389, 0.18872055074860974, 0.10719604790210725, 0.27501707656248925, 0.1663396904064763, 0.13802341065339505, 0.19752732898679473, 0.1618590719637371, 0.2724192417677372, 0.14325208331067718, 0.09982947665717333, 0.14735590906873827, 0.1324152946472168, 0.15630913267452873, 0.1284770511331097, 0.12376924165554586, 0.0947507274066729, 0.13766229212764772, 0.12931384897280124, 0.16588999679492367, 0.10866733508244639, 0.0806973270711399, 0.11654056623698243, 0.1009710472557814, 0.15322199752253873, 0.1676521828818706, 0.1984745507398921, 0.10709657904601867, 0.11502021112509313, 0.15290114457809156, 0.08902803529053928, 0.08332988097062034, 0.15255154801472542, 0.20556110918762224, 0.1662641081718668, 0.13115034558840338, 0.10715390540539257, 0.08222293754618976, 0.16683921037662416, 0.14266971859239763, 0.12454397871249145, 0.11886544390431336, 0.152213427448465, 0.1405460922227752, 0.16438875557674518, 0.0887781220878805, 0.1685222442592344, 0.12094815351789999, 0.13468688323853478, 0.09520465748444681, 0.0746552988646492, 0.14653613370272423, 0.10925217426472134, 0.10162017653666197, 0.10072923926336151, 0.10807940856583657, 0.16587424602720047, 0.13865097455920714, 0.09259520879676265, 0.18514059123493012, 0.14405468298542884, 0.14302358992638128, 0.14921972437972023, 0.09058841083559299], [0.0029125372501796172, 0.054629657102087816, 0.03883635617732521, 0.07860868793701933, 0.048983267343212525, 0.028796844792762594, 0.01380762879571487, 0.028587436573880336, 0.020036654276472908, 0.02155480113992047, 0.014770308287904389, 0.03643472799130025, 0.04603179487129373, 0.04498420410879678, 0.02369476624974801, 0.024193847634559198, 0.08316419147435697, 0.04045530297462979, 0.011355296122811494, 0.08169855802289902, 0.03453577222723154, 0.016599483975780108, 0.06841313784881946, 0.03816251290000735, 0.06830597746997111, 0.006715126463302201, 0.0023498042531672025, 0.02760564893363945, 0.016960070070420063, 0.09431856954770704, 0.07004131983605123, 0.02539668228447197, 0.011575700576236893, 0.019428953115317612, 0.02915803226642311, 0.014192605214644105, 0.04063542556738661, 0.055268628057092435, 0.022234246435184634, 0.04398889501669234, 0.04679936900614731, 0.05785777158434353, 0.042831527685085614, 0.06696271890353772, 0.024062126476858414, 0.052495895389227144, 0.006007381401310165, 0.042996098692979545, 0.03359378668509665, 0.04565250473998247, 0.04276141531825547, 0.03413236564806393, 0.03294523197015928, 0.020715999980306914, 0.015030618261305556, 0.05407521245820869, 0.023490044573742538, 0.07299637376901603, 0.04292092631540952, 0.015727077411758085, 0.03202882801903592, 0.08563706966777963, 0.031145578438055613, 0.060959895246572075, 0.05220350261116701, 0.060160375245276, 0.06791289009514355, 0.08459557313472034, 0.015349259126871346, 0.011714509962457082, 0.035800610203295946, 0.05261586475816946, 0.0456285989663053, 0.02773362966704994, 0.09257218785463803, 0.06171411263846582, 0.06645352324290622, 0.02985278782885402, 0.04159410033495196, 0.038260154636396516, 0.0591057594565134, 0.03590835280896675, 0.03443512742617919, 0.057213399709472736, 0.02654219632067027, 0.014332696840527558, 0.03200144420618252, 0.057085918848432844, 0.03943028499282176, 0.018042211398302067, 0.03327423225968115, 0.03406192386342633, 0.03356974684603272, 0.013375025648143024, 0.02006081094394528, 0.06147952119429266, 0.01897745345148348, 0.0362960162812904, 0.011194570876297452, 0.09495109770326846, 0.02376485371872062, 0.1018066883027073, 0.025648413030731104, 0.058480482323155294, 0.022141873468494704, 0.03513810885769706, 0.02373874927270076, 0.052342348386563604, 0.047618926037102945, 0.042436076929011655, 0.06099216286994277, 0.011025141913353676, 0.04310924604895615, 0.019033979248976516, 0.03756207999803367, 0.06412808250095095, 0.06750569904163, 0.046352138367271235, 0.04382142819644463, 0.027083966039842176, 0.09745891716691757, 0.09481730044729288, 0.13867446281496557, 0.04627298616293458, 0.043330940402924054, 0.028632871333449602, 0.06132327756213565, 0.0565772709406672, 0.033591132190439014, 0.05158640729684023, 0.025594164429592992, 0.023090483755954815, 0.018404856354238528, 0.041657984406957706, 0.02350188063217267, 0.08519437043897568, 0.02760772311669444, 0.0660578464908946, 0.04069567072175203, 0.03646367462351918, 0.04161101172588045, 0.04368644733462603, 0.043539071170192574, 0.10522950786135851, 0.030814923398617296, 0.04479925516211698, 0.07313675938114043, 0.06629295887485628, 0.028608613159327258, 0.007002648358578764, 0.023046274737064398, 0.023616834040430766, 0.05404266521274563, 0.03895188606674633, 0.021882192644801353, 0.027960129307522893, 0.04738247299927378, 0.012057243335631587, 0.056304306152366826, 0.019230409938421462, 0.061826532210914366, 0.02253821097134102, 0.06174494384697849, 0.05650910060672511, 0.07524946899784189, 0.028139778840986472, 0.05762579633043178, 0.01840798007774978, 0.13870651593371747, 0.04570950934242818, 0.04503651642270627, 0.06447428146437292, 0.05907867058751084, 0.012283311094037228, 0.02133598344610824, 0.04951017112621377, 0.011346695828251542, 0.018762807106418956, 0.009555371587104615, 0.07211359533210916, 0.07152631232935576, 0.009601007444754003, 0.023605065014694008, 0.06502510634280982, 0.029335287775123314, 0.05457569769914112, 0.03173927168151544, 0.0339131725711688, 0.038396495304280714, 0.03593434234179797, 0.07588041901227928, 0.023066160464358908, 0.05033686426618407, 0.0367317058055872, 0.036390808170601245, 0.0405884605471886, 0.025971056705701257, 0.018513418673988313, 0.05029971283229609, 0.03253770000751942, 0.09836221909931592, 0.04440261313932077, 0.012843059939182094, 0.04101381554538685, 0.01655267791882638, 0.02506293224981956, 0.07120475458401827, 0.04528737191351191, 0.0495028205125803, 0.09265677928323708, 0.014195687760929427, 0.04695450564125373, 0.0353273976924679, 0.07457115942792547, 0.043390319877935034, 0.06548131170171885, 0.11702250448926804, 0.021548341103498975, 0.08241642071234603, 0.04848609926299222, 0.06946542856073187, 0.056203025498337326, 0.018125649864575075, 0.029898730121673118, 0.04353455125143932, 0.0321630178950727, 0.02437765511023181, 0.010087085444660438, 0.0525799505562792, 0.003967246405907997, 0.13784316548657033, 0.06917392444466391, 0.06695305853481255, 0.009033323843933402, 0.03949701508146621, 0.06384775560769824, 0.04208327428768239, 0.03916451760057, 0.05348139089502154, 0.02766897950711991, 0.06741107952210211, 0.03330247026057013, 0.04732969720217009, 0.018623084160349062, 0.03240247399756505, 0.08866573698938855, 0.04933698162917168, 0.018505418800839016, 0.09072879644771738, 0.016302061830497077, 0.038934641427570776, 0.09992984183613332, 0.12713441309789497, 0.012510084610943113, 0.06814396519574427, 0.03192808937221285, 0.04249658638371095, 0.06828157756958278, 0.02141377967481892, 0.002363609396965213, 0.0063191514158050625, 0.039857034271042195, 0.05019793805155543, 0.011900033475080085, 0.008834847699730627, 0.06065453259995388, 0.02429677729284571, 0.06123610441723178, 0.05275269189188558, 0.03520651667889568, 0.06047036506295685, 0.03719985830567537, 0.031889198918736754, 0.03701496298515028, 0.10566097624119251, 0.029194386968869838, 0.042925021055364804, 0.16735944536424455, 0.044186947897316954, 0.019653700329663775, 0.015781803860238964, 0.02091766688071432, 0.055288508038727514, 0.01684848936424861, 0.04219340708767695, 0.04303672433560414, 0.023349417643921993, 0.029694849227164543, 0.01913652011764146, 0.037130274539512974, 0.037863305769860744, 0.028339045970971068, 0.038811389371872916, 0.01673291159433223, 0.046305357208175045, 0.045159557804224953, 0.04409290294373228, 0.038725464950285615, 0.02030277981482927, 0.07138205797321374, 0.026899407798003767, 0.01734682955899306, 0.040016215850388816, 0.06808747387220783, 0.028137331190068397, 0.10920949550645967, 0.05397094789171412, 0.02356852262070583, 0.03835963498380396, 0.07893201534546192, 0.028575169590992794, 0.08146696964338904, 0.03332528818939482, 0.011066564287419521, 0.029101320692608436, 0.03342650372595076, 0.025488310230655536, 0.022341257426887754, 0.022112867464461637, 0.046027424339685714, 0.012309988190780484, 0.09028605125363796, 0.05189196146543949, 0.03160219939966356, 0.01506060581549161, 0.08133470456326201, 0.04755223425285471, 0.008160310155231386, 0.04567759794994228, 0.008235399220739643, 0.01551699503550246, 0.04769760709736617, 0.042335558532466816, 0.021476030064326142, 0.05884628930699922, 0.01723164632435768, 0.052136431613396254, 0.0361109754040597, 0.033466294332737886, 0.10663124191905222, 0.027654335736447287, 0.012942880238105935, 0.04349311738605461, 0.04165594661307912, 0.02006066347201986, 0.024192215867280483, 0.06810031350581877, 0.05856970475325662, 0.042069572805156635, 0.07359899385201354, 0.013947162135023505, 0.025246205379164992, 0.14916070496603367, 0.16112492990589913, 0.1210636489333645, 0.2120750781989867, 0.09628170815807197, 0.1080167885389059, 0.20709303988804742, 0.15969373976751683, 0.13652704175441496, 0.32689520248001624, 0.11787267822411754, 0.13297817008870264, 0.1446364961204029, 0.10755752648917899, 0.18224307816595803, 0.08701955193593618, 0.1691001809893116, 0.09311113837024859, 0.13131468676992003, 0.1761444207401045, 0.14498950943591135, 0.10183450495523792, 0.13943221570262987, 0.12747266389910253, 0.3355242023544927, 0.14465644504995118, 0.18389943686704482, 0.23346293537366777, 0.0872817148845042, 0.21417342366710787, 0.1991941830924442, 0.14343887086837523, 0.17862421670748344, 0.15868049655710498, 0.1516976817360809, 0.21561766794371992, 0.17059627409663894, 0.2074130041705024, 0.1173244427228647, 0.1298884149160116, 0.22164630493329418, 0.16905836791040438, 0.20630824409665602, 0.16385416410142378, 0.16098468985048034, 0.15615557801098595, 0.13327148983315115, 0.11260347951564098, 0.1252168873625417, 0.14378972381593721, 0.10930666609877542, 0.18188338456374986, 0.09986026573085016, 0.09666606979144197, 0.2191060186634141, 0.1412280483712112, 0.14356596485501336, 0.3126189701499478, 0.12980189294584338, 0.14411976981547572, 0.18037425263995127, 0.1776609990385271, 0.10666053712127671, 0.1355291662677642, 0.20618139525815365, 0.16215435289327176, 0.17378695369247468, 0.1774986343638551, 0.13460766974716418, 0.18031078991630387, 0.12235936408321704, 0.16070851515377724, 0.1838687167412812, 0.168682387278926, 0.19225062261666023, 0.1326372916059148, 0.24541053620557635, 0.11275366339231692, 0.1984935956856897, 0.09604114122808942, 0.2580775242419012, 0.14285570941865444, 0.08016016154039292, 0.1296764230656047, 0.13608977408899417, 0.12491884851647962, 0.13843562724369188, 0.14816278351410744, 0.11294764451562397, 0.18532037674900026, 0.14815348320670668, 0.15285517930263473, 0.1117344446960957, 0.0900126574561, 0.09781243610045603, 0.13867501439827104, 0.10388442600566535, 0.15242871347694628, 0.31965024769306183, 0.19871646598462137, 0.1099967121356918, 0.3101601037046602, 0.14032745072918554, 0.2098156397621478, 0.05139911029067251, 0.10965178870866377, 0.110382468049084, 0.1821218524128199, 0.12959998281252, 0.10748258010754663, 0.17474427248441404, 0.11170572405981441, 0.160961645925718, 0.10087896348728288, 0.15359952565162413, 0.12137843446145136, 0.17094754073168003, 0.15078750799500173, 0.15177468889422957, 0.1337227769075863, 0.17687637178647905, 0.1423128748372678, 0.24819462229647946, 0.1998317061412719, 0.14160048967647937, 0.19783295210330717, 0.09244861021157234, 0.11094859936424803, 0.06856074000919057, 0.16014864277695456, 0.09416165941905591, 0.1030930188754874, 0.10405636677939085, 0.13106489614132913, 0.06666529292781508, 0.16163206479001432, 0.131638910501234, 0.11935645263762244, 0.15080517398253565, 0.14324186369776726, 0.13336116808556742, 0.10418023553586776, 0.21699304091593913, 0.1166587736036989, 0.21616224920557392, 0.12248144785483038, 0.18342542762477554, 0.15381148685851406, 0.10705569293349983, 0.16611499681828484, 0.1920550556913499, 0.08706179402408101, 0.11160286909510052, 0.09822556433538276, 0.12450386634877614, 0.10825268999342957, 0.1236880669790891, 0.07645560548670831, 0.13547932458741052, 0.09247519346254487, 0.10841066498429545, 0.15927695729319127, 0.10116253859333454, 0.21094303007327744, 0.17729773546659178, 0.14673553106765594, 0.14745727782287907, 0.12297160623054351, 0.14183298203974, 0.08489088470777197, 0.1450213940153199, 0.09551954260396381, 0.1005665528317613, 0.2634469119291152, 0.17004856719605385, 0.06925836265567811], [0.019848924430627978, 0.023670245690511602, 0.07566626679392592, 0.06283962986462059, 0.010726614686239873, 0.04195503883003708, 0.0590477551093265, 0.03853510359242078, 0.031091831624507908, 0.0262509239461994, 0.03974724238017394, 0.025894848194213647, 0.009689995260428517, 0.022214626923443812, 0.004274320062024579, 0.04878258295056801, 0.04430743437560816, 0.037203439766721386, 0.0353411604620276, 0.02306993919304542, 0.07839494174526584, 0.047550158154579907, 0.03180444278123398, 0.02338221769840006, 0.0983207124555784, 0.0944606482141441, 0.04427746884644993, 0.04950855851113316, 0.018126356580685225, 0.011118463871459807, 0.06023180528333592, 0.07593585313448022, 0.0532865900576355, 0.03428312409068308, 0.04131149049968489, 0.020814193300001567, 0.047628682166818655, 0.052397522038870284, 0.06636996603300495, 0.05379784649478332, 0.053112259089586236, 0.046330143982965144, 0.0697940266540935, 0.033366503719721115, 0.06950327330419133, 0.07335499484813021, 0.06287380121648312, 0.07229193294000241, 0.025341271144908764, 0.03823159487857934, 0.06459255777900258, 0.04230339816140552, 0.07542692560462222, 0.046166484619701104, 0.04492842907746954, 0.08064422185622877, 0.024518408444559863, 0.019071732061885057, 0.06647336492014509, 0.02966099388657078, 0.06485978456875009, 0.014351910325668514, 0.07120718308273824, 0.007054159631802431, 0.03727100872164292, 0.023948944646925218, 0.018108468427653276, 0.03527529605273758, 0.025316599283307314, 0.02527130625000404, 0.06570257321600953, 0.07479537038072463, 0.022377619790213726, 0.05822042994681866, 0.09010065031508285, 0.02622468160435317, 0.02639538514608097, 0.036337293098650636, 0.03221036212879323, 0.03234975948749531, 0.038539401345675996, 0.010826285598018478, 0.04345950910881643, 0.01270927513213528, 0.056462284973672325, 0.026494852086949735, 0.05679782765406755, 0.017699295121635643, 0.051060499428140546, 0.026804813176333427, 0.06389660137375036, 0.05354548564120647, 0.012023063365279908, 0.041448375089995326, 0.02337550102252393, 0.031639525118554314, 0.037660694666086666, 0.13749497852498485, 0.022287064367124153, 0.004884073860011995, 0.06566818352908858, 0.07584849612847452, 0.04565534692618155, 0.05107271086965358, 0.012766504772908747, 0.04756219722630997, 0.0354951671174457, 0.02154053658277037, 0.013027922700970404, 0.013716822478830094, 0.008076538440711316, 0.01802964947156368, 0.049008130726795045, 0.0301839733841799, 0.04735111319009335, 0.07092958346249596, 0.023909778401796377, 0.06344673539241476, 0.02365095368135841, 0.0038517193893165963, 0.010657277025823152, 0.05363825122795759, 0.04772527053231194, 0.017011244743761998, 0.044262886362811255, 0.06653190169843935, 0.028946059568214322, 0.04084209693715938, 0.027377643930395285, 0.04717779345810414, 0.05284535405676692, 0.0014360093102309733, 0.035989650059491396, 0.08139372397694858, 0.03584556424269273, 0.09343680234686022, 0.02911952677212896, 0.044474510491014495, 0.06124458501055356, 0.01976971285447719, 0.06858411335176037, 0.04158167055838051, 0.039201293651375084, 0.0532209248312058, 0.027967213705602675, 0.03251674750279034, 0.02527706723119463, 0.03884161920136502, 0.00578775069668829, 0.028820059172088103, 0.02355275653122414, 0.04329494576180174, 0.01824788493855346, 0.044719436461286205, 0.050508563722213434, 0.0618798902348405, 0.04860296597584121, 0.015452498093157288, 0.05799344192529398, 0.026690794395342953, 0.08245747536420822, 0.011745866898807788, 0.0986986849156599, 0.04591374072216211, 0.062479702605595516, 0.03370100835097894, 0.01904188336113528, 0.045972189400345094, 0.02355442277245945, 0.03311709613509236, 0.002278873369270455, 0.019563018502066695, 0.03623289829720894, 0.034909822317140723, 0.018908936462755647, 0.04613212940673675, 0.11258604335448436, 0.021443971199914817, 0.02012799302446506, 0.11642101055551922, 0.05472228479301257, 0.046336812778346004, 0.005046253237167313, 0.04501997275398143, 0.04745045947211404, 0.04397933423939732, 0.003270199043571108, 0.0947630231178576, 0.03389214728808692, 0.042098714789796265, 0.044769258989441785, 0.02727596299542535, 0.06432880136755205, 0.060260717441598256, 0.037770708722452966, 0.04365863834297465, 0.008918154973446602, 0.013910279789518927, 0.005880480851872915, 0.03619286637272566, 0.13258058577775955, 0.06626601556255933, 0.028582133330224503, 0.034842801115085045, 0.07286652952672974, 0.05095333521885257, 0.04861614651857846, 0.06240557210760252, 0.02986915529735627, 0.09801883550901568, 0.03781082874704753, 0.05578915798856367, 0.024946167043620543, 0.0014766248979515607, 0.14183629153957292, 0.08998943733111506, 0.021468685196352102, 0.04585050399445238, 0.043093820868600766, 0.0280610001045129, 0.0522309362197355, 0.044643980631184195, 0.06453401333982907, 0.045962666927446286, 0.019337482217158523, 0.0908523970734208, 0.06013445082991835, 0.0587748401167412, 0.011232704817948323, 0.04207048828022615, 0.019774240434109684, 0.03384474942821168, 0.024589939989269744, 0.0454690458343154, 0.06457780292558093, 0.010515258688810132, 0.09871104957475778, 0.016512213154665886, 0.048892459111107935, 0.042104487262305715, 0.07353037535663574, 0.02466615999207622, 0.07708087112874755, 0.026946518374907396, 0.04439707432362822, 0.02619604523774357, 0.05753994085675767, 0.020028805705688654, 0.008836113660025501, 0.016068659737826358, 0.052173245968597556, 0.057310880567397804, 0.014041714621858012, 0.008125605414651575, 0.00922286069966973, 0.0086946890411538, 0.025504773460148324, 0.012301164773112584, 0.03284589334901783, 0.004659984044865856, 0.0530703540801281, 0.07451882030093863, 0.06285810790535423, 0.03310660456096934, 0.01095712958504596, 0.02635854780824194, 0.03669099589329093, 0.033466443719883124, 0.022468962368645498, 0.03260429986121674, 0.048029767499575694, 0.030332471867422425, 0.048777044134875464, 0.036236740228149204, 0.0775954447266075, 0.037126693078466964, 0.028995047060532436, 0.026265217231646664, 0.007644141658074073, 0.0839699321095982, 0.03125306440427179, 0.029880039491540486, 0.11370690659649911, 0.0212952601272733, 0.05585816335834323, 0.02442361655524902, 0.028071861316059387, 0.06879139376143295, 0.034503301590560906, 0.03072837461537171, 0.04080239826092317, 0.06913970329708631, 0.019680879213997436, 0.042061161159748034, 0.0268377932614737, 0.05759781113855782, 0.0057677806997221085, 0.07745876698003662, 0.08176952840820437, 0.02212942837016477, 0.032620705634115205, 0.065921682023233, 0.03868486612073837, 0.08564532043472414, 0.017355312067534656, 0.05826194808187504, 0.04793737729590747, 0.02054010810811193, 0.1028728452060492, 0.031042821149552063, 0.06481787955929195, 0.07282870010502877, 0.016386670496074424, 0.0604139426873336, 0.044439649660020106, 0.03820714518247593, 0.028331141858812303, 0.0181778779088129, 0.007166477697601001, 0.04485869975460153, 0.0440290495152435, 0.04870599714077769, 0.0710699231093449, 0.06461701130554562, 0.02365496989730145, 0.06766218782192276, 0.017877153924576217, 0.07912423446654313, 0.03911844890324339, 0.018563260354342002, 0.03444915449607276, 0.03504085016527003, 0.06815874303180365, 0.009564973541625566, 0.0434776155969068, 0.04988237494422544, 0.037978927589832776, 0.048630208062428626, 0.0478239503178385, 0.08165259274744219, 0.06286687961208724, 0.02342742454681185, 0.019911247598488006, 0.04071075116254149, 0.023992644217345985, 0.09618801560493247, 0.09271029052474807, 0.020827745395382086, 0.05905987078984899, 0.019120512710463618, 0.06351219760554452, 0.10765494989050974, 0.16932168765173805, 0.11384080344390486, 0.24193710887864714, 0.2073100419534791, 0.13493406916818312, 0.10408047556636796, 0.12165047994424259, 0.18060596359352912, 0.16048288693831814, 0.25799362229243405, 0.10714951572158646, 0.29850165509889204, 0.08780327520423359, 0.15419638475343106, 0.12453352927320427, 0.10439575139072635, 0.12618918317340075, 0.15284250820836714, 0.1264413793180739, 0.1773653350650303, 0.12324458634060238, 0.1406345600562711, 0.12745430077155753, 0.31756890937685966, 0.29068774213233306, 0.1618848431615099, 0.1363085381566517, 0.14752919815721052, 0.09112279546717483, 0.13023301658611144, 0.20851793278369213, 0.12437723967577181, 0.06995279837640063, 0.17452667287040144, 0.12396616455648216, 0.11967624071985485, 0.1295913719842511, 0.12250182579361624, 0.20166818743511555, 0.18246066245821216, 0.13746090293411287, 0.253078417492009, 0.17009246403411513, 0.11167023886716175, 0.12024285467041117, 0.1640480149897837, 0.18594596414796769, 0.12626471944273482, 0.1809687521909514, 0.136042031489553, 0.1203780385455297, 0.1551262622759227, 0.11200445238500835, 0.12354807973268533, 0.1913604590921633, 0.20767541992808544, 0.1802447531372309, 0.09497571210827559, 0.27977420678061826, 0.14567027048718545, 0.18107560613463003, 0.12820236264697968, 0.1860538906147403, 0.11646837777187748, 0.1527226614134927, 0.0680065366830076, 0.2621064112792092, 0.08553303492766234, 0.1536112621186241, 0.1533325440100124, 0.1410324201588669, 0.15885159463411377, 0.10835829521379164, 0.17152173895268671, 0.11298603318150967, 0.14873823811930997, 0.10362516653033034, 0.11615782104913266, 0.1648826371397703, 0.07712565662880098, 0.1251336825530856, 0.11872534940560019, 0.20913457227570398, 0.08800377573577628, 0.12658540384783862, 0.12369675441615044, 0.14660607753021104, 0.07816938247771994, 0.19646810517916757, 0.09931749243649746, 0.17989074390742088, 0.11342043567809368, 0.10806478394736206, 0.13823754754998993, 0.11117399775332983, 0.1466445504657684, 0.08844946270748492, 0.3459209041489709, 0.14478090369412977, 0.18656756788972886, 0.1223415831824945, 0.1539124725686927, 0.09586676429476469, 0.2096939543562551, 0.10957160228562933, 0.16878752518565426, 0.17821682647110956, 0.1620370954755814, 0.1336832620924519, 0.11983259160432125, 0.10752600963197409, 0.1460574819676338, 0.10967185255140068, 0.11375609710211716, 0.22119484931951572, 0.15875292250946646, 0.06573110233030974, 0.20053692071908907, 0.1547493316954182, 0.08777377315826955, 0.20517452589927182, 0.22540336865330898, 0.16313741223946696, 0.1338543754912192, 0.1469850305828356, 0.14347274727638692, 0.10170876694422576, 0.21260364822322325, 0.11795923849868199, 0.10551027908560731, 0.15605508259707884, 0.12396031164474065, 0.27782215346251765, 0.12585086342428, 0.09509046441845356, 0.30218543484807014, 0.13453404869764082, 0.10863730443581458, 0.14411039289928254, 0.10266831505202478, 0.18775920233418866, 0.11785451427943285, 0.15187834059038471, 0.14639937168648168, 0.1704290677462855, 0.12670677515768236, 0.24856928525672806, 0.1054342678417602, 0.15614057800942854, 0.11800524207853502, 0.18240692905120312, 0.22194946124669046, 0.11908164923830379, 0.15332324370261163, 0.16944378674510988, 0.20122886665405768, 0.24479552081996397, 0.13480115291332045, 0.18960991754166542, 0.10441105016657423, 0.19868830459252482, 0.14998067951490804, 0.16320150315521226, 0.13640469751290737, 0.11442622485300226, 0.10458069267652689, 0.09698384306243352, 0.1658725146684916, 0.1507971300593307, 0.17966606564098792, 0.17571915001157792, 0.10899338210302015, 0.21557780072814037, 0.14661925424250866, 0.16374876572480127, 0.21235417935156056], [0.05308888957745606, 0.052231805729529554, 0.035927685037735975, 0.021891734269898266, 0.019797761248604908, 0.061906484977131894, 0.06537065796193577, 0.01942908909592417, 0.02015795663840348, 0.009114638331436343, 0.08014912221340403, 0.06700873780514925, 0.03441087691293609, 0.07229072252108205, 0.05730908792165499, 0.06766125319465514, 0.0726823236853365, 0.04684446477181008, 0.023192340891147335, 0.05552893707288369, 0.04803313445600291, 0.06669606667973342, 0.011821532445479066, 0.043278126301424164, 0.028185064213410504, 0.03152587597498731, 0.017730191447621873, 0.04085421261768188, 0.010480828782273157, 0.009246042520258456, 0.053671012978039445, 0.12138963466690433, 0.04071810560661458, 0.03134236152794573, 0.03715840145765293, 0.04463215989451255, 0.01789176513651206, 0.047988800947824796, 0.0668454538249681, 0.09193160045411318, 0.0371503422126895, 0.021571476958812247, 0.01622856527026142, 0.02700348275773708, 0.02040190393135192, 0.018190384294176777, 0.011781402844785443, 0.026992271060965238, 0.032887346366600644, 0.038804184314945055, 0.02504856235557987, 0.0653542713412354, 0.06250569213842673, 0.0748685087948557, 0.047209873389933384, 0.024382657664377364, 0.02392819707071589, 0.019247901640952598, 0.04220828451516648, 0.07275772971972343, 0.0523763167251262, 0.058359237417819045, 0.01031612083616276, 0.014540141001493942, 0.038168457742299766, 0.03517386218112323, 0.037595029439656966, 0.04419837026826797, 0.04952745023934592, 0.02600646337434169, 0.012211370649897765, 0.016888708980273337, 0.03459292621682248, 0.043248727677329894, 0.026311690040353327, 0.02412707158063929, 0.02348379904193984, 0.08149890018807304, 0.03742364407967656, 0.03109044692058477, 0.05401623900979758, 0.07435697656605514, 0.04197566574739833, 0.061581805423502965, 0.035694974339416916, 0.07473372328545778, 0.04103990466964822, 0.028953142051074295, 0.021313554306905118, 0.04757898604317058, 0.05666621757911579, 0.03783397226324005, 0.013208317254940349, 0.025967502057732596, 0.016020402901866022, 0.020017858309250687, 0.033177996294633035, 0.025484087170972943, 0.04491423729867224, 0.09943507161111602, 0.022401818592521935, 0.049126839881101926, 0.14463082706976324, 0.035262977358915155, 0.01935848068716305, 0.00429126544810471, 0.040784123233489455, 0.01949712344925971, 0.058899647330925356, 0.07917172425696928, 0.0414798153384078, 0.055497343606886365, 0.07104348541507799, 0.03338750985060488, 0.03680334651782628, 0.01637821671582999, 0.05486748909818069, 0.029643902464980082, 0.042239950759516615, 0.050342897208587783, 0.027039025406984073, 0.026349142163751588, 0.039676103455525254, 0.046696732376491835, 0.08900486879170903, 0.05938394896445736, 0.02365276164885971, 0.010943964364067202, 0.11110926332372813, 0.006977971708927785, 0.029232812023931937, 0.030168017687936945, 0.043497327039198536, 0.05664675511539944, 0.12283449947473504, 0.05008936424048678, 0.06135296346920152, 0.04519712675603167, 0.04809310381871559, 0.02558926912775684, 0.07554226014162264, 0.04105526090209042, 0.015932785425966066, 0.03767965151177299, 0.022051793019918185, 0.030016533377009536, 0.028257534215827624, 0.0552734007848607, 0.03813291509305278, 0.03444889785661813, 0.006937350375547766, 0.010327317211176119, 0.06453501691500987, 0.022157459527314193, 0.05982764027712326, 0.03250681134241243, 0.13775604596782115, 0.03663093843046696, 0.030656251267740325, 0.07532447666650818, 0.04933718847291124, 0.021459777509012533, 0.011349889457285886, 0.04174202042181165, 0.016748553194526224, 0.0680866464972496, 0.05121509214082072, 0.055818981791455904, 0.02560507926729418, 0.053244662065539634, 0.062232972498262124, 0.0357357417083075, 0.02445013277352818, 0.028505844379504843, 0.056890677510490345, 0.040081095836696126, 0.07159077862818396, 0.03467063434542187, 0.05127589653937086, 0.015679375031932948, 0.014336667091195143, 0.047723516190965334, 0.015860339363796577, 0.048472056871340166, 0.06219813464990547, 0.020598166081453526, 0.04915536133452289, 0.03547845873981714, 0.043464630406590245, 0.05255204580363728, 0.0799683024806361, 0.024168026641071327, 0.03044238824757838, 0.010887228850004895, 0.028727573207429344, 0.012817197768468291, 0.05222185424739315, 0.06579371469636118, 0.02551847494267408, 0.05089592075936737, 0.04296990231640878, 0.03979891884110628, 0.0262517647276963, 0.05308223610383369, 0.04833113499766877, 0.03928582762337981, 0.02703975319051214, 0.07517675959294842, 0.040256602749709165, 0.04687653704276008, 0.007801397483901031, 0.004606681083509278, 0.07582214270387927, 0.007491583866442764, 0.043184521848395954, 0.10469781219839089, 0.01698167374988477, 0.0167457033474479, 0.021088125274306344, 0.02538586895342075, 0.023224409331657717, 0.04735124342504048, 0.05059315132037286, 0.038945159814771146, 0.03233620739211479, 0.032509044488711704, 0.013801902288480872, 0.02036128786482638, 0.06999745364150695, 0.03398970092436479, 0.09151643442530787, 0.03666218715689836, 0.03477329012727545, 0.004568513146706767, 0.02665691415689165, 0.03873116847488188, 0.0353503420258001, 0.011926508516133314, 0.03258826564096155, 0.030845559254709273, 0.03355556272811467, 0.03701774005387579, 0.02468878448370003, 0.04223632716363476, 0.04947140707724518, 0.03188799616069563, 0.0677026066208078, 0.05376449485699977, 0.057764255231426614, 0.011798802616765663, 0.0021265147604994598, 0.011898204440160865, 0.021008584280348113, 0.053173557614847544, 0.03643569326208484, 0.015600658540103226, 0.06015088724633379, 0.06612765242255504, 0.05761854913866809, 0.05833093812989612, 0.05681769997482339, 0.04181148927478541, 0.053599092643708, 0.04466709350385974, 0.06351387150765908, 0.03287313926604486, 0.02898268431665436, 0.03426803598901437, 0.08004520238647539, 0.012435553832009677, 0.03286167859069763, 0.06816933802779644, 0.019963414355691884, 0.04871026042007631, 0.03442049131638581, 0.03194909933353624, 0.02766163463914587, 0.026601435984635068, 0.08734071131555304, 0.052060332269437855, 0.05667498545540918, 0.01117133638716393, 0.06142427093319355, 0.04738299010862266, 0.020838560641653115, 0.054715547049718524, 0.02792543127021242, 0.06732726950318584, 0.008181652407191934, 0.04284677666521842, 0.052668908686046643, 0.01808220310316932, 0.06945117166446102, 0.017121668657167785, 0.056580710675447225, 0.05257456878861112, 0.019439724311532996, 0.03024270743011467, 0.048025940890393914, 0.030668958751184326, 0.05781323123242586, 0.062155383113290996, 0.044079098039336746, 0.02334736261306511, 0.08431640303423328, 0.05622483219110197, 0.03213220966919776, 0.025758296852150274, 0.018979774697894053, 0.04595483750886014, 0.018406015062224, 0.03954104981535385, 0.10471104253684321, 0.04638747034233905, 0.03528988619725551, 0.0099159270382276, 0.026479779307039517, 0.033668721575410135, 0.019489901155353557, 0.020191024823655045, 0.0723962894370479, 0.09721716280065237, 0.01885552481267481, 0.047970878320836255, 0.054851064173084114, 0.04314419498006183, 0.03636333242719693, 0.05856591261803143, 0.02824254379036927, 0.04322579100487694, 0.08733544829151324, 0.025277572849224654, 0.06385545096089763, 0.031627723534080776, 0.02575058426197258, 0.05275674449700502, 0.030414029587841326, 0.03219521657053021, 0.08303964856050669, 0.024118807407156117, 0.015876561275593216, 0.047227416803399404, 0.053910438437014825, 0.02708498110634185, 0.017045599956726356, 0.02261728848210506, 0.015185015621565044, 0.005677088338416071, 0.032796913517578956, 0.019739136370199344, 0.05969024240790356, 0.04434968029419261, 0.22536291921090698, 0.14865902462793937, 0.13981763453733537, 0.12422986734177797, 0.0776404906965552, 0.1414232016090424, 0.17793616249917016, 0.10450017683568502, 0.10281632323899578, 0.16510190682545786, 0.15002946399392622, 0.109904934802363, 0.14948377956546124, 0.15422119068041926, 0.1493906539173857, 0.1728040935291398, 0.19192034679074443, 0.15084563874669615, 0.2192753700599555, 0.19827100117841076, 0.15957030768115676, 0.16201690139789737, 0.12768725278757273, 0.1093314873475221, 0.11883408026469332, 0.09425758128805507, 0.09479123047522961, 0.15663534823444583, 0.11960891691306907, 0.14886306448569223, 0.21709255573730316, 0.13853941683567342, 0.1217199411363371, 0.13475250633012864, 0.10526896138945896, 0.10038115955408543, 0.2212873774190103, 0.15728724309273306, 0.17605229100633055, 0.2078484791901804, 0.1704860953313689, 0.08969997100892568, 0.19089147538667728, 0.18883989192545417, 0.10012755380763162, 0.11340340554353692, 0.17823179582915, 0.11960252773978057, 0.13090858356125895, 0.10180739310359764, 0.12973619324545707, 0.18596088754073267, 0.148413447482932, 0.2514943928127327, 0.13656303256509766, 0.11164303508497055, 0.14053853859584178, 0.11913614107235787, 0.1445809241023756, 0.11898063288460817, 0.10276396879025045, 0.11235980226868585, 0.11165778227751294, 0.17363488523950502, 0.1944480232533909, 0.11165877053093527, 0.15995592569872258, 0.1772718570165096, 0.14565156262007453, 0.16149740185468428, 0.14400487194859213, 0.14335918240249157, 0.16167888808394634, 0.10848257765774766, 0.12951830251803323, 0.19445773724827076, 0.14559428988685533, 0.1404221545183851, 0.14674765057861805, 0.2561340051432771, 0.1528361650003541, 0.10085655541549768, 0.19527801823231483, 0.17214682073362414, 0.08787204691719624, 0.11293619150115598, 0.11623839817700848, 0.1152516156435013, 0.19497271687273057, 0.17550470667981333, 0.20500725826188443, 0.10701617811836543, 0.15633239110390987, 0.09815551325558655, 0.15575439308679875, 0.11588891652683098, 0.11220882166056864, 0.1754650539688526, 0.18562374756701533, 0.17412747977481735, 0.09089238686306823, 0.2574556447084873, 0.25633187033236027, 0.15271273291399404, 0.16328002716745102, 0.16292914357637206, 0.18411700583754048, 0.11740809952419613, 0.2224518463856751, 0.22025000243898363, 0.17045073271278413, 0.18304819060910135, 0.10290470680282002, 0.16041743238606762, 0.1446173439222959, 0.15201652753016642, 0.15407393325961408, 0.09990502058738664, 0.1452116596121942, 0.12932118809511586, 0.12831418084040766, 0.06663183786816175, 0.1524863079670937, 0.11140610707262832, 0.20393358603600534, 0.17428256661420868, 0.12622325876427273, 0.1881766436441291, 0.13979054566833282, 0.12995898693559632, 0.08636807076512806, 0.16582549219169926, 0.08868583913652167, 0.11832814813861925, 0.18137799636010202, 0.09376295661974339, 0.15253288611288995, 0.3096812987519849, 0.16489950639586295, 0.14451009161289663, 0.27818521785159267, 0.12686105760475322, 0.18399332860304465, 0.09510415440966045, 0.16253785650816657, 0.155952702606878, 0.0930540494981312, 0.21409807125887564, 0.14062663870713404, 0.11042559879922098, 0.13092327712764665, 0.11763330639129686, 0.14743192031258537, 0.18117927315254367, 0.18665903878788795, 0.195630265459899, 0.19481292625348415, 0.17973697473925931, 0.11765976706820151, 0.12372712214146891, 0.09247783646588364, 0.18485776689504424, 0.20628192131557774, 0.12383569978297719, 0.16427211102939424, 0.17805404810895845, 0.1455371550494625, 0.07470214514121895, 0.08834599487243161, 0.16653959338943805, 0.11834897806928044, 0.13238042232490357, 0.13690878336708392, 0.06899731819547954, 0.1341230884915398, 0.1816325980208574], [0.048443052782526905, 0.061044593927480524, 0.031951395682089274, 0.02414273807869083, 0.055187131623707475, 0.05017337344226338, 0.061168098792193405, 0.03160580192812749, 0.044398882291129524, 0.09013388320923814, 0.08279766436786422, 0.042362375440256256, 0.013407920506001722, 0.017854088932395946, 0.033776065815360315, 0.011198306512538225, 0.03809938725504664, 0.019127547312828324, 0.0287167732829168, 0.04432524975028731, 0.005276106427528806, 0.007026460765290165, 0.10526987303408886, 0.02309544417526453, 0.1021683047856054, 0.020787843705845938, 0.05610914525365638, 0.02390868672650428, 0.07704372352529919, 0.04435978116347425, 0.03788688978660972, 0.058138263186499964, 0.019067733082920313, 0.03885366210353471, 0.0249653096656285, 0.043327393415834636, 0.015306809237377058, 0.012642077729857017, 0.010252401473060732, 0.10732291972324734, 0.03405309086965938, 0.039749827926918384, 0.029946934289088654, 0.03554943295556211, 0.046470158042446266, 0.10196637166964431, 0.04508202587584815, 0.02127188486948369, 0.006690142899676557, 0.044830967371742574, 0.08599863252452306, 0.0289079160504644, 0.07595006406547562, 0.04536892580349119, 0.01626533174496745, 0.06242040740025621, 0.017826423582230366, 0.04609809978114021, 0.021931829396635297, 0.06933672578945275, 0.017791451668486963, 0.12692157088989212, 0.02352997882201547, 0.07295162657335882, 0.04147272519466858, 0.02797932938612517, 0.03946172524123423, 0.07292937938003771, 0.022870605030367454, 0.011681571054542738, 0.04271299473100132, 0.0558134506366426, 0.013258944175416424, 0.06678422807805962, 0.013900040066801013, 0.047062608308248946, 0.0037170133615408336, 0.0294413449873607, 0.05469287850803906, 0.04279293983633961, 0.030133677796731075, 0.04561385943464214, 0.02909740406809555, 0.02893452419929447, 0.026339085344525597, 0.09435481316740475, 0.02782357988067933, 0.050376294811646787, 0.07613892006056924, 0.03488423881090937, 0.05652671296810431, 0.010964354751781832, 0.028592456365004185, 0.011043083692540326, 0.1042747937683617, 0.05804722129757847, 0.02361777441335782, 0.11798174616189734, 0.07588579694950774, 0.045086902025486195, 0.1131837298312495, 0.01682609086856246, 0.09101441700852687, 0.0830575826788141, 0.04472101460241022, 0.14466367691995638, 0.09625802838033247, 0.01852870787373714, 0.02968726878715379, 0.03109879919417924, 0.022844058168571324, 0.023081752268837828, 0.028681584949334784, 0.05226748627460292, 0.06267207877470121, 0.011446817774295567, 0.06585950632729838, 0.019498803097033696, 0.047938844354282466, 0.022394716957463853, 0.027276932096649564, 0.03340117685917405, 0.06866700406516753, 0.027483235744218674, 0.015497944344045415, 0.0523682804628005, 0.02032088821813945, 0.006707449783495958, 0.0527925169726293, 0.04335928565612243, 0.020634109011640953, 0.021500954734942606, 0.04616745372092532, 0.032677599153811895, 0.01512994539112814, 0.04911512639673968, 0.03547618345868203, 0.006747693339768317, 0.023711030296380484, 0.00866333497763281, 0.03501540072442543, 0.0161947539797233, 0.058212477954164635, 0.04452946963870237, 0.006448987997212117, 0.0224538934191749, 0.03468336289628379, 0.06064432830880247, 0.03630104947895293, 0.06519454200902293, 0.03947634985970874, 0.011010209902099544, 0.030188981683984883, 0.041433321462283214, 0.043921785714525374, 0.0491287857444296, 0.025478718809843547, 0.02009461648882397, 0.05543322204762409, 0.014459379054906388, 0.054718033005032814, 0.07203514792866285, 0.02792713007018451, 0.02181015165162183, 0.0451952881450134, 0.04071363931401603, 0.03256878785548672, 0.002912676103615893, 0.060213832860632296, 0.04636862074896213, 0.03767680932557391, 0.030472292489702665, 0.04187212513399221, 0.04369593150312862, 0.007814680969703102, 0.02598404189601781, 0.012971462020950933, 0.02929634752593214, 0.0649206196108172, 0.01873063715925861, 0.017995255954203107, 0.017023607487640074, 0.03293165689214103, 0.07316141975142303, 0.11696572971319961, 0.07584909367705546, 0.04294632979097866, 0.022623880668693495, 0.01925499178469181, 0.031232521756582206, 0.051970113925034964, 0.0614766292123785, 0.01523667197268937, 0.029885197178490704, 0.015440223449390503, 0.05256707261827204, 0.044349370028583274, 0.027579165274097074, 0.06632489708041953, 0.028933233341142058, 0.047840612730191606, 0.03688786133763291, 0.04529229019798579, 0.004205974485469802, 0.07657038077952401, 0.013686507422056411, 0.06408822677669025, 0.0414316015948932, 0.010964313574555901, 0.128086231378538, 0.015681160016796522, 0.04605047209488769, 0.018073931268806902, 0.024882945637669296, 0.041448352107357596, 0.06292445111959692, 0.07524550066239412, 0.04910191138004584, 0.030304720332365365, 0.06445489943988862, 0.02801822367004089, 0.08054456147815912, 0.02868738423492159, 0.012925388535574801, 0.036575454512550946, 0.028187956195324663, 0.07391668285333342, 0.019848292408090447, 0.05559393580281927, 0.056699534742942745, 0.028111895155762474, 0.07081649356311367, 0.01203022245693231, 0.048619704996986736, 0.030710879082400954, 0.03910802627703355, 0.027576269461743297, 0.03852245931123053, 0.03459223673769063, 0.05427420762698016, 0.05147931969634468, 0.030398338191932252, 0.030816400033091346, 0.030613032417492043, 0.09928039845920379, 0.07935962264215754, 0.02669543114250466, 0.056243080405458334, 0.06765131703427724, 0.023055506096551978, 0.03881592078194503, 0.024477495518963666, 0.0205283620650129, 0.06959074522338568, 0.01990008761265105, 0.07830574612824187, 0.029538605595007542, 0.01301070104443258, 0.03616773868880926, 0.04997968343236754, 0.06386624130931112, 0.024053303059190515, 0.014501790640004461, 0.03197058809981231, 0.03734336189565159, 0.04489727611202867, 0.060191631632586645, 0.03494954780645428, 0.11094700590136553, 0.059010672623351704, 0.020928821120891842, 0.024038065570376577, 0.04412314809498288, 0.04168974258185875, 0.03810941534597547, 0.033315267759345235, 0.06220068572269333, 0.0916291949068827, 0.035329615517008695, 0.07961952563134894, 0.023066591388816317, 0.11055590269426185, 0.03589703769032513, 0.010952111709141924, 0.05020815000358609, 0.04924071885104622, 0.03029762252774691, 0.06527275192521273, 0.11486981274379839, 0.06076332474608095, 0.10292257197321424, 0.03595916359054466, 0.029945896239951256, 0.02409658511169255, 0.03425733374071217, 0.03434188303447539, 0.07610161923953603, 0.022947068266089887, 0.023169026920391668, 0.01749014737264764, 0.02607426215564051, 0.0806856212476569, 0.026866358764950308, 0.03895043433012982, 0.015552368187796206, 0.025609781131929448, 0.023353520044756514, 0.04018688874859964, 0.044505487256232774, 0.06765900089615776, 0.0073647034268135275, 0.054301545474558115, 0.053213390356470505, 0.03192978434174532, 0.04026809023813375, 0.04955766474707954, 0.12620028378742357, 0.01118431008616162, 0.043205964649396564, 0.032732278679407416, 0.03139315507254534, 0.07370472930732273, 0.042335918593791225, 0.03407924128095469, 0.03134762072154591, 0.0507082368787979, 0.025467459232576435, 0.04600855942455031, 0.015599952781602982, 0.0261599701573892, 0.009614706054450044, 0.03576666101693146, 0.09772818175054367, 0.07120177450199282, 0.05487026999734583, 0.04042254505498756, 0.10584207942649242, 0.06829974917514671, 0.023952596971104224, 0.07804504640760922, 0.03706399644274385, 0.09421930753535802, 0.040319946729728294, 0.042191940029301954, 0.007178203630892019, 0.008583506700702974, 0.011050199691746986, 0.032623164776352145, 0.023661491220756888, 0.01877915159228348, 0.05118784239335407, 0.026630836523949142, 0.12313584782063, 0.1461430693105344, 0.2187515804243665, 0.12793124413057683, 0.2291997786491148, 0.0833480908805805, 0.1450285339547742, 0.17227199950045155, 0.16748932791092705, 0.2845234309713687, 0.1846416841351217, 0.12236044426719028, 0.10120443594191345, 0.17268058483398732, 0.09620738996853752, 0.13234420168784358, 0.18019189307045552, 0.16100125267140328, 0.11710753258798393, 0.18532100494109816, 0.17691766392559777, 0.1480937130268543, 0.1682955894859568, 0.10304948975962978, 0.18184399232268336, 0.18978021888723298, 0.12209167764071496, 0.16042421992507674, 0.26656868957704116, 0.15050822298132605, 0.1969561338304512, 0.17899249049444355, 0.12963877750500558, 0.34083123048467023, 0.1218812486096736, 0.13922843631477128, 0.13560568312964133, 0.11645425111055376, 0.13153210252283082, 0.21624763736561423, 0.14140778792000588, 0.1105446182191372, 0.13180689826127023, 0.2768908050512114, 0.10867651281577927, 0.15954441390931606, 0.16617421541483174, 0.10234589162733286, 0.12287871040884527, 0.09786094478782147, 0.13734169965309484, 0.14030345685539708, 0.15031054165334473, 0.1218778471792898, 0.08747041000113373, 0.11393902357667686, 0.125295081956973, 0.33097940106545726, 0.09191544365979011, 0.2047993573209932, 0.12492711460518262, 0.1698734854618388, 0.15744053728638158, 0.18993907487921177, 0.11717327059276643, 0.1233653447801067, 0.1364616484891984, 0.16002311160968197, 0.14271969816857769, 0.13161966637257608, 0.11546163098706354, 0.1200648541412046, 0.1891682065662838, 0.18651988657732166, 0.15150258978528364, 0.0768821862255854, 0.20377100685671454, 0.13307523342870897, 0.09771633803123429, 0.1378007242155652, 0.11677685073546826, 0.13952825248481768, 0.13510771065710053, 0.1664201143167673, 0.11091408710325919, 0.1790588643522032, 0.14486034701187767, 0.07694841452663945, 0.142803508187494, 0.14307891679627283, 0.1535577432162339, 0.15100691557651566, 0.15619967403190751, 0.1054755216764827, 0.12666459435657149, 0.11746479003059289, 0.12949581017657635, 0.13445074429675458, 0.12499232400929737, 0.09001005275715744, 0.18818831882409512, 0.1453318741292723, 0.12196816128468323, 0.15792738616226182, 0.13095926793832935, 0.21890542620132047, 0.2590537041185364, 0.10631565965952412, 0.10168146357060441, 0.09461997151975671, 0.10600579241591115, 0.12300529877745336, 0.17348896081168808, 0.19772258947693533, 0.19858318200755506, 0.14917215031962242, 0.13991531074768113, 0.08585085416392935, 0.11606209836299382, 0.07250955553665277, 0.17826934945919823, 0.10524486026336109, 0.1422211128256975, 0.13927807881226464, 0.12384634074424544, 0.13557588230938683, 0.0829891786880551, 0.1048482948493573, 0.11777857198349892, 0.1081869749712848, 0.11126572912138318, 0.10547644864287108, 0.1308890329974313, 0.13555245534066232, 0.1074211858212948, 0.1474464913049052, 0.15254244689018498, 0.21325025707483294, 0.1235880388788158, 0.09172273424243735, 0.1711491291080752, 0.09590044918079531, 0.10469196694752864, 0.10641214843358725, 0.10391449495669335, 0.1434463632082747, 0.19342316615004695, 0.15568713056704692, 0.18559167912650495, 0.07997489083678493, 0.09812577372236599, 0.08924481519047292, 0.11180110966726658, 0.15234068997444647, 0.11751690699208169, 0.12141758921526133, 0.23341035109854516, 0.13466603032523586, 0.1441062713462499, 0.13252893612990457, 0.3304832212386593, 0.17954977349408213, 0.07561100121106833, 0.20451415810854207, 0.12075806412124827, 0.19854785003248723, 0.1033963054238308, 0.0958872571467392, 0.16823080909107962, 0.22371497215522876, 0.15982618104786644, 0.104165603256514, 0.09799593714095893, 0.15604549117626684, 0.2588886581361294, 0.1614837808113906], [0.033833281091985204, 0.053726381982766816, 0.031517897169255925, 0.011557091342946215, 0.017065207977148316, 0.041587757126938914, 0.058671897051916014, 0.03823767378625851, 0.045698822415884466, 0.03217596095055342, 0.05692404447003238, 0.10655844058360785, 0.07280440745694984, 0.05883861310599793, 0.029446244119636478, 0.02678611680054136, 0.01936743625499789, 0.06516747612265811, 0.03841300449904896, 0.03494062288213642, 0.03773047761510938, 0.02460784920971961, 0.016092808744419488, 0.06764169496994826, 0.052481944928125995, 0.03220263996251649, 0.012279144533339047, 0.034910462000557495, 0.03706256002788583, 0.0343377499901239, 0.05327028004572757, 0.0012116434640296165, 0.04467295407648048, 0.10782892079723459, 0.03815999630117609, 0.04273917195537398, 0.0504115003822071, 0.07936765124360401, 0.04022442705688938, 0.0069486540028705236, 0.04493420538041861, 0.006610304567842715, 0.05745182542370693, 0.05340970804794662, 0.02250961865478706, 0.06289022997201932, 0.09455424883673269, 0.016061684507275784, 0.04604193021453196, 0.02306198720039139, 0.020285090844657634, 0.030595515817103368, 0.006262826237587199, 0.04817684105927906, 0.03191234243492926, 0.05192311826131998, 0.021612085364458543, 0.10461628512148896, 0.023912501844367193, 0.020519040690194217, 0.07778964035453335, 0.060894501981355494, 0.12058511977234196, 0.02488218912584407, 0.006242848579741774, 0.05031299296646349, 0.04738791988441541, 0.1020992189765938, 0.05637084471903021, 0.0334335440739749, 0.030769599721797054, 0.03826433364602347, 0.014375735660113636, 0.05607378646551121, 0.04107660028122125, 0.04771895796781586, 0.05161561822939304, 0.05583552162974112, 0.0320218432123863, 0.09693709637729392, 0.031560914921424085, 0.025867018135144346, 0.008596245785273852, 0.03356543760145864, 0.03275529962153204, 0.04070128997667663, 0.04529417477427952, 0.025831318437872876, 0.1386094832372281, 0.006118810326311618, 0.04631905486026118, 0.014075424405746164, 0.013479474075739423, 0.029019897037576285, 0.06254066022173052, 0.016762404064197215, 0.085605277018922, 0.024544666108164578, 0.023150273088005283, 0.04688063561315498, 0.06745475419466535, 0.03900985977041625, 0.028597769184759068, 0.00406730251627103, 0.04488594567162856, 0.0390618771404749, 0.02458288240426731, 0.0636166766766579, 0.11932218552476938, 0.03350051164987587, 0.03179885033938674, 0.06670702173705063, 0.06158690373863905, 0.03050115293703012, 0.02860266640181503, 0.04504424624986226, 0.015203734979994837, 0.034006091375504775, 0.015564517384665388, 0.05064205454301931, 0.04519452588752874, 0.004314361562606909, 0.040941500675774394, 0.014143425242735014, 0.07826863682918972, 0.03901103188494041, 0.06074590007624319, 0.09524907526229659, 0.06184344360184285, 0.017414662814248475, 0.025659287648816264, 0.03564678357854005, 0.024386338716853532, 0.032123483927740205, 0.020431176150938677, 0.044880897152207555, 0.0329573170071648, 0.026776655614676497, 0.07049996901543872, 0.030854951492660952, 0.019210780850581585, 0.0033375183017098258, 0.08198250085115433, 0.062194488071385896, 0.030657404230066368, 0.06981135556294073, 0.02612276701256633, 0.016309789742433255, 0.007371796922187411, 0.026588236289699713, 0.013978481724587901, 0.05414470429382017, 0.02200700368942513, 0.060929347490591396, 0.008266714979864417, 0.009596905043919482, 0.05118635618278096, 0.08960910532022677, 0.06205454295981796, 0.03543977129964098, 0.054677411192847844, 0.011273057541749891, 0.08700431444712224, 0.014055865223429376, 0.05204902098123586, 0.007964852397450277, 0.006517434601611909, 0.03672128700981698, 0.06761809180100119, 0.04394303699354491, 0.032276824086664185, 0.0953792795659073, 0.05095115952914761, 0.042576079497173916, 0.012358062123248895, 0.014621591469603441, 0.0416236560070707, 0.028923287604665084, 0.06010466916186195, 0.08658301971492269, 0.027306631410254106, 0.04093261022541312, 0.01281456146839886, 0.03308011324054772, 0.08517153335795288, 0.06000687803832754, 0.05379225022249645, 0.09467079379265347, 0.03449778958794571, 0.022343318203404065, 0.0330680473557403, 0.13668300193403998, 0.04361128261793525, 0.04560367812612846, 0.05449587899831034, 0.029455889166603168, 0.042974399252524303, 0.013153426097555748, 0.040241656374306455, 0.026364042573878844, 0.017402347950865666, 0.00578424105638518, 0.011188026570204285, 0.02701590295820948, 0.01281572304921405, 0.016525077686134367, 0.05680342775679404, 0.009644389088686195, 0.048025312698296005, 0.05171078167134716, 0.0336626656503687, 0.03605428106722332, 0.06395933248343007, 0.042569908658943834, 0.009477070697973813, 0.037675545280498844, 0.04325913498178125, 0.04425665040710761, 0.056824924183949355, 0.04261619569132886, 0.10828586160055093, 0.10515010284800684, 0.07058691999484455, 0.024133343925519336, 0.012444280531077136, 0.03985481644650141, 0.023701038594628056, 0.009093275012057877, 0.032020259325602846, 0.02823403446875032, 0.013443692981625998, 0.0688707068442337, 0.058870175928478284, 0.05110301730793811, 0.041015983574212565, 0.06658670762854238, 0.06440733304067005, 0.04514461142882224, 0.027809062514514215, 0.029880558516109185, 0.03316013495467844, 0.10345732432699974, 0.03279983997344971, 0.034465659860401385, 0.08188823373207162, 0.01695648286371462, 0.040832471042390794, 0.06040461556685548, 0.057169529684488817, 0.010674786922942487, 0.06270869011660257, 0.019809411530713403, 0.029155869983256828, 0.014187114279446824, 0.03430594201950777, 0.03946171758035499, 0.006894135355739104, 0.009158064983034087, 0.040608792520699, 0.04351639113719425, 0.004309374330219843, 0.021066090670384226, 0.03368565211853674, 0.02951237665969999, 0.044697553159729134, 0.03237270765126713, 0.021094897491556984, 0.010026015788166514, 0.04187504392898372, 0.049492298294940305, 0.032832636197488156, 0.007578901610442348, 0.04823913932928155, 0.0255115878122348, 0.04132342231910556, 0.04116381939140059, 0.03965791652820284, 0.07270483134855187, 0.04274801261002018, 0.034852066948529214, 0.0056382208675777, 0.022455000416225484, 0.0113841115624734, 0.0209683665795432, 0.007284695598026438, 0.05631456023923332, 0.034349812044491695, 0.03436404212768521, 0.027263793688748154, 0.027617544363883716, 0.025589046962258798, 0.04294552922909779, 0.02795632759619865, 0.0220204217194189, 0.021230753608829072, 0.0256572000592226, 0.019795851774453636, 0.06575039242424312, 0.08883676611848416, 0.09041159008178981, 0.08023772794272631, 0.03651345501683893, 0.058399966482313416, 0.02413518445175742, 0.007028307037187681, 0.018647508958594936, 0.018475267495359146, 0.025540339092033047, 0.016031461381053012, 0.01970632482440241, 0.028822905188726804, 0.07800556989687105, 0.0897078846971835, 0.02910545565217974, 0.09028897004862947, 0.02180401337212853, 0.03403389653671653, 0.02422701349602111, 0.053983795186204296, 0.0477616673695945, 0.06276420850847518, 0.06989421563283091, 0.026084407074977795, 0.03882700990464899, 0.020076856655519337, 0.06314296237823945, 0.07600299308016416, 0.12910556498794787, 0.019022011040379445, 0.09152298447706046, 0.06374320758867168, 0.04732840251357806, 0.01077815325134584, 0.07600206611377579, 0.03291631598145731, 0.03935728447451707, 0.06895260164333929, 0.02317419609866075, 0.03580754712945031, 0.03676604952723269, 0.07881721707000848, 0.05037437193095685, 0.06550203438007063, 0.0751276993222775, 0.045471501146112724, 0.045586471791349115, 0.045599832364748565, 0.09891069974870452, 0.07176468824787487, 0.03569592811888264, 0.05246702153536101, 0.029108883895640893, 0.14117984611901546, 0.153427722773725, 0.21471250441766557, 0.2160105484748079, 0.1014927531322164, 0.14108693497555871, 0.1833851160781999, 0.09392961904767061, 0.1982679827919891, 0.23964682774197674, 0.3316486248325917, 0.30883510867434166, 0.13514367082426626, 0.15407416308599134, 0.15891222283244133, 0.25737627799953183, 0.07909987287055101, 0.17184597800575918, 0.14977631790022697, 0.10000491845271281, 0.09906384838564743, 0.0975168027704762, 0.13942424838821735, 0.23791140876710418, 0.22149590655199944, 0.12734638196566414, 0.07092474944769375, 0.1449257862423697, 0.1339208106360128, 0.11997224177203833, 0.14923997974443823, 0.23316408447440595, 0.18325770033463357, 0.1739668924241297, 0.168218199283846, 0.16061722811671997, 0.16794781621185043, 0.1951376249593112, 0.1334883233592395, 0.09014224888937128, 0.14270940194687537, 0.12671366994900088, 0.16755872015510836, 0.12310577120872275, 0.2085225446329963, 0.1559714104739889, 0.13629537676611256, 0.12436959411828749, 0.12053531639638448, 0.20916045072578618, 0.12126117704376099, 0.11722688142570759, 0.051172949644106056, 0.16040823933097625, 0.10943210533549709, 0.1868904586280546, 0.3863118174335649, 0.1690096906836956, 0.15001293181652023, 0.1716743283454449, 0.22708873144320904, 0.12503189245058646, 0.17758120332033406, 0.15638238600184842, 0.1261534375108538, 0.3220977147500361, 0.19021420769633787, 0.21193971046276633, 0.12254943049723103, 0.15564096610872977, 0.11348456489823519, 0.1700491494228763, 0.08585217183515911, 0.14536791090523044, 0.1414461995685293, 0.12259852907229817, 0.12243778850402563, 0.09805338607440073, 0.10244053412949848, 0.22202326615731563, 0.11865041068484707, 0.13596667908132076, 0.14745018384870023, 0.11814543616867836, 0.09300554847164501, 0.19130563784030177, 0.18031843547378817, 0.09923455575781484, 0.275657219632018, 0.1265492291760541, 0.1256541014018078, 0.10310981918366686, 0.07480226517204316, 0.1559636576641952, 0.135067812798004, 0.10201380783391577, 0.14743129212048747, 0.12054914428341774, 0.155168519685826, 0.24696091430321818, 0.11236692688638165, 0.18766420743157788, 0.13181435995765273, 0.10065127449530749, 0.14696814600498448, 0.1345149271430508, 0.11096172245039095, 0.14617849321615312, 0.15642148712950368, 0.07511511249768157, 0.23728335456502056, 0.23491652592295603, 0.1686931431533829, 0.10612301919008456, 0.09073089552862991, 0.17250052352826442, 0.10810835136761589, 0.18993843136535538, 0.08171751103814572, 0.21133943460881713, 0.11324540757003332, 0.10864360167855218, 0.17365506399543057, 0.19663872828166332, 0.16450207530250474, 0.1706078113807786, 0.22581454336402879, 0.2224272702850642, 0.11908556394759687, 0.11385381927773838, 0.1226017389807009, 0.1839713418796178, 0.14184035180557159, 0.13673095903809995, 0.13205963066749035, 0.23327829286215768, 0.13246902805422583, 0.0903788015186306, 0.176929124600945, 0.07506671106262554, 0.0846211068452366, 0.11869783152736003, 0.2503371097507977, 0.21371243791955136, 0.20648197751612435, 0.20982955191885272, 0.11340808634075428, 0.12461504102834772, 0.10850289430949958, 0.11354110984792633, 0.11998328875990645, 0.16166713629518786, 0.12046020147540878, 0.2012478962780968, 0.15254203320270585, 0.15047168058733787, 0.36434559451956905, 0.13048122907357831, 0.10052054925190826, 0.19252298219550043, 0.08860133197759429, 0.08028671160460481, 0.107118044829657, 0.11851503528774747, 0.1365851418625924, 0.09296034928411247, 0.12593444361681902, 0.2124335307387575, 0.12676066178227627, 0.12406141226810795, 0.1334910965975254, 0.31130571158662923, 0.11912016813913662, 0.17928835365080065, 0.16870003794470143, 0.05939275897558659], [0.03146749049905808, 0.0217899403369595, 0.025585578499181617, 0.027631222863771746, 0.0022816219491012877, 0.06461634480905148, 0.008329079324950375, 0.018339901674358595, 0.03001006951014842, 0.06441092599303493, 0.059779169894154036, 0.09551557426851603, 0.04312595059614509, 0.07687820256837914, 0.0732148926885378, 0.04315248405140254, 0.015486851390901835, 0.03336101086930402, 0.040987703438487746, 0.0339990625187995, 0.03607597284679932, 0.05356175351827856, 0.024971595417047222, 0.038169537926273006, 0.04475790173596433, 0.011200044574516435, 0.0416488373171418, 0.07687739817605865, 0.13096001870449514, 0.02360342750175586, 0.03584177976834678, 0.030455109137561054, 0.01704410608527401, 0.03362045420574085, 0.0561125313622817, 0.02981444321302397, 0.03352342150925148, 0.01717073275827833, 0.03536577486703473, 0.0271461455662164, 0.03647572901700774, 0.01873659923852932, 0.02056326886128274, 0.020463568263597066, 0.041164259891957045, 0.06094767231374018, 0.03906150558783163, 0.018163751247489167, 0.025624610678923708, 0.024791892257428942, 0.01201420451604551, 0.013639824896780475, 0.015358494316798546, 0.010726028628977797, 0.013115365891867589, 0.010016577584939379, 0.012257166428401346, 0.03307080144182809, 0.06342091056848727, 0.07775404790957129, 0.10234687988075519, 0.03770056954254547, 0.01933073298254561, 0.0437903709919943, 0.0825215432973158, 0.02107485663145781, 0.04013996203279784, 0.032782779195375984, 0.02118012285791338, 0.023013302312803366, 0.10512805483754604, 0.03708341294118474, 0.003650281118274096, 0.026168263059169538, 0.027189370162124117, 0.042059636644778714, 0.040512518251254674, 0.01761461367770549, 0.07991536580506833, 0.061895832524544774, 0.03557816508316225, 0.09058285669814195, 0.03063410941150881, 0.035228139510558504, 0.0888853437537628, 0.042071813612335154, 0.04185331767545112, 0.0390107982281235, 0.03800560277135622, 0.037635674234479666, 0.05967099444880601, 0.03205655848667507, 0.035832004486432964, 0.019954474109615532, 0.037000610327888886, 0.1320465765292606, 0.055251119117583, 0.02786427447121711, 0.06305111992743707, 0.03339245111771649, 0.021357544990737113, 0.018214282406974706, 0.04036690791948669, 0.07581252063955031, 0.01981156040734101, 0.04274317476477835, 0.04355066591092656, 0.16044617600498662, 0.04368590724263941, 0.026559377757592068, 0.02389030827720079, 0.01522659408604546, 0.1274585219160203, 0.05629393715231169, 0.06557156452007833, 0.06768341611830458, 0.09110729750846663, 0.03937106256583526, 0.01825799538393415, 0.01864672946413198, 0.04877869505435229, 0.045820140099573525, 0.04156305845226011, 0.052252704608103925, 0.035914535138515696, 0.07627824847135814, 0.026791916086128163, 0.07794988296565511, 0.034593902978925936, 0.03283819416537881, 0.013570728554059903, 0.05518572585236642, 0.03182338813560144, 0.07149031385779381, 0.041455721873189175, 0.03332685100876036, 0.027369067576082966, 0.02859301177874929, 0.12070674389120072, 0.02655801029064723, 0.10129720152866456, 0.020779196488400622, 0.047060287061838374, 0.014051612477839715, 0.029027818386713346, 0.025570578497624206, 0.06205025669788161, 0.031476059192491156, 0.023299455304720232, 0.040929097712280295, 0.1323289565381504, 0.07892214813299718, 0.024894119030044928, 0.03700798775459971, 0.05558606424939729, 0.011875555050679514, 0.0313898915379879, 0.06189504728442239, 0.08087279951019634, 0.02457843334864705, 0.02791532657049116, 0.035097188271221616, 0.023829327678428065, 0.03068097867071629, 0.021581886178483407, 0.05630262841981265, 0.03737302482007973, 0.0066459635666932075, 0.07583289091745693, 0.07275723942345189, 0.013576013603127532, 0.07867054953690499, 0.03611783572142163, 0.011236415556331557, 0.029444328899825775, 0.011421573261970715, 0.014189034287307053, 0.03695916497118531, 0.034329775014832135, 0.018253657411062912, 0.0602726799045359, 0.0499646604481724, 0.02105375090914388, 0.029480497825950868, 0.011122604576690544, 0.027120542907786947, 0.04426366777249402, 0.06751942733723311, 0.014602228597317253, 0.04004084174671481, 0.03029905511216531, 0.05893079263548698, 0.030411260179995053, 0.024822315524121927, 0.038798526755624244, 0.07034873559830651, 0.020928309757202383, 0.02711112768719754, 0.06589254003859336, 0.026375656466810938, 0.020648250994723172, 0.11917319674525531, 0.014036854751588357, 0.028201814725874897, 0.04403426274356823, 0.041344796172192985, 0.019292798223755053, 0.006417514711257912, 0.05157171373045252, 0.0546081951488891, 0.028091432947304942, 0.02926609088336268, 0.027581239457152067, 0.02380326153680442, 0.03666280385767741, 0.049205720124225465, 0.04345790798505468, 0.019060033899281296, 0.04464385039623707, 0.01771272655816809, 0.056924159383221026, 0.028360735835327257, 0.01681409776210785, 0.003786674933508039, 0.06837192231849318, 0.06172100359934473, 0.01305429336254395, 0.04439464199446863, 0.06017705297938759, 0.013612230409747891, 0.03412463582090793, 0.011304325420379398, 0.011660579287807548, 0.041177689413269686, 0.016637886048204476, 0.023106989120283437, 0.031567890151974656, 0.024135165299559315, 0.0538003477718561, 0.048920888633977984, 0.028317241193426233, 0.06886649336065016, 0.019291651007088444, 0.008985950881915708, 0.06946235654815551, 0.03813756141631353, 0.024443396945453943, 0.12297075587294756, 0.02811564707137164, 0.030578340125841, 0.08491026673225627, 0.03543864131995267, 0.05372650072639508, 0.03134227151261463, 0.008579946307074881, 0.023639682612772432, 0.12649423938484924, 0.04077193477461415, 0.03828134845882174, 0.044684269195122105, 0.028406101646983338, 0.0723982582830133, 0.05187086340400481, 0.04668053727777255, 0.012214368926511418, 0.03831637016828022, 0.10256779665547995, 0.04832374224919946, 0.05353972466001588, 0.04923807967814708, 0.022481328942963195, 0.07262268374043127, 0.032527702560107556, 0.0574852345180848, 0.01861343336772294, 0.03596650271285926, 0.033854114853086016, 0.008637619321234524, 0.03414743459753452, 0.019511972148452076, 0.06736132977229935, 0.014321367357737355, 0.041507842665117596, 0.04986824062202246, 0.057006241873868053, 0.033371081095068686, 0.05815898203441213, 0.03245961649583713, 0.05513100802237469, 0.02893785668176509, 0.07698566938239722, 0.042066485470821785, 0.10746903567304535, 0.0311125198289031, 0.03572736070641587, 0.06912982076286309, 0.02499147731390211, 0.03038135019221133, 0.07522832497113174, 0.033513707514371605, 0.011565037589940813, 0.04566296567058852, 0.037462848629201614, 0.020728098423851114, 0.021581393966992057, 0.05089218225029688, 0.04141804566907306, 0.023245677847655553, 0.05568183290081159, 0.025661415458025954, 0.018522492985451416, 0.0246830158416302, 0.029056362822772037, 0.13006594813158437, 0.06755238443973564, 0.08042074634783691, 0.04478250464965259, 0.03615075068908834, 0.04208800488061482, 0.012201469921086346, 0.016143226905936198, 0.027225336074949275, 0.022308512913784193, 0.015022576253320423, 0.05197023266866323, 0.04143866109511545, 0.12280145810256082, 0.09204931752455812, 0.09243439928057695, 0.03284138109114382, 0.03337284692773416, 0.021385476556456378, 0.08618757278928835, 0.03955355620071773, 0.012026851670065475, 0.04905424538939711, 0.023768475399382656, 0.04423824897516639, 0.037523174222799084, 0.03873586459385772, 0.06847162866183827, 0.002873926658198358, 0.06380681586902469, 0.05171206869905995, 0.033479888562954245, 0.03125092318852342, 0.08545624993501172, 0.04792130860169569, 0.07851743154347905, 0.065170249360944, 0.056244175911190054, 0.051128049230863976, 0.12031726479049652, 0.10699566994463244, 0.10881556543491541, 0.1004361876496865, 0.12372722173289907, 0.2224868872473317, 0.11943431781424631, 0.1115266050422384, 0.1120801495328065, 0.13717323691854555, 0.15655285588675932, 0.10981137248417062, 0.13188140797278575, 0.11844998676209681, 0.21055586455810457, 0.09786779361386454, 0.096070597308778, 0.15131423940822003, 0.1070303124405684, 0.15669997541173813, 0.08105651505531804, 0.15287963282917777, 0.15493552170453534, 0.1424641618805547, 0.11325951890959857, 0.19446890681020676, 0.18634665877588336, 0.17801644851363477, 0.21016344367977113, 0.17298832235317077, 0.20735187035414482, 0.08225223274841424, 0.10479116767284372, 0.14944316158371587, 0.12868639231929857, 0.13040452835059937, 0.11602664381385812, 0.07697998500999904, 0.1330895745946515, 0.11643670003620848, 0.2070448376358517, 0.16065079808956192, 0.11046659216404923, 0.1785875210959104, 0.19265399855231086, 0.2037747913310605, 0.1511696632951498, 0.13235501884933443, 0.19328243579835663, 0.14637321744474674, 0.11072690884071974, 0.10490554459993878, 0.090350165152021, 0.1706770197638581, 0.13548697014489483, 0.07811593252324289, 0.1225623467396344, 0.11945059718263727, 0.13431473304667782, 0.0953855614868864, 0.1981737386555441, 0.135293532944014, 0.13052083581926363, 0.20471095077453122, 0.2781266274471437, 0.16312400570079205, 0.11290210058852551, 0.12482424431871023, 0.24267644501261174, 0.14525845226260925, 0.21343877599123987, 0.1856337679970649, 0.09698307697450924, 0.10738642841217019, 0.19764791122607647, 0.12939165286239118, 0.1890053209518233, 0.17219641726584206, 0.14721972927931817, 0.15188040902778027, 0.2787850340527873, 0.16837368448895795, 0.11740722618396245, 0.15758253934402622, 0.28175197000945773, 0.15983160495037035, 0.21686485908444852, 0.14406160842026436, 0.0770071964530695, 0.10271327675230081, 0.22267929789039398, 0.13733379362571624, 0.1701095324730681, 0.2032962162047625, 0.10277595806626544, 0.18306553483970706, 0.15544426537329153, 0.1494929572987941, 0.10746495242440894, 0.12810051891832583, 0.08084511309261284, 0.13177043247607448, 0.08363800153376595, 0.16867032905499782, 0.16810452715764124, 0.1960209090142481, 0.1425917155199474, 0.24263777289419408, 0.15333459712564945, 0.11981155482992051, 0.11057636490271938, 0.12682424707999154, 0.17478167289687743, 0.11771450405039134, 0.14894957113410198, 0.20887563455729716, 0.22071003823751406, 0.1580765894463947, 0.1905329309163555, 0.1029570535906861, 0.11497003236605276, 0.10551109113880705, 0.1070071152982212, 0.16509821428166283, 0.11087487872329452, 0.16426103339800913, 0.12579867751487803, 0.1185837303919177, 0.0825923068388816, 0.18474778731263455, 0.14631004583451057, 0.22710584584743748, 0.12564280160492466, 0.14896530658006668, 0.11233694220502531, 0.1235110623641841, 0.11974354920488213, 0.25337970455087, 0.31812668267276983, 0.12365808229773276, 0.1531046941395729, 0.14315241527172828, 0.12663715308712375, 0.11809928703211969, 0.17791906341670022, 0.13306588715603276, 0.17283394031466978, 0.15126778383649167, 0.21543694780238215, 0.09778928492338428, 0.21185729472387224, 0.24039100555162277, 0.14932663961043283, 0.11924266559822906, 0.09014519832787976, 0.08497979687226397, 0.20296632342280882, 0.14349979018011402, 0.14230032631706807, 0.1583732033689176, 0.12157640690284392, 0.13010052934048638, 0.1000553500207682, 0.09889502558977374, 0.19016044364581186, 0.11236341820368845, 0.16320544084714306, 0.21120207504399363, 0.16632611532845806, 0.21174342341480717, 0.20706860168326288, 0.14836199701793734, 0.16351284128763985, 0.13093764893710613, 0.08121798340711864, 0.17493093746804422], [0.038037077493725285, 0.04314779942374557, 0.029550659988496094, 0.029101964206464832, 0.06781305351685132, 0.030889180301117803, 0.038739871233701706, 0.044208157041500655, 0.025558920554636468, 0.07553184134585243, 0.007962446881368036, 0.027390121587462006, 0.03506225849231405, 0.06665266013794369, 0.01323669698209532, 0.009406202776928344, 0.013327456376094733, 0.04206016907588609, 0.039389494641293446, 0.040626293799329194, 0.10765468175973623, 0.03598088218319801, 0.017220687436600848, 0.0597838162174148, 0.014633294420256732, 0.07277967047787483, 0.04830419551581145, 0.03968087618329352, 0.05875807428251832, 0.046739483913106304, 0.03766915610721035, 0.03978882563270388, 0.05272633463685071, 0.046183828850306814, 0.033508245307471485, 0.050429465144031474, 0.04532154709581406, 0.024059579234510183, 0.009831986784364187, 0.04560173226280078, 0.048203121705521504, 0.05906928217999878, 0.009919610963533483, 0.04026648145349276, 0.022659254778597145, 0.025199441457047098, 0.014762418539894205, 0.013158800204344576, 0.03181331407939715, 0.10544684700547688, 0.07278409080519792, 0.020979047760427482, 0.043244701885287805, 0.012859678301479549, 0.0358010315516543, 0.03746724597388699, 0.011454386722987459, 0.01608939390749701, 0.070492216205645, 0.07175377915583311, 0.05480281212517331, 0.07994632341808851, 0.08766506528181416, 0.05269362268248393, 0.07584574587282635, 0.10255249787963207, 0.0586506151293795, 0.08080337662249804, 0.032285840941532966, 0.025920108028296984, 0.01828474142859059, 0.021622222622916586, 0.041815741062765165, 0.022047397590452628, 0.038931630702028354, 0.05490490866284217, 0.01563497927911099, 0.008545029934705987, 0.03541668140960317, 0.039763613679115815, 0.06190174672332022, 0.017081856982962742, 0.04703253935722094, 0.021450138207705274, 0.07591614935306773, 0.06267891610942541, 0.06368680053480691, 0.04094876318929657, 0.08381153577037397, 0.027403813493888707, 0.03059276173101558, 0.13903050983865417, 0.14012365601956844, 0.03751034991094663, 0.011442147510787173, 0.017224906665843823, 0.062229708963704694, 0.08859377835066089, 0.05272640741520351, 0.07298279103011855, 0.03629552215457924, 0.0268264111101387, 0.03751320741890419, 0.11576334705516217, 0.05191258455236113, 0.019849684772892826, 0.020824022208070083, 0.013272543193682308, 0.03921938481770697, 0.0439280906181422, 0.04746138388591428, 0.06957920793924602, 0.09036785412219264, 0.026130607922471343, 0.034991357054921894, 0.03621389548624716, 0.04924132789094602, 0.011312570441664468, 0.054446623375218724, 0.011104018326037595, 0.04700149747452909, 0.012222839943734149, 0.018345796720935933, 0.03460586544186358, 0.01500017201197484, 0.11013014166946374, 0.0615791087940095, 0.013792048482554815, 0.02129525821205349, 0.04797801826029055, 0.04431687640927492, 0.1423444683032651, 0.06175445099811881, 0.052065595293477665, 0.06539014723872946, 0.05894016572124055, 0.06921597501082767, 0.06422526075414593, 0.05005182210175742, 0.0592989438483792, 0.05088956222959584, 0.10047651451802063, 0.043446278770364104, 0.06985624831530356, 0.03337525627425602, 0.0344558730871687, 0.02320532991190351, 0.03999706748272142, 0.03763916376497477, 0.03923984319572488, 0.03472490018353828, 0.032927225073499065, 0.06238167782524421, 0.03889675837971511, 0.03900072034147959, 0.014119549154964908, 0.029603652205438386, 0.05607571317664078, 0.07687428785908608, 0.055554777218569676, 0.016113278613756263, 0.0383978704321048, 0.06486680959501574, 0.036714671840590817, 0.1401887734931323, 0.031698113607783476, 0.014264318705236, 0.029728493893579132, 0.03313897177577019, 0.01627966333481093, 0.036822383802744656, 0.04433051277432711, 0.03933648518737286, 0.07060178210057559, 0.15922245779825797, 0.0123680854261282, 0.04906960545227893, 0.0788024009295529, 0.034706303399176366, 0.04958302991825247, 0.025717146439297546, 0.01561386589591782, 0.04328983978578641, 0.048234431718986844, 0.04472887849495296, 0.0574946842126308, 0.03929749897290622, 0.019372802700907476, 0.012977390583874959, 0.002985941161656933, 0.01136445661916608, 0.055286826475733714, 0.013028869777166796, 0.028160942019894723, 0.026099855237970912, 0.015813029604032636, 0.09089985622032996, 0.03121707933924852, 0.02464253001005179, 0.06524235355637728, 0.028950349660590294, 0.0241176410382914, 0.07227822762703703, 0.00798026273485213, 0.04461173216001161, 0.03248134657980935, 0.05097456351523438, 0.051253611041653546, 0.03134602151300398, 0.052580666848488396, 0.03040162470912741, 0.054706468907815796, 0.03967711852202493, 0.05917191497921463, 0.054299013553968364, 0.062406656122015375, 0.054321597825976155, 0.05274793831631542, 0.03770264181038065, 0.059239273259956995, 0.014163347359205929, 0.06011735557788803, 0.0355716226922889, 0.03753066273225892, 0.039343881766281785, 0.14447384033231966, 0.06380901454136738, 0.054080881508848364, 0.03367372795999531, 0.02993804383872738, 0.0034371573729590787, 0.059790967648187955, 0.02031676091944739, 0.039071882248766, 0.07006209614055772, 0.03949515731824983, 0.0687178263380643, 0.02082485532868774, 0.052051782728202885, 0.061076624063594695, 0.05189917035280697, 0.07059860283568983, 0.04504755574969515, 0.045055898447190566, 0.058152068090895494, 0.02912855894875623, 0.05404661822643492, 0.0028731438121007338, 0.046329420029876694, 0.025557238991642674, 0.026102327786746527, 0.05267859203740955, 0.01725642543826853, 0.03611589368853358, 0.04380997135153702, 0.09598912385803077, 0.017216638661921024, 0.050194207203364184, 0.06868735902131566, 0.04650902551328463, 0.09755083239607273, 0.03776114794515795, 0.05505169493957393, 0.03166294059595995, 0.031013223342597488, 0.009219346271317092, 0.01697065740553362, 0.09310307912528516, 0.060582332643530065, 0.03412071728117524, 0.032913669147678924, 0.012333807779566176, 0.04139150072249674, 0.03211316089296053, 0.031899740288574854, 0.036919102403185064, 0.034826835842743036, 0.04394224026210366, 0.02249196607379183, 0.07034392456614202, 0.027347810551403996, 0.007774670112637744, 0.02173271931467518, 0.048683255820745425, 0.04349172693647204, 0.0019327962617089432, 0.026827401278780836, 0.019188294254784143, 0.0488435750406596, 0.0315235489829173, 0.03276927689571054, 0.0557960183059256, 0.09469081167011492, 0.0360798875560924, 0.04858424278697179, 0.024977371719996297, 0.031718817133937156, 0.056858425208878134, 0.028005885824020353, 0.07544107524858368, 0.022215481111479383, 0.04488152917474509, 0.06254399270420113, 0.06972779069216022, 0.04432832559330329, 0.09804827626794578, 0.05710875209901602, 0.021061384975309336, 0.04469695561114819, 0.018046455525402582, 0.010116983941125294, 0.031086695004975608, 0.030630707981125004, 0.021505941967329672, 0.07128126378501616, 0.05531575395575455, 0.03928765474307922, 0.1769306108115181, 0.026412624039597092, 0.019029773426272215, 0.024140732843549024, 0.034089978003213485, 0.041775958116857276, 0.037168984962326866, 0.007529380250602, 0.022882990756883256, 0.06323638297016583, 0.0646539137608582, 0.040738337988694834, 0.026217668069406386, 0.027922579507914283, 0.052839075966227445, 0.042255858575264295, 0.06590604616869843, 0.00894757945300831, 0.07512222945449815, 0.011264795283486527, 0.04288713800750914, 0.035757517757555174, 0.001979409839071694, 0.09907907821358213, 0.07244259179119142, 0.021614197851909746, 0.03773463747253822, 0.07195331441659121, 0.009923362879142647, 0.04539765793109133, 0.01600191624264323, 0.0309429788256004, 0.023987509513033495, 0.06397934270001228, 0.06341050709447553, 0.11359331107908681, 0.2140672592025611, 0.11082212590882856, 0.1742638434253393, 0.11297340805251753, 0.05080479460077421, 0.11477897769861645, 0.22949726591187142, 0.18769348731204388, 0.17460046245926814, 0.062102473250800566, 0.11458652109027871, 0.12210433341322408, 0.20822620650212612, 0.07860666546489924, 0.16961309217637585, 0.08947387547983278, 0.13793789991928687, 0.12070803857979276, 0.13530678626510406, 0.1899731045048083, 0.15157541410336572, 0.130079094200365, 0.18253638258864804, 0.11014481991409295, 0.15974627807736397, 0.16926705026097838, 0.12426945876570479, 0.11347030800196434, 0.14989080207963146, 0.11805902911169876, 0.13931338014381547, 0.19335640924832515, 0.10924206956500009, 0.15735216138343658, 0.16476639095814, 0.10280192844689855, 0.13686511635539994, 0.10750701831233118, 0.2877436968828401, 0.1531708075274383, 0.1746104982110762, 0.11994552828611867, 0.13095565200332673, 0.0827700622199524, 0.13041474796350927, 0.13797693975990818, 0.18451436032210627, 0.15811078761133457, 0.17740010013503416, 0.15871588981920676, 0.2419023284868848, 0.09259957549793106, 0.08530340773323852, 0.15284589431699247, 0.23132668387505317, 0.16847356703252564, 0.07211233894791334, 0.17254705570878523, 0.14945171112495084, 0.1591652616738312, 0.182082322275927, 0.16834936885824128, 0.17716126456376047, 0.1332292630667648, 0.20129799842834475, 0.1233968080111569, 0.20124478596112422, 0.16075800443368574, 0.1055145002300701, 0.1767515147765798, 0.08854130132784767, 0.14535257382498634, 0.09313772162122112, 0.1317731750708434, 0.09996232396412282, 0.14954644555766738, 0.11543910800208969, 0.22656500309465394, 0.23963213417558904, 0.12192027312853645, 0.19455504573641286, 0.1923957656347944, 0.08407018237536953, 0.15342907108847173, 0.19506009686137402, 0.12461874889390123, 0.11183375267372017, 0.1578706650123481, 0.1592301952862932, 0.08162951817916286, 0.20890492975952166, 0.16412085462962428, 0.14686233394088286, 0.09788122313517718, 0.09627601612479457, 0.1892712760356165, 0.2530360068645208, 0.12395507926421782, 0.10805033552911013, 0.13257533041459899, 0.12507346038135791, 0.09314248668811015, 0.27926402286656443, 0.1207101759651015, 0.18901927907380367, 0.13827269566395592, 0.15102876440411614, 0.09470698378619649, 0.12994833831344882, 0.090325144720414, 0.1272986623488607, 0.21201372987801032, 0.06960325543918917, 0.14389915181504143, 0.1482629265275694, 0.25201471973090406, 0.07457627689525967, 0.15584518982758447, 0.11635149573727001, 0.12750349893805482, 0.1625782753070516, 0.05653618181484842, 0.08135646912119082, 0.06699431236953506, 0.17775956391086503, 0.19183194024428246, 0.1283988258951614, 0.2764193851861262, 0.196058263461436, 0.1624971465958703, 0.24426765559661776, 0.15826881622835515, 0.14370404454248567, 0.17567631037485215, 0.07362989783887902, 0.16832131471845413, 0.10181352180699188, 0.12822356796072376, 0.17803127997584883, 0.1388969347481766, 0.25506342791261216, 0.13831202661798847, 0.14125202692324115, 0.1803128889972164, 0.1362917148658345, 0.135491045732652, 0.12244611587976256, 0.09837358018323299, 0.15519410702249697, 0.17465761261841944, 0.14487405998572228, 0.16840774475807146, 0.14772641983243728, 0.10833818540577927, 0.06804003004705714, 0.22732603483863417, 0.12707153260107004, 0.12928202568042663, 0.23790672030900759, 0.127084877852711, 0.14303020892604706, 0.09497432548913265, 0.11505973360110676, 0.2338527975183341, 0.2000791831843315, 0.20692267725544594, 0.1833091814431452, 0.20669228397309783, 0.13110670922023634, 0.10891285094041979, 0.10824452349615675, 0.15019179802508126, 0.1508539737833123, 0.18947816574044768, 0.18780519825316247], [0.08228416329309826, 0.06327392893933481, 0.02268796775399918, 0.07179199928237547, 0.04367097235855557, 0.06158509577113775, 0.0355527769293516, 0.05897143359987005, 0.05738488083044368, 0.06598293075277921, 0.041836532689030134, 0.01872550437016593, 0.008668513732000945, 0.027965685360193736, 0.022876063406827952, 0.016260179803676663, 0.037658480671985496, 0.022822186358333118, 0.0670440391367001, 0.022182361215292927, 0.034045973912842815, 0.057864428888405525, 0.04078052645068496, 0.035597704155671026, 0.02176448706567528, 0.05241228838361079, 0.05655840219509217, 0.021552083443009087, 0.06422411162225951, 0.03433214222651816, 0.04221567726363579, 0.045399079024190866, 0.038101290983538476, 0.07096616416088036, 0.052818567792494456, 0.03762676080148067, 0.0368166113302352, 0.06304093095804415, 0.051086534926247214, 0.0341616416980903, 0.11142890584925491, 0.018186023338667808, 0.008819414858495998, 0.08658167140017595, 0.024172581033781174, 0.03549992452345548, 0.03063012383908274, 0.015474873606205709, 0.06406865706066452, 0.10625646404561498, 0.05344247745890772, 0.020279157493684082, 0.050215918135138295, 0.0242161656910133, 0.032742429344404134, 0.04736929628697615, 0.03368699660284385, 0.01932302230758773, 0.020232219286563418, 0.09736415209068407, 0.055973662604247375, 0.03490008533962312, 0.043170893144223, 0.07925226308044889, 0.04429002502752889, 0.06980404708414309, 0.05627972622131629, 0.07299314853885482, 0.006123148777987809, 0.11149379349644147, 0.03825827389054241, 0.021446179448356553, 0.08053183675773683, 0.031002235726543495, 0.0281945311449348, 0.02009940262313091, 0.012133708486573832, 0.03205146017153898, 0.03336304483274299, 0.03855501038713321, 0.027308265092752637, 0.008699002116167498, 0.04555612704866836, 0.05641570299743645, 0.031247295762201956, 0.04955625131485924, 0.022115487485162677, 0.013533159602253188, 0.03832184003605958, 0.020372715981436834, 0.06671835217745074, 0.04059731269315366, 0.03606602519510254, 0.02421452626285534, 0.03032341479293762, 0.020613399739827842, 0.019177254927795262, 0.02644159748489338, 0.05382362152299574, 0.037072848588708913, 0.05041976264047046, 0.04843050809276681, 0.038080277191775466, 0.019612816132364735, 0.0470963353291154, 0.012780137307521318, 0.08535032295772145, 0.08122727605364016, 0.049059772713770794, 0.02870855315948927, 0.10128309018909933, 0.017044751514350216, 0.10665954886785439, 0.02012917088464864, 0.027267668178425204, 0.03069407111334224, 0.029537305160756075, 0.02968825321013649, 0.0304005847447702, 0.02923096958247404, 0.040498257524544196, 0.0202901853293541, 0.03983368774154975, 0.0371820199483585, 0.017712194127060713, 0.03393159315530812, 0.042474067229176724, 0.020128833805961956, 0.009617019639981371, 0.04346594041694076, 0.02598890080867756, 0.032377656579257987, 0.006472195194463336, 0.01847648557515875, 0.04187773289759794, 0.007991680796558579, 0.02932222406079452, 0.06938325030909431, 0.045037508506568215, 0.017671440164708806, 0.05134288326746995, 0.019288845210065766, 0.046290717267942046, 0.07031661353164143, 0.032260425974644964, 0.02831315602957001, 0.0339693536290959, 0.0231482716833031, 0.0392867737419663, 0.03773944084382346, 0.049033139667083184, 0.021019983668661407, 0.07747327668532249, 0.018612874123538216, 0.060661676369847796, 0.0708492131783597, 0.03958532969737726, 0.060141969982895165, 0.0724697572689864, 0.057407725572345726, 0.018191719202384837, 0.05257412445761504, 0.04452107714549188, 0.033919994584134514, 0.05415373647044744, 0.1112346489342951, 0.031195697825281855, 0.016827142324238535, 0.048061330322056055, 0.008618124298781397, 0.056585031411340164, 0.041758793916913776, 0.07860714810029154, 0.012526581356782588, 0.022286099096339558, 0.02242317329341125, 0.025449235916077614, 0.02443817605624997, 0.05660655465157283, 0.09190603610007994, 0.008285127903124499, 0.032411306991332, 0.03453716267681411, 0.06415261263628641, 0.06785230786209145, 0.04631216389938228, 0.04064258848947864, 0.0232532391354682, 0.015160222143505611, 0.031194033499266353, 0.07716430576458093, 0.0077075181968299855, 0.04413722879103115, 0.01654841655474757, 0.06227107388117622, 0.03395285592564652, 0.03114815823914063, 0.04128903646262423, 0.011476373446414308, 0.042655476849646344, 0.024933691301773635, 0.018807154021135742, 0.0453310925513506, 0.06418293822676906, 0.030240179339964545, 0.09344136823088893, 0.002547547107584955, 0.04721081184764062, 0.033642900581922264, 0.13734605103250475, 0.08159237823659375, 0.06469168955640447, 0.01980773571337904, 0.013291965437782629, 0.03397532911490529, 0.05778736044322291, 0.03211182981519209, 0.02091684908185515, 0.04451220201688909, 0.05487934813924855, 0.021871239502703952, 0.015922091796153014, 0.08305284825544204, 0.017370693197834398, 0.0506409973416838, 0.09284431760710093, 0.04939116319761642, 0.034412144788450776, 0.03773249242635023, 0.02829666407178006, 0.05614147416406101, 0.01893959147104573, 0.017815480016232017, 0.02367423317815748, 0.02332698467427925, 0.1313271740030858, 0.029939125937920426, 0.024178782515528224, 0.007218236991790154, 0.05831647438988571, 0.055217319318363746, 0.10712882368675164, 0.04242791426217845, 0.014291194027229665, 0.02493031859968699, 0.04689362846435078, 0.06418223342587871, 0.02098052056446191, 0.00709172044392495, 0.03139051589964619, 0.044004059727153474, 0.019804772868331884, 0.05282876825320625, 0.05649539912419935, 0.03600178106177238, 0.05970717678146978, 0.019884041901076996, 0.04784736579524414, 0.06205962212275594, 0.01972803384095671, 0.03776512777192458, 0.036245328073780385, 0.05274541405660491, 0.036280977975336776, 0.02491472679520807, 0.010497163692038628, 0.12861957413054284, 0.0877676061504791, 0.04491156748225612, 0.016626320035767653, 0.014902837668365289, 0.028689745700948184, 0.03458535726813059, 0.062401956172599915, 0.07997034793539394, 0.0305168443329392, 0.017729446427115512, 0.026965013652619337, 0.05167852936973495, 0.0060282812374944416, 0.027698937375398896, 0.09602837054239166, 0.04927274515672077, 0.032187230103919585, 0.022602677270169222, 0.06823262455122125, 0.08166106567988474, 0.030311278044997208, 0.05507167068219954, 0.055392037160814776, 0.03602883545681834, 0.022021011607120597, 0.00973423779566562, 0.02087003727924199, 0.016311304681303523, 0.0863823046787612, 0.04555530350414976, 0.01505921345068923, 0.06898602605947564, 0.014886120672247585, 0.0645169449008761, 0.08651659989188756, 0.09855906539145978, 0.004554751813561926, 0.08864048673140426, 0.04581671568655199, 0.032985608634208484, 0.050887145222194737, 0.020163081766616915, 0.043507600278263135, 0.05385122367090756, 0.027035152832526835, 0.07738424960764186, 0.0774438895525471, 0.051537940744310624, 0.02743705979458267, 0.11123218213117893, 0.013720501616086452, 0.041225382216995766, 0.05663214964912303, 0.06338160259709244, 0.017252989533928134, 0.026739833598595955, 0.04822082599745162, 0.048712865119018865, 0.01124404196161777, 0.03242110525588355, 0.005609789429487842, 0.024963331243564046, 0.05136306968427474, 0.016484097727844794, 0.04619424381563741, 0.03961440273410371, 0.029914948203030135, 0.08669956467084347, 0.022279296235571948, 0.021201425847867807, 0.028438108800459775, 0.05759603764501311, 0.09105759372393932, 0.05838660207847434, 0.07200606723105715, 0.04800156780308293, 0.03098756514279352, 0.06133028726664282, 0.02784426042419528, 0.03150819466569491, 0.03887114039952717, 0.04281777257640516, 0.024473624859726237, 0.05941693288003726, 0.022007767862129598, 0.18001173983418173, 0.09554381226940502, 0.09198420005099428, 0.17514404780682058, 0.2671782504166326, 0.18676307352800525, 0.10611836137550493, 0.135741250048722, 0.15726383144576705, 0.20746555780210804, 0.16161459798534072, 0.14341242551322908, 0.15112737524172953, 0.11654767553291975, 0.14798091424088325, 0.17834856295056883, 0.16203859700791298, 0.10599132867590075, 0.22784354255324413, 0.1492963331721483, 0.12996421165523991, 0.14115122507416433, 0.13936176625711305, 0.15847408182678685, 0.13522308349849718, 0.16341210072559698, 0.13308546836337737, 0.15484045019313214, 0.12580050846501706, 0.17569403764942002, 0.13058779190384573, 0.1173375275046114, 0.244821583131148, 0.17269930802285674, 0.22788874174077667, 0.156217799672196, 0.10000905532750393, 0.18488828783794758, 0.10654895641510526, 0.12113335527359478, 0.2525566503285401, 0.1351458771574882, 0.12171876136093371, 0.20136674715866967, 0.10857142087432647, 0.14859323299700214, 0.21994353662575447, 0.12422310278540659, 0.2080649296723066, 0.18641749126536233, 0.15552910195002634, 0.13004094302173586, 0.2293898603848873, 0.127768412142271, 0.1672136128669785, 0.15480122649140898, 0.1503447398182846, 0.11650266020648903, 0.15165645088399612, 0.24484087322508138, 0.11754444019208032, 0.10705256729476875, 0.141681817570521, 0.2139375605169804, 0.19075285943765796, 0.23883930978275117, 0.13296750614479666, 0.12665327923792985, 0.10401110630482437, 0.16516763716936111, 0.2100600830970272, 0.10706794267940907, 0.16314859712316146, 0.09082046652873678, 0.09147096710700182, 0.1472797599290648, 0.14503486184102876, 0.13618070872560625, 0.14789099084033122, 0.13830769056033704, 0.12584843492556003, 0.20525953101535, 0.12925525856835227, 0.12063273979771523, 0.11497098231507887, 0.14834797760892302, 0.12248189218582646, 0.1592310533047684, 0.11086040732240486, 0.08696074702686842, 0.18451143386623553, 0.13707603568271284, 0.13293606589638418, 0.09979699452918384, 0.10775441874659832, 0.6059159158218292, 0.08978342862739679, 0.20761719724584013, 0.18442740934270044, 0.12673768680542707, 0.17423632554709914, 0.1038520970952607, 0.1919843917412143, 0.08207356572271356, 0.18133440595721045, 0.1987305773241866, 0.14762744127262026, 0.18921061719377197, 0.1170738630237118, 0.1556314666184687, 0.23570999382965027, 0.15302765633790724, 0.19989567448294934, 0.11699758364909119, 0.08192139767831372, 0.12867787342158057, 0.1536376002214609, 0.16057926079919263, 0.10233487528298171, 0.19919412180541024, 0.2384910155688563, 0.21007984816547365, 0.17947990627538774, 0.09963166509424487, 0.13405158184468746, 0.16669705510139468, 0.18025105037996847, 0.11044547111997682, 0.18120161227641568, 0.12213414189435783, 0.1780407028573175, 0.1685140624402031, 0.05344554947148408, 0.15619709997648196, 0.13628273631536192, 0.1880182013396294, 0.1388961226949769, 0.1566560479301599, 0.2071432186470878, 0.10051586079381167, 0.12289931817400841, 0.08358244483749713, 0.15989071629460783, 0.10959050933560056, 0.14403838063440016, 0.07965519468510344, 0.08713546869975906, 0.12081852378023249, 0.08990508338977253, 0.11595842368420094, 0.14669408571095238, 0.08762715159044152, 0.13029808809439983, 0.1506287898988493, 0.16689113581613188, 0.13310474313555226, 0.1591211656529096, 0.1819345592370918, 0.142456945332308, 0.20449699773903818, 0.1178834800638499, 0.14888469880867392, 0.2235768311807225, 0.1542952713826972, 0.13832842089956807, 0.21857452218330678, 0.16514523675845516, 0.12473756913095714, 0.16709827066909883, 0.15554183433132787, 0.12713131044180165, 0.07359749231968196, 0.14715240547253242, 0.12275265830178415, 0.1036564075958825, 0.15970734548905205], [0.016817165944244594, 0.020858930919559735, 0.024853912820558877, 0.036807854945260676, 0.05201513308190531, 0.05345925478444946, 0.021959684353562135, 0.027268880512565378, 0.07333522977968378, 0.046205110772843325, 0.08409974570836752, 0.022190811165097742, 0.014156148047937502, 0.0998895685939539, 0.018833545750127207, 0.04344044501082071, 0.03828971413895488, 0.06126138914917266, 0.03759482642635703, 0.03160349791869521, 0.03256471609816917, 0.020361398947575403, 0.028886365997154387, 0.042514378775752364, 0.015480538826405764, 0.028773576787282384, 0.05287219777763371, 0.013497380423359575, 0.025475077976983403, 0.052562744221499855, 0.03211085688352826, 0.03624665340588939, 0.016411784773452148, 0.05546397664734433, 0.0046415663335562475, 0.08445053736889556, 0.030779872960861654, 0.037449537851517244, 0.0202707132895387, 0.0735684882308687, 0.056295166723430164, 0.10965968707516309, 0.06290744013723827, 0.052571676806696964, 0.0671594426216137, 0.038360523645796125, 0.06298019933784682, 0.05017340025534073, 0.040112643337418, 0.04388823489388151, 0.019435010955578858, 0.056442883796989925, 0.016531330878816305, 0.03635982757494335, 0.00987689677370532, 0.03306092273804449, 0.08017317737422644, 0.0504697383862109, 0.036343728237214594, 0.10969517992869501, 0.03747861471868331, 0.041851191781461246, 0.04921770940024046, 0.05892536490254345, 0.026127158611592267, 0.02152735412481331, 0.005263041755590107, 0.05042208771732065, 0.057439541203841094, 0.07736757953440951, 0.015258732432078932, 0.00837459835419131, 0.03666273874020384, 0.041980009465929, 0.019404593434545304, 0.02395359863106522, 0.017448309395882874, 0.024483635713676774, 0.06454506798857643, 0.024801255767083457, 0.041415751235739845, 0.0827745208516717, 0.08900529780094663, 0.032190244659901626, 0.047882513909210125, 0.027595258866166397, 0.06476953175039062, 0.027528848619230335, 0.05048924298476308, 0.02069258067246166, 0.055216296590984836, 0.05830963322472188, 0.05315707906359627, 0.05414474642865601, 0.05926449670486393, 0.0472765268697854, 0.010098835318199089, 0.04781849194137801, 0.02805602053300508, 0.02154954769197972, 0.019380810234936017, 0.01535122510000703, 0.035179611670994954, 0.01831779429208367, 0.008182359123302084, 0.05905379571260945, 0.026344618414558714, 0.023358478548846418, 0.03064909983696717, 0.06104380868735814, 0.06515324220902498, 0.031189779796066786, 0.04667993589875199, 0.014430856643875521, 0.06458098219046671, 0.023029459107126442, 0.06252421231399621, 0.04906555667759911, 0.015734351416599127, 0.09375382485168596, 0.018520708000587843, 0.011965702531949408, 0.040652275671281164, 0.021548040413988695, 0.01660503428279152, 0.025192632850620057, 0.018151825173727928, 0.02983159783686842, 0.02247615401903468, 0.12373413184597609, 0.0812548092536388, 0.038183771839906136, 0.05633531356110208, 0.05398060059956005, 0.028985398183126124, 0.01755714559206559, 0.027110376921031746, 0.026638007106920405, 0.006783658294983569, 0.046362457571611296, 0.0833834918035615, 0.011223456221482447, 0.051466606467241244, 0.0769240835741643, 0.013740309776978628, 0.022005816253142494, 0.012425509461712454, 0.11305663584461136, 0.05780229915774638, 0.030657565108530467, 0.023577414986286915, 0.09813912663488619, 0.06525257316928718, 0.04201031973465316, 0.04981582488624319, 0.0406850527431215, 0.09572120758915141, 0.02949237984965646, 0.09498449147588785, 0.027490856403845455, 0.05782190717816834, 0.047034278376809055, 0.02726823125304955, 0.010056561628927388, 0.03838865056393608, 0.006431714629739404, 0.008117893782083788, 0.012630344135686757, 0.03283976847606321, 0.03313191993642719, 0.044383269419232686, 0.0069164620306823524, 0.028260303623673898, 0.045083921943460746, 0.006012274787926506, 0.010256701141535755, 0.04502289920985218, 0.030573115406197407, 0.0204217302868323, 0.04239279679172943, 0.010761804935041695, 0.07197852637017928, 0.06002421460805401, 0.0276272775109617, 0.09251681501947104, 0.045082730676738486, 0.03682907175032362, 0.058183274682491064, 0.026252440800289475, 0.057734128823804284, 0.09081760902077922, 0.04746794542898575, 0.06731885785777723, 0.015194156008111614, 0.05830587939389291, 0.02986836239635464, 0.07790488296098287, 0.0312836179059119, 0.026871432182228854, 0.05162300331698311, 0.04495771661881478, 0.03129277074138724, 0.05867850072982331, 0.07758498762644107, 0.012230376333689258, 0.03301566992435725, 0.03856988015374349, 0.034144546446059985, 0.06676694513448785, 0.006794138377787726, 0.011682191585761406, 0.01899705189580639, 0.05905170046213654, 0.058607744849136764, 0.05854621649749818, 0.03044939220642611, 0.057120051895899165, 0.053568123539368954, 0.04812660101320475, 0.060727261157045444, 0.04700151279628758, 0.05205334937800804, 0.04728094719710851, 0.0723071780896956, 0.036573129435700756, 0.04423085622669709, 0.01004860867866345, 0.09309532631549144, 0.014102051706774341, 0.017136207090750817, 0.011489378746538874, 0.037838158933746244, 0.03349029203696597, 0.061147433570435936, 0.05254770591554623, 0.09959632545829782, 0.012506653494652242, 0.06041031143057251, 0.09193796664476396, 0.09639804627025321, 0.016443648285442786, 0.033099388012722615, 0.07433221660434239, 0.07982679838014227, 0.04429089836776257, 0.023448643267094612, 0.008456100533235698, 0.017686572316433155, 0.024016427416955272, 0.04391798974886056, 0.07907122118218292, 0.043147408718904184, 0.03571067914186466, 0.023812730383548527, 0.059048559501646995, 0.07681113923148764, 0.02815249973096915, 0.059188171364967866, 0.061710925712700815, 0.03127828018829948, 0.016680488197673714, 0.011416555386066679, 0.03351038269278023, 0.04251619057369329, 0.03920547266100203, 0.049267604706748847, 0.018828681091808023, 0.042286341213771415, 0.031133608314238732, 0.04250997760062737, 0.047937959522729924, 0.04975213999709776, 0.034290114642992135, 0.009835109550265536, 0.05286213521274829, 0.05831404972160536, 0.011997921317214928, 0.03912112255009913, 0.11436994803408462, 0.06793590337638894, 0.02859761213673459, 0.07314474967819068, 0.04095835844054818, 0.05136087484237167, 0.04346352723997928, 0.05955198652020866, 0.05171649285682267, 0.042766130589429414, 0.0335731789199335, 0.08359588968056826, 0.06715100799356738, 0.07750364441064096, 0.028054867570679036, 0.036483290304820386, 0.006440194265451283, 0.07050412121198832, 0.012700630787519679, 0.05052266740089944, 0.008258429738963324, 0.015631071273087254, 0.0224829587950221, 0.046053456007352764, 0.04524776516782661, 0.04565726214599225, 0.06779865872475409, 0.04806540590981322, 0.04230571557737647, 0.05220075235551885, 0.04854683088318956, 0.03625051065858814, 0.05259025443886077, 0.05369239832244573, 0.00723666332158891, 0.04814169294531307, 0.03359285971870826, 0.022987709230472966, 0.011468135128398577, 0.02349533058042007, 0.01915304271894838, 0.10536135159312718, 0.03109299033249338, 0.051360269632911494, 0.02232196158729494, 0.059125447916167403, 0.05022078279345747, 0.011583586493807455, 0.08730888036229918, 0.031552811626405004, 0.023680967091011907, 0.031484449770481836, 0.067425305774856, 0.045018210751755584, 0.07484937191850717, 0.02107456743326639, 0.006331064083027624, 0.10007627954285953, 0.053308029028196494, 0.0188344037686024, 0.03799041124781774, 0.08105234753700995, 0.025148764740855947, 0.027409488290187814, 0.023240060507950765, 0.016846127898222017, 0.016881812273735003, 0.04098415645139833, 0.031199641262872085, 0.013482365100043676, 0.03568529098805401, 0.021059471670718446, 0.058216798690057574, 0.05213021480989072, 0.19860259467555633, 0.12450604969936034, 0.14172591359144257, 0.14196805866254916, 0.09348546425181051, 0.13028488073858524, 0.2200887409309226, 0.11625373525725258, 0.1721771118501502, 0.10667259534520489, 0.17135827111140375, 0.1719421067184979, 0.14410754305220422, 0.15583999575145785, 0.1597298684740259, 0.11298135238429231, 0.1801372097144204, 0.15244662461261596, 0.13091929347044037, 0.09820251274974116, 0.14833590406323635, 0.0875263344196062, 0.14321843672904278, 0.14600013262562214, 0.10175413467110166, 0.08305196725432912, 0.1460330897281247, 0.15902993990288627, 0.20307447971595874, 0.1116768885103445, 0.1552461550360726, 0.09659634812945321, 0.15743325945110093, 0.15346987293131892, 0.1438629005344645, 0.20145185952705724, 0.12115481339635388, 0.1805029400894719, 0.2002721913759747, 0.08969062473624946, 0.15895785102921148, 0.1169947031584959, 0.1240313356562007, 0.179659032953843, 0.16187497594904515, 0.16057559889891457, 0.21932728017770478, 0.13561279242557867, 0.17044719338657396, 0.11451785662962545, 0.16686766288213192, 0.14528711927273583, 0.11064083886242683, 0.06473947046024185, 0.07627869280235422, 0.12929996745961328, 0.14507160341787725, 0.2525142090575349, 0.1376627517804023, 0.28575055060848115, 0.07734368525205121, 0.17831788879008065, 0.19532864132235128, 0.20476275363997107, 0.13482978927993006, 0.12025724946250839, 0.12069601866026079, 0.17217297497535908, 0.11428002463353258, 0.12638664233588404, 0.0983230566846267, 0.09818425687450556, 0.13396234792326728, 0.09071447060353334, 0.12551384602463053, 0.11222071900603273, 0.09370131718535578, 0.11257306582504704, 0.2513116348775164, 0.16276699340631887, 0.11970860027377644, 0.19550096514003892, 0.18428145427136652, 0.12149993600624225, 0.08158451817449063, 0.1135590746097507, 0.07843398158588717, 0.13983808908491366, 0.1193666109634984, 0.16639233596863287, 0.12670329711850614, 0.15922395933058955, 0.12362148627758988, 0.20544944421177913, 0.10437442350291437, 0.13686182217732554, 0.09207246870162988, 0.16126167660038318, 0.10200276084604765, 0.13996594915947608, 0.11228625782795491, 0.136302363487982, 0.23483346667020555, 0.11462794346434456, 0.13125451822434703, 0.13127362445717858, 0.13287519254992086, 0.14366267579457453, 0.12857694899843586, 0.11832433302075633, 0.19124038247091157, 0.1736693132308222, 0.1253986493834565, 0.25631454142351306, 0.13379681164458876, 0.10502503899436806, 0.18160783805914466, 0.17151911893198568, 0.08905718493605815, 0.1581224781130591, 0.08181484250892555, 0.13409305784490802, 0.16871215745566354, 0.06139306817203761, 0.13222141311533991, 0.07842868025745116, 0.1760791500489558, 0.1789211830304515, 0.10133598856027089, 0.1950630079954863, 0.1889878388253912, 0.11578426891637426, 0.11020126527235394, 0.13873510633505162, 0.2042852203932501, 0.15233589426404046, 0.16906506351886258, 0.14464123054377495, 0.09633711929763518, 0.12863678046532218, 0.11721722871786165, 0.14355713952212565, 0.09704089363015468, 0.18503549929347732, 0.11075351507433, 0.1588445772687274, 0.05122641875078121, 0.24122525997940572, 0.18886308906780136, 0.1511660626819057, 0.18877455994727152, 0.1883126089289304, 0.18260398218708654, 0.16961722905116697, 0.171723235398531, 0.14741460672549664, 0.12154498963706917, 0.17055357235573954, 0.13596923781498788, 0.1776128733951238, 0.1901086561021305, 0.060081226871378964, 0.13203986559904393, 0.11806875842833713, 0.16314039998237165, 0.09492222384940233, 0.18113194424058163, 0.13273573390418483, 0.1772058662027121, 0.09333528037513457, 0.15728276913925526, 0.1647317637839625, 0.16953210136102093, 0.11490374277796477, 0.1337996308481501, 0.10110793950697107], [0.019157568383361065, 0.0741584525413571, 0.05250585836268241, 0.028290824566577232, 0.027021447519561457, 0.02423722736327158, 0.012667590372955367, 0.02108830147452893, 0.035273139515230735, 0.01651617957489385, 0.043333939637147614, 0.05893301429046739, 0.03503514281023414, 0.016650656733902234, 0.1304366580781437, 0.045579642117504156, 0.06275679277736815, 0.011869311434096627, 0.05284387167663344, 0.03995867498639611, 0.05903833988873709, 0.06780464953232197, 0.02603153551688358, 0.0012298951497218844, 0.02155043060831245, 0.04172114069543539, 0.03332575550302863, 0.033456909755665454, 0.025343247651753407, 0.020181983070928725, 0.031738381104303465, 0.05142903751543453, 0.03718628322765712, 0.05997489769792846, 0.06081832219816505, 0.02916879771697906, 0.019449200819156343, 0.03720943057428926, 0.02772148717345009, 0.05156390346406449, 0.03495787518219121, 0.041124672298469854, 0.05059840668353343, 0.020275041686310884, 0.04729536114140384, 0.04794591534582358, 0.017735492776057894, 0.16273901587532413, 0.04247268061003378, 0.042512076681539904, 0.012600382436968148, 0.0604229097464873, 0.009352785381188077, 0.03313375088656622, 0.06129087204293859, 0.04621178339866381, 0.017918246880834623, 0.08860105618594155, 0.07020083466364492, 0.03385097772303609, 0.06119239910115158, 0.07434010730996247, 0.022194725874390815, 0.03890404387587502, 0.02203593499988558, 0.02601184322678995, 0.06032893374081581, 0.055033224559719526, 0.029440755099659006, 0.031118723225869963, 0.033051162777889165, 0.03010195792622624, 0.026957356603816155, 0.05438865733242804, 0.08459385709776994, 0.0003959483840463368, 0.0644120138378874, 0.06159247702828819, 0.03302464464439019, 0.01096650745884906, 0.021961712571341666, 0.024144622654984557, 0.011026691326180534, 0.07562600121262573, 0.0384557330530257, 0.03186034230184892, 0.015232863558095791, 0.04396966237935328, 0.0758475615012069, 0.06294487119321862, 0.0835954300278137, 0.0827239437269107, 0.008727170211533386, 0.06172632024953924, 0.07916777124327999, 0.005591093532500729, 0.01842957609633525, 0.022902269359497775, 0.0375360100259704, 0.034512257158395745, 0.03247721353545785, 0.03738129090878271, 0.002406420544796293, 0.061046447860257286, 0.04735005598875785, 0.030984485469337915, 0.017834773940605023, 0.024209820567780448, 0.0168267956694528, 0.0162741819757127, 0.059480866747758085, 0.02999689662829042, 0.022005400650443572, 0.03697298136689971, 0.06451067830165548, 0.0567349088528464, 0.013123585057685213, 0.001196557157879485, 0.060267175562799945, 0.047498864737609704, 0.03631107756988176, 0.05407399820884871, 0.10161191810883823, 0.0429437404137946, 0.033110025143551255, 0.05019328023697581, 0.028300195737110994, 0.05135103827342392, 0.019718497961519227, 0.04414214707550503, 0.032531873908855265, 0.07888036569760692, 0.044578204322005474, 0.01644435117111331, 0.057515678852195704, 0.024436249345120405, 0.01713579914893114, 0.045615345645215244, 0.03931228446984484, 0.04479361292455466, 0.07397135088761007, 0.019569154866340182, 0.06596573973975836, 0.02099734577049892, 0.02291091083128366, 0.08689796612147363, 0.046081479503622944, 0.043314515477827484, 0.073062157739074, 0.026065716444845163, 0.040240821338468985, 0.07512212986306799, 0.06454987902074091, 0.08477928867984204, 0.10307964298032946, 0.06679614840616142, 0.06744284152744279, 0.03525559993220433, 0.04464439048822369, 0.01700414885436335, 0.026480018709515853, 0.054166488003947084, 0.0895928795779905, 0.03514994108568757, 0.02674429989119451, 0.02570065065106798, 0.015040094768928905, 0.05952810372916922, 0.03435045938878771, 0.04123716847971082, 0.030915382423348008, 0.03962589405296792, 0.03768902076708694, 0.04820171210374083, 0.04089525194778558, 0.06544936583527634, 0.016185233422044306, 0.10368396377851886, 0.06537340821758394, 0.028743222468502583, 0.04182460470004909, 0.07596501810175758, 0.0328123310370551, 0.05236973219941701, 0.023840524053441423, 0.050047041713109905, 0.04535305629213972, 0.03889128851193575, 0.06362278622785403, 0.07991630809321519, 0.04950128833673174, 0.04902690371137954, 0.01800441262011807, 0.0720260851085186, 0.03202949068509042, 0.03298955398701853, 0.07357962714928774, 0.04519848273165765, 0.03932815398119631, 0.004652821601578786, 0.08360624718930453, 0.01727860559889626, 0.07351129210644192, 0.03786488391098477, 0.04091019449274867, 0.043207316794582916, 0.022881948877306237, 0.08731762908639447, 0.028963673844813343, 0.06631117644569566, 0.07281942278026574, 0.03343275500341289, 0.012406139886156927, 0.0563160234671687, 0.042907021819583835, 0.02355540719544215, 0.05288894445965848, 0.026804229034291163, 0.05899431664616831, 0.017307320489518104, 0.0507477363721738, 0.05304053027723586, 0.016888425527741353, 0.057643228661148786, 0.06866081407473934, 0.008698026311673946, 0.04977277840577787, 0.07087820960629372, 0.023545053517145496, 0.045433610437377814, 0.04856645805580963, 0.047919037151000196, 0.012911011938065773, 0.1074158002231871, 0.020032502079923308, 0.04239661574003197, 0.06708490226658122, 0.08963653126791601, 0.056736931324966496, 0.027009477395744576, 0.04883000762352059, 0.02659687584626579, 0.06576735361088669, 0.07208767091675151, 0.04461740121065129, 0.07124611567105017, 0.042794288151086345, 0.028282307584079045, 0.016870514392071677, 0.05142168690180106, 0.0325321305483099, 0.024541873717680577, 0.039568154006114895, 0.04089392278523695, 0.07806981403020122, 0.0029337025837101525, 0.030438557807956974, 0.038929083459680124, 0.06794325015958279, 0.05521592503834156, 0.021228562597365632, 0.028324348574143746, 0.038002277949764844, 0.011831923470562025, 0.06190935397640832, 0.045745113278709115, 0.021157249387714173, 0.02078237958372601, 0.032877946467769724, 0.01725174081061156, 0.05083524276532474, 0.016237208657267115, 0.0012616717586136094, 0.05465476946424573, 0.05022838621610596, 0.029599199319378506, 0.011971864751690339, 0.03040458946939438, 0.04614827854018058, 0.01700687995781341, 0.0697419096926047, 0.04869911767121765, 0.08766735588470775, 0.02392740416971426, 0.034515934380432295, 0.014179849850704834, 0.05116911920448465, 0.04592692509533898, 0.047691731202986934, 0.08322831303361924, 0.018420335160748615, 0.029962196675760132, 0.027822087924446792, 0.015195812673247872, 0.04532559204005426, 0.02447154876145144, 0.0319161958571884, 0.022297232269099163, 0.09918459916427251, 0.00797504711250264, 0.04922938841064611, 0.03006453070068552, 0.021203852431367964, 0.0262639531865716, 0.027503129132392428, 0.028384827385326068, 0.07938904807932916, 0.044136968321136894, 0.06228770181957272, 0.014355516684572063, 0.01846014875017347, 0.03653442667376611, 0.05569820036931385, 0.008867889071904845, 0.024891569872476885, 0.03167448937141847, 0.04694560369957359, 0.024060875838322025, 0.016447580231714155, 0.021102759468879913, 0.030740266215176355, 0.018628609569502935, 0.03829550576366244, 0.025532028953274413, 0.044252096014397765, 0.010529208192301374, 0.038735676902316274, 0.0821793471432982, 0.018003225183835434, 0.02716662309643242, 0.023454216556743752, 0.0346210110001266, 0.02712459168246677, 0.03642198411867984, 0.027109714254977244, 0.04938714889689319, 0.03918117235204385, 0.0395811851617069, 0.036765712448546005, 0.04584108494342335, 0.04293874552052829, 0.04200340579113653, 0.10873456695868124, 0.09826996679147405, 0.02184724945935511, 0.044123791608839266, 0.04511516683945253, 0.053534538244768504, 0.0270561398112125, 0.046302181773728905, 0.06923546428762137, 0.06017848556380599, 0.11435940666424652, 0.21817367433780627, 0.14163851828104065, 0.10624833585273837, 0.08357169662391947, 0.12407672636571432, 0.18422563710520345, 0.13107871636748314, 0.10288688759770125, 0.2047237444428667, 0.2815158923547114, 0.1398835180988235, 0.10468121107307174, 0.13339424776213785, 0.22658423190155338, 0.12659470415523938, 0.1995536162247581, 0.2632659313178832, 0.10205048812373031, 0.12993140777032222, 0.15724060365990286, 0.15051638947859888, 0.09309914143335435, 0.10184151465974509, 0.10929632391179762, 0.0676013068145802, 0.1693050329002642, 0.11337896733875237, 0.10180907849703105, 0.08915768034996525, 0.12005673360920723, 0.1500872883104509, 0.11591078833706918, 0.1823004887950036, 0.12123887622428518, 0.1440516645990072, 0.1153053796940273, 0.11804802042822685, 0.0877105326001202, 0.09904312570729563, 0.15963810646245558, 0.1950092133014433, 0.19621581710394354, 0.1140925552575819, 0.12092280366848554, 0.20660122676241785, 0.08342886719131663, 0.2673195783169039, 0.1595668602854975, 0.14532861059471486, 0.09183900340670541, 0.14180201676584062, 0.1369122307627432, 0.07881360113500588, 0.2554164259063621, 0.11706962655749052, 0.08818943714422565, 0.23990804840239788, 0.2105043987713514, 0.20239255421103972, 0.10287914244878678, 0.20010685428015648, 0.13379886476022582, 0.1182698488475815, 0.1424025071244086, 0.09838941522062787, 0.1503098368524544, 0.14812234939346391, 0.1607628461093672, 0.1677403289584383, 0.11558482558616709, 0.12614514077863387, 0.059597744951925935, 0.11432288725289608, 0.19624984672954007, 0.0966108271912221, 0.2348177465459993, 0.1532854602461861, 0.10607190580377657, 0.1502727581969192, 0.19013998909823357, 0.15650450041697872, 0.1546128607925869, 0.19623691516537822, 0.15393755428733366, 0.14952425965138022, 0.13975636282515141, 0.15943873974104084, 0.13175310356722725, 0.1436639781440458, 0.13270551939645123, 0.2558132288076224, 0.09384156490165381, 0.16123086454406862, 0.12162827871619694, 0.0996394025822801, 0.0878656500830285, 0.15240471960315782, 0.094515860170847, 0.10639460502012123, 0.12342299289640882, 0.10389491374934874, 0.1468071296450592, 0.21410711109638217, 0.12896465077515573, 0.203040664594981, 0.23490252183570018, 0.10743158163442727, 0.11714922309282327, 0.09713091662213688, 0.14633598557162672, 0.17836344037805835, 0.07978422687419, 0.08063847619679668, 0.20087793709770327, 0.17322271461448363, 0.1719260341938465, 0.07558375146360168, 0.15653440848954264, 0.13827799699239193, 0.11119961573351776, 0.1282419923753027, 0.23735084691114966, 0.12464557729300954, 0.1614245775366022, 0.12756999536988237, 0.11434466713258337, 0.16765320943968912, 0.1692767029688243, 0.053320205995752934, 0.15314485246856369, 0.1986450972335954, 0.17130459899142866, 0.15847539949801662, 0.11202492225434511, 0.11954062783549871, 0.09383350565669038, 0.11496952674802273, 0.12181862092186367, 0.15266561850665078, 0.10344478346767927, 0.09682345489460616, 0.15524290682327363, 0.15227682888507843, 0.14475108755211677, 0.13522861465331049, 0.13262636719211457, 0.08470339234918357, 0.16950017081633692, 0.08962438877431617, 0.1861166332157389, 0.17369093223204538, 0.13536635726209612, 0.15480962281505908, 0.20715112467446636, 0.17504920612179464, 0.2080340563289581, 0.12250656787786754, 0.18539191403936955, 0.12176097280556157, 0.12388816914491116, 0.12429145315001089, 0.2323227054289272, 0.1514315121476689, 0.15078833536995997, 0.1170178083702922, 0.17401481888467268, 0.2440392081775973, 0.07732118524971508, 0.1974003575742245, 0.18964472857694473, 0.19075134258356788, 0.0932049764800937, 0.17112968579655694, 0.1356416892620825, 0.16256276968746416], [0.03399896292736934, 0.04926822906840713, 0.027266187713511532, 0.026121196532321554, 0.0776946684345603, 0.025044172671773744, 0.04027947813512818, 0.03257231569037803, 0.027418610482146184, 0.03204517825055988, 0.10311804696797364, 0.02711165054220586, 0.05082280532787404, 0.01663680203379162, 0.03659472545428622, 0.06370188097559637, 0.04296207672826225, 0.005129861200393568, 0.046504053602656054, 0.07472672124182986, 0.0337028622837557, 0.06469237903553633, 0.012848722286552433, 0.03330814314164943, 0.07797884108919291, 0.06437671250633656, 0.04878978417705625, 0.0793714280570707, 0.010150983880814767, 0.024845572038283272, 0.0443512890788336, 0.034812896872960755, 0.007333120494525159, 0.07048228004526708, 0.008853283605628438, 0.008097098325379193, 0.06548302773866924, 0.035048717888252395, 0.02378757780177459, 0.03298469315913897, 0.055750363296078104, 0.027112696252222505, 0.017829430477333166, 0.048835205530086835, 0.03543225597710379, 0.06916529063375727, 0.044862212267734354, 0.03553118857164537, 0.04412175764540031, 0.017574403637779817, 0.0326932426692257, 0.04670328625868406, 0.11663307901471855, 0.019891574460592483, 0.07157281386635958, 0.044086751257700306, 0.02582914083294811, 0.029228412764026757, 0.0682625402846644, 0.008826585441467263, 0.05234589920409265, 0.014596344084448874, 0.011453932815892322, 0.017922098387873942, 0.038874304342654445, 0.07046914929824491, 0.08440830294162997, 0.09567011718548114, 0.051625933603293477, 0.01100809549942853, 0.04463658788271489, 0.09420583204876992, 0.022743240997736013, 0.069343390754394, 0.060213997569536014, 0.011924483171183498, 0.06285329687318976, 0.05985339232269795, 0.03189948747955984, 0.030540257895125017, 0.012756528392914804, 0.045450180919179996, 0.06187933865153502, 0.023252350473476034, 0.0496458912628793, 0.03884851399268355, 0.04772226746764876, 0.03732048267979295, 0.05466189025150192, 0.020545122153576345, 0.023101860161630378, 0.015745642594993114, 0.017296501412807454, 0.04759818420655305, 0.00209609484544114, 0.020357338681576714, 0.1188294071283552, 0.024097764887095943, 0.08040204614160523, 0.018413342693219745, 0.07782202289109269, 0.061867425984312455, 0.08820856635969493, 0.012754359406479185, 0.039319489526772694, 0.04706718951403614, 0.06052687936913102, 0.05249010376451958, 0.07515299554553724, 0.016915292231245868, 0.0536887057786507, 0.025981841308455315, 0.09938431828613244, 0.0631509909796859, 0.031578866276709784, 0.019119022669450893, 0.0076663390556801, 0.038123507533342614, 0.04275760786127179, 0.014346198182583097, 0.07327832476866823, 0.027072252555479927, 0.01188031149907939, 0.07365643512457609, 0.0379025639455405, 0.023614669842044675, 0.05368532733090463, 0.025304857070647904, 0.041892380498710184, 0.046068980779138305, 0.045815555063346704, 0.03417065855295908, 0.0344292055665245, 0.021617411590752103, 0.07276359795322342, 0.014378552948455177, 0.01835487294761885, 0.048238411545753486, 0.08971449603597004, 0.008901967535606556, 0.021401066445715485, 0.04048627973984807, 0.05232192831294191, 0.11909411348883184, 0.059732691339787945, 0.09856203781260599, 0.012734426756299311, 0.05237936575506484, 0.022011414440649173, 0.03859796493704762, 0.03635207859558925, 0.037557548587961544, 0.07100006355152977, 0.047787925033199216, 0.03585564979021588, 0.02292277370279114, 0.021963955293739998, 0.06944704245054914, 0.020138038352372187, 0.028938256962705525, 0.04623562405486742, 0.028956260028926116, 0.04091204459508581, 0.029052541959249688, 0.11216382165589642, 0.010752956619516257, 0.008801484570628213, 0.03825205708703688, 0.05867485415130373, 0.03231581413157044, 0.02151786421065129, 0.031325607185041716, 0.14288243056545336, 0.02194194941811504, 0.029044319920602347, 0.014481395464240304, 0.026181667682624636, 0.05659141675418904, 0.019615650657684575, 0.03804700599322396, 0.0627274324576701, 0.05982845616076262, 0.09915852153133001, 0.02179395846812235, 0.015976536707321725, 0.027498252982754382, 0.08309172721759928, 0.026802304238381407, 0.04763797481334017, 0.02767900759804874, 0.04113371979685561, 0.027516439910076802, 0.05085850502514551, 0.009254937758669257, 0.06449448320293619, 0.06590761664894319, 0.02967520481756618, 0.035197936494143746, 0.032049970130526254, 0.03340451317208429, 0.05328944756559307, 0.037578914780169725, 0.04457035958166084, 0.02823097394749282, 0.04161002730289775, 0.023012124452619784, 0.05737869084001549, 0.07271289825439453, 0.0748992059379816, 0.0874347179647415, 0.07097023974863753, 0.045425095370099436, 0.011308389516817707, 0.04158704849560896, 0.031668667103193944, 0.0786502022416361, 0.08302448768048518, 0.006741255328374645, 0.03654311794126707, 0.03792549295711421, 0.08350343052898684, 0.03679080948894543, 0.08656913054085548, 0.04920204673262854, 0.020843208880133687, 0.03627947261256557, 0.01158486873347072, 0.05689110268928832, 0.06331902470499759, 0.05390079722048775, 0.03448105056680018, 0.03546471512245555, 0.009802612100517558, 0.07841626197219857, 0.0893411354251927, 0.018236238486884583, 0.037341710976174766, 0.012112296329090192, 0.0737505566869532, 0.044573209428739165, 0.050293296845930244, 0.03517238746186899, 0.0630353385161969, 0.007172690191861964, 0.03079596846815079, 0.0315722281248459, 0.01351868437092391, 0.008320696407838935, 0.04338853489307146, 0.12848914000055484, 0.07525441792583273, 0.0192825517977678, 0.043885002002841046, 0.07038402160809887, 0.059355389206640186, 0.06627680974141245, 0.04619276526594355, 0.051931116219249465, 0.030346294008796255, 0.03673353675572622, 0.04008292295639554, 0.06425233047095037, 0.012367865175849969, 0.07062979027508728, 0.031536681645159284, 0.011687870212500135, 0.01661309161253514, 0.005405357430478739, 0.03166063658652767, 0.043428524682718905, 0.05969114639165421, 0.006410758773375664, 0.0615181511778745, 0.01469695824198425, 0.036680868210931944, 0.05005090279624828, 0.0167414611355672, 0.04333099402907876, 0.030114611783515544, 0.04015394696785558, 0.025027347465736732, 0.04629932426577134, 0.05628791570122685, 0.07490264567276163, 0.07922263079953772, 0.08221294775965714, 0.007071059531412058, 0.04989071764172085, 0.031072192960568977, 0.08300393354147673, 0.031833374091694434, 0.029237567514721906, 0.04011920871092908, 0.026727377008947156, 0.0033732467272784565, 0.01809763977484357, 0.03612417509899505, 0.050388904618880445, 0.06831045908432815, 0.007457658141520956, 0.045503558095304236, 0.03380708088497481, 0.0424126576211664, 0.01784738183261887, 0.04299184690499979, 0.06539170239721576, 0.014004861004650595, 0.022967045923935312, 0.02014490633061336, 0.04288039643377547, 0.03460761978321018, 0.0338906763992723, 0.02970931296717496, 0.04902432582551434, 0.0726924896720917, 0.033786323732666435, 0.012020848413568833, 0.030374706294688008, 0.045210533294706576, 0.05612884903506887, 0.057072213535467466, 0.058225049457002076, 0.05602815060786182, 0.07516090923379506, 0.028019368971487688, 0.02496599531432073, 0.04786865920909951, 0.018705055568247073, 0.06927117930665132, 0.09683006623339269, 0.01647477252258649, 0.04061157341986414, 0.039582905029096914, 0.0548931913480403, 0.046662718072653785, 0.007908178170421913, 0.108112488242407, 0.04738312417400941, 0.02611530340096403, 0.04706855698098098, 0.053804105433124694, 0.07360362868395544, 0.1015829370026627, 0.04319849146169521, 0.07521943835121009, 0.026913218448058735, 0.030323075799031124, 0.046671995397416816, 0.04780125879352132, 0.043946315849860834, 0.01540657399492639, 0.020929131386501175, 0.17016672859749488, 0.1347773888659093, 0.10424545260086175, 0.1115488139311633, 0.23198346637429731, 0.1205058066895412, 0.2249864942484325, 0.06615271881943749, 0.16925128417149668, 0.10111098853690971, 0.2667033984776466, 0.1120968119451596, 0.1455937689470668, 0.08267057038122609, 0.1539706186421456, 0.10862564457760704, 0.10359047040823968, 0.07079892716700993, 0.14030702682512422, 0.19496144005848517, 0.17519133075350718, 0.11852612058001182, 0.12913846080341648, 0.1487774924645501, 0.14116927410566038, 0.1098486273399284, 0.16022958762703404, 0.3793045644077563, 0.17833066713665763, 0.14952614422767393, 0.23718209306318916, 0.12271120528420135, 0.15077696662516366, 0.20344232449368124, 0.15778691628046576, 0.11437713393881438, 0.15801441375046008, 0.1694751657064884, 0.21194035397662273, 0.1334804479753779, 0.2210228166152393, 0.19278613339749076, 0.1512320534957032, 0.13409500370823568, 0.17614815924917498, 0.16630037477420223, 0.11667499934593517, 0.13483086180302406, 0.23521994270624655, 0.25421141556674437, 0.08072572595049297, 0.14669577110438578, 0.1970770991136951, 0.12135237981114658, 0.1521886215214768, 0.11168904632570283, 0.1054409634502184, 0.07432018902393119, 0.3353970930460961, 0.17867293989946767, 0.09256546160266285, 0.1248856615875998, 0.14930054665573184, 0.17867212784626793, 0.09430809712578213, 0.10158079195647471, 0.15045691041215775, 0.14968555180295823, 0.11393700110455675, 0.1926339576922117, 0.10783979158488013, 0.14940680305082954, 0.15138268170337524, 0.2703196399154202, 0.22906309324166468, 0.09642806925600576, 0.09448021409973022, 0.1774652022868395, 0.2513974520467943, 0.1402721391810525, 0.16770875081419948, 0.1194313990192548, 0.11495478721635957, 0.1303157081166583, 0.10043071012102789, 0.13306846121145835, 0.1377914545516814, 0.12910311350659018, 0.1268485473889497, 0.10897684226473493, 0.13072755698475147, 0.09664648858409736, 0.17182359291661173, 0.09864121299958038, 0.14880989798374716, 0.09820428241284625, 0.22605852704615365, 0.10803687536428053, 0.1974021655417258, 0.14232248157983826, 0.16370447052101936, 0.1601534997743945, 0.13993305334400746, 0.12742092232069663, 0.1151319910141249, 0.1315358410319013, 0.12832953324241023, 0.2732482408323596, 0.2108869524372201, 0.15292020484564767, 0.14708354948989807, 0.16861625856930212, 0.15538515402905403, 0.290768671660654, 0.1122193553695275, 0.16371234590488096, 0.19844479588491304, 0.12555996451767223, 0.16044582360454146, 0.09335128395187278, 0.20501490381936874, 0.2929515625920988, 0.1242201150425019, 0.169746560014544, 0.22191696379694248, 0.15862726876812597, 0.1029991118177291, 0.13545563714879175, 0.12576241857342182, 0.12768988813003226, 0.0834581240891449, 0.20370709980207108, 0.1534121711888621, 0.14752397343756693, 0.123325630782112, 0.24161835501511253, 0.11002854308894566, 0.16721411848500853, 0.11671502743997883, 0.09465348786644398, 0.09731264033865544, 0.09542660847786935, 0.21189313231697007, 0.21965469083478376, 0.12975349151078733, 0.22088196368948107, 0.14139525472156464, 0.2077975649867327, 0.09176271637120555, 0.179638808232642, 0.14338994849353068, 0.07741047279728998, 0.1979004444494363, 0.14793664968061834, 0.10086765602952051, 0.09900865175070302, 0.13365389028143498, 0.17150511484472983, 0.15115021998363157, 0.12374478812900283, 0.2638047669203051, 0.170969374237522, 0.19146248668191895, 0.09389103885980384, 0.13318558073332235, 0.14531603143099817, 0.19219292087420342, 0.16237622727790188, 0.18095418119863158, 0.11513690163771953, 0.07580788580760842, 0.16448059419710792, 0.2453749131170973, 0.1673861971545604, 0.09812814093405202, 0.12995685721116682], [0.07043734132762879, 0.04026534764336483, 0.044846204860556516, 0.06093765954456984, 0.04964537415353041, 0.014907687004925984, 0.018105405991175966, 0.06372903113163288, 0.04590162121119999, 0.06200567421112811, 0.09005473866578072, 0.03258147810195242, 0.03852489164039012, 0.020256896893824303, 0.031105266891479976, 0.0355211719720354, 0.05686975947971787, 0.028880982314266508, 0.025123470432816014, 0.05715346099027703, 0.05301263701591281, 0.03923207506417267, 0.015193755727171179, 0.05834282015360171, 0.00540208240460244, 0.01869642175734043, 0.02171756226509329, 0.045450721011166616, 0.04570372537859986, 0.028102196482641083, 0.045366160226084536, 0.0139408792564345, 0.04645860543654812, 0.026463239468754302, 0.0026623089938619805, 0.020184570532892982, 0.043778668998950915, 0.008914997733588661, 0.07777663984245832, 0.04788949680063994, 0.05979194824073104, 0.026817287002960523, 0.04734509556944813, 0.04600466003701572, 0.02132186253044394, 0.033673846703623576, 0.06443445255318958, 0.04489626870640824, 0.029743386642827146, 0.07891122371919694, 0.07222873068624927, 0.017506733176208312, 0.07488721666196663, 0.07305006887162886, 0.04082818095001482, 0.05452151996113601, 0.03228800897035868, 0.030205238069738113, 0.05090294578563302, 0.0419542727421128, 0.04623010439137298, 0.03142661013219866, 0.034178633528250846, 0.04434376226497754, 0.02646033408030147, 0.07124223160527407, 0.028706712633251186, 0.02781811958899902, 0.06289610203595893, 0.0763382331558293, 0.11671952437609436, 0.04035344009377784, 0.06817200401377294, 0.012166258604866604, 0.010364024314068018, 0.01795162341647571, 0.028160269777741165, 0.010042852485522388, 0.025667266454547647, 0.025150312238462993, 0.01339916316341729, 0.009581050854326497, 0.04480164152600112, 0.03438338967821291, 0.03134651947015476, 0.06351557988373023, 0.02266809351802353, 0.049117221647212585, 0.009973488969638223, 0.0046567899370265585, 0.02548186934643215, 0.05903142594522046, 0.07872263585487682, 0.06544761915480898, 0.01447301541995858, 0.029378910736751654, 0.04646465753114993, 0.031941886615729144, 0.039663539613567056, 0.018024371125765385, 0.0693176731827759, 0.07078990265126191, 0.025494417866631865, 0.016147411661222577, 0.05562664009630681, 0.048166843611867204, 0.05380568740468833, 0.09654346508004012, 0.035153530207612825, 0.023330104567350882, 0.0063923559050195885, 0.07201964996995465, 0.04270921791753462, 0.03780316403736511, 0.019528270669041142, 0.08476696232514036, 0.010506186292566841, 0.017046095998657328, 0.02295893496803699, 0.025964552619224115, 0.04005687979740962, 0.013692117100881954, 0.06084780509193098, 0.032871312146345456, 0.017467932738063317, 0.056357939967945705, 0.01694846000792759, 0.06755023939354766, 0.007242381210333758, 0.03368328873729033, 0.07006498429203226, 0.029794756668589772, 0.01968711708492089, 0.06543494039966215, 0.014477821664073536, 0.02951491624116898, 0.06278772740775058, 0.07155880211822449, 0.031522547322956306, 0.02421354375509245, 0.0705670093696925, 0.029002746244171457, 0.030037064533380252, 0.03368151524374562, 0.04708807690129165, 0.037941481212093946, 0.03171615689362009, 0.02633625273442557, 0.08872161544258557, 0.03491656772131401, 0.024018051523354747, 0.020544440335323735, 0.05710536982083032, 0.043012347417853536, 0.029215981072235494, 0.07655214788692613, 0.03949909884062025, 0.028933794500546593, 0.03521976616954611, 0.0642902058579268, 0.12029982862933991, 0.034223671837319294, 0.01580140038934206, 0.020838962837813363, 0.038306273129438205, 0.027324073317070163, 0.03129493493977333, 0.013052490183092173, 0.02298296523100186, 0.003588114998438546, 0.032937214860031684, 0.01268551683038353, 0.02204437345837153, 0.08217476593751101, 0.0284262114549957, 0.07271061531238018, 0.038940475187114174, 0.09325316341053094, 0.04474441475805737, 0.04782628688600756, 0.024100999693356218, 0.02772501117790178, 0.01270259963348508, 0.057217030966233824, 0.03739353299381272, 0.02630915237410415, 0.04397622775286437, 0.01340899590192543, 0.08504394141416396, 0.009189610568536146, 0.05288498378508995, 0.024865865707397464, 0.017475250792960008, 0.04561032010843197, 0.054386550590636275, 0.08726702897899574, 0.07330323794796582, 0.074479297824925, 0.011608350285959822, 0.0675496035405705, 0.010144696214176234, 0.03416777806236379, 0.016998654088726448, 0.01395986483041798, 0.03608203260228038, 0.04156495835031233, 0.04683629444409763, 0.029109159687293634, 0.032999091781675816, 0.08697426847873196, 0.022688925363904527, 0.01863924286989195, 0.020405305361735727, 0.05749502895219673, 0.017132545190472758, 0.06733488441715318, 0.030393253283334837, 0.02389457155649941, 0.045185080023422364, 0.020697502787375165, 0.014746656280852135, 0.04353465850374872, 0.059359020463401274, 0.03739284734512049, 0.04400594813388683, 0.018543916634253917, 0.03467968950468687, 0.08798081608068559, 0.04819183723039685, 0.0050518921230949705, 0.04842848179020709, 0.13118653558194637, 0.05008387522050931, 0.10245408622487899, 0.07715535019674609, 0.032342454839137294, 0.03814333388882299, 0.037400527376561396, 0.09253957549170141, 0.021726048604074507, 0.053753581934518395, 0.05716382999033217, 0.07982237805281917, 0.004930767876606796, 0.09824450202887097, 0.10886342294754521, 0.056337263254869374, 0.031648233623033574, 0.014594593573541892, 0.06442524417633973, 0.005907744005878246, 0.01204646639375677, 0.019374740903355905, 0.04730012620829287, 0.03913193588115035, 0.022449791018340378, 0.016501832663291888, 0.05158178012577757, 0.03346753539517522, 0.0498051954162938, 0.06000893881484386, 0.08742278997576045, 0.01893323485649401, 0.10558087408782975, 0.021821447618065343, 0.05652290551112064, 0.06214665737183345, 0.03178435978629897, 0.0597032965461333, 0.048782544646171794, 0.052621890039693926, 0.04642079133660563, 0.02740264520980418, 0.04554871131756133, 0.010228820329141474, 0.06250942298661798, 0.03713122448853908, 0.06451434786281278, 0.027373238924830675, 0.06207165353360677, 0.028452074583319407, 0.022847492157691912, 0.04849821494351472, 0.06479485861716733, 0.07418683609895169, 0.048751970077113765, 0.04392535568425252, 0.050489668163561055, 0.010056509917992498, 0.0324488721126991, 0.006246172443723247, 0.03895241466741409, 0.024945351159981182, 0.028514824845197222, 0.08028049097065965, 0.05670061492691598, 0.024648222043329192, 0.07212782924574229, 0.04158727832198624, 0.03506882386582513, 0.027582451791292237, 0.020709200949978926, 0.05251535402250387, 0.04535162753816094, 0.05137538071721793, 0.02418247888976288, 0.035238064179617556, 0.03542318549608031, 0.009528486689011897, 0.03857958648774413, 0.051426118720443025, 0.059312331234856006, 0.030683916617905906, 0.04150837509622497, 0.02928250048670077, 0.0521311954024338, 0.08739246821571743, 0.03366121391375219, 0.05354357425183539, 0.03213789787203555, 0.06229303379152572, 0.07406058480903026, 0.01630359017590602, 0.009504901714653019, 0.02452880234247254, 0.025257656478413174, 0.01609125167071339, 0.061900919348362, 0.05731670283562234, 0.04875764678863268, 0.02537974216524632, 0.025067770095061392, 0.016558814283099868, 0.04525225444306289, 0.026083725256725185, 0.04085502467088161, 0.007418763857605237, 0.010648198883920428, 0.034318318169924526, 0.014647253499847027, 0.025947076238451466, 0.02691465294769695, 0.058130709559566555, 0.02233120635332119, 0.0044483757172260555, 0.0390454483849387, 0.04123166796841449, 0.06520712117273962, 0.06345914218634849, 0.029276323902811256, 0.01274765805236154, 0.05316960460115826, 0.22814715851939496, 0.11647849013247799, 0.14169185332232906, 0.1893965773765118, 0.10736383647928316, 0.1452962050755178, 0.1799789053057471, 0.17033877662352978, 0.15943831073180323, 0.13316426816726887, 0.1616936276156095, 0.10033328671969714, 0.23103592286427177, 0.0934694070489176, 0.1378059182916918, 0.08450820080695615, 0.1342624705284834, 0.12746609852559146, 0.13226990648094686, 0.1620698993604991, 0.13663768017243955, 0.13906213394816846, 0.12344009197887876, 0.18745630649068665, 0.1433538351087801, 0.10800705156138829, 0.10180612139764333, 0.12204190490827446, 0.1536710016549595, 0.12315087846570438, 0.18371981989231803, 0.08211107338748633, 0.11229594117931782, 0.25959931193820895, 0.07234752794066746, 0.08766230736528674, 0.1354797689184066, 0.2327752029222827, 0.17570062600556882, 0.13240308320570376, 0.15372099655289806, 0.11217804024777106, 0.12207591155123328, 0.11261939116182829, 0.13207375732881407, 0.11640549727505255, 0.27056959908335443, 0.1604462219702621, 0.11622910553048696, 0.08903068595475729, 0.24632614917091786, 0.20846714115431234, 0.10112135370652522, 0.16941351095034232, 0.19384488223060486, 0.19079879406959782, 0.16087271843946752, 0.1896789420636431, 0.14298819666427953, 0.14213639882303056, 0.1798361984472121, 0.058892993857302976, 0.14624552590952766, 0.11950328871006928, 0.19002481543969726, 0.17974086646591464, 0.15521875973190033, 0.22853162740507435, 0.184525866962729, 0.22326514064784975, 0.17991611673947305, 0.16050104322212358, 0.15601682416614027, 0.12317394537310447, 0.09081532607876486, 0.08236706166738465, 0.1257124619798795, 0.12308857253482267, 0.15995918923328, 0.1683549000130546, 0.09778405254286143, 0.1106104098500744, 0.09413699138789408, 0.15940069581472105, 0.1960330438469687, 0.14139289517075787, 0.09163307131177957, 0.20789226877593225, 0.09410187391744507, 0.1720929647525472, 0.12363242601314861, 0.0683220116902263, 0.19045155705703845, 0.1409919707164649, 0.1195411794188042, 0.08730590794115298, 0.13713194477942683, 0.13394373198670728, 0.1266220917985324, 0.14241940702401823, 0.20893935775083883, 0.18459268515148472, 0.11241217203918966, 0.1587710941150304, 0.1954469252978602, 0.11441818092979732, 0.23311540724769717, 0.17751735755272452, 0.1618813344788167, 0.1651585054013037, 0.12919489083991897, 0.13666887527271626, 0.15196392793328534, 0.10552812893424304, 0.10387456645407986, 0.2215541905212787, 0.22987655604318266, 0.1992009859532118, 0.20376158397524588, 0.21158452145755294, 0.21557441461951504, 0.10410578711138618, 0.09892248218097995, 0.1306526795510323, 0.12668556984393828, 0.16203852039912056, 0.09335875330913453, 0.1734773315969975, 0.1573452359486011, 0.12948114725370563, 0.19240465225471606, 0.1391483341614085, 0.10157646355970253, 0.1528998269068618, 0.13105815456759545, 0.11587087515621416, 0.179674492608155, 0.14522682815309496, 0.20057118017106287, 0.22408977301130373, 0.14189531095325947, 0.07327142231647046, 0.12959014624357224, 0.08250821336743333, 0.10126906311920575, 0.09807300558614154, 0.07977152513640542, 0.13118860401934193, 0.2155758395430542, 0.14778497959336928, 0.10636449010381777, 0.12062655746816628, 0.13885245568329288, 0.1422193967887471, 0.12485091183935443, 0.10971178105401416, 0.16001966421402272, 0.117165211347803, 0.17776207667925667, 0.16190227932266651, 0.11209688089307278, 0.15403403540051755, 0.16893974685620877, 0.12705612657291274, 0.12576971173046098, 0.14723308985271763, 0.15744058325165705, 0.13699820114960595, 0.0637209297518336, 0.09552443024492073, 0.11547603344004001, 0.10952859410956022, 0.15110017912041757, 0.12821684936962782, 0.09697732365419788, 0.1600365028265984], [0.023677711217333714, 0.031136316435051062, 0.05203641500444182, 0.09305316849701828, 0.007657643000129611, 0.026581226585192547, 0.025097503882622527, 0.032804084100550225, 0.07062239752661797, 0.06430561188608408, 0.06762725421257558, 0.06860094430345683, 0.012985974599066521, 0.03738927737539334, 0.054895187007083054, 0.06843605153863469, 0.05791230938367306, 0.009421638490992689, 0.03036116186018673, 0.0411020573829451, 0.016615857189941793, 0.01732287398960081, 0.033811026237784855, 0.08842303267409725, 0.06741233590629793, 0.14279172575521853, 0.009473002771095885, 0.02423951413572556, 0.04690919154053254, 0.04721440096956588, 0.029807500541210178, 0.03999955726847534, 0.0638458174052498, 0.03765287673881939, 0.06699102585233989, 0.03311927948567656, 0.08545640315259657, 0.03588585280663064, 0.046659619247000066, 0.13281598927513247, 0.05695530468778265, 0.04116060565255823, 0.04122987532267167, 0.07090266313283675, 0.08377185241589624, 0.04478140914392087, 0.07320971393416967, 0.012285414005389378, 0.02470956078820652, 0.042089108047225786, 0.0249513496284283, 0.01444204056996011, 0.061850545236900936, 0.023891669998486197, 0.05382252601726402, 0.057346760295331485, 0.028319125769719965, 0.04321543732658029, 0.04083775321862871, 0.05661008248646414, 0.026204259615511667, 0.02614526893012226, 0.02857879127165483, 0.05738054860323187, 0.08684159737200507, 0.006049370680439977, 0.03518277561412223, 0.18181287383119907, 0.05013084790158657, 0.02760378925520326, 0.03805007034492108, 0.020123421394776915, 0.01733644906761906, 0.03591466920390245, 0.0347275699999544, 0.0632515017153515, 0.06905350308384627, 0.0305770339459301, 0.04849695089843966, 0.039322515574073603, 0.020028143039634152, 0.04156314655237141, 0.03908445758204307, 0.06582684799908631, 0.04550304098595535, 0.05572902774738689, 0.005068468829361542, 0.03675559625750588, 0.03679711056212264, 0.0210153469214997, 0.022472995821566834, 0.012066963076170896, 0.06961291580791436, 0.013301916919919032, 0.049546732672400055, 0.08799882680778542, 0.06297621951108018, 0.07334744888207606, 0.01602167843825995, 0.04972530776754983, 0.043677882471632574, 0.03922907966038874, 0.030166615747035514, 0.07316181045626441, 0.049601990594378406, 0.046628064085398956, 0.018108294142650503, 0.008983587500669302, 0.014461695513267432, 0.04440859245556978, 0.1076784611289059, 0.050956740479675994, 0.1060386575878628, 0.01547992787128615, 0.08769558622471749, 0.04641458602441896, 0.04577683314921395, 0.053608189937808824, 0.05192918567768028, 0.050094857090903874, 0.06106422876097983, 0.0370592083932171, 0.03457566242544882, 0.05288665002632526, 0.014643679699680258, 0.10335760266189614, 0.027003331455372037, 0.03373348664852881, 0.030271673214531718, 0.029198809211412748, 0.03571528333028959, 0.0609988623088406, 0.048280362520487084, 0.027278349359309482, 0.07679204065953532, 0.05485855651298358, 0.018767164231488304, 0.06481784891577498, 0.018795176236439618, 0.05817020522250284, 0.036930900157218984, 0.01344094942924717, 0.08752405913847108, 0.04600506606361559, 0.020455974417047638, 0.023989336632732904, 0.04557498813336415, 0.036790866945539756, 0.0662766565238276, 0.05481980012489423, 0.01858786135281046, 0.033415491212039225, 0.03885180050987871, 0.10667628022812067, 0.08194519236924187, 0.054750323611041235, 0.038108388788156936, 0.024535967179784374, 0.06067498714753217, 0.021957443546383612, 0.04162888072671429, 0.035154265652020136, 0.025657437546479128, 0.03839182599838223, 0.053211796893588, 0.04444363714766599, 0.03436339095294957, 0.012011317322180878, 0.07381640960492435, 0.06140604570147492, 0.00642948770790451, 0.07843596575361106, 0.05164128983573568, 0.02334253051348271, 0.049660757199049964, 0.022781261941418055, 0.037096011257099534, 0.07143808964399562, 0.008996995954564022, 0.03066734805132353, 0.03475054497680357, 0.0929562583745968, 0.05297246719560316, 0.041093818107319456, 0.015257597664341092, 0.02875818991132321, 0.08728819598834361, 0.013930954587375446, 0.01653030240577796, 0.05970316248074655, 0.10976872436942593, 0.030929555049947197, 0.010496757665438759, 0.03908824588682863, 0.04167727833133071, 0.06099228927445027, 0.003936442249875155, 0.03468351228342902, 0.027891192885656512, 0.03703990297752523, 0.09005891384496804, 0.039945693626519174, 0.021535196949938135, 0.051237684073707754, 0.023008790054929354, 0.06629231536099989, 0.016027855979759368, 0.03295892962224541, 0.07025750218740395, 0.04332799096441558, 0.05940931413563029, 0.008671708318645195, 0.10580286338564851, 0.01677713976542075, 0.027528883093186927, 0.030340282133810466, 0.020244266019172726, 0.014305928770843294, 0.039579924947071465, 0.0746023775108399, 0.043276751173600074, 0.10487448739548845, 0.06914091371600667, 0.042024806457301306, 0.027829421301101966, 0.057573258020584626, 0.0397270827764465, 0.03853056835190904, 0.028883629148044897, 0.050495720258162874, 0.04353554716574089, 0.033029892346671516, 0.037539671926248463, 0.023197446867162665, 0.03877583523130706, 0.009887677546019756, 0.03175750840455294, 0.012491540495125998, 0.016976345608371402, 0.04740873449331811, 0.030840782696501385, 0.030934523130136154, 0.03742138795073956, 0.05558856552647007, 0.05059880121881443, 0.02214270850433217, 0.048245547654768156, 0.07007508899175352, 0.10064227296219719, 0.07488108029769314, 0.026534453086975603, 0.012537897433034115, 0.011302888047911469, 0.04916302221376569, 0.030258638228500084, 0.006925900712714441, 0.05264235607859108, 0.05967744107868883, 0.04750638389058652, 0.046745214250779925, 0.056390847274733175, 0.018685506919639248, 0.007688003543373799, 0.049592801369726665, 0.011674658068636013, 0.008516611903154803, 0.08964499653947931, 0.05140281432578641, 0.07669771991429791, 0.056550997955304, 0.08410192905895172, 0.05378328699378237, 0.04921265321994021, 0.02374789444729686, 0.03338616153585815, 0.01059292180974397, 0.041837107254973346, 0.022514544600140185, 0.02863483251853576, 0.07772453054184876, 0.13247072876941773, 0.05543918604211462, 0.015577163581075448, 0.10474792200951807, 0.02379563896195783, 0.023758154279822787, 0.12034946346595404, 0.06253781420509182, 0.020642225713198705, 0.0018448883906051878, 0.05826744859317138, 0.051746527333894086, 0.019603310896444227, 0.04601329767836198, 0.036430123802875324, 0.06762938393700509, 0.047069928278365446, 0.039132713460393494, 0.022739987039277633, 0.03766411141822896, 0.04267284023245016, 0.06673568874717721, 0.09121735369966877, 0.028549689506631226, 0.04037892400857903, 0.06731505040079355, 0.0738650638489954, 0.08437598935298382, 0.01887611151042004, 0.06201685526438298, 0.004836604658198814, 0.03103251152131106, 0.03839882421157053, 0.04904695223235796, 0.02075006982551948, 0.03205065194877886, 0.010404197964817287, 0.03592445597713513, 0.012034625547277111, 0.002374525671081257, 0.06588727701455355, 0.046396743836662466, 0.02354755096377865, 0.04188994433911097, 0.0543059466496831, 0.013924124913530485, 0.014662542699595854, 0.03680296730430376, 0.02823883400959594, 0.05682900360214615, 0.05712496634993342, 0.007353278661837742, 0.014030179252938159, 0.03559467427793049, 0.07711460198005361, 0.09103100281208755, 0.028323032818133795, 0.043545847217882835, 0.0488271271329253, 0.03777938466819544, 0.039120555645035165, 0.026847011214422605, 0.017749632843920303, 0.03011165276890801, 0.07635363918398658, 0.048581703205502806, 0.025567870376811876, 0.07426632538197503, 0.06116466288785301, 0.02521154181581111, 0.005483431366061973, 0.025088186338243466, 0.10460960483478923, 0.12280574053405754, 0.06369187586730526, 0.10888563949734935, 0.06963722377775178, 0.18027044772621126, 0.1399044935861903, 0.10501732448897055, 0.1103042581328942, 0.12921258747096986, 0.16220033349048707, 0.18443785878198762, 0.06915432791556082, 0.15814688567432666, 0.2915119914518249, 0.10923889796099356, 0.12807244179590097, 0.15788286113210265, 0.24749414214203436, 0.09007748381625261, 0.1038722298859108, 0.1280480572172711, 0.1850342429092815, 0.14713717564459772, 0.15065443852255422, 0.1805702026092237, 0.11671190180124776, 0.13358469722011398, 0.092463081612462, 0.14265142441276582, 0.1016591091249739, 0.09909521202526747, 0.10002757933351303, 0.12908213801922339, 0.1372122767591669, 0.10080104468450432, 0.1615922588614687, 0.1471589172198888, 0.1850371080781183, 0.2479064659846406, 0.1679676425673308, 0.1576160786733512, 0.09961979839229777, 0.12711107805972138, 0.16241077784328692, 0.1484548928396356, 0.12745933396922005, 0.1310205396505133, 0.1167886867938984, 0.09426759405722542, 0.13912974886836546, 0.13499256764208117, 0.17028230062175184, 0.20915013918232536, 0.15339124166677076, 0.159434832692627, 0.09812480845158139, 0.1346150088694788, 0.08981139849751227, 0.17800071306767004, 0.10352211238275613, 0.12031443026517669, 0.10697667862498954, 0.29535848827612016, 0.17994657639534245, 0.09947179786620602, 0.14595478022050473, 0.19173889120499935, 0.15413301396033458, 0.10880566757893372, 0.10613275616760216, 0.0940168304969707, 0.11833409298091166, 0.09325802040797088, 0.13060577964830783, 0.14756973953016345, 0.11335381667219824, 0.13131251108021508, 0.10731993964122188, 0.08624151304003694, 0.19849428516482154, 0.15223881560227565, 0.0998379189460989, 0.14402934079689367, 0.13737373745008824, 0.09385923088918771, 0.0898785537649547, 0.17384759721256074, 0.15023980109441668, 0.05105686817137946, 0.1701476376864218, 0.13188324658380401, 0.27133764819272105, 0.16776288258692912, 0.18739976920187476, 0.17425693331226227, 0.2261281950819877, 0.16142696773092594, 0.1876029663629109, 0.15155538856502504, 0.09553718560885999, 0.08957871461227056, 0.13195800144345532, 0.2243378782464612, 0.2096701903088439, 0.08087446958187126, 0.08110129289449224, 0.14070805853172658, 0.08929965176409291, 0.19353951958398666, 0.21833272951264537, 0.1468933758235747, 0.1495048929486544, 0.12730967869321186, 0.22254471156385638, 0.15138723226564546, 0.11190120671545306, 0.1290007641599063, 0.16284056849056677, 0.16163949584287984, 0.18297358896703492, 0.2388102903721794, 0.1382998611417509, 0.13707009084042043, 0.12722046775442938, 0.14284515272705786, 0.24825284497872477, 0.11512026220800416, 0.10515891285913606, 0.16567684049087186, 0.12622613925486803, 0.18620975886381444, 0.1182209341336162, 0.12382099855571024, 0.19719709912615438, 0.1871694218848021, 0.2164734954074506, 0.1552436882329564, 0.09648389408304807, 0.14062792573484684, 0.09298227472050537, 0.07063467025516496, 0.15271277887926948, 0.16970223416724514, 0.14710853927798812, 0.16108873991235612, 0.15986272344185462, 0.11254497338086368, 0.1868683033652844, 0.09109547677179498, 0.1410667102543577, 0.09453507365598794, 0.09040916924394908, 0.17126480838464153, 0.1779516681187576, 0.14562513258668686, 0.07283013268944717, 0.15802182948156712, 0.21811629435227764, 0.25196999551788457, 0.19860617996704197, 0.1626590056525123, 0.12583008711977353, 0.12153626389561162, 0.10004729077580476, 0.16312238159439257, 0.14494424896134486, 0.15489547062785397, 0.21419495073778017, 0.2199210442842976, 0.10262551371969524, 0.21352577293592118, 0.16071220769757227, 0.13891522892780844, 0.17966799618255708, 0.17132848561290773], [0.047391738832717946, 0.037582971215728796, 0.026758112456469287, 0.061438060515830596, 0.03856287044923633, 0.045041664533557436, 0.025943441151250756, 0.017308860326245908, 0.005881882792774348, 0.05516489975214486, 0.0397348853819553, 0.07113229032726058, 0.022703427408311157, 0.03596527697218042, 0.03392082578953236, 0.017872218403124043, 0.041565709116478125, 0.020615282400901762, 0.02778624841612914, 0.059422471695729805, 0.012321551330387594, 0.04829709771119299, 0.04845438705336663, 0.05869509419426323, 0.02290003812841831, 0.04042837115365171, 0.047064109840580536, 0.04049330859655335, 0.0593565191863285, 0.022818183548928752, 0.06303451880211793, 0.034316437424070416, 0.05670492417149006, 0.05761464592069388, 0.0531394552108982, 0.05081981375452973, 0.04587193530413412, 0.047857026163969314, 0.022293516742666403, 0.050721628095714316, 0.01592696603057125, 0.04967316399298368, 0.022461335963359284, 0.05987942015992538, 0.023713924193514452, 0.06563122744762129, 0.027599129525403825, 0.020115086358160745, 0.03183389503148294, 0.03470312413429061, 0.0403892815173153, 0.08171364995500735, 0.02587958580754217, 0.060740234856043136, 0.06454279270744132, 0.05435963026097706, 0.009220320160590835, 0.036170741753472437, 0.04378436869310756, 0.011330077465954087, 0.046117190692213275, 0.011994957514557869, 0.027778514758533532, 0.018688345275398706, 0.05813366665895428, 0.03879121061594736, 0.04157694762632732, 0.05795391944928035, 0.05109154514127201, 0.05063030658470047, 0.029546429267934257, 0.023116762486977444, 0.04550015666492043, 0.02056624894330819, 0.04206512566475619, 0.07248324041645374, 0.07643166523907455, 0.06164081717631029, 0.02519521265170507, 0.024184687138204614, 0.052729441123383666, 0.034179372803097775, 0.0550690506614985, 0.016434531839143847, 0.018060997789425236, 0.03397245628518924, 0.08079439807202547, 0.037714159942322203, 0.08981295365599856, 0.01570932045128317, 0.09411515788205209, 0.03045001848330421, 0.045837350264792485, 0.004737529379781336, 0.023661182870367364, 0.03186469751169845, 0.059635348377689246, 0.06607192718694288, 0.05553148431523193, 0.02950367007044054, 0.036630528573427475, 0.03731192547767874, 0.037376970172889774, 0.04882624613181238, 0.0010130550400654396, 0.05933280876507202, 0.029328347018529332, 0.022779737426448735, 0.04414133885274491, 0.029260144125850453, 0.08848225127064413, 0.03980361879052174, 0.038457376311623284, 0.026073277732657812, 0.05565516538016739, 0.026114880137385863, 0.013541858530633393, 0.01616566370601856, 0.039308270169121605, 0.03356930251503664, 0.04507176412810241, 0.0066720565213942, 0.02737765350649434, 0.08439375493194788, 0.04356251346067556, 0.026929059231113044, 0.021493165535972487, 0.06103182324178277, 0.02395537020939012, 0.03258230547691065, 0.030428077725152818, 0.021351711231193716, 0.03073711759380756, 0.13110320053754315, 0.009644918646963855, 0.053734782136856556, 0.03569129328694075, 0.022461230626269695, 0.06158028856941289, 0.042260248259070425, 0.028691277876796744, 0.0856040436173639, 0.05075576880405988, 0.04220685193074807, 0.017430145451198184, 0.03912596039534096, 0.05262695388087342, 0.010625338820259898, 0.0556260846825617, 0.03746040480872316, 0.055341172753082174, 0.04791921335122278, 0.04441155338539712, 0.019991797913286476, 0.0438002152218213, 0.03067150024787313, 0.1347953612886129, 0.02279643239753862, 0.05486044491971693, 0.07683806722202609, 0.035489413797134356, 0.020094141514310916, 0.031922682706687244, 0.004575122091468545, 0.07096406507996783, 0.08541143379144131, 0.009758633865614333, 0.049614516131940394, 0.01505601694882517, 0.02731308378579636, 0.10936981472637385, 0.02678354082989597, 0.009299815189273608, 0.044584424955950636, 0.0263958735271327, 0.010491063716941544, 0.044240152703658234, 0.0951821421603522, 0.009226339696455867, 0.011502648346997317, 0.05454447578578707, 0.022309164088519833, 0.02653878148374779, 0.020859733396660418, 0.005411599131841814, 0.048830344702207276, 0.0379404699760339, 0.062168705382294236, 0.046775647093571966, 0.055890760399521365, 0.035780569343196775, 0.06417710829766528, 0.045443699815340584, 0.029313565352030342, 0.019665329544354352, 0.01623364634841921, 0.06638459831235871, 0.03179590664653769, 0.04413092388741432, 0.11120131644870966, 0.04217300233581374, 0.02350922741536652, 0.03298776134127571, 0.05779011835975032, 0.03224671300080034, 0.03757544057143312, 0.040202413520385186, 0.019618502419982708, 0.005109883542548144, 0.018222609782711636, 0.019638725225963903, 0.04799673761872034, 0.11740354130104666, 0.03816999757902757, 0.046901557474367084, 0.03758792780459889, 0.08718360966492085, 0.014844296102021492, 0.04269123017307251, 0.03390229029220439, 0.03983335832374231, 0.014472808576219026, 0.01759492330283167, 0.05909617569658065, 0.029932905303975268, 0.041596597781585115, 0.1433973795463962, 0.07138297727872288, 0.03191867989728288, 0.07678410398863977, 0.018832038472136183, 0.029237035083614533, 0.03274352101969623, 0.04721255852810798, 0.01789720627599426, 0.06481214922161833, 0.05386381049550349, 0.02737639712229852, 0.030612509562483722, 0.029737765472682736, 0.05457446429758303, 0.019124555739484007, 0.025340104776044047, 0.04739521304145456, 0.004586019692191434, 0.06070980584369071, 0.00756403471666178, 0.07726348350725828, 0.02121036992438378, 0.04007605497815436, 0.04823785230156876, 0.06984308692476443, 0.114510617098741, 0.023629510880357796, 0.052495845593512065, 0.019943785267852007, 0.03334060611744081, 0.039888639228358384, 0.037882603524673375, 0.058846162902491714, 0.07442301334512812, 0.01221283196261333, 0.11228337733735962, 0.026942291484785177, 0.07278080428800277, 0.0341741519138938, 0.04232305597754256, 0.023091611820423318, 0.05330039496203104, 0.04493734251046854, 0.025453395773506454, 0.09781268890947105, 0.06290243758309273, 0.07885330747212134, 0.09676798246800901, 0.04480003657179975, 0.05056338497407494, 0.05568272156280376, 0.02779482860088108, 0.04090033111072356, 0.06551503489214568, 0.03475252531408783, 0.035914481512361, 0.026441616637091485, 0.09198583947915225, 0.04991851897249299, 0.022106742591507012, 0.03825858798659137, 0.09166376845490548, 0.011228168619826678, 0.03472619870256993, 0.03720604063522431, 0.029961265878932133, 0.06149905643636181, 0.06584999917615807, 0.01125835822970276, 0.0299908981598433, 0.020016868140608556, 0.01533506734807405, 0.0678722721133982, 0.0721055820524212, 0.03826489672064781, 0.011722422693104995, 0.02600272869571082, 0.02050055881902095, 0.04409586004312, 0.018621419834333564, 0.019379025250072443, 0.020496850953467434, 0.048974916984837864, 0.06650979240094462, 0.01573444717758966, 0.05364757068755646, 0.06253971027270441, 0.15611848403369227, 0.018413555282618732, 0.016623975806719354, 0.031960142490964745, 0.04511892833116074, 0.008603975612429843, 0.022727902002272107, 0.032489696938184, 0.07930362927577189, 0.03877322670192488, 0.03289399217934378, 0.04482491910758038, 0.0355211719720354, 0.013210323447692058, 0.10893158179016844, 0.03351686379661964, 0.09294305101878221, 0.046415516821246956, 0.05115802242090145, 0.037400332024140705, 0.05678559322991679, 0.038165799417202516, 0.03090566651324832, 0.01039277655147617, 0.04301677540605588, 0.04229811981560723, 0.07737854225260597, 0.05337295881021888, 0.0770383915533462, 0.05271727564714609, 0.03349632114893006, 0.084069155817551, 0.06263981881220976, 0.029412201087501262, 0.02578617862215446, 0.08441388006171874, 0.038102754211473855, 0.02543262712987921, 0.15149574095924057, 0.12080314073471293, 0.1113043935789216, 0.16666573742705007, 0.23081723540540666, 0.12547466062730359, 0.16682129924095448, 0.15139924452429818, 0.058059176099636865, 0.21901834756135943, 0.13254117821493458, 0.15711517974493966, 0.06821843660286359, 0.14471289040821214, 0.11904866915316352, 0.1606206908341377, 0.1894129869798499, 0.17872800629946495, 0.18505218468846815, 0.12557802121004752, 0.1103484997105214, 0.15681881097055253, 0.15748932176539976, 0.17320184637942623, 0.13685095905055925, 0.13175025372014892, 0.19449786493374457, 0.12328265324955988, 0.2258106209938565, 0.10012881019182744, 0.14817870282117399, 0.08201436244792516, 0.11757307655868993, 0.25984908724504135, 0.11500800734445935, 0.0994016165514627, 0.1259860549602778, 0.1935918587109735, 0.14007520861923695, 0.19309500472680216, 0.19327970852534618, 0.11184335941629064, 0.10090547012946299, 0.13962962123895847, 0.1437556482250652, 0.10104580977631193, 0.187782276902468, 0.2595584334865693, 0.1541557974152027, 0.16079077767508645, 0.31325653916405094, 0.16786884786861558, 0.13578359938917622, 0.14496479543947405, 0.14809110832791175, 0.19912290627196913, 0.11063985826988375, 0.13535630618852956, 0.10622595076359088, 0.18546357390380677, 0.12615433383372524, 0.13272713839767442, 0.16099068065804822, 0.1336148197972967, 0.12824222220168, 0.13580793034165137, 0.07206162392732597, 0.18021596355303643, 0.13052419128437198, 0.14318429985113684, 0.10363395355882184, 0.2149860744154261, 0.1492811952747645, 0.17485561570332897, 0.14241684829035114, 0.24723309002095656, 0.2418799740412543, 0.09365427938680496, 0.12438374376224896, 0.07753280171703908, 0.17197207607809575, 0.07857128752455597, 0.12020927703668995, 0.12318676202407769, 0.10944260840093899, 0.19834318198263648, 0.17776157106122664, 0.0744089632925968, 0.13834430956311766, 0.15659685997713, 0.25540092028677464, 0.17660696930702657, 0.13757325738908785, 0.14676622054990263, 0.1211526147240112, 0.2052680345913095, 0.12469176473396441, 0.16391057881616777, 0.16770013998593056, 0.26108656439089006, 0.12001833728244228, 0.14617757391064398, 0.12146195336695641, 0.1439232376193808, 0.14802137900504375, 0.15821257005295447, 0.1326840229692959, 0.12229176448477853, 0.2010855316034248, 0.16968593181621644, 0.22559970166654358, 0.08828944992274047, 0.21157980235593937, 0.09947284740666229, 0.1027151536677153, 0.08506297869908233, 0.078430442259677, 0.0813435988440629, 0.17659549330992086, 0.16724338304371605, 0.12262072263946458, 0.09518348281421969, 0.09370452709375851, 0.2334995237329314, 0.15259719153325405, 0.08332513888636905, 0.08960622482963147, 0.1944619507318543, 0.123996670177627, 0.11718612554813586, 0.157682835575073, 0.10536518203274858, 0.14964361614998312, 0.19394292616315428, 0.2018893876623723, 0.14364868702907718, 0.1596900625454803, 0.2653701909847798, 0.21043204942778235, 0.12550241599280026, 0.0789357538545324, 0.11290830590071217, 0.24898851921241133, 0.11948112578641985, 0.07744392019606407, 0.10193490843859412, 0.2735273113414165, 0.10153606774345522, 0.265292295164639, 0.137811572020573, 0.19165849793822537, 0.08682700339704753, 0.25489861175658246, 0.1253185089256975, 0.1276855673941393, 0.060429203158785263, 0.2224494102260759, 0.11570589812172037, 0.11590721836734204, 0.14393132750786122, 0.15521937260223975, 0.09093647522311057, 0.13682509592223552, 0.0853853714802573, 0.14706442793530805, 0.11671100547837636, 0.20690459758043292, 0.1117861326483469, 0.14611579658043, 0.106524748036698, 0.23196915585187175, 0.12092582971578646, 0.13337111190682457, 0.09729293655724296, 0.15961415855394256, 0.07751462245059591], [0.03527992322380024, 0.012434139442179474, 0.03199966305175857, 0.011099847934899792, 0.020400902271390926, 0.03299639132174273, 0.009845832865985652, 0.05373554056390159, 0.026723523586688024, 0.019712750386867314, 0.07060843940463758, 0.06649673060183564, 0.04315725294873119, 0.04047539363044404, 0.05970245001897697, 0.025389155470615914, 0.025785665343245192, 0.01744083620818152, 0.037731059841931834, 0.01215140511762471, 0.0374557048593077, 0.035757333896453344, 0.05895478650927544, 0.038283711840068145, 0.015140192774725298, 0.007817629450601677, 0.0822621229435167, 0.01563099657951464, 0.06743170260902374, 0.0424025988867206, 0.016613110764733246, 0.010960782866834873, 0.05989987087706405, 0.0533070637574119, 0.04417311617984407, 0.04690872039645911, 0.017598834181685123, 0.04173561592676467, 0.026985632909101345, 0.05764005322670264, 0.03587113625760521, 0.027825562133183403, 0.01354605860767826, 0.03138932654814374, 0.07421978554057498, 0.06875355667885273, 0.10319405821182075, 0.03709821759032146, 0.025796928750951926, 0.04224530571410733, 0.07899362413633255, 0.013662760611623527, 0.014138018577209404, 0.1323716429572913, 0.030746138279115966, 0.052312256452897866, 0.03158485708427766, 0.03730294309676655, 0.07180503043796747, 0.03501795179721329, 0.05653174999620646, 0.019062956524712425, 0.03712829037178909, 0.023053684722512, 0.05694666704643638, 0.07181253809962543, 0.020585665441749078, 0.023044604665389466, 0.040811472572386265, 0.04674358248350121, 0.03996293826569473, 0.03276613210478137, 0.0071363091551428365, 0.03838837094184372, 0.03822257036283132, 0.010835898086248387, 0.00735834154540733, 0.04619841133394549, 0.04891574052312682, 0.04116421392668159, 0.06805398816903753, 0.0640817916381263, 0.01381614960865268, 0.048606344423587286, 0.023128732610794327, 0.0657959746557378, 0.03126376090691455, 0.04388900864268503, 0.0251570250838995, 0.04740374343049142, 0.09894314357229779, 0.024420299394536885, 0.08775557090918865, 0.018275636473610517, 0.04670013763731526, 0.05207693339475701, 0.024584429901874354, 0.017014303349799687, 0.08686354579103571, 0.03133259007647153, 0.05186252453694901, 0.03953636135725726, 0.052233475801204486, 0.06219414716225959, 0.04010415891365659, 0.06391265091576404, 0.03484522961380501, 0.040011370344267744, 0.047430414781575246, 0.053090314500995224, 0.034736039101957314, 0.03472850462722202, 0.025099463152488875, 0.0521568785000953, 0.05603162098615881, 0.04211562235028513, 0.07969687752906354, 0.03195720837421475, 0.013403000306308031, 0.0641549185609385, 0.05427472473632905, 0.03413206687377345, 0.05765923989876624, 0.037699186753842144, 0.04104969527332052, 0.07207405753433704, 0.04487415174803427, 0.08870808632984277, 0.040432408437012665, 0.04328967124644307, 0.06664032612236277, 0.09276753261445031, 0.015973126658448772, 0.04000677381672206, 0.008716647993893394, 0.055267670447187084, 0.028213583751611655, 0.03956486748891973, 0.0733534703331609, 0.007575726654801158, 0.02023151448567308, 0.07296920063034182, 0.05438507204094241, 0.0841345873871638, 0.04932883045365734, 0.030179899711642536, 0.010408556047496537, 0.04195249541812847, 0.008368819178412519, 0.04520836143544124, 0.06029680784371111, 0.059039531155459346, 0.029302836290650794, 0.0020909491286147386, 0.019989796508584293, 0.029536510344534635, 0.02372716219284602, 0.04904764554192943, 0.02062109892346686, 0.06700672299390839, 0.034855893557710994, 0.0791221353856306, 0.031184784902800477, 0.04860784212547926, 0.03032128315328831, 0.0818560503783726, 0.02554581279025203, 0.03285570693532786, 0.04079942200933734, 0.03372126754613654, 0.037082305944134156, 0.0227633373992097, 0.02306381240487099, 0.033903830128932194, 0.01395111131827317, 0.10363081259833229, 0.032488697193442814, 0.06528921515470551, 0.02147643226048639, 0.011508640112175096, 0.046534218314674594, 0.06029467428884199, 0.0459999677484795, 0.023329846012676438, 0.026644281367020264, 0.022046298254281286, 0.04626171317912879, 0.06110735185023758, 0.024421178480429996, 0.03527314334567036, 0.050842183521918716, 0.024989135000073624, 0.02170363095619025, 0.017573250675453775, 0.02039977229170261, 0.011734072017603585, 0.02934680782228468, 0.018436643257436734, 0.05167765602950127, 0.026733385053493326, 0.04556770263720424, 0.045602563468198624, 0.055443200342837846, 0.08275824148328075, 0.03801676084197337, 0.015386081142951886, 0.039280591412417354, 0.05237019951305082, 0.024437881112399123, 0.03675818180425033, 0.01332753106966735, 0.05588177801860918, 0.0208039621957728, 0.039735800857024814, 0.035194469946286375, 0.025682580552154013, 0.02415217245147834, 0.02079694291516658, 0.02457024003829687, 0.04733844209582575, 0.11125264433963646, 0.029969367258731398, 0.028996433679675384, 0.05733565968130866, 0.03723533200700918, 0.030369420288010474, 0.03600284592398713, 0.04370553058481986, 0.06249864412952335, 0.08173805751627491, 0.026286589169514277, 0.019038416813277913, 0.08657538947919685, 0.017504524927766576, 0.08465535097545193, 0.020029265358443224, 0.005826332799774865, 0.008389988102980198, 0.06131608399652666, 0.1326992681189891, 0.07690596559475507, 0.03225148572856861, 0.05589334211582619, 0.05366614831972027, 0.03706824440028399, 0.031537173856650634, 0.023649737516778613, 0.017827668475107323, 0.03741059760232607, 0.041187227207926974, 0.04969160372932112, 0.03400642079331222, 0.020439909553275477, 0.03101066269371058, 0.04717743722721935, 0.027998866543414134, 0.03524435759191552, 0.010698071207791086, 0.06451939638223379, 0.018746089152691346, 0.031659491285080874, 0.053373717237263925, 0.04441973903486806, 0.05995942272185799, 0.010687738596912353, 0.019209158659401922, 0.010445513086573733, 0.007356256349838429, 0.08075685976373573, 0.011307090040176146, 0.04662559345184315, 0.05046413445304479, 0.017642539497765324, 0.024363049643955404, 0.04360314293373977, 0.02727134540046175, 0.062803658206136, 0.062112512833048264, 0.03171343536626908, 0.02873234976563723, 0.051076801779169234, 0.033016079781396736, 0.02398186727547117, 0.06423916524997161, 0.021707526513285214, 0.05213313743532185, 0.04252235375104412, 0.02967542698306422, 0.04092545113376072, 0.03369683700223123, 0.0365124476112185, 0.019986337621606166, 0.05776667223882772, 0.03606014930072331, 0.04986588107121568, 0.008457609726446531, 0.004369459563731066, 0.017074598299880183, 0.02578232328467552, 0.05358546010909542, 0.024424041734046997, 0.02005973650563148, 0.03201609180729476, 0.012575432868494142, 0.024186736423402064, 0.0456461921754864, 0.05570815185145025, 0.014175666053028358, 0.027851118826337402, 0.033373613015658436, 0.01060437769704168, 0.035348388501593185, 0.04145352320084649, 0.0591407313702568, 0.05500294493451234, 0.03474383404658687, 0.041046309164695205, 0.09797160618848379, 0.005782590136908356, 0.03270878659320935, 0.020998293804305217, 0.057441065718810407, 0.03058837013198964, 0.03386586281140486, 0.04712746914235815, 0.02626995931589796, 0.016826257492685993, 0.015253935764063031, 0.04473813283707827, 0.01558149485067735, 0.021916013511438525, 0.026107050718799717, 0.03464210523112166, 0.06567261917817016, 0.01867081909891098, 0.07746820518326375, 0.010650315201811252, 0.024949294597571416, 0.0069962553548506435, 0.05205255264656679, 0.06790045648813248, 0.05480070538338154, 0.015546542089132052, 0.04503073628931757, 0.038044887760113326, 0.036898973442974596, 0.05118873105534623, 0.11492791285197582, 0.025726511864171877, 0.00727428159030575, 0.029023836644726898, 0.006222109143216644, 0.20755915842469663, 0.11804686363546119, 0.09657361830073981, 0.09632181286090806, 0.13355086677737776, 0.14144835993647575, 0.17573980374201653, 0.1861709488495704, 0.14554801817622878, 0.06506221564186197, 0.15337305473944834, 0.13657032572213681, 0.14384197101237314, 0.07778448458280295, 0.1627473815554573, 0.14460064320554658, 0.12956728617991173, 0.08593522342703036, 0.13902468757042963, 0.10194467605962869, 0.15223699231301585, 0.14188499940979865, 0.14048106667976226, 0.1509983813570392, 0.10040992615564216, 0.16473521117962178, 0.194171067147005, 0.23404340019389508, 0.1969335802019604, 0.14944046495422242, 0.10397899189903852, 0.10382091731674249, 0.13119447225284192, 0.1616309156581279, 0.12410683362113854, 0.13657296106459635, 0.12439914212952699, 0.14496412128210068, 0.13064849671096573, 0.06233777715674332, 0.18910008602805678, 0.10502875452080082, 0.09058093381745201, 0.2331763878464699, 0.23234263903671698, 0.13307388511396226, 0.17174771956859097, 0.14540610804913506, 0.1799466223606179, 0.06412885624975448, 0.20967536906321205, 0.09156169489987435, 0.23605081102540418, 0.243557216299157, 0.12754035542809194, 0.12856326666810822, 0.21228870947755155, 0.10550956662383773, 0.18363038678803753, 0.15286218134626267, 0.12945666308364562, 0.08345224053388642, 0.13936184286590547, 0.18928656715058512, 0.22839236794219864, 0.12604967090151004, 0.13324031005463294, 0.1407315621092435, 0.13337091272396426, 0.15679322363388154, 0.14240872775835378, 0.06359055690887956, 0.06987190715247585, 0.11185797637388592, 0.13651778741228965, 0.10164797020655486, 0.16150270318312032, 0.16174562966390965, 0.13678636251678392, 0.1522866654540262, 0.17531667805967793, 0.15633677312683675, 0.1277014790403266, 0.14629792632354846, 0.08695132414539976, 0.12447215796959017, 0.19452092418026543, 0.2072541328567651, 0.1436351272728174, 0.09737767354254762, 0.12425084282914478, 0.11102621939273612, 0.1436631507690876, 0.08841570121266189, 0.22404471171959756, 0.11075775154055127, 0.149160367887347, 0.14323484633238087, 0.15768062924185108, 0.11868958076041554, 0.19053951927250434, 0.18095179100430783, 0.13321513640544108, 0.13966130663550672, 0.15530825412321478, 0.1263559758362751, 0.10615795279943174, 0.21986426184734992, 0.09938533718307173, 0.1669126169215287, 0.13830629628031485, 0.09082179186084578, 0.1507560371030723, 0.1309916581357679, 0.16042313208022427, 0.10260443864089829, 0.13405631626805953, 0.1385382523820285, 0.1712423926519771, 0.10037061818424733, 0.14497760442956803, 0.17664481405048602, 0.06895301533081839, 0.25053042437761064, 0.16769748932171255, 0.2175049868322188, 0.22535570266266025, 0.14853563850685475, 0.08104575918086114, 0.13139653560375014, 0.22950285835371864, 0.15768821351230145, 0.13018861413002014, 0.2465537538932216, 0.09014766513099594, 0.1882344526388953, 0.1425732987662477, 0.18033326693600227, 0.13775563228034204, 0.0927387353693766, 0.09575788787896596, 0.145319402217865, 0.21056277467118156, 0.18554706216579486, 0.1446866442359263, 0.19710929012827336, 0.1453596524774067, 0.11860826052725316, 0.20422273826214576, 0.12564568209551996, 0.17260967573571592, 0.12759880793671455, 0.09445177691598093, 0.08181966886284851, 0.11247470779644866, 0.09318107453685615, 0.17507505392835987, 0.17547231648237477, 0.16466109983382687, 0.143120254900667, 0.1884535537852395, 0.08441430141007708, 0.07073786229856553, 0.16983202478337675, 0.1571100316340885, 0.17613075373153533, 0.14331393724968358, 0.09990215541854983, 0.09744903463269435, 0.2005452863992222, 0.11389971560528202, 0.2522041885963371, 0.17387390467188052, 0.1231683299486195, 0.0766445457514736, 0.1641952724105889], [0.021803695445639953, 0.049025034456844294, 0.03362685487034821, 0.037187551103171804, 0.0596899627858112, 0.0029147282616430598, 0.11079752682557992, 0.08150224799230214, 0.057427843041237325, 0.07388836824365201, 0.05064785382860611, 0.06025470748183228, 0.013977105639153912, 0.030638112220913175, 0.058318592622996344, 0.023915290404411576, 0.05378763071231304, 0.05739918752242962, 0.0804463183627494, 0.029187001881279775, 0.03506240021858004, 0.019535429760693543, 0.06380061055683801, 0.0276551439592074, 0.06585020601989762, 0.06977325801046626, 0.039379815120370164, 0.007706161742399057, 0.014029258989819117, 0.021122407708917896, 0.07192199674224661, 0.03434149999051325, 0.032379947182151585, 0.0170479882358303, 0.061831860352427735, 0.026902763263112115, 0.05872717029565285, 0.05394703062671808, 0.01633524875937691, 0.018681755004030083, 0.04521066352965371, 0.031940444455211686, 0.07660149161012904, 0.029336906135863358, 0.033091378563474265, 0.02421892552276052, 0.04858602777183537, 0.07949600927531719, 0.04565618196201902, 0.03887759085984961, 0.018161424255419164, 0.07420893007468793, 0.049954804727026535, 0.06304629357351411, 0.02936308144501621, 0.070782080893555, 0.027019287151614987, 0.04519899984100654, 0.026557422318165342, 0.02916481597499261, 0.022199414332487413, 0.03690394918404279, 0.048808572483399225, 0.006627486483569468, 0.03612618224935667, 0.05518055475887753, 0.04234076026947268, 0.025507835896625638, 0.03647215521684097, 0.029909489826569637, 0.03650818050148026, 0.034401986462574814, 0.026554147292289044, 0.01397932633652442, 0.02322985813201916, 0.0748559832572937, 0.031674548743232604, 0.03340529458176705, 0.09578639401062843, 0.025413467270892956, 0.06119850099146847, 0.04835800553161291, 0.04375500071253027, 0.043268848976661126, 0.05282116100011815, 0.015550535322437364, 0.04593095854826031, 0.027765236539585937, 0.04039316941353102, 0.00609053306341652, 0.029349473808261178, 0.01113866656763299, 0.024763642765221097, 0.020340191718611508, 0.0760623112681412, 0.04113247107353903, 0.04382574127145833, 0.012899059051227187, 0.032335491099905585, 0.06128134190916054, 0.0849637856346465, 0.04568206041210121, 0.014294792725253972, 0.027551635904538057, 0.04397006457551353, 0.024613983658773285, 0.02401745588999362, 0.07417842445354308, 0.02716053269743439, 0.050547569088878176, 0.006627182921229472, 0.054156237747520215, 0.07693840941834836, 0.09914224216293904, 0.01112211523802891, 0.04164484982949592, 0.014740599398200792, 0.020878431687672293, 0.014823162609020309, 0.05676979266647851, 0.0321322709562317, 0.054475382315896215, 0.043271645197584745, 0.038963170541870984, 0.052012589669996695, 0.026401167194689476, 0.049022682566916755, 0.05262353329829151, 0.02264544029810256, 0.01711561656256597, 0.02797372162251944, 0.038483810175450585, 0.026353700386901057, 0.029501222419522466, 0.03876558880531981, 0.05369398795488862, 0.047574887472775676, 0.06927427430186542, 0.025756992587459185, 0.1219446040810116, 0.07256845237627145, 0.009859232701391224, 0.010878704206627465, 0.0280631298289424, 0.02213603587851169, 0.052363235773819114, 0.02522650925863174, 0.03463481207408252, 0.01721336938170416, 0.05253364054125644, 0.011156422570498, 0.037446350925752235, 0.036628291596688574, 0.035476892090011994, 0.028160652821703304, 0.03473365273807318, 0.03585214876840192, 0.02325627858930778, 0.047186978852316264, 0.05266579836907406, 0.03172189297695314, 0.04644134164517445, 0.049552194879300175, 0.04891749486447342, 0.06600292564760293, 0.024073876350397067, 0.04208521632057044, 0.05148630258777449, 0.07471090918707271, 0.0623994127606913, 0.008028997418155234, 0.05587084211349007, 0.0022455258013290022, 0.0018366266111467756, 0.02277991554189113, 0.06604527498805715, 0.07177909070085134, 0.07207532924029135, 0.004208917699513897, 0.01300899554119115, 0.018612268914078033, 0.015855059102778474, 0.05808576701148864, 0.026524754413854212, 0.043388780041207234, 0.023008251878162547, 0.07389506385211023, 0.032145072285446434, 0.05009384585484382, 0.05829516565427185, 0.03182966814136073, 0.051473899624280395, 0.044977228878246206, 0.021511063265103488, 0.006351454949547207, 0.03381537378675515, 0.03325377005122362, 0.017061729937972083, 0.0664974737071222, 0.026097650819968794, 0.047970299924453425, 0.08058512583374977, 0.03357402927752945, 0.06514849246389444, 0.019553233644053824, 0.04186615347862244, 0.02134112389608016, 0.040374063180699464, 0.020700258788682764, 0.0374234717098936, 0.018376612607690117, 0.046317756341229525, 0.033208735572594794, 0.04605091642588378, 0.030042543977258668, 0.05529417325892756, 0.08133069792341802, 0.03649861589374562, 0.04922427860419116, 0.08819795604194365, 0.08177086906207186, 0.04295527386749464, 0.06598733575834383, 0.04261657107441176, 0.03331888752478746, 0.039427634328603745, 0.02251264661730778, 0.03530100596347644, 0.02255266705047219, 0.03678050560636386, 0.047953829034081394, 0.07182966782561234, 0.025066354747621283, 0.05568617661934226, 0.020724377151758924, 0.030607359536412745, 0.06319971800210976, 0.06177151560663216, 0.08146804982736226, 0.03669878700748086, 0.020749625494523395, 0.04184911185274682, 0.07735755910435993, 0.034515811806364406, 0.016472949233326702, 0.02222562794603648, 0.018728522756587596, 0.06204046609420931, 0.030338828481974143, 0.0142398891189406, 0.027510805333393718, 0.02385600860561094, 0.08093712025231893, 0.025753292382784912, 0.06502479224676086, 0.01907092192390513, 0.030842807083841295, 0.05534231039364973, 0.05878852627750847, 0.0442872709414411, 0.036868222673693975, 0.006470939767877422, 0.03182986157856161, 0.028326700464071288, 0.03291261577678304, 0.02692148645198153, 0.03463973035855639, 0.0019130915226865442, 0.03485978528436634, 0.011508126833265828, 0.04783856727543378, 0.015266413421129749, 0.02724596682275015, 0.006431905672915521, 0.02557221601056236, 0.037830111180101676, 0.05702324519534746, 0.0025713178582654726, 0.02233546197174057, 0.06649302273628212, 0.04063351034757592, 0.024864007944181084, 0.13113514640398566, 0.06278968859283675, 0.010038079757754122, 0.03026618994021368, 0.05476788234626574, 0.05387969532861345, 0.05373286308660623, 0.05171666905704526, 0.02983427531416378, 0.0260772307463471, 0.07456863899865458, 0.012129932630717034, 0.03231694411125875, 0.0244373754943691, 0.05319417304088993, 0.06177358787446734, 0.08108910443561693, 0.03065672432703357, 0.08022126471323353, 0.0378017123007486, 0.03224822985489042, 0.015177654474222613, 0.010334296272166315, 0.03577674273401499, 0.053422176128914284, 0.007955034023090717, 0.0030746280484186908, 0.02294013900081477, 0.06571911305429474, 0.07610877450074881, 0.04556423608934687, 0.1023687899953896, 0.034647268663731315, 0.13303257765308504, 0.05177178908319724, 0.01892044693381796, 0.05461123651794849, 0.10746713577499313, 0.019188374694016193, 0.004717522036028846, 0.02121831425615857, 0.0860444599041535, 0.040843318847398606, 0.037818232986835704, 0.013434286379525739, 0.041418106956107, 0.09391199902541215, 0.03665509318271953, 0.02366575833049513, 0.04777224704382881, 0.0665326601254844, 0.057136649190778696, 0.03273751489036987, 0.014627686656650998, 0.048695294892475496, 0.058689486430657495, 0.05402312997067648, 0.06459162315173496, 0.03706438714758523, 0.011300458591581594, 0.01293086702184331, 0.02684172712296488, 0.030202625709916317, 0.10280641772213484, 0.02508644731865535, 0.03135120026737211, 0.07444719874089764, 0.020054343246644544, 0.017763705879089334, 0.023259206960398345, 0.11913883770185134, 0.08251619600360433, 0.10025144554674627, 0.16791648321574734, 0.15214077166972623, 0.15283884630808908, 0.2041834073081132, 0.17381436431840544, 0.18501404883159747, 0.1334800036443818, 0.1934606738148197, 0.1181531047088004, 0.08159816220042207, 0.09927121306499166, 0.16225486362893737, 0.11385676871624686, 0.1942111182236864, 0.20776537397215444, 0.26158528762959665, 0.13929087248060013, 0.09583606715163878, 0.0880430454027749, 0.11858627380382632, 0.13403564721586245, 0.15264459705400854, 0.1480532482626938, 0.1473900612684027, 0.2685906101138361, 0.07517721158482375, 0.09597179494918355, 0.0978145045378516, 0.17947333324099743, 0.205453826234706, 0.11266247594668982, 0.13885483055585815, 0.21729509406272443, 0.13684247079635822, 0.17765788872155452, 0.09618277556353039, 0.10913223553929599, 0.14723092948477115, 0.09283755305072955, 0.3356587580375133, 0.16408975145989851, 0.1550692959778732, 0.17532849113547033, 0.15883330045448196, 0.1329789514983854, 0.1467423032849066, 0.11993514013386543, 0.1047515226227622, 0.09030508853855634, 0.10821836925442181, 0.1126569064874803, 0.1877475577977396, 0.2253273114441864, 0.1147305915853189, 0.09711751774434121, 0.1100240767963471, 0.19202405977393353, 0.13971712380166978, 0.1678924586984419, 0.27001761741215186, 0.09368292341429381, 0.14516563304970342, 0.1382924913759193, 0.2106984948078471, 0.16851570186836107, 0.10721546823098775, 0.10062319737288261, 0.09632731337220439, 0.16307580344859632, 0.11657789770153262, 0.09547461154720477, 0.08087130563874399, 0.1556206188134609, 0.1950508425192487, 0.17752826664476626, 0.1451835441853731, 0.17270076358991285, 0.1278198855899034, 0.10648609890091805, 0.19082454994561213, 0.2863653821329917, 0.09976354713040976, 0.1485120583205454, 0.2012261700245642, 0.17526907335606315, 0.11518554822091134, 0.09982226010892661, 0.20559290183647988, 0.05028301977642602, 0.1241169229991013, 0.13069351203739643, 0.15357312626175343, 0.09717193296960286, 0.10215028639762633, 0.09288838298450555, 0.13769612257038394, 0.12444788830414896, 0.12919780197403125, 0.11774324766931035, 0.13520812946221522, 0.1118321285673207, 0.1525383559806693, 0.20646533808640896, 0.18428620401649706, 0.1180315112334586, 0.1347012397262358, 0.10286719913804725, 0.16848121259000995, 0.1983339736057866, 0.10462182393718152, 0.24049402905568001, 0.13112451310359663, 0.09792934877858048, 0.1670386843503483, 0.09207292835438445, 0.15109371333833665, 0.10550206662305903, 0.18034446714145524, 0.14658335536237688, 0.12748770220505615, 0.10074857532257035, 0.12740207655775931, 0.23010304227711695, 0.2322294112415083, 0.17601496720265958, 0.10899620896746075, 0.15655717662265226, 0.08904997604869067, 0.2886110616307105, 0.1475262410578228, 0.0818672352620671, 0.1806967296907979, 0.19644317667811148, 0.1287878070387148, 0.20220967370175547, 0.16269991474766887, 0.3790809586644173, 0.1369244575260147, 0.12652117503626695, 0.1536674776505078, 0.22776745470060458, 0.07106664425302898, 0.20758298375914175, 0.08048405585389945, 0.20349185973886522, 0.13824700107497556, 0.11193628588150586, 0.14171915669595042, 0.18447996297430608, 0.23785523920049592, 0.07855101683807951, 0.11145352791514128, 0.15230344277956795, 0.21935079907698019, 0.15849514924470456, 0.09378076816398291, 0.08550753952154229, 0.18571492735176318, 0.1961944279290976, 0.1519869718580477, 0.09699954786488126, 0.14260123033196698, 0.05929327479773953, 0.32170673411700035, 0.16955293895256135, 0.13077620356794328, 0.21693972119640922, 0.1312727817604619, 0.17385181069614428, 0.12192987987110693, 0.09504389393353656, 0.13696968735706422, 0.13484279745288436], [0.0727634677182763, 0.06421206872008982, 0.03888326374092891, 0.022690055343592842, 0.0506907164479696, 0.018658385491899906, 0.05382613429138738, 0.092936355410324, 0.02593853818853536, 0.02046882554197744, 0.0454260376582463, 0.0997160726617421, 0.02779241350869979, 0.0779468032921995, 0.024600596272296483, 0.10998227903919836, 0.073883855985778, 0.01619644894925577, 0.02360059680687564, 0.03328291969674249, 0.03970120432636431, 0.03032275978776236, 0.025117284272827452, 0.03289506470243777, 0.03583362476239282, 0.0635389685480585, 0.03643247952324249, 0.029767294331724127, 0.027367813107106956, 0.027794154443507715, 0.01430746381952157, 0.06084664063828607, 0.09828701990866855, 0.04464500718900273, 0.061296728785119714, 0.010823104417912904, 0.01294970703912118, 0.04849698537239625, 0.024496262757888725, 0.038972815588837674, 0.04680453626919658, 0.02571515461069442, 0.026088034501299266, 0.05534417964818497, 0.04682122932506665, 0.01052038764746319, 0.03370016565426223, 0.018986813130698377, 0.061493418029239105, 0.018554203279857195, 0.05467890889473981, 0.06876395249198522, 0.10048048285346839, 0.08312702088827088, 0.042014720909778154, 0.054803911461344654, 0.05094830202119005, 0.05922639532194984, 0.025553368332405246, 0.05983993215786834, 0.03131344553924376, 0.0419827290780602, 0.0531256388151838, 0.07876312360167503, 0.027795688534576087, 0.032585124680472, 0.06923714968105478, 0.034886759240180254, 0.028160675804341034, 0.038926681774037505, 0.060701279285093473, 0.029803614560214263, 0.01965566151474993, 0.03205340795008646, 0.016675658013311126, 0.058958697388128894, 0.015578306967302438, 0.05531420262770788, 0.06787937374845629, 0.041223689162683104, 0.06335826372847923, 0.033505295868963, 0.06247300699713731, 0.03360976344875751, 0.01997426982157894, 0.0699361666075645, 0.02998018825066186, 0.026433421411521496, 0.052059079715681654, 0.04190302529041806, 0.0348374231778566, 0.07542324072170643, 0.016715942746809414, 0.03436038405784676, 0.02601968222147515, 0.04176583043449829, 0.02204183962256197, 0.004262044939452842, 0.042640653048311515, 0.07353450457054762, 0.05160873492939338, 0.0340379529722756, 0.026003121315772017, 0.014104917833221056, 0.02963944574848058, 0.005141256758267241, 0.04719290454241057, 0.03416744864455635, 0.04209991371739776, 0.03842119397895952, 0.004849093327779444, 0.06465051999135364, 0.01488800620615122, 0.05983620897055634, 0.004953858724254514, 0.03281260299826822, 0.07677383841045442, 0.056880603454286055, 0.015174567139887763, 0.09468744854412733, 0.04559379942234486, 0.05125363402429128, 0.03234454242873096, 0.04530599168051155, 0.057390381341740015, 0.10284851425357404, 0.0012195684042038218, 0.10060294966904387, 0.019740254858568795, 0.01646633406410054, 0.043222558113836476, 0.03818490948047369, 0.042566660446144884, 0.042908033055643884, 0.01686284776716944, 0.0737674872300798, 0.03467181795126489, 0.015288626140494262, 0.09572803343255674, 0.012372383179383413, 0.0944957273801969, 0.08989150831175428, 0.009397125592635525, 0.050088104025851336, 0.03127082232235661, 0.11732038245686602, 0.035840197796783144, 0.014519155938028088, 0.055762306606817635, 0.034189534959413355, 0.04488475823534593, 0.06609333934442652, 0.041190460098967444, 0.044316914713671135, 0.051426068924727945, 0.09159282871311711, 0.06335778875396618, 0.015467864859308449, 0.10944859154762761, 0.03491973932532053, 0.025579388508753433, 0.04379417461853835, 0.05095476397283135, 0.013845935107148705, 0.023378189991138155, 0.0605859715611704, 0.021801856834621682, 0.07156764277287068, 0.043719396776249336, 0.044930803950034806, 0.04919721271782633, 0.047802197251228556, 0.020723314204763983, 0.02661095079665463, 0.046338126619136145, 0.08422229679361468, 0.03317290947081582, 0.02609274977247321, 0.014048967559281138, 0.039671070257862734, 0.03263777024262855, 0.02296796714466426, 0.0624342582699272, 0.016204573311692765, 0.015220770860211024, 0.024044136817176497, 0.033448915628175584, 0.036873439732458324, 0.08637171734364764, 0.05908187666547395, 0.022218809763510382, 0.08494831065857604, 0.019862660387110327, 0.027723517306449435, 0.023456953405853243, 0.02901144517255166, 0.036400610265592416, 0.022655851432993528, 0.006065673510273618, 0.07013073761857326, 0.05335780559107662, 0.06364686820175379, 0.05808791588811625, 0.029285409705593225, 0.013013510671894879, 0.015599726785665319, 0.042423428817381786, 0.008154464904369127, 0.02274287519075217, 0.05991979682397458, 0.03813912806611869, 0.05061150678703862, 0.0801360527534158, 0.011455078117339122, 0.08999496082504911, 0.02127671505384628, 0.03947228193283081, 0.03884766363508759, 0.03690912027753169, 0.02250754064129245, 0.025041447313983115, 0.013458630738539562, 0.040210832826673024, 0.03261831927023107, 0.10373144590806577, 0.0313463834895482, 0.02236501381341969, 0.0962188046786093, 0.0164014310951555, 0.05597136434047453, 0.014652099963578006, 0.05542859487656144, 0.026872583229335088, 0.013832322682344146, 0.04890990676358343, 0.06592513707977149, 0.043731600556883125, 0.038907077584055164, 0.060364139311376123, 0.05604388605382654, 0.042278799078156876, 0.022463858307849978, 0.030431641949220534, 0.0559733102038022, 0.0059611748081571875, 0.056399458103002086, 0.046756134834140546, 0.03216093796635828, 0.014147327503099317, 0.01335443224712846, 0.05356869427487255, 0.05947678732956129, 0.018169381993732626, 0.05252178916106782, 0.029688416003820398, 0.04953328399888931, 0.04323063268055839, 0.05236812341477602, 0.05035199450268861, 0.009713780375257617, 0.04341833571332597, 0.023553302368870186, 0.019878549050659906, 0.030667196748958483, 0.03981679933325898, 0.0482789337665083, 0.059793637464604074, 0.08276221747960776, 0.028574081746140317, 0.04920859295394152, 0.026497370601000807, 0.04478448498693686, 0.04299349399403699, 0.02178737394241316, 0.011222327199404039, 0.11245794579266541, 0.046316415687362035, 0.00741890941431085, 0.04574635817158607, 0.0411744526917896, 0.04103446544538583, 0.021553473892591653, 0.030784875515007207, 0.1302773730769273, 0.003949449465219533, 0.03282686372497871, 0.01545715016207748, 0.031034087747215267, 0.04261333052249205, 0.02044685605552889, 0.04503427178508813, 0.05714788387018827, 0.04289205629198302, 0.015312238885540397, 0.029124605935066942, 0.022160642622639577, 0.03787921358560843, 0.022314620549760522, 0.07972729888053671, 0.009732006564586154, 0.058881379964370886, 0.03156164462017196, 0.029597919952544956, 0.03482479038798521, 0.011304549501097251, 0.03245127762878134, 0.03646774638083674, 0.01675340444630673, 0.03430262102835602, 0.04093354485268074, 0.09579529595230857, 0.046744881002532865, 0.03470735677007226, 0.020698272705739065, 0.034955339431161844, 0.047828864771872766, 0.03977435040137461, 0.010522423526121965, 0.011622324687308602, 0.07803553159558967, 0.012066709309545978, 0.023192185758342667, 0.013097684582575195, 0.004709171198849236, 0.035071746491256266, 0.04329918222802301, 0.028198373075875065, 0.05243878736491165, 0.06737300495226538, 0.08054515136586082, 0.030724775917347402, 0.026502968788507487, 0.035804486608192805, 0.05362795883669488, 0.0757511493359362, 0.040956335968428084, 0.019551033056491328, 0.014605536181930334, 0.046936717079651934, 0.04748363490967501, 0.05818772182289151, 0.04232345051282356, 0.019857791898351525, 0.07510136121944075, 0.006496393517966593, 0.05061365566366623, 0.023854248518604907, 0.014017206511550374, 0.03097247895634463, 0.005500531884946771, 0.07994064670656958, 0.019016878251286767, 0.16819265791245047, 0.14211597491896924, 0.19374199662237399, 0.14418998943461528, 0.1502653118222952, 0.11471057370785745, 0.09941768141523485, 0.16092242222399483, 0.15025032714249628, 0.14400310994636628, 0.1512795509470086, 0.14615921844397822, 0.1725769944248661, 0.1831998760181089, 0.077803069875846, 0.1540706084380227, 0.14140973378333355, 0.06732394468159446, 0.16282780546574824, 0.095523871000736, 0.1989900513041404, 0.17003917495810217, 0.07572124892425153, 0.170958204675586, 0.11918619725733035, 0.1186876425579671, 0.19035840076544594, 0.10368653783394445, 0.1535089587372157, 0.13765683758162683, 0.10629701307944714, 0.10668885939183737, 0.18257415072331507, 0.17991951816985685, 0.1525870178856196, 0.16932328111462056, 0.17723399695129166, 0.12388220131998101, 0.17847864468011165, 0.11892824013146663, 0.13991390114590047, 0.16313398016556618, 0.13237384929051324, 0.21901715246419753, 0.15949362227993627, 0.1285639255037231, 0.11434957009529877, 0.11373548933695402, 0.1974744382765024, 0.09523301039852443, 0.093156743584381, 0.22648683148286036, 0.11930141688114214, 0.14048226177692413, 0.06537691690027714, 0.1336896512657404, 0.12705788091425935, 0.17948615755284988, 0.16061640074176176, 0.1220710315711556, 0.13920926879490578, 0.17324891482149402, 0.1378209642585247, 0.23584533092235369, 0.09058564525818633, 0.09883040607336069, 0.17385363398540407, 0.12044656511035659, 0.1356085789419951, 0.2070490970847107, 0.34631078161539575, 0.09208978228871861, 0.21867172341913949, 0.09161870716319931, 0.10148271738040833, 0.20501694161324732, 0.1115975677666645, 0.15000176225458423, 0.12681551367765473, 0.16857525754359462, 0.20547346872908456, 0.10952455682619926, 0.12228873843747763, 0.112284840565295, 0.07837582019067581, 0.1394098306134824, 0.11433874527292867, 0.10283228851133779, 0.1872008314896976, 0.1814115510111855, 0.09001831884586042, 0.33084996284977086, 0.131281714345659, 0.19842201243004493, 0.17818711758140596, 0.09109569893729302, 0.10990118863241327, 0.15617826953530312, 0.12981798079225326, 0.19478827354408082, 0.09825509702486378, 0.10500918097433545, 0.1330646767371124, 0.25143731926237384, 0.055475556066319834, 0.10957840514639694, 0.25996936304915336, 0.22479322558689505, 0.11501407476081965, 0.14539538281819514, 0.0640503820332308, 0.1359942429248364, 0.17298931826747235, 0.1470803472423746, 0.11645257337799958, 0.0967110161699595, 0.19223114866162502, 0.13707297133101573, 0.09197227972289247, 0.24096341112688666, 0.1235664198775926, 0.12067991549209242, 0.180631106599204, 0.14295890146205503, 0.1796530881115506, 0.18887099509517993, 0.11439581116240834, 0.16088836195488132, 0.10116996198532083, 0.07736531191415365, 0.19665849335010976, 0.13256080538755463, 0.2213152936629711, 0.29071348268658886, 0.13181515668909397, 0.1420792639856377, 0.132773915726331, 0.11228757549918468, 0.1344333694226319, 0.14737149129711813, 0.19075341102096344, 0.10350944894936778, 0.17287823551845166, 0.1429113580454742, 0.1413580534919616, 0.1731361926443154, 0.08464837957534098, 0.12537009728651854, 0.17291390457220618, 0.09748022973297105, 0.10910670948965896, 0.19058217504812827, 0.16285172273074427, 0.20366442870468865, 0.15560551155959407, 0.17696822572860027, 0.1352704277322177, 0.09567885824869718, 0.24546502037875115, 0.09956302361622935, 0.07622386388961347, 0.15018435165045724, 0.16393582907415208, 0.1302037826709209, 0.17226841420896594, 0.10219283492094088, 0.13946247617563895, 0.1358997842837726, 0.1175422338588584, 0.11990563808790139, 0.09402404704521741, 0.09687522711652903, 0.09326047955020782, 0.1389110001224664, 0.1274651562374446, 0.15864784588977215], [0.022307239292610078, 0.09482696081601805, 0.037041036787653164, 0.03591113370813189, 0.09311683806440524, 0.04023626311531952, 0.018741264713988192, 0.027878491147871942, 0.08742533338766906, 0.04742722785581024, 0.04665987971689432, 0.0471006139301725, 0.08109193896093676, 0.02238880850434784, 0.02540411142211768, 0.04508049369999959, 0.006474100838174984, 0.053443186090237675, 0.03653923770593059, 0.010839179815394024, 0.045199547593872395, 0.03223267827002752, 0.043726287737128236, 0.04714331184063227, 0.02479970252381698, 0.044689593506195856, 0.040266201831400394, 0.030361370619146094, 0.09828388660905824, 0.06408268030011846, 0.0503629457295662, 0.023932935324527567, 0.14367669520358886, 0.10895172990257702, 0.017823119828056906, 0.014300884081861906, 0.03839553003349612, 0.05410998135865216, 0.043109629092918295, 0.047793253174712585, 0.03379792996471928, 0.01359845806408914, 0.011019200901500882, 0.05479379910074415, 0.03868102802023773, 0.03297075418935668, 0.022551889471229047, 0.07463371050694297, 0.019059934307851138, 0.06433381924345609, 0.04943784093484283, 0.024357430389030807, 0.026041274409620993, 0.07065544655967144, 0.005735169294395394, 0.022408872347084746, 0.03394238733416123, 0.03947518157562421, 0.04382222492788588, 0.04111353338005082, 0.02632844629847715, 0.04773498835763143, 0.01834731932068544, 0.03452963586295805, 0.03443271041877809, 0.14210327318118465, 0.013819458150875666, 0.05487640636161931, 0.04953663563355804, 0.03608030890445075, 0.018023359889705336, 0.10260778644512739, 0.07371241316920327, 0.05661170659286361, 0.028147891712104602, 0.047380423714076324, 0.047104287321769425, 0.019349304869049982, 0.014851312509797996, 0.0842701772888822, 0.008824296753793474, 0.016950103266525175, 0.03696750000780148, 0.019130305229355733, 0.03935713891781146, 0.03141679654588863, 0.07180228018231931, 0.019039100546750332, 0.05168753473328487, 0.0356771283212208, 0.012112936970116872, 0.0302830170614705, 0.07970627742789446, 0.03385900632448254, 0.041546518613974896, 0.04704883404737038, 0.04328197206280405, 0.10632109122290727, 0.014551917688109943, 0.00475536294904868, 0.06822426653196735, 0.012347642369868775, 0.036919481616707585, 0.10513563144711718, 0.08141135166008627, 0.01602375645175456, 0.056284770910297675, 0.04745727382420052, 0.03210608032532036, 0.011257642895103464, 0.09910068955392608, 0.021372657990263357, 0.061414219859626994, 0.0452458307958178, 0.028306669180071162, 0.019895132939000765, 0.027383429809443416, 0.09842139939146657, 0.07003491534100426, 0.007260531748479774, 0.020399402654279145, 0.006604750909196634, 0.004574827147617696, 0.06203618366271258, 0.053254061964370554, 0.05460713028667435, 0.030630924400963613, 0.02921353916697685, 0.01673031647148873, 0.03631018890788959, 0.015225157671187435, 0.04189227324640078, 0.017829612423215183, 0.07722961476012584, 0.04032669596434121, 0.008994465949194086, 0.03416049256620388, 0.014986680246018355, 0.06429562976043071, 0.05247539870681302, 0.04625024101246269, 0.15543036853834508, 0.021869330028552684, 0.07803479615118235, 0.030118953586826404, 0.060086083868818904, 0.027198408084410815, 0.11159462598903526, 0.057175892044699965, 0.044481202269033085, 0.024271029077710646, 0.040122579497795914, 0.0182910961279225, 0.01994867099358911, 0.022030403845072277, 0.030964136258849216, 0.0212855959281085, 0.03906940395433096, 0.03730340274952112, 0.06337949585530066, 0.004006371473810906, 0.02747582384355126, 0.024371790707171447, 0.042668538648755326, 0.04916495275533488, 0.05418485879237133, 0.04108766259084787, 0.0392976368687326, 0.018159597135719754, 0.020302862169281132, 0.06545305837907138, 0.05114716312457478, 0.052343122135367126, 0.043241013171932394, 0.012580678655555653, 0.028209927596993027, 0.052203671150510354, 0.03507272325335972, 0.034023523706221775, 0.0308480701078811, 0.03459653832138546, 0.03435747675417412, 0.07318717562743733, 0.028215857117526957, 0.030999380133805737, 0.008974925919075408, 0.02522967894741845, 0.01926066849621073, 0.062437299638986594, 0.030951378979690136, 0.06345219376887526, 0.048400634494159496, 0.02284372300510445, 0.038353031305896665, 0.038174214893050736, 0.018065749449775587, 0.0220669902891161, 0.03704249618514892, 0.06508046385621832, 0.05192245176482586, 0.007698448194611458, 0.024980621848015055, 0.03907312714164296, 0.04951121300579079, 0.01991751228248881, 0.03260208203667595, 0.04178215576816471, 0.044072383278680426, 0.0399803284615759, 0.05317795112909329, 0.02123216895626918, 0.025197275343441197, 0.05057995545587713, 0.025793105972209768, 0.03935309397357126, 0.03488341526639077, 0.031207698592615706, 0.06429689380550577, 0.015172202801031452, 0.1116278665440698, 0.03014204922252365, 0.010117440721050147, 0.014265108733407915, 0.03111467445119014, 0.030989323314579747, 0.0240606383510655, 0.07059780610424858, 0.02406583242719212, 0.023074951323290026, 0.011909087676735175, 0.016860783160213503, 0.05542989722603271, 0.05386291034219246, 0.05554046669614412, 0.08059521521171255, 0.023692649931857185, 0.02319645478330072, 0.05542378767483658, 0.027838872910867778, 0.02076820121146739, 0.016703742796615247, 0.06408885496878816, 0.009487315208741255, 0.09796966032515611, 0.0015945978896437034, 0.05314003360728103, 0.03846523254328678, 0.022589111768250025, 0.049182480847042416, 0.024804469505925814, 0.032325980118325645, 0.11788028547720564, 0.060081360936765714, 0.03813666509344213, 0.031293994566846284, 0.04938510344213536, 0.05719673729711964, 0.014396640284347438, 0.05980527817061352, 0.06646242518458637, 0.009429515790074103, 0.04624733370879004, 0.08077686998031794, 0.089606998578435, 0.05102728185574374, 0.03832305045497995, 0.01817176835761676, 0.04341371237270294, 0.03380349176304956, 0.0346089834197154, 0.006217723289850138, 0.051311676675874385, 0.020649359906993566, 0.11620778530355423, 0.06529851546210629, 0.03043829159240329, 0.045778928399686857, 0.021117518152741176, 0.019805812832689094, 0.07028043885985691, 0.1400265313925282, 0.04287537472743181, 0.01248587814775566, 0.07330625633438749, 0.05555277006820806, 0.040628396710681344, 0.056942848098133846, 0.032278915506697474, 0.03115742598780461, 0.024005533646672003, 0.034495073806254134, 0.03195486031472683, 0.04937892494302604, 0.008986947753827178, 0.038016067532401894, 0.08718806063576091, 0.03985496583364664, 0.005273185717317486, 0.013598720449203206, 0.07259123583113955, 0.04484223652510874, 0.020909274387503826, 0.010932731599877439, 0.020160593896082813, 0.02856573138776566, 0.053124731000993526, 0.02315244686249043, 0.03069297369239071, 0.035786445237576, 0.0384025244162448, 0.0459211832663465, 0.05582586126101594, 0.04815436020914105, 0.07865987793211976, 0.06604709827731695, 0.04513823374685261, 0.04930169944981894, 0.08086356048982951, 0.02011595395273499, 0.0753720660483645, 0.02363766014065233, 0.032585113189153136, 0.055980538243367794, 0.020003530549846833, 0.05870473924122992, 0.03875820754816936, 0.04853149380294546, 0.01761322322812292, 0.03794504352094185, 0.0338096549404004, 0.044834828454880946, 0.05289365590039281, 0.052659003169185696, 0.0376098187670352, 0.04634827728413286, 0.04002422146919755, 0.08343200815180618, 0.026222337375304876, 0.03868388935863491, 0.04088525450037372, 0.025715146949815176, 0.03800777846106118, 0.043382172532860315, 0.06603801247453497, 0.01742831067061953, 0.06714913107815289, 0.022680170894149813, 0.04331275730604126, 0.0466194992224055, 0.05604583191715422, 0.09501342661678792, 0.03794432722873265, 0.14724789067141472, 0.21648802043449497, 0.15890891333260845, 0.10186425981021698, 0.2148587659241692, 0.1656142204639412, 0.1626999913564613, 0.14390831422661582, 0.1465151888588744, 0.131486673508921, 0.2487591065226063, 0.11484031069783435, 0.21445813258328747, 0.15969648236228576, 0.15982791240657532, 0.1251656130977696, 0.07740826646406805, 0.1614123354515722, 0.16063405140753717, 0.09518983368311199, 0.09016708545987645, 0.10350036314658581, 0.26348092623295327, 0.161220905401053, 0.06639461874240829, 0.10808382123228043, 0.1223250280224508, 0.1339880118687307, 0.16544146763701595, 0.17499150437933786, 0.196510240015003, 0.13562909477660734, 0.22225621817333086, 0.23331258295764848, 0.11172712089553957, 0.08425079526439791, 0.13293770532454216, 0.12166520415414726, 0.15719342796552568, 0.14901402977205094, 0.1478145812307635, 0.15052660909150878, 0.15726560876975137, 0.21601782631008856, 0.11699238191208533, 0.09652245894915636, 0.12394177997785231, 0.14622577616283972, 0.15104377972743205, 0.09397463437410132, 0.14748491827518712, 0.12382124370384602, 0.12741893815297273, 0.20882689604355445, 0.15563335119476243, 0.11482994552821883, 0.12050199923255753, 0.13794448827543568, 0.18680560672956129, 0.12051845480117107, 0.1701943843715614, 0.12965837403410865, 0.12959065186160226, 0.045480514170541886, 0.13641853306081989, 0.16129077261974736, 0.0495781690903729, 0.15249357048061588, 0.13569965147443358, 0.19656685391260734, 0.09328134778526523, 0.15929681429218862, 0.19327572486813993, 0.14608477001949666, 0.12505050072626722, 0.20597848921052872, 0.13635461068441793, 0.12981880816721147, 0.11146581596544675, 0.15257675230743425, 0.1541838975202653, 0.11870736166113809, 0.20751896945218887, 0.2358467864894098, 0.1318547327912623, 0.18125778184302394, 0.20928772857352612, 0.15431413246739298, 0.231266729834099, 0.1418108727422453, 0.1307214742466327, 0.10918587701575411, 0.17809014617195054, 0.08324079260590576, 0.1268171531058127, 0.1767860346984479, 0.23681329833644055, 0.20894272853770565, 0.1560503328519483, 0.20184737540060477, 0.20525807544829386, 0.11625604884278391, 0.14435866667378333, 0.14568997426859795, 0.2143115952851311, 0.21803750987014464, 0.12566933889062176, 0.21478192730536386, 0.1876272513501106, 0.08202875724002238, 0.197702165572874, 0.14293542852805508, 0.20015504121059374, 0.07020597511361684, 0.13663150550376985, 0.10787319301837876, 0.11429925344043201, 0.16995020150657625, 0.22422933890934915, 0.14756462206282925, 0.06398903754269404, 0.09483207828335224, 0.08205639769233043, 0.19870497466575718, 0.1154945191416529, 0.16985189710413257, 0.12276976504513334, 0.13644238903878197, 0.10507115748740974, 0.19657325840765433, 0.23719361502557035, 0.10638759531561406, 0.09942351900521787, 0.1070112674947708, 0.11099264175901491, 0.18224122423318126, 0.15911785615307672, 0.12107109530798851, 0.16956063047532113, 0.1444963633172935, 0.2041615891240297, 0.1967181715994112, 0.09310078086151231, 0.18305949806686372, 0.15191597082922537, 0.11398739436821592, 0.10288376195897019, 0.2177873361975916, 0.18861797157554858, 0.17249695355853728, 0.1341392989120176, 0.11212511889396176, 0.06193073549037499, 0.09162889613259224, 0.09005241741937015, 0.09036583931095178, 0.14259269611249048, 0.14951551092728493, 0.19118447337419758, 0.18198772573903685, 0.12334863640247815, 0.10660447480697786, 0.11332231513675182, 0.22761970698352785, 0.10346941319444489, 0.1318384304402336, 0.12537342210810992, 0.18363873714641218, 0.1141355251292548, 0.25456927055793427, 0.19005328326696352, 0.11867342396609246, 0.16039972043325826, 0.10972147206625632, 0.22644776099872208, 0.08579270042959722], [0.019166767184111862, 0.01884145752316521, 0.03939766879944552, 0.080496251973654, 0.03821224349761202, 0.05134336207242263, 0.02937846449053576, 0.0751575690904452, 0.05153875662794998, 0.03374005202203989, 0.013113924688960036, 0.046004100792830994, 0.04056851544807996, 0.0587738020676038, 0.04298099526955236, 0.020330268964772264, 0.01811306687041877, 0.04118242383664174, 0.019053282749448574, 0.05467777508461187, 0.021901620634561105, 0.029206121520650004, 0.022380019560636535, 0.06958670027914547, 0.020353150095850713, 0.017210182455939152, 0.01230015257944263, 0.020261566199722792, 0.03410932172330157, 0.023620595532138983, 0.03766595002924723, 0.01569428884859888, 0.009295116197468053, 0.030374947612384157, 0.0190277662759106, 0.018172835135051323, 0.014529956820150538, 0.11382271610801259, 0.07328264550456116, 0.027958413270572503, 0.04273908385526269, 0.08252493706682036, 0.04093398152279758, 0.04330560970570772, 0.11178397228040042, 0.05933150258516112, 0.013871395081702261, 0.06004501389519823, 0.07929285041867726, 0.07432830189504931, 0.04433485649285778, 0.01937393076537598, 0.13177089212882903, 0.08027715848818903, 0.05495954222316223, 0.04761664692552821, 0.02205267976669054, 0.03998806211917151, 0.06226992857972942, 0.02902515240073685, 0.05121295092507236, 0.04491602228353581, 0.08399310626930769, 0.022332206098062378, 0.013169525435284503, 0.04812273609962675, 0.0425655534490943, 0.026391853480750037, 0.04790033311432889, 0.049311513036128976, 0.06516028255704912, 0.05334808776575712, 0.00918495275395652, 0.03359741028097849, 0.03147027331344303, 0.05996137241562528, 0.03693710546940565, 0.13363245514131364, 0.027210004740364613, 0.06452542549419789, 0.041577640935898795, 0.020460944412456408, 0.04955041372487622, 0.05226260629452525, 0.015114058642798375, 0.018980130928778843, 0.06021139670103308, 0.04463522424620967, 0.013221021865554636, 0.06212319209871273, 0.01345451780399608, 0.04439896273036157, 0.055502656426641254, 0.04703918133952445, 0.04997373092919589, 0.08230831804535083, 0.011897705525400178, 0.055277549150970676, 0.03103685907028135, 0.019399401273638494, 0.09971408849401821, 0.01606833989611797, 0.0783319156917353, 0.036659080670365406, 0.030020327427454536, 0.06316361610867804, 0.02512588744021712, 0.0793711063001425, 0.016726558810220133, 0.047716039172824354, 0.032753648702055216, 0.04285172176276965, 0.0044821621099066355, 0.04921520812316768, 0.02107016242770178, 0.052477195182995456, 0.030547457206393444, 0.056858203043380094, 0.06146827502356422, 0.06202202635787188, 0.025708748200427622, 0.0537537083390259, 0.08221260302009122, 0.07498481626351995, 0.04761016199124917, 0.04897847929368577, 0.020095861381700924, 0.05012236730826478, 0.018826306219242753, 0.06166106871058864, 0.05942700693624155, 0.05380947953991352, 0.07936384378662033, 0.018529678890181166, 0.0493311670218264, 0.02683017260184692, 0.012280234293411336, 0.021165749133234064, 0.01715495517747777, 0.04205284527532997, 0.05419035547322804, 0.012837775847724369, 0.05531651621323921, 0.04741742576081907, 0.025528403442172755, 0.0441258906897518, 0.02398064345001213, 0.04336581655567692, 0.04349804716184736, 0.026526805614271474, 0.043460217740146384, 0.019144763223706715, 0.04453911468566907, 0.05673119332641364, 0.04237496992573143, 0.05443138205596516, 0.03288270004333989, 0.041654341658877755, 0.055441813723694895, 0.050064202082613786, 0.024403771047570536, 0.039947869316224134, 0.1103348097193145, 0.023938962521271843, 0.018155688172086112, 0.07135164428261981, 0.01844706588364657, 0.0199602140233882, 0.028605631162081997, 0.012136562164091777, 0.02691189694638935, 0.05275625037029386, 0.020690653961332097, 0.02125620688011329, 0.031124853844484015, 0.045380283056968646, 0.015070690405404857, 0.046656899634868874, 0.03554528075901251, 0.074079223728228, 0.04185894076081534, 0.03379100836032341, 0.05800235918873261, 0.053074150045792905, 0.08909351282542752, 0.01607366995285115, 0.06566409261957293, 0.04354644093602415, 0.033518457259502143, 0.012213986840159183, 0.03447433963658349, 0.02420982439822007, 0.025149421661251017, 0.0033725833430165247, 0.03444744995044124, 0.01347456057931507, 0.10541236538800502, 0.05751987701402076, 0.01772084517494565, 0.0384191332024432, 0.01655125299528722, 0.05376402371292634, 0.024704575471039263, 0.022284143656912832, 0.06017951595206415, 0.010344788803899241, 0.03523965764250006, 0.02383109351109353, 0.021528124043177214, 0.050088180634643764, 0.043590234352215644, 0.06155407304064401, 0.03856580839642594, 0.0337895029975522, 0.06668444512592209, 0.0457694863660201, 0.010669242361590508, 0.028813622118304336, 0.022861187894558235, 0.024530704155744567, 0.02867017406970263, 0.04973869515402664, 0.02401865864803474, 0.038592165651460814, 0.05041628460129423, 0.07342455563165488, 0.06416041141135559, 0.05198592597979212, 0.045555249877995065, 0.053387162080335046, 0.06182916372293427, 0.09912037035270084, 0.019536222661695173, 0.06239282057410287, 0.049145072773699804, 0.037878972267912286, 0.06851374051503598, 0.03440279085489531, 0.021369291033836144, 0.00597209970076238, 0.05041858286506707, 0.051536305146592284, 0.021541990234606692, 0.019446239889329, 0.08299588195739255, 0.020639737842664607, 0.050746081622257355, 0.02484536710976353, 0.055582421501317335, 0.03107274837431408, 0.10640984250893516, 0.024884225004502845, 0.035588813705309745, 0.04557264773475547, 0.00817163101953244, 0.06578959314332855, 0.056296518868616516, 0.055409201360758276, 0.016324559917613383, 0.08278880839145954, 0.02689105743962911, 0.053305876321129264, 0.03163374498516562, 0.07478205577260064, 0.03997171763330698, 0.10076743640726614, 0.06186688972276546, 0.03245168748582083, 0.058950994374050256, 0.015142649044132522, 0.01695075444126081, 0.014973502576110825, 0.07349700456665409, 0.01547567895613611, 0.0724946168221293, 0.05619101323968461, 0.041350633762176, 0.017779724777586037, 0.06730405703908013, 0.06733548196573412, 0.029947148793707454, 0.023112820964607022, 0.028117608256457795, 0.046665108266977534, 0.03915968358576779, 0.032705350688868956, 0.04489408152538442, 0.012378808741848315, 0.046022134502568555, 0.02121486877571912, 0.03871639063882251, 0.026323591216257023, 0.008431649879522381, 0.03450238228505177, 0.01703323338240866, 0.06078446494235147, 0.0585273745650005, 0.04531084484751186, 0.04276087522626885, 0.038772288244217634, 0.03104936928608485, 0.07647466575426441, 0.10541316978032551, 0.04407815192075026, 0.020431986288918604, 0.03334547460619961, 0.06310069730745689, 0.10482120598035474, 0.11151397991324626, 0.057163565689998294, 0.03578923379762038, 0.03408213709330848, 0.008825787752416105, 0.02635614420737951, 0.00479393691245106, 0.028814711878376625, 0.047981446503751704, 0.0456250558096555, 0.033178214629691456, 0.029449404232324134, 0.07184330419066452, 0.05080420088263289, 0.04040020976155516, 0.022874898953183044, 0.07194522452811081, 0.02514756772847426, 0.04236870332651081, 0.12936123917179723, 0.06079552342153846, 0.06140804136051767, 0.022760784411202037, 0.07057507627553518, 0.04309377873376493, 0.02559317043051124, 0.046971811567463224, 0.02666328417798204, 0.08034553183543106, 0.019732841042681568, 0.05493483205716457, 0.09423951693480054, 0.026892074421348593, 0.02029805688277608, 0.01819364399829459, 0.030043988052995938, 0.03671260340319526, 0.009722965769469738, 0.031220388839081414, 0.06854226962933618, 0.06893482074261674, 0.01601412002327702, 0.08056067996808598, 0.05871106712748447, 0.13398945211402832, 0.09646585271243127, 0.09874887899645875, 0.28208359415012024, 0.2081447866775336, 0.16048621175990951, 0.133948267227219, 0.2008992036984813, 0.2204010136906178, 0.09596160597979062, 0.12338737746880901, 0.1261339405731809, 0.23653572935971523, 0.13314637235335766, 0.12365941529072101, 0.09808825839671398, 0.0933563324712938, 0.14280344690046004, 0.10787797340702628, 0.10754737582418228, 0.17332719368559701, 0.1149715798636598, 0.1122705760081449, 0.2117565081965539, 0.09357365629365368, 0.13217172465257107, 0.09229775983840229, 0.09287274712997098, 0.22095872569949399, 0.07172393237030314, 0.13937934031409605, 0.1198325303172873, 0.16422222338376508, 0.12320881003453849, 0.08115367798675453, 0.1325111475683028, 0.14003731791050206, 0.16505367392974515, 0.17129771952186862, 0.14551247169654216, 0.10910311653729408, 0.15396419882534013, 0.11574944255933647, 0.08562017742904925, 0.18716660268124075, 0.19284708335274653, 0.1149517305255417, 0.12941245981041463, 0.11911839847603153, 0.170985370153381, 0.12081157536275926, 0.1556031366870288, 0.15771050667089803, 0.23685149548034515, 0.1275958278546891, 0.1372465515328992, 0.11856500720304829, 0.1127495265175258, 0.14390302821993828, 0.1714472292411712, 0.11156952894863584, 0.16244002708023594, 0.13896471820771694, 0.09207002488115142, 0.09714982367210812, 0.09705766329481717, 0.22697908893948604, 0.13099844567477703, 0.14050728220853115, 0.13388719469789537, 0.08504281526491528, 0.2132921161190156, 0.09539131480719774, 0.0944139015290045, 0.17880783266117498, 0.06901506079180587, 0.14413742048125114, 0.21115949587716212, 0.2986774569557559, 0.14387356447837046, 0.0929238451945205, 0.08719674807282225, 0.12321830952479956, 0.1923725684924472, 0.16590161068785578, 0.12805675997609092, 0.19771043932245624, 0.2813563315618423, 0.1352606218067869, 0.1994127479772414, 0.13464710795350615, 0.07675960449682129, 0.15595317758139104, 0.11332933250213824, 0.12331543415183983, 0.1761493083810614, 0.09141164125814553, 0.13580177099474017, 0.22644278142721425, 0.14816183356508134, 0.36171834194852465, 0.08727429915339717, 0.12812452045299355, 0.15896820853794777, 0.09810458373038039, 0.14405345724475, 0.10221024043858053, 0.2008708737670414, 0.10446175752628235, 0.12354046481871798, 0.09187407491187896, 0.0795305675015815, 0.11121165863568745, 0.11638540278879866, 0.22549680073655423, 0.12309709143254066, 0.13646601519036677, 0.1888740134816016, 0.13041710751431604, 0.1449571652037482, 0.12694172666317996, 0.16500064532362646, 0.13513556561402737, 0.11938194038286326, 0.16230930183683673, 0.1671408191924134, 0.11782895758627884, 0.17169430791851015, 0.08319472007813954, 0.11419682748495572, 0.17348365948325203, 0.2000102812364217, 0.16908505841368632, 0.07085333473139233, 0.19959187465569667, 0.10000199199684205, 0.14846927997085357, 0.15338744187066633, 0.10382221966621377, 0.15922043532613786, 0.17211027833963596, 0.13162047842577582, 0.15981027706255838, 0.18601636762820906, 0.1849425728282621, 0.13083130061145753, 0.06688979499402546, 0.11667005041794432, 0.118795546042102, 0.06871241009643964, 0.08967207774760262, 0.19323404968505908, 0.20116457655545206, 0.11803877374698078, 0.180294671426377, 0.12015563556023183, 0.14195311994802567, 0.08328623694157408, 0.24648722681787708, 0.13159008005694037, 0.07843978087147398, 0.09312464450035365, 0.1749634349177922, 0.17830917070950233, 0.08682388541919571, 0.1208649870128401, 0.09838468079725582, 0.11201048915785168, 0.16896009415147767, 0.10964411250766247, 0.11099425820453514, 0.16905735667434432, 0.12757520476776746, 0.17731546274115964, 0.18778338006907896, 0.20186645098991934], [0.07430595511029806, 0.037928871404860294, 0.007889040815268434, 0.00821616083774115, 0.0530189534108485, 0.06558205992464097, 0.008692292143560706, 0.05979548373650159, 0.04742018367734648, 0.016245166395580577, 0.052124373389468084, 0.02833383848830577, 0.039975594038203846, 0.03184995031915605, 0.0660878235113717, 0.022237697661283518, 0.01147099742440567, 0.02875769386939224, 0.052044550858197675, 0.07420592701002475, 0.03249027150412721, 0.049838393836492495, 0.04063899170667414, 0.03268551667250934, 0.02223057687402733, 0.08306175019712218, 0.025365912362993247, 0.03171162739876778, 0.03865173281801324, 0.015880011544082195, 0.021073242101157387, 0.14094667959838145, 0.06920648318144583, 0.030185526627446377, 0.04599747796272559, 0.024754987886896538, 0.051229379680608554, 0.04537824909352968, 0.050700702404062596, 0.020832154231386322, 0.03294551159225164, 0.016240380261273637, 0.017585132699159366, 0.023327900149348765, 0.0866400089956099, 0.057130903531346595, 0.07886358071118593, 0.00945347423229607, 0.07173041347414255, 0.030725377296367963, 0.06131210800019964, 0.03171404249094908, 0.055749562734197226, 0.04419601837834043, 0.006544078660813431, 0.11376011906371963, 0.04258740227669478, 0.05367080613429989, 0.08492219472123731, 0.04180059167406252, 0.10788904337753212, 0.04411785825786572, 0.025361296683249455, 0.0329298987203548, 0.006985065683106622, 0.04019565279445341, 0.026426371487398303, 0.0696793049874325, 0.024716486223042015, 0.027817757612454797, 0.009737368222446212, 0.03544744367020265, 0.025969024657482104, 0.08726296105211781, 0.04420117415007084, 0.025353697091040593, 0.05430487795702873, 0.03736865428847171, 0.021507207927624547, 0.032337555706861525, 0.022819106684877508, 0.038511492762594454, 0.03745563208095489, 0.06169427096122696, 0.015415931758921475, 0.023562554795775684, 0.02551473451838378, 0.007606580367146601, 0.03528896306130675, 0.01671937865114981, 0.042741221240571434, 0.03739595766209307, 0.04332204995256278, 0.029072803069627094, 0.020210994820621227, 0.029116065969931024, 0.0460294621335643, 0.04342302034098295, 0.0772453042408151, 0.0062569651861615, 0.027481590570401282, 0.0698952345297702, 0.012416509843821968, 0.022574199866803906, 0.04876652191723547, 0.014347710248623646, 0.02641516362106608, 0.02239686200365184, 0.08425810374319555, 0.07930082539396902, 0.036401728753961866, 0.07501611861610606, 0.06558772897528065, 0.02761877968066162, 0.045211479413293065, 0.04795462193508302, 0.04772627410749274, 0.08706872711979574, 0.07051128413408034, 0.02354105070774113, 0.08675784864012273, 0.04835666870818504, 0.05447116500187305, 0.009164308599616972, 0.037485727845060254, 0.029919481528322064, 0.027840778554579424, 0.024687566403900425, 0.07759860866973478, 0.03845572922258608, 0.029031750332984715, 0.00888639775615546, 0.011324700486335543, 0.03290223528540904, 0.02082019368366849, 0.03079092186394959, 0.0562956570197017, 0.038620568361253514, 0.01597718788205736, 0.03515444951312196, 0.03921671500129085, 0.010338835343117676, 0.01927939934595939, 0.06657139353093601, 0.06307386124746935, 0.043802210880864056, 0.036616616416722536, 0.05133645962022486, 0.05074464903783895, 0.014334815073638194, 0.022508810432026946, 0.03623113629498309, 0.07155216013592097, 0.026093743771554965, 0.010554209471710268, 0.03511584634261747, 0.017827768066537478, 0.027272862254551826, 0.02832077668919679, 0.0695101221302344, 0.10250063372715827, 0.05690868057671094, 0.03296413902013052, 0.01995564430891987, 0.015465445936687533, 0.05433369435430054, 0.03396625863388181, 0.03647253443036349, 0.08396292240509103, 0.02613809068627175, 0.07487242350414877, 0.024034577955101288, 0.030922062710047733, 0.037696444159073215, 0.008882561570874626, 0.01082320592456287, 0.042079110599813924, 0.05497715075410182, 0.026933249732058857, 0.05884901274957004, 0.05559703079803337, 0.0691063784723801, 0.019303665180960973, 0.017071685250548106, 0.020228277764192993, 0.08538023869116461, 0.018695092594791806, 0.03321941483825926, 0.05186702913394378, 0.022525763957791274, 0.039102311261118426, 0.035376523080612385, 0.05150898262077282, 0.03175433105488699, 0.06437016245458396, 0.03380106326432959, 0.06863926402142934, 0.018401328519347216, 0.04721057052994448, 0.091592415025638, 0.027905777284515, 0.04292711247539809, 0.003122074985801573, 0.03338577466145639, 0.0351663047237502, 0.01912598066302317, 0.007433996079564696, 0.025168606418094812, 0.07150177453314105, 0.03189410954233139, 0.00765239529784829, 0.032042621432112596, 0.0230604856680598, 0.017679505155331666, 0.057595329013683146, 0.05393408757123736, 0.02858367508217212, 0.052232786322072636, 0.049677733707452015, 0.0026494248313904414, 0.025412126617025466, 0.04849415850795565, 0.08074202064064243, 0.060086673756520596, 0.020350677547075098, 0.039617926738555395, 0.07401831973824771, 0.027102231491176833, 0.050590738143411376, 0.05023639566535431, 0.013142436566281945, 0.01714336618240322, 0.01475445697114112, 0.03752497452942114, 0.05802847512607133, 0.03658334904861066, 0.0903452238849094, 0.011419026977232388, 0.044159813063038934, 0.04119370448132677, 0.044586481902027325, 0.039524571264102575, 0.05096976014394915, 0.06200790352698776, 0.048520871993875316, 0.005642755150479535, 0.012846118545219784, 0.02796973988053299, 0.02405318431556225, 0.046437599305664344, 0.0469009867388635, 0.03492461547495858, 0.04861032808079355, 0.04982369643966517, 0.023043855814443483, 0.018021163132582462, 0.019698194716305985, 0.030727024385405165, 0.00797375529674032, 0.09154389867739332, 0.01327192074724383, 0.057848226128806995, 0.02752780290921369, 0.031328121868653164, 0.04098437861689637, 0.013503277385156724, 0.01860207228380586, 0.033659616620430065, 0.044933094552928404, 0.06705235885155779, 0.010205351225581142, 0.051407223161790645, 0.06554151855168805, 0.012678745570742797, 0.018752520460815682, 0.03374759032721481, 0.03224844818994884, 0.04593002392099269, 0.040728371184799946, 0.03237112184926387, 0.034928384627546036, 0.013898595033453838, 0.05936821351849264, 0.02886574482545257, 0.03490445204079151, 0.025617872935629664, 0.058706194808286045, 0.0477701326411578, 0.07886230134435239, 0.035451967419395526, 0.022966754810524084, 0.08703749371512283, 0.01989913574840513, 0.05836155866422962, 0.030878321004791126, 0.05439830237939473, 0.039476173659486156, 0.04664546960303861, 0.08277568530531661, 0.022095492590338956, 0.01339964292597987, 0.021473793087587244, 0.029149396540296656, 0.022536312988508615, 0.07805478338512682, 0.03431730310342485, 0.021246822303040855, 0.0120775054036189, 0.034099105940831285, 0.04080623636142381, 0.021660615119241902, 0.02034159557473275, 0.08953228202317992, 0.015967783195176916, 0.016527314662873265, 0.03856921748768899, 0.04892440880799005, 0.029095879553126234, 0.041535387356435104, 0.01628172794176686, 0.03081651303106018, 0.013630378075064191, 0.003595208733214907, 0.07354133041395296, 0.024303564831854838, 0.022080889039282358, 0.02753645395709863, 0.014590033435172614, 0.05885456688702107, 0.01498062623619673, 0.017967418234254566, 0.023735554686056513, 0.0014373853956649622, 0.05488707413596492, 0.036143495836445404, 0.03456967927876019, 0.12158078126489155, 0.06764074502092216, 0.060086011090466095, 0.02844502274397641, 0.016766853119817474, 0.008683485962871102, 0.07059234389734846, 0.04967220255263871, 0.0866187270730734, 0.11516385261089572, 0.015509654955577948, 0.04889997060320551, 0.03719108659894236, 0.05941783686378791, 0.011669568371989075, 0.03499607998697508, 0.11974608495591149, 0.20158355004124104, 0.16981434347408433, 0.1410586356876358, 0.1240101456642151, 0.1778320971155359, 0.12691555709968652, 0.12238629973463475, 0.1983691370415111, 0.15238896883543462, 0.12473547771092384, 0.08728225880693044, 0.18989842625394945, 0.11352764202221749, 0.1399286406775636, 0.13405968705492635, 0.17602766894044417, 0.07071075044692525, 0.1447296524119954, 0.14768718080895563, 0.16651714701325665, 0.12307220889676003, 0.17220128958504047, 0.1720595479972901, 0.09684762496861721, 0.16909926168380246, 0.2058297762226674, 0.1678677753455216, 0.10020255381541868, 0.21287098226528015, 0.07777563626727751, 0.20673726865601158, 0.2797907849232997, 0.16204025175782943, 0.10506487556643064, 0.14342551029497577, 0.1414711127478269, 0.11541495324983714, 0.11748594171818226, 0.12596936956528695, 0.14722372825828292, 0.14530072499427105, 0.19530219596720513, 0.16473013967756303, 0.2937817261103661, 0.13559534094266354, 0.19732426972158496, 0.17983083583174214, 0.13868098988408042, 0.1795523781930247, 0.18253463590818067, 0.14342189435997318, 0.13342835399652683, 0.13020684702261803, 0.16278963896536058, 0.28437238907621754, 0.19934294204558098, 0.1371876546932805, 0.21248177895622872, 0.20997564488601303, 0.32845869600292177, 0.07259754839563563, 0.11860145766648555, 0.16730854648255533, 0.07838327422617905, 0.128686468928091, 0.18526394671249777, 0.19111718021092877, 0.10080793947582284, 0.09914712980389596, 0.0874906653658517, 0.12412084536927363, 0.16045207488200358, 0.1485594331977829, 0.14529245124468881, 0.11449470545255369, 0.19706603680406848, 0.09651191757931825, 0.1652507270656286, 0.11573973622533584, 0.14566588846425857, 0.19805763036974017, 0.09888711956239517, 0.22840427294854196, 0.08373461288189696, 0.113796477596606, 0.0854528102002317, 0.10251754128764715, 0.10146258458975824, 0.07816133089363575, 0.17264220382898085, 0.09609977759781385, 0.12176252796404785, 0.12681424197170044, 0.10708991408107743, 0.1636374378276448, 0.10309229109195933, 0.09280464191350246, 0.123600066459227, 0.10045095016398739, 0.13863517782620846, 0.1244103270132215, 0.14474240011505543, 0.19493645027039513, 0.1944630079331898, 0.13397892606594872, 0.08999914366511569, 0.1821662395471527, 0.11897221357832033, 0.11530190931573031, 0.1880484311691215, 0.22194651946906122, 0.26853833227388324, 0.16610327567304337, 0.1341619597928178, 0.11533478214856117, 0.17430167284704026, 0.13484575455227207, 0.19858555688012033, 0.10642458970147757, 0.2047820896991799, 0.19654885084638674, 0.15132897893988317, 0.1292405343584476, 0.15266195660637272, 0.12061539556710951, 0.13487561665956052, 0.14631327872555103, 0.20952778988547865, 0.12657521487844567, 0.10236767150702016, 0.10736495496765261, 0.08067426016373981, 0.16737970072896252, 0.0621929137607015, 0.12727280688141623, 0.19662499998606023, 0.13845301743957306, 0.08037416054116142, 0.10421966608133047, 0.10578667594780845, 0.11216522359679784, 0.1668704667639348, 0.18385129590188304, 0.14787349339214065, 0.1271632333256064, 0.13888067836242338, 0.20048441305275888, 0.16246593617383512, 0.12312975742163197, 0.18076520262947007, 0.07758203818793259, 0.17025596251891506, 0.11386846687885062, 0.08608897727343344, 0.08259347895340574, 0.16350211605669993, 0.09553947621175359, 0.17967577963586778, 0.2179219378458877, 0.2924698771488282, 0.13788583658395276, 0.16798993572592738, 0.11282062713777828, 0.10537739347426162, 0.14894286020388528, 0.1448131406739835, 0.16177562966702447, 0.17969206666513798, 0.18264904347879274, 0.1998768746852875, 0.06110272467917493, 0.17116301062126316, 0.1929666696777267, 0.1135104280265589, 0.06828013732428513], [0.06191769284346412, 0.0378267863585103, 0.025206696309690035, 0.011799955579091706, 0.07033516052028826, 0.04466013359506765, 0.038428785910289136, 0.01916742218928712, 0.044043919281853784, 0.10653456162300803, 0.12498366721575299, 0.0557887711141619, 0.03332895008967288, 0.03511503428941773, 0.05712862441977186, 0.047864212068699064, 0.021411171145436746, 0.09768344987664493, 0.023826881942729798, 0.05034395057948367, 0.06011532927532831, 0.04534065332864562, 0.03060073287586772, 0.0394829995028915, 0.017818806753043207, 0.02078206357245724, 0.028969442486883174, 0.022509296897858865, 0.027421837627527215, 0.06193734299872191, 0.02982401165119823, 0.054420921125359116, 0.05206607792886996, 0.02873389726324428, 0.026336597473991495, 0.023243797101801442, 0.026499952317305633, 0.02866826842599098, 0.0187576245216112, 0.00658545506960382, 0.04237091349017236, 0.06227331085791511, 0.023744307240591418, 0.017396791898194822, 0.04408970452664841, 0.015927943750284612, 0.021365002856679985, 0.02910389283281421, 0.012257146318593334, 0.09490554611529074, 0.010757491860027996, 0.032545464308632, 0.061967450254146135, 0.014892987692878853, 0.03299119724561611, 0.007465798304521389, 0.014993606638463755, 0.028798292698939482, 0.04534806139887341, 0.08382027683359, 0.03520676565747108, 0.030474376248856707, 0.0639581029123116, 0.014320944094159191, 0.030410949914385716, 0.03033327625974292, 0.015349686220889131, 0.03327988598856234, 0.011295632237658627, 0.04592048995677502, 0.029411829534857988, 0.021470851309958006, 0.03719294053171912, 0.03784739412367344, 0.010748096749246603, 0.030993377834919, 0.050319240413486004, 0.08080074894091777, 0.024079756075215918, 0.014978266685389945, 0.023241966151662415, 0.03606724710534177, 0.03860004486576204, 0.06927766807136998, 0.05821353132506052, 0.031000544587450645, 0.05029837983930784, 0.05177937718408723, 0.042890252154921336, 0.06379924308989318, 0.026104945892227754, 0.034350218071091565, 0.007566113687766296, 0.020366539397547324, 0.048018509837528395, 0.027500304183171644, 0.0356678931312936, 0.03430197368406, 0.0349240830438512, 0.10888559353207389, 0.043286576251228975, 0.002300620450818491, 0.019056565436204115, 0.025074092235656518, 0.04152882581336364, 0.040560923516750336, 0.04767365918885316, 0.033620262683759776, 0.0391747372134799, 0.040650563464770396, 0.0042716200808964435, 0.02588273059847134, 0.012085355889622965, 0.02599308364874413, 0.05251114053892032, 0.009407152725954451, 0.03392381353243705, 0.03071584141693048, 0.05645290422703951, 0.042326430594849015, 0.058831362083794615, 0.08113099412331659, 0.029121480296335878, 0.0074463717511764945, 0.018992675618538936, 0.039222441508524844, 0.031640187784608816, 0.05357134876953018, 0.04814648865571907, 0.08781288960768331, 0.026421997125350663, 0.08006315948742052, 0.028729683779660734, 0.010672083590179684, 0.05824433572049584, 0.012365210681192338, 0.0308981282080734, 0.03355496900997335, 0.034953232689370076, 0.033282965662017945, 0.029170990643662312, 0.018370194706104456, 0.0064027268202945355, 0.031279147782873724, 0.022079973564212842, 0.036805127672250235, 0.09787782170479337, 0.0034562755759144506, 0.09416442499646256, 0.006033162175182013, 0.05177799439538391, 0.031656794655587406, 0.009068805206146453, 0.03951292672765352, 0.04563343298110751, 0.03195575855281805, 0.042005937711726275, 0.03984614050075893, 0.10609628272152717, 0.07596857274972624, 0.05943037772310838, 0.042918229685916055, 0.02398041553885466, 0.055528488911447994, 0.023309772593840476, 0.04937926202171272, 0.08509754458622587, 0.04459210881783117, 0.09249804586532617, 0.010376604435394609, 0.041536210900953704, 0.04620162507278785, 0.02816169661650014, 0.02655384277233914, 0.030033728220470013, 0.06972536985431949, 0.04628543509170414, 0.020226274444271, 0.051844375914022814, 0.032593678052146594, 0.01123373329098667, 0.07673795485208112, 0.03733746301863463, 0.029432178745346687, 0.06040914314648798, 0.02297758729377341, 0.059033850613500805, 0.056657656546561956, 0.049932143846226316, 0.012644395145827965, 0.04073047026571247, 0.02541727664309644, 0.023608393666725007, 0.04326984872140231, 0.03338386710252493, 0.053768945827839844, 0.05987062547055464, 0.05620380307758047, 0.047797217679720734, 0.07284229816568476, 0.05726861549661525, 0.026020291261374954, 0.04188163994601177, 0.056344839864440506, 0.04112517408606026, 0.013598202382244412, 0.011253156492696896, 0.03420919660599001, 0.016794911090044246, 0.0675212889308891, 0.03291428201801835, 0.029377121921448462, 0.03418883781940226, 0.055157939843352766, 0.017050539308618155, 0.021989021690622456, 0.004490464587786025, 0.06855396779193994, 0.041476731834512566, 0.0226368218089544, 0.03159642692715411, 0.020144835467480367, 0.053891630978473735, 0.030849657825104175, 0.01792263656464075, 0.009611713523495822, 0.09176676897632499, 0.015297461049481025, 0.04272736654046082, 0.0781144463126698, 0.02068069673353626, 0.0037774387859709326, 0.02385676894787579, 0.04782214618077682, 0.03531453890665885, 0.01207760212221934, 0.03417949537716566, 0.037442478351294994, 0.07933183663314389, 0.01057418329911607, 0.052294667074156385, 0.02731898840847275, 0.03509335783160022, 0.060774888843297965, 0.037304804690422556, 0.05180532075164299, 0.018023601207401485, 0.07174625617241667, 0.016892755839733348, 0.031112642402970986, 0.013223390992460473, 0.03141239537076364, 0.04141076400335278, 0.039508023764938116, 0.07550263807417885, 0.04178320147818135, 0.05304488931752501, 0.02167165253101097, 0.07253204787810964, 0.011423948134535985, 0.014099215266234694, 0.06900376099492274, 0.024870347321754502, 0.07976397917035126, 0.08917811957578506, 0.020125328953708374, 0.0399884183500563, 0.03029290534135315, 0.030137063905356393, 0.03940330720656822, 0.031355072841829354, 0.04420267951284205, 0.01101713150649542, 0.023949980780842806, 0.07473845770882984, 0.026301167822713335, 0.07866812103818502, 0.05936930902422436, 0.019075185203203754, 0.13032456409306298, 0.04887291620815954, 0.10568304723429103, 0.06495256547725971, 0.05766877386298391, 0.038938433562795964, 0.015531096798968653, 0.03073766343145361, 0.015263599963227828, 0.06770049987901604, 0.010877212250394928, 0.036331145243058284, 0.032519401997447975, 0.050191031768918044, 0.021683976970492833, 0.03883044580898939, 0.0432326743048766, 0.05528345185842726, 0.017553066173868797, 0.07313397082109606, 0.0537262172738631, 0.08447169671736418, 0.03595048381436256, 0.0381912105536509, 0.03593353411903785, 0.010679104786005714, 0.023749030172644604, 0.015430905905011442, 0.02947682251913413, 0.060584929681593375, 0.04727588718636863, 0.06567132448957813, 0.11122002431582059, 0.04060543705559066, 0.021070909363427953, 0.07265436913697951, 0.06877648569042645, 0.025027334059198058, 0.014188307461388891, 0.03274251744451542, 0.009084345299690481, 0.03259774597902452, 0.0580216875870622, 0.04951086826622487, 0.043983294913965854, 0.046600841151009646, 0.04139709316434399, 0.010474208824997468, 0.02060759662380142, 0.01102771788399907, 0.026734651013788198, 0.015195845231984653, 0.006410531819828096, 0.0273681789140908, 0.02750731005723919, 0.02223753678281942, 0.04079972844450705, 0.029247425151087587, 0.05552318375257235, 0.03866369145051126, 0.08547710284831063, 0.06422082127462472, 0.04008328684815957, 0.039529761509789575, 0.0731435699027873, 0.045482325968482805, 0.057858595128862135, 0.03856906810054376, 0.0628922141397432, 0.022212941530010393, 0.02397141017530474, 0.03152199957009045, 0.16283707512963205, 0.18117486048609982, 0.12717478593150455, 0.14018966215512446, 0.10273424457878837, 0.12836432129505182, 0.2030967728745553, 0.13311359911195694, 0.13339533560699032, 0.14365043370954453, 0.15444882604623997, 0.22582532988200266, 0.15353499040488275, 0.12987359877555602, 0.24014965721195747, 0.21604690700769427, 0.13530361466109753, 0.13483099969885043, 0.19339970853780547, 0.11618710092959866, 0.08639908966518219, 0.16851646795628533, 0.12288048007195035, 0.19148261947256906, 0.14070030572193284, 0.10821387231830629, 0.10633183177560569, 0.08378554240710313, 0.16468573722147173, 0.20523909178953018, 0.1166143864693661, 0.1281537773508218, 0.1418765571208731, 0.16220335187690874, 0.15750533300301722, 0.10639210757348808, 0.18836378360227232, 0.16560044620306263, 0.09925575341067969, 0.12814658378521282, 0.08309014907647526, 0.11542059931783907, 0.24735552619301507, 0.1186910593101094, 0.09882509708404542, 0.16427785668882633, 0.08391033046908918, 0.1206123312154124, 0.2170056354014143, 0.0886285740641817, 0.20127221190881348, 0.13375357364214238, 0.14264714964214834, 0.22836287355711385, 0.1261899645830835, 0.05186889072759979, 0.08641341550936622, 0.1086822814578491, 0.12668153256057732, 0.22129479315011735, 0.11009810387247032, 0.1584970184992398, 0.10230951777268803, 0.21885347011829578, 0.20993559380933163, 0.20811069576490313, 0.11092697270214559, 0.1693700890867941, 0.09687438441981232, 0.11037600226700307, 0.2917305716583806, 0.116735604561625, 0.2461957916497223, 0.08328774613478492, 0.09919689487545721, 0.12971717894317644, 0.10242902748887578, 0.13331866552752833, 0.22971989106266733, 0.13654280784389666, 0.1566043829605464, 0.14929054154744073, 0.09313409802533927, 0.17424815394465, 0.09594875868530044, 0.14410526011018984, 0.18009129040423902, 0.1878629766044117, 0.13906682240626506, 0.254964541283346, 0.16576823478023853, 0.09435993063473895, 0.08130335624540046, 0.10356253884252041, 0.10648822862534754, 0.12171162142147943, 0.12177156014067513, 0.14214661843594045, 0.09148399060171458, 0.19206334476269063, 0.2399056735298326, 0.1339619035922712, 0.09092516010446895, 0.16646146774291995, 0.25567612971269316, 0.14680683853164797, 0.15349464821479014, 0.1390587938048186, 0.17399056454098996, 0.2020027533534073, 0.07665203043049382, 0.07356655768929951, 0.12701247488298725, 0.16742693771037365, 0.12437972180064648, 0.12589616986412194, 0.06651872498614174, 0.14195293608692386, 0.1528700260866073, 0.10692070058036236, 0.18377811918335576, 0.210780052528266, 0.16801356187751218, 0.1215863354023426, 0.11082466165985792, 0.13821186828276805, 0.14326720588630246, 0.10912090509889588, 0.10691067248943353, 0.13976790010929108, 0.12054411108575522, 0.0963310901856711, 0.143481174243554, 0.15995618616861684, 0.10764417103341511, 0.14443712939898815, 0.31636707064124847, 0.1468859141271922, 0.13276936516406077, 0.16965689708388623, 0.1269285116464861, 0.06256665358500135, 0.10281456123676994, 0.0981194381752322, 0.08834580335045054, 0.15225095043499626, 0.20662825434438645, 0.1554284073532589, 0.11005408446034116, 0.24988793707903356, 0.12810867009384017, 0.13734695501625538, 0.14649289570027782, 0.10977329025345464, 0.11744776755691537, 0.1025764687707828, 0.1125859437630542, 0.12150359024564106, 0.10653955651627434, 0.18004210755950023, 0.16032649774945554, 0.18653902345367018, 0.1608397153716895, 0.13596860962288995, 0.17067973171511006, 0.09239689161580417, 0.15053249264676727, 0.12808815425922795, 0.24417479041843648, 0.22491330220814676, 0.11515803034267119, 0.15901078770477928, 0.09633233890898767, 0.07347034470688912, 0.10522441337666205, 0.11022220245532452, 0.331190534897389], [0.0869126367052236, 0.009347177617582343, 0.06632720300507161, 0.022545228336727428, 0.08443877791925784, 0.03454667365839405, 0.05532795007550909, 0.00923261491416563, 0.027017913939010714, 0.09631071224688523, 0.06230970769519768, 0.0841185148625124, 0.01118157898271156, 0.03738461573037409, 0.015349882530919729, 0.01761974455157836, 0.05024040996607754, 0.04435833708773698, 0.01964192172782796, 0.04943757280406933, 0.000646794927184425, 0.011054020555269335, 0.05391266009199524, 0.023379501916708487, 0.025858958890180916, 0.006681735084707579, 0.03597473815804528, 0.10644764128711917, 0.05538765513788789, 0.05680617418200259, 0.006241542399830876, 0.0024456449647268824, 0.007798779378419803, 0.05517716098937297, 0.111914582610611, 0.0558033919021968, 0.014190386432493407, 0.043375775698692574, 0.0651184541563834, 0.047292415533334985, 0.02037724164584952, 0.04689409577798459, 0.01703586297920875, 0.054776022030461224, 0.028271408068136345, 0.0328830064785096, 0.03600455430005828, 0.014251719431711302, 0.018511449828022913, 0.021091473078535452, 0.01853668093380909, 0.0027037634478596553, 0.07359136361628771, 0.004610356390326014, 0.07117519891189952, 0.016387965184666457, 0.058011889322510654, 0.007235329849795709, 0.026788282914147265, 0.1047981084294377, 0.004402702033985406, 0.03763146841177537, 0.044632539108035066, 0.045859199092392965, 0.09240036199410116, 0.05654472752564377, 0.05682970457259686, 0.05795948124761063, 0.02508620025529977, 0.08765743504608832, 0.05162438227524681, 0.03340499197703696, 0.03241455137369133, 0.013256800086838345, 0.10174968370026159, 0.026093169205611753, 0.03175557403254413, 0.02759059722114715, 0.045074054730996016, 0.029763241726604682, 0.021495590204252832, 0.017811101823744756, 0.020113140494833072, 0.021883299641851938, 0.06225796228635216, 0.03869893532546778, 0.04714418901130558, 0.015037175016327491, 0.04185977579665281, 0.026074043820582093, 0.0778309554762898, 0.05101890468429174, 0.016523196940280257, 0.038748187118119774, 0.05866411742904495, 0.011923387665451776, 0.09985545469868569, 0.07155871784855282, 0.00876579157662608, 0.04227739330681582, 0.03358049889005, 0.05904074157437971, 0.058347010654547525, 0.03050806113488732, 0.0440644312860264, 0.09127397525815234, 0.023780541284190073, 0.07933360629624898, 0.01315516415953396, 0.04194865731762783, 0.012003760822417756, 0.042703146670734694, 0.015631198635204666, 0.10878909709713153, 0.014581690737677198, 0.056066822726279504, 0.03697702631113991, 0.0415916373622754, 0.11907385812411386, 0.01102366623648953, 0.06518598480690872, 0.0028079696001500013, 0.03574443297580846, 0.0008166425452086955, 0.04010266887264387, 0.025052011666458943, 0.14372475955995823, 0.03303171946637092, 0.00968561802555116, 0.02701243641035211, 0.039514972182411345, 0.056432809740785635, 0.040811763685797496, 0.06542239187946243, 0.10128979345843678, 0.015857883094389354, 0.014135351633623004, 0.02878434989871758, 0.060388703920668176, 0.09140256311624281, 0.03818508568069628, 0.03185619010529932, 0.014976809203114002, 0.03905248873296284, 0.01467738948356841, 0.06950223142461431, 0.036512210123961976, 0.03220086646897178, 0.036434946326358665, 0.02169076833994158, 0.02819412894877455, 0.03012836497697619, 0.04513957057028048, 0.09541471113240528, 0.030785086189186385, 0.028441803259474617, 0.06634063252638425, 0.030434520524596016, 0.07694721176859833, 0.034884740598499775, 0.04740628684240003, 0.059434120062618494, 0.022372153752873984, 0.03779306699852309, 0.03521401284923477, 0.012052357609894489, 0.03742283968735607, 0.06906618949987235, 0.004912560839476365, 0.06909428194405572, 0.033113315491186034, 0.018271549394534483, 0.041464233110027934, 0.04903567924855217, 0.012248124675675025, 0.028264375380991448, 0.0239390448757237, 0.02450762958746524, 0.03861310666487102, 0.016766642445638295, 0.04004178403486167, 0.0377629290995819, 0.10393195410048771, 0.0870961377457265, 0.0275174415700378, 0.11304289222724977, 0.0347061846555481, 0.035508263390511274, 0.026546691341565985, 0.002649024789852481, 0.05636257096944798, 0.029271325179105325, 0.03593125883790274, 0.04222775847020169, 0.021205133713421323, 0.024717395952452096, 0.028878837268078522, 0.033351262400467555, 0.020315669244155288, 0.050899264733156854, 0.03219048597759778, 0.040195254428732785, 0.0071429257607838565, 0.07900237286042783, 0.025159041810360168, 0.03455204776518288, 0.01899086765103763, 0.06745428688103153, 0.054451185428807815, 0.06532946541424721, 0.03194131204978593, 0.05036111860986679, 0.07053058188889297, 0.03550861196051683, 0.05901906511656219, 0.04861883165675306, 0.025629297221800493, 0.023564090802063866, 0.02957951277494431, 0.011973799123699147, 0.03457197371209341, 0.05070038830801364, 0.0036562920356499815, 0.025816423773405053, 0.038205892628719734, 0.016077063722355713, 0.025780917513334466, 0.05867676171023519, 0.02379072642314338, 0.0626327210075913, 0.04968601511791349, 0.03202824196177385, 0.06604437866518575, 0.015638829828540406, 0.03644552217015336, 0.031036916526875673, 0.03455477886863294, 0.057854105853625847, 0.02162010438980595, 0.035799453410530285, 0.06289745035070567, 0.08291461535038487, 0.010139427444476996, 0.026121081619132912, 0.004707980410931933, 0.0627407662179922, 0.06728366377853578, 0.033651890623713696, 0.01347525676171626, 0.03679595376935698, 0.10719758007795581, 0.0069580639566054515, 0.013454196047067884, 0.03821358415147951, 0.02452555412967359, 0.02753452150030963, 0.03366252775454233, 0.02566925062227153, 0.002350511448082304, 0.05002553379463573, 0.02175399932199188, 0.030897783468507474, 0.049240642242253795, 0.041493191233565735, 0.08137955135034938, 0.023676188617584207, 0.0047631966768794005, 0.02398372695390736, 0.08591825457950754, 0.083944589921063, 0.09141155698847386, 0.03177115434570418, 0.0383455389659972, 0.027101798651499615, 0.03849535895090911, 0.008058795844384981, 0.04957815376861442, 0.05129951886051605, 0.051052198865480965, 0.021197246838240855, 0.03629226245046143, 0.06089187429977521, 0.04297348377745479, 0.011401382057116398, 0.020883574052864028, 0.025272576040738536, 0.039570923413961165, 0.03066502872013277, 0.047755155622238116, 0.0448003851418053, 0.025689276160612225, 0.07721903508589154, 0.09336056893751507, 0.08306420933935912, 0.022806113833681713, 0.017521352049023393, 0.019679601762383696, 0.06258066916357606, 0.03272204374473903, 0.013003970962017776, 0.0411743454394802, 0.020352939421671535, 0.0203416223878101, 0.0408571888692677, 0.05235640993041377, 0.0132054626198125, 0.050074797078606584, 0.010567308617605558, 0.07140340884366343, 0.005640175349394521, 0.056387085783024954, 0.00515727469915404, 0.028014774359161818, 0.038043240671076124, 0.03445835521204337, 0.06617972341876838, 0.048030330574200045, 0.02453776748640643, 0.048135905151045134, 0.027715052034886136, 0.030882046107322942, 0.02081270134376903, 0.04597401268960488, 0.0902945931339937, 0.019291580143955447, 0.048980563052839814, 0.03113964125664244, 0.05903091649675082, 0.02486083059451513, 0.07230400648568908, 0.021776166076080936, 0.00794088868837383, 0.0066277067338476985, 0.058015087739594524, 0.029233629822791107, 0.0384786237602032, 0.02973198533929404, 0.04050310303066527, 0.021328734339124734, 0.0260217315066726, 0.03426384165762894, 0.0690272339289227, 0.0836682543458958, 0.011568578831370802, 0.0903609210264779, 0.09475582189136937, 0.028645257059965405, 0.03889528366046087, 0.02752124519658185, 0.01658267026106196, 0.08588962587377719, 0.02322983514938143, 0.1546698270906364, 0.12805692851543427, 0.1324277665586241, 0.10657485018694594, 0.1757414125266575, 0.125119655483192, 0.23617073442907105, 0.08637262898827754, 0.12477036535499558, 0.19705178756867686, 0.1810621076654042, 0.1485240552574396, 0.12515765344423632, 0.10067401198490013, 0.08964664362851651, 0.07163990018588882, 0.2395303670557276, 0.21337217230710293, 0.09551315343067532, 0.12633002077740046, 0.16042573677916683, 0.09489754815736125, 0.1170195627116388, 0.13481169428315856, 0.08974142402650849, 0.1170214779314495, 0.18395847160248988, 0.14395588828671363, 0.12111501512868751, 0.14322900874239786, 0.10101477555449932, 0.1252695405855775, 0.16075593599629018, 0.18247302711731006, 0.2332033234978876, 0.1671772083688167, 0.15588170157805567, 0.17106371030451792, 0.1915113018044541, 0.14298698624535916, 0.13367377792394933, 0.13391699551814987, 0.1112043654786483, 0.14306505060484334, 0.17634292944304406, 0.13382472788854954, 0.13354627024983207, 0.08629819588555444, 0.1478006077870246, 0.13878612779080868, 0.18788571409400434, 0.07157639149696597, 0.14042716473340988, 0.17335734690629667, 0.16822909305412925, 0.11583024951358957, 0.1639228055794393, 0.19420704263592922, 0.10607180621234641, 0.16942468051227833, 0.1650140365405429, 0.09964761504482839, 0.13132230168388737, 0.1180281634292295, 0.15520159936239644, 0.1694354670302522, 0.20030390741603993, 0.07748715819851046, 0.0987255669409229, 0.14276497396490267, 0.09446024984842348, 0.15427872388353273, 0.1410847439640953, 0.08369882891495382, 0.2573840001658086, 0.09526504819551784, 0.1604884947019239, 0.1236536313268927, 0.16635518070430527, 0.1005730492573592, 0.09305603366585509, 0.13439586175785911, 0.16511097730648133, 0.1431760107797961, 0.12274007147718823, 0.13101025875056946, 0.14049925360708468, 0.12060023468708801, 0.2331805400430195, 0.12825534528782292, 0.07428817420957551, 0.11565394969957492, 0.15548238590840371, 0.12456208903102145, 0.1976463024414355, 0.133872700314368, 0.14255558681343833, 0.09874619768872377, 0.06046649631893924, 0.13488099459678898, 0.1019736878093212, 0.15025450998256284, 0.16143593095964, 0.09755625629857664, 0.16008832101379672, 0.20451225821048985, 0.10123378477029263, 0.14195014752687948, 0.08802984570783955, 0.14387529583707934, 0.11655103865890734, 0.12809806743696814, 0.1089210327594511, 0.172577116998934, 0.06749427667067898, 0.20459154831065288, 0.18333365029144674, 0.09352266548141357, 0.1453229109005582, 0.0738486159412611, 0.21101816797689085, 0.25547363735254736, 0.159633954265906, 0.14305866143155482, 0.1692192004092278, 0.1012347270584395, 0.22889519741217937, 0.15652921441341602, 0.11749615367021292, 0.07764488804124056, 0.11720798203661559, 0.12964740365503297, 0.14731579670502296, 0.1745359731778022, 0.17078203509651846, 0.17425097314821136, 0.13016345580258679, 0.14917452519218768, 0.12887121869191048, 0.17046489001762483, 0.1185263887107853, 0.1158028005832626, 0.12825261035393323, 0.09248972615046848, 0.09472207571830481, 0.1104126595741799, 0.23268603028789644, 0.18144035591713845, 0.15752119102304982, 0.1319972864322124, 0.1014011366773517, 0.07793448459837707, 0.1011314967106427, 0.20243065942439342, 0.09607307943365267, 0.12351494642996019, 0.11095350998784266, 0.10891871917391978, 0.13907172536898044, 0.1564650315671198, 0.18426012638355457, 0.156527100010745, 0.10480645878781235, 0.17545920105711107, 0.11627640379893205, 0.14623196615326792, 0.13525887512631957, 0.15321704859454788, 0.1240960700858024, 0.2298181801433525, 0.13591199572528564, 0.08772836712699744, 0.09985861098093372, 0.0747368948894643, 0.1825820873942106, 0.17104837322427383], [0.04404535186627219, 0.07063060998916626, 0.07335661129365045, 0.0914987760986532, 0.06114460287555572, 0.0767804037839655, 0.027533979493103204, 0.02158970027531107, 0.01762838219292462, 0.025734923509580475, 0.03541059101060514, 0.03324912755840248, 0.023753552006617672, 0.05367484341766085, 0.02394616374776008, 0.036422838306715416, 0.015729523147456348, 0.038558718252686724, 0.04273467118881884, 0.040991384490963914, 0.030132055605551412, 0.03930655796261084, 0.014884727349835298, 0.06282132036323029, 0.07323348564246009, 0.06372544584014724, 0.0371534908340583, 0.04942059629566727, 0.06130707863297674, 0.010052513811857471, 0.048182651836184726, 0.0404536405638341, 0.06478638568472478, 0.0809961396660055, 0.04105828694939133, 0.04494724419688986, 0.06773835228335473, 0.04285277896410516, 0.060318250644711725, 0.05004536015011611, 0.01421962034768395, 0.11120913054553733, 0.02769428147603908, 0.030600169801243374, 0.02297971893342272, 0.043130125775332415, 0.03679069457575679, 0.014340123105343553, 0.014974279197744064, 0.038963994086389585, 0.06593173309679955, 0.024430352383323257, 0.08140009016759935, 0.058364983077251145, 0.016957315984332276, 0.04160972852860728, 0.05417157099732468, 0.02503610385071126, 0.016821998043826992, 0.016129952517428225, 0.044119436398989735, 0.01301164045974973, 0.04609329257941535, 0.0646165439919118, 0.11335224619195347, 0.06023699169858329, 0.042398484994567213, 0.015083198705988546, 0.0421600362976953, 0.03752670971856963, 0.041089734858683044, 0.02824932175327934, 0.039114419280761675, 0.06451689893560064, 0.03678194202122189, 0.050099645140430624, 0.0328662904400018, 0.04838330175487265, 0.03499652814841078, 0.07750383593262204, 0.056515562558366414, 0.053222319111227996, 0.03197910699753031, 0.02172520973779742, 0.07423909095626685, 0.04272747379277022, 0.03348486430402245, 0.03425493588550918, 0.04309580886676427, 0.06389511899361688, 0.08176637978683557, 0.0376623111116069, 0.017393838629246722, 0.012048748378161223, 0.035038904301942356, 0.022696590073586955, 0.08126227861090053, 0.026534426273898255, 0.04583814699623374, 0.0353353075502861, 0.053566893968250484, 0.04659656638039216, 0.016745360523101785, 0.04296945415497307, 0.029742316034952962, 0.03879990954432757, 0.011133672631976586, 0.03987316425228792, 0.019979500286881963, 0.023154835141594374, 0.027152431317635124, 0.032139487504478426, 0.03030459584307767, 0.035368157400479244, 0.038154423011526946, 0.021934432180358038, 0.05286649042259782, 0.07575144044934742, 0.02633562071188804, 0.09112362284213306, 0.010658203034601625, 0.1432296982215297, 0.07573753595352173, 0.043939758137228994, 0.010068211911035883, 0.06437046122887442, 0.04359475044052928, 0.016122871949788065, 0.01615400576303082, 0.023516589520318855, 0.0516514060267758, 0.03753064741050044, 0.05151324206963182, 0.06631411056244566, 0.028466051857497905, 0.10065531177866845, 0.06597091083324726, 0.018244554371302648, 0.04149034138648741, 0.008040324506920674, 0.03483314457679949, 0.050099051422289306, 0.0815848705749358, 0.02310945400817981, 0.071970030455099, 0.06592658498594839, 0.07223577869515266, 0.05304485484356842, 0.022214176846788298, 0.0620885189592598, 0.039888463028135805, 0.02253340185439635, 0.06935907257420403, 0.04040187217235085, 0.028479818457497225, 0.044288818439048146, 0.04083113421896293, 0.07604037050998981, 0.03187455514806413, 0.032564559050144694, 0.03722289456955848, 0.06251230730765289, 0.078133920267705, 0.047529592524252595, 0.05520454097178675, 0.08162953350092135, 0.019522073017733715, 0.04937881769071664, 0.036148586490702246, 0.042632264385540644, 0.02483463613316417, 0.049713912209676164, 0.04746913286526838, 0.0421592319053748, 0.052052299837551774, 0.0661967458924459, 0.07686799827722773, 0.032691488327879104, 0.017594884998435457, 0.05024660761738497, 0.05143417030452721, 0.04094783622290819, 0.02895670819036182, 0.045534523369203654, 0.021591577190725554, 0.021024641483241034, 0.029397731601831414, 0.024504099837354115, 0.025879032309016874, 0.037662946964584054, 0.03287217782569989, 0.06368998746057192, 0.0269427607136388, 0.007035208531775542, 0.057634901285411856, 0.013640249117968545, 0.058062631156175375, 0.10439291686540651, 0.03712047627496143, 0.01796857694224004, 0.043440923815773386, 0.020236310196079074, 0.006456669465067887, 0.03897781814298323, 0.023107805003922795, 0.04171318870278136, 0.07195120767479943, 0.06763075523438954, 0.02166938874119472, 0.08877429164825909, 0.04163646499716467, 0.028515816929059166, 0.031227025075725494, 0.05734316351252699, 0.05698936878733578, 0.05418890373661153, 0.04264622250752103, 0.04824755097469015, 0.05280503484931204, 0.02590931001900425, 0.04173321424112205, 0.04117372490826153, 0.031446166441685734, 0.04473650490023917, 0.03761300952323983, 0.019274504044123234, 0.030478273721171484, 0.045595017502144466, 0.06648549209198644, 0.08152200539986934, 0.011736177801785451, 0.06413284373740036, 0.02513178631723408, 0.061011537233547825, 0.05351000810943304, 0.03182448555655297, 0.04255207796250621, 0.006411819805150792, 0.02695975445901915, 0.03840210689832607, 0.04728989893450372, 0.058273152117767645, 0.029250077730525407, 0.029516222421079878, 0.03895637151154299, 0.02839565412291596, 0.01637448203719912, 0.011631763848145644, 0.06553070905107646, 0.04012880779262032, 0.033277553250832904, 0.04495033919210396, 0.01618977632343529, 0.030257408657381614, 0.04067808900388979, 0.015514460242082997, 0.014571524750921997, 0.02742151778581883, 0.026171051619213917, 0.05167117109522224, 0.041429801288271145, 0.03669808220659052, 0.01796483077229031, 0.0437906046488112, 0.04433931129413747, 0.03703324567346323, 0.024999456119633494, 0.07511156551059216, 0.01036509683716201, 0.06721818624364753, 0.017228166369961637, 0.012424511632191078, 0.057472214853811654, 0.046427475453744975, 0.03161781801721983, 0.08439622173506407, 0.06242762011806331, 0.050340644910090396, 0.01643570969932743, 0.08684483026304553, 0.05265658616178459, 0.02135786674766531, 0.028275313201330365, 0.03541232619975363, 0.039877764610273224, 0.019938759731068727, 0.05611720449861981, 0.027229262275561213, 0.040503953388261224, 0.048538821433941205, 0.07137311006625814, 0.027675550626290422, 0.02750340875448479, 0.055042034570848754, 0.05914215629379596, 0.034556751545037956, 0.05529786197228297, 0.0658682627122729, 0.02024602419095895, 0.015125361312511227, 0.05688427684588298, 0.056876937723568374, 0.03277076693672327, 0.026391225288652127, 0.029292815860601205, 0.020796307062189427, 0.02727175525750124, 0.03878395193286481, 0.028924461634409045, 0.045236526657977415, 0.0223563531894357, 0.06568840058941035, 0.022422407205486973, 0.012573770457698454, 0.028000075047114686, 0.07939370589390879, 0.07001933311262439, 0.1032657104153787, 0.057173628254883715, 0.01953992478158926, 0.06641118156333124, 0.0530342368649379, 0.05221805828172834, 0.011356441424258295, 0.020013175596813523, 0.06111363377121668, 0.06504408234069425, 0.06616050993362743, 0.05847782399805804, 0.03796311553507563, 0.10802562153267284, 0.04106714292579601, 0.03842457242670559, 0.016434143049522273, 0.03200454494705604, 0.02753626626555718, 0.04010147760592161, 0.04938660880490657, 0.09576403190411868, 0.037838936512989384, 0.04592633520763728, 0.09243873533822837, 0.07685041655936549, 0.0473724372474657, 0.053204373501601725, 0.04856567281568724, 0.030891070623070966, 0.06011021563843374, 0.023117473033527215, 0.011492539816836437, 0.05776814695808196, 0.03070335609898452, 0.21318866360572078, 0.2006007511649401, 0.14436899353900265, 0.24170095461510846, 0.22221650417533614, 0.16982709117714437, 0.1892128082052354, 0.15051118008071376, 0.16288340812729252, 0.17154856735179502, 0.13482531532645226, 0.12233052087286789, 0.10751500860938143, 0.14658464239008967, 0.2096497510830241, 0.09080393435133081, 0.10729039929086163, 0.1685054362901757, 0.11554816827899027, 0.1472796220332384, 0.12208925680287423, 0.2481560421086127, 0.11097044819184851, 0.1267424825158331, 0.14494011208655375, 0.10072337869074076, 0.13477130612779048, 0.17636560564560277, 0.16255340809302946, 0.09953530655512888, 0.1870966894972709, 0.11969161610449515, 0.16075688594531629, 0.1851402694780019, 0.17223763279616836, 0.12296120275653179, 0.13174449273895833, 0.16226627833900914, 0.18029300135470208, 0.1369708977759846, 0.1114472842985584, 0.25897556315025977, 0.11263616082649078, 0.17254795969253586, 0.13696084670241804, 0.11911130450185269, 0.14938397363068598, 0.170549358872156, 0.1315522506352394, 0.1598637040343977, 0.15541342267345998, 0.12286207864000914, 0.20423481180783243, 0.11325987131004372, 0.11185786146069727, 0.13843962622265663, 0.16657599788759986, 0.11594697066973295, 0.16602000191567406, 0.07883143566188314, 0.08500927593559028, 0.07025439953131062, 0.1299571942898535, 0.10751962811956484, 0.17282482386837084, 0.1317793497395131, 0.16946840881099626, 0.13469296597665356, 0.11231600502205473, 0.1242518847087218, 0.0790769285372188, 0.1381766742035266, 0.17372531425808707, 0.16667011944997698, 0.13066816984886123, 0.13136313417025153, 0.11318166905473317, 0.12559692826001875, 0.18142308829532516, 0.1271477506886567, 0.12210666232051388, 0.10155086090127308, 0.17805873656705504, 0.0820654681733539, 0.19026165918236781, 0.19331353896808243, 0.12255572007908938, 0.08182700032428389, 0.13657751162686657, 0.17631401728478172, 0.12232818430469883, 0.19418026020209636, 0.09703173121858029, 0.11506570908691614, 0.07818758472680085, 0.10983823152679591, 0.12865605523749707, 0.19888571012885342, 0.19770020438778788, 0.10430516149368017, 0.16396941436875254, 0.14324561752859624, 0.11856720587539098, 0.09440011194636745, 0.2869561278531628, 0.08009458441407451, 0.11198997332323944, 0.16995286749255273, 0.12137170054859693, 0.10803057812154294, 0.12879609611005555, 0.26748980305367903, 0.14757546986783707, 0.13983992769593193, 0.10258660411402103, 0.13127650494777388, 0.13458269528083264, 0.14521795685493177, 0.10660202332562017, 0.1918570219629234, 0.12384374370618213, 0.17672349128030962, 0.23926545385151143, 0.088888852436456, 0.12978102471078598, 0.22484429300792758, 0.1431757196663849, 0.11727857703883802, 0.19396105180344275, 0.09046409774811999, 0.11152530269276713, 0.1532519362386196, 0.17512907844878015, 0.20144090446974003, 0.138966265705324, 0.17121190235259073, 0.1555567117588174, 0.09635267854337731, 0.15634890795955736, 0.11395064513048819, 0.15075695640858144, 0.13805000922612606, 0.1645800630531965, 0.09628155494048711, 0.2676109981633002, 0.15975597675048536, 0.143453503147729, 0.2439296729261837, 0.07534066410434824, 0.19247133254764542, 0.1904476653303831, 0.18312024883925918, 0.25157349905179394, 0.12256835286896076, 0.17985357332133478, 0.125073904712354, 0.19679330950302465, 0.15424901499382912, 0.10074263048027793, 0.08686220513716822, 0.14936684390469906, 0.18015539664174282, 0.13634541762932656, 0.14503035724403399, 0.12219365160431593, 0.15158390235756675, 0.19494146048541994, 0.11046021065163998, 0.13125344570125305, 0.17735577428773527, 0.07479931573353468, 0.15213715573472364, 0.11046761106098853, 0.13929735358443954, 0.17899589192482734, 0.1809659789526655], [0.049275150672803004, 0.07089141696210831, 0.013076876676941832, 0.059426589418322816, 0.025924968856176542, 0.031147775195178487, 0.03454645915377525, 0.08745945494381652, 0.024384494360175826, 0.03369647694090682, 0.031027667930409796, 0.04849884696605225, 0.016813119084784584, 0.052706634685877836, 0.06127055156074705, 0.08600553497672082, 0.0620704431146864, 0.05988964743371453, 0.03057079990544627, 0.027731298844540314, 0.016685668867261663, 0.07102860032670921, 0.03265168622977311, 0.023799886919497967, 0.03968168057561402, 0.08141875206943482, 0.02864812988968146, 0.019270279069220828, 0.019447090246924953, 0.060430271851439635, 0.014308030724585538, 0.059804672961153334, 0.08876803270991772, 0.04621492818959298, 0.01760844283947541, 0.05711677687002286, 0.04262163108515163, 0.1114068195343979, 0.002388497439002799, 0.044389294700757156, 0.07436976257351137, 0.06145141725879043, 0.03241725566406404, 0.04698950436807448, 0.02486271708602867, 0.014184139943080805, 0.06834949126407024, 0.02400196367694486, 0.02657213120631153, 0.016200771600368525, 0.0313869746582162, 0.04102555201238683, 0.00965600872727772, 0.03567368858644078, 0.05894372036920921, 0.0347111948705729, 0.01704847470166222, 0.061014061493258324, 0.04116096571388264, 0.0433213374907932, 0.0852960303065277, 0.04530012344701156, 0.01865471210030298, 0.028064822883255063, 0.036646152936643174, 0.027759408525701974, 0.012649803726573386, 0.02943921143249158, 0.03477672603161585, 0.0392095290965611, 0.021432818874957103, 0.04475066986595912, 0.03803839899539467, 0.032858579765043916, 0.045069642064552155, 0.02572135800766128, 0.03432248185779299, 0.019511974063671885, 0.02370996351894592, 0.06080346392287363, 0.04885173770749281, 0.05798244090270131, 0.0450855422194206, 0.010429355334640752, 0.07028936378417477, 0.0634862770206265, 0.03544969979913966, 0.026134250670551296, 0.04218573088667566, 0.008804365061223507, 0.06602960082912637, 0.02688638238807119, 0.02327522585889505, 0.009533914421955425, 0.016345859077128193, 0.04834679766528068, 0.03363679486116575, 0.01637760959115, 0.022152761493118543, 0.02776352050263555, 0.034208687157520366, 0.03544555143302968, 0.02572108987688778, 0.043515303292341774, 0.006001712350670489, 0.07256378690081258, 0.01871774198427316, 0.025880643008877675, 0.038883148827740265, 0.036765823531295025, 0.05205749391367839, 0.02967644971044314, 0.010106487578952746, 0.022412767904179714, 0.07052358750614428, 0.03749775542547146, 0.02714537756307231, 0.012085435371245108, 0.013074348586791707, 0.023858724387302518, 0.04561751367404096, 0.019890890727120063, 0.03850903745079714, 0.03788977410764464, 0.05554847614539247, 0.015104248886927964, 0.053526923330801154, 0.0755671120338863, 0.01949624627858641, 0.035830135231897715, 0.043860119467060414, 0.03314199016219185, 0.11631692985012648, 0.07137863356019221, 0.04234035041243319, 0.036566066105038895, 0.03426296831739526, 0.07512485713607843, 0.0040904805064201355, 0.12524156305458278, 0.06850885287407907, 0.0118279101274487, 0.03146165099385525, 0.12264213479694822, 0.015579198502124319, 0.0678128160295948, 0.02844442902583509, 0.010081976595815393, 0.021411494817584757, 0.03949686186388135, 0.033639219529446096, 0.006458152802811275, 0.01803954349710576, 0.0408108520411676, 0.02737723981901523, 0.10642578479863944, 0.02737737388440198, 0.01582476511342271, 0.03617977776053933, 0.04589792100652572, 0.13457724073481175, 0.027541931485757235, 0.0963517285943512, 0.02311891327882486, 0.04611569682076093, 0.035393744737150214, 0.036033366866890466, 0.0477132735954177, 0.03681856868488174, 0.0661746978819851, 0.060527346682764833, 0.05953455801993128, 0.05874786233048766, 0.11400465432914997, 0.037735415051781365, 0.01573115587234497, 0.08370602248056282, 0.02170759737641821, 0.03298594571289516, 0.09474662117539875, 0.046548030879949374, 0.028441793683375564, 0.06338232271974126, 0.025452876748937755, 0.03289981061712869, 0.02104342404392458, 0.015751260892307807, 0.02390470689973764, 0.019470691500652223, 0.05226432233147564, 0.06613042566084093, 0.020730019389321248, 0.03976486240243239, 0.019456327352071964, 0.03149992857699192, 0.08733215411343882, 0.02366422806986638, 0.04377450148064283, 0.04230444004098254, 0.04202323597705653, 0.07009915181345518, 0.04793621667270218, 0.015120742759937722, 0.01948917911748492, 0.041120006823010986, 0.021110021982402093, 0.06352927370537674, 0.0633402530013794, 0.053742546437969135, 0.06235540483988101, 0.03552340128789506, 0.010935402373903462, 0.023768684158342022, 0.035054907878680576, 0.044526451252280705, 0.009790005166113619, 0.022482811323096676, 0.035496082592515216, 0.007701137642030635, 0.08605857124371875, 0.023590396346163847, 0.03662675175996077, 0.013222627777365908, 0.03847495802948552, 0.05109390469207879, 0.04509399216922541, 0.019613679896499363, 0.02822952412609612, 0.09265343147900798, 0.0013954830196340599, 0.08487373199914733, 0.0743976864783514, 0.035561663549273245, 0.05337601167059714, 0.06091904743844944, 0.04946871044775171, 0.05773969445257418, 0.05228185808406242, 0.00769359311239133, 0.032659898692321394, 0.043923900117196386, 0.031592531370059136, 0.06191111597863417, 0.06322555814779575, 0.0355954097223378, 0.08089595834814733, 0.05876100073838907, 0.03849112631512746, 0.022795689292252067, 0.08344850202481593, 0.01203579766180126, 0.052255814925076506, 0.017686909395119837, 0.0654134209898691, 0.016278060295829372, 0.04677019254755109, 0.02709938547453813, 0.02702363278536547, 0.018916442209193786, 0.05109601909474981, 0.043116186805550134, 0.025015907857807416, 0.03228301407709237, 0.03719210166544203, 0.04471519999506493, 0.09534315852027747, 0.06557043837082964, 0.013091287748407454, 0.0270748783218404, 0.04965920204056367, 0.04905558221282498, 0.05024184255049594, 0.039490346286085345, 0.03910632939228127, 0.05078593351607842, 0.07660359069104157, 0.03846834669069898, 0.03463056028610276, 0.056233546441240664, 0.0733192338638248, 0.07734460455756034, 0.040264880329731016, 0.022910815070293123, 0.05041008311954718, 0.02024033598812117, 0.09006059923840147, 0.024502741946508328, 0.04131719402428116, 0.031437318126160296, 0.019243695818248297, 0.026334381564670516, 0.0787078503579382, 0.056232562018257964, 0.04397075022420576, 0.008675620155108553, 0.014025974387843764, 0.06341306582814263, 0.019490646175859917, 0.05445701918835121, 0.10833995506888437, 0.037903345355223265, 0.012560521924657928, 0.04634573770266387, 0.04236309556290508, 0.020465809070775588, 0.014299667917282112, 0.04930253065521679, 0.05064387400183947, 0.03293527665758326, 0.042490744963288314, 0.0447851361616725, 0.04167576913811988, 0.031917396700009704, 0.010188327794293723, 0.023757767405421026, 0.0539771723560989, 0.04211649569051881, 0.03248824903200711, 0.07071065085549509, 0.09857234169518757, 0.003946185691259621, 0.01948923465885943, 0.019234728759094592, 0.07472886628801785, 0.024210172968225616, 0.04547674501795442, 0.02367228923004962, 0.02899519070201824, 0.04200345558685161, 0.01594141636404299, 0.04868588350232571, 0.011012138528448921, 0.04947381259332742, 0.05989250111123247, 0.014958841568459908, 0.008904540633422234, 0.10047924945191031, 0.03743382155775063, 0.04741698526026261, 0.022866923977891286, 0.06687684810810512, 0.042380979885497404, 0.05613274076172421, 0.04360855151448519, 0.02897804565427284, 0.04285715715659242, 0.015522835498315193, 0.0471318090304492, 0.08007674222631801, 0.04403759905647847, 0.02013531490980137, 0.022768008620328, 0.15652504689510793, 0.21709502254041935, 0.13149071845316118, 0.17928824639849125, 0.15065410144386754, 0.22082291363227755, 0.1364393706523603, 0.13514457480801692, 0.12950193887997058, 0.18155969709398287, 0.10040922901563107, 0.12976755688507713, 0.13931158749807265, 0.14821625645122222, 0.20557545035356478, 0.11930989747446392, 0.15948320348416606, 0.14344833971511933, 0.13265029977886908, 0.10947434742364193, 0.04543141176503512, 0.1503194895603003, 0.11717924607857583, 0.10636793749947702, 0.16802159047895865, 0.14911938218339799, 0.17464075868408527, 0.16044957743537042, 0.10728197998457378, 0.12926900218571388, 0.13299264915047154, 0.128059885614822, 0.17378388934077757, 0.17205164196991152, 0.09293517563492061, 0.15266681360381265, 0.0960825712630345, 0.17731086621361394, 0.1776396251854397, 0.08201031750368495, 0.14566778836231078, 0.09584962690789854, 0.1186087508235247, 0.2723639608631211, 0.13541563203738582, 0.1295313106909875, 0.13815004498727862, 0.12457509720397573, 0.18147962558413708, 0.07336262508385605, 0.08679527203522383, 0.09397419004310524, 0.07306008930167845, 0.1017560039256369, 0.13893597458879794, 0.14395567378209484, 0.13389104045927525, 0.12836686470696043, 0.10222064391259225, 0.16274705979852908, 0.1376551675099519, 0.159853269916869, 0.12897292452473796, 0.1089926543194921, 0.12428812832841951, 0.11322743514732969, 0.16228895454156786, 0.19190062768757346, 0.11241154384709175, 0.125480099851566, 0.09689144519788605, 0.12589574085488436, 0.10402185451840201, 0.2005371045801909, 0.13099642320265695, 0.17058438441205412, 0.16528581389256064, 0.14741894278314807, 0.09885948677096637, 0.12773223747048648, 0.1297093342028318, 0.16120038956644075, 0.12641443600577693, 0.10548440829640436, 0.18978179702835699, 0.15395002619874093, 0.13755082633466492, 0.22408983429833768, 0.13664865055151526, 0.1797555140670269, 0.1535332284026569, 0.13287658682994305, 0.14120745592780654, 0.12206329408312037, 0.13601832872917577, 0.1900004844872221, 0.13337394643214442, 0.1148250349046242, 0.21589666184398437, 0.13774979469035903, 0.14661474964551388, 0.20605799381531056, 0.18788588263334768, 0.23300257781820916, 0.1440808065836468, 0.15064611880769654, 0.14162331909662293, 0.15805446482714147, 0.23431704680044807, 0.15793268749069783, 0.15331409661279571, 0.16677936358797937, 0.1192627524236037, 0.1195044378419557, 0.19944394307751812, 0.15919789701940554, 0.09937886374011155, 0.27792036593441044, 0.10025254105247798, 0.0629107189935542, 0.1353896923002697, 0.1026850157687741, 0.15841380602890448, 0.2091569880083684, 0.10649661728811842, 0.19947063358080006, 0.1333167962729931, 0.19329507624910724, 0.07641418311264246, 0.188760188137812, 0.1109412755636919, 0.1795679144561291, 0.16157512913548178, 0.16662967000757495, 0.19417423875101153, 0.09157919234806493, 0.09426851336273456, 0.13294253167846512, 0.07730800087653822, 0.2272877764076956, 0.12961780201763878, 0.1235909040476526, 0.1297460604579218, 0.22152794434899287, 0.11076519791517528, 0.13749560671708277, 0.11916394240313, 0.1555059354511961, 0.11134335681075051, 0.1018644972974735, 0.21643762717083578, 0.059753437000777454, 0.1518958993256092, 0.09927101388213136, 0.12643718115624883, 0.2096492148214771, 0.16367774937422047, 0.17751297552979764, 0.07399800308649579, 0.1726352171071114, 0.23825617897654736, 0.22613951786150857, 0.14999857532881922, 0.09658143239756746, 0.1979721809226659, 0.12633644059420596, 0.18407393637443745, 0.07766351929955906, 0.1578157211864187, 0.11379987136611056, 0.15178915263423998, 0.10581656103773464, 0.16141022104890118, 0.15903902570566825, 0.15146229356046648, 0.13740810415437146], [0.009654703504976728, 0.07680900184617889, 0.04199526610694105, 0.014646372498734104, 0.028388493116043752, 0.027666183286196286, 0.03395297849971441, 0.04009744798343989, 0.04125395729657143, 0.025837784219953804, 0.02914225085518293, 0.07586050838712724, 0.081714553938758, 0.030458795935696656, 0.07513231117158167, 0.04936246171353325, 0.041555991291158625, 0.06401632559455692, 0.07256112091483609, 0.04498300518119528, 0.07579198182230035, 0.048575405962765224, 0.04422491138440467, 0.0320511786342268, 0.03358914802271513, 0.0332193688729838, 0.014017723620899264, 0.09435158793724353, 0.022132527195818485, 0.02948216981284561, 0.04963520050589597, 0.05830235921988084, 0.05782091892474602, 0.0325012227310048, 0.055107722779916185, 0.03334517966234877, 0.02769894503627814, 0.045113830016024654, 0.020618881098926067, 0.038384241727931846, 0.05164303268576342, 0.024377461673030933, 0.051770751034059835, 0.08303736561849233, 0.0344089808453235, 0.014266451302495216, 0.06515431473211897, 0.037120801862329245, 0.01490979278910785, 0.04977182079587252, 0.006798686067228236, 0.013054292404934043, 0.015964583820483137, 0.03102032689287538, 0.03652346395556966, 0.020175170634062062, 0.015475470197176742, 0.05949480571754037, 0.05100818328379143, 0.007282675041126148, 0.053464567604204344, 0.04031877078476452, 0.03965754497555956, 0.03570904354414633, 0.030313323499755036, 0.04539641303821437, 0.03546229428461483, 0.08882154395142872, 0.05997151541974276, 0.09604289556943602, 0.043587254270190195, 0.019228391296740983, 0.13839477943556924, 0.08649071378092613, 0.03296402410694188, 0.06634848492760813, 0.05906999847220798, 0.037821515673591245, 0.12718808521787006, 0.05362584443402387, 0.04518760811357249, 0.030341122915307363, 0.06435179166615972, 0.03119014560305063, 0.0507183492393984, 0.04102129639396745, 0.03472700309489043, 0.061168826575721466, 0.037287705607952616, 0.005279974213936517, 0.027986419529864387, 0.04590836278493366, 0.09162226947204721, 0.03774727026240961, 0.05837720217964342, 0.06928187389407428, 0.05493252613251248, 0.013572875515467698, 0.07225408819654296, 0.04387567105192331, 0.012233839051107006, 0.013817101472898597, 0.03495610551908612, 0.0012800611007297714, 0.0059004216417369824, 0.030614011094815312, 0.041728694322368795, 0.05158091444642313, 0.03816976775265029, 0.08848645709334843, 0.043993736692373796, 0.02026626040347882, 0.0972993333914107, 0.06554269832709143, 0.025250556758574905, 0.03819707878715089, 0.012847737863569731, 0.023232007008646766, 0.04692885701754882, 0.01874176075591916, 0.03820208900217568, 0.024871793312711582, 0.06282103308025869, 0.08133778423671761, 0.04950217316828428, 0.0892471747412797, 0.03026138848414825, 0.021611185211147514, 0.0215505646736992, 0.11128009326996342, 0.02879077163074286, 0.03869698180126087, 0.05274246461809643, 0.03161235581031971, 0.04119086229512769, 0.0343467170492776, 0.03762698679741833, 0.023454425315703117, 0.015171701013441048, 0.031034254371338797, 0.04852181045158256, 0.030202173718040994, 0.021017398121916962, 0.014034266332014194, 0.0370467518035683, 0.039329735952759945, 0.08242816484022526, 0.015186510450627296, 0.026108895075477423, 0.03364694169572285, 0.04436166190932836, 0.014191901371363672, 0.08818988147522173, 0.06513678664041143, 0.026840616295474674, 0.029703427496696674, 0.015564297134387157, 0.029577300696062948, 0.05625542208191849, 0.03672466545756306, 0.0430284122816257, 0.029688327903709108, 0.02383333048783243, 0.02868096250289631, 0.03175628649431371, 0.02576301212332422, 0.04148689782126777, 0.013447855711884558, 0.04524224550433217, 0.001472199303773983, 0.05159073186317279, 0.08793452904830057, 0.05949886981397868, 0.026432251212217157, 0.03140203594680756, 0.04663307046998413, 0.04643928469909776, 0.05070017763383446, 0.024075184445527774, 0.029034680619295088, 0.009215168219300048, 0.04515888747729121, 0.03163407248775325, 0.020987932465129325, 0.00783360334143283, 0.016835140282168023, 0.01534873052620359, 0.02788746203746527, 0.0650180506730272, 0.04183126200411109, 0.032558924473461606, 0.0717516111270074, 0.04054554430167041, 0.1284736190592089, 0.06190641985965833, 0.056662823809611226, 0.06506249143351471, 0.043862283665446505, 0.017888281351676392, 0.01614345290187386, 0.029007471091444456, 0.049195469867798595, 0.025075534396173976, 0.0471504747627243, 0.013969624790573313, 0.04082135893704911, 0.06703093137231565, 0.05733083715782531, 0.014671156400694482, 0.04592973280758147, 0.023288563449656772, 0.008635706016643634, 0.13807737388678137, 0.06518200114970246, 0.04500401131207905, 0.041524056916034995, 0.04485567370730062, 0.021668436876948804, 0.052217770998756734, 0.025320238200947646, 0.030003908248017394, 0.012490908472588467, 0.033283850493570494, 0.07189952738342748, 0.08060840724576866, 0.013304122295531054, 0.01234123404438217, 0.03030948156881477, 0.03420536999680823, 0.06883830132503664, 0.02860583417538193, 0.028384951874613765, 0.02697029199841763, 0.03457164429428597, 0.05269493269283445, 0.004746923054147873, 0.048066191149935614, 0.02613808685583213, 0.024619089634788614, 0.02571634013175724, 0.0833419698380655, 0.01754166103989607, 0.06336865571117209, 0.04677251762440128, 0.02413329412980426, 0.039628847321916016, 0.08304297338209807, 0.0341142668208528, 0.13309478399253663, 0.013664386633242811, 0.03116725681109294, 0.058193961609034776, 0.07709761781077232, 0.02042659686037129, 0.08538895677174292, 0.04625756481301881, 0.0959747214050543, 0.02620686622967403, 0.003251472742469501, 0.026499657373454784, 0.03687639683184605, 0.011756092257377122, 0.04092913984711613, 0.023405801715149034, 0.020262698094630917, 0.03188673403084038, 0.009536316107598045, 0.07355328904645098, 0.08376865016837275, 0.045432319579225396, 0.028782281461322022, 0.07133983886770665, 0.006112683538137185, 0.04871636997127245, 0.050477537161280076, 0.0121194745729407, 0.029405522716021346, 0.03360536993451176, 0.028661940539736423, 0.030866676468342066, 0.13395847151837043, 0.05180405670656793, 0.015117817261676877, 0.027591428426544995, 0.018095772435528137, 0.08957332901416287, 0.038339414093042576, 0.02459832290638118, 0.04938020047941997, 0.15016176737844944, 0.05114738529007282, 0.022315612633622462, 0.03567871412322406, 0.04293426773661087, 0.06610237152105378, 0.023394432970352715, 0.0855401672062374, 0.05226525312830364, 0.044416536787344564, 0.07595686692624323, 0.045320141324473005, 0.05970747938619987, 0.03812136248715463, 0.06242994902535312, 0.07246067912708368, 0.04276849780111544, 0.024985532471609694, 0.05192689124434706, 0.008337537893244337, 0.04178143947595551, 0.03984338641467114, 0.03437709243547532, 0.02876708993778354, 0.04759917245997537, 0.04033077921297762, 0.026607978375508424, 0.03582359667146399, 0.039173898347202814, 0.03250829755298553, 0.014348161282889066, 0.07673449979554262, 0.027282534114595865, 0.05267132952388737, 0.03577755861765435, 0.015033710383689933, 0.034142910848341645, 0.08562413810361778, 0.028621598349643812, 0.03764248475612652, 0.03416819558028252, 0.02930886348739507, 0.02039501680091264, 0.04921669816418041, 0.05555912859797959, 0.06157582993769358, 0.005007384329914086, 0.08498712067282008, 0.03313946207204173, 0.06340395704272293, 0.031091864183244687, 0.023033107600865826, 0.03611203643583483, 0.007708541881818806, 0.024971865463040532, 0.023963274321548884, 0.034250166988180536, 0.05302078053054791, 0.04410538251601881, 0.0121485035596115, 0.030443797849359053, 0.06791534923738049, 0.024952650062679767, 0.1386702646531405, 0.15566895896148297, 0.1402341258982497, 0.08067061358522024, 0.12525690013482688, 0.09747760205139076, 0.19896342208789242, 0.24673223705782046, 0.12345908329852166, 0.07034728769212961, 0.08373575435290415, 0.15977336694636654, 0.20624335644946945, 0.22929990634081826, 0.12181830682581472, 0.14837338108449213, 0.2184275558759128, 0.18395036639225099, 0.14366022431321684, 0.16045710041878686, 0.22832029439028234, 0.17105753563584822, 0.10510333318022952, 0.13850253736299856, 0.14322582181663285, 0.17192128444871596, 0.1086519980022023, 0.16788131978002288, 0.08334576963416993, 0.1010096887306821, 0.16359407725113054, 0.11808127630501987, 0.14811516348873416, 0.13963388068781746, 0.2173283576003967, 0.20242848373468847, 0.21423103347901376, 0.11742770371417846, 0.13237259290631742, 0.11231818837263893, 0.10745659440515504, 0.10780529464564978, 0.15143359590682293, 0.1649937964975834, 0.15668592535920683, 0.1134625168877744, 0.1853871030072051, 0.18577871183233877, 0.15479485263987897, 0.175662643366283, 0.07216008154735451, 0.0736720939617484, 0.2781746458382376, 0.18276328251006144, 0.08097384650740894, 0.11463951905288043, 0.14162852849450805, 0.13788096426475432, 0.09854813331678029, 0.08569364526098774, 0.14573774751155608, 0.16539663617168704, 0.12903218908656028, 0.12979338936988385, 0.27307878218350873, 0.1264976178325953, 0.1584091788578418, 0.2965004495795696, 0.22888577453071074, 0.17166639167454936, 0.17253038563555287, 0.12530317184545342, 0.1873193146480668, 0.17174552855712755, 0.1334917247896233, 0.11195072663887856, 0.16014959272598067, 0.06921296428528524, 0.19277185351858217, 0.11882704757754842, 0.215236401305564, 0.23370224591945452, 0.1723608503779096, 0.1293819235457528, 0.14532787515030754, 0.17857593784649528, 0.0888355556995638, 0.14632074042193352, 0.17421087610625452, 0.16308758588087174, 0.1167250631917869, 0.12957404307540388, 0.18377476371824744, 0.20626209496009737, 0.13413785866671993, 0.14215815572008011, 0.1630118197851604, 0.15114805961568512, 0.17045945079336244, 0.12690917558727727, 0.10650114486775092, 0.12801514608004402, 0.12794459704309702, 0.09199960607915156, 0.22942981953101776, 0.1044833305622301, 0.15043967343386144, 0.1378583187057126, 0.11974391692708578, 0.2001949084261733, 0.2045758588299636, 0.10572148186545219, 0.17583456881825002, 0.33245988130088777, 0.15257917314527497, 0.053353163098255475, 0.11685101570741785, 0.15880608901141152, 0.17131906273143907, 0.10356833812810722, 0.15598978126241317, 0.13493360951542854, 0.2279028684021004, 0.17018753554551833, 0.13179496261140994, 0.1766633840217706, 0.17727469154182943, 0.17711813381362349, 0.10795099690796868, 0.18556598453752457, 0.10089142773781093, 0.11862431773014608, 0.17523113668205278, 0.13920784387136662, 0.12749767666983028, 0.12431406806553565, 0.12130090636351418, 0.11571897524258784, 0.1354215309144028, 0.16582961374473187, 0.1383162554233305, 0.14068118416734282, 0.18057083080132164, 0.09646132513279877, 0.2527186013157329, 0.11952835510695174, 0.3185484600403617, 0.1047727662409025, 0.12144736705287812, 0.08616730210281189, 0.15552732462604202, 0.11515832911696165, 0.2532006238376902, 0.1758099927176391, 0.08173086395066592, 0.11230322667547774, 0.1719531996716415, 0.13365416607308772, 0.14886881014512432, 0.1326206981414749, 0.21185708021925342, 0.11691114594859463, 0.125375191771215, 0.07923371609180205, 0.11006070346000696, 0.1382005301814887, 0.07995805222420924, 0.17125256629961152, 0.12118829143864494, 0.10319060315528225, 0.16180699330664453, 0.20037127718810113, 0.09409366145489678, 0.1939754848999362, 0.19701234936233492, 0.10931412013427866], [0.029457677981906363, 0.015991722485200775, 0.05308174580756215, 0.04576295546646561, 0.04632876119426182, 0.03180674870588607, 0.026658067119217692, 0.011517510452728358, 0.029963679055893616, 0.01844078587788728, 0.010770785400734074, 0.03426511336358325, 0.06143650535734431, 0.054725008235583385, 0.03883362507387515, 0.03638766337967208, 0.03860161534600681, 0.03345236302383485, 0.05708434836818807, 0.03349158289511839, 0.026557590857508685, 0.0008959813637756593, 0.07434597554346246, 0.04105013194343737, 0.03084879789140917, 0.021533230019192544, 0.019503771177222653, 0.035149569533044295, 0.02276999853371132, 0.05367123897397711, 0.11954403692676176, 0.043613937112592885, 0.031020254114522573, 0.03491099826210449, 0.012515760364852125, 0.029413484284774433, 0.060078714102987325, 0.09936394034734658, 0.035582773102026795, 0.03352523713763203, 0.024974962373474435, 0.1272940428386773, 0.05453291551900968, 0.006622568199095587, 0.045353883667097944, 0.09901013796127613, 0.04046985098431188, 0.06076275784101698, 0.035328535333035455, 0.025722788676859874, 0.09375634528095685, 0.027763744583353404, 0.04326874938523097, 0.10112893031609636, 0.02616930685396637, 0.04497554348481279, 0.012684392596354649, 0.02091650242706941, 0.003979504530903914, 0.08567010337907462, 0.047169132834120144, 0.039992313907151265, 0.08486938828061666, 0.008568859099590731, 0.032470648161946766, 0.05488998143963757, 0.03970875412285809, 0.03987365454855946, 0.05664595455351857, 0.0073705577749698875, 0.041731069194934065, 0.06609530052951267, 0.05207084299575898, 0.033639058650982, 0.042552303958443866, 0.06773655197673267, 0.01705076913499544, 0.08359748314345077, 0.0715571397074288, 0.017721749158696305, 0.03358079383390085, 0.03396464218836158, 0.04835967943372746, 0.07746102693941324, 0.02935759050981893, 0.04583961022416911, 0.14244012204149079, 0.0432372555106638, 0.034627449969130183, 0.03821458006578107, 0.01705167694918571, 0.02588477988366879, 0.016397631299051068, 0.04279018575025182, 0.05197703552943084, 0.012698613103449106, 0.006941605993967143, 0.033047941378167564, 0.12552429546391772, 0.12535193334183387, 0.024375975462457827, 0.059286131027845614, 0.012162102577877382, 0.01932608474406504, 0.035581543530908324, 0.0757931003106698, 0.11385778761318616, 0.024162035833503452, 0.009169758357588322, 0.0221968172944241, 0.017490463383916407, 0.03583647843991076, 0.0708282376909929, 0.04146450124080143, 0.1301976080022512, 0.027601862544073697, 0.049651613939673676, 0.04519062649999415, 0.06303218223394887, 0.06412524797563111, 0.010416151809265778, 0.026464840592516047, 0.02382285040502827, 0.01814412599008891, 0.02476653666235507, 0.05704353120358241, 0.06424298419827415, 0.041353188665403474, 0.057951008315168084, 0.04353054844203495, 0.017932120733143344, 0.07349073030655423, 0.045780506540810874, 0.02831924451334823, 0.07364272981161073, 0.07289330429968334, 0.0336802052333951, 0.01108630445800842, 0.022009476238200744, 0.048177595655884475, 0.011045354185625912, 0.019996114818739797, 0.04702759425966971, 0.06261466814565562, 0.11222657191777423, 0.034416128445657036, 0.02887017281365491, 0.06241108027977809, 0.027837790811674732, 0.06545435306766341, 0.04782749730492792, 0.034481502558675506, 0.05221979347087684, 0.017357340285314188, 0.0512224082804976, 0.032937904339163535, 0.03102890707762732, 0.018236600463428808, 0.10343506181192014, 0.018129524354252125, 0.04845788041430135, 0.04195998009714869, 0.031878850986099536, 0.03922475892449579, 0.06753464950428856, 0.0406945369116241, 0.032769207947797356, 0.10578361925699058, 0.06639914632204079, 0.03402245884400702, 0.08221425010912842, 0.0190057527394064, 0.05745629171630549, 0.04227807895550805, 0.044967966875241655, 0.09340117925838118, 0.00744385275832047, 0.036208506057699846, 0.07428519412755005, 0.053845746142248956, 0.05219468110871892, 0.040391970485929525, 0.01734685828729022, 0.043665483338578094, 0.026400378124127467, 0.038326042028324264, 0.023093063557039828, 0.014004242388651738, 0.06145135214131686, 0.02632098651731447, 0.029462632655556646, 0.05485376463301721, 0.023505881526357224, 0.07428145561847957, 0.07134234397521905, 0.02651346419307013, 0.004007975709804845, 0.03503240404590484, 0.04523147430811678, 0.008488190041163997, 0.022627540653751745, 0.058382821434568015, 0.024201408922371846, 0.029234600839235132, 0.07276909846451975, 0.0016490805067024346, 0.049383345270349134, 0.02127726089149233, 0.0387204509048212, 0.03234034043646628, 0.0566045819751678, 0.0209684202056979, 0.03616444834117447, 0.029842809533640265, 0.07305393761564648, 0.06943343672901392, 0.013411297038527987, 0.019893030027648615, 0.024697372329331214, 0.006251472814549362, 0.03621722413827816, 0.06790188907255089, 0.040719871439280055, 0.017194983271521427, 0.053219047915791316, 0.05941086546367696, 0.05542496361980035, 0.04511633129309743, 0.059520588406632026, 0.0704939705469916, 0.046408001498709765, 0.02301312419736097, 0.01794427280284224, 0.03484398855136768, 0.02899024751968682, 0.056125991527111306, 0.017304499370736942, 0.08282220982495817, 0.09531647567787478, 0.020842892868864923, 0.055274963604226235, 0.014754814159635816, 0.05039244394509062, 0.0544260002882971, 0.03336198763140748, 0.015113722521721598, 0.02368329408308191, 0.06938330393524901, 0.045369213086462794, 0.06151319075856478, 0.04184053166799488, 0.06040862986757871, 0.02659881404871422, 0.010987794169435098, 0.020631326197256005, 0.03073782430991771, 0.02700323760960131, 0.08448415330701298, 0.03194282890387601, 0.040500866053926374, 0.04312277516169895, 0.05603215341726619, 0.029177006349087726, 0.020137431227692196, 0.029257187026462732, 0.010277275390352213, 0.024656807973740563, 0.049430678012750806, 0.02429966544432025, 0.05980285350233317, 0.01993832689139151, 0.05976395921841745, 0.07625359576195478, 0.025829895429553527, 0.0858537806198001, 0.04841455814218329, 0.021765764517289017, 0.020877939476180944, 0.03357573382316097, 0.011141340214488728, 0.01655963782761847, 0.04143861129940037, 0.03865850503526388, 0.06855881712850063, 0.049198151175533576, 0.037129454825434, 0.032575027641629985, 0.04368758880563321, 0.04606202087034622, 0.05830347770825029, 0.05843830152204441, 0.014718645233510724, 0.026509660566526077, 0.06353067564627816, 0.016742083582005674, 0.03262667728948497, 0.010319346066323981, 0.04242461625366442, 0.010486280455464318, 0.08885941933840515, 0.028645781830193538, 0.043184832114005284, 0.031897294552876584, 0.02399262123470826, 0.015047298868246859, 0.023271856987248027, 0.011461990145635943, 0.04457739609924536, 0.043311022116892764, 0.029947447567997925, 0.07459417270917086, 0.07039136073041348, 0.04452411468411165, 0.0322573539620686, 0.08559000888659109, 0.03365644884686317, 0.045068757232999614, 0.022297527212950013, 0.029922436712489977, 0.0881789034352668, 0.03585157803289833, 0.014277159296456846, 0.13799753220331284, 0.032859491409673806, 0.014613003623972257, 0.05183916268569808, 0.039443745157651366, 0.06022514797927392, 0.029556070484461325, 0.016528764484269966, 0.040508258802395676, 0.04899975738578266, 0.11036268765887908, 0.005179888657068895, 0.06005924780883136, 0.03164252818321749, 0.026533874690592773, 0.019263681136972962, 0.013910600588837219, 0.03396156634534559, 0.04838483393072121, 0.021594197211426594, 0.019144732580189745, 0.011119091105947812, 0.06555353847122, 0.019471030494558717, 0.03291634279453466, 0.1080471792468621, 0.057981000657403664, 0.003220540745514295, 0.03754933612541326, 0.1070513568758484, 0.18275145411251054, 0.0837482032816737, 0.13710672516495953, 0.11225063473947587, 0.14026527503325095, 0.16808961908663475, 0.07113215243143421, 0.06656282100706332, 0.0826291250245225, 0.08186712800975769, 0.09671417245220754, 0.13502174027023778, 0.10206558771671788, 0.11814980286984675, 0.13593776692305842, 0.23481095900699017, 0.1225768258014033, 0.13431418146337235, 0.18138835386883828, 0.32378059541506155, 0.08929262673782726, 0.16531114075933734, 0.11548153395133635, 0.08846517517081193, 0.10239261532983474, 0.1024051561891552, 0.23023819550871852, 0.12557468106669764, 0.13515071883316965, 0.15192943865493422, 0.19769147098545106, 0.07673675209404, 0.11367628606216562, 0.15559542984251054, 0.09751710920564591, 0.12099947374794753, 0.11543966724627441, 0.2437127781130614, 0.12463813091838553, 0.10903512623401419, 0.12658708158039278, 0.28727243023533977, 0.2020623090286409, 0.12199356476025236, 0.1514372424853425, 0.14648949426989402, 0.12530616724923735, 0.12325635345111932, 0.1163863757204625, 0.13484606098744178, 0.14964795220763455, 0.1198318484990347, 0.09310539271081648, 0.1463000866914949, 0.08914166145146855, 0.11790509140419385, 0.1899444681381987, 0.3072201953299584, 0.12054325306728003, 0.15368385661032893, 0.1798962444187172, 0.37559286841461736, 0.2135417841735386, 0.11625179705480415, 0.10931015179883088, 0.12365337851787768, 0.17895248538303762, 0.21958038030612856, 0.1371495494799268, 0.11685621744442372, 0.13615835427997575, 0.2636833573060651, 0.13152664797680994, 0.1510206132286018, 0.10189140230537423, 0.13303553475247276, 0.07731242120386132, 0.16527112032617294, 0.175733981473792, 0.06502260123529742, 0.1040794643303079, 0.10819713329716076, 0.1339095185000089, 0.1392041206840546, 0.12669644829246307, 0.1698224793278402, 0.18005079499656157, 0.19891186437058836, 0.12459570496913888, 0.11023565495927488, 0.0830834994332925, 0.2189145579693779, 0.10086878983964843, 0.1445432172547425, 0.14439577597283548, 0.18566217453729722, 0.12693279407798283, 0.14029539761043366, 0.1664340417952307, 0.23981786453195159, 0.19885727294510414, 0.1471738406126538, 0.11759487176013571, 0.18556134204470343, 0.09429203226200997, 0.1336819750647391, 0.13665078027594474, 0.18947762947890068, 0.06040640055171906, 0.1317205754739623, 0.17480986493249095, 0.1631394806768625, 0.10905888262054614, 0.0750077146315767, 0.2536180345041137, 0.08753343605466428, 0.20348543992205975, 0.1570170745253563, 0.14628108771097276, 0.11952911353399677, 0.10876075950481238, 0.10179038595167861, 0.0816862393290766, 0.1673780153355291, 0.10803396423016826, 0.18716997346810757, 0.17956771527326879, 0.1177965750497195, 0.16317113542989378, 0.07856935698298678, 0.10126566934970119, 0.2064925648512379, 0.07995445161096512, 0.09793691772727237, 0.16552183026027295, 0.15851404097291732, 0.1343001773761165, 0.1639017228397631, 0.13311235804951962, 0.11122084402989958, 0.11056225356315413, 0.1848309691394529, 0.19256937648019484, 0.1217386260208103, 0.25086987793685933, 0.07985882085537718, 0.23539785896578144, 0.14584371279324257, 0.1360624553936143, 0.17542216836685137, 0.17897776628453888, 0.1649728363319751, 0.10607320815324785, 0.10984028464243298, 0.20043636401814802, 0.12162255603940257, 0.21395482813879368, 0.09605938178156653, 0.18630417153960277, 0.11225752186991515, 0.15720943920314312, 0.11255907705954968, 0.06428257562220097, 0.10824450817439826, 0.09930466046376575, 0.09554565854130254, 0.07834463275127834, 0.16968415449223212, 0.18555591814219954, 0.10502421928028907, 0.1679697876135188, 0.18394754718868964, 0.161284230228874, 0.08089877755170868, 0.12980638222107965, 0.25927681956560383], [0.022885289020656098, 0.05681241779858547, 0.0652808724572101, 0.10811657149104342, 0.12362681824954287, 0.016037537415902463, 0.05956240531597888, 0.03317301672312521, 0.026973881120342883, 0.03954857279877028, 0.06352252447076383, 0.006685108265599177, 0.0012814197097829874, 0.03693813968810343, 0.05047141611876507, 0.07595618510799063, 0.03169108666629801, 0.017074243984215202, 0.005102192977398274, 0.033586983824329036, 0.01740844984118256, 0.009418823117870958, 0.054593624156569286, 0.037156130006957444, 0.05027396461716102, 0.020601395142054366, 0.02552783653710879, 0.025351000461547125, 0.043554247371972575, 0.019665113124515743, 0.0025947469816122565, 0.05276353969689339, 0.010662147429801766, 0.019003623014976902, 0.04496995104296554, 0.027408526849842844, 0.02459467632786161, 0.01299199317732165, 0.03335425780425149, 0.03209042340336788, 0.031348442350844705, 0.07869873391163927, 0.07355114400026298, 0.059717538120645675, 0.03864560028417938, 0.034373901679270694, 0.032165469376430396, 0.03473217801881894, 0.04655643103403911, 0.027800300383880257, 0.01388903808659844, 0.03662352652979955, 0.027529151223960425, 0.03185831216884957, 0.03411533551350717, 0.08150524339608609, 0.0321104891613246, 0.023129320583276214, 0.09054240725573995, 0.019755007796770623, 0.11797878906250962, 0.019869507297933586, 0.002211428903636613, 0.022938294644137065, 0.055724676367976976, 0.11849747655252296, 0.02339270352686365, 0.03635614652246718, 0.06487827793124222, 0.036467654450285825, 0.015651497092368384, 0.11330170737158869, 0.017596650831100923, 0.06054644142427753, 0.06589514473753591, 0.0061712480871187105, 0.03663977525467354, 0.020882296601250287, 0.029539298904579014, 0.019591790849282857, 0.025801915983338992, 0.030423881478547573, 0.03358577340540867, 0.09677775008904357, 0.025346089837952487, 0.022134141726118904, 0.053848009932065205, 0.015293059874356035, 0.03609967943761618, 0.033581364569404436, 0.036835192792838624, 0.01661692013693673, 0.04515079375837119, 0.040241832574529034, 0.026728888117377798, 0.025783190879249768, 0.04965059121229476, 0.05759515281346056, 0.043121576234097445, 0.07342426451824366, 0.014566186075699667, 0.023198597914268895, 0.010618885487107741, 0.02002769104775883, 0.023418423013701554, 0.010418488377434833, 0.03664886488789513, 0.0373461734383337, 0.04833890312922098, 0.031498139761688734, 0.11820600307997196, 0.06839371751993895, 0.07652895840545816, 0.06824655202968467, 0.004691655556070469, 0.019335540184270472, 0.0712506126071657, 0.026245116999733354, 0.05068612758130316, 0.08357975586888292, 0.06910874568406614, 0.01711501901398503, 0.02942715703900303, 0.014701036702571137, 0.11791348006696471, 0.03239116270936305, 0.07979267682399481, 0.01465943142501337, 0.03272304731991983, 0.06179117725320882, 0.018339560765232292, 0.025250259899504246, 0.08270720470576517, 0.029549976255023674, 0.02276462442692249, 0.03007160935310587, 0.11819077325203728, 0.010571378459703299, 0.030702312304187688, 0.0056820884985368586, 0.0558579603450433, 0.029074990250650915, 0.06796754280766172, 0.011086462463642801, 0.017265865556715478, 0.006550312222492311, 0.04636658295508354, 0.04710930136723384, 0.02273869426590541, 0.025694108260194623, 0.05282196922287826, 0.035750025417655706, 0.03479927582966705, 0.01733481155468091, 0.03323783159195896, 0.011501265558293991, 0.06892822472558868, 0.026399847608239903, 0.040495197003286694, 0.07287760715811484, 0.03216114481009784, 0.04876317411300637, 0.058806759170106346, 0.052765094855379675, 0.059840372658424804, 0.013769829059920967, 0.06281968093507233, 0.04349120216624391, 0.024993760255916465, 0.06927821965467545, 0.007992273557089992, 0.0773704217206086, 0.04286899321502255, 0.09306744071504763, 0.0808137494529928, 0.0053822105626515565, 0.028859173706282052, 0.04887792259274472, 0.009678724191842542, 0.06414907714051586, 0.001502771239404777, 0.0671130176934023, 0.03421385825100926, 0.03791488263936293, 0.03631526040994833, 0.0860899885094935, 0.057543993461877115, 0.0035784191981468715, 0.009112036505323506, 0.04834954409048923, 0.05490493930635914, 0.04361245090201978, 0.062470957711939855, 0.02925574295072546, 0.025039036052241444, 0.04096703055585104, 0.0426399712300589, 0.04160347725114515, 0.06389304289534208, 0.033864365109512885, 0.03827331602693566, 0.038152258813140855, 0.020943528093818217, 0.035817268785209425, 0.03301222635913761, 0.030578481852106994, 0.07201636345275948, 0.027593454729104717, 0.02957386670694236, 0.029448883292535623, 0.0366371552339725, 0.055308192667941895, 0.08026890006036529, 0.033988023191810615, 0.03916402347385883, 0.04764478150454741, 0.0339965918852437, 0.042648746767231537, 0.06590166414577155, 0.049088190745321975, 0.031504132484476415, 0.03191538954964809, 0.036187067087138855, 0.05265476670296443, 0.02182626822632888, 0.0160525422055094, 0.03257320052193057, 0.046788184122452815, 0.020354856556702047, 0.025805537664001028, 0.08910198575787007, 0.011514649114331171, 0.054511438244052475, 0.03557024373402519, 0.03068204353293104, 0.03256581543434051, 0.028622090561135162, 0.012774911630267819, 0.014923303707262442, 0.04278545898775901, 0.03623616949264561, 0.08977379890218859, 0.04260592245226426, 0.06277248991893665, 0.02276193928874789, 0.11602511163800956, 0.005903478811359815, 0.05774107724127751, 0.015388769153956205, 0.07619800076128976, 0.034012538005387595, 0.029509423390751886, 0.05248662955578297, 0.0461346804795246, 0.04356403414520525, 0.021128026963842493, 0.019118028670369137, 0.0053682155726898105, 0.02085396858503021, 0.03638348437004513, 0.025863375387064395, 0.01282388763126707, 0.0648435358438761, 0.05732826693283935, 0.029128932416619315, 0.021473940559512666, 0.05634282505319965, 0.012560040246875537, 0.009085945465842323, 0.027349287185878045, 0.013430120776437465, 0.01454867426336052, 0.03377284824607834, 0.02223925856542924, 0.04425042211228321, 0.027605369311547088, 0.01103898607975533, 0.045336933971773234, 0.0013925705688081743, 0.03303393346047209, 0.031962996168482694, 0.017074410608338735, 0.004174737250357266, 0.059306267648935325, 0.035425384168422995, 0.08510160485222455, 0.0317903965591423, 0.014073407679285495, 0.07373823799313077, 0.04321346081973564, 0.06406950741826047, 0.02934945082562345, 0.04307007597338769, 0.0429822554841878, 0.04292739592793007, 0.03543434356669745, 0.030810495410414956, 0.016134945495474725, 0.08954303023675758, 0.04231934428154942, 0.05057294192093034, 0.03176829683774662, 0.07285750501098172, 0.014057501778757621, 0.07754161938904755, 0.03848822284189444, 0.05550383237160503, 0.05407540398018976, 0.0686991261318326, 0.08979894190786347, 0.036852108014206734, 0.12277355718035853, 0.0839712574417072, 0.02918084253436856, 0.019762936806786927, 0.05720086268059189, 0.054874571581040664, 0.048892236945609895, 0.0767542725248683, 0.017455682992154074, 0.056037826298345486, 0.05881935365558152, 0.06890562513182241, 0.05603641669656481, 0.017324009714948557, 0.04788413035473035, 0.07429181312721583, 0.03168689041969276, 0.055932094673475916, 0.029125111553096966, 0.01807769659095474, 0.06425093236048857, 0.08959003739179143, 0.08628566268711321, 0.05031672381465474, 0.010030009021471826, 0.04057748250723366, 0.033222957994909055, 0.012914624042628754, 0.0978128957532106, 0.06535177389460226, 0.05247441045339069, 0.016304344772511435, 0.046316821713961905, 0.08547911765955149, 0.03984023396286272, 0.033258481491957946, 0.030293598650924625, 0.028374144289221977, 0.00441612916127328, 0.06397612896116991, 0.0445342538577895, 0.061261381488293416, 0.29445603670131776, 0.12402121563472095, 0.2735180263557742, 0.17929771524523536, 0.2243979242179663, 0.13455153082407292, 0.07342828647984613, 0.10971057829597305, 0.141941582663886, 0.13404917632860525, 0.11193079303108877, 0.14024642927031364, 0.09453006344096315, 0.15562884659776766, 0.16851908797698636, 0.21076732014696445, 0.11246136254480771, 0.09109480261442163, 0.15255913228517579, 0.15837162522779358, 0.20728785604719194, 0.14991668052971363, 0.1937645655726233, 0.12146514795360067, 0.08946128099435761, 0.10333339428348888, 0.11315852553854067, 0.14919265083247615, 0.10309743154193125, 0.1697966161995165, 0.17717721451434398, 0.13627620924624706, 0.09706543142636938, 0.10923592553984736, 0.15381553180275426, 0.21449167191261248, 0.17635419093553098, 0.15767341269360435, 0.1594752055262366, 0.2016329014253232, 0.1897052648447214, 0.16857021668505284, 0.2092427285688539, 0.10900534839639742, 0.08227150752058915, 0.17551702537363575, 0.20039683388125515, 0.12692839673329748, 0.08841644431794844, 0.13787598469324652, 0.1262124952289366, 0.11287922520310649, 0.11723923842392622, 0.14198474405753997, 0.15891830557056014, 0.11570491752917729, 0.09568688685014363, 0.10420110377092516, 0.10366141781090729, 0.1371599835974555, 0.12269008424012892, 0.08840308374454899, 0.18271033051273516, 0.11465913090374201, 0.290764473498829, 0.12016328111771615, 0.14041720559039425, 0.09713574297605984, 0.20332425502279114, 0.11557099769913382, 0.21193998625441907, 0.11368927125248218, 0.14830832489796225, 0.1295112085438544, 0.1036568749095163, 0.09984047001888675, 0.08882770329833993, 0.13359983511749776, 0.10604426535146852, 0.08807489167778723, 0.07069301551147815, 0.16429179948904823, 0.2337095697200106, 0.11054421219253734, 0.22736067733457013, 0.1197619966020988, 0.1031474111181113, 0.0990953422602146, 0.11242088245888872, 0.09608986442007365, 0.11057541495369327, 0.21230009354410634, 0.08067552420881488, 0.22708096331165684, 0.205853647522388, 0.1391645292601278, 0.14355830397577057, 0.12333482383720337, 0.16712687639219148, 0.10243756170835226, 0.08785534620044694, 0.15513016932433651, 0.1101877821248866, 0.11532349001255729, 0.09555190215788542, 0.14284132228743646, 0.17489791907850774, 0.07265194063825954, 0.12499073054641487, 0.15921505738890943, 0.18416932964276883, 0.22926296558110948, 0.12404667273644479, 0.07963049601042464, 0.11591150079883876, 0.1820361118523344, 0.20812027186395662, 0.11846044386226325, 0.12774832531689637, 0.144999974196957, 0.12874861398050863, 0.20158800867296037, 0.160060879744349, 0.16481105388412554, 0.11591064278036357, 0.1848749732298236, 0.12056970608330543, 0.1273577200669435, 0.10828300409259335, 0.16780296430712746, 0.12907507468856153, 0.1676050071874934, 0.1176796317280781, 0.13528444714123203, 0.20329186482535255, 0.33054417119391505, 0.08313404591453653, 0.14414011711074462, 0.1521056848427942, 0.13531573417205967, 0.1317575315554296, 0.15541155341892474, 0.13881756803922116, 0.2197530258807444, 0.1464303216386226, 0.2768994158794803, 0.1693750993018189, 0.16877241793178743, 0.183613900575907, 0.1709813098873823, 0.12476363910302041, 0.15244564402007288, 0.218505620235397, 0.10005400170602145, 0.12089121786336746, 0.20666105822930414, 0.16483359219085786, 0.14410490770974468, 0.23181101998254178, 0.11172466941418187, 0.15071736498465463, 0.1384112503259413, 0.2597490668056473, 0.12583636904075263, 0.07123742057310958, 0.15940063452768713, 0.20819464367964577, 0.24163995869457724, 0.15935692155072767, 0.12754911947394573, 0.22521088140145426, 0.0947041952261521, 0.13873293064534664, 0.23801067844033244, 0.10125878988014114], [0.03411507887405253, 0.03386012481285199, 0.028664981908795815, 0.016673202701513807, 0.043417860738812916, 0.061289814841603084, 0.07695414486431307, 0.04976604832336307, 0.09534953237180749, 0.03626735310160345, 0.04648828368273474, 0.02438967311454396, 0.06243237752407309, 0.01978489863235624, 0.010767693278349696, 0.025678363238130848, 0.04195030440666503, 0.024513911508444338, 0.06620023159250137, 0.01703061527692743, 0.025699147203516577, 0.019403296830733458, 0.05427724899603956, 0.05038024016445683, 0.02573730987346461, 0.014496208731866172, 0.07544380252159412, 0.060574618138132565, 0.04992588490788495, 0.08497264161105118, 0.03036272276433245, 0.035655264171861836, 0.060141870391465006, 0.07314176959616524, 0.08950887803709315, 0.020067759361418507, 0.04402533398881074, 0.05590530840920345, 0.08086175252232822, 0.04066163343527625, 0.04030179427636247, 0.016130649657439322, 0.04291819521195946, 0.05765683438268401, 0.04220599391227288, 0.01936743433977808, 0.09281070932986275, 0.06752432263906925, 0.03382313425742811, 0.03880135745050446, 0.05645085111140244, 0.05791453869953271, 0.02111386582856217, 0.02973242009419107, 0.06218418801924395, 0.02368550424674346, 0.06586748896346939, 0.034525506649046175, 0.0476875177194034, 0.021732351592471524, 0.05128517003369428, 0.049457583020651535, 0.010289762623517985, 0.0321152140085976, 0.025117954599761197, 0.05224767907132065, 0.01468361777839281, 0.04897729951828238, 0.027858622657555728, 0.03424076325890999, 0.04531789285641524, 0.08698543804066797, 0.1462433502198227, 0.013459009952062081, 0.04412987817739768, 0.02802051044249487, 0.025986748101610332, 0.04331989341505593, 0.05864075174735439, 0.02553663697213896, 0.027161863775202827, 0.05297119932008847, 0.09070291799763519, 0.08841252194777613, 0.030160381706551682, 0.0400231029808281, 0.049177424666742166, 0.03407021293476705, 0.037691816988010565, 0.014163942992567055, 0.08474874475430097, 0.06701326538478175, 0.03971460320415997, 0.027420678919541742, 0.04470202711320693, 0.06479108180370062, 0.025964667532412757, 0.040466384436454506, 0.012602676870301368, 0.05162392645293186, 0.025832071119258483, 0.03165068701961108, 0.03042696306722299, 0.02986783954134632, 0.04991327893109091, 0.03850191666354095, 0.08019030710021335, 0.02126160971519928, 0.01852160432345925, 0.01003423878442376, 0.05389655309338724, 0.02333993730585902, 0.051161462155681466, 0.029732377959355235, 0.05100430304845495, 0.0321415942462702, 0.09543338069511999, 0.07135260189252515, 0.03571899885672235, 0.08264383391266869, 0.016183858294220223, 0.02425976183956429, 0.05172774285799073, 0.17244015579983113, 0.009609159577878253, 0.029170010051119234, 0.04436093412580029, 0.045454497824633316, 0.04281034535397926, 0.055396737110230236, 0.0672198256718055, 0.01066556130911434, 0.05415732559237269, 0.018759744669941646, 0.047456852475842165, 0.03793123095566708, 0.05955883151581211, 0.015960057198460546, 0.024941015102329756, 0.03351479152878446, 0.03653754848205755, 0.051322390415495446, 0.012986286779895667, 0.02700563738002412, 0.0035248607943480417, 0.052105022008500756, 0.10268005151902476, 0.04408832173794509, 0.021360590190236128, 0.03211150805826389, 0.015838670566858306, 0.030726650917542078, 0.012548290373336886, 0.012737486319946907, 0.03154801974643863, 0.03703504981052491, 0.05288656575665359, 0.026767966262395346, 0.035033828969444, 0.025311424359378797, 0.08684696764835427, 0.014346915432402204, 0.01773297426200682, 0.056576072013065706, 0.019902228828399413, 0.01553178340527079, 0.05767545031924402, 0.03758468342223956, 0.053718165689778906, 0.05448855519775422, 0.04158039502198658, 0.046279015274898666, 0.03513397581334557, 0.027902280093140663, 0.030789600362280206, 0.02225469523710349, 0.03885797517854841, 0.018310782672356696, 0.01836509064530894, 0.026771072748928305, 0.007953715394251049, 0.07859847598498867, 0.021031660763847253, 0.08866756793952758, 0.04564228129663295, 0.06603240471092925, 0.041016121470038934, 0.020144320273351286, 0.045468252933313774, 0.09079074997815395, 0.014177794819847952, 0.04625159315764905, 0.03276671816204344, 0.045102338697160446, 0.12293811286649398, 0.04330278667170675, 0.03208616203928907, 0.03780284228043691, 0.027487389855988087, 0.02804949729432983, 0.0345185658924522, 0.0518388792331661, 0.04883683346692593, 0.047327241890372775, 0.02548632989337127, 0.01734934041216489, 0.03211947728789622, 0.06006533820782939, 0.04283421282326022, 0.03998965941249363, 0.02936150138867238, 0.019368819043701215, 0.09978699708177198, 0.054419542167095415, 0.037159439506790334, 0.0226972967896971, 0.057779902577280044, 0.04570166843252317, 0.04234595817603892, 0.03336765285160753, 0.06911324262018166, 0.006927779543348739, 0.019987176487883253, 0.088612555165685, 0.04541511324444606, 0.03587139672749946, 0.00929897440777671, 0.02677145004723101, 0.013410058848920369, 0.02110050717038253, 0.07343266850277301, 0.055608989430531386, 0.03077377490098438, 0.028357855344731963, 0.0619178690436867, 0.015381199247654409, 0.0778835014470162, 0.05307896490839701, 0.03471326330796846, 0.06592680715144643, 0.0375936926162291, 0.060604315536517295, 0.025868933354955048, 0.013697618569788194, 0.020250214691904765, 0.0034086608173956555, 0.03654086947320931, 0.04636356073822226, 0.07398306437197232, 0.021803611175968282, 0.027340957894921306, 0.009148416105627773, 0.004902913877289863, 0.05703072604392806, 0.09093994560140757, 0.007174467037041342, 0.03066760086033854, 0.015335350800606032, 0.03464045048120522, 0.05153238660685959, 0.059716637967334646, 0.01882170203081783, 0.05171096170200937, 0.04965784989537732, 0.04424650740299014, 0.052728571613589605, 0.05010413824610653, 0.059441719654827356, 0.04828208238787709, 0.05589148052217019, 0.005805050877238354, 0.07825038095395412, 0.07527736992004418, 0.03633282297561246, 0.041706516076960874, 0.04949072781469553, 0.019409540447316343, 0.009449616979597317, 0.059660273048305706, 0.061751348342025475, 0.017293643904849887, 0.07245196104650536, 0.041643800289039655, 0.03167587790578123, 0.03167104580619883, 0.0379777861188256, 0.022527899427880204, 0.0675383267263251, 0.03072943947758646, 0.0062681764041283925, 0.014219868368649436, 0.006590490182486153, 0.045787566041033116, 0.10526935209430034, 0.04258320794530934, 0.08117731946009783, 0.021825433190491413, 0.09963274527821811, 0.013094024597516945, 0.0569852740473805, 0.03300144750204298, 0.01336228752118205, 0.08623824184460026, 0.04005209174788287, 0.019134520628159086, 0.02021591693553473, 0.02815359332148106, 0.04084341077794952, 0.036610292360907605, 0.02311284203202494, 0.02379252672976544, 0.08426282284480911, 0.044247104951571074, 0.04748525135519524, 0.006689079473876665, 0.023975301901960087, 0.017296932337264863, 0.03155128711143569, 0.013751467847595773, 0.023421422247925115, 0.03532264028645812, 0.02278515558329321, 0.03607257907729476, 0.03658907938628428, 0.014307714713316773, 0.03949114684796622, 0.010047279516114824, 0.01419536983444085, 0.06616250176223056, 0.01720752796128152, 0.05838393226205822, 0.029921777876875097, 0.0584986845722362, 0.003580092860858948, 0.030175567484430732, 0.07007155732642259, 0.03645186154772678, 0.03778683104281945, 0.02004024339839816, 0.03420202985345837, 0.0531040006617625, 0.0344539042412033, 0.010201266061724916, 0.07408707612945188, 0.03765772224494046, 0.05187897627512294, 0.022169891219105453, 0.04129726041649138, 0.01704049589593084, 0.03531392603631943, 0.038111564222603075, 0.020803424019005992, 0.13785493259708728, 0.17257353170744835, 0.08998860229527758, 0.10591139506188132, 0.19226211393552442, 0.23184802202928453, 0.11415266251612095, 0.12949590210712728, 0.13311005978574678, 0.22444874649086308, 0.08068543738655506, 0.1143345777546206, 0.15909450579314463, 0.1761101306446137, 0.10881492958193827, 0.12758458168396067, 0.10180598350181695, 0.14100756826660327, 0.16421001194225204, 0.16333192196344176, 0.10397847862012925, 0.1526258891868976, 0.1196742642130102, 0.14321730291891482, 0.10699894114006912, 0.148390035835966, 0.19170080131340414, 0.16865781117831508, 0.20415025102275036, 0.17172755613442392, 0.18594107650701078, 0.12010145782222671, 0.258569659124459, 0.12011189960063466, 0.15552259020266995, 0.12974060591190092, 0.22780379791173244, 0.25532233498750195, 0.22550892024751634, 0.10244292432382222, 0.23270731221043298, 0.10980316002162234, 0.1255105978118316, 0.11857607717355413, 0.13390202616010943, 0.11241839267313482, 0.10267137174284267, 0.15227436208196227, 0.12506866467095193, 0.10940907673249323, 0.16740521145684106, 0.15302563386578716, 0.09857372065345127, 0.1090908208261094, 0.2173683780335611, 0.15585366276002702, 0.13200222003844478, 0.19976865710510364, 0.1362993757450773, 0.09742211430303513, 0.19682352401075826, 0.16825809714294251, 0.1307282617856418, 0.1330191864361686, 0.11946755836928084, 0.10912861194341414, 0.1122814238131527, 0.13600510605160268, 0.2393596060574055, 0.1560374319313034, 0.09486927185207607, 0.19231728758783112, 0.23112557047317106, 0.14642419293522835, 0.2756350950127648, 0.14863729837440676, 0.1508153323084116, 0.10653976336001389, 0.21462636549145947, 0.12088718824088575, 0.15924240672780623, 0.13900294599513854, 0.28595647504252775, 0.18589779253928893, 0.2668819888945549, 0.13196307294551404, 0.21132448057253517, 0.16021926076181475, 0.138149079716494, 0.19651570988278236, 0.1273923395802417, 0.22556775580010108, 0.13933861508004128, 0.15892754459092695, 0.1046179551931639, 0.2075597100080021, 0.2577748888682935, 0.11449559411454586, 0.13870921256321092, 0.21000181444950644, 0.16568774958291363, 0.0772144845236213, 0.14475283423258414, 0.09238145494412991, 0.15078868777040513, 0.12484243890691189, 0.1396149889596047, 0.09701869240210903, 0.0645293478643702, 0.06385836592544952, 0.13339807820175925, 0.11901231828115641, 0.14035725154944007, 0.1797280115105452, 0.09361876355063531, 0.1642103796644557, 0.26825362335770364, 0.21013076236892134, 0.09807038556544051, 0.1901113374098655, 0.09099966215510523, 0.23409506516350856, 0.16881986941781738, 0.2102374784167736, 0.11351556847653083, 0.16464781586921987, 0.14260495351927896, 0.15459703341607126, 0.13077975821591195, 0.09846267620882682, 0.15755701329438918, 0.09922168548068694, 0.24857103193719543, 0.1542935553457468, 0.11918445057686299, 0.228617720366005, 0.15021119537132402, 0.12032792873440251, 0.1343182570511295, 0.1339382621189279, 0.09380916704333599, 0.21168487897563368, 0.14104020361217762, 0.13896261912680444, 0.11777251222801786, 0.20512590995959698, 0.27923301162738956, 0.07121138124456329, 0.11311241470637823, 0.12334298267359696, 0.10366671147846407, 0.12430643016893057, 0.1838506064227512, 0.09610715502452466, 0.1192652958355123, 0.149487242282879, 0.15564847377038774, 0.09549167998615773, 0.19151352345943454, 0.13656333900026738, 0.1592795160268584, 0.11586555084514043, 0.20905462333992605, 0.20920742723730304, 0.09270239981912798, 0.1168088578889447, 0.14459399356236383, 0.15037378987237332, 0.11316633197448908, 0.19153408525932222, 0.07793500553816557, 0.16870360791442857, 0.11456767532734141, 0.16803538006159568, 0.11573191446762894, 0.19448871784392865], [0.01695206445161133, 0.08221729913906706, 0.017119560000156204, 0.03461711161259202, 0.04648037382491654, 0.05051900167018176, 0.06642998902187233, 0.050051569292742404, 0.08460880347317265, 0.03698443821180732, 0.038819582682223096, 0.07298841411548276, 0.06998456038174129, 0.03372983623956961, 0.03666671473653086, 0.07849975023418665, 0.054368421119908174, 0.07139895021194412, 0.03564715513118333, 0.051616771191719084, 0.04034025189016135, 0.06567527750326742, 0.022962139130780296, 0.013118272237930328, 0.02675390663376499, 0.062187597110507, 0.0429325900040567, 0.0053919049265283734, 0.0023817941696653443, 0.023659053145937865, 0.05388631815871885, 0.0406390912981043, 0.02004859184155301, 0.020137130538181915, 0.04525931777372476, 0.027814172320969166, 0.020762175929942922, 0.07216713721713713, 0.05097126933715997, 0.08179703862556527, 0.06250743881889409, 0.07216565866744326, 0.03889533728661557, 0.034585770955609704, 0.04540870874939908, 0.05282797535220462, 0.026284853980365782, 0.008352633655792283, 0.05886487843048188, 0.018321322126974984, 0.023089618076600378, 0.035647526683826605, 0.0183672490980356, 0.029636756779866356, 0.03410523847466515, 0.02664232975803316, 0.037252783489924286, 0.025765758548532764, 0.04771719596559002, 0.03875741081672811, 0.06074510334480194, 0.038174597937012875, 0.047784925798975655, 0.0030543611923818507, 0.03857298280983683, 0.037225916786419774, 0.000472999801727823, 0.05162913968125659, 0.054247628206447254, 0.04612236178570217, 0.01519455245861243, 0.05710453095455324, 0.08016095061095492, 0.05450334835557207, 0.05385380921765201, 0.039655691042782805, 0.017939450279358896, 0.051917866728599035, 0.036751784970082586, 0.04415162358312838, 0.03410968178462598, 0.07721133590225251, 0.04673692517943921, 0.090321674342117, 0.025557566494230303, 0.06070817790685162, 0.02820835711674825, 0.05229753990387244, 0.01496296695193216, 0.03546714362117552, 0.05250284380670037, 0.024261297845852473, 0.019937578040445526, 0.05156018793763173, 0.033396335183492595, 0.06140769662095174, 0.027626961499692935, 0.03638468712808625, 0.013509727845479165, 0.031063390610318993, 0.07864226557074055, 0.02410680280938264, 0.04012244926284879, 0.03182873925975254, 0.10277658625836335, 0.02336353281392686, 0.05211067956782157, 0.03395356072653686, 0.08128900741857868, 0.06631207276856707, 0.028624114948475075, 0.010563279952733748, 0.0334482567925607, 0.03363739624018631, 0.023661125413773042, 0.027933722256772944, 0.10978832855940827, 0.05308248508240908, 0.0526661622608381, 0.020435918235189972, 0.02906830804873138, 0.032667881328492396, 0.046599577105934584, 0.01806384955172337, 0.02107961212224778, 0.024882612389422236, 0.03033734610184066, 0.022205809251435345, 0.04104808648867954, 0.05407510520589929, 0.015393119575756212, 0.0247231952380389, 0.10637588183125181, 0.046157885282751054, 0.023371140067014965, 0.07899862669047811, 0.028294848443399516, 0.027639130806370128, 0.0324758805424696, 0.07716638952373497, 0.031713703497042584, 0.04174151097334201, 0.048419924588092876, 0.026071586593564962, 0.06458639843209137, 0.06525829584608156, 0.07235394009659368, 0.08826653623292524, 0.037888261083994186, 0.02326479365658616, 0.04082480633270837, 0.02779433638938973, 0.01890860896016802, 0.03726245534996833, 0.09636484401961488, 0.04919817032773168, 0.09391226715618566, 0.040300829005577875, 0.04009488158889356, 0.03774012266207607, 0.04205160421289263, 0.025821885980305173, 0.02393362671887923, 0.026324895480948112, 0.04949247832560251, 0.04623471241023752, 0.02329600790906097, 0.030236871755351464, 0.027115994260736534, 0.05103242613615529, 0.0834030193847514, 0.033157583881890586, 0.0172536636913015, 0.05343243021578078, 0.0013388893515389835, 0.13056710752989018, 0.04692704138916828, 0.042783045810797525, 0.05485901999617777, 0.03359421569433424, 0.024718941534839334, 0.041585194562832196, 0.08644950591147908, 0.014684735309152354, 0.05133482402250652, 0.014464824982438118, 0.10446475293006628, 0.042678616535399234, 0.029737135365365014, 0.028636862651535103, 0.0169317094954632, 0.029497930156667868, 0.09846498979435814, 0.060799863309629505, 0.0218710154219861, 0.02377520548179746, 0.07505592454465167, 0.04768500112057213, 0.006122358271010942, 0.04674268999106942, 0.04967029882414688, 0.03707833760868638, 0.04508268471146303, 0.04583706298182088, 0.02627617037374406, 0.015349195924617592, 0.0316540195020817, 0.005523163558644874, 0.023174734275427558, 0.02184314514330078, 0.04907176198978578, 0.0050381671791265336, 0.04401169762375855, 0.008674198104399107, 0.09815230334718382, 0.06118694072469108, 0.02607947346874543, 0.010167719071520673, 0.013168002835534995, 0.029370098810402617, 0.0651508826582182, 0.018189041725089474, 0.028742184419365182, 0.06438579830911852, 0.05354924330247506, 0.03352409566662485, 0.053766682038023594, 0.11710202441580835, 0.05630267438508811, 0.0651816334274988, 0.04250597096078339, 0.059570288360719724, 0.03326661351527418, 0.007608617203415282, 0.039142515555384665, 0.09826063584055632, 0.01751325449966375, 0.04578523713374331, 0.035352816489795526, 0.025748330048255386, 0.033823858210516554, 0.03493606848942657, 0.04975001027266826, 0.09252617661390575, 0.007587199779077163, 0.006754776780238196, 0.05534431754401135, 0.02948629519631786, 0.07249512244015932, 0.06468578301850827, 0.03897402600775804, 0.049297539592390104, 0.01984317111031663, 0.05360574611733037, 0.04930967825555033, 0.04331720444644171, 0.025348399593044194, 0.024768275681943185, 0.11119684249523187, 0.0491290002490484, 0.06412569613706681, 0.11895910581393589, 0.010606307281000961, 0.01865339251385341, 0.06559712121323233, 0.035345350962973414, 0.08330657657596373, 0.038184216170902216, 0.014763714186096144, 0.03356602748916034, 0.029862312216972633, 0.052803330303680514, 0.05784302822224075, 0.02843787514364287, 0.008786067051152069, 0.06325767255358158, 0.06341213120087501, 0.0105351367552254, 0.021708518597147158, 0.015082785976119341, 0.06926316602696335, 0.043364556341041485, 0.03657820859863874, 0.08405803222089045, 0.06316163577139378, 0.023290252673529813, 0.025419628533023982, 0.015249983707983649, 0.007287774792677093, 0.0522885115576848, 0.04485429857947654, 0.007942237481925516, 0.05175414990874068, 0.04957627302276031, 0.03029022211839836, 0.02648981314362778, 0.04635122289220172, 0.00599657237950352, 0.05538815692547829, 0.019825123994040395, 0.024026068633482344, 0.011639900659511407, 0.05918945839268066, 0.050880997366602385, 0.03699112998982591, 0.057320211518315546, 0.04405441851685605, 0.016730002375439774, 0.08159233227131829, 0.03492589484179213, 0.02217903447848174, 0.010297385198364576, 0.02595639569805034, 0.016772736675075946, 0.03768825467916266, 0.07414625642160255, 0.017298587087181308, 0.033886275224147305, 0.012961670459668725, 0.014778782177956836, 0.057096287848487984, 0.0742054520355117, 0.01603856971938043, 0.044881253383092345, 0.07742256166473513, 0.013370652243705287, 0.030191829615843394, 0.008002266695257276, 0.04549703102618937, 0.05559176394355394, 0.1017900795165089, 0.04502563031330224, 0.008643265389236472, 0.028991865880426862, 0.06452762416654056, 0.03508463209014266, 0.013330964101178032, 0.06779659028735853, 0.022060241054503188, 0.0004208019521273297, 0.06435017522063947, 0.05079698816482579, 0.040048410695406704, 0.01936503456935527, 0.02746380583923911, 0.018895849765789126, 0.05382830998109234, 0.044449478568088625, 0.009013530047189806, 0.02520034544079775, 0.018385681173493786, 0.06885674872225331, 0.1258301713894452, 0.1588043116874272, 0.12063838586571718, 0.08268226854382985, 0.16150722310187357, 0.1764260499828285, 0.22927617293692407, 0.15632794779394904, 0.12955748025448094, 0.08860101022066609, 0.12567867750241873, 0.15730202858967168, 0.16184137533268622, 0.11299062204817611, 0.12374998220512945, 0.11799733605115645, 0.1464350100967192, 0.11973432550627379, 0.1353202540908129, 0.24504555659669064, 0.12402617988447029, 0.10806218690929875, 0.10959218706815474, 0.1308050237956547, 0.14807151179880867, 0.13370891071615681, 0.14619623581247945, 0.18895604617653355, 0.1256891805678606, 0.06048482114208802, 0.19792272228627436, 0.10751073383876394, 0.12335160116274511, 0.11496731275392157, 0.15235469406170232, 0.13052166319422184, 0.08891901331803492, 0.16366065029175053, 0.22328993125307947, 0.18162722008362894, 0.17450794968153202, 0.1217885213273187, 0.061933336358877926, 0.10574303957964144, 0.14610127155338565, 0.1612238471786822, 0.12160007901970418, 0.14328753785981288, 0.14546886597189213, 0.12032566877502589, 0.14727715523012225, 0.16544313770869087, 0.103266445859786, 0.15760345354435906, 0.08055571571833665, 0.27923889518264805, 0.11881930242863395, 0.08675386498291647, 0.09291532629680249, 0.19561952490720058, 0.12474991846829654, 0.11895640152356318, 0.12027735160964152, 0.16719001735891068, 0.11382188873305438, 0.124454767773709, 0.1799073526936193, 0.18086411990225318, 0.13774942696815537, 0.10587540425119862, 0.21501981292761144, 0.11392803787584267, 0.1457305003197924, 0.18987576537314924, 0.11400512164278377, 0.16533490480674853, 0.15704378035039673, 0.24025062760037763, 0.1968765066516015, 0.13861861500528552, 0.13357055523703176, 0.25127409656922667, 0.21960461932805278, 0.16275784631650295, 0.19896587356925013, 0.2050680703213138, 0.1562378098887782, 0.11074506512452519, 0.22870923722943953, 0.09822299794083643, 0.12564775053291552, 0.10380093774367725, 0.16484574234533697, 0.10606689558875178, 0.10917446230568233, 0.16647626856161704, 0.16149614547048846, 0.2642568200826645, 0.1074268778545722, 0.11093579037415405, 0.20223182896452568, 0.13916321158889802, 0.11378638821864322, 0.09267568633320833, 0.25037323845730675, 0.10001672386762597, 0.23871930977029188, 0.19666587843769984, 0.11894150111343592, 0.13846715942265528, 0.2041806493915858, 0.13220232220426684, 0.09952566916904143, 0.18535123477059026, 0.14591028583386254, 0.09012959311686217, 0.2672398745292618, 0.17710504903187677, 0.11567832661732552, 0.1547442601933595, 0.1405167050899998, 0.15791071608902948, 0.12517986999404046, 0.13654401826281704, 0.1299581442388796, 0.09019287197940773, 0.13743693970384138, 0.10213906320953563, 0.12573665503652828, 0.16315915381475804, 0.10862969718272648, 0.10546785313636066, 0.15904913806626875, 0.16207869404986983, 0.1635395930779557, 0.10211884614921386, 0.1159528848685084, 0.10449507469010931, 0.17361505888402465, 0.21532555861819178, 0.13776620429369713, 0.1073698043042133, 0.10893000364904443, 0.10571913763640389, 0.19208350819685768, 0.2033721968050926, 0.1531669617660584, 0.27737635157762036, 0.17277907309753282, 0.10132167803784532, 0.240532931000475, 0.10175710709224786, 0.12674452030971167, 0.17989598394882295, 0.2569190920480798, 0.14130454991132985, 0.20116312098839592, 0.09961698684961566, 0.13606103047007514, 0.0798160654883231, 0.10525739346180232, 0.12990214321161472, 0.07076556403790751, 0.1141900782503428, 0.2348712041613556, 0.11979411866876388, 0.14102272148574554, 0.1462539835202117, 0.0947154337360013, 0.15677756479670926, 0.15175115467319567, 0.12991600940304418, 0.09682530116650367, 0.18571483542121228, 0.06572080610860741, 0.18775207771649285], [0.016962358758093852, 0.012598608943423437, 0.042192847843492226, 0.02464652515857691, 0.06147386746541147, 0.019769770311071508, 0.011535349767655136, 0.07490774781833734, 0.008803453416593613, 0.046409832448848796, 0.08687070871312773, 0.04200433658796453, 0.019582216665449164, 0.06730354376017086, 0.07102574281875165, 0.030708824051544074, 0.028438166257054098, 0.038816388095578844, 0.015498977605133288, 0.016696468791774204, 0.07821949994972638, 0.04350503388371679, 0.027740507221390164, 0.03548444954738502, 0.019344156758198817, 0.04741032412576099, 0.02241218376213745, 0.06496128355783802, 0.04602623690340308, 0.06783307905519201, 0.04844423638836992, 0.031254518056108106, 0.049368444860221884, 0.02782762674013934, 0.08981341330875313, 0.07080773717813915, 0.055151408943798275, 0.040528678876017375, 0.013202061189428694, 0.05048517888832477, 0.051865336079631126, 0.0273101918038822, 0.05758412497779054, 0.05018543166619155, 0.07337905766983187, 0.04677575051544174, 0.013901332840173235, 0.03903281942550694, 0.08554467946411141, 0.040855572423747474, 0.0394249223773518, 0.03327278052306464, 0.07039271670603944, 0.059520722472018776, 0.028865656725341277, 0.09556219837958775, 0.05813338703686192, 0.03930997471475313, 0.04841361968447605, 0.027862435860198834, 0.022586024433915174, 0.034706268925219774, 0.04441840221144019, 0.07135062538568052, 0.06908920278111774, 0.037964214871246973, 0.04970867982915333, 0.04273312369121179, 0.024554330307329376, 0.04281771511981084, 0.05048422127841942, 0.03401956686209287, 0.07006306907222157, 0.0935850939863632, 0.011772071893867708, 0.07086366159661163, 0.034669692057275006, 0.020856308983638886, 0.08241375472636954, 0.04077697563315592, 0.04347999046947207, 0.018607907958569068, 0.012006133779763214, 0.017764667319434307, 0.09024631427300554, 0.06437803783844556, 0.028465603696062203, 0.02556668485574905, 0.018272326973777626, 0.05784649860053774, 0.010079496386160534, 0.03323355299090186, 0.020015876056746613, 0.01846555733091889, 0.023388193184209448, 0.06634044100440319, 0.04490671048481618, 0.061336389156959714, 0.010014253465699093, 0.03263362953739782, 0.04082537706821196, 0.08335186769404719, 0.02347593706461691, 0.09623902939981031, 0.07636054929706358, 0.04222230009374119, 0.0654768300873618, 0.007729886527804117, 0.06886213432036101, 0.07569656557133121, 0.006511862269572673, 0.07435082488002316, 0.02506675311334191, 0.06641754009310277, 0.0397881131709343, 0.0009872251288353226, 0.11267786665308861, 0.05570571569185104, 0.08312260056094778, 0.04099714164171488, 0.01683879069112722, 0.030307803836260593, 0.035086631579625036, 0.036196535933882966, 0.032135032703198736, 0.02545578596783021, 0.011047715651652506, 0.08961939388104985, 0.05975565482531825, 0.04801695084860248, 0.03376594579388057, 0.008024006834133499, 0.03026160873442648, 0.03055384063402251, 0.034654527346813874, 0.056511992588639266, 0.04596508776528701, 0.00987560112750338, 0.008486795761141806, 0.0254189869343874, 0.014608123643894591, 0.0491107443738128, 0.04426295531072444, 0.009600725907441831, 0.023341885084406506, 0.016443401222087203, 0.08600633936904131, 0.06511638571898784, 0.06437327277155654, 0.030938874509546067, 0.025834901814138698, 0.059163468859849445, 0.024538650402739167, 0.049305939746479836, 0.007175757895193755, 0.005135020323758645, 0.039459101390093565, 0.03559985303229863, 0.08585296090572112, 0.01372489896077182, 0.036521655988068356, 0.0556779143610789, 0.030460217028796196, 0.08413296328076432, 0.028021724691854853, 0.06321882806538094, 0.058504116135619344, 0.06684592879948116, 0.03178421039915374, 0.05923109144092568, 0.04078975397973292, 0.030853620414892514, 0.02598417979184418, 0.025307842898332787, 0.02194968116049084, 0.05347408241622391, 0.0503883951704108, 0.03945008836566441, 0.04221802532312371, 0.029663761379197243, 0.08052983726825445, 0.022428095408324755, 0.06621395988810448, 0.02914934674458158, 0.02636665110326102, 0.02882693864164814, 0.008791851014980387, 0.043926374581191814, 0.03304378152073872, 0.031034641245740558, 0.03313298862908156, 0.08354438558941887, 0.019754569211433974, 0.050798413088364955, 0.05159650433568224, 0.0618667901313353, 0.021012569852774183, 0.08432147453629202, 0.04194984475391046, 0.03319898710375832, 0.02829682303502435, 0.00941655932805471, 0.06245412292980379, 0.04964492982253433, 0.03553126134999818, 0.04517407133995045, 0.010293274179040905, 0.04166840703316754, 0.06426681719359852, 0.030520406641787103, 0.07159792622851749, 0.016577520234990987, 0.05497635019222095, 0.031055226028265975, 0.03214118055879109, 0.01854288624599576, 0.05610909928838092, 0.035921977682700085, 0.037166426228659774, 0.012068207969047852, 0.0784331082456535, 0.033406474357170445, 0.04350139113563684, 0.01667159774731244, 0.03883427624861079, 0.009033025069642932, 0.0956720247444126, 0.05083440772948727, 0.059757593027766676, 0.023710434663019354, 0.03487269769633009, 0.06343024918028424, 0.035897941674075784, 0.03424029594527618, 0.04666440729652682, 0.08309653058888451, 0.0451934993297102, 0.025620527430287292, 0.02002439686968442, 0.03471610549416754, 0.015384324886385473, 0.012958656861296585, 0.024474023225446864, 0.04555278307487888, 0.04367044375788781, 0.014588819185812629, 0.022302512530117266, 0.010207640870864834, 0.055509302239384384, 0.03556295440742566, 0.048580412347350395, 0.08955378611121448, 0.05443380672424551, 0.018614616973565954, 0.026713367176031875, 0.013256650699693109, 0.08655960040707743, 0.0318112475572214, 0.048114351267295505, 0.06560066820032175, 0.08214148707808026, 0.014472301042969189, 0.017849005939018343, 0.04975616578913985, 0.0262746018087191, 0.011735400222542306, 0.04886475737176595, 0.027791233733296398, 0.06346755383175708, 0.05770240895329945, 0.03834636634095542, 0.050324852007531354, 0.09105920250858031, 0.03608197897612568, 0.039289052853541034, 0.04884741314116025, 0.048180755768572135, 0.03134157054216391, 0.03858744271940762, 0.03204440450175636, 0.0549007258227756, 0.02660330906960993, 0.03773214002590507, 0.0378800141474893, 0.10502518455107367, 0.03309814695028528, 0.03981367752496754, 0.04048701135381576, 0.04036266379238617, 0.04701253680151798, 0.019524202742163214, 0.05111906684995179, 0.025084139478783456, 0.027108794949468107, 0.06943256338878025, 0.03370095855526386, 0.01783667766909686, 0.03772425698116422, 0.009382911788810407, 0.02751439062487935, 0.01758617840917601, 0.046940712228177056, 0.054317181329092676, 0.02958760649386433, 0.042341576153112036, 0.04181614325892541, 0.037116557735228733, 0.062453513889903986, 0.029024426532428593, 0.016253715936815547, 0.032073305168699835, 0.06552915389259016, 0.04695825181120346, 0.020783544037370913, 0.05601640264954298, 0.04373423206890303, 0.06291377568437208, 0.017808068115564606, 0.07619084550007697, 0.03761981238400744, 0.04548930885991262, 0.036690490275260904, 0.00231956819921071, 0.022394353065699823, 0.05738054477279225, 0.0325207847861513, 0.017600917940839164, 0.010090540501198942, 0.03233018211059032, 0.03620231223683204, 0.03342628539089234, 0.022808992409057195, 0.020558256731038133, 0.06955227994870755, 0.05053358032338081, 0.040437560378303455, 0.06218057208424134, 0.08173140021221292, 0.055217395927156174, 0.022943645768288164, 0.03200339773038943, 0.01729982240395921, 0.08351590244039413, 0.0387135063177876, 0.031062611115856037, 0.028722534264107386, 0.06652731283177292, 0.041791789323812535, 0.015545977099287896, 0.03853771212180296, 0.04514087675019138, 0.048779208333261555, 0.20476872912578045, 0.10018493379316024, 0.10486979127651262, 0.19761034227426977, 0.1305468368434137, 0.11299449079219373, 0.16418364319589832, 0.2659220500819145, 0.12969868558068431, 0.10742757499458329, 0.14608896818132172, 0.11601283124858335, 0.0782965147687543, 0.16916062532653733, 0.1734083223967783, 0.18981262440643004, 0.12261261742922569, 0.09903993112065139, 0.13575205188845435, 0.08874186314642431, 0.12589489815816765, 0.2743535218459945, 0.11409897507438738, 0.11686348761882513, 0.14071501461007904, 0.18571019292839114, 0.1814504223124635, 0.20496749829861427, 0.07663646352387245, 0.14260688406084815, 0.07815578441706397, 0.11728139624239937, 0.139032808102427, 0.11622636293571804, 0.17416215291427029, 0.12079258404311635, 0.1358928741706956, 0.13604141861921357, 0.12050148595364825, 0.19758149140304138, 0.24389214993965244, 0.10626217140065086, 0.11865755062430136, 0.1415245703631832, 0.2130474582795174, 0.0637624325651315, 0.208447820416862, 0.143494488851678, 0.15450668100628162, 0.10434609357147448, 0.19586799786456172, 0.11833413894618712, 0.24758144552188538, 0.23012787884762212, 0.12171172867378882, 0.1813783334387887, 0.10488490619125868, 0.10374962517450895, 0.15007691547995614, 0.15679333088619096, 0.15493284039680036, 0.1453771039603218, 0.1022677583199355, 0.19688122575321507, 0.09438112062672455, 0.14997470402909865, 0.22270562067147226, 0.2634434185681805, 0.14753307456210737, 0.12724376448820676, 0.11483875553934805, 0.050734900569002477, 0.15614097637514915, 0.16558596714129373, 0.18842638830744451, 0.15598808054722127, 0.1087938008769866, 0.11514263197539315, 0.19472075055443472, 0.1569581776857376, 0.1555737495542534, 0.24858707381832987, 0.22636071808876532, 0.11020666619222011, 0.1263295228202497, 0.15458600174996162, 0.07511387143524424, 0.11843851842587033, 0.1723683120742921, 0.08889243772794163, 0.10367362159154109, 0.09841966037187846, 0.1237169178503175, 0.09058840317471374, 0.11517978723972075, 0.24229211402275871, 0.19886000021811456, 0.10551322086323654, 0.13003510543175284, 0.2126104051187154, 0.1341514184229797, 0.24919458154228427, 0.11863633764967804, 0.11548024692362356, 0.17432319991771253, 0.13415262884190007, 0.09008449352075977, 0.0896802519057547, 0.231599978081161, 0.15721869354526843, 0.11670614082005717, 0.1494565681223908, 0.1516718032859987, 0.1804039002426209, 0.07805467613281743, 0.10045052115474978, 0.22191255113049863, 0.17896541694719947, 0.16090164591948833, 0.1681531124537991, 0.24963978587860064, 0.10806388762449065, 0.11117002175700282, 0.07796520472414072, 0.10768494223274531, 0.11679001978688663, 0.12986650480137718, 0.2368927722977054, 0.2627078822303203, 0.12064868974829875, 0.15034556719324282, 0.14115896256219956, 0.15514087923351796, 0.10503741897522442, 0.2286693546921015, 0.2043797709648648, 0.0926359876569721, 0.15420916310000807, 0.12380941530629513, 0.10943382137244749, 0.15401581782967816, 0.1985340451280917, 0.2069824321135398, 0.07414631004775725, 0.1581666507427731, 0.10934778969855079, 0.09953479327621961, 0.14758621042053546, 0.24782872338208461, 0.1247902529975099, 0.16360343884556525, 0.11196604839736417, 0.1394092790301769, 0.1696319839045886, 0.13621325214062968, 0.1404760258212205, 0.17474600384312292, 0.20320754918840625, 0.1310749165713787, 0.16000388280278252, 0.18356012120362253, 0.14696998461600275, 0.1606604201538909, 0.1845282724788112, 0.11971202468679798, 0.19816900423217207, 0.1490604700220208, 0.1579185608293741, 0.07473275035379395, 0.14679527060399133, 0.14677834006086474, 0.07281104177837411, 0.08350405106020552, 0.11212754739268173, 0.10288574612669407, 0.1802571944051212], [0.046135063523486744, 0.05343985743820668, 0.06186876280774033, 0.045372989899929494, 0.061545033203137506, 0.06362496957843823, 0.050635627065334594, 0.01610734526278271, 0.027179393782130173, 0.027929114237908396, 0.008752901189690156, 0.021001892502329523, 0.02675585058187285, 0.005783236044789515, 0.03644039704193992, 0.034059472382068634, 0.08185336907063762, 0.03680974335199402, 0.017405462098277865, 0.03055473695689392, 0.013721935158114762, 0.015635252197934015, 0.03227767061382052, 0.010165055958373893, 0.010855279153122777, 0.036464651385622646, 0.11624474138502153, 0.02762690021265899, 0.04278319136750314, 0.044337978301149224, 0.028680152364916382, 0.041570232865671, 0.058447084720096285, 0.03447129060664485, 0.04965071378636265, 0.02830630145786751, 0.0565556327872459, 0.016481745837917252, 0.056712144550176403, 0.07449686422102875, 0.01317358570128319, 0.0684975683989544, 0.08238305758324363, 0.043624095438468846, 0.050462640581592444, 0.03189920785746748, 0.10518350428150547, 0.055055008269846446, 0.05393588787785942, 0.053406835218230565, 0.027675960483329914, 0.013372550226537692, 0.02391812109929179, 0.03214437514543533, 0.10885472784960463, 0.07658511265030793, 0.03598809490100511, 0.04233478095322367, 0.05519152513795322, 0.03355044526078048, 0.04216267930103406, 0.018707083786026608, 0.018502034607433507, 0.008638970508810975, 0.014272878780179929, 0.05964220869505118, 0.06748124551508697, 0.03737201358401968, 0.016622704100765048, 0.02530711319958491, 0.010401018699931522, 0.010757527291594494, 0.0934261690464712, 0.03424473542479738, 0.030400410459767428, 0.04113159007242611, 0.013329773792065682, 0.03835172129554614, 0.04654993460844121, 0.02263449290166459, 0.034298097279163144, 0.09672006366834526, 0.022931198754738417, 0.02852590056136251, 0.034471846020389954, 0.10698607852382046, 0.0435129820459312, 0.035182082304550756, 0.028080707716365016, 0.06013414822518826, 0.06961141427558276, 0.016383092865468036, 0.005222263852990563, 0.019740668546047904, 0.06033362219891241, 0.050290845364572546, 0.029155128793190085, 0.08224373683333397, 0.07064041591459705, 0.07960349907197299, 0.05143690140797727, 0.012703268045199015, 0.03857989292291384, 0.017406082629496535, 0.033408060159173705, 0.022193193698542255, 0.01916345576905916, 0.008865367685024057, 0.019395049894228578, 0.024294898462211414, 0.02834189198760977, 0.028053038535759817, 0.05936175922773058, 0.03380077215091836, 0.043235478186679464, 0.021490114590814038, 0.04747098679804514, 0.027548178932779742, 0.05087603311685305, 0.021805355941215833, 0.08210911986327941, 0.02889615277038707, 0.06463630906035824, 0.012089119296550993, 0.015486272994519002, 0.03434439197242741, 0.05198874135291384, 0.007105297437163011, 0.04539033030009559, 0.05386624282466308, 0.03591334387179344, 0.06125469737115407, 0.09212309179166633, 0.10471811352838432, 0.025339331027240525, 0.01664666158537711, 0.02373470815890018, 0.06144268768689325, 0.05135037560736941, 0.003001554751761198, 0.08317802702226947, 0.046741927733584765, 0.037593604516117804, 0.04316565693326054, 0.06288905785749517, 0.0667549098931974, 0.04467897552756533, 0.09095968768721627, 0.07441921354902369, 0.033568471309638796, 0.02525129411820202, 0.027999900762111913, 0.08410193671983096, 0.09493254305374238, 0.03459564582895368, 0.010538187700383847, 0.041845633813570586, 0.05114819734327255, 0.06339584800204442, 0.03327736555929146, 0.04478106440435495, 0.013788810803464824, 0.042575206156940236, 0.05663521400082016, 0.07798668582953754, 0.04534818014250167, 0.03266855165542614, 0.07639542161937683, 0.004834124448543956, 0.016018998088134874, 0.046874491588002255, 0.062376839980002374, 0.04093594270788374, 0.065025458743255, 0.015478960685281744, 0.04179329468658374, 0.031818697762285034, 0.04384185593094557, 0.03497228912648655, 0.07337793918146242, 0.03062067989019617, 0.05235842857209425, 0.025944998224956856, 0.01282015774068573, 0.1344710609485065, 0.04508252383299893, 0.019450468694671028, 0.068737032162326, 0.03425958603920956, 0.020518630833154725, 0.05453496480420713, 0.0655146824917005, 0.024952042937999772, 0.011513336231150936, 0.012405809510739581, 0.04362672312004913, 0.07016858236203272, 0.018194917619468707, 0.007777893427579154, 0.017406718482473688, 0.017449523645242857, 0.012198243733315219, 0.024276711534888997, 0.03493884938859171, 0.06205055164173246, 0.07731160148978233, 0.02708276711224068, 0.040623432460932, 0.058041805055953806, 0.02051282197146887, 0.030692582987549327, 0.046385784948905634, 0.0459363249941699, 0.04884849332513348, 0.02115980812138127, 0.011136231365643684, 0.022287129484597715, 0.06466863797076287, 0.054067559239845124, 0.031171066183296424, 0.04876810388879911, 0.05018050572083843, 0.005034188788774754, 0.012786885584524323, 0.07908393058084673, 0.026753107987103925, 0.0486768436648192, 0.018965358838378903, 0.04780976619992045, 0.07652819231753388, 0.06963335503373416, 0.11581876585560462, 0.037512855018459024, 0.03557832979206597, 0.029704758574465112, 0.0487465538354891, 0.06596487406040392, 0.023828134496485995, 0.02902883536843283, 0.049824320801323464, 0.06019596002935883, 0.05823172208282256, 0.1051294797610852, 0.031015707382691965, 0.061694611870353265, 0.05390201146984774, 0.04215001969808533, 0.027906673607386412, 0.020190888843048486, 0.04260080498493007, 0.019279171434801914, 0.012753341467149798, 0.04789465257237035, 0.0357490218424749, 0.026069181077482722, 0.018892025071827155, 0.0669834032774933, 0.03201125779249255, 0.026345003373740662, 0.07499297509991354, 0.022813004794560617, 0.05451238819307858, 0.03877125402551986, 0.05256825239367543, 0.04280151619065193, 0.04868722032575358, 0.022656443235915036, 0.02808661425426122, 0.019403702857333328, 0.03030331073058469, 0.08503627287404192, 0.01961045083589852, 0.030234517950204112, 0.12050576838514498, 0.0370971144237105, 0.09163996610309809, 0.07977582288966065, 0.025435781496907436, 0.13027153548694428, 0.0793564280555133, 0.0801486702215287, 0.019592784848364613, 0.0571466351468717, 0.04351207423174093, 0.011236387785644302, 0.012119165264941271, 0.01731421911127625, 0.02733463192388656, 0.07635373877541674, 0.0036485550264197014, 0.03458631870847556, 0.04271960223934824, 0.02619269360307484, 0.03264271917061941, 0.022787419373109456, 0.05610698488570991, 0.034935264097106074, 0.024040800504266255, 0.025462100447546092, 0.045222135696319804, 0.02646769427003399, 0.020279010021758657, 0.02394848307895084, 0.039496877185639837, 0.022219591173193148, 0.04727985935225602, 0.02947842364289588, 0.07495723709824585, 0.03920990064920437, 0.08154593032574461, 0.0302282513509835, 0.06182094742994636, 0.0878519217874254, 0.03035280192571302, 0.012330617023361547, 0.03173659037378046, 0.06680370969397408, 0.028815261546462297, 0.05532392045302738, 0.03575413930980909, 0.042900624985416094, 0.015155708928021695, 0.023491651443163716, 0.04565919651800106, 0.026327410164559563, 0.016222057353344657, 0.030288278170290495, 0.04671977247081457, 0.018277928991723928, 0.07024489238017029, 0.04475227865060011, 0.07480117732719069, 0.039161016578756036, 0.020217516144076665, 0.02999603286415579, 0.045000728625323505, 0.07626101149306183, 0.03552824679401613, 0.022821828212228515, 0.032780159174674944, 0.09289929973742656, 0.019200898316358368, 0.08176513106351899, 0.019034655321569696, 0.015408194270886242, 0.05657690321846355, 0.012927745213551868, 0.09472457316493797, 0.027897070695255554, 0.020996493497683157, 0.03467502785966762, 0.05771155987355498, 0.13901138828406412, 0.09050929693565254, 0.12153555143384204, 0.1341368321089014, 0.20673150767482099, 0.11944565591552567, 0.13860238926304927, 0.10530661461093735, 0.1992888255946098, 0.14984279901029604, 0.0823351770879761, 0.14048379395277272, 0.09558680512371565, 0.17221048264013183, 0.17205873594409035, 0.08302589728226585, 0.17943636183777165, 0.18802180195287352, 0.08416206696100774, 0.104180779458294, 0.10507860386203374, 0.11716998407557128, 0.08087118306467611, 0.152351307953077, 0.11024130102727683, 0.15086771740067392, 0.18284021305941767, 0.20789145672273254, 0.13107382872652623, 0.13735138300445773, 0.14599616429017437, 0.14040577555856398, 0.1986095354321503, 0.24031078082419213, 0.14024318105751468, 0.11356541015688451, 0.1141684745708781, 0.1042786778341378, 0.12807629521816008, 0.18494243493243573, 0.10748702341750746, 0.17397256147476936, 0.12932782241654012, 0.2143349303233047, 0.13696430941983578, 0.16737315833808916, 0.18952230772664472, 0.13192781757923866, 0.1812591914448046, 0.09764404231381994, 0.10348137948782214, 0.0653695011691701, 0.05949534963996661, 0.1763483993108234, 0.2507817165385331, 0.2283136447470996, 0.12014613606997075, 0.1299793648743822, 0.12004010950125034, 0.148120112416725, 0.11881071458300276, 0.09747697385929285, 0.15230388711056403, 0.10293296012546747, 0.15770364252309646, 0.23711853840899086, 0.2263781082846465, 0.07317026040606922, 0.07369708374983842, 0.12294935903722241, 0.15604673223870416, 0.09180116632412519, 0.11043924282515243, 0.1735721732820234, 0.10688909179260654, 0.1253817954491223, 0.16896458342671397, 0.18051076950805803, 0.2207423518261602, 0.19682482636022955, 0.1201310211552247, 0.25798066008475523, 0.1393006937277894, 0.19365418762449296, 0.10803426300445873, 0.17986530978833476, 0.119747142157247, 0.15978035366823598, 0.15377399451549978, 0.27329650437158926, 0.10096405287303271, 0.1728414786198447, 0.14567247682040738, 0.07538802365982726, 0.12575889456897013, 0.12871944135235203, 0.1355669650459482, 0.25371698242041374, 0.10488528157434157, 0.2089678102563466, 0.14563285475296361, 0.2920333602495732, 0.13806838001455032, 0.14199502495748384, 0.22655933404401427, 0.06942067370419541, 0.1483226507421463, 0.12462658597336662, 0.08793265979376533, 0.152632906552284, 0.07402116958532604, 0.1399562198428377, 0.18024979399577265, 0.16358215692302874, 0.10669855806495875, 0.12063269383243977, 0.1307813976440699, 0.1121907190029179, 0.1432367002651576, 0.2158423308883944, 0.10467767174686156, 0.09622414431144154, 0.17803173962860339, 0.08484329532591567, 0.13065827199287955, 0.11153225111024034, 0.1584722125722516, 0.09690438442292715, 0.10754132372958046, 0.13927783366412888, 0.13251818025544768, 0.3539308436935948, 0.11726180737417553, 0.17101567659166553, 0.1346739669961314, 0.09933577129437078, 0.1523932282842936, 0.11947254560166791, 0.22496248505288557, 0.08528175808849835, 0.19153030078497627, 0.14726733398293296, 0.16318866352160133, 0.19717724212715704, 0.13272946730496424, 0.12265830691302977, 0.08835220018461828, 0.20306032241111804, 0.21512374041541932, 0.08223789924335095, 0.10821342032643096, 0.11997999458183205, 0.15765200819699995, 0.17096621795527397, 0.114936247888592, 0.21967566632215055, 0.13280472778264554, 0.1095639720499035, 0.15951157938088142, 0.0993607764042193, 0.13481396190341444, 0.0855264389106343, 0.1980013841943395, 0.15102183896928065, 0.2211744100936959, 0.2022456338689212, 0.24383124594967215, 0.15986310648581675, 0.07511661403001317, 0.1980354291416945, 0.09754401421354664, 0.204181507410061, 0.11136775671113884, 0.16816103380293618, 0.20830155891035834, 0.1711756204284968], [0.018957801381005876, 0.04036402359845177, 0.039369775538122466, 0.026655567757364725, 0.02315433143878416, 0.004083843790971104, 0.02513430100084553, 0.029951050096461852, 0.06860434573384062, 0.031796848934684555, 0.037190194106510574, 0.0493688240737444, 0.06321511253894818, 0.04240152636362661, 0.020238131570119052, 0.006500862683394865, 0.022751361529733387, 0.07556553389276228, 0.026700163650656902, 0.032683517183026964, 0.06979473145498384, 0.07381722931900332, 0.08038436483231284, 0.017112906526533828, 0.0289718096985692, 0.03059658259453793, 0.01607530172012987, 0.023501110713808768, 0.003918009216807062, 0.04278670771107559, 0.018558163954425725, 0.055231848175847725, 0.008531757461417828, 0.02513817740574239, 0.053672231057839054, 0.05390298057107195, 0.045714714909873666, 0.10364409656293931, 0.07154200947092426, 0.019095457804900025, 0.011808846987062886, 0.04915610827024906, 0.04767404606325492, 0.035566769525288575, 0.04361880177091207, 0.032496469155434644, 0.04757799012886901, 0.02213366100594642, 0.050149640038369164, 0.03775072148850849, 0.021145150944169973, 0.03870499891138846, 0.030946002957681497, 0.09380678450989147, 0.058321496096229365, 0.05006904375829524, 0.039315885083088954, 0.07287467304136484, 0.09363029317389573, 0.03365087938765365, 0.03603092304641201, 0.07792906069587316, 0.00693049484623536, 0.01923117411112593, 0.013055366843247847, 0.05414960342609594, 0.020582405737631267, 0.014823775479359733, 0.04541677565524175, 0.04973896711523976, 0.0025752064726886252, 0.027235957884019422, 0.03203850945517902, 0.04114284773447341, 0.08179915302823629, 0.042465356809477654, 0.014100487929798905, 0.07500556192450947, 0.03013336561590193, 0.02891513259871112, 0.03606373459220894, 0.03553443678444432, 0.057189141535350395, 0.0300640978610083, 0.12064863612214405, 0.04653545937711193, 0.02447439669330995, 0.049527013569229075, 0.011374070065005893, 0.06840627370101791, 0.044689616488833586, 0.021429258481329008, 0.03868444860281964, 0.07569133319080838, 0.05034756268404665, 0.03843876803594251, 0.051030154685459794, 0.037349279924866655, 0.010406953966124885, 0.012524945759064248, 0.03990944234594222, 0.05597990239039064, 0.026658457824059074, 0.11215862757976978, 0.08021534285357884, 0.07561938221295995, 0.04541147432680573, 0.05724720716957123, 0.012497819543275382, 0.028870730142619823, 0.03656806942496089, 0.00936851795432308, 0.08171607079284807, 0.031089318856116266, 0.045211211282519564, 0.038306162046689185, 0.02822392976902906, 0.05136362126758022, 0.025159773424327857, 0.02995568684362356, 0.02132435040097804, 0.0574344773626616, 0.04441479776775645, 0.05366554694069971, 0.029911558263965195, 0.053922630726329746, 0.014005537077243772, 0.02972979624305041, 0.029589770692250425, 0.03235220330797377, 0.086105432842047, 0.06184009962805337, 0.04825320470357134, 0.030400567507791906, 0.05782928077443954, 0.03738658074589987, 0.06274836197976144, 0.03637357885318418, 0.09659902943718819, 0.062410210769984036, 0.027844101460950992, 0.007652503028962642, 0.023148685370782213, 0.08172526384793943, 0.0036411139186501747, 0.06470662827092795, 0.02379477136738358, 0.034307202234143214, 0.015769524428422655, 0.02753028503408836, 0.09071761922490212, 0.09073476427264753, 0.025257911202647997, 0.09875387388972506, 0.01918552293171806, 0.022517107164246902, 0.006509186707497124, 0.03821254227190249, 0.05995425545880872, 0.04063726800884451, 0.11343913588432536, 0.038574120450404384, 0.02506356044191747, 0.020370394735026266, 0.04790088469763437, 0.1328561935693987, 0.02641163770139458, 0.005732378819131203, 0.012284602909799547, 0.07306011994519541, 0.0032383355315804725, 0.030419263883583972, 0.06463711345267874, 0.0974001122578498, 0.036122275200942834, 0.032107283083361485, 0.05451136163526005, 0.0387619728703172, 0.06429222066916766, 0.04055695518130257, 0.02738928846684435, 0.027585123522928166, 0.03556399245656306, 0.005968502917957883, 0.03207800703333511, 0.040021543991902185, 0.08883906438225701, 0.028381117604552742, 0.03885262022395769, 0.004109479486942291, 0.028879729760510307, 0.006058414827191061, 0.02767873755205543, 0.08095575917151668, 0.03919418052499814, 0.03946026201329885, 0.050538590538405606, 0.08897329064747019, 0.055223842557038993, 0.026407228865390344, 0.037777538396297924, 0.028506792413311142, 0.07032429739352196, 0.02035461332378609, 0.01702151989804641, 0.007404217284338008, 0.011899670540925958, 0.0329493152187957, 0.02863008660384484, 0.007150501412745085, 0.004001673918420209, 0.059580806747920094, 0.06414125155236933, 0.016524321174309138, 0.028470749891693556, 0.04119117639117664, 0.025936260992180438, 0.030899947666893565, 0.07912296276058882, 0.09464165180801384, 0.016011687694117427, 0.009074976044376532, 0.020675763127303893, 0.0637687336383087, 0.04378391670123224, 0.009920335874231833, 0.047831243474877654, 0.06057007523674158, 0.047037426998177846, 0.03423189196074682, 0.09926252562793032, 0.029633414721296682, 0.07921844795947114, 0.0919213118932901, 0.072461667380506, 0.059744504415580345, 0.05642411081240543, 0.03688011618871843, 0.04542835124377762, 0.011398035210497197, 0.04066641765436338, 0.009394316922783131, 0.015484075279786222, 0.016263680825490626, 0.023471486093776844, 0.0529217713272139, 0.03710598189143404, 0.03155287674387857, 0.06689096710854961, 0.09429695820736309, 0.03411206048763087, 0.027182308746682062, 0.03849494909386962, 0.035060580759759874, 0.04749034583989171, 0.044436462734255104, 0.028530188738518668, 0.02431927346474221, 0.0354352820244047, 0.032831969700994036, 0.02833894254910129, 0.028395200215820825, 0.050644509854816624, 0.03997947810397994, 0.03404318535279843, 0.016548133102215586, 0.03857549174778885, 0.046057389868843945, 0.06607234853530122, 0.03569238496223285, 0.04431745097521813, 0.036059191690817956, 0.014375209932275599, 0.06573005278985347, 0.028384218345426267, 0.03306349679347008, 0.01093908342637963, 0.04233334070792602, 0.0036414696707300124, 0.011634244057800502, 0.05505500443940682, 0.014278351520789007, 0.021717003020908565, 0.07694210962302263, 0.054318548796037515, 0.032325784765904954, 0.028376789207780556, 0.028588147120430108, 0.03302734127388366, 0.041212182522060416, 0.01818350482461674, 0.09538433574620755, 0.04402524205825983, 0.049048024755451954, 0.047092945390050454, 0.03160843152492758, 0.01653145345288419, 0.03586384310056606, 0.06840780587686647, 0.07509154763313071, 0.03040830116538752, 0.05208098216943684, 0.07674190020489116, 0.016779035833033345, 0.06905599286960018, 0.013061977224424483, 0.05670649082129521, 0.03540141710771188, 0.027267484317323374, 0.03391866925202551, 0.03832380505158536, 0.03978029907410664, 0.049636422416135195, 0.01601940219951493, 0.07413506387702881, 0.04908645555617348, 0.013611149268164752, 0.028835356032716173, 0.03273672581980786, 0.07247620772930884, 0.036090781326375665, 0.028732518304980574, 0.0486130936582002, 0.013240644250125175, 0.044821601946868246, 0.011586715005368236, 0.016886548612326864, 0.05283058005114717, 0.028079503043104085, 0.080543358720118, 0.023381553117125746, 0.012412165167681392, 0.018714585702025124, 0.1416245448373018, 0.03208782445008476, 0.035284554225302515, 0.022524505658375642, 0.04167082021012903, 0.0259913063247598, 0.044097392218968565, 0.03671484037993416, 0.09971310790147513, 0.08177648448655683, 0.01908121239994803, 0.03617131631941565, 0.06862684573617674, 0.01074131878633653, 0.05113644938495371, 0.11088984808133495, 0.0652280583557102, 0.04203531718362243, 0.05096204563855164, 0.10105655798988958, 0.19313366152346137, 0.18787250673818975, 0.11654221332601963, 0.19510186397500578, 0.07225477001479558, 0.10194781702011825, 0.1637050680696003, 0.14163183799434093, 0.13556572398351086, 0.17010956311658507, 0.21358166671087667, 0.1439932120903846, 0.0999540348927821, 0.2131432805570864, 0.04129861256167774, 0.23041107090971163, 0.11854547196097913, 0.08798811689860399, 0.11429824986525121, 0.14444129691729624, 0.22400763306406238, 0.1209887638387661, 0.15678036867851214, 0.12506462738759097, 0.14221858473554735, 0.17401895575946377, 0.09007746083361488, 0.04361555355811312, 0.14549374850767274, 0.10376257206042928, 0.1623066818161357, 0.12214149633843092, 0.06796589571862452, 0.10827099949481989, 0.18670422265366202, 0.31518107460391137, 0.12899999807198204, 0.16750019103769334, 0.10283143049286259, 0.10648383128066218, 0.10443182647108071, 0.16560855141330152, 0.16822673350332246, 0.12571450743463733, 0.10870372425884971, 0.20362070040597072, 0.2278795486856853, 0.16527773932583872, 0.0993384066368303, 0.1724102630490257, 0.14236784930671417, 0.12302319459136456, 0.2509824928617285, 0.16158039982040084, 0.18842294091178527, 0.1748187515524126, 0.1827826951780627, 0.19691956079294606, 0.1561392296946818, 0.12656193091383866, 0.12801790399657142, 0.09192981546924961, 0.09385649595529803, 0.16548747887774823, 0.1355740743418855, 0.17176129464660922, 0.0977537997307316, 0.10012750784235616, 0.11124299929266977, 0.16432979745009255, 0.1103544598745723, 0.11932410840545932, 0.17736983966202508, 0.21442227966843114, 0.08508464366558098, 0.12241182578427177, 0.09959403485540422, 0.07766566434574705, 0.13281605056216642, 0.09830673135096028, 0.13002474792301655, 0.11327287182211877, 0.13481276680625257, 0.2471754495655337, 0.12761584573215054, 0.13467683216496823, 0.11081710037204529, 0.11568773417703568, 0.2581996693005485, 0.11736164395246776, 0.12641282722113595, 0.12648351415390932, 0.16179346419390173, 0.09824346014929396, 0.23310486587785909, 0.10625978886720636, 0.12214505864727883, 0.19184931511840514, 0.15580455652408062, 0.10268169860806196, 0.11889037240536944, 0.08069681379223063, 0.18683382940869178, 0.15292556746111763, 0.1710355029471459, 0.13652333388886145, 0.20033930067814168, 0.1468565576379338, 0.1161821673233663, 0.1342789720623724, 0.14325793622241867, 0.22045198918109943, 0.20238760528304886, 0.12574598598744602, 0.171032760352377, 0.1695429951313042, 0.12153936655170496, 0.13242317003107842, 0.09820655003310212, 0.10657918624459736, 0.21108224357087768, 0.20899659984054106, 0.1633723560840853, 0.12444391996870119, 0.21711664154164254, 0.1948110569989489, 0.18087034053619833, 0.13851617372805072, 0.11614232309042447, 0.22606785799707138, 0.10237047538882303, 0.10688597381475473, 0.13520777706177006, 0.11991563553531324, 0.1440716594938309, 0.0979042977034565, 0.15630648201031072, 0.20796808083691906, 0.25714571617784043, 0.16508031846775165, 0.10241997232961078, 0.13444171978100655, 0.1474219918130867, 0.08236815717311637, 0.2503728707351031, 0.1072492297258108, 0.14600587828505426, 0.22413002327084544, 0.09045835974956713, 0.15681289677177707, 0.2430044072529962, 0.14835527076596214, 0.2231166728081242, 0.10428468396346416, 0.11297536923760369, 0.08977525446924473, 0.1853399426345864, 0.1199071779246292, 0.1494524159258412, 0.11088686033843026, 0.18540588748310843, 0.07594493893726219, 0.1346823173545061, 0.11348069615421758, 0.3539585147894198, 0.26343968005911, 0.09788291618948984, 0.12355119004965791, 0.2598699861236157, 0.1496188408665119, 0.13029514631677058, 0.1944133960792134, 0.1730152273610715, 0.11141965916800885, 0.14384042351476609], [0.04314881832068486, 0.0108250723062684, 0.007671896544765802, 0.006530150224740107, 0.026978684491628123, 0.038867011185615294, 0.02807717030537465, 0.026369207921708306, 0.02568438085877607, 0.010199324028836864, 0.04597128541659444, 0.046228028293098175, 0.08073914015004713, 0.018549283080163504, 0.029564980087020708, 0.023053014395578254, 0.030324251743994897, 0.05534509129281487, 0.02176926170866336, 0.05138985977898683, 0.04780795823241915, 0.06384526965238395, 0.05383791672366281, 0.05038015206434554, 0.016634040286824588, 0.012073064008877884, 0.0432699368215136, 0.04873581711323031, 0.036183190682241996, 0.018784462496818557, 0.0668675554615836, 0.05393709063590054, 0.03406330665212966, 0.03340407650196745, 0.07309404997936181, 0.04587440976812955, 0.03880605739991992, 0.03382252904796793, 0.07017401392541586, 0.015012544331951969, 0.025670106725526914, 0.0735559243889105, 0.03488613870896159, 0.008535881887280173, 0.03836453794651935, 0.03870327904399845, 0.03870922005585125, 0.020900498850331194, 0.02614769934406204, 0.035338053975494645, 0.0245188795886333, 0.008186550581857802, 0.06905183301217134, 0.012373235452199175, 0.06429091065881715, 0.014539510894176221, 0.009084833680742211, 0.015267433275678947, 0.08111103753288908, 0.06579054309235466, 0.04876923386848742, 0.07270741306485669, 0.02113628539166624, 0.04314799477616626, 0.04031688620847079, 0.019445240144587813, 0.07083567640473766, 0.011384536741271375, 0.031447740752370126, 0.04445535063202824, 0.057638444442061655, 0.01930120412350422, 0.0476893256869047, 0.05383264220830414, 0.010928386923736863, 0.009645475975928769, 0.046122403920538006, 0.05119497467192912, 0.03552987090041561, 0.04337396390075165, 0.04217925361327587, 0.07778587886282513, 0.04922042135149241, 0.060688420499284426, 0.08599292516948716, 0.06226729323726989, 0.029542064481985666, 0.01745026866574922, 0.07179584504375536, 0.0768767086969268, 0.05921291600492212, 0.02175667105362781, 0.027707582677624402, 0.06609582913018043, 0.06520297663706927, 0.0118714181758884, 0.031056649036585327, 0.01566358404459372, 0.0492866573134257, 0.02221270595797368, 0.03266632617000611, 0.042242436714830904, 0.05972363235008332, 0.03457749337558785, 0.012309516089097148, 0.030304450286372058, 0.05826432678487994, 0.032032708254372405, 0.0466163850749933, 0.015146046644076707, 0.07986695670913305, 0.08054975555428574, 0.031724775382768244, 0.042705115516700094, 0.09159007845746894, 0.054652268187172955, 0.050417150280648665, 0.045567265967087406, 0.05671092263993718, 0.04316993553431765, 0.04153224256550593, 0.12115239255851316, 0.025120235626555742, 0.06502111502472432, 0.012816844410413216, 0.028916668604999304, 0.06933629678021516, 0.02079082187265158, 0.027559639608126976, 0.08508770035639887, 0.03455477886863294, 0.04561378665628933, 0.017528670103920084, 0.05429577683248828, 0.027292849488496303, 0.031895595752904495, 0.07496914976546842, 0.009080984088922701, 0.02235982739817231, 0.048194495555494106, 0.058316635268349806, 0.04886106865841055, 0.05955744872710878, 0.09671608767201824, 0.06304335945676412, 0.02500218147742412, 0.026107805315405134, 0.04145813505015066, 0.049681338151135755, 0.012875064219828817, 0.01786358267699759, 0.05807677696969721, 0.012099972847218235, 0.012594456746873837, 0.014723088543471551, 0.056677023249287764, 0.0539040990594414, 0.03890213248650393, 0.009889608087588944, 0.03246339330930383, 0.03353822232794858, 0.13006596345334284, 0.048148426858167497, 0.01259935013349018, 0.06590352573942754, 0.022348044965896877, 0.04133618917436369, 0.031246949107416218, 0.08549889804975641, 0.03714346657356909, 0.035979556851089, 0.046554178735541726, 0.04557430631511154, 0.007289669902679781, 0.059998064196758696, 0.02416427664068197, 0.005188973502240955, 0.00945314672970844, 0.058071264967082016, 0.02936971385122067, 0.06214948040583442, 0.04374994836266964, 0.07835488300770521, 0.041093917698749614, 0.023052112327047417, 0.0688744453533042, 0.05825611815277127, 0.010979965708458857, 0.03182503713985845, 0.0359957174758517, 0.035182833070716554, 0.03759202254455417, 0.030566735809007962, 0.04615333089004121, 0.07730587115210873, 0.057042872367967526, 0.023640454446356145, 0.02148303976883331, 0.06436327532414468, 0.026632347632379785, 0.01849538687947056, 0.008985704776170033, 0.04264127357953018, 0.08779680942215266, 0.046596190997309266, 0.03856949710978135, 0.04092350910087267, 0.05480761932689817, 0.028756255539314404, 0.010401031148860292, 0.044488683117613684, 0.06335433752786729, 0.031178502981821378, 0.01551001693212217, 0.09982198431727388, 0.007809716241148812, 0.029809159121566245, 0.047378784285918366, 0.06366212101232621, 0.028291711313349586, 0.03726300310283419, 0.041211458568971966, 0.039083040319383144, 0.04993301335602038, 0.08217288902209652, 0.02234761021099985, 0.0559747236360225, 0.04186133478557871, 0.02389233649498032, 0.002565774733328351, 0.040404224062278386, 0.023976640640607765, 0.00978215946815908, 0.03453508274809968, 0.06511198837430247, 0.012520837612570295, 0.052069019706499194, 0.03189603433824115, 0.013501754785407216, 0.03351797845454947, 0.047060739053713704, 0.04029840816773715, 0.07429234938876284, 0.05172233044680569, 0.013210919081053187, 0.028672571924905625, 0.06153442288538622, 0.03136874751127776, 0.05663891037505481, 0.03716517750534319, 0.041680350343907074, 0.05744822098002319, 0.0819048578400285, 0.03251578606244537, 0.07839868025433633, 0.03854084542141326, 0.02170117181395331, 0.013747877768060614, 0.02461623404205086, 0.03315925395356552, 0.01671737533122782, 0.042642817246697606, 0.0307557909869619, 0.05839361561342113, 0.05424804189392636, 0.025706541867205696, 0.034988392294654926, 0.12397815383249715, 0.03371619987451742, 0.03812528102688732, 0.03600377289037551, 0.02219255401512548, 0.03150668738770389, 0.020108093890631874, 0.06921825029196278, 0.020603101602905703, 0.05648196960288671, 0.008465907416276394, 0.03796116967174796, 0.02869145599223914, 0.028904836377008792, 0.016591313648067655, 0.07198047989438619, 0.02841160407349948, 0.016634285434960358, 0.04973104193566307, 0.0076057673563369585, 0.017864848637292464, 0.034742359327332634, 0.0366557328661363, 0.02425997251374347, 0.04514708972325729, 0.06071408827518744, 0.04439340859291054, 0.05235804169769249, 0.015005710827667388, 0.025532549893062924, 0.03273325927195049, 0.017685005666628, 0.05171800971091275, 0.04508702459955408, 0.07719188492985503, 0.05698863717336809, 0.03138513796241774, 0.02050848016815801, 0.08839477935144979, 0.033863648817303686, 0.01703992324520744, 0.003457180038470054, 0.06489094136463058, 0.013698258253204967, 0.021439192726487116, 0.024057675506018346, 0.01781461433687758, 0.027122061677096833, 0.04706544283356878, 0.04251779169745503, 0.07620397624709914, 0.020361178697297172, 0.09988304918571826, 0.06077567025298073, 0.023575919199614756, 0.025368476842319774, 0.11134298908854685, 0.018505506900950305, 0.03591143248242236, 0.03370596110940941, 0.017618942074477673, 0.016868128028187542, 0.05552697971823716, 0.03191994968801737, 0.05878697111902218, 0.03485303604975343, 0.0186559684844988, 0.02832525830355383, 0.04750767474873893, 0.03700415348453868, 0.07963986526573859, 0.020539654201016794, 0.035852501168847084, 0.013158161478537708, 0.04218552021249648, 0.05562992661350197, 0.02157623628004184, 0.07336929004879729, 0.052058719654357245, 0.029868274296243346, 0.022310068072270484, 0.0315600588181687, 0.07339127677222414, 0.012624775634087142, 0.02682924180501892, 0.14465975454978405, 0.10094112386145901, 0.16963359268922962, 0.08939874523709859, 0.1196170297841872, 0.17099784206478827, 0.1784286651039316, 0.11964627902113623, 0.12150680015404379, 0.1285960705530259, 0.14967212994252482, 0.11448142914882592, 0.13068071836906095, 0.12228231862067215, 0.10121515351197413, 0.12250390955277028, 0.12855885400166436, 0.15078004629861924, 0.1424018789323107, 0.13115667347465793, 0.12103114382273729, 0.1308209124592043, 0.17932757735252383, 0.15127181345897336, 0.07767288089399377, 0.11580826279016272, 0.11653552537844067, 0.20499256469549673, 0.16811172838412947, 0.17339198940223263, 0.12069797984534696, 0.22411509987808045, 0.094785752946571, 0.14974067948998945, 0.16653663629005033, 0.1066404196523851, 0.1145575782884994, 0.09981291383625039, 0.23159702098177326, 0.11170588493827852, 0.23211754708280488, 0.21959435374986744, 0.07562977802609244, 0.11917118193401445, 0.14003532608189892, 0.140268400671982, 0.13839807361364365, 0.12397615434301477, 0.07243556676492577, 0.10335151992377736, 0.11702540030162181, 0.1072762726295379, 0.17742436980047535, 0.12198925168523866, 0.29073064305609275, 0.12795731410264008, 0.06492984330942554, 0.13958852828270005, 0.19699572525437803, 0.1491893106891263, 0.13577207742679503, 0.24764271723406933, 0.101718902287464, 0.10614826944806885, 0.12711867765193025, 0.10515443124477902, 0.1592885252208479, 0.1530654091508158, 0.12519343741117947, 0.13839539230590867, 0.10667573630569444, 0.09691377666087882, 0.18242289432354514, 0.14148986658021329, 0.1088964949632364, 0.14921886636124504, 0.14041323725494648, 0.19754703276820723, 0.18189567261405531, 0.19290100062085738, 0.1119449196924125, 0.15549021532698987, 0.1958339375954482, 0.12018666978204444, 0.2018331721304886, 0.15882778462142716, 0.11230892636963438, 0.12987241900015262, 0.2562496231328095, 0.1672143789549028, 0.18561927361353753, 0.13657403358769032, 0.09445910837741629, 0.1717300229375401, 0.12659104991584055, 0.08061812124064854, 0.155812140794531, 0.23414858406589878, 0.28552430952268265, 0.11967677698140183, 0.12757669097834057, 0.09369573240438778, 0.1816170464359945, 0.2576233566768708, 0.0686638477829195, 0.10600018465230543, 0.21580344426535794, 0.12910980911504838, 0.17394246954110362, 0.12920494191348553, 0.19034542323600864, 0.1706062332396546, 0.17645278645138587, 0.07383153218054965, 0.13170202082443622, 0.12077817392926063, 0.16203950099166364, 0.13687162810275633, 0.07122677195096208, 0.10756471239390875, 0.12427327388356771, 0.2904797339391324, 0.12605307999277307, 0.13739370170139498, 0.16524286700352547, 0.16852397561794327, 0.14900197154812275, 0.11785602347264368, 0.09078892668889416, 0.11932379430941037, 0.28660584181066484, 0.07482616711528071, 0.09363042340884287, 0.1402094272235709, 0.1468093513000396, 0.09249916435369561, 0.18370929384423842, 0.12976725044990742, 0.10819883401235265, 0.10475514621864404, 0.10820743717974234, 0.16810909304166996, 0.1531802763741824, 0.1955175279609619, 0.2332036452548158, 0.08806317819342499, 0.13169112705415295, 0.17577066176360653, 0.20019867757876075, 0.1211241239141072, 0.08453398732648743, 0.10566213303395819, 0.14613652691966103, 0.11647594672056938, 0.170474297577335, 0.20280786579655063, 0.12866630549392394, 0.1319113773323836, 0.07650681846444646, 0.12056442773750714, 0.21573858726168835, 0.2604682701489618, 0.1179051756738655, 0.11315008324961509, 0.1680667743447327, 0.10302217106424993, 0.1968184831522165, 0.15543948498464402, 0.20970999623738953, 0.1659631275481755, 0.15163417304715804, 0.11314573187020519, 0.16650902648125926, 0.15594689566041195, 0.19508871790622512, 0.14247340090092153], [0.08022733979047307, 0.0567556353616378, 0.03102069461507903, 0.07359937689597569, 0.03764710809674956, 0.041994362123190396, 0.012887731483656795, 0.03431197496191148, 0.03950185675714766, 0.07154331948127478, 0.018806824603328304, 0.053498187372761394, 0.016980620378988887, 0.07961139743847233, 0.04731268238937182, 0.07028150372207165, 0.09646573013836339, 0.06125697265228918, 0.021507640767301765, 0.05863849178797776, 0.05870030742258795, 0.017278117217844533, 0.036126618919473504, 0.017542701004253283, 0.04704656259667489, 0.07321697644769184, 0.058306656973136056, 0.0301001250608674, 0.042257666542765596, 0.011768656099335322, 0.13041361415338132, 0.035908605617981766, 0.018089015540035985, 0.011241857653423663, 0.04425664274622837, 0.03374285590384276, 0.05437478731055895, 0.050859665648350795, 0.05345518302713191, 0.02204797407161565, 0.04008624011710767, 0.06719727204331467, 0.01495211435887482, 0.021239883461666685, 0.03871916004666879, 0.045558069081556414, 0.054088913940734444, 0.019092104255011486, 0.00582947280265451, 0.03697537539166309, 0.023759588779461, 0.017062580295568033, 0.0656117228490691, 0.10689676033272859, 0.0406331502862515, 0.0016622556628839624, 0.027107423652083646, 0.037174692317362756, 0.09693335020734418, 0.0062295243955187264, 0.011961206553443786, 0.046379349810341676, 0.0412388998384197, 0.037575923206825415, 0.05370434163318527, 0.011206766996051998, 0.05244200110375401, 0.023179777049189134, 0.009277905074639187, 0.023358901812424584, 0.05827294910446771, 0.05745546051090764, 0.03286268216587844, 0.06227542909102575, 0.03549925419652174, 0.025908419441792275, 0.06484249396429909, 0.017881999430697293, 0.09864622321460517, 0.0430114281123444, 0.0024625802959030076, 0.07092254311447183, 0.04584225322750788, 0.017773649700346495, 0.01873413818107257, 0.03394697620082767, 0.024747824964804516, 0.06393470658710407, 0.05009411781605694, 0.041792689477123564, 0.09420220845288808, 0.021934888002672986, 0.04720284070278849, 0.007335100353004472, 0.03061941967556073, 0.03652609546758956, 0.04556151647721568, 0.005191444614601712, 0.07949082286006982, 0.13030050893224057, 0.04513364104974655, 0.0595073925421363, 0.06353057605484802, 0.09999021722544586, 0.040132270510038065, 0.053988705809798934, 0.03215441472768303, 0.034606397872970956, 0.034863339932335, 0.025682592043472875, 0.048479932255201766, 0.036751355960844986, 0.08586856611673871, 0.10685384408721041, 0.041464784693333416, 0.038364928651360736, 0.061337641710715915, 0.06189751025709895, 0.012946216551016175, 0.021623940575086785, 0.053625534168414535, 0.053524548458235885, 0.020861880358068213, 0.09242088548959264, 0.011222224735144165, 0.05719212544781547, 0.03166210364490267, 0.04759089487995352, 0.014474463326135471, 0.043454039241037065, 0.05947525132327311, 0.01499662310966561, 0.10229151470646744, 0.031743375997569774, 0.0386029368476762, 0.03742655904422845, 0.10464076163066972, 0.07011331677917512, 0.01157047777181311, 0.0888956706189821, 0.02800290191155528, 0.012571241409938424, 0.06924927685289614, 0.04365104258120541, 0.02811493269438225, 0.09970040616369057, 0.07657970406956251, 0.03669498338093681, 0.03616592306042871, 0.04323516409063051, 0.03822891357084436, 0.019285865128040314, 0.03816532827312908, 0.176550600557558, 0.06362341441995194, 0.025357234502030958, 0.08126161211440641, 0.06074524507106793, 0.007230273669495458, 0.01673491682947403, 0.028498524409388343, 0.05631923337557143, 0.014371277986004228, 0.054863781232627175, 0.016573318242726308, 0.03357812784792435, 0.027738973130321795, 0.07325950964924789, 0.030119198734962174, 0.0641310625829764, 0.02604849861874696, 0.05452709708122477, 0.018318211810002406, 0.09617411110910679, 0.02697723467023142, 0.04865366567467009, 0.051925799569054965, 0.05813690338043436, 0.013623480410915951, 0.09357301277979728, 0.03475133404736558, 0.036616827090901714, 0.05452002608968366, 0.012626657337551157, 0.03532717169653024, 0.06416021605893489, 0.08775702647624478, 0.01184300301716693, 0.009805822966530198, 0.04494923602549299, 0.07224635070850773, 0.0755202734181958, 0.012674664237326192, 0.07347903214395046, 0.09855737999802637, 0.0764532229532638, 0.046218789272731355, 0.11463970291398226, 0.02363259438425303, 0.045623351264023976, 0.04426811108245485, 0.1338400956123106, 0.08895379370979725, 0.0263225665736583, 0.08058509519023281, 0.04173233324000913, 0.06916791065445832, 0.03493418391313284, 0.017171916364121343, 0.055370931438500845, 0.04646788659175077, 0.05653096858652369, 0.06689231542329635, 0.02548877945950916, 0.08107654825453797, 0.029356211551555225, 0.06125910237671868, 0.01147984573993111, 0.00964729639235884, 0.05771513750416137, 0.04402210875864952, 0.028374217067574783, 0.03442466266513352, 0.04166175738998479, 0.026598865759649107, 0.05819387350892348, 0.06923231566625257, 0.030669780380483118, 0.07331399382242272, 0.06360163454026466, 0.04012756673018298, 0.017407095780776396, 0.05659913509002617, 0.0696261691290044, 0.013306979803488621, 0.024555356865147912, 0.0582163198851049, 0.031151509873809356, 0.05696654319763184, 0.047159215825940334, 0.05589873920525274, 0.059411302133793795, 0.05951246021375541, 0.07844073848137934, 0.05452675617209846, 0.07447557463761299, 0.017252246428641583, 0.04244042830842157, 0.04964240939326344, 0.032671420654702577, 0.024497019269713954, 0.031835747049039895, 0.02382306107920745, 0.03227811877525622, 0.01977485521966892, 0.06228778991968401, 0.067488124984647, 0.02180835326021958, 0.056071446066902536, 0.033886409289534056, 0.04750992704723631, 0.01547110828405787, 0.021816215237542506, 0.04928297626094953, 0.005955520600471045, 0.04777004454104651, 0.08782156938386541, 0.03700675818348124, 0.012522158156629774, 0.054726299093735796, 0.01938322915755693, 0.030367725318478003, 0.03361077085437794, 0.0448586231458091, 0.08602382915635264, 0.04783038545640246, 0.06750992784697203, 0.10457660942789047, 0.08362470990827969, 0.07512330197759214, 0.059127033718170664, 0.055544641875331445, 0.041766696113852725, 0.03859796493704762, 0.0422732372798266, 0.03577333364275194, 0.03298257875646795, 0.03198006460743566, 0.01596365015082542, 0.10713480683344026, 0.06245968855857369, 0.021132294073580735, 0.0277525941736155, 0.05708717906306829, 0.05267111501926857, 0.022483297788928595, 0.035769955195005865, 0.031171491362094402, 0.07349411641517956, 0.03262980292821604, 0.0553933126972087, 0.04932798009606139, 0.025451384792705218, 0.04946985191875889, 0.029846668701558828, 0.10875506747153499, 0.09544180766228708, 0.030127007086130402, 0.016747218286318165, 0.06454678402552683, 0.11039795068603371, 0.04653165192012826, 0.11435042811377395, 0.031675552318413416, 0.042304497497576865, 0.032852493196485505, 0.003728682317042483, 0.03443786236006887, 0.048921490012998545, 0.0831710173177623, 0.016020698803326777, 0.03427266316007703, 0.05259010122127591, 0.010372096965570125, 0.08903688360606471, 0.05398180718804079, 0.11155044569844201, 0.04573218171454726, 0.061468838098188566, 0.03213495992484593, 0.05022673529662913, 0.028496804541998336, 0.07701324088679207, 0.04749837827177779, 0.031524010550891685, 0.016460506050216577, 0.03589727517758166, 0.01754725156652351, 0.044950523053205786, 0.025602999338579756, 0.01621300027885985, 0.04814731220023767, 0.02103422332795397, 0.02452677795513263, 0.07009727489804068, 0.060301645688952944, 0.014010671781556261, 0.022265110202434085, 0.04533506471723799, 0.07660321530795867, 0.04474462543223654, 0.022103051962931792, 0.2176699255623164, 0.114868632968395, 0.11371646737379414, 0.14388781371376208, 0.09386745101261525, 0.14645391714669045, 0.14539144512626434, 0.09362900614618294, 0.10817318538864774, 0.20491094568804388, 0.18166095859581427, 0.11785395503524812, 0.12376818445421035, 0.1977810726290749, 0.11935780861324842, 0.15204418330423294, 0.19796021462928867, 0.14864946385064434, 0.16309109456356496, 0.20217998013381036, 0.10618712542758835, 0.22499746462750822, 0.1761374033747181, 0.10573618309271914, 0.10960160228874415, 0.31345768320945006, 0.20597214600251568, 0.12633144570093963, 0.11277969505998398, 0.12303212717656167, 0.23188782795783014, 0.11979851601344925, 0.1457388966434425, 0.11413262931690102, 0.13586727151226613, 0.11961564316504425, 0.27380923169755167, 0.09191202690764781, 0.160161497732324, 0.25361084859938393, 0.14136189925334147, 0.12279837842910521, 0.10430326925650721, 0.08475703382564169, 0.16477333171473396, 0.1176697338720964, 0.20331762070136689, 0.19896722188399685, 0.12901319010603812, 0.1988810369925153, 0.1737885471553572, 0.1548914869706477, 0.17359460433644636, 0.2450656127785483, 0.15449909673583123, 0.07919859862135303, 0.13907681219279766, 0.11728431503739088, 0.14871658847456978, 0.1474340347152564, 0.10698658414185049, 0.19461757383279263, 0.13828979474642586, 0.10859360678061362, 0.20577374455188552, 0.1157969476715211, 0.14487931534888285, 0.18063760302480192, 0.14172263473512667, 0.15288789125700153, 0.10955802720761108, 0.20029459178688067, 0.18892740980992395, 0.2163099356356167, 0.09323430232583516, 0.15948035363708774, 0.20848823921574702, 0.09591686644501264, 0.19454007637837242, 0.11003309365121589, 0.14435943276170762, 0.1936075175481458, 0.20527065461201055, 0.14679534721278376, 0.13924728207770856, 0.12506976783756288, 0.142273252769824, 0.24234342659192704, 0.19120311995427455, 0.13496500379856557, 0.1611456296016132, 0.18473839507468287, 0.19254219568064138, 0.15513917851832607, 0.20237750824420683, 0.07186591144531004, 0.12596278120913815, 0.1800049522951726, 0.18015152023684594, 0.21580152904554722, 0.24379257383125447, 0.17990336903641302, 0.13095126998039985, 0.16561723885036286, 0.15865273353072906, 0.19168883502002687, 0.23338776682653736, 0.1726836798292014, 0.13010118817610125, 0.18468830824619342, 0.13186761839014868, 0.11009427343284893, 0.12071006105191286, 0.17611342482268813, 0.15853947509200345, 0.12190544932720163, 0.08953112523041426, 0.17820047815480541, 0.133287072061531, 0.18110009030469004, 0.26915043652538334, 0.1395562146940539, 0.10880204398305186, 0.19383472390472892, 0.11337800206796778, 0.20376224281086078, 0.2070572022949496, 0.12655089924772903, 0.10102898648549473, 0.15221322826560468, 0.152218728776901, 0.15462182402130098, 0.16356110482686953, 0.1619345469460372, 0.1735304368119086, 0.11722875068024283, 0.187233405548238, 0.11633840329464405, 0.11002704921749332, 0.14108457542475195, 0.09670395283929764, 0.08122940577806965, 0.16646425630296433, 0.18760998372829732, 0.138926352524469, 0.2340942837538258, 0.2079686783855, 0.12926584590346585, 0.10782857605766867, 0.1523841731250286, 0.20773496028156052, 0.11947278308892444, 0.14640225217707697, 0.31149141129947483, 0.10981013142173329, 0.08169515659251521, 0.18910492770373824, 0.1657020601053392, 0.138237991880986, 0.08740310151610645, 0.0791106287450079, 0.16478419484150025, 0.1853923890138826, 0.1707726275368083, 0.08830356892318496, 0.1604328001098287, 0.15761241677307314, 0.1734990425287716, 0.1703890166696041, 0.13605647990780492, 0.06997617937984967, 0.0681545831743748, 0.1626810076976976, 0.09984718094910346, 0.1005273367909174, 0.1166673078231754], [0.07705268675401326, 0.02833975843274065, 0.09335090856878989, 0.01235123340701384, 0.013695528107364813, 0.038157475871905204, 0.024905947427595818, 0.02300847404366059, 0.042859240915746465, 0.03097157497259398, 0.039773197439048565, 0.016083261373663144, 0.023008000984367345, 0.040806079313399336, 0.03400361308106973, 0.03306273453598542, 0.02990646569448854, 0.07338969097022088, 0.009103757967691748, 0.018763977305723295, 0.12213868479574881, 0.017307347302595456, 0.006997105712446595, 0.010111382880788899, 0.023390125640998446, 0.008146305110365635, 0.008545392868860115, 0.029050295406411734, 0.05490862418927493, 0.00574133055652642, 0.012054898148973384, 0.09490954509425549, 0.03522877536353565, 0.013272540320852592, 0.03275971611841552, 0.021459890506981362, 0.003427024184343135, 0.05214040377928365, 0.0449207988417437, 0.027589900081136057, 0.021786017966787183, 0.037792090236419634, 0.03602200578297338, 0.024135546428301645, 0.041854344233269655, 0.024596641343387387, 0.03606165466349452, 0.06426530800038768, 0.08228463060673206, 0.05424052274094955, 0.06674618415173984, 0.062086408387028405, 0.05176561441452754, 0.008053227342785367, 0.0488326391355405, 0.013772609959086104, 0.020530039797567075, 0.09222972356984693, 0.037788707958233934, 0.03545573657198298, 0.03833164213105075, 0.026688206933378696, 0.07472823809591994, 0.01828985123504554, 0.029442306427705674, 0.04209080110153845, 0.047840700830302896, 0.07063939701765776, 0.06756746871096474, 0.07114846244334214, 0.0650593045077497, 0.10046479337277914, 0.02140334555729022, 0.05469058024426622, 0.040877137798815966, 0.02714881538263252, 0.029754881792130972, 0.02559991774990434, 0.07003401901813285, 0.05053898124324699, 0.06689551767081985, 0.04921837206629496, 0.06705795895428428, 0.04371941975888707, 0.09767096264347916, 0.03529945846586939, 0.03215167213291411, 0.030391715361826846, 0.04404351708569354, 0.018693912819388415, 0.011678206970945243, 0.03767846407549035, 0.013163698379010444, 0.04818857369583942, 0.024976879508504947, 0.029533038051017833, 0.025430646792594946, 0.05344757194360418, 0.00840547840080915, 0.05115425709875361, 0.05079458264874355, 0.0029300689329242995, 0.05236688618277831, 0.009525881990069344, 0.12916829226718796, 0.05026830705784021, 0.07453650161023102, 0.06278918680524634, 0.03457940476495893, 0.05231035655484565, 0.0984895735558483, 0.04766193038273243, 0.034091651905328035, 0.04258603864018956, 0.03515025518173653, 0.05543468144511985, 0.05778366023854864, 0.025081712895283298, 0.05710297196562733, 0.0692893585730945, 0.060097621152958566, 0.04193308275012721, 0.06190416373072132, 0.025199717248699842, 0.021809925655684164, 0.024614067928444956, 0.006761436478324956, 0.005550735063039728, 0.06874723645347743, 0.027644694519920215, 0.02614952646376145, 0.024830447547438166, 0.046064525977858616, 0.02840376699403409, 0.0590650801877341, 0.0037028864608146255, 0.06834941465527782, 0.042455501088331786, 0.017641562735661864, 0.05705345204220184, 0.07466963236971248, 0.011506814907695498, 0.08217911731692092, 0.025613835652268706, 0.019969803528980385, 0.04009761269234362, 0.033010272834930694, 0.09431173604342247, 0.0038777204134666753, 0.02674279261320349, 0.013272307621645591, 0.035280325419960484, 0.020642089732592146, 0.012088471952254974, 0.05296952924841354, 0.06478748885133574, 0.016297277611409946, 0.05423669613176777, 0.029375486323730122, 0.026362410806600126, 0.041100965707652995, 0.01344852029315887, 0.05438433276609548, 0.11564890884103314, 0.09253469551162374, 0.041724906017583226, 0.047963876277208335, 0.03404863606837969, 0.024634248599590316, 0.05827629690869682, 0.0438887711554285, 0.03444431665083093, 0.07741793449367247, 0.04849681683305291, 0.09214658004742476, 0.024859445890591993, 0.04188094280600067, 0.05272399806868165, 0.03180029824556362, 0.050311993221722306, 0.05076591946905659, 0.06184561163066857, 0.013660893272308093, 0.043907938675294, 0.03652903341477917, 0.03999244414209839, 0.025635630853714484, 0.026563053064408804, 0.022074896316494674, 0.02419941900898853, 0.02702601340359017, 0.008660806887482685, 0.1011445278662347, 0.06935357972378693, 0.04584627135867073, 0.08044858598300526, 0.06531417429927858, 0.0575719824841907, 0.025681326083178004, 0.04090093248974412, 0.017370001803482735, 0.03664940497988174, 0.03937304290311952, 0.04590283163012036, 0.06841584980007141, 0.05544432649208654, 0.05508766659805852, 0.07511101392728668, 0.056880342984391805, 0.049569171387702234, 0.022355075737821962, 0.0018614155405591575, 0.05743462674980683, 0.017525285910514575, 0.03937585827624125, 0.04803267097280872, 0.00649621396610934, 0.011593035230743549, 0.08969864567681667, 0.025559807301408825, 0.030439680126766046, 0.01203739208229367, 0.03163149268666823, 0.043292310419342214, 0.0932229259201596, 0.04408241136960926, 0.04952916244585668, 0.043234003467425224, 0.04486962799884139, 0.02608627058385361, 0.07719290382679432, 0.07023555376837332, 0.028205930533248092, 0.096750944672573, 0.010531939295751434, 0.022481196792796258, 0.02251196096861555, 0.04591348025226786, 0.08436273603189377, 0.08127613714145077, 0.01173140986206671, 0.0038754556660405212, 0.005257568536176076, 0.05778538393637827, 0.09275699890549145, 0.005825648587497493, 0.0337254848601597, 0.062192201298931916, 0.02820368206519033, 0.04231931363803245, 0.014653359220603542, 0.02489631195672818, 0.010963984156748461, 0.05286030426260926, 0.08650753707174333, 0.030897239546081236, 0.008738708453282954, 0.058240964933629, 0.026693864492699507, 0.013102589460510402, 0.05756435990934411, 0.02608493950608517, 0.04626765802142121, 0.03557634562434208, 0.011585920189146795, 0.04570515413257865, 0.04540764771762394, 0.045110938034110495, 0.04727539305965747, 0.03179176402608714, 0.017568774806756168, 0.04827802978275765, 0.022715169620970567, 0.019462339227057753, 0.032379380277087616, 0.04108453312167718, 0.05239972071121297, 0.04149154414452853, 0.03947194485414413, 0.012261305218412271, 0.05575730788311171, 0.008038106682379881, 0.06773623021980447, 0.04548215742913946, 0.0240228031837051, 0.0693482247691962, 0.07188429755549278, 0.027939276394223975, 0.019022995463362145, 0.013799733302045255, 0.09331501734953734, 0.058941276548730756, 0.03943239173461353, 0.024744212860241536, 0.09860920584610394, 0.03836811940756537, 0.10626573370949877, 0.05678357458823631, 0.004976577061649052, 0.04305472357138511, 0.018887099126474034, 0.06430529779003513, 0.05409282865002752, 0.046263256846296216, 0.054721855783774975, 0.07126295428362585, 0.028112663158906565, 0.05448395100932929, 0.04517608615119131, 0.00307431826161431, 0.04831601625248309, 0.07585785006202998, 0.06056693427625203, 0.015934019785134063, 0.037683673473375465, 0.036139163609233596, 0.015290429319946036, 0.023948837394615816, 0.017177453264594078, 0.02119073700610428, 0.015908743671682334, 0.024558252677501693, 0.08871313484926378, 0.023034980685840693, 0.011950449721376983, 0.0770361545766073, 0.016767130826690027, 0.04341774199518465, 0.04494304986550443, 0.019148034419143395, 0.06710306621126591, 0.042240529155899445, 0.017683458169020953, 0.058000493764636986, 0.021191018543416457, 0.11720648816516323, 0.01174127132887201, 0.07173120254470457, 0.028347047759340178, 0.017459971169310234, 0.07017993578507055, 0.01971307405901532, 0.061335806930137265, 0.03396852242369806, 0.036960003837462396, 0.021050981501297607, 0.04213776612173646, 0.019129158012689124, 0.05874251886721581, 0.041355559707529126, 0.03623839497806565, 0.0122900354307926, 0.187254166530986, 0.17343151953912553, 0.16508606412718374, 0.15178762045839142, 0.1368263982717068, 0.13412402311880744, 0.10618999059642516, 0.21473803046730258, 0.12009884546240492, 0.14961171624881608, 0.1479648876815073, 0.17668048310424053, 0.16448370451408048, 0.16995381744157884, 0.1533731007047238, 0.12585218109550977, 0.12427171872508143, 0.20661780490509926, 0.10442114720541625, 0.12059835011079428, 0.22301649915114527, 0.10483671159994219, 0.1083314055276494, 0.08163246761767134, 0.07505168041755116, 0.15367608847877673, 0.08256969958423607, 0.0906619169719277, 0.2422664807208123, 0.1985421196948136, 0.10649392065862495, 0.1281144923620647, 0.14744603165215062, 0.18884844146668914, 0.13375873707475203, 0.0991799413496929, 0.13057807790896586, 0.12127844466557428, 0.0885459055162726, 0.13522570351919821, 0.052578207706251455, 0.10867404601266308, 0.1851029303525725, 0.07644311059266329, 0.1215862817761879, 0.0762986800362987, 0.10825928601045763, 0.10525162481973249, 0.14259559192484425, 0.23417276180078908, 0.1750812132752711, 0.13603050952717183, 0.07623146348182233, 0.14176409541358873, 0.1680141747478516, 0.1499843414151861, 0.0893896900778336, 0.24122452453499843, 0.14326959608062623, 0.2348362705520084, 0.09347354392370871, 0.18492653094712766, 0.1578234893179709, 0.1184403723586471, 0.11321677120342372, 0.13696447795917913, 0.1513093824107801, 0.166754205260546, 0.2248698190575646, 0.10004072540229368, 0.14451643482090967, 0.2591452975907634, 0.12267206585214985, 0.13053028934424923, 0.2118206144340577, 0.1249948520994475, 0.10347293719889657, 0.19564904993580234, 0.17090882264798687, 0.12305996681173002, 0.26438202949300893, 0.1652967076628439, 0.17336536018598467, 0.09829108783554646, 0.17019554882520632, 0.1124851112704604, 0.11684188393936043, 0.10838774363360099, 0.10563840729094322, 0.13871782339147984, 0.11752654437816913, 0.15477891801105392, 0.1269737721210526, 0.18232311903228685, 0.17242978296933636, 0.18381752674618076, 0.23003715871562883, 0.14007916163292625, 0.12114152943174686, 0.17740860371099365, 0.11485279793100012, 0.0997924056625174, 0.16848528817776712, 0.16103004225559775, 0.14695172107988788, 0.16441795884841875, 0.18895072952633907, 0.21964563567551876, 0.16142687580037504, 0.14007130157082312, 0.20341957168233013, 0.1439099536547738, 0.13072512082515225, 0.09031048945842252, 0.17677298056021815, 0.10468671158436807, 0.16492497115846605, 0.17047507898701778, 0.21518481294474295, 0.1282854831867641, 0.14740524513106193, 0.1287341808840152, 0.1805686091463412, 0.10943479430411132, 0.10983044041260598, 0.18426602526057154, 0.09976884845884577, 0.16723034422724478, 0.23409708763562867, 0.22898403296787895, 0.11690981295560637, 0.0761277964639087, 0.10276298053682813, 0.06604360491638223, 0.078351910586559, 0.2704207635214252, 0.1560331878042029, 0.12840133866355305, 0.13987021881245798, 0.1046653836965561, 0.13538253703905692, 0.11860050771745945, 0.1667944401983292, 0.07347417514651053, 0.12876287853765872, 0.11317156435501192, 0.19273207823355354, 0.2147581632579527, 0.10119859835193043, 0.18718575487934774, 0.12449393784927747, 0.2467186773015607, 0.20307216613042742, 0.13196362452881952, 0.1456773491396058, 0.11842776255141343, 0.10470827695943656, 0.18672821652745047, 0.12696555199762508, 0.20653379570332267, 0.13796005518205706, 0.153630536890799, 0.14848974984019034, 0.10757521545935063, 0.19328101087481747, 0.09328789783701782, 0.1539285450933441, 0.23621800205399915, 0.1259754829469227, 0.14001081126832193, 0.15995819331897845, 0.08078332044064038, 0.12862486013722035, 0.14153120468460745, 0.18771332898928275, 0.1033936394378543], [0.023332330052770918, 0.029295395661686218, 0.02245320968570248, 0.056804883323850176, 0.033665017540296244, 0.03110822782130732, 0.09292844172206619, 0.046010141396113945, 0.02886178606610385, 0.03831358543867546, 0.056221813804680304, 0.03032193624324376, 0.08661518774686322, 0.016271705596497463, 0.038800752241044276, 0.018382272082230738, 0.05104744528991081, 0.03502229168530434, 0.04849436152125559, 0.032332809792170604, 0.0393835268163633, 0.034802060559271805, 0.04373938017975419, 0.014165778730755613, 0.012344003452228443, 0.023503091051093033, 0.04081488549408894, 0.025858817163914926, 0.016452695783828537, 0.04712150131742801, 0.012111319566986734, 0.010250553285943405, 0.029701464396390705, 0.06824622261187724, 0.052502353510428826, 0.03704621937246092, 0.04344875323435953, 0.0631592225944323, 0.014726871102597686, 0.03337935101421129, 0.04315875448106278, 0.04895330947493354, 0.03181621755263017, 0.01728889607493916, 0.030262047319763133, 0.06687042063042041, 0.03859736355802706, 0.0479387256106542, 0.04440570430409524, 0.0652376497765222, 0.060125104557242126, 0.07438391987835208, 0.021922569308850556, 0.013102171942591669, 0.009825267235658342, 0.02372131502676395, 0.01953912421970839, 0.05136571268761351, 0.01702706445939839, 0.04507141938853649, 0.03398051553015267, 0.012441650934277043, 0.045597840536145434, 0.04334797053748081, 0.04725976486600215, 0.08271959234750079, 0.031190348616350564, 0.04761714488267899, 0.03137218916127759, 0.0421789548389854, 0.02136740071188298, 0.04450028168878729, 0.028168509053366802, 0.11526024179352869, 0.01762128247308635, 0.028621362777607098, 0.020087089674967914, 0.08189503659283923, 0.045265718438332124, 0.06206732513683458, 0.11395887291479496, 0.16529551256568203, 0.08410415071393214, 0.1265126867820659, 0.09713474706175829, 0.06042177976679899, 0.015005371833760894, 0.029177550271513964, 0.08862595404348067, 0.05360352446234996, 0.053577952447437474, 0.09049344657649917, 0.01312149746809155, 0.0386299452774467, 0.044737826401908556, 0.002000718335283079, 0.06281640207875641, 0.07450541376226372, 0.10899418649534065, 0.07218765305174936, 0.05860965623850784, 0.033929367669888084, 0.08163107333764916, 0.03410160721790406, 0.0330987406684266, 0.01863479189905188, 0.045776679931629094, 0.04931537028882773, 0.04021889590207608, 0.008129884973318588, 0.060265846400251316, 0.016140681578807773, 0.04819726113290076, 0.02303797608962463, 0.07154629190242098, 0.011774539654593796, 0.029375911502528097, 0.018000503656484427, 0.05856107860322922, 0.039117395532347506, 0.0677281096878071, 0.07980586119717167, 0.03881104463230699, 0.02325083170416615, 0.027713872259482745, 0.12284723185603658, 0.07575861103231869, 0.04965891858803169, 0.042573080262950355, 0.008012793222141844, 0.03613775783789254, 0.030877796234562997, 0.03461796197018797, 0.06062353285209787, 0.010555122073950067, 0.022553381427461584, 0.05647348900956493, 0.010754254180938007, 0.024113642059326656, 0.04298383745575144, 0.014757566330503794, 0.037251331753307776, 0.05018707875522876, 0.061016233352523666, 0.05954013897045966, 0.004921968399186529, 0.04780515435061628, 0.10451933669467127, 0.02003215350991776, 0.044433597565418294, 0.012068732739275983, 0.03302124704444601, 0.0741618003455862, 0.03216586774215102, 0.03873659237738579, 0.10422040152573779, 0.022759054967712973, 0.011916380833774325, 0.009475359449072952, 0.022324817180032694, 0.030483412255923596, 0.016725585878556295, 0.02281269452895128, 0.026216861761866078, 0.05535936351084421, 0.10970363753937906, 0.031203760900684906, 0.03838652083950658, 0.019043155067089586, 0.056716882803988074, 0.03695507406166965, 0.04884222289547325, 0.09355336262453949, 0.04788255987448558, 0.0999338484759773, 0.03157387904432272, 0.05451406592563276, 0.0405159771382328, 0.03498629704418202, 0.02853992380081646, 0.011517921267377754, 0.12782683400737663, 0.048764779067207734, 0.014953680051070069, 0.036507644239933267, 0.027539859217922055, 0.012459414598021298, 0.03913662050880733, 0.03691635597797652, 0.045238112459980676, 0.04562494472690648, 0.005136967144696223, 0.054386634860307946, 0.0420944438496184, 0.028363250518938708, 0.036832829411592216, 0.11501834187055789, 0.03810911274124538, 0.028676586225628856, 0.0897763423140972, 0.06086255994535262, 0.042088334298422264, 0.0896623560918435, 0.026184902488884908, 0.0654597003613749, 0.029136577974103635, 0.04532058948590871, 0.04926692288849623, 0.0979505617532038, 0.04014488797815096, 0.03475326458893476, 0.013414294357531735, 0.06074390441720044, 0.0723999053720505, 0.011890814564521275, 0.05433519971707175, 0.03719592827462381, 0.007141396457765012, 0.036547235663860075, 0.018802187856166594, 0.027803757355638573, 0.06411825742332206, 0.03620049277801187, 0.03286703737572797, 0.10827580286610512, 0.03537757645150827, 0.07497630502668119, 0.02401616694706102, 0.021232121075773915, 0.05849964984302079, 0.006172207612243872, 0.0777045279861458, 0.07169750233691546, 0.09425883767225089, 0.04014706366785592, 0.06620993026562276, 0.05632648822821437, 0.03478236826917818, 0.05130585057721023, 0.038977293372755094, 0.0652206656072409, 0.030607499347458926, 0.017390136509352637, 0.03404948259553602, 0.022455054042380185, 0.08240784818847334, 0.018159279209231178, 0.025681295439661033, 0.046620659845610785, 0.10950879073671757, 0.02547042016240378, 0.07616237001193148, 0.06977613850106155, 0.100846374106984, 0.031135964034605893, 0.04276647149855572, 0.1487029521095176, 0.1812807185154769, 0.10373555980021916, 0.10134436190128328, 0.1153760742876799, 0.11722679715603591, 0.015151826777465403, 0.021711211396201004, 0.03259274725531859, 0.08447918905726365, 0.09354412360417266, 0.0419468455196869, 0.02287742704333317, 0.13250028444153647, 0.07438689996037753, 0.024120770507462086, 0.0925563987825186, 0.06217338617951159, 0.025263693251256502, 0.036681419794237426, 0.052513637985553474, 0.025756912148227135, 0.040782755766544616, 0.03843041767756786, 0.02027437135937714, 0.045963406202293215, 0.0892440797460656, 0.03269988465152922, 0.06647949362353933, 0.012753485108635599, 0.056635834532038826, 0.07181057691453926, 0.04871144785635895, 0.06124699818751505, 0.09735493605295498, 0.052235383360135945, 0.015572814116885346, 0.09990017125082594, 0.054155452507397825, 0.08039675247404846, 0.026020157195988203, 0.0564507017242572, 0.04696663664353471, 0.04157767157941576, 0.06369625789023216, 0.03256355930540351, 0.03309948760415277, 0.03745605342931325, 0.055644076257463426, 0.07248035992585844, 0.04969509325981621, 0.03500646047834908, 0.0027921326475353133, 0.02480204675286528, 0.0391267724485407, 0.054275172897764755, 0.02989717687840664, 0.021653764377979022, 0.0338229887007225, 0.04328916562841304, 0.026496081658068205, 0.038296467204007416, 0.021391547803256302, 0.03276001872314561, 0.022926104270041953, 0.031344443371879964, 0.01527727367506633, 0.019369474048876477, 0.022770157496955608, 0.026182914490721403, 0.06033780120853936, 0.02257306222623635, 0.04847133291825172, 0.05247823706257248, 0.034478848064017874, 0.06768785942826541, 0.010833583543107156, 0.03018802407407953, 0.03998986242579357, 0.04008132566307341, 0.04330264877588038, 0.0771009809367599, 0.026329526482450388, 0.02194517273305645, 0.03076917454299908, 0.07781145087773762, 0.03848040874506678, 0.010435986783235304, 0.028925700781626568, 0.03844793427795653, 0.020635593306994247, 0.062266343288243785, 0.02629189241317011, 0.05662209091467723, 0.058479425121819785, 0.0428473282485239, 0.132106852327143, 0.0893992814986456, 0.1657590264033887, 0.15875174273406306, 0.11887967781794649, 0.2876691412060492, 0.215933786464795, 0.0908970523385271, 0.1162672337264784, 0.12216187427721678, 0.14865997457696548, 0.13270325177619535, 0.09962393526708889, 0.10890688311548964, 0.13252683704899204, 0.11532653904249592, 0.15569796305029623, 0.12250128187119, 0.1331424193396684, 0.1967612104189973, 0.12884221460309722, 0.12161215256539085, 0.09261342636760204, 0.1331979913576957, 0.0865404635307289, 0.17085700446078855, 0.12852268699075908, 0.12193669805363302, 0.17831848633866157, 0.14492613864281487, 0.13593752177492266, 0.18406831328907322, 0.19508951463766638, 0.09776493864915065, 0.10302224767304237, 0.1494944588311257, 0.10161063108112543, 0.17109228538409357, 0.07527459668175829, 0.22653011545058221, 0.1411374354915273, 0.13381118345404827, 0.09889659607001851, 0.08760360204764912, 0.07280308212484084, 0.13962424330173, 0.11839247654162108, 0.1429756634658383, 0.2538101693555232, 0.1328190229833126, 0.29652563855051994, 0.14626182826055636, 0.14217664908257224, 0.1502572219338148, 0.0931686792342413, 0.22415617751258038, 0.11585693235599226, 0.25594251380572397, 0.13114916581299998, 0.19942175717123095, 0.1846732929228775, 0.09138558660784075, 0.10820438048892445, 0.15277985753791948, 0.12311020685780434, 0.16478410291094936, 0.1740233071388737, 0.13694906427014258, 0.14480762484092868, 0.10030085055698311, 0.1038677023062783, 0.10813157149260083, 0.12243734417302955, 0.3758855140016925, 0.13536505491262482, 0.13017104007303715, 0.17769798576351137, 0.2552081725650257, 0.2523299342682285, 0.25915194723394613, 0.2540936372092655, 0.3404786155348824, 0.23560775173527582, 0.29736858041536424, 0.2416356226369258, 0.178974962402736, 0.15064210450697332, 0.14112045898312522, 0.23872424337652423, 0.1441184981095214, 0.13216692894216509, 0.1139404101958198, 0.2433174614223742, 0.22031493605144564, 0.12045925152638268, 0.1043884046075325, 0.30238998032385306, 0.26447340846061707, 0.2252773778332818, 0.13564176587087495, 0.22092317921980736, 0.11518132707644856, 0.3066185405177455, 0.1344081191646476, 0.10940191381040121, 0.15110039362503638, 0.14175246619889814, 0.20404548083822574, 0.20563699785740147, 0.08298999074125483, 0.12013861308655432, 0.16753435855911625, 0.10463659411236163, 0.14568720103031205, 0.2457093411395627, 0.1535995716168996, 0.12629877205096907, 0.1767830469555432, 0.18267630088713863, 0.12688370316379494, 0.13465495269385078, 0.19173987179754243, 0.1563728252245534, 0.148435817250321, 0.1960370887912089, 0.14773956590121792, 0.14901916256114361, 0.09701488494512536, 0.19679360061643586, 0.1598177081154239, 0.17492165248240196, 0.14001196040020836, 0.06730635530285298, 0.09845140705546064, 0.08839247342679771, 0.19160450406132207, 0.05608926910246092, 0.10283032732625162, 0.17598784769014006, 0.22078246418987552, 0.20390337152827173, 0.10476689034652327, 0.12009018100798131, 0.1567774115791244, 0.10854217929825669, 0.1136963805484195, 0.2548301388179102, 0.18028728633878693, 0.17959267441784182, 0.16502505288489405, 0.26655477742033623, 0.13435751139636964, 0.19577234412633604, 0.20816897973418239, 0.10295100149608429, 0.161600976942047, 0.10492136431557518, 0.10257994680995904, 0.08603876787087611, 0.1426577522990204, 0.17843722996692504, 0.15017964787060215, 0.1268587440192219, 0.11197318067593921, 0.10436316201042745, 0.2088163087084409, 0.10418667833531096, 0.1929186512866328, 0.15881594090211779, 0.1638307218109408, 0.09633729549785776, 0.21501500189544695, 0.15442115495041495, 0.104833455726264, 0.3147053340029332, 0.11462221312667094], [0.004706067106341042, 0.0202056207138324, 0.018802187856166594, 0.10345671911753955, 0.05741094697206732, 0.07922648422179684, 0.049742747759146076, 0.015868881244152304, 0.070788738197617, 0.10685928331147279, 0.027863096611033526, 0.01596716457917806, 0.035537144905256654, 0.06895545915129685, 0.016879937273540327, 0.032527890251649004, 0.026833646810583534, 0.02604426215252569, 0.049866624176502235, 0.02681629300387877, 0.013560155583094927, 0.036224597734549356, 0.03429938047643631, 0.04123269835667264, 0.029682800579335422, 0.0262779668499265, 0.0036929644251828117, 0.015689029654998694, 0.03161199766421511, 0.03446516956412985, 0.024735644166808457, 0.03763303506158052, 0.038813159034978, 0.07972327691893424, 0.04479240250563429, 0.02247336737421011, 0.03857554920438317, 0.02667645322940042, 0.03696219101848622, 0.02140235155820847, 0.050530730476302486, 0.010944851110839557, 0.0351538481341014, 0.030234596474216353, 0.02769034378410828, 0.025826480592631047, 0.029870817708151958, 0.030423373945297736, 0.009337409038937861, 0.05498744314536453, 0.030357017324516372, 0.033011345358024684, 0.030915204307905612, 0.05223658228773744, 0.02287313312051758, 0.00968885570464115, 0.07276403462334026, 0.03666860697370383, 0.008238460699607047, 0.04368515647647362, 0.036618374588508765, 0.030697740674499544, 0.048058932466853055, 0.08817342590660819, 0.04702494742589132, 0.008295216323477368, 0.022600225788811525, 0.06631195785537844, 0.09671216530184593, 0.008811562457272123, 0.0413049596001304, 0.051779239288260864, 0.046278318134887565, 0.06669035166381829, 0.02477886110183693, 0.032107777210072644, 0.07178104422505825, 0.415084486406657, 0.3845067304228583, 1.1016539243921157, 2.4004096465726055, 3.2140913653758267, 4.343937202807396, 3.6547015030537886, 4.100401651474738, 5.605435188739531, 5.053690085487982, 1.8931210545762893, 1.4332794133693942, 0.8733036453204771, 0.7721888646483422, 0.6847799485248904, 0.3137502981530082, 0.23909415659164232, 0.2125135103180524, 0.8890704702465766, 0.6974094901834765, 0.7615497419911047, 0.9579230820940388, 0.7549186074926008, 0.7708488849382248, 0.13676707242285052, 0.06667001969030788, 0.08728278740759819, 0.0557279015981382, 0.08245773583410249, 0.003462440907887574, 0.08209955908598439, 0.035115643329317534, 0.08686741453505332, 0.05196070253488518, 0.0657275170388241, 0.052123392796925, 0.004403286654832623, 0.022459596943771167, 0.03669155130703603, 0.0833127818881504, 0.01643836227876525, 0.04891631125863041, 0.03950560675753702, 0.056824422396358945, 0.04668219968856824, 0.034710313869459976, 0.08298504947414322, 0.0535276664360877, 0.05961387493317166, 0.06444392906081292, 0.04957161137774106, 0.03158103622075531, 0.03911254236534719, 0.06866307403411596, 0.03128560015841598, 0.027920949655855377, 0.035287718168429794, 0.02764623244142821, 0.011303215550499098, 0.04679682942467832, 0.07661050080411858, 0.01081869941234829, 0.043529066061901475, 0.04519980806376665, 0.04184642671457222, 0.07030943528779092, 0.07239047482970261, 0.01347054819381165, 0.02426336819846784, 0.03380676295848624, 0.04435822217454834, 0.03505255598875304, 0.05064384718876212, 0.04203149440488027, 0.0446297352262322, 0.0361428331703909, 0.06359775813536779, 0.026991612225350355, 0.023554062711135037, 0.0646752646313079, 0.020571096364649075, 0.12772765626469929, 0.07667518160756558, 0.07182381491387083, 0.0368009333408648, 0.0383378244605997, 0.036385614094474626, 0.023743050856395595, 0.0406106349621569, 0.040692537422141725, 0.023060026015305234, 0.030034170636246284, 0.06837041312528234, 0.035119883625978426, 0.0037441704602491476, 0.0475596614752806, 0.016222955591435877, 0.010909005856862473, 0.06594697058561348, 0.020259691199528116, 0.03620693557745507, 0.011096137196516559, 0.04180933656771818, 0.15399583825661292, 0.03250711777758214, 0.05630175507957897, 0.0220514731782098, 0.04490736165955182, 0.029457492205584725, 0.05371381431036899, 0.035552853538144025, 0.04756958231390004, 0.03084058159842126, 0.06510740716851528, 0.01587197336653668, 0.04845493097579287, 0.04155654670490373, 0.031024140095518484, 0.017839071693860235, 0.016680865495976423, 0.03710752172816185, 0.06533918707000633, 0.024652983279778592, 0.01987107203251893, 0.019548485814143094, 0.06679194258345712, 0.029413409591201815, 0.04422947726843338, 0.056804982915280335, 0.015566222887906819, 0.021662729521912914, 0.029060103247062336, 0.0517462783553187, 0.03425846755084011, 0.03782682466290651, 0.02496814610616815, 0.046843089643986, 0.07736670619417584, 0.04861854054334183, 0.04068457010772921, 0.0289372859462615, 0.03213707049707732, 0.08745081347203063, 0.05585778797526033, 0.039320987228664665, 0.05648133374990956, 0.013770431396551432, 0.016583905577839866, 0.0383614506121845, 0.013987431546763308, 0.054922815968072226, 0.05572921543892834, 0.03405951068646485, 0.00789617931830787, 0.05684477735250708, 0.04671581945712528, 0.058950615160527735, 0.04901263915422944, 0.006189120918392174, 0.03454535215672466, 0.047952327501749804, 0.008485136223175834, 0.024936035530821934, 0.012894671282640869, 0.001139668067128608, 0.03707029751592106, 0.027366495435877193, 0.010522514499062973, 0.032235673673811464, 0.018109832064158494, 0.038159207230614084, 0.016024936227157952, 0.04548210763342438, 0.04611054104903052, 0.06852397544970436, 0.2796561985967621, 0.7550768506142401, 1.2607170665456404, 2.5458555452285276, 4.527081491485719, 5.281257177552869, 6.140790668226058, 5.874716687587, 6.170393286212799, 7.9428471576782975, 6.58028930425644, 3.299407329290144, 2.1788087246879457, 1.192445026770715, 1.2664090385360103, 0.7116131893088742, 0.3659158296162083, 0.16238411798352198, 0.233387092669164, 0.8410664816056529, 0.6921335958665418, 0.7746716023933503, 1.5538256158751826, 1.3234443457857257, 1.3523919279536893, 0.4536864005269543, 0.08112701812698957, 0.05951546710885822, 0.029339053097271153, 0.019296465869692546, 0.026305544099980788, 0.07438562825442323, 0.019402915701991128, 0.06803188653242204, 0.02370427340088833, 0.08950113288817868, 0.04220158890670827, 0.06546447308914316, 0.027194778742869536, 0.04118600529768775, 0.08095048848659762, 0.012921759194033522, 0.08587298644406181, 0.0356331012482124, 0.02329917951306749, 0.09821756637745327, 0.016083108156078284, 0.07661157332721256, 0.007567004264978272, 0.025224203333979654, 0.0069824916276810395, 0.013412800486079388, 0.04133519326006213, 0.061266292111888054, 0.05078768019654578, 0.048499207027376666, 0.061220629441161314, 0.011299144750791452, 0.01562894250626766, 0.08501725091088204, 0.04675200178978905, 0.048694314299932415, 0.039968216611493024, 0.03509050415408227, 0.040208308566962524, 0.012107029474610764, 0.0354595516898459, 0.11778977984983115, 0.1000338918980091, 0.02094676098485868, 0.08088052933735233, 0.04220054702713125, 0.0902605175431217, 0.053733395517713604, 0.0925236791672726, 0.043887438162440257, 0.06565810181200504, 0.06994620235937257, 0.037647115757628795, 0.00678117425488909, 0.05772494342959216, 0.039688280423081694, 0.10478184438280522, 0.03011763208515702, 0.11675408260235864, 0.028728858319922324, 0.06388215678593805, 0.025149203326192596, 0.04576498942990457, 0.03686185265260358, 0.057005636664407874, 0.029497457097374627, 0.056773772493245146, 0.06994090103093656, 0.11217857650931805, 0.09643438182050183, 0.08423629321999128, 0.04191932764144675, 0.06403153243985388, 0.04654983118657143, 0.26572703473990966, 0.24723669063420067, 0.12850704347534528, 0.2805845132998882, 0.21880057940800346, 0.22413065146294334, 0.28319996811689874, 0.13591642371348797, 0.1394257805640659, 0.17207575841776787, 0.091547958943392, 0.2011041781835018, 0.2146294145213981, 0.13555840018295473, 0.18979555596747708, 0.1309748501667092, 0.11606320152960478, 0.12282005105648311, 0.14656653207155967, 0.17422118764971534, 0.12296515577022107, 0.15542689049916883, 0.12039103905760473, 0.14520027554563938, 0.10467279176678389, 0.19991539358612032, 0.1446226605724904, 0.135758287844158, 0.1552247658612267, 0.24411361063680342, 0.10368302915125124, 0.15260822319936368, 0.15249776864244094, 0.1454884778227537, 0.11195939875418141, 0.22127082991984584, 0.1288986752831167, 0.12202244627499774, 0.29612960173718395, 0.1107137474501806, 0.09524961918472283, 0.10474585357212252, 0.1249949976561531, 0.1583284791558981, 0.21084178389320452, 0.14254290039741224, 0.15723574666246293, 0.15356333565808114, 0.10501740109776297, 0.12860143316849587, 0.16059842831905813, 0.13432663805302114, 0.06494754760135567, 0.1301671789898988, 0.11377461344724703, 0.11458753232633877, 0.15585430627388341, 0.15276671146913884, 0.18134977368097152, 0.1117871362235277, 0.09780717307641622, 0.13004722494271495, 0.08840782582880029, 0.17981700028382963, 0.07333167513171512, 0.11458970801604372, 0.13641038188530555, 0.099871366344873, 0.1584934944947881, 0.09772246673462853, 0.1397823638493015, 0.13917425857676616, 0.2018478656968763, 0.14655292635002445, 0.21660327070182372, 0.21132310161427145, 0.36578384798861324, 0.8943387036842685, 1.5150904943866115, 3.001323130822951, 5.696893584343695, 6.23880579586952, 7.438873091051656, 7.373669080195889, 8.333038168568766, 8.775998296276216, 7.753407464873407, 4.378054959158744, 3.3575628409462595, 1.7796885606742676, 1.9161848363376435, 1.1338352556190183, 0.572677934842725, 0.5018352410726009, 0.6561261151106127, 1.3818045561352086, 1.3134925572141525, 1.9485339714634804, 2.6145337954644234, 1.9172403216362002, 1.994345906761385, 0.7764698865432894, 0.26780910850051914, 0.16647271391364837, 0.21687875591939498, 0.16393875553002282, 0.13510395682627155, 0.1933450558252873, 0.06562140620043201, 0.17265168799748346, 0.12299155516009178, 0.17200484931949647, 0.15281165018677711, 0.14728737484303214, 0.0864830682234418, 0.09975842200219633, 0.21231870948066636, 0.09923914462448129, 0.16132230479871074, 0.09762803873708172, 0.11517117641145184, 0.19947921376555197, 0.09878571250385816, 0.15625147689734736, 0.1647017637808477, 0.08280560103875977, 0.13404946744201646, 0.09742648866508277, 0.13634223070356155, 0.16294089536513054, 0.2029523959443454, 0.15302362671542555, 0.12463547259328828, 0.09745173126218781, 0.11142883690134173, 0.1273041551992778, 0.12524714783555077, 0.15121149169581552, 0.10308525840481443, 0.10165382311829638, 0.12689219907887522, 0.10769842538021265, 0.21003084918183668, 0.2840358006858057, 0.20844719222476407, 0.3738995383103048, 0.17715610113115082, 0.14516102120039925, 0.17646133599262084, 0.12063497677445413, 0.27305803652251925, 0.18750544337015, 0.12360296227158078, 0.23908615863371283, 0.2936939630777605, 0.11514227957494798, 0.15579856571651277, 0.2000784324181657, 0.3016901130397474, 0.16260893414578131, 0.33074467172545774, 0.07940372632395837, 0.10497675247250066, 0.10347106028348209, 0.10334146118933156, 0.15815037903526138, 0.12699987273663282, 0.1805713057758347, 0.11848797706226188, 0.21385764222471945, 0.2926780385596137, 0.42654500853630806, 0.19232940709879323, 0.1910693456809367, 0.19213008634265394, 0.14111768574483935], [0.047100265360166954, 0.033542933768682906, 0.020712594719483488, 0.05470532743680862, 0.06003395924645086, 0.019189424234472455, 0.05313317712035872, 0.07930359863225492, 0.048707073494311304, 0.02405812558267386, 0.026527866646046602, 0.09902318443862662, 0.03892495041532863, 0.014281332560424364, 0.02450555731963006, 0.046868845520000306, 0.023042497923597697, 0.10779135184542787, 0.04172019074640928, 0.009414923730336372, 0.04464359375678244, 0.03893866338917325, 0.0713676248767203, 0.061722585570908366, 0.05509799729371744, 0.03935740704858496, 0.041290093663959734, 0.08565807579866341, 0.027488021878525618, 0.03083492786954007, 0.05690183558110749, 0.034975905061489156, 0.047880951089844595, 0.053487090589178186, 0.06884506588140804, 0.06618462638148377, 0.0403566729848183, 0.019194172064383185, 0.008729183107554432, 0.020378997902415937, 0.044010567644070235, 0.010084089083266596, 0.05395605131202648, 0.07867331511431164, 0.058799672856806755, 0.0252763643455241, 0.012994657248078335, 0.04395514118274854, 0.07156610293614288, 0.05939372424637118, 0.022051817917775725, 0.032588572076131264, 0.05117635490492948, 0.008978378102784196, 0.04118646878088194, 0.0532868390362109, 0.08084564935415983, 0.050596813220650926, 0.033119536125131195, 0.034423781664020596, 0.06872497393839783, 0.017687307760840463, 0.03191484371200204, 0.021793397308717814, 0.023717534382857626, 0.06183689738052988, 0.10592987310261497, 0.04978952125736302, 0.02016878337599337, 0.05568123152179103, 0.046660147847667824, 0.015065230113724548, 0.14062740479505834, 0.5037938521033334, 1.348471151244256, 5.315026823551425, 10.83366584393286, 18.541734141688195, 24.36242557341053, 33.51231890340006, 36.97876845636676, 41.25098659146217, 43.87220851836666, 48.92413108579574, 42.16932719753635, 41.65129976887857, 42.34485326274749, 28.332760449378725, 28.258682566304362, 15.94231765116415, 11.896678170850201, 10.911706301473803, 7.880310358539705, 6.591830388192208, 5.732365048700764, 8.956326323170817, 8.993178952124811, 10.762178686357315, 18.897469582096225, 19.849546494022494, 19.365312245584306, 13.82866709463058, 5.018229897945158, 1.0247361227389307, 0.01644376894429086, 0.1510799237556996, 0.033304431445656285, 0.08835572418906996, 0.056472581195374655, 0.017781166938103495, 0.022580972084054546, 0.061317110554345196, 0.016780296047668786, 0.02785266632394445, 0.05357634366279649, 0.15049985730119292, 0.015767684859794476, 0.07234349831818573, 0.05316539111757471, 0.014512717926634416, 0.02447066967555833, 0.04101102315490285, 0.07100393229554738, 0.03462209118409984, 0.03824469498208454, 0.021572815697459925, 0.054159819208566225, 0.04815618732884046, 0.03580611837547153, 0.018332116305828094, 0.0713995171170081, 0.06684995076108365, 0.029262051684781912, 0.07339475481140037, 0.025150589945335543, 0.09968681576391382, 0.007441762295897089, 0.02097694484907533, 0.04439684449725094, 0.0407530430464014, 0.04448021401561076, 0.03468895533813104, 0.05775860150254542, 0.06207790098062927, 0.021568797566297076, 0.04976451997795413, 0.033086762883730476, 0.009101202106854368, 0.025549928597625227, 0.09243957803494508, 0.01528994476933393, 0.03584720367085069, 0.004869183504788746, 0.05844939447518799, 0.12409814618407719, 0.0713166187427217, 0.13840604092805617, 0.014574994171609082, 0.024637715147447684, 0.0744523085473526, 0.039327905002620914, 0.06469047913748412, 0.05234041784499442, 0.048762844695198926, 0.03315616278879104, 0.045485191137319615, 0.04906927603447149, 0.042721586407072125, 0.0977652374234411, 0.0021493714725253203, 0.15237655821106127, 0.02940615282333907, 0.07590301094516631, 0.04858324687267023, 0.08960960327737755, 0.045809280803246845, 0.04993390584845216, 0.05559964698829478, 0.05082414598174153, 0.0615320748258983, 0.03300687140454689, 0.041571811006795016, 0.08804206481023182, 0.05726420666061102, 0.017978532254816066, 0.030143843783486276, 0.17911429847440413, 0.026605770127066684, 0.011965740836345622, 0.02482950334407149, 0.03823968093662012, 0.09572646295231196, 0.051760320746970755, 0.069304266644101, 0.08754388549395146, 0.04685399490558813, 0.0480707532035247, 0.04323566970866054, 0.05870153699370642, 0.06396603575276752, 0.046359592402774485, 0.0182366713265618, 0.0236820396141059, 0.12560936186702984, 0.018235204268186804, 0.04497344823433988, 0.017276721022602533, 0.037385174974558816, 0.0041440027604450385, 0.0465995081580214, 0.019522980831923987, 0.05730717653228391, 0.07618335316017752, 0.01352483414173607, 0.007968503285214425, 0.04821468963317814, 0.06690255801884398, 0.035356087685232206, 0.033137190621346235, 0.06751264745910322, 0.034159630717289065, 0.05570192738706547, 0.03658184368583945, 0.06732974396718126, 0.04993376412218617, 0.07238680526854531, 0.05702103120124629, 0.03808017376990568, 0.09652355445488807, 0.014248935659716447, 0.031744777938471205, 0.026955324555596998, 0.018639457374510747, 0.049487291910355134, 0.016585684817044005, 0.018178146039586396, 0.004310917518582315, 0.03654410619468939, 0.010424743485336584, 0.06806108214321636, 0.030076083306583668, 0.0494307124867074, 0.0879224171982177, 0.08873810931559532, 0.04126982297748327, 0.01997411468877427, 0.0489933222472187, 0.09900371048359141, 0.2134871927480544, 0.805639082625989, 2.4874553757329143, 7.51749356908183, 15.418097780596826, 24.665936616159257, 33.47774713270126, 43.15184954674014, 46.428648579505186, 50.82828883201846, 53.83309502755442, 60.98251288936984, 53.01554756779825, 49.7654559535365, 51.810556227161044, 35.846721433824115, 33.56455310698479, 20.6671606340716, 14.803016204987804, 13.643779312410663, 10.066259022681944, 8.208991740980457, 8.011769085161148, 12.22923436472493, 12.196935607540993, 13.646408281018658, 23.533636600740497, 27.27045120731477, 27.877365427632487, 20.04085813799212, 9.036394646090846, 2.566921614831494, 0.27388945642498236, 0.2294717092187174, 0.006157129565479175, 0.02327513775878376, 0.016032315569088584, 0.0444104578796654, 0.03732355852280894, 0.039057721113485676, 0.04760461551467738, 0.048692479519353765, 0.02351383351901126, 0.04630629949632191, 0.03685001659417345, 0.037001617733509316, 0.03138352917777675, 0.05193800718012837, 0.035996157976408164, 0.027355760628838214, 0.06839407758126337, 0.03922281306116812, 0.03059590077628532, 0.08535690365299102, 0.015759478142905622, 0.011584393758957666, 0.03110402008338321, 0.0501012347728735, 0.09564384803055756, 0.0047642797336823525, 0.012069146426755094, 0.05184789608803488, 0.006140614625051498, 0.01924957937350677, 0.04261209329049434, 0.03914285646451097, 0.018327554252239007, 0.019981903887744394, 0.020847340009265372, 0.02318542120197127, 0.06846269607664117, 0.0350617298916463, 0.015138366612635795, 0.043638245082430305, 0.04993153480632652, 0.03291322864712246, 0.057443241408515366, 0.0362566240402239, 0.022003175165023536, 0.04334052799329643, 0.05616043100974733, 0.05507041812844335, 0.09995875399439566, 0.036568257116502335, 0.03240402915605134, 0.01740704981550094, 0.0797569158396894, 0.04066122740867638, 0.03998624266035134, 0.04809782292032915, 0.04644771549670447, 0.08629422755010667, 0.0314271004284702, 0.08688035376009443, 0.05186900947122805, 0.03520434865006997, 0.08213364233773562, 0.08581931432408672, 0.0484739069736773, 0.049699854496265614, 0.1176046240594118, 0.0642666333324967, 0.021987114131690997, 0.07853376453802471, 0.1612488829320477, 0.09132718772537286, 0.18831363548674893, 0.17519277099880481, 0.18960703705107013, 0.11344124262611713, 0.20897593078834398, 0.14759227783689577, 0.21050179407240885, 0.18991022400798338, 0.24420488235210222, 0.2568916661003905, 0.17023357742976758, 0.08341287893633689, 0.1751582970422122, 0.18120216385972115, 0.14394585253490558, 0.21759129429776825, 0.203580450146429, 0.08908698575631266, 0.13365955933207466, 0.19089421798144618, 0.17183080946485843, 0.18649207758567027, 0.19880346292930268, 0.0944874229870977, 0.15150409131761522, 0.2360923176691417, 0.21269609971392542, 0.17408704565417382, 0.12950613704179564, 0.12744293968764045, 0.15018350895374052, 0.29031913126668624, 0.13582829295867874, 0.15704868331311211, 0.14927728822635067, 0.2271888897784295, 0.08961629888583576, 0.10502808036342745, 0.10409319262591102, 0.15811742193275885, 0.08249608619559197, 0.1702280309531958, 0.22733366507436, 0.1313524089393116, 0.15776047092531958, 0.14831540355038259, 0.18465824695604463, 0.22765598890762176, 0.18701297140890555, 0.14715418279651674, 0.18524965151183068, 0.07429049545598608, 0.07778145853550204, 0.10357337898664898, 0.16730589581833732, 0.14806021966280478, 0.06788531092986946, 0.08801483038452365, 0.11843907000917582, 0.23038836406363597, 0.16104303510679355, 0.213499863842322, 0.10491561099526384, 0.10076840933892997, 0.1879327059272797, 0.16859842404242487, 0.14585834507259632, 0.14921483673876332, 0.11336132433385619, 0.2614701599363358, 0.4835228591917023, 1.3383683514210487, 3.1987019460047446, 9.891068320120535, 18.19689308443377, 29.493783981569354, 39.604701149848204, 50.07540164455291, 53.6685045303837, 59.73147292290965, 63.48178832761703, 68.38049919374528, 61.597720961416925, 57.77932105525848, 57.98893643963722, 44.14534276531589, 41.29395615669989, 28.218262541678648, 21.43515483025582, 18.063169679334088, 14.16610860055493, 11.122409162982818, 11.744963834362647, 15.50685219226345, 15.90021198795688, 19.681065005640832, 29.697749191714873, 32.91781702349263, 30.840017910926576, 22.624480224424794, 11.346039175987245, 2.9035958070908827, 0.3538442144711172, 0.3844459336851874, 0.13725456481258716, 0.19465357996523383, 0.1375196312343882, 0.09365722882531344, 0.08675268520751307, 0.2239073061894986, 0.27077343975824697, 0.09209816329061024, 0.14491955028666606, 0.29622049040852055, 0.09887747451542847, 0.1775599520413145, 0.18735285397739182, 0.1674991491581163, 0.10642995997782677, 0.12257681047964482, 0.2071709969952222, 0.08328488096594812, 0.1949502245312737, 0.1392280992360846, 0.16507976688444614, 0.15113872866476738, 0.13785870174967474, 0.11383124266660984, 0.3194153038484435, 0.12572773011221042, 0.07987660941697898, 0.15178898409489663, 0.09932567425552877, 0.16439365853946056, 0.1527496123866689, 0.14453667486386915, 0.15210421395397958, 0.1311386091214034, 0.11471523918331632, 0.12201560510983392, 0.2239243593066931, 0.14914496952006895, 0.2676894762102635, 0.10907442654452978, 0.1005035880652647, 0.1926674050909858, 0.12667211733998793, 0.21018011375300347, 0.1155556912624067, 0.08178731696980615, 0.26183049705240036, 0.14124212906725947, 0.23997485126939513, 0.1621141792425225, 0.23579098464500522, 0.15624671183045835, 0.24298537762895708, 0.2399794784404578, 0.07984156089444315, 0.1441554848345057, 0.08752549938376873, 0.16860965489139482, 0.21431720304873683, 0.1865320826970762, 0.1534031313513556, 0.11781753521532783, 0.23505281296468553, 0.21756602871802547, 0.20620958729376718, 0.13908347715773892, 0.2725682918342852, 0.17317987497775786, 0.18469943184285395, 0.13861017271635995], [0.031341970823104345, 0.06710314282005833, 0.060439166132240534, 0.10676652538560091, 0.029178473407462723, 0.10828101992486946, 0.06423206744535316, 0.017168156787632935, 0.033210849975265806, 0.06234596663665387, 0.044030581691092065, 0.02480893388330456, 0.03339551929985324, 0.03937630260723733, 0.04872741312870095, 0.02321811208892013, 0.0074162218821114834, 0.01685654286355261, 0.05237774164866536, 0.029051881208414995, 0.07555756657834976, 0.09341381204825255, 0.01987179023994794, 0.0256867844596385, 0.03757181314511165, 0.027887126873998393, 0.013712516107085734, 0.014988486298299847, 0.04723253044029398, 0.010843206565046023, 0.05691629932111791, 0.06834442742289075, 0.03196093347674656, 0.0602751505380917, 0.0799751206631622, 0.010726801420171416, 0.06593819887888047, 0.0347362689283346, 0.03478774620640663, 0.04692422218560692, 0.040369692649091446, 0.025873141092879158, 0.032183614168916984, 0.050105363986785376, 0.052317906351339434, 0.019613649252982392, 0.021341570142296054, 0.022591536436530373, 0.03574309232194097, 0.015282307830338758, 0.033268804526737625, 0.04207813766815009, 0.05521572202504162, 0.05059748354758467, 0.06519653383762607, 0.021751069035681508, 0.05645557404345563, 0.014511742122140864, 0.04778905501288753, 0.027936574019071077, 0.08610924029903066, 0.016887791589984012, 0.04173196934824509, 0.06387075739762475, 0.050687820635615825, 0.03916056075644109, 0.17299632031110027, 0.07796141258891552, 0.15650777927329465, 1.009146233479823, 1.9584106221314401, 3.618784849682162, 5.59935208289854, 12.735333865688695, 29.998820520216423, 42.59048777241861, 53.57497561362482, 63.91619866894138, 78.59413931446691, 77.35925166837632, 74.95957697591474, 83.46083579524871, 83.99035576851138, 81.39729253707394, 78.69344588248961, 85.86574292952015, 82.92940170534196, 79.69620766178255, 67.74361610412598, 63.78621916617117, 47.52558646663543, 54.111865720441266, 43.32925834963399, 47.29047175376646, 40.038170122331195, 49.06583455301101, 52.311293848099254, 54.60243263552266, 63.38278770446778, 60.47746458361226, 72.03100204467773, 56.075439530034224, 49.334422772930516, 24.63757787981341, 11.625740451197471, 1.2849560884698745, 0.2478017111218745, 0.026284501579920613, 0.039272064853820114, 0.051490837828286236, 0.043188949836598295, 0.042906443423201004, 0.019206919767443213, 0.015960584841518393, 0.05865732989003582, 0.08011449503922656, 0.06520113802605099, 0.037117733680192506, 0.03168821766702158, 0.016898725579883304, 0.047178908116033966, 0.06282961709545025, 0.05782684461484033, 0.032462872369515325, 0.049691167059204275, 0.029912908493931738, 0.07427053886555857, 0.04226258482723948, 0.035857174305185195, 0.010061752832224293, 0.011589142546478299, 0.08634147219239705, 0.032871139776562495, 0.08923219006148078, 0.11769496114744295, 0.014387194420241061, 0.059271797522782325, 0.03162613198641808, 0.07186336803340143, 0.054296638681403095, 0.043259832121792345, 0.03877493890843565, 0.1238076379823108, 0.07648870814591646, 0.021765708975914507, 0.08529284338076269, 0.006054469474381017, 0.052680468952824036, 0.025754596647475998, 0.012669658810350926, 0.012084556285351997, 0.07455725493209978, 0.0036402997108281503, 0.04445760293052562, 0.040436246537513314, 0.0799634148396792, 0.023204330167162324, 0.05010300826641822, 0.05132218740219551, 0.08399645407353679, 0.04921172625355182, 0.017820202948285208, 0.020141700252650246, 0.0673931990299494, 0.06322867229520794, 0.01419868029188365, 0.09201434561081472, 0.1065620641794897, 0.03767808103152821, 0.03817244906038527, 0.05441861137026741, 0.01984847243875265, 0.018855714419436072, 0.03789702896028757, 0.053643456795403076, 0.08387970993475569, 0.029587911013814232, 0.03706383173384013, 0.04211949492474237, 0.02248669347365297, 0.017358309386538404, 0.05960529474841972, 0.06039725729234277, 0.048558862294040384, 0.038997629176705115, 0.05895163405746703, 0.11388737392882187, 0.037450828709669655, 0.07040978514499242, 0.020277500828547824, 0.005937501254882063, 0.059358798297903234, 0.02041432413182432, 0.027246457119021687, 0.033118635971820166, 0.0851530859607362, 0.04311457802090914, 0.05042591432650244, 0.03589398482994687, 0.07704214538417517, 0.026711689443477703, 0.07407962209394864, 0.03775138798500261, 0.04085314009458788, 0.024530560514258764, 0.038384563484860044, 0.0702086870648688, 0.0808661881714098, 0.04988688720209945, 0.057904617860913284, 0.06719265253313127, 0.0639963153779747, 0.06707439920113933, 0.0592895477799879, 0.014722033257355854, 0.042036014323633526, 0.05540488062486534, 0.04109292561488767, 0.030260589837487188, 0.022040311277153033, 0.06295204560662951, 0.028627788340072, 0.0371393526814157, 0.042239422158848856, 0.03483424774341045, 0.026528692105785016, 0.005049647964281781, 0.05626990497412701, 0.033185017490459066, 0.03740507027795238, 0.07292511993117871, 0.039688085070661, 0.023140388638562253, 0.02671198438732855, 0.010665101656359772, 0.04697840758449128, 0.012767254581464636, 0.04706629702160436, 0.01817955564136707, 0.04050685303105463, 0.04261604630418363, 0.063610321977326, 0.15295614969105492, 0.10415233461366546, 0.19396097519465033, 1.186833708517013, 2.0837223818225246, 4.861814600806083, 8.16943463779265, 18.69077636349586, 38.13065482724098, 53.58915498179775, 65.25875929863223, 75.54179007007231, 92.78450581335252, 87.95618580233666, 83.9527088595975, 93.71464098653486, 93.26242308462821, 92.71527597981115, 88.64844491404872, 97.15416739063879, 91.89513975574125, 88.93514663942399, 77.40753604519752, 73.45832901616251, 55.728984417453894, 61.79845609972554, 50.00225728557956, 52.752254547611365, 45.622303408961145, 59.05592310813166, 61.86069626961986, 66.70633746731666, 75.25262509622883, 74.47251273739722, 87.00817246590891, 70.2008633459768, 63.10663715485604, 34.80011540074503, 18.280586657985566, 2.6664247916590784, 0.30207833575625576, 0.10205995697047442, 0.021015063468967716, 0.021509408515187043, 0.02186491353166921, 0.10194078433297335, 0.041823907560037996, 0.03273324395019201, 0.05500820795855215, 0.034487286522503824, 0.1138781808737305, 0.028490765853935195, 0.11474808903350947, 0.06477176872712952, 0.017759226179952105, 0.04415419763855396, 0.07849381305277348, 0.10992989394693606, 0.028307134578485164, 0.0760328705092111, 0.041528841135122126, 0.029346759941789414, 0.04386497263406073, 0.06453120945802619, 0.05995443548947092, 0.04787512882162006, 0.008934388376562106, 0.018758626181572195, 0.05812823892601075, 0.02761877968066162, 0.0681625275061496, 0.020493334609894984, 0.05201852685140987, 0.037592099153346596, 0.014484218498241278, 0.019517260070349422, 0.01937134521863153, 0.07656145585520614, 0.0028911282049281705, 0.009766104180485973, 0.048568063010010994, 0.06494277487358739, 0.10915776158893302, 0.04315676648289927, 0.031374435714115544, 0.04169942593322166, 0.042736693660938935, 0.007060610092124872, 0.03281502766654857, 0.10727723023944324, 0.017601620826509692, 0.03447095352795816, 0.03558057826012373, 0.055910851055335616, 0.07520828411103257, 0.017454418947079012, 0.058259186334908016, 0.0791819132263622, 0.039791920627917976, 0.02022319285559558, 0.03237073880530173, 0.03197442045465353, 0.03887125914315543, 0.047045731391277046, 0.03632164192235759, 0.02792251630566053, 0.026199287704883084, 0.02983474645823721, 0.062197368561981194, 0.0583143255132581, 0.09709578382992938, 0.14870878969950063, 0.15536868313868202, 0.14864117477930364, 0.11268549688881445, 0.2660221318083425, 0.20322788116191665, 0.16856300013680614, 0.18159335899737575, 0.14734026555332447, 0.248265408820683, 0.12231288552885095, 0.12365894031620796, 0.31770649876806045, 0.1701734088841946, 0.20283244189716157, 0.10450120339350355, 0.1508556898202627, 0.252961328613662, 0.13605770564848377, 0.11344030799884951, 0.15148618018194554, 0.1641543786371908, 0.10879446737348072, 0.1585307876549421, 0.11807214453696244, 0.17730478347549516, 0.12321104701127737, 0.23132705159725683, 0.16278997604404727, 0.1749797219470624, 0.19727813590678478, 0.11902761705700429, 0.18943978473544124, 0.16634963422773347, 0.1231279188106137, 0.21975391454273657, 0.1954456382701474, 0.21505154428943513, 0.18337845111325865, 0.13820636777147172, 0.2067637293329162, 0.1163485769422785, 0.11619473882620374, 0.1790240686386824, 0.12722531709099008, 0.14149691458911667, 0.17391913450293003, 0.13146773581543278, 0.13577848192184203, 0.15663444425069517, 0.13660498353983128, 0.19937775308086028, 0.13855758844123733, 0.15745140041314787, 0.0795198652532793, 0.17643603976936112, 0.13272390550663396, 0.1003532356492454, 0.13201262351245652, 0.2068199601865584, 0.11714756068202758, 0.1402292229355343, 0.17315097814125402, 0.19982824342385416, 0.17985887464977082, 0.2037491120638386, 0.2847453819647912, 0.42281054441005955, 1.503016213255544, 3.26937202484377, 6.160938903208702, 10.601353664552013, 23.85391381479079, 44.972711839983546, 60.47585248947144, 76.02330023242583, 87.04616454339798, 101.51377985554358, 99.28761513002458, 94.92619837484052, 105.29904750085647, 107.64129084925499, 105.52672539987873, 100.68845041336553, 111.29484530418151, 103.1743388022146, 102.60353980525848, 89.26734001405778, 84.99527485139909, 66.93905168964018, 73.55442708538425, 61.37187873163531, 63.76158668148903, 55.322646479452814, 70.59371225295529, 73.82198764431861, 78.83847944198116, 84.37689750425278, 85.75372003739881, 101.87487325360699, 83.1490779692127, 71.8154364247476, 42.16347109886908, 21.124842397628292, 2.8520097751771254, 0.49928055234974433, 0.2345609232302635, 0.19908700739183735, 0.14212988707567417, 0.17193801580898224, 0.13692674046802905, 0.12482795218426375, 0.07609133067871295, 0.22692184684978378, 0.1650406504350324, 0.2385647898359645, 0.14533064838859344, 0.1415055100956271, 0.23342924282675792, 0.16893884287245814, 0.2074942554557516, 0.16798547709420805, 0.2154730918306497, 0.17981612694359597, 0.19783479071432547, 0.14546235422453574, 0.1799888950922797, 0.14713811027186532, 0.12008203749334621, 0.13499351759110728, 0.20476969439656506, 0.11331602555489349, 0.1354397331634837, 0.18639797134505165, 0.1262209605004999, 0.06984114106143675, 0.08840630131383097, 0.16191764704642758, 0.11794818384993462, 0.14929852418361172, 0.11799609498871912, 0.12327912924510818, 0.12125027561259848, 0.13285230184274335, 0.22711387444888392, 0.13380706190101563, 0.1037420102605416, 0.137021015247991, 0.11793656229612329, 0.10179269953720993, 0.18002767446300677, 0.16899576320523219, 0.1254925411194563, 0.2228817749287813, 0.14963620041887607, 0.16531072707185823, 0.24795952523427628, 0.18456080057207616, 0.21314367892280703, 0.1548525237388188, 0.12850391783661422, 0.15038609324443727, 0.3123899405041049, 0.08641228936011754, 0.21285875550200864, 0.17316230092077486, 0.17733453833047422, 0.16506030825116944, 0.14956625659138928, 0.09784460413239657, 0.13014189808839752, 0.11976912888067386, 0.1211604364817181, 0.1935765522742464, 0.17513813360804514], [0.05404218640779296, 0.04388393714062629, 0.0012861986620156397, 0.043797710114308906, 0.03721357510995962, 0.06694499162896987, 0.10066452781639754, 0.06593845168789549, 0.02957624157950763, 0.04297197841468357, 0.0341784649889075, 0.03155960874151319, 0.06874237945603748, 0.01893710934617106, 0.013151475446178548, 0.05216591833760181, 0.027454281451120496, 0.03382855049905277, 0.048613492023920825, 0.05131436947492823, 0.03163496689540485, 0.06639468002944224, 0.10900829017402665, 0.018425918026496808, 0.056240138627829096, 0.02872918390729014, 0.0652637274094647, 0.06986096741691714, 0.05979767474796503, 0.06695706517465654, 0.046654540084062085, 0.004116124820880472, 0.02294106405198334, 0.0769981412938045, 0.024937240204082865, 0.028002254567259265, 0.0545757474948562, 0.05740265407028699, 0.05340931351266561, 0.06366495170720643, 0.08087765650763627, 0.03850374761367998, 0.050777146487586924, 0.04120835591287863, 0.03714677224296235, 0.07802032475029269, 0.022010326595796693, 0.04547116023698642, 0.020478972376534538, 0.00904793122542962, 0.03989590174188057, 0.03481902174591538, 0.052638399234462174, 0.06339322415090377, 0.06258019418906301, 0.03068402195499549, 0.03165594046755183, 0.049201671349545645, 0.05546721719926404, 0.23523390082822693, 0.1406185794621706, 0.1786409787112667, 0.3131855074917117, 0.2509262926516033, 0.07301085283078494, 0.2516458330736045, 0.7450452050374401, 1.2470707729939492, 4.215432020925706, 9.192010760307312, 15.684390433372991, 30.642208860766505, 45.232184471622595, 56.207901893123505, 68.21120969710812, 78.89365934556531, 73.14215460131246, 74.15539695370582, 75.63489144848239, 72.21375311574629, 64.6746281654604, 62.1866334638288, 70.81748347128593, 60.665165685838275, 64.31285227498701, 58.40986559467932, 66.51550631369314, 64.41042907776372, 68.91619297765916, 68.9930949672576, 70.95402902172458, 61.66303234715616, 65.42777422935733, 72.02302394374725, 67.81694089212726, 73.87731659796931, 72.69764807916457, 75.36750347383561, 77.71283764992991, 74.18753685489779, 74.84547522760208, 75.66895331105879, 68.27672112372615, 69.06931446444604, 58.44452757989207, 30.723974589378606, 7.497909174811456, 1.0962480402761892, 0.17494707127972958, 0.04394025609437977, 0.016143690389130386, 0.021955294669756008, 0.03972093492085415, 0.048926707071762894, 0.002645215896453949, 0.031019872985780243, 0.018126274226233363, 0.018191602373976382, 0.054590253369702454, 0.026435945671232, 0.022277716179228118, 0.08421196992839537, 0.021317122361412453, 0.03639747696598211, 0.018441563457130425, 0.0437126781851534, 0.022520613931720296, 0.0453168471463986, 0.03525673757277189, 0.029592844620046597, 0.03388512609226089, 0.03321540819841527, 0.02020728695506771, 0.04512382363299689, 0.05648023824417784, 0.0650510537408052, 0.04140549714887335, 0.026422341864916588, 0.01535290762061073, 0.04784343576419258, 0.03372457704596943, 0.01508583021800845, 0.036731759431741895, 0.007802475752654456, 0.005186716415694044, 0.08581415855235631, 0.034632762788885066, 0.07804875427316274, 0.04015327664092183, 0.042664260047698216, 0.007330075295026144, 0.058238459826116605, 0.026014863528431426, 0.014828703339932667, 0.05143592081543419, 0.057608122682018634, 0.049229093466795264, 0.08002546796154592, 0.06128385467755218, 0.005195168280718668, 0.07147011211923054, 0.02770151143082448, 0.04938394281893008, 0.034278450954344966, 0.10552323363240688, 0.05999762752664186, 0.04395764629026094, 0.045221687534884106, 0.038640153399037744, 0.01926820297094603, 0.029031187258360368, 0.011758221024196717, 0.10415130805584694, 0.03008629717383414, 0.01409303293668575, 0.04975082232586799, 0.027462756298782847, 0.07060189701376424, 0.00230500869820976, 0.10917894392003936, 0.05835161867341208, 0.03818441152332291, 0.018035617296493823, 0.06690059683375782, 0.03580956960157041, 0.026020157195988203, 0.03884821521839307, 0.055050917360330784, 0.07044506349390553, 0.032562502104068, 0.0948510236377197, 0.0638779049979583, 0.020207413359575217, 0.017721052018685207, 0.01821841162088658, 0.05318912452146892, 0.055742388320786346, 0.056295461667281006, 0.0875022103108706, 0.1317721178695079, 0.046533662900929494, 0.0755167494137441, 0.032093298148303744, 0.09522758649602052, 0.0276029906085422, 0.04330803437398807, 0.03923681331798434, 0.0351180718280375, 0.022388705082478064, 0.05769143091334451, 0.02310613110180824, 0.005296682591565074, 0.0648889571969067, 0.0585864169613248, 0.06654317085180553, 0.035207891806719765, 0.04015607669228508, 0.04635562789776633, 0.018239735678258925, 0.023770492125843323, 0.07114060238123902, 0.023912877227450093, 0.046046331389656955, 0.03821937194574745, 0.019005067090714173, 0.06198695868313794, 0.05846054871536552, 0.03996684148366894, 0.052625961797011477, 0.02996019910149757, 0.005559607318812801, 0.024705669061551173, 0.0836331598580845, 0.04437887590498694, 0.01949646652886464, 0.13964826781903544, 0.13749707760589738, 0.18529633690993633, 0.28270746551213727, 0.26084610471321695, 0.14966379490590867, 0.4869866184890271, 1.4552856260730376, 2.7173849603822156, 5.661335337546564, 13.351766697822079, 23.812797569459487, 39.9986247862539, 54.421697662722686, 69.31935771819084, 78.86788937353319, 86.1954495214647, 83.2729934876965, 83.73453094113259, 84.06600259965467, 82.97355190400155, 76.45455698813163, 73.0365094830913, 78.92319479296285, 70.83393389178862, 76.71733225545576, 68.94128830202165, 79.11109201369747, 75.31120961712253, 77.77037097561744, 79.03139729653635, 81.7873251822687, 73.66977614741172, 75.28481206586285, 82.62474336931783, 79.3400642948766, 83.82694198239236, 84.33786992103823, 85.21120917412543, 87.20960970847838, 83.60950931426018, 86.23076654249623, 85.78748379984211, 79.1769721431117, 81.61394857591199, 71.78120197788363, 43.51097783734722, 13.63448819806499, 2.4486047894723955, 0.2762744719943693, 0.08904421506750007, 0.027389742373939485, 0.01754507779203836, 0.07205848296683642, 0.03615565748224336, 0.03222823879050632, 0.08380834884460896, 0.025094157993613232, 0.013896928792218528, 0.050949749927366936, 0.01147408475874052, 0.04178547292887684, 0.09965909870281335, 0.11262205714780478, 0.05533930732898655, 0.03692078779661848, 0.024071478495194067, 0.0393784974491404, 0.020804383544131153, 0.056221047716756026, 0.04896771958878925, 0.03664875763558573, 0.051348288017775745, 0.007777877148210763, 0.022890879547283537, 0.03815525421692479, 0.06948921559078079, 0.012160117452543591, 0.04268238568798669, 0.01837121168782394, 0.06540675602492786, 0.05632742285548199, 0.0333857401874998, 0.03575030503974807, 0.01828681178120596, 0.044391374629471576, 0.027694248917302298, 0.041253788757228085, 0.025817622701006553, 0.02174992947989414, 0.03823473583906889, 0.016495952938473033, 0.0877616306646697, 0.03593031271931625, 0.0023912172905364705, 0.046945335568800095, 0.015540003528698318, 0.027891673605829, 0.09976324069524005, 0.07164967546780264, 0.062300307796366756, 0.08787027725409116, 0.03702089633612383, 0.06321888935241489, 0.08788287940044558, 0.05641978624607286, 0.0675583369429073, 0.036241229503385486, 0.07757555708409318, 0.04394747647306612, 0.020225460475851453, 0.030984479723678484, 0.06017590384750117, 0.07195482360980204, 0.053500757597747355, 0.0172475426487865, 0.012988781353699104, 0.15851604812327894, 0.17003952735854735, 0.13928699607570327, 0.23162365019802125, 0.2653292206025893, 0.12156155245799212, 0.2512767012681692, 0.13606627051147724, 0.1280693697833246, 0.10924318039249029, 0.09990440005616796, 0.1520157920857591, 0.20205231924210826, 0.07094932554830467, 0.15274981156952921, 0.14024026992340244, 0.1509534426394009, 0.09113539761352925, 0.17417237252718018, 0.2099551290514008, 0.15681038400338543, 0.33125102519989014, 0.29345469849724926, 0.16065004732339613, 0.19094154689340823, 0.33476868644356733, 0.14066154167296427, 0.2448536209281414, 0.11999905484938815, 0.17091783184197643, 0.14267883503869658, 0.10450340206584624, 0.12475554921454, 0.1404615467594516, 0.1545378761065583, 0.13228550403108522, 0.24423275263078753, 0.2613269627815293, 0.1264660090448395, 0.23091016187062188, 0.14541432051168335, 0.14387610789027908, 0.09076023669612986, 0.10787153826846231, 0.1901105713219412, 0.14545404983143653, 0.2107893221921498, 0.09275182781200256, 0.12001253799685549, 0.11727261687478713, 0.07467183104205517, 0.2124103489181688, 0.12442787808756675, 0.22119760723604312, 0.17011334759093102, 0.09772055917569707, 0.16382348994093557, 0.16773202456533912, 0.1093529454702812, 0.5257527818602901, 0.34806478588331136, 0.3684868819771275, 0.6243636807607067, 0.5883500713013834, 0.6310165721562602, 1.2210929153427001, 2.633261642148418, 4.3078965044790705, 7.6962948133868565, 17.44382742912539, 29.3914395378482, 47.70001426819832, 64.67744050487396, 79.67182620879143, 90.14535473239037, 100.64176636357462, 99.23960531911543, 96.76924951614873, 97.47254617752569, 94.98810906564036, 88.73399180750694, 84.98430005965695, 96.10551388032975, 86.24715420507616, 90.98445169387325, 80.98133302504017, 88.5898760826357, 84.96162876006096, 92.16300625954905, 91.87530040740968, 94.21908916965609, 85.60501513942596, 87.47400099231352, 92.71692337528353, 91.78739224710773, 95.19554753457346, 95.63167587403329, 95.25049209594728, 100.76937675476076, 96.05865724625127, 97.92102998302829, 98.0771795395882, 91.78586252274053, 95.69251968014626, 82.18462990176293, 49.74587940400647, 15.254269203832074, 3.014919291580877, 0.3395987788756048, 0.2112261455265745, 0.25712607368346185, 0.09486516562080193, 0.1147130175283359, 0.14852650673879733, 0.08462269264723986, 0.10888426819996488, 0.12444670086786633, 0.1772185066534627, 0.1272343033023419, 0.11673349015895398, 0.13805166397604252, 0.23047214343903527, 0.15026966320170512, 0.21415160548302437, 0.11476121978053164, 0.14356395770465175, 0.11053542516404584, 0.2641744196655289, 0.07278542379818617, 0.08256675780660684, 0.0787038207354565, 0.13909833926346996, 0.08149366014667096, 0.11469330608604417, 0.16106695237178958, 0.13972815546777942, 0.14017530566742345, 0.12548874898423112, 0.11514866874823648, 0.23623421247447693, 0.1835487524588262, 0.1529433713444779, 0.1042434377896209, 0.13341536114533104, 0.10444455885238225, 0.13169806781074694, 0.16149937836152894, 0.13591122963736135, 0.11840972884167587, 0.12495477037924914, 0.13937589291843677, 0.15649213575788085, 0.10791070834403077, 0.09119551253294753, 0.18794767528532014, 0.10039478059737914, 0.1280469846941771, 0.16523333686974742, 0.2116472640585515, 0.12062009168608535, 0.21721810222633425, 0.1306922556532006, 0.14177344168626493, 0.16915483370182977, 0.19429054621967579, 0.18760708791594352, 0.14364884024666202, 0.13389638775298673, 0.12757430844489606, 0.15060396865010262, 0.221167377406551, 0.17093664696139677, 0.27968635181746176, 0.10950649247294474, 0.20885565498423195, 0.08924129884690048], [0.01572505398202808, 0.016938987330743865, 0.024652196124436396, 0.04416393844651119, 0.08471812421996748, 0.020440813537026127, 0.028876023810176604, 0.05436661315240687, 0.035990795360938195, 0.012016254758852865, 0.07241808463849368, 0.041497998435290596, 0.04665624462969361, 0.03190444598364974, 0.03754571635997103, 0.05391537587368681, 0.03495275771485702, 0.05104307475830278, 0.02841381423716103, 0.04759727256192316, 0.0699093382084562, 0.03752902330410096, 0.019156965089120695, 0.03555861451933461, 0.03352985281737582, 0.06325454308441089, 0.03562177846869154, 0.09510311253008344, 0.03958987642920787, 0.03891488018956396, 0.06898806385335422, 0.0244626468197713, 0.09546774739940321, 0.033437428139751, 0.0518118554816371, 0.059716074892710296, 0.044598118777597145, 0.02260674328182734, 0.014408546248300663, 0.038910494336197456, 0.058979929514950326, 0.032744999569390094, 0.0159973110966084, 0.019142637329716838, 0.037782016180215344, 0.04965654754590604, 0.035282278944167404, 0.01495022978258109, 0.05755397558753049, 0.02696198952053824, 0.05521087651892055, 0.010834252912430994, 0.05088543301568397, 0.08727493500637432, 0.11769627881867271, 0.13124710249324, 0.5500896178906964, 0.7260047944803393, 1.3287510674807335, 2.83897279731689, 5.671473193553187, 5.034934782212781, 5.064424141760796, 10.390738075779332, 11.566858810763206, 10.231832073580835, 12.501707692300121, 34.026969171339466, 32.85092100020378, 52.18155360990956, 61.33125474376064, 74.27852799815517, 69.3775970705094, 80.21905960575228, 72.08582109020603, 66.40805690519272, 53.76141763502552, 54.599247670942745, 52.02160327665268, 56.32491404010404, 49.2146885010504, 46.95177901175715, 43.4527345626585, 39.410712488235966, 43.860512010512814, 35.51676381018854, 46.05556841819517, 40.054855885044226, 47.53990704013456, 45.25776224751627, 45.70180592998382, 62.511605754975356, 52.60181596202236, 55.510853567431056, 62.09590904174313, 56.08178592497303, 60.96717249962592, 64.55133630383399, 58.16980477302306, 42.94749406076247, 65.21620550463277, 68.43217249839537, 63.829074982673895, 68.35352897644043, 78.48006110037528, 77.26000785827637, 53.549135038929606, 18.597227834886123, 5.592289365107014, 0.8390566346145446, 0.19580600602972895, 0.07627223468115253, 0.035524669163409746, 0.025100727197563937, 0.10305850661449856, 0.054654102967751604, 0.025908990177295865, 0.07272079662089387, 0.062196529695704106, 0.0922387940508704, 0.05196991857261427, 0.022100535364100532, 0.03680150407636839, 0.07398043669039205, 0.07991170390479027, 0.023959694775722684, 0.024496444703770742, 0.049126399380545464, 0.07518763804147321, 0.04369349534352941, 0.018740157716937603, 0.009518492114429754, 0.050347114522610946, 0.016013322334225862, 0.0284834286468404, 0.04879985823326054, 0.04359089318783053, 0.019957389074167418, 0.0808169900049125, 0.04472592905644448, 0.028593998116951798, 0.033424852806473934, 0.02703693207173098, 0.04573545290998394, 0.04359090084870977, 0.0051573034274512005, 0.03882410643141597, 0.09605762744021994, 0.07959999805015903, 0.024006179075748212, 0.0842843882198776, 0.053598161846879995, 0.011974836215226641, 0.03832817558319338, 0.06674993798256883, 0.004383568509271549, 0.06101823667244566, 0.07684946661033938, 0.0107151473076233, 0.03403248310449623, 0.010027750019705104, 0.05440115222647306, 0.07225788799264739, 0.08202399217313336, 0.03934794586272009, 0.04680668897626381, 0.048130416131067666, 0.025174160555545843, 0.05104181837410696, 0.012414200088730263, 0.05427799210132611, 0.13627458513984758, 0.04576519627364413, 0.030336398068034363, 0.014131063456466843, 0.0682720780793217, 0.06246625010164515, 0.031849731984097636, 0.051662472166842034, 0.030191881326778285, 0.07114411106393223, 0.028924511430124124, 0.045026921171454654, 0.01934585747339072, 0.05369602957920683, 0.007810817971344918, 0.009358690003864467, 0.07248308719886888, 0.043837665429999756, 0.016122354840439175, 0.03662773618294347, 0.04644394251367739, 0.02028892702993847, 0.028725060439037702, 0.043658837525834965, 0.05150646602194156, 0.02450802220752643, 0.04785414567337402, 0.02684618192424457, 0.032115367226182454, 0.04127470678800056, 0.024067671038210395, 0.04710468568749005, 0.007359376242910062, 0.011257613209196398, 0.023204709380684842, 0.045586494773986845, 0.023050633777353554, 0.09565939961542046, 0.0047715575689630165, 0.06833734110959115, 0.028437285255941174, 0.053656989738585494, 0.0571557094583348, 0.029741444609939095, 0.026934222663722696, 0.02028008254485265, 0.03146387456405548, 0.032370696670465895, 0.033002742190635016, 0.015482942427268193, 0.033984047195483605, 0.011491175222721313, 0.024908174828235662, 0.037774968171311964, 0.046935123616769436, 0.008909017459729747, 0.010277360617633789, 0.12552200486102413, 0.05302810433110403, 0.06428213129120489, 0.10333478856351107, 0.6716731034459607, 1.01508611152249, 1.432063601190044, 3.1630015132888674, 6.607467897476689, 6.622212086954425, 6.2172989499184395, 12.27978979387591, 13.701516601347155, 11.972134767040131, 18.961955308914185, 44.20961080058929, 43.18777453514838, 66.11877426024407, 74.36776976431571, 85.45624748353036, 79.79737343326693, 89.27754602124615, 80.58538544562556, 75.10838385551207, 63.66704187085552, 65.4943839196236, 65.82074472981115, 68.23974886248189, 56.18530119619062, 57.65322077658869, 53.36604664402624, 51.817667484283454, 54.10156557636877, 45.52433829153738, 53.57403032241329, 50.34692771973149, 56.214158073548354, 52.97126793092298, 54.525616938068026, 72.0219962827621, 62.50945629612092, 63.662719418925626, 70.00394467384585, 64.46842916550176, 68.66389043869512, 74.10314313827023, 67.68813810040875, 53.59750963026478, 72.41816351490637, 76.03500458502, 73.69269847869873, 76.49834632873535, 86.69197451683783, 86.52747815655124, 67.83233227268343, 28.341564209230487, 9.44069295160232, 1.6177395346664614, 0.33073952361460657, 0.060745608962831966, 0.08655342573840773, 0.032043546483281164, 0.05210391118101055, 0.039417927994603114, 0.02208231396282152, 0.03903265471660322, 0.06368988020826252, 0.011441850651716514, 0.01870209272319992, 0.02856354612196165, 0.04643531636364999, 0.08705219494238978, 0.048420874537118984, 0.009974945494304261, 0.037657323879219835, 0.02369846262398266, 0.018187672342924822, 0.027313614301683924, 0.03742360194484073, 0.00711635783156981, 0.021041164084547953, 0.049426790116535085, 0.04139544990574641, 0.03162129031073663, 0.02812027041199467, 0.04450303194443545, 0.0456888058162745, 0.022939604654487585, 0.017972190962022832, 0.03404875098156833, 0.037604352729695464, 0.030378634410519755, 0.05333437096147288, 0.057616044031155694, 0.02655354208282886, 0.10707581040239143, 0.08034894858757335, 0.0028344482322403743, 0.05329291794389006, 0.050518220260498986, 0.010849522959981716, 0.0523243070159468, 0.03478603399989586, 0.05636299231780633, 0.12096632512346392, 0.05067804918414162, 0.040936567069542025, 0.030007491624283216, 0.017122243223110997, 0.010495292522283572, 0.010265416349284351, 0.07272016076791672, 0.06999639644017143, 0.037686259020119905, 0.03731730724534681, 0.10074310545479098, 0.052119022265316985, 0.07672757436070712, 0.015401902773808089, 0.06145565755545132, 0.04602224175487796, 0.027343177634681907, 0.025800152065893336, 0.04454809323614163, 0.14125809433960146, 0.10078033732791102, 0.2747464023770825, 0.1776417395881107, 0.1735117289447977, 0.11063864019008414, 0.169759874622668, 0.15320992397685207, 0.20208627225891237, 0.05209586725780561, 0.2512948422302162, 0.19986562851455905, 0.1447446677353113, 0.10571899207969827, 0.19681966292761988, 0.11418974883253537, 0.152679760489733, 0.10478861660005585, 0.14734817158070304, 0.14939931071093007, 0.17105209641158584, 0.11442800983786584, 0.11037692157251221, 0.11500079079621262, 0.21861800533388892, 0.13100419133420915, 0.14791970381573324, 0.13934440670474885, 0.10193436451616789, 0.11816235905092572, 0.16743853628154726, 0.12765670886203168, 0.22660652506014994, 0.09681016326911988, 0.14610589872444832, 0.1949897393464081, 0.1331832824695495, 0.08572655639821485, 0.08492974068729148, 0.18706652095481274, 0.13068968159777503, 0.15068483689138967, 0.0940886895442682, 0.11036349205119957, 0.11610601052281358, 0.1549569874881737, 0.10215954073975164, 0.10383681364117131, 0.17031752534451025, 0.10201810558717098, 0.20828410742744324, 0.1131551853951908, 0.1968071144074202, 0.10674810097102197, 0.2306095796126512, 0.40363904088735586, 1.2332353476555118, 1.9195727835739813, 2.7065239173750726, 5.497588640259159, 9.775139727900106, 9.511954572892959, 9.438900428433573, 17.253788594276674, 19.41836230216488, 18.231113803002145, 25.520413191087787, 52.86205345584501, 53.70149558590305, 78.22702900055917, 88.84841519017374, 100.8002850317186, 91.7842229720085, 99.83367966067408, 92.33573175245716, 89.24556301486108, 72.08002382709135, 75.3848481947376, 75.21908098651518, 77.14892633499639, 68.7003057233749, 67.71569667323944, 65.14202171756376, 62.06507136744838, 61.547624449576105, 52.70171480794107, 65.99825551432949, 57.80231791157877, 67.04956839161535, 64.20627755503502, 65.77460981184437, 83.54932446633616, 72.882172061551, 76.87449378352012, 83.15277284191501, 74.87025676235076, 80.19419962360014, 84.2682243162586, 76.9999704053325, 65.07288602090651, 84.44085567228257, 86.89381968590521, 84.01361542363321, 86.33729027163598, 97.24359743056759, 98.37556208333662, 77.31391691392469, 31.951796085603778, 10.375274131374976, 1.766844636970951, 0.514863056521262, 0.143963503200681, 0.15169922923368795, 0.2665389347220621, 0.16478471578128878, 0.19902930564938054, 0.18087820059830145, 0.10439184434231251, 0.18069576442001328, 0.13160169394987245, 0.19936837616466707, 0.12121480574170429, 0.12073819180049243, 0.27805277657124305, 0.21697917472450964, 0.10319676250219346, 0.12911727081143087, 0.16056818316780752, 0.2136733061483791, 0.17858341486463625, 0.16879705531943232, 0.13019992158778254, 0.13330234785474118, 0.09715379200755589, 0.16818533411189435, 0.1315224498149849, 0.16194976145221343, 0.17793150468459054, 0.22284912426144848, 0.14545817138446918, 0.11032397723606518, 0.08808375531507116, 0.14993053139938464, 0.17156431811951822, 0.09124084195542721, 0.22829688274331633, 0.17803016148747938, 0.31302922555515844, 0.19115520881549006, 0.12245271189679062, 0.23719669469902593, 0.18809874782398825, 0.18291881368044885, 0.24060356430709365, 0.18880508089017486, 0.1569788620596932, 0.2521496431361283, 0.172609047543618, 0.10020939498058251, 0.15467390267839357, 0.09551543637268967, 0.18269001386098324, 0.14105549472714626, 0.28240789449022663, 0.13582714382679234, 0.138152297285776, 0.10192862651761501, 0.15377590973531047, 0.14007620453353853, 0.16971332712038872, 0.17941826684100015, 0.164224429716987, 0.16176853569284563, 0.10244781196477915, 0.17128727008258143, 0.1944015676816625], [0.0772076127149405, 0.0067793772999016995, 0.09975842966307556, 0.04847502929248637, 0.06816978235879252, 0.08534286126133897, 0.035079020496097305, 0.07678926742124943, 0.020529905732180324, 0.044542037311100194, 0.03394719836632571, 0.05805475577231377, 0.0721852628574256, 0.020266321690512762, 0.03640539065423993, 0.05974139792904739, 0.06517698327379842, 0.014438724366857883, 0.03384875606805567, 0.04108848996580609, 0.034219538792967796, 0.03384443916260235, 0.06478401847303876, 0.07169976995717134, 0.038142157943859216, 0.06017646692212551, 0.05185439251363278, 0.038894724416276144, 0.007813562002528699, 0.015066038336484663, 0.0424788782613412, 0.05022429147615068, 0.053191024419521137, 0.019949023394034277, 0.016583825138607816, 0.039866051125910976, 0.010441448990135424, 0.029934445140703075, 0.054994353258441535, 0.02748142011583813, 0.030555541349214413, 0.10057507172947931, 0.0610311490844094, 0.025416140917748697, 0.06811648562190033, 0.028919074121081544, 0.04748545053805556, 0.07336287023199183, 0.04456898445383676, 0.03994363285000286, 0.0363643474936966, 0.04742241299320613, 0.11148751157546237, 0.15040674697487585, 1.864011184342446, 5.068977523234583, 7.987956375845018, 16.462411188310195, 19.918313487883538, 25.320854763830862, 28.965787849118634, 37.948429353775516, 38.705270290374756, 44.26537513732911, 43.59341821362896, 41.5843919784792, 57.188694477081306, 67.9567341650686, 71.10152582968436, 68.77050045997866, 71.93229952166158, 61.62047463078653, 68.12567064839025, 48.32848387379801, 43.251156114762836, 42.33920897206953, 31.992025875276138, 33.33409424751036, 29.493882040823664, 25.31500650990394, 27.17001891905262, 17.535732484632923, 14.057035330803165, 17.40393300210276, 44.88726300577964, 24.19584055100718, 16.60811939547139, 30.77972519782282, 28.969396429677165, 38.301764303638095, 48.73592007544733, 37.16435540106989, 22.45394733644301, 36.128602566257605, 34.6127280881328, 32.99578589777793, 45.66926594703428, 45.04596210295155, 44.33876660562331, 31.09390900981042, 45.32301872007309, 58.40599813768941, 54.53801555018271, 57.81017441903391, 59.25710539663992, 67.43883225225633, 65.59032901640862, 65.48105962814824, 44.556148282943234, 21.766646100628762, 8.816602672300032, 3.4264563312453613, 0.6351877063993485, 0.07787994679904754, 0.0833953585055086, 0.025165745079697623, 0.030267658913808487, 0.029203999457099748, 0.03758175313592919, 0.03597288422526852, 0.026307340576163223, 0.005333929307638638, 0.07982389490690925, 0.02540408077860071, 0.03306530476097138, 0.07091848284847314, 0.024719029634950623, 0.027767902525562434, 0.019299352105947274, 0.03074645237516492, 0.08500343834560725, 0.03685220377519727, 0.058181589289057645, 0.09346993564958535, 0.06402972064191295, 0.03241450923885549, 0.05645121883360609, 0.05138965293524727, 0.05711810220213187, 0.012296900536204058, 0.10158970921991334, 0.010605928067478442, 0.01016082811064177, 0.008975461223012498, 0.04547061248412056, 0.0755632279681102, 0.0589676108211279, 0.04729358381741951, 0.13486234801671199, 0.08709004734672847, 0.0240459984108325, 0.04470634784909987, 0.02075864426461199, 0.08972937346345956, 0.05908525128278041, 0.042897081828766295, 0.04815642864653661, 0.019233861164520347, 0.0188638981536872, 0.021741694034708124, 0.05534984869882465, 0.06235640075418258, 0.01388674556848503, 0.008812149472144103, 0.06840160822555905, 0.042589961010361874, 0.030068273040195628, 0.01888996429531084, 0.023280027314960476, 0.06665267545970217, 0.016645470318654855, 0.016124561173661102, 0.0678841388153453, 0.07268875882390045, 0.024873668312906258, 0.01807630039571274, 0.013336792115061996, 0.050013027409271854, 0.02514484428590344, 0.013149283477105202, 0.12343591679969143, 0.058931275270879276, 0.031307232566177845, 0.07909925233933233, 0.04558314696975774, 0.06717747633135127, 0.010245187797643726, 0.06494954709083804, 0.07173248957241736, 0.03230126229144874, 0.05537757725124398, 0.043537247880932786, 0.05785215999029818, 0.07028312016759189, 0.05874678597695405, 0.07049172590937346, 0.04376730791503384, 0.026142319491613778, 0.05127277473107942, 0.11176619137967787, 0.060687979998727964, 0.10516645882519023, 0.03664896064888566, 0.014519389594844995, 0.06589177395066907, 0.014896395826531995, 0.03072244126439816, 0.034042652921691056, 0.012784028076566758, 0.04252736396606892, 0.028725941440150626, 0.05415716854434821, 0.04023359712934302, 0.018138807424674594, 0.05598633752895459, 0.0630644383660007, 0.03853077136520897, 0.06692844412980542, 0.0321395909263482, 0.04543102106019374, 0.01755903399879894, 0.07415443057975463, 0.02445111719651088, 0.05018976006296374, 0.04029158232433181, 0.030637813446622704, 0.07195424904385883, 0.09126353347974439, 0.0777516347326098, 0.31444464960405905, 2.7768745681931897, 6.866295299222393, 9.884008053810367, 19.805233517000755, 22.910215085552586, 29.603580928617912, 33.45692326945643, 43.729967686437796, 44.350886729455766, 52.23834953000469, 50.958013380727465, 50.91520071029664, 71.52738540403305, 78.81809096182548, 80.47770853965514, 77.76155348747008, 77.72840945951401, 71.58361650282338, 75.70220716537969, 63.0016274606028, 52.99629657499252, 51.85629106337025, 43.166174042609434, 45.1380632769677, 41.757697982172814, 42.33355683665122, 39.16660378056188, 29.936266560708326, 25.63485814679054, 32.67127056275645, 60.86632051775533, 28.988692529739875, 29.846344263322894, 41.31241090836064, 34.585400935142275, 41.883296197460545, 48.42236188150222, 42.51185601757419, 33.88032744007726, 48.175735012177505, 46.201806145329634, 40.0671015247222, 55.08341720027309, 52.373408502148045, 55.18052331862911, 39.58837232282085, 56.77674754973381, 70.26505685621693, 64.62541026453819, 68.92973299949401, 69.10376071929932, 75.14777229678246, 71.89910842526344, 78.91708374023438, 57.32036452139578, 30.50982298389558, 14.063276802339862, 5.2828035719933055, 1.61598427401435, 0.3026142908680824, 0.1463615422647807, 0.04700900513618704, 0.012667118271272029, 0.00712880723914432, 0.05463421532523729, 0.02690623747184873, 0.0201228104396573, 0.03277269364785283, 0.06962453736172569, 0.021408997370951602, 0.022608694890814445, 0.05730986550089814, 0.0269657950623021, 0.028043665450006246, 0.02118108621347816, 0.07442916503116008, 0.07108555130300022, 0.06116727907811442, 0.04109677520670718, 0.0837995847987552, 0.008711855156317113, 0.005261343434422968, 0.023850157609089248, 0.01972604009713377, 0.09443259407435695, 0.03395083728396604, 0.09798793918302945, 0.035104163501772194, 0.019497215379810622, 0.04349406733508072, 0.12725409135342608, 0.0790540531517998, 0.005108004711913847, 0.09482400371663033, 0.0478212115535092, 0.08930085452213403, 0.06259657697932375, 0.04428669254505827, 0.06515448327146231, 0.049402838377582456, 0.032496262311695084, 0.03217486161438208, 0.029254722138566357, 0.09429378660335656, 0.03880061434521791, 0.02030305177604239, 0.02784111754848592, 0.007268926156910077, 0.019543326211973064, 0.03861841182374666, 0.0567894428217363, 0.03924196525927513, 0.05134610849763117, 0.050685288715026075, 0.03855985589325428, 0.09712406779609381, 0.05682951688105541, 0.009623635766817438, 0.07667226281257407, 0.05971884430055657, 0.034282572507377596, 0.03176276568293331, 0.12109348805801523, 0.09656265558254334, 0.16856801035183092, 0.13165761836834494, 0.17536255140458384, 0.10906619109934378, 0.380461142668801, 0.31269551765534187, 0.18392330816676541, 0.13136828228110267, 0.10843629062536264, 0.18192512103386466, 0.26031676860105607, 0.1449086411946243, 0.10249247489076468, 0.11003931428516105, 0.15111127207356115, 0.18779608180686352, 0.2363346466013501, 0.13744185798831526, 0.12248892487297136, 0.16694128393165528, 0.0855119598488654, 0.20832772847385178, 0.19096923331099172, 0.22204067167495528, 0.10620484504127696, 0.11346863026941016, 0.2207264784843691, 0.056053328087493304, 0.19456377913874967, 0.11344273649756947, 0.12402634076293438, 0.08890325488943247, 0.12202551062669485, 0.12417308490483031, 0.13293546834780326, 0.16426400581915535, 0.08476566763654833, 0.19883743126786527, 0.10308422418611665, 0.19007154680307836, 0.12679495187776704, 0.11615701665681218, 0.17126171338942744, 0.2428745093845552, 0.08750506781882818, 0.23949716480508929, 0.1468907251593567, 0.15651519500440167, 0.179130416964331, 0.2769912238563261, 0.19589681809227313, 0.8704203968086551, 3.997711548882146, 10.219937486033286, 14.596115100768305, 25.35453615650054, 29.982197515426147, 36.9670170353305, 40.83793747809626, 52.12144720938898, 51.96533295416063, 61.38870569967455, 60.538351535797126, 61.91604875749158, 84.72820851110643, 90.5084877629434, 93.0424722548454, 90.03268857156077, 88.27723180094074, 82.34326624101209, 88.37496157615416, 69.09039328175207, 62.09785061497843, 63.99331638889929, 49.96991342113864, 50.80484482549852, 46.463647888552764, 42.527533731152936, 43.81227470213368, 33.663467437990256, 32.09075977725367, 32.648399222281675, 60.108926526961795, 35.62728835690406, 30.04711470296306, 45.45324140979398, 46.42143534075829, 53.66233464210264, 64.8984464522331, 53.49303337835497, 39.11373807537941, 53.14999072782455, 54.062996910464385, 50.41590259921167, 65.07234473382273, 62.77261203335178, 62.89619022800077, 49.27563821115802, 66.61646027718821, 80.21578834902856, 73.08256595365464, 80.37324013248568, 80.21549809363582, 87.0109651934716, 86.34562923062234, 90.50851914190477, 63.94598122565978, 35.12642129775017, 15.675627858408037, 5.951174959059685, 1.9469653911167577, 0.4530207620513055, 0.24842979596747508, 0.23627155159990634, 0.10256515365214118, 0.16861023711821727, 0.2328299169218348, 0.1724889249570908, 0.16083867349211248, 0.08103402271386116, 0.19852560283916615, 0.0902783444091197, 0.14981806969210026, 0.15078087367357748, 0.1085582365011496, 0.1707815754437639, 0.07591546753481512, 0.10992010334326376, 0.15633720213607435, 0.17657839422745092, 0.2373538959410883, 0.13397420696433515, 0.10646268725395204, 0.1283336394736844, 0.14375669010464223, 0.11885755319869327, 0.1926313836367861, 0.15441320295776093, 0.1397766335116279, 0.19303411605858034, 0.13989986641512764, 0.16553381187540872, 0.166722244072345, 0.16589946564166777, 0.20606030740084189, 0.20000896356519193, 0.25032649177216715, 0.1515445714035342, 0.1439476298588899, 0.16860283670886872, 0.12081716780460651, 0.26352652378620645, 0.11003247311999721, 0.08918826257990253, 0.11552916163758886, 0.14861089898453606, 0.11324051992907641, 0.08487453639146783, 0.12622782464830146, 0.19460422858115167, 0.09141603094195166, 0.112348196036633, 0.1334135838213467, 0.08435463082165488, 0.10707647689888555, 0.14143034154849668, 0.11339125538905782, 0.1827644009984309, 0.1968769203390806, 0.16866358748126417, 0.16222847956082515, 0.13380266455633025, 0.13286662768692742, 0.12148766327769527], [0.09074223362990926, 0.04000888821939307, 0.02891325376807682, 0.03995374521060337, 0.005171020231735443, 0.06385858043006833, 0.020771683081083243, 0.06420307867829839, 0.0857831779566984, 0.012293747126785739, 0.0224709676037873, 0.032558261807407105, 0.019681185649167147, 0.027218807090614593, 0.0394134157367291, 0.07251576850971869, 0.014910342457193523, 0.0377676175576785, 0.03977805060604888, 0.010207506805478085, 0.0344942081268997, 0.06326491974534527, 0.07911784529325463, 0.02130001561806327, 0.11188498097321681, 0.03307147559920146, 0.07485099602490664, 0.036160426379572, 0.07808204079347272, 0.09014425603973289, 0.03729573420939907, 0.04954781285637329, 0.030669906784990625, 0.04726199035142218, 0.06950056901381862, 0.01930628903210163, 0.02062385300955465, 0.0499477643790024, 0.03136587851200133, 0.06768035942748671, 0.01801030958191522, 0.06024086044260091, 0.08835258322858042, 0.10918147201018949, 0.04895733909741525, 0.08291540442094689, 0.01063264825666744, 0.027222135742645592, 0.027290624003076268, 0.012533791201759972, 0.10483551650278031, 0.509034843454438, 2.9949757552916005, 12.390462410065437, 26.196555283761796, 37.016081963816, 40.6085023572368, 47.00099299030919, 56.157432756116314, 59.316788181181884, 58.26625977793048, 64.50754304086009, 70.5530764979701, 70.72886928435295, 71.04122331065517, 71.35263596811603, 70.06382357689643, 61.589130970739554, 61.600023392708074, 55.13336858441753, 56.91381869777557, 37.73175370308661, 37.21496574340328, 23.676465788195213, 26.573910828559633, 27.538674646808257, 14.486081830916868, 13.168341959676436, 18.369145931736117, 16.47028338524603, 21.362430164890906, 45.64926185915547, 32.71719367273393, 21.151910674187448, 53.205696229011785, 63.8627524529734, 18.491937691165557, 37.03798447885821, 42.09712028503418, 27.74515409623423, 42.625479236725845, 61.21078698865829, 26.88476258708585, 27.846745444882302, 25.72705149650574, 35.25388263886975, 31.572950040140462, 40.0852071854376, 34.35471457819785, 30.66147162068275, 30.412318744967063, 29.831327469118182, 30.052847246969904, 30.265906472359937, 43.4979320341541, 54.35396617458713, 58.91635733266031, 67.70952286258822, 64.50799019105973, 57.07257270812989, 43.322629544042776, 30.177235411059474, 22.37005372201243, 9.13747706720906, 3.56929924699568, 0.5508402614824234, 0.3025542295748188, 0.028572199085066398, 0.05538286708836114, 0.023693222582580584, 0.06659433786426822, 0.011486379512315317, 0.08383994231060629, 0.031668456429014766, 0.023810786435440667, 0.01897952188887904, 0.023980524706383868, 0.05303508722253385, 0.02578082175234393, 0.030118457544895432, 0.05846413017641153, 0.017882166054820823, 0.023799071035858606, 0.036398963176555214, 0.09116476176366692, 0.052203249802152, 0.05832958215427014, 0.039094933834407604, 0.015741196412202573, 0.045282679624975695, 0.0388687655269619, 0.03988138437571545, 0.06564135512998027, 0.04691812029529003, 0.07844514348694394, 0.05966164434569017, 0.030214253009387085, 0.04835060129182474, 0.07003453229704211, 0.05822460129556637, 0.08641692419205943, 0.031722643743118936, 0.034718173931563096, 0.0562104488903236, 0.028219775657259652, 0.03266845206399599, 0.019607834645637104, 0.08955945516185415, 0.027375941299983574, 0.06424693721196344, 0.045036183174459204, 0.03962145074300709, 0.044182259439220356, 0.014920139764135164, 0.03336310228933731, 0.009797660299696991, 0.02933989196354824, 0.044112139411510966, 0.017507076000554428, 0.042394742655057105, 0.04110219144833185, 0.06219531927678374, 0.02640123614260266, 0.01947978496431343, 0.06937534428171574, 0.05390250176611928, 0.03203554086447243, 0.05651957685908964, 0.05902202221594992, 0.008605112295387494, 0.018684685290340456, 0.02783453493799654, 0.02148039293505492, 0.07269242072417852, 0.017464232533389044, 0.055104719715253006, 0.046926378723113775, 0.010771565852806935, 0.05344016770381601, 0.020476373423251416, 0.030158181118989186, 0.040677851516633265, 0.03014625504522795, 0.04262232056428348, 0.014785313077511327, 0.04171549079699382, 0.032718489096770366, 0.03003434683646887, 0.05002121688918241, 0.010847574223824328, 0.06170827121804319, 0.06875745606638732, 0.047633002902711594, 0.04319762195190115, 0.08820958525663422, 0.017909350684813915, 0.03745865429781618, 0.0767475615946516, 0.04511783665586864, 0.03108861214000612, 0.02184706176781366, 0.0704246549116027, 0.01933070042380883, 0.06126061540036913, 0.02504391794753892, 0.0256362954349888, 0.051139280079833926, 0.08165368825317391, 0.029982595681963913, 0.032663905332165385, 0.13648256268953124, 0.033610617636793086, 0.034868453569229574, 0.054819125967520865, 0.032568152002509565, 0.03649390062257167, 0.21066595139282368, 0.7231831394376294, 3.96332192324823, 14.800399003490327, 30.21845363801526, 42.223934435075336, 47.41762322764243, 54.59640395256781, 63.7212254924159, 67.92010707239952, 68.07091436078473, 72.37333866857713, 77.52541111361596, 79.6828245347546, 80.10861350644021, 79.94295612458261, 78.36697916830741, 71.54265911348405, 72.5287429748043, 64.74177129807012, 63.57025346448345, 46.6172282926498, 48.72939717385077, 35.102220273786976, 38.74835360434748, 43.47845746624855, 23.4707139384362, 24.920559237080237, 34.10021943430747, 23.961800567565426, 26.386854956226966, 41.06525844143283, 32.03110248811784, 14.999446542032304, 44.90324274186165, 50.25414797567552, 18.835080362135365, 33.7613501856404, 45.60444877993676, 36.379355769003595, 51.88017437534948, 60.17723460351268, 19.617199013310096, 32.647042082202056, 30.13898249595396, 42.870847025225245, 45.639608906161406, 52.589178085327156, 47.61243166462068, 38.24267379699215, 44.3009667242727, 43.02524720468829, 47.01546261387487, 42.95757062973515, 53.01093878284578, 64.03951406478882, 67.13814335484659, 75.58962729669388, 76.78663269166024, 67.52147659178704, 56.31024437565958, 41.775168218920314, 31.06620530928335, 14.587447643280031, 6.198780950038664, 1.1151128021940109, 0.5925296631551559, 0.03203191343815096, 0.04253576028971903, 0.02620986929433721, 0.03634493865613495, 0.0531918594553586, 0.08246186504801435, 0.01468476691027923, 0.03989238922874774, 0.0743303396889279, 0.023858779928677028, 0.05127469378132975, 0.04956539840467515, 0.05775819547594555, 0.07218835019176045, 0.006279828122651746, 0.007737532085288437, 0.011436624974463017, 0.018593091818113482, 0.08622331845183527, 0.02745626370362457, 0.03518924522664278, 0.011782714770355774, 0.05672301533782194, 0.026385073602620154, 0.05730580523489945, 0.12446275807075924, 0.03233414278515885, 0.03748299291117057, 0.06540253488046509, 0.0620654673736182, 0.023324833882431832, 0.03717620917145283, 0.0835331317578112, 0.026800712690718716, 0.03927063609984133, 0.0677923614820165, 0.02597041127662505, 0.01601187442804897, 0.054452981904990254, 0.03938400179087635, 0.05758913136237572, 0.10021847312248523, 0.05438410677015782, 0.016688037994167498, 0.03344470214459204, 0.058172032342202244, 0.019959457511562976, 0.056099201432399215, 0.03788158462773408, 0.021218609200009418, 0.06065166743111707, 0.0313918067577986, 0.051812353438787886, 0.07125323262786673, 0.026945489901869048, 0.06589073207109206, 0.05387583041503545, 0.04131293074498254, 0.03342819678026342, 0.16867192251788032, 0.22418953298080355, 0.12592456874347505, 0.12970527393683312, 0.13932053540502826, 0.13679517252791312, 0.1338424398413589, 0.13534542774000477, 0.37297652493561473, 0.12251041363924743, 0.09858797754972212, 0.1322860556143907, 0.08601291240343163, 0.14980241085492796, 0.13929444245032727, 0.17895564166528566, 0.16900558445242145, 0.062164790673001166, 0.1852299324086597, 0.15558283535703538, 0.15443690571813815, 0.15492680362395703, 0.3355421900989548, 0.08750670724698613, 0.20052397383316872, 0.18159386461540578, 0.18786524422466758, 0.1408533547674456, 0.23675928913777877, 0.16214512919466342, 0.13067622909382468, 0.12220073025673629, 0.15854050164982197, 0.161195854325929, 0.15589501618617968, 0.17100056933779872, 0.12253406277346997, 0.21652557406454317, 0.10655761320864963, 0.11418086221261371, 0.1381479305846076, 0.20697664048883224, 0.1353312244698886, 0.1900452087002416, 0.1731643080711365, 0.16936694812630454, 0.1182209877597709, 0.12685217098483156, 0.14297636826672863, 0.24268029077399164, 0.25215952567035155, 1.168312153989269, 5.520559510877056, 20.24486649420954, 38.13431832098192, 51.00210474383447, 59.306362521263864, 66.15602893214073, 73.89465347413095, 78.4719653283396, 81.31290666518673, 83.3150177617227, 89.1540619634813, 90.87805348057901, 91.45130003652265, 90.51083334030645, 89.01667702582576, 79.97607661831765, 83.06062067708662, 75.83092366495441, 78.689084206858, 55.52912004532353, 55.18996446363388, 38.61292592940792, 42.075037340964045, 43.425144610866425, 27.81015757591494, 24.95407981257285, 30.765190855149303, 26.78085704003611, 35.72382180921493, 59.860565970020915, 48.62473264817269, 34.129088078775716, 64.71005501285677, 75.82169040556877, 30.555685297135387, 50.120681485822125, 56.26827109244562, 42.995770592843336, 58.27918398764826, 73.21504792859479, 39.1830934247663, 40.94666557927286, 42.178544767441295, 51.38427695920391, 47.136373596806685, 58.76897035106536, 51.07052656912035, 44.220652272624356, 47.331342850961995, 44.482031176167155, 47.69140466567009, 48.72399607012349, 61.85554227521343, 73.90254528291764, 76.45938150344357, 89.04171743700581, 88.47692751115369, 76.77985483600249, 66.57084311208418, 47.254115304639264, 34.66565655123803, 16.767952057623095, 7.409674967488936, 1.5239936618074295, 0.7186729653227715, 0.16367212628885625, 0.17703744943343824, 0.154008524672639, 0.17764923192801016, 0.15208751323723024, 0.1852518578450526, 0.12611511013200208, 0.13466979947782334, 0.1580442145707146, 0.12846694643338843, 0.12433125907855651, 0.17351877695370108, 0.20352915289901918, 0.10650479910714973, 0.16149533341728872, 0.10518684442485533, 0.11433798684588364, 0.15675939319114532, 0.18539223579629777, 0.15024519435340358, 0.14661626649960396, 0.12396683105297628, 0.11553569636758297, 0.09604766829720429, 0.125613437454787, 0.2814048708927247, 0.09220992785788353, 0.19303390155396155, 0.12203108774678362, 0.1132682599728146, 0.2790553711595074, 0.150822349673798, 0.1944518536930123, 0.15794321353877747, 0.12344853426780432, 0.22649426253572588, 0.13079451306933357, 0.0961618000761636, 0.1266082715723784, 0.08979059921036806, 0.14805576103108545, 0.12857164766999984, 0.1876503565619069, 0.14032277759284745, 0.11116016986629657, 0.12330627174026544, 0.11262863784307435, 0.14583789052501803, 0.13097929347667003, 0.1932306022893998, 0.07750231141765272, 0.14384920288237835, 0.2009161495633664, 0.17882456402144126, 0.1540190353989601, 0.11976793378351197, 0.18900630154436637, 0.12560425972145411, 0.14172071951531595], [0.02674700418156722, 0.04102760895846352, 0.10473803947529486, 0.048896488733589656, 0.016940490778295264, 0.07074289549622806, 0.0871041203818975, 0.03167505244604282, 0.023339456585686535, 0.07705927511016208, 0.01899168161945718, 0.058121225391063965, 0.045526280263138395, 0.0812446279451251, 0.09509964215178644, 0.06797857447377137, 0.07255303102635569, 0.07953718650124728, 0.09362988714729586, 0.03802715665510586, 0.04073420111390372, 0.023077261078381733, 0.009725279355001067, 0.00886601790214979, 0.028390214898653572, 0.05945224570290697, 0.03485859018720446, 0.026571845838559732, 0.028392649143032973, 0.021818919527915218, 0.03843544704479076, 0.07419281924564032, 0.03764618879124042, 0.023985699630312385, 0.10409672429124195, 0.05529117019426438, 0.013459765506277402, 0.058191713140977014, 0.020891652450025566, 0.020156068231670127, 0.014935751678422095, 0.044984882096609766, 0.01087551057759312, 0.02839793706493032, 0.03136438272532917, 0.04622988222587494, 0.013381879262235618, 0.06524220799967166, 0.03847459413772149, 0.5480569108359276, 3.291387308028437, 11.958092681823238, 21.758736641176288, 35.78737597311697, 48.82611889992991, 55.71586801159767, 57.41592130353374, 64.37840684767693, 67.31542664189493, 63.420611120039425, 58.37392491679038, 62.458798885345466, 54.15702789060531, 61.693740583235225, 53.258393272276855, 51.15115481038248, 49.60671763266287, 47.92130654858005, 37.0777847689967, 28.368102965816377, 22.930901665841382, 23.590197178625292, 22.459277837507187, 17.724571074208907, 16.538426722249678, 19.928217472568637, 32.48336157491131, 36.814381922444994, 22.23585767130698, 52.052962626180346, 78.2372114735265, 68.24079221294772, 65.59680877193328, 60.468984419299716, 87.81460392859675, 76.84392283039709, 66.7839454835461, 60.63761495774793, 32.5590064448695, 23.836500452410792, 15.022791508705387, 24.91756646863876, 64.85138977727583, 42.83950336517827, 48.92092650936496, 20.787885304420225, 23.097161131520426, 15.48944079106854, 49.61206774557791, 39.94531193087178, 19.67860175717262, 29.383345726997625, 14.450009753627164, 19.30763771457057, 20.50650231299862, 29.072754806087865, 42.360927135713645, 53.68774375607891, 56.989394926255756, 62.60840592845794, 64.41980354247555, 67.76698558561264, 58.82179683254611, 52.346842288970954, 37.21365174939556, 24.297043585008193, 10.001292805517874, 4.810598742577338, 1.0794659343457993, 0.28925960102388937, 0.046925727548378135, 0.11432729225846068, 0.11665169495127856, 0.026900758027970314, 0.08560523105364654, 0.0642481821048404, 0.06443239177667326, 0.0395086098222002, 0.010158868840775423, 0.05760146154751701, 0.033960700665991155, 0.02033860974704787, 0.02766655292361975, 0.0021661736959246018, 0.029330461421200348, 0.025531789550798076, 0.06547617125174691, 0.06622391903112013, 0.05809682166023601, 0.030822486601649757, 0.048121755507083676, 0.04843290594796981, 0.11288884726743545, 0.05027061681293192, 0.05435174338579659, 0.028501854976639155, 0.07522503079305734, 0.03365116284018563, 0.04953775795236711, 0.04426497395240492, 0.009175013720748887, 0.068010903384176, 0.013011083130784815, 0.028951337914012616, 0.010841210906003273, 0.13375495260040607, 0.05827944553006561, 0.01992019742066341, 0.12487502062633155, 0.0621133057340499, 0.030328432668841658, 0.06945802815138333, 0.025669417246395064, 0.03624449686838254, 0.03690998212644651, 0.034477419310039094, 0.07442971661446557, 0.08323959750874389, 0.06204345766755362, 0.03025687431105443, 0.06592078570036158, 0.026442871106067495, 0.045023316727770914, 0.06776983849704266, 0.04068206116977719, 0.035655559115712686, 0.0366890040646878, 0.0335207938276712, 0.06265520568816893, 0.023921093520438, 0.01610447817872609, 0.03527298629764588, 0.03101367533447281, 0.034536860072084015, 0.059707977343350656, 0.019774788186975548, 0.04937483020307076, 0.0436179667350746, 0.03818974732571552, 0.022646058914101413, 0.029928243658956022, 0.03420060492991921, 0.04240144592439456, 0.06551193223605234, 0.06179829804046501, 0.04189875818067982, 0.06000193294077631, 0.055939985379096, 0.012738143240341978, 0.018445334524937698, 0.06788157242079897, 0.033719796657321915, 0.04918310137826109, 0.03343336787375231, 0.019926567441753803, 0.058799240017129537, 0.0225657154430425, 0.07639374388682266, 0.03931713380640553, 0.010709312590469998, 0.02118822040727302, 0.021744101466010177, 0.006095727139543141, 0.04111855125595485, 0.04133044351493159, 0.022137935776563904, 0.1146355737000704, 0.04039690026172227, 0.023517102799228123, 0.037643580261858246, 0.04331530837882911, 0.024069320042467406, 0.019802836581103263, 0.024874767649077603, 0.06355056711923211, 0.6495036220838947, 5.126405435223734, 15.089563977333809, 26.838874778439923, 42.49461327829669, 56.45470526910598, 65.38231395906018, 68.16408634185791, 72.13071653919836, 75.37304186051892, 71.91318973418205, 68.03809196718278, 70.5797407704015, 64.81894000884026, 70.97245631679412, 62.94874214356946, 60.17107255997197, 59.06369332344302, 59.18764806562855, 48.894764300315614, 42.63548520303542, 33.27249734632431, 35.077066113871915, 35.72420227912165, 27.278792127486202, 30.39583302313282, 23.22512257483698, 24.17036475673799, 24.778371357148696, 18.213396456933793, 34.98305082321167, 78.08999707621913, 85.3037457312307, 70.26315842905353, 60.933138093640736, 83.27741007651053, 92.18773288111534, 70.8892628454393, 63.11027319200578, 44.77411439341884, 31.168314410794167, 28.882459055992868, 43.93023998506608, 71.40826302189981, 52.7288576095335, 55.36133673883254, 35.06078435528663, 32.22374381557588, 31.06125920049606, 50.6663380899737, 52.820927404588275, 27.197779493947184, 45.04776639323081, 25.340690189792266, 31.10699795907544, 37.24597992435579, 42.18413414493684, 52.07591633642874, 59.66688717565229, 64.8305384574398, 72.5539638150123, 75.13405184591971, 80.23719664542907, 69.04607834354525, 63.78128090212422, 47.52886949046966, 34.39551115036011, 15.475603649693152, 6.844989965038915, 2.1710318903769217, 0.3812749425490057, 0.04592222897636314, 0.04057367121981036, 0.0638907216489315, 0.055427123987746824, 0.039668362137050404, 0.03319181269034743, 0.021308750935619878, 0.03441185367503955, 0.010792424511765281, 0.0843273044653958, 0.014375429224943923, 0.027211757166491404, 0.05381724001058648, 0.025968764187587846, 0.059138203280106674, 0.03477759554140991, 0.042908741686973846, 0.05693607588088321, 0.10086132814326595, 0.040208641815209584, 0.018590962093683983, 0.08215798861196927, 0.09960967837081802, 0.04875469351968458, 0.031094729352081497, 0.04140053672956363, 0.018260523474084276, 0.05345914753214006, 0.04293465461101263, 0.03700876916428247, 0.028696929690458124, 0.0342101963507312, 0.014261219879582286, 0.015987400791697925, 0.06815139624860979, 0.050778536937169494, 0.0877087782587736, 0.008311411422196656, 0.05686177684354687, 0.026446446821454073, 0.013127998681738974, 0.017511134351333304, 0.015744013700544113, 0.05128588632590348, 0.07485235966141186, 0.003560514526344055, 0.0965760161559428, 0.07615977297386817, 0.02740668632360476, 0.033792008105064594, 0.005287719841655945, 0.05377290650240837, 0.10248633852649121, 0.04660205156993001, 0.01877627876256743, 0.047552241913733945, 0.15439573615308733, 0.1611017174417934, 0.1498195252591564, 0.1257890784331868, 0.11845916449542969, 0.10970203641561732, 0.14950624126340115, 0.10306842745311799, 0.15227790140817243, 0.13419419677267153, 0.09419918240558717, 0.12191703257661675, 0.19344040312834326, 0.18942780312030547, 0.2225800588606827, 0.1282473396690142, 0.18107027416267704, 0.24939615459692097, 0.20050911172743768, 0.10905357363123087, 0.14485355947286854, 0.11519614321690415, 0.13168692889232791, 0.19948221683021516, 0.14432243071496487, 0.18236487082416014, 0.10345927785120665, 0.15926764166403204, 0.13962554565120128, 0.1475392185872601, 0.11887273706135251, 0.19676022982645422, 0.09415897811132093, 0.10324610622539636, 0.17218406792850266, 0.1272971761382876, 0.12396910633411139, 0.1715870556091109, 0.12672151468934553, 0.12650334817026893, 0.1924018483729132, 0.15652429612894214, 0.08840960315278462, 0.15372378511294243, 0.1975261951766668, 0.1936810926323937, 0.10960211556765342, 0.17214185648387478, 0.3172473363097637, 1.3734215930584939, 6.811554701097551, 20.573782728564357, 35.878955471900206, 52.7520937304343, 68.01194544761412, 76.40182464353501, 77.61729655727264, 82.80504688139885, 85.0225353240967, 81.44407856848933, 76.87199915609052, 80.26322549389255, 72.53285361874488, 81.65285064328103, 71.6971455850909, 70.40273204926523, 67.61275799043717, 68.6981091960784, 53.193462356444336, 45.7820301671182, 38.42086707392047, 38.01602355895504, 34.4310321346406, 27.93029977429298, 25.952521101120983, 32.84409019254869, 47.50871243015413, 53.73709501758699, 33.92083375684677, 66.95320360122189, 94.89584707444715, 83.9901674947431, 82.42471033527006, 79.82718344657653, 99.13448579849737, 88.56499256626253, 83.36319231217908, 77.10392105963923, 47.654867787514966, 34.858511647870465, 25.832153366458034, 41.11514706765452, 81.67366273941533, 56.602225611286784, 61.973664452952725, 32.494881576107396, 33.069757876857636, 28.084819586046283, 64.61862064176991, 51.80925007789366, 32.67132155356869, 44.57763894911736, 25.538085429899155, 33.99340544977496, 35.82286557843609, 47.27332707374327, 58.08279875786074, 72.86015972014397, 75.75007577096262, 82.05669787622269, 85.07733083540394, 88.57530839981573, 79.38883504559918, 73.15314508253529, 54.79717046983781, 38.94520951855568, 16.824479295361428, 8.422273070581499, 2.653492246904681, 0.5622494557211476, 0.10280907604723208, 0.192624596097777, 0.298927569341275, 0.18154595347662128, 0.18084574911382892, 0.24916931596254152, 0.12575313358777954, 0.15647623177257278, 0.15436536842776885, 0.24565956074624296, 0.09951434638952056, 0.1493192085575673, 0.1374286046672252, 0.17757357308460822, 0.14239582683770888, 0.17084474705400007, 0.20652181408818693, 0.1855258262085338, 0.11805482328899446, 0.13511434497852481, 0.13460039191188353, 0.13707030534503922, 0.2239922653403013, 0.2490365529252637, 0.12269148618103036, 0.10376504652442471, 0.11932921821191428, 0.19921905030646633, 0.1507193874567747, 0.1469534064733213, 0.13154987576267413, 0.09024427647912696, 0.06493070132790074, 0.14492949410792322, 0.13998356918173452, 0.34603477545803596, 0.17298646842039403, 0.1320164692738364, 0.30029313638806343, 0.18678685289717492, 0.1966887997883943, 0.15920776423187027, 0.13928946287881944, 0.23106471244846624, 0.2333870007386131, 0.12856361906855338, 0.17205833757836975, 0.17780416554981665, 0.1443771293927585, 0.13390096895877393, 0.164831324570602, 0.14037618924292827, 0.18326758286885678, 0.1818998401323634, 0.17037842933449054, 0.10470544243411672], [0.06526446285387201, 0.042249906072092634, 0.03722645304796677, 0.0686703825129136, 0.03418865778874006, 0.0896300501640766, 0.06826066336924992, 0.07499186427242334, 0.08189427050491495, 0.05791547332680034, 0.04153719915437602, 0.0446153634167727, 0.03352566997730925, 0.08861766497213995, 0.023301684620579886, 0.020342775350136143, 0.07469648375145851, 0.06620039247096547, 0.038003074681206096, 0.054057814601448276, 0.03231307919768076, 0.16305999139383917, 0.0977945173039071, 0.065557545111064, 0.0334497774770904, 0.08534096902416599, 0.05319591972135729, 0.037654581284450914, 0.03344652160341221, 0.053115028497432513, 0.00416290981041628, 0.07442548780912354, 0.034874222211299405, 0.020085754766759854, 0.025393501104366396, 0.017251717827973828, 0.059695739088760275, 0.056133767319542754, 0.04685579521221019, 0.0412177634725888, 0.0699203622136866, 0.07074062021509295, 0.04769708615757766, 0.03348225194420065, 0.031086880781297243, 0.05405247879905566, 0.058188836480821335, 0.058959302597589074, 2.238358393792183, 9.641689908119941, 28.663894784065988, 51.28979098412299, 62.77927614027455, 64.87084081096035, 62.735655461588216, 63.38228564108572, 60.25802366195187, 57.958353719403675, 52.985729709748306, 54.46271388761459, 49.92377850317186, 52.0463102863681, 37.03195187353319, 36.58636669958792, 31.983524137927642, 26.064479274134484, 29.62950779545692, 24.022420798578572, 21.337850632206088, 13.056136677342078, 17.492770764135546, 16.031883993456443, 22.5218867101977, 49.29457149197979, 41.61715553652856, 68.88811665196573, 67.17837118333387, 77.52345777327015, 65.90524042806318, 86.56670970301475, 57.19353860424411, 28.068176969405148, 24.177619180371686, 29.62029414792215, 37.70363815369145, 22.055265865018292, 38.87829780578613, 34.24356245225476, 36.94555774811776, 53.96003077107092, 46.68318294709729, 29.539044210987708, 22.33195181815855, 37.13966800320534, 29.29212708627024, 35.540847163046564, 37.692486855291556, 27.59255820705045, 50.87963657994425, 27.655529898981897, 33.646467885663434, 25.414732771535075, 25.035327788322206, 23.71250060296828, 15.330742674489176, 21.386356622942035, 18.123334915407245, 32.7706398887019, 36.435512342760646, 40.20601226437477, 39.72805969176754, 56.39949006419028, 61.14751131303849, 61.49414685464675, 61.016257039962284, 63.881254273076216, 48.43214427271197, 39.53623225612026, 19.338846052846602, 7.719368155925506, 1.768808763834738, 0.2997634631972159, 0.13815807358872506, 0.1284379500054544, 0.05156853829600638, 0.00779397169788999, 0.08109572343528271, 0.047140515619708646, 0.007313240991695034, 0.046162780584587206, 0.03617464497144665, 0.04752882260588869, 0.10516011561717718, 0.020545120238356536, 0.048368477953537825, 0.03493381619092918, 0.09098710597402627, 0.0038545642089429163, 0.049891058550847155, 0.045626587985504063, 0.0738874182946259, 0.05397166801436294, 0.032382467611422466, 0.026593288639560345, 0.039869421912777814, 0.09378594691835104, 0.050787182239395, 0.037064766361107754, 0.04985804399175029, 0.04927754086712676, 0.03617494374573712, 0.07464197659564596, 0.04504041964068048, 0.04622027931374408, 0.034314016586229686, 0.022639455236194116, 0.05956891706333526, 0.06315171493277436, 0.06262700599167617, 0.05788150498823774, 0.04884594608278525, 0.022342272493387424, 0.020718809607769215, 0.05433834833844055, 0.015489977029632899, 0.042314115731466206, 0.030932253594660473, 0.04528180245430239, 0.025750475094443368, 0.03625274380488742, 0.02141476409780162, 0.07613228573914498, 0.04755906009626004, 0.050447498853769035, 0.0524346428292413, 0.03987272758217108, 0.0085092555438619, 0.07864604238420725, 0.012751200251401433, 0.0037076302208832556, 0.044110936653469844, 0.035079238831155726, 0.05236893546797576, 0.06301301471408337, 0.03808827898014457, 0.018974325897532607, 0.05712628785160281, 0.0559950364573348, 0.0749397779544515, 0.03383114370667646, 0.04553753026430646, 0.06649675358447336, 0.08323253417808203, 0.030879726776132183, 0.032324739055888306, 0.017868876344554366, 0.03633548896158895, 0.02689695248620645, 0.009537790826852284, 0.017874009133647048, 0.03772007031065803, 0.03564833873702634, 0.03910997214036123, 0.032671435976461057, 0.021964851616611405, 0.03329407776735964, 0.023463411527054927, 0.07338707094951984, 0.020957346404752424, 0.06049102262383508, 0.06432972833394043, 0.09388540045268114, 0.017113092302855466, 0.012563717468912083, 0.03557983515483718, 0.027652709714828, 0.06694041042318268, 0.024490080428339785, 0.07817687481761941, 0.03321165819802592, 0.04887877295034067, 0.04426259907983965, 0.06635583937168121, 0.013355551693107814, 3.311278137468523, 13.950747924466288, 37.46868425799955, 61.66697432917934, 72.3708361964072, 72.90725954117315, 73.48016877328196, 71.86908660396453, 68.12742787022745, 66.45594120025635, 63.323250047622196, 63.63168170375209, 59.0889298531317, 61.45539383734427, 45.6957301785869, 49.46734405332997, 40.77254372258341, 37.71232620362313, 40.69983866906936, 34.088832793697236, 29.472940506473666, 22.42743407526324, 31.428549943431733, 23.906330408588534, 28.112042796227243, 48.239846152644006, 26.792522168928578, 59.17633595005159, 75.10168444725775, 77.8541841814595, 49.6470082190729, 80.68412719234344, 65.62417122625536, 33.52513328675301, 33.13391608576621, 38.015980412883145, 45.79099670533211, 27.252072941872385, 34.67358366135628, 34.18823349860407, 37.26610168333977, 41.56886723733718, 37.3663103965021, 31.606474538003248, 37.77448400374382, 38.258563318560206, 34.68428780955654, 29.72336619131027, 37.770290990029615, 29.180394449541648, 50.88517104425738, 32.14105240760311, 34.61387734259329, 32.58016959313424, 24.288814452386674, 32.85788516844473, 23.464316552685155, 30.671597219282585, 31.256018607847153, 44.94700070350401, 45.991539647502286, 49.39290531219975, 47.529806936940844, 62.8378685059086, 69.3920627717049, 69.48765093280424, 70.57313549903132, 73.50442471042757, 60.40579111345353, 52.37481663303991, 29.083598198429232, 12.079842071379385, 2.9075843672598563, 0.4267233538050806, 0.1581011655470056, 0.12834961240690562, 0.04713531771314241, 0.04136638452989921, 0.05531752361885964, 0.04372506582688901, 0.055295150021031025, 0.0659210385093766, 0.05117823565078359, 0.06523850013411815, 0.06549779791384935, 0.07179964483985979, 0.05483902127091443, 0.039886609095359044, 0.0637831399217248, 0.06068116181620187, 0.0435001845471561, 0.05467000695305967, 0.05986945335603049, 0.03980400183448388, 0.08573397212932188, 0.031427443252816316, 0.03438957583820147, 0.056047705002129085, 0.0325083818226572, 0.008272887733314306, 0.05747383512977151, 0.028085183585062626, 0.05934867827642349, 0.059986143868656895, 0.0904871876381578, 0.036508705271708394, 0.06494377844876821, 0.016752278297058037, 0.03960594129298003, 0.04105492765384336, 0.05047925702867009, 0.019113217638204658, 0.04700777173462895, 0.07288888397236025, 0.07964834585906037, 0.04759597021245188, 0.0655426906662122, 0.04317328333854676, 0.051260306650111755, 0.035425089224572145, 0.09237930989794194, 0.03571313062322236, 0.03209845392003415, 0.040750503464932405, 0.041355402659504645, 0.038291905150418325, 0.038286726396050186, 0.04202381054299974, 0.1064063414871212, 0.13840614818036556, 0.13451134185156516, 0.16727212666263505, 0.11869180241539595, 0.1667740929030603, 0.1735477197554804, 0.1371231347682976, 0.16321995055242894, 0.12417746692775719, 0.12432087092630326, 0.11558864070403001, 0.1280514203432587, 0.15857915844648116, 0.09457206804185145, 0.10332849898165274, 0.20098313629146547, 0.2533342755369602, 0.07911557001211951, 0.11498450376694241, 0.177122914202271, 0.19739474981061875, 0.1542774521775784, 0.18562085175466153, 0.09987608544648656, 0.14515363611280918, 0.0887483595720222, 0.1704954875693206, 0.12335882537187108, 0.08954110735606763, 0.08777115313756852, 0.21142807098165636, 0.12855592754579362, 0.12333145305033653, 0.12065455798179874, 0.17327934383384644, 0.1540733510327916, 0.1658085310050557, 0.11372424316622558, 0.14205844171585577, 0.2245825667294764, 0.12895003381756046, 0.16418018047848057, 0.11697369702761212, 0.19661007659329524, 0.13257626504186662, 0.18098081041487957, 0.28049003933706596, 4.273277665338209, 18.73078061688331, 44.4043682467553, 72.14208356795773, 83.52756315662016, 84.15182405902495, 83.99270919061478, 82.22717977339222, 78.88241783265146, 77.41407071390461, 71.5243887132214, 72.58804921180972, 67.53662478539252, 71.17186961635467, 52.9881105884429, 53.673650680049775, 50.779804414318455, 43.2542351753481, 44.6043267557698, 37.20267303528325, 33.818789374443796, 22.161736642160726, 29.74413121900251, 28.051508857357888, 32.62747141622728, 65.46933566370319, 54.997529060609885, 88.06078757009199, 81.34495242949455, 92.42038434551608, 84.61589536359234, 102.61496174720027, 66.9572671767204, 42.21126517941875, 37.73435423451085, 42.28391531975039, 48.80167076664586, 31.11147338344205, 49.945661406363214, 48.34384387539279, 49.700238704681404, 70.55619085988691, 61.52851858446675, 43.310434895177046, 35.00225082520516, 50.83954211204283, 41.799879151005904, 49.94014263153077, 52.01152670768, 39.3625497048901, 62.06199230686311, 37.9064796047826, 52.451263627698346, 34.044070705290764, 35.54302800086237, 35.30609330823345, 26.354191418617006, 32.81081868756202, 32.38382358704844, 49.94949748439174, 52.95009889910298, 57.18410138160952, 57.65798253397788, 74.43051199759208, 77.95179628556775, 82.77261672481414, 80.40609390504899, 83.9467154779742, 70.87306345662763, 56.85797199126213, 32.04158306121826, 12.83206049473055, 3.5991884431531354, 0.7717416531616642, 0.30570392346670555, 0.2679439399751925, 0.09707566636103777, 0.19932348341230424, 0.1834143806369074, 0.1085856011618049, 0.13390265435220736, 0.1784994516281351, 0.13979158754790985, 0.2661750123145119, 0.16647583955237943, 0.23724865078205065, 0.2049107158616666, 0.13928529536051137, 0.19380909060278248, 0.1528908943216647, 0.151949372262724, 0.15520500079278024, 0.3180773466104462, 0.11613893698179915, 0.23018769499274994, 0.15828033819073634, 0.12102914433325491, 0.26026305051580556, 0.0854793321641703, 0.1234983376437618, 0.15640824913017212, 0.0859111223009325, 0.13880577028518723, 0.2585376672927411, 0.154336977209295, 0.11756284928490078, 0.13427633671991288, 0.1895557398036603, 0.18483383430828973, 0.131505289445481, 0.1750093542279736, 0.1635121364867495, 0.11442378869340306, 0.16834164669196452, 0.14609218575060368, 0.1583820440235638, 0.24504969347148176, 0.1724648851180269, 0.07528686941030525, 0.2149910846304509, 0.17362760740422434, 0.08810555051651695, 0.24814234445652655, 0.16467390882392086, 0.1467808221857394, 0.12224366182401297, 0.1857580581019002, 0.11200324962696723], [0.02124686443787669, 0.05279757698336917, 0.025171504145668402, 0.07899395355413999, 0.08146051918306658, 0.014142720441844676, 0.07135025000259762, 0.01356472529756326, 0.07769440030378681, 0.03381111816833577, 0.027733959084857377, 0.04260610631336609, 0.03138519158857244, 0.03430667363347546, 0.03221732586802494, 0.046026194768567244, 0.04623984136889058, 0.03706056436884307, 0.019070058159770507, 0.02614085051801897, 0.043026765192588495, 0.04160918077574142, 0.022570375172841935, 0.08711232518356654, 0.08122994203961666, 0.031022644308846326, 0.06678858711834877, 0.08532341028894148, 0.030455076578824274, 0.03927414861297415, 0.046344017835273865, 0.007377667549712163, 0.042591079498731324, 0.107224531051132, 0.05749078482509621, 0.0822206699259339, 0.017100438445566163, 0.15906073663744236, 0.029674553642830545, 0.029881194369086338, 0.08369867569736897, 0.03197209154736371, 0.018159028315435977, 0.10715461020628292, 0.03293233871039364, 0.4555740411723814, 2.5140078606144076, 7.25054931256079, 27.309882794657064, 53.65720025954708, 62.71484336545391, 71.2649788395051, 61.10056054207587, 62.847847015626975, 55.28556439184374, 54.57955345030754, 41.87542792289488, 37.691792595771055, 33.890619739409416, 32.17642434181706, 27.850430511659194, 26.243523705390196, 29.580950813908732, 13.967702369536124, 17.268393539613296, 13.048406666324986, 18.502198611536336, 15.834655454081876, 21.597605674497544, 20.12513026114433, 22.564297337685865, 29.453734620924923, 47.08823042531168, 81.35256182762885, 95.28973148715113, 61.98782813164496, 29.044913822604766, 25.029658002238122, 30.565856002992202, 14.725072826108626, 15.681465325816987, 28.10774976207364, 17.38909467574089, 15.699639628010413, 21.139629733177927, 31.699946580394624, 36.71796221886912, 33.31547867867255, 38.37094314636723, 35.241260451655236, 42.00366589330858, 42.426768041426136, 41.21238262422624, 50.014173446163056, 53.84129278121456, 61.93751981181484, 44.45907746591876, 60.01552312604843, 35.08579730987549, 52.726888579706994, 46.4062322339704, 56.6769467630694, 48.01775370874713, 28.540320511787172, 37.3695267400434, 25.013941064957653, 16.405589772808938, 23.081210813214703, 19.945383725627778, 27.975356040462373, 30.424615375457275, 36.29464826276226, 48.24675736888763, 48.54423384512625, 58.1030656445411, 58.968944549560554, 66.12202198274674, 71.97933658476799, 61.16143964952039, 46.20148843334567, 25.460955942830733, 10.169026101789168, 4.175103191406497, 0.14292831923211777, 0.06480415892456809, 0.05547331908958093, 0.025981207370697975, 0.032797258257144885, 0.035111272797709515, 0.04542699909859127, 0.08414130597825974, 0.09800616441474808, 0.04709391449127467, 0.077951330871832, 0.07497154762067142, 0.0377134781240696, 0.052811201857102495, 0.016872678590457768, 0.09994086584136372, 0.08946036934972772, 0.03407029720443872, 0.036637270147161144, 0.02495956783663602, 0.0799272248461362, 0.02915213721984577, 0.052239236782395074, 0.06827445295188697, 0.0566452076177924, 0.051169050256571466, 0.05631310467217719, 0.08607705694533165, 0.06732283385410424, 0.08656282563723865, 0.06034722792044763, 0.04920969995099211, 0.03604845496855917, 0.05591485386473998, 0.025912500775208878, 0.12015585772572987, 0.02812340562682479, 0.04185511415163356, 0.03404802702847989, 0.017764416425639105, 0.039211417503294446, 0.05467419362356586, 0.05053375269316378, 0.01919102152779458, 0.022961104912082517, 0.04004849113463875, 0.06347631404717123, 0.08999581118264506, 0.011363503797310255, 0.0631661327075093, 0.09331696321286502, 0.09580610545292016, 0.016116902209638108, 0.11372078044880783, 0.11843196837411774, 0.02861401790963306, 0.14080507590645744, 0.08840467720743149, 0.08605797369513782, 0.027737666950410897, 0.06297000270757465, 0.047340418602670395, 0.02636250082193123, 0.010216353205783714, 0.009527487901880616, 0.10571749820824593, 0.04593076702627925, 0.009981920724854836, 0.029600898119350596, 0.00540497295010174, 0.05689802812412382, 0.014594055396775085, 0.009428895258855437, 0.0576898719244186, 0.019475826204964714, 0.01514104313232125, 0.030530164686722622, 0.03532983385206711, 0.017785784533067096, 0.04781658438244655, 0.03827320494418664, 0.008441385899430082, 0.01199638243809703, 0.023700994544572408, 0.026747640034544374, 0.07083266567919524, 0.08781617612487848, 0.05989408308279611, 0.07013071463593552, 0.06894844944678968, 0.017671160542616443, 0.006876774845765003, 0.011449989378302088, 0.03977615453843628, 0.021163831998203552, 0.07777712247785061, 0.1311104936945823, 0.045383508287129865, 0.6874683042687755, 3.99806309130884, 11.934102485256812, 37.28317576069986, 67.58074360509073, 72.49341810903242, 79.98652581245669, 68.76511896810224, 73.33494694002214, 64.65305905188283, 65.58279022093743, 53.97302950582197, 47.44822555972684, 44.09862733656361, 44.008051964544485, 38.52028346830799, 36.37048336767381, 37.57534527009533, 22.460487888705348, 28.034781909758046, 22.408920488049908, 31.843322938488377, 24.77043247991993, 27.561518530691824, 23.62644576257275, 29.900145453791467, 32.95784873347129, 41.68099603345318, 69.80924606323242, 70.40556400052964, 68.32555463237148, 36.76839213217459, 33.340942705831225, 32.38070726394653, 19.478947231846472, 13.563947312293516, 16.640957478554018, 11.92628029854067, 10.510345851221393, 13.756190519179068, 17.807297783513224, 23.201764860460838, 22.645525701584358, 20.60330052529612, 23.401707679994647, 26.541792500403623, 28.333393912161554, 27.294205081078317, 32.66820915283696, 38.20009646877166, 48.49749488215293, 35.95999556203043, 37.86722844646823, 37.19233366750902, 38.096173271056145, 48.5067085296877, 36.284991387398016, 39.155268130763886, 32.559355535814845, 41.18964464433732, 28.402719843772154, 24.294299887072658, 37.2233517708317, 32.54043794447376, 39.65334638472527, 42.96862779125091, 41.95010985097578, 57.41180673722298, 55.85348436909338, 65.99761224562123, 65.9983653406943, 74.23387573611352, 78.76458198793473, 73.35703772883262, 58.59336583845077, 37.9330732745509, 18.878116607666016, 8.54961674059591, 0.8054915647352896, 0.13307103526688394, 0.024955352437832666, 0.08740923021950069, 0.07674077405564247, 0.05972740916355003, 0.04823062043156355, 0.017356535892993692, 0.03033434112195767, 0.0519907370119566, 0.028095924137761037, 0.031271737797426126, 0.052191785296365145, 0.03163811934721326, 0.01152103637239986, 0.07423729831052404, 0.10413921152752253, 0.06939372273101922, 0.04676133274070678, 0.06536353334423996, 0.07444817933344072, 0.03103652582203429, 0.1039467012930301, 0.040973002211220806, 0.026862411496920452, 0.03732864151618654, 0.02358469090634777, 0.046104408515196656, 0.10825940858452551, 0.05483781851287331, 0.06468188363097369, 0.026536513863491918, 0.02482480722509565, 0.01344398505264713, 0.049098827876150615, 0.10309030692423544, 0.014956148769406062, 0.036712174393957665, 0.018910213914369384, 0.03475331055421022, 0.05553791945379588, 0.05681880314143435, 0.06669412081640574, 0.030947810925182798, 0.01978457687542804, 0.061728702782983744, 0.1022008941659043, 0.08800153875903738, 0.09127264226516409, 0.04240998014387104, 0.12592457640435428, 0.04195120072953644, 0.0638549070384714, 0.22214677485246814, 0.24116136824652074, 0.1709953752616721, 0.24686066403744683, 0.22459650952969828, 0.1408658420006114, 0.2605964519804524, 0.15317969414735996, 0.1743747729567751, 0.14605945847447843, 0.09345377119438303, 0.1384945087615521, 0.13403583107696426, 0.14931183879173573, 0.08532578516150675, 0.16852956805979052, 0.2177353954363254, 0.13177398712404315, 0.11630807387372179, 0.1249614047006734, 0.09717984665786067, 0.15347538876437372, 0.141444897219058, 0.13615101515766115, 0.21800217789507684, 0.1296610246983267, 0.16161400043675977, 0.2126910128901082, 0.14765361083611367, 0.14892303384840488, 0.1028357282461178, 0.11182915614617449, 0.23139659705902302, 0.209129745921781, 0.13453915084321655, 0.2395390085275135, 0.21918426688400008, 0.20385598132927574, 0.1767544105889336, 0.06230940509046759, 0.10337503882305277, 0.15551088437918695, 0.1307516887543663, 0.20191201789965554, 0.13348538158161025, 0.7996180605503821, 5.320252401213493, 15.454751349264576, 45.84040680239278, 78.1748144088253, 81.793318563892, 89.58698180414017, 78.71541900019493, 82.13077575929704, 73.9604865351031, 71.2879325497535, 58.5919027943765, 56.01770224109773, 49.490901808584894, 48.44400944248323, 42.98498799723964, 41.21271994806106, 43.503854813114295, 25.033627440852506, 28.539991032692697, 23.746327123334332, 30.695200081794496, 28.370685846574847, 34.00141492966683, 30.60453057289124, 33.940845689465924, 45.3954452853049, 66.30280402398878, 97.30265263588198, 110.92733490851619, 72.83001238299956, 41.21286507575743, 36.8925194586477, 41.097539547950994, 22.177920341491703, 23.33398403659944, 36.51326156431629, 24.392461123005038, 23.005173706239272, 27.292912660106538, 42.14564000406573, 44.84732935505529, 41.13398621159215, 48.080460640691946, 44.82359509314261, 52.675164284244666, 54.42422759148383, 54.58973984564505, 64.86912673519504, 68.40187611118441, 81.02534201837356, 58.670840494094364, 74.1240729055097, 48.09885655680011, 73.15097993420017, 63.36303072590982, 73.30603122711182, 67.17419778147053, 40.4645945179847, 51.86144505777667, 35.24201746909849, 25.33691098613124, 38.11256485600626, 30.77145488031449, 40.13281691458918, 46.369071698957875, 51.38978396692584, 67.9935573762463, 66.89861205316359, 75.35365750712734, 74.76494896796443, 83.58364520534393, 90.09280281682169, 84.44296590743527, 68.05014148835214, 43.029895213342485, 21.406335215414725, 8.690785784875194, 0.7386486773048678, 0.2884068532336143, 0.1864718375427108, 0.1737850231509055, 0.21747183054685595, 0.2175640828546978, 0.18967005544372145, 0.1642439189937807, 0.18351637758314612, 0.0964626734475455, 0.2196199257647799, 0.19534901926113715, 0.2266194719460703, 0.12867759762992784, 0.14770294689843733, 0.3177289298224834, 0.158069847872661, 0.16680982324384874, 0.12442498227521298, 0.08652076741019565, 0.13255185748059906, 0.11201621949552529, 0.2286946815588782, 0.21831250479144437, 0.17854943120431516, 0.10335518182405543, 0.13776534627522194, 0.14413106195147962, 0.17001746402632806, 0.18458526942037767, 0.15977037920346185, 0.1926947391081241, 0.08334283551741993, 0.1416395295171007, 0.19948793184613028, 0.2167428825651446, 0.07113459625191267, 0.36129555334487273, 0.14374067886702477, 0.09042607680443795, 0.13536612743571882, 0.17494723981907292, 0.34019586780378896, 0.19685485700686134, 0.14551665453660875, 0.18561738903724379, 0.27835369590790043, 0.21284732547017837, 0.22375998748165948, 0.1331363212797911, 0.21499057901242088, 0.21027579813474612, 0.16806714206693635], [0.09213472866723615, 0.105835345513638, 0.07973528917758696, 0.07518396081943667, 0.030568790839864846, 0.056943169855062044, 0.03433166342156549, 0.04855305917801396, 0.0704619327499982, 0.0312939792450878, 0.013848027484791895, 0.057076875180486715, 0.07949528149178914, 0.03478327225292883, 0.015985029749572277, 0.06754888341792169, 0.03577804508348627, 0.028796488561877803, 0.0358544010668993, 0.030460565598801743, 0.06661700640594767, 0.03759166248322975, 0.12256927983534914, 0.020482438924391905, 0.05259989182494822, 0.04537372151389719, 0.0541007538296042, 0.03302001747332754, 0.020994430805947033, 0.046801322530354225, 0.005042021558995569, 0.07925633866820606, 0.0721139400716751, 0.010953418846662727, 0.055984805353106036, 0.04867364141729571, 0.02492745343085018, 0.09315114348165451, 0.0671942689786515, 0.013811395075472613, 0.016248824465419018, 0.04863335668379742, 0.027906051160947933, 0.1155555303839426, 0.8732181499081274, 7.405202484899952, 34.36335948205764, 55.293173789978034, 64.00634650261172, 71.81373411609282, 73.05183026098436, 63.470421298857666, 56.629286043105594, 45.211521425554835, 51.428678189554525, 32.236238525759795, 56.72403089461788, 38.60495959558795, 24.955258484809633, 20.39867831814674, 19.510328154410086, 16.69680222388237, 13.91393255802893, 22.88766145706177, 14.817062212574868, 20.3865130870573, 18.27064148841366, 20.03934214192052, 27.829163420584898, 46.866404702586514, 51.19770157721735, 36.79995152258104, 39.19148729693505, 31.959638864763324, 20.246721775301044, 13.015927480113122, 14.587890871109503, 9.040628844691861, 2.1667562617409617, 1.6014717495249164, 1.2782577833821698, 0.618480799659606, 0.8423764306691386, 1.3984639654236457, 1.9498727254329191, 2.8976896982039175, 1.1771624919868287, 3.105845715730421, 5.306804555077707, 4.086562058617992, 4.999648159550083, 9.699344827282815, 20.704717328471524, 22.82328163423846, 24.691102543184837, 18.62683584613185, 30.380392612949496, 30.817581953540927, 25.589142922432195, 36.263865501649924, 33.90195538920741, 59.67957996552991, 44.34123769883187, 49.181473870431226, 52.73183861086446, 50.714853886635076, 46.161605773433564, 21.012029147917225, 20.802531434643655, 13.264687138219035, 14.436028465147942, 29.1548696256453, 27.50377339701499, 28.255291677290394, 27.096529391504106, 46.36831075914445, 48.95143470456524, 58.0265284353687, 62.96809511799967, 65.11932296137657, 64.92483615875244, 57.64617619975921, 36.24155113773961, 25.32323564252546, 10.239169847580696, 2.5369620611590724, 0.4349189317755161, 0.16093434255209663, 0.034108222387130224, 0.04676446220987747, 0.043615055600962335, 0.023828831636497093, 0.06283252439912289, 0.03605656400923768, 0.022730403279344884, 0.0768623368874673, 0.015232403905341222, 0.05294298430183723, 0.04011451642239287, 0.03739865046114691, 0.038364039989368576, 0.008903651013820162, 0.047797707975992275, 0.08522788678566295, 0.015665228260801207, 0.07353825074049734, 0.04248363183691137, 0.028580871200369253, 0.043363204195855126, 0.16949612587209673, 0.059760469687922355, 0.045479127551398935, 0.05013946639073472, 0.032642194400391275, 0.026982461305094824, 0.02549749562486766, 0.033557244291108464, 0.04791546335083343, 0.03588842686205622, 0.06552816563916784, 0.0074058466575919624, 0.07619762537820686, 0.019622750377522844, 0.019289825802608844, 0.05301901086744282, 0.042362084326845025, 0.07379208631332844, 0.0457936487791519, 0.05888611438774294, 0.07384623340781658, 0.07167736954626537, 0.02660723910066149, 0.04668230694087763, 0.11037060134713689, 0.014253778293007805, 0.025800954542994022, 0.10039699459148031, 0.07466826107232802, 0.03896912687548226, 0.04091742636275388, 0.06646774949566012, 0.011270210567501285, 0.0319833472941912, 0.07118128165001832, 0.054118350869224924, 0.09945949449414208, 0.012156663353614991, 0.016321936066472725, 0.1067024497916141, 0.011859885679798262, 0.029071973779449062, 0.09928854963471813, 0.029606896587797714, 0.05219601410170717, 0.023300636995343432, 0.04426016292024044, 0.05502481674475055, 0.04095620956392058, 0.0404798062968879, 0.06441963641273399, 0.06146926327698654, 0.027247897364319335, 0.012705063563771548, 0.05987038032241887, 0.02647847695756824, 0.017310968983257492, 0.025748686279140176, 0.030508628039951288, 0.05709513488616194, 0.03418401529591891, 0.08726594113414327, 0.07741051876256544, 0.02516525095298646, 0.016777093800145294, 0.056160687649201964, 0.11136964894831182, 0.07196028581670216, 0.09119751968330915, 0.007477635320561428, 0.05909475843392073, 1.6767615224084549, 11.559569085797957, 41.77290893370106, 67.00255486272997, 74.75076567742133, 80.39078097189628, 79.83531059757357, 72.23471426194715, 65.45756463081607, 54.308721634649466, 60.763919199666674, 42.85126263095487, 61.306994884244865, 50.90813259924612, 34.41988083624071, 30.18558417597125, 28.591485869499948, 25.512189942021525, 23.051179185990367, 26.56799589433978, 23.693116249576693, 26.95217832442253, 25.17450721033158, 25.836128688627674, 33.18923327230638, 38.86663659926384, 33.95965737681235, 33.169421380566014, 32.671768703768336, 28.499161120383974, 21.978273660905902, 13.064225585229936, 9.195278094660852, 5.943487603818217, 1.5639064749402385, 0.6416661748963018, 0.5281894317557735, 0.23181377789906918, 0.4699013868887579, 0.8267348764404174, 0.7485065741404411, 1.370799243450165, 0.971867291917724, 1.6374620699113416, 2.7617910936955483, 2.513223876876216, 2.219135347873934, 4.266722404187726, 10.99228649370132, 13.56371295067572, 16.756537960421657, 15.266245180560698, 15.156963044597259, 18.29057497362937, 18.63479825758165, 27.384154835054954, 26.282533637938965, 46.28967900430003, 37.44733087478146, 31.817272516988943, 41.088443571521395, 44.18820250418879, 45.878116469229425, 31.057483919205207, 22.591326390543294, 20.21038886039488, 20.953142604520245, 41.18934262183405, 40.00186858638641, 35.234682636876265, 35.94383931929065, 52.58471050570088, 56.93852178512081, 64.51547799571868, 70.1357598458567, 73.90496146294379, 74.73058900525494, 69.76804548694243, 50.614947195976015, 36.92742463081114, 15.796061292771371, 4.281418544630851, 0.7319544784484372, 0.1503727633145548, 0.01456727296294224, 0.05577256452412375, 0.04393846727907658, 0.03065574756493011, 0.012286885851813902, 0.08833045094844796, 0.03246970970423953, 0.03656052728934634, 0.03051366123761381, 0.07313311280262086, 0.019307304098601305, 0.040950494548005444, 0.07307240799550088, 0.12450764316224283, 0.06378630003441246, 0.05578883623163547, 0.018039480294852007, 0.1096486630699327, 0.05155489810051457, 0.038446241223643866, 0.017293082745445353, 0.07287402952750845, 0.012508689373311017, 0.05062928768776117, 0.05774378919252946, 0.06053552850179615, 0.056626304398260774, 0.06438363794117205, 0.0248208963462422, 0.04296157494067185, 0.030647190362815897, 0.027961370369960225, 0.023808197058256597, 0.03264407131580576, 0.009303336320895582, 0.027810238459477984, 0.03418144507093295, 0.03456283428315674, 0.07120476990577675, 0.03701030900101027, 0.1337073325750328, 0.07730128994632153, 0.028611254247446215, 0.04031454964030174, 0.01934747008847133, 0.06051859029779031, 0.025667620770212625, 0.036784803359619075, 0.1793622045267013, 0.36562018096446997, 0.1662533522974099, 0.15367576672184854, 0.22760902771786337, 0.16251124261367708, 0.12881207670415604, 0.25249787606298923, 0.16140162554239074, 0.23637914098799231, 0.16615368425846103, 0.18609913576754833, 0.27141539079527705, 0.11811243310090035, 0.14345512725412846, 0.20027894827146686, 0.11468336992566625, 0.27783496245261163, 0.14545440223188172, 0.11716029306332912, 0.21869199410561593, 0.12625381035069305, 0.20390547060918426, 0.08803734570861825, 0.15304657870963698, 0.20036847330629828, 0.12394471409460231, 0.18583347179716636, 0.08886889584602849, 0.10255813628675477, 0.18140415060183696, 0.1807331341889597, 0.18173059598813135, 0.12568950232478882, 0.19651030130203695, 0.12422006141634719, 0.12711493148198053, 0.1538222886982464, 0.21233971561155013, 0.20029566430997467, 0.1635738065646541, 0.1900622464956776, 0.11386384736866721, 0.328443558105538, 2.7487842690560127, 15.038379007770171, 50.99075340455579, 80.67174819207962, 85.77705029518374, 90.40693759918214, 90.17305451054727, 82.42189407348633, 75.22448601261263, 62.88715308712375, 67.34504838143626, 49.25395142647528, 70.62086289928806, 54.10252655706098, 37.54199727889031, 31.818943446682347, 30.553445623766994, 29.63617386356477, 25.486998519589825, 35.88973022276355, 26.05150603478955, 30.147731342623313, 26.037148198773785, 33.342029202368956, 43.53539851404006, 61.82380637814922, 65.36312964654738, 51.21196723753407, 53.54194533440375, 41.94425767467868, 26.078725322600334, 16.68726105843821, 21.080692198968705, 12.132886244404702, 3.3097655734708233, 2.6106604549192616, 2.0841038323217824, 1.3139026900452953, 1.5272600155684257, 2.2528741052073817, 3.189694468052157, 3.8713065510795968, 2.253159457637418, 4.506873440357947, 7.737702784999725, 5.620889817514728, 6.390997190629283, 12.829261883612602, 24.655420741727276, 27.247707343870594, 31.366133266879668, 24.65415381616162, 38.787032096616684, 38.6620222368548, 32.32486840217344, 45.83992435086159, 42.16395747277045, 74.07667498434745, 57.013180178980676, 64.86734597913681, 65.87302992420813, 68.61057758331299, 58.4696582055861, 31.57138501444171, 32.49555426259195, 23.092242479324344, 24.047488666349842, 43.71121875701412, 42.89370267621933, 42.62975069784349, 42.72470735734509, 61.70804938962383, 67.2743280472294, 74.1192719244188, 79.42310087142452, 84.6863175976661, 86.78407176848381, 80.80708565250521, 62.301147061009566, 43.491142411385816, 17.3443070919283, 4.803320784722605, 1.0431474831796463, 0.35759295847627426, 0.16623170265266973, 0.1570026107853459, 0.14697401423848447, 0.1272260908397936, 0.22751012576683877, 0.18148285847517753, 0.1296987775112352, 0.16770914917992008, 0.12011743841632722, 0.1708226837217808, 0.13570841552028734, 0.1417379411718538, 0.12195459386754422, 0.1752867853088725, 0.14379841125299855, 0.1759294564685514, 0.1131212860045414, 0.203902023213525, 0.16605709589296774, 0.16956458348901043, 0.1344617759628642, 0.26797541086712195, 0.1570398579802244, 0.2142022745383363, 0.23848192976607432, 0.1543463541254882, 0.11284940906109349, 0.1966099080539519, 0.10795756994235901, 0.18570729711603734, 0.06873015269276596, 0.14653932062848923, 0.12310074567193947, 0.1450229721564439, 0.09797836308397594, 0.16334064004402007, 0.22679384887939502, 0.17238951738803618, 0.23056264906640977, 0.12332596019991945, 0.27083374619964634, 0.18461519281470007, 0.2789282312075938, 0.23500888548310728, 0.13469728671254652, 0.30335405601128457, 0.12107281900581815, 0.21901684602902782], [0.04026102307703226, 0.08232168627962952, 0.029750587869315382, 0.01560272123183935, 0.03399337814640134, 0.039282828389156255, 0.015063899035956112, 0.011223455263872542, 0.03141660119346794, 0.023431710808748202, 0.08378129061912337, 0.03508861574734892, 0.03309368448812635, 0.05935531259784776, 0.026090765604749325, 0.08679515712203519, 0.020418742543927604, 0.06374413072462044, 0.01614350844324837, 0.03602087580328507, 0.04078113932102438, 0.055131712823265025, 0.019258163388698332, 0.06355955333058393, 0.09968868501844907, 0.04194350920677666, 0.02901092423276315, 0.023681070512881684, 0.04118110616541198, 0.03572968195282644, 0.041499515289380666, 0.02877979359078792, 0.07323430535653908, 0.053058169451692415, 0.0796812646571667, 0.10130857793434013, 0.030979459932554635, 0.049438798544748176, 0.059827364485470526, 0.06226402204183321, 0.0582016799448719, 0.03481449416628288, 0.030482856842178493, 3.6385656076092876, 21.14699790554662, 41.11504116365987, 73.78595675191572, 68.904967154226, 68.50133172927364, 62.30634812385806, 65.80626333913496, 53.87395828000961, 39.98009943193005, 31.08707231860007, 28.044680010887888, 27.472825896355417, 43.683899448763945, 25.81084312931184, 15.577560759359791, 17.029697702777003, 19.432406348566857, 26.84576834401777, 19.28916335105896, 26.147641366527928, 38.38222780535298, 41.687416953425256, 46.52456229732883, 37.327188676403416, 37.92475392741542, 43.35422815815095, 36.894304137076105, 23.040865313622263, 13.133661343205361, 10.96026328302199, 2.1457762391336503, 1.7269180955425387, 0.77338365537505, 0.10239322053929491, 0.07907927276626711, 0.01876374364890639, 0.03225248164287017, 0.09887546736506686, 0.05623879031308236, 0.11383990712103345, 0.11556059422512209, 0.010229541409400203, 0.0923846188872572, 0.04425201557516571, 0.018690835061152617, 0.10536674485211411, 0.2050581877870906, 0.46312558434663287, 0.3699323366726599, 1.1086753347227651, 1.5676003670500172, 3.057008775011186, 2.8595750466469796, 2.526607249052294, 3.0897627722832466, 3.0252262998011807, 8.22927971040049, 7.8292077587496856, 16.685919607839278, 39.37962378225019, 48.041507582510675, 42.97415833319388, 59.14681226976457, 53.96295685921946, 59.02637981599378, 50.762424392084924, 44.40710606113557, 29.149776427976548, 15.27889580495896, 15.605025195306348, 21.583673415645478, 28.96412476416557, 37.959537506103516, 37.43353982125559, 45.37154236147481, 52.87457758380521, 60.05442127104729, 65.52475090949767, 66.40526417763003, 64.41688137669718, 52.950467601899184, 35.8793241746964, 13.980789357616057, 4.522003002705113, 1.0037279693830399, 0.3963984068362944, 0.06428800718558413, 0.0460767833846471, 0.01121569479319958, 0.03134446443929788, 0.07706168062624431, 0.09225357188692979, 0.10057688735785986, 0.06218552484267181, 0.027686718273006623, 0.017357681194440495, 0.04375224662644248, 0.022858845580729748, 0.04998651310621251, 0.029944046137614116, 0.08066150479980054, 0.08786083138998478, 0.0144678644362777, 0.05221106772941928, 0.04457064303419283, 0.07921562109503054, 0.05843454386077582, 0.056865718365917285, 0.019769207236447164, 0.0795931568849952, 0.052495895389227144, 0.039345272215864355, 0.07166940223185286, 0.0418419489306548, 0.08074490113123771, 0.03209406232100821, 0.0495394203631628, 0.042060494663253914, 0.00856187908099063, 0.018996393060191505, 0.03991192064037727, 0.038950292603863824, 0.03010814600143462, 0.012054991994744108, 0.048205925587324366, 0.11153870157056278, 0.1456698108344309, 0.09149315301328899, 0.0027665177795795667, 0.07152245124621738, 0.047901742716109565, 0.023814478979235696, 0.045812758842423085, 0.10032440009977549, 0.06986617681480224, 0.058375118420489376, 0.09192644468238277, 0.018020538770924174, 0.06994966507679032, 0.02867752276811629, 0.13806474875778924, 0.034013338567268465, 0.027346646097759088, 0.04534724934567367, 0.079152311588968, 0.05880724946637789, 0.02239836545120324, 0.06133039834939184, 0.027146965280295383, 0.0828068957273518, 0.010986108776001681, 0.04113875299451813, 0.011802089133960827, 0.06527776980111677, 0.04961576485525697, 0.05753498043744795, 0.04318611531127845, 0.0077841178919639325, 0.03884341184710784, 0.02343402630949934, 0.06551274428925206, 0.011416908744121752, 0.03431400892535045, 0.06454498371890476, 0.03039061411043569, 0.020294237934473543, 0.014417205914674748, 0.02799326069502821, 0.037125459676908876, 0.049507834558044715, 0.022322746827417327, 0.026159590943866683, 0.07255686146597709, 0.0781245586732703, 0.1877156119312971, 5.5522159799452755, 27.077664752160352, 49.07021584049348, 82.04457775239023, 77.13963031768799, 77.66848348802137, 70.74469997036842, 70.12297291909495, 63.02188258017264, 46.612266494381814, 39.70288984237179, 37.4482879331035, 36.93155488660259, 52.14447936704082, 34.54495737629552, 22.793189210276452, 21.383407000572454, 27.66120949099141, 33.33059157094648, 22.85720621385882, 29.983266361298103, 36.67618897653396, 27.34308565816572, 23.640634936671105, 29.619111553315197, 28.429529243899932, 33.241373339006984, 27.517246738556896, 17.988150427418372, 10.944041340581833, 7.271806597709657, 2.2006288699565397, 1.2604765762244503, 0.52066988041324, 0.10781676298187626, 0.020583512734681852, 0.09439113339589489, 0.0684832502156496, 0.13151975318549142, 0.12414932085741913, 0.24652599086684568, 0.11441402873324771, 0.07673361879442969, 0.06091577624301277, 0.09812313837990647, 0.03579422869088669, 0.07756735228242413, 0.18951458556036796, 0.06558481018028914, 0.1346210609640806, 0.5628397111450473, 1.1194647944742635, 1.9955960396797428, 1.598085518325529, 1.470991654261466, 1.3909366919148354, 2.212629116350605, 6.344589667935526, 6.818737051179332, 13.406896591186525, 26.658675209168468, 33.47853945147607, 36.57784338920347, 44.20850861457087, 38.210412302324855, 50.29017494570825, 47.7202223193261, 43.088373830241544, 36.6016286419284, 23.153256908539806, 23.665906767691336, 29.92432490471871, 38.88356554892756, 49.409120390492106, 47.48084399007982, 53.49951705624981, 60.55585707387617, 66.89153609737274, 72.39523333887901, 74.50367989078646, 74.66381457544144, 63.48849165824152, 47.8211292143791, 20.869974628571544, 7.846004818716358, 1.6243959194229496, 0.4769884049892426, 0.04198717238802103, 0.057367502125881376, 0.008853064312960112, 0.02492749748090583, 0.05007599217576846, 0.08170728376435657, 0.030486208476847222, 0.03663086565211415, 0.04035099627329938, 0.07201798755915896, 0.05556944780231965, 0.0218281872765792, 0.0674839191619427, 0.06578952419541537, 0.05873727499537411, 0.07309408828375802, 0.01525901492700101, 0.024232701698858893, 0.048119936048263506, 0.027544034397109386, 0.04481507487775338, 0.036482872786901654, 0.040577049667556445, 0.059634881064055435, 0.03905512024498275, 0.03845589010105018, 0.025178852844082063, 0.08554741439800109, 0.027666840206591353, 0.08164705393174965, 0.011956017265366692, 0.020387687254697084, 0.05677206794761362, 0.06815737173441919, 0.03806770951937764, 0.017094755988387812, 0.030333483103482477, 0.04499785579560746, 0.015419695165849503, 0.01848598889585945, 0.09602187411679376, 0.06906162361584364, 0.040148055751717864, 0.043130075979617336, 0.09514234389268583, 0.05343696545629252, 0.1413950861822213, 0.1499502811460726, 0.18507306824528402, 0.10140630777084059, 0.1390404843034283, 0.14361891685233963, 0.1855544625751434, 0.16150415875017643, 0.23207115279811047, 0.09355557661864067, 0.17411980357381607, 0.23994957036789388, 0.14981137408364206, 0.19596440236895316, 0.2419034010099788, 0.28518186822052927, 0.11314471297326589, 0.17631505916435875, 0.11732302546020477, 0.13616313466862326, 0.12752606022742488, 0.20535929098484978, 0.14907001547755735, 0.18990152124916354, 0.16914072236226452, 0.1298280625093368, 0.15953977141649495, 0.11538090830248211, 0.16192078800691714, 0.114659950617821, 0.1554156443284404, 0.18548677104615396, 0.19604202239744126, 0.1374100806612161, 0.2880743404309596, 0.12482697159172067, 0.1391097846170587, 0.21051114034508506, 0.1445913582199043, 0.11745785693487815, 0.17696474768942405, 0.19059665410989718, 0.643826175120569, 8.184843178718321, 34.811517730835945, 60.60285099091069, 95.35386223946848, 86.63928924068328, 89.83851555855044, 82.20204522532802, 83.45079452760758, 72.05051975865518, 56.83038203947006, 47.00641370588734, 41.41579281899237, 40.51142369547198, 57.192408961634484, 37.900631350855676, 25.357162183330907, 25.690373413024414, 28.366716407960464, 38.38230233038626, 29.216205689214892, 37.37337850755261, 51.4123885862289, 54.8603480862033, 64.64586542498681, 51.625942030260646, 51.77791426258703, 56.81239012748965, 46.73365208410448, 30.91447038035239, 19.03326007627672, 13.512500524520876, 3.257669633434665, 2.5891384097837635, 1.378599244260019, 0.30619348429383775, 0.3454017723279615, 0.23569022876120385, 0.20027436706567966, 0.40103762080111816, 0.2623290670735221, 0.2893370984783096, 0.21879950688490946, 0.32194820503073357, 0.5555847359280432, 0.46450883270271365, 0.0844668856851997, 0.20175452554418197, 0.6122900737870125, 0.778390009316706, 0.7484535608560808, 1.783633852197278, 2.2289981476722227, 4.349408909197777, 4.5053746046558505, 3.171390482494908, 4.069304120156073, 4.227453595207584, 11.187674460872527, 10.79864594244188, 22.50938023290327, 50.18068982708839, 62.12395791084536, 56.13201971976988, 72.77823709672498, 68.20526338392689, 77.16086602980091, 65.26254830821868, 56.42073754341372, 40.66711825709189, 26.28957429239827, 27.339202511695127, 36.05173195562055, 44.19870268914008, 54.79178897796139, 55.18610485138432, 63.396351260523645, 68.60759658198204, 76.19347618472192, 81.61881231492566, 83.23329125681232, 86.15561392999466, 72.56358931141516, 54.391785667788604, 24.025731279004006, 9.124978434654976, 1.9223961546536417, 0.7842382632436291, 0.22805283777415755, 0.18203520786858376, 0.09047905178440195, 0.09575772700050185, 0.08741103052612274, 0.2653300786210645, 0.27825257230189543, 0.15073567448604494, 0.09454530859065634, 0.15466783526203326, 0.13827853325393893, 0.13281022829394187, 0.1984635497172994, 0.1015044053295447, 0.25014826907746257, 0.24545136869194048, 0.10564407634158289, 0.16119236096499429, 0.14111935581651427, 0.12753395093304495, 0.19345031630608345, 0.15210225276889341, 0.20200368798067495, 0.1629099607347481, 0.1545774062434512, 0.13052917085587978, 0.20183154802408912, 0.12089125616776368, 0.21337840826280657, 0.16807576821696374, 0.10680432416378491, 0.1601435099878619, 0.2223473060275278, 0.1318594059276004, 0.1643425145096356, 0.15694901527416322, 0.18415229184733284, 0.10264577674529246, 0.09020402621958526, 0.2841037373629309, 0.20901351506190918, 0.14518060240774386, 0.1352311580652191, 0.15795245255914428, 0.1958990091037366, 0.24613664966196785], [0.05804006603636569, 0.055665814002314885, 0.059588076922321515, 0.05869175788135298, 0.049728119310231945, 0.04732269515854217, 0.03356020139049619, 0.033666476937792, 0.024035667715173577, 0.021861201835676067, 0.0608975816548111, 0.03159756648294147, 0.01402935092037003, 0.0543873434916379, 0.04053935431124222, 0.06113972289547805, 0.02534291823394597, 0.0516992980133622, 0.06001721639486571, 0.022833407631204016, 0.06157117212311395, 0.009852318757874592, 0.03405699025719397, 0.009323038187088266, 0.041683188699666536, 0.03211928959635477, 0.04221319896920074, 0.030549163667244777, 0.02474551137927319, 0.08801863018062808, 0.05965781773650839, 0.04432726839196779, 0.023070684213551785, 0.022058998076846043, 0.015450166313037758, 0.06856891416734265, 0.03487295816622434, 0.05455941066987092, 0.03638406276642796, 0.04249685834492407, 0.09240950908391707, 1.2944488371572187, 12.385646720086376, 34.85705644853654, 63.62285244849421, 72.6895523071289, 69.63921131626253, 76.26567133011358, 45.06366768190938, 44.66228369743594, 61.736741527434326, 39.081033352882635, 33.161737457398445, 25.067706954094675, 20.580425262451172, 17.277034521102905, 24.521124670582434, 43.59383790723739, 47.90072587228591, 39.54698347276257, 46.73785294255903, 47.47887888262349, 47.68339910814839, 49.702501912270826, 58.540033371217795, 56.59704416028915, 49.943343285591375, 35.25822862502068, 23.84606711326107, 13.143177993835943, 5.914479224912583, 2.9123105781693615, 1.0130646812819666, 0.14495488226173386, 0.12438331475301136, 0.08240056269231343, 0.0892168912856329, 0.11137441401520085, 0.08772104332644133, 0.04584343300291127, 0.019080350551033215, 0.0958960288534722, 0.0342191634098849, 0.034124432807608, 0.08540388782538715, 0.08921328301150953, 0.07058028567342028, 0.024066248029891043, 0.041313080132127776, 0.07744893041108886, 0.05245098731510582, 0.05382618025666284, 0.03732889815564117, 0.1043767907146004, 0.06783327057717309, 0.02578133886169282, 0.011837039022676408, 0.02110574721178461, 0.05100525682792068, 0.23856429953969296, 0.4094914623325871, 0.8795754539389765, 1.7354211812057805, 2.490168430151478, 5.9249034139417835, 10.871831486302039, 25.221350116114465, 46.378159830647135, 40.68921296827255, 57.38936293509699, 53.16904952449184, 37.331165959758145, 28.09031874902787, 26.200542373041955, 21.903948668510687, 17.55001187324524, 23.984736627148045, 24.576000590478223, 36.16091505173714, 31.671438793982233, 42.80439815213604, 41.07482902465328, 53.15974958481328, 60.3752907629936, 66.77896407342726, 70.12265912948116, 60.199890213627974, 43.72268776739798, 20.46721193098253, 3.0878565003795013, 0.4336233851650069, 0.09407912110609394, 0.021170278628086372, 0.019615650657684575, 0.07160318925255729, 0.016596304710894343, 0.019498829910111044, 0.03993239817059329, 0.10108569231364997, 0.06929986163853638, 0.04043535787552115, 0.022071320601108096, 0.06642878626383121, 0.056234986686538306, 0.050631528494939695, 0.0070071721077716404, 0.1131421006134441, 0.03768615559825013, 0.12197042124405985, 0.04578087043257491, 0.0844280833318349, 0.05862237712849052, 0.04541035583843628, 0.04896852781154937, 0.013830268609097168, 0.05301860867128257, 0.05699967266991735, 0.04767467425535283, 0.0824721459479582, 0.07512441280508235, 0.038778531860800526, 0.009569049129382739, 0.008991723354425161, 0.03801804403924654, 0.09331312511236438, 0.03104177926997504, 0.05404850663316827, 0.008394133596260463, 0.10819488865954262, 0.03747990557683572, 0.07026229789780994, 0.05787633006430923, 0.024778035642098517, 0.037138954315695076, 0.011920063801470303, 0.061910135386091095, 0.14249973900375829, 0.053062559135498545, 0.024738233543992526, 0.016334804428380825, 0.05220076384683771, 0.032345247229621295, 0.10597473521146084, 0.06059111201114232, 0.04297351825141138, 0.043079675055078925, 0.04463413257091757, 0.053866177707189516, 0.04302598378290573, 0.05626563786438877, 0.03592247947029049, 0.04266766147808202, 0.03705106870902162, 0.05667185215579887, 0.0406717189827994, 0.06280152082082725, 0.035659745786218874, 0.02636911216071777, 0.06539491230561849, 0.0148716981094631, 0.006930134784910949, 0.0517349325931601, 0.03215243439039877, 0.010188718499135106, 0.030559662902247042, 0.03476299773601275, 0.043531061720944224, 0.036716790073701454, 0.033369874506587946, 0.042527628266402794, 0.008855516751927715, 0.04714471761197333, 0.04101082397204253, 0.08718789209641757, 0.014757465781463731, 0.0031668334333751834, 0.13347539179507764, 2.6807034448269875, 16.76986813545227, 41.636194721344985, 73.48848419804727, 81.46684400496945, 78.38870909906204, 85.08025692355248, 54.68247644362911, 53.370890771189046, 69.00562301758798, 52.59320635949412, 47.16995693022206, 36.56156947535854, 30.594657967167517, 23.945697276822983, 27.715959895041685, 33.27874960437898, 28.015758414422315, 18.974032286674746, 21.703952896979548, 30.49105248143596, 28.542972034023656, 29.328701226942, 39.4215617641326, 41.150628828233295, 39.95623180943151, 24.535790412656723, 15.62123635122853, 7.834939322163982, 5.618041196177083, 2.5515684773845058, 0.6891725741086469, 0.2495207817804429, 0.11916333719366982, 0.108863384643149, 0.11589979497535575, 0.10092371834381934, 0.14721376911526726, 0.1812129963429705, 0.2064826669952562, 0.5270518831187679, 0.33266476385535737, 0.4068519523547542, 0.22674262824077762, 0.05855153314769269, 0.053062363783077854, 0.13696361994070394, 0.11783019098783694, 0.19352174634414335, 0.1282549852264985, 0.06090117460717598, 0.049872457936045625, 0.058705777290367314, 0.05870489628925439, 0.09739661123603584, 0.050935404930984786, 0.018426530896836234, 0.05338905431750802, 0.22804755176748, 0.13185693912448423, 0.6264164286755747, 1.189404086720559, 1.9981121175712155, 4.89618682092236, 9.270018858294334, 17.599722031624086, 36.36904778019075, 39.756791053279755, 48.873261867030976, 46.664139839910696, 38.56270390172159, 30.101906291900146, 29.21499759920182, 34.05821869450231, 27.972600575416322, 38.373288723730276, 33.41765642166138, 47.71602538324172, 41.172719617043775, 52.29868342799526, 47.8314293584516, 59.87804797387893, 68.8112146623673, 71.90448991713986, 78.43360454805436, 72.0440713820919, 52.453617049801736, 24.996445332804036, 5.386263930028485, 0.5805093146139576, 0.06830131965539149, 0.021367988684364868, 0.020150401096250263, 0.003164540915261774, 0.0028994725782409193, 0.017728940809085485, 0.07089684852549145, 0.03616626396955502, 0.04043982799855932, 0.035680828525895075, 0.026988704921677712, 0.03602076472053605, 0.02979412081561262, 0.050252874216605584, 0.07505108286897022, 0.061890109847750396, 0.05924397703981208, 0.06399329699155304, 0.02130853451578127, 0.010768677701332397, 0.0398913971448858, 0.04004621968394326, 0.049733876460982915, 0.03679922879523328, 0.03300325546954428, 0.04626833217879457, 0.06588827292885512, 0.021976021178547415, 0.05072263933177437, 0.030833797889851758, 0.021695313156552373, 0.07067946341609763, 0.03652820987026057, 0.04329148304438399, 0.04068812858613749, 0.0179622164972487, 0.00462344931175692, 0.04877455434912155, 0.07987986529065717, 0.012750709955129894, 0.04244240098482659, 0.03630570729353255, 0.038006594855218165, 0.005938011182156662, 0.05829480942338706, 0.24154309453743122, 0.1279756236040304, 0.11573906972884171, 0.1965024718834508, 0.1392269960694736, 0.1482835649362495, 0.17806809816148975, 0.2107810331208091, 0.15626590999384082, 0.16873504816284104, 0.13070000846299434, 0.14764208887373248, 0.16533977712594694, 0.14525483632760663, 0.23588133705479486, 0.1719672497241728, 0.15137471438896272, 0.18615691411879756, 0.14612503560079684, 0.1850590488362697, 0.13989974384105977, 0.18251053478208282, 0.12078172091635005, 0.12997410951122162, 0.1106966024024352, 0.2040017525395078, 0.17153119247767235, 0.1447436105339758, 0.11090361468133428, 0.12776661949652818, 0.12988397160605078, 0.14992475509643555, 0.2293782311701967, 0.1271336316882122, 0.13164840999149507, 0.11415388059592056, 0.1278841373841128, 0.13521146960556507, 0.08693675315307994, 0.19995834047515548, 0.293351705636709, 4.105255094266707, 22.13913202285767, 53.574897166221376, 84.29610452344342, 94.41261891395816, 87.43317696356004, 95.39461566555886, 65.34819718330138, 63.26097065402616, 77.93838962431877, 56.762497578897786, 48.832061290740974, 36.98317327807027, 33.03844951814221, 28.120085616265577, 34.90064182589131, 55.244771742051654, 64.39529265126875, 56.114035652529815, 61.484603728017504, 62.683025098616085, 63.132489496661776, 65.54825767394036, 74.49207751981675, 73.69986857137373, 61.19741955111104, 43.97599443312615, 29.706682389782323, 17.86565480693694, 8.82316283641323, 4.542835200986555, 1.4660861174906454, 0.3947683555945274, 0.3299138034063001, 0.23015714340632965, 0.41595509936732633, 0.315579685472673, 0.2893346776404689, 0.3331190539944557, 0.305175322798952, 0.4151261615897379, 0.496035710337662, 0.3660336539389626, 0.5046894395303342, 0.2936228088313534, 0.1367962756945241, 0.2686515294255749, 0.22975010557040093, 0.3885833600596074, 0.4525020285960167, 0.3656693638092087, 0.27566904802956893, 0.24675321254518726, 0.22929458969062377, 0.29747708910895937, 0.13741176605464953, 0.2333227719270414, 0.32579071819782257, 0.5136984496587708, 0.5198138231231321, 1.6588978229030487, 2.5159638975897147, 3.4505791529532406, 7.841183735478309, 13.21146841972105, 31.680613217815278, 56.881929828274636, 49.99930766320998, 68.45769143873646, 65.2437876116845, 50.52340299852433, 41.83736524274273, 37.90352606004284, 36.2294820047194, 29.247339502457653, 37.62647728766165, 36.71689533418225, 51.37707156519736, 46.756029205937544, 61.12716205658452, 59.11232679120956, 71.77105088387766, 77.8717799340525, 83.34583190179642, 88.25564307551231, 84.22124216633459, 60.817420328817065, 30.731907583052116, 7.3013209623675195, 0.8840167414276832, 0.20479316733056502, 0.061314697377383716, 0.1280765327054166, 0.2630534798147217, 0.09028700886354332, 0.1648655993443343, 0.1062010069407763, 0.16803991530210743, 0.2877520319194563, 0.21547284668251393, 0.08853190142901675, 0.1152502749896338, 0.15700190598445554, 0.18627691413125685, 0.12571004114203876, 0.23717334433909387, 0.20251733461214652, 0.22432388948096385, 0.1691017744521941, 0.19917210443846642, 0.1269901664026322, 0.1530048115960052, 0.1578114617375597, 0.14325523959292522, 0.14101624038190613, 0.11348904651259223, 0.16252072678217966, 0.26399423578573816, 0.20167114453450327, 0.16099406676667352, 0.1246971503320721, 0.16581237676643557, 0.16429775965309915, 0.285553757942492, 0.1742711672258954, 0.2580023556947708, 0.10666200801009133, 0.2601083926856518, 0.15231635902197133, 0.10714176291179274, 0.18612135231735247, 0.2085850420858591, 0.15763616549872583, 0.07474413442034876, 0.19670078140353003], [0.03331870366368563, 0.06649581895720574, 0.06028108005862563, 0.030066480394452814, 0.030593424397070083, 0.031677128544317625, 0.03975165121617817, 0.04246171023095808, 0.028784234985528935, 0.14967530154653136, 0.06803366385640637, 0.035246334098760164, 0.11097895176780802, 0.016281651332974434, 0.03557796590030193, 0.042402445669135744, 0.036992363391384, 0.06502191175616558, 0.06475611755083646, 0.029228228902924928, 0.09296050250169732, 0.03261268469354799, 0.024254169397717042, 0.008507486838366716, 0.015486240435782221, 0.019874333651856552, 0.059567128248032064, 0.011633834200761011, 0.03344557548482572, 0.03162449638869974, 0.022498619547414205, 0.046079192731168964, 0.03234922322594831, 0.019030520361998392, 0.07091921063200121, 0.02332442211017253, 0.04497615252471259, 0.12430124375368319, 0.03538046460298281, 0.17048701463687807, 6.071451008319856, 29.22006137909428, 55.56528037594211, 70.20374236568328, 73.63029356925719, 69.32722599275651, 62.72686150766189, 55.702935957139545, 39.57757796010664, 42.801978049739716, 42.9574647257405, 18.57785132623488, 13.120833231556801, 12.766945227499932, 21.078026948436616, 34.67346206788094, 49.89765551782424, 56.63975877146567, 71.43537444453086, 66.12925483334449, 64.18237070883474, 51.34175454416583, 42.30761428033152, 34.09077044456236, 22.979617503381547, 9.10976650253419, 3.8262615617244475, 3.701469148358991, 2.057529038959934, 1.3537141344239636, 0.4667462078073333, 0.027670632341816544, 0.019047653918424924, 0.06265923148021102, 0.08421005470858467, 0.03594822002454631, 0.03503276793766887, 0.04513828737300731, 0.08254551418846653, 0.012271239463570378, 0.08696496051045195, 0.17649872108332573, 0.0622477503343215, 0.20327519475212022, 0.01011390331005978, 0.06719923322840084, 0.13797165375323067, 0.033047324677388516, 0.054167767370780634, 0.07976851441086301, 0.05221356900649206, 0.07390594996151424, 0.0315846138513617, 0.0357672585655124, 0.02031790622089419, 0.19132953978353934, 0.09664067397675208, 0.04826584132388235, 0.0060632809219251, 0.03678403344125517, 0.08552257782749592, 0.04714543007374291, 0.05687383506747504, 0.10788676043551777, 0.2058996281196033, 0.538462303098171, 0.6438926715523966, 1.4087975722166801, 7.64618065088026, 15.336838037736955, 28.53347597583648, 40.02460264390515, 50.4747538412771, 46.43408498456402, 43.20110274899391, 35.126107508136386, 25.313998460769657, 24.173928230039536, 21.64870435191739, 24.646232589598625, 21.70637103819078, 30.52207450712881, 36.22106459832961, 39.16610563955, 54.61501952140562, 58.57269494764267, 67.35800004774525, 63.054579457929066, 52.40456388842676, 25.766051623129076, 7.660406106902708, 0.8583657888154831, 0.07468965790805317, 0.01711981663961084, 0.07780714546360316, 0.0025776620238884204, 0.05761659178402155, 0.029634538955325564, 0.05273418320763496, 0.06957702458866181, 0.047339261809904734, 0.04957973574017806, 0.04153977704024123, 0.07283766333374285, 0.03382085131541376, 0.06746490485966206, 0.07388895047047446, 0.06173947014875951, 0.06387260366952227, 0.06750178433233692, 0.08871017008899681, 0.04403404440850981, 0.03473953629333166, 0.05772205527811762, 0.04887722545273362, 0.0521449045458388, 0.02332277885157495, 0.04508005319944313, 0.019003144210024227, 0.03554124730609117, 0.029785506156904083, 0.013662237756615205, 0.05538888470900636, 0.037074051346750035, 0.06575460590782665, 0.05523614975954256, 0.014745340524842183, 0.03229068261721442, 0.04072111250171739, 0.057730658445507295, 0.02336901800346471, 0.018572941790485097, 0.05164723467802809, 0.048737962159418294, 0.027492066822765816, 0.028061800666393775, 0.07095839602932816, 0.00862911191483539, 0.003088478918089682, 0.04901745018639392, 0.038607590831816196, 0.017995225310686137, 0.0555122938127287, 0.06064366564274796, 0.08714531292958606, 0.04704846632516673, 0.03533486321929001, 0.06877522930623063, 0.036244650085967396, 0.00903882339761983, 0.06633841087140384, 0.04183175613082225, 0.03897868382233766, 0.04112115978533703, 0.025641370767487154, 0.03690701736617954, 0.018627083139313806, 0.06570320906898668, 0.02707313355659285, 0.02648398896018344, 0.029366406266607588, 0.038509412833880034, 0.08462568039014455, 0.010240688946308389, 0.03976376689670067, 0.011025743292374237, 0.021316457780138142, 0.029669662171434012, 0.05293002592459802, 0.021061632038664915, 0.12128477255182883, 0.09051826016436662, 0.024482578512341268, 0.037257004634387074, 0.018193789555000204, 0.08178287365984532, 9.283749115082527, 38.14199832177932, 64.50833143726473, 80.5476365550872, 80.94763986525997, 78.05440548927554, 71.29565961899297, 66.49436473846436, 50.50760761384041, 51.14370622942525, 56.64509319490003, 30.211242360453454, 25.387172237519298, 16.01435688234145, 26.820198412864443, 37.72349711387388, 44.42968322384743, 64.31044786207138, 72.40740837589388, 64.52600955963135, 60.38854837417603, 49.43933048555928, 37.90440074859127, 30.05283744104447, 18.984989427751113, 11.366102099418642, 4.984447504243543, 4.145867805327139, 1.41268611194626, 0.9354154188786784, 0.321715620736922, 0.15546882615214394, 0.05175193974507913, 0.0233500630729982, 0.04149961871125045, 0.08104064171352694, 0.053209012163983244, 0.14460952982546824, 0.2837378844138115, 0.09450617681948409, 0.7659931745259994, 0.7135844254685987, 0.34175473415563185, 0.6354449893678389, 0.07417869258431659, 0.0761646299713081, 0.21122078291110455, 0.12306112360449568, 0.1562657108109805, 0.06634785673551022, 0.057222811099622524, 0.09088406714821055, 0.16030782052586157, 0.05288066304919701, 0.03485406260757196, 0.12571518925288994, 0.15264291166057511, 0.1129800423739418, 0.17504889968662493, 0.16185052242250214, 0.2513320587815777, 0.1926657656628278, 0.12990929847282748, 0.12725616745170087, 0.08673249879070828, 0.17061925673436734, 0.6531916919254488, 1.3851595309472855, 5.513466394716694, 11.270129546042412, 24.34130164884752, 35.98467511515464, 42.42741523250457, 41.79259530959591, 37.80199943050262, 31.555491570503484, 28.260553536876557, 33.05229156248031, 35.241123168699204, 36.559098382149976, 37.682363217876805, 42.2895243090968, 47.37228062845046, 47.0726703828381, 62.3214453266513, 64.73345195093464, 75.71400565485801, 72.545899421938, 61.50122281043761, 32.46319274748526, 10.42809178752284, 0.8361000868101275, 0.1321567859380476, 0.10447915538304275, 0.06256411783397198, 0.04970335168763996, 0.04350940058488519, 0.086278967078655, 0.029604609815343737, 0.03493146813144127, 0.043858947352536266, 0.07692597581133728, 0.059262194610651464, 0.03233593543090167, 0.013844884609082534, 0.016283890224933144, 0.03870528619436007, 0.06241543932006725, 0.06216621559654033, 0.08252733492202337, 0.08542942153590341, 0.0527834618133643, 0.056652136883067514, 0.02764929487790552, 0.09451053585977325, 0.03354450424892768, 0.08017179075508349, 0.07921560577327207, 0.07947514870113905, 0.016007053819785438, 0.014803108342382458, 0.07939993418873319, 0.03287968548735784, 0.027526776351395155, 0.021185008583650477, 0.022485174704343084, 0.02134193977971952, 0.05331951268618146, 0.06021781268739893, 0.007551988462857422, 0.032098348582944566, 0.06063839495782891, 0.06095807578775191, 0.05954242574291364, 0.06021917632390415, 0.03480458864942193, 0.12853083050539418, 0.16831166201060818, 0.13368266454387095, 0.13270695964174886, 0.13736432989037808, 0.06520011146823246, 0.12520067694206394, 0.14445694043271004, 0.2075079837513547, 0.21450288743982393, 0.14851253329505845, 0.12169233132754603, 0.1697857530727502, 0.11756849535290273, 0.21365187100825772, 0.13818110219172894, 0.09257258622035866, 0.14948816158838812, 0.14564263003487743, 0.15505006717097375, 0.1522967778146267, 0.189194590634396, 0.10348378500390439, 0.17713540143543677, 0.10157724496938529, 0.15100343753733944, 0.20036076646178, 0.11896275239245546, 0.05675534424822658, 0.133881724830116, 0.12243034979028088, 0.27314255134232585, 0.22072748972042916, 0.16336628866772498, 0.17081983387470248, 0.21889663151194974, 0.1874545598102193, 0.24801192564829705, 0.07369346781483582, 0.41636648858266495, 12.835344499157323, 46.650717489181034, 79.05099345791724, 92.51523510102304, 90.9190736278411, 86.491666916878, 82.78400728779455, 71.80272010064894, 57.187698195057536, 60.637050136443115, 60.72548781671832, 30.3258579392587, 23.335415701712332, 22.723116067148027, 31.996197315954397, 47.76548647111463, 64.41679508455339, 67.98807390274541, 82.1427546778033, 79.81951129051947, 80.67890259527391, 63.964851748558786, 53.8325458957303, 43.394067671991166, 28.79384094668973, 12.93233882996344, 6.065597361133945, 5.522658959511788, 2.977084844343124, 2.0445729599845026, 1.1578856360527778, 0.3168037714016053, 0.1685676119861103, 0.14053355902433395, 0.21943347528576854, 0.33956228244689207, 0.17357992609181713, 0.1742780926607309, 0.21899297472930726, 0.10768799892356319, 0.41728306681879107, 0.7278369090730145, 0.35416048620977714, 0.9876579575000272, 0.35979169210599315, 0.2524682284603196, 0.3603638372113628, 0.25767781020652863, 0.3265103811938917, 0.3992640353258579, 0.4503150927203317, 0.277035013442078, 0.19133732323685002, 0.15043702276964344, 0.3905050150088726, 0.483804289251566, 0.2864145649777305, 0.1155549941223956, 0.262430313253595, 0.2678952474267252, 0.5521324985930997, 0.2204059166533332, 0.2566357161248884, 0.2534060426537068, 0.5014677027300481, 0.8635316116194572, 0.9719435329879484, 2.0538584359230536, 10.006688025689895, 20.652030091131888, 37.11636127964143, 51.72675086605934, 66.37685837284212, 62.29471829629714, 56.60302969717211, 45.293016510625044, 37.43958811606131, 36.87340182642783, 32.96089249272501, 37.983071727137414, 34.98784788193242, 45.91837959904825, 51.86162940917477, 55.400462381301395, 73.02851569268012, 75.81008803459906, 85.52615980948173, 82.87037003424861, 72.88851061174947, 42.29370947807066, 14.700820811333196, 1.0974975603242074, 0.396355168833848, 0.2209306868814653, 0.18763572428255312, 0.15577593547922952, 0.21770341892636594, 0.08388989890414862, 0.16099395951436413, 0.17461511006038036, 0.12222418786897776, 0.15727392848460905, 0.22026573788494835, 0.12970058547873653, 0.08788345396638879, 0.1660357373616388, 0.16538716732494294, 0.18098306271337694, 0.26184707519508177, 0.2183782657788646, 0.28766120453515365, 0.24255623049553365, 0.16137052237266497, 0.21378330105254728, 0.14591638389373981, 0.07884739327334589, 0.1422593099696021, 0.14660416231040033, 0.11151845386672406, 0.11121199571437414, 0.11492320907212074, 0.13081175004762988, 0.13961482042026135, 0.0644145725715545, 0.07999367531268828, 0.11840800514384625, 0.12169942530172488, 0.23068799637258056, 0.1725133171965999, 0.17371170853655185, 0.17156486970282372, 0.13494002933223403, 0.13844756289355217, 0.17902357834241084, 0.1635784643792337, 0.09120958556811656], [0.019970960321746046, 0.015381307457573714, 0.031917281786821065, 0.021722788899956692, 0.04854863502025124, 0.05453821301700608, 0.04690984271526818, 0.03097920137788019, 0.007132403543143864, 0.04750657924300721, 0.06588684800531595, 0.029909551113603577, 0.03769056826469399, 0.01595604385534722, 0.018481195100673267, 0.07395912412433855, 0.056448077873116544, 0.0329995361126719, 0.00934581302346722, 0.07218310248947914, 0.05411127987768381, 0.06361464654365856, 0.08636808608688655, 0.04710531004914834, 0.019887263300798593, 0.035539891330465194, 0.07973705884069204, 0.04903818435606457, 0.042569119588381825, 0.017301343088488907, 0.05146528496557186, 0.026651425136914177, 0.026422692350141948, 0.08048340467916382, 0.042554640526612925, 0.06965080651664926, 0.04452093158878627, 0.07538774020729527, 0.9713391815462421, 9.908303214657693, 46.44963718229725, 68.0872235759612, 72.79981013267272, 66.67488005853468, 63.538152786993216, 55.357535962135564, 50.15099748488396, 36.77315388956378, 40.031611919403076, 40.61346023313461, 21.83057288969717, 26.22942670699089, 28.39450836181641, 68.13948523613715, 55.10883808135987, 54.54373044352378, 64.95517961440548, 34.938112228147446, 21.349050960233136, 19.71307154624693, 12.29335334993178, 6.755128954687427, 4.107367780900771, 2.175804434284087, 0.9645171992240414, 0.2347370315222971, 0.3121471825626589, 0.06579533114188141, 0.030767086953405413, 0.06736073988459765, 0.058742495884578076, 0.0665492535899243, 0.07160695074426551, 0.12773592235340228, 0.04046779020779556, 0.0761500972833845, 0.08489401800738228, 0.2975151790005546, 0.18190284319702657, 0.05085323434022646, 0.28362520820190834, 1.8200966956153994, 0.6085374686987169, 0.2881536458528811, 0.04907034089668624, 0.10467345060239877, 0.05309154790255332, 0.07262869753063687, 0.0393239290062939, 0.04032944621998937, 0.041611877405234886, 0.020521421308418917, 0.06173070993334536, 0.10462094293606859, 0.061527233150216847, 0.11260778492977543, 0.060418853310928236, 0.08779948306900841, 0.04182610623238068, 0.23396175054292526, 0.37403948725231234, 0.19487975976399838, 0.07963863186418049, 0.07112207071435067, 0.05376012815583137, 0.048209162308804454, 0.024326057173311714, 0.4668876889251894, 0.5901763636258341, 1.828525378819435, 2.7108542140453094, 11.446933323337186, 19.982552105380645, 31.553473511049827, 53.139765108785326, 63.64397048950196, 64.79566074186756, 33.615351723086455, 33.07196224889448, 23.413484596437026, 18.26986485911954, 17.016163564497425, 16.688310292459306, 29.426556518000943, 34.015704124204575, 41.37766738091746, 61.713368123577496, 62.277703054489635, 66.87043374584567, 52.02797320581252, 34.404803245298325, 11.019015485240567, 1.1675483949722782, 0.12100529601617206, 0.031696307555501985, 0.08762120674814909, 0.05435847346821139, 0.01679282158523077, 0.08143989609614496, 0.016155112760081407, 0.019567153461638, 0.029487942285355062, 0.03602371032860491, 0.0444397913862861, 0.023886027760923873, 0.026811370888965267, 0.010980784464927932, 0.07413646581793025, 0.06281759717591828, 0.07674096557762354, 0.08346901019854892, 0.14562779857266336, 0.0226533942059764, 0.03826259462643535, 0.042184014849725275, 0.04994930038529058, 0.053934811524325804, 0.030213684189103307, 0.021821782781532215, 0.004953946345560854, 0.03267746125798553, 0.04278690306349628, 0.05645162102976634, 0.00575705498997723, 0.0640219256972834, 0.03485988104535687, 0.010494175949133934, 0.016356919471534993, 0.060254014172260804, 0.0912688501299389, 0.031413994579305576, 0.019464449799289147, 0.11012279488626989, 0.03584695852271492, 0.04338126854910966, 0.06108988887600361, 0.054993192635236256, 0.07451624624551305, 0.07892322065609117, 0.008036838806865197, 0.01894693825423958, 0.036693884044765465, 0.014755966164351953, 0.06654264225113778, 0.030604538417631583, 0.025468767327707142, 0.07139390169252312, 0.04834186405904832, 0.035644600227955854, 0.08454005474284773, 0.07513503078371286, 0.0925246827424534, 0.043336555827409036, 0.011407425533229066, 0.029848593497468583, 0.0967893333384587, 0.05977179246744322, 0.10344660675693905, 0.043877291327883164, 0.05375438632683889, 0.03839916895113645, 0.0057807630172089465, 0.05602308293624271, 0.013126531623363977, 0.019522517348729798, 0.04261826795916404, 0.03460943541159073, 0.04296466610544632, 0.06661895993015458, 0.008929786103356992, 0.04156413097535411, 0.07328826858992539, 0.07446130241958365, 0.07472633053698848, 1.5155237937165846, 14.45974801817248, 55.83679468401017, 75.59127469216624, 81.77707995137861, 75.17255383153116, 73.9322219356414, 63.688461934366536, 62.09037065505982, 45.74754861093337, 48.07369847451487, 53.145542760049146, 41.04017488418087, 34.04470220688851, 27.731062981390185, 63.204143354969645, 40.681697707022394, 39.10557170068064, 65.03586276885002, 36.92231770484678, 28.9987769434529, 25.64385018041057, 15.505543101218441, 9.197582487137087, 5.318867314246393, 2.784430278885749, 0.9968406550826566, 0.35333421441816515, 0.343020556554679, 0.015792124979798833, 0.059765636950971625, 0.07483264055824088, 0.021135927245561636, 0.1619930147764183, 0.11129715404803715, 0.17770373142294346, 0.17019622298257966, 0.1419143558990571, 0.3396813937973592, 1.0566177603698548, 1.0377100975282731, 1.1303569712946493, 1.0806313685832487, 0.9749988754910808, 2.0870966007632594, 1.2323177581833256, 0.20708767727257746, 0.2412732936922581, 0.06470586218300366, 0.6567981887248255, 0.4172567440377128, 0.0828087036948531, 0.144198784123986, 0.5381859598621246, 0.58608582183238, 0.34206135318644587, 0.08455420438680919, 0.4140683167403744, 0.5317891869814165, 0.5290143552326387, 0.7261798302492788, 1.0178399831056595, 0.8995602364020964, 0.5666779342197603, 0.5065021261332497, 0.11308347956547815, 0.12149946869260843, 0.035383754950617595, 0.12122907795973363, 0.2525981263287606, 0.40592409730438267, 1.1113537006801175, 2.4612576202038796, 7.995037724894862, 16.053296212227114, 29.22410534274194, 45.49776031124977, 51.987427665341286, 59.01120808816726, 33.127593225048436, 28.266884242334676, 25.461742378050282, 22.85915170946429, 26.94722240970981, 25.32143331343128, 38.077079173057314, 43.76757537164996, 48.87467784266318, 67.50801501735565, 69.21066099597563, 75.26760070554673, 63.99070016799435, 43.165154226364635, 16.17302950351469, 2.0974541094995316, 0.10766152292490007, 0.016946966136475245, 0.14959351399973517, 0.047906710796298525, 0.053583636819835634, 0.06375512025589425, 0.04351267178032187, 0.025423324907258637, 0.02699987448361372, 0.09038562736203594, 0.03531281903926884, 0.034381551067194635, 0.056986829205866785, 0.019921700868214813, 0.05785307163492807, 0.05505893064001876, 0.05165584933673663, 0.016907108496994745, 0.047392367024815855, 0.06394854979589581, 0.07376707354260069, 0.07913522016737731, 0.07148416217176184, 0.02880888003405304, 0.03726499493143732, 0.03923024794447326, 0.04739969082537198, 0.016726759908300255, 0.057165595822997635, 0.029983947827150265, 0.03999530165005596, 0.040143171941200574, 0.03773320871855944, 0.06726582925165854, 0.03821052746066163, 0.02447455182611462, 0.003610317423496576, 0.01534372797205804, 0.03497299392737689, 0.03651000762117967, 0.052499756472365516, 0.03483632001124563, 0.050857474636887355, 0.17740032996141142, 0.16398626830308669, 0.14103517807539434, 0.14408276776873297, 0.09804220885158547, 0.11020229949105172, 0.08765557345243231, 0.15001368258268605, 0.09760871799963136, 0.14762039326371687, 0.16476029289826272, 0.2022286113952437, 0.07153905237153654, 0.163872565533365, 0.14737199691514816, 0.22688475287249013, 0.1644694246351719, 0.11821950921007704, 0.11161565510255676, 0.29491740549283646, 0.31532932793901813, 0.27171361350244094, 0.1120112092805005, 0.15821411755056153, 0.11072107125073673, 0.1084207313796205, 0.2098668604007652, 0.14891886633009682, 0.1300089358682594, 0.12564352938845275, 0.1233846348740401, 0.17416828161766454, 0.1530501793228811, 0.13553708761690125, 0.2814573019502625, 0.18135659186349762, 0.16338804556477457, 0.18141881352470768, 2.2532006425242272, 20.194473843420706, 69.174590879871, 89.26993662311186, 92.38272174712151, 86.69272761191093, 83.23992790714388, 75.2905701052758, 67.73945054700299, 53.28015458199286, 56.009775130979484, 56.97885551760274, 36.1696776267021, 36.11130099142752, 39.710397258881606, 83.16087645869102, 71.29682064056396, 68.91561246687367, 75.4603930442564, 46.856955712841405, 30.552121823833836, 27.871548552666944, 16.542913913726807, 10.49031626793646, 5.530422800971616, 3.3973795560098465, 1.595498102326547, 0.7948696637345899, 0.603854771583311, 0.20990271331562152, 0.17919319020884653, 0.1884087529634276, 0.1656822337498588, 0.192627783023542, 0.14984191034830388, 0.302099357208898, 0.3312428740243758, 0.18726286928980582, 0.24206976466361554, 0.5948726051757413, 1.2235608216254943, 1.5295226102875126, 1.0305493204824387, 3.41951790355867, 3.0866815053647567, 2.6127812314418057, 1.1813269459432172, 0.3886470679313906, 0.18111444679239105, 1.3497533985683996, 0.7928428402350796, 0.2189123363143975, 0.14683103158829675, 0.4103485921457891, 0.3404097595522481, 0.2529608689609074, 0.24381120508957296, 0.19977028121150311, 0.374432704862087, 0.3833909080393853, 0.5562485357926739, 1.234065664391364, 1.0315190039334758, 0.5901915015232179, 0.535064917658606, 0.2479363740572045, 0.17887949252561217, 0.15267430594371212, 0.20219934683653618, 0.7356141723932759, 1.0900381928490055, 2.4376469129516236, 3.45365232998325, 14.50366581639936, 25.953538956180697, 42.2398357237539, 68.4189776451357, 81.31919814694314, 80.2812683966852, 45.818182652996434, 44.654576240047334, 36.14356640846499, 29.506033543617498, 29.02206797753611, 28.70198492080935, 44.19342317888814, 48.53952700091947, 58.275104722669056, 80.79015670284149, 79.29098759928058, 84.61753491432437, 72.34177927817069, 51.332901754686915, 19.689354935000022, 2.80127318155381, 0.4382276961640005, 0.06876304850823457, 0.23410275668626834, 0.21276228971058325, 0.22035846516730326, 0.24571062816727549, 0.15067880011854634, 0.08968772126301643, 0.08718572406759185, 0.1621584744463044, 0.16316900570546428, 0.23602317057309613, 0.085019143148055, 0.10872001894899916, 0.1453961642278779, 0.14068052533172792, 0.2665226630145504, 0.16585331650510912, 0.3137025249100501, 0.10358554446288656, 0.17964018719090571, 0.12255679260218337, 0.18905540778031274, 0.14290691473551337, 0.13021030974003578, 0.08076137968248899, 0.10976050424599841, 0.13424368605258005, 0.12430711964806243, 0.1769667088745102, 0.23653303273022178, 0.13054980926455992, 0.17715806231623699, 0.14685274252007086, 0.13444084644077287, 0.20331809567587994, 0.21676260166831557, 0.08884370687507814, 0.10797505206879109, 0.2319381292909384, 0.14274021400318992, 0.13730209290740952, 0.24484015310243254], [0.02335492198565795, 0.06114903086375806, 0.02540017564540669, 0.024013868683288177, 0.02560257415978178, 0.020968740047406287, 0.047074750801848794, 0.02837696923844276, 0.059808411470223824, 0.0424057130341328, 0.037524886429309845, 0.057545617568276586, 0.04117501576641395, 0.08640170202500398, 0.1860992889851332, 0.0324965151207101, 0.0738813508782656, 0.008313972071083564, 0.037261359844236605, 0.04273859355899115, 0.054134611085417776, 0.023009500601479126, 0.008642265644495287, 0.05685996504560594, 0.053714806394230936, 0.07233113365908785, 0.01910669439952941, 0.05266354224013706, 0.018446420454570366, 0.031127876061345303, 0.014457851667107354, 0.0028909962941637084, 0.0269459648763821, 0.014396208402280126, 0.00345391841913243, 0.012609748819452381, 0.06600971318661206, 2.212795081638521, 23.01638580137684, 48.78570672004454, 67.29446549569407, 72.91386481254332, 63.964836059078095, 60.07183659461237, 47.89649755724015, 49.3736150956923, 33.27856917535105, 47.48308366344821, 57.60480303918162, 27.877663527765584, 15.522926065229601, 29.19425218336044, 42.36266866807015, 38.48679034940658, 58.67377834935343, 80.01371568249118, 44.0351398529545, 28.7403457010946, 18.426528246172015, 8.219120771654191, 4.577646726562131, 2.186159981835273, 0.5270164592131492, 0.25975016997225825, 0.036072464164106116, 0.03646881507349111, 0.010447601633777302, 0.05760564438758358, 0.03673086693931011, 0.12599981389939785, 0.030948253340959072, 0.045111945439730926, 0.02346281397847399, 0.2293786908229513, 0.2790434814749226, 0.18921997878820668, 0.21778859258178743, 0.6432270943637818, 0.6573964727501715, 1.0496461151107666, 1.663584442388627, 0.9450873708532703, 0.21733499192182096, 0.6724934303952802, 0.16745799491482397, 0.08570849970583955, 0.035652088737415696, 0.25206687499678904, 0.019332244090976256, 0.211313464228184, 0.12167326339911069, 0.3741029499759597, 0.9615046350706009, 0.051114937636039914, 0.19105888091989104, 0.41880798015382986, 0.28311732255162736, 0.8584309369325639, 1.1929011248773145, 0.2639318762287017, 0.16032220765707955, 0.35217904575890113, 0.21033677873351883, 0.10140220153956644, 0.05113137788289497, 0.0716393945678588, 0.03163487496485393, 0.046684578391573125, 0.046738748468699, 0.014521766382630074, 0.044678852953497446, 0.42095606004999536, 1.2716172106804386, 5.8986789372659505, 12.481003461345551, 27.90552608428463, 32.669162288788826, 62.87267954118791, 76.42994803767051, 66.653103059338, 68.16547486089891, 54.984761745699, 37.56441362442509, 30.98170961103132, 19.25547411364894, 25.039681619213475, 37.94262032355032, 47.74476458949428, 59.453816183151744, 64.31944970161685, 64.32308573876658, 48.89448188966321, 13.624983314544926, 2.5647844133838533, 0.3583923252599855, 0.03693749617424704, 0.09697814336827687, 0.05605751858843912, 0.061756783735848246, 0.028596692831225456, 0.04118884365344721, 0.028400991840528387, 0.025593045941223542, 0.007398068471135753, 0.07044521671149039, 0.05282520594435835, 0.026972965645273368, 0.05922695456613457, 0.017875259772183436, 0.016166665365979556, 0.028684530557403644, 0.03484025387273681, 0.0349183373844191, 0.03766508051945317, 0.01379932631783548, 0.031217311080845616, 0.03439689963875759, 0.004729533815876611, 0.0208677658285465, 0.03192771973478938, 0.031107511529098117, 0.0517873176854224, 0.06301823560328734, 0.005904412959822484, 0.07157856718667092, 0.02977303807593642, 0.01676605638837622, 0.0755394792424575, 0.05140937203841825, 0.03466819052494342, 0.02476733722423594, 0.02594281678959247, 0.0014549699863569152, 0.03394742053182375, 0.052670199544199055, 0.0319073015763875, 0.029532143643366236, 0.0856420569001667, 0.061158541845338005, 0.032518084326218215, 0.014820291694524068, 0.034849446927828175, 0.04182496093093388, 0.02659177561590989, 0.01580694495069404, 0.045468547877164624, 0.014513096182547031, 0.043773635801288395, 0.01132303711792995, 0.05861599178564164, 0.015468397290415823, 0.04264363696077659, 0.031979836696278185, 0.06095033063883744, 0.04192649056353877, 0.046326968548519, 0.015509871375416557, 0.005548393228016193, 0.1369769498705864, 0.10172381291105863, 0.07998862679326728, 0.02288163669647709, 0.04902829799140173, 0.03305182161350404, 0.023233309358118043, 0.10895171458081854, 0.023552609059298714, 0.03077171603968788, 0.09191982568271699, 0.023592254109380227, 0.01680481469168538, 0.11281421498185205, 0.06908498929753419, 2.043530099814938, 28.825737660931004, 57.70686703343546, 79.19412074550506, 81.56873149256553, 74.74288955811532, 68.40746156630978, 61.841253080675685, 60.63160588664394, 47.97372902593305, 51.699929698821045, 65.01730211319463, 43.36305349103866, 17.02517717115341, 26.69456881861533, 29.35369064730983, 39.66662360775856, 49.64427040469263, 68.28702911253899, 44.06265135734312, 25.04702037380588, 11.600985392447441, 6.40163024587016, 2.154680019424808, 1.1123879806649302, 0.31309428174168835, 0.048472148801891074, 0.028941225553412112, 0.10215476035110413, 0.061564729323670755, 0.1982849286568742, 0.08188302433418651, 0.624442128164153, 0.33643492767887734, 0.6610121626046397, 0.6656135931130379, 0.5298140897385536, 0.8919473449068686, 1.056952755297384, 1.191723065510873, 3.13377887491257, 2.327339322336259, 2.549114299397315, 3.516144757309268, 1.7732305007596172, 1.7716787130601945, 0.9149431593475804, 0.3889594785869122, 0.2690506305906081, 0.7001055068066043, 1.272742318049554, 0.15854895926050602, 0.8186766120695299, 1.8060155092708527, 3.8710572354255186, 2.466537130455817, 1.467799948107812, 1.4646988241903245, 2.2853736387145136, 2.6513163120515886, 2.1511334613446267, 2.6943819753585325, 1.6089376134257165, 0.8829986412198314, 1.41541154634568, 0.9704440844155128, 0.6963065687206484, 0.4794254226069297, 0.37419120330483685, 0.42203066690314206, 0.29050663894703316, 0.04973591808530112, 0.014789890452858903, 0.05277259102571876, 0.13337046839296818, 0.7445945001898274, 4.232269285186645, 11.550275029674655, 26.03774439903998, 29.29145439978569, 51.258882707165135, 66.80967623187651, 61.93822976081603, 62.66229929462556, 54.047840872118556, 45.361403034579375, 37.6053592466539, 32.54616264374026, 32.321102926808024, 46.93689753932338, 54.9171361615581, 66.671632336032, 72.53079045203425, 74.77896751896029, 57.52250779059626, 18.20304532204905, 3.9524015543922304, 0.6597389857615195, 0.07249791100020371, 0.024761725630190586, 0.06150741828605533, 0.008573494889142533, 0.024868824722004995, 0.1073354759043263, 0.026602985397461924, 0.0389997205967384, 0.0034358684300264766, 0.02616390401888038, 0.031238357431345412, 0.06596748642022572, 0.07171107741493372, 0.02583769228940289, 0.06493285403496797, 0.09151414382241427, 0.08141997781011366, 0.03772521842150919, 0.034809748251591964, 0.05962410220696081, 0.03476682051475491, 0.06988712931953131, 0.05001084022824803, 0.01077148637118479, 0.085821942005667, 0.026985931683391817, 0.00839405794507794, 0.08654293799472433, 0.056300399103953, 0.0769288256584156, 0.040223810356110334, 0.04023792169567558, 0.05944705928765959, 0.08335083347534941, 0.0528881247455795, 0.047162234212362, 0.037457815431539095, 0.07812092741650921, 0.07928708177660743, 0.05466269081338279, 0.05312795240071513, 0.15359969419096747, 0.1906403824086151, 0.16483521629725734, 0.10583795021258055, 0.1311556469168394, 0.17328358796094695, 0.20527094572542176, 0.16665534927479683, 0.1851486811234105, 0.14137864593536625, 0.14019052017359965, 0.13438614776297925, 0.125082423610072, 0.18728807358251465, 0.4116247107665385, 0.131256157652505, 0.11446943221193169, 0.13163154073540242, 0.1804400136273715, 0.12651917554678457, 0.1012787388096894, 0.0868465616217544, 0.32095140206717676, 0.13443408954528072, 0.14318523447840445, 0.14289960625671572, 0.2377343198825275, 0.18107214341721228, 0.11903745362595206, 0.2056032133799407, 0.10786275890085006, 0.14837554145243861, 0.13504673005832782, 0.2051409252829129, 0.07387053371677477, 0.1875371747319737, 0.1517961699996264, 3.3712497065144205, 41.966003294914, 74.12290403919836, 91.21807590607675, 92.41635214897894, 84.49958139850249, 79.57681071373725, 65.60799537166473, 65.16728570384365, 48.88930436103575, 60.13659492615731, 69.2858842111403, 40.63758673206453, 23.574009556924146, 40.78090229342061, 60.812125129084436, 50.69605004402899, 74.87872123718262, 90.24881901279574, 50.48370076764015, 37.53749832030266, 24.62669134140015, 10.709967036401073, 6.361283275388903, 3.1217499461866196, 1.2129392883469983, 0.4682747677208916, 0.27195349095329163, 0.19718763027941028, 0.39618111365745146, 0.27899334868115766, 0.22817769478405678, 0.4178557941509832, 0.35128391798465486, 0.26898100852004947, 0.46518207077057133, 0.38425946788441756, 0.5412511082906877, 1.036113202571869, 0.6899796017716009, 1.6987625870012468, 1.3826204091310503, 2.7063547651613913, 4.93007266713727, 4.4033669944732425, 2.9931935283445545, 2.6253436025111907, 0.847123540457218, 0.5666762181828099, 0.708132759938317, 1.230701006227924, 0.12034674385382284, 0.6096155689127984, 1.2279927321980078, 3.193989708538979, 3.0790497987501086, 0.7884290093375791, 1.477044606881757, 1.3556857383058918, 2.183509195043195, 2.4584896526029034, 3.071386713174082, 1.1922142198008876, 1.036286644877926, 1.0001475195730887, 0.6200977967631432, 0.5695890070449922, 0.3884630842554954, 0.5033159664561672, 0.4248343342013898, 0.3756756059104397, 0.1299166222733836, 0.19099848254794077, 0.29506602655014685, 0.756217279741841, 1.6357955528843788, 7.31021591732579, 17.337709665298462, 36.82509783775576, 44.33479324463875, 75.58885066739975, 87.33120318382018, 77.21340225588891, 79.04745548002182, 64.47773302755049, 50.6284519164793, 46.11235257117979, 31.898612668437345, 38.81665383615802, 54.14384480445616, 63.195321944452104, 78.20637379923176, 83.81842259437808, 85.06099024126607, 69.26147922392815, 25.80922515161576, 6.151777227078715, 1.1697767915264254, 0.17372405787389125, 0.1721238380958957, 0.3025908485775994, 0.11351982026451057, 0.11477458801481033, 0.13803830340264306, 0.1887939572935143, 0.11666813519813361, 0.09115494817735688, 0.11338366345772821, 0.13621296102721847, 0.20761166609102683, 0.287529866421415, 0.11296996065685827, 0.1143837069732047, 0.22687865481261285, 0.20094863169135588, 0.10654010043870057, 0.12532646091835153, 0.20276723249304682, 0.1044245562966793, 0.1523437236826266, 0.1327716787495921, 0.10738814444912058, 0.22301510487112308, 0.11514195015714054, 0.14228128137127047, 0.23637471299978996, 0.1145608724665738, 0.2232429240980456, 0.15091029656750543, 0.1539495359024694, 0.15982449565443302, 0.14349937649263492, 0.09119067085726608, 0.09564740267852623, 0.18526569339296511, 0.12537601914617325, 0.2010478553993087, 0.11039286386221649, 0.22879197472526183], [0.02756984389927839, 0.010173357478643378, 0.029422863116187435, 0.014718902830575264, 0.02642281875464945, 0.008722176275876983, 0.08009379534351249, 0.04147878495014964, 0.024563320349120808, 0.08025217636097824, 0.024904409506087823, 0.07464292654467207, 0.03864420983459681, 0.06916483864188194, 0.06548625296883046, 0.04314531346843128, 0.04206976815757733, 0.010493105341259752, 0.056652826362199364, 0.03947944102448322, 0.039636734197096485, 0.08618882151260492, 0.046351648070999694, 0.013070752761597115, 0.02554289399526052, 0.05757685863382875, 0.07504357520731227, 0.029793258966697805, 0.11744893201056028, 0.033663466212249575, 0.04289377998981265, 0.021249635760942777, 0.020359740367219336, 0.04059086989371046, 0.06114112866681911, 0.32988692904191635, 5.144136019291417, 21.819968761936313, 58.42555115299841, 69.81606314259191, 71.17678826855075, 64.7160562392204, 49.11762945113644, 51.40879177278089, 27.537260632361136, 28.519200509594334, 22.353717050244732, 44.705935755083644, 60.489667077218336, 28.662563139392486, 48.507712656451815, 74.98850837830575, 71.74983870598578, 53.43013032790154, 30.966802643191432, 18.536695857201856, 11.803461082520025, 4.8387814625617, 2.780245109911888, 0.5756075163522075, 0.0846102437184703, 0.050619891619369875, 0.05445126203760024, 0.02868375872381993, 0.09935942808947257, 0.07978230399350006, 0.07765477823634302, 0.09337284932694129, 0.09804279107840792, 0.3140311459860494, 0.31123360739119593, 1.017169931963567, 0.8123862947667799, 0.8410121812935799, 1.5724496423236787, 0.6239689309750834, 1.4634071386629537, 5.686355646579496, 2.4764065492537717, 1.13874189555645, 1.6180869095748471, 0.44129799270341474, 2.038057412832014, 1.327982773223231, 0.20749823911295784, 0.2631235615380349, 0.5543452056665574, 0.3163777958721884, 0.4481680853472602, 1.7568707850671585, 1.2653507340338923, 2.348456627899601, 2.9604155065551883, 0.6172119129088618, 0.30572108383620944, 3.2445360672089363, 2.9419475168951097, 1.6330652155222434, 1.6270096888465266, 1.3519346041064109, 1.439184541663816, 1.4193671340903928, 2.2391595378998788, 0.534074703051198, 0.3843468631948195, 0.05061248354914208, 0.1982358377426863, 0.21751025751713784, 0.2702004979214361, 0.09835092696331202, 0.09172362290442952, 0.04840670574095942, 0.07104052831569026, 0.07869710214436054, 2.456057537947932, 4.881467146258201, 18.82614520288283, 30.378447117344027, 43.23505870757565, 44.76354752817462, 69.22085915842365, 83.31442940619685, 37.02575452866093, 20.029897074545584, 15.848495537234893, 25.18427783443082, 28.640644934869584, 41.502183022037634, 43.973876353233095, 49.060888444223714, 58.545669817155414, 60.27668629923175, 42.47915913981777, 28.836859541554606, 8.919685502206127, 2.5358780161026986, 0.4238240787338826, 0.052519586658285516, 0.04741474062264447, 0.042399565178540446, 0.005032631236263701, 0.0657494577969755, 0.062277355802155314, 0.050687414609015956, 0.025038059290137984, 0.09066566314187743, 0.03462038280802869, 0.0572516389882132, 0.07416913180702156, 0.07091116670879626, 0.021620209726895538, 0.07744896871548507, 0.015319525339310209, 0.03406886078958069, 0.023576315650115573, 0.058065672525234764, 0.02482641600973664, 0.06768039007100367, 0.07666968875714848, 0.07019420800309989, 0.04918137001955221, 0.08858633197603688, 0.06592101552673886, 0.05964249214758316, 0.013718601718034237, 0.031488261057905136, 0.012264925941464402, 0.0665770625815757, 0.07186964229350129, 0.016763899850869374, 0.027933793119905938, 0.04387233856945269, 0.034434522216719006, 0.01619587438331256, 0.03430326837265203, 0.061605040870246396, 0.024188866147831566, 0.09546714218994302, 0.017581959179933035, 0.019886956865628882, 0.060089837699647874, 0.05753136450244535, 0.04171403522993769, 0.06954106442149609, 0.05482170768382569, 0.0997237871671396, 0.009843657176280695, 0.059616751593327334, 0.028003380716507955, 0.01023776632087726, 0.033190223057904554, 0.0476500598503457, 0.028357949190502687, 0.08458689335853824, 0.03410916467527709, 0.042748357349586104, 0.06928268594727402, 0.024113553959215363, 0.05623416697245933, 0.05602346981064447, 0.020864337585085345, 0.08582777959565002, 0.03295030730265764, 0.0796991451493194, 0.12829787082849972, 0.013153245109283637, 0.07404766090574764, 0.015624604533396423, 0.011840249888689048, 0.07556381019493265, 0.03547028075122545, 0.5173343335909228, 8.110165173007596, 30.746522334314164, 68.04464232537055, 80.20299357752647, 80.72476294732864, 74.05637279633554, 58.74083518981934, 63.88235645909464, 37.22599937069801, 43.50613371018441, 32.65078402334644, 52.000528381716826, 61.81801695977489, 33.31383912794052, 32.77513492491938, 50.640085666410386, 61.83334950477847, 43.67585466754052, 34.184695520708644, 23.86832852517405, 10.31818893647963, 3.314098321622418, 1.8420934701158156, 0.19648155768311795, 0.057252393584818616, 0.04483976972199256, 0.20262379019010454, 0.22432566680494817, 0.2548951643609232, 0.2798327358980333, 0.5135106661867711, 0.4343841411173344, 1.1905097048128805, 1.1222705148881482, 1.3681988345999874, 2.3587251478625886, 2.8442385792732243, 3.170675385382868, 3.8160531030547236, 5.0824802825527815, 5.686265432065533, 7.47861699711892, 6.594713820565132, 7.084063330004293, 4.9915617031435815, 2.092797765808721, 1.4489219481906583, 0.875144646533074, 0.09406924623274997, 0.1687030563311231, 0.3370201269224767, 0.9385626919327245, 2.303962241257391, 5.811820991577641, 4.730503453362373, 6.171083133066855, 6.969932654211599, 5.038135926569662, 4.7573324653410145, 6.802567570440232, 6.297362369875755, 4.212779518096678, 2.9638350779010407, 3.5520334637934163, 3.868823200464249, 3.3370711534254016, 3.0737494509066305, 1.2264371447024809, 1.7044557847322959, 1.1307907609208938, 0.9740792022597407, 1.008433955571344, 1.1482471467987185, 0.5498048170439659, 0.323570380888639, 0.09022166156360219, 0.029086673091496193, 0.2430696779441449, 1.3249672060051274, 4.721578590331539, 14.972865619967061, 29.968947748984064, 47.73171486393098, 54.34373271080756, 66.5660656652143, 82.862321330655, 45.232615932341545, 29.445423118529785, 20.509495081440097, 28.64236685537523, 36.12666883776265, 48.73740273137247, 52.76560237330776, 57.16922383154593, 67.80544834752237, 68.82197764612013, 52.490126471365656, 36.23070186184299, 13.04338211013425, 2.9941572056662653, 0.7977997355403439, 0.029325975976403684, 0.10691041968041852, 0.05173349234786245, 0.06254365562551445, 0.061480206842984886, 0.04256734226439749, 0.036402027528252334, 0.04536541329035836, 0.03574346004414462, 0.03077022025301572, 0.04758817909826194, 0.03244107333762992, 0.03149610962868939, 0.04773320337276786, 0.08819813224216623, 0.021698423473524953, 0.03910773516362233, 0.09210105144208477, 0.0035059975550299693, 0.03906391110391386, 0.08852926608655723, 0.05535523046649272, 0.10354734731898194, 0.022581849254727848, 0.03283699906821693, 0.05149858297720071, 0.07162997934726939, 0.04152879133940705, 0.03543969469084855, 0.02114573891665186, 0.0341408270891876, 0.024344443283494444, 0.031188163350546555, 0.020870537151612585, 0.027999176809023467, 0.012314241893980052, 0.007427246366146833, 0.010387308598916617, 0.007935475798383837, 0.1486197856044577, 0.22599610620208327, 0.10147631288536134, 0.05951832078637616, 0.12185150907645304, 0.17091852132110827, 0.23226224576994298, 0.1787192422536112, 0.12463189496268189, 0.33283888031878783, 0.08784804538252854, 0.1998228808083842, 0.1570925801511734, 0.09406104143108092, 0.2401968941933686, 0.09771901167809002, 0.10423445923914833, 0.14589634303364063, 0.1309892372979272, 0.1582606497310823, 0.1509181872731255, 0.1260332153328965, 0.22449630522920241, 0.12128201463530142, 0.11676258617831815, 0.1967020990747598, 0.21144141623329735, 0.1280565761149891, 0.1858060611712356, 0.10751503925289839, 0.14057926382989655, 0.10415587393987565, 0.06786069652486233, 0.1775826588873902, 0.15405850424881906, 0.6929835857402894, 12.589229499140094, 46.343007549162834, 82.85530028804656, 93.29614762336978, 90.10166737341112, 86.21807375261861, 66.44241686790221, 68.66432189941406, 41.60618074478642, 42.60136058253627, 32.83022265280447, 56.8806040671564, 69.38006031897761, 36.85621792270292, 68.1365591479886, 89.90262277664678, 82.991226103998, 64.00607193669966, 38.79429240380564, 23.818690930643392, 15.54910788612981, 6.274647924207873, 3.817982418883232, 1.0944917990315346, 0.167808786575352, 0.12410306446855107, 0.237838109474509, 0.17717275588262468, 0.34806889211458547, 0.28024574921977136, 0.4671546246015257, 0.29873086860583675, 0.9378906183185117, 1.1818987539699002, 0.6401013330586496, 2.0622836870531884, 2.2085993712948215, 3.299067063677696, 6.654090169937381, 3.8999570137070076, 7.112988848840037, 13.241708913157064, 9.656771421432495, 7.553637229627179, 9.133463501930237, 3.794973795452426, 6.489567333652127, 4.130261675004037, 0.9237515770139234, 0.5359993610651262, 1.3150471641171364, 2.0050029865195675, 2.90786408128277, 5.459387206262158, 5.930528092768885, 7.659588783018052, 9.197417747589851, 6.515349072794761, 5.192601805733097, 9.613406677399913, 7.190284546344512, 5.327707846318522, 4.964892527749462, 5.112958569680491, 4.527933626405654, 4.8354763753952525, 5.986001683819679, 1.5118199731073074, 1.0794468127912091, 0.7425236725999463, 0.5142456509413258, 1.0670051771786906, 1.3011540063927252, 0.5060074171952663, 0.45316634940043576, 0.21384124794313986, 0.21019966431683113, 0.5175883070595804, 3.1807740176877672, 6.4064322075536175, 24.115018152421523, 36.55684301930089, 50.670123177189986, 55.79491946005053, 77.42237829392957, 89.40437193839782, 48.69403308437717, 31.97183155244397, 23.396496811220725, 37.96495037694132, 42.78910090846401, 57.12918035445675, 62.707112373844275, 67.97389061220231, 77.37888705345893, 77.54273230029692, 61.755302183089725, 42.466148637956195, 15.919725779564152, 3.85268313750144, 1.105156478381926, 0.18835494294762614, 0.18351178105560043, 0.131663394671294, 0.13678833902362855, 0.15144933135278765, 0.1320199932782881, 0.12652855246297776, 0.10067188226047064, 0.18553978433051418, 0.07628901966757352, 0.19854018915324442, 0.23975947331036293, 0.1842916125972425, 0.18411361972891516, 0.28044909959839237, 0.07468648630404666, 0.1274030571503024, 0.1320184917459565, 0.1910177113548402, 0.133704436762679, 0.2445306995462987, 0.11822645762755025, 0.21441449621512046, 0.24169124062022856, 0.22809901755423317, 0.10753370881561311, 0.27030499231430793, 0.14409792098787524, 0.14010557634455545, 0.11972802060265696, 0.2951880183912093, 0.11946371260790095, 0.1003142724174165, 0.10049767386648925, 0.13651830835207818, 0.15908191130766947, 0.10625008253320571, 0.12471172898527115, 0.14861946384752953], [0.09724661888134095, 0.04431023825741103, 0.014316221162106001, 0.028997148056664777, 0.006500818154534266, 0.01644311585433541, 0.011659634126830968, 0.019736485705981334, 0.03078849145000981, 0.042826877531385234, 0.06284994140808141, 0.06052539698899754, 0.04079541153905373, 0.0029877936580188333, 0.034175595989631075, 0.0436959085204909, 0.04340884771438376, 0.011038271702765938, 0.04672693922334621, 0.08024235511378897, 0.0643638345683294, 0.022111201223226327, 0.07144932049296557, 0.03251803836094276, 0.03159628903132773, 0.0935090674207576, 0.027549617262857578, 0.05060584539727819, 0.04388284163489457, 0.028654404149781314, 0.05493044237335844, 0.02720898967386494, 0.013586534863157619, 0.10141324086655533, 0.21498602845015066, 6.159740128824788, 13.832787544496599, 49.24812670676939, 64.05513294281499, 67.7381169411444, 64.74508570086572, 55.545264520952784, 38.814163131098596, 33.108930587768555, 29.714593810419885, 18.357773019421487, 24.87001753622486, 24.234546499867594, 53.37605261033582, 47.66818031187981, 59.66833845261605, 74.15384369511759, 47.35384548864057, 26.033278780598796, 9.489659820833515, 5.3486513418536035, 1.675040827643487, 1.0949383363608391, 0.09550237457358068, 0.1461160417285658, 0.06714150084242707, 0.14965760491548047, 0.07324612609321073, 0.12792637947225763, 0.14759122063556027, 0.4481589229356858, 0.03348627773624274, 0.47145495191216474, 0.899418969788859, 2.1852973055454994, 1.8865401754456184, 3.3282664129810953, 3.0988555617870825, 3.5351819809406035, 3.2194993332509076, 3.0276449313086853, 4.206271325388263, 7.177321112925007, 5.471315624252443, 2.7853199214704576, 2.6467876905395142, 0.9437720898178317, 1.432794265208706, 0.8027636788545117, 0.19911956612861928, 0.4319899018493391, 0.3962415426729187, 1.316085611620257, 3.43191774141404, 4.393804746289407, 4.922567702108815, 6.450715766799066, 3.297618973639704, 5.356656409079029, 3.7705457643155134, 6.914183516656199, 5.135330788550839, 3.726033236711256, 2.556999734332485, 3.7889615374226726, 0.8585054619658379, 4.28221135370193, 2.8758960289339868, 1.6245438663228866, 1.3577317446470263, 1.8907156610681166, 1.0450445620283004, 0.9597145020961763, 0.6694023575513595, 0.17019217803833947, 0.23073264397680762, 0.06408074209767003, 0.014208497708633304, 0.07139266829096502, 0.06148220633246726, 0.09081312740642218, 0.9983040055921002, 4.3483130970308865, 16.16912478400815, 27.970900227946622, 55.10279370892433, 51.64642464730048, 30.53169215879133, 25.616827011108402, 29.364989034591186, 20.986751433341734, 22.205310252404985, 30.30306700737246, 25.95497650484885, 33.03787292972688, 53.03592428084343, 66.20670595476705, 70.50100311156243, 60.22359309657928, 37.79848498682822, 8.471461553727428, 1.6492690170003523, 0.2815083540495365, 0.05423554699988135, 0.08102273057785728, 0.007602034592925902, 0.021429471070727995, 0.05459431746614076, 0.04706807817602831, 0.039197122302627375, 0.07402617980035082, 0.10296161947471481, 0.02075943716561362, 0.02099074209259162, 0.013555394346645523, 0.022299344756550366, 0.035488540456900676, 0.07125770658134453, 0.04410320299587423, 0.03526678481589883, 0.044953231174018116, 0.039261902697504535, 0.05929424389896374, 0.04391082682676854, 0.06085866821869727, 0.16643866896629336, 0.07783336099237204, 0.013482147722595162, 0.06544368912375743, 0.05100255636798759, 0.02425599268697683, 0.042287398415106925, 0.056526781916017496, 0.058819480060089024, 0.053912200439240665, 0.056301674640346924, 0.015337115675661595, 0.020965844235052506, 0.03538628687120734, 0.10039409111824729, 0.03351197998610235, 0.03542471384148925, 0.02363762566669574, 0.03811592709333186, 0.034045690460310835, 0.034487037543928435, 0.01876215784690313, 0.03445424515032961, 0.010251487913211028, 0.06433681464724003, 0.012647126249278025, 0.033076960788739306, 0.05070313856366181, 0.05273156318693392, 0.08282214087704498, 0.004470210659482907, 0.05922825691560584, 0.025920404887367642, 0.0315541178063159, 0.016313740840902733, 0.015695550978454133, 0.04363614600151778, 0.028963166311563506, 0.023847541418827833, 0.02512479001926559, 0.03279098016660541, 0.09823314094495389, 0.05400289375815661, 0.03191248799163488, 0.030379555631248705, 0.026120669846873612, 0.06177038562694385, 0.02177620055003753, 0.04205541933075555, 0.13432718963632662, 0.2713758300148672, 9.152312451793302, 27.169975772980724, 63.43528862922423, 74.44700948653683, 78.05967715478714, 74.1338788309405, 65.77541389772969, 49.0750442781756, 48.07334546119937, 40.93607125743743, 26.667404443986957, 29.57680682982168, 33.60473778940017, 53.65777684796242, 32.18878961378528, 61.92542714457359, 79.62244356832197, 54.828325856116514, 29.6592217106973, 10.549695068790067, 3.9780089932103313, 1.5150099632240113, 0.48526353352973545, 0.06187983277824618, 0.11838661596900034, 0.2506628043709263, 0.3324304022375615, 0.4588456043312627, 0.7854109906381177, 0.9501516410420019, 1.45258090669109, 1.5171982780579598, 4.317035136684295, 3.321897219265661, 4.408026770237954, 5.819633862664623, 7.629721895340951, 6.286304718063724, 8.106004028551041, 8.748266158565398, 7.169198374594412, 8.648622266707882, 11.051556448782645, 9.585864774642452, 8.385490063698061, 6.1139243937307794, 1.4062939968801316, 0.49487582257678436, 0.3951932586008503, 0.21628306127123295, 0.26871293903358523, 0.48282075493085774, 1.83210184497218, 3.952410624873254, 5.882212336986296, 6.629617031543486, 8.257676689855515, 7.172736352489841, 6.74868401019804, 7.119481842364035, 8.436536769713125, 9.206473519725185, 5.865747207595456, 7.70095213767021, 6.806472289946772, 5.814573514846064, 7.2538593026899525, 7.1357577173940605, 4.116042102536848, 4.989725053310394, 2.8263638481017086, 4.217217679946653, 2.2182263385864998, 1.3396282902648373, 0.94093952568308, 1.1780070273145553, 0.45800431721633483, 0.4781888647665901, 0.08829200099552832, 0.02155889396465594, 0.11953071465775852, 1.0165221280147954, 4.706226433477094, 15.477620728554266, 24.30267022502038, 49.893909654309674, 51.232728342856134, 27.525167965119888, 27.05317347280441, 22.5368760478112, 31.015732249905987, 33.37920934923234, 36.35806122133809, 38.71548806467364, 43.12013326152679, 60.05220513189993, 73.24262219090616, 80.3319218850905, 70.47586071875789, 48.41992216725504, 16.98222525658146, 2.5896037009454544, 0.8076524229780321, 0.051399696347934586, 0.008947519123584272, 0.031443199766198957, 0.010954015437633762, 0.031047256798633648, 0.05745043497412436, 0.06636363048587116, 0.09601342416698895, 0.02379309363482941, 0.031948183858466726, 0.04431698366158432, 0.03183294891289646, 0.056491733393481666, 0.02480691524162408, 0.020229354117726608, 0.035494879834474094, 0.04747033945374912, 0.02665766300783763, 0.027102882665912473, 0.04087370189447557, 0.054569454082558234, 0.05429419869136426, 0.08046100426825785, 0.03163430422935034, 0.015245203319336138, 0.07343570221095316, 0.04976667651546098, 0.03745102023165073, 0.06684094922797335, 0.13404896182398643, 0.04433493310165021, 0.022425544335536902, 0.006268756236926082, 0.06654127861463255, 0.026356799212554773, 0.03209852095272753, 0.044608392016661745, 0.05783997536186249, 0.12957438015409056, 0.1921208779658041, 0.07457185656793656, 0.07876202043506407, 0.1653753848926675, 0.15574670156403897, 0.0915850069554102, 0.10223300091081089, 0.2070545056654561, 0.13326798115045796, 0.12719620574986742, 0.22644926253105366, 0.1785935885122707, 0.15581177307232735, 0.08196197735566287, 0.1528909096434232, 0.10335072319233611, 0.09990433110825478, 0.0895599301363672, 0.15152790133030186, 0.13717694478409906, 0.10469680096233085, 0.14952360081576532, 0.11386864307907321, 0.1175868891239647, 0.23490555554388032, 0.22702555983297287, 0.14438014777918018, 0.21872386336326602, 0.15984393896595125, 0.13918472333781182, 0.18795207263000552, 0.23669221047912878, 0.2921055563755574, 0.35519712574539647, 14.071752063689695, 48.10868209408176, 75.97273303616431, 88.08589073919481, 89.00337234620126, 84.55248632738667, 74.61233738929995, 57.472105333882, 48.078075839627175, 42.198674371165616, 28.27004175032339, 35.506102808060184, 35.962129331404164, 66.34614621439289, 65.36644797171316, 75.10024101503434, 80.87735099177208, 55.78332885619133, 29.361696204831524, 12.76885542177385, 7.290153484190665, 2.497377011083788, 1.4556038283532666, 0.34038297711841525, 0.20788508287120253, 0.33586707266588367, 0.42372427279910735, 0.48547816072260186, 0.29091444287088614, 0.45234645146035385, 1.6087816992113668, 1.2778524309396744, 4.812690836767997, 2.922779139011137, 6.468502244641704, 7.171998946897446, 10.694099087868969, 7.720189402180334, 7.607891453850654, 10.94899529410947, 10.985852826026179, 14.776280349300755, 18.521075017990608, 18.048215643052135, 15.500174357045083, 11.624296038381516, 5.524319102687221, 6.1247467033324705, 3.2605131066614583, 1.7681766493666558, 0.7893006335343085, 1.6444725711499493, 4.966440883374983, 10.431326762322458, 16.220192082466617, 12.845314183542806, 16.794220170667096, 14.231895573677557, 17.142359941236435, 14.435778414049457, 17.370055490924468, 13.222507930571034, 7.8538647582454075, 8.003828737043566, 8.587962811993016, 6.471380774051913, 12.933161547107082, 8.475136814578887, 6.0447793814443775, 5.684778853770226, 5.4509781349089845, 4.785373489702902, 2.856505301690871, 1.6313506494606695, 0.6641609678345343, 1.2713067305664862, 0.3967063128948212, 0.44362178252589324, 0.21719744849589565, 0.1255897576770475, 0.22809808292696554, 1.6862991332046449, 6.9071850276762445, 23.011149437196796, 38.139099690221975, 67.69028755926317, 59.01407141839305, 43.61475590736636, 36.73282015708185, 41.76489553143902, 33.95247551702684, 35.16500173076507, 43.54831095664732, 41.51533080685524, 50.367614300020286, 70.88892552160448, 83.80093666814989, 89.81241610742386, 78.34908531558129, 57.28244696894, 22.918403033287298, 5.239016682870927, 1.1326841625475115, 0.20051709436360868, 0.19224339074665503, 0.12238026296179141, 0.12641190025474758, 0.19101933546123967, 0.1828339004949216, 0.09902693826945559, 0.18957530568924644, 0.24983408109795666, 0.2190414680949142, 0.10091110087570646, 0.18312677590837403, 0.11735730789481633, 0.09246492022348028, 0.11521652115569, 0.10007398127908669, 0.13604825212349816, 0.1349330272886061, 0.1074738926704853, 0.13732110720969018, 0.19247133254764542, 0.18619861994539538, 0.34680656307647306, 0.1916071394037816, 0.08977384486746404, 0.15232507710254964, 0.11264388299276752, 0.08898652098592251, 0.17767045256351272, 0.2011099391646924, 0.1504374977441565, 0.10031601143700462, 0.12429863905474065, 0.1201100456678579, 0.12519242617511941, 0.1880938142177559, 0.22437042166148463, 0.10126377711252821], [0.04877584137683434, 0.011593251650582158, 0.019607537786566445, 0.1021534120363574, 0.015483259396146865, 0.10480562375197489, 0.03721651305714923, 0.05513590332421084, 0.06478994033269345, 0.023141846120838198, 0.08209841761497721, 0.023718924832440192, 0.02385021698090338, 0.029618613902599584, 0.0090545674620737, 0.04817629713685282, 0.021249310173574957, 0.09867616959156529, 0.035708445995565385, 0.02840633338858043, 0.06638491240840766, 0.05588006964253803, 0.05753655474813235, 0.034945115987812324, 0.046345668754750685, 0.018432602143636154, 0.05381116110290732, 0.041021104871986375, 0.0354751032747088, 0.016813431265613726, 0.05948261725866507, 0.052013585584298264, 0.03358922080106793, 0.10860736571973371, 2.681920115024813, 34.739969776522734, 41.70154533078594, 65.08859511344664, 70.57566935016264, 57.32409861779983, 59.33185008264358, 44.45371558589321, 35.617596180208274, 20.180365077910885, 23.130726814270023, 36.269003806575654, 32.58182091097678, 37.55606289832823, 47.52710442389212, 74.93976900654455, 53.33233387239518, 21.552110102868852, 12.235745499210974, 4.6330379478393064, 2.882730268662976, 0.680120234047213, 0.13087639254668068, 0.047193436973517945, 0.01942911399378171, 0.002149455742196991, 0.13763589273777702, 0.19052409026170933, 0.3296146307501101, 1.3340504347316682, 0.6904158428792031, 1.5668900503266243, 2.0478780471509506, 2.98655025901333, 2.0557877517515615, 1.5084053047241703, 5.019570367951547, 4.168974978308524, 4.854065958530673, 8.341429098959892, 4.165794426395047, 9.111226604830835, 7.5819302662726376, 6.760129486360858, 7.396264383869787, 7.262274257598385, 4.098845941405143, 1.3684860256410416, 0.05698059708060277, 0.42058934908240075, 0.17984399722228128, 0.28146726109327813, 0.7091365189802262, 1.4328586165943455, 4.517685453737936, 8.437749762688915, 4.658181811532667, 7.375377272405933, 5.792700417580144, 4.9532097481912185, 4.588149853291051, 6.126091095709032, 7.03709049570945, 3.720601489467006, 3.2613083672138954, 3.6460308586397483, 5.613326997526231, 3.3710450078210528, 2.6332319792239898, 0.6173256003568249, 6.561108423817543, 3.1627470495239383, 4.897500324633814, 1.7041673679505627, 1.3549281079922955, 1.4401840106133492, 0.6162288688844251, 0.2569728254550888, 0.038514564775170824, 0.20219118033926334, 0.1319361985811303, 0.08870317570624814, 0.06930644233380595, 0.3567848889337432, 3.1668373461692565, 14.067912063290997, 22.72631868239372, 43.14105910639609, 50.49037664167343, 39.746808621191214, 34.92436432069348, 23.894877087685373, 18.977974268697924, 57.785510555390395, 25.717839810156054, 30.037750044176658, 44.56916662954515, 46.69569138557681, 55.6268145192054, 66.64884336533086, 62.152905002717056, 53.38293636998823, 28.06650603971174, 13.75957944700795, 2.01371175146872, 0.44194070982836914, 0.07644689506700925, 0.05996470872853553, 0.07650244410239881, 0.03389682042442503, 0.046687910874043746, 0.06620281330880619, 0.011902551989131158, 0.03828131781530477, 0.012314513855193172, 0.016162934517788313, 0.0408478809009877, 0.010547436296849722, 0.014301636763247512, 0.04661820453381346, 0.07019865131306072, 0.037279604228153344, 0.0183451819353767, 0.06398448698042382, 0.012759748835026497, 0.018092708083831014, 0.10821401021413266, 0.047080251313145124, 0.049525071536341024, 0.02466654303603836, 0.11371842089800105, 0.03980230878017122, 0.0364312116477278, 0.0263057432828411, 0.03417021805240262, 0.032926202346120155, 0.008262222831798418, 0.04013031698583115, 0.029156770136567856, 0.024020426395920016, 0.06302482778987577, 0.02699517644941807, 0.05018501797871244, 0.026557759396852027, 0.030262627631365776, 0.10192671129780431, 0.0737888381005295, 0.030997323187729044, 0.04944324951558825, 0.017706597854773846, 0.06879881715341922, 0.015223998005592055, 0.07368627424922682, 0.02487340018213276, 0.04541543500137426, 0.051450104933352246, 0.04475905469829037, 0.012300294305708621, 0.05145193588349128, 0.018985688896669496, 0.014029140246190853, 0.03679816776345815, 0.13787356385540578, 0.04251134123713259, 0.045666482014160965, 0.014148162538936783, 0.04634335133877974, 0.10072432863976687, 0.02567156612302267, 0.007772265075360455, 0.057736691387911, 0.022163795074447993, 0.051427953501021674, 0.07856047036306513, 0.06743821435638013, 0.13719292537819955, 3.996544153459611, 41.148953976169715, 53.65257186274375, 76.60992207065706, 78.1984898351854, 71.62911599682224, 68.71534409061556, 56.12178625599031, 47.45227736811484, 30.777146239434522, 32.20720514174431, 35.360014130992276, 29.367617022606638, 34.750434660142474, 51.07401747857371, 68.28470706939697, 59.060433833829826, 26.411950280589444, 12.4101262323318, 3.527316648152567, 1.3793095609834118, 0.5726710706949234, 0.10644155088812114, 0.1205897469434046, 0.1462559293835394, 0.4867896113184191, 0.6472963695564579, 0.8785210105199969, 1.4455435617316155, 3.160090134028466, 5.270903100890498, 5.454403834958231, 5.226780849118387, 7.849469742467327, 7.229605817025708, 5.295700815416152, 7.936616962955845, 10.30251318408597, 10.004851375856708, 9.361325752350593, 11.828333812375224, 9.024143122857618, 8.989220300028402, 9.924375126438758, 8.027453662887696, 6.6809829204313225, 3.6078563909376826, 2.639422214800312, 0.7979268448487405, 0.38363764963803754, 0.2798311424351508, 0.4302179404804784, 0.5292570518870507, 2.102653456311072, 1.9180251633928669, 4.879018606678133, 3.2035137136136336, 6.262918076207561, 6.295934627133032, 5.3859491598221565, 10.083082068351008, 8.768685037089933, 11.863286052980731, 8.31558067952433, 5.598758334113706, 5.9408802082461705, 7.120810054963635, 7.681749193899094, 4.232733105459522, 7.015827327005326, 8.963064955126855, 6.291444003582002, 7.369829079797191, 5.128288663202717, 4.964951363302046, 4.675252456818858, 1.9735385910157237, 1.1867083152455669, 0.766903899850384, 0.35376132375771, 0.2700165142455409, 0.17908089704090552, 0.03746720766949077, 0.21079425579838215, 1.3826391629634367, 10.414544901540204, 22.488040577980783, 35.65092455956244, 42.24029856343424, 41.16616141411566, 37.0588004973627, 31.446186880911554, 24.699255189587994, 55.953473429526056, 31.263210273558098, 36.924828021757065, 55.78268558748307, 52.24156979591616, 64.08669233322144, 76.60953767838018, 72.50523228799143, 67.41219151404597, 42.66517754523985, 19.87081358509679, 3.660287448475438, 0.5063855581946912, 0.07918322323671273, 0.0870911428524602, 0.06772001979932671, 0.10914148988142129, 0.012802549209746142, 0.0649377646585626, 0.01216306689105207, 0.03354410971364668, 0.08725045849719355, 0.0076957175699663505, 0.0510856194511777, 0.042524674997454694, 0.006059598911839027, 0.11040230206544362, 0.03598472028369865, 0.0022967517068008744, 0.056824115961189234, 0.06917106693670635, 0.042712274608352495, 0.03767147735362092, 0.042873264155200416, 0.06952485400101832, 0.04824075577480178, 0.059168885101474104, 0.02469150984149066, 0.10543509521671843, 0.018149783549409722, 0.01725937104633739, 0.009261527072427975, 0.027699969678876862, 0.034188822497643774, 0.06912206795306937, 0.03372633138731603, 0.014155086058552467, 0.04904075075061091, 0.03935258452510161, 0.18501908969013922, 0.2598295366812137, 0.14170073994225071, 0.19761645565590552, 0.13219037123264807, 0.11915514771375926, 0.20392803955943356, 0.15229876964322983, 0.17280672887159934, 0.11307172011584045, 0.1564457567949449, 0.11536315038439729, 0.13714539728337719, 0.12294274003755663, 0.11169609433460621, 0.13133714846785993, 0.17686556994674668, 0.18566770569211055, 0.09900250006467105, 0.21391598748103266, 0.20582914803056948, 0.19058145492547945, 0.1174847849254166, 0.1586957110632812, 0.16194825991988182, 0.13032551404208909, 0.12962561611446644, 0.11495058139365529, 0.20580959746674185, 0.09223242786021964, 0.0797494541433069, 0.21487586500663913, 0.23342383424601248, 0.2246241806255233, 7.264474216968783, 52.409596289357836, 75.02747320359754, 90.41945780477216, 91.00625222729099, 76.83495629218318, 77.94253164722075, 61.62641702159759, 52.43187535193659, 32.083277856149984, 34.713403563345636, 49.88181306469826, 46.168356172500125, 51.2918580732038, 61.01623742811142, 87.76588809105658, 61.284300050427845, 29.867532906993745, 16.083966205196997, 6.741508524264059, 4.19484987374275, 1.0880407258387537, 0.3117207473804874, 0.19684388662778562, 0.1075124115713181, 0.3087698686267099, 0.6245258462525184, 0.4267509942573886, 1.3404179124101516, 3.8594457939747846, 5.989028773000164, 4.943807826888177, 8.431370027603643, 10.212953705941478, 11.5278753542131, 8.428880303136765, 17.709505250377042, 14.77052721285051, 20.303417674956783, 21.309907667098507, 17.04070583466561, 21.404179873005038, 19.735617329997403, 19.205414864324755, 18.47596776100897, 18.50380874449207, 10.03043209352801, 7.930774102287908, 2.6138682182758086, 0.9959126468147002, 0.5216738233162511, 0.6974136577017847, 0.7709164232496293, 2.797731036140073, 11.262824131596474, 20.42538965902021, 14.3250322534192, 17.91757914327806, 15.89308798313141, 15.118045287747538, 15.944606354159696, 19.502712872720537, 18.838437911002867, 11.226394138028546, 10.655332342270883, 14.461011021367966, 13.18507577142408, 13.10826889930233, 8.022929208893931, 9.782607920708196, 13.688057968693396, 9.241079611162986, 11.892355718920308, 6.430074784063525, 5.1888000484435794, 4.891536851083079, 2.805737329106177, 1.0954933517402219, 0.4351187887932024, 0.5222038335857854, 0.3805742172464248, 0.2963720532434602, 0.09050276986653767, 0.5879572827008464, 4.007253204622577, 17.375109464891498, 29.40001383904488, 56.31537875821514, 65.92697820355816, 57.936427670140425, 48.63738621434858, 33.17817611079062, 27.361607090119396, 71.63295207485076, 35.021635178596746, 45.121150016784675, 59.10988707696239, 63.94520067399549, 73.82117963606312, 86.0994142101657, 84.7283418716923, 77.71129223608202, 52.37945679695376, 25.506890819918727, 5.848331393734102, 0.7407837337063206, 0.2936578343712515, 0.22734353228682475, 0.2393115723445531, 0.19943930058469697, 0.10211777362611987, 0.18350983519227276, 0.09284845448189205, 0.17264707614817928, 0.15579219186498275, 0.08519043274704488, 0.1217579161147437, 0.21600890904664996, 0.07373247701194018, 0.22359432862891307, 0.1374722563571507, 0.12833333303851466, 0.07970393319884617, 0.17429821012962252, 0.17295899650742932, 0.22337683626720983, 0.1916863528951522, 0.11728210104328972, 0.13970600020500923, 0.1421581863635971, 0.18928324232899374, 0.17811852206866588, 0.09517907780865509, 0.1064048016503934, 0.12451723458305483, 0.12564849363820207, 0.05771170926070022, 0.161081952373347, 0.12470710947508774, 0.13431379841941019, 0.17864013601454998, 0.13096916579431103], [0.1044002176833249, 0.0691412431338141, 0.03825846158208386, 0.016003128576783404, 0.021420724261852524, 0.037645242672653935, 0.08583599205819831, 0.029760026072542516, 0.04497979144235292, 0.030766950972798853, 0.07842662714181409, 0.034604923153716716, 0.03941097957712989, 0.01705046844548516, 0.01993808940413498, 0.026509677803504373, 0.02015736100504235, 0.06396011006267321, 0.05754427308396948, 0.008287926039267934, 0.05801951955823649, 0.15769489379900117, 0.0901604741210899, 0.17152567664461751, 0.027555638713942423, 0.019039439540656827, 0.03731544565169081, 0.0453759967950323, 0.06901988714572883, 0.013244951579479441, 0.16096935277023625, 0.033241447526961565, 0.09365197346215287, 1.9114244272631986, 31.11997708197563, 36.949217319488525, 60.159348595526914, 67.78349091929775, 53.51233536197294, 48.22775740777293, 49.84551545112364, 33.99975576708394, 24.263948586679277, 31.828598360861506, 41.606117986863666, 79.01920657004081, 92.16618337938863, 60.4731656659034, 58.44271936724263, 54.85667282535184, 20.805890944696245, 16.15012090052328, 4.3430963447017055, 1.5989337308752922, 0.15665181912481785, 0.13159905860741294, 0.042739363477355054, 0.2040288107649934, 0.16754168235967237, 0.7073854871334568, 0.7022392761803443, 1.596484088128613, 2.581211299665513, 2.751475505290493, 4.875035439768146, 4.3789830900007685, 1.7096138240829593, 3.9986742456113142, 4.2756413836633005, 4.456271433061169, 5.054456908856669, 8.897120106604792, 6.532311852901213, 10.487911855020831, 12.759656483127227, 5.959501660639241, 7.52667191528505, 10.43873906135559, 5.068585286217352, 3.4456580492757984, 4.173028257585341, 0.518317990485699, 0.2652992512429914, 0.372770723075636, 0.5810664137524943, 3.074868306998284, 9.783394355927745, 12.181344186106037, 11.992493829419537, 3.3761154067131782, 3.1603470492747525, 4.430987344634149, 4.439794536559813, 4.971216369059778, 3.9700149576510158, 3.2963108631872364, 6.679282572961624, 7.214540483490114, 8.014652517534072, 7.157713184433599, 6.543395980711907, 5.858986512307198, 6.061555358671374, 5.428951084613801, 6.031205038870535, 2.9138356447219853, 5.908716282536907, 2.8632189285370613, 2.504001404008558, 0.8535078720700356, 1.772572645737279, 1.4692631147561537, 0.8519953693593703, 0.22296555430418064, 0.25179057772601804, 0.04019459176267828, 0.050290198020276525, 0.0938110669413882, 0.07111034190822994, 0.1998520534365408, 3.2103052975669986, 18.351240311899495, 35.27996247814548, 44.02516134323613, 33.731112633982015, 32.14568864914679, 35.18996761691186, 111.6952879198136, 50.40217822597873, 23.74884528498496, 25.450108628119192, 36.38874984556629, 56.99518042225992, 49.14742769733552, 52.83296908101728, 56.5275985963883, 68.98373619202646, 47.26849079132081, 36.59212866137105, 8.6192133157484, 0.9556405690889206, 0.15018381538891024, 0.024182095845800736, 0.05470055470904035, 0.01214817988746349, 0.0622891114213534, 0.034070753026753664, 0.02926439208339059, 0.09551032656623472, 0.023939178941110452, 0.03496895664401593, 0.06044680019840599, 0.12069293898680519, 0.19068090845980953, 0.07793011023632943, 0.048588260918134646, 0.032346392531068094, 0.06804413627833128, 0.05075530532086569, 0.04567906117787765, 0.05286650574435631, 0.09665808715527097, 0.11998570193686794, 0.0021869138506571614, 0.03252715863768132, 0.07073631480095849, 0.14805569974405153, 0.04673549259502081, 0.03586354432627559, 0.0381629878745204, 0.03847700348424335, 0.09311687636880145, 0.08121337155781447, 0.13434266461239708, 0.0598376338940955, 0.08328727882115111, 0.03536459892207096, 0.10840494996838032, 0.039770171391747655, 0.0909119604095336, 0.024003262195976514, 0.0237849673571726, 0.009582749654298589, 0.06824505815823233, 0.09217605911075108, 0.021097777982152278, 0.03450965245945319, 0.06303284873044299, 0.013876266443290779, 0.028416501290555445, 0.05538853613900081, 0.01379475373053743, 0.09545470092205272, 0.029852994672593572, 0.03575803486690406, 0.08121655082270023, 0.05785541586397637, 0.08348465371396273, 0.04435809193960121, 0.08832312714789184, 0.07141884551533768, 0.07478419315790938, 0.03666918920052629, 0.017204503829200423, 0.07937504399207332, 0.06949126870641786, 0.06800740236236204, 0.04456415809991379, 0.015805584187018537, 2.043608056922113, 36.23797001377229, 48.88101247049148, 77.3982870963312, 77.00578335792788, 63.14476651530113, 54.05526984122492, 61.09445341171757, 47.55915803294028, 38.29520217833981, 37.083119192431056, 47.64137091175203, 77.02068836458268, 70.97872426432949, 53.00271749496461, 63.40285062789918, 63.65018744622508, 24.56945219347554, 13.251982581230903, 3.8725967657181526, 1.3612660453204186, 0.09784506378515113, 0.11059717185074285, 0.03891886384677022, 0.8846853216809611, 0.8009864774442489, 2.6303451147771653, 2.9976704235999816, 3.8298583751724617, 4.4192545548562086, 9.218427923417861, 7.915225336628576, 7.421038073878135, 7.033853559724747, 8.1999639157326, 8.590458420015151, 6.555912754228038, 8.07914952116628, 13.538828453710003, 8.575504383733197, 14.867887304675195, 14.016930076383776, 10.102487014185998, 7.395745650414498, 8.063183513379867, 3.8280496722267525, 2.3224554811754534, 3.37167160645608, 0.8824667310522449, 0.12396524525097302, 0.33174876784605367, 1.0206889108784738, 4.111930968299989, 9.046814422453604, 11.533108776615514, 11.195697669060001, 4.761574018386103, 1.731579097047929, 2.718900956453816, 4.453101177369395, 4.3708049481914895, 7.730768524831342, 5.93868907420866, 7.528909137172084, 7.551238209970537, 7.295565374435918, 7.597417254601756, 8.56460705880196, 6.912620942438803, 7.361096412904802, 8.842816852754163, 8.630113582457266, 6.757422560645688, 10.745229144250194, 8.544405871821988, 5.123659776103112, 6.513559491403642, 6.337637266805095, 3.767578736428292, 3.2781434251416117, 1.590302432737043, 0.7794401626433096, 0.4321122614126052, 0.2237718771662443, 0.08445567781886748, 0.01396948785235685, 0.16902089088914857, 2.449409120505856, 16.012105441862538, 29.506684657066103, 39.452481808200965, 35.509805525502856, 32.75442088803938, 36.121244199814335, 117.5625261183708, 51.37835025787354, 35.489483725640085, 33.686166194177446, 46.52393471810126, 63.78725074952649, 55.70495597777828, 62.344328434236594, 65.55423928845313, 78.15383757314375, 61.66118098843483, 48.08694431858678, 15.145255750225438, 1.798249216329667, 0.1130163549415527, 0.0565201782381102, 0.05413160419031497, 0.030418302443239, 0.048362046645413485, 0.03384192256377109, 0.021359691952144908, 0.05114189243965572, 0.022405118516255772, 0.027478097209466562, 0.04940180415888468, 0.09056211103715243, 0.09933660633020824, 0.0866531090991151, 0.04791715257470647, 0.03645157426475518, 0.022684008994650458, 0.0049492100069689895, 0.010192111311029765, 0.04465100948788947, 0.05721444541948938, 0.02988919998789507, 0.024667996687874682, 0.030807590021962122, 0.05222050593264642, 0.059256238277040185, 0.05798928206786514, 0.038099567285708846, 0.028058094716060068, 0.02443718971804746, 0.03741823549893114, 0.06266062192979359, 0.09227280069382922, 0.042777989630497275, 0.12167546973233262, 0.15284385652311389, 0.18506367600733237, 0.15549755444930446, 0.12093527557989284, 0.10988677085767831, 0.14310219054741247, 0.1568045923786779, 0.15086204835003422, 0.1725671884994353, 0.12037233119049381, 0.2064843830322066, 0.12679453819028794, 0.1589965844346631, 0.09715897076192404, 0.1480490194573518, 0.05991560249258915, 0.17121156527390405, 0.10497492152236162, 0.2200399564519044, 0.17489814890488503, 0.19147304337351553, 0.17280979322329645, 0.16197848974937396, 0.2971077427989052, 0.16999127914107617, 0.2162069121315595, 0.24890054167518694, 0.10657341760252753, 0.21324365339692564, 0.173481039462551, 0.2723266064159332, 0.22924595842919043, 0.1238080133653937, 3.3916357351887614, 46.963581423605646, 69.04671376751315, 89.28301380526635, 87.45519714970743, 72.8496556128225, 64.05154397410732, 64.88991529710832, 47.38684831127044, 37.166826494278446, 43.37879396254017, 53.36751361047068, 90.48079582952684, 98.90508990133964, 74.2268939172068, 69.2744779586792, 63.61400358138546, 28.266613598792787, 20.285170808915172, 5.520213852005621, 2.3905086036651366, 0.19950002071357545, 0.24978554176707424, 0.19155158270751277, 0.5357162762553461, 0.46975812844691744, 2.319853233714258, 2.6306047266529453, 5.173392978406722, 5.992268160466225, 10.716870407904349, 14.626688995668966, 14.606193630926072, 10.009402305849138, 13.09795012397151, 16.757247909422844, 15.768631177563822, 11.215017303343743, 20.670571134936427, 20.578220890414332, 22.480919514932943, 27.04200452373874, 19.598659930690644, 19.53853980187447, 25.281103503319528, 14.420373305197685, 12.261336022807706, 12.64465258967492, 0.8434487086149954, 0.46724410367108166, 0.4967333712885457, 2.1111922110280683, 5.279001814703788, 6.4310225267564105, 6.862565615484792, 8.096400105184125, 5.417064341806597, 10.714279682405534, 12.193327026982463, 14.579970625139053, 13.533336154876219, 13.91979257906637, 13.833539658977141, 19.809353966866773, 21.990038810237763, 18.539784723712554, 18.327392301251813, 19.65350643281014, 14.869969102644152, 13.154907841836254, 13.180275770925707, 17.85078117924352, 12.45592284587122, 17.625695966905166, 12.147179361312622, 8.841234176389634, 9.319151447665307, 6.390804504194568, 5.6776425915379685, 4.241298091027045, 1.7684352806498929, 0.5745708461730712, 0.27130988516634513, 0.22564563629848344, 0.13023393589162058, 0.21542577824044615, 0.47706299130955054, 4.786818392815129, 24.500416517257694, 46.90109806676065, 53.307493502093905, 47.384702774786184, 44.2541257796749, 46.108775369582645, 119.23119652655818, 61.22706874724358, 36.89582601670296, 36.02852721368113, 54.22476330111104, 73.14111909558697, 68.35361526858422, 72.18887744411346, 74.7169077780939, 87.5833958964194, 71.69075996645036, 55.287537344040416, 17.87354857690873, 2.370480000972748, 0.3857222974540726, 0.13271592287046294, 0.13705973333168414, 0.10701861427796465, 0.09322212918871835, 0.2341818935688465, 0.11674567095695004, 0.10859636469714104, 0.11401695770121391, 0.18357875246194102, 0.11951288013088128, 0.17570015103105577, 0.20527243193599487, 0.1095226109628716, 0.22517908875259662, 0.12114126130097336, 0.22492609587648224, 0.10621409172252302, 0.09540119734142097, 0.13824530035978363, 0.13218283292747315, 0.23208445208447598, 0.09892332487769666, 0.19147186359811216, 0.1701706356459087, 0.3285822200198328, 0.13603392627931413, 0.09934711705652938, 0.09349560725592798, 0.21818040058978144, 0.3182480003564589, 0.1678118968923246, 0.3902010619640351, 0.152553585808604, 0.1920942487495561], [0.043715056888158285, 0.0787172272741314, 0.06745437881158245, 0.06135486719769336, 0.05847791975904858, 0.014298108928356201, 0.02065045541272529, 0.06334897874283694, 0.09343143973139026, 0.08723158209073929, 0.019035113059104453, 0.046765155519448945, 0.08814713376904688, 0.07068661867731041, 0.03561790972467392, 0.1401812045444404, 0.040676311679905465, 0.03553177462890744, 0.10846227632775422, 0.11566323468521719, 0.12469808495933972, 0.1474426761870423, 0.10139365965921072, 0.1308381494375006, 0.10276501066982748, 0.10245187989165706, 0.0373379226713892, 0.073152931497222, 0.08178627509022914, 0.03796629479996139, 0.13599249624436902, 0.03476800412059792, 0.44557935167704865, 12.45857927107042, 38.50795153648623, 57.684301637834125, 69.15194311449605, 61.9425129890442, 55.0616245115957, 49.12088109600929, 59.94857218957717, 35.2979818467171, 22.758031045236898, 43.65710966048702, 44.50871506044942, 64.4477229733621, 93.45922408565399, 74.12685778833206, 43.18836289067423, 17.31325957082933, 10.176486449856913, 2.4444024601290306, 0.20761803994255684, 0.026367545510912617, 0.14244101070348295, 0.20768233004116243, 0.30154682395439, 0.12751275328018014, 1.0463536530733109, 2.1128479415370576, 2.422010629407821, 3.636202869876739, 3.573182393466273, 6.258505900059977, 6.186747608646271, 7.672607129619968, 4.717104636853741, 6.258387248362265, 4.670978544219848, 2.17034817222626, 5.720620001516035, 6.953066952766911, 6.851307432497702, 9.48382039223948, 11.066591874245676, 6.307137896937709, 5.360954836491616, 5.55768572515057, 2.990057593391788, 4.144996058556342, 1.9310588317532695, 2.2070002700051954, 0.12928700525193446, 0.6807061993787367, 5.1204027379712755, 20.129719434245942, 43.27829891635526, 44.527813080818426, 40.794744337758715, 23.34379976795566, 5.0141383755591615, 2.692422751457461, 3.1683369173157603, 3.4402162509579814, 7.851026433129465, 3.3201137665779363, 6.404686752826938, 7.023195499374021, 2.254790183036558, 2.0930708608319684, 4.233152799067959, 6.023795191318759, 1.5866838011049456, 8.864660532243791, 4.94064639652929, 7.548366054411858, 7.733700496535148, 8.86359658933455, 8.805797523067845, 7.895791953609836, 3.1828190434363584, 1.5327129681264202, 2.297242485707806, 0.9119790119509544, 0.14208465724462463, 0.5023555067037383, 0.20108956122590652, 0.09526071979874566, 0.047788740916838574, 0.26564503268849465, 0.07484927998795625, 1.0998142102072317, 8.484186703158963, 29.328714955237608, 43.47639822190808, 55.90773859331685, 35.82129270799699, 13.301370124663077, 17.948893385548747, 14.349808885205178, 19.557459354400635, 25.690126303703558, 43.738345869125865, 39.02225663585048, 42.66153758571994, 49.31662697945872, 60.75322289620677, 65.25330328172254, 64.2196253807314, 44.40228154582363, 13.752943777268934, 0.609645783420532, 0.1222852067721467, 0.1075587981951333, 0.11218605352745903, 0.14968143024992558, 0.055192996026767846, 0.026261838783900586, 0.10242525833628832, 0.05916451073942646, 0.10741625987594167, 0.07717117757326172, 0.19573682829016642, 0.5131040267165631, 0.11738763731573859, 0.10706601213783988, 0.0569729438622392, 0.16401865850052527, 0.0657213959963091, 0.09711467555814213, 0.10286607298879855, 0.0338962956541969, 0.08436265942310134, 0.03780877563141046, 0.024286454258066033, 0.016103834664869695, 0.07219879963104764, 0.030600696486691316, 0.03787779632294851, 0.041566153447474205, 0.08042123664410845, 0.0336024588003995, 0.07169611571777253, 0.032077510991404136, 0.09966310534265735, 0.049555381805065184, 0.015410050118882811, 0.06214593724918462, 0.025274464447471886, 0.10419721970514906, 0.07541847565481741, 0.034853208419536395, 0.05735106570946594, 0.03179629160571964, 0.046973826378704085, 0.06887568641574153, 0.05199809145602969, 0.02756456363826029, 0.044486947928465186, 0.03489379958820439, 0.049382812839241765, 0.018153399484412327, 0.04121026347181009, 0.061771262797617146, 0.08135741140933768, 0.030696677727504607, 0.08900240964947209, 0.11572270609077909, 0.09215326033412449, 0.10601878526710695, 0.05931979676167812, 0.062037482181744236, 0.06073062811347266, 0.09636750234471214, 0.06935206286969685, 0.02393156019670348, 0.11533544864505531, 0.019488131492248466, 0.8071167743013752, 16.54134496565788, 51.12567901611329, 72.51517941874843, 80.21934201640468, 72.66503749355194, 66.65536234455725, 54.2725024684783, 63.18970903273552, 42.74542139422509, 25.756916422997755, 39.624042357167895, 43.39154558797037, 71.7458849568521, 102.89493268535983, 77.62243486219838, 53.939807030462454, 21.54835247224377, 9.525122950153968, 2.0715368034378177, 0.05417195404128683, 0.08273713576096682, 0.41285942999585984, 0.7979669878559729, 0.9362040604314498, 1.8333360432617127, 3.3720648240658546, 3.0071686881203807, 4.341237631536299, 8.023411170128854, 6.846844755834149, 5.763239495215878, 7.432486491818582, 8.478550257221345, 8.621048984989043, 8.37291886729579, 9.17964058537637, 8.20105286375169, 7.284013503982175, 7.891747499665907, 7.235716379457905, 10.086144458863044, 9.357552432244825, 5.301394135721269, 2.356649478597026, 1.4379193321351083, 0.9292690035316252, 1.6792448730238023, 3.835557333884701, 4.293389618396759, 0.7796573638916017, 1.9851664573915544, 4.336185128458085, 22.06107097287332, 44.19015976690477, 46.782434601937574, 41.09772389934909, 24.403381001564767, 6.720254180892822, 3.2210209677296304, 2.644402399178474, 1.9731381415359437, 1.0286649893368445, 1.6253393720234595, 3.206089975372438, 5.602366424375965, 4.0758481044923105, 6.258304878588646, 5.00939917179846, 8.156745770285207, 6.774847690136203, 9.395713171651288, 8.886119819456532, 9.644593442639998, 11.095307546277201, 11.53651535511017, 11.125324464613392, 8.122110751367385, 8.463892359887401, 4.177641455204257, 6.33881054578289, 4.370036653933987, 2.7036171959292505, 2.343098915392353, 0.8747821950143384, 0.6953525747503004, 0.2707953498728814, 0.05853669019415975, 0.0539462645387938, 0.8048939548673169, 8.416990618551932, 22.73342993951613, 39.62745481921781, 44.94973067314395, 32.20204330259754, 29.19813729101612, 28.089846103422104, 21.555079337089293, 25.063427648236676, 36.865313899132516, 51.51631178394441, 51.23009643247051, 52.311133030922186, 58.56431284258443, 68.67183716066423, 76.21471974157518, 74.4100058463312, 58.074165621111476, 21.553924199073546, 1.8489517343621102, 0.11250765723807198, 0.14523298750000616, 0.043368938363968365, 0.0694415572610113, 0.05169682354936677, 0.044093875875396114, 0.027944100832927133, 0.07121160341006133, 0.05253108180758934, 0.030013357942563393, 0.09881573548961071, 0.1258132561680771, 0.02860962631060712, 0.1269394820255618, 0.035870607656937455, 0.08783746570829423, 0.07840013582139246, 0.02810387996085469, 0.0275718855235966, 0.059549178807966174, 0.060611796385097894, 0.04611637863901354, 0.02905443419642266, 0.06634046398704091, 0.02557247265001699, 0.03157402460102833, 0.09107778014074411, 0.11713462145698648, 0.026416266787677046, 0.05753800265430924, 0.027993373692997044, 0.03410420042552775, 0.14495802322222343, 0.10712202848686327, 0.1718330924068728, 0.17230904751246975, 0.1663528977622909, 0.24976596055972963, 0.24432987725782782, 0.15853901543924886, 0.16581985378457656, 0.12973948742353147, 0.1755840733887688, 0.2932768435247483, 0.12480114676779318, 0.1646911917674926, 0.24782498487301413, 0.13960123002048463, 0.21084028236087293, 0.1846881090633331, 0.13685304280971328, 0.18060331292931112, 0.2152301500281019, 0.21699569158015714, 0.2995422782917177, 0.2558182237008887, 0.2723834194963978, 0.4014441989842923, 0.23809268049174742, 0.31300584455170943, 0.2991459350432119, 0.24413412647141566, 0.31865752031726224, 0.06798227467844564, 0.2645848282883244, 0.077682479975685, 1.419986868577619, 24.197544820847053, 66.52883452753868, 83.99601182629986, 88.15094717087285, 82.37944618348153, 73.66515559534874, 65.08057778881442, 71.75001129027336, 47.815076997203214, 31.84356220306889, 56.225403508832386, 55.89703052274643, 71.22683771194951, 97.57200964035528, 80.35637394074472, 52.798291406323834, 24.603272830286336, 13.484696803554414, 3.4327794371112703, 0.3580450729256676, 0.12409168040199627, 0.361483704539076, 0.534617767458962, 0.6426536928742164, 2.49650992212757, 2.9371813468394743, 6.841004346647571, 8.347651939238272, 12.292155065844137, 10.073398716988104, 16.255958214882885, 15.35732065477679, 16.256769164916008, 16.244226405697486, 17.651938584543046, 16.55336310786586, 14.212405316291319, 15.928127496473252, 15.443413738281498, 15.977414038873489, 21.816354297822524, 22.118796494699296, 17.772482825863747, 14.787088440310571, 15.98633448923788, 13.745870763255706, 12.060765624046327, 8.810139586848598, 4.431393800243255, 1.1342641422825477, 3.0570901641922616, 8.144766361482683, 22.555460237687637, 30.17154601312453, 31.141108851278986, 25.989685558503677, 17.47852863803987, 7.162128792655084, 8.400089125479422, 10.030183023022069, 10.913037946147304, 18.623684221698394, 11.962909352394844, 17.443317521002985, 15.573871770212728, 11.57564982291191, 11.676967586240462, 15.127191274396836, 14.995338839869346, 9.830033298461668, 19.336286706309167, 16.58988037417012, 21.71121124298342, 22.505383337697676, 18.332722802315992, 23.639921065299745, 17.543971423179872, 9.638433360284376, 10.367354865997068, 8.230138709468227, 3.2513335347175603, 2.0510932875256387, 1.2277598414690265, 0.5472865328192711, 0.3017815839379065, 0.25223449503462164, 0.3895328187894437, 0.26033745297501165, 1.5710293765990966, 12.446004152297975, 38.763525332174, 57.13716237775741, 71.07093918708064, 49.04755630800801, 26.709256133725567, 27.337537465556977, 23.370836665553433, 30.318693730138964, 39.851116211183616, 59.503359640798266, 57.80938602262928, 60.16019582748414, 68.86219762986707, 80.39940234153502, 87.25644280833583, 86.83310139563777, 70.2408322980327, 26.929644307782574, 2.7604082130616714, 0.24721062832301666, 0.25535248820820167, 0.24851251814153888, 0.34976476563080666, 0.2679221830781429, 0.16861515540269115, 0.14516227758459507, 0.25240606808614346, 0.12251145551882445, 0.16115951111480115, 0.3087944753708378, 0.5854308473006372, 0.19725051077623523, 0.1914928850507544, 0.14141826800281002, 0.39258184872808, 0.3677043997712674, 0.08400780749657462, 0.1645746391506926, 0.24116493821624788, 0.19568484156362473, 0.18412382402006658, 0.18904681227380232, 0.28142963085443745, 0.1358665820331343, 0.2311960199186879, 0.21208597196926995, 0.2995506746153678, 0.1175980740076592, 0.16752582433963978, 0.1506201943923389, 0.15782854549827116, 0.3938947395691949, 0.23232265946365174], [0.03178363391799072, 0.04865330178290606, 0.023913788872079986, 0.004995545398654236, 0.06643531333294607, 0.05768131472230439, 0.0829930627538312, 0.17633531452907672, 0.05817150374153449, 0.03721910626477292, 0.03301791839241501, 0.15930326475251108, 0.05046895697652813, 0.08668818060428866, 0.07653679548492355, 0.07146500231277558, 0.1001863050905447, 0.1488994843056125, 0.14248067873620218, 0.14820418290553555, 0.1597551034102517, 0.1449424103503266, 0.18116186763490402, 0.12086719334606202, 0.1298316784443394, 0.09919627434423856, 0.050371288427061615, 0.09124872500016805, 0.13777669969825976, 0.07075247159528156, 0.34349053617446657, 0.06192024391625197, 9.873743211069415, 36.316793964755156, 63.949715322063824, 66.90919460788851, 63.483741667962846, 56.07688688462781, 43.656501693110314, 37.32052064711048, 51.189170422092566, 52.543757038731734, 59.657183231845984, 80.67841622137254, 86.58221090993574, 36.29416188886089, 30.802482789562596, 26.113422609144642, 15.367132463762838, 7.21772103540359, 1.4854631164381582, 0.16189120169128143, 0.06324883955981463, 0.08380584373709657, 0.2598717021605661, 0.8235746105351757, 0.3953156488076333, 1.710356010064002, 2.1331037965513047, 3.8434108995622207, 3.9734605146992594, 5.381443337086709, 5.858917380532911, 8.286756161720522, 4.422553758467398, 4.333809643022476, 6.99964068589672, 4.115368925756024, 5.253542200211556, 3.6137357786778486, 2.8881340690197486, 5.4231636274245485, 5.224008223702831, 9.244319488925319, 12.295514575896725, 6.420658644168608, 3.0249833579986327, 4.290691518014477, 4.03451612880153, 3.587828523689701, 3.32368042680525, 4.677832395799698, 3.84409706919424, 5.150679023035112, 22.5675509437438, 39.8702024644421, 61.10436916351319, 61.24060876907841, 68.07785695598972, 53.888796606371486, 22.817741286370065, 11.607989764982655, 6.410100604257276, 7.917958248046137, 6.480258568640679, 2.906416726689185, 3.1086965434012876, 3.493926001171912, 3.2516826256628963, 2.903549719241358, 1.5792195306670282, 3.0205679949252837, 7.053829210419809, 6.686152114022163, 7.085171399577972, 5.19473655569938, 10.565545366656396, 8.113338370477, 6.408311513162429, 6.3971214813570825, 13.58845918409286, 3.176487847681969, 2.744543206307196, 4.119934074340328, 3.0802618111333544, 1.9917825152797086, 1.5763645354778537, 0.6763949629760558, 0.09300549484549031, 0.047050370053658565, 0.04120193226563354, 0.0932638579979539, 0.745299730089403, 6.657024102826273, 18.293359856451712, 46.427632685630556, 49.225365192659446, 21.824969783906017, 24.887981991614065, 28.366828195510376, 19.98554683500721, 22.69574380690052, 31.456894951481974, 21.118945114074215, 30.98821878433228, 47.26848294658046, 52.44561933702039, 53.59428151961296, 60.708794209264944, 61.939771252293745, 48.362934051021455, 19.407516948638424, 2.2430546966291245, 0.2938805514525983, 0.1083041481193035, 0.14931766105996025, 0.0487464810571363, 0.04457712796847186, 0.09827685392191333, 0.08900189637056283, 0.057612611957254915, 0.0858326442539692, 0.13942263960357637, 0.16585699372714566, 0.008091385224683872, 0.09910100364997503, 0.012251444709216876, 0.1735821783903145, 0.1759446709747276, 0.20898202884822123, 0.02324581574348192, 0.08669353555887939, 0.02960085023885533, 0.02206560175475334, 0.0992276379838586, 0.023779501319832863, 0.05282291534146475, 0.10735648969608931, 0.06716129655439047, 0.031009145839620503, 0.047762747553567735, 0.06483583666023708, 0.03324810866146319, 0.04945351892421323, 0.06469540508283723, 0.04736137876827871, 0.014381458336908012, 0.06981794391908953, 0.04723042369850221, 0.019084207803731965, 0.03048459969220623, 0.0596573542533142, 0.017029370384050474, 0.19653765064093376, 0.03389614626705166, 0.04989961192252175, 0.025987521850413857, 0.06640856920350945, 0.03493616808085673, 0.07533666512538349, 0.05267252845148887, 0.05475609608355069, 0.0946494276004453, 0.08060197210720471, 0.10190457135679261, 0.07330010464835553, 0.13255643868638625, 0.11288127065786432, 0.06599201655556118, 0.038990320697907484, 0.032239492622114, 0.13251493204264872, 0.10957151035507841, 0.061114426672218315, 0.11450154661771753, 0.0390220022640161, 0.1395506835392406, 0.08133447473688472, 12.558821324379215, 44.73507504309378, 73.62678697032314, 77.07895125112226, 73.43084889073526, 65.57542400975382, 56.929461110022764, 50.765574055333296, 62.70433925813245, 51.4488862406823, 49.892658418224705, 72.93788540747859, 65.69889237803798, 36.164276522974816, 40.152216957461455, 36.209101369304044, 16.473533068933797, 6.329978839043648, 1.1573779342635986, 0.17216074821208754, 0.21589008880959404, 0.4486270026574212, 0.7435581977328947, 2.221814326701626, 2.6490670779059013, 5.919372871998818, 5.123664679065828, 7.82936220207522, 7.341467891969989, 8.911175920117287, 7.531623907627599, 10.02345125521383, 9.67968100501645, 7.75993723061777, 9.22316026303076, 7.378312185887368, 7.331542334248943, 6.156754224531113, 7.774261236190797, 6.439782650240007, 6.67887709794506, 9.68315524439658, 8.292154323670173, 5.553993794225878, 3.1037308227631355, 3.218047811139015, 3.764081943419672, 5.744954876361355, 4.458598379165896, 6.319612014678217, 5.414999704207144, 7.946194410324098, 24.95275797382478, 47.9976241050228, 76.70156432736304, 73.93626197691887, 79.57497504449661, 60.608024597167976, 26.17589616006421, 14.175086905879361, 7.222785305592322, 6.440342078285833, 7.023799544380558, 2.2164355314547017, 3.6142574539107666, 2.511502446666841, 3.9480656193148707, 4.578908749165074, 3.725652766804542, 5.32034408661627, 5.617382728284405, 8.506305929153196, 5.9419289519709935, 7.755476024843032, 8.392885692657964, 7.365778742298004, 10.782087656759447, 10.039001491761978, 6.875770764966165, 4.377396981562338, 6.135797000700428, 6.7706684047176, 2.9849869493515264, 7.546244052148635, 4.430375454887267, 2.9327924597647885, 1.278087282853742, 0.2862483851851956, 0.07659737005709641, 0.08113090985364492, 0.9008080404131644, 4.860661914271693, 15.521838588099326, 38.97572948086647, 41.00951371654388, 22.07994345695742, 23.49014339908477, 24.745501895104688, 24.592001899596184, 31.511488460725356, 48.209181062636844, 33.5228543896829, 40.33660757926203, 55.27084765895721, 60.66705234589116, 61.90109668239471, 70.81785217408212, 73.60650047179192, 60.97597822066277, 26.096485814740582, 3.246797068465141, 0.2897421138421182, 0.09043913860354694, 0.07348522213437865, 0.0404840657457469, 0.07176068160803088, 0.17752330239501693, 0.07523014826039154, 0.06227820999019089, 0.05550946311784848, 0.09333436106962543, 0.12247592436089633, 0.04090320777087923, 0.09805280384757827, 0.054281531427536285, 0.0633980428439475, 0.142259968805217, 0.0429312493501892, 0.052128077424581976, 0.11580676125783114, 0.06907878398534752, 0.08763342585054137, 0.018213690604053197, 0.010367579919646585, 0.04922278856317844, 0.05919159960842902, 0.021005912548712185, 0.012995929911642546, 0.03600053999933504, 0.03990692191667134, 0.09067568357192701, 0.05502909917624728, 0.13836801232349488, 0.093125602110259, 0.13936919730997857, 0.12055084499860964, 0.1044413106395833, 0.1834620772710731, 0.20359400990268878, 0.12030788787430334, 0.15497771782740472, 0.33907820680929773, 0.19189998417371706, 0.2856172819531733, 0.10209888189790711, 0.21621314808726314, 0.154665996651015, 0.3563628357744986, 0.21330503236141898, 0.13559619896113873, 0.2034571559558953, 0.2863712963317671, 0.23206540713867835, 0.2825306830627303, 0.2987545560444555, 0.4272803916565834, 0.4489109761291935, 0.27572435957770197, 0.2576049092796541, 0.39880404549260295, 0.23143298623542632, 0.3089815846854641, 0.37315808777366916, 0.15597386195534663, 0.41514748947754987, 0.41537320962355984, 17.472560751822687, 57.58073145343412, 84.82396141175302, 84.69528413588002, 81.09920024871826, 74.13587923972838, 61.64879022106048, 51.69313615368259, 65.09186637017035, 64.69689153855848, 74.77178958154495, 91.89594776399674, 96.39089768932712, 48.12302620180192, 41.55318560138826, 36.09099488104544, 21.501138902479603, 9.506497575390725, 2.1346818151012545, 0.3759441044061415, 0.43063748087133136, 0.33070550931076853, 0.4860410208423292, 1.665308078931224, 2.6230740210702344, 6.592348141054954, 7.255509149643683, 11.117502277897252, 16.54641855147577, 17.351800780142508, 19.42255139350891, 23.039108091785064, 14.237249608962768, 14.430706789416654, 15.80935420528535, 16.68276798340582, 15.80444633960724, 14.036544869022986, 15.696586062831265, 17.3923090580971, 13.081254555333047, 22.91128589260963, 34.026510254029304, 20.66968075690731, 13.907306694215345, 10.026412644693929, 9.89006615454151, 8.59353748060042, 5.435415640954049, 8.185860053185495, 7.032475336905449, 9.789905490413789, 32.52939255006852, 41.692872970334946, 59.21794445283952, 58.69043665547525, 61.4841644225582, 48.97854220482611, 26.028181660559873, 19.27441720039614, 14.683854599152843, 17.18655916952318, 14.860730940295806, 7.716634754211673, 8.303002618974256, 9.245353033465724, 10.37270890128228, 10.355773087470762, 9.439388763520027, 11.867247646854771, 14.808476144267669, 19.897917162987497, 15.151822778486437, 15.659081339836122, 21.914166442809567, 21.17381907278492, 19.020373129075576, 22.268240759449622, 29.308053870354932, 11.378533071087254, 10.973444407986058, 11.56174207887342, 8.633227944374084, 6.869620488535974, 3.5163869636674083, 1.680500644349283, 0.7784012861309514, 0.2186902167816316, 0.12741116236054129, 0.25689431676460855, 1.1536248388790316, 8.792554620773561, 24.042628849706343, 59.50193974279589, 63.087739175365826, 31.955759640662905, 34.838895874638716, 41.22101968334567, 28.744264148896743, 32.53130666671261, 43.72033826766476, 31.508768297010857, 46.24196729352398, 64.07081065639373, 71.28723436786284, 72.66830875027564, 81.21267441780337, 82.99044162996354, 70.03089135692966, 33.075394322795255, 4.999639824513467, 0.5442530085002223, 0.363954920321703, 0.288252777630283, 0.2273123831518235, 0.20848689090100028, 0.2839633594116857, 0.1820448452546712, 0.15862051187263382, 0.17364826113466295, 0.3040385402498707, 0.4126385821690483, 0.13260410467703498, 0.20765099704505938, 0.22585813376692035, 0.4268694008069654, 0.30615334128660543, 0.37436173447678167, 0.11132336191592679, 0.2427903163216768, 0.19585713473779542, 0.16595419496297836, 0.21389393947057186, 0.10072108808784716, 0.18718376305074463, 0.13471470755194465, 0.19504123577667823, 0.10107616217987192, 0.1831125419947409, 0.2126553285145952, 0.13198158162976467, 0.2104605325768071, 0.3775476796492454, 0.19225505060486256], [0.021442132588896542, 0.04546624961339178, 0.057026133346821994, 0.033518162315651294, 0.017880446187430815, 0.1763210652936851, 0.018264675670633876, 0.08487138010921978, 0.06191490811385936, 0.07422466552065266, 0.03855564624011036, 0.0660690313745891, 0.03272609634985847, 0.042805411747746894, 0.051096915417621215, 0.20884439349174502, 0.115383145279221, 0.22311190774123515, 0.2206825203592739, 0.15472055743298224, 0.10153585323883642, 0.23163762364176013, 0.1616658339457166, 0.30956420987363786, 0.11323157968300004, 0.30575329017254615, 0.09635234912556988, 0.0884909770121017, 0.22120692286520238, 0.1608165335511008, 0.19577455045955797, 3.0903324965507757, 25.487010286700343, 59.45412997276553, 73.99615656945014, 65.33298230940296, 56.106316428030695, 57.88442488639586, 37.01809021734422, 23.263204866839995, 24.96957121356841, 64.3870399844262, 76.44477459692186, 73.55794937379899, 46.50286374553558, 37.79014602784188, 40.333563820008315, 17.760917717410674, 7.87185617992955, 0.5880605513530394, 0.19865378467065675, 0.12486418048220298, 0.19659726760320126, 0.18100852747598004, 1.179120980443493, 1.8486574340251185, 2.3230977692911705, 2.401184314681638, 5.6440376850866505, 2.3994516076580172, 3.9194997327943004, 8.491591157451753, 6.825741914010818, 3.0342193140137583, 6.11423033860422, 6.622963220842424, 6.997516722448411, 6.4276193803356545, 5.674366922147813, 5.206170264751681, 2.9352542373441883, 4.68616400034197, 4.646390676498413, 7.208983465548485, 7.4922393887273735, 9.520048383743534, 8.279215405064246, 11.516286711538992, 15.846558866962312, 20.026404203907138, 22.228875852400257, 17.677018219424834, 13.000984230349141, 25.32414367122035, 34.57055476404006, 53.067868063526774, 47.170870842472205, 56.735699945880526, 59.05898255686606, 64.6368988867729, 47.46012210845948, 36.68303743485482, 23.871415430499663, 20.614375337477654, 19.197658377309, 10.406114747447353, 10.63303464843381, 6.753820353938687, 2.722580384823584, 2.836417373149626, 1.9149848362130506, 4.346738265406701, 3.7435311751980938, 5.61209439269958, 6.915978491306306, 7.224763160751713, 4.403363562399342, 7.216296724734768, 7.603917602569827, 6.138828502547357, 3.5595141591564303, 1.0965646490935357, 4.51202743476437, 6.349759842118909, 4.06928401800894, 8.92423152923584, 4.052414639342216, 4.121980080681463, 0.8550703237133642, 0.024269052570866003, 0.05976032796165636, 0.11058092312586885, 0.05738075544697143, 0.5942116245146721, 3.783751404093158, 14.293434619903566, 26.599106173361502, 51.053789815595074, 50.17288823281565, 38.28310558872838, 30.69214455543026, 21.394738728000274, 11.893640295151743, 20.717676839520855, 25.1427673908972, 29.283821467430364, 30.498540286094915, 45.4043294537452, 54.40676912184685, 63.69840514275336, 66.43414851157897, 57.16044556710028, 15.639748957849319, 1.0284480332366883, 0.04238116757703885, 0.10582048340790695, 0.07538916513083443, 0.08182071840330478, 0.12312848571567767, 0.03336024861181936, 0.21283614058648387, 0.17652634621387528, 0.136960341084388, 0.1746981233478554, 0.10639752381511274, 0.12144097021871036, 0.12482232909889952, 0.22242947661828613, 0.15670402035597833, 0.0840373708295726, 0.07738068729879395, 0.07032102619808528, 0.08163318774032016, 0.03850016232219435, 0.09596016573449297, 0.04074214544567851, 0.05040259844052696, 0.04771355704794969, 0.025430265663852616, 0.09188253252256302, 0.038531824736104864, 0.1140090976391108, 0.041409147557832544, 0.08656041246027717, 0.04416604518830296, 0.030842583003123442, 0.010654036473903445, 0.059861505193816084, 0.039351768641462254, 0.024117338433561307, 0.018077221616441687, 0.13015135161338315, 0.03595466282398951, 0.036989601644416975, 0.0894332345154497, 0.0833332364357287, 0.10332754903262663, 0.010538663632506806, 0.02502320484528619, 0.019116142178855596, 0.03477742317162695, 0.07906395100778149, 0.10651567755567451, 0.23268091282056225, 0.0646016359209053, 0.02831783491156755, 0.09062344403637033, 0.06629866622989217, 0.08828555819608512, 0.1399077877642647, 0.1000461876091938, 0.12202158825652254, 0.016398125425762227, 0.0883191664733233, 0.07053652673118538, 0.12960111662264795, 0.1890622566063558, 4.147176406075878, 32.19518111598107, 70.8530750582295, 84.12865854078724, 74.69000031871181, 63.88015993179814, 64.700386370382, 43.71099125954413, 35.06066276181129, 36.22226876597251, 60.65655216093987, 71.60051407352572, 76.89384675795033, 56.11315311924104, 39.00968936181838, 38.13325928103539, 15.31072780009239, 6.430900933281069, 0.20167469918247194, 0.05194064635302752, 0.07687158356871336, 0.4532056650327098, 1.1670800394588903, 3.7422147297090103, 4.640899848553443, 5.586879926343118, 7.0428647148993715, 7.642001855757929, 7.007710962526261, 8.172241583947214, 9.359782299687787, 10.312412265808353, 6.553585808123312, 6.912631238660505, 9.859760941997651, 8.481069399464516, 9.462943576997327, 8.852212890501946, 6.136312302081816, 4.657474314012836, 5.231115068158796, 4.583510179673472, 2.003088992449545, 5.927436774776829, 10.130200520638498, 9.972306489944458, 12.896537396215624, 19.230341526769823, 22.053908724938672, 24.932467552923388, 20.30895998401027, 16.74217031848046, 29.15119044242367, 43.65683117220479, 64.69840949581516, 58.1685809935293, 66.16914533799695, 71.32131976466026, 75.18808641741353, 53.689500977916104, 37.73638602226011, 25.762133175326934, 22.96874861563406, 20.4003982774673, 13.753481141982542, 12.951605512249856, 7.6480741750809464, 4.313543246638391, 2.5720976725701363, 3.218011529214921, 2.988734038606767, 8.31713491870511, 5.647467307506069, 5.2766052465285025, 5.571457657121844, 6.894275036550338, 7.8210850204190905, 6.293280653415188, 9.357820134009085, 9.907014716056086, 6.058401282756559, 11.769222713285878, 12.851660578481614, 9.652046926559942, 14.687077806841943, 5.642819789148146, 6.833629800427345, 5.296130805246292, 2.147414073828728, 0.5222762135728714, 0.07782527110389165, 0.029115851465312224, 0.43056454930093985, 3.569245069257675, 13.130955888379006, 27.70178641042402, 45.866243454717825, 37.33893225269933, 34.752897908610684, 29.13090982744771, 23.048749277668616, 18.66358845464645, 27.352611134129187, 36.15880873895461, 42.422578950082105, 42.730822332443736, 56.16736419739262, 63.99778396852555, 73.96371072338474, 78.3027542791059, 67.07412242889404, 19.914955939016036, 1.3124266531198256, 0.08431824164525156, 0.048659756073668126, 0.08710029760315534, 0.13045306768148177, 0.06380761643090556, 0.04880479950037214, 0.0998571937182738, 0.08225869853049517, 0.03817165998982326, 0.0828240407750972, 0.031016921632051952, 0.057405438799891746, 0.19862119529035785, 0.2003115070082488, 0.10767102241516115, 0.06570408240922036, 0.10221741868243103, 0.09752105455845596, 0.027921577847953287, 0.051593129718375784, 0.052190038615897785, 0.011878335949844651, 0.03867276193153474, 0.05416111389715826, 0.06361108423481066, 0.09275554333843532, 0.07424413181480861, 0.08162056261132802, 0.011716429012707405, 0.09966339645606857, 0.03762442423331161, 0.042626886448312196, 0.23623652606000825, 0.19274353890890078, 0.10218135892383515, 0.17311673401103866, 0.11308119662346379, 0.30784746812235925, 0.1633820394354482, 0.21505077820151083, 0.3323498404314441, 0.19653041877092856, 0.2359229049855663, 0.15073595027769768, 0.09743035740910039, 0.17234364404313027, 0.17411866976368814, 0.30738064478481975, 0.3193033017939137, 0.6130649870441807, 0.3685887716710568, 0.30597646690664754, 0.46048711624837696, 0.3344480020384635, 0.27702012069282994, 0.48620980533380664, 0.2309353814850892, 0.36638868972659117, 0.2978769563619168, 0.32336981907006235, 0.4458427020618993, 0.2723180875182152, 0.3726608660672942, 5.214951470974953, 44.672050399165, 82.52211847612935, 91.22464979848554, 85.31571680499663, 74.30505891000071, 71.25903252632388, 53.01807749655939, 35.44105029875232, 35.6037070674281, 77.24127461833339, 85.74094880011775, 79.89704870408582, 55.78367010239632, 52.311435053425456, 51.69713697125835, 24.24094584680373, 10.476561496334693, 1.403155733020075, 0.3490969821089699, 0.294291848737386, 0.36547290822190626, 0.955017218666692, 4.369098717166532, 5.211970469643993, 11.467789546135934, 10.110193490982056, 13.635112835514931, 9.524858190167336, 9.03797830304792, 19.816843732710808, 15.743194606996353, 11.515387508176989, 14.229179332333228, 19.65596772009327, 19.9332243780936, 14.475619889074757, 14.178682738734832, 17.02837586402893, 9.798541568940687, 13.095439807061227, 15.271075579427905, 18.94462235512272, 14.761401818644616, 15.380204742954625, 16.350731503578924, 17.291286453124016, 18.372652530670166, 20.777530247165313, 25.843341927374563, 24.264187851259788, 20.949473227224043, 33.65561485290527, 51.988282742038855, 63.20700276282526, 61.64880983291134, 66.44380538694321, 73.42222752109652, 71.82517959225562, 57.54109590284286, 42.60789132887318, 33.06070504649993, 26.605230954385576, 23.773583673661758, 14.528139445089526, 13.807341168003699, 11.087844256431827, 6.6441646122163345, 8.79432459031382, 8.853415096959761, 14.726645696547724, 15.167994710706896, 13.498022075622314, 19.205020666122437, 14.89803856418979, 14.805961904987214, 19.204304833565992, 18.583989835554554, 16.642500931216826, 16.48133662439162, 7.822010699779757, 17.496508782909764, 19.239304142613566, 17.290505901459728, 29.378438841912057, 10.02676663860198, 12.101799499604011, 3.7553600630452557, 1.070663032512511, 0.4543261452307625, 0.17402531428923532, 0.1704437613126732, 1.3206465926862534, 5.2704672275051, 18.349873365894442, 34.21136371551022, 67.40334264693722, 66.18819236755371, 52.85452642748433, 42.35741269203925, 30.916745355052335, 18.666436095391553, 30.035214231860255, 37.4853660983424, 42.45726054714572, 47.835077162711855, 61.503964547188055, 73.83718290636617, 83.42587178753269, 87.49622514170986, 78.24488362958355, 27.477707286034864, 2.237866136335558, 0.23767968249176782, 0.2346239722664318, 0.2731320406160047, 0.4180486644468, 0.2449396679237966, 0.1632027288958911, 0.37260681090335696, 0.28579982538377086, 0.3396527421089911, 0.4923579673613272, 0.3709311927518537, 0.27357192830212657, 0.3562681473070576, 0.44330210935684944, 0.3508154705407158, 0.17164650403203505, 0.31095858182637925, 0.299866670562375, 0.3129480508787017, 0.1158573690261091, 0.1858835433038973, 0.15977163558765767, 0.10577992671319555, 0.11902145004921383, 0.14269847753307513, 0.3028003583031316, 0.21410213152487434, 0.23751350269923288, 0.10549530972756686, 0.3889470986060558, 0.17084182059812933, 0.23538400809611046], [0.005325936616563629, 0.07451941018864032, 0.04874112610254557, 0.027831688921357838, 0.03589383927324126, 0.0492421284528269, 0.0714220707454989, 0.043356964409711866, 0.020847083369810736, 0.04131219913101485, 0.028791378755422852, 0.005753978668156291, 0.02200966392974219, 0.027630958563437866, 0.022709098374170643, 0.03729482256476918, 0.0846128560782921, 0.13588398755077394, 0.12321386621483874, 0.03138754156328017, 0.1478520276085023, 0.14772121043455216, 0.17285486983676113, 0.16425135004664623, 0.07045677697826778, 0.15881532803177834, 0.31859862347764356, 0.05106496955117872, 0.04336672820030682, 0.040253354536910216, 0.3558584128416354, 20.01572947348318, 53.1725404339452, 65.84711090210946, 71.44957342455464, 58.91680448285995, 47.50120109127414, 37.40546349556216, 34.97536690004411, 25.93993421523802, 43.00800446541079, 73.78946335084977, 69.74522513727989, 47.77692802490727, 25.365387393582253, 30.366448586986913, 12.862835411102543, 4.933098775725211, 0.2601017123989521, 0.3266278684379593, 0.057501935234834115, 0.30935819350904037, 0.5280257953751473, 2.284862504851434, 2.3480957698437477, 5.019602237209197, 2.906379464172548, 7.9510419695608086, 5.179374592919504, 7.931289403669297, 7.188157150822302, 5.2437318621143225, 5.933652750907406, 9.296748830426125, 7.5689325121141255, 5.120203187388759, 4.199269404334407, 6.56433996654326, 5.372133591482717, 2.2584068534835695, 5.511179652906233, 4.452422607329584, 7.557860641710221, 14.567127804602347, 20.693434630670858, 28.47805484648674, 33.10631044449345, 33.696846808156664, 39.94299773247012, 51.836816495464696, 49.50537927689091, 42.75088133350496, 24.423995018005375, 38.11755803323562, 35.355197460420676, 43.342331609418316, 38.24443494119952, 58.562747816885675, 43.623251761159594, 56.43575237643335, 41.34434684630364, 53.252584242051654, 44.06703656719577, 52.90265390949865, 34.62689568919521, 29.721448152296006, 34.61270847628194, 18.885429866852302, 17.0147358217547, 11.832528787274516, 7.3985653442721215, 7.159986688244728, 6.093750663342015, 3.9849398213048137, 2.687402362785032, 6.544386869476688, 4.746088991242071, 2.726252458749279, 3.930932461254059, 3.3536676822170137, 5.8182698584372, 4.291921181063499, 5.369607585091745, 6.763354655235045, 0.5056650065366299, 5.682201856567014, 7.58572712059944, 8.416839607300298, 4.03948258488409, 1.819571098012309, 0.3589649300181097, 0.13658699579536915, 0.07997878256344026, 0.044773575894895105, 0.08781863526711542, 1.8796520031267598, 6.8648386289996495, 17.185090241893647, 37.71507186274375, 38.716249004487075, 43.30721855163575, 44.71300778850433, 38.90633098540768, 26.694833578601962, 15.599275981226276, 16.797232550959436, 24.6870272005758, 29.48902222418016, 47.605806781399636, 54.130402841875636, 65.54323311774962, 62.98472204516011, 39.97638494737687, 12.80849587532782, 0.6579350632044577, 0.07789093249988172, 0.05999911373721496, 0.08982759359623156, 0.09127687873138536, 0.12732627215765177, 0.12952564164034783, 0.18306650011049164, 0.06964045666879223, 0.23672617881769137, 0.09985192303335476, 0.2160297159946734, 0.04056561580528656, 0.15373788113074918, 0.15351157875791674, 0.028031578497780908, 0.024150678580025994, 0.1345405757667557, 0.02778031889559521, 0.023591585697666295, 0.05794290693536882, 0.06155247574732189, 0.03674840652233651, 0.021328822439236027, 0.06961885298932753, 0.04878811793582094, 0.03448971119078417, 0.12765670120115244, 0.06319101907372957, 0.09647324546090058, 0.051631288557884195, 0.08936698323175793, 0.06648209066160264, 0.07789421135619765, 0.020154718001703584, 0.014194920715395243, 0.028822981797519232, 0.07672220408435791, 0.028965186868463794, 0.05829074915738837, 0.04853948793043533, 0.06858185339238375, 0.004785909268614506, 0.03590943299293999, 0.05255743140174497, 0.01000595577586923, 0.03878816158600873, 0.02172291913490382, 0.06766273940522825, 0.09222164134224577, 0.08266085638634621, 0.006449802444436618, 0.12254424408198365, 0.11988707577749608, 0.0913329946718389, 0.1396312759888749, 0.05658669382213585, 0.07497068960219622, 0.05692608992479021, 0.09119306105158984, 0.07566960693727579, 0.024898999010122595, 0.990665986412956, 25.090784219003496, 62.12847648128387, 77.39874209127119, 79.17002170316636, 68.69916823602492, 55.918587869213475, 48.217398428147845, 44.400947939965036, 27.297713641197454, 34.959755866758286, 68.56879649623748, 68.2042984808645, 53.900724534065496, 28.565672751395937, 31.997540727738414, 13.631404234517007, 4.650290493042239, 0.14835508690486032, 0.45825363287041265, 0.06074739011725592, 0.8198099931882274, 2.644171959930851, 5.597716454536685, 5.162199514527475, 5.540231668180035, 5.749035612229378, 9.217262979476683, 8.997024836078767, 11.286360313815456, 8.504283947329368, 10.487429403489637, 9.323759252025235, 7.065467373017342, 7.773463033860731, 7.775761052485436, 9.753814781865767, 7.499349665257239, 7.954078374370453, 5.508170214391524, 3.3582730350955843, 2.3613516649892254, 6.128604844693215, 12.410774404002774, 21.40297374417705, 29.90775485192576, 37.044628973930116, 38.59289046256773, 44.86863566983131, 51.71775294888405, 52.85396552854969, 46.60927764831051, 28.836298642619965, 42.89910770231678, 43.96660427893362, 51.66607964423395, 45.953300460692375, 65.73927317896198, 53.42201494401502, 69.08336439440328, 51.50015946357481, 56.931488975401855, 50.065517271718676, 53.93798312833233, 38.58197842874835, 35.08062370361821, 38.579295527550485, 23.334344894655292, 18.408465731528498, 12.241708482465437, 6.288710601868169, 6.455921732610272, 8.435736606197974, 5.851321710694221, 4.458260565034805, 4.174322149445934, 5.381476186936902, 4.282043672377064, 4.722821981676163, 5.482559588647658, 5.994856924779954, 5.75351054629972, 8.149115289411238, 9.865738634140262, 7.179212185644335, 13.09979069617487, 10.09657698292886, 9.92704527993356, 6.889744699001313, 4.395335451249154, 2.429362621999556, 0.9117482049811272, 0.41534008398171396, 0.06995602360656185, 0.03081627745902346, 1.7649864141018161, 6.485654769405243, 17.16003021886272, 36.217616834948146, 40.92453948913082, 38.763035035902455, 34.495441375240205, 27.557176466911073, 27.12290733091293, 21.063547518945512, 24.94374828953897, 35.68290364357733, 38.505719707858184, 58.4163571173145, 63.36648241166146, 73.86465518705307, 70.37358883888491, 47.86745632848432, 14.832842888370639, 0.672606504972904, 0.03503099061368454, 0.03435421321961669, 0.09894454551319923, 0.02843533556217388, 0.03809528485421212, 0.10060959165134739, 0.17202735698271185, 0.05185720405631489, 0.11442767275917916, 0.0379759781513243, 0.1871127467001638, 0.020462855801827485, 0.17853913498261284, 0.0828749779611826, 0.042687215872349284, 0.02086377834090062, 0.19991893291233048, 0.010849314201022349, 0.05836790187224265, 0.1858453308382342, 0.03707980466706138, 0.012119129833374775, 0.013281031447883337, 0.08501687552779914, 0.07866674974080055, 0.03553390052289732, 0.07552515339827345, 0.01549003640144703, 0.05089737249598388, 0.004585471460520621, 0.08800410515358371, 0.18422280257988363, 0.23434674036839317, 0.18940512691774677, 0.1138540184605987, 0.0766168210294939, 0.16550111524280042, 0.17456321526438962, 0.12931449248665763, 0.17407385362011774, 0.20611102242142926, 0.1459546270029199, 0.13780654648378973, 0.11191362500070565, 0.22475438492913402, 0.1514141525953047, 0.15059733432867836, 0.18237636214302433, 0.26436784154465126, 0.2010174876739902, 0.13801768031572142, 0.30321680369877047, 0.3246508712970442, 0.3407692080063205, 0.35689903603446105, 0.23308410489511108, 0.2885958011592588, 0.5557927441212439, 0.2655657272665732, 0.324080319654557, 0.17922711258213367, 1.723695991020049, 31.86073433968329, 73.72479131144863, 85.24118392698227, 88.35007021504065, 75.55710300322502, 63.88391756242322, 52.278545979530584, 48.91817692787417, 36.97327321575534, 56.6102703925102, 86.41714972834434, 78.59776358450614, 58.30111003691151, 37.101428816395426, 39.4809268366906, 16.55177454794607, 6.090172971448591, 0.5400093104089461, 0.6364774920286671, 0.16167876550987845, 0.6677821735220572, 2.1526506831569057, 6.840524836894005, 7.673639203271559, 14.52140179372603, 9.851016998291016, 19.436487574731153, 15.452640133519328, 19.655810825286373, 19.203777274777813, 18.99981990937264, 17.061698359827844, 20.42624669690286, 17.317521226021555, 15.548024331369708, 14.923261365582867, 16.94347223927898, 15.322220344697277, 10.814902205621044, 16.233557558828785, 12.575586515088236, 13.771986884455528, 23.442743516737416, 27.573350360316617, 32.73599751534001, 38.55508665884695, 43.06853448190997, 50.26828419777655, 59.89072115190568, 51.02781980268417, 48.835430606718994, 32.79404074914994, 50.16853440192438, 52.717847516459805, 54.8269961726281, 51.138097240078835, 69.71769009867023, 60.43852721491168, 72.66277036359234, 54.11936529221074, 61.4157739762337, 55.73427569481635, 61.11669717296478, 44.135862396609404, 36.910848694462935, 41.4844342970079, 24.06640821887601, 20.940732225295037, 17.773653653360185, 14.26182423868487, 12.640794938610448, 11.453139493542334, 10.316013001626539, 9.68701191486851, 14.581918081929608, 12.749438708828343, 7.862575361805578, 11.146109104156496, 9.705495103713005, 10.087263314954697, 8.530643255479875, 10.743102239024255, 11.950773539081698, 8.81499351993684, 18.66293930238293, 20.29543565165612, 20.646738813769435, 12.83649669539544, 7.561232409169597, 1.3280422216461552, 0.8610570863369973, 0.2842439314530742, 0.15024494920526782, 0.34669054672122007, 2.7359539510742312, 9.593482998109634, 23.616751624691872, 48.51734207522485, 54.090469191151286, 59.52309700750536, 62.41958695073282, 53.56446366156302, 37.91060986057405, 23.86890119121921, 26.736389129392563, 36.18621433934858, 44.26810118459886, 63.46570660991054, 70.38124530546128, 82.57690614269626, 83.27544889142438, 59.913941583325794, 20.24508026338393, 1.2174164287505613, 0.15114140997250236, 0.14822420844387624, 0.1743275972623979, 0.17217493616044524, 0.243600883310841, 0.2523067830911567, 0.3975126357568849, 0.3421641621858843, 0.4684280159492647, 0.22887010037177996, 0.4563020698485836, 0.14976407581519696, 0.36165304061385894, 0.33157373207711405, 0.15676498563299257, 0.15848831574042, 0.39691683385641346, 0.09466478000244788, 0.08927430957555772, 0.3245344872195875, 0.22405186698081034, 0.14901645060989166, 0.16159806580793473, 0.2675318766024805, 0.19196887079986835, 0.07723798810113823, 0.2798925826866781, 0.19059648557055384, 0.17804597354223653, 0.14296810983890487, 0.3131578976829206], [0.005602017946300969, 0.022521282343434233, 0.07283901164848959, 0.051819589139232715, 0.04691203755717124, 0.05214110091929475, 0.02576929595952313, 0.03336447741716139, 0.06465801999213235, 0.018029691606399514, 0.050303554763236356, 0.026927364261580572, 0.028534789096503973, 0.1462119406149272, 0.104960955739502, 0.10029634595998835, 0.07463867475669231, 0.09564135824480365, 0.11018867844775801, 0.09918397863305385, 0.06726125570675058, 0.06234674804633664, 0.09558336538893562, 0.05786257878606839, 0.01003187827600707, 0.049515652485312, 0.07346896574862542, 0.08492044804076995, 0.0988519944310669, 0.19600551064697005, 11.592269885924555, 56.79619858341833, 64.74542302470054, 80.14648791282409, 60.54922042354461, 57.2696247408467, 52.61591296042166, 31.288652727680823, 24.868150488022838, 40.627533697312884, 77.16200351715088, 76.45449423020887, 93.03657301010625, 36.74668181327082, 41.69382610628682, 19.6111624856149, 3.3532600008672286, 0.27638543216932204, 0.20531058311462405, 0.06106181941445797, 0.2194825815217149, 1.452593531820082, 1.6606275881490402, 2.3136750103965884, 6.2641085155548595, 3.9719719752188656, 4.738721309169646, 5.160594284534454, 6.349817697078952, 6.849661507914144, 8.365895863502256, 4.046421502867053, 7.910637634415781, 3.1205962790596873, 4.310136177847463, 5.776584869430912, 5.481433378111932, 6.664410906453287, 8.367990409174274, 4.148367826015719, 6.517553444831602, 11.547851985500706, 17.870206717521913, 28.019427791718517, 43.12180026885002, 58.461487908517164, 51.373659103147446, 55.62199392626363, 59.24022351541827, 57.43385437996157, 60.74814342683362, 66.97902064169607, 37.86175674007785, 39.66615684570805, 44.98482804144583, 32.93070200950869, 43.73867534822033, 56.943095268741736, 41.72845279016803, 31.356854900237057, 32.510178819779426, 55.3752415410934, 55.620927041576756, 52.675521219930346, 48.26077984225366, 54.30386966274631, 51.816329956054695, 42.938629504173036, 37.40884065628052, 34.789764265860285, 26.69050132074664, 18.505644413732714, 26.536609088220906, 19.064119323607414, 14.283776763946781, 12.319284139140962, 13.258495676902033, 13.353799466163883, 4.1267134008869055, 7.255021795149773, 5.502345984981907, 6.448686430531164, 10.472228257886826, 12.092005341283738, 8.259599631832492, 11.633760717607315, 5.452665244379352, 5.3567294632234885, 8.259806536859083, 6.88747315637527, 1.6731111440927753, 0.8421083611826744, 0.07654592725298098, 0.10916504708509292, 0.039973740105427084, 0.0742981946396251, 1.2828280800773253, 6.982403339878206, 13.606457960221077, 32.48548161598944, 40.35880427206717, 41.746268195490686, 51.35716161420269, 59.030898386432284, 51.72624095793694, 35.907141623958466, 18.899573933693674, 23.720378683459376, 25.073141397968417, 39.51600067077145, 60.436750381223625, 58.31814096819971, 49.07705253170383, 18.396074964154153, 1.0193966737677975, 0.04386707171497326, 0.12157079147835895, 0.07198153709572169, 0.042687744473017035, 0.04815503819695404, 0.03205857329791592, 0.019471382895003886, 0.05025064873118555, 0.05690783404955461, 0.1280636241238925, 0.08909682232526042, 0.09282980790181507, 0.15521826943562878, 0.057363786599448616, 0.04324501981177638, 0.10537023821304883, 0.08456384943377587, 0.039531975503890746, 0.04705753680619021, 0.08451006240061215, 0.09779370525070737, 0.01212288557942356, 0.009439866595541038, 0.054931442118099624, 0.04144877345571595, 0.034353305405426415, 0.054175014562544324, 0.06639938380929732, 0.030887872205987096, 0.03385624840795513, 0.039368890706569924, 0.08294025631321054, 0.02686879683976933, 0.03270613209855172, 0.027364451896339178, 0.048291080090547764, 0.0031831247718899602, 0.02768903377375776, 0.0235859492057634, 0.01234773813085931, 0.040453000880417325, 0.015581194161167069, 0.06968225442594098, 0.014542749530876116, 0.096510331777315, 0.08894963385236841, 0.045523756003427895, 0.03584674784853574, 0.0915704895892451, 0.016039738961074863, 0.06816153925272726, 0.06176593465610378, 0.0644843018944225, 0.1354873378670985, 0.02203397381479942, 0.06100189601702075, 0.016462202934968858, 0.02642100504148872, 0.06907005058301073, 0.0679963706962524, 0.1396068990711243, 16.87514258969215, 64.90538120269775, 75.61321643091019, 87.37656931723319, 69.9975198315036, 65.17205922834336, 60.67312809728808, 42.96171265263712, 34.51272333821943, 38.105175110601614, 66.58479106041693, 79.26711605441186, 89.90325035587435, 42.99870060336205, 34.7724626910302, 18.49644253330846, 2.5934826798977393, 0.22941431391143033, 0.26524770884744586, 0.14392029584175156, 0.8641017648962237, 3.3881847848815307, 5.758845950326612, 6.438261751205691, 8.367220644027956, 6.852910701305636, 8.58740387424346, 9.744428550043414, 10.725627099314044, 8.857829724588703, 10.689601109873864, 9.305805583154003, 13.899109921147748, 6.477045657173281, 9.077018633965524, 10.211142551514412, 8.498615141837828, 6.686895403169817, 6.66944379768064, 4.8559207493259064, 6.058751354294439, 11.851867052816576, 18.147951710608698, 29.992699661562522, 44.202931004185835, 60.0821759623866, 54.17557285678003, 61.1790354021134, 65.3993566574589, 64.32435266433224, 61.042791874178, 71.70857537177302, 43.319636775601296, 44.9036192893982, 52.24422524052282, 38.482044281498084, 50.096700114588586, 61.005470521988414, 49.736359811598255, 39.28066630517283, 41.40537892618487, 58.183972374085464, 60.80756733494421, 58.21643783200172, 53.406851060928844, 59.647820534244666, 56.50095001343758, 48.11571490380072, 40.27292005477413, 36.49298683289559, 27.76140839822831, 17.737208950904108, 18.341950178146362, 15.450473023999123, 15.302204489707949, 12.747116665686331, 14.590777735556326, 11.064669912861241, 7.5539206208721295, 8.600465366917273, 8.23687538023918, 7.678173953487028, 12.88807096019868, 15.135345881985081, 10.768278952567808, 11.358881015931408, 8.731220518389057, 8.040822571323764, 9.799493724300016, 8.90675638952563, 4.385351057975523, 3.1295034914247455, 0.5266345184176199, 0.7182556006216234, 0.16090628841230947, 0.18224667877920214, 0.7601729287735878, 6.035010718530224, 12.64522231394245, 31.876249274899884, 38.2643017461223, 42.60031723207043, 43.82153934048068, 40.88302120085686, 39.06630485288559, 38.34028590110041, 28.266972495663552, 34.692387503962365, 35.1637504946801, 47.12298654740857, 69.49556627581197, 66.53118794964206, 60.583588230994444, 23.724012759424028, 1.6407765952810165, 0.017359106117979656, 0.22791845063048027, 0.10760786612668347, 0.0022490299353751567, 0.05031560532628529, 0.022827539397704027, 0.05538179839570677, 0.057457191869616515, 0.03616409594072931, 0.12447407318940087, 0.061713641494392395, 0.10634141553553844, 0.14445407526387324, 0.1052321355429388, 0.022414527991185748, 0.08245624962352938, 0.03606157039382285, 0.09908668546667022, 0.022176483405693885, 0.05997508155903029, 0.018212319306668737, 0.03620161509682094, 0.05736650238114019, 0.1160837326859755, 0.07712374140899028, 0.05603128007703251, 0.055126606847249696, 0.050644149793492216, 0.023544189753010872, 0.043530770607533, 0.058681109259205486, 0.2166591951202962, 0.12350888667447914, 0.1903862404006143, 0.15149209438072098, 0.15715956687927246, 0.10915581572560534, 0.1311235937980875, 0.16699543102614342, 0.1644167024642229, 0.27288744406354043, 0.12506730869532595, 0.15050949468728037, 0.1310957848064361, 0.16360788215552607, 0.2295496663258922, 0.2646566873356219, 0.20334829486185507, 0.22523413983083543, 0.19682894791326216, 0.18272551437539442, 0.26562588049038766, 0.29977771243260753, 0.3167103086748431, 0.2553151644045307, 0.27844262339415093, 0.1448465727509991, 0.24615520431149393, 0.21845904208960074, 0.34253090379699586, 0.5248145999446993, 21.911850283222815, 82.23853895741125, 86.118131760628, 98.6800870587749, 77.06128489586615, 73.30394452618015, 67.13839438653761, 46.3237722458378, 35.23589464925951, 57.504202089002064, 89.68817895458591, 83.16925464137908, 97.82385718437934, 47.35138616254253, 54.00862893750591, 24.62243753094827, 5.01660309491619, 0.7595714578224767, 0.34711100641758214, 0.21663659552652992, 0.5702466169191945, 3.3004751945695574, 7.108989011856818, 10.841666498491842, 15.912124226170203, 12.86112133533724, 15.111187023501243, 15.860319522119338, 15.87678170973255, 13.708979891192529, 22.036134504502822, 13.912852925639, 17.739544722341723, 12.678628160107522, 12.943257727930623, 16.684164347187167, 14.69729361995574, 14.924088985689226, 18.762657719273722, 13.67559071510069, 13.396938673911558, 17.962517738342285, 23.117367221463113, 30.509013014454997, 46.51172045738467, 63.370534220049464, 56.42933145646126, 60.37658906752064, 64.75630367955854, 68.69336312816989, 64.51099472661173, 73.46242397062241, 46.52442893674297, 54.554752303707986, 59.11528818068966, 43.6907204504936, 54.52532668267527, 69.41224728861164, 54.98382429922781, 47.73287980787216, 46.351083709347634, 63.0638401739059, 64.4170343491339, 65.60190393078712, 57.949904934052505, 61.01428801013578, 54.490680386943204, 51.73834539228871, 45.36768274922525, 41.896702858709524, 31.39346238105528, 23.83623177005399, 32.628399056773034, 24.433404784048758, 19.835043530310354, 17.721156650973906, 18.454390802691062, 19.35468066123224, 8.922357616886016, 15.960244844036719, 14.545595953541419, 14.505529922823753, 19.742046094709828, 27.98592486689168, 13.049077391624452, 18.85207599209201, 18.287176239875055, 14.257659662154413, 19.26599587163618, 18.570518455197735, 9.134569610318831, 3.2119056245973034, 0.5517239592248394, 0.5655738483032873, 0.21958451718091967, 0.24845975000531445, 1.8108238448058407, 8.259424105767282, 18.83914589881897, 42.67441080462548, 51.5232269225582, 56.04005190633959, 67.67280947777533, 76.05353386171403, 65.5006597118993, 47.66069250722086, 30.287791336736372, 36.91953282202444, 41.13861068602532, 56.28182288139098, 79.77301551449685, 75.81109216136318, 71.95505711340135, 31.11042807179113, 3.1711088072869087, 0.16673267818987372, 0.47751666857830943, 0.17649017154209076, 0.15382343783013283, 0.1604543884675349, 0.15045338640770606, 0.18177620886314302, 0.1527315173898974, 0.17656397645271596, 0.3301059689012266, 0.3023445972752187, 0.2048258792849318, 0.4596561559986684, 0.444393968510051, 0.2516704857830079, 0.18605428898046095, 0.12915050370558617, 0.1636798331333745, 0.15231960723477025, 0.186822981603684, 0.28932055097914516, 0.1095353203615354, 0.2248451357046443, 0.2563332646123825, 0.157258530117331, 0.1767175617597757, 0.21585389881605105, 0.23772295113773118, 0.13436144908830044, 0.13564640836369607, 0.13853777740751544], [0.0701277192321516, 0.15906574685246716, 0.09050288477972632, 0.1049779245870248, 0.045702970781994444, 0.04956139176483116, 0.14260719049601786, 0.10391138463972077, 0.06086644401112872, 0.040465093578302094, 0.05197500156599188, 0.02971109603681872, 0.08549181173645681, 0.06491267527904242, 0.04071437858886296, 0.006155549987940299, 0.054907624444533745, 0.07755229099383278, 0.08410954397291907, 0.11041319583572688, 0.10390458177895316, 0.21224234583637408, 0.08771256273311955, 0.10624261317594398, 0.04628405230300081, 0.13886048428473935, 0.015423687441544908, 0.07567842460928426, 0.08716177615907886, 2.4736098993209104, 34.04153685415945, 71.7082223584575, 68.24513819909865, 64.84356072641188, 58.54145326922017, 57.3721751090019, 40.72378081660117, 23.040449542383996, 26.02195097554115, 54.070202304470925, 72.20211152107485, 87.3943062751524, 47.0938668712493, 30.214288080892256, 18.727021025073146, 5.485515094572499, 0.4259074701657219, 0.14854912165432207, 0.11414279530365622, 0.31810517092385604, 0.8869149439757871, 0.8998373150825502, 4.687410823760494, 6.874177792379934, 5.117243759093746, 3.4441579878330235, 5.982119027645358, 7.5964788275380295, 9.165666161044951, 11.347211964668768, 6.496817344619382, 5.90393687448194, 9.651044760980914, 4.854265999409461, 6.551387809938, 5.1483452127825835, 6.811616478427765, 5.396346872852695, 6.857646472992436, 13.101114496108025, 24.109060072129775, 32.30712948306915, 49.71267261812764, 56.805000382085005, 59.9590527626776, 60.870207586596095, 64.66959576452932, 58.57523664351433, 69.56653764170986, 74.60463385428153, 63.09026910412697, 70.12806415557861, 52.466717766177275, 40.98438701322002, 53.7445318314337, 35.27313363167548, 51.41713073176723, 44.38044178870417, 44.81562091458229, 23.04672141228953, 35.11264201133482, 53.26038975869456, 54.91337068619267, 60.25333250722578, 63.199205090922696, 63.5202040210847, 57.96494330129316, 57.347621071723204, 57.18649010504446, 59.14090518028506, 50.76129082710513, 45.46983695799305, 49.295183381726666, 39.63742548419584, 35.66315058738955, 27.526276034693566, 32.409840668401415, 22.605209619768207, 23.469233243696152, 12.076934614489156, 10.91949220626585, 6.862149353950255, 9.902480456136889, 10.479183600794885, 11.16774489802699, 13.75655726079018, 4.310322000134376, 5.612430735941857, 4.470608676633527, 4.344621166106194, 5.528742555649051, 0.646561476732454, 1.2975547414633537, 0.32461602961824787, 0.06432722322642803, 0.2139439650120274, 0.03413605053097971, 0.22281825091809998, 4.84920859336853, 15.041482583169016, 33.839774054865686, 46.48395007656467, 54.57345416468959, 85.83822358039119, 96.70364395264657, 72.92884826660156, 39.73663399296422, 23.56372706351742, 25.124138093763783, 41.01389892639653, 43.38809390221873, 54.500498079484515, 48.005190357085205, 30.747604908481723, 12.633263007287058, 0.25174044493225317, 0.1688540062957233, 0.03201100498347754, 0.1360065769404173, 0.11835394231902978, 0.03777856112367684, 0.013401082213667613, 0.07579613401884995, 0.2015020689296146, 0.1487489480284914, 0.16357213649297916, 0.03140434187145964, 0.014275482521512577, 0.11205835433136072, 0.12034817643824125, 0.06781830888001189, 0.02381019654773897, 0.014157538497520071, 0.013295860994877595, 0.07117625611323504, 0.021381592490680276, 0.07638065910507595, 0.016175460055350296, 0.054028940747582146, 0.04271969800033877, 0.05249845795333386, 0.1140918581175708, 0.03932693973183632, 0.037070734186037894, 0.007646878028378612, 0.014258363329234624, 0.029452815238806992, 0.02896383089283782, 0.06838825531303883, 0.009773170383977554, 0.012162080552849558, 0.024110853499282273, 0.022204447530149933, 0.049548636400891896, 0.06730113824408862, 0.07639799567480242, 0.016019036392531088, 0.03827017889688573, 0.020795265182612405, 0.08957748887159171, 0.07563512531980392, 0.03459024107864788, 0.030909728694466815, 0.06343216056965532, 0.06500900317464145, 0.03820034998258756, 0.02325897521880125, 0.1085349704108892, 0.09160201410732924, 0.1012188154122522, 0.09753218581599575, 0.03158187125659278, 0.07330144530222302, 0.05991958998023503, 0.058586202456705996, 3.8925378505260717, 42.33478453851516, 82.20229625701904, 78.09999912015854, 74.0128815558649, 67.1882555561681, 61.47502922242688, 47.17040015805153, 24.922710657119755, 23.243900922036943, 43.45645689195202, 73.326521688892, 86.42657126149824, 58.399922386292495, 27.163619572116485, 18.238933047940655, 4.589453060780802, 0.5775805911229503, 0.24987218631131036, 0.09532095729223183, 1.366517853833014, 3.2654332297463573, 6.711598000218792, 8.722790364296205, 11.419187457330766, 9.874588481841549, 5.565554490012508, 11.524411901350945, 11.788770825632158, 10.63860539467104, 11.143249696300877, 7.23400769695159, 5.590022235147415, 9.884942558503921, 7.93756127357483, 9.284800310288707, 7.493779899612551, 7.189315230615678, 5.428537274560621, 5.618662891849395, 10.333297906383391, 21.608433377358224, 36.24675612295828, 51.262840378669004, 58.781627839611424, 61.853177085999526, 63.06035318682271, 67.87055969238281, 62.282821747564505, 72.60086751753285, 77.31205771046301, 65.47794918860158, 69.87187847014397, 56.426938810656154, 46.279394549708215, 57.09735816524875, 42.350375959950114, 59.18380414285968, 51.75756108376288, 52.72394680207776, 29.745123578656106, 42.88527742508919, 55.85773229599, 57.223658484797326, 64.28385419230308, 67.12276766377111, 69.3461710406888, 61.69012808030652, 60.748174805794996, 60.619081758683734, 60.916436641447014, 50.285785813485425, 45.64726537273776, 49.290351021674375, 40.98639918911842, 37.511336111253314, 29.776563336772305, 31.407471126125706, 24.699025730932913, 23.128381236906975, 14.248904931929804, 15.729870315520996, 11.341770656647222, 8.869585067995134, 9.59019212953506, 9.78415725692626, 9.68399953457617, 12.51757073786951, 10.680396287671982, 10.16119901211031, 9.970712046469412, 10.035960674285889, 6.436026980800014, 5.431551125741774, 0.9107989301123928, 0.573157015587053, 0.3785176388919354, 0.07388597804932825, 0.3123316871783426, 3.2412809902621857, 13.002165844363551, 31.370491020141113, 46.074082005408506, 52.73888711006411, 79.3380952650501, 88.46472109517744, 64.82030107129005, 37.423780964266875, 25.803480840498402, 29.781381968528997, 48.286432143180605, 50.45069794501028, 62.18641381109915, 58.78143564347298, 36.60770831569549, 13.840890180680061, 0.36961180548514094, 0.021462269209986253, 0.08604233784060325, 0.057515184725484544, 0.1422930791253044, 0.022462561704038132, 0.06898778806170149, 0.0818420922563922, 0.11176529505680646, 0.07283952492739885, 0.15215661436800035, 0.07061336534999071, 0.10701047076332955, 0.11008911000023927, 0.056390196099997535, 0.11372268034686005, 0.04399061871452197, 0.06275945876334464, 0.030453444811545556, 0.01582293416328368, 0.025140356925886967, 0.017189099716262955, 0.01725362921734491, 0.030102835096899542, 0.026119474749711734, 0.09371017316176046, 0.08305892333268158, 0.04876425812741922, 0.021598096598961183, 0.02968421401155572, 0.036744763774256554, 0.13839743009978725, 0.12579152991454448, 0.22062791361203118, 0.2046475493379178, 0.17664723488832676, 0.2064501848672667, 0.3271551514344831, 0.18780830857013503, 0.14298102608130825, 0.19269385044613194, 0.10167278379442231, 0.1487290450642186, 0.08539897720179251, 0.09032627086966269, 0.20226248780325537, 0.09917022735481301, 0.15923287659402818, 0.22740475803373322, 0.1653191693607838, 0.18898840573045517, 0.1838216329774549, 0.26860562543715205, 0.20794731985417106, 0.3088131372726733, 0.2172297620845418, 0.25557476095855236, 0.1783898091244121, 0.18063795542524708, 0.11803175638159437, 6.0950023897232555, 54.215212329741455, 94.46963448678294, 86.58516053230532, 83.29520194761216, 75.66771384208434, 70.51594734191895, 54.38605116259668, 35.28286503207299, 39.28051725510628, 71.07269640891784, 78.5042699690788, 94.82312633145241, 55.67896635301652, 40.14469385147095, 22.866506153537383, 7.120304559507678, 0.7639487616477475, 0.3443888202309609, 0.2615094142815759, 1.4064614330568623, 3.054777191531274, 9.4175450840304, 14.628564869203876, 18.59640217596485, 15.17115516047324, 12.305099868005323, 13.383731072948827, 18.007693636801935, 19.785547141105898, 20.641863307645245, 15.410224603068444, 20.72856730030429, 19.62691472422692, 12.905744179602593, 16.552900268185525, 11.856720985904818, 14.3204842652044, 10.656997388409032, 15.002049034641637, 19.207631003472116, 30.091549273460146, 38.482169797343595, 54.45538690013271, 61.80171951170891, 65.50665701589277, 64.90816608552011, 70.74942250405589, 61.96743180674892, 69.62385131466773, 74.97077926512688, 69.60699296766713, 73.31046350540655, 60.79518048994003, 52.97553154730028, 65.38226296824794, 47.08613195726949, 63.35670786519205, 56.22829821801955, 58.78686812616164, 37.35251934297624, 49.58310104185536, 59.17364520411338, 63.74054316551455, 71.24540621234526, 69.01962587910315, 68.12423506090718, 61.975535423524924, 62.298738725723766, 61.4674041348119, 65.29015002712127, 55.79375843847952, 49.75310833223405, 53.17331314086915, 43.56576550391413, 40.927406741726784, 30.789319315264304, 38.292174108566776, 26.781164946094638, 28.10651617665445, 18.138102639106013, 16.51024841493176, 12.970746678690757, 18.608926303925056, 16.49606316320358, 22.14719053237669, 27.243747711181644, 13.30837449719829, 14.371562350180842, 15.036208956472336, 15.11431609430621, 16.63118293208461, 9.21306114042959, 6.096263431733655, 0.5299293093623654, 0.38534142918163733, 0.739490699864203, 0.2593091178324915, 0.564072990129071, 6.487003084151976, 18.763504951230942, 43.959241990120184, 58.01117627851425, 62.59470116707587, 88.9145855749807, 103.62603895125851, 80.63139484774682, 50.16983270645142, 36.63630631662185, 37.38534173657818, 56.14911733135101, 60.50905927535027, 72.7687841846097, 69.40968205851894, 50.49733884872929, 19.58531210499425, 0.7193584607974176, 0.3464469001177819, 0.18381354308897452, 0.284186658719855, 0.25166739078779377, 0.1265386724844575, 0.189084948130673, 0.3443529060290706, 0.31094037957729836, 0.19574476496106197, 0.2550614207622505, 0.1249441677223771, 0.20211660934071388, 0.3568060023169364, 0.3018507463557105, 0.2429204286947366, 0.13375813952617108, 0.14820111855383844, 0.13656105605825303, 0.18204892084242838, 0.1260998113561542, 0.18173755206648382, 0.13946780814759194, 0.12140687164520064, 0.12063239505814931, 0.16714209089836768, 0.21248761654621173, 0.13911154661928454, 0.16704101325763812, 0.13492760338610219, 0.18482773624841245], [0.051681735447698066, 0.026118660781292186, 0.05801028053786966, 0.12749821293137728, 0.03139400159970167, 0.03392921828274285, 0.015848534906493322, 0.01389754453538767, 0.00913409409188335, 0.05207661546826844, 0.05366783371315368, 0.05739009405876841, 0.04617537507006238, 0.018376003567790313, 0.008162063538968083, 0.04451194154699484, 0.029165808058854555, 0.04545191993876811, 0.0465127601919155, 0.059081972426464485, 0.021889897574099804, 0.16892782652810698, 0.07010420799375543, 0.10195199219930558, 0.044944482449922836, 0.024878025437975605, 0.08957246333480844, 0.12882407364105025, 0.4699170150824132, 12.55304563430048, 58.49515753407633, 77.43798148247504, 71.410247741207, 58.931132901099424, 56.02429574535739, 44.75028599462202, 34.314004298179384, 38.00810821594731, 46.983067758621715, 69.29850639835482, 79.88482659862888, 64.96979436566754, 29.288210599653183, 20.214683855733565, 3.1043760526564816, 0.5030825547873974, 0.044250353164370024, 0.14575503045512786, 0.35842931198496975, 1.2139644978507873, 3.5394666800575876, 7.504186928272248, 6.3132881733679005, 6.958246442579455, 6.864407168280694, 2.471968387403796, 6.628059360288805, 7.899957020436564, 10.205270763366453, 6.532811955098183, 4.663885918355757, 8.313575367773733, 11.452652139048423, 3.8726313316052963, 8.977612045503433, 9.684112302718624, 7.200847979514831, 11.571069475143187, 10.44396169724003, 28.16087434368749, 49.57067105077928, 66.75089559247418, 66.03737723442816, 57.76133698801841, 60.21715256475634, 62.478591165234974, 63.94449856973464, 63.97710915534728, 63.895712129531375, 69.4163187088505, 71.10212202995055, 68.43413368348153, 66.66420336692565, 51.66510689643122, 61.95915560568533, 42.62968401755057, 39.62970233732654, 44.93317827101677, 40.72591850834508, 33.31583561435823, 42.54287019852669, 53.46583566358013, 58.829312093796275, 68.43612624752906, 68.8658218999063, 66.03975419075259, 59.28423643112183, 61.05874807603898, 60.88610103053432, 63.49220222042453, 56.476160633948545, 53.684095951818655, 57.82444007935063, 59.41589078595562, 57.74831079667615, 52.764735529499674, 51.61332768778647, 42.92528952321699, 38.080801502350845, 29.964168340929096, 36.05804304922781, 20.119497737576886, 15.255804811754535, 14.057396188859018, 12.096081664485316, 7.9744433203051175, 8.31073655236152, 8.042470457092408, 7.064181325897095, 6.680337200241705, 2.4674792347415804, 6.214360604363104, 2.1567436764317174, 1.2350316706203646, 0.68661384044155, 0.4201524338174251, 0.16955335264004048, 0.22815039141043542, 0.038170342318593495, 2.7701001446093283, 13.036631711067693, 45.85724553754253, 71.29419265254852, 87.35425887569305, 97.84187655295096, 82.3807248761577, 61.8081678882722, 44.95359813013385, 24.715695804165257, 29.946541209374708, 49.700842749687936, 52.85527952255742, 56.235464388324374, 48.795065495275686, 19.048788739788918, 0.7213577664186879, 0.030271150359523394, 0.04823855327201947, 0.007709909827568599, 0.0715671601374784, 0.019137336001280817, 0.0864659921236096, 0.05877513506059205, 0.048874421570930755, 0.032687512331552086, 0.1040998652517315, 0.06622623261665145, 0.077447451861395, 0.0691979029966939, 0.03916588506751484, 0.0998703474479337, 0.1102923914309471, 0.03615821238547083, 0.011345582127931618, 0.033360562707868316, 0.06347357528284192, 0.03787545209390022, 0.06884822982453531, 0.020437892826814807, 0.044818158381648605, 0.0698774995943231, 0.043091250643614805, 0.06190903604991975, 0.03534512113659613, 0.03368766692977759, 0.04560646668617283, 0.03837186940795472, 0.07155865656151887, 0.052112257708945585, 0.09103157737803075, 0.06893902656532104, 0.006633408822029108, 0.019446925538021232, 0.05322916027639182, 0.014495535532102711, 0.04937036774091182, 0.06257089771210186, 0.04626486180049758, 0.014282602351158859, 0.0863360406290139, 0.03277349804017333, 0.10433433412183678, 0.05717279321904625, 0.05365526987119548, 0.046676078646053235, 0.10074787052168001, 0.040065165038310716, 0.1559928302923518, 0.06120890063504058, 0.0358717797714616, 0.047732617315505786, 0.06365578929563204, 0.10356548828102889, 0.08014164519526305, 0.480016015109516, 16.368555734234473, 65.68718410307362, 85.07494603433918, 80.56169432978477, 67.22130544724004, 66.4506773794851, 58.722364748677904, 44.772349326841294, 39.78018799135762, 34.452063883504565, 61.18235372727918, 82.98936690053633, 77.27617586812666, 32.24824097848708, 17.369512242655603, 3.142418630661503, 0.5370577881413122, 0.06301789469416104, 0.2958866599346361, 0.9891236369167605, 4.045794168787618, 6.57363304207402, 7.7350762678730876, 8.4082035287734, 11.388823409234325, 12.884795781104797, 13.327829453252978, 14.600667991945821, 12.274474982292423, 14.439284032390965, 9.149431470901735, 6.812066570405038, 6.659216707752598, 6.603572493599308, 5.910439673931369, 5.993485566108458, 5.001708874779363, 4.377424438153544, 7.9607910206241, 12.451507237649734, 31.285573667095555, 53.331490562808135, 69.35225855919623, 67.0012761700538, 61.32340215867566, 65.44871576370733, 64.84902066569175, 64.35735940933228, 63.984463599420366, 62.60571126014956, 69.97295010474421, 72.03721507903069, 68.22935458152526, 70.22395041681105, 59.732378990419456, 64.67951151632494, 49.83772170159125, 46.61543184711088, 51.79556492836245, 47.852155162442116, 40.454015885629964, 48.82301238275344, 54.29680547406597, 63.51118256968837, 70.2727839254564, 71.65363081039922, 66.72854592723232, 59.62800079776395, 61.65328525727796, 60.59284110223094, 64.42874654646843, 60.992758120259936, 58.758678051733206, 60.61044862193447, 61.93463294736801, 60.58650647440265, 56.439470783356704, 53.11600731265161, 42.57450019159625, 36.09616848730272, 27.283863752119004, 28.688890087989073, 16.056263485262473, 11.395764043254237, 8.742795432767561, 11.10075277666892, 11.644442312179073, 7.402271493788689, 10.92153674171817, 9.293690362284261, 9.657353893403085, 9.224308536898706, 6.2704676581967265, 5.1538286862834815, 3.3825907495714005, 2.694914927405696, 1.0437943065358748, 0.40555285109627637, 0.1433698157028806, 0.08299760565522217, 2.232761907000696, 11.791820468441134, 47.39547752564954, 73.08533514699629, 94.30657371397942, 102.94710020865165, 82.88831095541678, 67.18603549465057, 51.07627676379297, 32.58438417988439, 38.744046841898275, 56.56595937667355, 61.450373203523704, 64.67145496799101, 57.82162381756691, 24.4184938938387, 1.3691235333681109, 0.06837483345260544, 0.08916933254729356, 0.031949022724743814, 0.06616924333596422, 0.028920263472583987, 0.012124623641401771, 0.03398427702186089, 0.09802930793094058, 0.03859642510031981, 0.15387240617025286, 0.01576901497995301, 0.07095736947150962, 0.11437256039390642, 0.056167697353709134, 0.007754356812520494, 0.03797425828393429, 0.05331865083726664, 0.04958537031686114, 0.0953875303328518, 0.028772023544015906, 0.05008033589429913, 0.10416918854799964, 0.03497701971941898, 0.031231487537884427, 0.07424639943506449, 0.056463085535553195, 0.04870228161434493, 0.0345587280518826, 0.021686319284321322, 0.045972281330896, 0.12790241624198614, 0.12570913715828813, 0.17629985997994102, 0.27763167336102457, 0.19905697674520556, 0.11909384535805834, 0.17274227023365038, 0.10148821789170466, 0.16387259617688196, 0.15274405058833862, 0.17065857236664142, 0.15711206942796707, 0.12519486999559787, 0.14188326805108978, 0.20692286111654776, 0.2293360656908443, 0.18071451825239968, 0.1130566435054906, 0.0985370020592405, 0.2231880109156332, 0.16015225871195718, 0.5101412276346837, 0.20769425036926425, 0.2367183800426222, 0.1402861892335838, 0.15591502640276186, 0.27817630058815407, 0.23371764428673253, 0.9328547853135294, 21.42901239856597, 78.86793644197526, 95.71944282900904, 91.52581722505631, 77.64032087018414, 71.4823095260128, 61.10760904127552, 46.85302157555857, 53.329086149892504, 64.16569279086205, 78.80864589445054, 87.59668488656321, 73.8308600456484, 40.11934749541744, 25.160504348816414, 4.006554532435633, 0.7846793460269129, 0.2168596496865634, 0.3772770361073556, 0.7470582389543134, 2.7540998160839085, 9.99117014869567, 15.840150694693289, 16.936898346870176, 14.827872264769772, 15.423906810822027, 11.296722235218173, 16.839652984373032, 16.05626936881773, 20.347864012564383, 14.757028375902484, 12.03051728586997, 19.58390985765765, 20.455193788774555, 14.490678848758822, 20.557881439885787, 18.696665802309592, 15.254585935223488, 17.408396659358857, 16.330934320726705, 35.6835037662137, 56.70129683709914, 71.37255376385104, 69.3626920638546, 61.58121562773182, 63.819280824353626, 67.68019922317998, 64.86473760297223, 63.55473656808177, 62.81683283467447, 68.00916056479177, 68.8001771127024, 73.33692381458899, 70.4794849887971, 62.365952460996574, 71.2143410405805, 54.84371331430251, 47.66552486727315, 58.0330591817056, 53.00806368550947, 49.5125925156378, 52.45487613062705, 60.16669911722983, 65.81649288054436, 69.08050106417748, 70.45586447561942, 65.51583928446617, 60.74360524454425, 61.40591705999067, 63.245112511419485, 65.73023996045514, 63.39694353841967, 61.42388936012023, 62.06918985612931, 64.1666223925929, 63.822603071889574, 58.25790905183362, 56.16195917129517, 45.36488609929239, 41.080618443027625, 32.45714249149446, 40.02585387999012, 25.27089749613116, 22.215571172775764, 25.1016648738615, 23.41450441268183, 14.753442348972445, 15.330792684708873, 17.702139039193433, 15.324303123258776, 16.276038788980056, 12.04805616409548, 14.959388356054983, 8.078208152324923, 4.045916742855503, 3.2026451537686014, 1.0152687468836386, 0.623640371186118, 0.5783355248070533, 0.19324908033013347, 4.06038268919914, 16.567764089953517, 55.562628853705625, 81.43533168300506, 92.75274245969712, 100.34245814046552, 86.23538709455921, 72.51321823366227, 56.5222994742855, 35.252007745927386, 44.49979559067757, 66.32313759096208, 68.39862054394138, 75.30372573483375, 69.21947063938265, 33.350391695576334, 1.8474706718998573, 0.26824816881168273, 0.17205715780296635, 0.16258673291773568, 0.22954793496718331, 0.1390877366065979, 0.08036412478935334, 0.17765799597386392, 0.2445896729947098, 0.11163431700439223, 0.2788227255786619, 0.25902808613834843, 0.23469036144594993, 0.24283044400715062, 0.3118247821206047, 0.24595991317783636, 0.13886102054628635, 0.1507605110565501, 0.10751507755729461, 0.17456686184290918, 0.09701826339287144, 0.25581702860372685, 0.15439431122954816, 0.1464450152050103, 0.22854046805972056, 0.17370245419442656, 0.15272523546891828, 0.08750509846234515, 0.10802603522015196, 0.18073463572129128, 0.11140840533640116], [0.017630167177788193, 0.04384025863762345, 0.05252331750647676, 0.04585168760029539, 0.025337944408097578, 0.06124787152774873, 0.04951463358837271, 0.08429862213351073, 0.01923933103229971, 0.04615636842866098, 0.06301217584780629, 0.06336864421985323, 0.041648722403953155, 0.048798142196310144, 0.009650393302792744, 0.048249339789993344, 0.08641401305794717, 0.03332811505383542, 0.031566156878045974, 0.02008120803492925, 0.03448231078143563, 0.06468145462173609, 0.04110554308300057, 0.12350204550931532, 0.04292759894123001, 0.023060635055205034, 0.15397303947998633, 0.09427206034982398, 2.2797286125921437, 41.045109225857644, 71.12058070398146, 72.61067344296363, 67.58655655768611, 61.920551638449396, 33.44727816120271, 22.896131815448886, 16.163622679248935, 12.578334135393943, 37.8727158423393, 60.654645889036125, 72.1954748707433, 28.657618991790283, 22.632968233477687, 4.344957999644741, 0.4598106299677203, 0.01251979860582299, 0.14600897328026835, 0.3565417326265766, 1.2192158160671112, 4.4390522280047024, 6.844053499160275, 5.585582112112354, 6.0878504380103085, 9.745916108931265, 10.786854317111354, 7.774279377152843, 10.777742651201065, 14.213516327642626, 9.487070075927242, 6.220185814365265, 4.587097187196055, 2.950478181723626, 7.15643939472014, 11.209872134270208, 13.787572422335225, 11.30470916148155, 14.04460632031964, 23.27323240618552, 39.82917839480985, 55.99163809130269, 69.57471186114897, 67.2641847979638, 64.33864185886999, 71.25779305734943, 72.643323252278, 65.69168698403143, 68.70873881924537, 65.13759728400939, 69.01822167058145, 67.2600741540232, 71.3263874669229, 67.99979394482028, 72.39626884460449, 65.65827231253347, 62.33673080321282, 47.53534140125398, 28.301201058972268, 43.55752068181192, 46.231059182074766, 45.217404980813306, 50.26356166408908, 58.11283234627017, 63.70532420373733, 71.03244504620953, 65.80039939572735, 63.2716473456352, 59.62651029709847, 63.164817671622004, 58.95979365994854, 62.40462703089561, 60.81018747821931, 59.623395935181655, 58.588490332326586, 63.4539238099129, 63.850110653908025, 60.929466755159446, 62.09933719327373, 58.200285511632124, 55.59589055276687, 42.189150856387236, 52.19045739020071, 40.09275774801932, 24.92554653075434, 17.506279407009004, 3.6878842644153105, 11.286852571272082, 22.47762864635837, 10.669931404052242, 10.05315536452878, 8.233241304274529, 8.93289702553903, 5.361734407563364, 8.010042261692787, 3.993764663896253, 1.6525084044664138, 0.3784338595165361, 0.15605739618261016, 0.18993490736090368, 0.02075021346700528, 0.08282034823130216, 1.4163374708544825, 12.060713652641544, 31.460938915129635, 42.34766167979087, 45.35946930608442, 40.53437740572038, 31.15777107977098, 18.335289993593772, 21.567656417046827, 33.198568513316495, 39.16362277923092, 44.89226010537917, 58.52966654685236, 56.22167333479851, 26.645821602113788, 3.2945136822039083, 0.08838943205773832, 0.04244753760435889, 0.05603707936261931, 0.04182537844885261, 0.03572900779545307, 0.055408534864264156, 0.03707992724112926, 0.04489878913567913, 0.04018460580658528, 0.06357322416959271, 0.05071238524490788, 0.05985186397728901, 0.09151845689742796, 0.022225480474111055, 0.04551337168161427, 0.04797550166145929, 0.056293492821315606, 0.061990651226932966, 0.055291852012517, 0.02262490531129222, 0.03304861936598055, 0.04016193726490583, 0.029037647294781865, 0.06740868932777835, 0.029165346490880175, 0.030658838729704582, 0.027217364930097136, 0.03609800553550163, 0.026165524294840235, 0.1177712481829428, 0.041488663653933236, 0.02963452937922651, 0.11650097481305562, 0.09028058138585861, 0.10002445369478195, 0.03310755834043507, 0.04603823000985769, 0.07709001055768422, 0.04495866273740127, 0.03520251769993094, 0.007546847055275595, 0.04983116962736653, 0.05498941582176955, 0.018334835917959293, 0.04608387735882594, 0.050556972818148714, 0.03952295098814272, 0.04067808900388979, 0.03891387278394353, 0.06302710307101089, 0.049693193361764, 0.0958287356902034, 0.06409521732899932, 0.10970074938790453, 0.051580010462672486, 0.06760880681535891, 0.07753274043000515, 0.10390003121668294, 3.397508749077397, 50.60737702154344, 80.53762666640743, 83.21423638251521, 75.55280408551617, 68.77891786636846, 40.315736647575136, 30.12494629429233, 26.97011140085036, 23.767496155154323, 43.28217421808551, 63.33624486000308, 79.47150291935091, 36.111991328577844, 19.1275675835148, 4.355245886310454, 0.2574924169288528, 0.029173106961553136, 0.6118664578084023, 0.8944775801031821, 4.854017909496061, 6.562679333071555, 12.742848146346308, 10.246817488824169, 6.9620545737205015, 11.823010175458847, 15.895981711726035, 17.326407355646936, 19.88236692643935, 20.555973206796956, 11.93315621345274, 8.667100552589662, 6.328000003291715, 5.8499621191332425, 5.306417711319463, 7.517417573159741, 9.056216343756645, 9.937108120610638, 12.647720863742213, 22.73936056321667, 39.74550247192383, 59.41924833482312, 70.14118840617519, 69.26913569050451, 66.39387361464962, 71.96778128224035, 72.57344230528801, 67.5718790485013, 68.0586765658471, 66.5522510774674, 70.74258189047538, 68.72940186531314, 71.60641331826487, 66.95130517405849, 72.63736909435642, 70.46535661143642, 63.6028483606154, 50.01255742965206, 36.37850853704637, 51.19768588773666, 52.67137527465821, 50.88768528353784, 55.94781737173758, 61.752599670041, 65.45384230152254, 70.29168974968695, 66.82857421136671, 61.988977386105454, 60.31318787605532, 63.09266174993208, 59.65428852265882, 61.934103427394746, 60.691963318855535, 63.5761409421121, 64.01748211153092, 67.11596627389231, 64.52628412554341, 64.46789180078815, 62.42807495978571, 60.15442994333083, 55.34717306014031, 44.630328147642075, 42.603262932069846, 33.9841761127595, 22.80477393058039, 19.142578494164255, 7.580336313093863, 8.503878962609077, 10.275497859524144, 13.319810167435678, 13.095962462886689, 8.090151769499625, 9.829221367835999, 8.957504995407598, 9.315725257319789, 4.991102295537149, 5.212192573855001, 2.1071975221557, 0.9777561178611172, 0.12582812593468737, 0.111354541694445, 0.09037511663571482, 1.6788913694120224, 14.343253624054695, 41.72233781506939, 56.88769179005777, 55.900007601707216, 46.6953383722613, 33.12174104875134, 26.743933808419015, 28.173265111061838, 35.10654272571687, 45.9254280982479, 51.57948155556956, 68.44459072236093, 64.3465611242479, 33.74137747672297, 4.3933982906803015, 0.15046339151599716, 0.06541090822147747, 0.07505465283869736, 0.022702709200882146, 0.06196713615809718, 0.06092893380311228, 0.07409365682472145, 0.066037729022003, 0.02587538956093692, 0.11835070942798931, 0.009923540994585043, 0.08831302244817058, 0.06388637409996122, 0.03363690977435439, 0.05199516116971931, 0.05540546285168779, 0.04399372903149455, 0.02107454062018904, 0.061313460145386, 0.031052064000358506, 0.04519546434523598, 0.053923530879640774, 0.00316355936510879, 0.10176885888100633, 0.03663261616302114, 0.030634316255248366, 0.03719161136917049, 0.02639781172958113, 0.030287764891381228, 0.01434486710481466, 0.09960744139407912, 0.1506965273931142, 0.19062869190689058, 0.12812661953390608, 0.16077449064581625, 0.19516344212235945, 0.11368973856611599, 0.20522357084818427, 0.13663754227661318, 0.07106734905391932, 0.1583853382016382, 0.1488212360850265, 0.25622501638868167, 0.17803074371430183, 0.14214683294055924, 0.2069132084087018, 0.14331672580972796, 0.16844925140180897, 0.18924136796305258, 0.1665220959412475, 0.1139024658609302, 0.20403302424857694, 0.18764173041187948, 0.21119090548205763, 0.12104170051433387, 0.12383581469616584, 0.17116218324630492, 0.21697218800264023, 4.311509497704045, 60.485603501719815, 88.93730394301876, 92.95463469720657, 87.85418848837577, 78.45845668546616, 45.880218859641786, 33.922351714103456, 24.595841899994884, 21.743443319874427, 50.37892641559724, 71.34472846984863, 81.89763792099492, 38.84517338968093, 29.485160650745517, 6.084778731869114, 0.9416281467964573, 0.20100161433219912, 0.5194166831431851, 0.39307992845293016, 4.355030155950978, 12.823692117967914, 16.897957055799424, 19.044697707699193, 19.340777820156468, 22.834321145088445, 21.36390301489061, 16.661342036339544, 21.414538852630123, 26.070425587315714, 18.292026250593125, 16.327386536905845, 13.577052931631766, 13.593979920110396, 15.2149905889265, 19.699619777740974, 23.29583114193332, 18.732426051170595, 18.758994225532778, 28.806692592559326, 44.89861042268815, 60.077355369444824, 73.19063509664228, 71.42647850898005, 67.09777432103311, 74.07549827329575, 75.53993871135097, 69.67755640706709, 72.62999503843247, 69.03193427670386, 72.21171348325669, 73.68516752796789, 71.9899034500122, 70.40507762662827, 72.791212297255, 71.31501259342318, 67.0146357628607, 53.802477005989324, 38.7529702340403, 58.325793512405895, 57.67437804129816, 58.96965057619157, 61.56385913971932, 66.31829738616943, 67.90006376081898, 69.27874549742668, 66.68411331792032, 63.18891279159054, 60.807971339071955, 62.38981223875477, 60.56011284551313, 65.36428282337805, 61.73725928029707, 64.6671482055418, 64.74957289234285, 67.67525703676286, 66.69793575040757, 66.80444379006663, 67.66207002824353, 63.293036030184844, 61.029145948348514, 47.35192744962631, 54.910370073010846, 44.675376569071126, 28.567422128492787, 23.8441784920231, 10.578796113691023, 23.542185406531058, 34.35700916474865, 25.850153123178792, 16.73536696741658, 21.23883039720597, 22.60048120252548, 16.495288495094545, 21.00937174212548, 11.927406018780125, 5.018239703870589, 1.4552348804089332, 0.728226020451515, 0.3559186579960008, 0.26812847523439315, 0.3109805838715646, 1.9991799828506287, 16.77899549084325, 45.15587475992019, 56.11119193415488, 54.04931568330335, 49.31445006401309, 40.04043332992062, 28.488405981371482, 33.25858862169328, 43.609739195915964, 55.773087547671416, 61.774984636614406, 76.18488619404455, 75.69404079068092, 43.76621823157034, 7.327737144885525, 0.24726091433436642, 0.16720385290682319, 0.21516780579282394, 0.116746237862014, 0.11591227454764229, 0.19484966783033264, 0.14627834511620386, 0.22190184122131718, 0.18295230704449839, 0.26723297973794324, 0.17261496174239344, 0.2612650015902135, 0.3181526990186784, 0.2227641191453703, 0.11384106391379911, 0.13262180130808585, 0.13901825243186566, 0.19368932041670048, 0.1960847854253746, 0.1105635712343839, 0.11864659556698416, 0.14250168486708595, 0.10324510265021555, 0.20942179396027522, 0.1497759501780233, 0.10436998019295354, 0.2010056745981978, 0.14232143970026126, 0.1177845091649121, 0.41209251469662117], [0.05895587818456754, 0.02843525512294183, 0.041350369461842125, 0.06675287976019806, 0.06587101296792108, 0.04597037377196454, 0.009310132478393856, 0.08217581547796726, 0.004609840717391982, 0.021491118165994846, 0.04187962896521053, 0.011308067759889509, 0.07312136867474164, 0.01687189526555519, 0.04635871140166156, 0.1008980084330805, 0.042842854295046105, 0.03020792895357215, 0.013018575470684277, 0.02158819874297948, 0.011121400861039517, 0.06900249694984767, 0.02764022439688204, 0.03714367724774826, 0.013518747573177661, 0.059946261331318855, 0.07419936163651367, 0.19158123031018243, 14.022614571356005, 71.47352341682681, 78.43042742821478, 61.31518871553483, 57.53048981389692, 50.32576653265184, 36.14650818609422, 37.02262447726342, 39.07893488484044, 38.890645427088586, 19.99205404712308, 59.90233136761574, 48.3613690253227, 25.79780517085906, 5.334127785698061, 0.6760787218809129, 0.046167331146857435, 0.16925353646999405, 0.3382355713796231, 1.9953853348570487, 4.115491990120181, 4.774775735793575, 8.462980408822338, 6.569945523815771, 6.126184742296896, 8.121477288584556, 18.339771301515643, 26.643883951248664, 23.951949534877656, 12.281065544774457, 11.463319024732037, 12.4894267512906, 14.382643045917636, 12.591282859925302, 17.662603509041574, 24.388354401434622, 21.46777718297897, 29.10318455388469, 39.06913288177983, 53.80576002982355, 64.94532269816246, 64.88152534730973, 65.03334852956957, 64.8038310389365, 63.92588300089683, 61.31715382299116, 62.89600587660267, 69.03827282690233, 66.65020835015082, 66.69708851845034, 63.72088032384073, 66.14380682668379, 67.29330447412306, 68.94423792439123, 71.45410768447384, 74.34007783089915, 62.20477442587576, 57.25846559770646, 22.547411534094042, 38.45024954888129, 42.45030618483021, 48.972760631192116, 52.4938605677697, 60.11151529127552, 62.92945584943218, 64.1729687875317, 62.00276059489097, 62.484725752184474, 60.86896419525147, 67.19960689544678, 62.30011940002442, 57.720603173778905, 58.37739621439288, 62.353687209467736, 60.73636454920615, 62.331192416529504, 60.82447275038689, 62.88058703945529, 62.361406433966856, 62.83040031310051, 58.77234358941355, 58.547023034864864, 51.312968269471206, 41.48705836265318, 35.98816210223783, 36.86603561524422, 29.051664221671324, 26.366025209426883, 10.025195729347969, 14.800149932984384, 15.04219743513292, 7.017789002387755, 8.504815428487717, 5.4688901285971365, 4.880159035805733, 2.739281346721034, 5.125475343196623, 3.2520584377550312, 1.4576039919930122, 0.2646381173643374, 0.07410733149416986, 0.0503035087979609, 0.04322717762401989, 1.4684315722796226, 12.775697015946912, 37.45333602351528, 38.555977036876065, 30.66872016076119, 38.653906852968284, 31.06974328717878, 25.31061149412586, 27.863962688753684, 37.959106045384566, 44.88805924692462, 54.51730151330271, 61.37176498290032, 45.254200735399806, 10.632771849632265, 0.10241573586338952, 0.022305684134123788, 0.05056315131725804, 0.061940104745688944, 0.043824676409243576, 0.06479501949563142, 0.03481599569861447, 0.013869287382300585, 0.09106238177346607, 0.06499976415427462, 0.017295869390269922, 0.040690963111457326, 0.03240613206740349, 0.06080552469938994, 0.11471295624130196, 0.025547270272527973, 0.03273295283678078, 0.061365420058850324, 0.028086646812998002, 0.005031159389839178, 0.08357117568413097, 0.025891716809823148, 0.027095865300526063, 0.06146547497220098, 0.04978942549637249, 0.04743935119721198, 0.04193914250560826, 0.01995546044781804, 0.026051059267633868, 0.04819163804753654, 0.056588413689525864, 0.02910460146414417, 0.060859675624317704, 0.10454362168187097, 0.10367861648480739, 0.0037917153132448517, 0.022759269472331773, 0.07751587117391248, 0.038678599521517754, 0.03542287140003136, 0.018192012231015874, 0.03890417794126176, 0.07268970877292656, 0.030853840665170745, 0.04258994951904301, 0.02577147931010733, 0.0338847890135742, 0.04886049026202771, 0.0753482636965571, 0.022079324304697015, 0.042584521786099484, 0.04936005236701139, 0.05739097505988133, 0.05132651962940732, 0.03658937433013513, 0.023428832233372717, 0.1265848292818954, 0.24075498924620692, 19.54383304042201, 80.49335095190233, 86.52861564390122, 70.18680557127922, 66.82586777594783, 57.86715469052715, 44.57150828453803, 44.1316262368233, 38.813464949207926, 34.05799904177266, 27.0769920656758, 68.55246374683996, 53.09891754581083, 22.9332511655746, 5.176782886828146, 0.5472177074801537, 0.049018698909710494, 0.22463980881917864, 0.862015676834891, 4.946698613705174, 9.367616253514445, 10.238138264225377, 11.180064082145693, 14.223777248013405, 13.23235700207372, 13.939634869175574, 17.503971092162594, 24.928188247065393, 15.464227795600893, 16.65332667289242, 10.657818144367589, 8.126748954096149, 13.361103900017278, 13.83451730974259, 17.856399974515362, 22.126658885709702, 23.97233605384827, 29.41799790628495, 38.74282698477469, 54.10920243109427, 67.38469569913804, 68.62867539928806, 67.73655583781581, 67.25040158917828, 65.34532600833525, 64.72039830300116, 65.15868002368559, 70.86545405849334, 67.93067393764373, 66.56390836161953, 64.260429797634, 68.80158132122409, 67.93570241620465, 70.44368943860455, 73.18573213392689, 75.57120784636467, 64.08412710312875, 59.28466789184078, 28.943132239003337, 42.773403583034394, 49.0438888918969, 52.76324895120437, 56.95246973345357, 63.805376022092766, 63.8805913925171, 64.83309976516232, 61.22920643898749, 61.36578729075771, 61.630774774859034, 67.57231050922026, 61.72542941185736, 59.965359933914684, 59.344586018593084, 61.552295992451334, 60.20694655756797, 62.84895704638574, 62.65289345095235, 66.15411481549664, 65.23084771248602, 64.17225491616034, 60.76243262137137, 58.6522602265881, 52.05395106346377, 41.958084029536096, 35.586005410840436, 32.07399948950737, 26.582149767106582, 24.384455565483343, 12.08267794501397, 19.004246304112097, 14.289041565310571, 17.232831370445993, 12.63209512156825, 7.791184302299254, 9.107953386922038, 8.031093132111335, 8.816507554823353, 8.230275992424257, 3.5369399382222086, 1.2295474616750595, 0.20104376448979303, 0.029576385220993432, 0.04978045843721879, 1.727848432717785, 14.248710774606275, 36.583452378549886, 36.30029647581039, 29.537791013717655, 32.6816060081605, 28.153031564527943, 34.31559285809917, 34.816667802872196, 46.60232720836517, 51.463720644674, 61.085482951133486, 70.99707311199558, 54.526632831942656, 14.262458682060243, 0.1615081270856242, 0.04787471896458057, 0.07860012307402589, 0.07670941041602243, 0.01061232968969571, 0.06925495356441506, 0.06093370653088055, 0.043710713169627616, 0.05326284899286205, 0.07356659599369572, 0.05802953232740683, 0.04173949999254077, 0.04261664768320419, 0.018737918824978897, 0.06150066139056318, 0.06564454205574528, 0.06505534383318116, 0.12483933625081856, 0.026095758582795822, 0.02549110262113954, 0.026966239393298185, 0.02115533033746385, 0.03219108735661834, 0.07400299031888286, 0.08029133111478821, 0.07602817439023526, 0.040606793031216636, 0.02675344698101042, 0.005568151114388339, 0.014084923896007242, 0.24664920844858695, 0.06860302806261086, 0.13212149992825525, 0.17785579987591316, 0.2826755349674533, 0.1620930965028463, 0.1309051208438412, 0.19626142997895518, 0.1164272158677059, 0.1163170064589189, 0.09906001794602602, 0.11256286919477487, 0.1698216059876065, 0.23545346162732572, 0.1958776965376831, 0.23179185246267628, 0.14571520920482375, 0.18873706760425724, 0.16485818361322727, 0.09882368748226474, 0.16117449579460008, 0.2123501956943543, 0.19158119966666545, 0.1988712617106015, 0.1071686755805727, 0.2065636884541281, 0.30798389305991514, 0.2817394368110165, 27.551857732957412, 91.58645706792032, 96.46098259956607, 80.1870922888479, 75.66050452570762, 67.0266225261073, 49.33490130209154, 48.877254839866396, 53.87471529745287, 56.37832495474047, 30.874689702064764, 73.888212942308, 60.13521032948648, 31.738036717137984, 6.4083683875299275, 0.9474798940843152, 0.2398880075422987, 0.27361538080919173, 0.6109871114453962, 5.834328532218934, 10.563682240824546, 18.190068160333944, 20.50727894229274, 18.210858683432303, 14.267330265814259, 20.28261930711808, 32.42297276373833, 39.16778833635392, 34.941963995656664, 18.535936878573512, 21.983351169093964, 24.370670395512736, 22.79305781087568, 19.17180995787344, 24.19853129694539, 31.472453032770467, 27.101755949758715, 34.13313204242338, 43.21266197389172, 56.08165256438717, 69.05039295073479, 71.20131092686808, 70.62054126493393, 70.72846920259538, 67.9335137336485, 65.57221158858269, 67.9425665640062, 75.0041429458126, 70.4469685400686, 71.04391405659338, 68.34979488003638, 72.37614708562052, 71.68009111958166, 72.64254662298387, 75.45229727222075, 75.73433137709095, 63.91793235655754, 61.47535477915118, 33.14370632171631, 47.234836855242335, 53.95102500915528, 57.284400309285815, 61.60726801041634, 67.40953999180948, 66.07761290765578, 62.68038142111994, 62.477128121160696, 62.74477497223885, 62.56732694564327, 68.03034920846262, 63.33661748516945, 59.92910546641196, 61.885591553103545, 62.21292903346401, 62.42427418308874, 65.06053055486372, 64.14659477049305, 66.30752655767625, 65.78198386776832, 67.46290776037401, 61.84926648293773, 60.6313705444336, 55.82724371264058, 42.99317790615944, 38.89416379313315, 39.536777465574204, 34.84302613043016, 35.699679620804325, 17.753618186519994, 20.876599511792584, 23.91328084853388, 20.43386786214767, 18.109345782187678, 12.887560071483737, 11.770668106694377, 13.359055442194785, 15.814676861609183, 8.936448731730062, 3.321553521579312, 1.4269132840056575, 0.21855529337640733, 0.09897769413768284, 0.25140738054629297, 2.359355914015924, 17.846337133838286, 51.72823352198447, 55.528076694857695, 45.49727785971857, 54.69180383989888, 44.40288166845999, 37.23653877935102, 39.8630049151759, 53.05828963556598, 59.53769999165689, 69.34674370673396, 80.28260984728414, 66.40051026498118, 20.660835812168738, 0.22124482889569577, 0.1695286233218447, 0.21113324970487626, 0.16118470008575148, 0.16214226402582663, 0.1843997842121509, 0.1861807088097257, 0.15052071021449182, 0.1959890550783565, 0.19322249707916092, 0.10352644844040756, 0.14937091949245623, 0.19191233351105647, 0.1613067991791233, 0.19182639376771068, 0.11184211069297408, 0.14814864153102522, 0.22166001790713882, 0.10121162950752244, 0.12705775067931221, 0.12564639455728954, 0.14851873860724513, 0.062059331009344715, 0.19599924404774943, 0.1847748915033956, 0.1795206315094425, 0.21170087489149264, 0.13177103002465543, 0.11557305847565014, 0.08932219007082524], [0.04229509759874594, 0.06027405120192036, 0.015883801764087574, 0.013602188912280386, 0.051337129947158604, 0.07748066177291256, 0.05835623052271624, 0.0589192170469511, 0.03703501533656832, 0.05520593142136932, 0.01988919001192816, 0.03543119877576828, 0.00215255169502099, 0.04447614608873283, 0.0734443360218598, 0.01807040917957502, 0.010548868881268127, 0.059769819791038195, 0.07350694838791125, 0.06500568601392931, 0.07273483901254593, 0.018601204689231612, 0.08054502113091369, 0.02547061934526409, 0.034594109822665496, 0.01824177347213751, 0.029021019356385357, 2.966910706412408, 39.6737152530301, 72.96978212171986, 67.34802153802687, 67.89443123725154, 48.97323523798297, 29.474211354409498, 15.759065497306088, 15.905579751537694, 23.9619319669662, 40.40071087498819, 33.52618055958902, 44.29852701002552, 26.132728515132783, 6.436410392484357, 0.3034124012675978, 0.06025570339613384, 0.03701760598848905, 0.35018776873907737, 1.7421828570865816, 4.733733034903004, 10.42737203259622, 7.541115553148332, 8.406345305904265, 9.206206798553467, 6.221261524385022, 10.448544006193838, 12.30848781524166, 22.492435593758863, 22.809455279381048, 42.96474072241014, 23.870497595879343, 25.50007374055924, 34.51835586178687, 39.88946522435835, 45.93842683299896, 49.40821824535247, 54.596305893313506, 58.10815295865459, 59.673849382708156, 65.34435718290268, 65.50670016196467, 61.359178097017356, 62.51681858493436, 60.98914561733123, 57.73585727137905, 64.4784547436622, 63.68576726605816, 65.66969817684543, 64.08348775679066, 64.39334323329311, 62.727791109392726, 63.48987233254218, 63.71777772903443, 65.36959763496154, 66.5216330559023, 70.30533175314628, 64.99267747325283, 62.95126030522009, 31.115860554479788, 33.80842255007836, 41.26382843140633, 46.32527843598397, 59.71864677244618, 64.64887780527916, 61.81895832861624, 61.84583833140712, 67.36981422670426, 63.88844397760207, 65.44434232096519, 66.42673523195329, 63.59670592892555, 61.06214092623804, 59.34877510993712, 62.36988267590923, 58.54071978599795, 60.2359446402519, 58.219485513625614, 61.68038883516866, 59.49919408367526, 61.55374726941509, 60.85005444865073, 62.812686889402336, 58.3676883482164, 58.31337528844034, 52.909961285129675, 43.11608537550896, 35.219887456586285, 33.47037307677731, 20.370247017952707, 29.839303608863588, 30.649853560232348, 11.409993421646858, 10.417252317551645, 6.105038754401669, 7.3937334745161, 2.428386442122921, 6.986333064494595, 5.877538832925982, 3.1655336483832333, 1.0495288117278008, 0.11664947329629814, 0.07806064395774757, 0.05730207055626858, 0.15545206414836069, 1.8472466065037636, 19.164016208341046, 41.990353368943744, 50.08904364801223, 53.97274317279939, 43.15148868868428, 18.584813533290742, 16.884358198412006, 24.619576161907567, 34.432526557676255, 50.88257051283314, 58.745126262787856, 51.90259072088426, 27.007330771415468, 2.0537981294816543, 0.052688394132400715, 0.034391123335808516, 0.05617173080663047, 0.01648668327458924, 0.03627106479759659, 0.1037632002525272, 0.03872737633965669, 0.060039655110167886, 0.014450795039714826, 0.00560620796844183, 0.02799702218673643, 0.05461682895979574, 0.0183210923005977, 0.05046911785499223, 0.05293578690578861, 0.07980812881742755, 0.035795224605188254, 0.017729230007276903, 0.03485125106488986, 0.095709394513359, 0.06537379126154608, 0.012855663043146413, 0.08790219247701668, 0.07722750801833407, 0.021170998750735196, 0.0535966411623503, 0.02293287265685297, 0.0292153203214008, 0.017554125290424112, 0.03821083389583134, 0.036623809982331536, 0.03393281889598697, 0.023803035540866758, 0.06793846211005604, 0.04364025606323154, 0.026625799495846997, 0.07958846842689861, 0.037197893290149595, 0.026729531631234194, 0.06392774667831198, 0.037325523538334716, 0.012088846377727967, 0.04300934052275073, 0.03505720997289304, 0.05702696455221984, 0.030719700584849043, 0.05492721714319722, 0.043616285172080806, 0.02570781165794019, 0.05076136890678637, 0.04414218537990124, 0.041250456274757465, 0.04165017797100929, 0.05601264115783477, 0.1002851687371731, 0.026333598239767938, 3.841430102625201, 48.25711634851272, 82.57179137199157, 75.09911921716507, 75.62113177391791, 57.88772752208095, 41.844307837947724, 23.383103878267352, 25.162377280573693, 33.09774006566694, 42.780942378505586, 32.33859081422129, 51.481661565842174, 29.69272855789431, 6.5577430302096955, 0.4014337189014881, 0.17042174394572937, 0.1685156559030856, 1.021174242900264, 3.3124259210401967, 9.167168428820949, 12.776906086552529, 12.124477663347799, 14.35592778267399, 16.463027000427246, 15.884625469484638, 13.926968555296622, 13.137468003457593, 16.05928174911007, 18.98625046976151, 12.177834645394357, 18.35532153806379, 22.946028286410918, 28.948531381545532, 35.143334557933194, 43.016041401893865, 49.35361100781349, 53.49740289872693, 56.137075654922, 60.034781963594504, 64.01178290767055, 67.46656340937461, 62.850643665559836, 66.00636697584584, 63.61115201827019, 61.833765276016734, 64.89157445969121, 64.52766087747389, 66.80833478127757, 66.8102724321427, 66.27699482825496, 64.59753005735337, 65.59328648351854, 66.39678401331749, 65.54698682600453, 67.46039744346373, 73.25598962845342, 66.66497999621977, 64.47106107588738, 36.116815843889796, 39.54637550538586, 47.87067267202562, 50.04821961925876, 64.33606878403695, 66.56063710489582, 64.31538612611833, 63.53270461482387, 67.42162089194021, 65.99830258277156, 67.18453714924475, 69.2844956920993, 65.39576376638105, 60.27934566620858, 59.14475694779427, 62.469891348192775, 60.14230981949837, 60.176650170357, 60.22135734558106, 61.73087366165654, 60.93641719510479, 62.697235845750384, 64.28623507099768, 63.00405540773946, 58.846464618559814, 57.97171723458075, 52.050177743358, 47.14894871557913, 37.328832149505615, 33.21244978135632, 24.336257480805923, 19.71936498918841, 14.321961037574278, 9.893420761631383, 9.42490246988112, 6.73092596953915, 9.634465882855078, 8.546460213199738, 13.574239611625673, 12.545282283136922, 8.514250689937223, 2.8082042547964283, 1.244209036231041, 0.16308484328610284, 0.149099693723744, 0.0846785404569199, 1.5314752151889186, 17.80193982585784, 42.93375792041902, 47.269459616753366, 49.81154772543138, 42.51506059400497, 20.977926100454024, 23.32676491429729, 32.435185063269834, 40.33608590402911, 56.96478597579464, 67.18132865044379, 60.113492165842366, 33.43860972312189, 3.0375185176249477, 0.0916625886795021, 0.0478513149784938, 0.045128983235166925, 0.0127856464373068, 0.05411889862209078, 0.07396378959979742, 0.018364556298981753, 0.021838696087680517, 0.02662364487355996, 0.051274919777267405, 0.033049638262919845, 0.007514252408122223, 0.05911511722050848, 0.0064012860961919354, 0.03676105463396638, 0.03048238569810506, 0.04052273403372496, 0.04587146032962107, 0.015946954222125633, 0.05786413394455468, 0.02916803354427459, 0.04761206571974101, 0.06743282875827245, 0.048904819939766205, 0.0798370946018446, 0.01717617581298034, 0.03771568445729152, 0.02586342518277947, 0.07744280170769462, 0.1700730207225969, 0.1699990166291114, 0.11340610217303039, 0.07364966290732546, 0.1254741243657566, 0.14719285491493442, 0.13054138229739282, 0.24178574522656782, 0.20603784570290198, 0.2177889296604741, 0.16984137105605296, 0.13717452394625834, 0.1171414243177541, 0.11248007807279788, 0.09163144720538009, 0.13360581060330715, 0.07466580193009108, 0.17734006948528752, 0.1521150311154704, 0.1281125235160993, 0.19859758446053152, 0.1919844683500067, 0.23943261423658943, 0.11989086791272126, 0.14363160326836572, 0.1509786928973852, 0.08448116556410828, 5.827920359949912, 59.54551335304015, 90.81593882653021, 84.97351354168308, 84.06900713520666, 66.27560630921396, 46.471951546207556, 26.816444704609534, 23.735244466412453, 38.288663587262555, 55.64048005688576, 46.57217594885057, 58.62545867120066, 33.796043549814534, 8.8775170810761, 0.8169025362979981, 0.386635443616298, 0.23694554043392982, 0.6285091970236071, 3.4107364521872614, 13.125089003193764, 24.121552821128603, 16.98867363314475, 25.86962376871417, 20.46070864123683, 18.422978501166067, 18.049502180468654, 27.76214776500579, 31.727791486247895, 36.769541386635076, 56.499373220628314, 35.0370853947055, 33.15717966325822, 41.534809297130955, 44.4142565419597, 50.882833311634684, 53.74526923702609, 57.550823380870206, 60.93126320069837, 59.59660614690473, 64.6405819923647, 70.55187625269737, 66.5575070534983, 68.60378403817454, 65.3819570233745, 62.019160024581424, 67.4319367254934, 68.33203438789614, 70.45054574166575, 70.66570343509798, 68.624462773723, 66.75214290618896, 69.85567908133231, 68.91021528551656, 70.08443955452212, 70.60569117146154, 74.63719737145209, 65.35719902284684, 65.45386975811374, 40.01591459397347, 44.04284338797293, 53.94097197440363, 56.65786050981092, 67.71160956351989, 68.99395004395517, 64.90103521654683, 63.50077652162122, 70.13157075451267, 66.99887567950834, 71.99916808835923, 71.36899225173458, 66.88194197993126, 63.4584580698321, 61.25274458239156, 62.22503346781578, 60.36118591985395, 61.71933797097976, 59.9876154622724, 64.00620529728552, 63.56855507819884, 64.91866234810122, 64.35237015447309, 64.50533474645307, 60.8752792112289, 58.83761182908089, 54.53928639811855, 48.535416356978885, 38.345106494042184, 38.25394668886739, 27.82990278736238, 37.88279633368216, 42.36764223344865, 17.70270189931316, 22.968740770893714, 16.335257753249138, 20.059034401370635, 13.372925923716638, 15.860290104343047, 15.13103029420299, 10.983832805387436, 1.4952850990718412, 0.5078533213705786, 0.4591106707530637, 0.27259914985587524, 0.14032253244471166, 2.7380394262652246, 23.581579731356715, 55.157165604252974, 66.88534659724083, 68.67626943895894, 54.819249491537775, 29.596069589737926, 26.044361437520674, 38.157911377568404, 48.64009657213765, 67.07542465579125, 76.0074773911507, 69.78462142329063, 43.05368438843758, 6.09655466771895, 0.1598168347751902, 0.28584618902494835, 0.09789052344257794, 0.0877385790790281, 0.19704444844636226, 0.24560565879989057, 0.11519978979542372, 0.1476751685503029, 0.1305408920011213, 0.15524238588348513, 0.10325119304921358, 0.1536897554873459, 0.1510845049614868, 0.11285562969503865, 0.1623442660897009, 0.12764539374339004, 0.13344176053520174, 0.23893992777072617, 0.09726898098785071, 0.22214495156320835, 0.1607956499942849, 0.21796676931121658, 0.14801770178300722, 0.2355341766510279, 0.17971699516619408, 0.17732249542830453, 0.1014410115538105, 0.11110010091215373, 0.08533643378365426], [0.02339287015098718, 0.04817445469539493, 0.14048403910090848, 0.03345554994959985, 0.021698865889301224, 0.09549293637035355, 0.05383140497630643, 0.003790878122785099, 0.12070597780327644, 0.02248060498987475, 0.0695960465518217, 0.04054157979666226, 0.02335053421707163, 0.019322953359674544, 0.06298613651926, 0.022462261014527852, 0.01733980836316703, 0.03924966444291415, 0.10389264612909287, 0.07994135150745993, 0.03323232725022301, 0.05809223279356957, 0.05814764010269315, 0.07605543179858117, 0.0694950685025223, 0.06207322401385154, 0.198345786681579, 10.740149674877044, 58.616872602893466, 67.96496329769012, 70.55441794856903, 52.80307277556389, 45.43507299115581, 29.355351771077803, 30.910936324827134, 36.188842327364036, 44.55293586177211, 41.3078962602923, 43.10529885753509, 30.26206058840598, 7.134142191179338, 0.8124627809851401, 0.07575231378958111, 0.03479300923044643, 0.18757439128333525, 0.8366335904405964, 3.454429939869912, 6.342927563575007, 7.404958807652997, 11.690550754147193, 9.38059929878481, 18.528084293488536, 21.10837040408965, 14.40024075969573, 15.359062187133299, 25.366285616351714, 23.460674631980158, 27.729629355092204, 36.143487961061545, 36.996854505231305, 58.0470581208506, 56.490190952054924, 57.01743595061764, 59.04064547631049, 62.77767973561441, 61.055496431166134, 62.99804633663547, 63.46308254426526, 65.00796687218451, 62.08073339154644, 61.54028961735388, 58.81901587209394, 52.979226420002604, 51.92412845550045, 50.59215038053451, 56.67057291153939, 54.437638175102975, 56.611227450832246, 54.977595575394176, 57.91156376561811, 58.188443876081905, 65.63451059402959, 61.99062478157782, 66.45223848281368, 66.486253276948, 65.02799449428436, 40.40403704489432, 42.077445676249845, 60.187193501380186, 50.50916479479883, 64.82222695504466, 58.834521001385106, 64.04707639448105, 61.555022039721095, 64.74055144094652, 60.01442486240018, 63.67117212664697, 64.01018650301042, 65.33414333097397, 61.82213937082599, 60.653367196359945, 60.3531176044095, 59.292846033650065, 57.83991382968042, 58.783314458785526, 61.01307599775253, 59.572640465151885, 59.26979034177719, 56.928586421474336, 61.49612765158377, 59.452227623231956, 57.43778459487423, 60.96135562466037, 56.43969435845652, 58.23608106182468, 54.25473805396788, 49.744757606137185, 49.55473053839899, 28.028631633327855, 29.82068607884069, 14.17798161506653, 8.740998006636097, 8.320734673930753, 5.298704370375603, 8.163692287860378, 15.892523161826597, 8.76312311618559, 4.554782740531429, 3.1809470922716203, 0.17756963539267742, 0.09297194785528606, 0.035355459493134296, 0.17537873118154465, 1.416246520896112, 15.053204586428983, 35.68073849524222, 54.71514586479434, 34.638137202109064, 35.418135812205655, 19.718094141252582, 22.154892106210035, 49.75136287750737, 43.20087132915374, 56.12178625599031, 60.45535810532109, 51.839813186276345, 16.060486897345513, 0.7409470636517771, 0.04606984645849274, 0.014704655510403458, 0.07692805957049131, 0.0650866155422503, 0.028046733632142988, 0.009313609559960183, 0.04965132665670207, 0.02918938441472429, 0.08708342834706269, 0.020089795880560434, 0.04220781337109305, 0.08302343814002891, 0.06566125809425308, 0.04032920490229323, 0.05327558137416359, 0.02084179544791339, 0.0223782594736305, 0.020443324390197956, 0.07774507701997796, 0.01819085735347002, 0.017197055539356607, 0.008226148709053955, 0.019768423911544587, 0.05352117767136905, 0.03635463732925635, 0.015337348374868593, 0.03442991419785446, 0.07028096746052466, 0.008055527521778018, 0.1266712899650297, 0.05631332683767523, 0.07701887929391477, 0.023272176828956413, 0.00617190835914845, 0.07303753567318763, 0.04524671945780997, 0.024948135889585943, 0.038963649346823656, 0.01897690378339781, 0.03455867059528828, 0.0658516156216783, 0.059854089462709044, 0.04866878058941615, 0.03845432728168465, 0.01575596275694308, 0.029733684139266133, 0.05213237517783719, 0.033501059402741735, 0.012547696655195568, 0.046966288073529164, 0.11626230012024603, 0.056284131226880904, 0.07599635875873989, 0.029356983385138938, 0.11239865824820534, 15.167084720826919, 69.5920487373106, 74.5568907645441, 80.18003202253773, 63.26806622166788, 53.18106766669981, 38.9970907088249, 34.762770514334406, 22.838712238496353, 30.328254507433986, 37.19096868268905, 37.196205046869096, 34.42766281866258, 8.291925845607635, 1.0291345705909114, 0.009425488082812199, 0.10602394869971661, 0.9568194864738373, 3.195003641228522, 6.7190446199909335, 9.196642098888274, 14.19091170833957, 13.408888174641518, 13.680812370392585, 13.415463047642863, 19.9901811153658, 14.432788587385609, 12.645307625493697, 12.700651288032534, 16.35710633570148, 21.483301924120997, 29.60706203214584, 38.14789756651848, 52.135830540810865, 57.394485550542036, 58.746448101535925, 60.03796692817443, 64.42680105086296, 61.70040861252816, 64.22731714863932, 64.22572858871953, 67.70945225992511, 64.89983889364427, 64.40672243795088, 61.06296462397422, 55.92479305882608, 54.8187788071171, 55.679386046624955, 58.32001586114207, 56.960012451294936, 56.926519332393525, 57.548987711629565, 60.84046033120925, 59.53222828526651, 68.30386392531857, 63.563181431062766, 67.61011431294104, 68.17947772241408, 63.397955509924124, 45.79661353941887, 49.64738084423927, 60.415679408657944, 54.05026097451487, 64.90893879244405, 61.44041038328602, 64.57934202686434, 62.40848272077499, 64.88987999577677, 61.96473713844054, 65.22190863086333, 66.38069445087065, 67.09707613914244, 64.56315048279302, 62.82013154798939, 61.36878790393953, 58.71098595280802, 58.83983973533877, 59.10084993608537, 62.4493302837495, 60.91336150323192, 59.68475357178719, 58.38536254821285, 62.81011773693947, 61.44022210951775, 58.31524233664236, 60.726456642150886, 54.19234491163685, 55.359599128846206, 51.41765240700015, 45.78661541784964, 42.631347102503625, 23.58742798528364, 19.382786404701974, 10.15228738707881, 9.223437770720452, 9.370068715464685, 10.686804459941003, 11.172825347992683, 10.123799212517278, 9.397834193321968, 6.3038548731034805, 5.531753465052574, 0.9049017691323835, 0.23384866064354298, 0.022792582805719108, 0.15995027196984138, 1.1386722734858914, 16.8298529424975, 36.83966944294591, 54.37483710627402, 36.82751009541173, 33.434079385572865, 22.089851364012688, 28.24541711038159, 55.18581459599157, 51.068247672050234, 62.51451223127304, 67.9869834838375, 60.74954371298514, 19.67607771196673, 1.0092652528997392, 0.12130734150207813, 0.03784604197848709, 0.03107741193455314, 0.06629236132627533, 0.027859139766904618, 0.023522900169595115, 0.012834058406071798, 0.027010756762578126, 0.10635372656848162, 0.017594720289531737, 0.0780874953394936, 0.09496350066676255, 0.015842715511098504, 0.008771249953086578, 0.014691260463047414, 0.022419610984563347, 0.04139666798554602, 0.03847406170661411, 0.059470041925388004, 0.04427972497538694, 0.04498328863372726, 0.012401654441360266, 0.027603524954869386, 0.044232330945951324, 0.07423637134413566, 0.05325419986019692, 0.04401711386538321, 0.032090501927380125, 0.1823522303734095, 0.14882312066132022, 0.2813852283983462, 0.2438987995828352, 0.15928123206380876, 0.23401692419523196, 0.18382141847283612, 0.17863036073263616, 0.16620859744087343, 0.13128461015801277, 0.14792813078290032, 0.10281465316732084, 0.16394831630731785, 0.21819720855884014, 0.16820741276587212, 0.23761747615231624, 0.11723362299944125, 0.17251540095575396, 0.22538988550584163, 0.15065177253657772, 0.15863557316122517, 0.13061448240712767, 0.15215445400005387, 0.1446127627165087, 0.1914476705414634, 0.21821297464832184, 0.26909598299572546, 21.43426052985653, 79.71233644793111, 85.57162007977887, 87.41662456143288, 68.94423792439123, 63.59774927939139, 41.319859489317864, 43.66531133651734, 50.08565864255352, 60.43141595778927, 55.643123734381895, 58.54954119651549, 40.12497217424455, 10.665549135977223, 1.4605623171214135, 0.23587016749285886, 0.14797909095162345, 0.5921883556631304, 2.8503805206667994, 10.471474182221199, 16.67960263067676, 19.828057789033462, 26.936447658846458, 14.776022453461925, 33.585741750655636, 34.682440373205374, 26.33877258146963, 25.732521241711034, 37.18321807922856, 30.075208679322277, 37.70273600855182, 40.95750701042914, 43.02216814410302, 60.67706615694108, 61.413538225235484, 60.008878630976525, 61.822621822357185, 63.08076912356962, 62.19762394505163, 64.81791234785511, 65.3566655805034, 70.60671883244669, 68.79610569246354, 67.60953380215552, 65.23575067520142, 58.31825079456453, 57.27709293365479, 55.999777009410245, 62.10748787849181, 59.24706805136896, 59.30856689330071, 59.29449342912244, 63.206492854702866, 62.52005061795635, 71.82080222714332, 67.70038374008672, 72.91422567059918, 70.2685320761896, 64.46187880731398, 48.36851558377666, 55.418842607928866, 64.14022484133321, 58.67141708250969, 68.63121709515973, 62.46898920305314, 66.81175508806783, 63.918481488381666, 69.52632550270327, 65.20504243912237, 68.2656208161385, 69.9087409050234, 71.18870442913425, 65.02118133729505, 63.762783004391586, 60.48365408374418, 60.28636670881703, 59.23571671209028, 60.41979005259853, 63.85904581316056, 60.97362479855938, 62.20799076941706, 59.48441459286598, 65.8289267939906, 62.934904021601525, 57.55429075610254, 60.96006908724385, 56.90124357900312, 62.15412093747047, 56.66179856946392, 53.710466046487134, 56.8926182869942, 36.638079227939734, 35.98622052900253, 22.573779667577437, 18.819553659808253, 21.38099866528665, 17.492482469927882, 20.30998372262524, 26.012723599710775, 18.690778324680945, 9.811192193338949, 7.444157013970037, 0.46141402134972237, 0.5421639173742264, 0.15756790706467244, 0.43759389630248474, 2.077768223900949, 20.24542150958892, 46.02788825188914, 69.19089225030714, 49.42954809434953, 48.61813522154286, 29.586344072895667, 34.13137874295635, 63.06395000027072, 57.439592807523674, 72.07393630858391, 76.03511441138484, 71.1931759311307, 26.17103045986545, 1.202546846001379, 0.16727799489613504, 0.09450788519555524, 0.15879700320862955, 0.23091973796967538, 0.15548445434579927, 0.08341534573945307, 0.17100236198354155, 0.13175990642799487, 0.2106166306522585, 0.11848943262931802, 0.2046770130794856, 0.1798209686192774, 0.17385585564038447, 0.12939980403790552, 0.18859903388206037, 0.11375326257679733, 0.15605633898127466, 0.185544794545539, 0.15183252853251275, 0.10378068237895928, 0.1792559634533621, 0.10234858825682633, 0.17765013591176082, 0.18682495811052863, 0.18480109171040598, 0.12342617982217383, 0.14013836490771464, 0.1704895120835112], [0.04335168606391357, 0.040569879084585175, 0.04439796681606001, 0.033369751932520064, 0.08034327187605443, 0.02685200036202948, 0.034554809512149905, 0.05108161664177334, 0.028373774651798512, 0.031506172193574815, 0.04163429696833895, 0.10954108900360524, 0.024179010426685698, 0.02319576721938868, 0.010140581364412943, 0.11455559412077551, 0.05782938802674894, 0.03613034976766475, 0.07382451481516324, 0.047083223734291337, 0.06244339386842424, 0.006505675630779156, 0.05408139861819725, 0.025762364779028202, 0.05540599528279516, 0.024810678648552107, 0.5331860410590326, 27.939656588339037, 67.33558762458064, 69.3328663610643, 56.07947172657136, 46.177930678090746, 32.724489281254435, 22.307988097590787, 14.487942014971088, 41.63946597806869, 46.04805707931519, 37.946236748849195, 37.758508190031975, 11.227161941989776, 0.831438104712194, 0.12372355217174177, 0.02601591689932731, 0.23524910001264465, 0.728628492403415, 4.404919272468937, 4.278241424791275, 5.102288251922977, 12.434376285922143, 9.471687520703963, 16.04649188057069, 10.110286647273648, 19.32011281290362, 14.729052070648441, 17.459509065074307, 23.676224562429613, 42.18208274533672, 38.662128140849454, 52.36191987991334, 64.33910077618015, 61.05042088416315, 62.31251801213911, 62.22214660336895, 62.542631703038374, 63.85441349398706, 60.31753778457642, 59.43731869420698, 61.68042021413004, 65.4427969071173, 59.565564509361025, 63.0073933447561, 52.65194385282455, 50.565172318489324, 51.15974872343002, 51.36773240181708, 53.37059659342612, 53.57899996542162, 51.89232587814332, 53.50115268461166, 52.26698675463277, 54.19887565797376, 59.12552556683941, 61.66617416566419, 61.37090206146241, 63.10707646031534, 67.74615779999765, 51.380272219257975, 42.33670649989959, 57.31134306999945, 51.97215787826046, 61.07674391038957, 60.05479781858383, 63.629720518665934, 62.849188466225904, 62.90030479431153, 60.01961808050833, 61.625357981651064, 57.67112247405514, 60.51272276909121, 60.49807271649761, 59.30999071367326, 57.580578480997396, 59.320675250022646, 57.34643651593117, 58.12896113241873, 59.135884546464496, 61.08285888548821, 60.17950173347228, 59.30100456360848, 54.23536546768681, 57.206933498382575, 61.85845267388129, 61.14225925937776, 58.94106434237573, 60.78713570871661, 62.45282119320285, 60.107934167308194, 53.12371477004021, 38.669898356160815, 31.669130479135823, 23.853717696282175, 11.0768675035046, 8.346094758279863, 9.876194692427113, 13.613479002829521, 11.311423278624012, 7.495425333899837, 6.571280600563173, 3.892193662543451, 0.8977267734946743, 0.3000662824319255, 0.059147530400584784, 0.05186382305598067, 0.17178308218717578, 3.94476420937046, 19.450894440374068, 36.32699212720318, 40.55408731583626, 36.7087838726659, 22.324414983872447, 23.03450519038785, 47.836681412112334, 45.36226203364711, 43.2702462903915, 50.15017378714777, 51.37337669249504, 29.279924592664166, 2.8343054219599697, 0.21009112497971905, 0.06496293830775446, 0.009698274755670179, 0.031324220565898765, 0.040154808816770395, 0.017506953426486543, 0.039903424725297, 0.014433381861195931, 0.07165513001382351, 0.04093508468940854, 0.05042284614436569, 0.008331425469218483, 0.05171707508364513, 0.034569177491169785, 0.011886693969098552, 0.043094449060698675, 0.05578291437198078, 0.013119496063389366, 0.03651461564004421, 0.05410603217540249, 0.016078274141276078, 0.02067348401572916, 0.04619940724824706, 0.02621741334517156, 0.03195350816954048, 0.06998617682726153, 0.057291391290604114, 0.04750520411518313, 0.016985553985221252, 0.08523738627592403, 0.06208314102203135, 0.09471393986454896, 0.016795462673349727, 0.035045274323032755, 0.0662721825703498, 0.0389408199266801, 0.03184420274450414, 0.0514142137140997, 0.05599968278059556, 0.05743937266449775, 0.03997050721438662, 0.0519736992165206, 0.021140602297119556, 0.026831687540717186, 0.0229839209256874, 0.018516364282057173, 0.041720573790371425, 0.027115266477208466, 0.14046473368521661, 0.03178873414834661, 0.05844790443417527, 0.026084820762456908, 0.04177154928085305, 0.041693783695659334, 1.285374924059837, 39.76058398523639, 76.96542216885474, 79.11372000171293, 65.24450932779621, 54.8778889256139, 44.354134451958444, 29.909039428157193, 24.135624324121785, 39.03550247992239, 45.640624800036036, 36.097513860271825, 40.76797808370283, 12.736877318351501, 1.6212799640432483, 0.10038194862464744, 0.0699160491386729, 0.7962439641837151, 1.7731000819513876, 8.670638530485093, 12.48493661803584, 12.298794657953325, 14.230254061760442, 12.848468749753891, 11.484694961578617, 15.722029497546536, 14.213661455339002, 13.87517071539356, 14.131933969836082, 19.50214412904555, 32.550398803526356, 37.89901533434468, 52.151053259449625, 61.409188316714385, 64.17980155637188, 63.85780242181594, 62.43672378601567, 63.19619663300053, 62.723676543081964, 62.27389835542249, 60.80850085904522, 62.6198749388418, 65.88577762726815, 61.83685610371252, 64.11756530884774, 54.061698605937345, 53.474617850395944, 53.68830857738372, 52.70713552351921, 54.82175196370771, 54.5988279773343, 53.78319855659239, 55.00771937831756, 54.82964769486458, 55.748058903601866, 61.840825542326904, 62.748101142144975, 63.65259970388105, 63.84478015284385, 68.16327833360242, 52.15525804027435, 49.53551092455464, 59.541155599778705, 55.48180449393488, 63.50445178247268, 61.28705747665898, 65.46095355864495, 64.41593216311547, 65.97220313164496, 63.07197124727311, 63.65735753890007, 60.007399897421564, 62.5135394834703, 62.900316561422045, 60.433008440079234, 58.7194896513416, 59.63112300442111, 58.33783126646473, 59.54264217807401, 58.39206980120752, 60.29664724103866, 58.637790603022424, 58.552816375609375, 57.42216963921824, 58.60610177440029, 59.959009616605705, 61.331776418993556, 61.34421425480997, 61.737278892147934, 61.75636122303625, 61.40832931764665, 54.0556973795737, 42.684506985449026, 29.222002952329575, 20.15872928404039, 8.649692093172382, 7.256239200792006, 10.196486615365552, 10.32898820215656, 16.21510967131584, 7.236993601245265, 13.126811904291953, 6.41990113642908, 2.6026313631765308, 0.8154848446288417, 0.07223354171841376, 0.041674076083807216, 0.16903806658041093, 4.101584000933555, 19.031061587795136, 42.52701205592002, 42.464477708262784, 34.21921630059519, 24.487627629310857, 28.43782505681438, 53.65272875755064, 49.476973472103, 51.73907103077058, 58.276230442908506, 59.26234960556031, 37.58945403560516, 4.260606938792813, 0.20776920441177585, 0.08758480224998728, 0.028307056054472927, 0.03200172382827488, 0.08721423019925434, 0.025428921179545504, 0.06005130730749619, 0.02971273354975687, 0.07914346327344257, 0.03241445944314042, 0.0745291241835202, 0.03468283812605566, 0.03642278468056071, 0.0074371609803018796, 0.06880090857345252, 0.02412130676900908, 0.02725293630764129, 0.04708082204864872, 0.023814959699408184, 0.03744539714628651, 0.059968393611451315, 0.05356990469379291, 0.028739698464050892, 0.025662378813590736, 0.03768496050108825, 0.023863135138526562, 0.03921676479700593, 0.013045086900913909, 0.1887153719942416, 0.277120171775741, 0.2210457992529677, 0.17730887438501083, 0.20305924988802404, 0.10713490642487042, 0.21908420047933058, 0.14662066384428932, 0.1043125925465457, 0.1372741153764148, 0.11782999180497662, 0.23275597411538326, 0.12071461161418308, 0.15455741134862747, 0.092536817575174, 0.13425444192703695, 0.15110756420800764, 0.07910322067478011, 0.13613236857758415, 0.09618521938400884, 0.17795899191931372, 0.08285825426179556, 0.1181059443361817, 0.09442475699489156, 0.1563662368684046, 0.18367759312593168, 1.998523721291173, 52.3892980237161, 84.28219579881238, 89.80487731195267, 73.23134929903092, 63.13339556417158, 45.88896574512605, 32.9381819694273, 24.645542252448298, 61.359107494354255, 65.40139236757832, 53.73330600800053, 48.01760858105075, 15.24558605686311, 1.6218667261062132, 0.464724593705708, 0.19409318664862266, 0.8060633114749386, 1.4863974985576447, 12.137310677959073, 16.279936644338793, 20.188790329041023, 19.787702483515588, 20.08547509870222, 26.76245524037269, 23.380697504166637, 34.497845788155836, 28.94155348500898, 30.91872222961918, 32.046856687914946, 47.176307247531035, 46.51551731171147, 56.9361291393157, 70.25405853025376, 66.77920726037794, 66.31334735501197, 65.76149732835832, 64.69998628862443, 64.52945340064265, 61.173999078812145, 59.972969332048976, 63.012614019455455, 70.11446922056138, 63.19297636708906, 68.92385728897588, 56.19195745837305, 55.341630751086825, 55.67270232785133, 55.121040574965946, 57.620688638379505, 58.555350226740686, 56.59933090209962, 57.591580729330744, 59.12925574087328, 58.63062835508778, 64.7859214967297, 65.51387417700984, 67.37226963043213, 67.75271600292575, 69.1501937373992, 56.59740109597483, 54.03149243324034, 66.24266624450684, 60.61149981714065, 66.45019100558373, 62.189383045319595, 68.01771917650777, 68.14222305051743, 68.63291155907416, 65.96638233430924, 66.9768633381013, 62.7937339967297, 64.37874417151174, 64.00387540940316, 62.119623691804954, 61.000336139432854, 60.97889646407097, 59.31093208251461, 59.355921668391076, 59.68695009908369, 61.549617013623646, 60.39270216418851, 59.882546932466575, 59.85031681676065, 60.80154257435953, 61.15594440890897, 61.7771105612478, 60.60922876481087, 62.87699022600728, 65.36412200620099, 65.2653528028919, 59.27207316121748, 46.181947185147195, 41.40561034602504, 31.37110487107308, 21.37188307700619, 17.967479536610266, 16.47321927932001, 25.01975009518285, 24.608236589739402, 17.730770380266254, 18.26238489920093, 10.646263822432488, 1.8891551706098744, 0.8164670919218372, 0.20070130786588117, 0.21068706477601684, 0.48208871195393227, 5.429585037692901, 26.117986286840132, 49.23189986136652, 55.41257858276368, 51.359503269195564, 31.211123158854825, 31.627253293991092, 60.812658571427875, 60.060850035759714, 60.14862091310563, 67.85827482900312, 67.80816262768161, 48.339646939308416, 6.960226749220203, 0.3854484056993839, 0.12656726288579165, 0.13441918147427423, 0.08141757995491067, 0.1979927427225536, 0.08532924021804526, 0.1615018604864036, 0.13996596448123455, 0.1852005452758843, 0.2710943080244526, 0.2729431539773941, 0.2036714001047996, 0.23139635191088725, 0.09068802524838718, 0.1299764843837869, 0.13730534112020848, 0.2233180007146251, 0.12459650170058013, 0.09530509161131998, 0.13411132138102286, 0.12779829723219718, 0.11599706515910164, 0.1952633553094441, 0.13611704681909856, 0.09668215763785186, 0.17740074364889055, 0.12977273563944525, 0.19753197147961588], [0.024654191783479145, 0.055355958250020786, 0.014262583516087505, 0.02499420650213236, 0.04966803503433063, 0.027360056466873617, 0.023684749650138042, 0.03661948541599897, 0.045704763427737265, 0.013683823241491713, 0.07124656000204625, 0.047584210762814175, 0.07048017330347531, 0.047646681402599624, 0.03197935980654532, 0.03037632657064786, 0.04157612791224834, 0.0271182791179707, 0.06719908767169522, 0.02789692130811032, 0.11122758560363324, 0.062232589454299984, 0.07350241314739951, 0.15360263596859672, 0.03447630465210926, 0.25094691573852496, 9.029460876218735, 51.47106724400675, 68.73996088581701, 64.64104875441521, 54.17523945531538, 31.474465208668864, 20.114790893370106, 21.012794010100826, 24.477241193094564, 33.47273434362104, 25.170979038361583, 35.11213602558259, 16.11878704640173, 2.3389777300819277, 0.10409039640498739, 0.03415164808111806, 0.02722998814386947, 0.370150487869978, 3.6980851234928256, 3.191446051482232, 9.730775760066125, 8.535213797323166, 13.16395773041633, 5.81958826511137, 11.321303729088077, 13.25294356192312, 21.96517686690054, 26.23350008841484, 28.557316141743815, 37.1586012840271, 49.36221668797155, 56.42090228296096, 57.81400657469227, 59.33892211606426, 61.1406667770878, 62.15554083547285, 62.53943497134794, 59.745926856994636, 60.23193990030597, 61.75062671784432, 58.855309563298384, 63.68342561106529, 63.204551281467566, 58.95573008445002, 59.039578591623616, 50.61032664391303, 50.29790201494771, 47.93885131036082, 51.899609719553304, 57.986971332180886, 57.90180883099956, 54.829945794997684, 53.46119549966628, 48.68397220488518, 53.17703939253285, 55.68802702811457, 60.24917479484313, 58.06379879674604, 63.9330138698701, 61.98764378024686, 61.453828811645515, 32.588777234477384, 42.23371682628509, 56.84716193906723, 60.05970862603957, 64.277205774861, 62.25856973278908, 62.11476387516145, 59.96646996467345, 58.8742506888605, 53.83889229066911, 57.767808898802734, 58.07604835879419, 61.53936393799321, 57.755739765782515, 59.08261483715427, 58.48598703261345, 58.14792971457205, 57.39132019781298, 59.12168556644071, 58.50139802502048, 58.02841117305141, 59.883170589323974, 51.86259431223716, 58.67407252711635, 55.98853549649639, 59.261290565613784, 58.58067304857316, 60.804743228420136, 67.05895070106753, 66.26190154783188, 66.72540803109446, 60.798236016304266, 52.25678466981458, 36.02900574284215, 26.272164852388446, 14.203744722950844, 8.895494284168366, 8.669256875591895, 8.433559690752338, 5.910292094753635, 6.448019137305598, 7.156361437612965, 3.724697424519447, 0.4080353743366657, 0.1107586325416642, 0.05003799038428453, 0.06055022206818385, 0.20382421932393507, 4.195415185343835, 23.229397958324803, 48.50675952049994, 59.02552081692604, 32.86340198209209, 24.00472894791634, 41.719207763671875, 44.92761635011242, 33.14258060147686, 58.49554192635321, 57.176237029414025, 53.62307956141811, 14.643087444766877, 0.35999997609084655, 0.04075684667294545, 0.10043987253260228, 0.01964303447053798, 0.055473713624861934, 0.04563727108160815, 0.026975742713998885, 0.005029966686702064, 0.04123312353547062, 0.017563500291397496, 0.031982372447307554, 0.016840271156040892, 0.14300627633929253, 0.005757703291883152, 0.1349535584449768, 0.03793863136501562, 0.030478612715077978, 0.03210233224015082, 0.049617308522424394, 0.01540243999296499, 0.027679300626679778, 0.01753737669317953, 0.03619560896749458, 0.05314444244328526, 0.028286961568219048, 0.06613978725527564, 0.015958426388791733, 0.015261119753572971, 0.026638392066102357, 0.06557962376504176, 0.04026866863451658, 0.025076589682289673, 0.06741186093178488, 0.02172099625421388, 0.02439621933585694, 0.0527936278001195, 0.023192183843122858, 0.04048171385581936, 0.06558035920944906, 0.022666226178708098, 0.02552106623507796, 0.033998342396150676, 0.03495527048324866, 0.014798054077302017, 0.060078997555519306, 0.0270092130954107, 0.04511833461301942, 0.020710807819400105, 0.027831432281903205, 0.11961087809815524, 0.03944997728291539, 0.04416828216504186, 0.03599452620912944, 0.24233300779615682, 12.790064657888106, 63.13817301104146, 75.32255311166087, 72.10416209313178, 58.622932664809696, 40.81216750606414, 28.387026440712717, 22.96906044406276, 18.514255977446034, 34.13095904934791, 27.239695902793642, 35.10622501373291, 20.459322083380915, 3.053477170967287, 0.11502251704974521, 0.20532262601679374, 0.33332001417875295, 2.5840297677824577, 7.334890567487286, 11.422265537323492, 11.518788203116387, 12.475399374961855, 17.761643355892552, 10.75513607071292, 6.095650561394231, 6.763653735960684, 17.933423557589133, 15.02956642258552, 28.92510306450629, 33.31956186602193, 50.76535832497382, 57.2491656580279, 64.00085126200031, 63.127339424625525, 65.36234125014275, 64.45893702968475, 64.31872798550513, 59.96970199769544, 61.813121841799834, 60.10870295186197, 60.76078522589899, 64.10030688008955, 65.31025609662457, 63.07435212596771, 62.05195103922198, 51.72901799601894, 52.53204876376737, 49.16994994686496, 55.135984805322465, 59.59426056954169, 59.727174005200794, 56.79174277090258, 55.05628616579118, 51.72617035527384, 54.19181931403376, 58.152577723226244, 63.016803110799486, 62.4251292597863, 65.35243334308748, 63.85263273792883, 61.564200385924316, 39.18779242423273, 48.105673636159594, 57.910332141384, 62.88882401681716, 64.12570814932546, 64.87761474424794, 63.22554772899997, 61.46335624879407, 61.08027012117448, 55.7798771704397, 57.142273226091945, 60.530279297982496, 63.974371340967, 60.06859279447987, 59.94950179130801, 58.82825697621992, 59.30950041740172, 58.503186625819055, 60.220212013490745, 58.78787617529593, 57.58321039138302, 58.186341485669544, 54.5023141368743, 59.05550341452322, 55.14427669586674, 59.78090655419135, 57.34506368637086, 62.739895543744495, 68.11278174000402, 67.17430760783535, 66.41274021517846, 61.85643657561272, 53.977226441906346, 39.86183997123472, 26.203097797209217, 15.131515687511815, 8.898095796185157, 7.174931899193795, 8.288813444875903, 8.325445440507705, 9.598232007795765, 8.825868291239585, 5.763858739406833, 2.4456897329899574, 0.4117300631778856, 0.10590941089415744, 0.03351376497096593, 0.1695906917654699, 4.242452248450249, 22.161822934304517, 43.04094060774773, 52.79196070086572, 34.06684790888141, 28.365714242381436, 47.282870200372514, 50.026528912205855, 41.90846212448613, 65.87640316255631, 65.05655719387916, 65.08391964820125, 19.573158641015333, 0.2690364426422504, 0.041469695316928054, 0.03672907429356729, 0.03298057543654596, 0.009508149927451966, 0.043950448894212325, 0.03667982633135492, 0.031302448347090714, 0.011439662513082788, 0.06854693510479505, 0.052932285883974646, 0.007615228542201822, 0.028049631359716578, 0.025071196423302737, 0.05794528946881333, 0.02120009477009937, 0.02629610398153384, 0.022852245733262073, 0.008200359316692959, 0.08570427090049752, 0.09298330127832391, 0.049047530628740794, 0.04412441597049756, 0.030877813471541293, 0.019711685524652564, 0.029829611753924724, 0.01643563117531519, 0.04795666355940123, 0.10731754944689813, 0.12297781154273019, 0.1916296011017215, 0.1294248244695125, 0.20843668149844294, 0.16085181956089314, 0.0767559732400602, 0.10768809851499335, 0.0953941340107591, 0.16685918994968937, 0.3187179493327295, 0.21717608996456672, 0.10987484286869727, 0.15941782554070796, 0.12098835781216623, 0.15827080805695828, 0.15823334635746095, 0.11640285427171378, 0.10685300905137293, 0.16080183998471306, 0.22590598361867092, 0.13118713313052732, 0.21827996137642094, 0.18332395161832535, 0.15469760543877079, 0.4913298773669428, 17.899955934093846, 76.97927598030337, 84.296504605201, 83.7648900862663, 68.99247523277037, 45.68037802173246, 30.9697404984505, 30.33881745030803, 34.83922535373319, 51.68844107658633, 39.19243258814658, 46.21019609512822, 21.851100613993985, 3.7398752810493594, 0.40335408682304047, 0.4454021402184041, 0.17429819480786402, 2.8389230322453285, 11.156020933581937, 15.397903457764658, 22.094295409417924, 19.89725624361346, 26.92080132422909, 13.395105946448542, 22.48269242625083, 23.282434286609774, 31.690154383259436, 34.280624928012976, 36.96473029352004, 39.94679066442674, 55.316511892503314, 59.244408684392134, 63.46784037928428, 63.56527205436461, 65.7415638431426, 66.57514987453338, 65.20265371568742, 60.89676987740302, 61.1483742344764, 62.118039054255334, 58.974094621596805, 65.91335188957953, 68.90898366128245, 66.09414177556192, 65.79400593234648, 55.794589980956054, 54.0077385594768, 53.1618284410046, 57.14921189892677, 61.9383042858493, 62.29374162612423, 59.24433415935886, 59.427963841346006, 53.60052593292729, 57.612600711084184, 62.012794017791755, 65.83304528267153, 64.91020964037988, 67.42370759287189, 65.47394052628549, 63.86874975696687, 44.51180981051537, 51.90650132394607, 62.78411634506718, 63.43564948728008, 65.40608352230441, 66.61903335202125, 66.6861843293713, 63.7811436191682, 62.327874091363725, 58.55459320929743, 60.18866046782463, 62.69303498729583, 66.50878337121779, 61.498951758107836, 61.94768659530148, 60.06657277384112, 60.67626207105575, 61.822300188003055, 62.85815108206965, 58.52642666909003, 58.57472281302176, 59.138528223960634, 55.95288899637038, 60.97280502319337, 55.6347220174728, 58.71242938503143, 57.3801806665236, 61.82414762435421, 71.95052285348216, 69.50720002574306, 70.58020361008184, 63.265736333785526, 60.60356093991188, 43.32945054577243, 34.34837995036956, 21.35637990890011, 20.013956562165294, 17.31461867209404, 16.58620903568883, 16.262013373836396, 15.933217752364376, 16.29516426594027, 10.496701886576991, 2.5399484557490197, 0.2791499370528806, 0.331304436849971, 0.11492675605921016, 0.46003641140076423, 5.963971691746866, 29.975637351312947, 61.86819584138932, 73.91421041181012, 46.63599683392433, 34.019838302366196, 53.310505882386245, 57.47112474133892, 47.16004510079661, 74.04993226451259, 75.56626565994756, 74.74404273494598, 25.5219841003418, 0.6716644619741748, 0.12117173627860124, 0.14205543865119258, 0.1093772151357224, 0.12225753567632168, 0.12309864659102694, 0.11589909783534466, 0.07959570795778306, 0.11270578289704938, 0.2048709252548795, 0.09777891209288951, 0.08074955128493809, 0.1935145757611721, 0.13076878783683624, 0.28203750630059554, 0.10581917339755643, 0.09852197907504537, 0.08399378808756029, 0.09496397564127561, 0.16118306065759352, 0.15146011787076152, 0.21133502194237327, 0.13934644449862743, 0.07225999473443917, 0.1264296045466777, 0.1684814883816627, 0.13694748612901858, 0.16843084996986776], [0.008385183774085056, 0.0675574406200359, 0.05597911331982863, 0.025750961560275287, 0.02205395721830428, 0.08233320058113144, 0.041787901427596814, 0.029594886244364807, 0.049669122879183104, 0.03531278073487263, 0.05141529006763332, 0.024447267604691368, 0.08721852029163031, 0.09163602075028805, 0.04284855781964237, 0.042912411248131145, 0.049127123333633914, 0.01655723231153623, 0.08855408733530391, 0.08262782267505124, 0.06185384707585458, 0.034299388137315555, 0.06824028543046406, 0.02346292889166263, 0.04084550985886205, 0.361755206099441, 24.305321747256865, 64.83198188966321, 64.08604121977284, 59.158457786806174, 47.38849178437264, 38.97382713133289, 28.707905738584458, 28.564356796203125, 53.27591842220676, 37.42809949382659, 41.83198375086631, 25.531801792883105, 3.855013515680067, 0.28887143959441497, 0.05005145054911414, 0.08448750877212133, 0.4385354796484594, 2.2738806038133563, 3.875747409559066, 12.123563751097649, 10.291314817244007, 8.627574828363235, 12.301210837979472, 11.594444840185105, 8.610035950137723, 21.512853060999227, 34.22877511670513, 34.34334362706831, 41.69251995701944, 54.512406395327666, 67.14284235431303, 60.6139709103492, 60.897895597642474, 61.23061456987935, 58.00821488903415, 59.30326777119791, 61.986110133509484, 60.49832374818864, 59.45951146464194, 58.683497982640425, 59.42324523002871, 64.14986994958693, 62.07812893775202, 58.963363016805346, 55.24875687014673, 50.129306777831054, 46.56303682634908, 52.04867155321183, 56.48641370957898, 58.923021439583074, 61.1824910102352, 58.75385353642126, 53.9228270899865, 49.35357570648194, 52.01522550275249, 54.95929771854032, 58.79427356104697, 57.74754593449255, 62.289615292702955, 62.425266542742335, 58.88866147687359, 31.26249247981656, 50.44083318402691, 54.6742747675988, 60.62240008384951, 63.399732343612186, 62.160785044393236, 59.590557852099025, 58.44976002170194, 55.205551962698664, 52.74422153349846, 54.1214676826231, 58.76352610126619, 62.175282124550115, 57.34009404336253, 57.430375237618726, 57.62824312333138, 58.19517858566777, 59.2194780995769, 58.53171402408231, 57.64956120521792, 57.50424915744413, 59.89842860929428, 55.6940164873677, 52.46178734687067, 56.8874329136264, 57.48739865518386, 60.19492057061965, 59.06661548922139, 62.399433812787464, 61.796577284413004, 58.66723191353583, 62.43540586963777, 61.78424143022107, 59.2812515074207, 42.50832196204893, 38.173169397538715, 34.82272002004808, 12.634992772533048, 14.943052664879831, 3.5533273556540093, 11.831961024192072, 5.011763380419824, 5.803578130660519, 1.6998604829272919, 0.2934846372133301, 0.05170698570568235, 0.06302278999599718, 0.03288560734701253, 0.31325267808091256, 6.447700935025369, 32.0400905993677, 42.00717249224263, 32.58546675405195, 19.779224280388124, 54.43602608096216, 81.25441628117716, 39.80771126285676, 32.5401065041942, 50.51458943274714, 50.64458854736821, 37.37414336973621, 2.8299498750317484, 0.029235049000670834, 0.07442948678808828, 0.019342220470970197, 0.021813260053374597, 0.03435705540581577, 0.010664622851407096, 0.043937482856093876, 0.05901618845640652, 0.026923731089599674, 0.060404941154223304, 0.030515714353250883, 0.06727614079511936, 0.007482366392298812, 0.03740785117711752, 0.0060585527230174316, 0.04984384072163413, 0.02834894191173296, 0.020646262996559663, 0.03337770392517409, 0.03629592052029987, 0.07749832776044646, 0.050426757023219144, 0.05952023983662648, 0.0049504194682794475, 0.02387694770380134, 0.021900770276965156, 0.015545492548675788, 0.03517596126203576, 0.01814930665967686, 0.039915050109547955, 0.039979570034530856, 0.046430853901491057, 0.009077928355714728, 0.031251823341834455, 0.023977874042165857, 0.023804100403081507, 0.01833947074990119, 0.0203684680238967, 0.005581451358363754, 0.034063341126086256, 0.047612739877114375, 0.05023746052756906, 0.08891538206127383, 0.004869612992831296, 0.04461368568421853, 0.019916843870774876, 0.008666203019299335, 0.04640396038490919, 0.013431713281710063, 0.056372729295323935, 0.01703307058872475, 0.040466790463054375, 0.7493086375536457, 31.06007660588911, 74.99801620360344, 71.92147377998599, 69.28700600900959, 57.546367568354455, 43.47851237943096, 38.17486778382332, 31.904562903988747, 45.80207740106891, 46.31600595289662, 42.67756439024403, 29.100815442300615, 4.75204118797856, 0.3851691206857082, 0.007017273934663184, 0.19514260453081902, 2.007303456625631, 5.209396414218411, 8.301940637250102, 9.69150891227107, 14.135819077491762, 19.621386143469042, 16.322150172725802, 15.248268958060974, 7.815093109684606, 13.429912078765131, 23.657559963964648, 34.14675051166166, 41.052342076455396, 52.93258159391342, 65.31399803776895, 64.3293732981528, 63.53823907913701, 63.05844299254879, 60.9745151765885, 61.88519147134597, 64.79964194759246, 60.751457829629224, 59.10367796497961, 58.96801102545954, 60.8404956325408, 65.2872553179341, 62.932013234784534, 62.50378847122193, 55.52542517262121, 51.90680334644934, 48.53422787881667, 52.98227017925632, 59.00446161147087, 61.38259464694608, 62.33391061905892, 59.431533198202814, 55.00460501640074, 52.139164555457334, 52.89970820949924, 56.6221434070218, 60.77024990512479, 59.94901541740664, 64.08539795106458, 64.8544256917892, 59.88692429757888, 35.696255391643895, 53.562365193520826, 57.50599461217081, 62.673846752412864, 64.21667575836182, 64.35790069641607, 62.390216242882516, 61.068565768580285, 58.15717081869803, 55.228172271482414, 56.643618383715236, 60.560320731132265, 61.45681765771682, 59.53284409738357, 58.445598386949115, 59.416467374370946, 59.13808107376099, 60.065337227236846, 60.85512215091337, 58.61234226534444, 58.119468996601725, 61.82519489719022, 56.40221611146004, 54.77548760752524, 56.532317207705596, 57.54586158260223, 61.38071190926337, 58.13882589340211, 64.74286956171836, 63.965600921261704, 60.79828308474634, 63.24561849717171, 63.37788081938221, 59.966426818601555, 44.77237286106233, 35.2847203131645, 26.038940721942534, 13.12160986085092, 12.578870519515007, 10.662458308281439, 16.175954611070697, 7.7943864272486785, 7.131789259372219, 5.898891725847799, 1.1472671671259789, 0.23807309928440282, 0.13635903867262025, 0.023056174508265914, 0.37800941616296774, 5.969817494192432, 32.01710354897284, 45.766995722247714, 38.32541227340698, 20.259457711250555, 53.062870963927246, 77.29007674801734, 43.74194660494405, 43.83919785099645, 57.17142820358277, 60.0811404566611, 46.37732044343026, 4.519965331400595, 0.1096208694000398, 0.0696163402209359, 0.019672747190681197, 0.028175212322704257, 0.02273077291676835, 0.027015401170619076, 0.06019811273642606, 0.0179494017614953, 0.05059040872560394, 0.026495997388396534, 0.00858899859351016, 0.060672267535400976, 0.060443544324727795, 0.043122349982900966, 0.04503671177512696, 0.07158730824988696, 0.018890027497564594, 0.03081586185632454, 0.046599489005823294, 0.04090215056954373, 0.10179924958896253, 0.09087357940452714, 0.046301542090312134, 0.060970179976955544, 0.03245021276656659, 0.03824703538069322, 0.03213600180442295, 0.07859739580101545, 0.1363291765653318, 0.1759932562708855, 0.08149044257738898, 0.1874303667535705, 0.08528802468771897, 0.14316982078936794, 0.13217187787015594, 0.19886491850258844, 0.11859096226192291, 0.16576924601629858, 0.12462475502322759, 0.20769619623259192, 0.22132096271361076, 0.17330798020045604, 0.27313084551884287, 0.1387759847866912, 0.163539822904333, 0.13778946272307827, 0.14586084251922948, 0.12276958118403151, 0.1761201357529048, 0.13449995778501034, 0.15925294809764431, 0.1453799997726756, 1.1498597312358119, 38.702022567872085, 86.95986455486667, 80.3717339423395, 77.217865913145, 61.569162184192294, 53.21862436109974, 39.53851507556054, 42.5658082192944, 75.5676620237289, 51.665612882183446, 55.15625953674317, 33.21026894354051, 5.1892628881239125, 0.6783019703242087, 0.25646159966145793, 0.2499982997054054, 1.3077806056507173, 7.420128083998158, 11.49641304246841, 20.95625304406689, 21.86610564108818, 22.87968727850145, 22.07693696022034, 26.996565826477546, 14.696333619856066, 31.478012992489724, 47.62493225835985, 38.904891475554436, 43.74673581892445, 56.582774577602265, 69.16117637388169, 67.49224708926293, 64.91041360362884, 65.9051384464387, 63.738028926234094, 64.0790319442749, 66.28177227512484, 61.28257028518185, 59.47974697236092, 58.87452525477256, 59.3968790577304, 67.64541564449188, 64.85572399631624, 64.87444154677853, 58.80689182589131, 53.93530807187481, 50.79404261804397, 55.67010179642708, 61.4403280135124, 63.496473681542184, 67.21151521128994, 63.44319612749162, 58.6526995320474, 55.38311373802924, 55.64364540961481, 59.86783019958004, 64.50840203992783, 62.39768835806078, 67.98069984682145, 68.33768260094428, 60.88373584132041, 39.800662763657115, 56.79820291457638, 59.72544816232497, 64.40557710586056, 67.1025360784223, 65.78508646257463, 65.0609306366213, 64.98273034249583, 59.14183870438607, 56.17168272695234, 59.22617750783121, 63.59112831854052, 65.98724934362596, 63.18910891009916, 59.64870306753344, 62.35433440054617, 61.805457530483125, 63.34098700554141, 62.32052356966081, 60.63413581540508, 58.5628301866593, 62.01317448769847, 55.74093195699877, 56.480224209447066, 58.59819819850307, 59.33723157451999, 61.008090665263516, 60.53331913486604, 66.28564757685508, 66.7955792334772, 63.18977571302845, 66.21427612919962, 66.23201308711883, 65.25409560049734, 46.916265872217, 44.98946820535968, 45.84168549506895, 20.227690435224964, 24.085063011415546, 13.108160053530048, 22.849296754406346, 14.240342397843639, 13.506912127617868, 6.551955082724172, 1.2584337568090809, 0.20074019448891764, 0.22418285269410382, 0.13773169969358753, 0.7119682250965027, 8.582146917620014, 39.413720946158136, 54.904255097912205, 44.92814979245586, 29.593441601722475, 64.1426645555804, 89.07272769558816, 52.77958954534223, 48.94117378419446, 67.62905936087331, 68.64208206053704, 58.59311872912992, 6.709839307492779, 0.15331616505019127, 0.1644646289247659, 0.17497720917867077, 0.207700900012447, 0.12296936925380461, 0.09962677745328796, 0.1917553620953714, 0.09181799727582163, 0.14076122503367164, 0.11339860983313092, 0.20547365259018638, 0.176040631148123, 0.20250826413112305, 0.09818781152247422, 0.22225886883754886, 0.19106194527158815, 0.09676599063940587, 0.14790931566348, 0.17705033503232465, 0.15475674742652526, 0.1520007920842017, 0.16991054879561548, 0.16318176873028278, 0.15043876945011078, 0.14462737967410397, 0.11744032884317061, 0.10747345600036845], [0.0009615522656296831, 0.03012112927653136, 0.07793598613070865, 0.03976047271862626, 0.04134054821465285, 0.014350298668197809, 0.012092554243281485, 0.058431694013697494, 0.02552071000419317, 0.036008461348472104, 0.08512362221916837, 0.020440838434883667, 0.031845823020463994, 0.04875421854517153, 0.06448694489776127, 0.04659434855585137, 0.024846837998578147, 0.06935953988783783, 0.027446329458466465, 0.03172131075013069, 0.05803405990703933, 0.10431777896179308, 0.10201871079663116, 0.0348894520392341, 0.031024726152780558, 2.2955247327204678, 38.62319861688922, 69.2896967549478, 64.89454761628183, 47.058557694958104, 37.82792629734163, 27.004722395250877, 21.549087916651082, 34.088173835508286, 28.304546840729255, 30.23225057509638, 22.478834775186357, 5.94574345696357, 0.3805062805692996, 0.20544852490626997, 0.013931350080266356, 0.457073612318885, 2.5043490240650796, 3.511495032618123, 7.665531664125382, 8.358509059875242, 7.554492796621016, 14.396870463125168, 20.325151528081587, 14.243533245978819, 12.2194411869972, 26.011911669085105, 51.070973719319994, 54.85596287635065, 64.76457203588178, 58.281776674332164, 64.17540850177889, 59.25650135163338, 56.78382742789484, 52.802315758120635, 56.93678417513448, 59.97455004722842, 60.571177851769235, 59.78524469560193, 58.5882196887847, 60.14252947222803, 58.673586153214984, 60.313701706547896, 63.56709987886491, 58.87775728779455, 51.56121900004726, 45.28372441568683, 47.13014095060287, 51.9914363276574, 60.02993783643169, 63.031955226775146, 63.1356313151698, 57.205011536998136, 51.817953817306034, 48.001966168803555, 53.23644368879257, 53.38537216186524, 57.26862453645276, 58.55498152394449, 61.83428695124965, 62.09037849980017, 59.08659604287917, 32.211476602861964, 47.23815125803794, 58.665596285173976, 62.5891000224698, 61.146793519296956, 59.744985488153276, 58.31763890481765, 57.50055428474181, 55.16891702528923, 51.38990163803101, 51.185805028484715, 54.7030375080724, 56.771358213117054, 56.168960602052756, 58.2569480711414, 57.53931514678463, 56.81836781963226, 58.617923798099646, 59.65910911560059, 58.40848884274883, 58.54661510836694, 56.28159146155081, 57.61167503172352, 53.54225127927719, 54.356429423055346, 57.80535774846231, 57.397697971713164, 58.05471066505679, 64.11081883215135, 62.395938980963926, 59.659944580447295, 60.43647581531156, 63.58336987033967, 63.442682296999045, 64.41146850585938, 50.880495579011985, 33.3393306116904, 24.937613702589466, 12.878237578176684, 9.493841067437204, 7.950390856112204, 8.561268141192775, 5.429128081567827, 3.7952454195868586, 1.881144710125462, 0.04105639088177874, 0.05783951187866831, 0.0731472777683408, 0.06054781655210161, 0.40061927550742704, 7.927970588207246, 37.80661606019543, 62.38838841838222, 47.9196277741463, 63.6993347444842, 78.0935428988549, 43.52806368181783, 40.19075816677463, 44.19256025745023, 49.45425902643512, 47.20257536057503, 13.839234940467344, 0.12704268172984162, 0.06378770580575352, 0.023596419712468505, 0.03479622296928879, 0.01440169646464769, 0.014431177443193813, 0.043296160011161725, 0.06016940742190327, 0.06372936054944031, 0.03395052318791709, 0.012127091402127858, 0.05216930061578751, 0.05804065592406739, 0.053406712644162684, 0.015609558566563554, 0.029545389303577044, 0.028202199685056845, 0.013668904636776256, 0.03871076755345829, 0.008225306969947152, 0.03873746954805909, 0.053644491014100855, 0.028290780516521587, 0.041534797468733405, 0.022530858442487738, 0.005505799697036105, 0.05788087679613983, 0.014788061417939683, 0.0605080642497107, 0.03602117074713592, 0.08600742721389379, 0.021627305616294185, 0.019632742079275272, 0.05594956147814951, 0.0410551498193414, 0.033082560891465794, 0.012498432413614806, 0.04491084352916768, 0.06391935035466187, 0.024953419981043667, 0.018659507810708978, 0.02455319841242125, 0.009372123355616727, 0.02293825442452104, 0.018154998692954262, 0.046878969371919675, 0.023405690632400014, 0.04669958605400978, 0.08072467641003671, 0.05002158461138607, 0.019627299024573257, 0.007527397519292971, 3.9196779554890053, 47.98811627972511, 78.11761056223224, 71.1045382099767, 54.62519414963261, 44.28988995090608, 36.795432952142534, 21.204319423244847, 33.26095381090718, 37.440419658537834, 37.482416475972826, 26.158639692491104, 7.659340693104652, 0.6408313842069718, 0.0639067558691867, 0.09856838102061903, 1.561644615665559, 4.662521423832064, 8.96469077756328, 13.629633284384205, 12.246009361359382, 11.75626124105146, 13.777345822703454, 10.803608721302403, 11.19867867039096, 13.349422101051578, 29.23949476211302, 47.03094028657483, 52.50268590065741, 57.64057113278297, 61.04534925953035, 66.80089012269052, 63.469087692999075, 58.70006999661846, 55.97266950914937, 57.68773763410507, 63.294208818866366, 63.52077668712985, 60.74436618435768, 58.079872669712195, 60.5167628103687, 57.74756162397323, 61.059811038355676, 64.75006318861439, 60.82710466077251, 53.124114851797785, 48.1800849206986, 48.52763829692718, 53.98333357226465, 61.68557028616629, 63.96022727412563, 64.54976735576507, 57.4970280739569, 53.14382868428385, 50.51797051583567, 54.59404268572408, 56.091038796209524, 58.24958185995779, 61.3395623237856, 62.135364163306456, 63.35255015280939, 59.81894962249264, 36.300414146915564, 51.18934692875032, 61.384049846280014, 64.15028964319538, 62.8927150080281, 62.78727777542607, 60.737388287821126, 60.19089621882285, 56.45186547310122, 52.137199448001006, 52.335843963007775, 58.068709604201786, 58.749374189684474, 58.432140734887895, 59.689483950215006, 60.397938528368556, 59.19442592128631, 59.592126800167954, 61.37722099981001, 59.90038194964009, 60.91709952200613, 58.03520079581969, 57.02163680907219, 54.723425988228094, 56.29497851094892, 56.746184441351126, 55.931763110622285, 59.499613777283706, 63.90198399943691, 64.82389003999772, 61.977261266400745, 63.17218388280561, 67.81276749026391, 66.17095747301656, 64.88258438725626, 54.58128321555353, 35.28941931263093, 22.560274947074152, 15.748342717847517, 8.672542841203752, 8.926758516219355, 10.300607892774767, 11.758139075771457, 7.0668632465024155, 4.019133573578251, 1.5194374611300807, 0.18043987573154513, 0.014584068483072183, 0.030323928071846886, 0.5357059187466099, 9.078377735230232, 35.87996744340466, 45.618204532131074, 27.2972390344066, 64.59030112912579, 87.94758796691896, 49.44334699261574, 42.7495438052762, 52.84181794812603, 55.179554493196555, 58.08827438662129, 19.0713188340587, 0.15046945893235747, 0.052258733720068014, 0.05199744794217329, 0.06062784209667195, 0.012311300116350815, 0.048708322217627886, 0.059271935418608694, 0.07201814843762307, 0.04024637547592002, 0.0604657915180489, 0.08293932934682216, 0.07016164926631797, 0.04640030614551037, 0.03951578423561108, 0.07750734461531525, 0.016794114358602993, 0.030188799738102866, 0.006862586418602376, 0.050005178838487596, 0.017022192140199968, 0.08593317797227253, 0.017533481136084567, 0.08184585374810043, 0.04196617774845612, 0.05161795479756209, 0.048924699921401284, 0.07686827406888047, 0.12829939534346904, 0.17174123846475156, 0.125619841949834, 0.17326117222828252, 0.1257602122401999, 0.12966902265625616, 0.15253670123075286, 0.1974485598264202, 0.14402298226712212, 0.15713321345467723, 0.22951415048972254, 0.2103853793514352, 0.2556372277678982, 0.14066984606606348, 0.17998647425443898, 0.12837729116360988, 0.1834509077091371, 0.15010066420560883, 0.07619311312033285, 0.12803560828850155, 0.2023119770831639, 0.292440336798468, 0.21606065062505586, 0.10690223020050796, 0.08586714119319955, 6.764474491919241, 59.77794516471125, 85.96400614707701, 81.15155604577835, 63.87722992127942, 51.623788649036044, 40.324546290982155, 31.82203035200796, 48.20460757901592, 38.93361499232631, 42.704067845498365, 30.917257224359822, 8.179862749192024, 0.8394084221893742, 0.44804302915450067, 0.16716087537427105, 1.441728076146495, 5.72707720341221, 11.639784497599448, 19.883833892883796, 20.513576307604392, 16.284347349597564, 26.946632092998875, 30.757424562208115, 23.430386089509536, 18.479929354883012, 32.2436616113109, 59.936997275198664, 57.51023469432708, 66.07096841258388, 59.70208652557866, 71.57783492918938, 65.054709757528, 61.52861272135089, 58.160398929349846, 60.88723067314395, 64.6800567257789, 65.3593014132592, 61.67673318616806, 59.77383844314083, 60.999747783907004, 58.78080021950507, 62.15836886436709, 68.48673266749229, 64.71368712763633, 56.73042043562859, 49.86459778201196, 51.23155947654478, 56.59849543725291, 64.43544595472275, 66.65401304921797, 66.15151036170222, 60.53448015643705, 56.316100474326845, 52.29611819790256, 57.42854741311843, 58.44846563954508, 61.408203801801136, 64.95726631533715, 66.52729695843112, 67.7253770828247, 59.94427327186831, 40.84977519127631, 53.52486733467349, 63.40077961644819, 68.03074144547986, 63.40712993375717, 64.41735598348802, 61.40208882670249, 62.247449813350556, 58.47217244486655, 55.43318671564902, 54.898391154504594, 61.11585386337773, 63.0040632524798, 62.019940576245716, 62.876158683530754, 62.15252453281034, 60.14018781723515, 61.76556702583068, 63.92774612672868, 61.56902882360644, 62.786822780486084, 59.826711993063654, 58.08199074960525, 55.040765347019324, 57.675546907609515, 58.98103329443163, 57.365695353477236, 59.941468777195105, 65.61799349323397, 67.48646551562895, 64.58711616454586, 65.51300341083159, 69.79195625551286, 69.14153314405873, 70.01727288769138, 56.19577000218054, 37.79898705021028, 30.40458186980217, 18.23621484541124, 13.523666531808916, 22.675800515759377, 20.809028840834095, 13.955143920836912, 12.039779963031894, 4.45814436481845, 0.8446315483700845, 0.19203103117404446, 0.18961290528457012, 0.23341036642030363, 0.9388105979850216, 10.993443592902153, 48.97715368578511, 75.95989119622016, 61.76570823115688, 71.47513158859746, 81.84189319610596, 53.1503672753611, 53.94161524311189, 60.78421354293824, 67.1620855023784, 66.56213545030164, 26.523657421911917, 0.36925073292466903, 0.09984806961109562, 0.12618882311207633, 0.1891803413990044, 0.09375094436109067, 0.0944850787580494, 0.09160427406670586, 0.1775415352876148, 0.13095894618140114, 0.1745904726727355, 0.16587470567995505, 0.14051757843023346, 0.17227316395409648, 0.09940425189392221, 0.14123299729920205, 0.1639810435834431, 0.1305943342947191, 0.12582929038833227, 0.0967164553942219, 0.09386907511901471, 0.15293068492845183, 0.13591443188488483, 0.12852141528480476, 0.15703565981839934, 0.15684946980928222, 0.20529696207133033, 0.18075055502835782], [0.03686250765777884, 0.022783554459531462, 0.027534241878217267, 0.04747909200828403, 0.051592585795949546, 0.024730034487982912, 0.040465744753037734, 0.029764827528607943, 0.012622465878995437, 0.02470938075754431, 0.01294121495448053, 0.051002303558972575, 0.02344180784759022, 0.04716691884001897, 0.037089380766114885, 0.03386752139176092, 0.03291476848385027, 0.07187882768771342, 0.08386263383492347, 0.028191409336643356, 0.06505924322071575, 0.023628811825126893, 0.07248926186753858, 0.06075283700239755, 0.10567612946033479, 10.231878161430359, 55.35173085428054, 65.2280314507023, 54.17003054772654, 45.212556931280325, 41.12918915287141, 25.86414617876853, 47.97891832167103, 48.01988747812087, 42.51842598761282, 40.94051138047249, 16.115389293239964, 1.4909796849373849, 0.1688647774919387, 0.06438644948385416, 0.12341100362039382, 0.8735385585215785, 4.2212351675956485, 5.917402861579772, 8.27010864211667, 8.15786462637686, 13.248919210126324, 24.65525992455021, 22.876449361924205, 20.526586809465964, 38.47927508815643, 55.43224926917784, 57.54248834425404, 67.46142510444888, 61.096877436484064, 62.43682576764015, 63.10262064779959, 57.90691183459375, 54.854468453315, 51.38732856319797, 53.883842652843846, 56.68657618184244, 61.37735436039587, 59.177430291329664, 59.11073823128978, 59.167946000253, 58.010717361204094, 58.590898667612386, 58.63999497505927, 57.98624961606918, 50.98458743864491, 42.962238250240205, 46.82335668994535, 54.7957544942056, 62.203629093785445, 59.53196940883514, 63.38396833788965, 56.54993649451964, 53.76092733875398, 48.67996354256907, 50.43897005819505, 50.17629285012522, 53.17302288547639, 54.87792030457528, 59.260058941379675, 56.28369777433334, 64.78098715505293, 32.978213679405954, 45.71559306113951, 60.67339874082997, 58.01117235614408, 60.961865532782774, 57.24074825163811, 60.09055806744484, 55.84700069119854, 54.26389286595007, 49.92455121009581, 50.018703783712084, 51.015099556215354, 53.878084613430886, 54.9226745482414, 54.88074833346952, 56.37550477058657, 58.94392767260152, 55.0401456125321, 56.917442967814786, 56.64165327625891, 60.13509265838131, 59.20212553393457, 59.124015454323064, 55.13565532622799, 56.88085509884743, 57.10138251704555, 54.92018384318198, 56.92609963878509, 60.08923230632659, 62.381924352338245, 59.560943957298036, 58.27599902306834, 55.57101488113404, 59.45675403841081, 59.68476533889771, 66.48555509505734, 56.7791715745003, 38.409233323989376, 35.04963697925691, 17.201287669520227, 15.366145007071959, 3.8091933679196144, 7.477170623117878, 7.638918872802489, 1.6543455445958724, 1.2540559014005046, 0.5352049585311643, 0.07247511988445636, 0.05266996588738215, 0.028780293463158513, 1.6118348966683111, 11.671172284310865, 54.06516990353985, 56.944899559021, 30.115552217729633, 18.48766426886282, 25.490220746686383, 41.99822556587958, 45.35718648664413, 51.78784570386333, 56.26465858951692, 27.547082247272616, 2.1636536669346595, 0.045304206695647976, 0.11966616666365056, 0.04721945331942651, 0.056021317103577245, 0.06297954050223194, 0.014120010722939287, 0.07619456102650973, 0.07029988983225438, 0.08932163082664052, 0.06362384725962916, 0.02280274304681488, 0.0627622243407513, 0.03255959096995573, 0.03765559635095058, 0.026541673465661948, 0.05394244176005164, 0.019684621553507545, 0.029267795428994204, 0.06794831400076229, 0.08587259573922043, 0.038898941730299307, 0.0374829622676536, 0.027305321399903586, 0.048230329318152326, 0.04348202060247141, 0.01556346688659922, 0.026880110043191144, 0.016969598288978302, 0.04392771906549892, 0.021105772109642144, 0.03677674028421602, 0.009427676221445925, 0.048596576802552714, 0.05459081261388717, 0.1177333957786041, 0.05837562786895902, 0.1412585999576315, 0.03284256852742645, 0.054155314611571456, 0.03449915705489055, 0.027194571899129983, 0.028850277510261344, 0.012927908007235778, 0.021473517295934504, 0.07431385347679739, 0.014996493832328388, 0.05548052797694841, 0.05076673152225633, 0.045007872395217426, 0.09198224652678737, 0.12534333783532345, 14.300418399995374, 66.85965507261216, 71.25255277079921, 64.46174544672813, 51.89291031129899, 49.90286442541307, 30.978224585133216, 38.34147830163279, 39.545900898595015, 39.668274925601104, 36.8741863004623, 16.383581353772072, 2.1150770735356117, 0.059822078478792985, 0.047180409648365555, 0.5546728461500138, 2.3818181022520992, 7.826719014875351, 7.357499599456788, 10.932248734658765, 12.508028591832808, 9.92557046874877, 11.761912395877223, 18.0981356482352, 21.142891183976207, 37.68513633358864, 51.53337017182381, 57.76195280013546, 64.1878463375953, 61.69399553729642, 63.28663864443379, 64.73176925413071, 59.6534687472928, 58.054855792753166, 54.36666680920509, 56.007515845760224, 58.840098611770145, 62.256773287250155, 60.1314958449333, 58.017295175983065, 59.827088540600194, 57.56075089977634, 61.31389433337797, 62.010428828577844, 60.03369546705677, 52.46168144287602, 45.71430260135282, 49.513043588207616, 57.136993715840006, 62.8547856884618, 60.94315582706083, 64.9147831240008, 57.7554298985389, 55.67505574995472, 48.65820615522323, 53.1737446015881, 52.21313261216687, 55.44055684920281, 57.42450344947077, 60.573225328999186, 59.67831303996425, 64.86114863426455, 36.0708103641387, 47.28918129397977, 62.62675477612404, 60.289045687644716, 62.72470028169694, 59.23004888719129, 61.605440185916045, 59.63850098271524, 56.58870127893264, 52.33896616966494, 52.32647342066611, 53.344328480382124, 55.112560410653394, 57.79582246657341, 56.88163172814154, 58.78136504080988, 60.78230334866432, 56.25071848592451, 58.89605122227823, 59.46697965745003, 60.86816403173632, 61.63144157778833, 59.146439644598196, 55.85781466576361, 56.21799807394705, 56.63432236640685, 55.87399444272442, 56.58686168732182, 61.468129773293775, 64.68399478543189, 62.63711375574913, 58.715912449744444, 57.20682367201775, 61.7097124745769, 62.31711502998107, 66.27770869962632, 55.284830908621515, 34.703883970937426, 21.929165586348503, 9.766294783161534, 9.206660812900914, 11.956861057589132, 13.315394559214193, 9.531937087735823, 6.811985671520234, 4.481486880010174, 1.7614739316125072, 0.26524789270854765, 0.08831894430782526, 0.10028545218970507, 1.5363783004783815, 14.436778618443398, 50.70276906413417, 57.22510583939091, 43.45373476705244, 35.50042713842085, 32.076676507149976, 46.74632133976106, 50.00561091207689, 59.41980923375776, 65.19535810716691, 37.40001532339281, 3.0740009728939306, 0.13144080016401508, 0.08668490174797275, 0.052622483757835244, 0.05544583568529737, 0.0316755848771502, 0.0848913366996473, 0.09297337277882523, 0.05458751460537315, 0.014284589391712461, 0.0610548441839074, 0.042195222716057496, 0.04120179820024679, 0.055686651593855316, 0.011068397152778364, 0.028542112897060094, 0.059688346340290965, 0.05041978945354781, 0.03128112045927875, 0.06531336990695807, 0.10721360663733176, 0.0728026301329655, 0.025791541237624425, 0.055619511648171374, 0.06991277028235697, 0.044921147411749254, 0.03577133798370919, 0.08169615250681678, 0.1736324490799058, 0.1924954336737433, 0.15283230391721572, 0.1505839737552789, 0.1077978176275088, 0.11553078574398834, 0.08884138562866757, 0.16692749434901824, 0.10472366000495612, 0.25034198206999614, 0.10420319519095844, 0.22512877209772988, 0.11754231046765082, 0.18766013184382072, 0.09761372821465616, 0.10806832327357224, 0.14248253266897895, 0.2107244805102387, 0.10798488863773885, 0.30395730428638, 0.10745657908339655, 0.20425967902185457, 0.19817614417162635, 0.35144372392565976, 20.831690334504653, 78.94623479535504, 81.75575010238155, 71.82452847880703, 60.474263929551654, 56.48539389333418, 37.55880071270851, 64.14897957155782, 65.1700392077046, 55.736935061793176, 50.40906983037149, 20.879847234295262, 2.414879515286415, 0.43121443700886547, 0.1504344946794933, 0.6100736894915181, 1.5818448220529866, 12.243578472445089, 15.190804273851457, 20.802378462206935, 18.70050580270829, 25.692301257964104, 37.91273186283727, 35.69368623918103, 27.667695130071333, 43.30377078825428, 58.99086275408345, 60.82979932908089, 69.33561986492526, 60.685848343756895, 64.78162650139102, 67.23155852287047, 61.96891054030388, 59.41128592337332, 58.83961223786878, 59.02490108243881, 62.740487821640514, 65.60159014117333, 61.72907329374745, 58.7319863227106, 59.38572383696034, 57.727698741420625, 62.34462653436969, 64.02733902777395, 65.09376479733375, 56.74589418595838, 47.411174851079146, 50.517801853918264, 59.18170959718766, 65.8414077758789, 62.85523283866144, 67.32142786825857, 62.038199209397845, 59.48620319366456, 51.02411708524151, 55.663822081781205, 54.09246175519882, 57.84319685351465, 60.12637715185843, 63.32132024149742, 61.75013249920261, 66.95923620654692, 40.06205343431042, 51.53588441110427, 63.97368492618684, 63.58506433425411, 64.34474898922828, 62.13723905624882, 63.85484495470601, 62.01765383443525, 57.74840885593046, 55.72018261878721, 56.3729787641956, 55.58882636408652, 57.526645891128055, 60.195610907769975, 59.78671950678672, 60.00385799715596, 64.4146534704393, 59.91551837613506, 61.44228527622839, 61.9457136431048, 64.0562782749053, 63.74383011171895, 62.00773808263964, 58.53745245164441, 58.29621884130663, 58.54669747814056, 54.86707495104883, 57.51856188620291, 62.392875609859345, 67.28289450368574, 65.254087755757, 63.700958605735536, 58.838843453315, 64.56336621315249, 63.71698148788945, 71.41763748661165, 61.12546759267008, 41.922233566161125, 41.96183381542083, 25.766485045033118, 21.789664529985, 13.086385015518436, 16.12561000931648, 15.543984290092224, 9.766297724939163, 4.0074454007610205, 1.4789947603018054, 0.22803730151105314, 0.2396241975046935, 0.21406514479989008, 2.127225144255546, 16.112046453260607, 65.93000627333119, 70.6276015312441, 39.56037444453086, 27.771394752687026, 36.347533579795595, 57.91167359198294, 59.01897830347861, 67.41655318967759, 72.93637137259208, 47.73166387311874, 5.300147802599016, 0.22717007465900915, 0.2012311955613475, 0.11870271916831694, 0.14603851363062859, 0.09660148091854588, 0.19814188471965252, 0.1679875455316036, 0.11838267061619029, 0.13699853822829264, 0.14528007126383244, 0.1796525518500036, 0.16132334667828777, 0.10589710752209348, 0.12677468885216983, 0.12256934878326232, 0.1968696884690754, 0.22636761288008383, 0.10466391280774148, 0.11759460362936221, 0.20769201339252535, 0.2148723869674629, 0.1596186171856619, 0.0916200478170668, 0.22275036020625025, 0.28568613793580766, 0.11321939888500399], [0.09005357421213582, 0.017703995071051103, 0.02626835436169659, 0.047216526863555756, 0.013856396995364659, 0.03733085167984809, 0.07027173610103708, 0.04869571241039423, 0.057861797376385624, 0.04163812740796036, 0.04225981541939321, 0.024550465393751383, 0.03423563813069656, 0.06239056827560548, 0.027632408384834568, 0.0909070574468182, 0.009911571828378065, 0.04393206661446922, 0.03146521713314278, 0.03144062188033375, 0.06461397759736547, 0.026511981812936646, 0.013610736538295545, 0.11715393453355759, 0.48905888632420574, 30.576864134880807, 63.32060637012605, 60.098838190878595, 51.32938731101252, 37.10714370973649, 24.38538124484401, 22.58204802390068, 52.47226007523076, 47.41226134761688, 44.05430847598661, 31.266320713104744, 4.073975417883166, 0.049689282482910546, 0.03906662305516582, 0.055734838524292556, 0.5066286532148239, 2.1866255181451, 7.069026923948719, 9.379603016761042, 10.006955727454155, 12.34947560294982, 6.990206405039757, 11.705802890562243, 26.161146087031213, 48.85984343867148, 61.07893651531589, 64.21380066102552, 66.81868199379214, 64.58923816680908, 61.97472349289925, 62.079490000201815, 59.91248638399186, 57.347621071723204, 51.48273629526938, 48.84460895292221, 51.67663474236765, 58.25652445516279, 62.6639231558769, 58.556260216620664, 58.48295504047025, 56.28877724370649, 58.557809552838734, 59.39934622856879, 59.77417968934583, 56.523189852314616, 46.43309262491042, 43.057045859675256, 48.92278179045647, 54.37374668736612, 59.34056558916646, 59.187726513032, 62.744998547338675, 55.035897685635476, 51.46192812150525, 45.09361497817501, 50.002818184514204, 47.464946623771425, 52.26212693798927, 51.41379671712076, 60.571091559625444, 56.777594781691036, 67.18576877347886, 35.340920032993445, 44.08203178836454, 63.353079672782656, 56.29863415994952, 59.535126916823856, 55.449954848135675, 57.33061367465604, 53.71138388110746, 54.78679187836186, 47.35461819556452, 45.25303186908845, 48.19037722003076, 52.36446549815517, 50.73203386798982, 53.24545729544855, 51.16596175778297, 51.219929648983864, 51.563207641724624, 55.338955694629306, 57.52958766875729, 58.396521691353094, 60.372945185630556, 58.513325952714496, 58.52657964152675, 56.26303472826558, 57.61990808671521, 56.02875548024332, 59.50892548407278, 58.08339888049711, 62.982396079647934, 60.823500002584154, 58.758933005794404, 56.94808452360092, 54.72311219861431, 62.472974331148215, 61.16886861862675, 55.448511415912265, 49.30301243259061, 35.38913380715155, 21.15295990820854, 7.970585669240645, 8.748307343452208, 16.19567530770456, 4.974609709555104, 6.938672834827054, 5.152386234652612, 0.8378756947575078, 0.08622442161844623, 0.07105036488463802, 0.029862224116861343, 0.023570554668924982, 2.986333057765038, 17.149526111541256, 39.62195173386605, 34.3596096961729, 21.200095030569262, 20.042311376140965, 27.754375588509347, 47.66616029124106, 57.373092943622225, 52.91414645410354, 46.542287488137525, 10.282632650867587, 0.5194694512794095, 0.06228002561857143, 0.07145177197432326, 0.09124020610245005, 0.010720682292876225, 0.012433961326737079, 0.07188818162126888, 0.05389040906823451, 0.021754951186237798, 0.07533155531892854, 0.05783026902786186, 0.0405215772409593, 0.042124007182616385, 0.05571538372145546, 0.02428483206688637, 0.04459299364938371, 0.04813637629511857, 0.021100951501378612, 0.02371320407086563, 0.030215723898201704, 0.029944477062071526, 0.04555148072540761, 0.04916134831165114, 0.010312138136566408, 0.019329135689223488, 0.0317526686440913, 0.05420267416705048, 0.029921038602028164, 0.002249496770204015, 0.054939018727670756, 0.04452768848427842, 0.04278670771107559, 0.057553699795877745, 0.05190305824902269, 0.06809204741711579, 0.025886892371119994, 0.04537970849102543, 0.017713345174166947, 0.08575032044562601, 0.04931719357808752, 0.02523711191550378, 0.025546806789333784, 0.01168512761773121, 0.10676810352672493, 0.04074548175858875, 0.029847902103116917, 0.007264572862280353, 0.05729165559093799, 0.05596073104008552, 0.06256272355394979, 1.0450533873611882, 40.37174417126564, 72.98049803703063, 68.87344698752128, 57.63880606620543, 45.726132469792525, 34.17421102523804, 30.550841169972575, 57.21910853539744, 49.235159350979714, 38.46173032637566, 27.812426667059622, 4.310116075700329, 0.15914695217244088, 0.0739432201390305, 0.32175499765623006, 1.3633691711771874, 3.7211949931037043, 9.405123918287217, 11.922186324673316, 12.930429616282064, 13.232470750808718, 8.569437457669167, 15.33731068334272, 31.597798255182084, 49.91198785843388, 60.69366562751032, 66.72252116664764, 68.47453409625639, 66.54009172993322, 61.34212363150812, 64.32112063131025, 62.678071145088445, 59.688322928644, 55.754099353667236, 51.621843153430575, 54.97885465621949, 59.93796610063123, 64.84673000151112, 60.220212013490745, 58.51590687228788, 55.324376244698804, 59.069259166717536, 60.95535439829673, 62.01763814495456, 58.83416014332926, 47.47718049633888, 45.805329045941754, 51.46961988941316, 55.81782610185685, 61.16451086536531, 61.27086985495783, 64.56925761315131, 58.11951606504379, 53.33418915348669, 48.21034992894819, 52.23102646489298, 50.06998092897477, 54.87800659671907, 54.23336505889893, 63.6595501438264, 59.75720367124004, 66.76254503188595, 38.24005365371704, 46.93328895876485, 64.23527956008911, 59.615178569670654, 61.313768817532456, 57.96389602845716, 58.36087126885691, 55.478031173829116, 56.76243874334521, 49.33620745135892, 47.00031442026938, 50.25601894624772, 55.686108989100305, 53.353757858276374, 55.65201182519236, 52.21351308207358, 54.2301957837997, 54.675467168131185, 56.60354745003485, 59.18175666562973, 59.97715842339301, 60.3611231619312, 60.677772183572095, 60.438503680690644, 56.3479854214576, 56.160209794198316, 54.89795577141547, 59.09404854620657, 58.33446979522706, 64.0631934135191, 63.31396187505415, 61.75312526764409, 58.764043854128936, 58.21883832254718, 63.455304484213556, 64.80825939486104, 59.1085534711038, 49.62252086208713, 35.40885156200778, 17.037046263294837, 5.193738802786797, 8.076329827308655, 12.869314186034664, 14.803729095766622, 12.729541505536726, 8.168391777623086, 3.4206267085767563, 0.3251841604228943, 0.11011426832767264, 0.006246042687581071, 0.1541270231527667, 2.7052685137717956, 20.166854473852343, 48.38589952838037, 37.61543973799675, 22.616602143933697, 27.48021171938989, 38.457831490424375, 55.73092599068919, 65.20460705603323, 60.40820337110951, 55.63018383518342, 13.442122417111552, 0.586567047622896, 0.02007258380012166, 0.023366074310615662, 0.024457946870355837, 0.07220553354390206, 0.07975470184558824, 0.04872924407883998, 0.02747538717343442, 0.05779309844177577, 0.029413078258174564, 0.1091067860984514, 0.029941349508120652, 0.01857524579991737, 0.05344849507955294, 0.05101828415307307, 0.07174735933902764, 0.01592902393425785, 0.03218412744782625, 0.030274806514142022, 0.040549627550306826, 0.07222224958240986, 0.027523125942435958, 0.029184196084257097, 0.042518017693392696, 0.02580389823584307, 0.03964984579192054, 0.2389776805836347, 0.14793451995618884, 0.11316362768411638, 0.1415857807883332, 0.10250669348263934, 0.11529993280888566, 0.16628735127948946, 0.1399359951216367, 0.13659563726715504, 0.10250339164368569, 0.1308651770194692, 0.08672879858603401, 0.21950522708075665, 0.1424563018184516, 0.10941458490466881, 0.15022918311578615, 0.07590203801350248, 0.22735416558721375, 0.10487379025547736, 0.06773659794200813, 0.11777988965472869, 0.14169516282216196, 0.10414469671706039, 0.20022605756117454, 2.3893100744293583, 49.86278956936252, 82.34643551611131, 76.91031286793371, 67.50785812254875, 52.54709497574837, 37.50848062576787, 35.059078124261674, 65.13678143101355, 61.679518068990404, 57.2117893926559, 37.83639861691383, 5.56084176225047, 0.29933004129317503, 0.1455433297181322, 0.2559927691735568, 1.2019481942538293, 6.814465099765409, 14.925347085921997, 16.653083485941735, 21.008506859502486, 29.910298508982507, 18.607810389611032, 21.715674900239517, 33.09904229256415, 54.07712921019524, 65.72117536298691, 69.55925772267004, 70.33171361492526, 68.3741920225082, 62.08413800885601, 65.85211584644934, 64.89713245822539, 61.95615891487368, 57.69536664409023, 54.45944655326105, 57.926339334057225, 63.64678675128568, 68.34531553329961, 60.954107084581935, 58.721635187825854, 54.84726698167863, 60.491596883343114, 62.63598803550967, 63.87244070729902, 62.36972185873217, 48.792237466381444, 48.761160527506185, 53.559599922549346, 58.265392934122396, 63.35839840673632, 62.346058199482584, 65.85754440676781, 60.061952221778135, 55.80141490505588, 49.29508532247236, 54.85739846383372, 53.154599512777025, 56.342003806944824, 56.89373616249331, 66.24217987060547, 62.99144498763546, 67.89914592619866, 41.56605489792363, 50.24648366435882, 67.17161686189714, 61.3297720878355, 62.819041129081484, 61.89811960343392, 60.9545228558202, 58.433462573635964, 59.25719561115388, 52.50782812795332, 48.57871540131108, 52.39582092531266, 57.771590063648844, 55.46698577942387, 61.15961574739026, 56.06841848742578, 57.03367456313103, 57.71360958776167, 60.09925788448703, 62.31550293584024, 63.277542668004195, 64.1616762838056, 63.047397598143554, 62.8539502236151, 56.85113137768161, 58.438204719174294, 56.28411354557161, 59.913266935656154, 58.91039532999839, 66.6093058739939, 64.56948118825113, 63.758793953926336, 61.87651126615463, 61.349019158271055, 68.10077928727674, 68.20924066728162, 61.544772886460834, 55.43896828928302, 40.963861250108295, 25.27674771124317, 15.325893644363651, 17.264671210319765, 31.13723747191891, 16.931044209387995, 14.588692015217198, 14.018452936603179, 3.227983419933627, 0.5395086566286703, 0.21940425669233646, 0.24211972891803712, 0.28177780249426443, 4.30094704512627, 22.548080298208422, 53.911758161360225, 48.21571965371409, 33.01240105782786, 29.68595462460672, 42.59878750770323, 60.92566597846247, 73.45136288673648, 67.05346722756663, 64.89665785143453, 19.19243181905439, 0.9563877806067468, 0.1784295384441653, 0.12077013766693494, 0.11589109221653593, 0.2206161924667897, 0.16644749429918107, 0.32882733751208554, 0.14440420294000259, 0.26473528795665313, 0.16455518051741586, 0.1935259598277269, 0.06982339846511042, 0.13806784375300332, 0.16681622773889573, 0.163280563428998, 0.1435552855893489, 0.14107127613838644, 0.15012088892680986, 0.19613623589036927, 0.08122726073188168, 0.19753955575006624, 0.17256196377979172, 0.09862536264042701, 0.1901169758169882, 0.08347559855469773, 0.19497120001864052], [0.07732909127709366, 0.02478011748603275, 0.043150557340272976, 0.05913302069529892, 0.04963940632860026, 0.036358096216234474, 0.05371343509684648, 0.06730784151342607, 0.024983080990251996, 0.008990055197970042, 0.046117286453203815, 0.0814605728092213, 0.039431924420979717, 0.021134942822578936, 0.06613682249500867, 0.05963739000200745, 0.05100671239497681, 0.04233418340464273, 0.11303366086776219, 0.017093334895288272, 0.03343967660780876, 0.0688301348277638, 0.05163994152098895, 0.09610244358379035, 5.805113248286709, 54.44263919707268, 66.26046596034881, 59.16824017801593, 48.69329567878477, 35.0366029431743, 27.492688778908025, 29.58025851557332, 36.18083676984234, 45.242719957905436, 32.87219789720351, 10.465925009019914, 0.4895341672724294, 0.1685503596860555, 0.0321513656977444, 0.2859811430736896, 1.257123194875256, 4.461405815616731, 6.033035314852192, 8.179165547893893, 8.857996425321026, 8.263906394281696, 3.768024660887257, 30.91952435431942, 60.16753458207654, 62.85398944731682, 65.38672270313387, 59.63521403651084, 63.43726942616125, 62.51814042368243, 62.470479703718624, 58.85028892947782, 62.79592267928585, 55.027444977914136, 51.340781796363096, 49.51343974759502, 52.188908053982644, 54.395327568054206, 59.42583791671261, 60.00473660807456, 57.23047948652699, 57.70886744222334, 56.80210567289784, 55.42716587743452, 59.8370199818765, 54.294408905890684, 46.23662110297911, 42.34763030082949, 47.37893296826271, 55.4562698641131, 61.96128153031873, 60.201761184200166, 61.858617413428526, 58.24292559777537, 52.16750760232249, 45.87709273061445, 47.27281716562087, 48.59884108266523, 50.642937229525664, 49.75874477817167, 61.4669648293526, 56.5978874698762, 66.29331188817179, 37.44545205946892, 44.04907995654691, 62.70089933949133, 52.2585379692816, 58.40567650333528, 53.50361201070971, 56.1912553541122, 54.089990661990264, 53.22216233899517, 47.19993952781924, 46.604492356700284, 46.139173738418094, 50.53014163048037, 47.13621670199979, 47.342768715273955, 48.26827941402313, 47.60401818060106, 49.12038687736758, 50.58794559970979, 50.579645864425174, 55.60141717233966, 55.17019179559524, 57.71370764701598, 59.88328433805897, 60.653378963470466, 57.29870911567443, 56.67422463816982, 55.901329440455285, 58.9168829302634, 56.13060766650785, 62.99376703077748, 60.04561555001044, 61.04144257883872, 52.910373133997766, 55.58932842746858, 62.71492573522753, 68.46701883500623, 61.93493496987128, 44.948969733330514, 25.0111855999116, 13.792191993805671, 12.84772938297641, 10.184355705015122, 12.741803815287929, 9.940459785922881, 5.233311595455294, 4.429080582434132, 0.5745931546534262, 0.11380398525826393, 0.07342247187250084, 0.020312300372508266, 0.15474756969319237, 8.907379065790485, 32.571263851657996, 45.77893541705224, 39.20818090438843, 15.48233247572376, 16.70934988606361, 33.74882998005037, 41.35760837985624, 46.44341630320395, 49.35768242805235, 26.59859234286893, 0.6499827028282228, 0.037143880261048194, 0.06586100019875073, 0.057883052485844785, 0.02165664678379413, 0.068232616890342, 0.029285388638175307, 0.030660043402965513, 0.06186251919115744, 0.060304526179548235, 0.03947443463989804, 0.043828575796778166, 0.05851885949772212, 0.05658353753988782, 0.03654327115885193, 0.03081700715777134, 0.0807575875472638, 0.01337440032887483, 0.06264025165188698, 0.03917440779567246, 0.04855156913700123, 0.012879961436884779, 0.054315840675225185, 0.036836211689777916, 0.021213993520265626, 0.13045562641514888, 0.01509940721124651, 0.021931118850085526, 0.01489022020025239, 0.02361530952546145, 0.059359311576812505, 0.03916410008265127, 0.026075767518411723, 0.027443077415227893, 0.029533039966237642, 0.02948806677464276, 0.025691959383567015, 0.06906418234951074, 0.006929566922237076, 0.042610342779587355, 0.03889894556073893, 0.020115147645194686, 0.022847584088242823, 0.01378229331044901, 0.01261169755560977, 0.04245478479612259, 0.06741916941058251, 0.13683910000949137, 0.022519001316639687, 0.05726112698715541, 8.638834972535411, 63.736742388817575, 71.7717961342104, 66.56333569557437, 56.889684354105306, 41.817635720775975, 34.62595039798368, 25.390451338983354, 41.395784808743386, 48.147513558787686, 34.43473877445344, 11.962912294172472, 1.0254317918612113, 0.28412377822303003, 0.05337460972969571, 0.916098787659599, 2.7902902999231896, 6.148880066410189, 9.843850827986195, 10.514069161107464, 12.45206323362166, 12.773016075934134, 10.014745554616376, 31.56583093827771, 52.314823981254335, 66.05305102563673, 64.23575024450979, 63.97206890967585, 65.96785714549404, 64.38014838003343, 60.74927306944325, 60.68740944708548, 62.44652578907629, 57.59655821707941, 52.56019569212391, 50.74353033496488, 53.251285937524614, 57.60940790176392, 60.97553107046313, 61.96666694456532, 56.505186173223684, 58.32292625980993, 57.66375626287153, 58.334458028116536, 61.80151554845995, 55.78800824380691, 47.93700387400966, 44.83611922110281, 48.175221181684925, 57.343894820059504, 61.777694994403475, 61.77444334953063, 64.13147795584895, 60.00054751673053, 54.15529812535932, 47.37981550155148, 49.57278128593199, 50.50228495751658, 51.92355578945529, 51.585047398844075, 63.322932335638235, 58.622599263345045, 68.00818781698904, 39.57345554905553, 46.25558968513243, 65.15943311875867, 54.94210989244523, 60.692300642690356, 55.96004339956469, 57.486731852254565, 55.80392914433634, 56.84421231669765, 49.780306047008885, 47.88642883300782, 48.07514582910846, 52.47549603062292, 50.82109520512243, 50.2320493421247, 50.180780041602354, 49.92539451968286, 50.83156793348251, 52.60561673871933, 54.361116655411266, 56.92472680922478, 58.60728633019232, 60.1770894758163, 62.19736114625008, 63.111846062444876, 58.04832504641626, 55.396649837493904, 56.877117080073205, 56.47294429040725, 57.22249354085615, 63.92266273498536, 63.59029677606399, 62.2243352859251, 56.41092377324259, 57.42143615599602, 65.36152931951708, 67.67537470786803, 61.962501387442316, 44.318319289915024, 26.871738356928674, 10.262908031863551, 8.552823278211779, 10.322922256685073, 12.513059031578804, 9.053419693823784, 8.70130067871463, 6.861085411041015, 2.30058606113157, 0.5164666317643658, 0.09494925909225019, 0.05747280091107373, 0.2882507551581629, 8.58610753090151, 35.492103868915194, 49.893548796253825, 35.24214298494401, 16.731995690253473, 25.856989814389138, 38.868131022299494, 46.1543180096534, 55.192039397455034, 56.49488602915118, 33.23376786324286, 1.1469238371618333, 0.021762527795808933, 0.024236526392820864, 0.01628472526077061, 0.0732981511241486, 0.03685066393846947, 0.056533657555137916, 0.02621260422822689, 0.0484146309205361, 0.053895419283259305, 0.01903319592407394, 0.0841741405066944, 0.0319637852390447, 0.09988076624370391, 0.018967603475997047, 0.027700513601303104, 0.017466155414078987, 0.034830808008630434, 0.02459728102680416, 0.028774942339007414, 0.023416858279116215, 0.02032031556741605, 0.02701243641035211, 0.0447375123058596, 0.03404330026598708, 0.12225983394009453, 0.13964244555081093, 0.14919758443870854, 0.1768326588095196, 0.09367661084979774, 0.1958110622100292, 0.2262164637326233, 0.1932743765533932, 0.1845412806517655, 0.12367987749917854, 0.04558248047326361, 0.15044888181071128, 0.17637124405272547, 0.1719022854681938, 0.09241866383461222, 0.18129058572794163, 0.1398053771305469, 0.10670912241743458, 0.12646612395802814, 0.18649307349997182, 0.11337660778794559, 0.21841580408715436, 0.23660705214546573, 0.11119358662155368, 0.1575054862206021, 12.293142522535017, 74.61872300794049, 80.1507789857926, 78.04772177050191, 62.422187482157064, 49.07498544262302, 36.91010736650036, 41.73766251533262, 48.62352063578945, 59.09549197842998, 43.21270904233379, 13.0110284397679, 1.0149746916947826, 0.4549500165927795, 0.18507754219876182, 0.8131239455073112, 4.96736950451328, 17.14393085049045, 17.602597128960397, 22.096586073598555, 23.710007936723773, 18.862166289360292, 14.516771435737612, 35.59542302162417, 63.23283549278014, 69.27246186041063, 69.86934461901265, 63.35589201219621, 68.59822996201055, 64.47139839972219, 63.548601981132265, 59.88327257094845, 67.01024270826771, 59.00978426779471, 56.31548466220979, 54.4457535589895, 56.468653217438735, 59.19661852621264, 64.08692767543178, 62.38218715113979, 56.715911588361195, 59.304009099160474, 58.23126831362325, 60.46148876990042, 65.36179996305897, 59.498260559574256, 49.56370099898308, 46.53336017362533, 51.624604502031886, 60.77221109021095, 64.17040747980919, 63.36913785626812, 66.23555106501426, 63.56310298365932, 56.78430987942604, 50.55113023327243, 52.45872789813627, 53.19430958840155, 54.17085424546273, 55.23875874857749, 66.4265077344833, 63.28139835788358, 68.43649495032527, 43.02617680641913, 50.117527900203584, 65.43642305558728, 57.34329469742314, 63.19707524391913, 58.97601266061107, 59.83921258680282, 58.71238231658936, 59.374517625378026, 52.70837107012349, 51.69993754356138, 51.0879183584644, 55.87128408493535, 51.84960734459662, 52.69715309143067, 53.809945198797415, 52.55237056363014, 53.80647390119491, 55.41048011472149, 56.25636669897265, 60.01099671086958, 60.637195264139486, 63.05411661824873, 64.38272537723665, 64.46592669333181, 58.82524067355741, 55.13321168961064, 57.316967748826556, 60.150911577286266, 57.32917808717298, 67.25919554310461, 67.17615112181633, 67.6242583797824, 57.63908455448767, 59.874400169618674, 67.94801081380537, 70.30044447991156, 63.17889113580028, 47.65977859497071, 28.251379113043512, 20.08418660010061, 20.673901227212724, 20.078942391180224, 21.322953470291633, 22.20241358203273, 15.907608597509324, 10.478896287179763, 1.9529591404622602, 0.33608163857171613, 0.2027902457742922, 0.16742984884448592, 0.3705106411249407, 11.541129043025355, 44.32593653278966, 61.7469749912139, 52.99073857645835, 25.51107010533733, 27.117382672525224, 45.966405099438084, 56.21584861509262, 63.425729813114295, 66.13729569219774, 39.87127719386932, 2.0527709587927787, 0.15548056261914392, 0.14411334999867026, 0.26153907720600406, 0.19372917231052153, 0.14236421804995308, 0.14368542860592567, 0.12054935878803655, 0.15485566469930834, 0.17129620266777856, 0.1073241301421677, 0.11578536442210598, 0.1930280026769446, 0.1387019040844133, 0.09271789011695693, 0.20479247785143315, 0.20693721760424877, 0.10819215372565294, 0.1796593853542882, 0.1251433659044485, 0.07448861345408425, 0.081138264297718, 0.12047948390846291, 0.2091714823918958, 0.06962098271375702, 0.27573548317436253], [0.08488330809820084, 0.07015769625262869, 0.0628352286894956, 0.02712568718819849, 0.04338953463781265, 0.08994214672354922, 0.02659887725096797, 0.021947741042822603, 0.049750090711900306, 0.01934140458733084, 0.03756471917093281, 0.036916899900402755, 0.06071920957296126, 0.06330244656231615, 0.018868425733319694, 0.04625503289242906, 0.06173995278415181, 0.1042376921301888, 0.052643317518936056, 0.003966173882814004, 0.06722654426290144, 0.06689143442218343, 0.02419865675150387, 0.1803345233201981, 24.435944518735333, 59.74588371092274, 61.55435131442163, 54.26660322373914, 43.54089375465147, 29.047078970939886, 22.646798510705274, 33.78005596899217, 49.110000441151286, 37.73402083304621, 18.61416070692001, 2.3880853143430527, 0.08836214400587544, 0.03165733283235422, 0.053637504292231415, 1.3601357898404522, 1.9174968691602832, 3.3885958983052165, 5.005811183683334, 6.898408234119416, 13.386682656503494, 8.796883936851255, 15.029650753544225, 46.950672903368556, 62.727363571043945, 64.82097571895969, 58.63470762006698, 60.10166621977284, 64.59347432659519, 62.79989604027041, 60.51723349478937, 60.451000352059644, 59.03397352464738, 54.71164318823046, 49.17210725045974, 47.195154236209014, 52.26348407806889, 55.73348337604154, 61.31096824522942, 57.64935724196896, 57.92977140795801, 56.581256620345584, 58.32801357392342, 57.39859619448262, 58.593805143910075, 50.369277384973344, 43.35305929183961, 42.46699586991341, 48.27439438912177, 53.40714916106194, 57.945202012215894, 59.87969929172147, 61.40128866318734, 58.523512348052, 52.228429855838904, 44.020819279455374, 45.82015168282294, 45.555281869826786, 48.92224442574286, 48.460914857925914, 59.87774595137566, 54.89757530150875, 67.93494147639122, 33.43943342085808, 38.64257904791063, 64.76922396690615, 53.38763929182484, 58.314061703220496, 50.39090925647367, 55.1161729135821, 51.140360447668264, 51.708739342228064, 44.92267808606548, 44.37740195182062, 42.76748472644437, 46.02986904882616, 46.09212098583099, 48.44432323209701, 46.350456130120065, 44.79489511059177, 44.790925671977384, 46.59494923007104, 46.33423712945754, 49.47070944693781, 51.61966231561477, 53.67986371440273, 53.85353057615219, 58.56754879797659, 56.396865998545, 54.80221463787941, 56.10364529394335, 58.78249076104934, 58.1748136397331, 60.32498244316348, 61.01015383197416, 59.180556420357, 57.74264689414733, 52.40877259162165, 58.069031238555915, 60.23929434437906, 62.38423070599956, 63.13865546257266, 46.270016162626206, 17.32076894852423, 15.414076370577659, 8.566704546251605, 13.070909304003562, 11.790757506124436, 8.032185021908052, 4.97901943422133, 1.2821032996139219, 0.6694792114919232, 0.1161557143073409, 0.14258903421221242, 0.03733820229348156, 0.9479971566507894, 16.658372802119104, 49.297073964149725, 40.3883397194647, 37.339187206760535, 21.056730439586026, 48.17062808621315, 37.504009123771425, 53.18333479665941, 55.166740109843595, 36.75205153803672, 7.19862497621967, 0.09098738176567901, 0.033570895977919145, 0.004441041382960975, 0.026555300254615086, 0.0324811244143113, 0.02404977139385958, 0.04451607076090671, 0.0621245825482953, 0.041572439198892926, 0.05421998009325997, 0.013488713096106246, 0.054216283719025316, 0.029999426633660353, 0.035842986356827526, 0.043752342387433016, 0.02672080205933702, 0.03165558423666704, 0.04882983142329801, 0.026652258257531834, 0.03517203506142382, 0.03711556565136679, 0.03163981623196554, 0.009342969879658233, 0.03846631272726002, 0.04295577565508504, 0.020486146789945422, 0.011562850408916994, 0.0270056163126062, 0.04999991581444779, 0.03666058986357624, 0.049193022216880516, 0.03391803339904836, 0.0405949033466318, 0.02518480343203391, 0.01884313908615901, 0.038964373299912106, 0.04465285575978699, 0.006321513839441562, 0.04171846704857965, 0.04117607296774945, 0.044299080186793884, 0.09983240311304409, 0.044785955875751474, 0.05893779084867528, 0.0348159650550975, 0.0665370804528075, 0.04500784175170045, 0.02926792183350171, 0.3404404337127363, 30.347546685126524, 68.35419577936973, 71.08324758468136, 62.1685121136327, 51.368450195558616, 37.440451037499216, 33.01362483732162, 41.362554488643525, 51.63704626021847, 42.21727817289291, 22.332230306440785, 2.396389952590389, 0.11126013667953592, 0.02681943204914851, 0.15968050176818527, 1.8346258901780652, 5.198832000455549, 7.4414643068467425, 11.448559145773611, 14.853048978313325, 12.313098561379219, 13.700743894423209, 20.41450312060695, 48.34705237419375, 64.06731974694037, 67.4501443678333, 61.5177163770122, 62.73232536931192, 65.66910197657924, 64.64801880621141, 60.162039341465125, 61.24184823805287, 61.31661645827755, 58.09153387623449, 51.01034956593668, 49.009968234646706, 53.911828764023326, 58.83832962282243, 63.56703319857198, 59.42244506651356, 57.64558784423336, 55.968503952026374, 59.91733835589502, 58.60365813778293, 61.54246261042934, 53.01060538138113, 44.64392308265933, 44.77889576265889, 49.878965423953154, 56.04643752498012, 61.02243477298368, 61.258024092643495, 62.04400823962305, 59.535397560365745, 52.34738357605473, 45.54924926450176, 47.54667705105197, 48.11387923456008, 50.32450745182653, 50.217395367160925, 60.97201662678873, 58.01445145760813, 68.21733643931728, 36.052139882118475, 41.243353659106845, 65.46682142442273, 55.0738936854947, 61.34648530713974, 53.15405822569325, 56.51127761410129, 53.46307039260865, 54.87894404319025, 47.06489624515657, 45.78246555020733, 44.35648002932149, 49.26600487001481, 47.836697101593025, 50.86959923467329, 47.87991769852177, 47.522491716569476, 46.539255495994325, 49.48766977556291, 47.64468139217746, 51.58798133173297, 52.341515710276944, 57.59626011694632, 56.34291771919497, 62.15210876157207, 56.444981713448804, 55.149768014107984, 55.79224832596318, 58.22115644331902, 57.11333005659042, 61.99755953204248, 63.26114716068391, 64.72849799740699, 58.30498141627158, 54.57670973193262, 60.58804796588037, 63.31991211060555, 62.05229228542697, 65.25283259730186, 43.21007713194817, 22.699717167885076, 10.515774411539878, 7.632006675966325, 10.778206471473942, 14.3651286825057, 9.99784896450658, 9.882396940262089, 4.407338884568984, 1.9221703732205977, 0.13355779221221326, 0.06684242011678797, 0.04283095694958203, 1.1261087992498953, 17.236194802868752, 46.697891835243475, 40.40663757631856, 32.70131591827639, 22.08036118938077, 52.96705530535791, 46.24576414785078, 58.88073828912551, 65.18640333606352, 45.32682734151041, 9.434974135891084, 0.02728131603479626, 0.05549849273877279, 0.008154595139316254, 0.040695111477567304, 0.021865072494913495, 0.033800090332665754, 0.05438996351233894, 0.04554237577042753, 0.02641546431057636, 0.02224554240162815, 0.02347107049107792, 0.04450914149563159, 0.04130520474826617, 0.01763048510427677, 0.03936173927579676, 0.011462342546081111, 0.01380936302725346, 0.015079123118231374, 0.03894923540252832, 0.02727973980889205, 0.037593359367982034, 0.03480690223495326, 0.03196002183211667, 0.14764708376699878, 0.07790055456421069, 0.18479562184262663, 0.20271789643072313, 0.17146739267533825, 0.13210236305190673, 0.15567608357917878, 0.25008868275871204, 0.13023310851666237, 0.09889397604931748, 0.09684628431474972, 0.09518292357003498, 0.17179440496669662, 0.10577844816350168, 0.13215997286381262, 0.17125019142704626, 0.10609323369158853, 0.1416680892749179, 0.1715925714421657, 0.13977548437974147, 0.09678505090696198, 0.1124673763350133, 0.22043257651309814, 0.15739950561715713, 0.19468422348220504, 0.4242087774459393, 37.29990859185496, 77.48822704438241, 77.40890887475784, 71.00570232637467, 59.910666404231904, 44.094289195153024, 34.18324816611506, 48.58505395150954, 64.06373077823271, 50.49770755152549, 24.682716515756425, 3.616871468482479, 0.23365413559780968, 0.131977490720249, 0.2665972799783753, 2.304113497657161, 7.406070799596849, 10.411854155601995, 16.881534091887936, 22.704100416552638, 26.375833096042758, 16.599401927763417, 22.533655781899732, 51.08537274022257, 67.84565264178862, 70.5380145965084, 63.03660323542934, 66.09755423761183, 67.81134759226154, 65.80156041729835, 62.75206665838919, 62.71503163922218, 64.10124040419056, 61.214697591720096, 53.68394690175211, 50.017397634444706, 56.986900298826164, 60.90807022586946, 64.9765839884358, 60.70736254415205, 58.09478944347751, 56.47579585352252, 60.83269011589789, 60.888450530267534, 65.17294176163213, 56.10288043175974, 45.71922517591908, 47.502581765574796, 52.945725456360854, 57.86727628400249, 62.53171182447865, 63.91941501248268, 64.90436530882313, 63.20504550010928, 55.1492698730961, 48.348597788041644, 49.20330578281034, 49.71407682664933, 53.43960285186768, 52.35690709083311, 63.08489153462072, 61.33353756320093, 69.18365155496906, 37.81009520253828, 43.96258777187717, 69.22009037386987, 59.230892196778335, 63.727611111056426, 55.43360248688729, 59.04224972571097, 56.6352637352482, 54.72601083017165, 49.27515575962682, 48.4348036396888, 46.453237918115434, 51.060971675380586, 50.627749812218454, 54.3166369776572, 51.82600252089962, 49.48902299327236, 51.24546035643547, 52.47087547855993, 50.93359270403462, 54.30368138897804, 56.51442335497949, 59.0086938488868, 58.92446879417666, 63.50375752295218, 58.99667570667883, 55.43578724707327, 55.6905020436933, 59.17448851370043, 57.816305083613244, 61.70457809202133, 64.84209768233761, 66.20491735396847, 63.240295840847885, 56.53739275470857, 63.325199465597834, 63.48054493627241, 68.29651340361565, 68.58410158464986, 49.33844712472732, 20.938186607053204, 23.11535896793489, 16.637646998128584, 27.967091606509303, 24.196201409063033, 15.878158461663032, 14.658672982646575, 5.294200999121513, 1.6337589847464717, 0.21921659579440472, 0.530292741473644, 0.1360367148393585, 1.4297538154548215, 22.008301365760065, 61.72429584687757, 53.40923193962344, 50.80392306850803, 29.162531975776922, 59.791642081352975, 50.85101504479685, 68.37721224754088, 72.75915084346649, 54.078937422844675, 11.226606926610394, 0.20414038381028562, 0.1580066149753909, 0.11022925812510714, 0.2262084810964523, 0.0986352221920125, 0.14045002479707042, 0.16996705544091043, 0.1257640043754251, 0.30779880621740896, 0.3392087788351121, 0.0863906090718604, 0.13307088204929907, 0.12448858289468674, 0.12299153983833329, 0.13213320575173826, 0.15802207462970289, 0.13323297093231834, 0.08908419719626827, 0.051553331450709415, 0.08604960801500468, 0.13736417667279321, 0.17658737277792347, 0.07445911906899945, 0.2854937885797793, 0.15256570531956612], [0.041477275756938804, 0.032466748774412184, 0.04977206594400829, 0.06823973384715858, 0.055061232734231226, 0.026008146852555297, 0.05340809543286601, 0.04490459608214517, 0.019207590094376958, 0.041394534430676894, 0.04285850547133915, 0.0041526207707882415, 0.0696742947724077, 0.05554541562413497, 0.02888123895372114, 0.02076917222791141, 0.021220162443275896, 0.007962756189367464, 0.05855179361758694, 0.030665260461729862, 0.0373840986210252, 0.06446223090132398, 0.14623290078053552, 1.705697950336241, 36.16014626718337, 67.19867337134578, 59.989945350154755, 44.58983752035326, 34.50661228549096, 16.076974580364844, 15.19034339535621, 25.758948210747015, 49.13388767550069, 27.586727603789303, 8.739287853240967, 0.3594506297621035, 0.09572893741630739, 0.0868498711215873, 0.25665811653579435, 1.375210316431138, 3.435266955244926, 2.190002678863464, 8.421118913158294, 8.320877840442042, 9.480467746334693, 26.42222689044091, 36.7868664956862, 64.02953947744062, 60.79717697635774, 63.62802997712166, 56.34869929282897, 60.160952844927394, 61.44626648195329, 61.264656820604884, 59.56958493878765, 59.54195184092368, 59.26077673512121, 55.13099947283345, 48.98352361494496, 47.92420518013739, 52.337146189904985, 55.917909299173665, 59.97002363204957, 59.84157385364656, 58.72005839501658, 55.694985312800256, 57.66528206486856, 57.6406378130759, 57.46902235092656, 47.05724762332055, 44.33061199803507, 43.793827795213275, 47.017706209613436, 53.95951694057834, 58.868931954906834, 61.37554614774643, 59.410850540284194, 57.492525192999075, 54.30131227739396, 44.15527028422202, 46.29816309098275, 44.68056194243893, 46.05038304482737, 49.75607756645449, 57.451646251063195, 54.57823553392964, 67.3080918096727, 34.018379180662095, 36.602887722753714, 65.69284408323227, 50.93754253079815, 57.597852599236276, 49.35302657465781, 52.80305316371303, 47.48002029234364, 54.712337447750954, 47.47763549127887, 44.20007159633022, 42.034546713675226, 45.83917517815867, 46.784199668515114, 46.03361883471089, 49.14625883102418, 48.083724052675315, 44.61051233353154, 44.6652921553581, 44.91426852441604, 45.57558405783869, 45.023541835046586, 48.993137344237304, 53.82936877589072, 58.820898609776656, 56.8129784830155, 56.63777012978831, 52.34970561919674, 57.062488294416866, 53.27719319251276, 54.40801643556165, 60.40452418788787, 58.34151044968636, 61.02469798057311, 53.492319506983605, 51.105823978301025, 57.82361245924427, 59.306307608081454, 61.962701428321104, 55.3978540051368, 36.275185461967226, 21.246420183489402, 13.064630569950229, 8.752407200874822, 5.144572382973087, 4.68032310085912, 6.098829642418893, 4.336311624896142, 2.2243891175716155, 0.19092057140604143, 0.11740574763426859, 0.06024231600965704, 0.15304457155927537, 4.788232407262249, 29.719777222602602, 51.50553703308106, 40.03386335988199, 23.183333643021125, 28.3516643124242, 39.605446400180945, 46.08614329368838, 52.0586932090021, 42.04431341540429, 15.530162838197525, 0.6320347336511458, 0.02433069966613285, 0.03183802616061463, 0.07689492626776619, 0.09258369449526073, 0.03448641701270977, 0.024555165343166842, 0.06537955224273667, 0.08643464380574804, 0.039153991552490386, 0.024018176012642445, 0.056459025269554514, 0.06793127620532628, 0.04185722855430457, 0.05558376981606407, 0.04518316480361166, 0.04518855423215897, 0.10232306986806855, 0.06386487001192666, 0.016551151488637252, 0.09907454297307039, 0.021596279055360827, 0.03037190432810495, 0.035198740886464235, 0.09821441775608448, 0.014359519493976429, 0.013445543083963136, 0.01777345243270599, 0.05639434446610751, 0.013878825176957876, 0.07645239557830558, 0.025352490502559853, 0.04027633334419901, 0.03462348546412203, 0.0568035273482242, 0.044170243350128015, 0.010067918882404846, 0.047212995198224826, 0.04261308154391666, 0.014480346881393946, 0.04157933399021145, 0.016815499703009284, 0.043318066295356526, 0.04959280903060591, 0.07699755906698204, 0.06380139962740003, 0.0626726150362482, 0.10895538414197584, 2.688386142253876, 44.21343903387747, 76.60428170234927, 67.47385117315477, 52.486294315707305, 41.565615592464326, 24.34806381502459, 19.180182257006248, 27.263853780684936, 53.81337335032802, 32.161234963324766, 9.962515273401815, 0.4781121946871281, 0.03369537377429586, 0.09383795662753044, 1.495612126684958, 4.483392171321377, 7.372827241497656, 8.492369747930958, 11.770342549970074, 13.061485809664573, 16.938875221437026, 22.204625798809914, 35.00143104983915, 59.75982381451515, 63.50704839152675, 64.38831867710238, 59.23982735603087, 62.15338353187808, 63.86579621222712, 62.00702813363845, 61.27986777213312, 61.16040414379489, 62.261786076330374, 56.78324299473917, 50.894294477278194, 50.19091152375745, 54.80010832509687, 57.108776184820364, 61.72755141412059, 58.69320584881691, 59.08161463276033, 56.540307075746604, 58.82684492295789, 58.370810554873565, 60.03975945134317, 48.8763762289478, 45.68851301746984, 45.977599543909875, 48.55393386656239, 54.996815189238525, 61.0948181921436, 63.57851005369618, 60.07331140579716, 59.19641848533385, 56.53214462341801, 47.46105955493066, 47.9874377096853, 45.68778345661779, 48.54640291583154, 52.48183065845121, 61.377311214323974, 57.32382797425794, 68.17583776289418, 34.73978542512463, 38.58408474153088, 66.1095174666374, 53.317601450027965, 59.46518321191112, 49.94084473579161, 54.12686094161003, 50.387532095755304, 55.803858541673236, 49.48880726291288, 45.46975851058961, 44.47025229853969, 47.42368328955866, 48.99405125648745, 48.29166458499048, 50.933984941051854, 52.374565601348884, 46.47675644966864, 47.176989739941014, 45.89245665457941, 46.84081123721215, 47.01196385968117, 52.275816009890654, 56.20052783719955, 59.925567488516535, 57.401263406199796, 58.219964042786636, 53.81323214500181, 56.7751629121842, 54.62297016574491, 56.04185619661885, 59.916134188252116, 61.46924764879289, 62.41926531637869, 56.02759445867231, 52.87289096463112, 59.878212713426166, 62.889102505099395, 61.8505177190227, 60.21954128819128, 40.95639697967037, 22.073967725999896, 13.712366857836324, 5.059374090163939, 9.369508797122586, 16.806134370065507, 14.314339872329468, 7.674964964389802, 4.519914340588355, 0.5666320302313375, 0.17237591166650096, 0.04418862562987112, 0.11450908492289244, 5.381655635372286, 31.576034984280987, 48.47374493075956, 42.78057367570939, 24.516253086828417, 35.33798610010455, 44.26935242068383, 50.35965973331083, 59.31686662858533, 52.4721698607168, 19.978145322492047, 1.0669986807530927, 0.060328366835751844, 0.020171688764446208, 0.028475514958582582, 0.031634591512321945, 0.016110536018987338, 0.013046220711041844, 0.023887000692587708, 0.024563366314396266, 0.02545171804095228, 0.02265304180553123, 0.0462100635312738, 0.014033879457612433, 0.024134542853120836, 0.05479938771215178, 0.06387820377224876, 0.006242129893507809, 0.046600841151009646, 0.03881742231427662, 0.028490465164424914, 0.021512756319416147, 0.031436521394719044, 0.13011038123119262, 0.07773021491424692, 0.07157898853502928, 0.13277242951575788, 0.11179697279247547, 0.19057011682420008, 0.22991927310584054, 0.1390997795087676, 0.15131802388256596, 0.10113137413657482, 0.12081153705836305, 0.1386146007045623, 0.12920515641810434, 0.1109563981393172, 0.13606617858092632, 0.1421340852374992, 0.16996831182510624, 0.12655156574422313, 0.15491404059913852, 0.24811565395324464, 0.09104227196545371, 0.21746803075075152, 0.23024887477438297, 0.24618690502980065, 0.12410377693032065, 0.2682807428702232, 3.719797158433545, 53.73616541585615, 84.26605916792347, 76.23948558684319, 59.48145320338588, 48.15975135372531, 28.072444508152625, 24.69662916275763, 38.631780762826246, 64.62062889529814, 36.82810629567793, 11.902330306268508, 0.5836003261708445, 0.23962761425683576, 0.20527807034311757, 1.4104860300017943, 6.408503709300873, 10.466844804825323, 14.043091304840582, 15.767746683089966, 14.162053850389297, 18.5725070968751, 31.733263192638276, 42.575437638067434, 68.00389674402052, 66.25117778778076, 69.59724195541875, 60.912922197772616, 66.5037392031762, 65.04903801025884, 64.30346996553483, 60.719004138823486, 64.00946086452853, 64.56785340462962, 61.2838097541563, 54.35313070974043, 53.17044588827318, 56.95021829297466, 59.77243031224897, 62.776197079689275, 61.093912124633796, 60.331532801351244, 57.3469268122027, 60.386030212525405, 62.00486298530333, 62.951730989640765, 51.15169609746626, 48.72330573297317, 48.0880896506771, 51.22459334711875, 58.267671831192516, 64.58044813525292, 66.23289954277777, 61.37316526905183, 62.07958805945612, 59.19762657534692, 50.287370451035045, 49.880142135004846, 48.41728241212907, 49.41624341472503, 54.68910524922033, 61.629421557149584, 60.62973883844192, 68.17601034718176, 37.392139204086796, 42.103435301011615, 67.71562607057633, 56.031512906474454, 61.22055761275753, 53.126127027696185, 58.20117588966124, 53.09529327577161, 58.031541224448915, 52.04047379955169, 47.58252751442694, 45.858202595864576, 50.00935285322128, 52.39714276406073, 50.604125376670595, 54.69489466759467, 53.94904813458843, 50.09004385240617, 49.887575026481386, 48.47664748468707, 51.16277287083288, 49.42286045320573, 53.29148238705051, 59.42058194068171, 62.90424285396453, 59.59160120256486, 58.88058923905896, 54.860250026949, 58.255571319210915, 54.86172091576361, 56.62627758518342, 59.01380469722133, 62.15366202016031, 67.67133466659054, 58.37205394621819, 56.615824468674205, 63.34661952910885, 64.33285636286583, 66.17268331589239, 62.16375820098385, 41.02261835528959, 26.49381014608568, 18.353211302911085, 19.7724130845839, 14.213398656537457, 16.875966287428334, 20.118752487244148, 14.259045239417786, 5.106587169631835, 0.7311298001197077, 0.32598931883131305, 0.21264152361019967, 0.29192405482453687, 6.18409461552097, 39.074616355280725, 66.29878751693234, 53.484776789142245, 35.33170638545867, 38.73369962938371, 49.65115416434504, 61.871557312627, 66.47873801569786, 64.02477772005143, 25.52902867717128, 1.602321923259766, 0.1786473372410382, 0.18644781302540533, 0.18237041730073192, 0.18930450892977177, 0.09540853646373558, 0.11376965685837692, 0.14599434100091457, 0.16251875027533502, 0.0908687913550004, 0.08670582360918484, 0.13036899719267123, 0.20788845365806935, 0.17514279142262476, 0.14714819198894888, 0.14079412084914025, 0.10975102773837506, 0.24670412163099936, 0.15680439319581757, 0.10238659387874989, 0.20857033319771293, 0.11397206494885107, 0.21536717251423868, 0.22658685192225442, 0.17900093278336912], [0.04262373399650378, 0.0324613823285026, 0.012378349089093748, 0.06476053787815957, 0.014062516781831942, 0.04568045162746022, 0.025689255093194308, 0.055236103794267105, 0.06269481243385423, 0.03146463490632032, 0.04886763403192163, 0.026812786236405376, 0.06731398553857881, 0.027286738022080353, 0.009035879704770784, 0.021159495940552126, 0.03335678206396199, 0.06049318682222117, 0.0747915705846202, 0.062093552156922326, 0.028098159199280125, 0.0386296579944751, 0.031056398142790122, 4.17102441672356, 40.9478501350649, 65.19383230516988, 53.09333601305562, 44.2655751782079, 32.60431570391501, 23.44609518204966, 40.808343195146136, 56.56317057148103, 39.401047768131384, 16.01437355241468, 1.7558265765828474, 0.04140611001921277, 0.04218461239830621, 0.013751690013093815, 0.43667511173313667, 2.769901574619355, 5.131890869909718, 6.45814718738679, 12.599493361288502, 18.26827629919975, 24.22851977809783, 37.02873945236206, 51.552954566094186, 61.85453814844932, 60.25562317140641, 58.34291858057822, 54.09798053003127, 61.64923344888995, 62.525388963760875, 61.053927483097205, 57.49065422242688, 59.26591111767677, 57.47857332229615, 54.19874621975807, 48.98478269577027, 46.898936840795706, 53.32827029689666, 57.54443776222968, 59.92621860196514, 56.88391454758183, 55.99408957266039, 58.43979720146426, 59.325723340434415, 53.80709363568214, 51.66645619177049, 43.434930924446356, 44.60079662261471, 45.20059370225476, 50.21477914625599, 51.616124337719334, 55.85184481836135, 57.325726401421335, 59.41236065280054, 58.41402330706197, 54.23938197474326, 45.35418587346231, 46.18745027049896, 42.01328746734127, 48.04739506013932, 51.26640581315564, 61.530668043321185, 53.88698447135187, 63.985695223654474, 32.64855023353331, 31.516379656330233, 64.98387175221598, 52.382108319190245, 58.829778855846776, 48.22090894945207, 49.78478931611585, 43.94383099771316, 49.25337091568978, 45.21206663500878, 44.60768038226713, 39.82413814913842, 44.52626766697053, 48.06098999515657, 51.07722597737467, 50.05142027331937, 51.75931046085974, 47.87408121170537, 47.022687619732274, 42.99342501548029, 46.0512577333758, 40.750425477181714, 46.867346071427875, 50.90913672601023, 58.7393956799661, 55.16401798494401, 55.500333770628906, 55.58363706834855, 60.08027361285303, 56.200390554243526, 58.92017379883797, 57.923111223405414, 58.281886500696984, 61.19186155257687, 60.57584154990412, 53.0434238526129, 51.424736207531346, 56.489175058180294, 60.775094032287605, 60.175948066096154, 60.34708892145465, 33.646463963293264, 23.818102575117543, 6.7516233363459195, 10.68840870934148, 11.362663161370063, 9.407767595783357, 4.493051007870705, 1.6676275480178095, 0.5573843071056951, 0.205842983578482, 0.10760842537086819, 0.05260413212160911, 0.5206880826623209, 11.473410302592862, 42.40341817179034, 43.30319419983895, 29.59438885411909, 23.951163099658107, 33.00833355995917, 45.49271614320817, 49.43179169008809, 53.074445878305745, 30.935005949389552, 2.8594814000591158, 0.05115829821255419, 0.05820329639039213, 0.038991416203639204, 0.02307840254938891, 0.028098950185061946, 0.07828313887359635, 0.04667892849313156, 0.03984767650704711, 0.05504940816711995, 0.06379380386563079, 0.07159661621816697, 0.05839642715610324, 0.045575781034365784, 0.026597775999576818, 0.01896225618228557, 0.011378364945431391, 0.07827073591010225, 0.0503469459832676, 0.03017564983888259, 0.02706842403107834, 0.05306834692976648, 0.06320929410116327, 0.03615137505074663, 0.043297722830527255, 0.11171247329442732, 0.05937434222188689, 0.020258128380162582, 0.042269180844267534, 0.04902331841989391, 0.025035772517684008, 0.015706329835548757, 0.014475902613823213, 0.05221910016130536, 0.0514970776144295, 0.0424050695202764, 0.04410234497739904, 0.015835062292734944, 0.061097365894144585, 0.056993003874536485, 0.027101907819028825, 0.020820615032026847, 0.05574483980214404, 0.07012051034478411, 0.044432586329358245, 0.006322515499402559, 0.028351881774142388, 0.07790689011134448, 5.957544888219526, 51.62278059990176, 74.04145994494039, 59.452121719237304, 50.75401483043548, 40.090996603811945, 24.35407484731367, 28.89041558388741, 53.623887569673606, 43.98666327999484, 16.550193832766627, 2.394311586695333, 0.08562457477373463, 0.02310606598433468, 0.0909851064845439, 0.9309725379270892, 7.748862908732507, 7.560160131223741, 8.444644308859303, 15.137478670766278, 12.051470587330481, 21.74792855016647, 34.017626085589015, 49.01846016606977, 65.95557228211435, 64.6720080221853, 60.48430519719278, 58.12200284773304, 63.56604476128856, 63.714345655133656, 59.601701305758574, 57.31946629862632, 61.07906987590175, 60.53904187294745, 56.35098211226925, 52.07219008476504, 48.577817178541615, 55.68982739602366, 59.95567167958906, 61.47696687329201, 57.228330027672556, 57.70584329482048, 58.41804373648859, 60.30846926473803, 56.19882945091494, 54.997509448759025, 45.571136090063284, 46.53968695671328, 47.537259440268244, 52.05860299448813, 54.006228446960456, 60.76770428688296, 58.2021878611657, 61.176034788931574, 59.221356914889434, 55.37513955946892, 46.75487995147706, 48.65578213045674, 45.143511449137044, 49.38931242112191, 54.320649562343476, 64.35717505793419, 57.45568236997051, 64.17201172920966, 33.51726893455752, 33.086879022659794, 67.3658290986092, 52.777926460389175, 60.69715261459351, 49.653346769271366, 52.41298913955689, 45.496167828959805, 50.721451313264915, 47.137177682692005, 45.039035197227236, 41.61807729351906, 48.08867408383278, 49.57899432028494, 54.86998142734651, 54.075634787159586, 54.63794577506281, 50.367582921058904, 49.547862468227265, 46.3382379470333, 46.07910656159925, 42.41123937791394, 49.39504692631383, 53.81249866177959, 60.08510205053515, 57.40768432617188, 56.76205827343849, 55.88304335071195, 60.77499597303329, 59.02184555607458, 58.93262340176491, 60.04794936026297, 58.59597029224519, 63.34334827238514, 60.27675297952468, 55.713138041957734, 55.09652576138897, 58.41192483901978, 63.81187538946829, 63.90137210969002, 58.4651670917388, 37.9609848606971, 18.5573471361591, 7.3793305312433555, 12.46262715708825, 14.904295725207175, 12.107231001700125, 8.552588916593983, 10.619656424368582, 2.3881816575604105, 0.5440399747702384, 0.17347077388436566, 0.03508256748318672, 0.576734401045307, 12.436342373971017, 45.7750875719132, 47.99565115282613, 33.34561817107662, 32.07295810022662, 41.37839301939934, 49.811108419972086, 55.71536987058578, 61.65339116127261, 38.74073636147284, 3.7452499087779754, 0.019177475178073493, 0.022080092307841106, 0.03378914676666741, 0.041355942751491265, 0.05661655209898468, 0.051512085276866154, 0.07375604953737029, 0.052892093081027276, 0.15944787150909825, 0.05165258580217919, 0.03692392875710803, 0.06583924330170117, 0.05852556276705958, 0.004647205698288857, 0.0443277357056016, 0.01177089116085441, 0.09318658270903173, 0.0412383291029161, 0.020375180869333206, 0.06009762881383781, 0.031671852113739137, 0.025948556703365138, 0.03797308999984976, 0.01663868469486554, 0.18189199539201875, 0.17426657069834972, 0.11926986938042027, 0.16441222851074513, 0.1059518751478003, 0.13318096888401817, 0.08826856636592458, 0.14405992302683093, 0.1443682887381123, 0.19687613892939784, 0.22008466534316543, 0.1307719134755673, 0.19116054078744305, 0.14609525010230082, 0.10190791916102172, 0.09251575781813554, 0.09021356401424255, 0.14667455046888322, 0.16640445547959498, 0.13237662252879914, 0.09039976934511816, 0.17075894520648066, 0.23599081101917455, 7.78590577263986, 62.71683592950145, 79.7404049288842, 71.35287131032636, 57.83608951876241, 46.40366700387771, 34.953978215494466, 54.47744238761164, 70.13306125517815, 52.87996692042197, 21.527826709132043, 2.908138402046696, 0.2030717371211898, 0.2292633486250716, 0.22280300576840678, 1.6128715055604137, 7.891136590511569, 15.297680035714182, 19.014787673950195, 23.358630249577185, 28.443210471060972, 33.99839862700432, 44.200934517768125, 53.04486336246614, 68.54286962939848, 64.96529148470971, 64.12739476849957, 58.176233537735484, 67.41473320991763, 66.42316587509649, 61.737051394677934, 58.03440063230453, 63.93704606640724, 62.441116840608665, 58.649055650157315, 53.99622640302105, 51.36295103257703, 57.7805644466031, 63.015273386432284, 62.76036639367381, 57.904887891584835, 56.72515661485734, 61.689606405073604, 63.65898924489176, 60.11035034733435, 57.475604088075706, 47.91244591436079, 48.32776608005647, 49.70975045234927, 55.20058624206051, 56.680116038168634, 60.44686617389802, 60.53337012567828, 60.64375738943777, 61.97969313590758, 57.66320320867724, 50.167706781818026, 50.190331012971946, 46.69099238611037, 52.20103994492562, 57.20117153659944, 66.45518810518327, 59.65339029988935, 65.32282337065666, 36.899061972095126, 36.46786012957173, 66.42250691690754, 56.532301518224905, 64.08486058635097, 52.91117721988309, 54.35239330414803, 47.69041622838667, 53.17745124140094, 49.46063287796513, 47.878650772956114, 43.197996231817434, 49.606352852236846, 51.890207798250266, 56.50346425271804, 55.25699776987876, 55.618965856490604, 52.051268162265906, 52.46159515073223, 47.8167361597861, 49.858196473890736, 44.26098992747646, 51.46460317796277, 56.97443108404837, 64.48173776749643, 58.03299250141267, 57.84555027561804, 57.05989560773296, 62.120106143336145, 61.78539068468156, 61.97463720075546, 59.23324169651155, 60.250253446640514, 64.89599104850524, 64.54634312660464, 56.77511584374213, 57.83941568866853, 61.431577205657966, 68.49231027787732, 66.0262220136581, 67.06019017004198, 36.31835506808373, 29.79482589229461, 12.82349011590404, 22.210438751405288, 27.206518534691106, 20.15255351220408, 15.228819885561544, 10.905083379437848, 2.270159745408643, 0.6126317490012415, 0.39625343235750354, 0.2301202332901378, 1.1238270829762183, 16.361728848949557, 54.994877538373395, 54.61623153378887, 39.13775867031467, 35.06245528498004, 45.39874007624965, 57.9832725371084, 64.75583299513787, 68.79759619312902, 48.521495865237334, 5.456230188569715, 0.1421638247707198, 0.2602020392735159, 0.10505413501373223, 0.16158265211889822, 0.1780483484148018, 0.10016870805092397, 0.15429706402843998, 0.19980418826303176, 0.1937301682248231, 0.12758687994773352, 0.28858642424306563, 0.11483789752087287, 0.11042842566366158, 0.12680056730225203, 0.15267942341104632, 0.09552441492316224, 0.26638930242869163, 0.10557202577230432, 0.08130907892219483, 0.05551893579503221, 0.13625647482131759, 0.1275941654438934, 0.09335281612772135, 0.08545375248837857], [0.05232830599491155, 0.051770260737788294, 0.033343858160679384, 0.010033470781279669, 0.05568900731422248, 0.007929263782927827, 0.026836774364534407, 0.06805420267365633, 0.08056216617865909, 0.023597691418422807, 0.05624434062009377, 0.03697140322577569, 0.02137662249527151, 0.006380580176013492, 0.023900246352798516, 0.056178621767509374, 0.05421740986827401, 0.0131677174677832, 0.034065696846453414, 0.03475132255604671, 0.03673845887063973, 0.08334716391419211, 0.2293585273887842, 10.870935224717664, 57.69542155727264, 61.43849626664193, 60.05016157704016, 35.86060270186394, 22.848414221117576, 29.62164148207634, 38.11559684814946, 36.59600004073113, 29.07236453025572, 8.71688425540924, 0.15412303949556044, 0.14143692990464551, 0.05737412495598678, 0.22747051902115348, 2.1251227538431845, 6.2348103715527445, 5.205528466932235, 9.023591049255865, 11.986907393701616, 20.333663071355513, 41.85875392729237, 48.711456252682595, 59.052561636893984, 63.74405760918895, 59.4348083772967, 53.58103567554105, 57.241399365086714, 61.555002427870235, 61.84626979212608, 58.64586676320722, 57.922946483858176, 60.25284613332441, 58.549521584664625, 52.4537072643157, 47.641143414282034, 49.27663449318179, 53.4204303064654, 58.229840570880526, 58.66355665268437, 56.68301466972598, 57.18449361862675, 56.969104505354366, 54.76202603309385, 49.54896465424569, 45.08819818496705, 42.58320000863845, 44.86464661936606, 46.64822678412161, 52.02947155121834, 56.14244930205807, 58.973078727722175, 56.73542930233864, 59.677508954078924, 56.10921113721786, 51.50164996424029, 43.225433211172785, 46.354911942635816, 42.860386063975675, 49.42042073895855, 53.206551305709354, 60.27172842333394, 54.64006777732603, 64.85886189245409, 34.44610580321282, 29.358746582461944, 66.15499342641523, 50.23990192720967, 57.562268857033025, 47.566759586334236, 51.332972357350016, 48.62569755123508, 53.17643142515614, 49.118790472707445, 47.558224508839274, 40.00343753445534, 42.703302983314764, 46.79597070140224, 52.44622338202692, 53.34793313857048, 54.32729013504521, 48.70674156373548, 47.79374322583599, 44.211972067433024, 44.29774645836123, 40.69004451074908, 42.51540184020997, 50.2980589097546, 57.8339086809466, 55.37342548370362, 54.87762612681235, 56.97822793837517, 54.723280860531716, 56.79415110618838, 59.89465528918851, 59.86258991302983, 56.243328740519864, 56.39362612078267, 60.27758452200121, 56.36335719016291, 55.77024775166666, 51.665648183514996, 54.112022615248165, 57.56576368885656, 60.13753629499867, 56.335033755148615, 38.16310851804672, 10.263873915518484, 10.002396952721382, 18.541390934298118, 13.826420557114387, 4.131836506628221, 10.970897809151682, 1.9439447983618707, 0.20236381059212072, 0.046895218096793666, 0.1151781478115628, 0.041991420345561165, 2.879320012946283, 21.358464648646695, 46.824098017907914, 23.639901453448882, 13.672786220427483, 20.351262746318696, 31.647569210298602, 44.88333279086698, 50.82603739153955, 38.00355826654742, 12.55739946519175, 0.07715132057426438, 0.041073191189958204, 0.050332057064459215, 0.054394962236044876, 0.007984424986305737, 0.08176110144103728, 0.01652024750177178, 0.05849626756483509, 0.027113519796741106, 0.041044401605763746, 0.077855225141731, 0.07927552150983004, 0.036018753739734816, 0.06990048989293075, 0.024527647464926687, 0.04890145681377861, 0.03261347376411, 0.02132585767896906, 0.038468986374115756, 0.033969851586246685, 0.02173062023376265, 0.051274575037701484, 0.05576124557504251, 0.05122390598238957, 0.03148186230851758, 0.02973239711155334, 0.005023540166627255, 0.04877259699447502, 0.00028701466127982245, 0.009260986980441357, 0.029588435784042365, 0.06844693764803872, 0.06641901864279663, 0.03359848280407248, 0.032775359633829326, 0.023248445340282014, 0.056892853200195305, 0.042376034787946174, 0.0541752060845254, 0.037376008732544805, 0.0366493973190025, 0.030702059495172677, 0.05877208986109304, 0.02377149570102413, 0.046302426921864676, 0.021072792024501873, 0.17708220428997473, 16.12676710851731, 69.77193647815336, 67.9988290417579, 65.90301252180531, 44.12827261032597, 32.93747986516645, 39.293119830469934, 47.94205196442143, 45.52227904719692, 30.4722878625316, 8.76062064401565, 0.24132203220600085, 0.2121441640079983, 0.07238446103949701, 1.0024601857989066, 3.784616041568018, 10.458224415779114, 13.154888229985392, 7.268342164254959, 9.996903673295053, 11.49835559629625, 28.396436206756103, 47.39918416546237, 61.107110900263635, 65.8953638999693, 61.0964185191739, 56.53707504272462, 58.751209858925115, 62.20755930869811, 63.15659638374083, 59.33736885747602, 59.45423195439001, 60.89633057194372, 59.9601863276574, 54.205194596321356, 49.74278073157034, 52.103984817381836, 55.2906713178081, 58.488548340335974, 59.81700412688717, 56.789365814578154, 57.94740246188257, 59.94823878811252, 56.94699018232284, 53.874660384270456, 48.54172352821597, 43.5857186009807, 45.95413984790925, 49.70841684649068, 53.8175977430036, 57.83966279798939, 61.095249652862556, 59.72372231944915, 60.290579334382095, 58.91471385955811, 52.423599150873, 45.253259366558446, 48.1989711330783, 43.803100278300626, 51.40335144535188, 55.51800797062536, 62.35811556539228, 55.78156771198396, 64.34960096113144, 36.97367329751292, 31.39005776374571, 68.10441924679664, 53.06571860467234, 60.249041434257265, 49.93552992420812, 52.9837606799218, 50.43882493049868, 55.05187742171749, 51.83951900851343, 48.23607283253824, 41.94135512075117, 45.4258514988807, 47.977843592243815, 55.0710460447496, 56.44365202996039, 57.007633947557025, 50.2651894477106, 49.42685734841132, 46.3696639768539, 46.057913995558216, 42.12341585466939, 44.54677774060158, 52.37539322145524, 59.353834967459406, 56.80356087223176, 55.73257730853174, 58.57498953419348, 57.528430569556456, 58.660642331646336, 60.57907750529628, 61.29816170661681, 55.39905032803936, 56.55074058040496, 61.22681771555255, 58.10546221271638, 56.44848439001269, 53.990009446297925, 57.16850211543422, 62.562918201569595, 63.10185970798616, 56.056310130703835, 37.023487398701334, 13.35432408317443, 10.430617793913811, 12.28231187789671, 10.166134334379628, 12.165879261109138, 7.877057733074312, 4.081902037705145, 1.6894522285269153, 0.3181471218985896, 0.016754431004125266, 0.08762152850507729, 2.9203810999470377, 27.239540969171834, 45.42127801525978, 33.158062196546986, 20.900739739018103, 24.13810326207069, 37.55263082442745, 51.415287217786236, 57.8375643299472, 44.45452751651887, 15.681965428013957, 0.2296872097518175, 0.041022223360355825, 0.024977362143897244, 0.046240377630437576, 0.059906551163763776, 0.06043855709234073, 0.02335088470229699, 0.050258926311207396, 0.021245016250759367, 0.04578984515260785, 0.040232651010756536, 0.07374513278444929, 0.059971013632152355, 0.06822522414187271, 0.09218426391242013, 0.0831449933109745, 0.048715940962034854, 0.043495986385331045, 0.08927535145513474, 0.06824740238728062, 0.03509346891434924, 0.06668635268485354, 0.050296629328400864, 0.034830796517311566, 0.2116107369863218, 0.09704604940188509, 0.1404942280703014, 0.1252212693854686, 0.17985748036974863, 0.08196999829623007, 0.058170775958006425, 0.2056506801877291, 0.12454864418795034, 0.0712112739922539, 0.12738443355286314, 0.116103436467388, 0.1343051722693828, 0.15129133337928405, 0.13554572908868714, 0.14564685884021944, 0.22251290359324027, 0.0988597242582229, 0.11061127552942884, 0.18263346125041285, 0.19491772708152572, 0.18012619337006924, 0.42937505990266805, 20.42844126301427, 79.65687413369456, 76.0401350452054, 76.59724497026014, 49.59349140044182, 36.433123619325706, 40.155390154930856, 49.9702742791945, 48.69438609769268, 40.15885753016318, 12.073492734662949, 0.3687988023363775, 0.415372014526398, 0.14166582165466202, 1.086972370263069, 6.7504515282569395, 17.249093517180413, 17.972559005983417, 19.54067357124821, 23.491526034570512, 29.921549827821796, 53.156293976691465, 58.13182838501469, 64.45354377069782, 69.4038377269622, 64.54825724324873, 59.36200918689851, 61.65534450161842, 66.73039728595366, 65.14270028760357, 59.329041665600194, 60.27520364330661, 63.63223868031656, 64.36360382264661, 57.29231172992338, 52.91679405396985, 54.50439299306562, 57.12956866910381, 60.360362222117764, 61.73567072037728, 58.127223522432395, 59.45097638714699, 62.19947922614313, 59.39517674907562, 55.699390134503766, 50.24920971162858, 46.35526103358115, 48.02224874496461, 51.03220109016665, 58.50555965977331, 61.212669726341005, 64.25118084876769, 61.536732027607584, 62.92179153811548, 61.842374878544966, 54.77682121338383, 48.02877556893134, 49.57133785370858, 46.24184177767846, 52.824477149594216, 58.97986442812028, 64.11073254000756, 59.0650269293016, 66.03585535480131, 37.99133223872031, 34.27118770537838, 69.7262094866845, 55.6509017944336, 62.45590417615829, 51.5934883394549, 54.81116156424246, 53.34730163697274, 57.896799964289514, 55.127481106788885, 51.25065749691379, 43.95236999757829, 47.61751113399383, 50.88351580404466, 58.90958732174289, 58.5712593601596, 59.12954207389586, 52.0699857127282, 52.04124650647564, 49.50015860219156, 49.07052178536692, 45.751341542889996, 45.95863488412673, 55.60429619204614, 61.869976597447554, 58.22548281761908, 56.17031381976221, 61.467666933613444, 58.52423406416371, 62.55691697520595, 64.32582747551703, 64.9763721804465, 56.956717660350186, 57.92240127440422, 64.45518724380001, 61.235380249638716, 61.48080295132053, 57.2453688037011, 60.028686600346724, 65.55000312866704, 63.700193743551935, 63.470134965835086, 42.1238826167199, 15.78462758371907, 16.96500801271008, 28.77155011700046, 21.293469013706332, 16.586944480096143, 18.69712668080484, 5.63826983974826, 1.6011460702265463, 0.2983435651948375, 0.28810630161916057, 0.12188128691406981, 4.1126132155618365, 30.827938971980927, 60.071436512854795, 33.00027308925506, 21.94905004193706, 28.997959129271973, 46.97550935129966, 58.568933394647416, 66.42744125858431, 53.144134629157286, 18.541530178439235, 0.4200195328843209, 0.16693161590205086, 0.18995147018182665, 0.2700418870775931, 0.1428209443486506, 0.12740598360617317, 0.08651384197536015, 0.13024058553480333, 0.13432780250666604, 0.20902630873024466, 0.165912029483626, 0.1931487381338112, 0.19996750288672988, 0.19056858464835152, 0.11223693708738974, 0.13314712311952345, 0.13578304780587075, 0.1317846663897076, 0.1943228904518389, 0.16809718803532664, 0.10296682887259992, 0.18092205147108725, 0.09682232874535746, 0.12767222214249835], [0.025666393114313967, 0.015422045140557233, 0.07442530394802171, 0.08102100688002764, 0.05376268688949847, 0.042531650228005265, 0.005974632100157079, 0.038537934287301, 0.04171614197172946, 0.028341250388973185, 0.04259153149060665, 0.07883469919644057, 0.052753503945085316, 0.08557292512587963, 0.018569689747246525, 0.018878595550514517, 0.03598819449243527, 0.025068926887827057, 0.012964590212270137, 0.028461811560837012, 0.0066830848358691705, 0.0964585901989091, 0.6759413163508139, 34.40483070188953, 64.3121737049472, 52.70136963936591, 49.56862357354934, 29.447362730579993, 18.812544384310325, 18.842070025782434, 29.250706857250584, 38.62318292740853, 24.63239839000087, 1.52485768641195, 0.0878765285315533, 0.03798787549678837, 0.0379916561406947, 0.8009204713086929, 0.16144771339191546, 10.394236829973037, 5.421131839675288, 3.657330961958055, 21.007408595854237, 25.35072361269305, 37.99475254551057, 53.58438537966821, 64.45517155431932, 60.950827983117875, 56.31970905488538, 52.846548326553844, 59.02953732398249, 62.01019740873768, 62.54904085589994, 58.1462509401383, 58.73053504574684, 58.1579396032518, 57.67225996140511, 48.85424621643559, 48.72829498783235, 49.72921717551447, 58.01835813829976, 58.154291798991544, 59.408924656529585, 57.924625258291925, 60.06295634854225, 55.279535708888886, 50.984418776727495, 44.67048145109608, 42.307496609226355, 43.02066587632702, 47.71566844755604, 49.61046349617743, 55.62594375302715, 55.47384992722542, 58.89561191681893, 56.895532608032234, 59.28999054816462, 53.661718829985595, 46.40658524728591, 41.288386391055205, 46.12528462563792, 43.75851077418174, 49.123854252599905, 53.205037270822835, 61.52320769525344, 51.39877011699062, 59.90338256282192, 38.25994791523103, 29.96216597095613, 64.37370000347015, 52.63328513791485, 54.59768656761416, 51.649335045968336, 55.32762788957166, 55.48456192016602, 59.374321506869414, 54.72070778569868, 51.90701123206846, 40.582520577215384, 41.96340668585993, 46.161174312714614, 54.11856120632541, 54.25217674624536, 56.33213512359127, 54.170642437473425, 51.086980911993216, 45.88421967721755, 43.43726081232871, 40.537715342737016, 43.45178927144697, 50.05688021259923, 56.50607262888263, 55.66053121320663, 55.555831386197, 55.196440296788374, 54.770580722439675, 52.58847990343648, 54.59617645509782, 57.09047440559634, 58.12141841457736, 56.319752200957275, 60.50648620051723, 59.63094649776336, 56.666689765068796, 54.65668293737597, 53.209995146720644, 57.5281834602356, 60.06858887210969, 59.58462722839848, 43.15180640066824, 28.248860951392885, 21.27634002316383, 9.487386807318657, 9.773336418213384, 9.582013007133238, 9.271938858493682, 3.7082143993146963, 2.7254611205670143, 0.38014606602730294, 0.07978794240062276, 0.05112882681010712, 0.29884483184545274, 10.15321404703202, 51.734944697349306, 32.19426916491601, 20.034735318153135, 27.399040229858894, 30.667521876673547, 40.589314122353834, 52.10786011911208, 46.97612908578689, 15.68494446815983, 1.0272077062437612, 0.014438602750399902, 0.050133766696578076, 0.045433326984845826, 0.03520387750599654, 0.07086926169933812, 0.021318214036704555, 0.022702726437860442, 0.10240437477947244, 0.026333567596250967, 0.04448814685606668, 0.020094737147672043, 0.021022281932434248, 0.007414236756777692, 0.056061310723664305, 0.05201681081445948, 0.05448827940610148, 0.07220902690483678, 0.04791407290125086, 0.00319554808459455, 0.029443951601523067, 0.04333376343692503, 0.01865424670188898, 0.05494240483629608, 0.03481377787407368, 0.06665413102675831, 0.03828123737607272, 0.06580622491216467, 0.03270762597000407, 0.04045724883795746, 0.005669729585098404, 0.08748577006401555, 0.021644186363705707, 0.04935681564553131, 0.05379916416601308, 0.10264405304746282, 0.04998627561895598, 0.13256429874848935, 0.010522144861639509, 0.025586844459476493, 0.03875074585178687, 0.042267495450834115, 0.0985454673308038, 0.028269498593985077, 0.05203865964205996, 0.0517616882139156, 1.3749296218156817, 42.03699427266275, 72.3213594190536, 58.43048549467518, 59.85176809372441, 38.91747443906723, 24.771364042835852, 23.672053121751357, 25.465188180246663, 35.91840667109336, 24.890996333091493, 2.1922734860450994, 0.11769197340453826, 0.037851753163962595, 0.27318842468723176, 1.678686425570519, 5.739220371169429, 12.734862200675472, 13.942682550799463, 12.249087441352106, 13.049330384500566, 21.84099070487484, 34.62526006083335, 55.3114559573512, 64.82848705783968, 63.48420058527301, 58.94670863305369, 55.10551975619409, 60.883100417352495, 64.98707240627658, 63.386239390219416, 57.92142460423132, 58.57036505976031, 59.841205150850364, 59.714642032500244, 52.77596135293284, 50.38233103290681, 53.395707607269294, 59.16764790011991, 59.77170075139692, 59.784883837546076, 58.62396032579484, 61.36129225454023, 58.95710291401033, 53.9613369203383, 46.99758837299962, 44.80933335519607, 44.85996330938032, 49.19289581237301, 52.343331767666726, 57.25477464737431, 56.922420455563454, 60.13671651963265, 59.666345888568515, 61.34342193603516, 54.49689342129616, 48.88517802761447, 44.28594404651273, 47.18541106870098, 46.6574796553581, 51.086875007998565, 56.00040458863782, 62.50794226123441, 54.6743885163338, 60.458429321166015, 39.24012468707177, 31.885484495470603, 67.36596245919505, 53.71571810014787, 56.013897542030584, 53.37482098610171, 56.38765627338041, 57.500511138669914, 61.45467996597291, 56.20929433453468, 54.53585824658794, 43.246986635269664, 44.18092650751914, 47.61289842667119, 56.667207517931544, 56.10527699993503, 58.676775040165076, 56.31373528511294, 53.105177648605846, 47.661661332653416, 46.08396637824274, 41.567863110573064, 45.39639057651643, 52.15147687542824, 59.55704512134675, 57.355512880509906, 56.51178359985352, 57.59420087260585, 56.42842931132163, 54.27464016022221, 57.13781349120602, 58.45103086963777, 60.17951350058279, 57.37052379115936, 61.95210710648568, 62.32238669549266, 59.544218970883286, 55.6148434454395, 56.47237554673226, 60.27620777007073, 62.956139733714444, 60.425732443409586, 45.80412880066903, 25.90426810326115, 14.931134543111249, 5.004556515524465, 10.195061814400459, 13.989648030650232, 10.560573762462987, 12.317845609880264, 2.7699702160973705, 0.5245178481263499, 0.0931488145743647, 0.04637652294590108, 0.3355852135967824, 11.028505659872486, 46.33192685342605, 25.27214284866087, 22.33621543453586, 31.50433994108631, 37.10865382225283, 47.85189236364057, 58.946355619738185, 55.651235195898245, 19.128479534579863, 1.3691954843459593, 0.07537364418948851, 0.08009274580305623, 0.029204905356070208, 0.001466957466853332, 0.014458296955713342, 0.04107073204772126, 0.09138103604557053, 0.04338478872312173, 0.03682316521242742, 0.08591663813398731, 0.06898004291278702, 0.036359930996813124, 0.008127302299403857, 0.030279757357352687, 0.06656500435764752, 0.043933805634057334, 0.03585802466278115, 0.06280202260841766, 0.02560765140749995, 0.04780835659813978, 0.07566213758001405, 0.025807837842993682, 0.07050708597225529, 0.13923890107581693, 0.1930771855216834, 0.18366582601541476, 0.22663281719771125, 0.12466266871460023, 0.12658999271450505, 0.16231483299165003, 0.16940657019374833, 0.05807726726596875, 0.12245650403201581, 0.10756310360926775, 0.2199486234495717, 0.15391641026062353, 0.20498965356138446, 0.07707452025985526, 0.1342977105730003, 0.19499001513806083, 0.10057296498768753, 0.17824469674979487, 0.12095632767605206, 0.10902523603891173, 0.17861459464315446, 1.7384878618101922, 49.888112391194994, 81.61652165074503, 66.63646436506703, 67.27027231647124, 40.89903231590025, 28.70805871102118, 27.95240821376924, 42.25558403999575, 51.742577629704634, 32.48601309714779, 2.389694711854381, 0.45475300942217156, 0.11092623725773827, 0.4842585793906643, 1.4242416596220386, 6.322061534850828, 23.609542308315156, 16.164167888702885, 13.989235201189596, 34.622392808237386, 33.98263462128178, 43.88866286123953, 60.20323599538496, 68.12718468327677, 66.56399465376332, 61.1296292274229, 58.490301639803, 64.30533309136668, 66.58006068198912, 64.94643272892122, 58.694590445487734, 59.269492241644095, 63.45762652735557, 62.560568701836374, 54.896014198180175, 53.31363593378375, 55.063154235962905, 62.53108816762125, 61.34011145560973, 61.073594247141195, 60.595563227130526, 63.918963939912864, 62.338315440762436, 56.612368860552394, 49.347009658813484, 47.33451212606123, 47.330632901960804, 51.38949763390326, 53.85620171023954, 58.7714728232353, 58.57111423246322, 61.869474534065496, 60.46063761557303, 63.563381471941554, 57.702662252610736, 51.05480963183988, 46.71719381886144, 49.267605197045114, 48.52342567136211, 53.79014899653774, 56.746702194213874, 66.14352441603138, 55.892806130070845, 60.629723148961226, 41.86558669613254, 35.77551472571589, 67.06386150852327, 56.83713636090679, 58.3042714672704, 55.39111145081059, 57.99314514283211, 57.96295073724563, 64.96206729642807, 58.83141056183846, 56.258335728799146, 45.12786903688985, 46.672482721267215, 50.64633007972471, 58.47047798095211, 58.51374172395276, 60.603286373999815, 60.43695434447258, 55.5724230120259, 50.868014597123675, 48.33564612173265, 44.37429543464415, 47.1927890469951, 54.831475519364886, 62.600533731522106, 59.40513172457295, 58.18123848207536, 59.501704400585545, 60.930737603095274, 57.96771249463482, 58.490046685741795, 62.6010867857164, 62.331439525850364, 58.275536183388006, 62.41682560213151, 63.90019539863833, 61.42184972763062, 60.051126480102546, 59.01553446246732, 63.66905404675392, 65.44104753002044, 64.20527735064107, 47.4272487240453, 30.832826245215635, 28.43753480142163, 16.49074442924992, 19.92752713541831, 19.745472285055346, 23.264838534016764, 14.149400284213407, 5.733648154043383, 0.6058006349109835, 0.21576711637598855, 0.25278986281444954, 0.707209777207144, 13.450437841876862, 64.05043394334855, 43.316459655761726, 30.29748743580234, 39.677865120672415, 44.43269168176959, 55.7693063828253, 67.24520052632978, 65.01288160201042, 24.103113758948542, 1.7501460039807906, 0.20115470934298732, 0.20047840692343252, 0.18274239895324554, 0.0934006659794719, 0.17268896583587895, 0.10950070084823717, 0.1399280431289827, 0.16764547195165388, 0.12219854690615209, 0.17089268883630154, 0.14300076050623772, 0.08515624224298424, 0.1492245354118847, 0.19253571457680196, 0.1721545275781424, 0.1133168529298517, 0.16116047638558573, 0.15595314693787407, 0.10899437035644248, 0.17609442584216597, 0.2554515586985696, 0.09529196086429781, 0.09155001971990832], [0.0712656662348778, 0.07502682086440825, 0.06361937713659098, 0.04539660456019544, 0.09295137839451914, 0.012409651441679848, 0.030175303184096853, 0.05286643679644312, 0.0856740027666092, 0.0383723673651055, 0.01697612535809317, 0.027513411947556084, 0.009900010603990768, 0.03339255070914665, 0.03172915549047532, 0.029011081280787627, 0.08018055480093726, 0.0635311467903516, 0.031149292049268563, 0.07821442078678839, 0.04946527837385093, 0.047600130069880724, 2.1530193859531037, 47.84537730678436, 63.66409617085611, 58.27351616274927, 45.8507893162389, 30.720685681989117, 23.574493969640425, 40.54457949053857, 54.24113919658046, 40.6303931051685, 10.717028283303785, 0.2598967379139316, 0.10628765914589168, 0.042975123205612746, 0.1160704870257647, 1.9676544228869102, 5.9652695059776315, 8.395650963629446, 17.60366205246218, 9.784400443876944, 14.537530579874593, 29.39686025342634, 47.23996339305755, 63.39076972776844, 61.64824501160653, 60.32460589562694, 52.97883418298537, 53.06379664328791, 59.867033958435066, 61.50743192242038, 59.28220856574274, 59.08139498003068, 58.07082768409484, 57.71773984355312, 58.72582820154006, 48.862283152918664, 47.18530124233615, 52.33078802785566, 56.27648061321628, 57.64364627099807, 57.65849636447046, 56.13358474546864, 56.664920776121086, 48.98503764983147, 45.529919824292584, 42.647840669078214, 44.042462918066214, 44.62268737054641, 49.089070673911806, 52.92804733399422, 56.71083604135821, 57.32680505321872, 58.48937203807216, 58.27598725595782, 56.588830717148326, 47.88907251050396, 42.739365254679036, 42.3625196180036, 43.066404634906405, 43.959967628602065, 45.82279928268925, 49.26643633073377, 58.402954378435695, 54.818708204454, 60.844731792326904, 39.44131874269055, 30.55955863768055, 62.179718325215006, 53.066867859132834, 58.27488114756923, 53.369004111136164, 59.68070568576936, 56.77930493508616, 61.164620691730136, 57.754417927034446, 58.13455443228445, 46.50300495086178, 42.07799480807397, 43.37676609716108, 54.53882355843821, 54.17296840298561, 58.08968643988333, 54.601404974537516, 51.684114702286266, 48.86517786210584, 43.26799484991258, 40.584391547787575, 42.706440879452614, 48.13607984973539, 55.601817254097234, 55.978647201291984, 57.240379548841915, 56.24922014051869, 54.83759049446353, 49.4273123433513, 50.29469351614676, 53.19776911889353, 57.267840062418294, 56.5341724887971, 53.491605635612245, 58.02541448223976, 60.50531733420588, 56.464252318105395, 56.97068522053381, 52.989153938908736, 57.72494523755966, 58.33652903956752, 58.797886063975675, 38.07422760994204, 20.165905260270645, 8.959905485953055, 6.575445667389901, 13.312780299494344, 3.581033752810571, 6.824987348048919, 1.6009835370125312, 1.5579474140559475, 0.034157600584289724, 0.06777370724106027, 0.06575780049447091, 3.103120158756933, 28.237074229025072, 67.5069873563705, 29.022134657829042, 15.417428035889904, 20.550536801738126, 39.41949467505179, 49.27397904857513, 51.16627554739676, 21.379939625340125, 2.085163852860851, 0.05673074133453831, 0.03988822171043965, 0.042764472009073344, 0.021844972263000185, 0.03914538838510071, 0.021519831141396877, 0.08589984548668708, 0.07846025840168999, 0.021041966561648636, 0.02720730236521171, 0.049371666259943485, 0.09413959608683664, 0.023299579794007926, 0.026932935636009903, 0.018539831470397693, 0.026651007618995446, 0.05913865144154238, 0.022654587387918465, 0.04694438561977399, 0.03036369952643591, 0.07776023023912022, 0.016472543206726833, 0.08471824679403536, 0.09159716477076854, 0.050874635006391236, 0.025243759643466725, 0.06904329879269486, 0.04580456170163328, 0.027377471560612324, 0.033246488385503335, 0.03724951995536685, 0.06053393503891365, 0.01960575280170287, 0.014548045113652706, 0.01575257856353757, 0.024392630213931687, 0.02495823101320815, 0.07114971882753796, 0.013560552033595743, 0.035075377748017354, 0.047048539103519534, 0.01275757314532154, 0.09924185657573324, 0.060959661589755174, 0.03500737978385822, 3.145220428705216, 57.19658236349783, 69.25928269663166, 67.12723132102721, 53.395939027109456, 36.758311640831735, 29.17451873902352, 32.77175188064575, 44.338264542241255, 41.195806687878026, 12.677499498090437, 0.33460121962331957, 0.05043961580902819, 0.17674340956634094, 0.7616874539563734, 4.145814853329813, 7.12701867665014, 8.048169660952784, 8.478925824165344, 8.692852873956005, 19.138075613206436, 30.875787965713013, 48.51478076750233, 63.37977532417544, 65.52112663945844, 61.83742876975768, 55.298665108219275, 56.8842165700851, 61.64277722758632, 62.26323735329413, 59.622415342638575, 58.48874838121476, 59.56107339551372, 59.919130879063765, 60.38239809774584, 51.038257229712706, 49.40626098263649, 54.49831724166871, 58.64070100169028, 59.52637218659925, 60.52991451755647, 59.21056255217522, 59.40734786372031, 51.77267397603681, 48.93624728725803, 43.20526438374674, 44.25612226609261, 45.78497978948778, 50.38373916379867, 53.7814256452745, 57.88151056535783, 59.8190829830785, 58.46707728601272, 59.63228010362195, 58.75866628462269, 51.27151273912, 44.84915717955559, 45.68109189310382, 44.90772601096861, 46.277037205234656, 47.45716856371972, 52.494229270565896, 61.96268966121059, 57.54095077514649, 61.46870636170911, 40.33454441255139, 32.71696029170867, 63.42451387836088, 53.57241038353213, 58.503896574820246, 53.910071542186124, 61.728331965784875, 56.79667319020918, 62.02445914668422, 59.3359842608052, 58.67855579622331, 47.82806396484376, 44.536226564838046, 46.118671509527395, 56.67878243231005, 55.380528896085686, 58.8452055377345, 57.41134389754265, 53.89068326642437, 50.69261404775804, 47.224340592661214, 42.17372025212934, 45.158683176963564, 52.05709680434197, 57.932399395973455, 57.29977600036129, 56.54034629944832, 57.24363903845511, 56.64981180621732, 51.193508563503144, 53.43069122683618, 55.24359895337013, 59.34005175867389, 56.738692714322, 53.49945822069722, 59.45348278168709, 61.09884254394039, 60.072613223906494, 58.95278046208044, 56.614773273468025, 59.08781590000276, 60.35733415234474, 60.501861726084066, 37.5338936621143, 19.52301113836227, 8.431612233961783, 9.346728651754319, 16.071481300938515, 8.377086385603874, 10.845076999356671, 7.017163874641542, 1.9429002221553557, 0.1599921156922656, 0.057926918680389086, 0.08464762880917519, 3.6003190663553055, 29.88841756697624, 51.02634106912921, 27.72357125436106, 24.19492075520177, 27.55774521058606, 45.90110548080937, 55.34589436746413, 59.322405015268636, 28.85019756132557, 2.670693801295373, 0.014385729277085875, 0.03854070369514727, 0.025740763014783303, 0.0306538304298996, 0.015341057198032018, 0.060965108474896806, 0.042115878989739765, 0.04087022768573896, 0.022500075114470337, 0.03814583133545615, 0.04569478513252351, 0.05834221494414153, 0.016062841300041448, 0.05031443321176114, 0.036637848543543974, 0.08427897963913218, 0.01393529734829621, 0.06988133769482374, 0.060102949294471936, 0.03354962171626187, 0.057024164500856594, 0.0350614809130709, 0.06664069384456643, 0.269636289486962, 0.14725290088643953, 0.12613158868325333, 0.10879591527965762, 0.17805818498374956, 0.11482393173801322, 0.12846259505397853, 0.1514745969325304, 0.1790956825378441, 0.23374277197064894, 0.13380012114442166, 0.05874546447528466, 0.10332477579434073, 0.11576356155978096, 0.1846537117155329, 0.11352074723089896, 0.1735637769583733, 0.1321121996208545, 0.11352859963212283, 0.17819482442592421, 0.13653801213349068, 0.16662050759600056, 4.6613432418915535, 69.6663070494129, 76.95891103436871, 77.65632414048719, 58.70225867917461, 44.77428697770642, 32.801544243289584, 58.86034588659964, 70.23565476940524, 52.07005239302113, 14.3049487375444, 0.4523976261336958, 0.2568510174751282, 0.28069170432225354, 0.6233746306069436, 4.408781336199853, 13.670901521559685, 16.480609024724654, 35.35664089264409, 21.06181775369952, 19.515391934302546, 32.82893807657304, 48.883346280744, 67.69923056325605, 67.55743688152683, 65.73977524234404, 57.28401591700893, 59.74167108535767, 64.62222922232844, 65.29240146760019, 58.56378724498134, 59.28178887213431, 59.59592757686492, 62.90177176075598, 64.29796688018307, 54.10506433056247, 51.314678422866336, 57.90339346854918, 59.52582305477512, 61.21277170796549, 61.216446968816946, 61.2512933054278, 62.12295378408125, 54.15514123055243, 50.40911297644339, 46.4241692327684, 46.93218677274643, 48.71333506799514, 52.23327006063154, 56.82508291736726, 59.25605812380391, 60.75734922962805, 59.13695927589171, 61.342864959470695, 62.11618377316383, 53.36184578557169, 47.738320135301166, 48.15502489766767, 46.564072332074566, 49.40926159581831, 49.289888181994044, 53.73188610999815, 64.23925684344384, 60.33047376140472, 61.9919740769171, 42.5052664356847, 35.77771517538255, 64.25969239204161, 57.444515382089925, 60.75754142576649, 58.5376524925232, 64.01775667744299, 61.08020736325172, 63.9175989550929, 61.456166544268214, 62.02292942231702, 50.56037133739841, 47.41346943762995, 47.99746328784574, 59.5668432020372, 57.021272028646166, 61.81657352755147, 59.19473186615975, 55.663092520929155, 53.7785074018663, 48.356085592700595, 44.512304029157086, 46.64684218745078, 52.59553624737648, 61.39887248316119, 60.06629036318872, 59.578433805896395, 59.93992728571738, 60.26558991401427, 53.949448216346006, 55.95124160089801, 59.114899866042606, 63.433182316441695, 59.41354520859257, 53.844407143131384, 61.36167272444695, 65.01124597364857, 61.18948459625245, 63.80052012781944, 59.19355907747823, 63.54227519804432, 63.641326812005815, 64.88189405010593, 42.72011033950314, 24.57947384926581, 14.600099248270835, 12.215215813729072, 24.107312656218006, 13.563303062992713, 14.818029076822343, 6.215191166247092, 3.748666538346199, 0.4078442813648332, 0.2469945302413356, 0.3542098222721008, 4.4407594396222025, 38.07416092964911, 82.31347191718318, 37.696479828126975, 24.77093062093181, 32.259349130815075, 54.79127906983899, 62.327799566330455, 69.45824884599256, 36.001792338586625, 3.312541140664009, 0.18808871207218017, 0.14787387643610278, 0.13312000360700393, 0.1571833922137176, 0.17223387896533937, 0.17341849604441276, 0.172017076082768, 0.1466345300357188, 0.21732808180874397, 0.12454399403424994, 0.0903821646446182, 0.22738160685666148, 0.13437707728195575, 0.17076576338900676, 0.06723077306824346, 0.14444298231072966, 0.13250138760814745, 0.13738507555136759, 0.19851826371685152, 0.09441550265276626, 0.20904270301182426, 0.14422478514813608, 0.1887928847704203], [0.04425121884372446, 0.0597650777067869, 0.02702833273478093, 0.029780750666114113, 0.044638185176037015, 0.10534499561594379, 0.009221935648501161, 0.050357525657501914, 0.03570536632210978, 0.011566233644712598, 0.03578340386851661, 0.0933742665896012, 0.021605228877536232, 0.07820867512735628, 0.028252315241843465, 0.030245834984065547, 0.015473859497315943, 0.07431903989204476, 0.047719532533759074, 0.06619296907897919, 0.050683791013134104, 0.12091959376008281, 7.859704186839442, 49.51651488581012, 64.49674475577571, 46.17277668368432, 39.79195510187457, 20.92984372569669, 19.00447380158209, 39.90002816723239, 37.089630326917096, 29.50187190886467, 3.4155925916087244, 0.13345731212006462, 0.11765784418751156, 0.06615707019884741, 0.4107815237535585, 4.839188898763349, 5.496981653474993, 11.744269574842146, 11.266228748906045, 19.54652966991548, 30.88429950898694, 42.05859084283152, 50.54979270504367, 62.77160790658767, 59.091993224236276, 56.92745677886471, 50.463673145540305, 57.70536476565946, 61.104255414778194, 61.32871697025915, 61.52509435530632, 58.4164551765688, 57.28303532446585, 58.28861336554251, 54.53938837974302, 49.145144877895234, 44.99319053465321, 49.57544457527899, 53.78581085512715, 54.7699256866209, 55.25490714657692, 51.05047541279947, 44.91696319272442, 43.23607067908011, 42.558626359508885, 43.01002840841971, 43.6794004901763, 45.8410696829519, 49.37808659768874, 53.9022542584327, 57.22066963872602, 56.24112044611285, 56.96924178831039, 57.615754296702725, 50.139308821770456, 41.16642813528738, 42.7747058099316, 41.49013742323845, 45.30617606255316, 50.47836242183563, 47.9823935416437, 49.41065403722948, 56.91419524531211, 56.73242868915681, 60.17053519525836, 43.2865398160873, 27.66730093186902, 62.94748698511432, 54.02505582378757, 59.82113830504879, 54.35761790121756, 57.6570450875067, 53.4686166240323, 60.1378147832809, 57.738465647543634, 59.50050415531282, 48.72529437465053, 42.252195112166866, 40.93975436302924, 53.15414059546686, 54.67617319476221, 55.55225418459985, 56.9695948016259, 52.92295609751056, 48.6191354259368, 46.506437024762555, 42.48222251092234, 41.433239521518836, 44.19295249446746, 52.17932570365168, 56.512693589733495, 58.48353162888558, 56.6108940493676, 55.395418213259795, 48.443091607862904, 47.72212466885967, 53.64511935941635, 57.390335682899725, 56.81071919779624, 58.126493961580344, 54.92110952254265, 56.331644827319735, 58.51440852688205, 60.663883070791925, 54.95548125236265, 55.550787218155406, 57.76268628335769, 60.0931703659796, 48.2825646861907, 30.184978169779626, 8.857765986073403, 11.47822795375701, 18.331291137203095, 8.97754144284033, 16.529432727444558, 4.539892933061046, 0.8429441937515814, 0.10777717921882869, 0.06889168999247974, 0.056511345244343245, 0.5238394006606072, 11.50764867182701, 42.36590462346231, 44.82070822869578, 17.415666772473244, 23.251959431555964, 40.72457313537598, 49.23940335550616, 48.583841939126295, 36.26321831057149, 6.11686421017493, 0.13990892157439264, 0.048545524703278664, 0.06590008600464752, 0.0036726618981769974, 0.019470674263673927, 0.05185816932709948, 0.06439289228329736, 0.0410061278530667, 0.02815294214674542, 0.027691554203028643, 0.023607731000670505, 0.026872669414226568, 0.0457675175200547, 0.05801021158995648, 0.01065233863154126, 0.08462699040049508, 0.06475126821427576, 0.006623358227267501, 0.07166195585722886, 0.04059449732003193, 0.02967211748323133, 0.05620988581569926, 0.019010805089267033, 0.00832082951561578, 0.01099306676957396, 0.01585776052032147, 0.013775142837285757, 0.04545759281984741, 0.07385478294905155, 0.058512332428607254, 0.07745480630546808, 0.025274276755930438, 0.016370619038840937, 0.011301782966080693, 0.02853946031762227, 0.06012122815234527, 0.04092230251239192, 0.021094635106442917, 0.024954402488806558, 0.01190938740863555, 0.09025812734879794, 0.006264431191788566, 0.07225648605174596, 0.06855858730212336, 0.1855151775863863, 11.739817684696568, 59.07545651158979, 69.29767485587828, 56.40695041225803, 48.094228159996774, 33.71581931268015, 19.331983866230136, 36.62617875683692, 42.10617311539189, 35.099388322522564, 3.909359915602592, 0.21836924126311658, 0.11906947610118698, 0.08579861462837265, 1.2351283815599259, 7.429178462874505, 8.8511920936646, 9.407288086029792, 9.822414094401944, 9.514923807113401, 21.974429738137033, 36.35879078219014, 52.14334187969085, 63.126292151789514, 62.808003579416585, 58.0411353418904, 53.62266379017984, 59.075962497342026, 63.46995453680716, 62.435425481488636, 62.934527474064986, 57.189412270822835, 58.87831034198884, 59.57015368246264, 58.23371587261077, 50.72702892364995, 48.57588345004667, 52.12049407343711, 56.5282928559088, 56.424102937021566, 56.835755686606134, 53.36514842125678, 49.137115786152506, 45.83670800732028, 44.96947980696156, 44.69499626467305, 46.92393802827405, 48.3578977277202, 51.95709597679877, 54.85319760537917, 60.00215176613101, 57.08293953249532, 59.13299768201767, 59.650530892033736, 53.30795241940407, 43.35992343964116, 44.68321738704559, 42.16271015905565, 49.50704236184397, 50.22490670604091, 49.38570776293355, 51.25075947853827, 59.87177218160322, 57.28894241394536, 62.00562000274659, 43.94046952647548, 29.770267932645737, 63.37097352550876, 56.57372566961474, 61.02483918589931, 57.19538996296545, 60.287162949962, 53.865462426216375, 61.7897915840149, 60.634398614206624, 60.14976624519595, 52.72274655680503, 44.21904410085371, 42.77057947651033, 53.91649638452838, 57.87262247454736, 57.92904184710596, 58.42787711851059, 55.45878410339356, 51.928717628602065, 47.59049777061709, 44.3876197261195, 42.931730055039935, 46.53627057229319, 54.51775258587253, 59.30841784323416, 58.406519812922326, 57.912697330597915, 57.874775855771965, 49.42079728649509, 48.43821610173872, 55.16503387881864, 58.383664161928245, 58.284326214944166, 58.333391143429665, 55.681774770059896, 58.29412037326444, 60.36553975074523, 62.99705789935205, 57.70918123183712, 56.01686677625103, 61.010977529710345, 61.942481610082815, 51.12859725952149, 26.907706491408813, 10.517894452618016, 5.859081629783877, 13.796663495802111, 8.386119604110718, 11.4605684626487, 8.320285562546022, 2.7905979608335807, 0.20267721716194384, 0.23688017781223022, 0.027099326102724, 0.4332219857362009, 14.669622278982594, 49.74167854555192, 35.86053209920084, 19.095192340112504, 26.932109517435876, 45.63304678086312, 56.14614025239022, 57.15813136869862, 42.9542052361273, 7.486524495386309, 0.06394056715972482, 0.023549659620790232, 0.019965869667489203, 0.028352670844704397, 0.030410593683500926, 0.002564426179179141, 0.12300141471167728, 0.012780519393873552, 0.08166111164516018, 0.0339774243653782, 0.01320829427230262, 0.10996828261282175, 0.04353245983140604, 0.085989102390745, 0.01482745270139628, 0.0755905390026108, 0.018921799079004317, 0.036489047455571355, 0.03377736050395235, 0.049836842508445826, 0.036510451952175754, 0.06753121743038779, 0.07504546744448524, 0.19022474906617598, 0.10706056525269825, 0.14331686370555433, 0.08549643124664023, 0.19325389136229792, 0.20693487337520047, 0.11782468281566136, 0.2106535560902088, 0.2570830808291512, 0.08534471519411573, 0.10664277920319189, 0.18154737840016044, 0.15149256935523403, 0.12536972190343565, 0.07251470364750394, 0.11813135547263008, 0.1504472730260703, 0.17587693348046274, 0.16295799444760048, 0.11819583709321677, 0.2295904222034639, 0.3641238580307653, 17.059017419815063, 69.77232087043025, 76.82823334970783, 61.140878585077104, 51.777537715050485, 31.42184465162216, 29.705205617412446, 55.99479559929141, 49.020111483912316, 39.049854432382894, 4.884685941280858, 0.3081625754073743, 0.25807534855219627, 0.19553387627726604, 1.8151922620111898, 9.919663379269263, 13.263384911321825, 21.071135344043856, 18.56806697384004, 25.6718853212172, 35.78346537005517, 47.00342485981603, 52.7453629432186, 67.34769990367275, 63.13634518654116, 61.94374069090813, 56.02662563323975, 63.53956484025525, 65.308012500886, 63.596862823732444, 62.63900041580201, 59.60948721055062, 58.86947324199062, 63.20435124058878, 59.36749658276958, 52.80840327662807, 49.35944357225972, 54.13768668328562, 58.11024358195644, 60.61985446560768, 58.93872268738286, 56.684054097821644, 49.260843030868045, 48.81130410778908, 46.704540252685554, 48.35864297805294, 47.828644475629254, 50.23219839219124, 53.033210000684186, 59.17335494872063, 61.335522282508116, 57.96344887825751, 59.5110906324079, 63.41715158954744, 54.894464861962106, 45.194357133680775, 47.91303034751646, 45.40421962738038, 51.08688677510908, 54.464973172833844, 52.75865977810275, 55.30830629410283, 61.98436860115298, 62.42065383541969, 61.28306450382356, 47.44487977796986, 32.56078523974265, 64.09513327383226, 59.02647003050774, 63.00512229242633, 58.890979597645426, 60.140787939871515, 55.90624024791103, 61.44403073095507, 61.45722558421474, 63.75511084833453, 54.99151214476555, 47.06282523370559, 46.15912291311449, 56.27397421867617, 59.932717969340665, 60.80172692575763, 60.505850776549316, 56.849389845325106, 53.499885759046, 50.825743213776626, 47.90393437108686, 45.63424310376568, 49.51186295478575, 58.25131162520378, 61.55754412374189, 62.328850761536636, 62.13194777888637, 61.436997921236106, 52.220373307504964, 51.770120513054636, 58.61420539117629, 63.461988202987186, 59.962684877457164, 61.69091647671115, 56.64785846587151, 58.07922547863376, 61.13828589839321, 65.69970038629347, 59.57658636954523, 61.612500452226215, 62.985659491631296, 66.35759953529605, 52.6763488400367, 34.916739233078495, 13.442323438582884, 17.95086829893051, 26.555471766379576, 15.697985368390238, 27.774263966468077, 14.866472309635533, 5.493972705256555, 0.25466159947456857, 0.45080161983928374, 0.18015279194280026, 1.019358798380821, 16.054429777206913, 56.35991334915162, 57.74361179720972, 28.825419948947047, 34.706190324598744, 54.61163843831709, 61.94945950661937, 63.90302734990274, 51.55073450457666, 11.65074654163853, 0.2892151985677981, 0.22449455854873504, 0.1381998713458738, 0.1516223906148826, 0.13899488675017513, 0.13140038136513005, 0.2798595183318661, 0.1330780832757873, 0.14284313025493778, 0.20812195725739005, 0.12778740346191392, 0.157130807938595, 0.16906704002570722, 0.1883681656251992, 0.12873680090471623, 0.1544087596478001, 0.2735223470916671, 0.12458291896168264, 0.17720195915429823, 0.15153139469123658, 0.12247154999884868, 0.1516361342322442, 0.1629032651262899], [0.05925555262834795, 0.06577504513364646, 0.055576714146281445, 0.03575073404898567, 0.08372426303403993, 0.027771993435078093, 0.032956711797704624, 0.056995968634803454, 0.0997080900255711, 0.02959027822550026, 0.013602416823437859, 0.05890077348017405, 0.027203671108450622, 0.041972478821633324, 0.027934377261948203, 0.05269142401014125, 0.02749124902390665, 0.07551506402031069, 0.06161064863385213, 0.058611165431718674, 0.07213653200456212, 0.7203902280138386, 32.25708984559582, 61.80633221903155, 55.40480052271197, 46.93264569005659, 30.016096599640388, 16.68757288686691, 42.61333557867235, 48.208220081944624, 49.853007178152765, 19.67636992854457, 0.4682121017286855, 0.11853360525903203, 0.03882810157994109, 0.3521192296137733, 1.2036940167027137, 7.387817069407433, 7.7824594801472085, 4.613031408479137, 11.367107206775296, 9.51190064030309, 36.367251334651826, 44.10397352710847, 61.94434865828484, 59.86297822767689, 58.57349118878765, 53.111225943411554, 48.62158298492432, 58.338737333974535, 58.78992365252588, 58.677383007541785, 59.615625719870295, 55.69032553703555, 55.65956631014424, 58.095189525235085, 55.655906738773474, 48.519515068300315, 42.58599665857131, 44.95049161295737, 43.07272749562418, 45.62744563625705, 43.80603813355969, 43.14628370346562, 44.38169694715931, 45.94503602673931, 47.16772117922383, 48.453583948073856, 50.3230247959014, 49.25177843339982, 50.243730160497854, 54.81845325039279, 57.623100896035474, 58.17565302694998, 57.24625918173022, 52.179651260375984, 42.10895015347389, 40.99266321428361, 41.549765294598, 42.302507354367165, 52.54604770291237, 51.93935901887956, 55.64229611427554, 50.5771904606973, 56.72532527677475, 52.55187242261825, 62.52537719665035, 42.153837757725874, 27.489401832703624, 57.98825002485707, 49.39571372924313, 59.4814649704964, 53.20045986483174, 55.90657364937567, 52.29504346847535, 55.4624475971345, 53.784963623169936, 57.672946376185266, 53.42884771285519, 44.75816211392803, 39.62941992667414, 49.961190069875414, 55.13956200691962, 55.26867466588175, 55.57347812960225, 55.5508735102992, 51.10166234354819, 49.19018545458394, 45.07906298483572, 43.69415644676455, 40.261572637865626, 46.38098785954137, 53.96747935202814, 54.41006783516177, 53.38496815773749, 50.35361928324546, 43.59751316808885, 42.04073229143697, 48.09531857890468, 53.12622116458032, 54.92591050363357, 56.18670540471231, 57.906350935659106, 57.89596057707264, 58.677096674519206, 57.85548171689434, 57.65635867272654, 56.12013886051794, 55.428683834691206, 62.601784967607074, 59.38525707490983, 40.70948377732308, 23.791914870662076, 9.984414846666398, 14.88670781735451, 6.392431307223536, 7.187756088472183, 8.089330032948526, 1.0208215973069592, 0.8034079281553146, 0.13098320052508386, 0.07168715248905844, 0.0315767920936548, 4.51736823205025, 30.736277103424076, 56.26622753758585, 37.10599837764617, 22.570602547737863, 35.41667669050155, 43.73142288577172, 49.41925579501737, 43.77747935633506, 11.599203655796668, 0.2938804288785304, 0.05930201969139519, 0.005694444060340645, 0.06545406195425219, 0.05578209848834142, 0.021341303926742366, 0.05237093878789775, 0.05496674728009009, 0.02181865139714172, 0.035097410436719656, 0.02259128745795498, 0.02263593889262167, 0.036079879895213156, 0.02816008974707896, 0.015409263921150518, 0.03863882040604949, 0.02885652304206404, 0.07996580503400295, 0.06988724423271996, 0.028979397799459197, 0.04848560896672068, 0.049570711224430034, 0.004247832572042582, 0.057865926590297496, 0.08693769544122681, 0.04048335328397732, 0.021039206729901415, 0.08183433944659849, 0.07262942531416494, 0.07833065930753946, 0.041780964501442454, 0.03653530001399979, 0.035877521600454085, 0.021077959287551143, 0.05751566736087684, 0.03669432071488231, 0.043688619193891366, 0.03797518141988305, 0.037072787301674966, 0.029575067549763672, 0.041652732874236764, 0.02856649939090975, 0.07223933334312133, 0.03976678528312234, 0.8338835186535313, 39.93144635231265, 67.81071216829362, 61.9575160549533, 50.87200756995909, 40.45553384288665, 21.221573929632864, 31.10469945015446, 48.01629066467286, 53.76525763542422, 23.417681532521403, 0.7924809402996494, 0.03081394663651384, 0.021388935443434506, 0.3793460863732523, 3.797081579123774, 9.208227799784753, 9.709873449417854, 7.517383742717005, 6.632382302514969, 12.302423830955261, 34.8339536882216, 46.52129496297529, 61.43975926983742, 62.82491291722944, 61.57989378898375, 55.81567664300242, 50.51472279333299, 61.2387260313957, 61.0606582703129, 59.37823603230139, 59.67715986313359, 56.42323217084331, 55.50661740764495, 61.60691499710084, 57.9959104138036, 50.92235903586111, 44.26405329858103, 46.10538644175376, 46.97197137340423, 48.22261518047702, 46.227332930411066, 46.194141834012925, 45.52385976237636, 46.257660696583415, 49.64098345848822, 50.45872311438284, 51.12025830053514, 50.62429028172647, 52.097265797276656, 56.427793887353715, 58.524006566693714, 58.52649727175313, 57.668753362471065, 55.16808156044253, 44.597666571217204, 42.88612073467624, 44.216357277285674, 44.72116239609257, 53.62087126701109, 54.17956582961544, 55.6780053723243, 53.2015149824081, 58.98628534809236, 55.331542415003625, 63.637224012805575, 42.329155937317886, 28.511067475042037, 56.94488779191048, 51.70009443836828, 59.74544048309327, 53.86552910650931, 55.98435032752253, 52.82832107236309, 56.49923986004245, 55.33158163870535, 60.27388572692872, 57.45033617942565, 46.057486457209436, 41.86385300851638, 51.487172495934274, 57.92700221461635, 56.10712835865637, 55.8959008801368, 57.92071073285995, 52.43033386045887, 51.384551525115974, 47.086865440491714, 46.68874094563146, 42.70859818304739, 48.029367846827355, 56.20733707181869, 57.26361959211288, 56.95376803798061, 53.943815692778564, 46.9281388867286, 44.338248852760564, 50.12527458129391, 56.66070030581567, 56.16805061217278, 57.89732948426278, 59.53264797887495, 58.66874594842234, 59.99542882365566, 58.89708672800372, 59.554919196713364, 57.30961330475346, 58.3249855041504, 64.36161125859907, 60.077767218312914, 41.396031918064246, 21.231322980696156, 8.020532150422374, 5.567097942675314, 5.549153099136968, 11.106162705729085, 13.956405943439854, 5.702349110957115, 2.6287979848923224, 0.1594156651727615, 0.06901340604188942, 0.08095686999900688, 4.812151020573032, 32.69706014663943, 51.09032277138003, 34.7520310648026, 30.302143289196877, 41.579026176083474, 50.40959542797458, 55.322379758281095, 54.02263964376142, 15.183978369159085, 0.46749323546405763, 0.020434912744789355, 0.026691752005248304, 0.017289778991271893, 0.06359421497871799, 0.05518060838503223, 0.03479693543105837, 0.016802633256320993, 0.07199363362404608, 0.029467114269913688, 0.03154577893926011, 0.04232310577325764, 0.021708867167152708, 0.07997517428931691, 0.017965089326964754, 0.016388315669891816, 0.07190086037641572, 0.010790885632647382, 0.06677020866904529, 0.03786253585149685, 0.03431651020242322, 0.024470190870605653, 0.0022734042196985217, 0.2462655362943488, 0.1320143548711654, 0.17608354739364118, 0.15132770723392888, 0.23385351764098292, 0.07546027341196615, 0.20300436734912858, 0.1767632206000628, 0.1553945615887642, 0.11550195785539767, 0.08522373458911335, 0.16953047725462145, 0.11722190185419976, 0.12174430273232922, 0.07534260230679667, 0.13105748041022208, 0.1514875897837262, 0.17604345035168434, 0.1634088678345565, 0.12426536785618914, 0.15965273874180932, 1.3630839413212192, 48.48205251078452, 78.33423522210892, 70.16193774438673, 60.021626334036554, 41.91021150158298, 26.200057960325672, 56.75408801724834, 60.369838668454086, 60.689249038696296, 26.470366139565748, 1.1580638587474823, 0.25200664516418214, 0.11988935105863119, 0.5908431052680939, 4.16800223050579, 13.90479833849015, 16.879719995683242, 12.711442708969118, 19.49370122724964, 15.730020346180087, 38.29733987008372, 47.84212566191151, 67.63708453024587, 64.08009882896178, 64.80306225438272, 58.2989723451676, 53.20200920104981, 64.17560069791733, 63.20708905496905, 59.438985701530214, 59.95338886014877, 56.08879520047096, 56.1683173333445, 64.63929153257801, 59.90632434045116, 54.79422869220857, 47.6068187529041, 49.15010275379304, 47.54980318007931, 50.14204271378056, 47.53626315824447, 48.83912940179148, 48.456604173106534, 50.01217695974535, 51.45586021484868, 54.784108977163996, 54.26341825915922, 53.51675979552731, 54.41408434221822, 58.45555728481662, 61.44181066943754, 60.474401212507686, 60.14420040192143, 58.43435295166508, 46.14838738595286, 45.51807034400202, 46.22970988673549, 48.57145901649229, 56.60795619410854, 56.61080383485364, 59.52172417794505, 56.49830633594144, 61.44961226371027, 58.05898212617444, 66.85051595011066, 44.315318676733206, 31.853226923173477, 57.85565430118192, 53.40886323682724, 61.28088758837793, 55.10553936804495, 57.76933470079976, 53.457928165312744, 57.864436487997736, 58.25053499590967, 61.375138221248505, 58.40917133515882, 48.86102014972318, 44.27760900989656, 53.54725622361707, 61.6312611487604, 56.891272914025095, 56.706925438296416, 60.23692131042481, 55.81383705139161, 52.84035490405176, 49.868979069494436, 48.93278775676605, 44.597756785731164, 49.54589736077094, 59.57868875995759, 59.258031076000584, 60.784346903524096, 55.824741240470644, 48.75728522577594, 45.43368447211481, 52.64553862233316, 58.93774209483978, 58.94075447513212, 59.651174160741995, 61.480183216833304, 61.86819584138932, 61.71867116805046, 62.43296223302042, 64.4485584382088, 60.46238699266988, 60.56959321421962, 66.44184420185705, 64.69819768782585, 46.88611069033223, 28.759243680584817, 15.839577048055588, 24.045654958294286, 14.473497886811534, 15.199552139928265, 19.237333151601977, 6.937933958345845, 2.8617534329814296, 0.2946535648117143, 0.2728237974787912, 0.2141485870966027, 6.803582483722318, 42.84064477489841, 70.52239571848224, 45.31632715655912, 34.60448718840076, 47.94759035110474, 59.86782627720987, 62.97916404662594, 64.24659167566608, 19.97820023567446, 0.8397004549061099, 0.1997940299371558, 0.20647474564611915, 0.1988714455717033, 0.1681730307398304, 0.13169180121152632, 0.14240610773765272, 0.07925205623670932, 0.13210997796587406, 0.12123951973814158, 0.15914923511445522, 0.1508724365022875, 0.07852058782572709, 0.14795442292046163, 0.06932165683998216, 0.09756071493029596, 0.11806700408699052, 0.15005932610121467, 0.1401522617426611, 0.19017794109400243, 0.1373136148697907, 0.16462385263894835, 0.08815679413777205], [0.0690938835783351, 0.01834021385518774, 0.01966900868161071, 0.06858910824502669, 0.04992623730833012, 0.015858327425385437, 0.04923965015839185, 0.07157211672634849, 0.06248985710103185, 0.05298975013917493, 0.03265951181791964, 0.01213648938573897, 0.036116824485361576, 0.036980400928446365, 0.059251588123339805, 0.08936936576520244, 0.06838254795800294, 0.03872324712574482, 0.0871236096586912, 0.06534499401647238, 0.0606026339735235, 2.1059673688104077, 36.05532092432822, 58.419640141148726, 49.46525735239829, 44.572080950583185, 26.71579472480282, 37.73025143531061, 48.86794705544749, 46.94612295396867, 39.23648864992204, 8.032780731877974, 0.33117873714335505, 0.013370469340213366, 0.0518911034469643, 0.17652689779718078, 1.8730008890551908, 6.874452848588267, 6.534377961389481, 8.818295175029386, 12.073255431267524, 22.878165398874593, 42.55897152808405, 50.49976287349578, 62.459477455385276, 57.01040314089868, 60.358310822517645, 46.71002372618645, 50.92977231548679, 57.26001493392452, 60.559320526738325, 57.54551249165689, 57.095969646207756, 54.00726003031577, 56.92793923039591, 55.58287220616495, 54.928252158626435, 47.587442244252856, 44.55631302249047, 41.278027411430116, 42.89345948926864, 41.30629201089182, 42.77747892564343, 45.151336577630815, 50.52790195711198, 54.8464628957933, 56.51385853367468, 52.94473701907743, 55.683684964333814, 55.200507794657064, 54.83307192402502, 53.40576456439111, 60.06468611378824, 53.34499136094124, 57.07747959321546, 46.22852140857328, 43.25203472568143, 40.73490073603969, 43.883234300921046, 52.98711430641913, 57.8972275026383, 58.26415346514795, 57.82769172422348, 55.32117951300837, 56.06947360500213, 53.465792517508234, 60.85477305996803, 42.59765002035326, 21.753833678460893, 56.3549005600714, 49.17695529999272, 52.29373731920796, 51.18591485484954, 56.14319455239081, 54.83203641829952, 56.648988108481134, 55.649521120132945, 58.64059117532546, 55.511143822823804, 47.546578991797666, 37.50555845998949, 46.455658020511756, 55.05916910786783, 53.032762850484545, 54.036328715662805, 55.452033704327, 54.80488969433693, 52.719832235767, 45.550563258509484, 42.69821566920127, 41.10916937551191, 38.817567748408166, 42.979830080463046, 45.36230910208918, 46.82487464720204, 42.4325966835022, 41.49005113109466, 39.8220867495383, 41.31286198093046, 47.94519770529963, 51.972291238846324, 55.598161605096635, 55.97038276733891, 55.35852439941899, 57.50150349832351, 58.13528007076633, 56.64663860874792, 55.127692914778194, 56.45215572849397, 59.23960378093105, 57.55432213506391, 47.1653167663082, 30.4974086823002, 15.688871741294863, 10.287983744375168, 5.08115501173081, 9.104937084259527, 9.329785973795, 3.4686534347072726, 2.4360522243284413, 0.5346697388637451, 0.03816799425910558, 0.043071665605830575, 1.2713074660108936, 22.032267047512917, 58.21452371535763, 64.52170671955233, 22.03566578126723, 35.82561123755671, 41.71985887712048, 47.73168348496961, 52.03877933563725, 20.76565331028354, 1.5198229565735788, 0.12451647615600979, 0.03139894478203308, 0.06602135772306113, 0.09392294642185012, 0.032012447143994996, 0.045285521811174775, 0.04131638580152104, 0.015047295037807237, 0.05317428922881523, 0.04809560126534874, 0.016065566657832073, 0.03224640656563063, 0.025755155891660723, 0.019931188867157026, 0.03708375001987142, 0.0215597098482953, 0.025419843037642782, 0.0274475168947491, 0.03528751515512986, 0.03555636988171647, 0.0695887457339033, 0.04849754078614135, 0.06773127363093438, 0.03543000750904603, 0.033376570115046154, 0.07681988029470367, 0.058209995829289964, 0.06926453732434781, 0.03526539436631626, 0.0898233418082518, 0.033497282589275035, 0.06746338800557199, 0.029019381843447208, 0.04076759871696273, 0.043214552495027744, 0.06637638584981043, 0.061722118257274555, 0.009049729616831868, 0.05164633835515669, 0.047617845853129705, 0.048624500707392736, 0.024492733007777604, 0.08372678346331082, 3.4379027880007222, 44.181275598464474, 63.94492610808342, 56.86361235956992, 51.81014437829295, 32.72108270275977, 32.8674243727038, 49.59840220789756, 51.781154140349365, 47.293868526335686, 9.735797374479233, 0.3098811864131882, 0.0354004901413235, 0.0959398031174656, 1.1286916800083653, 7.077401184266614, 9.28408153595463, 10.615606577165666, 7.164259620251195, 12.560986472714333, 24.034537000040856, 43.353545665740974, 53.5709826407894, 63.79586819679507, 61.51652005410964, 62.41548807390275, 51.34113480967861, 52.4755548661755, 60.71079461805282, 60.979261244496996, 59.46277879899549, 56.04834379688386, 55.163025625290416, 57.68147360893988, 59.110518578560125, 58.100339597271336, 49.82265587775938, 47.67320486807054, 44.04312972099551, 43.14828018988333, 42.501755914380475, 43.394887447357185, 45.883470504514634, 50.60431757280904, 56.51666302834788, 58.32760172505533, 56.90663291561989, 57.07356114541331, 57.33953706679806, 57.815697116236535, 57.376999624313854, 59.566600015086514, 56.37040568936256, 61.53217031109718, 47.8532063576483, 43.93187953579811, 42.44868232357887, 44.90789859525619, 55.46713482949042, 59.049208010396654, 59.46650112828901, 59.48481075225338, 57.27715569157755, 59.55902984065395, 54.8615679433269, 63.12514289732903, 43.957971142184356, 23.196308843551144, 56.54650442061886, 48.9721252072242, 54.54802543886247, 53.19395265271587, 56.226458626408736, 54.857469066496826, 58.82060050964356, 57.50113087315714, 59.556507756633145, 58.22683211295836, 50.02316744096818, 39.607180087797104, 49.39888300434236, 56.16134728154829, 54.769525604863325, 55.21194542607954, 57.304663273596, 56.21264796103201, 52.933550419345984, 48.29990156235234, 44.76443006146339, 43.295282779201386, 41.55897894213277, 44.4311737245129, 48.57385950703775, 49.883389857507524, 45.026824858880815, 43.067189108940866, 41.00270055955456, 42.67689366494456, 49.67818713957264, 55.45337123255576, 57.26684378039453, 57.87717242394724, 58.16727092189174, 60.11693992922383, 60.36396688030612, 60.55778688000095, 56.91787442853374, 57.82049417495728, 61.3987155883543, 60.39490261385518, 50.956605249835604, 34.104377146690126, 17.820116089236354, 10.78076679860392, 5.665795072432488, 12.401952012892693, 9.322157944402388, 7.954743706410932, 6.033603568230906, 0.3232741806535952, 0.08575519276482445, 0.07168455545099513, 1.4051963461022223, 22.637955527151785, 61.44422684946368, 54.00707567891767, 22.86870268083388, 41.90574784432688, 48.52548099333241, 52.9417089493044, 58.525167588264715, 26.15569595367678, 2.0065345494977893, 0.08285993965522898, 0.06381300585945288, 0.05412219280016519, 0.07106758654117584, 0.028472988783652266, 0.009309189232637086, 0.029639545339910738, 0.04811069319745706, 0.04396230410484057, 0.04449034935884899, 0.01616391127989177, 0.04475873294136217, 0.017346076877607454, 0.003162349424993379, 0.042276267157567125, 0.045475163046390786, 0.01230507469435613, 0.04699179114052846, 0.06897127886693324, 0.08501771822451584, 0.05168352426300126, 0.08350482480900903, 0.213036717726819, 0.13743317055125392, 0.1895260615574737, 0.1981354189375716, 0.18490095893221517, 0.11629423832580929, 0.12133041607035745, 0.20113019452941036, 0.1253202785888026, 0.11287491978897203, 0.08801635489949296, 0.10795684215883095, 0.16262160524004893, 0.2784089155254826, 0.14729822264803996, 0.1540698423500984, 0.17424616211604688, 0.2207709881927698, 0.16875225449762038, 0.26921135583712213, 0.12385482899844648, 5.093930171382043, 52.66185960462017, 75.35739160353138, 62.963604004152366, 57.73367643356324, 37.729270842767534, 50.76679783482706, 61.86442644365373, 56.26289352293938, 50.446379415450565, 11.751365142483866, 0.5939713180545838, 0.10705927822498545, 0.1619343630849354, 1.536929270913524, 7.971335332239828, 15.941620449866019, 17.05795445749837, 18.939476205456643, 22.605803858849313, 27.932251153453706, 44.78167672311106, 55.083766291218424, 66.71847328062981, 63.75771922449913, 66.25071494810044, 52.71198749542237, 56.85046849712249, 64.07420742896296, 65.16580304791852, 58.330606260607325, 57.107203314381266, 52.91473088725921, 59.26994331421391, 61.44034370299309, 60.86009179392169, 53.44770646864369, 49.50532044133833, 44.558336965499386, 46.3150724287956, 44.670559898499526, 46.106033632832194, 49.718371821988015, 53.98524376653857, 60.439158716509425, 62.042619720582046, 57.68555287391909, 60.31973823424309, 59.1904604050421, 59.28689579809866, 58.32414219456335, 63.34676073443506, 57.24995013206237, 63.33989266426333, 50.33642361241002, 47.4848565747661, 43.253195747252434, 48.920844139591345, 57.78838957509687, 60.899252737722094, 62.514994682804236, 62.97782259602701, 60.46643487868771, 61.27987561687347, 58.29190031174691, 64.3647373876264, 46.00673490954984, 27.825680355871878, 57.11704061877344, 48.456317840083955, 53.49675963001867, 54.23501637674148, 57.56526947021485, 57.714825522515085, 60.54516861515661, 58.410603000271706, 62.89499390509821, 60.579285390915416, 52.49969313221594, 41.85508651118125, 52.59583826987974, 59.48925479765862, 55.257162509425996, 55.776531388682706, 59.259647092511585, 58.331873186172984, 57.98759891140846, 50.79932997303625, 47.291997555763494, 45.40112095494425, 43.9640429712111, 47.53541200391708, 50.495463955786924, 51.55878713054042, 47.227407886135964, 46.09297606252855, 42.42754859309043, 44.30119029937252, 51.88711697055448, 57.45338778341971, 60.604251277062204, 62.008142086767386, 60.63695599955898, 62.92865176354686, 63.680899604674316, 61.40646619181479, 61.12823286364156, 60.076394388752604, 65.39122166172152, 62.41537824753792, 55.02370695913992, 37.110167857139345, 21.338499784469608, 22.1351037486907, 13.83919571676562, 19.76222865043148, 18.20365721179593, 9.393944182703573, 3.7951645207020546, 1.0528353697830632, 0.19944323827662777, 0.14502609779517497, 1.9671119100624517, 27.238536842407722, 67.419385140942, 69.23221834244268, 32.92930564572735, 48.764898546280406, 54.70052326879194, 60.74929660366428, 67.24174884057814, 33.286480595988614, 3.2022406593445814, 0.2663625812818927, 0.14160310969718043, 0.3011758228944194, 0.1813425724544833, 0.11223844628060058, 0.10571698492933666, 0.15998353550751365, 0.12838569514813924, 0.08796229207467648, 0.12514770962297916, 0.07414534477697265, 0.16605090590253954, 0.1723549821444096, 0.0767547934646568, 0.1659002776948675, 0.2958470378671923, 0.15397538370903463, 0.12322728807527213, 0.1688003648192652, 0.21586250964431994, 0.213128249912012, 0.19430398340186766], [0.04953506515331326, 0.06364199205211575, 0.02263791156902669, 0.031666625478875735, 0.01974153422540234, 0.017603030428290367, 0.030398949147051865, 0.026456392557931044, 0.033548629632399934, 0.026271830485653014, 0.06454964153348439, 0.03548120516502569, 0.039058042870413874, 0.04742887111440782, 0.012630471497804168, 0.06105154617539337, 0.045128286095155824, 0.037027687705572576, 0.020515790562175458, 0.01597969490478957, 0.12200204535357415, 5.65106951421307, 48.25005215983237, 56.440953439281834, 38.55906786457185, 31.41976187306066, 23.399407209888583, 35.10558566739483, 52.02407044749106, 53.49279411377446, 30.09125509569722, 3.101889760263505, 0.06353018535000664, 0.08575635721846935, 0.21583473129618555, 1.0409722837709612, 7.605974395428935, 7.706201249553312, 6.671045595599759, 7.075828804123787, 18.089531929262225, 37.81341745007423, 55.603366590315304, 59.77970630891862, 60.9362877568891, 57.679508501483554, 52.595830425139404, 48.996188948231364, 53.263480586390344, 57.264164801566835, 61.35272187571372, 55.91734840023903, 54.967405257686494, 53.50829532069545, 53.77133730919131, 55.765297720509196, 54.805576109117084, 52.73336441286149, 49.83111643022107, 44.95774799777616, 42.405253841030984, 41.98581518665437, 47.735025344356416, 53.46974626664193, 56.013395478648526, 55.123950973633804, 55.03428951386483, 54.87548451269827, 55.926769933392926, 55.54174615490822, 57.60697210988691, 55.958399926462484, 57.197151107172814, 58.08622298702117, 53.39580958889377, 41.342601391576956, 43.603102545584406, 40.259917397652906, 52.49602571610482, 56.16579524932369, 58.796991763576386, 52.751379859062936, 57.23016961928337, 54.47041742263302, 57.382134006869414, 55.5980674682125, 61.31350994110108, 39.7714920966856, 21.915215676830663, 59.21113521822038, 49.05607569602228, 57.989822895296165, 54.40129741545647, 57.008332129447695, 55.20671298426967, 57.790915581487845, 54.98172190881545, 56.47369346311016, 55.09303877430578, 46.82731043907904, 40.031380499562914, 45.89213502022528, 54.61838491501347, 55.18736000983946, 51.45074152177381, 55.021988961004446, 56.21131435517342, 54.73216110660184, 51.1471422256962, 44.041607841368645, 40.31847838432559, 39.84091020399525, 38.485535190951445, 38.16536780326597, 39.308146430600075, 39.220838392934496, 40.03292591341081, 40.50920363395445, 40.185309994605284, 43.894719000785585, 44.12307546984765, 44.85312661816997, 48.1286822595904, 49.27252777161137, 51.44020211312079, 53.12879423941336, 54.00510664909117, 51.89287500996744, 55.01938058483986, 57.831939651120095, 57.634220815473995, 49.91929915643508, 37.2866980491146, 20.123629954553422, 7.191009694530118, 3.653406385452517, 8.344471877621066, 8.824368965241218, 6.836196011112583, 8.510738207447915, 0.5882215523912061, 0.0695103366348532, 0.1220978599702639, 0.09695253304896817, 8.581535027873132, 30.626211474018714, 48.16774122176632, 31.690477978798654, 32.32844168140043, 42.809591370244185, 44.359872879520545, 55.0322538037454, 32.78966142285255, 4.034637967425009, 0.0939995781969159, 0.03103707357490015, 0.0318332955676822, 0.031945439348477996, 0.01520632723000862, 0.01804615100545268, 0.04681815731249029, 0.006324449871411368, 0.05810703361226667, 0.018574761249305263, 0.01764037338415942, 0.03391042997639987, 0.049250804398569374, 0.01765678681793713, 0.016827471742045977, 0.08940041530877353, 0.03358863857424548, 0.04020981392973373, 0.04984640711618047, 0.03239705392550076, 0.048502183278962496, 0.04613589472888459, 0.06377386642740139, 0.03227880059350883, 0.055145992702173616, 0.0041657294927825855, 0.10536656099101228, 0.06054674785944724, 0.04804154993185113, 0.10553230411343037, 0.012719621149552687, 0.02450697266707017, 0.0831462650169288, 0.07183569693757642, 0.04089451267293865, 0.01962757673144581, 0.11082369638907333, 0.02394505483548968, 0.06539297410317006, 0.017122873330428716, 0.10020702776889648, 0.10613479396148075, 0.09331279569455693, 8.66976874489938, 56.21899435597082, 66.11488326903313, 45.21638124219833, 38.739375299023045, 25.751874216141243, 34.22977139872889, 54.70282570008309, 56.54013449145902, 36.17829507397067, 3.5216870663627504, 0.07486748223703715, 0.043511695018218416, 0.29242204261883614, 1.7990916678982398, 6.375278782459998, 11.050100268856173, 8.651271827759283, 7.169036576824804, 17.051345263758016, 36.953582917490316, 55.73695859601421, 63.264457641109345, 62.899653680862926, 60.10407455505864, 55.75976717856623, 50.280757334924516, 55.34406654296383, 58.35984753024194, 62.2280615375888, 55.24417554178546, 57.61003548099149, 54.627061197834635, 54.86871450178085, 58.21362941495834, 57.487818348792295, 55.67176488138015, 51.6070048270687, 45.71085876034152, 44.2942084804658, 43.43919061845349, 48.84964919859364, 55.15011710505332, 57.89091640903104, 56.16777212389054, 58.186792558239354, 56.557757700643236, 57.34594621965962, 58.20180739125898, 59.063144191618896, 58.05774657957016, 57.9830450396384, 59.53474644691714, 55.464769640276515, 43.63896869844006, 44.61329329398371, 42.23617223001296, 54.133987888213134, 58.23540249178487, 60.24609181188769, 55.388840398480816, 60.00870996905912, 55.6904314410302, 59.434957427363244, 58.83383458660495, 61.50159935797415, 40.681893825531006, 22.51210431898794, 59.71543435127505, 50.57696296322731, 58.10201837170509, 56.279391011884144, 57.83847824219735, 56.93572121281778, 59.98143380688083, 57.58510097380608, 58.82653897808444, 58.40751217257593, 50.01653863537697, 40.51377711757537, 47.948355213288345, 56.4118141512717, 56.44871580985285, 52.32187640282416, 55.37867753736435, 55.900972504769605, 55.762269650736165, 52.75153283149966, 45.72319461453346, 42.68949231793804, 41.252908552846606, 40.98477140549691, 39.69222099550309, 41.38949724935716, 40.029042766940215, 41.25314781742711, 42.80493159447947, 42.62803269970802, 44.298668215351725, 46.70340276533558, 46.50942194846369, 51.17946647828626, 53.290148781191924, 53.29150592127154, 55.76525849680747, 56.39509700959729, 54.966703153425655, 56.10082118741928, 59.931396130592596, 60.41949195246543, 53.177239433411636, 36.70998411793863, 24.036780595779422, 10.255057407963662, 7.251016074611295, 12.600283718878224, 12.808039899795288, 10.821692808981865, 6.0087200518577335, 2.7481699278277736, 0.2243354267651035, 0.17126552850729035, 0.041336407509422114, 10.336470123260252, 38.611564866958126, 53.88185401116648, 32.46626592451526, 41.33567840822282, 48.97105832253733, 50.664059192903586, 63.35899460700251, 40.371273486844956, 6.096660571713602, 0.026525629669307705, 0.04353172821743835, 0.021590920270330483, 0.022920316475774014, 0.07057309976869053, 0.04470637849261684, 0.06372970911944587, 0.03455562922622889, 0.05367690036373754, 0.07698602944372163, 0.07225612599042154, 0.0717719584222763, 0.030180667714786627, 0.005923865847439776, 0.03413953240059557, 0.0871032240590261, 0.04687330032128, 0.03353275246016922, 0.026295290013114293, 0.05655192109125276, 0.060146397971097505, 0.04706087694954007, 0.17992305749606702, 0.1592464823155634, 0.10226817966829385, 0.17295812316719564, 0.14703585285573237, 0.16413459824698587, 0.18415569327771666, 0.11177651058401793, 0.0723868588947, 0.14202632731006992, 0.20827473051125006, 0.15481926020114653, 0.10605650743649853, 0.08801977931251449, 0.16994156003479036, 0.176654972376362, 0.17961876737254281, 0.10227261531737544, 0.15623054737525602, 0.17856974785606708, 0.32767826691269875, 12.325230452322192, 66.13374986956197, 72.93730489669308, 53.75028594847649, 42.495903738083385, 33.85018010293284, 47.812347027563284, 61.27734568811233, 61.17326167321975, 38.74155613683885, 4.795744726734777, 0.2177252983974834, 0.13168122919817127, 0.5274538034873625, 1.652848057208523, 15.73962034717683, 18.99768025644364, 11.435590809391392, 11.641755488611038, 21.763535661082116, 40.68412957652923, 58.47757354859383, 64.56121675429806, 64.13282332881805, 63.39573937077677, 57.081017571110884, 53.827454659246634, 57.55498109325286, 61.7964086224956, 64.51937683166997, 56.80960916703748, 57.52480237714706, 54.02941749941919, 55.109916733157256, 59.98722322525517, 59.16329406922864, 58.4935454399355, 54.97333195901687, 49.26343571755194, 47.1110664644549, 45.0711750984192, 52.3427120331795, 59.168761853248846, 61.96413701580417, 58.71612033536358, 58.69470419422273, 57.64929056167603, 58.75209631458406, 59.92128426028837, 61.7929647814843, 58.775242220970895, 60.219784475141964, 61.38266917197936, 58.71403363443191, 44.81929617543375, 46.92167482068462, 43.419382649083296, 57.32711099809217, 62.715294438023726, 62.575583534856, 57.50868928047919, 61.31426303617416, 58.057228826707416, 61.595689173667665, 61.358436769054784, 62.38301869361632, 41.259686408504365, 26.25648517762461, 57.096707051800145, 52.00639624749461, 60.324684343030384, 59.134566630086596, 60.30333488218246, 58.745879357860936, 62.736263428964925, 59.71719549548242, 61.65503463437481, 60.924265692310954, 53.924023412889056, 43.54133306011077, 51.07372330081079, 58.57508367107761, 58.61537425748764, 53.55035881842337, 57.265463106093875, 58.335956373522365, 58.656829787838845, 55.90847207653908, 48.313441584187174, 43.604812698979536, 44.0420393020876, 42.829579768642304, 41.34573144297446, 42.87583235771426, 42.63895650063792, 44.86138712975287, 45.20199398840628, 43.46150105999362, 47.05235642771567, 48.661681375195904, 50.120983508325395, 52.24658650736655, 55.2720675160808, 55.74742347963395, 59.64137608005155, 58.628784841106786, 56.88817816395914, 60.70273806971889, 61.60694245369204, 64.12171125411987, 52.82821516836844, 40.83960840778966, 25.94586483893856, 9.297862783555063, 9.236595361463486, 19.289877222430324, 20.396570044179118, 16.865528860399802, 16.50358626919408, 2.724467044876468, 0.326851780616468, 0.3037364871030854, 0.25000243658019655, 11.903433472879472, 43.05990918990105, 59.90286480995917, 41.27636040410688, 43.72975980081866, 53.702366352081306, 59.22641285004155, 69.90181399929908, 49.34564075162334, 8.213070025367122, 0.2218374285486437, 0.1447282581319732, 0.09714535737950956, 0.1433014500165178, 0.12142256878676916, 0.14782401943399062, 0.1695201963546776, 0.14908952007610954, 0.19849258444962964, 0.19497260962042118, 0.14843036270430013, 0.21062773892716055, 0.1881024097242663, 0.08677120921352217, 0.12770007709942519, 0.1346001927290232, 0.17361227032398024, 0.10058359828807655, 0.07126218053482233, 0.13222521291144435, 0.09779918277936597, 0.15405435205226944], [0.04652333220527057, 0.05291717479966822, 0.030026860242228837, 0.04827859668782161, 0.048924493077661724, 0.005804141626633223, 0.055155492192434694, 0.08902258840539763, 0.04601225196834534, 0.13534090782125152, 0.0914161611768988, 0.054814426018105405, 0.03009670830872511, 0.041072758350280986, 0.00791973221273492, 0.03262028811619647, 0.04976004602447633, 0.0834522175512487, 0.040895539230757186, 0.06306961328992922, 0.08601165601923581, 11.795866393273878, 59.299651345899036, 49.12923182210615, 49.855042888272195, 29.760640475057787, 41.107055217989036, 57.79575186391031, 55.10903812223866, 42.175140150131725, 15.50911638044542, 1.094901318992338, 0.09308037994008872, 0.10739633392903114, 0.04869609545435637, 1.710887491222351, 7.368189529065163, 5.106546475041298, 11.980451172397984, 11.90517500523598, 25.178608048346735, 46.632874627267164, 58.66579240368259, 60.03486041099795, 56.08360982710316, 52.536214320890366, 50.74431088662917, 49.22837365058161, 52.041391634172015, 56.110011300733014, 57.72037567630891, 53.530754812302135, 54.283979323602495, 54.35233839096562, 54.80096340179444, 57.10725430519351, 56.34450627911476, 54.85895564479213, 53.0290287540805, 50.40954051479217, 46.79382516491798, 45.73721708789949, 48.40356980600665, 53.25669880836241, 54.10229905959099, 54.20468861056913, 53.80444211344565, 53.24322938919068, 56.00824932898245, 56.72380339714789, 57.166234985474624, 56.8971800035046, 57.278712872535955, 55.75908468615625, 47.35957607146233, 38.785066989160356, 43.08929950960221, 42.47961413475775, 52.807446218306026, 56.391260931568766, 49.52200228168119, 51.31754175309212, 58.87708656249508, 54.49996855951125, 60.39403969241727, 50.65371590275919, 58.68680846306586, 35.22916386204381, 24.5879618583187, 56.881412075411895, 52.086157644948656, 61.218623884262584, 52.766908522575136, 55.96638979450349, 49.33828630755025, 50.75243411525604, 50.76406786518713, 53.87202847388483, 47.08970915886664, 42.54017553021831, 40.5215512552569, 43.479822451068515, 52.86546984026509, 57.88221659198884, 51.88381433486939, 52.349658550754675, 55.0840251676498, 55.425545938553356, 52.15739180964809, 47.474752549202215, 41.90333558667091, 39.34777413645099, 40.74426343364101, 45.80777660492928, 46.02991219489805, 44.35451884423533, 39.32631877160842, 41.61256244105678, 41.32770815203267, 44.25082314398981, 43.644644368079405, 45.62799869045135, 44.66929297293387, 44.40067729642315, 45.5744348033782, 48.61924132993145, 49.55576212175431, 54.14646494773127, 55.89333957241428, 57.555424321082334, 58.70153304069274, 59.63229971547281, 38.843239661185976, 27.70495176315308, 15.702276441358752, 4.779413938522339, 10.865549810471075, 6.595036435511805, 9.163156824727213, 7.647341672451266, 0.38782517816270556, 0.17860215337526414, 0.07648843235426372, 0.06911579369296951, 1.8583646873312614, 27.95342803001404, 43.971950469478486, 33.30894793233564, 17.874111437028457, 31.767938906146636, 51.152002042339696, 51.070404975645005, 42.2522617924598, 11.606949356294448, 0.18982278273230602, 0.040008221722898946, 0.05623907376561434, 0.06926626102217744, 0.0363453217000971, 0.05166922140145495, 0.011342040886501632, 0.07693481646598348, 0.0622668297540757, 0.04616988221964529, 0.03531417501489482, 0.07640865195782916, 0.006544925666774714, 0.05887194942202299, 0.03377317766388578, 0.13335696992374238, 0.05970755982543192, 0.050627027728384545, 0.034644143025000254, 0.0028937561259109288, 0.016461490473199277, 0.06424840043989882, 0.10295451783965673, 0.03816514058158763, 0.08215548350445687, 0.022924091374020905, 0.02607190835049316, 0.015110894699671097, 0.04204372499859141, 0.03946169842815688, 0.044283785241385626, 0.054724613700302384, 0.025765436791604566, 0.012623134290709371, 0.0226572246455978, 0.0329415126132869, 0.00678215867787179, 0.04035773018615381, 0.04454171172373238, 0.11445290769540495, 0.03584500882894762, 0.0338863096981039, 0.18465867596528224, 15.676872230345204, 64.7139185474765, 56.1694783549155, 55.41530070766326, 39.3620397967677, 39.3983099537511, 50.77099869328161, 59.64754989070278, 53.24983466056086, 17.819502238304384, 1.498729552953474, 0.19566032675004777, 0.12856191835336148, 0.5627094149108857, 5.797644074886076, 7.2850377328934215, 9.959676457989602, 7.145388116759639, 9.561278377809833, 27.74492463757915, 46.02790394136983, 60.445026582287205, 60.263016839181226, 62.30133925714801, 53.140235793206, 53.4602149071232, 51.44971778315883, 55.76727067270587, 57.941809162016845, 59.28318131354548, 55.012167346092966, 54.59326605642996, 54.566750834065104, 56.28958132959182, 59.19729709625245, 59.76708412170411, 56.29382533411826, 56.432355603864124, 52.030534513535045, 48.15813533721432, 47.25601765417284, 51.0298712022843, 54.83082440591628, 57.17555453700405, 55.21083539532077, 56.1348085249624, 51.16466737562611, 55.60351564038185, 56.650125595831106, 58.80959433894004, 57.83674063221101, 58.36219702997516, 57.89084580636794, 50.49392246430921, 41.89688721010762, 43.917982578277595, 45.186834027690274, 55.82668673607611, 58.27770133172312, 52.94585489457654, 52.79406701364825, 60.29241892599291, 54.70965062418292, 62.51139786935622, 52.40648977218136, 58.57937474404612, 35.49611645360147, 25.40072991001991, 57.821721876821215, 52.524019672024636, 64.39559467377202, 55.64514375502064, 57.256374974404615, 50.56122641409598, 54.20624971389771, 52.915935054902114, 55.63642432612758, 49.15716694247339, 46.33479410602201, 41.055982035975305, 45.554575843195764, 54.57319921062839, 59.175661302381954, 51.26689218705701, 52.79101540965419, 56.17781731390185, 57.28152521194951, 55.02196542678341, 48.887382399651315, 42.884132092998875, 40.98806619644165, 41.468117237091064, 46.943808755567, 47.99764371687367, 46.736099643092004, 42.11581822364561, 43.20098115551857, 43.08296095940375, 45.23488698467132, 45.58196967647922, 47.62884286142165, 46.05317577239006, 46.22721525930589, 47.995117710482695, 50.12029317117507, 51.5719388377282, 55.15073291717037, 58.814414931881814, 58.59577809610675, 60.697882175445564, 58.7185404377599, 43.79973880706295, 25.83342617557895, 12.706588775880876, 7.295560471473202, 7.2187035891317555, 6.80187282062346, 13.68461020531193, 11.846161965400944, 2.7595107257366185, 0.3020351590408433, 0.03976062593621112, 0.031720293768411206, 2.9195662275437386, 27.781547807878066, 49.29447735509565, 37.72774111840033, 21.145148508010372, 38.0587891609438, 56.847338445724986, 58.7659618931432, 50.97171421973936, 16.62958456623939, 0.28487043815755075, 0.05120094249685926, 0.025912868497412533, 0.05643002501118088, 0.04202142034867599, 0.056977429307035865, 0.06968854400779932, 0.056469405760928515, 0.052701999853935935, 0.04827884566639701, 0.02290143815409993, 0.05104142383882596, 0.1262274186217016, 0.004256656947320387, 0.026319197702011275, 0.0766619053038378, 0.024411573653079333, 0.056426658054753664, 0.05063941153968054, 0.032457632328113245, 0.04534392452408229, 0.06781149835836503, 0.13321774110438364, 0.1991074159741402, 0.11304845402558004, 0.13029188278221315, 0.1449176963538893, 0.1330777615188591, 0.21386298951843094, 0.20349541438683388, 0.174830564628205, 0.17412280663847926, 0.16706462408746445, 0.09211920772589023, 0.0710301171807993, 0.168657903108866, 0.10312095044120666, 0.10762766183864687, 0.23103615269064906, 0.2943597854145112, 0.12952570292738178, 0.17254992087762203, 0.44685752341343515, 21.00000119978382, 76.19048733865061, 62.4011008201107, 63.07903151358328, 41.73820772478658, 52.084055254536295, 66.24489415076472, 62.89370736768169, 53.044886896687174, 22.25379663129007, 1.606470074865126, 0.27262893535437127, 0.2671849000598154, 0.9868629420957259, 5.524916283545956, 14.944463737549322, 15.504917483175955, 18.56841410360029, 15.793419576460316, 28.409685973198187, 50.701627654414025, 64.26151237180157, 62.98898566153742, 62.783598592204434, 55.3759083440227, 56.23664502174624, 54.6453433652078, 57.20454085257746, 59.66895818710328, 61.70557045167493, 55.832923304650095, 54.89853628220097, 56.783301830291755, 56.351990161403535, 61.16830379732194, 60.20752706835347, 60.01379336080244, 58.669824600219734, 54.53798417122134, 51.60108989284885, 51.12837368442167, 53.52785618074479, 57.3201487910363, 57.934788119408395, 57.012179974586736, 55.1680148801496, 52.291399586585264, 57.48966186277328, 57.69364472358458, 59.11587261384534, 58.724427915388546, 61.05505320333666, 59.74311843995125, 51.9805399833187, 43.45852398103283, 46.314676269408196, 46.739488570920884, 57.92504887427054, 61.37049805733466, 54.505652073890936, 53.96577312100319, 60.29602750655144, 57.19983400837068, 62.98023093131281, 52.04486293177451, 59.22483997960245, 37.67776620003485, 27.245655944270474, 56.19699770404447, 55.12809299653577, 64.52504465656897, 57.94036572979343, 60.120089592472205, 52.35075681440292, 54.62387231088454, 55.74210082331012, 56.84182359326271, 51.342691990637014, 47.54734385398127, 44.165382154526256, 47.34951911434051, 57.45713364693427, 61.59406139004616, 52.085035847079375, 52.76029148409444, 57.53997802734376, 58.26341605955555, 57.45992637449696, 50.79919269008022, 45.58198144358974, 42.75071659395772, 43.832463141410585, 50.59415471169257, 51.36111536333638, 49.51248268927298, 43.89928071729599, 46.010241508483894, 45.066617304278964, 48.73632800194525, 47.97495280542682, 52.95582948192474, 49.44075430593183, 50.595994303303385, 52.10897799461119, 53.339962882380334, 55.07652167351016, 60.06265040366881, 62.10898622389763, 62.952570376857636, 60.47462870997768, 60.694301051478234, 47.52016967342746, 29.64788998326948, 20.452406944767123, 11.967618157786708, 23.36144651136091, 12.77680116315042, 21.479607051418675, 16.85784297604715, 2.970256978465665, 0.49001965251180435, 0.10764574151365988, 0.22462002842897372, 3.4165413148941535, 35.90931461703393, 57.02172702358615, 42.06612963830271, 26.473001972321544, 44.97311584411129, 65.43335576211253, 64.85976403759372, 61.4645564940668, 22.52773496412462, 0.7437629577132964, 0.1580210940371598, 0.14355681776519746, 0.1912575734839324, 0.15809419414689466, 0.11749562506954517, 0.21229583409524735, 0.26111300974603624, 0.17977025359869006, 0.13718698053590714, 0.12320293414015925, 0.18238668900824365, 0.29682058240136794, 0.1401937683863986, 0.13693674557632016, 0.18967057638350995, 0.24009857446916644, 0.10255911687929785, 0.15682939830566608, 0.18883523411087452, 0.20208844794861733, 0.22916787874794778], [0.0038221792783588175, 0.07326188452181316, 0.01386134017769608, 0.04971993366076101, 0.02739210192474627, 0.014126165281800974, 0.049749807259368325, 0.046928631021611156, 0.03802752820774913, 0.041617412390487815, 0.07873202809282849, 0.09853884067025878, 0.02190471371455539, 0.06818091361633233, 0.08607959269636101, 0.06803129664472035, 0.026697737067156745, 0.07598589399769422, 0.08503243477354128, 0.10240366231770286, 0.21525074247150652, 23.955195296195246, 56.28205822360132, 53.3186448004938, 38.80776966771772, 24.154673314863636, 48.050278002215975, 58.96465739896221, 44.35476203118601, 30.28766189852069, 11.422709745745506, 0.21947276027452564, 0.06504918448626995, 0.04778982876169105, 0.6466095257670649, 3.817072919299526, 4.420610714343287, 9.715299067958709, 8.939030631895989, 14.643625790073028, 33.493248339622255, 52.56878960517145, 58.12333645359163, 55.013112637304495, 51.26734325962683, 51.25328548492924, 49.6755709186677, 50.00409687719038, 52.68273053630706, 55.74747839281636, 56.07771450473417, 55.70611307697912, 56.73557443003501, 54.00183539236746, 54.96654233624859, 50.555095749516646, 57.627125247832275, 54.60821420915666, 56.9280255225397, 52.434342522774976, 52.653469654821585, 47.69360511533676, 50.085446834564216, 53.76419075073735, 57.688043578978515, 54.475791069769095, 50.56444275763727, 53.23039539398686, 56.702116612465154, 54.74509316105997, 57.59556977979599, 54.447852027031686, 56.188525384472264, 51.0177275442308, 43.24676306016984, 39.18033207616499, 42.67171221394693, 41.74809601999099, 52.40414811718849, 52.893734439726806, 54.99686225768059, 55.98045933631159, 57.01326647112447, 54.3366567550167, 58.842118632408884, 49.698418724921446, 58.17747300670993, 32.92194727928408, 26.342273296848422, 58.26350627406951, 49.9392169521701, 58.24152531162385, 51.16565581290953, 51.47291468035791, 42.80502180899344, 44.010103364144605, 40.059849062273585, 45.358622074127204, 43.42214399768461, 44.073998774251635, 41.12813403529506, 41.87263127296202, 48.23655528406943, 58.10300288661834, 53.76827001571656, 53.459814825365626, 53.67605117059524, 56.65316151034448, 53.25610653046639, 47.50117755705311, 41.849422608652425, 43.29144277880269, 46.69749567585607, 52.35329066553424, 53.15434063634565, 54.95229628778274, 49.857462990668516, 46.607092888124534, 46.73061616959111, 50.55795907974244, 51.55270353440316, 52.76810876784786, 53.8138440347487, 55.53609401948991, 54.184084400053955, 55.38709494375414, 54.73720919701361, 56.43466195752544, 58.0126000988868, 59.41533380939115, 56.381796252342966, 54.47103715712025, 47.21094569852276, 33.23549370611868, 18.287038956919027, 8.415822732833124, 6.917144906136298, 11.839977368231743, 9.668242393001433, 4.619849958727437, 3.1030186674287243, 0.3134850785136223, 0.11587047679049355, 0.0021670817495173505, 0.41153823476164575, 14.153409927122055, 36.910848694462935, 34.673756245643865, 32.51608590925894, 25.553604287485925, 36.96133352095081, 49.82508382489605, 53.4409325353561, 25.51765380367156, 1.344962836273255, 0.13477680663908684, 0.030554323269414808, 0.04754937674489714, 0.0779757997201335, 0.03861168557177148, 0.0366946769457671, 0.0362202386942602, 0.04670816623876172, 0.031130861889030186, 0.015523148636754244, 0.021645006077784686, 0.032398337122773936, 0.06766520620834443, 0.034732116731785, 0.048463212386254347, 0.034701565145364696, 0.03872722695251146, 0.028843193112181562, 0.08371812666976645, 0.05034106625844875, 0.0978176225157034, 0.07097954005603829, 0.04692954266624105, 0.009743969985133698, 0.020454053451577504, 0.030267490374465144, 0.010767102433038096, 0.03759137903069777, 0.060822547173067454, 0.00981410054655205, 0.04241770231014779, 0.04299513342219495, 0.05542636556070178, 0.06804377621700687, 0.010989685448998166, 0.06639581383957018, 0.020265969290067593, 0.0030229135224926137, 0.05782982086642616, 0.02994511291504868, 0.14465200173999035, 0.30319394363510993, 29.453752271590698, 65.35301385387298, 59.924857539515344, 47.29764576881163, 27.446804892632272, 48.366981937039284, 61.865591387594904, 52.13973722150249, 37.002522330130304, 10.81429914120705, 0.233735264308991, 0.09380909043454355, 0.2581531524417862, 1.018473078166285, 6.105777630882879, 9.828863451557776, 5.988600254058839, 8.301818063182216, 16.186890179111113, 33.62916238846318, 53.32565015362155, 61.9190062246015, 57.80882120132447, 53.398794512594904, 52.79161160992038, 53.29978212233513, 52.423807036492136, 55.75697837337371, 56.92162813678865, 58.325522868864006, 56.04858698383455, 55.69631891865885, 53.06509494781495, 55.89556355630198, 52.35059207485568, 58.01324336759506, 57.47906754093786, 58.86713943173809, 55.761430263519294, 55.967986199163626, 48.9315325983109, 50.768766864653564, 54.94059585755872, 57.600386450367594, 55.080538180566606, 50.37573752864715, 54.298849028925744, 57.17730783647107, 57.67511152452039, 59.90792466748146, 56.42028254847373, 58.23163701641945, 53.19068139599216, 45.617859363555915, 40.45202332158243, 45.102612895350305, 43.64771558392433, 53.38674891379572, 55.07252477830457, 56.85111176583075, 56.56643790583457, 58.751762913119414, 56.88973926728772, 60.225063985393895, 50.66487504589943, 58.13252656690536, 34.316428322945875, 28.882113887417702, 57.07175685513405, 52.454511350201024, 61.13075887003253, 54.58209122380903, 54.09071630047214, 45.26639146189536, 46.35692019616404, 41.99708807852961, 47.90769984645229, 44.95986607766921, 45.16007954074491, 42.366351773661954, 44.560509958574855, 50.237991732935754, 59.288727544969134, 54.83218939073625, 52.64348330036287, 54.346854917464725, 58.15527239153462, 55.31531164723059, 50.61404505083638, 42.62706387427546, 45.24675607681275, 49.030364559542754, 54.761061130031464, 55.216711105838904, 57.1658702050486, 52.35862508896859, 48.89685884598763, 47.80438853848366, 51.71981219322451, 53.739558266055205, 56.80227825718542, 55.262367494644664, 55.70423033929641, 56.108010891945135, 56.72961634974326, 56.586779317548206, 58.67232707238967, 58.9089911214767, 61.21437203499579, 56.57991124737648, 56.36335719016291, 49.55611905743999, 33.60350616516606, 18.5816599476722, 11.799210213845777, 9.66167732592552, 13.223959207534792, 10.53044407598434, 8.939120846409953, 6.776001847559407, 0.9634109069743465, 0.1922942130195518, 0.03619495779275894, 0.33664082146940694, 17.152303149623258, 44.94068176515641, 42.02491729490219, 33.21665456218104, 30.960675900982274, 42.33148190283006, 55.9130024140881, 62.00743998250654, 32.774666201683786, 2.26337845767698, 0.12856948730205336, 0.025674347022187807, 0.06816976703703403, 0.07856894329550766, 0.019607216029638247, 0.026904996409411394, 0.028335215531349666, 0.053065056582131696, 0.017679252346316655, 0.0444473258610214, 0.056941913470866225, 0.07713413722212277, 0.03330954508255086, 0.04938537157290886, 0.042496218661507296, 0.07906536060956218, 0.05664729137694644, 0.029009380565595724, 0.12914431371515797, 0.02099363407450578, 0.07328744887584641, 0.14208444274000584, 0.08946878099513632, 0.09422254808727773, 0.12032217541409117, 0.061740301354157354, 0.12578712490897986, 0.21937105444169816, 0.1638343224241849, 0.12624683128970285, 0.10486268198057529, 0.1819002538198425, 0.35151781994969616, 0.2896546572446823, 0.15652584362654917, 0.22845189297391524, 0.1469836822680889, 0.11594073471402931, 0.19565957598388198, 0.11862896022296722, 0.18713500921524343, 0.9914882132603277, 39.49051703176191, 74.40605994193785, 67.5040691129623, 52.60422429730816, 33.64902527101579, 58.0382877011453, 65.64260636606525, 52.836581583945986, 39.801713958863296, 15.35735301433071, 0.3492660423921001, 0.18279795564951437, 0.4324362553175419, 2.070249530576891, 7.880751134887819, 15.130049701659912, 15.011669628081785, 13.540607248583148, 18.22921145346857, 35.64324848113522, 57.242501551105136, 62.4923586845398, 59.17301762488581, 55.88973099185575, 55.925004866815385, 54.849322303648925, 54.817841360645915, 58.552902667753166, 59.37939313150222, 60.84561824798585, 57.37803120766917, 56.71983788090368, 52.852753516166445, 55.430166490616344, 52.894664041457645, 59.63251544583229, 59.78724118201964, 61.94219135469007, 57.76676162596672, 58.19350373360419, 52.900441692721465, 54.43513178056287, 59.267923293575166, 59.29219099783129, 55.36312533963112, 51.90233968919324, 58.06068051245905, 59.49256920045423, 59.8696070332681, 61.93014967826105, 57.096958083491174, 60.91439700895741, 54.81562129912838, 46.39898761626213, 42.24175376276816, 46.632654974537516, 45.948166078136815, 55.518325682609316, 57.77698332263578, 58.78176904493763, 59.01111787365329, 60.008462859738266, 58.1649253445287, 62.23256049617645, 52.91446416608749, 56.86658551616054, 38.28811837780861, 31.773247834174867, 58.31569733158235, 53.01007586140787, 64.75991226011708, 56.61016841088572, 56.947358885119044, 46.76561155626851, 48.25861469391854, 43.0138409522272, 51.53164040657782, 46.76978103576168, 48.150365121902965, 44.56478534206268, 46.99408177406558, 52.4140638689841, 63.64870086792977, 56.05624737278108, 53.53076657941265, 54.17232905664752, 60.74270702177479, 57.38221245427286, 53.81683680319018, 46.10464903616136, 49.40247981779037, 52.213062009503766, 58.65986962472239, 58.35437582385156, 59.774313049931685, 55.44462826944167, 52.798911140811065, 50.84013046756868, 55.94174162034066, 57.497941986207046, 58.72380033616097, 58.30080801440824, 59.91899751847791, 58.983029780849336, 61.73054418256206, 59.65276664303195, 61.580034994309955, 62.02086233323621, 62.672564137366514, 56.69845311872421, 59.59409582999445, 51.2479785180861, 39.443887895153416, 21.342865382471395, 13.787099776729463, 15.333107863703082, 22.506452183569632, 17.800543462076497, 12.065669567354265, 10.827185107815652, 0.5850949330675987, 0.46891696390605747, 0.10203304430169445, 0.807245844794858, 19.52403683816233, 51.15948592462848, 45.74575608776462, 42.36088398964175, 36.68255106095345, 49.75954494168682, 64.37354310866326, 68.34526062011719, 41.22063136869862, 3.74386751844037, 0.33074635711889117, 0.10975377033314399, 0.14123969290766025, 0.17496743389675695, 0.12414009715881079, 0.14731002040207386, 0.10699745492949601, 0.2181219787246758, 0.22740653535771757, 0.19121358471532024, 0.1637221211867948, 0.09651277559779345, 0.12133466785833721, 0.12879654044105163, 0.18514143393164684, 0.13659980478546313, 0.20788207980653933, 0.07930562110437502, 0.25879537927046903, 0.11537314783180914, 0.19069014748017635], [0.04194725154628677, 0.03600403719070939, 0.057011137175704205, 0.07910632333087345, 0.046177209850641034, 0.02649568137712777, 0.017380583392936858, 0.03032339181029989, 0.09092959575355054, 0.029976993664017612, 0.05963645154430021, 0.05143846039690318, 0.0229400547311431, 0.0741735597952239, 0.07680897886354117, 0.09798624612871679, 0.052830319581252914, 0.018019115762604822, 0.08624717442979736, 0.07641937718876908, 3.8190475875331513, 35.93546505897276, 49.94839922074349, 49.272292429401034, 29.84680710300323, 27.263906732682262, 39.42102832178916, 46.30182658472369, 45.630787495643865, 34.30180572694348, 3.167886825338487, 0.032272396098461845, 0.04345438015016337, 0.2535338261194768, 0.5099129640767651, 9.857942923422783, 6.258859893968029, 8.136782376996933, 8.728769037031359, 18.56231677916742, 45.861230665637606, 50.449305503599106, 62.070594064651004, 53.62942987872709, 58.94108787659676, 50.3934274181243, 57.05216069375315, 50.39536506898942, 53.23054444405341, 53.43523725386589, 58.729460316319624, 53.501054625357355, 54.657922406350416, 51.99616670608521, 53.794008608787294, 50.86017770151938, 50.33968310202322, 49.770213788555516, 53.83105539506482, 54.752679024973226, 55.50846092162594, 49.09501306472286, 52.28610830922281, 51.00910225222188, 55.57431751681913, 51.20070219039918, 54.54352648027482, 52.78339424440938, 55.03738426393079, 50.16409820125949, 55.94387931208457, 52.40309692198231, 52.99097784103886, 41.20656574926069, 42.76910858769571, 41.468811496611565, 42.352243008152136, 39.401761639502745, 45.2623631877284, 50.050902520456624, 55.02250279149702, 52.225162521485366, 57.99336479556177, 52.25345457753828, 58.38269141412551, 49.545971885804214, 63.033296677374075, 30.78758170527797, 27.40034834031136, 58.18062659232848, 50.9754914622153, 59.781745941408225, 51.89389090384207, 51.74094592371295, 44.20994812442411, 47.563268676880874, 41.77413663556499, 42.781460131368334, 41.08508602265389, 43.8676977926685, 40.21409234692974, 42.19561492243121, 46.493081354325824, 54.78424233774985, 56.31129949323593, 51.65059412679365, 52.50995797495688, 57.143324421298125, 52.19285003600582, 48.16106534773304, 44.04540077332528, 50.15894420685307, 52.219122071419996, 55.06155783130277, 56.574321869880926, 56.4960313612415, 54.53318711250059, 52.794988770638746, 53.606884094976614, 53.15775702076574, 53.89449581023186, 57.367303525247884, 53.95836768611785, 54.043494885967625, 56.2767747909792, 58.279799799765314, 56.69499358823223, 58.313010508014315, 58.23653605676467, 55.81845368108442, 54.54123973846436, 49.68256058231477, 55.97111232819096, 41.094629149283136, 22.24571066517984, 18.277452684217884, 3.839677783750719, 5.370959331912379, 10.589729720546353, 14.05828852807322, 3.260667795135129, 0.4981163132094568, 0.14886441280043897, 0.05131353826953038, 0.06933438156040446, 5.029970532463444, 32.826049250941125, 36.5815382619058, 17.814167814870036, 16.153300962140484, 29.139625333970596, 44.95146828313028, 51.32178575761857, 41.16739696071994, 7.618243079031668, 0.05438361647388628, 0.12041813558748654, 0.033519054808083086, 0.04738067269265171, 0.04969053120622712, 0.01573110033097046, 0.010232973483300978, 0.031259401866625396, 0.02710189441249015, 0.01719015500237865, 0.02699332251664131, 0.02628769042090543, 0.03619267102030497, 0.07114994865391525, 0.017918480537651528, 0.06837249688443638, 0.018633631275846593, 0.012859917703955885, 0.018047574013772032, 0.04780734919251935, 0.03668675559663004, 0.027014280767029813, 0.05292077924335196, 0.08294900503730582, 0.05729309200579601, 0.026997218073736277, 0.060339559380325584, 0.025216124936818116, 0.02172015738793679, 0.08793134212253556, 0.07985433158014091, 0.06631020351403183, 0.019810053129349987, 0.06581312736436244, 0.0046796705893000536, 0.019961253987745415, 0.06422201254134698, 0.059714584851697575, 0.008803988720530705, 0.047331290665052594, 0.09709311784395287, 5.618838908210878, 43.232921015831735, 57.24634155150383, 55.579436209894, 34.73965990927912, 26.466826200485233, 43.89904537508565, 53.5744264818007, 49.107901973109094, 31.5056872752405, 4.5123642683029175, 0.039475989798384334, 0.2328331038475998, 0.6014495619362401, 2.495671025206966, 7.146309383453862, 10.560102097449764, 5.215107875485574, 8.210602854528736, 21.528264053406257, 44.07861540394445, 55.253326431397475, 61.75349789281046, 56.16439104080201, 59.96941566467286, 54.333271749557994, 58.324601111873505, 53.527671829346694, 54.28917646408082, 56.342148934641195, 59.83254847988006, 55.90117254564839, 54.550276879341375, 52.4983948276889, 55.08407615846204, 51.512110925489864, 53.73698911359234, 50.48280646724086, 55.488496057448856, 57.064951542885076, 57.93552552500079, 52.88265374399001, 53.82072387203094, 55.106143413051484, 57.22275241728752, 51.902382835265136, 54.1370669487984, 54.46349051690871, 56.3395131018854, 53.64948495741814, 58.6018773817247, 53.94503947227232, 54.40386656791934, 43.84094330572313, 45.11499974035448, 43.251481671487134, 44.154634860254106, 41.981955574404815, 49.10945523169733, 52.69050075161842, 57.63382857845676, 56.3239138357101, 59.9134159857227, 54.24119410976287, 60.56529821888093, 52.42112805766445, 62.29208246354134, 31.821696950543313, 29.453614988634666, 58.645556895963615, 53.235733739791385, 59.934796825532, 54.26104130283479, 53.18106374432964, 42.99147559750465, 48.82052952243436, 42.708433443500155, 44.76896824375276, 43.85713092742428, 45.412503673184304, 42.02377588518205, 43.598058377542806, 48.3004036257344, 58.00022502099314, 55.93986280502812, 52.26875182121031, 53.277204959623276, 59.34652366945821, 54.27448326541532, 50.07865328942576, 45.71325140614664, 51.79971087363459, 54.9687506306556, 58.014996667062086, 57.26132500556208, 58.19611210976878, 55.26177521674864, 54.51974514992007, 54.84212083201255, 56.242399138789025, 56.22701952534338, 59.52537198220531, 56.44952774047852, 57.060762451541045, 58.2762029863173, 62.50534957455051, 59.188997360967825, 58.04155111312867, 58.50668930238294, 56.729502601008264, 54.603385771474535, 52.28272722613428, 59.05558578429684, 40.858067081820586, 22.190420935230872, 13.191117202081989, 6.488477895336767, 8.691025049455705, 8.000981586594737, 11.440024068278651, 8.154189855821672, 3.0236612741024267, 0.25745432703725757, 0.07198094720802001, 0.09217032111219822, 6.397542155558064, 32.572691594400716, 38.73014988437776, 30.296524493925034, 21.443380040507165, 33.144333900943884, 48.97826371654388, 56.67042386147284, 47.67493071094636, 11.035859123353037, 0.17093857750296595, 0.1278289943753231, 0.0434432182491066, 0.05307146107717868, 0.008827033602902967, 0.09332199641052755, 0.03224611545221941, 0.019230333329629035, 0.02534139180375684, 0.04387374434079375, 0.037658331284840266, 0.0681246597800524, 0.013801399543280564, 0.02104555951401351, 0.0702334393657023, 0.12285315371569126, 0.04259310580129105, 0.053554207552224405, 0.005366307056148447, 0.014549878936621451, 0.007683794847839783, 0.1937571958067917, 0.1547114563084418, 0.2666266977546677, 0.12196893503348674, 0.135437817943673, 0.15419212530457205, 0.10765239881772189, 0.09384698114327847, 0.14663895802392116, 0.10852377786631547, 0.1491139429591356, 0.1389598765320355, 0.16621463421371677, 0.1215338966839256, 0.12917783772272448, 0.2208988789108492, 0.11049390319854983, 0.19052468781029025, 0.17256384835608546, 0.2200335826003744, 7.468989049234699, 53.98656168291646, 66.40302058189147, 64.51727836362778, 43.68265605741932, 40.70461219356906, 52.13903119487148, 54.96231402120283, 56.11660872736285, 45.26373601728871, 4.774200127970788, 0.293072788345237, 0.5132823413418186, 1.0626365148252057, 1.4114304631948473, 20.197421504605202, 15.022941539364478, 15.482263834245744, 12.520066345891646, 21.071323617812126, 51.120407350601695, 55.07295623902352, 65.68384616605698, 58.74874268808673, 62.71406673615979, 55.14493957642586, 62.809694120960856, 55.958113593439904, 58.218861856768214, 57.89358362074822, 62.01463753177274, 56.15884873174853, 55.65574199922624, 52.33777769150273, 54.37239739202685, 51.61605765742641, 54.114827109921364, 50.49487952263125, 56.64761920129099, 59.63718306633734, 61.51018150391118, 54.67532596280498, 57.93951849783621, 55.12002075872114, 58.91768309377856, 52.983054653290786, 55.49539550658196, 55.34175234456217, 60.450333549130356, 56.14405747382872, 61.95368389929495, 56.100342658258256, 57.72611410387101, 46.092713263727006, 46.653161125798384, 45.292126132595925, 46.39541433703515, 42.58526709771926, 49.98979199317194, 55.021169185638435, 59.501920130945024, 59.30255389982655, 60.939221689777995, 57.803835868835456, 62.51222548946258, 55.211486508769376, 63.271506140309, 32.93658948713733, 31.09984551706622, 56.31290374263641, 55.66136667805334, 63.24186871128698, 56.746400171710604, 56.75005974308137, 45.82526253115746, 51.19383412022745, 45.6356983030996, 47.549665897123276, 45.82009676964053, 48.01120335055936, 45.2183267378038, 45.44663221605363, 51.73071245993338, 61.53246448886011, 58.96490058591289, 51.97056147360033, 52.7393695615953, 61.24024006628222, 57.407578422177224, 51.21102586869271, 48.64499953485305, 55.696785680709354, 57.693503518258375, 59.73261825499996, 60.81390980751284, 60.50124983633719, 57.54455935570502, 57.30866801354193, 57.555424321082334, 60.363496195885446, 58.42189942636798, 63.973641780114946, 59.75958454993464, 60.0691693828952, 60.76762191710934, 64.31935164236253, 60.65657961753107, 61.93752765655518, 61.19621146109797, 58.90055802560622, 57.13176911877048, 53.59155939471338, 57.91625099797403, 45.04813509602701, 26.415074448431692, 25.33036062794347, 12.477258578423532, 11.964789148299925, 20.86400281998419, 22.660073772553478, 9.61045705503033, 4.0285149024378875, 0.3423630386110275, 0.22628415526161272, 0.23689099497372107, 7.37399414662392, 43.82677178229056, 50.11875167969735, 28.579259841672837, 25.00485489445348, 41.51458163415232, 57.57160409804314, 66.01051684348815, 55.9853034634744, 15.73877311521961, 0.5549565438301333, 0.256071339151071, 0.22637341982654988, 0.10735402289297312, 0.18273804757383563, 0.12000643227609897, 0.12919461504826624, 0.12245115673830434, 0.08030751089174902, 0.1587809919710121, 0.10543013096696909, 0.11539043843626015, 0.07829679822128627, 0.15705910210888233, 0.09844817416442019, 0.17783212775905288, 0.16117388292426066, 0.12825096326489605, 0.11478721314380247, 0.1667937966844728, 0.12068332458335547], [0.008655215403245342, 0.06712048705066405, 0.025412886959290313, 0.020517265281429695, 0.03803907698320766, 0.10031932093683751, 0.019351070701715448, 0.042846657921590155, 0.04400524716343611, 0.01881616513034509, 0.025295330767309474, 0.026671075292171973, 0.008800739550121851, 0.02833451647611876, 0.034414435391344374, 0.03685082481693357, 0.06911137336564642, 0.0805568878328608, 0.024915795487862442, 0.042957323152692094, 6.015493985145323, 41.21890944819297, 51.706707554478804, 43.890298489601385, 31.29376357601535, 31.296917161633893, 30.657135440457253, 30.93821837056068, 33.30801440823463, 21.83696831426313, 0.9434829988787252, 0.1141066206318717, 0.10152931084796306, 0.8583790268148146, 2.0142244787946826, 3.629595882469608, 9.667705028287827, 1.889214864180934, 8.634643920006292, 26.11489938151452, 40.07638577492007, 60.80215446410641, 59.44334345479166, 57.39383443709343, 58.06504611046084, 58.43351748681838, 54.68469258277647, 55.14687330492082, 54.734977368385564, 57.40446798263058, 56.48222854060512, 53.43987741777974, 57.34447925321518, 51.41338486825266, 51.95069074630738, 55.16226860784716, 52.4242934103935, 49.47187046850882, 50.67202944909373, 52.88572888220511, 56.94848852772867, 52.288418585254306, 52.20133804505872, 51.66561680455362, 56.0898385509368, 51.21605042488345, 53.01139377778577, 53.54210222921064, 52.42823539241668, 46.00035713564965, 46.38248228257703, 43.411577132440385, 42.260184980207875, 39.12620336778703, 42.17614819926601, 38.53862054886357, 41.5658744688957, 40.1700205956736, 42.32078559937016, 40.38376231347361, 45.966687510090495, 43.87738212462395, 47.847930769766535, 48.204156506446104, 55.49879620152136, 51.536892460238555, 61.05557487856958, 31.3030792051746, 27.127225860472652, 59.064717062057994, 47.31591224670411, 58.54497555763491, 53.04322381173411, 57.637252807617195, 52.2187533686238, 54.22884256609025, 50.828488872897246, 51.33647895628407, 39.79862313116751, 41.65704211881084, 41.562512997658025, 43.73416462252217, 42.706687988773474, 51.0244151853746, 56.74842411471952, 52.82054693468156, 49.91680060663531, 56.23455832081457, 54.51980006310248, 51.00599573504541, 48.79346909061555, 53.77772685020201, 52.05566906159925, 56.29991677499587, 53.90062647481119, 56.82695781030963, 56.38997439415225, 54.98760546407392, 53.21945590357627, 56.47316002076673, 54.82234424160373, 56.66980020461544, 56.840372316298954, 55.54318566476145, 54.00944871287192, 54.5678137963818, 53.17830239572833, 53.01786568857009, 50.95097664863833, 57.89063007600846, 58.92875202240483, 66.96147195754513, 57.26927564990137, 46.03699599542926, 35.34174373072963, 17.899677445811612, 16.33832896909406, 14.718434214591982, 7.32669085264206, 5.524500022011419, 7.313727909518827, 2.5311317030460607, 0.5312543963232349, 0.04220281847782674, 0.052482956164186044, 1.62431882033425, 28.587386992669877, 48.403510970454064, 20.697457021282567, 24.649729382607248, 37.33593948425786, 42.24399735850673, 52.820594003123624, 45.31860605362923, 18.97476969226714, 1.51249842057305, 0.03425412383230944, 0.04300474016476543, 0.0975417695759285, 0.01770343391164657, 0.01771426256445627, 0.012784334511736469, 0.027949518989771608, 0.008135649784948797, 0.041145326028908455, 0.02409054642362941, 0.012567975002551272, 0.06218859302480856, 0.009248445163510982, 0.04310711632452665, 0.04019266888198834, 0.06353807988606634, 0.09878650923529941, 0.018414514807743892, 0.03364007371748167, 0.029702904641688354, 0.03045267106274203, 0.15502098647336807, 0.08042211764522138, 0.07278094218382913, 0.03526215764483617, 0.03505694567255917, 0.007989864210568128, 0.04307814287923036, 0.02853936455663174, 0.013616927486333637, 0.06409130261970625, 0.005453245586625511, 0.019749572402947856, 0.07922996992185231, 0.021354139729913686, 0.051234658026406844, 0.013221519822705419, 0.07881533249371475, 0.05508635275726838, 0.01334085046584087, 8.472851053360971, 48.74023860500705, 60.25221463172667, 52.49192683927475, 37.887259990938254, 37.079357639435806, 37.19867221770748, 42.29224643399639, 41.825029388550796, 22.771512231519146, 1.453170733105752, 0.09219264491431176, 0.10315788354003623, 1.3551736238502687, 3.9844853166610967, 9.870640616263113, 12.082563215686429, 6.701161553782802, 9.526602664301473, 24.117195067867158, 42.817349818445024, 64.3454550158593, 62.208688951307735, 60.324794169395204, 61.67797657751269, 61.211602841654134, 57.92977925269835, 57.09887220013527, 58.01605178463844, 57.997396992098906, 57.83643860970774, 54.300645474464666, 55.52168323147682, 53.32933325921336, 51.37769129968459, 55.199166344058135, 51.979708440842174, 50.4000719131962, 51.25385030623406, 55.40414156452302, 59.85652592874343, 54.402321154071444, 54.54552296669253, 53.542451320155976, 57.38941000353906, 51.9069916202176, 56.42724475552959, 55.012736089767955, 54.36326611426569, 48.31617547619728, 48.747020383034986, 46.628787517547615, 43.863520468434984, 41.363605683849705, 43.818950576166955, 39.87392479373563, 42.13501430326893, 42.12618112564087, 44.45157789414929, 43.330705704227576, 46.9488529236086, 45.945632227005504, 49.9056806871968, 49.0905729416878, 57.862247805441584, 53.27711866747949, 63.315016992630504, 32.30351501895536, 30.520054486490068, 58.362750084169456, 48.61884124817387, 61.965392174259314, 54.93510453931747, 58.447296773233724, 53.90916155230615, 56.27893209457398, 52.65878446640507, 51.34325681194183, 42.758565256672526, 42.59439837548041, 43.2575652676244, 44.90102268034413, 45.422325288095784, 54.27576980283184, 59.38029135427168, 52.92068504518079, 50.89758534585276, 56.7220736319019, 56.58663026748165, 54.058270454406745, 51.116398688285585, 54.264685184724875, 54.4796859833502, 58.55447161582209, 56.3991331285046, 57.445099815245605, 58.46573583541378, 57.3394468522841, 55.880646782536665, 57.97125439490042, 56.062566311128684, 56.845506698854514, 56.28378798884731, 55.42918197570309, 54.14526470245854, 55.91364960516653, 54.08128300020772, 54.68952886519894, 51.909486247647195, 58.965951781119074, 58.26700895063339, 66.19646072387695, 57.54204119405439, 49.41551777624315, 33.09053467166039, 16.626227017371885, 10.221391704774673, 7.46762945767372, 13.422040862421836, 13.789928786216246, 10.324455903422448, 5.1234592449280525, 0.36093512429825725, 0.16190822416495892, 0.0032685052710510194, 1.7335249603756013, 28.94712913420893, 43.62286344651253, 22.91038178628491, 26.557993850400372, 42.23201844000047, 47.641535651299264, 57.9813584204643, 53.3439205538842, 23.695575575674734, 1.8595751062516246, 0.02874857359265368, 0.06035393118978508, 0.07826155817676937, 0.058803066626311316, 0.02046598527099817, 0.010142537761449574, 0.00990835138626637, 0.04758149881156222, 0.04582964725071385, 0.056706866204378106, 0.0767923930599805, 0.01630245636577808, 0.019062646259103092, 0.008790021980061166, 0.033158016721567804, 0.046657761483783686, 0.09607171579714745, 0.008472058144698461, 0.05571640644883437, 0.03557543781015181, 0.129506841842686, 0.22250056957765935, 0.34129967792860927, 0.1575365434250524, 0.17339954302916605, 0.19789169572534102, 0.06946096226813332, 0.19955465810433512, 0.24034789012324428, 0.11155562445281014, 0.12834569769761256, 0.09128554318580898, 0.07984654046595097, 0.16172750402362118, 0.12949772539638704, 0.12023334751927084, 0.10314614707303625, 0.21651255056983043, 0.1269151587339659, 0.1340616788835295, 12.455625726330666, 57.52921896596109, 68.3709050763038, 58.584799381994436, 45.20224109772713, 44.187312126159675, 41.69333188764511, 39.231291509443714, 46.353821523727916, 27.394286317210046, 1.9205509246357026, 0.2625760844638271, 0.2884225120707866, 1.935726084536122, 5.792630795509585, 8.376183259871699, 22.67928161928731, 7.430466961476111, 10.795243286317396, 29.110050662871334, 43.25786729012766, 66.62763903217932, 62.31110595887708, 62.76157056131671, 64.651082177316, 64.8637060196169, 58.880836348379816, 59.97499719742806, 59.8132033501902, 60.464885542469645, 57.60158669564032, 54.49690518840667, 56.274829295373735, 51.85158421916347, 52.1174071681115, 57.25544929504395, 53.021195780846384, 49.129702506526826, 50.230586298050426, 55.006836845028786, 61.50152483294087, 56.78609848022462, 57.630855421866144, 56.188290042261926, 58.227079222279215, 52.24195026582288, 55.09145805912634, 57.77624983941355, 56.66372053084835, 50.641721294772246, 50.7194979729191, 47.79242530945809, 45.0618084784477, 43.472013012055434, 46.08001262910905, 41.48817623815229, 44.51705794180594, 44.87007125731438, 46.61409431888212, 46.83071897875878, 48.3494685542199, 48.39419141892464, 50.36102079576062, 51.88493613273867, 59.865449320885446, 55.62730481547695, 63.050229549407966, 33.41365560408562, 33.62971544265747, 57.71633563503143, 49.69096229922388, 63.47760315864318, 59.1803014662958, 61.06842848562426, 57.91046550196987, 59.4598723226978, 55.59687899005029, 55.81490393607847, 43.52736157755698, 45.45839148183023, 46.39830512385215, 46.96025133132935, 46.716966321391446, 56.08553963322794, 63.49877611283333, 52.80723441031672, 51.089032311593336, 59.228558386525805, 60.19431260324294, 56.11630278248941, 53.4609523127156, 57.62113186620898, 57.54993692521126, 60.9547072072183, 56.45363053967876, 58.95261964490337, 61.40498745825983, 59.59067944557437, 58.543045751510135, 60.691280826445556, 58.53391447374898, 57.78803656178137, 57.86496208560083, 56.27522937713131, 55.15770689133675, 56.14888198914067, 54.684982838169226, 54.13296022722798, 52.914079773810606, 60.396820652869444, 60.8674148590334, 67.31122970581055, 60.8443630895307, 49.999217448696015, 38.26950280897079, 23.308892634607133, 22.60301309247171, 22.285544295464796, 17.23542994068515, 17.094128516412553, 18.418783526266775, 6.084863062827818, 1.2654709791944874, 0.24102083707769073, 0.15333574625753588, 2.6003198614043574, 36.248481965834095, 62.03464161965155, 28.889213377429595, 35.335824874139604, 49.60727853159751, 55.53801990324452, 65.27452330435476, 61.47266403321297, 27.792634387170118, 3.058740991738535, 0.1475688202246543, 0.13352981468121852, 0.2142832959972082, 0.13384101491781975, 0.15841342298494232, 0.1517950668330154, 0.12200279611973994, 0.10639491911617019, 0.09028859466554658, 0.14401371260323834, 0.18848969781350708, 0.1597031320054685, 0.11144857132627119, 0.08800494785030043, 0.09618044665624058, 0.14905697666108608, 0.23075152038326188, 0.10738853515396196, 0.1889220625162125, 0.11821706538959859], [0.03865013552469112, 0.017723702682903218, 0.10178797277471713, 0.03036394084413206, 0.08872977427897916, 0.04414467133521553, 0.08752853309194888, 0.026398943624489253, 0.06622353598715798, 0.03178282761045041, 0.046442467794423146, 0.022436382564445658, 0.016782699648531216, 0.005334657091166704, 0.024343428216994773, 0.06451872988573967, 0.04819953641403587, 0.017997487185282574, 0.02297201783456389, 0.36513150879932993, 10.636450052261354, 49.318662689578154, 50.84069921124367, 44.13230088449294, 23.954573600522934, 23.915263606655984, 32.65788155217325, 32.65869348279892, 37.0300377568891, 10.215686617359038, 0.10748954384677833, 0.03945251303394476, 0.13455864012001023, 0.6948184582494921, 3.334991316641531, 7.175067711261011, 6.939925541800838, 4.004995390292137, 9.370642362102386, 29.0640785232667, 40.38666486740112, 55.354143111936516, 56.565531838324766, 57.46614333122008, 57.980781832048976, 55.2065953131645, 57.924876289982954, 58.12493678062194, 56.768789060654186, 55.33556284443025, 53.36241452924667, 57.72399210160779, 52.02537659675845, 50.71279464229461, 58.99059603291174, 55.53907502082087, 56.442612601864724, 53.166048911310014, 52.03447257318805, 50.82924981271067, 55.99397582392539, 55.323411341636415, 56.22937294744677, 53.14561336271225, 54.57661559504848, 50.98012770375898, 53.961521271736395, 53.31809566866968, 51.82259398121988, 42.51531554806618, 40.25489676383234, 39.1095450616652, 40.73590094043363, 39.13300083529565, 42.47725286791402, 41.407226362536036, 43.939661518219985, 44.22180544945502, 45.290023742183564, 43.27112097893992, 45.476571667578916, 42.71595262712048, 47.90633093926215, 46.938176231999556, 56.56174282873831, 50.923159199376265, 61.97573546440371, 26.021039024476085, 28.646555946719264, 58.44092292170371, 47.99709458504954, 55.93241030170072, 54.23060371029762, 56.24213633998748, 53.099670640883915, 57.357744709137954, 54.6543687389743, 57.391653599277625, 51.25476814085438, 44.574775618891564, 38.19721352669501, 41.259576582139545, 38.92559374532392, 48.79005662856564, 55.629505265143614, 54.855099954912745, 50.30289519217707, 56.17631504612585, 55.9836599903722, 53.018195167664565, 51.5238937254875, 53.48043472536149, 56.291354240909705, 54.7923969453381, 51.68666424289827, 51.37463577332036, 53.15174402729158, 53.93931673419092, 58.316379823992335, 52.473887858852265, 52.298224510685095, 53.07379476485714, 50.21792488713419, 49.28509504564347, 52.490930557250984, 50.77479554760841, 52.16299687662433, 51.59796768619169, 55.24186918812414, 52.02262309289748, 55.68288872318884, 57.86516997121996, 67.91894605082851, 55.65147446047876, 38.25848487115676, 20.360437170151744, 8.252666842552925, 6.128098368644715, 5.067044775332175, 8.605236930231895, 8.495837123163286, 4.145383392610858, 0.24511802851432757, 0.1776463361156564, 0.06407508453834923, 0.5407475127327828, 11.766446655796422, 40.64350166628438, 46.401466554211034, 25.267216351724443, 28.921198344999745, 40.38557052612305, 47.31635547453358, 51.338553890105224, 27.149899121253725, 3.2463724718939875, 0.1612156806814094, 0.05065190643372555, 0.052778685255156416, 0.026825765681062496, 0.01312089991951061, 0.02405318431556225, 0.041666154734670155, 0.035889610467899236, 0.06485490458867242, 0.02257587376891846, 0.07197452739121453, 0.03850021594834905, 0.026660543498432925, 0.05545268451134044, 0.022320211076387958, 0.031748462821387, 0.06251896078127527, 0.050641372724766695, 0.0732507226207564, 0.020899612103558837, 0.04217001459290905, 0.02764265481082182, 0.04621483242860244, 0.04265697455153831, 0.06759700906132499, 0.04568885178154996, 0.07893198470194494, 0.04717145791097034, 0.029140622918343836, 0.07649366473478657, 0.0562888733111322, 0.05513107697028787, 0.05799309335528843, 0.04346640773057457, 0.07376522727070317, 0.019290362064155842, 0.03603044424145933, 0.004893740453201557, 0.04160371473840168, 0.2881710207270038, 13.742787780300265, 56.311283803755245, 56.84473006956039, 48.09007829235446, 29.391694491909398, 29.418770613208896, 38.644293123675936, 35.02374933611962, 37.49308532284152, 12.009671849589195, 0.11244997081737365, 0.0812595360161316, 0.2946182634801634, 2.226555491647413, 9.839735281082893, 7.088783902506675, 10.942547898138724, 5.550216061453666, 10.694482499553311, 30.007455618150775, 43.405156212468306, 57.12825859746626, 58.54330070557133, 60.14065850165583, 58.64380359649659, 57.276214322736195, 59.774042406389796, 59.45587150512203, 58.03552635254399, 56.00602142272457, 52.770976020443825, 56.974489919600956, 52.81658926317769, 51.924348108230106, 59.133927283748505, 56.72662358130179, 57.93943220569242, 53.024918110139915, 52.49800259067167, 49.746824695217995, 57.31906229449857, 58.384036787094615, 57.88895914631506, 55.24497178293044, 54.06805676798667, 51.582517470082934, 53.5655423133604, 55.424890902734575, 54.9215135266704, 44.78012346452282, 41.02887061334426, 39.822094594278646, 42.66001962846325, 40.91071313427341, 42.44568955513739, 43.025902240507065, 45.40406273257348, 45.932209876275834, 48.63464055522796, 44.35289890535417, 47.981675747902166, 42.71783536480319, 50.30089870575936, 49.811147643673806, 58.34158497471964, 52.49399000598539, 62.27455339124126, 27.34510567880446, 30.949204929413337, 58.31314386860017, 48.71904603896603, 56.90054539711245, 56.07337244095341, 59.13362918361541, 55.684002676317775, 59.582163979930264, 56.54306057960757, 58.90798699471259, 54.21497698753111, 46.596698607167895, 40.169141984754994, 42.67879209210796, 41.10373689282326, 50.16847164400163, 55.79349563967798, 56.67415011313654, 51.060877538496456, 56.51328586762952, 56.596749982526234, 55.04726079202468, 54.28616800615865, 56.410551148076216, 57.52310399086245, 55.90175697880407, 52.581780495182166, 52.285943569675574, 54.6037740861216, 57.098326990681315, 58.86209134132632, 55.135537655122825, 53.04650683556834, 52.532593973221324, 51.823786381752264, 51.167067866171564, 51.3153491481658, 52.14984516943655, 52.14992753921017, 51.931451520612164, 54.26269654304751, 54.83630395704701, 57.77065653954783, 60.12705179952807, 65.98708460407873, 55.936756287851644, 39.793516205203154, 22.097209730455955, 10.81470706770497, 8.177803504851557, 9.779602404563658, 9.502549709812287, 7.468292338232841, 7.67740713011834, 1.3246199536708094, 0.37311635130355436, 0.08981502975427336, 0.19498457591379845, 15.11599781051759, 42.48319918109525, 37.62696758393319, 28.624029774819654, 37.53657656331217, 45.7043868495572, 52.86579931935957, 57.9405540035617, 33.802123223581624, 4.140504454412769, 0.19816175704040837, 0.02075654326847965, 0.0430025338315435, 0.008839554352415426, 0.06347740189202371, 0.03287987317889929, 0.07181112849784475, 0.013004373158178022, 0.050246216912543586, 0.02917862662504758, 0.027902532902155674, 0.029479369761482365, 0.01979055810689686, 0.00494004663778469, 0.04230543978572373, 0.022778781731763197, 0.031063478710430286, 0.044313666500872186, 0.014785210613251455, 0.007596487637549158, 0.13617145438348094, 0.1768269131500875, 0.17443379237046167, 0.11185685022463722, 0.20656030234550277, 0.14463283422012485, 0.17110567660101, 0.13163982980674313, 0.13373074422199882, 0.14877490308736602, 0.25714090514567595, 0.1977011083715385, 0.15177617510480268, 0.1525570944912972, 0.1662455994876162, 0.21099389831144966, 0.11494397771574798, 0.1608837960708526, 0.15839912778427526, 0.6729084661891384, 20.54044650446984, 66.35638360054263, 62.803990994730306, 55.793323055390395, 34.779660240296394, 35.25000341476933, 41.90538306390086, 41.980637658026914, 48.832775162112334, 14.599436367711714, 0.34724559274411976, 0.17399824074199124, 0.3718298751740687, 1.9684224719962768, 10.872546338265943, 19.43840365256033, 14.797675897998197, 12.129606162348102, 13.556779180803607, 31.42765368184736, 42.76264452165173, 59.44057426145, 58.62481148012223, 60.11961498568135, 58.40424876059256, 56.84537726063883, 61.13095891091132, 59.88690860809819, 60.19096682148596, 56.28717691667619, 53.321719938708895, 56.815877114572835, 51.97042811301447, 53.58209863785775, 61.42978468248921, 59.496499415366884, 59.5075055860704, 54.85255825904108, 53.40659610686764, 50.36064424822408, 57.98803037212741, 59.845786479211625, 60.06488615466703, 57.165948652452045, 55.251988903168716, 52.52154857881608, 54.83259339486399, 57.24937354364703, 57.25408823259416, 47.012469845433394, 44.503337490943174, 42.95813152866979, 44.08174937771213, 42.791140540953606, 45.50229457116897, 45.54295386037519, 48.81062553774927, 47.861961087872906, 50.22538131283176, 47.79149963009743, 50.61473931035688, 45.58970066808885, 51.664451860612445, 52.63170834510557, 62.43358981224799, 55.88513789638397, 64.35063646685693, 28.23481494380582, 33.171790492150095, 57.13067085512223, 48.498495086546875, 56.44818236750942, 58.24297266621744, 60.12490626304381, 56.64264955828267, 61.2191887055674, 58.45609072716006, 62.31578142412248, 57.5604449549029, 48.73266058583414, 41.95620521422356, 45.537313492067405, 42.68813910022859, 51.889070310900294, 59.83113642661803, 57.52510439965033, 51.203541986403934, 58.74383188063099, 60.18987248020788, 57.281760554159845, 57.415313336157034, 59.134531328755045, 60.255568258224, 56.66179856946392, 52.97778691014936, 51.187479880548295, 54.83770032082835, 56.41702698123071, 60.47432276510424, 55.9938895317816, 53.49359427728961, 52.964784253028135, 51.623984767544655, 49.94460236641669, 51.65718370868314, 52.98624354024088, 53.731038878040934, 51.501414622029955, 54.30992187992219, 56.29948923664709, 62.14105944479666, 60.18825254132671, 68.19333937860304, 56.92412276421824, 42.832447021238266, 22.588984735550422, 13.634074388011811, 11.472880782619601, 12.817480064207508, 17.96873861743558, 15.585428053332915, 13.973390786878525, 1.5554336650717644, 0.5522100266910369, 0.2054571357345389, 0.7111461821102327, 17.711407599910615, 55.18348470810921, 63.473100277685354, 35.43750055374638, 40.91110537129064, 53.15224216830347, 60.34770865594188, 65.13600872408959, 42.417389654344134, 5.586943174562147, 0.30945573182355973, 0.19469297220630033, 0.11436848480614925, 0.20758534330994854, 0.18160866543410287, 0.11012088732733843, 0.18214745507124933, 0.15093232925620773, 0.1600727847506923, 0.11094248598261226, 0.187135438224481, 0.13260477883440833, 0.20021016889762497, 0.14047381948799859, 0.12157787779165853, 0.19655681816079926, 0.18068091763604074, 0.2290045028372157, 0.11656780066269061, 0.11347848216011641], [0.10329252349272852, 0.04240518443346505, 0.044340016095027815, 0.035650395683103034, 0.10102899414637398, 0.13394930910679603, 0.03447107993246567, 0.044622453560511914, 0.02089718552005868, 0.0035448013448096333, 0.025923641608847726, 0.04285506573655913, 0.042531830258667476, 0.04261868547708277, 0.006723274287181877, 0.02907016198150814, 0.08095963557641353, 0.019284516813293583, 0.134392261144615, 1.1430936426885667, 16.35611593723297, 51.654755761546475, 52.03682207292127, 46.383580546225275, 25.422395121666696, 16.647902034944106, 27.4912473078697, 36.898724648260306, 39.84952372889365, 4.914276301860809, 0.13666087731478677, 0.1322109943195697, 0.650709628337814, 4.444341053885799, 6.211460501916948, 10.891113858069144, 7.4869505628462765, 6.144041332506365, 11.6597758377752, 24.822448991960098, 43.08522808936335, 52.5880798216789, 55.29720990888534, 52.09099392737112, 54.16429212016445, 53.95767734896753, 52.432632369379846, 54.09900034627607, 54.59520762966525, 57.969924711412006, 58.55096109451787, 49.79863528282412, 50.38953250454318, 55.34461959715813, 50.622042763617735, 52.69084199782341, 54.13261898102299, 54.30135150109568, 54.52892349612329, 51.560622799781065, 53.708057711201334, 53.54109418007636, 54.922831443048295, 52.27631807327271, 52.915789927205736, 50.758337282365375, 52.67312072938489, 52.96088149470668, 52.24653551655432, 43.14582870852563, 40.892517259044034, 39.61886875091061, 37.73775100708008, 38.77407650793753, 42.49053009094731, 43.39066697705177, 52.14086686411212, 50.83996180565127, 57.46167182922364, 51.943253932460664, 55.5521051345333, 50.94406151002454, 54.499909723958666, 50.81380744134226, 58.075577674373505, 51.4548796223056, 63.35882986745527, 25.42750793118631, 28.213010488017915, 54.453594376963956, 45.11081849375079, 52.55515152408231, 47.53956579392957, 53.89740620889972, 49.940848658161784, 54.45326097549931, 53.32596394323534, 55.2057167022459, 54.68576338983352, 51.40531263043804, 39.999201374669234, 41.53214208541378, 38.97931452720396, 44.04040759609592, 54.25587161894768, 56.99864779749225, 50.806527522302446, 52.64463255482336, 54.48932716923376, 54.15561191497311, 54.29810377859301, 55.23285950383833, 52.02048540115357, 50.9065479616965, 52.89329905663767, 53.450330534288966, 52.153018366905954, 51.58346668366463, 52.74320563962383, 50.32956730934882, 52.46553713275541, 51.74797481106174, 50.25073159125544, 54.556976287595695, 52.774843477433734, 52.51302526843164, 53.24032291289299, 54.72978415027742, 52.62128268518756, 48.030654384243874, 43.815098808657744, 48.79022921285322, 42.85361605305826, 57.03512191772462, 48.30757764077956, 31.092524413139593, 13.74434005829596, 11.397484983167342, 15.737450295878997, 11.62117677350198, 7.120038818928504, 7.140343948718041, 0.6047384080386932, 0.08616525664805405, 0.07312670830757388, 0.07358868996943198, 6.6502619366492, 33.50394464308216, 37.15449848482686, 20.3164928959262, 23.631548766166937, 36.44987998470184, 43.27355677081693, 46.38430618470716, 37.49537598702216, 5.635405038633655, 0.7428924366831781, 0.08590703139141684, 0.04971601129058869, 0.07858882327714274, 0.06027492454215404, 0.029277509423874082, 0.052989278995101495, 0.03346960383257078, 0.02697512792843965, 0.019755463619085572, 0.024526117204297936, 0.03156358856827982, 0.0184903287839505, 0.07084912124780879, 0.058508727984923514, 0.027872105805023063, 0.052054513831652945, 0.08969033362283822, 0.016795861039070353, 0.019025107950813348, 0.05958160730980097, 0.030934448436563535, 0.022807678568267056, 0.04029121077168853, 0.037808132117554065, 0.07044853387220253, 0.03492441629209826, 0.03407924894183394, 0.012689847142375525, 0.01864803564404288, 0.004681066784542054, 0.02069129555996868, 0.052371057531526016, 0.05939624850608169, 0.07820913478011086, 0.04761442910098741, 0.07027632496770352, 0.01267857607378955, 0.09470192760589624, 1.1157045897937592, 20.982876131611487, 58.09296161897721, 58.39887903582666, 51.13796387949298, 32.593656662971746, 25.83874490953261, 35.901226689738614, 39.55451442349342, 39.52854441058251, 6.8254541100994235, 0.23519184260118395, 0.12976220959136564, 0.5697066168631277, 3.301431517447195, 8.501300984813321, 14.407024498908752, 13.668518681680004, 9.057330296885583, 13.21527704115837, 26.530933418581565, 44.02542806440785, 55.63616544969621, 58.26160784690612, 54.775589589149725, 54.99033151134368, 52.419708159662065, 53.009138414936686, 56.22093985157629, 55.23319682767315, 56.17154152162614, 57.81186888294836, 51.99476641993369, 50.49151020665323, 56.5761810733426, 53.57861949551491, 55.556407974612334, 57.06024862104847, 56.38194530240951, 56.10678711245137, 51.36526523097869, 53.6673709654039, 55.786960970970895, 56.24448191735053, 53.507102920163064, 53.63946722399805, 51.607726543180405, 53.526455894593276, 56.184512799785985, 54.72930954348657, 45.86175626324069, 41.51631924413866, 42.27543123306767, 39.983672711157034, 41.427461870255016, 42.831933190745694, 44.62466816748343, 54.40264671079574, 52.75023060460245, 57.706388504274436, 54.50192974459741, 57.75556325912476, 53.17188539812642, 57.145466035412205, 53.79087463501961, 60.859401456771366, 53.098548843014626, 63.51216316223145, 26.716730210088915, 28.681231660227624, 55.511461534807765, 45.81922600346227, 53.887816013828406, 48.545653743128625, 54.89406085783436, 51.76184038962088, 56.71644503070463, 55.11345471105268, 57.23258187693935, 56.119295550930886, 54.348588605080884, 41.563442599388864, 42.50571750825451, 41.13648476139192, 46.92556581189556, 56.443534358855224, 57.53884838473413, 51.40515573563115, 52.86916863533759, 54.93513984064902, 55.92661696095621, 56.04759070181078, 56.3297660120072, 53.95798721621114, 51.358310868663175, 53.82161032768988, 50.825480414975075, 52.33122733331496, 51.836228139938854, 52.78385316171954, 50.59654343512751, 52.39798215127761, 52.26155819431428, 51.58960911535448, 54.5572155521762, 51.5885147740764, 51.6036472782012, 52.64125147173482, 53.129676772702126, 54.88589840550577, 53.60526415609545, 50.20984088220904, 53.35303614216467, 45.76279486379316, 54.97663067233179, 50.694779196093165, 27.712416033590994, 13.52867735970405, 8.275861778566915, 6.6701611011259025, 10.694380517928831, 6.442561159210821, 6.04974510208253, 3.1400036763760353, 0.23777798689421148, 0.056773309010050954, 0.1372230326336238, 7.2578037361944885, 39.26034058293989, 38.72024197732249, 27.071561544172226, 31.94573014013229, 44.14460143735332, 51.52786316410188, 52.91565656661988, 46.720672961204286, 8.988928083450563, 0.8408482997648178, 0.06268932724431639, 0.10348102708737697, 0.05410260776238096, 0.10069829697209982, 0.033583555580867876, 0.15690032272569596, 0.06254618371566457, 0.04084120827516721, 0.0791908075071631, 0.011587917763409356, 0.03817584666032945, 0.001961347401036971, 0.07942939026942177, 0.032272392268022226, 0.06745592630918949, 0.0712560518314281, 0.06394613278849472, 0.027790768334882397, 0.0742945097567093, 0.2063539642239771, 0.1314024498025256, 0.13623001414441294, 0.14443107730438634, 0.2194969839746914, 0.222961432751148, 0.14610908565021333, 0.15919193685535463, 0.23263537655434302, 0.12894382850537378, 0.10942337959403954, 0.10967711557544048, 0.16089387778793612, 0.1381332523399784, 0.1739881896684247, 0.11058144406565737, 0.3136943124475018, 0.10941233260617142, 0.2149450887114771, 2.1198020587044377, 28.660435253574004, 66.33001742824432, 66.78478487076299, 58.57507582633727, 38.84191390006773, 28.05464086994048, 37.43321034216112, 48.5151533926687, 50.512647859511844, 7.5274338356910215, 0.38112782302402687, 0.1979694230061385, 1.2333331617616838, 7.556802092059967, 11.079636696846256, 17.901885740218624, 16.438735761950095, 11.900633881168982, 15.092991148271869, 27.951649235140895, 48.01649070555165, 56.23440142600768, 58.87584317115046, 55.10725736618043, 57.41446610419982, 53.95808919783562, 53.33613464909216, 56.26970275755852, 55.121687766044374, 57.14037872129872, 58.152024669031945, 51.846853840735655, 53.524733974087624, 59.85814586762459, 55.39213126705539, 58.189232272486535, 60.7909482525241, 58.523100499183904, 56.64783885402065, 51.856373433143865, 54.78609369647119, 55.877210786265714, 56.3878837708504, 54.56527210051014, 53.910910929403, 52.42318730200491, 54.92123896075834, 57.84012956003989, 56.43966297949515, 47.962032518079205, 43.62167496835032, 43.34202174217471, 40.49292187536917, 41.69621090735159, 46.130830857061575, 47.83243348521572, 57.813928127288825, 54.41249578229843, 60.64091367106284, 56.892661433066095, 61.07934444181381, 55.510771197657434, 58.629369274262466, 55.25658984338084, 62.542698383331306, 56.68456400594404, 64.30312479695966, 28.366216305763494, 31.05996874070937, 55.69257305514429, 47.12470454554404, 52.762382107396284, 48.868147096326275, 53.86456420344692, 49.95490643285936, 56.49317979812623, 54.51477550691175, 58.66565904309673, 59.81454087841896, 57.71275058869393, 44.52569892329555, 44.60022787893973, 44.852448048130164, 47.66085332439792, 59.093244460321245, 60.54625903406451, 52.630559090645086, 54.06140050580425, 56.20186144305814, 57.564014311759706, 57.264184413417695, 57.99946015880954, 53.82252423994003, 49.74519691159649, 53.95452768571916, 51.6805963362417, 52.71938900793753, 51.99089896294379, 53.47011104706795, 50.18586735571585, 52.90175176435902, 52.514786412639005, 50.62820088478827, 56.5585421746777, 54.31815885728406, 54.051551434301565, 53.697275115597634, 55.31924578451342, 53.555861903775124, 56.04852030354162, 51.40952525600311, 55.634651414809696, 45.83475466697447, 58.07017657064623, 51.16287093008719, 35.23228999107115, 18.22581075852917, 15.543595975445164, 24.38060379797413, 22.214212071511056, 14.132645880022357, 12.587051603101916, 3.8348625840679293, 0.2967713382695952, 0.386209529373915, 0.16432529285309777, 9.455569521073373, 44.17062636344664, 51.176195221562544, 29.94957712388808, 34.7534195838436, 47.70245790481568, 59.43995452696278, 58.65405667212702, 55.86456898720034, 13.038365398683856, 1.1154182567711801, 0.22243064107193103, 0.3358064291457976, 0.14622585277163214, 0.21499626338481906, 0.1300823883784394, 0.22742006447046037, 0.12936166818103484, 0.16271379626085683, 0.10646949011471965, 0.08256331041094758, 0.10741468173481765, 0.12014564577369921, 0.13115451310671147, 0.17154066132441645, 0.2005462363482483, 0.0974473798827779, 0.18229362464720206, 0.10675383130869559, 0.1615761710150588], [0.03396194555886811, 0.045362666865149816, 0.03072324182627903, 0.06582700121667116, 0.01679571165192512, 0.07689796763682559, 0.07106654466159883, 0.06399630388665585, 0.06021175293191787, 0.031045690148828492, 0.06560786942680998, 0.058951683853182106, 0.03908382938994516, 0.08328603775871378, 0.03639322517800235, 0.019462915708220774, 0.05725350441230882, 0.022046482115383112, 0.09042220039954109, 2.89061717448696, 26.19424108536013, 49.42240938063591, 49.58721953053629, 36.44572227231918, 12.077765176373145, 15.795865174262756, 19.95004350139249, 34.43333064356158, 27.138555626715384, 1.58331252394184, 0.05280499654491583, 0.031378348508188804, 0.5759251057620972, 1.562510233732962, 15.459069878824296, 6.501572237860772, 17.068262446311213, 6.868690886805135, 12.781702164680729, 32.54254229607121, 42.26327188553349, 49.91437658186882, 54.163817513373594, 51.808006686549035, 51.16894275911393, 51.26063992900234, 46.30660795396375, 50.050278863599225, 50.288994312286384, 52.09710105772942, 51.0618345968185, 52.13641497396654, 59.385198239357244, 50.63133878092612, 51.17388886790122, 49.18839685378536, 51.626655901632006, 50.86074644519437, 54.371695287766, 54.912739184594926, 54.349902599088615, 50.8145958377469, 52.29563574637137, 51.999763519533225, 50.85774583201255, 49.989376221933675, 53.87072624698762, 53.390071161331676, 50.805437103394546, 40.41256035527876, 40.74970376107001, 39.94730841728949, 41.95367528546242, 38.81089187437488, 48.07658141659152, 54.09002988569198, 58.37296001372799, 56.143233776092536, 55.28022996840939, 54.11701579247752, 57.563959398577296, 54.7957976402775, 57.712166155538256, 55.64892099749658, 57.18648618267429, 51.58020327168127, 57.10533626617924, 26.963047212170018, 33.71148901600992, 57.24573750649729, 48.112898642017, 54.889585433467744, 48.93074812427644, 49.648659536915446, 47.362380566135535, 51.860829245659616, 48.635683905693796, 52.33678140947896, 54.683970866664765, 54.04244761313162, 44.11050035107521, 40.91366275664299, 39.50283327410298, 40.501135318509995, 50.55458191902407, 53.70661820134809, 54.23328268912531, 54.48336908894201, 52.23169719019244, 52.735298141356445, 53.16016927842171, 49.000040715740575, 49.777434872042754, 53.31138841567501, 54.2261008293398, 50.8465592322811, 44.213843038005216, 50.74135341951924, 52.19481122109198, 50.61465694058327, 50.355670682845584, 54.376060885767785, 55.109904966046734, 53.52293360617853, 51.16616964340211, 54.6899877825091, 55.56385655556956, 57.234692112092056, 59.546878337860115, 52.53485718081075, 52.281111209623276, 42.97617443146245, 40.908042000186065, 27.992130056504283, 30.629849472353538, 32.73795281687091, 25.378397895443825, 9.94456748808584, 4.788399598290844, 6.743639842156441, 5.510905577290443, 3.4865193405459007, 2.161259795388868, 0.6703825210852008, 0.13648818577489547, 0.057494098155368725, 1.74561946622787, 23.888183562986313, 45.14846148029451, 28.217613389415128, 14.47241335145889, 24.030087071080363, 46.27578989151986, 55.49953360711375, 44.86220298274871, 15.564186457664738, 1.6841495517761478, 0.02165643419439514, 0.035502257261184916, 0.028824270740451834, 0.09241302542748953, 0.036421057152291464, 0.0576018177784018, 0.03648984035657298, 0.02909428609024373, 0.054708387958066124, 0.04687518489757373, 0.0983290704748323, 0.042728523333226485, 0.03788073043969851, 0.04744296330177496, 0.06770167199354019, 0.03077374425746741, 0.03673175177086265, 0.027878255575835228, 0.08307266695004317, 0.012695888703268383, 0.03363260819065956, 0.008541414957313288, 0.047682078495141, 0.06875397036633185, 0.07718440791171405, 0.03158757861162866, 0.039664547019187486, 0.04045911809249271, 0.025958768655395797, 0.035350813169873534, 0.021760597254239747, 0.06831242793029355, 0.04965029626844391, 0.013125540497111938, 0.03464588204458837, 0.12164747687957941, 0.025849072525518078, 0.020486211907418988, 3.5683480722288934, 30.593408692267637, 56.201284854642815, 54.988672348760794, 44.83813531937138, 18.500494341696463, 21.996040036601407, 29.78124272438788, 35.39443292925435, 29.35884071934608, 1.9449109271649394, 0.11236681197319301, 0.21896606972140653, 1.339141058344995, 3.4380917972134006, 13.289406895637514, 7.360109936806464, 16.492546758344098, 7.587142605935374, 13.907940156998174, 31.004396600107995, 45.51866262189804, 51.1584347294223, 56.350527117329264, 52.6446403995637, 54.623978214879195, 53.47151917795981, 50.32919468418245, 48.70884003177766, 51.35371777319139, 51.708825634371856, 51.884237950848, 52.34644612958355, 58.903778291517696, 53.68192688111336, 55.458015318839784, 51.367383310871745, 53.660526429453206, 53.08340849414949, 57.40982201791579, 55.77329935566072, 53.78014695259833, 52.11520671844483, 53.180487155914314, 53.095105002003336, 52.84637966463643, 50.03800184495988, 55.998384567999075, 56.02853582751367, 54.29145143878076, 43.08007017258675, 43.23604714485907, 42.3671244805859, 42.87334949739518, 40.97732674690985, 49.55870389938355, 56.47406608827653, 59.32387198171308, 57.56882313759097, 57.33741506453484, 56.07611025533369, 60.25294027020855, 55.36881277638098, 59.61719466793922, 55.70448529335761, 59.53404826502646, 52.614979436320645, 55.77835529081283, 28.34914811195866, 34.67428576561713, 56.08822645679597, 47.07344701213222, 56.00607241353681, 49.97457319690336, 49.40248374016055, 48.70618850954118, 51.47276955266153, 49.766769947544226, 53.525604740265884, 55.535438983671135, 56.20792150497437, 46.69788006813296, 42.537194528887355, 41.89021133607434, 43.552947198191, 52.89658992521225, 55.676981633709325, 54.934684845709036, 54.07074359155471, 52.90302261229485, 53.364685581576445, 53.55812903373472, 48.83924315052648, 48.48674366551061, 51.90785454165552, 52.021532673989576, 51.83817755791449, 47.979569435119636, 50.64260382806101, 51.84164885551699, 52.49707298894083, 52.224789896318995, 54.970394103757805, 56.5846690823955, 55.3556885257844, 53.98320413404896, 56.131741231487645, 56.12301395785425, 59.110604870703916, 59.43560461844168, 53.38405816785751, 52.476598216641335, 48.837713426159276, 44.30420660203503, 29.964503703578828, 30.96623193833136, 33.55422942869125, 24.429384354622137, 10.429534239153709, 6.685317629768003, 9.382868389929495, 10.038224862467859, 8.256498017618734, 4.706865289518911, 1.2300123851145468, 0.3560029583111886, 0.07514692812917695, 2.2254253587415143, 26.971968643126953, 45.16569637483166, 28.74625082938902, 21.640653687138713, 28.747749174794844, 51.167385578155525, 58.84440929658952, 52.870278666096354, 20.787657806950232, 1.8131683190022747, 0.08106943129772141, 0.06187186163339404, 0.056081336262005, 0.09894685143785131, 0.031811402690026074, 0.018010437901642536, 0.05288531320289739, 0.06335743635352101, 0.04692580798761018, 0.04336528412456955, 0.09217892427958789, 0.05236163081961775, 0.028571704958355235, 0.10716939570322152, 0.07297373587085355, 0.06226528225646866, 0.0548441885339637, 0.07245592938195314, 0.042219419603145895, 0.09615986187371517, 0.12236363885383453, 0.08836099487398902, 0.14636521948681724, 0.15200203314663904, 0.20280463290551018, 0.13277832839277484, 0.12554743898011025, 0.20218059300414978, 0.1268141117367533, 0.28449214394054106, 0.12052718820350787, 0.15922216668484673, 0.25783154873117325, 0.18017068775671144, 0.11816492544547205, 0.15694089474216585, 0.11136646968342605, 0.1987072882512885, 5.085354889592817, 37.97415225736557, 63.22662638079736, 62.917167063682314, 50.02340278317852, 23.680827463826827, 24.805451400818367, 28.32701025470611, 45.55610948993314, 36.7257716578822, 2.805232078798356, 0.1472411184541641, 0.2700694049558332, 1.532554479856645, 5.068398483337895, 26.53227879155067, 13.762659488185761, 25.906531310850575, 15.36121851013553, 15.412587831097266, 35.152814926639685, 45.58114205637286, 52.49491176297588, 56.26446639337848, 52.649170737112726, 54.393354615857525, 57.02917952691355, 53.849235580813506, 50.12778489820419, 52.55754416988742, 53.78640313302317, 53.482086043204035, 54.352436450219926, 62.76602637383246, 57.058071705602835, 57.227549476008264, 53.01597118377686, 57.4790753856782, 55.32504696999827, 59.689272142225704, 58.96713633691112, 56.83701476743145, 53.06682863543111, 52.952267969808275, 53.378182457339385, 52.04869508743287, 51.042254124918294, 57.84538945844097, 57.949014556023386, 55.87242157228532, 45.63369789431172, 45.74721520946872, 43.79654992011286, 46.37007974809217, 41.89719707735124, 51.5865888903218, 60.16851517461962, 61.46015559473346, 61.46920058035082, 58.836713606311434, 57.53902881376205, 62.209069421214444, 57.888504151375066, 62.093379112981985, 60.611127191974276, 59.96618363165087, 54.88202310377552, 56.24687848552581, 30.183558271777247, 36.01255532233946, 55.27323638239215, 50.42655183422951, 57.867182147118356, 52.294925797370176, 51.23095543153825, 50.4258301181178, 53.3956644611974, 50.94577558578984, 53.22853619052518, 57.28938564177483, 58.592502917012865, 50.40051906339584, 45.62452347047868, 44.343045911481305, 45.442258773311494, 54.07753321432299, 57.06770504674604, 56.7597048513351, 55.01545429229737, 53.39942209182247, 54.651219075725926, 54.78834121457992, 50.76897082790252, 49.967050090912856, 55.33535888118129, 54.37662178470243, 54.91483765263712, 50.91068998459847, 51.99073814576673, 52.285339524669034, 51.203628278547725, 52.03218975374776, 56.58078985829508, 56.87036275863648, 56.77051098115983, 55.980784893035896, 57.27303328052644, 58.18123063733501, 61.79842472076417, 61.477719968365086, 55.666426535575624, 55.38430613856162, 51.433063399407175, 50.9812730358493, 32.506236837756255, 34.11287692285354, 37.20841146284534, 31.11980057531788, 15.998566400620247, 8.953603217678687, 14.834292204149309, 15.882992782900411, 13.552938199812367, 6.283399712654853, 1.673861052240095, 0.4158587561499688, 0.2384546876794869, 2.638904461937566, 32.40468667399499, 56.633208413277906, 36.76723111060358, 24.289228262439853, 36.298060724812174, 61.12638934966057, 68.35858098922238, 61.718043588822894, 27.118863367265273, 2.522355890081775, 0.18354864520651681, 0.17762770485733786, 0.20129900966440478, 0.17469703550300292, 0.12590701766912976, 0.0869767812471236, 0.15528401510129053, 0.1618978360127057, 0.20674272320203244, 0.11844165938635988, 0.3483678502661567, 0.14553133278123795, 0.12394718855859772, 0.15338848375024336, 0.1530156747227715, 0.09731165974611238, 0.11811909040496235, 0.1427428953109249, 0.167653898918821], [0.06061650016495298, 0.023998680990189317, 0.08388927837292995, 0.12292731102676162, 0.015787201907275426, 0.04406286463622124, 0.06084096775720678, 0.035378874970539924, 0.03960152096565693, 0.06778032624072607, 0.05063623993567402, 0.05847069554992261, 0.022499253485171546, 0.033418061437025186, 0.08821729976203173, 0.02470303563431146, 0.05219132181317095, 0.052814300682756214, 0.06392847063140043, 4.781031425922148, 23.540728246012044, 51.194143987471065, 47.05325072811496, 39.991231118479085, 25.963531194194672, 18.78544080641962, 24.051760127467496, 48.72151713217459, 17.754949831193496, 0.8290944272472013, 0.06351012533770935, 0.03249435092232401, 0.25175565943842937, 2.3253354814744767, 6.9544451755862084, 9.32090082476216, 12.195070520524057, 7.166765524495033, 15.66727811290372, 27.16982868409926, 45.78104957457512, 55.29536247253419, 55.30445060422344, 57.17474652874855, 56.927158678731615, 50.48112377043694, 50.17226065358808, 55.543730874215406, 53.92405086948026, 50.440570385225364, 54.44130559121409, 55.967574350295536, 51.292254232591205, 50.110432332561864, 48.99254506634128, 44.32175136381581, 43.044082426255756, 47.50927725145894, 53.294035850032685, 53.920744311425, 54.663343121928555, 53.46074050472629, 54.33449160668158, 54.08444835293678, 51.84301776270713, 50.442708076969275, 54.41680254474763, 51.73146163263629, 47.48473890366093, 39.168800307858376, 38.98837520230202, 38.856705157987534, 41.93829174964659, 42.117736262659875, 55.63412973957678, 53.92508245283558, 56.395936396814164, 55.735456328238214, 57.55946436235982, 54.29626418698219, 56.035290148950395, 52.536139795857096, 53.37751957678026, 49.10981216738301, 55.31823773537913, 46.35813613091746, 56.858128886069025, 22.6691383700217, 31.503473097278228, 55.67885652665169, 54.9980507358428, 59.08964372450306, 51.280130186388575, 51.88429678640058, 52.51281738281251, 56.157734778619584, 52.790156410586455, 51.79250155725787, 53.709767864596465, 54.34490549948908, 47.37666583830311, 38.40484026939639, 39.2092477890753, 39.671216703230336, 43.720114692564934, 51.90422634924612, 53.995057536709695, 54.41122101199243, 53.799676433686294, 51.15473201197963, 52.79205091537968, 55.43755623602099, 53.87986929185929, 52.41408740320514, 48.70125024549423, 45.71814260175152, 50.273948100305375, 50.2187446625002, 50.616586746708045, 51.06807508776265, 55.20315539452338, 52.8008331021955, 55.99347376054334, 54.342116694296564, 51.563886211764434, 53.978454143770286, 53.20296233700168, 55.22144148426672, 56.062707516454886, 57.6215397927069, 57.1851251202245, 51.31740447013609, 39.7819765921562, 37.67848399377639, 23.459086072060373, 19.22079251658532, 21.00546702261894, 12.1665931324805, 5.487084042641425, 5.982013123650705, 3.70802293862066, 3.765240758657456, 4.33566737559534, 1.1600794667197813, 0.20182822320249774, 0.10550413506045457, 0.8267099939046368, 17.171967952482163, 41.09204430733958, 39.254037334072976, 26.903117318307203, 27.58798472342953, 39.84641721171718, 46.55597263766874, 50.5207161749563, 22.66496692934344, 2.431319149271135, 0.06156680542194556, 0.06575001704116022, 0.04404941979315012, 0.008916090366490667, 0.044444824583948626, 0.05067262911207734, 0.03421215370537774, 0.07940940303547729, 0.09366853628307582, 0.06249019417971854, 0.020934528475927732, 0.009462226786830974, 0.05838302061742833, 0.03683592440680631, 0.053220243012953194, 0.019054140767923767, 0.05455843773820708, 0.034707900692498496, 0.0323465189355756, 0.020916680542511806, 0.044626475522114385, 0.09964127183681536, 0.013548575206509521, 0.07644992877518939, 0.028957893711424647, 0.03622437173861169, 0.04620267844368373, 0.024530405381454096, 0.06991908284685305, 0.0655141998563082, 0.031197919480262265, 0.07065923869489663, 0.10107112132133016, 0.030571253812541405, 0.03784541378638918, 0.01845164900465358, 0.04536911732547226, 0.08245896923566058, 5.869950517531365, 29.071625163478238, 58.711346810863866, 53.29787977280156, 44.90667089339226, 25.793414077451153, 19.056529537323986, 19.66677188873291, 46.20479499140094, 21.939822666106686, 0.9615366269023189, 0.07898423189838087, 0.11926762474280213, 0.37347340956330305, 3.33866780323367, 11.098570958260568, 14.429191773937596, 17.312490786275557, 9.219681120687916, 14.682558255810893, 29.36945661421745, 46.91873696542556, 55.40580464947609, 54.990504095631266, 57.065469295747825, 55.425243916050086, 53.11682708801762, 53.063000402142926, 57.04720281785535, 53.017536209475615, 51.067624015192834, 54.51381060384936, 57.51997001709477, 53.9911469336479, 52.530632788135165, 52.768567685158025, 45.49217093375422, 46.53674517908404, 50.70400853310862, 54.352169729048214, 55.61043077899564, 56.60659905402892, 54.397292675510535, 55.104358734623084, 52.68148322259226, 52.4604655081226, 49.94264118133053, 55.43590491817844, 53.84289310824487, 50.24796239791378, 40.765950218323745, 40.52324964154152, 40.12589785360521, 43.84378702409806, 45.09233628549884, 57.59059229204732, 56.006923567864206, 58.837804025219334, 58.22181540150797, 58.28067448831374, 55.848914807842625, 56.47521142036685, 53.400186954006074, 55.36715361379809, 48.643509034187566, 56.004468164136334, 47.18994140625001, 57.772033291478316, 23.438122964674427, 33.73667847725653, 58.0934166139172, 56.0021931894364, 61.833494632474846, 52.76183689794233, 53.07899582770563, 54.72300237224948, 56.67377748797017, 53.11150050932362, 52.57839941209363, 55.08791223649056, 57.45282688448506, 49.297022973337484, 41.16436104620657, 41.01544434024442, 41.277972498247706, 47.235178101447325, 53.93043648812079, 55.20029990903793, 56.99422336393788, 54.1125835141828, 51.84420231849917, 53.27420434644146, 55.071234318517874, 54.67788334815733, 52.53468851889334, 49.895368776013775, 49.24056437707717, 49.932772497976984, 51.149809437413374, 50.96496382067281, 49.61119697939966, 56.27111088845038, 56.301740677126, 57.575393107629594, 56.54606903752973, 54.45251572516657, 55.63230975981682, 55.485377773161865, 57.18004957322152, 57.56277484278525, 59.78556632995606, 58.720654595282774, 52.1976000262845, 47.08065632850894, 42.620776314889234, 25.475370653213997, 22.047174015352805, 23.787682633246146, 14.542212909267796, 6.275275993731714, 10.599119874738879, 14.733415707465142, 11.939269227366294, 5.605152778087124, 1.5088948655513026, 0.06700419490375827, 0.05036391100035079, 0.8882374568812309, 17.910354137420654, 45.626563102968284, 35.091645563802416, 25.57857409600289, 30.929398921228227, 46.522926668966974, 52.951844353829664, 58.10934928155715, 28.633502298785796, 3.0915812811543866, 0.07770178539137687, 0.028920336250936794, 0.0649249480075894, 0.032989312669322375, 0.08324629311720211, 0.045995306103460254, 0.03531930014310825, 0.06869255309744228, 0.051575854435683265, 0.027095623982829914, 0.012301737423835984, 0.03542227768189004, 0.023872052401965185, 0.09615356463097757, 0.018847205097817125, 0.06256411400353236, 0.007087139716942705, 0.054933050902740616, 0.0030347244436627315, 0.1377693146106697, 0.07839671140837093, 0.28488692436968127, 0.15735779979055928, 0.10070961209074145, 0.1296671993669964, 0.10906915585961073, 0.23723362013697627, 0.13673649019291326, 0.18976213921221996, 0.2229141498044614, 0.18774168956423962, 0.11157150545548047, 0.2331132468797507, 0.16228990449059397, 0.18594032574084499, 0.14644976495014084, 0.12450947411238186, 0.17469193335742722, 7.368915167547042, 36.6415269913212, 66.26565133371662, 59.86067971875591, 51.536590437735285, 39.20655704313709, 29.074159014609556, 34.1065344502849, 62.08823688568608, 24.9109729643791, 1.3898088879162267, 0.20276476568993063, 0.4004618597607459, 0.781699018853326, 6.923075039540568, 12.038130606374434, 19.89354372024536, 23.426312708085586, 11.84545103580721, 20.29748312888607, 31.424782506881225, 49.23102517281809, 56.35900728164181, 55.443486859721524, 58.19592383600051, 54.10856308475618, 52.92982809005245, 54.25665609298214, 60.106612328560125, 54.505526558045425, 51.80813220239455, 56.978588796431026, 59.83983624366022, 55.69303589482462, 53.45849298661756, 53.73252153396607, 49.84028693168394, 47.572647063962876, 51.801891711450395, 56.826255706048784, 57.614024531456735, 58.7663580525306, 56.62395161967124, 56.74791812896729, 54.92205873612435, 53.48352555305728, 52.82992139939339, 57.06088012264621, 54.69353360514487, 52.64293809090891, 42.9595043582301, 42.98967915196573, 43.755655288696296, 46.356606406550256, 45.84152860026206, 60.351160341693515, 57.06861111425585, 59.67364149708902, 59.670746787901855, 60.17528910790721, 55.920172506763095, 55.6075321474383, 52.96011663252308, 54.62350753045852, 48.73218990141346, 56.03950277451546, 46.67762887093329, 58.29861540948191, 25.373543962355583, 37.425726459872344, 59.31848656746649, 56.97106569044052, 63.10937889160649, 56.195742545589326, 55.92389091368645, 57.61083564450664, 59.35724350713915, 56.17421265571348, 54.0709004863616, 57.41879640087005, 58.867896449181345, 52.52956982581846, 43.52292145452192, 42.79729473975397, 44.48547893954862, 48.98775192999071, 54.84857313094601, 60.40589701744818, 57.43109303136026, 57.93975384004655, 53.173944642466886, 54.07127311152797, 56.47538008228425, 58.0507843725143, 56.042009169055575, 52.89128688073928, 50.624713897705085, 51.61816397020894, 52.27138765396611, 53.34938049316407, 51.134312152862556, 57.99077995361821, 57.25477856974448, 61.29029343205114, 58.84644500670895, 55.45322610485939, 58.279831178726695, 58.02630878263905, 60.25261471348425, 59.73190830599878, 62.35065521732454, 60.315164750622166, 53.49604968101748, 50.30220093265657, 47.773888188023726, 31.19938938848434, 24.833668931838005, 30.144791526179162, 16.843510635437504, 10.945819154862436, 11.149746121898776, 15.240872348508528, 14.734032500174738, 9.379466714397553, 2.741689927154972, 0.3345146210443589, 0.34036379427679125, 1.2464037249165199, 22.53203976538874, 54.524518674419774, 50.479845077760764, 38.06134262392598, 39.31177462300947, 53.21563551502844, 61.252940700900176, 65.63128248337777, 37.04726480668591, 4.616585566151527, 0.2444716801326121, 0.12138548247035473, 0.18326707725082675, 0.11884512725256144, 0.29000705768985136, 0.113263571514718, 0.07917367012029694, 0.1528739791002966, 0.3058090613734338, 0.14221426399965442, 0.08443762112649218, 0.11412021869252767, 0.10230636149043999, 0.1550357566485482, 0.12767547801617654, 0.13052477351119443, 0.19474561776845686, 0.12109134301182725, 0.0897121824504387], [0.06668249160171517, 0.04976197656604552, 0.0797340787586666, 0.046743383300640894, 0.07093445578169438, 0.056168225954376885, 0.11307355872685872, 0.014812696890364734, 0.05049297383295433, 0.014792891602302271, 0.1344372917928042, 0.03312176927143047, 0.023103022700055473, 0.06460149802507893, 0.0554485974322644, 0.0037052790491631437, 0.06773275984150749, 0.060643263446587714, 0.06591129387097974, 3.3263824495577046, 29.58691477775574, 50.8020991663779, 49.68153292132963, 38.51580412157121, 19.574717783158828, 14.882807020218143, 36.63033646921958, 40.03704440209174, 9.778786551567817, 0.22141850102813015, 0.04808638522761965, 0.0956718102397938, 0.8371840092924334, 5.26001803336605, 9.46787399630393, 6.9034416156430405, 13.637216206519836, 8.61782185492977, 13.352416830678141, 36.22387301537299, 54.71255317811043, 56.84648336902742, 57.12329679919828, 54.2783546447754, 52.768814794478885, 53.51471231829736, 50.1654004281567, 50.6064199632214, 53.30863098944388, 52.780405398338075, 57.90513500090569, 51.25279126628753, 54.41371956179219, 49.77815266578428, 49.285553962953635, 45.96111382207563, 41.620187528671764, 39.944574525279386, 46.33545306421096, 50.10375253615841, 55.51228523254395, 52.06609079914709, 53.93207603885282, 50.40285287364837, 51.24184785350677, 52.194395449853715, 55.62562604104319, 48.045861413401944, 43.378715515136726, 35.615670296453665, 37.89647363847302, 38.50021662250642, 42.02248542539535, 47.82928774433751, 57.302388298896055, 58.61602537093624, 54.80516818261916, 52.09914461258919, 54.97939594330327, 53.97894444004182, 54.841928635874105, 49.345122998760594, 50.50616025924683, 47.50990483068651, 52.41950027404293, 49.43567091418851, 51.671884752088985, 23.23172784620716, 28.170548869717507, 55.8941868043715, 51.349803247759425, 50.951918017479684, 47.69813153051561, 55.16078987429219, 50.065164258403165, 51.96236764231036, 49.72265897258636, 54.47786600359025, 54.78538374747, 52.33454565848074, 46.986880302429206, 40.1375747496082, 36.99940404584331, 38.618860475478634, 39.75965830587572, 45.02937439949282, 54.021564914334206, 54.6960517667955, 53.374781762399984, 53.73003082890665, 56.09580839833906, 54.59071651581795, 54.355021292163485, 53.03717159455823, 50.40390406885455, 54.472170722100046, 55.65176471587151, 52.32173911986813, 53.14025148268669, 55.40923280100669, 53.93264086015763, 52.31690283744566, 47.7973831853559, 47.984244900365034, 49.04593244675667, 49.15825736138129, 47.907829284667976, 50.05174975241385, 53.07294361052975, 53.33591891873268, 56.02762976000386, 57.0387226535428, 51.024321048490464, 41.0219358628796, 39.24735361529935, 21.98700877927965, 15.857605241960096, 12.170511580282643, 8.77506281099012, 9.968579257688216, 9.790087880626801, 11.027196568827476, 4.783708443564754, 1.6176754284289576, 0.46253955772807526, 0.0440738809805724, 0.17558784254135626, 8.299988277496832, 36.448409095887214, 37.88614996017949, 29.609268365367768, 23.222892707394017, 43.63721539897304, 49.03743659296344, 52.42934934554562, 39.9613622696169, 7.101370298093365, 0.010901191760034812, 0.05527168474791031, 0.022191280393951365, 0.0528886801593246, 0.04087174070938941, 0.021297106399170814, 0.07126840882964673, 0.028127327996997104, 0.04908943946863856, 0.03997547146413596, 0.009521126499279373, 0.04293157876799664, 0.04495634915186994, 0.0035612063995006707, 0.028091578504010558, 0.023478899909664067, 0.029548746683905204, 0.10172198962179885, 0.013952934607532958, 0.030623880222499855, 0.050050952591963356, 0.07870394330952438, 0.06872410825904339, 0.03572540718220896, 0.07296333239684183, 0.05158353446712417, 0.019718317930857023, 0.01223987103590081, 0.016906514778853427, 0.03964862771212094, 0.03929453804307888, 0.030248993181533394, 0.06851380180206991, 0.07570547517389059, 0.022510748634475376, 0.031222874794395703, 0.022701853097626762, 0.08379156385818798, 4.367720984643506, 34.95704943133939, 57.60604250815607, 55.223559564159764, 45.35970464829476, 27.956869909840247, 19.613258992472005, 33.182522096941554, 44.7180833355073, 12.716258398948177, 0.3519532643258572, 0.009098263202054847, 0.24580640447956903, 2.249903400098124, 7.552934635070063, 11.44937107639928, 9.963725324599974, 12.010637733244128, 6.661566697782086, 13.592130522574148, 34.67558799251434, 55.20878791809083, 56.26899280855733, 57.06950541465514, 55.757417678833015, 52.812141295402284, 53.63730207566292, 52.07067604987852, 54.018964382909964, 52.449871186287176, 52.83831527156215, 58.8521755895307, 52.26045208592569, 55.67051364529518, 52.123027924568426, 51.065603994554095, 47.522228917767926, 43.34133532739455, 42.22991604958811, 49.13603713435512, 54.218707161564986, 56.55286650503836, 54.24836420243787, 55.12366071824105, 52.99670057912027, 50.78922202510219, 52.31881303171958, 56.946696004559925, 51.810556227161044, 45.581922608037154, 38.02868889224145, 39.43314060088127, 41.09437811759211, 44.046326452685946, 48.50932867296281, 59.31337964150214, 58.37796495806787, 56.15887618833973, 52.38982362131919, 53.9197519517714, 53.057422791757894, 54.92798543745472, 49.570753420552904, 50.352642613072554, 46.33079721081642, 53.03168812105733, 48.41560363769532, 55.17975845644551, 24.59287266577444, 30.07157656454271, 58.67699469289472, 53.387360803542606, 54.71879759142476, 50.72691909728512, 58.14486634346747, 51.94024155216833, 54.03792119795277, 52.19694891283589, 55.52562913587017, 56.579620991983724, 55.45509315306141, 48.764541610594726, 42.59910129731701, 39.241073900653475, 41.803746607995805, 41.712484821196526, 49.06601498203893, 55.59438828499087, 56.13012129260648, 53.287634541911466, 56.05100316386069, 56.66702316653345, 57.796928574962, 56.3594622765818, 54.93514768538937, 54.40302718070246, 55.08771611798195, 55.72990225207422, 54.75478533775576, 55.358300824319166, 56.92169481708158, 55.3467769007529, 55.70121011426372, 50.757999958530554, 50.9079090241463, 50.52919633926884, 50.85730652655325, 50.52070440784578, 53.25758526402136, 55.93183763565556, 56.03172863683393, 57.09180016671458, 57.399090413124334, 50.71032354908605, 46.92172581149686, 41.83062268841652, 24.111270327721876, 17.069235194113947, 12.656376554119973, 8.202367838351957, 13.84202962921512, 12.897693514823915, 8.747382644684084, 8.99694246630515, 6.238070841758482, 1.246261906719977, 0.028292684245013425, 0.19357806912833647, 9.955219664881307, 37.760214421056936, 42.97862983519032, 36.89037392216344, 32.262408579549486, 47.75274269042477, 53.16539387549124, 58.19474320257864, 45.664198244771654, 8.557040806739561, 0.07077965239483504, 0.03250245230212327, 0.027566576534281337, 0.07064158036824196, 0.026345903527051694, 0.024423290967881203, 0.023648379625932827, 0.03309908540799253, 0.04376630433985303, 0.01600085999891763, 0.04530434842191396, 0.07600408092501663, 0.04570543758511063, 0.007453566753200346, 0.022808391030036637, 0.01774250248056506, 0.006653374030945763, 0.06594809673486218, 0.0340017821309307, 0.12609992626934283, 0.1477440858199712, 0.1557728404840154, 0.11647418471834353, 0.23057153568633143, 0.17405381276001855, 0.17742156591867247, 0.11757595704928522, 0.09171813005401243, 0.18298874218617717, 0.19200538255033955, 0.09942390204918, 0.18938637308536038, 0.1136453361100247, 0.1389994985994793, 0.16871243324731627, 0.09605783428395949, 0.1441076503045136, 0.2031416962704351, 6.893962717825367, 45.20360216017693, 65.10049558454945, 61.13494796137656, 50.945179385523645, 30.88086743508616, 22.958077807580274, 49.34454641034527, 53.213309549516254, 14.581128704932429, 0.6837953110375713, 0.15174186968755338, 0.4589463602150641, 2.296709288512507, 11.692533512269298, 23.846877082701653, 15.52255932361849, 22.34029862188524, 14.693531086367948, 19.737607932859852, 39.79288078123524, 55.35107581846176, 57.29848946294477, 57.12122578774729, 56.20364219911637, 54.2334827300041, 53.69410584049841, 51.67065312785488, 53.79642086644327, 53.5617886051055, 53.32385370808264, 61.02079129988148, 53.7204602456862, 58.996456053949174, 55.26503078399166, 54.14823001430881, 49.74559699335406, 45.98197690902218, 45.842513115175315, 50.104740973441835, 54.064420730836936, 59.41450618928479, 56.39419486445766, 57.04551227631108, 53.96339616467876, 52.93241293199601, 53.65762779789587, 59.162917521692094, 54.158141843734256, 48.105046056932025, 40.38142065848074, 41.248813598386704, 42.80906577264109, 46.69650723857265, 50.85235649539579, 61.386956322577696, 58.93119173665201, 54.67290193803849, 53.50972698580835, 53.33038053204937, 54.157129872229795, 55.226517031269694, 50.492075027958045, 50.57974784604965, 47.36432213937083, 51.87695410943801, 50.258972490987475, 56.36237659761983, 26.730158444373842, 35.01542606661397, 60.81654171789847, 57.843396894393436, 56.22896894331902, 53.427317988487985, 60.49078495271745, 52.94603532360446, 56.54461776056598, 54.44223127057476, 58.907830099905695, 59.74553069760723, 58.434780490013864, 50.71990982178719, 44.86427791656987, 41.29044563539567, 44.415798033437426, 45.196690943933305, 50.29866295476114, 58.991082406813106, 58.69020915800526, 57.324318270529474, 58.185557011635076, 58.9753419353116, 59.926010716346006, 59.3203849946299, 58.025763573185095, 55.57961271655176, 57.414117013254476, 59.63580239203669, 54.66960714709375, 56.468264902791674, 59.5081723889997, 57.72715745433685, 58.61749233738069, 52.18507589832429, 52.446984321840354, 53.12935121597783, 53.61794910123272, 53.17534100624823, 54.811098806319706, 56.68373638583768, 58.96893278245003, 61.366865942555094, 60.113025403791866, 54.237691433199, 51.46980816318143, 47.426597610596694, 29.808907201213223, 19.703904967154227, 15.078591146776754, 14.109175397503762, 18.329024007243497, 17.258536623370265, 20.640317893797352, 12.197626925283863, 3.8621586032452124, 0.766309722056312, 0.18913949359088175, 0.40095785572644205, 11.666681170463564, 47.931120318751184, 48.9449078805985, 41.61441772214828, 34.725531531918435, 53.966569362148164, 60.22888829631191, 65.00991629016015, 52.149037161181056, 11.20418763929798, 0.259446952371828, 0.1662648436162741, 0.19771426976207765, 0.2529459455681424, 0.13128920668555846, 0.09405974674248889, 0.11695849018231516, 0.06723559942216643, 0.15550867804596502, 0.11618618928496877, 0.10264285795030095, 0.18195303727782544, 0.1587064669377381, 0.18997207794698978, 0.11925649348526232, 0.15048599110976343, 0.06931829371399457, 0.1518563079016824, 0.09917132286054474], [0.07265902695155914, 0.01722891905134724, 0.020471842013179295, 0.052521961530850786, 0.03871069860554511, 0.04142216722210569, 0.03753600236509116, 0.025932164337005348, 0.04499712035120015, 0.04872316900160044, 0.029729014833367644, 0.048459044867946256, 0.09479423353989279, 0.024602059500231862, 0.09943968346042019, 0.0323208358379141, 0.11469620955927719, 0.023909720945202058, 0.12883593268211813, 9.137902644372756, 32.60319978960099, 47.61519693559217, 45.590230188062115, 31.110308439500873, 15.636099192403979, 20.22099494934082, 28.083686021066484, 34.122600478510705, 6.351648953653152, 0.1616677338437688, 0.07174951970697412, 0.08122265654345674, 1.5490055132296778, 2.229643132417433, 9.35002540388415, 16.452001217872866, 16.408427607628607, 13.98055793777589, 19.921706338082593, 38.277818233736106, 52.88758024092644, 55.31838678544568, 55.31812006427396, 54.21994270816926, 53.0210231965588, 51.38896811393, 51.82167222422939, 50.34611971147599, 50.95019609697404, 53.010424952353205, 53.46779684866629, 50.049329650017526, 50.58844374072168, 50.73760363363451, 51.337714502888346, 49.53815067968061, 47.997506433917636, 39.54648533175069, 39.0870032002849, 42.61840720330515, 48.20469387115971, 51.09136219947569, 55.19364364685551, 55.912292465086914, 55.268517771074855, 52.69387398996661, 51.76860255579795, 48.19943789512881, 39.20612166004796, 38.8457303662454, 38.28744373013897, 39.144681653668805, 43.05285284596105, 52.745496303804465, 57.907347217682876, 40.56266553940312, 52.35968412891511, 50.84609639260077, 53.47878340751895, 52.46710608082434, 56.79361766384494, 52.38555216020154, 55.50788433321061, 49.75432034461729, 53.61391690469558, 43.12176888988864, 49.97801703791465, 23.24382443581858, 33.58516516224031, 60.545431413958156, 49.64867130402596, 50.423347257798724, 43.39080033763763, 45.200024958579775, 46.277574569948264, 47.82947994047596, 46.61820888519288, 50.33673347965364, 49.99892327093309, 51.192206336605935, 44.282821839855565, 41.32611959211288, 36.6500699135565, 39.01614950549218, 38.429484521189046, 39.460608959198, 44.334291181256695, 50.22833485757151, 51.971314568673414, 53.0535827913592, 52.57446135244062, 52.89667229498587, 49.122877582427, 50.46531269627233, 52.866905427748165, 52.450726262984745, 51.71963960893693, 51.633006218940984, 53.53566561975787, 53.92618856122417, 52.24258568979079, 48.38335783250871, 42.072346595025834, 41.0954410799088, 39.731244656347464, 41.649907327467396, 42.13214705067296, 43.61428914531585, 48.5201544146384, 50.80266398768271, 52.200761456643384, 53.010817189370435, 52.31560061054846, 49.898989123682824, 46.303732856627434, 45.73639731253348, 25.44847299975734, 18.921827500866307, 5.898316608321283, 15.893596910661268, 19.263026637415734, 9.994890516804112, 6.756374307217137, 3.151244698993622, 0.3044546179233059, 0.27073991575068046, 0.18769013184693553, 4.020417414365276, 27.717838710354222, 36.55933764673049, 13.814810341404332, 18.07889053898473, 33.029718322138635, 41.022998825196304, 55.23793897321148, 43.011671881521906, 13.982180818434685, 0.14177014750819053, 0.04936150027318828, 0.028602153122905764, 0.008407408942378337, 0.07216894518463843, 0.03871614932112637, 0.05147027985883817, 0.033407860976313396, 0.07891539889838427, 0.02661881468919737, 0.04565411352462346, 0.008864823762597817, 0.06434338768163035, 0.0484411184105181, 0.04084982676431537, 0.037550803183788256, 0.07149633530887865, 0.06573484850025947, 0.04245079730847671, 0.03221136187353442, 0.007955940879671084, 0.0680404896998117, 0.002149234294906379, 0.06789196057305222, 0.05024220261182036, 0.09692906777584746, 0.03922469763746185, 0.011533286118309104, 0.0774300386828761, 0.02323742516549124, 0.06809039266719934, 0.04090184796481364, 0.04054782724368476, 0.03209230223400218, 0.07058409313040395, 0.03206622651627949, 0.026175305322413484, 0.1660705483969181, 10.624701573002724, 40.258524956241736, 54.18195847542056, 51.73482702624414, 35.54348691817253, 19.649913541732296, 20.149366586439072, 32.797008022185295, 36.20290402443179, 7.323246031038224, 0.10231992124669975, 0.12450722181388449, 0.30294021531458826, 2.984443946230796, 7.458484941913237, 10.865353691962458, 8.4456435326607, 6.494284474080609, 10.325585546032077, 19.518527869255312, 40.0893452859694, 52.34734827472318, 54.86855760697396, 56.042581835100734, 54.64351946307767, 52.48068140399072, 51.75888292251095, 51.22786068147229, 50.775289766250125, 50.87374517994543, 54.071877156534505, 54.50853501596759, 53.43888505812615, 53.62216564916796, 53.44339578382431, 54.88776937607796, 51.170182228088386, 49.53750741097235, 41.38201728943856, 41.56660795211792, 45.41379021060082, 50.738105697016564, 54.03827421126827, 56.43827053808398, 58.43154061225153, 56.07538853922198, 54.21485539405577, 53.73192533369988, 49.68885990881151, 41.186714633818596, 40.403844848755874, 40.2000424169725, 40.46498283263176, 45.44354531072801, 53.48226254986179, 59.936122586650235, 42.68047478891189, 52.276549493112874, 49.71289227085729, 52.82173541284377, 52.81287477862451, 56.412873191218225, 54.47535176430979, 55.77590380945514, 50.585921656700876, 53.52072531177152, 43.8057674900178, 52.30628105901903, 23.984281632208056, 35.49601839434716, 63.32527399063111, 52.5037645524548, 52.76190357823526, 45.61669441961473, 48.23600222987514, 49.115938909592174, 50.82964597209808, 48.70964019529281, 53.07960771745252, 51.820111120900805, 52.541136895456624, 47.015035075526086, 42.85389061897032, 39.87452099400182, 41.87442379613077, 40.334705229728456, 41.14527479294808, 48.24656125037901, 52.99730854649698, 54.35893973996563, 55.80194050265897, 54.31287542466195, 55.336229647359545, 52.422238088423214, 53.04038793809953, 54.34074778710642, 55.78901629294119, 54.390252021051225, 54.98932738457957, 55.12609651011806, 56.90682511175833, 55.548371038129254, 50.93953117247551, 44.275475240522816, 43.23766708374024, 43.01067952186831, 43.60785253586308, 44.13061426531884, 45.60431934172108, 50.270814126537694, 52.779373814982755, 53.51183329859088, 55.44368690060031, 53.26854828865298, 50.46734448402159, 50.04934141712804, 48.23233089139385, 28.98215197747754, 19.19757208516521, 6.619707653599401, 10.50344640208829, 10.081733753604274, 13.486050021263862, 6.32900167857447, 6.34470243607798, 1.0273152037012963, 0.410942800583378, 0.1252802811382759, 5.031678234377216, 33.86060184048068, 39.79548131265948, 18.77420517706102, 25.416076183319095, 39.695798197100245, 47.35076250568513, 61.784166905187796, 50.6947595842423, 16.795936207617483, 0.3316615563967536, 0.05764024857912333, 0.03441714734259633, 0.04405127372592688, 0.028466969247787233, 0.043323444232584975, 0.05395756433567694, 0.05432468899075062, 0.02380654039312034, 0.03896805435238827, 0.05246076642745926, 0.055430617348681537, 0.025947562704283385, 0.05142836335806116, 0.07527976777524718, 0.04232250439423708, 0.05919130466457817, 0.03158482261032107, 0.015065269375730668, 0.1803721842025557, 0.10164725774478528, 0.18813567326193859, 0.17131474199554614, 0.16954547725617888, 0.127664890681063, 0.24181367679228707, 0.10901824165616306, 0.13352339486441306, 0.13404765947451516, 0.1853113828767692, 0.15835857108956383, 0.2331574348312232, 0.12845160935314434, 0.17997348140324318, 0.23258369626297107, 0.15246335597288224, 0.1692342157325437, 0.4504876157208797, 15.06954518056685, 46.85332752043202, 61.94949480795092, 58.426237567778564, 42.22597798993511, 24.88519906997681, 29.4272429327811, 38.98453912427349, 45.50167091431157, 8.931770324707031, 0.3274935171488793, 0.26018861741308247, 0.37415253118641917, 3.6266452795074837, 10.478854121700412, 19.677944760168753, 28.586653509447654, 29.698453257160804, 17.57704680965793, 24.103407936711466, 39.94294674165788, 54.84918109832272, 54.81668033907491, 57.261011215948294, 53.94310966614754, 53.965424030057854, 51.57373136089694, 52.7967812938075, 51.86305322954732, 50.22785632841049, 53.52321993920111, 56.53196811676026, 54.17926772948235, 54.53058658107635, 55.72551311985139, 57.6369115614122, 54.55179483659806, 53.0396544548773, 43.67829830415788, 42.46177519521406, 47.860498043798636, 53.246292760295255, 56.42083560266803, 60.5157429941239, 62.26651645475819, 57.77277461944088, 56.620013560018236, 56.233785613890625, 51.08547864421722, 43.62880191495342, 43.349948852292954, 42.45573082277852, 42.95492302986884, 47.92606438359907, 56.79340977822581, 61.93546841221472, 43.90230878706902, 50.94274359364664, 51.2363879142269, 52.76342153549195, 53.649331984981416, 58.37272859388783, 56.627054214477546, 57.220179342454486, 51.87850344565607, 53.4035837265753, 44.84496416584138, 51.922994890520656, 27.000113610298406, 38.220559473960634, 64.1726863768793, 53.25518869584607, 54.71257671233147, 48.74438062790902, 49.5117845073823, 52.22175398180562, 52.9916524887085, 51.47403647822719, 56.19357347488404, 55.265948618611986, 55.569100764489946, 49.260274287193056, 46.17411028954291, 41.27650553180326, 42.90217107342136, 42.51747285166095, 43.92341898333642, 50.04166926107099, 54.56061232474543, 56.89381068752658, 58.02739527917678, 59.1859261451229, 58.105881906324825, 53.49113495119157, 54.0909908663842, 56.052258322315836, 59.32319341167327, 56.81009161856867, 57.263776486919774, 57.73068366512176, 57.523617821355025, 58.19931668619956, 52.920449702970444, 46.639448519675966, 45.29496200623051, 44.90724355943742, 45.638844043977805, 46.77083223096786, 47.78285080386747, 53.53200997075727, 55.84225462329004, 55.72625052544379, 58.531157047517844, 54.38223077404884, 52.02353308277746, 52.865673803514056, 51.782597572572776, 31.168565442485196, 21.306199066100582, 9.121917024735483, 23.90226291071984, 33.24471127602362, 20.275207988677487, 15.919804226967598, 8.66034132819022, 0.42492062634518074, 0.4128806659531209, 0.3251741399928447, 5.899003023101438, 36.495508916916386, 48.440789176571755, 24.48869255281264, 28.066539379858202, 44.56511874352732, 55.45838009926581, 68.79527414998701, 56.351935248221125, 20.290124762442804, 0.6792752084232146, 0.18068790435791018, 0.0797415787594453, 0.15498231435495038, 0.11304223339163488, 0.09083028011504682, 0.22828710746140252, 0.25791385721775795, 0.20310270239508924, 0.13817010116913628, 0.13354504450915322, 0.1145670471352435, 0.19128939677630702, 0.172021335531627, 0.15925475606514564, 0.15593594060309474, 0.19279304351056778, 0.2486369767857175, 0.1416428236951751], [0.032270940531405716, 0.03998725006597177, 0.036423160063643614, 0.04389804464975192, 0.0361003804080669, 0.11142394159950557, 0.03211097754237633, 0.04759545693354261, 0.08942899038834919, 0.021757423735013413, 0.018362041615370302, 0.0879150627541446, 0.04597349941069561, 0.018030369594212503, 0.05764977488246176, 0.036774579916269555, 0.07085600071736882, 0.006798492151222402, 0.19152253265342406, 7.452097852383891, 32.947532899918095, 47.894422623419, 47.49410160126225, 33.046423696702526, 21.625676116635724, 31.476455811531316, 40.97531457101145, 27.572314854591127, 3.1650149149279443, 0.035389845349615624, 0.2123170547307499, 0.5287649782915269, 4.041229020203314, 7.778948958842986, 9.206568637201864, 3.066973311285819, 4.170382618904114, 12.948195011385026, 26.05312401248563, 46.934418601374475, 55.202535660036155, 55.47615628088675, 58.731809816052845, 52.51218588121476, 52.23649817128336, 51.87985666336552, 51.06864775380781, 47.870319658710116, 52.60083929184945, 55.37950907984088, 53.79832321597684, 49.605089849041356, 50.219058452113984, 50.00566190288913, 52.582408074409734, 51.59471604131883, 50.685706753884595, 46.61481603499382, 40.12509376771989, 37.757186351283906, 38.82199218196254, 43.41194191286641, 49.08220260374008, 53.04716187138712, 53.649473190307624, 54.22870136076405, 48.78641274667556, 40.14499587397422, 38.50853204727173, 38.14295930247153, 37.969555239523615, 39.71803019123693, 43.03225255781605, 57.16616046044135, 47.52916759060275, 38.94470745517362, 56.30031293438327, 53.56406750217561, 55.5033383061809, 51.85032121596798, 55.23388716482348, 49.96052326694612, 55.084958691750806, 50.159101101659964, 56.37740319774997, 48.041095733642585, 54.76372441937847, 28.041930429397095, 38.22569777888637, 61.33401216999177, 47.52756726357245, 51.405802926709576, 43.14320464288035, 44.42994602264897, 39.374359961478945, 43.09101358536751, 44.26568108220255, 46.282014692983324, 44.45682994781002, 46.23960210431007, 40.150879429232695, 38.30446681668682, 38.81353162950085, 41.80300528003324, 38.56174292102937, 40.722576648958274, 36.93031149525797, 41.252943854178156, 42.964697576338246, 45.78867858456027, 46.145343626699145, 46.63481620050246, 44.75410246079968, 46.40157638057586, 45.483263231092884, 48.97227033492058, 46.19150600125713, 49.62207371188749, 48.87288139712427, 49.52353985078874, 45.19890316071049, 42.02183038957658, 38.08879921513219, 40.35439945036366, 41.61939128752678, 45.883148870160504, 43.94632170277257, 47.696072286175145, 46.51901606590518, 51.46658789726996, 53.481980139209384, 57.39602704201975, 53.20066382808071, 53.443485998338275, 47.30525124457575, 48.50092695605371, 42.520618592539144, 29.208643359522668, 12.716779093588553, 11.04879706136642, 9.897144071517452, 5.340227561612283, 8.046475687334615, 26.193478184361613, 22.71048015163791, 1.2402338366354666, 0.06446424571256484, 1.2477037454805067, 21.325381417428297, 46.45479117670367, 33.51723363322596, 16.744961084858065, 22.33122814086176, 48.78507129607662, 50.7115630180605, 53.50077613707512, 20.42486013904695, 1.5632634513801145, 0.08197219696857276, 0.023950748783986897, 0.04044750419956061, 0.033191942925294565, 0.06281964263067612, 0.11274451630250101, 0.05149313609205908, 0.0393749542924906, 0.021518685839950077, 0.0321756353631856, 0.02124694104666912, 0.028828702559093797, 0.018870419477142634, 0.01691242706240906, 0.03401043126359582, 0.044680308520553574, 0.048804979531034354, 0.012106503746772726, 0.03222611289651644, 0.020262581266222462, 0.06359639449886258, 0.016125064876471317, 0.0071657417743887395, 0.10221071541309358, 0.0430676436442281, 0.04900290983759108, 0.022476058258044145, 0.031838181293419296, 0.035880965165673726, 0.1038441144590897, 0.016850274349112185, 0.04887580435963408, 0.06629691954942481, 0.0035484287711311014, 0.024317377397129615, 0.06479244544020583, 0.2852755148083933, 10.082365255202017, 38.43726650361092, 55.58746137926656, 52.95135013518795, 37.23955508201353, 23.65210786942513, 30.441004999222297, 37.78126578177176, 32.682967070610296, 3.4869378084136597, 0.08792223333711587, 0.12578359324364893, 0.7442771559280734, 6.5944328808015396, 9.824271336678537, 8.478531625963027, 6.856653132746297, 4.371035387439113, 8.874213464798467, 28.829871839092625, 47.015392011211766, 58.70800887384723, 55.11543943035988, 58.42449211305188, 52.499555849259906, 53.14125168708063, 51.46319896944108, 50.84182885385329, 47.86682090451641, 51.487349002592026, 56.22917290656798, 55.39601441352598, 51.597885316418065, 51.91223975150816, 50.541100732741825, 54.17992276530112, 54.35347587831559, 52.661169267469845, 47.22192833500524, 41.45543621432397, 39.31270422474031, 41.72318896939678, 45.45821889754265, 51.557559428676484, 53.23627502687516, 57.535918374215406, 56.71577430540516, 51.270681196643466, 40.50713262250347, 39.86815890958233, 39.3051262055674, 39.64005739458146, 40.246365608707556, 45.31333438811764, 57.24371356348838, 52.574955571082334, 40.42960305367747, 55.23197697054956, 54.04835078024096, 56.58365711089104, 53.43560987903226, 57.25009133738857, 52.03169945747622, 57.0098618538149, 52.827952369566894, 56.67922566013952, 49.31525414989841, 54.480909762843964, 29.460690944425522, 39.17963781664449, 62.61839620528683, 50.147710538679554, 54.1392909326861, 46.15265100233017, 46.09172874881376, 41.40478272591868, 45.38636107598582, 46.79872028289303, 47.98079321461339, 47.01285423771028, 48.25775961722098, 42.27157162081811, 41.222796517033736, 41.064681853017504, 42.01600174750052, 40.25756789791969, 42.390133104016705, 39.7613331579393, 43.93280913752895, 46.00417752419749, 48.23366841962261, 48.54154702155821, 48.46684548162645, 47.2043796508543, 48.982656771136874, 48.49820090878395, 51.7312341351663, 49.2373441111657, 51.83614577016523, 50.711539483839466, 52.43029071438698, 47.9715834894488, 44.31406351827806, 40.71559875242172, 42.938060760498054, 42.89506766103929, 47.21524069386144, 46.248050889661236, 48.64490539796891, 49.33864324323593, 52.183271608045025, 55.942922253762525, 57.86848829638574, 53.68420970055365, 52.04193684362596, 51.13280988508656, 52.48091674620106, 43.703923148493615, 30.047159810220045, 15.87515784848121, 12.279154369907996, 10.109479619610696, 10.851576366732198, 10.273513140216952, 8.959019030294112, 9.41961609548138, 1.3099388898380342, 0.10466635662821994, 1.5071147223634105, 26.459707098622477, 50.275517048374304, 30.911230502590058, 20.45864155215602, 26.470562258074363, 53.19836139678956, 56.98778675448511, 60.05158931978288, 25.195405598609682, 1.809259431977426, 0.05263798171654344, 0.007173301146981577, 0.03970524927060451, 0.026945815489236868, 0.05940601229667664, 0.03877026194165792, 0.02869345931216113, 0.03132602278774064, 0.06547576522514706, 0.018118605686111316, 0.009880094233179286, 0.01085021626955319, 0.09774929513373683, 0.02722431526279017, 0.07288938192951103, 0.10049522238513155, 0.017557271996573094, 0.11466581119044174, 0.1914197389757441, 0.13623300188731763, 0.14142982060870818, 0.06609665650513864, 0.120617808744071, 0.26302127347838494, 0.15299819259633943, 0.2326901365191706, 0.17831287857505584, 0.08804822415714303, 0.11360782078437268, 0.36181912847584297, 0.10861365530159205, 0.12250162661075593, 0.20899767236363506, 0.1458760263818887, 0.13771530541200794, 0.13518661771330143, 0.4693547984765422, 13.171720100987343, 48.31901527220204, 62.79956263880577, 61.10797774407172, 45.114023070181574, 32.24413033454649, 41.942790708234234, 53.155136877490634, 37.60647712215301, 4.544535058159982, 0.2406086204873939, 0.22156588102300323, 1.0097727095407825, 9.734071531603414, 16.533323718655495, 17.180748178112893, 14.581449358694016, 14.25111714870699, 19.398815170411144, 31.789368775583085, 49.915635662694136, 56.640660916605306, 57.28179977786157, 60.280808710282855, 54.53334792967766, 53.45360571338285, 51.539944064232614, 49.950776177067915, 48.37048461360317, 51.8300151055859, 57.78421617323353, 56.4627069042575, 53.326536609280495, 54.655106144566695, 53.58345970030754, 57.113569321170935, 55.3885462207179, 54.87333113147367, 52.176332935210205, 43.61015496715423, 41.36111890116046, 42.85654214120681, 47.96680212020875, 51.96609781634424, 57.45782790645477, 60.062113038955204, 59.36896354921403, 54.104005290615945, 42.586400662699056, 42.13444948196411, 41.920484189064275, 41.532012647198094, 43.04440013823971, 47.124218171642674, 59.78123603328582, 54.82945942109632, 44.19021075771701, 55.0152934751203, 56.41188083156463, 58.33227326793056, 56.18036293214368, 59.36799864615164, 55.900580267752375, 58.69448846386325, 55.83672800371724, 59.47460866743519, 51.27145390356741, 52.69610581859466, 32.7519949020878, 42.59755588346913, 63.7178522540677, 52.41048274501678, 55.22804283326673, 49.27540286894768, 47.622849479798354, 42.396530489767756, 47.15846830798734, 49.39344659928353, 50.59271127946916, 48.00074631167997, 50.83506276530605, 45.8887186358052, 41.991228057492165, 42.357346011746316, 44.94992679165256, 42.536037429686516, 45.1312344304977, 42.04119120874713, 45.35955559822821, 47.18457952622445, 50.07581741579118, 49.50705020658432, 50.180921246928555, 50.04533667718211, 51.72255000760479, 49.7370619158591, 54.349388768596036, 49.6197908924472, 53.57927845370386, 52.80537128448487, 53.4879421418713, 49.50469286211076, 46.80298389927034, 43.10668737657609, 44.97500642653435, 46.63314527080905, 51.76597849015267, 48.6150679280681, 53.184068279881636, 51.94314802846601, 55.44345940313032, 59.23261411728398, 61.39671910193659, 54.764069587953635, 53.74678327191261, 53.7661244792323, 55.334484192632864, 45.916963623416045, 32.64200379771571, 18.389934493649392, 18.986764300254084, 18.401540786989276, 12.07634331718568, 18.253783141413045, 39.02983465502339, 28.78384674749067, 2.4710255476736256, 0.18828478461552053, 2.1768257214177043, 29.416515250359815, 60.47671148853918, 43.33158823751634, 26.470279847421956, 34.43793158377371, 60.96324228471326, 63.9465303574839, 67.33943939208984, 31.04267304943454, 2.7004116389059254, 0.2408526501347942, 0.07719154785116834, 0.1574141225747524, 0.11568762692472628, 0.20080592483282092, 0.17416924688844912, 0.12025489757258086, 0.12094706567304751, 0.18311438060575919, 0.07943442346708429, 0.09179142934660758, 0.10219144064091867, 0.2141230150816902, 0.1484169714873837, 0.1675083268914492, 0.13353097913486342, 0.12271865165882534, 0.1678180562392358], [0.03818441152332291, 0.08132559577784232, 0.0055569260110778194, 0.05795741281021507, 0.06695746354037715, 0.008388679050239585, 0.03293124320466192, 0.01833067606053045, 0.03399759929086413, 0.044327459913948854, 0.022127674028818167, 0.026932259563416727, 0.05423145992080531, 0.05728246636628624, 0.026802802195532188, 0.0906745344400406, 0.059457861127391945, 0.02631268020899546, 0.17792562112933208, 10.8044167295579, 35.03214713065855, 49.84011042502619, 46.65076063525292, 39.53227066224621, 21.403746451100996, 29.39886458458439, 40.513184839679354, 23.054430830863215, 1.980557917587219, 0.05463870460047357, 0.019882346931544524, 0.2608377696766008, 3.295358217531635, 4.820053615877706, 3.1228401199463875, 4.887157034489417, 4.67041225202622, 19.10534147293337, 38.13103137477752, 52.35905262731737, 60.18142369485671, 59.87727918932515, 54.74240241512176, 52.56265109585178, 53.42267390220396, 51.24338150024415, 51.54258774172876, 50.45026256192116, 52.79647927130423, 50.66283933577999, 52.43320895779518, 50.47201602689682, 48.720010942028416, 48.194703594330825, 52.332066720531834, 52.89224001669115, 53.687076953149614, 51.33343127466018, 48.18361113148351, 39.062527610409646, 39.807013080966094, 39.258045996389086, 40.76580116825719, 42.41427529242731, 45.763445977241766, 42.53706901304184, 40.626325607299805, 36.31622914345034, 41.27798818772839, 38.80028970779912, 40.3016161149548, 36.905553494730306, 44.12384033203126, 53.66582947392618, 52.79474558368806, 55.085480366983724, 55.9379957568261, 53.517705086738836, 54.286544553695194, 49.48838756930444, 50.71625417278659, 48.34056869629891, 49.248828811030236, 46.92003526995259, 52.14562862150131, 49.87628252275529, 57.39283815506966, 28.427430775857744, 33.64727589391893, 57.73334303209859, 50.275940664352916, 53.18967726922805, 46.12242129541213, 47.398980202213416, 41.40289214349563, 41.58061865837344, 38.78766359821443, 42.08431766879174, 40.831061563184186, 41.337898469740345, 39.84531894806893, 39.26026998027679, 38.83220211152108, 38.900737685541955, 39.4141367173964, 40.749048725251235, 39.20031655219294, 42.091009232305716, 37.76632155141523, 39.254323667095555, 39.789558533699285, 41.9726909360578, 41.13908137044599, 40.20007379593388, 39.7781797378294, 40.260442995256, 40.28811531682169, 40.373807337976274, 40.51516955898654, 41.75751363077472, 40.28399682814076, 40.175641352130526, 41.57744153853386, 44.90784760444395, 45.804630864051084, 50.09667265799738, 48.57187478773056, 48.93318391615345, 49.81727438588297, 49.36819438011416, 50.36610810987411, 53.191379577882834, 54.927522597774384, 55.4097270196484, 48.679288894899436, 48.29675974384431, 45.01389280442269, 31.30040414871708, 20.443707127724927, 11.513236088137473, 4.004826973522864, 17.52946649828265, 5.089532704122606, 30.194844891948087, 71.2183104791949, 4.574820658852977, 0.020445890784744295, 0.5814878846849165, 19.77523130755271, 40.623148487460234, 28.084188084448538, 25.808881944225682, 27.55639591524678, 36.81476239235171, 53.42286609834241, 55.660291948626124, 30.18241882324219, 2.143520631136433, 0.02124732026019164, 0.07081638631080428, 0.06476763951321764, 0.01564536455853452, 0.048234944997896115, 0.07976567222466392, 0.03436834754181966, 0.0746712641369912, 0.03033001847084492, 0.04260259380023326, 0.07520371056612461, 0.02553476963282353, 0.042523908909530415, 0.04369041183963419, 0.030219761181562662, 0.014520695774755893, 0.022942117422879226, 0.04108055329491054, 0.06752302028959797, 0.04922235955394084, 0.06098873845692124, 0.02314168907281372, 0.0710995783728938, 0.027508417054289774, 0.037557544757521925, 0.056188262984036445, 0.05970903071424654, 0.039158791093336004, 0.021956832591264, 0.024867725385833653, 0.11524826783927218, 0.031029464406592232, 0.047173116491326404, 0.05440027505579976, 0.021933905494910096, 0.04083430582296945, 0.1710630974341785, 12.352766471524394, 43.4797675378861, 54.989688242635424, 53.61657234930224, 44.66792014337356, 25.37167299178339, 29.275580567698327, 41.93793481396091, 26.383052218344908, 2.52103429648184, 0.025061026606107914, 0.21728170284580803, 1.5721587740605878, 5.587886014292318, 9.260761084095124, 11.562243161662934, 7.154919476278367, 7.129319637052475, 23.04095356695114, 40.43505514821699, 54.741198247478856, 59.2643343248675, 60.418511359922356, 55.82437646004462, 53.75807969800888, 54.2015193354699, 52.63397939743535, 52.14460880525651, 51.560281553576075, 50.650813348831676, 52.756945702337454, 53.56462055636991, 51.84295892715455, 49.94185670729607, 50.241372816024295, 54.8379631196299, 54.582652122743674, 54.6045664048964, 53.23224283033802, 50.26092583133329, 41.19604595245854, 41.35490978917768, 40.94580658020512, 42.13787371112455, 44.549040948191, 47.30363130569459, 45.19414532569147, 41.687597382453184, 39.32662079411168, 42.72735887958158, 40.39507835142074, 40.89327035411712, 38.712687492370605, 44.797393660391535, 54.14519802216561, 55.36273702498406, 55.48642504599787, 57.3478760257844, 55.88607926522532, 56.31348425342191, 51.36515932698404, 52.924564269281205, 51.345720060410045, 51.765339143814586, 48.7799173016702, 54.278150681526434, 52.279761914284, 58.60688232606458, 27.999345256436257, 34.3270932474444, 60.01255781419816, 51.463567672237275, 55.59055220696234, 49.409159614193825, 48.89906714039464, 43.109405579105506, 44.612304856700284, 42.319440226401056, 43.76090341998685, 42.88612073467624, 43.6408200571614, 42.07362528770201, 42.3341412698069, 41.01982955009707, 41.326594198903734, 40.24008981643185, 41.8084652193131, 41.67348861694336, 42.764825359467544, 39.908292601185465, 41.43878967531266, 41.58187773919875, 42.477241100803504, 42.150821455063365, 42.97298162214218, 41.93530682594546, 41.28533086469097, 43.858405697730284, 42.328732321339274, 43.567377598054954, 44.455253155000754, 41.44781897144933, 42.03149118731099, 42.94935326422415, 45.37304070688064, 49.1106358651192, 51.33312140741656, 50.9367698238742, 51.71619576792563, 53.22295858014015, 51.83241951850153, 51.803460659519324, 55.86013278653545, 57.61360876021847, 54.25351427447412, 52.67841592911751, 51.016225276454804, 45.448475730034616, 32.46349673117361, 21.933076189410304, 11.99376859972554, 7.3777189273988055, 7.033556930480465, 8.652978058784239, 32.094693914536506, 62.58280854071341, 6.222977071039139, 0.036076746595602845, 1.0752948613897448, 20.604100688811272, 45.283853853902514, 31.78158679316121, 24.938688432016683, 30.472578117924353, 43.790462401605424, 59.44283746903943, 62.824846236936516, 34.565863609313965, 2.7739406353042972, 0.07390317672322835, 0.04108003235512203, 0.09231076801135656, 0.028640497738735813, 0.016560800366043564, 0.08807637022748109, 0.011609183406577477, 0.07568214779659625, 0.026333745711693363, 0.02506256835805553, 0.035832368378197, 0.031413640263640595, 0.030081306111007452, 0.0467974691080951, 0.04691994358454982, 0.05386728853467972, 0.03778300443363767, 0.06402322804675468, 0.09549989244870602, 0.1338109076623955, 0.14673868734990397, 0.17144125375536182, 0.15591237573854386, 0.12074687923755377, 0.08827573694889584, 0.22592625430514737, 0.11763922825095155, 0.1793473883862457, 0.12827319513645866, 0.15392938779006082, 0.23535310410924498, 0.11372618902955325, 0.11001348946123354, 0.2126907830637309, 0.30558943928730103, 0.12040069942632992, 0.6587184953593439, 18.529023701144805, 50.108235805265366, 63.226751896642874, 59.61764966287921, 51.89005482581354, 31.003190471280007, 40.849029940943566, 51.94847068478985, 29.926244904918057, 3.3437565882359785, 0.2721517238645785, 0.3089967225828479, 1.9854584288212562, 8.822808842505179, 15.850065465896362, 16.098622141345857, 11.0917656460116, 8.62993315342934, 25.102974945499053, 41.813156374039195, 54.64264869689942, 63.19172513100409, 59.03321650720412, 56.9398553909794, 54.562753938859515, 54.86444696303337, 51.769351728500865, 53.70082878297376, 52.522948864967596, 52.15521489420245, 54.02393010354812, 56.3583993142651, 54.884572644387525, 52.75622398622575, 52.16982180072416, 56.58331194231587, 58.150953861974905, 56.81349231350807, 55.13580437629454, 53.28615973072668, 43.56210593254336, 44.133987503667036, 44.99548512120401, 44.79576587677003, 45.40332924935126, 49.312265303827104, 45.759986446749785, 45.27717405749906, 40.95850721482308, 43.672685392441295, 42.98251298166091, 43.83991956710816, 40.38270719589726, 46.644798632591005, 57.51331375491235, 58.218289190723056, 55.37216248050813, 59.06204985034082, 58.26771497726441, 59.352944589430294, 55.18652846736293, 54.76526983322636, 53.239212882134225, 52.369823455810554, 50.87380401549801, 55.87766185883553, 54.19615745544434, 58.99087844356414, 31.0166088996395, 37.22156317003312, 60.578881386787664, 53.42668648689024, 56.07924815147154, 51.667232821064616, 51.51386422495688, 46.05601949076499, 47.23105176802605, 44.3330438675419, 45.698071833579775, 44.63718052833311, 45.71835048737065, 45.44354923309819, 44.09248098250359, 42.949470935329316, 41.305789947509766, 43.566950059706166, 43.599415517622425, 44.159361316311745, 44.899924416695875, 42.216521155449655, 43.66101634117865, 44.63758061009069, 44.609927900375865, 44.745316351613695, 44.30062155569754, 45.10632737990349, 44.711889913005216, 45.70194713531002, 44.5445066882718, 44.06233756772934, 45.22796007894701, 43.98916182979461, 44.212395683411636, 47.115392838754964, 50.55442894658735, 52.51837930371685, 54.36353675780758, 54.2601470024355, 54.47974481890279, 55.56280536036338, 53.7197228400938, 54.305909295235914, 58.34443261546474, 59.84410378240771, 54.63389788904498, 52.49999907708938, 53.05803860387495, 46.64851703951436, 35.83080053329468, 27.425767260213053, 18.478578098358646, 12.483030346132095, 30.137474344622706, 11.316563544734834, 35.7964248811045, 76.07308295465286, 6.06050318287265, 0.23490204686118712, 1.1018413401419118, 25.110150921729304, 52.092202017384196, 38.277445608569735, 38.1357382189843, 37.981126231531945, 49.99716997146607, 65.20695655576645, 69.40035466224917, 41.36069528518185, 4.203319741833595, 0.23979129660273754, 0.11487268557351445, 0.22166142750891948, 0.06992054607478843, 0.11046268511563541, 0.20430665553337146, 0.11524196293565536, 0.26273209060872754, 0.13317962056927143, 0.257117432211676, 0.13772978447377682, 0.11818681257746874, 0.09995310026551447, 0.2397666592150927, 0.12058390935342159, 0.18416134700659784, 0.1201691953164916, 0.10362881310884992], [0.014986464783789651, 0.04817406016011392, 0.01471288329471023, 0.020534419905274146, 0.027564220813914176, 0.00932677956898847, 0.03107004408394137, 0.10226170622533369, 0.01848468080072874, 0.027642721843515194, 0.05094396979397824, 0.01683617067042618, 0.00897544015559458, 0.11470331119433527, 0.029953181736111164, 0.03041841161076821, 0.05783103511578614, 0.06669004522864858, 0.5991117680265058, 10.182566123624003, 31.87106586271717, 50.441064603867076, 43.8330554193066, 36.17974242856426, 20.307271403651086, 28.977139188397317, 35.969703428206905, 18.244796991348267, 0.6400857048649943, 0.014176512580184687, 0.0698166109261013, 1.3203758265702956, 6.3659994352248415, 7.5525821120508265, 9.120208832525439, 5.223211492261579, 10.022216689202095, 20.576251860587828, 42.08396073310606, 54.0961487831608, 65.26395643911054, 52.49486077216364, 49.60136751974783, 50.72613854562083, 55.610269961818574, 50.33439966940111, 53.4995327457305, 49.958620917412546, 53.62764520029868, 55.60776748964864, 53.84505825657999, 49.401848316192634, 47.98312702486592, 44.81001192523588, 50.500919972696614, 50.13602187556606, 51.859405425287065, 50.24496178473196, 51.99080482605965, 46.04011820208642, 39.21906940398678, 38.23554292801888, 36.879187322431996, 37.14983870906215, 36.879544258117676, 36.66358247880013, 39.311209801704656, 37.655349854500066, 41.43961337304885, 37.68993339230938, 39.559739020562944, 36.13148158596408, 40.945983086862874, 51.057351327711544, 55.07034394048876, 53.32485391247658, 54.404764790688795, 50.08155976572345, 50.19073501709969, 42.87072935412007, 46.304136860755186, 41.59910086662539, 46.721904585438395, 45.467891462387584, 51.561693606838105, 48.1117219309653, 59.70303181679019, 27.56458974653675, 33.3236175967801, 60.85055651203279, 49.42419798143449, 52.57007614258797, 45.86900088094896, 49.20442758067962, 43.89323634486045, 43.132390668315274, 38.938996484202725, 40.25541451669509, 38.70602338544784, 39.50535535812378, 39.386876244698804, 39.67746111654466, 39.1707379587235, 40.983563315483835, 41.1077965459516, 41.2412198897331, 43.234238932209635, 45.10380921825286, 39.49844021950999, 41.609652042388916, 39.1075760318387, 41.47853112989857, 39.15331871278825, 39.268177478544175, 38.45235193929365, 40.27142563173848, 38.68552115655715, 40.77726625627087, 39.10696414209182, 39.509120833489206, 41.25575227122153, 44.16387988675026, 46.640272217412154, 49.998821289308616, 50.080261461196415, 50.15673983481623, 48.39326573956398, 48.99217244117491, 46.22160234758931, 49.34393452059839, 50.78938284227925, 54.56057310104371, 56.17042364612703, 56.08756357623685, 50.76434243109919, 48.86867661629954, 51.478060830023985, 34.068130523927756, 25.174750397282263, 14.518740465564115, 6.509354710578919, 5.577958005089914, 8.139775635734681, 2.2186058279006713, 6.493759366773791, 1.0952240565130789, 0.05001105473286683, 0.03963299185758637, 10.550892372285167, 43.96602376814812, 43.970201092381636, 30.244829616238995, 26.792477061671597, 38.89641523361206, 48.87952589219617, 49.90347239278978, 37.201751278292754, 5.236748082022514, 0.15409535307797695, 0.11831626611491365, 0.044508563099248756, 0.0595897201809191, 0.013004399013645467, 0.03530406265429432, 0.026230919475276625, 0.039004803590116, 0.04867504335819714, 0.012574176484298323, 0.07962399192394749, 0.03058554901320848, 0.049206911390947725, 0.00849483585390713, 0.04775731599018459, 0.016165514318873326, 0.10158227816704782, 0.024210818397301822, 0.03760468980838214, 0.046388883774559346, 0.03537903584900402, 0.03538135326497498, 0.018735404141367446, 0.04641935875218722, 0.050809348993484056, 0.05985795437628704, 0.021074492739693775, 0.020033961477419062, 0.03634089371189475, 0.024315063811598286, 0.0253865756695309, 0.10456874936578736, 0.03866323562819631, 0.0330194199247466, 0.04784627028951242, 0.012422323493557352, 0.7136412998360973, 13.344092580579943, 37.91188463088005, 57.04405315460698, 49.71696761346633, 41.41204695547781, 25.32119797122094, 29.749977511744348, 39.80652278469455, 20.65987483147652, 0.9563408347387469, 0.03163671549109202, 0.05419444255230408, 1.3392966048371409, 7.714061679378633, 10.98576065032713, 8.9129380449172, 8.17640616047767, 11.02088547522022, 22.97601284519319, 42.90789381150277, 56.09589076811268, 62.13479934200164, 55.90679330210532, 51.67325365927912, 54.30341859017649, 56.04866935360817, 51.582635141188106, 53.72022882584603, 51.81051700345932, 53.07980383596113, 55.94474615589265, 55.08193062197778, 50.90070755250993, 49.97478500489266, 46.538114086274184, 52.05921488423502, 51.84424546457107, 53.67125411187449, 53.418174943616314, 55.15205083354827, 47.935521218084524, 40.987897534524244, 40.6415012574965, 39.856144689744525, 38.34327082480154, 38.65569937613703, 39.336081550967315, 40.55221634526407, 40.174197919907115, 42.74948496972361, 37.96265971276068, 39.617213510697894, 38.81287267131191, 44.52067044473464, 53.155529114507864, 55.70890188217164, 55.27930036667855, 56.393151513991825, 53.31890759929534, 51.06540003130513, 46.29376219164941, 47.32904041967085, 45.344219130854455, 48.72688293457032, 47.49390548275363, 53.67219155834567, 51.27326603858702, 60.18496167275214, 28.83330587417849, 34.566251923961026, 62.2406288116209, 49.85878875178676, 55.095211767381244, 48.41374835660381, 50.98250466008341, 43.961340458162375, 44.89875162801435, 41.254261770556056, 41.18952305086198, 40.21606922149658, 41.80630399334816, 40.423637128645375, 41.83497651930779, 39.22910674925774, 42.777698578373084, 42.9544327335973, 42.23792160710981, 43.766198619719475, 46.40279623769945, 40.18929512270036, 43.11939585593439, 41.027329121866536, 42.42637972677908, 41.18381992463143, 41.18605959799982, 39.44933998969294, 41.06159887006206, 41.22496558773903, 41.79794542251095, 42.077869292228456, 40.874097808714836, 43.30638308678904, 46.06333863350653, 49.51961355824625, 52.31961319523474, 52.28727325316399, 51.974146519937825, 50.97579348471857, 51.918146840987674, 48.51564368894024, 52.179486520828746, 53.78362609494118, 57.70667091492684, 56.48388770318801, 55.0308652847044, 51.44677208315942, 51.04468207205496, 51.33102686174455, 35.09734476766279, 22.72170989744125, 17.998005382476315, 9.025911131212789, 9.007369106815709, 8.166244279953743, 4.634623565981466, 11.036149378745787, 1.876744055940259, 0.09507665185317879, 0.21357097212345372, 12.619373894506886, 49.73408091452814, 42.989369284722116, 33.020304633725075, 29.285506125419374, 41.34496265842069, 55.872802042192035, 56.322929320796845, 43.75552192811043, 6.592996803022201, 0.11947567124039897, 0.10793812663084078, 0.04259821943818562, 0.05466101691126824, 0.025818601378329822, 0.03634313068863365, 0.08488646438044888, 0.038111008808857975, 0.04260255932627667, 0.029606844876862826, 0.051477009941252976, 0.06777268834412098, 0.02498991066409696, 0.07332036767395274, 0.11655012701427746, 0.02440547559320206, 0.04972256517278091, 0.06385640474036336, 0.06623845937992297, 0.20053693604084755, 0.2041705217092268, 0.10911135964335934, 0.13254644889985362, 0.12338165479201464, 0.13864136781663666, 0.1059608766809106, 0.1108045212083286, 0.11732658776905268, 0.15872229431425372, 0.13197681656287563, 0.09035120703159802, 0.3248711368970333, 0.13057925768436926, 0.08964194750954067, 0.15285285039534494, 0.1538649751173873, 1.1292486565728341, 15.499304571459371, 47.41487756852181, 64.05695292257494, 57.54284527993972, 47.655656183919604, 28.93758208520951, 40.82799034733927, 47.51512158301569, 25.17796870200865, 1.2342920586947472, 0.18272957464139308, 0.2437386412413851, 4.22110818086132, 14.034916104808932, 20.460600776057092, 18.02031386283136, 11.732635824911057, 13.977772074361003, 22.405874767611106, 45.766528960197206, 55.32609816520445, 62.590335569074085, 55.90693058506135, 55.03383844129501, 52.99602200908046, 59.338573025118926, 51.714873929177564, 55.224983384532315, 51.29172863498811, 52.29163885116578, 57.78950352822581, 58.69408445973551, 52.9112752791374, 51.84984268680696, 49.00819532332882, 55.880505577210464, 54.70414361646099, 55.53330913666756, 54.860179424285896, 57.5856932517021, 50.472549469240256, 43.95020484924317, 41.58576873040969, 40.78771152803975, 39.86428753022225, 40.0693255086099, 40.92107995863884, 42.306892564219815, 41.61133473919284, 45.71548323477469, 40.759286111400975, 41.90443385031916, 40.91243897714923, 45.00372209856587, 55.09074418775497, 59.25374392540225, 57.70550204861549, 59.22562053126674, 55.64441419416859, 53.11657997869676, 47.10762654581378, 50.081136149744836, 46.27216954385081, 50.084183831368726, 50.834784277023815, 54.20093097994405, 51.26067523033389, 61.68984174728394, 32.401935131319114, 37.126178972182736, 62.32080205794304, 55.13920114886377, 56.37319449455508, 49.729456440094985, 52.72053434002785, 46.417101121717884, 46.48973557256883, 43.386168018464126, 42.56975412368775, 42.32427650882352, 43.56731876250237, 43.64871578831827, 45.054854116132184, 42.45054544941072, 44.98467899137928, 44.17418003082276, 46.137106649337284, 46.941937784994806, 48.13131024760585, 42.935389626410704, 45.430758383966264, 44.14016131431826, 45.45461816172446, 43.97586891728063, 43.134779391750214, 42.19661512682515, 42.966674450905096, 43.481320796474336, 43.068385431843424, 44.09953732644358, 43.01424495635494, 44.952715596845074, 47.76474906552223, 52.29480812626501, 55.06140485886605, 54.92903271029073, 54.52264770384758, 53.247163526473514, 54.36092838164299, 50.47689153302101, 55.162868730483524, 56.784662892741544, 59.645792668865575, 59.92842297400198, 55.20172372941048, 53.450656091013265, 54.34518791014149, 55.70153174861785, 37.083409447823804, 31.059358812147575, 23.830485497751546, 10.898833082568261, 17.36374831968738, 17.07739176288728, 4.7689078700157905, 8.594675948542934, 2.421976798965085, 0.15033864175840733, 0.474016351565238, 14.628603112313057, 58.225510274210286, 55.396096783299605, 41.500845493808875, 37.39601058344687, 51.1406663925417, 63.99466960660873, 63.02050190587198, 50.871419214433246, 8.968045384653154, 0.3826891715007444, 0.20577978132472885, 0.12528757429531506, 0.1398931095196355, 0.11513615853243298, 0.11070542007444367, 0.2647770857138019, 0.1042488080659701, 0.1286699520724435, 0.10414535555267528, 0.17250867470377879, 0.13937998382795241, 0.15135694114911943, 0.1789147019266121, 0.22819453339663245, 0.10169355243804956, 0.17658634622010494, 0.21720825033562802], [0.025179134381394234, 0.04814522461064401, 0.048452693999053977, 0.10523094044577692, 0.024596068692663987, 0.0945445884680075, 0.026483682525013725, 0.035129272033490484, 0.016242827912191712, 0.04582277161159343, 0.031042750286419066, 0.04704630595722026, 0.06465386779558274, 0.04702722270702643, 0.08883591576088821, 0.01429564787089945, 0.06364061692429167, 0.11152292015932261, 0.6638702834325453, 7.93093393887243, 33.55246436211371, 43.38286146040886, 48.415132953274636, 30.253800076823083, 23.603931357783658, 28.863686592348163, 36.067935266802394, 11.770608290549248, 0.5774026135763815, 0.08669733535498382, 0.500744944738765, 1.5634991613126572, 4.5409152007872065, 8.832091131517965, 6.260068474277374, 8.9844810962677, 12.181881550819645, 32.89426711297805, 42.73983986146989, 63.969805702086425, 53.31345550475582, 45.280178593051055, 49.262592407964895, 57.204568309168664, 53.64261296487624, 53.29586367453299, 51.56378423013995, 54.895002226675714, 49.8355604756263, 52.50375278534428, 52.41340883316533, 51.58960911535448, 47.95362687879994, 45.730858925850164, 46.7633326591984, 50.8972127206864, 50.89912291496031, 51.931820223408366, 51.15914075605331, 50.75076318556263, 45.55850213573825, 37.96687626069592, 36.1547294739754, 37.535168432420306, 41.12518441292548, 38.48203643675774, 37.254664051917295, 37.874461297065984, 39.3111901898538, 39.70077960721908, 38.46398961159491, 38.48815533422655, 38.542695891472604, 42.703942329652854, 50.97795471068352, 50.380220797754106, 47.237154976014175, 42.32837146328342, 42.12658120739845, 39.25146818161011, 42.122831421513716, 42.809595292614354, 47.054862822255785, 45.07004545580956, 49.49766789713214, 48.28640076421922, 56.84402796529955, 31.36023206095542, 33.74033412625713, 58.540782543920706, 49.956836238984145, 53.07079415167532, 45.68091538644607, 48.37361858737085, 44.116305458930235, 45.22360232568557, 39.41021826959426, 39.73450806833083, 38.398411504683956, 39.744612093894716, 38.95125389099121, 41.543116877155924, 39.36049830528998, 40.50731697390157, 40.538590031285445, 40.341361491910874, 40.26094113626788, 40.99007444996988, 39.57063928727181, 39.49138779794016, 38.44085547231859, 38.993411525603264, 39.39248131167504, 38.25221300125122, 38.12982328476445, 38.49009690746185, 37.44260834109399, 37.6114232309403, 38.581668561504735, 44.750737067191835, 47.631121758491766, 51.559536303243334, 52.846442422559186, 51.23898844565115, 49.58689005144181, 48.97093672906199, 48.01994631367345, 49.133573885886904, 47.21019260344967, 47.37572839183193, 50.15379413481682, 52.29297245702436, 54.35606072025915, 55.269553276800345, 50.390720982705396, 52.701483388100904, 53.47583770751954, 41.50784300219628, 24.70262058319584, 15.275464711650727, 9.656004598063808, 3.1956008220872576, 4.747005845269849, 1.4211896879057733, 1.4394245416887346, 0.34149123055319636, 0.013030188406006464, 0.20823768249923186, 5.818896457072228, 31.564491448863862, 34.26530415011991, 30.366954572739143, 29.98158954804944, 32.68372212686847, 49.57078087714411, 51.67684262798679, 40.754755773851954, 7.986700236797334, 0.07185397579544975, 0.00974903861436272, 0.055917776490171114, 0.05983779094211998, 0.07159283174382103, 0.0378037347728687, 0.016438109469750238, 0.03274854655647951, 0.004993194466336601, 0.03418412637866793, 0.04061525064190069, 0.008625038242298029, 0.08531441641671043, 0.036462870231198694, 0.02460558158946374, 0.013638632672448314, 0.055812240217722235, 0.09782163681642664, 0.028830244311041413, 0.02322518882612067, 0.038725192989072496, 0.02951967556239857, 0.03392606200049481, 0.031954040600647854, 0.02802095477349095, 0.07875342492855365, 0.05088373230049207, 0.04692331820185627, 0.022355315140298298, 0.09634990530509142, 0.06493043319712724, 0.025936473581579425, 0.020382688530991157, 0.03453212947915158, 0.10203270722300777, 0.10327804443095961, 0.7170735575979756, 10.611694993511325, 40.46983872690509, 50.125690352532175, 54.23307480350618, 34.917660990068995, 25.969901123354514, 36.01024896867814, 42.085898383971184, 13.778147947403694, 0.6529901188708122, 0.08071476323229652, 1.392668295771845, 3.0391073226928715, 6.390459825915675, 10.730230000711257, 12.441536572671707, 12.336247409543684, 12.565406983898534, 32.91726789166851, 45.22252759625835, 63.300076684644154, 55.31867704083843, 48.80049405559417, 51.20342431529876, 56.61059987160468, 53.38627430700487, 52.12665611697782, 51.33134849609868, 55.34595320301672, 50.83367032389487, 52.154030338410415, 52.30750091614262, 52.826332430685724, 50.066074248283144, 47.65177303744901, 48.623422576535134, 52.92565468818911, 52.56700884911322, 53.46585135306082, 52.97166016794021, 53.757173630499075, 47.703520867132376, 39.69448812546269, 39.60508554212509, 39.59773894279234, 42.94473663453133, 40.365495835581136, 40.162309215914824, 39.31133531755017, 40.37643140362155, 41.119595035429924, 40.60366999718451, 39.071619664469075, 41.194347566173924, 44.076065863332445, 53.51734422868299, 53.89123632061867, 50.725197176779474, 45.98434602060626, 44.63204614577755, 41.326311788251324, 46.117353593149495, 45.53003749539776, 48.057679514731134, 47.67358141560709, 54.09332467663673, 50.18733039979012, 58.446363249132716, 32.38033463878016, 36.18398251072053, 62.10535803148824, 51.16513413767661, 54.85422134399415, 46.52904948880596, 50.45600491185343, 46.66085681607647, 47.23022414791969, 41.59899888500091, 42.14509479461178, 39.97920513153076, 42.04543913564375, 40.359580901361284, 43.592802401511904, 42.456468228370916, 41.96490503126576, 43.08014469762003, 42.34139373225551, 42.43134544741723, 42.45435799321821, 40.21355498221613, 41.176194837016446, 39.94107184871551, 40.30014522614018, 41.46237880952897, 41.603874391125096, 41.09738657551427, 39.759783821721236, 41.073095337037124, 39.75253920401297, 40.58957299878521, 47.17391460172592, 49.540104020026426, 54.44756177163894, 53.24690857241231, 55.21283580410866, 52.520952378549886, 50.99580149496756, 51.184608705582164, 51.66367523131832, 50.423100148477864, 49.25091943433208, 52.84997647808444, 54.590226219546416, 56.17132579126666, 55.38034454468758, 51.63914865063083, 53.76104500985915, 55.17700103021438, 41.33863587533274, 26.211589728632283, 17.161671730779833, 7.026203957296188, 8.997074846298464, 8.736510815158967, 7.123316449503745, 4.525434586309618, 0.8969209715723993, 0.026017125403027863, 0.09385141679236005, 6.459053254896595, 37.120934763262355, 42.99695907100555, 35.88910656590616, 36.051869238576586, 40.020539068406634, 56.75723375812654, 56.63247100768551, 46.228599855976725, 9.628652930259705, 0.049049388391957174, 0.04843909976883762, 0.03312270772913772, 0.006614395956163325, 0.03876885617031686, 0.018422417004682848, 0.03819895953300499, 0.03356607728487542, 0.008791419132913073, 0.05517821436026885, 0.022958645769845576, 0.013975313951021001, 0.03563354557920848, 0.10058840932024103, 0.014467418190061808, 0.005595878709197766, 0.01054392091088718, 0.06548698841323776, 0.13606550442355295, 0.09378979267973094, 0.1717688789170596, 0.2144144349280865, 0.14046526994676362, 0.19558558721215497, 0.12857532489203638, 0.1987869154301382, 0.23780225655965267, 0.22442587110544407, 0.1124217174947262, 0.1579096129224185, 0.20603737072838893, 0.16208719762582935, 0.2112940975254582, 0.09838688713047775, 0.1807902077393186, 0.23736321157024753, 0.7992627796146178, 14.644720131351104, 48.251275939326135, 58.773261424033876, 62.5252438360645, 42.32713199430897, 34.068491381983605, 41.053252066335375, 49.17209940571939, 16.982080128885087, 1.159544308339396, 0.28011051937937737, 0.9906172019339378, 3.2575458336261014, 11.976242469203088, 14.4967673478588, 13.154798996063972, 13.059633470350697, 16.194894756040267, 36.26904303027738, 46.2127770147016, 61.95895164243637, 56.84234134612545, 52.29545923971361, 51.84943476030904, 57.755010204930464, 53.256130064687426, 52.11800729074786, 51.05787300294446, 54.49199045858076, 50.913478789790986, 52.491624816771484, 54.70679513869747, 55.34986380607852, 52.21098707568262, 50.939009497242594, 51.05033420747327, 54.65577294749599, 54.18163291869625, 56.189898214032574, 55.01203006313693, 55.52391898247504, 51.35801669090025, 43.1602983320913, 41.063395315600985, 41.396408465600786, 44.85914353401431, 42.026992228723344, 40.60718051848873, 40.52932147056826, 42.82322552896316, 43.1231495641893, 42.26699813719719, 42.526733567637784, 42.720934037239324, 46.066919757473855, 55.35504133470597, 54.9419020068261, 52.20301289712229, 48.66929469570037, 46.19364761537122, 43.41953562152001, 46.62856394244779, 47.12483398375973, 50.74834308316631, 50.85126215411771, 54.9536612726027, 53.34657207612069, 60.916668061287176, 35.63413289285476, 39.007386930527225, 61.50837721363191, 54.72428890966601, 56.65935493284657, 48.71051880621141, 52.17843140325239, 47.652730095771055, 49.46798339966805, 43.77714987724058, 44.74954858902962, 40.76831148516747, 44.04396910821238, 42.19583457516086, 45.58968105623799, 45.13393302117625, 44.05295525827716, 45.607735726141165, 43.737761435970185, 46.172156949197095, 44.66174633272233, 43.546961661308046, 44.69836558065107, 41.924300655241936, 42.3206090927124, 42.25450931056854, 43.72309961626607, 43.65265777034145, 41.61984628246677, 42.382268751821215, 41.99043181634719, 43.19422683408184, 49.8577061776192, 51.97324437479819, 56.77812822403447, 56.22700383586269, 56.42383621584985, 55.12472368055775, 54.376715921586566, 53.59172021189044, 54.383011325713134, 53.26507306868031, 50.69395549835698, 55.7613871174474, 58.521492327413256, 58.38922216046242, 55.91600302726992, 52.47413104580295, 55.913218144447576, 56.76724364680629, 46.02156931354154, 28.36395113698898, 17.87235813756143, 20.066706557427686, 7.408784589459819, 11.830206744132504, 8.455301388617485, 4.865333947443194, 1.7031584607978023, 0.12071442775308125, 0.41075707022701546, 8.23364334721719, 43.63741543985183, 45.301665336855, 41.06723923836985, 42.38856023357761, 44.741590099949995, 63.14260921170635, 64.67068226106706, 56.700151505008826, 12.313188775893181, 0.4324821286624478, 0.1396349225673945, 0.14499292618805362, 0.13708904385566711, 0.08697272098112492, 0.17015759682943746, 0.1366843808923037, 0.10386936471707399, 0.06425308889799541, 0.19138275225075985, 0.13214910973704633, 0.08823763173554214, 0.12571735728171565, 0.2831795288910789, 0.13838469771848572, 0.07574076118368296, 0.1415353109158816, 0.22494388443808402], [0.01865579611471584, 0.05027672253368844, 0.044098142985134356, 0.06307304536382999, 0.034581748994007226, 0.030061481670746883, 0.04603226601536717, 0.05398016009900359, 0.1195381916758995, 0.09127229752559816, 0.05323545368868978, 0.021561747642173883, 0.04207408123259102, 0.07442177228269077, 0.044262147087964325, 0.034252024751396916, 0.06896683555697242, 0.06834087277492208, 0.19368657782193155, 8.95017114377791, 34.18055349780668, 43.57173535131639, 38.264274289531095, 27.130836402216268, 24.586791030822265, 28.275107491400938, 34.898641417103434, 7.392119909486464, 0.19772151695384135, 0.0529197488550938, 0.12180748200344464, 2.1102912916291148, 7.137108483622152, 11.062593998447543, 10.571873130336886, 10.927541890451986, 14.781878552129193, 33.506584398208126, 51.716890027446134, 63.58807671454645, 42.0897932975523, 46.31469980362923, 51.50448583787488, 55.1493836218311, 54.646602446033114, 56.81745390738211, 51.73710200094408, 49.68260765075684, 49.24780115004509, 49.18761630212107, 55.55428204997894, 49.15477821903844, 51.895251966291866, 45.85415863221692, 47.289926544312515, 48.77010353149907, 53.732752953806234, 49.393968274516446, 51.827618537410615, 49.8344700567184, 48.454607686688824, 45.36752585441836, 39.88508785924604, 37.04913185488793, 38.28485496582524, 38.00696288385699, 36.617078858037154, 36.077348955215946, 38.47217559814453, 38.99831448831866, 39.09658555061587, 39.38156535548549, 38.97276809138637, 38.26447040803971, 40.68062297759518, 37.96637811968404, 39.690130372201246, 39.4595459968813, 41.00404985489384, 40.529125352059644, 45.74888613916213, 43.96421555549868, 48.25296255850023, 45.87197403753958, 50.20414167834867, 47.908598069221746, 59.002869129180915, 33.740867568600564, 29.887042776230846, 60.03412692777572, 46.76373274095597, 51.1506841259618, 43.91274621409755, 45.20525740038964, 40.98073136421942, 40.66473345602713, 37.53899666570848, 40.433443054076164, 40.44259002131801, 43.28825781422277, 41.03242820309055, 42.04141478384695, 40.108380548415646, 42.68127887479721, 41.64048971668367, 41.01342039723551, 38.51718479587186, 40.75940770487632, 39.43995768024076, 40.032416005288404, 40.28693860576999, 43.3000563037011, 42.481893031827866, 40.87956167036488, 39.34999812033869, 41.34902623391921, 36.59908302368657, 37.25794315338135, 41.57619030244889, 49.712182321856105, 50.90575172055153, 52.59507733006632, 53.37632325387771, 49.52452828807216, 49.31246926707607, 49.19514725285192, 47.709565239567915, 44.11659571432298, 44.43149535886703, 44.73503974176223, 47.93053980796568, 54.67829127465525, 54.71374557864282, 54.740433385295255, 53.46087386531215, 54.01452818224507, 56.83999184639224, 48.272970568749216, 31.01985073858692, 27.120016544095932, 6.875859508591314, 12.145037747198536, 9.483255570934666, 6.659302019303845, 8.278986927001707, 0.39265269653931745, 0.04166891265119757, 0.025004688500156327, 3.7920442752299772, 28.083925285646995, 36.14138557064918, 38.05571402272871, 34.24100506690241, 28.91601101044686, 37.9224750303453, 48.89063404452417, 40.454886651808216, 11.252360228569279, 0.05698939176997351, 0.038439932489587415, 0.04202071554778565, 0.018431966290659, 0.07528048023701676, 0.07510761249690287, 0.06197443314557595, 0.038270638549640294, 0.02484996555252902, 0.04774950955423617, 0.03259137595793413, 0.053424451410049395, 0.1017855519368764, 0.04186618412213941, 0.029504991572109923, 0.13489145935783464, 0.0327163823549786, 0.0859762167918586, 0.034028591377840894, 0.02216875932419733, 0.0660271723304064, 0.06967172837786137, 0.041468615132954814, 0.01077072028326051, 0.02706569292762828, 0.04334487937270634, 0.06436869156576934, 0.019500369746838848, 0.07136312027972552, 0.05176689761180071, 0.02854396299939723, 0.05644160059971675, 0.052230488058299794, 0.0664707908647195, 0.07018129176069653, 0.05343645983826249, 0.3870950350838323, 11.262623110125142, 40.710738935778224, 52.201098780478205, 45.34699616893646, 32.39170558990971, 27.24151980492377, 33.774046897888184, 40.08763513257427, 9.24950093992295, 0.2659819888011102, 0.1094414669299318, 0.43363073960908, 5.613178928052226, 5.481866800015973, 4.222850693810371, 11.581199976705737, 9.561003811897772, 17.198853838828303, 34.05199389303885, 50.85709864093412, 61.51447649924987, 47.47496043482135, 48.612349725538685, 51.625945952630815, 55.089489029299834, 57.235425595314275, 56.73786117184547, 54.522286845791726, 51.69371274209792, 51.461190715912856, 51.91812330676664, 55.2129142515121, 52.48820450998122, 53.01524554529498, 47.85586572462513, 49.644913673400886, 51.28467621341829, 54.334052301222286, 51.76382903129824, 53.17507428507651, 51.8230450537897, 51.30090305882116, 46.55430955271567, 40.83340321817706, 38.26616094958398, 39.575048031345496, 40.20173295851677, 38.718661262143044, 39.338489886253114, 40.6181082417888, 40.602877678409705, 40.72480847758632, 41.72835865328389, 40.72577730301888, 38.905122895394605, 42.300993319480654, 40.50613241810953, 41.31185393179617, 41.19291197869086, 43.1116452524739, 41.866022079221665, 47.68274407232962, 46.6649047020943, 51.46311659966746, 47.24490557947467, 52.990958229188, 50.21555969792028, 60.1277264471977, 34.610523716095955, 32.61898929072965, 61.273513532453975, 48.40592715048021, 52.856138521625155, 46.191839402721776, 48.0963070161881, 42.729112179048606, 42.98308957007624, 39.241003297990375, 40.77929804402013, 41.75484249668737, 45.04419311400383, 42.58468266456358, 42.9487649086983, 41.31613716002434, 44.29769938991916, 42.489078813983554, 43.06682040614467, 40.94850909325385, 41.83604732636483, 40.408802724653675, 41.81055192024478, 40.59727261143346, 45.38224258730489, 45.28222214791083, 43.26380575856855, 41.38962668757285, 40.89821254053424, 39.45812217650875, 39.66018699830578, 43.44802771845172, 53.12524841677759, 54.11712954121252, 55.11390186125233, 54.365239066462365, 51.82059749480217, 51.647911225595784, 52.10855437863258, 51.09313511079358, 47.405707067058934, 46.950315967682876, 47.01160692399549, 51.61396703412456, 55.84416089519378, 56.243395420812796, 54.27084722826558, 53.87398573660082, 55.61427470176451, 59.44619109553676, 50.89824038167154, 31.137657165527347, 22.29693093607503, 13.896129900409331, 8.7391133077683, 9.538581582807726, 8.369716252050093, 3.63423187886515, 1.0132448038747235, 0.10328647905900594, 0.010576335048573393, 4.384100802483098, 32.63865997714381, 38.478871084028675, 36.45187647111955, 34.40394032386042, 34.80862302164878, 43.44723932204708, 55.34624738077964, 47.59216085557015, 14.870387815660047, 0.08504309871744725, 0.013768976787105204, 0.0593958041750856, 0.014913077391083203, 0.062046031722979206, 0.06610444761932859, 0.03639777574027258, 0.04299602591462674, 0.043104071125027635, 0.08157703349547041, 0.04900086821327287, 0.027572310702394576, 0.03407258780733232, 0.03594632778737334, 0.057313929597336444, 0.05009502563024721, 0.017120176700935248, 0.08262540949808975, 0.08343854288180029, 0.09477199400745093, 0.1512165325543573, 0.1368096975549575, 0.16581297431501651, 0.12844407870884866, 0.11690442735749869, 0.17812673453121416, 0.24275084747181785, 0.15308238565921783, 0.15321645104596693, 0.12396945873455656, 0.0884093656655281, 0.09082126326017803, 0.24977611888560558, 0.13579314484471275, 0.2643202828063119, 0.20737385707757167, 0.7210680626092419, 15.088850105962447, 50.49354591677266, 61.920018196105964, 53.750027072045114, 38.72347793271465, 35.13090064448696, 37.87873668055381, 46.746203668655895, 11.762737074205953, 0.44202795192118616, 0.25012802903450304, 0.3096853436962251, 4.858502159195562, 13.113734722137453, 16.462344508017264, 17.470652518733857, 15.691883140994658, 17.970227156915975, 35.7678190354378, 50.505571903720984, 63.086923322369984, 49.34702927066434, 50.910376194984686, 50.83840070232269, 54.99841159389865, 57.955329572000814, 57.09288274088214, 55.77517817097326, 52.25479995050738, 50.93245129431448, 51.268955353767645, 57.94605708891346, 53.62430334091187, 53.9351394099574, 50.35931456473566, 51.400739146817116, 53.49639092722247, 56.49240709120228, 52.41322448176723, 54.61907132979363, 53.4156136358938, 53.464415765577755, 50.55505652581492, 43.77116434035763, 40.510545084553385, 41.23712885764338, 43.05133488870437, 40.621454023545795, 40.06579929782499, 42.36728137539279, 42.138666029899355, 42.79151316611998, 43.48874976558071, 42.804029449339836, 42.07840273457189, 44.01829719543458, 41.897130397058305, 43.165460171238074, 42.75142654295891, 44.98138812280471, 44.14189500193442, 50.24936660643547, 49.51314164746193, 53.13410512862667, 49.421993609397646, 54.817504036811094, 53.29769542140346, 61.999332443360366, 38.070677864936094, 35.66009113865514, 62.65090873164516, 51.00364231294202, 55.67584806872953, 47.88231426669706, 49.06816051852319, 46.9430713499746, 43.1867233399422, 41.209711490138886, 41.998288323802335, 45.321473306225194, 47.08941890347389, 43.99972477266866, 44.49828547816123, 44.67551385202716, 47.428750991821296, 45.18881874699747, 45.236961918492476, 41.370697329121256, 43.45981444081953, 42.639082016483435, 43.30162525177003, 43.82321811491444, 48.02814014496342, 46.505632938877234, 46.11819690273654, 44.30903896208733, 44.48534557896276, 39.599080393391276, 40.371810851558564, 46.35967762239518, 55.73972386698569, 55.16048392941875, 55.79036951065064, 56.67261646639917, 53.45146802163894, 54.36143436739522, 53.91313883566088, 53.81066299253895, 49.2049257216915, 49.080853308400805, 50.19990944093274, 53.95159767520044, 59.73698385300175, 58.267303128396314, 55.158946360311205, 54.7810338389489, 59.19590857721145, 60.6476640701294, 53.80598360492338, 34.54544375019689, 33.435201183442146, 12.432048359224874, 18.397624300372218, 21.39905921874508, 15.629855759682195, 15.758955670941262, 2.361889274850969, 0.2056006546462736, 0.13604189359372662, 5.543001351817962, 38.46495843702747, 46.96025917606969, 48.84933933135002, 44.580674863630726, 42.572240906377, 50.70954691979193, 63.0652012363557, 55.529398533605764, 18.76220468551882, 0.43423119932413107, 0.2430336871334622, 0.1391246007575143, 0.07393702248772306, 0.21856499204952873, 0.19932495430111888, 0.20864472033516054, 0.11124120664692695, 0.1381170419195006, 0.1518102966609501, 0.20390000074140488, 0.23441335937428862, 0.1694051299484507, 0.20775752923180982, 0.25142838667717676, 0.1933521957647416, 0.1427804795844901, 0.18644386001171606], [0.014629256179285868, 0.007265008574787288, 0.029066714585848877, 0.04879304388117406, 0.02031861868266377, 0.04969613130895361, 0.028319014686970945, 0.0594872405992881, 0.024068981048560912, 0.025848137898250453, 0.043159428638436144, 0.028326665990114696, 0.017391205202007008, 0.0567463465455559, 0.057731164063537316, 0.006779235573635707, 0.04827585409305269, 0.0934926041912648, 0.7165053655062953, 10.69623677961288, 37.74392874010148, 45.466361738020375, 41.13592778482745, 22.823836649617842, 22.883711630298247, 36.948483836266306, 34.398558831984, 5.341997531152541, 0.26588972117150983, 0.579919059190058, 18.759511978395526, 6.819362669221817, 11.806212625195904, 11.080567279169637, 15.015098760204932, 18.285446474629065, 22.875884540619392, 41.61502176715482, 54.63921270062847, 45.41482571632632, 34.30563396023166, 55.5743920418524, 53.034778948753114, 56.77140920392929, 53.995053614339525, 54.35273455035303, 53.879990885334635, 51.157332543403875, 46.768706306334465, 47.94515848159791, 51.09948935047273, 51.850238846194365, 51.239466974812174, 49.941774337522446, 47.22127722155663, 51.325115849894864, 52.29958949550506, 52.78089177223944, 47.413920510199766, 51.07643365859986, 51.444453962387584, 51.0699107570033, 48.44255816551947, 48.63086331275202, 44.628904327269524, 40.57482880930747, 37.091450306677054, 36.74596009715911, 37.65070576821604, 35.71742834583406, 37.1225860811049, 38.145214665320616, 38.26341529046336, 38.22611355012463, 40.45269012451172, 38.71923785055838, 37.69804485382573, 37.33914798305881, 43.64280477646859, 46.35942659070415, 48.4954160259616, 45.950268468549176, 47.451771382362615, 43.69398778484714, 52.76037777623823, 46.55347408786897, 58.10769404134443, 37.11674959428849, 31.300551237598544, 60.127844118302875, 49.14048117976035, 52.412589057799316, 41.99990041794316, 41.05846881866455, 37.931971088532485, 40.341377181391564, 37.686034556358095, 39.172793280693796, 37.80645524301837, 39.27349621249784, 42.06181503111317, 40.31313611615089, 38.64923138772288, 42.24120070857387, 40.9587033333317, 42.731363619527514, 41.15804995259931, 40.99384777007565, 40.702466657084805, 44.27403965303975, 45.883109646458784, 51.03844942585115, 50.3654295398343, 48.676205911943995, 45.00300038245417, 42.63662661275556, 39.46848115613384, 44.29823675463277, 49.179904922362304, 52.39149847338277, 51.76244835699759, 52.02568254163189, 51.8209897318194, 53.95375497879521, 50.0848820132594, 45.64784588352327, 43.53099761470672, 42.32471189191265, 42.00422679224322, 42.97012221428656, 48.6048815327306, 53.43023230952602, 55.15833447056433, 52.33087431999945, 52.65817257665819, 55.218491861897135, 57.78281588708201, 53.961160413680545, 43.723978227184666, 26.272304096529563, 13.704545651712726, 14.104580340846894, 6.069514828343546, 5.230165364280825, 2.953965659103086, 1.214455652140802, 0.04361010667297148, 0.11992752521989808, 1.386659102093789, 21.625258384212373, 56.28337613997921, 78.62889935893398, 49.4253158569336, 26.270490000324866, 39.03284703531573, 50.55963000943584, 46.627198957627826, 14.246816269813047, 0.3741925516195836, 0.042605914791385015, 0.019159447213995363, 0.08473761349676118, 0.07505787040797934, 0.05334497744878454, 0.041817081716632655, 0.0759334322966395, 0.017666037329622818, 0.009075349512239619, 0.05166562844909007, 0.0683096470311284, 0.020609994479004416, 0.0890796542948773, 0.007952428366538257, 0.04453617290803983, 0.06056033059834473, 0.07611401454215089, 0.05411749285074973, 0.045701147492734656, 0.04380047569171556, 0.035433665578884464, 0.031796797223749666, 0.03166664271585403, 0.05691682409134604, 0.02224011275346481, 0.10027263553873186, 0.02484600487796049, 0.03315140155234164, 0.023474303382118384, 0.021567615875673872, 0.01525864433196764, 0.07511138931036958, 0.06149801455678479, 0.03336135943930957, 0.08569399766143292, 0.7951798374133726, 13.698325753211977, 45.720660763402144, 54.007142359210604, 46.31438993638562, 30.547471853994555, 24.198374402138498, 32.52289906624825, 38.562107701455396, 6.709833914233792, 0.12928053946985354, 0.6760142479212053, 9.175376968999064, 7.446647228733187, 11.263790015251407, 9.266204353301756, 17.19341939495456, 12.783912420272829, 21.159451430843724, 42.4182721876329, 54.59749829384589, 48.19367593334567, 38.729016319397964, 54.821920625625125, 52.67396011660176, 58.134676025759795, 55.7572490169156, 56.14504198874197, 54.46403572636267, 54.91766568153135, 48.42251877630911, 49.89218773380403, 51.8357966792199, 53.58142006781794, 53.78972145818896, 51.158454341273156, 50.31463876847298, 52.89334220270957, 52.88684675770422, 53.072967144750784, 49.6978303693956, 53.811655352192545, 53.59159469604493, 51.73657248097082, 50.61763009717388, 50.00727007465978, 44.52188245711788, 43.141820046209524, 39.35291244137672, 38.00254237267279, 39.67909674490652, 38.214821046398534, 38.957768947847434, 40.30404013972129, 39.61613878127068, 40.92637908074164, 40.36365624397032, 40.37903977978615, 39.647023524007494, 40.130361510861306, 45.23514193873252, 46.66596374204082, 51.4850151923395, 48.380459200951364, 49.843452284413004, 46.090218636297415, 54.31037295249201, 48.778595462922134, 59.487026891400745, 36.44285109735305, 33.617885574217766, 60.26235003625194, 51.26516242181101, 53.47815582829138, 43.27360776162917, 43.0593208343752, 39.59388717528313, 42.50843571078393, 39.875081892936464, 41.602391735199966, 41.21315140878001, 41.707334749160275, 42.960684991651966, 41.98440705576251, 41.844382362981, 44.027310802090554, 44.33930397033692, 45.0241772590145, 41.98674086601504, 42.03414663191765, 42.537947623960434, 47.0229386514233, 47.671361354089555, 51.6589605423712, 51.19497160757742, 51.85580468946888, 47.063013507473855, 43.48772602696573, 41.4144435236531, 44.970276048106534, 51.89373400903518, 54.9981644845778, 53.24137410809917, 52.449533862452355, 54.03428516080303, 54.61949886814241, 51.75678053209859, 49.087897885230284, 46.31447622852941, 44.815973927897794, 43.99880693804833, 46.39046430587769, 51.10336857457315, 55.441772783956225, 58.93687917340187, 53.750325172178215, 54.65416869809551, 55.975830939508256, 60.425987397470784, 53.90569025470365, 40.12152441086308, 22.85944392604213, 14.182831625784598, 8.409692068253795, 8.956374372205428, 11.346864834908517, 7.0338947446115565, 2.5145925389182184, 0.06593488937904758, 0.03509585144779375, 1.7313318651530052, 23.944895152122747, 44.968828693512954, 66.07686765732305, 55.117102515312936, 34.65951804191836, 44.62389938292965, 55.85748518666914, 51.21028061835997, 17.67106210031817, 0.2638555125844094, 0.05784645263526229, 0.028494866339549906, 0.09796701732181734, 0.027078176330354427, 0.05593240493908525, 0.05253306980575285, 0.024335899487918904, 0.030471242949246403, 0.037814762608538714, 0.015820601425554245, 0.02626913577137936, 0.02955258478440585, 0.02186544213233696, 0.0514652926264511, 0.04927677094876286, 0.07050926166196024, 0.05695612823230125, 0.11044051453110673, 0.14035843132484344, 0.1775314382487728, 0.17576382825932196, 0.07841093000024557, 0.10020888936255248, 0.1665271980868232, 0.15455581788574496, 0.1322652946316427, 0.10912028456767721, 0.16290453683224418, 0.14594489768628152, 0.0671790391507168, 0.07916565684060897, 0.1568164054544703, 0.20053250805264522, 0.15515310599678947, 0.24196565331470585, 1.3264108833766755, 18.226846264254664, 56.46766478015531, 61.78696747749083, 57.08963109600929, 36.79611936692269, 34.88810985319076, 46.91457140830256, 46.31664922160488, 7.871635056311085, 0.527600218211451, 0.648205440130926, 23.391050600236465, 16.607297658920288, 20.885109093881425, 18.619934435813658, 23.968682366032755, 26.676204281468546, 24.04998721614961, 44.355840682983406, 53.77030180346582, 50.378098795490885, 41.54883177049699, 56.28577663052467, 53.65654914609848, 60.97966917099492, 58.76389088169221, 58.31688188737439, 57.22098735070998, 55.63547903491605, 51.5459256787454, 51.449356925102975, 53.21160331849129, 55.71141219908192, 55.78709040918658, 54.93924263984927, 52.60024309158326, 55.07170500293855, 54.11841607862904, 54.19202327728272, 49.68170942798738, 54.690332951084265, 57.12670533887802, 54.21173710976878, 52.43991228841966, 54.63188963551676, 48.0940830323004, 46.49646243741436, 41.77093205913421, 39.54306502496043, 41.62857747847035, 39.13425991612096, 40.531549376826135, 42.98039097939768, 40.962186398044715, 42.44654463183495, 44.32553252866192, 42.28974396182645, 41.00470489071262, 42.86387305105887, 47.78047384754304, 50.57406040929979, 51.67424601893271, 50.53483278520646, 52.000136144699596, 48.66234425575503, 56.5876304718756, 52.63078658811508, 60.59021311421549, 40.29954118113364, 37.555729496863584, 62.322614192962654, 54.10535066358505, 55.32414874722881, 44.813993130960775, 45.027625022395966, 42.320385517612586, 43.72738676686441, 41.81160311545096, 43.23585494872063, 42.676615176662324, 42.80910107397264, 44.58175743779829, 43.87391474939162, 43.42859237424789, 45.91787753566619, 45.673592321334354, 46.76133617278069, 45.34538407479563, 43.32644208785027, 44.50080756218203, 49.6477024785934, 50.68798172858454, 54.95686192666331, 53.67692193677349, 54.176596595395, 49.697598949555434, 45.18594364966116, 44.879328050921046, 48.53749913554038, 55.32735724602976, 57.2345156054343, 56.730765604203754, 54.52463634552495, 55.1606329794853, 58.00856397997949, 54.824599604452814, 51.04571757778045, 48.2320406360011, 46.70998450248472, 46.41089985447545, 48.47871065139771, 52.068067673713934, 58.54142973499914, 58.88307209937804, 53.20450775084957, 53.74648909414969, 57.95748687559559, 62.49029159545899, 57.68075581519835, 46.376555581246656, 26.50195102537832, 18.48341045841094, 25.789423065800822, 12.187254217363174, 13.85084221439977, 9.71641988523545, 3.028434063157728, 0.1656500733787975, 0.22636683147040107, 2.064633677082677, 29.77205261107414, 68.073424677695, 82.87239397725752, 59.9579191976978, 38.67048278931649, 51.09723398762365, 63.174921697185894, 60.383645411460634, 22.778450904353974, 0.7232310046111384, 0.15076608817663886, 0.11548178676035135, 0.21621855666800854, 0.2485895865867215, 0.11970143735168443, 0.14206503007200458, 0.12588942062950906, 0.1468548416009834, 0.10746443148462043, 0.1359144012413679, 0.24188440202945666, 0.10006453541498031, 0.20895282557654768, 0.1404838858833236, 0.23258691383225305, 0.1513849799671481, 0.10680299117079667], [0.11488708036561167, 0.07430027839877913, 0.015242100663242802, 0.052713866555883046, 0.03557379838199385, 0.07959252103201805, 0.007237102385730513, 0.019014932387959094, 0.037355910415851304, 0.020167536567896605, 0.016194129618065014, 0.03431851352234522, 0.037907551177927566, 0.028583203938098687, 0.06498311706368001, 0.0686811383873705, 0.036781853921110594, 0.10500794757277736, 1.219493936627142, 15.208731466724029, 38.79872075973019, 48.740085632570334, 36.63113271036456, 21.703091936726725, 18.39034830370257, 32.21650508142287, 29.88554050845485, 4.139274791363747, 0.027270359062259237, 0.4530557263041697, 9.212259015729352, 12.44313003555421, 7.148533857637837, 3.045002399913727, 11.917890348742086, 10.092298657663408, 28.471345632306992, 48.57143548227126, 53.84538381330429, 32.94040987568517, 44.696557368001635, 57.567007080201186, 56.463911071900405, 53.32733285042548, 51.31113260023056, 48.33106871574156, 50.87457280005179, 48.487159436748875, 49.889179275881865, 49.6369630290616, 45.20698716563564, 52.899712131869414, 51.34938355415098, 49.640179372602894, 49.524826388205256, 52.953570196705485, 52.53732435164913, 50.250892408432506, 49.97739730342742, 48.45359571518437, 49.94357862780171, 51.50601163987191, 52.45211085965557, 51.66163559882872, 51.9269839409859, 47.41050412577968, 41.61415100097656, 38.10178226040256, 36.024804884387606, 37.46935106092884, 37.806447398278024, 37.20060594620244, 37.618754140792355, 36.697499213680146, 37.89228454712899, 36.66242930196947, 37.9218945195598, 42.4385900651255, 46.32823198072372, 46.475928829562285, 49.56079844505557, 47.21140461583292, 47.96275815656109, 41.850709146068944, 49.52148452881844, 46.81537074427451, 57.99529067931637, 40.90705748527281, 32.37926383172312, 60.57939129491007, 48.507728345932506, 52.87139261922529, 44.41584510187949, 42.50452510772213, 39.26675365817162, 37.95949043766145, 36.97097862920454, 38.728569169198316, 38.18996890898674, 39.499993478098226, 38.33091928112892, 38.836199006726666, 38.15975489154939, 42.82321768422281, 41.81056368735529, 44.27687944904451, 45.189756193468654, 47.5853673104317, 48.170992866639175, 53.385976206871774, 53.07452824807937, 54.551700699713926, 53.385066216991795, 53.70835188896426, 49.12983194474251, 49.46504554440899, 48.02586124789331, 49.358098199290616, 49.839169056184836, 52.8620966019169, 49.4153412695854, 51.50199905518563, 53.1832367374051, 51.16156870318998, 45.82492912969282, 45.184143281752064, 40.15247583389282, 41.74962966672836, 42.91510705024966, 45.40416471419796, 53.00531802638885, 54.04029423190702, 56.957003993372766, 52.46608234220936, 53.94211338412378, 53.519705495526715, 57.83050014126686, 61.539512988059755, 43.448423877839126, 30.055867472002586, 27.448044361606723, 3.298786369062239, 7.199322667814071, 9.270965130098405, 1.2482569222488713, 1.3619201005466524, 0.0862860533919546, 0.06578287455223261, 0.7109796039519772, 17.885260774243264, 64.74639185013311, 68.22722081215151, 21.956798684212472, 24.637534733741518, 42.20053357462729, 50.76112608755789, 50.98285375102874, 10.869296654578179, 0.009562660913704144, 0.049018449931135105, 0.03337363216785654, 0.02833976226318027, 0.023573689883755102, 0.005034824162946954, 0.03276887086911067, 0.06111170706008712, 0.09948181829625562, 0.037445761038050536, 0.04740775007033541, 0.06303239673856767, 0.04962071761368744, 0.09001602058208759, 0.013748457122053352, 0.07519683875744382, 0.02186203304107391, 0.054022053617142865, 0.045324013898930246, 0.017828365615118417, 0.10147430573499973, 0.06095775020038409, 0.048402285413636316, 0.051758999245301376, 0.028628276721123728, 0.031089018166605985, 0.05683230161066017, 0.020607445321436373, 0.004583197136995413, 0.08070665036117838, 0.018302744494811184, 0.06978529325175671, 0.07221813569025648, 0.027650290792207086, 0.06556922029103003, 0.0794093340875641, 1.6446373106971865, 18.792814862343576, 46.9399687551683, 55.96552295069541, 45.80310506205405, 24.35729903559531, 23.809436098221813, 36.900956476888354, 33.61421815810665, 5.243657827377319, 0.08255329764177723, 0.658636493307929, 13.8345584946294, 12.973280529822073, 9.647854893438279, 8.443109681529384, 12.261376227101973, 11.056272118322312, 26.395827377996138, 46.28280701175813, 52.93820627274052, 37.79311918443249, 46.96635846168765, 56.76205827343849, 56.95821208338584, 55.51111244386243, 55.07983215393559, 51.39019581579393, 51.972648174532004, 50.87572989925262, 51.63149610642464, 51.150452706121634, 47.79546906871181, 53.91473131795084, 52.61217494164744, 52.19923173227618, 51.576508398978945, 56.042436707404356, 53.025953615865404, 49.33564655242428, 49.76349476845034, 48.3513669813833, 52.11251989487679, 55.13590635791902, 54.97201404263897, 53.52147056210426, 53.06341225101102, 48.38310680081768, 43.42315989155924, 39.54104892669186, 37.535227267972886, 40.13789246159215, 39.25619856003792, 39.37992972712363, 38.8856993183013, 38.37875258538031, 40.692178280122825, 38.06895202206027, 39.757022473119925, 44.09703877664382, 47.602315871946274, 49.33389325295725, 52.021411080514234, 47.18401470491963, 51.016821476721, 44.52405937256352, 51.167852340206025, 49.585713340390114, 59.30648019236904, 41.48771732084213, 35.70239782333374, 61.38532461658601, 50.46053524940245, 53.68845762745027, 46.09643559302054, 43.7723724303707, 39.490085571042954, 40.025049794104795, 38.70206963631415, 40.449732657401796, 39.52868561590872, 41.2487155391324, 39.650859602036014, 39.9777263979758, 40.20090141604024, 45.1721094500634, 44.5015763467358, 46.848342187943004, 46.44698566006076, 48.992548988711455, 49.716908777913744, 54.455626164713216, 54.94309048498831, 56.981609021463704, 54.233259154904275, 54.86760447102209, 50.26664072467435, 51.19980788999989, 49.11928076897898, 51.89514213992704, 51.80539831038445, 56.50324459998839, 50.56829452514649, 52.35220416899651, 54.59673735403246, 53.223954862163914, 47.80934641438146, 46.769278972379624, 42.69677223697786, 43.7300657456921, 43.94666687134774, 47.45101044254918, 55.517541208574855, 56.235817401639885, 58.42259368588848, 53.132030194805516, 53.71720860081335, 56.856881572354226, 59.80976343154908, 61.119336928090746, 45.414190292358406, 25.990366089728575, 16.510695565131403, 7.1467805581708115, 4.292084940018193, 8.116717982676722, 5.04785506956039, 2.8772306153851175, 0.41011704973155455, 0.13453328260971656, 0.784575954800652, 18.96431657575792, 62.438904623831476, 72.82991040137507, 30.58258491177713, 27.143497813132505, 47.268051485861506, 57.07348662038004, 59.64307446633617, 14.148026474060552, 0.2596299248116632, 0.030268317749423367, 0.03749748346425834, 0.038617174591748946, 0.020369421803362427, 0.032566773044245864, 0.10935059358035365, 0.02907305970908173, 0.06330442689960042, 0.08572123974802033, 0.07385237743296931, 0.012849120652273059, 0.04363703083307032, 0.05771250599214147, 0.044065358252414775, 0.08686975110322238, 0.04475403299194671, 0.06665174849331379, 0.1776695179362451, 0.09271076549926112, 0.15891205429309802, 0.1626618401778321, 0.2516170588111685, 0.3195736695441508, 0.14214363069303576, 0.09032275452609025, 0.10636683433286606, 0.15656359643945772, 0.16044735578039002, 0.13913920239335106, 0.09972490565550905, 0.1748178016033865, 0.14995637920594987, 0.15773068542682356, 0.2694199462571452, 0.21800321977465384, 2.5080703727660643, 24.37447117220971, 55.02444436473232, 65.09332156950428, 51.879711535669145, 31.69196651827905, 26.723688494774606, 43.18172624034267, 41.04513668244885, 6.319056999298835, 0.20161469917624228, 1.0146856007556762, 11.52936879665621, 21.78178841067899, 12.924599013020917, 7.629070781892346, 19.538118147080947, 12.733328553938097, 32.8431115611907, 48.54053112768358, 55.45048436810894, 40.375199779387444, 49.750264613859116, 57.43967909966746, 60.55868510277041, 59.39802438982072, 56.90597003506076, 54.147912302324855, 54.17539635012227, 53.40651765946419, 53.12782933635097, 55.345945358276374, 49.78977857097503, 54.88774584185693, 54.932833486987704, 53.541258919623594, 54.681064390367084, 57.41620763655632, 55.66292778138192, 50.80428392656388, 50.398440207204516, 48.75284902511105, 51.58642807314473, 54.9642163707364, 57.42781785226638, 56.554215800377634, 56.27110696608021, 51.878013149384536, 47.12844256431826, 43.28837156295777, 39.723611723992136, 40.6823056743991, 40.36180096287882, 39.936106128077355, 40.907386964367284, 39.89060271170832, 41.44462223975889, 41.21745424885904, 40.556632934078095, 47.23655485337781, 49.9682621032961, 51.256368467884684, 53.95101324204476, 50.90916810497161, 53.86188130224905, 46.14728912230461, 52.76986206731489, 52.624106791711625, 61.86875674032397, 44.13606635985836, 39.25311165471231, 63.27584035934941, 54.12080480206398, 57.100398002132295, 48.80240424986809, 46.65670302606399, 43.03478248657719, 41.4354831172574, 41.680803837314734, 41.66911517420123, 42.98274832387125, 43.74728887311874, 42.4901770776318, 41.72477360694639, 43.17614862995763, 47.99448620888495, 46.35155047139814, 48.39041809881888, 49.82256566324542, 51.70860990401238, 52.64049837666174, 57.789240729424264, 58.25828167699999, 59.50226529952019, 56.68477973630352, 57.84827632288779, 54.24921927913543, 53.876174419156975, 51.70969640055011, 53.90669045909759, 54.15786335545202, 57.66578805062079, 51.56763599764917, 54.094783798340835, 56.43806657483501, 56.460898691608065, 49.96020163259199, 48.47611011997346, 45.70973304010207, 47.126285260723485, 46.553376028614665, 50.91827192614156, 58.4370711541945, 60.09622981471401, 61.05694770812989, 52.40045716685634, 54.44900520386235, 61.14074914686142, 61.71507827697262, 65.52921848912393, 49.111714516916585, 38.12227664455291, 36.90240775385211, 11.349255519528544, 16.72450592440944, 20.37513036881724, 8.885811913398005, 4.411272531555546, 0.4837455149860152, 0.3393743764008245, 1.4028781027563157, 24.338314763961304, 70.62018825161842, 70.5798113730646, 31.480187946750274, 34.81434183736002, 55.22030399691675, 64.30357979189965, 65.90717807892831, 19.623335561444684, 0.6999946998492365, 0.11474386022816743, 0.17928933424334373, 0.13245465624476635, 0.08153758762824921, 0.08454548630623088, 0.2653654105961323, 0.1770609376891967, 0.19276434585692423, 0.16677927165742845, 0.1542524470677299, 0.25058922928667837, 0.1608782649160393, 0.15147691051806175, 0.14867362626377614, 0.23370088228294927, 0.09337446577246152, 0.22761095825943256], [0.05019844366958545, 0.05200083022035899, 0.030510558581520474, 0.013109094504597447, 0.019308587295874473, 0.059837143597823966, 0.015049357729543363, 0.06948070435394203, 0.056816991343493425, 0.03970447552180098, 0.07325958625804033, 0.04716840505059208, 0.03739899520071284, 0.027245549304831414, 0.06993984382960104, 0.048853852110163826, 0.03056539707036028, 0.028059510063500177, 1.0941906345467414, 12.405323290055799, 45.27673082966959, 45.08228325074719, 34.48054421332575, 25.51225858349954, 27.559778959520404, 33.03160890456169, 25.960707087670606, 2.2317666055694705, 0.3958071708198517, 0.2697380872503404, 0.6415991881682027, 3.4664674487806137, 3.201887155732801, 8.178089837874136, 14.598897041813022, 20.487567070991766, 28.05344650822301, 56.5063746513859, 38.104837786766794, 35.432966293827185, 51.51032624706146, 55.7904597251646, 52.08858951445549, 50.4520982311618, 46.517627546864176, 45.29836270116991, 46.97705476514755, 50.14495311244842, 51.96811391461281, 49.26689524804392, 50.617963498638524, 49.41845955387239, 51.47962585572274, 49.70161937898206, 50.84047563614384, 49.68991110401769, 51.874486938599624, 52.51245260238648, 54.216655761964866, 52.20569579832016, 50.42362574608096, 51.28478996215328, 51.128965962317686, 53.55483032041981, 53.34008839822585, 49.663599844901796, 44.35838630122524, 39.67840640775619, 38.362706169005364, 36.759880588900664, 39.56550098234607, 38.76452161419777, 37.872158865774836, 37.09964021559685, 37.72543868710918, 37.54311515438942, 41.558218002319336, 43.6076093489124, 46.91435175557291, 46.681951322863185, 47.60270026422317, 45.15580415725709, 43.91128709239345, 43.62343611255769, 47.2414578160932, 47.31848139916697, 55.868432521820075, 43.4603988739752, 33.28484496762676, 57.43696481950822, 50.42652830000847, 50.52552892315773, 43.602341605770974, 41.02627400429019, 41.75609765514251, 42.45489928030199, 43.0883228394293, 42.026294046832675, 38.45276378816174, 40.061935763205256, 37.614239492724025, 38.6739383974383, 37.64896031348936, 42.7183021268537, 45.449848559594926, 48.293527710822325, 50.97246339244228, 52.69679615574499, 51.855569347258545, 52.85108650884321, 54.703916118990996, 54.31976702905471, 54.087350906864295, 53.922995751903905, 52.285661159023164, 51.274964424871634, 51.821554553124216, 52.86593267994543, 53.45617094347554, 51.85189408640708, 49.05501665607576, 52.140925699664706, 54.21833845876879, 50.67664215641637, 47.588760160630756, 43.086051787099535, 40.84544489460607, 40.247946323887, 41.20556946723692, 49.14589797296832, 53.59869418605682, 55.58617484185004, 53.70822637311874, 54.562702948047274, 55.949625584387014, 51.54652187901159, 55.51865908407397, 53.83737041104225, 50.56594894778345, 24.870398006131573, 16.181694019225336, 7.206048061770778, 4.103920998111848, 11.349943895493785, 7.95594395168366, 3.7808983700890697, 0.05814306272734558, 0.08860130133407731, 0.2383148000245133, 13.392744679604808, 38.97382713133289, 36.755950373988, 29.81312963270372, 35.0174186306615, 47.03214445421773, 51.86904268880045, 46.368997173924605, 17.445406183119744, 0.20666530235640465, 0.06696782870999268, 0.066821881299538, 0.10897843572761744, 0.033638066567120053, 0.04887052601383579, 0.051460401155054576, 0.04653252526036194, 0.09124818107774181, 0.05237613286402437, 0.03336961020625407, 0.04756423118974894, 0.012524696780488858, 0.03804734307191065, 0.013697171365962395, 0.08633517494965946, 0.059919283545065316, 0.02238151151686907, 0.043334330341989, 0.07054895267731721, 0.00786741846241057, 0.01497037310694014, 0.03616275145642219, 0.08520560128794563, 0.03094036455055879, 0.013294305836391306, 0.06413080977396139, 0.07552429537979827, 0.054458934408161914, 0.028516360851485404, 0.07149438178467174, 0.03938133197446023, 0.038116719994333484, 0.013406389287763066, 0.03386715366955727, 0.026913764285704782, 1.3495191595246716, 16.891951907065607, 52.074786693819114, 53.406902051741085, 39.80209835114018, 28.683312477604037, 25.05781081414992, 33.59988581749701, 28.76852204722743, 2.93709873191772, 0.25409398960971064, 0.5166596246342505, 0.7761727057157025, 3.8718696563474597, 7.746192264941431, 7.545279639382517, 9.642622451628409, 13.897589022113433, 29.58766591164374, 54.014434045360936, 42.066890578116144, 38.349472092043975, 53.34122980794599, 55.104731359789454, 55.75612329667615, 53.48126234546785, 50.59363695882982, 46.43698361612136, 50.43964862823487, 50.83159931244389, 53.09597184581142, 51.539406699519006, 51.55886950031404, 50.50775666390696, 52.97736721654093, 52.766873221243586, 52.8134278328188, 52.41305974221999, 54.772286953464636, 53.009832674457186, 55.05866704448577, 52.38433230307795, 51.43900186784806, 51.20784090411279, 52.77571032124182, 54.89772042920513, 55.32390556027813, 52.03421761912685, 45.506566032286614, 39.640316271012836, 39.22257600292083, 38.76082674149544, 40.22537308354532, 38.936909783271055, 39.71352731027911, 38.45818058136971, 40.679379586250555, 39.54530469832882, 42.76138936319659, 45.878900943263886, 48.54754824792185, 48.43635689827704, 49.94191162047848, 47.31040916135235, 45.721802173122285, 45.40489819742019, 50.14819299021075, 50.409458145018554, 56.939976984454745, 43.89588786709694, 36.11195602724629, 59.27202609277541, 53.28565766734462, 52.97608067912441, 45.74503437165291, 42.748814244424146, 43.424697460666785, 43.9687458930477, 43.990134577597345, 42.5751591497852, 39.40790407119259, 41.50605832376788, 39.31398291741648, 40.20762435851559, 40.15506852057673, 44.312255305628625, 47.073137144888605, 51.3919295034101, 53.87573903606784, 54.94665984184512, 54.479211376559356, 54.919979879933024, 58.28743665449081, 55.06708445087556, 56.17113751749839, 54.51946273926766, 53.79019998734998, 54.239334906301195, 54.525424741929584, 55.374864993556855, 57.387966571315644, 52.878872579143895, 50.105093986757346, 53.39001624814926, 55.10862235100039, 51.9641052522967, 50.15090727037, 45.070449459937315, 42.58760090797178, 41.19540268375028, 43.03637889123733, 50.52873349958851, 56.639570497697406, 56.87180619085989, 55.18042133700464, 52.35943701959426, 55.43297883002989, 54.037321075316406, 58.48839536789925, 57.06978782530754, 52.4493298992034, 33.325825891187115, 24.38840343106178, 9.573731903106937, 12.805749235614655, 10.764216357661832, 5.853317216519387, 2.8465464038233605, 0.20452597118433447, 0.09757049787308901, 0.34810391765448356, 14.89239231232674, 51.44300268542383, 48.13318514054822, 30.206133473304014, 39.185364477096066, 51.87106663180936, 58.99698557392244, 54.82243837848787, 21.1021436414411, 0.35518897456988213, 0.0580382427471059, 0.05268952794252865, 0.04907515192885072, 0.06680636035819208, 0.07722493396290848, 0.016026516283501782, 0.04384657886299876, 0.048950716267309846, 0.06739292323829667, 0.030669085155691833, 0.03305534944839535, 0.014616004773415627, 0.05121650557304102, 0.01710963533109715, 0.03474933072744358, 0.021315733827049696, 0.04199150078479321, 0.12557162437587976, 0.1838294011090071, 0.12948598892938706, 0.11484116871630955, 0.1250515885711197, 0.16820882236765278, 0.17992350182706313, 0.2674455538151726, 0.2552456802297985, 0.1062004860009878, 0.12134528583696774, 0.20539339721923877, 0.24092979518876922, 0.10818832328603153, 0.21184313741903152, 0.16752386315455361, 0.11149875008531156, 0.21657281104595433, 1.8875895320407807, 23.623417692799723, 61.06320388855473, 59.846002209571104, 48.118366426037205, 36.45479471452775, 38.80382768569454, 43.966208119546216, 36.730843282515, 3.245186200064998, 0.881284871889699, 0.43231643916618445, 1.1143565201951613, 6.598673453254085, 8.103536857712655, 18.37588260250707, 22.248811298801055, 26.11906493863752, 29.90318529067501, 58.308962621996486, 43.87759001024308, 42.78759864068801, 52.39572286605836, 57.771323342477125, 56.370456680174804, 57.38200064628356, 51.15573613874374, 49.87580399359427, 50.7179957051431, 55.110665905860166, 55.54532335650537, 53.22285659851567, 53.348890196892526, 51.55909307541386, 53.617741215613584, 53.613375617611794, 54.08252639155234, 53.07001360001103, 55.925432405164166, 56.07895397370862, 56.52936758533601, 55.039125796287294, 50.99686445728425, 54.23068215770107, 53.06305139295517, 55.877559877211056, 56.04515490993377, 52.89098093586584, 47.83925840931554, 41.39949929329657, 39.825322704930464, 41.079320138500584, 42.84765797276651, 41.836674905592396, 41.493161570641306, 40.494447677366196, 43.87590339106899, 41.706656179120465, 44.62242457174486, 48.551396093060895, 50.31783550016342, 50.680548837108, 52.012977984643754, 49.9956637813199, 47.40584827238514, 48.32116473105646, 52.09709321298907, 54.61446254484115, 58.406304082562855, 46.696338576655236, 39.195025274830485, 60.92955304730324, 56.27911644597208, 54.90370988845826, 48.15977881031652, 44.98377684623965, 47.037996630514826, 44.70652803297966, 46.68892529702956, 46.18455556131179, 41.99960231781006, 44.84996518781109, 40.270954947317804, 42.43997073942616, 41.92031160477669, 47.39650126426451, 50.07513492338119, 54.915916304434504, 55.63954653278474, 56.8287895571801, 57.069556405467374, 57.5969426093563, 59.43612237130443, 55.91889773645709, 56.696033016327895, 56.40453815460206, 55.36456877185453, 57.16982395418229, 57.415952682495124, 57.82869585098759, 59.37069331446002, 54.55705865736931, 50.23470086436118, 55.12590431397962, 58.466065314508256, 54.96143541028423, 53.69041881253643, 47.82978980771957, 44.589323689860684, 45.40252908583611, 45.25541274778305, 53.5621847644929, 58.87335638846121, 59.25310457906416, 55.62567703185543, 52.79123898475401, 57.99785590940907, 55.171780355515025, 61.899786610757154, 59.3292260169983, 57.597550576733006, 34.84586592643492, 23.706638620745753, 11.380545246985651, 12.936759341147638, 18.040155172348022, 15.526575830674942, 9.339107486509509, 0.4371895550960495, 0.3174968971119773, 0.40696245287695243, 18.4009563538336, 47.928531554437455, 47.37025276307137, 39.0274537763288, 45.54535827329082, 58.24324330975933, 66.5935379459012, 61.47064009020406, 27.280263016300818, 0.8134814327762974, 0.12845478861803009, 0.1402516846334742, 0.2034835706675245, 0.12597902993401214, 0.23491902336958917, 0.06265266993713957, 0.12080632766047794, 0.1372875525586067, 0.17499617751567595, 0.16282938360687227, 0.11574513714520202, 0.07919398677204886, 0.18553160251148287, 0.07593026835351221, 0.20971039460311014, 0.2162710949778557, 0.1254525206862919], [0.025254034797751138, 0.0826891326916314, 0.055003259030561295, 0.0482382889716856, 0.07045462427120056, 0.08770448816639763, 0.024724815513998754, 0.04417719559804086, 0.08222679862932813, 0.03638858651562083, 0.030853271844886968, 0.03557667504214952, 0.04162561719215686, 0.11675311733157405, 0.0673313067865468, 0.031087976287028966, 0.05588182398388463, 0.034032096230094476, 0.7756422051498968, 13.165504124856765, 47.88687598320746, 45.9341279152901, 35.293271080140144, 15.676520197622239, 26.58398739753231, 42.126844006199995, 21.18803962584465, 1.6686201528195412, 0.042410401492229396, 1.6856744957547036, 19.028049207502796, 25.751330967872377, 6.460177994543507, 7.108594323358229, 8.73506247997284, 15.39878010749817, 34.204962407389, 42.29622763972129, 27.140153992560606, 45.05452071466754, 53.51628518873646, 55.8295226097107, 51.95478962313745, 51.104812006796564, 43.39710750887471, 40.541229786411414, 39.45178362631029, 45.049802103350245, 51.40870155826692, 52.56205097321541, 49.51719345584993, 49.9029742517779, 49.905100176411295, 49.58436796742101, 50.86990517954673, 51.773403536888864, 50.85364695518248, 50.228966359169256, 51.71989456299813, 52.238373064225726, 51.66884883757561, 52.00194435734903, 52.052393882505356, 53.21252899785196, 50.56475262488089, 50.252163256368334, 43.925148748582416, 37.760590968593476, 37.9515907841344, 36.7512043060795, 38.79869722550915, 37.793935037428334, 38.02581771727532, 37.03730983118857, 37.24971794313, 36.89859521004462, 42.402041419859856, 43.013935089111335, 46.109257821113836, 44.38750205501434, 45.49970580685524, 40.83511729394236, 42.15762676731233, 39.7750771430231, 46.31091863878312, 46.052705087969386, 55.84749490984025, 44.6852413300545, 34.39965709563225, 55.80979701011412, 47.52079333028486, 50.513879483745946, 42.786363094083725, 48.55528708427183, 47.78873043675577, 52.57818368173415, 50.68011345401887, 49.63863395875501, 43.462622857862904, 39.63012987567533, 38.91319513320923, 37.48500131791638, 38.17806059314359, 40.43698495434177, 47.765408023711174, 50.52283425484934, 52.544184577080514, 54.09187339967298, 53.08360461265811, 50.33377209017354, 50.31120277220204, 50.2289742039096, 49.330359197431996, 49.96010357333768, 51.69009631679904, 51.80373914780156, 52.83260430059126, 56.014638869993156, 53.682154378583355, 48.73383729688583, 50.27451292161019, 55.386718396217596, 51.51283656397174, 49.02511250588202, 45.29874317107662, 43.02128953318442, 38.601292179476836, 40.04475578185051, 44.65117554510794, 52.660353414474, 54.92715389497819, 53.7657557764361, 47.001663715608665, 44.7971583181812, 54.66643002725417, 50.4519570258356, 53.65203057565997, 59.160921035274384, 51.111605551935014, 36.0085545047637, 26.912558463311967, 10.753914252404245, 5.002956678790431, 8.228422672517839, 2.8676159055002275, 1.828775675066056, 0.3496816604127807, 0.040616058864660805, 0.17945356817255098, 8.888806643024568, 28.492493091091035, 30.678763389587406, 23.645222148587628, 25.526049637025405, 43.85901366510699, 47.86587561330488, 46.58368026056598, 16.852985120588734, 0.15723105820436634, 0.0498591739714386, 0.04859009186827368, 0.01758034081919299, 0.01062803257692365, 0.052194393825747316, 0.09099684295154388, 0.0361173837295463, 0.031733054878009904, 0.01821336310146557, 0.0718144150150399, 0.09816564859882479, 0.030846685403957966, 0.03181470835941934, 0.03392705791479638, 0.19416905999664338, 0.030910820369758917, 0.06995988468970023, 0.020200453450783126, 0.07845334062773375, 0.043073232255635724, 0.04086363549915053, 0.04382906609304971, 0.05949641833262098, 0.10346553678954802, 0.06976482338241993, 0.0543406121282568, 0.03259898704146186, 0.04020367756546025, 0.06752586247579706, 0.10094253346323968, 0.048783107720796144, 0.0607679327649455, 0.05620717769488693, 0.04892649639758372, 0.0747031410555205, 0.7068798078163978, 17.330657243728638, 54.58009473739132, 54.79572311524422, 40.66382738851732, 24.859913510660974, 34.17122217916673, 43.22702961583292, 24.58992696577503, 2.0602215009350933, 0.06354563734343936, 2.25323177633747, 17.777470119537846, 22.955018358845866, 8.132730568608931, 5.752897675960295, 10.03652745677579, 16.956435672698483, 37.68349678285661, 43.985090409555745, 28.779455654082764, 46.73325984708725, 54.93047614251414, 57.63640949803015, 53.73670278056976, 52.80288450179562, 45.951782503435695, 41.61010311495873, 40.28706412161551, 47.83301399600121, 53.90455668972385, 53.27858563392393, 52.43698620027112, 50.666342012343875, 51.33037967066611, 50.77484261605048, 53.91340555683259, 51.79906760492633, 52.51138964006978, 53.02132914143225, 53.11556016245196, 53.55613646968719, 52.66994753191548, 54.778064604728456, 53.131598734086566, 53.18180899466238, 51.8071476874813, 51.19299865538075, 45.817217749934045, 40.36204807219967, 38.38056864277009, 37.85150758681759, 39.98331969784152, 37.67427529058149, 40.044343932982414, 38.69529178065639, 40.269029063563195, 39.776026356604795, 44.49038190226401, 44.133940435224964, 48.14487772603189, 45.50733481684039, 47.98618647360033, 43.03926575568415, 45.16591210519114, 40.787417350276826, 48.04773630634431, 48.613899061756754, 57.23099331701956, 46.61855797613821, 36.14342520313878, 57.70316039362262, 49.40474694774997, 52.12096475785779, 44.76536750793458, 49.07189069255706, 49.92325290556877, 52.70926144815261, 52.822425749994096, 52.143675281155495, 44.624601487190496, 41.18036431650962, 41.56231295677924, 39.470932637491536, 39.64184991775021, 42.738349360804406, 50.53360508334253, 52.05244879568777, 55.576910203503026, 54.45032704261042, 54.37523326566143, 51.21437165044969, 51.3579813895687, 50.453871142479684, 48.28530250057098, 49.28725627160842, 51.80843814726799, 53.10319685166883, 53.453029124967514, 56.42382052636916, 53.71785579189178, 50.08335621126237, 50.28729592600177, 55.54365242681196, 54.178008648657034, 50.59248770436933, 47.02144422838765, 45.148536005327784, 41.85713006604103, 41.20238842502717, 46.831868233219275, 55.35460595161685, 58.38567241545647, 56.19156129898564, 48.8662172902015, 45.19507492742231, 55.345019678915705, 51.13604976284889, 55.68750535288165, 60.72614677490727, 54.91335107434181, 38.135659771580855, 25.458004359276067, 13.827371731881174, 11.773127432792418, 8.188307121876749, 4.710507210223906, 2.9443104997757943, 0.5468531109152303, 0.17022456823577806, 0.23391500385778569, 10.696785911437004, 34.49671614554621, 34.456915855407715, 31.108496304481264, 29.94211481463525, 48.04374725587907, 53.992680580385276, 54.093716913653964, 23.26459534706608, 0.08848916138372115, 0.09417911856285027, 0.03595891461196927, 0.037608658143829916, 0.012898808157431984, 0.0513493528799905, 0.033794011424986586, 0.04903575202690498, 0.030114330246203372, 0.017957972370148186, 0.04930455312733689, 0.07890580747757228, 0.025978020444932966, 0.04496284940790746, 0.058760345733213815, 0.0676740775065076, 0.03282373425580802, 0.013030509205324756, 0.13189844576822174, 0.17907329744869666, 0.21379087000123917, 0.10334840960680478, 0.12602114178720983, 0.20601414294252474, 0.23451045335781193, 0.10972675807293385, 0.20380378009811526, 0.07925232436748282, 0.10814878548825942, 0.17587576902681784, 0.13695710819334755, 0.2506294642244616, 0.2704931128649943, 0.11470739444297169, 0.13441764929842565, 0.18344787400095694, 1.3009171932935715, 23.93462246464145, 63.23130184604276, 61.76670843555082, 49.147992518640336, 26.433082049892796, 38.19553867463143, 52.487239606918834, 30.338209482931322, 2.551018610115974, 0.22885189812269904, 2.5454405094346693, 26.770460797894387, 34.2354941368103, 14.89982912617345, 12.955932867142463, 12.648467094667497, 20.21769819721099, 36.19830700658983, 47.225976221023075, 33.82069172397737, 50.71161400887274, 55.85755186696207, 60.65443015867665, 56.41990207856702, 54.99755651720109, 48.17994763774257, 44.329290159287, 42.61158227920533, 49.72066248616865, 55.05927501186248, 56.37759931625859, 53.288791641112304, 53.00533763823971, 51.21403824898505, 52.519508946326475, 56.64079035482099, 55.722598798813365, 54.83498211829893, 55.642570680187596, 57.05660473915839, 55.90177266828476, 55.360618945091005, 56.65122778184953, 56.21309511123165, 57.28854233218778, 52.985004071266424, 54.21356493426908, 48.18310906810146, 42.51668053288614, 41.704922491504306, 40.33958465822282, 41.69174332772532, 40.31884316475161, 40.54019820305609, 40.99343199883738, 40.990976595109515, 41.98383831208752, 49.536005143196356, 46.89953696343207, 50.41847175167453, 47.87110805511475, 49.555577770356216, 45.355358662143836, 46.353433209080855, 44.0958228418904, 49.880781481342936, 50.70813878890007, 59.36236220021402, 48.537397153915904, 39.09164336419875, 58.01643225454516, 53.25061128985498, 54.892523288726814, 47.164524447533395, 53.88433294911539, 53.30012336854012, 56.31555134250272, 54.50780545511554, 53.00591030428487, 46.4182895998801, 44.31233767540225, 43.10777779548399, 40.35588210628879, 41.56259928980182, 44.78507741805046, 53.14047505778652, 53.66602951480497, 55.80925180066017, 57.14383432942053, 56.706999963329686, 52.11465366425053, 52.28349208831788, 51.254332757765255, 49.70535739775627, 50.27718013332736, 53.8348130256899, 53.3778686677256, 55.61018366967478, 58.081496530963534, 54.41642991958126, 50.060881030175, 51.929376586791015, 58.26402794930243, 54.80464258501607, 53.63733737699447, 49.54223386702999, 47.92080448519799, 43.81170203608852, 45.368200502087994, 50.43175289707799, 57.28854233218778, 59.8031856167701, 56.89617979911066, 50.10043421099263, 47.42088271725563, 56.62408890262727, 54.90063867261333, 57.559876211227916, 61.09333161384829, 57.8781569388605, 36.540416133019235, 31.124615284704397, 19.13327463211552, 8.892471117358054, 14.667769939668718, 9.003712477222566, 6.388248589731033, 1.2075683378404187, 0.2065260888588044, 0.44948128262354486, 12.01601432215783, 40.12912204188686, 42.16966452137117, 34.82549313575991, 37.01912572306972, 56.90796652147847, 62.07823484174667, 64.38476500972625, 28.3611995943131, 0.4630540010909881, 0.16434398539845022, 0.14040272652862534, 0.1467765780586389, 0.10765307297509526, 0.14244657250181322, 0.1655003797983931, 0.1727797319331477, 0.12272094992259819, 0.09650179755783851, 0.16058889818528008, 0.20942278987457677, 0.12155913928103064, 0.18643691925512207, 0.15928783574171607, 0.26553977220769853, 0.1148091232584369, 0.16711264247855834], [0.042405433412040436, 0.08661203912549442, 0.03233726459345029, 0.011183022100838923, 0.05676805747733001, 0.11224068325733948, 0.06291548789088285, 0.013683060026397149, 0.053862979290105646, 0.0529405634639965, 0.030305482589850025, 0.004844167861231273, 0.03807649654786914, 0.027156196639782963, 0.008908580789612907, 0.07228340638140518, 0.054530000554457794, 0.07830828954015048, 0.9988512375181722, 15.193744090295608, 43.843320262047556, 41.43321990966797, 31.18022664900749, 15.932213625600262, 19.70234190264056, 38.916674275552076, 18.8088926576799, 1.6451974741874205, 0.03963345151034094, 0.06012908055356914, 5.387138618576912, 10.357909798622131, 9.544225873485688, 4.846623261128703, 8.742771898546527, 19.386596987324378, 39.054239642235544, 25.558907331958896, 28.732532339711344, 53.418645628037, 51.14613025419174, 53.91416257427585, 50.97592684530443, 48.69059708810622, 43.65008861787858, 39.557742534145234, 35.987977750839725, 39.92330743420509, 45.54704489246492, 50.85838125598047, 50.71591684895177, 50.508082220631266, 50.62389804470924, 51.102258543814386, 51.13645768934681, 49.425680637359626, 46.98573497033889, 46.687768197828724, 43.249183162566155, 44.134203234026515, 46.07432911472936, 44.93463739272087, 47.44066715240479, 48.530003486141084, 46.18159417183169, 42.12540449634675, 38.66459531168784, 38.1813318498673, 39.5727809013859, 39.96104063526277, 37.50851200472924, 36.42708709163051, 37.82795375393283, 36.061247625658595, 36.364474296569824, 36.44046237391811, 40.90442949725736, 41.77545455194289, 45.76656426152876, 42.939578717754735, 41.774987789892386, 40.34748038937969, 39.396411526587706, 41.84689267989128, 48.55006248720231, 48.198645576354004, 56.352276494426114, 44.85677442243023, 33.37824444616995, 54.90372165556877, 47.80878943781699, 51.675669839305264, 48.82729953335178, 49.08577196059689, 50.9387113971095, 56.18730160497851, 54.78885896744267, 51.81116419453775, 49.94992894511069, 41.9684547762717, 38.142614133896366, 38.06410789489746, 38.28533741735643, 40.185078574765114, 43.17783524913173, 49.75277100839923, 52.73630226812055, 51.60593402001166, 50.11121680659633, 50.7389646960843, 52.31044661614203, 53.85978675657704, 53.46933441777384, 52.98985996553975, 49.870497026751124, 50.53615854632471, 51.02239516473586, 51.09717122970089, 49.45769110033589, 51.202004417296386, 52.2624485723434, 51.95606047107328, 50.05111040607576, 46.52170681184339, 41.874686594932314, 38.1853562016641, 38.871516027758204, 38.44284803636613, 43.811603976834206, 51.57635542654222, 53.86365813593711, 51.740565453806234, 54.351334264201505, 55.72996893236714, 52.40646623796033, 53.822500705719, 55.8516957682948, 59.21903094937725, 56.22760395849905, 37.47773316598708, 22.149908734906106, 11.057885193055677, 21.866303720781882, 10.112641049969582, 6.545921006510335, 1.4385261963452063, 0.5477054296962677, 0.11423533106403005, 0.32810513110410783, 5.658609290276805, 39.14795683276269, 52.59177077201105, 30.320572545451505, 23.53701376145886, 47.00151466554212, 50.67199414776218, 48.78123914041827, 16.243923402601673, 0.10078759218055396, 0.0194866874165112, 0.053675490761956865, 0.03587412783094952, 0.06759507085887656, 0.028004790318288633, 0.07104450431201728, 0.03065582225850273, 0.07980170133974283, 0.03535325699035199, 0.022007536120532502, 0.039547155536110365, 0.028373832108392835, 0.06676719028262362, 0.06516464159733827, 0.05573708699235032, 0.04573452977403518, 0.05994181802135803, 0.0218945324060417, 0.057053957660231865, 0.09755513014932794, 0.053808801552100535, 0.023624646222038616, 0.03605335410083494, 0.030638116051352797, 0.026632489358645775, 0.0829070310799345, 0.031055666528822436, 0.01665529348106394, 0.04285993422531793, 0.03053420005486377, 0.022863867287073406, 0.039197321485487685, 0.053618164402582956, 0.044410419575269186, 0.09402313540058752, 1.542396564637461, 19.48407376966169, 50.07802571019819, 49.01644799017137, 36.95690908739644, 20.293519573826945, 21.072398347239343, 43.56893870138353, 23.02233211455807, 1.8332285458041777, 0.04448395635512087, 0.1302159328254, 4.17699622531091, 11.236521697813465, 6.061750986883718, 5.924739164690818, 12.22486876672314, 17.856095990827008, 41.78062031345983, 29.37954102793048, 32.264061858577115, 55.345388381711906, 51.590362210427564, 57.53231371602705, 52.78975632882888, 51.73710592331425, 45.43923462590864, 42.44287721572384, 38.31200953452818, 42.00650961168351, 47.71418186926073, 53.284155399568625, 52.189598391132975, 53.512252992199315, 52.947761166480284, 54.41420201332339, 53.42808677304176, 51.72031425660657, 50.632935185586255, 48.776293031630985, 46.024291438441125, 47.2065055754877, 49.2203131798775, 49.34100843244984, 52.17732921723397, 52.3656932000191, 48.94309182320872, 44.248912949715894, 40.595499700115575, 39.12051985340734, 39.3522770174088, 42.00399929477323, 39.299693722878736, 38.48556264754265, 39.52328451218144, 37.22334000372118, 38.27301725264519, 38.742046433110396, 42.221282912838845, 41.89823258307673, 47.06940304848456, 44.962211655032256, 44.508758206521314, 41.613503809898134, 42.4831638797637, 43.2808719911883, 50.04878836293375, 49.08043361479237, 56.590599706096036, 46.698229159078295, 35.69427851707705, 56.58726961381974, 51.26807282047888, 54.28535999790315, 51.37166653909991, 52.02295257199196, 52.59690907693679, 56.928405992446415, 54.633890044304636, 56.12772080206103, 52.35865254555979, 43.037045694166615, 39.68809466208182, 39.5952796166943, 40.879765633613836, 42.334972812283425, 45.86049326004521, 51.3963500145943, 53.77037240612892, 53.882375686399406, 53.06951938136932, 51.1541554235643, 52.3948520998801, 55.52868858460457, 54.0943209586605, 54.12855540552447, 51.71774902651387, 51.66226317805629, 52.156830910713445, 52.18673506090718, 50.56430547468124, 51.26367192114554, 53.91806533259731, 54.195349447188846, 52.45296985872331, 48.938102568349535, 43.97926961222003, 40.139794811125725, 40.393077942632864, 42.16795436797604, 45.00212569390574, 54.03190035973826, 54.84916148647186, 56.387573903606786, 56.46376594420403, 56.25091460443313, 53.10050610573062, 56.409715683229514, 57.046179079240375, 61.12717774606521, 56.630447064676595, 38.94699419698408, 20.989595151716664, 12.886305893621138, 19.108457796035275, 10.45249383295736, 8.356547874789085, 3.769460248370325, 0.9543428774322233, 0.18847641384890004, 0.19758841683787687, 6.898667110550789, 38.361043084052305, 55.69299274875272, 29.975131365560717, 27.96660915497811, 55.1425116292892, 55.888103208234234, 56.20594070803735, 19.475913278518185, 0.13858219518536521, 0.06348160005384876, 0.03610213091897388, 0.07094826834696917, 0.040650686038838285, 0.010792094136347935, 0.03838640975675756, 0.02291838976464445, 0.03435009166658406, 0.08181991401098429, 0.061083086015236, 0.0746022166323758, 0.021013964132796374, 0.08561721266878229, 0.05431024823337794, 0.033973256847070116, 0.012354540991626922, 0.05058252185042347, 0.10471579228197375, 0.15948052217643108, 0.24318430001937577, 0.22488723989696274, 0.1440678290542095, 0.2524237034301604, 0.2559278355610948, 0.10745202852112633, 0.19205504036959142, 0.12595747221982287, 0.18881488681560565, 0.09760746161543554, 0.1496762208520405, 0.18744216450760443, 0.15279409145155262, 0.19220176152884963, 0.1461718282512119, 0.3075309818790805, 2.10023703113679, 24.659672590994067, 58.96272759283743, 55.72481886033089, 45.18209972689229, 25.845711038958644, 28.798163398619625, 50.68695014522922, 27.418352019402292, 2.683330942546168, 0.14831350365233037, 0.495739724607237, 8.393957480307549, 14.330288229450105, 15.668255763669169, 10.83410514939216, 13.79673311787267, 18.8815192637905, 46.06077732578401, 32.69917626534739, 37.03686268098893, 56.409503875240205, 53.698161571256584, 59.98852152978221, 56.10832468155892, 53.75233342570644, 48.53267069785826, 43.32309238372311, 39.8758702893411, 42.74812782964399, 49.40486069648497, 55.06546058962422, 55.303760267073116, 54.790121970638154, 54.743798778903106, 55.59747519031648, 54.73441646945093, 55.62785394730107, 52.38923134342317, 51.275960706895404, 47.188737238607104, 48.379745329580004, 50.981335793772054, 50.86577492375528, 54.22171561948715, 53.84161049319852, 51.387638430441584, 46.28391312014672, 42.75544305001536, 41.72108265661424, 42.55408425484934, 44.49404931837513, 40.81488963096373, 39.78110190360777, 41.757105704276796, 38.4665273850964, 39.163214852733, 41.09000467484997, 45.236679507840066, 43.90123798001198, 49.98810537399785, 48.577868169353856, 45.876959370028594, 44.21497268061484, 45.16349984753517, 45.30901978092809, 52.99695945555165, 52.2693911675484, 60.32697500721101, 48.15997885119531, 39.61617016023205, 58.45087789720105, 53.21289377827799, 56.54293898613223, 53.67454498044906, 52.26423717314198, 54.68206067239085, 59.72911950080626, 56.69209887904506, 58.208306758634514, 55.39556334095617, 44.866227334545506, 42.0108320636134, 41.46129623536141, 43.13871352903305, 44.39094197365546, 47.5525253049789, 53.16404458015196, 56.09423552789996, 55.15029753408125, 54.42359216751591, 52.52992676150415, 54.12872014507171, 58.06767017610612, 57.17141251410208, 55.79588436311292, 53.30495180622224, 52.5280636356723, 54.52141607961347, 51.93798226694907, 50.54336001796108, 52.60295344937233, 54.79098489207607, 54.86299568606962, 55.295703718739176, 51.13447689240979, 47.21903362581807, 42.23246559020012, 42.82767349673856, 43.901175222089215, 48.42515853143508, 57.11926852503131, 59.59224447127312, 57.0586012255761, 59.415020019777366, 58.1112398639802, 54.64136608185307, 59.37417245680287, 58.67109152578539, 63.9806196766515, 60.64491841100878, 43.708983006015906, 27.705722508891938, 13.638298780687395, 29.265356909844186, 14.782267847368795, 14.2839297363835, 6.095947680934784, 1.1990677036585347, 0.5812143606524314, 0.5569848382184582, 8.973245466909102, 49.36929656613258, 61.695152636497255, 37.91570894179806, 33.9552721669597, 60.9376762759301, 64.51865511555826, 65.2449486332555, 26.12993382638501, 0.5663075153866123, 0.19911342210346655, 0.2000805468208367, 0.1330107901125185, 0.1592224118329825, 0.13128438033163548, 0.2308889565568778, 0.11943697613934356, 0.21486602843769137, 0.19964386138223833, 0.149218360743215, 0.19646038301289084, 0.12114071737854712, 0.2151018456225434, 0.20748054248190698, 0.16079557338549247, 0.11412329836598328, 0.17962474285835223], [0.06881271398836566, 0.05952443033757229, 0.0310810029716982, 0.03782141991260071, 0.05203602813004006, 0.02937260966357445, 0.032930389016626344, 0.03193875523133865, 0.04345881962968458, 0.051819933878798644, 0.042307312870698596, 0.033132050171374314, 0.014785411711331579, 0.031238119944088885, 0.005133048604963528, 0.061955725278465025, 0.03698778601603643, 0.02667339079292311, 0.8186341401550078, 18.097102103694795, 45.714384971126435, 43.97781049051593, 27.372305354764386, 17.624833045467255, 43.94723561502273, 41.51054943761518, 17.813220562473422, 1.2320069103471696, 0.13242482478099485, 3.0491250561129664, 5.714913443211587, 15.082453700803942, 10.801172929425395, 4.273288451856183, 14.669023136938772, 20.499292996621904, 28.607683297126528, 17.43563359783542, 40.2955795872596, 49.68698893823932, 54.49386142915296, 51.17955277043005, 51.73780410520492, 45.89319013780164, 44.34890985488892, 38.166218957593365, 40.04878797838765, 37.742673581646336, 39.90456242715159, 41.25523451835879, 46.91026464585335, 48.07921332697715, 50.13814780019945, 49.13211084181263, 45.798602181096236, 42.3742945732609, 39.48426477370724, 36.62721034019224, 36.79433076612411, 36.8164921575977, 37.24361865751205, 35.76967823889948, 38.11656175121185, 35.472566543086884, 38.38084320868216, 36.46720117138278, 36.49831733395977, 36.53113972756171, 39.897506083211596, 41.228966405314786, 37.736884163272, 39.75129581266834, 36.405686639970355, 34.547181360183224, 35.15331306765157, 36.505173637020974, 37.77297389122748, 38.24679620804326, 40.70555356241042, 38.29254281136298, 37.762842409072384, 37.320665774806855, 39.955714056568766, 42.9088665593055, 48.43357593782487, 48.89614889698644, 57.94441361581126, 45.345768467072524, 31.23508099586733, 53.948718655493956, 52.11348479793918, 53.3066580372472, 52.441065465250325, 53.18354660464872, 51.918166452838534, 50.80213839007963, 51.90096685963293, 52.34314349389846, 53.66026363065166, 46.85436694852768, 37.68297902999386, 38.50312309880411, 40.26149811283235, 40.42031488110943, 38.54165646337694, 44.69199172912106, 49.685176803219704, 51.596524253968276, 53.63385823465163, 53.71510621040098, 52.749940349209695, 51.158273912245235, 51.79528251771004, 51.6626867940349, 50.755113094083725, 52.453813168310354, 53.924968704100586, 53.02305890667824, 52.36279456846176, 50.86248797755088, 49.46642621870964, 52.991134735845755, 50.016189544431626, 46.70561498211276, 43.522074222564704, 39.44819465760262, 39.950563984532515, 38.607713099448915, 41.51831573055637, 43.03619453983922, 47.57154880031463, 51.350203329517, 54.26209249804097, 52.18210274173368, 55.073262183896965, 44.472225250736365, 51.57321753040437, 54.004792859477384, 42.370470262342884, 31.321847746449134, 23.598826393004387, 18.542783375709288, 15.094015867479387, 5.389262091728949, 4.650521912882406, 1.8912950686870085, 0.37949596381475853, 0.0723953241662633, 0.04518269748997785, 4.488389761217179, 33.28876733779907, 36.435210320257376, 30.255798524425877, 24.951312580416282, 36.64096217001639, 53.94052482420399, 45.01757983238467, 18.977846791667325, 0.6226176744507206, 0.047172649177692594, 0.034098872284014384, 0.05000641607048531, 0.04108586611466543, 0.10248243913895662, 0.033478214660839695, 0.07955955626863627, 0.09099112793562875, 0.0100499062400852, 0.01509690497656383, 0.059457236765733654, 0.037640902784562884, 0.054038601116307323, 0.027952843811362985, 0.0264857720298272, 0.06109799025580288, 0.024661299164196657, 0.034897607045188066, 0.020425047447544434, 0.04187109091529443, 0.01945918102958991, 0.0678134442216927, 0.046403780354246985, 0.04098089674728052, 0.04138324612511262, 0.06300230480490193, 0.022607225917219635, 0.02851055773545898, 0.006015485175134194, 0.09260666181123064, 0.08356975842147105, 0.036010916660269426, 0.039274807448589036, 0.05207881414061112, 0.07165706821627195, 1.1666848606640294, 22.204868985760598, 52.426160458595525, 49.97860147107033, 35.98600479864305, 20.669325782406716, 35.43516282112368, 44.15027710699266, 20.905385786487212, 1.1448844498203647, 0.19527708360504722, 1.448755370032403, 5.955011527384482, 11.89944246122914, 3.3616607371837866, 4.504677893653993, 12.735780035295795, 22.751221810617757, 29.21655478016023, 19.870238957866547, 42.40655999029837, 50.76000428968861, 55.299324066408225, 53.82480313701015, 53.437339644278254, 49.38367597518429, 46.143343217911266, 41.13713979721069, 40.580610382941465, 40.28436553093695, 42.09848919222432, 44.09197891912153, 48.86109075238628, 49.85470556443738, 51.57976004385179, 51.800860128095074, 48.371951580047615, 44.460438528368556, 42.934554161564, 39.70173666554113, 39.021111303760165, 40.35098698831374, 38.94000061096684, 38.553502021297334, 39.41853369435957, 38.09413363856655, 39.793390689357636, 39.17634694806991, 37.89430064539756, 37.986880348574736, 40.64005390290291, 43.059952335972945, 38.10244121859151, 41.26345580623996, 38.36771503571541, 38.29147200430594, 37.25309902621854, 37.28744722181751, 39.15011021398729, 40.74034106346869, 41.5399750586479, 40.331622246773016, 39.04470436034664, 39.65629992946502, 41.21224926364037, 45.75044332012054, 50.72835860713836, 51.39858968796269, 58.667486867597034, 46.07592944175967, 32.766288018995716, 53.53615199365924, 52.521097506246264, 55.298771012213926, 54.51017456669962, 54.68775987625123, 55.071963879369925, 52.286018094708844, 52.273160565283995, 55.21627964511995, 55.309502617005386, 48.410641839427335, 39.29002900277415, 40.553298919431626, 40.83263835599346, 42.411027569924634, 40.670926878529215, 47.7358490420926, 51.21170443873252, 54.14806919713175, 56.41606992290866, 54.89410008153608, 55.174616229149606, 53.05509290387554, 53.11716833422261, 53.41178148023544, 53.71106224675333, 53.47407264094199, 55.25746845429944, 53.93775170849216, 52.5628040682885, 50.99979839017315, 51.05393886566163, 54.77385197916339, 53.36638789023123, 50.29573294424242, 45.475414568378085, 41.42564581286523, 40.80196934361612, 40.53242014300439, 43.47741411578271, 45.54498564812445, 50.96787814171084, 52.842359235209805, 54.524122515032374, 56.81495535758234, 54.79595453508439, 47.24418386336296, 52.76563767463931, 54.94334543904951, 45.68818353837537, 33.799110843289284, 25.30975837861338, 15.976004927389084, 15.585259391415505, 8.544293103679534, 7.249840834448415, 4.096428045342046, 1.1255068380025126, 0.06846242028498842, 0.07814405561094323, 4.584401538295131, 37.57521583187965, 43.559960396059104, 32.77633909256228, 26.725604572603782, 41.78426811772008, 60.91471864331154, 52.40226930187595, 23.543509206464215, 0.4782043397426606, 0.05503903916706482, 0.00614408356693363, 0.03300633514299989, 0.01336705354568098, 0.09214199884163757, 0.06784554330572005, 0.0780697604040465, 0.010971017801503261, 0.014521944498072469, 0.050780283617636854, 0.027095350106396986, 0.05494637317174385, 0.02989463729693765, 0.016381727313743006, 0.07163397066535489, 0.011207352095704165, 0.018438102654932488, 0.1623965286078953, 0.11337777990246974, 0.11829250206750248, 0.10632450031417032, 0.15235950509386678, 0.18503591298095642, 0.1740411723092679, 0.11158509585525721, 0.18804646998403535, 0.1004740400540252, 0.25163023552346614, 0.1532503427757371, 0.196533651661969, 0.08915441681540782, 0.0789528989022778, 0.1392989930125975, 0.15265121605367432, 0.15666925528597447, 2.1178499440993033, 30.6088432188957, 57.8256207127725, 58.54162585350775, 38.99699657194076, 26.955790827351233, 55.92274558159613, 54.68164490115259, 25.044423764751805, 1.9627200812101366, 0.1695256509006985, 5.774035819115178, 10.950209267677801, 21.862616692819905, 17.87397219288734, 13.134355602725861, 22.798072561140984, 25.688524015488166, 33.65248480150777, 24.486929447420184, 47.375571497025035, 53.02321580148513, 58.401456033029866, 56.127889463978434, 56.5442608248803, 51.977052996235514, 48.749679750011815, 43.84306530798636, 44.47329998016358, 40.629691000907656, 44.36011606647123, 43.65804318458804, 49.974808539113695, 52.4867336211666, 55.005785649822606, 54.39963433050341, 50.26110626036122, 46.23286347235403, 45.13205812823388, 41.049651330517186, 41.39456887398997, 41.40800691420033, 41.430191839894945, 39.443393676511704, 42.853949454522905, 38.82030556278844, 42.05077748144827, 41.168063763649236, 40.34217342253655, 41.30450733246342, 41.317176588120006, 43.65433262240502, 40.10412869914886, 45.065656323586744, 40.50472036484749, 39.946272911564, 39.25757923433858, 41.06082616313812, 42.7417932018157, 43.220083098257746, 42.95835902613979, 43.4575512332301, 39.98905420303345, 41.961735756166526, 42.94752151735368, 49.814175713446836, 53.76509681824715, 54.19829906955842, 60.34933251719321, 46.67144329317155, 36.60386831529679, 55.00586017485588, 56.21207137261668, 57.88300498839348, 56.37757970440773, 57.05201948842695, 54.548264703442975, 52.927184412556315, 53.43592366864605, 57.72346258163453, 58.18158365065052, 50.67942311686855, 42.19370865052746, 43.35401635016165, 43.98522377014161, 45.33997904869818, 42.777106300477065, 49.61151076901344, 54.401305260196814, 55.20821525204567, 60.550510883331306, 58.68764000554239, 58.01620475707516, 54.497846557248025, 56.330487728118904, 55.1740082617729, 55.77792775246405, 57.115816839279674, 59.182219505310066, 56.23327570576822, 54.16892443933795, 51.11767345859159, 50.91435740070959, 56.65644845654888, 56.408111433829035, 52.57485751182803, 47.93556828652659, 42.942198861029844, 43.245668718891764, 42.6506765427128, 45.65167803918162, 46.7975631836922, 53.28567335682531, 56.01594109689036, 56.82446710525021, 58.1552763139048, 56.82643221270654, 49.3983809409603, 55.28232059171123, 55.904643843250895, 49.62708650096771, 37.220041290406265, 29.612598457644065, 30.061743182520715, 27.418759945900213, 14.219278289425759, 9.184335662472634, 8.035155727017312, 1.9490063719211088, 0.26298762689675054, 0.19705077633261683, 6.655191375363258, 43.03359793078515, 44.2369536430605, 41.204455514107984, 35.342649798239435, 48.767593214588786, 68.14166607395296, 61.46651375678278, 28.67364383512928, 1.1847159963461662, 0.18807833924168543, 0.21715687647942575, 0.10625082563849227, 0.15659206426672398, 0.26222950628688263, 0.2682493026218107, 0.17358913446866697, 0.1720838023409728, 0.15700455664867358, 0.09502900884516778, 0.20305675244139088, 0.15550107845375616, 0.06463375032669114, 0.14344152153259324, 0.18206171451076386, 0.13223334876520018, 0.10240335588253315], [0.01788729118303426, 0.1447355359672539, 0.04738539945514453, 0.04895782173280755, 0.04744736447689995, 0.11763251732073485, 0.051788930300503015, 0.03243951817914363, 0.004069234973060027, 0.024723287168589812, 0.03898619531443523, 0.05434044741935307, 0.06620971576100396, 0.057381268725880695, 0.05092110589987809, 0.057145198732013666, 0.05149155412049544, 0.006125743422026356, 1.8157087891332566, 17.490315360407678, 47.30744777187225, 44.29514592693698, 20.611353151259884, 16.03450707850918, 34.28820294718589, 44.011099646168375, 17.45182906427691, 1.0687866686813294, 0.4688834705420079, 10.493816983315254, 10.768738850470513, 2.733149946697297, 6.271180548975545, 2.328502550240486, 14.575532463289077, 19.505742903678648, 16.94542361843971, 26.73570859816767, 50.5193276559153, 51.14232947749477, 52.62995896800872, 51.13026034447455, 51.294666490247174, 46.95732916555097, 45.334719150297104, 40.94163710071195, 41.78015355140933, 40.43462760986821, 38.39174739776119, 36.021419878928896, 39.01431775862171, 38.61659726788921, 41.26806066882226, 38.71990857585784, 38.61483612368184, 35.19857329706992, 36.37268381734049, 35.49921120366743, 35.42181891779746, 35.275620414364724, 36.30484250284011, 34.65957295510077, 36.64164858479654, 34.86685060685681, 36.672345053765085, 35.1565529454139, 36.15601208902175, 36.46795818882604, 35.89962636270831, 36.430040636370265, 39.40129095508207, 37.51328945159912, 37.48864912217663, 36.60791620131462, 35.617011747052594, 36.122954353209465, 36.771914420589326, 36.9024940459959, 36.763500936569706, 35.853232568310155, 36.96563243865967, 40.025442031122026, 44.114328584363385, 48.10612470872941, 52.03437843630391, 52.14360860086257, 51.680102117599986, 44.351192674329205, 25.387321287585845, 50.476546364445845, 50.54540749519102, 54.69117626067131, 54.0864722959457, 53.62269124677105, 49.98786218704716, 47.72016348377351, 45.367945548026796, 52.82762681284259, 50.44629312330677, 48.09573827251312, 38.79076619302073, 38.891182791802194, 36.52846467110419, 38.99379199550998, 39.29888179225307, 37.62986621549053, 38.377928887644124, 40.20044642110025, 45.35219330941477, 47.325529898366625, 48.49911089866392, 46.62373942713584, 47.79176635126914, 47.631659123205374, 47.785353276037405, 49.5286310872724, 52.131425719107355, 51.508490577820815, 50.16295679153935, 50.392399757139145, 50.652523502226806, 51.303793845638154, 52.36827804196266, 51.73048104009321, 45.5091900979319, 40.15781417969735, 39.705054990706905, 38.04053837253202, 40.36126359816521, 44.605938849910615, 45.176926120635, 44.07703861113518, 50.44053116152364, 51.973734671069735, 54.13481943068966, 49.730174233836514, 47.214177731544744, 47.25331514112411, 50.438730793614546, 49.5232339059153, 36.9337357244184, 19.508388542359878, 20.546390856465987, 8.144712919189084, 7.2760339321628695, 2.696356398444022, 0.6626585161974353, 0.11210348457098009, 0.05945614892088118, 2.7386125826066543, 27.15695546519372, 60.37538489987774, 39.47589835812969, 33.4606259868991, 48.56953313273769, 53.225912124879905, 48.85514443920505, 19.04569987327822, 0.8137945482327092, 0.060958749945125276, 0.03343139519734729, 0.09014787963561474, 0.027588503885894056, 0.03881701245723713, 0.06408243132154308, 0.1253444026975382, 0.06001464616987975, 0.08630451611092976, 0.126023639233843, 0.017964104903982054, 0.042581135677474166, 0.06860517310879885, 0.12211821492641203, 0.057666333872945084, 0.031552725441513524, 0.009104910930017791, 0.05064645954858392, 0.027332745432373018, 0.017996010550808524, 0.057607126767717065, 0.07400068439423077, 0.06792512451929432, 0.02857220866116545, 0.02719789672072136, 0.02633638679981232, 0.055506371953074014, 0.014934486675737126, 0.029012939044004007, 0.06366676350514736, 0.043656600549096064, 0.005953302297125301, 0.056936118015719045, 0.047449827449576515, 0.03884866337982878, 2.273640113492166, 23.95115721610285, 53.0306290811108, 51.356647783710116, 25.399672831258467, 18.941757063711844, 37.36953458478374, 44.289627152104536, 20.609325285880796, 1.0698739006634683, 0.5069923304742383, 15.109603366544171, 18.4791233078126, 6.883663554345408, 12.029992668859421, 4.501311029157331, 16.08461437686797, 21.938445914176203, 16.909559426769135, 29.368187727466708, 51.8433197852104, 52.050930838431086, 55.00830773384341, 53.11516792543473, 53.67925182465584, 49.973631828062, 47.086775225977746, 43.409953271189046, 42.87005862882061, 42.422206324915734, 40.221517393665934, 38.686835150564875, 40.552408541402514, 42.428744915992986, 43.35483220315749, 42.127169562924294, 40.32285574943789, 36.967828965956166, 38.87116693681286, 37.32823202686925, 36.673592367479884, 37.49699592590332, 37.5453273711666, 36.096831367861846, 37.393406129652455, 36.21669900032782, 38.43874915953606, 37.86217251131612, 38.230079066368845, 38.498800646874216, 37.84073675832441, 37.631905847980136, 40.62377214431763, 40.27442232255013, 38.714950699960035, 40.110482938828014, 39.038530549695416, 37.67271418725291, 38.46613907044934, 39.46028732484387, 39.37743902206421, 37.86569872210103, 38.76920884655368, 41.65433568339194, 47.16053931943832, 48.74094855400824, 53.86124980065131, 53.00320779123614, 51.84222152156215, 45.56346001163606, 28.147726558869888, 49.91537286389259, 53.606970387120406, 57.560609694450136, 55.009657029182684, 54.56442486855292, 51.96578794910062, 48.43266987031507, 48.241807337730165, 54.21809919418828, 51.21267718653525, 50.13098947463497, 40.88271525598342, 41.26504436615975, 38.619248790125695, 40.192154530555975, 39.3351480268663, 39.14563871199085, 40.36752370096023, 42.69215168491487, 49.04653649176321, 51.4778176430733, 51.50718442855343, 49.75542645300589, 50.034997309407885, 49.60522713199739, 50.71996473496961, 51.61291583891838, 51.7600949348942, 53.378845337898504, 52.50212892409294, 50.09494289275139, 50.98205358751359, 53.43853988955098, 53.61553684357674, 54.124323168108546, 45.847004229022616, 42.08600428796584, 40.99905275529431, 40.7381994493546, 42.67080614643712, 46.65744043165638, 46.75315410860124, 46.65772676467896, 53.20080895577708, 53.662111067002826, 55.05348951585832, 50.596723864155436, 50.98941195395685, 48.95920099750642, 52.3057750732668, 49.519605713505904, 32.84887352297383, 16.511409436502767, 11.804802533118956, 9.340003748093883, 8.952270592412642, 10.357083159108317, 1.7467521731891942, 0.14870373351920038, 0.04202307892903205, 3.504769148365144, 29.677794133463216, 50.08221480154222, 36.67358060036936, 36.99968253412555, 51.2278881380635, 59.735305078568004, 54.59410152127666, 23.292289241667717, 1.1229125578557293, 0.03171086322606331, 0.065250895436733, 0.011508560630552953, 0.057890284355849995, 0.05694603119345923, 0.04163144329082101, 0.02981053999504976, 0.01610765361317223, 0.0280470400673127, 0.1116041714445718, 0.026323344152901443, 0.04108234594065336, 0.003339874500881941, 0.05762585761746573, 0.039149184350765524, 0.05698672578399701, 0.04515947353455328, 0.18092203614932878, 0.3694187819717392, 0.1594128919344756, 0.19620421853276993, 0.2645702419742461, 0.20903654366491303, 0.18517909481400446, 0.2002155468348534, 0.12753275583588308, 0.13878883974206063, 0.10918704913027825, 0.1292827151595585, 0.15816784583993498, 0.10749531248884817, 0.11853587287928789, 0.13500491697942058, 0.2030452151572512, 0.05424459832870672, 3.4189655848087805, 32.01521885010504, 60.16387893307594, 59.54467396582327, 32.049516054891775, 27.20495547017744, 45.57854544731879, 56.492383556981245, 24.14273754242928, 1.6040058458043684, 0.4251437724357651, 18.086729395774103, 20.91401696205139, 5.1836176168534065, 11.070898636694878, 6.5034588979136565, 21.38328932946728, 22.694061110096595, 22.33106928486978, 33.95484462861092, 54.46770314247378, 54.57448182567474, 58.314081315071356, 55.97459931527415, 56.02087543856714, 52.46399956364786, 50.70751513204267, 45.4217996904927, 45.9424158834642, 46.69991185588222, 42.47239697364069, 39.549254525092344, 43.146628872040786, 42.683816648298695, 44.2480617953885, 43.235290127415816, 41.79090084568147, 39.49402363069596, 39.034357147832075, 40.67880299783523, 38.48203251438756, 39.466798459329915, 38.74055593244491, 36.56048690119098, 39.41441128330846, 38.970073423077984, 39.73461004995531, 39.99018776801325, 41.448681892887244, 39.895799852186634, 40.43204276792465, 39.152361654466205, 43.90604680584323, 41.78851212224653, 41.03620544556649, 42.98317586222003, 40.40748480827578, 39.73967775221794, 40.15002435253513, 42.57114656509892, 40.97436927979992, 39.557134566768525, 41.92823479252477, 45.667606784451394, 51.161431420233946, 52.15931769340269, 55.51536429312922, 53.86709805457823, 53.12774304420718, 47.341074251359515, 31.807246938828502, 49.39156778397099, 54.75917446997858, 59.05548772504253, 56.45969844633534, 56.02550775774064, 54.5964196420485, 48.84239281377485, 49.44004435693064, 56.82751086450393, 53.456253313249164, 52.25380759085379, 44.14617823016259, 43.96220730197045, 41.08811801479709, 41.9734989443133, 41.649405264085345, 42.28164034505045, 41.98009244857296, 44.19586681550549, 49.21032290304861, 52.438696353666245, 54.585044768548784, 50.27413637407365, 51.39074886998823, 52.051554495288485, 51.633696556091316, 54.69595762991137, 56.382031594553304, 56.630674562146595, 53.04589886819163, 51.18516568214663, 52.18439732828448, 53.848486408110595, 56.39816038070187, 58.06108843895697, 48.53273345578102, 44.07688171632829, 43.952895595181374, 42.79052080646638, 45.99197503059141, 49.5299215470591, 51.241961602241766, 48.51303923514582, 55.71129452797675, 55.47004522815828, 55.92374970836025, 53.01866977445541, 51.912479016088675, 52.7397814104634, 53.19024209053286, 50.06151645414291, 39.92171495191513, 25.631241721491662, 25.447306094631074, 10.480403457918475, 12.040497756773426, 6.865093092764578, 2.7513494991487075, 0.3284895540245118, 0.15917103797678026, 4.520725780917752, 37.26225383820073, 74.58491217705512, 50.85091698554255, 44.327462334786695, 59.22966841728457, 66.69222477943667, 63.167563330742624, 28.92709758973891, 1.8913138225193948, 0.15186330994531033, 0.12534455591512303, 0.15612274348255128, 0.13369884432083176, 0.12905207672907462, 0.16017974594668036, 0.16641492024064067, 0.18480568823795165, 0.17427652984136538, 0.23568341057867775, 0.16282872477125737, 0.11859868442819965, 0.15163205864448703, 0.24096797701091538, 0.15307942855983012, 0.1538902560188886, 0.10848473802569414], [0.04429981946164081, 0.03535649754227169, 0.07790622361485036, 0.03375966004246185, 0.03744399520538507, 0.06176906795571409, 0.04345867407297896, 0.10114566167636264, 0.0392089928350141, 0.06507700113880058, 0.050777724883969755, 0.07156839353903648, 0.04690015170302603, 0.03812438853445553, 0.011774614348166413, 0.04172103727356561, 0.04275393830011449, 0.04152043715059277, 1.6224202705967812, 20.25578441158418, 46.58304875896823, 44.25758531016689, 35.18477832117389, 24.122545180782197, 48.42326402664185, 51.77501170865951, 13.144544939840994, 0.45325288669236247, 0.7226183181328159, 0.9554620399590462, 1.604692138010456, 4.974186093576494, 2.9423998152056052, 3.615700886134179, 9.740927834664623, 12.978301163642639, 17.82860017591907, 37.29454278945923, 48.93188953399659, 51.93861769091699, 51.171205966703354, 48.99357272732643, 46.393033458340554, 45.51862339819632, 44.65145011102, 44.895880453048214, 43.31574186202019, 44.252317567025464, 43.49027948994791, 38.77629264708489, 37.04421320269185, 36.09575663843463, 36.49649735419981, 34.5482050987982, 35.89600601503926, 35.63864361855292, 35.07534811573644, 35.18873207030758, 35.30625412541051, 35.14868859321841, 34.18366393735332, 37.17050567750008, 37.055595920931914, 39.819937290683875, 38.41261832944809, 36.33490747021091, 34.261071912703976, 35.222864535547075, 38.470328161793375, 41.29410128439627, 42.74893191552932, 42.898891971957305, 40.49629119134719, 39.63537408459572, 36.983663574341804, 38.05528256200975, 36.34415641907723, 36.6821902028976, 35.45019726599417, 36.79309129714966, 38.354002429592995, 42.97122047793481, 47.07571021972164, 50.07025549488683, 52.285567022139034, 51.40423005627048, 48.61490711089104, 45.84638841690556, 27.544960245009396, 46.87108409020209, 45.1003614548714, 48.32303570162866, 46.808887066379675, 47.10252354221959, 45.40935400993594, 51.500488942669286, 42.78569236878426, 47.915317089326926, 50.023889157079886, 48.953470414684666, 37.42249050448018, 36.94294937195317, 37.182657180293916, 37.471900601540845, 38.24056748420962, 37.499749429764286, 37.285203626078946, 37.556262939207016, 37.0123557121523, 38.21608012722385, 38.44072995647308, 38.50690034128005, 38.312958748109885, 40.01938589157597, 40.887790802986395, 42.199172512177505, 45.71210999642649, 48.5664854511138, 48.922338562627, 52.966533630124985, 51.18427530411751, 51.5792775923206, 51.06196403503419, 51.44714078595562, 47.921989040990034, 41.527674505787516, 37.97770984711186, 43.66984167406636, 52.841292350522934, 52.00857708531042, 51.365798673322125, 48.22281129898564, 49.32697811434346, 52.13838008142287, 55.106049276167354, 53.09212792304255, 50.8047349991337, 61.5225330475838, 62.79330253601075, 48.746561465724824, 36.3127068550356, 21.305787217232492, 12.872412858470796, 12.134816050529482, 8.598080565852504, 9.638058773932919, 1.336966962102921, 0.03170526120811701, 0.07811954079736626, 1.9920776736351753, 27.890725020439397, 38.26883208367133, 33.39369073990853, 31.942403970226167, 44.720393611538796, 51.8133960231658, 47.088006850211855, 19.518710259468325, 0.7233285122821409, 0.017182850354020635, 0.01521267522607119, 0.031713935238639676, 0.039762851421631155, 0.04779040715807388, 0.1069086270346757, 0.019499869874468254, 0.018451256384592385, 0.0452518445860234, 0.06601740470937183, 0.02638150554811282, 0.0035169088016940102, 0.025389580649413893, 0.023005982342686866, 0.05074316282726584, 0.08181449776935963, 0.0679626704884633, 0.03470463332750144, 0.039800619556298183, 0.030539126000216896, 0.05214341067438645, 0.0499987896651991, 0.12387152205431655, 0.06725008614481458, 0.010586224286065949, 0.013569679013603638, 0.03841408085258257, 0.03179470771893619, 0.034435518131020575, 0.036866181049375765, 0.017237972295392427, 0.017257450080867258, 0.037604820043329275, 0.034491932845764586, 0.038549992511229175, 2.5115867776255456, 25.508644119385753, 53.955869136318086, 49.87200321689729, 38.25548818034511, 28.46889807331947, 48.16338346850488, 55.10260151278589, 17.67379403114319, 0.7134086542552518, 0.7128951301978481, 2.9145048991326363, 3.4591586022607745, 4.824519234318887, 3.853698786227934, 5.804853391262793, 11.988665596131357, 13.979183147030493, 18.81468599842441, 40.67724973924699, 50.750743573711766, 52.847226896593654, 53.56196118939308, 52.0415642184596, 49.34698612459245, 48.67060084496775, 46.92821733413204, 46.334394024264434, 45.31477782034105, 47.128709285489975, 44.93544932334654, 40.306844634394494, 38.46707651692052, 37.46932752670781, 39.19104014673541, 37.12967380400627, 36.86546294919906, 36.90190569047005, 37.432570995823035, 35.88060678974275, 37.682257313882154, 37.30106569105579, 35.15841607124575, 37.40602831686697, 39.03116041614164, 40.99553438924974, 38.92476220284739, 36.48742883436142, 36.3094905114943, 37.18472034700456, 39.697461282053304, 42.12585556891657, 45.28905099438083, 43.49946568089147, 41.20416133634506, 40.3920385145372, 38.85890168528403, 39.200697022099654, 37.66286511575022, 38.52013441824144, 37.700782668206, 38.70119102539555, 39.78586366099697, 45.09112427311559, 49.64964797419887, 52.410541580569365, 54.13959687755954, 51.30615511248189, 49.580598569685414, 46.14711261564686, 28.02120658659166, 45.904161007173606, 44.97507702919745, 49.18516089839321, 49.16236016058153, 46.02196155055877, 46.4832087486021, 50.786221411920366, 44.857707946531235, 50.657218579323064, 52.207139230543575, 52.5218152999878, 39.252931225684385, 39.28891112727504, 40.130879263724054, 38.33745002746582, 39.924303716228856, 38.15686018236222, 40.19353128248646, 39.10315159828433, 38.4391963097357, 41.38854019103512, 41.35407432433098, 41.24048640651088, 40.575460310905214, 42.96610178485994, 44.094697121650945, 45.88786355910763, 46.90252580950337, 51.40400648117066, 52.126365861585064, 55.21123155470818, 52.574029891721665, 52.28191921787878, 53.724723862063506, 53.76819941305346, 49.510348919899236, 44.430899158600845, 39.20905167056669, 44.348482316540135, 54.208085383138354, 53.746014487358835, 52.076336030037176, 49.986948274797015, 51.375196672255, 55.43903889194612, 54.551649708901685, 54.916751769281205, 51.58076024824574, 60.20659746662263, 61.52427457994031, 51.30465676707607, 37.07557647458969, 20.303147031414895, 10.222496832570723, 12.80934310728504, 12.2605437040329, 12.964216912946394, 3.843470225411077, 0.013076797195319689, 0.1392944884156027, 2.675943893771018, 29.84192179095361, 51.996433427256925, 41.18484758561657, 34.728685117536976, 51.17722288254769, 58.21606520683535, 54.46316496018441, 22.624374320430142, 1.2425997612937805, 0.05730804604207797, 0.03247987186055511, 0.026460211506233584, 0.058934941001596956, 0.04955314865876591, 0.06565706759330726, 0.07377337844621751, 0.045098695949080496, 0.046311642959593766, 0.027004754463691386, 0.05522704097412287, 0.04816238498014789, 0.05005280652474012, 0.029537029369103334, 0.037500697203100695, 0.030804422248395223, 0.054509848611609596, 0.16487960343159017, 0.11583933531637154, 0.19640355461066772, 0.10105170099244964, 0.1782737314821251, 0.19732141987450663, 0.2226912182184958, 0.16166080840893332, 0.09308883755077278, 0.11871368188651339, 0.14971265599371927, 0.16128416894184006, 0.12098691756686858, 0.2119870240529699, 0.09261763219030635, 0.16508275462735086, 0.11105757537147692, 0.16100758055765785, 3.873258665684731, 32.15054454342012, 62.13630160977764, 56.71907694109025, 46.19876238607591, 35.66254654238301, 59.887006667352495, 61.02787117804251, 18.83299562238878, 0.906484445496913, 1.159355911997057, 2.2593313071035572, 2.0643642592814664, 12.299440868439214, 5.692465718715422, 7.574156128591107, 13.541034786931931, 16.7500993897838, 23.796404023324293, 44.09412445560579, 55.12677508015787, 55.49432077715474, 57.28011708105765, 54.11226580219885, 51.975342842840384, 50.798117960653, 49.75637958895776, 48.59331838546261, 48.55339650184878, 49.092047752872595, 48.621692811289144, 43.12506760320356, 40.96874067860265, 38.93783546263172, 40.267907265693914, 39.415972386637044, 39.76036041013656, 39.32589515562981, 40.60304634032711, 39.96940705084032, 39.675637214414536, 39.49446293615526, 37.07946354343046, 40.41924015168221, 41.28479742234753, 44.49443763302219, 43.741020925583385, 38.6207079118298, 38.53707513501568, 38.899011842666134, 41.732449685373616, 45.74862334036058, 47.01330923265027, 46.1389030948762, 43.40955318943147, 44.69385877732308, 40.43263504582067, 42.38174315421812, 39.96803814365018, 40.067729103949766, 38.95680404478504, 40.628086751507176, 43.6348266755381, 47.13206683435748, 53.8549034057125, 53.543628031207675, 56.45188508495208, 51.99278562299667, 50.351108966335175, 47.12386908069734, 32.869391441345215, 46.65855046241514, 44.68779087066651, 50.075876251343765, 49.68118775275446, 46.89603428686819, 46.92713868233466, 52.719789089695105, 48.13676234214537, 51.8923847136959, 54.12165595639137, 53.31475380928286, 41.93213755084623, 41.26623284432196, 40.84797482336722, 39.84931192090435, 42.086894665994954, 40.53297711956886, 41.44776013589675, 41.72705250401651, 40.1986538979315, 41.701482572863185, 42.101136792090635, 41.89681268507435, 41.57411144625756, 45.18626528401529, 45.650987702031294, 47.98332706574471, 51.098414621045514, 53.88660400144516, 54.73758574455015, 57.354422461602, 53.54021556915776, 53.33679752965128, 54.92381988033172, 55.39797952098232, 52.56462797041863, 46.05084588450771, 41.79830235819663, 47.73966550827027, 58.92906973438879, 56.15094907822148, 55.21869190277592, 53.318958590107584, 53.256447776671386, 58.49340031223913, 58.304542110812285, 54.60483312606812, 55.49139468900619, 61.20929256562264, 60.10029339021253, 51.85238438267862, 38.953936792189076, 25.006312054972497, 21.497365582373835, 26.626862825885897, 15.046218845152087, 16.28789415282588, 3.0498774157416437, 0.2107897512013874, 0.39087693537435225, 3.0282190682426577, 37.008707907892045, 52.921744085127315, 42.31589048139511, 42.54864392742034, 56.41428524448026, 66.99117214448991, 62.554869497976, 28.248115701060144, 1.969055812205038, 0.2185127448530928, 0.1312081545831696, 0.22983060608948433, 0.1853057444696465, 0.11679480017553415, 0.2933598261687064, 0.19654079160142332, 0.22528821031653115, 0.13701746060002234, 0.1205918383634379, 0.1570490357135573, 0.14000100534289114, 0.14691769145429134, 0.12550590169285575, 0.1637358494823979, 0.15578920412207806, 0.17026985935386152], [0.008004041146411891, 0.007706454771030094, 0.02672881533902499, 0.051051371490522746, 0.07184426946144912, 0.005959082909318949, 0.03298157901172677, 0.04419650101373273, 0.04750371024373078, 0.019743912928407232, 0.13797313996380375, 0.07442747197684742, 0.01543594006028387, 0.08946832134238175, 0.039546255382799336, 0.01325289591125423, 0.05109464396692572, 0.05174656946872992, 0.4534267580076572, 26.34658790403797, 53.52671477102465, 46.01362259157243, 30.551202028028428, 27.06980039996486, 55.836645633943625, 39.310409638189505, 14.2401070556333, 0.292555280630627, 1.9873073360612317, 3.7411723598357174, 0.5477369312317141, 0.984447987810258, 5.047656009274145, 2.2075636204211944, 11.594665473507298, 16.88192044534991, 26.31298495877174, 46.63682053166051, 51.24606832381218, 52.797734429759366, 49.60618811268961, 48.54843862595097, 44.79626009541173, 47.38672279542493, 47.447276346145145, 47.56208019871866, 48.60599940822971, 49.860730325022054, 45.046970152085834, 44.02516134323613, 37.655997045578495, 36.57182255098897, 37.451241477843254, 36.80099879541705, 37.34740064990136, 43.08689509668658, 45.443270744815955, 46.35872056407314, 45.303889320742705, 45.01007241587485, 45.82852986551101, 45.831620693206794, 47.757865305869814, 51.10037972850185, 47.50665710818383, 45.64347636315131, 38.066633901288434, 36.27231036463092, 36.844603784622684, 43.47460962110951, 45.82292872090494, 44.04721290834489, 40.49179615512971, 37.511355723104174, 36.30040237980504, 36.39197011147776, 36.14855958569434, 36.23511845065702, 38.06947761966337, 37.282069652311264, 40.029776250162435, 44.19061868421493, 47.46837477530203, 49.79121808082827, 50.93380451202393, 52.73787513855965, 52.09510457131171, 48.9492577891196, 27.305154377414336, 45.92763247028474, 45.81394649321034, 46.927248508699485, 48.608195935526204, 47.07057583716608, 44.64195797520299, 46.78477233456027, 50.402221372050626, 52.54662036895753, 51.61046435756069, 46.38062700148552, 37.55015580884872, 36.27556593187394, 38.34705198964765, 38.87147288168631, 37.422623865066036, 37.40869552858415, 37.64213146701936, 37.593682350650916, 36.66979159078291, 36.78321476905577, 35.857970791478316, 36.53505425299368, 37.51328945159912, 36.215694873563706, 35.827254710658906, 37.5738626141702, 39.37177119716522, 41.639277704300426, 46.90171780124788, 48.12671715213407, 53.02590262505316, 53.238087161894775, 51.63603036634384, 54.01354758970199, 48.23727307781097, 42.15058611285302, 39.22237203967187, 49.383628906742224, 55.09058337057791, 58.28711894250686, 53.602867587920166, 51.41360452098232, 54.34362288444273, 55.01057486380301, 56.02453500993791, 56.18154356556555, 61.61947442639259, 57.700810893889404, 54.81932401657105, 53.998336638173754, 43.00037937779581, 28.312309211300267, 12.513537560739826, 9.984506041772905, 9.540078947621009, 22.014632071218184, 3.382757450303724, 0.120830750543504, 0.13471855331332455, 1.3206442637789635, 20.373910511693648, 39.94936766162996, 22.706143971412416, 31.928928667499175, 45.3801441192627, 50.31316003491802, 54.08367172364266, 23.260253283285326, 1.0454086070099184, 0.0748271477078238, 0.03734349979147796, 0.035909555567007874, 0.03830197537618299, 0.01869029688438581, 0.007851313379022383, 0.027240680816072612, 0.020052565922660213, 0.04476379295210204, 0.02670045476406813, 0.01653467102216617, 0.0538042318376322, 0.040737610205166766, 0.07663765862103432, 0.032980119614231015, 0.02267043966229164, 0.04704957332221731, 0.04915512767770598, 0.015091145910593051, 0.027207468989335244, 0.026727945829230933, 0.07989596079794631, 0.04919998978655185, 0.03902700098772203, 0.05358255280542278, 0.061465310263297254, 0.07845989834036558, 0.0761117622436535, 0.0939704974993102, 0.04595873689639472, 0.14754212972137237, 0.0190375913535395, 0.003210483686885827, 0.020787175294132005, 0.0352285876719942, 1.165360693008669, 32.30268543766391, 58.44703789680236, 52.79956225425967, 38.68154387320242, 30.192677782427882, 56.99974213877032, 47.18259872928743, 15.97851328311428, 0.41748678491961577, 2.166375546686111, 5.08506610508888, 3.273089941470854, 7.483947007886826, 8.1521703254792, 4.603128894682854, 13.561297751242115, 12.133697194437827, 30.238122363244337, 47.94062814404888, 54.04888422258439, 54.66400600248768, 53.01421003956949, 50.34596673903927, 47.404028292625185, 48.80369078728461, 49.44598282537153, 49.1175353142523, 49.96489278731808, 52.36592461985927, 48.52248038015058, 46.22767809898623, 39.31974487919962, 37.660221438254084, 38.14251607464206, 38.31807351881458, 39.73106030494937, 45.029817627322295, 48.59412247134794, 48.339293925992905, 46.04853168610604, 47.32980135948428, 46.41377102944159, 48.00193478984218, 50.82584911777128, 50.5834387963818, 48.94465684890748, 46.22848610724173, 38.572858918097715, 36.24027244506344, 37.93859204938335, 46.20769754532845, 47.20158692329161, 45.689693650891705, 41.95076880916473, 41.27814508253529, 38.16979615919052, 38.84909575985324, 38.1222923340336, 38.362470826795025, 39.07314938883628, 38.719033887309415, 41.98168100849275, 46.36182315887944, 49.82742155751875, 49.57979840617026, 52.419990570314475, 54.73751906425723, 53.537140430942664, 49.3194353965021, 27.681423425674442, 45.0053341927067, 46.28977314118416, 47.158142751263036, 49.257567851774155, 48.732691964795514, 47.3012347375193, 49.181724902122255, 51.87198054405951, 54.59362691448581, 54.30424228791268, 50.3394595269234, 39.99266278359198, 39.992945194244385, 39.86742150398993, 39.675480319607644, 38.87370078794418, 40.07459325175132, 39.081641320259344, 38.91372857555267, 38.1826772228364, 37.76376024369271, 37.28593710930117, 38.98739460975894, 38.25886534106347, 37.59982870471093, 37.07444290960989, 39.72232126420544, 41.55627642908404, 43.786912656599476, 49.02484970708048, 51.32462163125315, 54.01738366773052, 52.87026689898584, 53.16323264952629, 56.44691936431393, 50.80263260872134, 44.811624019376694, 40.54688976657006, 51.96017503738404, 56.89352827687418, 58.96929756287606, 57.48151117755521, 54.865529537200935, 54.895143432001916, 57.97349799063898, 55.3103498489626, 56.671074974921446, 59.05586819494925, 58.61686868052329, 52.29663202839514, 56.22126540830059, 42.40199435141779, 28.928625352921028, 10.374851495988908, 8.793698972271336, 9.341721746229357, 18.49826055188333, 4.377658309475068, 0.14787337081807275, 0.16027778987922978, 1.3201460001930114, 26.250036801061324, 40.64021864245015, 27.754269684514693, 35.71942875462194, 50.74061209155668, 56.57162327920237, 60.13619092202956, 27.367478878267352, 1.4402837859046076, 0.020599945320657665, 0.023863468386773622, 0.03843514060962104, 0.017863031093692108, 0.01917626092871351, 0.07024922077694247, 0.053018152848967624, 0.022928812390854283, 0.028033953370346178, 0.0631560394991069, 0.01493900276405076, 0.021908260701644807, 0.07986906345092482, 0.11325450869457376, 0.08410305520820041, 0.03467566371264477, 0.0426465749079662, 0.15063916272934408, 0.08143385166242238, 0.0897173535439276, 0.1846133695254403, 0.23275793530046943, 0.1312550698076525, 0.1134460689800401, 0.137594907033828, 0.1156878797337413, 0.15039024544098686, 0.2577506804898862, 0.15268282484143011, 0.10861342547521477, 0.39124821222597556, 0.19328500985378222, 0.11869666707371512, 0.11758544121778781, 0.28587441170407885, 2.1899639454580124, 42.01304035802042, 65.57520827939435, 61.50819286223381, 40.43085036739227, 37.25795492049187, 62.367501797214636, 48.02868535441738, 19.90933322137402, 0.6113604107691396, 2.676721013361408, 4.938482228786715, 3.6948327431755685, 9.366107121590646, 15.432232041512767, 6.144812078245225, 18.25254563362368, 19.67345952987671, 31.571147711046283, 53.56884102667532, 55.97772936667166, 58.228989416553134, 55.691113933440185, 52.57828566335863, 50.423684581633545, 52.18140848221318, 51.61832086501583, 51.29278767493464, 52.7526742412198, 56.55227422714234, 50.546999977480986, 49.19846165564753, 41.16239593875024, 38.72492528730823, 39.85807841823947, 41.6957127663397, 41.560747931080485, 46.6573815961038, 51.50428971936626, 50.743648006070046, 49.51027047249579, 51.60512208938599, 50.48585807123492, 51.932749825139204, 54.076866411393695, 55.01839214755643, 52.961026622403054, 50.37585127738215, 43.54053289659562, 39.48101312883439, 39.59689955557547, 48.62109268865278, 48.976596709220644, 48.85182611403927, 44.46438835513207, 43.37120417625674, 40.6633488593563, 41.38750076293945, 40.56580343554097, 39.94605718120452, 41.379561885710686, 41.17872476577759, 44.73875422631541, 47.98662577905963, 53.23223498559768, 53.05086458882978, 53.61995343239077, 57.60874109883463, 55.19540871343305, 51.02519965940907, 32.227458300129065, 44.99866616341376, 45.66258222826066, 47.240383086665986, 50.22509497980918, 49.094079540621856, 46.293907319345784, 51.65326918325117, 53.86190091409991, 56.89024917541012, 58.49485943394323, 51.519080977286066, 41.095664655008626, 41.05512695927774, 42.10230565840199, 42.60985643632951, 41.49295368502217, 41.56338376383628, 39.963131258564616, 40.65681419064922, 41.073471884573664, 40.05438127825337, 40.09260477558259, 40.856733475961995, 40.81552897730182, 39.915694113700624, 39.21726119133734, 42.10416093949349, 43.67398369696833, 46.352483995499156, 51.181686539803785, 52.68097331446987, 58.025406637499415, 54.85966167142315, 54.000792041901626, 58.870587195119555, 54.908495180068485, 46.06434276027065, 43.32102137227213, 54.460952743407226, 59.3101829098117, 62.041199822579664, 58.97014479483328, 57.176182116231615, 58.60985156028502, 60.97658226566931, 58.526756148184504, 57.36627586426274, 57.358548795023275, 56.405424610261, 55.661017587108, 57.916227463752996, 46.74521915374264, 31.70609489563973, 18.766142745171827, 20.701644151441513, 17.655496174289336, 35.85884940239691, 6.3862550450909525, 0.293206884375503, 0.2099613803288629, 1.9966554473484717, 29.39159054909983, 50.28009053199522, 32.59884988107989, 44.24886588127383, 56.99498038138113, 64.79614319339876, 68.9498939821797, 33.69739593998079, 1.9974607589744755, 0.11324902350503592, 0.13823508074687374, 0.14381413137720478, 0.1462287792275029, 0.1097911784064866, 0.18297098426809236, 0.14735062306206073, 0.07826292181327459, 0.15572028685240977, 0.07271045443391608, 0.12448158085105882, 0.15746333606300816, 0.14722856993396438, 0.1733614837810878, 0.14161784922884357, 0.11692872766645686, 0.1562700775121489], [0.05293481397412477, 0.02517127814973074, 0.0336112649810891, 0.07488105731505541, 0.08797722312832072, 0.04105567458956953, 0.03331438292779269, 0.02299039245342776, 0.01785074878904608, 0.012366305229314154, 0.006403089754448663, 0.05710884786000656, 0.0608126225040084, 0.03477266576561717, 0.02708686759785539, 0.027064486339147535, 0.051770712729663625, 0.04028132440702569, 1.6198957350946244, 30.906174567437944, 50.81703162962391, 40.72518502512286, 20.335877249317786, 43.6733365058899, 46.13380401365219, 33.755533310674856, 15.15738764116841, 0.61967957404352, 0.34741750287432827, 9.342366976122703, 8.506847216236977, 4.188143601340633, 5.476997177447043, 5.146023169640572, 6.906098531138513, 16.054197376774205, 35.29776611635762, 44.2649515213505, 54.03186113603654, 50.73175930207776, 49.144176052462676, 44.449534339289514, 44.4710720739057, 44.313290811354115, 46.451253198808246, 49.145497891210745, 51.225060109169256, 51.09251929867653, 50.08435641565631, 44.04965654496224, 36.180342551200624, 38.743097628316576, 38.859678314578154, 36.377982939443285, 45.031833725590865, 50.67953294323337, 52.740326619917354, 49.864146709442146, 50.94910175569596, 49.11080844940678, 50.75962774215206, 51.49420530565324, 51.93729192979875, 51.05803382012152, 50.32071844224007, 50.29869041135235, 48.462695613984145, 40.059241094896876, 41.57355446969309, 49.07669167364798, 47.70128119376398, 45.319716084388, 40.58348548027777, 37.906267796793294, 36.52867647909349, 37.21290649906282, 36.58056943647323, 37.374472848830685, 37.30730225962978, 37.12269198509955, 40.60209712674541, 41.01266337979225, 43.28318226721979, 46.20652475664693, 47.890935636335804, 50.76859820273615, 50.3069705347861, 52.879837482206284, 28.754152444101152, 44.56565610824093, 46.97462681801089, 45.1750002368804, 48.55349063873292, 49.98853291234663, 48.014945291703754, 50.44921921145532, 54.85064022002682, 52.445309469776774, 49.07681718949349, 40.521355136748284, 37.24165747242589, 37.183276914781146, 35.804540264991026, 38.66612503605504, 40.091282936834524, 39.951689704771965, 41.9310785108997, 41.50408929394138, 41.235030389601185, 37.47738407504174, 35.95575155750398, 35.68620627926242, 36.05039834976196, 36.527640973368, 36.98287910030734, 37.50064765253375, 36.66127612513881, 38.14390459368306, 38.859129182754025, 47.52036971430625, 49.558915707372854, 50.44352000759494, 51.5282710905998, 51.91521683046895, 49.80942572316816, 43.298816834726644, 39.03078386860509, 46.70752909875686, 52.059685568655695, 55.07241102956957, 53.326748417269805, 55.59692998086253, 52.82789745638448, 54.54840590876918, 51.82666147908857, 54.496379590803585, 50.79177156571419, 53.66153840095767, 55.92191011674943, 57.867448868290076, 47.88909212235482, 33.99899482727051, 10.205904226149283, 3.152806292618475, 13.92476418325978, 11.959047778960198, 6.293843023238644, 0.103648156828938, 0.15716414808505969, 1.0828244638058449, 18.45043509237228, 48.734704140693914, 40.383950587241884, 30.03928565209912, 45.052943921858265, 52.91511135716593, 56.34647138657109, 28.260355457182857, 1.0950509819292253, 0.01469181108874299, 0.030441478518168294, 0.023108027169420835, 0.05834838578237161, 0.03370168633879193, 0.12114659327292636, 0.01576304811263277, 0.006907886155174986, 0.02711890347962899, 0.024105716879749974, 0.005339681670340079, 0.025153539383844025, 0.020487682796233607, 0.02591064684243212, 0.02713557163764152, 0.05146847189133687, 0.03466245635683018, 0.08834014962156934, 0.06690251205356852, 0.0350367094600393, 0.07400551840903298, 0.038695905447727254, 0.010584138611692094, 0.007731962626078918, 0.04681281384921843, 0.05081559261006694, 0.036046240974458, 0.015657011967813297, 0.02790672148788168, 0.02699888239975178, 0.037480844034542965, 0.14618845235916877, 0.014649618796313242, 0.04400925763371972, 0.019812200090757782, 2.3741008389380673, 37.53211682842624, 57.821470845130186, 47.93028093153431, 23.308451367962746, 42.90456764159664, 56.27482145063339, 41.03649962332941, 15.623391693638219, 0.664468935180095, 0.827402843823356, 6.202704791099795, 5.037938337172232, 5.796919416996741, 8.703828646290688, 5.062206041428351, 9.536904769559062, 19.206073822513705, 36.37181305116223, 48.99974261560748, 54.05481092391476, 53.380822212465354, 51.65199833531534, 48.53207449759207, 46.432072808665616, 47.013466127457164, 48.7349747842358, 50.83454109007313, 52.40240266246181, 53.24508859265236, 53.44988338408932, 46.26676451775336, 38.98947738832043, 41.24231423101118, 40.23106836503552, 38.37737975582, 46.88292572575231, 52.61923520795761, 53.44911459953555, 51.574762944252264, 53.954853242443455, 52.18073383454354, 53.45360179101267, 52.69650197798207, 52.52582788467408, 52.39575424501973, 52.52740467748335, 52.25955386315623, 49.014282841836255, 42.49046341065438, 42.30908909151631, 48.46688470532818, 49.85590973208028, 46.737543075315415, 43.23257584725657, 39.102743671786406, 38.657491899305775, 38.460581071915165, 38.715648881850704, 39.4453077931558, 40.46877968695856, 38.88133764266968, 41.587220007373446, 44.13639976132301, 45.62411554398076, 48.61616226934618, 48.63734699064686, 51.834015923161665, 52.44576054234659, 54.55085739012688, 29.861474806262603, 46.56568050384522, 46.77274634761196, 46.552360134740034, 49.346829229785556, 51.019127830382324, 51.0434857491524, 52.85148266823062, 56.473109029954486, 54.242398277405776, 51.18458124899095, 42.965034900173066, 39.005653242911066, 38.037463234316924, 37.503024608858176, 40.47685976951353, 41.43002317797753, 40.80723316438737, 42.78431561685378, 42.70735086933259, 41.82647282077421, 39.634868098843484, 37.18026061211863, 38.55735771117672, 37.799453812260786, 38.24616862881569, 39.08801909415953, 39.45539220686882, 37.778743697750954, 39.79129222131545, 42.956586114821896, 48.44292686831567, 52.08016034095518, 53.46707905492475, 52.23066168446695, 53.79560109107725, 53.49380608527891, 46.46442451784688, 42.061697360008, 49.4060609417577, 54.407737947279415, 56.457246964977635, 54.19461204159645, 57.0481441866967, 55.65815425688221, 55.87209993793119, 52.95897914517311, 53.64785717379663, 52.0733864076676, 54.66383734057027, 58.11395022176928, 57.83386945724488, 47.76385476512294, 32.29384441529551, 13.550175870618514, 11.270150138485818, 10.727225465159263, 10.776135460022958, 2.6065348569423925, 0.5596855126561657, 0.24091838047869746, 1.1832679063081741, 21.503176573784124, 52.25132473053471, 34.531523258455344, 36.587433584274784, 50.73457948623165, 61.07946995765933, 62.28960352559244, 33.50514881072506, 1.4553068313867816, 0.07255116177182044, 0.05431599389281004, 0.020573003923580534, 0.019471725719350002, 0.0365464159497811, 0.04859617460639246, 0.021392670122065374, 0.01186034533255283, 0.07732272508644289, 0.034998309302834735, 0.06352552370498739, 0.0788294974594347, 0.053582564296741644, 0.05547118170427219, 0.038565352574111, 0.024486521949931502, 0.023791699354807218, 0.1544480446365572, 0.1906375325615368, 0.12883326669614162, 0.188360933755194, 0.15749889786445326, 0.16162236611689293, 0.12188575320666838, 0.15078862648337119, 0.16345521615397546, 0.11460465439144643, 0.10769647185600574, 0.14190674098508974, 0.13580690378383284, 0.1880387784612756, 0.19195373290248458, 0.0943402345142057, 0.08478987601495559, 0.20572653821399137, 4.270901689606329, 46.71982965161724, 65.346436039094, 54.630053966276115, 29.67979846462127, 53.36577992285452, 53.61177529058149, 43.869317731549664, 21.012235072351274, 1.0001857626822688, 0.927501975768997, 12.191977731643185, 14.429379067113324, 10.718409938196983, 10.2283941161248, 9.478287889111428, 11.350956847590785, 18.355096001778882, 39.99209403991699, 50.72335758516866, 58.9405583566235, 55.72547781851984, 54.389447935165904, 49.39531756985573, 49.60421123812276, 48.107419090886275, 50.77662337210871, 54.86540794372559, 55.597855660223196, 55.46919799620106, 55.27430326707902, 47.468586583291334, 41.00576785302932, 42.18078836317986, 42.07033834149761, 40.50669723941434, 49.02714429363128, 54.15877726770217, 56.049371457869015, 53.93664560010357, 56.355692878846206, 53.917912360160585, 54.89455899884624, 52.726566945352864, 54.937218696840354, 53.67535298870456, 52.71115987531601, 53.61567804890295, 53.180020393863806, 45.30874521501603, 46.42793078576365, 52.25159929644678, 51.8227469536566, 49.790410072572776, 45.87543749040174, 41.854878625562115, 40.2331119198953, 41.39860891526745, 40.35141452666252, 41.806892348874, 42.66073742220479, 40.122893318053215, 43.4507223867601, 45.73608744528986, 47.947198114087506, 51.005042599093535, 52.01232687119515, 54.85375850431381, 55.096686578566036, 55.947770303295506, 34.04017579170966, 46.513481601592034, 46.845023862777225, 47.33723817333099, 49.45805588076192, 51.057920071386526, 52.95828880802278, 55.086472726637325, 57.692452323052194, 57.308181639640566, 54.35246390681113, 45.83404079560311, 41.24536191263507, 40.233751266233384, 39.02185263172273, 43.08396116379769, 43.77312160307362, 43.59585792787614, 46.74908661073255, 44.591390778941495, 45.210791864702784, 43.003046589512984, 38.995776714817175, 39.941417017290675, 40.069070554548695, 40.097429290894546, 41.0550485118743, 40.484892783626435, 39.616338822149466, 42.14992715466408, 43.31622431355138, 51.69396769615912, 54.357923846091, 55.53603518393732, 53.984145502890314, 56.264505617080204, 55.89297086961808, 48.474090099334724, 43.97668477027647, 52.382229912665586, 56.52756721742692, 58.10790584933374, 55.34343896373626, 60.22050226888349, 55.127587010783536, 58.92253506568171, 54.274173398171705, 54.193674595125266, 52.636995700097856, 54.88306253187118, 58.52576771090108, 59.903264891716745, 51.50914169126942, 37.08194248137936, 13.312296867370607, 13.975225475526626, 22.987756421489102, 20.46328171606987, 11.064258063993147, 0.6008461298000428, 0.34326858518104403, 1.7141768889081095, 25.44786503238063, 62.248002867544855, 49.67513945794875, 41.94414784831386, 53.82823128854075, 68.15435886383057, 69.3316347368302, 39.10514808470203, 1.777194423540946, 0.21336124789330269, 0.09438808436595625, 0.15712339220748794, 0.15746171195660869, 0.16927912380666504, 0.16769735142588618, 0.2282875364706401, 0.20974702892764924, 0.12521177755608676, 0.16598223378100704, 0.12126254834114544, 0.16196327524319773, 0.17863526369535154, 0.20496242679655555, 0.12071334756910802, 0.09966773251371999, 0.06533834437328963], [0.012451374505255974, 0.014873875714387867, 0.04108007065951824, 0.02004613461453588, 0.034967910933999286, 0.012657916597691516, 0.02203282276769319, 0.010163671254450756, 0.1052121100045981, 0.04245104245661248, 0.015078514078331572, 0.08277016947226179, 0.042494510285436146, 0.009137407422155864, 0.03522822761066979, 0.04721254703678912, 0.03801057085154518, 0.09878388155371913, 3.227490181884458, 29.8356459986779, 49.09154176712037, 43.86206134673088, 35.42975387265606, 26.625515491731708, 30.381277107423355, 39.186898123833444, 16.138287109713403, 0.5293442633363509, 1.167150642121992, 6.773912695146377, 6.383088711769351, 7.2514328264421035, 9.933992778101276, 2.038395349537173, 8.421506247212811, 14.636154655487308, 33.867513056724306, 50.07652736479237, 53.92442349464663, 49.27247678079913, 47.054078348221324, 43.86245750611828, 43.77429439175514, 45.01009595009589, 47.47831406131868, 50.739454992355846, 51.52857703547324, 51.621490140115064, 47.99741621940367, 40.07921772618448, 35.66173068938717, 36.58991252222369, 34.859417715380275, 37.99859254590927, 44.437708393219985, 50.20948002415319, 50.008003557882006, 47.93766283219861, 48.65569976068313, 50.35942046873031, 50.35249356300601, 50.99816668418146, 52.10843278515724, 50.67397886706937, 51.81083863781345, 47.82483585419194, 49.96966238944761, 48.70340362671883, 51.295305836585264, 52.956296243975245, 48.199214320028986, 47.72979290254655, 39.54295519859561, 37.06302489003828, 36.89923847875288, 37.627630464492306, 37.24390891290481, 38.25698260338076, 38.71440549050608, 37.80264662158105, 37.567633890336566, 38.58528106443344, 39.22049322435933, 42.07615521646316, 44.067542552948005, 47.90065919199298, 46.56671993194088, 55.13081904380552, 30.14918261958707, 41.382146727654245, 50.53656255045245, 50.718011394623794, 54.53122200504426, 51.30568050569104, 50.905830167954974, 52.128001489946925, 50.210958757708156, 47.39252398090978, 41.047584241436375, 37.92744467335363, 37.29340137973909, 38.07095635321833, 37.588944127482755, 37.65083520643173, 40.68472185442525, 43.7317092187943, 44.92411367354855, 47.69798248044906, 48.15762935146209, 45.25014500464163, 36.65550239624516, 35.48427481805125, 37.230561087208415, 36.28817635197794, 35.15439171944895, 35.52822889820222, 37.78736506738971, 35.455931771186094, 35.85552323249079, 38.89506201590262, 47.85173546883368, 52.30311570628997, 54.727218920184725, 54.87531585078086, 51.20476576589769, 44.158204217110914, 38.79158204601657, 43.53011115904778, 49.809594385085575, 53.671473764604144, 52.4579865701737, 51.82989351211056, 47.83324541584138, 54.58527226601878, 51.99134219077326, 55.522393180478005, 56.79757141297864, 59.0652975728435, 58.43215250199842, 60.983132623857074, 53.07764260999618, 36.44860913676601, 20.923985665844334, 9.84348604756017, 9.001064877356253, 20.82666970068409, 1.1569076175651243, 0.7042290823113534, 0.1256060830107139, 0.553946472223728, 16.765818288249356, 43.24788093566895, 36.79413856998567, 18.398369550704956, 30.06490069050943, 46.96592307859852, 49.2948813592234, 22.36768068805818, 1.1202345596205805, 0.04500341376349811, 0.04221311852996869, 0.04915420837219685, 0.022253092198121934, 0.05521811221936538, 0.02916224000434722, 0.05506650341915027, 0.10292073336219597, 0.03226230289005945, 0.062406384160802256, 0.0712766902401082, 0.05715384020379955, 0.01616405109093795, 0.03839029765297328, 0.014727793280936539, 0.04341164393530738, 0.008365376570802784, 0.03947915374151161, 0.0664182448939931, 0.03022165150351582, 0.027071429010961327, 0.06272977285627877, 0.03207848775350759, 0.05273176620023386, 0.07175598548905504, 0.04585935614041744, 0.02965361837507977, 0.04978122069470344, 0.06780304074768098, 0.054365257176780896, 0.045555544821845914, 0.048028829041868455, 0.03034549153169557, 0.09072334956257574, 0.1019642189625771, 3.88614070992316, 36.265297166762814, 56.03226600154754, 48.27941502294233, 35.95735580690446, 36.1088377429593, 40.14689822350779, 40.39023422425793, 19.199517580770678, 0.7525170137805324, 1.2790378447501891, 6.962212449119938, 8.915849424177601, 9.000890331883586, 10.22631427934093, 5.706480837637379, 6.971583481757873, 16.53280008223749, 35.6585378800669, 49.90204072767689, 56.08624565985895, 53.35399712285688, 48.9647158499687, 45.58685302734376, 45.564483750251036, 46.35608080894717, 48.1847329293528, 52.56754229145666, 53.93428433325983, 53.791259027296505, 51.36155859116585, 42.88517936583489, 38.157056300870835, 39.09223564209477, 37.065613654352006, 39.53463977383029, 46.269302291254846, 51.00448562252907, 51.40388488769532, 48.292496127467004, 48.22752206556259, 50.01608756280715, 52.12149035546088, 52.35552249416229, 53.78404971091978, 52.33471432039815, 52.719840080507346, 49.85933003887054, 51.97335420116302, 51.42741910872921, 51.77896545779321, 52.980724765408425, 50.323334663145005, 49.34192234469999, 41.90735209372736, 39.49205067849929, 37.68313984717093, 39.336203144442656, 37.75924559562437, 39.37163783657936, 39.80118443889003, 38.72236005721554, 39.24626711876162, 42.17676793375323, 42.33216047286987, 44.651222613550004, 45.83690804819907, 52.08476128116731, 48.58536381875315, 56.632137606220866, 32.281898836935724, 41.05010632545718, 49.56564649458855, 51.77749456897859, 55.70725840906943, 52.08187833909066, 53.95561810462706, 53.22688487268264, 52.03824981566399, 50.64483173431889, 45.020658892969934, 40.064912842166045, 39.38984155654907, 37.8591718981343, 38.571168376553445, 39.48843033083024, 43.32727755269697, 45.30384225230063, 47.062244722920084, 50.91590281455748, 50.99125154556767, 46.08915567398072, 38.33074669684134, 38.75745742551742, 38.79075050354004, 38.21213030046032, 37.2749230938573, 37.47798812004828, 38.39202588604343, 37.77358185860419, 38.75819483110982, 41.38360192698818, 50.375498264066636, 54.39929700666859, 55.507021411772705, 54.99340272718861, 54.05067282338297, 46.826129805657175, 41.185518310916045, 46.2551543020433, 53.33575810155561, 56.184367672089614, 54.59109698572467, 54.81048299420265, 51.26273447467435, 54.1733802518537, 52.14340463761361, 55.380693635632916, 57.97663588677683, 60.54814961648757, 59.79423869040705, 60.944548268472, 55.818139891470636, 36.216675466106786, 19.866379345616988, 13.545170926278638, 10.344442340635485, 10.963366858420834, 4.7803714871406555, 0.1334279403090477, 0.16967856205038487, 0.7081993789442125, 18.794217109680176, 45.482600350533765, 42.243918911103286, 28.912614237877634, 36.03970204630206, 55.29681767186811, 54.572202928604625, 28.084068452158284, 1.1625641656498755, 0.07190020920168008, 0.0965723465947855, 0.052459448756229494, 0.05464298320153067, 0.032309949728510076, 0.022552015875736554, 0.0625692238099873, 0.0687431685265995, 0.11522130920521675, 0.032338245185993375, 0.049007881748219656, 0.025083781332678856, 0.034933111390038844, 0.008899733431697374, 0.010727787758373927, 0.029763823953427138, 0.02577790487257223, 0.13021499819813237, 0.09881988002528107, 0.15902132907461736, 0.10354660421369538, 0.10691489363389631, 0.20880366825769026, 0.1688456099720732, 0.10920532032727234, 0.22521046771397515, 0.1420814090318257, 0.15731724309584788, 0.27109636114008967, 0.13851241989722177, 0.12703731911437166, 0.09437498426245106, 0.113742430093548, 0.10146729603049257, 0.34301225216157977, 5.7057855975243355, 43.022403486313365, 62.33567568563647, 56.73050672777238, 46.76980456998272, 37.25777056909377, 39.48930109700849, 49.66541590229158, 24.086849651029034, 1.1814953627124911, 1.5200466542474687, 10.261892137988921, 11.035947376681913, 12.37936798603304, 19.615651638277118, 8.15341861978654, 10.863579800052028, 18.350979474283037, 37.79273086978544, 54.03027257611675, 57.663764107611875, 54.99105322745539, 52.29026994397564, 49.17164833314958, 46.86898169978973, 48.45981267190749, 50.411689973646595, 54.910028826805856, 55.02263615208288, 56.63696604390299, 52.737812380636896, 43.63474038339431, 38.75972455547702, 41.17728525592435, 39.22128946550431, 42.101403513262355, 48.846719188074914, 54.21749122681157, 52.62518544350901, 49.035142006412634, 49.14605879014539, 50.92568128339706, 53.50786778234667, 54.346592118663175, 56.546814287862475, 55.21126293366956, 54.25053719551333, 50.47758579254151, 53.59592499271516, 54.12528414880076, 55.71099250547348, 57.64424639363443, 51.573833342521425, 50.767558774640484, 41.851434784550825, 40.346582166610226, 39.60776059858261, 41.73987865447998, 40.257422770223315, 41.3583497078188, 42.045635254152366, 41.56299544918922, 40.34688026674333, 42.971577413620494, 43.78264119548183, 45.4716294811618, 47.99902046880415, 52.618242848304014, 51.33307041660432, 58.99209045594739, 35.55374391617314, 40.91720073453842, 49.16079905725295, 53.56592278326712, 57.20249337534751, 55.556086340258204, 56.265556812286384, 55.24420692074684, 53.457641832290165, 51.15242173594814, 44.68382143205212, 42.38485359376477, 41.85681627642724, 39.78861716485793, 41.67199419390771, 41.73451677445443, 46.04808845827657, 47.72521157418528, 49.309229389313735, 51.08221130986368, 52.67157139316682, 49.53093744093373, 41.05889635701334, 39.83854109241117, 41.321138181994044, 40.27763866609143, 38.78575340394051, 39.55085485212265, 41.89149787349086, 39.51982890405963, 39.399463130581765, 43.29742831568564, 52.74161315733387, 59.01735444222728, 57.679312382974935, 57.10157079081382, 56.643175155885764, 49.27924679171655, 42.71521522152809, 49.33599956573979, 54.23258450723464, 59.89107416522119, 58.30265937312957, 54.92326682613742, 50.96985893864786, 56.43598379627351, 52.4654390735011, 57.692428788831165, 59.56771396821546, 63.273208448963786, 62.77538122669343, 65.92542494496992, 56.39740336325861, 42.23897672468617, 27.732376975397912, 20.83904085620757, 16.997669589134954, 31.44047590994066, 6.374388894727153, 0.9030653031602983, 0.36745526797829137, 1.0360660115557334, 21.747732431657855, 55.93694063924975, 48.37524637099236, 28.725415199033677, 42.93296167927404, 62.03690482724098, 64.0464880389552, 34.61304187774658, 2.4677851796150208, 0.11425962371210899, 0.1237439607540446, 0.24578847802214085, 0.16729353115923945, 0.17893455892560944, 0.160725798097349, 0.15336332542280998, 0.15079749778153437, 0.22358420094655407, 0.12660608056091494, 0.1981808939167569, 0.33915230283333414, 0.12428783721500829, 0.09983706858850296, 0.050090333341710994, 0.1767227864794193, 0.09260991768490884], [0.029708043176440463, 0.011784008501337902, 0.02094888879406837, 0.0455987291981376, 0.03814756269416502, 0.02578230030203779, 0.040634215148466254, 0.10222128742644865, 0.029109353124494516, 0.06266345262467381, 0.012957716488369532, 0.041760961945739486, 0.011595149633414563, 0.050387560134573336, 0.08400556285895648, 0.07083367691525529, 0.02267827291131741, 0.052227033001761285, 2.7720476013998834, 27.482969145621023, 50.67370430115731, 39.023896186582505, 25.432563866338423, 13.666834023690994, 25.250497248864946, 39.55293763068415, 16.6037537974696, 0.4652839911080176, 2.5734773662782486, 13.818459126257128, 8.424021467085808, 4.440972718500323, 7.895375201779028, 2.619977064671055, 3.5448820023767413, 13.339710312504923, 35.093932305612874, 53.39714711712253, 47.608124902171475, 48.03320392485588, 46.24000610843782, 44.086495445620635, 45.38710240394839, 47.12102536232241, 48.65678625722086, 53.61316380962249, 50.898448267290675, 51.159364331153135, 45.651709418143, 39.4934941107227, 33.59035053560811, 34.48157579668107, 33.7148073411757, 35.967291170550936, 38.72854563497728, 47.40790359435543, 50.147028046269575, 49.79024141065536, 46.29269922933271, 51.4694159261642, 48.372751743562766, 46.972889208024554, 46.39672833104288, 48.03930713284401, 49.35575262192757, 51.49008289460213, 48.03317646826468, 51.3873246408278, 51.078175190956365, 50.12212099567537, 49.34630363218246, 47.364663385575824, 39.13155348070207, 36.21952310685189, 36.531986959518925, 38.28348213626493, 36.347125653297674, 37.85581827163696, 36.71234538478237, 37.48970816212316, 35.67666707500335, 37.095568795357984, 35.2541728942625, 39.85993762170115, 41.60939708832772, 46.13132899807346, 46.03830998943698, 55.00856268790461, 33.722428506420506, 43.49853215679046, 54.44176058615408, 51.726421386964866, 50.29359917486868, 49.82848844220562, 51.85036828441005, 48.460467707726266, 46.29402499045096, 40.64904005296769, 38.337473561686856, 37.1437668800354, 38.09904444602228, 38.98389585556523, 36.92740501896028, 37.87632834526801, 38.95893781415878, 42.30864586368684, 47.82840521104875, 50.75550533110096, 52.747743821913204, 49.701411493362926, 39.512419546804125, 36.871036637213926, 36.61045005244594, 36.58155395138648, 38.990324620277654, 37.73275390748055, 38.69255396627611, 35.978473847912205, 35.988315074674546, 35.90231710864652, 37.89735224939162, 48.96447658538819, 51.892529841392275, 52.978014407619355, 51.705813254079516, 45.90554168147426, 40.75679932871173, 41.45322007517661, 44.33485600256151, 48.762815767718905, 53.60861778259278, 51.694230494960664, 54.57887095789756, 51.49036922762471, 52.8076619486655, 57.22533725923108, 53.47221735985049, 56.01148528437461, 56.89621117807204, 60.144729921894694, 56.787133985950106, 41.44764246479158, 22.078613773469005, 19.28260514813085, 7.896413158985877, 12.753634664320177, 2.14160087608522, 0.5752293753527826, 0.1423331148802273, 0.5233342729268536, 15.227314676007918, 46.976650761019805, 31.483570991023896, 25.749285451827514, 32.552611020303544, 49.632420924402055, 53.821457355253166, 25.012642760430616, 0.9581609983598033, 0.046793290098468145, 0.009906527139396678, 0.05088665109548358, 0.06802475425384699, 0.05149998491810215, 0.09792236205671104, 0.06192949059749804, 0.03124723447516801, 0.015607355106171342, 0.03367434849121398, 0.021771623174689954, 0.0907961815415371, 0.017684668587941318, 0.036878139681873784, 0.03195327259750376, 0.025896508689789523, 0.07899504139899247, 0.041776731865660804, 0.05402249028725971, 0.03273752638168874, 0.0160106448569305, 0.02834680644164403, 0.019679973315026973, 0.06542187093967392, 0.033326035125120994, 0.019007913107352874, 0.009523926550642619, 0.0354516226798296, 0.01985149465561394, 0.016326442578687303, 0.05036856881493042, 0.036882134830398906, 0.03302444546152988, 0.06991425649293008, 0.03920847955610483, 3.6525944548268474, 33.90323800425376, 56.830319281547304, 47.41947458636376, 34.65727052380962, 19.47026114309988, 32.12076394788681, 47.44739793962049, 19.15027222325725, 0.6487829478517656, 2.6825143541059187, 14.325326431182123, 7.787121707393278, 8.383239603811695, 8.713874816894531, 6.543396471008179, 8.551841705076157, 15.81665961973129, 37.73489159922446, 54.533963741794715, 51.60370611375379, 50.06820017291654, 49.03908398843581, 46.72685853896603, 47.49192468581661, 49.61529585622972, 50.95198077540244, 53.98189014004123, 53.28699519557338, 53.94452564177975, 49.12172832796651, 41.99537792513448, 36.658424562023534, 34.96319970776958, 35.43858705028411, 38.05571010035854, 41.414416067061886, 49.03161971799789, 51.18069810252036, 49.316419093839585, 47.726855047287486, 53.29679327626383, 51.899142957502804, 49.65103649323987, 49.217269420623786, 50.250202071282175, 51.28369954324538, 52.65039843897666, 47.991105125796416, 51.455099275035245, 53.575093284729995, 51.707009576982074, 51.60257647114416, 49.462856861852835, 42.221494720828154, 37.54947723880891, 37.99830621288669, 39.0532825839135, 38.50245237350464, 40.152220879831624, 38.64836846628497, 40.311708373408166, 38.6740796027645, 39.88104389559838, 37.30223455736714, 42.72822180101949, 43.95072260210591, 47.22960049106229, 48.19124014146867, 56.49423491570258, 35.91219363674041, 44.033421854819025, 55.196424607307684, 53.72446498563213, 52.74231918396489, 51.90491276402628, 53.45281339460804, 49.29005684391145, 48.94658273266208, 43.00782795875303, 38.771122963197776, 39.67928501867479, 40.49650692170666, 40.41502752611714, 38.6334163911881, 38.85579516810756, 39.89383082236014, 45.842195403191354, 50.165537711112734, 52.65205367918938, 54.46587139560331, 52.18896296716506, 41.75474443743306, 39.017600782455936, 38.50117760319864, 37.69809584463797, 38.31923061801542, 37.91518334419497, 40.127580550409135, 37.26938862954417, 37.12971302770799, 37.65714237766881, 40.09323627718034, 51.72206755607359, 55.081714891618304, 54.51263389279766, 53.87098120104883, 48.64324623538602, 43.46211687211068, 43.023101668204035, 46.10882243802471, 50.774705333094445, 54.77363624880391, 53.024922032510084, 53.98964074350173, 51.56592976662421, 53.68091098723873, 58.52710131675967, 56.34115265261743, 56.88569922601023, 59.10779645366054, 62.664860602348085, 58.77526575519193, 45.49496758368708, 24.110193637109575, 10.402249251642536, 5.2216744134503035, 13.72976060836546, 2.9956746726266803, 0.275985197194161, 0.0776720458581563, 0.6652774337318637, 17.147955202287246, 50.858816639069595, 35.1256799697876, 25.483366404810262, 36.86889502309984, 54.86343499152891, 60.0750490157835, 30.899936037678874, 1.4302020688210766, 0.030469804619168563, 0.06485403124843875, 0.013360301438238353, 0.07004170288001338, 0.03906460441348534, 0.04556700932763277, 0.0075190816348749065, 0.01195654682364435, 0.024251223789648186, 0.06346595653843495, 0.04375699637157302, 0.06924299493191705, 0.013651932916423727, 0.08005242659560136, 0.07680440531863321, 0.008071312763457818, 0.09249760153433008, 0.08241248302041523, 0.17669076400418438, 0.13106563158573645, 0.1311006877691515, 0.16786314817445894, 0.09470566611496672, 0.18983988181477596, 0.23527401319194227, 0.16732924617826941, 0.15365189542212795, 0.16188980741125925, 0.17757308278833667, 0.13534501405252566, 0.10145745180066555, 0.1343343448975394, 0.0992268872176928, 0.1614022996997641, 0.1833883183257234, 5.963596615099139, 41.03003555728544, 64.10652383681267, 51.356949806213386, 39.54408484120523, 22.987381835137647, 36.176047555861935, 50.14055221311508, 23.248743088014667, 0.9914675595298891, 3.2481728398030807, 16.017158435237025, 14.823083050789373, 14.917358198473531, 15.916642796608711, 8.620853847072972, 7.9423387204447105, 14.951417119272294, 37.51507413002753, 56.98179729523198, 53.46677703242148, 52.47977533648091, 50.39187023716588, 49.95044669797344, 51.0789361307698, 51.48117126957063, 52.66990046347342, 57.433975973436915, 54.148198635347434, 56.28166206421391, 50.6191284425797, 44.49330799041256, 37.920580525552076, 37.13525925913165, 37.24069649173368, 40.64036377014653, 42.30346441268921, 50.41415322211481, 52.10811507317328, 49.87831823287472, 47.45320304747551, 55.590995434791814, 54.73749553003619, 52.16035319912819, 52.32536731227752, 52.319546514941806, 53.46556502003824, 54.42471788775537, 48.28636938525785, 54.71230999115975, 54.429224691083355, 53.7560086865579, 53.37868452072144, 51.13488089653754, 43.51722225066155, 39.4736861413525, 39.356426885051114, 41.61704178779356, 39.68229347659696, 42.98443494304534, 40.072028021658625, 40.89829883267803, 39.793233794550744, 41.3276336269994, 38.7042308622791, 44.801472925370746, 46.03671358477685, 49.753849660196614, 49.99236506800498, 58.748428898472945, 39.72516890495054, 43.84180230479087, 56.15327112136349, 57.04848935527187, 54.837770923491455, 55.28728631234939, 56.00531147372339, 51.50703537848688, 50.47642869334067, 45.972178828331735, 39.32612657546997, 41.55904954479587, 42.52740037056708, 43.13774470360049, 40.701486064541726, 41.33380743765062, 42.96274815836261, 48.110431471178615, 52.98720452093309, 53.02441212438768, 56.87145709991456, 54.764391222307765, 44.89634721509872, 41.05176548804007, 39.830406096673784, 40.236583217497795, 41.51545632270075, 40.75834474255962, 43.08997807964202, 39.95207409704886, 39.57764464039957, 39.94705738559846, 43.129480269647416, 54.37663747418312, 56.59732657094156, 55.823078155517585, 55.82522761437201, 52.63664660915252, 46.240476792858495, 46.38161543876895, 48.57780933380128, 54.017038499155355, 56.657421204351614, 55.205285241526944, 56.31223693970711, 54.08250285733131, 55.36923246998941, 61.58123131721251, 58.801624082749896, 61.293250899161066, 62.24478260163338, 66.1977158823321, 61.444081721767304, 46.82834594480453, 26.134044470325595, 28.168819104471517, 14.855690694624379, 18.149861904882616, 5.508751215473299, 0.6229119135006782, 0.3578420596257333, 0.9159144362615002, 21.294686909644835, 57.947935904226, 42.79018348263156, 35.378896421001805, 46.183920137343875, 64.264822852227, 67.43751433587843, 36.95438700337564, 2.3150919666213374, 0.15968866826545808, 0.1079953840423015, 0.11817712922610583, 0.26853361317226965, 0.11247029513000481, 0.23478284358016907, 0.2968638510473313, 0.21615446575226324, 0.07335555409231494, 0.14487534701343507, 0.14029936594588144, 0.14505019892127285, 0.10235716078069904, 0.19074913625034595, 0.21530107444813176, 0.0528186482317265, 0.1202873720396911], [0.0320956347164728, 0.024934129887110284, 0.04230357053118848, 0.033727273675462896, 0.012947313971967708, 0.045035554982361295, 0.009786976245982994, 0.034190898595918576, 0.038257925320536866, 0.0207495546313904, 0.017434307223846836, 0.0409664674812267, 0.07416448931420043, 0.10394216605251837, 0.021838937405376666, 0.0439455229488592, 0.04080721695396689, 0.0376107304116651, 3.4641022595667073, 30.585793410578084, 55.06993993636101, 34.40533276527159, 44.04778949676022, 49.11387966525171, 28.91222788441566, 39.74810692571825, 17.51787393323837, 0.8552867895172489, 1.2710762913188627, 24.96410539073329, 33.30699459198983, 7.447304225737049, 6.706109133458908, 4.928607661877909, 3.69034432595776, 12.959319833786259, 35.997677772275864, 51.630080130792436, 51.224632570820475, 48.4100809404927, 44.61436017867058, 46.49734497070313, 45.44534960100728, 51.78822617377005, 51.37769914442494, 55.45468914893366, 49.8684887732229, 50.575421471749586, 39.98389628625686, 36.02195332127233, 33.92840785364951, 35.46124266039941, 35.60212635224865, 37.585535587803015, 42.31278788658881, 46.714506995293405, 50.087058928705034, 50.54023388893374, 49.377313890764796, 47.99808694470314, 45.31499355070053, 42.909768704445135, 43.38097872272615, 45.56228330058437, 47.38889578850039, 49.82743332462926, 51.89979014858123, 50.365959059807565, 48.89436814092821, 52.12383593282392, 48.049211117529104, 41.6778895162767, 36.85683765719014, 36.39101305315572, 34.8481918919471, 36.809035731900124, 35.778766370588734, 36.378610518670854, 35.50000744481241, 38.215103457050944, 35.83558974727508, 37.187897466844134, 35.70309600522442, 37.63941718686012, 38.538361672432195, 46.013504920467255, 47.58030745290941, 53.79343986511231, 37.1872071296938, 48.58037064152379, 52.239306588326734, 47.59323166262719, 48.4863631956039, 46.50318537988971, 45.483169094208755, 42.755909812065866, 41.57723365291473, 39.25238601623043, 40.0073246032961, 40.365656652758204, 38.44250679016113, 37.86564773128879, 36.443768931973366, 37.13057202677573, 38.71126367199806, 43.32172347653297, 47.06719083170737, 52.40332834182247, 50.86413929539343, 50.57293861143051, 44.025279014341294, 38.74003817958217, 39.7370340747218, 42.51800629400438, 49.02432803184756, 47.8675308535176, 49.57140453400151, 44.16107539207705, 39.171298857658144, 35.526404996072095, 34.95134238273867, 37.579671644395404, 45.59806316129623, 51.81225853581583, 49.19607685458276, 45.51827038488081, 42.2879514386577, 39.48719870659613, 43.41615453843148, 47.26372511156144, 51.368630624586544, 52.73692984734812, 52.03218190900741, 48.01326259489983, 51.74616267604213, 55.857614624884825, 55.13512580625473, 54.32648997153006, 53.65210117832307, 58.69889720793694, 58.878416245983495, 46.85393548780873, 24.385836239784, 11.44647538661957, 3.41321686102498, 1.7369577697207852, 4.896795278595341, 0.14866340665086625, 0.15227492898702621, 0.4184793284343135, 12.482188997730134, 39.40936711526687, 45.1990012199648, 33.50767089474586, 31.583967977954497, 51.176261901855476, 51.129875952197665, 27.090614457284254, 1.2053157941948984, 0.06538960331630322, 0.02832265935027071, 0.04720838717936028, 0.11044173261090634, 0.023413345765983386, 0.05682073368300354, 0.029219916848946485, 0.03305749449458334, 0.020539435865958373, 0.02197537957991083, 0.06145374616608024, 0.009145227264642957, 0.08657000388108915, 0.03799136502728347, 0.044042084501275135, 0.07837156840269605, 0.07509811300664179, 0.0774392547206052, 0.029116759279502497, 0.050240455931353, 0.07241317401489905, 0.01436911091478842, 0.01180014422824306, 0.03279895897233679, 0.04330397793842901, 0.015389247958908881, 0.03665822648232983, 0.03322465871010096, 0.0042703952978275, 0.07214377153544657, 0.03051464183015689, 0.040992759618788, 0.04408898057355996, 0.034443244127736944, 0.03937655158581273, 4.606129017568404, 35.19800455339494, 61.06735375619704, 40.698563898763354, 46.02676645401986, 48.218704577415224, 31.992865262493012, 44.60992397800569, 20.286216120566092, 1.2361070129179186, 1.7460776480936235, 25.783900368598204, 22.222590254199122, 9.178523690469804, 11.012228804249919, 10.416805167352, 9.757522402271148, 15.367568827444508, 34.749826692765765, 53.92869103339411, 54.660154234978464, 50.044803234838675, 46.8273731970018, 48.31494385196317, 47.55307443680302, 52.872384978878884, 51.63754440123036, 55.2814184465716, 52.477665101328206, 53.127574382289765, 42.69836864163799, 37.743548270194765, 35.849431791613185, 37.35368036454724, 36.85717498102496, 39.6053248067056, 43.4633602634553, 48.74307447864164, 52.628829325399096, 49.943896339785674, 49.969019120739354, 50.25710936515562, 47.11153714887558, 45.56429155411259, 46.38269409056633, 47.75777901372602, 49.713127613067634, 51.563741084068056, 52.451228326366795, 51.04408979415894, 50.58828684591478, 52.84682681483608, 50.36864196100543, 44.77788379115444, 37.90716601956276, 38.787710666656494, 36.72364573324881, 39.23069530917753, 38.018867277329974, 37.82875783981816, 37.118334231838105, 38.84547933455437, 37.377430315940614, 39.28329821555845, 38.546775156451815, 40.7667503818389, 41.287284205036784, 48.94900675742857, 50.4900118612474, 56.392869103339414, 38.98719064650997, 48.18688238820722, 54.17336456237301, 49.8406477897398, 49.49950356637278, 48.914709552641845, 47.29294676934519, 45.90158400997039, 44.597843077874955, 40.50041360239829, 39.93087368626749, 42.96010448086647, 41.0757900053455, 39.36170639530305, 37.36976992699408, 39.594393161035356, 40.683674581589244, 45.687999186977265, 50.24090213160361, 53.64052626394457, 53.48550242762412, 54.12544104360766, 43.855856157118275, 40.749072259472264, 41.63177028779061, 44.67669056307885, 49.18902443301294, 49.801537836751635, 50.21189228180916, 45.349992859748106, 39.86109864327216, 37.08573933570616, 37.2723460966541, 40.586548851382354, 49.30066685522757, 53.00260374622961, 51.358950215001265, 48.122037764518495, 43.087083370454856, 41.83390178988057, 45.274259736461026, 49.70504753051266, 52.84040589486399, 55.863690376281745, 54.35872400960615, 51.16028608814363, 54.07309309128792, 56.591529307826875, 56.68399526226906, 57.762172452865116, 56.36196867112191, 61.3667796504113, 59.693143521585775, 46.91805839538575, 25.462436637570782, 14.772343270240293, 1.7180227728620654, 3.336531827526708, 3.787003048966008, 0.4551234588988366, 0.042166865971540256, 0.4984221355088296, 14.777140328961035, 42.9527461144232, 44.449922653936575, 33.51608830113565, 35.80585033662858, 57.42148714680826, 58.71269610620315, 31.145294020252845, 1.4000092566974702, 0.025118341474162958, 0.051134373286678914, 0.03461958224614782, 0.06466901335384577, 0.06881849795219398, 0.026843939201846242, 0.024873070764325322, 0.023986714696812055, 0.04457060472979661, 0.027153231879515995, 0.03276826565965049, 0.02622210563370778, 0.07725282722423155, 0.021330977061523065, 0.022345110849146883, 0.03902412815800598, 0.05110222057649686, 0.11176808361685085, 0.11838147551902842, 0.19746576616119957, 0.1809758614868887, 0.15300093519110836, 0.1314246050652958, 0.10345018438754544, 0.15230800866359664, 0.08753530530919952, 0.1641608750627887, 0.09267259133799423, 0.15630315718871934, 0.19000100542701062, 0.13845268036088637, 0.24886531695242853, 0.1591251186665989, 0.07850093000959005, 0.22445774036309413, 6.578811551294019, 40.97703256914693, 68.98810571239841, 47.7019166177319, 52.9165037985771, 59.14086987895351, 40.51517348135672, 50.05139673909834, 24.32926389478868, 1.5952739143563857, 1.8766624216110477, 26.30917633733442, 38.546104431152344, 14.829117617299481, 17.53552656019888, 14.00811553001404, 7.3725418890676195, 16.050648612360803, 39.42036151885986, 56.99633752146075, 55.76698433968329, 53.34935303657286, 49.71513978896603, 50.891246795654304, 48.80684045053298, 56.59590275056901, 53.51803848820349, 57.90673140556582, 53.7911884246334, 56.83448091630013, 44.16216581098495, 39.92327997761388, 37.47688593402986, 39.81416748416039, 38.602598328744214, 42.852647227625695, 46.20144528727378, 51.90945879105599, 54.79988474999705, 52.17737628567604, 51.524199670360936, 52.4313929004054, 49.43227806398946, 47.82400823408558, 48.78213736318773, 50.308837582988126, 52.72089912045387, 55.3548530609377, 55.41354348582607, 52.65571717293032, 53.132065496137066, 53.85555844153128, 52.93712762094314, 46.44289855034121, 38.53038749387188, 40.55573471130864, 39.636966566885675, 41.458789840821304, 39.305647880800315, 40.36460153518185, 39.11672299908054, 41.27308914738317, 39.44450370727047, 40.74543622232253, 39.472607489555116, 42.35884827952231, 42.46525041518673, 50.3697794483554, 52.55145272900982, 57.58065692840084, 42.29139135729882, 51.23026509438792, 56.67031403510802, 53.296938403960205, 51.470290614712624, 50.867838090465916, 48.409053279507546, 47.925876109830796, 48.49135245046308, 43.99642213698357, 42.806171063453924, 44.83452281644268, 42.46799215193718, 41.55729624532884, 39.72571803677467, 40.724730030182876, 42.802162401137814, 48.62344611075617, 51.72301284728512, 55.36667508463706, 54.86576880178144, 56.818336440670876, 48.882499048786784, 42.498025740346606, 44.00648693884573, 47.23327182954358, 54.52660929772162, 52.69971047678302, 55.477027047065, 49.01746780641618, 44.37148701760077, 38.23786497116089, 39.47536491578625, 41.56997726809594, 51.77602368016397, 55.71690351732316, 54.07122212071573, 49.56673299112628, 46.657420819805516, 43.563953368894516, 48.192338405116914, 52.074931821515484, 55.824399994265654, 57.88111440597042, 54.87926567754438, 53.96225475495862, 56.17095316610029, 59.306182092235936, 59.77664293781404, 58.30051775901549, 59.12846342209847, 63.52870771961828, 62.78107650818364, 51.68877840042115, 27.104687921462524, 14.153616832148645, 9.922397271279367, 7.296578816829189, 9.42078103942256, 0.7564534799706552, 0.44336741069151514, 0.6339135489636852, 16.82635614948888, 51.327626166805146, 58.59003574617448, 45.81999086564588, 43.48660815146662, 65.26523513178672, 66.06099774760585, 40.00170384683917, 2.1866887663641283, 0.16306604348844098, 0.15746025638955255, 0.16956533425517623, 0.273724839451813, 0.12565894307748926, 0.19586476497352126, 0.18424897214337704, 0.09092113048198724, 0.185488885448825, 0.04736284965709333, 0.15488266163776, 0.195627614795681, 0.21977214743533444, 0.07650114175292753, 0.06821845958550131, 0.15141432113464803, 0.31714826581939576], [0.02737972768954933, 0.02772973027951535, 0.07992721718525694, 0.013111655153484355, 0.06190195356705978, 0.028029414299394817, 0.044768374157889236, 0.02002534681871053, 0.04081972716977039, 0.0028843655637765847, 0.17989026893290783, 0.06049548891643363, 0.021099162686075416, 0.05218650312012723, 0.026552722368749882, 0.02602519996974978, 0.014490765677164159, 0.027960391692636956, 4.148196712616952, 30.114228417796475, 53.263904202368956, 42.273481815092026, 38.209023783283854, 23.129928611939956, 24.242622660052394, 41.564937022424516, 20.929706442740656, 1.1355737236238297, 0.12947363959204766, 17.822238091499575, 43.776891000809215, 15.486821628385975, 5.273162876406024, 7.023461239953195, 10.543516355176127, 17.792941908682547, 35.009585657427394, 51.917864430335264, 49.0802727976153, 47.67900213118523, 46.81383317516696, 49.98342990875245, 50.718117298618445, 52.46386228069183, 50.77356784574447, 50.016064028586115, 47.41099049968105, 41.283789373213246, 35.9954067199461, 35.450958205807595, 36.547958850860596, 42.198568467170965, 44.71514548024824, 44.58360879651962, 43.70062051280853, 49.82503283408381, 50.04368143696939, 47.98010679983324, 49.29096291142125, 46.356410288041644, 44.58482473127304, 41.03709190122543, 37.83470807536956, 41.261702506772934, 43.865571868035104, 47.5791621208191, 49.300941421139626, 51.83245874220326, 50.41777356978386, 49.88764562914449, 44.860559509646514, 39.91650996669647, 36.53925511144823, 36.63678876815304, 36.76116320394701, 38.20382664280553, 34.85445199474212, 36.39047568844211, 37.20136688601586, 37.351075910752826, 36.8338761022014, 36.13048922631049, 34.80830923203499, 37.42263955454673, 36.23173736756848, 44.632199118214274, 45.24641875297793, 52.628919539913056, 39.737018385241115, 48.68835741473783, 51.293038706625666, 45.022008188309215, 42.6570660837235, 38.43639573743267, 39.91347012981292, 37.21641702036704, 37.927680015563965, 38.62667775923206, 39.32819366455078, 36.903062789670884, 37.60929338393673, 36.662931365351525, 37.64123716662007, 37.46355379781416, 36.130457847349106, 42.62057235164028, 48.389712072187855, 53.29618138651694, 51.33868725069108, 51.98594108704598, 47.2051445130379, 46.563538889731134, 46.868165846793886, 49.123803261787664, 51.39713448862876, 53.454664753329375, 51.54140710830689, 52.057689082237985, 50.06572515733781, 41.96663087414157, 35.88755722968809, 33.84331595513129, 37.44397332591396, 40.78437359102311, 43.88897272848314, 43.50537669274115, 41.52636443414996, 40.800502377171675, 42.32952071774391, 46.485111098135675, 50.099681115919545, 53.780598025168146, 51.57155836782148, 49.365499711805775, 51.668036906949936, 55.597357519211315, 54.89766551602272, 52.510652234477384, 52.857778072357185, 57.85877650783908, 58.117084195536954, 44.48472976684571, 26.50716973889259, 12.111111206393089, 0.7594056151086285, 2.0070699530263103, 1.2597106108742377, 0.1353917300941483, 0.035619618100745064, 0.33048294544700657, 12.981147823795197, 43.72120903384301, 35.553751760913485, 23.521604730236916, 37.26889833327263, 54.4583914356847, 54.71476931725779, 27.12532743330925, 1.1364893519109296, 0.055881398805086656, 0.08340649742392764, 0.04166287587835424, 0.020018176235739264, 0.026164216199709524, 0.048465809424317656, 0.04630098667656703, 0.06375610467887695, 0.06925806388138764, 0.04116631683803374, 0.04626054872548388, 0.03947426993099432, 0.039269755098728404, 0.02166277740240818, 0.11778609496691536, 0.015256352771464136, 0.03548293652373456, 0.009102000753515431, 0.055495114291026715, 0.07492024271238236, 0.021041336454330914, 0.03100943886825154, 0.017232963995587443, 0.006959922198626784, 0.03374299379966913, 0.07514611607597721, 0.05769541840099039, 0.011977335577079607, 0.057098735499406056, 0.03696327120245945, 0.10079975765679153, 0.054532459696694735, 0.08549375759978449, 0.07363579671589598, 0.03582319830574336, 5.71461534307849, 35.899214513840214, 59.33380734535956, 48.68611381899927, 47.25711199545091, 33.82805793516098, 30.876639120040405, 47.95301891142323, 22.374207512024913, 1.5344046128372995, 0.22651585089343212, 21.267514690276116, 45.480599941745886, 10.898584992654863, 8.04303429780468, 8.369834903747805, 9.194623058842076, 18.840673662001088, 35.69805183718282, 55.27942196015389, 51.5191045115071, 50.270508181664255, 48.799113381293516, 50.75390500407065, 51.50363468354749, 53.92225050157117, 52.89893550257529, 53.06200412011916, 49.6674673018917, 44.10413826665571, 37.50176945040303, 38.02513130249516, 38.78420799009262, 43.25594140637306, 45.22841899625717, 43.90770204605595, 46.23013742508427, 51.89612665484029, 50.48040989906558, 50.01573062712147, 51.23288131529286, 49.192440817433024, 45.295726868414114, 42.67316741328086, 40.161030523238644, 44.2010090428014, 46.50071820905132, 50.45097643329252, 50.74506398170225, 52.275141362221014, 52.32953679177069, 52.70682173390543, 46.19220810551798, 41.6720804860515, 38.8065262763731, 38.105014293424546, 38.28504716196368, 40.446006405738096, 36.591461858441754, 38.43719197857765, 38.58020943980063, 39.73932473890243, 38.44830013090564, 39.3021648160873, 35.980846881866455, 39.43869467704527, 37.91337513154553, 45.705987176587506, 47.66665843225295, 53.71258804875036, 41.08032818763487, 50.26977077607186, 53.786873817443855, 48.28056819977299, 45.21685192661901, 40.63809664018693, 41.337702351231734, 40.00389645176549, 40.529176342871885, 40.25288066556377, 40.941664557303156, 38.70474077040149, 39.78170987098448, 37.64783459324991, 38.28752609991258, 38.844294778762325, 38.24405054892264, 44.460054136091664, 49.411418899413086, 53.834173679351814, 52.6204550650812, 55.61600054464033, 50.30569184210993, 46.9456797261392, 49.26657753605997, 51.51532726903116, 53.182216921160304, 55.66726984516267, 53.12180849813646, 54.309651236380304, 51.18877034033499, 43.6548464528976, 38.27380564904983, 35.097391836104855, 39.40509957651938, 45.590281178874356, 47.47077918821766, 46.39114679828767, 42.27553713706232, 42.3749888327814, 43.21760023793867, 49.225651525682025, 53.20958722022272, 55.222931984932195, 54.246053926406375, 53.669889127054525, 52.79421214134463, 58.103512794740745, 56.35472013104347, 54.98445972319573, 57.42797866944344, 58.12115169340565, 60.9284390941743, 46.34079141001548, 26.427918249560943, 13.464201438811518, 3.422635452401254, 3.438596312076815, 1.6400155328935193, 0.29071424877451313, 0.18050874703593794, 0.5121182554191159, 14.680223464965822, 48.65820615522323, 47.075937717191636, 30.91292104413433, 40.84753944027809, 61.85666799545289, 60.24164776648245, 33.166103055400235, 1.7596700090554453, 0.03803391738103763, 0.13297775640122353, 0.022335810541746118, 0.05237145972768626, 0.045855839796844995, 0.014085490801071208, 0.05869712432726257, 0.015880724005851776, 0.017800709841051893, 0.0412949544918393, 0.04160767924340983, 0.025506629308144894, 0.034565584538804914, 0.05943097527168932, 0.054096046219309496, 0.050125661486339186, 0.0621137002693309, 0.10383003376304142, 0.13666132164578285, 0.13806706234332056, 0.09579778573806248, 0.19235995868521352, 0.08587652577027198, 0.23301224584781358, 0.18596952901251856, 0.13315774109815398, 0.20448031234404734, 0.1883516640913102, 0.2876698460069395, 0.09845565118256117, 0.0975757762188873, 0.12326707102118001, 0.1580747661571349, 0.2402803364900812, 0.15363753893442694, 7.900663537363853, 42.329481494042184, 66.38874315446424, 57.680269441296986, 49.919597256568174, 34.256757305514434, 32.929591978749926, 52.71236796532908, 26.494512250346524, 1.7896344656905823, 0.4223260704067446, 20.861372870783654, 50.96325758964785, 24.934058074028265, 15.053696843885607, 15.08026501824779, 16.473946878986975, 22.74994900149684, 36.97336735263948, 57.836375851784986, 54.27598553319132, 52.75986394574566, 50.52046906563544, 53.34931773524131, 54.68543391073904, 57.181175293460974, 54.15713379459997, 54.892005535864065, 52.01167968011672, 46.16254321990475, 39.752974587102095, 39.73621429935579, 41.10658061119818, 46.64664999131234, 49.43969526598531, 48.07749925121185, 49.259901662026685, 54.22274720284247, 52.203718923753314, 50.55461329798545, 54.067829270516675, 52.30587705489128, 48.20186584226547, 44.430436318920506, 42.05390361047561, 45.78370894155195, 49.905155089593705, 53.10087088615664, 54.88101897701141, 56.34194104902206, 54.24188836928337, 54.41889316804948, 48.94719070003879, 43.78219796765236, 41.34653552885979, 40.75389677478422, 40.445578867389315, 43.58836227847684, 37.251741886138916, 40.01039974151119, 40.40211900588005, 40.46108791905065, 39.490332680363814, 41.23612865324944, 37.54010669646725, 42.02452898025513, 39.112769249946844, 49.29508532247236, 50.41469450919859, 56.19018454705515, 45.57206569179412, 52.90244602387952, 56.85532439139582, 50.05913165307815, 46.8377870898093, 42.25987119059409, 43.598952677942094, 41.67162941348168, 41.738086131311235, 41.80262088775635, 42.05976755388322, 40.106364450147076, 41.163231403596946, 40.72930351380379, 40.99667579896989, 41.19609694327078, 39.17388762197187, 46.484754162449995, 52.36399873610466, 57.08232764274844, 54.761433755197835, 57.54410436076503, 53.084965675107895, 51.02514866859683, 53.920905128602065, 55.0723639611275, 55.56492344025643, 57.01154847298899, 53.52076845784342, 56.5730784785363, 53.94509830782491, 47.70438378857028, 42.50257961211666, 37.330758033260224, 40.66707511102, 46.108030119249904, 48.78084690340104, 49.117080319312315, 44.3924952322437, 46.50280490998299, 46.786192232562655, 51.642270857288, 54.95613628818143, 57.15183988694222, 56.88713873586347, 55.999726018598004, 54.15452149606521, 58.39893787137924, 59.74127492597027, 57.54988593439902, 58.93992685502576, 62.83292239712131, 61.98342723231163, 49.064340129975356, 28.305103817293723, 18.84050107771351, 6.467998710370834, 9.269704088088005, 5.362518881597827, 0.9543987712071789, 0.399976251947303, 0.7874172829812573, 18.277346780223233, 54.34255207738569, 47.70134002931657, 34.721232614209576, 51.415538249477265, 70.18631135263752, 70.55611241248347, 39.63890029538063, 2.4242765336267413, 0.16315949089344473, 0.19789390205856294, 0.10703086402387389, 0.16039664075980264, 0.16654399073412343, 0.13014157633146933, 0.13646157188040597, 0.14100588287316984, 0.20915357125622613, 0.17544089155572076, 0.13799428399051392, 0.1763905647901758, 0.1777767396021274, 0.1874055608265823, 0.18161808831557152, 0.10882465123769738, 0.11107115811037441], [0.09549228519561792, 0.03457905236451376, 0.06253998223391753, 0.08373131870382255, 0.026404855908044887, 0.06339694350777615, 0.015000399923132313, 0.035846506530839595, 0.08013627491891384, 0.1183549305724521, 0.058585758125709916, 0.0437384340611677, 0.04808911633106971, 0.004982741675414746, 0.0304528625847231, 0.10664160708866774, 0.015410352723612903, 0.05438899441111473, 2.3833316468423416, 26.25747165372295, 45.99211623591762, 41.35756915615451, 26.73732069230849, 18.039137317288308, 23.727833147971864, 39.99770695163358, 21.910777514980687, 2.6146588210136663, 0.04553686759825196, 5.342384374910786, 33.30418617494645, 32.7257267890438, 7.081231869036152, 7.813292741775514, 9.437535443613607, 12.702386936833783, 39.03381978311847, 53.0217606021512, 52.49802220252253, 48.95352925023725, 51.38186862391811, 51.56640437341506, 49.75927429814493, 50.8065196775621, 51.16838186017929, 47.23828854099397, 40.66909120928857, 35.57697219233359, 35.61223430018271, 38.2082667658406, 47.489606565044774, 50.5363154411316, 52.17448942122921, 51.185142147925596, 49.98082545495803, 50.21482621469806, 49.073004645686, 49.478883666376916, 46.91151195956815, 45.6071356035048, 43.8683645955978, 37.382953013143236, 35.308580090922696, 37.54538228434902, 37.4982040159164, 40.736842309274984, 42.831913578894834, 45.46613031818021, 46.10325659475019, 44.036363632448264, 39.04627330841557, 37.24105734978953, 35.53577946078393, 36.51396759094731, 36.07195961859919, 37.66092354251493, 38.1914476425417, 36.1741961971406, 37.43190419289374, 37.054952652223655, 38.79027981911936, 40.946442004173036, 40.50376722889562, 41.88602616710048, 41.996982174534956, 46.06334647824688, 44.08223967398367, 51.96881209650348, 39.05205095967939, 47.08684190627068, 50.96179846794375, 43.252121017825225, 39.87172434406896, 36.71920168784357, 38.3003600951164, 36.276754410036155, 38.02797502087009, 36.09138711806267, 36.110081134303925, 36.667924542580884, 37.46158869035783, 38.00780227107387, 36.366074623600134, 36.84104227250622, 37.39398271806779, 40.53405184899607, 46.8054549924789, 51.90389294778147, 49.76779760852937, 49.76259262331071, 52.765520003534135, 50.79320323082709, 52.48001460106143, 53.40111263336674, 52.01487641180716, 50.7848995731723, 51.95404045043453, 51.93475023392708, 51.842582379618, 50.19152341350433, 47.117601133161976, 40.6815133556243, 36.99359893798828, 37.10965402664677, 36.650313100507184, 38.63298885283932, 40.786577963059955, 39.399498431913315, 40.739944904081284, 45.112846359129875, 49.02817979935677, 52.8562601151005, 51.68369500867782, 48.8636246035176, 51.78951663355674, 52.97975201760569, 57.44665699620401, 56.71283252777592, 53.90496461622177, 60.37817370507025, 59.641705559146025, 43.41039649901852, 26.246406647466845, 17.76795837186998, 0.6094784085308352, 3.399730281483743, 1.5601093754653008, 0.19995608817665808, 0.005675684961099779, 0.36565119220364484, 12.975155422764441, 42.253622854909594, 32.649726944585005, 23.617249765703757, 35.98317284737864, 49.039491914933734, 55.19630301383234, 22.742512187650128, 1.4830354144496303, 0.07386977528972972, 0.1260210115522627, 0.03786044060102394, 0.038410840300662864, 0.034795640742466334, 0.018425418154126214, 0.003332007735509486, 0.030245340857354384, 0.03631396189091667, 0.07682120562681267, 0.09320228751147948, 0.047961099208482814, 0.059495146626666676, 0.001987143257264829, 0.035930910267897194, 0.003009512490074661, 0.04942187949294045, 0.04619630842259334, 0.0105441210513574, 0.014538274619788414, 0.06942756849551393, 0.026310759243525328, 0.028692482550057675, 0.07986849654586085, 0.01730777248139343, 0.04647536360989175, 0.04964208763633525, 0.04724580291358214, 0.04476797196172899, 0.022401828168620987, 0.030348971486091617, 0.009763805916713131, 0.04169990473817434, 0.06466534379268847, 0.018925809549287926, 3.6482845054518793, 33.01674312160861, 54.10750404480965, 47.08171929082563, 31.61484879832114, 19.77893794736555, 26.923747024228497, 42.75305432658042, 25.37640533139629, 2.6582677325894757, 0.06080293532220587, 7.493275384749136, 39.92703368586879, 24.36615182507423, 8.302149503461777, 12.362726349984447, 10.033428784339659, 17.460338646365752, 39.943593932736306, 55.46279668807984, 55.27018870076826, 52.22681383932791, 51.65331625169324, 54.115823391945135, 52.588844683862504, 52.99952076327417, 53.18930464406168, 49.581681143852975, 43.20427594646331, 37.77259734369094, 37.66400652547037, 39.14917668988628, 47.88460493087769, 52.23425065317462, 53.21614934552101, 53.063318114126886, 50.975232585783935, 51.069757784566576, 49.894258745255016, 50.44352392996512, 49.04561081240254, 48.64792170063142, 45.53853334919099, 38.75637877372004, 36.041710299830285, 39.540484105387044, 40.604230896119155, 43.869972767368445, 45.906412447652514, 47.76215637883833, 48.14170845093266, 46.70233588064871, 41.42708532271847, 38.32436892294115, 37.38093299250449, 38.673710899968306, 38.44357759721818, 40.04666597612443, 40.267707224815126, 38.860090163446245, 38.31039744038736, 38.80228227184665, 39.849304076164, 42.72873563151206, 41.974275573607414, 42.6475739479065, 42.629209410759714, 48.08574799568423, 47.60880739458146, 54.579816249109086, 42.646201118346184, 49.4140233532075, 53.56042362028553, 45.4528570175171, 41.777733449013006, 38.08498274895453, 40.08916877931164, 38.335390783125355, 39.327028720609604, 37.49811772377261, 37.62257452934019, 39.260383729011785, 39.301670597445586, 39.375752402890114, 38.56084077588974, 39.172330441013465, 38.24507820990778, 40.49718941411665, 49.35953378677369, 54.271855277399865, 50.49587972702519, 49.90931280197636, 54.968683950362674, 53.774016288019, 53.808839090408824, 53.17484286523635, 51.26053010263751, 51.37006228969943, 52.03817921300089, 52.40996891452421, 53.01160558577507, 53.2185733702875, 48.27183700376942, 42.17165316304853, 39.562731789004424, 38.38946850069108, 39.24498450371527, 41.47434203855453, 42.91211428180818, 40.19374309047576, 42.151570627766276, 48.981997812947924, 52.13679936624343, 54.16723389779368, 52.19030441776399, 51.76544504780924, 53.19181888334213, 56.237892335461034, 59.55594685769851, 57.48089144306799, 56.830209455182484, 62.01822257811024, 62.12530328381447, 45.217267697857274, 26.770119551689397, 16.198410180307206, 3.525483185245145, 4.854458195547904, 1.2278000457632927, 0.26765343943430536, 0.11341311953841679, 0.34743585834099405, 15.253524934091876, 45.700511547826956, 37.62963087328019, 29.81606944914787, 43.05306073158018, 55.6130862236023, 62.40644308828539, 29.950677348721413, 1.760566025491684, 0.031789136344506856, 0.058365772147813154, 0.01673256110910687, 0.019348665185633208, 0.043961511203838934, 0.0035357385246653954, 0.059836136192203536, 0.06392517645332603, 0.027188604074199835, 0.10602742673889284, 0.1020559426697512, 0.01945096856704162, 0.04468618441493281, 0.012088897131052951, 0.0628902989199325, 0.04949935779516255, 0.027603111267390273, 0.20741262112654027, 0.11805535188966221, 0.19511660350666893, 0.19706499492449148, 0.12209727008256221, 0.13251646421849728, 0.15045380009518516, 0.09637552328527936, 0.1932350609211191, 0.19376407527635175, 0.18142846623255363, 0.1372133339605024, 0.12790843003219174, 0.1554152306409613, 0.22455737775852605, 0.2592252465265413, 0.11833365631079483, 0.15319204348469936, 4.32951464768379, 39.349311705558534, 61.06249001718337, 54.760739495677335, 37.89669329120267, 29.951159800252608, 33.14504384994507, 51.91778990530199, 30.33789961568771, 3.648599030510072, 0.16338850521752912, 6.774411816750804, 39.932701510767785, 39.89392495924427, 15.791369157452738, 13.605571504562134, 16.47976375395252, 15.445719111350277, 44.213843038005216, 58.69504151805755, 57.513027421889774, 55.2183545789411, 55.38918164468581, 56.140119414175714, 52.62789187892791, 53.895166535531324, 56.96090282932405, 52.45359351558071, 43.37279273617653, 39.8222711009364, 40.53476572036743, 41.83159543621925, 51.24404438080327, 55.721280882435465, 56.8968544467803, 54.06859805507045, 52.928702369813, 53.547621004043094, 50.541653786936116, 52.24089514824652, 51.02776488950176, 51.787092608790246, 49.171330621165616, 41.17397869786909, 39.10412434608706, 42.49973197137156, 41.69920759816324, 45.784465958995206, 46.35364501707016, 49.329358993038056, 50.50650150545182, 48.47680830186414, 42.6013841167573, 40.192546767573205, 38.97014794811126, 40.42234274648851, 41.593570324682425, 41.411238947222316, 42.30631989817466, 40.432081991626376, 40.50670116178451, 40.721003778519176, 42.02574883737872, 45.94605192061394, 45.2498939729506, 46.03586635281963, 45.51387733028781, 50.85123861989668, 49.11957886911208, 56.08076610872823, 44.305136203765876, 52.739024393020145, 54.99470887645599, 47.02075389123733, 43.33527526547832, 40.31923540176884, 42.91303996116885, 40.951470482733946, 41.91700504672143, 39.46358211578862, 38.7885461315032, 40.3520970190725, 40.99082754504296, 41.71685434156849, 40.047352390904585, 40.43267034715222, 40.30736630962741, 43.27357246029762, 51.614445563285585, 58.40370747350878, 51.83383941650391, 51.3764008398979, 56.627054214477546, 56.13554985292497, 56.913536287123165, 55.85689683114329, 52.364175242762414, 51.53873205184937, 53.67349770761306, 54.0883981797003, 54.73937434534873, 55.649113193635024, 51.053982011733524, 45.353970143102835, 42.74045175121677, 41.55482515212029, 40.8692576039222, 43.26863811862084, 44.556175739534446, 43.293160776938166, 44.67539225855182, 51.65757986807054, 54.4269654058641, 57.6723893996208, 54.31944931707075, 53.72106429069273, 56.283686007222826, 56.93208125329787, 60.8601467071041, 59.862009402244325, 59.353693762133204, 66.5735887712048, 63.39382525413268, 47.55172514146375, 29.379517493709443, 22.6323857615071, 4.7643897898735545, 7.437333560759022, 5.290688026335932, 0.5935438409928353, 0.16809663645202116, 0.6365284828409072, 16.639249286343976, 53.15534476310977, 44.19983625411988, 34.002795603967485, 49.4495717940792, 62.214682332931034, 70.45420139066636, 36.05814110848212, 3.164332667666097, 0.1363684615540889, 0.26177086476837436, 0.1674822645802652, 0.07154253807159201, 0.15617666075066214, 0.12433482904828365, 0.18953629649214207, 0.10485652263366407, 0.2089569624513388, 0.2035901641413089, 0.2600977593852628, 0.07074516311648392, 0.1341776186299901, 0.11242662045744159, 0.13559105085028758, 0.07810014345112347, 0.09001402109260521], [0.0878250397621624, 0.02785827600276999, 0.028737028647634773, 0.0721895223062846, 0.02368433979309855, 0.06011372049068732, 0.049081027823229956, 0.007429213296892423, 0.03863482142708475, 0.061768581489882166, 0.021404362539009705, 0.04032138314458632, 0.025278848385618582, 0.14739459650891443, 0.04715362721453271, 0.044010234395823175, 0.05419032099927145, 0.02514986216180748, 2.2625716751621616, 22.908269589947118, 43.915025111167665, 40.764330279442575, 31.021947245444025, 25.224582149136452, 38.758877323519805, 41.9443125878611, 25.59041573155311, 2.9114523145460316, 0.02985651484660564, 0.2018900311762287, 17.468748208015196, 22.224912297341135, 4.236119091510773, 11.401838814058612, 6.651780384202158, 18.91363759194651, 37.50624879713982, 53.458355703661525, 52.98823610428841, 52.697615931111, 53.40587439075593, 52.77794214986986, 53.6299240973688, 50.95746424890334, 48.10228863070088, 42.049134008346066, 34.722232818603516, 34.49433134448144, 37.84879722902852, 45.02127078271682, 50.28452673266011, 48.17460929193805, 47.37142947412307, 49.11651157563733, 48.557420853645574, 47.860713774158114, 46.78463505160424, 50.19626163667249, 48.15056124041158, 46.82659656770768, 42.781260090489546, 38.6797474276635, 33.781832802680235, 36.476108874044115, 34.177388145077614, 36.15423917770386, 38.10573600953625, 40.44448844848141, 36.616616018356815, 37.89538714193529, 35.0151240441107, 35.45169953377017, 36.58987722089214, 36.57843958946967, 36.594556608507716, 37.282775678942286, 34.581741363771506, 37.70676036034861, 36.88563177662511, 42.15503408062843, 45.8504637595146, 48.77992122404037, 46.104892223112046, 48.90737079804944, 46.05192061393492, 46.4341869661885, 45.20233915698144, 57.31870535881289, 35.651614896712765, 47.47217162962883, 53.61567804890295, 46.278998390320815, 40.007328525666274, 38.94278549378918, 37.79297405673612, 37.26733722994405, 35.58690755598007, 36.08322466573408, 36.650877921812, 35.632611013227894, 37.66153150989164, 37.65077637087914, 38.64471673965454, 36.628987173880304, 37.03290500948506, 39.35610917306716, 43.550193694330034, 49.947265655763694, 52.857868286871145, 51.9663998388475, 48.6919032373736, 50.960096159288966, 51.420958965055405, 51.95693515962171, 51.32558653431555, 52.10123523589104, 51.13143705552625, 50.699509574520974, 51.83223124473326, 52.4687966223686, 51.49225981004777, 49.77075899800947, 45.12167169201759, 40.217865667035504, 36.813522923377256, 35.87818668734643, 38.70746681767125, 39.99594188505604, 38.6475133895874, 43.90832570291335, 48.92114223972444, 52.029824564533854, 52.22513506489416, 52.172379186076505, 50.69484195401592, 53.11918443249118, 54.85499012854792, 56.637542632318315, 55.191874657907796, 56.62665413271997, 58.57748023925289, 43.168417638348, 25.238388892143007, 10.301052101196783, 4.007173776626587, 4.781042702736394, 0.6097929335890279, 0.3315795849888556, 0.061893698969675656, 0.36991992604828655, 12.311673760414125, 45.969539073205766, 43.5067730565225, 28.93432063441123, 28.628948427015736, 47.64495203571935, 53.07847807484289, 24.796584883043845, 1.1416296180217498, 0.11990867179608154, 0.03826866204279565, 0.02018074009327158, 0.016549443112566106, 0.043820382486427986, 0.11188269803120245, 0.050481574444641034, 0.06642189913339193, 0.05309146363288165, 0.04154412841965114, 0.030237335238545656, 0.015656918122042573, 0.030189006581842422, 0.06262238265105313, 0.07719609841343857, 0.04676870250653836, 0.10398985502580482, 0.03367614113695679, 0.03512616937739715, 0.050040955144551494, 0.07561161408140775, 0.022536155940484137, 0.02135415313645236, 0.029803830980052872, 0.028269220887112523, 0.08030809311857147, 0.042922240156199665, 0.051430680774032116, 0.025289194403035987, 0.028377419315098275, 0.0398121300273605, 0.03847863908196169, 0.06884976966126312, 0.024753603182973403, 0.016408902367637042, 2.5618529319763184, 28.123739304081088, 49.750711764058764, 49.274806668681485, 37.55295245878158, 30.334124334396858, 38.689172883187574, 45.99101797226937, 29.193406912588305, 2.983839656076124, 0.0706876912004044, 0.3111681528389454, 19.956068261977165, 21.04666171535369, 5.449213558627713, 14.201919840228173, 7.893480206689528, 15.472038215206517, 40.24195686463387, 54.79740581204815, 55.706109154608946, 54.171481824690304, 56.186540665165076, 55.378446117524184, 54.08714302124516, 52.88379515371015, 50.776376262787856, 45.04055707685409, 37.40503987958355, 36.1178631167258, 39.57420079938827, 46.76584297610868, 51.99942227332823, 51.13092322503367, 48.81589720326085, 49.36153811793174, 49.12036726551671, 48.26795385729883, 48.398729601214015, 50.806449074899, 51.70091029136412, 49.902836968821866, 45.16432354527135, 39.825518823439076, 36.48854278749035, 38.875065772764145, 36.53470123967817, 37.8831297351468, 39.41789042565131, 41.91808369851882, 39.32974300076885, 39.22084623767484, 35.95697533699774, 38.57044273807157, 37.30057931715442, 38.80405910553471, 37.81853222077893, 38.13847211099441, 36.56871995618267, 38.60725418213875, 38.340360426133685, 44.6498066379178, 46.7908049398853, 50.19664995131954, 48.639645499567834, 50.702592557476414, 47.981107004227184, 47.589489721482806, 48.480973858987134, 58.43331744593959, 38.44150658576719, 48.58306923220235, 54.72981945160897, 48.076451978375836, 41.97697416428597, 39.58973338527065, 39.94743001076483, 39.0747614829771, 37.81632784874209, 38.34960545262983, 38.32819323385916, 38.419270669260335, 38.47158332024851, 37.932990904777284, 39.37389319942844, 38.46859055180704, 37.99144206508514, 40.51047055952011, 45.85375855045934, 51.576575079271876, 52.80157443015806, 52.2114420706226, 49.381381388633486, 51.80986981238089, 50.67126066453996, 53.09822328629033, 54.19409036636353, 53.788321172037435, 53.515528171293205, 52.80125279580393, 52.69134406120547, 52.63432456601051, 53.91746128759077, 52.24087161402549, 46.736778213131814, 41.39617312339045, 38.32869137487104, 38.86400861124839, 41.61335475983159, 41.908607252182506, 40.48736779920517, 45.373225058278734, 50.57601767201578, 54.82310518141716, 54.72763861379316, 53.2743259399168, 52.54469448520292, 54.34437990188599, 56.858983962766594, 58.496746093996116, 57.6899576956226, 58.75380646797919, 60.06350548036637, 44.41852015833701, 27.808867116128248, 12.456076798900483, 5.528667050023233, 4.075242098300688, 2.4230066662834537, 0.6711135528260662, 0.10347080747446707, 0.49338676215660193, 13.823834734578288, 49.54835276449881, 42.47733523768764, 28.31934202101923, 35.08039228377804, 52.7834060115199, 60.9037007054975, 28.716230969275202, 1.3465183011947142, 0.0378304022935129, 0.01837899131069501, 0.12991486027115776, 0.04739369235692486, 0.05281161554458161, 0.06101552855163332, 0.06463648526058083, 0.018370849711279717, 0.036105076527042736, 0.012269044621667315, 0.03306725062429905, 0.014078498333542338, 0.08606478421678466, 0.03735106490973023, 0.05006543548417188, 0.08442235299416127, 0.037345870833603606, 0.11589417955087078, 0.14860492349872667, 0.1562445208189949, 0.12385129733311555, 0.10454998787252173, 0.1817897379758858, 0.08497785866981553, 0.1773231849074364, 0.14066423830245772, 0.13766832890049105, 0.1143514546715925, 0.15042786035806904, 0.10605836903015453, 0.2574089133451062, 0.10219873379795782, 0.11437236887192535, 0.17650731658983618, 0.11924583720223558, 3.5309468017470453, 33.41760543084914, 58.99300044582736, 54.997281951289025, 45.35102052073325, 35.52613435253021, 48.59666416721959, 54.89000120470601, 34.03719871274887, 4.112651458671016, 0.17406626934966735, 0.8360554698494174, 20.77340783611421, 27.756391686777917, 12.519922198787814, 22.569502322904526, 11.746441587325066, 22.787919505949944, 40.23264515784479, 54.37653549255864, 56.89566989098826, 55.469154850129165, 58.060315732033025, 55.5397653579712, 56.30081499776533, 56.22441899391913, 53.62979858152328, 46.77813960659889, 39.41901222352059, 39.36943346454252, 42.817812658125355, 50.00227297506025, 53.57213973999024, 52.40923543130198, 49.386711889697665, 49.88398213540354, 49.58044167487852, 48.62218310756069, 47.63298096195344, 51.77685130027033, 52.4339424410174, 53.52718545544533, 47.03747103291173, 42.01045551607686, 37.51708630592593, 40.39640803490916, 39.592643783938506, 39.65717854038362, 42.18592274573542, 44.459210826504616, 40.87497641963344, 41.36734370262393, 37.65167067127843, 38.77432361725838, 39.0544867515564, 40.21636732162968, 40.26271796995594, 38.67499351501465, 38.29533553892566, 40.83345813135947, 39.864311064443285, 47.258284784132435, 50.22004296702724, 52.73889887717463, 52.38075902385097, 52.640667038579146, 50.82445275398993, 49.2877269560291, 50.60022654071931, 59.447913016042406, 40.41093649402742, 52.50014028241558, 58.01165873004545, 49.616248992181596, 44.09414014508648, 41.9403862953186, 42.904673545591294, 41.98966695416359, 40.42953245101437, 41.11732398310016, 40.15944196331886, 39.57661697941442, 39.75023677272182, 40.55440895019039, 41.10745922211678, 40.2073537149737, 40.188240005124, 42.80334695692986, 47.36880540847779, 55.34016378464238, 55.263579507027906, 54.50905276883034, 47.53957756104008, 52.903097137328125, 51.50699615478516, 54.86113648260794, 55.343733141499186, 56.456568394937825, 56.19793122814548, 54.86379584958477, 54.176596595395, 54.4496210159794, 55.9912262424346, 55.67147462598739, 49.802196794940585, 43.9716366798647, 42.713426620729514, 39.71078165115849, 43.478127987154075, 44.32021379470826, 42.25701570510864, 48.852167360244266, 53.83646042116227, 57.08925847084292, 58.81656046836608, 55.99019073670911, 54.99240644516484, 56.20602307781097, 57.11846051677581, 61.421990932956824, 60.56140330529983, 61.12989594859462, 63.90217619557535, 45.76395588536417, 31.290566844324914, 18.20462211485832, 8.377541380543864, 8.484659348764728, 3.3353985076950443, 0.9667776488969404, 0.46445272442313934, 0.641648953239764, 17.368672855438724, 57.68505865527738, 53.19606681023875, 40.43017179735246, 43.21294438454413, 62.20222488526375, 69.04850236831173, 35.75336902372299, 2.0159772879654363, 0.2370781349318643, 0.09293427165116995, 0.1689752933358954, 0.14311930495164088, 0.1518544999341811, 0.28444476906330357, 0.19081687374461084, 0.18092320060297368, 0.1508113026859299, 0.1434961895668699, 0.08682737878013043, 0.09898808995081533, 0.17001216269789204, 0.15118472458374116, 0.17495807230232224, 0.23237144394266993, 0.31346034919542654], [0.052930412798999786, 0.022781313652352943, 0.030734614401514974, 0.07877397140668285, 0.07770209182654658, 0.007499925127523321, 0.05771179736081151, 0.017833544369486552, 0.02653616337826656, 0.040813843614511916, 0.14048106667976226, 0.03561752668071178, 0.11253572669961762, 0.03278620743883714, 0.0301065142341559, 0.046157230277575796, 0.018115646671503782, 0.0060990026442243935, 1.0973878565334505, 16.877707819784842, 43.63814892307405, 44.83611922110281, 34.99062884238459, 22.416388680858, 21.83178294089533, 34.621361224882065, 28.674294948577884, 4.369783170761601, 0.02685440396289191, 0.5916140961550898, 1.2419015794031083, 15.492581628984022, 15.931726271106353, 16.310434053021094, 11.20582522884492, 13.663386260309528, 36.679118987052675, 54.21604779458816, 53.87111848400485, 52.714282081973174, 54.60136575083579, 53.735498612926854, 52.831929652921616, 48.82370664227394, 44.26934457594349, 39.3321866373862, 33.8700351407451, 37.68089232906219, 43.74750068110805, 50.713108431908395, 49.00514371933476, 48.23732406862321, 51.6129550626201, 48.9452059807316, 49.52273576490341, 49.66329390002836, 48.39923558696624, 49.7289857556743, 48.312190348102206, 44.95835596515287, 46.150085772237475, 39.37998464030605, 36.746756338304095, 35.53118636531215, 35.675592345576135, 35.6083550760823, 36.972520120682255, 38.60234337468302, 36.11142650727303, 37.039474979523696, 34.175799585157826, 34.54308640572333, 36.91572420058712, 37.74584285674557, 36.57093217295986, 37.471759396214644, 36.27702113120787, 36.74968242645264, 39.22374486923218, 47.63946071747811, 49.422636878105905, 51.39099990167926, 48.28388652493877, 52.55383360770441, 47.449347357596125, 52.21186176423104, 51.20624842182283, 55.60917169817033, 33.805257197349306, 42.870239057848536, 52.6372584988994, 47.391563000217566, 45.80162240612892, 39.96053857188071, 44.9541864856597, 43.8316669002656, 44.18280532283168, 38.64509720956126, 36.074819026454804, 36.24466157728626, 37.86849929440407, 37.18696394274312, 37.64778360243767, 35.45328024894961, 37.66424186768071, 37.90966064699235, 40.805832878235854, 45.801010516382036, 50.3087709026952, 53.095108924373505, 50.17853644586379, 51.18524805192025, 51.30357811527868, 49.38964974495673, 48.06419457158735, 45.357057048428445, 45.42384716772264, 48.11568744720952, 51.016896001754276, 49.96924269583918, 48.49467469799904, 51.86799149359427, 53.04419655953684, 48.03283914442986, 37.407648255748136, 37.702920359949914, 37.989096487722094, 38.702861955088956, 39.48653190366684, 42.20964524053758, 44.79646013629052, 49.07487169388802, 50.50690550957957, 52.69665495041878, 53.5432279494501, 55.29670784550329, 55.934504847372736, 57.7211993740451, 57.49097193441084, 57.584642056495916, 57.61577390855359, 42.23574861403435, 26.468371614333122, 12.037856040462373, 4.781227054134493, 10.467066418740059, 0.6421037643186508, 0.6755007238638017, 0.06453890098078598, 0.42934555019582477, 13.026754202381259, 38.26579616915795, 36.693349346037834, 35.744245590702185, 42.68521301208004, 51.081544506934385, 55.61597701041929, 19.70872752128109, 1.0435324883268726, 0.06643071680540039, 0.0582030397509375, 0.05479935323819519, 0.038823313530414336, 0.09153729499948603, 0.04053151723177683, 0.013574933419154297, 0.02110701125685967, 0.09483219319654089, 0.03740188335218737, 0.054719948224843516, 0.03666137510369863, 0.010699380260531702, 0.04032304938582163, 0.043640370976420186, 0.02708831550403228, 0.025150670384567593, 0.058028961591903246, 0.021797323509329752, 0.026469772283528602, 0.03836467967278535, 0.014571181926575881, 0.04011289997687263, 0.012876318688804825, 0.007371335833017985, 0.034845842484144435, 0.0468697571646302, 0.04104231018573046, 0.060862035175124486, 0.07795217356854871, 0.028542145455796874, 0.034610929283043074, 0.017365121823405067, 0.002977929318383817, 0.05853920679299101, 1.5571945641309985, 22.47987420328202, 50.9026805047066, 50.2188858678264, 40.14650598649056, 25.986663372285907, 29.425495516869333, 43.67647440202775, 33.75700419948947, 4.9371716668528896, 0.1169240468692395, 0.3209647932840932, 2.184278960189512, 18.984787425687237, 16.390053264556393, 11.965209822500906, 8.156538865258618, 15.589051342779591, 38.63363212154758, 54.71185891858993, 56.16308489153462, 55.086598242482836, 55.013740216532064, 54.83498211829893, 54.38678856818907, 51.55203673147386, 48.01919714097054, 41.0238068334518, 35.191073725300456, 39.52959952815887, 45.50172190512381, 52.920445780600275, 49.99062745801864, 48.27881490030597, 50.26805670030656, 51.20433430517874, 50.80324449846822, 51.22619759651923, 47.51938912176317, 50.215685213765795, 49.97050962140484, 46.6676385941044, 47.10111933369791, 40.91329405384679, 37.535207656122026, 37.38709895841537, 37.550273479953894, 37.918886061637636, 37.43452433616885, 40.77150037211757, 38.136020629636704, 38.50947733848326, 35.54154926730741, 36.40839307538925, 38.58683040065151, 38.61670317188386, 37.93269280464419, 39.695606000961796, 37.15327078296293, 38.70754134270453, 40.94976817407916, 48.417686416256814, 50.93924091708276, 53.36168104602445, 51.37726768370598, 53.45274279194494, 51.24180862980505, 53.95533961634482, 51.46023757996098, 57.83244171450215, 36.44417293610112, 44.9810351094892, 53.24182125829881, 48.805797100067146, 47.499498782619355, 41.52144970432405, 45.928499314092825, 45.98647978998, 45.06455413756832, 39.860600502260276, 37.40338071700066, 37.9292332741522, 39.39317557119554, 39.30801307001422, 38.447025360599646, 38.35464962067143, 38.85915271697506, 39.10355952478225, 42.99081271694553, 48.10330452457551, 52.66468763351441, 53.50524763907156, 51.20130623540571, 51.32139352060134, 53.41106368649391, 52.665272066670084, 51.6386152082874, 46.97949840176491, 48.49800871264551, 50.91648332534298, 53.02076432012743, 50.81203060765421, 51.58441197487616, 52.43672732383975, 54.12713158515192, 48.675205707550056, 40.74388688610446, 37.96505628093597, 40.38357796207551, 40.43473351386286, 41.85300765498992, 43.20269130891369, 47.548473496590894, 51.19258288414248, 54.53274388467112, 55.65890342958512, 54.716185292889996, 55.96160842526344, 57.79969776830366, 58.1438700614437, 60.26530358099169, 58.175256867562574, 61.65674478776994, 42.23224593747047, 29.061719217608054, 12.079609670946676, 7.357559415601916, 11.78923366531249, 1.9494269235480217, 0.7121321679122987, 0.03470117827096293, 0.49316717071398614, 13.851041274686015, 44.21909901403612, 43.81582052476945, 41.53111442442864, 48.30551055169875, 58.48095855405254, 61.18627609745149, 24.508480910331976, 1.3960556301378435, 0.06421479216266064, 0.07081150633072661, 0.04598027545838587, 0.03959043567339259, 0.030625121284937187, 0.032554519467896996, 0.02101608619634663, 0.008373429112496876, 0.06629008604514022, 0.07704160146174893, 0.029619964132566127, 0.08848486363046593, 0.03576020289572977, 0.0484488865420703, 0.026104265989194957, 0.05181395073211001, 0.04333629152707515, 0.18887660285878569, 0.23831216468205377, 0.10484989597311906, 0.2547401388085658, 0.19540977003353258, 0.10951888011468035, 0.1352923684903691, 0.0860246105660354, 0.1869471031691759, 0.17369243376437696, 0.29339175671339035, 0.25466827976126827, 0.24686317680583847, 0.16235598723494238, 0.16793859251324209, 0.15165378489801962, 0.0888266077926082, 0.13199796058958577, 2.116265061401552, 26.217122231760335, 58.618245432453776, 57.356050245223514, 48.44466447830201, 31.745916758814168, 31.418192924991732, 47.47399945412913, 39.94124835537326, 5.701722022025816, 0.2268169847347083, 1.3735187942943266, 3.072121176988848, 18.659815134540683, 26.056001071007024, 22.332469571021296, 18.183174594756096, 17.01575367681442, 40.79971790313721, 55.731494734364176, 56.09518474148166, 56.428950986554554, 56.091999776901744, 56.15001947649064, 57.51461990417973, 53.59565434917327, 49.844256370298325, 43.09770907125166, 37.37768134763164, 41.87287053754253, 48.885299621089814, 55.377359620986454, 50.01022754176971, 47.90880595484088, 51.999465419400124, 53.2803899242032, 52.508561611175544, 52.07534367038358, 50.26048260350382, 51.845532001987586, 51.48995737875662, 49.378404309672696, 50.94120994690926, 42.89947248274281, 41.51786073561638, 39.6132166154923, 39.278607060832364, 40.32064745503087, 39.94058939718431, 41.25078262821321, 41.32168731381817, 40.78747618582941, 37.18282584221133, 37.35726933325491, 40.76453816506171, 40.31762330762802, 40.07460501886184, 41.66305903465518, 39.26700468986265, 38.51528244633829, 43.13672488735568, 52.23813772201539, 52.966423803760165, 55.069559466454294, 53.09053544075259, 54.321096712543124, 54.181075942131784, 56.37572442331622, 54.32936114649619, 57.61476978178948, 42.44909809481713, 48.0968600703824, 55.8522056764172, 51.61021332586966, 50.39160351599417, 43.97076591368645, 49.18394888600996, 48.3235966005633, 49.55813123333839, 44.026753825526086, 40.01508305149694, 39.61349510377453, 41.01214954929967, 39.24785960105158, 39.514808270239065, 38.83382989514259, 40.41496476819439, 40.823161909657145, 44.795201055465206, 50.19462600831063, 55.027107654079316, 57.03071709602111, 53.47113478568293, 54.18499046756376, 55.555192039858916, 54.40860479108749, 53.6709128656695, 50.099304568383005, 52.455185997870664, 53.473562732819595, 54.98753093904065, 51.29414873738443, 50.47294170625749, 53.87099689052951, 56.37206485194545, 52.47147167882612, 42.53953618388022, 40.97493802347491, 43.6183056523723, 42.723071728983236, 43.74921867924352, 45.50135712469778, 50.35363497272615, 54.67946798570695, 56.221947900710575, 59.38666128343152, 57.36035308530254, 59.316572450822406, 59.13200532236407, 60.323829266332815, 62.87825715157294, 62.248626524402255, 64.30767082398938, 44.58413047175254, 36.97545405357115, 20.2180512105265, 8.380940114298175, 14.39757158679347, 3.2023029269710666, 1.1087643234960496, 0.2502765275177456, 0.8135068668953834, 16.71859295137467, 51.53273082548573, 48.86132609459662, 48.6510556743991, 56.16435966184063, 65.10563781184536, 69.38552810299781, 33.14698934555054, 2.298435866832733, 0.19093246109062628, 0.20566963320297582, 0.1048007590936557, 0.10951435253504785, 0.2165596343336567, 0.1483319970148225, 0.1421818891239743, 0.12105038029051597, 0.19317990259057094, 0.15943285618578235, 0.12639601925207725, 0.16365888828952468, 0.17680512560952097, 0.1252322780689405, 0.10079759728884506, 0.11879035196597539, 0.09641040326847185], [0.013241919786519101, 0.14532124082888329, 0.027759381712624626, 0.01768980903791324, 0.08207646153506734, 0.058103915634414846, 0.01963637908169579, 0.059194533725179015, 0.046927278876424804, 0.09513188679251941, 0.014518088202983623, 0.03034611397813405, 0.028391978816099228, 0.0447486971895541, 0.024069118944387284, 0.04264555984146653, 0.03483817394402239, 0.01685482682660222, 0.5577161151074594, 14.154794523792884, 37.499714128432736, 47.07574552105319, 36.21408670179306, 32.83704169334904, 29.237435517772553, 41.852576194270966, 29.191706565118608, 6.807319521903993, 0.10372601434468262, 0.10923059356789436, 2.284382014505325, 5.247846918721353, 11.528846140830748, 8.330653367503997, 2.1633793461707334, 9.996137830518908, 37.86639298162153, 48.799082002332135, 54.88206232747724, 53.56751134318691, 51.146777445270175, 51.27477222873319, 52.249791083797334, 47.22798839692147, 40.19024825865223, 34.80830923203499, 37.814986398143155, 43.28584163419662, 51.8214015806875, 51.93833135789441, 47.30566701581402, 51.80761837190198, 48.776649967316665, 46.556459011570105, 46.73190270700763, 48.0726747358999, 49.03666780840967, 48.793924085555545, 49.76415764900946, 48.75317065946518, 46.56065987002465, 43.38204560741302, 38.490744098540276, 36.1988208370824, 36.054544295034106, 36.225355671298125, 35.21433730279246, 35.88889475791685, 37.436669872653106, 36.456285215193226, 34.450620451281154, 42.10002676133187, 45.46939765253375, 39.60360680857013, 38.32560446954543, 37.14353546019524, 36.255220597790135, 37.00436976648147, 41.54305411923317, 48.25766940270701, 51.393965213529526, 52.39327530707083, 50.09956344481438, 52.22700995783652, 50.2357324477165, 51.45107492323845, 47.140582300001576, 51.79471377403506, 31.756450283911924, 38.87122577236545, 56.5374319784103, 47.42812341259372, 49.788311604530584, 46.13378047943116, 50.55755507561469, 47.48913195825393, 49.13531149587324, 48.98939932546308, 41.01189851760864, 34.62822145031345, 36.81276982830417, 38.39270837845341, 37.46831947757352, 36.32593700962682, 38.494254619844504, 36.93300616356635, 37.5102613818261, 40.403342785373816, 47.60357495277159, 49.097539071113836, 53.26491617387342, 49.77053150053948, 47.423338120983495, 47.19965711716683, 45.79456213981875, 44.28730118659235, 44.998030739445845, 45.03055895528486, 46.193318136276744, 51.82459439000776, 48.05218427411972, 48.68459586174258, 52.785932017910866, 49.587686292586795, 45.57325024758616, 39.061441113871915, 37.164935911855395, 38.75506085734214, 39.61991994611679, 39.236265074822214, 41.12864002104729, 43.93439769744874, 48.76327468502907, 51.506866716569476, 53.28100965869043, 54.49693656736805, 53.841763465635246, 54.10736283948345, 59.51231833427184, 60.560105000772786, 56.93622327619984, 38.638272285461426, 22.444368908482215, 8.933677577203321, 5.931794037742, 13.943780814447711, 1.123471618179352, 1.0312524053358263, 0.08429859148999376, 0.41124522145236697, 10.769759647307858, 47.561111373286096, 40.273359360233435, 29.143626151546357, 42.324719736652995, 52.36107657032629, 51.78460190373083, 16.156053485408908, 0.9147553145885469, 0.024195458334419998, 0.024408279475004926, 0.03562799910263669, 0.03725291755531104, 0.054127095762880585, 0.023281222412122354, 0.06675649569520066, 0.07715404784727482, 0.04782236451583524, 0.057771724588688345, 0.0482847866782498, 0.014266649527745623, 0.08572961308903272, 0.029450040085301287, 0.02304608896074276, 0.011209535446288365, 0.05337426499012978, 0.01728105324981434, 0.00968908648862834, 0.035929592596667434, 0.05979999216393598, 0.03609197642353754, 0.029594964768377044, 0.022068612480295763, 0.024727198047443263, 0.05071531170077863, 0.043500862534969084, 0.04220169998945729, 0.047146349379252044, 0.047702923747560674, 0.03646562048684686, 0.0579318599475007, 0.042412531216658896, 0.013237653634390764, 0.024786056582665732, 0.7008212167889841, 16.87493862644319, 45.57954565171273, 51.357934321126635, 43.21015165698144, 35.6453626386581, 29.32235679318828, 47.19272628907235, 34.12269853776501, 7.019095641951408, 0.09450812268281177, 0.07104116416866742, 1.3314692700101485, 8.785133496407541, 15.687161587899732, 13.887383014925065, 7.825742834998716, 15.14511944786195, 40.98743861721408, 52.99613968018563, 55.69788002198743, 52.964427317342455, 51.2824639966411, 53.39898278636318, 53.758832793081964, 50.56769440251012, 42.58935028506864, 37.14627327457551, 38.72202273338072, 44.62197742154522, 53.26977991288709, 53.289846758688654, 48.35891362159483, 52.23507435091081, 52.03555514735561, 49.23505736935524, 48.805781410586455, 49.56687419645248, 51.2494807858621, 49.89071684498941, 51.20401659319478, 51.074503852475075, 49.437683090086914, 45.57355227008943, 38.72895748384538, 37.50638608009585, 38.48126372983379, 37.50558983895087, 37.11233692784464, 37.40198435321931, 36.75643674788937, 38.12091165973295, 35.410075341501546, 41.94712884964482, 45.179044200528054, 41.38194668677546, 39.46421753975653, 38.86322021484375, 37.55350551297588, 37.8239764705781, 43.66880616834087, 51.164212380686116, 52.662848041903594, 52.84543045105473, 51.684102935175744, 54.27303591082173, 51.271701012888265, 53.734620002008256, 47.64992167872768, 52.58165497933665, 35.418794770394605, 40.12936915120771, 58.646894424192375, 49.89427051236553, 51.19290451849661, 48.37201433797037, 52.185891751320135, 48.13904908395583, 50.613221353100194, 49.40480186093239, 42.990008631060206, 36.45569293729721, 38.94946921256281, 38.99944805329846, 38.637542724609375, 38.876042442937056, 40.02321020249398, 39.31988216215564, 38.004480023537916, 43.586612901379986, 48.29490838512298, 51.38178233177432, 55.197758213166274, 52.600717698374105, 50.44234329654325, 49.36259715787826, 46.86944061709989, 47.12977617017685, 47.125198764185754, 47.551219155711514, 50.845355064638206, 53.974053244436945, 49.84091058854134, 51.87135296483194, 55.60373921548167, 52.40315575753489, 48.976953644906324, 40.32008263372606, 38.9318734599698, 41.042398868068574, 42.59496319678522, 40.23942301350255, 43.97668869264665, 47.503989896466656, 51.67904307765346, 55.03401102558259, 56.56169576029624, 56.13118033255301, 55.06777478802589, 55.70221031865766, 61.009498796155384, 62.54410651422317, 61.2490261754682, 41.24249073766893, 26.40276408964588, 8.984779196400797, 8.904367666090689, 19.686872074680945, 0.12080686392202494, 0.4964986113050292, 0.06049920444286639, 0.4962853937139435, 12.735346613391755, 50.5701772628292, 42.243918911103286, 35.62883377075195, 49.47111345106556, 57.18612924698861, 60.85839340763708, 21.081855181724798, 1.2053730362846007, 0.04960240811229714, 0.016332565536422115, 0.037693268724627076, 0.06514476161570319, 0.04042657850790889, 0.06912612821906805, 0.025873560526017702, 0.060305372706704566, 0.011283729146535118, 0.03408341646014202, 0.0494765475272171, 0.029715686818704973, 0.048173841825055505, 0.0703643944354788, 0.06945481058210135, 0.017560730883551222, 0.040953137551344214, 0.12280672112660063, 0.2045055932455486, 0.15887785612815813, 0.16575459841518633, 0.13251651018377275, 0.1513578144893531, 0.11366956747106968, 0.15997132406600062, 0.22626160163312192, 0.11453007573201773, 0.10134018672209594, 0.17383239802814301, 0.1393342330571144, 0.10227742634953992, 0.17777594287068615, 0.17231755108842928, 0.1373911276459694, 0.09641025005088699, 1.13472587879627, 21.487249789699433, 52.55301775470857, 59.478178024292, 47.70434064249839, 44.445984594283566, 38.94750802747665, 53.73108202411283, 39.577440677150605, 9.574186898046925, 0.1889187223728626, 0.4646236846043218, 4.347113342054429, 8.678080247294519, 15.883034948379764, 18.703914342388032, 7.384091308040004, 13.694251391195483, 41.84115817469936, 51.529455646391845, 58.3424400514172, 53.76167651145689, 52.919520101239605, 54.55158695097893, 58.221611438259, 52.31760101933634, 45.9267460146258, 39.39214006547005, 41.98834511541551, 48.535824283476806, 56.309965887377345, 54.01490080741144, 48.282972612688624, 56.51316427415418, 54.37638644249209, 51.04012035554456, 50.299871044774214, 50.917150128272276, 52.80848956877186, 51.39291794069352, 53.13314022556428, 53.60813140869141, 52.60107855642996, 47.15586777656309, 40.75941162724649, 38.470151655135616, 41.738156733974336, 39.514255216044766, 38.74881252165764, 39.13867650493499, 39.76571836779195, 39.22347030332012, 37.480008140687026, 44.354864012810495, 46.68144141474078, 42.78684554561492, 40.399973469395796, 41.52750976624028, 39.402722620194965, 40.05227104310067, 45.41502575720511, 51.599289524939756, 55.014148143029985, 55.25827646255494, 54.450499626898, 55.902627744982325, 52.53216251250237, 52.48138350825156, 47.71449565887452, 53.0829260426183, 40.9877759410489, 43.36277108038626, 60.777306249064786, 53.13316768215549, 53.504047393798835, 52.03766146013814, 55.44420465346306, 51.081560196415076, 53.02824035767586, 50.82973618661204, 45.364380113540165, 38.03102270249398, 39.982511689586026, 42.18577369566887, 41.336204005825905, 40.438145975912775, 41.26056894179314, 40.42236235833938, 39.9392871702871, 45.51084533814461, 51.83891104113672, 53.59330877181023, 58.052094444151855, 55.796429572566865, 52.705652867594075, 52.93797485290035, 48.25556701229465, 49.95884449251237, 48.569254644455455, 49.895619807704804, 51.78269563182708, 56.643853725925574, 49.55748011988979, 52.609182173205966, 56.96862205382317, 54.09459552457256, 52.1374975481341, 44.22445304932133, 41.15568476338541, 44.05255909888975, 44.431346308800485, 44.23969145744078, 45.638581245176255, 49.81438359906597, 54.80583106317828, 57.81195909746232, 58.636841389440725, 58.887594592186716, 56.019690882775095, 57.72576501292568, 62.95501009110482, 66.18841202028337, 61.925650719673406, 43.56471430870795, 24.790815076520367, 12.476348588543555, 11.069590526242411, 18.143319391435195, 6.522199492300711, 1.5472109063017754, 0.21437375565930722, 0.9762121749020393, 15.288707613945009, 59.273289095970895, 51.25724315643311, 40.458773720648985, 57.16282252342471, 65.69564857790547, 68.79298348580637, 28.768743661142167, 2.136559159524979, 0.14595421331544078, 0.14927612377270577, 0.13838115839227555, 0.18581900805715593, 0.14765669050956928, 0.11777902397537425, 0.13865074473282984, 0.2063743881280384, 0.13511313455960444, 0.1042059607683651, 0.1474483912029574, 0.20118811077648596, 0.1179215316510489, 0.13148367044425782, 0.1796616223310271, 0.10982114776608445, 0.0939318560244095], [0.03630461561824045, 0.05099448180126567, 0.0676652904780161, 0.013801582446772487, 0.02838043578630013, 0.014734681368985725, 0.06347329949118918, 0.036840310260172815, 0.05199633328424347, 0.02844571796876769, 0.010192964541455431, 0.03476973547930679, 0.001656378810894826, 0.03418994481645284, 0.016206477040184603, 0.03354640031654028, 0.08270124454171428, 0.04082365337038233, 0.3063122279221012, 10.318054595301229, 37.61072504904963, 51.24071428852697, 39.97845988119803, 22.500217576180738, 22.22221762903275, 32.85801264547533, 36.6455356536373, 9.21394661549599, 0.15334651745375127, 0.0539597055514253, 1.084974780678749, 6.0719246345181626, 13.388888009132879, 12.51119786693204, 6.576755739027455, 8.067352012280496, 31.182546730964418, 50.7530342378924, 53.85276963633876, 51.53228759765626, 51.533966372090006, 53.64568025835099, 51.22831959878245, 45.935104585463, 37.02344033025926, 35.63603524238833, 39.185968522102606, 49.12248926777994, 51.09184072863672, 51.13551632050545, 49.39763176825739, 46.31081273478847, 43.36087657559303, 42.092260468390684, 43.002799480192124, 46.280496735726636, 44.05738753657187, 50.55153815977035, 50.04906685121598, 50.87148981709635, 47.53361555837816, 45.206904795862016, 40.45214883742794, 36.84140313056208, 35.491174267184356, 36.14198569328555, 37.71290671440863, 35.54312606011668, 35.128519765792355, 38.42138874915339, 37.321897399040964, 40.863436806586485, 42.36655573691092, 38.27605316715856, 37.33101298732143, 38.558848211842204, 35.504780969312115, 37.965832910230084, 40.96512033093361, 48.287946178067116, 50.63424525722381, 50.51943355990995, 50.514809085476784, 51.8280460757594, 50.321479382053504, 53.67747499096779, 48.17255789233793, 52.527494891997314, 34.77955825867192, 36.79952006186209, 55.652686472862, 46.51402681104599, 51.092672271113244, 50.03664470488026, 52.22226781229819, 52.48676500012798, 53.302841571069536, 49.805424905592396, 45.4044000564083, 36.26091587928034, 36.471029404670965, 36.82335630539925, 38.791821310597086, 37.20992157536168, 38.47839255486765, 36.9493624471849, 37.06970076407156, 36.1127483460211, 41.46188851325743, 45.01736802439536, 46.38332559216408, 45.95260620117188, 44.96808736555038, 42.22453848008187, 39.72956195954354, 37.2493217837426, 40.36486041161322, 44.351745728523504, 46.24137893799813, 49.74869958816036, 52.11856426731233, 50.70487929928688, 54.04806444721838, 48.8376545906067, 45.6503915017651, 39.47028936878328, 37.20167675325948, 37.9355953585717, 38.2510402125697, 39.6506634835274, 40.280133293521025, 40.10931799488683, 45.0556032888351, 50.14149358195644, 51.27265807121031, 54.8239641804849, 55.50131044080181, 54.09494853788807, 56.9732504506265, 59.88448850570187, 57.086630482827466, 35.9910136653531, 21.059026987321918, 6.601753494431896, 7.23975298866149, 6.877401980661578, 1.215500105773249, 0.652184316948537, 0.08431776667073851, 0.3106333621807637, 14.252781214252597, 47.2631210665549, 38.27269561829106, 29.993393921083022, 41.09202469548872, 54.40386656791934, 51.4938287581167, 20.93082824060994, 1.1875477024624426, 0.07052356452350655, 0.0838510046202329, 0.030769544180422544, 0.09338301531369649, 0.012937129790624304, 0.09628217547170578, 0.021909294920342586, 0.05942283175705422, 0.04192806487422317, 0.06226972173598986, 0.09937666506776888, 0.026508203084250132, 0.03137883305880091, 0.02409757144989506, 0.11863170281773615, 0.015344827308229383, 0.04887067923142065, 0.04646899741924098, 0.09831846781796026, 0.09993491333819206, 0.043587415148654295, 0.040561647469838785, 0.03915343613874528, 0.03991852431828457, 0.05714494975343828, 0.02312676759526855, 0.053256494293530146, 0.0075199894490651795, 0.011483470293422861, 0.027132143394180366, 0.05591268966635389, 0.02618378017007584, 0.049424442057047165, 0.03164312190135881, 0.05683491014004235, 0.5836734416023378, 14.036922397152072, 44.11389320127426, 56.36723641426333, 44.04641666719991, 28.084972558483003, 27.555297651598533, 38.54652020239061, 38.42029440787531, 11.085876207197867, 0.09744629203792542, 0.07864808783896508, 1.767747394980923, 5.529216672143629, 14.259200173039591, 10.632440409352704, 8.542154431343079, 12.531279421621754, 32.791461790761645, 52.193344254647535, 54.35959869815458, 52.79167829021331, 52.40609753516413, 56.06346453389814, 51.911745532866455, 47.13756991970924, 38.91266953560614, 37.13239592890586, 40.68250963764806, 51.760883331298835, 52.64519737612817, 51.33348226547242, 50.97924124810004, 48.71238977678361, 44.9859380722046, 45.37078926640172, 45.14246417630104, 47.7558413628609, 46.498698188412575, 50.915043815489746, 51.985878329123224, 52.05475514934909, 49.89208182980938, 47.282905501704064, 42.134347500339636, 39.62473269431822, 36.734632292101466, 36.906192841068396, 36.67129778092907, 37.48314603682488, 36.91868559006722, 39.900844020228234, 37.51095171897642, 42.76887324548537, 44.56931175724153, 39.279011064960116, 39.31979979238203, 39.920475482940674, 37.735095562473425, 40.7214823076802, 41.95409497907085, 49.951486126069106, 52.062450839627175, 52.57375140343943, 51.90454013885991, 53.978846380787516, 52.837287610577, 53.421218702870036, 49.419428379304954, 51.74593125620196, 37.37556719010876, 39.22553739240093, 57.21109905550557, 48.80829172749674, 52.924242634927076, 52.50566690198837, 55.915234242716146, 53.410471408597886, 54.08482490047332, 50.49777423181842, 47.20421098893689, 37.71764101520662, 38.64413230649887, 38.08786961340135, 40.07342438543997, 40.17242108621905, 40.4815117005379, 38.18779983828145, 39.11765652318155, 37.62359826795517, 42.42887827657884, 48.155479892607666, 49.19187991849838, 49.32882162832445, 47.57743627794328, 45.72940372651624, 43.89647230025261, 40.82413465745988, 42.46606626818257, 47.699135657279726, 46.971998829995435, 52.493429107050744, 52.807520743339296, 50.80541356917351, 55.33347614349858, 51.1768816363427, 48.642422537649836, 39.92669636203397, 39.426860886235396, 39.669079011486424, 40.40646106966081, 41.036727120799405, 41.666271455826305, 41.923441656174205, 46.483047931425034, 53.542451320155976, 54.584970243515514, 57.649176812941036, 56.8548027161629, 56.928711937319854, 57.73264485020792, 63.04614243968841, 58.0148240827745, 39.09705231266637, 21.11845481780268, 8.172553412375912, 11.41287930550114, 6.929309646929465, 2.6425078943852456, 0.4292496359877048, 0.29140599552662144, 0.414691605875569, 15.358966089064076, 53.73357272917225, 42.504748682821955, 37.05159510335615, 47.62787403598909, 59.98817243883687, 59.08761585912397, 25.723062446040494, 1.4274979623094683, 0.03684378446890943, 0.04534717656732087, 0.0012550914224477546, 0.008206459291790041, 0.05419300230700643, 0.07342240292458765, 0.023739576647658984, 0.046931028876814156, 0.03869310539636401, 0.05628935211608487, 0.003236985780418881, 0.026013162813239524, 0.018383187557300253, 0.028606964155070247, 0.0011696410177636052, 0.0017442597492199933, 0.033106079790741205, 0.31683453749264445, 0.15662234006149156, 0.22835095322901205, 0.12610210961992704, 0.16838145262051016, 0.133281234471548, 0.13188807293772697, 0.16802831673093382, 0.11110536393619354, 0.11038226120534445, 0.09726928742302042, 0.0773805877073638, 0.10397235757761425, 0.1459525738872828, 0.12402729071196049, 0.15145152236425108, 0.18236038154892384, 0.14921425451194087, 0.6581608446375017, 17.126952871199578, 51.28260520196731, 65.36915832950224, 52.213701355841856, 33.54376062270134, 33.65639932693974, 44.1456251759683, 46.57647486655943, 12.994382881349134, 0.3042792757191966, 0.290596240590657, 3.0656502467970697, 10.444123495009638, 18.44840330462302, 19.518731832504272, 11.858713549952354, 11.478676084549198, 33.700290649167954, 53.98351400129257, 56.370919519855136, 53.82437167629119, 54.56740194751371, 57.548991633999734, 55.6631003656695, 50.37247411666378, 41.47463229394729, 39.43733753696565, 42.87631088687528, 54.723508358001716, 53.65686685808244, 53.01563385994204, 52.97140129150883, 51.133264880026545, 47.59122733146914, 46.58729276349468, 47.172922242072325, 51.10337249694332, 48.500475883483894, 54.01447326906266, 55.21400467042, 55.81512358880813, 53.27678526601484, 48.82010590645575, 44.770760766921505, 40.243925894460375, 39.635915371679495, 39.31277090503324, 41.593323215361565, 38.44750388976067, 39.20242286497547, 42.73612929928688, 40.88014610352055, 44.14131449114892, 46.75452301579137, 41.33813773432086, 40.79989048742479, 42.443900954338815, 37.694914802428215, 41.470019586624645, 45.29815873792095, 51.331815258149184, 55.23758988226614, 54.875998343190844, 54.408808754336455, 55.95854505415886, 55.7657644825597, 54.9660873413086, 51.94520335043631, 51.23052789318947, 39.22670233634211, 42.04702377319336, 57.836968129681004, 50.40602607111777, 55.496466313639, 55.30120680409094, 55.731031894683845, 56.10781085106635, 56.69389140221381, 53.18884572675152, 50.19382192242531, 41.524701349196896, 41.14971099361297, 41.047799971795854, 41.990796596773215, 40.88350365238805, 41.78772372584189, 40.093757952413256, 41.512345883154104, 39.8305316125193, 45.43914441139468, 49.580543656503, 52.19294417288996, 50.355490253817656, 48.49086215419155, 48.37561899615873, 45.879861923956106, 42.23456013587214, 44.85648808940765, 49.34588001620386, 49.86123631077428, 54.08078093682566, 53.09459509388093, 50.77813740699522, 58.53162773193852, 53.54644821536157, 52.18908063827023, 42.26190297834335, 40.80846478862148, 42.51889274966332, 42.69470122552688, 43.1453933254365, 44.418563304408906, 44.356221152890114, 48.855544520962624, 55.87199403393654, 57.37131610993416, 59.89893459504651, 59.25084921621508, 57.3003133650749, 58.5060146547133, 65.04514309667772, 62.13487778940509, 40.5125690275623, 24.83746578616481, 11.345905815401386, 13.294206896135885, 14.505795663402928, 5.794797414733518, 1.5346020796606619, 0.6396580439421439, 0.599667334989194, 19.09581795815499, 60.26771583864766, 48.928547674609774, 40.038385852690666, 51.92222218359671, 67.72371399787166, 68.82621380590624, 31.53372241604713, 2.2538421951955367, 0.1370105964522208, 0.17598893553499254, 0.1369702695838867, 0.14307663385425845, 0.09213402386634581, 0.2109840617425019, 0.10596355798864558, 0.17441113148966145, 0.09103398289411299, 0.10315642031210084, 0.1975019101894671, 0.13289196987546262, 0.22762758236738945, 0.12741070270778673, 0.18890188376028694, 0.09221651621403233, 0.1607037500868882], [0.06968496637719293, 0.0506154942746845, 0.05576175885395177, 0.024606636875579437, 0.028227538043152423, 0.06093340775659008, 0.08495608645100748, 0.06276144293106853, 0.03488101358074815, 0.03307337549725368, 0.05274185940863625, 0.030255085495751233, 0.0067187400042800416, 0.008781185155854592, 0.024184736933919693, 0.03142213617872087, 0.029030143463563536, 0.05211772757672495, 0.10961603538523759, 4.057669634780576, 30.583134043601255, 50.166408477290986, 44.212740851986794, 28.684422508362804, 33.48603510087536, 50.22139618473668, 45.25161981582642, 13.50784565171888, 0.4038965996474989, 0.027439788982812918, 0.7031010331646089, 2.7357352789371245, 10.452695835021235, 13.05229667694338, 9.775220136488638, 11.566170434797964, 24.75555689104142, 46.71988064242948, 55.573419294049664, 54.23535762294647, 53.38277947518134, 51.5820271738114, 48.941797441051854, 38.7622348723873, 35.25542413034747, 36.97148853732694, 43.616936745182166, 50.583356426608184, 48.31050372892811, 51.04677661772698, 47.34280009423533, 44.736526320057536, 42.67717999796714, 41.083152294158936, 40.15993618196057, 41.335399919940585, 44.573504770955736, 45.183782423696215, 49.60276388352918, 49.28711506628221, 51.0901148857609, 46.64388472034086, 39.013984357157064, 36.52275370013329, 35.21893432063442, 34.554626018770286, 35.086636697092366, 36.55024951504123, 37.932759484937115, 37.086884667796475, 35.67942842360466, 38.12584992377989, 36.31174587434338, 38.52797131384573, 37.95599952820809, 38.139495849609375, 36.18764992683165, 36.966405145583614, 37.170372316914225, 42.213493085676625, 43.74997961905695, 48.61695458812099, 46.656008766543486, 49.49581261604063, 47.64647783771638, 51.05634327857725, 51.617081396041385, 49.33547004576653, 35.80938046978366, 36.10884951006982, 45.35838673191686, 49.38759442298643, 53.70496296113538, 50.18296087941816, 52.38003338536909, 52.90827858832575, 52.477861219836825, 48.5483915575089, 45.15171704753753, 38.224819167967766, 36.60109912195514, 36.29484438127087, 36.491747363921135, 36.485204850473714, 35.8822424181046, 38.12087243603122, 37.04346402998894, 36.61469013460221, 36.5808008563134, 37.44641696253131, 39.659308387387185, 39.50552794241136, 38.88229470099173, 37.732373437573834, 37.9669076396573, 36.67730292966289, 37.83064842224121, 41.31707852886569, 47.02568431054392, 48.158884509917236, 51.85199214566139, 50.21972133267311, 51.77077162650324, 50.88323339339226, 46.060267417661606, 42.642274825803696, 39.270475987465154, 38.57721667135916, 38.301179870482414, 36.62402145324215, 37.583488110573064, 38.91225768673805, 38.759234259205485, 46.820442368907315, 49.35441901606899, 52.69357196746334, 55.60707323012814, 51.00871001520465, 55.045986021718676, 59.695724441159165, 51.99533908597885, 38.805067154669, 19.353148975679954, 6.746260966024091, 13.301341687479328, 10.102615471809141, 0.6958515124936259, 0.2273699929637294, 0.08761877824942912, 0.6689917344239451, 14.977337121963503, 47.22254022475212, 42.03322487492716, 21.833753931906916, 34.94216795890562, 49.88578250331264, 52.58968407107938, 19.225691556930542, 1.5272730084196215, 0.024632070994665547, 0.024656323423128457, 0.028372311423863136, 0.039099802323166406, 0.06527292812543531, 0.06853468535888581, 0.033696323723321965, 0.02972199555276142, 0.03544779607064782, 0.0391456718376327, 0.04239909020402739, 0.06844224918994211, 0.06342738784188706, 0.07432573550050298, 0.015254690360668448, 0.019536303100927223, 0.025027814779370546, 0.056288609010798324, 0.04106069629591319, 0.049284546741194306, 0.04348858980642211, 0.014829549867088997, 0.037718143599528464, 0.013899025957911246, 0.036309273432820074, 0.05790102107810879, 0.019681832993463166, 0.05579097361694421, 0.03113352021412744, 0.015382046732420643, 0.02185470157963855, 0.10557015651776906, 0.03821416637830196, 0.0852637780049155, 0.053635290298130245, 0.24356538279642984, 7.197607611456226, 36.28408924225838, 57.30571054643201, 47.926782177340606, 30.736345744902092, 29.966731609836703, 45.27145131941765, 46.75628808236892, 15.103401118709197, 0.2397407501214935, 0.15693444428184342, 1.1984815544659093, 3.134440039434741, 13.086729203501056, 8.213753498369648, 13.460436944038639, 8.808731455956737, 29.4952372197182, 49.61048310802829, 56.49312096257364, 54.09357963069793, 56.16669739446333, 53.726049623181744, 51.88540289478918, 41.96809391821585, 37.71953944237002, 39.09707192451724, 44.70465706240746, 53.54767199485533, 50.600355978935, 51.59479056635211, 50.474389060851074, 46.75404056426018, 46.058023821923044, 43.35276903644685, 43.65694099856962, 44.087836896219564, 47.54360975757722, 47.51483917236329, 51.76651585486628, 52.501179710511245, 52.846316906713675, 48.254072589258996, 40.74209436293572, 38.56264114379883, 37.10397051226708, 35.466592773314446, 38.30462371149371, 38.24271302069388, 39.03730677020165, 40.91833822188839, 36.65269397920178, 38.09216460874004, 37.26297555431243, 40.771425847084295, 39.95654952141547, 40.12892200100807, 38.54070724979524, 37.35996792393346, 39.88410334433279, 44.54698562622071, 46.100738433099565, 51.16214921397548, 49.689773821061664, 51.61512805569557, 50.944449824671594, 54.18347251030707, 53.72102898936118, 50.01895089303294, 37.073211285375784, 39.512992212849284, 47.4468997986086, 51.23898844565115, 55.93315947440363, 52.74953242271177, 54.38343494169174, 53.3736325079395, 54.2987980381135, 50.32700992399647, 47.785623919579294, 39.559436998059674, 37.9105039565794, 38.41401077085926, 39.40269124123358, 37.802521105735536, 37.93385774858537, 39.579099839733495, 39.469469593417266, 38.32682040429885, 38.96558230923068, 39.7298090688644, 43.674419080057454, 43.04571413224743, 43.31576147387105, 38.77386469994822, 39.89433288574219, 38.069069693165446, 39.375873996365456, 44.659334075066354, 49.08927855953094, 51.91700150889736, 52.84482248367802, 49.61846905369913, 53.984604420200476, 53.94191726561516, 48.690448038039676, 45.694467175391416, 41.206502991337935, 40.46194299574822, 39.585603129479196, 38.32421595050443, 40.60067330637286, 40.64229357627131, 41.19560272462907, 48.190055585676625, 53.533488704312234, 55.450955052529615, 57.427186350668634, 51.76271115579913, 56.81554763547836, 59.76810393794891, 55.84706344912129, 38.74255634123279, 21.744843606025945, 6.30581017463438, 10.949933721173196, 15.092496929630158, 4.5308626563318315, 0.2718923264934171, 0.06848130435232194, 0.8429714664816857, 16.478471332980742, 55.22424597893992, 43.392055496092766, 24.955766431746948, 40.43936975540654, 55.888334628074404, 58.72376111245925, 24.11040936746905, 1.623264805924508, 0.06545770087189252, 0.06475626310754208, 0.014251562383686824, 0.035926520584091064, 0.08657299162399384, 0.0570091491775407, 0.020306719421979882, 0.021316752723988988, 0.049641984214465466, 0.0832134509278882, 0.010572595581893, 0.09822863634795913, 0.039716227310559446, 0.007725403955837171, 0.05462576537543247, 0.005995755059449303, 0.01021269609355518, 0.16485274438896488, 0.11477287963873918, 0.10048993637845402, 0.17462430311547172, 0.07131531639325042, 0.21529287730734195, 0.18820149553639276, 0.1916114907831915, 0.15024801355696496, 0.12356144796696403, 0.10819585393032721, 0.15190539881587029, 0.09252620725742272, 0.16235030286254423, 0.18420990165923873, 0.11419480501283562, 0.13399020288019411, 0.15576769237316426, 0.3786281394141336, 8.42573260107348, 42.65104916787917, 62.97520637512208, 56.700849686899495, 39.979393405299035, 44.08269074655349, 61.46200303108462, 55.177628609441946, 18.761108383055657, 0.8522302212734377, 0.16252320890705432, 1.804435284387681, 5.16002603115574, 17.045438174278505, 25.255664971566972, 17.726165517683953, 15.571148664720598, 28.631470511036536, 49.582249887527965, 58.102763622037834, 57.26026988798573, 57.388123466122536, 56.21227141349547, 54.540419963098344, 43.75431383809736, 39.43143829222649, 41.27370495950022, 47.20416392049482, 56.22831782987041, 50.7486137267082, 52.14895871377761, 52.611504216347974, 49.84617048694242, 47.70509765994164, 46.75255790833504, 44.75692656732375, 46.67347115855063, 51.275372351369555, 49.85514486989668, 53.344756018730905, 53.90493715963056, 56.40530301678566, 50.48382236111549, 43.40449333190919, 40.93368645637266, 37.82405099561138, 36.53671733794674, 40.40761424649147, 40.41948726100307, 41.07132634808941, 43.152159413983746, 38.462506955669774, 40.803338250806256, 39.58186903307515, 43.19823941876812, 42.240981055844216, 41.613342992721066, 39.783227828241166, 38.20360699007588, 41.968160598508774, 46.30832987446939, 48.144913027363444, 55.4104644252408, 51.92655640263712, 53.89900261355985, 52.44920830572806, 56.601649022871456, 55.342183805281124, 51.41659728942379, 40.970705786058986, 44.71708705348354, 48.95772618632163, 51.52511750498126, 58.277622884319676, 51.94293622047671, 57.01676914768835, 57.477604496863584, 56.28985197313371, 51.85038005152057, 50.57783372940556, 42.26966142654419, 40.21850893574376, 40.709919160412205, 41.65818745090116, 38.877756518702355, 39.147035075772195, 41.33141871421568, 42.40888987818072, 40.888787085010165, 40.04316722193072, 42.763558433901885, 43.59812113546556, 43.79411020586568, 44.35700954929475, 40.81429343069754, 41.6564812198762, 39.080978439700225, 41.77312074169036, 46.50004356138168, 51.63839947792792, 53.69778894609021, 55.67316908990183, 50.12084622536936, 53.24241745856501, 56.18497563946632, 52.44654893875123, 47.19837057975031, 43.99002082886235, 42.50723154314103, 41.69017045728622, 40.2376736364057, 42.0502636509557, 43.00519212599724, 42.62039584498252, 51.47562896051715, 55.21360458866243, 59.734983444213874, 60.23021797980032, 53.280091824070105, 55.915697082396484, 63.442395963976466, 56.27773577167142, 42.65594428585422, 21.61582116157778, 9.13548058079135, 24.914132433552897, 19.975886037272794, 2.9431987529800785, 0.8417369617569832, 0.3027438516578367, 1.0614221735346703, 20.716005909827448, 60.230214057430146, 51.17854472129576, 33.40514013844152, 49.09134172624158, 63.59101849217569, 67.02004078895816, 29.221540112649244, 2.1775577337511125, 0.1054201488413157, 0.1442470323414572, 0.12688214800530864, 0.18263451845174838, 0.20959169694012214, 0.16749052300808892, 0.1345373888409907, 0.07795343761362376, 0.16525705495188314, 0.14628954532165683, 0.09208713928537984, 0.18911913097385438, 0.163062856562676, 0.11934387347390575, 0.12919853741843856, 0.1062856749781678, 0.09162243801139056], [0.10300615216575323, 0.011978674315727286, 0.026170528764205597, 0.041680878944574826, 0.03488871659482679, 0.011300821525735721, 0.033901505052082004, 0.0203212195511667, 0.03513031008262788, 0.10730915312324801, 0.010111263179550729, 0.06860864348709583, 0.05163017389995437, 0.05719929220034711, 0.03408440088312473, 0.026805414555353985, 0.02242120061700623, 0.04016586346551776, 0.045846972329121445, 4.47895989302666, 29.677109679868146, 46.701296452553045, 45.65503166567895, 34.62806847787673, 42.56996200930688, 57.4765258450662, 46.99183425595684, 18.035240442522113, 0.6274174298009565, 0.04666757507009372, 1.830885787644694, 2.6349073215838406, 8.403024038960858, 4.344942800460323, 9.281760473405162, 10.66135710285556, 20.179109919455744, 43.7531175151948, 52.49330359120523, 51.534809681677054, 49.838831732350016, 46.25506408752934, 40.28436553093695, 37.4667779860958, 38.11010160753804, 37.17585186804495, 44.61241860543528, 51.28576270995602, 49.21296265817458, 49.75785440014255, 46.98487597127115, 42.09241344082741, 40.275018522816325, 35.89713173527872, 38.11921719581851, 38.893963752254365, 41.5441406157709, 45.2894236195472, 47.353641525391616, 51.87128236216884, 47.82019961264826, 43.336930505691036, 36.73793885015672, 38.207203803523896, 36.800779142687404, 35.30458711808728, 37.3389793211414, 36.081502745228434, 38.315492599241196, 37.99874944071616, 35.350459237252515, 36.58446042768417, 39.09815057631462, 37.63669506196053, 37.483004831498675, 37.26592909905219, 36.88158781297746, 38.146465901405584, 37.774817405208466, 38.18097491418162, 40.702360753090154, 41.10803188816194, 41.97762920010475, 44.53791318401214, 44.97340609950405, 47.48260121191702, 52.06940520194269, 48.35503831986458, 35.25701269026726, 36.697518825531006, 50.79835722523352, 51.02215982252552, 52.17431291457146, 49.04083336553266, 50.84466864985805, 50.0740288149926, 48.30034479018181, 48.15909239553636, 42.21736054266653, 37.46733496266027, 37.151795971778135, 36.877171224163426, 38.32589864730835, 37.15775797444005, 36.800673238692745, 35.99315135709701, 38.13727186572167, 37.990163372408965, 35.44592188250634, 36.13863598915839, 36.319778888456284, 36.198134422302246, 38.31307641921505, 36.771541795422955, 37.47483845679991, 37.161903919712195, 38.3182264912513, 45.269341084264944, 44.83724886371244, 47.85430854366672, 51.46438352523312, 47.31908544417351, 52.06902080966581, 51.61757953705327, 49.4193930779734, 46.608677525674146, 47.38134130354851, 47.91142609811599, 47.4119750145943, 43.13288488695699, 39.03523968112084, 39.16993387283818, 39.94952455643685, 40.89781245877666, 49.92184085230674, 51.320765941373764, 56.41626604141728, 56.23018095570227, 58.06782314854284, 57.569078091652166, 52.0744768265755, 30.313333811298495, 16.63409136956738, 3.914587944746018, 12.458976411050367, 12.42318674441307, 5.665294970235517, 0.2910403264386039, 0.041163566582385576, 0.8287290339508365, 15.90827343925353, 44.812369269709436, 48.81167281058527, 39.21344472515968, 41.45332597917126, 53.383869894089244, 51.71607025208012, 18.3513383711538, 0.5163602374734417, 0.07488298785662459, 0.024108993820846084, 0.052424089968084335, 0.037048169066228216, 0.010837014659398026, 0.04146885262021134, 0.033088770034092094, 0.08358092798340706, 0.025394887723509344, 0.01288082615862931, 0.07244584766486961, 0.04424776378718596, 0.09638044156975324, 0.056329625358264294, 0.02139004818614452, 0.018338605070546753, 0.05387358960785693, 0.06181255110629624, 0.01821530896479324, 0.04978253836593321, 0.03534020668256187, 0.06937589586502121, 0.03328865003441611, 0.08624270813719881, 0.033486151331735235, 0.054685995208039406, 0.015166208163023958, 0.01475263655471105, 0.056080872778810804, 0.050777464414075504, 0.02349087769436019, 0.028693330992433815, 0.027824254038052696, 0.07089504055799016, 0.024994987911815127, 0.16507527760920987, 5.442806857247507, 34.6521871320663, 53.33162392339399, 50.15394710725354, 36.70362987825948, 42.47123987443986, 60.755340976099816, 52.34742279975645, 20.680414322883856, 0.843925215303898, 0.03591577237051341, 0.1047009991241559, 2.198853752305431, 12.879072062430843, 7.580703545001246, 9.601400302302453, 9.701014776383678, 23.9116059964703, 46.88487514372795, 54.43317451784688, 55.04096538789811, 51.63210799617153, 48.717178990764005, 43.01982648911015, 40.19168776850547, 39.34105903871598, 38.79198212777415, 46.60802248985537, 55.000988591101866, 48.985826046236106, 51.31483531767323, 49.14306994407408, 44.53403395991172, 42.20781741603729, 38.648380233395486, 39.254676680411066, 41.581034429611705, 43.22791999386203, 47.307275187584665, 47.615875505631976, 53.7358751604634, 50.76293037783716, 47.73799457857686, 40.33022588299167, 39.53958196024741, 37.57308598487608, 37.572666291267645, 38.61464784991357, 36.95630112001973, 38.873441911512806, 38.234550568365286, 37.2692435018478, 38.606410872551706, 41.39957381832985, 39.44080883456815, 39.908880956711315, 40.072706591698434, 38.31154669484785, 39.446743380638864, 40.094762079177364, 39.19795136297903, 44.5632085492534, 43.41485231153427, 43.87917857016287, 45.731125647021884, 47.66969042439615, 49.48624203282018, 53.799154758453376, 49.43400390686528, 36.995367926936, 41.22350646603493, 51.63973700615668, 52.021246340967, 53.82410887748965, 51.77083046205583, 51.881602118092204, 51.50221478554511, 51.73808651585733, 49.582677425876746, 44.15403473761774, 37.41350043204523, 39.22965980345203, 39.35761144084316, 39.02158198818084, 38.380027355686316, 37.717550800692656, 38.154683266916585, 39.763545374716486, 39.486696643214074, 37.112948817591516, 37.86329038681523, 38.5814606758856, 37.69541686581027, 39.34444796654486, 38.63596985417028, 39.07872699922131, 37.82454521425309, 39.7531863950914, 47.699869140501946, 46.33497845742011, 50.51709582728725, 53.381661599682225, 47.017015872463105, 53.99674023351362, 53.154297490273755, 49.760568680301795, 48.058766011268865, 47.90498556629304, 49.647376921869096, 47.88367140677668, 44.311345315748646, 40.02612844590218, 40.474710310659106, 42.77439202031782, 44.73785992591612, 51.530777485139915, 54.8068351899424, 59.083348320376494, 56.60634802233789, 55.37900701645882, 58.08974527543592, 54.54197714405676, 32.66966631335597, 16.483109535709506, 5.260008227440619, 12.573780263623885, 14.646259661643738, 4.233300378245692, 0.544601425288185, 0.08902084172493027, 1.1560495990899302, 17.903727293014526, 48.52201754047025, 52.00196789157007, 38.681504649500695, 46.42587938616353, 60.548569310096006, 58.63859861127792, 23.161995949283725, 0.9971337296789693, 0.04892340140236963, 0.07006863853143108, 0.011798866776629321, 0.041992194094364686, 0.03932785903734546, 0.015806505407747484, 0.05787592786814898, 0.01941881202641995, 0.04089697564561521, 0.027208679408255606, 0.11230530277375253, 0.10347788612688742, 0.029110417986709266, 0.05111426347866655, 0.036991321511806986, 0.0284226682983459, 0.04223977455929403, 0.21584826040892832, 0.11848940964668028, 0.12742907349621097, 0.13485980460480337, 0.1399083393475702, 0.08619247575200374, 0.19774863646636087, 0.15640866281765123, 0.06427769564212331, 0.1861217506830731, 0.10101289863908484, 0.15160774301377036, 0.22799533521456106, 0.1094177182042791, 0.10642415303136073, 0.12392252818831515, 0.23031149480131366, 0.18876683778099476, 0.17990185218232294, 7.3748845246530355, 40.677740035518525, 61.57990947846444, 58.56703888985419, 46.16280209633612, 52.25206605849728, 66.50641425963371, 57.57986068725587, 23.927115048131636, 1.1551441444504646, 0.20748014411618634, 2.0045016585819186, 6.39047404450755, 15.083391147275126, 12.722920544685858, 15.4537776208693, 14.569209602571304, 24.403469254893643, 48.36377343823833, 55.95180642220282, 57.07335718216435, 54.71034096133325, 51.37937399648851, 43.363104481850904, 41.62791459791122, 41.57853195744176, 40.89692992548789, 48.573286840992594, 57.20831417268323, 50.051828199817294, 53.36603095454555, 53.642377622665904, 45.30102599051691, 44.550045074955115, 39.799203641953014, 42.018433617007354, 43.460928393948464, 45.836080428092714, 49.55848816902407, 50.969953075532, 56.62828583871165, 52.842359235209805, 48.89573312574818, 40.81906695519724, 40.84508011418004, 39.74168600574617, 38.83499091671359, 41.31424265523111, 38.33238232520319, 41.68877801587505, 40.02933302233296, 40.08200260900682, 40.36718245475523, 44.01538287439654, 40.145533238687825, 41.294826922878144, 40.167851524968306, 40.30982563572545, 41.6243334739439, 42.93473066822175, 41.195720395734234, 47.05394106526529, 45.25276907028691, 46.20864283653998, 47.52398221723495, 49.864436964834894, 51.63051551388156, 56.82382383654195, 51.12168212090769, 40.345832993907315, 44.284869317085516, 53.23528266722157, 53.802241663778986, 55.71586801159767, 54.925467275804095, 55.82002655152352, 54.89009926396032, 53.12425997949416, 52.47806126071561, 46.666316755356334, 39.948014443920506, 41.076323447688935, 41.17080550039969, 41.83835760239632, 39.726612337173954, 39.90498212076003, 38.61977046535861, 41.66075660336403, 41.63612411868188, 38.623924255371094, 40.632362134995006, 39.95649853060323, 39.86665664180633, 42.093401878110825, 40.25364945011754, 41.5839958190918, 39.73481793557444, 42.38438290934409, 52.161341636411606, 48.68740820115613, 52.41034938443092, 54.27025887273974, 48.340627531851496, 53.369215919125466, 55.742893142084924, 52.77513373282648, 51.080865936894575, 52.056602585700254, 53.12387950958745, 52.97950883065501, 47.62303775356662, 42.338055795238866, 43.747818393092004, 45.55044558740432, 46.05833368916666, 54.46620871943813, 57.99371780887727, 61.26065208065895, 59.54205774491834, 57.24347429890787, 58.20639264199042, 56.48711581383982, 32.288049113365915, 19.89007046145778, 7.083222962194874, 19.95344811870206, 19.612707899462794, 8.891981801679059, 1.268216148018837, 0.29425357498468896, 1.5084996867564417, 21.443607537977158, 57.5304505901952, 60.75205010752524, 50.973628336383456, 54.38888311386109, 67.33354014735069, 67.48244116383215, 30.149072793222246, 1.459705769535034, 0.1334627666660855, 0.19771259969040272, 0.16365698839147247, 0.17361554918029617, 0.17225232636255605, 0.10834320328168331, 0.13873196537456206, 0.09697389158029711, 0.3024478659274117, 0.13608767500808164, 0.16730249438795353, 0.22140023749201532, 0.20118107808934105, 0.14332314562653342, 0.17059380729352275, 0.15016391242463745, 0.16937493076247556], [0.020792482368227456, 0.029653137654907284, 0.08037978362652563, 0.040655359175176396, 0.008266567507938994, 0.042823399492209, 0.024730804406346816, 0.059425532216987306, 0.044384525803428505, 0.03551980450509056, 0.05714170154063933, 0.038127261364171584, 0.014974674690634975, 0.0472757033252668, 0.011921579697950473, 0.06437615326215183, 0.016200080206016862, 0.0778180698774034, 0.016033156350585484, 4.297123714800804, 23.679082009100146, 49.98399865242743, 47.553231331609915, 38.284505874879905, 29.9615462364689, 31.540627748735492, 42.983489651833814, 22.779639382516187, 2.730256218102671, 0.04150989578075467, 0.6796028489066709, 1.6884273867453299, 13.029275305809515, 4.492592580856816, 13.516843568894172, 5.344274957333842, 20.676321329609042, 43.22856326257029, 51.22780184591971, 49.87799267615042, 47.4009374649294, 40.04936456680298, 39.25853237029045, 37.75258541107178, 37.58499822308941, 38.95572931535783, 43.90634098360616, 51.520920568896884, 50.32347586847121, 50.1416543991335, 45.28389699997441, 43.384744198091575, 38.34169403199227, 33.529243930693596, 35.67407438831945, 35.61760402494861, 39.411442049088016, 39.800023417319025, 43.12875463116554, 47.55809507062359, 45.23781699519004, 40.64043437280963, 35.355538706625666, 33.87151779667024, 36.206798938012895, 35.908000623026204, 39.303000280934, 37.982193116218816, 37.124111883101925, 39.563284843198716, 38.72941247878536, 38.215248584747314, 37.057004051823775, 37.11801651985415, 36.926196928947206, 37.96775879398469, 35.66144043399442, 37.54980279553322, 36.68410039717151, 36.47340636099539, 36.538509861115486, 37.945664082804036, 39.653177722807854, 41.83201120745751, 45.41567687065371, 48.205850970360544, 50.41987988256639, 51.16047828428207, 37.78189336099933, 41.351411034983975, 52.37452245527699, 50.79052817436957, 50.68706781633439, 46.362364445963216, 48.18577627981863, 46.35219766247658, 45.648367558756185, 41.90281391143799, 37.908652597858065, 38.83743847570112, 37.19406343275501, 35.50377684254801, 38.32874628805345, 35.850059370840754, 36.11452517970916, 37.98594290210355, 36.21947603840982, 36.66281369424636, 37.08664540321597, 36.56657834206858, 37.792624965790786, 39.82418913995066, 37.944295175613895, 35.79094532997378, 37.640464459696126, 35.93519441543087, 39.75820702891196, 44.860645801790305, 46.9047184144297, 48.16948275412283, 51.31765550182712, 48.789256465050485, 49.15668056857202, 49.961672521406605, 48.66519974124048, 48.245086439194225, 55.421450984093454, 54.97974895661878, 55.904608541919345, 52.47082448774769, 46.7834936418841, 37.779928253543, 38.56162132755403, 37.764085800417014, 44.813043917379076, 50.15767728128741, 55.149732712776434, 54.82413284240231, 55.940498228996034, 51.90701515443864, 49.037958268196356, 25.807671893027525, 12.373745268391026, 2.2449040941653715, 9.341034350856658, 14.017082068227953, 5.608941787673581, 0.19403419787845305, 0.013882856714659402, 1.0448528561861286, 15.255420419477648, 47.386820854679236, 34.398617667536584, 27.88737923868241, 44.119694386759114, 56.45839621943813, 50.17316279872772, 17.40172274651066, 0.7857100100767228, 0.015176037071092476, 0.01484701092610316, 0.04403414399993997, 0.042751417870843605, 0.02451277003743716, 0.020081464674383886, 0.05968934608503215, 0.0539057461484786, 0.01331728655889991, 0.01571799735463555, 0.051364946599689223, 0.02145018034254111, 0.009516348983461579, 0.04595103771275571, 0.009788856034227198, 0.04412417848324103, 0.03279222122904274, 0.05139634471326586, 0.0266564219454003, 0.09940117222046661, 0.040060442106257525, 0.036928402710585825, 0.04261841734630927, 0.07718111373363964, 0.013700270191616109, 0.011031290726555933, 0.053386365348893794, 0.04347263219495935, 0.03012287787221853, 0.07519401955388247, 0.08956333922763025, 0.03542059611889624, 0.09739278079641443, 0.010527912546099435, 0.008134928704690068, 0.0004130688930379092, 5.343232587460549, 28.97599973986226, 54.45841889227591, 53.69127781160417, 44.14083203961773, 35.85141651092037, 42.60952695723503, 50.61044039264802, 26.046263787054247, 2.280234108048101, 0.16581492017834418, 0.9000688574967847, 3.9600428217841737, 11.678547320827363, 7.585708979637393, 5.133135732143156, 7.413371311080072, 23.97722136589789, 43.97584930542977, 54.06179666519166, 50.657897149362874, 51.04214822092364, 42.775380457601244, 42.40668550614388, 39.335850131127145, 39.29573997374504, 40.66719278212517, 46.998792540642526, 53.31988819183842, 50.039049117795884, 50.040112080112586, 48.18472508461245, 45.340132021134906, 41.04164185062532, 34.86615634733631, 37.666673737187544, 38.09328640660932, 42.15336315093502, 44.056508925653276, 46.69957845441757, 48.47363510439473, 48.028387254284276, 42.653131946440666, 37.88818959266909, 36.55197535791705, 38.34081934344384, 37.831836900403424, 41.067105877783995, 39.834450060321444, 39.583857674752515, 41.32829650755852, 39.957086886129076, 38.42166723743562, 39.313135685459265, 37.80611399681338, 38.64502268452799, 39.55284741617019, 37.363984430989916, 39.03977394104004, 37.935061916228264, 39.331817934590006, 38.1290937239124, 40.22247837435815, 41.75059064742058, 43.21675692835162, 47.57358451043406, 50.85287032588836, 54.15207001470751, 52.40837643223425, 38.88870385385329, 44.0352810582807, 54.60432321794572, 51.66558542559224, 53.58460895476803, 49.67936777299451, 50.42604584847727, 47.75264855354063, 48.257049668219786, 42.73627050461308, 40.189197063446045, 39.204850812112134, 39.73344510601413, 37.89403000185567, 39.74365895794284, 38.601264722885624, 38.4833739649865, 38.18865099260884, 38.9493436967173, 38.08142515920824, 39.49738902430381, 38.69355024829988, 39.96542584511542, 42.62679715310374, 38.57564772329023, 36.701123483719364, 39.64212840603244, 36.402729172860425, 40.4836376251713, 45.83769644460371, 50.41889536765314, 50.85296054040232, 53.478324490208784, 48.95429803479103, 49.66331351187922, 51.8310074652395, 51.9698436798588, 50.552102981075166, 55.9096448652206, 56.26230516741353, 58.6741509745198, 54.789141378095074, 48.75122124148954, 40.29745448020197, 41.331763882790845, 40.40313097738451, 48.0536747747852, 53.621824402962964, 56.389193842487956, 56.115443783421675, 57.12951767829157, 53.144048337013494, 51.88626189385691, 27.79361301852811, 16.99663212222438, 5.695400141900586, 11.562342201509784, 11.631714220969908, 3.060506303464213, 0.5428821401249978, 0.027425518680003383, 1.236135572675736, 18.963463460245443, 54.09025346079181, 39.959142208099365, 33.94010043913318, 48.93732593905542, 62.53761499158798, 57.78884064766669, 21.95899913387914, 1.0207650293746302, 0.024054750965367404, 0.027343796250680764, 0.006071552756287519, 0.03418403444811702, 0.04326852721973293, 0.07780175220461623, 0.061463559752390276, 0.03964511136854849, 0.05152476786245262, 0.03255325925326155, 0.058567134528270656, 0.04815649376401017, 0.028480806710919546, 0.0388763536278519, 0.011147190253400515, 0.02749234644485818, 0.06242349090415144, 0.10608165810305266, 0.1306896203107411, 0.21123641110475988, 0.16188306583752557, 0.1149180303177526, 0.1916986869107331, 0.21332464421228056, 0.1208684573911371, 0.08591999359909566, 0.13139670414309348, 0.12666752081244223, 0.17077276543263467, 0.13394972279427514, 0.25395805496842633, 0.14296055621197148, 0.2625606401312736, 0.12580580213257384, 0.2961174362609464, 0.13130979912896312, 6.856144205216439, 33.02526643199305, 62.942176095901004, 59.53025141069966, 52.62081984550723, 42.865449843868134, 42.64902130250008, 53.67485484769268, 30.542521822837095, 3.8388719818284436, 0.30726913302656145, 2.571741472328863, 3.876940300387721, 20.66559756955793, 14.433544624236323, 24.565129741545647, 8.308136020937274, 22.6340998372724, 46.550238132476814, 55.68259062305574, 55.253114623408166, 53.40826703656105, 44.62255793233072, 44.536124583213564, 40.99520883252544, 41.10081472704488, 43.28131521901777, 48.35144542878675, 56.653730254019464, 50.623521497172696, 52.35829168750394, 49.4532274430798, 48.48331943635018, 41.62607892867058, 37.831778064850845, 39.774014180706395, 39.616001498314645, 44.837307699265025, 46.24305379006171, 47.72756891865885, 53.05959970720353, 50.46680319693781, 44.739060171188854, 39.06672062412385, 36.848290812584665, 39.99797759517547, 39.3246635313957, 41.969478514886674, 41.109891091623616, 41.974322642049486, 44.560796291597434, 42.33191728591919, 39.60843132388207, 41.821644383092085, 40.33108488205941, 41.29825507440875, 41.49186718848444, 39.760799715595866, 41.361428768404075, 39.80855065007364, 41.0513497168018, 40.25447314785373, 42.87269053920623, 43.231120647922644, 45.62930483971873, 51.319655910615005, 52.83767984759424, 56.85424573959843, 54.24091954385081, 42.17634431777462, 46.44322410706551, 55.188148406244096, 55.540361558237386, 54.70087628210745, 51.72296185647288, 52.55558298480127, 50.29673707100653, 49.46682237809705, 45.845172482152144, 41.63964640709662, 41.3988011114059, 41.211637373893495, 38.69659792992377, 42.02159504736624, 40.22714207249303, 39.95315274884624, 40.922342961834325, 39.94957162487892, 40.705247617536976, 40.41453330747543, 40.67894420316143, 41.82715139081402, 43.984023524868874, 40.396549240235366, 39.86618987975582, 40.96424564238518, 37.718123466737815, 43.814510453131895, 49.750903960197206, 52.91911609711186, 53.75101550932854, 54.13332500765401, 48.22015193200881, 49.89651410810409, 51.666201237709295, 53.91195427986884, 52.8854739281439, 59.73125327018, 58.336666322523556, 60.055923538823286, 57.90478590996035, 52.7245783036755, 42.29321133705878, 43.94815737201322, 42.96565071229012, 49.06850960946853, 56.41807033169655, 60.47910021197412, 57.95518836667461, 59.755721015314904, 57.31483790182299, 52.52611421769666, 28.7992577398977, 15.19764586802452, 7.173141337210133, 17.111379100430398, 20.561178192015618, 8.66461867286313, 0.746944796654486, 0.154908187687397, 1.6675210311528177, 20.8540694175228, 59.639210931716434, 45.50365955598893, 40.32614269564229, 58.390798953271684, 69.65195117458221, 66.40655071504655, 29.250598992070845, 2.171889908852116, 0.07477664719185523, 0.15758306028381472, 0.17892424738214863, 0.12767220682073988, 0.11273088759832806, 0.10327704085577881, 0.1314072455129316, 0.18782787445572116, 0.11171071895308073, 0.07604766366702896, 0.16773102865103753, 0.15495056767136822, 0.2228529087357944, 0.14167057139979256, 0.12911834333452488, 0.10628900746063841, 0.12492437201041369], [0.04999427357688547, 0.011880001233470057, 0.037115213250921625, 0.027370092218681693, 0.04556722766269119, 0.07204297734724899, 0.13150769496156325, 0.012572729535731337, 0.050619818841017065, 0.06297220521035694, 0.057517214858483885, 0.07514273762823113, 0.026868025006185618, 0.07302786764358321, 0.04158772265298232, 0.020914330567804076, 0.04572988345077442, 0.0658982550545085, 0.09612678985802398, 1.6961214835605316, 19.175236148218957, 49.78143176724834, 50.4466579037328, 35.2602368785489, 24.15072741047029, 34.60493041623023, 40.37393677619196, 31.740258739840602, 3.8095022545706843, 0.18195038661360743, 0.14973117999972838, 2.20681224138506, 8.79873235379496, 3.885918850860288, 2.757944964593457, 8.146784420936338, 18.678354217160134, 36.10509972418509, 50.64619671913886, 50.39875007444813, 46.65548709131057, 42.00482299250942, 40.17070308808358, 37.870021174030924, 36.55081433634604, 42.59596340117916, 48.32756211680751, 50.38036200308031, 47.41712116426038, 50.17151932562552, 47.336689041506865, 41.765185786831765, 39.18101456857497, 33.49435052564068, 34.490750220514116, 34.33599702773556, 36.61337614059448, 39.31551656415386, 38.46491529095558, 38.8877389507909, 38.046786708216516, 34.871043620571015, 34.68051841182094, 36.95439484811599, 34.020779671207556, 35.81543268695955, 36.17569454254643, 39.32245523698869, 39.72441188750729, 39.613224460232644, 41.800290999873994, 41.13225252397599, 39.70265842253162, 37.449421498083304, 36.41634371972854, 36.58806116350236, 36.51717216737809, 38.41526985168457, 37.46606411472444, 36.99635636421942, 35.101098475917695, 34.83564815213604, 35.404886045763575, 37.42751898304109, 42.56057577748453, 46.84679677409511, 49.40835160593833, 52.316855769003595, 39.42669222431798, 43.90950633633522, 53.97550059903053, 47.214334626351636, 47.37239437718546, 43.905948746588926, 43.06880512545186, 42.19413618887625, 40.01302772952665, 38.51784375406081, 38.08886589542512, 36.39921472918603, 38.014285948968705, 36.1739843891513, 35.9048274255568, 38.34394939484135, 37.29195794751568, 37.45981970141011, 40.73395544482816, 38.686976355891076, 38.08738716187016, 36.731533619665335, 37.46694272564304, 36.48562062171198, 36.871593613778394, 36.152387818982525, 35.628382698182136, 36.142954518718106, 43.42957296679097, 46.09832617544359, 49.65151502240089, 48.930281362225934, 45.5852448555731, 48.25040125077771, 50.56712565883514, 50.737407515125895, 51.76656292330835, 54.782312531625074, 51.59454345703126, 51.80154262050506, 48.56411633952972, 56.30435297566076, 54.38050100880285, 46.07187763337166, 37.10600230001634, 38.85199046904041, 42.58343142847861, 48.427198163924686, 51.5709190214834, 53.54126676436394, 53.62789623198971, 53.843712883610884, 47.78605538029825, 23.739631637450188, 8.26154120506779, 3.928850663285102, 9.746571144750042, 10.609593583691506, 2.2829964372419544, 0.21682583456558568, 0.07481947916770175, 1.1470353795636086, 14.073888774841064, 45.65269001068608, 40.71739912033081, 25.072335350898005, 41.6011679557062, 56.56838340144004, 51.05615108243881, 17.462225306418635, 1.7903983472816407, 0.06910729777788924, 0.029238199537259438, 0.04916404494114461, 0.0357976301212705, 0.019223007613853104, 0.08664073677913797, 0.02773705408007147, 0.018620933368501645, 0.0599057506018829, 0.09400136318177947, 0.07063415697625569, 0.007785527493744608, 0.03362480175471114, 0.01724218769419578, 0.04833311916539266, 0.0584328776195405, 0.009564303214691821, 0.08289562403074197, 0.035543591535139474, 0.06811711381399824, 0.023515187579417424, 0.018584812322871822, 0.07593887152090188, 0.10861655877482508, 0.0320957419687822, 0.027043916878380606, 0.03766919824204618, 0.040867925591526494, 0.037119104977576964, 0.04348831784520899, 0.0401662809834365, 0.039521924430324186, 0.06371560927119947, 0.020948090147407308, 0.04348959721204254, 0.022725439029595545, 2.53739107039667, 23.88160182583717, 57.04167227591238, 55.523052138666955, 42.34931692000359, 32.63950917028612, 38.91711358101138, 44.35485616807015, 33.014742712820734, 3.984160985677473, 0.2395233650120997, 0.18638078033203082, 3.3066504761095974, 6.530353609592685, 7.214114416030146, 4.052562953964356, 7.080541041589553, 16.888615931234053, 39.89812189532865, 51.826477127690474, 53.657729779520345, 48.874101254247854, 44.074014463732325, 41.37873034323416, 39.55369857049758, 38.62601095630277, 44.49610464034542, 51.7630131783024, 52.79003089474094, 47.444409093549176, 52.45232659001505, 50.078374801143525, 44.28093517980268, 41.18876211104855, 36.25949205890779, 36.38770649510045, 37.06573132545718, 39.51560058901387, 40.92348829392464, 42.63171188292965, 42.00279512713033, 40.34970437326739, 36.670364256828066, 35.63346216755529, 38.251455983807965, 35.222080061512614, 37.51535261830976, 37.86118015166252, 40.292151435729, 40.92162124572262, 42.190919845334946, 44.369466996962025, 43.45333468529486, 42.07867730048395, 39.90111466377012, 37.82396862583776, 38.32188998499225, 39.63964946808354, 39.55577350431873, 37.23782923913772, 39.050509468201675, 35.960144612096975, 37.3718919292573, 37.50308736678093, 40.023359252560525, 43.88508565964238, 48.71769674362675, 52.922493257830226, 54.030476539365715, 40.90889315451346, 45.94455749757829, 55.68466947924707, 49.50069988927534, 49.43766347823605, 46.577196582671135, 45.50660917835851, 44.36025727179743, 42.90239857089135, 40.139045638422814, 40.29901950590072, 39.4279787617345, 38.8850756614439, 38.4794633619247, 38.5260062063894, 38.85211598488593, 39.49964830952306, 39.05898963251422, 41.779784848613126, 39.36815477186634, 39.75177826419954, 39.12734477750717, 37.829730587620894, 38.05342335854807, 39.155911399472146, 37.993591523939564, 38.25839857901297, 37.35430794377481, 45.423733418987645, 47.71164017338907, 50.902762874480224, 50.50316749080535, 46.622119488254675, 49.234084621552505, 48.50553574100618, 52.2966084941741, 53.402218741755334, 55.43936052630025, 53.59216343971991, 51.89107464205835, 51.47243222882671, 56.98631978804066, 57.14901970278833, 48.13409905279837, 39.09309856353268, 40.50483411358249, 45.51669751444171, 51.24123988613006, 53.967546032321074, 56.56761461688627, 56.995462832912324, 54.44704401877619, 47.70945541320309, 26.643509364897206, 11.690543889999391, 8.76388797836919, 15.184702046455877, 10.281670689582825, 4.914022328392153, 0.40019008240872816, 0.06566611509169303, 1.2460208035284475, 17.011576352580903, 50.847355473426084, 41.21956448401175, 31.39545886747299, 49.429289217918154, 62.74648512563398, 58.6841098723873, 21.255284740078835, 2.05277843581092, 0.033247423012770956, 0.05265473988988707, 0.03189703216776252, 0.043906050268560655, 0.03277201949047946, 0.05134579440158221, 0.024418267346317732, 0.046340884535663554, 0.05082736355102351, 0.11294635748791118, 0.015672914995511454, 0.05372828571125866, 0.06588559928199937, 0.033954005057532946, 0.021703891426084504, 0.0335962305055751, 0.029161349427135243, 0.14367989745111237, 0.13799603067098126, 0.19128866133189973, 0.1011643925261113, 0.15365702821122063, 0.08601580055490618, 0.3931731766750736, 0.12467723970692005, 0.21577338297520915, 0.1337483336007403, 0.2076128611881887, 0.13569902328233566, 0.15377963292262248, 0.1086591762460528, 0.0737564632248494, 0.1735543081116292, 0.1403241105858357, 0.22368016111994946, 0.1739484603486715, 3.4111166769458405, 28.53267385113624, 65.74759252609746, 62.678781094089636, 47.5200794589135, 36.414123658211004, 45.421415298215805, 49.99425172805787, 38.90191047422348, 5.084303204090365, 0.43420257827927994, 0.28605833409294007, 3.8249610508641894, 18.33049293487303, 15.270976539581055, 8.993423119668039, 16.187028442659688, 22.72480464750721, 39.63638605610017, 55.04536628723145, 55.42301600979221, 50.13804581857497, 46.98631155875422, 44.18009104267244, 41.63597114624516, 41.31095570902671, 47.12575181838005, 54.96154915901923, 52.652136048962994, 50.29215574264527, 52.604549854032456, 51.862362892396995, 45.885125744727354, 43.31470243392452, 37.202849541941, 39.10423025008171, 38.0961654263158, 41.80735126618416, 42.17776029340683, 43.86126902795608, 43.089436792558246, 41.91312974499118, 38.77689669209142, 36.018368274934836, 40.054734291568884, 36.8989796023215, 39.746859612003455, 40.48386512264129, 41.591126688065074, 44.475967191880756, 44.09320662098546, 47.17720547030049, 45.741410101613695, 45.466322514318655, 39.93992651662519, 39.877239196531235, 40.649730390118016, 41.329371236985736, 41.42493194149387, 41.27513662461312, 40.446367263793945, 37.35704575815509, 38.53584743315174, 40.05798201407156, 41.07862980135026, 46.4767486049283, 50.563246434734715, 55.135518043271965, 55.40331394441667, 42.777467158532914, 50.712076848553075, 57.717194634099165, 52.41661340959611, 50.9359343590275, 49.61921430403187, 47.15829180132958, 45.97779958478866, 44.257044023083104, 43.12305150493499, 42.1396505448126, 40.88127574613018, 41.841275845804525, 40.75447728556972, 39.94971283020512, 41.73758014555901, 41.98925510529549, 40.32094555516397, 44.56406362595097, 40.75569714269331, 43.01118942999071, 41.031165199895064, 40.52798001996933, 40.105438770786414, 41.99422867067399, 39.39572903417772, 39.88254224100421, 40.39820448044808, 49.267048220480646, 50.09200503749233, 54.9515784940412, 54.67941699489471, 45.76600728496429, 49.19772817242531, 50.269221644247736, 53.398649384898526, 54.16303303933913, 59.444775119904556, 54.600369468812026, 53.42267390220396, 53.074104632100756, 60.096720110985544, 60.90762307566982, 51.74148721079673, 42.64026657227547, 42.84526924933157, 49.15031848415252, 53.33879401606899, 56.93738037540067, 58.867523824014974, 61.82213937082599, 58.09702127210556, 49.97338864111131, 25.752470416407434, 11.90222244108877, 8.28727489517581, 15.055316782766774, 17.693325473416238, 8.976751085250608, 1.457324032821963, 0.17139620778541412, 2.1464405905815864, 20.1337633978936, 59.015758037567146, 53.22538652727681, 38.70030456973661, 54.208528610967825, 69.93311451327416, 66.46155018960276, 26.81226149682076, 2.5949528332679503, 0.1196799562462876, 0.1192010593630614, 0.1174106352752255, 0.22780359872887213, 0.09244494065041504, 0.1720883988685185, 0.12312991063921683, 0.14236654695724288, 0.3235965198086154, 0.2616698943799542, 0.20252196178320916, 0.22201870027328693, 0.13678055557031787, 0.10783317258521434, 0.09200583437397596, 0.08587436540232551, 0.12095146301773288], [0.04631662636154121, 0.04599784568492924, 0.01063497141829782, 0.018791173427035252, 0.011429140295442796, 0.051466801819661935, 0.0446882949871642, 0.036382626351569934, 0.06176105084558649, 0.02326741176206739, 0.06525376826644906, 0.004046485034538613, 0.032914002395925984, 0.04020949983368478, 0.052161463536322124, 0.041511742052652185, 0.03452580542333665, 0.07407671095983637, 0.07835592488728224, 0.7879401839548542, 7.838095359263882, 47.093906094951016, 48.416039020784446, 38.89210454879269, 21.042437322678108, 28.83603192144825, 44.37719014383132, 35.99639907959969, 7.234610761365584, 0.2608813754012508, 0.16407476678009958, 2.1834613911567198, 2.5667978150229303, 4.548657469211086, 0.5988390407254619, 4.254613066873243, 12.884522195785278, 30.390488793773038, 49.35894150887766, 51.809022580423665, 51.60958182427191, 47.19493066110919, 39.518801243074485, 39.54250804839596, 36.304944484464585, 41.26603672581334, 51.061289387364546, 50.39055624315816, 45.37178554842549, 50.54479952781431, 47.219257200917895, 44.398578828380955, 41.07655094515893, 36.01442237054148, 34.883167666773645, 35.009962204963934, 34.47085203662996, 35.47179383616294, 35.96732254951231, 36.400320837574625, 35.09253201946136, 37.23064345698203, 35.825117018914995, 36.28478742414905, 35.94637317042197, 36.958827126410704, 37.09269369802168, 38.13858978209957, 38.89311259792697, 42.35878552159956, 41.40055441087292, 42.84254320206181, 42.493624841013265, 42.0110595610834, 37.92358898347424, 37.318308430333296, 36.145131434163744, 39.126301427041334, 36.85655524653774, 34.467663149679865, 37.35859117200298, 37.2888514303392, 37.125763200944476, 37.05351706474058, 41.27582696176345, 47.65888821694159, 48.34718573477961, 53.50363162256057, 42.08369008956417, 43.57817196076916, 52.513786208245065, 46.034666107546904, 46.60513954777872, 41.95879397853729, 42.454718851274066, 38.196648705390196, 39.692930944504276, 37.563197689671675, 37.70408922626127, 36.698303299565474, 39.16586245259931, 36.32033194265058, 35.67571393905148, 36.16963840300037, 38.03900864816482, 37.14553194661295, 39.71903431800104, 39.19869661331177, 37.96939834471672, 38.13673450100807, 37.52640585745535, 37.463377291156405, 36.0526184112795, 34.71024213298675, 35.94389423247307, 39.25575925457863, 44.60293431435862, 48.269314919748616, 50.949137057027514, 46.29300909657633, 52.72880661872126, 50.26675839577952, 51.45588767143988, 51.09279778695876, 52.1521201441365, 52.981222906420314, 51.026368525720414, 50.65339426840506, 53.96605160928542, 49.90267222927463, 56.94522903811548, 51.2040715063772, 44.58639367934197, 36.65249001595282, 40.33959642533333, 41.97493845416654, 49.5750327264109, 52.371372792028616, 56.03811425547446, 55.34685927052652, 45.75969619135703, 21.122967504685928, 11.395503205637779, 6.830269800078485, 13.658665687807146, 7.843178751007204, 2.919025185608095, 0.13122745999886146, 0.016639590593836, 0.9433034891563078, 17.20922850793408, 45.57910634625343, 43.94359957787299, 34.66946909504552, 35.75598524462792, 53.82396374979327, 53.35805677598523, 13.093775741515621, 1.3168882266167672, 0.02326282481062076, 0.051344323512767596, 0.03740623856203691, 0.037102285517199386, 0.027564195916056636, 0.04747612341757744, 0.04548037244427589, 0.05944636214764849, 0.12822540657174203, 0.04743883791830271, 0.0188981001490667, 0.020224389867977272, 0.060025436518293236, 0.048518228990536545, 0.08751160254882229, 0.0301388010097247, 0.026128635246066317, 0.05647138609821278, 0.016490463918495565, 0.04146131431503643, 0.010107794716473549, 0.003193091336382373, 0.0204802364216096, 0.025153043341913053, 0.02170936512430349, 0.008887348662791474, 0.02793636142967209, 0.07033757369724974, 0.03831358543867546, 0.03754024266175205, 0.049010551564635775, 0.03623663680627942, 0.08058213809084508, 0.046673592690738945, 0.04117120447899065, 0.039408945613690925, 1.2274064604313144, 12.649809525858972, 55.99944753031577, 56.501958062571866, 44.14895526824459, 26.38027321907782, 36.821532403269124, 47.63651109510853, 37.97591732394311, 7.917065908831935, 0.3224807280686594, 0.038104527705018564, 3.3894955919634913, 4.294254991316027, 4.833436742905648, 5.378968811804249, 8.632897484687067, 14.090336253566129, 33.58845995318505, 51.066141359267704, 52.12114518688571, 50.649871979990316, 49.10711749907463, 41.04938853171564, 40.57404041290283, 37.624982864626, 43.63228497966644, 53.30569705655498, 52.44093210466447, 48.69063238943777, 51.478437377560525, 50.0483412127341, 46.37982683797037, 44.22401374386203, 38.18237912270331, 35.316318927272675, 36.59079505551246, 38.20227730658747, 37.19696598668253, 38.58984670331402, 37.89295135005828, 36.74529329422982, 38.102907980642016, 38.781607458668375, 39.003586153830256, 36.730200013806744, 37.76277965114963, 37.930653172154585, 40.2585720246838, 42.07748882232174, 43.639584510557114, 45.21031725791193, 46.43519501532278, 44.179561522699174, 42.78747312484249, 39.12215940413937, 37.84693410319667, 38.381207989108184, 39.40190676719912, 38.84993906944029, 37.78330933663153, 37.736484081514426, 37.448864521518836, 39.53977807875603, 39.14720373768961, 42.99214632280412, 50.562426659368704, 49.791767212652395, 55.29419752859301, 43.14214560293382, 45.66872073758034, 54.81071833641299, 49.55190250950475, 48.064453448018725, 44.39866512052475, 43.3833517566804, 39.83821945805704, 42.33159172919489, 39.34849585256269, 40.6315972728114, 39.732672399090184, 41.016150366875436, 38.20172425239317, 37.7654194062756, 37.16266093715545, 39.954341227008456, 39.67313081987443, 40.514918527295514, 41.662851149036044, 39.75679497564993, 39.229953981214955, 38.98298586568525, 39.723490130516794, 37.329989248706454, 37.858183460850874, 36.94776604252477, 40.7996198438829, 47.036572810142275, 50.85739674106721, 53.48410998621295, 47.63863701974192, 51.40563818716234, 50.085611574111454, 53.802759416641734, 53.941925110355506, 54.121275486484656, 55.00352636460335, 52.874891373419, 52.562137265359205, 53.169273099591656, 52.427658804001354, 58.477051873360914, 54.52947262794741, 44.64879074404317, 39.71396661573841, 43.200832105452015, 45.293102802768836, 53.61732152200515, 56.06934416678644, 58.12921608647993, 58.67402153630411, 46.284489708562056, 24.154434050283125, 10.234599305737405, 8.833406106118234, 12.809504905054647, 5.366939392782027, 3.941349050691051, 0.0687368176577072, 0.10245017917646516, 1.2510278316274768, 19.315025498790128, 51.68702117858395, 49.736803039427734, 34.6538306051685, 40.88801045571604, 60.92261437446841, 60.698988283834154, 18.054360035927065, 1.918542671107477, 0.013055013485192774, 0.017983322219562628, 0.05540374298429778, 0.03883454054894467, 0.06792153922780868, 0.038541282091530106, 0.026479664393850876, 0.05145511897881666, 0.035412134677772565, 0.05794822358556333, 0.007108255972965591, 0.0559522619380826, 0.025236692482365236, 0.011009173768181956, 0.044814726307747826, 0.030818554655378385, 0.004354460998588512, 0.13485162278577206, 0.0678521010183519, 0.15427604257579774, 0.09258695802981816, 0.11702952185465444, 0.17584399169971868, 0.15031757434048962, 0.09953418040588018, 0.11231333903607824, 0.16609386811333318, 0.1060886448249221, 0.13616721025638043, 0.168765431209918, 0.1530170383592767, 0.2534900058902079, 0.11888033665356137, 0.09696307441880626, 0.18187541724933734, 0.19319300269407613, 1.3051817902634222, 14.95605238022343, 63.127410027288626, 62.9515270263918, 51.60875028179538, 33.38461829769996, 38.744654809274984, 55.2904712769293, 44.43352714661629, 10.130451552329525, 0.6419932637964526, 0.2912630741634677, 4.763343007333817, 7.862778344461995, 11.182118423523443, 6.94519377523853, 10.694514859107233, 16.650955600123254, 34.22346422749181, 52.06905218862718, 54.65609065947994, 55.624441485251154, 52.782370505794404, 44.51325324273879, 44.36130454463344, 41.56987136410129, 45.57780804172639, 56.13320819793209, 55.933794898371545, 50.99608782799014, 52.76429622404037, 52.737741777973795, 47.62379869338005, 46.869185663038685, 39.212974040739, 38.098024629777484, 38.525504143007346, 40.043630061611054, 39.3626909102163, 39.49073276212139, 39.988359943512954, 38.83486932323825, 40.19733205918343, 41.06356789988857, 39.75356686499811, 38.27958330031365, 39.12206918962541, 39.26095247268677, 41.73322239229756, 43.41071813337265, 46.582656521951, 45.47153142190749, 47.96675897413685, 46.720174820192405, 46.401784266194994, 41.44125684615105, 40.75945869568856, 40.010521334986535, 42.69239487186555, 41.4633241007405, 39.06164507712088, 41.85471388601488, 40.29392434704689, 40.636802258030066, 42.231783097790135, 44.746010611134196, 52.49006763581307, 54.63637682699389, 57.613612682588645, 46.7451250168585, 50.445045809591974, 55.64723437832248, 52.283323426400464, 50.43742072197699, 47.31213500422817, 44.824830639746885, 42.372160803887155, 43.4252191358997, 41.341444292376124, 42.05638254842451, 42.62994681635211, 43.32786983059299, 40.86777887036724, 39.31029196708433, 39.803075021313084, 41.3562669292573, 41.26317339558756, 41.992138047372144, 42.92374803173927, 42.16689532802951, 42.20331845744964, 42.284464451574514, 41.72420486327141, 39.05574583238171, 38.251365769294004, 37.61592218952794, 42.90383023600425, 49.905727755638864, 51.134924042609434, 56.45865117349933, 51.74562923369869, 54.031225712068625, 52.06076422045308, 56.29162880682177, 56.40111392544162, 56.582005793048495, 58.597103857224994, 54.71520470034692, 55.425228226569395, 55.72428934035763, 52.47031850199546, 61.640490485775864, 58.22699685250559, 49.07248689282326, 42.452353662060155, 44.258663961964274, 48.26355295796549, 55.85306075311477, 57.74951888668922, 60.83645559126332, 59.16195654099988, 48.295241786587624, 23.89096844580866, 16.55079395540299, 12.434019350236463, 22.956432373292987, 14.04413269412133, 5.7735685667684, 0.6676181081321932, 0.341389402146301, 1.7166434468761569, 23.841772117922385, 57.42532322483679, 58.26964870575936, 46.19091764573128, 48.56211200837166, 67.56422258192494, 68.70961743016397, 24.42648180069462, 2.6335700385032164, 0.1555900519052821, 0.11473113550774514, 0.13874647507984794, 0.11579872499550543, 0.17782989078231398, 0.15482126735150814, 0.10763355305478459, 0.21594065061259657, 0.23449039717595424, 0.1472870990513794, 0.1561316760677484, 0.14605637880102282, 0.12076641447962293, 0.1696760952472687, 0.22676151996899038, 0.08752278743251678, 0.22995570824751932], [0.08729153613169348, 0.05935165452800932, 0.0741246450812586, 0.014709088286655325, 0.004675102311246578, 0.07335340138524771, 0.08246809334283875, 0.021188530672882355, 0.027696529944096843, 0.0831566072039066, 0.04770029223554077, 0.04170930463700526, 0.0278593695932819, 0.05983610554868656, 0.01611868336406206, 0.022397580211080854, 0.033037683460861444, 0.04017565406919007, 0.00670664108193089, 0.3777596408561353, 5.525176140569872, 37.28619598573254, 50.44315130479875, 37.52591556118381, 25.799397653149022, 34.42132034609395, 40.618814268419825, 38.01154813458843, 10.853071770360394, 0.26769857733480396, 0.12996782759024253, 0.9810353418992412, 3.7068437760876076, 3.9330779977383155, 2.4594707354422543, 4.600642602289877, 7.418669452590327, 22.547884179699807, 39.31931341848066, 54.97565792452905, 47.509340009381695, 47.848377919966175, 41.8687520488616, 40.16985585612636, 35.69211336874193, 41.63410802041331, 46.93902346395677, 52.60869187693442, 49.01539679496519, 48.46227984274588, 50.09593917477516, 46.535905791867165, 43.471730601403024, 40.83936522083898, 35.91907347402265, 35.52795433229016, 34.415334809211, 36.83872807410456, 35.78342222398327, 37.37043672992338, 34.518826546207556, 37.36617703591624, 35.908377170562744, 38.761713197154386, 36.35446440789008, 37.026017327462476, 36.19776179713588, 38.3883467028218, 37.91662677641838, 39.683089717741936, 42.2626325391954, 44.307101311222205, 44.69565914523217, 42.191935739209576, 37.71476199550014, 36.94532632827759, 37.167112827301025, 36.29592303306826, 37.23753506137479, 37.14811286618633, 35.436441513799856, 37.715628839308216, 36.85443324427451, 41.821091328897786, 41.17042503049297, 47.847146295732074, 48.88918668993058, 51.82564166284377, 45.460972401403616, 41.4243318188575, 53.635693903892275, 46.858293241070164, 48.56379862754576, 41.10050485980126, 39.02665361281365, 36.77376185694049, 36.616188480008034, 37.15474559414772, 38.19915902230048, 38.01595295629194, 37.310785324342795, 38.12015856465986, 36.541949779756614, 38.51510593968053, 37.40911129982241, 37.513834661053075, 37.828412671242994, 39.845346404660134, 40.398835982045824, 39.451340398480816, 38.84780922243672, 38.81055847291024, 38.169980510588616, 36.349902691379675, 36.91317465997512, 36.195671173834036, 46.57272900304487, 49.234547461232836, 52.293909903495546, 49.40053824455508, 52.46913786857359, 52.000069464406664, 50.04606623803416, 45.536372123226045, 46.690882559745546, 50.64098781155002, 48.99238424916422, 50.069584769587365, 55.40953090113979, 52.8332083455978, 50.978335180590236, 54.048217419655096, 48.80229834587344, 41.01653083678215, 39.75628506752753, 40.5443912167703, 46.14587314667241, 53.163954365638, 53.497932418700195, 55.4807532987287, 41.76196159855012, 18.104313381256596, 3.6859463684020506, 9.997322386310948, 18.21775224901015, 6.197826343197977, 3.77990625558361, 0.3266594925474736, 0.09378460626448355, 1.603806172647784, 19.174716434171124, 40.060923791700795, 29.06992089363837, 40.52412040771977, 40.59411510344475, 55.33060496853244, 46.6280658014359, 14.240518904501393, 1.1126860807980261, 0.11148829298514513, 0.012316169562719524, 0.04518912496766256, 0.0641772193804143, 0.01100858771091988, 0.033361401574145404, 0.03624448537706368, 0.058888144520742286, 0.03623606990121546, 0.043056485573610956, 0.04772247814182793, 0.08921445512603368, 0.036271811733322765, 0.03935190653728862, 0.030720746294865688, 0.03851609695101938, 0.039063501246874376, 0.02439895618496643, 0.036484125340657855, 0.01913953275840369, 0.07284217559161686, 0.04070082266304282, 0.06149020045995713, 0.029826830854759585, 0.05073899147851814, 0.02519277840732567, 0.047428511053083405, 0.029658295341857502, 0.0689863401555246, 0.01411724610314254, 0.09133838793082584, 0.025574389785047502, 0.04819286761865501, 0.01863064544816171, 0.020669711032702077, 0.04274939539872351, 0.2703117645315586, 7.756530652123113, 44.91208768660023, 55.36551014069588, 42.91492662122173, 26.460207200819447, 33.10056417219101, 47.815732033021995, 43.754054961665986, 11.811508805521074, 0.31318869441747665, 0.16073615560608526, 2.0324844602615606, 1.8220175538332233, 6.331096714542759, 5.544907623721707, 7.890538919356562, 10.61479268535491, 26.886229553530296, 45.26509315736833, 56.208419645986254, 49.89441171769173, 49.96351995775777, 44.10180445640318, 41.2231416856089, 38.25114219419418, 44.044514317666334, 49.68177610828031, 53.54953119831701, 49.908218460698286, 50.04015522618448, 51.22336172288465, 48.17636651377524, 45.483667235220636, 42.59599085777037, 37.58363716063961, 37.00573475130143, 37.79937536485734, 37.77078520867133, 38.3057023632911, 39.40266770701255, 36.83434286425191, 39.81625418509207, 38.496608041947894, 39.47198775506789, 38.55842459586359, 37.42179624495968, 38.79087209701538, 38.253185749053955, 41.25979623486919, 41.87816965964533, 43.7899132697813, 45.45866997011247, 48.01475309556531, 44.9521311636894, 39.877874620499156, 38.941918649981105, 38.37717579257104, 37.59993853107576, 38.09129384256179, 39.54575969326881, 36.286650549980905, 39.350774749632805, 39.72680845568257, 41.989196269742905, 42.50079885605843, 49.80873146364766, 50.50724283341439, 53.23785181968443, 47.734915517991595, 44.65792986654466, 56.82321586916524, 48.93130117847074, 49.8403928356786, 43.773184360996375, 41.432223627644206, 39.789487931036184, 38.86722495478969, 39.198861352859005, 38.96472723253312, 38.964723310162945, 40.113460017788796, 38.763603779577444, 37.556749313108384, 37.96958661848499, 39.333210376001176, 39.33785838465537, 39.57318490551364, 40.90419807741719, 41.12530600640082, 40.23257847755186, 40.51001556458012, 39.53051736277919, 40.14538811099145, 36.94569895344396, 39.016831997902166, 39.06496732465683, 47.83847001291091, 51.50085764546549, 53.70476292025659, 51.04117155075074, 53.33565611993113, 54.44975437656526, 51.95031812114101, 49.39674923496862, 50.65129580036287, 53.12670753848169, 51.49156555052727, 51.46335978661814, 55.91565785869476, 52.05748119661885, 52.088707185560665, 55.34208574602681, 49.80810388442009, 43.372639763739805, 41.66514181321667, 43.18802164446923, 48.417392238493896, 55.59926379111506, 56.15233759726248, 59.47398501057779, 40.81800007051037, 24.040016551171583, 8.385771493757925, 11.058031301344595, 17.818419664136826, 3.995392937814036, 4.355644497179217, 0.42839710270204856, 0.07710063619719398, 1.5085918624554913, 22.28205534719652, 46.37328824689312, 39.825126586421845, 43.905152505443944, 44.46607889667634, 60.366739996017955, 55.616467306690836, 17.77343007826036, 1.592557550437989, 0.06673335217900815, 0.09793377676678282, 0.10213950754053171, 0.045622489415109165, 0.012504688479126462, 0.055868348497296536, 0.034703055186377424, 0.0393248061769672, 0.11794666699584454, 0.08879267775844182, 0.038263946771621704, 0.10519845831778743, 0.026281628750204563, 0.030354586910576593, 0.049289679530286984, 0.03861891361133706, 0.02221268489055576, 0.17389411407132305, 0.1764368977878363, 0.1444733806795651, 0.08124521017194757, 0.1080934432966094, 0.19522491301740372, 0.19619537787812372, 0.13837996329511368, 0.13846273143445292, 0.4266440177396421, 0.11693115616517684, 0.2753330418659795, 0.10580424234391221, 0.11267779770517543, 0.13417521311390784, 0.21471861779930132, 0.13594001922155582, 0.11052221780823124, 0.15186646622755837, 0.6006934637984922, 11.831210870896617, 50.5565195698892, 62.20370754118889, 50.282412575137236, 36.61203861236572, 42.796898580366566, 52.08545946305799, 48.1701103333504, 15.156722799424204, 0.3448181665472446, 0.4151951707899571, 3.563554935878323, 9.207005981476076, 11.94966252773039, 10.551432678776404, 10.764183998107912, 11.476139291640251, 25.615848379750407, 44.5320531629747, 62.02421595973354, 52.23109706755608, 52.378754692692915, 45.998619525663315, 44.215886592865, 39.314528126870435, 46.495364173766106, 52.94230907194076, 56.28643166634345, 47.43004537397816, 49.868661357510476, 55.24891768732379, 50.45550284847137, 46.521251816903394, 45.08011810241207, 39.86888847043438, 38.91853347901375, 39.881240014107, 41.024873718138664, 39.77189610081334, 42.27839654491794, 38.373218121067175, 40.941523351976954, 39.68275631627729, 41.96373224258423, 39.69445282413114, 39.2460435436618, 39.29882687907065, 42.043034722728116, 42.6541478403153, 43.429710249747004, 46.89756008886522, 47.745113680439616, 48.55781701303298, 47.25426435470582, 42.102850867855935, 40.25703837794643, 41.159156060987904, 38.859764606721946, 40.35404643704815, 41.32954382127331, 38.89161817489132, 41.79637647444203, 42.13285699967415, 46.03545450395154, 43.94622756588844, 52.54980141116727, 53.70093860933858, 55.41600673429428, 51.01385616487073, 48.157460689544685, 59.05534651971633, 51.31123458185504, 53.3205000815853, 46.47364208775182, 42.209715843200684, 41.65970933052802, 40.535895362977065, 42.381641172593646, 40.15064016465218, 40.657751637120406, 41.77530157950617, 41.31354839571061, 39.03135653465025, 41.70826827326129, 40.434831573117165, 40.981582518546816, 41.65365711335213, 44.67853015468967, 43.178792307453776, 42.5848787830722, 42.4446540494119, 41.79196773036834, 42.06065793191233, 40.12437989634853, 40.35534474157518, 40.58199105724212, 52.03298991726291, 54.11322286052089, 55.80472146311114, 53.37602907611478, 55.5749450960467, 54.30979636407668, 55.23704075044202, 50.73294778023997, 51.11819121145433, 55.58031089844243, 54.69191758863388, 53.66153840095767, 59.22430261488884, 54.01516360621299, 53.01024452332528, 56.77006383096018, 53.13888649786673, 46.567010187333636, 43.866693665904386, 45.62675137673655, 50.03216928051364, 57.72561596285913, 60.310708938106416, 61.83561663473807, 46.046378304881436, 20.85951562850706, 7.63885562458346, 15.553491134797374, 26.552188742545347, 11.64718601011461, 8.015555643266248, 1.5123009537496876, 0.2749445740013354, 2.3957145694763433, 25.045690690317464, 52.65567010448825, 42.75777293789772, 54.05061006546021, 53.355240514201505, 70.29244284476005, 64.02573477837348, 21.10830176261164, 2.0556478947401047, 0.36135377602711805, 0.17076620772000284, 0.16749115120018684, 0.11603959069977846, 0.12929393068676995, 0.11072186032129873, 0.1093819955243699, 0.09192389360959492, 0.2205834958341814, 0.18145771546950265, 0.19796035252511504, 0.23320462584735888, 0.22949813925210508, 0.10016449456734043, 0.07864821807391222, 0.15727970478755815, 0.15293897399979253], [0.03319634026997993, 0.057581995253361044, 0.09826218333816338, 0.08585886744361731, 0.05329382575808033, 0.06638535673940374, 0.05668667212669408, 0.06582305586386113, 0.07264955810481503, 0.08387191882056576, 0.07281543912305947, 0.03961399670750384, 0.05938903961871421, 0.00999733632911117, 0.009294985962520924, 0.13580581593898036, 0.0633363880878014, 0.02598670788199431, 0.1084099218790089, 0.21091157450310646, 5.893020427996113, 32.04645464497228, 54.89655548526395, 45.29247522354127, 36.551861609182055, 44.69902453884002, 35.5962545641007, 38.28760062494586, 20.418347043375817, 1.0291240292210733, 0.10513036076219813, 1.295882831177404, 1.3198002187475082, 3.0975425483718997, 5.681102122029951, 9.432944309326912, 9.95226808132664, 18.72810163805562, 32.862382165847286, 50.955197118943744, 51.03546842452019, 48.4469747543335, 44.48483567084036, 38.66326170582926, 38.04555116161224, 41.48206126305365, 45.91693616682484, 48.55687564419162, 49.072118190027055, 44.4439253499431, 46.879881966498594, 50.12465092443651, 47.24695305670462, 41.76295003583355, 36.45767373423423, 34.29721655384187, 34.18415423362486, 34.18503284454346, 35.208065432886926, 36.52641327150407, 36.04579740954984, 34.525855433556345, 34.420029886307255, 36.71150599756549, 35.6062291514489, 39.05863661919871, 38.914077666498, 40.476122363921135, 41.1677578187758, 40.011231283987726, 41.27815292727563, 43.00575302493188, 43.371655248826556, 43.15972174367597, 40.02366519743397, 37.190305802129934, 35.52695020552605, 37.440078412332845, 36.390538446364864, 35.7650419973558, 36.12911247438, 36.97832522853729, 36.956916932136785, 40.14292094015306, 42.593017701179754, 46.77529196585379, 48.84348323268276, 52.961807174067346, 46.990167248633604, 38.56837172662058, 55.56886149990944, 48.37927464515933, 50.211602026416415, 46.08554317105202, 44.631183224339644, 39.0659204606087, 37.70381858271938, 36.261370874220326, 37.191710010651626, 35.07714848364554, 36.93629703214092, 39.785169401476466, 37.36305875162925, 35.558995969833866, 37.36451787333335, 37.88131760012719, 39.03105451214699, 41.63133098233131, 43.31058394524359, 40.04507741620464, 39.31239435749669, 38.200928011248195, 37.16410436937886, 36.82597644867436, 36.387039692171165, 34.660706520080566, 40.935247559701246, 48.826052219636985, 52.59676787161058, 51.276584363752804, 50.57873195217502, 48.94338207860147, 46.696464092500754, 47.52819092042985, 44.020179933117284, 45.280951299975, 45.093144293754335, 47.85933309985746, 50.44493990559732, 55.65760904742826, 49.692927406680205, 52.870419871422556, 52.496386574160674, 46.029013972128595, 37.39112331021217, 42.60799723286783, 41.00852920163063, 49.44660255985875, 53.2710389937124, 60.19732498353528, 40.39089710481706, 23.653390484471476, 7.515154365570315, 9.576963936128925, 9.366292453581288, 1.524324366642583, 3.058299234797878, 0.21167240706422638, 0.24515181299178834, 1.621607236804501, 20.731654205629905, 48.95454514411188, 34.96069331322947, 31.652844798180368, 45.55927092029203, 52.736996527641054, 48.14824704200991, 14.968753995433932, 1.0807983144637079, 0.1258026688329635, 0.12619030932264944, 0.042812214608514504, 0.008364135508365449, 0.024728153742128806, 0.06911754037343687, 0.025867479703118725, 0.031734000996596394, 0.06865642439093321, 0.0494437244901013, 0.061035354907113704, 0.013764468359670812, 0.026639196458422852, 0.021833498181114276, 0.01785044235387637, 0.057023452039087014, 0.01848669944240922, 0.04127806991398816, 0.05303357419888339, 0.012046511401422324, 0.12825130034358273, 0.1089665460430326, 0.08345302960444843, 0.04344314930119342, 0.017551338645599542, 0.025860581081360582, 0.019978429679007783, 0.05610289397619425, 0.004686034864731013, 0.016370174707844853, 0.06029726366602606, 0.032986125743557373, 0.07462401949470082, 0.06380000151693821, 0.04745879067829059, 0.0771084426331424, 0.341007154915602, 7.923591261909855, 38.65692707800096, 60.3411739872348, 49.87114814019973, 37.91151985045403, 45.33854346121512, 41.71045695581744, 46.01463456307688, 21.07498711155307, 1.2244253365262863, 0.14351442245946777, 0.6619203138735987, 3.0259874847627457, 6.915541637328364, 5.426550594068343, 6.324249236814438, 11.891675187695412, 20.280487498929425, 33.98234044351886, 51.910749250842684, 52.748877386893, 50.658195249495975, 47.44947679581181, 41.49305958901682, 38.557887231149984, 43.400347386637044, 48.32717380216045, 51.95251072606733, 50.578669194252264, 44.85169887542725, 48.78909172550325, 52.502878096795854, 48.950528637055434, 44.57995314751902, 38.20769802216561, 36.232310033613636, 35.973017831002515, 35.6212479068387, 38.527539853126775, 37.76915350267964, 36.79503679275513, 36.92286291430074, 37.153172723708614, 38.27934403573313, 37.18778371810913, 40.240203565166844, 40.88536285584973, 42.68155344070927, 43.988118479328776, 43.216054824090776, 44.1274606797003, 45.081075160734116, 46.160370226829286, 45.19705180198916, 43.86210841517295, 38.05955794549758, 37.35474724923411, 38.972583739988266, 39.57965289392779, 37.19749942902596, 37.771275504942864, 38.38558143185031, 38.75273096945978, 42.47239697364069, 44.51347681783861, 48.69527647572179, 50.55336206190048, 53.77784059893701, 49.27257091768327, 40.15306811178885, 55.3726488544095, 52.503270333813084, 50.9775036381137, 48.80689144134522, 44.76458303390011, 40.78806846372543, 39.977020371344786, 38.646991714354485, 39.40732748277726, 38.20432870618759, 38.029673407154704, 41.27909821848716, 38.42855491945821, 37.734809229450846, 38.72836520594936, 40.258222933738466, 41.07942996486541, 43.67434063265401, 44.18415461817096, 42.54192882968534, 41.31581944804038, 39.54382204240368, 38.83049195812595, 38.32400022014495, 38.098899318325905, 37.55522743348153, 42.85021535811886, 51.69526992305633, 53.35596223031321, 54.740429462925086, 52.845959971027995, 51.33332144829535, 49.426312138957364, 48.26987974105343, 46.417987577376834, 47.16401846178117, 48.01370974509947, 50.43480057870188, 52.004329158413796, 56.81386493867444, 49.64433316261538, 54.430099379631784, 55.12896376271402, 47.45917681724795, 40.458471698145715, 43.376993594631074, 44.274278917620265, 52.37426750121578, 55.91024106548679, 62.36313227684268, 42.90390868340769, 24.140158584040982, 10.997917056083681, 12.727530310230872, 13.63193375449027, 3.9458887038692354, 2.936256402923215, 0.322384292920751, 0.05340418072357293, 2.0361402318362267, 25.32139212854447, 48.580456933667584, 39.64195189937469, 40.91525523893295, 50.70940571446573, 60.207362328806234, 56.853476955044655, 18.47279260235448, 1.5425036943727926, 0.1392149838108209, 0.10412636423303236, 0.024202805117613847, 0.05316306987116414, 0.021256247099729318, 0.07161088843619631, 0.010319845938694575, 0.017258920969681877, 0.031024710831022075, 0.03680503574169932, 0.09435810734547916, 0.02255102570709442, 0.016448269710846005, 0.039036128925339836, 0.051726563082587336, 0.0868492429294894, 0.009089958808955648, 0.17441270963078545, 0.12476894809233567, 0.18792443217769747, 0.2164977497511333, 0.23935387571973188, 0.16425683523618406, 0.15965776427859263, 0.1644218352533156, 0.15019011263164783, 0.1676717640892152, 0.18370690364991465, 0.11167594622219763, 0.19487923882420988, 0.16020518006576648, 0.10080430055818251, 0.33814894215714547, 0.18640007042596418, 0.1456048465784519, 0.27236981377486263, 0.3978369360969913, 9.332130570565502, 43.51523753135435, 68.13004801350256, 57.77897588668331, 49.02244137179468, 57.15669185884538, 48.647168605558335, 50.321581363677986, 27.298998217428885, 1.5458586691848695, 0.5109135055493924, 2.7743171828408397, 5.925928623445573, 9.690267482111532, 13.030779534770598, 18.518284251613004, 14.169490664236008, 21.15262846792898, 36.193623696604085, 54.10304430992373, 55.975262195833274, 54.45624197683027, 49.46074270432996, 43.59538724345546, 40.669930596505445, 47.03610604809177, 51.46877657982611, 54.41184859122, 51.764311482829434, 45.80137921917824, 51.144086699331964, 55.61481598884829, 52.91633905902986, 47.03367417858493, 40.7905944701164, 37.199574362847116, 37.700064874464466, 36.933935765297186, 39.15117709867416, 40.074134334441155, 38.15556580020536, 38.05258789370137, 38.76255650674143, 38.703752333118075, 38.81727357064524, 43.74195837205456, 42.564882539933734, 44.629539751237445, 47.10742650493499, 46.96267535609584, 46.305317494177054, 47.38189828011298, 48.198861306713475, 47.62174729377993, 47.06574347711379, 41.263306756173414, 38.805020086226925, 41.507031071570616, 40.859055519104004, 37.806055161260794, 39.2002655613807, 40.6870242857164, 40.04916060355402, 45.179714925827525, 46.602899874410326, 49.80577791890791, 54.14018131071522, 55.7344522014741, 52.39759775900072, 42.85397691111411, 57.061456711061545, 54.945153651698945, 53.98789528877505, 51.445207057460664, 48.11626795799502, 44.110865131501235, 41.4664266955468, 40.17922639846802, 41.648761995377086, 39.34680138864825, 40.98055877993184, 43.644236441581484, 41.147008480564246, 38.81271577650501, 39.84863335086454, 42.30167188952046, 43.11834858309838, 47.334249327259684, 46.9788472883163, 46.03834136839836, 44.20313888980497, 41.50365391085225, 40.41455291932629, 41.59426066183275, 39.268781523550714, 39.24653776230351, 45.35366027585922, 51.80004427509924, 56.25776306275399, 55.78973408668272, 54.49143740438647, 55.082181653668805, 52.16445207595826, 51.26473488346223, 49.436796634427964, 50.611934815683675, 49.58556429032357, 52.12684439074609, 55.85137805631084, 58.95334136101508, 50.72490299901655, 55.726434876841886, 58.55111406695459, 49.67161716953401, 42.56890296936036, 46.634706374137636, 45.44823646545411, 54.6889679662643, 60.11997584373721, 65.10406101903608, 44.97253141095562, 26.2219016398153, 17.364528871351673, 18.772243991974864, 18.18362370614083, 6.854459547227429, 6.292969805579032, 0.7562238374544729, 0.32432369046634246, 2.8686945572976144, 28.84985043156532, 61.01945377165272, 47.522334821762584, 43.65196351082095, 60.17702671789355, 67.43642391697054, 64.62031510568434, 23.1747652253797, 2.2495614184487254, 0.25474304994267805, 0.18830948329019934, 0.19488372809944615, 0.08159815453954282, 0.16018659477272343, 0.1187458269358162, 0.09654527304754143, 0.12985404821172838, 0.10177168574544693, 0.1903458828887632, 0.18724379370049124, 0.10118203553100748, 0.12459022744048028, 0.1315440534944496, 0.16782046175531803, 0.19405028572486294, 0.11193863011055416], [0.07875133350852036, 0.015464897226211766, 0.0406793607098441, 0.07241348045006876, 0.011545690997023017, 0.07097024740951677, 0.0344838812616804, 0.017816043090856364, 0.05984630600939836, 0.03209850563096904, 0.08655412287841882, 0.05598457552672875, 0.02146704385297433, 0.025153506825107242, 0.013701525618202023, 0.03594223687785768, 0.02951786951011708, 0.021367624792600834, 0.06193253196655743, 0.07679403248813844, 2.2719262828749995, 27.592130668701667, 53.61763138924876, 47.075529790693714, 32.75038084676189, 31.497707213124922, 34.18948081231887, 41.578073040131606, 24.20903148189668, 2.2457309788273228, 0.1495886723240537, 0.28042532022922273, 1.4717451170567544, 4.907674952860802, 1.6979368055059065, 3.828881459851419, 5.3619898519208355, 16.18175187418538, 22.82581940773995, 45.79283629694293, 49.97292972380116, 50.660140745101444, 47.34728728571246, 41.68800138658093, 39.96438641701975, 45.03244953770792, 46.0068251240638, 53.46669858501804, 48.739763998216205, 45.62136988486014, 50.2343439286755, 49.97091754790276, 47.51900865185646, 43.348587789843165, 36.174439384091286, 35.02560069484096, 35.80372833436535, 35.75089008577409, 36.5515713537893, 34.61300265404486, 35.43823011459843, 34.08843271193966, 35.820406252338046, 36.92178426250335, 40.45666740786645, 43.32434754217825, 45.76046497591081, 44.34994143824424, 39.432552245355424, 38.53248988428424, 37.4934854045991, 40.745651952682, 42.93059649006013, 42.38261784276655, 39.833830325834214, 38.849217353328584, 36.85275446984076, 35.76764645115022, 36.80016333057035, 36.532288982022195, 36.19290198049238, 38.43317939389137, 38.352217751164595, 39.36560130888416, 40.723019876787745, 44.50897785925096, 47.52064035784814, 51.729849538495465, 49.353552172260905, 34.26158182082638, 49.85605093740648, 53.007624380050174, 51.27926726495066, 47.740324466459214, 46.877846256379165, 46.108477269449544, 40.4138586598058, 38.252789589666556, 37.4289624152645, 38.050387444034705, 38.8252987400178, 35.606311521222516, 36.84796133349019, 37.93121407108922, 37.088849775252804, 37.99669411874587, 44.865317344665534, 48.541554866298554, 49.30841353631789, 44.99652454929967, 40.75322604948475, 38.83515173389066, 38.90899427475468, 36.95025674758419, 36.920121177550286, 35.71779704863025, 35.47470815720097, 41.85981296723889, 46.60296655470326, 46.166061585949315, 44.46050520866148, 44.22269974985431, 42.26575866822274, 40.85121077875937, 39.3045300053012, 41.26633874831661, 42.65230432633431, 46.085425499946844, 48.81494014493881, 52.2651824643535, 53.72082894848239, 50.813783907121234, 53.985537944301484, 49.85650593234647, 41.19565763781148, 40.950509502041726, 41.81637663995066, 51.227754777477635, 53.03841890827302, 60.73117917583835, 42.5006615731024, 26.173952625643825, 9.624887454894282, 12.194187987235285, 17.87048128343398, 2.1103101680355687, 3.0528760677383793, 0.2764421839627528, 0.10385413488913929, 2.345821285440076, 22.78874516487122, 46.505040660981216, 45.272475058032626, 31.56100250059559, 40.95267072800667, 51.43305163229666, 42.504729070971095, 12.67880564735782, 0.4029817068048062, 0.11174116328719164, 0.05317322436660048, 0.030722301453351978, 0.04965269412364691, 0.06863695809677725, 0.004243708146180237, 0.05921210395172239, 0.04965860832242235, 0.033368338500299764, 0.016930658039787126, 0.03163369901989016, 0.09837203268562594, 0.046496967289356456, 0.0966450636605582, 0.008292066744498668, 0.03690103804993053, 0.025039758090110078, 0.03458888893346152, 0.03254835246010654, 0.0650920547665127, 0.0284156700851576, 0.009509096046038454, 0.08335266442548844, 0.06976706035915883, 0.03971117879113844, 0.049291154249541225, 0.0034569782221825014, 0.09248414903037971, 0.02093453039114754, 0.007650518861238755, 0.06251043805311765, 0.058294889862619104, 0.05961888514819646, 0.027446000040659023, 0.09181320922629488, 0.03684140193546492, 0.024002067098814635, 3.6665796656762404, 32.88004655991831, 59.23646980716337, 53.58206725889637, 40.261894272219756, 40.06437547745244, 39.678253435319476, 45.33841402299943, 28.062801361083988, 2.261435413552869, 0.2501508890981636, 0.15055123115739516, 0.852454654391735, 5.196682051304848, 6.364162785391654, 6.2301466734178605, 8.406494355970814, 18.539161066855154, 26.304645999785393, 50.47876642596338, 53.82113179852886, 52.547196957372854, 49.13709225193147, 43.717725969129994, 41.95936272221227, 47.32257635362687, 49.431446521512925, 55.22631306802073, 48.498193064043605, 46.78752191605107, 50.93007433799006, 53.37477391765964, 50.00778782752253, 45.31391097653297, 38.00946143365676, 36.84609428528817, 37.153137422377064, 38.030869730057255, 39.24967958081154, 37.61863646968719, 36.382011213610255, 35.98569885376961, 37.70314393504974, 37.821685806397475, 41.41238035694246, 45.34101455442367, 46.65997820515787, 45.835080223698775, 40.33903160402852, 41.701482572863185, 40.68274105748823, 43.435966430171845, 43.61533641815186, 44.49470043182374, 42.257725654109834, 40.31350874131726, 38.72389762632309, 37.13738126139487, 38.14963125413464, 39.377136999560946, 37.04737855542091, 40.215292592202466, 39.27299807148595, 42.565616023155954, 43.14523643062961, 46.81426071351575, 49.77668962171001, 54.15028925864927, 50.679968326322495, 38.152043511790616, 51.865194843661406, 54.3691300576733, 54.325929072595414, 50.34737094756096, 48.855846543465894, 48.96497864877024, 42.80868530273438, 38.96726108366443, 39.56980382242511, 39.29985846242597, 40.45883647857174, 37.73867276407058, 37.91546967721755, 39.22711026284003, 39.199783109849506, 39.810166666584635, 45.88295275165189, 51.042320805211226, 49.09861380054105, 46.407255972585375, 43.33303166973976, 41.0618342122724, 39.43286211259904, 38.82627933256088, 39.0330784551559, 37.689372493374734, 37.88063903008738, 45.617239629068685, 49.4747063421434, 49.179371480018865, 46.04176559755879, 46.23516982601535, 43.42793733842912, 43.8858191428646, 42.92283019711895, 44.29625595769575, 44.027573600892104, 48.39084563716766, 50.989784579123224, 54.85614722774875, 54.97513232692596, 52.79748339806834, 55.56844965104134, 52.643667651760964, 43.19028877442883, 42.597861828342566, 44.58178489438949, 53.227681113827614, 56.383882953274636, 61.36134716772265, 45.12985375619704, 21.9988602207553, 7.206942362170066, 14.458472267273935, 10.754373169714405, 3.574680248575826, 3.0670814216136937, 0.11915270389328081, 0.1397639317738433, 2.541793195470687, 25.62836858534044, 53.06896632717502, 44.79059227051274, 37.023954160751835, 48.84078071963403, 58.277779779126575, 50.29246168751871, 16.882744143086096, 0.7649940120116357, 0.11454827032021939, 0.14466179234366264, 0.025713898226498597, 0.000588214218535746, 0.04357647541309557, 0.0480059651477683, 0.05090663832942805, 0.07426538309382816, 0.08378890553309072, 0.0545712543891803, 0.006123192349238502, 0.014641506882805019, 0.005532047784541764, 0.040785000404162754, 0.002848057784215217, 0.02557635288535347, 0.023318325965515068, 0.19378786996727992, 0.13525443181635874, 0.11137560145148348, 0.17024627916755217, 0.13331874213632078, 0.11980166463481805, 0.19708161903244836, 0.11642294875796765, 0.13687873739869366, 0.06133377679713792, 0.17708778141006348, 0.19506486192826303, 0.2350980581174935, 0.11582359220952758, 0.1297295895675498, 0.2639456964548557, 0.12484974738570953, 0.15888459770189178, 0.17759736777553636, 0.20309174733777202, 4.198019639138253, 38.27011469871768, 68.23981946514499, 61.181812440195394, 44.9730295519675, 43.332404090512185, 45.61148943439607, 54.39485688363352, 32.77447204436026, 3.30409872916437, 0.33637658242256413, 0.7068123920790611, 4.085253703017389, 12.519406407110154, 11.065216102907735, 10.875147850282731, 8.287356284356887, 20.60338289506974, 25.537534336889944, 50.39785969641901, 56.58246078798848, 57.13170636084772, 51.553185985934356, 47.03057550614881, 43.96012452340896, 49.988466232053696, 50.43838954740956, 57.15744103154829, 48.7413094120641, 46.1632021780937, 53.562580923880304, 55.6264615058899, 53.836738909444506, 48.716747530045055, 39.51078784081244, 39.72966394116802, 40.43786748763054, 39.61014932201755, 40.42783798709993, 38.82167054760841, 39.043186403089955, 37.5257194426752, 38.59889953367172, 41.251182709970784, 44.88467424146591, 47.207686208909564, 49.46749702576668, 47.65463244530463, 41.65441020842522, 43.100317447416245, 41.209605586144235, 44.408776990828976, 45.498183927228375, 45.82851417603032, 44.78839966558641, 42.86532825039279, 42.184659742539935, 39.09532646979056, 39.786491240224535, 42.79317625107304, 40.00122139530797, 41.248841054977916, 41.584709690463164, 44.768458335630356, 45.37836336320447, 48.85528564453126, 52.22123622894288, 55.59052082800097, 53.317817180387436, 43.925348789461204, 55.89198243233466, 55.577443645846465, 57.35967451526273, 54.031527734571895, 50.82081671684019, 52.24580595570227, 45.32233622766311, 41.8080690599257, 40.14695705906038, 40.301423918816354, 42.88342214399769, 39.21523724832843, 40.1011476978179, 41.30667248079854, 39.15201648589104, 42.663847861751435, 48.70053637412287, 53.56689945344002, 52.54684786642752, 49.062884930641424, 45.02598154929377, 42.79232901911582, 41.87112900518602, 42.37667545195549, 40.73788173737065, 39.13062387897123, 39.794638003072436, 47.413496894221154, 51.45109845745949, 51.9752840072878, 49.50522238208402, 49.585070071681855, 46.502314613711455, 46.0551251903657, 43.916719575082105, 45.85117370851579, 46.80234063056208, 50.29836485462804, 53.33881755029002, 57.36518152298466, 56.23411901535527, 54.4269379492729, 57.471987662776826, 56.69584474255962, 45.15450193035988, 46.56200916536393, 46.35400979749618, 55.06216579867948, 58.29266517393051, 64.76070850126206, 47.194942428219704, 29.448531596891343, 15.606235246504507, 24.094929733584006, 29.073684407818703, 9.26835479274873, 7.830933111329233, 0.47819146946553265, 0.4071391740393254, 3.0980281868288597, 30.02956994118229, 58.9357691426431, 57.28681256694179, 42.43925686805479, 58.02905836412984, 66.64778432538434, 59.282028136714814, 21.169184792426325, 1.3609385274110304, 0.23237103025519082, 0.24961101161616467, 0.08913904143076751, 0.14457957578762887, 0.12684721439596147, 0.13281153064341317, 0.09226284155081357, 0.1529451946337377, 0.11844036469776785, 0.08032173714450291, 0.19226959095366541, 0.18972060192496548, 0.12914989083524675, 0.23274469730113787, 0.08216278432237525, 0.12702964291337038, 0.1407493506708453], [0.02522255816016226, 0.02006656426425663, 0.03817253333005694, 0.017339007801286156, 0.08208579248598508, 0.0025028133184664073, 0.020510108104997107, 0.04204074491656596, 0.019558973557826494, 0.007433676716661262, 0.059388825114095406, 0.027422417939129858, 0.0445250531418189, 0.04595641181954453, 0.04020489181482023, 0.006513355183415116, 0.034682769178142475, 0.07906251076248386, 0.055480807599040775, 0.03993213003981979, 1.327086266490721, 25.067383358555457, 46.36843235261979, 43.779687650742076, 30.08518130548539, 25.64356384738799, 30.239799176493, 40.915498425883634, 29.503797792619277, 5.751118390790879, 0.16175362762183915, 0.12225519910815263, 1.1914818397452756, 5.860180874024668, 4.0788470016371825, 2.203727542392669, 6.2981929317597425, 10.487769669102086, 21.546426588489165, 36.581757914635446, 52.05841472071987, 52.27228979910574, 47.91798822341427, 42.74009089316092, 45.66857953225413, 46.50214987416422, 52.23617261455905, 50.33835341853481, 47.56925421376383, 50.58468218772642, 48.37794496167091, 48.94267997434063, 45.83116962063698, 40.88329184439875, 34.67603122034381, 35.76962724808724, 34.523184299468994, 34.827313115519864, 36.27038055850614, 37.072356208678215, 36.23960956450432, 35.61993783520114, 35.38246970022879, 36.756562263734885, 40.40128746340352, 48.422177530104115, 49.82616247669343, 46.61558874191777, 41.529286599928334, 37.058023868068574, 38.17966876491424, 38.316331986458074, 38.99041875716179, 39.91291707561862, 39.951685782401796, 37.4696687729128, 37.93626608387117, 37.54340148741199, 37.59630249392602, 36.11161870341147, 36.19656939660349, 38.25941839525777, 39.69530005608836, 39.67250716301703, 40.497303162851644, 42.46466205966088, 46.71891966173726, 49.427037777439246, 51.39090184242495, 34.021493542578916, 35.961807697050034, 48.91094015490625, 51.96177928678451, 50.16078379846389, 49.43207802311067, 49.95298447147493, 47.97566275442801, 40.02839165349161, 39.741568334640995, 42.87077250019197, 36.80032022537724, 37.277539314762244, 36.28976098952755, 36.78081035614014, 37.566602306981245, 42.04565094363305, 48.95047764624319, 51.276419624205566, 52.459641810386415, 48.93208173013503, 41.443033679839104, 39.22420378654234, 37.6987430357164, 38.02050290569183, 36.90636542535598, 35.055830401758996, 37.011665375001975, 37.38089376880277, 39.24198781290362, 41.059822036374, 39.35479517905943, 39.47438432324318, 36.015857958024554, 37.699190185916045, 36.63190541728851, 37.144057135428156, 38.4331323254493, 45.186987000127, 47.4995772300228, 51.719435645687966, 55.278037363483065, 52.08362379381734, 53.48501605372275, 52.585714632465, 46.461490584957986, 42.27141864838139, 41.825731492811634, 50.81144225212836, 51.844480806781405, 61.521344569421586, 44.504710320503484, 21.691868074478645, 8.165652002057723, 12.132247878659157, 9.070465334000128, 4.220230060238992, 1.383431849460448, 0.3712158097374824, 0.20152879007641347, 2.0127246625000432, 29.507535811393495, 45.67718913478237, 40.319819834924516, 33.45880992950932, 41.763452099215606, 56.67586026653167, 40.561747704782796, 12.013345149255569, 0.33235419181085407, 0.09217357698587642, 0.09033931734701318, 0.04795371412089275, 0.025021647771580086, 0.04420570939058258, 0.03924215295081658, 0.04436405210365211, 0.007696487967135205, 0.033085694191076105, 0.004010423839527873, 0.05822884925310651, 0.033145495014445435, 0.05926212566273828, 0.05183305313450195, 0.023640103961130785, 0.07925445409191233, 0.04689341395973198, 0.012054366675475913, 0.05489226438165192, 0.023818204081767512, 0.05439338792536048, 0.05510268575181404, 0.06388105361932708, 0.0021615587343882412, 0.023580822162330154, 0.0323455345125929, 0.02976462068486839, 0.016471238942035747, 0.02995733201744095, 0.043373144186672666, 0.02979997564257393, 0.0484360545693386, 0.03952885752603893, 0.05274070644631021, 0.03397373182158317, 0.0411724302196695, 0.07873955107624493, 2.137628250545071, 29.958278902115364, 53.60860601548226, 51.75840047097976, 34.19546634920182, 29.96000082262101, 36.82280325120495, 46.132827343479285, 32.38157803012479, 5.6173670388037165, 0.12729159901819884, 0.08849401072028185, 0.886745791762106, 2.5200404659394295, 6.244967839410228, 5.4841863916766265, 6.84109309027272, 12.21775064545293, 23.848555857135405, 40.16795350659279, 53.55241021802349, 54.50491466829854, 50.57603728386664, 45.883698001984634, 46.62330796641689, 48.92988128046836, 53.14969655006163, 52.054068734568936, 48.41457597671017, 53.914452829668605, 51.131142877763324, 50.1098322099255, 47.74127760241109, 41.512310581822554, 37.2044224123801, 36.31427580310453, 37.413029747624556, 36.62933234245547, 38.57568302462178, 38.07653396360336, 37.93872148759904, 37.50220483349216, 36.88591418727752, 38.92480142654912, 41.15082102437174, 49.62248556075558, 50.98016300509053, 48.75144873895953, 43.51931679633356, 39.22745150904502, 40.48255897337391, 40.524328293338904, 42.63555972806869, 41.90790514792166, 41.42913279994842, 40.45942875646776, 39.83953737443493, 39.28756575430594, 38.2808227692881, 38.893089063705936, 38.68714894017866, 40.502453234887895, 41.46751319208453, 41.89390228640649, 41.75590938137424, 45.1391536958756, 48.73045229142713, 52.63124158305507, 52.36047252531975, 37.35424910822223, 40.24778550670993, 49.839459311577585, 53.90408992767335, 52.12234543215845, 52.16600141217632, 51.689786449555434, 49.51985674519693, 43.53907769726169, 40.49491836178688, 43.88184185950987, 39.0141490967043, 38.67076912233907, 37.425922578380955, 38.98544126941312, 39.41849447065784, 43.218318031680205, 50.46696793648505, 54.75752707450621, 55.94360866854268, 49.29955290209863, 45.112383519449544, 40.059315619930146, 37.288843585598855, 39.42945357291929, 37.999565293712, 37.245626911040276, 38.482189409194454, 38.608003354841664, 42.24160863507179, 45.04858616859683, 42.35311769670056, 41.57019299845542, 39.833630284955426, 41.72737413837064, 38.827675696342226, 40.17709262909428, 40.849449634552, 46.92608748712848, 49.82078098481702, 54.39210337977256, 58.014565206343136, 53.111347536886896, 55.413853353069676, 56.50133832808464, 50.0473213964893, 44.943301908431515, 44.58782142208469, 53.45768497836206, 57.37827439461985, 61.56958187780073, 47.20326962009553, 20.10243150495714, 5.59145046818641, 8.420002018251727, 11.926588204599197, 6.20217134875636, 2.1243586271039905, 0.294194953936723, 0.06922316857643666, 3.384298206337037, 29.65243208792902, 54.607845506360455, 43.98352538385699, 37.0462606799218, 47.263026929670765, 62.62070648131832, 47.422549724578865, 14.168139407711646, 0.48406356404865947, 0.13422125499815712, 0.07626819739779157, 0.0641194103856481, 0.04607566872671728, 0.0755801585112368, 0.05452097603870977, 0.025423514514019894, 0.031811257133320454, 0.015910922234217008, 0.05802621133625508, 0.019468513895727454, 0.031187397262622273, 0.05704978248104454, 0.054234800064155174, 0.011544418333458805, 0.02678451184633999, 0.0338938441728392, 0.13993371217962236, 0.1398751217751734, 0.15320020998197217, 0.1017042087210763, 0.18344658697324415, 0.15276023036529943, 0.13202887989820974, 0.09514716258572956, 0.11815976967374164, 0.1713426888830239, 0.12757450762775638, 0.11684328588026187, 0.1036206849159733, 0.08868044587753474, 0.21622249435993934, 0.1187045731010937, 0.23500853308266212, 0.1984445200932603, 0.10172248757894962, 0.11563768565294244, 2.7611735655415446, 33.703695266477524, 60.333246877116544, 58.543849837395456, 41.40155461526687, 36.26360662521855, 42.44915300799955, 52.44567032783262, 39.30368277334398, 8.214746838615786, 0.4216980008829025, 0.6950832182361234, 4.04969128870195, 13.069684543917257, 13.372281674415836, 7.397337152111915, 13.927845205030135, 14.06680497430986, 26.613922926687426, 40.9387541586353, 56.31876768604402, 57.964154904888524, 53.44212101351831, 48.15723711444486, 49.94752453219507, 50.1377163394805, 54.90016014345231, 52.48885562342983, 51.21882746296545, 54.86432536955803, 53.140318162979625, 52.24751610909739, 49.67253108178416, 44.043553336974114, 39.113267390958725, 39.42757083523659, 39.82420875180153, 37.86962109227335, 40.9514626379936, 41.41310599542434, 39.51148210033294, 38.98803003372685, 38.60312392634731, 41.38244090541717, 43.91031042222054, 51.99907710475307, 54.5323359581732, 51.05948117471511, 45.99910982193486, 41.225510797192975, 43.340048789978034, 41.52307356557539, 43.936774653773156, 44.77400848942418, 45.29985712420556, 41.53669595718384, 42.54369389626288, 41.44703449741487, 39.23359394073486, 40.196578964110344, 40.06969813377627, 42.40382217591809, 44.88072833707256, 43.6177251415868, 45.17412947070214, 46.26166151415917, 50.7601337279043, 54.41875196272328, 54.1349135675738, 41.2294880805477, 41.24541682581748, 49.44767728928597, 54.64302524443596, 54.82117929766255, 54.83382109672793, 53.56098844159035, 53.37581726812547, 44.93668094758065, 41.224847916633856, 45.96387909304711, 41.079245613467315, 40.71436712818761, 39.394666071861025, 40.88428420405234, 41.196449956586285, 46.16923478341872, 53.86561147628292, 57.4935842329456, 56.83354739219912, 52.607934859491166, 47.42737423989081, 42.223938357445505, 39.77548114715084, 42.06696902551959, 40.58646255923856, 39.06288062372516, 40.59800217228551, 40.90585331762991, 44.531951181350216, 46.13535727224043, 44.32362625675817, 44.07502643523678, 41.04430513997232, 42.95864535916237, 39.07095286153978, 41.037119357816636, 42.73096353776994, 50.842719231882405, 53.64303265848468, 57.24031679091915, 61.05273116019465, 54.97315545235911, 57.33730523817001, 60.305413738373794, 51.93662512686945, 48.050332915398386, 46.129795351336085, 56.51232096456713, 57.42977119261219, 66.54169205696353, 47.81590461730958, 25.35558342933655, 12.51435439432821, 20.718551528069284, 21.27794231137922, 9.352377845394997, 4.647011881874454, 0.530391842607529, 0.36762821998807693, 3.788948789719613, 37.865812470836026, 59.3641508010126, 53.2172985999815, 44.020568247764345, 55.75138115113782, 70.99671225393973, 57.39732534654679, 18.634062813174342, 0.9947187141064675, 0.2528109608758842, 0.22410592214474756, 0.14683826345830195, 0.08905416654963648, 0.2432662254619983, 0.13572258814688654, 0.1342014746079522, 0.18782514718271073, 0.14708935643636412, 0.11360964407363247, 0.10335160419344903, 0.1858473839538713, 0.15073598092121465, 0.22617840448454504, 0.15458989347661697, 0.20818070087942386, 0.12274741826038207], [0.06021299782479483, 0.05848019887062331, 0.030425972898580858, 0.12029471116200571, 0.023713048938060963, 0.0945523182951635, 0.022982513239126534, 0.05900704519703023, 0.05099367740894518, 0.04859988247194598, 0.021475851948883747, 0.05572079996308012, 0.014643320595965752, 0.03779041250386546, 0.0873237731115472, 0.018076267836975957, 0.03902298285655918, 0.016618948354716265, 0.056850768160074956, 0.02284975977794778, 0.6091360591592327, 15.533453706772098, 40.940260348781464, 49.39233656852476, 35.64593922707343, 28.249992555187596, 43.76362554488644, 42.214061829351614, 33.63220614771689, 8.814747391208526, 0.6071525043056858, 0.011345534247436352, 0.3937548212707043, 1.276403850605411, 4.024972021579742, 6.27164387895215, 4.425277354255799, 7.5469476272982945, 17.79257712825652, 32.73825876174435, 43.78298244168682, 52.769924825237645, 48.036820350154755, 46.98049860615885, 47.487923868240856, 52.398994122782064, 51.49242847196518, 49.641709096970104, 51.7401026141259, 47.60020563679357, 45.613819322278424, 43.624750106565415, 38.3439140935098, 34.51446879294611, 33.97562926815402, 34.17860015746086, 38.83595189740581, 42.6574779325916, 41.850297297200854, 42.11075836612333, 37.731679178053334, 35.45171522325085, 37.79904196339269, 39.10042162864439, 44.6988990229945, 47.70077128564158, 51.05333482065509, 50.50653680678337, 49.41398412950578, 39.94116206322947, 36.339484876202, 37.68033927486789, 37.85578297030541, 37.39165283018543, 35.551735662644916, 38.179343208189934, 36.689297537649836, 37.32498430436657, 35.992378650173066, 35.870165440344046, 36.80850228955669, 38.67055339197959, 36.31816287194529, 36.527868470837994, 36.855417759187766, 43.60698961442517, 47.35823462086339, 52.52412165364912, 47.60560674052085, 39.42328760700841, 38.167215239617136, 45.84378396311114, 48.599225474942116, 53.07900759481615, 53.36897273217478, 51.264907467749815, 48.9286143549027, 40.556436815569484, 41.34908114710162, 37.50296969567576, 37.231239657248224, 37.74706271386916, 37.74054373464277, 39.72360387925179, 38.900757297392815, 45.16642985805389, 50.93269055889499, 53.223240990792554, 52.59036656348936, 49.65159739217451, 43.928235653908025, 38.7709778355014, 37.287702175878714, 38.985955099905695, 38.72146967918643, 36.06687230448569, 37.149889699874386, 36.54629576590754, 36.68176266454881, 34.86752133215628, 35.834350278300626, 37.68968236061835, 37.48823727330854, 36.98844102121169, 36.930189901782626, 37.51644303721767, 36.97483039671375, 39.734366863004624, 46.649164230592795, 50.68389854123516, 55.77377788482174, 53.22520609824888, 54.587445259094245, 53.21946374831661, 53.063502465524984, 46.428295566189675, 44.08686022604666, 48.723344956674886, 56.24716089617822, 55.86088195923836, 49.38508410607615, 19.529155531237205, 3.53645307402457, 9.07167930756846, 5.250839196866559, 0.9317856330064036, 2.2902829752814386, 0.20979474088357342, 0.07685171890883677, 3.4970653681985797, 30.624909247121504, 48.65585665549002, 36.54468367176671, 32.33659432780358, 37.92968042435185, 55.11788306697723, 38.36579307433098, 12.291078375231836, 0.2223861466852888, 0.12417648633521412, 0.07267398098784109, 0.08844993768199798, 0.02044076757175067, 0.029804210193575393, 0.10130224238720634, 0.05810760434777026, 0.05399155565687726, 0.025308802423457948, 0.04708746403095223, 0.03499896813844962, 0.04163609344452139, 0.077495631130953, 0.03515304757222053, 0.03004344987622913, 0.024007594423188318, 0.046246717008011, 0.025839128704260916, 0.018476186800868283, 0.0433723627769899, 0.02119957766075048, 0.015735006421774386, 0.07271601623224636, 0.03158563849396043, 0.02829660853040555, 0.02098442761287574, 0.09163136293570842, 0.007180352986324579, 0.05743025238775919, 0.04515696459660127, 0.09050058651595347, 0.026623148831628987, 0.01700009816446372, 0.04663976990888196, 0.039580503343454296, 0.032300802638694164, 0.0399638997060397, 0.879131980961369, 21.15648219662328, 47.324463013679754, 53.700389477514456, 39.37745078917473, 31.342255838455696, 44.08430676306448, 47.85932917748728, 38.427150710936516, 10.714046301380282, 0.5498264513669476, 0.06030727260475678, 0.8419683203101159, 2.21916108842819, 6.187815473925683, 5.667384612944819, 4.768077308131803, 9.822356239441904, 19.516184253077355, 34.32856021388885, 47.548202853049006, 55.08628837523922, 49.31758403778077, 48.27826184611167, 49.824805336613814, 53.35976300701019, 51.68900589789114, 48.952740853832616, 53.70792827298565, 50.71463423390543, 48.79077834467734, 45.35914374936012, 40.36345228072136, 37.331828840317264, 35.874232938212735, 36.08669596333658, 38.52701033315351, 45.054120632909964, 43.365846218601355, 43.09628917324928, 37.71435799137239, 37.41284539622646, 36.571081223026404, 40.189126460782944, 45.61732984358265, 50.74987672990369, 52.381484662332845, 53.64364847060173, 50.721737646287494, 41.716140470197125, 37.20329669214065, 39.80245528682586, 39.193260208252944, 39.429147628045854, 38.86566777383128, 38.921934173953154, 37.90076078907136, 40.083559789965236, 38.171423942812034, 38.29073852108371, 37.52413480512558, 40.20514542056669, 37.91026861436906, 37.85785790412657, 39.433050386367306, 45.37317406746649, 49.310943465079035, 53.25391784791024, 47.068700944223714, 41.550302659311605, 38.34729517659834, 45.20299419280022, 49.26716196921564, 54.59906331954464, 54.96691888378513, 55.40944068662582, 51.338302858414195, 42.29047744504867, 43.03482955501926, 39.91224635031916, 40.28854285517047, 38.92356980231501, 39.28423566202964, 40.52058242982434, 40.29073153772662, 47.22338745670934, 53.882375686399406, 54.834103507380334, 55.67447916153939, 52.905591764757716, 46.185602834147794, 39.96036598759313, 37.819567726504424, 41.1353825753735, 40.24849937808129, 37.11322730587375, 39.57972741896106, 38.95729826342675, 38.03540006760628, 37.44176503150694, 38.98639440536499, 39.00869307979461, 38.88135333215037, 38.760391358406316, 38.87562274932861, 37.79726120733446, 40.22587906929755, 41.782958046082534, 49.6559629901763, 52.19779614479312, 59.03314590454102, 53.79871937536425, 56.31189961587229, 56.772911471705285, 55.330130361741595, 48.05313741007159, 45.98534230263003, 50.04149275441324, 58.61367194883285, 58.17880661256852, 50.19650874599334, 19.4529301504935, 4.3613162444483855, 9.361483627750028, 10.365483895424875, 6.7341908524113325, 0.871158292697322, 0.2649188119797938, 0.10496778158290733, 4.092850843744894, 36.04350282299903, 50.25361061096192, 42.3730041134742, 37.73893948524229, 45.296170096243586, 63.187916509566776, 45.33091445122996, 14.299093619469675, 0.2863940338213598, 0.051660759960331266, 0.029058632358247717, 0.04118975146763748, 0.042611683433454846, 0.05971540073533693, 0.018666802882967938, 0.018871926755133658, 0.05117411026731134, 0.011475933903467753, 0.05571945547877301, 0.020284679072398334, 0.08901518033516985, 0.1467540091083896, 0.026162626567266645, 0.025180815944388032, 0.027762930614933855, 0.022353357785651763, 0.17001901152393512, 0.14518985674986917, 0.10799292490006455, 0.3086176622779139, 0.1791183893839198, 0.21320193224856931, 0.12657161426520155, 0.12184426188468934, 0.10810895657707607, 0.2593019778930372, 0.10604280212353315, 0.1628108136355877, 0.11388466963844915, 0.21165576763451102, 0.20760734535513387, 0.10120654268370521, 0.16538883739661786, 0.18711928909103717, 0.1563517271631187, 0.1884570777896912, 1.2980747006593214, 24.235744783955237, 54.710333116592906, 61.60067058378651, 46.57361938107399, 39.084508572855306, 54.86719654452417, 53.14235779546922, 43.655607392711026, 12.372731335701483, 0.933568595397857, 0.15331227332353592, 2.576287009062306, 6.381268732009396, 13.182646843694872, 14.486099481582643, 10.526623687436505, 10.994284941304116, 20.180857335367513, 36.28288507461548, 49.182136750990345, 58.91883234823904, 52.548228540728175, 52.12852316517984, 50.37821254422588, 56.551266178008056, 54.44010534594136, 51.804527544206195, 55.77493890639275, 53.81883328960788, 49.9034135572372, 47.93195186122772, 40.820404483426, 39.041825340640166, 37.05857692226287, 38.01658053551951, 41.24011770371468, 48.083508322315836, 46.24517186995476, 47.04530400614585, 41.78776294954362, 39.37290476214501, 40.22926407475626, 42.99854370855516, 48.52105263740786, 53.214450959236395, 54.40942456645351, 53.79474601437969, 54.75584830007246, 44.578643075881466, 39.69051476447813, 41.330442044042776, 40.017169752428615, 39.65133813119704, 39.60466192614648, 41.90666175657704, 40.115279997548754, 41.74850394648891, 40.88772804506364, 40.199909056386645, 40.744361492895315, 42.43489127005301, 41.01657790522422, 39.056950000024614, 41.53613898061937, 47.64527367007348, 52.294164857556744, 56.28892237140287, 48.744239422582815, 44.07417920327956, 39.14488561691777, 46.484330546471384, 49.63753177273659, 56.06859107171336, 56.28008134903447, 57.29712447812481, 53.428294658660896, 43.73244270201653, 43.98378033791819, 41.273073457902484, 42.06059909635975, 41.47839384694254, 40.856984507653024, 43.38804291140649, 42.812035006861535, 50.36409985634589, 57.618837279658166, 57.197974804909, 57.7572577230392, 55.46333013042327, 48.22934204532255, 42.155622436154275, 40.20334113028742, 42.91612294412429, 42.84677543947774, 39.66534099271221, 41.57469980178341, 40.70698914989349, 40.78356166039744, 38.150937403402025, 41.1671616185096, 41.55847295638054, 41.35321924763341, 41.96602682913504, 42.04282683710898, 40.311763286590576, 42.07624150860695, 42.74112247651623, 51.45881375958843, 56.416721036357266, 62.489628714899865, 55.43841523508872, 57.24288202101185, 56.582237212888664, 59.2606080732038, 49.77057464661137, 47.263434856168686, 52.69279141579905, 62.287508979920425, 59.26899017826204, 54.192980335604766, 23.55797294647463, 7.08681095031, 18.254553887151904, 14.708623386198475, 6.663209190291743, 4.8241073854507945, 0.9734256373297785, 0.26819837309660455, 5.730934364180412, 40.908163593661406, 61.75572579906833, 48.804749827231134, 47.62621095103603, 51.95568784590691, 69.89769551061815, 52.987408484182055, 16.86290087238435, 0.7088766619563104, 0.25177324881717084, 0.15687016950499627, 0.15818180396191536, 0.07689174700288043, 0.25948924042524835, 0.1757144921969983, 0.12151754836762145, 0.1654870958337861, 0.1033865148201585, 0.1748597372563616, 0.19108708827726303, 0.15185137429545004, 0.2665047672006392, 0.08585677602358403, 0.13102121380788664, 0.09276527265507369, 0.15397941333151635], [0.01766522719164289, 0.07648568209861556, 0.09040310182758877, 0.04699317392923179, 0.05393606790852162, 0.024294703109790722, 0.040792454439666004, 0.03176491264434111, 0.047192624920318206, 0.05625555614730524, 0.03030105268642787, 0.020285533260433905, 0.02588279380072509, 0.03791833386546181, 0.06593246088032761, 0.0264507828791055, 0.043489677651274594, 0.004024007536035272, 0.05311327415608591, 0.01937404759378443, 0.0999695328514903, 12.296243156156233, 41.781977453539454, 49.12867484554168, 33.91182799493113, 28.876850066646455, 28.888515195538922, 38.72363874989171, 42.44906671585576, 12.540353825015407, 1.2056140169020624, 0.07565440009197882, 0.12877194901868222, 0.736822568841519, 4.405389956889614, 3.519287801557972, 0.20661363738679117, 3.289946327286382, 9.418283470215338, 24.14081361985976, 42.62281986974901, 51.48628211790516, 48.046363476784, 46.715079661338564, 52.89388741216352, 52.543215751647956, 48.969995360220636, 53.967938269338305, 47.25430750077771, 46.51579187762353, 41.90148815031975, 36.502086731695364, 36.326537132263184, 35.19287409320955, 36.25469107781687, 41.797306076172866, 46.447158244348344, 48.40263235953547, 49.75848982411046, 47.11731087776923, 43.00034407646426, 37.53858481684039, 37.932633969091604, 39.09909978989632, 45.93498299198766, 48.00951673138527, 51.55824192108647, 51.35569072538807, 50.02181422325873, 43.08008978443761, 36.407789030382716, 38.383078959680375, 37.49152029714277, 37.095549183507124, 37.495509347608014, 37.02654684743574, 37.75735501320132, 36.002788620610396, 35.661758145978375, 37.029637675131525, 35.758762282709924, 36.94825633879631, 36.31765688619306, 37.40438876613494, 38.80107418183358, 41.50529738395445, 47.470708585554554, 50.33947521640409, 53.249250227405184, 39.61546021123087, 49.52685033121417, 51.54457246103595, 53.64962616274434, 51.55140915224629, 52.61830560622677, 48.98290388045773, 46.38549466286936, 41.99061616774529, 37.13033276219522, 37.21087471131356, 35.68060513465635, 37.25164382688461, 37.35056208026025, 39.145803451538086, 39.53926032589328, 47.34408270928168, 51.83217633155085, 51.0473963522142, 53.35067095295076, 51.73144202078543, 44.24049162095593, 40.25670105411161, 38.44461310294367, 37.729768983779415, 38.539153991207, 37.85988576950566, 38.589419164965236, 36.543479504123816, 37.54408790219215, 39.212122886411606, 36.98512661841608, 36.267289730810354, 36.8092514622596, 36.96165515530494, 36.465930323446955, 36.13410172923919, 37.841066237418886, 37.60397464998307, 42.5329230677697, 48.86218509366436, 52.046828039230846, 54.650630720200084, 54.682241101418775, 56.1268029674407, 56.99101094276675, 51.314042998898415, 47.85742290558354, 48.53426318014822, 56.99032060561642, 56.613706388781154, 43.181110428225615, 19.15071741227181, 3.4247170052220746, 5.132498837286427, 7.427852211459991, 10.502151039338882, 0.9663197734663564, 0.288831970744556, 0.07548677239326701, 4.924923575693562, 28.247972534548854, 44.79019611112533, 40.19500217130108, 30.999144546447265, 36.81893187184488, 50.50848230238884, 38.041977882385254, 6.812991269173161, 0.2326840537810518, 0.04667382634755585, 0.03386433446599591, 0.01812317731579946, 0.05548209845719319, 0.03631407297366569, 0.030354539030081326, 0.03816697919260591, 0.08274059847838457, 0.1782354117641526, 0.029533403858001676, 0.02088226978817294, 0.05870397698374526, 0.03241269744091457, 0.03511838209364684, 0.06079920830445425, 0.04621968942604238, 0.048754272171326225, 0.01026593345863324, 0.05064829432916257, 0.09059741236870328, 0.13762498364573525, 0.06439832384668051, 0.02312677334092798, 0.00810943425617992, 0.013990818612998532, 0.03788722686529641, 0.04877829285819204, 0.020583958980897744, 0.01992655786565475, 0.03560889670024476, 0.045109792732663696, 0.07728535531749649, 0.06621823465872197, 0.04937270430908088, 0.049885753391971516, 0.03847334158396529, 0.021837943406294913, 0.2437459037549073, 14.27056622120642, 48.1560133349511, 54.17086993494342, 39.92939103034235, 32.29086733633472, 42.68409513658093, 47.717056966597035, 46.84027387249855, 13.823120863206926, 1.1494510692934836, 0.04093177135913603, 0.255077968261415, 1.8088586147754424, 6.764630896429862, 7.309455958104904, 4.153585068641171, 6.172182377307646, 10.503881785177416, 26.955061266499182, 43.83270632836127, 54.93585763439056, 50.615712058159616, 49.356297831381525, 54.901026987260394, 53.816326895067775, 50.67234323870752, 56.75954403415803, 50.53565648294265, 49.825232874962595, 45.1410952691109, 39.07310624276438, 37.7399867580783, 37.30390156469038, 37.88552630332209, 42.63693647999918, 48.134393230561294, 50.14097975146387, 52.552205824082904, 49.08658389122256, 43.89273035910822, 39.20519990305747, 38.92773928180818, 41.45777786931684, 46.73034552604922, 51.15881912169918, 53.94120731661397, 54.388114329307314, 53.142671585083015, 44.56680928507159, 37.52753942243515, 39.3059616704141, 37.68991770282869, 38.37403005169284, 38.93066144758655, 37.79718275993101, 39.68861241494456, 38.160849232827466, 37.52263253734958, 38.40628762398997, 37.69704857180196, 38.14222581924931, 37.23263994339974, 39.80863694221743, 40.77540705280919, 43.51135046251359, 49.57853932534495, 52.93242077673636, 54.68544175547939, 42.559854061372825, 49.963363062950876, 53.214074411699855, 53.980007402358524, 54.0995063320283, 54.81639008368216, 51.9179585672194, 49.96927799717073, 43.300844700105735, 39.61890012987199, 38.6188094846664, 37.13547106712095, 38.952956199645996, 40.297517238124726, 40.71060165282219, 40.86620992229831, 49.29863114510813, 54.63434503924463, 53.763892650604255, 53.44404689727291, 52.63694863165579, 45.65674181907408, 41.87342359173683, 40.30419703452818, 40.138010132697325, 40.925747579143895, 39.54372398314938, 39.75188416819419, 39.05774231879942, 40.56395207681964, 39.97591034058602, 39.282243097982104, 38.42420501093711, 38.0765849544156, 38.38459691693706, 37.71080824636644, 37.240029688804384, 39.0091480747346, 39.44755138889436, 44.76206094987931, 50.640352387582105, 53.846760565234774, 56.211569309234626, 54.94955062866212, 56.55684771076326, 59.18741272341821, 53.11139852769914, 48.673483787044404, 52.421347710394095, 59.526023095653905, 61.07888944687382, 46.99549774969778, 21.639569151786066, 3.7623399207668924, 7.901955468039359, 11.059789503774336, 11.86230153806748, 2.1644589785606634, 0.1733854470113593, 0.14037367647453663, 5.243741668039753, 34.46998519282187, 51.291705100767075, 43.03047180175782, 36.37565305156093, 43.39180838677191, 57.44630790525868, 43.1136142823004, 8.985995131154215, 0.33941534678301505, 0.004782731918948553, 0.05596259263374152, 0.02168661805861179, 0.06436101536476804, 0.0295212556187424, 0.03660648873436355, 0.05703413130475148, 0.029323323396965865, 0.07254877923837594, 0.026611473651662953, 0.04781885966358166, 0.05798770392674112, 0.05158655285354584, 0.042680558568287286, 0.014197414331588776, 0.017451264580050786, 0.06404036926406045, 0.126657132660189, 0.2236594461024769, 0.20065269192620633, 0.17927909930867536, 0.13273878293412347, 0.16749423087364243, 0.06699696303375306, 0.14397081167947862, 0.1584445414764266, 0.20138527116467878, 0.10381126460889656, 0.1864049733886796, 0.1277985347194537, 0.11590813001197194, 0.16395801498043924, 0.21049296873952114, 0.14647628691407943, 0.17811121358986826, 0.23563962099292587, 0.15138334053899014, 0.49909819278024864, 17.599810284952966, 54.08304806678526, 62.39868856245472, 46.27840611242479, 38.410821883909165, 39.24488644446097, 50.24904497208134, 54.09130073362782, 17.54096296525771, 2.2580648718341707, 0.23964331905928352, 0.9889614714249488, 5.473856829827832, 9.318415022665455, 9.923015044581506, 5.7170599602883865, 6.134605580760587, 11.17117795252031, 27.76040819383437, 45.996517135250954, 56.0808131771703, 52.88235956622709, 51.14799730239376, 57.54504180723622, 55.10279370892433, 51.028757249155355, 60.44647001451062, 53.489499322829715, 53.423144586624645, 47.73719049269154, 41.42126452538275, 40.113405104606386, 38.95822786515759, 40.74416145201653, 46.276754794582246, 52.36746218896682, 52.935954832261615, 55.756135063786665, 51.22674280597318, 46.647454077197665, 41.49890784294375, 40.14422708942045, 43.58384370803834, 48.857144847992934, 52.579717328471524, 55.27354232726559, 56.05062269395398, 55.627920627594, 47.35861116839994, 40.61836711822018, 41.328641676133685, 40.03525972366333, 40.808437332030266, 39.87037897109985, 40.784032344818115, 41.829469511585856, 39.92935965138097, 37.83977577763219, 41.4340945982164, 39.33853695469518, 41.511702614445845, 40.0881685749177, 42.17823882256785, 43.096481369387725, 45.057611542363325, 51.16227472982099, 54.014183013669914, 57.13911179573306, 45.038054604684156, 51.17725818387924, 53.19879285750851, 57.03509446113341, 56.1912553541122, 56.97034789669899, 55.032422465662805, 51.80464521531136, 45.005055704424464, 42.532456305719194, 40.87681601124425, 38.93296387887771, 41.93789951262936, 42.93893937141665, 43.33225504044564, 43.51733599939654, 52.22542139791673, 55.53737271216608, 52.36646198457288, 56.3290286064148, 55.38349813030612, 47.386393316330455, 42.98640789524202, 42.02141854070848, 41.990188629396506, 42.484783818644864, 41.506854564912864, 42.27914179525068, 40.922040939331055, 42.014385730989524, 43.23054013713714, 41.11945383010372, 40.08208105641027, 40.79970221365652, 40.12577626012987, 40.20081512389645, 40.01341996654388, 41.203027771365264, 41.402346934041674, 47.07719287564678, 52.90772553413145, 56.742815125373106, 59.0863371664478, 56.0704698870259, 55.942953632723906, 61.599662534652225, 55.96868830342447, 52.820570468902595, 55.093536915317664, 62.86386205304054, 63.70147243622811, 47.848962353121856, 23.15707337471747, 6.4878110924074734, 9.152567405854503, 17.217214453604914, 21.81657591173726, 1.9556397127528347, 0.7514875141843673, 0.31307041044196776, 7.9604801727879435, 38.60194721529561, 58.670036408209036, 52.508722428352606, 42.982081520941954, 51.48205772522957, 64.9815889327757, 51.03971635141681, 11.323538499493754, 0.48217573954213055, 0.1351379864518681, 0.18058218422435945, 0.11426173045390076, 0.09489214723749508, 0.09794964244769466, 0.21081506274640563, 0.15689842282764374, 0.13803678654855298, 0.24216379429544174, 0.1273997782939865, 0.09856478806825415, 0.2007051076619856, 0.13562943185529402, 0.19660016341555506, 0.12228190493319305, 0.07826748003642406, 0.14655291102826595], [0.014093180408611173, 0.015161154855553423, 0.057562015680295814, 0.071753901729901, 0.02816336860339488, 0.04431064811445052, 0.027939785842693625, 0.04601730814864559, 0.03953205211268317, 0.025441494597602757, 0.06262325599128682, 0.04981166502881435, 0.06257166380002614, 0.064724930111439, 0.08660329040139915, 0.039743844780229756, 0.010903328187733648, 0.07867054187602575, 0.024822005258512594, 0.05044749502332942, 0.05757039668218744, 5.933704232015918, 31.11014173876855, 46.511496882284845, 46.37451202638688, 28.84868156525397, 24.526004099076797, 39.66095970522973, 40.67410792073896, 17.933468664846114, 1.92122042419449, 0.047818867324460904, 0.24230371259393232, 1.9849702163088707, 5.93727162768764, 6.803823709487916, 3.63295637311474, 4.034003524049636, 3.896299403521323, 13.845901989167738, 30.28787566769508, 49.58860020483694, 52.91332667873752, 54.33598602971723, 51.173751584945194, 52.90453664718136, 52.634410858154304, 48.84675841177664, 46.16887392536287, 39.74984845807476, 34.990103244781494, 33.6174698029795, 33.55940303494854, 38.85993326863935, 43.599952882336034, 45.761021952475275, 47.56186446835918, 51.54995787528254, 52.5545435567056, 49.797897877231726, 46.12037774055235, 43.195070143668886, 40.944751462628766, 44.05519885401572, 46.28120668472783, 48.803074975167554, 52.304869005757, 52.95964202573223, 49.466885136019805, 44.82730565532562, 37.604935630675286, 37.05325426593904, 38.425369954878285, 38.128246491955174, 36.81287180992865, 37.023204988048924, 36.71264348491546, 37.53608626704062, 35.962552947382775, 37.42606378370716, 36.77306367504981, 38.43048864795316, 39.30591067960186, 39.351410173600726, 38.52383713568411, 42.37819733158235, 48.43348180094073, 49.17199350172474, 50.24862135610273, 44.83555832216817, 52.765822026037405, 51.04349359389275, 50.232214081671934, 47.742387633169855, 47.150352924100815, 48.8320573683708, 44.73179201925955, 37.80711420120732, 38.03538437812559, 38.17246729327787, 36.791439979307114, 36.86272905718896, 37.21216909347042, 37.98824925576487, 41.31821993858584, 48.89970648673273, 50.9829439655427, 53.76631275300057, 52.58079598026892, 49.85237567655502, 47.79965816005584, 41.04830203517791, 39.68705131161598, 41.90583413647067, 44.9187361040423, 47.29627686162149, 45.37602955295194, 43.73463138457268, 38.912092947190814, 36.78188508556735, 36.15918920886132, 36.333311065550774, 36.1126071406949, 35.60398947808051, 37.42393001433342, 36.72680324123752, 36.61302704964915, 37.405208541500954, 38.072439009143466, 46.60052684045608, 49.75674829175396, 54.00385149063603, 54.56086335643646, 55.97789018384872, 56.534333305974165, 55.33548831939698, 51.36151544509396, 51.80175835086454, 54.433449083758944, 56.6041789516326, 38.07068963204661, 16.092990598370953, 3.6543842813661023, 8.840178078220738, 12.523534701716516, 10.82042980578638, 0.9369443465144405, 0.0738292875429315, 0.09325690191960143, 6.007858601308638, 30.08556962013245, 46.86930333414386, 41.74869614262735, 39.113337993621826, 45.75697014408727, 55.679401736105646, 35.26074286430113, 3.7019160534105, 0.15734197241404366, 0.04491703735003549, 0.013639432276719281, 0.042139447684730255, 0.018648958779991637, 0.06388224488604935, 0.06696941451199594, 0.07901970176927506, 0.07289011737391835, 0.009102438381242176, 0.08851381409312449, 0.019717542266833688, 0.011965922782227639, 0.021468531978767247, 0.01870933416930418, 0.03824777465554015, 0.056467069192759456, 0.01818094034529021, 0.04750145411479378, 0.03861316412146534, 0.032659764626934644, 0.03505115021741198, 0.003289786714782578, 0.1132352415832781, 0.03312677948645527, 0.017491558889648127, 0.055441281292587526, 0.05977796713611292, 0.0503871426166546, 0.052694101487436605, 0.03526048374272162, 0.06266396590358307, 0.006565598549411422, 0.034807924962332176, 0.017133387887189468, 0.00607591993626087, 0.06443652865146438, 0.05887443920777691, 0.0115704222304386, 8.36234219612614, 38.38026662026682, 53.59855298073062, 49.56329307248516, 32.18504571145581, 24.805743617396203, 45.834331050995864, 45.94707173685874, 20.512911465860185, 1.8578154329330692, 0.04187552273393639, 0.1657452827860271, 1.0941693066589295, 5.839770820833022, 7.461502715464562, 5.330845742456375, 4.809027833323325, 6.1106276416009475, 17.95211169027513, 35.69739680136404, 51.310901180390395, 54.93535949337868, 54.3662118142651, 53.68779866926132, 51.579230523878536, 55.37089555494247, 51.049416372852946, 49.67899122545796, 43.74602979229343, 36.911864588337565, 35.62348758020709, 36.86630233641594, 40.946532218687, 44.38325805048789, 48.68951843630884, 49.66822431933496, 52.63190838598436, 53.67427825927735, 50.62560819810437, 47.86809959719258, 44.21718097502186, 42.781213022047474, 45.975104916480284, 48.06889749342396, 49.413725253074404, 54.25898990323467, 54.67372955814485, 52.33651468830725, 46.21592667794997, 38.160778630164366, 38.96168739564958, 40.62200315536992, 40.2034156553207, 38.921063407774895, 38.37772100202499, 37.68609731428085, 39.643097231465006, 37.27897882461548, 38.87623071670532, 38.71503306973366, 40.99067065023607, 41.62802050190587, 42.09777924322313, 40.040527466804754, 44.36147320655085, 49.77348504527923, 51.888430964562204, 53.35439328224429, 45.97565797067458, 52.277989002966116, 54.04252213816489, 53.03043688497236, 51.31005394843317, 49.89549429185929, 51.08607876685358, 46.181872660113925, 38.506861117578325, 39.81710141704929, 39.0524039729949, 38.591450952714496, 38.72053615508541, 39.217414163774066, 39.04163706687189, 42.22134567076161, 51.29012046321746, 52.76703011605048, 54.56090258013818, 54.61816133991365, 52.70958700487691, 49.452678311255674, 42.869580099659586, 40.47652636804889, 43.2514581372661, 46.89456732042375, 48.47443526790988, 46.29983402067616, 45.40161517358596, 39.572110176086426, 38.673287283989694, 38.74562755707772, 38.00236586601504, 37.35113866867558, 37.29943790743428, 39.54375143974058, 38.06271545348629, 38.169874606593964, 38.89885887022942, 41.36789675681822, 50.26985314584548, 53.62220487286968, 55.70150036965647, 57.061778345415675, 56.434818852332334, 59.19186069119362, 56.86196496409755, 52.9486946905813, 52.18006703161424, 57.514867013500584, 58.98653245741322, 42.710288724591656, 19.30405462941816, 3.780272997194721, 8.129881456975015, 8.312887972401034, 8.494974201725375, 2.286047305791609, 0.12735259493873005, 0.1373549223306679, 6.811470860435117, 32.396585018404075, 52.47764156710718, 43.37926464696085, 42.187530917506066, 51.89777405031266, 63.40579240552841, 40.69138203897784, 5.653962752511425, 0.11723156222292494, 0.03622983011507219, 0.013026622266718938, 0.008016763472809427, 0.05171116854574892, 0.05171794076299956, 0.06088581837473377, 0.01664280241745855, 0.020440455390921524, 0.010756621392624033, 0.051699117982699994, 0.031199666160729625, 0.017924563275770317, 0.04268083819037965, 0.04379038248331316, 0.05231493009975361, 0.08991456755827512, 0.012745528327932042, 0.17349110585787605, 0.12065137105603373, 0.14202908522659732, 0.16765829626350634, 0.09796982120362022, 0.15278810064398474, 0.1422314090473998, 0.15667757500083218, 0.226238634317152, 0.10706944421174065, 0.18370394655052694, 0.17956956920604553, 0.12799304444342852, 0.1526346225892344, 0.22189827125159003, 0.13682745547304231, 0.09561931023434286, 0.12209243606776, 0.13214535590621734, 0.12657856268267478, 0.3167699103153521, 9.247356384031235, 43.99300967493365, 59.707977925577474, 59.00017446087253, 40.451709531968646, 33.63351621935445, 50.157069313910704, 51.38686180114747, 25.06306286781065, 2.4253407216841176, 0.18988246098160746, 0.8094828828207908, 3.7702270717390127, 14.195294957007132, 15.059245036494348, 5.441433537390925, 7.366413675969647, 6.057002957790129, 16.677998381276286, 33.43902941673033, 54.39116985567155, 58.90036582946778, 56.7953670409418, 53.24895604964226, 54.735597102872795, 56.92689980230024, 53.78173943488829, 50.97779781587663, 44.548978190268244, 38.42101220161685, 37.837520414783114, 37.71533858391547, 44.317625030394524, 47.8585760824142, 51.43351447197699, 50.69969392591908, 54.38990685247607, 57.77259811278313, 54.90220762068226, 51.75887900014078, 47.77368814714494, 44.73509465494464, 48.39617613823184, 51.14509474846625, 51.23901590224236, 55.2228182361972, 57.42984964001564, 55.165453572427076, 49.27973316561792, 40.02725416614164, 40.81801575999106, 42.61784238200034, 42.06714945454752, 40.51649139773461, 40.246671553580995, 39.8914695555164, 40.70829922153104, 38.79635557051628, 41.587255308705, 41.12583944874425, 42.51344065512381, 44.360978987909135, 44.78866246438796, 43.88045334046887, 45.30932180343136, 53.167276613173954, 53.980164297165416, 54.04555805267827, 48.93112859418316, 52.98137195648686, 57.52093099778699, 55.76616456431728, 53.7930162491337, 51.94120645523072, 53.14184788734683, 47.76977754408314, 40.732649295560776, 41.88084471610285, 41.628118561160186, 41.10616091758975, 42.62709917560701, 40.90202508434173, 41.228946793463926, 44.709179555216146, 53.91597470929546, 54.15703181297549, 56.25166377713604, 55.49648984786003, 54.744728380633944, 51.98349745042863, 44.57367735524332, 43.426156582370886, 45.29060425296907, 49.191511215702185, 51.47432281124977, 49.12358360905802, 47.772687942751, 43.739754000017726, 41.05306771493728, 40.625325402905865, 40.799788505800315, 39.392026316735056, 39.10419494875016, 41.97014531781597, 40.11929258223503, 40.846751043873454, 41.2768820793398, 42.40427717085808, 52.32850520841537, 55.1990290611021, 58.55431864338537, 57.84770365684264, 56.240418341852006, 59.71053138855965, 60.5453686560354, 56.547422255239184, 55.44875460286295, 60.41681689600791, 61.16676230584422, 43.72209548950196, 17.915006068445024, 7.436442692433634, 16.382859637660367, 19.71549753219851, 16.121362082419857, 2.740169763565064, 0.22310919578998323, 0.44856608334568243, 8.223551579060095, 39.70033245701944, 61.33049772631738, 53.25052107534101, 52.38406165953606, 59.868732344719675, 71.20260530902495, 47.48500954720282, 7.392737682788604, 0.2484899185477726, 0.11188931703086823, 0.1337437523949531, 0.10481775092381625, 0.17768188259534298, 0.1243346605089403, 0.18226298113023082, 0.09845988764878243, 0.13303807816438137, 0.09262464955569276, 0.18470284859499625, 0.1467188609944236, 0.09991546236579457, 0.09753775527520527, 0.10763158420881919, 0.10984883418366795, 0.2954548314934777, 0.08654404882221453], [0.0702947723649202, 0.14070963667285058, 0.015670521928357984, 0.032801418114573724, 0.03720775284173508, 0.050143078495297706, 0.03199037423567667, 0.024953462115879503, 0.05689281489579909, 0.045216880333159244, 0.029981331636888847, 0.044949366260440125, 0.019669217440570076, 0.017935732837706324, 0.03644401680738215, 0.08056693890642735, 0.045552124239264, 0.08254939825424264, 0.02504651307038242, 0.023159019896880757, 0.059642350421317165, 3.016847871964978, 22.366115662359423, 46.183531822696814, 47.91735672181653, 40.67746154723629, 43.481618896607436, 37.54273076211253, 43.06316867951424, 23.801263839967792, 3.495874193406874, 0.21721479272650135, 0.051635590141579035, 0.2794775162493029, 3.6210328580871707, 7.451783572473834, 5.835792066589479, 2.7677364262842366, 0.9999802672574598, 8.403278012429515, 23.005326678675992, 36.603346640063876, 52.8139808870131, 52.69806308131064, 50.21177853307417, 55.01434818390877, 47.21759019359466, 48.082461049479825, 41.230927590400945, 35.887019864974484, 36.2501960415994, 37.29171868293516, 41.95846842181298, 46.53719625165386, 49.54486185504545, 50.74709576945151, 49.71128409908664, 46.26870609098866, 49.99840944044052, 49.98313180861935, 48.02972086014287, 46.20973325544789, 46.75092227997319, 45.84920860105946, 46.845541615639966, 51.24402084658223, 52.00603538943876, 51.21392057787988, 51.09098565193915, 44.25902482002012, 36.867224093406435, 36.20723039873185, 37.95753317494547, 36.89511606770177, 41.71611301360592, 38.971006947179, 37.474916904203354, 37.45614444055865, 36.42113293370893, 36.281963317624985, 37.19775438308716, 40.91642802761447, 40.76145518210627, 43.235949085604766, 43.43113014774938, 43.067404839300345, 48.170388821632635, 49.36245203018189, 52.81676184746527, 42.34382560176235, 52.90018281629009, 50.17717146104383, 48.04067604003414, 48.0247002263223, 44.21085811430409, 43.05305680921001, 38.43033175314627, 37.310812780934, 36.90699692695372, 36.10067136826054, 37.73993184489589, 37.00937863319151, 34.6215965670924, 37.71001984996181, 41.50548565772272, 49.41670625440536, 50.12601590925648, 52.57874065829862, 53.0984547061305, 50.073667956936745, 48.64722744111092, 44.63387789264802, 43.831498238348196, 45.22290414379489, 49.19144845777943, 51.03574691280242, 51.1949598404669, 49.02402208697412, 50.43472997603878, 45.856386538474794, 41.46329664414929, 40.72919760980914, 40.56082987016247, 39.673122975134085, 39.01989144663657, 36.91577126902919, 37.21918229133853, 36.01267299344463, 36.50137678269417, 37.84209782077421, 46.271926356900124, 48.17132626810382, 54.24211978912354, 54.44381590812437, 55.91966652101087, 56.34333349043324, 55.242418319948264, 52.92909460683023, 56.953403257554584, 50.42373165007561, 35.151249900940925, 16.362026949082654, 3.354973831484395, 3.629078619903134, 6.712242249519595, 8.562528202610633, 3.230717557091867, 0.1379156986912412, 0.17474180568129788, 7.8778574062931925, 32.19398479307852, 41.867320383748705, 34.593908556046024, 32.793579870654696, 44.83016898555141, 50.398353915060724, 28.503575748012913, 2.9325365251110447, 0.11236822923585293, 0.05071015592904822, 0.04393014373377927, 0.038451691939225124, 0.10840544026465186, 0.011197703218297854, 0.051560318172578855, 0.04008434021905546, 0.0598172482944304, 0.03860322796108742, 0.06395181716089288, 0.027747534162875627, 0.010888724636677052, 0.03314417351277606, 0.08204550392204717, 0.02724316294094728, 0.02702623939952783, 0.02697081485342595, 0.09197647788471754, 0.08798666899242709, 0.03792695618504959, 0.07514125141765803, 0.06536589289504675, 0.013964798436650347, 0.032414562865010196, 0.01962497777816269, 0.00889673707030353, 0.056058196576252106, 0.04229342369663139, 0.03631629845908573, 0.06113982631734783, 0.02086280157879716, 0.05868164552075248, 0.0302508739273875, 0.03402012610627759, 0.029018175254966465, 0.069960918908398, 0.018538774269062187, 0.06364477295128089, 4.4974926017945815, 27.444504422526208, 53.76046842144382, 51.73437987604449, 43.06313730055287, 38.96041654771374, 42.49411513728481, 48.51761271876674, 27.10741396873228, 4.054621217712279, 0.0923899355374517, 0.051387994354891206, 0.612828235232061, 3.605608137384538, 8.562977313995361, 7.0075069992773, 5.339935835330717, 2.8787863254547124, 11.89097700580474, 27.111010782180298, 40.83421122643256, 54.55711357055172, 53.84753327215872, 50.726299362797896, 57.35652485201436, 50.07537026559153, 50.575033157102524, 43.5073967133799, 37.52295417170371, 38.21189888062016, 38.652945872276064, 43.26586108053885, 45.177361503724136, 50.69546561087332, 51.05190315554219, 52.17508169912523, 49.03052929908999, 52.37352617325322, 51.991314734182055, 49.516267776489265, 49.684247201488866, 50.204667275951756, 49.41981669395201, 48.480299211317494, 53.81680150185862, 53.753188502404, 53.780833367378484, 54.17380386783231, 46.00085135429136, 38.19920609074254, 37.81938337510632, 40.14163832510672, 39.37323424123949, 42.42665037032097, 39.624650324544604, 39.824004788552564, 38.944009273282944, 38.06236244017078, 38.92455431722826, 39.22202687109671, 43.197101931418146, 42.978904401102376, 44.8641877020559, 44.996763813880186, 44.737852081175774, 49.53861744173112, 51.41497342817245, 52.71668257251863, 45.02937047712265, 53.25450620343609, 52.31916604503509, 50.28641731508317, 50.72014516399753, 47.318167609553186, 43.93448398959252, 40.771319943089644, 37.74638806619952, 39.527787393139256, 38.32659290682885, 39.78492621452578, 38.72792197811989, 37.012202739715576, 39.27006021622689, 42.40893694662279, 53.81112583221928, 52.631061154027144, 53.915774668416674, 54.641056214609456, 53.4173983143222, 50.700552924986816, 47.37483016906246, 44.77575786652104, 49.504041748662154, 52.23735324798092, 52.767500800471154, 51.98312482526226, 51.25233234897737, 52.381680780841464, 46.266897878339215, 42.23846289419359, 42.30227201215683, 41.15482968668784, 41.86782636950093, 40.36980259803034, 38.221183130818034, 38.74050886400285, 39.111878871917725, 38.96027142001737, 41.55386809379824, 49.63828879017984, 50.648569753093106, 56.6196370124817, 56.63467930209253, 56.49319940997709, 59.43313352523312, 57.497337941200506, 54.90640455676664, 58.89622772893598, 54.964173224664506, 37.82654954541115, 17.19825763856211, 6.961326974053537, 5.965033183174749, 7.3840104091552, 5.944308850073046, 2.8384163110486926, 0.1209270018303106, 0.19888402473542, 8.356156618364396, 34.703511345771055, 50.43544384741014, 41.77492503196963, 39.2754142515121, 50.72982557358281, 59.05131432317919, 33.69737240575975, 4.4441733725609325, 0.035675745532517476, 0.04719969208141969, 0.04207312362268568, 0.004521562969462285, 0.06393753345154467, 0.0037278693062328407, 0.04249787724186336, 0.08025373151946454, 0.011951184208174388, 0.02419909725206033, 0.008937424957571972, 0.02230156449631097, 0.009180606162596134, 0.0643644780821858, 0.04009432234470883, 0.015575810478279188, 0.03655462075145014, 0.030314072350701018, 0.10181563620966289, 0.2288586550181912, 0.12026563812527927, 0.12492359060073092, 0.13281494739555544, 0.15437100683489155, 0.15132122613008947, 0.20305699758952667, 0.13081584095714555, 0.13834455471125343, 0.2062807721836913, 0.19380657783439084, 0.10730863218345951, 0.08253612195051487, 0.14494158297536835, 0.2815490486400743, 0.06690207538345168, 0.1947005717985092, 0.17701938508018372, 0.12005072747988087, 0.1903430177199264, 4.950352791816958, 32.65348065283991, 61.23314057627032, 60.1073105104508, 51.89869188493299, 55.3975990510756, 46.58434706349527, 53.95853634803526, 33.20421672636463, 5.590596372081388, 0.38297829308336784, 0.30260034806786046, 1.916797461528932, 11.310055352026417, 17.70763820217502, 13.217209789060778, 5.880845390981244, 2.9195461253966055, 10.832144944898545, 27.051173064016528, 41.78803751545568, 54.08236949674545, 52.9865102614126, 51.78433910492928, 60.082540742812625, 52.126275647071104, 53.56328695051132, 45.67671845036168, 39.035682908950314, 40.17991673561835, 40.938597263828406, 47.54561408873528, 49.754277198545395, 53.40736096905124, 54.83830436583489, 53.39908084561748, 53.31808782392933, 53.77534597150741, 53.676698361673665, 53.029519050352036, 52.099870251071074, 52.24928902041528, 51.62537720895583, 50.95121591321884, 55.974383584914676, 55.401301768518266, 55.07596469694569, 57.23419789345034, 48.46140907656763, 38.84771116318242, 38.75473137824766, 41.83578060519311, 42.84745400951755, 44.82711738155734, 41.75073185274678, 42.558179209309245, 42.158901537618334, 40.017028547102406, 41.215010612241684, 40.668432251099624, 45.604491926008656, 45.4726492974066, 47.076475081905244, 48.16597615518878, 48.15205174107706, 51.774007581895404, 52.61470094803841, 54.06276941299439, 46.488856961650235, 55.94567967999367, 54.96735818924443, 53.33807229995728, 51.393804396352465, 48.44402513196392, 45.627724124539284, 42.52594909360332, 39.082727816797075, 42.73010846107237, 39.91683944579094, 40.645078459093654, 40.721023390370036, 37.98053395363593, 41.43305909249091, 45.25703268666422, 55.71600137218353, 56.24683141708375, 55.521997021090606, 55.799583158185406, 55.314888031251975, 52.05471592564737, 49.50264146251064, 49.83864738095192, 50.62178388718636, 55.16078595192202, 55.73485228323168, 54.71307877571353, 53.09470492024576, 56.050783511131044, 50.392007520121915, 45.8934647037137, 45.51717604360273, 44.59427372101815, 44.881061738537205, 43.40528565068399, 40.78846070074266, 41.67093515396118, 39.85346571091683, 41.08993799455705, 42.004403298900975, 50.608573344446, 53.466804489012695, 59.70853490214194, 58.38077337511125, 57.19742175071471, 60.49925727228965, 60.61094676294635, 57.22075985323999, 62.94840874210481, 55.93374782992948, 40.89280359206661, 19.294644863374774, 6.6706960143581515, 12.197763227647352, 13.96352896767278, 14.94056195982041, 8.199312802283995, 0.6224031085448881, 0.47464926276476155, 10.600146555131483, 42.86353180485387, 54.17995806663267, 47.80880512729768, 45.80750596138739, 58.775171618307795, 66.47046181463426, 38.51699259973342, 6.857197361607706, 0.19874559264750252, 0.10696197739772259, 0.21644585495514257, 0.1551477433813195, 0.21361051758210506, 0.08154525616837126, 0.15374705886408208, 0.27496415520867995, 0.16428207017240987, 0.1222827016646343, 0.11442967224866153, 0.09590517594328812, 0.12703203310769412, 0.18254300158831382, 0.18480355851352218, 0.09490016051718304, 0.05375501834937642, 0.1366485739427228], [0.08711243243587595, 0.029954482170362628, 0.05297044472348306, 0.04549664032134799, 0.04601845728053201, 0.007278825449306639, 0.05874503929648669, 0.056152885043693174, 0.05602723513279231, 0.006480617373580895, 0.053925166477359114, 0.01946224346606722, 0.010642003147832809, 0.020348607194459727, 0.03662063071744577, 0.0029210044369627273, 0.1136570419335077, 0.04579554101632488, 0.1082708079728388, 0.07715932619307311, 0.14600897328026835, 1.2471059517514322, 14.756141920243541, 44.22941876995949, 50.721059076247684, 35.236322187608295, 28.856681239220407, 32.69077258725321, 37.00427562959733, 25.974076486402943, 7.622406674969581, 0.4336774709724611, 0.20701249340368857, 0.7587318254574653, 2.5573142593906772, 4.3498472340645336, 5.294221101268645, 4.2561398494628175, 0.44222826859162706, 3.899883224118141, 13.503679114003337, 33.66271826528734, 46.60373141688686, 46.768008124443796, 53.86384248733521, 51.014173876854684, 47.01215997818978, 43.33757769676947, 37.250263152583955, 37.08548438164496, 38.47570573129962, 44.719252201818655, 46.697479986375384, 48.17466420512046, 48.8021767523981, 49.278407404499674, 45.24191194964994, 46.795590231495524, 48.57153746389574, 50.052204747353834, 50.75563869168682, 48.304345607757575, 48.44293471305601, 47.71355429003316, 51.18877426270516, 49.08986299268661, 50.56746690504013, 50.60534523379419, 47.71135776273666, 42.341762435051706, 37.934359811967425, 36.25842517422092, 38.035164725395944, 38.181033749734205, 42.68868038731237, 42.302130806830625, 36.400979795763575, 38.8293230918146, 36.17461196837887, 37.54903008860927, 39.1140361755125, 42.69792541380852, 42.415126446754705, 44.4211716805735, 42.7354311173962, 45.96447137094314, 47.04478625328311, 51.31679258038921, 51.46438352523312, 42.51584899040961, 53.35686829782302, 48.51692238161641, 48.982013502428615, 42.56034043527419, 38.214962251724735, 36.81964574321624, 37.3166924138223, 36.67348254111506, 35.588233317098315, 36.08688031473468, 38.181798611917806, 36.711870777991514, 37.801414997346946, 38.678453045506636, 40.6456236685476, 48.06839150767173, 51.543988027880275, 54.39003629069175, 52.67917294656077, 51.976856877726895, 51.20111403926727, 46.82667501511113, 49.42118560114215, 48.181120426424094, 50.802691444273925, 53.032496129312825, 51.8491994180987, 52.857421136671505, 49.22386684725362, 50.28645653878489, 48.71588460860714, 47.120558600271906, 49.776791603334495, 48.24512958526612, 48.391281020256784, 46.611584001971835, 41.525980041873076, 36.60324858080956, 37.67176889604138, 37.63007410110966, 43.09947021545903, 46.98059274304298, 52.30680665662212, 57.194738849516845, 55.79877514992991, 58.12066924187445, 55.55028515477335, 53.999423134711485, 53.180969607445505, 45.85892038960611, 30.167853101607296, 11.811091073097723, 2.9706462737052672, 5.63882093275747, 4.081023426786546, 3.968142516190006, 0.8482911810278894, 0.18149879310400258, 0.28482998871514875, 8.529818577151145, 34.851859308058216, 40.28371441748835, 29.977833878609445, 31.436808493829545, 50.36093450361683, 46.37210369110108, 21.551566854599987, 3.081686857246584, 0.04627081430366924, 0.04402629159871609, 0.018876232169268113, 0.06047916741320684, 0.09212169751164415, 0.004383263031711742, 0.07747155298749286, 0.06636699361185874, 0.06451322937444334, 0.03396686384334199, 0.026040540880433498, 0.019334586404804743, 0.011164681955931649, 0.04942945227207196, 0.012316431947833589, 0.06550180455369335, 0.025250922565558748, 0.13998975917216272, 0.09207924091888052, 0.05411005030656534, 0.05057435535315064, 0.001292499256387894, 0.013192063742016834, 0.003086744207746139, 0.04021112010964463, 0.07851654288148688, 0.025330812129522526, 0.07392536262951552, 0.09511966002924789, 0.03808673531297715, 0.058680075040507707, 0.018364594603377967, 0.024848688100915284, 0.03152666121510969, 0.05027175062305985, 0.04370719299561555, 0.0336609649351768, 0.04054901851040702, 0.023253382776954004, 1.5745891726786092, 19.241230026368175, 51.31743584909747, 55.82766732861919, 41.65237057593561, 36.79642531179613, 40.30948438952046, 48.23210731629403, 30.833906858198105, 7.928046584129334, 0.3823540233556302, 0.05521171538519764, 0.8841908578911136, 2.188040513184763, 9.384002935501838, 8.49658335408857, 10.043470051980789, 6.1438197185916295, 5.638665508839392, 15.95520655955038, 35.38118708518244, 48.306114596705285, 47.67639375502064, 56.324870894032145, 51.79111303821687, 49.92590050543509, 45.24030770024946, 38.64433626974783, 37.33992461235293, 41.136367090286754, 46.15082317782987, 49.1913386314146, 50.68206679436469, 50.780177039484826, 51.21943935271233, 47.81428075605824, 47.892908588532485, 49.526097236141084, 51.02826303051364, 54.55463463260282, 49.93246263073337, 51.906348351509344, 50.92776406195856, 53.687873194294596, 51.313078095836026, 52.28402553066131, 53.27113313059653, 50.55997910038118, 44.27671470949727, 39.26347455670757, 38.798956101940526, 38.97861634531329, 38.16406557636876, 43.551256656646736, 43.28630447387696, 38.318736399373705, 41.605157006171446, 38.039832345901, 39.18547822583107, 40.13158529035507, 45.017709270600356, 45.98684457040603, 46.75254221885435, 45.01548136434248, 47.427452687294256, 48.913022933467744, 52.61177878226004, 52.99280174316899, 45.31070640010219, 54.90402367807204, 51.02137927086123, 51.05653939708587, 45.0207491074839, 42.0194612779925, 39.440946117524184, 39.062849244763775, 37.988896446843306, 38.15019607543945, 37.887691451657204, 39.39627424363167, 38.76493346306586, 39.315226308761105, 40.20020323414957, 43.22065968667307, 49.133644488550004, 52.88746649219144, 54.131081411915446, 55.37259001885691, 53.843457929549686, 52.00800834163543, 48.49769884540189, 52.39711138509935, 50.82184045545517, 51.90281821835426, 54.78162219447475, 53.996108731915875, 55.489355056516594, 51.21763506243306, 51.62412205050069, 50.3321482289222, 49.366190048956106, 50.95323201148741, 49.66262709709906, 50.548325738599225, 47.097546054470925, 42.84510058741416, 37.56363699513097, 39.13068271452381, 40.28399290577058, 44.96648311614991, 51.08752612144717, 54.78081026384908, 58.218198976209095, 55.58218186901462, 58.58547402966408, 60.054891955467966, 56.22780792174801, 57.44863779314103, 48.20131671044135, 31.79433841859141, 11.570798831601298, 4.560979104811146, 5.711317120059844, 3.4308788036146476, 5.528527315585844, 1.0247609439876773, 0.16609867914549767, 0.3766985784374899, 8.876796345556937, 39.056071389106016, 42.34455124024422, 33.85839354607367, 36.42813044209635, 55.72849019881218, 53.268964059891246, 28.92903327941895, 3.63360601567453, 0.055208957468670224, 0.04143100404631227, 0.04596925911403472, 0.08784539471831053, 0.05568106298244769, 0.03153999880587142, 0.07187103657352348, 0.015453578277130522, 0.009487322869620497, 0.05387104619594832, 0.015580554477750294, 0.035228177814954714, 0.05290714670873938, 0.03353192125477138, 0.06540599759788283, 0.07009218807422346, 0.02493632281379354, 0.06661214940850774, 0.19145180741625448, 0.08976933260959002, 0.12606568980000674, 0.15145653257927588, 0.12661898914243908, 0.12904881319451716, 0.1197910083517913, 0.21729806648387065, 0.12202541103526471, 0.14550566883577457, 0.19845087862303182, 0.11737382475046382, 0.09028396749448392, 0.10902890560006905, 0.1530791374464189, 0.18520868112964017, 0.26237236636300243, 0.11981259670949752, 0.24707617989230543, 0.188446122732374, 0.2772544823106258, 1.8569048301827524, 22.962763078751106, 58.25925442480273, 64.18982713453232, 48.09436152058263, 43.46954584121705, 45.228458219958895, 50.13400577729749, 35.34765474257931, 10.53884187052327, 0.5541364007419156, 0.5729432464126618, 2.247721581689773, 5.178623949327777, 9.708615349185083, 17.06729950443391, 10.286386359122492, 4.829308448299285, 5.855444121745325, 15.80348437832248, 36.123542708735314, 52.82816025518602, 50.961743554761334, 56.697978511933364, 54.83391915598224, 53.30203356281404, 48.61516598732241, 40.32403246048958, 39.93918518866263, 42.69588970368908, 49.14426234460647, 52.1085229996712, 52.59928211089104, 53.419065321645434, 53.977151916873076, 48.231322842259566, 48.095903012060354, 50.58262686575613, 53.22319392235049, 54.52719373087729, 51.99058909570017, 53.642095212013494, 51.980512526727495, 55.28730200183008, 52.45107535393008, 53.60095739364625, 55.73934339707898, 51.82266850625315, 46.44450672211186, 40.26360050324471, 41.61142103133663, 39.71689662625713, 41.706546352755645, 44.4043682467553, 46.25207131908786, 40.35259516008439, 42.68005901767362, 39.83967857976114, 41.04092797925396, 43.235270515564956, 46.00641719756588, 45.63216424757435, 48.967202632657944, 47.490457719372166, 50.02708981114049, 50.98535230082851, 54.33396208670832, 54.83215016703452, 47.63482447593443, 57.851206333406516, 54.2928478025621, 55.013167550486905, 47.66621912679365, 42.38903484036846, 40.69721852579425, 42.76863005853469, 41.24673081982521, 39.33318684178014, 39.42871224495673, 41.48370865852603, 40.6403245464448, 41.71691317712107, 42.4477997902901, 45.930142787195024, 52.00436445974535, 57.198088553644, 58.3724775621968, 55.43620301831154, 55.570720703371116, 56.34615367458713, 52.510738526621175, 54.39574333929247, 54.00909962192659, 55.360101192228264, 58.68038754309378, 55.48020808927475, 57.37818810247607, 54.817845283016084, 55.93710537879698, 54.744602864788426, 51.3409936043524, 53.53363775437879, 52.962003292575965, 52.94308177886471, 51.25384638386389, 45.677797102159076, 40.27704246582524, 41.57000472468715, 43.141231690683675, 47.283580149373705, 52.38946276326334, 57.39115938063591, 60.749708452532374, 57.22707879158759, 57.38915112710769, 61.357793500346524, 57.881655693054206, 59.599030171671224, 49.704482709207845, 35.197565247935636, 13.444297371372102, 5.979278741344329, 10.070407909731712, 7.297474588117293, 9.86903146389992, 2.9186711917000436, 0.6805523076365072, 0.773106821842732, 11.161656398927013, 46.50709990532168, 54.17545126330469, 41.006473879660334, 44.89681397714923, 65.97016349915536, 60.45161224180653, 31.636108044655096, 5.1319840262013106, 0.19632968841300857, 0.1839218219561923, 0.13579435526363312, 0.13742963122504373, 0.17322121308215205, 0.07720386654499077, 0.22685875184834006, 0.15799829526053322, 0.08731531550086315, 0.09190168472067003, 0.09420124318210349, 0.1547200824584692, 0.09922177741123785, 0.0823204298954337, 0.12748300608608032, 0.1255643618623576, 0.12153733641870561, 0.1978132483218947], [0.11479812223584422, 0.05872484904924228, 0.005778906211602472, 0.04862277317912348, 0.06868719048197232, 0.03695290986328356, 0.08198097633618502, 0.05644396398096316, 0.06758378638375191, 0.01780122886562059, 0.0803004552219664, 0.04630880460383431, 0.03635579412202201, 0.06387548799055719, 0.027544538099919597, 0.04874310643982984, 0.09054685056570078, 0.022332219504601052, 0.04103518556803465, 0.02245394896054941, 0.06841447850268695, 0.27460939521270417, 9.067997182569197, 36.718715313942205, 47.80232929414319, 41.28473858679495, 32.46253967285156, 30.988807139858125, 41.56745518407514, 31.312000636131536, 10.950087674202459, 0.8799887736958842, 0.06119686922418976, 0.3750476283171485, 2.031145583718054, 10.408114175642691, 3.6271919598502502, 9.646888029190803, 6.463387964233276, 4.113677403619213, 11.629087213547, 25.45264247925051, 41.593644849715695, 52.15177105319116, 50.88008373014389, 49.15274643128919, 46.957733169678725, 42.680031561082416, 39.60907851496051, 41.956585684130275, 45.43880316518968, 46.87128413108088, 50.883402055309666, 50.759357098610174, 50.831163929354766, 51.5975832939148, 53.6124538606213, 52.800872325897224, 53.64289929789882, 49.88239749785393, 47.73416634528868, 50.40713217950637, 50.23182968939505, 49.44806560393303, 48.83178280245874, 47.372610107544936, 50.997982332783366, 49.11051819401403, 47.259281066156205, 46.47892159800376, 40.21739498261483, 37.633710138259396, 37.98662147214336, 36.04398135216006, 37.43286909595613, 37.93465791210052, 36.44768737977551, 38.28292908207063, 37.09330951013873, 38.18282235053278, 39.913022979613274, 45.04463241946313, 47.60596367620653, 48.766043878370716, 47.34754223977366, 47.88494617708268, 49.721403814131214, 51.02637637046076, 52.47433500905191, 44.168504361183416, 52.09457897370862, 47.225368253646366, 47.50919095931515, 41.24575022728213, 39.41415240687709, 37.80536090174029, 36.73419690901233, 36.76523462418587, 35.23323528228268, 37.4066755079454, 35.18986563528738, 36.205924249464466, 36.19562802776214, 38.39360660122287, 40.24879747821439, 46.28346596994708, 49.634758657024754, 49.862919007578206, 53.58658975170505, 52.07944254721365, 50.876506528546734, 51.04954188869846, 49.30897443525253, 50.53857864872102, 53.39659406292824, 47.06353518270677, 48.14514836957378, 52.739440164258404, 53.653270044634425, 52.341551011608495, 50.33371717699113, 50.6238901999689, 49.99689540555401, 53.04750311759211, 51.16770329013948, 50.8070727317564, 47.77617885220436, 46.7599594208502, 42.42062168736612, 38.58795219852079, 40.682125245371175, 48.88257749619023, 50.236316880872174, 54.64046001434327, 53.06675018802766, 53.219550040460405, 60.280416473265625, 58.9058885266704, 49.47459651577858, 38.33350412307247, 20.878248868450044, 6.636805265180527, 5.589360335180837, 3.9250778334756053, 5.361696654750455, 2.798932016857209, 1.185565802358812, 0.08363087691607014, 0.4104410742800082, 9.362306344893671, 35.56542865691647, 45.79135756338797, 41.52922384200558, 39.242125095859656, 50.240627565691554, 48.360400199890144, 18.350093018624094, 1.7561018779393167, 0.03237116015366009, 0.05194069231830297, 0.0871526750345384, 0.025523818405945937, 0.05064709923200069, 0.06494907977720422, 0.05653888227478151, 0.03433530233920582, 0.03380050402014487, 0.046952138429567705, 0.06657121733071343, 0.00604273300738104, 0.036995481369235826, 0.03774486857676699, 0.03611357627256263, 0.03390145908680654, 0.0314872881262413, 0.027204149913403298, 0.018683988150329362, 0.042775281509684945, 0.10023461459504981, 0.016065150097523247, 0.12699289367564265, 0.05246350902222818, 0.014800733469817189, 0.011350563614659253, 0.04711670177658239, 0.05329780558484697, 0.03809793551843013, 0.03134466745259781, 0.08258712808451346, 0.05514849397924639, 0.03346932804091804, 0.05066349734401992, 0.047137734720543514, 0.012433991012644145, 0.03345780607853686, 0.024251436379047173, 0.05561983340509957, 0.4274599933095517, 11.831065743200242, 43.4682632261707, 55.10965393435571, 44.72628893390779, 37.373417731254335, 32.43857202991363, 44.70168390581685, 35.57492471510364, 12.612281268642796, 1.0224479713266896, 0.014822157118619691, 0.501642493350852, 1.2076486238548834, 8.091026458048052, 6.734009933087134, 9.737507527874364, 9.236572807834996, 6.923582496181612, 13.202921575115575, 30.439881240167928, 42.41217682438512, 54.21858949045981, 54.0261423203253, 52.833482911509854, 48.79204134787283, 45.74707400414252, 40.056624873991936, 43.317087234989295, 46.55378003274241, 50.4137727522081, 51.54432142934492, 52.50099535911314, 52.47724540771977, 52.515817995994325, 53.73736173875871, 55.43525380472983, 53.16575081117692, 50.4219901177191, 48.794069213251916, 52.77414137317289, 52.31190573784613, 51.62513402200515, 51.20008637828212, 48.25121318140338, 52.22013404292446, 53.28352782034105, 50.22811912721204, 47.339560216473, 42.329155937317886, 40.08479533656951, 40.108290333901685, 37.741802815468084, 39.12220647258144, 40.71767760861305, 37.92752312075707, 40.98417912760089, 38.70687846214541, 40.151361880763886, 40.28353398846042, 46.42784057124969, 48.27345694265058, 49.91341167880643, 48.50593582276375, 49.63739841215072, 50.86183686410227, 53.0907747053331, 52.882936154642415, 46.98979462346723, 53.60350301188808, 49.98981552739298, 49.90336648879513, 43.47893599540957, 40.03839369743101, 39.94864202314808, 38.30647507021504, 37.91691703181113, 38.420894530511674, 38.20470133135396, 38.072439009143466, 38.062942950956284, 38.13554994521603, 39.61038858659806, 42.01790801940426, 48.87394828181113, 52.352368908543745, 51.04791018270677, 54.91980337327527, 53.37541326399773, 53.248948204901914, 52.243421154637495, 51.93279689358127, 54.02451845907397, 54.9165125047007, 49.38693546479749, 49.71187245461249, 55.61446297553278, 56.65564829303373, 55.47947460605253, 53.48824416437457, 54.01934485281668, 53.5308724834073, 54.56111046575732, 53.71156038776521, 52.48263082196636, 49.82153015751993, 47.879807872156945, 41.870709311577585, 41.10043425713816, 42.71480729503017, 50.19937992095948, 53.10481286817982, 57.83549724086639, 54.25162761442123, 54.34111256753245, 60.48733718933598, 60.123564812444876, 53.13049262569797, 42.38587341000957, 24.334835621618456, 7.505083680152894, 5.574487688079958, 7.463909089565278, 4.314661122137501, 5.942701658894939, 0.8119597982975745, 0.04215570407048349, 0.550575501495792, 11.278994102631847, 41.958440965221776, 53.31189047905707, 42.23434048314249, 42.79716137916812, 55.97146534150647, 54.66718704469743, 22.177226081971202, 2.6201077286274206, 0.06984704759933295, 0.046755338102699294, 0.025203382979417523, 0.04989283204439187, 0.013309429369626508, 0.03999975645133565, 0.03494747170817948, 0.058345999418487476, 0.03694660495966673, 0.025976670214966423, 0.04750188312403137, 0.03831582624585398, 0.029668966946642727, 0.03855050195969882, 0.054061407553813154, 0.03971918440994717, 0.031731244995288795, 0.04116689523441657, 0.2728875053505744, 0.16642227468471374, 0.15573861167555855, 0.14487645018004602, 0.3235503706720568, 0.25251037861791353, 0.15859300931615217, 0.12082720355641459, 0.1375738396159103, 0.16945723924906025, 0.13745849741803062, 0.1786095844281297, 0.11317030030993686, 0.22117382786687345, 0.1128055964927039, 0.13518683221792022, 0.1428664346495944, 0.08489790973403762, 0.11919630195705161, 0.09122779547807672, 0.10890220997915154, 0.6043479483454459, 14.320016522561351, 49.84212260092459, 61.35938598263649, 53.05197854195872, 42.41738573197396, 39.760074077113984, 52.68915930101949, 43.02739274117255, 16.29554375525444, 1.3601580983208073, 0.2722680466550012, 1.0643996202176618, 5.212625015166498, 23.321222605243808, 12.289224074732873, 16.230997231698808, 10.64228653907776, 7.2145870616359105, 14.899177032132304, 30.459810803013465, 44.885446948389855, 55.84824408254316, 56.49916925737935, 54.8858081909918, 51.47900219886534, 48.49436875312559, 43.52809898314938, 47.0640137118678, 49.03022727658672, 51.820181723563906, 55.42641278236143, 55.07884763902234, 53.300311642308394, 55.046966614261756, 55.98662530222247, 56.1372874629113, 55.17137635138727, 51.42033923056818, 49.07587189828196, 54.63632191381147, 53.6799656960272, 52.01641005854453, 52.44147339174825, 48.48679465632285, 51.99862995455342, 54.0878176689148, 51.72238134568738, 49.806064251930486, 44.87650786676715, 41.16989158814953, 43.25137184512231, 39.823789058193086, 40.49003501092234, 41.30875918173021, 39.183026744473366, 42.98196384983678, 39.447798498215214, 41.77325410227622, 43.395228693562174, 48.390100386834916, 52.74646512923702, 53.511127271959865, 50.141556339879195, 52.135120591809674, 53.9447452945094, 54.54702131209835, 55.835453233411236, 48.367531068863414, 55.67477333930231, 53.558909585399014, 51.64582844703428, 45.47401035985639, 42.16192568502119, 41.95204357947073, 40.31657995716218, 39.7969090554022, 39.24759680225004, 40.331943881127145, 38.810970321778335, 39.58695242481847, 41.32364065416398, 41.857945919036865, 44.907659330675685, 51.20475007641701, 55.43893691032164, 53.861147819026826, 57.13267126391011, 54.575003500907656, 55.54125978100685, 55.37349608636672, 54.19750675078362, 56.374763442624, 57.1094233758988, 49.36333064110049, 51.372376488101104, 56.5307011911946, 59.4077322559972, 57.958800869603316, 56.22969850417107, 56.61089797173777, 55.57813006062662, 56.74332111112533, 55.61569067739672, 53.61056327819825, 52.35307101280459, 50.572052155771566, 46.70202993577527, 43.09246486233127, 45.321881232723115, 52.25337220776466, 55.113572382157855, 58.83071630231796, 55.53015162867885, 52.88035131269886, 62.67333684429046, 62.22317818672427, 53.40463492178148, 43.68269135875087, 24.470904604081188, 9.220582285235006, 12.00923744709261, 8.855559652851476, 14.590243312620348, 10.59068089531314, 2.508677604698366, 0.2674838582113866, 0.8881050156008814, 13.671261399022995, 47.97806716734364, 57.869747377211056, 51.66248283078594, 51.15402598534861, 62.427623887215894, 65.31740265507852, 27.555680082690333, 2.9035578091298384, 0.19969206363443406, 0.16612854125278612, 0.1705650177093283, 0.17398737761522495, 0.19043482569677217, 0.13994747111874242, 0.14262980541154263, 0.07127433068930142, 0.23448091300745166, 0.11497783880200117, 0.2332877463871433, 0.14493815090146758, 0.11967479281367795, 0.1612361199072292, 0.14811456594015324, 0.162127478528888, 0.19741497453181975, 0.14108924856109006], [0.035766423529674934, 0.07753497740674405, 0.03211528295651078, 0.0406874505983245, 0.046691208882557775, 0.02783661295149115, 0.04964999366371382, 0.018613910257455804, 0.011103100935748268, 0.0474454224440119, 0.018679843614659002, 0.022523396746105245, 0.017519879244988965, 0.13533010598151915, 0.02844743975137751, 0.029294619997662884, 0.08049606045167293, 0.016435535414324656, 0.07354519149709134, 0.0091115883438878, 0.013983016965099642, 0.05719128275109876, 5.27337811646923, 28.276839217832013, 51.31512949543615, 44.105836652940326, 32.863231358989594, 33.606585225751324, 35.489930875839725, 36.025683495306204, 18.12601585542002, 1.7654150556172095, 0.09092608707085734, 0.10710599426660808, 1.0822798672222322, 2.8549449338066966, 6.092388130003407, 9.452513994709138, 13.851873797755088, 5.50277058155306, 8.833871887576196, 26.454419743630197, 41.88299809732745, 51.8837986453887, 51.04346221493137, 50.66456517865581, 46.876187093796275, 44.601781137527965, 44.191108980486476, 45.966993454963934, 48.08754444122315, 50.05810791446317, 51.78211119867141, 52.42785884488014, 50.63973657546505, 50.263424381133056, 47.4106139521445, 50.483983178292554, 51.14678529001052, 52.00212870874713, 48.49294885512322, 49.55677409325877, 52.05613582364975, 50.587867152306345, 50.74877846625544, 48.822824108985166, 49.25482611502371, 50.24733089631604, 51.63082538112518, 48.05456907518449, 46.37502977924962, 44.08391452604725, 37.39468089995846, 36.67287457373835, 36.67201949704078, 35.999097670278246, 35.63854163692844, 35.439226396622196, 36.6662222339261, 38.360737139178866, 40.736963902750325, 45.57041437395158, 50.67026046014602, 50.2304058690225, 48.12898035972349, 49.29007253339214, 49.8048443948069, 51.598595265419256, 51.13370418548585, 41.963987196645434, 53.01048378790579, 48.68289747545796, 47.52403320804719, 43.02021088138704, 37.52960651151596, 36.36673750415925, 36.695734147102606, 36.29063567807598, 37.605900533737675, 37.042777615208784, 38.41469326326924, 38.1402293328316, 37.487393963721495, 37.61415320058023, 38.803596265854374, 40.119080774245724, 48.95041096595026, 50.474192942342455, 52.084737746946274, 53.083608535028276, 51.26311886695124, 52.50314874033774, 52.48039899333831, 52.27523157673498, 50.42569283516177, 48.7579284944842, 50.8614367823447, 48.60599548585954, 50.47216899933354, 49.19581405578121, 53.488452049993704, 53.01125649482974, 53.94380784803822, 53.99895245029081, 53.51715203254454, 50.79857295559299, 50.93712675955988, 48.79794451498216, 48.90677067541307, 45.72016654476043, 45.16360575152982, 47.97641584950109, 52.364241923055346, 54.1335956511959, 58.40576671784925, 50.442280538620494, 55.60449623292493, 55.86910324711954, 47.918298090657885, 27.49128064801616, 14.86596828506839, 2.7156784842091226, 3.1488709295949633, 3.3684356510639195, 2.6005552036146966, 5.479886003078954, 0.49589809030294424, 0.09265327826142312, 0.7963574064835426, 11.010584350555174, 36.3031284270748, 29.07074655255964, 27.776682107679306, 46.159283730291556, 52.43356589348086, 44.706649626455004, 13.414913915818738, 0.4531185148704437, 0.04911861592723478, 0.04662450560699067, 0.05494170769628498, 0.05441043721211534, 0.01220876020529578, 0.0665371340789622, 0.027051382405202717, 0.04010775569646109, 0.05861677319532441, 0.04633513887623145, 0.040090480413768566, 0.03276718547567725, 0.032828836401383725, 0.007955487930185853, 0.06624146244458615, 0.024961661171889114, 0.01220741284815895, 0.016830802309296785, 0.018768037571721984, 0.14986185927785214, 0.053131510879123406, 0.07388892748783674, 0.042323404547548106, 0.02111679419965273, 0.027648701159764203, 0.02243125169057279, 0.02420021190999016, 0.10757049635773706, 0.04246316962845383, 0.039937450520453915, 0.029410241817634915, 0.0372794701627666, 0.0682623411018041, 0.0060928399456785095, 0.09115772907652202, 0.035135197723584796, 0.08915691426204098, 0.03861453158841018, 0.005186230428667078, 0.13703947796696617, 7.165466239375453, 33.95704115590742, 57.08022525233608, 50.213010157308275, 36.904874924690496, 37.84296466458229, 41.33114807067379, 40.642917233128706, 21.015598504774033, 1.7513174443475663, 0.05319906834272608, 0.20230606288438846, 2.2177409452776757, 6.53103365052131, 8.843725862041596, 10.173882976655038, 11.079653366919487, 6.1125407776524945, 13.273370285188, 29.70121264457703, 45.049515770327666, 54.043792986100726, 51.66105901041339, 51.16907219732962, 50.07184405480662, 46.69359683990479, 46.89681091616231, 48.63790004484115, 50.84110321537141, 52.64427954150785, 52.73823991898568, 52.362300349820046, 54.08725676998016, 53.16020850212344, 50.491345467105994, 51.97358954337336, 54.70814835640692, 52.90244602387952, 48.45309365180231, 50.56427409571987, 52.29387067979383, 51.530636279813706, 52.14983340232603, 51.19845074992026, 51.137238241011104, 52.19931802441997, 53.97060155868531, 49.83675679852886, 47.95911035230083, 45.879097061772505, 39.60282233453567, 38.21116931976811, 37.51618023841612, 37.30906340383714, 37.96704100024316, 37.698444935583304, 37.9083074292829, 40.12115178569671, 43.87772337082894, 47.439859144149295, 51.24759020343904, 50.87066219698999, 50.907579545051824, 49.76817807843609, 51.40792885134297, 54.04704463097357, 51.305429474000015, 43.581121583138746, 54.851126593928186, 51.170131237276145, 49.44006396878151, 44.66824962246803, 40.75870560061547, 38.727772928053334, 38.66684675216675, 38.62685818825999, 38.38275340295608, 39.3018667159542, 40.029293798631244, 38.36318862053656, 39.266192759236986, 39.18137542663082, 41.084026982707364, 43.10201975607103, 50.57665701835386, 52.85884495704405, 53.5161518281506, 55.238139014090265, 53.599270774472146, 53.96238811554448, 52.463352372569425, 54.712066804209066, 51.646640377659956, 48.86758227502146, 50.71031962671588, 49.240148605838904, 52.46095188202397, 50.141983878227975, 56.12360231338009, 53.672956420529275, 56.12144108741514, 56.750091122042754, 54.87500206116707, 53.56342031109718, 53.64659024823097, 52.233670142389116, 50.153213624031316, 46.449582269114835, 46.592011374811975, 50.68305523164811, 53.70381762904506, 57.14285373687745, 58.6366609604128, 52.1909123851407, 57.24438821115802, 59.11540585179483, 49.62158733798612, 32.348610508826475, 19.254001263649233, 5.187908689821921, 6.0263363968941475, 10.129273860685288, 5.685689333946475, 4.494448842540864, 0.8619181078768546, 0.05898312027115495, 0.9608368515487641, 13.152979016304018, 40.75100598796722, 36.32543494624477, 34.768838420990974, 50.5585317457876, 58.618892623532204, 53.21894991782404, 17.845950780376313, 0.8283266845730044, 0.06559093888368338, 0.033781884253145225, 0.01644541028766863, 0.029016899718572537, 0.049646201528488636, 0.011958763690575237, 0.03565428740975838, 0.043527786695067926, 0.029231063428244768, 0.010609469308908428, 0.01103399788975836, 0.08943102818222777, 0.04186338024033655, 0.018267569567767844, 0.03829714902226002, 0.04301362295424746, 0.012778478727165251, 0.06203457104763197, 0.19650604185317794, 0.3208743029784772, 0.18509404373265084, 0.2557788314598222, 0.1467148160501834, 0.0871010790128381, 0.1651571111212815, 0.10669641301877077, 0.05966833995414838, 0.1388437222809561, 0.08670068315921292, 0.10972390822585552, 0.12500873361263545, 0.1353732673751731, 0.1277054320540159, 0.10777661997464397, 0.22773989085708896, 0.0738152374904002, 0.17820386426343074, 0.1255488102774947, 0.0938371445743307, 0.21377513455527447, 8.132506993509109, 38.98682586608395, 65.0514659573955, 58.33034346180578, 44.63664708598968, 44.82880007836127, 46.57472941183275, 47.40655822138633, 25.62680748201186, 2.7790828626002035, 0.30533558839271147, 0.8661220306831022, 4.400538475282731, 10.502625646129733, 14.362037854809916, 18.134956898227816, 25.599566621165124, 10.410337178937851, 11.94602550998811, 31.570339702790786, 46.331483625596576, 55.585257007229714, 55.0642878009427, 53.9279418606912, 51.11826573648761, 49.25838370477, 49.720740933572095, 51.60576535809425, 53.91651207400907, 54.71223938849665, 55.25520916908018, 55.10825364820419, 55.06202851572345, 54.68208812898206, 51.479080646268784, 55.436281465714984, 55.40244710060858, 53.969985746568256, 49.28505582194175, 51.4254657683834, 52.68240890195293, 53.62713921454645, 54.132077693939216, 50.587882841787035, 51.355027844828946, 54.90925219751174, 56.48006339227, 52.17463847129576, 51.69938448936709, 49.40941456825503, 41.09549207072104, 39.76536535447644, 40.2452398884681, 39.28114875670403, 39.708620425193544, 39.50038963748563, 39.5333924601155, 40.49617744261219, 44.52223154806322, 50.33131668644567, 54.89337052068403, 52.66213024816206, 52.5739828232796, 52.397119229839696, 53.91162872314454, 54.952515940512384, 53.62365222746327, 46.55432916456654, 57.30928382565899, 53.19907526816092, 52.40127694222235, 48.38046312332154, 41.93683655031266, 40.559610013038885, 39.695531475928526, 39.46392336199361, 41.06103797112742, 41.12579238030219, 42.76075393922868, 41.675936175930886, 41.37448633870771, 40.42209171479748, 44.33201228418658, 44.813977441480084, 52.863912659306685, 54.92666359870665, 56.3414115290488, 56.725576308465776, 55.19475367761428, 56.110348624567834, 55.554497780338416, 56.60071942114062, 51.52517634053385, 49.15980669759935, 51.40783079208867, 49.792441860322036, 52.12932725106516, 52.55573987960816, 57.79992526577365, 55.18363375817576, 56.93677633039413, 57.33397514589372, 55.76771390053534, 55.164688710243475, 56.158036801122854, 53.906839509164136, 52.14083156278057, 48.86590742295789, 49.67360973358155, 53.18697083380915, 57.094687031161406, 58.34367167565131, 60.25155567353772, 51.27513308678904, 56.86805640497516, 58.47689497855402, 52.80005647290138, 31.699038551699733, 19.392360910292595, 4.392327483623259, 4.706372541766013, 11.210067272186281, 10.280054673071831, 12.734706286461124, 1.9211194231625528, 0.3448821808541975, 1.6322417629341928, 15.995623642398467, 47.025892196163056, 40.77937256905341, 41.37534533777545, 58.036499100346724, 67.42420965625395, 59.580822529331336, 21.062790501502253, 1.082788059307683, 0.19236142957402816, 0.15165542432617757, 0.2156737915450527, 0.1346651569850022, 0.16949122290938132, 0.19614958114201025, 0.1468322726507341, 0.13108320564271944, 0.165721426808065, 0.15132634359742367, 0.132400723654897, 0.1731336339106483, 0.13007691851066006, 0.13798230237537815, 0.11888389130153003, 0.2173113198049607, 0.10924197763444916, 0.2549314309632586], [0.019255763618275523, 0.028399128331652576, 0.04473743186662755, 0.006947543175380317, 0.01719015691759846, 0.033800274193767584, 0.014917098395075771, 0.003054223057153004, 0.050350029487162835, 0.09297299739574233, 0.01052888164732365, 0.007859837543594862, 0.01853116510075427, 0.06667512949676284, 0.035143034803050185, 0.04733380343344423, 0.03774718216229831, 0.008232941993722513, 0.02191698069744293, 0.03712842060673622, 0.044469036792795506, 0.06226633945780416, 1.253488015743994, 14.717985103207251, 42.253818973418205, 45.65511795782274, 38.18533266744306, 25.31072328167577, 39.01822051694317, 42.51620592609529, 26.607349034278627, 4.127685658393368, 0.15475938276898477, 0.1105300855312136, 0.7783770164655102, 5.631418929946038, 5.997038252892033, 5.615176395062478, 4.660603875114072, 6.977036556889934, 13.995215835109835, 26.316758278877508, 39.927904452047045, 52.92943585303522, 51.86042524153187, 50.324401547831876, 48.86393054839104, 46.45985103422596, 47.24923979851508, 49.11605265832717, 52.28051108698691, 53.441544425102975, 50.02708981114049, 50.23402229432137, 46.35874802066434, 48.51030142076554, 47.467068626034646, 47.6334124226724, 49.867555249121885, 52.12107458422261, 51.62985263332244, 52.28449229271182, 51.451408324703095, 50.08708638529624, 49.0499803327745, 49.715924263000495, 52.46150885858844, 51.238145136064105, 51.13487697416737, 48.353124203220496, 50.21136668420608, 49.99395362792477, 42.785292287026685, 36.91987014585926, 36.93168432481828, 37.96841382980347, 37.17926433009487, 35.05532049363659, 37.72549360029159, 37.01324216781124, 38.598158205709154, 46.582919320752545, 48.311515700432565, 50.96164549550703, 50.587278796780495, 51.34626526986399, 50.704961669060495, 52.26241327101185, 50.44734824088312, 46.57679650091356, 53.156686213708696, 50.62453346867716, 48.441518737423806, 42.54455681770079, 39.78192952371413, 38.746023716465125, 37.692059316942775, 37.03187342612974, 35.41380551553542, 38.81901118063158, 40.269978277144894, 37.34333707440285, 39.15570351385301, 37.14495535819761, 37.43312405001733, 39.94195438200428, 43.84586588028939, 47.20427374685965, 49.629549749435924, 54.04579731725878, 48.97510620855516, 50.4787625035932, 52.203860129079516, 53.28706579823648, 52.081325284896366, 54.02944103364022, 54.20157424865231, 54.91048774411602, 48.374752152350645, 51.402504213394664, 53.18053422435638, 54.090057342283195, 53.37924149728591, 54.74904691019366, 51.92686234751056, 53.284888882790845, 52.10246293775497, 53.19172474645799, 49.84356995551817, 51.01577420388499, 50.12854583801762, 49.884029203845614, 53.053108184568345, 56.01727470274895, 52.92726285995976, 50.079375005537464, 54.03082955268122, 47.31603384017945, 35.89080495219077, 23.376273070612264, 9.132202459919839, 3.5356207961036317, 8.20964579620669, 11.542052761200937, 4.628046731795035, 3.1794950798634565, 0.42569995226879276, 0.06854467514541841, 1.0773517768229208, 12.030149563666313, 40.20781263228386, 41.260113946853146, 29.79441208224143, 39.317917054699315, 50.616622048039595, 34.56358471224385, 7.2138565201913165, 0.24812477039954356, 0.04390165292387528, 0.03439160980164044, 0.047771182181614066, 0.00639681980359338, 0.09664866427380232, 0.05053202516489452, 0.025919179146688794, 0.01498490387964393, 0.07180745893668744, 0.011800125076044953, 0.019845180175898057, 0.02945982302809435, 0.025538749459590164, 0.0777644130791868, 0.05085154894679304, 0.0407057945736714, 0.0916518864311999, 0.05763185608591284, 0.02387458432255493, 0.014434153694779643, 0.011450042046846883, 0.021572269859813878, 0.03533492067588433, 0.12750199740572324, 0.01159949813999476, 0.05345186203598015, 0.04579698126162252, 0.05990955039798733, 0.013640736541410368, 0.012689569435502975, 0.05814243836568729, 0.03341279458254576, 0.058179241229569724, 0.008683688018561132, 0.08028795266704214, 0.029648447281590877, 0.036405762206883206, 0.022651417699131756, 0.04612916081603016, 0.02035516490709157, 2.0292869931267155, 21.343498845254224, 49.58186941762125, 50.10929092284172, 41.73463836792977, 31.63584916822372, 40.71488488105036, 47.846824661377944, 30.1844721840274, 4.721581532109169, 0.14248317618283535, 0.21139367363385617, 1.2077647014971704, 5.776881988971464, 8.278451523473187, 9.772512720477197, 7.0154630368755715, 6.679562532132672, 14.640431019567675, 28.39544188591742, 42.01145179810063, 53.22831261542536, 53.76717175206831, 52.10915450126895, 49.54921176356655, 47.49537244919808, 48.78105086665, 50.023104683045425, 53.962517553760165, 55.480047272097686, 52.40391277497815, 52.03821059196226, 49.09378536285893, 50.3141406274611, 50.27823525090372, 50.12727106771162, 51.57728110590289, 54.89243699658302, 53.798515412115286, 52.59498711555235, 54.696059611535844, 52.76329601964643, 51.968906233387614, 52.50594931264078, 53.151842086545884, 52.20581346942533, 53.44668273002871, 51.281165692114065, 52.993186135445875, 51.54894198140791, 45.30352846268685, 39.02198991467876, 38.76989918370401, 38.02169530622421, 39.49178395732757, 36.6163218405939, 39.67557837886196, 38.80931115919544, 41.814639029964326, 49.61154607034499, 51.29121088212537, 52.11157460366526, 52.330438936910326, 53.29179617666429, 51.96205385269658, 54.66183300941221, 51.56731436329504, 47.30069345043552, 55.316586417536584, 51.97094586587722, 51.921014093583636, 45.10463683835922, 41.41090946812784, 40.40453910827637, 40.577174386670514, 38.19081614094396, 37.40870729569466, 40.36886122918899, 42.340907358354144, 39.554914505251, 39.723560733179895, 38.27257794718589, 38.67441692659932, 41.22078826350551, 46.57126988134077, 50.61402936135569, 51.295984406625074, 55.650003571664136, 51.39638139355568, 50.763867824308335, 52.632837987715206, 53.556732669953384, 54.08591139701105, 56.299073465408824, 54.60127161395166, 55.41002904215167, 50.17834424972535, 53.52632645637759, 54.66046410222208, 56.27064412639987, 54.22433184039209, 55.821799462841405, 53.86998884139523, 53.17383089373189, 55.19935854019658, 54.25152171042658, 52.32460637246409, 51.46066511830976, 51.49110271084694, 52.15757616104619, 55.58901856022497, 56.44575049800258, 56.192279092727176, 50.63262531834264, 56.390849082700676, 50.352301366867565, 40.29770158952282, 26.66733776369403, 11.24776811369004, 3.4746791758844933, 7.389436027696056, 7.696751769511931, 5.991236577110906, 5.272246022378245, 0.33135104563928425, 0.11613915148641794, 1.582787784357225, 14.707320178708724, 44.41888101639287, 42.33407851188414, 35.49714019221645, 46.2920206592929, 58.30522852559244, 42.54648662382557, 10.553549778076912, 0.6939716553015094, 0.09202992017831534, 0.0688575684363323, 0.02682785710109578, 0.06281259462177273, 0.012703698012046518, 0.006243946958303211, 0.0236501109846417, 0.03621895549698703, 0.023066122159962694, 0.030896293427494746, 0.014739416749967683, 0.02700101978506052, 0.02210122101279276, 0.06023468577393121, 0.08765221798732396, 0.15585252894989907, 0.07649483684931072, 0.06607139858627512, 0.12571993899802048, 0.09820001530310801, 0.10557793997107975, 0.1026655801181351, 0.08123136696315582, 0.2770391196733521, 0.13496547877307863, 0.18753008075779487, 0.21044203921431498, 0.20902220249897052, 0.0736059116259698, 0.10509895115730264, 0.2542393318107051, 0.12237493098983843, 0.17236144792649055, 0.13312544283126632, 0.1297184966144062, 0.11993963706998095, 0.09997330200407775, 0.08158374442568711, 0.15162105762189435, 0.17938463558112422, 2.1306699658593824, 23.825829644357007, 56.258994686988096, 57.2936257239311, 49.6980147207937, 36.50560509773993, 50.685706753884595, 54.94829547020697, 36.52646818468648, 6.24228984117508, 0.287602246408501, 0.7332928034086382, 3.423184829373514, 8.495926357084706, 14.730228781700136, 18.126043312011227, 14.137794971466066, 12.093135964485908, 17.725792892517582, 31.821322364191857, 43.68440543451617, 55.864408170023275, 55.03041421213458, 55.87310014232513, 53.00112893504482, 50.90946620510471, 51.77162670320081, 52.95404088112616, 56.112305887283824, 57.13616217336347, 53.660475438640965, 54.22918381229524, 51.272560011956, 53.583153755434104, 51.794152875100416, 51.497441261045395, 52.208425767960094, 55.70388517072124, 55.24774882101244, 56.787028081955455, 56.797779298597774, 54.56048288652974, 53.374240475316206, 54.578251223410334, 55.633890474996264, 53.53359460830689, 54.820355599926366, 51.367469603015536, 54.211807712431884, 54.37688850587415, 48.086238291955766, 41.39599269436252, 41.62090532241329, 40.395270547559186, 42.602929530605195, 37.489370838288345, 41.776862682834754, 40.23359044905632, 42.284876300442605, 51.46760771351477, 51.61429259084886, 54.86454109991751, 53.30435952832622, 57.25267225696195, 52.517790948191, 55.33413117931735, 52.37550304782007, 49.62736891162012, 57.67441334262971, 54.440026898537916, 54.929675978998986, 47.017121776457756, 43.83528724793465, 41.81869868309268, 42.23940818540512, 38.82549093615624, 39.352681021536554, 43.56210985491353, 45.201040852454405, 40.832257886086744, 42.09075820061469, 40.05673862272694, 41.210531265504905, 43.03644557153025, 49.2782622768033, 51.331854481850904, 53.10774287869854, 57.91831808705484, 52.78029164960308, 52.3294936456988, 53.320653054022024, 55.87934063326929, 55.289125903960205, 57.62166138618224, 57.435901857191524, 57.91029684005245, 52.18358147528864, 54.76921181524954, 55.94332625789028, 57.945908038846916, 56.380137089760076, 57.37210842870898, 55.16879543181389, 55.19214922381986, 56.584088571609996, 58.00128406093967, 54.40343118483021, 54.35750415248256, 54.96783279603528, 55.17676568800404, 59.1110324090527, 59.559088676206535, 55.53934174199259, 51.56870680470621, 56.929939639183786, 49.667934063942205, 39.059621134111964, 26.805016879112493, 11.855739412769196, 6.294815280745107, 15.304105858648978, 21.051699999840032, 13.906228042417958, 9.43416710822813, 1.7527782820886182, 0.3641270449565303, 2.034760538128115, 17.527426865793046, 52.13768974427254, 53.487793091804754, 41.91868774352535, 53.42946352497224, 65.29701809729299, 49.86473506496799, 13.316137848361848, 1.0718625423408326, 0.25284100684427446, 0.11011382399667656, 0.15929713604911683, 0.13051049363228584, 0.20640915319804223, 0.09815787280639333, 0.11106288436079219, 0.12298675944968579, 0.09223536197696963, 0.16007085420912312, 0.0914896673132335, 0.11816250460763132, 0.10579347880857606, 0.1832657442578385, 0.19241839587207765, 0.2644454922166563, 0.16895384287401555, 0.11285420477149949], [0.05781621514489094, 0.07091652932426623, 0.04017018037097108, 0.08006474528942378, 0.04252966606028138, 0.050563699070123896, 0.06318599353694627, 0.09287271648645402, 0.02603312706454627, 0.010324121666921964, 0.07302844220952642, 0.02569095580838621, 0.011434775829735783, 0.03337404202489603, 0.017779904808248245, 0.0396648534543572, 0.02090338508658592, 0.05700159172016767, 0.11791225432628587, 0.02515812250485103, 0.013417495647445323, 0.012690546197606432, 0.49932492416231866, 11.131490430524273, 40.86744154653242, 50.568965250445956, 38.280265792723625, 29.28142489925508, 32.54689024340722, 39.33494406361734, 34.733748897429436, 7.89118169776855, 0.3596732549128994, 0.09424003787458905, 1.344776646264138, 6.982104749448839, 6.578088854589771, 10.397381590258691, 6.089388497414128, 5.780915166101148, 12.293142522535017, 23.85302932031693, 36.99233985716297, 47.17530312076692, 52.552225435933764, 52.6664880014235, 50.44717565659554, 50.745609191156205, 48.75308828969156, 52.217713940528135, 51.50363860591766, 52.20372676849366, 48.36097678830547, 46.29154213013188, 46.13218015240085, 44.46971885619625, 42.45898246765137, 44.559278334340746, 47.10812860919584, 49.38502527052357, 51.35130551553542, 50.98964337379702, 49.49755414839714, 46.21759760764338, 46.420109579640055, 47.88204754552534, 50.60833407986549, 50.64663602459816, 49.66325467632663, 50.455848017046534, 51.063803626645, 51.32357043604697, 49.337470454554406, 38.48281698842203, 36.26751722828035, 37.24010813620783, 35.608649253845215, 36.20626941803963, 36.11515668130691, 37.10254276952436, 37.19172570013231, 45.7349342684592, 51.95664490422895, 48.561982570155976, 49.26903686215801, 51.952161635121996, 52.589789975074034, 51.987553181186804, 48.22582367927798, 44.30237093279439, 50.00062950195805, 48.959714827998994, 47.94752367081181, 40.135335076239805, 38.19480911377938, 36.939964448252034, 37.14675964847688, 35.57859605358493, 36.4135431474255, 36.733902731249415, 36.42114862318962, 35.88855351171186, 36.217922779821585, 36.60939885723975, 37.450507994621034, 39.03875804716541, 42.47818639201503, 46.98023188498713, 49.934266921012636, 51.34818723124843, 50.353372173924605, 52.36369279123122, 52.59322204897481, 49.09351864168721, 51.31553742193407, 49.37885538224251, 51.7491985905555, 50.30160865476055, 52.21917306223224, 50.94061374664307, 53.29784054909983, 51.495746797130955, 50.69698749050018, 49.941150680665054, 52.941410849171305, 51.68012957419119, 49.6530016006962, 52.512107433811316, 53.8356053444647, 54.04783694974838, 53.379606277711936, 54.36989884222708, 55.88340028639763, 56.610533191311745, 55.97968662938764, 53.811996598397535, 54.42995032956524, 43.1984551491276, 27.893115705059422, 15.946554791542793, 6.100991848976382, 2.2442855854188246, 7.739023152858981, 8.46843054217677, 3.836420500470746, 3.7250810813519264, 0.2462411440548397, 0.07510706857447663, 1.570104677830973, 15.064962871613043, 36.214588765175115, 26.87968900126796, 29.532236937553655, 43.74263694209438, 51.55488829458914, 35.22379413727791, 7.309781024532934, 0.2811810812882839, 0.034041718294423436, 0.008051304462095423, 0.03360250476567495, 0.06833030076156701, 0.044917014367397756, 0.029479465522472898, 0.07248079659597528, 0.03762837341656128, 0.0795572886483804, 0.06284118502310689, 0.01971492033091284, 0.04115932245528506, 0.020549601852713574, 0.050229795817886634, 0.02707474042601403, 0.05702201562422899, 0.0557151768777159, 0.03595585026027214, 0.09202713161827096, 0.07787790134428971, 0.0416361662228742, 0.1009497500114864, 0.009833870403048013, 0.05000494901211031, 0.03236295535199104, 0.0441230982992678, 0.06112050174945786, 0.04778723555406736, 0.04272368548798465, 0.02933093448049359, 0.06017468193726194, 0.05382181355549444, 0.03130873984416887, 0.0584258794063522, 0.031637862707758625, 0.07611262792300794, 0.07319243865147715, 0.030802828785512718, 0.020490515406333634, 0.023759500679349708, 0.5077880506794299, 13.660252286541848, 46.25384423040575, 56.68718414921915, 44.630292846310525, 30.630298583738266, 40.65561002300632, 46.23377346223401, 37.114286345820275, 8.124206767928216, 0.46544974189131494, 0.10468999044068399, 0.5905887027901988, 5.045426141831183, 5.933210993966749, 7.733267074631107, 7.3310495864960465, 6.069815870254271, 12.726343793253745, 24.327894987598544, 38.66692912194037, 50.52511707428963, 53.732035160064704, 54.357645357808764, 51.99320923897528, 52.78146836065477, 52.211508750915534, 53.98787959929436, 54.310949540907345, 54.287278036917414, 51.900425572549146, 50.07961034774781, 48.31446532280215, 47.49834168341852, 45.76540323995775, 46.03805111300561, 49.17038140758392, 52.263672351837165, 51.881657031274614, 52.037041725650916, 50.2172423947242, 50.73921572777533, 49.79936484367617, 50.71044906493157, 53.49049560485348, 51.74713150147469, 50.78056535413189, 51.83440423780873, 52.76941883948542, 54.94678143532046, 50.62860488891602, 40.178194815112704, 38.665242502766276, 38.14039799474901, 37.570689416700795, 37.0130499716728, 37.12559061665689, 39.15319319694273, 39.33809372686571, 48.79659129727272, 52.82227277755738, 50.96210441281719, 52.08736181259156, 53.49200179499965, 52.24531565943072, 52.066106488627774, 50.068160949214814, 45.22594398067844, 53.77125101704752, 50.4217351636579, 49.73042918789772, 42.82406491618003, 40.15433111498433, 38.64582284804314, 38.899808083811116, 37.00329895942442, 38.44167132531443, 38.90304796157345, 37.16279822011148, 38.231699005250015, 38.17344788582095, 38.54732036590576, 39.105759974448915, 41.203172899061634, 45.73847224635463, 49.15005960772115, 52.41689974261869, 54.05001386519402, 51.47348342403289, 53.27694608319191, 54.649720730320105, 52.17254392562374, 53.09189650320238, 52.255494210027884, 53.60591134717388, 51.7195023259809, 54.011868815268244, 54.041765120721635, 54.18976791443364, 53.42504693615822, 52.55851299531999, 52.12724839487384, 55.681970888568515, 51.3927218221849, 50.492467264975275, 53.88186970064717, 55.76197547297324, 56.483632749126805, 55.738574612525206, 57.56041749831169, 56.23287170164047, 58.38288753263412, 56.01305815481371, 54.46120377509825, 55.381258456937736, 44.895625498987016, 30.989613186928537, 19.137442150423606, 7.15330591124873, 5.134709583174798, 7.334564030170442, 7.981961033036632, 6.617429737121829, 5.267527411060949, 0.4967076920213238, 0.027490580612192714, 1.4726958015272695, 16.749524762553555, 44.77347504708075, 32.11870862591651, 32.27365989838877, 46.777370822045114, 57.35672097052298, 40.604713347650346, 9.210358627380865, 0.23849092363830537, 0.07037772436536129, 0.04055058516021218, 0.03180131139684349, 0.0278460894591145, 0.03560507009106298, 0.0294529416433145, 0.08721729455095145, 0.018516019542491245, 0.0482242389191543, 0.027490145857295686, 0.039846355005377726, 0.10671604785227007, 0.05119295986068826, 0.044903190310804114, 0.03649691517855372, 0.024077509522377968, 0.026118011521776358, 0.03197681639463671, 0.138034105240818, 0.09766655763791454, 0.11019980204441857, 0.17204087077369615, 0.10669351720641698, 0.17643801627620576, 0.14645423890361864, 0.12375752817118361, 0.20136739067252607, 0.16654175375738453, 0.1984063995581481, 0.10655282515912287, 0.1032224877346908, 0.3139483472031932, 0.17459405796422114, 0.12836747757729985, 0.08345047853166059, 0.155750394107834, 0.1885063678867394, 0.1725114172985477, 0.08354509039030922, 0.0727397189926236, 0.8257365106574951, 16.680081159837787, 52.627440806358095, 62.89103231122417, 49.68440409629576, 40.0704159275178, 43.894165946591286, 49.18447840598322, 43.91191859399119, 11.143777255089054, 0.5967013489815497, 0.23355034600582816, 3.5970571252607533, 14.032118474283527, 17.58840991604713, 15.730354728237277, 13.63622090508861, 11.394336300511515, 17.92284688641948, 26.220542538550596, 41.06012405887727, 51.415769669317434, 54.82241484426684, 56.098150053331935, 57.289107153492594, 55.87565752767748, 51.72277750507478, 55.82414504020445, 54.752639801271506, 57.10238664380966, 53.08718573662543, 52.362245436637636, 50.24968431841943, 50.14490212163618, 48.18261092708957, 48.16652136464273, 50.250951243985085, 54.14870462109966, 54.31652715129238, 55.98324421913394, 53.738542372180575, 50.75188106106174, 50.6984152332429, 52.462760094673406, 54.26765834131549, 51.7257506616654, 51.72509562584662, 52.98985996553975, 55.258158791449766, 55.92171007587064, 53.918445802504024, 43.65836481894217, 39.9449275385949, 40.19609259020898, 39.70359979137298, 39.479350043881325, 38.35361803731611, 40.89652984373031, 40.866453109248994, 51.18381638680735, 56.126712752926736, 52.41859420653313, 54.3072860471664, 56.1705413172322, 55.04421703277096, 55.187112900518606, 49.73946632877473, 49.032161005081676, 54.307329193238296, 53.53358284119637, 52.00858100768059, 44.49169589627174, 42.29648259378249, 40.91793029539047, 40.24710693667012, 38.69060847067064, 40.92304898846535, 40.139029948942124, 39.04846983571207, 40.23944654772359, 39.79358288549608, 40.47138806312315, 40.863240688077866, 44.26350416675691, 47.655436531189956, 52.73890672191497, 55.77991247177125, 56.20459141269807, 53.20155028373965, 54.020494107277166, 57.26718502659952, 53.654929207217315, 56.25659811881281, 55.18974088853406, 55.20917231036771, 54.60319749770626, 56.366855944356615, 55.019761054746574, 57.118064357388405, 56.32814215075586, 55.451202161850475, 53.81419312569403, 58.94657919483801, 53.64003204530286, 50.658320765341486, 53.87388767734651, 57.34888407491869, 58.60648616667717, 58.87609028047132, 60.058888850673554, 58.13770017316265, 57.01903235527777, 57.09081565180133, 55.061161671915364, 53.885819527410696, 47.025817671129786, 32.053110907154704, 19.692653648314938, 8.322398739476359, 8.10150016700068, 16.233713473043135, 18.980019784742787, 11.322121543269004, 5.8083908788619505, 1.2855100006826463, 0.18223497295571914, 2.284103281074955, 20.43365017060311, 49.64478815755537, 38.221073304453206, 41.39662027359009, 57.508551997523156, 65.34978966559133, 49.18889891716742, 11.998301879052194, 0.4780739209344311, 0.09314481559539996, 0.08535175554213986, 0.1474300970233256, 0.2091261299867784, 0.21433750437873028, 0.11570126328977848, 0.21989545694762663, 0.11796419508755208, 0.1394982984469783, 0.105108680473941, 0.17581717862236887, 0.21252132441488006, 0.1488835496767875, 0.16500928679541235, 0.20301835611462596, 0.10451359103523916, 0.11148456213695389, 0.14097798195096756], [0.03892856251989161, 0.06206375516710743, 0.061395412401085904, 0.016646186610864058, 0.04142877473045261, 0.08587477908980462, 0.03275022428903369, 0.025222071694330345, 0.021285659130362254, 0.03867186177822371, 0.04270619570067333, 0.07162408813113166, 0.0933577650557122, 0.07322414703066311, 0.01142476880622487, 0.02226800026912843, 0.09048481276559253, 0.03101776624398847, 0.016725013227832895, 0.013856296446324598, 0.09583281127796059, 0.07854355514169702, 0.11868444797132285, 6.213222136420589, 33.06655722279703, 50.45667955952306, 43.929259392523, 32.307345213428626, 25.765982981651064, 42.914581452646566, 37.54331519526821, 12.5013635043175, 0.4776680169086303, 0.08311160719923436, 0.043951950426543915, 2.6211915285356584, 4.084150781554561, 7.027224263837261, 3.9070552779782206, 3.617570140669423, 7.5793253221819485, 22.08329708345475, 33.10811865714289, 50.20196084053286, 53.71229779335761, 48.66876517572711, 49.654044951162035, 51.351533013005415, 53.02895422904722, 52.077497051608184, 51.4078974723816, 48.21698657927975, 46.93255155317245, 42.74470360048356, 40.63051862101401, 38.07034446347145, 38.16549724148166, 40.05161600728189, 42.47540935393303, 44.66798682366648, 47.20261850664693, 47.58258634997953, 45.095960555538056, 41.45196491672147, 44.056434400620006, 48.02959534429735, 50.98223009417134, 50.50894906443935, 51.69386179216447, 50.27215165476645, 53.26392773658999, 50.62117199743948, 51.009718064338934, 39.803839883496686, 34.31161949711461, 36.523832351930686, 37.11650640733781, 36.26401455171647, 37.40735015561504, 36.864533347468225, 35.78349674901655, 41.56021841110722, 49.20264290225122, 49.075220784833355, 50.01489516227476, 50.34428796460552, 50.14240357183641, 48.6103218601596, 51.1130960526005, 42.4173935767143, 51.372078387968, 50.27446977553829, 46.21301235691194, 42.98994979550762, 39.46431167664067, 38.46097723130257, 38.59267865457843, 38.89707811417119, 36.70328078731414, 36.7010332692054, 39.234692204383116, 36.24290435544906, 36.38088157100063, 36.77908451326432, 38.751495422855506, 41.74134562092443, 48.373449925453436, 48.07618525720412, 51.4162285866276, 53.152497122364665, 51.478449144671046, 51.470019971170736, 48.03720866480182, 49.60731383292906, 48.6594573913082, 47.65315371174967, 49.4805153723686, 48.82320850126205, 50.45422023342502, 50.26764485143846, 51.3523567107416, 47.564304182606364, 47.689153225191184, 49.67093467712403, 51.263981788389145, 52.742770256534705, 52.67235978957146, 50.94395952840006, 52.08942890167237, 53.53454774425876, 52.046424035103094, 54.40769872357769, 52.676290004484116, 51.25787465803085, 52.38004907484978, 52.88914526662519, 49.494286814043605, 38.16378708808653, 22.565664283690914, 10.102842969279136, 3.449535312191133, 2.276541441679001, 3.7752915870758796, 4.414009365343279, 4.210455023473309, 6.758341866154825, 0.14752711439805646, 0.04197645864839997, 1.8621804180645176, 17.42427441381639, 37.41611273058, 37.62860321229504, 39.94264079678444, 48.627788174536924, 53.3556955091415, 25.589519469968735, 4.968961496506968, 0.012220060959788821, 0.05738856571335947, 0.04688569562389486, 0.03384504054162291, 0.06864964451280332, 0.04353464701242986, 0.038204207235286315, 0.02492529306290371, 0.03371590110022695, 0.06708264996808383, 0.045456187048506354, 0.06605756303836262, 0.012163336937045379, 0.020119460720208385, 0.015426338105762919, 0.035780569343196775, 0.03531644646559031, 0.07882969664229501, 0.03682064478315654, 0.039876569513111346, 0.029379345491648685, 0.08176934454710254, 0.030558303096181447, 0.043077372960866465, 0.008188492614745854, 0.03531346255312524, 0.02032212353491735, 0.048965674134031426, 0.021398187870340004, 0.041914325087301196, 0.0523414175897356, 0.06978031368024888, 0.040879585449734045, 0.026425714567003232, 0.03746200210204528, 0.054249007164710955, 0.06058091538087015, 0.02662427689609749, 0.008937890355985974, 0.008357945517937263, 0.1038993264157926, 0.29796214533909676, 8.556574044689055, 42.228986447857274, 56.99395664276616, 48.186737260510846, 36.04904120968234, 30.067259996168076, 46.56405272022371, 42.29019895676644, 14.261850714683534, 0.9550550940536684, 0.1309736703913058, 0.25346049618336464, 2.0963364791485573, 4.428322584398331, 5.580907137163225, 5.362645868332156, 3.5227152176441687, 8.493738655121096, 23.19752477830456, 35.95288038253784, 51.14338459507112, 56.14439479766354, 51.7529248422192, 51.885081260435044, 52.992119250759, 54.02952340341384, 53.96634186467817, 52.94809456794493, 50.52715670677924, 50.28242826461793, 45.054508947557025, 41.35459207719372, 42.25322669552219, 39.73963460614605, 42.75891434761786, 45.19837364073723, 46.28492509165118, 50.390564087898504, 49.78756635419784, 47.82738147243377, 43.88533276896323, 46.31988517699703, 51.25692936681932, 53.06620105620354, 52.85108258647304, 52.675823242433616, 50.56154412607993, 54.70396710980324, 53.05649711239723, 52.643271492373565, 41.87327454167028, 37.3511778923773, 38.14861536026001, 38.341392009489, 38.102841300349084, 38.76392933630174, 38.44009061013499, 37.619287583135794, 44.079129234437026, 50.84609639260077, 51.98096359929731, 52.04256834522371, 51.724479813729566, 52.96135610149753, 52.34783072625437, 52.29757339723649, 46.42856620973157, 53.69193284742294, 51.669539174725934, 50.17718322815434, 43.309473914484826, 42.0286278570852, 39.84525619014617, 39.66565870469616, 39.50419433655278, 37.54542935279108, 37.83535526644799, 41.05135756154215, 38.82876219287996, 39.91201493047899, 38.59879755204724, 40.20633782109907, 42.613480706368726, 49.87701208360734, 50.02066889116841, 52.882453703111224, 54.02967245348039, 52.42862762943391, 53.41998315626576, 50.62898535882273, 49.72734620494228, 50.95249068352484, 50.86072683334351, 51.08636117750599, 50.45030570799305, 50.93909186701621, 51.48801580552132, 53.41887312550699, 49.06217890401041, 51.24799812993696, 50.8449589052508, 52.27176027913248, 55.39974458755986, 55.453626186616965, 52.498563489606305, 52.49760643128426, 53.61189688405683, 54.58383275616554, 55.08054994767713, 53.131241798400886, 51.65688168617987, 52.9990343893728, 54.697644249085464, 51.27127739690965, 39.27819913433444, 25.772213666669785, 11.368299607307682, 3.9413108075818712, 4.560154426482416, 6.575886443738015, 6.229175396503941, 6.495783800078977, 4.558419758273709, 0.09030846698630242, 0.1236744842401916, 1.9567925218612918, 20.736798394110895, 41.49391858808456, 36.06207916813512, 38.75291139848771, 55.56962243972286, 58.61652351194813, 32.68334165696175, 7.424444652372792, 0.005953527335453058, 0.04059575370422775, 0.008093470899057726, 0.08345791724540534, 0.04460347373218787, 0.02292639346823337, 0.05500854120679921, 0.022077568048130602, 0.034481598319666046, 0.04558282521282954, 0.01771510526117298, 0.022373523135038636, 0.08716905399435952, 0.011882560924747059, 0.03914716187864542, 0.02767308190795443, 0.026973124608517658, 0.04868002676014458, 0.035215751868822885, 0.14966980103523503, 0.16301511396323481, 0.1962199080134592, 0.11586303041586954, 0.13623306317435158, 0.19293507621172937, 0.1609638829024569, 0.047026491093058745, 0.17581894062459472, 0.12760167310555137, 0.13440778208596094, 0.15633934718226233, 0.16557125825314753, 0.1672995219668073, 0.16279034376625093, 0.1265681515477838, 0.1543565737383981, 0.13840316043746087, 0.13823347196223276, 0.14180950910574006, 0.13130762343925814, 0.15057654270241339, 0.5572190772621863, 9.82419583105272, 47.08722629854756, 66.39274397204, 57.58443809324696, 44.05697176533361, 36.93706189432452, 55.96177708718085, 48.00650042872275, 17.62611173814343, 1.0564858706728106, 0.508536426650901, 0.7821024713977691, 8.474182698034472, 11.831102025124336, 14.970337652391004, 12.32067854173722, 7.146130915611022, 9.638179386815718, 23.8391343239815, 36.95405360191099, 52.21298356210032, 57.26792243219192, 53.96450619543753, 51.43271823083201, 53.80540701650805, 55.43481057690036, 56.649007720331994, 54.730552934831195, 51.795737512650035, 52.55788541609242, 46.33195431001725, 43.035919973927165, 43.034370637709095, 41.56641575597948, 43.770477925577474, 47.561378094457815, 47.742105222517445, 52.5456044750829, 52.055049327112016, 48.885264319758264, 45.347976761479536, 47.618268151437086, 52.544129663898104, 55.49347746756769, 53.75104688828992, 54.3079097040238, 49.60659603918753, 54.51800361756356, 55.24240263046757, 55.378803053209865, 42.893887027617424, 37.916909187070786, 40.71933677119594, 41.094205533304525, 39.38285581527218, 40.690558341241655, 40.62908303353095, 39.46020495507025, 46.71756252165764, 52.677411802353404, 53.60656638299265, 54.229226958367136, 55.16039763727496, 53.2126937373992, 52.72821826319541, 52.592104173475704, 48.15797452003726, 56.220645673813365, 52.36941552931263, 50.57977922501103, 46.44256907124674, 43.69072437286378, 41.92803867401616, 41.43909169781593, 42.3319878885823, 38.66463453538957, 41.060614355148815, 43.7476771877658, 39.69470385582217, 41.90334735378143, 39.70052073078771, 42.44171619415283, 44.852091112444484, 51.93597793579102, 52.125397036152506, 56.79735568261916, 55.68962735514487, 52.9483534443763, 54.127178653593994, 52.43513876391996, 52.4686122709705, 52.589303601172666, 52.21347778074203, 53.091241467383604, 52.660188674926765, 54.52103168733659, 54.428746161922334, 56.03005770714053, 51.490643793536776, 52.902045942121944, 54.74270443762503, 55.902968991187315, 57.99272152685351, 57.10521859507407, 54.95947814756825, 53.67279952572238, 54.52029820411436, 55.67547152119299, 54.645300219135905, 52.28338618432322, 51.55231129738593, 55.20444585431007, 59.384551048278816, 51.76307201385499, 41.68016841334682, 26.505063426110056, 12.411854036392706, 5.277138688871938, 6.849703673393496, 10.849670094828452, 14.447455310052442, 12.443047665780592, 12.993544474724802, 0.5402216086945226, 0.25354588434340497, 3.2372483034287733, 24.208688274506603, 49.63869279430759, 49.96059386960922, 51.89772698187059, 61.72894385553176, 70.05361756970807, 37.6074694818066, 8.535997290765087, 0.1805006877909745, 0.11020939346523055, 0.13564113767877703, 0.09008715184585703, 0.20904112487070023, 0.15990784602059474, 0.1105429711301, 0.18735202660243358, 0.16284070638639314, 0.1656167485540913, 0.08297295294581883, 0.11708608212610407, 0.17386005380220954, 0.2500160116582148, 0.09464157519922142, 0.1077591072046949, 0.20639373950900572, 0.1542936319545392, 0.1318886858080664], [0.03856489675179605, 0.015193737532582977, 0.027602356670784856, 0.038090171217317545, 0.08380169154054697, 0.057743417639886184, 0.004118722816553688, 0.00846940748048045, 0.0721550866540882, 0.03361155609450033, 0.028148246027769584, 0.06159895047124836, 0.0327577625942086, 0.03256485016355592, 0.042503917845146316, 0.030432038399721348, 0.0359085749744648, 0.06895206538179229, 0.07418559503651435, 0.07778694372503989, 0.03160163057937978, 0.0350642541513568, 0.08278947488795366, 3.352184535995607, 24.865697045480054, 46.61769113233013, 47.35426518224901, 27.242588650795724, 24.832949176911388, 32.96944718207083, 42.76620211139802, 17.853868084569132, 1.2166963061017375, 0.12305687947739517, 0.47979023367647206, 1.5428393021706612, 1.9027786653849388, 2.559588008349942, 4.134459101384686, 2.0396528368996036, 5.380831447339827, 20.720969669280514, 36.269356819891165, 50.57300921409361, 43.379715719530665, 51.46192027676491, 53.87092628786641, 52.93511936741491, 49.74007037378127, 48.94297807447372, 46.651321534187566, 43.43264026026572, 39.98349620449928, 37.44773487890921, 38.12910941339309, 38.83486540086808, 37.679209632258264, 38.65526007067773, 37.59820876582977, 37.0913444026824, 37.20607765259282, 37.99780807187481, 39.25313518893334, 36.15973834068545, 42.63190800143827, 46.07387804215955, 49.28594227760069, 49.90482561049923, 51.776592423838956, 46.96633492746661, 50.231017758769376, 54.83151082069644, 48.33368885901667, 40.56637610158613, 36.724563567869126, 36.04429906414401, 34.65135951195994, 37.63616554198727, 36.767297790896514, 35.80468147031723, 37.0013181624874, 37.43921156852476, 45.26754071635585, 50.30389147420084, 50.79136363921627, 49.85804742382419, 51.075143198813166, 48.65478977080315, 47.77978351039272, 43.9853806649485, 51.02625477698542, 49.95190581967754, 49.44545722776844, 44.61144978000272, 40.545328663241484, 39.93902044911539, 39.550913687675234, 39.08569705101752, 36.834790014451556, 37.009347254230136, 36.50639349414457, 36.30750186981694, 36.470727382167695, 36.48824468735726, 37.51525455905546, 46.399842692959695, 50.20644410963982, 49.80876676497921, 51.774027193746264, 51.09747325220416, 51.771136406929266, 52.39398525607202, 48.62205759171517, 47.06851659282562, 41.3151369556304, 41.617030020683046, 41.50609362509943, 41.56405448913574, 41.91988406642791, 41.83936172916044, 41.1932179235643, 40.06849396613337, 40.171758205659934, 43.15525416404971, 47.55170945198306, 49.56752138753092, 50.200442883276175, 51.19362623460832, 52.514056851786954, 51.54278386023737, 49.276999273607814, 53.46439615372689, 54.158004560778224, 56.305584599894864, 54.821551922828924, 58.52708954964915, 52.2083394758163, 34.8798728758289, 19.40981741874449, 5.796714473155237, 2.382768051278207, 4.753367439393075, 6.870806024920556, 4.197929914920561, 3.0886755403011077, 5.9610240305623705, 0.43790379418961467, 0.09919537802136714, 2.6398423987050212, 22.080178799167758, 46.627449989318855, 36.35566857553298, 43.20869645764751, 53.90223856895201, 45.9756265917132, 22.864462598677605, 2.2659868338415703, 0.18410579031032903, 0.028464977419184103, 0.011877769044780684, 0.07285256374387011, 0.04484653044792433, 0.043190723330143004, 0.01831770810719219, 0.027605162467807535, 0.06045833365210603, 0.05409596961051707, 0.07069053338660349, 0.024562012253990097, 0.034733648907633564, 0.04275523681914614, 0.029672381783565207, 0.049734002865490415, 0.06837894734475883, 0.038679813770877744, 0.01530647503152009, 0.04122280433113056, 0.07933319260876986, 0.021753321334178892, 0.06777304074456615, 0.01780464370254307, 0.0035947584171569158, 0.046261720840008035, 0.028386702385520744, 0.03584135841998843, 0.05385473235360077, 0.011510380089373119, 0.0351958527349897, 0.03748955828468165, 0.029474242718049118, 0.013000649970866019, 0.09881114662294427, 0.03720812056393873, 0.0430312046721097, 0.06479022378522543, 0.020794799784198407, 0.03302646410321036, 0.05856065725487086, 0.07682776333944452, 4.683566900991625, 31.7720103263855, 52.934582002701305, 52.96093640788909, 33.63493611735682, 30.31165895923492, 39.97565538652482, 46.146414433756185, 20.00509592794603, 1.3675800807053045, 0.07915805724840011, 0.410083587011022, 2.4157649903528156, 2.3016875117055835, 5.164196000945184, 6.73844172108558, 3.932858835304937, 8.21829560302919, 20.7677557006959, 37.02750782812796, 52.09704222217683, 49.43786744148501, 51.49677053574593, 54.43604961518319, 54.42010125806255, 52.66998675561721, 51.31199944403864, 50.3849394090714, 46.159609287015854, 43.44683531791934, 40.327542981793805, 40.73326510767783, 40.97051358992054, 40.179069503661125, 39.83022959001603, 39.421726503679835, 40.28165517314788, 40.995114695641306, 41.424006262133204, 41.1952300994627, 39.42322877145583, 44.05435946679885, 49.113318766317065, 51.0025401269236, 52.81516544280514, 53.4827136224316, 46.25647614079137, 50.01255742965206, 55.87461025484147, 51.976570544704316, 41.73376760175152, 37.002196773406, 38.51379979041315, 36.90971512948313, 38.484127060059585, 37.736397789370635, 38.80310204721267, 38.85790148089009, 39.02631236660866, 49.203599960573264, 53.0515706154608, 52.653595170667096, 51.84365710904522, 53.1870061351407, 50.93092549231745, 48.38465221466557, 45.93139794565017, 54.34932208830311, 52.94070874491046, 51.02286584915654, 45.272514281734345, 41.66285899377639, 40.90710455371488, 41.80941051052463, 41.106364880838704, 36.942353171686975, 38.024146787581905, 38.92904543107556, 38.337316666879964, 39.09111776659566, 38.8738263037897, 40.02255908904537, 46.41541058017362, 52.123922224967714, 52.070275968120946, 54.15822813587805, 53.27019176175518, 52.98740063944171, 54.49437525964553, 51.221318168024865, 49.52372812455701, 44.2245001177634, 44.303378981928674, 43.64859419484293, 44.54718958946967, 45.06623291200207, 45.136055023439475, 44.26955246156262, 42.3005618587617, 42.24337370164933, 46.55088532355524, 50.67341796813473, 51.887462139129646, 51.597795101904104, 54.27893907793107, 53.45754769540603, 51.43757412510534, 50.14760855705508, 55.70031973623461, 55.53470550044891, 56.28122275875461, 56.44605252050585, 60.17527341842652, 51.913055604504, 37.49503474081717, 21.108129178324056, 8.054708742326307, 3.8617658759317095, 3.8984196897475956, 6.766702888473389, 6.804542483821993, 5.747738288294885, 6.4751256569739315, 0.6754708770782717, 0.15613503153285674, 3.075739073176538, 24.909870778360677, 45.277115221946474, 39.56197477156116, 46.49991804553617, 60.63745021820069, 54.52577775524509, 28.526996220311812, 3.637044953723108, 0.12343145050709287, 0.026007625912766785, 0.03273502510461596, 0.015959983462497832, 0.05523891533694922, 0.024833366342429674, 0.042264289372871, 0.06560534133665985, 0.030686601756080508, 0.04620796061992165, 0.009920329170962496, 0.02306883411121465, 0.08186996253507753, 0.03979472067928122, 0.018606804791958104, 0.04766589105730096, 0.027268501299042857, 0.019879512406224688, 0.04095860358868395, 0.1460437230285137, 0.24217848786182944, 0.1715354978918068, 0.13710608165110313, 0.12913755681966582, 0.14255874309568636, 0.06901458581729282, 0.11881078353091595, 0.18046273579520566, 0.18130033036633847, 0.3049710837583388, 0.13840434021286427, 0.09874612107993135, 0.07146093438589765, 0.05387032990373912, 0.3067182545219698, 0.1471642338700833, 0.16455150329537932, 0.15106067962704167, 0.2257559836030968, 0.08903381159348835, 0.14779576611134315, 0.2906436767549284, 5.248076377376433, 35.514178968244984, 60.29089312399588, 59.84406848107616, 39.8580744958693, 36.69907992885959, 41.98410111088907, 53.72453951066541, 23.235157958922848, 1.86422421807243, 0.32463824616805204, 1.063805258562488, 4.622732410507818, 7.706752832858794, 10.436170889485268, 10.95165858345647, 5.151683640095496, 8.104452240851618, 23.72804887833134, 38.34043887353713, 52.07302554961174, 49.1057760484757, 53.69718882345385, 56.0247625074079, 56.84854653573806, 53.25566330263692, 53.52817781509892, 50.713998809937515, 48.47276433821648, 44.840433828292355, 40.93358055237801, 42.25055948380501, 42.627958174674745, 42.32932067686512, 42.982936597639515, 40.758521249217374, 41.48672103881836, 41.662690331858975, 42.44327337511125, 43.18430715991605, 40.54332040971325, 46.042138222725164, 51.75408586379021, 52.7294106637278, 53.981415533250384, 53.887604205839104, 45.68982701147757, 51.808022376029726, 60.035582127109656, 52.32485348178495, 44.078866435635476, 39.79304944315265, 40.2738457341348, 38.823451303666644, 41.36518639902915, 40.120253562927246, 40.19379800365817, 41.00751723012617, 40.54569736603768, 50.696422669195364, 55.201221666028424, 54.2620179730077, 52.72196992751091, 54.70664216626076, 52.24029894798033, 47.22593699732135, 50.00608944123792, 56.55884419718097, 55.477340836678785, 54.43486898176132, 48.60201035776446, 44.32395965822282, 43.57954479032948, 43.358719271998254, 43.415217091960294, 38.763760674384336, 40.79227716692033, 40.69891691207886, 39.92096185684204, 40.819129713120006, 41.2405687762845, 43.132814284293886, 49.45537297956405, 54.1814564120385, 53.9951281393728, 54.669971927519775, 53.91497842727169, 53.196886585604766, 56.21095741948774, 53.53199035890641, 50.23532452121858, 46.10640233562839, 45.61441552254462, 45.724775329712905, 45.22581454246275, 45.32101438891503, 46.84730668221751, 45.08479356765748, 44.33879406221452, 44.04441233604185, 47.441231973709606, 52.55451217774422, 53.73500831665532, 53.263817910225164, 55.478690132018066, 55.19284740571053, 55.72444623516452, 52.05861083922848, 57.78992714420442, 58.22725572893697, 58.6661728735893, 56.35581839469172, 62.50392575417796, 54.256824754899554, 39.95460010343983, 23.210207762256747, 8.921182867019407, 5.085756442239208, 9.763081381397864, 15.834338722690461, 13.141459015107925, 11.464124091209905, 11.236525620183638, 2.372570869422728, 0.37502363444336, 3.844722442088589, 30.797446466261345, 57.95698088984336, 49.48911320778632, 56.64057854683169, 69.06738465832126, 61.85104723899596, 33.86460265805645, 4.577431486498925, 0.2855358927720978, 0.100513378668937, 0.12140470361637494, 0.20125275327553674, 0.18628546367249182, 0.12905632085617513, 0.14216180229859968, 0.1960118691767416, 0.14235721600632514, 0.13024014120380725, 0.2978979165275251, 0.1239167059200906, 0.10744827469029736, 0.1743615656009605, 0.12622856009270877, 0.32787199522699084, 0.1788737009009046, 0.22652248521485638, 0.12319325844967559], [0.04192113560894805, 0.03815454941603445, 0.0434641209581206, 0.030791222553459868, 0.030310067626076843, 0.0562947798490284, 0.026807818156216415, 0.060737764222487334, 0.07763862910289919, 0.07176647323273844, 0.028932921160312913, 0.04429637589642117, 0.012435410190523874, 0.03284042731167809, 0.016919923232748144, 0.031443448744774345, 0.08105997011185655, 0.023367784601906617, 0.07100367948653237, 0.05459255929435453, 0.04954041627746436, 0.045741570122059316, 0.06310051344635506, 1.5706415522483088, 20.425570088048136, 47.58403370457311, 53.727685251543605, 29.352919901570967, 25.449698740436187, 34.12428317531463, 45.12310727950066, 22.66834997361706, 3.2919857146278506, 0.2608197819321387, 0.18317629583179953, 1.1415235914530293, 2.4277201294898987, 2.798561843172197, 3.918350723481948, 2.400652098078882, 6.233149738081041, 18.679262245855025, 37.598302902713904, 41.65905037233907, 50.49191813315115, 58.03395348210489, 50.22914286582701, 48.74195268077236, 48.24319193440099, 45.84394478028821, 40.28633063839328, 37.67507937646682, 36.665280865084746, 36.90458859166792, 35.91057369785924, 38.97644335223783, 37.720190555818625, 36.75296937265704, 38.0237663176752, 36.67729900729272, 36.56731574766098, 38.286843607502604, 37.07596871160692, 37.741104633577415, 40.62889868213285, 46.94111016488845, 48.37527382758356, 52.250497110428356, 51.113794234491166, 49.039221271391845, 51.94632122593542, 50.823072079689275, 47.335763362146196, 38.423761783107636, 35.94435314978323, 36.868883255989324, 35.088935206013346, 36.371691457686886, 36.551630189341886, 35.932688020890765, 37.39145671167682, 36.69944863165579, 40.257783628279164, 46.76094393576346, 48.262631200974994, 50.91331012787358, 51.58359612188032, 50.39387456832394, 48.72226238250733, 40.4883836930798, 48.593290928871404, 51.643561317074685, 47.99435677066926, 47.00473885382376, 42.83062311910814, 39.5491054750258, 37.45679555400726, 36.42114470081945, 36.853374204327984, 36.415241533710116, 37.32747108705583, 36.542447920768495, 37.12616720507222, 36.935630229211625, 41.20866813967305, 47.05531781719577, 52.36309659096503, 52.54761272861112, 52.26209948139807, 51.26386411728398, 53.13674880612282, 51.66001173757738, 48.966571131060206, 46.413476851678666, 41.62492575183992, 38.81323745173793, 38.95507427953905, 36.63355673513105, 37.08974799802227, 35.93998755178144, 38.12483010753509, 36.39232312479327, 37.64793265250422, 35.72726172785605, 39.54144900844943, 44.17427024533672, 47.651710279526256, 50.56592541356241, 50.50434812422722, 51.73639989668324, 51.49154986104658, 53.554822475679465, 52.30609278525076, 53.8530049785491, 54.86981668779927, 57.37855288290209, 50.121316909790046, 33.506529485025716, 17.679859976614676, 4.429766016621744, 1.8556445236167602, 3.1614374681826565, 3.7555944246630517, 3.878039054332241, 4.453408102835379, 3.717402306295211, 0.374624380060742, 0.08093473005799517, 3.441632962034595, 24.053705623072965, 34.96517265996626, 41.20537727109848, 50.78091444507722, 52.369933282175374, 39.870661381752264, 18.720047050906768, 1.251832530383141, 0.12111736701861506, 0.054282136636996464, 0.044041628678960186, 0.04543222381823486, 0.016903831555898634, 0.0491446246122641, 0.02749512925924313, 0.06340547389681302, 0.018625853568195336, 0.03553269010397696, 0.04028665254853907, 0.03327320570186262, 0.06932974672846257, 0.05176888944040384, 0.01978405976607915, 0.01736264161375021, 0.0601157927585225, 0.06628155182566374, 0.023635396350836082, 0.05218436190437886, 0.02189400572059376, 0.07001828357216812, 0.023755193349995443, 0.05349202036497094, 0.06157005363474451, 0.032943856842335195, 0.08119003651964088, 0.004654031062889244, 0.06267950216668748, 0.05236753352707433, 0.030035986264626828, 0.030928564881305062, 0.02164928084840217, 0.014534346503956665, 0.008209205716998588, 0.02593303576201922, 0.047414376730880434, 0.06043657292461684, 0.03996154781611216, 0.028615373885259036, 0.02748098919138072, 0.06903953730098664, 2.1648379775785633, 24.90547772376768, 54.222115701244725, 60.28472323571483, 34.30591637088407, 28.67248477474336, 35.91374689532865, 49.59584874491538, 24.572125288747973, 2.6356236444365595, 0.20732173245520363, 0.37151936441659933, 1.2573365963274434, 3.992117023275745, 4.7485463561550265, 6.322329236615089, 3.8716806471347813, 6.889527497753021, 20.7768948231974, 38.190549419772246, 47.37392802392283, 50.36008727165961, 57.89832184391638, 53.37692337651407, 51.68848030028805, 50.3787342194588, 49.348558995031546, 43.878904004250806, 40.47729515260266, 38.20490921697309, 37.598389194857695, 37.69882148311984, 40.62088920224098, 38.928013847720244, 39.11128267165154, 39.70532955661897, 38.85300244054487, 39.14658008083221, 39.68501952386672, 39.695229453425256, 40.106274235633116, 43.42131637757824, 48.93659637820337, 50.71300645028391, 53.67622767725299, 52.21518793413716, 49.4624371682444, 53.79323197949318, 54.173407708444905, 50.09362497637349, 42.20911572056432, 37.51546244467459, 39.162952053931456, 36.98065511641964, 38.64684266428794, 38.853135801130726, 38.51925972969302, 40.104403265060924, 38.79532790953113, 42.899515628814704, 48.970673930260446, 50.40374325167749, 54.072500813391905, 53.614422890447806, 51.980849850562315, 49.79725460852347, 44.23421582868023, 51.69528953490719, 52.74342529235348, 50.61985408106158, 47.99161895628899, 44.40876522371846, 41.52814126783802, 39.97558478386172, 38.006762842978205, 38.35028402266964, 38.179747212317686, 39.82112969121626, 38.500710841148134, 39.47451376145886, 40.38036161853422, 42.02796497652608, 49.4542198027334, 52.6693787882405, 54.99630920348629, 54.51778004246374, 50.09154219781199, 52.99897163145004, 53.22370775284306, 51.04176775101693, 47.30410983485561, 42.797808570246545, 41.75148494781987, 40.716426372528076, 39.49681635825865, 39.909653663635254, 38.77423732511459, 39.732170335708126, 39.48841464134955, 39.658237580330145, 38.75911266573014, 43.3581740625443, 48.06678333590108, 49.00963091081189, 52.72396641392862, 51.78305256751276, 52.87326751216766, 52.36585793956634, 55.47012367556172, 54.48443989599905, 55.02581327192245, 58.066732729634936, 57.493933323890936, 51.13074671837592, 35.27114498999811, 19.80079339396569, 6.169443092038555, 3.6639548645865534, 4.394946156009551, 7.563519641276329, 6.861085411041015, 3.9925038670339896, 5.779730120012838, 0.4890431661999995, 0.04386130307290343, 4.025847935868848, 26.429406789041337, 43.07063294995216, 42.41423999109576, 54.529327500251036, 59.782777524763546, 46.641590133790054, 24.899949143009803, 1.996648828348806, 0.18954967238730003, 0.06905653679202642, 0.03838198176855522, 0.0453602651795072, 0.025220907240685438, 0.10065855233058815, 0.005197317636151228, 0.04251959583451671, 0.0188313968734996, 0.021215140736932238, 0.03092689480963013, 0.03744268902547417, 0.08505388523542112, 0.06776117404261905, 0.0349492452017242, 0.008108172126324668, 0.05282820900902153, 0.016122628716872107, 0.028576510244860288, 0.11162387522598428, 0.1868596006064646, 0.1744886902311156, 0.1750185932483404, 0.2786087112561349, 0.10226035024970771, 0.16876612068904986, 0.2182122698474315, 0.2410054540321712, 0.17985161213624865, 0.13686565261694694, 0.22083245908781407, 0.13539603550828275, 0.23598986107014844, 0.1608194906504885, 0.1945529772990173, 0.15893306042398178, 0.1071608538228658, 0.18830804304490167, 0.15051896353402447, 0.13904220034037867, 0.1350959282248251, 0.13896940666581356, 2.2827976221038453, 27.26561100252213, 60.22990811255671, 65.39943902723252, 40.99731906767815, 36.99575624158306, 45.866941636608495, 57.766938132624475, 29.15480882890763, 4.807166668676562, 0.7868092543175145, 0.6690207844780338, 3.8912084121857924, 7.39205175830472, 9.39117891173209, 8.66243391267715, 6.650549740560594, 8.366918621524688, 21.428565248366326, 39.02191146727532, 50.11635118915189, 53.4359864265688, 58.95841690801806, 55.48678198168355, 51.83835798694242, 53.39252264268937, 51.11054651198849, 44.578478336334236, 41.77426607378068, 39.74372563823577, 39.42113422578381, 40.37019875741775, 43.374922583180094, 41.833854721438506, 40.74980574269449, 42.28228361375871, 40.94062120683732, 41.65368456994334, 42.978904401102376, 41.07806498004545, 41.928203413563395, 45.15928329959993, 49.82873947389665, 52.90302261229485, 56.821670455317346, 53.60246750616259, 49.42554727677376, 55.893002248579464, 56.67346762072656, 52.06871878716254, 43.237345449386105, 38.97851044131864, 40.686157441908314, 38.414261802550286, 39.97838535616475, 39.67600591721074, 39.87396009506718, 41.816655128232895, 40.76863704189178, 44.068240734838675, 50.86502575105237, 53.137039061515566, 56.1386485253611, 55.766313614383826, 53.026698866198146, 50.64380015096357, 46.99056340802101, 52.71891047877651, 54.327050870464696, 53.16932801277407, 50.76009842657274, 47.57600461283038, 43.28522582207957, 42.81114855120259, 40.47899746125744, 40.40841833237679, 38.91375603214387, 42.17540294893327, 39.85544258548368, 41.5468313617091, 42.7429267667955, 45.85650028720979, 52.31654197938981, 55.02883741932531, 56.913861843847464, 55.536917717226096, 51.68222019749304, 56.13626372429633, 56.922757779398275, 54.48950367589151, 49.05921751453031, 45.23809940584245, 43.16981792449952, 44.15480352217152, 39.65141657860049, 42.00490928465321, 39.918400549119525, 41.93423994125859, 42.37087034410046, 41.49702902763121, 39.91336814818844, 44.26667344185614, 49.59912392400926, 51.00107708284932, 55.3986894699835, 56.54559835310906, 55.67465174582697, 55.80204640665362, 59.28543667639456, 56.56237040796588, 57.16084564885786, 60.28725708684614, 62.508346265362164, 54.468499383618756, 37.86936613821214, 21.586642649865922, 7.46704355362923, 5.688312909295482, 9.310994878891977, 11.409746312326002, 14.583419369113061, 9.836280653553626, 7.507810708015197, 0.7804623077954016, 0.2748656669451345, 4.964080106827521, 31.7033080516323, 49.3940741785111, 53.68260545115317, 64.05254417850126, 66.75467675732028, 55.714738368988044, 29.030030388985914, 2.4928427511645905, 0.27500429821591227, 0.22184642242087474, 0.14931844246964301, 0.16956473670659528, 0.08793445243950813, 0.1940126401642638, 0.10338874413601815, 0.17683570783945823, 0.08844889580242096, 0.17766374163329604, 0.09948753331217075, 0.09573353394385307, 0.17943479901840612, 0.12285832480918016, 0.09668706060056725, 0.15192485744914702, 0.1351229711285522, 0.1274578784021639, 0.1130454049956414], [0.028102991298862526, 0.02417052025726486, 0.08686274139871521, 0.05680598649046114, 0.021273179558075724, 0.024355708606420987, 0.0098234161757113, 0.018865771238662062, 0.03393878672091711, 0.04536924372997977, 0.00727565959095955, 0.03739936675335612, 0.03393325173566419, 0.026689493961091486, 0.022586811589257374, 0.06282890846412029, 0.04750472147979083, 0.0785602328758086, 0.035533843066303, 0.005509198733395147, 0.009081765498605468, 0.027340597833596894, 0.02501005111562629, 0.3575084742999846, 14.222319106901846, 40.67416675629155, 47.98344081447971, 39.96553567148025, 31.914849319765647, 34.145244321515484, 41.02526987752607, 31.438681425586825, 9.7150097931585, 0.2912515522010865, 0.19059803306816087, 1.0433238672633325, 1.4622296921668516, 4.383599229397313, 6.44487633820503, 3.791016369096695, 4.53604361703319, 17.62143038934277, 31.922215530949256, 38.764694198485344, 57.723309609197806, 50.47677386191584, 52.21822384865054, 46.359995334379136, 44.24086032375213, 39.99492599118141, 38.22107722682338, 36.65338823872228, 40.85089698914559, 42.77320746452578, 44.13813737130935, 45.2784292159542, 45.988919504227184, 41.40524556559902, 35.95222534671907, 36.29022775157806, 36.941086246121316, 36.03307324071085, 37.44809573696506, 40.63073827374367, 47.29289970090313, 48.390335729045255, 50.02261046440371, 51.282609124337476, 50.24429890417284, 49.478864054526056, 53.576862273677705, 49.65592376647457, 44.4444784041374, 36.7406060618739, 37.50209892949751, 34.69539596188453, 37.07158350175427, 34.808344533366544, 37.676389448104366, 36.83100884960544, 36.183817771173295, 36.44658127138692, 37.166238138752604, 43.616368001507176, 47.1960485366083, 47.74842023849488, 50.24437735157628, 47.844577143269206, 53.00622801626883, 36.88354115332327, 51.25505839624713, 52.325751704554406, 47.95462708319388, 48.61360488399383, 48.22294073720133, 45.67178018631474, 41.14350580400036, 38.81509665519961, 35.37915137506301, 36.81590772444202, 36.15826352950066, 35.89386832329535, 34.90574875185567, 37.230204151522734, 39.95278012367987, 48.689667486375384, 52.23694139911283, 52.48614918801093, 49.946481181729226, 50.82794758581346, 51.59525732840262, 50.18050547569029, 50.16651830365581, 47.30552188811764, 41.39696936453543, 39.46524912311185, 39.17221669227847, 36.88498458554668, 37.23589943301293, 39.06639898976972, 42.25514473453645, 40.30100422520792, 38.46966135886408, 37.91282207735124, 37.362074236716, 37.91748969785629, 37.831225010656546, 42.805594475038596, 47.65420490695585, 46.097902559464984, 46.695483499957675, 47.6777312832494, 49.64779269310736, 52.50393713674238, 51.027953163270034, 56.2083568880635, 50.00372425202401, 34.14546789661531, 15.294331312179567, 5.02785490405175, 3.1120786070823674, 2.2221192909825236, 4.536638836706839, 4.257925508483764, 2.898764427631132, 6.052588820457459, 2.2909210958788475, 0.08856695761243183, 4.671206041689842, 25.613245887141076, 42.76333093643189, 51.61106448019705, 44.83045531857399, 48.57949595297537, 39.00477463199247, 13.34244518510757, 0.35870050711016505, 0.06355624000031142, 0.06592146751861419, 0.029255886592211264, 0.07856185698220808, 0.1317499472849792, 0.04438977733614945, 0.06692423064622187, 0.074604936244507, 0.06832144478516233, 0.07756774298726551, 0.049035035734695774, 0.03303238596286505, 0.03071960099341889, 0.03473847909199615, 0.010072840997318347, 0.039256084259719624, 0.06352356251990122, 0.01755113946273923, 0.028613799574574637, 0.031265208813091444, 0.028066094589209365, 0.01094528299290687, 0.02119627390657702, 0.030459343688562516, 0.03535380474321785, 0.06745702947580046, 0.04519659049448468, 0.01733997307207075, 0.06258832238193962, 0.010784755971643233, 0.003852884321766455, 0.00942319556469879, 0.06159929138037467, 0.028226641720281016, 0.044331715532368234, 0.04209225283815496, 0.010517379794750484, 0.033275435017722274, 0.031102070389615915, 0.03492514024518671, 0.036114055077515306, 0.029059775744474707, 0.5496761755597207, 18.295275934280887, 48.53870330318328, 55.812958440473004, 42.03275419050648, 34.34204532254127, 41.921786415961485, 46.364753169398156, 33.16455371918217, 9.11635902620131, 0.4532751645292006, 0.009861865171021032, 1.0533145118144251, 2.9988098721350394, 5.639947143293196, 6.308863249517256, 5.497836239876286, 5.751465520551128, 18.50542868337324, 35.66456264065158, 43.35327109982891, 56.11111740912161, 54.23653041162799, 54.06829603256718, 49.42276239395142, 47.2324049857355, 42.446324979105306, 39.49986011751237, 37.00650745822538, 40.884225368499756, 42.77842029448479, 45.29912756335351, 47.07455704289098, 46.211965084075935, 42.92674472255092, 37.45600323523245, 38.87924309699766, 37.65422021189044, 37.33287219078311, 39.160276997473936, 42.52971849133892, 48.91534889897993, 50.286185895243, 51.01328349882557, 53.67191307006344, 50.75841965213899, 50.72237307025541, 56.00020062538886, 52.48961656324325, 46.03858063297887, 38.3233138053648, 38.62863109957787, 36.84765931098692, 38.84359267450149, 36.91430038021457, 39.65842193172824, 37.94708398080642, 39.13707225553451, 39.272437172551314, 40.04388501567226, 44.988224814015055, 49.177304390938055, 50.34886537059661, 53.10000404234856, 50.5465018364691, 54.098635565850046, 40.241270449853715, 54.755616880232296, 55.41405731631864, 50.80628825772194, 50.30992800189603, 49.80824901211647, 46.83518263601488, 43.29099955097322, 40.05615026720109, 37.061765809212964, 37.8513781486019, 37.716126980320105, 37.03762362080236, 37.309592923810406, 40.52907828361758, 41.21414376843361, 49.42548844122118, 52.92126947833646, 55.03055541746078, 51.69405006593274, 51.224883602511504, 52.58084304871098, 52.74997957291142, 51.34844218530963, 49.222745049384336, 42.76078531819005, 41.34854770475819, 41.11452341079712, 39.10488136353032, 37.59989538500386, 41.009184237449404, 43.021175784449426, 41.49999826185165, 40.32166727127568, 40.310872908561464, 37.544319322032315, 40.74823287225539, 42.72987311886203, 46.92725635343983, 50.251092449311294, 50.20007810285015, 49.1660628780242, 52.03447649555822, 51.192790769761615, 54.89043266542497, 53.809035208917436, 56.880839409366736, 52.341225454884196, 36.201593952794234, 16.915205678632184, 5.803862502498012, 2.9109134789436095, 6.487672338562628, 9.330882276258162, 7.850257648575691, 4.200174491251669, 5.25686837011768, 2.5520793660994503, 0.12552077145946602, 5.47576359202785, 28.745421248097575, 44.64986155110021, 57.01964032265448, 53.46157989194317, 55.30956537492814, 46.76022614202192, 16.885327023844567, 0.6756570058003549, 0.045552936292463736, 0.08514441384543335, 0.03788129734476248, 0.033267145946381554, 0.07161484911076485, 0.05141602934248025, 0.05453762312930438, 0.13196583086204144, 0.0022121815850222183, 0.07050778311226638, 0.04421723135296376, 0.16433586486645285, 0.03180162357767263, 0.02028437072200881, 0.010257690352567983, 0.006572081089665693, 0.050358261101909225, 0.050706486367890914, 0.026917261477079124, 0.07508311300508438, 0.12981703084322715, 0.2062237292768494, 0.2775348092038786, 0.1296296917022236, 0.16927144760566373, 0.12351443315105093, 0.10741164036575826, 0.09669711167413382, 0.17432839399383915, 0.17155354692330285, 0.10728722768685511, 0.14344726719202536, 0.10741678847660942, 0.11791288251838378, 0.12890071307699527, 0.16001086952465196, 0.16282186062345583, 0.1160269272663901, 0.10643586651572298, 0.1071432414614866, 0.16235758069782488, 0.1463478139691776, 0.6963342091729564, 19.901935631229033, 53.50949556596818, 62.405191852200424, 51.941630071209325, 43.001187386051306, 44.88807493640531, 52.536712461902255, 39.17267560958862, 12.955752438114537, 0.5695419386029243, 0.5540037143134302, 3.595661742071952, 5.812797171454276, 12.001121082613546, 13.356714767794456, 8.434091171910687, 7.947746688319792, 18.459538913542225, 36.80845522111462, 45.86413321956512, 57.846966251250244, 55.17674607615317, 56.754833267581084, 51.37192541553129, 48.82005491564351, 44.48177229973578, 41.12612970413701, 40.096703652412664, 44.069986189565356, 47.558793252514256, 49.34364818757581, 51.50609400964553, 49.679987507481734, 46.19928798367901, 39.90691192688481, 41.00318301108576, 40.01720113138999, 38.73056173324585, 40.40273481799711, 45.244359508637466, 51.40804260007797, 52.48154432542863, 53.38378360194545, 55.448491804061405, 51.9142323155557, 50.81235616437851, 57.42403668742026, 55.474987414575395, 47.806714503995835, 41.01014914051179, 40.49052138482371, 37.65352987474011, 40.4514741897583, 38.30145835876465, 40.53681319759738, 40.70798543191726, 39.79006451945151, 41.42911318809756, 42.501112645672215, 47.1570287981341, 50.88469643746653, 51.91924118226575, 54.531912342194595, 52.54510241170084, 55.504416957978286, 42.04004979902699, 55.518200166763805, 56.407005325440444, 52.41253022224673, 54.322132218268614, 53.05366908350299, 49.77519912104453, 45.736954289097945, 44.2728001840653, 38.98409197407384, 40.421138578845614, 39.80025875952936, 39.01628678844821, 38.88513057462631, 42.35887573611352, 42.73707066812823, 52.98664754436862, 55.23444021901777, 57.01974622664913, 52.85728385371547, 50.807951342675, 53.85442095418131, 54.62881449730166, 55.68210424915437, 51.6777055494247, 44.93428437940536, 43.34282190568986, 44.021925387843964, 40.04445375934724, 39.73599072425596, 42.48567811904415, 46.60189574764621, 44.39454270947365, 43.12772697018039, 43.22226393607355, 40.581539984672304, 41.402794084241314, 43.784669060860914, 47.87102568534113, 52.58021154711324, 52.226880519620835, 50.51246350811374, 51.38408476306547, 53.813867568969734, 56.74665904814198, 55.88835423992526, 59.03467170653805, 54.48174522769067, 38.23198141590242, 20.891227991350238, 8.030843081012849, 7.394050696203786, 9.704428219026136, 13.092626487055133, 11.098470937821174, 9.813415196634109, 11.989973706583823, 4.6568305550083045, 0.589862390150947, 6.312263944456655, 34.691104888916016, 56.531568035002685, 64.12065221417335, 58.82593493307791, 63.763461574431396, 55.14638300864927, 20.60924683847735, 0.9704336043327086, 0.23084076962644057, 0.1224516163910589, 0.11312561440131358, 0.1745605646001716, 0.14919435154766808, 0.13548145431184, 0.14127729250298393, 0.30815877561126986, 0.17329820491854223, 0.14551559733527322, 0.10583991905854595, 0.20698762618966643, 0.11858821200627474, 0.11358782588954895, 0.0582072455736418, 0.172987540943488, 0.247105383163979, 0.14805533202184787, 0.09540099049768141], [0.03948800971791629, 0.0424233062433139, 0.03695024004686744, 0.016397462759707725, 0.06546205225130243, 0.020404529697712392, 0.0407238895704429, 0.04718158559332933, 0.07344218331479258, 0.07762631040907676, 0.02131063742713342, 0.08622655134287574, 0.058676225448688196, 0.0792409556226865, 0.06754003510239624, 0.08920517014039141, 0.02049659239879299, 0.0625653742181678, 0.009365708326860782, 0.013114148769677888, 0.055187920694269484, 0.06096739524735078, 0.06504608183017661, 0.10936811401118195, 6.115870869928791, 33.091311300954516, 47.966131394909276, 41.24888812341998, 31.63794763626591, 26.37783350483064, 40.06470495654691, 40.8230403161818, 15.192038839863194, 1.505346714008239, 0.13289848162281898, 0.5693255953731076, 3.7203708050712465, 2.844072613985308, 4.083922793788295, 3.9563293178235335, 3.6810157039473137, 15.393934019150274, 24.075886626397413, 43.7131917092108, 56.1637124707622, 52.58890744178526, 50.575958836463194, 45.07699589575491, 39.47539629474763, 39.3810397578824, 41.203863236211966, 45.421682019387525, 46.12704576984529, 50.641886034319484, 50.753967761993415, 52.31761278644685, 53.772274755662494, 51.17436347469207, 40.79135148755966, 35.696682929992676, 36.29806856955252, 36.8166765089958, 41.78344834235407, 47.84164321038031, 50.51210265005789, 51.68060810335221, 53.12091419773718, 49.94040543033231, 53.96943661474413, 51.2613812569649, 51.9781316480329, 47.03732982758553, 37.70850189270512, 36.08739022285708, 36.71314947066769, 34.99446099804294, 37.18852896844187, 37.64821506315662, 41.72336155368436, 40.78531888223464, 40.76881354854953, 38.61396143513341, 38.15494606571813, 36.35006743092691, 43.89328733567269, 45.43939152071553, 51.8140902826863, 48.83738002469463, 54.763873469445016, 39.95625926602272, 44.64393092739967, 57.262309520475334, 51.33551405322168, 50.95056872214041, 48.60383818226476, 48.645152507289765, 44.59966698000508, 43.14849984261298, 37.275664421819876, 37.34509429624004, 38.86108252309984, 37.50209892949751, 35.570653253985995, 38.500173476434526, 37.97468177733883, 46.384702344094556, 50.45636184753911, 52.1716574699648, 52.4784456529925, 48.869343419228834, 52.8527025253542, 51.42426552311067, 48.68165800648351, 44.75028207225185, 40.402009179515225, 37.822438901470555, 37.99578805123606, 37.68623851960705, 43.37039616800124, 48.66632153910976, 48.3657895365069, 50.66066242033436, 47.663426399230964, 45.00429868698121, 40.85374462989069, 40.82083594414496, 36.42250576326924, 37.42434578557169, 37.867397108385646, 41.10837313436693, 42.82879529460784, 44.75357686319659, 47.11522417683756, 49.68835392305928, 53.58094546102709, 55.12071501824164, 50.75804310460245, 32.98164183093656, 15.895542406266737, 3.7656317699340085, 2.075710450449298, 4.51783303291567, 7.804803261833807, 5.009561950160611, 2.022217778909591, 2.2975084714351164, 1.1108224646699045, 0.1758195688166926, 6.062684020688457, 29.519708887223278, 49.32380491687406, 38.53648677948983, 40.46062900174049, 56.315637634646514, 36.12872023736277, 10.041312748386014, 0.18172751631467574, 0.06418966447874423, 0.021105693585629907, 0.09220877106511786, 0.04489655598937985, 0.02330532736865984, 0.056930165512547384, 0.07029569933130857, 0.022466307873987866, 0.056503630738945744, 0.027878636704577554, 0.029099275237850608, 0.01645650324081221, 0.06430332894406973, 0.013371924907269498, 0.002594854952129085, 0.017538862903752638, 0.03790665868549578, 0.06816320166352295, 0.027739356174283934, 0.027334486367180947, 0.045507890322516044, 0.06584462889980885, 0.009612569626751206, 0.02996331133368996, 0.01797784469090402, 0.07691798551428704, 0.023757244550412702, 0.02279758727508447, 0.044184278080900835, 0.05554204100682851, 0.1039754449119491, 0.05413494816410446, 0.05727680880696543, 0.03809262269867524, 0.018028410324346156, 0.028080571735758456, 0.09119090068364337, 0.08665867855832463, 0.024561458755464807, 0.037663747526464925, 0.02973973623386795, 0.015388477082935073, 0.18331394651003424, 8.752225791254352, 37.746384143829346, 53.559246909233835, 47.41502269621819, 35.4708210883602, 30.704705945907104, 45.53031598367999, 45.32972989543792, 16.769016981124878, 1.4667931247142054, 0.08290051933257811, 0.6330166132219377, 2.742971561608776, 5.799372859539525, 6.36965508422544, 4.578206154607958, 4.279804979601215, 16.16840502908153, 29.229104403526556, 46.21826833294284, 58.73897206398749, 53.708038099350475, 54.012010020594445, 47.02220909057125, 42.40129616952712, 41.47566779967278, 42.399562481910955, 45.77881774594707, 47.508516311645515, 51.442139763985914, 53.518164004049, 54.50702098108108, 55.47849009113928, 51.84803055178735, 42.834267000998224, 37.31389576388944, 38.785690646017756, 39.39958472405711, 43.36979996773505, 49.78303993901899, 53.33541685535062, 52.960630463015654, 53.9712683616146, 52.21000648313954, 54.32101826513968, 53.39738638170304, 53.8935975874624, 49.309590247369584, 39.51811482829433, 38.15322806758266, 38.881059154387444, 36.338088512420654, 38.01850249690395, 40.0628496754554, 42.507157018107755, 41.474318504333496, 43.2934392652204, 40.58124188453921, 40.248883770358184, 39.08204140201692, 48.38464044755506, 48.88562517781412, 53.12871579200991, 51.02785118164555, 55.75795504354662, 42.667130885585664, 46.655942086250555, 57.93722391128541, 53.32764271766909, 51.64475763997724, 52.61694846614715, 51.092240810394294, 47.050281493894516, 44.08944899036039, 37.77662954022808, 37.750949782709924, 39.52177832203527, 38.567010664170795, 37.049316206286036, 39.55152949979229, 40.68253709423927, 48.937443610160585, 51.98475260888377, 54.913598183662664, 52.894165900445756, 49.05982940427719, 54.38361929308984, 53.007424339171386, 51.38427303683374, 47.49713359340545, 42.16557348928144, 39.51807952696277, 38.14573634055353, 40.6498323717425, 43.84114334660192, 47.71385239016625, 49.764957812524614, 52.013758536308046, 48.91635694811421, 45.2922006576292, 42.080936585703206, 41.42136258463706, 38.868005506453976, 39.231840641267844, 40.24439265651088, 43.039630536110174, 46.191141220831106, 47.338399194901996, 50.043908934439386, 52.44349733475716, 55.55448993559807, 56.82412585904522, 51.645236169138265, 34.14948048130159, 17.352047889463364, 5.4460908616742785, 4.006417004331466, 7.808018624782563, 9.21572050740642, 7.078966700261639, 4.226844647238332, 2.993452649924063, 1.447265849959466, 0.20944528221603365, 6.635616787018315, 32.83533546232408, 56.03914191645961, 49.63908110895465, 47.26483121995003, 64.37186825659968, 43.612426019484, 12.756038096643264, 0.2737528476263246, 0.02068684458912861, 0.0687287277692268, 0.09671248705877412, 0.0528958200987789, 0.034009868188971476, 0.0612606805178427, 0.03028839882913857, 0.0018940689610204692, 0.029951795116968216, 0.04829093836428178, 0.04178254647300609, 0.029562526690443198, 0.010153293635906472, 0.09027836739175743, 0.020160973109605334, 0.0543674405273651, 0.09415842652801545, 0.07403692801392849, 0.0768419359660437, 0.10166591964662076, 0.14675149633999796, 0.16726239734599668, 0.08919352560394234, 0.18667243000480438, 0.0860204583694858, 0.2828299782929882, 0.13628431445648595, 0.1257875769008552, 0.14576431544077012, 0.1473596016125333, 0.19283007620082748, 0.1775426231324673, 0.15590063927154388, 0.15423490365426387, 0.17977760804276313, 0.20562717661021218, 0.17102260202650102, 0.3061313085979031, 0.08814328034678776, 0.10276736255975501, 0.15491325918945575, 0.12868938006220326, 0.28127589232979283, 10.0705442120952, 44.212329003118704, 60.85223136409637, 54.004518293565326, 43.64317347926479, 37.72442279323455, 51.418801661460634, 52.035335494625954, 20.817769842763102, 2.28809870539173, 0.3846119296166205, 1.4543539405830446, 8.735085033601331, 10.677044622359738, 11.092357923907619, 7.501468235446562, 5.297406065848566, 17.88044410367166, 32.76956515927469, 50.50782726657007, 59.678093387234604, 57.49244282322546, 55.47503056064729, 49.083849999212454, 43.61361449764621, 44.162997353461485, 45.36188940848074, 49.18519619972476, 50.26411079591321, 55.24921970982706, 57.12727016018283, 56.195942586468114, 58.716265463059955, 55.10229164554227, 45.41269586932275, 39.84415400412775, 39.6354603767395, 42.783652736294655, 45.87149943074873, 54.34360719496205, 55.79930466990317, 55.588304688853604, 55.67126674036826, 53.594101090585035, 56.90338911548738, 55.96917467732584, 57.33803872139224, 50.855890550921046, 41.24201220850791, 41.28841384764641, 41.30512706695065, 38.02597068971203, 40.320820039318455, 41.72749180947581, 45.63736923279301, 45.1871282054532, 45.64217021388393, 42.68223593311925, 40.9298425336038, 41.507282103261645, 48.6208063556302, 50.62144656335154, 56.25118132560485, 52.75952269954067, 55.03965139389039, 45.88532970797631, 48.480526708787494, 61.15721133447463, 54.91816774491341, 54.6012088560289, 54.03223768357308, 52.69661180434689, 49.864487955647135, 46.522357925291985, 39.88555069892637, 40.36226380255915, 42.064890169328265, 41.67429662519886, 37.750110395493046, 41.58325056875906, 41.995774084521884, 52.093770965453125, 54.355825378048806, 56.44701742356824, 53.24116622248004, 49.201121022624356, 56.20550532494822, 55.51108106490105, 52.8716750298777, 50.0257718947626, 43.19676068521316, 41.608922481536865, 39.83747028535412, 42.1943832981971, 47.19205556377288, 51.17714835751442, 52.76016204587875, 55.20613247348417, 51.04244632105674, 48.63617812433551, 45.15239169520717, 44.36086131680397, 40.88044028128348, 41.20785228667721, 42.89638557741719, 44.39482904249623, 47.132933678165564, 51.089852086959354, 52.91691956981536, 54.703421900349284, 58.567438971611764, 59.10494881291544, 55.59649852014358, 36.5730227962617, 19.282183493337325, 7.342055757199565, 5.430675946897076, 14.283990533121171, 15.68561323227421, 13.538524470021649, 8.3492914899703, 6.680237179802311, 1.883869163932339, 0.5509318243111334, 8.045975094841372, 39.628443256501235, 60.71845108462919, 53.21268197028868, 54.159538207515595, 71.14112607894405, 51.47517004320699, 15.336160448289688, 0.6143857839126742, 0.14357066863486845, 0.13853517270857288, 0.27276885365286185, 0.1257447296032502, 0.10191243141889574, 0.1393065313177724, 0.2052644186563069, 0.19650791110771318, 0.11458028513457506, 0.1507053374042434, 0.10624743952986695, 0.1690172289888705, 0.1677229847278326, 0.0787832870358421, 0.1366714952934173, 0.19922933120641018, 0.2629132550810614, 0.1638558341730987, 0.16573723886282216], [0.01015427231322974, 0.027061715016081452, 0.05639674232131051, 0.08694114283688607, 0.059015656025299144, 0.04970055929715595, 0.03202714262560251, 0.07162614124676875, 0.07789365211201292, 0.04406420529008873, 0.010531756392259513, 0.08495060892234887, 0.05522191584590943, 0.015470060658821417, 0.03788762523101703, 0.034733932360165545, 0.018375076601401936, 0.011152524140573317, 0.05501100034903615, 0.017407727803313927, 0.09647146813691625, 0.04284326415208559, 0.12683845035010768, 0.047974371681770975, 2.787477960509639, 25.948041754384196, 43.25799280597318, 47.241701003043886, 35.56216132256293, 29.93551738800541, 36.93012714385986, 40.59757463393673, 23.085431283520116, 1.8921233016637065, 0.08021230914539869, 0.7986484996734128, 1.1961962835442637, 4.097642509206649, 5.602397313041072, 2.9165227134381575, 3.317178362800229, 9.027539895426843, 23.551938379964522, 49.282470979998195, 54.71341609954835, 51.96636845988613, 50.41565156752064, 43.313058960822325, 43.92551745137861, 46.47007665326519, 48.478012469507036, 48.22902825570876, 49.411116876909816, 51.110852456861934, 52.90615266369235, 50.36442933544036, 47.30049340955673, 51.89367517348259, 44.410734253544966, 35.84110067736718, 36.33377390523111, 38.36586759936425, 47.43316365826515, 49.21355885844077, 51.07233478176979, 51.32897153977425, 49.47962499433949, 51.93105143885459, 49.872885750186065, 49.88778291210052, 45.847702410913286, 40.02985077519571, 36.250549054914906, 36.59733364658971, 34.65688220916256, 36.04357734803231, 38.25202864985312, 44.89161291430074, 47.280120618881725, 47.147583730759166, 48.2768968612917, 44.47345687497047, 41.350053894904356, 38.46022805859966, 38.314100157830026, 42.333599982723115, 47.55513760351366, 48.84096507103213, 51.80339005685622, 39.82233385885916, 48.83374398754489, 51.50082234413394, 48.37115533890263, 52.22927316542595, 49.865668589069, 51.81464725925077, 48.893422849716686, 47.88594245910645, 39.589278390330655, 37.34878524657219, 35.9977013064969, 38.231396982746745, 34.652826478404386, 36.955210701111824, 38.14427329647926, 44.43135023117066, 50.35881642372378, 52.62994720089821, 52.7992602317564, 51.77019896045808, 52.113598546674176, 50.41272940174226, 50.168601082217315, 42.80778315759475, 40.25208442441879, 37.42641679702267, 38.480561625572946, 40.78142396865353, 49.57329903879474, 52.692995379048014, 52.78357075106714, 53.63487805089643, 50.51578183327952, 50.404111954473684, 48.08153537011916, 47.05294086087135, 44.98043106448266, 45.221256748322524, 42.76926940487277, 42.03789249543221, 42.320122718811035, 44.83885703548309, 47.68671743331417, 52.305320078326815, 53.66051466234269, 56.3987369691172, 46.93869790723247, 31.199571778697354, 13.45261867969267, 3.7409149542931592, 1.4728577218709455, 4.754693200511317, 8.092400758497178, 6.848745634478908, 3.1142756246751357, 1.815239820749529, 0.15434355024368535, 0.38535907984741274, 7.281103105314317, 30.63768440677274, 36.81273060460245, 29.02829670136975, 39.68513719497189, 48.36813903624012, 35.31735835536834, 6.314240819023502, 0.01262901305791832, 0.026664609510091045, 0.04042345669961745, 0.03419230053682001, 0.08288272311009708, 0.07277923380775798, 0.01844042581656287, 0.008081112943229177, 0.08301648206167644, 0.09947348325963944, 0.062385634669373115, 0.04813294422121779, 0.04658819303937978, 0.06953940967157965, 0.005706819731952442, 0.01300439422559594, 0.056263944810076114, 0.07507706091048257, 0.0918751550958522, 0.05326336227177132, 0.0374337985751129, 0.0070159869069503925, 0.03549199551343918, 0.05855311511925632, 0.06747330884419142, 0.08362003677194157, 0.06091539319905062, 0.04629301553171489, 0.030150524070186, 0.05883110161390036, 0.16166523639713565, 0.010536547314615981, 0.04718415581831529, 0.04357813399345164, 0.06798961380076024, 0.03775937062117361, 0.08352391572008211, 0.009228443565417924, 0.04460363461065196, 0.008593230271681903, 0.0574271573925451, 0.04588066870647092, 0.06419683123127588, 0.10064924436230814, 4.09708381660523, 30.551060822702226, 50.50481096390755, 51.866198970425515, 39.111823958735314, 30.866374277299453, 46.76980849235289, 47.04734363863545, 24.380478282128614, 2.6404672813030983, 0.08901616092771293, 0.5078041998128737, 2.7174692913409206, 4.919065515841208, 6.717265825117789, 3.2876912095854363, 4.6690031405418155, 10.643970216474226, 26.245520191807902, 53.01157420681369, 56.74883204121744, 54.059058850811375, 51.15120972356489, 46.05967121739542, 44.683790053090746, 48.22885567142118, 49.56259096822431, 49.921005387460035, 50.86455506663169, 53.69573362411992, 53.19840062049128, 53.671544367267245, 51.412459188892, 54.75179649168446, 46.07920462085355, 36.48114519734537, 38.438152959269864, 40.115813439892186, 48.53155674472932, 51.84059766031081, 52.6975884745198, 53.96168601128363, 49.885135312234205, 54.13506654001052, 51.955228928596746, 51.62630681068667, 48.747965674246515, 42.48971031558129, 37.86774619933098, 37.97952590450164, 36.51409310679282, 37.46220450247488, 39.66719235143354, 45.33275796521095, 49.02022523264731, 47.42429125693537, 48.97598089710359, 45.46582829567694, 43.443222814990634, 40.56749789945541, 40.298980282199004, 44.1867551495952, 50.04461888344058, 49.9311407919853, 53.837342954451046, 42.300440265286355, 49.44442564441312, 53.18402121143957, 51.907740792920514, 54.64016191421017, 51.88158642861151, 54.06140050580425, 51.42642674907562, 49.377623758008404, 39.92239352195494, 40.58603502088978, 37.29985760104272, 39.75454353517102, 37.544303632551625, 39.25893245204803, 38.962887640922304, 46.85663800085745, 52.684272027784786, 55.893590604105306, 53.1588395949333, 51.97551542712797, 53.51459464719219, 52.250567713091456, 52.21793751562796, 46.63781681368428, 41.375761109013716, 38.28776144212292, 40.70931511540567, 42.404590960471864, 50.99524844077326, 53.93293111555038, 53.31807997918899, 55.45904297982493, 52.6910420387022, 52.49739070092478, 50.474585179359686, 48.361773029450454, 44.69815769503194, 47.51114429966096, 43.934319250045284, 43.49402535346247, 43.53755581763483, 46.05110083856891, 49.61877499857257, 54.345627215600786, 54.96841330682078, 56.8748930961855, 50.47901353528423, 34.399664940372595, 13.836497126087067, 4.934552013874054, 4.809219048869226, 8.7753560081605, 9.25652394371648, 8.808510822634544, 4.055752821506993, 0.9369619971802159, 0.2041270998456786, 0.4040339745340809, 8.20240019790588, 34.855173710853826, 44.35260472759124, 34.80416720913303, 44.54042742329259, 55.19054889678956, 41.1139311329011, 8.644478282620831, 0.04148939909834055, 0.06600166926340711, 0.00854254110656198, 0.012449544512726849, 0.010779925787280644, 0.056974809286334825, 0.011832982587117341, 0.021357273029523994, 0.11198207495674012, 0.04730280751602785, 0.06703322197520925, 0.02584933299541233, 0.06000099448306907, 0.04954641091547186, 0.04481270383562773, 0.035355704641270067, 0.037196161931440715, 0.03413194813014519, 0.03642345117705484, 0.056723057472657774, 0.12258357503601622, 0.08006442353249558, 0.20032718116717957, 0.2043704859792225, 0.17518294975161555, 0.23031363984750164, 0.15646487834953493, 0.25854888281995253, 0.13214439063543273, 0.15016645583654606, 0.1727111364204076, 0.1360076494635113, 0.13721722568715775, 0.10094130006168159, 0.19528662906058375, 0.10028320755208693, 0.26814076328469866, 0.15421749813662422, 0.1684899766358637, 0.108685843766697, 0.15064981135149158, 0.16276221301767135, 0.213276258098983, 0.22058220880646862, 4.867551067183095, 33.938170633008404, 57.49315669459682, 59.79984375738329, 47.666603519070534, 40.31840385929231, 49.08676432025049, 52.74058549634872, 29.93850035052146, 2.915027309809962, 0.2997689790302708, 1.5524951969423604, 4.337061287895326, 15.320424879750899, 12.62263338412008, 7.5745831766436185, 5.902089438130779, 12.09744861049037, 30.968363746520016, 55.119620676963564, 57.67326016579905, 56.12199021923927, 54.51619148254395, 46.57456859465569, 47.5165650152391, 51.45508358555456, 52.152300573164425, 52.4116986797702, 55.018745160871944, 57.645458406017674, 55.53994186462895, 56.297433914676795, 54.14202874706638, 55.79365253448487, 48.8581411300167, 38.721438300225046, 39.89462314113494, 42.114653279704434, 52.330729192303075, 53.79239651464648, 54.81168716184555, 55.843733356845, 51.259416149508574, 55.035062220788774, 53.904007557899725, 53.17203837056314, 50.669142584646906, 43.54823643161405, 40.38742972958473, 39.693162364344445, 39.023429424532004, 40.086540791296194, 42.95059665556877, 49.85414074313257, 52.134489090211936, 50.48243384207449, 50.770928090618504, 48.6582257670741, 47.00644900721889, 42.893953707910356, 42.516994322499926, 45.973214334057225, 51.75325039894351, 54.1992090594384, 55.05106156872165, 46.32632963119015, 50.40108780707083, 55.10053834607525, 53.29372598278908, 56.04928908809539, 54.64076988158688, 56.70503485587336, 53.37783728876422, 52.40415203955866, 42.83399243508616, 42.31526290216754, 38.0349019265944, 42.0386455905053, 37.51965938075897, 40.75364966546336, 41.52608594586773, 48.12804291325231, 54.237907163558475, 57.3710140874309, 53.868149249784416, 52.52068957974834, 56.34741667778262, 55.14430415245795, 55.00962957259148, 47.81593991864113, 43.7018286028216, 40.367049094169374, 42.13863857330815, 45.62730443093085, 53.61498378938245, 56.00910440568001, 56.56182127614176, 57.78669903355261, 54.42486693782192, 55.082248333961736, 53.804528405589444, 51.83012493195073, 48.735519993689756, 51.575774915756725, 46.77007129115444, 46.121664277968875, 45.86780455804641, 49.511988470631266, 52.19561922934748, 57.64596831414008, 56.83203727968278, 60.04079887943884, 49.160650007186405, 36.0051538098243, 16.101698260153494, 6.45165664534415, 6.892202063914269, 11.879081437664649, 15.983744744331608, 13.971977753023948, 9.613999935888476, 3.8780174812962933, 0.3340837425522266, 0.6626843793257591, 10.262276530265808, 39.73564163331063, 50.699219319128225, 40.42790074502268, 52.98687896420879, 63.66430013410507, 48.12249668182866, 9.94460573119502, 0.18074916074833564, 0.17978709221126574, 0.1646714879860801, 0.13111925774043606, 0.14212627114067156, 0.201367482603077, 0.14352775238935025, 0.06651895481251902, 0.23696571918985537, 0.16205888301614793, 0.23792290008596836, 0.1445853827340949, 0.17358683620489415, 0.1690139348107961, 0.15891422998280297, 0.12230743098283008, 0.12498484699115639, 0.17148945600755755, 0.20584710513151463, 0.11238988654147233], [0.03015311153215026, 0.014857182658517794, 0.06845699638248452, 0.12664826902290507, 0.062000847857205145, 0.04952085805275748, 0.0325637738100223, 0.016341599628269192, 0.036059536430383884, 0.04251315686551314, 0.0480925867093667, 0.05171614811725674, 0.030848428253985705, 0.07302072004324968, 0.04413991392920575, 0.09512087044816825, 0.024466797101101088, 0.03908007172867656, 0.037425563129926884, 0.03269675135191891, 0.0166143728945885, 0.029411028972977114, 0.016798406366198775, 0.050158813941262426, 0.45121760558216806, 12.841315327152131, 40.25527723373906, 45.40221529622232, 33.83370222583894, 22.93977406717116, 24.399193871405817, 39.76163518044257, 27.739282308086274, 5.206507098290229, 0.2994920229238849, 0.1508584630585486, 1.4049800028724055, 2.5320262485934846, 3.7523633722336065, 1.6727656077954078, 2.207035571336746, 10.27260511152206, 32.00953533572535, 51.50393670605075, 56.28747501680928, 52.63791353471818, 48.38597013104347, 48.0814726121964, 48.656794101961204, 50.335133152623335, 52.064341422050234, 52.70367599302723, 50.93134910829606, 51.83572215418662, 51.379452443891964, 48.42102043090328, 50.2162657245513, 51.94839615975657, 42.12300008343112, 37.437921108738074, 37.023965927862356, 43.8172874912139, 51.37299622258833, 50.352066024657226, 52.02489414522725, 47.65397348711568, 51.26476626242361, 50.22906834079374, 50.06249704668599, 49.35097125268752, 39.89630583793887, 37.2156011673712, 37.460415901676306, 35.56003539792953, 35.93784986003753, 37.187881777363444, 42.77414491099697, 50.49771147389566, 51.03586066153742, 52.04224671086958, 52.31041131481048, 49.070423726112615, 48.6290237211412, 44.063851602615856, 43.116803169250495, 41.300545738589385, 49.11901404780727, 46.880234979814105, 53.3867802927571, 37.065597964871316, 41.878393234745154, 51.23771367534515, 48.49435306364491, 49.47063492190454, 50.404590483634706, 51.272591390917384, 50.41112907471196, 48.19054588194817, 41.447144323779696, 37.79869679481753, 36.02864096241613, 36.27529528833205, 35.15299143329744, 37.71153780721849, 37.04462505155994, 46.95859216874646, 50.70138054509317, 51.85543598667268, 52.36676008470597, 48.505912288542724, 52.67146941154234, 48.82092960419194, 48.426115589757124, 41.519280633618756, 36.43882674555625, 36.649560005434104, 36.34856124078074, 37.98505644644461, 50.358345739303104, 51.57322929751489, 49.315332597301854, 50.426465542085715, 55.497537120696045, 51.87240416003812, 51.63157063145792, 50.54836888467112, 50.85182305305235, 51.442261357461255, 50.419797512792776, 50.7997614337552, 49.42511189368464, 48.973011662883145, 51.44677600552959, 53.4134877112604, 56.17692301350256, 55.440184224036436, 43.68657058285129, 27.62495698467378, 9.318641539542906, 2.99444206780003, 4.659259482737511, 7.4231326195501515, 7.5094992883743785, 5.885313460903784, 2.0056928333736237, 2.8845377458680064, 0.23987501469110292, 0.5309674504303163, 8.996151128122884, 36.22855240298856, 39.41383469489313, 38.60155497827838, 48.34515002466018, 50.47511469933295, 27.30028867721558, 2.0266667272775405, 0.016204724614057812, 0.018818821540222536, 0.06789382982758746, 0.028442835562952587, 0.029509934754441344, 0.07605933884699499, 0.00982046865242263, 0.020044184920768586, 0.039950194393074324, 0.02063570822018289, 0.04646001503832879, 0.016885617815498865, 0.030977895197969292, 0.03543983258667492, 0.0460744736295554, 0.07127255336531708, 0.04045688494619343, 0.0315537596602113, 0.029701052624131405, 0.04400637714312442, 0.058748387100715796, 0.042463326676478313, 0.009952202259052184, 0.06189740300478955, 0.05814787375951006, 0.05170158478581617, 0.039822146626970464, 0.10612629804640047, 0.035962289229275725, 0.06890986159804367, 0.07637811569316734, 0.027631383742235845, 0.018743986241339196, 0.09099282865082065, 0.059976586921801495, 0.02938233898021281, 0.03527313185435149, 0.08769340287413328, 0.03221958582740157, 0.0664676575651092, 0.01731869497997386, 0.01895611598757246, 0.07981796538637531, 0.08769455966689894, 1.1918403688938388, 17.7006132371964, 47.286361109825876, 51.18684053421021, 37.19423993941277, 27.749711890374464, 30.899828172499138, 47.04381742785054, 30.4248664071483, 4.28285462241019, 0.2794973426047833, 0.3889601833878025, 2.4357678524909483, 5.2236767834232705, 5.998180152908449, 5.283170803900688, 3.5646164273062064, 11.146237561779639, 34.77736957611577, 53.230391471616684, 57.85089254379273, 54.13966355785247, 51.158242533283854, 49.185396240603545, 49.40000480221164, 50.92297092560799, 54.02278869382797, 53.07411639921127, 55.044848534368704, 53.36030821646414, 51.70842947498445, 49.82483279320502, 53.17849459186677, 55.08179333902175, 45.54236550484934, 39.28393363952637, 40.45394528296686, 45.69354149603075, 52.970114754092315, 51.295305836585264, 53.712195811733125, 48.209577222024244, 52.1312217558584, 52.254866630800315, 52.47642170998358, 51.002673487509455, 42.715497632180494, 39.0518234622094, 38.89534050418485, 37.47812148063414, 37.05904368431338, 38.05844399236864, 45.60726111935031, 52.086640096479854, 52.34494778417772, 54.502231767100675, 52.87165934039701, 50.93572255103819, 49.49490262616066, 46.26135556928573, 44.13084568515901, 43.52107401817076, 50.78315019607545, 49.80040034940166, 55.93078644044938, 40.70208618717809, 43.65923558512042, 51.55681417834375, 49.44752823921942, 51.41995091592112, 52.835495087408255, 53.34569346520209, 52.23305825264224, 50.58565101315899, 43.40968655001733, 39.16750200333134, 37.8106874804343, 40.17326047343593, 37.52955159833355, 40.049399868134536, 38.70164602033554, 47.47728640033353, 52.6846799542827, 54.10646461671399, 52.08622824761176, 48.780125187289336, 53.854746510905606, 51.389328971985854, 50.66154103125296, 43.71532940095471, 38.44995929348854, 39.14519156179121, 37.477819458130874, 40.566544763503536, 52.45745312783026, 54.17336064000284, 49.591824393118586, 53.20285643300703, 56.7134444175228, 54.161424867568485, 53.261515478934015, 51.70798624715498, 51.95843350502753, 53.17794546004265, 51.16053711983466, 51.36806580328172, 51.54494900857249, 51.87726397668162, 53.28582632926203, 55.57415669964206, 56.962691430122625, 57.78459664314025, 44.88089699898997, 30.29259231782729, 10.308549711781165, 4.349280941870905, 5.839801219201857, 5.4840187103517595, 7.7897619528155175, 8.007463303304489, 4.46386710289986, 3.239918947219849, 0.16950439962167896, 0.4911414197375698, 9.93036654687697, 40.18452944294099, 43.4806892948766, 38.464483830236624, 50.47642869334067, 55.721571137828214, 33.356345853497906, 4.0440675904673915, 0.01657288923348871, 0.03601842049148775, 0.10157929042414313, 0.011995144248489412, 0.04500284685843414, 0.04122466209434694, 0.032667793228381106, 0.0021700412429298366, 0.05005181061043855, 0.019880131022223545, 0.05848455791091246, 0.01574073771705791, 0.05875300661089921, 0.015679495690781024, 0.03977991986058412, 0.023787941693538622, 0.035453580034476136, 0.05217315403804664, 0.03955219639465213, 0.021959929501697905, 0.18179707709820042, 0.19161420273444346, 0.15676136969798998, 0.31101193218942613, 0.12086252020972392, 0.1471901123201655, 0.23845900841537984, 0.1992871248794179, 0.09776817920107035, 0.1299146304447805, 0.17632900196458065, 0.15445210490255587, 0.10180245183648602, 0.4240376334036551, 0.14984388685514852, 0.14730433602967571, 0.13644723071446344, 0.15489864223186048, 0.2156109723352617, 0.23244298123303922, 0.14716735950881435, 0.12373255370485207, 0.17634081504037305, 0.2742378732129451, 1.3795066600845707, 19.35925022248299, 53.553896796318796, 58.34733516939225, 44.70006396693569, 35.83494647856682, 34.150986671447754, 51.04998119415776, 35.887423869102236, 7.214839073919482, 0.6060354868250509, 1.0291295450541282, 4.761426929504641, 7.986222688228854, 11.507516291833694, 7.751902745616052, 5.856603672427516, 13.489133004219303, 35.45524927877611, 54.4266123925486, 58.26398872560071, 56.187470266895915, 52.4932094543211, 52.05169570061469, 50.98597988005608, 54.37128736126808, 56.91101812547254, 56.401298276839725, 55.32539606094361, 55.36595729089553, 54.239625161693944, 51.47893159620224, 53.738526682699884, 55.73723316192628, 46.541926630081676, 41.141929011191095, 41.234563627550685, 49.23394733859647, 55.32032051394063, 53.43499798928538, 55.27439348159298, 48.05474165947207, 53.21092867082166, 54.70052326879194, 55.08700616898076, 53.47042091431157, 43.67275207273422, 40.170954119774606, 40.02289641288019, 38.74633358370873, 38.21720192509313, 39.437631714728575, 46.05840821419993, 54.85230722735005, 54.002345300489864, 57.366746548683416, 56.3419920398343, 54.473186615974676, 52.22610389032672, 50.02986684922249, 47.90015712861092, 45.60329168073593, 53.72519454648418, 52.28967374370944, 57.76557314780451, 43.26126406269689, 45.55654487302227, 54.7550912826292, 52.08893468303066, 52.074998501808416, 53.97878754523493, 54.22273151336178, 54.67668702525478, 52.69168138504029, 45.96389086015763, 42.20884899939261, 39.932983921420195, 41.01687208298714, 37.87466918268512, 41.00223379750406, 41.107043450878514, 50.83718476756927, 56.45081427789504, 56.027531700749556, 53.94419616268527, 49.43424709381596, 57.12854885285901, 52.507953643798835, 52.85258877661921, 45.130261682694965, 39.53447895665323, 39.369994363477154, 39.99375712487006, 41.08986346952377, 54.62535888917985, 56.114427889547045, 50.301777316677956, 50.54474853700208, 59.549643608831595, 56.18131214572538, 55.77464472862982, 54.18142503307712, 55.95275171341435, 57.59045108672112, 55.52125961549821, 55.172831550721206, 53.59257921095818, 54.98261620921474, 56.33696356127339, 58.08545028009723, 60.318714495628114, 59.60667487113707, 48.8540893216287, 30.67606479890885, 11.383250701812006, 6.1170931785337395, 11.523721564200617, 16.24211322876715, 17.792465340706613, 13.686315455744344, 8.469417998867652, 6.230166775564994, 0.47746295049305887, 1.0832882840787212, 12.535797992060262, 45.5095862573193, 52.93715507753434, 51.691516214801425, 58.96904260881486, 62.469514800656235, 38.29760266888527, 5.78746356310383, 0.13518712333133145, 0.18447247063440664, 0.30624980707803084, 0.118943017967526, 0.1673413963327485, 0.21188148778052102, 0.135178022206791, 0.15018186952558257, 0.16256001177093676, 0.21202047145174396, 0.17186966544437796, 0.06770511172832021, 0.1946944737386319, 0.17807649448513987, 0.1385182268436878, 0.14618295184787244, 0.16670661587868968, 0.18078427821878465, 0.1192457146281677, 0.14537333480773434], [0.0863032903702509, 0.041197186350942626, 0.09619982868072488, 0.0681785464046463, 0.02308474384218214, 0.06308949710200391, 0.07325702752437323, 0.05971389920300534, 0.050069920928968545, 0.031090102181018844, 0.026597967521557887, 0.030804182845918886, 0.04726061905403772, 0.016137264826665484, 0.021579321699156877, 0.02360985306422076, 0.049714774058590976, 0.02341430912154817, 0.032847237833324945, 0.05422646119709938, 0.04224306873736843, 0.09370350819681922, 0.006951412398202886, 0.026256342103043874, 0.1334660608441599, 7.915872527707008, 28.488792334833455, 47.42110236998528, 48.410571236764234, 31.217934354659054, 39.67516260762369, 44.495547663780954, 37.07334464596164, 10.94388738755257, 0.3459258377552033, 0.19741112877043987, 2.4378256259425997, 3.230619497837559, 4.011083399095844, 5.070523917675018, 2.675578868196857, 10.731343953840195, 29.961085357973655, 43.9737194584262, 53.531005843993164, 52.87386763480402, 53.459442200199256, 50.2002546095079, 52.45036148255872, 53.64134211694041, 52.80791298035653, 51.79954613408735, 51.72058882251863, 51.99551559263661, 53.20113451250138, 52.59649330569852, 52.876338728012584, 46.9989102117477, 36.214804495534594, 36.63245062674246, 38.34672251055318, 47.41560320700369, 50.19285701936292, 51.83288628055204, 52.35695808164535, 49.93365895363593, 53.80879202196675, 47.80646739467498, 48.68960080608245, 42.081917178246286, 38.399372485376176, 37.62343352840793, 38.04378217266452, 35.654768482331306, 35.0457852117477, 35.96621644112372, 46.00555819849814, 52.1443263946041, 52.58734633845668, 51.04145396140314, 51.61937990496236, 50.81480764573621, 52.79707939394059, 48.34568346700361, 49.83948284579862, 47.27268380503501, 48.48545320572392, 45.846937548729684, 52.367560248221125, 38.07511014323081, 40.46935627537389, 53.31060394164055, 50.781761677034446, 51.052448364996145, 49.879804811170025, 51.61500646222023, 50.94961950855871, 49.209679634340354, 43.72306039256435, 37.675620663550596, 36.342685530262614, 36.98664849804294, 36.10488007145543, 37.38977401487289, 37.3546491899798, 45.66128000136345, 49.855054655382716, 54.779829671306, 51.93669572953255, 53.52009773254395, 52.396978024513494, 48.97820095862112, 47.786122060591175, 39.521923449731645, 37.95921979411956, 36.28574840484127, 37.07263077459028, 39.10221415181314, 47.855791199591856, 51.895169596518244, 49.60394059458087, 49.85947124419674, 50.567894443388916, 52.75295665187221, 51.93402459544521, 52.01794762765208, 51.43918229687599, 51.07866156485773, 54.443129493344216, 52.55435528293733, 52.280252210555545, 52.500877688007975, 51.24437385989774, 53.8595082682948, 56.14444578847578, 56.08832059368011, 44.01249600994972, 24.887778028365105, 6.75953426668721, 3.0248497522646383, 2.48564985971297, 5.175715511845005, 6.369107423290131, 7.642146493158034, 4.842267959348617, 0.49177733400175655, 0.18518602024883996, 0.9266318837481161, 11.231756018054101, 35.72883852066533, 36.95135893360261, 37.67326331907703, 41.01544434024442, 44.86215199193647, 20.64612300165238, 1.4340532234599515, 0.07462375902480657, 0.044372873606100205, 0.03443243845756497, 0.03338247665294236, 0.018900407988938595, 0.021977467169504494, 0.06808909031772806, 0.032206286541036064, 0.05997453380616442, 0.05497899319555971, 0.05383105257586126, 0.009334505565704839, 0.09300521905383757, 0.025570653191196824, 0.03399517462258378, 0.029188187402342598, 0.09287907501622554, 0.11713585485854458, 0.03341828743296285, 0.015147478270885206, 0.09065139858472733, 0.06570460334900888, 0.03676577756601957, 0.04175030183227312, 0.053428569132642406, 0.023909291935964458, 0.018880799968516635, 0.020142805334481022, 0.08564049408080117, 0.04987894287032466, 0.013761923032542391, 0.01718275650824991, 0.04628509035213821, 0.020015642399929708, 0.03386448385314115, 0.05064682344034795, 0.02634357078932226, 0.040415248067508784, 0.03435827348561537, 0.04599957704363812, 0.01225063648645676, 0.007451191880635076, 0.06146923646390919, 0.026529396906675353, 0.19602267101647394, 10.40592255130891, 36.54805691011491, 52.19916505198325, 51.64726011214718, 35.87096168148902, 36.4574501591344, 45.58419366036692, 38.546171111445275, 11.5746594244434, 0.3482096071445173, 0.2357528794316515, 2.6192283822644145, 3.1729572242306125, 5.074768902794008, 5.663638259133985, 3.491280362490685, 11.202728517593878, 32.97173784625146, 47.11338458522674, 57.05942100094211, 53.56365957567769, 54.26753674784015, 52.55276672301754, 54.31603685502083, 55.922208216882524, 54.71284735587336, 51.131354685752626, 52.85401259699176, 51.88601478453606, 54.89466882521107, 54.39746525979812, 54.34806692984797, 50.710166654279156, 39.63333837447628, 39.08412810294859, 39.64226568898847, 49.372128517396995, 51.596775285659305, 54.75183179301601, 53.16280511117751, 50.86362546490085, 55.69264365780739, 51.247562746847834, 50.75951791578724, 44.99179809324203, 39.29737952447707, 39.788217083100356, 38.899647266634055, 37.126441770984286, 36.33418967646938, 38.577675588669315, 47.784996340351725, 54.62269952220302, 52.37587567298643, 52.51409999785885, 53.28204516441592, 52.34642259536251, 54.627473046702725, 51.37796194322648, 50.78699804121449, 48.55247474485829, 51.02525065022131, 47.846306908515196, 53.8559663680292, 39.34755840609151, 41.4534907187185, 53.57280262054936, 53.617168549568426, 52.61224162194037, 51.39589501965431, 53.91474700743153, 52.81993896730485, 50.76260482111285, 44.186421748130556, 39.323278934724875, 37.84463167190552, 37.57445881443639, 37.43340253829956, 39.68548628591722, 39.41605083404049, 47.210541694395005, 51.462587079694195, 55.6260928030937, 52.00103436746905, 53.014221806680005, 55.01760767352197, 50.14712218315371, 49.143470025831654, 42.09193098929621, 38.68403457826184, 37.98084382087954, 38.675405363882746, 40.47385523396154, 51.02614495062059, 53.818464586811686, 51.96574480302873, 49.584999469018754, 52.05384908183929, 54.31252633371661, 54.857202345325106, 54.48582057029971, 53.41853972404234, 52.52981301276915, 55.32126580515216, 54.0739756245767, 53.73288239202192, 54.30951395342427, 51.44378323708811, 56.13829158967542, 57.82764073341124, 55.97585055135912, 46.470174712519494, 27.657391063628662, 8.818152008518096, 3.0836799115903917, 5.144886662883144, 5.932605968367669, 6.046392946474015, 7.6821978149875525, 3.534194524249723, 1.0685385787679305, 0.11120062696957782, 1.104873209711044, 12.55663852537832, 40.855650901794434, 41.88755981383785, 43.571158762901064, 49.04306519416071, 52.6933797713249, 24.931010392404374, 1.8468929803179157, 0.05890346627922789, 0.030653361201045976, 0.07461318701145149, 0.027100454167192502, 0.022790916564483798, 0.04618756352893768, 0.0019047285956818793, 0.021138273389829744, 0.015350847801704322, 0.027004038171482184, 0.04485932794669944, 0.042698569295387116, 0.0053657540364281065, 0.034681493641748544, 0.03528925034427836, 0.046243208325317794, 0.012255770233159345, 0.03331219191632925, 0.051019337523968956, 0.039653921379677715, 0.15662005711947719, 0.205356425816013, 0.164078566576204, 0.1890635436340686, 0.14729692029856867, 0.13657581091167467, 0.16773400107218375, 0.1788470870064151, 0.14725490803680114, 0.1299218623147857, 0.11767557146207941, 0.16153803515818813, 0.1250173521017836, 0.092378176087814, 0.09316944532216558, 0.1239116574006696, 0.14072957028064037, 0.09844282687070871, 0.11863990761940518, 0.2130966564460147, 0.12965319527974054, 0.1853580069878409, 0.1641135001855512, 0.14223952957939717, 0.2986552404059518, 11.602985801235324, 40.51315738308815, 60.19201409432196, 60.9427910466348, 43.353380926193736, 50.391026927578835, 56.238476768616714, 46.76853372204689, 13.749036115984763, 0.7402080645964992, 0.4927607457483969, 3.964385130713063, 8.718019781574126, 11.983558670167001, 13.085501501637122, 5.0733921508635245, 12.22097973669729, 32.48656811252717, 46.34361943890972, 57.69524112824471, 56.825255501654844, 55.84461981250394, 55.16990546257266, 57.22849476721979, 58.76619331298336, 55.8476439599068, 51.28913202593404, 54.83433884959067, 53.300860774132516, 57.97998559090399, 56.87757599738337, 56.36861316619381, 52.658498133382494, 41.427250062265706, 40.743396589832926, 41.01439706740841, 51.36144092006069, 52.924811378602065, 56.536404317425145, 55.26266951714793, 50.86113083747126, 55.958784318739376, 52.3506469880381, 53.5640125889932, 45.19580841064454, 41.132076017318234, 42.52115203488258, 41.52114768182078, 40.41460783250871, 37.76675301213419, 40.67360977972708, 49.585725107500636, 56.554870836196415, 54.1117480493361, 53.51745797741798, 54.74148850287161, 55.074438894948656, 56.723403315390314, 53.16310713368078, 53.98477308211788, 51.426269854268725, 53.00986013104839, 49.52255533587549, 55.256091702368956, 42.84390818688178, 44.321735674335116, 55.89218639558362, 54.590265443248136, 52.90246563573038, 53.25586726588588, 54.83165202602264, 54.45632434660389, 54.39747310453846, 47.73543719322451, 40.755524558405725, 39.64366205276982, 41.04703510961225, 39.72098373597668, 42.433718481371486, 41.43801304601854, 50.740419895418235, 54.40147392211422, 57.8780431901255, 53.58177308113345, 54.13891830751973, 55.852837178014944, 52.31613405289189, 50.68529098264633, 43.50710645798714, 41.812446425038004, 40.05626401593609, 40.693480507020034, 43.28824996948243, 51.88460273127402, 55.34620423470774, 54.077988209262976, 51.96634100329492, 52.33041148031912, 54.621318847902366, 55.73751165020851, 55.959843358685895, 54.55521122101815, 53.78362609494118, 56.18765854066419, 56.1520944103118, 57.50077393747146, 56.96271888671383, 54.356021496557425, 57.251577915683875, 59.216383349510934, 58.19832824891614, 47.978541774134484, 30.509934771445494, 9.115898147706064, 5.423735312877163, 9.091083272810906, 13.561483083232758, 13.773133197138387, 14.165001511573793, 13.150589312276534, 2.1014701262597115, 0.32172165750976534, 1.6926434443842981, 15.345910479945523, 46.851833097396366, 48.77423770966069, 51.043854451948604, 54.38212879242436, 61.6069346089517, 29.241928592804943, 2.8994344174861912, 0.30757100231224493, 0.11687055861036624, 0.15684272823554857, 0.10395147402079837, 0.11040731994134766, 0.18764402867565233, 0.09339418487563249, 0.15219033755842717, 0.19607268123617097, 0.12379866709271747, 0.18674709293390476, 0.11305051480209637, 0.10252379256510928, 0.14193110258108185, 0.31385525219863464, 0.20043660916628378, 0.2007178706868041, 0.13230494734260345, 0.28436344116926193, 0.2565274525794291], [0.03800282570263071, 0.0057864933548825645, 0.012731862276972783, 0.06445618646760141, 0.06324023256198534, 0.05121940521583442, 0.03299384790983412, 0.02752176805159017, 0.07941246738717442, 0.08446641837156589, 0.09556003035076203, 0.058834453248569084, 0.05196604982859666, 0.018252000745926655, 0.01021570298865798, 0.04445067749569013, 0.046309639639671774, 0.052066468633711345, 0.054326186692642595, 0.013117080013598166, 0.11335105109479159, 0.03816097306327955, 0.025979983545238935, 0.037860509548937125, 0.03215697346135013, 1.9313108440368407, 23.679644869219874, 49.05744068084225, 44.77882123762562, 34.09256689010128, 36.871876024430804, 44.74689314442296, 32.94151598407377, 15.225775145715284, 2.598990423064078, 0.30611702871899454, 3.5827453770945152, 3.2449655667428052, 4.214747567330638, 4.278058544281991, 3.4416057505915245, 7.183457170763324, 24.734660463948405, 42.49379350293068, 55.259853255364206, 55.879917221684615, 54.25212575543312, 53.365846603147446, 52.15020994986258, 52.02867923244354, 51.43056092723724, 51.0891225261073, 54.61428996055357, 51.529914563702, 52.664432679453206, 50.7564074762406, 46.23797039831839, 39.680932414147165, 37.40023497612246, 36.69557725229571, 39.45248965294131, 47.726823668326105, 50.64843639250725, 52.56133710184405, 50.99412272053381, 50.65309224590179, 51.71113198803317, 50.00045691767047, 47.7314716769803, 39.61041212081909, 38.34978588165776, 36.365682386582904, 37.44980589036019, 36.67726370596117, 40.13277376851728, 34.98694965916295, 44.253702163696296, 50.206808890065844, 51.23675269465293, 51.40612063869354, 48.82285156557637, 51.09888138309602, 49.62988315090057, 49.495553739609264, 49.86546462582004, 49.545148188068026, 52.7013421827747, 52.84022938820624, 52.644981645768695, 38.58190782608525, 44.17234828395229, 51.93668004005186, 51.38163328170777, 51.50535268168296, 47.678437309880415, 50.006489522995494, 46.404220058072, 44.41887317165252, 40.3393179370511, 36.438258001881266, 36.24417520338489, 37.83097397896552, 35.29216889412173, 36.635474774145315, 39.51727544107745, 47.36028602046352, 49.513294619898645, 53.570100107500636, 52.24813584358462, 50.48010395419214, 50.32649609350389, 49.59522508805799, 45.12648051784885, 38.99245054491105, 41.36181708305113, 37.16410044700869, 35.97837186628772, 36.31420520044143, 40.99870758671915, 50.98843528378395, 51.8014524059911, 49.81807062702794, 52.09295903482745, 53.009475738771506, 51.241906689059356, 51.67017067632368, 49.84640190678258, 53.7129645962869, 53.76187262996551, 54.37849275527462, 55.09892625193442, 53.063784876177394, 54.273404613617934, 54.741413977838334, 57.510462191797075, 51.93050622940064, 39.40421312086044, 22.22138216418605, 5.40756828361942, 1.6339391686262625, 3.757542616898014, 3.1890453157886385, 3.608548934421232, 5.504130173114039, 1.9105032831430437, 1.4237921805151048, 0.13913010126881062, 1.475388140928361, 14.73749791422198, 42.58655755750595, 42.443132169785045, 31.96881917215163, 43.75728699468797, 37.99666666215466, 13.476277435979537, 0.6561180865091663, 0.019552622688934207, 0.03475027301559045, 0.057669482494313876, 0.06842492794197413, 0.02092922714749171, 0.015712944047165014, 0.1358721131879476, 0.01860532049660481, 0.023581839144049634, 0.04999722684583357, 0.04652670682257703, 0.09729132011172273, 0.07805176499870517, 0.045055113207068176, 0.018786869928120606, 0.03358467789967695, 0.023159268875456145, 0.056739467075995864, 0.039080811003523494, 0.07294909082232945, 0.04758043011890785, 0.03392455280728398, 0.030425587939398906, 0.046851217836862614, 0.07138717544054793, 0.054030764036841934, 0.04198980390004093, 0.03211669064307165, 0.05075260869137222, 0.13868371715709088, 0.06252274525562121, 0.07443112621624624, 0.030596050163430553, 0.02813297023455943, 0.023118378932497675, 0.06709643188984164, 0.029502264299099485, 0.040663395437502095, 0.006847889500580007, 0.07299458112327323, 0.06297634974602731, 0.02474316715022489, 0.02588332431661266, 0.03242804601247753, 0.0451355830826346, 3.963926458551038, 27.45383574116615, 56.75575110220141, 51.4590451794286, 37.27580170477591, 42.50311697683027, 50.277709653300626, 42.506458836217085, 15.45349717140198, 2.4926731086546376, 0.09371744333616189, 1.2499952676796144, 2.7340609171698174, 5.128891237320439, 5.108483145313879, 4.035618069671815, 9.146425954757198, 25.987496875947524, 42.920661126413655, 56.86790343253844, 56.93473277553436, 55.94533843378867, 55.09750635393205, 54.207493105242335, 53.31156884470294, 51.27695698891917, 52.230567547582815, 55.29145971421273, 54.282637873003566, 54.02469888810189, 52.632288855891076, 49.01538895022485, 43.06260385820943, 38.67666836707823, 39.249208896390854, 41.06568205741144, 50.75108481991676, 53.9534725681428, 55.44245919873638, 50.946493379531375, 51.82578679054014, 54.13221105452507, 52.55781481342932, 49.48787766118204, 41.592303399116766, 40.2164065453314, 39.76356106419718, 40.40038139589372, 37.70597196394397, 40.48715206884569, 36.725222526058076, 45.704292712673066, 52.05372356599378, 53.83607210651521, 52.46066162663122, 49.696245731845984, 50.87899331123599, 52.097838463321814, 52.36782304702267, 53.16053013647757, 52.130425514713416, 52.37115706166914, 53.6142542285304, 55.394206200876546, 41.31428580130301, 46.43834075620098, 54.73664045333863, 54.5232399817436, 53.15826300651797, 50.77449352510514, 51.43757804747551, 48.48929712849279, 46.743799255740264, 42.37062323477961, 38.55538475898005, 37.99698437413862, 39.88646461117653, 37.367589089178274, 37.78527836645804, 40.53829977589269, 49.67919518870693, 52.57079393632951, 55.40441220806491, 52.894275726810584, 50.975573831988925, 51.832682317303075, 51.229355104507945, 48.39343047911122, 41.4382601553394, 43.611786673145915, 39.360525761881185, 39.08639131053802, 38.867256333751065, 44.66840259490475, 54.85582167102445, 52.9958455024227, 53.32771724270236, 52.12054506424935, 51.95937095149871, 50.643047055890484, 51.679341177786554, 50.86599457648493, 54.09469358382687, 54.36043416300128, 54.373636861001295, 57.58607764397898, 56.57707145137172, 56.00990849156534, 57.28517301620976, 60.59591624044604, 54.463600343273534, 42.73406613257624, 24.208986374639696, 6.844527125358582, 3.0273012336223357, 3.8215713875909008, 5.404178865494267, 7.832966369967307, 9.662482392403389, 4.010853940440763, 0.5516939285782076, 0.1791480676301064, 1.6096020874477204, 16.86158295600645, 45.244347741526944, 44.498026601729855, 39.74266659828925, 50.6419684040931, 44.73403561499811, 17.209134371049945, 1.3067352939997952, 0.06707699623920264, 0.04230657359585167, 0.0534793071358675, 0.06039843706774616, 0.06170937055421453, 0.06610524435076984, 0.06732297174993061, 0.010384366821287381, 0.015234840064940434, 0.05378320655455032, 0.012137629899136242, 0.07110327091668883, 0.06774224401001008, 0.05443165784761791, 0.019285913008535584, 0.03456570328243318, 0.042852832590259855, 0.06479632950598194, 0.02907969977616543, 0.014876887397540194, 0.07621100127336479, 0.1753200182030278, 0.11118165863257264, 0.09096550995544081, 0.15284567981237365, 0.18685696526400505, 0.13525619381858459, 0.09884925183629799, 0.1008301790082647, 0.24665697658013916, 0.15388100167676327, 0.16609368425223137, 0.24438410096110838, 0.17948286337477548, 0.12716735487863903, 0.13093213310405133, 0.14004989707421872, 0.16215455207613208, 0.16132336200004624, 0.24664652714085197, 0.21713709608922083, 0.1858270366586024, 0.12911336376301705, 0.1867604688290627, 0.16554577816878596, 3.82795823197211, 32.381015170005064, 63.08703707110498, 58.6819996372346, 47.653997021336714, 47.747471024913175, 56.96342883571502, 46.40247068097515, 20.627632948660082, 3.858061197303957, 0.700827713214582, 7.324704662446053, 8.590899686659537, 10.652058143769542, 11.330410492035652, 7.3274400253449725, 8.478573791442379, 27.106084285243867, 46.371123098558, 57.47802026810185, 59.63836369975921, 57.210895092256614, 57.82225139679448, 55.12286447709607, 53.176533406780614, 51.901566982269294, 54.11989873455417, 58.432748702264604, 57.624006963545284, 56.113470831225, 57.875101412496264, 50.28116526142244, 43.681938263677786, 40.121140018586196, 41.212084524093136, 42.9961863640816, 53.806250326095096, 54.86926363360498, 57.99818146613337, 52.063764833634906, 52.08725983096708, 56.454450315044774, 54.293832317475356, 52.51821456416961, 43.79062321878249, 42.92835681669174, 41.88699499253304, 43.099854607735914, 40.54105720212383, 44.497312730358495, 39.028995267806515, 47.23732756030175, 53.60731947806574, 55.450311783821356, 56.12465743095645, 51.32212700382356, 53.0592780728494, 53.285598831792036, 52.96458028977918, 54.50616590438351, 54.860928596988806, 54.81437790778376, 57.01485110867409, 56.54626515603835, 43.364187056018466, 49.39940860194545, 53.72307254422096, 54.83153827728764, 55.200645077613096, 53.08130610373713, 55.22844683739447, 51.119748392412745, 48.24731826782227, 44.577109429144095, 40.22686750658097, 39.34318888571955, 41.80393488176408, 38.53910300039476, 39.93165423793178, 42.99633541414815, 50.93814657580469, 53.52905642601752, 57.51190954639066, 53.16835918734151, 51.835726076556796, 53.26453962633687, 54.57239120237289, 49.4538079538653, 43.573527874485144, 44.78306916452224, 41.61166029591715, 40.39517641067505, 39.36495411780573, 46.00290667626166, 55.985778070265255, 57.19927310943604, 55.378265688496256, 54.14812411031416, 55.16548102901828, 51.57425695850004, 51.987019738843365, 50.948870335855794, 55.396383116322184, 56.85957624066261, 57.99611437705256, 59.765793661917414, 58.93181539350941, 58.127137230288604, 58.81949832362514, 62.755173175565666, 55.61579658139137, 43.12084713289815, 28.413535779522313, 8.643819324431881, 4.388970425052028, 8.523143683710407, 8.83713137718939, 12.72004544734955, 14.915946145211498, 7.913642660264046, 3.10476559304422, 0.3756059838398811, 2.1910852530310234, 20.084547458156464, 52.611500293977805, 54.90871483279813, 44.59315976788921, 59.456546152791674, 51.87492232168875, 21.07787593718498, 1.7455079238260947, 0.16780057411280372, 0.2037185757991768, 0.14520560751759237, 0.16236744791028962, 0.1535037186958136, 0.1481988202900656, 0.17265731108284768, 0.12887553942780341, 0.06914998419703015, 0.1565320029734604, 0.16339178407384505, 0.2796561985967621, 0.19147869710239673, 0.15622650243101582, 0.11424798683653917, 0.11066351506498553, 0.2310598401292678, 0.2984731872716258, 0.11348253476523584, 0.16447912330829328], [0.07458312572130273, 0.06255592069318218, 0.029613314489383372, 0.08852646220475437, 0.05976467551062665, 0.0241103574573513, 0.07955404809646069, 0.05568482447415591, 0.02513632921862506, 0.04754007643749637, 0.037516248787963585, 0.12564344511878106, 0.03620573664985357, 0.024205231701114008, 0.03289840867622726, 0.03199759844480263, 0.062488792238817106, 0.00236728135214728, 0.0334638275296217, 0.039380493108183146, 0.045494207992188396, 0.003686704289829058, 0.021183773266872572, 0.08928390865724894, 0.043121733282121925, 0.6611423362647334, 16.197643356938517, 38.66035522953157, 53.355844559208045, 44.26803842667611, 35.01696755809169, 28.95734102495255, 45.466040103666245, 23.436226498696115, 3.0653607268487257, 3.685925775958646, 5.894141245272852, 0.8058847823450643, 3.4710225462913518, 2.0666103065013885, 5.4116102860819915, 11.405505249577185, 19.985915537803404, 39.93802024472145, 48.502029142072125, 54.32620756087765, 53.129245311983176, 51.595759391784675, 51.036578455278956, 51.9336715821297, 55.534532916161325, 53.22382150157806, 49.107344996544626, 49.27462231728339, 48.620029726336085, 44.90651007621519, 38.75358996852752, 36.63013250597062, 38.24376029352988, 38.215527073029556, 39.77257467085316, 47.86611880025556, 50.1519976892779, 51.594170831864886, 50.08729819328555, 50.921539260495095, 52.59828582886727, 49.77666608748898, 46.32303091787523, 38.36724435129474, 38.71815527639082, 35.602463676083474, 37.8257768384872, 37.71430307818998, 39.906688351784986, 36.86712211178195, 41.472267104733376, 49.16428212196597, 48.744953293954175, 52.55982306695754, 52.5057061256901, 47.59068212201519, 47.10730491145965, 50.314987859418316, 50.35445082572199, 52.20369931190245, 51.260592860560266, 50.56098322714529, 37.417630687836684, 32.64666553466551, 45.58093417075373, 52.774965070909076, 49.48207255332701, 49.62111273119527, 47.02595887645599, 44.999725203360285, 43.7132623118739, 40.82802564867082, 39.319548760691, 37.61469448766401, 36.483490774708415, 35.72219010322325, 35.94674971795852, 36.00413791594967, 37.72257143451322, 46.52704908001808, 51.912212294916955, 51.23981606575751, 50.81461152722759, 52.690606655613074, 51.82518666790378, 48.52900720411732, 48.0075006331167, 45.3451330431046, 39.67431929803664, 37.546723734947946, 37.1724864744371, 37.464487321915165, 37.20746224926364, 42.91640927714687, 47.29651220383183, 47.17101989253875, 48.05921708383868, 51.39675009635187, 53.915272605034616, 53.63655682533018, 50.05006705560992, 44.573077232606956, 44.47579460759317, 51.70036900428034, 53.45103656091998, 56.31666529563166, 56.36360822185394, 57.14776846670336, 56.0053663869058, 46.84428645718483, 37.196671808919604, 20.37979995050738, 6.065459587881643, 1.866353574779726, 2.7402989566326146, 4.3740516901016235, 4.606795820497698, 5.959072161105372, 0.3534104248448726, 0.15892811149599093, 0.2383802852202808, 2.317480690056278, 15.686569310003712, 40.34626837699644, 52.226429447051025, 28.313538874349288, 48.232985927212624, 38.9780907477102, 8.288620268144916, 0.3511167269560599, 0.017707191572915164, 0.024389922093119354, 0.014668099709876604, 0.06090306301390933, 0.01917370219504641, 0.02848070137382996, 0.022813659799735875, 0.05932130978532857, 0.036219916937332, 0.06511020338943889, 0.05827105686729474, 0.06939186879824247, 0.03433735545484289, 0.030242199896864837, 0.04366902649522789, 0.02199607927562489, 0.027174234179960146, 0.07213881494657648, 0.023881433148598, 0.08003184181307593, 0.023055192000503023, 0.03696120659550352, 0.07527256654875894, 0.060035916601097396, 0.06783909284539762, 0.05353519708038338, 0.03681225228994604, 0.04232834581465971, 0.0482006510719657, 0.02300634048879147, 0.008077704809576033, 0.06300628846210819, 0.031021274926681674, 0.02244528642134561, 0.05661641420315831, 0.028448734439969547, 0.02368463090650978, 0.04066636402820868, 0.03354439699661828, 0.00997163216403175, 0.12241475990102177, 0.04689056794309328, 0.00877121260630027, 0.05554288370354522, 0.09336970836645173, 0.7560488629725672, 21.003868656773722, 46.24026498486919, 57.21726109904628, 47.36811114895729, 38.191106396336714, 37.283062011964866, 45.10072231292725, 25.37170437074477, 3.393906297222261, 2.964256487546429, 5.2389289198383215, 1.849249957069274, 3.621063256456006, 4.6901844297685935, 6.279855360907893, 12.525338011403239, 20.32944456223519, 42.71133599742767, 51.4109294645248, 57.07842488442698, 54.328710033047585, 53.719322758336226, 51.52296412375666, 53.42270920353552, 56.526202232606956, 56.60886618398852, 52.02462742405554, 52.308920814145, 51.10496497923329, 47.93879247480824, 42.23631343533916, 38.42985322398525, 39.95783213646182, 40.56329311863069, 41.274128575478834, 49.51576179073703, 51.27481537480509, 54.16767320325298, 51.02869056886243, 52.243778090323175, 54.11659609886908, 51.861331309041674, 48.13894710233135, 40.32487184770646, 40.655598255895804, 37.56431556517078, 39.23362924206642, 38.92805699379214, 40.76007450780561, 38.850158722169944, 43.09663041945427, 51.99882607306204, 51.62169018099385, 53.509362205382324, 52.67969854416386, 49.59940633466167, 47.04523732585292, 51.99083620502103, 52.601086401170306, 52.46542338402041, 53.48459636011432, 51.352227272525916, 39.3696060488301, 37.4073697674659, 47.16778393714659, 54.76146121178904, 53.12766459680373, 51.773026989352324, 49.979852707155295, 48.07541255028018, 45.46989579354563, 43.31066239264704, 41.284644449910815, 38.495129308392926, 37.84012094620736, 38.62224940330752, 38.08123688543997, 38.12818373403242, 39.676507980592795, 49.688612799490656, 54.014037885973536, 53.435786385690015, 51.96578010436028, 52.22767283839565, 55.33306429463049, 50.13780655399446, 51.20200049492621, 47.17828019972771, 41.55186376264019, 38.76849497518232, 38.43133195754021, 39.10537558217203, 39.57451066663189, 46.24055916263212, 49.88674348400485, 49.306538643375525, 51.13214700452743, 55.20174726363152, 54.827055008180686, 54.26929789204752, 49.359918179050574, 48.13601709181263, 47.74622371119838, 53.0402781117347, 54.66198205947877, 55.667509109743186, 57.56946640629923, 58.95161944050943, 56.35796785354615, 48.97620839457358, 39.21591974073841, 22.462458879716937, 6.713737162851519, 2.7006646317820397, 3.8617136593787906, 7.820185817057087, 8.308461577661577, 7.6438904769958995, 3.851299031126884, 0.5784538700695961, 0.16458894967311816, 2.3905985730309642, 18.938193590410297, 47.81935238069104, 54.04181218916371, 34.53541424966628, 56.154255636276744, 45.4869737932759, 11.3916887006452, 0.4983321967865191, 0.03217011569969116, 0.04475836904959814, 0.0429858177930357, 0.07302121033952122, 0.0240165576519024, 0.01789177662783092, 0.02968205747404887, 0.030935754616474433, 0.053392111008325895, 0.017690944763260986, 0.031272896505411596, 0.03602438448597828, 0.01450508003002934, 0.021926361444075743, 0.03579930402338505, 0.03492124468809174, 0.013083361611220867, 0.05250795744359494, 0.043505964680544795, 0.02743284822621894, 0.24425950442110342, 0.14933384083692106, 0.1771583687514067, 0.16605164134694686, 0.13767620428435265, 0.15592231955980101, 0.1645642816419563, 0.11172081599192274, 0.11080405389469479, 0.09537007118905745, 0.21472519083369165, 0.2638046443462372, 0.10698354277279108, 0.14852053125298795, 0.1666411460046807, 0.09295838043814705, 0.13709082117965146, 0.06480568343953741, 0.10092885113291203, 0.11552399820497922, 0.26565033401693067, 0.21591969044698825, 0.10056824588607396, 0.2603473201874764, 0.15259018948962613, 1.514809064326748, 22.2114428781694, 52.3040609975015, 64.94614247352847, 55.65263548204976, 44.81216922883065, 40.91249389033164, 56.638111375993304, 29.294464818892944, 5.255381301526101, 4.368890831547399, 9.089796735394387, 5.3424093800206345, 9.891375245586518, 6.564250732621839, 9.172348899226035, 17.370226114026963, 22.42841466780632, 43.57997232867826, 53.43005188049809, 56.91961203852008, 55.487841021630075, 53.21299575990247, 51.81140345911826, 52.86779580577728, 57.66685885767783, 59.666828340099705, 55.12333908388692, 52.98039528631395, 54.844101628949566, 48.782784554266165, 42.16221201804377, 40.63825745736399, 42.20675837609076, 43.45410739221881, 43.23628248706941, 51.70523666566419, 53.4883539907394, 55.84592596177132, 51.49047120924919, 53.780958883224, 56.19218103347286, 53.52136858047978, 49.77968239015149, 41.13615920466762, 43.285029703570956, 39.81925479827389, 41.60013637235088, 41.34587657067084, 42.80839504734163, 40.22002689300045, 45.279821657365375, 53.9867264224637, 53.21651020357686, 55.612262525866115, 54.71548711099933, 51.297019912350564, 49.015887091236735, 51.506890250790505, 53.95928944310835, 56.17740546503375, 51.877252209571104, 52.662255764007575, 42.99786906088553, 44.34140636074928, 49.57618198087139, 57.03060726965628, 54.41850093103225, 53.25474939038677, 51.59680274225051, 50.05926893603418, 47.112392225573146, 45.245163594522786, 42.79953049075219, 41.5569196977923, 40.4271907960215, 40.38711593997094, 39.023523561416134, 39.68243075955299, 42.03375831727059, 50.67675982752154, 55.923541822741115, 55.568045646913596, 53.90224641369235, 53.454774579694195, 57.55413386129565, 52.73325850886684, 52.37964114835186, 49.56578769991475, 43.62732318139846, 40.683105837914255, 40.40811630987352, 42.4514122932188, 41.18224705419233, 48.385875994159335, 51.737619753806825, 52.43539371798116, 52.30856387845932, 56.77142489340998, 57.48957164825932, 57.10660711411507, 51.073786058733546, 50.259011714689194, 49.05533044568954, 52.96664737885999, 54.664927759478175, 58.18973433586859, 58.79079441870413, 59.23539507773615, 59.1413523304847, 52.112104123638524, 40.80875504401423, 24.643324152115856, 9.200216358707799, 4.768959351124303, 7.588722340522274, 13.246286319148156, 12.291360785884242, 13.776391706159039, 5.046259645492801, 1.6645710410610324, 0.5055864672026327, 3.1921358983362875, 21.46586894989014, 50.9470699679467, 62.084604770906516, 42.7154113400367, 60.73704704161614, 50.82661397995488, 14.454612655024375, 0.6979814207842273, 0.20169771246371732, 0.13757250662292206, 0.16771261189733783, 0.15031032714872591, 0.15887217175575996, 0.07244631497850341, 0.13345034071995368, 0.10520156863476, 0.1679417947607656, 0.18996870716012296, 0.17140357755124572, 0.1989764455826052, 0.13085527916348752, 0.13140802692261436, 0.12936125449355573, 0.12920437500842158, 0.12419425957505742, 0.10574512333879549, 0.1158049456294506, 0.2044107055952472], [0.04965521072247817, 0.015621806397252988, 0.04304471846309401, 0.05438249798551683, 0.03133765966331046, 0.05365156966652121, 0.05734474931453025, 0.05763919903866707, 0.06738843396306038, 0.0443780102256325, 0.06644144203634032, 0.06745953458331286, 0.10181503100020271, 0.04496370359594303, 0.030961843740735805, 0.019640322519286026, 0.05187309655030409, 0.015540940071185751, 0.06602773157459113, 0.0433366400970807, 0.030087465457918666, 0.06767253000890056, 0.03942005005815337, 0.046115578077132666, 0.1108560482821157, 0.11002870396740976, 5.2717630805507785, 35.20399009027789, 45.8866633138349, 34.79872295933385, 45.008158299230764, 49.46488472723192, 55.48955901976555, 24.207635118115334, 5.7393630473844475, 2.2925045076877844, 8.272155138754076, 5.042523587903669, 2.451009447536161, 3.1110857571325, 2.2071154896290075, 15.957395242106532, 21.507601007338494, 39.273955129808, 51.31992655415689, 57.79107247629474, 53.42192472950105, 52.52652606656475, 54.99666613917197, 53.83731942023001, 51.58145450776624, 49.79048851997622, 49.72832287511518, 45.47122547703405, 39.853885404525265, 37.627253916955766, 38.68255192233671, 41.5300436173716, 37.413975038836085, 38.59331800091652, 41.40155853763704, 47.882820252449285, 50.95420475929014, 53.28165684976886, 50.970102125598544, 49.90421764312252, 53.96933855548982, 49.93253323339647, 45.15277608748406, 37.973744330867646, 38.21168315026068, 40.29627776915028, 38.05811843564434, 35.37122034257458, 37.121613333302165, 35.85928870785621, 38.266733615629136, 43.8204881452745, 50.08075175746795, 49.90710450756935, 52.7278377932887, 51.621152816280244, 52.290164039980986, 47.88034915924073, 51.66702101307531, 50.70805641912645, 52.56365522261589, 47.69812368577527, 43.434985837628766, 40.80698605506651, 44.491182065779164, 53.23651429145567, 47.446421269447576, 48.09626387011621, 41.421405730708955, 39.686639462747884, 39.42264826067033, 38.48399369947372, 36.53674871690812, 38.55653793581071, 36.66040535896055, 38.998079146108324, 38.3410664527647, 37.17038016165457, 36.427334200951364, 45.85371932675762, 51.177568051122854, 49.949262142181404, 50.41267841093002, 49.328805938843765, 52.78571236518122, 52.33483199150332, 49.113691391483435, 49.69923850028746, 49.140771435153106, 43.21170883793985, 36.94451439765192, 36.970123552506976, 36.15778107796946, 36.3343701054973, 38.957698345184326, 44.55268090771091, 44.254470948250066, 49.194558897326075, 49.71559870627619, 49.95637339930381, 50.441586279099994, 48.831080698197894, 52.28992869777065, 51.629758496438306, 55.59387837686847, 55.473755790341286, 55.254024613288145, 54.25627562307543, 52.46941635685583, 43.830199933821156, 30.7689739811805, 11.163657788307438, 5.005892082568138, 2.3714870695144903, 2.587877367773364, 4.399954042127056, 8.428741058995648, 7.031465326586078, 3.801480026975755, 0.34828453054351194, 0.20880731483620985, 3.4433585597622782, 21.93204068368481, 33.871223618907315, 45.47205701951058, 44.927577126410704, 43.952891672811205, 36.40623969416465, 4.185013059646853, 0.06717327050864697, 0.03451775000881284, 0.055827236388840025, 0.0470374193372986, 0.06284384334820413, 0.03541061399324286, 0.05191936060005138, 0.015637025691478724, 0.05168632814480413, 0.02481488830169603, 0.07022868195969252, 0.010609317048933479, 0.039290098563557675, 0.0714580615561816, 0.06252443447949425, 0.05169923289588863, 0.0003304896721777867, 0.03369851856522503, 0.06826250964114744, 0.06954140150018277, 0.04268388722031828, 0.023418445996339285, 0.04058782469421145, 0.03577668144698105, 0.040542997059322176, 0.032327565920328906, 0.04403270375464232, 0.07282309234142303, 0.026425147661939267, 0.0628372511616157, 0.02886008726613176, 0.027901954505772843, 0.021607017692839427, 0.09309600813374405, 0.032991649237491434, 0.05518275726165983, 0.05926822755305518, 0.017604736889141704, 0.04019491351960648, 0.0533216500714902, 0.09359636313972935, 0.03838698049226115, 0.039866212004375075, 0.016836396666363846, 0.06801075016659114, 0.0737489479023122, 0.3366933444574956, 8.286604169876345, 43.47430759860624, 53.71440802851031, 43.94604321449034, 47.6281133005696, 45.33859052965718, 57.59243580602831, 27.021890609495102, 5.798983074003651, 3.7720629861277923, 7.300236917311146, 5.530106069580202, 3.3453917263015627, 3.728798997979011, 3.5240718674275184, 18.65511025151899, 26.64712775138117, 41.054283649690696, 52.700604777182306, 56.4049421587298, 55.381242767457046, 54.35634705328173, 54.99204558710898, 55.46265156038346, 52.93009481122417, 50.62700456188571, 52.007949506082845, 49.8325284834831, 42.957421579668605, 39.568223107245664, 40.653386039118615, 43.11228067644181, 39.50782645133234, 40.87239942243023, 42.72475442578716, 50.37497266646355, 53.221472001844845, 54.373562335968025, 50.68231390368555, 49.9829827585528, 54.14187577462966, 51.56447456729028, 48.177535380086596, 40.04153551593904, 39.95760071662165, 41.889552377885394, 40.55452269892539, 36.81034188116751, 37.85041716790969, 36.8883970475966, 39.765082943824034, 47.13926438362368, 51.070687386297415, 52.72194247091971, 54.72468506905341, 52.59681886242282, 51.465419030958614, 48.09169038649529, 52.27536101495066, 52.21572922122095, 52.10418093589045, 49.11693126924577, 47.13924869414299, 43.37451857905234, 47.9487003818635, 54.01100197146016, 49.7247927419601, 49.83387777882238, 42.51145985818679, 42.406356027049405, 40.628000459363385, 40.80890409408077, 38.4892535978748, 39.819227341682684, 38.049073450026974, 39.66176379111506, 38.07011696600145, 37.92722109825381, 37.963224534065496, 47.22466614938552, 52.66281666294221, 51.97704515149517, 53.77413788149434, 50.13467258022678, 53.38568202910885, 53.41757089860978, 50.274552145311915, 51.19216319053404, 50.01046680635022, 42.525662760580744, 38.91850210005237, 38.88560518141716, 37.13168597990467, 38.95199914132395, 40.98438701322002, 48.261827115089666, 46.634298447639715, 52.13637575026482, 52.082094069450136, 52.50100712622366, 52.348250419862815, 51.352427313404704, 50.99235373158609, 52.71239934429046, 53.69646710734214, 57.102323885886904, 55.28457595456032, 57.05939746672108, 53.654003527856645, 47.51947149153679, 32.18800317856574, 14.575090216052148, 4.818523401214231, 2.6350519589839445, 5.621873351835436, 6.42764977870449, 9.6079820394516, 5.697583431197751, 2.970685007110719, 0.1793787060605903, 0.09677529860768588, 3.8155297117848552, 22.630718754183864, 40.38557052612305, 54.048844998882664, 47.6322357116207, 49.366672500487304, 42.71684692751977, 6.500483289841683, 0.1322012803246898, 0.06849587534464176, 0.03404425787589243, 0.005465976052707242, 0.03249799750084358, 0.043501218765853875, 0.02531831340503789, 0.05555689162124069, 0.027061174924094832, 0.09933492093677483, 0.057750894658027165, 0.09301091108711497, 0.028495299179227124, 0.030143135152156317, 0.017918227728636518, 0.06702655701026802, 0.09199961374003081, 0.028746892029659885, 0.02856907153111552, 0.00894062624748556, 0.06541894448380317, 0.09330493563245382, 0.15943095628773013, 0.17022619234217753, 0.1202277550774236, 0.16091416379617107, 0.13052912489060434, 0.11969307167155128, 0.17918336896165726, 0.15480154824833717, 0.1292985731795911, 0.1623141435125182, 0.20519381599320521, 0.24317930512610944, 0.16309772888498922, 0.13588772605984442, 0.18246395663628656, 0.142272210890247, 0.14512598033874266, 0.1978403831561727, 0.2504141935177388, 0.12093437925702143, 0.2323940435364362, 0.1082435505644929, 0.13675329816197196, 0.19884544454755324, 0.5892444329877055, 9.756047591086357, 48.20906339153167, 60.142443180084236, 47.63245144198018, 55.41630875679755, 57.921918822873025, 65.18327720703618, 30.76930738264515, 7.8855555480526345, 4.164173016625067, 9.542620643492668, 8.994996970699681, 8.54271238850009, 10.532438601216963, 4.7436321166253865, 22.73797988891602, 32.90086846197806, 47.907476271352465, 54.2346162949839, 57.978695131117306, 55.520290790065644, 54.513120266699026, 57.06803844821069, 58.536934698781664, 55.527970790863044, 53.21966771156558, 55.21616981875513, 50.187161737872714, 43.06420418523973, 42.520987295335345, 41.596672919488725, 45.87408035032211, 40.744753729912546, 43.56232558527301, 45.335287893972094, 53.4493617088564, 55.607896927864324, 57.0217623249177, 51.9708634961036, 51.95043971461635, 57.40897478595857, 53.18158541956256, 47.72772581346574, 41.96643867800313, 42.06500391806326, 43.92193632741129, 41.75964347777828, 37.78487828470046, 40.2654440172257, 38.25599416609734, 42.434275457935954, 48.011913299560554, 53.486165308183246, 53.80617972343199, 55.056541119852376, 53.48946009912799, 52.85027065584737, 48.435670483496885, 52.893648147583015, 51.639831143040816, 53.67006171134211, 51.61445340802593, 47.92721756042973, 46.23591115397792, 50.59465285270445, 55.80343884806479, 54.014681154681796, 52.95435074836978, 46.0536229225897, 43.1797807447372, 43.01568054383801, 42.87409474772792, 40.199289321899414, 42.12139583403065, 40.65383318931826, 42.79642789594589, 42.7139953644045, 40.23093108207949, 40.10467390860281, 48.334049717072524, 55.38753424921344, 53.00733020228725, 56.071834871845866, 50.5633484163592, 53.91633556735132, 55.586625914419855, 53.33918625308622, 52.56736970716908, 52.910745759164136, 45.81148324474212, 40.78904513389834, 40.206722213375954, 40.193809770768695, 39.37395203498102, 42.43623272065194, 49.65696319457024, 48.59433035696707, 53.63076740695585, 55.44258471458189, 54.99886266646847, 54.21121543453586, 52.16799789859403, 51.85454560864357, 52.63102585269559, 56.05814187757431, 57.93894583179105, 57.14575629080496, 57.24882833419308, 56.480828254453606, 49.62135984051613, 35.84768241451633, 14.179342677516324, 6.375815166581062, 5.5246054357098, 7.653594420802209, 12.760384082794191, 18.41165069610842, 17.0439515959832, 8.95583700749182, 1.1886350570186492, 0.3096786634095254, 4.992455513246599, 28.07424487606172, 47.49337596278037, 55.54486836156538, 56.35077422665012, 58.011572437901656, 47.76765946419009, 8.341725237907903, 0.14419656246900558, 0.15081602178754347, 0.15548309070929406, 0.1169661740441957, 0.15196987277557775, 0.1643232244157022, 0.12386987496527935, 0.08761958264174961, 0.23286163296190002, 0.16855647306769125, 0.25287148182190233, 0.11008416873312767, 0.0730611388421347, 0.13604520309355952, 0.20600850453540204, 0.16848954762662613, 0.13654663828351807, 0.06687068110031467, 0.1669823615661552, 0.2375355353879352, 0.16385056348817964], [0.0728118461706946, 0.03639692921311625, 0.06939389127036256, 0.020632147826554797, 0.08804627829381535, 0.022356918179279855, 0.04320797946063742, 0.020327484235167503, 0.015391376725728474, 0.058918669294085235, 0.04904496806463407, 0.06434656694651612, 0.04535327845763776, 0.01715208426298153, 0.026397149063526627, 0.05144952653696941, 0.028902877107142445, 0.041374183304968386, 0.09007091078186229, 0.07781741870266777, 0.03331619855617324, 0.09551883014219423, 0.10137842983127603, 0.026122008585521293, 0.0832483692154769, 0.04309225038835599, 4.731590440196376, 21.875546786092944, 46.75949658116987, 37.531395112314534, 46.84640453707787, 69.72988866990613, 60.164020138402144, 30.933344825621578, 7.125768421157715, 2.96059274865735, 6.263629005801294, 3.8647905136308367, 1.5506690884790115, 1.7221263075067152, 12.248757962257633, 14.158565882713566, 18.76426589104437, 38.20047693867838, 40.79507381685319, 47.796728149537124, 50.03366762591947, 56.4464565246336, 55.363662704344726, 52.80479861843971, 49.60257168739073, 48.15394624587029, 41.71905871360533, 39.69555501014956, 38.83648926211942, 42.2813069435858, 39.98087998359434, 39.009701128928896, 35.45775567331622, 37.89527339320029, 37.09873022571687, 43.461210804600874, 47.10586147923624, 51.23667032487931, 52.38636409082721, 48.93203466169296, 51.938417650038204, 51.42304958835725, 47.59742075397123, 44.09030014468778, 40.19890492962253, 39.63519757793796, 36.97707791482249, 36.61387820397654, 36.07577608477685, 35.19601983408774, 36.05916092472692, 38.943063982071415, 46.23410294132848, 48.803553504328576, 50.37095615940709, 51.17513225924585, 51.47867271977087, 51.4903143144423, 52.82123727183188, 52.00230521540488, 54.06107494907995, 52.41446002837151, 54.927926601902136, 41.10159527870917, 42.128844414987874, 53.189030078149614, 47.944366162823094, 48.26244684957689, 39.12522669761412, 38.883851881950136, 37.388161920732074, 37.28911815151092, 37.478552941353094, 38.55152906910066, 34.713281969870295, 38.513705653529016, 36.42521612105831, 36.3230776017712, 36.5707556663021, 40.85660011537614, 48.38473066206902, 52.81834648501489, 53.53812494585591, 51.20792327388641, 51.84442197122882, 52.84481856130785, 52.799876043873454, 51.18045099319951, 49.45487483855217, 49.51656587662236, 41.58620019112864, 37.55272888368176, 36.61332122741207, 35.831537938887074, 36.55565454113868, 37.805874732232866, 41.43047425054735, 45.3120086269994, 47.16524224127493, 47.94376211781656, 49.56219088646674, 52.64914720289169, 53.291611825266195, 52.11774056957614, 46.16782665252686, 53.52407893826885, 57.36205147158716, 55.99440336227418, 47.62130798832063, 38.13327889288626, 20.60339858455043, 7.296832790297847, 1.07259749645187, 2.0451820305278225, 4.656734456939082, 6.264032519632771, 9.272535058759875, 4.030038007805425, 2.4058590444826313, 0.10884026410959421, 0.10694840998058358, 5.107864881715467, 25.0158473368614, 36.64104061741983, 32.776495987369174, 49.263965237525206, 46.74587026719124, 24.57026412410121, 2.536017260243816, 0.044778302657387914, 0.010091884985506054, 0.016385343248745608, 0.04694818924631804, 0.040500950323598045, 0.056084511696451136, 0.021669427045590935, 0.04802125626273694, 0.005593556026372338, 0.09167268571834411, 0.03103549926421575, 0.022358199461333217, 0.06129284088890399, 0.08998106399010267, 0.006794510409235955, 0.020334716105172713, 0.045274218183852015, 0.09755938959818694, 0.04186001711434895, 0.06245439106057729, 0.05848432808453518, 0.06409965680852052, 0.049789337396261193, 0.04257190814842621, 0.07189658560579823, 0.05569805098216861, 0.07553325860851234, 0.04597642586656636, 0.06152516471282129, 0.04199926125546617, 0.04224154422239911, 0.011042721715996103, 0.050301991943870826, 0.03442267083653039, 0.03499642089610139, 0.020778824935757348, 0.03822310662437831, 0.033613965441022194, 0.0691797543737677, 0.07747012040307445, 0.03989404397866419, 0.05511903406811818, 0.04608083215932693, 0.027801204367630908, 0.049799652770161636, 0.014729641468053865, 0.04252491248471122, 5.474326043359695, 30.551698207855228, 52.2360667105644, 42.13193524268366, 49.892497601047644, 66.08008400086435, 62.90887125076787, 35.616470459968816, 8.706794938733502, 3.363227724067627, 6.320550441741944, 4.162831075729863, 4.391774919725234, 4.8310911655426025, 14.886939237194678, 21.681662067290276, 25.13416563310931, 43.04626718644173, 46.177487450261275, 54.33586051387172, 53.124526700665875, 58.45150939879879, 57.88967694005659, 55.650058484846554, 50.58809464977634, 51.96558006348149, 45.53065722988498, 41.18456909733434, 40.52088052995744, 42.431973026644805, 42.650386287320046, 41.28909634005639, 37.44370268237206, 39.666400032658736, 39.511811579427416, 46.886887319626354, 50.433314000406575, 54.16846552202779, 52.187531302052165, 50.951647373937796, 53.709148130109234, 53.842873496394006, 50.00960388491231, 44.74886217424947, 40.96919567354264, 39.86051813248665, 39.57360067675191, 38.987790769146336, 38.607191424216, 36.69825230875323, 37.14960728922198, 40.67603380449357, 48.94888124158306, 50.35030095807968, 50.94752496288669, 52.737992809664824, 54.27633462413665, 53.016892940767356, 54.47350040558846, 54.16660631856611, 55.54278558300388, 54.258860465018984, 55.6272695141454, 44.09404993057252, 46.31810049856863, 55.09109720107048, 49.083881378173835, 50.790339900601296, 40.75907430341167, 40.60660000770323, 38.51412142476728, 38.98938717380647, 38.3406977499685, 38.84485960006714, 36.96216506342734, 39.70707501134565, 38.34420827127273, 38.16046876292075, 39.583838062901656, 44.185103831752656, 51.68806845141996, 53.87638622714628, 53.6566315158721, 53.68526874050018, 52.32782663837556, 54.623691881856615, 55.137875387745524, 53.76921530692808, 52.019159640035326, 51.040202725318174, 42.29144234811106, 39.413352243361935, 38.56157818148213, 37.3507111303268, 38.5758791431304, 39.603857840261156, 45.318170670540106, 47.119134779899355, 49.06201416446317, 49.69611237126012, 51.877389492527136, 54.61500775429511, 55.14825790159164, 53.10157691278766, 47.8427493187689, 53.819782503189586, 57.703933100546564, 55.71412255687099, 50.056036903012185, 39.40160474469585, 23.571611027563772, 8.55144456509621, 2.780878082398446, 2.3273383417437157, 6.90569942997348, 7.570423503075877, 9.939094801102916, 5.926463536677822, 2.4633251995809617, 0.2550631214774424, 0.23232170951462564, 5.749378819619456, 29.107357955748036, 41.49784488062705, 40.36297767393051, 55.59435298365932, 55.06353862823979, 31.943559108241914, 3.2079332442052904, 0.038966012728070064, 0.023489517888294596, 0.006984855487732398, 0.04409237817350415, 0.011399996395583355, 0.04261504655944244, 0.07204421074880708, 0.07400282944041876, 0.030394831424458858, 0.013365340381560308, 0.046614864390463605, 0.0456422544835556, 0.08377755211005289, 0.03125056695763863, 0.012056364249738475, 0.051912232151915955, 0.08974082647792755, 0.03035078902969197, 0.07504676979395651, 0.08844206229813638, 0.06350415368233958, 0.1573961195085318, 0.21183366857228741, 0.13728726144519546, 0.13177250091347004, 0.1701099461605472, 0.1238940986654451, 0.11263837482059195, 0.1817561986465608, 0.12658191814778313, 0.15150190030615177, 0.11252819605532194, 0.20551882113420195, 0.10996107372545427, 0.16745410318816864, 0.06324009466615897, 0.22391254623090068, 0.14427594449971953, 0.1797600799510556, 0.15518774849272546, 0.170182571295769, 0.21010137523614594, 0.2540976974752642, 0.29682695625289796, 0.12039490780162236, 0.14527195073183508, 0.17442046244057918, 6.3628424175323985, 34.409541468466486, 60.34385688843266, 49.14634512316797, 58.30722893438032, 72.47528106935563, 65.92715863258609, 38.932383368092204, 10.248979695381658, 4.589613387661596, 7.045495154396181, 8.924252121679245, 7.01411521242511, 6.766126300058057, 17.443427347367813, 29.815300664594098, 29.760626746762185, 42.80959921498453, 46.361172045430834, 54.11491732443533, 53.32158265575286, 58.72417296132734, 60.344794334903845, 56.68744302565052, 52.98589052692537, 53.027342134906405, 47.27082067920316, 44.45095031492172, 42.8101130454771, 46.43765041905065, 45.08762551892189, 42.93026701096566, 39.557114954917665, 41.98053959877261, 41.24841351662913, 47.751499299080145, 50.991635937844556, 55.780842073502086, 55.47815668967463, 51.42383798476189, 54.664821855483524, 55.991751840037686, 52.12556962044009, 47.22529372861309, 44.02005833964194, 42.23079073813654, 40.40481759655861, 41.128718468450735, 39.869767081352975, 38.55803628121653, 38.589458388666955, 43.30073487374091, 50.152966514710464, 52.098658238687825, 51.83280783314859, 54.65330185428743, 55.293671930989916, 55.227066163093816, 56.14702278567899, 57.621884961282056, 56.63912334749776, 58.79172402043497, 55.14963073115195, 46.81631211311587, 50.30898663305467, 57.83210831303751, 52.72197384988108, 52.944795854630016, 42.70455814176991, 42.513126865510024, 40.50276702450168, 40.91092101989254, 41.536452770233154, 40.3305043712739, 38.989218511889064, 41.84611605059716, 40.4474223813703, 39.06027224756057, 40.418624339565156, 45.20816387668733, 54.15796925944667, 57.22331723859234, 57.79477127136723, 56.60969772646504, 54.24503411016157, 54.39498632184921, 56.245019282064135, 56.14757583987329, 54.043745917658654, 52.38113557138751, 45.13659631052325, 41.508262695804724, 41.128385066986084, 40.14481544494629, 40.50619125366211, 42.024548592105994, 45.66530827553042, 49.15363288694813, 51.03972419615715, 50.53549958813576, 55.13332151597547, 55.5515677698197, 58.02062526825936, 54.15066972855599, 48.52207637602284, 55.093215280963534, 57.417003877701305, 56.9540386815225, 50.64169383818104, 41.176838105724705, 23.35756140370523, 9.45705609936868, 2.4735505734720538, 4.560327501066269, 11.664305194731682, 17.00378848660377, 17.587088077299057, 9.843555669630728, 5.59017030462142, 1.0401210068695008, 0.4864421751229994, 6.960701846307324, 31.98470477134951, 47.60588915117326, 45.58895934012629, 58.88286029138873, 62.62099673671108, 34.99873245916059, 4.315140631891066, 0.12965023818035282, 0.08760700347803294, 0.2301787930510698, 0.15209004132738038, 0.1328073324815881, 0.12222614139318468, 0.08272421185768421, 0.09848889939847494, 0.15355832544305634, 0.10038386384445815, 0.1830598351455504, 0.11591479497691316, 0.14593418777710007, 0.11822681002799543, 0.08750529764520545, 0.10220063369601004, 0.14618195593357086, 0.09832662665435384, 0.11035613760712648, 0.13447694450376496, 0.17165246419608596], [0.04606300529332892, 0.014238010288306303, 0.01714749348109528, 0.07769585587084293, 0.03375104538375332, 0.07994214823890118, 0.023355630616987907, 0.07655966320946332, 0.04644201963298744, 0.013493636168629653, 0.07284583749189492, 0.024026260155463414, 0.050080699786063165, 0.023687844645352136, 0.06317782703967345, 0.07646190272944589, 0.04449144486458071, 0.036926299799233675, 0.028432838115540725, 0.027871638491389253, 0.031413345319789746, 0.01902538374246609, 0.040405576207464745, 0.020688633404431805, 0.04133946420023999, 0.016378971312435407, 1.467426097200763, 18.7219690122912, 42.643875152834006, 44.92657299964659, 59.93572250489266, 63.372907254003714, 44.49059763262349, 28.30141875051683, 12.950025777662955, 1.7107221388047742, 3.34276496402679, 1.2813967826866335, 3.639890878431259, 7.130426726033611, 13.47028503494878, 8.512824908379587, 11.297965626562796, 20.839621366993075, 36.28037083533503, 53.94321557014219, 55.200111635269664, 58.31326938444569, 53.86932596083611, 51.651935577392585, 47.61554994890767, 41.65294716435094, 40.61301308293497, 39.85669774393882, 41.192864910248794, 37.21556586603965, 38.713522957217315, 40.49173339720696, 42.370736983514604, 40.89478831137381, 40.12305805760045, 42.39279247099354, 45.47679916504891, 51.55147191016905, 52.15422253454886, 49.93103488799065, 52.469663466176684, 50.89050154532156, 50.26869604664464, 50.614554958958784, 48.993031440242646, 43.789050348343395, 38.499816540748846, 36.423427520259736, 37.61349032002111, 36.2926439316042, 37.21216517110025, 36.42957387431976, 40.66050514098137, 46.46798210759317, 48.981703635185, 48.62898449743948, 51.83423949826149, 47.143594680293916, 51.121423244476325, 47.214299325020086, 48.207204188069994, 49.47696954973283, 53.83867263793946, 41.579645910570704, 42.02912207572691, 53.17539199706047, 48.044927889300936, 49.436345561858154, 45.29524049451275, 43.02288986021473, 37.83490811624835, 37.69581302519768, 36.37136590096259, 36.80433281006352, 38.5071905966728, 37.95789403300132, 35.76075092438729, 34.878052896068944, 36.60577850957071, 37.46600920154203, 37.32847913619011, 48.3033924718057, 48.80529111431491, 49.27747388039866, 50.534381712636645, 49.55067873001099, 48.40921017431444, 53.940626805828465, 54.227442279938735, 49.631079473803126, 46.04300114416307, 39.59194560204783, 36.01843887759794, 36.049825683716804, 35.936539788399976, 37.04730010801746, 36.391499427057084, 39.23320170371763, 39.04364532040012, 42.48938475885699, 48.061099821521395, 47.82595372969105, 51.752132523444395, 53.4360295726407, 48.81559910312776, 51.00017493770969, 55.07048906818513, 56.1244377782268, 44.97717549723964, 31.356072387387677, 15.041716944786812, 3.725585351067205, 1.5346375035662807, 0.7276499836194901, 2.798306153666589, 4.090050516589995, 6.369047607145002, 4.58392349943038, 1.1929209818763118, 0.10721945954907326, 0.75506005796694, 5.955014469162111, 26.198714548541655, 37.276947036866225, 39.59378127128848, 47.59145090656896, 41.374086256950136, 17.448218522533296, 1.1870800823934617, 0.029409468068831393, 0.04503573118258388, 0.014384934460864434, 0.012173327681187902, 0.09619801305234434, 0.05844000223723631, 0.051660798264727484, 0.03354671058214961, 0.043917970596662456, 0.0842575061946146, 0.07301987734653297, 0.0640001802915527, 0.018197242696318897, 0.06851679720585385, 0.1261326152410719, 0.08771554281514499, 0.032388657601850654, 0.09980791128210484, 0.11750666439653405, 0.0587077614580912, 0.0013878882154747243, 0.09090261413685738, 0.046626711940212597, 0.05438909400254489, 0.09522836024482405, 0.03732055162770614, 0.03665455309073291, 0.039966542709378466, 0.012842385781808727, 0.07499513546786002, 0.04968868876476923, 0.044141212448237405, 0.01899530521533903, 0.025529299765044165, 0.021982075188369043, 0.029030823366596337, 0.0881505888255854, 0.007659689412497345, 0.03395046956176239, 0.039522564113740964, 0.039792732681117715, 0.017398167026018905, 0.0032958548493503084, 0.07518992098348756, 0.06749401620078473, 0.005860124938114877, 0.017389707500115037, 2.4693614821280203, 21.302598330282397, 50.355070560209214, 50.181470378752685, 62.80467740951046, 68.24822902679443, 57.2246116207492, 35.83720968615624, 13.634039086680259, 2.6380324700186333, 3.6051095060763823, 2.2951437725174815, 5.517291195930974, 7.755525544766457, 18.71333391435685, 12.235012015988751, 12.305589183684319, 26.528678055732485, 39.562159122959265, 55.27276569797147, 55.752040109326764, 60.368093213727406, 54.55377955590525, 55.12508061624343, 50.27721935702909, 44.740593817926225, 41.79245410426971, 43.437052926709576, 41.504199120306204, 40.61994783339962, 40.37926727725614, 43.046169127187426, 42.00066528012676, 42.13327669328259, 41.55566453933716, 44.07515979582264, 48.51728323967227, 53.65705905422088, 53.713854974316014, 51.146424431954664, 54.87421758713261, 53.338978367467085, 50.85222313480993, 52.26578258698987, 48.80236894853654, 46.494454183886134, 39.739054095360544, 38.6541304280681, 38.66318325842581, 37.154831886291504, 37.95888639265491, 39.95189366802093, 42.043748594099476, 49.465049466779156, 51.78359385459654, 52.37408707218786, 52.14919013361777, 50.91622837128178, 53.84181053407731, 50.49022366923671, 51.95922974617251, 52.04937365747268, 55.82451766537082, 44.71885604243125, 45.55857273840135, 54.47840729067403, 49.9448847770691, 51.166106885479344, 45.82088516604516, 43.947404276940134, 39.14112406392252, 39.59037273160873, 36.68249614777104, 37.37737932512837, 39.975827970812404, 39.8479587031949, 37.43172376386581, 37.021973363814816, 37.923596828214585, 38.758912624851355, 42.174838127628455, 50.44715996711485, 49.90550025816887, 52.83899776397213, 51.75905158442836, 52.41857459468227, 49.29657974550801, 55.70423426166658, 53.44044616145473, 51.673924384578584, 47.85551271130962, 39.232605503451445, 39.20923209959461, 39.242791898788944, 38.72984393950432, 38.92977499192761, 38.32156050589777, 41.39651829196561, 41.45280822630852, 45.58236191349645, 50.44896425739412, 50.325186021866344, 53.30084116228166, 54.847949474088615, 50.99873542785645, 53.61358350323093, 55.372829283437426, 55.34849097651821, 47.32894628278671, 35.22442563887566, 16.07634896232236, 5.2288817686419335, 2.2960552332862734, 4.703971070628013, 7.301328807107865, 7.857393420511677, 6.224343526747919, 4.20923222457209, 1.6168568788036224, 0.09868081974526567, 0.5966251079113253, 6.904037325612961, 28.848352086159494, 42.4223671420928, 43.280632726607784, 53.17079497921852, 48.035431831113755, 21.84615646639178, 1.807605785227591, 0.03826462475943469, 0.021097879488802245, 0.01988228372929077, 0.05314140490466549, 0.045962471575025594, 0.04565240131811269, 0.01158661541393808, 0.04841187683444831, 0.03384809340200117, 0.05045510610685714, 0.012645857416153436, 0.043333418697359107, 0.0473272648730105, 0.029217126373682293, 0.031555094568419366, 0.07474753585073256, 0.06505201135071055, 0.04098585333615061, 0.06510094138643434, 0.05727786600830094, 0.010455489466567675, 0.1433098616619264, 0.10557030207447468, 0.10858257511450399, 0.2122133723910778, 0.2651905586882945, 0.20743039436638358, 0.07849169865010247, 0.12648794214211165, 0.1423498309187351, 0.1578264617391171, 0.12045217287396232, 0.20469849418488242, 0.13453086177187581, 0.13286766956650442, 0.13294764914579932, 0.15997469485286744, 0.14968213505081593, 0.11405338518201344, 0.14389925906735082, 0.09277484109324795, 0.08111537359054051, 0.15778939840534043, 0.13450412530331843, 0.12887484994867157, 0.23863215960802572, 0.23709797660910317, 2.646242481085562, 27.828271081370694, 57.05813838589577, 58.85681575344455, 69.36941500632994, 70.38344967749812, 53.02164293104603, 39.56849767315773, 19.05172855623307, 3.580506684318666, 4.800222112286476, 5.3997225626822445, 11.304746423998187, 15.54798608826053, 20.716978657630182, 13.71226683739693, 13.866168875848095, 26.03620094637717, 42.24813938140869, 54.75751922976587, 56.36150190907141, 61.877225137526, 56.618142589446045, 57.844291194792724, 52.84349280018961, 47.82353362729473, 44.685402147231564, 44.44643566685338, 45.2553343003796, 42.759565461066465, 42.94453659365254, 44.979026855960974, 45.11660006738479, 45.14553539214596, 43.71539215887747, 46.217244594327866, 50.016813201289025, 57.148886342202466, 55.252279158561464, 51.04495663796702, 57.0686895616593, 55.13312931983702, 53.73651842917166, 55.22339482461253, 51.03566846539898, 47.83676378188595, 41.19401416470928, 39.89634506164059, 41.49201623855099, 39.30266295709918, 39.679198726531, 41.138096855532744, 42.783291878238806, 50.63797150888751, 52.97238972879226, 53.12735080718995, 55.502746028284875, 51.51192265172159, 55.12536694926601, 52.388878330107666, 51.482175396334746, 53.944545253630615, 58.5851876966415, 48.84731146597093, 48.864707177685155, 57.33094707612069, 52.99893240774832, 52.73143460673671, 48.674656575725926, 47.91108485191099, 42.04764350768059, 41.74105536553168, 39.038977699895064, 38.40594637778498, 42.171794368374734, 43.147025031428186, 38.551964452189786, 37.4317119967553, 40.95528302654144, 41.25197502874559, 41.774634776576875, 52.82827792629119, 51.482214620036466, 53.193234858974336, 55.023165672056145, 54.67055636067545, 49.41007352644398, 54.97777208205193, 55.377536127644206, 53.23645545590309, 50.43630284647788, 43.37771531074278, 40.61832789451846, 40.49522822903049, 39.91619617708268, 40.36664509004162, 40.81264995759533, 43.6281390343943, 43.80729329201483, 47.79832847656743, 52.6488491027586, 53.553253527610536, 55.9552384961036, 56.591184139251716, 51.340020856549664, 55.191694228879875, 58.19056195597495, 53.54286316902407, 48.773280651338645, 37.07045385914464, 17.967485420165524, 5.175128136911701, 3.1461510110285977, 5.146650258571872, 12.838993284010119, 14.052550100511121, 16.205037024713334, 13.256175594945109, 3.5174621833908946, 0.4086136481454296, 1.0386922835342347, 8.2816727699772, 34.822590581832394, 48.85108086370653, 51.313344817007746, 59.897044012623454, 55.00546793783865, 25.387525250834805, 2.439726749735494, 0.22000508412959116, 0.1649566565550143, 0.1442000711516988, 0.1604123455622504, 0.15811976616180715, 0.1414256684121586, 0.14281654700396523, 0.15206310567596268, 0.19959915249097734, 0.2004431975224326, 0.16861066612745487, 0.18996092370681225, 0.11094803245918405, 0.10578191088091944, 0.20445009783631374, 0.11822629674908616, 0.15172072566084324, 0.13465410999713406, 0.2870793760784211, 0.14078589306483347, 0.1861712399629816], [0.030339812904956843, 0.04688111441810766, 0.06894035189743004, 0.03163571766157064, 0.050114752394297434, 0.012713849634653138, 0.05988646433838914, 0.018935232430756576, 0.05990590764990738, 0.015414432141809695, 0.036936975234458526, 0.0850136119932417, 0.032334690538024714, 0.11605952430756823, 0.20640805003143128, 0.014071358394088044, 0.026386040788624558, 0.01249583441794159, 0.031431909545414874, 0.06181320228103188, 0.009334627182162818, 0.01804218458522472, 0.055237394652419516, 0.04368300376940639, 0.06735098758532156, 0.06253834280575957, 1.6204952448606493, 17.130641860346643, 42.74963401979016, 49.45287050739412, 48.72139161632907, 36.896928202721384, 33.481304722447554, 34.878833447733236, 16.90685103016515, 2.6554281817328547, 1.1171823427561791, 0.3816150549438692, 2.677736662087902, 4.446113474907414, 2.630704011647932, 0.8735250753741112, 4.241204444439181, 16.033507854707782, 33.894114571232954, 47.8660717318135, 56.31144069856214, 54.1376474595839, 52.18368345691312, 48.61753117653632, 46.13993075586135, 43.625656174075225, 41.26194177135345, 40.41745939562398, 39.70887145688457, 43.20593118667603, 49.89268587481592, 51.54074815011794, 51.66000389283704, 49.31206918531849, 48.06852879062776, 46.64232753938245, 49.69040924502958, 53.23798910264046, 54.727164007002315, 49.51887615265385, 50.99908059643161, 50.45741304274529, 52.49060500052668, 52.50561591117613, 50.48470489440426, 51.93675064271497, 48.86611923094719, 43.117199328637895, 37.759151458740234, 35.63826707101638, 37.03316388591644, 38.284168551045084, 37.58242514825637, 40.909430519227065, 45.296542721409956, 47.98284069184334, 48.11706812151017, 46.64536345389582, 47.65245552985899, 45.42831866971908, 48.03114860288559, 48.385526903214, 54.6305795638792, 39.1002215877656, 41.13546494514712, 54.549868952843454, 48.232272055841264, 48.486018027028734, 45.12642560466644, 47.37176287558771, 42.6614159922446, 39.31004485776348, 34.890726074095696, 38.54815975312264, 38.544853195067375, 37.67041175596176, 35.19403119241038, 36.04995512193249, 35.37926120142783, 38.94492710790327, 36.76855294935165, 36.886192675559755, 43.29512980676467, 48.018828438174346, 50.07306783430038, 50.15699478887743, 49.92994839145292, 45.75345570041288, 51.427713286492136, 51.55203280910369, 47.567724489396625, 39.24463933514011, 36.277252551048036, 36.85412729940107, 34.67278349784113, 37.27860227707894, 37.59934233080956, 38.37637955142606, 37.38140367692517, 39.71369597219652, 41.40521026426747, 47.72122252372004, 49.383311194758264, 51.93662512686945, 51.46113188036027, 49.80523270945395, 47.11279622970089, 51.78469604061496, 43.910745805309666, 22.594776115109845, 8.237010702010124, 1.966949621996572, 1.911549575386509, 4.985029976214133, 6.313796610601488, 4.344932994534893, 2.9298227352480737, 2.30639043354219, 1.5660651268497592, 0.25131203324323703, 0.8281148152966654, 9.384163752678903, 27.75597787672474, 37.57497264492897, 42.20640144040508, 50.57688059345369, 40.49369458229312, 13.248713285692277, 0.782493421387288, 0.09992031936323452, 0.013660973711540143, 0.01990609374197741, 0.05561669627504964, 0.06242791889235378, 0.01744562425770827, 0.00576121436860112, 0.08630099210647807, 0.040236856833460836, 0.03619852776248609, 0.023492714390158657, 0.015220750750403012, 0.0918270294524489, 0.03122363322144074, 0.01845331141544927, 0.027016575200363036, 0.019484025260974324, 0.016705855284066453, 0.025872859555566986, 0.06628395734174598, 0.06690270357554959, 0.04423081792230087, 0.04251626718248572, 0.04207863562530087, 0.04689003168154628, 0.05316885383499246, 0.06638268309254801, 0.028419318578896985, 0.0587337471604828, 0.042204201266530066, 0.0687478416629376, 0.020629688684317856, 0.05635513991658246, 0.03290202461122986, 0.04302979507032902, 0.05859400506221479, 0.026342576790240504, 0.03520847403354222, 0.046913450989391536, 0.04876672876097503, 0.08830795860699109, 0.0888172998243282, 0.059533803423325864, 0.01425246540982757, 0.02979052211758831, 0.07802804691656944, 0.04631468815909279, 1.6715114299328098, 21.775593026991814, 50.3759140353049, 53.23583572141586, 57.39632906452302, 47.063903885502974, 36.981502348376864, 39.697904509882775, 18.517036937898208, 3.0090303430634164, 1.4233422111118994, 0.7993631677762155, 3.377124926736278, 6.167914838560167, 5.092369558349733, 3.221511018853034, 7.461154114815497, 18.666436095391553, 36.85557465399466, 49.45396484867219, 57.72683581998272, 58.014553439232614, 54.3978927981469, 51.15698345245854, 48.61045129837529, 45.519878556651456, 43.35529896520799, 40.64166207467356, 40.58488576642929, 44.69018743884179, 49.798450931426025, 53.9826746140757, 52.449090634622884, 52.22568811908845, 51.32598661607312, 49.06210045660696, 51.72479752571353, 53.64001635582217, 54.98705240987963, 50.300953618941776, 51.72218130480859, 52.18913947382281, 54.88194857874225, 55.117604578694994, 53.14453078854469, 52.98358025089387, 51.74311891678841, 44.79738581565119, 39.25165253300821, 37.0636446245255, 39.26772640597436, 38.48806511971259, 38.59600874685472, 44.92469810670422, 48.70161894829043, 50.07722554668304, 49.91587492727464, 48.48839890572333, 49.70785594755604, 47.86252590917772, 49.773386986024924, 50.76197724188528, 55.67856234888877, 44.90301132202149, 45.41761059914866, 55.98943764163602, 52.13143748621787, 50.283008775403424, 49.26033704511581, 49.22837365058161, 43.850411907319106, 41.45750330340478, 37.371382021134906, 40.35049276967203, 40.20401577795706, 39.52579482909172, 38.5353571368802, 37.971677241786836, 37.12536311918689, 40.32157313439154, 38.59185103447207, 40.07396567252375, 46.644692728596354, 50.63324505282987, 50.95138849750642, 53.38165375494188, 50.70165903337541, 46.40455345953665, 53.656890392303474, 53.46509041324739, 49.239626930605986, 40.51865262369956, 38.740426494229226, 38.39195136101016, 36.46473792291457, 38.73014596200759, 38.74970682205693, 40.74578531326787, 40.00218237600019, 40.92455517861151, 44.122385132697325, 50.8878461007149, 50.86137402442194, 54.17764386823101, 53.087923142217825, 52.202793244392645, 50.38039338204169, 54.47468888375067, 44.88115587542134, 26.33858430770136, 9.922744401039617, 3.3916992285559258, 4.404611856706681, 6.854336973159545, 9.272466417281858, 8.193415518729918, 6.952566850569941, 3.4630628314710434, 1.4930710436836367, 0.05985021688825181, 0.8611985368113365, 9.78779427466854, 34.18332269114833, 40.81983966212119, 45.825042878427816, 55.89185691648915, 46.483185214381066, 16.982576308711884, 0.9756220420522075, 0.0687673309397313, 0.03587161123211827, 0.06725040024086353, 0.02032235719173426, 0.02571048530479593, 0.07152872550631724, 0.019688681819506233, 0.05193488920227655, 0.023836814272668094, 0.0747860930559616, 0.007689069842003407, 0.03206968157281799, 0.07458402204417414, 0.05540040284094792, 0.046247368182746634, 0.1481477222255161, 0.032564375189042864, 0.019278951184523684, 0.04908125381916762, 0.04420757098423858, 0.06829735131994372, 0.15571708460488629, 0.13517848185954556, 0.222839517518878, 0.10753789165567969, 0.20276153279889017, 0.1749310753638706, 0.22740224526534158, 0.17666805715810868, 0.12667521233520201, 0.1649910539028145, 0.11415141379280437, 0.07542528617646425, 0.19715582230879417, 0.20092551115780108, 0.23210547353711822, 0.10449325140084952, 0.18615928899136283, 0.09564343434307845, 0.2839913369426804, 0.16148489929976004, 0.19801794701526243, 0.12622465304429495, 0.14066489713807262, 0.15646706936099838, 0.16184739678377108, 0.2410944428054556, 2.4763771314774794, 24.853433755136308, 56.840764553316184, 62.49819909372638, 59.16105047349007, 48.458349627833215, 44.96074468858781, 49.071349405473285, 22.15357222864705, 4.413574472550423, 1.3355392193601978, 0.9222599731818323, 8.721421457106068, 9.408216707168087, 8.661324862510927, 2.7499376910348095, 5.991585177759971, 19.270622307254424, 37.301626589990434, 51.16089405552034, 59.63868925648352, 58.539142993188676, 56.943452204427416, 52.9984538785873, 50.345511744099284, 48.08785038609659, 46.21482841430172, 44.514618227558756, 42.29777697593936, 47.06300566273351, 54.41365288149927, 57.18436810278124, 55.72802735913185, 53.63820422080256, 53.375260291561005, 50.96600717113864, 54.432378276701904, 56.74132462470763, 56.63800547199865, 50.028898023789935, 51.490341771033506, 52.31727154024186, 56.66796845774497, 58.15787292295887, 55.190431225684385, 56.69173409861904, 55.007727223057906, 47.25524102487872, 40.912089886203894, 39.10452050547446, 41.09772389934909, 40.722631562140684, 40.508191662449995, 45.934547608898534, 48.60323413725823, 52.334074974060066, 51.467592024034076, 51.26958293299521, 51.47646050299368, 49.10597608935449, 51.04445849695514, 52.14608753881147, 58.50098225378222, 48.45884384647493, 47.5877050430544, 58.34928458736789, 54.055685612463186, 52.54806772355111, 51.81386278521631, 51.44825866145473, 47.30362346095424, 44.17134807955834, 39.08875649975192, 42.896111011505134, 43.15024529733966, 41.08768263170796, 40.41107769935362, 40.15722190180133, 39.027920538379306, 43.74625336739325, 39.44770043896091, 40.87483913667741, 47.09134478722849, 52.301609516143806, 54.21818156396189, 55.084178140086514, 52.341833422260905, 45.83066363488474, 54.11461530193206, 55.925879555363814, 52.19901992428688, 42.909447070091005, 39.66165004238006, 39.535757649329405, 39.46084822377851, 41.008717475398896, 41.82862620199881, 43.817609125568026, 41.660960566612985, 42.51864564034247, 45.9987215072878, 53.56025103599795, 53.821731921165224, 57.32287876067623, 54.55734106802172, 51.28983805256506, 53.47452371351181, 56.04334277491416, 45.48700909460745, 26.762268927789506, 10.414299753404434, 3.6232607643450465, 5.208163809391761, 9.481187501261312, 11.816376466904918, 13.929012110156398, 12.946273050000592, 7.544387300168315, 3.182686173146771, 0.9777568533055245, 1.2195463983281967, 12.651927605752023, 37.21097669293804, 50.425237840221776, 54.11414069514121, 61.76763803728166, 52.96830654144288, 20.48698263783609, 1.1690922153572882, 0.2289006059929248, 0.1688995732054595, 0.12330443312924717, 0.1460329671540568, 0.15082849369895074, 0.16711674870983248, 0.14951836077436326, 0.1847236555430197, 0.11382426360561965, 0.2117330659060709, 0.08298892587904008, 0.16383536430376192, 0.1944272163053674, 0.12324411136608933, 0.11274586461724774, 0.32589288368340463, 0.08820576247789207, 0.11946650116794533, 0.14972247724090854, 0.169881789854938, 0.22933153045033255], [0.08149246504950909, 0.012533168755321494, 0.06426973598859002, 0.07078205791091727, 0.05002613134321667, 0.020842297235503796, 0.05633382352008935, 0.013458889293214007, 0.03340339085327522, 0.06238074319797659, 0.026325897140909108, 0.04168426888363977, 0.0420768506404373, 0.03111243364401162, 0.04217889738239108, 0.03264735783300093, 0.07316843711680944, 0.027617563516081824, 0.02179623183403765, 0.025528351731237867, 0.003791542464656936, 0.024702771333977584, 0.035180630567934246, 0.030633079023250652, 0.07233216787778562, 0.06319155533527655, 0.4733527355617093, 6.295000122439477, 28.507005860728604, 52.38448527551467, 37.50889639700613, 30.738267706286525, 34.34215907127627, 32.36344295163309, 23.595092296600345, 3.845808203181913, 0.6783344524521983, 1.0820870582134494, 3.194750158056136, 1.8405263606579074, 5.4816152780286735, 1.1696833900866972, 2.550074789793261, 8.450645535222947, 25.55788947689918, 42.32207605915685, 54.48234142795686, 58.57124367067891, 54.103181592879764, 51.51784150831161, 46.857755876356556, 45.53014339939241, 43.7152038851092, 40.84437016517886, 41.515499468772646, 48.490815085749475, 51.26024769198511, 53.882026595454064, 51.929792358029275, 52.303915869805124, 50.67843467958512, 50.62782433725173, 52.72311133723105, 52.70519787265409, 51.6318138184086, 49.28600503552345, 50.20736194426014, 50.88038575264716, 51.5319973422635, 52.81855044826385, 54.603762319011075, 51.62110574783818, 52.849313597525324, 48.67575876174435, 42.192151469569055, 39.6403633394549, 37.68711320815548, 37.18381427949475, 37.09279567964616, 37.20432435312579, 39.991301721142186, 42.74852791140157, 43.51516692869125, 40.27138640803676, 40.09587210993613, 41.34611191288118, 49.647180803360484, 47.96249535775954, 53.366752670657256, 37.47454820140716, 38.21229896237774, 51.89801331489317, 46.69960983337895, 52.34543415807909, 49.38363675148257, 49.91501592820691, 47.01178343065324, 45.69247068897371, 37.664441908559496, 36.56144395951302, 34.992095808829035, 36.459242682303156, 35.54625611151419, 36.773432377846014, 36.45060562318371, 37.12863045354044, 37.52823368195565, 38.05802822113037, 37.04513495968234, 41.18392190625591, 47.16981572489585, 50.860189468629905, 51.06747496512629, 50.76666055187103, 51.34874028544272, 52.12671103016023, 49.121873455662886, 41.13746143156483, 36.18930516704437, 37.8188342432822, 36.89309604706303, 41.67519877033849, 41.45538522351173, 41.518586374098255, 38.27561386169926, 39.3907868477606, 39.04108793504777, 42.42754859309043, 46.224999120158536, 50.87831866356635, 52.35827992039343, 51.94993372886412, 47.772036829302394, 44.949059947844475, 33.569609042136904, 18.581222603397986, 3.699368719131716, 2.4587931459949863, 2.447112572769965, 7.183400296395825, 13.083369693448468, 7.3593426231415044, 3.949578673608842, 0.53749022945281, 0.9550312533974649, 0.08847631408923096, 2.331802489296083, 9.4910503010596, 23.584607801129742, 27.031006197775564, 39.10250832957607, 45.71310627845026, 30.122665436037128, 6.8399918848468415, 0.22765951291207345, 0.07818716337844249, 0.04994852663648706, 0.02222945838565788, 0.09516171059541165, 0.047921389040927735, 0.05885275125864053, 0.035332974812556664, 0.08319322620668719, 0.03254571711764701, 0.06943395766880243, 0.07000464720711594, 0.07161614379935688, 0.06229760733643367, 0.014732014425399323, 0.02807315025899199, 0.027157899270194675, 0.02471429138113895, 0.011891065458316478, 0.07920874928634974, 0.028515590933121504, 0.034022700161703175, 0.04709222143696201, 0.034957193363938606, 0.0607705642769654, 0.04683923239128725, 0.05086359567940236, 0.02280884302191196, 0.008392507574641177, 0.05050658721536879, 0.045712466441815904, 0.07107866417256094, 0.03080873723862873, 0.08132828474645654, 0.021577783777648886, 0.029850014590568123, 0.026752498947204124, 0.08916872733783338, 0.061295583483672915, 0.01952290422313156, 0.03193233349931336, 0.10313793461048797, 0.07221723170650583, 0.015869460598145042, 0.043360434788008856, 0.03719837592554189, 0.05987874600255202, 0.03231728118994544, 0.7119768052812546, 8.545344298885714, 36.96831533985753, 57.87751367015224, 43.320295733790246, 36.71650309716502, 41.2947484754747, 36.06440905601748, 24.403712441844327, 4.5317442090280595, 0.6739219698694445, 0.5360140699532725, 1.9583796108922653, 4.926713157084681, 7.503911872063914, 4.934070542935403, 5.097461285129671, 11.215656649681831, 27.516281835494507, 44.4872243942753, 56.99614140295214, 58.5012685868048, 55.95901573857954, 54.02079220741026, 49.67775175648351, 47.22648612914547, 45.6038486573004, 43.13825068935272, 42.345025847035075, 49.60785119764267, 53.3255442496269, 56.28630222812776, 52.89695862800845, 53.91274659864364, 53.40338368569651, 53.22096601609261, 54.11267372869677, 52.68780216093987, 53.56041577554519, 49.72904066885672, 50.581093219018754, 52.11002918981737, 53.63831796953755, 54.898497058499245, 55.17000744419714, 53.66479789057086, 52.90310890443864, 49.0729340430229, 43.9279414761451, 40.95317279138873, 38.76365084801951, 39.46297807078208, 38.42268705368042, 39.439055535101126, 44.14060061977756, 45.97860759304416, 44.72903067065824, 43.246115869091405, 43.72429201679845, 42.52151681530861, 50.737054501810384, 50.17203707848826, 54.31556224822999, 42.83583987143732, 41.468988003269324, 52.74033054228752, 48.830798287545484, 54.59549396268783, 51.390843006872366, 53.192042458441954, 49.4516114265688, 46.62819523965159, 39.8285625826928, 39.35524625162925, 37.04640972998835, 38.82037616545154, 36.64835976016137, 37.81678284368208, 38.45390127551171, 39.97680071861514, 39.55689922455819, 39.74027395248413, 39.92895172488305, 44.438210456602036, 48.870304399921054, 52.558764027011016, 52.48544708375008, 51.239553266955966, 51.080203056335456, 54.19612215411279, 51.377279450816495, 42.80250756971298, 39.358368458286414, 40.51554218415291, 40.075181607277166, 43.30363350529825, 42.60577324898013, 42.84839145598873, 40.46329229108749, 40.855631289943574, 41.11762208323325, 45.46105084880706, 49.43425886092648, 52.97671610309232, 54.70176666013656, 52.592496410492934, 52.06540438436693, 45.782649901605424, 38.42594262092344, 19.7651017865827, 5.3544976345954405, 3.394972936760995, 6.0568009557262545, 11.057648870252795, 18.270502244272542, 9.600689372708722, 4.357816999958408, 2.41328384607069, 0.34433746169651713, 0.2994604907449215, 1.913900423434473, 13.451834205658207, 25.833106502409905, 34.945121503645375, 43.960952143515314, 53.120082655260646, 34.85762519221152, 9.31018392885885, 0.29502747700579707, 0.05928953245822942, 0.07614180821204379, 0.089916015464452, 0.027495908753706083, 0.06686587006815019, 0.020307033518028837, 0.048742275234431996, 0.04081175985535787, 0.007755557176536851, 0.04027362522338668, 0.030853053509828546, 0.019657036642574018, 0.08735768016307585, 0.01806141722256378, 0.03579306040680216, 0.0181140742760392, 0.04087275194544946, 0.010725209872508723, 0.04440318770526398, 0.05327817841222691, 0.03674961694125687, 0.18055200036014282, 0.09120859731469425, 0.11143256008865372, 0.18989649571238026, 0.18434298645344474, 0.1031320893596257, 0.18556388545661204, 0.1271219641691254, 0.12066532917801412, 0.0894936558700377, 0.19063606167272215, 0.3028309098895519, 0.19837043939098237, 0.08364871910382664, 0.13094751614957087, 0.15929676832691317, 0.18653191415773285, 0.09007720802459987, 0.1313796663476575, 0.16245321911429206, 0.139763226972953, 0.09141095177901369, 0.19972495944990268, 0.21318382193003932, 0.1923129208866627, 0.20411416828151674, 0.8956931471343964, 11.51633672175869, 41.101391315460205, 65.13169803927022, 51.37321979768815, 43.2164196045168, 46.69190629836052, 44.17932225811867, 31.753416330583637, 5.854632681415928, 1.2569080773861179, 1.7744278042547166, 7.184421093233171, 9.134476454027238, 11.11226297193958, 4.069861832164949, 3.6124409062247125, 10.127531347736236, 29.3327255787388, 44.46043460599838, 56.9911874494245, 61.68592722185197, 59.31266969250095, 55.82739276270713, 51.59164090310374, 52.022474042830936, 47.94282467134538, 45.31817459291028, 44.155509548802534, 52.35779354649206, 54.33195775555026, 57.65589583304621, 55.79051071597684, 56.04989313310193, 53.20333103979788, 55.31147164683188, 57.80937817788894, 54.47604602383029, 53.35777436533282, 52.81154117276592, 49.872493513168834, 51.649978314676595, 52.10696189634262, 54.605170449902936, 57.17874734632431, 55.23897447893697, 56.12097824773481, 52.72141687331661, 45.354021133915076, 43.17956893674789, 41.432957110866425, 41.222984790802, 39.774225988695704, 39.96963062594014, 44.67976962366412, 47.725478295357, 45.87174261769941, 44.522984643136304, 44.99417504956646, 44.747673696087254, 52.85429500764417, 52.51561403274537, 55.919246827402425, 46.98988876035137, 44.29997828698928, 55.07390937497539, 52.05193888756537, 56.04584916945427, 54.167614367700395, 54.94366707340364, 52.45920250492712, 49.693198050222094, 42.26113811615975, 40.134711419382405, 37.93952557348436, 39.66691778552148, 38.76012071486443, 40.222392082214355, 40.522433788545676, 42.78751234854422, 40.70465141727079, 42.79558850872902, 41.64772648965159, 44.9814744149485, 51.14302373701527, 55.59747519031648, 54.403795965256236, 51.718298158337994, 53.154901535280295, 56.991391412673465, 52.76518660206949, 45.31821773898217, 41.44902313909223, 40.89393323467624, 41.84372340479205, 46.923612471549745, 46.29981833119547, 46.687054326457364, 42.65298289637412, 43.038697012009166, 44.57534044019638, 48.14265766451436, 50.54581149931877, 55.41766589687717, 57.047626433833955, 54.31350300388952, 52.05418248330393, 50.82056568514917, 40.014800640844534, 22.68118985237614, 5.853456950956776, 4.68993192718875, 5.869348433709914, 13.875980684834143, 24.295433452052457, 17.09046894504178, 10.001687003720193, 4.809757884471647, 3.184097245816262, 0.4910271807063011, 2.8233612737348004, 14.324743959211535, 32.717381946502194, 40.14267775320238, 48.42532327098232, 59.295324971598966, 39.41978100807437, 10.503944543100173, 0.4243417396660774, 0.21903737718539856, 0.16085730475043097, 0.11440820646502319, 0.1405320268484854, 0.1747681591058931, 0.17540033486100937, 0.1198302933405484, 0.16395202417287136, 0.11700344422171194, 0.15824636985217372, 0.16291829577136427, 0.1926983397213682, 0.18499437569370195, 0.1325957696404188, 0.09892299545988922, 0.16418626321659935, 0.1519914458115255, 0.1617747410050323, 0.0983237385028793, 0.13127587675567598, 0.15123741611117317], [0.05397788098742885, 0.09047780306108537, 0.028951113833294764, 0.01240976635486849, 0.011401288211345674, 0.012101753044032283, 0.023285776804832202, 0.08226561630445142, 0.03914983935594078, 0.053162717470718976, 0.04047532468253086, 0.13624671486116227, 0.07966649448198658, 0.013765380004300706, 0.07653583021413896, 0.010075409307084497, 0.03483844207479589, 0.01833171027922823, 0.03973061444177743, 0.019033000571653247, 0.07741750548443488, 0.03583369754074562, 0.003925069435236735, 0.03802139567391526, 0.04247408255093521, 0.007647426738854378, 0.1926178545240433, 3.7251798760506416, 18.34808280391078, 44.44390966046242, 45.41880692205122, 36.94485564385691, 25.45609220381706, 32.27995138014517, 21.646680408908477, 7.388738336101656, 0.41620456823898905, 0.36034523659656126, 3.2535553122720415, 3.8300831760129626, 4.256115824945511, 7.45961360393032, 3.405870016544096, 4.079667022151332, 16.780044724864347, 35.801174871383175, 51.37670286240117, 56.138236676493, 54.62220138119113, 51.301667921004764, 48.37674079402801, 48.02639861260691, 43.3490074834516, 44.05521454349641, 48.39477977445049, 52.679569105948175, 53.46907554134246, 55.230686510762865, 50.782032320576334, 53.40921625014275, 54.0443774192564, 54.63571786880494, 52.82487723135179, 52.33872298271426, 52.274902097640506, 51.65033917273245, 53.31898212432862, 53.93509234151533, 53.45920685798892, 52.11790138675321, 52.441241971908084, 51.74525660853232, 50.54811785298009, 52.511789721827355, 49.03297293570734, 41.86781852476059, 37.747721672058105, 36.46426723849389, 36.95817209059192, 36.75955503217636, 36.92926814479213, 36.90533776437083, 38.971371727605025, 37.27044766949069, 41.35732204683366, 43.974872635256865, 52.59102944404849, 50.803299411650634, 51.44436767024379, 36.68306489144602, 40.2020545928709, 48.522280339271795, 47.85020966683665, 49.246298882269095, 50.50498747056531, 51.46504248342207, 50.213669115497225, 46.393739484971576, 39.11329876992011, 36.319469021212676, 35.78211999708606, 37.173117976034845, 37.167732561788256, 36.567500099059075, 36.852781926431966, 38.80323148542835, 39.19829260918402, 40.356886233052904, 39.87526624433456, 42.337859676730254, 48.09968809927664, 49.33769010728406, 49.874344871890166, 49.74388683995893, 51.790673732757575, 52.3580994913655, 49.09325192051549, 42.999108529859974, 37.87511633288476, 37.77315432025541, 40.51885658694852, 48.21111871350197, 47.97252485829015, 47.64124147353634, 44.01020534576909, 41.85144262929117, 41.31993793672131, 42.983038579264, 45.38401549862277, 48.42205593662877, 50.94880757793304, 49.218579492261334, 48.98840696580949, 43.29215272780388, 24.55164267170814, 9.580805897712708, 1.6410184339169533, 1.6370128359525435, 6.66155198889394, 8.255278160495143, 12.748876829301159, 7.278246148940056, 4.5036065963006795, 1.9495846763733897, 0.23214428355136227, 0.21264397509155736, 3.8296811330703, 15.34031423830217, 28.491690966390795, 32.2624066183644, 36.96830749511719, 41.047976478453606, 19.256337035086847, 2.2136611900021954, 0.1319627818321028, 0.03598287401180114, 0.021815276779835264, 0.01993761634484174, 0.024590256000538508, 0.013380933143649132, 0.0850755348801613, 0.03197163764026857, 0.08590647214723211, 0.04190126711863183, 0.020908180796991915, 0.10905394901431377, 0.016554865099850203, 0.04142189526089257, 0.018834857675697536, 0.03302142707510822, 0.04356381581014684, 0.06309577519254339, 0.07699080983236914, 0.030299689049922654, 0.04015347199334253, 0.0036307260057994077, 0.04284644341697136, 0.029151689058410066, 0.022185322145120274, 0.05142932479840614, 0.026902962445972428, 0.05378006942450039, 0.015404885728663255, 0.047340035558708256, 0.03804404889383624, 0.06874473134596502, 0.012078261915444127, 0.030085437240139134, 0.05093128720839178, 0.055424354579900546, 0.013106372019636535, 0.030684401168518012, 0.07661630775058463, 0.029048033531815298, 0.08522835409929676, 0.06638222343979344, 0.05842436638270175, 0.025782003442967133, 0.11054617337762349, 0.03150543866438731, 0.023757267533050432, 0.06854681253072716, 0.19981497478100563, 5.3645781259382925, 23.514340500677786, 52.18101624519595, 49.74488704435287, 41.03302832572691, 29.830219399544504, 38.250114533209036, 26.5866389197688, 7.961868691828943, 0.5487434481901508, 0.6393104238856224, 1.8441612946410335, 4.757024559282488, 6.47373027378513, 6.2422462048069125, 5.70844006153845, 6.709286743594754, 18.984277517564838, 37.480227793416674, 53.021282072990175, 58.37869451891992, 56.380368509600245, 53.23467469984486, 51.54146594385947, 50.53921799505911, 46.0710931593372, 45.470797938685266, 48.237065192191835, 55.50870410857662, 54.34139497818486, 55.04549572544714, 52.77164282337312, 55.442772988350164, 54.69766778330649, 56.04726514508648, 53.524302513368674, 54.647634029388435, 53.79497743421986, 52.83269059273505, 53.81658969386932, 53.41607255320395, 53.566056143852975, 53.69262710694344, 53.54819367008825, 52.2140347573065, 52.35043518004879, 53.04440836752615, 51.18630709186677, 44.032068637109575, 39.15253031638361, 37.55157178448093, 38.66477574071577, 38.07856575135262, 37.73597417339202, 38.89964334426388, 41.30474267467376, 39.63912779285062, 42.1146297454834, 46.05426226892779, 52.47897517296576, 53.66585300814722, 52.44681565992294, 40.448752064858716, 42.563721518362726, 50.76294606731784, 50.0963157223117, 50.33198348937496, 52.15467752948884, 52.628723421404445, 52.91713922254501, 48.08607355240853, 40.43446287032097, 37.0218909940412, 37.010598490315104, 38.730244021261896, 37.48424430047312, 38.91173601150513, 38.514647022370376, 39.55736990897886, 40.91438055038452, 41.24966867508427, 40.84391909260904, 44.056469701951556, 47.82059184966549, 50.250912020283366, 52.17669771563623, 50.034891405413234, 52.602019925271314, 54.52997861369964, 50.812913140942975, 43.880045413970954, 38.966256956900324, 39.03862860894973, 41.93416149385514, 49.347166553620376, 49.18301928427912, 48.87193610591274, 45.16941085938485, 43.50907548781365, 41.83230930759061, 44.650540121140025, 47.33617913338446, 51.17207281051144, 53.60833929431055, 51.474228674365634, 49.92172318120157, 44.59125741835564, 29.623435966430176, 12.897260092919874, 3.618678455391238, 4.999577066590709, 9.958954741877895, 11.746746551605964, 13.076425137058383, 6.882758957724418, 3.2063427231004162, 1.4393728154320873, 0.5237924547926073, 0.4901981816416787, 4.418631878591353, 17.591520355593776, 28.54840059434214, 35.29474196895477, 41.811607037821126, 48.86040041523595, 25.015388419551236, 3.888742221939949, 0.0734327910768409, 0.05885978394578542, 0.04898196116330163, 0.014491810429570897, 0.04116998639919105, 0.03573213726462376, 0.03485331184140617, 0.07667246199543439, 0.030798230342747226, 0.018278411627116225, 0.02852582395257008, 0.046385696848794344, 0.032298446918327006, 0.11172605603332482, 0.04897541111154903, 0.025778895041214365, 0.038021786378756646, 0.02712765411894408, 0.05853832962231771, 0.056445925166049314, 0.08219342783934648, 0.024281083981716828, 0.1599037244675621, 0.21993601364233803, 0.12705775067931221, 0.13597478429155965, 0.126379762866324, 0.28147948785654964, 0.16426314780068013, 0.09375196325802997, 0.179584538564086, 0.1799367245046362, 0.139730729523205, 0.21579806632812948, 0.17056881750543273, 0.12818927786523296, 0.23179909965443998, 0.10819451327645972, 0.17173570730993826, 0.1623150934615443, 0.16331777998035954, 0.16843512474048525, 0.2280718367546797, 0.12793636925879026, 0.2048087189154279, 0.10434995465461286, 0.15477131841884506, 0.14994468870422534, 0.30060481159917773, 5.994273962513094, 26.947828415901434, 57.631228047032515, 56.90879021921466, 48.463178065515336, 39.09582461080244, 44.94194869072207, 30.68974602606989, 9.995634786544308, 0.9288404233032658, 0.9815480692252037, 7.797742014931095, 9.644949397733136, 11.205691868259061, 13.807514732883824, 6.723449441694445, 6.88393468818357, 17.905641409658617, 39.017051650631814, 55.17099195911039, 59.44808560032999, 60.26670386714321, 56.76041480033629, 52.98821257006738, 53.08704453129923, 49.777223064053445, 47.96784547067458, 51.46914136025214, 58.11438168248823, 57.687031607474054, 59.8665475845337, 54.71342394428869, 57.113981170039025, 57.84321646536551, 56.7118440904925, 54.468781794271166, 55.29452308531731, 56.05054424655054, 53.39514670833465, 54.609434066280244, 57.02880690174719, 55.05025356046615, 54.733675141488355, 53.55098247528077, 53.16020457975326, 53.886105860433275, 55.25050232487341, 53.234455047115205, 46.65448296454645, 40.3479746080214, 39.30533409118652, 40.19514337662728, 39.6034969822053, 39.2509739629684, 39.641230183262984, 43.44608222284625, 41.01182791494554, 44.399806530244895, 48.56031948520292, 56.24385826049313, 57.75917576205347, 54.36701590015043, 43.66046720935453, 46.017086044434585, 49.717552046622004, 53.0809413233111, 51.669539174725934, 53.81059238987585, 55.266933133525235, 55.895944026208696, 50.02139845202046, 42.05968910647977, 38.326157523739724, 38.598868154710345, 40.71762661780081, 40.092404734703806, 40.9306073957874, 40.352842269405244, 42.69575242073306, 43.6557250638162, 44.373122645962624, 43.34041357040406, 45.819641774700536, 51.00482294636389, 52.39817434741605, 53.71803229854953, 50.362464227984034, 54.728238736429525, 56.65338116307413, 52.675721260809134, 46.558314292661606, 42.43941376286168, 41.68782880229335, 44.224288309774096, 52.32567325715096, 52.083290392352694, 52.19653314159763, 47.987594604492195, 46.31144423638621, 44.456716199075025, 46.67848002526068, 50.14880487995763, 53.47632015905073, 55.368369548551506, 53.43939104387837, 52.755623863589385, 47.696943052353404, 29.750236388175722, 11.481379578190467, 3.289116991143073, 4.431550695050148, 13.122086428826856, 18.51728600840415, 25.121053149623258, 18.517174220854237, 9.284100167212948, 5.398835126430758, 1.8982232001519974, 0.6989146384500688, 5.362555163521921, 20.86407538383238, 39.17595471105268, 43.12802899268366, 49.72897791093396, 53.15986333354827, 27.79258731872805, 4.42050677153372, 0.2118515950297156, 0.21869761719098016, 0.1377244831453408, 0.12722401474151881, 0.13390343576189012, 0.1637827953503978, 0.19172974411518345, 0.1342873683860225, 0.18486122961246199, 0.10514100938434563, 0.06632888839850504, 0.17683420630712665, 0.12915087142778983, 0.23082003928720954, 0.24386751255200756, 0.10691293244881016, 0.1288580113360959, 0.13000801656275027, 0.1948927219716772, 0.1522063028307692, 0.1785494924913491, 0.08357485290616752], [0.05059263804146359, 0.02640923601575196, 0.05967857488881677, 0.037770547843988866, 0.015602575675133738, 0.016337389975125273, 0.027061914198941765, 0.019722037287729404, 0.03714566524591177, 0.044984636948473995, 0.023026143861634117, 0.06513090308515296, 0.07025518860187262, 0.03270998552081085, 0.07021748941511878, 0.01640598931830497, 0.03034420641920259, 0.04522974294940791, 0.015793811330842157, 0.026803388252794266, 0.05312981782481075, 0.0781494565308094, 0.05090090799175444, 0.05853505459644141, 0.05137048541538177, 0.06318440007406377, 0.1510522526598746, 0.32790027919315523, 8.910392426675367, 32.05880030508965, 43.367579906217514, 43.678447354224424, 32.69575203618696, 25.74232912832691, 22.974314458908577, 9.817022796600096, 1.035750138182794, 0.05147112255555488, 0.8341556330842357, 5.993095780572584, 4.131210888585737, 4.309696382091892, 5.580465870518839, 3.593960168861574, 9.150266935748439, 28.974921088064875, 48.647647134719364, 56.136981518037864, 55.51568200511318, 52.20637829073014, 53.18653545072002, 47.417238835365545, 49.16340743341754, 48.6178449661501, 50.40604960533881, 51.166051972296934, 54.402423135695926, 52.70363284695534, 52.311721386448035, 50.76412670073971, 53.4381123512022, 53.441564036953835, 53.660067512143044, 52.97405673611549, 52.25500391375635, 53.42848293242916, 52.51269186696699, 53.06507141359391, 53.813777354455766, 52.79652633974629, 53.87060857588246, 50.434153387623454, 52.93989289191462, 53.04881711159983, 49.68519641507057, 46.479302067910474, 40.68147413192257, 36.41428839775824, 37.94436970064717, 39.209181108782374, 40.2350378036499, 38.17379697676628, 37.39612433218187, 38.54835979400143, 40.654617663352724, 45.97660326188611, 50.29541130988829, 48.60285758972169, 51.99777880022603, 36.98854692520634, 39.74375701719715, 50.31297568351992, 45.38117962498819, 52.416480049010254, 50.03136911699849, 50.06713721059984, 47.978231906890876, 44.874252503918065, 38.23385238647461, 35.87267575725433, 35.65994993332894, 36.441948952213416, 35.43895183071014, 39.4856297585272, 45.655172871005156, 48.3967056582051, 46.49442672729493, 48.116260113254675, 47.15560497776155, 47.5610682272142, 48.55166673660279, 51.454310878630615, 51.95024751847791, 51.970043720737586, 50.83034415398875, 50.623823519675966, 50.22610695131364, 40.47339631665138, 35.553539952924176, 36.51652105392949, 43.47412716957831, 52.345916609610285, 50.6811724939654, 50.92764246848322, 49.050972692428104, 48.61114555789579, 46.049967273589104, 45.31968470542662, 47.35292765402025, 50.71110802312052, 49.41836541698825, 50.12297215000276, 46.20334371443718, 41.79539980426912, 31.42859897305889, 10.409431111428047, 2.394265498845808, 5.251415294985618, 8.814212968272548, 11.183920752617622, 9.274165784159015, 3.2375140440079475, 1.6038500541640868, 0.8143928322580554, 0.09960912678751255, 0.724893537980895, 5.052064263051556, 19.36684000876642, 23.880964440684167, 36.48373003928892, 44.33159259057815, 35.891083440473004, 9.087487439955435, 0.8157442113564861, 0.027233470013485323, 0.021178309144752643, 0.03365033163478778, 0.03952586212225499, 0.013361481213641745, 0.037003391227054025, 0.07119302577789753, 0.07471840918785141, 0.03405299510866885, 0.01620766639168705, 0.06543451905130379, 0.02711145518978517, 0.04953428757407012, 0.03483483763111215, 0.044795263844031485, 0.039149896812535105, 0.05658466368913651, 0.020719744235036835, 0.037087634085647525, 0.017649051245121707, 0.013428336749183796, 0.05425330491796617, 0.06320249507083528, 0.028763609983387495, 0.056299226989428845, 0.022615216214269884, 0.029145700166062005, 0.05098502061540081, 0.03279963696014977, 0.036923530391387405, 0.06344995296169674, 0.009055569122034696, 0.026475443249388088, 0.04381104770507063, 0.024927018675953153, 0.04554256346196898, 0.04521274345836813, 0.019352095344314174, 0.06828693252417349, 0.0622641982420558, 0.05131312458205128, 0.055384537160036065, 0.07751165769032894, 0.03274707183722527, 0.08465001134261971, 0.04790802463708867, 0.04053082775264498, 0.01415707118388626, 0.09149123013259904, 1.008096386588389, 11.301874268439509, 39.68008910456012, 52.531295668694284, 45.63933826261952, 34.71407821101528, 30.185684196410644, 27.806927504078036, 10.361967490565393, 1.1767190190092212, 0.09956556702813796, 0.7741317249113514, 6.196699152069708, 4.442567161975369, 6.248946593653772, 5.833531800777682, 3.5305815310247484, 10.583500016120173, 30.09940774210038, 50.20111360857564, 57.04190369575255, 57.76199594620736, 55.40394936838458, 54.042478992092995, 51.143337526629054, 48.8051655984694, 51.51864559419694, 52.88146918819797, 53.0659657139932, 56.37809745727047, 55.25831176388649, 54.45965051651002, 54.22226475131128, 56.51945967828074, 54.382352367524184, 56.3849929840334, 54.49091572915354, 54.930923292713786, 55.82788698134884, 54.68568886480024, 55.47994921284338, 57.379564854406546, 56.02353480554397, 55.96578967186713, 53.295604798101614, 52.655144506885165, 53.91880666055987, 52.2229189257468, 48.493933370036466, 42.5781205392653, 38.29754775570285, 39.75437879562378, 40.7914024783719, 40.686118218206595, 38.924789659438595, 39.89677259998937, 40.383236715870524, 42.20418530125772, 48.511835067502915, 53.20223277614963, 53.03425335115003, 53.416154922977576, 40.29344189551569, 42.90042169632451, 51.689590331046816, 48.63213023831768, 53.79191014074511, 52.98965207992062, 52.10110972004553, 49.834501435679776, 46.691847462807935, 39.30212951475574, 37.931045409171816, 37.358885349765906, 37.93118269212785, 37.26532113167548, 39.697869208551225, 45.6552238618174, 49.18707893740747, 47.8964622559086, 49.17339771024643, 47.97032833099366, 49.77392435073853, 50.82003616517591, 52.123310335220836, 52.64067880568966, 51.40626184401974, 52.74606504747945, 51.540351990730535, 51.85815811157227, 42.92419910430909, 37.28756881529285, 38.65340086721605, 45.60500183413106, 52.55426899079354, 54.25756216049195, 52.73101491312827, 50.70073727638491, 48.59860966282506, 48.03206643750591, 46.734711124051, 49.40142470021402, 51.2445346770748, 51.712877442759854, 51.849438682679214, 49.44944235586351, 44.661024616610625, 32.36329586275163, 8.70929446912581, 2.1970323016566615, 3.927903901184759, 9.478236898299187, 9.22620794465465, 4.026496842984231, 1.1942722384006748, 0.35320848406803224, 0.8020666614174844, 0.08936578047371681, 0.5345776857387635, 6.470928230593282, 23.172500056605188, 27.931788313773374, 42.890458876086825, 48.80497732470113, 42.806684893946496, 13.0840168845269, 1.1064006051709576, 0.05837856964658826, 0.054671914511991125, 0.02299705358792938, 0.04254999803379179, 0.06826641668956127, 0.009435705780502289, 0.09154854117021446, 0.0337974856337232, 0.05029644163685942, 0.03484685755064411, 0.005881852149257377, 0.049611578184750774, 0.012013758269829616, 0.037814869860848116, 0.03867909364822892, 0.0105908150679522, 0.08899410525637289, 0.05304300474123128, 0.01103384946022303, 0.037996493985936526, 0.029622084280896573, 0.01888418990758158, 0.13625629096021577, 0.1613461914201898, 0.10918552461530893, 0.18600591818892187, 0.10754428082896818, 0.2154418814086145, 0.1279114254359757, 0.12959553950255917, 0.12052671322899482, 0.13446154613648692, 0.1372592073054083, 0.10831088203215793, 0.17323806701648622, 0.1554789997997784, 0.1889007346284005, 0.09050755025518518, 0.11372386012226345, 0.20035273786033356, 0.13655238394295016, 0.15020704317477443, 0.2043562061003139, 0.21555967508785187, 0.19260656238803942, 0.1968507354538287, 0.17185627422746153, 0.1521097144652759, 0.2189383986255815, 1.2040753446279036, 11.666277166335814, 44.65281509583996, 59.75897266018776, 57.36010597598169, 44.29163540563276, 37.9941681123549, 35.32591304471416, 13.925126021908177, 1.5826017169221755, 0.5250410555351166, 2.152002021189659, 12.121078929593487, 10.485248565673828, 10.531086364100057, 8.908279249745032, 5.886109702048763, 12.81724178021954, 30.847291946411136, 51.93627603592412, 58.9505054873805, 60.612072483185806, 57.29221759303924, 57.81602267296084, 52.5742377773408, 53.480662222831484, 53.97741471567462, 54.33352670361919, 57.20444279332315, 58.00326093550652, 56.90948055636499, 55.164135656049176, 55.84326659479449, 58.81024153001847, 56.20730177048714, 56.53145820863786, 57.873030401045284, 57.980122873860026, 58.29796037366314, 56.77813606877481, 55.98251073591171, 58.81901979446412, 56.887723169019154, 58.41129333742204, 53.075995214523815, 53.289274092643495, 55.41539876691757, 53.4149193763733, 50.98549742852488, 45.21672248840333, 40.076538747356786, 41.64615361921249, 43.257557422884055, 43.0049567837869, 41.522649949596776, 41.856176930089156, 43.67868661880494, 43.05366869895689, 50.785511462919175, 54.060270863194624, 54.677585248024236, 54.417281073908654, 44.43225237631029, 45.1620917166433, 51.968298266010905, 50.32029482626146, 55.59274481188867, 54.70300220674085, 54.317762697896654, 51.95495828505486, 48.19826118407711, 42.32930498738443, 38.70093214896418, 39.78585581625662, 40.3432559967041, 37.86312956963816, 42.09633188862955, 48.11785651791481, 51.23810198999221, 50.88003273933165, 53.21148564738613, 50.783762085822325, 51.795133467643495, 51.310257911682136, 55.136557471367624, 53.667108166602354, 51.52565486969487, 54.35743747218963, 54.06312634868007, 55.20656001183295, 44.75924861046576, 38.662496843645656, 40.18045017796178, 48.913356334932395, 55.56488029418453, 55.61996998325471, 54.88782821163055, 53.447318153996626, 51.5286829394679, 51.67307715262137, 48.646933263348, 51.78211512104158, 53.67159143570931, 53.86223431556456, 52.203758147455034, 50.815458759184814, 46.30552537979619, 39.565587274489864, 14.559277180702457, 4.662231658735584, 8.984705651960066, 16.09646091538091, 16.648662974757535, 19.63897797369188, 13.426416266349054, 6.328587868521291, 4.6686962150758315, 0.15584702843860274, 1.7865936482144942, 6.600650818117204, 28.67953327394301, 34.02702016215171, 50.56596855963431, 55.52799824745425, 48.72414119781987, 13.274969631625762, 1.5209803009225478, 0.11650357185111893, 0.13854551489555067, 0.21806466002618113, 0.13588257794899328, 0.24037160820538, 0.19516511219403437, 0.39933007210493093, 0.16698188659164215, 0.17076590128483313, 0.19844113398463498, 0.13554753705618844, 0.16908700427701398, 0.1261026228988363, 0.07851890243229367, 0.06470378608472886, 0.1606045110571769, 0.2016652456574863, 0.13433437554105637, 0.13655940130833658, 0.1584795516945662, 0.10611194155869946, 0.12248992844815217], [0.047714403575106014, 0.05580347234142884, 0.09037443481746221, 0.015448624561090144, 0.07165432562150302, 0.026083692697988405, 0.0015762723482874855, 0.014459583983426134, 0.02332723173763483, 0.06701558663119232, 0.04836725221285897, 0.04534482467739333, 0.0779213538513549, 0.04855569069003386, 0.024835810162908128, 0.06171062310797073, 0.029503957353412148, 0.04134109213707909, 0.017566533999577645, 0.05157314631487093, 0.04329907114527399, 0.07040481323436384, 0.011719153412888128, 0.06869315830690247, 0.02061844825924885, 0.09915253072376214, 0.0640898087482539, 0.10657609124938328, 2.6932074706400595, 18.178187301081998, 40.931823330540816, 46.07018316945722, 33.319083336860906, 36.192858834420484, 24.634016367696947, 16.33937330015244, 1.8096087680708979, 0.7098017284466375, 0.27095393007320745, 5.987335289678266, 7.396191820021599, 10.369647491362787, 8.646686577027845, 2.555339346008916, 9.901646952475271, 21.78733660328773, 43.841943510117076, 47.3933006102039, 55.14356674686555, 51.85087034779211, 52.817562010980424, 52.20232648234214, 51.195626643396196, 51.30465676707607, 55.930045112486816, 53.94813422233828, 54.99238683331398, 52.05770084934851, 48.58912929411858, 48.4392672969449, 50.54468185670915, 51.24394632154896, 51.996413815406065, 50.672547201956476, 49.05877820907101, 47.621276609359256, 51.027490323589696, 50.012663333646714, 52.465937214512984, 50.61141314045076, 53.63008099217569, 51.52954193853563, 53.763057185757546, 51.937758691849254, 51.8075163902775, 48.35909405062276, 41.93922919611777, 38.16271628102949, 39.481330840818345, 36.411574117598995, 38.66170452487084, 39.12805864887853, 39.49041112776726, 39.985061230198035, 44.28870539511404, 46.55866730597712, 50.83987943587765, 50.54637632062359, 51.017629484976496, 37.97584672128001, 39.875132883748705, 50.90102918686406, 50.18508288168138, 51.98777283391645, 46.551077519693685, 49.711895988833525, 45.56363259592364, 40.714943716602946, 35.23150943940686, 37.22592092329456, 36.55775300918087, 35.802512399611935, 37.905961851919855, 48.78837393176172, 51.30933223232147, 50.68926826600106, 51.53031072308941, 49.43127001485517, 49.93120747227823, 49.219309053113385, 51.26987318838797, 50.47508332037157, 51.64930758937713, 49.97426332965974, 51.662121972730084, 51.58464339471633, 50.06618799701814, 41.500347352796986, 36.199507251862556, 38.06688885534964, 46.47236339507565, 52.02077173417615, 52.689053397024836, 51.97174995176254, 49.13176567323747, 50.6312289545613, 47.87883120198404, 47.00513109084099, 48.935980566086315, 48.62920022779896, 51.267904158561464, 50.22872709458875, 44.58891576336276, 30.896427477559737, 14.00574347665233, 4.019554247779231, 1.8789131266455499, 5.090993787011793, 9.414136544350656, 7.626837972671756, 3.1711644559137286, 0.26852668773743416, 0.25865766730520034, 0.02971535740089753, 0.13103049879352893, 1.4905146389238297, 11.196630212568468, 20.57067228901771, 27.37416651941115, 32.11134633710308, 37.29429175776821, 21.825322797221524, 5.4974018373797024, 0.052795317023992545, 0.052392576941319054, 0.051805516104063684, 0.06188200080707189, 0.04009239946401889, 0.10894156391582183, 0.03823869651363742, 0.04032324856868194, 0.02528273053617487, 0.06272207367263975, 0.032888016693534396, 0.05436610753437685, 0.015176918072205399, 0.05438252479859418, 0.0497434142556402, 0.053633934322504274, 0.06055120649116655, 0.031336299857244856, 0.031894808597562295, 0.05623561870907584, 0.04510996510244666, 0.040636026946407174, 0.04320885663131072, 0.04919284218621831, 0.09012150322838176, 0.10416259253097158, 0.011329045162476119, 0.023978435201570395, 0.022256156549819057, 0.01856803116689046, 0.0461300992737374, 0.0062363871069054215, 0.020875865293125954, 0.04070906576910808, 0.036475395768760674, 0.033030359660305326, 0.010436224270491831, 0.038178474341909734, 0.0701614041181822, 0.03351119091554034, 0.004693526247020571, 0.029601694850791848, 0.01618883212006861, 0.05419675230739578, 0.012771401032354805, 0.02050305051999467, 0.0325541440848141, 0.03934187844635979, 0.04220547680292399, 0.09704046462091709, 0.18996051001933315, 4.184025602955972, 23.682465053373768, 47.15150217856131, 52.09028005599976, 38.95103423826156, 39.13029047750658, 30.939200924288844, 17.24769715339907, 2.6969204843044285, 0.27044298007122936, 0.2688307633563396, 4.258810002957621, 8.584213026108282, 8.872589603547128, 5.559834693708728, 3.9288477215074726, 11.853646828282265, 26.79935689895384, 44.497967766177275, 51.194202823023645, 57.89250496895083, 53.8984848606971, 55.97994942818919, 53.02282748683807, 52.68147145548175, 52.78517892283779, 55.715573833834746, 55.89773262700727, 56.972481666072724, 56.289106722800966, 51.001065315738806, 51.24944156216037, 51.81165056843912, 52.32821103065245, 54.53989828786543, 54.03651698943108, 50.99369125981485, 49.68287829429873, 52.175477858512636, 53.00133682066395, 53.52252175731044, 51.749316261660674, 54.73303971752044, 53.48079558341734, 53.91499411675238, 52.63870977586316, 52.7011303747854, 51.753058202805065, 44.03234712539181, 39.474109757331114, 41.038080338508856, 38.428754960336995, 39.76918574302427, 40.465900667252086, 42.325767009489, 41.145619961523245, 46.40778549255864, 49.226812547253026, 53.127056629427024, 51.831376168035696, 51.19502259838966, 41.03174178831039, 41.44672463017125, 52.53513566909298, 51.63233941601169, 52.829737047995295, 50.20869162774856, 52.06582800034554, 48.44255816551947, 42.98064985582906, 37.077631796559984, 38.61034108746437, 39.14981995859454, 38.587767847122684, 39.51870318382017, 50.695865692630896, 54.17630241763208, 52.880829841859885, 53.18065974020189, 52.50958142742034, 53.80426168441773, 51.64023514716856, 52.85525598833638, 51.78378212836481, 50.84582574905888, 49.76002739321802, 53.146578265774636, 52.874663875949004, 52.637850776795425, 43.649708147971864, 36.886816332417155, 39.38550733750866, 47.75873999441824, 54.653376379320704, 53.8020690794914, 53.51339440191946, 52.73583158369988, 52.468765243407226, 49.061257147019916, 48.61843724404612, 49.819459146068944, 51.64021161294753, 54.24895255796371, 51.53013029406148, 46.46850378282609, 34.9793206491778, 18.53478370174285, 5.284178853034973, 4.038650061815016, 5.333456570102323, 8.576547734199032, 3.521188925350866, 0.634320617443131, 0.21581193251955896, 0.24786702777829864, 0.25219372383529143, 0.21593894989740467, 1.565465739657802, 10.600612336589444, 22.181011169187485, 31.705504578928796, 38.181139653728856, 44.56583653726886, 27.872099645676155, 7.055567310702417, 0.184746255136786, 0.15359483719352754, 0.02228492889703522, 0.0679306173697114, 0.021370721703034737, 0.03172953087355822, 0.03397463580533382, 0.01218953331361615, 0.05087291130856161, 0.032082369904063886, 0.02970369179703055, 0.04042722202176529, 0.019856623614267, 0.00845457601826638, 0.024220304481024225, 0.02042569287662064, 0.04460129038160367, 0.026682198888832526, 0.0371830043713412, 0.07450423398686033, 0.057665249858532226, 0.004184709799911587, 0.029335483127544006, 0.22625988559617152, 0.21702855675210878, 0.3537814871918771, 0.17050425161517438, 0.19301036733292765, 0.1696365651103758, 0.1123059769311259, 0.15028354471489308, 0.183808762700327, 0.12100602379970013, 0.10401836881834654, 0.10781957452455837, 0.1808651464600717, 0.15888599198191397, 0.10740317509419496, 0.18903567335538327, 0.07195257897218389, 0.1507063946055789, 0.06865909803778895, 0.14644052592977402, 0.12392084279488172, 0.12487941031013766, 0.09772663425293662, 0.09437677690819388, 0.10936698020105401, 0.1954005923001997, 0.2191365396063174, 0.2734961162411398, 4.198947279684005, 26.435307994965587, 56.47613709972751, 58.84499372974519, 46.93394007221345, 48.36744477671962, 35.54117664214104, 21.12669179516454, 2.9507181817485444, 1.099035497153959, 0.558843061087593, 12.268825788651744, 16.272895009286945, 16.424085709356493, 16.65247355737994, 7.494557019202941, 13.933765042212702, 28.23477375891901, 47.60373184757848, 52.18799021936233, 58.19172297754596, 56.20350883853052, 58.32247126486994, 56.65095713830764, 54.88320373719739, 54.957634633587254, 60.18640118260538, 56.80820103614562, 60.15253151616743, 58.17424881842829, 52.332470724659586, 52.3255124399739, 53.2421781939845, 55.666924676587506, 57.4481043507976, 55.523620882341945, 54.70769336146694, 51.05761412651309, 52.96449399763539, 52.67971031127438, 56.33108392838509, 54.502996629284276, 57.9943375433645, 55.40866013496153, 56.795873026694025, 55.19289839652277, 56.17853118527321, 54.400308978173044, 45.97570896148682, 42.303786047043346, 42.83980538768154, 40.84563316837434, 41.366261128456365, 41.27392461222988, 43.330674325266195, 43.25607084458874, 48.027869501421534, 50.76732735480032, 54.29568367619669, 54.95701097672986, 53.76609702264109, 43.148684194011075, 44.17053222656251, 53.55246120883573, 53.284300527264996, 54.2756050632846, 50.937103225338845, 54.92790699005128, 49.365691907944225, 44.759495719786614, 37.93113954605595, 40.19262129260648, 40.93038774305775, 39.6827406267966, 41.92819164645287, 53.92367432194372, 56.52004018906624, 55.06240506325999, 56.10408067703248, 53.51953683360931, 55.97523473924207, 54.62854385375977, 55.64814044583229, 53.123914810919, 51.65691698751142, 50.19171953201295, 54.04995110727126, 55.73740966858403, 54.22572035943308, 47.50682184773107, 39.10628949442218, 41.55828468261227, 49.8285904238301, 56.631478648031916, 56.05837329741448, 54.89160937647666, 53.83966891996322, 55.171035105182284, 52.337785536243075, 50.50861174060453, 51.803848974166385, 52.452985548204, 55.61423155569262, 51.695599402150805, 47.130188019044944, 33.63426539205736, 19.258019731890773, 5.587846300294323, 4.44193369919254, 9.475120575197282, 19.5160783490827, 16.653383547259917, 10.2989810897458, 2.451994207597548, 1.2424752260408094, 1.3348865124487108, 0.6243785735099547, 2.4451298146478595, 14.494879707213371, 29.362580699305383, 40.163078000468595, 45.07186151319935, 49.096381971913004, 30.675364655833093, 7.361674472208946, 0.3116673970174405, 0.24212555118626167, 0.11013122951431621, 0.23134537642040562, 0.19378610796505408, 0.1831226696770999, 0.15512702836384698, 0.1480116343666469, 0.15923898997566394, 0.11694159794358477, 0.21994067145691765, 0.11987105687899936, 0.15770466908091502, 0.13826158738905384, 0.13877837498101497, 0.15786721761668884, 0.1467608272909157, 0.08976950880981262, 0.13262091264609369, 0.09917898373978754, 0.1531123396970572, 0.103607423934004, 0.1388836354618111], [0.027117945869723638, 0.026458248405927615, 0.07521925449010826, 0.06118127167405141, 0.034828199479248256, 0.02081726531257793, 0.029904161685056267, 0.03735115684028115, 0.018641851399274125, 0.0569745181729236, 0.02338516522168873, 0.027348111240914273, 0.014703181748759123, 0.035601346903750976, 0.01339462983812536, 0.007900887407407525, 0.027874061244449792, 0.05072567687039414, 0.03711299542638083, 0.018577042276099808, 0.0879632956498573, 0.04183888457895767, 0.05614482579872974, 0.027601851052754832, 0.029208776015307636, 0.03019050045329477, 0.055796416671646226, 0.019465564457218976, 0.27021490037441254, 10.046683453744459, 37.74164592066119, 44.97402975636144, 42.016311614744126, 23.61578279925931, 31.00459860217187, 16.83951177904683, 5.345623762376848, 0.4559719165967357, 0.250055174072904, 2.252374493306683, 13.708598440693272, 31.35873175436451, 43.74942264249248, 36.69881320768787, 10.514901684176538, 12.175504757512002, 25.731495541910974, 39.452552410864065, 52.9903777184025, 56.530909076813735, 54.9675896090846, 53.78537154966786, 55.53366999472342, 55.30130878571541, 54.87998739365609, 51.381660738298976, 53.266845979998195, 50.815211649863954, 48.328468184317316, 44.11408931978288, 45.369565486907966, 46.40786001759191, 44.567378028746575, 43.28256253273257, 40.59701765737226, 40.63953615004017, 43.60016469032534, 45.492370974633005, 46.589728555371686, 48.14511306824223, 48.02911681513633, 48.877737291397594, 51.565294342656294, 52.45635878655219, 55.001937804683564, 47.972768045240834, 46.96638591827885, 39.78559301745507, 41.03482084889566, 38.18070427063973, 36.20223722150249, 37.36413740342663, 40.27533623480028, 39.435760744156376, 46.716166157876295, 47.24481928733088, 52.326273379787324, 49.42686911552183, 51.64827600602181, 43.13754858509187, 37.743548270194765, 53.86077911623063, 50.884629757173606, 49.9397974629556, 47.64853315968668, 44.39361310774281, 40.36422498764531, 38.75970494362616, 36.40997771293887, 36.3127774576987, 35.24943859346452, 36.13185028876028, 43.44683139554916, 50.99961403877505, 52.89728026236258, 53.079901895215436, 50.26875488219723, 53.75851900346818, 51.35769113417595, 50.30553102493287, 52.02197197944888, 52.546914546720444, 52.73916559834635, 50.639964072935044, 49.836733264307824, 51.22027481755903, 46.32767500415925, 38.74802804762317, 36.27223583959764, 37.182833686951675, 44.12182815613286, 52.56573407880722, 51.47551913415232, 51.035601785106046, 52.1894807200278, 53.21962456549368, 49.83419941317651, 50.76006312524119, 50.908183590058364, 51.28642166814497, 52.742115220715924, 48.69582952991609, 32.912372773693455, 17.939971954591815, 5.606831552520876, 2.5741728515394273, 7.101989051988048, 9.838968457714204, 7.037033621341952, 3.235191265421529, 0.5683408965987544, 0.03139255943918421, 0.06500363289829224, 0.1309988133969807, 0.5448848165331349, 4.051933168403564, 13.963872175062857, 26.77973328098174, 38.0251116906443, 42.52941254646548, 36.13235627451251, 13.28958438288781, 1.62225982114192, 0.1334668269320842, 0.03365337300384718, 0.04203333684633817, 0.06541072436037564, 0.01870326866816369, 0.05472638719384709, 0.03659331585250555, 0.023643166397608096, 0.010039961461218135, 0.05362795883669488, 0.044788143056775295, 0.023601395453536705, 0.044506912179771936, 0.011119030776523776, 0.0049618629066483875, 0.09072105895968215, 0.02974925487632713, 0.01839604442788949, 0.060812580369172566, 0.008873888497961866, 0.02994339496287848, 0.053339473107048584, 0.08775586968347912, 0.026757011205078136, 0.03288369595764145, 0.025935569597828775, 0.03155384584510278, 0.047027130776475516, 0.026664582697013696, 0.015219654287061384, 0.05698097629412528, 0.06978952971797797, 0.13945556606256193, 0.033956196068996386, 0.015644089979750496, 0.09377510677422247, 0.03580468962149274, 0.01592455572643948, 0.026996203007236607, 0.04665343691745112, 0.052760712832452795, 0.04050953433878961, 0.0234328024840403, 0.04251461243256927, 0.01668080612416229, 0.034634731634850466, 0.028855220692592765, 0.005749071396196322, 0.03755794695368217, 0.04682862590397558, 0.024513712325584025, 0.7637290476310639, 13.159958874025653, 43.58886826422907, 50.3403655944332, 46.54925361756356, 29.577359884015976, 30.554885133620235, 20.01854769645199, 4.757397674745129, 0.39763349378781937, 0.19138563274135514, 2.0874513301157185, 12.90982638635943, 27.178877592086796, 38.90115737915039, 27.779757245894405, 11.683112959707938, 15.801468280053909, 31.687751931528894, 43.86604647482596, 54.43109958402572, 57.84762913180936, 56.14870156011274, 57.30040357958887, 57.28676549849972, 57.282062576663115, 56.54215451209777, 52.86927453933224, 56.44596622836206, 54.782379211918006, 51.18791526363742, 47.50301714866392, 47.25201683659708, 48.247479084999334, 45.960537233660304, 46.30072439870527, 43.201153739806145, 45.03852921147501, 46.054901615265884, 49.16641981370988, 49.295842339915616, 50.84785753680814, 51.481018297133915, 50.43234517497402, 53.182338514635646, 55.92178460090391, 54.77076507383778, 51.11861874980312, 49.7731634109251, 41.06661558151245, 41.65006029990412, 39.63815896741806, 38.64831355310256, 40.02923104070848, 41.195383071899414, 41.76244405008132, 49.190534545529275, 50.656163461746715, 53.75452210826259, 51.598167727070475, 52.768908931363015, 44.96277647633707, 39.92510387974401, 53.880351743390484, 53.09575611545194, 50.53091825977449, 50.368226189767164, 48.029724782513036, 42.60607134911322, 40.02336709730087, 36.744104816067605, 38.53340771890456, 36.47063324528356, 37.86835808907786, 44.85750790565245, 54.3092550769929, 53.377860822985255, 55.551057861697295, 52.007196411009765, 54.4171045672509, 52.61855271554763, 51.2488139829328, 51.55448036809122, 53.245645569216826, 53.9768655838505, 51.835835902921616, 52.89444046635782, 53.054798726112615, 49.293987058824115, 40.158147581162, 38.2559431752851, 39.20403888148647, 46.02989650541737, 54.681205595693285, 52.98678874969483, 52.90190865916591, 52.9280787129556, 54.440207327565844, 52.74033838702787, 52.77736556145453, 52.369038981776086, 54.44613010652604, 55.55251306103122, 49.86393882382301, 35.85566443781699, 20.59342399720223, 7.523606582995384, 3.098850658824367, 2.8894385022501794, 6.7333480331205555, 5.353716592634878, 1.4124668269388139, 0.03449566752439545, 0.07640485216172473, 0.06986453738664428, 0.05465545128249834, 0.6256445184830697, 4.5157728079826605, 16.182670689398243, 29.683099139121275, 42.6658365034288, 45.265987457767615, 40.61924965150895, 16.549746682566983, 2.9172520291420723, 0.014713564155352934, 0.0472901096086829, 0.047974494255838857, 0.01706666928986388, 0.023806528901801478, 0.04485004679149678, 0.05674870992680231, 0.058060110726904486, 0.029625135226055022, 0.032341554685826265, 0.061047731057530454, 0.0196819823806084, 0.02433615804259335, 0.019517352000900337, 0.028843170129543835, 0.08876220278081395, 0.023118072497327963, 0.059668837911299163, 0.015380365169426848, 0.05535010533827928, 0.06930868697142409, 0.029249058833586115, 0.032694169635614084, 0.11459902364520297, 0.09466839593745048, 0.16965325050536664, 0.17395529385295608, 0.14658482625119149, 0.15666111943221864, 0.11834755314574127, 0.1446207147091627, 0.19204033148144523, 0.2076292707915268, 0.07188336292822516, 0.10616834861256423, 0.19023438645226343, 0.13750872214234647, 0.10730346875084985, 0.08034223765735665, 0.08894840811168955, 0.17868041691760864, 0.07862003369917793, 0.07380825076853076, 0.17498182102797494, 0.12235974712717919, 0.14494556663257463, 0.1150016105102916, 0.1902462148498143, 0.14463104157438203, 0.16118284615297473, 0.13463137250754142, 0.8774535742498214, 15.365182065194654, 48.90942612001973, 58.562084936326556, 55.337618166400546, 33.13979964102469, 43.86349301184378, 22.48559498017834, 7.254784001458076, 0.7988641074588223, 0.7181803401439422, 5.200847608427848, 25.75805194916264, 37.868738558984575, 47.26117557094943, 39.946822043388124, 13.676357538469377, 17.44509239350596, 31.206847775367002, 47.24718839891496, 55.34673767705118, 60.42946653981363, 58.95920530442269, 58.577601832728234, 60.081870017513154, 59.99453844562654, 56.9694967423716, 55.07904767990113, 56.08635548622378, 57.04816379854756, 52.23651778313422, 50.539857341397195, 48.93624728725803, 50.48955294393724, 46.60517877148044, 46.78716105799521, 42.571797678547526, 45.3605205012906, 47.19856669825893, 49.82568002516224, 51.4020884421564, 52.57270413060343, 52.72380559675155, 52.67641159795946, 55.1915059551116, 55.812687796931115, 57.68493706180204, 52.96592958511845, 52.114469312852435, 43.48077166465021, 43.05470028231221, 42.20323216530585, 39.949653994652536, 40.988658474337676, 43.08980549535444, 42.63719143406038, 51.27325819384668, 52.73549818223523, 55.781912880559126, 54.508719367365686, 52.80592826104934, 47.13287876498315, 44.078709540828584, 56.564037415289114, 54.37274648297218, 52.753254752005304, 52.25121882654006, 48.26003851429109, 44.69494135149064, 42.18593451284593, 38.660535658559496, 40.49945262170608, 39.19626474380493, 40.183082088347405, 46.102197554803666, 56.1887332700914, 55.81332322089903, 55.91192376229071, 53.35036893044749, 57.23333104964226, 52.72034998862974, 51.91248686082902, 52.794490629626864, 53.42107357517366, 54.86976569698703, 54.29778606660905, 55.23905292634041, 54.92909939058366, 51.72382477791079, 42.442583037960915, 39.314120200372514, 39.31699137533865, 47.480777309786895, 56.55685947787378, 56.08338232963316, 55.45759954760152, 54.18630446157148, 56.32589463264712, 53.984055288376354, 54.46895045618857, 54.60024395296651, 54.56802560437111, 55.37998368663173, 49.82850805405648, 35.008459937187936, 21.29153136284121, 7.822691231004654, 4.509464165856762, 9.120170589416258, 17.63416828647737, 14.972254710812724, 10.45819107563265, 1.5725554237442634, 0.20747789181768897, 0.2902899279950127, 0.466758220065986, 1.204466601052592, 5.413935761297903, 18.693657344387425, 36.415908336639404, 51.43777416598413, 54.7920007859507, 47.85307691943261, 20.426311416010705, 3.2279370869359667, 0.26674482851259174, 0.18199391572946505, 0.10865598165940855, 0.16120264186493813, 0.07904949492865032, 0.1177718380706445, 0.11159918421218473, 0.10987206963041138, 0.133981837200061, 0.1041050210234619, 0.10876127278372165, 0.16447097213277895, 0.09644720613235429, 0.08547478160190006, 0.1818724907934666, 0.18339708237157715, 0.12234410361176538, 0.14998605745213647, 0.15798088974289357, 0.10726967661250984, 0.13339031007020705, 0.12262800047474524, 0.1908496163424946], [0.050704490708848166, 0.036654848034583756, 0.04051915640311857, 0.01853375256271853, 0.05155627705877827, 0.028172052210016597, 0.04094121339280279, 0.02101304865772686, 0.02530419057415378, 0.049917051914117994, 0.045983435571073525, 0.029934521749495503, 0.1157548894444781, 0.04117428798288588, 0.06653184807228466, 0.06749493550629386, 0.026867626640464992, 0.0747321145008168, 0.02776542423112739, 0.027752331788501436, 0.058111174317497405, 0.002730562400463368, 0.06784191204895897, 0.03619985692503472, 0.009048710719892576, 0.03305724551600795, 0.018127883010874354, 0.07295846773852264, 0.061801550083703576, 3.703679158802956, 22.225792869444817, 49.91302728652955, 38.52467260053081, 41.74597009535759, 38.65811947853335, 20.48371138111238, 9.486128707085888, 0.6748055450377927, 0.29708696649439875, 0.5829710921933574, 4.453474292832037, 13.427252711788302, 38.434089383771344, 30.29415734352604, 9.041451561835505, 3.2839026902952506, 12.17037037495644, 31.216049655791256, 46.08828883017264, 55.876100755506954, 57.30283937146587, 55.90813083033408, 54.57182638106808, 54.081357525240996, 52.84898411843085, 54.341900963937086, 54.53736051436394, 50.99494641826999, 46.892143295657256, 40.782530077042125, 39.44307596452775, 38.864279254790276, 39.279956356171645, 38.44969649468699, 40.340965332523474, 37.26758433926491, 39.395627052553245, 39.40870031233757, 40.355176079657774, 41.38010709516464, 41.72879011400285, 45.025181385778616, 47.72041843783471, 51.106326041683076, 53.09750157017862, 49.371967700219926, 47.09966413436398, 40.713504206749704, 36.50495006192115, 36.39806155235537, 37.84221549187937, 37.87522223687942, 38.81850519487935, 42.80815578276112, 48.42804931825208, 49.72419261932374, 51.68930792039441, 51.47188701937276, 49.24312176242952, 42.39259635248492, 39.32014103858702, 52.94559209577499, 49.43298409062047, 49.743596584566184, 44.643836790515536, 40.73212762032786, 38.225744847328436, 38.290012882601836, 36.36820839297387, 36.99917654837332, 37.34446671701247, 38.47026932624079, 47.858701598259714, 54.483667189075106, 51.67269276034448, 48.86748813813733, 49.50595194293607, 52.166707438807336, 52.58840145603303, 51.34155450328704, 50.47553831531156, 51.35694588384321, 52.61659545283164, 53.219499049648164, 49.847551161243075, 48.54253938121181, 44.182985751859604, 37.25851974179668, 36.174725717113866, 37.079306648623565, 39.85010816204933, 49.43619258942143, 50.98408929763302, 53.97898758611372, 50.75015914055609, 53.818484198662546, 53.81513841690556, 54.80030444360549, 52.98203483704598, 54.00072928397886, 49.504810533215924, 38.94191472761093, 24.422985007686002, 10.030841981211017, 11.7166619723843, 19.526433406337617, 27.63468054033095, 22.753377153027444, 8.11690184377855, 4.295204204897727, 2.1915537311184794, 0.794011338824226, 0.1218224743441228, 0.31561455779498626, 3.0601042605215505, 6.412893822116237, 15.232018578437069, 21.155691839033558, 34.324861418816354, 41.2331437295483, 24.52094228036942, 6.668812786379169, 0.2647282705912667, 0.020271871997524175, 0.03231636954531555, 0.02689872214931154, 0.011922148518234253, 0.05268342605221176, 0.06517906703295247, 0.038554290264484384, 0.01944271588487731, 0.025907220514190775, 0.035070333059035966, 0.09095017287519672, 0.05309837374595865, 0.04067726545937119, 0.04689572754526331, 0.06078440365531753, 0.045839640867686084, 0.04026344774531261, 0.07024958083826689, 0.03521789691501087, 0.07353314859492165, 0.016529653146262133, 0.0591672380124369, 0.06632666674352462, 0.018543736603591713, 0.04020330601281697, 0.01862336952810086, 0.030605714362595352, 0.06036945979201025, 0.03436195070765192, 0.022302290364619226, 0.03680769023635695, 0.01821631637041367, 0.09742589877738107, 0.043033705949182474, 0.04132877344325666, 0.003425859251893276, 0.021715191222967643, 0.015334210287208761, 0.10558103496629385, 0.05233700109285213, 0.0466454504508405, 0.03232127250803094, 0.03384581045998681, 0.05205440657934354, 0.023458271077083006, 0.03058043920675353, 0.05931881999957466, 0.012789516138934321, 0.019522118983009172, 0.0388905645588473, 0.045784490198017135, 0.0622252005362703, 5.733192178510851, 28.002302723546183, 55.82798111823298, 43.14475790146859, 35.54622865492298, 40.4702623428837, 22.450387785511634, 11.093327729932724, 1.018334814617711, 0.3239099110566801, 0.5355274509037695, 4.766642210945006, 18.354460577810965, 51.386355815395234, 36.99687803945234, 10.922062339321261, 6.039945060206998, 14.744491500239219, 36.5197060185094, 50.102920993681884, 58.44542580266153, 58.585423038851836, 57.26401575150029, 56.66614063324467, 55.879077834467736, 52.425426975373306, 56.616538340045565, 56.04440573723086, 52.56248243393437, 48.64219504017984, 44.07937242138771, 42.3804997628735, 40.52810161344467, 40.943041309233635, 40.49741691158664, 40.75976071819183, 39.34579726188414, 42.57663396096999, 41.37321941314205, 43.41968074921639, 44.333239986050515, 45.42769893523186, 47.66915305968254, 51.805849382954264, 53.00655357299313, 55.28541141940702, 51.66360462865522, 49.45753812789918, 42.23499551896126, 39.11542077218333, 37.74780404183173, 39.17386801012101, 39.441408957204516, 40.44399815220987, 45.29795869704216, 49.86868096936134, 51.17082157442647, 53.24764990037488, 54.07545435813166, 50.840310896596606, 43.29421981688469, 42.25530162934334, 55.61747927819529, 53.77746797377064, 51.52840052881549, 46.64017415815785, 43.10889959335328, 40.118398281835745, 38.89933739939044, 37.70620730615432, 36.99756053186233, 39.11140818749705, 39.49957378448979, 49.116095804399066, 55.78823966364707, 53.94603575429609, 49.94116244777557, 48.95412545050345, 53.56618165969849, 52.65041412845735, 53.047008898950395, 52.20564088513775, 52.41825688269831, 53.56447542867353, 53.904062471082135, 51.79593363115865, 51.71551719788582, 45.85805354579803, 39.65628816235451, 37.004895364084554, 39.379478654553814, 42.6628751139487, 51.1611686214324, 52.1271268013985, 54.225822341057565, 51.71664684049545, 55.425800892614554, 53.93285659051711, 55.8697465158278, 54.81094975625315, 55.57297606622019, 50.6020700547003, 41.12505497470979, 27.29481500964011, 13.155781549792136, 10.854380861405405, 18.97796054040232, 28.170360595949237, 24.099156087444676, 8.313152732387666, 3.5461700106820757, 2.466598172341624, 0.83588233397853, 0.13218913017021072, 0.3217067034734834, 4.085548371076584, 8.717410833604875, 19.14155475554928, 26.181216855202955, 42.54563939186835, 47.94016922673872, 31.731539310947543, 9.081283230935375, 0.3352594117243444, 0.0419576013941438, 0.04002142524827392, 0.023530614674992623, 0.015126111121067118, 0.062228674745006915, 0.02533308932587745, 0.04678271808511308, 0.08287600451900114, 0.02881944247130906, 0.0231050317656369, 0.06902094434706435, 0.05137128980770227, 0.04809747051988398, 0.0629566612863733, 0.056517481608616735, 0.02473901303845548, 0.04811761480185294, 0.028407624246732845, 0.05064645954858392, 0.01931018267397679, 0.025805143128720023, 0.04892225993136245, 0.013414193808491673, 0.11425028510031202, 0.11704285178453692, 0.1290801921558957, 0.11356740964636688, 0.2049665177060712, 0.08844268282935505, 0.11592489967663443, 0.092271437057324, 0.10764548104376563, 0.22321643277762399, 0.087403308359846, 0.13840988668943607, 0.19921661414686712, 0.0816404962191178, 0.08376384679708751, 0.1780874035771816, 0.18602150041730176, 0.14413112323851357, 0.1294587008775242, 0.14148795136040257, 0.10489188525224886, 0.06682162082964374, 0.1712197011276599, 0.1274950106838538, 0.09793170066850801, 0.10205485482489872, 0.149518100304469, 0.16864311761192738, 0.18229955416773597, 6.045609943328365, 31.012625732729514, 61.980665883710316, 51.06372910161173, 53.07749748229981, 52.66012199463383, 28.527898365451446, 12.274386728963545, 1.3679428999462437, 0.7861529927580588, 1.109543281697458, 8.35508777249244, 18.369428342388524, 46.13417271644839, 35.3530676134171, 12.656682498993414, 4.994448077294135, 13.68762944975207, 36.658440251504224, 48.94089137354205, 60.09692407423451, 59.3904895167197, 57.7840357442056, 57.01912256979174, 56.60856808385542, 53.27517317187402, 59.069086582429954, 59.044964005870206, 56.886899471282966, 50.45418493209347, 45.62780649431291, 45.345521357751664, 42.52501556950231, 43.25052853553526, 42.44910986192765, 43.69915354636408, 40.26251792907715, 43.663914972735995, 44.2694426351978, 43.77619281891854, 47.21092216430172, 45.858163372162856, 49.23666161875571, 52.941822698039395, 54.5188194705594, 55.516505702849365, 53.34719965534826, 51.03438192798246, 43.717094467532256, 41.008952817609234, 39.48725754214872, 40.67621031115132, 40.956024354504, 42.03670793964017, 46.04043199170021, 52.28428048472251, 53.38272063962875, 55.37849318596625, 55.71811160733623, 50.457381663783906, 46.01516800542032, 45.84543528095369, 55.67670314542709, 56.05884790420533, 53.24879131009502, 49.737948371518044, 44.81457364174628, 42.22344806117397, 40.727797323657626, 39.854258029691636, 38.976486498309725, 40.43660448443505, 41.88783045737974, 52.4029282600649, 57.91022231501918, 52.6001371875886, 48.77743051898096, 48.98673211374591, 52.26748097327448, 54.57624689225228, 54.172909567433024, 52.761060268648215, 54.501533585210005, 55.84856963926747, 56.47630576164492, 53.87812383713261, 52.5518371212867, 47.913250000246116, 41.07214220108525, 38.39733285288657, 40.374144661811094, 44.39318164702385, 53.88367791329661, 53.706418160469305, 57.586889574604655, 51.82243708641299, 55.48545622056531, 55.348463519927, 56.044468495153616, 56.115357491277884, 56.11211761351555, 51.38935250620688, 41.97016492966683, 28.617224462570686, 14.236657331066748, 15.403040782097849, 24.732046204228556, 34.244437140803186, 33.56981300538586, 13.337565756613209, 6.320573485666706, 3.4182960852499935, 1.1203420570781155, 0.4453869716775033, 0.4317701571891385, 10.713973737532093, 10.52210609759054, 22.740017560220537, 31.155892264458444, 47.17499717589348, 54.28127681055377, 35.60158114279471, 9.42363162194529, 0.4480555929964589, 0.12158252794535891, 0.1501205058828477, 0.09737244882290402, 0.12200124096125366, 0.12343629218277433, 0.1322414233319221, 0.17126296977362326, 0.19783949449418053, 0.11304843870382156, 0.11105100233708659, 0.19457430518682928, 0.16562604886149207, 0.15335892807812462, 0.16266386264995222, 0.1444854235817348, 0.17629331758906766, 0.11755167972296478, 0.08932730753815944, 0.19729282947317248, 0.1512670943573598, 0.11628908255407888, 0.13621518268219887, 0.17739964048227957], [0.031012899670449477, 0.010847285983242817, 0.03252040174218916, 0.03447217160775777, 0.03144547887777369, 0.07692127969236144, 0.012071109527061063, 0.030292897680473906, 0.053119050459034985, 0.01315926081470905, 0.03785473707642767, 0.0689718610937557, 0.10912259815320854, 0.07385016343886815, 0.06948624316963457, 0.07510005120909022, 0.023594276581500328, 0.028224021699579976, 0.06726867143785761, 0.0360740001703943, 0.0339587586331031, 0.026682545543618263, 0.022616503241982673, 0.03933827017223643, 0.015299868480783078, 0.1210193154251864, 0.017906031608881972, 0.02300612981461229, 0.016678299101430084, 0.3605047667459134, 9.38963447847674, 32.51868840186827, 52.995876881384085, 41.738513669660016, 22.377472885193367, 20.078907089848673, 12.653862314839518, 2.513920342729938, 0.47519223524197457, 0.5295432623355619, 0.9691281292227008, 0.3249998090247954, 3.0483131254872973, 0.8901241782211489, 8.302897695572145, 3.818630590554207, 3.8524772130673934, 19.290010583016183, 39.13220851652084, 54.23352979844617, 54.6527252658721, 55.8142057541878, 53.93686917520339, 54.52882543686898, 56.77504131870886, 54.52696231103713, 51.61466521601523, 46.73669192098802, 41.52487001111431, 37.78381140001359, 40.19946582855717, 44.693866622063425, 48.146423139879786, 48.424903577373875, 49.40081673283731, 45.66879918498378, 42.2607772581039, 40.89187791270595, 39.30166667507541, 39.05199996886715, 41.17648901477937, 44.28152353532853, 48.969140283523075, 51.33008157053302, 52.25676505796371, 50.0730796014109, 46.80026569674092, 41.20573028441399, 38.883871493800996, 38.30228990124118, 38.13871529794509, 39.66938495635986, 44.85416996863581, 45.35752381047895, 50.159885575694425, 48.17764912882159, 53.92237993978686, 48.63955528505387, 56.957235413212935, 43.29806766202373, 35.96179592993952, 54.41106019481536, 47.69992405368436, 52.43505247177617, 45.25807603713005, 43.633124366883315, 36.78858841619184, 37.71675848191784, 35.92428238161149, 36.94995472508092, 35.502376556396484, 40.14951444441273, 50.45893884474232, 52.731379693554295, 49.91550622447845, 50.49584442569364, 51.489471004855254, 52.04414906040315, 50.1109383183141, 49.91305866549092, 48.99812659909649, 48.76260003735943, 49.908524405571725, 48.61288709025229, 47.0643392685921, 42.55831649226528, 40.41577669882005, 36.49925478043095, 36.23768368074971, 38.912249841997706, 40.008218903695386, 45.22638720850791, 49.42720643935665, 50.791198899669034, 50.95008234823904, 51.815745522899014, 52.66304808278238, 53.70364896712765, 55.439078115647845, 51.96379538505308, 47.14488514008061, 29.580048668769102, 14.279238581657411, 4.211775881628837, 8.768815455898162, 3.8319315929566664, 3.249119111607152, 4.771256389156465, 1.906464590180305, 1.7571794265700926, 0.5086965696705926, 0.17413809775344788, 0.05917531640959844, 0.1775208815571762, 3.028281581017279, 12.647530628788857, 22.175504161465554, 26.152226617259366, 36.18436690299742, 33.82003276578842, 14.974676774394128, 1.9438118054982156, 0.06413159118364416, 0.02542334022901712, 0.03926656051208416, 0.008641961124545385, 0.10153615967400613, 0.07207549011875546, 0.06818112046007188, 0.027674719420892578, 0.0262569913625597, 0.060398804789949814, 0.00999811678118403, 0.03928521858348001, 0.008529067535193698, 0.03323673991666686, 0.053262255274720734, 0.027117610706256765, 0.03692900792004601, 0.08456780244746516, 0.05973451079860811, 0.016945179236391862, 0.023188081442288334, 0.05025431446190323, 0.030678502291501052, 0.023751590821531512, 0.03303023708623744, 0.03471646555549195, 0.007777575501090577, 0.02945862793093247, 0.052302105787901156, 0.017031726104417638, 0.06507023658242918, 0.04877532809792508, 0.10570286592889218, 0.034159159573215636, 0.03748400414723062, 0.04060799195881813, 0.08664132666683967, 0.03644221267032047, 0.036133440932439226, 0.018101744090897903, 0.006401776392463475, 0.020743404860578237, 0.009765475030778157, 0.003033836978682948, 0.029996517414767897, 0.009052524880145588, 0.047875036891069145, 0.030260787105127692, 0.04144085210657889, 0.06370114170074945, 0.0260364250730603, 0.043744064807411165, 0.015958254976618676, 1.1303452041841324, 12.858180538300546, 40.38003998418009, 55.27355409437611, 48.700202972658225, 30.702123065148633, 23.306384278881936, 15.998246727451203, 2.6982839982355795, 0.1917530178663231, 0.33444916649210843, 1.300678419009332, 2.4513386814825, 8.024422651337039, 3.546424964743276, 7.178948406250247, 5.5173441479283, 7.148254879059331, 21.986314519759148, 40.25492422042355, 55.62460230242822, 57.25213489224834, 55.84629074219735, 54.77864903788413, 55.08858296179003, 58.563375396113244, 55.07348183662661, 53.48865209087249, 50.11269554015129, 44.4235094131962, 40.81658801724834, 42.41682483303932, 45.68298247552688, 48.94273488752304, 48.44033418163177, 50.4556832774993, 48.053757144558816, 44.44866357311126, 42.75987925068025, 41.685083143172726, 41.88231952728764, 43.96039124458067, 45.524244154653246, 50.74507967118294, 52.76083277117822, 55.08739056125764, 52.78218223202614, 50.849689283678615, 43.5024937506645, 39.70501184463501, 38.97597266781715, 39.08592847085769, 41.109679283634314, 46.8406347305544, 46.6949696694651, 52.14859001098141, 49.92114267041607, 54.8674044301433, 52.598211303834, 53.74268439508254, 45.32652531900714, 41.15094261784708, 56.74893402284192, 50.80351906438028, 52.33949176726803, 46.162919767441295, 44.53454779040429, 38.85106478967975, 40.16901646890948, 37.610976080740656, 40.020629282920595, 37.15704802543887, 42.35244697140109, 50.82561377556094, 53.7163221451544, 50.806296102462284, 49.86827304286342, 52.32770504490022, 52.708935891428304, 52.197815756643976, 52.45776691744405, 52.05683008317025, 51.21690550158101, 50.610864008626635, 50.34758667792044, 50.68613821460355, 45.94670695643271, 41.415412349085656, 38.60350047388385, 37.95967478905955, 40.60723150930097, 42.10790288063788, 47.698355105615434, 50.857247691000666, 53.77192174234698, 51.38912893110707, 52.11800336837769, 54.05857247691001, 56.74947138755553, 56.4086409538023, 54.654749208881015, 47.969053560687655, 32.91359655318722, 16.07705302776829, 6.531190055031931, 12.712076171751946, 9.497371200592289, 7.5940297976616895, 6.668199916039744, 2.3201716811426225, 2.5950754073358353, 0.8664999265343913, 0.12525518409787648, 0.1357762755886201, 0.4139266211178995, 4.358584313623367, 14.352195647455032, 25.180045597014892, 30.824924630503503, 39.69601000508955, 40.670605244175086, 19.201376784232355, 3.2256326944597307, 0.10452474527541669, 0.035132110389249946, 0.04385430869015475, 0.02121462745802297, 0.03451435623930828, 0.037167448956038684, 0.0426145562631709, 0.014764133619234688, 0.04059538981246372, 0.04292258106532597, 0.041620070715585065, 0.0870841101653153, 0.042976747312012224, 0.056266013247471665, 0.01424486964805833, 0.020693000105600205, 0.029680967713976582, 0.043099727406496965, 0.02308454657454164, 0.02622530213557184, 0.017295170335039016, 0.06772431755258192, 0.10658651004515349, 0.05517247636171599, 0.15232634880850393, 0.10966198533893594, 0.09227937372821955, 0.12869563133966538, 0.12372348322382859, 0.2258614892320287, 0.12174154481580182, 0.09774832986295225, 0.18269174521969211, 0.16588089567038322, 0.0860496309976424, 0.19776587344465718, 0.16926737201790656, 0.1235249515382513, 0.19373281888904112, 0.14146355912089348, 0.13649105094373226, 0.0848778075869045, 0.2011244029047028, 0.1699700738273321, 0.13501293025910854, 0.1022101102036334, 0.12411024271240159, 0.18943186338630416, 0.15806768750471456, 0.26511024203031297, 0.12779687996953726, 0.19533156777822203, 0.12345354448282912, 1.2381894237572149, 15.497275725487741, 44.741892122453265, 65.27941842232981, 53.40349351206134, 33.81893450214017, 28.85310011525308, 18.26917059959904, 3.875012455448028, 1.021469217394629, 1.4463498539501622, 2.808093692987196, 2.847541705254586, 6.927205295332017, 2.0468517344805504, 10.892505318887773, 7.350316268782462, 5.131309378531672, 22.749370451896425, 41.84847339507073, 56.05170526812154, 56.06200541219404, 55.969715964409616, 54.16550413254769, 55.473579283683534, 59.94176295495803, 57.60526195649178, 54.268399669278054, 50.25543843546222, 45.205461363638605, 42.08539239821896, 43.92498400903518, 49.859118230881236, 52.99863038524505, 51.55217793680007, 54.07667813762542, 50.79457213801723, 45.240331234470496, 45.94997036841608, 43.24329176256734, 44.142777535223196, 44.34416770935059, 49.29278289118121, 53.47406479620165, 55.235412966820505, 56.19905302601477, 55.20726996083414, 52.09549680832894, 45.90082307015696, 41.07242461173765, 41.60363904891476, 40.174664681957616, 43.922638431672134, 49.63748862666469, 48.94766530682964, 54.322128295898445, 51.72138506366361, 56.26320731255316, 53.93227215736143, 53.36010425321518, 48.07797778037287, 44.124381619115034, 57.00962651160456, 52.94921244344404, 56.2874867839198, 49.89348211596089, 47.07355683849704, 42.16612654347574, 40.85873780712005, 39.27308044125957, 41.02035514770016, 39.45610607824018, 42.95060842267929, 53.59452470656365, 54.892703717754735, 51.74152251212828, 50.148793112847116, 52.025529569195164, 54.580922357497684, 54.096996015118016, 54.207422502579234, 54.03976078956358, 52.29465515382829, 52.619168527664684, 52.0937591983426, 51.889121301712535, 46.465358041947894, 42.91762521190029, 39.55280819246846, 39.99504758465675, 42.66676218278947, 43.487663269042976, 49.14130487749654, 53.04396513969668, 55.05410532797537, 52.38409303849744, 50.957123002698346, 55.23990015829764, 56.49599998228012, 57.83013143847066, 54.59642356441867, 51.2561958835971, 34.583792763371626, 18.854696135367117, 7.684827273891819, 12.495427977654243, 8.087191850908342, 6.8671366476243545, 8.659535281119808, 5.57614145740386, 2.500778441467593, 0.9039214217374403, 0.4576726317886384, 0.5465792804475754, 1.5559417345831472, 9.632324268740993, 19.732197023207142, 31.65031094704905, 37.35805772965954, 48.155828983553, 46.11979330739668, 22.795381815202777, 3.17557099365419, 0.16557962393328068, 0.1690457734249292, 0.11707564034769613, 0.0986997421169954, 0.3743594668565258, 0.14694801321433437, 0.15016798801239462, 0.13459383419925167, 0.14266844688644334, 0.16097964899193856, 0.10498524838758093, 0.3051491225919416, 0.15967803496506908, 0.12488620551002604, 0.13129562650236393, 0.11930182290774201, 0.13938739955905946, 0.2125471568996868, 0.1412777521557385, 0.10362746479410319, 0.159374127885507, 0.12001339601533068, 0.18562071385883516, 0.150462502854005], [0.07087470092360051, 0.01749558851212984, 0.03709108914218603, 0.02144936637412156, 0.025505505074116013, 0.0595643243662292, 0.02422018382217615, 0.09971444089446338, 0.01829539005073809, 0.04995653608573541, 0.04836204281497387, 0.020790452235228112, 0.08204274600551975, 0.0271632369878071, 0.10424566710548056, 0.0363575101589724, 0.056586801074445255, 0.03373784951925759, 0.04662778446330659, 0.029190905099253983, 0.03352598790379782, 0.03264321329733057, 0.04286309050756597, 0.03089556372874687, 0.03762864154733477, 0.02983750245954481, 0.043224894682005535, 0.033705474643577496, 0.05029571768377097, 0.1752730570132694, 1.9669356485528333, 17.58558777070815, 42.26313852494763, 38.984119430665054, 33.19507760386313, 22.30701142741788, 18.31247356630141, 8.853683779316565, 0.8899663028217132, 0.14339094440783226, 0.19239515276445499, 0.050521702130114844, 0.433188921381389, 1.2006001246552314, 0.5024459357223203, 3.907053807089406, 1.620185500191104, 5.730265109769761, 27.027646687722978, 45.79581337590372, 53.77461641065536, 56.789346202727295, 54.287631050232925, 57.49148576490341, 56.03714935241207, 54.36478407152238, 49.99106284110777, 43.976241542447, 40.82199696571597, 43.22362107615317, 47.152702423834036, 51.349516914736846, 52.8779233655622, 53.613089284589215, 52.51080128454393, 52.71890263403616, 46.54609218720467, 42.61019376016433, 41.69230814903013, 39.88095760345459, 41.046070206549864, 43.930212528474875, 47.5639158679593, 49.15751995578889, 50.615194305296875, 50.882229266628144, 48.307095189248365, 40.41889890547722, 38.35852884477185, 38.62938419465096, 38.96919873452956, 41.824978397738555, 47.07364313064083, 49.05721710574243, 51.14116453355359, 52.8847090659603, 53.9397442725397, 49.36359343990203, 49.5144203401381, 43.74236629855248, 35.71489449470274, 50.51779008680775, 50.18097616011097, 50.71876841206705, 47.228780715696274, 48.83226133161976, 43.024101872597974, 39.97753420183736, 34.37651511161558, 35.71771075648647, 34.421689048890144, 44.65272880369618, 51.08021874581614, 52.61098254111506, 48.14989051511211, 51.85309040930964, 52.05754003217144, 49.81482682689544, 48.08537144814768, 46.101950445482814, 42.46070831052719, 44.48613789773757, 44.086958285300966, 42.87909576969762, 39.35733687493109, 37.608983516693115, 35.34102201461792, 38.39675626447124, 38.22157144546509, 39.498550045874815, 38.87146503694596, 45.61300346928258, 48.12446571165516, 51.10476101598432, 50.9656031670109, 52.135814851330174, 53.384564153609745, 52.56731087161649, 53.890506759766616, 49.71918767498386, 36.14863411072762, 18.181833144157164, 7.39597559936585, 3.821053144431884, 0.3625179538803716, 2.169657589927797, 2.546539753675461, 0.40435422992994713, 0.05946798114887169, 0.08951738161305267, 0.08596267235735733, 0.10358116243995967, 0.09594881997233438, 0.9790618994062947, 7.062652582122434, 14.003971545926987, 26.96967209539106, 38.10807766452913, 35.20101693368728, 32.28827857202099, 6.580282440108638, 0.7514756857868164, 0.03387352752108728, 0.07037746389546702, 0.0845443448352237, 0.04436368821188808, 0.039925974523348194, 0.045908481528561924, 0.03684056306918783, 0.049367900937795646, 0.04642048490143592, 0.029966883218636917, 0.020881227908595916, 0.016201805819066304, 0.03211912488745105, 0.0795884301225024, 0.018291791352713783, 0.060136051953680096, 0.021124215676419197, 0.03674505105722816, 0.010106667609614952, 0.025572317517212322, 0.045843747098960226, 0.06636333171158068, 0.1503647500348668, 0.061295790327412475, 0.016340743525013808, 0.08603492977037545, 0.027716394603973436, 0.019868905918913025, 0.049145268126120495, 0.053087062457756656, 0.023833575635968197, 0.01677093636845389, 0.01190081105432323, 0.0710404976721733, 0.011806412742683485, 0.044777685956608866, 0.052178646888463735, 0.04194204597884128, 0.049429364171960664, 0.04601326703484501, 0.023442079808803338, 0.03818577515982813, 0.04410333323082136, 0.04538550777661224, 0.051480024497235016, 0.019855823052386125, 0.02406640507791552, 0.0706876912004044, 0.011094220061486047, 0.05335000298556782, 0.09031703951017511, 0.060264555542098905, 0.03505349061602066, 0.203125822928644, 3.500982099963773, 23.282608832082442, 52.45815915446128, 44.24819515597436, 32.384486467607566, 26.384899654696067, 19.011414435602006, 7.704410687569649, 0.9494919474086455, 0.18041248042737285, 0.39601098085122727, 0.9985878258462876, 1.1017894913111965, 2.5335687206637476, 2.1719668853667478, 3.770166275001342, 3.305165368703104, 9.206671599418886, 29.59603821077655, 49.27756017254245, 54.470087943538545, 57.754115904531176, 53.69628275594404, 58.01387879156298, 57.043433420119754, 56.02603335534373, 51.82133882276474, 45.35575874390141, 41.13357436272406, 45.14948521890948, 48.690436270929155, 52.82583821204401, 54.352012834241314, 56.59406315895819, 52.85292610045403, 55.29445640502438, 47.74074023769748, 44.10433046279415, 44.099529481703236, 41.545988052122055, 42.95711171242499, 46.42764445274107, 48.79947816171954, 50.36102079576062, 52.57967418239963, 52.720859896752145, 49.50835243348153, 42.60532609878048, 39.50783037370251, 40.41075214262932, 40.71716770049065, 44.85629197089903, 49.17202880305629, 51.97094194350704, 53.80434013182118, 54.271800364217455, 55.57653757833666, 49.93900122181062, 52.27275656115625, 47.198076401987386, 38.106300830841064, 53.18883788201117, 51.92046496175951, 53.507832481015114, 48.652832508087165, 50.45674231744582, 43.346901170669064, 41.22999798867011, 36.300308242920906, 37.69454609963202, 36.203998365709865, 45.435229885962706, 51.98144997319868, 55.05893376565749, 50.33457617605887, 51.42018233576129, 54.49897227748748, 52.203875818560206, 50.360895279915106, 47.696393920529275, 44.98700495689146, 45.92942107108332, 45.145790346207164, 45.4682287862224, 42.99185606741136, 40.14125393282983, 38.25334656623102, 39.55411041936567, 39.325083225004136, 40.69098980196061, 41.29911015110631, 48.27984256129111, 50.520743631547504, 53.40161861911897, 52.038292961735884, 52.57893285443706, 50.67308848904025, 53.63576842892555, 55.494540429884395, 51.35673015348373, 37.828036123706454, 19.09832827506527, 8.287053281261075, 1.1850786930130375, 0.23690207260510615, 0.9877099901918442, 2.26628297278958, 0.7410807919598396, 0.19913547011392735, 0.07887182381725119, 0.07758507955699198, 0.15119135890516544, 0.2960703371753616, 0.5783384052976486, 8.755104810960832, 20.094225906556655, 29.543241147072088, 40.23426509672596, 40.76071777651387, 37.61932680683751, 9.84745156380438, 1.1185085941706936, 0.004128771974900437, 0.03537543523575991, 0.02499819015933862, 0.03406022314823443, 0.08468657671924561, 0.03315697101155116, 0.0642160753599338, 0.06900225946259114, 0.04635193152353168, 0.010014028427371336, 0.021970308077852094, 0.05463267548850948, 0.04668447496970335, 0.018580342199833646, 0.03716486340929424, 0.03791706598994713, 0.06334796367633728, 0.010466456972813655, 0.026088699082573576, 0.04278483845654034, 0.11689311223885707, 0.06711776743853284, 0.048985259171815655, 0.13606090789600728, 0.1803639870617659, 0.21980438441518815, 0.11072919944361334, 0.0704961002714211, 0.10797362714525192, 0.23666237901535728, 0.07797421391813025, 0.25563008782844393, 0.056525245909729314, 0.1061732285926419, 0.07880837641536229, 0.16601658516353177, 0.15195818227385322, 0.22487095286769254, 0.2782119389983916, 0.13045129035749745, 0.22293829689583472, 0.10775870883897429, 0.2359408927300284, 0.1833854531568866, 0.16987014531848893, 0.11198002950198228, 0.14293640912059816, 0.13931682753947475, 0.12259870527252076, 0.12731882578302778, 0.1680615496250891, 0.22023530887259593, 0.1548149394652536, 0.2280163566672033, 3.978992282382904, 27.521737852404197, 54.78597602536602, 50.60547467200987, 43.07227642305436, 34.035971010884936, 23.627322412306263, 10.036953033939486, 1.3963165903283705, 1.0144521584433894, 1.323388574584838, 2.310676358399853, 2.6505499789791727, 4.141452687401926, 2.8071094232220806, 6.743558943271638, 4.340862554888572, 7.833938627473771, 29.730371544438025, 48.02739881700086, 53.281464653630415, 58.621971684117476, 56.15222777089765, 59.49163567635321, 60.449949156853464, 58.77451658248902, 55.106143413051484, 46.52053010079169, 43.19864342289586, 47.49412513548329, 50.77074766159058, 55.752534327968476, 56.17840566942769, 57.16759212555424, 55.31812398664413, 57.896207686393495, 51.52164228500859, 45.76102979721562, 47.30406668878371, 43.54062703347976, 45.2916201468437, 48.99040737459737, 51.05051071413102, 54.02743670248217, 55.33519021926388, 53.80067663808023, 52.62297322673183, 44.85095754746468, 40.910466024952555, 43.30484551768149, 42.582584196521395, 46.56798685750654, 51.658748734381895, 55.2582960744058, 54.796107507521114, 57.188376765097345, 56.29864200468987, 51.33490608584497, 50.19456325038787, 48.10817610832953, 42.02933780608639, 52.386901455540816, 55.871837139129646, 54.86162285650931, 50.92249239644697, 52.784433672505045, 45.9109623970524, 42.78521383962324, 37.66188060083697, 39.35844690568986, 38.75843017332016, 46.848059777290594, 54.94339642986175, 55.65600479802778, 49.05219254955169, 52.78393160912299, 55.51290104466101, 53.2254453628294, 50.94971364544284, 48.72819692857804, 47.446299675972234, 49.04210029109832, 47.334692555089156, 46.35449224902738, 44.15206178542107, 40.91736155171549, 38.63223575776623, 41.8385027300927, 41.65734414131411, 44.043961263472035, 42.62571850130635, 51.03511148883451, 51.5357235939272, 54.371212836234804, 53.561549340524984, 52.200690853980284, 51.238145136064105, 54.250015520280414, 56.160707935210205, 52.15371654879663, 37.42718165920627, 21.385856520745065, 10.586032886658947, 5.387445053746624, 1.553047025395978, 4.788671222425276, 6.831092517222128, 2.1025073480221534, 0.9038557833240879, 0.25490492432107853, 0.24028145497845066, 0.4100645573869829, 1.240799025662484, 1.868617272665424, 13.942313848003266, 25.91987325299171, 37.19094122609785, 50.533008883076334, 46.26967099405105, 42.694512951758604, 11.138895865409605, 1.3602451259090056, 0.18636176602975016, 0.12044248186172017, 0.18115236814464294, 0.20495738593801377, 0.1579729990372735, 0.16055132923347337, 0.10590560343717376, 0.17127044679176423, 0.17648582016268086, 0.10966152568618137, 0.07575167027572471, 0.06492858692522972, 0.13181558569833157, 0.32680455895681537, 0.10682595082588735, 0.20742402051485356, 0.16332161041998094, 0.058998591416785796, 0.17915506967373435, 0.16775771915431947, 0.16839798479791612, 0.1569942910704882, 0.14814818187827064, 0.2544643624775833], [0.030730797368432247, 0.015021619601024976, 0.07822443355595873, 0.026690713956110904, 0.04975060016036995, 0.022492502335338824, 0.10200839925317035, 0.022368903624855226, 0.025845678756013516, 0.04391119837941181, 0.12513237254273507, 0.06556018811440276, 0.06225782056008616, 0.004623724624604708, 0.012727553032398706, 0.029776274797416506, 0.004318580313044931, 0.022119111081044522, 0.039882893568926284, 0.0320583185736811, 0.02917163990317814, 0.042934148992982604, 0.024320727116578532, 0.04932312309862145, 0.06328846162725842, 0.08262681909987042, 0.03617801575831348, 0.07908794488156996, 0.03445565092167066, 0.03246805112388346, 0.18394838988540635, 6.876622899886101, 30.81174546672452, 43.69526255515314, 39.558844720163655, 30.51397285153789, 42.81551414920438, 15.456574270802161, 2.451810836791992, 0.25141845817767805, 0.2515108177378293, 0.15897845879437464, 0.3979574876927561, 0.8439990661797986, 0.8011624938057316, 1.0820206230686558, 3.425082766240643, 1.9963366321979032, 11.017757385007798, 31.285287334072976, 48.5555891067751, 52.67991819689351, 55.938819454562285, 57.80227868787704, 55.08772004035212, 54.584683910492934, 45.97498724537511, 45.40218391726094, 47.11791884514594, 52.75090525227209, 53.43157376012495, 54.69654206306704, 50.579861594784646, 50.35023035541658, 54.95980370429255, 50.96034326860982, 49.32107494723413, 45.643982348903535, 42.31602384198097, 43.59310442401517, 44.65072839490829, 43.64027092533727, 47.00298163198656, 48.55423981143583, 51.325006023530044, 49.48505747702814, 45.30300286508376, 40.91039934465962, 39.48408434467931, 39.24092485058693, 39.763141370588734, 45.37253864349858, 49.717352005743216, 50.00113548771028, 52.527589028881444, 53.90913017334477, 52.44488193142799, 51.61965054850425, 46.086441393821474, 38.56048384020406, 37.1834808780301, 49.47823647529849, 46.78866724814139, 52.00746313218148, 49.83210878987467, 49.610008501237445, 49.90327627428117, 47.886260171090406, 38.33519074224657, 35.665857022808446, 35.97151164085635, 43.967471122741706, 53.50571832349224, 48.91438791828771, 47.12609306458504, 56.565751491054414, 49.74930755553707, 48.99819327938942, 45.23090577894642, 43.27603178639566, 38.03337612459737, 38.43368145727342, 35.95926600117838, 36.60495088946435, 36.68424552486789, 36.52748015619094, 35.715596598963586, 36.84371732896374, 39.21241706417453, 40.090690658938506, 40.36566057512837, 44.86863959220148, 48.77179015067316, 51.373302167461766, 52.283021403897195, 50.49742121850291, 53.52311403520646, 56.406028655267534, 51.44480305333292, 41.54465444626347, 23.97364612548582, 9.872690054678149, 0.9466272075810741, 0.4085651701015811, 1.165036239450978, 0.6942465889357752, 0.7006799501757468, 0.03018641337421873, 0.05188765988174466, 0.17279752049474947, 0.052323609875935706, 0.26826998699576626, 0.2027737442404032, 3.185473507450473, 5.3003699068100225, 10.869110341994993, 30.333190810295847, 37.03245001454508, 31.431668227718724, 16.740983801503337, 3.4818333339306617, 0.2881668225651787, 0.07168375105867464, 0.04638285466259526, 0.02655657004534958, 0.018465402198114225, 0.03906327142049709, 0.03510396048847226, 0.054060289065443703, 0.032123646721424114, 0.10649958970926462, 0.03479392853595557, 0.0540958317146907, 0.03445749336312856, 0.009120231730893496, 0.026124414101603533, 0.04147332274324952, 0.010581877694705562, 0.014238146268912863, 0.03749848703943914, 0.07216856980155553, 0.051204060474711086, 0.019310169267438112, 0.09112423571247248, 0.029291827607178883, 0.021328299584227706, 0.02022668047087087, 0.023308271061508887, 0.051165962922236616, 0.04306382469592556, 0.10674306777335944, 0.05131441544020369, 0.04683504955122068, 0.016503550615462086, 0.09311266288521791, 0.02418077242891154, 0.0592596243856655, 0.017554782210819183, 0.004470281522615903, 0.031123365718691103, 0.04580543504186696, 0.04056474246505288, 0.022204449445369746, 0.02062153942402332, 0.031502456667142055, 0.06205804781207155, 0.012199048125635714, 0.06990245873889617, 0.005970141867310891, 0.04936478679038344, 0.03746460297054822, 0.0645650705442794, 0.024472738112953883, 0.06237526183887836, 0.05945349825666316, 0.06475732030887758, 0.33440675586462026, 10.18799174216486, 36.36547842333394, 49.961688210887296, 43.480897180495724, 25.77109971354085, 33.99814759531329, 17.515610725648944, 3.554886007501233, 0.268147841937119, 0.1424145500265783, 0.7013903281861736, 0.26583735140100606, 0.2282014128661925, 0.10424237292740615, 2.935711683765535, 4.115889130100127, 3.6722827919067877, 13.1354695558548, 36.11597253430274, 51.07411946019819, 55.24949427573912, 57.24119540183776, 60.5031757200918, 58.22894234811106, 55.61926787899387, 50.327339403090946, 46.4433103992093, 49.433388094748224, 55.31527242352886, 55.64058988325058, 57.23246420583418, 53.10836653555594, 52.70792391992385, 55.92819375376548, 53.97329622699369, 50.75151628063571, 47.45147328222952, 44.42019501040059, 44.546389425954516, 45.4041451023471, 45.68497896194459, 49.042339555678836, 51.31936565522225, 52.196662579813314, 50.5979476436492, 46.93519130829842, 41.6347748233426, 41.26423243553408, 40.85274442549675, 40.83358756957516, 47.56082896263369, 50.61322919784054, 54.01572058277746, 55.48879023521177, 56.72287771778723, 52.47622559147497, 53.17364654233379, 45.37377811247303, 40.624223216887444, 39.44291514735068, 51.72473476779077, 49.79195156405049, 53.85051427348968, 51.58746357887022, 52.31595362386396, 52.23025375796903, 46.94069831602035, 38.56283333993728, 36.490672634493926, 37.204606763778195, 47.04569624316308, 54.65843231447282, 51.55321344252556, 48.57555397095219, 55.856257484805205, 51.75613726339033, 51.41386731978386, 47.45875320126934, 45.74359486179967, 40.04463811074534, 39.22869490038964, 39.02630844423848, 38.31874816648422, 37.98057709970782, 37.4688607646573, 36.46274143649686, 38.75497064282818, 41.144639368980165, 41.31845920316635, 41.6282715335969, 46.543142564835094, 50.116649289284986, 53.004729670863, 53.34078658011652, 51.49041629606678, 54.007766016068004, 57.235049047777736, 52.94143438339234, 44.9908528020305, 27.05673694610596, 10.779816604429676, 2.316659688949585, 1.6004883377782761, 3.4741020971728913, 1.9425044304901555, 0.7343803418259467, 0.1617225857391473, 0.04901919303642166, 0.07339034980583577, 0.06952650109005552, 0.22272843476985732, 1.0355618644145228, 2.914343836807436, 9.092307052304669, 14.485282647994257, 33.903277227955485, 44.91166799299179, 34.85311838888353, 22.6630743857353, 4.586410282119628, 0.22888603500060498, 0.04050932749505005, 0.04640009164089157, 0.029087171048646974, 0.03475424518147784, 0.03271522556221293, 0.045412489393305396, 0.02051754681874187, 0.05168030286327966, 0.04134655817441883, 0.07797845804523076, 0.020345244068472136, 0.020054377720601136, 0.03788265715082807, 0.025149798959553726, 0.03750650414956674, 0.04880126017416197, 0.03532760453620746, 0.016405401345823082, 0.08079802166790732, 0.03224361417514663, 0.03729561929621043, 0.13518885469004033, 0.07575026067394404, 0.026929746795025085, 0.13076183175848377, 0.1421998921901949, 0.30828505754470825, 0.26087181462395576, 0.16063792781243402, 0.13182681654730152, 0.17568630016138478, 0.15089091454302112, 0.10425135147787871, 0.14899970392786688, 0.1741254266591803, 0.16442696804240828, 0.08239371386627037, 0.1124644575400218, 0.10581263100668307, 0.17797322583294686, 0.13167923736956813, 0.08789498358964921, 0.20107920371717025, 0.1369862042127117, 0.11273207503461069, 0.16109598710411982, 0.1426899739571156, 0.1607329227150448, 0.17467380771713872, 0.1462298211070799, 0.11578094409478289, 0.21108025174227454, 0.202944842317412, 0.10449325140084952, 0.41388687647638783, 12.518126733841436, 41.452784692087484, 58.98465756447085, 51.63519882386731, 38.822576615118216, 50.21950560231363, 19.82988561353376, 4.694410783629264, 0.6713801514237159, 1.7613502543780113, 1.9786113188151393, 0.8111167951456962, 1.1812661492055463, 1.8848682651596687, 5.15735391647585, 6.677711173411339, 4.8432186438191325, 12.624391586549821, 35.78272796446277, 51.59459444784349, 57.20586269132553, 58.117668628692634, 60.018362922053186, 58.702093939627375, 60.695960214061124, 49.38498996919202, 49.06256721865747, 51.30597468345396, 58.16812992095948, 57.126548444071126, 58.26328269896969, 54.76794488968388, 56.19924914452338, 58.860459635334635, 55.866043798385135, 53.27012508146225, 49.821628216774236, 46.50423657509589, 46.64462212593325, 48.71322524163031, 47.32849913258707, 50.38122884688839, 53.49330794426703, 54.435225917447, 52.64542487359817, 50.37547080747543, 45.07308529269311, 42.73941624549128, 43.974194065217056, 43.79761680479973, 50.43539285659791, 51.890866756439216, 55.13317246590891, 55.705399205607755, 57.806499158182454, 52.69547823936709, 54.88495311429424, 46.289628013487786, 42.76170707518055, 43.300562289453325, 50.054895493292044, 52.52604753740373, 57.20197562248477, 54.084012969847656, 53.76651279387936, 53.82453249346826, 50.820240128424864, 42.06310549089986, 38.73250330648115, 38.52767321371263, 49.03433399815714, 57.77318646830898, 52.573296408499445, 48.96152304064844, 57.81156686044509, 54.13656488541634, 53.696129783507324, 49.33400700169225, 47.11221179654522, 42.67155924151021, 41.26191039239207, 41.46237880952897, 40.596727401979514, 42.09799497358261, 39.72922463570872, 39.45488229874642, 39.952705598646595, 43.50675344467164, 43.80895245459772, 43.988746058556345, 48.75793633922454, 52.94243851015645, 55.60309202440324, 54.009550694496404, 51.55563354492188, 54.76693291817942, 57.23984218412831, 55.917944600505216, 45.37945770448255, 28.58462956643874, 14.5770239445471, 2.678689062595368, 2.084230819056111, 3.1245000179736846, 3.410714879151314, 1.5915083164168944, 0.3670166979633993, 0.28468381913919605, 0.25855865810186635, 0.3161700634706405, 0.9093313507976071, 3.443056292110874, 4.186142211960209, 13.488295578187513, 22.29667794319891, 40.70071335761778, 49.92234683805897, 40.289213580469934, 24.5342351928834, 5.678762428222164, 0.3766235631079443, 0.13557499364739464, 0.1506527531291208, 0.19285151134094886, 0.1568739846228592, 0.1390094883860119, 0.077956379391253, 0.10507679589453245, 0.08842522368556069, 0.1743447576319018, 0.16555846458481205, 0.175773925298164, 0.12230446622256311, 0.08173412748522337, 0.069733337168732, 0.08973541789718213, 0.18496074443382604, 0.09151047426125697, 0.11657333947838315, 0.3170473873615265, 0.13267798619645257, 0.09208149321737791, 0.2696828369892413, 0.14061853349689515, 0.18074646411884218], [0.0543479320983733, 0.07888929828280404, 0.010644669133809306, 0.017731532101489363, 0.06843881711604134, 0.05511783131007707, 0.0953489961102605, 0.043995617438227906, 0.031803199803576834, 0.04026461985983676, 0.024088497138431957, 0.04342406222055997, 0.018085196591733445, 0.04939019792683182, 0.030683487608668306, 0.04400608219927357, 0.08690749625525168, 0.10437502871237456, 0.0475312396132898, 0.047751240912945046, 0.04116864191488393, 0.02328197126306834, 0.0830162062700237, 0.09535629692817889, 0.02539471343850657, 0.09435055371854575, 0.06560785410505149, 0.09244891664674205, 0.08543229436561947, 0.037686025363303004, 0.0622632865974259, 2.500927736682277, 18.233990861523537, 43.578611266228464, 36.037219185982984, 43.49619442416776, 39.200481291740175, 12.877588425913165, 5.93784821610297, 0.7790031248042661, 0.07961650724492728, 0.5565086992517595, 0.3287271025680727, 0.393639050063587, 0.0667175018198548, 2.4647723090264106, 0.853435124360746, 1.4865331880507933, 3.1573018191322206, 12.976499815141002, 32.0424989346535, 52.35012531280518, 57.293794385848514, 56.70554868636593, 55.26631339903801, 51.8649398896002, 50.06592127584642, 49.25680691196073, 52.77684780859178, 53.76447316138975, 53.641538235449026, 52.11938012030817, 49.70693419056554, 51.3664693986216, 54.837896439336966, 51.60713034291422, 51.057425852744814, 48.07381222324987, 42.43032170880226, 43.51004823561638, 44.34549739283901, 44.92569046635782, 48.85426582828645, 48.06257071033601, 47.96861425522835, 45.28274774551392, 42.122035180368734, 39.66747476208595, 39.212444520765736, 41.716905332380726, 40.49655399014873, 45.41604165107974, 53.33434997066375, 50.96215540362943, 53.00170944583032, 50.962790827597345, 52.53994057255407, 47.94821793033231, 54.253757461424804, 44.8765431680987, 36.570885104517785, 52.35522439402919, 45.305085643645256, 52.30617123265421, 52.069185549213046, 53.90823195057531, 50.02435199676022, 51.62708736235096, 39.75462590494464, 36.355072375266786, 35.8294237813642, 45.677102842638575, 51.80742225339336, 49.40593542591218, 44.512590362179665, 54.53626617308586, 49.89705539518788, 49.006744046365064, 46.6673836400432, 46.781454009394494, 45.9898373388475, 44.348768649562714, 42.934601230006066, 43.95619823086647, 39.926857179211034, 39.26178009279313, 37.95369709691694, 38.226494020031346, 39.315277299573346, 41.40463367585213, 42.111280041356245, 47.188862754452614, 49.38261693523776, 53.68476667711812, 51.76702576298868, 54.578353205034816, 52.7591775309655, 54.52382833726945, 45.168540093206595, 28.60389428754007, 12.916359093881423, 1.6752776407426404, 3.2965006078443224, 1.8355494857795778, 1.4033535675656412, 0.7549325809363396, 0.449600363330495, 0.05568860128762261, 0.06924464968183348, 0.10568202833735174, 0.04960966296494008, 0.2944123696896338, 0.270302816624603, 3.8349268128795013, 8.431692642550315, 21.03821881355778, 31.037244489116055, 30.395721235582908, 27.13164637165685, 10.52478801819586, 1.119907041711192, 0.10505557525902988, 0.05207630137221948, 0.05531577310795265, 0.0788516374004464, 0.04593610665911148, 0.04351808419150691, 0.044751347853772105, 0.00947107989040594, 0.08128424235168966, 0.03036244697267971, 0.0838664336310279, 0.003351961931912229, 0.05280439133545565, 0.05755426287050209, 0.031827147712089845, 0.03990298422474054, 0.045268732994314165, 0.0352192988559123, 0.10551972494971369, 0.02099291969751639, 0.0933478671997305, 0.048774596483957385, 0.05189901330478249, 0.02683647559024394, 0.14442683317728583, 0.009751111839807803, 0.01828867145964215, 0.08719576748027917, 0.08422807309656374, 0.045154336915020986, 0.0299122036930414, 0.018072383771199855, 0.012343469105901258, 0.020998860709369186, 0.05722317499138656, 0.05051445876879077, 0.06417684016689178, 0.046834881011877334, 0.05615114602410505, 0.029986000942787337, 0.042173561579998464, 0.053038768275010015, 0.010743048229825594, 0.00951517878415724, 0.03774854196836391, 0.11573382202656039, 0.03933145198971033, 0.029144256090324734, 0.06739312242115698, 0.020012463135043942, 0.09097996603457198, 0.04764330295485355, 0.05110594759424848, 0.04568107981955813, 0.029354079911905914, 0.03123696123610341, 4.669555704439841, 24.73037527453515, 46.81948923295545, 39.267141972818685, 41.68993903744606, 46.607147801306944, 20.398129186322613, 7.400856989045297, 0.7014802362649672, 0.03730663181012196, 0.06395621833601786, 0.5478034276635416, 0.5482089639671388, 0.2648921521200288, 0.4287226287828338, 1.2570361672870576, 1.4118104428052904, 5.205076904066148, 15.627597455055485, 36.10277768104307, 53.03080558776856, 60.3241430559466, 59.20674608599756, 57.01467460201633, 55.865122041394635, 50.687291391434215, 50.52199879000264, 54.981823890439934, 55.27102808798514, 55.63549864676691, 55.172086300388465, 50.859597190733886, 51.754913483896566, 55.88221180823542, 53.9347275610893, 53.47368040392476, 48.79609707863101, 43.826046143808675, 45.83542539227394, 47.07634956605973, 45.587468839460804, 49.47665183774887, 50.76854328955374, 51.20736629732194, 47.5712703120324, 43.68411910149359, 41.324582023005334, 40.63741807014712, 42.595747670819684, 41.061524345028786, 49.171565963375954, 56.930724113218254, 53.256487000373106, 53.88481147827641, 49.81330886963875, 52.056226038163715, 47.086402600811375, 53.71386281905636, 46.70554045707949, 40.02304154057657, 52.153959735747314, 48.861639884210405, 54.20688121549545, 53.51077818101453, 53.69888328736829, 51.89196502008746, 52.71348976319837, 41.68591468564926, 37.615647623615885, 38.967770991786836, 46.76846704175396, 55.46748784280593, 49.728813171386726, 45.71549107951503, 55.377551817124896, 51.81277628867857, 51.02908280587966, 48.07367494029384, 49.073757740759085, 46.825557139612016, 45.45342183882191, 43.945439169483805, 44.92317622707736, 41.311081224872225, 40.0398410520246, 39.128901958465576, 39.32891930303266, 40.57305982035976, 43.143157574438284, 43.14554237550305, 49.649338106955256, 49.99607170781782, 53.41817886598649, 53.38917293856221, 53.319013503289995, 52.99169171241022, 53.87270312155447, 48.49603576044883, 31.402075905953687, 14.559978304370759, 2.0665585802447413, 3.8724244265787067, 2.362308478163135, 3.481018461527363, 1.095722197524963, 1.4792788869911626, 0.23275473305294592, 0.2448340550425553, 0.013102864294553236, 0.014160540604573345, 0.600410562849814, 0.5462978503877117, 5.629123853098962, 10.355822117097917, 19.920904213382354, 34.22318966157975, 36.88130540232505, 32.656626393718106, 13.594278020243491, 1.889792065466604, 0.14107305346237076, 0.07877335853634343, 0.01455664923865228, 0.014506407277358156, 0.04613426679204549, 0.019977642523665583, 0.03046702946566286, 0.043502681993789254, 0.06271506396813259, 0.02394420639311354, 0.0627615080485421, 0.00680723273563349, 0.06473212367704799, 0.032170268917276014, 0.05802259540125247, 0.016725777400537364, 0.012654148402713962, 0.014327429028438225, 0.06690763718178196, 0.02314512880759374, 0.06229940764305573, 0.015576974931924094, 0.04523640025346991, 0.00858165372553612, 0.04062347842620746, 0.21016738137170193, 0.15040118517654558, 0.16991994103356717, 0.11782527270336306, 0.12902393065873655, 0.10362314405821024, 0.29945108318521135, 0.1952696372304232, 0.17549513058075983, 0.17114839366366788, 0.09761462453752758, 0.14681978541756832, 0.1595375804050315, 0.16329084432894186, 0.09904394542137462, 0.1203946473317281, 0.15548638488736846, 0.25152920384801203, 0.06658350538101888, 0.16137832114773412, 0.2326832264060936, 0.14745684881364146, 0.11812862819961964, 0.18599900807584488, 0.07133464479158003, 0.23570479975352365, 0.17769171916429075, 0.2370711175664779, 0.18002510040758118, 0.11380973091769604, 0.08732931958811899, 5.254967491472922, 28.82199375860153, 55.85364518627044, 47.75640618416571, 55.53311694052912, 50.38913242278561, 21.44817709922791, 8.80280573521891, 1.3635503356495213, 0.18381862991279174, 1.3632534612571041, 1.003150829384404, 1.4218522007426908, 1.087671900468488, 7.975267508337575, 3.604256390563904, 3.5063233875459243, 5.268000546962985, 15.52514808793222, 35.686359251699145, 54.04553451845723, 60.60452192060409, 62.31131776686638, 58.22357654571534, 57.294296449230565, 54.390322623714326, 53.698392991096746, 57.45780437223373, 56.10527307756486, 56.390158745550345, 55.72618776752103, 51.938488252701305, 52.91052610643449, 57.54024474851547, 56.820866369432025, 56.34172924103276, 51.88969789012786, 46.00754684017551, 48.674068220200084, 49.01645975728189, 48.34185131134526, 52.62507953951436, 52.17067295505155, 52.574292690523215, 47.82718927629533, 46.1375145758352, 43.56392983467349, 42.847779566241854, 45.257483759234034, 42.48821197017547, 50.01416167905254, 58.12328938514956, 56.008457214601584, 55.431574621508204, 51.68387543770575, 52.87046301749445, 48.23500987022154, 52.23008901842179, 47.72834947032314, 44.66950478092317, 49.50158242256411, 49.62406627593502, 56.26515673052881, 55.702029889629735, 56.51618842155703, 52.20689996596306, 54.34647444755801, 44.5065224555231, 39.83615236897623, 39.41025357092581, 48.416329276177194, 56.32937769736014, 51.46025326944167, 46.42094504448676, 56.90493845170545, 54.346949054348855, 51.576865334664625, 49.71957991200109, 49.895666876146876, 49.74755033369988, 47.40704851765787, 47.24782774525304, 48.23471961482879, 44.08908420993436, 42.404767467129616, 42.56969136576499, 42.34595937113608, 43.91063205657467, 45.804273928365404, 44.99557533571797, 52.731591501543605, 51.63598722027194, 57.581362955031864, 54.755244255065925, 53.31072161274572, 53.1068132769677, 53.69820863969865, 49.77637583209623, 37.402137325656035, 17.02733055237801, 2.4392026230212185, 6.530309973224518, 3.591610669128357, 4.6607798914755545, 2.3687161601358846, 2.3931277663477006, 0.4674735010391282, 0.32270525311750753, 0.27721112173411155, 0.17688849129744116, 1.1701751572470511, 2.1658597550084515, 5.628346733508572, 15.86428798014118, 30.633752230674993, 41.32972425030124, 42.80314299368089, 36.26516380617696, 15.077311473508036, 1.8675359242385434, 0.3587640924078803, 0.18489521327278308, 0.23104016699137228, 0.16795671815353055, 0.16799296943410752, 0.13266321602127246, 0.18685379365999855, 0.20683745763474898, 0.20885798389152174, 0.10389722733488006, 0.1340243091145831, 0.15688210515485657, 0.17524999776674857, 0.11846950668240748, 0.1405069910951199, 0.10643138490136593, 0.20257439284074694, 0.12810701534392374, 0.12112129704966662, 0.13097630573376534, 0.22141776558372284, 0.13843406442432635, 0.15675406121919233, 0.0789765403756211, 0.15031446402351703], [0.03194622267338057, 0.10606703348457815, 0.07837077933213404, 0.029205543124267173, 0.038437496329988205, 0.02530796164196105, 0.039232994369681806, 0.009195450073738974, 0.03317945569212879, 0.04267954733222724, 0.034432626149106416, 0.0664317740067359, 0.031961914069289644, 0.004787317433980324, 0.043755954491996, 0.07236461170137891, 0.046427892971663706, 0.01228354953890366, 0.028696502596440337, 0.06115550813715785, 0.04676610929891468, 0.04735669797106136, 0.017576834051719597, 0.05754305117373025, 0.039378351892434785, 0.04185803677706469, 0.054039631504565484, 0.039136268108362154, 0.07435422631040697, 0.032106593604229634, 0.030831409610747814, 0.5655619586187025, 6.551004888549929, 37.539149638145204, 44.43730438909223, 35.64061657074959, 15.041969937662925, 16.562941535826653, 11.340611596261303, 2.6782647111723503, 0.05970911498391821, 0.07663396607723928, 0.3173788582846042, 0.06610976426952309, 0.0619060559678943, 0.17858376726508143, 1.4308101587718534, 1.406349768081019, 0.8802938605508498, 4.406586770088443, 19.47347160308592, 35.70550434051022, 54.634160687846524, 55.87157826269827, 54.05313607185118, 54.64246826787149, 51.202526092529304, 51.81479238694715, 54.83089500857938, 55.52302468207575, 55.734777758198405, 53.974625910482104, 55.97119469796458, 53.29446731075164, 55.71007859322333, 53.23945606908491, 53.10678189800632, 49.740066451411096, 47.24987522248299, 45.36225418890677, 42.74387990274737, 44.47541413768646, 45.20054271144252, 44.68761436400875, 43.16593085565875, 43.04873043490995, 39.204156552591634, 39.14273223569317, 40.91882459578976, 40.659077398238644, 41.79474476845034, 42.82901494733749, 51.35416884576121, 51.557943820953376, 53.66615503065048, 53.163083599459746, 53.802120070303644, 51.08885972730575, 51.67343408830705, 44.19825161657026, 35.4520211681243, 48.34721711374099, 44.91757900484147, 49.99501659024147, 52.018520293697236, 52.61467741381738, 51.205558084672504, 51.970118245770855, 39.66392109470983, 36.82656872657038, 36.329922137721894, 45.45797571059197, 51.435805136157626, 52.92232851828299, 53.332612360677416, 51.8659753953257, 49.61660985023745, 50.521347676554036, 49.34258914762928, 49.24502411196309, 48.54939176190285, 49.81392075938564, 50.73863129461966, 47.68887473690895, 49.021751034644346, 45.561114434273016, 39.7345825933641, 37.48009443283081, 39.48107588675715, 42.524748848330596, 43.31427489557574, 47.54414712229083, 50.030898432577814, 49.16233270399032, 51.28164422127509, 49.426559248278224, 52.014331202353205, 43.67117920229512, 31.93405128294422, 13.738841875906914, 2.372302677362196, 0.7142724949986704, 2.5547289271508498, 2.252310754791383, 3.533132052229297, 1.327581343150908, 0.8818242590754264, 0.04056871463094027, 0.06985736680367301, 0.08335377525297866, 0.0713981764631406, 0.012416574003685628, 1.4576597631938997, 5.561728217909414, 18.109463453292847, 24.311293555844216, 35.2348905224954, 29.664940526408536, 13.787224311982433, 4.14475973575346, 0.16206226912477326, 0.03275598143978465, 0.017215024131620606, 0.03737788947839891, 0.03347159566117391, 0.06984207568870437, 0.0036604779879487455, 0.014506154468343144, 0.03588617839399846, 0.11507154667689917, 0.029365699550497438, 0.03605485563316653, 0.09145267292737, 0.0014650900078366602, 0.005716212448709074, 0.03559346768944975, 0.03209227159048521, 0.003923679464459119, 0.03649455562774693, 0.024304811639951605, 0.03012807194834515, 0.08264305250298593, 0.021202781823493784, 0.059723088427657084, 0.03805802233757512, 0.05825949277007773, 0.032557966863556255, 0.09403452712802157, 0.03393871011212468, 0.02163095794047319, 0.029928555839785168, 0.0710124205497484, 0.05146292158432546, 0.04201412719163684, 0.021901149490487673, 0.026289529031923702, 0.027491235617367972, 0.07596783730531893, 0.06370534369301412, 0.016860084104982596, 0.062457976352062926, 0.02439567349821089, 0.039010162375146346, 0.04985812443098234, 0.05260924575850368, 0.008342320197111657, 0.04889704797777438, 0.034247658050228516, 0.02446108783084539, 0.05679260293442396, 0.05387375048632103, 0.05087409874484424, 0.034585181067908005, 0.060028914557469476, 0.035746888287605784, 0.04007352305756461, 0.02745137989310728, 0.6226324446259007, 10.056314833702581, 45.52970409393311, 49.10471700852918, 43.656944920939786, 23.18494769834703, 17.069093988787746, 10.791332683255597, 2.0742581928929975, 0.026799132634374886, 0.14698244120565154, 0.23085589220206584, 0.06269869266919072, 0.08329300149794548, 0.6296746312610565, 1.6132604330778124, 1.2712030329050557, 1.5856458438980965, 5.13807007381993, 22.17572577538029, 38.51831051611131, 57.87459542674404, 59.39319202976843, 58.149612411375976, 56.86631879498882, 53.03073890747563, 52.92635679244996, 57.55365140976445, 57.018530291895715, 56.62410066973779, 54.53790180144772, 56.27437037806357, 52.672065611808534, 57.44421728195683, 54.59667067373953, 55.015873985905806, 51.31977750409035, 47.85050384459957, 48.27033473599342, 45.644551092578524, 46.296401946775376, 47.286933775871034, 47.32837753911173, 44.7363184344384, 45.14465285885719, 42.04816518291351, 41.68994295981623, 41.84143666298159, 44.20053443601055, 43.2630761977165, 46.87021332402384, 54.28400285782353, 53.638153229990316, 55.50928069699196, 53.71179180760538, 54.62582172886018, 52.40051208003875, 54.03189643736809, 45.28777622407483, 40.10860412351547, 47.9530934364565, 46.83624559833158, 52.99883042612384, 52.949220288184385, 54.630144180790076, 52.62516583165815, 51.89500093460084, 39.88993590877902, 38.09667925680838, 37.87848564886278, 47.02506065368653, 53.030083871656856, 54.99846258471089, 52.6141635833248, 53.323787027789706, 53.0143080988238, 51.47551521178215, 49.941919465218824, 50.73156318356914, 50.73045315281038, 51.94253221634896, 52.94889080908991, 50.35466263371129, 50.17702241097727, 46.49100249813449, 41.195469364043205, 39.550290030817834, 41.08760026193435, 43.868650928620376, 46.19096863654352, 49.33906293684437, 51.97256972712856, 51.05162074488979, 52.34184518937142, 51.68260066739975, 52.24456648672781, 47.48262082376788, 34.681424479330744, 15.035660805240756, 4.266870963958002, 1.2706510818773702, 6.010896967303369, 4.060869308248643, 5.044567142763446, 2.5365158915519714, 0.7877739122317684, 0.3578321924132686, 0.15276648164276155, 0.0975051888775441, 0.13455886994638752, 0.07188574546166966, 1.2249039882613768, 7.267071806615399, 17.010564381076446, 27.3175000375317, 38.904856174222886, 35.2697015577747, 18.867024144818707, 6.396987140178681, 0.5468325797588595, 0.10313507710253039, 0.09132241499760459, 0.03286576950021329, 0.06446556338379461, 0.028060266575325402, 0.010559132544233674, 0.041256692230461106, 0.06568206504227654, 0.03852747718713457, 0.02821039874106646, 0.05267154402850617, 0.06844336767831156, 0.022160087208894473, 0.022114859293064764, 0.035052804967328426, 0.05244053021493939, 0.008513688320113767, 0.07748310559339101, 0.015589182542997505, 0.03316140283019312, 0.03248052303529075, 0.06282674426573419, 0.003071418379418432, 0.03369473409087908, 0.10359512056194006, 0.10936894138614017, 0.14138961631444194, 0.14608165970252407, 0.17214395556478732, 0.12710663474976056, 0.1115426392624936, 0.11941050780155968, 0.08977445773780347, 0.11517745833243094, 0.09813282173126937, 0.16632249939345545, 0.192054427499252, 0.12075127658223915, 0.06743194009628027, 0.08932599752780893, 0.11699966740824523, 0.13936360486813132, 0.18163101987973337, 0.11392027740516972, 0.14424131732554207, 0.26622468545552225, 0.12038635826038739, 0.15149912706786586, 0.15788178860900864, 0.2072889438920444, 0.13157869599038555, 0.18264210272219875, 0.1363479150759597, 0.132690304890275, 0.16562808665537065, 0.1777893034440856, 0.9003923917489668, 12.987968825524854, 50.2939364987035, 60.00426592365388, 49.641528667942175, 25.416313486714518, 25.019012689590458, 15.602559985653048, 5.372018862155176, 0.546941670679277, 1.1090435472226914, 0.9057842411341206, 0.23391383940414076, 0.2051252511239821, 3.062391737776418, 7.855477832978773, 2.730041958632008, 1.5706762407095203, 7.3416757775891215, 22.76105127026958, 36.64215849291894, 59.70251406392744, 60.275819455423665, 60.96176747352847, 59.20958195963214, 55.325090116070164, 55.92555007626934, 58.40011066006076, 58.580312190517304, 59.0389157110645, 54.64527668491487, 56.819211129219305, 52.74508445493637, 58.27586566248248, 57.260207130062966, 57.60439119031353, 54.39193079548498, 48.966861386452955, 50.220121414430686, 46.97605456075361, 49.51580493680893, 48.987508743040024, 48.50077790598716, 46.48579751291583, 49.378725944026826, 43.03752814569781, 43.620255070347945, 44.60403257800687, 45.49924688954508, 44.48198803009526, 47.787385063786665, 56.163171183678415, 55.26180659571002, 57.84631906017181, 55.92628355949156, 55.176098885074744, 53.004294287773874, 52.7206402440225, 46.149014965180434, 42.89378896836312, 48.447861209992446, 48.105744238822695, 53.4764103735647, 55.38953858037149, 54.66808918983706, 55.02726454888621, 55.257374317415305, 41.99628007027411, 40.3457506241337, 38.86067459660192, 47.947088287722686, 56.12119005572412, 56.08407266678349, 54.59132840556484, 56.00744524309712, 52.53928553673529, 53.98265500222483, 52.15348512895646, 52.729132175445564, 51.79663181304932, 53.7447867854949, 55.20172372941048, 52.441312574571185, 52.43921802889917, 49.62410549963675, 43.48403899900375, 41.55373473321238, 43.31171358785322, 45.66112702892673, 47.829162228492, 51.18570304686024, 54.8623602621017, 52.16928051364038, 52.769673793546616, 49.794085333424235, 51.71974551293158, 47.87036672715218, 35.68952068205803, 16.824730327052457, 3.287823344430616, 2.402364212659098, 6.089333093935444, 7.813930617224786, 9.44794737523602, 4.2273878955071975, 2.6958418325070412, 0.2996991730986103, 0.1476163176759597, 0.30557794796843685, 0.3007044030293342, 0.18058569290705268, 2.0042864185187126, 8.971452943740353, 25.160227821719264, 36.849683253995835, 47.522495638939645, 43.070468210404925, 20.98438428294274, 6.527847215052574, 0.6213492779962478, 0.16955358246641775, 0.17688974768163698, 0.14456531123047875, 0.1263387235362203, 0.1380659438549511, 0.12541937972268752, 0.15878010330901993, 0.19529905500671557, 0.21548847487616926, 0.1698788021120333, 0.12854489587968396, 0.19608470881658216, 0.17694921142631964, 0.11777340855088927, 0.11890906495072188, 0.15440993942320347, 0.17510732155173056, 0.19437807942590407, 0.05489304579133469, 0.14197925886800214, 0.16677936358797937, 0.22249365946458233, 0.13576633176736294, 0.19934029138136297, 0.15470531228328907], [0.07575079693549103, 0.08730394675606683, 0.024669210937234665, 0.03723194972882348, 0.04558694676586217, 0.056702595264200246, 0.022361631535233992, 0.05839068532711076, 0.08059414268861856, 0.034814731653539405, 0.027977375861918254, 0.040319084880813476, 0.02746478451656238, 0.008034078017508071, 0.04235281083252161, 0.12903212779952636, 0.02217430771598893, 0.05645300764890929, 0.07843629517141851, 0.013045729457160399, 0.05610159162672297, 0.08151673471495029, 0.05992770668179278, 0.015147664047206844, 0.0690202012417778, 0.03705793285682317, 0.03199432533414614, 0.03717330569821981, 0.017530537443235517, 0.005150455080213086, 0.10712791204212174, 0.054755490874090505, 4.28164113913813, 21.94409412722434, 33.330779844714755, 41.15358629534322, 27.167967519452496, 26.399571280325613, 17.21755962218008, 2.605352262335439, 0.7968032696554739, 0.19006361013218281, 0.24911945896042934, 0.3886811128787456, 0.0715680411385913, 0.08098769737707992, 0.8165379397330746, 0.9088766622927882, 1.4939616668608882, 1.2954362938480994, 6.708388030529023, 23.20274349181883, 43.60624044172226, 56.84728353254257, 58.00199008757069, 55.71469522291615, 55.590383545044936, 55.88543207414689, 55.198487774018325, 54.14157375212639, 56.53694560450893, 55.21249848027384, 55.202645486400975, 52.11030375572943, 52.89289113013975, 54.83795527488955, 52.011942478918264, 50.9786803491654, 50.37768302425262, 45.85184443381525, 46.12733994760821, 42.99438599617251, 42.718855181048, 42.25156361056913, 41.94752500903222, 40.1524091535999, 39.05255302306145, 38.70713733857678, 38.69335020742109, 37.31398205603323, 45.061000470192205, 40.6240741668209, 48.411300797616285, 52.023489936705566, 54.83336217941777, 52.17017089166949, 53.780154797338675, 50.36335460601315, 56.75271126531786, 46.59179172208233, 35.198898853794226, 52.04837737544891, 47.147179726631414, 54.32449740748252, 50.687562034976104, 50.54740790397891, 50.76137319687874, 46.136126056794204, 34.3251242176179, 36.999811972341234, 36.7016294694716, 44.86006921337497, 51.53550001882738, 50.517621424890336, 51.24937095949727, 51.607063662621286, 50.41664000480406, 50.939844962089296, 50.43138027191163, 51.88872121995496, 50.83299567622524, 49.62341908485659, 50.68236489449778, 51.99982627745598, 48.82488335332563, 47.53357241230626, 45.53578769007037, 43.056586942365094, 39.53975454453499, 42.64771123086253, 46.342293677791474, 47.16317907456429, 49.28570301302018, 52.163942167835856, 52.40381471572384, 53.095748270711596, 47.00775515648627, 29.526576957395, 14.750232869578948, 3.114373683929444, 0.5449481873262314, 0.5994960377293249, 5.254549268753299, 2.7946821287755044, 3.5453661699448866, 1.4237596983871152, 0.20759352512897986, 0.3591989545572189, 0.12512091186738786, 0.11883983358500466, 0.06858991263734718, 0.35329713576263, 2.4983801572553577, 11.1325494704708, 18.35493322341673, 25.892852044874623, 33.03207958898237, 26.425174551625407, 10.405509721848274, 2.0178592902037407, 0.04153739833723634, 0.0519667201555304, 0.05083983929287042, 0.028164657546327482, 0.04583124837447559, 0.01178034468584003, 0.025829596655263055, 0.05418487411412982, 0.0536111202241192, 0.049607686458095435, 0.022203432463650263, 0.028411146335964723, 0.013071232524159695, 0.042057629494417104, 0.046919798027844205, 0.042959391590087645, 0.06198439611903122, 0.023596214783948757, 0.044440534491572654, 0.024768262275404507, 0.019010299471237006, 0.011311120620267767, 0.01963055106781183, 0.06102536129014147, 0.040271679360059, 0.06574933522290762, 0.06145372701388213, 0.06457404909475196, 0.0591511846399836, 0.024748803642127785, 0.027990983498673287, 0.039275791871571736, 0.02778100262906763, 0.06146264427732076, 0.02290880217427208, 0.055998093148152676, 0.02852899172613698, 0.04176956511312916, 0.027149414846433267, 0.009055323016289021, 0.031083184407062592, 0.024735575218895273, 0.19429943283959744, 0.005921924293356678, 0.08258544269108004, 0.027957086023243687, 0.08628679649724115, 0.09210523428215135, 0.015371948735968722, 0.018359274122743838, 0.010737937465760737, 0.016334967222064734, 0.05667683172730669, 0.07221261985720166, 0.05863053213444449, 0.033840080122313196, 0.10773854540480722, 0.20103055713397844, 5.5044140546552605, 25.542160772508193, 40.51822900772095, 45.308078412086736, 26.492290227643906, 26.702480239252893, 18.40408444404602, 6.975980458721039, 0.31313954221625484, 0.16232028753767092, 0.1885442892389913, 0.26318120199345774, 0.09343956026338762, 0.12590175464508996, 0.30254328983926004, 1.1177599117640526, 1.9609423895036022, 2.326371232348104, 8.47030347393405, 22.711447015885387, 46.23000014212824, 58.91304685223488, 60.43566780705606, 58.20115627781038, 56.35989373730075, 56.862243452379786, 56.46863360558787, 56.11345906411448, 57.71027165074503, 56.38183939841486, 57.26285080755911, 53.62570754943356, 53.4904367693009, 56.355037843027425, 55.07429376725228, 52.98475696194557, 51.82574756683842, 47.53000697781963, 47.29521782167497, 44.90583150617538, 45.42350984388783, 43.08737754821778, 42.827116520174094, 41.55225207728725, 40.719976117534024, 41.267797870020715, 40.508940835152906, 39.945323697982296, 46.145610347870864, 41.7747171463505, 50.40397074914748, 52.62455394191127, 56.71378958609797, 54.87233092707973, 54.48077640225811, 52.57111557068364, 55.82222700119019, 48.85930999632805, 38.21365610245736, 51.99811612406085, 48.91614514012491, 56.20047684638731, 53.58622497127902, 53.50970737395748, 52.4892282485962, 47.71394652705039, 36.25367518394224, 38.87382238141952, 38.295186488859116, 45.98007063711844, 53.73227050227504, 51.86977617202267, 52.89544067075176, 51.38450053430373, 51.76452721318891, 51.68811551986202, 52.75428241299045, 52.7920626824902, 51.829599334347634, 51.962304884387606, 50.93566371548561, 53.64962616274434, 50.495016805587284, 49.61625291455177, 47.255076285331484, 43.52117207742507, 41.02840777366392, 46.05210496533302, 48.67056946600638, 48.97359217366865, 50.183274669031945, 53.698342000284505, 53.37343638943088, 52.700498873187655, 48.072156983037154, 32.15564558582921, 18.215339991354174, 3.640148774270089, 1.2560983530936705, 3.512878403548272, 7.154568424147945, 6.800587754095755, 3.0064864408585334, 1.6126756321999336, 1.1121994617485231, 1.0739085486819668, 0.20581197233930712, 0.11322067825183754, 0.20910625766602256, 0.3339575219058222, 2.997103886258218, 11.920208469513925, 22.72614217573597, 31.543991181158255, 38.7430231032833, 30.518938572176044, 12.332569206914595, 2.465505301952362, 0.04088161175229377, 0.08841855872061946, 0.06114702371339645, 0.012203506757355025, 0.008368943667700215, 0.08760579305911258, 0.016755089839740146, 0.04168969278614368, 0.03965043184918262, 0.022887382355909196, 0.013087012020180063, 0.059609715075742815, 0.05932128297225122, 0.023035616538817846, 0.07740561579985004, 0.08851244279574003, 0.01365061620280387, 0.032538653786985144, 0.04298576799732062, 0.030442796189398057, 0.05911086543252873, 0.0032447055526708644, 0.11175414081662895, 0.051052800244501526, 0.041526021931560776, 0.09585385571324057, 0.16695798464840458, 0.269270068815639, 0.12082070713081669, 0.1741197729302991, 0.18292789948323082, 0.17254331719971475, 0.16572666684946707, 0.2720389250786074, 0.19551274757231438, 0.15013599618067666, 0.10113728833535027, 0.14960250787196622, 0.1236116803521591, 0.09904038311252672, 0.14136036707749292, 0.15659252391947856, 0.23449185274301038, 0.1183439065672217, 0.21463284659529888, 0.18827709309276075, 0.2055415892673116, 0.2203589401418163, 0.1481383453093229, 0.1273825642983279, 0.17821014618440983, 0.10075338635473483, 0.12495020449522043, 0.10394907616559537, 0.24308294658699345, 0.10050413198769094, 0.16955532914688512, 0.1885833597231296, 6.371446136505374, 30.82469124947825, 48.135483649469194, 53.96915420409172, 38.27309177767846, 37.85029165206417, 26.088393965075095, 10.69734484918656, 2.9229813862231473, 0.3249537211752707, 1.1811224923979853, 1.1036484496247385, 0.3829952695917699, 0.7219820974334594, 1.9931564480066302, 3.508895236638285, 4.499222857336845, 2.7197575040401953, 9.474119390210799, 25.40337358751605, 47.63107861241987, 61.55950923119823, 62.788195610046394, 60.67787808756675, 59.621344535581535, 61.04967171146024, 59.30479357319494, 56.73089896478961, 60.12605943987447, 58.724051367852, 58.87922033186882, 55.38429829382128, 53.260911433927475, 58.508940742861846, 56.131756920968336, 54.23251390457154, 53.85595067854851, 50.15062485971759, 50.392203638630534, 46.17095278155419, 47.606069580201186, 45.86634543634231, 45.52857052895331, 43.88834514925557, 42.32663385329708, 43.32066051421627, 42.1107191424216, 40.816121255197835, 47.61910361628379, 44.42937727897398, 53.16286002435992, 55.102075915182795, 59.72347913249847, 57.0348826531441, 56.606500994774606, 54.72496355733564, 56.4101706781695, 50.15693595332485, 40.955800779404186, 51.51818667688678, 50.89122326143327, 56.23376600203976, 54.440277930228945, 54.985083380053126, 54.92118012520575, 49.4303168789033, 37.58115822269071, 40.55480903194797, 40.91060723027876, 49.021594139837454, 56.36227069362518, 53.717326271918516, 55.156326217036096, 53.83717037016346, 53.716879121718875, 53.777891589749245, 54.16366454093687, 54.379767525580625, 52.772207644677934, 52.944674261154674, 53.543753547053186, 56.629109536447835, 52.58528709411622, 51.08322720373831, 49.60883571255592, 46.45615616152364, 43.38619547505533, 49.087199703339614, 50.57892807068364, 50.17167622043241, 51.96402680489325, 54.63345073884534, 53.47919917875721, 51.20190635804207, 48.96875981361636, 33.54684360565678, 17.311306230483517, 4.641866222504647, 1.9325736020841908, 3.0094730805966163, 11.099666280131187, 6.952154511405576, 6.8873309704565235, 3.266302279887661, 2.3045640799307057, 2.060891490790152, 0.2798973630753256, 0.2054970795589109, 0.37227917041990066, 0.7947027791411647, 3.9687154273833003, 16.439752636417268, 27.39523356960666, 38.134698790888635, 44.10633479395221, 36.33649210776053, 14.095439257160312, 2.524478872937541, 0.12142600852154917, 0.12483339140852615, 0.25249856554212113, 0.20725229424574684, 0.1761532460729922, 0.14535966779916518, 0.16433914372276875, 0.13547483531217422, 0.14385091891932872, 0.12416616713087406, 0.19203446324794524, 0.21401197829794502, 0.11246542281080639, 0.1256639226489971, 0.31282063513513536, 0.12893302666564144, 0.1465744840642137, 0.06679994820226585, 0.13497199052043501, 0.0983406154198512, 0.07642365962026582, 0.11148248603867908, 0.29665277850243355, 0.18410461053492563, 0.10757892332490414, 0.12298806179915706], [0.05696254038822748, 0.08486924272391104, 0.047841355835478154, 0.021388805208487377, 0.03881687073097114, 0.03610715262531754, 0.009447691226077658, 0.04667518615362145, 0.07437648882548656, 0.08244530988797065, 0.06765066585954159, 0.09081912587486929, 0.02536138861380037, 0.08161218927031563, 0.04358627367764712, 0.009360824516343494, 0.05393271244341328, 0.035519072891122876, 0.03519117959865159, 0.04111064522857628, 0.012287013213931313, 0.02380837134325937, 0.07506860329979852, 0.05031816405995239, 0.022044365797492287, 0.012473838118415688, 0.03168925188571936, 0.09314587279673546, 0.04330141920476191, 0.047258845560493014, 0.06278764696851855, 0.04383617155854741, 0.8990648533067397, 13.058622479438784, 30.24819697103193, 39.8607809312882, 25.329917400114, 20.228925981829246, 16.85908636739177, 7.619977256944103, 2.010952976922835, 0.2385625528592256, 0.045422341284011646, 0.030007813381211414, 0.039208920056661295, 0.07420624110607371, 0.08781502699299205, 0.2805794571195879, 1.8641831557596884, 0.8349797598296597, 1.385195322575108, 9.804543775896873, 27.949823371825683, 45.849412564308416, 57.304490689308416, 57.13957463541339, 54.94318069950227, 55.37053861925679, 58.307268158082046, 55.499949378352014, 53.30889378824542, 55.3090044759935, 56.817512742934696, 55.94610329597227, 52.678251189570275, 54.63896166893744, 53.805862011448035, 54.22057420976701, 50.63282143685126, 51.38190392524966, 48.093726096614716, 46.347012289108775, 47.08515528709658, 42.90011967382124, 43.94810638120098, 41.09718653463548, 39.396074202752885, 40.27074706169867, 41.518229438412575, 38.188521554393155, 38.23741389859108, 39.331766943777765, 39.31945462380686, 44.69990314975862, 50.58421934804609, 50.69040183098086, 50.97774290269422, 51.98770223125335, 56.16304959020307, 50.1389911097865, 37.182892522504254, 45.179930656187, 52.703158240164484, 53.75632639854185, 50.27363038832142, 51.28873586654664, 46.07572940088088, 39.45306231898647, 35.654356633463216, 37.456352326177786, 35.48554958835725, 43.084980980042495, 50.243255553707, 50.68689915441698, 53.342936038970954, 49.861475575354795, 48.869072775686945, 47.89962760863766, 49.86779843607257, 49.94787754551057, 50.94189243931925, 51.58820098446262, 51.35127021420387, 51.13027995632541, 50.05427575880482, 50.388155752612704, 49.25605773925782, 45.1581536569903, 40.81257543256206, 42.83109380352882, 46.54129512848393, 48.47502362343573, 50.048439271988414, 52.05269198263846, 53.87139697228709, 47.401702327113, 33.70848055808775, 15.141915852023711, 4.945307152886545, 0.24193891684614846, 3.240225382389561, 3.893835664756837, 6.685907456182665, 4.923473769618619, 2.8251182504238623, 2.2341898948915544, 0.6885645454449039, 0.5700341347725161, 0.4917537078501717, 0.30569647709208153, 0.07138296961784363, 2.2154799440214714, 8.42283396951614, 15.644545035977519, 24.36385919970851, 32.05070453305399, 29.48016355114599, 17.395246913356168, 5.341491055104041, 0.751393132152096, 0.03234977863969342, 0.03671006765216589, 0.04781273479062704, 0.05291859972320738, 0.041538064833730466, 0.05213499136809861, 0.09977031168678116, 0.03267206033811935, 0.05084485716877445, 0.027479123767285098, 0.014450073959456097, 0.05111834672730296, 0.041404554860726486, 0.054225706600493966, 0.08467409714695909, 0.04056976034095691, 0.029825628096718463, 0.032913669147678924, 0.03638017103977261, 0.021569852852412773, 0.02690228828859906, 0.03309093040203856, 0.030525367061096816, 0.021051828028453935, 0.018495971021512826, 0.03345576062377903, 0.0513731207578413, 0.03907927116679569, 0.05129465037175725, 0.006161055287286159, 0.05463716476374576, 0.027760798975284544, 0.026461718784224604, 0.06988795669448954, 0.037167138690429355, 0.05118645960465074, 0.03154099280495317, 0.04284021512214695, 0.053953948400674336, 0.06544820904251068, 0.021268719011136604, 0.04416846602614369, 0.09847945353436856, 0.07228767349114341, 0.05937509298805268, 0.07081304616745442, 0.012614731263789921, 0.05654685341963365, 0.025657780370825244, 0.00658220685680487, 0.029753219381335284, 0.06357267258628722, 0.022825482451627334, 0.04645551427177364, 0.025614931158000426, 0.01882304843034475, 0.044643268169414614, 0.009787766274154909, 1.259826198220253, 15.882646633732705, 36.156063079833984, 47.2356919319399, 31.4381891681302, 21.935290367372577, 21.70800078299738, 5.260765244883876, 2.9495907454721393, 0.35512116046682485, 0.10942269777578693, 0.09399785449908626, 0.05884577602808995, 0.023646931719755935, 0.026610286215380318, 0.08408187287709407, 0.5847937072957716, 1.523932497347555, 1.7967154470182236, 11.459371159153601, 29.57752266237813, 49.095719091353885, 59.41855799767279, 57.054722001475675, 57.42780608515586, 57.411743979300226, 60.0141110727864, 56.891284681135616, 55.257746942581676, 56.56497878413047, 59.36484898290327, 56.66508943803849, 53.04072133956417, 53.624444546238074, 53.75071348682527, 54.2773622851218, 52.37015293490503, 53.206657209704005, 49.30605619184433, 48.08303763789516, 48.17549574759699, 44.387968817064845, 45.42725962977256, 42.19950983601232, 40.854933108052904, 41.2381172949268, 42.7061741582809, 40.30500504278368, 40.28529121029762, 42.23222240324944, 41.53660574266988, 49.10553678389519, 52.54981317827779, 52.93270318738876, 54.058274376776914, 53.11645054048108, 57.19536250637424, 50.65145269516976, 40.12434851738715, 47.18107684966057, 53.69519625940631, 54.0727283108619, 51.146851970303445, 52.984015633983, 48.93699253759077, 42.113025496082926, 37.177291377898186, 38.473289551273474, 37.468531285562825, 45.467801247873616, 52.147146578758, 53.526036200984834, 52.292074234254905, 51.99321708371563, 49.47635765998594, 49.83554086377544, 50.942574931729226, 52.09754820792906, 51.71581137564875, 53.77660505233273, 52.861527858241914, 52.11446146811209, 52.7553100739756, 51.951683105960974, 50.63372750436106, 46.213800753316576, 42.15511645040205, 44.350015963277514, 47.82553011371244, 50.813226930556766, 51.89087852354973, 52.235721541989236, 54.88472169445407, 48.34999415182298, 35.504780969312115, 15.49342493857107, 3.268261503788733, 1.3802471300286632, 4.978007953013144, 5.822257438013631, 4.90762984560382, 4.819807487149393, 4.837385098780356, 3.2422299586957504, 3.5202478016576464, 2.6219752671257144, 0.3974914610866578, 0.2999237594344924, 0.18927306868135932, 1.788634874166981, 7.556445646670557, 20.176017130574873, 26.848745422978556, 36.45421420374225, 34.963144794587166, 22.24019189034739, 7.986589429839966, 0.9075816672655844, 0.06572914114522357, 0.04855755994456911, 0.0500625396718181, 0.06121044813264763, 0.041106561979939865, 0.027575782995911378, 0.04857347925163565, 0.04546257622179486, 0.010726224939008395, 0.01862242149429456, 0.04514703609710259, 0.026118584172499758, 0.008871784628999811, 0.19775550061416244, 0.03106740299582241, 0.05880976989564877, 0.09785895295921834, 0.024221384664997462, 0.027400967477250005, 0.026337514864280823, 0.04991289588712877, 0.047923982248551426, 0.0021686503145423148, 0.012639805321551621, 0.03091067289783349, 0.028731359596995097, 0.12943792457301773, 0.15470125201729037, 0.13277455924018738, 0.11794449130613958, 0.12924286326573742, 0.17332025292900302, 0.18474892112276248, 0.17246601892815483, 0.24990689009428027, 0.13411492199426697, 0.2170883728972366, 0.18216297601259526, 0.136325775134948, 0.17042546713304135, 0.18521474854600045, 0.09507651395735242, 0.2128070598888782, 0.10915909458192126, 0.10751784313470127, 0.13244016186123894, 0.13724570883618248, 0.1852859640794416, 0.1407821085904875, 0.1658942102785072, 0.13999529032697602, 0.16071108920920282, 0.1234788483669681, 0.12122426692756916, 0.23117092287828847, 0.11168782058502398, 0.14273515782288967, 0.1046184225067977, 1.4760473442654458, 17.037365936463882, 42.38165686207433, 55.96231052952429, 40.120535973579656, 30.878251214181226, 25.617299656714163, 12.774005493810101, 5.760827727856175, 1.155249190426642, 0.30355351466325026, 0.21205272375335618, 0.2598665540497149, 0.24294822236462948, 0.48782732337713247, 1.6755888563010002, 5.036216416666585, 2.650023645931675, 2.1844444351811565, 12.2020140963216, 29.87111403096107, 48.904354495386926, 60.046403946415076, 60.59800294137771, 59.87359608373335, 58.336046588036325, 61.38990986731745, 58.782035766109345, 56.48306792782199, 58.378302281902684, 61.228806357229914, 57.90616266189083, 52.93549983732162, 55.02427962518508, 56.237013724542436, 56.21510728713005, 54.330953628786155, 57.260277732726074, 51.144835872034875, 50.45907220532818, 51.93830782367338, 45.697075551556004, 47.27496270210513, 45.261068805571526, 43.41720573363766, 44.22574350910802, 45.169897233286214, 41.8684970948004, 42.594759233536266, 44.61150077081496, 43.345041967207386, 49.6818624004241, 55.120718940611816, 54.28605033505348, 55.7408142858936, 55.591422973140595, 59.00609723983273, 53.259715111024924, 44.35325584103985, 49.41228182085099, 55.81850859426684, 55.81649641836844, 54.79344029580393, 54.73403992191438, 51.25483874351748, 42.65270048572172, 39.563163249723374, 41.04791764290103, 40.36345228072136, 48.385640651949, 54.42336859241609, 53.65094407912224, 55.52597038207516, 53.62027898911507, 53.414429080101755, 51.30840263059063, 54.675396565468084, 52.784366992212114, 53.65418787925474, 54.84856136383549, 54.79997104214084, 54.56447193699499, 53.57664262094806, 53.56080016782207, 53.069950842088275, 47.967127676933046, 43.71486263890421, 46.616596791052054, 51.37862090141543, 51.823072510380904, 54.047829105008034, 54.16402147662256, 55.95744286814044, 47.60114308326475, 37.939196094389885, 17.45114068831167, 7.628546655178071, 1.0288323029395074, 7.036091271908053, 10.003474623926225, 16.15216935834577, 10.12777747646455, 6.895125700581459, 3.563613526282772, 2.7652685200014426, 4.484132518691402, 1.9396103341733257, 1.3110550493001938, 0.7057060998293662, 2.494574477595668, 9.767012576903067, 24.107136149560255, 35.20740255232781, 43.53078188434724, 42.13804629541213, 24.336108430739372, 8.6291879030966, 0.9861282331328239, 0.16946206560298321, 0.11766125327877461, 0.142651240551664, 0.15227906586181733, 0.15405188524915328, 0.27427985483119566, 0.10924250623511692, 0.08089329236217084, 0.08620838739819105, 0.1514141372735462, 0.10050705078268245, 0.09994501803791332, 0.11699424350574134, 0.32689743945675515, 0.13527752170639654, 0.19240452968064817, 0.23898059171774697, 0.10449060073663151, 0.1997751841742185, 0.08784662811986862, 0.16362407725424538, 0.08499426827315362, 0.0850879378436554, 0.0706397800616199, 0.0905435257441094, 0.11194358669942427], [0.09633688947125789, 0.08440634175654381, 0.05174240578086146, 0.028639434791740873, 0.08982814517953704, 0.040302219455160444, 0.06560069118295947, 0.0159853017107854, 0.025820242721707593, 0.02600422639760279, 0.06906128653715696, 0.029147061887347413, 0.023975489593501535, 0.08013296541908095, 0.08471476875485913, 0.02226136211726454, 0.004347584880663142, 0.004878149127527591, 0.05059476393545347, 0.027727449252720804, 0.04684358377069716, 0.034552840666184505, 0.033312980986891255, 0.052326306505429174, 0.038754128129972566, 0.06153057712400633, 0.07067060743969295, 0.013135875980820388, 0.011526310887758531, 0.05861494224518538, 0.02914044288768163, 0.03861515211962885, 0.12992799101817992, 3.6228668112908644, 12.736298768751084, 41.40251951832926, 36.698660235251154, 26.302108226283906, 23.208668231964115, 20.56969758002989, 4.167918880139628, 0.9283512301983373, 0.5140602576636499, 0.05479469159317594, 0.09933261501212275, 0.04191424847850877, 0.05280865078431465, 0.021157203422438715, 0.37761546310878574, 1.722909065504228, 0.6656659322400248, 1.8803717580533799, 11.374570496620672, 29.681249741585027, 44.47519448495681, 55.28996136880691, 59.15348814379785, 58.51827206150178, 56.669576629515625, 54.21036820257864, 53.07614818696053, 54.0760152570663, 54.66557887292678, 56.28701217712895, 57.39039844082248, 50.75670557637369, 53.00306658590994, 54.5375644776129, 52.36004498697097, 51.467168408055464, 51.1229843478049, 50.590451994249904, 51.37045452671667, 50.618300822473344, 47.48358572683027, 45.252208171352265, 41.06196365048809, 39.95014821329425, 39.05326297206264, 40.61657459505143, 38.480102708262784, 37.81337038163216, 39.16921607909664, 40.69566526720601, 42.52660020705193, 46.6509763656124, 51.01293048551006, 51.38674805241247, 53.424250695013235, 54.55258715537287, 34.79633031352874, 47.52876358647501, 53.26193909491263, 51.387830626580026, 49.611047929333104, 46.304117248904326, 41.28387958772721, 38.40761730747838, 34.67765508159515, 35.491515513389345, 36.379944124529445, 37.148395276838734, 47.57060743147328, 51.73856112264818, 52.05615151313044, 48.26718115037488, 49.09800191079417, 46.99156753478512, 47.484644766776796, 49.102445956199404, 49.657504481654016, 50.04021798410724, 53.329105761743364, 51.28873978891681, 50.72290259022867, 52.14042755865282, 47.8378620455342, 46.74118303483533, 44.97543396488313, 43.04113672625634, 46.48005908535373, 47.66407359030939, 51.41408697251351, 52.34592445435063, 48.54970555151663, 37.35121319370885, 17.928589236351755, 3.5006567883876065, 0.15599350444972515, 3.066608285711658, 1.5341702512195035, 5.671412396815516, 4.538140614186564, 5.218347753247907, 3.2990410779753043, 1.6147158775598773, 2.981323210462447, 0.9589866572810758, 0.3753282922890879, 0.1891574506918269, 0.40816640601523463, 3.6441368441427913, 19.909986296007713, 25.728394908289758, 24.965929292863418, 33.51160503202869, 23.1228095100772, 11.747787940886713, 1.7981328935392442, 0.21784764263899098, 0.07905358583816598, 0.011109750578931023, 0.016858253154843565, 0.0689246317732238, 0.049585274555870605, 0.03551743346296492, 0.08888347449922755, 0.07004963189002968, 0.01916642627498556, 0.08094136437941944, 0.04124906965561452, 0.019109057780775814, 0.03686981230613686, 0.014845211577091007, 0.011203571451797841, 0.04876321241740258, 0.02624202008929945, 0.014797077315198559, 0.021771033286988255, 0.04975580955825506, 0.023081290700863448, 0.055176540458154295, 0.02641819924446604, 0.02920124154057234, 0.055845480772756764, 0.030076786192254196, 0.06631525203345284, 0.027277326631930568, 0.04787164695200421, 0.0547875439928424, 0.05126073182890973, 0.023465943447644674, 0.032935479670883186, 0.025451620364741936, 0.013462021635214408, 0.04393248413238795, 0.05569050884655407, 0.041790827883467566, 0.023135767213159034, 0.037131427501839016, 0.04069156066003827, 0.03640663554711688, 0.014877651570244663, 0.030457453366609353, 0.05307216970850864, 0.00580191997165281, 0.06454610986815346, 0.005639805233166103, 0.01121961429054218, 0.0334082746637925, 0.025764080815978592, 0.038333752703282147, 0.042930540718859246, 0.0780593416082763, 0.021240927256463517, 0.12068204521652191, 0.1312662700131055, 0.021497256445488142, 0.3615025809455303, 5.131132381577646, 19.424800872802734, 47.86696603221279, 40.8066055851598, 28.0616658349191, 26.09570134070612, 25.525616215121364, 5.323495711049726, 1.1495166464198021, 0.2091076059807693, 0.04279251465754163, 0.032344776085547866, 0.1120352108151682, 0.056742247975161, 0.04065073200411374, 0.24269679230788063, 1.2503041543306843, 1.1607112134656599, 3.074596928011987, 11.561234131936105, 29.09878169336627, 45.51769771883565, 59.57074596035866, 59.65050343544253, 59.716497313591745, 57.66079487339143, 56.25528020243491, 54.01617165534727, 57.153883441802, 55.90816220929546, 58.573804978401434, 56.93371295928956, 50.3210400765942, 54.16890874985726, 55.854727760438, 54.04855082111975, 53.26021717440698, 52.294890496038626, 52.87658583733344, 52.029879477716264, 51.62860924197782, 48.624379634857185, 47.69665279696065, 42.97802186781361, 42.086161182772734, 40.79559941445628, 41.83259564061319, 40.389316389637614, 40.33452480070053, 41.195787076027166, 42.26177746249784, 45.320935941511586, 47.77958346951393, 51.26010256428873, 52.676592026987386, 54.98136889549994, 54.77793516651277, 39.12158673809421, 49.23366492794406, 54.885694442256806, 55.29892398465065, 51.60479653266169, 49.02559887978339, 43.5970817073699, 40.93998186049923, 36.04337338478335, 36.361795317742136, 37.04386018937634, 38.81437101671773, 49.19601801903018, 52.4955040408719, 52.986839740507065, 49.83399544992755, 49.3776669040803, 48.46402529747256, 50.42926219201858, 51.33378821034586, 51.06243471945486, 51.118430476034845, 53.72218608856202, 51.97662545788673, 53.45741825719034, 53.29782878198932, 51.47079267809468, 49.12098700000394, 46.35403725408739, 44.104020595550544, 48.415007437429125, 49.259313306500836, 51.96215975669123, 54.55199095510668, 50.20495753134451, 38.922412703114176, 19.875106619250392, 4.431548733865061, 1.2088849059035702, 3.0234114681520774, 5.807127875666465, 9.086161678837193, 5.68120361335816, 6.072815012547278, 3.9288352189525484, 6.00916475057602, 10.597463653933618, 2.33348150887797, 0.2968345864886238, 0.1995567112199722, 0.45063798345865747, 3.8212862803090006, 18.711680635329216, 25.76134870129247, 32.508876592882224, 39.18678829746862, 28.652288490726104, 15.189516755842394, 2.7040008527617303, 0.34074245621600463, 0.05428502095803138, 0.013453965263080694, 0.09412709353191238, 0.07448605472041715, 0.027895927309028568, 0.07868040142761124, 0.08827066544683711, 0.025640108637631904, 0.05930699543246339, 0.029223461920816093, 0.031651962556005005, 0.03763935911739546, 0.0169062772915969, 0.047327058029270945, 0.0381123915975613, 0.06354264577009505, 0.04869108523933157, 0.02542066275172176, 0.011710336698489565, 0.017665841977202126, 0.1384169653418564, 0.03857073051133945, 0.014435910908955962, 0.03427332965657115, 0.021514614082632527, 0.018216134424531655, 0.18301912523325414, 0.13794071912284822, 0.1963160367261979, 0.13919852824220735, 0.12268541876467005, 0.10039121828853123, 0.18396999356487106, 0.13589897223057287, 0.1183587610120735, 0.16248613025151915, 0.16626850551655217, 0.08799855867701192, 0.08420981722132814, 0.21608357197575032, 0.17782429834046673, 0.09937158590483089, 0.11689012449595237, 0.15921917894194204, 0.12379417015660195, 0.12158298759811348, 0.17824921666854815, 0.07343493612302888, 0.13545657177605938, 0.1244757432610758, 0.1596271207616214, 0.08753405658588295, 0.0986046552838337, 0.1479483861476183, 0.1644902009396784, 0.15903358648140586, 0.28675216460420244, 0.08628229190024637, 0.39672525058830943, 5.428660829221049, 21.623181489206132, 56.155126402455, 50.512541955517186, 38.17635436211863, 33.79551795221145, 28.016129078403598, 5.975660354860368, 3.4386906941090865, 1.4403230096063306, 0.33235023879716474, 0.1936859955951091, 0.36869240804545345, 0.10248967100896182, 0.7121096755708418, 1.1489026729137668, 4.661600647434112, 2.0551499988763564, 2.9899676240259603, 13.803253077691602, 31.691992013685166, 46.905785299116566, 59.5576766229445, 62.92139537872807, 61.13519899306759, 61.80465736696797, 57.58031568219585, 56.413230126903905, 58.57714291541808, 58.87257191442675, 60.93797829843337, 58.77614436611053, 50.56808271715718, 54.541537838597456, 58.642905373727125, 56.192887060103885, 55.57489018286429, 55.95210844470609, 55.965330754556966, 54.46380038415232, 55.03859235394386, 52.07031519182267, 49.57575052015243, 45.20086042342648, 43.87784888667446, 42.275725410830596, 43.678427742373565, 41.55117734786003, 42.53780641863423, 42.56440401077271, 44.22593570524647, 46.66612848158806, 49.51146679539835, 54.26170418339392, 54.21265102201893, 58.033643614861276, 57.75522593528994, 45.26055889744913, 52.5673383282077, 57.32125882179507, 57.835842409441554, 56.00128712192659, 51.514162325089984, 44.98784434410834, 43.725315755413426, 37.88252961251044, 39.26392955164756, 39.472215252537886, 40.79133579807897, 51.36661452631797, 55.609975784055656, 54.7294036803707, 52.45404066578035, 52.357432688436205, 50.71465384575629, 51.5293771989884, 53.322327906085604, 52.24945375996252, 54.35681773770241, 56.07299589341687, 54.054257869720466, 54.05489721605855, 55.38439243070541, 53.18349169146631, 51.06385461745724, 49.07997469748221, 47.70607040774438, 49.851261723426084, 52.44082620066982, 54.278468393510394, 55.487876322961625, 50.62902458252446, 40.9720354695474, 20.912459781092984, 4.6430184187427646, 1.93489343889298, 6.119779511805504, 5.416458825911246, 11.920796825039773, 8.955657559056437, 10.075112792753405, 7.040758892413109, 5.90724882579619, 11.447193180361102, 6.302099612451369, 0.8425256033097545, 0.3897520731533728, 1.0623266475815927, 5.484527637881618, 23.18162545081108, 32.02515813612169, 37.43195518370598, 44.21122289473011, 33.13273937471452, 17.33990619259496, 3.0222739808021055, 0.36410596221685415, 0.1691576835489081, 0.1224835086313467, 0.19244828862288307, 0.18330821617236062, 0.09588360290734038, 0.12092350846937588, 0.17197939987865188, 0.11832035702442932, 0.09244302543060434, 0.238680821512976, 0.11340143669757152, 0.07388722677264484, 0.10394083305953011, 0.1607624324218881, 0.08432338975610272, 0.12344586828182783, 0.14809302354772247, 0.09866579676107054, 0.07900472475035537, 0.08209610402944588, 0.22966128533645985, 0.1583895976504972, 0.12952122897390397, 0.20651887231055768, 0.194517630002191, 0.15161353463847793], [0.04502401769822163, 0.0059927093811453355, 0.008636824505013085, 0.05541791944133659, 0.09018784644262445, 0.00959366544960968, 0.0423910730938998, 0.021641453345035835, 0.05639454364896782, 0.0756532509600924, 0.04339100169618765, 0.029148902413585497, 0.042969955942563476, 0.016644652519795685, 0.027291160264623263, 0.03183419380577342, 0.016613574247927438, 0.04488335246400488, 0.05132862254075947, 0.01842384958910125, 0.04551981065061785, 0.0510179853787826, 0.1435273999889051, 0.05770836145647111, 0.06266683107241988, 0.03169955768352074, 0.016795843802092057, 0.004101525100263497, 0.019707044947051236, 0.09432957057029971, 0.049381778620543985, 0.06900059705179545, 0.017226488637407462, 0.4278179402312925, 7.618645612270602, 23.356076786595008, 38.02647275309409, 31.575619213042724, 19.690743454041023, 12.050418411531757, 9.621665227797724, 0.9305253877274452, 0.2111976317340328, 0.1201890063502135, 0.04696315477391885, 0.02181733564113177, 0.06440867369453754, 0.11254174048982321, 0.08512546849106589, 0.8818275072882253, 1.056104297599485, 0.17227386875498682, 1.6606525932588887, 11.057730259433871, 23.833097796286307, 37.3062079183517, 51.719651376047445, 55.61422763332244, 60.84448860537622, 56.83057031323833, 56.72300323363274, 51.80120137430007, 53.67385856566891, 56.307879186445675, 54.79265582176947, 53.854499401584754, 52.79409054786929, 52.01508429742629, 52.33997029642905, 54.24961543852284, 53.227657579606586, 54.477556136346635, 53.05493993143882, 53.76907017923171, 50.08571355573593, 50.37992661999118, 47.44451107517366, 42.63574015709662, 41.9719966765373, 40.31285370549848, 40.20712229513353, 38.43728219309161, 38.1277326614626, 39.048210959280695, 39.31261793259652, 41.13204071598668, 49.01642053358017, 50.59871642820297, 52.90309321495795, 51.322507473730276, 36.14018140300628, 52.11085680992373, 51.97596257732761, 50.9105448569021, 47.391817954278764, 42.21839212602185, 39.58330069818805, 38.59194909372638, 40.83592530219786, 42.97000454318139, 37.67706017340384, 36.97355562640775, 40.03404378890991, 47.54463741856237, 49.78347924447829, 47.80192529001544, 45.02227490948093, 43.55173518580776, 40.07168285308346, 45.10583708363195, 45.87661027908326, 47.763744938758116, 50.055197515795314, 51.33989926307432, 51.39739336506013, 49.78380480120259, 49.86134613713911, 49.042359167529696, 48.03320784722605, 47.144273250333725, 46.286807829333895, 48.622010523273104, 50.58074020570325, 50.90391605131088, 38.48326413862167, 20.774082483783847, 6.56503128428613, 0.38492492249896454, 0.8777631963452986, 2.4449993958396297, 8.260912645247675, 4.255834394885648, 3.2552970897766853, 1.4438723868900731, 4.486989475065663, 7.080320898563632, 13.067151673378484, 1.8651969658751644, 0.42364849138163757, 0.3012396839837874, 1.1611012441496695, 4.742640247268062, 19.58880105326253, 45.022043489640765, 27.268152698393795, 31.382567997901674, 22.95020757182952, 6.784739417414512, 0.7825985286504992, 0.0848692350630318, 0.03366474940952274, 0.0730148901141459, 0.05212100643304087, 0.05526402769910713, 0.010462629406021969, 0.052226132848450256, 0.04510907261001487, 0.02207729225647786, 0.04408228113466213, 0.015163471313914465, 0.027613943750639598, 0.030133350294143445, 0.05710354270113092, 0.02661811371874665, 0.04355269221348628, 0.1084764259717157, 0.021948246660852627, 0.03059633744640216, 0.10935008796232362, 0.012610158676491871, 0.021698783534849365, 0.035681613766017466, 0.025696224578085448, 0.01928956341749478, 0.05818536993296397, 0.046368463700937654, 0.010347649184686523, 0.007399783071671283, 0.017653785668493762, 0.05060573048408955, 0.0768072475048323, 0.03647194071222217, 0.05622750200751809, 0.017649694758978103, 0.020512103764039856, 0.03926378727379826, 0.040198161732405424, 0.03565022714375969, 0.05363841210642169, 0.03221657893229877, 0.0691375735726568, 0.08215045030679434, 0.047314904044352235, 0.03500039306198878, 0.009618876445587845, 0.03847930174801619, 0.028629939131919416, 0.03434371398461442, 0.053716430500630415, 0.027394630014896396, 0.04607919656160859, 0.01853854061224528, 0.012558073316129946, 0.02010300515159484, 0.06301880633879094, 0.0612149527296424, 0.055348822141006115, 0.14348357975963624, 0.05075363907963038, 0.9611839200219802, 8.452906781627286, 33.91138476710166, 45.40525905547604, 38.06448444243401, 23.687164052840203, 16.45931447705915, 12.570042244849667, 1.5110315767026719, 0.9319870221999385, 0.08307157144431146, 0.08042797821784213, 0.11097100743603323, 0.04226999289746727, 0.0697467590291654, 0.17643996213953342, 1.6002558147714985, 1.2842913692997349, 1.708609084448507, 2.700369473426573, 11.403350887760041, 27.301545796855805, 39.854740481222834, 54.3165938315853, 57.56270816249233, 61.560693786990264, 58.16221498673963, 56.66473642472298, 52.880578810168856, 56.477784495199884, 56.816465470098684, 55.60765374091364, 54.165402150923214, 51.08274475220711, 53.18604123207831, 54.402109346082135, 55.535242865162516, 55.57323886502174, 56.375269428376235, 54.69603215494464, 55.133953017573205, 51.777839737553755, 50.54305799545781, 48.31548513904695, 44.29975078951928, 44.03744228424565, 41.61328023479831, 41.487815380096436, 39.71607685089111, 40.057126937373994, 40.511549211317494, 40.49445552210654, 42.918558736001295, 50.16117603548112, 53.4465846707744, 54.722515998348115, 53.82892554806125, 38.947535484067856, 54.16895581829933, 55.0214712081417, 53.03769719216132, 50.41625953489735, 43.40706248437205, 41.34689638691564, 40.36573510016165, 41.616586792853575, 44.10036102417977, 39.47099147304412, 39.85291657909271, 42.93228310923423, 49.95634202034243, 52.35109021586757, 49.60559975716376, 47.46378167983025, 45.79556234421269, 43.22030275098739, 46.9588706570287, 49.34217337639102, 49.686777130250015, 52.26690046248898, 52.88556414265787, 51.86192358693769, 51.16956641597133, 51.17779947096302, 50.878534393925825, 51.4942249175041, 49.1868475175673, 48.88925729259368, 52.320923266872285, 52.96313293518559, 51.3716547719894, 41.36858709396855, 23.91224926517856, 7.8912101349523, 1.5425635105179203, 1.8005593697870932, 5.652788002644816, 6.235404610633851, 7.569503216974198, 5.939427460393598, 3.6609861206623817, 5.0759534585860475, 7.917590525842483, 9.2760593083597, 2.316493478513533, 0.3031147914307733, 0.12214370267165285, 1.3906077031166324, 6.228527715129237, 25.037938125671882, 45.56564084945187, 30.585001091803278, 35.41129519862514, 26.2535963519927, 8.826375257584358, 1.1172170312173906, 0.11876253531344476, 0.00641614532909326, 0.02377998970088459, 0.029634761120823604, 0.032215613661514174, 0.028900804839307265, 0.07713832006218933, 0.006479709080585669, 0.014629373965304227, 0.0397291588747213, 0.03546011093403063, 0.02072139132407404, 0.03215660573914647, 0.016447204848631256, 0.05399608706694938, 0.045589325468867056, 0.05380674843646346, 0.005365120098670764, 0.01134810064198269, 0.09196223631020516, 0.020482383383017395, 0.023679791146048138, 0.015253793080187133, 0.02186661041642149, 0.0058703684912724124, 0.0990080388803636, 0.053998753052925876, 0.11124240940496807, 0.1444620885435612, 0.08660965659204992, 0.18228676049940049, 0.3816764339083626, 0.07373534984165624, 0.12123106978833677, 0.057883236346946615, 0.21107461333515184, 0.1656374329280469, 0.14693684365239837, 0.14639924911241378, 0.1320065407743377, 0.058446900858994455, 0.2657715291265519, 0.1392802545019696, 0.12074870252681356, 0.16843817377042386, 0.17063748962696523, 0.1696339297679163, 0.10647703608077382, 0.16545026232638668, 0.28229163298683785, 0.14238203725507184, 0.21292260126961818, 0.12151060761102747, 0.13757866596983326, 0.10876038412172949, 0.1084239719315402, 0.2942312665043339, 0.20933101254124797, 0.2098104303642627, 0.16503470559273997, 0.9972485202935435, 11.48945083541255, 40.6740883088881, 54.25260820696431, 46.829887436282256, 31.26836819033469, 20.813965143695956, 13.870905137831166, 1.7824365487021787, 2.691444120099468, 0.19726463743755895, 0.33887265009745476, 0.1643901192132504, 0.1679070603342787, 0.3297865715238356, 0.7237315358173463, 2.4349358197181457, 3.367951238347638, 1.5996501763020794, 2.412414060484979, 12.856342907874817, 26.439757923926077, 40.09312645081551, 54.27329086488294, 58.2342924610261, 62.38723524155156, 61.32599484535956, 59.1926137862667, 55.822348594665534, 58.27946639830067, 61.522862526678274, 56.593078644044944, 56.36852687405002, 52.106216646009884, 53.83819410877844, 55.38362756852181, 57.94823792672927, 56.03879674788445, 57.577103261024725, 57.55334154252083, 57.35958430074877, 53.76043312011227, 53.56904106755411, 51.87345143287413, 45.98766042340187, 46.74848648809618, 42.91950010484265, 44.45758696525328, 41.08601170201456, 41.834623505992276, 43.99820681541197, 43.158501886552386, 44.23385889299455, 52.79953087529829, 57.275696569873446, 56.59071345483103, 55.3126169789222, 41.9719966765373, 52.701585369725386, 56.55568276682208, 53.22107192008726, 52.29869519510577, 44.45765756791638, 43.15769387829689, 42.96239122267693, 44.465561143813595, 46.51182636137932, 41.94789763419859, 40.97419669551235, 43.94197963899182, 50.8080494019293, 52.56138024791595, 51.99320139423494, 48.90320131855626, 47.94865331342144, 44.44397241838517, 47.50458609673285, 50.41729896299301, 52.435287813986506, 55.141436899861986, 55.138922660581535, 53.68059327525478, 52.168245007914884, 52.7219150143285, 51.643184769538145, 52.97338601081602, 50.97415001161637, 51.13723431864093, 54.08149088582685, 55.26430122313961, 53.06986847231465, 42.28427225543607, 22.92329619007726, 8.13621755569212, 1.287124423730758, 4.061805528979148, 8.631334420173399, 13.906473190553728, 10.71443755780497, 9.56010558912831, 6.363448423724021, 9.983624489076677, 16.674366266496722, 18.321589154581872, 5.650164427295809, 0.8530806401564229, 0.6425275028713289, 1.6418742460589257, 7.501230932051136, 26.983986785334928, 52.46009288295623, 35.956116337930005, 41.35623162792575, 31.830537972911713, 9.826335483981717, 1.165437301801097, 0.3805741866029078, 0.1455304441192458, 0.12062415961296329, 0.1677643994410192, 0.14598965254281798, 0.1291520665249517, 0.22650808276187992, 0.11285691672275144, 0.07198117703439728, 0.16344813750155512, 0.06938237696886063, 0.14826641988850411, 0.11579843388209421, 0.11358951128298238, 0.11575531079283646, 0.1596499042164895, 0.21020380119162224, 0.09353941216343835, 0.11977888117994993, 0.12974941592303016, 0.14358854912702115, 0.1908131658790573, 0.08929954451178351, 0.18537524396613722, 0.10783223795794672, 0.18614119399459134, 0.1312993803331929], [0.02351567213002953, 0.062330583591134324, 0.07270280121555252, 0.038162961061443054, 0.015278183404476413, 0.01960829238317186, 0.1406553210390191, 0.031784668136688496, 0.09391456541995849, 0.04040718499210574, 0.05127133448578177, 0.027800459347124544, 0.034355764547663356, 0.08753982522795278, 0.008795601972979645, 0.07332123335330717, 0.05236225518127603, 0.024385903961956504, 0.03329498558154991, 0.05613292845326567, 0.04888899639369019, 0.011343435166523823, 0.027080742724900766, 0.030026335472000704, 0.055118179880082614, 0.04618145780818117, 0.006302737024417448, 0.03742939739998791, 0.05195273139003304, 0.05906617952390544, 0.04798730324593283, 0.08379016957816579, 0.032181017130853674, 0.12934107573763018, 3.110999464988709, 17.35166741955665, 29.620698152049897, 37.29733159465175, 27.12595501253682, 22.121314656349924, 11.51505018434217, 6.938149688705322, 0.9851325639793951, 0.05457700770949164, 0.16268459298918325, 0.021803157268873146, 0.025513083598906958, 0.0744982508401717, 0.09622150130810277, 0.5519792197212097, 1.3007614016532898, 1.2706999889304562, 0.7274963370253964, 0.6265368576972716, 7.930525522078238, 16.606505340145482, 31.388371144571614, 42.547035755649695, 52.917272583130874, 56.64643856786913, 54.5575136523093, 52.58521649145311, 50.106129492482836, 54.20548877408428, 56.060636505003906, 56.24773748459355, 55.8207521900054, 53.23460801955193, 51.93917858985163, 52.11300234640799, 53.778550547938195, 52.93284047034479, 55.16615175431775, 55.24101411142657, 53.71963654795001, 50.80012229181106, 49.47431410512617, 47.78409027284192, 47.16082957483108, 43.70754741853283, 43.51969726624028, 40.450697560464185, 40.63581774311681, 39.126834869384766, 39.04800307366156, 39.65649604797363, 45.49872521431216, 49.260776350575114, 52.65606234150549, 54.65219182352866, 39.24281151063981, 51.61250399005029, 54.605970613418094, 52.47548034114223, 48.26730666622039, 41.599453879940896, 40.34979458778135, 40.72459274722684, 45.39257803270894, 39.26692232008904, 36.946063733869984, 37.759735891895915, 36.88546703707787, 39.38376188278198, 40.940844781937145, 41.62622013399678, 42.291916954901914, 40.4198088953572, 40.86965376330961, 41.55648431470318, 43.33562043405349, 44.58083175843762, 48.137546816179835, 48.9560160329265, 51.17543820411929, 50.852878170628706, 52.62643275722381, 49.693637355681396, 49.56708992681196, 45.67221949177404, 48.165897707785334, 45.41211928090742, 49.020990094830914, 41.164996470174486, 26.832377372249482, 10.863026745857733, 1.4118605755990552, 0.5782396718859673, 2.315959300725691, 2.5661976923865657, 6.302179040447359, 9.9120637870604, 6.462327943694207, 4.720891685255112, 3.269621830794119, 5.424176089225277, 8.520809873457878, 1.69933843997217, 0.4991849139332772, 0.32703263865363214, 2.7587255162577478, 7.729297636016724, 14.719025511895458, 24.7805384666689, 34.25658472122685, 29.911847845200572, 15.485834171695096, 3.2237207841488624, 0.0479892491092605, 0.036461790047225454, 0.10199755910904178, 0.03427400381394452, 0.05765299245174374, 0.05650698620405409, 0.09785368993517854, 0.0674263246717953, 0.061614911913150744, 0.005371179854151823, 0.05526716865959668, 0.022753380171413866, 0.014423069360125211, 0.04488165557925259, 0.023699096561740005, 0.023385477402517875, 0.05851227880245256, 0.04127582910680964, 0.06035479686913952, 0.06334183114250341, 0.06330328542859325, 0.015631872792578032, 0.011406502397280308, 0.044106899370108886, 0.03919956229266621, 0.04588469832895264, 0.09020717484095404, 0.004715870158942116, 0.041651970616752104, 0.04908878446346329, 0.10595438791619194, 0.06157228678104378, 0.02426962139114978, 0.013956089932171088, 0.018745326895206686, 0.017631101805055817, 0.029077570051735932, 0.047435202831101995, 0.03243962543145303, 0.04199041677038035, 0.023201298374201984, 0.059191147616553696, 0.028328715275312145, 0.16639903157709107, 0.058087739687893665, 0.07531467840195664, 0.03215777019279138, 0.03567136350959059, 0.026361357435704242, 0.024948419342117927, 0.029616099218988133, 0.02780668189628951, 0.09097144713685398, 0.01859022090361724, 0.06699094158266822, 0.03841644423382898, 0.06498202921882754, 0.06517841585821683, 0.05059495162699492, 0.031247766906275388, 0.03971560677934078, 0.21372946039322885, 5.198266688854464, 19.517292322651034, 37.216887704787716, 43.473028905930065, 30.35617393832053, 21.687190648048155, 14.909065327336712, 7.667089335380062, 1.1684743194810807, 0.12683768426218342, 0.16617282113480955, 0.059838265916633035, 0.10112722960090446, 0.08420404857925831, 0.567157443973326, 0.5393678190246706, 1.6053368776075303, 2.7265277601057485, 3.036740907738286, 1.566786965535533, 10.125897680559467, 20.721318760225852, 33.40910565468573, 44.81893531737789, 55.59144258499146, 57.26591417866369, 57.18371306696246, 54.247748390320815, 52.674164079850726, 56.431359321840354, 56.76026182789957, 56.29336249443793, 55.69486764169509, 53.41766111312374, 53.01940718004781, 52.871384774484945, 54.327886335311405, 54.81096152336367, 56.92715083399127, 55.22730542767433, 56.252110927335686, 53.666943427055116, 51.35067009156751, 48.65658621634207, 48.81774071724185, 44.563973411437004, 43.879472747925796, 42.376993163939446, 42.62274534471574, 40.78332239581693, 40.34240092000654, 40.78715062910511, 48.251950586995775, 52.074574885829804, 54.9167949153531, 57.53316487035444, 41.88726171370476, 54.410864076306744, 55.11961283222322, 52.351353014669115, 50.431494020646625, 44.41742973942911, 42.575206218227265, 43.281950642985684, 46.99849444050943, 42.157010955195275, 38.65480899810791, 39.118327248481016, 38.729196748425885, 40.46291966592112, 43.48139924387778, 44.45242904847668, 43.348662314876435, 42.49348755805723, 42.822484201000584, 43.20477800984537, 43.93963798399895, 46.959839482461255, 50.53487200890818, 51.07405277990526, 51.87075676456575, 51.73973391132971, 52.71140306226669, 50.593640881199995, 49.95866406348444, 47.92287941901915, 49.69193504702661, 48.944880424007295, 51.59970921854819, 45.11126956632061, 30.600084566300918, 12.488585402888637, 2.069762666379252, 2.4425072198913944, 4.463858277566971, 5.199400253834264, 6.70124049148252, 8.584530738092239, 8.101639411141797, 6.240281097350582, 4.775045398742923, 6.639357747570162, 4.883371947273131, 1.063469895912755, 0.10173761781545416, 0.7273106985995847, 3.0538640147255314, 10.346537866900045, 21.670638245920983, 34.58669923966931, 39.074690880314, 35.41787693577428, 20.537902847413097, 4.172089340225343, 0.14799560780727095, 0.04530395771707258, 0.04407959982692715, 0.046429245116850065, 0.03657836181622359, 0.012075936838593936, 0.1102104200230491, 0.025355231182108966, 0.043019533322583285, 0.02778367436070356, 0.04725278580501195, 0.023725978587003007, 0.04369036204391911, 0.07629639709428435, 0.05267029147474997, 0.018290395157471783, 0.0922692537067398, 0.02918441824975514, 0.04805050933012559, 0.050128859903423056, 0.04472605163051237, 0.03053113953360627, 0.011547823594282232, 0.045872977183711146, 0.07418765581303066, 0.052296463550338824, 0.07714472455723632, 0.024567687050289205, 0.08546866055938505, 0.14724533193774764, 0.16254205466999164, 0.24976576137686932, 0.08416048881988372, 0.16991364379082957, 0.22144991063302566, 0.1411440238476761, 0.250780260971477, 0.12836074366444541, 0.1350245901173161, 0.1349089721277837, 0.11352818594464373, 0.17816755169581983, 0.12005054361877904, 0.2156863553870109, 0.171922326328293, 0.1677224637880441, 0.17369647870861715, 0.12328584783620412, 0.13182104024435246, 0.09555374842978294, 0.09132405442576255, 0.10961805019647845, 0.12113452738811895, 0.07821567717098421, 0.09742647334332429, 0.1115508747076796, 0.13568149519062814, 0.19608098562927018, 0.12103943289407801, 0.17442657582221494, 0.13299713842570782, 0.3525920897241562, 4.879731987753223, 23.551402976436002, 46.50409144739951, 52.076622363059755, 38.965633300042924, 32.47073546532662, 19.285027211712254, 9.036250498987014, 1.3840901947790578, 0.28390958003940125, 0.5616471880385953, 0.20517907646154204, 0.194483554411319, 0.1660299763804482, 0.4434454290857239, 2.5325444917525015, 2.7290172394244903, 4.69238389884272, 1.5877889289009957, 1.6907822797375343, 9.609922632094353, 18.66244900611139, 33.15204135833248, 45.42154473643149, 56.75874387064288, 59.66888366207, 58.10074360139909, 56.37861521013322, 55.10058149214714, 58.5729028332618, 61.07821872157436, 58.83293636383549, 56.79410403774631, 55.5152113206925, 52.535088600650916, 53.28164116028817, 55.24617202820317, 56.646042408481726, 59.37765944388605, 57.83822328813615, 57.56604609950897, 55.254361937122965, 53.89183644325503, 52.174038348659394, 51.878958440596065, 47.496094165309785, 48.32405551787346, 42.81533764254662, 44.83598586051695, 44.23626722828035, 43.45911233655868, 44.16682166437949, 49.525524570095925, 53.02783635354812, 55.74756468496015, 59.30023577905471, 46.68799177292855, 53.858327634872936, 59.19945439984722, 55.83135827895134, 51.75369754914315, 46.84154864280455, 44.87065176809988, 44.76433592457926, 49.24238435683712, 42.49179701651297, 41.33687473112538, 40.987897534524244, 39.77011534475511, 42.779640151608376, 44.26470048965947, 46.76678042257986, 45.6354158924472, 43.66846492213588, 44.10544049355292, 44.078030970788774, 46.47583469267815, 49.867178701585345, 52.92152835476784, 52.34223742638865, 54.160055960378344, 52.00024989343459, 53.66828487765405, 52.46068516085225, 52.655540666272564, 49.759180161260794, 50.26693490243728, 51.92956878292946, 52.33744036766791, 43.96384685270248, 30.491372154605006, 12.838197042865138, 1.9256330906383454, 2.532789885036407, 6.023610349624388, 7.128453283540665, 11.886825176977343, 17.770619700031897, 10.971204734617665, 11.517830164201799, 10.3268289373767, 17.58883745439591, 20.910606461186564, 4.633633657809227, 0.7628030618352275, 0.8097923210551663, 4.777319392850322, 11.934944814251317, 23.808294688501668, 36.77913158170639, 46.01931395069246, 41.455887286893784, 22.272072915107977, 4.906340856705943, 0.2607880352485565, 0.12395389182793519, 0.18698825741246825, 0.18611666385925588, 0.22072813323428556, 0.10089891241683115, 0.24427065866128092, 0.17768744439367326, 0.13606149012282973, 0.12672892275957331, 0.1657775504093978, 0.20619258014184816, 0.21564006835462587, 0.14281483096701486, 0.13797723087331942, 0.09954276825151137, 0.15693570066603924, 0.1432400404085075, 0.11816154699772598, 0.14716222671972168, 0.17064939463330855, 0.11856601077822909, 0.08110768206778073, 0.11973824021556687, 0.20098797796714693, 0.2043130906719354, 0.22858657123100376, 0.09807518893672575], [0.05485527765666766, 0.05202968109158739, 0.04408916826510141, 0.040105993694235245, 0.04375552165231878, 0.05945949289467066, 0.03223658914888098, 0.10271985744757038, 0.057916120671096354, 0.018815567581764153, 0.06645630414207136, 0.04336082166241061, 0.024132922577160983, 0.019837521211875063, 0.050333753949211496, 0.042476522540974046, 0.039151754575751485, 0.041410511194337765, 0.08518055787370091, 0.07116225202597919, 0.05924242571176541, 0.010230737464171986, 0.02942268500074504, 0.06966468036895798, 0.009062752153934732, 0.06060375246189295, 0.049115164701135895, 0.04308189671005934, 0.04897839885445372, 0.016984402938115022, 0.07176751511231547, 0.037929832845205264, 0.016489866369914626, 0.08272155353258695, 0.47557512598652996, 6.080724962296025, 23.752446020803145, 39.48121709208335, 30.04933084211042, 21.69203869758114, 15.238916066385086, 10.03828860098316, 3.053422748081146, 0.24267624582975145, 0.023345133297205455, 0.025252129154039488, 0.0370452311190386, 0.27907118321426455, 0.2412477523208626, 0.6341862149776951, 0.7084397466913347, 1.5683579973636137, 5.562855409037683, 0.9541302114244431, 0.8147951816358875, 5.354884478353686, 10.78218081305104, 21.49192721612992, 35.75941339615853, 53.23849116602252, 56.59361600875855, 57.12743489973007, 53.65415650029337, 51.18154533447758, 52.8063871783595, 58.04069211406093, 55.620695621736594, 56.9672570690032, 52.06762836825464, 52.253960563290505, 52.22767676076582, 51.59131142400926, 54.15834580698321, 54.85029505145166, 54.9692330821868, 53.66552745142291, 51.76704537483954, 51.49346397769067, 50.83583154985982, 51.40634421379336, 51.07368799947923, 45.9261223577684, 40.567952894395404, 40.19000114933137, 41.06457202665268, 41.00634444144465, 47.39639928264003, 51.928450907430346, 52.54749505750595, 51.43202397131151, 39.02139371441257, 53.0277108377026, 51.03721387924687, 53.79694254167619, 47.965095889183786, 42.942249851842085, 40.64285839757612, 41.83220732596613, 38.41169657245759, 38.69609194417154, 37.870040785881784, 41.01371457499843, 37.25978666736234, 38.68258722366826, 40.13302480020831, 37.76174806779431, 37.7003433627467, 39.17533105419528, 39.49839315106792, 41.876522264172955, 41.47866449048443, 44.54091379719396, 48.1955704381389, 49.38577836559665, 49.818455019304835, 49.54974520590998, 48.66419561447636, 51.947419489583666, 49.32446387506301, 52.5599564275434, 47.91105739531979, 49.54929021096999, 44.00440416028423, 32.215551945471, 15.755318653198982, 3.581782680365347, 0.5231364383812874, 2.09249182093528, 1.7834427592254456, 6.2347157443723376, 4.23830924495574, 5.972548934721178, 6.22164297488428, 1.4421926318637788, 4.783983009476816, 4.458713108493436, 1.913214621524657, 1.1068815858133378, 0.2582919062866319, 1.8411881380504178, 5.329189031354843, 14.329131130249271, 16.87226356998567, 26.372616752501457, 27.773685416867657, 26.469240419326294, 11.36256706330084, 1.2267141620959006, 0.021334560437788887, 0.049380204309859586, 0.07166312031087375, 0.05239384481683374, 0.03722405519276377, 0.02427931814905136, 0.028995119838885246, 0.03329506985122158, 0.030099613697177945, 0.0802162851417257, 0.029329957718390132, 0.023251220493787722, 0.024917138056949745, 0.04635812534439949, 0.04328373023459027, 0.026552948364687544, 0.045266936518131726, 0.08088747009394631, 0.025699543654017394, 0.027838179601296306, 0.018701696272699103, 0.02117437145282184, 0.026736102750404712, 0.038827063530803695, 0.10804010059444175, 0.05457152635039342, 0.09762687428343682, 0.08776711585420756, 0.05387483833117351, 0.07562783982364402, 0.0639601445366298, 0.038991695825731566, 0.04743952356699494, 0.05065637655676373, 0.034326848558961384, 0.050270770030516776, 0.05437326279558963, 0.06705869439869158, 0.03096636365948906, 0.008956188366057412, 0.013480297620258024, 0.011303559332455118, 0.016200275558437553, 0.06245972303253028, 0.028489003851709348, 0.024653827891715115, 0.0782815913759893, 0.053092218229487065, 0.037040075347308195, 0.07690451768857819, 0.00484142909690197, 0.058744932044177293, 0.0188046048635677, 0.03428591648116708, 0.009360132164381927, 0.10332044739756854, 0.023419976256968036, 0.024490032547844515, 0.0866928767232645, 0.02605043682119539, 0.02272115659809882, 0.09205857186668343, 0.6664504062744879, 10.27898092423716, 30.4629232037452, 47.26768278306531, 36.16767721791422, 24.010510521550334, 18.733228175870835, 11.933144446342222, 3.6367919608469936, 0.23184480446000255, 0.014903911149069188, 0.0929910157837214, 0.09167670001906734, 0.7467241633322932, 1.1246186663066189, 1.2632862190085075, 1.8130564088782959, 7.9317517530533586, 5.754820617937273, 3.0269822958976995, 2.104956868194765, 7.032910719994576, 17.43279968538592, 25.525196521512925, 40.68911883138841, 53.658475029853086, 58.88179340670186, 58.63544502565938, 56.621708023932676, 52.499469557116115, 55.66493995728032, 58.282792568206794, 57.56785823452858, 56.80119960538803, 52.58521256908294, 53.644589839443086, 52.641380909950506, 50.97656619164252, 54.86603944532333, 56.10536329207882, 56.36159212358537, 54.145558880221465, 53.16653528521138, 53.914060592651374, 52.60765637120893, 52.29296461228402, 51.4920715362795, 47.06771250694029, 41.073236542363325, 41.42695196213261, 41.64816971748106, 43.97474319704118, 48.80564412763042, 55.150050424760394, 53.956477103694795, 53.04429069642098, 42.26453881109915, 53.63587041055003, 53.586236738389545, 55.324407623660186, 48.72444322032314, 44.679322473464474, 42.81893837836481, 42.182949589144805, 41.31056739437965, 41.136598510126916, 38.95057139858123, 41.253300789863836, 38.81303348848897, 41.410246587568714, 41.43050562950873, 39.829672613451564, 40.4032447261195, 41.390650426187825, 41.17089179254348, 43.465717607928866, 43.053017585508286, 46.90574607541485, 49.7739008165175, 51.358024535640595, 51.4934875119117, 49.66895388018701, 50.1538961164413, 53.52670300391413, 50.51336957562355, 53.98787959929436, 50.363786066732104, 50.67470058318108, 47.441231973709606, 34.934723300318566, 19.43926461281315, 5.184311386077635, 1.6480147165636865, 4.054706774411663, 6.253257768769418, 8.27107942873432, 6.315283679193066, 9.218546575115575, 7.401272760283563, 4.870659055248384, 3.8761286149101877, 2.051439068971142, 0.9936967528154774, 0.688341950937625, 0.2114379535158796, 2.0354378824272463, 6.078768680172582, 14.335442223856527, 19.660317628614365, 29.368101435322917, 32.267115423756266, 32.346865054099794, 13.609260493709197, 1.8602204587190383, 0.03447331690920457, 0.02522227662285009, 0.04527043753994569, 0.028988887713621223, 0.04995706085596354, 0.021078254231401992, 0.07766125934018243, 0.07450115431340472, 0.017310516991382165, 0.030937231250948487, 0.02386315812116429, 0.03390808191691195, 0.056763552880335244, 0.025783372825131785, 0.043393231012047305, 0.016097447406801007, 0.085602879163719, 0.028961875453411095, 0.05303571541463176, 0.010950343003646742, 0.011599472284527316, 0.01436561372341408, 0.021262262805154728, 0.041065181740709854, 0.08773942177574481, 0.106737406383599, 0.01903860067437974, 0.04001462621794593, 0.16404910283463617, 0.18187926301071722, 0.16800836780138556, 0.08837109191283103, 0.23384084654671533, 0.2212510801731579, 0.10386629270449763, 0.13583731747442676, 0.1952994380506777, 0.14942407067264282, 0.13728664857485604, 0.09763213730747662, 0.06972936883328423, 0.12151015561915214, 0.12848370077629245, 0.13185618835831844, 0.1902316438574945, 0.1800591606766947, 0.1685764526407565, 0.1046048550896587, 0.20001388184966581, 0.16694070170483283, 0.10255304946293754, 0.09590029596321045, 0.08115583069382176, 0.09208890128760569, 0.10681763111102967, 0.17517683636997977, 0.20837917893884644, 0.11159031291402156, 0.15731506740614293, 0.10835525384473224, 0.14664482625742115, 0.2841263522784556, 0.9183685529616572, 10.719620969987686, 37.91796822701731, 55.71331062624532, 43.71668261866416, 34.164389410326564, 27.152607517857707, 15.123993562113855, 4.317147414530478, 0.34652185416029346, 0.2035493622984617, 0.23633423291387098, 0.1423494785182899, 1.0318624564716894, 0.967331744970814, 1.2280771857307804, 1.7478271477645444, 4.357548317601604, 8.877086600949688, 2.703689269481167, 1.5708517667747315, 7.144680619239808, 12.866909773119035, 22.737709245374127, 38.433124480708955, 55.62983866660826, 60.61491227919056, 60.40866228841967, 59.25790948252524, 54.99291635328724, 56.41442644980646, 62.48620840810961, 59.79359542169879, 59.693194512398016, 53.31817411607312, 54.49501852835379, 53.02563982625162, 51.26739032806889, 55.94406758585284, 58.780874744538345, 57.30856603191745, 57.43405834321053, 56.116228257456136, 54.969095799230764, 53.883113091991795, 56.253840692581676, 54.91980337327527, 50.71722299821916, 42.652916216081195, 43.553664991932536, 44.07148845734135, 47.156307082022394, 50.31776097513015, 57.127709465642134, 56.204175641459805, 54.66073474576397, 46.16717553907826, 55.082056137823294, 54.76217116079023, 59.01325948776738, 51.77872227084253, 46.10343702377812, 44.41797102651289, 45.27876653978902, 42.767088567056966, 42.461692825440444, 41.471106083162375, 43.23555292621736, 40.48242561278805, 42.95538586954917, 45.02581680974653, 40.849214292341664, 41.76761373396843, 43.23274058680381, 43.96598846681657, 45.146166893743704, 45.55080252309, 49.33882367226386, 52.72771619981336, 53.513923921892726, 52.829842951989946, 50.31022217965896, 48.71834001233501, 53.627868775398504, 51.126632152065156, 54.4654477796247, 53.23962865337249, 53.62341688525293, 47.99147382859261, 35.34603088132797, 18.982169243597216, 5.224269551615562, 1.34658228485815, 7.677175219981902, 5.803166281792426, 12.964184553392473, 10.527521910205966, 14.761171379396993, 13.59567536461738, 8.885515774449996, 11.10114795546378, 8.986080442705463, 7.87276715040207, 2.5594575895417124, 0.6196436598416298, 2.4919570309500543, 8.868441697089903, 20.552396005199803, 25.869639458194857, 37.009778714949086, 39.610655307769775, 37.66386924251434, 16.028725504875183, 2.0477569439718804, 0.25169500059658484, 0.187927603781704, 0.20432761569897975, 0.21166244792121075, 0.1152439394425, 0.13550684246565067, 0.16743830645516997, 0.12257147850769183, 0.10930219980617685, 0.1388196671201337, 0.0830343165885537, 0.24463456574707265, 0.16470053804016885, 0.12302273493860999, 0.15776678348981565, 0.09176767296007565, 0.15442518457289667, 0.18411381891177547, 0.14249330386519432, 0.1193779030995023, 0.09528534186463203, 0.10828355567589884, 0.14798281413893546, 0.160204092220914, 0.19919297267352382, 0.17479930824089437, 0.22681418085290542, 0.13890358439135936], [0.053059755253695676, 0.028656263828217506, 0.03437234269034478, 0.008393783111035103, 0.03817675830495935, 0.059312974748712395, 0.011712241384591307, 0.017573898019749793, 0.03809408975705024, 0.019289712804640015, 0.10035891236076433, 0.016636284924442732, 0.01608636594497629, 0.02090829762540037, 0.06883081664601642, 0.05522107314919272, 0.0082973163619998, 0.036590550275098895, 0.04348274455555985, 0.03531374983609684, 0.06550342099921358, 0.027589296786895687, 0.06219507412864797, 0.046380345724643245, 0.030921195115473483, 0.03431121653486644, 0.017423599229885206, 0.04295686349993752, 0.05274687728454029, 0.06589150581989558, 0.04282361782726742, 0.08535853542026975, 0.04920472804036352, 0.08960133718867457, 0.03878061945039419, 1.5855360175332718, 11.287750794041543, 37.782477794155, 31.003427774675433, 29.730626498499227, 14.854139397221228, 11.870546360169689, 6.742875960565383, 1.565326372942617, 0.05311513191930229, 0.044916819014977065, 0.16899219323550502, 1.3599038797040142, 2.3690407362676438, 1.139035583023102, 1.494631656715947, 8.375785139299209, 5.129579613285681, 4.299598730379536, 1.1393363797856917, 1.0248078285686433, 3.6110514065911694, 6.891735792160035, 15.170653097091185, 30.18355238822199, 50.31632146527691, 55.0575295571358, 56.54051496136574, 51.4308354931493, 53.982556942970525, 52.023901785573656, 52.68371505122031, 55.18483008107832, 56.96626863171978, 53.82006491384199, 53.02221559709119, 54.40145038789319, 54.18899912987986, 54.38423902757707, 53.13291272809429, 55.50506807142689, 52.87218886037027, 53.426980664653165, 52.98632591001449, 52.29707917859478, 55.06433879175494, 52.81574595359064, 49.096774208930235, 38.187203638015255, 39.23566887455602, 40.7811729369625, 47.26581573486329, 51.79478437669816, 53.141659613578554, 54.26991762653474, 39.076275517863614, 51.648193636248195, 53.50021916051065, 51.7089040817753, 46.58543748240317, 41.449427143219985, 42.11845797877158, 39.93866351342971, 40.05603259609592, 40.86262879833099, 41.374317676790305, 42.15564204800514, 40.53394594500142, 36.948075909768384, 42.22280479246571, 39.21246021024643, 39.19655107682751, 40.203046952524495, 43.56801302202287, 44.010676030189764, 46.30250123239333, 46.80507844494235, 49.70340405741046, 50.58973420050837, 50.570338080006266, 50.96754474024619, 51.000351444367446, 50.12981276358328, 53.036575394292036, 48.09174137730753, 44.59161043167115, 44.84031223481701, 30.789682134505245, 20.489383128381547, 9.118376105062424, 1.3385057569511476, 1.3844298475211667, 3.8640388894465665, 8.160301889142684, 5.533108153650838, 4.467732598704677, 7.337345971215156, 6.686814504285013, 5.0970401206324185, 1.7529226743405866, 1.365578936473016, 0.8369848877191545, 0.34605791131334923, 0.778237772324393, 4.244455599015759, 8.501079370898585, 20.749340172736876, 24.344682731936057, 26.613785643731397, 27.85484317810305, 19.186869898150047, 5.902417936632711, 0.048209112513089375, 0.035834229971852996, 0.0400349696827752, 0.035180251354411725, 0.02312205423931441, 0.03361363219277513, 0.01717349067480574, 0.03411653827154829, 0.029272192773679574, 0.04478673728543424, 0.019365199278258992, 0.02236747295565663, 0.03900581482617606, 0.017905704106294343, 0.033063243984455065, 0.016927360031273098, 0.05564291180381852, 0.038004020799792586, 0.09314963428844368, 0.03338521158683204, 0.017739867138105537, 0.05396935442883161, 0.05946529984113671, 0.03178643396935396, 0.06022421335200629, 0.02321988558246484, 0.02798071600526812, 0.011321475256174322, 0.07518275806139554, 0.05272321282855926, 0.02381219029156191, 0.010262200695222184, 0.028671579841043682, 0.023322464755525994, 0.027024038811965335, 0.046754476253784476, 0.1341924194486872, 0.03867027597622045, 0.03423105692490935, 0.03367998306789706, 0.02698820887974674, 0.02719265667931928, 0.045203630842508814, 0.07173333993001331, 0.008979241866918822, 0.032519804193608226, 0.015185122873874442, 0.049599424199832064, 0.05977556928090992, 0.022483071792990934, 0.05210817446030917, 0.07373563329418821, 0.04530648197678309, 0.06557583162981657, 0.014892532828173813, 0.030080166555220084, 0.03683576352834221, 0.05057470009271657, 0.16358730503387992, 0.046201728494657625, 0.03189193768306606, 0.056454398098491856, 0.06409764582771929, 0.04479865378309642, 1.9739019005529344, 16.674760464699037, 43.87957865192045, 36.65827551195699, 32.48385383236793, 24.286545361241988, 17.841520463266683, 8.423529209629182, 2.2552775375304686, 0.08979951647380668, 0.02621180941200545, 0.3874518481954452, 1.2007184086307403, 4.16100521241465, 2.9343903353137355, 3.4455249338380756, 9.197870781344752, 9.975544406521706, 6.95313657483747, 4.0634722911542465, 2.6283665241733676, 6.560995165378817, 8.88514805224634, 19.756902071737475, 34.14250258476504, 52.67970638890421, 57.88058096362699, 57.367782054408906, 52.869423589398785, 54.44707539773757, 55.719927664726015, 54.488217138474994, 56.0363531112671, 56.8218195053839, 56.08286457677042, 52.9763787792575, 53.70881080627442, 53.954657123934844, 53.31734257359659, 54.101487128965324, 56.54829694378761, 56.017890514866004, 55.1404719967996, 54.853797728015536, 53.20008723966537, 55.08879084740916, 53.21430190916985, 49.75577554395122, 39.150082757396085, 40.883315378619784, 42.32092680469636, 47.881039496391054, 54.23313756142893, 55.26806277613486, 54.59396031595046, 41.853482261780776, 52.829219295132546, 54.81540949113908, 51.84543394273328, 47.77855580852878, 42.85634602269819, 42.80276644614435, 42.03935946187666, 40.57133397748394, 41.05341680588261, 42.337628256890085, 42.77301526838734, 40.27495576489357, 39.79931739068801, 43.12013718389696, 41.606372940924864, 40.924692461567545, 41.68879762772591, 44.007342015543294, 45.53880399273288, 47.14830936924104, 47.62189634384648, 50.97982568125571, 53.91642185949511, 50.90063302747665, 50.292575436253706, 51.42931361352244, 50.01591890088974, 52.68744522525419, 48.332551371666696, 49.03434184289748, 47.13137257483698, 33.72724125462194, 23.860756389556393, 11.069598370982755, 2.4780774789471782, 3.0775762133059965, 4.442903014921374, 9.001174703721079, 8.389757602445542, 8.537549568760781, 8.856221552818052, 7.5568270971698155, 6.103442349741536, 3.5717958356103594, 1.0559879748090621, 0.23403077506490294, 0.050871819633269505, 0.8281361431844774, 4.426985056169571, 11.744058747445385, 23.733238174069314, 27.357208151971143, 31.46746377791128, 32.41665186420564, 23.8220759361021, 8.313486133852313, 0.20455728885867905, 0.02699468806836634, 0.08242133899681992, 0.03832546746238105, 0.06831770627609185, 0.051663157815534266, 0.039814688761027596, 0.043419867889174533, 0.03886334928533724, 0.031419950912916855, 0.015533351970295754, 0.057048744431907134, 0.0777712312617129, 0.01237514779918016, 0.0602523479310255, 0.03976158354611647, 0.05193500028502557, 0.051829525299610636, 0.06689554065345757, 0.0662313424231064, 0.0213752435370078, 0.04036267528370504, 0.0663777418254364, 0.10009938475465584, 0.025849595380526398, 0.02474086314079262, 0.05703274851604816, 0.057093173701075785, 0.054890142318101666, 0.12749673438168344, 0.1522584580966542, 0.12937121363657136, 0.08854106384059114, 0.17820672943226754, 0.14191899839187824, 0.09494133008223388, 0.24018261431446, 0.11728704231040132, 0.14707066389101167, 0.24316022953679486, 0.11291834931339949, 0.1196859164103385, 0.17102796464197098, 0.15414137964046773, 0.11523379643838252, 0.14507371782054826, 0.07279777313552557, 0.11493460079955478, 0.13226854284444164, 0.1629333570599556, 0.10454706907753022, 0.1391923076082622, 0.13446942152034852, 0.25197071564053336, 0.12171289312743372, 0.06592297671182502, 0.12759857811033726, 0.15109830986588232, 0.26380758612386646, 0.2219657329542022, 0.2066815434203994, 0.18095271030981697, 0.24082191468727207, 0.27317218362323703, 3.1008096375773033, 19.368220683067076, 51.88782691955567, 45.86391356683547, 42.56283114033361, 27.378794916214485, 21.298923069430938, 9.976005285016953, 2.462897906380315, 0.36345515520341937, 0.18273024879876645, 0.8053050682910028, 4.028641398875944, 6.385457333057158, 2.7381546458890362, 2.873607816234712, 16.163564824288894, 10.767417992314986, 6.985108304408289, 3.005806645078044, 3.5619693177361644, 4.8972463511651565, 7.770724729184182, 17.843799360336796, 33.54631408568352, 54.07202228423088, 60.159434887670706, 60.72853549834221, 55.36782826146772, 58.27999199590376, 57.10563828868251, 56.151761008847146, 57.99894632831697, 58.53266323766401, 57.473431095000244, 54.95844656421293, 55.46060016078334, 53.99083706640429, 55.265152377467004, 54.9074871309342, 58.19567672667965, 57.807919056184836, 57.716822008932795, 58.0235945024798, 55.15709892396004, 59.06581140333607, 55.57370954944242, 54.85195421403455, 42.609628938859515, 42.677717362680745, 44.85707252256332, 51.200317798122285, 56.082087947476296, 57.28738131061677, 56.55386278706213, 46.99028491973878, 55.794931227161044, 57.25930890729351, 54.53499140277986, 50.15292729100874, 45.258393749114006, 45.00504393731394, 43.55457105944234, 42.12190181978288, 44.455770907863496, 45.472704210589015, 45.913931631272845, 43.61898030004194, 41.2791060632275, 45.6830491558198, 42.88344175584855, 41.75824711399694, 43.17779994780018, 47.980965798900975, 48.08998023310016, 49.112801013454316, 50.5467293339391, 53.693117403214984, 54.45567715552546, 52.96659246567757, 52.21859647381691, 51.70755478643602, 51.90494414298765, 54.88221137754379, 53.127162533421675, 49.225286745256, 48.42291885806669, 32.059647537046864, 23.241202331358387, 10.764659585491305, 2.1865853138508338, 4.301694256644096, 7.468153584387995, 16.1375791218973, 9.821758077990625, 10.754311392384192, 14.983345212474948, 18.230423465851818, 14.30569398787714, 11.37751619662008, 5.472970374168889, 1.418080841822009, 0.48684547444985765, 1.2463061559584834, 6.027711677935816, 14.45562364593629, 29.71576071554615, 33.95907294365668, 37.82924029134935, 38.896352475689305, 27.116845307811616, 8.636081468674446, 0.40294720220469665, 0.12050342415609669, 0.13783325230883015, 0.15933334136441832, 0.14847856495649586, 0.16622083952590344, 0.10759281249897135, 0.1309624855076113, 0.14209781863516377, 0.18227111698398668, 0.09012626063439155, 0.1102798275889889, 0.1490583709411083, 0.16189201374448117, 0.2077971359774951, 0.15392065438772404, 0.19302038776297725, 0.1567577231194704, 0.1321121996208545, 0.2128346084106353, 0.16326306598080745, 0.1029533304033741, 0.13919707267515122, 0.2799225826897929, 0.17361841434913297, 0.07738933643145908, 0.20827068556700984, 0.16787131467173178, 0.17474257176922214], [0.014870544189527152, 0.038328527983638554, 0.045709953673424265, 0.034083780351906054, 0.07848072061014753, 0.05101949457199343, 0.0373687232363849, 0.10112022755727654, 0.012136558333652155, 0.03384051679243003, 0.015963768894453684, 0.022035481092790445, 0.008665144860353923, 0.08795663068491606, 0.02811035340381486, 0.14314630189009253, 0.016559001974641316, 0.05922868592484344, 0.03396248565085473, 0.05777538265852679, 0.03463023852917456, 0.0008905405833971717, 0.010520136753667989, 0.008473525203073458, 0.01305769766575747, 0.04839722157245682, 0.03693982508153685, 0.028309375385663686, 0.05022825598115883, 0.028751802653254523, 0.08755659489261527, 0.020871856738062158, 0.029578129986240983, 0.031782766323416464, 0.03760922887933351, 0.16903749967534698, 3.983116164322823, 20.27850866317749, 39.614361947582616, 32.33844568652491, 14.618150976396377, 12.573835176806297, 10.305432408086716, 4.0269839523300055, 1.063016371861581, 0.17962215348116814, 0.4284600751294244, 0.22916628528506527, 3.3563093985280688, 2.7254513146415835, 4.170891546433972, 17.775230446169456, 7.4425400168665, 7.394050205907515, 5.2755569930999515, 1.010528256095225, 3.808609425060211, 1.3198171339688765, 4.428301501658655, 12.96062304127601, 27.831538415724232, 46.22770163320726, 54.798837477161044, 54.806235067306034, 54.61822802020658, 54.2857640020309, 52.90166154984505, 55.26372071235411, 56.257233542780725, 58.54658765177573, 53.18684139559346, 54.64710450941517, 54.39688867138278, 53.413393574376265, 52.62388713898198, 55.02692330268122, 55.24495609344975, 56.30136805195963, 55.41915247517248, 55.38714593456638, 56.04281717731107, 55.39359038875949, 51.9947938765249, 43.95543729105304, 39.10910183383573, 40.80209485946163, 47.075937717191636, 51.98597246600736, 54.68576731220369, 54.982447547297326, 38.82575765732796, 51.67202595741519, 52.17652513134865, 50.59447242367653, 50.13386457197128, 41.811446220644065, 39.84313811025312, 39.41950251979213, 39.48533558076428, 44.08168661978937, 47.99457642339891, 48.792927803531775, 47.91115937694427, 43.84197488907845, 41.88246857735419, 38.83442217303861, 40.10149286639306, 40.21699490085725, 42.868517137342884, 47.08846184515184, 46.612635197178015, 48.214154628015336, 49.659842214276715, 52.380417777645974, 50.57141673180365, 49.625286133058616, 50.90816005583733, 49.75210812784011, 48.81270831631076, 47.83605383288476, 47.46211467250701, 34.945800073685184, 21.08111385376223, 12.688253656510385, 3.8915052865782096, 1.8867288169360932, 2.0251378609288126, 4.439240011476702, 6.609560481963619, 9.83327905977926, 7.094249235045526, 6.3805533897492195, 6.102627477338237, 3.4565798890206123, 1.8953516574636584, 0.5502419161700434, 0.232405963864538, 0.5601719478445669, 3.819665360835291, 9.097182558428857, 17.562547768315962, 18.22922714294926, 25.015649257167695, 23.97990034472558, 25.097840562943492, 12.52809936000455, 1.4449876883337576, 0.033105819320846955, 0.08898965428553282, 0.006487675916193234, 0.029614791123857422, 0.03568283950669631, 0.07688329705307562, 0.07238853662725418, 0.005824477909388202, 0.017432028112272104, 0.07052902673040667, 0.02899781072271928, 0.10586590476093755, 0.027014908959127726, 0.08964053790776, 0.02659786026924849, 0.03877549432218075, 0.0621629175880263, 0.014015366942922195, 0.098883043974638, 0.034409758424566644, 0.05058801470084056, 0.006412194709428737, 0.026434164516808047, 0.042684680121319915, 0.013257452219183887, 0.03189801659074522, 0.07740308770969992, 0.018942529418235345, 0.036957640456215995, 0.006381858106432182, 0.05557269984555822, 0.05358703441977982, 0.0820795871737984, 0.05968639664652367, 0.04742071227801423, 0.08761773636985211, 0.08395860933007733, 0.022195016987802043, 0.047951170708984144, 0.005721212130024909, 0.08291232474749127, 0.021158086338771448, 0.018828849631151365, 0.0297478529354257, 0.001582408712560972, 0.03228222883696998, 0.06019590257276451, 0.03665428112951979, 0.05880797341946633, 0.08299075682917911, 0.052593200046929627, 0.045435234543777285, 0.028282273110122453, 0.043675373533680555, 0.026215344907776005, 0.01804827881466237, 0.03455531129974031, 0.07715158104415863, 0.06098106991679919, 0.03101121427701606, 0.046001971068401495, 0.09452486170395728, 0.03830110203594931, 0.05027147100096749, 0.2684485774126745, 6.1852786810167375, 25.943858546595422, 45.85963818334764, 35.1606478998738, 17.272072722834928, 22.083012711617258, 13.773666639481823, 4.809210223536338, 0.9761065160555225, 0.0909996927986222, 0.31428282119093404, 1.4097364895766782, 3.8918857564849243, 4.719869907825224, 7.457467577149791, 14.130029659117422, 12.019086518595296, 8.438103756596966, 7.992139583633793, 2.3732391432408364, 5.29599009021636, 3.5470782845251025, 6.600874393217026, 16.477239708746634, 30.410171247297722, 50.38840286193356, 57.1333812129113, 56.93185767819805, 55.99647829609533, 56.16503430951027, 54.0732813650562, 54.845831394195564, 56.6895571831734, 58.42629640333114, 54.41211923476189, 54.086264410326564, 54.29842149057696, 55.03807852345129, 54.25094512201125, 54.75575416318832, 56.72905152843845, 56.88138854119086, 56.11565559141098, 57.51265087435323, 57.082033464985514, 57.72850282730595, 54.067417421648585, 45.40207409089612, 41.75153201626193, 42.30835953066426, 50.44958006951117, 53.808615515309, 56.68842754056377, 56.101217346806685, 42.21410497542351, 52.20501722828035, 56.20086908340455, 53.33192594589726, 51.40862703323365, 43.403328387968, 41.2390665085085, 40.597602090527936, 40.61239334844774, 45.76085721292804, 49.634488013482866, 48.451003028500466, 49.82096533621512, 45.14000092783282, 43.57451238939839, 40.60117929212509, 41.088835808538626, 42.367042110812285, 45.80962011891027, 48.28213714784192, 48.28495733199581, 50.25208088659471, 51.597312650372906, 52.946368725069114, 51.81493359227335, 50.67255896906699, 51.423131958130874, 51.440602194878366, 49.17342908920781, 49.1079294297003, 47.29956380782589, 37.135698564590946, 23.741763445638842, 15.052191634331981, 5.390998721122743, 2.3611359346297482, 4.038274004574745, 6.2051101846079675, 10.268894549339048, 9.518648097592017, 6.341799882150466, 9.61112581914471, 5.491954645802898, 4.736562044389786, 2.3104017924877907, 0.5883996525118428, 0.2196375151435214, 0.7716831853312831, 4.08898804456957, 9.48040989137465, 18.723896857230894, 23.97791954778856, 28.548567295074466, 28.157069644620343, 29.781270180979085, 15.533047741459264, 2.473462074995041, 0.13839286421575855, 0.011449835203107328, 0.04841993990985136, 0.09621964737532601, 0.019978941042697238, 0.08323424255415317, 0.058960122311668056, 0.037330001322252136, 0.05827011457914787, 0.029922473101666378, 0.032167016874037446, 0.02782524612191464, 0.04885439986302968, 0.044423312835034826, 0.148524698771296, 0.027282844380205198, 0.03447838841126331, 0.021865015038319176, 0.061249859525912234, 0.03865040365546461, 0.05850102114040525, 0.05629055870456561, 0.07581884852580487, 0.03934209295097859, 0.015464919251239589, 0.035263938799260125, 0.044331098831589186, 0.019320695315517725, 0.009829113954648135, 0.15354628254088665, 0.17776590711887807, 0.18422715395929354, 0.2081985507280596, 0.21468688643747763, 0.20177570021440908, 0.16818487445913977, 0.19975407079102533, 0.15480360136397425, 0.12027984905627467, 0.1309703762132314, 0.17294724471867087, 0.08354052450628051, 0.20567766180442226, 0.10607652531395997, 0.19760412164032462, 0.13905336990231468, 0.16384308647003867, 0.17430320502288882, 0.09420669006724512, 0.18046871128101505, 0.18086730682801816, 0.1429096573302823, 0.09493060485129395, 0.09704346768558027, 0.14460459621923585, 0.09510213193754036, 0.1170618737476968, 0.16506387822089658, 0.14196759900979458, 0.2522052457976726, 0.10409557515935552, 0.21288696285938064, 0.13388644393172958, 0.13618539718370284, 0.45771596172163564, 8.095446478935981, 31.922074325623054, 53.461407307655584, 44.20847331323932, 23.806223677050685, 23.20511064221782, 16.975627829951627, 5.98248282747884, 1.3426472895568418, 0.6644372497835468, 0.9023731273989525, 3.169490094146421, 10.545637376846807, 10.813537220801077, 14.155504472794073, 31.753135881116314, 17.36251865663836, 12.380662368189904, 11.630430625331018, 3.49608771743313, 6.930542251756115, 2.9652679687546146, 5.758054612144347, 15.102121445440478, 30.018195067682576, 49.87342703726984, 60.09625334893504, 60.43191409880116, 58.7345358633226, 59.242212157095636, 56.086688887688425, 57.76598499667261, 59.66123896260416, 60.412431686155266, 55.497058591535016, 55.45787411351358, 55.36530225507675, 55.285187844307195, 54.670791702885786, 55.530096715496434, 58.40516267284271, 58.674743252415816, 58.01096447052495, 59.50180245983986, 60.25672143505466, 59.21327290996429, 57.75444146125548, 47.18624653354768, 45.01142171121413, 44.82246937290315, 52.953299553163596, 55.409985896079775, 59.58124222293977, 58.1158878726344, 46.43495575074227, 54.496320755251, 56.30774190348964, 53.75832288495956, 54.590763584260024, 44.73767165214785, 42.91980997208626, 43.515814119769686, 42.62986052420832, 47.60533217460879, 52.542917651514855, 52.397299658867624, 52.847744649456395, 47.993191826728086, 45.35849263591152, 41.865041486678585, 43.18955136883644, 45.07698412864439, 46.95673296528478, 50.82485283574751, 51.34800287985033, 53.100545329432336, 53.53404175850653, 55.56518623905798, 54.60469584311209, 50.76435027583953, 52.182039983810924, 51.679945222793094, 50.24486372547765, 51.34484144949144, 46.11902060047273, 36.45775218163767, 21.805985512272006, 15.445733820238422, 6.481708865011893, 3.6477385605535204, 5.181920701457608, 9.82173454376959, 11.942554212385609, 19.452622244434973, 13.689287631742417, 14.531241059303285, 13.765726781660511, 8.397462118056513, 5.721302003629747, 2.5408665355174773, 0.6681535729477484, 1.1664802845447295, 5.689090519182145, 13.283209550765253, 24.776814176190285, 28.659911617156002, 34.14289482178227, 35.18946555352981, 33.62960561629265, 17.602169590611613, 2.7494491108002204, 0.23756430965037117, 0.2535640712707274, 0.08664969234697281, 0.33015950312537534, 0.11096982766062984, 0.23587070375440583, 0.16810933818980572, 0.14722018893207275, 0.2474638663472668, 0.16524841348009725, 0.21931332205572437, 0.18737876307099097, 0.1318990279950442, 0.2150137608330096, 0.28899487168077503, 0.12027945069055404, 0.13743908475002936, 0.09841719356876227, 0.21504483335921842, 0.1599401289657239, 0.11480114828314512, 0.12671018424894542, 0.1678944964923205, 0.20575019500909314, 0.19928974490011894, 0.1872927926841282, 0.19600877418152748, 0.07634923417842196, 0.08019815184055798], [0.026246348486071634, 0.055341145940004825, 0.02848709246233827, 0.0385400640117305, 0.028904855529206897, 0.10883973550892646, 0.035485257770145134, 0.07476060531072079, 0.05572572590843324, 0.0323129604540525, 0.07357494635207039, 0.047149754640075474, 0.0565129655203031, 0.04936865553440106, 0.07143042110387357, 0.06787352083671479, 0.05334784644806097, 0.03810686810362724, 0.040337919152431914, 0.0672699737873289, 0.05436887694222312, 0.019598390696750536, 0.04916349335783913, 0.025152767550260312, 0.007928406243257585, 0.026602391679320606, 0.07652489047858023, 0.0037836948514825878, 0.03726703655575553, 0.04724163922571367, 0.10442638724681833, 0.10821422471875146, 0.0223977851396006, 0.017669277881542524, 0.10430023554832706, 0.01366780817343463, 0.8917527585741013, 7.77229416754938, 28.092634908614624, 36.962019935730964, 29.917639224759995, 16.13087579127281, 11.748843058463066, 7.1506744911593785, 2.678013924629458, 0.22643588663589573, 0.1328871894868151, 0.677130407383365, 3.443705934670664, 3.3661452320314225, 5.195627914321038, 3.188839146206456, 10.018283532511804, 10.804143144238381, 8.153801050878341, 2.417795552361396, 4.131023105113737, 1.9692852708601185, 0.924532435113384, 2.260945362429465, 8.415587390622786, 21.985726164233302, 40.44509249348795, 51.646106935316524, 57.40244796199184, 57.003287961406095, 54.63525110675443, 55.22827033073672, 54.329298388573434, 54.909534608164144, 55.10381352516913, 55.08065585167178, 53.376166359070815, 53.31638551527455, 53.07676792144776, 56.05460389967888, 52.90449742347964, 54.09872970273418, 54.55060243606568, 53.84902769519437, 55.60270370975618, 57.02724187604843, 54.37759061013499, 46.44805254474763, 39.38162419103807, 41.99029453339116, 48.58976079571632, 54.177718393264286, 55.402317662392896, 55.35479422538511, 40.90611219406128, 50.910693906968646, 53.701389681908395, 50.08082628250123, 48.69499798743956, 41.195363460048554, 39.91543131489908, 40.33931401468093, 42.01024763045773, 46.78832600193639, 48.264953244117, 53.06169033050538, 51.83463173527872, 48.98728909031038, 46.73380113417103, 42.19439114293745, 40.37607839030605, 43.540403458379934, 43.89689199386105, 46.655993077062796, 50.52255184419694, 48.870123970893125, 52.483332926227206, 50.80959873814737, 49.35344234589608, 51.91080808639527, 52.194391527483546, 51.043626954478604, 48.47167784167875, 45.54280088793847, 36.155027574108495, 23.303883767897084, 13.645107034713993, 5.623301094578159, 2.4471598863601685, 1.357123899844385, 3.1793761830176077, 4.231296047087639, 11.480984399395606, 6.5080720955325715, 7.364295105780325, 8.801637849500104, 3.492076113339394, 4.1414669059938, 1.6297734889291948, 0.43961192511262437, 0.6011669674227315, 2.027853366828734, 7.0161102279540035, 19.596092739412864, 21.093794876529326, 14.956193585549633, 25.207288419046712, 33.62477325624035, 20.101703905290176, 5.898881429626096, 0.5278044266085471, 0.07208387112064708, 0.02889014281062109, 0.012388771715303584, 0.018553442937592347, 0.02365964111841975, 0.04903133169958188, 0.02480562438347167, 0.07781135128630746, 0.013354318291549722, 0.07438760476126786, 0.048053987369301825, 0.036976746689047546, 0.039158116935962634, 0.004543000503608416, 0.010733726855006911, 0.06488036169039627, 0.07088050020918732, 0.012974602981440484, 0.019184115245157195, 0.0416621710774639, 0.022549531835642074, 0.02841058326134038, 0.026883316121154258, 0.05085952392208481, 0.05046577388120275, 0.07853017924653907, 0.07218640432843278, 0.07099997162097885, 0.024706984817561124, 0.04473484248944348, 0.02910824229700431, 0.04556629303542357, 0.049309751033903136, 0.0481599526509883, 0.07943264614309996, 0.02571734945259748, 0.03033180345570849, 0.019868612890281988, 0.008732460048650543, 0.08643246045516384, 0.019180235009820714, 0.05829823000596897, 0.10683760302321565, 0.026836136596337445, 0.05242662188867408, 0.04554336019341023, 0.04670293768867851, 0.10594492673032707, 0.03135342575279215, 0.056104441473801295, 0.041898581980457233, 0.04420815321106104, 0.02993902443127046, 0.06338090545708133, 0.031801794032235785, 0.05046205835476999, 0.017601195647711718, 0.06369657964716036, 0.020005323195589647, 0.05151900688126203, 0.07902320279108901, 0.06426022883744971, 0.07396489276640839, 0.07686809020777864, 0.02474491383069225, 1.4964326374953794, 11.417342962757235, 36.685645811019405, 41.5511812702302, 26.932927331616803, 18.53605454967868, 18.867475217388524, 10.925351246710747, 3.536198119963369, 0.22479829708895377, 0.12619365712687855, 0.5389258169358777, 2.3584503368023904, 3.9858731002576895, 6.573120192173989, 8.394647817457876, 10.118562848337236, 7.912714039125751, 9.732217231104451, 5.494141857470236, 5.010571470183711, 2.735451642544039, 2.9466207758072884, 4.395610017161216, 12.131319257520861, 26.38152445516279, 43.710336223725356, 54.406369040089274, 58.559715824742476, 58.509497719426314, 58.81253219419911, 56.33466505235242, 54.825309553454005, 57.16780785591372, 56.96117739523611, 55.648238505086596, 53.31908802832327, 53.02117224662535, 52.201149771290446, 54.51018241143996, 54.55440713513283, 54.95259831028601, 55.75507602384014, 54.322857856750495, 57.31033502086517, 56.44978661690989, 55.98605655854749, 47.96317000542918, 40.575566214899865, 44.01193118864491, 51.094272598143554, 55.52224413041146, 57.30387879956154, 56.216919422149665, 43.027486878056685, 53.30565391048309, 55.37275083603398, 52.55947005364203, 50.54975348134195, 44.57397545537641, 43.17891390092912, 41.25953735843782, 44.296028460225756, 48.106136475839925, 50.52272442848452, 54.28947456421391, 53.609680744909475, 51.254976026473514, 46.99775311254686, 43.998728490644886, 41.608083094319994, 43.939359495716715, 45.25856241103142, 48.87329324599236, 50.662368651359316, 50.4239591475456, 53.473884367173724, 53.39658621818789, 49.964916321539114, 52.279683466880556, 53.48707137569305, 52.4969357059848, 49.91060326176305, 48.22267401602961, 38.30421970736596, 25.293672738536713, 16.22874677181244, 8.925936779668255, 2.2157939787833922, 2.3368451864488664, 3.870825815585352, 8.203654866064749, 8.850336036374493, 8.831240957783116, 8.336151549893042, 7.713936163533119, 5.414984014726454, 3.233845647304289, 1.221797838807106, 0.09503690721166712, 0.671423603930781, 1.985354363437622, 8.422443693683993, 22.030358814424087, 26.466594780645064, 21.149343482909664, 29.26362910578328, 35.20723781278057, 24.22514261737947, 8.088083699826273, 0.6643929392580064, 0.04283645746087836, 0.02106104215096322, 0.05674983224561138, 0.04021334942550429, 0.0903365824131235, 0.05009876030887808, 0.027994538146641948, 0.037173018415248206, 0.12064875869621193, 0.06568668455245995, 0.07833710976786191, 0.0185695959014758, 0.05798880326291246, 0.03565501519328645, 0.08741653103741907, 0.05298212373388871, 0.05019167911321406, 0.04565444677287052, 0.05322230378946951, 0.03849572667311277, 0.013350277177749142, 0.02363527569198801, 0.03484605315832361, 0.022118082608006174, 0.026893146944442586, 0.03576203767630843, 0.064256593750249, 0.06719835988816715, 0.04096386661272376, 0.10524757987549228, 0.10684558565938666, 0.1285729653412296, 0.15536663002304493, 0.17369583519476076, 0.14383596488304679, 0.11517417181523577, 0.09388551536586978, 0.22087560515970955, 0.11302435289948218, 0.23707044340910452, 0.17630457908155459, 0.10208008976112451, 0.2306026541778157, 0.16847260176174103, 0.12356390710920097, 0.10839227887411272, 0.08585594864862581, 0.2409340852811452, 0.16548631442410333, 0.10383676001501661, 0.15900977646871922, 0.19434797217047986, 0.08697364028663405, 0.16278300464393633, 0.14252074513464205, 0.22009994113637557, 0.1067018062777577, 0.21584919503619596, 0.14563038794984742, 0.24011429459337266, 0.4317257853765642, 0.1180497671086942, 0.22300888423717793, 0.24199182287819926, 0.11428838265278649, 1.468392838874171, 15.467470615140854, 44.69067381274316, 48.97921293012558, 38.29571600883238, 25.356932724675826, 22.592285410050426, 11.95371727789602, 4.258597214375773, 0.5845990596759705, 0.4190781640429651, 2.203913119531447, 8.641537485584136, 11.139134149397574, 13.967873973231162, 11.502280908246195, 20.8944070723749, 17.902509397076024, 18.074693602900354, 8.455864248737212, 8.159639498879834, 4.88328222305544, 2.9311963002527914, 4.035304770354302, 10.196591538767661, 24.64275344725578, 43.632947860225556, 55.88788355550459, 62.2556475670107, 61.074535615982555, 61.97886551580122, 60.230339573275664, 57.06441417817147, 58.01987217318628, 57.33159818956929, 57.124728464311175, 53.236141666289306, 53.896484451909224, 53.07607758429743, 55.30490167679326, 54.98912342133061, 55.259394338054044, 55.34056778877012, 54.676428148823405, 57.79751300811768, 58.71755200047647, 59.00199051826232, 50.025532630182084, 43.07893268523678, 45.283798940720104, 54.44423167936264, 58.36357770427581, 59.82520580291749, 56.55602401302707, 46.6649321586855, 54.83707274160078, 58.74409075706237, 55.1585070548519, 53.279381875068914, 47.10166454315186, 43.725280454081876, 43.456252928703066, 45.52582094746251, 50.879428694325114, 51.22624074259112, 58.510211590797674, 56.492618899191584, 53.74586151492212, 50.9400567700786, 46.05651763177688, 44.1434992513349, 47.14542642716439, 47.82742461850567, 51.1473265770943, 55.659295666602354, 52.26161702986687, 55.58435878446026, 53.430918724306174, 50.66270205282396, 52.312756892173525, 53.648614191239886, 53.251980197045114, 50.809453610450994, 46.55084217748335, 39.29233927880564, 25.268169487676314, 15.116620486782445, 8.12124292696676, 3.858652249459298, 3.9542487455952555, 8.5136446837456, 8.95952501604634, 22.488932917194983, 17.37522909718175, 15.827268650454862, 16.712660366489043, 9.5314585585748, 10.751169573876167, 3.89548011845158, 1.2507467692898167, 1.2133466019745798, 3.5016351745974634, 11.116689366679038, 27.731565044772243, 31.642701548914758, 24.66434217268421, 36.24992932042768, 42.97777475849275, 27.92288257229713, 7.881558162550773, 0.7789852902773888, 0.12326060523909908, 0.07509101903246296, 0.09527201193474955, 0.12536160903231752, 0.392134606597885, 0.14910767635991498, 0.24844779903369568, 0.12575340171855304, 0.14139946820514818, 0.17063408819658143, 0.14309842139482498, 0.1718597063013623, 0.09943273504294696, 0.1457031356591371, 0.21705733101454475, 0.17252457868908683, 0.13790296630993967, 0.16494951661555998, 0.11608744821240825, 0.09117905696433398, 0.1230762308583625, 0.12847408637284272, 0.11749856684717441, 0.11113932461387689, 0.10589135420178214, 0.20794381117147787, 0.12021267080619452, 0.2019869259768917, 0.07448130497528661], [0.03737178375764239, 0.027302770327115734, 0.00623846464159508, 0.05437023674828872, 0.07296970624837183, 0.0026698429897923266, 0.07746923174108229, 0.03045969034334825, 0.019760887521589478, 0.024478866816348126, 0.12062618208508338, 0.08355529468146064, 0.04322071184193896, 0.03390984774957742, 0.03484252149299268, 0.024730122588094205, 0.03089910688539667, 0.0400206514994704, 0.04017429809356409, 0.01186796599217961, 0.04296152897539639, 0.0313046642564117, 0.031174297159117077, 0.02717250090603146, 0.031058832387169524, 0.013466918852270372, 0.007999725198568477, 0.06172859553067435, 0.0328360989149059, 0.06944910322706546, 0.04846271825954319, 0.04384799612565868, 0.02703279136650024, 0.014665347539008626, 0.03808004736539818, 0.09509599557326687, 0.0748396426018688, 3.2053528149281783, 16.19881712621258, 32.93739357302266, 29.190141539419855, 26.743047352760072, 11.811501941373272, 9.06976224914674, 8.127049505710602, 2.406191465354735, 0.11301348211183665, 0.7713857593555605, 1.258080253197301, 3.249177702011601, 4.609270345780158, 11.931705917081526, 8.651233584650102, 6.298474361819606, 6.9960051390432545, 2.225019148280544, 5.060927348752176, 2.911360138846982, 2.7649422278327327, 1.0453552872903886, 1.220958819312434, 4.598542173062602, 14.790903925895693, 29.81987414821502, 44.54632666803176, 55.06697854688091, 56.50077350677983, 57.53033291909003, 55.21711510996665, 56.2680475173458, 55.954654062947924, 56.5560632367288, 51.06559614981375, 53.62234607819588, 53.26098595896075, 52.273195866615545, 52.69000653297671, 54.4296012386199, 52.52706343127836, 56.02102056626351, 55.78960464846704, 57.04442185740317, 51.650476455688484, 46.889366257575254, 39.32454193792036, 42.85411027169997, 48.74571423376761, 54.205814330808586, 54.00917022458969, 54.8532642856721, 42.60969561915244, 53.26995641954484, 53.52041152215774, 53.364152139233006, 48.67002817892259, 41.8148979063957, 40.82460141951039, 42.44366561212848, 43.42363449835008, 47.84200014606599, 51.15828960172592, 52.619599988383634, 52.74081299381872, 51.36783830581173, 48.35944314156809, 44.643177832326586, 41.88208810744747, 42.951769444250296, 45.229956565364716, 51.49980252788913, 49.768342817983324, 53.24750085030833, 50.655096577059844, 49.96269233765141, 51.0058545297192, 55.16268045671525, 51.89859774804885, 49.85112444047005, 43.36769365495251, 37.82261148575814, 24.286276678885184, 15.944493586017241, 8.904292160464871, 4.069833149833064, 0.9607818157922838, 0.863084645280915, 2.349024636130179, 7.195747917698276, 5.306404473320131, 8.326811405920214, 5.3843429492365935, 6.481077363414149, 3.421440355239376, 1.38503756974974, 1.0204529557977955, 0.309435231310706, 1.3316072884105867, 5.566188443091608, 11.81537037895572, 17.371302804639264, 17.95492991324394, 20.111478451759588, 26.047001192646643, 25.63221643047948, 11.946189268942803, 1.8747280802457564, 0.033824371489425825, 0.012314135599280558, 0.027986716388935046, 0.023234399118190332, 0.025566096883267168, 0.016271925846775694, 0.011095421861917263, 0.024285222771727753, 0.0404729344882071, 0.0251448730142006, 0.042309936721839254, 0.02820881868472263, 0.004199674848707453, 0.01854735828425375, 0.030359457314555204, 0.05103210820966671, 0.015452892628438292, 0.03783392246752497, 0.0329529311537983, 0.04305838547166317, 0.010739191934736747, 0.05803551164365584, 0.050248925033355915, 0.03936722063489499, 0.030495675408371517, 0.02578961835693448, 0.04378514627235071, 0.040547451860601866, 0.060271469485615535, 0.026937288930639628, 0.05409823340033332, 0.048475983071952104, 0.019185404188089797, 0.06036501648204942, 0.0514350283230024, 0.02971109603681872, 0.0613241087675335, 0.041091125308265614, 0.0480361566728642, 0.03589848559650202, 0.08111719687980029, 0.03949226916677529, 0.04096642917683048, 0.051314603131745136, 0.0971151888370514, 0.006145514236132224, 0.04174560571329729, 0.045628813470924096, 0.07010542607355504, 0.07203390686622552, 0.03319508388578411, 0.027820128654580445, 0.031498386825044314, 0.1037015608181396, 0.06266770824309319, 0.03773111729852615, 0.03267550773377861, 0.05429772652625557, 0.039315846778692744, 0.03669634701744203, 0.03891735465355939, 0.060577188363118525, 0.020124239193636085, 0.08291666846602194, 0.051574935130174124, 0.06220804782764566, 0.09071560441366128, 5.286844103567062, 21.580743405126757, 40.52947052063481, 34.46189726552656, 25.400696569873443, 22.270382373563706, 16.321554953052154, 10.7893842458725, 2.7616273347408544, 0.16485864326598185, 0.32510307767698843, 0.8478973505477753, 2.353730009448144, 5.746181107336476, 4.579626052610336, 7.760679539172881, 8.903309606736707, 11.790993828927318, 7.614645775287383, 7.998317806951462, 3.9595302170322793, 3.037065483870045, 2.5423445336280333, 2.907982978128618, 6.86919883374245, 19.120642638975575, 34.1590000737098, 50.37559632332095, 56.069783472245746, 59.91377684377856, 59.263196837517526, 58.3167955952306, 56.9845704109438, 57.5442220318702, 55.94157295842325, 52.379488175915135, 54.22395921522572, 53.95323330356229, 53.98554578904183, 54.10614298235986, 54.5477940190223, 54.60496256428381, 56.978882974193944, 58.06034318862423, 57.71402928137011, 54.9524571049598, 49.49278454626761, 40.988305461022165, 44.912723110568145, 51.59965430536578, 55.120397306257686, 56.151972816836455, 56.25130684145036, 45.75124348363569, 53.67136001586915, 56.896979962625814, 55.338547768131384, 50.15441779167422, 43.506078797002, 42.35357661401072, 42.503426844073886, 46.113933286359234, 51.23654873140397, 53.2651593608241, 52.76518660206949, 54.0678684942184, 52.63393232899328, 50.61585326348582, 46.22381848673667, 44.740487913931574, 44.83966896610875, 48.21739450577767, 52.397476165525376, 51.6344771077556, 53.628543423068145, 52.52610245058614, 49.702450921458585, 51.358679571459376, 54.26185715583063, 52.46786309826759, 51.825853470833074, 46.36847549869169, 38.876685711645315, 28.412519885647683, 18.088343451100013, 12.214523515393658, 4.466411740549149, 1.8510305905534377, 3.1133612221287144, 4.8076059741358605, 7.776228304832213, 7.524998043814014, 6.055567370307061, 6.65195002671211, 6.587433901525314, 2.8940404230548493, 0.4172466623206293, 0.0947931610167988, 0.24316289552277137, 1.8210274005128493, 7.348633571978539, 15.730278242018917, 24.26069105825117, 23.97270279545938, 24.54596504088371, 31.730156675461803, 32.03445415343008, 15.09951699164606, 2.7874186346607828, 0.0382117570317801, 0.046993683377701434, 0.04886728163147646, 0.07823188759146199, 0.01193291684161992, 0.09335758119461038, 0.02463393641876117, 0.04220461495400917, 0.059361380014208064, 0.012087808328590566, 0.03718718338096815, 0.05404904672515489, 0.023478890333565015, 0.029846417807763623, 0.01660875555488371, 0.02540847812328608, 0.05159777221119693, 0.03744986343888506, 0.02424511998411148, 0.06867084982654742, 0.027338967981537985, 0.01931220131565727, 0.005391348076368412, 0.06014851620420814, 0.044462666771705114, 0.049586481144351345, 0.006176917137758386, 0.044711308268409584, 0.031927194964561256, 0.07373091419257465, 0.1564286117471995, 0.14582523475250891, 0.09385270382007284, 0.11749488196425861, 0.15731473032745624, 0.09484221362659047, 0.22282008952911825, 0.18871278261705754, 0.12892308284438428, 0.0797744745749139, 0.2593358389792904, 0.23191122428303768, 0.15564674241167886, 0.18307937038761957, 0.2519936523129863, 0.11451187348293682, 0.13434484030210203, 0.08614796604360304, 0.2375195394720762, 0.08978071667614484, 0.11332215425828773, 0.061671694350098415, 0.1296093597287132, 0.12142721894046954, 0.11565836236601877, 0.29449522975952397, 0.11785124308399617, 0.26493416438179634, 0.12614588388392042, 0.19062332929142062, 0.11538649308345011, 0.18505952381078275, 0.18496883432230643, 0.17232003321330394, 0.18822035662108855, 0.1968222063395285, 0.24814865702102262, 5.995840459100663, 27.555576139880767, 50.618634223937995, 43.92508991302983, 37.05146566514046, 25.69838877647154, 18.095025208688554, 10.70456789385888, 3.160805231140506, 0.4359052546562687, 2.16927491368786, 2.2562475887037095, 7.666790744950695, 15.140237077589958, 21.296224478752386, 17.570998514852217, 14.748359937821666, 16.621988896400698, 7.887903576897037, 10.119034513350456, 7.431650046379336, 5.868244776802679, 2.9408629815424643, 2.00477450845703, 6.016617744199692, 17.60700587303408, 33.355310347772416, 50.66662050062611, 59.9386642825219, 60.45122392715947, 61.607366069670654, 61.47161283800679, 59.50512862974598, 58.438844065512384, 58.51991553460398, 51.80915594100953, 53.69615724009853, 54.400375658465975, 57.8783687468498, 51.43392632084509, 53.867419688932365, 54.35354648097869, 57.78427500878611, 59.71862323822514, 62.407866908657944, 56.37273165487475, 51.407230669452304, 43.33391028065836, 47.37660308038035, 52.604761662021765, 57.41649789194907, 58.85049681509695, 56.24495652414138, 49.89986773460142, 55.99401112525694, 58.45987189200617, 58.11098883228918, 52.51616708693966, 44.91018141469648, 43.682922778591035, 45.35236981607253, 47.17396167016799, 53.2721725586922, 54.42837353675596, 55.07610982464206, 56.91174768632459, 53.56809577634258, 52.07126440540437, 49.427665356666814, 45.920419231537856, 48.20858878474082, 49.29591294257872, 55.874516117957334, 53.70163286885908, 57.0023662044156, 52.2502068550356, 52.30990532905825, 51.27730607986451, 56.123076715777, 52.83433014346708, 52.26093845982706, 45.34099886494298, 39.948975424612726, 25.95561977355711, 18.970790447727328, 11.982572194068663, 6.573035370919013, 1.943126616458739, 4.025858722386822, 7.345420170214869, 14.13765964969512, 14.113647880092746, 15.929424820407746, 13.2812620939747, 17.244355294012255, 10.9288078354251, 4.639740788167523, 2.615791160252787, 0.7116584191399237, 2.4991447742908233, 9.05537401476214, 18.50238492411952, 26.250050529356926, 29.13311027711438, 31.017754231729818, 38.51089723648564, 34.213132704457934, 16.631755598129764, 2.999851506563925, 0.1572628048879485, 0.13012561105912732, 0.1741992928568394, 0.14412998942838562, 0.16670926654290769, 0.19989267141828615, 0.14748643512927717, 0.11075562947700102, 0.16304096176980004, 0.13670026955585327, 0.07955185708499725, 0.1479693769567436, 0.07018906755312797, 0.20563900500776308, 0.1020622628951265, 0.18237253170340292, 0.09922266607323002, 0.10683394878381684, 0.24328117949828026, 0.20105459697304234, 0.09847944587348931, 0.14762551073105107, 0.10809878292944163, 0.13687470777621194, 0.12161493346455599, 0.14267566343469007, 0.257607207543427, 0.13084862952030477, 0.14943838119506836, 0.13206411994272663], [0.03806394036679018, 0.022508915769116535, 0.08199012342600093, 0.03135369005312603, 0.05246209559000788, 0.0321840470085942, 0.07768346822910732, 0.08299369860680834, 0.035625026681490486, 0.05538529175664148, 0.052235567221237775, 0.025114681489104708, 0.05440276101111405, 0.043240335184119405, 0.04868710158212532, 0.014185690313517569, 0.05625435338926412, 0.017406270321037982, 0.07317530892549023, 0.006799920426396233, 0.03300946461217057, 0.02896822823752319, 0.046595501518177415, 0.05490571305516267, 0.03902055052739959, 0.026489581402030685, 0.06500134229539864, 0.08592769278273468, 0.03953813102036234, 0.05602602088343232, 0.008594551773351288, 0.03171595771075978, 0.05131156176268574, 0.011563393373733327, 0.017611516767271587, 0.08904972323967565, 0.07459223450672242, 0.4143518918464261, 5.61522150231946, 25.32507327295119, 33.17379874567832, 26.67758103339903, 13.74113646245772, 8.245118241156302, 9.62705554500703, 6.485158589578445, 1.109868102977353, 0.20639927066381902, 0.5677346452589959, 2.4965947433825466, 3.9418940149968673, 3.4091530403783246, 4.411399027993602, 5.170271752342101, 8.488753322632082, 8.915546421081789, 6.175889017120485, 1.8565695901070873, 1.4136714848779863, 2.114871394249701, 1.1114667139707075, 0.31124178921022727, 1.5520974440920738, 7.857164452152868, 16.873081384166596, 32.50834511172387, 51.45417751804475, 54.58984182726953, 57.819329231016106, 56.8498016941932, 59.27903536827334, 55.20134718187394, 54.250121424275065, 52.472087490943174, 50.083811206202355, 53.033527712668146, 55.447781855060214, 56.54761052900746, 56.71577430540516, 55.836578953650694, 55.59811453665457, 53.62099678285661, 51.383982781440984, 44.29771900177003, 40.40123647259128, 43.68270312586139, 49.95874251088789, 52.621274840447214, 54.139086969437145, 56.86876243160617, 41.84824197523056, 54.593850489585634, 55.267576402233495, 52.80748151963758, 47.47312084321053, 42.436130739027455, 43.76139371625839, 42.96286582946778, 45.47941930832402, 48.040495611006214, 51.347720469197924, 52.682514805947584, 54.242614007765255, 51.767214036756954, 50.0244539783847, 45.41677121193179, 43.6800947496968, 44.49880323102398, 47.3398857731973, 50.635249383987926, 51.611417493512555, 52.9254860262717, 48.006547497164824, 52.159451053988555, 54.87092279618787, 52.15173967422978, 47.38380455201673, 42.86224918980753, 33.74588035768078, 25.24147971983879, 17.88740631072752, 8.581020216788016, 5.661860444853383, 1.9297523147636846, 0.7324101475457991, 2.0610645653740054, 3.311167330511155, 8.208974580610953, 4.132363084823855, 4.2733002189667, 7.082322287944056, 3.659242136824516, 2.685359053073391, 0.9060710031659374, 0.11323358683336167, 1.5694986716393502, 7.444903735191592, 20.576045936153783, 26.18234649781258, 16.384425643951662, 13.473235637910905, 24.841531322848414, 29.559836695271155, 20.508618431706584, 4.462460442896813, 0.34560647102132924, 0.016617058032763102, 0.06422623751624938, 0.07086149356778591, 0.02897017027041124, 0.07558087863388561, 0.06390244662461263, 0.018755366477454384, 0.008916691745511227, 0.04680640935417145, 0.04927459908949752, 0.05867553213911672, 0.1208476427822344, 0.03388814064824293, 0.06479392398989971, 0.06466913592791365, 0.016324431597886067, 0.04220179958088745, 0.007024460318197887, 0.028411037168435516, 0.023333117208113114, 0.020379771651219458, 0.023826661692451567, 0.1212536617212238, 0.012433533275109387, 0.014872178829635584, 0.07297249480841622, 0.057084846325338855, 0.041019948079220714, 0.028214868864104636, 0.06222302101612572, 0.13398131626027246, 0.006703215711299451, 0.047973460037141084, 0.02875738743422253, 0.022948259532812144, 0.07025555632407628, 0.09618285983320206, 0.058082139585167177, 0.036818312045427105, 0.02770692384200952, 0.06249760608038595, 0.011978830406141859, 0.042078949721349825, 0.04647665063760454, 0.022237335684739297, 0.02046953034286778, 0.04090709949753458, 0.0426374469703484, 0.04655775253570849, 0.0433347785034247, 0.06304871058091521, 0.08486139798356641, 0.02451389044102642, 0.03391655101891487, 0.0522269640538481, 0.053898644513420524, 0.06793391920866505, 0.0574416900804687, 0.06329012020761449, 0.08621076993163555, 0.03989064254828038, 0.06229978302613862, 0.054546670627690134, 0.04116049073936959, 0.018738717471639958, 0.10618358610137817, 0.0405548675917089, 0.9084095325200789, 10.635830317774127, 32.84056005939361, 38.46279328869235, 27.911282162512503, 16.74691442520388, 12.719327653608016, 17.702933319153324, 10.157463935113723, 1.2005371215843386, 0.15042347833514214, 0.28186170444373165, 1.0585709781416002, 2.169115077103338, 3.757672545409972, 5.1806778004092555, 6.056092967910152, 8.994772415007315, 9.837666230816996, 6.932104825973512, 4.4507948237080734, 5.793767302267014, 4.3435101547548856, 2.7747138325245153, 1.7897170806123366, 2.8131189846223403, 11.753067451138651, 22.07041209743869, 39.2140801491276, 55.74266172224476, 58.07339291418753, 58.888147646381015, 60.16899762615081, 59.384147044151064, 57.880216183200965, 54.35153822745047, 53.08500882117979, 52.105647902334894, 53.27785999544206, 54.78085733229115, 56.4712655159735, 57.60730943372173, 56.59923676521548, 56.684567928314216, 57.12463824979721, 53.93023252487183, 46.338975352625695, 42.567165359374016, 44.06935861033779, 51.61012311135569, 55.480796444800596, 55.24502669611285, 56.949622092708466, 44.38696076793056, 55.38387075547249, 55.9269150610893, 54.0007528181999, 49.04759553170974, 44.846493890208585, 44.922211324014974, 44.511107706254535, 46.225889498187655, 49.679218722927956, 51.58298815450361, 53.635301666875044, 55.070304716787035, 53.762680638221006, 52.7386753020748, 47.92554270836615, 45.792240096676736, 46.08646885041268, 50.031945705413825, 52.596669812356275, 52.68579782978181, 54.150461842936856, 50.31861212945754, 53.07803484701341, 53.87828857667985, 52.740059898745635, 50.82637863774454, 45.32776871035176, 36.209438693138864, 27.97541487601496, 23.312112900518603, 10.350665180913865, 6.897877243257339, 2.8789741089267116, 1.877395659685135, 4.837119358201181, 5.964131528331388, 9.61147294890496, 5.443573680616194, 7.886365517493218, 6.474210273834967, 5.779663439719908, 1.1544774640952389, 0.44062889151034823, 0.24108531103739816, 1.099666998751702, 6.1472110979018675, 17.37310121136327, 23.559406572772613, 20.272105393871186, 18.37638270470404, 28.392362825332153, 33.34062891621744, 24.0699089342548, 6.813282014862184, 0.5369157860836675, 0.012930750193434858, 0.0554589051452856, 0.023966252488354524, 0.037582136179891326, 0.07019524222179767, 0.01921400991118243, 0.01807594608004776, 0.019236728248576966, 0.037238449984861, 0.07882809551853327, 0.026063538839920394, 0.09997930047252487, 0.08145156361523175, 0.016417082271448547, 0.05966685374357528, 0.022587470424872254, 0.020456815198544535, 0.02467575524332783, 0.036545990770983125, 0.024246912629854296, 0.022476328304037455, 0.06958064052366442, 0.02129719641450192, 0.0062717320097069595, 0.02359879266981396, 0.04941169435398714, 0.028970375198930986, 0.01664619235652349, 0.057930339262970997, 0.015109879633171425, 0.2025637595403579, 0.06563983061501096, 0.19996146611388654, 0.12218406018350395, 0.12881085096347716, 0.12525478573215584, 0.14569717549508618, 0.19978836088651614, 0.15184446418237302, 0.11634138337666951, 0.10577640270874386, 0.2342996719263254, 0.2188769890175712, 0.12432086326542402, 0.11955410332208681, 0.1488713995223084, 0.16309746841509498, 0.11968688934200233, 0.10429796792807118, 0.19014429451236803, 0.08673166375487082, 0.17482815911212277, 0.2102718910863323, 0.23465841557950745, 0.22156893005294187, 0.16498138587321007, 0.12829962516984633, 0.12017274230358102, 0.14503499973685513, 0.180149880808688, 0.13092909939587116, 0.13125824141165904, 0.17920936998580733, 0.15477940830732548, 0.12301947140405256, 0.24903076130055615, 0.18185986566447443, 1.1435828357934952, 13.254888076936046, 40.27865063759589, 47.678456921731275, 37.956595728474284, 25.68330334078881, 18.078770906694476, 17.953258983550533, 9.450506721773456, 2.1752200011284124, 0.596380633932929, 2.0050176954077137, 5.492278731638386, 10.110712224437345, 10.549481299615676, 12.87419165334394, 13.056813286196801, 15.82019857821926, 19.73634885203454, 14.938783164947266, 5.803028018243852, 8.352212675156133, 4.363359799308162, 3.484815561002301, 1.0519864217888926, 2.2512838292506436, 9.105124377435255, 21.218516442083544, 38.52577086417906, 55.67797007099275, 58.26688343478788, 61.10978987909133, 62.22049920789657, 63.49284156676262, 58.379957522115404, 56.45062600412677, 52.7940748583886, 54.8953866189526, 53.11177507523568, 54.91517497647194, 58.35408949082898, 58.94447288205547, 57.969552086245635, 59.88045630916473, 58.76784855319608, 56.50073820544828, 47.89859210291217, 45.250156771752145, 46.702061314736646, 54.367502274051795, 59.502735983940866, 58.556687754969445, 58.65992453790481, 47.87061383647304, 59.207201080937544, 58.23247640363632, 56.513332936071585, 50.97260852013865, 47.044723495360344, 47.13609903089462, 47.94928089264901, 47.92457780530376, 51.801530853394546, 55.70018637564875, 56.87557951096566, 56.82817374506305, 56.16645420751264, 54.363881926382746, 49.901699481471894, 47.70037904862435, 48.40348351386286, 51.617187300036036, 55.444467452264604, 54.96932329670076, 56.43682318349039, 52.761774140019575, 53.26524565296789, 54.401022849544404, 52.946917856893236, 49.334010924062426, 45.79991225273379, 35.77148252917875, 27.792589279913134, 21.767332515408917, 9.41539268339834, 8.070115812363165, 3.165535609568319, 3.936751787700961, 7.490943535681694, 9.369536253713793, 15.217240068220324, 10.136282155590674, 15.132257996066926, 12.851691957442993, 11.990527741370663, 7.652694727143935, 1.6453506917722764, 0.30519082841853945, 2.4150175336868536, 9.94965087982916, 26.40719440675551, 34.26358222961426, 25.933540751857144, 22.73978025682511, 36.19935427942584, 39.64386993838895, 27.89988571597684, 6.745004826976407, 0.578154728056923, 0.11828770635709648, 0.08239228128185196, 0.1497916243369541, 0.1476424106306607, 0.1993356795320588, 0.14073344668553722, 0.06708186089752183, 0.1982317774766876, 0.11214539724131746, 0.14629346769182913, 0.12090121531077933, 0.16792031365536875, 0.13122295540186668, 0.1699689706607211, 0.2117993937985551, 0.09545501501810166, 0.06440582384745921, 0.06010740026531201, 0.14148971336262842, 0.07950864206518858, 0.1328420209427995, 0.11977453746141926, 0.20757031266487416, 0.09752851625483844, 0.09978390974743713, 0.19104939675138843, 0.15776586418430652, 0.12462127698405136, 0.07921744438429033, 0.18975040274521998], [0.019451301815288684, 0.05522252871624886, 0.05151240703379435, 0.030831943957075, 0.03548326977198163, 0.03245629550468537, 0.03428250355946441, 0.036601892206817865, 0.06283095774931774, 0.06271248225182777, 0.029572623729285215, 0.017122137886021408, 0.059650961249586076, 0.07323378441675056, 0.059316809018773425, 0.007161921868476296, 0.0253312909344752, 0.04334430480676313, 0.025231393069149028, 0.08384322116692221, 0.05965077355804463, 0.10049020450922752, 0.05996725597088376, 0.04140047927296931, 0.011286889259222777, 0.03024415342107175, 0.027417842479002093, 0.1269098650664091, 0.03164703469543207, 0.011423589988431383, 0.07500527847197748, 0.08783456223506121, 0.054894869080594474, 0.12579103961827295, 0.0748398724282461, 0.06427001178024278, 0.03448317646079006, 0.2702721424641148, 1.8269760426013701, 13.081665423608596, 27.074011064344838, 33.28842609159408, 28.603702091401626, 18.932257083154497, 18.463782918068674, 16.15959930804468, 7.965882257107766, 1.5958565089010424, 0.27230347056061993, 0.4153596651890586, 1.2622530421903058, 1.6824907569154617, 3.8699285734084348, 5.298269477582747, 10.486085011113076, 9.013062427120826, 5.166633263711007, 3.4591237912254953, 4.4724732733541925, 3.4370008880092255, 2.338132704457929, 1.7578337269444622, 0.5644331127405167, 1.2128759175539017, 5.885593910371104, 15.096756623637292, 29.24567053394933, 40.64118354551254, 51.10196044368129, 54.73348294534991, 57.40150267078031, 55.5906149648851, 54.409432411193855, 51.55448429046139, 54.009891940701394, 54.50595017402403, 55.69323201333323, 58.34288720161685, 56.40078052397698, 52.21773747474917, 52.46264634593841, 50.223514264629735, 46.777049187690984, 43.739828525050996, 41.760800576979115, 44.17896532243298, 50.613609667747255, 55.80650614153955, 55.14613197695825, 55.960482705023985, 44.09627783683039, 53.40295222497756, 55.59535711042343, 51.18743281210623, 50.316843140509825, 43.1558778209071, 43.24737494991672, 47.2189591007848, 49.54853319352674, 49.7790861898853, 52.47622951384514, 52.2637233426494, 55.23857439717939, 51.84025249173565, 50.314136705090924, 47.17240841157975, 45.345607649895456, 42.98349357420399, 45.622389701104936, 48.84182407009987, 49.73091556179909, 50.57370347361411, 47.57902483786307, 50.454620315182595, 50.95258482040898, 45.52815475771504, 39.813998822242986, 30.42841026859899, 26.637727791263213, 19.548655594548872, 14.447326852429299, 5.630405977849038, 3.8355286515528157, 1.0384781466376398, 1.3895056396722796, 4.592835124461882, 5.749554345684667, 7.261744737625123, 5.077956809151558, 3.870066836957009, 3.3881382067357344, 4.377744111322588, 0.7227035683970298, 0.12613142780478925, 0.6975089590395651, 5.591331326192425, 21.84319507691168, 40.53285944846369, 48.35441858537736, 33.15086856965096, 23.900152675567135, 23.724318704297467, 27.85142679368296, 12.492516598393841, 1.0252256835660627, 0.1196373234533014, 0.037965678099182346, 0.02686311438259098, 0.05239630395907068, 0.06673918210811193, 0.051893508963046536, 0.05787012858256217, 0.03318816994226748, 0.013602298079809595, 0.036455121251844594, 0.036902466803909316, 0.02819798045581387, 0.08316375480424013, 0.03804972943579478, 0.057511630077515884, 0.021874278956543536, 0.02112383071723725, 0.031984437054263494, 0.028841804577818805, 0.028069609017562003, 0.03738190760956176, 0.06720225927570174, 0.028548559526942914, 0.03503505471012285, 0.010247885384747099, 0.0830017272082548, 0.11908695056673982, 0.07182274239077684, 0.0270750219633262, 0.050172124718946796, 0.06306643402504344, 0.011942491025453614, 0.07461398374289274, 0.04509658920728872, 0.012227108011082297, 0.044619228330350695, 0.032797974549354084, 0.015906352519748673, 0.02310494941118504, 0.06739668473000489, 0.07978923708921479, 0.04728609147752005, 0.023596289477521376, 0.06792084208779758, 0.06251583897298382, 0.013902591139588867, 0.02102586530870007, 0.035634227397461096, 0.02824648339751988, 0.028344981237164432, 0.050797566561208624, 0.028113590125294945, 0.0811388158810235, 0.07171902940758774, 0.008808087290925606, 0.020597779207051765, 0.02814965754477007, 0.020683370380392, 0.08692947531779928, 0.054011673125768864, 0.0760661953339173, 0.023764346185470783, 0.04745832336465678, 0.0484885277617122, 0.0811815023001644, 0.03527372557249281, 0.08985762424286335, 0.0686173156023987, 0.15456318765157653, 3.110633949118276, 20.51219759448882, 36.03312030915291, 38.83306895532916, 27.86341355692956, 21.397774642513646, 18.279174604723533, 17.866129413727794, 8.980628348165943, 1.0787787841212366, 0.08951663850776612, 0.17390249507321467, 1.0098269485658216, 2.0236933255387894, 3.5847644171407147, 8.51133931067682, 7.948382602583978, 9.606143428433327, 5.7693750627579234, 8.247402041189133, 6.115156017964886, 5.1214514816960985, 5.103823859845439, 2.7952133647857176, 1.6469756561902262, 2.77485381211004, 8.315034489477835, 19.06620602453909, 34.23943611883348, 44.626139056298044, 53.3706005157963, 56.615577359353345, 59.79915342023296, 56.41805071984568, 54.05467364095873, 52.15926670259046, 53.84771370118665, 56.46559376870432, 56.277163105626265, 58.09879418342345, 57.75357069507722, 55.14474345791725, 56.00797868544056, 52.674666143232784, 50.289421850635165, 45.8499107053203, 43.85926861916819, 45.220334991332024, 53.78749355193108, 56.563076434596894, 56.93531328631986, 57.017600690164876, 45.56721764226114, 54.403054637293664, 56.9683474879111, 53.01312354303176, 51.426054123909246, 45.262014096783055, 45.819088720506244, 47.57263137448219, 51.253391388923895, 51.97763350702102, 54.12066359673777, 53.81455006137971, 56.617307124599336, 51.37981330194781, 51.495742874760786, 48.88798252228768, 46.39398659429243, 45.69597728790776, 49.47920922310122, 51.72206755607359, 51.831662501058275, 53.2316074063701, 49.263306279336255, 50.41736172091577, 51.10470218043174, 46.80014802563576, 42.674528475730654, 34.26133078913535, 28.902837730223133, 20.457229498893987, 17.147229563805368, 7.301464128878809, 4.261921423096811, 1.4747775994962262, 2.5232197921122275, 3.6238640739071757, 4.791304603699715, 8.027989066416218, 6.497102697049418, 5.222426527930844, 4.906971868007414, 2.7166884945284937, 0.48088531039895555, 0.12549598085423633, 0.5331398919224739, 4.837212024196502, 20.07043477027647, 44.44426267377792, 50.332673826525294, 32.891629319037165, 25.008745885664418, 28.096039525924194, 33.05953225781841, 15.838703340099705, 1.6251914251235224, 0.015747947562035295, 0.020771290461022048, 0.02897939971467901, 0.007676844036341795, 0.1287126691351014, 0.04399202065542341, 0.058485243559604695, 0.026463415668976885, 0.01263039680423155, 0.1009376688049205, 0.06780583696860461, 0.03319523710336897, 0.010944276544896346, 0.0395270265758999, 0.08946762420237066, 0.02830160342367186, 0.011319426928586777, 0.02257071608196824, 0.10088678524498979, 0.019581483136261665, 0.01985745098922522, 0.0028711050606122423, 0.03549291481894832, 0.03303684459458436, 0.06538882956749971, 0.02018136253971006, 0.021533375575898156, 0.030368416712829666, 0.035472452610490784, 0.039189756367235415, 0.03480991679093531, 0.14478220604360104, 0.1469280796065446, 0.11768104899073802, 0.13652757801596196, 0.1354809333720515, 0.14887754354746113, 0.1309894364807875, 0.09105289760496348, 0.19215311494565782, 0.2004504447141963, 0.0908727290469312, 0.09563361309588918, 0.20112925990214273, 0.1435371599490604, 0.12414878459587214, 0.14087138847718317, 0.1180776144047418, 0.09474637602726299, 0.11067168922313761, 0.2668069735650094, 0.12123219593758545, 0.2543900213054111, 0.16567555346315907, 0.15725603267069788, 0.1005694869485113, 0.1936015420623364, 0.1314812342846586, 0.2196690320007263, 0.2391613271808432, 0.26776927192845656, 0.15377518961266165, 0.19991802892857985, 0.10526336894761171, 0.18491355341769036, 0.2317480628769244, 0.1664936587574982, 0.15616276391571568, 0.43563684809111786, 3.6887094330403114, 25.92594704320354, 45.61813785183815, 48.087822929505386, 40.569129605447095, 31.03258275216626, 29.342027479602447, 21.565410860123176, 10.466355489146325, 2.1399350945026647, 0.820735733835928, 1.2991440368275489, 3.555500839025744, 6.8489844087631475, 10.546359092958513, 16.120083389743684, 24.78607685335221, 19.17787786453001, 16.31254134639617, 12.631468522933222, 10.467517491309874, 10.491601824760437, 6.892589397968785, 4.347050584131672, 1.1101630161846838, 2.1939324034798533, 6.954322111222052, 17.61204807989059, 32.45260234802, 43.4552841032705, 54.888918630538456, 56.4744387134429, 60.86902695317423, 59.89964062167753, 54.556497758434666, 52.84039020538331, 54.591226423940356, 55.00755463877032, 57.56865839804373, 60.40713256405246, 60.57289192753454, 56.013022853482155, 58.597480404761534, 55.26190073259416, 51.68700941147343, 48.312814004959606, 45.97266912460328, 47.25804551955193, 56.14124905678534, 59.36408412071967, 58.288123069270966, 57.636433032251176, 48.84465994373445, 57.08157847004553, 59.03846856086486, 55.36443541126867, 53.61696458631947, 47.494788016042406, 48.08348086572463, 48.93783192480765, 55.01115929695868, 54.21085849885018, 56.37572050094605, 55.01360685594621, 57.85446190064954, 53.530739122821444, 53.288207207956624, 50.21499879898564, 50.05983375733899, 48.04936016759565, 50.38094251386581, 51.87652657108923, 53.81014916204638, 54.18049150897611, 49.62743166954287, 51.09016195420296, 51.97125181075066, 47.857505275357155, 41.70746810974614, 33.287300371354625, 28.606863521760513, 22.453508030983713, 16.536189010066373, 8.209542343693396, 6.027804834227409, 2.422049117665137, 5.186059782581945, 10.378859177712473, 12.009477692265666, 15.088300974138322, 11.689764318927644, 10.645431299363414, 10.214535401713464, 8.204848247189677, 1.5457384240242744, 0.643836961638543, 1.3824446379177033, 6.805046508389135, 26.484159154276696, 45.507597615641934, 55.878026639261556, 41.03272238085347, 33.669766764486994, 34.77541231339978, 38.54851276643815, 17.50829354409249, 1.917681220558382, 0.1741341447397586, 0.1361050805257213, 0.19600633802192827, 0.12236532424726795, 0.1918151782404992, 0.11870663387761002, 0.15474292720037122, 0.2115809361660673, 0.09281560463169891, 0.144314831122756, 0.13661946260160016, 0.13546604062280349, 0.12986866516932366, 0.13565558609702896, 0.1981022932957257, 0.07240719852908965, 0.08413076460842164, 0.11878983868706612, 0.18157077472536795, 0.11966363091262118, 0.11408503993504471, 0.1430351884975549, 0.10471913242532362, 0.08398526152896305, 0.1573505372770371, 0.1363162909664454, 0.20780145671338807, 0.08234408669053547, 0.10980425552735407, 0.1675962891069151, 0.1412477368308652], [0.04018651336551674, 0.024641700719873753, 0.035270052180895885, 0.08368479418418101, 0.09724995902469082, 0.01164813035903799, 0.11030353801024538, 0.006333157897085673, 0.08079163249461882, 0.0073541117824553965, 0.09187734610731564, 0.03765544696380535, 0.02592102924902593, 0.09953484690237431, 0.11294824972508416, 0.05682469818801169, 0.04565240131811269, 0.015721612332028248, 0.05241875799613134, 0.0833572915965511, 0.008842077654516025, 0.013067659681602834, 0.02139328682284442, 0.07301091411781889, 0.02889926308735965, 0.06374936693558289, 0.1259803476052419, 0.009101478856117015, 0.037298928796043324, 0.030425363858681054, 0.07046133520141726, 0.0732619994350018, 0.037713344058682846, 0.07618046500870297, 0.04956035371569376, 0.06113484674584001, 0.06269305043162839, 0.013771266432388896, 0.2894568839861501, 6.608410246910588, 18.959352816304854, 31.657424165356545, 28.862180402201993, 20.496162945224395, 22.536277886359922, 19.69027080843526, 11.395820917621737, 5.705900326851876, 0.891743442944942, 0.2706736644669887, 0.8450869110322768, 1.0852611137013282, 3.0651040567505747, 3.662680094280551, 4.508489456868941, 5.606178968183456, 2.9871236605028955, 7.075718487462691, 4.920059346383618, 4.50236467584487, 3.768374977573272, 1.9160547852516177, 2.138015584599587, 1.2812126764366705, 1.7079577258517666, 6.61272632498895, 14.34452937495324, 24.695264177937663, 36.428381473787375, 48.625062127267164, 52.19835704372775, 56.8685467012467, 54.86315650324668, 56.825004469963815, 54.33051824569703, 54.38791036605836, 55.35495896493235, 58.607015686650435, 55.686144290431855, 55.47832535159204, 51.51851615598125, 49.59868069617979, 46.65163924617153, 45.37054607945104, 43.51931679633356, 46.81976772123768, 52.62861751740979, 55.18925059226252, 55.23730747161373, 56.339132631978686, 44.01018573391823, 53.175639106381325, 57.44442124520579, 52.872059422154585, 50.003622270399525, 46.34886757020028, 49.97423587306854, 49.89141894925026, 53.16864159799392, 50.547933501581994, 52.282283998304806, 55.172921765235166, 53.8089410720333, 53.187390527417584, 51.30128745109805, 48.25456288553054, 47.26010476389239, 45.073301023052586, 47.72546260587631, 48.89067326822589, 49.80479732636483, 48.86976311283727, 45.80285403036302, 45.79671944341352, 44.31274167952999, 37.152827555133456, 30.073363204156202, 23.206159876238917, 16.863322527177875, 11.186606595593116, 10.05910756126527, 2.292413312581278, 1.659495739206191, 1.1135319644404997, 1.8018226181307149, 2.7303214275067855, 3.094079830954152, 6.570388751645242, 4.723784923553467, 4.002954532061854, 4.136770848304995, 2.400546439232365, 0.587635096763411, 0.46634128437407557, 2.024659209193722, 11.167020240137655, 17.928240145406416, 17.16761019922072, 16.612379089478527, 33.25764333048175, 45.212470639136534, 30.513237407130582, 19.50105174895256, 3.4770585836902743, 0.30657698790873256, 0.025952339262491273, 0.0933708115330627, 0.02728913204684373, 0.0365979966497229, 0.026312015627721147, 0.0607446322007285, 0.09213809945410298, 0.024124614353622162, 0.05152052756579173, 0.04779871155117308, 0.041817575843343814, 0.029978759496683077, 0.050683492238843636, 0.07338022212347678, 0.0483336094616642, 0.03286043369782067, 0.07944028403970503, 0.024894525056644797, 0.06462532335952406, 0.07624349872311277, 0.02003105800418604, 0.04782999475156108, 0.09070404414688388, 0.05966481594969669, 0.07002383770961916, 0.08943053788595623, 0.053002946003670656, 0.040849003219796766, 0.05676734501556043, 0.09781197644770147, 0.023155244998633865, 0.06045758671637985, 0.019901790243062763, 0.07149041344922397, 0.01957362498937836, 0.053531550501863805, 0.04978386369804221, 0.10600597627701298, 0.019544302974076524, 0.09269034925607905, 0.03767277204221295, 0.09030542561724302, 0.01652959568966781, 0.0788754933784085, 0.033309805552445115, 0.03626955177394613, 0.0680331505774971, 0.023336420962286573, 0.1040480700471709, 0.022205393648736423, 0.029513596654719407, 0.011985188935913388, 0.048476400589870836, 0.015898037592940513, 0.02149858177759715, 0.07100088326560874, 0.02078115384304716, 0.013684162235398208, 0.10176507440666038, 0.04248083944642737, 0.04084806476208953, 0.029367628176846815, 0.0877863293393485, 0.08623252682868512, 0.07582172135552091, 0.09790788299494213, 0.028108162392351418, 0.027838256210088733, 0.028853322709760362, 0.6445888309709488, 9.511759434976886, 25.799499634773504, 40.85458009473739, 33.16559314727783, 21.207926042618293, 26.06052552500079, 25.12461662292481, 17.139649583447365, 9.310869363046463, 1.0117827403929927, 0.31974260725321313, 0.02157657144350871, 0.7535720087828175, 1.373107313148437, 4.237062911833487, 6.041481158425731, 8.402608267722592, 5.676070211395141, 7.085310643719089, 8.052683818724848, 6.282285269229643, 4.936848561609946, 4.647302627563477, 2.33141785187106, 2.44511240913022, 3.4321462194765773, 8.209229534672152, 16.71395278746082, 28.965901597853634, 40.73498702818348, 51.39055667384979, 54.500286271495206, 57.67510760215021, 55.32595695987825, 55.989916170797045, 54.30142210375879, 56.16996865118704, 55.768384625834805, 60.5303067545737, 57.283882556423066, 57.19529582608131, 52.63133964230938, 51.64126280815371, 46.65731883818104, 46.964154089650805, 45.39265255774222, 49.363711111007206, 54.52542081955941, 57.28021121794178, 57.37069637544694, 57.447457159719164, 46.74670965440812, 54.71581266772363, 57.87927481435961, 54.385917802010816, 51.4754093077875, 47.75434693982525, 51.03079295927479, 51.108961874438876, 54.08847662710375, 53.02727545461347, 54.48232573847617, 55.86781670970302, 54.949946788049516, 53.796738578427224, 53.4179082224446, 49.106207509194654, 47.6781980452999, 46.67978617452806, 48.80218851950861, 50.23079026129938, 52.11061754534322, 51.30424491820797, 47.21002394153226, 48.34457343624484, 46.09761230407223, 39.434258476380386, 32.09670216806474, 25.189639714456376, 17.376448954305342, 14.714123529772605, 12.276495002931165, 3.550821941706442, 2.4370644409810347, 2.0734246892313806, 3.4386938810348515, 5.110160939155087, 6.3988899800085255, 8.28472045160109, 7.409740176893051, 3.6036619063346618, 3.333060529924208, 0.6582162481161856, 0.17424128979684847, 0.6036041076144865, 3.1848824552951323, 12.089299886457383, 22.362583568019254, 26.22354119054733, 27.76391871513859, 39.755704556742025, 48.45869087403821, 33.38550867572908, 24.58138208235464, 5.068928493607429, 0.36522147816515743, 0.03741580316977155, 0.0262307720033512, 0.04333748662423703, 0.012664040513036233, 0.010387825708265507, 0.08643111214041711, 0.024170512596385616, 0.046186054335726846, 0.07773796772404064, 0.01931132797542359, 0.05461861777509894, 0.034479978043706186, 0.03596003310033872, 0.050750881163102966, 0.08168028682590493, 0.04644322239102856, 0.02020482781283077, 0.013284081435431878, 0.05643462536916618, 0.020732028454902674, 0.05382791161537171, 0.047255953578578855, 0.037830532528460026, 0.02439753509186689, 0.058582414151920434, 0.06539732548257997, 0.01130911825795568, 0.04235343902461952, 0.00426741904624167, 0.03760049547699671, 0.03344079126573859, 0.11568018821098151, 0.0941187584952962, 0.1448383756102093, 0.26998164192322766, 0.21099743763765982, 0.1885674863813385, 0.2715933376983289, 0.10074499003108471, 0.2593291280490737, 0.15757524618698707, 0.2215840219850502, 0.1280473983816562, 0.14766160879404316, 0.1784523065772749, 0.145784693379556, 0.17275146328874175, 0.22167955314920795, 0.16323076771391978, 0.17540229604609553, 0.25197552667269785, 0.1419218022736811, 0.15253982686948392, 0.12534644049141677, 0.1682185057190157, 0.19340317125522322, 0.20035217095526958, 0.17534631034058912, 0.2582377898356607, 0.20732482745041772, 0.14434414164673898, 0.24199686373674104, 0.2119882957589242, 0.16877264775816472, 0.2010390913534549, 0.3160693688738731, 0.18958364072586262, 0.23638160779110848, 0.18769174063157654, 1.0387864204183703, 11.40902263502921, 34.89993187689012, 49.54883521603, 42.47311476738223, 30.403265914609356, 36.33514673479142, 28.938835282479566, 16.251700482060834, 8.665258019201218, 1.227319432843116, 0.5902915219626119, 2.282891268691709, 3.154040123185804, 8.53003332691808, 11.719828305705903, 10.686425951219375, 14.190984272187757, 9.89213324362232, 14.809609709247468, 11.532465507907252, 12.861040926748707, 8.963396395406416, 5.255341097231835, 4.2945192610063865, 3.414230058270116, 2.779338306957676, 8.946769468245968, 15.481093006749308, 27.5219928064654, 38.94671178633167, 51.249343502906065, 55.06301695300687, 58.4954164105077, 57.47299178954094, 56.218637420285134, 54.7214844149928, 56.367907139562796, 55.105853157658736, 61.872420234064904, 60.95658210016067, 59.812540469631074, 54.883144901644805, 53.03160967365388, 50.14566306144961, 50.2402941642269, 47.436560430834376, 51.38695201566143, 57.86990819438812, 61.6127436391769, 59.65830895208544, 57.35866254375827, 50.409265948880105, 58.025465473052, 60.021014444289676, 57.96756736693844, 54.03649737758022, 50.39278807178621, 54.555003335399014, 53.9812429489628, 58.08100623469199, 54.86037162042434, 56.643602694234545, 58.750492065183586, 56.05185824055826, 56.41241819627824, 55.574843114422215, 51.78163266951039, 49.55111411310012, 48.75411202830654, 51.87278070757466, 53.060913701211255, 54.54093771596109, 51.766606069380245, 48.904232901911584, 50.09526060473535, 45.24754447321738, 39.91685513527163, 32.61594553147593, 26.1373451448256, 18.876661408332087, 13.478688713042969, 11.692942419359762, 3.164556487914055, 2.6433095287892128, 4.468713191247756, 3.5917827631196673, 7.464735729079093, 10.496831324792678, 15.085555315017702, 14.54438296056563, 9.332260008781187, 10.343101870629097, 5.7222369986195725, 1.1730668020825232, 0.9787297849693607, 3.8424665889432355, 15.924472828065197, 25.300101503249138, 26.561070949800555, 26.43368217252916, 41.20906822143063, 57.37445400607202, 40.999252796173096, 27.091312639174927, 5.569071385168261, 0.5552455734822058, 0.09329008884848126, 0.22879790424579577, 0.12179507137907129, 0.14211807399988174, 0.08055566209218196, 0.275156841643395, 0.1379162502745467, 0.134857552306306, 0.17781545768582052, 0.09282115876914994, 0.19575000500246403, 0.08011533007506402, 0.19680769663424263, 0.1510761086378367, 0.18948967238107037, 0.11408792042564, 0.15703418892958473, 0.10604767444273157, 0.10026590928675667, 0.19267538772715678, 0.11993098027643659, 0.10930347151213116, 0.13826794591882538, 0.09714688189447888, 0.20571150756891698, 0.23041352239106935, 0.11176040741584956, 0.17812039132320112, 0.1406977929535412, 0.19751790610532607, 0.13627270056355384], [0.03713977402977405, 0.007243009881236621, 0.0591434165084314, 0.056919107033360394, 0.11045261872031036, 0.059734303954868555, 0.042318804189562804, 0.012569124134437693, 0.070215129864312, 0.033945520633771535, 0.04428888738696133, 0.02699408285890616, 0.09563923618125339, 0.035883646473408706, 0.019494603019988826, 0.01052301149860385, 0.018911887816483938, 0.015825523540467745, 0.08224254939705133, 0.007002984958460495, 0.013892828306603818, 0.01903062186864836, 0.04994031800437839, 0.02288465891333838, 0.04928321757864568, 0.03042508423658869, 0.04056716713333323, 0.05507868038670671, 0.13570627047409936, 0.025880780904704047, 0.08544593073067167, 0.03280142194501335, 0.10241876957156967, 0.03332067250965103, 0.0070804431508745885, 0.01696214042303543, 0.04688936901549178, 0.05923111059312379, 0.13875019826715992, 1.2656631753329308, 12.619903414480149, 25.57385156231542, 32.51433653216208, 29.11403382978132, 14.22698574681436, 16.52016808909755, 17.12774911234456, 11.302954881421982, 5.144815079627499, 0.7072827087775354, 0.10686135174886835, 0.6697331236735468, 0.9862183250727193, 3.566113792119488, 2.8316960652028365, 6.45462784074968, 2.888661382659789, 4.96964693069458, 5.7409364081198175, 3.320758996471282, 5.450805060325131, 5.383208403664251, 2.29083112651302, 1.1984357117645204, 1.7797752205402622, 2.6583268132901963, 6.827103466756883, 15.022615002047631, 22.80263427765139, 33.155991185096006, 42.59106043846377, 50.79003003335769, 56.223022630137784, 56.43938449121291, 53.96658897399903, 56.805282792737415, 58.04176684348815, 57.04734794555172, 53.958183334719756, 55.58383318685717, 53.03191561852732, 51.866410778414824, 50.93709145822833, 49.0940167826991, 51.32226820914976, 53.215376638597064, 54.13198355705508, 57.682693466063476, 56.18088852974677, 52.71539211273194, 43.48066968302573, 51.30845754377304, 55.52955935078283, 51.90084918852776, 52.05652413829681, 49.43596116958126, 53.83726058467742, 53.098035012522054, 52.600039128334295, 51.9646857630822, 54.26580306022398, 54.474112295335345, 53.5580192073699, 54.354432936637636, 52.380096143291844, 50.607118145112075, 47.753884100144916, 48.04903853324152, 46.83653193135416, 50.98346564077562, 48.832755550261474, 52.38400282398347, 42.71942392472298, 36.416261349954915, 33.14760908003777, 25.84457943516393, 18.723122189121863, 12.627563803426682, 7.053049639348061, 6.61542393507496, 7.2152396459733295, 1.9701284578730984, 1.411996019944068, 0.5538532546451015, 4.079253702394424, 2.584098654408609, 4.739742106006992, 5.55615060752438, 5.3792610283820865, 2.5708444753000816, 1.4099427817329284, 0.3466690656158232, 0.29766637411329055, 1.6267715274326264, 6.922864702440078, 20.193561892355643, 20.810586021792506, 25.639712079878777, 23.859660087093232, 29.397442725396928, 46.0885202500128, 26.668000644253148, 9.84582378018287, 0.940912988397383, 0.1090995925328424, 0.04456679727281294, 0.02302374792165093, 0.010588569472724152, 0.03571846259517535, 0.05336233700114874, 0.028111025645968415, 0.01344850592901029, 0.04521610658435572, 0.022979456548308654, 0.06435205979693322, 0.03550444061176912, 0.022222092450265924, 0.13056551406700767, 0.03935001046967603, 0.0157296572128431, 0.028247862355783585, 0.07623124897720353, 0.025033953058863842, 0.0335754158966724, 0.053708620234242374, 0.048481839814133225, 0.0167978739350914, 0.03843498356159657, 0.04311942735746984, 0.09964235968166783, 0.018383434620655833, 0.05813292738410735, 0.02718533670920278, 0.034319708619507096, 0.02561248925274178, 0.036146690423089656, 0.03775597685166905, 0.02789230562836653, 0.02075067503497966, 0.03341285970001932, 0.0794365531915138, 0.028637498504512256, 0.024146204626548196, 0.027915644496979735, 0.03758602790654667, 0.021609361921887726, 0.01716964299820604, 0.032780231953027754, 0.03613876141307335, 0.05404906204691338, 0.004506764065984998, 0.016878439571648356, 0.060149879840713356, 0.03291863339742826, 0.03519315227505661, 0.03320403562317933, 0.03435878676452464, 0.006237314073293801, 0.040524829284197865, 0.040690668167606484, 0.029388364261737274, 0.031181304948404435, 0.05141636642116693, 0.0435203020160477, 0.14953660898871962, 0.054005693809519854, 0.09367070431190153, 0.07750845544280545, 0.0736969918192875, 0.03916781560908403, 0.030246022675606995, 0.04218430213269688, 0.012318479317811229, 0.09273634517505285, 0.20143212510212777, 2.913545144181098, 16.467423977390414, 32.99131831815166, 39.7596465387652, 29.52907354600968, 18.638608840204057, 19.51691577511449, 19.367879436862086, 14.412460903967581, 7.231209085833642, 0.8958400521547565, 0.1370643911462638, 0.17939301658301585, 0.2422606278090708, 2.8521105310609265, 4.826406384668043, 6.290997343678629, 6.749534674229161, 9.048500061035156, 7.301704374051864, 6.390954044557388, 6.358565072859488, 5.788491714385248, 3.620751182879171, 2.7611510119130536, 3.82357596389709, 4.772583621163522, 8.919777677905175, 17.894978446345178, 25.80595389489205, 37.147802998942716, 44.294710543847856, 52.841162912307254, 58.06015883722613, 56.48299340278872, 55.28019074470767, 57.0354788534103, 57.375858214593705, 59.64281951227496, 56.479122023428644, 58.22623591269217, 53.65376034090596, 54.53231634632234, 50.751010294883486, 50.810183171303045, 52.12892324693742, 55.28525060222995, 56.10459842989522, 60.210174668219786, 58.07351843003304, 55.27277746508199, 45.262618141789595, 52.75239967530774, 58.59748432713171, 54.94073706288492, 54.067507636162546, 51.757572850873395, 54.09875323695522, 55.393100092487956, 54.89485317660917, 54.29623280802081, 55.602617417612386, 55.2302001368615, 54.971413920002604, 55.774036761253114, 53.17757283487628, 52.57762278279951, 49.48455933601626, 49.2566696290047, 50.309778951829486, 52.05131915307815, 52.40411673822711, 53.42719639501264, 46.551163811837476, 39.59112190431164, 36.51577188122657, 29.431122156881518, 21.02141341855449, 16.715282470949237, 9.792966900333282, 6.130717531327279, 5.072487554242534, 2.758826517289685, 2.3134225078167456, 1.640239598289613, 4.831919275945233, 4.849088961078275, 5.7947905505857165, 7.101075139737899, 4.694243102304397, 3.0696177242263674, 0.8571777396625089, 0.24968437219579376, 0.24573152704584986, 1.8015386140154255, 5.546547174453736, 22.403185982857984, 25.348485900509743, 24.424361759616485, 22.320369059039702, 32.576241339406664, 50.93441247940064, 31.435755337438277, 12.414001534062049, 1.4000700534351411, 0.06341101271250556, 0.013144586400519456, 0.058323687107692805, 0.055605028755962856, 0.03987940403843119, 0.04998488899981303, 0.05491414002232975, 0.09668359788314951, 0.0550109735359588, 0.12718910411480935, 0.04612904973328114, 0.06052448534436765, 0.02717566293393893, 0.04631274229576511, 0.035087616002607735, 0.050645379364610686, 0.06734450648148214, 0.07085873565125851, 0.04848847796599712, 0.036499945056294246, 0.026337687234063784, 0.10550619583697089, 0.05262289361487474, 0.037238158871449774, 0.010853853271973711, 0.042191840437871796, 0.04876583243810362, 0.09982380760653366, 0.0754146988413507, 0.05698333584493207, 0.04649364246776508, 0.09417465993113096, 0.09293806378639514, 0.10711591510522751, 0.19250824266383726, 0.1310734456825641, 0.13700311943407983, 0.1194137866578756, 0.2098362934925864, 0.09185653915929218, 0.19198344179218818, 0.11926666713289677, 0.15467578725468728, 0.12937481424981548, 0.20823025144636634, 0.16877071721659553, 0.15775837184440705, 0.09029361254145062, 0.11261506276505609, 0.11820320685904835, 0.19064726187817513, 0.17214703523824293, 0.12458745420219437, 0.09661612085877888, 0.13776344637716972, 0.12957139241118587, 0.13428320086771442, 0.1474021961011233, 0.1131700934661973, 0.15566077714245166, 0.3145005127354976, 0.17469663713728228, 0.1576671920596592, 0.1461858936255017, 0.24474606218357242, 0.24492342685980184, 0.06189749876578009, 0.19235815071771223, 0.1339315665104697, 0.15092828431196753, 0.3560326212356168, 3.498642896452258, 19.64699725950918, 44.30199830762802, 49.39558036865727, 38.848072021238266, 23.189695727440622, 27.467042361536336, 25.768350132050056, 16.71047168393289, 8.297610340579864, 1.3714485182877512, 0.451899056112574, 2.0299577184261817, 4.92445191068034, 10.326398457250288, 11.4660588002974, 16.067167674341512, 12.646495123063366, 14.186984435204538, 14.97416784686427, 10.308349670902377, 14.835299272691051, 13.91457582673719, 5.514492584813026, 2.8685016257147637, 3.5092808546558505, 4.301455972656127, 8.399637072317063, 17.948138329290575, 24.904334352862453, 35.481156533764256, 44.951232940919944, 53.48928359247024, 59.10272090665756, 57.77489662170411, 54.80142624147477, 55.957666443240264, 59.30517012073148, 59.342479705810554, 57.44961838568411, 59.45687955425632, 57.47486668248331, 56.2329815280053, 54.879438261831964, 53.14607228002241, 57.16531322848413, 55.84831860757644, 58.599316074002175, 61.50641210617558, 59.84318202541721, 56.39073533396567, 49.246083151909616, 55.46835076424384, 60.570126656563055, 56.94546045795564, 56.026962957074566, 53.491668393535, 56.69588004389117, 58.03798175627186, 56.356018435570505, 55.89841511941726, 57.63478171440863, 56.188537151582786, 54.62416648864747, 57.92790043738581, 56.16410078540925, 55.046221363929014, 52.62044329797068, 51.473334373966345, 51.59960723692372, 56.50775532568655, 54.110708621240434, 53.737863802140765, 47.75837129162204, 40.06993347598661, 34.55175484380415, 29.61984503653742, 20.598527000796413, 13.746796442616372, 8.996310964707407, 7.964171613416365, 9.653969868536919, 3.932797303122859, 4.386282620891448, 2.704322732263996, 8.601121383328593, 7.379357987834562, 10.064105641457344, 12.391742083334155, 11.69382691383362, 8.785874824370108, 4.951567255681561, 1.2396941430145696, 0.7812706224860684, 2.654869979427707, 10.288714285819761, 25.997851933202437, 30.397254882320283, 34.7698268582744, 34.838848806196644, 39.554475199791696, 54.334789706814675, 35.90204646510463, 13.643801866039155, 1.7702172624488033, 0.22748152004374614, 0.16018366831685268, 0.13772485086754446, 0.1872153105514665, 0.14084949368430724, 0.2290140023274768, 0.1034042727382433, 0.18347450321720493, 0.07993326927985876, 0.2122449658570751, 0.16994940477513498, 0.19234109760051776, 0.18818338521786276, 0.19014559686183932, 0.22519955862193342, 0.11643078583743303, 0.12188408313499344, 0.1721242977486503, 0.16171199840403375, 0.1782070971544712, 0.11930536223395218, 0.21097174304867947, 0.1763937976812163, 0.16909034442036383, 0.2023607309186651, 0.14874557724162457, 0.15652333085815753, 0.12103015556931497, 0.14393023966300872, 0.11334532075711798, 0.06681546914361178, 0.16825581420092814], [0.020099607551650658, 0.04659302705418199, 0.008384888830234208, 0.08012098380394521, 0.09053620194355327, 0.1435503826266335, 0.008731843347871497, 0.05976039307912993, 0.047760322885287386, 0.019594236584981124, 0.017442577142989444, 0.024869546759873632, 0.05847920678676136, 0.01642531197097513, 0.08336502908458633, 0.01587666182463328, 0.05887200304817769, 0.0501254316599619, 0.026730265160421693, 0.05310758978368775, 0.03518408945491237, 0.07486028101054892, 0.04769813952847354, 0.01760642611301474, 0.08326637994257674, 0.10114628986846055, 0.07469796996203161, 0.05652300893299042, 0.036010870694993966, 0.02490382153360594, 0.04779706063169626, 0.05879912510394089, 0.03967325360844693, 0.03232840095616637, 0.029021408146006927, 0.04241382207481131, 0.031012999261879635, 0.06292969882187825, 0.01879736533268325, 0.23059997287008072, 2.995719534735526, 14.609136389147851, 25.771691991436867, 27.568490543673118, 29.487700385432092, 22.313716719227454, 14.243298884361023, 15.46618211653925, 9.551500889562792, 3.9878757153787925, 1.1800070683802328, 0.07405149134536905, 0.24793082758063273, 1.1149696356827214, 2.1486986500601617, 5.46171268147807, 5.029457682563413, 6.106509643216287, 5.407263319338522, 5.385521621473375, 3.4963583609750195, 4.3781799847079865, 1.305786815862502, 3.543181654907042, 2.6552531459639153, 1.9074994830354568, 2.669861033078163, 7.7907886332081215, 16.18840225281254, 23.535195742883992, 29.42268317745578, 41.111283533034786, 48.659378943904755, 54.55085346775671, 54.74544617437548, 57.436635340413744, 56.79629664267264, 56.7411873417516, 54.65896575681625, 56.8822475402586, 54.7427789626583, 56.073137098743075, 54.8496517827434, 56.26545875303207, 55.40295308636081, 56.88919013546359, 54.179165747857866, 60.482481295062655, 53.02401596500028, 54.061004346416844, 44.6536740949077, 50.28950029803861, 56.93636055915587, 54.38246611625918, 55.57143065237231, 52.75211726465533, 53.943905907292525, 53.720554382570334, 55.463698833219475, 55.37553571885633, 56.4881395524548, 52.125330355859575, 53.900869661761874, 53.24266849025604, 53.9556690954393, 50.99311467139952, 49.47793445279522, 49.87523524991928, 50.015616878386474, 49.402652402077955, 53.055226264461396, 46.331216904424856, 31.68607511828023, 27.963330053514053, 20.688719941723733, 15.222631366022172, 9.177761770063832, 7.561816352029001, 2.3237981575150646, 2.0326891589549283, 1.6251362667929743, 1.8915480615631228, 0.8107260290172793, 2.268700868852677, 4.412675759484691, 5.598844135961225, 5.292496729281641, 7.180404095880448, 3.627073553300673, 1.9713312772012528, 0.5640119482432643, 0.1714658758212482, 1.544559138917154, 8.724228893556903, 16.420050571041724, 20.901281026101884, 29.531013158059892, 19.29737287182962, 23.96754095631261, 27.964583250784106, 25.808721127048617, 16.15546218810543, 3.9780822925029264, 0.03520842423782714, 0.016294224751031688, 0.03792320618466024, 0.03401164551295581, 0.051636639682035294, 0.08411293774242364, 0.09659059480914185, 0.09360672064846562, 0.009491780543729905, 0.027050792517501022, 0.01995640656640453, 0.018269459889721007, 0.05141681075216301, 0.030320925007183707, 0.0658879664936854, 0.024341825178013216, 0.036184531336109486, 0.06899871247550173, 0.057197553180758996, 0.03166331023338341, 0.03211083964654996, 0.04020005780001802, 0.0754271554309995, 0.01185265476740296, 0.04874051706264577, 0.010973056552991753, 0.05000356622340699, 0.039755102442277056, 0.01960714516650525, 0.046298466247296145, 0.034288624601979414, 0.04274923835069903, 0.021087462608251843, 0.0369537946948361, 0.07981562115732702, 0.030838488263168165, 0.030523476739143653, 0.0068154691384294105, 0.07745130528365413, 0.04657046576481193, 0.04433529699341424, 0.0675569043584889, 0.041774085031882416, 0.10662762598404962, 0.028532990705101725, 0.011956346683174133, 0.030518133275871797, 0.05909052579813908, 0.05797631602974669, 0.058959992076720924, 0.10255694885047213, 0.028600239818314874, 0.06459861753448363, 0.045867943986048626, 0.013077809388989644, 0.061924162455984665, 0.03529896433915823, 0.03861190007639028, 0.04468828732628496, 0.071656470667691, 0.0603691112220047, 0.040946051238044616, 0.05984152945119047, 0.07058717280385957, 0.04050456242816102, 0.04387484750740471, 0.07393110062806837, 0.024603024771016453, 0.09270570165808163, 0.02804452729892106, 0.0553159071733394, 0.09881582742016162, 0.32115533467262025, 5.271370353237276, 21.52061935394041, 31.929134591933224, 33.49240895240538, 28.47761554102744, 21.70583171229209, 19.562744748207834, 18.029172535865538, 15.061222891653738, 7.144981661150533, 1.483243300068763, 0.08861605618749896, 0.1839543040841818, 1.0022386331712048, 2.484230942303135, 3.5205066780890193, 5.270327493067711, 7.856264268198322, 6.434294273776393, 7.2712202033688955, 5.537531116316396, 5.679591028921067, 5.309654157007895, 6.033067674406114, 4.714181000186551, 3.443141848810258, 5.063316072187116, 11.264772568979572, 17.460864243968842, 27.87467468169428, 32.7551680995572, 44.78164534414969, 50.54423078413933, 55.025413190164876, 55.444549822038226, 59.47939395904542, 56.01227760314942, 58.0336553819718, 55.38132121486049, 58.0926517517336, 55.663982898958274, 56.86778968380344, 55.559149711362785, 57.795908758717204, 57.09449875739313, 59.58740426648048, 56.01006146400206, 61.48332503534133, 54.16875969979071, 55.085123431298044, 47.559950351715095, 53.75145481478784, 59.39343913908928, 55.19616573087631, 57.062064678438254, 53.45826941151773, 54.900442554104714, 55.693310460736676, 56.47641951037992, 56.07824402470743, 56.57714989877517, 54.11082236997543, 55.55067739179058, 55.464895156122026, 55.437673907126154, 53.36103777731619, 51.33592590208977, 51.087051514656316, 52.14029027569679, 50.54981231689454, 55.114482372037834, 49.10717241225704, 38.7651962618674, 32.433274868995916, 24.567744001265496, 17.53046278030642, 11.661274183181025, 8.25656371731912, 3.9335592235288317, 2.777635508006619, 2.5235666767243417, 4.028253574525157, 3.665434333585924, 3.205205971194852, 7.182858028719503, 6.154336573616152, 6.637580423585831, 5.8750040012021225, 3.835820377834382, 1.7029390532162882, 0.275547577128295, 0.3755654118234112, 1.207408378681829, 8.128299761203028, 17.44094644823382, 26.15858477930869, 30.826564181235533, 26.94315883421129, 30.360959229930756, 35.50465937583677, 32.80336814541971, 19.984097519228538, 4.966586011071359, 0.14273201686240014, 0.07007041585541542, 0.03655162151722658, 0.05394859344608361, 0.05457671659608042, 0.06492169979479044, 0.041548046959383834, 0.04088090695140343, 0.028419506270438436, 0.06535824733756243, 0.04812160228949882, 0.03446499719434688, 0.07285992584882245, 0.057358734249587984, 0.028349700338777997, 0.0387455249625829, 0.02559533079845771, 0.03731925310867448, 0.03162453660831577, 0.03151225684691341, 0.013677348840921639, 0.11287440651006277, 0.06842293611337101, 0.03475139916483914, 0.02970417826286247, 0.006409751846560187, 0.07378380490286697, 0.04659404595112128, 0.050127174509989644, 0.08161224289647034, 0.022808082679647113, 0.012874167896957408, 0.017292061933286248, 0.15748976609639584, 0.1717744407153899, 0.1181235566975609, 0.10402796023915853, 0.16490886799029766, 0.2506009504319199, 0.11180570619481225, 0.12958772540573152, 0.18519676080153835, 0.1430091874734048, 0.23329908448842265, 0.16643874557508578, 0.15333419875992885, 0.132270825786456, 0.14397923864664572, 0.24300298232945705, 0.12629978328702912, 0.16088664591793092, 0.1987900104253523, 0.25163078710677167, 0.14891670596215034, 0.1817604734171783, 0.13095199010304867, 0.16360235100071277, 0.1887969297146605, 0.17466429290511917, 0.1789290584143131, 0.21028391866674348, 0.10855071351773317, 0.1436346982635798, 0.138617588447467, 0.13373161756223248, 0.1076917757370299, 0.1705380667361521, 0.14563202737800537, 0.16717118691773186, 0.15549684964841412, 0.13880307365569378, 0.2216288381286206, 0.4876954643236053, 5.530941044130634, 26.81745275374382, 40.104120854408514, 45.35294248211769, 40.180940474233324, 33.22359323501587, 27.542228314184374, 22.992941794856904, 14.704348983303195, 5.812130858821254, 1.5374804864968024, 0.3422529670980669, 0.7912540351671558, 3.187314324801968, 7.214346326166584, 10.680604173291115, 13.720641097714825, 15.239844687523382, 11.900166138525933, 12.498758069930538, 8.946462542779985, 9.221891376280016, 8.585039665622096, 9.420253480634383, 5.827738950329443, 3.623971203642507, 3.90368890377783, 10.589067820579777, 19.003561850517027, 26.44556107059602, 33.204679566044966, 45.03344974210186, 50.712429861868586, 54.62653167786137, 55.46029813828007, 58.74556164587698, 56.82879347955027, 61.44610174240605, 57.74836963222873, 59.92431625243157, 59.12646301331059, 58.955557500162435, 59.210892031269694, 60.11234683375205, 60.20614247168265, 61.61757207685902, 57.4814562643728, 64.61705169370099, 56.63711901633971, 56.03978518516787, 50.11942240499681, 57.574514496711, 59.7994593651064, 57.94114628145772, 61.187460653243534, 57.077004986424605, 56.99147770481726, 58.57265180157077, 57.616091620537546, 57.82768780185331, 56.62314361141574, 54.35927314143027, 55.31654327146469, 56.23808060922931, 56.52169150690879, 55.37948554561984, 54.18516697422151, 54.081310456798924, 54.14402131111392, 54.17223491976338, 55.390158314858716, 49.49221580259262, 38.44619381812311, 32.45706992764627, 23.489859027247277, 17.482082305415986, 11.046014139729163, 9.80403975132973, 3.2297416223633677, 4.235017395788624, 3.166060962023274, 4.351025906301314, 6.705932136504882, 4.666830637762624, 12.331838665470002, 12.097654534924416, 13.634063601493837, 15.594287706959634, 10.001866452155575, 3.9883841526123787, 2.3608755873095606, 0.7299724557707388, 2.306053109707371, 10.90025592234827, 23.020145393187, 29.058859809752438, 38.9832055184149, 29.700734115416008, 35.02001131734541, 41.44184127930672, 35.98624014085339, 20.86962945999638, 5.399517618840741, 0.3240640479470453, 0.20408783017867999, 0.14548360550355527, 0.199014458865408, 0.1417697644642284, 0.17344062066366597, 0.27751700532051826, 0.14648445341135227, 0.16201789731219893, 0.1695574741930731, 0.104382551695791, 0.09848624873425692, 0.11888059712345563, 0.20036297279500193, 0.10154696151373849, 0.1918445806950331, 0.17032187672392016, 0.12515835058424743, 0.12383851898653854, 0.15695137482497, 0.15799308586264812, 0.16385894449007127, 0.12676951775868095, 0.1886334159081021, 0.11536272903603893, 0.10121719130585272, 0.15162222207553927, 0.0983369994848486, 0.13519754212710167, 0.14483866672362053, 0.10855519513209021, 0.12110247426936704, 0.09037874023159666], [0.056368780112074274, 0.044005634037837874, 0.013231816044407747, 0.03540247047860776, 0.029048297832149173, 0.03309306012646806, 0.018054961016581907, 0.05981814844774143, 0.09250513983950501, 0.04284965332537409, 0.025773333242884087, 0.04235998907637212, 0.026116940913902178, 0.04002155165278143, 0.04576670929729458, 0.035340980431365396, 0.025839134449920347, 0.011114737811318089, 0.042189649426408356, 0.09324331918070394, 0.050799841842343735, 0.1347157187880047, 0.05922232739507191, 0.04212036060409681, 0.03671134701899944, 0.04661873696492084, 0.0811065482576528, 0.02760119221713995, 0.10941847663132415, 0.08376750869736557, 0.039175533944921154, 0.07378639428005104, 0.04952962209861125, 0.029697852291827722, 0.05393355897056961, 0.015260429316831213, 0.058781604673112595, 0.01292067613723057, 0.03171831151590713, 0.07956372378694435, 0.8411661343228433, 7.162470529156347, 18.52396776599269, 28.455416887037217, 31.88402733495159, 25.082774739111624, 19.496964639233006, 26.141728393493164, 21.72142117254196, 8.22956310164544, 2.828754287573599, 1.2283741826972654, 0.12865288363349053, 0.7858189784230725, 1.8093659488424179, 2.5171317833085216, 3.17523023774547, 7.704632301484385, 5.2342916977021, 4.489118341476687, 4.951556469163587, 3.774422536934576, 4.051531125460902, 4.626972982960363, 4.378723723273124, 3.0549904704093938, 1.62203612346803, 3.0831266122479595, 4.854486142435382, 12.916969022443219, 18.68681476962182, 27.51364011918345, 36.53738021850586, 43.594779276078754, 46.68268872845558, 55.72034343596428, 56.8237453891385, 59.14452160558393, 57.01577286566458, 57.66703536433559, 56.694428766927416, 56.862831807905636, 56.990304916135734, 59.58582747367121, 57.84426373820151, 58.689612957739065, 56.841086187670314, 59.54312462960521, 56.9423774750002, 61.530013007502404, 44.45398230706492, 48.05208229249524, 55.215714823815134, 56.138334735747314, 56.68348927651682, 54.26926259071597, 58.11862960938485, 55.42225506997878, 55.71888823663035, 55.236071925009455, 56.018459258540986, 52.7604679907522, 56.45470526910598, 55.89196674285397, 54.163229157847745, 52.087730515387754, 53.078882078970636, 52.238628018286924, 52.69028109888877, 53.40500362457768, 45.74840761000111, 30.89861616011589, 23.99877675117985, 15.134430989142388, 10.028263022822719, 4.78250035355168, 3.097557502408182, 3.0419713883630695, 1.0047599817475965, 1.58398533300046, 2.5206415691683373, 3.741014729584417, 2.656864014364058, 1.5901508086150693, 5.208083891099499, 3.396029280078027, 4.0254713883323054, 3.9422301130910076, 2.356743370333026, 0.9408805675564275, 0.2620000476318021, 2.063508447139494, 6.718952444291885, 13.902208593583877, 18.27993554453696, 23.549773231629406, 26.13224998597176, 18.602122952861173, 26.176927743419526, 20.979846100653372, 12.157612865970982, 3.3784320565962025, 0.24425922862945065, 0.037865944942759897, 0.06763196565330991, 0.035679687054887894, 0.033606607166509476, 0.027098387645016757, 0.13339700567866528, 0.020740089615085916, 0.057184280707470836, 0.012787584639755229, 0.004743659519590437, 0.06362142259134881, 0.028291512130489273, 0.053381776482227354, 0.07556915748864412, 0.051005023171103774, 0.05731882872961222, 0.025266983598891287, 0.026703584233238816, 0.04120648282790377, 0.04354513858655288, 0.05547773175602479, 0.0701033806187972, 0.01017276184528225, 0.03521271816064273, 0.03845047768986514, 0.02019429601909172, 0.027561501201782978, 0.06277651954141837, 0.04986577381890628, 0.058523203216252796, 0.0308082124684006, 0.02294480830671326, 0.037583461512000337, 0.009746530634020607, 0.0456563581622416, 0.04147366365237583, 0.03687971399255818, 0.030726384701988393, 0.043168763419793504, 0.05230484838267008, 0.11362589279850645, 0.022080684110762614, 0.027750284418523796, 0.04899131126641747, 0.03821452260918675, 0.05571601191355337, 0.07681670102981791, 0.004425166125950074, 0.022982183821319092, 0.038029891588995536, 0.04133805842889894, 0.033311778228850134, 0.037852833347935835, 0.0632973176036631, 0.1115456116836398, 0.044716410413985296, 0.02314638902222918, 0.012386393969908599, 0.050160549130410924, 0.07761376954975628, 0.04215761162941495, 0.011764763415070071, 0.04422234498985833, 0.03570422102066298, 0.03209957049318379, 0.03095153028205518, 0.07430150413945799, 0.04814316766456731, 0.014127920580757482, 0.0516323993853744, 0.04104686840887993, 0.02926786820734701, 0.09057691185584954, 1.8103216588497164, 9.778493354397437, 24.53836544867485, 36.57266193820585, 37.18859957110497, 29.294815871023363, 18.995972064233598, 21.639975117098903, 18.728427194779922, 9.905103541189625, 4.2703981553354575, 0.9471391994626293, 0.060024080542667266, 0.18985426894599394, 0.319092229249016, 1.9879716875091678, 3.526768496920986, 4.873121323124056, 6.21961118713502, 6.646097360118744, 6.7269888904786885, 6.082953849146444, 5.163407604540549, 6.255996563742238, 6.532331955048346, 4.654645304526053, 3.93187873305813, 4.686821487642104, 7.26743511615261, 15.08047486505201, 20.89888249674151, 30.897311972033595, 38.495309737420854, 46.28428182294292, 48.37621911879509, 56.25292285796135, 59.02507366672639, 59.8109793663025, 60.20256919245566, 59.20679315443962, 58.25060952094294, 60.51751590544178, 59.30645273577783, 60.84188807395197, 59.63818719310146, 62.01883054548695, 57.90118909651234, 58.24842868312713, 57.02892849522253, 61.36464588103756, 48.797528743743904, 50.70412620421379, 57.410339770778535, 57.87106137121878, 58.54665825443884, 56.05617677011798, 59.1389439951989, 57.1742719219577, 57.32178834176833, 54.630465815144206, 55.13345879893149, 52.760475835492535, 56.97092056274415, 56.832351069296564, 54.8520601180292, 54.11541938781739, 55.58298203252978, 54.27504024197979, 53.06272975860104, 54.44587123009467, 50.33532142639161, 35.59655658660397, 28.412390447431996, 17.8381315354378, 12.485635780519056, 6.817531902943888, 4.8309073044407755, 3.3635961817156885, 3.2655482042220334, 3.2582430349242304, 1.9832181425825244, 5.954499658076994, 4.63179063412451, 4.552630830195643, 5.655854315527025, 5.925507949244592, 5.396508180326031, 5.247255131121605, 2.385132505047706, 0.6193531593007426, 0.2042404961802306, 1.2103906057534681, 6.899876181156405, 16.126215034915557, 22.669577675480998, 27.951992442530972, 30.944519658242505, 22.09616441880503, 28.85460238302908, 26.25089187775889, 16.21974297108189, 5.7757753902866, 0.5147129645751369, 0.029530295456248908, 0.025368103374456687, 0.05393091213679122, 0.009147782167870431, 0.011289020898872086, 0.01929189040956478, 0.03614231223060239, 0.04240529551621407, 0.04999168803014102, 0.020191622372235984, 0.06945791323819468, 0.05237387290464775, 0.039102338074195775, 0.02533625901466416, 0.025379648319475596, 0.05254648783574662, 0.006170169818365286, 0.013626841621683731, 0.04732756747774059, 0.013571836508720393, 0.02004413704027332, 0.07211556417807456, 0.0409179128285858, 0.044656402746876406, 0.05627586896861753, 0.01859227018881469, 0.03365973919449795, 0.022024146821950714, 0.05908270404043217, 0.027753980792758447, 0.013120178839251881, 0.021914954394883206, 0.0439355714667228, 0.107463282352734, 0.13735406431219271, 0.10329993922383555, 0.1404450452255626, 0.1322730780849534, 0.12743964550956605, 0.14163124044576, 0.22946332821682577, 0.173042913778655, 0.12472300579951656, 0.15535222757006847, 0.13857982031279995, 0.2445294278403444, 0.21017878076001523, 0.09781596776578697, 0.12523977040883996, 0.11511495321868889, 0.1476667722266528, 0.22517234717886295, 0.14498872802622859, 0.07779609847573504, 0.2611014264966211, 0.13832664357558375, 0.10589676278252756, 0.1016474952320418, 0.11043663046533063, 0.183399916896897, 0.10098358811510187, 0.2051161040341662, 0.1659205024160685, 0.15391092507108567, 0.15307838668025311, 0.09639534964075974, 0.11274985593533325, 0.251623984246004, 0.05010554018700796, 0.11730725937072309, 0.10764468431232438, 0.13576081593430814, 0.20069482676204176, 2.230750711694841, 11.557843242922138, 30.520576161722985, 45.872464333811116, 47.220755546323716, 36.6567575547003, 30.540994059654977, 35.05378684689922, 30.52947994201414, 13.874822605040766, 4.508968476326236, 1.7710571399619504, 0.31129431219831594, 1.5632994881560727, 3.504355093163829, 7.690223964952654, 9.906557759931012, 16.481815153552642, 14.659415291201684, 12.17236686137415, 14.25955024457747, 12.54667668573318, 11.241741391920275, 10.922363381231985, 10.11187324600835, 7.5635823991990865, 3.699419955092092, 5.615639725039083, 6.6192065708098875, 13.947787515578733, 20.303878553452034, 30.13426584582175, 39.50775977103941, 45.8389163017273, 49.29611690582768, 56.49300329146847, 58.647643596895286, 61.02262304675195, 61.051844704535704, 62.752074503129535, 61.34544587904408, 61.78041319693289, 61.02570602970739, 63.46717749872516, 62.210599145581654, 64.01616419515302, 59.943445651761955, 58.28389083185504, 58.88306033226752, 60.152249105515025, 52.189155163303504, 54.66652416413831, 59.340749940564564, 62.49049555870795, 60.56483145683043, 58.23615950922812, 61.152088719029585, 57.501346603516616, 57.77003288269044, 55.21762109571888, 55.46133364400556, 52.33123517805531, 57.18091249465943, 55.62864234370571, 55.73480129241944, 54.42125835726338, 57.769589654860965, 56.84447511549919, 54.77944920139929, 54.298382266875244, 50.137904613248764, 37.71724093344904, 27.816704011732533, 17.492056892764186, 13.831647115368998, 5.338334037411598, 4.014773123687314, 4.192365052238587, 2.4855128219050746, 2.9807493186766103, 6.174240150759298, 7.815660872767049, 7.4131585224982235, 6.187188384994385, 10.651125600261073, 10.47429338578255, 9.17407964506457, 10.551747448982733, 4.991903929941116, 2.012918452101369, 0.8507075449151378, 2.666970491409302, 8.392562097118747, 19.356961519487445, 25.384910991114957, 32.68858978825231, 35.12000822251843, 28.57173869686742, 37.51362285306377, 31.82389347783981, 18.320249665168024, 5.894871786717446, 0.9984119933459067, 0.13807060166953072, 0.19128375836918432, 0.27098959912696197, 0.12286859804824476, 0.13590557590848015, 0.15383140514454535, 0.0969080463232052, 0.1757027863735153, 0.2227430517274526, 0.08734823429896947, 0.17966379802073204, 0.11236543301492931, 0.1331387727611488, 0.206519607754965, 0.21102729974494827, 0.15524865248270575, 0.08958898785133516, 0.10510959977945013, 0.147317880464177, 0.16710145759486383, 0.123301430064584, 0.2364383289410222, 0.1187835184616908, 0.13692215926224185, 0.2502939330353852, 0.07512386122177686, 0.20245951029562181, 0.10340863943941171, 0.17567283233567593, 0.13837020333495834, 0.16848306652278672, 0.12342937440881807, 0.18041575928368878], [0.03392888503449579, 0.06655915910678525, 0.02813488353915032, 0.03937058376088258, 0.0520354995293723, 0.08170444923903673, 0.02873292433158044, 0.05925524619317824, 0.032034454934839765, 0.027639069519336187, 0.018987763079724485, 0.011344145713073593, 0.03597973305131159, 0.06046431296835504, 0.013414450447946308, 0.05200544206966316, 0.06483896995984739, 0.05473518188321783, 0.04095309541650838, 0.038598156459028685, 0.030944721675628138, 0.031170028134159027, 0.0373459589337149, 0.06745401875025804, 0.01175590743866539, 0.04157545758531459, 0.07233269647845338, 0.06521613036672916, 0.08009530453672332, 0.030045458941810557, 0.04299010022453243, 0.04437688407638381, 0.026487934312993483, 0.07771854739516013, 0.03665693562417742, 0.05065583263433749, 0.06410159501096895, 0.042403648427176865, 0.06642602068642456, 0.0428767881596521, 0.10463735253940668, 2.4451690383495825, 12.16006140555105, 28.086141424794352, 40.45340007351291, 31.341718473742088, 31.909006949393984, 37.8650515310226, 38.841564809122396, 41.42902689595377, 18.567878700071766, 3.216491120476877, 0.8358453778970627, 0.32342519190522934, 0.6664043797119972, 1.6542186804356116, 1.567379243431553, 3.7049612835530317, 3.313517320540644, 5.6935134818477025, 2.7484501321469588, 5.086651232934767, 3.45766834674343, 5.087144470983937, 4.911329130972586, 3.426128323039701, 5.78560043727198, 2.436797719809317, 2.1350576271933894, 4.353153301823524, 7.63672479698735, 15.857068857839032, 20.485376427250525, 27.311279158438406, 34.5693309845463, 46.782928820579286, 49.44166821818198, 59.61195830375918, 57.004535275120894, 60.31228573091569, 57.682630708140714, 59.41496118422478, 56.3697349640631, 58.81872953907136, 58.16596869499453, 59.70884869175573, 55.773997537551395, 58.454353117173724, 56.18448534319478, 59.242121942581676, 45.49215132190336, 49.83079087349677, 56.07480802843648, 51.33248990581882, 54.62109527280254, 56.132737513511415, 56.19946487488286, 54.79436989753477, 56.04220528756419, 53.6747097199963, 53.212023012099735, 54.130799001263036, 53.057418869387725, 54.54648394738474, 52.966729748633604, 51.98011244496992, 54.375680415861076, 55.49284596596995, 51.43973535107028, 42.280134154904275, 30.037047939915812, 20.723211303833995, 13.703667040794128, 6.28782561709804, 3.7004265333375628, 2.5120221607146727, 1.833924643935696, 1.136654949476642, 2.101423793262051, 2.9672242508780573, 2.1685652098348065, 5.527903658728446, 2.2223173706762256, 5.197912204650141, 3.5345595498238844, 4.585574817272925, 4.770315020315109, 2.910227554459726, 2.0784298787193913, 0.9299622211725482, 1.449731549909038, 7.549275553995564, 14.009514835573013, 20.761919213879494, 15.556844761294705, 18.864809966856434, 23.64460829765566, 29.295837648453254, 23.696795432798325, 13.947696320472227, 4.046892922732138, 0.41759284213185316, 0.03050314476563325, 0.002673777090685983, 0.03696733912933738, 0.0986992594816031, 0.019754977153253653, 0.028795371988728165, 0.019249207820863496, 0.035608617078152396, 0.05327064776793123, 0.03769603047159411, 0.06164031921915951, 0.05874565216682612, 0.03722927991240736, 0.0491686069947337, 0.014855731879511188, 0.04450811110737343, 0.14103868675808753, 0.011761944211508718, 0.042144392782281485, 0.06095770040466901, 0.06120908832658203, 0.01705907161287483, 0.06798850297327004, 0.034160910084122614, 0.012977971853087506, 0.04378348386155502, 0.0071984599532199005, 0.044710986511481386, 0.007872457405732525, 0.028905887832684867, 0.07615433374960577, 0.05057179661948354, 0.09546814576512384, 0.014190865237446082, 0.04643042106181384, 0.10956806295941915, 0.07025440719218985, 0.04100832652540938, 0.09174589308038836, 0.021436078579074914, 0.045929702164064494, 0.03546395669541052, 0.06765502489983075, 0.029104318011612184, 0.018835889979175503, 0.05874844072687049, 0.024938285914099505, 0.03896375659913306, 0.051400447114100384, 0.05669065961433996, 0.030202342257384333, 0.059545084068010894, 0.03673030386468576, 0.07310606223801452, 0.05177859960484409, 0.023751971950273842, 0.03685364785093454, 0.041427920542417035, 0.07599809011744876, 0.03827885867306783, 0.07831670118555908, 0.017187826095088836, 0.012921337845675167, 0.04012892270580896, 0.008578656406532372, 0.009921196765536744, 0.0950807351018152, 0.03414422085869216, 0.08821831865897102, 0.026296939017371308, 0.05885038787739412, 0.03800968985043226, 0.03397221113705347, 0.03514644772475285, 0.16731429214198745, 3.9668976539565675, 16.230011736193013, 33.3026917519108, 44.72175075161842, 35.405172378786155, 33.32453150903025, 41.693335810015284, 42.52529405778454, 35.416708069462935, 13.2469815592612, 6.238874437347536, 1.66107265458953, 0.03744510220243566, 0.13913940157621138, 0.5323570113508932, 2.3210211194330648, 2.871816028510371, 4.762296715090352, 7.05173074237762, 7.262576770397925, 7.398609961232832, 5.438774170414095, 5.853927145081182, 4.976112467627372, 5.536935406346475, 3.890824265057041, 3.540032481954944, 3.374426090909589, 4.739345946619588, 10.445271768877584, 18.45636767725791, 25.36297513592628, 31.893856794603412, 40.10997303070561, 49.346225184779016, 52.70590782165528, 60.370681978041134, 58.231480121612556, 60.21617589458343, 59.50461479925341, 61.075928057393725, 59.20300414485317, 60.79059523920859, 59.62834596633912, 60.8756047679532, 58.07729175013881, 58.40220912810295, 57.19468393633443, 58.49445150744531, 47.286576840185354, 51.956531155493956, 58.71766967158164, 54.57010838293261, 58.21470414438556, 57.5265399871334, 58.3945095154547, 56.8763953639615, 55.646814684714045, 55.559185012694336, 53.564616633999734, 55.06328367417859, 52.29335292693108, 55.95300666747555, 55.119381412383056, 53.77201980160129, 54.252635663555516, 56.912626297243186, 54.011688386240316, 47.172569228756814, 35.80977270680089, 26.41572948425047, 17.110335749964563, 9.420887924009754, 4.06608336394833, 4.838145548297513, 3.594827748114063, 4.0300220731766, 3.671643690716836, 6.793514740082526, 6.893404760668355, 8.650398119803398, 6.53462310952525, 3.982759473785278, 7.0416482898496815, 4.9928502017451875, 4.058237643011155, 2.0797963344281722, 0.4361208011546443, 0.3854665466614308, 1.49132129886458, 7.437014868182521, 18.237346449205955, 25.244260680290964, 18.44576943305231, 21.130068955882905, 29.82398871452578, 31.176437639421035, 29.79258425774113, 18.252957482491773, 6.172233368119886, 0.8445412725690873, 0.043659220569797104, 0.038230533846804214, 0.11916450164731472, 0.04748688695291358, 0.042735291720037503, 0.02073029901141361, 0.10464751852616187, 0.035724970512092113, 0.08920510885335746, 0.05856782783784213, 0.04858015187745614, 0.04597197489572629, 0.05896364631611974, 0.028079909069703955, 0.05129792922807317, 0.047954185264966184, 0.06049879075538728, 0.0391410370056908, 0.032959703371048935, 0.019031081521402926, 0.03892017385712074, 0.030571818802385565, 0.08016536327739877, 0.009656020218596585, 0.05975708357929703, 0.04147385900479652, 0.02654170410917892, 0.022055908827291384, 0.010623830584658971, 0.009186379592715493, 0.05410233580116784, 0.07133035469920405, 0.0419783087507371, 0.07755148660151229, 0.2197980565289336, 0.17982467648483094, 0.12273601887206878, 0.14110607185190724, 0.19301969828384538, 0.16374226929920335, 0.18846717482853323, 0.13082440582013902, 0.1878938346260017, 0.07668930826888931, 0.057554795301609465, 0.16802892960127325, 0.19415470350894237, 0.1345432570744907, 0.11038095885587317, 0.14553281899181106, 0.10710803206048666, 0.17357802619376492, 0.1711822241064041, 0.11432966713102595, 0.12998250583487173, 0.13459522847927388, 0.13675058621072, 0.1564921970449148, 0.1276201664680435, 0.12973124431746622, 0.2284297836764205, 0.23346040728351763, 0.25228107318041787, 0.1626847615285266, 0.16468702424918452, 0.09643581440492023, 0.3195479596334119, 0.11913827079678736, 0.23208013134858302, 0.19091606680904666, 0.28815006056139547, 0.15934648743319899, 0.16160350503219714, 0.12531811055997688, 0.32060179018205215, 4.016639926741201, 19.059030048308834, 39.14313231745074, 54.84302297715218, 44.14321291831232, 44.317566194841945, 47.67056511294457, 48.60376757960166, 48.18342285771524, 23.113048691903394, 6.159844561930626, 1.2827010933429965, 0.8496419472559806, 1.5483264528935956, 4.964838595159592, 7.623750577049871, 9.783442404962356, 10.347413536041014, 13.31959737885383, 10.355973128349552, 13.062078087560593, 7.467809396405374, 11.261968074306365, 9.703503520258012, 8.644209600264027, 11.54029946173391, 5.055294334888458, 4.999523134000841, 6.646538136466858, 10.215693481506841, 17.73101160603185, 23.696969978270992, 30.407896272597778, 36.653462763755556, 48.63245579504198, 50.467415086684696, 61.23106564244917, 60.605086741908906, 62.58142002167241, 60.97998688297888, 62.0722375377532, 59.23953710063812, 61.4797870574459, 60.405661675237845, 62.551845350573146, 58.45184280026344, 57.815857933413604, 57.39982781871673, 59.60464308338781, 52.4442857311618, 53.908392767752375, 57.75845404594176, 57.07138422996768, 59.56607441748343, 60.17907419512349, 59.3611894115325, 57.13917455365581, 57.1526361280872, 56.02035768570439, 54.03419494628907, 55.73350691026258, 52.65077106414303, 55.466448414710264, 54.94547920842325, 54.65427067971999, 55.12291546790831, 55.852903858307876, 53.78369669760428, 49.04686989322786, 37.27236570850496, 24.753903612013787, 16.627121317771174, 9.46665511977288, 4.9371383267064255, 4.172787522116016, 3.794547727992458, 2.998494121336168, 5.710422819660557, 7.9453623775512945, 8.024117196759871, 12.376422286033632, 6.848407820347817, 11.04209275014939, 10.712270448284766, 11.708863319889193, 11.54937582631265, 8.935640723474565, 3.6061526113940827, 1.9298452259071412, 2.4406634607622704, 9.201259709173634, 18.639946368432817, 28.730688825730358, 22.83076551652724, 28.327061245518347, 35.87634709573562, 40.28636986209501, 33.40441842232981, 19.611201709316624, 6.14654625615766, 1.047022172039555, 0.10460379022744395, 0.10165690279175198, 0.24498767099313198, 0.22719474269017098, 0.22854930871436674, 0.15194837634842243, 0.1965297292917967, 0.24323604159778167, 0.15344854504350694, 0.19419058706731568, 0.15471259011856972, 0.10937837192848807, 0.16613946566658636, 0.11144592832293242, 0.10493156860672659, 0.11234922259445153, 0.20509980168313752, 0.11591219027797062, 0.14770912156710703, 0.18058773070093126, 0.21111539985624053, 0.15307921405521133, 0.1792184711103478, 0.13054179598487195, 0.14923138423792778, 0.13615293037747184, 0.12115391707348248, 0.168173459749068, 0.10373511546922308, 0.07904197960611313, 0.18585872205515064, 0.21814411866568753, 0.14650757394490704, 0.21296449095731784], [0.04260123399416766, 0.013970975978149763, 0.015723276658043746, 0.07289828387119117, 0.06077814471697616, 0.042349497502249096, 0.046506022448621454, 0.05838321980028864, 0.08255277670198873, 0.03854483673949877, 0.014232655333715582, 0.029748871832364993, 0.0378655350857204, 0.017809265127946294, 0.024499051317933108, 0.031774373830205975, 0.04458622909301231, 0.03749289842803152, 0.03675354314186881, 0.062457746525685635, 0.046851056958398515, 0.024751670726184404, 0.022109797367105083, 0.0034972438034826833, 0.012481345780073635, 0.060287852275876276, 0.12995524842652584, 0.05446042444917464, 0.010337400843479462, 0.041279414398295265, 0.01745867265027858, 0.026699158160256285, 0.01375354681870029, 0.021496281598604495, 0.0319310158280836, 0.05676011314555522, 0.0833218906735701, 0.03706555926210938, 0.04827354433796099, 0.07378905260514829, 0.05160067568442995, 0.36460241783530484, 4.740773199066039, 16.483356645030362, 37.27001228640157, 39.09816234342514, 30.379602255359774, 13.079612062823388, 10.86795618457179, 21.898161211321433, 29.14222194302467, 14.246401479167325, 3.973520330844387, 1.034928156483558, 0.2896031761361707, 0.2507154805765998, 1.0333349387491904, 1.0192106063327482, 3.8969407110444965, 5.045047633109554, 7.33326425475459, 3.3334307036092206, 4.282245674440938, 2.594119574754469, 4.148048152846675, 3.2716416062847262, 4.918122676111037, 3.5587500324172363, 1.104574251559473, 1.802460248431852, 2.3184563796366415, 4.3272710519452255, 7.59801394516422, 16.55509287311185, 20.135922662673458, 28.116400549488684, 44.459265739687034, 53.317032706352975, 58.737254065852014, 60.935244406423266, 59.45731493734545, 60.0671572069968, 56.42063163941907, 57.32200407212781, 56.167485790867964, 57.55505561828614, 58.22036804691438, 58.66499616253761, 55.912437592783284, 57.620978893772254, 51.53066373640492, 54.97602662732525, 57.87646247494606, 54.88454126542615, 54.38400368536673, 52.73400768156975, 57.31379062898698, 56.43313615552841, 58.03738947837584, 56.27155803865003, 57.534886790860085, 54.98078053997409, 56.859431112966234, 53.95360592872866, 54.357923846091, 53.16614304819415, 52.06527494615125, 48.410496711730964, 39.72226242865286, 30.391675310750163, 22.793528495296357, 13.046823009367913, 4.82797239095934, 2.209320842258392, 0.7717253508106355, 2.4826693486782814, 1.2377732847967458, 5.367565991417055, 5.0431639148343, 6.662165349529636, 3.1354878025670208, 6.504852319917371, 4.784667463071885, 2.6156242143723274, 4.792941212654114, 3.1333530526007376, 3.149134954137187, 2.201609217351483, 0.40088155336918374, 1.4863819316510232, 6.388472164830854, 14.968156814575197, 15.944180776996, 13.59324545629563, 13.36555971253303, 21.241264227897894, 26.323767554375436, 29.73374870515639, 10.375617338765053, 3.7970577997546044, 0.4522477180486726, 0.07208392474680178, 0.03710559501703228, 0.007706953206985829, 0.018771402612929384, 0.028882047176481258, 0.06475552766313476, 0.024368850844762018, 0.04712755341202982, 0.04110351678044085, 0.021772086657884143, 0.07939382080709742, 0.022821711383820064, 0.02066578866252976, 0.030094930984740777, 0.05386318230340558, 0.04236435577754052, 0.07548063602899352, 0.01743942660640084, 0.08596058093732403, 0.05223146865084287, 0.024163324776436054, 0.014795030902830825, 0.025854370023514477, 0.046715984166029005, 0.04837247310206295, 0.03899689373229781, 0.07437631262526398, 0.05906946987154023, 0.03945739684446205, 0.05681247142474017, 0.03473647577207416, 0.0189324630229103, 0.019614423001785914, 0.023469331471489805, 0.05062362246756112, 0.049724208431378494, 0.08025591487004873, 0.03486574161797762, 0.02987434554304327, 0.01992465030672329, 0.05627845451536198, 0.048722360778840325, 0.006289484660937301, 0.01539535080683568, 0.031710074155501304, 0.031636202212182746, 0.03473223164497364, 0.03730190887806877, 0.043847666707851236, 0.05266373376211813, 0.045910228209029284, 0.0174543634057045, 0.0343515663858383, 0.04857193175402861, 0.09968748226040795, 0.06097864524851884, 0.0764450794386287, 0.07770774555542777, 0.03627314855675063, 0.012050298748597985, 0.05536266918023748, 0.03334219958032331, 0.05505030448999136, 0.048149621955329375, 0.02526136817440631, 0.04358355789595554, 0.018669273516523744, 0.010139217727907724, 0.051877823312796896, 0.05507097354218845, 0.043585729755220876, 0.06274643526863187, 0.0027686463069966846, 0.03167240944270405, 0.0504557074858777, 0.04305365870917036, 1.040902048830063, 7.495934751725967, 22.511194329107962, 44.95020527993479, 45.16251925499209, 36.3115026873927, 18.908205109257853, 18.02146311729185, 32.25875489173397, 35.79766827244913, 12.420296938188615, 6.24905445883351, 2.2925042625396483, 0.1515135908078763, 0.0982662512650413, 0.2452094534472112, 0.9552411002016837, 3.686436174377319, 6.605725384527638, 5.464157788984237, 6.20214585335024, 6.773260110808957, 5.9161982036406, 6.213992882159449, 5.254416888759983, 4.2434877541757405, 4.069965039530109, 2.985797163940245, 3.591527318762195, 4.323976751296751, 5.9598188823269265, 10.021309641099746, 21.9491579071168, 25.75171143777909, 33.6329553204198, 46.19100786024525, 55.773052246339866, 59.65193510055543, 61.596756058354536, 59.711484524511526, 60.31918125767862, 59.333870103282315, 59.12248572995586, 58.55023937840616, 59.413937445609804, 57.447990602062596, 58.192158360635084, 56.43097885193364, 58.41820847603583, 53.45902642896099, 54.70655195174679, 58.60816101874075, 55.87838749731741, 55.41359055426813, 55.33096190421812, 56.388123035430915, 57.71588848483179, 58.72531437104749, 57.577083649173865, 56.85079797621697, 55.628858074065185, 55.61386285289642, 54.503012318764966, 54.12844950152982, 55.39292750820037, 53.614011041579715, 51.294693946838386, 44.84124575891803, 36.09538793563843, 26.11937284469605, 16.538989582369407, 7.523185418498132, 4.119925739303712, 1.9234233253425168, 4.851018767203055, 3.859936825690731, 8.257381531500048, 5.591433798113178, 8.011172884894956, 6.072584573299655, 10.213169436300955, 9.2840148556617, 7.104520451638007, 4.992316759401753, 3.9885633558996267, 3.3672057428667626, 0.6990978866815568, 0.29519515833066357, 1.3578657181032243, 6.19394515791247, 14.910745082363007, 19.37119972321295, 19.058237729534028, 15.031660968257537, 22.133030776054632, 31.351116472674956, 32.192664915515536, 15.509771416264197, 6.06332189613773, 1.1058280616998672, 0.15285475029339715, 0.026108734197013324, 0.04658111821739905, 0.028245732631354083, 0.03548622687136935, 0.10394226564394851, 0.042812681922148314, 0.052714962061614766, 0.03561194956062302, 0.04318485892708263, 0.042624293240688504, 0.057157835352324673, 0.044479727549778844, 0.04525049627127667, 0.054818991902134115, 0.053807487711310394, 0.02376684746254356, 0.05504764999533373, 0.05804832063374981, 0.024097632736929005, 0.058087961853391705, 0.03447169663324472, 0.03514770027850905, 0.04925415986367772, 0.02969813765957952, 0.08948281572590913, 0.027950166334067623, 0.07556680559871659, 0.07408470125688661, 0.06880146781763724, 0.02108022116214758, 0.04315049222279941, 0.04143432503746402, 0.02519054143058677, 0.03669040983602886, 0.13963990213890232, 0.1793461166802914, 0.1370126036025824, 0.14752999488865176, 0.15408065951158925, 0.15019950486959951, 0.07588815650031452, 0.22952577970441312, 0.18335905376701586, 0.11747119452563987, 0.13856140355910027, 0.13417496796577208, 0.27446414494226057, 0.15143048558985034, 0.10349806488281298, 0.19765347302440675, 0.14780431565257812, 0.09900813081091452, 0.17587120314278912, 0.20541245748679485, 0.12286448415609137, 0.16551297428386827, 0.13813804805038438, 0.13713928390174143, 0.09246837528001878, 0.1333592681875152, 0.2358335944553537, 0.12266302601464334, 0.14078996865259064, 0.10972098943086402, 0.2532451795113664, 0.13148575420341185, 0.07649302122093017, 0.13483685261059192, 0.13905551494850268, 0.14361165433881745, 0.2116697410782499, 0.1526356644688114, 0.09536015801131727, 0.25217484742883717, 0.2153888681242543, 0.9746630838321102, 7.073751909117545, 25.279673799391716, 49.50543419007332, 54.33627628510999, 43.94130106895201, 23.7331263865194, 18.109549745436638, 30.13607013610102, 37.053701416138686, 18.98355187908296, 5.891790274650821, 2.097397235132033, 0.7522244294804912, 0.8963225649729852, 3.1405648204588124, 5.2980880679622775, 10.602147944511907, 14.197288501647211, 13.681795904713294, 10.802473195137518, 11.506657292765956, 8.608002201203378, 10.552150472517937, 7.47219999951701, 8.39404377245134, 7.455009721940564, 3.703702202727718, 4.478856440513365, 3.703925042383133, 6.091838507883011, 10.050109644089977, 21.29213736903283, 25.294055169628514, 30.231834803858114, 46.82705156264767, 55.66206878231418, 60.371195808533706, 63.145845167098514, 61.26195430755616, 63.736385453131895, 59.27932170129592, 58.670161924054554, 59.44815620299309, 59.80267178627753, 57.885601597447554, 58.4049940109253, 58.47504754220286, 57.56498313719227, 57.897435388257435, 58.929242318676366, 60.235775978334495, 55.814990228222264, 57.28642425229473, 56.55854609704787, 58.231538957165135, 58.02327679049585, 59.18209006709438, 58.69585737105339, 57.12074725858627, 56.06355867078228, 57.911752039386386, 55.27881399277718, 56.69083979821975, 54.61430172766409, 55.03831386566163, 53.33502461833339, 47.34796977812245, 35.634925211629565, 26.024192610094627, 15.387059084830748, 7.064147495454358, 3.94667832601455, 1.9490739102325134, 3.753375343738064, 3.828156311665812, 9.779515131827324, 9.708268219424832, 16.21077447168289, 7.344731303953356, 13.681232064001023, 11.59149423722298, 10.570889596016178, 11.637431075496059, 8.560112022584486, 7.448430926569047, 3.4030280142061176, 1.2508535313029445, 2.294865039087111, 8.815950578258885, 19.447797729123025, 22.26775242436317, 21.506998923517045, 20.8276738274482, 31.668385228803082, 38.506810126766084, 37.353503857889486, 18.149514775122366, 6.102859877770947, 0.9483577082714728, 0.15722275381126713, 0.1391296109725391, 0.17960749055829742, 0.17821808285530538, 0.20405156357634455, 0.18967485115412744, 0.14175799735371145, 0.15166918326529766, 0.15406403540363237, 0.11195510100092619, 0.20514337676427058, 0.1670066465533549, 0.12594952022716885, 0.11913003535160135, 0.13240748055038914, 0.1456761693642024, 0.19365380458053083, 0.1254489813600817, 0.2103090463506599, 0.20765026160065206, 0.18465720507646763, 0.11259411792120627, 0.135032695327555, 0.15911543531523598, 0.2382644527261296, 0.2622591079242768, 0.1269992598662934, 0.210298290476203, 0.15051717088828165, 0.13677022870509856, 0.12227340135723354, 0.11149076744914056, 0.20528085890316194, 0.11198094114661218, 0.18224876253835617], [0.010630769426033143, 0.012842810002996797, 0.0052541651905724605, 0.07842817463942113, 0.054536887684897076, 0.03038527830804308, 0.02274219337249956, 0.04716083993233981, 0.036016566558710994, 0.008075787674545521, 0.02762773907893608, 0.021507996998186556, 0.015950707095344702, 0.037055109822822195, 0.03176981943749613, 0.02549774077300343, 0.0317614748247809, 0.021593890776256883, 0.051694100106795954, 0.033155151552730994, 0.07685862902191377, 0.013962267473670504, 0.049542883080580545, 0.02316903075083129, 0.014557009299976692, 0.09607068923932892, 0.09197997124565226, 0.06655052529587861, 0.09082118665138561, 0.041175586501917535, 0.057304790168399775, 0.006130240358141882, 0.032924505461367874, 0.0333517718489372, 0.006718323922776167, 0.04930288688610158, 0.04166948338670116, 0.008870158607380526, 0.014074569260100684, 0.05644279569687863, 0.03672455820525366, 0.05145646346312377, 0.49486166527194364, 5.073165143689802, 21.830110050016835, 40.19852445971581, 35.255828134475216, 30.521089992215558, 23.67539498113817, 17.207098660930512, 5.715694975468421, 12.875324237731196, 17.34467383353941, 8.112162640017848, 1.9057931294364316, 0.4407587893787892, 0.3468825896420787, 0.6406272370969096, 1.9031686960689485, 5.424412412028159, 6.593056128871057, 5.699853012638708, 5.495357792223654, 5.225303096155967, 2.6618679781113905, 4.609096290603761, 2.2644193566614583, 3.18658231246856, 3.5734008204552437, 2.738351990138331, 2.3065134979063466, 2.078631880783266, 2.748813686832305, 5.5358322397355115, 8.613580792180954, 15.32405601393792, 28.214404890614173, 42.363712018535985, 53.576446502439445, 57.94321337053853, 58.61698242925829, 58.34196152225618, 58.4679441298208, 59.25286531448365, 57.6211279438388, 57.34373792525261, 57.25746931568269, 59.41294508595621, 58.228008824010054, 60.63796797106343, 55.60001688618814, 59.47467142535795, 59.3717445096662, 63.710941037824085, 62.83883733134117, 53.37670764615459, 58.55850381235923, 58.97545960641677, 55.90087052314512, 55.17503592275805, 56.11056827729749, 54.198954105377204, 54.7168795524105, 52.95949297566568, 52.10855830100275, 51.12035243741928, 46.552893577083466, 39.56801522162653, 29.106293032246253, 21.7925121707301, 9.729273492290128, 4.050587305138189, 2.2369676684179614, 1.4860017068924443, 0.7891331360705438, 6.622530289234654, 4.325202982271872, 9.514612959277246, 2.572670093467159, 6.837038340107088, 8.709030689731721, 8.854359407578746, 10.324780479554208, 2.9431835537956608, 4.147406845323501, 2.578349930624808, 1.4021594509963067, 0.5324447130964649, 0.6172119129088618, 5.357303109861189, 13.897267387759301, 24.9416615886073, 22.588984735550422, 26.40177957473263, 25.30091931743007, 28.626989203114665, 30.208961502198253, 15.970218450792375, 4.767821863774331, 0.7442422223187263, 0.03217661212528906, 0.020291886044546, 0.08425398219016292, 0.053254797408777865, 0.036756538545652744, 0.024576621550706126, 0.049793317223027836, 0.006158800115959058, 0.06818305866252031, 0.047725852759134386, 0.02786221177948098, 0.0752982764594978, 0.01396308623013958, 0.04224317215923821, 0.018314772075222387, 0.017806055219543558, 0.03626201346877121, 0.04071244421685415, 0.006053691895137872, 0.032845035330542637, 0.039925924727633115, 0.002745013212740061, 0.03193646845888467, 0.047243343771345196, 0.020915313075566967, 0.13466612225578678, 0.10001496952627936, 0.01749817788931391, 0.06929518850219828, 0.006544737975233265, 0.055898191452386885, 0.028436802620548877, 0.04098760767749721, 0.06664889864623547, 0.07603944354360143, 0.04052045492215022, 0.010031353505778938, 0.05279890231547817, 0.017922372264306874, 0.041131609224624215, 0.09032087761067575, 0.01863324057100521, 0.04665865014577585, 0.06837891670124185, 0.03267873296393983, 0.0350948057377771, 0.012331307460103306, 0.003220512256619611, 0.021272281319984508, 0.04358842638471434, 0.015563847057731643, 0.05438831642330174, 0.028474509468181964, 0.0454344148296983, 0.047144085589435794, 0.04789312422696141, 0.07742349629200275, 0.027103399775261362, 0.01969209282598909, 0.05519162472938338, 0.012798364454459761, 0.053622420021002336, 0.11261769044663637, 0.014630944445549, 0.07518961454831785, 0.022182317165237282, 0.02283837188095335, 0.06939032896151466, 0.02022069157852281, 0.029946694886612318, 0.07084437150267825, 0.04075239187166576, 0.030113872508668614, 0.009541763950349584, 0.07302582218882538, 0.06311570113945393, 0.02822845734866156, 0.05646381331908126, 1.0154276641626512, 8.102154712523184, 28.42043915102559, 45.65894226874075, 39.85763126803983, 28.469502118326005, 13.864036087066898, 12.861293919624822, 16.972427175891017, 21.204815603071644, 13.482836619500192, 7.774479908327903, 2.2535494883214278, 0.3131900733757404, 0.20019155296106494, 0.36604680000774326, 0.5115189908012268, 2.5351977300259376, 5.165228564893046, 7.3935280403783254, 5.623561441898347, 5.256362384365452, 6.347465745864376, 5.257874458066879, 4.508143307701234, 2.2651028296639844, 4.261627245333887, 2.7084032229838835, 3.1764520560541465, 3.0210818254178573, 4.42310534177288, 7.245277647049197, 13.53621909695287, 18.633207736476777, 32.06465052020165, 44.032441262275945, 54.54607602088682, 59.40507681139054, 59.89191747480824, 59.143909715837054, 59.40271162217664, 59.00075497165803, 58.27570484530542, 57.75217825366605, 58.30539326513968, 59.83955775537799, 58.51731108080957, 60.32087572159306, 54.29423239923293, 59.2481114018348, 58.89395275423604, 61.975323615535615, 61.17079450238136, 55.46568355252666, 60.19633654625186, 58.51993906882502, 57.37399901113203, 56.830762509376775, 57.99178015801215, 54.2945344217362, 54.674129639902425, 54.1923802129684, 52.67850614363148, 52.902175380337624, 49.15101274367302, 44.07117859009774, 33.20682902489939, 26.20447062676953, 13.797926498997597, 7.231403733453444, 3.7525266408920293, 2.8852722096827725, 2.2377538584893752, 5.341096856901723, 7.542403561453666, 11.71412027651264, 6.603228305616687, 8.101107439687176, 4.720648008008157, 13.073287240920529, 9.57904181172771, 4.629513698239481, 4.130365617813603, 1.9114301882443892, 0.8731069139415218, 0.28372847685410135, 0.5339762760746865, 4.525173748693159, 15.607018739946428, 28.443745874589492, 20.766473085649555, 20.497118042361354, 25.846650446614913, 30.75704016993123, 33.42241033431023, 22.122252102821104, 6.381912000717656, 1.2905290410403283, 0.025247660946221124, 0.08953674065489924, 0.04844610564290516, 0.05024470005845351, 0.030522168644012946, 0.09625019896174632, 0.03900045987158533, 0.017441121575933312, 0.11329461339740984, 0.04627804234323483, 0.042324683914381656, 0.03701977018687514, 0.03727932843650061, 0.022688097988946304, 0.061608538061620734, 0.025821393768813823, 0.03092342060089352, 0.03180104135085018, 0.08938061193593087, 0.07129352885268389, 0.020039100012171174, 0.10801146422783214, 0.06922415682985898, 0.04978292907077459, 0.09254969551318115, 0.06965463695627067, 0.04852880483433124, 0.04070859462503464, 0.07735621078961319, 0.008467353407233473, 0.059812506210179105, 0.024167040302868814, 0.01705718895180091, 0.04100535027382355, 0.044998426531111045, 0.017651012430207867, 0.13289273596338688, 0.16060075722634792, 0.16720163125184276, 0.18645378851121475, 0.17238220890923855, 0.1394122667730816, 0.12216599583024941, 0.1946376453364088, 0.14529157790445513, 0.09804415471491315, 0.17747284784432382, 0.0720429083993358, 0.22547599378853078, 0.2724139710828182, 0.10551486795227374, 0.18698721553289122, 0.13505624487034737, 0.15420133368142191, 0.1889075374891681, 0.13185261838859128, 0.17744733711644528, 0.13872464157400594, 0.23159973293302522, 0.14164866128515813, 0.18029839461368902, 0.1804151923786248, 0.21180127837484886, 0.0922939140770224, 0.22980935481046477, 0.145832589196582, 0.1113099400554934, 0.16958103905762398, 0.14479060236725116, 0.12206629714778355, 0.1413346112014786, 0.13883000930711148, 0.14200944273221877, 0.10544174485990118, 0.15147285025206306, 0.08243422459570632, 0.2779230319203869, 0.10955696234539633, 1.0014729742561619, 8.248723879937204, 30.040077970873927, 51.42434789288429, 48.30319635329708, 39.874085610912694, 31.581159560911118, 27.128500630778653, 14.401421393117598, 21.31206497069328, 22.364725182133338, 11.075537820016185, 2.836613981954513, 0.6453778402459237, 0.9072902474191882, 2.2165085855991613, 6.239255397550522, 11.315038723330344, 15.453023545203672, 13.558657015523604, 13.557266535297519, 10.299232121436827, 10.1588769689683, 9.77300105556365, 6.394896516876837, 7.261291213573949, 7.56401336962177, 4.934116630784927, 4.9824132650129265, 4.273478196513269, 4.691146391053354, 7.0530403237189025, 12.182177689767654, 19.17566760893791, 31.735271446166504, 45.34977320701846, 55.24642698226437, 59.84459407867924, 62.17574888660062, 59.55019666302589, 59.864700148182536, 60.31447833584201, 58.20394116063272, 58.49019181343817, 58.16299946077409, 59.99718996786303, 60.297659212543124, 62.36520721066383, 58.060656978238015, 62.116234763976074, 60.955868228789306, 62.616399718869125, 60.544038972546986, 55.553466196983095, 58.744934066649414, 60.50631361622965, 58.347441073386904, 59.326276394628714, 60.37781676938457, 57.25910494404455, 55.28182245069935, 55.55582354145666, 54.334271953951934, 54.60994005203248, 49.32726052499587, 43.75387061026789, 31.17915584195045, 24.884732307926303, 12.053914223947833, 6.1440933039111485, 3.516411968777257, 3.7351012662533796, 2.249866382729623, 13.661368200855872, 8.845515443432717, 16.810962807747625, 8.584522893351894, 11.61242106268483, 17.041764874612134, 15.143493625425524, 19.33975015917132, 9.525270039035428, 10.154845753023702, 6.270580426339181, 3.905850620039048, 1.7266188922428316, 0.9581043078534065, 6.471815176548497, 18.453551415474184, 32.541402847536155, 30.884530928827104, 34.811411826841294, 34.72937153231713, 38.01245812446841, 40.60018301010132, 23.468374244628414, 6.638660546272032, 1.1707603258471335, 0.15013907585413228, 0.1679510337811324, 0.22816172951171476, 0.13298391574813476, 0.13333314458929724, 0.1833543346654023, 0.1696482096468249, 0.2139133827820901, 0.16372049708039532, 0.19024560197947488, 0.10816553983116343, 0.11655275469585774, 0.10645527918372424, 0.13170018221341795, 0.15494256971343873, 0.14370793626914102, 0.15906160997767604, 0.14296765018615032, 0.15279775335183068, 0.18798193473729397, 0.12559254623709187, 0.1745405390618309, 0.20071377977728846, 0.2029715787859694, 0.16901773460690053, 0.19505502535931526, 0.21329861254461352, 0.12243041107731482, 0.22185140199238257, 0.11780764502022537, 0.1013463537298864, 0.12050173110178403, 0.17234660114251799, 0.16368925601484316, 0.15183592996289655, 0.11542349513019286], [0.027286640345870007, 0.028412245672136068, 0.031179690418104013, 0.07421397093322969, 0.021093290622135805, 0.05723730548314991, 0.06342459545140305, 0.0417907091398393, 0.03358218045304379, 0.03113164138349314, 0.053732116150880055, 0.01348360233204139, 0.034407226503976894, 0.022856964834875638, 0.02794534189536447, 0.041806184115909764, 0.03454960394470442, 0.045542329805152076, 0.02965225856901417, 0.032509174723658836, 0.054096452245909366, 0.041542990779083584, 0.08206182925571358, 0.07753670876545292, 0.043546831640865535, 0.015639118069121917, 0.05815434337203061, 0.04599520268159048, 0.017451013686255585, 0.03153510350403527, 0.024470388138246153, 0.0299856006618469, 0.0664431197688945, 0.05849472006722804, 0.027304769816598105, 0.007329882815435169, 0.04191223749770753, 0.01127910484830218, 0.047903734544712695, 0.049196247447041735, 0.01473418819988447, 0.13193157141006764, 0.06091776041073665, 0.9794195092493488, 4.753085519036939, 20.853455566590835, 37.741551783777055, 37.068845687373994, 29.995710080669774, 28.306033419024562, 16.405260293714463, 8.730236003475806, 6.644745613298109, 16.08461633805306, 11.32179206417453, 2.3521218376774944, 0.44714762558860166, 0.01449658219972926, 0.3875815009157504, 1.7456969330387733, 2.2424146148466297, 4.980552100366162, 3.770150095224381, 4.646567673452439, 5.001533348714152, 5.9515961235569375, 3.848922565098732, 1.1492692919508105, 2.761705291848029, 2.0434168413762124, 2.011227297686762, 0.4434791063108752, 0.7057586841044888, 1.9002700645116068, 3.09706499980342, 9.788451271672404, 17.10110837413419, 29.59180989573079, 42.02003002166748, 52.323810131319114, 56.81523776823475, 57.16317161437004, 56.112196060919, 57.88368748080347, 58.35612912331858, 57.90244425496748, 58.067693710327156, 59.52840005197833, 57.22960087560839, 56.15616583055066, 53.13614476111628, 57.02310769788681, 57.38375394575058, 63.86885173859135, 65.65825270068261, 57.72260750493696, 59.894153225806456, 57.98883838038291, 57.174201319294596, 54.141514916573804, 55.516242904047814, 53.621075230260054, 54.942137349036436, 54.25742879990609, 57.8286801615069, 52.114222203531575, 42.25456814612112, 27.40549448997744, 14.998702272292107, 7.9937835470322645, 3.193990443983386, 4.661798727127814, 1.4221249280437347, 1.741663020464682, 2.5622341373274407, 3.4706467341992164, 8.693439268296766, 11.339010288638454, 10.08910192597297, 6.789973820409467, 3.5364077216194527, 14.848288201516675, 8.218950638847968, 6.091159447546929, 4.200469649607136, 2.3492979763015627, 1.4894717787542653, 0.5092911151868682, 4.654145692625354, 11.810617446899416, 21.09976080156142, 12.593464678333653, 16.351072749783917, 24.485327159204793, 25.70137566135776, 26.568678386749763, 18.98316748680607, 4.326057078376893, 0.5073805531907467, 0.017972087540153055, 0.0625545647175562, 0.052812393123824755, 0.055338414836554765, 0.01823636297617228, 0.013923115592690246, 0.04958407562826911, 0.05511267553834666, 0.02635581287435226, 0.06581845933631544, 0.03023210668846244, 0.07109536488931026, 0.1055423858305139, 0.06546857165953805, 0.07983025343668076, 0.03919454441676217, 0.058893832723580064, 0.17019202482075463, 0.049110357499411034, 0.06982755066166002, 0.020406577067690033, 0.0693074688916245, 0.06603380665183067, 0.06339869018824351, 0.0577006277988755, 0.03362924889511159, 0.0066966536894230355, 0.12411376671685327, 0.025204380808938897, 0.06778401112364185, 0.059194211968250816, 0.11443408491510539, 0.07052965492250458, 0.054057286000780524, 0.020293452694351156, 0.06482141888550212, 0.05771732085474557, 0.04206814405117785, 0.05362440801916584, 0.04242761165744836, 0.03806145441147589, 0.02238771299861612, 0.07404592954703877, 0.005922151246904246, 0.06187746939699977, 0.05214506159386328, 0.011919777476108603, 0.0684826756497064, 0.03556288545951247, 0.01714733068741137, 0.02183594583203235, 0.04208928424744837, 0.018231320202410705, 0.0732401276247636, 0.07549917535676111, 0.0579325226135552, 0.037540790414617914, 0.01713140563468539, 0.10930628305481327, 0.07362684114806115, 0.0231625898666079, 0.03250547834942418, 0.019294286349547968, 0.05052195110869023, 0.0502412258497169, 0.027716176268915017, 0.03829241842932759, 0.02739701829400034, 0.032897370627089854, 0.03605225093422398, 0.1205418894307748, 0.028975289652965246, 0.012867525914653897, 0.06909655722519083, 0.011243521021829258, 0.05627884522020336, 0.02435611654824067, 0.057111529167741544, 0.03135079998643168, 0.1858383287946063, 1.752101428085758, 8.85973697708499, 27.243673186148367, 43.448055175042924, 41.66677744157853, 31.935671221825388, 24.115063259678504, 12.165236972993421, 12.00176239013672, 18.580920580894716, 23.77151462339586, 9.937107140018094, 2.1125988710311154, 0.24118553065965254, 0.15818552714922737, 0.2445336566456864, 1.23601189544124, 2.566064822096979, 3.9839266240596776, 5.353325336210189, 5.400667853893773, 5.002665442805137, 7.2705950756226825, 4.777249280483493, 4.076983630657196, 5.232928183770949, 4.18101224207109, 4.257689185680882, 3.019270916138926, 2.532291744024523, 3.431065361345968, 4.4413281832971885, 12.047049095553737, 20.3082186560477, 33.652559326541045, 44.124134509794175, 53.83874716297273, 56.41175531571912, 58.806566269167014, 57.94763388172273, 58.77817615385979, 58.2694878885823, 58.94562213651596, 58.47450233274891, 61.584098569808475, 58.04382608782861, 57.29053881860549, 54.118141512716974, 58.66419599902246, 60.85760893360261, 61.578450356760335, 62.89123627447314, 57.66136361706642, 59.954969575328214, 60.134669042402706, 59.50132000830866, 56.21200469232375, 55.35120133430728, 55.21804078932732, 55.3288399019549, 54.714847764661236, 57.11553835099744, 52.85673864426152, 44.19719649899391, 31.96345925331116, 19.11398441560807, 10.623245393076251, 5.2293284285453066, 4.431010388558911, 2.5169815075012947, 3.1632326879808983, 3.3632826372500393, 3.7956861959349726, 7.205203771591187, 13.362806208672064, 16.35493334262602, 9.566473557103066, 7.471430234370693, 9.100574428035367, 8.100394548908357, 3.2077530603254996, 2.299711862879415, 0.7839435951844339, 0.7921578350567049, 0.6071203898998999, 4.162556509817801, 13.099949552166848, 22.073461740247666, 18.246569902666156, 18.79721380049183, 26.588460860713838, 29.937084374889253, 32.22030978049002, 23.074860495905725, 6.261429046430896, 1.0133256414724936, 0.040726222308172334, 0.021108905409252452, 0.06354064245017306, 0.06704612289585414, 0.006659808211899813, 0.0730198850074122, 0.030998661926376726, 0.040059557274704984, 0.05680360395701663, 0.02212833861009248, 0.041952889953409477, 0.030814025160526077, 0.07375824054883373, 0.07064872030769626, 0.04744601999259284, 0.05115519555646086, 0.12523649921340327, 0.029529393387718067, 0.04366278287864501, 0.03771869135239432, 0.05766537243260011, 0.04495795027563169, 0.019981637672190706, 0.03352282396067054, 0.027708873535776814, 0.03053234037642758, 0.05943275259567365, 0.09799047493405881, 0.041876170078232404, 0.04733674521107347, 0.0490323199530042, 0.004505122722607226, 0.04785984919797029, 0.06371860850542303, 0.0733657124181909, 0.016179123870848168, 0.028155824552560528, 0.12151329657964169, 0.08325023080913291, 0.10800690600468267, 0.15468413761306196, 0.14740558220974861, 0.17615525322335382, 0.14974886130902076, 0.22025841408439223, 0.11716628387089699, 0.14024652120086456, 0.1802906111603783, 0.17419354719740732, 0.21325212632936819, 0.1109560227562343, 0.07409250003195579, 0.06976373553756746, 0.1754484298608957, 0.10255670370233637, 0.1256366116144965, 0.11601423318948477, 0.15212385644835813, 0.21004647737549198, 0.1687670246728005, 0.14011642414956324, 0.08849417925962517, 0.1228999770096233, 0.0978172088282243, 0.19683625639205982, 0.11887590100447978, 0.09354184832303755, 0.1357053664903487, 0.1185659035259197, 0.14257348262734953, 0.2044255370574613, 0.19192998417683188, 0.09357978499704793, 0.17990730672834382, 0.08796071393355247, 0.08878013689912136, 0.1618809820783715, 0.1154191360899037, 0.3057466711728804, 0.29412110306082234, 1.8425449104078355, 9.443009111189074, 29.75909898358007, 50.35170516660137, 50.21821514252694, 41.056605692832704, 39.469438214455884, 23.771720547829908, 18.115129317006758, 16.667323650852328, 22.167626080974458, 13.91326379391455, 3.2271450133092943, 0.7817888043580518, 0.5420858376929837, 2.5674229427691433, 4.646668184188105, 6.8828908474214625, 10.712525402345966, 9.828779120599071, 11.525806303947203, 11.899237517387638, 12.249349259561109, 9.318046319869257, 6.394252757872305, 6.576339477492917, 6.832414355970199, 7.121241025386318, 3.1051171354709135, 2.3295329078551266, 3.9615039046733616, 5.081250129207488, 12.661380517867304, 19.410217500502064, 31.68820300409871, 44.45078165300431, 54.63641212832544, 58.38112638842676, 58.65188760142173, 57.61751936328027, 58.45695757096814, 59.68180002704744, 59.55801002440914, 59.42911701817667, 61.110421380689075, 59.45917021843695, 58.50219426616546, 55.67733072465467, 62.11353225092735, 61.31577707106068, 62.992990401483354, 65.95429358943817, 57.564586977804865, 60.396553931697724, 59.98531303098125, 59.248201616348766, 58.613377771069935, 57.388641218985285, 56.02412316106982, 57.30555365162512, 57.325318474923414, 56.754566546409364, 53.266649861489576, 42.72285599862376, 29.230247774431785, 17.582904869510283, 10.47797845255944, 5.193976106182222, 7.693682024555822, 3.3321321539340483, 5.977140559304146, 5.449383201137667, 9.05354226789167, 18.468476033979847, 18.45300816720532, 19.270008456322458, 16.289474868005325, 13.90674481468816, 22.480468442363126, 17.95517113900954, 11.806856874496708, 9.415620180868334, 4.382466154713785, 2.4747189494871327, 0.9790400812222112, 6.298108110504766, 16.126344473131244, 28.41844462579297, 19.465022817734752, 24.31402352548415, 32.24772518680942, 36.42944835847424, 37.594435445723995, 26.54741914041581, 6.652438852094836, 0.9962606345934253, 0.24233648583533304, 0.17122605965743143, 0.15955832606602102, 0.17359183109816045, 0.08830242745217778, 0.11830770891279944, 0.11163577257144837, 0.18970287465039762, 0.12763944890109763, 0.11007036382873213, 0.18666768025967384, 0.11648314794705761, 0.22518940029605744, 0.15215894327529017, 0.17893282756690057, 0.13321611699798416, 0.29164663906539645, 0.21917637617838, 0.149341348498579, 0.16691606431718797, 0.18888075505533528, 0.19600935640834993, 0.2176889551863555, 0.14225969301356425, 0.09946331727288424, 0.24817553138540638, 0.11769035695901803, 0.23242952872908887, 0.16379750423854397, 0.10928025904802546, 0.14615364132388947, 0.22562409390605268, 0.12194286506142347, 0.15457593535463657, 0.16790563541073955, 0.20278739592721387, 0.13005433423865226], [0.05501278916433935, 0.037409666805498065, 0.11294732275869578, 0.024226306779910962, 0.06833666695221778, 0.053600647802194284, 0.054562724000143434, 0.042351244182716456, 0.011647290535150998, 0.046200127370895884, 0.023559817946666194, 0.037310243914684946, 0.03519632387906313, 0.06103505230238361, 0.12893215332540775, 0.06518265998531735, 0.02155028696682665, 0.06290511122994846, 0.010591428895901528, 0.026212837885043798, 0.06834513222378108, 0.027274691289471045, 0.04003431467759994, 0.15203342742977605, 0.08587759063248673, 0.023794980126342947, 0.07590949970988498, 0.07954034278349531, 0.07482587600186949, 0.09998021211715476, 0.028204934618946527, 0.0032991377755083266, 0.04886443944527738, 0.04173844279120526, 0.039853196170541554, 0.008404040070731313, 0.007518723967575258, 0.050775595159540256, 0.029104450161779122, 0.04143611768320684, 0.02343137564528133, 0.03847555557806646, 0.01778729372627793, 0.02433462586674479, 0.5694098650447784, 5.29833076461669, 17.070549188121674, 35.30020975297497, 36.233541657847745, 24.80906390374707, 25.93115006723712, 24.507088468920802, 12.713484302643808, 7.447942101186322, 16.599662765379875, 10.904449916655018, 3.898009802064588, 0.7968354453482936, 0.1140062171485155, 0.42327338409039283, 1.9640490292541444, 3.972331117237768, 3.5157363405150757, 3.768128848844959, 3.4398811334563844, 4.405715023317645, 4.413488180406632, 3.0235112434433353, 4.064047898977034, 2.331018750706027, 1.989694098311086, 2.4813024026732293, 2.7878606367495755, 1.2866427076439704, 1.9390316619988412, 1.714528676482939, 6.4680462691091725, 14.891690208065896, 27.479076193225, 37.966613461894376, 45.93435541276009, 52.95645706115231, 57.2221326828003, 57.34279263404108, 58.14659218634329, 55.904286907565215, 55.10259759041571, 60.135025978088386, 57.37095917424848, 55.22667000370642, 45.44862870247134, 50.534150292796475, 59.91878178811843, 51.94931791674707, 58.651028602353996, 59.80110283820861, 61.01403697844475, 54.63655725602181, 57.35017453470538, 61.15460295831004, 56.639558730586884, 58.439769744873054, 53.81435786524127, 54.968095594836825, 50.46526955020044, 38.55949932529081, 23.17883272324839, 13.388928213427144, 8.21024788002814, 3.5809138753721794, 1.9149535798257398, 1.5712884981786053, 1.87928979675616, 1.5463049613660382, 1.5032774185942066, 4.010913511437755, 4.1521337916774135, 9.669396550424638, 12.83775479562821, 7.909083885531272, 4.339421574146518, 11.191928271324405, 4.442311717617897, 1.6899270804659015, 1.2695251164897796, 0.37985397202353327, 1.094931104490834, 4.231918233056223, 12.323196703387845, 19.76973802812638, 26.224441374501875, 22.16377039109507, 21.771013659815637, 30.55947626790693, 27.413009751227598, 19.862411868187692, 6.117566314435774, 0.7044014214507995, 0.054622363945048664, 0.049199319459618106, 0.039714323582067605, 0.11988855432718994, 0.03241357078114825, 0.030565647964155486, 0.054659856288062955, 0.033195585673374516, 0.09033480508913917, 0.046415922847846826, 0.08043130303943351, 0.0355482493497191, 0.1099731932364164, 0.03437894253781246, 0.0564318904352765, 0.016316016122037848, 0.03998495180219893, 0.026492944528018276, 0.02953513521671055, 0.07619541138410568, 0.06611797673207137, 0.06585902369190609, 0.0523205838286348, 0.06686811470576833, 0.022970229019260695, 0.0512033288607434, 0.04718618595131463, 0.019948307101825075, 0.05257615842105401, 0.11623180982085968, 0.053439087519842776, 0.030412987708264304, 0.019094335486090953, 0.02742564891495051, 0.020068467992748466, 0.06576435054622351, 0.056289298489930174, 0.05852610285904619, 0.044530814123009486, 0.05936861954509251, 0.07369092440292721, 0.023874944383879344, 0.014002700636704123, 0.031204176503383828, 0.09252245342659374, 0.03144375709516387, 0.025304188658933968, 0.007207332208992974, 0.06036525013886633, 0.03124911905146174, 0.016900744221563783, 0.08140745227255168, 0.034586659617601864, 0.05770527412213626, 0.06819912352629247, 0.03203665169196264, 0.011316846169891858, 0.03401903826142511, 0.0838393907273008, 0.09556345476378357, 0.029867801236950105, 0.18610253719793213, 0.014131845823759514, 0.0763706616576641, 0.06720986652878985, 0.06633561465048021, 0.02240428539563812, 0.03102407497804492, 0.0219315976550382, 0.0034618876487647575, 0.09049434289937058, 0.05192696785313949, 0.003029473629149218, 0.0175662390557268, 0.019707345636561513, 0.01935553316387438, 0.008632504726730047, 0.026039746064212055, 0.04385520118258653, 0.056843647372818766, 0.05128854465100074, 0.12203923892229797, 1.3501880462131193, 7.888537039679866, 22.973461343396096, 41.097272826779275, 39.03019159070907, 28.537861185689128, 19.565945402268444, 20.145859987505023, 10.143951369870095, 16.746477080929665, 24.777590805484405, 14.26808532207243, 5.806143360753214, 0.6784782318338272, 0.027577740350557912, 0.2490648522131866, 0.29473863121482635, 0.35083410179903435, 1.5880094396491207, 4.374131118097614, 2.5662170590892917, 9.343782951754909, 8.501878553821195, 2.432668444610411, 4.001188239743633, 3.510907167388547, 3.593859903274044, 4.105297995190467, 5.28955053898596, 3.6267465256875564, 3.3471062923631365, 3.456941237372737, 8.438755850638113, 16.513048987234793, 31.63625317235147, 40.804887587024325, 49.3016396030303, 56.32744789123536, 58.87313673573156, 57.4424365258986, 56.52315062861289, 57.01862442877985, 56.83159797422348, 60.0841018461412, 59.30014164217057, 57.75937188056208, 45.54843733387609, 50.4115056222485, 59.971902447362105, 56.17835467861545, 61.314416008610884, 60.54661989212037, 62.013492199682425, 58.428712583357296, 59.09950456311626, 61.383853727771395, 58.680717022188254, 58.29211996447656, 54.80793345359064, 56.24079881175872, 53.84595647934945, 41.08275221240136, 27.660797642123317, 16.521868436567246, 11.08972111055928, 4.9898937152278044, 2.7531192235408293, 3.1021496172874206, 2.9699105841498223, 3.36913162662137, 3.861034844190844, 5.666175052042931, 2.9609935658593334, 6.945220251237193, 14.589336264518, 12.446800393442954, 8.767184730499022, 7.353718924906946, 3.829748303659501, 1.9303188521054484, 0.7176256311997291, 0.512112831516612, 0.736218830270152, 3.4275749421888784, 10.872757165662705, 21.049093584860525, 26.96293346343502, 20.389864752369544, 18.865123756470222, 33.36921515003328, 28.990004562562515, 24.741208860951087, 8.66176514856277, 1.7261219769716265, 0.06815099022200993, 0.03831920852403968, 0.027853771405775222, 0.08047977342240273, 0.027938592660751556, 0.02047769875536042, 0.017435167157541842, 0.07216414181335319, 0.07240668525018039, 0.05886878930933534, 0.08927872224200158, 0.04811920826473544, 0.026269543713199037, 0.051722908843188524, 0.05045560789444754, 0.010229926368582153, 0.02808498057176269, 0.0767154012235903, 0.07045093172740552, 0.08127033785586396, 0.08642820866718408, 0.0222464463853788, 0.0251120135879084, 0.031970731741298115, 0.04921126277035764, 0.037020628205350334, 0.0235027807854837, 0.05360985234860451, 0.031531920408709876, 0.03785237752562089, 0.05188440017762685, 0.03886939371905981, 0.03877007808055609, 0.021735825801208135, 0.0009135959994783926, 0.007137352949939669, 0.04395521779154097, 0.05419665271596563, 0.15018427504166482, 0.19952750794829863, 0.17767046788527122, 0.114294741182558, 0.16862516051098225, 0.13226206174060223, 0.17965940067604666, 0.11401207772113624, 0.11850352098624553, 0.1517865785788144, 0.15772083353611732, 0.17885482449445034, 0.14080230266817156, 0.12068106462397885, 0.23732700625494604, 0.14170634770585647, 0.21056763166862152, 0.13265439068838475, 0.07083544657836038, 0.16064951106184916, 0.23582012662964486, 0.20023338136173066, 0.2172963044816448, 0.32901536613222093, 0.21132935289173357, 0.2535075952689494, 0.22851648950769057, 0.1558479171005949, 0.18749025950749076, 0.1594446386180578, 0.1609758798393511, 0.06334551985585882, 0.23565872722575743, 0.13765585698908375, 0.13641151569543347, 0.10191941814076516, 0.10871899239118062, 0.15078974497174064, 0.11796237179829229, 0.11096936800787527, 0.18289371664004941, 0.08891659248019419, 0.07955957925127399, 0.1959808732593252, 1.3942660487467244, 8.171712554270222, 25.320074212166574, 48.157786246268984, 49.37344251140472, 36.41164079789193, 35.5964389154988, 33.240855586144235, 19.931765256389497, 13.323496214805111, 25.102625854553718, 15.00642934153157, 5.471739240231053, 1.1472131119620417, 0.3362783393071544, 2.2163659093841432, 4.440995272128813, 9.021628883577163, 9.579759605469244, 11.03981581426436, 8.922004603570509, 9.964964793574426, 10.913860663290947, 7.845222796163252, 7.798595130443574, 6.235403630041308, 4.557045948120856, 7.30674167794566, 7.581597355104263, 4.433231920965256, 6.394335617942195, 3.3097057573256956, 7.314221637864267, 17.414054678332423, 31.011672596777643, 40.383024907881214, 48.39387370694069, 56.579330736590975, 59.4269871711731, 59.36720240500666, 59.39824796492054, 57.895117267485595, 58.05816235080842, 62.23708298898513, 61.02368208669848, 60.292218885114124, 46.722708671323716, 53.44097175905782, 63.30705850355087, 58.5837991776005, 63.02209438816194, 59.50430100963962, 63.34834537198467, 60.40800333023072, 62.19399183027206, 63.875747265354285, 60.073789934958185, 60.930376745039425, 56.99983235328429, 57.43523505426223, 52.64248309596893, 41.13764186059275, 25.32582440683919, 15.891541588690975, 11.023301655246366, 5.69041726089293, 4.133097548638621, 3.730554994075529, 4.588167013660554, 4.6080303865094345, 6.460146615582128, 10.728846384632973, 9.987595888876147, 21.696747502973004, 20.0297107619624, 12.811215058449777, 8.180720767667218, 23.274010996664725, 13.728207349777223, 5.632325978048387, 3.1771995127201085, 1.1358250004629935, 1.9949168567695927, 6.083395115790829, 16.57659138402631, 26.26013102069978, 35.40015566733576, 29.571580271567072, 28.938488152719316, 40.63745729384884, 38.117761996484575, 28.298053356908984, 9.725430550113801, 1.6486377605507452, 0.14553591398702515, 0.1601863955898631, 0.23211558589771872, 0.2357733186574713, 0.13635980476054455, 0.1229334090866389, 0.13739554031241324, 0.12939735255654783, 0.17692639732793455, 0.13475250633012864, 0.3251540072021946, 0.1399331299527999, 0.13491643382416618, 0.17242887898558573, 0.1811615458779758, 0.13490307325076673, 0.12682243145161098, 0.2456254391900955, 0.11082942672674695, 0.16244068591585084, 0.1919193202329259, 0.23102233246449502, 0.08745548660836874, 0.2328751773964013, 0.1699684497209326, 0.11771356176224448, 0.14488026529790896, 0.15643860153373212, 0.22165195866217538, 0.21346329080481685, 0.16603088036419886, 0.13691785384810742, 0.13751241468614148, 0.11186832622174295, 0.07610423926023707, 0.18196423748327842, 0.244348309333286, 0.14332129169375668], [0.07179831950775079, 0.024450647967657255, 0.03276557286059664, 0.0421696123967488, 0.10449132085928034, 0.07918968901879365, 0.049275150672803004, 0.039722945901655385, 0.0012008435395170726, 0.03561268883546995, 0.10317901224498788, 0.050669775434559396, 0.07185209121915602, 0.12346515071488197, 0.08685622965135882, 0.017206721653741215, 0.06417209808264049, 0.1068114104770845, 0.055407761115460634, 0.014269019612261366, 0.05558447078651479, 0.021804852238405618, 0.08234744215564382, 0.06362565905757009, 0.02102152350538921, 0.08791366081324317, 0.12829583303462114, 0.03176446448290541, 0.053223464412674795, 0.05019007415901269, 0.0791981466294777, 0.034190408299647035, 0.053598050764130975, 0.04617638630612243, 0.06393367619884592, 0.050413285367070675, 0.046345289541228164, 0.018009348141570247, 0.025034142665625102, 0.07562708139659897, 0.04386206533038809, 0.07139856716798199, 0.05544003256927094, 0.0066667374771749305, 0.05481331136017557, 0.4173764989020363, 5.345733588741672, 18.58258366584778, 36.26728580844018, 39.241842685207246, 29.52964621205484, 18.147255489903113, 34.56445940079228, 31.203849123370265, 8.97240117672951, 13.491378561142954, 10.071280637095052, 4.175233610214726, 0.9317891263673383, 0.3564040819483419, 0.48835699656798, 0.6757617453413626, 1.974068356137122, 1.3891183056177632, 1.0601035217123649, 8.489914344203088, 4.4712401782312705, 3.418227198623842, 3.444542625258046, 3.2894452444968687, 4.528905883912118, 3.8236419087456124, 5.349232342935378, 3.3247080877903974, 1.3215835488611654, 2.8070670125945925, 2.044761969197181, 3.4540509408520115, 10.08579929028788, 21.994816257107644, 31.449795461470085, 41.62982479218514, 48.938761526538485, 52.95005183066092, 58.750319480896, 58.380008512927645, 56.39597954288606, 57.45278373841317, 54.85576675784204, 47.478867115512976, 40.87435668514621, 44.57060613939839, 57.22996173366424, 48.63088292460288, 51.57871669338596, 56.19674274998327, 46.550042013968195, 55.33535103644095, 61.527992986863666, 53.75550270080567, 51.281789348971465, 55.93485393831807, 49.01434952212919, 46.161013495537546, 35.828431421710604, 21.178737724981, 12.114715864581447, 6.330175938144808, 2.5480224096005966, 1.5565005497586344, 1.2697502850524842, 1.8748805623862053, 2.121716420496664, 2.807603641863792, 2.4318822545389978, 2.036408669044895, 4.646749083072909, 7.3782322675951075, 16.97105826870088, 17.28503615625443, 12.319354741804062, 3.4243573729069006, 4.198881089687347, 1.1455480658238935, 0.7620906613526807, 1.6320793522942452, 5.213168263435364, 9.79313458165815, 15.238295351305316, 20.541323154203354, 16.35514024765261, 19.130970239639282, 27.21857197823063, 30.34642880962741, 21.97045833833756, 7.195013944179782, 0.8280977775012294, 0.00814174976004588, 0.028429683748512503, 0.026347293976634264, 0.055767941183500716, 0.06599644454376352, 0.04314742404066267, 0.015945557069273728, 0.062021578196436174, 0.039992463294296496, 0.011060839695405337, 0.07913426255747195, 0.014971125788325745, 0.04038183897313091, 0.025286838682668827, 0.07587137917477278, 0.028515213634818796, 0.07556171877489937, 0.0072899040383016395, 0.05301673941674733, 0.013749185863191323, 0.06381058502161215, 0.031093823453111034, 0.10906687291759638, 0.0085189561322031, 0.0686149024254372, 0.021099235464428222, 0.013783228895326537, 0.04911256383263296, 0.12534754365802775, 0.007483158335690537, 0.07843369047247595, 0.09826658834372798, 0.016784693392354156, 0.04247632335811373, 0.046043945025772824, 0.06374258705745302, 0.006977089750204957, 0.026619048346014276, 0.033641445014866135, 0.030717444455912037, 0.04810567532155303, 0.07764174708075101, 0.042359755419555216, 0.09748889418739466, 0.007297755003110656, 0.029609853687185436, 0.06141140448650526, 0.011505717486743967, 0.02968047167204561, 0.06738019851787437, 0.001033273297399583, 0.03633927726637452, 0.05381172417753166, 0.0412643148053077, 0.008658577571623027, 0.08868230747119074, 0.06889510674462204, 0.06764816075202919, 0.014142440819752314, 0.02331896181849222, 0.01038068672642112, 0.07753438751904235, 0.01369215923571779, 0.02096937973082306, 0.014462248054182818, 0.08673527968987342, 0.04257454732132535, 0.03678609421777149, 0.049325781423718705, 0.026546043997269966, 0.06481875289952563, 0.03952745175469787, 0.016721876097782966, 0.08970087499267633, 0.03998224751182622, 0.024223140921563874, 0.1194499230252639, 0.01610461415933265, 0.052792758290325446, 0.01562930927086141, 0.010533043419972304, 0.00843310831940823, 0.07080274228487285, 0.13138623938204783, 0.9072187254505774, 7.960373778497019, 23.760945796966556, 43.84585411317887, 43.51326065678751, 31.44728122218963, 18.655469148389756, 20.915744766112297, 16.199006380573397, 13.637400557917934, 20.841070682771747, 13.084615045978179, 4.884636421357432, 0.8003307061810648, 0.28350379858766833, 0.22554541667622907, 0.5109647108662514, 1.2685842379446954, 4.0635980521478965, 2.9266841036658136, 9.581534477972216, 9.093373936991538, 2.8189821925855454, 6.468597362118383, 4.090602590191749, 4.945186049707474, 3.801714388593551, 4.686835706233978, 4.8976650641810515, 3.7074100682812356, 2.904841895065, 3.9428275390978786, 5.432363056367444, 14.8689208492156, 23.50567598496714, 34.72384491274434, 43.55487700431578, 53.129461042342655, 55.55698456302766, 60.04059883856005, 58.07830764401344, 57.64497203211631, 60.803852850391024, 59.117453329024784, 52.00086178318147, 43.483050561720326, 44.074661654810754, 60.82573575358237, 53.009389446627715, 54.19659283853347, 60.81528655944332, 52.13177481005269, 58.33554452465427, 64.5630955696106, 57.0853792467425, 53.967989260150546, 58.53278875350953, 51.69867061799573, 48.179300446664136, 38.926801835336995, 24.384326127267656, 14.611395674367106, 7.711873977415024, 4.590862662561478, 3.168101820253557, 2.8807980110568385, 2.335400773632911, 5.578872407636335, 4.073878829517673, 3.899439996288669, 4.679671006817972, 6.0416331502699085, 6.714525068959882, 9.503736226789414, 9.56230898057261, 6.554913040130369, 4.42152560718598, 1.5211081456753517, 0.8555535106889663, 0.27286240831017494, 1.4508249105945712, 5.0570476343554835, 10.718544279375385, 21.173597458870184, 23.791828578518285, 19.71907473379566, 21.390710453833304, 30.621581116030296, 36.5829973836099, 26.000850585199174, 10.231669295218683, 1.5584144212545887, 0.0362669853793998, 0.054449940535930864, 0.014772910114017226, 0.01886420458885691, 0.0745397728056677, 0.0665184338727305, 0.04993585937265908, 0.039737401980786555, 0.010886867831070578, 0.016663866004936637, 0.05622122774741823, 0.04438540680454143, 0.06983748682203793, 0.03219625845010723, 0.05153768793529561, 0.018148211153945135, 0.03354130200140419, 0.05701675260018918, 0.06843319403067713, 0.008653838360201447, 0.04760038287889573, 0.1350361886884897, 0.0930774764668557, 0.006970506660910624, 0.02256126447220243, 0.038478543320971156, 0.024352132891034408, 0.031489270378745375, 0.05094952010098965, 0.040051337151277455, 0.16950887357515676, 0.07809789881350533, 0.04550391049574941, 0.09019215951763815, 0.05694271786318672, 0.014403189378490132, 0.07153624848973367, 0.004618095793581058, 0.06334829692458434, 0.21097025683810636, 0.14233951937527428, 0.1556632899108433, 0.252936813800085, 0.16943039552819344, 0.19074585739403002, 0.21833827598921715, 0.18452554520580078, 0.09355837283956428, 0.13752148516716498, 0.1451808781993966, 0.12787708937520945, 0.17539003863930705, 0.18508089766387018, 0.1946849895701293, 0.17248989022787542, 0.14189276754135086, 0.32290293444548884, 0.2704968820175817, 0.06617930973128927, 0.1116646464253145, 0.14535353909577095, 0.15951131891098716, 0.1292654628595037, 0.12939583570245775, 0.16989479802789229, 0.19008766529300522, 0.12637438492909556, 0.15621729405416598, 0.1579314464282605, 0.2898269350970945, 0.18008871634881343, 0.14504436133128984, 0.17166873590359766, 0.25667998068515335, 0.12574364175839772, 0.14347748169975896, 0.2170525812694142, 0.1501572627814547, 0.22084356736271615, 0.22146426712072667, 0.19933123622209797, 0.11801167721709899, 0.15528119589772918, 0.20604448002432624, 0.8551827241336146, 9.041720244192309, 26.17357803929237, 48.848998085145034, 53.70992083703318, 40.8938116412009, 27.10779247745391, 45.540059151188025, 43.91286388520272, 17.594960274234897, 21.728044094577914, 14.077036476904347, 6.311570665528698, 1.791500165577858, 0.7320879003213299, 1.6671028084331945, 1.3660711939296415, 7.795849961619224, 7.483636650346941, 5.911328581071669, 15.110872253294914, 8.789262771606445, 9.218391641493767, 9.622522265680375, 10.919767752770456, 11.014749907678175, 9.656525292704183, 12.22227608003924, 8.487568766840043, 3.277752168716923, 5.831272025262156, 3.792351445844097, 4.57785019951482, 13.157374032082098, 24.07579052832819, 35.4257805116715, 44.20133852189587, 52.81340822096794, 56.58081339251611, 61.37341237837269, 60.96477593145063, 59.90692446308752, 61.75871464513964, 63.3842154472105, 54.47162551264609, 43.49673571125154, 46.06517822511735, 63.58284427273659, 57.7480479978746, 58.132648160380704, 61.32328448757049, 54.84956549059961, 60.5466002802695, 65.13673828494164, 58.212123224812174, 56.43155936271914, 60.030235936564786, 54.55440321276265, 48.68587847678892, 39.1762920348875, 23.154537562401067, 13.638148750028304, 8.373458193194482, 4.331983779707263, 3.095476930179904, 3.6333456683543424, 5.313741266727448, 7.7052922402658774, 7.47759472939276, 7.371200928764959, 8.855244882645147, 10.061406070186246, 16.75678114737234, 31.44917376579777, 29.77087001646719, 20.520742477909213, 9.19254812502092, 8.187170124823048, 3.1265999569046885, 1.5425772388135235, 2.7893263774533428, 6.774632940369268, 13.203471687532241, 22.316787935072377, 29.399252899231453, 24.858681886426865, 28.233740214378606, 38.113392476112615, 42.46981997643748, 29.444619032644457, 10.935852412254581, 1.5874376316224377, 0.12833242905476402, 0.1637988525532907, 0.10877864765784434, 0.21007667656146714, 0.22184951741608883, 0.1670998028449474, 0.10782888249283838, 0.1535451640525172, 0.06664987923877855, 0.1269412363669084, 0.2671934189575334, 0.10968899759914606, 0.2750370561355545, 0.09909318189226812, 0.1587526620395722, 0.06304664597395929, 0.2656462890726905, 0.12402149908725293, 0.17895873666049975, 0.10589932151619466, 0.1317827511698969, 0.23866588279845255, 0.31883935894696946, 0.11044940881190762, 0.14889318706287494, 0.1223213048351388, 0.12239810514954791, 0.08455326209866232, 0.19938823316366444, 0.13616793037902925, 0.13723947288047883, 0.14909702773776748, 0.161007932958103, 0.16106188086973083, 0.1789546151074671, 0.11323180950937733, 0.1514449033645853, 0.09746357498149719, 0.1816535735082242], [0.10558124181003341, 0.06230170207638895, 0.06632488941954029, 0.011622443430936866, 0.023341205181373705, 0.09485473916415246, 0.029074932794056596, 0.040883779781119484, 0.0516072180753033, 0.014562196672833977, 0.055372076739947644, 0.027778667976118387, 0.03735178120193943, 0.05297178920779017, 0.035150121116349776, 0.03558865665728527, 0.0381298239282783, 0.0635215170651434, 0.030257349285567482, 0.05143651070313589, 0.05483417959523298, 0.011999334749435226, 0.030764214123689362, 0.09768649124570432, 0.15094559789905626, 0.042037921882564985, 0.06891432022976299, 0.04561828742284448, 0.09363772422676125, 0.011993884991463876, 0.07745757954375398, 0.04052007187818808, 0.020599301806801272, 0.04817414059934597, 0.05047926851998895, 0.028874313518885645, 0.060447727164794365, 0.024021083316315087, 0.04518459355759044, 0.013554990235265466, 0.06695952431689348, 0.016004109169326482, 0.01854034091886734, 0.050072406884282834, 0.030969824461686998, 0.03254112825098057, 0.21360510900135965, 3.9450642706886416, 17.691038731605776, 31.880981614512784, 31.769480397624356, 38.91438361137144, 23.11536289030506, 25.873838355464322, 25.359295952704645, 21.136221193498184, 21.633567925422422, 14.859032554011192, 5.171302845401149, 1.5584431035864739, 0.11630078071668265, 0.2966813382602507, 0.3446440194402972, 1.9284372175893478, 2.205927501763067, 10.306250222267645, 10.377316705642208, 0.5793559539221949, 4.6874623048690065, 1.1237955814407719, 2.9641312168490503, 1.2798589684309498, 3.1199667386470304, 3.4339098151653045, 4.1709670520597895, 1.5207551323598432, 2.9590147301074, 0.5119618509084948, 2.147828374178179, 4.234199581607696, 13.632145562479574, 23.288106033878943, 35.17274448948522, 36.143366367586204, 45.36863588517713, 48.88944164399178, 53.454915785020404, 50.85378031576834, 57.5768090832618, 47.66581904503607, 33.79198781905636, 36.96289462427939, 53.66472336553759, 62.69838902258105, 51.897342589593705, 45.966334496774984, 53.68559429722448, 71.57783492918938, 50.31649797193466, 55.95179073272213, 50.79167350645989, 47.49959684187367, 42.11187624162243, 32.66671669098639, 16.964827583682155, 8.173612452322438, 3.9546990827206647, 1.6895045676539022, 1.9393883525363862, 2.093962464601763, 3.06870136049486, 2.605681496281778, 3.9324901325087396, 4.046644097374332, 3.862764119140564, 2.083477233686755, 3.153214219116396, 2.8212716310254993, 5.068404366893153, 5.246654518188969, 8.17107173704332, 3.032961458929124, 0.9219847331123968, 1.336398218427935, 1.5665159542714397, 6.147940168457647, 12.810718878622978, 14.495164079050864, 13.253664297442283, 14.594854058757907, 19.573968610455914, 29.75094633717691, 26.920528719502112, 21.100772773065877, 7.314354998450126, 0.9634023267895946, 0.033553858182483146, 0.012053390870982362, 0.0728621015385274, 0.016906131734891285, 0.019023407235621445, 0.07185061266946216, 0.025216588420012308, 0.06845150353206743, 0.062418518993522853, 0.007638326093118879, 0.0031637097098639296, 0.03257113591497464, 0.061875776342687115, 0.09605997933014747, 0.05282989440245494, 0.0456085542757665, 0.016259082382725134, 0.015710966582710467, 0.014007948338985445, 0.022592459572479132, 0.055529067307830825, 0.06965914155326544, 0.03251762084302402, 0.03376850835798729, 0.026633245870471004, 0.07676860602993159, 0.05071758698191374, 0.0382665936054001, 0.0653344220031173, 0.01599365494198977, 0.05062467200801738, 0.04251784149317011, 0.007405688173152627, 0.003997865743229106, 0.022912218926414367, 0.027699885409205195, 0.06793321440777472, 0.028713523154898037, 0.024475848429926464, 0.0818608997149333, 0.01858057585665055, 0.08789291515225366, 0.0421343723522319, 0.012012949089459594, 0.03651705563008305, 0.0465001235716045, 0.032635280456874645, 0.021966828123456048, 0.03866557602680499, 0.037780625730632775, 0.04698191243674486, 0.07707989053620447, 0.045339416096647905, 0.020239068112606486, 0.039840513584955085, 0.060004717670381076, 0.041740599328712116, 0.08207237828643092, 0.047320167068392045, 0.05065783978469911, 0.04035610224931471, 0.047354637194545045, 0.04979554270844787, 0.0347048593234391, 0.0736802911025382, 0.03165167144259378, 0.04257039512477575, 0.058558366651977264, 0.03359054996361656, 0.026553373543485522, 0.023748490080657988, 0.0869533159740029, 0.06822702444849477, 0.02245796709171226, 0.04339233851961551, 0.07193812289305272, 0.05992512113504833, 0.03321749195756932, 0.052090642538162014, 0.018880384365817713, 0.035527783310821945, 0.04217029804544103, 0.017382217075435386, 0.06391345913852416, 0.027256182605220426, 0.11477781324497155, 0.613081657117413, 6.683590316003369, 23.224398897540187, 37.93505407148792, 39.40537022006127, 35.95574763513381, 26.84879053023554, 19.919321537017822, 18.266293541077648, 18.657432294661, 21.292833589738418, 14.479915865005987, 5.582257903391316, 1.477578049225192, 0.05996411884083383, 0.3788727666101148, 0.1834015103597795, 0.6213034965818929, 1.1298486566351307, 9.29108786967493, 10.211383777280009, 2.879167285657698, 4.599301151690945, 4.689388188623614, 5.296853501950541, 3.702178852212045, 5.552428768527124, 5.316972319156894, 7.906924620751412, 3.4312671182617067, 3.0462759444790506, 1.057556432581717, 2.493560544906124, 6.5733295486819365, 17.549423517719394, 25.753215666740175, 36.89294307462631, 40.07975901326826, 48.31335921441355, 53.12571517882809, 57.60572871854229, 56.842831642396995, 61.92009664350941, 52.161522065439534, 38.26511367674797, 41.100948087630734, 52.933354300837365, 64.29416218111592, 54.33651162732033, 53.30892908957697, 58.78148663428522, 71.19423497107722, 55.4033806247096, 57.7885700041248, 52.30377858684909, 53.97878754523493, 45.73134922212171, 35.17104218083043, 19.61196461031514, 10.581310352971478, 5.544874283575243, 4.0847428143024445, 3.5638133220134245, 3.5305594676925294, 4.926287579920984, 3.819383440479156, 4.583307197017055, 5.165476164510173, 4.369749830615136, 5.8504038760739, 5.861089883312102, 4.656469696952451, 5.979292469639932, 4.394266115080926, 3.8543275911961836, 1.643982029730274, 0.40911181980083067, 0.30776200335352655, 1.1115156210237935, 5.0511851618366865, 12.265622192813504, 18.09006144923549, 17.528003454208374, 17.992359130613266, 19.673183002779563, 27.024234225673062, 32.407853987909135, 26.018154121214344, 10.441316058558803, 1.408573016524315, 0.07560610590923218, 0.022634987028375752, 0.02951281907547626, 0.09472691739398627, 0.02964517800137401, 0.023256558211400144, 0.037794572361294305, 0.06704400083230388, 0.02409283702652301, 0.055838045889451626, 0.013644667530071833, 0.06662773929776684, 0.04497845461892505, 0.053528670011268514, 0.07551779895420037, 0.1319486245272621, 0.06619870707753205, 0.0920878287645117, 0.043855821713805206, 0.01655691630026746, 0.05756480040990057, 0.032533819772182934, 0.017925143587372957, 0.03130078976673465, 0.013070166704335041, 0.026283093893359748, 0.01837979378779569, 0.08840644687053659, 0.09189393957175555, 0.020566101471382766, 0.018559941278410055, 0.04726353784902923, 0.027263144429232326, 0.06533612271830921, 0.038316186307178396, 0.02759898588391802, 0.05471614459829946, 0.1049226743259257, 0.06797493555613103, 0.06883801021162542, 0.15269321299368335, 0.1562286627989623, 0.21026544062600983, 0.11464203948215132, 0.10856315478562348, 0.13683837988684255, 0.08735375779290354, 0.20946210550685085, 0.12598466834113484, 0.10661854018126765, 0.1521330495034495, 0.17978608097520568, 0.16267633456135952, 0.10499713807216576, 0.14956043432316474, 0.22131307200799066, 0.1390198305729897, 0.15764309093356133, 0.18837119933337937, 0.206085205258381, 0.21696403682712587, 0.1827688596301502, 0.07271250754955315, 0.2240125053832608, 0.21680361801578155, 0.08353391316749396, 0.133986066005403, 0.11596940172415589, 0.17567588136561457, 0.09736261991483551, 0.14012528012596792, 0.14579762494371784, 0.16130500653338048, 0.13557885473053302, 0.19072511173304052, 0.1763261827610193, 0.19774333513792486, 0.11302163328735099, 0.08996055581636968, 0.19502202229153728, 0.14262349284704656, 0.1454379160197512, 0.14608132262383738, 0.13365373706385014, 0.17113221388670707, 0.20536560354934585, 0.5402559907205644, 6.520063271445613, 25.227782803197062, 44.806611230296475, 46.71636227638491, 50.84280944639637, 36.84949498022757, 36.39177399296915, 35.71455717086792, 32.949650979811146, 28.42846824276832, 18.892237140286355, 7.115688420111134, 2.197409829785747, 0.6216722606651245, 0.986389070749283, 0.8604320198778184, 4.36633687826895, 4.1458236786627, 21.413656319341353, 22.25302980792138, 6.424190248212507, 11.249091913623195, 6.107037692300736, 8.112620086439195, 5.9752210494010685, 10.3405297763886, 7.8047566836880105, 12.108336129496175, 4.587393816440336, 6.462576523903878, 1.0341702810218258, 3.217723725303527, 5.349165662642449, 14.77662551787592, 26.00001512035247, 38.017066909420876, 41.90711675151702, 50.11539413082985, 55.718786255005874, 61.078352082160215, 61.501485609239154, 67.06550890399565, 56.348816963934134, 41.81662767164169, 43.0784345442249, 56.307989012810495, 70.3234060349003, 59.26228684763755, 59.48960388860395, 63.09163408894693, 75.74818518853958, 58.80646820991271, 62.35054539095972, 54.07149276425762, 57.25593566894532, 47.26574120983001, 34.29802456209737, 18.46666389896024, 10.474970975229818, 5.575436411365386, 3.4086051342948793, 4.0214053613524285, 6.01029537377819, 8.80480908578442, 8.530078434175062, 10.199924572821587, 10.082923212359029, 9.215295910835266, 8.276034362854498, 10.528054371956857, 7.223298645788624, 13.846737454014441, 14.21416744109123, 16.44610001194862, 7.891422433237876, 2.468847651635447, 2.194412158381555, 2.3562123794709486, 8.090137550907752, 16.539305333168276, 21.59879807502993, 21.106189566273844, 23.656948074217766, 27.79675875940631, 38.0585067502914, 38.852084605924546, 31.446637953481368, 12.03503977867865, 1.9394019582579214, 0.1613529023504065, 0.20466090991131722, 0.2491344129967113, 0.22823816976479946, 0.14070027507841587, 0.1298385885574164, 0.14869670083205547, 0.18431937562361841, 0.19469163921331206, 0.1928810823348261, 0.09812596524434705, 0.16454689144607515, 0.11269799178285946, 0.1976500256287475, 0.1489208888022169, 0.20460277915962283, 0.1540548270267825, 0.1450365012691867, 0.11883009660748706, 0.1775760245659659, 0.1372563421365715, 0.11897478763374592, 0.12798780440202645, 0.1566014411829172, 0.14358514769663736, 0.2678694149419185, 0.08411267727252938, 0.20702925540747183, 0.15587578737928023, 0.12447316920565021, 0.07110944558535853, 0.17261940505235426, 0.08504463089329582, 0.10710265412325821, 0.1849515207352177, 0.17011478783622866, 0.1663189447454868, 0.18212795047269714, 0.14010525458762724, 0.19950136902832216], [0.04009210068972842, 0.04062955733388662, 0.028009651146168192, 0.0581756750902822, 0.04738797351057011, 0.09780374100251545, 0.052660466397121075, 0.07821527114438434, 0.052419673471200856, 0.01676520794600008, 0.07889341217495742, 0.019394655358947573, 0.020481188285855517, 0.0577363696309828, 0.08247612960516446, 0.02341436657814249, 0.010879764280792688, 0.047272562364777254, 0.037694092269145676, 0.056571709142336925, 0.007496331696353493, 0.0989286108843742, 0.021300385255486737, 0.03632448027811704, 0.11807536210624442, 0.0027426503102986085, 0.004339947941667971, 0.019171038124289726, 0.04762662522074196, 0.044693174967241865, 0.0680402905169514, 0.0910589880039615, 0.036742055653444225, 0.03379939702309428, 0.08053116260036346, 0.004945471976703454, 0.052751856856048114, 0.014678888143070284, 0.09502733877349286, 0.03452200562723222, 0.03818487883695672, 0.020150299589600296, 0.04021254886362342, 0.037827211537308274, 0.07528156808186924, 0.055202395925598766, 0.06579965187777435, 0.3404429771246449, 3.403061354352582, 13.773915709987765, 30.06486931154805, 38.16886655745968, 38.02905759503765, 32.424726063205355, 19.08500986714517, 16.090729351966612, 19.529761537428826, 19.5185298304404, 13.402138756167504, 6.170631079904496, 3.0499075689623436, 0.5763498249073182, 0.48568488188808967, 1.8084879507941587, 1.6670834417304687, 6.015220890122076, 10.897884849579105, 1.510271127185514, 6.2791537469433205, 3.016589976126148, 3.0550490608138428, 2.4491352900382015, 3.528434768799813, 3.796503519819629, 7.158280457219771, 2.5890224547155443, 3.612516902146801, 2.1415783224567293, 1.3341363591532553, 0.13999495324828934, 4.518544452805673, 6.387484217843702, 15.823303134210649, 18.71434980823148, 24.10621831493993, 30.151314427775723, 36.14696318103422, 44.98391805156585, 56.41616013742263, 43.391929980247255, 32.57709445491914, 27.00687969884565, 46.66203352712816, 63.56535050176806, 51.66439694743003, 55.745030833828835, 61.154834378150206, 51.53133838407455, 50.786186110588815, 51.144729968040224, 46.46021973702216, 35.953339299848004, 26.08915098251835, 14.425850895143325, 5.391965095073947, 2.075732023485245, 1.2440949197738402, 1.9557291918223905, 1.8750801129687218, 2.601672098521264, 2.0925457535251497, 1.7654331965792565, 3.9863231922349627, 3.083893680764783, 2.3813290317212386, 4.832914577376458, 4.201590957180146, 5.128787294510873, 3.0939209749621734, 2.9500013685995534, 0.9157318009003517, 1.1716385690435287, 0.20076447947611734, 1.4746676505573335, 5.845740668235287, 12.179516361605737, 15.249779070577315, 16.828162400953232, 17.790384523330196, 20.360388140524588, 26.222223274169433, 33.1916965207746, 23.77076937306312, 8.938240274306267, 1.1514987916715684, 0.03599556042782722, 0.04381686231241592, 0.05420890629231449, 0.016297559148722118, 0.03995974367905048, 0.05818682166958048, 0.03037782235732002, 0.07697715814555846, 0.05834282015360171, 0.04784759562162142, 0.013535394663772276, 0.02201826135147243, 0.02289607936906959, 0.0660388934756479, 0.04300875446548866, 0.014984299627793653, 0.0723928343805094, 0.010180089476277993, 0.08503566766458173, 0.03136331211745499, 0.02998417956874736, 0.022201879220383785, 0.023887102199237675, 0.03281235018925321, 0.05371497110313466, 0.011449786365002153, 0.04209692597449307, 0.046762252046215924, 0.07405555161136775, 0.0838201695812806, 0.08079051400624937, 0.03019276998877045, 0.04665421832713389, 0.01882667777188603, 0.04043312472922187, 0.06664337515230141, 0.13219452342919766, 0.05332792433159006, 0.05064525296010318, 0.01612995826308766, 0.04365396137619692, 0.04161782607796692, 0.010714217468405203, 0.045879787705358, 0.03320517326374689, 0.05964783178041539, 0.024983670877953692, 0.020996319212680383, 0.024950734842869065, 0.013906407215061688, 0.036330677929424474, 0.044162283696594744, 0.02139515033172023, 0.022598678291204478, 0.10310068741560945, 0.02512034287886514, 0.10251250808998462, 0.009356006780909676, 0.023950256572495547, 0.0595100776803109, 0.04550291075100822, 0.03499335654440426, 0.06547578820778478, 0.016402756427264503, 0.04898685263469816, 0.033378129103972067, 0.04240787340207927, 0.047457074641340205, 0.0712749895249163, 0.034466111852276715, 0.029572656288021998, 0.03178090089932084, 0.044180995394145293, 0.058841168009225404, 0.07966483973207013, 0.07441465532587421, 0.020648902169458812, 0.03705940757607741, 0.03373936254290804, 0.0048012372515645, 0.044780712003909776, 0.06044371286407114, 0.05116346930604308, 0.02015025170910503, 0.03967438358813524, 0.12633314641613153, 0.02493711954523479, 0.041813538559982856, 0.37860273593856447, 5.878553255911797, 18.823458379314793, 36.63434513153569, 47.28771040516515, 39.53264720978276, 30.37796270462775, 20.210673232232374, 17.56603083302898, 21.97357858380964, 29.43341870461741, 21.83725856965588, 10.290045930493264, 3.628191919096055, 0.8518860945778509, 0.17366724479342663, 0.47598752643792863, 0.6229660299516494, 5.445426510226342, 4.749797592239996, 1.9819317277400725, 4.094695583466561, 3.4884552753740743, 4.747433873914904, 4.38096143545643, 5.115684616950251, 6.5223534453299745, 6.426575049277275, 5.385390712368873, 5.661758953525174, 2.17524794801589, 2.4308756762935273, 1.871480112594943, 4.59119116106341, 9.546555761368046, 20.35897412607747, 23.50438552518045, 29.44382279149948, 35.06468319123791, 44.56545606736214, 52.11972921125351, 63.57642727513468, 49.91611811422533, 36.283175330008234, 33.4945741007405, 51.12459644194573, 65.4264170892777, 56.80951895252351, 64.06822189208, 62.52392199731643, 59.1179750042577, 56.4186155411505, 54.91473174864247, 49.511309900591456, 42.546392486941436, 30.379698353428996, 17.99330638300988, 8.415358912560249, 4.562480391994599, 2.545736893530815, 4.496318832520516, 2.748791623500086, 3.60519947544221, 3.616066892300883, 4.965871159107455, 3.981380025225301, 2.6880316580495527, 5.32355748837994, 5.392117086918124, 7.785453229181229, 6.657283469553917, 3.417521417140961, 2.7402786093373455, 0.6014834536660103, 0.8110750586755815, 0.3923641878270334, 1.274606669622083, 6.975246975498815, 15.171139470992552, 21.95434916403986, 19.237772457061276, 18.848985164396225, 21.098803743239372, 28.436664035243375, 37.05407404130505, 28.139789642826205, 12.522208940598274, 1.920554847005875, 0.018739010500270995, 0.08800762149715617, 0.05883834497522443, 0.0484056830135805, 0.03959965554156131, 0.0034342589271780587, 0.08254521541417607, 0.0380013203398595, 0.05823279460591655, 0.06060141589372389, 0.055911414129959966, 0.06757788750673495, 0.013467111331861348, 0.009240716293964897, 0.06703571942184242, 0.008670852215389812, 0.08397473548088344, 0.06947548729517768, 0.10165693343526895, 0.03588067022182288, 0.07113623568007062, 0.055024230687488476, 0.07136212436542397, 0.02005140338423512, 0.024443029223250288, 0.05917374592935366, 0.03545614259858285, 0.021201856772325212, 0.0896175399482731, 0.06063994628587558, 0.1045956390519296, 0.02995721135859288, 0.03799187830619274, 0.04231703835689733, 0.09197436348204652, 0.042875443675344994, 0.09590077859860274, 0.035193033531428344, 0.10439209715132752, 0.036176927913461006, 0.042837392088145985, 0.13936728209016785, 0.13626215919371576, 0.1672131991794994, 0.14393722638487816, 0.2487481208217721, 0.24384785473587053, 0.20280371360000105, 0.16148554281361643, 0.140982318008619, 0.11681573735850474, 0.11962597003026355, 0.09235708568725856, 0.12927108594486791, 0.22615586617781272, 0.18581577516611547, 0.1785074495860646, 0.12769947955084424, 0.17396013552863754, 0.1533800108178008, 0.24313511717463696, 0.10773192640514144, 0.14582627663208594, 0.09075005538761617, 0.08490519523019753, 0.16173331097008722, 0.1409235284213097, 0.14117099014261078, 0.2083962473777994, 0.15938480715117148, 0.13907227695228594, 0.14530276278814963, 0.1482706946591216, 0.0907259159571221, 0.19547979046981181, 0.1619982241743034, 0.13868459049732457, 0.11837831923678038, 0.20334521518839946, 0.21292399554964037, 0.22099324562136205, 0.1186571982238562, 0.17273886880326658, 0.10810356331808914, 0.13827387543935932, 0.3170466825606362, 0.08644045075221408, 0.15254799336675676, 0.6837605000022919, 5.583776350944273, 20.58103322982788, 42.28280136662145, 56.22887088406471, 50.075950776377034, 43.621647511759114, 30.408270858949233, 27.856880849407567, 29.147725028376428, 28.87961337643285, 19.245409311786776, 9.127742725033915, 3.720100651825628, 1.1948931986285796, 1.0850564150079605, 3.6602416057740492, 3.3453672114879858, 9.146855454291067, 17.541894528173632, 5.863018218548068, 12.131649717207878, 9.788158074502023, 8.52550102818397, 7.524239065185671, 8.511053958246785, 10.455390503329616, 12.387616730505421, 8.355669263870485, 10.334630531649436, 5.568384970388105, 3.3832541204267934, 1.8355232549290506, 6.778575902984989, 7.575925607835093, 17.89831049980656, 22.549280543481153, 29.18248703402858, 36.59510966270201, 46.622456812089496, 52.73623166545745, 63.48105092202464, 53.699491254745, 40.6232661585654, 39.11450685993318, 52.67752947345857, 72.02091370859455, 57.910704766550374, 65.2314478351224, 67.14811401982462, 60.61921904163977, 59.31925927439044, 56.096471278898186, 53.26006027960008, 42.23323829712407, 29.445519216599006, 15.662971350454516, 7.148595634968051, 3.458614863695637, 2.7526992847842555, 5.456053681911961, 4.33553058293558, 6.6636391801218835, 7.576455127808356, 7.977229183720005, 12.495889836742032, 8.031280915583334, 9.633118548700887, 10.630839101729855, 10.320826730420514, 12.38548296113168, 11.013761470394751, 6.510145558464912, 3.7196147682205325, 3.4799228945086083, 0.630432200287619, 2.612606440821002, 8.453046025768403, 16.46695133178465, 23.595384513178182, 24.093458844769387, 28.117514502617624, 28.46815870654199, 36.320080910959554, 44.762202155205514, 32.92757195811118, 13.242449260527088, 2.4964371131312464, 0.1153479052347041, 0.20562074147164824, 0.1676181072909986, 0.11059822139119911, 0.2153426883441787, 0.20539001111061345, 0.14280367672683733, 0.2222706512698243, 0.1796488133409331, 0.1492329777008103, 0.13809433507342495, 0.16458472086777612, 0.1653201346315684, 0.1831175522097657, 0.21676584988111453, 0.11288421243549356, 0.2224402478145015, 0.20887615549708569, 0.19818071005565507, 0.15645732472260154, 0.15675896418190774, 0.14911418810727137, 0.06869428445615115, 0.07959835096112183, 0.13860422787406754, 0.17611607548690614, 0.10355700002682787, 0.15735924003585694, 0.2194104007174892, 0.1827067758647665, 0.14160700142383575, 0.1310388185083866, 0.19265697097345708, 0.1053521738597943, 0.11302466699553114, 0.1251959501795711, 0.20243638976206704, 0.24050751220314737, 0.18911937612199015, 0.16437416926266687, 0.11286269302570051], [0.05580291309724412, 0.01282536426574112, 0.03328141433397128, 0.027550134372206467, 0.012001275824713371, 0.08053189038389152, 0.07119104161017364, 0.03406024996131178, 0.021522070033355586, 0.04726437288486669, 0.029902137297716354, 0.05233359200158908, 0.05486965712700641, 0.06843051272294215, 0.0872368834191753, 0.028494864424330094, 0.08345842286343537, 0.022422330596694545, 0.03408558065852812, 0.05837200044263756, 0.04210151484115951, 0.030434683318279927, 0.010475329228586728, 0.07422675694068594, 0.028817584708092675, 0.0035608118642196664, 0.11524361002469256, 0.09014499914501944, 0.03866048154210852, 0.05250834814843632, 0.04410085110594669, 0.05984587316972114, 0.005466985373547482, 0.09101010393351318, 0.024648857896306345, 0.04109799711694641, 0.015960786897208423, 0.036811106988499244, 0.03700812181998645, 0.03134348001631518, 0.03848276829587356, 0.08000597868475222, 0.02547632286986036, 0.0330322518974783, 0.0024409438182990397, 0.02923132389813902, 0.024122871503594424, 0.06482375545367118, 0.07752463521976626, 2.285408449749793, 10.544763668890923, 27.662739215358613, 40.75466163696782, 36.65559261075912, 29.969802825681626, 27.083093312478837, 18.452410005754043, 13.53624459235899, 13.934466165881004, 12.912836805466684, 5.832581606603438, 4.064218522079529, 0.6566736534718545, 0.2618076676322568, 0.22700142806335805, 5.16527122066867, 4.184738493734791, 0.9821427986025811, 1.352445737969491, 3.244777047826398, 4.405786116277018, 2.563186782983042, 3.4538714924166283, 3.8883759706251086, 3.473979768253142, 3.9199520311047955, 2.0505008870555512, 1.83926924101768, 1.6291407615907731, 0.4536934485358577, 0.291033860656523, 1.157672602322794, 4.081498523873668, 4.524736404418945, 6.5114973052855465, 13.054033306337173, 22.28687397895321, 29.992028936263058, 40.210746565172755, 38.65356952913346, 27.90156056804042, 25.869004034226943, 33.7376747592803, 53.38148901539465, 56.97556857139834, 56.676793790632686, 43.78770105300411, 34.40192030322167, 44.24549264292563, 40.5873215583063, 32.07063017352935, 20.607450392938432, 8.5656072631959, 3.7275681091893107, 2.071799111943091, 1.186706108912345, 1.0822538815198408, 2.7080095150778374, 2.8388423785086605, 1.9673416138656679, 3.697923080575082, 3.321388536883939, 1.4687954946871729, 3.077539441085631, 4.158913118223991, 7.331312875593863, 5.185826401556692, 2.817167115788306, 2.5148470026831475, 1.57361090904282, 0.7024626674190645, 0.6225530166299112, 2.4274227648012103, 7.015940095147779, 11.580953847977424, 14.313243569866305, 15.338318732477005, 16.181563600417107, 15.973128849460235, 24.12218236154126, 30.893768110582908, 25.077703114478822, 11.047342842625035, 2.050102766483061, 0.03357097258671157, 0.0699010874415117, 0.08042281478523247, 0.05589470192189178, 0.01895906542608094, 0.03667270171365911, 0.06260609179134331, 0.07835083806346502, 0.04158181611508612, 0.003729220972614243, 0.01831565882199474, 0.04470648574492624, 0.02889751449167248, 0.04081840566810101, 0.05446981668712632, 0.026995404360575542, 0.0292699960165567, 0.044163463471998135, 0.07203868725487302, 0.017236713995976795, 0.09278722873498356, 0.027103116322729378, 0.05106828288145123, 0.08236493194295515, 0.05988812674918483, 0.032222550587668534, 0.03143904756964936, 0.05813265925333385, 0.037696003658516754, 0.1150513832427321, 0.0915387046012667, 0.07752433644547578, 0.05814905736535307, 0.06056164826957449, 0.030653548892587427, 0.05399475790440075, 0.013242516377490136, 0.0640353667099149, 0.01296945870102894, 0.02319544546246048, 0.021407105133778626, 0.009553633525126405, 0.05049719880785673, 0.013042667978292993, 0.022104946115324577, 0.03350388626718233, 0.03513273475090823, 0.09961752311116266, 0.05082785767773467, 0.039756332013395526, 0.03133185463206422, 0.06868288506783786, 0.04883520936052646, 0.03321786734065221, 0.08423326717269036, 0.0668896034720444, 0.05376709189506308, 0.07711371331806145, 0.07724793958327464, 0.0697918586252678, 0.03326182163530781, 0.07638541651108573, 0.055979186098181435, 0.014105422493641176, 0.09715460406075563, 0.017486341830883777, 0.03339561506084377, 0.02252624467796376, 0.029782367111634345, 0.06716370973135195, 0.0569037163269616, 0.06170753577363588, 0.033883383242233146, 0.04341331783742194, 0.04185683401902357, 0.030766975870656393, 0.02135799889783225, 0.022202153096816713, 0.06571498384038288, 0.05415785802348007, 0.09690270669037297, 0.01680808588712206, 0.04334418223269525, 0.015436948423514204, 0.04138099382661524, 0.02663186882742711, 0.08146947475090142, 0.015859361644083216, 0.07888159909916502, 0.03655700711533427, 0.17648134620920305, 3.816264911044029, 16.539766211663526, 33.51328380646245, 48.48064045752249, 43.21676085072179, 31.713186540911277, 23.919515455922774, 16.16740188290996, 19.185628467990508, 18.881036812259307, 19.170448895423643, 11.342899318664305, 4.427572431102876, 0.8269439265131951, 0.12453366716903065, 0.10695859128909727, 0.4607324788887655, 1.486623892861028, 1.1793943206148765, 2.249586423558574, 2.5767098895965086, 5.200460764669604, 4.244726732853921, 5.787793042198305, 7.090864229586817, 7.380249836752492, 4.887053581976122, 4.381282579514289, 3.967148195351324, 5.140896631825355, 2.859574066054437, 1.3524627757649268, 0.805551809889655, 5.292965942813504, 7.023932904966417, 10.196049271091338, 15.774986397835518, 25.87308329920615, 34.87719781937138, 46.64665391368251, 44.916288545054776, 31.507271912790117, 30.44603740015338, 37.41414762312366, 60.78749264440229, 60.32686518084619, 61.60250625302715, 51.92778410450105, 45.37016560954433, 50.809594815777196, 46.59215650250835, 37.37368053005588, 23.637277387803604, 11.989188251956818, 5.818043341559749, 3.9458994903872093, 2.462145791899774, 1.2883344749289176, 4.798300150902041, 3.003108789843898, 3.6413781921709742, 4.191253060294736, 4.2953110894849225, 2.8790282866647168, 3.6635918001974788, 3.481075335894862, 4.335746313295057, 5.480632234004236, 4.410006096286159, 2.4881290428100096, 1.5309546431226115, 0.49085903972868, 0.6489013544013423, 2.383358858285412, 6.452238136722196, 14.780668500931034, 16.539950563061623, 16.188890587898992, 18.11836527239892, 18.016020828677764, 26.34155942547706, 34.33117251242361, 28.990161457369407, 13.542130108802551, 2.8197860333227345, 0.10474873406271781, 0.046542618468764334, 0.03979245688946497, 0.020034179812477484, 0.032148580968139634, 0.02209145913741762, 0.11757107706920755, 0.018624158598662868, 0.08113513099810771, 0.06701414638589467, 0.06772836249682211, 0.0466064335928569, 0.05420331385046725, 0.028639913596693548, 0.007597743542940026, 0.029039964710752812, 0.04802515948071115, 0.027588415785782763, 0.016784371635425958, 0.04832454281108034, 0.025805989655876355, 0.020307541051278674, 0.03388217282331279, 0.07358351121506385, 0.03910773516362233, 0.08662395945359623, 0.01524748530374059, 0.04538806267983971, 0.04494645895676748, 0.02153551679164652, 0.029061049365648822, 0.020889022853225473, 0.04852023614089816, 0.09025220548914326, 0.13356405881143388, 0.03924581102065502, 0.053527884771146124, 0.03883297772957914, 0.03815304788370286, 0.11161301209921799, 0.04352724277264169, 0.025929101900528037, 0.11006540723986204, 0.07672835577038989, 0.16712327577894734, 0.13328652047822553, 0.17015453247774034, 0.19576508161281386, 0.25867718722551103, 0.273459650455944, 0.09236185075414759, 0.14756511235910078, 0.0951098541038171, 0.1377893248272519, 0.19219396275378045, 0.22608935442422667, 0.14464539806208304, 0.17649392537291975, 0.1965234626925761, 0.1427117308541652, 0.09315492029512122, 0.20678599184799581, 0.13566870152229263, 0.15997008300356327, 0.19222057664826994, 0.14348952460192865, 0.17956773059502726, 0.13240000353224818, 0.189075892971408, 0.19046798198213502, 0.1741330875384231, 0.12838238564830634, 0.21700632488054616, 0.1462480539996778, 0.14101878379381474, 0.16201864807836472, 0.16375953692101664, 0.16585262702597728, 0.06922624058901303, 0.1595675804081463, 0.19613335539977397, 0.11718810205498051, 0.13839865584046612, 0.21045996567174313, 0.2756635628400311, 0.06625468512215922, 0.11552011413920311, 0.10088020454972021, 0.2189489553171781, 0.21396546143918269, 0.32056722429490864, 3.796425562712454, 16.996051611438876, 36.68260205176569, 55.68017444302959, 51.02425436819754, 41.03634665089269, 37.92405574552475, 28.53725321831242, 21.244129519308768, 20.097452056023386, 19.86871119468443, 10.121024135620365, 6.047361771906576, 1.086459275214903, 0.5557520495307061, 0.5026370593376699, 7.454413031378101, 7.088504923928169, 4.794323848139856, 5.8219073664757515, 8.464364024900622, 8.701746848321731, 9.116358045608767, 11.679588710108112, 10.767369943280375, 13.967629805687936, 8.96322577230392, 6.765198169216034, 5.437237091602818, 5.010649917587157, 3.6318698765770083, 1.9938999823024197, 1.6839866508399288, 4.945102209045041, 5.486218179425886, 8.344096310677068, 15.711899976576529, 25.635534755645264, 36.29172217461371, 47.210879018229825, 47.92759803033645, 38.81429256931428, 37.71491889030703, 43.301613484659505, 66.33519495687177, 61.91044761288551, 64.35081297351469, 54.53286940051664, 50.81208159846645, 55.16828160132132, 49.80294989001367, 38.101609676114975, 23.337926018622614, 10.893487872615939, 5.186172060428127, 4.016971367020761, 2.961962881588167, 3.2867089010054067, 7.291575343378129, 7.651239527810005, 7.018338624508151, 9.100357717083348, 10.50736092752026, 6.599009796496361, 8.308637103726788, 9.329843828755042, 15.14029493255, 12.663339741768377, 7.41742164857926, 5.1664807815705585, 4.305634277482187, 1.7417370552016844, 1.347420201186211, 3.3242763819233065, 9.564071105372522, 15.2768640172097, 21.147829448023153, 23.76454261041457, 25.352365124610163, 24.27816717855392, 34.04560827439831, 42.915311013498616, 35.392734542969734, 16.06742753136543, 3.3494153426539515, 0.1466546628263689, 0.15616106320052378, 0.14332139894606608, 0.14161414136329006, 0.16764913385193195, 0.1814902282410091, 0.16053046099841595, 0.26429487933074275, 0.1536495971583551, 0.15765764660412268, 0.12012154464760136, 0.15552344822114514, 0.11870121763598536, 0.13530320097361842, 0.1270953809181529, 0.13915116868672833, 0.12469364931025814, 0.0794061471617991, 0.18455433478999525, 0.11887650621393997, 0.31255042060248317, 0.16478261670037625, 0.12614124905197852, 0.11163040229509916, 0.1339941712156419, 0.23606832379535322, 0.2814774040973956, 0.1242123852153459, 0.20481561370674642, 0.34253740022259377, 0.25638566502640325, 0.10906830550201478, 0.12625316683683666, 0.25339554724914415, 0.17437799052605707, 0.12275361591168951, 0.15948694199323654, 0.15036995943275192, 0.1603471821234111, 0.19480877405693456, 0.1192519965491468, 0.16492680976948432], [0.00987549004475436, 0.010753693021533471, 0.005431232050121312, 0.1526266246313049, 0.028928018197597518, 0.060420688091506886, 0.06431968492125312, 0.02648629488483552, 0.05906368207727229, 0.013766994534601128, 0.13633861476855894, 0.01772084134450603, 0.034592252059449116, 0.023076470092599912, 0.016446930972198327, 0.04376049356294736, 0.06390690908677156, 0.013182918567420735, 0.021010384586970174, 0.05690473139346127, 0.030167025604075005, 0.06291287553106105, 0.0372985304303227, 0.028180371924874284, 0.0896361175804369, 0.04063800728369144, 0.06832507604192342, 0.05492201157575173, 0.05647763354523529, 0.06647226175353413, 0.013515803880328614, 0.026034442820556225, 0.013974126514738366, 0.010726797589731794, 0.018533834917170387, 0.10410951795957743, 0.16839484383742656, 0.023360022216013843, 0.013406795314362934, 0.08144232459486493, 0.030634992327841542, 0.049495596303454334, 0.03542266838673142, 0.03720671096215806, 0.03994101282930182, 0.03775007414421247, 0.08544516464274737, 0.04047950752259743, 0.08029031987872817, 0.05375290777714503, 0.47696104032858727, 7.843763184162879, 26.204317654332808, 37.98775111475299, 36.3032421758098, 30.192216903932636, 23.55949874847166, 23.51467194095735, 30.67502929318336, 21.81188867938134, 21.455415833380915, 12.925815928366877, 7.470366781757725, 2.8627413799685817, 0.9681072710983216, 2.3944228839489723, 1.3696468020639112, 1.0302808832737709, 1.8617858521399961, 1.177887149876164, 5.3015348507512, 3.273580973186801, 3.5946446224566433, 6.469483817777326, 3.8956985454405513, 4.229751613832289, 3.4809716382334313, 2.313402650817748, 5.61088090942752, 2.2107208832617733, 0.5909759142706471, 0.1672695985724849, 1.0607086698855124, 1.7178234674276847, 2.082297580857431, 1.8744884479430415, 4.770300801723234, 8.586430145848183, 13.74831832224323, 20.57811890878985, 21.85785101306054, 19.18039014262538, 25.45012627878497, 33.29743185350972, 40.75043332192206, 41.57005179312922, 30.39260687366609, 28.88706195739008, 25.461895350487005, 18.875217976108676, 13.468989672199374, 5.40819880462462, 2.8878474908490337, 1.7946714018621754, 1.5064835884878713, 3.3087379124856766, 1.5797252712711212, 3.864532617792007, 2.6324452988563047, 4.407553634335918, 1.545316156360411, 3.013517534540546, 3.2236109577840377, 0.9427431418049721, 2.572347968816757, 2.319012865904839, 5.532996856397198, 5.37379079288052, 0.9375344793642721, 1.076597823731361, 1.0284702191429755, 1.8283204349779316, 10.72037112328314, 17.33603677441997, 21.91668068209002, 21.099552915942287, 27.11030475554928, 21.777385550160563, 24.289840152186734, 31.350800721876084, 25.455001784909157, 12.931231740982303, 3.2558548017855617, 0.32558574371280213, 0.023013275499726017, 0.05378852703518445, 0.06323711841457313, 0.008753929662728503, 0.07980157876567495, 0.005580255303591971, 0.052290468912331335, 0.08429653071347745, 0.03389256863644527, 0.12974088170355366, 0.048281408230503725, 0.015286126778641296, 0.0882209080361551, 0.03933657328748415, 0.04147623387736179, 0.02205900956816491, 0.06085322133355564, 0.03896480997002894, 0.06173400794185939, 0.08497218195829662, 0.08687502178814142, 0.03200089262287704, 0.08367229929013599, 0.033107064213723905, 0.07368201480036782, 0.04165209702125961, 0.03320751366235557, 0.027585575514803493, 0.05675557407460386, 0.04751240151123174, 0.023454314232954097, 0.024413389281459877, 0.04208697832279629, 0.010389754334614884, 0.04552956294989394, 0.11204593604610813, 0.03713314353878941, 0.03462939583245785, 0.032162922134082166, 0.020389952959733147, 0.05438701024339084, 0.08110369841057448, 0.012485786217204746, 0.06356913709051668, 0.04881413811216912, 0.06905113587216025, 0.026646845846346794, 0.034957415529436646, 0.0757858684406646, 0.1015700514037763, 0.04269348247156989, 0.02943281651354365, 0.06374948567921115, 0.047814558079886826, 0.06438775949420468, 0.028469763553491043, 0.049216112106918335, 0.04016352689734871, 0.046566665968707496, 0.012383712662173616, 0.033618833929780996, 0.016120286403043617, 0.14280641932160626, 0.06559105379687202, 0.016418135642344435, 0.018612249761879928, 0.030843538697808984, 0.03404056533209739, 0.035229732973441, 0.02984017419118074, 0.05640629160728666, 0.014811971979666383, 0.06352164730009052, 0.06708579858945263, 0.02927428227849305, 0.05711507615483096, 0.02944409907344849, 0.09550143994631306, 0.08318037125131778, 0.05249108818750228, 0.030683669554550323, 0.027561976176296032, 0.029732738020679647, 0.03771723961577781, 0.032362947691111796, 0.05231461217326503, 0.007970008169180684, 0.02709050460027591, 0.0557683855144968, 0.04331415541650307, 0.028583058381393075, 0.21813716258733504, 1.0587136543566182, 11.849002741998243, 31.80759995214401, 42.756247135900686, 40.038279948696015, 33.668805783794774, 23.096982663677586, 15.40275444907527, 21.028414849312078, 19.875310582499353, 22.888494960723385, 17.537550503207793, 9.783683630727953, 3.1585969367334923, 0.5431358684455195, 0.5028005118571943, 0.09841436670432169, 0.4893550252722156, 0.5136594711051834, 1.060632428815288, 2.9078858994668533, 2.9083423652956566, 4.2616895129603725, 4.726021164847959, 6.274658220429575, 6.035976111888886, 6.255285143852235, 5.6803147062178585, 6.524318062490033, 4.7299592245009645, 3.405011998068902, 2.796123109517559, 3.134849927117748, 3.911584880082838, 4.300207188052516, 3.8856430592075473, 6.797720501499792, 12.85278629872107, 17.693760856505364, 26.008291321416056, 25.809162393693004, 23.7283234442434, 31.226339993938325, 42.51036943927888, 45.76883531385853, 48.44173839015346, 35.268932773220925, 32.248170375823975, 30.455133376582978, 23.864772896612845, 15.769046948802089, 8.321135736280873, 4.2293956587391515, 2.0760543932837825, 1.9002537621605782, 3.191379861485574, 4.334292094553671, 4.571796511450122, 6.258927554853502, 5.382733306577129, 4.8711670021856985, 6.056491578778913, 3.954772136865124, 3.303756747514971, 3.387028175976969, 3.8726131906432495, 5.054608410404575, 1.3103843240007278, 0.11370788718904219, 0.4040425853623498, 1.1239778490797168, 3.165163474698221, 10.034279938667051, 19.250243633024155, 20.98405872621844, 22.16024418031016, 24.380329232062063, 21.309117309508785, 26.52567352018049, 34.28454729818529, 29.0503070815917, 16.725190378004505, 4.6097591711628825, 0.4533567988584119, 0.036100338273231065, 0.035123637456807404, 0.04111518046908802, 0.03411080793387467, 0.046726835801476435, 0.008342706113903513, 0.07753254124714483, 0.057154376465346546, 0.0471063940635612, 0.04552230043637176, 0.007116998472596489, 0.015771790133458714, 0.03001597030238519, 0.031389219295834346, 0.07214913415091653, 0.04774475214822639, 0.041930600625252536, 0.022672341475563667, 0.046205382734056444, 0.04752796075697388, 0.19280819672971003, 0.016372059284138585, 0.018157381226398775, 0.026966185767143488, 0.08295833598822355, 0.040554955691820195, 0.02384985308913935, 0.08780255508158477, 0.03820338752120733, 0.03574690743980389, 0.056232650118369254, 0.05757233871507549, 0.03758279884594583, 0.016800844441017797, 0.036494260683896086, 0.08383414302501949, 0.06725752485855933, 0.032608551649196495, 0.06579012940487554, 0.1267811469733715, 0.017403648385117133, 0.010353359412552129, 0.09659402688304264, 0.10938970236888818, 0.1547426207652015, 0.26723650374239494, 0.15003974489387006, 0.1480396578629171, 0.17945977348473766, 0.13386062676868132, 0.23689174573988686, 0.07554652725136088, 0.2236645635698111, 0.11445987143463666, 0.21808116156007015, 0.15447101195252713, 0.209939991154017, 0.22291807217463372, 0.19615454539175958, 0.18799685813005895, 0.14219779310928238, 0.1947251478991201, 0.26812712691964646, 0.09305141415567168, 0.15936881123531252, 0.12790304443408407, 0.16252137029603606, 0.16475068615569224, 0.11050136489493233, 0.2013558533883864, 0.19543342682863438, 0.10749749583943237, 0.17623711737894243, 0.17600799580254864, 0.14418971364296254, 0.08187645129979619, 0.14384385558866686, 0.2662574433751645, 0.2523131262991698, 0.1859848201274872, 0.12695943095511006, 0.13486268509539867, 0.1515738512840002, 0.13007927806146685, 0.10335981665599732, 0.14419067891374712, 0.08036303694450087, 0.11945326316861377, 0.13792832382023335, 0.15702364755974663, 0.22816421163658943, 0.27943210255715156, 1.827068953744827, 13.329201302220746, 35.42042647638629, 51.75522335114018, 48.776383246144945, 42.372141192036295, 33.16664042011384, 32.504687501538186, 41.6167672218815, 31.089441430184152, 28.304486043991584, 18.91138222909743, 10.384491701279918, 3.741464086117283, 1.1779321345590776, 3.108053274693028, 2.747191051321645, 3.013547197464974, 5.239630043506622, 5.014776741304706, 11.229332973880153, 10.12435422789666, 10.98022226364382, 14.727506656800548, 10.733080583233988, 12.145194642005428, 8.381439235902603, 9.03363427808208, 12.215632565559881, 7.299236222620934, 2.570753770489847, 2.49385227118769, 2.9475312559835376, 3.0598917170878384, 3.817198680293176, 2.66735365794551, 6.800289163666387, 11.260515816750067, 17.165682354281028, 26.747654176527455, 27.550641798203994, 26.405654876462876, 32.344572428734075, 42.91732318939702, 48.97656140788909, 51.73103801665768, 38.61090590876918, 35.80244571931901, 29.889872766310173, 22.357421728872485, 15.680472966163391, 7.074197098132103, 4.5942957170547984, 3.325568312598813, 4.93246776442374, 7.845242898310385, 6.233212496003797, 8.00778199588099, 6.5152735671689435, 13.315395539806737, 4.799933327782539, 9.447212911421254, 9.139437271702676, 5.737418532371522, 10.161745202156807, 6.443680505598746, 12.714868899314636, 10.858826867995724, 3.7820966541767125, 1.8757064664556136, 1.7892625759686194, 3.153878570564332, 13.811113507516923, 22.219883818780225, 29.917205802855957, 31.285489336136852, 34.74672017558929, 28.810985626712924, 34.0950301385695, 44.23352156915973, 34.9313892856721, 18.477287638571955, 5.138492218909725, 0.48569545390144475, 0.13137428841042903, 0.13017980411889093, 0.13519076990985102, 0.14389927438910932, 0.16957166214143077, 0.13986409010906375, 0.11858760679681456, 0.16748748929990878, 0.1207883705595328, 0.3180652730647595, 0.0902413500232562, 0.11544078573464386, 0.16343819368029797, 0.14234338045841263, 0.17508030929152044, 0.11967106962636595, 0.15043435678366693, 0.11349797909778934, 0.2595167889470055, 0.16644058418610405, 0.2827957188410144, 0.12898639235044682, 0.15891847410990348, 0.12096618722763755, 0.21754211145302943, 0.09388296429308192, 0.15324720181524754, 0.14533504573327882, 0.12289316648797644, 0.2588142556769233, 0.1883110154660479, 0.16220664605498314, 0.18334917123279265, 0.0575470156787384, 0.1725299413045568, 0.24858761007987687, 0.1495492800829872, 0.08700053763365553, 0.14827274777475866, 0.2472500665293586, 0.10653626233819993, 0.21439100795936203], [0.05059411659115746, 0.061195743074941064, 0.04963685908625203, 0.06361391492969086, 0.05932062796707596, 0.014510139083159308, 0.10103129241014681, 0.015205557311644718, 0.07021401137594255, 0.04878530256269921, 0.04304184180293833, 0.04013924191014902, 0.040143968672641826, 0.05595876219412012, 0.08577173260310966, 0.04740517984534945, 0.001450308700441383, 0.02245058391934201, 0.07286757140630677, 0.051072136303710367, 0.07784466845013442, 0.022483569750141714, 0.04411997266053673, 0.022209429016877568, 0.040299415573357575, 0.0435407220896694, 0.048095455708643126, 0.030716291493585998, 0.019661924283530925, 0.07045263244259743, 0.008295617562027709, 0.028388397355053215, 0.025230596337707776, 0.024771880125626925, 0.05764779071473788, 0.10497908137979046, 0.019668093206541195, 0.09951855987310411, 0.0185389734519225, 0.033287248093514674, 0.02653343610525612, 0.042479920140918226, 0.009238767557807509, 0.026052556969525836, 0.04567320443569653, 0.06676867649319672, 0.046060232055043025, 0.0061937346829161535, 0.06959755574503253, 0.027068425946298148, 0.020634503546921958, 0.9701100700805265, 5.424328571365726, 20.11319841108015, 36.70508899996358, 39.96056995084209, 29.218484586285008, 28.373637430129516, 21.449459714274255, 22.1406715531503, 16.05927880733244, 15.724198568251827, 11.728416335198188, 7.909527603657016, 4.0188950444421465, 1.1813124822032068, 0.36498389897807954, 0.1975852758773873, 0.23347655641696147, 0.5574072284563896, 2.287228184361612, 1.5787634325604287, 3.760196590615857, 3.44684652743801, 4.647474231258516, 3.823040315220433, 5.632324507159572, 4.079585387822121, 6.401122298932846, 3.176671708783796, 3.486727716461305, 2.3688585912027667, 1.5713615523230646, 1.3167705555115978, 0.8020160383274479, 0.6950948627725725, 0.9879673957344025, 1.3417876776187652, 2.212548952910208, 5.347518267170076, 6.696864106962758, 8.508629933480295, 9.432779569779674, 15.86031363856408, 17.527032667590728, 20.282478101791877, 16.268041076198703, 14.81244852465968, 8.756307017418647, 3.7201965047467143, 1.5184069809413727, 1.0170639666818804, 0.29658671107984363, 1.114186387388937, 1.2360014766454697, 2.039410998263667, 2.6269005383214643, 4.913794830922158, 5.304699713183988, 2.332374174748698, 4.743284496568865, 3.022644889931525, 2.0544676290404413, 2.2646676917229933, 1.3270737639357968, 2.2426332869837364, 2.900638339980956, 0.8579049103202359, 0.5342828338184665, 0.979578978111667, 2.8905649579340413, 7.243261058484355, 30.61755088067824, 31.89280559939723, 19.077524023671305, 15.880940402707747, 14.392997122580006, 28.8799605061931, 33.907089771762976, 25.754678710814446, 14.253398006962193, 3.602810261710998, 0.2792586908946114, 0.0311886727990162, 0.05120193841116083, 0.03648986333921071, 0.005322920145361775, 0.04227872246936445, 0.04706032153579497, 0.06089850479075986, 0.09797707605626314, 0.06248784612023062, 0.011646797366049743, 0.07642503857852952, 0.049281237241361416, 0.1026073038097351, 0.040112306258731315, 0.03972620177533358, 0.06945500210408243, 0.025358155722759908, 0.10346343770863549, 0.04108883087493239, 0.011830685280954406, 0.06438664866671448, 0.023058796444186763, 0.029820520205483324, 0.05753902155124853, 0.02420174600105853, 0.01805330243622584, 0.006105789704428565, 0.03448675409139645, 0.023265711046875488, 0.06668750181673996, 0.04783516967548959, 0.040131581030906215, 0.10745323894004669, 0.06435209810132943, 0.06031390309574143, 0.04365067868944138, 0.04940479956266861, 0.024993038218047832, 0.03319269369146036, 0.01687088402949514, 0.0026625141617842023, 0.12459988780920545, 0.06395267517936808, 0.03192025420796727, 0.07962502614264527, 0.03827058109304598, 0.024468775523165544, 0.07767528641007601, 0.01670394580991518, 0.0433892396939618, 0.03982785781244597, 0.0674370652244937, 0.08083162228426627, 0.05353436204454592, 0.03310151007627288, 0.05516001977206719, 0.01767495267784163, 0.09031504002069274, 0.024301019504726417, 0.0214278431338889, 0.03151412227100903, 0.04181608963277071, 0.024573584012086355, 0.019183494713938525, 0.02184028955056302, 0.01782859352627589, 0.05349107041594483, 0.0066594189434732885, 0.014849840663373472, 0.037826755714993325, 0.010028901066811336, 0.027105970000247323, 0.025135350541301796, 0.030380649221760612, 0.06972149344942263, 0.04292124041145848, 0.08820816033309506, 0.013350121087334571, 0.03528885580899735, 0.09447836782783271, 0.05181870813811979, 0.08501279227916272, 0.020076542559470383, 0.01523845983038266, 0.03249598268960272, 0.029514611721219077, 0.029457938451800617, 0.0850469904441026, 0.06431084426660692, 0.1007247270054875, 0.005542201801173149, 0.06685981797354837, 0.02389578006019996, 0.09933288314289625, 1.6069005549915376, 9.861836856411351, 26.901887655258182, 42.395604810407086, 42.402237538368475, 31.205743628163493, 26.231991937083585, 23.095764767739084, 21.414201528795306, 21.063274914218535, 24.39584612846375, 19.67935092987553, 11.852303416498247, 4.737520083304375, 0.9049612788423416, 0.353588862044196, 0.12002641951004345, 0.16588582927661558, 0.15360433668378862, 1.1486388935196785, 1.4288425998341654, 3.2315368421616095, 3.144928457275514, 4.265918318302401, 3.4445941063665577, 4.453790043630908, 4.692479996911941, 6.07041108992792, 4.618630101603847, 6.223403138499107, 6.043298686704328, 6.714055365131748, 3.747001982504322, 2.6219240311653387, 3.0404465669585816, 2.008556531321618, 3.0069252560215616, 3.044267200654553, 8.165322032666976, 9.645397528525322, 11.60662183838506, 12.751445981764025, 20.52233692138426, 23.337875027810377, 24.156507022919197, 19.520589074780865, 18.826741403149022, 10.520941153649362, 4.8147407654793035, 2.8200851140483736, 3.477364528563715, 1.3902959972620013, 1.9144969914228687, 2.7044587894793484, 3.577676449091204, 3.8708721485830124, 5.349604968101748, 4.7070707236566856, 4.09001374436963, 7.002078929255086, 4.697182918748548, 3.234267302097813, 3.1664112787092886, 2.1081734568841997, 2.656672308521886, 0.4006696840928447, 0.9692614898085595, 0.8601879136216256, 1.8442827655423073, 4.530110541851291, 9.313042356121926, 29.654328553907334, 33.00831787047848, 23.453445703752582, 17.472042998959942, 18.549012099542928, 28.75458194363502, 36.599730214764996, 31.192348734025035, 18.747593856626942, 5.1297742609054815, 0.4748541759627481, 0.03526378558167527, 0.05142889195872892, 0.056207246642800114, 0.04560128027092546, 0.01633771556249309, 0.034897572571231474, 0.07590103443832168, 0.035474394643378836, 0.007612968582825195, 0.006669953131237098, 0.02187194813403391, 0.02004933303161975, 0.08552456199521981, 0.005855806117441746, 0.023308456837830525, 0.08344761336282377, 0.04760621663843913, 0.039303803876523054, 0.04966084912960088, 0.017298987368121743, 0.08417473805527534, 0.03653915726669854, 0.012591565722569585, 0.04219333047888452, 0.0072731415557134305, 0.026311701531672192, 0.009962558810178553, 0.023587826121177886, 0.0360314937819156, 0.0453186551138999, 0.059070029115724954, 0.016785110910272887, 0.06252618499040123, 0.07258096259207496, 0.01729900460510004, 0.022532827288453138, 0.075287145201958, 0.05375951528549195, 0.05432425998151303, 0.01552995437035157, 0.03195540806759269, 0.01932643905973002, 0.031549082693433574, 0.19612164957629097, 0.15355965843604458, 0.11536148031272235, 0.15836966404270741, 0.14857195107446564, 0.09951800062891938, 0.132379962672149, 0.1773568161673123, 0.2732036238716495, 0.11027547620957899, 0.19700248214987018, 0.21544496108207012, 0.20142035799161082, 0.1434589423719914, 0.24288917230742596, 0.10712441868118702, 0.14037929955990086, 0.11520211870271353, 0.17959734755417994, 0.1481332278419887, 0.16411536944008645, 0.12393083258141434, 0.09507868198617812, 0.1740763204232339, 0.10655362189056412, 0.16640679970864328, 0.10313240345567466, 0.10703468680261605, 0.07827199229429807, 0.15339605269893525, 0.07609494661371555, 0.1665166720387436, 0.09003162579310518, 0.20655734524611505, 0.25168914768484335, 0.2418266389999659, 0.3166240471745691, 0.1534008024440658, 0.20017476031376472, 0.12657248760543524, 0.17443521729400083, 0.1431825225271525, 0.13739003980111691, 0.07748355758526633, 0.1561609712699729, 0.1819786246144964, 0.2565185966030244, 0.1587678918675069, 0.1561179324503868, 0.17214256128476513, 0.08997366358075412, 1.5140720264565561, 10.21301450267915, 29.84708166891529, 49.60204608978764, 52.95895953332224, 40.527772134350194, 39.0459006832492, 33.24678620984478, 33.20040026018697, 25.84497755573642, 23.89038989620824, 17.638818256316647, 11.237467969617537, 5.507096465556852, 2.002469257962319, 0.6324330380847377, 0.7088932094554747, 0.6516971463157285, 2.3587072520486774, 4.956865887488089, 6.493411746717269, 9.941621788086431, 9.99666048634437, 12.115756273269655, 10.644413444303698, 14.2685148216063, 11.303345157254128, 16.09543619617339, 10.314737250727992, 10.25253140157269, 3.8894725182364067, 4.069653456249545, 3.9324102142164787, 2.7128602612403134, 2.516085736213192, 2.312133764067004, 2.810444663609228, 3.549078448164848, 7.19944033891924, 9.79941233511894, 11.68774724006653, 12.935838564749687, 20.335341845789266, 21.73093095902474, 24.913765691941787, 20.27726919420304, 18.851197381173414, 10.961268390378645, 4.526370561891987, 2.113216644333255, 2.324077626389842, 1.3207593608287074, 2.9699659876285063, 3.6453138003426218, 6.055103550034185, 6.13081657117413, 12.282132429461326, 12.116634884188253, 7.351646932863421, 12.991632319265797, 8.99396146497419, 7.97040916258289, 8.904435326976161, 5.068673049249957, 5.863154520911555, 5.990666852843377, 2.0222897298874396, 0.9865397755657473, 1.6400225196153888, 3.852736579795038, 9.832764248694144, 34.7506425457616, 39.62707827168126, 26.80227710354713, 23.011067067423177, 22.368055274409635, 38.44067112092049, 44.54695032488915, 35.794679426377826, 20.747502542311146, 5.6219027696117285, 0.5407889427677278, 0.08283779971421727, 0.1166334314151637, 0.17908563146427756, 0.20640328496454224, 0.14413233365743391, 0.14244396780287066, 0.14276773188143008, 0.3214485624865178, 0.12289356485369707, 0.08280311891388509, 0.20040697688537262, 0.11510902369815497, 0.2183156457519339, 0.19472669539672716, 0.12457587095277926, 0.13395162269232735, 0.16099273377368528, 0.2172314474779752, 0.10749092280504205, 0.15192340188209089, 0.22357059522501885, 0.1173531863417837, 0.13506560646478208, 0.11572674337414005, 0.16728256078016374, 0.07399974976696315, 0.1652120855907279, 0.11399333921050835, 0.19134861537285391, 0.19978973984477982, 0.24296057170196889, 0.16951199921388782, 0.15316362162270855, 0.21109290751478366, 0.12001933319674385, 0.10525092001884215, 0.13373368599962804, 0.10747551677688476, 0.20877674792803105, 0.2426488198820622, 0.13380612727374802, 0.21022722816034672, 0.16947000227387876], [0.10644366529079215, 0.09888980853100938, 0.03269462928836865, 0.04294191329409519, 0.025700512755241607, 0.044072299009008754, 0.03529748578946437, 0.08526944705555517, 0.05995943038273723, 0.04844201090294988, 0.012295653728107292, 0.06047871925177113, 0.027050489912770932, 0.018279152817182967, 0.05106790366792872, 0.07973757978048056, 0.08096302168503886, 0.08165978631305118, 0.06183255749243883, 0.03491946353366779, 0.06523308389249348, 0.09749372054131762, 0.020694176050563975, 0.005693704785493713, 0.029188664292075464, 0.056925997994239294, 0.07148981590064303, 0.015086535976508693, 0.02764984071555157, 0.020365373028682607, 0.05497103737246606, 0.032339624144257076, 0.027610523168057687, 0.05380744557647456, 0.022568798946937727, 0.07386455823096537, 0.05088265977739807, 0.07216824804462733, 0.017453313865248236, 0.037202271482636856, 0.03442588074493312, 0.08874911799906723, 0.01989246886824408, 0.04985316401167263, 0.05223099750676944, 0.030756145302626877, 0.065336337222928, 0.029160558441353422, 0.0359423824345633, 0.023688943981523478, 0.061639499505080526, 0.056363076587478, 0.3252522809611213, 4.871704857195578, 17.276677585417225, 27.516224961127005, 41.08654514435799, 30.966835983337898, 26.99969783906014, 19.722063579866965, 20.759973718274026, 20.728335880464126, 28.6015800891384, 23.170119177910593, 16.121791581953726, 8.295808011485684, 3.309106124985603, 1.1302450611706705, 0.6182157945248389, 0.11861630445045811, 0.42262677523878317, 0.5259547839241644, 1.638807565454514, 0.7569879029066332, 3.9904355522125003, 2.840671183601503, 4.435814311427455, 4.008071754247912, 3.193723967959804, 4.572102456323562, 5.334790175960911, 10.248933607532132, 7.614321689451895, 6.152344499864887, 2.487785590271796, 1.6588111630370541, 0.882764831185341, 1.5188812200100192, 0.2020869923815612, 0.6220215354715625, 0.6630587818161134, 1.1839865580681832, 1.9165285340239926, 4.097794010754555, 4.999400069636684, 5.293596954114976, 2.7137572582690948, 2.1943077252757166, 1.400065027898358, 0.21714483357725606, 0.24993716588904782, 1.0960897971545498, 1.327791189955127, 2.2921348242990436, 1.7446763813495638, 2.3507740132270323, 4.866973498175222, 2.729898056676311, 4.146783678762374, 2.694380749617854, 4.738654628876717, 4.915768273415105, 1.5739012870096392, 2.289149900597911, 1.217726663716378, 2.3645756081227334, 1.4823219108004726, 0.8478074424689817, 2.2084667461533702, 3.4576158850423755, 7.970758253528227, 15.756388479663482, 49.373183634973344, 28.884975256458407, 14.444561581457815, 25.84170041545745, 25.60329483401391, 36.34393676634758, 31.317015386396843, 11.792075422502334, 2.882393680272564, 0.34893496983474304, 0.010084009601644451, 0.032267979601578366, 0.03494577099298758, 0.042159228074935176, 0.06747680220512614, 0.030182674865148244, 0.01948587153287184, 0.05697386316774834, 0.031244687232819778, 0.020821685639901027, 0.029442388782157537, 0.021728743318348162, 0.030208756328530373, 0.07455442040677994, 0.04994068572658205, 0.028201946876041835, 0.027489707271959034, 0.02039840482475777, 0.040060491901972604, 0.03424677704911559, 0.021772758900037697, 0.05812978259317818, 0.02612640401498685, 0.021545071823282108, 0.016293046890848106, 0.015135268744591986, 0.05407650714680072, 0.04151057759900728, 0.06783373022992766, 0.04282724142314927, 0.04086565031039138, 0.054784571571696195, 0.04356385794498267, 0.011110851830322177, 0.08765733545465816, 0.01725749030048328, 0.04969343467946014, 0.028889901492924943, 0.1122539672219465, 0.01801889551232659, 0.05930756616796698, 0.04987223960098721, 0.05868487841179294, 0.033459273136911855, 0.05632050891196536, 0.03433326071488761, 0.027443138702261834, 0.06240251541678464, 0.041329137335020694, 0.035873706482591174, 0.045755164352275675, 0.0492843130843774, 0.07893621350728697, 0.04128280816779983, 0.07168957332689917, 0.03919732531592731, 0.051585878696172476, 0.028602183766422734, 0.03979020459096759, 0.0583299498764738, 0.053634512718887105, 0.049891449255688544, 0.02983034911355184, 0.06613971830736246, 0.0662500809337343, 0.04324243043459231, 0.04793094215734352, 0.0425653389444755, 0.02448474462594717, 0.06996478765241562, 0.020177890246193257, 0.08034323357165822, 0.02061886386194777, 0.02730187974990376, 0.023341475227367015, 0.009576606586755765, 0.06743961629728157, 0.07685976283204171, 0.07101671830300363, 0.02741171760604747, 0.0443734098676472, 0.026759579514844284, 0.03919591188370701, 0.017329274654208172, 0.05142121575772763, 0.05022100495895551, 0.03660159726296702, 0.014292945495746551, 0.009606514659319675, 0.0630971005246524, 0.024912780931880398, 0.05944258533418179, 0.03544042247437662, 0.032250497475146286, 0.0883058518651993, 0.01287646807595006, 0.6795308979288225, 6.512142535178892, 24.470018148422245, 35.880343990941206, 44.45328412517425, 33.65770155383695, 26.040976432061967, 20.0992210449711, 15.185227644058967, 17.311490581881618, 24.24803945326036, 23.398214809356197, 18.517921432372063, 8.587200891587043, 2.5226132956243332, 0.6759721437288869, 0.36401409295297443, 0.027873107464984063, 0.10145558254613031, 0.1542205165230459, 0.7334152549024552, 0.7378253472908851, 1.6402398434377488, 1.953680366277695, 3.9781678492023103, 2.6158325902877317, 2.83195837370811, 5.515475138541191, 7.717552098535723, 13.113022811951177, 18.46371819896083, 5.621639480513911, 4.912713237347142, 5.180407156867366, 3.506656053566164, 3.262864812727898, 0.9786187941508909, 1.6982319638613732, 1.9417547674909716, 1.6147009235235954, 2.9336958306451, 5.984668568257363, 8.433725410892118, 7.115966908393368, 3.5452340350997065, 3.225674859939083, 3.2021325490167065, 1.1295528854093244, 1.9167774819558667, 3.8607941087215183, 2.477277315432026, 2.898321935246068, 4.669161996533794, 5.48149025247943, 5.870154971076596, 6.219397417960629, 4.254083056603709, 4.442391635910157, 4.086194336414337, 2.3772161814474293, 2.459949754899548, 2.098864446724615, 0.4733925414902549, 0.8608162895806375, 0.4717129703250624, 0.47443016161841733, 1.5259903933732741, 4.121135300205601, 11.358329922922197, 17.831167367196855, 48.17130273388278, 35.77030189575688, 15.535222695719813, 22.888569485756662, 24.423020309017552, 40.501041181625865, 35.80606606698806, 16.16670075924166, 4.278385081598836, 0.40891511906539246, 0.05323508596648613, 0.06647292825002825, 0.02922976873965273, 0.043590908509589014, 0.04650366672825429, 0.01610592800012279, 0.03491616552515376, 0.0408796850411642, 0.013687431515615075, 0.05784772051077697, 0.028699635896050645, 0.019517451592330492, 0.0508845788276484, 0.03224135421577, 0.011693123660440887, 0.12432401954767205, 0.04295405961813466, 0.06763463930016564, 0.05531274706065174, 0.06295119141859394, 0.042634099166119294, 0.037017920084538004, 0.026585859501914635, 0.022950327970207702, 0.049383992614645156, 0.06379298798199143, 0.0662801498847623, 0.03074380937182615, 0.06935557155239006, 0.05557235510599229, 0.022823841108249563, 0.0624442097520636, 0.05022426466307333, 0.051022562754130175, 0.023624253601977424, 0.05220671251956975, 0.03661928240269904, 0.025667708870323918, 0.0756515502449005, 0.10153131799832468, 0.08025600680059965, 0.020089987402541504, 0.037182134861547145, 0.0026978140569201884, 0.22144994127654263, 0.18443591291865996, 0.14303417726149484, 0.12332084273258526, 0.15070394312422122, 0.21909878679340888, 0.18334362475622087, 0.11158184764245827, 0.1824233539762997, 0.1477624872519124, 0.11301550458395675, 0.11516524689091791, 0.09650037263429935, 0.12095020663353706, 0.07487660634421534, 0.17112752542861048, 0.1466528548588676, 0.16891207576038378, 0.12835538870985472, 0.18744411037093212, 0.13912919728505996, 0.1492472269362019, 0.08085426018242875, 0.11931690717897109, 0.15782589483405315, 0.13924815541794225, 0.11314871961310988, 0.17181101375289504, 0.0993980389208563, 0.1538451947271824, 0.09957456090036901, 0.20086171135546702, 0.06979676924886243, 0.18459795583640376, 0.18668959037430827, 0.17021353656966842, 0.10566010290095884, 0.17961266931266556, 0.09121924593684175, 0.08321987840557292, 0.17329491074046782, 0.1498264506939919, 0.15942233013770274, 0.13410775141129572, 0.15837029223480534, 0.19737208892981853, 0.15490196705345186, 0.22451213260571803, 0.12990177548941106, 0.1325226235654085, 0.2522615839036242, 0.24106338560100526, 0.5902225740494267, 7.515173487124905, 26.549017506261027, 42.65326530702653, 54.80289713028939, 42.8442455107166, 37.947338934867616, 30.90399765199231, 31.32960031109472, 30.131920268458707, 37.508057009789255, 31.687842146042858, 22.18329987218303, 10.454236345906413, 3.9723541611625306, 1.2089183686241027, 0.9584152782636305, 0.5088898076886131, 1.7855597359518853, 2.600069320009601, 4.407810059285933, 4.5029927453687115, 9.426761673342797, 7.928076492201898, 11.892342971217248, 10.630287028128102, 10.15193731554093, 10.319750039808213, 14.962600777226111, 20.245839242012273, 19.70479142281317, 14.150760366070656, 11.051149502877267, 5.472411436419334, 1.8270346330058191, 3.135550315341642, 0.9830920121842815, 1.2875142092666318, 1.3228045091513665, 1.65260830233174, 2.794370790643077, 5.751326276410011, 6.3128420037607995, 6.831393559132853, 4.381848871707916, 3.7672360193344856, 2.6185799654453032, 0.4400063684630779, 1.0594053398216925, 2.8517710008928856, 4.053774966347603, 6.29141164402808, 6.021555517950366, 8.899308789160944, 10.19182389782321, 8.124043989566065, 11.382209312531257, 9.296657635319619, 13.248088648242335, 12.644390771465918, 5.876230232177242, 5.357305071046276, 4.24339214640279, 4.228263564648167, 2.36124649643898, 1.7277308841866834, 3.1959273594041027, 5.4508271236573504, 11.76312440826047, 21.117397739041238, 55.42390246545115, 36.149912803403794, 23.348261464026667, 34.2433584890058, 33.80971300986506, 47.01267380868235, 42.20681328927317, 19.804605937773182, 4.659215846369344, 0.6094996751316133, 0.09286563783403366, 0.1336115102974638, 0.16328033360262073, 0.10851994742669406, 0.10863303732607635, 0.1543706391126879, 0.1765111163859406, 0.11560281333062919, 0.10698026391647517, 0.2403799125984792, 0.18404389040604716, 0.11748781097271752, 0.1272966245549821, 0.15565641044128328, 0.12676138956580432, 0.2179740165029803, 0.12042113099127047, 0.1230293386165173, 0.1617551444759292, 0.1614562782549089, 0.13612654630935964, 0.1668167180351673, 0.09932158334601311, 0.10980910486391476, 0.16155738653915544, 0.18892388580547226, 0.23240907418151058, 0.08053780458266697, 0.20954309632220577, 0.19396220093532918, 0.20670533811132755, 0.1038388514350499, 0.14924186432073194, 0.1967288048998002, 0.12629118011963944, 0.09919189998219091, 0.10645601462813155, 0.2118317686742352, 0.3099599708953212, 0.12746026093560842, 0.19817700219010154, 0.1381225883960724, 0.14276711901109065, 0.2017349903021128], [0.10824162768380297, 0.024777832628798582, 0.06762437372198028, 0.05588280840686733, 0.043605965967740745, 0.040000886431023966, 0.03386295933817183, 0.038506371464820645, 0.03126861407391487, 0.018057586782942378, 0.06176215401219745, 0.038206313977078084, 0.01107299272271414, 0.031077423425872, 0.1348678791715253, 0.07555015850812197, 0.03323508516675042, 0.01625926815904677, 0.03891856124204013, 0.04155042566238873, 0.05047044701754086, 0.026984951090848735, 0.02784273016356653, 0.031685925148908174, 0.03799985711192412, 0.0485083234736756, 0.01164571047880717, 0.053437995844550674, 0.06755830629939033, 0.019182399208206805, 0.035886906177526524, 0.044342762520236355, 0.019081455632863988, 0.030092927664818785, 0.08487139543097827, 0.08451669672203642, 0.045288291219021046, 0.02883846251924913, 0.045237005462930094, 0.04241261165589095, 0.029959936716383504, 0.06814907500219923, 0.04533338698468382, 0.025565242695231593, 0.05281690538169877, 0.08353675535369305, 0.059334842728510986, 0.05590669885878602, 0.031849264670463825, 0.006079910296736466, 0.04448936110542667, 0.04531767452135683, 0.02863761916336033, 0.11441164619980321, 3.423017393196783, 13.560982000443245, 33.50955363242857, 40.83199900965537, 40.49397307057535, 30.828103711528165, 24.264670302790982, 21.589247103660338, 27.015095103171568, 24.303031083076235, 17.56939034308157, 16.90166565679735, 12.034270994124874, 5.078529965492987, 2.149524799277706, 0.37765131602364205, 0.38325693458318716, 0.13731408984430377, 0.7509511300633032, 0.25337519995387525, 0.7317755815963591, 0.9332940907728289, 2.4306560235638774, 1.165138343649526, 2.7741990214393986, 3.0351927972609, 5.144986193026266, 11.745180545314668, 21.496881169657556, 2.532758260926893, 3.5955815786315553, 6.271660549025382, 5.4409922707465395, 3.253258928175896, 1.0405497709589622, 1.3471042052392037, 0.2854160459772233, 0.22018326085902032, 0.3672031024771352, 0.8848237078036032, 1.2381465228334552, 0.5422291267783411, 0.19197237948256154, 0.4612837557590777, 0.24748695623730463, 2.164821552653467, 3.0800220562565714, 6.471160631025992, 2.412338309711026, 1.6375921209973674, 3.9977166969929976, 4.266795948628457, 2.546739794554249, 6.690617732463345, 2.31891603239121, 2.7935799427570838, 3.7333840035623123, 1.4532064021595064, 1.7277291681497329, 1.490781605243683, 0.713259297753534, 1.3326925592076395, 1.294212146632133, 4.241162278959829, 6.593604280102638, 13.150016646231375, 13.4297679316613, 31.31142600890129, 56.906499555034024, 19.72703322287529, 22.21356684161771, 28.89182567596436, 38.534282407452984, 32.750724054151966, 13.926457666581678, 3.1946158168777345, 0.3130971928758006, 0.07093614883600705, 0.034153789296866424, 0.03879172006441701, 0.09042164881623561, 0.0481820389658453, 0.04592979409461541, 0.08450384176666699, 0.05570805992089933, 0.0014155560793663046, 0.03830590923767417, 0.029569013539942044, 0.03969885626687639, 0.05755808181880463, 0.0037341804343140536, 0.055199886987646746, 0.02858482421405854, 0.02941489580177492, 0.0668703286998695, 0.021460773423314098, 0.059158021974707806, 0.054642033252504565, 0.03849306834801551, 0.024738995801477183, 0.04450110523330589, 0.03921856127318837, 0.051862175966943466, 0.03923759089722749, 0.06315165747618003, 0.032401328696118246, 0.02621932473454264, 0.015531652212713756, 0.06394983682360861, 0.025886045843963663, 0.06131706458906974, 0.010869350273071999, 0.04988305676247805, 0.01182285969280788, 0.06778218017350282, 0.05209800464311435, 0.0421879218981391, 0.030333366275074023, 0.06346253212541342, 0.053155340044008154, 0.05988481341891232, 0.04728945460350764, 0.04266246357151578, 0.018488589764362382, 0.05424795379381507, 0.05154558247135532, 0.03647464117215526, 0.030840752052984415, 0.01443127320418435, 0.025088341471048135, 0.054366559526252176, 0.06658100793438573, 0.0749841804105428, 0.013560494577001422, 0.03782894289601715, 0.07445171099877165, 0.02094938483599934, 0.04098762682969532, 0.032885756734157764, 0.018046934330355258, 0.0255997319735827, 0.018530341556235667, 0.03923463379783977, 0.007115868492908175, 0.03130488833712955, 0.025156735885708083, 0.030194911204518813, 0.033709600027049744, 0.041552337051759806, 0.022785762707973202, 0.10639940073052723, 0.028962042077534625, 0.01172096138038943, 0.04917999872216775, 0.07419009963350912, 0.019807450345627243, 0.06564002979787127, 0.02735175973465366, 0.02111234131359285, 0.03588939596328043, 0.009090981536334562, 0.009383437516648442, 0.03464441115577375, 0.09370950666526634, 0.06254470516597072, 0.01447036284052076, 0.02058014960869426, 0.04147003239561473, 0.025683873325526237, 0.031873835025415305, 0.05796953998205643, 0.05450689151222187, 0.01778803683156448, 0.023734204456089966, 0.03908811182144188, 0.44664746210459744, 5.2717802409202825, 18.164078535572177, 38.55466696523851, 45.90565150783908, 46.20537550218644, 31.10295399542778, 21.941568120833367, 19.154159292098015, 27.586594243203443, 31.978931042455862, 29.072193907153224, 22.082006623668057, 17.690640611033288, 7.271717854084508, 1.6497178832369468, 0.43126809380708203, 0.19452928986039855, 0.02492608596390534, 0.19852923409592724, 0.13725928391420072, 0.7179801766910862, 0.6729046663930339, 1.2641466889650592, 1.5848335455502234, 2.2062339369327795, 3.926382266706036, 5.385966810487933, 13.049776554107668, 10.545716804842796, 4.987872223700247, 3.623306852194571, 6.958321457909, 6.6930270483416905, 5.14720086128481, 2.809758248829073, 3.9150522553151657, 2.3135009552201917, 1.164677097432075, 1.0696701825626436, 1.3541265961623963, 2.6057871551282945, 1.2709208674007848, 0.4265040075106006, 1.30007118707703, 1.02504562226034, 5.256086347564574, 4.383355061854086, 7.978044056123304, 4.089803652417276, 5.946154815535392, 7.381855066745513, 6.850488637724231, 4.919639162478909, 4.471722629762465, 2.83095522753654, 3.010474755879372, 2.9426292738606854, 1.8330614773496505, 1.098609552268059, 0.4163651402679182, 0.3974634529121461, 0.653289383457553, 1.295659256077582, 5.336055630637754, 10.679632406080923, 18.526505539494178, 18.161291691564745, 24.867748445080174, 59.95471069889685, 23.675596983202045, 21.23822439101435, 29.690441816083847, 41.22947631343719, 37.932351558439194, 18.14885581693342, 4.159643659668585, 0.4855149022994503, 0.039966481422344526, 0.008572848502456421, 0.017952042849614255, 0.019534544929141, 0.03656900022178888, 0.04059482290739975, 0.06621105641487145, 0.09896589638364893, 0.07260049017326486, 0.058067258327238025, 0.08715308106113827, 0.061774809784706564, 0.05657085495430136, 0.043666467761560794, 0.08877099747018469, 0.0531064712953183, 0.07039123049546635, 0.09483595468824911, 0.04218783762846743, 0.05794224426931432, 0.06535580351708398, 0.08476924526715472, 0.03496876129159524, 0.06776731806777178, 0.04658054748189546, 0.02809106522510129, 0.044605840943873896, 0.0544014816442805, 0.0196840048527285, 0.0659354639449908, 0.040189570056334625, 0.05298957776939196, 0.07039470853464258, 0.04371296163768538, 0.05487770105021135, 0.03009761420769557, 0.06692569387415725, 0.08936221050398965, 0.024904844260984854, 0.011236409810672124, 0.027026840778548392, 0.060670926881533485, 0.055679270336704875, 0.05387315676817971, 0.004718702769042143, 0.18626231249542008, 0.11809570174063407, 0.11831533914852528, 0.12957313909165322, 0.1546454195293688, 0.10874939076001607, 0.1976767620973049, 0.39810537330565915, 0.14820055164877446, 0.13763655157339189, 0.129346591570685, 0.18563260354342, 0.10969199300293, 0.21846230562415817, 0.27914714849283623, 0.18458997320023277, 0.11455221567302944, 0.18937797676171028, 0.10716546567216997, 0.16856831678700063, 0.15510470456173345, 0.11497757067122769, 0.11754426399185774, 0.15710329006035484, 0.15334748272453586, 0.16589788750054377, 0.15254851430654526, 0.14405716511030353, 0.21615774460857917, 0.12160487473011018, 0.12864787341846576, 0.10568343027825318, 0.1600708848526401, 0.12364896585143383, 0.3324928537251488, 0.26181005782658057, 0.16654213680134666, 0.18818349247017216, 0.1358474911220612, 0.13347226615634658, 0.15921799916653864, 0.18307056037649033, 0.12412933362347466, 0.11774523949791348, 0.1773888539643057, 0.1292299163798171, 0.1653967740675134, 0.12865743419576076, 0.20404494457667877, 0.10641265405161728, 0.16020540989214377, 0.09635394258845238, 0.24835456613331075, 0.5197418108582497, 5.307249253795994, 20.862208335630356, 45.12606082424041, 53.63968295435752, 53.73293730520434, 42.315788499770626, 35.92990313806842, 33.067941819467855, 38.74398800634569, 34.280824968891764, 26.4362552473622, 25.17458369654994, 16.72765951002798, 7.32040084177448, 3.4158482811143323, 0.7438713744763406, 0.7441963796173373, 0.45969856662615655, 1.9605772413553733, 2.041204011728687, 3.2754208099457527, 5.0490479603890455, 6.004109305720176, 5.982704931689847, 7.204490880812369, 9.133593920738466, 12.757552131529778, 20.90783138428965, 34.79617341872185, 8.307810464212972, 9.223693705374195, 13.186296609140213, 10.608953256760875, 6.211480113767809, 2.843496761014385, 4.101900242028698, 1.9747877433415384, 1.146300180304435, 1.011457735251996, 1.9811095008927009, 2.0907176838767145, 1.6565000289870848, 1.3499569940951563, 1.3584740532021369, 0.8070783473310933, 5.778961335459064, 8.628323020473603, 14.303139544302418, 7.623783917196336, 8.883383966261341, 12.918119257496251, 8.876738490596894, 9.775453517513892, 15.078154783095084, 8.338037229353382, 9.34402221633542, 6.757495124493876, 5.566292876197446, 5.266211946164408, 3.207447115452059, 1.6011142009688963, 2.168461757321512, 2.2848360288527707, 5.948106194696119, 10.039662411136012, 18.305409377621068, 19.863870989891794, 38.614522334068056, 63.536744656101355, 26.403277920138454, 31.53257512277173, 38.72682763684181, 49.50060967476138, 44.10891571352559, 21.627386270030854, 5.671600670583787, 0.6322236202897564, 0.22764889493344292, 0.14388622025087958, 0.1489667927906398, 0.1728614735146684, 0.2184707019478083, 0.20938617087179617, 0.19668639427231205, 0.1657845677747842, 0.18179353777199023, 0.07672382819075739, 0.18364609159048528, 0.13233675531321956, 0.2557065280815286, 0.17969012080181032, 0.17174592692284815, 0.17038169286904797, 0.14832963746401573, 0.1562566556517155, 0.08005454865915161, 0.14061815045293302, 0.23241933975969595, 0.14233392693342703, 0.13108288388579123, 0.14204981556582835, 0.17326699449650704, 0.12985561103109391, 0.22148842953385847, 0.19103035180559083, 0.11900198375505787, 0.09389579626581362, 0.1072111628168533, 0.22590808269958343, 0.16190958780146417, 0.15693249841851575, 0.05093949584050044, 0.19526937676052894, 0.2455680438828084, 0.22735451798765893, 0.122251866625682, 0.10647673730648334, 0.2045870437136581, 0.14195623026499826, 0.131965784896766, 0.2157303441556231, 0.1333388289616954], [0.03686317032383334, 0.05169788841158152, 0.02649568903800701, 0.01709247879203289, 0.012326609425907655, 0.05447040274438839, 0.01724685125443484, 0.06825345448188244, 0.08050880815473296, 0.028459023000792633, 0.04020009610441424, 0.03201623353356075, 0.06016442401995582, 0.044778436722774664, 0.06089354820188977, 0.033926759140505906, 0.07907558022247207, 0.03149288631374798, 0.06543366103282859, 0.05962384173706655, 0.06177764047958678, 0.07016340360766457, 0.047836897203758846, 0.008848743577067171, 0.012802608581560274, 0.05043376672772631, 0.03881265341694798, 0.08565174791240886, 0.05225548933770868, 0.013240079260281017, 0.08671659480540023, 0.03663519404888634, 0.05186211084946991, 0.030024632841588992, 0.018891802906329115, 0.0048061531420136175, 0.04366847108148279, 0.023416461828615398, 0.038704443497643355, 0.04493430497184877, 0.00637361069112235, 0.017374839648724567, 0.03827533849905576, 0.027847221354022626, 0.049396073821211056, 0.04591984261247901, 0.04215858456107878, 0.03447478013713995, 0.08089804210730138, 0.033755212902061404, 0.05667747907160271, 0.07804889982986836, 0.052911816014637875, 0.022988739618731123, 0.16015942929492843, 3.2881761125979887, 12.415541064354683, 26.561941715978808, 36.554336624760786, 38.359689866342855, 33.551495536681145, 23.051420411755963, 25.127358359675256, 12.2212690114975, 17.78096495136138, 31.617011985471173, 20.28079148261778, 16.440297845871218, 12.963995299031659, 5.312919530176348, 1.711724181809733, 0.6941397656356135, 0.7765356475307096, 0.13400327234018233, 0.48515287978995236, 0.302016313277906, 1.0186489719536997, 0.7328866542347017, 1.6798413184381302, 3.99380658422747, 4.255547571566797, 13.491099092268175, 10.805969988146137, 3.0707444250583653, 2.2453169236260075, 7.594708857997772, 9.61023053815288, 6.409873106787282, 2.3043098613139126, 3.220606177083908, 1.7026285731023358, 1.8486759427093693, 2.1011359893506576, 0.7690409174369228, 4.065988736767923, 2.487786570864339, 1.0331241113524283, 1.4805243620949409, 0.41399486423019444, 3.9448112778125273, 2.602270995416949, 5.816540093191209, 1.9044421180602045, 4.379243927617227, 5.799368937169352, 7.015912148260302, 4.711772174604477, 2.13187781072432, 1.8126602494908919, 2.0119077063375905, 2.123018157097601, 0.6085040672652183, 0.8439701999868117, 1.0642074240792183, 1.0441957366081978, 2.542318302777506, 5.440740258462968, 7.520064192433511, 10.910939478105115, 11.295081703893601, 16.483835174191384, 42.687131051094305, 44.488558000133885, 24.87873696511792, 26.873166099671398, 41.055605488438765, 30.31028416848952, 16.712519161162838, 3.990006788123039, 0.48627381964075955, 0.03881677113954098, 0.04658629697176718, 0.07835371089318106, 0.023923839945646546, 0.02116781182497019, 0.04286374168230161, 0.09924111347044669, 0.027144617220807462, 0.031106576901830496, 0.053996071745190895, 0.031696704006002795, 0.032118184514523994, 0.08966764975940028, 0.021973269007679437, 0.04136139346707252, 0.04174198977829468, 0.03662545707136874, 0.0076277794564263, 0.040025370601083965, 0.027038724717473792, 0.027355714663562757, 0.05539784410728082, 0.059570951026774226, 0.0514604241376923, 0.04369361025671806, 0.018416410875356486, 0.04142526987819903, 0.05110120934043681, 0.021351603978884318, 0.04021894569779116, 0.0506153333962204, 0.03292589974139006, 0.0554157016167958, 0.04801014798783487, 0.009327041954102536, 0.011270991019574145, 0.04561345340804227, 0.0764726432821443, 0.026050501938668952, 0.04684993080914982, 0.05638071576193456, 0.033321001927458474, 0.023273063575728767, 0.006364816959361516, 0.0650493530256133, 0.08232545543221698, 0.04770297737371537, 0.05562218912546674, 0.05378260134509014, 0.030398920418754704, 0.05088559772458769, 0.03296203227833875, 0.030443851475513754, 0.019289622789308913, 0.00627391919073078, 0.06432936827261602, 0.03004024571348583, 0.008976838266056393, 0.011276291390400262, 0.03660771830548202, 0.04396236156143489, 0.012602619413707047, 0.050005117551453655, 0.01873891473928046, 0.05149365320140797, 0.01488903372157966, 0.07235406267066156, 0.04504595845637303, 0.06317973842904454, 0.05708442114654088, 0.04807590514481549, 0.018446094867202546, 0.0659208240047578, 0.07838418587080895, 0.03043677090787359, 0.04334225169112606, 0.04536404965385314, 0.0451563440653826, 0.05355421138266402, 0.05865572110539483, 0.039184968317708666, 0.057714225859531475, 0.015744942582152303, 0.045740624003472834, 0.03189495798470753, 0.061417996673093694, 0.04610120243723354, 0.12430601648145145, 0.05291500294040288, 0.035322690082173196, 0.05778727617355124, 0.028921529432878863, 0.06289348967613713, 0.08136282765096234, 0.029943350912822835, 0.024823581484416803, 0.05974430140228041, 0.04466116781376543, 0.047084434153211695, 0.027781617414626866, 0.29737146090595956, 5.403843993140805, 17.09914718904803, 33.8903961643096, 41.398444175720215, 42.56435694233064, 35.822088949141964, 25.2698855246267, 21.890659678366877, 15.62996558604702, 18.13410182153025, 34.53992889773461, 25.269909058847738, 19.388744484993722, 15.154829275223518, 4.497144001145517, 1.9390485772202093, 0.6673035830740006, 0.19908123108888828, 0.08252072358323682, 0.18446294050062859, 0.17035359276398537, 0.09985606756902511, 0.3378523129128641, 1.051490732258366, 0.747901977550599, 2.7698711762505197, 6.252939076192918, 4.664218829524133, 3.8206025621583386, 2.997781966001757, 5.982017536317149, 5.547616510621963, 3.409109158862022, 5.074273213263481, 3.5382728086363886, 3.66871980890151, 2.03158856639939, 3.967565437478404, 1.9163505564774237, 2.3055770320277063, 3.6733543344082373, 2.491263261725826, 1.8267501385942584, 5.027781849907291, 5.6213943323781415, 4.8274786626139, 8.532079823555486, 4.686115461011087, 4.596580007383901, 4.501074216058178, 4.017586443693408, 2.843686260523335, 3.1808747735715683, 2.2239579020007967, 0.17184072264259861, 0.7589080256800499, 0.3247475822366053, 0.17147562045964504, 0.4115675606073872, 0.9418104144354021, 3.281845407139871, 7.47642586308141, 12.022487213534694, 15.633541807051628, 13.966967905721358, 13.607565049202213, 38.68249308678412, 53.09793695326775, 25.179276812461115, 28.139311113665183, 46.08065982018748, 35.101761356476814, 20.385050042983025, 5.228808714497474, 0.5128242820501328, 0.05887027551990844, 0.027810265272555333, 0.020011946025695053, 0.01583917810010814, 0.04618292103611654, 0.07117144508107055, 0.022044055531882954, 0.01666444440131947, 0.02408006059516582, 0.030584631622919155, 0.047206908629666415, 0.04419915933882998, 0.011128762965991853, 0.0476032403868533, 0.016956940601249377, 0.04463422833190811, 0.0724567107916359, 0.021004794060342738, 0.04955327506327341, 0.04883061283298078, 0.13700606121170905, 0.033178559369257385, 0.03838795342392499, 0.03017351819923328, 0.05031023121949646, 0.047897337710544954, 0.030836542399840492, 0.017888103236233997, 0.06906518592469155, 0.04501047709415998, 0.016723887078584205, 0.030389179610797477, 0.08358915576771384, 0.07767212246694873, 0.025468522179571372, 0.026253319886182586, 0.04264343777791627, 0.048876302316784866, 0.07910815428101248, 0.016671804591051994, 0.03808118883640536, 0.030015106538250565, 0.0049304844240748115, 0.016572713033266125, 0.041981323306719144, 0.0469556815862175, 0.2908250250883641, 0.10163519185997787, 0.14080222605937912, 0.09265347744428343, 0.1488327427256492, 0.10008420089199659, 0.11100798650013824, 0.12595939510051282, 0.19785014311632804, 0.11885202970475921, 0.1374720571742904, 0.10312696423141227, 0.10452430860529985, 0.10739343811667736, 0.11526548183493077, 0.16608700396553164, 0.19128650096395325, 0.10829372932353329, 0.17726529930387774, 0.12169511222671117, 0.142295086275666, 0.17856656093030207, 0.15735197752233476, 0.17185743868110642, 0.08971983566880228, 0.11269369402960425, 0.13602704680975408, 0.21937756618905455, 0.2062629070132971, 0.12650347840521606, 0.22663566704478957, 0.17522212748806323, 0.13312731208580156, 0.18469860446789574, 0.22580723488523116, 0.11331315272517743, 0.1773271225993672, 0.09612789302463494, 0.17282162162084735, 0.11012951347736583, 0.2680106815551558, 0.24710803382819702, 0.10832307815191247, 0.11623339562286293, 0.14184039777084706, 0.14865378458653727, 0.15185404028142654, 0.21672153935557414, 0.18665572928805507, 0.11227495803107178, 0.1971949694017249, 0.17507585065980114, 0.13323686265897366, 0.16217470018854066, 0.36382168230991213, 5.543875550070117, 19.537261109198294, 38.12299051592427, 51.20848417282105, 51.241498762561434, 44.97690877606792, 35.16725317124398, 35.350192516080796, 20.420690659553777, 25.06798936474708, 42.823374579029704, 28.508108046747026, 22.91312156185027, 17.7331865602924, 7.033178421758837, 2.823804991860544, 1.4995021373033526, 1.1208702287366314, 0.37374809804943304, 1.2927140463744442, 0.8171668672753919, 2.55473701703933, 3.6876597087229457, 4.94304100351949, 9.047017405110022, 9.879265908272037, 23.72256736601553, 21.63184992728695, 8.68326856243995, 8.289657735055494, 16.523900224316506, 20.567663831095544, 16.155228807080178, 11.412787129802089, 8.93220276601853, 6.591940704853305, 3.2263632359043246, 3.9738267660140996, 2.408033263298773, 7.7829620338255365, 6.550386624951517, 2.169229806430878, 4.4695496366870024, 5.15224551962268, 10.91350470819781, 11.534135457008116, 14.99521920757909, 10.741475435995287, 9.050132747619383, 14.935468762151658, 14.61916785086355, 10.888138740293442, 8.331923234847284, 7.213098522155517, 5.184866401457018, 6.493906455655252, 1.924407962829836, 1.8539119391672074, 1.7670130537402247, 1.8382778619566273, 3.369490768640272, 8.21383979051344, 11.190858444859906, 17.187816289163408, 17.462825429055002, 24.892100480295, 50.57828872434555, 52.90035932294784, 32.02520912693393, 36.65110149691182, 52.97957551094794, 42.21298317755423, 23.746678175464755, 5.582099047399336, 0.6620791085785436, 0.1628814162986894, 0.08503045060581739, 0.1562136474756464, 0.12880308283192496, 0.11417746078222991, 0.1432338657398378, 0.1383621440899949, 0.08437836422554909, 0.09181148552846524, 0.13978362023349733, 0.21726641173083938, 0.17551598349405875, 0.12590714024319766, 0.11300313992485886, 0.12633048043015505, 0.16456422035492238, 0.15488215601972996, 0.13329799647533125, 0.21708083459206168, 0.12164438954524456, 0.1723015858160873, 0.13810624007976827, 0.15764008786889816, 0.14758847804079134, 0.18058339464327983, 0.20295832546487932, 0.1259657612911636, 0.17425728571270743, 0.08873692954019194, 0.13825023396601602, 0.1898677367717028, 0.11400846944701289, 0.20267015383128198, 0.14197446315759613, 0.18874652112924284, 0.19036854376956341, 0.15309566962382487, 0.2087396233072204, 0.2138253592795903, 0.18612133699559397, 0.15107681343872703, 0.15171413730469444, 0.15777655877172947, 0.12163511222048153, 0.16206468996261397, 0.16929760184739867], [0.025001947820607214, 0.004389520533638256, 0.06556872233387924, 0.0431883791010947, 0.03544093958372551, 0.042746740904065876, 0.061272099058354096, 0.046667651678886146, 0.038532502723917846, 0.08662858662465889, 0.031187962252466433, 0.08847214657092288, 0.0358245657726882, 0.05208997221122827, 0.032534160681309245, 0.0148320023060566, 0.08913583152236478, 0.006952408791309404, 0.022391440016367746, 0.031991523367563085, 0.036050653640901854, 0.03864624379803577, 0.0354172061798313, 0.07474061807677632, 0.044552011775874326, 0.03063242401807539, 0.039960157366529594, 0.06225797760811064, 0.02979669295581839, 0.028563132434482538, 0.03152230409004035, 0.028102995129302148, 0.04255677791192167, 0.04886910109029663, 0.07401079675483127, 0.010041200608435658, 0.007509905816761838, 0.0345569200843813, 0.030437412506510175, 0.005025677551935998, 0.055197749602338, 0.041277311486943115, 0.064611280967872, 0.01919890265731562, 0.07146518617387741, 0.032372726803465236, 0.022679310960454807, 0.02978426126402713, 0.02282421649133246, 0.131034160693807, 0.026620243443176154, 0.01596189772469863, 0.015696747033225916, 0.010904742577563851, 0.01465414446072593, 0.04680379699434965, 1.8431871985235524, 10.031975546190816, 23.917493474098947, 36.64468057693974, 40.267962178876324, 41.75858051546159, 36.42038376100602, 29.623773290264992, 28.539602718045636, 21.59843525578899, 32.72559342845794, 25.814163415662705, 20.6551875991206, 14.110823773568677, 10.508767097227036, 6.0799958917402455, 2.655277415629356, 1.7546942373437269, 0.49741405573102737, 0.750153847038746, 0.14362028048884484, 0.31925929770354305, 0.6578178823955598, 0.36578927189111715, 1.773140041097518, 7.26905603562632, 2.5008649787595196, 4.510967414225302, 1.5750197753790887, 3.9420972428014203, 2.507381751652687, 2.413900393632151, 4.139228213217951, 3.3874863578427226, 3.3142375657635355, 1.6948128828117925, 2.4606182738657925, 1.0497748178820456, 1.1086113510593292, 1.7953748544377668, 1.9405835722723317, 2.173443167440353, 4.055384854155203, 4.543586334874553, 3.2065351643869957, 6.262310108830852, 2.6527264041285363, 4.416457904923347, 4.615779028784845, 2.9242451248630403, 2.286012739904465, 2.0147455411572612, 1.6415135105771403, 0.6871847291627239, 0.5223977457611791, 1.0736456273063537, 1.6929964576998067, 2.900797195972935, 6.346241966370614, 8.77877337317313, 11.252378859827596, 14.716368106103713, 16.45573531427691, 21.881938288288733, 20.420043468475342, 35.82004147191202, 40.14940069567773, 31.38936938778047, 39.910449904780236, 29.402943849563602, 15.6514052614089, 3.477212536719538, 0.3371020063998238, 0.08970911809874159, 0.04170527118408392, 0.08110418104596677, 0.08413279474142098, 0.032161964524176814, 0.038994882751496575, 0.044811271251209324, 0.02425754976068293, 0.08249649988307108, 0.03731457231145713, 0.05169992620546011, 0.03407743331345339, 0.012050047854802782, 0.039583261259981704, 0.021179377837407014, 0.026841773088240338, 0.03911800840268693, 0.032023237492408485, 0.043823986930111726, 0.04789099450253191, 0.021589886051632708, 0.007877666803617633, 0.0708932938775228, 0.015916714816534474, 0.08724606881338744, 0.028130246791988615, 0.06120650277983758, 0.05171024157936054, 0.03625030381484859, 0.06056334515432678, 0.033696902119704795, 0.025771806812694958, 0.04634086921390507, 0.0797242881549943, 0.0676709442068973, 0.008984689709670361, 0.05432635140154631, 0.015185356530691347, 0.030576710273782094, 0.0286728362252395, 0.0825539181729959, 0.03112144475322097, 0.042697240132838495, 0.057603928350633195, 0.04133547288215449, 0.11610047936800028, 0.05288564262070483, 0.008628398495455904, 0.03807854200262697, 0.09098640883401518, 0.03525096893070206, 0.007779638671631655, 0.07865841470418439, 0.01702012944846384, 0.0465252167815643, 0.08103730157017708, 0.018757281697265083, 0.06704412340637177, 0.03055807135458435, 0.05087142126754888, 0.02446638915928141, 0.022472308257654793, 0.025282106174516584, 0.048057496051995024, 0.06458700364155155, 0.0338092259311628, 0.028445403872718735, 0.01939456534361647, 0.02557320426398468, 0.04801192148137958, 0.025330785316445177, 0.08748758569239609, 0.050222426052055055, 0.04332146772574033, 0.03542298248278038, 0.0075385651660091705, 0.032373270725891475, 0.03230280978905578, 0.01961490180673859, 0.022625845684219274, 0.030554966783271204, 0.06212514945335927, 0.04904507531694347, 0.035821658469015555, 0.03980141245729981, 0.04020355116095274, 0.039340196883366, 0.023455304401596228, 0.04656749717410534, 0.04105648664276927, 0.0485209945679432, 0.05280877335838253, 0.026475941206538872, 0.027347370050847534, 0.04409150483327047, 0.03775008180509171, 0.028319865044566895, 0.023592049180860483, 0.015848633540313573, 0.020340410053669926, 0.03393074662815179, 0.06559509108023298, 0.17105289314302707, 2.7816032305840523, 13.847504277383129, 30.499214933764552, 42.39917808963407, 45.86634151397213, 45.182715539009344, 39.124304940623624, 22.655245334871356, 17.451929084716305, 27.84609825380387, 32.383725527794134, 29.0263060985073, 30.746716491637695, 19.443965573464673, 10.377355929343931, 7.34450331618709, 3.2847800754731704, 1.5803391222030887, 0.43764807404048983, 0.2016287339070151, 0.2337399527670876, 0.3647748182617849, 0.05742752511474875, 0.12270100865392916, 0.35501403073149346, 0.6442280954891636, 1.299400461777564, 2.270664505420193, 1.502396601342386, 2.0213647859711803, 1.9501903148428088, 2.6407501822517765, 2.2814914728364637, 3.3107236123854116, 2.5268948078155518, 2.022483151766562, 4.177757655420612, 3.0082865636194907, 2.4434520208066512, 1.6230643973235162, 2.670007876811489, 3.114653152804221, 5.738600636682203, 5.993171776494672, 2.6460620520576357, 5.812274515628816, 2.4369857484294526, 3.8864902911647676, 3.1557544440992418, 1.8095121797054046, 1.20572715276672, 0.6248064795809408, 0.45210231456064415, 0.36020412320090883, 0.27845344055564175, 0.6492565127630389, 1.3341541323930988, 4.258450125494312, 7.0985937503076375, 9.204746696256823, 16.57097847230973, 18.346011792459798, 17.350096510302638, 17.9824649518536, 17.524945966659054, 39.92459789399178, 44.342971386448035, 31.447616584839363, 41.55794735877745, 34.92280713973507, 20.03629053792646, 5.070977932022465, 0.42989459008939807, 0.08735748098021553, 0.11737796162525493, 0.010280396241033751, 0.04468724927714756, 0.038133041497560284, 0.08777144425097974, 0.03134769541511853, 0.03983209044822762, 0.04529072354818064, 0.045620474603868304, 0.11049265447523325, 0.07394916498132291, 0.030652129714707696, 0.025976459540787245, 0.028647641508629727, 0.006121306336529914, 0.03918519814408595, 0.058348868417763905, 0.14091767550956819, 0.04529307160766856, 0.022843881968348738, 0.01254182842169558, 0.13450280763208866, 0.06364526707799205, 0.1021118364447067, 0.03558311018071348, 0.07144771936920381, 0.018991070664337566, 0.06018167632001062, 0.05323044347366499, 0.054517490338654294, 0.03854206350121287, 0.04687788918794644, 0.058574059963106155, 0.0997244843071507, 0.04219559809914039, 0.04268959074491455, 0.03277449012403527, 0.06910932025000935, 0.03285783282931774, 0.023016573508240046, 0.028482279514953978, 0.026293637178417657, 0.0435393967575604, 0.021116606508111282, 0.023022445572179653, 0.005002346344202036, 0.10747396927927771, 0.16373321413993835, 0.16080983794264256, 0.3609203847665941, 0.12359801334358993, 0.20390018460250672, 0.17778628505766395, 0.20658458733270246, 0.14245204236959258, 0.07874098366066333, 0.17007234656522352, 0.19551988751176866, 0.13453752673681707, 0.12733548053450164, 0.11480700119488663, 0.1462532633975629, 0.1888359082682479, 0.19750816146692923, 0.09356908274874573, 0.15915361713738213, 0.1263657511181889, 0.11794370223557758, 0.11140865814541617, 0.24377758915145553, 0.16170484314282096, 0.14203475427723702, 0.1627429842107719, 0.11515288223182002, 0.09438652154659072, 0.23035867049569086, 0.12571743389050807, 0.10972674275117536, 0.11358496838159139, 0.15292991884052753, 0.13186018733728316, 0.2288072351967135, 0.18976304319597062, 0.12446075858127688, 0.13184713319905345, 0.1201644532322403, 0.18725549952397424, 0.11456163855449808, 0.17554252077975582, 0.1346597330824983, 0.1344639976178446, 0.09488077849269876, 0.13524428881224126, 0.20826536891681535, 0.1388506630375501, 0.27502541159910543, 0.10967675551411607, 0.15189620576077892, 0.0968194712373999, 0.14395608746957395, 0.10613559835380125, 0.2858403667567238, 2.7212830608890903, 14.51039562302251, 33.38326115762034, 48.669698699828125, 53.03470050134967, 54.87199752561508, 49.91634561169533, 40.113707127109656, 38.674926834721724, 32.01994922853286, 43.09287671119937, 36.26680335690899, 29.011491306366462, 21.44709844743052, 13.95281207176947, 8.64082165302769, 3.776299881358301, 2.914271518107384, 0.9128467750645454, 1.1028955996997896, 0.7579354004513833, 1.128546184589786, 1.9975396966741932, 2.687716397546953, 3.868328001229994, 12.132182178958772, 4.899813052146666, 10.716955719455596, 5.611100071860898, 8.482362801028836, 9.656880267204778, 9.190422200387525, 10.346435885275564, 10.919712839588042, 10.835739797161473, 7.088238693052723, 7.967039356308599, 7.215862322238184, 4.876887779082022, 5.841103936395338, 5.715550338068317, 7.054091028628811, 8.450257220575887, 7.464528333756232, 10.59446107956671, 13.295283586748186, 10.00678216257403, 11.965666778625982, 8.764071349174746, 7.6571333792901815, 7.859461490185031, 3.9272118479974814, 3.819545238248764, 1.6749850564425992, 1.7230299235351625, 1.638978924001417, 2.231285870075226, 4.253247101460734, 8.562729224081963, 12.500869285675789, 16.391177023610762, 22.886082703067412, 24.16294755474214, 31.07971787452698, 29.34847193379556, 47.27468029145272, 47.68305393957323, 40.62303081635506, 50.68633825548234, 40.2080479744942, 22.926745914643814, 6.187409508612848, 0.5992144238083594, 0.1793469900205251, 0.32674786845041864, 0.24999558775415345, 0.16978806665828153, 0.1911794478374143, 0.20335557269713572, 0.1515915019497756, 0.15256398928261575, 0.17913364985537145, 0.10720985280650278, 0.13131090229557407, 0.20091811074845253, 0.1297854680207468, 0.10993007780803789, 0.12425360840655143, 0.2157537558025891, 0.15819884175735136, 0.14036633735222204, 0.23181135706122846, 0.1852279099365396, 0.12333424927126016, 0.1290977662128787, 0.19315613854315974, 0.25628955163542305, 0.14372082186802743, 0.19711748726906317, 0.14381957060146716, 0.18049049882158158, 0.1926428902774088, 0.22602094277258844, 0.20390888736132654, 0.15465995987817166, 0.14983870810078037, 0.09879306694793125, 0.24591958630950222, 0.16882661099155105, 0.19788919827870785, 0.12576598854314897, 0.14695391209135134, 0.09447000980857881, 0.13535771579031022, 0.1740880415684754, 0.11346524416078484, 0.14200663885041592, 0.18316431421666377, 0.2829799783085623, 0.13205048357767443], [0.030656448535380826, 0.0645191129297018, 0.01978061237041989, 0.018480168542854728, 0.028802452556368326, 0.06463453939725315, 0.03397652804250679, 0.048923995120510946, 0.05491664896028177, 0.08292708726179215, 0.014276594306612688, 0.051878045478294936, 0.0251728103255793, 0.11485763194580233, 0.021502239847435586, 0.017452321781386292, 0.04319900474060447, 0.09979751546897235, 0.12938618299461183, 0.03411438556448106, 0.036981193829448, 0.0361197815847493, 0.06316614036838855, 0.044552505902585485, 0.0660117433196114, 0.04936798137702769, 0.030776484937016523, 0.06921408277365469, 0.062392533291131265, 0.016149742483732202, 0.04462660192662189, 0.03110101318828041, 0.017157873972469283, 0.03431778956925677, 0.05331049200087305, 0.0324752715025698, 0.08286062913436083, 0.02311077359462938, 0.04123097082840339, 0.039353699183031436, 0.037807626499524044, 0.013973226361427338, 0.035821091563951586, 0.022927663258967862, 0.025153794108078848, 0.05099884084155483, 0.03626388655374608, 0.05498429835443536, 0.013033252757703586, 0.006394167702960512, 0.030952842207625512, 0.0793039893370963, 0.03962831872124826, 0.01739298635643096, 0.05929714354175714, 0.021824946724659493, 0.037510070288854266, 0.8075049663743665, 6.657414378658419, 18.86411178496576, 35.17844761571577, 35.93690849119617, 41.69983909976098, 42.36027602226504, 36.52297727523312, 24.974368272289155, 21.756757805424353, 31.384297763147664, 32.46762306459489, 22.901399558590306, 23.378481365019276, 20.197358746682447, 15.500876461305927, 10.672689810875925, 6.484137302444828, 3.942483351115258, 1.887265691353429, 0.9647962390895813, 0.5340656938572084, 0.0981874131567536, 0.5627145630217368, 0.7941209813279491, 1.0067864988119373, 0.9561317846659692, 0.5810312349950114, 2.010829789984611, 1.9926931180300254, 1.0683184357420092, 2.3299288220943946, 1.393520185543645, 1.5348859612018833, 1.715595561169809, 4.969876389349661, 2.388223577891627, 0.9236852644431977, 2.477358949761237, 2.4384627659474654, 1.6225061950183686, 5.819298009718619, 11.133024077261648, 1.434170771991053, 7.001677376608695, 1.7343033057066704, 2.7012868177506233, 1.1966520139286596, 0.7630918463391643, 0.44310930034806656, 1.5173147234224504, 1.0701864645365746, 0.8932533716001819, 2.069219908406658, 3.5402207557232153, 7.043384428947204, 8.698147093096088, 9.54193030634234, 12.064071201509046, 10.832261635411172, 9.37821645890513, 10.885826503076862, 13.69973780647401, 21.597786103525472, 39.476333741218816, 32.46211213450278, 32.787523731108635, 26.125795725853216, 14.391690973312626, 3.3871911994872557, 0.2256448089235252, 0.02491368874607067, 0.025936657442681255, 0.033428384471804864, 0.01702085723199191, 0.051091663884900274, 0.05955044285304124, 0.08496730197821895, 0.04517872915453008, 0.0889732753257117, 0.031302764358359485, 0.04109511662635111, 0.08108610137095375, 0.007477170879757333, 0.013378344724074969, 0.04668684601182899, 0.057106266143701734, 0.07250735686431009, 0.023810422543676633, 0.03435339733597732, 0.07773364698814769, 0.044242761233040405, 0.027659127616413662, 0.019478545817095908, 0.04153559803061428, 0.06730213415839019, 0.03203234244738856, 0.055640287952677864, 0.05764692886582306, 0.01008732388952687, 0.04911934371076284, 0.07747434154753724, 0.06287050703840871, 0.037880155873755296, 0.0810597479463585, 0.07255087831928846, 0.0351619380225818, 0.0507023839670564, 0.08507717430831925, 0.027658566457009124, 0.03628131505402346, 0.025399832821060574, 0.05306923559175865, 0.021523588802665476, 0.034864121342017766, 0.070117698802102, 0.021064378463873462, 0.021454052916998347, 0.049678484473617814, 0.0647337171399305, 0.02356584322819066, 0.04731527176655589, 0.023469086323354035, 0.03760576999235538, 0.01712895032288807, 0.05583264496958545, 0.027498484724351478, 0.05109731378334184, 0.025503917356892943, 0.05831366667764322, 0.051103323743107824, 0.05950666858904785, 0.08232355553416476, 0.0069579504798316675, 0.013713129935035063, 0.04162903777473877, 0.0935792793790179, 0.04744362213738984, 0.07136059985045465, 0.03546378432562755, 0.012907065627645823, 0.09133256566260131, 0.029039422703546383, 0.06674625309965303, 0.030441398078936244, 0.04112641131805797, 0.0475652807302052, 0.09614223419057746, 0.03757510349274643, 0.10803190345365195, 0.04725594591769961, 0.01915731557434605, 0.0030027859986970023, 0.053335558397755514, 0.014741718844180147, 0.02748467024385689, 0.061974080745130784, 0.03061848504829311, 0.07185461930930614, 0.05795992174816709, 0.05197472960477875, 0.025589228908140815, 0.01970184512526518, 0.020616768611474864, 0.10901210529188957, 0.008298374520945213, 0.06326424941841154, 0.023124296961712743, 0.015574332886195232, 0.024412514026006384, 0.1016658736813453, 0.0360430923530892, 0.0947147519177487, 0.03827440770222776, 0.09024672796048465, 0.16126589008396672, 1.514208451394112, 9.538853206942159, 24.749632150896137, 41.70788780335457, 43.152139802132886, 47.62033131814773, 41.61495900923207, 34.739687365870324, 22.248295507123395, 23.489394226381858, 33.82917188828991, 31.26845056010831, 30.915456856450728, 26.530837320512344, 22.734345812951368, 15.273613352929393, 11.305677986914112, 6.0479702295795565, 4.4486360492244845, 1.611308073324542, 0.9824330539953325, 0.5132088888316385, 0.19983919848117138, 0.1573638365634026, 0.24755035767391806, 0.21677217776736907, 0.2633621519611728, 0.370010967937208, 0.41608671327271773, 0.5965023499823386, 0.3443708937735327, 0.39039350325061434, 1.2422740819954103, 1.199449521879996, 1.66800826307266, 3.146622676041819, 1.8778915943637973, 1.4813805419591166, 1.1895802256561097, 1.9489437365724196, 1.104008939958388, 1.7156566030556157, 4.765362047380017, 1.2863044032166082, 0.8210182670624027, 0.6445775541567034, 0.8783584160189476, 0.3426504441567006, 0.3515445104529781, 0.15528982204775657, 0.23500182215244542, 0.5848004488695053, 0.5400223032601419, 1.9314632036032218, 4.1615058049078915, 7.745787770517412, 10.704622807041293, 15.309516768301688, 19.01324422128739, 14.15195276660304, 11.827394404718953, 12.98301193021959, 18.03482859365402, 23.622329235076908, 43.34116274310697, 37.015391626665675, 36.145649187026486, 32.17171749761028, 17.720211359762377, 4.5461422493380885, 0.3058172125489481, 0.1013963945931004, 0.005794248079896094, 0.05783392326726068, 0.08216392579338244, 0.06585604360988064, 0.06436386521184637, 0.011355197488991244, 0.0450971407905942, 0.03237780979684284, 0.038717344418288245, 0.02909875812850172, 0.05685420023397573, 0.06017257902590979, 0.026999252037175243, 0.03301584229414021, 0.033866851064827175, 0.030081449752493255, 0.06357772493614786, 0.060522868898847414, 0.10625796557794656, 0.030908912810827457, 0.03168250265110645, 0.035668586440865076, 0.03466367060619016, 0.06442750413571635, 0.015064235157032889, 0.013863399996602488, 0.05788920800231638, 0.06453920741595569, 0.022500065538371285, 0.005355231818788115, 0.04984960553326434, 0.06549225909815681, 0.046847096283829985, 0.026339935702121547, 0.04053803280957284, 0.05868101732865457, 0.019284055245319204, 0.007998003415958656, 0.022309279001708475, 0.0276739533329683, 0.019706252046049606, 0.028363139436189688, 0.002301733911735937, 0.027469769833729635, 0.02027428325926585, 0.04039285531748207, 0.029509015448932207, 0.13590055037169688, 0.16731737181544307, 0.17041929246437165, 0.08005343017078216, 0.1379125117654762, 0.11710626088202962, 0.15231278905224416, 0.12227732372740585, 0.19938568975175583, 0.19861673665863855, 0.13855764972827128, 0.1577897354840271, 0.2267026231293717, 0.27399560556777064, 0.2561235097387145, 0.06027317403124706, 0.17941940065112807, 0.28310273623754906, 0.2531796789938404, 0.19369037761803598, 0.2501371608025605, 0.08383645661055081, 0.17343276060156285, 0.10807743205899194, 0.1355887679082732, 0.20379866263078106, 0.12167710916049058, 0.19118735386479288, 0.15557719694991268, 0.19607741565954304, 0.23991871234630388, 0.09247977466833207, 0.10592900742326053, 0.13218047337666636, 0.18063619342302123, 0.08689801974762833, 0.18043452843783364, 0.1323575775830015, 0.07081590367541199, 0.1246209782097609, 0.09538386843257374, 0.17895646904024387, 0.1382317252817654, 0.13722801220513162, 0.08858872983123987, 0.13133540178739256, 0.15529952072087796, 0.1265990248911323, 0.10424457159974884, 0.09585183324112047, 0.11229811686902277, 0.15705271293559384, 0.1778407385873218, 0.10743146672123864, 0.16963869483480531, 0.1352074093395664, 0.20920505236473777, 1.2475643787653217, 9.464830237050212, 26.129316053082867, 48.226494404577444, 49.92698307960264, 56.72829843336537, 53.49044461404124, 49.53477744133242, 34.3107722651574, 33.54563551564371, 43.26653965057866, 45.05477174635857, 34.54606348468412, 32.7284332244627, 26.590382822098274, 19.392702156497588, 14.40741869711107, 8.859585965833357, 5.9076886215517606, 2.3533206120614083, 1.7935873568058016, 0.8720936554093516, 0.315784169661422, 1.0679160250771431, 2.1512871692257542, 2.5726318503579786, 3.005661762529804, 2.803784969352907, 4.39239808628636, 7.381141195374151, 5.50146492258195, 6.490015464444315, 6.482446270604288, 6.807599971371313, 8.172690695331942, 13.782224270605273, 5.754778452457921, 5.69589828291247, 6.213860992462405, 8.560628794854688, 7.943308526469816, 12.218241922317013, 20.76080526075056, 5.246615294487246, 13.151860160212363, 4.785024889053838, 7.2900696435282315, 3.4930684729929897, 3.3479243516922, 1.838811549448198, 2.5315482097287334, 1.606820268977073, 1.5851003892960087, 3.090844365858263, 5.50445229776444, 10.600013194545623, 13.173835239102765, 16.15897467059474, 20.877574220780406, 17.71194104225405, 16.07497613276205, 18.457614990972704, 23.419121042374645, 31.30402449638613, 50.328410210147986, 41.56250123054751, 43.0376575839135, 36.41075826460315, 19.784543014341786, 5.47804101820915, 0.6423424773158566, 0.1775433738986331, 0.13763066801813342, 0.1688668918946097, 0.1241494587532455, 0.19093673586124377, 0.29015227731677795, 0.15066491860535838, 0.07903225795035401, 0.32854419141527147, 0.05525185456199031, 0.12878468139998375, 0.3082434130051444, 0.08245166841774218, 0.11319440909691396, 0.10461702822677552, 0.1472083145692464, 0.16260985345129045, 0.17716606027416645, 0.20134621600229896, 0.21544310714929335, 0.08726781038867851, 0.09722893757204856, 0.09525531887887947, 0.13682733289897442, 0.11795616648610562, 0.1514407358462772, 0.15399346338404765, 0.16040548141444885, 0.12780671653848502, 0.1378837681465572, 0.08179647938138054, 0.27354333790079244, 0.17496464533671258, 0.21182916397529267, 0.15304831006834585, 0.12145510454091335, 0.0921831147805337, 0.15605034817370678, 0.10988415849785652, 0.08406740147620441, 0.14492308961287623, 0.10146875159754869, 0.10326290653357584, 0.0914394119454007, 0.1419574560056771, 0.11931233363406313, 0.1329550955204233, 0.11341723343057018], [0.008463475087116803, 0.03062925432928868, 0.04597847132132419, 0.08567833882426062, 0.030169814164119384, 0.018960065170822125, 0.0544322822092762, 0.025005996595287037, 0.01230957737613109, 0.04782424143124973, 0.01800428046995113, 0.016367175473621296, 0.07781371083711425, 0.007138941624772645, 0.06151270429273287, 0.030763220124607606, 0.054685321050666036, 0.08809239678685704, 0.03891458524571311, 0.03467991550062453, 0.03375352367818837, 0.021931423370035428, 0.05543394983115216, 0.02408221904789248, 0.025632840378450292, 0.03949443336516138, 0.034561980095121174, 0.018970039635596257, 0.024265750731912353, 0.026886807566869165, 0.026618236292814536, 0.02710033542356424, 0.06435523906181898, 0.03377464472226078, 0.0965822980769219, 0.04852634186165468, 0.024792734954145648, 0.048459795634112054, 0.01635607294437866, 0.08427655114041221, 0.025849239149641608, 0.009989483927887295, 0.03554465639735422, 0.0213758161877312, 0.02753845153136119, 0.006994707378438644, 0.049612792434110764, 0.05735819798804099, 0.07329838095052589, 0.009260762899723506, 0.05100431070933419, 0.08866449592695122, 0.03426447368016647, 0.029504575969411, 0.016635423075527917, 0.0444397186079333, 0.06665022397834448, 0.059994203113620324, 0.423578808024045, 3.024020661269465, 12.360701426382988, 30.212038601598433, 43.729312650619015, 48.37237127365605, 46.73162814109556, 45.81686473661854, 39.054667180584325, 22.95037623374693, 25.01426858286704, 22.494283030110022, 31.910303292735932, 41.38541798437796, 25.65244213227303, 23.428844598031816, 14.64069381836922, 13.896108327373383, 13.26324272540308, 9.275103230630199, 5.255443569152586, 3.9049707833797704, 1.9830288882217102, 1.3598829195384057, 0.7466351745590087, 0.9144416475488294, 0.7115770912458821, 0.42844450822280306, 0.1537130598820025, 0.6338962047330795, 0.521378971395954, 0.9043629335299616, 1.2387283819337045, 0.4205632101624243, 1.214514119971183, 1.3029187052480637, 1.2950156196471185, 0.26981509440848905, 1.1220596874913862, 1.6450217029740735, 2.2188835807384986, 2.0755341889396792, 0.5283546615992823, 0.4661574232722483, 0.6243391659471297, 0.8211398605377445, 1.1111855290589796, 0.6884677732183088, 1.271345586546006, 1.3853970794908463, 2.7171444700610254, 5.722091380626925, 7.373097394743274, 11.15904410039225, 10.997369885444643, 15.916828128599352, 16.65048295451749, 12.366536932606852, 13.406978960960144, 15.890260934829714, 20.490044047755582, 22.336584137332057, 36.83326813482469, 33.39252579596735, 28.260196601190877, 18.048197992386356, 8.23208910803641, 2.2352835007252234, 0.10448420390246377, 0.04463557664665484, 0.027689104636890755, 0.03788646077737212, 0.053211425340944724, 0.019134539780357195, 0.012884686284157778, 0.033379224609703786, 0.05096380381033786, 0.05555930096776255, 0.028478577395059892, 0.026955533314556367, 0.02157358561582383, 0.01901389050838207, 0.029920898790981983, 0.04533916328763289, 0.018012270767001376, 0.0073753975354315295, 0.03987748498818086, 0.05951513003017153, 0.03330619344788213, 0.038213974856320894, 0.004954316940594224, 0.0441821598477902, 0.043493626834524256, 0.08986567582694754, 0.019016545003039703, 0.03560339618894843, 0.037102492360938946, 0.020468124571526726, 0.046287097502499826, 0.08167273319897153, 0.08835418435234217, 0.03871798027126539, 0.07372710673559098, 0.03662644149435144, 0.02668803073315611, 0.041687114900278474, 0.06237947149202228, 0.07160594716908471, 0.09721134053242785, 0.057733749610281763, 0.04118736893419297, 0.016599531856275374, 0.04362670779829064, 0.057249371367957325, 0.03642435516080549, 0.028990753137716846, 0.014961833141804224, 0.021814732857409026, 0.012530902092675529, 0.06256117605634275, 0.03102062758238566, 0.07730327411404542, 0.08905208279048243, 0.04787746538978912, 0.009959284741912159, 0.069976095110178, 0.05404660290467644, 0.004560234609075012, 0.01977886568995253, 0.008319811576286392, 0.06532374273745284, 0.05040360201570777, 0.027608251717362194, 0.060860610251585325, 0.06358099996202415, 0.059960039422637036, 0.03551171078617054, 0.07923698728723873, 0.02331070913632791, 0.012487003339394447, 0.026764296701238043, 0.03071867594225032, 0.0416228860887068, 0.035013845565939145, 0.03194781805148288, 0.027034001785420606, 0.057776738634152766, 0.026340205748114857, 0.03145207872524137, 0.028956802036132545, 0.10348428296105516, 0.04055353076828103, 0.10444782238693968, 0.04612063808787254, 0.05234877586424832, 0.022466055064972852, 0.049446436441353256, 0.1650462888421551, 0.05119411665345392, 0.04153582402655194, 0.03532408819263501, 0.1239468438190318, 0.082760363546831, 0.008817625085582897, 0.05782620110098393, 0.03589713728175529, 0.11896700418043522, 0.018347662145031557, 0.030006660418885372, 0.09649962186813356, 0.005844426838936465, 0.07979459204380551, 0.04339455251371668, 0.11261700096750453, 0.04634075430071643, 0.04527863851117511, 1.136330128196747, 5.020710797079149, 18.462831743301884, 36.32059081908196, 50.38564935807259, 53.53067636489869, 53.299346739246005, 44.40027721466557, 33.13430832278344, 25.78725007272536, 26.904490147867513, 27.35388590443519, 37.36982876254667, 45.259017405971406, 36.720319563342684, 30.739467951559252, 19.766482460883356, 17.14951434443074, 13.526720096988063, 8.705056348154622, 4.528313606016098, 3.1350556064036588, 1.7659080485182426, 1.136762569508245, 0.7491567682835364, 0.4456462771181138, 0.14236645502669198, 0.2638936944065556, 0.2245769130005952, 0.26868097784538425, 0.20824364266328274, 0.1408048001148047, 0.16826932799191247, 0.2534882438879821, 0.3044962318193528, 0.19306102106648107, 0.23532750145081552, 0.2512876869690034, 0.3717236953877634, 0.3619712122505711, 0.6363611692382444, 0.5546401801609224, 0.4017930141379757, 0.27935610663506294, 0.11672770619512567, 0.20575318275199783, 0.25506618582913954, 0.5111128416272902, 0.8432975747892935, 1.4983407480101434, 3.0317997019137106, 6.659703571950236, 8.891843538130484, 12.391360632834896, 17.453951066540135, 22.163901790495842, 18.68135679152704, 15.12466428741332, 14.042346054507842, 14.356609294491431, 19.956544829953103, 22.406553337650916, 38.01311316028718, 41.148989277501265, 31.93116637968248, 22.824324984704297, 11.878348935034968, 3.116154439987675, 0.07672133074412424, 0.06798181502569108, 0.025649280625305353, 0.027557098111438177, 0.019425404213008382, 0.01596213042390563, 0.06685000438723834, 0.03883441414443716, 0.023413479831370137, 0.0034574840796150028, 0.012019198451701914, 0.050734617116470496, 0.039074080921108686, 0.11515824484728998, 0.027124852152361024, 0.003083914231073352, 0.04514809712887772, 0.02924696741355283, 0.05671161977994827, 0.033691849769844164, 0.041497730304517096, 0.037854043766856194, 0.03698844868209093, 0.06603460338327193, 0.061174200682510296, 0.07009990257962097, 0.02987895930756725, 0.07159754318455536, 0.022835066211560083, 0.04334350807532188, 0.04176544356009653, 0.015759908109753123, 0.04570032011777644, 0.03279014513076794, 0.048550013978514946, 0.10575889759967405, 0.06106825455302193, 0.07078329131247536, 0.01311384137689827, 0.04838199557496175, 0.08706688084789822, 0.04769428227577479, 0.03373299252181765, 0.025006785665849046, 0.036589171316835194, 0.016623048840330976, 0.038142525666062875, 0.05473446559100863, 0.00771978757374229, 0.005243574025019283, 0.0899332677645068, 0.1878723381988464, 0.11691884513223365, 0.20988319339531086, 0.1400310819547984, 0.18681927373813045, 0.1267405136698677, 0.13716762915493982, 0.17263474213259836, 0.07881596834669191, 0.10944870646081625, 0.07815095040226176, 0.2747865147407978, 0.18493984555525167, 0.13120179605339805, 0.13926899300948267, 0.19000100542701062, 0.12311514812491595, 0.16947855181511373, 0.12805012565466667, 0.19293404965391084, 0.1463413022218212, 0.10787684725777757, 0.14362337548405896, 0.10355182893333897, 0.11815230031647991, 0.14243491264360567, 0.1592364772072723, 0.1961576097434567, 0.14122389617466158, 0.1424985285848379, 0.09493205275747085, 0.2773786804849102, 0.12393554402214867, 0.22057139164497777, 0.1521348421491923, 0.1829356829365415, 0.12150464744697656, 0.09464730553689504, 0.2156903084007002, 0.14465690470270573, 0.20176370327751483, 0.11525760645106917, 0.12800240603786323, 0.23663240965575943, 0.07279568171549229, 0.14530403449410392, 0.11941365642292846, 0.22595778648411075, 0.10113643031687507, 0.17800583053500424, 0.16156601268918286, 0.09720296719141545, 0.20030326390218353, 0.16763382741520483, 0.1302939665413672, 0.18298170949903228, 0.1674098386279037, 1.076909774734128, 5.372195859109202, 19.19363598669729, 40.35407389363935, 56.53671418466876, 62.41680991265082, 60.34217811399891, 59.20794240890011, 48.886044871422556, 36.63316842048399, 35.4719977994119, 33.42631701500186, 44.25726367581276, 54.67654581992857, 36.22194713161838, 34.116767914064475, 21.228504757727347, 20.12539109876079, 17.119900449629753, 12.626182148533484, 6.797738152165567, 5.362322763089211, 2.812765971306832, 1.9658110314799895, 1.394428336812604, 1.6880309822097903, 1.2698072819940507, 1.139470230667822, 0.5419075537112452, 1.5163641615260033, 1.3312410370957468, 3.1205938275783294, 2.472151758209352, 2.1825236995374007, 4.153685579376837, 2.8346782922744755, 4.409013246336292, 1.2216889930348243, 3.3117819168875298, 4.129886108060037, 5.04772465075216, 5.5775481174069075, 1.9078713727574197, 1.9186536006389128, 0.8977668552148728, 1.3872321358611508, 1.6739502861615152, 1.4364765127820354, 1.9838239036260115, 2.38751117740908, 4.713963308641988, 7.476131685318486, 10.636279429158858, 16.274504161650135, 17.315175648658506, 25.2244056424787, 23.8743003337614, 20.80160967765316, 21.754684832788286, 26.631852080745084, 30.84860594041886, 32.26199673068139, 47.87261032289075, 46.693255593699796, 39.37433250488774, 26.582822453591135, 12.93013838029677, 3.444911818350515, 0.31415335233173064, 0.20719767217674565, 0.10323273799111767, 0.14248792592796589, 0.24903541911513577, 0.10258013067106087, 0.20476139000346585, 0.09223897791197223, 0.13108266938117244, 0.11422131165501573, 0.09639930265444903, 0.1692074945857448, 0.12624196663138368, 0.20758309101145114, 0.11737780840767008, 0.07970098376033768, 0.11652214948328272, 0.0841324040365796, 0.11412863033793627, 0.1630310945573353, 0.11366228963578902, 0.16990331692561028, 0.12101117957143054, 0.13643474348129767, 0.13023401250041303, 0.1744728168893245, 0.1304807234555483, 0.13171084615732395, 0.14603023988104638, 0.21099532323498882, 0.14855138927457795, 0.22795837913309375, 0.17371845011028553, 0.2037011089945032, 0.123350934666251, 0.3161637815496614, 0.15933810643130736, 0.17154174916926893, 0.23219657671307367, 0.20438827454082428, 0.26402512445084514, 0.16923194811228784, 0.12486889192293729, 0.09902698423473105, 0.15238837128685367, 0.19763802869185326, 0.22349715803659734, 0.08766321900991664, 0.08880608429711673, 0.04373743431642652], [0.02826416279159246, 0.06991141430673099, 0.024861801610959154, 0.03213177682952054, 0.04386188529972588, 0.01890387070635634, 0.061803101411750244, 0.11227547897086029, 0.029993372623838728, 0.011735405010591832, 0.032992177838159185, 0.06349152855334744, 0.07240482365652438, 0.08865850511938335, 0.06020563571984249, 0.01165919458388441, 0.026574609500746575, 0.02998101371040027, 0.03142663694527601, 0.03933438993689995, 0.0069832644188746575, 0.03139471597669106, 0.0722730488726689, 0.0672702802224986, 0.08181427560386159, 0.009701138009287177, 0.032770353249244155, 0.021050841690251426, 0.02097227171273722, 0.06262421743163178, 0.10611178834111461, 0.12223434619485371, 0.0648942202209465, 0.026366038232921597, 0.05318707523627147, 0.029355772966218573, 0.033722734604511535, 0.014735289451275623, 0.0662949660252179, 0.07129517594172109, 0.006144977495780276, 0.06041373967403366, 0.04993488261055562, 0.026007465034302686, 0.023432532438046993, 0.019664571117309314, 0.08426975594052384, 0.03587354177368745, 0.03397841261880052, 0.025102659654352936, 0.02111553206979748, 0.016812881597528057, 0.04709237465454687, 0.08625148750481107, 0.03633985566275735, 0.029791602301561547, 0.020358761689896067, 0.11864572988762973, 0.10569148952321661, 0.0601688405168393, 1.2252318738929688, 9.555954740893457, 20.485496059540782, 34.612531969624186, 42.85352583854429, 49.65866942559519, 55.42081948249571, 43.10581268802766, 30.898312176427535, 19.3661633999117, 37.218703762177505, 34.80655593256797, 21.38936900323437, 31.118863128846694, 27.020641334595222, 28.644326079276304, 24.08680062140188, 21.37595057487488, 17.578656942613666, 12.755562509259871, 10.047134526314276, 7.873111338384691, 5.648756296403947, 3.1946925482442303, 2.7051537844442555, 2.000773445733132, 1.5861760993157665, 1.2937866920425047, 0.4916819713769421, 0.3579235100938428, 0.6827240136842574, 0.5344749073828421, 0.44918146645349843, 0.7868982430907988, 0.41143337264657026, 0.5551032037023576, 0.7340064296318639, 0.5107497772382152, 0.48347235867573374, 1.0799195809710411, 1.1224586660823515, 0.5662693948515001, 1.4087942627168473, 2.15484794589781, 3.0472219711349857, 3.8611194202976846, 6.731576592691484, 11.02184449472735, 13.4719471393093, 11.086847974408059, 12.648150363276082, 17.470199484978956, 14.148041182948699, 12.45575124217618, 22.430632768138764, 22.50201794408983, 20.851555178242346, 28.964475816295995, 27.46268656945998, 32.353060437786965, 28.536556997606834, 20.70971638925614, 13.721605020184672, 5.133212708657788, 0.528268859751763, 0.11045638021201858, 0.051462791349378326, 0.049472740070233424, 0.05035601646429108, 0.031338674729810126, 0.03617882015063398, 0.040835068080454104, 0.029697647363307978, 0.05321913218546299, 0.1363192940311086, 0.10977266206135673, 0.009723067276119705, 0.06244256649346602, 0.01530931147205974, 0.020893040984388322, 0.034740206620265404, 0.019961280800822764, 0.033453906691002275, 0.006060525399422454, 0.014972614871728566, 0.02902925097113175, 0.027378285529031873, 0.04514953737417537, 0.06669959068418511, 0.050326265439751654, 0.029557267496843013, 0.07156223419212526, 0.008173563476321439, 0.033306756522506475, 0.017380765338818875, 0.036127438633552486, 0.018945344791357076, 0.01001707171165054, 0.031712437536747705, 0.052516353767245054, 0.05519572329977828, 0.05204676485229885, 0.027894801159779874, 0.04381352599950568, 0.023617381793296626, 0.021891559984895493, 0.033285719748105735, 0.032669727600389914, 0.06334899406459543, 0.032669011308180715, 0.012295454545246979, 0.07273378947208967, 0.038264299172066876, 0.06274573429818116, 0.01541592218282242, 0.04166422419310097, 0.028058173240072308, 0.04397199128664309, 0.014833898373669194, 0.034777086092940265, 0.053165831618131175, 0.05419739199081256, 0.07657500028970742, 0.02770286166079102, 0.07507996438371559, 0.038422412058759126, 0.018178689962012634, 0.03389072236454776, 0.01901456658097525, 0.010208697114590435, 0.06374842464743603, 0.018374174532871095, 0.08258331296665054, 0.006754583821842268, 0.027059562309014223, 0.035148301657529614, 0.050586543812025944, 0.03211720392198092, 0.0045192642268844915, 0.010167687470393797, 0.02839272766704521, 0.0015487459712594208, 0.022300817560584798, 0.03680563329028026, 0.03156864666379988, 0.07411721402839308, 0.0888522717380716, 0.08080516926824086, 0.0577065688107283, 0.02376199046510362, 0.016310634354369778, 0.030759021962782553, 0.019774679019446337, 0.030126009256609028, 0.04029097711487163, 0.047160311331672054, 0.013246389909557277, 0.06270811555065936, 0.01375626547322158, 0.04717799264096445, 0.015898794104765742, 0.025368375335669806, 0.08840681459274023, 0.0772814023038072, 0.06088287276666492, 0.048139754742864645, 0.025407476463325085, 0.06284416893557196, 0.05351398793619968, 0.059757481945017656, 0.05537088930366501, 0.03482757894802959, 0.03678481868137756, 0.05835846749945514, 0.08147647679452935, 0.06989452206800062, 2.0204061341862527, 14.554994933066832, 28.311006984403058, 43.98180738572152, 48.17670775998024, 55.842764531412435, 59.5255994796753, 42.60125860091179, 29.381802274334817, 18.48857033637262, 41.50141031511369, 37.72652910601708, 26.638165135537427, 38.05077183631159, 31.442444939767164, 33.12202345940375, 28.5706227825534, 25.11900959476348, 22.21582220446679, 18.78371692472889, 10.692170262336733, 8.84424557608943, 5.267461711360562, 3.2802345387397276, 2.352010540423855, 1.9954418415023436, 1.5655587733753267, 1.1829376917692924, 0.4101172335926564, 0.6121418204519057, 0.3642536639686554, 0.4268586449325085, 0.3166577243997205, 0.34009986166511813, 0.42171709179397554, 0.6380002909610349, 0.4702960447438302, 0.5292316790549986, 0.3612507525230608, 0.4339748663046668, 0.7084063452578361, 0.7564167690373237, 0.8302529973368492, 2.223253836554866, 2.6944457138738325, 4.518940612193077, 7.440536176004718, 10.583828514622105, 13.595096815016962, 15.577099880864544, 16.388983438091895, 21.988838564965036, 16.941795426030314, 15.12195687140188, 22.51815849734891, 23.763220771666496, 19.752769854760942, 29.87924510432828, 30.091119773926277, 36.953849638662035, 33.9037283005253, 25.64291665630956, 18.92464964620529, 7.442363019912475, 1.2138779605588605, 0.15422279946506023, 0.08423562672349715, 0.06113090522346958, 0.04596449021670607, 0.0354958642574568, 0.01206233015944881, 0.02329650203577213, 0.04720503171425193, 0.03241376230312932, 0.042128956110607234, 0.08245870876576632, 0.03815242352204458, 0.03782893906557753, 0.02912454656325281, 0.028272649130573677, 0.0324733026566044, 0.09738561787432241, 0.054930158920826457, 0.06052175807135721, 0.02487011941059703, 0.03872544962852713, 0.059262880259343696, 0.02992490160038635, 0.043475233063462286, 0.022809231811533534, 0.06570968251194685, 0.1843857341596196, 0.01981289723076888, 0.07472543421411708, 0.04303424221072947, 0.004727653070022503, 0.08867873750146359, 0.042092651203875585, 0.018425345375773408, 0.04783337319930715, 0.02603440834659963, 0.06103199178112611, 0.04288382467723662, 0.040418469467230385, 0.03619603797673218, 0.018951680338490876, 0.053530048969532215, 0.04965963104980127, 0.08969142912856995, 0.07517776316812924, 0.013150951633560322, 0.06565251703103704, 0.07532672896500557, 0.04281909790851417, 0.028907276367047624, 0.020877456840788646, 0.11258659493778983, 0.11846594437355958, 0.11538109216358393, 0.11605036189599384, 0.12217625374755553, 0.13044776635304575, 0.17954028932557953, 0.19484016834007156, 0.20374034801798485, 0.1054363822444312, 0.11045088736160148, 0.129424303529724, 0.12778147394137998, 0.10949621923388013, 0.1994238256086265, 0.13922489698856108, 0.12196784718863427, 0.15638788651314475, 0.13624792528008262, 0.12508786283433437, 0.11843176919125742, 0.22050123331287216, 0.16808152919815433, 0.1575281317796438, 0.20291372382592773, 0.07917386930315726, 0.0986166445598487, 0.11759546930871664, 0.09915212469716227, 0.24389466270804408, 0.2855012655979203, 0.20792269778828468, 0.17321068703407244, 0.14158219549684756, 0.15071629246156062, 0.14454073512986784, 0.1110365232753177, 0.18861907474215955, 0.14721868739974114, 0.18691616853879345, 0.07920666552719571, 0.1618983722742527, 0.06643488432370848, 0.20452842266569216, 0.18505676589425535, 0.07797499532781302, 0.1714074079908671, 0.20258108844920514, 0.11173648248997428, 0.13530750638775288, 0.11070158963482227, 0.11586933531948637, 0.15571826438028968, 0.27899589209306624, 0.13746245043171992, 0.10070477041505999, 0.1632785256351194, 0.2857903258935098, 0.20549965361433647, 0.25328095581743026, 2.664360154059626, 14.281650839313386, 30.52958976837897, 48.47379199920162, 56.245693929733775, 60.42305738695207, 65.87228467387538, 54.19364713853406, 43.81368675539571, 30.532339349869762, 48.96262914903703, 46.43737977550876, 31.428263610409154, 44.159326014980195, 38.4569921032075, 39.138578445680686, 33.31405093592982, 29.102923716268233, 23.844682516590243, 17.286436442405947, 13.64680051803589, 10.42617472910112, 7.859072194945428, 4.463786694311327, 3.508224021042547, 2.788223210842379, 2.4875286750255095, 1.9139993407072562, 0.9916756290101236, 1.1056223824139566, 1.118880606466724, 0.8909346992450377, 0.9853641676806635, 1.2346765735457021, 1.0982778668403625, 1.2512123055996434, 1.744451335360927, 1.415565009078672, 1.0295537739030778, 1.4271094025142732, 1.7555803252804665, 1.2803937590891317, 1.5609753612549075, 3.1214918051996543, 4.616960152502983, 6.573811019620588, 9.379542220023371, 15.110011293042092, 18.214649654203846, 16.4520816264614, 20.90583489787194, 27.80141265161576, 23.532189246146913, 19.354974838995165, 31.655476708565992, 31.870051930027625, 30.233405713112127, 40.14092053136518, 39.5067987903472, 45.647991011219645, 38.9121792393346, 29.16619350833278, 19.38440634358314, 7.875101450950869, 1.6129131807434944, 0.22520835331130415, 0.18973650591027355, 0.17559795490195676, 0.19968743646337142, 0.2918512151846963, 0.1662758139953498, 0.08272506221528016, 0.1499010676578168, 0.18824859462197752, 0.17254523241952543, 0.13021853752434254, 0.1235891650280645, 0.10533976323542096, 0.09615890426380981, 0.1316742731198188, 0.13241442130698314, 0.2768287519293447, 0.22358475252985957, 0.1888957397351342, 0.18968880927610784, 0.2432054440460859, 0.11927500216951294, 0.1545624981724447, 0.14878262525364278, 0.15804891835056967, 0.20934949058198163, 0.2425481865723287, 0.07079990775955301, 0.1465299896775715, 0.16158324966747917, 0.12389745413055345, 0.17343755631196886, 0.18913026989227344, 0.08686330830377918, 0.13135509024704659, 0.18174744992246553, 0.15110468371741234, 0.09770650912316577, 0.2102243936350269, 0.1384836303130273, 0.18378142868318867, 0.23807988682341194, 0.11070823927800502, 0.17311451235605826, 0.20301614978140403, 0.19563097026078932, 0.15263767161917302, 0.24448738493505986, 0.15593993958205948, 0.10010570498003114, 0.1093191380101827], [0.03126090722939661, 0.04014552766156774, 0.012984384009013734, 0.07952283001354626, 0.02833285598054288, 0.04174441444657503, 0.046333319417411284, 0.021730141428809975, 0.02144731325848449, 0.014146947331966893, 0.05810695700347424, 0.017788153659972935, 0.038722956012333595, 0.017208380234097282, 0.062195901503606196, 0.06278384717241411, 0.0652692202598818, 0.026014258318971244, 0.044326536778000095, 0.12381626413233819, 0.04399798464991393, 0.021238973732256604, 0.027412384102541595, 0.026627934965935927, 0.019039410812359665, 0.03578102899595134, 0.03065620721768468, 0.0400045981270171, 0.03741256261785184, 0.012178855963171491, 0.08618339761010102, 0.03417304491684322, 0.06455432999158098, 0.04072350269604114, 0.055350794817411134, 0.07828961997743576, 0.07980606038003199, 0.04521287369331525, 0.03513155114506522, 0.033122110180556774, 0.023842356918800264, 0.04687234271137465, 0.026821274490606402, 0.04186601558279607, 0.058477460106294, 0.045162445955699494, 0.04587005838871964, 0.041482044654267455, 0.027283116341418317, 0.057088550360452746, 0.014662508225639262, 0.015391258939710117, 0.0032494610434608356, 0.04209775334945129, 0.03501271941669045, 0.02782052702030107, 0.05183913204218111, 0.023713320899274082, 0.055929597226842764, 0.03879280024839025, 0.07311018379104715, 0.363933623077408, 4.33059084799982, 14.212623988428424, 28.29684134452574, 37.77338574009557, 45.42556908822829, 54.45263731864191, 52.16461289313532, 30.50827757004769, 35.86045365179739, 47.54910499818864, 22.70518691309037, 26.70625355935866, 25.22209732763229, 20.723207381463823, 22.045814914088098, 26.56276345252991, 24.446474121462916, 22.392785818346088, 24.654100864164292, 19.4368915788589, 16.550342882833174, 18.885647558396865, 14.91056171155745, 12.533530862100664, 8.550525749883345, 6.46178420512907, 6.780871470128337, 4.774797308829523, 3.9295794886927453, 3.7302897437926266, 3.265344240973073, 3.1356231243379655, 3.355158182882494, 2.76734737619277, 3.4425652603949275, 3.343856118379101, 3.5386616135797198, 4.507090641606239, 5.572860394754718, 6.208200522007481, 7.863574585606975, 11.66904635967747, 14.054569140557321, 14.565874607332292, 20.123951588907552, 18.86050516559232, 20.18021014428908, 22.538899990820116, 15.752780879697493, 16.458067163344353, 24.34962687953826, 25.466482562403527, 22.526874003871797, 27.16306063436693, 37.187313033688454, 30.333145703038863, 25.583078938145793, 22.90018754620706, 15.359402452745746, 7.174698027872271, 2.4092911183834076, 0.26822239761391, 0.041215384769583904, 0.04889191135824208, 0.01962452004062793, 0.1511415631900872, 0.036019136783696955, 0.009007194500056007, 0.053011867097548904, 0.010906970935813602, 0.007110257856472726, 0.13289543259288036, 0.044245002040218924, 0.033593277236627, 0.02622273191058588, 0.03447938049512525, 0.029522636492225914, 0.11740387837973335, 0.06225497454344746, 0.05305309411919406, 0.050596606376911366, 0.033446563738248045, 0.056703024273437846, 0.030365170415250525, 0.024368621018384735, 0.03655195476547365, 0.08786610207490383, 0.061547691528234756, 0.06163141727747937, 0.04767511475590929, 0.02133185614741618, 0.031567610529882294, 0.03390037890283331, 0.06987858743917558, 0.046150833443408056, 0.13218142332569247, 0.040981651343885935, 0.031996981744023587, 0.0713387203793372, 0.018099895903780576, 0.07063932806974457, 0.02989482881891872, 0.023719041660848646, 0.0582915956845447, 0.13169029967919474, 0.12637773273332467, 0.030780171735152125, 0.08931326514650738, 0.08887427378325694, 0.027348465556579254, 0.031472602220732844, 0.05230491350014364, 0.05086552239053192, 0.022809976832039898, 0.022107047111456914, 0.0489483988513389, 0.034345518121676105, 0.009881544054575987, 0.02751441360751708, 0.05202825233760861, 0.05864992948068727, 0.02520913821494868, 0.06641526481196766, 0.10157306212931873, 0.015901624799645957, 0.03329199017776597, 0.04139395220385444, 0.03761800441650614, 0.07052426166351765, 0.12166713469571645, 0.1123467481304561, 0.018699149030350873, 0.018801833540501616, 0.10300103469841904, 0.0473475432203662, 0.02806913404304895, 0.04698301943379545, 0.061305351104707494, 0.05189122985147181, 0.028252933857842322, 0.02402201985880252, 0.04125465443658252, 0.018733981133048094, 0.027553689020175128, 0.047901765698747295, 0.07332356992147623, 0.033171323668812557, 0.02502403988112365, 0.03984924315685227, 0.024054477088934472, 0.018827397894534855, 0.02448635915624759, 0.03168963876012112, 0.039501676726485455, 0.02215136912831616, 0.09837268386036159, 0.026849437797922763, 0.051717979067395774, 0.009990133187403123, 0.07042063295000023, 0.04662582327822044, 0.034887701528327125, 0.03329811122028097, 0.0209961430124578, 0.04617752011625036, 0.06396932226996269, 0.0344235671594018, 0.06055935766668089, 0.03951665374540514, 0.019791046487948587, 0.061501561543874206, 0.07600331483709236, 0.04313332036197667, 0.06372306330670273, 0.038637778526472474, 0.7579941747169342, 7.108660023058615, 18.92173924753743, 34.27776944252753, 45.44825215493479, 51.1655616760254, 59.984489333245065, 55.37775970274403, 29.395769834518436, 41.56065379419635, 47.32831870355914, 20.394908920411144, 32.05321484996427, 27.34769444311819, 25.002736814560432, 31.50372609015434, 33.61765023200743, 31.30222216729195, 29.862600526502057, 28.146720470920688, 25.867366444680002, 19.608746305588756, 21.840119938696585, 18.880277833630963, 12.835660249956193, 10.403420079138971, 6.773296392733052, 6.398061869605896, 5.32279311649261, 4.020146525675251, 3.601850016463188, 4.086538034100687, 4.038658887147903, 4.348266028588818, 3.0233342464893096, 4.030349345937852, 4.756068481552986, 3.431733390015941, 4.296699118229651, 6.64481915773884, 8.467973586051695, 8.759418437557837, 11.742864385727914, 16.21395061092992, 16.84738789835284, 23.193894624710087, 27.251443401459728, 28.087667226791385, 21.496320270722915, 21.04409452407591, 23.24849597869381, 20.93042031411202, 21.122702744699296, 26.173952625643825, 31.723023845303445, 39.011681925865915, 34.70848883351972, 31.13967718616609, 28.38156846261794, 19.831293744425622, 10.439376446508593, 3.549236078416148, 0.4810226239985036, 0.025458586019193454, 0.07428349341235815, 0.04258772403362297, 0.15411907116011267, 0.016118556959554553, 0.06063574812405052, 0.07046277544671489, 0.011659863953208251, 0.0073793232572385145, 0.010104223789136496, 0.047301493675237706, 0.07537180557847023, 0.047843677081888726, 0.03981429039530697, 0.03802549424431017, 0.03077396450774564, 0.01116047613322735, 0.015580243254531057, 0.006939654863784991, 0.03400876885280013, 0.04317248660710551, 0.020486047198515267, 0.05417342109966183, 0.03890218228221901, 0.03605461814591, 0.02230873890972186, 0.05657245990850272, 0.031511117291126045, 0.05933770023646855, 0.027139731495070363, 0.0901410001660547, 0.03071900344483795, 0.0017455230760876272, 0.05642318384601705, 0.1434466849652029, 0.05205031183938827, 0.05535870850566895, 0.007574339078048305, 0.016155509210582224, 0.06348193713253544, 0.018392459136403857, 0.04473562389912625, 0.023013742813359828, 0.021507577565048012, 0.02024577329716375, 0.06324182219442821, 0.028030664937931205, 0.025271955509519866, 0.04733483382170239, 0.034579450730234385, 0.062134062886358275, 0.06100043278908538, 0.16753192239951703, 0.1533788770076729, 0.04695008914437025, 0.16997316882254618, 0.09128428680161316, 0.16600454226136208, 0.129997659054014, 0.14540561775286354, 0.17444224998114571, 0.10835112463082038, 0.14762543412225862, 0.07626144816317866, 0.18212755210697654, 0.1174913886033239, 0.16961488482211867, 0.1518954856381301, 0.15798588463615987, 0.1888967203276773, 0.08045087658589886, 0.20908037921594036, 0.14307343160673497, 0.0748906487358674, 0.11620577815319262, 0.1409794221962652, 0.170057469137734, 0.08053251857598943, 0.17296949191199196, 0.11653704223253074, 0.11903351593402126, 0.06317402724356902, 0.22997594829047882, 0.20867390828507565, 0.15387088931616277, 0.22147309245361438, 0.1778080419547135, 0.13813614815233216, 0.16965717287553897, 0.13484698029295092, 0.12496769428253175, 0.13246700558210575, 0.15710008781283133, 0.1427303467907252, 0.09675043139366374, 0.1891897029934391, 0.1422751833113932, 0.16854879686668997, 0.1258143363520503, 0.14556430520549898, 0.10112590426879545, 0.15476482199324718, 0.10915648222209946, 0.1784231186273598, 0.18742022374945302, 0.09347634780551158, 0.2115414366726914, 0.10199613418550262, 0.16619879151544265, 0.127713575568651, 0.17229608530479093, 0.15712657913325295, 0.4012765176594258, 0.8483494037101347, 7.773856251470505, 21.34136115351031, 37.48048666984805, 51.212084908639234, 56.318128339705936, 66.12679158487629, 63.71543999641173, 42.99654722213746, 47.06931675634077, 58.40757885286885, 33.964889818622225, 40.98901148765318, 37.933669474817094, 33.82840702610631, 36.26512066010506, 38.15424788382746, 35.99210016189083, 31.309023557170747, 36.6163218405939, 26.64471353254011, 22.77723693078564, 25.54195288688906, 19.371493900975874, 16.691632539995258, 12.013397120660352, 7.9931589095823234, 8.559477579209114, 6.5672596808402774, 5.5325296040504215, 4.650514558438332, 4.83887069648312, 4.81083506538022, 4.993833736065896, 3.5974966758681886, 4.47634220123291, 5.087631335181575, 5.003677414309594, 6.614506100454639, 7.344228750275028, 8.881168807706526, 11.172606675855576, 14.287078419039327, 17.62541747862293, 20.384657805965794, 27.44715790594778, 27.578331770435458, 32.29249119758606, 31.376092164747178, 25.239147870771347, 28.368289278399562, 33.431639671325684, 33.49376217011483, 32.54627639247526, 38.81477894321565, 48.492831184018044, 42.14298848182925, 35.0772386981595, 31.155092100943293, 20.430222019072502, 10.135107405724066, 3.554151788834603, 0.49190858018494427, 0.19000322708199102, 0.1649481376572963, 0.13554784349135815, 0.41027762176048377, 0.12677010764638263, 0.1210816519995851, 0.2137835002354076, 0.13557739916347689, 0.13784063739642022, 0.2684189144882464, 0.23803893176297988, 0.16520220305650465, 0.17156422618896733, 0.12470014573585604, 0.1472267160011876, 0.2287240840134121, 0.09737142992596473, 0.15825495003692566, 0.05541538369030722, 0.1701115549451882, 0.16306676361108982, 0.15616071080007862, 0.1413258931209003, 0.10018007679572029, 0.14416346747067668, 0.08378283811673042, 0.14495881995366466, 0.1248613766004001, 0.14176046415682764, 0.1289302840708725, 0.11167045337178054, 0.1963935341806181, 0.08733645186669405, 0.2711288126245622, 0.20408761567406117, 0.10273519452781447, 0.1883738193540804, 0.14541393746772122, 0.12158892477952665, 0.12998845067716416, 0.11114155392973654, 0.20269204862415793, 0.28746854874395555, 0.2237899874847743, 0.11778183551805636, 0.28622800724640973, 0.2067584280044802, 0.16190417922071873, 0.22271427746501662, 0.2038468648829768, 0.12018002013886168, 0.2617731630321472], [0.16871620239990373, 0.062220531230371814, 0.05999006623882921, 0.06397034882778121, 0.02727372601868645, 0.02849599631923822, 0.07667243135191741, 0.0432991439236268, 0.033717333684645356, 0.059119912930914474, 0.02461385916948559, 0.06404566676205685, 0.05165653115498924, 0.015412311035869344, 0.045897384744978724, 0.029432121288752364, 0.04064514339270611, 0.06771784410962174, 0.046046319898338094, 0.030631995008837794, 0.011716449122515418, 0.11799595709289275, 0.0280455366197613, 0.028929466103774407, 0.05841200555404348, 0.0461241927358412, 0.021569431504054416, 0.009749115223155148, 0.05315396491618407, 0.04086439775663518, 0.07070612327586259, 0.040954229226636316, 0.05578095318689462, 0.05826063041064528, 0.0626050001160512, 0.047590534818629106, 0.046388539034993424, 0.03552604812167345, 0.018045415561045372, 0.08453845361908598, 0.03722566780784438, 0.05537110380828381, 0.04293837013744539, 0.016103338622938723, 0.03856765466832346, 0.003407657721019801, 0.04715304881814988, 0.027652150470643278, 0.028245650276902224, 0.0475102832781211, 0.02761670358238682, 0.007188635833200909, 0.053233936834599704, 0.04128008472522901, 0.025680238238325524, 0.08979557878187588, 0.03714831591012978, 0.016647569399567384, 0.048555648555198026, 0.073593455036321, 0.07915255673710378, 0.10674176542388816, 0.0285685486761072, 1.082213186929303, 6.219448408772869, 17.629885058249197, 32.87184684507309, 42.228766795127626, 45.106405827306936, 49.867057108110004, 40.90329200990739, 51.81831467536188, 32.59617874699254, 25.95792220484826, 25.770336812542332, 24.73007913558714, 16.901720569979762, 22.63544717142659, 26.435902234046694, 37.58599450511318, 27.211715675169422, 30.27491419546066, 25.319676091594083, 19.89888402723497, 20.639570682279526, 21.16760407724688, 21.39638416228756, 19.088024208622596, 15.64121396310868, 10.787382856492075, 14.716777013194177, 14.65016536174282, 13.705343854042793, 11.781890007757372, 11.212491296952772, 13.186990868660713, 10.99168440987987, 8.950353533990922, 16.986114286607314, 17.583803092279744, 13.30142209606786, 20.252909314247873, 22.381628636390936, 25.782096078318936, 21.990278074818274, 22.397896666680616, 26.103563731716527, 15.726160733930527, 16.215062602873772, 24.54197402923338, 19.51315618330433, 26.127092069195164, 29.90111427922403, 35.01252351268646, 31.715249707621915, 30.529336775502852, 23.887161785556426, 18.024493148249967, 11.649158962311285, 5.856750761308978, 1.723160219769324, 0.46985882304368487, 0.0634734986740495, 0.05766822611011806, 0.06309666768497517, 0.02692714401130234, 0.027617820155536457, 0.08535777699322471, 0.04879198284939893, 0.015505164722731758, 0.06990808948513962, 0.021935422349000172, 0.01739280058010932, 0.06639777502465634, 0.06060015184864883, 0.06014201594817062, 0.01189370558882553, 0.007012033893261106, 0.04158187740212006, 0.07175468313958376, 0.02275529539122457, 0.019407487331679272, 0.035150454364596836, 0.004699284355381444, 0.04662286234839309, 0.02755071659902892, 0.02314611323057644, 0.06298034872499204, 0.05656365755825274, 0.05230718112039951, 0.026867615149146127, 0.00864084359378584, 0.08740976648104769, 0.028469436050903414, 0.04049173428586895, 0.08216391813250319, 0.019512621407967903, 0.0413442254366894, 0.038729253255071185, 0.034277209891907634, 0.11778900610102762, 0.048420292310296535, 0.05869494097667837, 0.06710017039891213, 0.038234149781806816, 0.007405854797276158, 0.12011248182745711, 0.07971130296467774, 0.02851520022828012, 0.025922335428936828, 0.03574382776634828, 0.029391284971948595, 0.015391686033727902, 0.04150251835404385, 0.0891601777965984, 0.10969390822274071, 0.15366498020387467, 0.039354990041183854, 0.04743887622269893, 0.022045285103001425, 0.07897040401134761, 0.04386781098982019, 0.03724689227378657, 0.058005749127797546, 0.03271876871886273, 0.06334917026481802, 0.015209127281371866, 0.08677108663945429, 0.05240410656457948, 0.028779523544794613, 0.019938639072220654, 0.026400159789069046, 0.05139171754220321, 0.09927677486332194, 0.05365941057642622, 0.026127656568743052, 0.04559351213937325, 0.04111721060208736, 0.013690771658964937, 0.04274055857451693, 0.032898891311619556, 0.01591623984202142, 0.03078354443723877, 0.005829896066232675, 0.057711429638607856, 0.026235226804630894, 0.159809602905185, 0.07683628223716252, 0.07524356245994568, 0.026743367179146698, 0.07527417533339993, 0.05405822445848777, 0.0371556933368406, 0.014173042201887698, 0.028934372896929423, 0.06668844410488683, 0.039938419621678135, 0.023128753678212245, 0.032178286027403614, 0.0152697334546716, 0.04199515885463165, 0.028649572050198916, 0.03244880699522553, 0.11170420720572434, 0.05353029028722837, 0.08105806255292508, 0.022419714406433127, 0.022126867721277862, 0.03715648240740261, 0.01932173527987494, 0.042169340435535684, 0.022659603348602692, 0.029087804986404318, 0.09175923067115008, 0.11408559917922943, 0.04795598940202787, 0.04673625485250547, 0.013286646872368312, 0.032607023303787556, 2.4456321231780516, 9.480648175362619, 23.693188813424882, 40.237061746658824, 49.346903754818825, 52.78961904587285, 53.23871081875217, 45.67702047286495, 57.56090779458323, 34.79515752484722, 28.491775297349502, 27.15560224748427, 24.163200547618253, 19.824253089966316, 27.3993795148788, 26.47768920467746, 32.90774437689012, 36.009939101434526, 32.41909942319317, 29.746921985380112, 27.97422051429749, 31.613330841064457, 27.476061851747577, 22.956132311974805, 21.096717042307702, 23.73081022693265, 16.455968695302165, 20.642082960374896, 18.348080842725693, 17.78268687186703, 17.557382006799024, 14.806457104221469, 15.139802675093375, 16.14944233048347, 12.500998723891474, 18.60086779440603, 18.737576123206846, 21.091349278726888, 24.319165752780055, 28.066325610683812, 30.946406318295388, 27.88651239487433, 28.50947499275208, 29.268818401521255, 22.663545070155976, 23.821885701148744, 29.26024998387983, 19.879519285694247, 25.983468601780555, 32.13283308090703, 38.112984549614694, 35.719467978323664, 36.95113535850279, 31.810473088295232, 23.829838306673114, 16.952397592606083, 9.666007622595757, 3.7810922822644635, 0.9646926640022186, 0.0839041787830572, 0.04066755912537056, 0.049598991360154845, 0.005950896302238108, 0.04549361427404708, 0.06427593363989746, 0.10559808808348833, 0.06815598511527624, 0.021793460510971568, 0.016987969077402548, 0.005687343861697423, 0.006259080067637467, 0.051268852360907106, 0.05584644221310174, 0.019426250740164713, 0.03728565632275516, 0.03930892900473649, 0.08593461055669092, 0.037903529216325095, 0.07601161156931231, 0.04597085257691722, 0.030102781470744844, 0.01864096465250177, 0.02542631456538314, 0.02210454774960395, 0.04447030849874981, 0.05076421875386469, 0.040117584604529605, 0.04278569647501554, 0.03346016562934364, 0.030126411452769276, 0.1110272536114339, 0.017805340842554168, 0.03145140839830762, 0.03785989284815808, 0.06637473109989397, 0.028437783213091955, 0.011597674850734973, 0.046369421310843005, 0.014522226035384642, 0.0344724282472124, 0.06447565276175737, 0.03927533987969641, 0.015104656828747643, 0.07110412893516403, 0.09433762981526314, 0.044182148356471336, 0.02943466661588079, 0.011348129370279852, 0.06079642740528911, 0.022678240352580627, 0.03770259201466557, 0.07526754101197566, 0.06626211617502474, 0.3039289590331816, 0.23287445727375247, 0.1675765700037441, 0.23670482028636242, 0.14367096486591524, 0.17584275063728133, 0.2548227537303202, 0.15241895351679097, 0.12749547033660835, 0.17243004343923063, 0.14785087847661588, 0.27800917084659305, 0.1957222726196051, 0.16700620222235882, 0.22700069261895073, 0.14232991263270378, 0.17287126411834072, 0.3247039458684383, 0.18983638845384124, 0.10341750307669563, 0.11924206038876889, 0.19374192001358156, 0.1476806230963238, 0.13326969718740833, 0.2161416107968938, 0.1489428142386098, 0.1617732547944592, 0.0801646354938707, 0.28137885454681616, 0.10589376737874363, 0.335358849936916, 0.15946169173525226, 0.300804668616864, 0.181181050476528, 0.2001538001481564, 0.16127309131045497, 0.1512856336851274, 0.13827084173117915, 0.14016850280665583, 0.22263152464743585, 0.1294484659428558, 0.14270151124125527, 0.1871813575346624, 0.12659986758784902, 0.11436835457120212, 0.14536020406071218, 0.12020961411537663, 0.18949978474167087, 0.14890093987266864, 0.2057123502656337, 0.0792839637987556, 0.16456696294969128, 0.11987520907554897, 0.13603384967052168, 0.13651702132436538, 0.14763923902665416, 0.10846695712497158, 0.177565835596573, 0.1988691166644135, 0.1228085061114642, 0.13534942671896952, 0.19399871268580038, 0.16585752998869266, 2.6050267056111367, 10.41744843606026, 27.45932705940739, 44.71276852392381, 56.797120340408824, 58.64179534296836, 63.38697287344164, 53.62114975529333, 65.02886526046261, 47.53594544626052, 40.07455010567942, 38.54024048774473, 37.118510738495864, 26.477191063665575, 35.03974476168233, 41.3674182276572, 49.771194381098596, 39.39283824736072, 40.431815270454656, 38.177950766778764, 29.200798619178038, 30.18722764907345, 31.232084305055682, 30.409055332983698, 27.23939976384563, 24.357624592319613, 17.725608541119485, 19.61993682769037, 19.883445578236735, 19.909480310255482, 18.09417013199099, 17.017459907839378, 17.525997161865234, 15.6179464632465, 13.736660057498565, 21.93243488188713, 22.582887411117557, 19.235762242347963, 27.78285199596036, 30.574720559581635, 35.44314092205417, 30.523684640084547, 33.87480082050447, 35.065616715338926, 26.225722028363137, 26.420530465341386, 37.77285622012231, 27.46304350514566, 34.99818724970664, 42.23328536556613, 47.36345921793292, 45.16145237030522, 43.623090943982525, 35.68523353145969, 26.010583946781775, 17.242807918979278, 9.891310526478676, 3.269720380344699, 0.9516319067728136, 0.28278287920740347, 0.14446467792074527, 0.13975086231385508, 0.08041768965701904, 0.17659377727297046, 0.18526256775423405, 0.2996179984221536, 0.20097699226631274, 0.12713701779683753, 0.09361447345825935, 0.11681746871721362, 0.17036387366392922, 0.22744384383963, 0.183920580893755, 0.14413956552743912, 0.1489927478495144, 0.10292986513025339, 0.19966521991356728, 0.08453925035052723, 0.1748461315348264, 0.10840946222625433, 0.15921634441662222, 0.1737518209002672, 0.13861558129710538, 0.14354695055273273, 0.13663394166336906, 0.1917577982549706, 0.09263394220221428, 0.11097582612907696, 0.12305803627016083, 0.18518899266998615, 0.2217004979930578, 0.2583090360126188, 0.16452412331296554, 0.20073094014679232, 0.16930445067344174, 0.19404404976915932, 0.0695118228454263, 0.23203064206867452, 0.15742046578276545, 0.23198792500601662, 0.21866107479699198, 0.11575374797347093, 0.1075907287398173, 0.23936457030715483, 0.1544271610797413, 0.15871942914541692, 0.08718512651901092, 0.13704280278855754, 0.14895703283048448, 0.13498916621169738, 0.18744339024828327, 0.22350143280721482, 0.3565286478448299], [0.00631428292704626, 0.05781824527789028, 0.06147677093864449, 0.06411061569627735, 0.05355105510041599, 0.017320405271264817, 0.03177794379993312, 0.07233627410905977, 0.04385655332777289, 0.05154247598482236, 0.04331515899168388, 0.02810686004288014, 0.04330858978773317, 0.0491825842689122, 0.03970269053693741, 0.03787247201187476, 0.04075178666220557, 0.015813500748106068, 0.07285178999506658, 0.016578043089999307, 0.06704101308939919, 0.05203413206242746, 0.07022586275613116, 0.04224756184304434, 0.03520571994745443, 0.05953641195270804, 0.04840530763049761, 0.09326792592483182, 0.04195661314072148, 0.09350837794162574, 0.05325057626431508, 0.018896512431843628, 0.02434432070942656, 0.011232757486493118, 0.012424949259917824, 0.005319299422309644, 0.06807176140888084, 0.004808066446604508, 0.06460769567638636, 0.052844710542910525, 0.026138510119410294, 0.032673550379132076, 0.026793635953518174, 0.1035745817446901, 0.021866053087456573, 0.03049686475987396, 0.01994925896607099, 0.04387892309516188, 0.0648009413552861, 0.04954163435726397, 0.05380805844681398, 0.035601703134635766, 0.05449135141867784, 0.07268932572896443, 0.046077369441909176, 0.03673655897258751, 0.05167239683590109, 0.04474954371671042, 0.04131489576050832, 0.06818961637515215, 0.023133045685808026, 0.05515035557290239, 0.03449440347932039, 0.06571640876392204, 0.2773410808895865, 2.6178204965206886, 12.042525622152514, 23.307759069627334, 37.416418675453436, 41.615923912294456, 40.69249599210678, 43.59747002201696, 47.4614792485391, 43.66709993731591, 41.592307321486935, 33.09153487605433, 31.190444423306374, 27.138943941362445, 29.263242752321307, 25.916798114776615, 15.065466896180185, 34.01647683112852, 25.231108973103186, 30.5217077655177, 26.572869439278882, 14.86269408656705, 24.64929988307338, 19.6713355664284, 16.080091884059293, 22.735193044908588, 15.749135036622326, 14.68311131000519, 20.32293538893423, 22.857318001408732, 23.21299264507909, 20.97253676383726, 22.830949867925337, 22.69896407281199, 38.810099555600075, 41.69855256234446, 18.897704924306563, 25.999226723947835, 20.31472782934866, 23.40586735356239, 27.026446442450247, 27.46704432272142, 24.48188135700841, 22.738277989049113, 25.05787161088759, 23.673998617356826, 32.69453021787828, 38.84674233774985, 35.092610466864805, 31.11087718317586, 26.274953657580962, 17.50185693463972, 7.594442136826054, 3.524911744940666, 1.205516570518094, 0.4570589953612897, 0.050678734832833854, 0.030784457997088472, 0.040346575945976286, 0.026636183817660617, 0.027233261254525958, 0.01616600844558449, 0.021492820796406558, 0.00691752641409215, 0.08475261349831859, 0.03843384975146863, 0.03224013230553077, 0.006589659455893261, 0.03764359941405635, 0.08360481460488613, 0.02073455462983299, 0.03206839071466558, 0.03604933980011171, 0.038267574197943174, 0.04335353999669033, 0.06484706750920703, 0.025295493560993386, 0.020325459847827593, 0.015583856316703944, 0.0189521495673445, 0.057745386485851584, 0.0035048043730879024, 0.08632538434598716, 0.1500125640943166, 0.027163062702804327, 0.02209916023627645, 0.03359521160863581, 0.014430372093263415, 0.03253539025242771, 0.05082816411290438, 0.04177374795319573, 0.01370186844254814, 0.1022316602569434, 0.06135179901555662, 0.09188417961160023, 0.0283243581502428, 0.063273208816686, 0.03730196250422347, 0.04504291325687401, 0.058509834981974096, 0.03860608929948461, 0.06639192977379407, 0.049050549015162453, 0.015333243101204356, 0.005811980621318423, 0.050604849482976624, 0.026369757589793978, 0.05241962367548578, 0.042872394645406355, 0.028144720108098084, 0.04400328597834995, 0.1364697077341618, 0.003914368144544443, 0.057278302678417777, 0.024648118621459412, 0.04482436369383528, 0.008146989801447959, 0.021678306004633347, 0.03774986730047292, 0.02970251010640735, 0.031203820272499037, 0.018184207710287264, 0.03340478513329741, 0.020227682130831866, 0.0400347015520017, 0.05437554573760398, 0.027039523364134857, 0.07085077599772523, 0.051827215544518926, 0.017340266100701787, 0.05186087361747219, 0.03396389525263541, 0.03022257272424477, 0.02558218664489687, 0.05582778797214551, 0.03980667931177924, 0.0324898041904934, 0.0711242770475726, 0.06427018798046535, 0.0813002689110656, 0.05140232019907525, 0.021667352862535946, 0.06192660627646312, 0.01627573330375937, 0.016243115195163315, 0.058058647498969114, 0.02641895575629127, 0.01623807625184136, 0.04213319257682851, 0.03623894656137113, 0.016330462625069965, 0.047333500828714146, 0.04603164165370888, 0.018744281185190045, 0.03277357081852613, 0.019740842831050678, 0.054166982130658244, 0.11563953192483996, 0.06077460539076598, 0.02308585275445254, 0.04218527889480034, 0.02503324059709426, 0.03691521833740896, 0.037688507488177675, 0.01619037770245585, 0.07211694313633828, 0.03049178368171617, 0.06203853555264012, 0.0580931329468806, 0.027212613269746787, 0.026677724935354728, 0.09335671551525594, 0.04483908790373995, 0.07161071223597373, 0.023742098992149678, 0.021843141312861157, 0.44004559216480105, 4.070282261217795, 14.84582789482609, 29.96780437807883, 44.4926647217043, 51.60593009764149, 47.373182773590095, 48.87485827169111, 49.568823614428126, 45.12872411358742, 42.22318526237242, 34.8508277247029, 27.55523293249069, 26.283072963837657, 32.80764156772245, 28.354629624274473, 20.955260684413297, 33.24155769040508, 27.726756218940984, 28.18672472430814, 25.412357776395737, 25.20367983848818, 31.010797908229215, 28.03462697613624, 24.23646257769677, 25.617433017300023, 21.262768622367613, 26.360194606165734, 27.06796080835404, 26.19015789801075, 28.31610998799724, 26.50059976885396, 24.55622596125449, 27.605874653785463, 44.841088864111136, 44.41529597005537, 22.573501179295203, 32.41560459136963, 26.916178810981016, 29.763888197560465, 27.91523395046111, 31.863150519709436, 28.6314901228874, 22.576658687283917, 24.305817927083663, 28.14102715061557, 31.537791875100908, 42.77271716825424, 41.679948760617165, 37.71178883890952, 31.244447615838823, 23.113748834979152, 11.81832294310293, 6.168499762012113, 2.590710544778455, 0.6875759243003784, 0.06578685054855962, 0.004824319001918118, 0.04005600645717594, 0.05959874469666712, 0.06269437959417701, 0.0574339411011146, 0.025836772983893756, 0.029126888877081297, 0.05253128482088928, 0.044619718626622236, 0.0036248955978906805, 0.00944299893754144, 0.058637568652029, 0.035323996262084094, 0.09492175653576852, 0.02265746404807414, 0.0337306751058467, 0.07791509491301353, 0.04146531329400117, 0.09830608017622464, 0.023108293384974523, 0.024873101407842293, 0.03891102676730483, 0.03086614212201488, 0.020479650364347526, 0.05179345404969589, 0.025391662493348125, 0.09428132235282853, 0.045524740426410595, 0.03819121438409052, 0.022824063273747603, 0.04158979109037788, 0.05233338515784952, 0.04294961630817383, 0.03276884405603332, 0.0634292915703789, 0.045774550207199595, 0.02259664432776551, 0.11946379687757262, 0.04386193126500134, 0.08138990119820641, 0.024102819152176384, 0.004911581683348144, 0.0730569330194304, 0.030085703455692822, 0.016267758328467607, 0.1077566710450957, 0.04585105174731824, 0.045565423525629506, 0.056855445126852686, 0.026509375198774283, 0.04303924859531465, 0.04684545685567203, 0.04930060394408722, 0.06645000689933378, 0.01772168595644255, 0.06098074049899175, 0.10725066997110845, 0.18484042266443854, 0.14860463238531543, 0.12412418551262348, 0.1068864334675093, 0.13603974854753864, 0.11584806105782909, 0.15745860163963613, 0.10681668116200356, 0.16733471604604877, 0.1262164099382297, 0.12043318921519865, 0.1321267706131743, 0.10167560299798366, 0.16159403618545304, 0.08177296814298438, 0.14283550001921194, 0.13157840487697434, 0.12750946676298497, 0.12330681566269168, 0.2028646788770153, 0.16348919981429655, 0.08188364486540518, 0.14217545398541037, 0.1866685842434245, 0.17923555487105924, 0.15064037314826442, 0.14002283884873315, 0.199009663155002, 0.1552627485005125, 0.11895600315784255, 0.09539068661509983, 0.08786653874502068, 0.13343291988055553, 0.18158352242842798, 0.084482008260825, 0.08204148962132393, 0.2433860109698388, 0.1392966487835492, 0.19429860546463923, 0.1370031347558383, 0.15460651758457386, 0.19351615390229612, 0.08191669389845864, 0.210715118915804, 0.21693754550670424, 0.10125003349516662, 0.09927330448502496, 0.10211112398293712, 0.15938673769274067, 0.11853368186782445, 0.1720653855872731, 0.09828141214506281, 0.16956187153775848, 0.1799877306386348, 0.1998024415825644, 0.10050561819826404, 0.11189089517199224, 0.13849881417568655, 0.24739280403141053, 0.21095164090154633, 0.08759038703095529, 0.10615973012341608, 0.5410685955036072, 3.8544013807850503, 15.634308630420318, 31.511439431098204, 49.716940156875125, 56.07903634348224, 57.48395481417256, 57.42674704520934, 61.52745954452023, 57.25916770196731, 55.339242027651885, 45.78996512197679, 42.70411099157026, 41.88797166270595, 44.938093000842684, 39.05616160361998, 26.954973013170306, 48.180426166903594, 37.27908080623996, 43.03777917738884, 37.290514515292266, 27.928940673028272, 38.33077807580271, 30.94484913733698, 27.789043457277362, 32.65599685330545, 24.75701797393061, 25.978714689131706, 31.745510793501335, 32.61578275311378, 34.0157864939782, 30.967573388930294, 33.101689892430464, 32.567872962644024, 49.729903590294626, 54.5013217772207, 27.07610364883177, 37.61749505996704, 31.873183942610222, 38.20335988075503, 38.99695342586887, 38.612012017157774, 36.09702748637046, 31.606339216232303, 34.55661466044765, 35.63379556901994, 43.87360880451818, 52.778714856793805, 47.626344311621885, 43.997571391444055, 35.86990656391267, 25.89503876624569, 13.279486240879184, 5.990499171518511, 2.3807752420825343, 0.8310097696319704, 0.16139748866759962, 0.15973268767758725, 0.1789271738380194, 0.07628030158699521, 0.11591634247452022, 0.10493925246860712, 0.15597113468233617, 0.09808601375909583, 0.11960759924183931, 0.14895419830516463, 0.11518450634133433, 0.09810495911346329, 0.11046411003917457, 0.12201113115635612, 0.22989287371596984, 0.10558574640702818, 0.12034207071748473, 0.13800704701533242, 0.12777520734215939, 0.20618438300105835, 0.12740297288063074, 0.14782188970956112, 0.10319148415639516, 0.07186137620479831, 0.20200295253626763, 0.1345281191771069, 0.2766392217768777, 0.17623996722602076, 0.11878914154705503, 0.10082206613714657, 0.10348639736372618, 0.13047100946066842, 0.163519061921585, 0.10835096375235628, 0.1462259906674585, 0.18515171483159068, 0.18615435538513048, 0.1735735828838041, 0.28969869197856996, 0.12190859028769117, 0.19488833994875032, 0.09632744360715152, 0.16924959877806325, 0.19444793132283997, 0.14429586278575082, 0.13183582574129105, 0.21618451172065353, 0.07868806996773328, 0.1059133256034505, 0.2759504168023986, 0.07234031905329998, 0.15859239644581274, 0.1495083097007967, 0.08867230236289964, 0.1421473079150723, 0.36891533963141904], [0.0466621664893483, 0.008220311119070938, 0.029467738631571976, 0.05380722341097651, 0.02920586296597556, 0.022552326141345887, 0.0631149082384523, 0.04245630165021266, 0.017786648297201724, 0.04456027403413769, 0.03908323567180384, 0.08344953624351371, 0.0373193450392254, 0.0243723729339939, 0.044534311314383825, 0.07824461231188429, 0.022444912953482523, 0.07233056675402388, 0.04651217796509305, 0.038573281584127296, 0.059684508239790324, 0.053980424399337465, 0.0061940468637452974, 0.02126876880685168, 0.11065000893488047, 0.07192680011353186, 0.02695810928520176, 0.03884222824126482, 0.0593079453814895, 0.04754289564105773, 0.05724539920206993, 0.09602958096131202, 0.03215884271588537, 0.03940491599120921, 0.0189534921364318, 0.01411752189479528, 0.014315072030219582, 0.020627440216260094, 0.01570260760584666, 0.014952469632149705, 0.009245895048333033, 0.05839127904525208, 0.11709226445565302, 0.04547723914466558, 0.021516240104251814, 0.04758887623827304, 0.017826097994862546, 0.07353445094439291, 0.04700260447157968, 0.03239941730674717, 0.0454698502266359, 0.03369816616477986, 0.02915375175014619, 0.022143815501382755, 0.09393279065167713, 0.04405726070305513, 0.08036078464600348, 0.03975049059297289, 0.035010536066106254, 0.03734382537884578, 0.0600473006676522, 0.06011151798790502, 0.04979369643655035, 0.04605878414886613, 0.08529359414692848, 0.048366991742964716, 0.2332245288116317, 3.055399622647993, 10.635837181921929, 19.07754167433708, 32.150368036762366, 38.65496197054463, 48.841455367303666, 49.43259577597342, 52.35395354609336, 47.250491034600046, 49.0107762429022, 47.004448598431004, 35.864387789080226, 31.180481603068692, 31.068874482185613, 28.081585591839207, 32.30208335384246, 33.901068933548466, 27.595196000991333, 24.133184609874604, 25.714862731195268, 25.731597523535452, 20.477429705281413, 25.40224394490642, 29.300315034004953, 21.140784871193674, 31.827674642685924, 26.27324546537092, 26.98483990084741, 31.223849288878906, 38.203281433351584, 27.486909166459117, 68.6044273068828, 69.36681055253553, 31.264033971294282, 21.258918816043487, 21.21753388835538, 32.18529085959158, 34.834498897675545, 40.695390701293945, 31.521570913253296, 40.00763839290988, 45.30559162939749, 40.662819339383034, 37.75238144782282, 28.643594557239165, 20.568938601401545, 13.20978670350967, 9.488354652158677, 4.373802619595682, 1.1228603413028102, 0.3507253786008204, 0.05311277236849551, 0.03225989354353759, 0.056743278363419164, 0.05099497592797683, 0.04893288940131184, 0.05262028125505294, 0.032932020783905065, 0.05209364177238557, 0.035316637987571384, 0.019557418399340203, 0.05926614762434076, 0.02732807804169434, 0.024545455178726586, 0.048574827566382386, 0.04212237924577729, 0.05832125860897284, 0.01633506106783546, 0.07756179048409385, 0.020533284179926403, 0.06477598221071305, 0.04800763904988285, 0.06678261163253939, 0.018446564096056165, 0.027693176394208308, 0.02629093480326476, 0.04575535587425675, 0.03340098150675336, 0.033475544844423576, 0.08692952128307474, 0.04365437123323641, 0.015292617458579762, 0.013579454295517457, 0.05474670001515939, 0.006954411153621491, 0.023787694630183043, 0.042876083358761766, 0.050881269327815504, 0.04820789060285015, 0.02896751769097342, 0.02414850863598047, 0.08128778167789982, 0.04799874476908196, 0.02105320124105821, 0.040347365016538295, 0.024697971793131965, 0.03491927584212634, 0.07524403743445873, 0.029768376430917173, 0.05627683806984175, 0.006696136101269194, 0.020759588467978665, 0.07623416777219504, 0.029609934126417485, 0.04664850714165838, 0.033342996311764565, 0.03529159840376627, 0.01712348428554833, 0.038160436801732554, 0.05215016373943898, 0.025743597540103143, 0.04322095315963511, 0.029315222017166596, 0.04183728345519593, 0.09984345776179146, 0.05148499257742398, 0.0645691691146743, 0.07267032674844227, 0.05389576785326485, 0.055614957255461527, 0.0413922629799814, 0.1212706458905051, 0.011533357939052006, 0.08825525941867983, 0.04059367377551333, 0.007040232632143964, 0.0676920805727282, 0.062165399712900964, 0.05538128128635788, 0.02123995624001949, 0.0633747959058852, 0.034810460713361545, 0.06156447651465574, 0.10086576379234753, 0.021468960988004843, 0.11168680934896393, 0.034514271969636606, 0.07047307166841722, 0.04496050517885916, 0.02762968494226375, 0.009351356627209293, 0.028818096071782134, 0.04524976465730898, 0.028489783346172304, 0.015366954800312319, 0.05363797160586523, 0.04281257466983892, 0.021159587871103037, 0.030772235064256578, 0.03601318811096492, 0.02823793768672453, 0.1438336972627909, 0.020009128737353513, 0.03317230426135563, 0.044196838092419415, 0.02761733368970454, 0.04973131389687619, 0.061550832488724304, 0.02580207303136347, 0.03267893214680014, 0.028892031217354442, 0.02127277736191548, 0.0110214771402459, 0.031463267439375484, 0.054383930569935235, 0.03756947274650297, 0.03387934978931181, 0.00600121678754447, 0.0476490945795611, 0.031749460650908376, 0.04411631459069829, 0.020925798904030554, 0.027739415546098066, 0.07664262287078366, 0.023049005840514458, 0.7121610953923195, 5.120723391732862, 16.16543971723126, 25.609917756049867, 38.73467237718644, 45.82835335885325, 55.83662209972259, 54.23722074877832, 58.86436239365609, 49.545434521090606, 49.03726793104603, 46.69068251886676, 39.682215029193515, 33.39349069902974, 28.111679976986302, 29.481452049747592, 33.22098093648111, 35.54873112709292, 26.000273996783843, 22.113768016138387, 29.055127674533477, 26.03489479710979, 23.03892570157205, 26.149414277845814, 30.042939339914632, 19.71847068878912, 32.06808259410243, 32.04988475768797, 31.870748150733213, 31.84202659514643, 36.446369463397616, 29.402788915941795, 67.00976417910668, 72.85262092467278, 23.721000379131688, 20.315147522957098, 22.247881697070216, 34.554778991207, 36.00217673086351, 41.503038098735196, 33.870133199999415, 39.37312049250449, 45.6272965861905, 43.27511002940517, 44.31891941255139, 36.82339552910098, 27.344276097513017, 19.183806527045466, 13.279685301165427, 6.619271289917731, 2.1430185677543765, 0.535910249717774, 0.0927243099337624, 0.0746020557539117, 0.03206317940156066, 0.03765042908790131, 0.07613463762907252, 0.031784915200044075, 0.06069023229722535, 0.0256573973268631, 0.013125372915378502, 0.012207154293484505, 0.06771314032976666, 0.03836600117445473, 0.07627180567191494, 0.034487010730851086, 0.022602112280325066, 0.03944762922342747, 0.05565233468528717, 0.03473883532288094, 0.023303969477814053, 0.07268582470715046, 0.05197822296571347, 0.05212125541161626, 0.00889547685566809, 0.05954128427190646, 0.02603670661037247, 0.03295123043860639, 0.05040874629611931, 0.011428349309660977, 0.07109212433739055, 0.04106099123976404, 0.022388569101871505, 0.0151798713411535, 0.06433761137868128, 0.023582904006264383, 0.08252058568741046, 0.03789724729534599, 0.07907976306253865, 0.024002233722938165, 0.036107141133998676, 0.04380312635593357, 0.033646616108355024, 0.05849758906650448, 0.04864895040349615, 0.020696604549283945, 0.02774016822748367, 0.03354995496450894, 0.025149852585708423, 0.05002752562323886, 0.03870912429486071, 0.10096729342495242, 0.03702656538676351, 0.027693940566912777, 0.0243347714234504, 0.033020113234318076, 0.012169802719126306, 0.0733897139528586, 0.06465906953258861, 0.053343479746892575, 0.2406306531760962, 0.1089920108056357, 0.1648368863689323, 0.10576985265699126, 0.13440753693782514, 0.19848691539898997, 0.26801006868481636, 0.15605221742824202, 0.1118716280606966, 0.10789533295939047, 0.25811444967985153, 0.14602958104543148, 0.18933487665509025, 0.2061117272223196, 0.15909301958257155, 0.1874448611370979, 0.12775716597154257, 0.11323971553675591, 0.17390977290849532, 0.1559334125129446, 0.1689962535015037, 0.12454797003057697, 0.08595689605440825, 0.19799156294715023, 0.2914342794927859, 0.18284453379531063, 0.13966319121180043, 0.19177501991150842, 0.11913118448348776, 0.1302711830864991, 0.12549958912835968, 0.2846281398688593, 0.1376946823250863, 0.1104448582496374, 0.1337533284940066, 0.13031296552188937, 0.18017559071942685, 0.1043059888686384, 0.08363105311629274, 0.13382223044191638, 0.18858968760938416, 0.11940696081447026, 0.3375480227893399, 0.1484167416610064, 0.12925404814943192, 0.15184998001542785, 0.11180554531634816, 0.18396994759959562, 0.1416061280836021, 0.09834920326548238, 0.14219806890093512, 0.11136653097046, 0.08529851243140237, 0.08671627304847203, 0.2527726564796702, 0.11070515194367017, 0.24303312022839826, 0.07690299317360887, 0.12597149928971646, 0.10683166584180248, 0.1415965366627901, 0.1574836527147601, 0.17427996191526615, 0.14413610281002137, 0.1717595173226249, 0.16676013478107993, 0.7500458592849394, 5.361686848825024, 16.347215098719445, 28.890899996603693, 43.94748272434358, 53.17991056749898, 65.2228460773345, 62.98881699962001, 67.23061715402912, 60.152892374223285, 60.07694352057673, 60.8798840738112, 49.75444978283298, 43.965604074539684, 42.448180260196814, 42.41294168656872, 45.493830096337106, 46.55293280078519, 41.00229655542682, 38.10613216892366, 41.1634785129178, 40.49574205952306, 34.63644666056479, 39.007206501499304, 44.402877746089814, 33.551154290476155, 45.584432924947436, 40.55728012515653, 38.656381868547015, 43.15623867896296, 49.921719258831395, 39.32488318412535, 76.53542057160409, 77.99352245946085, 42.754772324715894, 31.61197173979975, 31.420826796562444, 44.062804329779844, 46.776064672777736, 52.509291172027595, 43.235953007974935, 51.64246697579661, 58.724698558930434, 53.159663292669485, 50.55180880331224, 44.26951716023107, 32.82033043522989, 22.098423704024285, 13.54513660553963, 6.451808637188328, 2.1107065725711087, 0.6280935483594096, 0.25126730903021754, 0.16533957794308662, 0.23906015760956273, 0.166303301230073, 0.12219761227888447, 0.12795041931132156, 0.23255835407443587, 0.13458940621104934, 0.1327125827271131, 0.06917350309630556, 0.12584659631454176, 0.08756535127758981, 0.13871385505603206, 0.12963464063021446, 0.12248256634319983, 0.1662309978517794, 0.09021556350372492, 0.19389973412598335, 0.17260933865702924, 0.12934407880229334, 0.16696870987934453, 0.12245733140697404, 0.08800890852486895, 0.15218805461641283, 0.0861906601236232, 0.10293967871656341, 0.1371220928887206, 0.12770565421951394, 0.18535265969412942, 0.16159391361138514, 0.09504442253420431, 0.12772506688751523, 0.1262415223003876, 0.09346274974485559, 0.12199538804951215, 0.11897225954359579, 0.18143408931791785, 0.09320842387575297, 0.11899546434682225, 0.14379655732022179, 0.16430755025677143, 0.17083297994348312, 0.10246199225225758, 0.13551068822703055, 0.12877410938662867, 0.15690278952881215, 0.1381927620499365, 0.198066302485043, 0.1282510092301715, 0.19142289525799214, 0.1376366588257013, 0.1584777437270649, 0.18727828297884236, 0.13989764476014724, 0.19315806908472893, 0.2769218775774202, 0.15711616033748274, 0.1313070565341942], [0.014290058301881918, 0.016593334204967947, 0.08345052449693603, 0.03507627790132838, 0.02705365577111802, 0.020684776151733055, 0.06335202394233597, 0.03255724291046781, 0.051473371023612643, 0.005865751853918718, 0.08998707011942902, 0.015285435384289633, 0.01664895410349052, 0.05041439619456088, 0.04027496204681454, 0.04556341254482827, 0.01912349662292869, 0.08006230146894533, 0.003420900268998418, 0.06093693559148139, 0.034998332285472465, 0.07794874915552717, 0.12590429805699857, 0.052438078733581694, 0.03268688030901455, 0.10124663206478281, 0.059649877235173225, 0.019481704014563755, 0.013595333382967981, 0.036717747683606805, 0.01526397247348101, 0.04200833939736889, 0.020015441301849582, 0.028620485606933796, 0.06421213383756338, 0.007994026940826687, 0.049228944079650026, 0.07013770901868421, 0.01247742724034094, 0.039608771987860246, 0.018499029627550515, 0.04188707533983454, 0.025960042276569915, 0.010835628040255079, 0.07835947187437166, 0.047253839175907836, 0.028740470297634605, 0.017166946368712573, 0.04606583598820914, 0.025206158132923227, 0.03739164075663975, 0.07717369800253261, 0.05811928335817591, 0.11931538266400177, 0.004445283594841679, 0.018963805595112425, 0.06350862380537776, 0.017267905265813874, 0.04324274836108089, 0.052489931394736615, 0.03339851853407679, 0.009792413555025574, 0.022023869115078164, 0.06157420966173373, 0.0695396701414739, 0.06289079304664366, 0.027779834344983104, 0.007683848952799435, 0.22270934385878427, 4.184695347662895, 8.412655418918979, 17.075822814818352, 27.547588233024847, 38.81472795240341, 44.766763871715916, 46.78057147610573, 50.75179476891795, 52.23103430963332, 49.98611673232048, 54.72051951193041, 49.35641158011652, 47.97325834151238, 40.07278503910188, 44.96263919338104, 37.90429876696679, 37.21242404753162, 34.22802986637239, 35.83526811292095, 27.742278998897923, 30.66149123253361, 28.762077593034316, 32.33091669697916, 28.367946071009484, 24.235191729760942, 25.921073498264438, 32.26626426942887, 31.11467403750266, 27.133450661936116, 75.13081981289771, 80.29602435327347, 41.80189917164464, 38.55110153075188, 31.360412489983347, 32.58453126876585, 47.18821164100401, 45.963961462820734, 41.3368002060921, 41.39256454283192, 37.0590829080151, 32.116115939232614, 17.13156165615205, 14.004280432578057, 7.95607780256579, 3.291000709418328, 0.6839612150384534, 0.24049528543987583, 0.03800778995238004, 0.06401970787274261, 0.028803207152973742, 0.0525003808340238, 0.005100818328379143, 0.031729741547737396, 0.015349649831712728, 0.03512076845753097, 0.08650852532516565, 0.015141172409658472, 0.03578355325566184, 0.04717269514296805, 0.02907685375952673, 0.048905666466922536, 0.02031214332448379, 0.07431455827768772, 0.026700092787523905, 0.032360584309865395, 0.023112181281190247, 0.021645318258613832, 0.094881858676672, 0.023506509718455137, 0.026956590515891873, 0.027538194891906558, 0.04144505026840395, 0.01998213945978111, 0.03189303893445721, 0.06850240241375662, 0.01533686956991592, 0.058141450112264965, 0.041102551509656256, 0.04908440627097603, 0.03843506400082861, 0.025667641837630543, 0.05726554348403889, 0.01136953769732387, 0.006918203923100185, 0.05042842326445445, 0.06649162845625993, 0.01637756171065473, 0.04792281013402728, 0.09074774946296409, 0.07542522488943032, 0.03157191785923656, 0.035289326953070785, 0.03137493558648614, 0.05212044335841652, 0.01390439240382083, 0.0819261167799273, 0.038058776934180534, 0.09652537008326861, 0.028226668533358364, 0.004929610605036179, 0.014356674434947632, 0.0336637573256608, 0.08919194746281832, 0.021157034883095373, 0.02009268020159535, 0.08905052763199614, 0.15833877537760044, 0.028307642111735, 0.026768341645478245, 0.03436930898216463, 0.04486976972510738, 0.010405145998623584, 0.04329466613970938, 0.022211108664651553, 0.14706523998850776, 0.023911925363204172, 0.031831899372440194, 0.03615279997428579, 0.011220152467308987, 0.027434345928110906, 0.04336413116224351, 0.020989275034216624, 0.038895881209041805, 0.05440787847844824, 0.032603901495496114, 0.07266352388767466, 0.08683492474618458, 0.039851192850619555, 0.033185756765305996, 0.10740300655485162, 0.051173934067088755, 0.04895969098734279, 0.07992621361007614, 0.08478696488084332, 0.07213699931819594, 0.003326048289666013, 0.02290299905824565, 0.03851308622547696, 0.08454062164791169, 0.019190897038506887, 0.05691629549067828, 0.024073432019400983, 0.056208966510190125, 0.03056124104337106, 0.058605366146131876, 0.02764901334059335, 0.05417529035419707, 0.046217448618863864, 0.0348629990232087, 0.0791060628609792, 0.014633049272120962, 0.06917980033904314, 0.011228623484531719, 0.04507672837785175, 0.012117991235197313, 0.0666896392020487, 0.06897497141072828, 0.01180471873076092, 0.07125708605012587, 0.0382045979401277, 0.013593669056952482, 0.0640368337682899, 0.054838266674309015, 0.04637463070872811, 0.03854955584111233, 0.041318841113318364, 0.06363175711744735, 0.08145557791595498, 0.04442207560303711, 0.01000724088836221, 0.06407636390518277, 0.024510542636797316, 0.016047973448650974, 0.08021068503899921, 0.04028991225265688, 0.6589587405323982, 5.861326696411257, 12.935583610688488, 23.071620618143392, 35.485345625108295, 46.37735574476181, 52.55690482354934, 52.77096817570349, 55.15363154872772, 59.414059039085146, 54.968719251694225, 57.131471018637384, 52.87519339592227, 50.029270648956306, 43.961697393848056, 45.73402035620905, 40.6280553725458, 34.40861971147599, 37.068951591368645, 38.21407971843597, 27.410232713145597, 33.76850851120488, 35.251584129948775, 36.34776107726559, 34.39190649217175, 26.34419525823286, 26.82925908796249, 34.79729521659113, 34.39254976088001, 27.666516457834554, 79.76921081542969, 84.11025477993874, 39.338831132458104, 33.23154780172533, 30.893397446601625, 35.55723874799667, 48.77720302151096, 51.94165752780054, 46.50452290811847, 49.34794318291449, 43.25038733020906, 37.728698176722375, 23.35743392667463, 19.612399993404267, 12.134466959584145, 5.046845059241019, 1.6267298522495455, 0.44444593991483416, 0.0686670883348392, 0.024750259209183917, 0.020422335496292483, 0.0351265715735574, 0.046874307726900426, 0.0153705487102871, 0.07122219074517488, 0.022699378633631334, 0.030008472216826294, 0.037811024099468224, 0.025106758224747838, 0.023971180348927458, 0.00981733822564204, 0.060437587991116516, 0.023283018888304793, 0.06387105617191523, 0.02306812547988469, 0.04390422697930087, 0.05655325791468063, 0.025993363270836494, 0.02871361125500933, 0.06520120697396417, 0.021626614221942522, 0.07501493117982343, 0.059823851972337694, 0.07073770908098068, 0.005611470992481637, 0.007846166225781125, 0.018675610978877353, 0.03647289832212752, 0.03965806974578769, 0.05073176343895255, 0.04947938971341618, 0.020714021558242462, 0.0274925647799166, 0.0587661603405591, 0.029021998033708626, 0.026753979412117795, 0.028262862357340997, 0.04966367599404147, 0.030388601214414647, 0.03396248565085473, 0.11073229443882743, 0.021954913541013678, 0.034885525838622165, 0.049239251792671225, 0.048120342074863376, 0.01765537530093664, 0.055116444690934116, 0.009109267097477232, 0.026728734899792942, 0.06590576271616644, 0.025151432642052253, 0.04964589509331892, 0.018883504258889346, 0.0590898133363695, 0.011662305858466896, 0.05494787853451506, 0.02611402403413048, 0.1746308301845866, 0.11076561926353364, 0.10142146098998286, 0.18210380338132384, 0.2400501423905934, 0.1146359873875495, 0.14963325864124685, 0.17012300029877694, 0.22321243379865924, 0.1688466518516502, 0.22675886930477238, 0.20950522093522936, 0.11140912545904999, 0.07076282144313858, 0.10674741149189011, 0.19471316628398436, 0.14971987254196598, 0.11655411833236295, 0.1575493370933879, 0.14964807478170242, 0.17328291380357358, 0.12721577163545356, 0.11015784340880572, 0.2904163937895529, 0.14119188902118515, 0.11003221265010296, 0.28909636300898367, 0.19515694569676154, 0.17157942537338505, 0.09970631270158677, 0.1812631291367354, 0.07660492368402981, 0.17345520697774428, 0.20397596601997653, 0.18520103557215584, 0.19643594480810628, 0.175174476819173, 0.1696607428452661, 0.15536361163662327, 0.11360846429822907, 0.11832753526827983, 0.08333692131864448, 0.11285997341356932, 0.12170592938820202, 0.1288093341093871, 0.17318566660246543, 0.09151379908284835, 0.12552146859947713, 0.11687654941793411, 0.11336550717392277, 0.15692581813181603, 0.0807566222764792, 0.13610809891214296, 0.12183574298697135, 0.18699729724997477, 0.1328391864174797, 0.16198791263084258, 0.13312634681501698, 0.09709785226732494, 0.11089606871528011, 0.12395437446332748, 0.1364127874013878, 0.09131238690667576, 0.10365685192687858, 0.16914867435491857, 0.1327899729292239, 0.1486810266731247, 0.1149674429888687, 0.12294136874017217, 0.8648806005235642, 6.242801220186296, 13.414444211990604, 25.676692185863374, 38.23811600285192, 52.002921027521936, 58.41376835300077, 60.37238036432574, 65.32848335081532, 67.45794203973585, 64.71460888462683, 69.67918811305877, 62.64560176480202, 63.007095244623, 53.83067100278793, 59.46291608195151, 52.60015679943947, 50.53505243793611, 48.796316731360655, 49.03008607126052, 39.46718677397698, 46.09783195680188, 42.75955369395595, 46.82139158248902, 42.89325160364951, 36.581244084142874, 38.52024816697644, 46.548386773755475, 42.601517477343165, 40.443139153142134, 83.64151585486628, 88.21110848457583, 53.741876386827045, 49.812022332222234, 41.78065169242121, 44.38760011426864, 60.49659398294265, 59.81768269692699, 55.015909287237356, 57.142685074960035, 50.08302280979772, 41.54968292482438, 25.86873535187014, 20.375791288191273, 11.568464040756227, 5.080525961614424, 1.532114806675142, 0.4225429652198669, 0.26555647292444784, 0.19215446326040453, 0.11504864830884243, 0.12049697369577424, 0.18619577009831706, 0.10955177593014895, 0.1198580870104413, 0.07962509509055846, 0.2201033272450009, 0.19240880445126565, 0.12472377188744084, 0.10964433467316051, 0.08346681152620623, 0.28434992737827763, 0.16249382177427893, 0.18143641822520765, 0.1137404076214279, 0.15507134909351028, 0.10762069043853592, 0.07283083749033752, 0.12187643757750913, 0.0960966213155658, 0.09727009947622016, 0.14800616449886753, 0.15987478166578278, 0.14371715996774936, 0.07973004147530564, 0.08051499814516114, 0.0688753953023303, 0.09963954047810647, 0.12844213284552097, 0.12976642307494918, 0.15059417804643033, 0.06432164610633928, 0.12495829438370083, 0.12151865919511165, 0.13459573409730388, 0.13743369149104243, 0.2004596990563216, 0.09606489761462135, 0.15521649211164446, 0.1579993831053857, 0.3085448226380733, 0.10673159177625373, 0.22533918580701276, 0.19110496876941574, 0.14951515852683975, 0.08167868570214318, 0.15137702797449407, 0.0838372763246298, 0.2104375192955617, 0.13512991188514617, 0.13722182221470342, 0.18344139289711753, 0.1242018974716625, 0.19332349811109806, 0.07940007974543879, 0.16830980807783144, 0.24357174132620138, 0.3556058489747586], [0.035151955896928426, 0.0680942690720962, 0.1440522927911051, 0.012186939148382555, 0.03302377513459614, 0.047704482736486586, 0.03724311929075949, 0.054154552354086796, 0.03934077911018845, 0.062017050616803675, 0.06003208233103637, 0.0562060630369571, 0.04354324251894028, 0.036332754027699275, 0.04224763079095752, 0.11592726688832046, 0.05520066839732951, 0.027854704117823034, 0.018002822987675186, 0.019165631458764116, 0.05743861040701309, 0.035291023837823066, 0.08089890012577658, 0.07067888118927518, 0.018467637259633313, 0.09395860015384613, 0.04576060740697769, 0.013331694757535815, 0.030759136875971194, 0.014497983183020787, 0.03402241287873157, 0.06472278506525102, 0.016428602318609917, 0.05494027128142696, 0.04760200698529521, 0.06933294131510681, 0.04804571745015922, 0.04566213446519068, 0.03681565755076947, 0.008450869110322768, 0.02772055637662209, 0.025880169949584433, 0.014708868993987, 0.023976613827530417, 0.12083364635585778, 0.066533341943737, 0.01235025089925095, 0.021599310848321167, 0.0316489537456824, 0.022108629083020553, 0.1060686192865814, 0.029819543443379865, 0.03129317293754749, 0.04922736210808639, 0.01910822082971854, 0.047898984799582156, 0.055675865075881445, 0.03770106366925663, 0.012145154797772487, 0.053260431985460946, 0.026545105539562724, 0.022783209719965537, 0.05681857331505707, 0.04496828480173023, 0.02563542784041455, 0.02370364520879042, 0.02833866292700893, 0.07138761211066477, 0.08031426012636193, 0.07462785759520146, 0.4591122029289123, 2.340184594354322, 4.50001125374148, 9.38612493776506, 16.1154196916088, 21.92234262343376, 27.617665298523445, 35.025345740779755, 42.94991024078862, 44.81878234494118, 48.59034130650182, 54.86058735078382, 54.685806535905414, 60.40221391185638, 51.333274379853286, 49.59629589511503, 49.31796058531731, 52.930592952236054, 46.85327652961978, 47.75967351851925, 40.45076424075712, 46.128818681163175, 53.20189152994464, 47.19067096710206, 40.94504171802152, 45.30965520489601, 45.60043619525048, 39.481754456796956, 54.20566135837186, 65.02549202211442, 44.335605175264426, 50.02922750288441, 41.84888132156865, 41.02384213478335, 38.37803871400895, 35.2698153065097, 23.047674548241403, 19.74157148791898, 18.26077868861537, 9.578560340789057, 4.240661686466587, 1.7776720946834934, 0.6002680704958978, 0.12755115726782432, 0.023671431211574424, 0.01713457340825229, 0.020391153802554456, 0.01227646226799416, 0.019234671302500273, 0.04492400875014644, 0.049661124921253616, 0.04440378908428454, 0.027104368876485575, 0.10040267896387847, 0.0399461800923511, 0.037536190056632605, 0.011060416431827171, 0.030101990484963023, 0.04124282220859201, 0.038887649594295415, 0.07353488761450976, 0.036701521941370545, 0.03833228947534677, 0.040452027948753494, 0.027596783381135716, 0.070437379632025, 0.02423785555536949, 0.05504800622621852, 0.019245243315855344, 0.022655431999854987, 0.03565848557158344, 0.02848854419895478, 0.033374846417216525, 0.02098620302164026, 0.00604417373148364, 0.026172815536659573, 0.0475481356824598, 0.032483008990605036, 0.01472017645174938, 0.03494928350612041, 0.05313219269737602, 0.0372085265905386, 0.026955866562803427, 0.03160813658107673, 0.03356749837797496, 0.05917738101655438, 0.0319296541067982, 0.024688462726771835, 0.02264634428185321, 0.0191078205487781, 0.0986382635610719, 0.04051921769015251, 0.0420523319964207, 0.0614421590862255, 0.04828039316400405, 0.005635180934933165, 0.06851935593952095, 0.026819550792776772, 0.05631502755286713, 0.03261301794179505, 0.02926816506641767, 0.04258761295087395, 0.023049287377826633, 0.031828735429312915, 0.09647892217241949, 0.031746019000908544, 0.07962890254754214, 0.0774070407233892, 0.043370045361018954, 0.04489370614230152, 0.03928964657168235, 0.018644764448606202, 0.060690205484148, 0.02426975545653653, 0.05185305952064453, 0.07147076329396618, 0.08790529513311002, 0.045738754748937585, 0.055110921197000055, 0.043991744863770665, 0.051483127153328354, 0.024509648229145718, 0.04442097626686577, 0.028186469984751557, 0.07933319260876986, 0.10458342761041657, 0.05688452199401875, 0.02111040694158404, 0.10388212008101326, 0.014105816071312276, 0.025301578214331984, 0.006454708279981729, 0.03770603941032483, 0.031694007376509334, 0.06521593118386884, 0.026207048175556046, 0.051727398118424806, 0.06506294342539003, 0.018811744803021994, 0.03875088374761324, 0.022688617013515006, 0.044028122548855124, 0.019407989119269678, 0.024870178782411163, 0.059643246744188576, 0.01200963001352765, 0.049719278655585744, 0.035891629109579715, 0.016223233298308427, 0.0810939844156946, 0.02978063192248585, 0.029069602737323414, 0.08123385674890973, 0.06108140062180258, 0.03158685274332041, 0.05642350177250563, 0.07217207082336949, 0.09969000268967883, 0.011594033060264925, 0.09181225927726877, 0.01856306117148169, 0.02765549444443276, 0.06556948076092428, 0.04983863515418865, 0.04024395080763967, 0.04190448085747419, 0.05838389778810163, 0.10020999252916345, 0.05956785986199976, 0.031964482379055796, 0.006538691626290881, 0.041014091337039586, 0.037564213552902785, 0.033863162351471764, 0.026811177451764385, 0.011052062243012892, 0.5450792802918343, 3.608750936485106, 7.518732057463739, 13.883292963427882, 22.21766571844778, 29.66049255863313, 36.55787460265621, 43.585522482472086, 49.74244733010569, 54.97044117219987, 55.98896695721535, 61.80814043168099, 58.462193935148186, 65.99010482911142, 56.432108494543264, 52.79189402057279, 52.579372159896366, 54.96618147819273, 49.18090120438607, 52.04060323776738, 44.210010882346864, 47.51362715998004, 54.44630661318379, 48.45434096551711, 43.74418235594227, 49.47149784334245, 46.99329337766094, 40.88296236530427, 58.25634402613486, 69.64680502491613, 49.39178351433047, 55.74263426565356, 46.31331520695841, 46.90848388979512, 47.36365925881171, 42.07321736120409, 31.245665511777325, 26.396719717210342, 23.306460765100297, 14.186177407541583, 6.380127322289252, 2.867502401913366, 1.1347414457028913, 0.4391918944254999, 0.028599799317758412, 0.056932245441261804, 0.03212525933650473, 0.03500520409415326, 0.059254292413712516, 0.02232726866139039, 0.009247233786980712, 0.07435316144819222, 0.018398794683537657, 0.0469195107448726, 0.042980255994705424, 0.059873938800827156, 0.04302702183204313, 0.07483480858706659, 0.017032982488613457, 0.009675104426400316, 0.07415672884352746, 0.026878886217732104, 0.036125561718138, 0.06211704424312038, 0.03202296170075575, 0.07539999761408375, 0.037081076373015685, 0.047687142336320494, 0.015117868972611765, 0.04901519788789654, 0.029434879205279776, 0.05388300099800672, 0.058336871480869676, 0.011187429979233252, 0.02260048625870578, 0.07337754847662104, 0.09273918736125193, 0.06662010140116177, 0.04933414327341223, 0.06279964007497316, 0.05127041134983302, 0.026535948873647762, 0.04366323487052033, 0.044530051865524826, 0.07341680282186117, 0.027588124672371536, 0.030848349729973464, 0.02060913454530941, 0.034770015101399154, 0.035213070561087904, 0.046958722955276894, 0.04202562617138029, 0.08117482201346467, 0.09519711151839265, 0.06757540538186027, 0.0702911947343138, 0.02759173677693452, 0.07139898851634034, 0.04073276852948531, 0.02140397374938813, 0.0024709672828565443, 0.021801839597643386, 0.027571215196662856, 0.037689963055233804, 0.01637875872303642, 0.07580240061807056, 0.15256587385890946, 0.18027400237417993, 0.19625937686331812, 0.14420690465598338, 0.17854022282746532, 0.1419302905278821, 0.17254104957945887, 0.13738682223183496, 0.1734717697986672, 0.222779885234852, 0.1023057179765836, 0.20197439277845047, 0.15648657395955057, 0.23625243004531632, 0.24339371781435706, 0.1631185358330127, 0.14866627181970304, 0.15801413795880734, 0.0903119373645994, 0.16641855149740176, 0.19025059687274118, 0.13573098447053664, 0.22511679048259414, 0.11089940119775073, 0.09652445077775948, 0.18504705189937548, 0.14299464712460197, 0.1119617583049882, 0.14486748695133195, 0.1270994488450308, 0.17698871091969554, 0.15790402048057126, 0.08809041261913315, 0.10424018191594271, 0.18280066760076633, 0.13565538691416865, 0.10044872850900698, 0.11332275946774792, 0.13784216957226877, 0.0771854727739288, 0.19971990326960243, 0.09167388847638523, 0.10932881370066636, 0.18065962039174574, 0.1815806572595912, 0.17531902228872623, 0.19597727264608109, 0.172562193606169, 0.1287815557612527, 0.11116680418772083, 0.19099646007582066, 0.21589896010775722, 0.15310610374135358, 0.18791350776389723, 0.15945413810831888, 0.07845707913680423, 0.20792501137381603, 0.1293086855401916, 0.14515334499939797, 0.10970279484266236, 0.12601133586177904, 0.1911939268991832, 0.17235482892682477, 0.20797310637370234, 0.11174788953916681, 0.1455818639407235, 0.09361235905558833, 0.12020478010057442, 0.20218017931667068, 0.17690454850033407, 0.6546524683794668, 3.2189710390183235, 7.488656303574962, 14.284914251296753, 22.588619955124397, 30.579121458914976, 38.797242026175226, 46.89800723906487, 55.198825097853145, 60.9576685966984, 64.22018235729587, 69.4896827205535, 70.67423851259294, 72.93933668444234, 66.45943210970971, 66.75471598102202, 64.04429935639905, 68.14328209046396, 60.068353529899355, 62.91544906554684, 54.47499482862411, 61.599627233320675, 66.37466184554562, 59.40112698462702, 55.378642236032796, 59.477264112041844, 56.35595960001792, 54.52403622288858, 62.95111909989388, 74.90624843105194, 59.61985403491605, 65.35140960447251, 57.400243589955, 58.17130311842888, 56.70324233270461, 51.14218042742822, 37.83912858655376, 31.154523357268307, 25.43653722732298, 14.749204228001258, 6.5371917716918455, 2.7563301738231414, 1.0267430892394436, 0.33975873803419454, 0.14281449388832818, 0.12748012559548502, 0.0869086300653796, 0.11990436638194708, 0.12081736698746683, 0.15862772842088055, 0.09661022198176193, 0.2816967503918756, 0.1609175499047964, 0.19539670057354436, 0.17459531434841696, 0.1549287648090432, 0.11551484345428406, 0.17387431835935963, 0.18824162322186655, 0.09282228491839864, 0.19684825332895403, 0.11595744309165787, 0.11630985885858537, 0.15420239088275742, 0.1305402484872649, 0.2813295797715264, 0.13870832390121876, 0.0840284918705302, 0.12856473755692283, 0.1596930043231095, 0.0900758903533701, 0.12566576126001536, 0.19812357521826224, 0.09152246353727195, 0.0567120181456689, 0.1062301412645367, 0.18478079038041254, 0.11148685273984749, 0.15143676751082943, 0.15981309626611973, 0.14189728746010413, 0.19701222678826702, 0.07512038318260063, 0.0726505923235128, 0.14335282387272005, 0.1303804272245015, 0.09861751023920313, 0.1299233485253588, 0.08082877243718795, 0.0664126064868704, 0.37230855755267606, 0.23161471761282415, 0.08722906932234765, 0.1900380840825458, 0.15062708918365741, 0.1442198821854207, 0.12468373613251794, 0.13623010607496386, 0.08888968747229346, 0.0759256105389326, 0.087493545856447, 0.09324387842488867, 0.11268427114813559, 0.1336428126500499, 0.18546325214687856, 0.1383340439849323], [0.07342201221974627, 0.01306593215333358, 0.023126457329659213, 0.022233095388078404, 0.07285380480630745, 0.026567289530630075, 0.06225896969197258, 0.04511646535848418, 0.045016609627993844, 0.016748060983034874, 0.04769968319564097, 0.04231915275956835, 0.05493271765449355, 0.03448861568505245, 0.023124463585836273, 0.021661584220466115, 0.047907561153894475, 0.009027981338271452, 0.07624354468838823, 0.009886615556634722, 0.03964992623115259, 0.053061969247796846, 0.0382065667860931, 0.019005172427803762, 0.03176387459520371, 0.020200118287316254, 0.015093673043133271, 0.0267777300529903, 0.049953548342830716, 0.07726323069824327, 0.08387263128233534, 0.03855085819058361, 0.044240558730258096, 0.03411938045774737, 0.12709176498315028, 0.018565424552728093, 0.052830403850924586, 0.0630840348951038, 0.031914996929586895, 0.08173198243903537, 0.08288600962729224, 0.06498260378477073, 0.01053951973576219, 0.03481572756784097, 0.02098923289938079, 0.041984161662478606, 0.05644900483950492, 0.04288135404368082, 0.03461341140791774, 0.07705391249469212, 0.06041639033825167, 0.019881647876313618, 0.0744910572745627, 0.013243191492473407, 0.04470335244531593, 0.051824017127435056, 0.02848201904505972, 0.034673346296673825, 0.02203424386079273, 0.010206432367164281, 0.046418209620300806, 0.06531033619877792, 0.007878748424005726, 0.0351477079393883, 0.026490278542041782, 0.06923757102941314, 0.02525352151884187, 0.013218208407652716, 0.05407959065069595, 0.08068599663073979, 0.062813249626948, 0.05205255264656679, 0.02753006286859032, 0.4337802186848656, 1.0762845244138473, 3.3419594072526504, 3.1182301092532376, 8.478704210250608, 11.808661164775973, 15.077263424473426, 22.522641766455866, 28.59517485864701, 32.320875429338024, 35.977763898911014, 42.408658458340554, 46.49105741131691, 48.90378967408211, 47.37250028118011, 49.41840464068998, 50.184149357580374, 49.553189046921275, 52.68350716560118, 53.37007884056338, 46.21317317408901, 48.644171914746686, 48.194809498325476, 49.108557008927875, 50.11496267011089, 51.28629222992928, 42.946686052506976, 42.152586521640906, 39.52901117263302, 37.71805678644488, 33.627871928676484, 22.093936512547156, 13.69380129921821, 6.538191485789515, 4.710466515633368, 2.1237018752482633, 1.021997143905009, 0.2558410531210323, 0.057808799413783904, 0.01988375270288558, 0.09044963400810958, 0.02934737664256846, 0.03842902722798529, 0.024444065357167876, 0.03749676717204913, 0.02511870345070718, 0.02025131785851573, 0.035904449590992545, 0.05009230984855564, 0.009357905721351987, 0.008068070296318302, 0.018004594566000086, 0.03646630996597871, 0.06211933101557436, 0.027805484883907824, 0.021643203855942816, 0.015056598218037717, 0.05672045660415485, 0.03753171610315481, 0.037564891540715774, 0.0309865405001948, 0.07433456083339068, 0.0073300264569209714, 0.036991608794778585, 0.036626050789510055, 0.08268538652168167, 0.012886028853245081, 0.05324902493626841, 0.05432881054378325, 0.025082354493919882, 0.003205619028566646, 0.02044735209745986, 0.04761550545452103, 0.09210056880669248, 0.011694010407213244, 0.030692483396119172, 0.03631314983771693, 0.05435576534739906, 0.006016502156853677, 0.05887743078112122, 0.06817558930525858, 0.06253936170269886, 0.09567272954530294, 0.02382025528218477, 0.04272362037051109, 0.0472476568463589, 0.028707949865248897, 0.0433768367304677, 0.02755833534343589, 0.017585138444818797, 0.015872994178695785, 0.03357124837836431, 0.05256079069729294, 0.06030616943814582, 0.03937339530356469, 0.0684730995506529, 0.02879937671335234, 0.06868804083956827, 0.016031281350390808, 0.047223207150255485, 0.04421052425318668, 0.033974796683797916, 0.09465677438363915, 0.0692945143448249, 0.036102150071171984, 0.0763631463351269, 0.0640111506706284, 0.09987574070692064, 0.05556799606570313, 0.023720150573119044, 0.06683330367048902, 0.053622531103751356, 0.05623323234519171, 0.0795344515673576, 0.06504949092143966, 0.033448643666962465, 0.02315464170439349, 0.04017529400786565, 0.023788441565909216, 0.015357264745680076, 0.07127277553081512, 0.06926456796786479, 0.038816399586897705, 0.026852908176219752, 0.07200769133745663, 0.05756383130867636, 0.01587769125528153, 0.019966503605246544, 0.044057387107562636, 0.03889941670481236, 0.020203023675769087, 0.06646778780005633, 0.047274370332278555, 0.0868032853149118, 0.1104373582488587, 0.06062968836856946, 0.07424323549193722, 0.06355373872323863, 0.14045489711626885, 0.021609021012761423, 0.06898699133026023, 0.06362647494120945, 0.04086979484606174, 0.03749784352558275, 0.0942450021243384, 0.02304649690256244, 0.0279349135234952, 0.018313414184376597, 0.023990299988297686, 0.048341343119259805, 0.020233942984393048, 0.05423624030945282, 0.02504913692152308, 0.06781298456893814, 0.011008580050040639, 0.06805055609513676, 0.10004531426896011, 0.06863584726928704, 0.041787912918915676, 0.05965635450857301, 0.04148176886261471, 0.018217829394064123, 0.04757553098663207, 0.02693898581539191, 0.03058874551507254, 0.032457988558998035, 0.045647620929465185, 0.011914805565480024, 0.04242393443541181, 0.03590868988765344, 0.08384961034021071, 0.03755548398100561, 0.005158420000600839, 0.016293431850030057, 0.07115488226014761, 0.10695672969544127, 0.9292754386701892, 2.0872431993484497, 5.143624149983929, 5.7265883780294855, 13.160502122294519, 17.885335299276537, 21.920126484286403, 30.158313897348222, 37.493046099139804, 41.930607826479026, 46.690780578121064, 49.595248622279016, 53.85165960558, 57.49729479512861, 55.868526658704205, 56.29127971587643, 56.136075450528054, 56.97869470042568, 60.572907617015225, 62.08429882603308, 54.96280823984454, 55.53592927994267, 54.92555356794789, 56.44523666751001, 55.60103278006277, 57.19192258773312, 51.559391175546956, 48.229930400848396, 46.04918279955464, 44.35165551400954, 40.838388550666075, 27.709772356094856, 18.46910165202233, 9.269777632528736, 7.519420923725252, 3.1299293137365773, 1.4943709416735558, 0.48407431992311634, 0.08400403834398716, 0.10024311051013009, 0.02989225859393276, 0.0473815996590401, 0.0413394833524381, 0.027216441794148376, 0.05266291404803915, 0.041031952676994186, 0.022879547191663616, 0.06472136014171186, 0.011248637531553547, 0.051305479024566954, 0.05496229630925002, 0.08087312892800377, 0.037900380594956304, 0.09847023749663945, 0.037769525116609956, 0.047303818752087896, 0.05430738306454113, 0.02388733585605458, 0.10711432164234501, 0.08026461762886855, 0.03833549172287026, 0.039013927697294185, 0.04235862160942728, 0.0345923210073623, 0.04558502771561185, 0.032818295031545625, 0.03947445762253577, 0.08442794543600853, 0.04028811194603482, 0.012777293206102425, 0.013825430763855338, 0.004432528230902409, 0.04775819316085789, 0.0562724981817507, 0.044481451247608474, 0.04116558139362643, 0.025537138759729364, 0.02373945598881091, 0.010077581166349834, 0.07119382250933878, 0.05771190844356053, 0.05234897504710863, 0.020587239752433473, 0.026171652998234478, 0.036553065592963854, 0.033346738651274674, 0.004480957915450657, 0.06186374110139667, 0.02766500351079289, 0.0479268589087071, 0.020773130987260132, 0.05317492125135276, 0.041277062508367726, 0.005690024211822499, 0.036095370193042105, 0.027534285928272915, 0.03833692430728867, 0.026725109388691284, 0.03717606744518684, 0.039350933605624784, 0.03789690255578007, 0.033515454194838964, 0.08825915114533517, 0.1325525316379724, 0.10098116727726114, 0.31922785745513055, 0.17580983950005424, 0.21039028231415058, 0.229965100485471, 0.09927964003215875, 0.20836882143011018, 0.10372129524306906, 0.18722796632397562, 0.24053267053058072, 0.17599463522914918, 0.16259283097761293, 0.12212925425340092, 0.1216651045627171, 0.08983063496529095, 0.15081021484107743, 0.17035331697233264, 0.12871122888980374, 0.10194518167765872, 0.20571731451538303, 0.11092734042434924, 0.1140062707746702, 0.06971833716717458, 0.11619442473015479, 0.16009834144384633, 0.09745858008823088, 0.14737594992883746, 0.16633935332778962, 0.13972038733622721, 0.2178529592891855, 0.2574761145778241, 0.12327514558790192, 0.1836592836245414, 0.2052495259070589, 0.22693925236742343, 0.1412690340751602, 0.18849107677177077, 0.08010321822498115, 0.28011839476323896, 0.19834934132954768, 0.20126999025383305, 0.10807681152777326, 0.08021954867628314, 0.14742723185448878, 0.11923963189004891, 0.10765815213803323, 0.11385870691869529, 0.1124379508978417, 0.10539833831811145, 0.1471732890293483, 0.10266043966816318, 0.13326071863693575, 0.1684318765276863, 0.15145614953531375, 0.15105828943271793, 0.15336332542280998, 0.1516231413810484, 0.16868010433691163, 0.1361902235376258, 0.15798623703660505, 0.09375467520928192, 0.16985085522455556, 0.1406284773181523, 0.05039564236217449, 0.1592284792493428, 0.1228261337946019, 0.2177363453853515, 0.22879330771825007, 0.15153436711238277, 0.13887004506203438, 0.13768558120054586, 0.17543059533401845, 0.8409203733167342, 1.9312310483186477, 4.8651535184152666, 5.745233854939861, 12.420361657296459, 17.314467660842404, 22.556931126502253, 31.579365076557284, 38.81967798356087, 43.76528078509916, 51.24174587188229, 54.96327500189505, 60.49388362515358, 63.295871903819425, 61.69934565021146, 64.86616926808512, 63.98291818557247, 65.54697898126417, 68.46140200091948, 68.81046941203456, 62.61541520395587, 64.47567378321003, 63.36575285080941, 63.85516658906014, 65.41464605639058, 67.91811450835198, 59.60970686328027, 55.99076732512444, 53.71617701745803, 50.56507818160519, 47.02271507632348, 33.056496343305035, 20.44625078478167, 10.691036697356932, 7.408538951027778, 2.674976294079135, 1.475849019423608, 0.6105977549187599, 0.20962223320478396, 0.200240996275698, 0.15368955630448558, 0.13613770054953714, 0.1559431265078245, 0.23858657737653102, 0.17883553440051694, 0.09900436165832704, 0.12926144855878047, 0.1562495157122612, 0.2042383664558011, 0.09944388928312449, 0.18193791470220014, 0.13179369090545562, 0.17740440554916861, 0.16303071151337317, 0.2069801185280085, 0.15281525080002126, 0.10070778880148165, 0.12443720137760525, 0.2348629150900149, 0.26474965976611264, 0.08140911468334737, 0.1383669398004009, 0.10495139496220697, 0.10175761271027789, 0.10476374172515447, 0.2329258617734717, 0.20348887199596052, 0.27860889511723674, 0.17874769475911895, 0.13285749591886997, 0.11512079846955116, 0.08163654320542851, 0.08786804027735226, 0.1500273495912552, 0.09294561741332855, 0.24007376854217824, 0.13314373701089813, 0.0920405611395836, 0.08835231509780692, 0.09540049254053062, 0.21015644163614322, 0.11954809719276045, 0.2007747450543027, 0.13677649530431918, 0.088027493817912, 0.14209371240388963, 0.12141103916350873, 0.1394401830170424, 0.13265331816529075, 0.08893024416700487, 0.18702858428080238, 0.11339741473596905, 0.19042033131324476, 0.21661111544216835, 0.1142608954180633, 0.30039046019796406, 0.17391168812830604, 0.1959271092087992, 0.09174341861639293, 0.2128899965675608, 0.13286635189527465, 0.20389030206828349, 0.22769381832932273], [0.07443476513388657, 0.04772849576247316, 0.07251562295301307, 0.06350845909647404, 0.06460630139636417, 0.06996130195236014, 0.03395086026660377, 0.049676243666439295, 0.08872743004993086, 0.03799465537491826, 0.023564853059548526, 0.012875178175407552, 0.045796326256447265, 0.08672836957679642, 0.051862164475624604, 0.005316965726970305, 0.030128234742029063, 0.011591924403253342, 0.025921716812937975, 0.03235449008042774, 0.045176518990868525, 0.028028224947892373, 0.017564835199605555, 0.0278808813421957, 0.01912548845153182, 0.05459281976424879, 0.015662699213041174, 0.037995436784601024, 0.03649075200120288, 0.02510111598718551, 0.011598739712949724, 0.011337160906423966, 0.06112193050343664, 0.0862431371464364, 0.024117748290600798, 0.02610315899214437, 0.036165329342287396, 0.030855307723545743, 0.054718611401415644, 0.002133211805372529, 0.024401317650993026, 0.038510914366211624, 0.007825901284964095, 0.020710507129889824, 0.059866756726537025, 0.0706252473736963, 0.03479143491976204, 0.0050611349739014145, 0.08170868570525801, 0.0910435053670118, 0.02785842922035485, 0.04348235002027885, 0.007694199279461417, 0.018239540325838233, 0.09027101294768435, 0.08599513150270909, 0.030593874473725597, 0.06637638584981043, 0.049846916564650116, 0.078553146562509, 0.03946621068603089, 0.03541623707860708, 0.02077397368397684, 0.02237078054026971, 0.05778307035084694, 0.028026704263362675, 0.10988525400358824, 0.07273392736791603, 0.025870783457292185, 0.053553384007705804, 0.03209106308678466, 0.01454076536315223, 0.037619348900813254, 0.11774564552451335, 0.0478192963336985, 0.026808139913144614, 0.09005852314012666, 0.15492723263319463, 0.658268035659867, 1.1999557527803606, 1.5071546815095411, 3.107473744500068, 4.3249392028777836, 6.442094397160315, 10.888348587097662, 13.427969524937293, 15.633546710014345, 15.217618576941954, 22.34091247281721, 21.892573795010968, 23.65553209858556, 19.820311107943137, 19.43871351980394, 27.36455867367406, 20.634459833944998, 24.117381380450343, 23.045982045512048, 24.62355736763247, 25.650610385402558, 22.98815061969142, 18.24351437630192, 15.287397542307454, 9.726757291824589, 6.2087025853895375, 4.105378158630864, 1.3880079071367941, 0.41873845001382215, 0.16965018615366953, 0.0662089190295627, 0.03969931975007057, 0.10793316238109144, 0.022561333420115615, 0.03493359402543114, 0.05694451433936915, 0.012886813135757562, 0.04390647544735863, 0.05922042366658008, 0.05508670515771355, 0.04140774944737073, 0.04607613220991147, 0.07688810042436085, 0.042587563155158874, 0.03127244642875608, 0.025780817921904307, 0.036799615669635036, 0.052714027434347145, 0.02775726730995361, 0.05958215506266683, 0.012671235993865037, 0.056567599080623164, 0.019470323778448567, 0.03414680257499699, 0.044996017184589183, 0.037083451245580955, 0.020636508782063762, 0.01583293352591535, 0.009765639739681878, 0.06399058504030108, 0.10466576674051824, 0.0058978145487696655, 0.05909470863820565, 0.007297157454529718, 0.04843639164802529, 0.03795536272528191, 0.023882321810590166, 0.09304545399162079, 0.04776149883025116, 0.05549250959208416, 0.008232427757203339, 0.03614338092325676, 0.06005119622474717, 0.016303829578382355, 0.019821630633105675, 0.06107021190766847, 0.01571791212735397, 0.050881893689473795, 0.036921806693557775, 0.02557151504011164, 0.09766035998660712, 0.026188407341138493, 0.028398536528731068, 0.022426727941379915, 0.05014142757582088, 0.03264103760762561, 0.09272306121044582, 0.05955397068793255, 0.07303444833885278, 0.026495076167667587, 0.023664350643934264, 0.0894120445234641, 0.0031749860453043855, 0.06298730863378414, 0.04804223175010374, 0.01834949692561021, 0.1076435428413172, 0.037726815714831316, 0.059615778661663496, 0.01936866391089655, 0.026152500800127466, 0.0676056735157486, 0.005693900616719358, 0.023655153758403276, 0.037884082074367234, 0.016450104491424658, 0.015229378815650221, 0.040438027691937266, 0.031861778716706944, 0.07562324329609833, 0.03369404461174723, 0.04121974380987306, 0.05471103862228413, 0.022035000372617956, 0.07325515060895875, 0.02909051502243646, 0.06890777017801039, 0.014965694224942597, 0.004667680834480111, 0.04066266765397403, 0.025776977906183853, 0.025475200551051288, 0.057969494016780976, 0.016603982827115445, 0.0584534049454716, 0.03283741658613567, 0.04269484993851474, 0.041117720050557006, 0.012783112601497242, 0.030880354968230092, 0.01952386374825672, 0.0016437664899351678, 0.03790094366958065, 0.0674761510303905, 0.05145790753886104, 0.05968701717774234, 0.03531110683275807, 0.045826609712094075, 0.015315069580420613, 0.05524189158853504, 0.02663378404723781, 0.06451960322597335, 0.017691492516126846, 0.041403306137409904, 0.03294290306286947, 0.0033488396448158333, 0.013631956216188209, 0.03415936258651557, 0.03786841940675532, 0.04267293982388031, 0.044191192024417465, 0.05129898642940868, 0.10705170161541432, 0.03311556012880418, 0.07082382502454905, 0.06577743532797022, 0.016344801875792684, 0.02003289278476469, 0.03347111302578161, 0.026801229800067605, 0.02739967087343816, 0.018820587372888, 0.03278127000216515, 0.06325689880477806, 0.09126662081407924, 0.04833533698993345, 0.05006199191895224, 0.0764623853648382, 0.02045661793090403, 0.04841525528219439, 0.020158749539405107, 0.022324491592664874, 0.026466661966556025, 0.0509630415528532, 0.1497370175897114, 0.5184444869237562, 1.1331949286883878, 2.4013519960065044, 3.407563990162265, 5.8605500671171376, 7.5147930172181905, 11.042795835002776, 15.841356823521277, 19.19657188077127, 21.686021781736805, 22.055059940584247, 29.87401266251841, 30.680157792183664, 31.758215350489465, 27.78019851253879, 27.61343109992243, 34.577968043665734, 29.452956030445716, 33.40682675761561, 30.858890395010675, 32.34141295956027, 32.97629171802152, 28.343837222745343, 23.146881095824703, 20.728916391249626, 13.885620890125153, 9.825046985380112, 5.784189854898761, 2.294522321993305, 0.8308261536782788, 0.23075786359127493, 0.05852301552471134, 0.02589214964950037, 0.07888894588235887, 0.03542570209491157, 0.01541858338074939, 0.05543949247728433, 0.004874394339088712, 0.02133536099966976, 0.033786373528381514, 0.06392674310313118, 0.06864777525826808, 0.09799746165592825, 0.005215827756816702, 0.08354304493555138, 0.05083186048713904, 0.040958094140214306, 0.012699426114258748, 0.008853338189393042, 0.019331154330903967, 0.0647141742369821, 0.00844012376957483, 0.027294626812480634, 0.019341799122611844, 0.08343828241190604, 0.055409607387358145, 0.03977557997249308, 0.01738829406789474, 0.08646499620930803, 0.01761158188474515, 0.05601838681726687, 0.1142475808099393, 0.14301234375565283, 0.045479127551398935, 0.030583643369496833, 0.03762003071906586, 0.049379809774578586, 0.020274107059043263, 0.07293321748053835, 0.020728247810996348, 0.052377442874374895, 0.009472050906849966, 0.054076032172287666, 0.008023922564461827, 0.013718527982071524, 0.04816563702338646, 0.07638199975894344, 0.04147857427597046, 0.05972097785542569, 0.027955255073104656, 0.02359411761825604, 0.07678280930004774, 0.029947487787613948, 0.0389124708430421, 0.035276253662642934, 0.018020732208125053, 0.01252650283277035, 0.019495497427640424, 0.043750078597616766, 0.030178796545031573, 0.05263434279890311, 0.055522141872995326, 0.022003698020031857, 0.09800367462899416, 0.03748087850849956, 0.07115272189220113, 0.09199095694648643, 0.05587348128638922, 0.05662889377544484, 0.1885136150785031, 0.18838546389052946, 0.13894962627560864, 0.190474386477182, 0.22385530414119845, 0.19106545395428137, 0.1107885406142281, 0.24421007642822884, 0.183493057866731, 0.10904629579595021, 0.18268224572943104, 0.1269842062385813, 0.10243190797947108, 0.16356032341718674, 0.1142582294320868, 0.09836481613737923, 0.288538130060319, 0.15050096046780387, 0.14217215980733597, 0.14876373352543001, 0.23019616792519249, 0.12845777636093478, 0.1172307501697252, 0.20222010781928418, 0.1785947529659156, 0.11691893706278456, 0.14149515258689083, 0.10865984274254692, 0.15794630853399155, 0.11006891592255524, 0.1348074961213335, 0.06898611799002656, 0.09251822462125171, 0.09842617978011409, 0.16627566077776496, 0.14968657836077676, 0.12602344005098268, 0.13115028430136944, 0.13910269064287986, 0.13578615812284334, 0.08533336177107789, 0.13623724601441814, 0.10640270256948088, 0.16149968479669866, 0.11572374030947687, 0.17379787810627492, 0.16132359182642353, 0.12647572303971938, 0.25000537835782577, 0.10556610391264963, 0.09626644768662031, 0.1313758512297946, 0.07335996675875879, 0.10976140822974906, 0.23396600999178427, 0.19174397802881657, 0.1212947010513275, 0.12527701760371848, 0.10091331486980762, 0.15745322370240766, 0.14722605716557274, 0.12275151683077698, 0.12273149129243628, 0.12548491088373045, 0.141164371142945, 0.14552492828619096, 0.15741301940814142, 0.1872173330235866, 0.07376782430876648, 0.13279941113245103, 0.11357618901397913, 0.15247645607638746, 0.08363966394456164, 0.26713807676588336, 0.07228485428758206, 0.11684540028293287, 0.24767516871854184, 0.5959947707672274, 1.0429833565027484, 1.994011647278263, 3.293003079391295, 5.253960913227451, 6.875495708757832, 11.342713006081121, 15.79696539909609, 19.263328659919, 22.238264045407696, 22.96030375265306, 30.632106796387706, 32.67228253426091, 32.8428840637207, 30.654246614825343, 28.20776039554227, 36.82940067783479, 30.438520177718136, 36.919015069161695, 36.00296120489798, 36.50116497470487, 38.200877020435954, 32.322330628671956, 26.64477432927778, 22.65559050344652, 15.285979605490162, 10.997450294033175, 5.812969755741858, 2.0812534949471875, 0.7214700442648704, 0.29569762007844064, 0.13474331327503727, 0.11840229012793112, 0.20901209013837002, 0.13695041258488933, 0.32087369010813777, 0.19938078678904042, 0.1564242450460311, 0.09604624337366513, 0.18595719499693764, 0.1625697717310921, 0.1482245914878384, 0.1256436979277961, 0.21457661574165668, 0.18256460526777854, 0.17378644807444465, 0.19823016869204663, 0.1487080389333348, 0.09986899913318696, 0.15026713511155498, 0.14560025005090624, 0.10238873892493787, 0.11688574247302548, 0.09537733370257963, 0.11925049501681521, 0.1977173341137748, 0.1468962409924115, 0.06590295883436358, 0.23962690945594545, 0.0922563681078534, 0.08566997314412748, 0.3233622194778535, 0.23467939106687424, 0.1428317002231075, 0.08963019572078221, 0.06601595680319494, 0.1246398239726982, 0.15592697737438066, 0.15259731410732194, 0.1776609990385271, 0.19536008157076376, 0.12663316176903824, 0.2244345432207469, 0.11264448054134847, 0.11532758858295218, 0.11777194532295389, 0.23621227171632553, 0.189723237267425, 0.14800811036219522, 0.1482614096734793, 0.13345421712485053, 0.22115780130749751, 0.136495049922697, 0.2615453284834662, 0.11897031368026811, 0.0964673619056421, 0.13697477418088144, 0.19319448890464921, 0.18111732728298635, 0.16769932793273082, 0.1707668818773762, 0.178737536433243, 0.19045497380918075, 0.17312644800591856, 0.1758981694377238, 0.17225447140874403, 0.22337544198718765, 0.24419314588510224, 0.16855434334326178], [0.07956445157047241, 0.03678579927392064, 0.045016755184699456, 0.007945924280061117, 0.08303056275772472, 0.026455867787702914, 0.049801070032821554, 0.06764783133422175, 0.030644453513706406, 0.014260449003608478, 0.017710577681540482, 0.0798144567036821, 0.021387148543351123, 0.011788302424153494, 0.061162491028587666, 0.11344116601732471, 0.03756556186764952, 0.03409321089425395, 0.005046219242015673, 0.05584877878127079, 0.043749094174634066, 0.005545802414417268, 0.02324526224495663, 0.037201018928880655, 0.035309996005267866, 0.06451306849597924, 0.027808807790279392, 0.016430010005170782, 0.06520353588125398, 0.03201811427941486, 0.03740752175931008, 0.0016214976306899542, 0.03625198920828201, 0.053829731074191874, 0.024412981339640195, 0.10144254372965905, 0.036245818370051926, 0.05023117094571072, 0.04600337300930293, 0.03229231438449314, 0.04682193029551737, 0.02722545481857754, 0.024556867973578554, 0.0658622642438258, 0.06770531857205976, 0.024850413713964726, 0.03411946855785866, 0.00977583253951443, 0.016260610728134072, 0.012203843836041709, 0.04965899136638449, 0.039088383782655, 0.04638974945391378, 0.0498893118703798, 0.046116562500115366, 0.04713769258570768, 0.021748992937406706, 0.031060956365939592, 0.08019311864289545, 0.047663569810890385, 0.04876511997633404, 0.05560206782613551, 0.0661301345474297, 0.053195724368936596, 0.034953098623983325, 0.03562188189056131, 0.010850953629180309, 0.03911029389728943, 0.03825093093778818, 0.12595879755193187, 0.01127791645440964, 0.0939636410123879, 0.02738942636267072, 0.02620552749102635, 0.027039657429521604, 0.010382516718950244, 0.07070692000730384, 0.04075329202497679, 0.08502092047203934, 0.018446939479139064, 0.08425477126072492, 0.02074018537607645, 0.09938080194256, 0.17226369510735237, 0.3394226705835712, 0.334954294225862, 0.7374483707451052, 1.573822717032125, 0.962776892608212, 1.356093297081609, 2.2618139222744973, 1.9291519469791845, 1.7148251831531527, 2.543817628775874, 2.647138987818072, 3.5636473567255083, 2.3794261918913935, 2.304075989992388, 4.392009771639302, 3.0253702017568775, 2.7168456344835223, 0.7215110452905779, 0.36279325523684103, 0.07785662708263244, 0.11793231050814353, 0.06955442499489554, 0.1320865203536326, 0.04198822958935653, 0.017339762397891572, 0.032313297532739184, 0.007627173768161166, 0.08579347417840073, 0.026028429030350624, 0.03895169071432564, 0.014368531560795683, 0.008092234624669918, 0.058719222133438435, 0.1145020445748683, 0.019577175806907397, 0.024664095385120283, 0.09549956303089858, 0.015379029303608883, 0.019806418042149276, 0.10541504669574, 0.024725776954343723, 0.026959955557099274, 0.058265081381485354, 0.04142487534291802, 0.02163160528476921, 0.0192385247247594, 0.0623286109147293, 0.029684415109635844, 0.009017256107331525, 0.054185912163267215, 0.030893905148390802, 0.04337655710837534, 0.014277097051812997, 0.025612113869658885, 0.02550451490547388, 0.07102090114307019, 0.08426603275321184, 0.016489845302496708, 0.074861797864639, 0.034612354206582235, 0.03969743900421647, 0.12118318163219, 0.03825820494262922, 0.0023360386107777876, 0.0205276821619801, 0.033726476944021644, 0.03337289672344923, 0.004386435593328169, 0.004275767489396517, 0.02522511306338974, 0.02893855956743562, 0.03496419157712691, 0.04811947256506932, 0.050270662778207374, 0.06591415903981655, 0.03354270394230562, 0.043790424618149, 0.06731881189250177, 0.02822853204223418, 0.08225374960250433, 0.03048361526922353, 0.021498648810290524, 0.010107116728660562, 0.021163728576333776, 0.014230678826870938, 0.049743605777621276, 0.018340508799038587, 0.04025273783613117, 0.0520091537656563, 0.04114909901193554, 0.012325878769549872, 0.005476612225925971, 0.020315307267611066, 0.05041180298693719, 0.12058934857768398, 0.04404570426671736, 0.046455138888690746, 0.05729344057580156, 0.08626654879340241, 0.02965097345652119, 0.09243693503160631, 0.015797649431342802, 0.04082343503532391, 0.044781144843586994, 0.03076923391481321, 0.022159681182294604, 0.07514954814987798, 0.06555762171985642, 0.035139235006945754, 0.04543693525896919, 0.03480899365498655, 0.013627767630462206, 0.005955777718730632, 0.024232592531329682, 0.034014273194536086, 0.023094183960629087, 0.10876658177303691, 0.04641429491100773, 0.016926720347856323, 0.0537153541470968, 0.08594542771818177, 0.02335902821693209, 0.053918942012974334, 0.056654925443111896, 0.03453570710975797, 0.025358149977100473, 0.032889384160479235, 0.07402637132233189, 0.011612822324217809, 0.030639052593840227, 0.06458068341617623, 0.025713564978251537, 0.016839095211077123, 0.0420855840427741, 0.018089482853669795, 0.08564401042437361, 0.06143053753241416, 0.001525430444387659, 0.07257466534933738, 0.010390619056359416, 0.01857833504947203, 0.052169239328753565, 0.04172011413761685, 0.029586453531538288, 0.03757647095969127, 0.027908108107024626, 0.04273694646995395, 0.0156836258623028, 0.06269966177041493, 0.020196803041823932, 0.047316110632832975, 0.052218629017231934, 0.031264825769129305, 0.03782753329423647, 0.09671827868348169, 0.023530622335871863, 0.051544559743976405, 0.04760913926387026, 0.03473375232950334, 0.045559605087844596, 0.010138529206385777, 0.030782257409525976, 0.04944160625699067, 0.029997662716214697, 0.03478750105827086, 0.057064154290504036, 0.010044573310522303, 0.029524189735492392, 0.08808586205686293, 0.026610634785385865, 0.048162695245757225, 0.028788465706090775, 0.08238769241518552, 0.05130005895250267, 0.22508902745621823, 0.2856778948297424, 0.7917629626970139, 0.7155587872670544, 1.5848182237917379, 2.4378670559775446, 2.325997626589191, 2.4786214626604512, 4.132075280912461, 3.1804445385932927, 3.852377437776135, 4.551836550235748, 4.867500076370855, 5.291352377783868, 4.092042100044989, 3.905925880516729, 6.460042672772562, 4.451006631697378, 3.706750619796015, 1.5942518917783615, 0.6435560218749509, 0.10937598939504355, 0.1494609041800422, 0.036255057390418746, 0.04861731097222336, 0.05619678571219406, 0.014267729711718859, 0.03560617708811357, 0.018945695276582436, 0.022547698970283234, 0.04834843326299902, 0.04871923130966964, 0.04948661009210253, 0.030916439624683514, 0.03983577916158303, 0.08182635681042749, 0.0266739442914484, 0.049116126141480865, 0.10940313955108005, 0.016706502628362468, 0.09874279625833997, 0.016951392209457777, 0.07597162944054411, 0.019784810532244946, 0.02348002414369295, 0.057105722221275496, 0.020080531962336074, 0.05210103452085488, 0.08789477674590965, 0.0055564467273201915, 0.03583825576389509, 0.006511742089529552, 0.044260423390134696, 0.039277048255767555, 0.013078474927873862, 0.040457750625547864, 0.048325213138014085, 0.030756493872632424, 0.05364902242417297, 0.026049350891562722, 0.035808853309361205, 0.021210006032619747, 0.027596346711018876, 0.06635452170045146, 0.03679667006156618, 0.019672440755511486, 0.020690811009356574, 0.0203024274143841, 0.09026064011718958, 0.024258469066192067, 0.06043481475283062, 0.02605464647433931, 0.016439206890701767, 0.05412433018547393, 0.07692061319586731, 0.04885743740164945, 0.07010790053755045, 0.07365438200893902, 0.004504508415852944, 0.07813326909296936, 0.01718277757566783, 0.057685489901491714, 0.01262726829267077, 0.031048336982606884, 0.0244723110189361, 0.05368291415394314, 0.022226332746926817, 0.07983324884046471, 0.022036655122534405, 0.09891450720568819, 0.05215756031834791, 0.03139519669686354, 0.07771361378892776, 0.07480029632607776, 0.15329529681513387, 0.11484030303695511, 0.24895271226283044, 0.1192720220874875, 0.22961083078576675, 0.19438307431917037, 0.21160660011153068, 0.22310076882281613, 0.2297119237482548, 0.22734120337953492, 0.13052576942549599, 0.18477386494557704, 0.06528903129360368, 0.15183167051403754, 0.15068471431732178, 0.14310539279493595, 0.23090337433161276, 0.1545084123649905, 0.09260951931918822, 0.1376541103086164, 0.12815470431721018, 0.1344067402063839, 0.14324999955152312, 0.16282973600731743, 0.19044879914051105, 0.1521799647279324, 0.1898776039841675, 0.1366610611758886, 0.15876593068242073, 0.13826071404882018, 0.10435131063023884, 0.13061538639087833, 0.110840282192634, 0.15900176318903125, 0.11233356375727924, 0.2132604920095013, 0.14160500959523264, 0.1881623637652205, 0.2019638973738878, 0.14926060283135983, 0.15370296284316048, 0.10708394625614728, 0.1253520482550225, 0.29145315589924015, 0.1816097073136799, 0.1012345661799754, 0.12237615673051727, 0.06392004366423334, 0.08466942401062097, 0.12234712965906629, 0.15833077741967094, 0.2334424501825725, 0.18710145456415994, 0.190503130096101, 0.110038019596569, 0.14119751210654938, 0.15563091503516321, 0.08966953433569401, 0.18115546313985703, 0.10221561837580898, 0.10643518469747036, 0.14378669010775705, 0.19572994882060638, 0.13508535621147003, 0.15988939862337806, 0.164914368501594, 0.056379371277627446, 0.1112925805031292, 0.153482559347345, 0.15800506747778387, 0.15568132362058087, 0.18456144408593256, 0.1191780997079707, 0.07265642225261658, 0.08538043021314567, 0.0692103978907389, 0.21372011412055264, 0.139374575247207, 0.19267730294696747, 0.0975951046172169, 0.2054995003967516, 0.1441983551147484, 0.28526580081351344, 0.49946484246080924, 0.7712431444275765, 0.7470567067784648, 1.420681986116594, 2.14705002884711, 2.129004429424963, 2.6456041153400176, 3.4501155778285, 3.0649488779806324, 3.2497501229086234, 4.041557518705245, 4.1253856785835765, 5.980544196021173, 4.100003040605976, 4.064263874484647, 5.8041684473714525, 4.2439388267455564, 3.855453556583774, 1.7121180122898472, 0.8724292632072204, 0.3290986858548657, 0.276683654876486, 0.16927396037405537, 0.2641020090349259, 0.12667237014900293, 0.07931792447643896, 0.11047468205252964, 0.11118463105371884, 0.1975656793482842, 0.17310394034270318, 0.16906085003527904, 0.1370935637744204, 0.12315318439035647, 0.18724454446665703, 0.2095250779342267, 0.19375293635793273, 0.11944702721291012, 0.24409337059384395, 0.17143288807522866, 0.16501271886931312, 0.23290195983023415, 0.1708404722833826, 0.09733693298673439, 0.1189895501480468, 0.11578970047975741, 0.12049599310323117, 0.09582712690556243, 0.2136087555798792, 0.11110131133107409, 0.110993338899026, 0.15786144131373975, 0.1634532856124063, 0.10019473971859102, 0.1665921470210437, 0.07839294991666272, 0.15212548055475758, 0.25651115022840043, 0.14238965216903918, 0.1113791484385729, 0.12727512812782682, 0.14070202175888324, 0.147427553611417, 0.17310597813658177, 0.13725747594669943, 0.10178460964872953, 0.10448889236056036, 0.1081230449340036, 0.149468059441255, 0.08589686540466163, 0.15923155892279842, 0.10465907879293927, 0.10878755726040372, 0.11558423569846539, 0.2500479728464158, 0.11796771909200376, 0.18904440675772008, 0.17056186142708027, 0.10273767665268914, 0.19571759948326697, 0.12479884850402033, 0.1571465587063182, 0.09991499505216077, 0.21602911844609246, 0.15283762056741024, 0.12228899890737188, 0.0879339621432366, 0.2678638378218297, 0.09444544902972637, 0.1437938760124868, 0.1343946206954218, 0.08522257779634769, 0.12735038860550812, 0.22537595802737823], [0.012337421799348968, 0.02169694300861128, 0.0488435750406596, 0.00957573228891218, 0.0468245656379769, 0.02110487961721036, 0.012423854711796007, 0.04638370118975159, 0.054767472489226254, 0.02979336430378739, 0.05367136537848462, 0.028458534619740905, 0.050950810959142064, 0.083484094469778, 0.04257804068226007, 0.008384042303077877, 0.007785619903100475, 0.014077829921828404, 0.059863485531100345, 0.07843179823530298, 0.015692108370844397, 0.024895896354029258, 0.014800251792034796, 0.010660624830052258, 0.04281858079916528, 0.04014033741588074, 0.017664106788053628, 0.044034515552583246, 0.05441232944928831, 0.07491150164916631, 0.028483712099372383, 0.01827329224456222, 0.044258063839327906, 0.027583114457346743, 0.058855202739998225, 0.03120450592119127, 0.0702169225100548, 0.012300346974253416, 0.05862814577056035, 0.05552494192435857, 0.09083919737848545, 0.05411074361613682, 0.02824763635984592, 0.0453535006231358, 0.035268194417679505, 0.0624279227227934, 0.01848191905376171, 0.08097053700757605, 0.027387064896644126, 0.06656462897456462, 0.045378969216178504, 0.03386061127868391, 0.13297257764685538, 0.012012215560272098, 0.012901587141377312, 0.05288666917852337, 0.047257344028161424, 0.04105769323125001, 0.033195164325016166, 0.026644501617298495, 0.03094955569043035, 0.058032680948775624, 0.08587342311417864, 0.01925907694854804, 0.03891505255934693, 0.07616882047225391, 0.04025387930713835, 0.02936633540347459, 0.04003675083719915, 0.03471061264375045, 0.05348756556369124, 0.028155567913105892, 0.031186328569967902, 0.03686788559500729, 0.05565005940415206, 0.05480886421977513, 0.04775843830899366, 0.03973162567783748, 0.014452341579711966, 0.025973100245239276, 0.0199409564881916, 0.030503499081298232, 0.03324907010180816, 0.05305580990088563, 0.09743017354799856, 0.04489010935949703, 0.01406134754013751, 0.08732623225378414, 0.05168394561135962, 0.07286773228477086, 0.03258848014558035, 0.10070249513392487, 0.020302892812798103, 0.01866088102331325, 0.04644205793738366, 0.06470324216230262, 0.09804682836176888, 0.032555457925604235, 0.07832932631455122, 0.06502972585299323, 0.07650311825977218, 0.029018837921020967, 0.09217666432021127, 0.05569307907154003, 0.0365979966497229, 0.018982978860637354, 0.02727777287814646, 0.021173844767373898, 0.02865818479368764, 0.04272864207685475, 0.03609632397250783, 0.004079266415623528, 0.04890950073698356, 0.01586704742118356, 0.03241439049522723, 0.014685379780618655, 0.017127644142977173, 0.08059433421059962, 0.022678678937917276, 0.026007482271280982, 0.00879863472354989, 0.06391997854675978, 0.019391916594618273, 0.09694996665442183, 0.029727243255042744, 0.029069711904852625, 0.050502557592887076, 0.04527392707044079, 0.039746909131926876, 0.05421361007216958, 0.027465994935482744, 0.02281414051990836, 0.03416810748017123, 0.04724374596750544, 0.021188369794418255, 0.01325269002512458, 0.004028219583203956, 0.0022050971869424347, 0.00844875758048147, 0.04289754531196049, 0.029042077198204015, 0.05277829071987541, 0.020613817257746574, 0.043882481573570165, 0.020054626699176528, 0.03899097570308274, 0.038827798975211, 0.010335200255916966, 0.01528156185222249, 0.03715429522637879, 0.07693505395324, 0.027096776945155956, 0.03247007742644318, 0.0721492720467429, 0.023865146119327798, 0.04379721598759775, 0.05900354034477665, 0.026420288749279517, 0.0324285592913868, 0.011049408705965167, 0.047947911004866325, 0.0491462180751466, 0.023569332758685755, 0.058088862006702734, 0.03792487625633517, 0.06735628891375757, 0.03911928776952048, 0.029321818034194654, 0.027984619223242326, 0.051695475234620036, 0.05952022451486799, 0.06341020448974545, 0.05366508728794513, 0.04827295445025929, 0.05335823843075384, 0.02815244418959464, 0.04357836765026854, 0.04159785033534131, 0.02868017726277392, 0.0665244093585399, 0.012070272576003786, 0.07376518896630696, 0.09082733833741757, 0.1365816178581407, 0.04669418130370398, 0.08020127747928904, 0.09403733100982443, 0.04637564194478816, 0.00758819425696387, 0.06736342885321187, 0.04545109256380989, 0.02439376019362, 0.00725838335065712, 0.023796064140755805, 0.06342903493092426, 0.060527136008585655, 0.046463136846620234, 0.0425695983933345, 0.10458262321809608, 0.0346558028832078, 0.015524011443278965, 0.057090860115544456, 0.04981516988106793, 0.10809267720868511, 0.023433476641413667, 0.0516822065917715, 0.04176619432626232, 0.031051479858316244, 0.037369316954526215, 0.018078397561405456, 0.05546136428752253, 0.05096661152258035, 0.023890735371218576, 0.06506582391598532, 0.021612535441114057, 0.06388142900240999, 0.029705174177164034, 0.027941965362838203, 0.05701727737041731, 0.06742912089271892, 0.047061600902628516, 0.0309460929730126, 0.0263373673923554, 0.063003821658992, 0.025447740129405455, 0.01383910830613346, 0.05188444997334192, 0.06251655909563265, 0.09223372254881168, 0.021283470034118623, 0.016347013954674045, 0.04145523540735726, 0.06677099007872805, 0.0675758573737356, 0.014337120040680372, 0.09825883553393426, 0.07605776070587097, 0.00810370008806668, 0.04138523412327613, 0.018092832573118712, 0.062098033771279364, 0.03316685354577438, 0.06867099538325303, 0.05566625067243173, 0.0534345637706499, 0.05856897696972855, 0.04789624603525285, 0.09274200656481328, 0.02825697880208252, 0.066366181558659, 0.02216919790953398, 0.08278600450965666, 0.02046016300277364, 0.0471376427899926, 0.05827750732761718, 0.088751224740859, 0.07246375880053929, 0.03525529732747424, 0.01618377019410893, 0.056059161847036694, 0.03886135745673411, 0.0710550686644931, 0.044086245639670285, 0.05044902719917798, 0.021712569287046794, 0.008950131483406069, 0.020037583158081098, 0.04045443346483573, 0.04201451789647822, 0.019053098888346748, 0.11156206725225334, 0.05412333810161199, 0.007549235334379539, 0.15487696194360334, 0.08173617293998119, 0.06300329688876387, 0.1071718778280962, 0.07774487783711764, 0.06042641076830126, 0.03348701318065005, 0.11907571971776987, 0.021506872764157674, 0.025336213049388705, 0.028229428365105586, 0.042852388259263775, 0.014216768585385816, 0.05167612002321309, 0.0337468548828075, 0.02478858275759605, 0.04431122651083335, 0.00905274034237429, 0.07185026792989624, 0.020149020222766746, 0.004301448671838209, 0.04285198989354315, 0.02239948010913307, 0.015079064704027149, 0.024300500480157715, 0.012615784634685805, 0.103309576609923, 0.08422042753907942, 0.014242774397585423, 0.017068676440225496, 0.04112451525044538, 0.03891050965795594, 0.03739673524133621, 0.024899357156227195, 0.0228639917763611, 0.06282829559378086, 0.04034056981664993, 0.01857939799646697, 0.012012779592506349, 0.04137951527692137, 0.04220117138878953, 0.06056842431726475, 0.023644493644936912, 0.06403015348159018, 0.03851518530638949, 0.018251071864318465, 0.051363996650663116, 0.04620008140562042, 0.040805504747456124, 0.04061468373683672, 0.03653934495823999, 0.010812762230935117, 0.03931114299883766, 0.015605837294471361, 0.045140374962600975, 0.0304826614897578, 0.012571045099907826, 0.04306374808713313, 0.027582107051726312, 0.035057232955530766, 0.11807569152405185, 0.011990900121388898, 0.0396361289876363, 0.07283433851215147, 0.06703797172033979, 0.004269549249476123, 0.021344171010798985, 0.017557099626790133, 0.049322621311031045, 0.02795468816804069, 0.07617392261782963, 0.028165967556678002, 0.049143594224005945, 0.05828665441743309, 0.013309811455978742, 0.036138412843067805, 0.021272135763278893, 0.025280269478718122, 0.005214363092466468, 0.09795456839304778, 0.08829758577649632, 0.2034318137673601, 0.18016098908359007, 0.16950070707788392, 0.1653933879588881, 0.14029132202267647, 0.3006006440808696, 0.1160686101103502, 0.13861832389187428, 0.22365693333408526, 0.1369666230053671, 0.10819548620812355, 0.17332457366489595, 0.07597316927727192, 0.13380681675287986, 0.123222362129919, 0.09311409546963631, 0.16706117669180517, 0.12278613634407522, 0.13869960582064045, 0.13927041793302183, 0.1342587320194129, 0.1305924037531499, 0.18471199568481217, 0.1515537031715916, 0.15017848341695725, 0.33314464133112665, 0.23641701637496873, 0.16002282049627076, 0.1468621654015395, 0.13391872687685874, 0.1604999706990296, 0.16232097701680276, 0.14544954523444176, 0.15699888759803388, 0.1325066582930665, 0.2479787540411757, 0.15606847381399525, 0.100002842354438, 0.22005852642318896, 0.13131935990625812, 0.1259024594459803, 0.16138331604100045, 0.1345562499256865, 0.15683754948118042, 0.1738614787257487, 0.15798269771039486, 0.23267876777437427, 0.15229605769197788, 0.20425108351534416, 0.2041749037321537, 0.21601678443051156, 0.11048673261557856, 0.0893876139795588, 0.2019265582484584, 0.10487654051112552, 0.12665743143447947, 0.1338010404499308, 0.13091463565586076, 0.19287932033260025, 0.15107267656393591, 0.21672325539252452, 0.09196319392011051, 0.11109968722467461, 0.20496743701158032, 0.13149074909667816, 0.1517528247448706, 0.133674620620666, 0.1461020529630684, 0.17595231653221194, 0.14638493858998822, 0.15532051153000326, 0.13570630111761633, 0.13124086653753636, 0.32172827650943114, 0.17677445144903275, 0.1330401772452939, 0.12440987502134616, 0.17465534499816357, 0.15363381574711493, 0.11932492045865906, 0.16645848000001523, 0.2271940838545561, 0.2387369604360673, 0.2396716489907234, 0.1466638099161848, 0.14660883544673844, 0.09088133221432086, 0.09184697838199717, 0.07345483908730169, 0.23289483521253834, 0.08940681214294127, 0.11908189438643957, 0.22865728114641484, 0.15978294304542004, 0.17994306771264923, 0.1759966577012693, 0.15305777891508995, 0.1763427609037007, 0.18049777665686223, 0.17510159121405694, 0.21689104396970044, 0.11953970852998957, 0.1721856154261097, 0.06014175164783674, 0.1945978087643462, 0.06905767826303359, 0.146997916181722, 0.1848767811973249, 0.16293982284203654, 0.08139917852296945, 0.13825870689845857, 0.1954128650287467, 0.07226327359075509, 0.10185065408868176, 0.1281001358743637, 0.1351142530479739, 0.23605545351822532, 0.09818241060260804, 0.18232302710173592, 0.1632211609713493, 0.09991236737058048, 0.13435565746359288, 0.23484561682468463, 0.12478367996311958, 0.08968789746323902, 0.11756333958117232, 0.13259137229573342, 0.11303168436091755, 0.08675572657657248, 0.11748421802035264, 0.09766105712661821, 0.07418578655849542, 0.18080343041689168, 0.16215940907357201, 0.09669004834347195, 0.07240238749692518, 0.17491123368663175, 0.19345809975939413, 0.1152269169688225, 0.09113946554040717, 0.16824642196297648, 0.1014226484262655, 0.134521086489962, 0.12016005588755493, 0.14249937128155463, 0.13711149023184854, 0.1362387935120252, 0.14839092449795815, 0.26277885261562567, 0.15214374409087245, 0.12863901744206108, 0.22788123407911873, 0.17892548844458597, 0.14866841686589105, 0.15741053728326676, 0.2784718266658245, 0.15413699761754082, 0.0938082937031023, 0.23864003499188732, 0.11735570677105459, 0.1084837650940303, 0.18197025893436325, 0.12822084068771333, 0.13496339501392457, 0.14293389635220652, 0.21231734584416115, 0.1022977889665673, 0.15392033263079583, 0.11786454237036167, 0.09875002812834517, 0.15399801394631787, 0.14180763985120481, 0.17755903273580537, 0.12142200954258443], [0.03559009690258292, 0.11479566309360728, 0.07642293949761698, 0.048306773401676655, 0.025566583349099083, 0.04220424723180552, 0.01854897089933436, 0.03745783075329758, 0.024096876225103776, 0.13777093871706916, 0.02851741230716148, 0.07487803892863375, 0.04603913399360834, 0.010349217749711488, 0.05050253077980973, 0.081941599416877, 0.028872626210232417, 0.018890975531370893, 0.05955218570306898, 0.06934855418700366, 0.039414185655093005, 0.027992151782757817, 0.02749611942788526, 0.023063576832834273, 0.04939649133912979, 0.07359066647627661, 0.015542082499802835, 0.015061073129125422, 0.029452547108033494, 0.01996388933020494, 0.05121363657376459, 0.06979993319198971, 0.04247837264331118, 0.0841823912736389, 0.035723503453717116, 0.059584974266228184, 0.03269040048302662, 0.05994345361907637, 0.07880810828458878, 0.08887291014675172, 0.0382619051473035, 0.05277028127062706, 0.054112677988145626, 0.03753013796203079, 0.05022311170074729, 0.051397398084161744, 0.031385063268845124, 0.06212902585825613, 0.014189404882340422, 0.01807564347531767, 0.006459799413043525, 0.06916055621038522, 0.019384989244562965, 0.034596032703355435, 0.03307117682491099, 0.017740412975751588, 0.04794685380353082, 0.0463300290697765, 0.02832367250155057, 0.04603642204235639, 0.037637210240767854, 0.03371076065025503, 0.05020898503942355, 0.03437012486580399, 0.007069885022863145, 0.03294584101005908, 0.04454372270453361, 0.015028501943414731, 0.03233354140613829, 0.018714652734718496, 0.031568594952864994, 0.0529196952289391, 0.035632852269637014, 0.03622990672386462, 0.02835973034492664, 0.017427015982027498, 0.010409621867321191, 0.04601733113128332, 0.04764145668295603, 0.020522842401518457, 0.027883551158611814, 0.04116442460086077, 0.06806342637226467, 0.08862904137781552, 0.03383034697523521, 0.016765116015449166, 0.04382343917724587, 0.0721806816516384, 0.07173957588571696, 0.035119960234770854, 0.0390385574240598, 0.025760920703290932, 0.10151441043783581, 0.030016338024588845, 0.006244905047013515, 0.046820241071644335, 0.08483770288406842, 0.0376710445139437, 0.02545108793363456, 0.02394067664300242, 0.05740659559265741, 0.0356410647321853, 0.009422811563126743, 0.07687350644940331, 0.014745077182118212, 0.07755840437546854, 0.06477630396764125, 0.036689184095350005, 0.03186337217958945, 0.07503795978282729, 0.05494486780897264, 0.007227441538200384, 0.012921564799222737, 0.05104819222563698, 0.07542744654441073, 0.05406259499009579, 0.048327932750145276, 0.05090438603093067, 0.03813402209010336, 0.04716856209861656, 0.009954364542218467, 0.052510458720667716, 0.05370437993758148, 0.04847961049827357, 0.041202763471031384, 0.05667928320866439, 0.03489034453166589, 0.049743165277064814, 0.03403655869225341, 0.06410661288687299, 0.016940984905006427, 0.013036416700830864, 0.04033161424881509, 0.02942951275937019, 0.04348757090948282, 0.05110332757354744, 0.04955590274485369, 0.022472156955289747, 0.04956937440100217, 0.04898141341043576, 0.06641588534318632, 0.04943973700245542, 0.030052644846540306, 0.04462519232484122, 0.04560110407070287, 0.03381159697328845, 0.03327407138121705, 0.033314788954392556, 0.03479675156995654, 0.004372443476196138, 0.05604447211108862, 0.02513661458637686, 0.05236065788795391, 0.019757472684667, 0.022758963037162058, 0.053731821207029205, 0.04139363044692625, 0.09199762957230692, 0.02879009555814968, 0.019886750021889325, 0.027432103205712575, 0.01900910628929494, 0.0532696939884655, 0.02320738494276039, 0.021209567447283098, 0.022578357809012937, 0.03680159983735892, 0.0334386270673525, 0.05947793263100809, 0.056570774515069304, 0.05233365711906264, 0.01917979642448406, 0.07077890928954848, 0.022138238381293994, 0.03309291456976245, 0.02041519938727781, 0.0664043020937712, 0.12278684114496555, 0.06487885249718543, 0.030526361060178572, 0.02966736007722155, 0.028811352582828655, 0.0879961378391712, 0.1030403120262969, 0.08171758764693815, 0.08780515978052732, 0.02028160322938235, 0.07462667015891883, 0.03457087820636169, 0.008952764910645783, 0.05718328096272965, 0.022257223327253616, 0.04707025769617289, 0.007435730789908238, 0.01969787678981741, 0.03183981306069801, 0.042687361429054896, 0.03440430387854576, 0.02424965330940341, 0.043957596494545864, 0.013812371837576071, 0.06308437963466972, 0.007155421612438776, 0.05003416760554237, 0.07223165714212003, 0.039343724718257304, 0.024955141763653488, 0.007814387462267113, 0.05107918431261375, 0.0158119312254712, 0.05321338652603088, 0.040229663267851844, 0.04568780224109369, 0.03719123215564797, 0.03437084115801319, 0.07828686206090836, 0.019192802682218534, 0.04970207998168565, 0.04674497293308378, 0.01275217509828508, 0.043358875799082944, 0.08190447479606637, 0.057045515371306296, 0.03717603680166987, 0.04866815239731823, 0.023034023075935342, 0.02383690620321901, 0.03241710627691881, 0.07981362932872388, 0.05359064269390318, 0.021760491917150158, 0.029263829008766243, 0.011744268647875759, 0.02112998240326922, 0.011545825062409766, 0.03388474687873837, 0.008555734098227996, 0.032557093523322575, 0.035935250155988245, 0.05274706497608174, 0.04674309984810891, 0.054905988846815405, 0.029090275619960124, 0.06164250640018333, 0.04385497135620925, 0.013315036175622335, 0.013025363009693402, 0.032190922647714615, 0.03609096135703787, 0.05629225558931789, 0.06880687639838265, 0.01707453509762643, 0.03861050962680771, 0.08666084658715033, 0.060490930693284164, 0.05113629999780848, 0.021337337506514405, 0.03983038973303572, 0.03280108869676629, 0.050517887012251926, 0.01276969457150347, 0.029798993134811044, 0.026887579400452877, 0.06158406155243997, 0.050981649828533974, 0.027275185416182204, 0.0421025145859007, 0.046770594743711334, 0.01022568224148164, 0.03927495300529465, 0.06584949355812804, 0.040899856136210506, 0.024287272056925203, 0.03695027069038442, 0.045893692201183695, 0.03886852420926575, 0.052597237330290585, 0.09024753235280515, 0.015779257575500638, 0.04269980269694521, 0.057050552399408434, 0.04383242155815806, 0.03986010245317894, 0.0546164995419883, 0.011318250983623008, 0.07521812834085957, 0.04245657361142578, 0.026949169039125406, 0.029507014044230024, 0.02039286026340579, 0.011961416270013058, 0.04623609519894085, 0.029341897198690042, 0.035517058079882015, 0.03850855481540484, 0.017117541358475725, 0.05209102941256377, 0.03310792606263872, 0.031220976811563297, 0.07552092459293143, 0.050891010135772734, 0.052248855016284415, 0.05598343405572157, 0.05239280293725672, 0.038507884488471096, 0.0114184208101623, 0.004545325580458608, 0.04966767497300621, 0.11198625013592745, 0.05379122749511754, 0.01827646384856874, 0.03338925270063262, 0.09718336300143311, 0.017164245908779484, 0.016547470436161085, 0.018200728396374374, 0.03515233128001133, 0.040533849969506264, 0.009439330333994042, 0.006349262980473859, 0.028408750395981536, 0.0652374888980581, 0.05689198369040124, 0.021447958687560695, 0.021784903308857354, 0.04368446699734177, 0.03176051721487555, 0.028772569381661957, 0.01773936343529532, 0.023180248193262566, 0.03964011647528218, 0.026907618345332243, 0.02152598282742885, 0.03925041903951957, 0.047281173193046165, 0.015878394140952056, 0.04672874719084752, 0.014934148639440538, 0.09204822967970565, 0.06450073448039832, 0.04924861721754555, 0.0160273245062619, 0.042770730947414716, 0.06276160763997225, 0.04002231007982646, 0.06571925095012111, 0.06910974925924694, 0.06325770702753818, 0.09322889374508973, 0.06271075472355851, 0.03745238386815594, 0.020830436279216123, 0.09467867683739432, 0.2919724102943175, 0.22309293940422997, 0.15055880010608705, 0.10707943399827327, 0.11504258089248212, 0.11231618888315656, 0.15341571051507227, 0.13760894176460084, 0.22303165237028755, 0.10989769527147855, 0.17980963051799806, 0.1430098463090197, 0.06432276459470873, 0.1738906513539053, 0.14348558690999785, 0.13158393603178764, 0.10220346822132988, 0.14079338540473293, 0.14515302324246976, 0.12174008158786644, 0.07110177704523649, 0.07759861633061402, 0.1390571084113852, 0.11154486857835325, 0.17235764813038612, 0.09058608958918242, 0.14759005618191537, 0.24289419784420924, 0.10554367285822669, 0.12893841992462837, 0.13309322117317107, 0.11604728988341748, 0.2634490263317862, 0.24509346773547513, 0.09717504328657543, 0.10827164300867628, 0.12145252282460853, 0.1537562978844489, 0.17216713738537606, 0.14668683851918868, 0.17297419569184705, 0.13696755763263474, 0.14894385611818683, 0.12012774995978802, 0.18454293540168196, 0.20221629270142127, 0.1738279547181822, 0.10856402812585716, 0.09027136534812952, 0.1008059093428235, 0.1704674027860165, 0.16101053765704557, 0.19332660842807065, 0.11758999944093729, 0.1298301769120078, 0.1699321524750802, 0.08566782043706025, 0.106225828189523, 0.16072317807664796, 0.11303937588367732, 0.09415931519000761, 0.16429068100067878, 0.15523002122438725, 0.16765455775443586, 0.12200314852018511, 0.1102875037899902, 0.15471663506280992, 0.09562150890668554, 0.14767086313616845, 0.07928333560665769, 0.13694891105255774, 0.17222125383634723, 0.14893190514656807, 0.19274534687640207, 0.10130523013011103, 0.15321076667356878, 0.2175579081860281, 0.1331979760359372, 0.10429334075700852, 0.15107282978152076, 0.0671517970641294, 0.18114705149444843, 0.22502390998265437, 0.14616836553379414, 0.0975897190191092, 0.14215317614857229, 0.2482966805297521, 0.17784164257107243, 0.15748749847613996, 0.11724954996738704, 0.16394998637899277, 0.20822023101631673, 0.14761124617390095, 0.11371129628030524, 0.13177600959616323, 0.13906320647126244, 0.17056343956820427, 0.10973268759346778, 0.16861596745589089, 0.1401260615356507, 0.2910590189839563, 0.11421774934616782, 0.14787379982731036, 0.10310335340158594, 0.1770102379903678, 0.23306695984736567, 0.14014228727788697, 0.15863541994364033, 0.18755525440698673, 0.12357522222784259, 0.09980319218049127, 0.11528099511539745, 0.13070158660411835, 0.13037310342394537, 0.19710336060773945, 0.09862930033235781, 0.115836194355882, 0.0855446947858699, 0.17411300071304844, 0.14080671533461542, 0.09343496373584194, 0.18658505001616094, 0.11487614829093219, 0.12153617962593995, 0.13410171463845239, 0.12353608279579109, 0.15279493414826933, 0.12899832800030708, 0.11218400041182196, 0.08475197764534144, 0.20048429047869099, 0.22732044239678692, 0.15465816723242884, 0.15829657925473106, 0.14524452478414582, 0.15223584318112943, 0.15959489910352617, 0.13562771581834362, 0.08958567069062302, 0.1891883087134169, 0.11536705743281112, 0.10463898430668539, 0.20550357598450877, 0.16357425089565017, 0.17636175988422287, 0.16603713164166098, 0.14562052073738269, 0.12759424205268585, 0.1375319958934861, 0.1893323025996647, 0.07885683147657303, 0.1290528428169989, 0.10252255150267195, 0.11737262965330195, 0.16914944044284283, 0.10044520450455528, 0.1847304737255458, 0.22392008453607562, 0.13761746066231884, 0.09220153153423341, 0.12194792890260298, 0.2122528718844537, 0.1628066614390381, 0.11996899355923939, 0.08589931688601933, 0.1868399121468106, 0.16001802478586474, 0.12174144522437166, 0.14961813606562155, 0.13231856838589715, 0.1373676240684525, 0.18290556035935882, 0.13577494259563186, 0.13530134704084168, 0.13208051422430625], [0.030631320851464427, 0.04494239486032917, 0.029393989262321306, 0.013550007790927927, 0.036086870447522214, 0.05744388492237176, 0.0763571325449213, 0.058059605108874465, 0.04505482209365695, 0.035283952846281955, 0.08089019736695675, 0.02715666203819696, 0.025831937053871733, 0.03144068508258751, 0.06007129837188029, 0.04378225429043655, 0.05561146772496643, 0.07056726217870751, 0.018533472940626166, 0.028863818114323002, 0.03845659873238014, 0.006049912687646406, 0.03024969798242373, 0.022762885407334375, 0.008192180370491358, 0.05088075987934586, 0.013908980312877366, 0.01984655147328252, 0.03690890960335251, 0.04483088693251053, 0.037569442102986, 0.049266574318490686, 0.03324527796658297, 0.030810131518650922, 0.011036532683177822, 0.02874288730503571, 0.058658953996435295, 0.02161622415446947, 0.03217362821282398, 0.023036736942407106, 0.039094416725058714, 0.0466971920292464, 0.012482074521211608, 0.02264118467968318, 0.02908344594611516, 0.05470157743641927, 0.024779910642293193, 0.04134763069751282, 0.09829791367895181, 0.048257724622324596, 0.012430019804366655, 0.04239496865099476, 0.025096611390190742, 0.02310664629593732, 0.023567714397945715, 0.0725530693307519, 0.10887112979206348, 0.0757147831421706, 0.008638157498001332, 0.033684931995887915, 0.01384950316165604, 0.03914086080546822, 0.01677550033726279, 0.0238737914215533, 0.018881326653964577, 0.027716199251552744, 0.06517483822761044, 0.01529941265846813, 0.036757396564127943, 0.04767144136431237, 0.017656246725950512, 0.02597869077186671, 0.03135080764731092, 0.061777242113866156, 0.07075855433340035, 0.047907476884222804, 0.05460145357515543, 0.08359171450138093, 0.022185875643645565, 0.02859757574755819, 0.05070126547868695, 0.05203518543332335, 0.07707092730749039, 0.003275703385307063, 0.04848948537161754, 0.05965584122966375, 0.08148232970627085, 0.013828678976654286, 0.09338411081942821, 0.03675872189623695, 0.06348039729580765, 0.051660147089991844, 0.07675431849014375, 0.06247711705885107, 0.037085726526716066, 0.0478895427659154, 0.0674887148723487, 0.052501235022059375, 0.025957315003559477, 0.004098064776870513, 0.02831581052422764, 0.03455187539539991, 0.0626861249967929, 0.011104120790297467, 0.040986891385288014, 0.04817735816862795, 0.07302311789845267, 0.05545044753460154, 0.015255681486920485, 0.06113695348763178, 0.02093943909952237, 0.007955455850254024, 0.013721786728579433, 0.004712419411648186, 0.00476684038256926, 0.058519709855318076, 0.049525182619090044, 0.018803455731681278, 0.05511390893990475, 0.014550783877982008, 0.004018490745370547, 0.029869789235113613, 0.044552911929185354, 0.012431484947521842, 0.017275418673131256, 0.014163430671267694, 0.08857537691871967, 0.04015511908237973, 0.02480442737108998, 0.0933014422715191, 0.042719751626493475, 0.03852851906671159, 0.031721195836942044, 0.05695491015250164, 0.02515181185557477, 0.05264065536339918, 0.03788243498533003, 0.023947747634543527, 0.08474873709342173, 0.02963887309775718, 0.04762159202307944, 0.016931418382051974, 0.01716127923329271, 0.0073462004882223425, 0.06107928621913157, 0.007696853774119049, 0.0682143610151064, 0.051963222964156064, 0.043356964409711866, 0.005494697646598422, 0.017426654005483273, 0.03497411624618596, 0.05246879885934534, 0.019426250740164713, 0.044169936914958303, 0.034923929826266346, 0.022912921812084895, 0.012661344841152672, 0.014062519654661659, 0.03400158294807038, 0.0159628764020219, 0.01225703810867403, 0.0723010034210259, 0.030104939923471505, 0.020318986404867425, 0.029041111927419424, 0.03877794963397807, 0.041437649859055396, 0.02372391014960745, 0.027050553115024686, 0.05277865844207907, 0.033704934551590876, 0.05951679627140684, 0.15635399478337458, 0.015866284206088994, 0.05867118075970681, 0.0756328117342726, 0.03408826579670272, 0.05093566923131866, 0.01974393399582515, 0.039425171355927185, 0.058883471384404175, 0.07613771730252812, 0.05628224282014755, 0.0296585098464763, 0.04807867072222214, 0.05530884767311716, 0.015452621624835077, 0.05307431475469663, 0.043024551198487325, 0.046943071778983846, 0.012418952706690519, 0.04658049768618038, 0.021472136422450987, 0.09679628175593193, 0.009193734036788586, 0.0441472607123996, 0.03025356864166116, 0.06694856159869703, 0.007782341525589507, 0.068822473948521, 0.04489096737797222, 0.023883899951714183, 0.043426260892902656, 0.046483261976391084, 0.023517188984119607, 0.07376489785289572, 0.011790265524459463, 0.01059554183044501, 0.020422808555585724, 0.0401664610140987, 0.04436016037699677, 0.08575428878107379, 0.0399969372477743, 0.014389869024706705, 0.027681039646267894, 0.03781474728678023, 0.031014590809542327, 0.06406701380206693, 0.06623344916489816, 0.027382025953322172, 0.04393732197762978, 0.0071294229823134605, 0.038098904619654345, 0.04045112396500284, 0.04221320663007998, 0.07312713731681147, 0.04764811781745765, 0.06163703653240397, 0.059925508009450096, 0.0626666893461539, 0.04252814920619131, 0.039575508450187986, 0.014171466933593396, 0.05698917343491509, 0.04151835339143873, 0.019363893098348094, 0.055110047856766375, 0.11248547899266405, 0.12176972152965686, 0.04450531871688943, 0.021625528292309855, 0.10783492692656095, 0.022413725514085065, 0.07619463763530217, 0.021037697536690582, 0.052625482992058804, 0.05157412690741401, 0.08267081552936185, 0.02406678620665785, 0.08185470206362587, 0.02071492745721292, 0.057431650498221, 0.030892539596665772, 0.013951309543523579, 0.05739722633734346, 0.08872317060107186, 0.02946733835063154, 0.017856471465840455, 0.030309119592270548, 0.031574051414105686, 0.05156690652872767, 0.02972559425078573, 0.007790838398279683, 0.037607505181503874, 0.028062312030083233, 0.01942774461161706, 0.041398678966347253, 0.08834147495367835, 0.07401824312945528, 0.029169950679305102, 0.07852690805110239, 0.02565661783240015, 0.07969855526161772, 0.027509049076827306, 0.0416457231697296, 0.06670636290143575, 0.03172734943819383, 0.036996714770793915, 0.019416615269297076, 0.011585666422521877, 0.04839393505526166, 0.016596312371773586, 0.0276481093568427, 0.012657286490373796, 0.038100023108023795, 0.007139940890708879, 0.02977367392891357, 0.04542099679970453, 0.06041085535299875, 0.05612637840151306, 0.04202419358696188, 0.03971511648306924, 0.012468407512642445, 0.030100492783071055, 0.059272019688280365, 0.04941617213790456, 0.03850036150505466, 0.024681228941546816, 0.05273074347285494, 0.08897116858391993, 0.018848268044812065, 0.06697719796530663, 0.03958475513143405, 0.09924024779109225, 0.040269656887938904, 0.050195655109541076, 0.045075215354201295, 0.06747538494246622, 0.07267587322501406, 0.05097338757027061, 0.019813452644513983, 0.03541157543358784, 0.01977848264599039, 0.057525909956424474, 0.024370151279013486, 0.0828333487433772, 0.06220910885942079, 0.033644758345138644, 0.022060591539728547, 0.060115854045556444, 0.03304679224628114, 0.018498211828691345, 0.058518587536509, 0.051283296948719415, 0.05589511943981052, 0.07637387156606683, 0.007618471488146292, 0.027655147789647023, 0.010227993911793156, 0.04547602106486598, 0.06005047993253797, 0.03661680410826399, 0.018906126835293347, 0.047340874424985344, 0.052824585413139676, 0.030092023681068135, 0.03086527452744063, 0.0763510498068025, 0.03529728277616444, 0.1013090375870947, 0.05302181474924569, 0.01944004415324138, 0.021616028802048777, 0.028695002979328556, 0.050669308120925585, 0.042581986035070116, 0.006667581610306497, 0.04958543926477433, 0.07148004827960845, 0.009932717770308016, 0.049999544261804515, 0.10526297058189109, 0.16625364341082113, 0.1345266176447753, 0.14914360588356373, 0.13983706252709513, 0.16356943986348568, 0.14365670030876515, 0.23195735809783782, 0.14825198679201065, 0.13486953392144174, 0.1967502093964046, 0.038535540262537624, 0.1196059521528021, 0.13597850747887166, 0.11063093334556588, 0.10240746211380729, 0.14253772164304412, 0.1671711409524564, 0.23333297621819282, 0.1393911993551639, 0.20109210463781513, 0.09839837078846271, 0.1923849331515451, 0.21096815775719382, 0.11702040540835551, 0.09460836528770386, 0.13380834892872842, 0.1528760781812091, 0.16544679960896894, 0.162774317206875, 0.2790486908728077, 0.17938121882898195, 0.17267808738735416, 0.1279740837673026, 0.11101140325228054, 0.12293108017934908, 0.14477808449056842, 0.16742391932395198, 0.12824477327446784, 0.1967182022429282, 0.09807738760906844, 0.19208937643035767, 0.18291032542624783, 0.09315315063201612, 0.1331356011571423, 0.14340153174294581, 0.07753084819283217, 0.2195110187054642, 0.14810921864644175, 0.10359616244151708, 0.08517701088661149, 0.17148286765140874, 0.14141316585723432, 0.2088709307774421, 0.23139803730432065, 0.2299564743354436, 0.20461695178622202, 0.1431055460125208, 0.1014148266685586, 0.24298283421704847, 0.1772428988929718, 0.11372147758881893, 0.16800110528786338, 0.25608951075663494, 0.14261307405127635, 0.09902139945376305, 0.1900421137050275, 0.18784714922789605, 0.2168844709353101, 0.11713020112966338, 0.14113435581807168, 0.09168216222596746, 0.1252342622366644, 0.1343674552176268, 0.14529413663812224, 0.18273103020844922, 0.11175070874272816, 0.11531695528256318, 0.17702045760327773, 0.1136227518380169, 0.10953728154662157, 0.14007948338985443, 0.15293175745154583, 0.09056825506230516, 0.19369931020323308, 0.16011680416282148, 0.17809259765330823, 0.14089366631402125, 0.24270976983731796, 0.10134999264752674, 0.1376081297114011, 0.13623844111158004, 0.1549797556212833, 0.16660423588848886, 0.09619475717866614, 0.16057015967465219, 0.15053721174838083, 0.2932257914254743, 0.11302017772029485, 0.18949814531351292, 0.15813070589736586, 0.11386151080049815, 0.15788433202091726, 0.08203538390056742, 0.09386308431144684, 0.15621544012138922, 0.21233329579474466, 0.16285304040197404, 0.1135432319114766, 0.13284154596828646, 0.07911628247388909, 0.12512881023388717, 0.15514371375883781, 0.12455433622122773, 0.12421698940377082, 0.08257237323109182, 0.07704369288178221, 0.19345809975939413, 0.1700956049946047, 0.15815839231494935, 0.13844396228030806, 0.09089345172528299, 0.23648738921169313, 0.10767173487693073, 0.16399161559679817, 0.11880654706469468, 0.10376519208113033, 0.1778561675981168, 0.1463614196907128, 0.12077023725836508, 0.16119720264067575, 0.14311187389877536, 0.12652235481167032, 0.2309252538027302, 0.11218727926813787, 0.11461265234937591, 0.12081378935686043, 0.12985057017255214, 0.19843669067467415, 0.11161158717567883, 0.18266028964952116, 0.19148367667390456, 0.13609521331325655, 0.13138862957637157, 0.15443757987551152, 0.09808653469888434, 0.16967485418483136, 0.19206024976747652, 0.17948723007594386, 0.14380268602361604, 0.08813345143871923, 0.10641237059908529, 0.15470692106793005, 0.10048866467249971, 0.10699878026160503, 0.11714851063105369, 0.10165127204550851, 0.09195304325511379, 0.08836965166753338, 0.17547919595193479, 0.06739963416851337, 0.19639696625451888, 0.1978463586419821, 0.12798863177698466, 0.14492466775400026, 0.1282149494715756, 0.11187943449664502, 0.08808236869592821, 0.1583534995875051, 0.12064018617233924, 0.08380433454388574, 0.09007993529761031, 0.1424918329763797, 0.18011123933378728, 0.10863794794967098, 0.13269813430886115], [0.08841459038517169, 0.06089966158352553, 0.047076780934848135, 0.07769108314307467, 0.03313476212262627, 0.10468120341219249, 0.02127837554942216, 0.04859663042870741, 0.01094017893211135, 0.04815097793095535, 0.04865643508251637, 0.05815263499595946, 0.0751932917703544, 0.11344923292316737, 0.019948749517601345, 0.017697743793588974, 0.03373078618859572, 0.01266524805912688, 0.016986676304030324, 0.03098332101569301, 0.05841377521714857, 0.07316770167240212, 0.01344083164322881, 0.04978682079742994, 0.03783951873981184, 0.0024333269891118814, 0.013523950267793431, 0.015115009549434389, 0.05779211018835345, 0.05309920112091688, 0.01853828588801046, 0.0625649260567321, 0.009195740229540296, 0.03443180643502743, 0.011848083137714816, 0.07506971412728872, 0.043275249641268485, 0.012190534973577147, 0.014338295028034239, 0.08204255448353868, 0.024756483673568697, 0.027842513743727922, 0.07651995687234787, 0.023026456042463263, 0.052668855059891946, 0.047893189344434976, 0.09248647793766954, 0.02107117749420145, 0.029767305823042992, 0.07066580406840771, 0.07225221894200771, 0.039833599641438455, 0.026532708321728056, 0.08394037643747945, 0.005841433350372339, 0.053372254009328546, 0.05266365332288608, 0.03650644531233176, 0.027122957999968243, 0.01680259303670497, 0.05176263433250208, 0.04015465559918554, 0.03321348148728571, 0.016202627448365092, 0.07567984187194417, 0.043014565242394324, 0.07680376946565605, 0.027713847361625205, 0.06264796615728448, 0.039329563582976984, 0.015644862770944113, 0.013381146690658024, 0.04734002789782901, 0.08025663499269756, 0.02568088749784135, 0.02614789469648273, 0.07966197456323332, 0.050046352233978054, 0.02841783428354369, 0.07306580431759357, 0.06583268558906932, 0.06548992252998775, 0.02935876837000251, 0.05952302073579162, 0.03958444869626434, 0.04626954259771494, 0.03556773479607317, 0.011980717855265305, 0.08568878060266857, 0.03745338361289713, 0.0356317759161034, 0.04808474962990131, 0.02560402015073886, 0.04101013449291068, 0.06027333874015078, 0.03875653364605481, 0.04770170949820069, 0.025294405716140906, 0.061631049555275715, 0.035449998573430126, 0.012713489573328726, 0.018177785978261984, 0.022453353327188282, 0.0815038491160639, 0.04050130272404321, 0.05915924771538666, 0.1041202508513966, 0.038577966211784276, 0.026856301945724317, 0.02538547058770013, 0.023405094999038888, 0.02412349586525271, 0.03506786242548016, 0.027183994140115478, 0.03381550019126266, 0.0970137817785144, 0.03396102242291935, 0.03766495794538529, 0.03720081591558072, 0.06892655465391374, 0.03176407186284421, 0.02355051763926543, 0.012915934052979274, 0.08153233226508864, 0.0016035389736287237, 0.07235012497873076, 0.026914252666756514, 0.04708515427586052, 0.027994419403013684, 0.017230238637796814, 0.03484283558904164, 0.06419171376394169, 0.02392503312758861, 0.028522479978780595, 0.031199036053411906, 0.10451726825727571, 0.051497246153772845, 0.062254645125640024, 0.027330303527114373, 0.03697381640273718, 0.025622492445813074, 0.034050807927645026, 0.03958431080043797, 0.013095300133910873, 0.03147456532103881, 0.07296956069166623, 0.06254140332701706, 0.060898573738673044, 0.04221751587465406, 0.020571699658889445, 0.029161715234119086, 0.019856648512124535, 0.013603068955783403, 0.03037154235156073, 0.05294635125826444, 0.09063554056469472, 0.04631284188719527, 0.06737954734313874, 0.04145230512104688, 0.009177139614738766, 0.029003675125779647, 0.08380801942680152, 0.04335254408238877, 0.07457584788602206, 0.029450854053720835, 0.04290058285058026, 0.08137569026721102, 0.06737740995783, 0.029421173892314398, 0.08871470532950856, 0.03020495653242594, 0.05870219965976092, 0.014735600674494862, 0.027687606934998787, 0.08241778434885126, 0.05535852464456713, 0.0644571670601445, 0.060849513468002124, 0.03323167607548737, 0.04572513370564388, 0.0628488305805912, 0.054088446627100634, 0.05546072460410576, 0.017292540738238923, 0.0554058765391669, 0.0478717350521155, 0.04387587023478362, 0.057519589731049155, 0.07535699709889389, 0.07725854224014668, 0.0009407282601797864, 0.02052786985352155, 0.025591190093226975, 0.02785321982246974, 0.05817781630603056, 0.01787212647257313, 0.039205242834624746, 0.004568890923814428, 0.020718104806878877, 0.05239267270230959, 0.0027701507121579904, 0.053227206752184904, 0.01582424991929363, 0.023705847711572726, 0.08414055521209395, 0.02804092094001751, 0.021559698356976433, 0.03486346633684251, 0.04761681546487155, 0.011545408502100937, 0.02298929694769604, 0.030401982855232015, 0.04878183218440221, 0.017485412949275587, 0.04222012823447586, 0.04780584382974813, 0.05191703552320119, 0.01350607073325063, 0.07572517129442385, 0.038428973601830584, 0.023798327930572055, 0.10070879237666246, 0.07170898599490043, 0.042558823366679495, 0.07762583543456371, 0.02536250901738963, 0.06436492241318188, 0.03960619410199504, 0.05451006311622839, 0.08688220769287118, 0.01901401499766977, 0.03723923905542301, 0.0670950299489402, 0.045297495765431274, 0.030127453332346295, 0.030277669767759023, 0.06225008690249055, 0.08226184715186396, 0.04573050781243271, 0.07654699211519572, 0.038902550004422665, 0.07011638879175149, 0.04567506985979215, 0.01527716259231731, 0.02549634457776143, 0.05692962925100038, 0.048602996619358185, 0.01205868645375895, 0.028898711504054167, 0.04151191825287477, 0.07282681552873504, 0.024297803850664247, 0.04608232220033965, 0.04832649250484763, 0.00949160625872713, 0.025278976705345898, 0.00997748124533363, 0.03930244407045745, 0.055370598190253785, 0.018937304698591752, 0.06944600823185137, 0.034604015339526444, 0.02354926891594885, 0.1312778685842791, 0.031712818665490035, 0.05027348964264797, 0.0735643896604738, 0.05194838001062313, 0.030868727668759324, 0.017908846982003703, 0.04352774839067171, 0.038037705685823195, 0.08495278461205383, 0.03117235704144884, 0.060006529468321995, 0.06461688873147772, 0.04237266400107934, 0.0378330146533347, 0.07229670566777069, 0.024824270963548653, 0.026537333577570897, 0.10452031728721435, 0.01115202522581263, 0.03966154395452431, 0.09530667741332324, 0.03741214509993311, 0.04751498322753657, 0.05311906578079347, 0.08118056767289678, 0.044428775041934945, 0.05725659174664367, 0.1272884580577093, 0.0017862097663436868, 0.023394921351404443, 0.03435210647782491, 0.03263474802576727, 0.03593218580429112, 0.06714883996474166, 0.05708839714286789, 0.09871345509084002, 0.012554108811121796, 0.07603603445233838, 0.048771827076111114, 0.02089513623486123, 0.023043340620314403, 0.05960433713851437, 0.0975323926597353, 0.05479402509668181, 0.03193323173740458, 0.02076468869833456, 0.08847754749078905, 0.06418918184335194, 0.044659528385607467, 0.11427895977131783, 0.0356654416499359, 0.036682159069084355, 0.016612831142640883, 0.1184892334464577, 0.020664273723659497, 0.03169057147216893, 0.018171364246236704, 0.05397171781007802, 0.07501230349824314, 0.02821485928800558, 0.04696226228148707, 0.04792772075762192, 0.0458315011834906, 0.025910995412437667, 0.12707459695276715, 0.028172592302003217, 0.03398185618402016, 0.02741310805563004, 0.06376368894932732, 0.04359999048193136, 0.06028393373614358, 0.023604377450781967, 0.03636352777961762, 0.0922724559542633, 0.053111964145735394, 0.09941748989325377, 0.03843979076332143, 0.024093844432143435, 0.11409700622842198, 0.06388500663301637, 0.00995804463708473, 0.09108551762877934, 0.06429127072014156, 0.061389027058237025, 0.015420326230777128, 0.034057093679063746, 0.055008583341635046, 0.03205380057014766, 0.19266902919738524, 0.18334074426562558, 0.12663404277015117, 0.15767427071207957, 0.1371890489733027, 0.17851910944427216, 0.09781586051347757, 0.1257165758720329, 0.15326020998820183, 0.13208603005736105, 0.13851533103133404, 0.19977714535930466, 0.09270572464071936, 0.21804126370097363, 0.1285438999653824, 0.09472818143906132, 0.0857960252511886, 0.06183295202771984, 0.11977036228223194, 0.16223670734513193, 0.15361090971817895, 0.19145367667078975, 0.0726369712802191, 0.12906715333942445, 0.105342383256122, 0.0950723770825613, 0.1108193756531804, 0.13527742977584564, 0.23053457960486415, 0.18161241926493185, 0.11127809378048105, 0.1208326810850732, 0.11891619722929694, 0.14789727276131032, 0.17007308200963084, 0.18377134696610514, 0.18890559162584045, 0.09940547763460106, 0.13344536114844585, 0.1748848802620365, 0.15728021040558815, 0.11753714703504117, 0.13425742966994164, 0.1208611948776149, 0.16327190663545363, 0.1846187781061857, 0.18060550394077457, 0.10131544208214169, 0.1352544624598757, 0.10565897675171014, 0.21271883720351806, 0.14687479053053165, 0.132346392699307, 0.16519846454743417, 0.06346568074678222, 0.11364044080818854, 0.18766955472528937, 0.20283480144796834, 0.1246220354110964, 0.1212735110593419, 0.2034061651436552, 0.17328985456016757, 0.14066092880262485, 0.18657228699134243, 0.1268738895774849, 0.18693303779488613, 0.28053695456154887, 0.08266668631544999, 0.1316689564696243, 0.11799208834887513, 0.1285090889301031, 0.07655601663094375, 0.22244098325890882, 0.13239942130542573, 0.14717702753841877, 0.09170426386258296, 0.15544366782471059, 0.12314186927171485, 0.11880309966903542, 0.11202715923108401, 0.12535071526203426, 0.13679975373370035, 0.13925210843163152, 0.18507017243293025, 0.17131232115770542, 0.13102911983526525, 0.10316862409273464, 0.1129064136635392, 0.26364385781268923, 0.19018932516055723, 0.09303438402111493, 0.17720865476275646, 0.17360202006755338, 0.1873884311005954, 0.19319035202985813, 0.1521276102791871, 0.21636337792921453, 0.14974524537401815, 0.18722036673176676, 0.18477119895960056, 0.09782248717402259, 0.07468134585407472, 0.17464025306605524, 0.13588980981899848, 0.10333385393624345, 0.2732210600328061, 0.17361602415480923, 0.23927625569124378, 0.25715015948780123, 0.08956695516263286, 0.12807637948783177, 0.10511398180237702, 0.15206396369443786, 0.13051197984285895, 0.20443794768183463, 0.2273050287077504, 0.11132746814720093, 0.10103596554648492, 0.14460916210326458, 0.1358996923532217, 0.12771146116598, 0.14359427946469477, 0.10547217387225359, 0.20393770758903798, 0.1067401413174887, 0.16174362251354804, 0.14715041364392928, 0.09144211623577342, 0.13829203172316476, 0.07015136836637413, 0.135128486961607, 0.21254000163847403, 0.10547953597720593, 0.06156283708649778, 0.20580254945783846, 0.18445531026490275, 0.1926294837387339, 0.16125859692692757, 0.12356921609851623, 0.17368645827856757, 0.14873059256182564, 0.17740861903275215, 0.14370669520670368, 0.12355381773123819, 0.09264338040544141, 0.15476586387282418, 0.17345972689649752, 0.14786498981618112, 0.10751275631088404, 0.10288900200037226, 0.0998688995417568, 0.12248645806985518, 0.27463697437797824, 0.15398371874565078, 0.1200170502547295, 0.13622906419538683, 0.21094280024690015, 0.16523201919851765, 0.21436689151150568, 0.19462307434408896, 0.11478240977251723, 0.15370136938027798, 0.13284494739867028, 0.23859094407769943, 0.13192594832470342, 0.19783089898767012, 0.18862573970710078, 0.13147754174086357, 0.07816134621539424, 0.35335704383830874, 0.08685282056009577, 0.10864752404872449, 0.1157113986330167, 0.1000269128370189, 0.08250324145680474, 0.09618369486903953], [0.06962250722872634, 0.019020664640852523, 0.04230130291093261, 0.04346038244905011, 0.06896001737444632, 0.05873253674156243, 0.01269706560584206, 0.019797952770585978, 0.011656474971753216, 0.023121020020616632, 0.021123788582401413, 0.06436171250477915, 0.009364026763866986, 0.02975045380392863, 0.04430640781778963, 0.07686761523326559, 0.04071126061101114, 0.04813810382338782, 0.015348064029709467, 0.03585244371225277, 0.04675426941004492, 0.03336530096167999, 0.08929792806626329, 0.022510961223874363, 0.030311707054234804, 0.07044386839674366, 0.05640343792976872, 0.02991692662509459, 0.043700604639466734, 0.05920068924165061, 0.05331118148000491, 0.030723303113312974, 0.05254677511871823, 0.04351119706106763, 0.007415158456311592, 0.07626383835750242, 0.018302181420186837, 0.00582917929521852, 0.04709394513479164, 0.03908957887981688, 0.04004734583319195, 0.11635298960872235, 0.04748586805597429, 0.024554901042832963, 0.02452787729130397, 0.026814609525665164, 0.020230319388511202, 0.04841461942921724, 0.044021760188643975, 0.03769876157504417, 0.03468504062883797, 0.017157770550599503, 0.06716413107971031, 0.009263936418949837, 0.026440028919868415, 0.008659163628885103, 0.06593526476213048, 0.0228311323500689, 0.04058822305993207, 0.02357205045559714, 0.014849681700129184, 0.042078823316842325, 0.07616110596685641, 0.07961137445583459, 0.021997954275819565, 0.048559685838558984, 0.023187321100023486, 0.02276058331312191, 0.08916329577445023, 0.03658787279780354, 0.03633574177060397, 0.019666871296301968, 0.03480720100924373, 0.057781775662254904, 0.004460506719507037, 0.06990944546076559, 0.024655189613000523, 0.06023258286257906, 0.022168715274141684, 0.02341881946420237, 0.040808136259476026, 0.009764942599670782, 0.08461619622164196, 0.016057470066082335, 0.04736406390645331, 0.04887355589157632, 0.019561386734787977, 0.020067184795475295, 0.022086609800856923, 0.022244839515957623, 0.019108102086090276, 0.07669690786109817, 0.013881379122575446, 0.05845943022699607, 0.029421020674729542, 0.043277942440322334, 0.12304016343888738, 0.0490335725067604, 0.03204045148806707, 0.051908137411960674, 0.019868836970999837, 0.011990745946194136, 0.06920269870709989, 0.013651612117105435, 0.03297273452664095, 0.03854122080449616, 0.050126190087006944, 0.003948272083840904, 0.010015037748211575, 0.03652388913436763, 0.009866036519768738, 0.007754346278811535, 0.007477081343231182, 0.05702667726924824, 0.014798603745387688, 0.12460964776936079, 0.011231865951671235, 0.02264099507292192, 0.01866031028780966, 0.024903672146460703, 0.03806327770073568, 0.026409322200643442, 0.03160221855186167, 0.0902305022182484, 0.06353228060047954, 0.002811996589204477, 0.021999103407705986, 0.030657737478313428, 0.02234130530738302, 0.11830064558213758, 0.05490904553763329, 0.021226363925022945, 0.029143907520319187, 0.04132651348388003, 0.043673511940024556, 0.026926232366672447, 0.05364360618254831, 0.024061249306185112, 0.03424571984778008, 0.01587890071659199, 0.02406107693640215, 0.006599444313906134, 0.04230357053118848, 0.04013919594487356, 0.024769060922065572, 0.015513262272091403, 0.029832836984085943, 0.058682292865048495, 0.014683092050554772, 0.024232423991986343, 0.06249330449669112, 0.015499375970853914, 0.01886169565090489, 0.04744752918580367, 0.01710233834361838, 0.05714367421704435, 0.05686874824365782, 0.05334469399625256, 0.031397305353875124, 0.08077464066445827, 0.037945821100185, 0.04390213555926758, 0.05414461236326926, 0.025058268689580505, 0.031393009515839725, 0.012893699308586939, 0.07671753860889904, 0.020582744731537757, 0.012080271938635458, 0.019906488277258414, 0.0069575286526683605, 0.030012951915963527, 0.04229718518833961, 0.02939621666296115, 0.04388620093044254, 0.020299020238340865, 0.02004394743351206, 0.0402812899330691, 0.07526939494475242, 0.05516154811747613, 0.07029153947387973, 0.06350450225234514, 0.03005453708371328, 0.03432990524977927, 0.051492055908085844, 0.040458068552036444, 0.05560622002268511, 0.05303832011357431, 0.005199078680767168, 0.04183586236209639, 0.01564322621561587, 0.02606529126604719, 0.07837830231555047, 0.00160975314370702, 0.0777039380984441, 0.024766002316027883, 0.028960540545203035, 0.025355911085141764, 0.040420989896501267, 0.019197200026903904, 0.032277034760843364, 0.018627810922841874, 0.053405521377440424, 0.038933660835027695, 0.03461510063179078, 0.0268268401193763, 0.0545432998408233, 0.010797724882591396, 0.12196177977227396, 0.023119357609820944, 0.014310484121163047, 0.04359236407664515, 0.026048314757645134, 0.026137069874112646, 0.06509102054781492, 0.00471351204455019, 0.026206691944671255, 0.08769467458008759, 0.04346502111143163, 0.04810444191999493, 0.0043912552439817985, 0.0643144908451265, 0.016204625022627654, 0.014988858808553027, 0.05517375955898916, 0.07848224512511685, 0.004856723084700324, 0.08216627002243074, 0.012603134607836124, 0.047893660488508405, 0.001879514008666569, 0.12995057529018772, 0.04575959617091764, 0.008217046626903599, 0.028378842323417627, 0.02933082339774457, 0.02034467333296855, 0.06075383291669911, 0.06280876418215132, 0.02119275181734514, 0.04128290392879037, 0.05638364221780531, 0.04068074732898705, 0.031352119572881254, 0.030925948691043644, 0.05336389599007465, 0.03453721247252918, 0.030016853218717925, 0.031545662110851656, 0.03710550691692099, 0.07993561350890706, 0.05356954080202887, 0.046996809016432495, 0.03069430668537896, 0.06643555848108185, 0.03666518639112192, 0.01664513323996817, 0.0391715885921111, 0.09019128617740448, 0.023307340264680888, 0.025847356488567688, 0.03710709654936387, 0.0766345406431825, 0.015323426642064607, 0.06667201917979025, 0.056506078389863816, 0.03694782686990596, 0.01959682213172557, 0.0604253076016903, 0.014725234547269442, 0.04651093307221609, 0.027706286073812557, 0.024928118012124495, 0.032665606047357285, 0.04645598158540745, 0.021398680081831354, 0.07870670122605178, 0.01809971587311837, 0.08673522606371872, 0.016603490615624095, 0.026398041555958412, 0.054830962025950995, 0.03230286341521048, 0.01726071361542469, 0.07199836804741813, 0.031617243451276617, 0.01750180723085519, 0.030111715971161763, 0.025793217054958788, 0.06462108689330279, 0.04216408507237512, 0.01189697391143249, 0.0799827968641635, 0.022046516589339704, 0.01547491861387126, 0.062075951286861976, 0.02184184662426912, 0.015311427789950564, 0.03367508776606091, 0.04876028979197145, 0.06695723371399988, 0.02434350674100701, 0.025301359879273563, 0.03660103418834267, 0.058421497383425315, 0.011021852523328797, 0.0805700262407622, 0.04485388872243705, 0.019462523088159583, 0.0327421190787948, 0.060939486664269245, 0.03856202009164038, 0.022099175558034933, 0.06084327751229848, 0.07300452494453039, 0.04046553024841894, 0.06645314785982333, 0.034652615957442796, 0.03452657917214017, 0.042858022835946856, 0.021736227997368383, 0.0380886773458652, 0.00411092356267956, 0.0082379330565492, 0.02261225719966235, 0.0451598527480758, 0.06608118152906818, 0.07117166724656859, 0.007955486493770996, 0.018038662495992838, 0.037645146911663395, 0.035267677308330615, 0.07570474739036254, 0.09364409807829127, 0.03284560989648585, 0.06201024392559644, 0.03429730437816151, 0.061858324859772, 0.03544147967571213, 0.06436796378224127, 0.024864431207759247, 0.02542647161340762, 0.05234427509769317, 0.017063085913598057, 0.05782789032485697, 0.061862752847974344, 0.0076302615813009685, 0.06579196801589382, 0.033004599953851396, 0.011371924061208002, 0.032557717884980866, 0.038450879886025385, 0.14759221654986182, 0.073310500461488, 0.1303557285498227, 0.12533825867238546, 0.20792095110781733, 0.17090235686590596, 0.12058990016098946, 0.1427858115564431, 0.20499552179488445, 0.1363062858581543, 0.1547150415999274, 0.159402871504426, 0.19902533731393277, 0.1127609259058391, 0.17407894044393496, 0.11746134263493362, 0.15964976632066313, 0.11347564763479656, 0.13247423745211095, 0.12334321249997425, 0.1578115843116276, 0.14477391697226033, 0.12830698727479867, 0.1642120957014061, 0.07387185138800452, 0.13884916150521848, 0.1819075929421571, 0.10527407119591391, 0.22315643277139435, 0.16237633453021127, 0.10462288879939627, 0.08919943980271779, 0.2650687507083339, 0.1787110144693044, 0.1387064852902005, 0.13965085719621953, 0.14051937107597628, 0.1730677350274017, 0.13738502958609214, 0.11256517511942696, 0.10575043998898999, 0.22752054456260898, 0.14234056125485128, 0.1441655818733477, 0.14295988205459811, 0.18092601980653503, 0.10478039647662833, 0.13786244025874522, 0.20344436228755983, 0.12052221629287928, 0.09069996855912671, 0.17978974287548374, 0.1500324364150724, 0.1477438406718354, 0.1302386090279587, 0.18337386990747145, 0.14346113338345481, 0.1333871691097175, 0.0828283921545071, 0.11692221591910047, 0.12165657034324062, 0.16353294343477295, 0.1919668023624728, 0.14383406498499457, 0.14816724214582674, 0.23002399732508969, 0.11809436874764583, 0.08072103749239638, 0.17143650401023128, 0.1713095785629365, 0.13926366103752968, 0.06833770117091556, 0.14315883508853375, 0.19552285993291488, 0.2387983700440776, 0.20597473537969976, 0.11043283833010543, 0.15251551123876728, 0.1071941250214173, 0.19675676710903647, 0.14648780887646062, 0.13263188302516937, 0.1556063389345523, 0.16053165609557785, 0.21463842371538763, 0.21900040578217278, 0.12657170619575248, 0.15143986250604355, 0.16788291324290538, 0.15176924966996716, 0.09436913901158879, 0.1367345290078271, 0.18027685222125825, 0.13203586662007918, 0.12084601101495566, 0.1795199879955861, 0.24090325790307215, 0.14338722122052025, 0.10666691863368596, 0.12093568926737194, 0.126057431372183, 0.12709715058125798, 0.1890488500676809, 0.07854154033045616, 0.1271209069677899, 0.11421102309419263, 0.11654944519602484, 0.08462553483343895, 0.17584170875770433, 0.0957061922658355, 0.10525180101995507, 0.19154726197161984, 0.10307522265300637, 0.17427731125104814, 0.20372562380808018, 0.2078903229126046, 0.10654255958093752, 0.10148130777862766, 0.07242805144238858, 0.11008754718087374, 0.15269149695673298, 0.07160400896663628, 0.10474985255108726, 0.20249196178009435, 0.23035749072028747, 0.1005521427179056, 0.10461530452894588, 0.15281825386468442, 0.0828946281164404, 0.16950358756847922, 0.18452792007836605, 0.17230904751246975, 0.06059652059188774, 0.13370986066518292, 0.12411224220188395, 0.14020354366831242, 0.10217415769734692, 0.17758175490363953, 0.11405197558023276, 0.1191600047111992, 0.09390833712513409, 0.06094202241529861, 0.26610919004005773, 0.0806949828420916, 0.13065402786577904, 0.1469285086157822, 0.28351804782305995, 0.1770605240017176, 0.06921540044488446, 0.1582749449317494, 0.16649784159756478, 0.1568920949413892, 0.09213810711498223, 0.1250372167616602, 0.07188085782071275, 0.1267834912024198, 0.20425420915407522, 0.20110940290314538, 0.07995753128442072, 0.1807415458343683, 0.17295939487314996, 0.16171411280670475, 0.08890372220306628, 0.21666324006453638, 0.28949889624791764, 0.08935259610053994, 0.1886026038517875, 0.09152471583576934, 0.08832352551361246, 0.08120809321201618, 0.08412377022567295, 0.13965989703372603, 0.1414766592243987, 0.20638381100950703, 0.19177333451807502, 0.12928421669189008], [0.017116884438080654, 0.09204552538933293, 0.042804427324764194, 0.020528492299960028, 0.05668461901105701, 0.04368608727330162, 0.031205430972359838, 0.02679792030023471, 0.050142231968141375, 0.04853069324106459, 0.05017405909095561, 0.0921779053826486, 0.047246749032168626, 0.02473983275253446, 0.03983440403375895, 0.008822346102416275, 0.017179787917543324, 0.016722768590214755, 0.033512608178200266, 0.040770383446567485, 0.03229634017653523, 0.05231748117254146, 0.028792183147743348, 0.07965161705449705, 0.028165538547440406, 0.08965146232156024, 0.03613350988035241, 0.04551899093653887, 0.0062168609621303704, 0.025154795768039844, 0.033254007538480145, 0.0398119691488964, 0.0458787305040225, 0.027323016115734657, 0.04978702381072987, 0.04804994625550124, 0.011165266097973914, 0.028318773369274797, 0.027145002179989414, 0.1022530647535478, 0.10336674209083281, 0.028746972468891935, 0.06153868999512446, 0.02252700693544842, 0.028960452445091742, 0.03622339880694786, 0.06898881461952003, 0.006359749766547354, 0.03398060746070358, 0.06033168399646398, 0.0499436121824528, 0.063288637827481, 0.01934867093129264, 0.007908947131175908, 0.026635739486664537, 0.06131403854176883, 0.03323206678032875, 0.060034936008554314, 0.014750892747073405, 0.03794637268349048, 0.03437480566302135, 0.0488693117644758, 0.026044821396710414, 0.03374728006160548, 0.05772559843476742, 0.049380365188323685, 0.07193744873567935, 0.03353133136706968, 0.049379380765340986, 0.06251228049457555, 0.08906395715330878, 0.009098327361918505, 0.02655951948385806, 0.06106235950644459, 0.0593211718895022, 0.06280856499929102, 0.030509817391453736, 0.019597469476021586, 0.037536462017845725, 0.04260743164547509, 0.06688900592346346, 0.02125398714035269, 0.09536336791972, 0.03648828136764708, 0.028885749296375343, 0.020531487703743963, 0.003985018448738923, 0.045105291966108546, 0.015170934925516768, 0.07008372280266016, 0.024840439249190594, 0.08168254678528156, 0.024814738914550796, 0.04752144134873825, 0.15732931664153454, 0.00865065813770578, 0.01635756298539139, 0.08954001951121515, 0.07919133610783086, 0.12625440023839474, 0.016658202699956395, 0.03960786034323035, 0.009135680851496516, 0.022755023430011446, 0.023241046846153277, 0.01384311015792792, 0.01587392018747426, 0.03628489268462985, 0.05471534786685821, 0.07342366696966272, 0.024804379490594712, 0.021248812216424176, 0.04125848487620393, 0.0558213260205042, 0.042645977359385266, 0.03281636448997644, 0.04599195446879153, 0.03528225979196929, 0.10645370870347946, 0.030356718550225904, 0.05035974731248233, 0.012924760343476891, 0.03598452493127796, 0.05129817820664856, 0.02293505217699755, 0.03837126802893416, 0.03339442379412151, 0.017311170081337614, 0.0162522220653632, 0.042961973306392474, 0.060895505556536306, 0.024700459663666064, 0.018338465259500572, 0.031298681109723066, 0.01972142633260979, 0.07770505658681355, 0.047948696244988716, 0.09325073491181098, 0.09845507661661795, 0.021611711896595456, 0.03338873559128373, 0.0680065366830076, 0.03326356065489593, 0.0730546041121406, 0.03788031292177978, 0.0060247854825349586, 0.023872025588887836, 0.01967444216021367, 0.07459309252519762, 0.033157177855290716, 0.06968314308793315, 0.05177000792877329, 0.04599535206873571, 0.021585873666129286, 0.056839870559352065, 0.0777856413755686, 0.004643683130252025, 0.004845478829191697, 0.023148714099079374, 0.021525279941758322, 0.0692099305771051, 0.0465244468632004, 0.005802107184389306, 0.03649624868205959, 0.033193199309490384, 0.13070140274301653, 0.06785733339887473, 0.04056393424229276, 0.05320130148902536, 0.04253370717408196, 0.02830965500775605, 0.06651327810100009, 0.04873014040171139, 0.036622691493962085, 0.10947911249053095, 0.015749737334948395, 0.02116601343356794, 0.07326831966037713, 0.0615372650715853, 0.0179497062814452, 0.030517641064380447, 0.03486349698035948, 0.04258601182711221, 0.02158910847238956, 0.031051380266886086, 0.023710926874510707, 0.0165836431927258, 0.013669700410607602, 0.04930820736673571, 0.017108520673167323, 0.02596903614880097, 0.03389246904501512, 0.032436365727335215, 0.037939673244592645, 0.016273595918450626, 0.030462614883999192, 0.025503070829736612, 0.05030609817514497, 0.04216121607309869, 0.03303368065145708, 0.08051696699112654, 0.10414220693130648, 0.021033328920302373, 0.015345172047795308, 0.025894915226907022, 0.06484981776485521, 0.04684123954164886, 0.04975512390956283, 0.008544443877443911, 0.015353349078777096, 0.032684352218864426, 0.07113052066415548, 0.03722961316065442, 0.015130842671609454, 0.006342416548455555, 0.05952371787580271, 0.07352588608139947, 0.024324120886083093, 0.05771430629876353, 0.03174280143162656, 0.027963415824718056, 0.03283029196843986, 0.09876062312433798, 0.061438650403532295, 0.07359208373893654, 0.05045845774152587, 0.06532732802893847, 0.017409482144660527, 0.0256207610871042, 0.00783108722140652, 0.045087369339120005, 0.03837969499610124, 0.056740386381505005, 0.09303092130369718, 0.027929966510724158, 0.028367467832961873, 0.03169223962862405, 0.03013816707196736, 0.01252081175710285, 0.04312672434494861, 0.027989518355518102, 0.026027864040506464, 0.029756601659520984, 0.009843987551698042, 0.0835214259343282, 0.00781675323753828, 0.09583372292259047, 0.053728561502911394, 0.03649183601561574, 0.049327593221659624, 0.06081071494507694, 0.04138321931203527, 0.05044127055894464, 0.024884020075983098, 0.01729162143272979, 0.08319652804564084, 0.08636303756746554, 0.03944107151079563, 0.08815988913298616, 0.03579302210240595, 0.0386296771466732, 0.05011926848261107, 0.024014692227806778, 0.03817396591447535, 0.031773634555359045, 0.033169408449001854, 0.032632614470898144, 0.050057475830638604, 0.031377745213948434, 0.011946738982993749, 0.033197309371204145, 0.05723090864898217, 0.016638801523273992, 0.07960177537414335, 0.056389989256257975, 0.006153097070167743, 0.004400056157816923, 0.039144840632234855, 0.03975409503665663, 0.025405028812407006, 0.025117489201347196, 0.03485148089126714, 0.02434396256332196, 0.026211271235238642, 0.06161562820535995, 0.019683030005844853, 0.016147779383426233, 0.06795246619731188, 0.0278658123927251, 0.05133973464610116, 0.10381538616192919, 0.018646767768528194, 0.05938334375499718, 0.05416621221229435, 0.051346663911376274, 0.07069992562455517, 0.04246812621732393, 0.052998540998106046, 0.08571204669292896, 0.047731203883285486, 0.048639941209506606, 0.0646625935370403, 0.03978379626548098, 0.016614932138773224, 0.036511547457907474, 0.025645245257164204, 0.065770486910497, 0.03572475600747332, 0.02820215755022101, 0.09063683525328675, 0.04936596656578684, 0.01708027118095948, 0.01094299047479346, 0.02115535906576101, 0.0260164340086762, 0.04210408506614547, 0.06351082630816006, 0.05235316554805445, 0.030683696367627675, 0.02099766944264693, 0.04815982624648079, 0.011135000836915307, 0.005726885489909159, 0.024259955276765173, 0.02425500634877432, 0.02225195455755438, 0.03633182706131089, 0.05760478253866877, 0.09667989767847524, 0.05368518943507826, 0.025072383859585372, 0.052696878556162126, 0.042032459675664866, 0.020038446922215725, 0.022983794521179893, 0.051819489547802564, 0.0973887128695365, 0.06263526441949992, 0.02795706495582577, 0.08053432654349074, 0.030750018514452443, 0.09359387335397544, 0.013350082782938356, 0.037599223771042405, 0.003265027950082215, 0.031164213526813738, 0.008830473337682986, 0.021323404282391555, 0.01880234490419107, 0.04426778549508703, 0.021100754233738108, 0.00614286117788945, 0.06540409769983062, 0.22128426710203772, 0.09949878714377842, 0.13299805773121695, 0.11894419774292939, 0.11125088233741061, 0.1343816125224675, 0.12558472447938498, 0.11109543543669487, 0.15682835642608906, 0.14231399332563724, 0.12390574320189415, 0.15865403588020033, 0.11095859681165988, 0.06770113573199318, 0.12549437206959532, 0.11112897476601986, 0.1622617584202559, 0.11412148273760274, 0.11961263243950183, 0.18048458462280614, 0.1478120991058888, 0.1594555017448241, 0.16522662593953072, 0.19030575520328938, 0.20273396895537454, 0.11631410298568588, 0.07699782719775554, 0.13456528976319299, 0.10577422701903891, 0.12551694101984465, 0.18311186783736755, 0.08365193667310862, 0.09233580376472204, 0.18223800666389928, 0.09957022484271758, 0.11941121260245001, 0.10515903543320396, 0.11110835167909823, 0.18098470214153492, 0.23529716436901402, 0.15549798345854207, 0.12423630248034194, 0.07710424447131735, 0.10460613445649225, 0.11701646771642471, 0.1306329757696198, 0.07675810296448969, 0.1459299130064826, 0.14927330456914442, 0.165129455347215, 0.15128678281701383, 0.2000994845143249, 0.10566841495493728, 0.16477253498329272, 0.1936891825208741, 0.09101573467975663, 0.09689085531018435, 0.13729604081280772, 0.13536940629203476, 0.09391111802429923, 0.11250863016973581, 0.15423436739271687, 0.10084837359646637, 0.12859983970561337, 0.12211055404716924, 0.18011304730128858, 0.12874302153866138, 0.20872342820850112, 0.16924691747032827, 0.2573243985252996, 0.12068367698380064, 0.08545183726856787, 0.14535565349844196, 0.1797822352138258, 0.13928475909896437, 0.18982957027131514, 0.1307011269513638, 0.0953751809955124, 0.1580035353019353, 0.2694417644412287, 0.19214592904092806, 0.22701517168071964, 0.10449356549689848, 0.11255271086889891, 0.09493871772241208, 0.05467671405283674, 0.17671573847051592, 0.16544892933339844, 0.08318423999533539, 0.10657897940085781, 0.14835939231899478, 0.12437257420031295, 0.12193426955491306, 0.21018613520408833, 0.1756033481609437, 0.07986373147897183, 0.23252323660398685, 0.16850304609585195, 0.21984167757534215, 0.120172489494566, 0.09907902458742743, 0.16198320885098752, 0.13906896745245304, 0.1467213277975398, 0.12821564661158671, 0.09375279829386743, 0.15614949527286714, 0.13603749624904127, 0.12574354216696756, 0.09430756086423513, 0.09458427948336448, 0.17388660640966508, 0.15160193606730432, 0.17802697456171437, 0.09672407030818925, 0.15515685982761845, 0.1415471393134325, 0.2732347883284092, 0.20809457727497627, 0.19644875379820026, 0.09612479802942085, 0.14405955530462727, 0.11620758612069393, 0.13499892617185272, 0.09324228496200616, 0.13483974842294572, 0.12180476239131344, 0.11241941157007411, 0.1629490158971279, 0.19287837038357414, 0.1462316443963397, 0.06644828320150414, 0.20356266158482722, 0.17184263786240933, 0.11788266801065016, 0.09838964504700515, 0.13321570331050506, 0.13474559621705165, 0.08703454427661435, 0.1312703149573457, 0.1275989228499032, 0.12231675427286856, 0.190277976855155, 0.1669387251979882, 0.14524820200618238, 0.16175497593658586, 0.28484031558036804, 0.19800886121248046, 0.10755660718366986, 0.10188898912841275, 0.1423597134529583, 0.1709743691307883, 0.14630529608938003, 0.09818332990811718, 0.14272708325616776, 0.06205879474779772, 0.0950875379625828, 0.08996192711375414, 0.17477517647127952, 0.21416047678118755, 0.16132379100928385, 0.07710651209157321, 0.16014567035580837, 0.09891879729806416, 0.20011186449518129, 0.0835706624052217, 0.10724773585435846, 0.12918318501643597, 0.10441087396635164, 0.1336673887506608, 0.1337425879413082, 0.09522202469769026, 0.1328889821325579, 0.1513896531034862, 0.1413910412379811], [0.026136627458336375, 0.0443961396963606, 0.04255773935226664, 0.067855448822581, 0.01988485012383711, 0.09292890903569999, 0.04027333794041507, 0.007111944686321001, 0.0012927432075112819, 0.05637171422882427, 0.028370815637190978, 0.02997701473143553, 0.018329923379144842, 0.04301657622319557, 0.054856610649655906, 0.023689788593459996, 0.013311019959679295, 0.012022503163485278, 0.03644899254845035, 0.05760989617556334, 0.0932205663693528, 0.040699807596543146, 0.024897397886360847, 0.02061019940752416, 0.04490550389633544, 0.023097688812882673, 0.015882274376288537, 0.08466324934195127, 0.030344512854372303, 0.07519444856312006, 0.02215485674359145, 0.030667688960449833, 0.04674550536419115, 0.02100078359005913, 0.03370092791174689, 0.021995989260293787, 0.07206086550028094, 0.015618999642620405, 0.04649486820844393, 0.07194998193412058, 0.011054617146240368, 0.06256164336997656, 0.04519725316053918, 0.0275760913463009, 0.003673590540382711, 0.08250082061896402, 0.033003324417457465, 0.00878560931361731, 0.05001811040264945, 0.09711358771328965, 0.0847282212588095, 0.026812828371241212, 0.032398118787715514, 0.024401844336440968, 0.03651602141138527, 0.028154148735226165, 0.010069583208420345, 0.04386305358381041, 0.07877237794380035, 0.028924595699795795, 0.03520621407416559, 0.10018458139271506, 0.05508763978498117, 0.10074137409608211, 0.022192814485019734, 0.08350546066198619, 0.012888551197735774, 0.0794172247931842, 0.07869056741436643, 0.02202795236371458, 0.03987813233247688, 0.06167199695482851, 0.043664253767459624, 0.05237661166897705, 0.0546627635917356, 0.023166337951777444, 0.08001251341474634, 0.06010124474884041, 0.08763303514569999, 0.03324264262412344, 0.04019570259016849, 0.05096226780404968, 0.006502617982351372, 0.052622211796622125, 0.008211326822938939, 0.06137599207220539, 0.0643484438619306, 0.043590234352215644, 0.021640422956777677, 0.014176342125621536, 0.03020990354519698, 0.03902730359245212, 0.02280102700986449, 0.03774859942495823, 0.03616277443905992, 0.03378637735882113, 0.020312290796409213, 0.03426921959485739, 0.03071280770875033, 0.01918329170063859, 0.05680979777788443, 0.018507079296414892, 0.01605403128891222, 0.021550903667605693, 0.07984836375521076, 0.030082305855748635, 0.06664673061740976, 0.07353353163888378, 0.024606056563976793, 0.06885045147951573, 0.04203206897082348, 0.023629152734253197, 0.0388933033231766, 0.050080749581778244, 0.03701089505827235, 0.05096041770171254, 0.07478694341355756, 0.03572604686562573, 0.03666144405161181, 0.02156875543146124, 0.047357590463493145, 0.03290901516353892, 0.037333827931433916, 0.030276583838126356, 0.06992611553399794, 0.020936997194263725, 0.018230144257446932, 0.04654995376063932, 0.03907224614053004, 0.02461606741792733, 0.009007942393392084, 0.10838127785152006, 0.08535636739144403, 0.04962751281357581, 0.03312684843436845, 0.018490539458129677, 0.02666991849940631, 0.019084636812969562, 0.012295739912998774, 0.022551276600889625, 0.023109226097022335, 0.0287081471328894, 0.019508593700705998, 0.047611893349958044, 0.044020113099606774, 0.0017861693073251857, 0.04997296867171123, 0.06841963427441736, 0.055841815042039084, 0.025390406109152303, 0.0248047529584578, 0.08069947211732788, 0.04007900058622322, 0.08152091755501686, 0.018373326090494954, 0.03316626365807268, 0.028432068197176825, 0.09134283124078667, 0.07892242392464992, 0.03571593067458561, 0.05765740894862722, 0.06907185088963279, 0.015016527989158228, 0.06115465011868266, 0.037017257418483496, 0.005649764854986702, 0.0325593879566558, 0.0401849658679097, 0.01672363235434938, 0.03576188062828395, 0.053003106882134755, 0.07159899109073224, 0.024852863280102614, 0.07801714548540693, 0.05035454940591609, 0.08553873462181899, 0.028163307316360936, 0.10807901786099519, 0.07864044994236001, 0.05374898923741234, 0.05967418903545026, 0.04252006314815052, 0.010482238384053833, 0.027333794972829284, 0.061129595213119066, 0.051509905756721576, 0.04366198997764338, 0.053967963979249044, 0.04277954478898356, 0.04908634447342446, 0.016960761464771726, 0.049591070011017785, 0.012849356224309775, 0.04818266715794321, 0.0699249280977153, 0.038811144223737146, 0.037278619805170644, 0.021913016192434777, 0.05721270256946164, 0.04325738830131389, 0.03950319741101515, 0.032622724275795684, 0.029751367363778335, 0.07930584326987306, 0.06603264219818578, 0.06591290265562073, 0.019052602846415776, 0.0019079853072687385, 0.008543661510151242, 0.030456693024344506, 0.06246139310420521, 0.02180059470476643, 0.010927200445064135, 0.03845364546343204, 0.048216589531230356, 0.09390388615429403, 0.018442101633897232, 0.003976960640190349, 0.04383673846361138, 0.03488022834062576, 0.05632622392788049, 0.03485554881814507, 0.05475556748288293, 0.031156292177676678, 0.06838070934698467, 0.058087272374259855, 0.07136354162808388, 0.04481511701258921, 0.030420824787729693, 0.01223419240916208, 0.05904570965456867, 0.02671523643056712, 0.031943583500481425, 0.04303785814573208, 0.06971094441870529, 0.04129897645344177, 0.042469696697568705, 0.030152358850764654, 0.02776572492063767, 0.01255165062649476, 0.035807585433846524, 0.01289368877487798, 0.007189918551669126, 0.06025512499975101, 0.016425068738059174, 0.00038820757430174484, 0.07059972898493852, 0.06295044831330739, 0.08020011302564414, 0.057200629023774985, 0.0333813926385295, 0.04618819938191483, 0.06840954489645458, 0.033305243498856024, 0.020161022905320413, 0.059302908353387356, 0.04591131605388177, 0.03685780770836338, 0.09324890396167194, 0.005372631111963382, 0.012140242258958038, 0.05657600689559214, 0.06518331116005298, 0.05325208162708629, 0.04467707945995274, 0.06819969043135643, 0.04677453243564214, 0.07377071246024101, 0.056638565635488886, 0.03058560263936318, 0.013199385627353144, 0.010470582356285906, 0.047436505180573275, 0.06249180679479915, 0.017504452149413766, 0.0039544726079780495, 0.055369705697822, 0.03330363471421503, 0.024924222455029527, 0.06655375052603983, 0.04561095596140912, 0.030931407067504142, 0.016971726098187992, 0.0275416748463026, 0.04736331314028752, 0.05588126090926029, 0.023766041155003255, 0.023590957505568385, 0.042582208200568156, 0.05079744015670112, 0.043473708548492966, 0.05231825109090536, 0.02019172004844633, 0.0478473236604083, 0.013880752845697347, 0.022739228612232595, 0.046273629676790974, 0.03549304888433507, 0.071004330661268, 0.056624668800542434, 0.024399101741672046, 0.05908035598094425, 0.047560213058586084, 0.02471369383255801, 0.06038949682166981, 0.026857874341188904, 0.04117395856507844, 0.06780876342447535, 0.04191073979581556, 0.010054483615432777, 0.08189833843179288, 0.09055776731862177, 0.01648673115508451, 0.021982990663438555, 0.07778119040472854, 0.021861471881669377, 0.05164795863111654, 0.06408512795103655, 0.027975797720794237, 0.04839226115314711, 0.07179637364442311, 0.020306648558846885, 0.03489339356160453, 0.047228780439904625, 0.06490116863841973, 0.019476299264257955, 0.02623768403164802, 0.010763083344265338, 0.01856544178970639, 0.022449132182725498, 0.05904257252451874, 0.032367119039859504, 0.04384273693205849, 0.06627737664647641, 0.06968724931920729, 0.021179111621853326, 0.07199970870128564, 0.008089311041628883, 0.030043645228649822, 0.03197239606731361, 0.06893658274484259, 0.013047473264798042, 0.012523532326843952, 0.06324079180617007, 0.031684659188613296, 0.01164559939605815, 0.012503093101024147, 0.02233934029185724, 0.08622292774699389, 0.0415082908265533, 0.012876016084074736, 0.029652948048146024, 0.10484492406249048, 0.2059209253638983, 0.14601087317832057, 0.2737444819461915, 0.13494024383685282, 0.18175687280393418, 0.0819844084100858, 0.12377857260646359, 0.19063128128407464, 0.13619560147485427, 0.08244304992859403, 0.10081905541160416, 0.08403428349523775, 0.19921575612839193, 0.13536408964184024, 0.14084019337690648, 0.09951201748223075, 0.10593560344028859, 0.18568834410079066, 0.16059275926841846, 0.21090808114217174, 0.14597200187704257, 0.11279596676749569, 0.24590103165997615, 0.0957105742887624, 0.1597551034102517, 0.13020925253870028, 0.2829321131350533, 0.08802051475692181, 0.2261399162272292, 0.06304271977334734, 0.08830276453086446, 0.14374591890842686, 0.12909359869457063, 0.1986804598521802, 0.12919993169846075, 0.3086682853679503, 0.11399605882263954, 0.17026334760650513, 0.23256388522924917, 0.14343882490309978, 0.11733826294901872, 0.17471149924301332, 0.14449694554411596, 0.08738063981816654, 0.20748783563894613, 0.16418229488115157, 0.12244152701309613, 0.18768959558538853, 0.16777547707240428, 0.26062780029831395, 0.1283499494855923, 0.14886528614067263, 0.11105439610659115, 0.1522744386907547, 0.10364349901435838, 0.07027324529424792, 0.15342001592920673, 0.11142465406127515, 0.1346262856837242, 0.0934008421796945, 0.29631631268608954, 0.12631873630227583, 0.16500813766352593, 0.1533336012113479, 0.2757784760286731, 0.10712000601474317, 0.1740383224621896, 0.1809842731322973, 0.17849848635735052, 0.19937355491903522, 0.16153527724166072, 0.20390294251903412, 0.15235386668674408, 0.15053131287136387, 0.17794573859822366, 0.15034579701962011, 0.10842241677305392, 0.1808971995788236, 0.13474942665667305, 0.2061876158920988, 0.30352728381272287, 0.15679728389988024, 0.18493996812931954, 0.10406876974288495, 0.14113697583877272, 0.11973597259531099, 0.14333633766058954, 0.17978759782929576, 0.10839889021289927, 0.1210095784476688, 0.12269660364836456, 0.15606655859418456, 0.1672520551590189, 0.09031499405541728, 0.12675306985094664, 0.12872699497928544, 0.13374260326306667, 0.17317014566111952, 0.10384657360132664, 0.18452151558331906, 0.20111867256702917, 0.0934981889722328, 0.14639025524018273, 0.2023628606430946, 0.14650237986878042, 0.14870319725765338, 0.133519732964135, 0.0787558687490321, 0.29359850852239516, 0.15303147145577017, 0.19227650106674243, 0.15321131825687426, 0.17016400132448445, 0.15120415257350092, 0.13013881841494193, 0.16959288277693335, 0.1607818910551648, 0.06428606898313569, 0.19279701184601555, 0.13968125556505498, 0.10403031978996531, 0.12381550570529316, 0.11772603367365177, 0.14934531683402677, 0.13114783282001174, 0.2752552992634235, 0.10678488851314592, 0.1087695312115454, 0.08085422187803254, 0.13705509083886303, 0.22554488041468207, 0.29715211461147956, 0.08260172972035024, 0.20568087937370425, 0.2514843264174077, 0.12457214776546725, 0.2833426749754337, 0.10058218868629587, 0.08809169198596671, 0.12785674207994055, 0.19057243040973143, 0.18108020266217573, 0.13692784363464003, 0.1370271899166607, 0.14679228286108664, 0.12811096835761301, 0.2076701339214079, 0.13427708748607867, 0.14522809985904925, 0.1452962050755178, 0.1863144524395466, 0.201369060744201, 0.11769803316001931, 0.1150510231814077, 0.07585824076687137, 0.21232468496647575, 0.15229415779392566, 0.16324091071803726, 0.12481030151848832, 0.15920243225991726, 0.19147900353756644, 0.07009334486698912, 0.22369710698483453, 0.1727582201842339, 0.09997911661142304, 0.18342558084236038, 0.11155123476900401, 0.0838831649912942, 0.1606319829701416, 0.09657711932255376, 0.1813885530516986, 0.132764324305519, 0.15082572046066486, 0.1775482462178315, 0.16510118670280904], [0.06305390465704185, 0.0495775945244297, 0.09977437195277984, 0.03691458248443181, 0.029114290561166503, 0.03603890951302263, 0.007478037516721675, 0.039762629256133115, 0.014818590979332165, 0.07344250507172077, 0.062229797063815984, 0.027572193873986125, 0.08173100184649229, 0.024265019117944667, 0.02489759898444097, 0.02910015815418334, 0.08545587455192882, 0.02187666723564748, 0.035423108887287884, 0.0571683805526024, 0.018245027430595893, 0.050292768245262486, 0.0380029674288967, 0.056620325082011765, 0.02741048995014881, 0.01619253615518251, 0.05573489215044726, 0.07978685455577028, 0.01455119948068093, 0.03275937520928922, 0.015839556356020752, 0.0490174463559543, 0.009178159469287963, 0.06411605875097937, 0.036845623079927704, 0.00539438130574361, 0.10490873152570379, 0.08246979405803066, 0.053157232281181126, 0.011860530151264563, 0.03614819961630049, 0.0012387780589051545, 0.03301396920916534, 0.019660780897303935, 0.05005669442095584, 0.029373525138643962, 0.038682177152124145, 0.07156824798233087, 0.03721658966594166, 0.01876546160107659, 0.03288024856198219, 0.021272164491576054, 0.08740377567347982, 0.10005770957157498, 0.05032996181398631, 0.0892166767810141, 0.029310265428296504, 0.08323832580278959, 0.01349009205436995, 0.030375817122178215, 0.028651780298640652, 0.0266155626459588, 0.03697909091809585, 0.033202055285895066, 0.0018664298254260495, 0.032896321086633595, 0.1001176176472537, 0.01987622014337009, 0.035026554964602954, 0.06400255899455759, 0.03804036018048083, 0.06419467852420865, 0.012705343185863908, 0.060575307617264415, 0.03727197782286713, 0.03649837840648909, 0.07298426191893316, 0.061129177695200335, 0.03772338747137016, 0.017230977912643747, 0.0403929510784726, 0.035908237895778114, 0.017863892942606922, 0.027467291539294586, 0.05226090557933335, 0.03761240814421927, 0.043625194774640184, 0.05920202606507848, 0.03344617686384628, 0.10965921210065004, 0.03841276318135281, 0.03437177578528081, 0.05172537181586508, 0.04879820348334409, 0.06272323429584503, 0.052293471976994514, 0.08411126000986946, 0.0489941802656939, 0.02132494794955898, 0.03550126517732297, 0.0805550798653595, 0.026514379668139645, 0.04001576768895311, 0.03329712679729827, 0.09389999442763867, 0.01992248419311739, 0.010498408584915584, 0.08886840554975695, 0.0682853926874457, 0.051378376121001865, 0.032451591724830295, 0.06740255296350488, 0.059453777878755526, 0.07293956834943065, 0.013552930416359056, 0.07466776311517724, 0.01672628684900701, 0.021621862561592174, 0.060406419703917164, 0.016783632360579028, 0.03667954670926256, 0.0364394087885176, 0.04776790332529814, 0.0617214096259446, 0.033690459320261594, 0.11548916418706218, 0.051395624590617035, 0.08393481463914917, 0.031443609623238444, 0.07311953772460261, 0.06277625141064487, 0.05201206873020819, 0.022840153035377304, 0.03299195184222153, 0.007546892062941147, 0.031219331637745908, 0.014882838943101948, 0.1348205042942878, 0.02111834744291921, 0.041913329172999635, 0.01585503516253084, 0.04073102567945758, 0.08877747091314486, 0.06535864570328305, 0.01853162858394846, 0.03170659611632507, 0.08582009573376949, 0.018940194765286102, 0.03278576310784106, 0.04199706258312349, 0.050840930968162515, 0.006628386636880497, 0.03472969206350465, 0.09405806134905546, 0.05032882800385837, 0.03484195075748909, 0.006199205508305421, 0.07687364434522968, 0.030975231127212607, 0.05098624252564004, 0.01879586954601109, 0.058225930458115, 0.05551793221985141, 0.03441522446190638, 0.04093340695685437, 0.04806312679823849, 0.004069321157951509, 0.07912044999219718, 0.0659784184949052, 0.05490081392288689, 0.012436274912268406, 0.013412949873224623, 0.030161341231676842, 0.04140098872143896, 0.04265290279422076, 0.037767855044935024, 0.05499999166556424, 0.031395077953235276, 0.02891676819642946, 0.05192317188747468, 0.033016202355464624, 0.01827039834742825, 0.051872790115134376, 0.06457935808406723, 0.01097007455574649, 0.02510329933776971, 0.05658859755062769, 0.06265488776168035, 0.028783436338867874, 0.020431771784299807, 0.024045464064505313, 0.04708788537931058, 0.07032718554499649, 0.006094713988263281, 0.029506743998236717, 0.009947047444931682, 0.05245576770375333, 0.029486444583463094, 0.02393865991654175, 0.06684968263031014, 0.03782135862556677, 0.030887655786148487, 0.0297075662867076, 0.0325947888796368, 0.03292701822975951, 0.022796261942975467, 0.013765453740263419, 0.012603555956194478, 0.04167928931213195, 0.05620673336389084, 0.016876928463217714, 0.0557550172802181, 0.13082440582013902, 0.022484718882028135, 0.027197609437749754, 0.03157604324270881, 0.03715257152854916, 0.03945219127701656, 0.04096592355880045, 0.03676313073224118, 0.10054712484200155, 0.02445431752881456, 0.020326547692680073, 0.03556060634793774, 0.09062416415901915, 0.05373594659050146, 0.017273591553431847, 0.03778891097153387, 0.021019027973975868, 0.025588290450433572, 0.012809794486290025, 0.08097934701870527, 0.015521456540051489, 0.019433842671494332, 0.050246576973867994, 0.08689262648864139, 0.044889603741467006, 0.03285705141963498, 0.0386769792455579, 0.014373940141541103, 0.016535042574809446, 0.029649349350121715, 0.05441273164544856, 0.04348436866195933, 0.04276228482804952, 0.09086561975099387, 0.05912896042930023, 0.0062030287658525335, 0.01077711328698863, 0.04653550151194777, 0.04959713742737809, 0.05192806718931083, 0.08761580582828292, 0.034944549082748355, 0.003972008599967306, 0.04308383108206815, 0.010418245144518874, 0.013265316111726627, 0.0222212286861313, 0.01918672568975918, 0.05855434852081442, 0.04407773057239191, 0.07958967118493973, 0.03369232474435722, 0.012320962400295803, 0.06316018786521689, 0.03389477113922758, 0.06769008874412506, 0.041908223196984305, 0.016310823961131034, 0.020387028419082204, 0.03036868101316354, 0.06807096467743959, 0.062078038876455646, 0.031069733818332036, 0.06850499179094069, 0.05362035924448602, 0.06415473086939705, 0.12746821292826246, 0.02779681659904459, 0.08224676288063489, 0.033272140839647864, 0.032221393794902874, 0.050132858882387804, 0.04727797860640192, 0.07940358076725276, 0.04842679256633405, 0.031247464301545295, 0.02476916242871554, 0.0052941444465109426, 0.08962311706836186, 0.0874306193943466, 0.02204076518424817, 0.03462211799717719, 0.05857930383494785, 0.02762596367017156, 0.04845046851363394, 0.0215918357454, 0.03231703604180967, 0.05755796307517637, 0.033354571900300445, 0.019861019043732556, 0.05901538789452565, 0.052269780707936135, 0.032572802156209946, 0.09067583678951187, 0.04896305028289076, 0.015220643498093612, 0.01391501229767117, 0.028960207296955972, 0.027425089670765786, 0.02518581466809396, 0.07829583295050167, 0.03353770904903931, 0.073633115408161, 0.05024685276552074, 0.048384879895996664, 0.055596149796920444, 0.0568379438482225, 0.05258343242589505, 0.031263743669936256, 0.038590587510336796, 0.020287521258597414, 0.011365097260192759, 0.040564010851085186, 0.09048917180588169, 0.05381027627135477, 0.04289410940762009, 0.045535909988346605, 0.022681810322307774, 0.0785436240896102, 0.03458469843251571, 0.07199721125465247, 0.0745436568714438, 0.02762700554974858, 0.009725605899978791, 0.04301260788774779, 0.01762815811220677, 0.07080585260184542, 0.0331216850017588, 0.028923666818187605, 0.05883053470883639, 0.09717524246943575, 0.061044011700658075, 0.016297354220202374, 0.03308679735768707, 0.06250385735784808, 0.08490047612858397, 0.003540224927071963, 0.03864841565730111, 0.033453833912649465, 0.03001278146140037, 0.12815566192711556, 0.0776753017318345, 0.16265275437505017, 0.1481306691083216, 0.12624668573299724, 0.20042439772477075, 0.12658848352129423, 0.12266408321597885, 0.0985334933765473, 0.1060897556524123, 0.2371510818240143, 0.1660736127486152, 0.16508975667097878, 0.13670007037299295, 0.09291987685907273, 0.1281378657046345, 0.2233709220684344, 0.14404359003228528, 0.09757726242946041, 0.1269946939822647, 0.19263351336121562, 0.07642914480980366, 0.12996816466892921, 0.20356597108466012, 0.2626391181782369, 0.10345706385710549, 0.0890995036329954, 0.141213339483065, 0.17742027889095968, 0.15109408106054031, 0.07966378253073463, 0.16781908279705435, 0.179833670357062, 0.2758981696059627, 0.14156973890719876, 0.09261196313966667, 0.20914439352289324, 0.19320328359401998, 0.07043991538305437, 0.08486865283620935, 0.1142153285083271, 0.0981276736204182, 0.0903102366494075, 0.08416991936223162, 0.16272591577181894, 0.13571094361043748, 0.16218845912766072, 0.1808683487075952, 0.18986871736424585, 0.11033209010718331, 0.10798866545120556, 0.11786304849890933, 0.13500687816450674, 0.19729647605169207, 0.08116143079654825, 0.28247460542667296, 0.10143189510751156, 0.1759807690377197, 0.12984451807795033, 0.22337277600121117, 0.15795856594078003, 0.18338859411737612, 0.15623039415767118, 0.14819169567236978, 0.12812830492733948, 0.0798102125765816, 0.1522921966088395, 0.09839429520070554, 0.1754923879859909, 0.21025039465917697, 0.2033270742263525, 0.11548314273597733, 0.16183762150185724, 0.22265395570185878, 0.10062024027349488, 0.21083662046059487, 0.16343813239326402, 0.17039752024556362, 0.08821942182558198, 0.09398092395595967, 0.10503501345914219, 0.14248729773586796, 0.09113407228142024, 0.17540845539300673, 0.08548911510696335, 0.13763733298307465, 0.1144862248592319, 0.19361557679310923, 0.1080878431938829, 0.2882747490319514, 0.1668448028184714, 0.1499898725699994, 0.11176368627216547, 0.17329466559233206, 0.14948077650079805, 0.15739988866111926, 0.2288481289701116, 0.11038099716026938, 0.1295040839261586, 0.15248964811044355, 0.13338997299152036, 0.0935553161487464, 0.261246339688378, 0.18743998881789947, 0.2261256669918376, 0.2458337691402243, 0.2151979743352821, 0.1330842732662155, 0.25855206974571754, 0.197603723274604, 0.16871724427948076, 0.17275759199213597, 0.1575518805052965, 0.07843859343519134, 0.17357172895102732, 0.20258678814336178, 0.2399815009125779, 0.19798992351899225, 0.21113816798935015, 0.12679621592284213, 0.17631901217804802, 0.07747337627675265, 0.09487064314946052, 0.25974303003280397, 0.14023608708333585, 0.32819062651645753, 0.12464013806874714, 0.17045581953660136, 0.09010245062170491, 0.22303822540467788, 0.14209398819554236, 0.08765301471876522, 0.0986497548799361, 0.14719503060463937, 0.21558513985045497, 0.09890808738888272, 0.14351157261238945, 0.26535116136074066, 0.12127518879189608, 0.20851195729788274, 0.0980764683035593, 0.0848350675416089, 0.16584309689219923, 0.14722622570491609, 0.08780231759432824, 0.09818894533260215, 0.1877775884443714, 0.11499614064251223, 0.20138815165527407, 0.19990509736441797, 0.14773345251958217, 0.1312271995289672, 0.14325880956265236, 0.1520294284508113, 0.22381260240029907, 0.1507017521127578, 0.10658040432439697, 0.21029750906652023, 0.0712564655189072, 0.10439951288243456, 0.13886768551122758, 0.1002469792541477, 0.17266756133927455, 0.13779883963927148, 0.13893042811222617, 0.14448127138518518, 0.21962413924836346, 0.12883810837182308, 0.10852441371929263, 0.18306980961032454, 0.12986449765101557, 0.186215519845005, 0.0961245222377681, 0.154929484931692, 0.1229762027580892, 0.08231737320461581], [0.03386822236221164, 0.05235011651811581, 0.04297550241913527, 0.10783373182939907, 0.04765150009564335, 0.0537631580335719, 0.018339595239188884, 0.09622797475106294, 0.006846869646030809, 0.03871196648105979, 0.01747818299449019, 0.03205025741349786, 0.006614499856838056, 0.033630539753264, 0.08307228390608104, 0.03815092965059223, 0.023052330662105835, 0.005003518458726186, 0.029657873993499145, 0.024815614170004285, 0.035596240927735646, 0.011413275572140853, 0.011773667271970021, 0.04801908440347161, 0.004393625807302494, 0.04184985112759375, 0.029590163312311617, 0.021399666420033863, 0.019284886450717048, 0.010389144337105175, 0.014317878784852163, 0.012221550043191642, 0.024245499197634, 0.0030648735945203133, 0.008557882974855602, 0.07113249717100013, 0.06055792125182287, 0.06255499372679381, 0.005845182393151786, 0.031099774041062886, 0.052461712546045744, 0.04373040545972125, 0.003322969095015358, 0.009120344728862327, 0.12224143250815331, 0.03127185462583457, 0.04003523398310908, 0.06317102800934546, 0.03615627035258278, 0.024803347187116746, 0.012116748257540168, 0.05461084964354673, 0.05443633864483526, 0.022381030796696583, 0.014221027076634911, 0.052115467617348324, 0.03403511461651614, 0.04655442005323787, 0.02648232654938775, 0.026834031769765482, 0.05893343180838612, 0.01615027491483958, 0.03867265084878572, 0.08698170719247672, 0.03489895152949518, 0.05883980820315981, 0.035376657145999135, 0.03494594719321017, 0.034955596070616476, 0.03236848650680434, 0.04555583210481752, 0.03044404108227501, 0.0068211458499483285, 0.04489122784786648, 0.014535071414655015, 0.05570221850047669, 0.03753503709430656, 0.05256968880853346, 0.061922189779579646, 0.0476961630216289, 0.012653829518615479, 0.025199927922879017, 0.05229524930097884, 0.01920319083447178, 0.013393516137805438, 0.03376315340339657, 0.018484851255291895, 0.04499798220011496, 0.06701004781549977, 0.05130039220074973, 0.03326932929696576, 0.03400915955764151, 0.03545764796135407, 0.03679278216535046, 0.022457013312246532, 0.017146599073443684, 0.0662647208739673, 0.08646855851815594, 0.03174221345914468, 0.03641437303515212, 0.04453595457298141, 0.032598623149697824, 0.02501198357241529, 0.02491389750503004, 0.0802951385717719, 0.03816686810985689, 0.04221889483291776, 0.00493847711514982, 0.04768404351066678, 0.039828520478500475, 0.05892758272708424, 0.06882399080261108, 0.011924852808606962, 0.006751039707582565, 0.078395041336696, 0.02551863582113818, 0.050148724563299656, 0.046421718302994006, 0.07504176723981097, 0.036862722162397644, 0.02917297289616639, 0.06402333146862446, 0.10315216086324185, 0.033732663104010206, 0.037125685672846534, 0.010979189086825618, 0.03998272248633927, 0.010553328470597345, 0.016390552646630717, 0.03224778552389434, 0.02237241805320786, 0.07474426465529589, 0.06892989479726361, 0.014639195212493501, 0.03251685858553937, 0.04457048598616835, 0.04505145130679012, 0.008534393761487258, 0.07666062593700425, 0.01770731797742267, 0.06986878917462404, 0.04902817924777347, 0.07537926727485272, 0.018073891049190875, 0.07850541162394709, 0.036726703251441645, 0.1247350563625655, 0.023441311805659247, 0.031251748648261836, 0.02040279833900352, 0.03210355031995043, 0.008751638102224998, 0.031974154239099835, 0.05120347441744901, 0.058918251776166504, 0.04498330395548575, 0.031657089599438255, 0.034347130736756715, 0.06222755242619784, 0.04478892063601844, 0.015830421715133613, 0.05079794960517076, 0.035485974062354333, 0.04380978749043519, 0.059897484513179916, 0.04783614260715343, 0.03874539855807539, 0.02306690548486527, 0.050515500648367795, 0.05320435434940362, 0.01607762105132063, 0.011710980212345961, 0.07776053667428993, 0.07087799510167492, 0.021000448426592256, 0.018052314182803515, 0.03129179589450359, 0.033438079314486634, 0.0742304724671187, 0.03279749574440141, 0.061306308714612845, 0.04631506354217568, 0.05173039352220874, 0.04262780575382133, 0.11940885305164323, 0.026882203378444238, 0.014273863203162629, 0.05157234575299006, 0.07776646619482387, 0.037410160932209224, 0.034522358027677384, 0.038388213893819245, 0.06666367648229485, 0.03989808126202515, 0.011187117798404108, 0.01734431487538161, 0.03453081563836144, 0.0521596708905793, 0.05903119611884317, 0.05229849368333817, 0.006035258862069778, 0.03318385303681416, 0.017139606605914813, 0.017118772844814004, 0.004330216709809799, 0.042123716069205154, 0.06544506808202114, 0.03706688459421839, 0.07138522191634102, 0.0041007187927231915, 0.04707789559277797, 0.01230232539631787, 0.08992458798832471, 0.0492557303439225, 0.061247285470486655, 0.0761175615292403, 0.05166699591603491, 0.03596130863673264, 0.05772852106019855, 0.04516301669120308, 0.08301945448282265, 0.031654689829015446, 0.03302493958824104, 0.03576497562349804, 0.05112467461355752, 0.009358268655506114, 0.042021880001430555, 0.02184219519427467, 0.03417047086141763, 0.03529875366497905, 0.02768068150016329, 0.043476527752054316, 0.03930576506160921, 0.028547218873075424, 0.02999933087266982, 0.025171923578806946, 0.031810111831873655, 0.014471951515353737, 0.04805155887058185, 0.06343579565685603, 0.076886621874667, 0.014827262137025116, 0.047746334119790027, 0.05665107202085276, 0.0883649478876783, 0.04633428085775626, 0.051733350621596466, 0.04495013617880402, 0.04003991478032643, 0.04897326223492142, 0.022042825960764484, 0.09476421821501949, 0.0498979916465619, 0.036215764740782405, 0.0858636784757818, 0.08539665595538194, 0.019813240055114995, 0.030531355953444878, 0.05571503515144991, 0.004943136844949256, 0.031245771247232636, 0.056447962959927905, 0.04490104909505575, 0.03900790241576972, 0.07556564114507168, 0.08695931444245, 0.021293084437568343, 0.09041967230939096, 0.049351158086210496, 0.06196210296043466, 0.029018491266235232, 0.022821634775027636, 0.026608418876064882, 0.03698143897758376, 0.015593722571558772, 0.02294751451230578, 0.07392817417219763, 0.039063784699406356, 0.047419651246239106, 0.04972488641919148, 0.14245388098061085, 0.07452065125107765, 0.03436635188277691, 0.05443761035078957, 0.012556324720442777, 0.06046119116006359, 0.05025390460486374, 0.04377394989733735, 0.03315152795684915, 0.029277708606734395, 0.01991161149025204, 0.06311917534819053, 0.06095976884206457, 0.06906203730332275, 0.08014275602275327, 0.03840751164863187, 0.08861464658571828, 0.0612749450749928, 0.08361033043794094, 0.015360195031990449, 0.06399956359077366, 0.014438464854573532, 0.028137356087925936, 0.04924626915805763, 0.03364485410612918, 0.05880321984389617, 0.04830203131742535, 0.053532891155731295, 0.04365350172344235, 0.038539562224140095, 0.025359354650361404, 0.08005890769944077, 0.05170764837173685, 0.0067315662313523076, 0.03789085046117825, 0.02070508897304535, 0.03612739649871665, 0.03180840920146195, 0.035000829732105616, 0.036694646302250125, 0.04353137581699318, 0.033407454949713526, 0.11723728489971931, 0.018598883442821044, 0.04781175036764434, 0.00602540314092391, 0.07786159133238178, 0.08573570348803075, 0.018825164748235576, 0.05143353445155006, 0.004789192434175, 0.03325894114471251, 0.030753536773244702, 0.007613744725653482, 0.027310291395312356, 0.01423373934812844, 0.00648122689228565, 0.06039907675116293, 0.028400499629037037, 0.027634752613882867, 0.022966547966784528, 0.056600138665206974, 0.06309878208764619, 0.04006989946168277, 0.04385174229560841, 0.0327719543730059, 0.01972986670631555, 0.04297227335853442, 0.02443770874261616, 0.05323779408729846, 0.04524254427862264, 0.042878998323313655, 0.1452062203879318, 0.14296026509856025, 0.18378850733560903, 0.20575600195555918, 0.16611861275328746, 0.126205692368169, 0.12719789114330085, 0.17717617263476695, 0.23141634680571097, 0.10701793245971204, 0.12952657626761546, 0.11317355618361505, 0.29300218568213526, 0.10291902498612482, 0.14806927482206977, 0.15507796809317606, 0.13224375223921192, 0.08233230425826005, 0.14791227276286772, 0.11462522385221337, 0.12891381318050046, 0.10674169647597498, 0.1937891723167512, 0.18692939121636654, 0.1468065167747198, 0.12945255685237148, 0.0566954093594705, 0.12889777129936603, 0.08155989610860426, 0.11912121767959288, 0.15733516955327603, 0.1332604734888, 0.1269121480084235, 0.08378697499152153, 0.13286368590929817, 0.16974678984092129, 0.2122029229517906, 0.15126430579731542, 0.15401263090391315, 0.1171392256454114, 0.14732172622555686, 0.09575804109655081, 0.11393199855041121, 0.11793236413429822, 0.24462647585859223, 0.10641905088578502, 0.1727849260092743, 0.1446674613943023, 0.11203103563598088, 0.06260144163764293, 0.17476299567328346, 0.20803540464370482, 0.19949594512581828, 0.14935785003246801, 0.10899162010079431, 0.13364413032127967, 0.1869131195088548, 0.10410777893998932, 0.07764749274018311, 0.10973009055540447, 0.12958187249399003, 0.07583667539180287, 0.1337110710841033, 0.18643247594516124, 0.1651127086651902, 0.17978972755372527, 0.16703733603560156, 0.10488073867295059, 0.15618537883124045, 0.14836558230942296, 0.176803486181363, 0.1495359807966217, 0.09031765238051453, 0.11476420752343633, 0.09237269089827616, 0.3584746337465702, 0.14982507173572818, 0.18033265406566282, 0.1430927676659438, 0.22255637142206394, 0.11756597492363184, 0.14758550561964512, 0.21511263214051726, 0.14008277756792886, 0.09424242806891281, 0.12125050543897575, 0.12881921664361032, 0.2362146465888908, 0.17794894084574717, 0.1674229540531674, 0.09719342173587892, 0.16452631432442896, 0.1576771818461918, 0.18208144893569334, 0.1349084205444782, 0.20013401975795148, 0.09835324054884334, 0.17565887421369555, 0.12140597532232925, 0.12507071012570975, 0.11708087272821896, 0.14085778275564795, 0.11071802222079809, 0.13561780264060344, 0.21509688137279404, 0.11334044843791954, 0.09328619712182591, 0.11531069634422181, 0.12148521179633757, 0.14561232359659287, 0.20019640995850488, 0.25765151806896736, 0.1513732435001481, 0.0884883646522799, 0.1105164644879199, 0.1361257342561599, 0.18671739936595966, 0.1698804108966743, 0.13709308879990734, 0.15429848895197915, 0.22058338858187201, 0.1658922031281456, 0.2921927984683745, 0.05983478404701718, 0.18953136288590972, 0.09452283923183719, 0.19262706290089315, 0.15712475584399316, 0.1295103352036207, 0.07973203330390877, 0.17471742876354726, 0.19415500994411208, 0.15191960208598645, 0.09338663890957834, 0.13129885939340438, 0.1531662263216511, 0.15570884149882103, 0.14979050584858464, 0.2099801341612493, 0.1421261026013282, 0.14377945823775184, 0.13760207761679927, 0.13084475311540789, 0.15650129816945524, 0.166048806821627, 0.154422166186475, 0.18992766016914, 0.18562731753674247, 0.09494814060388074, 0.1307805549473532, 0.18743094898039298, 0.1891398613130854, 0.10411476566185875, 0.2664721931420988, 0.10675187778448868, 0.14787700207483384, 0.13836764460129125, 0.12679682879318155, 0.1392293402985219, 0.20123589934120256, 0.08848857915689869, 0.19702410115109337, 0.07250444573019782, 0.11703529815760352, 0.1476567517966032, 0.17308172379289904, 0.14626302335771824, 0.1812570770421336, 0.12178989262470316, 0.11850485397923378, 0.14494878420185658, 0.15635522052405343, 0.15292815683830172, 0.14380673096785623, 0.09122013459883391, 0.17956281231055338], [0.07710446663681539, 0.05317028258897124, 0.028961908012147874, 0.05308536174256475, 0.04745999343633171, 0.061586532185995774, 0.0049605442778087195, 0.1117387424493509, 0.022673657231573618, 0.046824561807537274, 0.09072307377092301, 0.044293702249565435, 0.07490628459040197, 0.04012453685244245, 0.05473408254704649, 0.0288662695956807, 0.023598039988428358, 0.04241057769245198, 0.024171525747665477, 0.03216269230770488, 0.04786090256886617, 0.061344827615445664, 0.020290361529576684, 0.010858514916992957, 0.02266290710277615, 0.05461033253419784, 0.020635499461223523, 0.05599762200407925, 0.034564588624503345, 0.01943366838649156, 0.00528802148877613, 0.016980758274815256, 0.09951155782947618, 0.0361958809287077, 0.08288808572556704, 0.022697216350465052, 0.01921555166313004, 0.04899436029635611, 0.06307286916360741, 0.05257433513179422, 0.028514884217011354, 0.04157762561414031, 0.051273602106037645, 0.01776405444909488, 0.023158629192039374, 0.020965792524117618, 0.03451871911003705, 0.03252913131408634, 0.05106865060365489, 0.028057673367701715, 0.036829998716712, 0.02584979073294709, 0.0151307430801793, 0.053906922093442375, 0.033208819842266465, 0.01729712577446574, 0.0583262266891618, 0.05979053480851074, 0.041892012776506525, 0.028690184286284833, 0.020666748187654925, 0.0329303813557471, 0.03609768377857343, 0.03325604150191911, 0.0663937224195369, 0.009291768393238947, 0.03466710651053056, 0.060411180940366564, 0.007197786753456439, 0.01766135078674603, 0.02976776547579756, 0.021365037330636577, 0.02237451713412039, 0.04648678215040315, 0.045425627801206805, 0.0639917686461441, 0.03994087110303583, 0.031157106146096226, 0.04653796448462433, 0.014935481632428785, 0.012248068176690611, 0.03515032796008933, 0.028845929961291053, 0.06629784651581319, 0.026584233480295347, 0.03067658515647054, 0.031222351939387383, 0.012005426106043162, 0.04028332772694769, 0.03872728440910578, 0.02289963018659863, 0.04229579856919666, 0.03748560144055275, 0.05411742007239692, 0.05881899359425711, 0.04948471785492955, 0.010376388015556, 0.05171186568576002, 0.015421303950490491, 0.0333902869193304, 0.027101260474732807, 0.015681890673154307, 0.015577341696517843, 0.032069907568755655, 0.01476723723293793, 0.03518858256058828, 0.0497588777403918, 0.008645440121331524, 0.046960580718493274, 0.029583440890776056, 0.026843837695196274, 0.09376354650744508, 0.011778605666251914, 0.06299457114730632, 0.04574931144053417, 0.012641097137313938, 0.016623292073246934, 0.03221882356991691, 0.02701246896908889, 0.060240764681610375, 0.0177014171851859, 0.04569030734860609, 0.03145531353150164, 0.03151930294059698, 0.03349607983123391, 0.046558637367261034, 0.041622935884421876, 0.05706412364698707, 0.04374447849489028, 0.04139454975243538, 0.023918299214734186, 0.05712874699383975, 0.028705128746467735, 0.05108216822507882, 0.014571390685535248, 0.02549277077759466, 0.0362199705634867, 0.06842069913663211, 0.049162229312764066, 0.07274233901332464, 0.03687346654553567, 0.02864461546132882, 0.0556238477058228, 0.030133375192000985, 0.09097929953807786, 0.025136204729337367, 0.04716226102543935, 0.025780973054708976, 0.050940066576004035, 0.06573485616113871, 0.07958364973385489, 0.04823813958454037, 0.03159530843878466, 0.04232532359779843, 0.03128516923395857, 0.058815959886076956, 0.027489745576355248, 0.04194403780744441, 0.03401184469581612, 0.022832831150040995, 0.036100541286531, 0.03304868448345411, 0.018658485083330064, 0.0736463074422171, 0.06236231878339764, 0.016873166971509496, 0.064242742880578, 0.054337712485463395, 0.08379991421656263, 0.038712349525021936, 0.03931553268264379, 0.07280800040931472, 0.08497104048728944, 0.028463996826641025, 0.02359351240879586, 0.057081992647820906, 0.07272358518093824, 0.013088221481490522, 0.05818766053585757, 0.06622189655900002, 0.06412864940601491, 0.07377277323675734, 0.062240844051684105, 0.10404059302902992, 0.03420931151917866, 0.031573511322119066, 0.11291117873042823, 0.022563876832024227, 0.10229922921186495, 0.010088760304384896, 0.07569310285391347, 0.05341805840632128, 0.01730200000888398, 0.027710805992565812, 0.0249317703363035, 0.03357107600858135, 0.020672020787793784, 0.020774174782056964, 0.03476723803267364, 0.032821098913348494, 0.024177531876991835, 0.02452246488011893, 0.031410037735176664, 0.015126305515877904, 0.036986414718651967, 0.029477186410898165, 0.03435309473124724, 0.04974023499075444, 0.05162886388960385, 0.025707851877556216, 0.0576828200850756, 0.04199605517750306, 0.0819023680542746, 0.03154060784577122, 0.023416915735710534, 0.05111238273281244, 0.024558241186182828, 0.004419279697861884, 0.10327145607481081, 0.04715610933940738, 0.033713177657656135, 0.016111145058887142, 0.07345078648218224, 0.012235296533382949, 0.02924292629975225, 0.05053117480729857, 0.0974361413729287, 0.061703923669072895, 0.042147801873544534, 0.030800722043720946, 0.04839954664930702, 0.021664123801935106, 0.059431848611923, 0.022130837971945445, 0.025250455251924937, 0.05011755244566068, 0.03281495488819576, 0.0242258662793545, 0.026355847348308852, 0.12676027107743487, 0.011873067180145414, 0.04483977355243218, 0.017709489836688005, 0.02589381780595549, 0.023218347660956845, 0.025621755086185954, 0.0737908069464949, 0.010329136669996285, 0.06819540033898047, 0.01772548383732717, 0.01937609113332245, 0.04071898277728789, 0.04854613374317846, 0.09077117643168858, 0.0522952416400996, 0.010764426870962546, 0.04419416444556368, 0.03060642299392531, 0.08822080844472494, 0.05315554688774771, 0.013002854388868137, 0.042503025352714524, 0.07215661116905751, 0.06595269326240787, 0.0741879316046834, 0.031005811441930074, 0.05896372292491217, 0.05639290805124948, 0.025506190722808245, 0.07984169112939028, 0.06457169720482442, 0.027274909624529463, 0.012917025728271374, 0.05982442270784129, 0.04023888696646018, 0.032541963286818035, 0.042241892792404666, 0.01905748091127363, 0.05041934512255173, 0.04362952700185199, 0.03300482978022868, 0.013543639685057346, 0.04481085756373021, 0.04686467800169222, 0.038582371217348886, 0.054836692363624616, 0.025492569679514538, 0.08259041460170861, 0.03335093681309973, 0.02224447945463321, 0.03011422107867416, 0.03687291496223019, 0.079855028720152, 0.07124528063521271, 0.007567812008933435, 0.06787228743515669, 0.06856181253228458, 0.04022226285850329, 0.008117133439818939, 0.041722692023482055, 0.07458758435302204, 0.06802908265061917, 0.018655095144265124, 0.017970199133419705, 0.03371968174413328, 0.11231038959756975, 0.019256060477346182, 0.013443222795162472, 0.061838613417480266, 0.05342561203325468, 0.023073629821620645, 0.009291500262465448, 0.03921506791225365, 0.06782269090293877, 0.028902170391032295, 0.04493729271475346, 0.023723291533608592, 0.034343587580106916, 0.03797726517903709, 0.02130031630757355, 0.03141014307226626, 0.004084312541019773, 0.02487487681660681, 0.011061290729670756, 0.025701150523438573, 0.07036103897037045, 0.03653301707198543, 0.01370121535259269, 0.06966926923562443, 0.08082930869873493, 0.0316209991973254, 0.008755407254812459, 0.00809991848655045, 0.044800147654548775, 0.03307134153381471, 0.06794784668712847, 0.05814094832467456, 0.026784433322327755, 0.08122976583939406, 0.15637765157847636, 0.017489994155062784, 0.016441893944096182, 0.04293691840082888, 0.04573024734253845, 0.037590758499479106, 0.07018543629636688, 0.07903711494779395, 0.06462530803776557, 0.027885788135350715, 0.019867571010704965, 0.01347469655992163, 0.03233886571721204, 0.14560674647650412, 0.13557816525140118, 0.15802507769436608, 0.1685568407898949, 0.09305286972272782, 0.19652026044505258, 0.10805655616305529, 0.25067277883570044, 0.0983750127676514, 0.13080790428625, 0.2136643582414235, 0.1549929629770979, 0.14742761489845094, 0.07079233114998187, 0.17536789869829533, 0.09122014225971314, 0.13658364033026082, 0.0786553043872118, 0.11965659056459704, 0.14466102625573837, 0.06666418976120411, 0.19498477509665876, 0.17868188780642327, 0.11929093679833798, 0.13531715909559883, 0.16266583915679686, 0.16407839803686067, 0.17260887900427466, 0.05748506980918108, 0.08103590729015489, 0.09932493881112146, 0.16267469513320154, 0.15715353010642916, 0.142605995398856, 0.2186491544688902, 0.11620954730578008, 0.19604030636049088, 0.14854254861993177, 0.1572396077456013, 0.10334439530608155, 0.1910361281085399, 0.14555091398858255, 0.24207618448042104, 0.11962254561724202, 0.09902749751364032, 0.06597084188533407, 0.24130700156092647, 0.1787388234609558, 0.12474080968287685, 0.18965171529881417, 0.10857645407198899, 0.11473395471130649, 0.08597213354322218, 0.1944498005773752, 0.0903730022330438, 0.13006364986781152, 0.13452352264956122, 0.14328827330422017, 0.19403764527411232, 0.11888628149585379, 0.1303489103672966, 0.10859640300153725, 0.13934282856362482, 0.18920500943016624, 0.14027759372707338, 0.08730683490754136, 0.14286487183022883, 0.1697605181365244, 0.07022773967154565, 0.15324775339855304, 0.142248799243281, 0.10925582850412016, 0.17904047824202046, 0.09649064331766098, 0.17718459960193406, 0.14425625604006553, 0.15817265687209947, 0.11612258100461577, 0.16580453202609094, 0.2058289335259507, 0.11979935871016596, 0.2593535509320998, 0.189316536510183, 0.13081455392943275, 0.12750285542419842, 0.11969474174322621, 0.17115164187646684, 0.10022671622855049, 0.13248926809718534, 0.10769372926123681, 0.1759808916117876, 0.1357744522993603, 0.159653075820496, 0.17603776597928616, 0.15055955087225284, 0.08078204107380683, 0.10684063673139581, 0.2075290664910309, 0.0618712104586584, 0.06557235359064033, 0.1582577845622455, 0.15777133405208588, 0.08966970287503735, 0.08772688857730358, 0.08266551420092583, 0.09297285949991596, 0.0903797667894152, 0.11194117352246277, 0.17089405247280676, 0.14981353445158851, 0.10424137701310458, 0.17662360873674193, 0.10235461736879042, 0.1936040088654526, 0.15239831510811083, 0.11224295087759534, 0.1480727681830045, 0.1926161691306099, 0.14901752313298566, 0.1826377819863058, 0.21578078338455772, 0.10554174997753675, 0.21087809646081543, 0.08867641625505301, 0.12319638408840665, 0.18092431909134313, 0.10887486830113396, 0.10036773769365204, 0.1428491670277811, 0.2981851688556133, 0.21196716705397253, 0.17100265309695276, 0.11017216925298977, 0.2449414605695394, 0.16904235667278691, 0.11491580100189294, 0.16000546094390655, 0.12845882590139104, 0.16557605396355354, 0.17504536036041476, 0.2686585774344783, 0.11700446311865123, 0.12117881493102159, 0.10837422218173744, 0.18464755236862168, 0.1396404384004493, 0.1262752225081767, 0.11284135747700931, 0.11032649000445682, 0.18834172027005305, 0.1302309328269574, 0.1235466241656292, 0.09637940735105546, 0.23478445236481008, 0.09799870271836558, 0.10524023309229844, 0.0715887101907884, 0.19861938732285656, 0.12684520724559986, 0.18420849205745807, 0.22418639202031398, 0.1560658844368112, 0.1685514322091495, 0.24020576549153175, 0.14795331975385068, 0.1373420367317815, 0.14889212986153944, 0.08710502436564815, 0.17334927233957476, 0.23065416592984433, 0.12358804653969505, 0.16233078294223355, 0.21385390371564897, 0.1114271515079083, 0.07319656020450978, 0.19751350876064072], [0.03236554472917511, 0.01917623986129559, 0.10384884888246175, 0.02268251129275849, 0.046144386813525236, 0.04761624855980758, 0.03760616452763638, 0.04669448773887369, 0.05176846426160586, 0.04208017546202868, 0.0365370198813898, 0.060809163617030274, 0.047543715355136705, 0.03608804639248598, 0.03623856734784861, 0.0217145036590556, 0.031831600598149726, 0.02572633566394929, 0.02986986775912585, 0.04819520418682406, 0.09603485164623107, 0.06245908717955313, 0.03986414356697952, 0.012614896930303546, 0.0627907726072496, 0.015353617209550596, 0.02262387109259444, 0.016017301203382593, 0.00860530669019828, 0.02311789246666576, 0.04488437902182341, 0.0512870699317465, 0.024001078845392314, 0.05337996851472605, 0.014162319843777487, 0.02679291008520992, 0.005684931642345844, 0.03842112120060671, 0.06688702175573957, 0.01849504980078388, 0.03188146334592133, 0.08202909431870907, 0.02260141322509416, 0.018765314129151164, 0.06825224406296207, 0.012316175308378955, 0.06853054082321544, 0.010426337905828992, 0.03802817555204515, 0.03419449920916269, 0.004452202805212789, 0.05878589859592819, 0.07458451234044568, 0.02348256372516194, 0.06047663932305671, 0.041306476454220475, 0.024301820066607287, 0.07707636653175277, 0.017538297913908478, 0.008403120765222177, 0.02943868857748326, 0.049874805995533546, 0.006129776874947692, 0.044684453056223934, 0.033775066070619135, 0.10679156879984564, 0.05262276721036723, 0.0332223221419319, 0.04515674626154285, 0.07591916007861015, 0.04412161208869469, 0.005435333972150881, 0.034226046709884564, 0.04434620991589562, 0.024292117563046278, 0.041272094428178766, 0.05845806659049085, 0.01251230339309381, 0.017346241586511175, 0.08293379819200886, 0.041839485957978234, 0.03621807449587411, 0.07523718094753643, 0.061630348584824995, 0.013963463528442287, 0.061927740086591056, 0.06033256116713728, 0.011622431939618002, 0.06594626578472315, 0.030122048582040498, 0.018689684014046387, 0.0572573846476453, 0.027779213813764435, 0.023625940910630652, 0.026014800326177673, 0.07042867687320517, 0.03243036342844848, 0.04274427027051007, 0.014935156045060967, 0.009373902594820868, 0.029027443003630447, 0.06809755558929137, 0.013447641207265758, 0.021859307683283286, 0.007005288010282863, 0.015174529793101455, 0.017061873579457883, 0.024129672449142225, 0.005697991047430063, 0.05488663363540846, 0.06290308109694911, 0.0032164910132245674, 0.07281953769345438, 0.06614065293463008, 0.034388265827850956, 0.07541898893372667, 0.051083393965757666, 0.06793418733943855, 0.029921831503029794, 0.05028606880636466, 0.06455519567093541, 0.023311375632822033, 0.015306754653612453, 0.04885554516447648, 0.015260782674886288, 0.08286522566190652, 0.010564881076495494, 0.07118128931089755, 0.030275739226189834, 0.01799761550500989, 0.029833742883056406, 0.025884594107347152, 0.026869271814282385, 0.08661768519349637, 0.05516328713706425, 0.03562094726329369, 0.0618850460065709, 0.04284560455069427, 0.05021227921749796, 0.08572158448758625, 0.03635129718590648, 0.038079300429672, 0.03961074849470489, 0.07891657867378767, 0.07303451728676597, 0.03979651715546366, 0.03796670082656126, 0.01136490956865131, 0.024092316086734497, 0.02567599602644482, 0.0473189604799113, 0.0037010394707096806, 0.04434033402151639, 0.02893512749353484, 0.02173162572416327, 0.016417425095794663, 0.016292213770230452, 0.008894584363236303, 0.017911666185565053, 0.0458561270798166, 0.01974400868939777, 0.03873416387866582, 0.035752534355607726, 0.042357246481603196, 0.03736692292976283, 0.0841951159940612, 0.0041367100822108415, 0.08386701585785036, 0.02659480740887023, 0.06794362554266568, 0.06116336819926097, 0.04600438041492336, 0.0839317043221766, 0.11564864837113889, 0.05426701023093155, 0.016269455213219892, 0.02877028835486741, 0.009816762702088925, 0.01086735844446887, 0.035045044496655464, 0.02365999734930454, 0.05183592213377838, 0.029306739508625, 0.05512543090228593, 0.00867576283898445, 0.024688876414250945, 0.033824677924595536, 0.046856285508481726, 0.023928695027866674, 0.00790676378059171, 0.02332772586434599, 0.05499065688420689, 0.019913180055277004, 0.04181963278942051, 0.01608557878963409, 0.057313856818983634, 0.0060386626864783475, 0.04471836010775259, 0.06163187693023394, 0.03687597548348769, 0.025197834587625922, 0.06270592453919592, 0.017487151968863704, 0.02964649567260377, 0.012942097870813263, 0.0276160198489144, 0.03488633023094266, 0.048244862006075924, 0.015606351530990534, 0.031276366883708585, 0.02275322695382901, 0.05389546524853476, 0.024033131964144208, 0.028389598197874524, 0.010228038919458707, 0.04197482305068163, 0.029294055007818728, 0.029078899214284557, 0.031526806771815304, 0.021592915929373235, 0.04602866157168343, 0.052011800599434686, 0.010387830496315035, 0.017307820361888698, 0.06256248223625364, 0.028341192932378863, 0.09373897040683417, 0.022273422256412528, 0.053016812195100134, 0.041251992281045646, 0.09465819930717831, 0.024094386439349864, 0.07134958350610349, 0.04781490281945275, 0.054751691077986074, 0.04113113425011116, 0.0290104856474265, 0.07532606246851145, 0.062050720181075804, 0.024240163395241387, 0.020658888125551805, 0.05716336650713798, 0.0845625470843046, 0.04803651673418861, 0.07014733108301317, 0.09119201151113357, 0.07100038530845797, 0.008672901500587263, 0.02842695647550206, 0.0860515998436078, 0.05427677785196612, 0.09353087794396187, 0.019893807606891762, 0.005369646241888405, 0.05006677230759975, 0.019530262497644273, 0.012353610194798921, 0.043808416193050724, 0.014557952545733463, 0.07995629788286264, 0.031084965561486544, 0.06921120228305941, 0.05802567124426846, 0.054004559999391924, 0.05656854519920965, 0.04077689902436349, 0.013269811132622343, 0.05258205346763135, 0.024650579678916165, 0.026862830930058996, 0.0524457396128245, 0.07969482441342647, 0.008981045046370597, 0.01901850235768624, 0.024823903241345, 0.02035628722590064, 0.012047356013358842, 0.05397077169149153, 0.05634676274513045, 0.0829918293522731, 0.012786785035484262, 0.07611034498099359, 0.01944711131434287, 0.019902060289056073, 0.02380571876382155, 0.046577146051511656, 0.008688056634949341, 0.026933563828107812, 0.007643172078044906, 0.03955459424985513, 0.03475372807212895, 0.0202103991872601, 0.03937208529321417, 0.029479015445817384, 0.03954926227790214, 0.03640947390287634, 0.050132249842488, 0.03173838493474309, 0.03537361577693974, 0.02014542727040187, 0.03488255341747596, 0.050334470241420695, 0.007008051672469705, 0.06941325031220913, 0.04127767154826753, 0.07763899682510285, 0.05606234111192246, 0.08632514685873063, 0.03210132100409077, 0.020067483569765766, 0.03528382644177445, 0.10382331517194548, 0.04590810231503941, 0.09122542826639068, 0.05404058145359159, 0.04597235793968843, 0.0378343399854437, 0.062418748819900144, 0.027929623686378042, 0.04576259923558082, 0.11620512697845699, 0.08791328543016026, 0.028332342701633612, 0.03907375916418049, 0.016329863161269217, 0.02044948373710917, 0.04090806859875879, 0.025459398072393193, 0.011377242626622321, 0.0685366695266097, 0.029625232902265368, 0.06846591364592314, 0.06926956286113109, 0.028350135093675028, 0.021922624850225066, 0.01021866487609523, 0.02168284124514509, 0.009496596363943913, 0.07307550299071497, 0.03976037695763573, 0.01449711750366635, 0.01922775544376383, 0.04543782009052173, 0.03834726649426645, 0.06491298937509138, 0.06305393147011919, 0.0397330965666521, 0.05091693455113038, 0.029431194322363987, 0.03859955073905088, 0.07175950949350673, 0.05721679730941692, 0.17111140693868362, 0.07976694393061823, 0.10897937801576431, 0.08214556266583743, 0.172471703300553, 0.16149340287571953, 0.12003172083847946, 0.19462456055466207, 0.1304013720683513, 0.13361026923502647, 0.12174572765586839, 0.12427451494600504, 0.12898351185985152, 0.15082040381047035, 0.11855082691556985, 0.12077758404155894, 0.11715915925320118, 0.12538195632758642, 0.11230822156874404, 0.08147649977716707, 0.19398853903816593, 0.2566217733246665, 0.16348918449253808, 0.09146563513504882, 0.1340069495622189, 0.07942883102523704, 0.1359020519040285, 0.10262676244301182, 0.176483521898908, 0.20709012875393515, 0.10557439298399034, 0.12511535772993682, 0.11684165411298314, 0.11206550193169426, 0.21268180451325833, 0.1397618326929308, 0.06672513971645987, 0.1586469419060215, 0.2564052155902309, 0.18346014672950392, 0.1250634016469121, 0.20389387203801065, 0.14966966313940866, 0.08648283839706453, 0.15435456658803648, 0.1624038830519684, 0.13804908992061693, 0.10079166776831112, 0.15653885179950347, 0.10512098384600495, 0.1304351565458121, 0.1107725217157314, 0.24655263540485214, 0.14121326287427258, 0.18001000847547285, 0.18587553002420934, 0.14177564801948686, 0.21945733126373063, 0.15754300920713335, 0.17390721417482824, 0.12781348875573567, 0.12595007947135356, 0.22034622308227325, 0.11099971275055602, 0.13195286865436262, 0.17682960977958095, 0.16011680416282148, 0.14292644997758253, 0.15661043505514824, 0.11169688340516822, 0.24981073073802457, 0.050631222059769984, 0.10350853730473789, 0.10969719473993587, 0.10951491944011181, 0.16942497162568956, 0.17998992165009822, 0.1116042633751227, 0.11959099045564091, 0.11467924071175438, 0.17739403271867385, 0.0469714132017426, 0.14753669049711, 0.16619986403853665, 0.15410483724647953, 0.2037875390341205, 0.24991304944119147, 0.20970080318229817, 0.17539330217386448, 0.09707597279620749, 0.10277843253026087, 0.20596931147719585, 0.11925543628392682, 0.138457874437013, 0.12505225506761383, 0.23474657697783363, 0.09998969628565735, 0.09238665668113578, 0.08376222269068803, 0.11644004784043759, 0.11254873487257189, 0.12500261257012046, 0.21356695782273047, 0.18512779756659464, 0.10564445938554504, 0.1414638655560632, 0.08904728708007643, 0.10300370834527478, 0.08885016499627983, 0.151465970782503, 0.16636256579189532, 0.11918812779889953, 0.12652394061367359, 0.2419201323702451, 0.06682092368963265, 0.1333084765581354, 0.12380085044330168, 0.1401939828910174, 0.120854698452017, 0.09571064323667558, 0.13649037678635892, 0.09365847754863002, 0.12931648431526077, 0.124224251917293, 0.09347293871424853, 0.23886547934624458, 0.13650290998480014, 0.22775651496504584, 0.11203520315428896, 0.10745668633570594, 0.07731779914108977, 0.20243677280602917, 0.14088825773327582, 0.1850691765186287, 0.1129210536037722, 0.23253184743225577, 0.10556181382027366, 0.17875789905027037, 0.16204014450552004, 0.21876181535903486, 0.17772369567425023, 0.24839231894621927, 0.06917226969474746, 0.20627027677912868, 0.2391039471953146, 0.14384250727392014, 0.14538117954807897, 0.07749704839361292, 0.21249953687431353, 0.11857721864456132, 0.1339181599717948, 0.14134761937443288, 0.14863722176561434, 0.11129931441598362, 0.07250026289013124, 0.10458882853028276, 0.08301422976317906, 0.1214217720553279, 0.08799755510183112, 0.13827588258972093, 0.11115709019284095, 0.17266800567027063, 0.18093544268800368, 0.16868626368382286, 0.13452389037176488, 0.18467583633478613, 0.1108077617602483, 0.28395021334290504, 0.15660093556488716, 0.1955209140695872, 0.16506632970225427, 0.16895456299666436, 0.12172833745998722, 0.2456188355121882, 0.14631254328114374, 0.19282851338146195], [0.06027652183547617, 0.031891301830088904, 0.017309850494888042, 0.04437465093008453, 0.05356959059774395, 0.018454996808882684, 0.06565976422280073, 0.025206144726384553, 0.061242106716118516, 0.050727235859320055, 0.03860706989202769, 0.07664201000044424, 0.037606382862694805, 0.02342166165040145, 0.04145905818609942, 0.0076908414203283055, 0.01655958228624396, 0.0554959531573038, 0.042633899983258984, 0.03187073045410216, 0.007819689269508085, 0.004866840712155306, 0.03768359686458304, 0.08054915034482557, 0.023527942943356694, 0.018144882501914136, 0.030636905632432432, 0.020661421961361365, 0.017072248325172453, 0.09962595773920899, 0.009516189062607386, 0.01198136998761085, 0.05312776470917368, 0.06574475401712042, 0.03984750413726415, 0.027736626986053683, 0.038445685809898766, 0.05801996388923257, 0.03258307156483493, 0.0588319136671001, 0.07507187449523518, 0.07849994941704697, 0.046879708646766605, 0.0021885630943166514, 0.032856070827091896, 0.0077178421892195705, 0.03587255735070475, 0.024149102354121786, 0.056421283947964834, 0.01795314601622522, 0.054102603931941336, 0.005705234408754135, 0.08335411233166534, 0.10714868834662823, 0.06677123522686382, 0.01977679342211735, 0.04095385384355341, 0.027230499507558924, 0.011486382385145032, 0.04701706055071085, 0.0873243093730942, 0.03915804415760983, 0.046767135856733213, 0.03729686801952701, 0.04161426759955864, 0.052613194941753344, 0.038559626066877, 0.07759568221386402, 0.013075333967384313, 0.017268537288351406, 0.04088921517494225, 0.05612475429511359, 0.050564756271459406, 0.05443172679553109, 0.04753497429192067, 0.031151293453970746, 0.04516762854050725, 0.05774733617961888, 0.024616982892996842, 0.017820369572408738, 0.06673098496732212, 0.04201728730432449, 0.04987518137861645, 0.03760383945078619, 0.017008103783272447, 0.013125998234646696, 0.06281335304881777, 0.03852687197767439, 0.041238214189727465, 0.04551735150838091, 0.03429244738072157, 0.07005932290227183, 0.0556905318291918, 0.056719855225134286, 0.03232153297792519, 0.05635783654607593, 0.09449365894280135, 0.05841579385882905, 0.011765219237385018, 0.06572649048100557, 0.02895200632572655, 0.10166963517305352, 0.028160593449889172, 0.024678042015781807, 0.011562797740372199, 0.05560647666213974, 0.010647561115723465, 0.03862798409236055, 0.030163252621047923, 0.034243831441046736, 0.03522574931623475, 0.08827700099397091, 0.06131489272980441, 0.040623057077849106, 0.012619776910381212, 0.052125936208833615, 0.03799683106462321, 0.03239985397686401, 0.039780421648174524, 0.021914215120036277, 0.0356787562580599, 0.04998979962340767, 0.05341659900882552, 0.009543347837133034, 0.028444775680620826, 0.04318192481033264, 0.030333569288373958, 0.0366324131497212, 0.0414250860170972, 0.008632187757851377, 0.06327968225964616, 0.01679396497145776, 0.02954215832775639, 0.0638365975370811, 0.10064919839703268, 0.044847679579810756, 0.015620803779682085, 0.06337797134033134, 0.04302208822581076, 0.059127968345438285, 0.08753733544219887, 0.04748002663555165, 0.026395182132781036, 0.04994689103876872, 0.025828278984033295, 0.021347147262384816, 0.034059989491417524, 0.04471133508148693, 0.02730917482216272, 0.051500666736354755, 0.07558021979827075, 0.020863253570672487, 0.03667723312373123, 0.025808117465086045, 0.02687379173303564, 0.019545233770904523, 0.05514244188464457, 0.10088319229262491, 0.025196371359690547, 0.028897286580515005, 0.04832162018564921, 0.02916824804889339, 0.03774364666652776, 0.061166673868654244, 0.036231549982462204, 0.04414860902714633, 0.028657328690432256, 0.00709373573397076, 0.022282385485126607, 0.0398658404517318, 0.05675400359435909, 0.07641557739266465, 0.09860015068683894, 0.033146969733699676, 0.018225867571609638, 0.030801202763893434, 0.019152948873177655, 0.037447986523470575, 0.03037473502298517, 0.03704885854536007, 0.09777380228643456, 0.011379750606964433, 0.05851216771970353, 0.03698150409505733, 0.06466521355774134, 0.03341221235572331, 0.0313345359397992, 0.0342502512578522, 0.024159170664666642, 0.06448891374372667, 0.03653068050381638, 0.056091341370296095, 0.03941704699349019, 0.09674889921781518, 0.05859211282504182, 0.03396043253521766, 0.07843932121871941, 0.03970729089492271, 0.029671406936681563, 0.03765767244922538, 0.046109047177578175, 0.028373996817296552, 0.06305074071391456, 0.08172341757604192, 0.015480212281428039, 0.08195144364670401, 0.047796099191351284, 0.03872677113019651, 0.03932511261213691, 0.05451492011366833, 0.012716783751403133, 0.017185522085656563, 0.029441329665602218, 0.04125071674465172, 0.02342308274350099, 0.030405805633974173, 0.03366128286166537, 0.040776163579956184, 0.03827444600662397, 0.03498591400021988, 0.0791942625637016, 0.06563799200399269, 0.11680930221994078, 0.0651684413934427, 0.019907721678816506, 0.03975815913309494, 0.024061500199980313, 0.03192187639914694, 0.03922152603345533, 0.04892076989034972, 0.054253239800492604, 0.04690837565689318, 0.05585616769930048, 0.06335680050054385, 0.03700487743762713, 0.033649898795110565, 0.09904821253111286, 0.03522616300371385, 0.041017929437540235, 0.03086144791825885, 0.03839666384362406, 0.04790264286942059, 0.03547671205934978, 0.060509653882153576, 0.015318212456129974, 0.0009825757531929883, 0.038955934841426156, 0.06882037486760847, 0.0749262641634672, 0.038392887030157356, 0.022013341151778738, 0.024024086380978266, 0.038509707777730884, 0.03997994924805338, 0.04037393294575234, 0.0395139264723947, 0.008555120270278667, 0.06730926643696523, 0.027950938167651335, 0.006876950567182635, 0.04065678026827593, 0.013184826126352195, 0.07771832522966209, 0.08664823677991668, 0.0412306682236733, 0.032361078436576554, 0.035936655927329295, 0.025975584285333756, 0.05456413743236373, 0.006075822260050524, 0.04459968925784192, 0.03740344617155291, 0.039746330735544046, 0.04095701778668069, 0.024179251744381847, 0.03911413965866931, 0.04344781860709191, 0.043836217523822864, 0.01984208135024434, 0.02046849420895019, 0.041095254522177486, 0.0243057232845815, 0.05124083652551617, 0.042329705620725314, 0.009958010163128136, 0.07975813391948901, 0.017787941070573948, 0.022185170842755227, 0.043743264245530294, 0.03828062833617291, 0.009593258465399906, 0.07070380969033127, 0.01987173661379324, 0.09850089633536917, 0.014773785369470717, 0.014003160289458692, 0.008195497531203494, 0.03782927997470383, 0.05017367221655385, 0.028049204265698794, 0.07878256691319328, 0.037909592802245776, 0.041135320920617356, 0.036392160315787604, 0.04825924530685429, 0.027560221834949432, 0.015846892605505643, 0.05877468306871672, 0.04017207643858368, 0.022829232452016686, 0.09485375091073014, 0.015450550314609804, 0.06289984054502941, 0.009710919994470334, 0.061603826620886405, 0.015136424579747744, 0.04631005332715089, 0.01986151891610315, 0.04530719060811304, 0.007285122692044224, 0.10084507941839196, 0.037310109849298195, 0.0174143985139146, 0.005381731757698882, 0.035802429662116116, 0.02589133568108082, 0.057029216850717226, 0.010435780897105654, 0.0456756865605712, 0.03323676289930459, 0.08313897185988965, 0.015863420952471997, 0.054632844027852824, 0.10971693682574457, 0.01809140956479936, 0.02519278032254548, 0.009254367023165668, 0.0315285591979421, 0.04337658392145269, 0.03605806554156927, 0.03571506882567079, 0.025593130210895213, 0.049919978369988745, 0.03135110450638158, 0.04120948589256695, 0.022359314119263042, 0.024393645280431357, 0.021688914407164823, 0.07556713501652403, 0.012056617058753487, 0.009625870828336526, 0.042763154337843584, 0.18478383941035117, 0.14875792657896397, 0.1751310243121078, 0.08330813173445002, 0.20433711518924083, 0.1526873447601834, 0.14380749705578053, 0.1108033950590799, 0.12835657614613735, 0.11974664420009622, 0.14068335985704777, 0.282934595259928, 0.10788196472511177, 0.1331722201599229, 0.18469178628536964, 0.13509097929683425, 0.09525679742857333, 0.1799152280774809, 0.1445377933522386, 0.13802137285951646, 0.10828287385764623, 0.11894667986780406, 0.14290967265204077, 0.2819319393846297, 0.14111161832847904, 0.11573692468265373, 0.16050265200676458, 0.14390733363407274, 0.11212131909785733, 0.20200051637666844, 0.14981443843533918, 0.16461537970650583, 0.1319135070568131, 0.20861908703321413, 0.11699186863317607, 0.09720525779430905, 0.11108592828555454, 0.1350918679588264, 0.09409583714460173, 0.12467521723479995, 0.09063321165740491, 0.1427515367827108, 0.09942811553276355, 0.16585126338947206, 0.13972430970639954, 0.10950801698791404, 0.30074810068453517, 0.16399176881438302, 0.1570886424592426, 0.14046436596301295, 0.17113262757418618, 0.10915321102666278, 0.16097990946183283, 0.23638925334859281, 0.28691595420241356, 0.11164478942631714, 0.11787293103313255, 0.09030773920277435, 0.13646650548663833, 0.1609847051722388, 0.16384089545857522, 0.11924836529238571, 0.2693539094780722, 0.08574370144596023, 0.14393236938743822, 0.15213510261908655, 0.08929192959781616, 0.2257741705304192, 0.07956718650436209, 0.05805601981738883, 0.14210178697061154, 0.18900176630385462, 0.12931717379439261, 0.1676125608144268, 0.09840449949185695, 0.06786513217394391, 0.2551226924744345, 0.15924121163064436, 0.16189524663552163, 0.14910641997571916, 0.17242664200884683, 0.11140688082143185, 0.08705314489141588, 0.18131629563868049, 0.10820575944718816, 0.10158630778952953, 0.14989316163043823, 0.2444611540845325, 0.10753048358545189, 0.18325632137636985, 0.17742620841149362, 0.11184093091757068, 0.1652318966244498, 0.12144221894202695, 0.15559213566443614, 0.18669953419556543, 0.1442917259109597, 0.11776881202334359, 0.1283750388651125, 0.14107772659870887, 0.09937404504706783, 0.17129744373021588, 0.1244591344748774, 0.08165171940720851, 0.16648527775560656, 0.1571032134515624, 0.13439029995952884, 0.1710280412507634, 0.11631504527383274, 0.14513382507908731, 0.1280325592585629, 0.18288217935590975, 0.14890357521512818, 0.13337846635089767, 0.09685056674624644, 0.1810513517909473, 0.1504000973316931, 0.1899545192117653, 0.19553672612434436, 0.1715553089255287, 0.14563400388485, 0.16081109432683838, 0.15315782999800098, 0.11973531375969611, 0.11896200162628967, 0.202448693134131, 0.13129827716658193, 0.14473734393475518, 0.16305467474364466, 0.09742612094287911, 0.0864533746554967, 0.15928294810075916, 0.07763428538436852, 0.135214212200334, 0.3336001572109038, 0.14558471378780183, 0.16273710065551344, 0.17268516603977452, 0.1756698905580467, 0.14618669035694293, 0.23875448852777484, 0.27190697409452935, 0.09080950381054033, 0.08251144625847379, 0.246636368814976, 0.14362351337988533, 0.14174957038654437, 0.14295407510813207, 0.07160115911955796, 0.11091325206742172, 0.2975457918740088, 0.11855499443387794, 0.10295781967861038, 0.05774536733365348, 0.19454730824837763, 0.08145414533153658, 0.17194304134576552, 0.18701860981602825, 0.11685632469673311, 0.08165697477036908, 0.22491722457831909, 0.1292226691880534, 0.1300422760147241, 0.1315769339881597, 0.20535699272107696, 0.1461865064958411, 0.12638488799453745, 0.14899792660388256, 0.09844764556375243, 0.12138873834403292, 0.11830224670589932, 0.1858576954973321, 0.15900565491568658, 0.1595692964450967, 0.11069282558896851, 0.14707504591393858], [0.05311037451329251, 0.043242721548003536, 0.05184797269682731, 0.04866192793293346, 0.06248593473085954, 0.057094579472416834, 0.060396996822448513, 0.025639158688605796, 0.07325325837178577, 0.0278323803157095, 0.05059762527385066, 0.04744369874618227, 0.03937802630506697, 0.04025632695805642, 0.045082274854423544, 0.010964873776350532, 0.0383174235391761, 0.013506442285893906, 0.028505811820768064, 0.05903244867259937, 0.020529417351128596, 0.011520076847274699, 0.018559908719673272, 0.020271847099666635, 0.07445737238853209, 0.02814238928558846, 0.03674454543919813, 0.04117968890275206, 0.05453369692869244, 0.017300381648143934, 0.08630888281209816, 0.04139286052856234, 0.0564681149027761, 0.041748869247854724, 0.015274008225289085, 0.02191433577888435, 0.029880721309793093, 0.07187395536851499, 0.05317217482614422, 0.01276616003334282, 0.02831286491615878, 0.038240646207404715, 0.029252492822706703, 0.04652401402352318, 0.04811545443390647, 0.05795096234989263, 0.027789126991504626, 0.009785311919967494, 0.04384996497162408, 0.03430630974171143, 0.03538775009914272, 0.030368991278772874, 0.03521079527995279, 0.041939705580232606, 0.03880354080108866, 0.047457970964211615, 0.02029758382348284, 0.025677428610863227, 0.008007647505315442, 0.07485730858940272, 0.03332489748455344, 0.05591931632689892, 0.023547974227356817, 0.02828125038274354, 0.04492092907669083, 0.030060968391837615, 0.027548404928717404, 0.011240973779481026, 0.02937272266154328, 0.04115370703080008, 0.10065644558879638, 0.029970070144401926, 0.0531387044447324, 0.018476793925548275, 0.04096220037148845, 0.12694084566206704, 0.015709513888484048, 0.05763873555547288, 0.017321380118148464, 0.09532725453496942, 0.047038016885879545, 0.0192683944929271, 0.017034937928040183, 0.046284458329600674, 0.046081812751870004, 0.02478814608747921, 0.024937594519747842, 0.020049285151124484, 0.01662369235418737, 0.05975391963616975, 0.06676974901629072, 0.0653819041326642, 0.06961352867825378, 0.09583755336221188, 0.017726525716904192, 0.07589943331455992, 0.01144827142613189, 0.03240693262928436, 0.044256945350958456, 0.05307490464239832, 0.011551534332665465, 0.04240217753836224, 0.0030967988723498443, 0.022663324620694886, 0.039068607222889705, 0.019349871774113948, 0.02679635556564937, 0.013807745624123322, 0.03868936688729352, 0.050442955952378056, 0.023586747852424463, 0.048153521342863964, 0.03572984666173016, 0.01874773241128893, 0.059446423434682434, 0.06889920531501693, 0.02218753422400163, 0.03200406997254299, 0.0781772502007023, 0.07493184128355596, 0.02312494813644838, 0.038359431970504024, 0.07215640432531796, 0.04589851089422742, 0.014781706718607776, 0.03126778286851702, 0.020270652002504757, 0.027616799343377355, 0.07416198420668803, 0.027613472606566165, 0.01846017364803101, 0.052141583554687045, 0.022453280548835476, 0.03210688280242105, 0.0389164085349729, 0.04880430537366098, 0.0253587628474399, 0.022266014186184735, 0.013443388461676097, 0.022557405304283868, 0.07774180582454128, 0.012246490993176498, 0.10811411234880648, 0.0425087480295089, 0.016091326364286004, 0.010714894498608286, 0.10583751354246371, 0.061514060268358844, 0.008342526083241307, 0.11614652891312877, 0.03644527702201759, 0.013140601785703292, 0.03996869158600608, 0.09255074505363742, 0.07205757898308578, 0.011036375635153344, 0.06474683256519419, 0.06329910258852667, 0.025447324526706533, 0.07972381318048125, 0.09739247436124472, 0.06935420025500559, 0.07203641963461715, 0.017167283447399255, 0.05209045101618094, 0.023796027751579404, 0.1867205556482077, 0.05135912816190431, 0.036865353674417546, 0.020020384484181003, 0.03049546664941215, 0.0578420169861807, 0.0700383244322673, 0.0288096786807141, 0.07336928238791805, 0.014005007518966113, 0.03031251336177511, 0.02278526666604223, 0.05831159440980804, 0.06702190685656763, 0.006199448262416428, 0.03995490966424827, 0.058491111793104685, 0.03060979952645158, 0.036065883468836546, 0.06514472331130697, 0.09245544371585693, 0.06742779556060992, 0.021340809800031207, 0.014839717769064011, 0.04329312630298157, 0.04541100701317192, 0.008393915261202043, 0.04823481859338861, 0.030510972268999587, 0.04261273680435073, 0.0034552866042846997, 0.008181507808096226, 0.008668391157933062, 0.0335474077221607, 0.03509051181496151, 0.03706732126433523, 0.0867422893943806, 0.04318831015318152, 0.029337745002140442, 0.02975236136286009, 0.009821348695925648, 0.044384931830028375, 0.028094663923125596, 0.11177910762208124, 0.042288578190510316, 0.00570641657818229, 0.024922761142313964, 0.03883097057921752, 0.02164532017383364, 0.01442402697003056, 0.027913187269962607, 0.05683420916959163, 0.009501732983476213, 0.03739081338168152, 0.07074943022622217, 0.042800317263050426, 0.043445960843875524, 0.060226078776101914, 0.034717905800789595, 0.03518226233521297, 0.028559604599591226, 0.039365041114750414, 0.01891517241845929, 0.05975694185303104, 0.06697801001850637, 0.042795356843740716, 0.05295225779616064, 0.05879739757567164, 0.030013989965100924, 0.053961578636400165, 0.03891792155862336, 0.05696840479128784, 0.010838831245388475, 0.05153501428843987, 0.050818503744179205, 0.045373702361699075, 0.022281753462589076, 0.06420747602298375, 0.06785643707600332, 0.03853925195853076, 0.04941375130006383, 0.028578701256323728, 0.04951380238297486, 0.027709181886166338, 0.04725636343561834, 0.090032345915754, 0.03269027407851911, 0.09217160047903177, 0.014923760487187295, 0.014511930771292219, 0.03533108257538369, 0.02996879843844762, 0.06940023447837561, 0.03303314822034971, 0.06564650324083145, 0.11198183746948359, 0.011478131618200531, 0.030068154296567364, 0.012049145786271942, 0.058127940151720285, 0.00702786845185103, 0.04748920053844491, 0.04133197569078015, 0.0423822860654083, 0.022029637757147995, 0.07217675162058684, 0.02910518369096662, 0.02718968042773345, 0.052123155309668476, 0.01287336637746663, 0.030685531148206324, 0.002585332718632755, 0.001438226057460622, 0.08287808061727593, 0.08131963561379141, 0.03603388014579973, 0.11397914360127143, 0.020649264146003033, 0.09691225980678875, 0.05855444811224457, 0.046131164135952155, 0.022804675503603877, 0.03417929619430535, 0.044706478084047, 0.050218181924954544, 0.004660306280599006, 0.01590757251476809, 0.019888985083408414, 0.024424777178454305, 0.051272571717779485, 0.042652649985205744, 0.029072992676388354, 0.025382446455619028, 0.024205469188370535, 0.044887968143748666, 0.04901069712134139, 0.00967618077993393, 0.026968959005429383, 0.07291003565994963, 0.019971749392308055, 0.011261430242279125, 0.04172877476160084, 0.0707786258370165, 0.04345236916936213, 0.07726634101521584, 0.056552097291475346, 0.0351136515007144, 0.021586448232072498, 0.01803304132584843, 0.034894837637341795, 0.09007417431641972, 0.026119853963234255, 0.07503772229557076, 0.0329236512733323, 0.03470859783250959, 0.022232769800710584, 0.08622000895200238, 0.026010088885443348, 0.018533359942657333, 0.07186465506111422, 0.04156475916745202, 0.06129852526130215, 0.014020585916906357, 0.03376772694830452, 0.03189156613042278, 0.0018617738063649966, 0.026703992175058495, 0.042319558786168214, 0.0582031470032469, 0.07010078358073389, 0.016750556514448216, 0.0728740371883877, 0.00963712178711449, 0.07399010471999645, 0.04584353642478105, 0.019134409545410066, 0.05676854011272231, 0.10391514613142899, 0.05518553049994573, 0.0062902775619389315, 0.09155735118134369, 0.01988998291292979, 0.04086069755196091, 0.01101313348514058, 0.03400316875007364, 0.028240844990397175, 0.17593940028980856, 0.16679669249682658, 0.1384755251027884, 0.13111159686119328, 0.18222630084041627, 0.11137475109388752, 0.13088193902325246, 0.16071665100753307, 0.19183204749659186, 0.21472846969000756, 0.16272708022546384, 0.12183699937116717, 0.15602177309413112, 0.0918715927870043, 0.10388280189926587, 0.19071881449030292, 0.11856710628396082, 0.12707297284636768, 0.06823787225350257, 0.11246536152377246, 0.11079080823448398, 0.09121418209566225, 0.1277014024315342, 0.19350651651620868, 0.20624061385470055, 0.12224359287609979, 0.0936268687608742, 0.13519731230072438, 0.15376325396280136, 0.08740205963652942, 0.09487916204717853, 0.1999275590623579, 0.13303444690762029, 0.15551609377707207, 0.08660471532493831, 0.07534014316455973, 0.10532751348951172, 0.17449642771915083, 0.21185277480511897, 0.1123820034967315, 0.15097758973077421, 0.12130254579167213, 0.13008191340392636, 0.16710263737026723, 0.1310742730575223, 0.1992303577642287, 0.08841292031349675, 0.11760378902357434, 0.11628587264567615, 0.11386371713372008, 0.13876106139392624, 0.16035660500487975, 0.12409512013677629, 0.18993715965940108, 0.15445120091880524, 0.09878393517987383, 0.1411522363102244, 0.225998496396407, 0.0737824872316372, 0.14495364119929655, 0.10267852700405544, 0.1818299882354275, 0.11636970564723016, 0.11451085458599752, 0.1785079858476116, 0.22184185653684602, 0.13798450870860007, 0.13614695489166245, 0.1394160052821521, 0.1076917757370299, 0.13320981975524657, 0.13237147441794797, 0.17816373657795692, 0.12918169880586286, 0.11053202373366203, 0.16206472060613095, 0.11530019327877991, 0.11364670740740915, 0.15711625226803366, 0.22184351128676247, 0.0640458008274436, 0.13190717917055855, 0.18307626007064698, 0.10397104756726373, 0.31547249445030767, 0.22198931314051154, 0.06541801751741479, 0.14782426458212639, 0.13189767968029747, 0.15264620583864952, 0.1371320826752532, 0.21932145790948024, 0.16165084926591766, 0.26991572771822253, 0.18355987605548676, 0.20637322367439348, 0.09828774769219661, 0.17625852187554683, 0.1741984654818812, 0.09323706024236257, 0.09407080139123625, 0.09713695339498021, 0.14781953015875432, 0.16633901624910294, 0.14252043869947234, 0.1469950356911267, 0.20322823356236183, 0.1340587983929342, 0.19555278332723727, 0.2297870769736267, 0.06342094121200424, 0.19077620979759002, 0.14635830937374025, 0.11996696342624004, 0.1698274742211065, 0.11049112996026395, 0.1106782929010449, 0.08272127008005496, 0.24735641485500723, 0.13449039700771534, 0.10554842260335723, 0.15717056790186515, 0.17661977829712053, 0.07915414253910703, 0.23045775630781729, 0.15079233434892472, 0.18346868094898042, 0.14617826338977585, 0.13409750115486885, 0.1048549674751778, 0.17942902271545705, 0.11635782362352456, 0.1246915119249494, 0.13592327253953104, 0.1905520065056701, 0.16447601299132072, 0.12062133274852269, 0.19877683371305468, 0.1410667562196332, 0.14891750269359158, 0.23840729748049092, 0.08536465646278474, 0.15701309086815005, 0.11063829545051822, 0.10245066181185747, 0.091305737263493, 0.25930164081435053, 0.17419918560453002, 0.0661038424098684, 0.26353286699421946, 0.19344133775561087, 0.15866203383812982, 0.12352606236574151, 0.15570729400121397, 0.11794626863012392, 0.07227926184573481, 0.22474791914705308, 0.16489448085907968, 0.13386939081453508, 0.17838942608044994, 0.2837965973923283, 0.18308272585272792, 0.12669190539107208, 0.09403305623920695, 0.1248249184760836, 0.13988966212397622, 0.34502939230972723, 0.18495636241089913, 0.2015990250173115, 0.13972905945153008, 0.17645560565494722, 0.10880798882534427, 0.17840140769558568, 0.14285840604814792, 0.19365270141391985, 0.09462979276694598], [0.020725639281614174, 0.03882161281522244, 0.012085353016793247, 0.03223061749351121, 0.03751674674511437, 0.07967590204169674, 0.06764796156916889, 0.07838857555461508, 0.05834734390279459, 0.06989825291619187, 0.0652263576405183, 0.0665728567588714, 0.036216998142340494, 0.04713074033779483, 0.011436564645038979, 0.021657839965736194, 0.1075956317025327, 0.023864722855749632, 0.07702847071472677, 0.04141413862065923, 0.028177196490428144, 0.022258370543920228, 0.04137212635889169, 0.10788878290763787, 0.0592131266791013, 0.032016570612247434, 0.023847472470914646, 0.011876803773996091, 0.0443633511332014, 0.05477191579918708, 0.03398434596977407, 0.043060630109281316, 0.05907618463219655, 0.09235751469649615, 0.04535200675168345, 0.02968921656570127, 0.008015669403492564, 0.05819236814615227, 0.060487954441698334, 0.008625745916018083, 0.04042853969299505, 0.043357558127853184, 0.03132560143938228, 0.014954003723218076, 0.046277100055087964, 0.08578726120533482, 0.046337253278902465, 0.04384649459332709, 0.022353643153403557, 0.0244330988085318, 0.031502678832640095, 0.06775526750472284, 0.023992694013061065, 0.029235897443046974, 0.03512011345235571, 0.01679554885824121, 0.038671409786348386, 0.030585976107226267, 0.04166645350896063, 0.027849496635157737, 0.03871700733960156, 0.033924617924757546, 0.08290502392957289, 0.03653046216875796, 0.03923452654553037, 0.025741745522546194, 0.011312523518779106, 0.09107690680051043, 0.0377184193911812, 0.025067321933625687, 0.05121852038428188, 0.040223806525670716, 0.00464160607436732, 0.02785471943958152, 0.02673629235716597, 0.0036497225922968, 0.020990449063960585, 0.011606763526346656, 0.035002047811905225, 0.04230296149128868, 0.009366619971490676, 0.02712231831655147, 0.02979220942624154, 0.06422181335848666, 0.0012980598577057884, 0.007745358152239914, 0.019571788293579896, 0.07789473229598615, 0.029654648763337926, 0.014293462605095439, 0.02125639074121512, 0.05897368589836744, 0.07800036049898594, 0.026780819302544962, 0.046861981372198755, 0.037764867302030325, 0.04003002458522397, 0.031779382130010955, 0.040239480684601495, 0.0331198770342575, 0.05057043298297832, 0.02669651898735714, 0.021196090045475194, 0.04567538395584111, 0.050949922297149904, 0.02698687397153868, 0.03787838238021059, 0.023887328195175337, 0.04749646688240671, 0.09132356412949101, 0.030053068110118472, 0.07897222730060739, 0.013520555540678963, 0.045295254958252755, 0.03942345914941642, 0.04653454007160279, 0.12022776273830284, 0.056753379232700796, 0.12860400722392146, 0.052153258734653075, 0.017483957382219455, 0.03112677097951453, 0.005056824771717432, 0.0247992409558426, 0.025550256100212856, 0.08516388780046856, 0.04748347020077129, 0.030039803297709555, 0.020839949176015875, 0.09854686161082599, 0.04752835146181526, 0.06595155945227993, 0.02819210073099502, 0.03156601515177998, 0.04673625102206584, 0.09755506886229401, 0.04040720414430384, 0.02315523733775462, 0.02646123997927193, 0.05358335336730365, 0.00814148833254172, 0.010743925400498894, 0.07397020175572365, 0.038031531017153494, 0.04737874598152215, 0.07129338329597827, 0.023654682614329844, 0.03727612618897711, 0.03848234311707559, 0.009031646111379228, 0.043910972383474155, 0.03640936282012732, 0.08968785149796356, 0.014691090966094167, 0.031778987594729954, 0.07491788316157556, 0.049023778072648475, 0.032747351459317633, 0.027098514049524264, 0.07784854485503129, 0.024285820320308692, 0.014149115360792608, 0.021173218490495797, 0.057523619353530876, 0.015427684505289842, 0.04843180661179847, 0.027640182262046203, 0.036960988260445096, 0.08643467444926502, 0.0601592835699839, 0.04861269912291919, 0.026918129071653373, 0.0820729834958911, 0.06052159336245349, 0.05346240340581825, 0.044825168086155776, 0.07792708418902852, 0.022884626354601596, 0.02149688489284487, 0.00391852704436338, 0.15102228330027673, 0.022576547926291827, 0.05032431574598436, 0.03245475566795757, 0.07355201734049667, 0.022634261160067493, 0.02578513291213782, 0.048209380643862876, 0.01618436774268987, 0.0240818647322275, 0.02331747560791912, 0.046021935319708246, 0.04748281136515641, 0.017762156466262478, 0.012744209699092374, 0.01192849076863739, 0.009238454419368458, 0.04656334880799536, 0.03289523324178111, 0.038286381656484264, 0.017583236631546772, 0.006284268080977904, 0.0808755497658445, 0.01480934621330591, 0.014833918483477208, 0.03053630488143573, 0.05538280963176682, 0.057513277166553085, 0.013455531912885848, 0.029712212609968362, 0.037132794968783855, 0.023788439650689403, 0.03537850724833627, 0.03708955696633747, 0.015990760087245898, 0.050142389016165856, 0.08135348137828612, 0.061275224697085164, 0.03525593701089102, 0.030785712466064482, 0.017785964563729304, 0.029012377884599472, 0.04398301529187349, 0.044592867244876204, 0.0075833497084527015, 0.06081151933739744, 0.10784901528348846, 0.07237702232575224, 0.05954890301631344, 0.014252285379165364, 0.014905101458181538, 0.01690802014162464, 0.04803378180029893, 0.0638160510589519, 0.014386186057010726, 0.005826548262003569, 0.04428955005301584, 0.07532124377546773, 0.06163073928966638, 0.015609338316285323, 0.03115911904211727, 0.014392413394225222, 0.021409121860239296, 0.009275798332847415, 0.029141147688571966, 0.039941955117448684, 0.06728076030530276, 0.06340863017906105, 0.010683949334516881, 0.06346101144088373, 0.03451964224598581, 0.027207629867799343, 0.07578446649976316, 0.08320097901648091, 0.03120505558927694, 0.039323733653873205, 0.09024660538641677, 0.023746343119250193, 0.0560798155774753, 0.011935643157020453, 0.008673782501700185, 0.010388038297664496, 0.034645644557331844, 0.024231127388174498, 0.036941123600568504, 0.0907326115655803, 0.046051988948977766, 0.007671927188282773, 0.028978986027199897, 0.04913482251727293, 0.048870043378443494, 0.09167712902830494, 0.012168241814980585, 0.03829058364874894, 0.043484142666021665, 0.02221854929361613, 0.04442305619558019, 0.04539290052508155, 0.06532845417818715, 0.023048500222484433, 0.02675841697641919, 0.03942009602342883, 0.06739628636428426, 0.035358339983729586, 0.061381730070758256, 0.050620067819592454, 0.036232507592367555, 0.07977981420774614, 0.035860407196225665, 0.0538330827088606, 0.07213590381246421, 0.013079625974980094, 0.05658443386275923, 0.0344144047478274, 0.058668710126151005, 0.019488483892693635, 0.03720886366922529, 0.032537876207742004, 0.041481186635792255, 0.03341390924047559, 0.017066795694371386, 0.03576324809522879, 0.04620254820873661, 0.015573091823757898, 0.04209299594344151, 0.03797756778376718, 0.030797734300816254, 0.019040360761385773, 0.035476708228910164, 0.034568216050824815, 0.04192952427171892, 0.06780263472108111, 0.020116404029390505, 0.057920694216004306, 0.038350143154422124, 0.04358586765104725, 0.03366940339366275, 0.0304259269333054, 0.12355652968249015, 0.01202642840648731, 0.01705710276690943, 0.015192787583556869, 0.03341773968009699, 0.04176598748252277, 0.08664665863879266, 0.05467246226485699, 0.028176007138925697, 0.03259703734769456, 0.05002516607243208, 0.0663502699124717, 0.014910403744227465, 0.08759242482483388, 0.013783271987772277, 0.04664125994989469, 0.016965976608316266, 0.07729947431794099, 0.04231019719173351, 0.05248706622589981, 0.05156134089995777, 0.09735807701344452, 0.05317141256865956, 0.0379511185981814, 0.02910619875746629, 0.04366699636222855, 0.028513765728641904, 0.05073015465431156, 0.07163053859145412, 0.07204363618286387, 0.01732478537897189, 0.02831799579003165, 0.054022953770453894, 0.024901488795876506, 0.15277743670007876, 0.24817151708468316, 0.07427476001002135, 0.07225627154712716, 0.29896314646447864, 0.15992561926043805, 0.2877370472396574, 0.12214513525607125, 0.1545140507721132, 0.18464176074391414, 0.15980333630596438, 0.10276651220215906, 0.09780331199327785, 0.16319131418581934, 0.1084420286239155, 0.13694719501560734, 0.19836994909471084, 0.1284224290641085, 0.18598770061808248, 0.23923727713765638, 0.06975457312599306, 0.10249799838469875, 0.1307248756770165, 0.1651947260383637, 0.12375048016228023, 0.08756206476039465, 0.15486321832624175, 0.09075233066875128, 0.09972084538951036, 0.24262278821439515, 0.12090872297243727, 0.13888850778100953, 0.17272091170232143, 0.2005622169423488, 0.19651912663492466, 0.13483000378454887, 0.14750054646884242, 0.1360243655020191, 0.21372768306924453, 0.18779295616813246, 0.10008328158648745, 0.12907780196157195, 0.13130897175400488, 0.10019755126127314, 0.13398110175565367, 0.13656586709041751, 0.15283443364164523, 0.1017257587743863, 0.1262439737817453, 0.17073001772645982, 0.1584251594519423, 0.2504350464310377, 0.14731889170023704, 0.09720272204327969, 0.09392156746358642, 0.1018613103717085, 0.08328043765598729, 0.1570904351049854, 0.16593205502196667, 0.17795382848670407, 0.16615544626068685, 0.2129716615402891, 0.1317373068342286, 0.14099577051256934, 0.12075955033182137, 0.07751045493228782, 0.10690550139594464, 0.1429242283226021, 0.173652995558035, 0.07646824593745893, 0.12119514026468801, 0.20823883163111828, 0.12291304646961151, 0.1819349729245709, 0.1456602347353774, 0.16318011398036636, 0.16822092655685641, 0.2365518478496421, 0.14923002060142257, 0.1808363875193942, 0.12036212689934239, 0.09425311499545652, 0.13621605602243256, 0.16444432759477248, 0.10779054745310739, 0.11451382700714374, 0.11928759665498812, 0.12885798069257892, 0.21608017054536652, 0.15083666019622358, 0.22839138734965558, 0.13831208790502242, 0.23529212351047227, 0.11445150575450352, 0.19376835004696924, 0.1245925410260116, 0.1958913175809768, 0.10893518240341257, 0.16066549165594965, 0.11834008378847954, 0.199167768380815, 0.09991518657414183, 0.20571549122612323, 0.13942412581414948, 0.17347224477318027, 0.0969841801411202, 0.11899459100658856, 0.11438887040581434, 0.19796193066623904, 0.18972533634833752, 0.06829389626340521, 0.22580208677438, 0.1209005334925267, 0.1253553424330969, 0.1059630447097363, 0.10682295542210342, 0.1953665320310862, 0.13585173524916172, 0.2347711224349276, 0.07205790840089321, 0.14060301255554924, 0.09859474210609352, 0.04760258155123842, 0.09723328895145848, 0.11125545588231857, 0.19205350819374287, 0.20496687010651637, 0.13002831789274372, 0.11589804063400916, 0.2098147817436726, 0.12284727782131204, 0.1729809525873392, 0.10953924273170772, 0.17970070813692388, 0.12639643293955635, 0.21601070169239275, 0.23756922793484506, 0.10503158138524141, 0.17968212284388083, 0.15637345341665132, 0.13751233807734906, 0.1590335405161304, 0.2365215260895991, 0.2600471669387433, 0.1972654494907587, 0.24054555612946713, 0.10316336872957407, 0.16947597775968815, 0.20318548585618698, 0.09307075787575976, 0.10167098348780025, 0.16027204421979768, 0.23201996280301004, 0.17305402205355708, 0.2655814473907794, 0.21799194296040844, 0.12505726528263864, 0.1159323920165339, 0.10676807288320796, 0.1412540340736028, 0.14364240510809806, 0.13459054002117726, 0.08466429122152828, 0.14791800310054135, 0.09982440515511459, 0.16881741793645968, 0.14212938145764414, 0.14148723123775375, 0.17797558538375363, 0.12006493841087627, 0.2045973705788774, 0.13924933519334565, 0.10785787125989314, 0.15906596135708595, 0.12323957612557758, 0.11393557618101759], [0.014107906533735655, 0.05123843100943393, 0.05200689763671929, 0.01059455932268212, 0.040788811691586054, 0.0516540720127523, 0.054970095084319194, 0.07849924461615664, 0.06359164475373204, 0.030690154488829356, 0.016340818218586427, 0.029449810258924004, 0.018098356067052773, 0.14338902918802154, 0.02496024965488863, 0.07097498183288882, 0.039797126195363464, 0.047561936756415714, 0.04357793864103095, 0.02985547296702862, 0.047738600462194414, 0.011933543118498018, 0.06620412331915672, 0.01418912526024806, 0.06251583897298382, 0.02176480882260348, 0.03552519393363788, 0.012073994805705885, 0.051636394533899524, 0.018822127209615805, 0.01565326292503385, 0.046668785489014084, 0.006368438640023552, 0.05889990397037999, 0.05547352210288087, 0.09940478815546921, 0.026450026367280274, 0.008085648183740916, 0.0551070639443013, 0.04865312175224385, 0.06252416634872075, 0.040360637489826455, 0.05865862840906747, 0.04290963800984525, 0.007208591944823463, 0.00499432731885463, 0.025528910975422592, 0.03675832736095594, 0.049511684149864225, 0.06446598473215295, 0.03888933115728921, 0.03489558074262834, 0.059110375136257186, 0.04109122489969577, 0.04840885844802664, 0.0223981969118599, 0.06167693056106087, 0.040769939115571405, 0.04397080768080008, 0.0075400355760188355, 0.060083942653070536, 0.06661695277979297, 0.012822799786414592, 0.011627023679114157, 0.05894267465919257, 0.01707000560277412, 0.05892033936576017, 0.06592525965383937, 0.0563773756185847, 0.019318496643175042, 0.04532181139614794, 0.05036183873251562, 0.0869552311938136, 0.09279144987944635, 0.058335530827002186, 0.07274855198639055, 0.0668729410596913, 0.030911253209436135, 0.029854038467390404, 0.024795586716443784, 0.0444722198881209, 0.022455797147666736, 0.004748503589296653, 0.059926787376283645, 0.029777747601450934, 0.030362167350587346, 0.045961981278754054, 0.07759100141664667, 0.07897255671841484, 0.01294114887939706, 0.05551825780721922, 0.05199488154762695, 0.030877842199838454, 0.014692761037769097, 0.022513200115833073, 0.03859923664300192, 0.017363467073488622, 0.014558138322055101, 0.018352247181258375, 0.018647641108761874, 0.06605915650124512, 0.032337371845759695, 0.03921696397986624, 0.04786703510270004, 0.004288026811404815, 0.0084200915279648, 0.025462410713155425, 0.03748781543465392, 0.024056013095222657, 0.01055152529114557, 0.02294033052279584, 0.03800495925749983, 0.0317794434170449, 0.05037072535243727, 0.052838252421708844, 0.06767557137795994, 0.027589810065804955, 0.06556152876827025, 0.0405524505843078, 0.02313021690614762, 0.04384820296939823, 0.05305911940071852, 0.0632210420594821, 0.049031255090789455, 0.02679752959539333, 0.034585487503077716, 0.019873873999101982, 0.07065776014520277, 0.07419607511931851, 0.04991014563148061, 0.04580095725794954, 0.012699704778741204, 0.025792309240768516, 0.07622704315449923, 0.04913599463179708, 0.052048450245732264, 0.07391602401771853, 0.024085310212666952, 0.013771264517169087, 0.08646809120452212, 0.03964498113360136, 0.042304719663074905, 0.049541726287814884, 0.017712477579592698, 0.020993754733353857, 0.02886061012114008, 0.04294824884122899, 0.042780069559211695, 0.09229032112465752, 0.034178832711111155, 0.051547746669741414, 0.01488412788603455, 0.05585385028332953, 0.012418963240399476, 0.062049797045127045, 0.08033190313125811, 0.031505007739929904, 0.026211349759250883, 0.040754218991365165, 0.07831916798867526, 0.016088327130062446, 0.012453281106577526, 0.06392288585043242, 0.037135108554315184, 0.02174473731898733, 0.031573746894155784, 0.012913923072178039, 0.028297985573449445, 0.037117220401283235, 0.036234671790753646, 0.05911656512668537, 0.026129887799822518, 0.07451299037183486, 0.04268271893623375, 0.031036847578962485, 0.11592103859349606, 0.06302444091547402, 0.017704039121106747, 0.0351467426686037, 0.03773605856563776, 0.049841592253576365, 0.01947461961648397, 0.020288017300528385, 0.03724003578686426, 0.08391787643514334, 0.04010879374559849, 0.02888273857083292, 0.0223089610752199, 0.013337879002304568, 0.050960674341167175, 0.05660280848162309, 0.043265060671875556, 0.10183975265751924, 0.06306721160428659, 0.03993958407532304, 0.0063865934874141415, 0.04453515401110054, 0.011145651374282617, 0.0125623959672427, 0.09351883504179218, 0.05241964665812351, 0.0438125454069626, 0.03320944037348513, 0.034337746159684275, 0.024523903210196766, 0.06562663858095485, 0.012950566015206279, 0.057609329270499374, 0.025562580539694717, 0.030380978639568054, 0.03595390822738409, 0.04759892348139998, 0.03066604187141263, 0.008694644991098153, 0.08082768459233546, 0.025222108083506747, 0.019107443250475392, 0.04186372114946285, 0.06798591359608597, 0.0072748006148744505, 0.03918074334280626, 0.01672035349803346, 0.06674475922820068, 0.03455755593735845, 0.048883009416561936, 0.05171545863812489, 0.061024698624086965, 0.0177914401771681, 0.05751688927111607, 0.07566095780461066, 0.03017947644806437, 0.016108268398731466, 0.06129539962257109, 0.033527340048984174, 0.06794499684005015, 0.05581454614237432, 0.051740379478301735, 0.0244605170953418, 0.02833594139965792, 0.048594190438668576, 0.03779377946029267, 0.01969170595158733, 0.027564883479968678, 0.05957903708481501, 0.04557409947137198, 0.03990459683982115, 0.00700748524621069, 0.0030332408665168674, 0.03889593483519651, 0.07112344967261439, 0.022715523936635545, 0.019070165412079905, 0.020000402995895956, 0.03780699064654689, 0.02032555752403794, 0.05655401634172567, 0.0607432532424648, 0.02314425929779968, 0.0641514481826415, 0.01122822128837147, 0.030617460405694383, 0.012153621984555597, 0.07541973203901323, 0.11666975930453309, 0.08296447235249704, 0.002252235055728365, 0.010497625260013006, 0.029882199859486955, 0.028098770154399738, 0.015896041933897764, 0.014223883626982571, 0.035760471026503274, 0.02288941823456797, 0.07826196420336924, 0.05683412489991996, 0.05626009904869622, 0.02257707844217939, 0.05582583827837821, 0.01957865627182107, 0.03098853998967717, 0.0475209855264233, 0.024719029634950623, 0.07956465841421197, 0.07581082758523765, 0.05506524320451483, 0.029594972429256287, 0.0645691691146743, 0.04881699562012669, 0.03497116297723786, 0.013604849152597449, 0.015970494188818962, 0.06285733798699034, 0.019014332924158345, 0.031217694124807755, 0.09251532114801869, 0.01647341271652089, 0.029186636074295932, 0.029163971363056092, 0.04543151135646528, 0.007179569182617049, 0.03800112881787843, 0.012018928405708604, 0.020086522769903945, 0.021521196693121906, 0.01069008952922999, 0.017538290253029238, 0.01513579926047955, 0.0366573071768207, 0.03797755246200869, 0.008783610781744845, 0.014373056267598465, 0.03384779845815032, 0.12522283220483413, 0.043470598231520385, 0.011998626118105267, 0.03463362080736026, 0.022338041772825584, 0.04811040591448546, 0.02172968752171484, 0.06153713483663817, 0.007659221620058582, 0.09384117419681243, 0.019505684481813543, 0.013344652177165113, 0.03037607950729228, 0.018065552182135083, 0.019490661497618404, 0.023049183955956853, 0.020472142702689575, 0.03712490426316377, 0.05503394468236835, 0.05833390672060271, 0.08020589698947246, 0.017859415158689503, 0.04854544043360699, 0.066981059048445, 0.03339286097475598, 0.024284713323258107, 0.008035129473184147, 0.020696079779055812, 0.10991929129006402, 0.015039925271975658, 0.025073176760587002, 0.028943230788553917, 0.06667711366448673, 0.031049815532300743, 0.025649186779534625, 0.011177541699350603, 0.040229774350600864, 0.03150095321959065, 0.04424754162168792, 0.10509442357767014, 0.131664467194388, 0.15022046503520783, 0.1713490933780709, 0.18991875822745985, 0.13194565210611592, 0.12075255594907269, 0.1531705930228195, 0.21494153406350844, 0.22426226536833474, 0.11043623976048925, 0.1470383809458825, 0.1240774388274839, 0.10987812172501318, 0.2145013399422169, 0.17555854733913176, 0.21802557422028435, 0.18208006997742962, 0.14161412604153156, 0.20170803932893663, 0.06813743046575016, 0.18943626073098954, 0.13032862435906165, 0.1246962923135969, 0.16977462947608965, 0.14400383006901513, 0.1379735536512829, 0.1405215008004058, 0.09956861605807658, 0.17053366939146675, 0.1113851086026238, 0.06923297450186745, 0.17128938448525247, 0.1349093858152628, 0.21775641688896766, 0.13060101458141882, 0.25741773867799395, 0.09306209342133615, 0.1055517474249486, 0.23651080085865914, 0.15500149719657438, 0.10604784298207491, 0.16349577284868688, 0.12947345573094585, 0.12832354243484237, 0.09678958614747371, 0.09029476167333704, 0.23339936539771097, 0.1099667887413694, 0.09532426679206472, 0.10612789150928298, 0.11139002688709768, 0.2280245538079931, 0.17782932387725, 0.17036808714751275, 0.1303722147619532, 0.09177903404399272, 0.12947290414764037, 0.13199232218246307, 0.2139228669505927, 0.1492260522659748, 0.12614510247423766, 0.13689364546970015, 0.12410098070939704, 0.17864318504448862, 0.13167971234408118, 0.08305607348560326, 0.20465205393491254, 0.16613759641205111, 0.17608078947711378, 0.1457661693735469, 0.09828122062308174, 0.22055024761826764, 0.23282165849401107, 0.17174255613598133, 0.1330802130002168, 0.17993842521982809, 0.17027719847617612, 0.1394474148870476, 0.1136793427529835, 0.11340433250992529, 0.10823986568157712, 0.11671424603029606, 0.19075172562753, 0.1996893670049406, 0.09949938469235936, 0.054221366712402914, 0.11627141656654498, 0.17530474240981764, 0.2961382432089698, 0.08609516726386163, 0.12308987488429393, 0.13153291457603056, 0.12307810011289774, 0.0728860111426442, 0.17347633568269594, 0.1497522320958876, 0.07186135322216057, 0.14018531077571456, 0.116218694395596, 0.0952875022325785, 0.14379531625778447, 0.2724949925416901, 0.12068497933327191, 0.09565229031948314, 0.11282906942670384, 0.07781347334985772, 0.170112305711354, 0.15358000573131347, 0.16401976166713625, 0.0653785027022804, 0.15063891758120831, 0.17390281683014286, 0.1208779262378812, 0.12593171634380856, 0.1119472102953061, 0.2707500587547979, 0.11358447042444061, 0.20372329490079036, 0.22936923729796566, 0.15200993917401762, 0.10222760765182395, 0.1573001593351364, 0.1269391449468751, 0.213951304134342, 0.12177463981413073, 0.09718100345062633, 0.08181347121154109, 0.226563899928043, 0.1286753912967059, 0.14968441799283028, 0.08509877798778397, 0.1438881201489318, 0.16462017541691182, 0.142796031169353, 0.12176782163160464, 0.1049932616672689, 0.2191419941523383, 0.10005613143045096, 0.036252939157308116, 0.1233979341604056, 0.10819155617707199, 0.11431707264555079, 0.13796727173030376, 0.24741066920180477, 0.12148046971208627, 0.15655284056500082, 0.1326322967126485, 0.09393774724054722, 0.15809951079708917, 0.15238166035663697, 0.15034766627415536, 0.12201045699898275, 0.11721706783939755, 0.08409675030458359, 0.1853487679674741, 0.1106452745115084, 0.19980259480014925, 0.09867001790553333, 0.16571080882943448, 0.15585213058417843, 0.11502964932832027, 0.10224013318938595, 0.2562893677743212, 0.1153648894039854, 0.1636112682641514, 0.11546046653341864, 0.12367653735582868, 0.1962830489801784, 0.12116032156852946, 0.20815686022322025, 0.15504144102094636, 0.15557013361925082, 0.15563888234957574, 0.13140013621699426, 0.08435095359961833, 0.23727823709768636], [0.0083827399536066, 0.037822189830964616, 0.03556237218060321, 0.01765107563246162, 0.042154715817061164, 0.026734206682792114, 0.00635146979250074, 0.043208377826358044, 0.05644199513499776, 0.010697721680175635, 0.06983121256193808, 0.0373058695526373, 0.03859798791968534, 0.07697524292574776, 0.07668737006644089, 0.012174356154226249, 0.01021212535805159, 0.06764546412253572, 0.03552280756975374, 0.037927791220887054, 0.06483068854938592, 0.05351549329897089, 0.029766463126326283, 0.042723310104901754, 0.021553937375785846, 0.01605272798183104, 0.05276037192332649, 0.056418663927263794, 0.10857528195746484, 0.009594058069670874, 0.06445473856142452, 0.03141561485526543, 0.017873721850675442, 0.0582159789759786, 0.09211618933946857, 0.011888382235361684, 0.0425132219829867, 0.022864235009277062, 0.018510743111912763, 0.051531505605746666, 0.018140255330851483, 0.05547193630087761, 0.07705545999229917, 0.015694390355248847, 0.06222994645096122, 0.02057013109386448, 0.011346302250580443, 0.022277930683846918, 0.11494574737885307, 0.011593177914619448, 0.014595802077242445, 0.03151234303180489, 0.047842187040876, 0.05140419328405012, 0.022488468882417487, 0.037519876214285056, 0.07731622099996575, 0.05105876806943167, 0.08769751676628668, 0.08987188880001346, 0.04269139488197623, 0.04029363543996888, 0.06235575724032618, 0.043317108685451175, 0.05360623641360191, 0.022781809694283915, 0.01419943584609897, 0.022393899158604687, 0.07703060043915626, 0.05803902798722829, 0.004460154319061868, 0.011275390279479327, 0.08591790983994162, 0.009077065549190006, 0.08223056778191559, 0.01973836262139582, 0.02108136263315476, 0.025352546043934363, 0.046885147871028994, 0.007911300936323262, 0.06533783109438035, 0.03512899624183774, 0.026104472832934513, 0.06902642187572296, 0.020071656833733284, 0.04892450073854097, 0.03364036866133252, 0.0355539413829965, 0.035231226844893354, 0.04246451028232132, 0.07590566160938433, 0.020584460768488147, 0.03558527054865995, 0.1149708980454072, 0.07507354456691012, 0.014228348961971221, 0.018459976380390507, 0.04532282263220799, 0.014835786780402547, 0.030755969102404294, 0.0590926785052063, 0.07538531936945454, 0.028011116289323377, 0.04678831052696032, 0.05085434899815629, 0.03534502537560559, 0.03994562084816637, 0.04499137086132842, 0.004835874959450937, 0.10935461554195612, 0.02198567580161316, 0.06755324245821084, 0.04404244839303917, 0.057599255214295084, 0.041524106711750074, 0.04577969831805076, 0.008590463736665346, 0.04355559568671931, 0.07650951509393993, 0.05875659573282446, 0.07909681617973313, 0.03316907137031517, 0.07683873371852022, 0.054366785522189834, 0.06044682318104371, 0.0397552709816204, 0.028237100735667254, 0.03618244757695544, 0.08925843623376663, 0.03912750023206876, 0.010517745601734328, 0.011323060100567679, 0.0395387132471848, 0.028184167890539093, 0.03908174180035149, 0.015678271865321985, 0.05600280075844738, 0.06564903899186081, 0.014846943893409787, 0.027931619345420794, 0.0359788405588798, 0.02976022525540283, 0.08526586176406953, 0.01787133740201112, 0.022658103731490915, 0.02966671081770572, 0.049797795006945256, 0.02591550958553149, 0.048556793856644825, 0.08558008804797165, 0.032736216371338216, 0.05440233583231607, 0.04045912192293233, 0.05332416283988184, 0.08864272370814316, 0.03279574140305481, 0.09807453776199011, 0.03665497826953088, 0.04434089326570111, 0.08425533816578888, 0.0630063267665044, 0.03268470078886997, 0.025157419619180506, 0.05026543805856378, 0.05549327951044806, 0.07299057448342924, 0.02214666726368089, 0.06268556958304779, 0.003025451906949222, 0.014562115275992021, 0.031318919237462745, 0.030275210625522082, 0.03880483165924107, 0.0465230870571348, 0.0567638669763842, 0.048230639583761656, 0.022659007715241566, 0.035373029719677665, 0.04845949685982159, 0.06413852044891927, 0.006276126960367566, 0.03303421691300408, 0.05516585736205021, 0.05895505847048856, 0.0852899092640127, 0.04162598491436051, 0.01620373636063549, 0.003951537294215673, 0.09987926471137232, 0.009633905175442417, 0.015355730654611705, 0.06622162842822653, 0.04762441505708041, 0.03265131850756946, 0.03888117232089562, 0.0650300246272837, 0.00891022787865011, 0.014875500778397246, 0.06506957008593506, 0.01626289750058805, 0.0134200333136945, 0.04910098058321784, 0.03361336789244125, 0.03443314708889492, 0.050838000681852145, 0.038387980237002337, 0.05027126798766756, 0.050475277201903444, 0.022704840840531454, 0.02692664222371194, 0.05981078634278909, 0.018105783289478674, 0.030976698185587605, 0.04098815543036308, 0.07196613872844367, 0.0404593134449134, 0.024834021347604936, 0.046016859987209884, 0.05326618147533267, 0.025025729104996692, 0.05755187650661796, 0.0804508995685366, 0.02359359667846753, 0.04870440367789519, 0.04738800415408708, 0.04177362920956747, 0.03898717207653869, 0.012670198902337542, 0.0401337797032489, 0.04772924652863895, 0.02091322357075349, 0.020414293488307346, 0.026105717725811467, 0.03478927072137594, 0.03221047704198188, 0.047272669617086656, 0.004520386545693562, 0.07065821979795733, 0.022254813980731755, 0.10114780672255064, 0.025518421316519383, 0.03562185890792358, 0.03147855855434412, 0.014220461129180849, 0.036711929245821895, 0.02006146211868092, 0.08420281517770022, 0.025769698155683377, 0.11707788498531427, 0.01810963096607837, 0.07480258692897136, 0.07994599400028106, 0.0506163178192031, 0.027548109984866558, 0.01296008753049518, 0.041832277070610754, 0.11414108692758507, 0.0367630809365261, 0.07800639727182927, 0.02014938028409116, 0.02772637672962681, 0.028136806419840264, 0.031422017435092604, 0.03518636856648711, 0.033958287489029675, 0.05994445336381755, 0.06153584780892538, 0.02801732160151005, 0.054278038066601565, 0.05695000335934663, 0.011235144807987157, 0.08611646450815663, 0.02659133894579305, 0.03904617233802715, 0.08395394385461846, 0.022654767418580673, 0.057237753644585616, 0.08742093604298369, 0.054995655607912815, 0.026396737291267323, 0.02616095266515209, 0.024792673667111707, 0.043669382726112684, 0.04125959953413375, 0.039197444059555574, 0.11011844350685997, 0.015510430619601282, 0.04275265510284132, 0.005370795852579778, 0.03631185897956452, 0.030840778866061763, 0.034589279638302904, 0.012732975977292706, 0.01715931613298674, 0.06380921372422768, 0.026612467650744705, 0.022710486908533403, 0.014103430665038047, 0.03088458760401174, 0.0884703615860593, 0.05986835401985915, 0.03264355420645687, 0.10603452837395091, 0.005944982582267615, 0.020153655054708643, 0.10338888969272376, 0.0163564195991644, 0.05950836547380013, 0.0565064690947052, 0.05214122349336263, 0.030237438660415433, 0.039170994873969786, 0.07744311580374356, 0.03573918144308752, 0.03867235590493487, 0.06811532882913467, 0.04461756208911539, 0.019688308351643143, 0.04927037794503474, 0.02644624572337395, 0.036634033425681056, 0.06624493282288313, 0.041012444248002385, 0.016684266926360228, 0.02204748760578373, 0.01400848651575225, 0.03197963176775844, 0.062396248817564025, 0.042354159147268346, 0.023824035926091097, 0.02507429141851683, 0.04568670290492235, 0.06185902966066234, 0.04032198069316726, 0.011568229303755348, 0.03604963091352294, 0.0374446080757245, 0.030394253028076024, 0.00755632643572866, 0.03427663532596442, 0.03712911008586807, 0.11363467982699794, 0.02086855681432832, 0.09681921076750565, 0.013656101392341718, 0.018251091016516573, 0.04629821343828113, 0.031646326064102115, 0.05428569894584437, 0.04078781194684487, 0.034640350889775066, 0.025409031621811372, 0.11758057655946863, 0.20901204417309455, 0.21686747910514956, 0.14447911101723873, 0.1505468184909513, 0.06302415746294203, 0.12586527353813573, 0.07865019458075685, 0.17272581466503684, 0.12238543405528031, 0.12663739823525952, 0.10936983770901158, 0.20794414825016455, 0.14445514778696722, 0.13923068861326865, 0.1073078431128975, 0.10908240151982154, 0.14956055689723263, 0.11263638299198882, 0.15155589418305507, 0.13812264968310634, 0.16263798419987002, 0.15219851937745849, 0.12100541092936071, 0.12086255085324088, 0.14906482140143074, 0.13916690413269306, 0.08911672528953322, 0.22315709160700922, 0.18571535636100078, 0.16928684597294177, 0.10553731432845516, 0.09644584249584906, 0.15965238634136417, 0.18498691399731945, 0.1446138199178442, 0.2079556702125457, 0.16409004257330972, 0.16311940917324635, 0.13097213821545725, 0.11394970284234132, 0.3155844045742866, 0.15688991925168425, 0.15573259022447372, 0.18246714356205157, 0.19105364087848895, 0.1402475630804416, 0.16743326559662822, 0.21149423033479722, 0.08791849482804538, 0.19564577107948644, 0.13355089742089474, 0.09874183098755537, 0.1567100418070632, 0.12087404983298433, 0.10756167868572859, 0.2583394037379373, 0.20806384182745413, 0.16731663637103575, 0.12100031644466425, 0.12605139459933967, 0.23659212875270078, 0.13546948801846276, 0.15807616043715708, 0.22665389993738747, 0.13107422709224686, 0.1470106792065405, 0.09952762269324834, 0.23349754722608676, 0.16511833175055443, 0.1263297373248685, 0.08635697015110524, 0.338846848256165, 0.20686866805678417, 0.21597449637709126, 0.13326275643081437, 0.10682672457469088, 0.10040988785124595, 0.11787614860241452, 0.08633710549122865, 0.17097251519801157, 0.17704509499092258, 0.15686512864645452, 0.1489300512137913, 0.11278046114790825, 0.15387557777425936, 0.060651835970460415, 0.14765575588230165, 0.0837175291211855, 0.18931639861435662, 0.22421521224802543, 0.17623838908489675, 0.13011448746246676, 0.24460216022787556, 0.1671417691414395, 0.21764737193382558, 0.18925446806655777, 0.12405474730316671, 0.24993191052588726, 0.1471195096570638, 0.21339397516942796, 0.1846149629883228, 0.1363400550138566, 0.07994800881152192, 0.15962139042394777, 0.10082333018222164, 0.14697870269658106, 0.09713443296570932, 0.11634907489942929, 0.2664840521831667, 0.171850957577267, 0.24003598508575272, 0.09657693546145193, 0.13794554547677118, 0.11518876579019333, 0.10487198228797606, 0.06106852268379542, 0.1302490278237289, 0.2233111978538575, 0.09065152115879521, 0.2885121750014444, 0.09282366387666234, 0.16825719315919185, 0.23137683199057657, 0.16845875089207005, 0.09319959088198601, 0.19854368251417914, 0.10055907581362034, 0.16201319353234384, 0.17926226069609966, 0.10954920187472336, 0.14257015780575816, 0.13421793017656575, 0.11027620399310706, 0.11918292606189368, 0.10522916312179259, 0.187446347347671, 0.15026523521350277, 0.152592457109882, 0.1619631986344053, 0.10571542210997113, 0.1968327477093666, 0.1729634857826656, 0.07384915986368734, 0.15587992425407135, 0.1682879132849555, 0.17078834766101453, 0.10452717377413666, 0.16323421510957903, 0.1386469755802424, 0.12799224771198728, 0.1493647754673035, 0.11849089585725339, 0.14062012695977766, 0.12340272987081159, 0.1321101618269759, 0.17883444655566447, 0.12308677988907984, 0.1678410695204812, 0.2519635757010791, 0.11536033884171518, 0.09367458071679839, 0.09208078075560833, 0.1428560771408581, 0.1734706972755732, 0.15982343845309752, 0.14668743606776963, 0.17203086566540504, 0.08228321334407215, 0.07322245397635045, 0.13510832352743996, 0.18895609214180903, 0.09955792913153287, 0.1742376125748119, 0.16354779021874552, 0.11147233537368237], [0.00889583117133307, 0.11071542518273478, 0.044280686415731914, 0.0465194711221322, 0.03223973777024977, 0.04139507835310313, 0.02944639542200152, 0.18059531497138162, 0.019845727928763917, 0.03965133583293327, 0.024432899625671488, 0.015843714298229786, 0.031290072196673964, 0.028356976258838852, 0.036784619498517246, 0.04468386699896186, 0.013875548235861766, 0.03958993771624181, 0.03206426916163295, 0.09724022204717321, 0.07133839096152975, 0.07724671384259578, 0.0371992914006114, 0.06578736382746889, 0.027729125070055167, 0.030126392300571167, 0.020005041658277475, 0.0760696657122143, 0.04732580930595437, 0.046590927973269455, 0.03606955686043348, 0.024178409047665137, 0.03184625586014121, 0.052961293803227526, 0.025029599764234117, 0.020432405722057147, 0.043835133509410006, 0.020838282934780565, 0.04933670200707932, 0.020451680494232044, 0.017293142117259484, 0.0609817517350518, 0.09404501487170497, 0.024146252507043463, 0.061219706305212555, 0.024142358865168308, 0.02875583993661548, 0.013594677420182815, 0.0693251731835546, 0.03878018661071697, 0.13488686283028897, 0.018844190541835084, 0.017649516643535708, 0.01663628683966254, 0.03975779141089128, 0.0401204650951249, 0.04015347199334253, 0.06837824254386848, 0.04794379328227332, 0.04982832361072783, 0.006288830613371947, 0.06341460566487044, 0.015528698943765655, 0.03899574843085101, 0.046999034501852534, 0.017033905624562216, 0.03369049762465781, 0.03219706667286735, 0.03342586404253398, 0.050283862473142725, 0.00756180827363184, 0.02433788365564279, 0.036145575765159824, 0.009397322860276027, 0.043876613340070175, 0.05799297461166017, 0.0679245652751096, 0.03728648369771339, 0.025794302984591455, 0.01556920488515208, 0.044088819695095864, 0.024136936877884214, 0.019147662866500118, 0.002219759391605734, 0.046528756107774474, 0.09712400650905986, 0.08121038381490978, 0.037505707418125485, 0.03490580801641749, 0.07789136150911932, 0.07629327145555327, 0.03683080693947212, 0.023671680190149817, 0.015695461920732935, 0.03943264071318892, 0.04299201927478275, 0.038603101556579915, 0.06463754246191633, 0.026295194252123757, 0.04063234206349139, 0.04186921399987994, 0.015457213364331233, 0.013899351545279066, 0.025016919093867464, 0.01134286730384995, 0.01610029342343971, 0.01139525431133206, 0.03744530904617521, 0.00783551856124353, 0.03829754355754103, 0.06131219610031094, 0.04124604743875323, 0.04528241915508144, 0.03633099202547343, 0.012626622863594564, 0.036523529073043216, 0.13398428868141868, 0.05065949453461555, 0.021295514851508122, 0.06480811959913661, 0.033382645192285704, 0.04820253947869905, 0.06767258363505525, 0.04212197704961704, 0.02587934832028564, 0.07000242555213552, 0.04277671409410335, 0.02439463927951311, 0.009355423596477317, 0.020785980196970127, 0.049222217827674844, 0.008126099541362735, 0.030252381205378525, 0.04024718369868013, 0.05721169516384121, 0.05058082879611081, 0.00936586537488526, 0.0449766198383464, 0.03260462927902418, 0.09200816328126578, 0.022809461637910818, 0.04007216708193864, 0.05416059678780937, 0.021232890994137815, 0.04336937503408521, 0.04550191866714628, 0.033249997068196535, 0.07202249215615374, 0.09433648834425597, 0.025254306758964257, 0.02925191251110406, 0.03766524139791727, 0.019026157491269614, 0.04947765069382806, 0.058790644510619106, 0.024597478294444662, 0.04377422185855047, 0.02853929560871855, 0.019220584860792565, 0.027023899000919154, 0.08919098219203372, 0.04444197856730992, 0.03601983009326843, 0.10321613686579852, 0.036461027789740794, 0.028900697586997866, 0.03420408296909544, 0.03279879809387269, 0.13660381908618635, 0.03842019040377871, 0.043686454995505275, 0.07275160101632919, 0.04253308281242367, 0.056159427434566526, 0.011930273838281151, 0.0025390583745789745, 0.013798974875000217, 0.06858114859149342, 0.06412925078503548, 0.04880486078740609, 0.025559788149210717, 0.014526222141519671, 0.008536745651414799, 0.037809200810208436, 0.05859284826944913, 0.07123700688563048, 0.011001663233694291, 0.034033329631652565, 0.060881386556091814, 0.03987727431400169, 0.0830231853310139, 0.01894548843284288, 0.010688846551572845, 0.01215978420429653, 0.035668835419440464, 0.10648976846207535, 0.07627572038120801, 0.013223722325487724, 0.04322134769491611, 0.07415521198943739, 0.04705300539611809, 0.08227173734696643, 0.0024838538393528475, 0.02153734391134593, 0.040567956203895236, 0.023824093382685416, 0.08062812634893964, 0.0232611681454845, 0.033738025719480175, 0.0851239822804928, 0.07715309023736946, 0.05012286526541557, 0.0336268357181501, 0.011513882068796985, 0.052059064393923174, 0.038719228994581974, 0.04580025628749882, 0.040986362784620256, 0.0514159489032482, 0.10080990832178824, 0.05554729636998908, 0.07461972940232485, 0.032228342212376096, 0.05617466109294084, 0.08015021771913575, 0.02506292650416013, 0.09370572985179963, 0.040999351805376436, 0.029257554748666384, 0.02164952408131813, 0.07548335564112471, 0.07504731371638275, 0.01650419221409867, 0.07701723986575681, 0.04219957409546741, 0.04666480183180782, 0.010338201405360334, 0.021947279474848223, 0.0381578857289447, 0.008070134903274236, 0.015743350076879707, 0.02873089802902072, 0.03638203263342862, 0.035180929342224714, 0.02184171064366256, 0.011824939621522302, 0.025666856597508156, 0.013760339145758941, 0.021674425769296866, 0.07383393003575264, 0.035322226598979004, 0.01823382339470329, 0.023276298381989042, 0.020341518965940324, 0.04490631211909556, 0.03316902923547933, 0.0275858627977751, 0.0683114703203882, 0.07182401409673114, 0.01881326357233188, 0.016794581672236804, 0.012688033429214792, 0.08650212083011867, 0.035291268985958836, 0.0141983317218781, 0.05040958899283602, 0.046135791307014805, 0.04624265291157269, 0.031174959825171582, 0.05306971439671132, 0.022324880382286447, 0.071872346583874, 0.04913479187375596, 0.05667823749864775, 0.04156591596021768, 0.04005622862267398, 0.03310041074010153, 0.01980364097342376, 0.04251543597708787, 0.03253937390963397, 0.036996760736069376, 0.07895655314167661, 0.017833281984372486, 0.07644896350440479, 0.05803293375779064, 0.04559219446814349, 0.06729729248270874, 0.0741311415068565, 0.011939684270821031, 0.047059287317097194, 0.03498127150739874, 0.05212351920143251, 0.058827895535937244, 0.09970746183347318, 0.09352303320361723, 0.07067200938059438, 0.04610990902649299, 0.025377170025040547, 0.06875993819126199, 0.08004511045592447, 0.08354435494590191, 0.009406822350537105, 0.040745274914849194, 0.054845709218493396, 0.023452747583148942, 0.014886347625795153, 0.013542941587436344, 0.02551609623966919, 0.018278769773220824, 0.023469452130337878, 0.02405998909154967, 0.042946042508007064, 0.049436745429111105, 0.04832331707040149, 0.013435473815808374, 0.04473985270446828, 0.027869447479925813, 0.0616725868425302, 0.03546513647081391, 0.04455262847665337, 0.04715621659171678, 0.01277083125446112, 0.07453385094601302, 0.05009422123792672, 0.021819934594414888, 0.056258566872847665, 0.03396981711229009, 0.0256268821296192, 0.020218554193214066, 0.058101418187781695, 0.09697746155002425, 0.039361988254372156, 0.050425822395951524, 0.045821013439807205, 0.04898864528044097, 0.01861965974732753, 0.02512700592858657, 0.09249886557940515, 0.037782016180215344, 0.06286944217619396, 0.03202521399925313, 0.01284242025576532, 0.056874785016501145, 0.0428872567511374, 0.05930229165260831, 0.08346762357940597, 0.028514912945308515, 0.06310167023912072, 0.07581780664622784, 0.06621021371815475, 0.03735318314284086, 0.050416621679980914, 0.11739610258730189, 0.25885452125822345, 0.09970335560219903, 0.10123700233957461, 0.12688954075377795, 0.07110949921151323, 0.18398818049219348, 0.26845332715780507, 0.11912195312400019, 0.21535059437155726, 0.12195028079253052, 0.19280862573894764, 0.11330580594198358, 0.10102936186857762, 0.2641560641988631, 0.144592737178168, 0.11990530867009394, 0.07803601423098196, 0.1277151154053788, 0.26324435828193543, 0.24010444270266643, 0.1491311799374319, 0.14118562242196453, 0.11819419000417956, 0.11543677143392064, 0.1925166389874874, 0.11556054059896739, 0.1862303359854606, 0.17122506374312987, 0.15444571572926738, 0.21071665109165255, 0.20712768238398338, 0.09783921087340963, 0.11786974410736754, 0.13229347134549774, 0.12178575574991204, 0.12719285028475907, 0.09259549991017388, 0.1074021255537387, 0.09422047198900292, 0.11809643718504137, 0.13523330311140708, 0.1521984274469076, 0.2341868884621128, 0.1416071852849376, 0.12405803382036187, 0.09626034962674303, 0.21857424639165404, 0.1297514077516333, 0.14567698141740215, 0.20826322387062735, 0.09804990037434524, 0.173901621732981, 0.15241086362831055, 0.129137372958564, 0.1941032530439477, 0.10380916552798403, 0.2678928265888845, 0.20509186501224197, 0.18411740420326111, 0.09709627412620092, 0.14805140965167554, 0.11033875507212455, 0.14776247193015393, 0.12067902683010026, 0.10026545729488136, 0.08401499340130437, 0.13293908428280585, 0.14437452469381595, 0.2599962374135371, 0.17567111629872553, 0.11181102284500677, 0.11554885775812211, 0.14535588332481925, 0.11396002970756063, 0.2519299291194447, 0.1102743347385718, 0.09322576810635867, 0.1472672114088651, 0.1558571714427202, 0.1632632191983923, 0.09392006593125482, 0.15265077172267824, 0.08615600996680799, 0.06712507591733048, 0.15071030165399277, 0.1478240347557491, 0.1378984617129449, 0.10253953567195324, 0.22966297072989328, 0.17639298562801656, 0.15118642529893309, 0.1306532004908208, 0.10401145870526952, 0.14031678678527956, 0.12709675987641658, 0.09566437152604904, 0.13814359452695618, 0.13974580613355483, 0.142644836056617, 0.14707824816146206, 0.06576118660309622, 0.10600611417283935, 0.14982850380962895, 0.16550851565214897, 0.1974574158028249, 0.08037121110265294, 0.1262014482410685, 0.13873343626337667, 0.13571739407075992, 0.16539459837780845, 0.38091751656705336, 0.1426883958159916, 0.13838148014920373, 0.11016159723963469, 0.0968689758390669, 0.2826629711254951, 0.20651092031790366, 0.15787063436883111, 0.2572748786018741, 0.0823798323530824, 0.14245401887643722, 0.18577097434430354, 0.16656965467958681, 0.15189170116378417, 0.1776382309054175, 0.1422315316214677, 0.1275406158979862, 0.1354826494090019, 0.12876889998874358, 0.1754162694898344, 0.10268672414484525, 0.14559622042842452, 0.10391405828657652, 0.2027258177798602, 0.1078912573716333, 0.10864439074911418, 0.1285446507315482, 0.09428868445778087, 0.15155344270169735, 0.09260138346543235, 0.1268920535221696, 0.18343059105738518, 0.0823396510414539, 0.16817436373281866, 0.1449402653041386, 0.1129263319495705, 0.1768282921083512, 0.2499254907090818, 0.1854833542940117, 0.14875968858118982, 0.17431806712861986, 0.06335878083782812, 0.23917330879597898, 0.1444677422724424, 0.09538349304949084, 0.1260220840753567, 0.12411614925029779, 0.24466723173616395, 0.08605366828100336, 0.19985114945279014, 0.11236961585499587, 0.17127551829382298, 0.1950647087106782, 0.11570790527208198, 0.11783408271449229, 0.09273651371439619, 0.09908348321914674, 0.13787806845240055, 0.15097915255013974, 0.1080346154049039, 0.17513226537454515, 0.20194868286771162, 0.12811600155527555, 0.08678914333182959, 0.10858334886330752], [0.020510548605553566, 0.013316184349898851, 0.0354536987781044, 0.015234399564383973, 0.022538525067389976, 0.034934252861046025, 0.024185390023875143, 0.06536203947278761, 0.0393053513741301, 0.011224616844687733, 0.06713516529529326, 0.03160087981321399, 0.06344989167466279, 0.019007420895861524, 0.02647349738606042, 0.03519522454289179, 0.027122412162322192, 0.06345172262480182, 0.02629424813353727, 0.04467291577208427, 0.05959352763790277, 0.027287230233571706, 0.0356132710622924, 0.027768821831071572, 0.007827831826533281, 0.009454763175228672, 0.04346045139696329, 0.004481063252540245, 0.035718523882209294, 0.07360359037955923, 0.015519504931064384, 0.08081311360001564, 0.041449026264730966, 0.013933442457909546, 0.05321257447283115, 0.024469518628452095, 0.04241395614019806, 0.05395645733862635, 0.06508094649161063, 0.016166366591689088, 0.056763675454403126, 0.04943924670618388, 0.08104785826177367, 0.07227038288669241, 0.011395185363418874, 0.02834905490970179, 0.032103690130996614, 0.04016291019656966, 0.017669772008253683, 0.03406549383315348, 0.05841465238782187, 0.04265654171186109, 0.007382378990446488, 0.02717247600817392, 0.07879742901892432, 0.03746544949770455, 0.054672144338368416, 0.058406573990660335, 0.018232139916489684, 0.049909789400595816, 0.008240879622227963, 0.08496104303987757, 0.035695200335354574, 0.058528052552813487, 0.06048064979334032, 0.05107124381127858, 0.04598065850234801, 0.0578425532477277, 0.061164965492583094, 0.03598698790395453, 0.04722492318720587, 0.019852243506559925, 0.04125073972728945, 0.008410280814484484, 0.01107596705908016, 0.07536170853962822, 0.0869927082150694, 0.038737346973991206, 0.03583151802060104, 0.05089591309848813, 0.017910706660439892, 0.05338030942385236, 0.015826416032899533, 0.014081234225041926, 0.027074730849914977, 0.0885214060244541, 0.06726270361292748, 0.04939257279939709, 0.04171899181880778, 0.057638950060091676, 0.035501077485781525, 0.07966200520675029, 0.033046600724300074, 0.0613898276201179, 0.022066157168498444, 0.04732366042932676, 0.026975060895746274, 0.02937043780430911, 0.01444240350411424, 0.058747490777844386, 0.004999743081674341, 0.07217782414368085, 0.04362045269038889, 0.02868714866288487, 0.06816510156157517, 0.011853298281259354, 0.05259447558332355, 0.03731841041195778, 0.03498134045531193, 0.017876175247252952, 0.023051736943964517, 0.07146799771655953, 0.020837026550584746, 0.014809969617354294, 0.03255554602571553, 0.022841629669851354, 0.014872676786786367, 0.17288568189307568, 0.05204581873371236, 0.018735563104611733, 0.025029498257584153, 0.03781998349774269, 0.026927726238124797, 0.027579303169923446, 0.01363626067271276, 0.03147144159752756, 0.052699785859834765, 0.037502064670045535, 0.047946014937253735, 0.06921471862663185, 0.05762693780143896, 0.005612417589873076, 0.05587010283864314, 0.007546363462273393, 0.016730207303959518, 0.030552201205864552, 0.04260932771308769, 0.047939484037699244, 0.019196717391511606, 0.045224644634271824, 0.06949551283351837, 0.019080519090376554, 0.02007115696136269, 0.0180678638524466, 0.02218646361612745, 0.03565057571376524, 0.08567567283828413, 0.019715816653784246, 0.03219737310803706, 0.04328499427966533, 0.015070190533034265, 0.012912592952019505, 0.014129163558414627, 0.007294246320417452, 0.030120020364260966, 0.03740987364923762, 0.011350433379712125, 0.060078897964089155, 0.008624129470497852, 0.019296973402942383, 0.0660600298414788, 0.05196803782676017, 0.06499017273346264, 0.05411897906132283, 0.05489861142010458, 0.05873174767100042, 0.025566615907835866, 0.038617224387464025, 0.022109822264962622, 0.015298112224216665, 0.01932241901334736, 0.03754765073197984, 0.02402406531356035, 0.01258616192987369, 0.0428841426037252, 0.052821164830557765, 0.061194425403711304, 0.02444427411612724, 0.009743342750645693, 0.04418419764166878, 0.15170131299284198, 0.07239132518729857, 0.027508690930722703, 0.11724386559498888, 0.0782090888148354, 0.03287370234066921, 0.061711530922161, 0.08398837950681487, 0.04255497760529961, 0.02024872082045242, 0.04276069519560664, 0.015822455358331003, 0.11957541588814029, 0.007733785915338705, 0.05289584308141663, 0.0765375385902101, 0.05503805474408212, 0.0056034768649917705, 0.02306534649593936, 0.009822493997372447, 0.0669058368751599, 0.007335501112749861, 0.04366844043796582, 0.0365670696802197, 0.02228992379030153, 0.04307897025418859, 0.02870353528358523, 0.03479895407273885, 0.06592463912262071, 0.03266758255420193, 0.02453637129116443, 0.013352111958327794, 0.019273452588447162, 0.05592904564353728, 0.014078511740081014, 0.029673624761222355, 0.058950837326025775, 0.07312192791892637, 0.02905967615304455, 0.02633264446030221, 0.0990242722834791, 0.042448993171415025, 0.03697759321620388, 0.0905762453593554, 0.06820195039073307, 0.07367082991667333, 0.014971859317513244, 0.023228260838697036, 0.07984101697201691, 0.024701633693410024, 0.041652729043797146, 0.07401787540725163, 0.05394749794035189, 0.02366554765631595, 0.012557708466756008, 0.03456040961487639, 0.021532450524729588, 0.05651227604117125, 0.04827049530802235, 0.020453565070525776, 0.03382094324596467, 0.017865553438182802, 0.05538799604701419, 0.029987462255502903, 0.044308453272547454, 0.04821228028665628, 0.018254350720634385, 0.029542328782319546, 0.023045591003591978, 0.05449124033592882, 0.020129488811137217, 0.03368062275131384, 0.0556229705351495, 0.03639691389135776, 0.054614794996356776, 0.04857037659554232, 0.038504529023362745, 0.03976278630415759, 0.015279443619111854, 0.08913659761028905, 0.023731030936863635, 0.0051030533898982315, 0.013727453863999296, 0.060861751722592505, 0.05812777544281656, 0.050300183976369525, 0.03886884596619395, 0.019189121629742366, 0.033152347670928124, 0.03459479547135773, 0.03090725040003177, 0.0682870397764829, 0.019619008038012732, 0.03524911116748568, 0.03907360977703526, 0.022413782970679384, 0.009298287801474575, 0.015656377072446048, 0.05376400839116785, 0.03949380517306347, 0.010987539445200275, 0.05951978018387191, 0.05521508617206447, 0.012801682572781801, 0.038392890860596975, 0.057679472280846494, 0.028145246793546026, 0.05525146002670931, 0.09393555622908378, 0.04121091847698535, 0.03605730711452423, 0.022750880809560902, 0.1431806073073418, 0.03201577579602599, 0.011392027165951028, 0.03907573567102513, 0.015481900547691172, 0.07557450478235561, 0.03253446328603933, 0.02470319651277556, 0.0452986448973177, 0.013021384140536671, 0.021605012457697623, 0.06294932216405869, 0.07951975034009065, 0.06961754297897702, 0.062190738070996544, 0.06398930567346754, 0.08008229636376904, 0.08001990616321564, 0.049736894847404574, 0.03201620480526359, 0.02172809980449177, 0.03588974453328598, 0.040905823961140654, 0.09471230043639099, 0.022654252224451592, 0.053288221824914224, 0.07587702524277472, 0.05408832022259313, 0.019287805245708556, 0.03365690083873849, 0.13116461014555347, 0.05186365068619771, 0.028549547780365236, 0.007628974553588177, 0.03881916133386474, 0.04532934587088324, 0.04855589753377342, 0.005282935622568813, 0.03841089392681757, 0.06757702182738051, 0.03130697592672321, 0.036562978770704045, 0.04601016054831205, 0.030541104422281348, 0.05489578838610361, 0.08169806772662748, 0.04062126443210629, 0.023262049146597425, 0.02304822060039207, 0.02599007866886114, 0.06925602608750905, 0.019621683600088282, 0.05659001098284799, 0.013594955127055367, 0.009060608065356652, 0.055027394630615754, 0.030474389655395385, 0.024587099718290473, 0.05200718108925128, 0.08030839189286194, 0.11591286443534399, 0.12150153713000399, 0.13584641859896723, 0.08144798598462537, 0.17823305221334582, 0.1684657376139395, 0.15055674699045, 0.3606096901480229, 0.18512916120309986, 0.21674986928701404, 0.295642921400647, 0.2591518553033952, 0.19760677230454263, 0.10174002333153641, 0.13967031582949624, 0.15220812612002896, 0.16534605904692606, 0.1399446212716641, 0.17187766340230742, 0.13330944182892002, 0.12590764586122768, 0.15338033257472902, 0.13256388506101024, 0.13886998377500043, 0.2828754532721735, 0.08801513681969336, 0.29490551580825164, 0.13747086207712853, 0.13011537612445895, 0.17344967582293097, 0.14171891154781466, 0.14161533646045193, 0.12565256156508, 0.1056177152561084, 0.1561221918992458, 0.16638363320981303, 0.10920879836644858, 0.14637022970184205, 0.16855610534548762, 0.15496297829574154, 0.1734216523266608, 0.14833884584086557, 0.22901392571868437, 0.11292991724105612, 0.13216821596987788, 0.17078356727236704, 0.14450301296047627, 0.22680511037188195, 0.26065136516286486, 0.16669688656205134, 0.11798929978883076, 0.2693131536005005, 0.1167097797376975, 0.12353653478766642, 0.2073619061059529, 0.1337351109231672, 0.1494321758828817, 0.14588768624009626, 0.13011267949496547, 0.18814826774741375, 0.09332369712571945, 0.24921741096242783, 0.09905036523818009, 0.11274042539298536, 0.0976700050335738, 0.13820184785271847, 0.12745983958725007, 0.11488642919087604, 0.15237819763921923, 0.10080571015996319, 0.09601272702697786, 0.11739552802135868, 0.10829932942625978, 0.1022787670034074, 0.06660458812069509, 0.2023830700425371, 0.10436837140831257, 0.1598673352911588, 0.1740872754805511, 0.1553733562750201, 0.12481309773941195, 0.1392034005614058, 0.20350011816668898, 0.156223131644149, 0.10265323844167495, 0.13762594891651986, 0.14870981625731916, 0.17858885408889863, 0.1512853272499577, 0.11550863048121815, 0.14880560789137118, 0.21498230526283865, 0.13318579523794113, 0.1292137366028563, 0.20278935711230003, 0.15486821321950806, 0.13720008063941233, 0.10886425032250344, 0.08716856369808798, 0.15459355537689504, 0.11018119376873779, 0.1536000925566881, 0.16656537990896933, 0.12226170319462977, 0.18084869089145816, 0.12472013296980052, 0.17626904792362647, 0.14699134314733167, 0.08369715118239965, 0.11419132697365939, 0.09999336584681466, 0.13863841071724892, 0.21131468996886285, 0.1424853518725403, 0.2614057779071793, 0.10904757516278375, 0.31917836817522205, 0.2853169141998214, 0.21484791811916137, 0.10530180357877286, 0.11719105149348898, 0.19191997906854077, 0.17575445134312878, 0.12361741835071195, 0.12362269669651024, 0.09026804052653814, 0.1620899095770813, 0.1146870471477028, 0.18176767464366653, 0.22645638714874947, 0.1541340558399116, 0.14831233919868547, 0.212015108836274, 0.11922381983529176, 0.0997280466159986, 0.17624873127187454, 0.1521879780076204, 0.15713207964454928, 0.08704898503398703, 0.16325702920796412, 0.13395952871970593, 0.11939695570617916, 0.1409889063647678, 0.1417943405648393, 0.07353668792113181, 0.10074329697677206, 0.24958291151110204, 0.13119146918817876, 0.1734422907353409, 0.14148966739735297, 0.14247189936858995, 0.0623390986584127, 0.1554686576128006, 0.2041226412139593, 0.06978633513133373, 0.09752987989134367, 0.1168830611652905, 0.1741883531212807, 0.12537938227216083, 0.1775843442808236, 0.12964190314373664, 0.16823634024589293, 0.17976289915461696, 0.15288850412734095, 0.2079264362973552, 0.1228355643369498, 0.25548080793551864, 0.1291441758193316, 0.18042843037795636, 0.14073375312070693, 0.08182138489979891, 0.1543126156133029, 0.0938483294580252, 0.1273722374331086, 0.14202557654390413, 0.17134170829048082], [0.0580467080186692, 0.062408379819845004, 0.04704254063507242, 0.0749165271859496, 0.06648152375653868, 0.005504438933360601, 0.03512470231902215, 0.02845467162138272, 0.02075509727752257, 0.04591197871993627, 0.05491545386311989, 0.0846602309555296, 0.02168528123518392, 0.04661869866052463, 0.04350797183090641, 0.03467261468270614, 0.05845099176851012, 0.10748723792212625, 0.03328624068789425, 0.06583328313765026, 0.05144823950925662, 0.020752825826827078, 0.04903374487654336, 0.061742442569905714, 0.044961692615141796, 0.022182165862872236, 0.02629610398153384, 0.01580965977477571, 0.041578380210745725, 0.06106812814851442, 0.019736596788730354, 0.03469880339839766, 0.012577212107698283, 0.035136626477563576, 0.011881519045170036, 0.04844759951435751, 0.01513725961558521, 0.026523752753893216, 0.018617597055591403, 0.03833975500216888, 0.029096021279392224, 0.05417800613588864, 0.03279861040233124, 0.05908625868840083, 0.04648240778835551, 0.08934455983821424, 0.02982551318352982, 0.10676716889945731, 0.031911281403154135, 0.041532372800453056, 0.05015824320575884, 0.07702069492229531, 0.0879555275183051, 0.048264148269569686, 0.04301920390477584, 0.05065018273589592, 0.01581182971882123, 0.06191940888041451, 0.014342514257277212, 0.035221769489468105, 0.030049823727759144, 0.017275627432090622, 0.031020644819363955, 0.04371240622394028, 0.06294292916033058, 0.06611243791637883, 0.04708346122154786, 0.0411196697443243, 0.02360460344671963, 0.03807870288109107, 0.07468834789770265, 0.0434425555830521, 0.10046295476176086, 0.014898487246565282, 0.006716156372755406, 0.05902157788495383, 0.052655249338356726, 0.02846406960499383, 0.06151070480325049, 0.05634418485926525, 0.07956735504370543, 0.05131109061861231, 0.09033252214712482, 0.06643035674407598, 0.05509026363612183, 0.033160023871929414, 0.06164352529712262, 0.04231717242228408, 0.05853051552549005, 0.05077171492420378, 0.08022157114840324, 0.016414199865633444, 0.03936351276934147, 0.06164992979216961, 0.08373946221845766, 0.06527136530606978, 0.019794968858120904, 0.03035017998979217, 0.048053849473475456, 0.02540250072225688, 0.018294608641055324, 0.051823354461380554, 0.029983066826037345, 0.033668549205627174, 0.0736631460547928, 0.020992331725034504, 0.019605980712860342, 0.06424894053188544, 0.10064799563899156, 0.059097926207487626, 0.07948407362545691, 0.019492869746060144, 0.05383475661097516, 0.032508144335400675, 0.06275252183719028, 0.047922128315774665, 0.027193809641645323, 0.09274469553342751, 0.008016951164350876, 0.018881129386324077, 0.07421808482538308, 0.049484511011189995, 0.04599710641008231, 0.07076927956434027, 0.02214907469498294, 0.07588519940092679, 0.07552592714707698, 0.07144873826614312, 0.024522529997592492, 0.03221564813547077, 0.03372585641280298, 0.029537048521301443, 0.028972146777255885, 0.03878968610097805, 0.05891514912007317, 0.043109694210391854, 0.054118435138896595, 0.037933579015155, 0.043270549691853025, 0.06172847295660646, 0.03125055546631977, 0.02157291337367027, 0.041468098023605925, 0.09484559207433656, 0.03326483619128985, 0.03954913204295501, 0.08745593860024407, 0.04716924774730879, 0.06100691389292479, 0.03177948555188074, 0.02222814837530736, 0.06924025233714812, 0.024138279446971514, 0.044905477083258094, 0.05467653019173492, 0.12140938441359228, 0.016198203290602373, 0.041926322024195425, 0.004143714998668481, 0.035567271312878984, 0.03866634977560851, 0.04549757877905523, 0.005138848369355284, 0.06676181234539517, 0.024436038670941226, 0.04278447073433669, 0.10254542688809096, 0.06171684374191588, 0.01208299633881618, 0.05155197164464382, 0.05684833966135498, 0.011410690025396405, 0.025732929765757535, 0.05351797159340593, 0.04779105833280952, 0.06693178427315528, 0.11967260946309376, 0.03758750262580091, 0.015279161124189776, 0.04302576544784731, 0.017755457027364644, 0.037196047018252076, 0.006200636177504015, 0.08707557594583881, 0.048778741019627744, 0.009996063665546959, 0.018331078256690697, 0.038838409292962284, 0.04863663554011334, 0.10327563125399813, 0.045655228182553284, 0.057792918411113565, 0.02850066754035652, 0.08703711833203993, 0.030472462944265817, 0.07676303657072206, 0.07970355015488402, 0.04161352066383247, 0.06343301858813052, 0.04190120200115827, 0.03807210686406301, 0.02054499957950846, 0.007977866794868943, 0.048965026789735404, 0.061778571276414784, 0.04292869061652211, 0.03258503274992108, 0.04346273050853803, 0.006237130212191974, 0.03873637021188775, 0.024830612256341887, 0.03402381098919338, 0.029911202033080404, 0.006694473211668553, 0.06618107173351512, 0.03383681658775576, 0.07386190756674736, 0.046675515571428884, 0.03523953506843217, 0.04569431398845008, 0.035463769003869064, 0.02300899881388872, 0.01043003523767355, 0.020777208490237113, 0.026122895332293648, 0.012461299174315026, 0.05347083803386458, 0.04978945613988946, 0.07401097295505386, 0.10851906642558114, 0.019427512870019963, 0.048205086721047286, 0.0622106678483467, 0.05205105877511444, 0.024898558509566134, 0.053578959853057904, 0.05775862448518315, 0.0026985935513831436, 0.06537426623605913, 0.021976597659710436, 0.02908942526236417, 0.037578420653458566, 0.05786967659068685, 0.04034643805014991, 0.011715143900214425, 0.05395185698064105, 0.07594625660849195, 0.07481726517360057, 0.04836989138575812, 0.0386986518729358, 0.013086694093691486, 0.014055150846439986, 0.025394119720365253, 0.038805218533642834, 0.057860698040214285, 0.017443693716139082, 0.02407468457315718, 0.0711654389517442, 0.032314009994508765, 0.0381080785225476, 0.06385139069489895, 0.023120447369893233, 0.09549872799506111, 0.03528591020092849, 0.0391891626490941, 0.07941350926675143, 0.07356723184667288, 0.04883297621422718, 0.0067184254294261345, 0.05438418337895025, 0.045441374738490393, 0.04177517670717451, 0.01114682253119686, 0.017850218273158518, 0.04597325043212022, 0.01272163500318364, 0.054654949494907935, 0.06484246332078211, 0.04216068364199131, 0.09686123835103166, 0.04941457867502205, 0.04924618105794634, 0.03150720449705278, 0.0784929933386945, 0.057680322638442444, 0.037360889987359126, 0.054294485974335865, 0.02737666716829183, 0.03677910749590205, 0.1060907056014384, 0.08515171466335174, 0.027671260533914454, 0.09606771681818271, 0.06446735602953742, 0.09506368964549997, 0.042000908344503374, 0.03554462192339763, 0.04815758543930227, 0.03410566748390275, 0.03175764821559912, 0.011829428896758587, 0.09113629393640066, 0.0408250974461196, 0.06406784500746478, 0.039157350848038355, 0.041020231531752695, 0.05750176669549077, 0.048040998348545645, 0.04888963224666734, 0.05171745046672802, 0.041191992274816, 0.038448221560928135, 0.03163289845800929, 0.04584327212444717, 0.06298205327062358, 0.05111646981188848, 0.03680823415878319, 0.043707625835292765, 0.03687353166300924, 0.031001417927684325, 0.034549975497347694, 0.0316709136560319, 0.10434790919985502, 0.07847400967993083, 0.05982530370895421, 0.03454947370975729, 0.06418043311925666, 0.07290736967397314, 0.058060627836253376, 0.003638977251548861, 0.03431048875133838, 0.039106298748764305, 0.027046818436393817, 0.06979545923851191, 0.005718580139200053, 0.015641806080126237, 0.026135859455192284, 0.02126380264188253, 0.01468473435154245, 0.04203415272997753, 0.031407760538821744, 0.03351891308181709, 0.05245042041004185, 0.032373542687104594, 0.03286890663026321, 0.055002925782314235, 0.04446041830364735, 0.02120023649636536, 0.006693955623514711, 0.04350771519145177, 0.010267932948115613, 0.025955721540676973, 0.21830482859044306, 0.19988488796497547, 0.10362146632565607, 0.20171586874752276, 0.12351353682817952, 0.06867360008219558, 0.10718143860539121, 0.21464387826140852, 0.17673862917769342, 0.10412621867632675, 0.2414119402847944, 0.16155556324989567, 0.22856144354708735, 0.12328632281071718, 0.13360616300375233, 0.1280937467010752, 0.09045777752274468, 0.24464757392002692, 0.10644873679285088, 0.14756641470857207, 0.13482605077085957, 0.1072262317663239, 0.21929205545494634, 0.17954696961227926, 0.13598152586529333, 0.0780705264919708, 0.10769634928193786, 0.14377185864554298, 0.10311034778433462, 0.12351522988249218, 0.06792148560165398, 0.09230382725476258, 0.13965528518442186, 0.23761926879805906, 0.11339119410202389, 0.13693176600481236, 0.10686625471158374, 0.12384274779188058, 0.1757527046626614, 0.11848341117823318, 0.16032660500176493, 0.1528368085142105, 0.0992240756750107, 0.20137404031570882, 0.08878605875877604, 0.14276391676356717, 0.10172026592396921, 0.18534080065306158, 0.09691451210528614, 0.1311069696901306, 0.14355652665178623, 0.14564132768540614, 0.19336367176184732, 0.17101935381370206, 0.11855206797800719, 0.17840943629703215, 0.14725639424737424, 0.15871126264814409, 0.0699800864282635, 0.16490027248378725, 0.16995168771714936, 0.18426398746669295, 0.10308644584109707, 0.14258422318004793, 0.22617135647564168, 0.11722403157862926, 0.18295321102824905, 0.18967039252240814, 0.10479551905225362, 0.18228171964085874, 0.2110362170083869, 0.13772645965218544, 0.16951196857037085, 0.1713156459792968, 0.05795033798823434, 0.15498173212812794, 0.13617108666127728, 0.11736034926387573, 0.18013020767079246, 0.20361400479751252, 0.16020161009603934, 0.17493073828518393, 0.2679925099495919, 0.12497273514107352, 0.1852552745971949, 0.13696054026724833, 0.21935466016011856, 0.16048808101444476, 0.14163707803574302, 0.14781905518424127, 0.23297982500685802, 0.2244470151321542, 0.17688214808942812, 0.10200037831260313, 0.11756671036803916, 0.23665582130272544, 0.15824889794232386, 0.22112898107978607, 0.14631698659110456, 0.1384231553322846, 0.16398102826168462, 0.17561361373912904, 0.09410654705378318, 0.16391330608917823, 0.16524680469545627, 0.14356005065623792, 0.17290647351934066, 0.17949266930020627, 0.15058899929206218, 0.1599144956637775, 0.16074521076535025, 0.17835741892697352, 0.12604461472120979, 0.12082321989920833, 0.21841820960323657, 0.199313631521598, 0.13509998849082377, 0.14323337544356624, 0.22891972754751483, 0.1367340693550725, 0.1278212262437709, 0.14033066829846752, 0.22905937005435267, 0.16913623308702824, 0.15702386206436544, 0.18039233231496427, 0.13494948285721964, 0.3580517532123674, 0.17071733131043373, 0.08563621931018368, 0.13599240431381812, 0.17002504829677845, 0.18727123496993897, 0.08328829005721115, 0.1655913297567637, 0.11178129097266544, 0.18371130099460004, 0.0927928364985893, 0.1844901672654575, 0.1598672127170909, 0.10226031194531149, 0.11179376288407272, 0.18037854273232723, 0.12522732914094964, 0.14089354373995336, 0.1081982517855302, 0.17834759767978423, 0.18247186266366514, 0.15255566956775804, 0.1024997603869246, 0.11990232092718925, 0.1586837754134209, 0.07300838602766876, 0.11140920972872166, 0.15934711562529688, 0.20226028147003344, 0.21332335718456777, 0.16582979760583372, 0.11878924113848519, 0.12966739854985668, 0.39312328902944443, 0.11241505252978495, 0.0943791977460346, 0.17163947134489016, 0.069117134346837, 0.13177046311959145, 0.14039624542478593, 0.12886990102068072, 0.15009015347928772, 0.1992080033185982, 0.13109728633876772, 0.13898610738256287, 0.1743727351628965, 0.1290316528250133, 0.1598228102609996, 0.10981877289351918], [0.020939209273145087, 0.022032569958678177, 0.04670697114159984, 0.020594848920741392, 0.030249826302151048, 0.04069019319309343, 0.03908971294520363, 0.011017825773676798, 0.018119389011013894, 0.008273044781338784, 0.045112918371394764, 0.07187790838220427, 0.03917823440485424, 0.05701613589941014, 0.06337974866431567, 0.023185739128459847, 0.004070147096494874, 0.020154878880167683, 0.020828835155454375, 0.03186718538223255, 0.03924877195048236, 0.0395854446105659, 0.017256931056298556, 0.04254081647001928, 0.04242434812289092, 0.09908470895982559, 0.04985044822998105, 0.010109075998526909, 0.02044268087634156, 0.014337323053980307, 0.014872189363344543, 0.06772384257806886, 0.11448762680013334, 0.03502960782498121, 0.011339836468499516, 0.08875526968509921, 0.008129982649528933, 0.0657508367552392, 0.02645697669997331, 0.021365060313274304, 0.021004843856057814, 0.01621611251105224, 0.05812174633085247, 0.0650909822434187, 0.06313979077423293, 0.012909921220383577, 0.05811728003825392, 0.026937557061413125, 0.015536618377682904, 0.02547219748638811, 0.02604440579401149, 0.05147590677464201, 0.011245365378506964, 0.021728413900540724, 0.06422693082582086, 0.050387318816877184, 0.02879219080862259, 0.021051552236801194, 0.04120382833324614, 0.015928059621083162, 0.042297338405924464, 0.0782433252841715, 0.06384887026562806, 0.0326421637568743, 0.014038553551560449, 0.024985972972166155, 0.09159140378957795, 0.06912306386737094, 0.03589658569844981, 0.06655666932103134, 0.01042588304112395, 0.06939525490686779, 0.08650333890991826, 0.038617737666373296, 0.010235305263420508, 0.04801535738571998, 0.018689904264324618, 0.040160133127844146, 0.04163405565064281, 0.04502528940417594, 0.06581267537248713, 0.03954018796643904, 0.051404285214601025, 0.05400075254240825, 0.041558304876689954, 0.04382132477457485, 0.07004065333955711, 0.06193522476561128, 0.007859630221050353, 0.050586689368731556, 0.04663608119552655, 0.023274739393063133, 0.06049893248165327, 0.031674456812681696, 0.07005444292219416, 0.037825683191899336, 0.015421842127257298, 0.028871827563571355, 0.04157431228386779, 0.09700482621067956, 0.04680307687170083, 0.01738002031831251, 0.05530292964390209, 0.09896181313501251, 0.02909201655476805, 0.0061513365043567554, 0.02963835215796867, 0.04439458453787431, 0.035306510305212396, 0.04386678060156204, 0.03665038940286444, 0.06083474712326162, 0.018803114822554975, 0.012866597990655612, 0.05818068530530699, 0.0880074146534166, 0.006786937151299489, 0.031933400276747924, 0.020499541837301467, 0.04269729758943281, 0.03115373344400958, 0.07746537831882316, 0.02872852315645545, 0.062434434470149784, 0.05284814644725092, 0.029792307102451884, 0.008584913429653934, 0.034066160329647606, 0.045238407403831525, 0.0631061748361155, 0.033148161000421936, 0.033438186566796035, 0.06712351309796495, 0.02666584482686895, 0.033142997567812284, 0.0046289311496601, 0.023423368111252788, 0.03128501793159352, 0.004232772241061133, 0.027039787664468733, 0.07815770729775391, 0.025909221918892958, 0.13711607143763574, 0.01899344745212265, 0.02724184526971752, 0.05648545530294219, 0.05431209450527545, 0.031385691460943034, 0.06184854574741856, 0.060769181488262075, 0.03641814984861882, 0.062488684986507705, 0.07266704789212636, 0.05738857720467833, 0.02947211873927905, 0.041609257384533846, 0.030428062403394334, 0.04348404690503113, 0.03248698115649243, 0.05543550882007807, 0.02067741596200053, 0.06066822642160039, 0.057136859864957874, 0.05150896729901434, 0.027745666823560194, 0.06254438723948214, 0.031165734211343433, 0.016324805065749154, 0.049625578441567, 0.019891779389112227, 0.02260731593255074, 0.027759249562457688, 0.019539802207521374, 0.04364398308098317, 0.06770753256616092, 0.03875391362535377, 0.04359050631342877, 0.02626116462652722, 0.03589689596405914, 0.007252347056618742, 0.034649900175751217, 0.013921435944916261, 0.041571971885259115, 0.04481980547068581, 0.040156195435913346, 0.05128482912456797, 0.017786100544335864, 0.049123262250495535, 0.09557189705270915, 0.020964335041841673, 0.02807850138314309, 0.02500783712152512, 0.019156239220812436, 0.01204154619406308, 0.041332335752104564, 0.037797230686391556, 0.04718805137541025, 0.04724667625381582, 0.04119302649351378, 0.05664268335808189, 0.04450251483508656, 0.11804150868087046, 0.03170589897631398, 0.05052204303924115, 0.02181942131550562, 0.043836328606571884, 0.0700369991001583, 0.07180319948782844, 0.032293701003636086, 0.011438906958867467, 0.005801382273690956, 0.003714987298383588, 0.04959344871402268, 0.030212592513811205, 0.10240768427930533, 0.08549144401425317, 0.05402802144207301, 0.0413598497999051, 0.04810263395249363, 0.07053759159340013, 0.019690759833000844, 0.0378496770656878, 0.04623642078630867, 0.034506484685886296, 0.031481090474933866, 0.0029533960708161638, 0.10502038117978843, 0.023539882423656604, 0.0367403511078127, 0.017355932598753322, 0.04615986945047494, 0.022251266993642337, 0.05119496318061025, 0.038800541566865104, 0.03812147356990365, 0.026882770283508207, 0.05405667696088072, 0.04080380786270384, 0.049733447451745315, 0.041845032434550025, 0.06623935570279438, 0.047492035063764745, 0.04719581950696246, 0.057144758231457204, 0.029597914206885526, 0.04144439526322869, 0.036865464757166566, 0.07221381495436353, 0.02887186395274776, 0.04451261187392858, 0.02371019334532321, 0.01673059992402071, 0.03529994110126169, 0.06731875826634708, 0.042130614690963304, 0.025887985961631905, 0.022675662466715422, 0.023106472010934548, 0.018674921499745503, 0.05458713539185063, 0.008788207309290526, 0.08069276118711119, 0.05375491875794627, 0.047467236797655785, 0.04522208207016511, 0.025649041222829013, 0.02118258391537013, 0.05686441218600639, 0.04781861451544589, 0.01573667170539979, 0.0747915169584655, 0.010649704246691639, 0.025305305232083606, 0.027486953185871247, 0.046398444551854365, 0.0839175470173359, 0.021519976698102492, 0.04099420369452527, 0.03722682077017042, 0.023503037424938335, 0.03223822474659931, 0.011532218383264639, 0.038338835696659745, 0.03844348330711646, 0.04460823496863727, 0.035577935256784966, 0.04023146740491352, 0.049362821774857665, 0.019617341796777422, 0.03864943838468002, 0.017585655554167686, 0.020018676108109857, 0.05500510913289844, 0.03467270278281743, 0.03541881879491191, 0.04086573841050267, 0.05952114765081675, 0.004498361517870498, 0.001975749734312206, 0.03367339854218787, 0.028654021105819175, 0.0701882325172905, 0.06425298164568602, 0.04219530698572917, 0.028040580030891205, 0.06294648763873885, 0.05853817257429323, 0.058249407222554575, 0.04488372018620853, 0.06334676091829616, 0.029984026351162506, 0.055310935262710824, 0.021552116001745867, 0.04666844457988778, 0.046219057403504855, 0.12175112091485532, 0.026259732042108814, 0.06612984343401848, 0.04957205570873715, 0.04746598807433921, 0.039399940250141006, 0.007155238708946855, 0.01496296695193216, 0.02550751797013706, 0.0348777462157511, 0.0524386877734815, 0.08106944661947989, 0.0578647812888507, 0.04826582983256348, 0.05170341956639483, 0.03910838633835797, 0.02932735493466739, 0.050246868087279226, 0.014528078947126146, 0.02667065394381362, 0.043435193478099765, 0.023681533996075876, 0.06561364572975906, 0.03876056709897615, 0.05181852427701797, 0.01850295391294264, 0.047003029650377656, 0.08426784838159239, 0.04960881643778375, 0.011190664785493527, 0.008782635934861198, 0.11096448036691836, 0.023572268790655562, 0.058284038227171674, 0.03882533600253444, 0.03874834799658387, 0.01696656075035853, 0.11980619221445053, 0.09526217536580178, 0.12692632829590192, 0.07190755598487393, 0.22242677998879265, 0.21030867862845623, 0.16938027805618702, 0.18474539711831078, 0.15832074166786286, 0.10520212021806549, 0.10356071555326063, 0.11901182032400563, 0.1952434523451713, 0.1744299312873233, 0.14367787497899226, 0.10160909890527688, 0.0898286737802048, 0.18343034590924942, 0.1532921711764028, 0.120870410915344, 0.14900722691128332, 0.10641393341845083, 0.1256411621767667, 0.18005120868404068, 0.15425886688453538, 0.22160344997480994, 0.1537745001335298, 0.17583421641780486, 0.16476311210182407, 0.11336477172951545, 0.1459059497762111, 0.21580525223285923, 0.2611572283410257, 0.1868500091856526, 0.16705900100210022, 0.1484981155203235, 0.14045797678972446, 0.13264437025833514, 0.23420729704441565, 0.19579797742828248, 0.14046617393051425, 0.08728422765289584, 0.16752872015199355, 0.1794296049422795, 0.13928360996707795, 0.12184809998518999, 0.1434685184710449, 0.14220032119943252, 0.08117178064440528, 0.08334997545687423, 0.27291673926576493, 0.15854309102700603, 0.16856485406958288, 0.1526556900071521, 0.1538122989117138, 0.13944925349806586, 0.1394160818909445, 0.12462152979306637, 0.11126711574052611, 0.1208053011026594, 0.16692116646276367, 0.3268703199442356, 0.12065643489721323, 0.05199013563293604, 0.1546093367881352, 0.13460304257610153, 0.21151788712989902, 0.13629825725670786, 0.09363375589131348, 0.17916570297412335, 0.0819628430350173, 0.20623177320005434, 0.12978487047216586, 0.1635498433343826, 0.15173030175989674, 0.11050765447679067, 0.09065395731839443, 0.2539391325966966, 0.19518375877411137, 0.11871862315362501, 0.1692353188991547, 0.1747122959744546, 0.09903708127357307, 0.17803955372543107, 0.10492067483644332, 0.13622417655442992, 0.16872047717052122, 0.1516302966422612, 0.18123882882777723, 0.251083662433009, 0.09757432065183118, 0.14192618429660797, 0.12107901665712557, 0.1003715068462395, 0.13264938047335995, 0.13233199024633055, 0.17566226032232085, 0.06737975418687829, 0.13472642869718615, 0.1523179678066123, 0.13746185288313897, 0.1883541308944264, 0.19147322723461738, 0.14074602584925391, 0.19881285516725433, 0.11513834188301718, 0.11227504230074345, 0.188638839810606, 0.16457486897706985, 0.14048492776290064, 0.12490929540006385, 0.17913193381842107, 0.0766194180675572, 0.11011135719356038, 0.15954809113135263, 0.19119342128115316, 0.12603571277952966, 0.15085768164886584, 0.21836047721726282, 0.08768927366022142, 0.10304812612312456, 0.1267161214303586, 0.14913721671027524, 0.147071399335419, 0.11873399087738608, 0.18583517251235826, 0.12921609615366306, 0.11323112003024548, 0.17376737248513008, 0.1845903715659534, 0.15486324896975873, 0.09083247112651026, 0.09347172063444892, 0.09949751543782412, 0.23366538176853813, 0.10123416015337552, 0.09635294667415081, 0.19396862075213464, 0.07285234923925131, 0.23414912032744578, 0.1613473711955932, 0.1680214219396153, 0.15307003632187843, 0.1471921347922856, 0.1155605789033636, 0.1797335733088755, 0.16997076330646393, 0.12697514341843705, 0.10679196716556627, 0.0991806231679455, 0.16736060981788944, 0.1299747683468365, 0.22037335791655127, 0.1467270581352134, 0.26522815828361823, 0.09102272906250532, 0.13972064780612148, 0.08150351203737721, 0.161534970806491, 0.1996935345232487, 0.1325420821986852, 0.11951314060077553, 0.095942308224978, 0.08429438566728946, 0.12287794432092099, 0.12875785300087544, 0.22353610594666776, 0.09795419300996488, 0.15778216653533522, 0.11019440112455238, 0.25714268246966027, 0.08948633206948158, 0.13355615278405528, 0.20377283014597433, 0.152495592952736, 0.09900538821614559], [0.012733472976833584, 0.05695192240959695, 0.014520448711400312, 0.017839510279196887, 0.018567519803201, 0.02311563059206932, 0.062167230663039995, 0.032360745188329494, 0.01549593527846399, 0.032044676462969476, 0.044757499539804076, 0.019144973897885893, 0.023643706489594716, 0.01398193390829669, 0.05024011885266631, 0.03116616130536122, 0.0511954726290799, 0.05033963367403035, 0.06885772165391715, 0.04240974648705414, 0.021781528691550898, 0.03731110193316014, 0.02998691258741723, 0.12855004399053513, 0.11637378123498733, 0.031223460851657777, 0.04427988968429066, 0.03791848708304667, 0.08540820856128009, 0.018947390246114904, 0.02941370261983285, 0.07163579395461468, 0.07066562786818513, 0.022049657549829255, 0.046655482372208956, 0.03766366708723288, 0.02847901598039654, 0.007931116279289729, 0.01132590611720638, 0.04812043783585391, 0.06307682600773631, 0.1050236140708289, 0.03503863617116886, 0.008863749324284013, 0.040582105847856695, 0.08057497516875306, 0.06111064602831199, 0.039325564604012236, 0.027228090161037062, 0.026569143463406834, 0.0692404974852839, 0.048823836785290516, 0.040074970963741505, 0.040130968160566785, 0.02982504203945639, 0.03303725445162385, 0.05137336207553745, 0.03838350628352454, 0.028314873981740207, 0.019562110687876423, 0.017450912179605618, 0.04457258506708088, 0.010369003885575842, 0.07957074115233076, 0.02757786675506542, 0.051213081160019484, 0.07311259696800863, 0.06268019547625896, 0.037604904313000946, 0.03548316251967223, 0.06739909024608713, 0.05904831818395084, 0.04962198931964175, 0.04551501494021185, 0.06938566348605579, 0.014261884460856598, 0.034218876126913295, 0.056050524205690434, 0.011918017389102569, 0.030702000123358546, 0.039683909891473676, 0.07882031972610182, 0.04112096060247671, 0.05651233349776557, 0.049855086892362566, 0.011689995148880108, 0.06141235826597099, 0.08683398245803772, 0.05770564567477954, 0.0356387741292917, 0.06984318651619457, 0.051421874593342506, 0.06803063780910547, 0.07371188456853552, 0.05401992006227375, 0.07298807703679608, 0.0568092193815016, 0.053484505042433746, 0.01468501014319519, 0.010942785546273716, 0.025023082271218303, 0.042831056541012186, 0.028193253693321062, 0.003579995184648602, 0.026564560342399825, 0.06892532125235566, 0.05265100904169583, 0.052257565435983484, 0.03718122704735687, 0.024207058820813417, 0.0851023479575111, 0.0679460080761102, 0.05392454594614045, 0.07256240794254888, 0.024048930612362684, 0.015381319906502483, 0.03082629022819381, 0.06687371480849481, 0.017704966087495128, 0.02959514288381944, 0.019215775743847894, 0.06423943721118473, 0.028482275684514356, 0.014848593855276706, 0.04610669145721101, 0.052074478082959695, 0.0197689812405095, 0.04746293138352133, 0.11151517501040814, 0.06922480800459463, 0.032793837674562974, 0.02226258402750377, 0.033777701413078655, 0.04217662976213521, 0.04812778078860814, 0.010901005983713173, 0.028582374647920652, 0.070304294837819, 0.0025433819833016328, 0.05005204043681583, 0.05244130779418254, 0.049252551079036734, 0.05539892429125406, 0.05451782741734097, 0.017114614902604974, 0.03446091777615009, 0.011831266550166954, 0.0634934744166751, 0.031887969347618283, 0.08438008026249948, 0.09959017377226584, 0.06681479498623841, 0.023898896122831973, 0.04781466533219622, 0.0901936533890905, 0.048266511650816094, 0.03661828648839747, 0.033457771604580265, 0.030421466386366277, 0.015969212906765604, 0.04489689689850615, 0.018689279902666327, 0.028867073988001195, 0.013999316443298614, 0.01896256070223547, 0.06197749366683345, 0.040444401543467276, 0.041191701161404776, 0.047604190335879405, 0.01867772538154837, 0.09579381740261471, 0.022385579443747, 0.031988635216088544, 0.0098615730999999, 0.0354673006692, 0.010499270433830398, 0.006476647601718264, 0.06365092080687323, 0.028930385409283544, 0.038309253211463654, 0.021038488522472403, 0.00836559777869092, 0.04076576010594445, 0.03970722194700953, 0.054457911680783, 0.06618048950669266, 0.015904183533313056, 0.04234062237364631, 0.04182173953121228, 0.015349508105446736, 0.0015469362082395463, 0.04558404329262915, 0.05911016063163838, 0.042084101662640615, 0.02256274302189629, 0.020401072725954077, 0.05060707113795704, 0.05503169238387097, 0.04587335256679405, 0.07689167805496724, 0.05394192465070275, 0.07303617203668242, 0.058547070685533754, 0.020467774086301366, 0.10132473472866321, 0.01692390497473459, 0.07236665715613673, 0.05888994865780396, 0.023346721014428525, 0.026331162080168728, 0.05455404805440096, 0.030115670900070862, 0.017362360076438037, 0.028712142281414523, 0.03698210930451751, 0.07361322010476744, 0.038482680195762266, 0.06539986889448858, 0.029759424693521955, 0.038156782562333735, 0.027157182977985472, 0.036724638644485705, 0.03450029469545811, 0.035215613972996516, 0.06093828390622812, 0.04689900640157923, 0.042076107535150745, 0.030338696331807205, 0.026656923732990702, 0.014667588346187147, 0.01412093864693757, 0.023807589933576605, 0.09375720329943205, 0.015454424804286852, 0.008474396628087327, 0.050366293533795306, 0.05480052152227971, 0.03628723308323853, 0.0095889798643428, 0.129437081876301, 0.012988370539049708, 0.043264715932309634, 0.0864763726149836, 0.016169289217120218, 0.023585907070927566, 0.10230732676122459, 0.014753813457284725, 0.023102905871647022, 0.031822055142613194, 0.025965169320003163, 0.05089000656059192, 0.07680070511395894, 0.049964128017065026, 0.06098872696560237, 0.03649422237949987, 0.07211331187957717, 0.015925950006461673, 0.015838781649607326, 0.03681063201398619, 0.035344155865811536, 0.08573587968825333, 0.030787880494890195, 0.02943229557375514, 0.11125928632193997, 0.03796444086718463, 0.07988623148130794, 0.011404773911401149, 0.0478161285601316, 0.01972353115918175, 0.053664677430905645, 0.03581007905004006, 0.04028354989244573, 0.038114122956270174, 0.02296051310916101, 0.05203774033655083, 0.02592296745147436, 0.0545889203767142, 0.028509665243027192, 0.040529885464498115, 0.026624748040170922, 0.008551285042607737, 0.10745389777566157, 0.026404687368701545, 0.028459381146897233, 0.03305584740554614, 0.06640080107195724, 0.05712556006807474, 0.06672433532413936, 0.02507128069297441, 0.045269912769717556, 0.0819216811308457, 0.01297407438077273, 0.08880362515487979, 0.11572221579450755, 0.018278859788551927, 0.0719155156384072, 0.04309327694617453, 0.06985051797762995, 0.018312502539746704, 0.05787626111639604, 0.04791983388244145, 0.08122576686042933, 0.08238449016766203, 0.014734403662113173, 0.02761862071741733, 0.0592304862314655, 0.018555683744770866, 0.10241928285047894, 0.05873719838658168, 0.029676447795223326, 0.07095630460929486, 0.05333364700838443, 0.0616216151824882, 0.09412490252044894, 0.03176008437519833, 0.03358894883985481, 0.03507450057734405, 0.018215347269189455, 0.019145688274875283, 0.04723218187028843, 0.018817105503272147, 0.025007953949933572, 0.07170404472778882, 0.10730128540026565, 0.08144798598462537, 0.05344378363881862, 0.06607125302956951, 0.07829598616808653, 0.01743929062579428, 0.043670206270631284, 0.036487522940602035, 0.046477566112674056, 0.049761827178900285, 0.03680562562940102, 0.05812274224515404, 0.05540093527205529, 0.06009927973331464, 0.0760678424229545, 0.06941213182383968, 0.05940753298120634, 0.056743044706602255, 0.018343973431676146, 0.003183099634629945, 0.03619748971334869, 0.03594826215938215, 0.07628100638788554, 0.05215437339258291, 0.022226687062591798, 0.023480966431839813, 0.05912961160403587, 0.08711644673659917, 0.011505951143560872, 0.10809787894569098, 0.29403079661630815, 0.08807682988023566, 0.095383592640921, 0.10448882341264717, 0.09924769416571626, 0.19836110844006463, 0.09285989217460157, 0.15695911231300524, 0.18074097892930432, 0.1264988129297572, 0.11003844860580661, 0.19163692490227763, 0.10617992420110012, 0.13212511586325784, 0.1261236520123578, 0.10173161934700706, 0.22480675469963785, 0.16260963894667166, 0.13750460058931382, 0.24956521488005118, 0.10797201836061095, 0.169132249429822, 0.1916307808771249, 0.25048533244238746, 0.10599491396738638, 0.11063981230460829, 0.09659457080546888, 0.132604074033518, 0.06056897973100986, 0.16599741764366627, 0.17186776554632574, 0.10662720463569127, 0.11962634541334645, 0.13798199594020844, 0.13068879293578287, 0.1117517889267014, 0.07490921870715196, 0.12348379729495895, 0.16912783676337811, 0.13685465159435428, 0.17075108514437753, 0.17900240367218373, 0.1695183883871763, 0.1982869358072358, 0.19555667505389263, 0.18520681187510493, 0.1261039482309453, 0.2202831280808295, 0.11474982039221834, 0.08365228907355378, 0.10719247027150086, 0.2541345309826636, 0.08124166318485815, 0.12991582554194236, 0.13016137204343273, 0.0993067978490745, 0.15398255429200589, 0.08173636446196227, 0.10879449035611846, 0.08073721726935718, 0.3210893898240982, 0.102205207240918, 0.18722134732430984, 0.11324898520063971, 0.11480741488236575, 0.22575762303125477, 0.09027390876003812, 0.1306220053905441, 0.2585010789334774, 0.11239751677719817, 0.16584433795463654, 0.16593147279514422, 0.1564362879482008, 0.16405460334593253, 0.15588741659397082, 0.12312697652246683, 0.17167586052129347, 0.14745156280696392, 0.09478226724651553, 0.15439369835920874, 0.11136463107240778, 0.16949169788389437, 0.20583921442589453, 0.14518815603467727, 0.12343342701393752, 0.16838229531722684, 0.2141587147789617, 0.21059804535921545, 0.1832956676521609, 0.16926476731896403, 0.10665403303479958, 0.17864753642389852, 0.14303770126594653, 0.17490332765925318, 0.19307286478579047, 0.11141906161942791, 0.17881146391793606, 0.21412466983160666, 0.15787530750516923, 0.12447708391494329, 0.11784761948811433, 0.10175905295557554, 0.1638673408137214, 0.16930028315513365, 0.23902255801423905, 0.1390140695917991, 0.15567995998407566, 0.14636883542181986, 0.14858644545799302, 0.17579333796616525, 0.22195919056332883, 0.22961777154236074, 0.12004267589579667, 0.11547984089702369, 0.12066021937155917, 0.14005613302992237, 0.22157947142277995, 0.11980590876191856, 0.10102710957008024, 0.14531943286138196, 0.15935672236786735, 0.11344312720241086, 0.09129934809020451, 0.17651444120753199, 0.15545379550706956, 0.2479962208458493, 0.13405150523589504, 0.22605278138672152, 0.22809731683904128, 0.11493781070795753, 0.20841719222164926, 0.1418096929668419, 0.16859781117208544, 0.258144878692204, 0.20381007734085285, 0.08048589446491773, 0.20414916317789786, 0.07762670877479738, 0.09142415913482828, 0.15120283490227115, 0.2321140384001117, 0.11096474083681261, 0.12724223997323744, 0.10397706135746934, 0.10874568289446254, 0.09511673357337715, 0.23244806805685644, 0.1399139777546929, 0.19357690467469155, 0.20442973521928634, 0.2066448171653094, 0.14462528059319144, 0.07296122565505005, 0.1571355883272425, 0.1287137110146784, 0.24829790627043097, 0.07534280148965698, 0.10915311143523264, 0.1471401480657439, 0.1009849900560033, 0.1807148093658109, 0.2356339519422862, 0.12249161384158558, 0.10107322040224269, 0.12443457369602497, 0.12181002541535324, 0.18120528949845224, 0.12918810330090985, 0.19057494317812307, 0.15020416268417913, 0.10413517424416158, 0.23022737834722767, 0.1287651614796731, 0.19992274803019341, 0.06187521709850239], [0.03652858908378309, 0.014079143762618545, 0.048280178659385255, 0.02112296120744319, 0.004969310717687252, 0.03997446022807591, 0.07070800019127708, 0.06363411283781452, 0.006856749786229264, 0.05142568205032618, 0.05011307083130364, 0.024845190909540942, 0.021233616862446073, 0.011640612163671083, 0.02796077856703872, 0.03392444172453496, 0.044666921134076776, 0.07382567926880813, 0.06491223860892557, 0.015238092108179006, 0.0466810658784403, 0.09406098014404697, 0.05351728211427408, 0.048282231775022326, 0.03801430936061567, 0.08311526143863317, 0.060801253759212075, 0.0427787825314989, 0.09409166196541441, 0.0900754230397363, 0.011951183250564481, 0.0769963716306994, 0.030258971476747148, 0.019559546208549893, 0.04552473276553135, 0.009214798581876583, 0.043300120685730255, 0.056243425145024256, 0.03791481752188937, 0.036207854882964206, 0.07680854219342433, 0.05694097118271936, 0.05184997984718892, 0.012459993952014034, 0.05326024046347988, 0.03313763878278194, 0.041557132762165806, 0.06153151175127395, 0.03086379980818639, 0.020652541087099144, 0.021006701619274194, 0.013512634191541903, 0.012845836050297706, 0.03363004562655284, 0.038059328517486016, 0.03197203026032977, 0.02997912338844711, 0.007594002161039821, 0.0557173066021454, 0.04716080545838322, 0.02904856021726324, 0.017323182339990334, 0.05827542739890276, 0.015821981341427854, 0.022559360743710594, 0.022566602189814853, 0.08429103786306036, 0.08427830548175881, 0.02964851239906444, 0.00725106529576043, 0.08382354802902668, 0.06006321231383951, 0.04218324493136137, 0.04181078064345545, 0.022472666403759393, 0.08446812674763703, 0.06029370518761778, 0.02347902439895176, 0.062179319530485146, 0.03564677208722119, 0.06613049460875411, 0.018173020911372958, 0.06946791834648579, 0.013943615147934086, 0.014795576740476876, 0.034694333275359486, 0.033872202188978275, 0.029314668518641306, 0.04581797973162705, 0.006972530569445583, 0.024194795668365496, 0.020527151646092534, 0.07356072776019573, 0.030772083761891535, 0.017124422743255575, 0.036530653690739025, 0.009626217483122264, 0.03265303837495946, 0.15976276428949449, 0.04244522018838794, 0.021300795112526225, 0.015213239258305441, 0.04257114206050192, 0.06961683817808667, 0.06001936910193294, 0.03129778861729128, 0.0406705009029998, 0.03526098169987241, 0.024774592076878876, 0.05466637186585896, 0.027181257291005987, 0.031027397884416486, 0.02779963197216632, 0.051054079611335075, 0.0412939355949, 0.010458258874413949, 0.010352886353258886, 0.035528250624455755, 0.034766989054098245, 0.0347280181613901, 0.021930140172762257, 0.06324594757790047, 0.04680305005862348, 0.009870936609654418, 0.04615511204446516, 0.06320558623560975, 0.011459031131028408, 0.017004116295626568, 0.013991740791337385, 0.14235335492318676, 0.03866160003047797, 0.022808833445812908, 0.029314990275569504, 0.03688106230730492, 0.03184310915399223, 0.029833986115972363, 0.03291100316170243, 0.060907418223758863, 0.020467685986190073, 0.03272291325453309, 0.031008825997912118, 0.014880464070536678, 0.03981418314299757, 0.008188648705160426, 0.0225913621515276, 0.061514037285721114, 0.034647670859891566, 0.06330146213933345, 0.03377769758263904, 0.008688102600224798, 0.029102134661027984, 0.02561960812477816, 0.06272370927035809, 0.005455784210484596, 0.024480737986103184, 0.052444659428851265, 0.025578737334017793, 0.022075039957980477, 0.05204637414745746, 0.018329373711059173, 0.027102281286891912, 0.043395264975486264, 0.016296132309963147, 0.028625758207072655, 0.03631390060388273, 0.07863551633612764, 0.036917750257998705, 0.09062294607921954, 0.08058422184999912, 0.0062316991276137775, 0.050140868331636154, 0.04422414146604077, 0.03841646721646671, 0.024363570583743915, 0.06976529835693299, 0.013834800019169287, 0.05787778563136536, 0.05778456422229929, 0.03071843079411455, 0.02903594083393053, 0.020939230340563005, 0.033691489708519755, 0.04733845358714462, 0.06922078604299216, 0.044624740332965894, 0.04759153839380992, 0.07089969837256978, 0.025802019405208772, 0.005542055765662583, 0.021853326451814464, 0.011125360577998143, 0.03575931423373761, 0.02872837951496965, 0.060906406987698815, 0.011126987557227333, 0.06488671255928856, 0.05246108818438746, 0.013960650070540368, 0.08211252895454246, 0.0493196603812037, 0.04982373857450101, 0.025310217770898057, 0.05140379491832949, 0.028583529525466507, 0.02332075446423504, 0.10482323611335409, 0.03095424031808732, 0.03158245539863504, 0.02864671645746116, 0.036497190970206456, 0.011521321740151655, 0.07040281374488147, 0.017201878062839952, 0.059128106241264654, 0.0733737486805166, 0.048839660331366525, 0.0952333627989696, 0.15118017402147094, 0.050112978900752725, 0.052182044488407915, 0.02534658396466365, 0.045162124198771296, 0.056658434125805096, 0.06969422071931825, 0.01836932902675002, 0.04098526344844892, 0.05905405618250371, 0.009777921086718, 0.05228170869691719, 0.054681938772480336, 0.046554561779503865, 0.03097375832317818, 0.005207559752893905, 0.0362848658715525, 0.09649272707681503, 0.036450505572100805, 0.012279897214724653, 0.06238719748873865, 0.047911188580215945, 0.0398101803335932, 0.013543322716178674, 0.020118380536235148, 0.032855235791254433, 0.01451228891739682, 0.03499336803572313, 0.04246941324503672, 0.02359337068252987, 0.08301202342995713, 0.03996887161666828, 0.0662393786854321, 0.0329427306930865, 0.013079096416702435, 0.10156543189359289, 0.006919422960509697, 0.09397303325033958, 0.06005922482619363, 0.11180410507105051, 0.08290598153947823, 0.038243668424266006, 0.06814169757548841, 0.024911421125814803, 0.0773863869929506, 0.030531677710373076, 0.05157675841943391, 0.04248481161231476, 0.05402947317868952, 0.043939658545798836, 0.024685390714195468, 0.04135732170975497, 0.05534314925992682, 0.03436682302685034, 0.047577162753910794, 0.10297696421583814, 0.03565819828861183, 0.07142711160404068, 0.04610879053812354, 0.032170023769140244, 0.06850064041153078, 0.07391397090208146, 0.03799691533429488, 0.02578988840292779, 0.08195347377970334, 0.026208576520964987, 0.02802000482446484, 0.04044862651836969, 0.06948725440569463, 0.032834248812568766, 0.010551214067926331, 0.0380099120159303, 0.04880162023548638, 0.024873275692845066, 0.04998717577226701, 0.06761442990072312, 0.03793541762617327, 0.0452030562765656, 0.011441140105166744, 0.0292180763227084, 0.03098485510676138, 0.08121811364206576, 0.05933573139050315, 0.022116786004194332, 0.046421446341780886, 0.010117172590276648, 0.03930096935120322, 0.014837893522194317, 0.022734561221553914, 0.03556306165973506, 0.057147351439080896, 0.036652032661462025, 0.037642955900199955, 0.05478180599428954, 0.021501037089394468, 0.05027860327954254, 0.050769577538895036, 0.019418700943670927, 0.025683541992498983, 0.06214983280627959, 0.009538024483669189, 0.05505463671720317, 0.023987925115732417, 0.0034613700606109157, 0.06424457000027742, 0.032367582523053696, 0.026751761587577003, 0.039711305195645946, 0.05520146895921039, 0.03113679907044336, 0.033831151367555705, 0.08540326729416849, 0.022313186050122304, 0.03541125750709926, 0.05657158273782942, 0.04249757080669365, 0.10092368003942313, 0.04933188714447522, 0.04610764140623712, 0.03285961781418131, 0.012059669919131745, 0.03363402162287985, 0.02947394585897846, 0.016018363192767626, 0.05061044958570311, 0.010542434700314077, 0.04690677836357106, 0.056636688720074393, 0.09480050779999265, 0.034842578949587005, 0.038413728452137405, 0.0579056061143356, 0.035815606374413736, 0.047410473512906226, 0.017571917682465528, 0.14396639901303476, 0.14436569936092825, 0.1502681003823396, 0.1257659042734773, 0.14635644011920498, 0.10009806708342607, 0.19433275766430363, 0.22800500324416548, 0.13573303758617372, 0.21322778005513454, 0.1430018483510902, 0.11677029302283642, 0.15319089435281294, 0.24170688413564237, 0.12773342490676912, 0.1602929890636475, 0.21773734129965308, 0.15309619056361337, 0.10187157594989385, 0.17448450739104904, 0.1774022605029806, 0.18921237919599782, 0.1937329567848675, 0.21049229458214777, 0.1541679016044063, 0.11265396470985106, 0.1715943947314255, 0.17135499225508782, 0.10090164735072082, 0.2232393234848015, 0.19023051004736655, 0.14713593458216037, 0.11172506011902325, 0.11412379632313406, 0.14222414653387763, 0.11863338821116956, 0.12998843535540566, 0.11082044051539515, 0.12385410121491841, 0.17249603425302815, 0.227315585399347, 0.2344413675488003, 0.1229517568924254, 0.1350819854246032, 0.16239530286721646, 0.1860926853072259, 0.10960580811144845, 0.18576008057402027, 0.1631898586187632, 0.11165919187929362, 0.11174589771056369, 0.09710166738518784, 0.11714999684162679, 0.10577718411842663, 0.10609333328301869, 0.1295610195806911, 0.07671936189815884, 0.10864713334388311, 0.18639170474583105, 0.13441282294450269, 0.11241245549172164, 0.2327943551203897, 0.202680250870124, 0.10679074142488743, 0.0812586933194149, 0.12486524534441772, 0.10908269263323277, 0.290190551069475, 0.1699923056988947, 0.09831344994205622, 0.19579733391442608, 0.21244850009679797, 0.12961556504089988, 0.09221339057530127, 0.12669658618828944, 0.0955870119674552, 0.12320343209731004, 0.12289112869409785, 0.14809195102462847, 0.15925100223431665, 0.19910485724047308, 0.18374036637044724, 0.1740967749708122, 0.1418054028744659, 0.08303500606768555, 0.16475378115090633, 0.10331136925566582, 0.12114794924855234, 0.09646455802383924, 0.11490793327891058, 0.16868784182494687, 0.11597857179660952, 0.13231112201127315, 0.16763935857001813, 0.16650677418276189, 0.13040040679756673, 0.12759356789531248, 0.11015874739255636, 0.32771341502666473, 0.15926036382875136, 0.11068628319809515, 0.19065821693549234, 0.16917657527712085, 0.16992488996155802, 0.14130793601995514, 0.15360248275101185, 0.1623751394330494, 0.23299854819572743, 0.1382508621581139, 0.14150840590798086, 0.07566910898012501, 0.12029086540062582, 0.07478805424104776, 0.1735500333410117, 0.11864746890721783, 0.1477470735628759, 0.13622811424636072, 0.12578570764631997, 0.1421158063796259, 0.05375880665416199, 0.14586816631978558, 0.14113012701272964, 0.1806105907645918, 0.14947906046384765, 0.2025803989700733, 0.18418549409797116, 0.10723660459681865, 0.13668954432491334, 0.12405284740511449, 0.2915811538696289, 0.1822203253546069, 0.14807854448595356, 0.11282493255191273, 0.1679624331694457, 0.1598647459139747, 0.08378217928111555, 0.19920978064258255, 0.19511157796988565, 0.1082106547490243, 0.21120245808795576, 0.24581064860666954, 0.0911539675848138, 0.16731407763736864, 0.10578748034012896, 0.11544003496847807, 0.10910487853951993, 0.08447013389799865, 0.14085254271424588, 0.09048511920076224, 0.13683995802796659, 0.1445556738443913, 0.11647545642429784, 0.19634652702558428, 0.1220428625181798, 0.1331132007462363, 0.08805291261523963, 0.11213150040637102, 0.2109322129117866, 0.13252734266702207, 0.14422218044919355, 0.05971661881513654, 0.12015229541688197, 0.11546257327521041, 0.12472552622878745, 0.17885808802900777, 0.23126872166270213, 0.10801850457585628, 0.2474218234419823, 0.16960419023469572, 0.19335513754237085, 0.17524514076930864, 0.12191720877683933, 0.19138071445688126, 0.13344343060687666, 0.1918577727290892, 0.09765718072172135], [0.0873615718897312, 0.015377356359104236, 0.03815701238871102, 0.026237233954992507, 0.05822472386963426, 0.02871371467687911, 0.06687323983398176, 0.020398755309983127, 0.04660007123264574, 0.007901279548663766, 0.056432380731548035, 0.026721121901045405, 0.021683109375918587, 0.09585621526404735, 0.02257612657793347, 0.07469422379208189, 0.019764614539341103, 0.0674997771819753, 0.051797973968449144, 0.034781219137291756, 0.03905672136874449, 0.07633744408526728, 0.025621892982012322, 0.045138988343458024, 0.0409850642655886, 0.04193625818457335, 0.07005172331006297, 0.01974597562014336, 0.09750813065517334, 0.016203387790629943, 0.027247230867825212, 0.03956740707038872, 0.048531528276902054, 0.02424957670061098, 0.02945982302809435, 0.01171073123377057, 0.04627118968675214, 0.018190541342201254, 0.03192295083746074, 0.026254794605436827, 0.020411723263321385, 0.016182668942717776, 0.08089470196395152, 0.08210236296778725, 0.038559380918741226, 0.027054734039871443, 0.007836719882869794, 0.12794933912734832, 0.027800066727063352, 0.09194758870909292, 0.04947591933511919, 0.01930871370038198, 0.04648798873888389, 0.03821016739933722, 0.04246372504219894, 0.016153335436097076, 0.03613470880795391, 0.006271461484908697, 0.10286343764633903, 0.06962466759667282, 0.0347185148406894, 0.012887431751756419, 0.00671623585437755, 0.021831042869316957, 0.017385982397583225, 0.059315617752051165, 0.02343533631984986, 0.029638440258079962, 0.03462315221587497, 0.052014508720247016, 0.028605334303011338, 0.05130482018895207, 0.018384087710611282, 0.0744505005798513, 0.026665147686857852, 0.026422713417559866, 0.016804104145135612, 0.061251701967370134, 0.04816047742121643, 0.014685964880270824, 0.008446547416819921, 0.03020938643584809, 0.06051387885705598, 0.016132597435986804, 0.050659195760325085, 0.10501473511178648, 0.045480912536262505, 0.033564376569683516, 0.02245010128394971, 0.010467815821269348, 0.020917437054337035, 0.026579610139672315, 0.027811157764987122, 0.033060945720682224, 0.0375417556854025, 0.055096576200617906, 0.02992795829120423, 0.03785649141777427, 0.005733630415277496, 0.04933490170045726, 0.012099496915095277, 0.07490098326196594, 0.02271239446746486, 0.050700713895381465, 0.032287576130681464, 0.025205922560886513, 0.018886388579924262, 0.1053999241201147, 0.012704717866595716, 0.04200335982586107, 0.003036678686077076, 0.028936671160702265, 0.07177421072077367, 0.023816463146959583, 0.011245270575126334, 0.07044135562835202, 0.024289554998939557, 0.09457053586600289, 0.009362886250469713, 0.017607749529903936, 0.022289207498092326, 0.07222873834712852, 0.05318118018969413, 0.041560308196611946, 0.07152561518934465, 0.04454443133586357, 0.03267540431190883, 0.026182343755217812, 0.05110042410031442, 0.030844260735677618, 0.02187617885459575, 0.008360828881362274, 0.040441881114196394, 0.05861392334824609, 0.05711889127269388, 0.021939417497525295, 0.05696148318689197, 0.03735268135525046, 0.01879436035280026, 0.022867197854324214, 0.009354692940119534, 0.018640637149914138, 0.05027290358538589, 0.06382968359356446, 0.01748588983900845, 0.05211036930221224, 0.03476666729717005, 0.024981895469189174, 0.06797646007110035, 0.014912283532471668, 0.033788399830941236, 0.004184205139491467, 0.03764520436825772, 0.03942579188714585, 0.01988924172286305, 0.06434670484234249, 0.043661852081817006, 0.057793462333539804, 0.06527229227245816, 0.07491259715489804, 0.03478412261052478, 0.01212798102172993, 0.11571538229022296, 0.046606330170987115, 0.04899007403441975, 0.045952692462672154, 0.047112135892553676, 0.046802981110710296, 0.021490380806367726, 0.0065370656046715965, 0.034560696897848, 0.013534332674387242, 0.031193740470635316, 0.0037304395312188015, 0.014331114868963919, 0.03682642491654523, 0.037733584101642334, 0.05440533123610001, 0.03081580823016984, 0.03916643665082032, 0.0885299938700853, 0.04237711880235903, 0.09889636624364123, 0.07619952527625908, 0.016329750163300384, 0.04116608701165646, 0.00300056817415621, 0.018261006109476573, 0.03106791435951187, 0.04992706085284872, 0.03184087026203352, 0.16313014972594478, 0.0611445454189614, 0.06665155697133272, 0.026346397653762853, 0.028346766222028003, 0.05846962685726824, 0.038720041047781706, 0.03816414466728607, 0.026926544547501593, 0.07517476010346606, 0.009107281014533534, 0.0376399221920198, 0.07753421131881975, 0.059696650733390165, 0.03486894769594073, 0.014565501384617341, 0.030486440218444315, 0.039568065906003605, 0.014478518804084631, 0.018177925789308165, 0.039150724187493324, 0.005675424491205523, 0.010360621926074308, 0.04142325123651855, 0.031713075304944674, 0.02779582643040246, 0.04560560866769764, 0.1905713885301544, 0.052985812447244124, 0.018229761213484793, 0.03716937566716825, 0.08683428889320743, 0.052122281969434796, 0.04959236469960982, 0.05006314105083866, 0.02173162380894346, 0.01722361580769141, 0.058026096423066435, 0.08674080318380749, 0.030002492900577285, 0.03628486204111288, 0.030654945087829427, 0.12132653200458135, 0.05547105913020431, 0.05614964066133384, 0.037753655605258486, 0.07540342968798454, 0.04455114226608027, 0.06902469817789332, 0.02726971363318303, 0.04734688438475133, 0.03869914983008658, 0.046405749200212384, 0.015514020699136441, 0.0351779377688804, 0.029012812639496503, 0.027719851575731754, 0.05515319009822223, 0.030586633027621338, 0.022505673301977017, 0.058180915131684274, 0.02152043635085706, 0.009496830978370722, 0.004405679243181142, 0.0698025455518115, 0.012060339288455586, 0.010346268311203008, 0.02854790069132803, 0.017706459958947474, 0.041438243577196714, 0.06626033885104042, 0.034202700180392114, 0.031425941720484726, 0.006327892479021103, 0.04245566579723551, 0.044237322008778016, 0.025673268753434383, 0.052321139242379903, 0.06819281862267564, 0.053359249666813886, 0.07796922668574319, 0.03918299181086402, 0.05281217478876633, 0.02341332278334566, 0.04752652434211585, 0.02405722925980245, 0.045955978979867314, 0.04383983728926509, 0.04291169112548233, 0.03432289171483248, 0.020397179084078922, 0.06423673292081203, 0.07235138902380582, 0.03402400251117445, 0.027076391345490853, 0.06947003274915681, 0.017258292777583967, 0.1175451143494537, 0.03039959457612807, 0.018762226794816313, 0.041774111844959765, 0.037460017934321396, 0.043049192416571805, 0.05784873174683702, 0.05546990233743864, 0.06791993044316769, 0.03554349960458856, 0.006314970012153349, 0.09201742528427033, 0.040808592081790974, 0.005492847544261285, 0.004637244161248448, 0.02876342803750548, 0.05263684407597589, 0.08791653364295922, 0.06746603100891076, 0.05689074645840353, 0.01821836565561112, 0.03149266989390937, 0.0378367378406467, 0.03171124627002545, 0.029204754053705165, 0.07348470119459015, 0.015801127470519035, 0.05603433676785039, 0.05704580648471752, 0.06305228438108199, 0.03794027079317359, 0.04348327315622761, 0.030490651786808046, 0.06780438906242771, 0.02682575227452382, 0.026120447681375572, 0.05580422693803426, 0.020721621150451324, 0.020165401097807675, 0.024465529225586403, 0.03373103133673149, 0.02729192443732773, 0.018210337054164662, 0.02379293467158512, 0.03164793293352329, 0.06818511943903661, 0.05228617498951574, 0.042642353763503414, 0.028046044153011138, 0.018710670992732048, 0.08968963648282713, 0.03502704909131412, 0.07183643238198373, 0.05597799483145918, 0.07266265054744098, 0.035318779203319745, 0.10713575678246637, 0.05086975119587395, 0.01970263802626681, 0.02693456740328862, 0.04442931130348195, 0.044318711189853574, 0.02020171558063838, 0.004956507952057667, 0.20615082834997486, 0.20369925506172643, 0.08993538216717782, 0.08247417608095754, 0.22349381789324746, 0.13679215414149148, 0.1762954013482217, 0.1150470165415637, 0.10580816471408452, 0.10180573069280195, 0.18482467189671534, 0.086838218924259, 0.12871354247533506, 0.18649008575706713, 0.14370510174382117, 0.26734084491768195, 0.15851085404715232, 0.17458681077245744, 0.15943091032245468, 0.08929428148774371, 0.1568045923786779, 0.14336177177967566, 0.10437381063257495, 0.1452556177372894, 0.14613893243574327, 0.1681332248112848, 0.13553903348022892, 0.21529683032103125, 0.15932702879992225, 0.11839757102631754, 0.10893712826674024, 0.10921734024680431, 0.13113375212396347, 0.14830657821749488, 0.09709147075491567, 0.15042539355495285, 0.15247135393081174, 0.06080740161480443, 0.11915443525198968, 0.17034865915775302, 0.10436474015155148, 0.09973147102902014, 0.3916818486346353, 0.14581047989908727, 0.10511341489731305, 0.12346440760959541, 0.12099538283843188, 0.24994064392822407, 0.097098043789306, 0.3351128131391541, 0.12126937418455079, 0.19794538316707458, 0.11248513425309813, 0.2169774280440423, 0.1420406071889785, 0.1605438368935739, 0.1315913057976192, 0.16875567124976268, 0.15216649690222356, 0.19560146055394606, 0.11284802244195055, 0.1561801081463214, 0.1131157395279696, 0.1621373917066282, 0.05924862719351246, 0.15044146607960426, 0.08037186227738857, 0.1295006671740163, 0.17600680070538677, 0.16572329606260025, 0.12502644556544482, 0.16370938880549324, 0.16118828537723712, 0.2735830212552702, 0.1692648898930319, 0.16469709064450958, 0.11944572486343885, 0.16196794837953585, 0.1410314702098408, 0.183691106916916, 0.08213471486082963, 0.11861867166214413, 0.18768567321521623, 0.18794683258860342, 0.145013319448598, 0.24650314612494362, 0.15902445471334845, 0.11247884467123978, 0.14896962731595964, 0.15740191113323937, 0.17012892981931088, 0.10595142315592497, 0.24199090357269012, 0.21014879607865888, 0.1711588124594381, 0.19714687440183856, 0.08230484000617459, 0.12855450262225446, 0.10891519516946808, 0.14562490276030957, 0.12666487014822422, 0.2222346604591416, 0.15512419383852713, 0.1273687134286569, 0.17435434905271377, 0.1633253795725684, 0.2084912576021687, 0.2723281998788157, 0.12379218598887806, 0.09768796979539818, 0.11542182505851793, 0.14843120540101684, 0.23705090816703536, 0.11265548156394113, 0.19993779399702627, 0.10226417302844987, 0.10958943681250657, 0.19770711450086487, 0.06848523438337349, 0.13806459554020437, 0.29480806942428317, 0.18259098933589074, 0.12386834278943078, 0.17608166281734744, 0.17078133029562814, 0.12934018707563802, 0.18685359447713823, 0.12014162381209674, 0.11230476651220553, 0.15887765694529782, 0.10702124962042417, 0.21779931781272735, 0.3815373123413132, 0.17895070805905328, 0.09344817875253578, 0.12406968601769018, 0.13129058564382215, 0.17938033016698976, 0.10388308535179785, 0.08462247814262107, 0.13743580589371343, 0.18574757801909603, 0.13385062166039022, 0.1903335488731823, 0.07266989007832543, 0.13466379334849699, 0.10753246775317578, 0.14772375384646078, 0.19934957636700523, 0.1728234755536241, 0.15861582341453723, 0.15950103801104332, 0.09651465251320794, 0.11398917169220026, 0.0702363581606938, 0.1452615932230988, 0.10954157163899754, 0.1646622489657133, 0.17211587078148322, 0.30774907178936467, 0.09912246177273412, 0.11589378118515016, 0.15533797833467686, 0.12137081188660477, 0.15691513886615155, 0.12971180100594798, 0.21956374087641317, 0.12126136856574206, 0.19588670573167263, 0.16147110971712297, 0.10014768659828172, 0.09810710415965128, 0.3016725543045229, 0.14343897812068462, 0.13819548932294692, 0.15591461271528276], [0.03295476976481657, 0.05392942592621811, 0.034558413955833645, 0.030277325028193094, 0.018078119854532906, 0.0045853771359449435, 0.047697890549898155, 0.012086886150251714, 0.026669502896707387, 0.055856661826011636, 0.03850751293582782, 0.06651241242164566, 0.036745426440311056, 0.06497732543897244, 0.05813511456513117, 0.050603937838346734, 0.025362882485252716, 0.07383323289574155, 0.014170429842065901, 0.008501039250873992, 0.007192988170220727, 0.06578501193754135, 0.060300167139259085, 0.005366999408110015, 0.05514509254886259, 0.032259047016381256, 0.03177264438671691, 0.015389526623391337, 0.03249027150412721, 0.06289304917558067, 0.05144073950847791, 0.007203849381767214, 0.010805296704113003, 0.0880538012772318, 0.056351642725208116, 0.019998621841472004, 0.06396888176940622, 0.04627720730739736, 0.04710573139750669, 0.03379210003561551, 0.055323422495876594, 0.06687880929319129, 0.032829487576119365, 0.04838475349148916, 0.010566989733507077, 0.027703775220640728, 0.02066356892276916, 0.058794494102438616, 0.055520628849344875, 0.01868565247634486, 0.03513086932681261, 0.06423106003973274, 0.04145396370140295, 0.008643709720232555, 0.034762856009746754, 0.021868956560689597, 0.04033568983657226, 0.04652939962163087, 0.023846141393146208, 0.03580480070424176, 0.050449812439300364, 0.030516888382994843, 0.08607549412596611, 0.013555010345073478, 0.06898499950165711, 0.055114146427161274, 0.04279130423862127, 0.006863338621183029, 0.05569884771360986, 0.03257772810156307, 0.07803412199380898, 0.05580251856196312, 0.008742769676891547, 0.013550234744475495, 0.022152769153997786, 0.043814701944469445, 0.02817738035152997, 0.07540028872749499, 0.05118017768367164, 0.06827590851894311, 0.04948917648664886, 0.09450658284608396, 0.09515589598806636, 0.0284216474861868, 0.07221733895881523, 0.026112265862344254, 0.0036892235220875595, 0.061071694287801945, 0.06113190496821077, 0.028961967383962006, 0.044081572503332174, 0.02783952983126285, 0.04794730196496652, 0.08231666074284623, 0.01426694255637666, 0.07743921641620898, 0.012605494158642908, 0.02161404463432489, 0.0039072583698021674, 0.05099909748100946, 0.004110932181168709, 0.028320079549185695, 0.14466032145484803, 0.01016111252078366, 0.0239043238557755, 0.02861394130084063, 0.047850085407375335, 0.027217479843285777, 0.0057634010708199875, 0.0064864650184679185, 0.03182375011214566, 0.026860264535512657, 0.07728257441833135, 0.020701875234202995, 0.02802105819536073, 0.018487009708018556, 0.06182594232321267, 0.04220278400387015, 0.03080215079769973, 0.07442776309025866, 0.04983446763588056, 0.0852623837248933, 0.09902327636917753, 0.056264852624266386, 0.06219696636582094, 0.057305192364560026, 0.01679276604385626, 0.02130033545977166, 0.04889969481155277, 0.0715487816881749, 0.050217025132188876, 0.05470622759011965, 0.03334281628110236, 0.02165405932182987, 0.09647683841326544, 0.06558618913855284, 0.04353129537776113, 0.045905057115540396, 0.010056522366921268, 0.049613232934667226, 0.024803069480244192, 0.0325948425057915, 0.09072195528255356, 0.039250499478751616, 0.028232080944543405, 0.010140468366444111, 0.03613726371118138, 0.03692359933930059, 0.03866848716091725, 0.03279039027890371, 0.027610714690038757, 0.06758072203205479, 0.040249060614094626, 0.036761357238696474, 0.03339300653146159, 0.058001945501253496, 0.025538180639306386, 0.007254247433475911, 0.08881437336845745, 0.019003937111025857, 0.039910239077383475, 0.04423751736119871, 0.021140895325750596, 0.017196950202267018, 0.006494488831864851, 0.02829844139576439, 0.02995213028043509, 0.014980577398091556, 0.10302909649908544, 0.05254842986863467, 0.04342737172039286, 0.013508763532304477, 0.03528874855668795, 0.05222500669920156, 0.04519680116866385, 0.018652293177682067, 0.05435393056682041, 0.06258693193235705, 0.025692173888185815, 0.04397734624123381, 0.08442768496611426, 0.013935411303874948, 0.04940540477212879, 0.0284126095639001, 0.04678367569501843, 0.06899043872591949, 0.04397910441302004, 0.012898096653272309, 0.13473533063886628, 0.0701452243412214, 0.04640207580861546, 0.010466014557037382, 0.01718114580838911, 0.04309233848846728, 0.04563093553447435, 0.03335053461693949, 0.04269756572020631, 0.08746965923496793, 0.014289388932558078, 0.0418216897354972, 0.03603797871619463, 0.03332454891454789, 0.05671069664399951, 0.019596488883478508, 0.020298453333276897, 0.06272629481710254, 0.00968171097713733, 0.07791447438179486, 0.020122906200647838, 0.03232119206879889, 0.07816745959703, 0.015936631187345954, 0.017802826158942717, 0.08429300670902576, 0.03717210294017869, 0.019125482705872388, 0.06710042320792714, 0.045604417400975386, 0.021999457723370964, 0.05609492283134211, 0.08389457204048673, 0.04257700646356229, 0.03150226322994117, 0.04700440860864136, 0.042669389006351276, 0.04877977906876514, 0.03370881478692736, 0.062468138508378505, 0.06565051754155467, 0.053088345655029824, 0.06140219994009503, 0.04161692975509552, 0.016837754557209633, 0.049899546805048184, 0.04643943791668262, 0.05189188868708668, 0.040086067747324705, 0.045548102277661526, 0.04669826838278002, 0.02317217362654065, 0.051740708896109176, 0.013761460506958107, 0.05463624162779701, 0.027022307453256462, 0.025235763600757046, 0.032225193591007305, 0.02194853011338461, 0.030242943002151388, 0.026788148848760514, 0.15239309038846724, 0.013285424962129085, 0.1819590280853933, 0.008519072003001648, 0.056961471695573106, 0.0912865314392313, 0.10892229680452617, 0.05505747890340225, 0.06180530008409293, 0.04710873063173025, 0.03463088587347058, 0.04990625007438564, 0.07196655241592277, 0.037865615524952455, 0.033411553520108425, 0.035332840747169914, 0.08002311607161838, 0.005827219067742267, 0.07886202555269965, 0.03971015989419915, 0.047402329998271125, 0.04061205605525644, 0.041701544166332295, 0.012734507195531361, 0.012344236151435444, 0.055998633240139296, 0.043263854083394816, 0.08381138255278911, 0.03829121567128647, 0.06539344907768312, 0.024281654717220415, 0.04988242857038014, 0.03461735293028816, 0.040849347959362695, 0.01780494439205335, 0.017240080952404008, 0.07752846565938766, 0.06706751973157929, 0.03008013016604368, 0.02192479479427059, 0.011503520729621092, 0.04355871749501075, 0.03617225094668327, 0.03610622948936878, 0.04892189987003804, 0.025243052927356575, 0.05106834416848518, 0.05315201139197715, 0.047867322385671644, 0.03034722863606388, 0.10476613958035746, 0.033390827011317015, 0.04892053240309319, 0.02619548407833903, 0.046715026556123654, 0.042796785597719496, 0.04765918012708426, 0.044272531409777945, 0.038922736421227455, 0.0265455307183607, 0.031219218639777075, 0.010972262694380217, 0.035735508051490596, 0.014866722368394897, 0.060311597171089346, 0.058946443811780026, 0.037161592213857564, 0.03940054545960119, 0.03591432829477614, 0.00717024301974884, 0.02411133038901514, 0.08033496748295524, 0.041381246635630246, 0.009172646509062861, 0.05784946719124433, 0.05472279807192184, 0.03759406033843275, 0.07580461461217174, 0.015160718185436583, 0.02079344572379224, 0.011843174429339989, 0.011346685294542583, 0.032963664045617465, 0.03424589604800267, 0.04336490491104703, 0.11932121259310555, 0.0360392082873131, 0.015672543442868177, 0.049659711489033316, 0.05766202079793138, 0.015905246480307993, 0.004402661814369381, 0.010151536421730153, 0.06476550978878814, 0.03239312772488883, 0.11863420792524854, 0.01417087513067189, 0.025064255666708755, 0.05457242267326482, 0.0328916517807351, 0.033374846417216525, 0.07321488502765856, 0.032062162419841174, 0.11120333892082977, 0.14627212448225868, 0.1044733637583352, 0.0965977424094754, 0.18614275681395687, 0.10363517163862145, 0.19111359491944316, 0.10494849148897395, 0.14645882010940584, 0.22383941547764888, 0.12932598380552185, 0.11401478201150896, 0.21239484329858135, 0.12499834546038222, 0.12843752865709607, 0.15029523521661758, 0.13664694983632336, 0.12323186928105932, 0.13458203644521777, 0.08430698015276464, 0.13975519837150652, 0.18226736315315772, 0.10228267405182125, 0.10030749253928663, 0.1371612553034098, 0.1441360721665044, 0.13878741481852147, 0.11628574241072902, 0.16950986948945831, 0.30090024574629726, 0.10733257243109327, 0.19243635297302278, 0.11554277502000333, 0.14884504609771315, 0.1598627387636131, 0.1684139960355336, 0.2292307745665312, 0.1441183142484196, 0.11052698287512026, 0.07488429786697512, 0.10941704404690575, 0.17926866519114665, 0.09167758102018027, 0.1988874414875623, 0.1602121821093944, 0.12277302091881154, 0.08861994025327506, 0.14379865640113432, 0.136846944749836, 0.11989397822969383, 0.12564254113503043, 0.1759696147975422, 0.06781837782792507, 0.11516140112953803, 0.1551471151892216, 0.14637908567824673, 0.13237764908661767, 0.1696417898300194, 0.21893720352841964, 0.2587403128704717, 0.11411876312547153, 0.09813888148675043, 0.1898115059180606, 0.053154244538276434, 0.23460753201957674, 0.09152626333337638, 0.1920531404715392, 0.11658567349396406, 0.1941430896160103, 0.1457978854136121, 0.15076460196606575, 0.1318970055229241, 0.09431504554325536, 0.24788317691174247, 0.10774527931766165, 0.24240099043855745, 0.16826609510087198, 0.200951696043053, 0.16700456279420084, 0.18278055013187472, 0.15506116012411733, 0.2738105800122984, 0.11505853084306564, 0.07169261469595856, 0.15675781505002132, 0.1411643558211865, 0.12848682641502351, 0.1525331619045427, 0.2388925069282132, 0.1604586632381524, 0.13835209301642834, 0.10138622094546595, 0.15118034256081428, 0.189474074830932, 0.08666135220518036, 0.12716226039394257, 0.08794727675136059, 0.16398226932412194, 0.12969327699993888, 0.21012262651516547, 0.14499064324603927, 0.14674417253944183, 0.18795651593996635, 0.09182795641883727, 0.16261889328879697, 0.09101547420986238, 0.11140865814541617, 0.24022251217355653, 0.1388233749856872, 0.12030703751670739, 0.12224417510292224, 0.15909665083933264, 0.16171400555439536, 0.11827389379182171, 0.1398328490435116, 0.09735643758528656, 0.1435257912042641, 0.12532384855852974, 0.11309792032285083, 0.14798112874550207, 0.07604219379924959, 0.2151795729033409, 0.23503617353497014, 0.221946764617197, 0.14427807422414904, 0.09385867164500299, 0.1344281447029883, 0.12305331716854727, 0.15725178854359737, 0.258611181089955, 0.12384886883439557, 0.13319429881390066, 0.1399555916507398, 0.20192902505157456, 0.1213914885996811, 0.1879454689520982, 0.09437496127981333, 0.15406362171615326, 0.09270395497761427, 0.14192197081302443, 0.17223227018069837, 0.11627722351301102, 0.11753721598295436, 0.16846696335461833, 0.12988771011512126, 0.1480918131288021, 0.15624295799962937, 0.16003461825030466, 0.11131295078103581, 0.08716153867182233, 0.22639899184146237, 0.1292905905434201, 0.13841785400384857, 0.13083130061145753, 0.0800494465135759, 0.22291707626033216, 0.1711224845700687, 0.13419462578190913, 0.2659480051407891, 0.07736823837002439, 0.25777016976667994, 0.15625150754086434, 0.1260548036906027, 0.1048748168132959, 0.11046766468714322, 0.10483907115074897, 0.1554869824359494, 0.1574379785527145, 0.2755109274819974, 0.11650092118690092, 0.11626951666849276, 0.10108632050574788, 0.1610207266264385, 0.1166420728869496, 0.23579795604511616, 0.119185775908972], [0.11495362276271467, 0.10145465557974193, 0.05164387921291975, 0.04001040890392277, 0.03297915817388604, 0.03937101277012018, 0.014509544407408086, 0.05864904464913472, 0.01661046584617467, 0.019685335930496938, 0.1016913231221899, 0.003192000379297702, 0.04351888858382741, 0.026342306744247198, 0.04551515283603822, 0.018402822390799562, 0.02042490189083882, 0.045535013665475195, 0.024110564301090858, 0.04288341098975751, 0.03434473671199333, 0.11310515985373529, 0.09454556139967135, 0.04264282490757685, 0.05726455906105619, 0.0423426256935683, 0.03068884639369865, 0.041984433623691725, 0.012147365919043942, 0.03350601599161183, 0.038630312999650356, 0.0459744110553255, 0.048275011396335984, 0.019429052706747767, 0.013001498413242161, 0.04286804326599644, 0.02316949614924529, 0.009391419195209541, 0.02187331368575894, 0.028467721929172837, 0.08222272304157097, 0.027371882949204698, 0.03950728065965157, 0.05439102454411407, 0.03157012521349375, 0.039709558515178586, 0.06087397082498478, 0.041490544399787346, 0.04088467227355127, 0.12477925963579647, 0.008815870744236296, 0.05279879506316878, 0.019753969747633226, 0.030139344932150938, 0.047621117048566385, 0.032904173487857465, 0.019507547990689357, 0.037086193840349876, 0.03189607647307698, 0.0565904974486799, 0.04452697985294846, 0.018746625414238344, 0.013583030968513942, 0.07372520683753876, 0.05953929244330334, 0.04132320398404714, 0.07394898112022108, 0.05376356406017177, 0.011555620454131596, 0.012169841981132426, 0.03946483938864643, 0.03498866808630767, 0.05440153910087482, 0.03671467567103044, 0.10234046006394971, 0.09596984908585587, 0.043724993048536206, 0.008621200141797384, 0.0768321989885261, 0.08341274104051052, 0.015031759732312735, 0.05269297533818791, 0.006247626574364521, 0.022438441425742164, 0.005562315918430085, 0.04715748446723146, 0.03618335922158534, 0.046341325036220016, 0.04024701515933679, 0.02170740010877771, 0.02246287963052671, 0.03681800944069701, 0.015846377411376567, 0.017749696046174053, 0.03839399019676832, 0.07133384039925952, 0.01666737277241003, 0.06747295644374625, 0.04227179320408933, 0.017708829085853313, 0.10501037607149732, 0.04882748336381009, 0.07639416523518101, 0.053944747684703725, 0.028134487088649508, 0.029775016498000875, 0.10571213559277597, 0.06330760999492581, 0.042295074616108215, 0.00837038008255824, 0.04268835351291684, 0.10800784829282954, 0.02333056230488564, 0.06819465723369392, 0.02262080099523789, 0.022375269815505996, 0.06273603179462015, 0.05835434594642251, 0.019969887798652053, 0.031122578563348904, 0.07004387856971833, 0.023141756105507096, 0.032739035574899565, 0.01509501848505029, 0.061668063093337326, 0.06062380481331099, 0.07074932297391277, 0.009849837590609829, 0.006155141088510714, 0.02654719695959601, 0.021227811831199837, 0.04854844349827017, 0.013649046680169, 0.07172528068504988, 0.03662745656085111, 0.04297020875157849, 0.015054844834301022, 0.034056086273443316, 0.020138461615950353, 0.012467853056507246, 0.03903652729106046, 0.06292162425515634, 0.0676574150941545, 0.03278716121830287, 0.07589970910621267, 0.0469135161068651, 0.07114473159515089, 0.0517337145133605, 0.029811645076880534, 0.06949840098499291, 0.005699447093291149, 0.08268862707360138, 0.017258698804183834, 0.03134977534383295, 0.04812163676345541, 0.013429320214556591, 0.03418679236464443, 0.03743992344806752, 0.04958194973427923, 0.008402597910213855, 0.06219184123760751, 0.041512102113976594, 0.16913175913355044, 0.02186150444040616, 0.041479022437406164, 0.023949381317042058, 0.014099582030828443, 0.0280144315348157, 0.08277263627537797, 0.08710356879859202, 0.05825339087976083, 0.05648999437389355, 0.011864004360001174, 0.029866632952865575, 0.08943943982763637, 0.02434980589896441, 0.05957539433673505, 0.040111137974646785, 0.020824380354174686, 0.03477644257908387, 0.04831526165587768, 0.015028656118609493, 0.008859911223783368, 0.021068919450044635, 0.05119457247576887, 0.035853554539742975, 0.08790056070973797, 0.03869982398745995, 0.03579274248031359, 0.07564396597445011, 0.005276649871150093, 0.07859702807881179, 0.05147547010452517, 0.06399309014781349, 0.026370985245692636, 0.04256623909778653, 0.027288381280677936, 0.08205448247251973, 0.07059755329523357, 0.04528089847055174, 0.04379869836773123, 0.037747863980550925, 0.08641516985071283, 0.013461750631611194, 0.035325689316396756, 0.08246885943076304, 0.031459980922180324, 0.06229323297438603, 0.07520417787975843, 0.02569964133022774, 0.006310652627895076, 0.10225830479494988, 0.07687161421223034, 0.02812016124446546, 0.010239065797518819, 0.05364139218844714, 0.07159711417531775, 0.014393592212018708, 0.044411208645831195, 0.04690650640235794, 0.09302237942334145, 0.045374131370936675, 0.049289763799958655, 0.03320706167048024, 0.08171445434732784, 0.018898086742528023, 0.03479068798403587, 0.0252455810175067, 0.03140492026784247, 0.07980424475165145, 0.07899343261435147, 0.014141798263505824, 0.03455169153429809, 0.025582776532598564, 0.017165188196926348, 0.07737852693084749, 0.024517261227893255, 0.057298500586541436, 0.10344642289583722, 0.01284435654299394, 0.04772495643626298, 0.010078443972874555, 0.06007766073209144, 0.04215288869736176, 0.04642556023393427, 0.04577634285294241, 0.02861221568779119, 0.02882540646579958, 0.03204207367924673, 0.02804577985267726, 0.039172189971131664, 0.012308178308059373, 0.04512066735074886, 0.047477322345178936, 0.05374646497770183, 0.020047272255103436, 0.019685768770174156, 0.036924085805132505, 0.035952238155709165, 0.0014245307993992504, 0.0660583827524416, 0.03592855071709041, 0.02382122821384861, 0.03094363766121528, 0.040905295360472896, 0.05383114833685179, 0.04377582298231222, 0.08855917415912114, 0.021710504680090857, 0.0396627965082805, 0.01792982438459031, 0.026889923629501176, 0.022245942682568586, 0.02563512523568446, 0.03934776200161826, 0.02583763674802838, 0.10263829972715148, 0.08024134387772891, 0.035212331286240975, 0.07620003855516834, 0.018896883984486905, 0.010038532707239351, 0.0648232574965204, 0.07140487973247805, 0.025096808657831243, 0.03218350691660758, 0.06519586734113193, 0.02088265091691527, 0.04533181267399942, 0.04409611668257464, 0.05140331994381644, 0.013075580073129988, 0.05422471834707165, 0.024646394923629782, 0.01882202378774603, 0.010695468424068344, 0.015617609193037837, 0.03747708637327437, 0.04582323892522724, 0.03585697129188526, 0.018372542765592376, 0.03592847027785836, 0.07684201257483614, 0.06641636797857862, 0.07065875605950434, 0.0197275665273229, 0.04923714505087945, 0.04840114011218952, 0.026022179668108304, 0.07193387876595221, 0.004294972834853275, 0.060341995539924795, 0.027643049346102823, 0.02801735416024683, 0.06914302811867769, 0.005920515649185907, 0.014054442215110026, 0.04615123180912868, 0.057403408666892405, 0.024181000340069016, 0.04102830226803499, 0.03191433809397202, 0.0385130211080034, 0.0110801623480755, 0.022921731823214123, 0.023225171589142373, 0.06754957289705354, 0.05868847519459744, 0.036063520087590145, 0.006287844275169436, 0.008388454011911827, 0.05872418638318778, 0.06935740250252909, 0.053226750929869955, 0.03182538187942438, 0.03960300717623003, 0.04354597745282997, 0.0293981050696945, 0.007532300003203414, 0.03730364406721727, 0.03361540951675946, 0.03679137256356978, 0.02920944251180176, 0.05973153071658266, 0.056564550050684524, 0.02450269215079325, 0.022512273149444692, 0.055839612539256775, 0.03304973785435, 0.059474688248648766, 0.08439313440072922, 0.025739299786847927, 0.24247698636064607, 0.15222845809353938, 0.09968168297482115, 0.08325266696873211, 0.13859452920094614, 0.09886491067347028, 0.0791794234406083, 0.21834786741002915, 0.14138860507838188, 0.14560588845802894, 0.2705096603641587, 0.09621162643475879, 0.11182664337778285, 0.14502741546640474, 0.1740613204216765, 0.11364416399550055, 0.26398133486509323, 0.1440531201660633, 0.07928206390070339, 0.16386821415395508, 0.08849928906608014, 0.2285248705095822, 0.1442223336667784, 0.15495255949997133, 0.17531238796730197, 0.20090733955223716, 0.246633181889211, 0.0927034953248597, 0.10803858374035168, 0.1266813103950793, 0.08443831826650328, 0.13315193415168794, 0.2125504663995197, 0.07224230576426753, 0.10512370345813614, 0.17126508417629427, 0.17736584068306033, 0.10290977830487875, 0.13286814454101747, 0.1323387624635812, 0.25953296872396625, 0.12369863899244417, 0.17852326164082175, 0.15331222735826047, 0.18931039248503026, 0.1099177667750947, 0.11910931267324956, 0.1766270408106427, 0.19176584217817555, 0.3226020763958654, 0.10537034546535824, 0.1745378883976129, 0.1102408490354015, 0.15823022071872989, 0.2685707531148388, 0.17394876678384122, 0.1804506469277605, 0.11168631139181315, 0.092319080065335, 0.18506995792831146, 0.09357773188141086, 0.0879624912575368, 0.13463724074104141, 0.14271997396023045, 0.14820456594949769, 0.15622719191014767, 0.19825727288280764, 0.12844042446944984, 0.13325455929002455, 0.1202188607966227, 0.1160449686370069, 0.13516846142949598, 0.15934915341917547, 0.07924390506119498, 0.18747046379552734, 0.165053857790847, 0.12761527116620733, 0.16335864311024068, 0.11489019068258424, 0.14295539277936184, 0.08524862478577322, 0.19970185423810638, 0.1410228747033304, 0.13684401829396525, 0.08483981728673944, 0.12545020710076057, 0.14566732870955623, 0.16824944034939812, 0.10856729932129384, 0.19295534689820584, 0.16269053783147566, 0.15672914803989474, 0.07417303119455615, 0.05835785079867609, 0.11078627299397223, 0.2178911717548486, 0.1040945869059332, 0.3218918822465405, 0.12242284212862292, 0.21466457795712257, 0.22331645321701804, 0.13797200615367583, 0.19251147555487771, 0.114446472556841, 0.04512869595219532, 0.15800146686453975, 0.22315575861402098, 0.19861365698518293, 0.14491017337047285, 0.13164611172772225, 0.13651846156966302, 0.1872095802137929, 0.1803505652013325, 0.22303525298353166, 0.13157544777758662, 0.09881251792032873, 0.2295787317017394, 0.15058054168137813, 0.11940843170328487, 0.12109349571889448, 0.20127886155199623, 0.16378179943609625, 0.14703462711505352, 0.12836858840479007, 0.19325412118867522, 0.16799071713561015, 0.15730382123541448, 0.17245704037768228, 0.10317245453235604, 0.08285280737665393, 0.1425318840530611, 0.21740908794585737, 0.08475827488807902, 0.10740342790320997, 0.1835123479606644, 0.16328350520662724, 0.06588552267320695, 0.17733228603197684, 0.08546660744374798, 0.07732352181788414, 0.1341669546860841, 0.16454200380511824, 0.2134168352330885, 0.0985537334195068, 0.18282745003459916, 0.09577805131313302, 0.0707068050941152, 0.11359340300963772, 0.17343193322660463, 0.14236680742713714, 0.1266436188692047, 0.13800215937437552, 0.08907216961585707, 0.12322024006636874, 0.12444636378917964, 0.15534213053122645, 0.19518662394294817, 0.1077231853419254, 0.19282961654807293, 0.1469915576519505, 0.13354669925906967, 0.13466757782284292, 0.23009069293977755, 0.0837452844866822, 0.16571287726683004, 0.1352801417270976, 0.062304318266650366, 0.1918998462778907, 0.17435376682589132, 0.2162870755719562, 0.15397671670202287, 0.11987956045495889, 0.18523460554499782, 0.1728899260201762, 0.1618308646063651, 0.1291556824599543], [0.05568662095033834, 0.04137976425549677, 0.036275538751074386, 0.07647333276127616, 0.050484474087434436, 0.06795690184639347, 0.015234050036768521, 0.01714296015580335, 0.05385809164914874, 0.017180942795089176, 0.018923074615398244, 0.11639617398501405, 0.04623811767106095, 0.08443919160673696, 0.07301992331180843, 0.046149002493269024, 0.041749888144794016, 0.025503620497822285, 0.04982713234400557, 0.04970393391446241, 0.06026190104744127, 0.034890409649139455, 0.08003064671591406, 0.06038219983419103, 0.025376938283443454, 0.04965490428730846, 0.034036256087523316, 0.02239988805095275, 0.0029338287488151825, 0.0035742705926344164, 0.024511833494949727, 0.030234992924717166, 0.05456407231489017, 0.04931446247463746, 0.019137663503868446, 0.033283161014438636, 0.049272063338468154, 0.04831960154396873, 0.07344347800338462, 0.0447802868251118, 0.019600997310912898, 0.0456580397252354, 0.03611438066488312, 0.030876258313055002, 0.02537231494282042, 0.032974860420630824, 0.048248056592720176, 0.02745246965317957, 0.024396916475868034, 0.01690772519777379, 0.08001699502910338, 0.08410562160274676, 0.007101767687051888, 0.027399852819320177, 0.0253841414251515, 0.02542805933063069, 0.05613880434764489, 0.01825496550619362, 0.010603696836398975, 0.0671573282189427, 0.033753738182807164, 0.05410420122526346, 0.04773295822463209, 0.045523326994190295, 0.026299225789825284, 0.05359280306184965, 0.042927863241563884, 0.04820636608788083, 0.04710102378721199, 0.04482938156973931, 0.06863847495086732, 0.06603383729534765, 0.04323459335512692, 0.04836820216188508, 0.058985882018121986, 0.026656831802439787, 0.07965697966996702, 0.02079743129621831, 0.05895446858278686, 0.05751777410266861, 0.03356296696790284, 0.027523164246832172, 0.018232499977814096, 0.03547632901538764, 0.030350961399474935, 0.07994495212070404, 0.008226341188644931, 0.05985751387573058, 0.03163173975002381, 0.0243982169101195, 0.07030145265161991, 0.04696427709272793, 0.05088210053321335, 0.04083018810037644, 0.01767079856607222, 0.01841677476712052, 0.03530636474850678, 0.021857637611608353, 0.018493848957962567, 0.09205581395015602, 0.01969378588030175, 0.05159556970841462, 0.02411231481199784, 0.03133528479074519, 0.011460109399781834, 0.02390590582733914, 0.04031612395098613, 0.010800621652555083, 0.038862663636645006, 0.00848782710700987, 0.08347670938218794, 0.04100789368573216, 0.11746718022491663, 0.01922957681780381, 0.04947953527012179, 0.02036458970378003, 0.07071134033462695, 0.023495765335317102, 0.02929539757690603, 0.07039541333553291, 0.03427833604115633, 0.06145903217275778, 0.058477188145080884, 0.02642286471992491, 0.030018936977871967, 0.011015009442945162, 0.06459130139480676, 0.06588201399051374, 0.04945964379716785, 0.06272695748315704, 0.010041247531321022, 0.0372454481980493, 0.09643728529373485, 0.017902555484925548, 0.0931266056854398, 0.019471130085988872, 0.0471068958511516, 0.024872563231075485, 0.024799581864968907, 0.026818380593472434, 0.003599647973333636, 0.05791931142730098, 0.040844134731037963, 0.09211539260802731, 0.012542319675577025, 0.020601523461781686, 0.026057352679931832, 0.012900401620314488, 0.05745655984707898, 0.024590920581812822, 0.05935510958454782, 0.037026890974131324, 0.05530656090066318, 0.04641902933437978, 0.06474137035829407, 0.05844458344302351, 0.042537024334794095, 0.023883030441920125, 0.040030499559737025, 0.06839537993073463, 0.020918567034025348, 0.009655760706312234, 0.041312789018716545, 0.12515363148263386, 0.05387290012872508, 0.06753733847290277, 0.020757901159325437, 0.09178759124610694, 0.07366908323620597, 0.0330493088451124, 0.026046035646070397, 0.054795825403303876, 0.017681768945147915, 0.0426152189292254, 0.02183666020902174, 0.03799253714180762, 0.1133920367987406, 0.06326018915241284, 0.046907682347321705, 0.0187805152287887, 0.03212893081288184, 0.0568151067671997, 0.040359668388602235, 0.04561656755545447, 0.03923192950746706, 0.0291852877595492, 0.055654203939822414, 0.028025524487959284, 0.020057093502292712, 0.02461235955237381, 0.10818691368425086, 0.07361338864411078, 0.013217232603159164, 0.043017281024085904, 0.016683389755686926, 0.037622635418008414, 0.06128329926380708, 0.05346529538773241, 0.02303925354123837, 0.02064521537132321, 0.024374136851439555, 0.06970551285532213, 0.015209502664454764, 0.021680274850598747, 0.005871887739387251, 0.058590622784029094, 0.02176186896019405, 0.04510222378397181, 0.011457813051228803, 0.03151123220431468, 0.06740625316817915, 0.028658745953092174, 0.04262860248526258, 0.027320652734488252, 0.02343818042126875, 0.003961384157469917, 0.020266580245187207, 0.01943037037797753, 0.04792328127810071, 0.02255083035467373, 0.03933144049839147, 0.04002910144927521, 0.027290721679286613, 0.008360721629052874, 0.007816293105978759, 0.08207819289377621, 0.03855964904951473, 0.1145368556101476, 0.04733823908252582, 0.0450635823090711, 0.032685275354813186, 0.03262355931163315, 0.05901537640320678, 0.03406067897054938, 0.02239115081817633, 0.06151309116713463, 0.04741093316566079, 0.05376746727814598, 0.04655175023682175, 0.10948130350199439, 0.016081708130396662, 0.02046412176212236, 0.08235169394362359, 0.0639772014842639, 0.029833212367168842, 0.013780131984892634, 0.028456108036240744, 0.08481218449531064, 0.04006584685656332, 0.07151115144933425, 0.014972800648050203, 0.035327933954014894, 0.09883396838220859, 0.08672919695175464, 0.018340635203546094, 0.05089273383360236, 0.035184369077004736, 0.049687723493984634, 0.020408549744095054, 0.032116751930105596, 0.044898440565673575, 0.0240217478975894, 0.014186255303361725, 0.026938030120706367, 0.06105679770811431, 0.0028565814699827424, 0.04959671990945936, 0.05792664671917597, 0.01495715617502649, 0.020223907232584975, 0.018678024155838836, 0.07945017423480749, 0.05994430397667232, 0.00406863598806423, 0.031125593119330948, 0.03729487236048426, 0.03917957122828211, 0.020420958453248587, 0.0786043672011264, 0.0029553838295771954, 0.0016425357218043158, 0.022626770735387842, 0.0215603725143498, 0.03778296995968108, 0.03972585703576765, 0.05073590414418329, 0.01150933150652676, 0.06144323543975912, 0.04154532351681302, 0.012001894440712228, 0.018616942050416144, 0.07601585569641284, 0.036779279865685015, 0.01815379018925371, 0.09191307644810408, 0.028744442463521997, 0.025873437951949817, 0.00985280713892632, 0.07477671613976841, 0.031710317388417265, 0.06837608217592202, 0.043868213185980436, 0.04618136970806987, 0.030492568921838558, 0.07274715004548912, 0.05693842394037112, 0.018964814915952664, 0.003291120186575779, 0.01824276172555983, 0.018702904776399656, 0.030462814066859505, 0.036668564838868, 0.0699145093019451, 0.07147288535751643, 0.024079039783006715, 0.030814262647782604, 0.05619771650902206, 0.0416950668929325, 0.01613088714469585, 0.11253726653634541, 0.050839452418468656, 0.06529744293901228, 0.055488437834766605, 0.014758795901622265, 0.04012029655578156, 0.07129812538022957, 0.054434637929643356, 0.0814645488055483, 0.059981803980565844, 0.046696644276380546, 0.02031957629256912, 0.020229176002284213, 0.08032631835029011, 0.010974540848345047, 0.02213479098563473, 0.030105349780510993, 0.020999142246681358, 0.049047545950499274, 0.019369198257223736, 0.037250791661321156, 0.031741650384520335, 0.02873963909223676, 0.06509894189695198, 0.022498834052033, 0.031112401085274837, 0.06505842350663678, 0.07348681559726115, 0.07557291131947311, 0.052860874998112845, 0.036274925880734964, 0.042470707933628754, 0.030581333614405126, 0.3047165893498929, 0.12408742861401652, 0.08963594138021432, 0.25853300947816144, 0.10065791647761099, 0.1548814818623566, 0.09252201675647691, 0.16815605423142835, 0.1735071477390105, 0.05576852724076279, 0.18988190939830196, 0.24521332985210806, 0.09832569202708621, 0.21164582381325386, 0.2346433389691576, 0.24441929504034982, 0.13600369644982202, 0.13611294058782442, 0.20903409218355534, 0.11180719240538536, 0.23377076482340214, 0.16007411774368058, 0.2286781034161968, 0.10672538646406705, 0.09532621265539239, 0.18677287945343604, 0.21250689131838663, 0.12218257397293084, 0.1921960158694175, 0.1051956620968638, 0.09805114143678258, 0.17627565160153374, 0.11139091554908984, 0.1534646635334338, 0.16453562995358822, 0.1804477664371652, 0.19229369207976327, 0.10094104725266657, 0.23884920763873288, 0.1590423811707766, 0.1000079061956175, 0.13248154593090858, 0.09528942511326845, 0.15519573112889645, 0.23764392150746239, 0.15411985256979543, 0.23914703198017614, 0.06713305855350149, 0.07319065366661356, 0.24829743129591791, 0.17946784805145957, 0.3379571750279396, 0.11025908192799938, 0.1970731767435228, 0.1585554710078624, 0.12380242092354644, 0.17837624936815233, 0.12468640211849444, 0.13197922207895788, 0.11140145691892794, 0.15347653789626015, 0.10889878556613, 0.15397469422990276, 0.2003038001637305, 0.16977346502244475, 0.15952749868794797, 0.19602483138442042, 0.19011889103679888, 0.14056697577959107, 0.08146910702869778, 0.12812291166835255, 0.25111185446862255, 0.14530558199171098, 0.13538469740700337, 0.1710974794602202, 0.05500985887802898, 0.17816315435113447, 0.18607975374306404, 0.10747964599079664, 0.16812803073515817, 0.08344388251463253, 0.18483221020189025, 0.11796982583379555, 0.16749986928076516, 0.11177035889798596, 0.1670212175456747, 0.20700149238109591, 0.15869537398459452, 0.13918820137698806, 0.15699285082519054, 0.16518107435155302, 0.17377996697060524, 0.131684691915589, 0.17007059988475617, 0.1025458635582078, 0.14001805846008564, 0.10413404809491289, 0.08735707495361568, 0.06722934048382506, 0.17052207082029314, 0.11998158038383532, 0.09670946867235246, 0.21736897558214205, 0.14707421853898034, 0.1064391989981936, 0.18996303810948328, 0.10795075175983292, 0.13534873723983765, 0.1867652492177102, 0.16092347942533033, 0.1921765419143823, 0.13911352312612918, 0.13528415602782082, 0.05593623154826703, 0.1000750384804222, 0.14475504056580607, 0.08360513636181433, 0.11351096428810589, 0.17478535011891397, 0.11923256089850781, 0.07197756109939468, 0.19409314068334718, 0.14644915207980141, 0.11765168484060035, 0.19157075022737827, 0.13151567759773425, 0.13657562705057283, 0.13905280299725073, 0.1577551389533666, 0.17218055924580944, 0.11862555113170417, 0.08563862482626593, 0.186444963178327, 0.11098927097214807, 0.1839515155241374, 0.13867078559292903, 0.1587603382405735, 0.15995420966177218, 0.08759911277241285, 0.10488682141106938, 0.14878127693889603, 0.1432649382660466, 0.15332741122091972, 0.2697217848993117, 0.12738752088719799, 0.0914509185860234, 0.08337027678686766, 0.07003729021356953, 0.12033526019583787, 0.1223730464135447, 0.14711894275199983, 0.20158802399471884, 0.11821537999616516, 0.12850508995113835, 0.14603688952422914, 0.31811589615479596, 0.12753464807305606, 0.11855495612948172, 0.08219413264023681, 0.10068948696097059, 0.09958351646820385, 0.12020753801710184, 0.12213742841155299, 0.1711907583258806, 0.13761384472731622, 0.11995632246497179, 0.21230432234944838, 0.18097805249835217, 0.09422131468571963, 0.12725906326405464, 0.09998697667352616, 0.12638488799453745, 0.11787661591604834, 0.09689846256327245, 0.10669076695076882, 0.1483851328732506], [0.04918316266529503, 0.007254588342602215, 0.06373402602489918, 0.05252283104064484, 0.02817003739877574, 0.07893986008580654, 0.052052728846789374, 0.012137325379186341, 0.05615939679104955, 0.05298868144652056, 0.009814248976087379, 0.028088872298418034, 0.04524401516743726, 0.027876058818712354, 0.04845199685904288, 0.027072880747577837, 0.0789443800045598, 0.03154471024660574, 0.10305419353948486, 0.085182580345821, 0.04202784016548146, 0.03663950712390004, 0.03545174142345786, 0.059326542165851405, 0.012545445314308089, 0.04083037579191789, 0.055282796853252, 0.02035945882990716, 0.06976369723317123, 0.06698476691399852, 0.04822903079912067, 0.042718855303622065, 0.014154104508399485, 0.07971222227018687, 0.021311828693855676, 0.06975569161436251, 0.026277267794695594, 0.08476822637021543, 0.037746312652504256, 0.054107399642347336, 0.020365510924508976, 0.09995896083813521, 0.040716784104945204, 0.03345187272756331, 0.05549597997038115, 0.06034283823664151, 0.025630176307693608, 0.04387057656722684, 0.010792419723715755, 0.0161916398323111, 0.021896840245913596, 0.021463523678962263, 0.08051151244510567, 0.0787437339163115, 0.056005673588163433, 0.02560847495201855, 0.03776025545272616, 0.05831199660596829, 0.07290799786607105, 0.05397015882115211, 0.04243888847169377, 0.04398178955119464, 0.06715132208961634, 0.00559890762932839, 0.01635207971107335, 0.04328513983637095, 0.055125940350755576, 0.03456435496768644, 0.015235346640580365, 0.0415406312282768, 0.028308729956587477, 0.008909054806516057, 0.04353804078193442, 0.015402799096679496, 0.038741778792633165, 0.05285799450751755, 0.026719237324751677, 0.032863934719634634, 0.12073888127962429, 0.05424734092347565, 0.055080706689266436, 0.06995165690539346, 0.02433910748110183, 0.010934907289582395, 0.03592349836722978, 0.03142616197076296, 0.060288541755008127, 0.03219626611098647, 0.028981132988607692, 0.04716760065827159, 0.023072978646885005, 0.030489146424036835, 0.034878121598833994, 0.01179166267731137, 0.08104251862894143, 0.023344141213343512, 0.016718783017788685, 0.014201491834565759, 0.021647398187328252, 0.019826343989059813, 0.0061068732400364695, 0.03235915555588661, 0.04408607710032694, 0.03337225704003246, 0.06103041747044172, 0.04002076641265904, 0.028087525898891113, 0.006880747011652397, 0.008419877023346001, 0.06923974671911809, 0.01735045890053434, 0.039164046456496564, 0.03353634924297372, 0.04034659509817439, 0.043385397763021534, 0.04716669667452093, 0.09890375899211054, 0.0734751710608121, 0.02036076500981806, 0.037768483237032933, 0.003764625007827436, 0.05150737766657145, 0.05108053262736048, 0.02314958552409324, 0.045929859212088975, 0.042764935492267536, 0.0331448974658645, 0.0305090417274304, 0.04425336005947283, 0.11142075467374056, 0.04291972738780803, 0.15804128811484383, 0.046295647043734796, 0.019756430805089976, 0.0036335203115032207, 0.024633509324743383, 0.001957318017957732, 0.011305035009319264, 0.02700598786524948, 0.042310132074259946, 0.043061051457639665, 0.021737735275359407, 0.08074051910831083, 0.08398007511371568, 0.047509183941949765, 0.012740874343792037, 0.02952022331526443, 0.023441930421658104, 0.01820085097044226, 0.05134429669969025, 0.07078560489800668, 0.016830279454288465, 0.040100458708982316, 0.009994371568844205, 0.03519586805674819, 0.055451125522414525, 0.04402687382553855, 0.013581106172604187, 0.03483124467874727, 0.04926902579984838, 0.030546386598519264, 0.044828749547201785, 0.03809499374080089, 0.011883105804783203, 0.01366446324203524, 0.055712522383058266, 0.01951684063721088, 0.06699565302340255, 0.09264533392964833, 0.0610527144594779, 0.06281714518404295, 0.06521319624997916, 0.01788262379235558, 0.060910405966663556, 0.02763943149588041, 0.06005422993292732, 0.02842593949378258, 0.02166793700457821, 0.0448172084326225, 0.02688993703603985, 0.05897627527555151, 0.02765808956727626, 0.07001646028290834, 0.057379326692992644, 0.018777661551270756, 0.03894576119379171, 0.06549700884328735, 0.06527274426433348, 0.014436401205227501, 0.0655652059903068, 0.11192030528740537, 0.06994170542325705, 0.04284953458174583, 0.06504273402594751, 0.012441625078809599, 0.05278313622599649, 0.044399813087957526, 0.059596982694441275, 0.02183302512182103, 0.042513317743977236, 0.02242275960593214, 0.04960814994128962, 0.019082449631945744, 0.08692590534807214, 0.030968704058097738, 0.17181282172039633, 0.05379035798532348, 0.08540552725354511, 0.07114496908240742, 0.017297298144248706, 0.014386684971771414, 0.050569586455822, 0.05185467596616476, 0.043078196505385066, 0.025003426370301077, 0.03153825021018425, 0.020000621330954378, 0.014169927096865593, 0.03173843664567798, 0.05172033861820256, 0.06392319228560214, 0.012485629169180269, 0.04369851704987307, 0.007042621390052861, 0.016672986281675198, 0.0258585796766584, 0.06449147247739377, 0.027171780783382636, 0.02527138477401628, 0.007980639554349887, 0.033084686785455675, 0.06251950087326189, 0.014196693251330047, 0.059231413197853876, 0.025345559322064923, 0.01855626980203294, 0.0385070073177978, 0.08681709788018659, 0.02822083477381497, 0.02050430498897068, 0.06396417798955115, 0.024208587166222355, 0.02980862669045887, 0.041437615385098804, 0.034664072802350405, 0.05695217904905158, 0.04853810131129238, 0.014073810833055648, 0.038035487861282406, 0.04140129132616905, 0.06459671763643142, 0.057143302664401076, 0.03285006469776554, 0.020079658622102394, 0.03026532234563943, 0.01787366247886131, 0.025238975424379594, 0.0476140498874649, 0.005707444093610731, 0.06895722881440194, 0.037435916808223536, 0.028597642780251564, 0.009780028786119676, 0.031612545417080966, 0.05677880952134729, 0.0060115355130795755, 0.02419316964674621, 0.0629496285992284, 0.04156971192588249, 0.06831438911537971, 0.02444273236417963, 0.02601537106168126, 0.029166869090629682, 0.09396724162563201, 0.06600881686374065, 0.04271183410779603, 0.03757125390092692, 0.041490732091328794, 0.0721598287383395, 0.007034926036853464, 0.04368423334052486, 0.008895848408311365, 0.045242973287860234, 0.03122770114831867, 0.031412841616979534, 0.04829491436060879, 0.03400463197800902, 0.06231472940154134, 0.025931664464634754, 0.11349468491971494, 0.01876470317403155, 0.06264390206084618, 0.04932030772549972, 0.036245646000268965, 0.002285421745205719, 0.013066973075300697, 0.010659145322748491, 0.0665244629846946, 0.049469537822709936, 0.02855867763320285, 0.04185875689971351, 0.030212965981674292, 0.08844750152239877, 0.021711134787408576, 0.018346694959027153, 0.06500976926256573, 0.0218976465534539, 0.013615642373840655, 0.018768690661677433, 0.013282171961280608, 0.031310540150790926, 0.06849438147318941, 0.03962870942608964, 0.023010814442269267, 0.031544332948303035, 0.030499498187113675, 0.03325632495445109, 0.12340318952356616, 0.10257183393884091, 0.048512295639563, 0.0450249791385666, 0.021278279788431623, 0.008670447146399848, 0.045213658933437643, 0.03790414208666452, 0.09080288481087455, 0.08465393371279202, 0.0436396048884959, 0.03265466248135894, 0.04304450012803559, 0.05778603511111391, 0.044746563634684974, 0.053285823969711224, 0.0321467500180006, 0.01610457968537606, 0.04133455740708498, 0.034595071263010466, 0.039982312629299785, 0.010500091105519284, 0.06176841678097845, 0.07062569170469238, 0.03201416701138501, 0.005003501700552842, 0.0818703149355227, 0.04985299164188966, 0.03256313029616591, 0.029724874128136906, 0.03351347002711508, 0.08297251627570199, 0.0341630551303106, 0.015152473164151515, 0.03431217414477179, 0.15257912717999952, 0.1440372774677892, 0.20021974499667847, 0.14261158784070324, 0.14689195090003554, 0.1671231225613625, 0.22721861398989157, 0.1273458763476341, 0.17130758673433336, 0.10650391810603681, 0.22457610094739547, 0.1444874154103379, 0.16507052786407933, 0.19580334004375244, 0.26222726931014373, 0.11439188879223601, 0.21172332126767407, 0.12188261990705807, 0.25598351483143145, 0.18916076019165978, 0.10976897717844095, 0.19558765564955052, 0.09643989765355665, 0.117726577596078, 0.08921152100928369, 0.15177815161164732, 0.10371898165753773, 0.2582968398928642, 0.1403804027265118, 0.3561050625097367, 0.14143591866858546, 0.13376933973162405, 0.2737161673365101, 0.20852942410255634, 0.10761568788439037, 0.17466155031035024, 0.10997161509529238, 0.254957631170269, 0.18630181198879597, 0.11591111009399738, 0.13793639838695526, 0.17413756149190088, 0.09008629382738183, 0.11463887553902403, 0.2471159398555756, 0.18076489619430036, 0.11605949366405127, 0.10455826162210397, 0.11753637328623764, 0.12094215504945287, 0.20707724315504875, 0.13083822604629303, 0.14583946866614206, 0.21684920024727622, 0.07071281122344156, 0.09046169223203775, 0.13744544327980088, 0.1626985970764391, 0.2324707136158982, 0.13810889074398627, 0.15961170707258487, 0.18111116793607512, 0.09796093458369856, 0.0988824540869363, 0.1239305031636069, 0.09272675375424086, 0.18589969243734114, 0.12152471128971347, 0.089376229913004, 0.13476548385956597, 0.14800640964700332, 0.09761044935834023, 0.09965617990782184, 0.14852161909784042, 0.1602788164370483, 0.15557391809359675, 0.10761754947804636, 0.1560368956697564, 0.278331785793266, 0.16876828105699632, 0.12860601437428307, 0.2245044104394413, 0.12391164207891112, 0.15967915345343853, 0.15716207964766413, 0.14344066351411805, 0.14645667506321786, 0.1288879960174522, 0.11914258387180106, 0.06077880738303066, 0.06359432223102739, 0.14981509727095405, 0.22752219931252543, 0.10411232950225954, 0.14626935124397278, 0.12911337908477555, 0.17781001846155814, 0.1424086817930783, 0.14564143493771553, 0.15273413741059844, 0.0957171626449112, 0.07983419878949082, 0.16959508911015528, 0.12758530946748872, 0.13940774685432836, 0.10550366774682077, 0.14802189994483225, 0.17894677036712248, 0.07013652158240158, 0.15172758980864479, 0.10412163747053954, 0.1825904224308268, 0.14658953003104658, 0.11267512405831968, 0.13124728635434182, 0.15970671729695413, 0.13384407926951686, 0.1480245046437748, 0.060887534411684166, 0.15561170155002227, 0.09788269402399179, 0.23598357914916931, 0.14635363623740213, 0.1321834151542956, 0.20550936760921634, 0.10601455646176493, 0.20554701316981547, 0.09239177414846998, 0.1465692593445701, 0.15941158958500432, 0.13359677076580065, 0.2393629002354799, 0.1018179268125565, 0.1143779459920141, 0.1070828584112948, 0.12058364888352734, 0.154018085449934, 0.13536226635258045, 0.12566496452857412, 0.18913713404007498, 0.10410769467031765, 0.31795897070438633, 0.23889724135158524, 0.13713053517764615, 0.14995044968541593, 0.1232105490541266, 0.1138377850574832, 0.17488149415341117, 0.10491167330333304, 0.16440662074713938, 0.21640750459365307, 0.09006254510172913, 0.10021369273383772, 0.10047902728641227, 0.1643199302376278, 0.17857262834666238, 0.19371970346377743, 0.14410726726055145, 0.11146691913205771, 0.16284593110603673, 0.11865729781528635, 0.11290440651317758, 0.11387868649176053, 0.10300733960203587, 0.11329118132350907, 0.14952347824169746, 0.06567842612463622, 0.13312070840789428, 0.1518729166878808, 0.13757281305809177, 0.10205889976913891, 0.11425532595885378, 0.14514499464102332, 0.11840747654317849, 0.17288255625434462, 0.2583508031262506], [0.01744611646919962, 0.06813180738038595, 0.029688195753542167, 0.020188812744773684, 0.017260227149592775, 0.030558737851078474, 0.05749540816571924, 0.040389745000509486, 0.029037187642027295, 0.04329050628228053, 0.04923222293596595, 0.019939878219438177, 0.03020798449494666, 0.04071866868123893, 0.02680190778788059, 0.04916120275494553, 0.025036756940666708, 0.03213168681418944, 0.06286201878420769, 0.06854521140696541, 0.014085909276599846, 0.02019515978322635, 0.03608020931302059, 0.06346822798913045, 0.0808601743812042, 0.11474063499800621, 0.02285661051921066, 0.058004653622065826, 0.027269458908948208, 0.018248227762899572, 0.017967362692880056, 0.08045914267460186, 0.03646724076280671, 0.03442645531087633, 0.053769623815652826, 0.06663287208685953, 0.04296573096766107, 0.02225135892419325, 0.01870108531757949, 0.08161603503169552, 0.033116889291352807, 0.05633024205904334, 0.035143096090084126, 0.06834419759651346, 0.02190889655462196, 0.02038130574228783, 0.10504571570744438, 0.019522488620432637, 0.017693654799293128, 0.013894505081548086, 0.0551923793259888, 0.035987324982641206, 0.030326557668646982, 0.04400934190339139, 0.062069159917413234, 0.010804705858801403, 0.0851681012840521, 0.080439017544831, 0.06854569404235772, 0.01783739204608625, 0.02347276354539058, 0.07587849613158934, 0.08147901254555873, 0.04833454408893182, 0.02287646943342782, 0.08878503986183675, 0.02606185153126717, 0.049777964821025256, 0.034502439741646095, 0.03961177888296304, 0.04314611403031215, 0.032930228138162244, 0.06080629844819346, 0.07054978771315468, 0.023185080292844967, 0.03225492929378825, 0.04387067998909662, 0.019353001243284634, 0.025159463158718524, 0.029350802970809803, 0.009032221634932345, 0.026512964320699536, 0.05311844141913518, 0.08292445958021187, 0.053884874082981586, 0.07777372104746681, 0.018253860424362847, 0.0441429284851878, 0.04992994900432326, 0.045101672200666326, 0.024607537028890465, 0.04289387958124281, 0.030292183303484516, 0.008671590532626837, 0.04622137864991542, 0.04774162650949532, 0.021625796423083352, 0.03399744990371889, 0.12024555896078387, 0.03857543812163415, 0.040709736096041824, 0.03187627501545414, 0.03101448738767255, 0.0558692371592887, 0.048928564834979274, 0.038971658796072006, 0.018734195637666894, 0.05938495637007779, 0.08867191931893749, 0.034905493920368534, 0.032476945404684356, 0.009148606669998938, 0.018553735966223384, 0.06843667206985336, 0.021092298538273862, 0.07205685119955771, 0.021661925129592422, 0.047628831553963885, 0.11152781546115877, 0.052908518006123846, 0.05788633134216071, 0.07492715282545936, 0.03653628826742211, 0.023118484269587264, 0.05340607679118553, 0.040699206217522585, 0.014603387305302726, 0.05316929433554892, 0.02975506756845261, 0.016508003501521967, 0.01186083754404418, 0.02337560061395409, 0.04731269388069068, 0.04045921768392286, 0.15839039438193844, 0.04443174363264153, 0.048864224940658584, 0.07707199216970513, 0.02544846216727409, 0.006407337233183846, 0.05532640257790204, 0.005951026058380282, 0.024797224229381933, 0.06797567100053833, 0.0128605286590755, 0.02642791898500535, 0.037191864178185506, 0.03071411771910085, 0.029101416453598972, 0.03878056965467911, 0.030808693188573086, 0.06691458559925519, 0.03946583530294799, 0.035468020791848826, 0.04874084265001359, 0.08724970007014853, 0.037538967125358126, 0.023894720943644646, 0.022064563705615943, 0.08418619873062258, 0.09945788570950109, 0.014086831454938699, 0.022109806943204136, 0.014271122523613516, 0.05218063488662724, 0.03956994665185771, 0.010954493284976531, 0.02539122007757185, 0.02294792628456508, 0.05423979878786111, 0.05344513195356535, 0.033768929706345645, 0.08569629592520576, 0.05095847949926412, 0.11158688084012079, 0.04488481952237987, 0.009237441268088597, 0.017502692062407732, 0.04455439047887922, 0.03780429784749304, 0.005519816712025674, 0.015025662630045367, 0.03269347249560299, 0.025981136507564978, 0.0335405703874365, 0.06553978719297918, 0.056560340397540605, 0.03505232999281537, 0.0568534073329741, 0.05552341357894963, 0.030326653429637515, 0.08638496300385845, 0.02495345828543988, 0.04188356282670171, 0.04620157527707277, 0.01497255837274415, 0.07329584519949651, 0.023324280383906538, 0.012247070347169235, 0.014602133793936623, 0.05016205066274251, 0.01414801698223117, 0.09535635055433359, 0.04252624547769947, 0.07861332276896124, 0.05138059394554265, 0.037865604033633586, 0.026222582523440643, 0.027235996188415636, 0.07685695128935961, 0.04345195548188302, 0.0782450796255181, 0.037954397454497316, 0.01343690831544659, 0.04402194788018542, 0.07230408309448151, 0.014523885573350616, 0.03429165064928032, 0.035370011333256, 0.058968465009163466, 0.021749827973244172, 0.04087832140465898, 0.05968504067089769, 0.06342336588028459, 0.040817225892697616, 0.04505494466772483, 0.012561405798600567, 0.010302336041575239, 0.009323794698913493, 0.016234046629359646, 0.018579715922955545, 0.017241519282481844, 0.07642311569783958, 0.03882381914844436, 0.017487751432664452, 0.06352709801567179, 0.033747931236341115, 0.060130099450508435, 0.0708543306456939, 0.04143715956278386, 0.025991340798716393, 0.025224000320679722, 0.01779493928376225, 0.02909636027329872, 0.02462505745971876, 0.09296367410570384, 0.06032304635511772, 0.11697768068481838, 0.0421164573861226, 0.028818019462989706, 0.009425032260497252, 0.018837291920076937, 0.029241901657153523, 0.03641896190181856, 0.03491355699577159, 0.07094377141085363, 0.05093211075291038, 0.0926411051243063, 0.020721862468147473, 0.009219622062969833, 0.03774997455278232, 0.04091401344105121, 0.03081627745902346, 0.06461424572813897, 0.019623872696331913, 0.002975859923378354, 0.006471129853443633, 0.007619799214280061, 0.10046339909275694, 0.008542638782772326, 0.0387766664367049, 0.012756948783663253, 0.03609573025436651, 0.05750630576644213, 0.08786561943951153, 0.002391304672440334, 0.014493364630447281, 0.022415860984173995, 0.040048387712768974, 0.04398959598714306, 0.022324849738769477, 0.06520790258242239, 0.029040681002962015, 0.08363898212630903, 0.06375813864231591, 0.06080010079688603, 0.03103120534140016, 0.016798592142520413, 0.03762789078116898, 0.0906987504793271, 0.03173759777940089, 0.02853079394797885, 0.029742130258631323, 0.03004350541760364, 0.06578698078350675, 0.03324922331939301, 0.021461840200748657, 0.04539746640911026, 0.036541873048390114, 0.01679082018052859, 0.011612303299649109, 0.07459154502759058, 0.06854103622777809, 0.02005981694486353, 0.032020529371596156, 0.026619900618830038, 0.053341300226748, 0.013698855801785906, 0.04618913783962208, 0.04439984756191412, 0.022823410183792154, 0.0870498736959792, 0.03035603098631386, 0.03518438439876322, 0.00504660324358772, 0.06119133040849721, 0.014935436624763234, 0.056399814333886876, 0.015378383874532678, 0.009619494103976797, 0.02517729960081558, 0.029726519301954298, 0.047814205679441654, 0.017698806740583915, 0.030424032780912616, 0.02199990780002648, 0.02412185260665513, 0.0191531538016974, 0.017407580331388502, 0.01228128191864779, 0.026365103605653972, 0.04991412928868687, 0.07087612584713968, 0.042737789166670655, 0.020210874161773154, 0.03725923395024673, 0.009226419178078012, 0.007740905744984987, 0.10016107781519813, 0.042349646889394334, 0.010569875012151899, 0.038906510678991195, 0.0033394155663348016, 0.020591154461726546, 0.06026053741093605, 0.029872173683777935, 0.04233154423174359, 0.0123435840190899, 0.04141457912121569, 0.04344932396986312, 0.05004983793403353, 0.04276522660567876, 0.061806989307965965, 0.14573892728695947, 0.1020911673925096, 0.14831620028182385, 0.11465234336473289, 0.09674132260824404, 0.15526544513000598, 0.11467252978153768, 0.08992147767135213, 0.16689332682759533, 0.11856587288240272, 0.10950913547628349, 0.1351504277197584, 0.13384933463267742, 0.07859047036617994, 0.14269109244548506, 0.12024628674431194, 0.1835958362226525, 0.15623860662021946, 0.10897403838293207, 0.1892988398791321, 0.10021402215164515, 0.13217569298801884, 0.1362356065862602, 0.23432412545286843, 0.20640849436242736, 0.23557746061874976, 0.18460051457007087, 0.13597483025683513, 0.16226422522337208, 0.12905448224515687, 0.12610102177507457, 0.10254286049354462, 0.22246874628528474, 0.10136235730662461, 0.19148827320145023, 0.13318046326598815, 0.1257662643348017, 0.23990478486784045, 0.10231204586283815, 0.13673082114227358, 0.10141904015214213, 0.1444908474842387, 0.28026128548287577, 0.16053986855812613, 0.16081664080341018, 0.2835107546660208, 0.12646397125096093, 0.07176297987180372, 0.08864531308532723, 0.12150708360657578, 0.135900427797629, 0.11193775677032049, 0.18323205171092866, 0.15673654844924328, 0.16737112054421058, 0.1404109849564491, 0.277393818382294, 0.1472533452174356, 0.1549635758443225, 0.09060003238940433, 0.3175912485007317, 0.2106370698780783, 0.07060276269311867, 0.0671510309762051, 0.1731240731333533, 0.1862787833857921, 0.12744618023956014, 0.14382079634214603, 0.1900146571138213, 0.2127598688727425, 0.2652126220205138, 0.12521409880249731, 0.1718939963968531, 0.1455231049969312, 0.15893886737044782, 0.14303834477980293, 0.19156112816304932, 0.14626824807736183, 0.17365039085909245, 0.11154521331791917, 0.20554523584583115, 0.12268543408642854, 0.18933645479621428, 0.13884059664222503, 0.1835125777870417, 0.17824567734233795, 0.13273807813323316, 0.1196881533870774, 0.15278500564877065, 0.11504130152564858, 0.09615345737866818, 0.11970070956815636, 0.13336804755512746, 0.15927167128651373, 0.16470677399587247, 0.13546173520866903, 0.13117542730704432, 0.1906869299108944, 0.22546197437951643, 0.10900701846807234, 0.19192004035557472, 0.11084516983359091, 0.18794514719517003, 0.12465993378071055, 0.1329302895934351, 0.08872778245037602, 0.14924938730414838, 0.17025501256988895, 0.19205343158495045, 0.1897678542281351, 0.08498813190888013, 0.1168495218359655, 0.2230336135553737, 0.15285645100858905, 0.21177187592031496, 0.08979966969139154, 0.12948012069588707, 0.16465023670706058, 0.16779125848364446, 0.26899967042188494, 0.22552790390628003, 0.11394181213672123, 0.12542192313459613, 0.1287973065289759, 0.16875225449762038, 0.12289546475174928, 0.15256523034505307, 0.12180821744785195, 0.1076859228252884, 0.13427575449309043, 0.08369244740254457, 0.18861077034906035, 0.14515754316122303, 0.15350685965630317, 0.1667890316175838, 0.14192262964863933, 0.1906744426777286, 0.06905285956998987, 0.1292904832911107, 0.1319209687531956, 0.16508946555756754, 0.14640266586455608, 0.19214317112440066, 0.051367218050384716, 0.12345378963096489, 0.15040037312334584, 0.08695483282809296, 0.11915882493579581, 0.16032426077271664, 0.09466332443539174, 0.11529424077560825, 0.18433158706513145, 0.07280380224748965, 0.1490883556224646, 0.16855457316963904, 0.14457752267199178, 0.16822394494327808, 0.11078454163526336, 0.1699871882315605, 0.4714401817369846, 0.08087370349394699, 0.17815572329826895, 0.144141833147695, 0.16436716721903893, 0.22105955819208778, 0.06837347747697946, 0.1227979647416261, 0.1678866364302174, 0.1377343043925301, 0.07552546749432242, 0.09267748663983039, 0.20895092567849546, 0.17471330721051465, 0.268584358836374, 0.10294150966670244], [0.022845128776445504, 0.035464060117280295, 0.05233768674154436, 0.034465866704140945, 0.058334661317208124, 0.05022965026118102, 0.05356594018878476, 0.03552915460820641, 0.07579188223087019, 0.020730775901146477, 0.024418824675282644, 0.03980503222274204, 0.025765379335010247, 0.01982254227773557, 0.061306285731975114, 0.03143701743665001, 0.04052120951875564, 0.028186874096131617, 0.032690714579075575, 0.02307894838703496, 0.06556050987133095, 0.08368359908701913, 0.04400822341502194, 0.01856402644226628, 0.008855349170194279, 0.035580888525733066, 0.01672958294230123, 0.027559877095383503, 0.12753107810332892, 0.03868771596781669, 0.024244938038229465, 0.028568144564727144, 0.08100690320134163, 0.03736739790427589, 0.016961196219668757, 0.03345791716128588, 0.038589174078116496, 0.03543810888884529, 0.07319224712949607, 0.047690448005713766, 0.02437682773527359, 0.029662374760054296, 0.07952391785839874, 0.030849939362416347, 0.03985265990899455, 0.014012532417602358, 0.12962547821864007, 0.013920715822267437, 0.038722304837597955, 0.02391010781960382, 0.01255692131141381, 0.015526517508401266, 0.0012744153918315387, 0.08605595888389696, 0.029605059891999252, 0.025517034697376435, 0.032600726061049974, 0.03459309858660545, 0.046698260721900774, 0.09890388156617842, 0.009508393160367926, 0.021536997256560192, 0.0357092542183255, 0.004602844419423491, 0.0437325083710734, 0.04349817356635486, 0.04314795647177004, 0.0317179131501865, 0.013967302586552838, 0.0287875215027241, 0.019249571712627526, 0.03129396392332931, 0.00958594998660227, 0.05471075516975215, 0.03154624816811374, 0.007019364875891517, 0.03940180567423663, 0.05199205468318636, 0.014326448435895147, 0.053755600576198874, 0.05737116019571981, 0.01527119955543669, 0.010427746549999763, 0.009876590338535607, 0.01156729563409763, 0.015000457379726634, 0.04124032859239848, 0.026081342723280675, 0.010505138667330388, 0.025335402911408775, 0.04697891703296093, 0.02609047257611829, 0.053963348299505255, 0.06110136870354895, 0.07329238248207877, 0.04652299895702351, 0.05209770586882388, 0.05534309946421174, 0.041862560526257565, 0.028708099252394134, 0.025541130077814864, 0.027733122133800102, 0.019060692734896176, 0.0023940525340637375, 0.023855064402244264, 0.02586899081154937, 0.028387763417295875, 0.07396890706713162, 0.026431038878076983, 0.07667744922782145, 0.014677610691456545, 0.060153001649004806, 0.05507690306272238, 0.027144728303556482, 0.08365097906320326, 0.026597109503082694, 0.02965955172605332, 0.022109128955391147, 0.023107061898636243, 0.05850971623834583, 0.013693429026452285, 0.017441462485059615, 0.05004519927165201, 0.04760849958045348, 0.029541537796537724, 0.020749288415836713, 0.011488277495147721, 0.0038017110848393774, 0.11411624269620066, 0.054831061617381154, 0.04939092571035989, 0.01957059128119821, 0.05461237032807643, 0.10163981903104052, 0.051181192750171314, 0.019493166605130802, 0.02248595994446547, 0.02633393914889424, 0.0476823466259145, 0.022605371984442877, 0.022299967202988845, 0.03528126387766773, 0.03337599554910295, 0.057810128576332526, 0.10400415788735114, 0.02892411114918369, 0.031922657808829705, 0.06008221895524091, 0.04287289260255714, 0.046559863107939886, 0.04974653223349203, 0.06511482289962231, 0.08049959211700386, 0.049570772511463974, 0.05266258846067133, 0.030830653098922585, 0.021285513573656642, 0.05176964403700925, 0.030758836186460914, 0.08555355076227458, 0.06300161915620969, 0.08894570382131685, 0.05029401313813944, 0.030895873994356206, 0.04458147168700253, 0.05772603893532388, 0.08067768457676135, 0.036672429752445994, 0.04509215738864676, 0.04489127381314193, 0.03858843480326957, 0.04880382656870831, 0.03201830963183555, 0.020499978507418307, 0.02592193131755677, 0.056581890450850617, 0.013097616592271915, 0.03685361337697795, 0.04452648189579768, 0.02996235372378461, 0.019264307413851062, 0.0586520821877545, 0.055367572142952876, 0.0349768090452398, 0.034078413905996474, 0.027371953812337695, 0.030766792009554567, 0.0024627304012556713, 0.023592024283002944, 0.05333188883659821, 0.0810677305825295, 0.01596304302614543, 0.05920505594281901, 0.00961275827590256, 0.031201573719661084, 0.016454865727874062, 0.039663723474668885, 0.026778205027503353, 0.019661949181388465, 0.04165015498837156, 0.04168238430734604, 0.03976767777555412, 0.06022307188099912, 0.031407009772655946, 0.03400363606370745, 0.06554649812319586, 0.06982789540122594, 0.02828068156245976, 0.06238612113520504, 0.05394373261820405, 0.028955239216767015, 0.07009532137383377, 0.007056397566151235, 0.07604111361527637, 0.08705512139826052, 0.04721698651631032, 0.02848401278888266, 0.010786522761918606, 0.07055655993040531, 0.06903539276531628, 0.044116954274115064, 0.036288554584907914, 0.09030354870182854, 0.03306468806019233, 0.008076650481070242, 0.0711101733688866, 0.04812749350563653, 0.016174837608911818, 0.0444970985934619, 0.017689159778397412, 0.024395342165183638, 0.0803788106948618, 0.06186723829277101, 0.006753124903151465, 0.02815777233110801, 0.10527500582318153, 0.024412456569412065, 0.05605274203023123, 0.014323830330413918, 0.01135612924342915, 0.038276008825989506, 0.07250125880443281, 0.0399590312172809, 0.030316659812665278, 0.04818587706634595, 0.046497963203658024, 0.023752793579572634, 0.10188684408222476, 0.06239866582496513, 0.02977060957721645, 0.024610068949480212, 0.018481840529749473, 0.02986060958656092, 0.0701467641779492, 0.026364107691352407, 0.052649361952658624, 0.0577228749921966, 0.027590122246634097, 0.013739217144076624, 0.03237647680385459, 0.02645321137782547, 0.031511341371843894, 0.049763416811343164, 0.04901496423107963, 0.0729368410764202, 0.07158169282540199, 0.03544637497754828, 0.013108485464697645, 0.06080565493433707, 0.024590323033231883, 0.044132551824253415, 0.02632131210468229, 0.04263864206751028, 0.06322755763727812, 0.12431307215123408, 0.03365616156389156, 0.06182700718542742, 0.05052401188520655, 0.020119573718177217, 0.024355779469553984, 0.03278672071774641, 0.024388569947933, 0.0557030075710387, 0.029909127850025415, 0.03619000886476809, 0.02507186291979686, 0.014069975605384718, 0.07489407314888893, 0.055239083876292554, 0.06133646576575214, 0.01669558587544147, 0.04390332682598983, 0.04717700055710251, 0.0074670216511754746, 0.033182274895690145, 0.04604805891792621, 0.05063730479788877, 0.05292707648608954, 0.0696891109128633, 0.006537041185619009, 0.03260973908547913, 0.022010194445629756, 0.015951451158241158, 0.027320179675195008, 0.046531410602432106, 0.055989444015487555, 0.037317161688641194, 0.018145740520389333, 0.05288045237501783, 0.0661389752020759, 0.03303050138657132, 0.026386944772375208, 0.03675909727931984, 0.04393680869872051, 0.026748808318628903, 0.014891923788274008, 0.03664838225250283, 0.027981269503793413, 0.03872348078256173, 0.038737090334536574, 0.04736505215987564, 0.0443010337110008, 0.022139464121972843, 0.054258525807170145, 0.022321909876360048, 0.019558040845778682, 0.03650331201272146, 0.03703901048509344, 0.04087005531595599, 0.024685496051285057, 0.07975358335721879, 0.08373296579285976, 0.0507941804525833, 0.047249595048807325, 0.0519529918599273, 0.032323409893339684, 0.03622180151362573, 0.10066685672368735, 0.03398528825792094, 0.041917757161201975, 0.07299255865115313, 0.060632005784540415, 0.06056043785065413, 0.05619701936901097, 0.04109324354137625, 0.04221170126730877, 0.022436367242687175, 0.04435706155134305, 0.023386743362812747, 0.01831631191195019, 0.057101834325059775, 0.060742502476299004, 0.10123212235949694, 0.09788417257368566, 0.13295177069883193, 0.0956296447604414, 0.1395913628080199, 0.15721323899924755, 0.23096216391892205, 0.11954952211629961, 0.1276919182630316, 0.08678147479170754, 0.09091864069623333, 0.12139927971387103, 0.09008133723851174, 0.14662267099465096, 0.13095488591540244, 0.08155917598595543, 0.12556610088194572, 0.14743549028231254, 0.07417768134825653, 0.14757859550656813, 0.16931618714044172, 0.13273463073757388, 0.07039178973965107, 0.08309710515482772, 0.1404817714806526, 0.1455777883529663, 0.09376747653849664, 0.12492978059115911, 0.19833414214512995, 0.15998122192198233, 0.13947939139700707, 0.06092671597857149, 0.269526585696205, 0.18282536627544513, 0.11061387256749215, 0.16510802020709361, 0.13599068827686772, 0.17166394019319167, 0.23739650575143678, 0.1130963038773306, 0.12307015578112296, 0.2736850641667843, 0.19766085811199682, 0.14745580693406446, 0.11221717967982255, 0.11593777761464158, 0.23797894707850872, 0.1205278393782435, 0.14007295632073957, 0.18140022823166463, 0.14881055681936203, 0.065933387846716, 0.08241569292881797, 0.26211296899184106, 0.17497530928061855, 0.14835237495360837, 0.13358367066229546, 0.06256843856986492, 0.1628918657379766, 0.1759523471757289, 0.14924358035768234, 0.1383633391871568, 0.12658551876102725, 0.07397070737375368, 0.1846017556325082, 0.23702666914511114, 0.2147710182133221, 0.12938307267763924, 0.2075606906005452, 0.09137850795542041, 0.16404752469351216, 0.25550035849934627, 0.1036008738822514, 0.10851461545474107, 0.1343646973010994, 0.12174190487712623, 0.15431918864769323, 0.14520850332994617, 0.06150369892918295, 0.15506367289250897, 0.08127078984773929, 0.12318260982752809, 0.09545328365939279, 0.08096216366656366, 0.08267119091244475, 0.12119902433046412, 0.15109500036604945, 0.18963110753365103, 0.15470476069998357, 0.1507035447585006, 0.15054625158588733, 0.11112012645049442, 0.12639300852653482, 0.1744624134153128, 0.218952264817011, 0.10349523801837238, 0.14122556624633653, 0.12454774786507893, 0.18751327278873614, 0.1122163676266228, 0.2028033305560389, 0.13340040710904907, 0.12571920355361316, 0.1322380372232968, 0.17892614728020084, 0.20308669115747177, 0.11262928901780998, 0.09968564364938967, 0.17537566682984754, 0.11132115558270486, 0.10929457723133026, 0.16646183546512358, 0.12107145536931292, 0.12948796543623173, 0.1787090992494937, 0.14210076041279301, 0.19476947374641898, 0.13172904840640484, 0.07023317889580805, 0.15536722757162588, 0.08717470006236146, 0.13043762334892828, 0.22605380794454008, 0.1487420379154144, 0.0958744788001622, 0.06587570142601767, 0.13532341037306095, 0.12762188250499387, 0.17850389493809593, 0.20637933705602923, 0.17531031952990642, 0.14120544877744493, 0.1146672897401356, 0.18333501392795196, 0.12328109809107358, 0.15801297350516244, 0.05514493933127773, 0.09021680456616225, 0.08098253394447028, 0.17480678525903534, 0.13181370112203783, 0.13331819055301528, 0.1260021657893254, 0.18937232303282908, 0.15050140479879995, 0.20419830005736123, 0.117008967715646, 0.17034758663465902, 0.12471948179506487, 0.11376108433450423, 0.122941016339727, 0.11026143381792693, 0.19265936116778082, 0.2694973824245315, 0.13510939605053396, 0.13352976871594308, 0.1386566436098468, 0.1346219189825558, 0.1403388807610158, 0.13974496343683812, 0.1667536843207575, 0.20459399979201057, 0.10161846816059082, 0.1311163619280823, 0.11285280283059805, 0.2581624374274285, 0.19726318187050282, 0.10503292969998815, 0.15140941817193262, 0.12922447715555468, 0.09750180276891879, 0.20300346336537795, 0.04428385418929881, 0.1697786284550544, 0.13456832347137315, 0.12880876720432313], [0.0353783693525099, 0.0462148783938779, 0.06832454744125567, 0.032440016136294415, 0.06446666655040557, 0.05481045002177839, 0.051436146811371854, 0.047797780754345084, 0.017106590131598137, 0.03204581218831722, 0.051359430766634406, 0.04177235750361316, 0.04506943905125222, 0.0611217083379386, 0.015887365030545383, 0.032228058759844115, 0.05757135812253241, 0.03373588833417143, 0.015966421473891507, 0.05744097761869912, 0.04298843781373674, 0.012464155724662687, 0.07087359775698955, 0.028669413727437778, 0.015287916551554396, 0.02451512575780432, 0.017475762156649463, 0.07014512474979125, 0.025789760083200473, 0.028371106750602205, 0.03970523777928564, 0.052778796337905436, 0.018166671957700484, 0.01822235888891643, 0.013829512097271941, 0.017333076365532416, 0.024436678354358, 0.040108751610762654, 0.04898578011160416, 0.02599207049746427, 0.04368042205310157, 0.010951068871954997, 0.06410873111998362, 0.020974127560733788, 0.04688078500030022, 0.02853317648142336, 0.03965258455624984, 0.03389587047539892, 0.028696607933529926, 0.02259157857136621, 0.0727080948831093, 0.09229089569060073, 0.03462195328827347, 0.05618830511887228, 0.06159929521081429, 0.03964128092892709, 0.08462205679426271, 0.027332190018627914, 0.052641007763844345, 0.038963036476484234, 0.0785063462512147, 0.04190172294094678, 0.0783391475617405, 0.03095346848450361, 0.05386123644007791, 0.07514613905861493, 0.027458443223769148, 0.03634641720582882, 0.046054034403735594, 0.04230871481160003, 0.03260954756349806, 0.07622697420658604, 0.018909344404575326, 0.040634931440675454, 0.026238949991942897, 0.10796458730774541, 0.021014517631321665, 0.06063181426255934, 0.013052073622783347, 0.018477391474129214, 0.03995305573147151, 0.08326079516160874, 0.04755634048412885, 0.06584361000286956, 0.025132383865815018, 0.019202436237866362, 0.06350496956597894, 0.040438789949421926, 0.04175053165865041, 0.04367184569878925, 0.06457287698022782, 0.029902849759485935, 0.028619721434229327, 0.0468526121168848, 0.06526951137329302, 0.014849903865627226, 0.01911672057523843, 0.06300282957513006, 0.0689499356573628, 0.0334582427486537, 0.12146352384720119, 0.05592765519395471, 0.021185198190411734, 0.021559125706253034, 0.013635905399437875, 0.04399720324023117, 0.03169845451690978, 0.03360687529728298, 0.04921278345488733, 0.03598154867969213, 0.03504304117673347, 0.07774532982899297, 0.020429967647238124, 0.007189917594059221, 0.02814449602738023, 0.0651278693769728, 0.10837436773844304, 0.0637920342025257, 0.027469723868454178, 0.03871712608322982, 0.014869344304315748, 0.08107716878575665, 0.025972052620002822, 0.018022909813049822, 0.07615231127748567, 0.0405322450153049, 0.07644989813167243, 0.013229153888870873, 0.02598105989877255, 0.0673034977948954, 0.05607080638348576, 0.05297928154768963, 0.04682886339123211, 0.04540026263003388, 0.08162358099774969, 0.03692812691893309, 0.00670532388950608, 0.03816632801787027, 0.03511552075524965, 0.0031570983710773894, 0.013260784701654508, 0.08201424753473652, 0.015200815227393423, 0.09197549729217445, 0.05407177272342867, 0.04291649832720718, 0.03255918111291624, 0.023819385772390712, 0.03507903581785579, 0.03568597280630662, 0.06954540047914752, 0.035835647234512914, 0.07362340141328112, 0.06394271603635242, 0.029478739654164643, 0.025374475310766892, 0.09266976447355363, 0.02900744810880673, 0.04721570714947678, 0.06729455754881905, 0.010204615781173832, 0.05804244090893096, 0.04318349529057742, 0.005691165204024724, 0.0642830276140763, 0.07507171361677109, 0.044695300861231746, 0.03663667642901983, 0.034319662654231635, 0.02719429227703762, 0.031132302134327834, 0.023347178751963283, 0.03995744924571726, 0.055673635760021795, 0.030957367872038198, 0.01775664446364728, 0.029160621643607176, 0.043149634204324216, 0.02635567497852589, 0.024911591580377954, 0.04637526273126564, 0.01265112714346258, 0.05027296487241984, 0.05431175742658877, 0.028192204152864796, 0.04293576543850284, 0.03787965791660451, 0.02462770429349715, 0.024421473424280846, 0.03776712343096733, 0.005782087391708047, 0.08783444732187257, 0.03501459633210494, 0.011703590336706371, 0.07020399860677219, 0.05067829433227739, 0.06494035403574668, 0.024235789033193744, 0.08449804248108019, 0.01523922400308713, 0.07174303094225545, 0.010123726472468867, 0.05059413957379518, 0.12434260484071509, 0.053149138562261104, 0.04164914375231151, 0.032351295493783495, 0.043054838484573754, 0.06178008813050486, 0.01600405650078169, 0.02290948973818412, 0.03153954681399609, 0.0196180178693706, 0.029556725489636584, 0.022018663547632676, 0.06366413965400669, 0.06356436053230878, 0.017718179188969157, 0.0855167938636676, 0.02922366301889622, 0.049072344216608235, 0.05911508274655189, 0.04127869427564644, 0.02191492566658605, 0.032976653066373644, 0.0286808897245435, 0.06658358198981132, 0.033250820612715136, 0.048040898757115494, 0.05348622107938413, 0.015415950911119582, 0.033214814480273955, 0.05712015148732932, 0.028759840830800035, 0.025211444139600764, 0.01988591307083205, 0.06855633500362597, 0.07589702013759844, 0.013056745801511551, 0.07937014102935791, 0.049370969119932384, 0.0379437105279536, 0.007082619319384497, 0.07182334760023702, 0.005969521336092224, 0.1014413716151349, 0.024219641814969724, 0.06897468795819629, 0.01625943095273068, 0.0265455843445154, 0.022236485327143344, 0.04610369222298746, 0.021280723608910077, 0.047625299888632955, 0.053542915416220506, 0.03950255772759838, 0.08153705902758145, 0.06429595151735891, 0.03866205968323254, 0.07135267084043834, 0.040981885000702836, 0.07220294416671799, 0.05751152665564611, 0.010997770549429041, 0.027184448047210614, 0.04016620437464407, 0.06866088302265252, 0.1423427063010393, 0.003912827829011686, 0.06343958396164161, 0.09119732050044883, 0.0327412419081215, 0.031967056434481375, 0.029031700537269636, 0.040340956691051685, 0.025682588213033257, 0.13584585169390326, 0.10102258199044775, 0.058936335281619144, 0.014213062635052108, 0.023415548268765695, 0.03375725835681923, 0.06241798273197586, 0.047880472284891916, 0.01283892497961079, 0.022578489959179875, 0.03845494398246369, 0.018367538296227014, 0.0373912577126776, 0.023320030511146592, 0.03188407762096294, 0.04493820435938336, 0.0439556697834163, 0.014936021724415403, 0.010199237843945382, 0.06021114389201807, 0.037070990825492534, 0.06143140704220822, 0.03971443083437701, 0.01724492071286565, 0.03155437636099035, 0.04501276769705358, 0.05757929096298833, 0.03127410692433196, 0.018558665742016128, 0.046711349334087104, 0.031056149164214734, 0.10379748268713875, 0.01771529486793424, 0.05168367748058612, 0.014548728847125126, 0.03442210393146642, 0.07325559493995483, 0.008306699023852426, 0.019720120152698892, 0.03889840163831269, 0.03791769418204504, 0.028286710674423846, 0.06500660531943844, 0.07262876647855006, 0.022131856868884737, 0.0278738486550508, 0.005212104090699746, 0.058244255281263785, 0.037661862950171196, 0.03367858878787487, 0.05341221698589864, 0.05924654726479804, 0.04063721438268981, 0.04027462879856748, 0.03576979814698139, 0.028914439289139646, 0.015807211166247725, 0.010354596644549841, 0.04542746641222508, 0.0484506753573735, 0.015916238884411512, 0.02699501365573416, 0.03491350336961689, 0.02840323456292672, 0.07429241067579678, 0.04151186462672007, 0.02134436253278006, 0.050712166909849456, 0.026159790126726996, 0.038053659466846336, 0.02586801404944591, 0.02570526824603158, 0.04716403834942368, 0.03342358493095925, 0.05720163259895579, 0.03508640941412699, 0.1634360026688345, 0.15953748847448057, 0.1611636020243168, 0.11045395937417785, 0.14717635338104543, 0.14026323723937237, 0.11457069371376308, 0.09733236710270567, 0.11396674829865656, 0.16744705517926525, 0.09493110280844475, 0.1622164979456894, 0.1371976444798131, 0.14365700674393486, 0.13884088775563624, 0.13639682212904577, 0.1564687394326733, 0.12828128502493905, 0.12715910411169454, 0.13444270037354963, 0.13817167931026028, 0.18048907389804242, 0.23167839484109035, 0.10037929796042944, 0.19167147546766267, 0.06899921043265252, 0.1579668856556377, 0.2515960220367678, 0.14089565814262436, 0.1400553669419981, 0.10916715382688469, 0.16291494030625592, 0.13803974364794072, 0.1489196324180211, 0.2782493853761304, 0.1327739004045725, 0.12410746181323645, 0.11839878144523791, 0.06799547437338099, 0.15747839735159952, 0.0783498498100427, 0.13163809844803426, 0.15112611885753371, 0.09335983349310775, 0.11227100501738249, 0.12008133269245587, 0.09247615873332947, 0.1258157306320725, 0.12453019679073365, 0.12970069273104592, 0.1488642749046126, 0.14111782364066572, 0.11731672055658796, 0.14460822747599694, 0.12239984416913603, 0.16420129386167373, 0.17473446655898325, 0.09893090914814703, 0.10642671176502783, 0.14293617929422087, 0.2898057604268674, 0.19354748689839918, 0.1493224261268493, 0.20313066460432547, 0.21357276476919654, 0.14068760398414829, 0.09027211611429531, 0.13643483541184856, 0.07010741790215816, 0.16689101324206398, 0.08932259609742511, 0.13463595371332862, 0.21037083900263234, 0.11459496337920429, 0.14546682817801354, 0.15628144625694523, 0.13329765939664456, 0.12646422405997593, 0.1506362515952318, 0.11210177619490894, 0.13967983064151582, 0.19767074064622003, 0.1764240275107084, 0.1395551574927184, 0.19359519885432339, 0.18165961028106753, 0.1668641695211972, 0.08446180652226172, 0.13784387028746067, 0.0761735089303505, 0.28937886559194137, 0.16757362822611488, 0.1563801796686265, 0.1371434820635665, 0.1454984829310448, 0.1418216132949437, 0.13639533591847267, 0.12338714764243174, 0.19312698123676164, 0.12955021774095873, 0.18393984034417138, 0.115615522729293, 0.1274618314158532, 0.08197520003323594, 0.15112101671195802, 0.15011217084623155, 0.11979735922068359, 0.17730744946147167, 0.1227438253080172, 0.13537001916237418, 0.10806950304897563, 0.10936297356121003, 0.1680815751634298, 0.07194151666255728, 0.12105744362117783, 0.24918194109153366, 0.12592387926434317, 0.1856901980335674, 0.14981267643311333, 0.13200814955897872, 0.15386181883513927, 0.1824788187420176, 0.16713279059096692, 0.1036918085188635, 0.20996753967577414, 0.1280850516031346, 0.11588752224680879, 0.07397060778232352, 0.09070055078594916, 0.1376695546411699, 0.14787614405635865, 0.11015631123295716, 0.10776260822650888, 0.1372775321285571, 0.15282674211888544, 0.17762620332500628, 0.14042924849256394, 0.13243369607915803, 0.09815733654484635, 0.14866041890796156, 0.2322243397394496, 0.09721003052207733, 0.23505212348555368, 0.19103343147904644, 0.11861313284645159, 0.11208254738800949, 0.08210261577680227, 0.19229444284592906, 0.09620420304277251, 0.08605230464449815, 0.15206773284702532, 0.09585895019793704, 0.15978292772366157, 0.1613253385068909, 0.048670607709115556, 0.09118967494296451, 0.15605664541644437, 0.10771272058087973, 0.17525035016719373, 0.12205392482780641, 0.11196898251411416, 0.1482070021090969, 0.1305641963957779, 0.2309127052825305, 0.2224760394423239, 0.18282006494700911, 0.09949129480387896, 0.12274115166116147, 0.13516568819121008, 0.16622505300948698, 0.14673887121100582, 0.0656503796457283, 0.15235593512413964, 0.148127589434866, 0.12217099072351573, 0.1747069640025016], [0.04132408115472044, 0.0329373795689354, 0.022303857014424378, 0.050817691690979466, 0.044562468876040755, 0.05366150965733875, 0.05620744965610005, 0.046024482562056476, 0.015353743614058103, 0.007200092678108523, 0.023172324928905697, 0.09729229304338656, 0.029831304808237383, 0.03484881107485102, 0.04924517365232591, 0.11253881403395247, 0.04387134648559075, 0.0549548652563845, 0.01856304201928358, 0.024224240257735216, 0.11961018095814413, 0.04222212389351861, 0.06034969089312419, 0.03296489744717556, 0.039110075562231006, 0.07870969662983572, 0.029382398352026943, 0.0055384340850005475, 0.08322533295159379, 0.02133847323186215, 0.06282781295838856, 0.014428978770851128, 0.0532253987846836, 0.049208094996790734, 0.010054500852411073, 0.011651455180629367, 0.02311704976994905, 0.03294378789442201, 0.04680930899696485, 0.025616794666876237, 0.051596780127334985, 0.021955369363328623, 0.03991435296953686, 0.07342100864456547, 0.04450533403864792, 0.04522809202993109, 0.06496769571376425, 0.03517918649219698, 0.024308006226595853, 0.0335124358084173, 0.06657766013015663, 0.025928575215080095, 0.02439458756857822, 0.0022985096391846217, 0.05150240958638249, 0.05499605397363344, 0.061269712694469965, 0.02867370765025337, 0.025908490304925272, 0.025212809691325794, 0.04046166533484094, 0.059807561112627874, 0.01584487683665488, 0.06596351808477795, 0.013372191122823186, 0.026836994614812638, 0.07383177732868541, 0.014410615643306125, 0.0502223800867796, 0.05666958836598262, 0.009065421012740944, 0.03671842950185941, 0.04217400974143417, 0.027156604581602642, 0.04528129683627237, 0.03704247703295081, 0.033055073656742616, 0.055606419205545425, 0.005450330622073624, 0.014837442487928898, 0.02736590746339531, 0.05268773912722546, 0.0793516323451073, 0.04349292969451316, 0.02532741261435853, 0.019264564053305698, 0.030463578239563974, 0.04566871516046025, 0.0356056101830496, 0.033682890371569706, 0.02162347326145297, 0.03745097426637527, 0.04700682561604246, 0.07108570452058507, 0.11626710349153127, 0.005893422949743728, 0.06579111765829787, 0.015980697522360473, 0.03603376140217147, 0.019699797755287542, 0.021274951136400624, 0.04637094582581232, 0.05456615990448383, 0.017162382399903673, 0.04878771190922107, 0.06172029496801477, 0.08779687837006585, 0.033539245055327495, 0.06241368880916027, 0.0501707649128812, 0.03744820102808937, 0.036395224667484724, 0.017233375767846743, 0.04415143972202655, 0.0032418801246451275, 0.032466097599676544, 0.0121624281652452, 0.03324922714983264, 0.053817082962562005, 0.0785562951838778, 0.0609734664941507, 0.07739505910825345, 0.03336829636546393, 0.04544737320693751, 0.05010575086118714, 0.07365058221283459, 0.031293586625026605, 0.0664198919830303, 0.06451720537077035, 0.17339511504096372, 0.07064384798849783, 0.06745470822938988, 0.041321901634575865, 0.024901375797907674, 0.027217581349935745, 0.023954837778282743, 0.04630688938402361, 0.017791959201736797, 0.02995328132754132, 0.03183227092508347, 0.010414307452588072, 0.04257984481932175, 0.038199151054986065, 0.08079088938933227, 0.03989616221177482, 0.03775099344972161, 0.008962132250739923, 0.028550934399508184, 0.005144807096991328, 0.013486651361980026, 0.01571824633321094, 0.07464338619742664, 0.019788271334442883, 0.024550204923857125, 0.024144708839876038, 0.029395657418776425, 0.012526375470652938, 0.025528376629095406, 0.02383215645808847, 0.01630193351076976, 0.029616014949316462, 0.02433730142882034, 0.01322978878423812, 0.021965857107012023, 0.02418292130553915, 0.037713175519339504, 0.023703712241483793, 0.03126916757244016, 0.01702993154345501, 0.0005643444150806435, 0.028470219375805992, 0.09714828383538032, 0.02387774060480297, 0.060519180185492, 0.04177448339760304, 0.030267549746279276, 0.07227648094656967, 0.025039556992029952, 0.041406171306246714, 0.03312843423637171, 0.031171635003580205, 0.09281538246620087, 0.043053719996204304, 0.045258298876785466, 0.08396312158795134, 0.029411927211068334, 0.026659905730235963, 0.013819080852572958, 0.04349747259590415, 0.019744864792653152, 0.024863465936974655, 0.049177164196847915, 0.01620753615673992, 0.033531396484543244, 0.024861096810068817, 0.0727480770118775, 0.03663067413013309, 0.046659213220400196, 0.011918421500482628, 0.04642385568830275, 0.0474571282674949, 0.06049970623045679, 0.10555504160302301, 0.05232392780242428, 0.05942179753835644, 0.0796699878429213, 0.022060660487641732, 0.03476935626578427, 0.042900525393985936, 0.04232400592656867, 0.03248195945014877, 0.013837859582816883, 0.04121468762957281, 0.0312363330440055, 0.015776975591096188, 0.019884103188110937, 0.05301767404401495, 0.04457316729390333, 0.06278788445577507, 0.02343752541609349, 0.027382493266955982, 0.05139508832907004, 0.037814624712712346, 0.015752837118212015, 0.03085481168161477, 0.052015048812233636, 0.04794410354788265, 0.04701640554553559, 0.02052674944993229, 0.0638699951401401, 0.04676096118806351, 0.02377589496092931, 0.027389058640467066, 0.03979533354962065, 0.010293267475771568, 0.030044357690419403, 0.03375642715142139, 0.023028214214249484, 0.021531176903555473, 0.03292707185591421, 0.04653109650638315, 0.047654514651625395, 0.09802294940116907, 0.029890502337366346, 0.058336442471632076, 0.038014110177755356, 0.06212435272191802, 0.04093655174778354, 0.06778514493376979, 0.07751282980485309, 0.030728462715483004, 0.1443187841364453, 0.009036393941289956, 0.056827938739931395, 0.0269365860449691, 0.03710906156488965, 0.035122059315683386, 0.030843599984842925, 0.05775336146114334, 0.012397573107943661, 0.025648204271771738, 0.08398652557403812, 0.023906024570967403, 0.04333625322267894, 0.04388133244168374, 0.018320222790803642, 0.01572388378272374, 0.028031264401731953, 0.06254732135623213, 0.01318282089121039, 0.029192745625492067, 0.03642193815340439, 0.015764385893670543, 0.04272247123862467, 0.102493999405734, 0.050250499344040314, 0.01287592223830401, 0.04748799778040379, 0.04673405618016278, 0.0361684971158543, 0.031658298103138804, 0.0212996268284417, 0.0316948615645449, 0.07451674420266383, 0.02975036570381734, 0.051750782952313466, 0.03455996528388031, 0.02963819127950457, 0.03337318017598122, 0.029208571086787892, 0.05373036180953345, 0.041772319199216944, 0.045406471772660176, 0.0703874460211204, 0.011228566985547302, 0.03806939108237144, 0.023892156464318116, 0.05034294317386324, 0.07367433093848728, 0.01463144719074931, 0.026207456117375728, 0.0684913554258885, 0.024251922844879092, 0.0521067648585285, 0.04915823799467856, 0.05378392284675952, 0.07483303126308226, 0.030582513389808517, 0.055705275191294576, 0.05928724185533582, 0.03085909794355112, 0.018144790571363225, 0.038840914400474685, 0.03512734532236092, 0.051075794373548804, 0.07769829203044215, 0.005936255883200155, 0.12924687756646064, 0.021294892405069644, 0.0711508909420621, 0.014914517636380851, 0.05615402651470035, 0.01517873848863547, 0.03448166726757923, 0.06711486396529982, 0.016612800499123913, 0.06629459830301423, 0.040754785896429134, 0.04495661728264344, 0.03782522353914477, 0.06185583507401809, 0.05726738592549678, 0.02808058131185751, 0.060504930950100386, 0.01974469816852962, 0.020167827681307832, 0.0296532123484799, 0.03389723794234376, 0.021770625345168576, 0.05420632840644929, 0.04531053458190253, 0.030623016458365227, 0.05086177239014257, 0.06920705774738904, 0.039734605759862936, 0.03620692791657583, 0.025743497948672985, 0.08088901759155336, 0.04979344362753534, 0.07106766314996828, 0.06408498239433093, 0.034464966550829916, 0.12613964792821677, 0.1077355346792648, 0.13799051483792646, 0.14147966228906186, 0.15411176268131505, 0.17907129029833502, 0.10418586628211123, 0.100087495070071, 0.15176998511437448, 0.11283680691473907, 0.13262635187035607, 0.14557906005892063, 0.1453660416506952, 0.12903732187565298, 0.21896233121233605, 0.27267922136572104, 0.17043415457010272, 0.13849840048820744, 0.11571542825549842, 0.12831332282193247, 0.2188056355883037, 0.23637129624764766, 0.1264889380564132, 0.0935904489409539, 0.1312654119946303, 0.11845402404545777, 0.12461338627843127, 0.1266293619729338, 0.1832521385363033, 0.1394240951706325, 0.10742902290076019, 0.061858592990545504, 0.22222931316543013, 0.26171009867422046, 0.08223736298180397, 0.10207822050658927, 0.0764384221345667, 0.19595631248047277, 0.14772113382575974, 0.09282567102702395, 0.18270729680455502, 0.13540850741969002, 0.1031709606609037, 0.14611300802038563, 0.17273600363442976, 0.2051400519426792, 0.1879777518972274, 0.10969524121572895, 0.15415781988732277, 0.13403766968798253, 0.12720862403512, 0.15317845308492262, 0.09403593672980225, 0.18634137276920582, 0.19122362046712832, 0.10313134625433915, 0.17964836900993703, 0.1779916119431296, 0.09055330868690245, 0.14915500527187703, 0.10202338393296927, 0.23343497316443154, 0.07433958637017397, 0.1568932593950341, 0.12632550851952645, 0.15712277933714852, 0.19660099079051327, 0.13808731770803853, 0.14230575021957198, 0.12237274763925422, 0.07387426456496601, 0.15028982663587218, 0.18255829270328247, 0.19328238983308116, 0.09827107761896427, 0.27127954808454363, 0.13744902857128652, 0.13060939558331044, 0.12622223986733344, 0.09627325054738792, 0.11786746882623243, 0.20107377981466634, 0.1525352916289722, 0.18690752706700758, 0.0924991260492994, 0.16034774902847507, 0.21083430687506355, 0.07859906587269037, 0.09018638321468908, 0.11548237664805305, 0.10616189049136256, 0.19305274731689887, 0.10006569220774597, 0.2519946482272879, 0.21731459866127661, 0.1581683361362065, 0.1924693253972838, 0.21091572669965608, 0.1635232141181346, 0.0973667184852304, 0.10862475591561488, 0.17193053879084128, 0.15940068049296258, 0.19985574598033584, 0.13424083620550173, 0.13809312465450457, 0.1952257863576374, 0.17974924746780627, 0.131578772599178, 0.1802690074809136, 0.08102774079288207, 0.09647243340770084, 0.18107289418337807, 0.18787316557380462, 0.11292060927277613, 0.18549159740007695, 0.12842596839031867, 0.3016992754513218, 0.22263612117498155, 0.1334884459333074, 0.1463042695315615, 0.12714709185304182, 0.19340891691465534, 0.14034274184415418, 0.07500262014688024, 0.1888745650649071, 0.10921122686516856, 0.1249913280949958, 0.1492076508340336, 0.38577858959474876, 0.14934959160464426, 0.14513889658114604, 0.1428374458825396, 0.19247341630679948, 0.13753173542359184, 0.11730161330272114, 0.12019424639161556, 0.2042417678861849, 0.11532761922646916, 0.1773915046285237, 0.14505913150646996, 0.17298387904320994, 0.09893571251943227, 0.223417132492027, 0.1609650167125848, 0.19311090871211023, 0.13310128041813452, 0.10541954363185553, 0.15115293193488352, 0.15754127784842448, 0.16821697354316714, 0.13092974290972756, 0.10322126199401195, 0.07157599313124534, 0.17216166751759668, 0.2531671457953992, 0.15549225312086845, 0.11825756845815528, 0.1436745195138839, 0.0765735830270475, 0.11822067366372194, 0.13725626552777906, 0.14551826332124973, 0.20574270266919367, 0.17034116681785355, 0.14311368186627665, 0.22077978288214054, 0.2047184584361892, 0.16348696283755765, 0.13168231704302374, 0.15704247800092544, 0.21889920556737533, 0.08669526691758826, 0.14940985208076818, 0.11845047705836835, 0.13504032556328083], [0.017007056158035994, 0.052073148920411066, 0.05485241248783085, 0.11793634779150448, 0.024317429108064503, 0.006976692820899189, 0.009494587298362486, 0.04430399081038852, 0.03841504229292755, 0.05010548273041364, 0.06312911150856845, 0.027997966390103105, 0.04796936146674618, 0.017633258342562665, 0.060535685549820625, 0.022123397342980872, 0.05547472486092199, 0.007316717594456409, 0.054092591162770993, 0.03878656429268661, 0.05724355676061204, 0.03662897341494118, 0.01972697280918158, 0.010018615378817965, 0.07013423864038722, 0.029202819681696357, 0.048384496852034525, 0.032787345079404694, 0.03929011771575578, 0.02210876123318749, 0.03712973827796598, 0.03803211707441557, 0.14285688919405784, 0.02099467020842337, 0.06797338039764474, 0.07806979870844273, 0.026656002512261755, 0.0665145498069544, 0.03481569309388438, 0.03431323517654692, 0.07528427237224194, 0.09800009699838777, 0.038065974330229145, 0.06302416512382127, 0.03890569096491222, 0.03750609429252725, 0.05869204133388497, 0.02118543567766826, 0.027613526232720866, 0.014226218279931816, 0.028556902224438328, 0.037543287861251065, 0.0147963150577139, 0.02154766694612561, 0.06765926902693126, 0.013814230558402358, 0.05802045418550411, 0.03564656141304201, 0.05999711424773259, 0.019072408134478237, 0.06510366099856554, 0.043811748675521345, 0.08904518799916392, 0.05587592893730729, 0.06502929684375564, 0.04674511465934977, 0.028447581477643504, 0.041648967552088925, 0.02793551298729595, 0.038891292342375365, 0.04223079217838184, 0.033258240174261794, 0.04523250852681456, 0.03126433164241814, 0.01545960738909461, 0.03543279989953003, 0.04509861934028807, 0.02886351167915329, 0.008830856381645127, 0.05029557595750497, 0.011993192639502307, 0.03971780928212308, 0.03628775402302704, 0.027618547939064524, 0.0618225830276647, 0.04609723027134615, 0.0252804265267426, 0.023145144129352226, 0.0756803857943704, 0.03041677026739044, 0.04811407164520314, 0.05978272071168308, 0.048152069606247454, 0.02159355752800982, 0.0567347479743823, 0.035669992212206125, 0.040725050193648187, 0.04231061470965224, 0.02709372791521732, 0.028239695858510754, 0.06592666159474081, 0.06069129332900048, 0.018060038264300075, 0.018469261366032788, 0.07134005337232543, 0.015999730019229316, 0.10452817734931746, 0.02782000991095218, 0.07984261043489942, 0.041215947844208255, 0.036816902443646424, 0.011595994245351083, 0.060661898535345836, 0.057638421459423925, 0.03255310986611632, 0.0324154591878816, 0.014364121767181545, 0.04528040051340096, 0.08117331282025383, 0.07592212483887711, 0.05823674761960584, 0.09097364580919666, 0.03274259405330785, 0.024902251053361163, 0.04002387672963162, 0.0394852556318285, 0.010554290868552222, 0.022875768462977102, 0.15163631809334602, 0.04281339055347828, 0.028989136692196615, 0.04882662151489527, 0.09848750511845274, 0.07751237781297776, 0.07589984700203904, 0.02253682243697826, 0.026555327067692435, 0.05026381395216431, 0.057422380834337206, 0.07275731603224432, 0.016640429460113088, 0.048418273668616056, 0.10845616294611847, 0.028954963425114274, 0.021199407206187328, 0.010567215729444739, 0.02697810609524529, 0.03813485712594083, 0.060937356939839746, 0.1093887217763451, 0.021047047639806426, 0.00913601409974358, 0.07332752293516552, 0.0423939727366932, 0.040778415878453565, 0.04971495408925319, 0.11515326527578217, 0.03587231220256898, 0.03064806944870901, 0.05346822184360316, 0.048002801204641024, 0.010820224884927515, 0.038844875075043216, 0.034749384353598284, 0.04060154532893531, 0.019182117670894634, 0.018129269630017302, 0.038332798923816414, 0.014286072729455849, 0.03814163700407071, 0.03528135197777902, 0.0973468691471123, 0.06316456605770415, 0.05408573467584868, 0.023214691506338217, 0.03225158531999877, 0.057112980904358054, 0.039016570700632955, 0.02130047527081784, 0.04537947483420853, 0.04060021999682631, 0.02359442213820594, 0.0519915069303205, 0.017835103358412464, 0.04194061339442288, 0.07875047549004517, 0.08043107321305622, 0.04005246330052614, 0.03280400366131817, 0.02304322187668614, 0.024732507036758528, 0.05065159616811622, 0.032707296552196626, 0.02198646678739498, 0.04758236066047703, 0.03959603577611908, 0.03425130462874809, 0.0428402764091809, 0.026186308260225964, 0.04690610037575807, 0.0491136095426496, 0.02689709229725263, 0.0419840352579711, 0.07572640469598194, 0.04464679983474555, 0.08695743752703552, 0.04441145762440659, 0.04189030440043538, 0.02590982329791352, 0.035270921690689946, 0.058788258146734974, 0.08480620900950125, 0.03149155715119935, 0.030696045704967076, 0.05551407879759228, 0.11108180673252191, 0.01845921603812566, 0.0967072546782513, 0.026549472240731124, 0.0414093007754174, 0.0409921505788882, 0.03214522550303129, 0.011287001299581701, 0.025394778555980133, 0.009459815525089302, 0.05986775647127821, 0.055541060414285436, 0.028397793423444517, 0.03468863358120284, 0.04749364001796611, 0.04367308676122658, 0.04761801822291267, 0.03603406400690156, 0.04433613202925171, 0.049932086389632, 0.06425314252415011, 0.043266880130695726, 0.023859431103412664, 0.024443216914791736, 0.10018157832805188, 0.05785137091973617, 0.02552188594915694, 0.008343418575673094, 0.023263927977231723, 0.011330886646324109, 0.057993300199027986, 0.013700188794774155, 0.020918555542706482, 0.016783375721124393, 0.06786022921122851, 0.04614121903995833, 0.044546978578211806, 0.007380785048759032, 0.01532194521954103, 0.026834861059943517, 0.05197128603955911, 0.03237019105243587, 0.04230239841666433, 0.03470389788309413, 0.036873746167628035, 0.036046459309516415, 0.02842372933012103, 0.0428444477579286, 0.03374005202203989, 0.06064353923824045, 0.016435462635971846, 0.03234399850630472, 0.04147285159917609, 0.023232792248769153, 0.02480612808628188, 0.060242216418226885, 0.028129817782751018, 0.029066467522493297, 0.05383602448648984, 0.08700469749108439, 0.017899922057685834, 0.02132825744939187, 0.04165493537701907, 0.032078349857681224, 0.056920865205146616, 0.008169722502991077, 0.023707042808734605, 0.02187207262332161, 0.012202534783301095, 0.01732349643603929, 0.03807407187958879, 0.00848556331719362, 0.07169780877208518, 0.03012956773501731, 0.07257954532941503, 0.0387956386041497, 0.11637195794572754, 0.043858640917366555, 0.025147943111557155, 0.03321758005768061, 0.03635744121105921, 0.054524622617229346, 0.025062824997510162, 0.14010553037927997, 0.032324593499182694, 0.06965085248192472, 0.029349831954365777, 0.03486846123010882, 0.05525846207033723, 0.031062923296685183, 0.07857055208014865, 0.024547734290301323, 0.04212713665178707, 0.07298173382878304, 0.0321244855877012, 0.03664359037253646, 0.04397098388102266, 0.052085452292475014, 0.010512175184914903, 0.012223055405962852, 0.0656109337785071, 0.05319209311217551, 0.04338358596508061, 0.03763271330465232, 0.07107772954529332, 0.022554796774901693, 0.02032667601240739, 0.09018386278541819, 0.017376147743855274, 0.06490298426680027, 0.07394243106846848, 0.009323550508387629, 0.039013104152775584, 0.050321937042979464, 0.019606666361552574, 0.02346642416781716, 0.0731612895164759, 0.03286076694606774, 0.013474721457779169, 0.05294695646772462, 0.013262057365218719, 0.08122293999598873, 0.041794803879794576, 0.036150811976122285, 0.027630707669642665, 0.012679621783806192, 0.017355388676327084, 0.026418699116836634, 0.1372616741085245, 0.03258309071703303, 0.016199059393857757, 0.08503652568305693, 0.04272782619321539, 0.04292315563126918, 0.06567120957638949, 0.03199866139179757, 0.018511287034339, 0.11775050252195328, 0.14486814578694684, 0.12502320501352512, 0.18783205729578772, 0.11768158525228502, 0.12434900167488283, 0.12013115139017183, 0.08195460758983128, 0.1158070600321216, 0.16681365368347015, 0.14286805875599384, 0.16345020593895068, 0.13731196011987426, 0.07025602363771008, 0.12258590394330603, 0.20978605344651208, 0.14430510180611766, 0.12599401461381105, 0.2537870794654854, 0.12896367018261265, 0.1935992131550466, 0.1393446671746431, 0.07500700983068637, 0.1109621437987493, 0.10905456188465319, 0.14311590352125708, 0.1345425063083249, 0.09956059511750938, 0.2559939336272017, 0.1447420170710933, 0.09892895562394012, 0.20785120646319083, 0.27873582056453156, 0.10554881330819861, 0.19336419270163585, 0.21658037999464622, 0.22511484461926648, 0.15227604747539566, 0.13424658186493382, 0.18315924271460504, 0.3130518711142002, 0.26033874000272444, 0.08388455161043713, 0.13532573928035077, 0.08955529530442531, 0.13137707697047343, 0.16347553280572738, 0.09579125866894761, 0.17190830691927866, 0.2927028598083604, 0.1407687020518126, 0.10936875752503834, 0.09426187904131028, 0.08081658397831264, 0.16035956210426747, 0.1254265196621418, 0.14223390649403297, 0.18004043748782528, 0.1104839287337757, 0.18029143853533655, 0.2146976729554515, 0.18370328771491207, 0.21925816372517618, 0.25216088930685676, 0.14490732352339453, 0.10392128249570247, 0.11687002234881926, 0.10081365449173797, 0.09460215231463795, 0.15831873451750125, 0.22186398115609923, 0.0828855729571754, 0.13368480959005896, 0.1634308085927079, 0.11774749179641086, 0.14119441711133526, 0.1944104083363087, 0.10198080476613776, 0.14959014321286834, 0.11232345139667874, 0.12953126472571205, 0.12043265295365166, 0.0887287094167644, 0.06993134025364153, 0.11129713872627867, 0.09402138872012016, 0.16353234588619203, 0.14458941235657663, 0.11102966678839539, 0.09897945613990869, 0.12975621878379776, 0.15661916845748503, 0.21371072188260096, 0.15760677836595044, 0.2149292306914445, 0.10136532972777083, 0.10956237858702099, 0.15643549121675954, 0.20464299877564754, 0.10057735467149366, 0.12945131578993413, 0.08578527703761094, 0.11976472387510924, 0.15841817273007286, 0.15281154293446772, 0.09365994843744463, 0.20875281534127652, 0.07748392530746999, 0.21073263168575304, 0.16949833220531865, 0.12162589618275244, 0.2565881420647906, 0.16267717725807623, 0.1067325187426421, 0.12868803174745652, 0.2031521150662053, 0.08464626517266997, 0.20057640489070647, 0.13673488140827225, 0.13750276197829556, 0.10792959241136428, 0.18530214385640237, 0.22538600910094478, 0.12450391997493084, 0.24189164922122033, 0.09336640652749809, 0.19520327869442203, 0.1855512756493784, 0.24096589325176132, 0.24678739538836866, 0.15012448954005397, 0.12870160682547477, 0.16291311701699612, 0.15320522019699698, 0.22910145892491265, 0.19489095996945136, 0.23852519841203768, 0.13245615777709793, 0.08444440100462207, 0.29935853976395826, 0.19730306440784087, 0.10234877977880741, 0.17044120257900608, 0.18055406879753838, 0.1125625167943297, 0.08994201648860209, 0.1353583899476836, 0.1500865375442851, 0.19342060741637984, 0.1462507046638958, 0.14481894762044953, 0.09805686411357696, 0.10919511603612093, 0.13668206730677238, 0.1187994301078781, 0.1882946058627098, 0.2758146047351822, 0.2861642074440756, 0.13164871642666479, 0.15233929569442428, 0.1799783690442001, 0.13191214342030788, 0.10699518730924015, 0.11295859191206195, 0.09379219053493393, 0.1298679910119503, 0.093426919812637, 0.29055493312977976, 0.11710000194368825, 0.10172336091918331, 0.1252687515150155, 0.1575595260627808, 0.24092115371698336, 0.12214596263102948, 0.16521361776657645, 0.16371784641617732], [0.06099155766048259, 0.010153692001627098, 0.04516496255453076, 0.013222373053131085, 0.09569756611580811, 0.04875103928028576, 0.07995034537969098, 0.0205678615583888, 0.06748581139911568, 0.043038133937384815, 0.00891601758813786, 0.03651434750927072, 0.04798105962934995, 0.01865172435739829, 0.02488043861493709, 0.025199215461109436, 0.035223294004437425, 0.009552713262007363, 0.09065452422345839, 0.05173445378820743, 0.09249118937840385, 0.05350233573887137, 0.04135077931888161, 0.02180485032318581, 0.026516308294489022, 0.04098717100738038, 0.01583720733892293, 0.04074046388268471, 0.01801872888820306, 0.03735387645241234, 0.038505892659867966, 0.032083689490513455, 0.014904626483668484, 0.014542865401674664, 0.03493866169705026, 0.01053236830498903, 0.005148014132564347, 0.015799728402447318, 0.06171961698020178, 0.0047349821374331035, 0.030007700383242582, 0.057217214827335654, 0.053803806658834226, 0.07138254826948529, 0.018933299973967577, 0.009450438608896107, 0.02862262299224254, 0.009080388455561573, 0.038946351081493406, 0.03986685551823147, 0.043089752941722834, 0.04736546967779437, 0.03649061410537651, 0.020974114154195114, 0.025048054822330034, 0.07618706102573103, 0.05173904648531349, 0.05512838417123403, 0.04879349970348901, 0.09050909775279223, 0.07569487251701855, 0.03534604810298451, 0.012128826591276355, 0.08090131330273806, 0.030113062370688688, 0.026326519587347587, 0.028473392895032323, 0.02712390603377454, 0.028204080430910956, 0.026475270879605127, 0.01749347410945883, 0.05753773452353574, 0.05636229134735562, 0.02840203755054503, 0.04416224922263815, 0.05534705630834064, 0.029123305500815475, 0.030454099816720814, 0.06175376151898696, 0.08612468463158415, 0.061276232102705594, 0.03629590136810176, 0.024368923623114828, 0.07449503327088972, 0.06936430495472685, 0.036905090655049974, 0.08571607631541069, 0.03366543122777536, 0.1091230731277216, 0.012622933192629249, 0.08683499369409778, 0.04854570473394087, 0.08262716383943636, 0.03543651542596279, 0.04106227443703721, 0.07138310751367001, 0.042322113689395695, 0.02536838108132924, 0.018306241686185522, 0.0663744323256035, 0.017017467292926965, 0.02819060494432286, 0.04766922353977158, 0.017981648317448074, 0.05722933050785815, 0.09296489984638269, 0.05729707949344189, 0.020226201665918195, 0.03697834015193005, 0.01570983085736272, 0.01946607390568862, 0.026948010331139933, 0.037709594058293494, 0.03765299548244765, 0.04632793381930359, 0.02432296409331743, 0.012817655506003047, 0.014434469706048409, 0.06560027749548036, 0.0731277501871509, 0.044692458675032666, 0.05702127634938206, 0.03994092089875091, 0.015973630361258984, 0.03221255314025668, 0.011197278039499877, 0.06404684270702063, 0.05756788008335618, 0.06808486917326528, 0.07655207127813371, 0.02214611759559522, 0.04773825955306811, 0.053340181738378546, 0.08366520531595716, 0.04289663366733059, 0.05902473799764149, 0.01697778776888886, 0.014477533423492025, 0.018966500309386083, 0.04225857435695587, 0.051834252062103445, 0.061578668293453036, 0.06642068105359232, 0.03389640673694592, 0.031177217869328398, 0.06241294953431334, 0.018260736063483263, 0.061784496966509096, 0.006581548499994942, 0.07162145278867214, 0.014352301030509896, 0.08027609362597428, 0.02154690277342114, 0.03177505756367839, 0.04312438394633993, 0.0736404545304756, 0.022574473743236834, 0.06624810442688965, 0.024839698059123852, 0.044585141248159835, 0.022533235230272817, 0.007558726206151469, 0.02556673848190375, 0.017262626920015584, 0.012548791203317384, 0.12157358003840332, 0.03855289215402257, 0.029815360603313294, 0.018177864502274224, 0.04620874969048366, 0.016029867918170508, 0.05125670986730726, 0.04634838070600264, 0.05285894062610404, 0.018608371441763256, 0.04452698368338808, 0.02965152120938705, 0.029172890541714527, 0.02875526537067227, 0.015791794604381487, 0.049828821567878614, 0.06017995262218099, 0.06201693570361503, 0.024761917152171655, 0.048816566610889095, 0.02069517388008535, 0.05469444515784422, 0.012651249717530465, 0.052147808019071824, 0.0282689661628777, 0.051865412688423554, 0.02846817200582835, 0.0645070853492906, 0.03859152979848366, 0.01906310591185766, 0.040606685778907234, 0.042944242201385, 0.09757442790414057, 0.011484367573904175, 0.041055191954177235, 0.09203411067926115, 0.05016626031588643, 0.08468084638157199, 0.013144327845845013, 0.03706822524808588, 0.03731017879721138, 0.012861934430416555, 0.00903073542435924, 0.041377408535129605, 0.05600065954269902, 0.039508207626039946, 0.04241442728427149, 0.013620064616383565, 0.08277893351811556, 0.0378855261501045, 0.026581188280796333, 0.04268515892627259, 0.07202744108414458, 0.04101726294104611, 0.02372945854139905, 0.04125450887987691, 0.01566588805402599, 0.008334153699838828, 0.03491207844607773, 0.056515662149796565, 0.034402921089842435, 0.02716048290171931, 0.025288535567421108, 0.021242248758132902, 0.021118178903575868, 0.020307441459848516, 0.050060413777828223, 0.05271333412477567, 0.027394578303961505, 0.019857473971862948, 0.022680636292563814, 0.10844381360877907, 0.040702994522308154, 0.02904703570229392, 0.012007461984701937, 0.028826505801970922, 0.021475660426902677, 0.02223802707909096, 0.022430744157322956, 0.06958911345610697, 0.07002954506465504, 0.04646108373098316, 0.01082557888190833, 0.04318405453476214, 0.06808368939786189, 0.009106441190646542, 0.03165356559498656, 0.04968482768163086, 0.06622689145226633, 0.03798402207452924, 0.08334775380189381, 0.05161057354041165, 0.04542894496191894, 0.04866544810694553, 0.06811536713353089, 0.14734719098815996, 0.051271292350945935, 0.06115708627828187, 0.03705032943417469, 0.049348109056271856, 0.009354336709234743, 0.09836297752636095, 0.030748878958665078, 0.09978637655055332, 0.01790048130187056, 0.008957154594451911, 0.005485924503450553, 0.08537826218431996, 0.042180387423403805, 0.011708899326021633, 0.02911954592432707, 0.0322998067243926, 0.006437511521301443, 0.06189939100295306, 0.021020705706530043, 0.08105546551486177, 0.06362482402173263, 0.032584044496498765, 0.03549915460509158, 0.032193971677653255, 0.054380709170213634, 0.022874625076750116, 0.06465413592635624, 0.04840781273801, 0.024336454901664008, 0.03737595127595048, 0.006719755070779714, 0.01971137142860361, 0.05478390890564169, 0.02909979809285893, 0.03815884716928967, 0.021421210727684444, 0.0032684674454597578, 0.02087252514977609, 0.042221434414386756, 0.05211232282641915, 0.01668924649786805, 0.015511097116095406, 0.03303572610621491, 0.017959943131333398, 0.08479330042797713, 0.07546994144157057, 0.02285161562594435, 0.017676329720885526, 0.03746583254166669, 0.046894972948657895, 0.008039229958798856, 0.0792985118084377, 0.025317524334475882, 0.037020394548533425, 0.02995978349879865, 0.09224789517541086, 0.052353380052673246, 0.03910005896262104, 0.038904721863688006, 0.02148867051507677, 0.008661638092880529, 0.08521678617164012, 0.04574830786535337, 0.06242830193631592, 0.02986935064977696, 0.03156112942604288, 0.06891984372369706, 0.009362494588018426, 0.11738375324996249, 0.02713835828246609, 0.04825603539845155, 0.020717957334953453, 0.009018248191193469, 0.013297439136001612, 0.02246030749032094, 0.011714215976216141, 0.03665524640030438, 0.008942136398306298, 0.06905822984633908, 0.023388539838995186, 0.16259546632007246, 0.024074751605850556, 0.03338081424214667, 0.03399124842197184, 0.03205460496246815, 0.026923162269315896, 0.011658352844777608, 0.01576733341695921, 0.03353423100986308, 0.03414007632302181, 0.04100191053904353, 0.11695005555426884, 0.10835738356916175, 0.12038638890390435, 0.05327876446948898, 0.24484900907883722, 0.1643279281955573, 0.15482473006892591, 0.2349537118308006, 0.11634717500137708, 0.17255238768073822, 0.10475997257256701, 0.10160157592186045, 0.15529147679767302, 0.19399278316526644, 0.10485946441129332, 0.11081467953420455, 0.18767923807665227, 0.1714811975797338, 0.138011199211882, 0.13205118837856478, 0.18387826219681772, 0.13234945705100415, 0.14045840579896204, 0.10246333290612507, 0.23766612273550805, 0.17619790899897778, 0.15712380589496705, 0.17744428808650664, 0.18696205720545786, 0.20636456688084912, 0.1270025157399716, 0.17348108542782648, 0.09310196829779495, 0.1391225629636357, 0.07114684599782191, 0.13074761316660913, 0.12446061302457126, 0.14400553078420703, 0.17461639708809315, 0.16856710636808028, 0.11410958539213865, 0.12363107003752263, 0.19143941211363963, 0.10186723223136318, 0.1105643603049459, 0.08126309066410027, 0.061027851075895374, 0.16226690653110706, 0.11179403867572547, 0.25423707951220775, 0.18681905923351166, 0.10947242454295197, 0.08870410267263652, 0.11140494261898341, 0.06308292406761358, 0.16464603854523552, 0.20549559334833778, 0.13631295082309555, 0.19859911663638008, 0.16557890381063187, 0.22410118772137552, 0.17748668339223633, 0.0805131288906259, 0.13328175541133652, 0.1806539206975891, 0.13048718923762923, 0.11020216925610458, 0.1391549531610743, 0.20463927558833556, 0.12701551625204663, 0.11473493530384957, 0.18791721562945074, 0.1478039172868575, 0.15900772335308214, 0.09493084233855048, 0.11280965675870258, 0.18357823152215252, 0.11179871947294283, 0.15829106342167626, 0.18786512165059968, 0.2377794731047846, 0.08441644645626507, 0.1306274446148065, 0.1345022407270247, 0.21315547667684095, 0.1045218647848214, 0.2191871320528369, 0.14056368160151667, 0.18843552007550196, 0.15420355533640231, 0.2100207981082701, 0.12136063823897032, 0.22288877697240925, 0.15016031181139333, 0.16457137561613516, 0.21162130899967688, 0.1069919927225959, 0.1649656963925208, 0.10614903553599313, 0.11374812978770464, 0.1528868493774245, 0.11459084182617166, 0.16765411342343978, 0.09124761417267785, 0.27439050857097874, 0.23218928355603452, 0.11904318396362568, 0.11481004256394603, 0.1505767265635152, 0.13782928397338237, 0.16845542607047867, 0.21285726929143553, 0.08360333605519227, 0.12605547784797608, 0.14268266547831798, 0.1474126148968935, 0.12277848312571166, 0.20419379546036645, 0.13539381385330232, 0.19265214461953412, 0.19938172141630806, 0.14195313526978418, 0.11836789278013092, 0.11497166413333147, 0.1431973080240911, 0.11318677886118812, 0.11911631471687749, 0.1550603633926761, 0.19418508655601935, 0.18389375249464668, 0.17318678509083488, 0.15558767703271684, 0.12254175429622974, 0.13742730231775394, 0.10676441864380914, 0.14796496429029973, 0.1480935291657525, 0.17514973217921873, 0.14518821732171122, 0.1789120359406356, 0.19103651115250206, 0.16590766278245758, 0.1279948677326883, 0.12916063138794515, 0.12382001796316718, 0.14560487722196888, 0.1606191126930137, 0.11377989179304532, 0.08913573959181387, 0.09666591657385712, 0.12737046777000352, 0.19918688993540504, 0.12974272031457196, 0.24997035281792765, 0.11581221580385201, 0.27971690340388206, 0.10670659432728445, 0.28504063225080895, 0.1437315011336919, 0.14273855925327347, 0.09163032871701064, 0.1322509075004247, 0.08115926276772253, 0.26660077333931004, 0.10288548565679982, 0.345180832570599, 0.12207217304216278, 0.22948336907692496, 0.07670082257039125, 0.12477435667308108, 0.07571813094639972, 0.11419822942585715, 0.12366656289105454, 0.10718072614362163, 0.1427414244221103, 0.306050532287167], [0.05865916850105409, 0.08538773869194331, 0.03808491202371736, 0.01091123708794194, 0.014440430827709216, 0.052150244178671035, 0.04880008805963782, 0.007184925094817675, 0.036168087258814804, 0.06028410227548692, 0.02195925917476416, 0.02097453933299309, 0.05261766506479152, 0.014337579693434941, 0.010101142200461079, 0.07436391732264912, 0.006965559648139583, 0.052216426514449625, 0.01638319820255762, 0.04313958313075766, 0.07537467074730704, 0.04709897067157492, 0.008864875473532706, 0.04173815167779404, 0.025698505604879993, 0.050073969703648365, 0.0328000889520251, 0.042986453646012855, 0.024956668193842617, 0.020671930772462682, 0.0316998353903933, 0.027934264263979373, 0.024786301730801503, 0.017384840926576047, 0.09307467258505284, 0.04251692984854022, 0.036601509162855726, 0.05234443597615727, 0.02402633867947565, 0.01770870459656562, 0.028155135073428674, 0.05290435431825538, 0.02806965689805727, 0.06009736834394355, 0.08150349671561873, 0.026649910198043913, 0.013771566164289272, 0.0655773944491821, 0.030490105949162, 0.02256109976329871, 0.07101360798603104, 0.011396289487639743, 0.03319285073948484, 0.022458853838484616, 0.03672840779707317, 0.050053534308268186, 0.07443135604262352, 0.036822989012204835, 0.04923321501982789, 0.04390987304730281, 0.01289074125158931, 0.031705054364377455, 0.05084275808786193, 0.050732602305229635, 0.06005711042352262, 0.05540803307667375, 0.07761104993762509, 0.049683540653918064, 0.037102714526436986, 0.04810723814091856, 0.025293231686396946, 0.058600643214078686, 0.018447104188042785, 0.029098884533009226, 0.02512086190343384, 0.04768275648295399, 0.06633164631503244, 0.014971591186739746, 0.03968648011645964, 0.041883731366045056, 0.05684107331739319, 0.04321879279168864, 0.0804152841409368, 0.06767041560622954, 0.06430253221262848, 0.05413487538575165, 0.10264234467139167, 0.054618449235755595, 0.0038350967177745677, 0.03860268020822156, 0.06074126524430129, 0.015402459145163097, 0.038309448563884345, 0.04968785372893176, 0.09617696861706435, 0.03941855618670102, 0.01939346600744513, 0.04482788003740772, 0.060725066315142386, 0.023014457190349218, 0.10295191314071418, 0.025230655709521908, 0.03960543567495, 0.011912878854350458, 0.0450476361889272, 0.03710561416923039, 0.06202549673616887, 0.056029705766348116, 0.056272015546358405, 0.025367595841206854, 0.04455480799679795, 0.004982401723898347, 0.03937788074836135, 0.0568774433415984, 0.037605731687959165, 0.04836527187557471, 0.022650875691925327, 0.027425009231533737, 0.03361205405165111, 0.03183043039884539, 0.03601377033778737, 0.02471125958817861, 0.017954727987788858, 0.029736922775966027, 0.030480008910319982, 0.03615316769648944, 0.019085697844744693, 0.0019997466006316245, 0.03282435478702669, 0.025428367681020213, 0.010229003232633396, 0.01249313012756888, 0.023429695997507344, 0.020201219538707408, 0.010711105236212813, 0.03523874599787016, 0.014906942942029527, 0.013781363471230913, 0.038660872246949904, 0.07611286541026446, 0.029908118529185176, 0.04248544746529191, 0.03538015433737347, 0.025614708992502382, 0.015952409725756417, 0.02396337391297904, 0.047572229147678426, 0.06256453918233033, 0.058010027728854656, 0.03946221936794539, 0.05860943024257018, 0.02957255669659184, 0.020001870054270954, 0.04360929078933212, 0.07498431830636917, 0.05171024540980017, 0.060616576773745406, 0.06453626563832646, 0.06227020054094254, 0.025036032987578262, 0.05796257624282472, 0.03493524494490797, 0.005718306262767123, 0.06580515238907068, 0.08102003394836381, 0.02063007747393943, 0.03532858895919016, 0.02151873946610478, 0.027985731965952346, 0.05506674856728604, 0.09578337562420676, 0.0787585883611633, 0.043112287418015545, 0.04882453009486199, 0.017699078701797034, 0.034823009233561256, 0.02718688995246926, 0.04288759382982408, 0.06722199370063121, 0.00982165513109536, 0.10396190047744783, 0.016833673223793026, 0.03943217722999473, 0.03124091999545213, 0.04481790940307322, 0.060300132665302486, 0.03108850871813634, 0.03152721854407461, 0.05545921541089493, 0.05677723521066289, 0.032560881828108144, 0.10007021978737847, 0.034009711140947, 0.02307537075642857, 0.028693637427603527, 0.04706568032082531, 0.02457059626918166, 0.022577076526959578, 0.08683048143622377, 0.028356388286356966, 0.012802746477386644, 0.00854840263679263, 0.023933525212229263, 0.02122443529867357, 0.0395293363309916, 0.0391385855243331, 0.03773269543965017, 0.03417535467193492, 0.04691651917152828, 0.0059734508883388295, 0.02765302955653639, 0.02378463027848592, 0.01429280951513999, 0.015651091065768515, 0.0228774500259709, 0.029813751818672306, 0.03037517552354163, 0.004507903142967412, 0.0433452126209534, 0.06376691800992816, 0.0575865151721143, 0.03215468285845653, 0.026653085632490057, 0.024508979817431782, 0.022996890794245467, 0.05633088174246012, 0.05940241168343252, 0.016339261144880327, 0.04346500578967314, 0.05527935328803236, 0.0393740234956626, 0.00952924415844703, 0.06317124251396426, 0.08485510074082883, 0.05061709539844625, 0.03527131239553133, 0.010611391231988468, 0.027208221670720848, 0.07286883545138183, 0.034305612601700335, 0.04989102407689056, 0.032636303184253555, 0.06300498994307653, 0.05955992702154383, 0.07024628666019248, 0.07927931364505522, 0.05715054602572515, 0.00471850885303631, 0.04337256962072946, 0.030426097387868552, 0.014054234413760565, 0.03897386895973356, 0.0636918452237883, 0.04224760014744055, 0.08014100168140666, 0.0476230705727733, 0.017711117773527102, 0.01926138095798031, 0.019151399460350795, 0.04678975077225797, 0.008795027407036434, 0.027657589694905668, 0.0375975230558505, 0.02132454766861854, 0.023207928865186633, 0.038267524402228095, 0.044877219930171006, 0.02944120326109471, 0.033354365056560885, 0.017127381757863106, 0.009663475211709738, 0.03091159220334263, 0.044899447971294006, 0.015093883717312448, 0.041915064362148126, 0.025642473934098117, 0.10006914726428448, 0.08462948018624898, 0.056463859284356724, 0.02698564440042021, 0.023538827137540907, 0.04276514999688633, 0.03991789612618666, 0.03666069711588564, 0.035032419367663326, 0.01635320011466261, 0.03446654469195393, 0.05094128082536402, 0.014460191108106125, 0.04861883548719268, 0.030582030754416224, 0.031290901486852, 0.02026330521931091, 0.0383349975961591, 0.02669983231762965, 0.06536699606165772, 0.04242853096295749, 0.021216996584928805, 0.028422484437244076, 0.02874777877643224, 0.025074615090664838, 0.011187033528732437, 0.041604657026548544, 0.007389116733740535, 0.03700130746789998, 0.09384208584144231, 0.02570194150922039, 0.007911305724372788, 0.03756307591233523, 0.007539114834094841, 0.03476195202599611, 0.018380726499843503, 0.024457293780400388, 0.04877694071300569, 0.012151228917402127, 0.010103325551045279, 0.043438614060681675, 0.01902262008027925, 0.04591184848498914, 0.0569678608688616, 0.07789213525792284, 0.03770898501839369, 0.02157326194367582, 0.07228666225508337, 0.0541844949006073, 0.08877751687842031, 0.047400966361765905, 0.049377634084873626, 0.04919663049100388, 0.02765615136482783, 0.061148157523524385, 0.020348224150497588, 0.05753020004880044, 0.04322142430370854, 0.12361004858488038, 0.023769471313684218, 0.11543982812473852, 0.029018918360253016, 0.04117574354994201, 0.01974108606396664, 0.052112908883681225, 0.08327348923851406, 0.0573176259715711, 0.04021627971181466, 0.07526869780474132, 0.037649896656793934, 0.06364247468750804, 0.04825753310034352, 0.030495064453251904, 0.109430619124924, 0.008689043930761756, 0.013256818281426547, 0.11405553022820143, 0.12618457132409658, 0.13232311894816737, 0.20378364730746518, 0.19821886123428423, 0.11088934246330492, 0.15601035838405933, 0.14132767044488462, 0.14348059201673155, 0.22988521283672703, 0.12144096255783113, 0.10462134130178921, 0.15268192085767948, 0.26397857694856586, 0.10704945697779618, 0.2967019919906893, 0.0953078878322436, 0.13766025433376913, 0.10596351968424936, 0.16698124307778575, 0.12599354730017726, 0.13183847640550908, 0.17758777635472436, 0.1463297189724061, 0.16543201411203032, 0.13381896690735895, 0.08676417652637729, 0.1434172671889105, 0.18635585183097472, 0.16306239690992141, 0.09364133250088462, 0.07994561095631893, 0.13819460066095476, 0.15406170649634254, 0.18846725143732565, 0.08881326254096725, 0.20611826961319293, 0.17605642788112166, 0.08699921230154653, 0.14526418260028287, 0.20520103254145194, 0.14538750743433354, 0.13476402829250983, 0.15658604281563915, 0.26027144683945563, 0.1406530993840387, 0.07775683646961566, 0.2772919899753986, 0.1457015575180131, 0.2210923314334885, 0.16201578290952792, 0.16490250946052615, 0.16252065017338724, 0.13508328777407447, 0.10358392035648709, 0.13463515698188736, 0.16859247920013246, 0.1281723856265026, 0.13399786375943692, 0.10844971248579603, 0.11065432200989417, 0.1102021539343461, 0.1648316463275302, 0.12751758729498233, 0.17707439019314705, 0.08101616520434618, 0.17742829217064768, 0.14188095446555846, 0.2810449934294147, 0.19120192485711268, 0.18363578004702447, 0.16730382738094177, 0.15241011286214476, 0.11724922821045884, 0.10373063385486604, 0.17600244932597683, 0.1511699084432856, 0.18162029464879345, 0.16678301016649894, 0.1360551315930582, 0.12412856753555038, 0.16421638579378206, 0.175645099952817, 0.16911819937729067, 0.10000253591926829, 0.10018760744001597, 0.17985904318911416, 0.1013117571992259, 0.09382609758646258, 0.2004039891424679, 0.12854776104852078, 0.15749302963095327, 0.15065309020780748, 0.15378426009368512, 0.16780988974196298, 0.17646121341855298, 0.10949861708908312, 0.17753612670686938, 0.2645095984541601, 0.09415399087893386, 0.22833062125550163, 0.22950947735338445, 0.19476106210101038, 0.12659410660665843, 0.0843872431845915, 0.12862879782915115, 0.16438880154202062, 0.150219744912559, 0.098515720136704, 0.09164220307983699, 0.12404546231752443, 0.14661390694879717, 0.1324248860680288, 0.16071285121142864, 0.14329735910700214, 0.08832831356313922, 0.07625709678376875, 0.14063515760485204, 0.10828408427656659, 0.189947884890341, 0.13614998859984262, 0.07243035736704066, 0.10037566670366835, 0.1594223454594612, 0.1012312030539878, 0.12338211444476921, 0.12563127198166427, 0.06960127893234454, 0.1408272618127446, 0.24998205864141065, 0.12774287077087548, 0.094827022103052, 0.15248241624043835, 0.10483379280495067, 0.15185083803390304, 0.16785732590623442, 0.07437809761012755, 0.17147986458674555, 0.21683216245184023, 0.15716728904554922, 0.08207461526316982, 0.15689658421662547, 0.11592388077969513, 0.17939002884011115, 0.14268577579529057, 0.24320035722226868, 0.17867611150347418, 0.22247279122952493, 0.13794549951149573, 0.13770974361367766, 0.22081883804452038, 0.14767044944868934, 0.10439880808154423, 0.11710275219933641, 0.15278209451465838, 0.1417777624221579, 0.11971112836392657, 0.12355062314459395, 0.29380397330368724, 0.102574928934055, 0.1770190633232555, 0.17382001804728664, 0.15623998557848318, 0.08963119929596301, 0.23757019320562964, 0.22609566698872277, 0.11367356645003443, 0.15001674693438316, 0.16748588051526778, 0.34830631808407847, 0.1756540172162556, 0.21605718790763812, 0.12088305136609463, 0.30587396434237885, 0.08244075166482119, 0.3338877772611957], [0.0371704941555377, 0.04429205133008861, 0.06164672371420649, 0.03193748161016453, 0.032450036566344, 0.0762939915782021, 0.05729950416172224, 0.06794929459330536, 0.07366433349107543, 0.08342362714991455, 0.036577814063357736, 0.05333371978673724, 0.010569581025910955, 0.03458671707419619, 0.02681458271258781, 0.04154518179054703, 0.024148516296859712, 0.08398112465417193, 0.004765874632979714, 0.055912065304695606, 0.009217486592880901, 0.03584330045287648, 0.02737743900187554, 0.09782095499817403, 0.03287580908246098, 0.021478533256618727, 0.06187728553589794, 0.020606493457190452, 0.008727746692696407, 0.016303716580413522, 0.016645715466790622, 0.07421330443673557, 0.048433051504675424, 0.04826623202872373, 0.03614012121913895, 0.026416159535367644, 0.041699958364329034, 0.05655128523827561, 0.06127136361394679, 0.07214345743939762, 0.01980017442556639, 0.028387409101630894, 0.05356130152640324, 0.03626538808607767, 0.035258721740495776, 0.01316897385197902, 0.030896663064918214, 0.04935282815788542, 0.05190653245775931, 0.01568477307896941, 0.022083945730100238, 0.09105721834085642, 0.0372151302684459, 0.04441079878879171, 0.09219598505766162, 0.05620319020724105, 0.019313610917437943, 0.04682180006057025, 0.00841038423635426, 0.06791554075936157, 0.017796448476973082, 0.032446079722215096, 0.019607727393327702, 0.02735938613993987, 0.05526029302047626, 0.04508399472181355, 0.0592622367454873, 0.040092809321058374, 0.02987816640656562, 0.037488252104770754, 0.03369736177245936, 0.049290637140192335, 0.04242480394520587, 0.0514264557991297, 0.08850681204949656, 0.00566853161510681, 0.04496242422910948, 0.042074678781171965, 0.030105211884684624, 0.05520457927618296, 0.008176503338730864, 0.05315707906359627, 0.015449695168964326, 0.07430637645865641, 0.05402687997106583, 0.07207428736071433, 0.05447463921060967, 0.060893463932218096, 0.006416250666182849, 0.02175607350504687, 0.03970323445936365, 0.01567615363221135, 0.04661368844549983, 0.020482553837580547, 0.06102027446632424, 0.08631920201643821, 0.04090804561612107, 0.042455060587775324, 0.1000562999697943, 0.04963343850367012, 0.04912513916591003, 0.04760368088740976, 0.038682805344222054, 0.03704566778915544, 0.056451927464936054, 0.05057974861213758, 0.026087655287776745, 0.0764644461413545, 0.06174545329544814, 0.02116816422541536, 0.034713573573577794, 0.020832282551113638, 0.03223370482784606, 0.1269397501563353, 0.02814334689549381, 0.054652084326071125, 0.023649149544296727, 0.035419814709213474, 0.05170812717668953, 0.06887894228941972, 0.02506727213791061, 0.024278266693375284, 0.050853598231990496, 0.0467358679781037, 0.039385537797164534, 0.01544418891200856, 0.023655841322315317, 0.012471650937391866, 0.05555456271395088, 0.03474254701887408, 0.025150785297756235, 0.022641968004585757, 0.06512069879400154, 0.01568783647305663, 0.07614442823274482, 0.05672757739141103, 0.1181940521083532, 0.061989360368780555, 0.013280041279241204, 0.07048023459050926, 0.04279638723199887, 0.027087493874733488, 0.033758744567392335, 0.07088517334552542, 0.08581968204629037, 0.07525696133774135, 0.04941457867502205, 0.041674233131831696, 0.06284028486979586, 0.06150312053280012, 0.0365752131948548, 0.03916349870363071, 0.05269538468470978, 0.03711023750985342, 0.03968678655162935, 0.019501266069710255, 0.03708311799733389, 0.021262741610107404, 0.032351115463121284, 0.03206135611230087, 0.05162810163211919, 0.03219091498683537, 0.021357589040792758, 0.030665348561841155, 0.03605239649092959, 0.02969437233743168, 0.036122271370503216, 0.025517258778094284, 0.02245334566630904, 0.0507521030733422, 0.012254826987402575, 0.04507218930690039, 0.02022189625178374, 0.017551120310541124, 0.04774926057566078, 0.0989329622637841, 0.1079776491068544, 0.047063776592333476, 0.05108435923654226, 0.04384527651352748, 0.015105602947334129, 0.03651741952184708, 0.0865380120493712, 0.0032561813103741096, 0.07262592429235097, 0.061744668055325753, 0.037144060291710405, 0.012694315350193892, 0.021072587095982125, 0.08176795026708035, 0.04793411376135004, 0.10459139492482909, 0.023118478523927833, 0.0520736200644845, 0.040479400270288034, 0.04428950791818, 0.016334940408987385, 0.02354467430362298, 0.052025616995149085, 0.06956334991921341, 0.010119123241653847, 0.045295967420022336, 0.04054809537445826, 0.044218169810671004, 0.029984524308313287, 0.03412297724055187, 0.05429347473827582, 0.05120042921795, 0.09046414371339545, 0.05918938178388823, 0.014074857500682195, 0.03657680282729768, 0.007421652009079774, 0.03115133175836696, 0.0489754953812207, 0.038761003769092986, 0.0265345239501086, 0.022142892365434, 0.02400455879978836, 0.033125247310606704, 0.03777224089830153, 0.06910738204756091, 0.052493290690284584, 0.012603692894410944, 0.0706962637242771, 0.01069612630207332, 0.01579325400187724, 0.04219585473859503, 0.058689463448019764, 0.03387538145386404, 0.09387037746848599, 0.03144015456669994, 0.016895843174068198, 0.028492131405660225, 0.009847205120980019, 0.017989408788121036, 0.03896879745767482, 0.039675436959031134, 0.07257963725996595, 0.04426365628117516, 0.04591579000735956, 0.06588656455278397, 0.06794216231473031, 0.026186342734182556, 0.08031392304767525, 0.018803492120857683, 0.030837237624631777, 0.06227151438173267, 0.04096417304789347, 0.010332014287761863, 0.05093720523760684, 0.046987370813205365, 0.020296972868363225, 0.006120415280512985, 0.053473607441710855, 0.07885966600189287, 0.018621988654617342, 0.01959802297454688, 0.020717453632143237, 0.014574096891127769, 0.014248843729165534, 0.043871752512190616, 0.11963980557817606, 0.01874984298352032, 0.05997515050694347, 0.008897377711330211, 0.04376804718988077, 0.055206739644129435, 0.029298940733555826, 0.05152890856768336, 0.038019894141583674, 0.04841808980751423, 0.054414957130868594, 0.040843962361255, 0.04241455751921862, 0.05889154595112609, 0.02731534949083242, 0.0406024569735652, 0.034791814133284554, 0.04923654367185889, 0.01578572048475185, 0.011374235731519518, 0.03782636501015194, 0.06990014515336483, 0.052636529979926926, 0.05944282282143832, 0.01595289523397843, 0.04193675614172413, 0.06375465677270005, 0.0006608226554348104, 0.057810890833817186, 0.009465556396471878, 0.07976764873150857, 0.06200922119821753, 0.038865337283500744, 0.025547580538137306, 0.022989019240823486, 0.0022310148990307486, 0.02671750213560318, 0.07126100075941894, 0.05299775958842328, 0.03739672375001735, 0.011349884669236358, 0.011012987928434966, 0.014052626586729481, 0.06305104331864465, 0.05829978899489488, 0.02102843170324641, 0.021231330089992093, 0.023146515426736687, 0.023320938325336864, 0.0397809540792819, 0.035402884166086876, 0.1410444630610366, 0.010076294138637042, 0.024485298124472463, 0.04515200417729155, 0.011440890168981447, 0.044645221693621534, 0.031013050972814524, 0.009067227065022434, 0.010790366608078682, 0.006513598895136027, 0.033163501911105654, 0.07174539815394149, 0.04925179648243132, 0.05316361379359038, 0.04482914025204317, 0.0656223331668204, 0.011396269377831732, 0.029836454834308357, 0.0840202257818272, 0.04783415460898992, 0.02562360327330328, 0.06822935335578457, 0.023393291499345534, 0.005473454507263077, 0.026970606094466585, 0.019507105574913083, 0.05261135250029545, 0.003428439292380767, 0.052164784527473876, 0.05061694601130101, 0.02892062161868859, 0.05770931906637646, 0.11078315501612042, 0.03831380377373388, 0.04205939532708257, 0.019198950537810885, 0.04984370282580776, 0.04138549459317038, 0.07364172623642991, 0.15918482755941732, 0.08282702851800189, 0.10916678610468104, 0.20502415816149405, 0.18639403365312085, 0.16024610448268153, 0.22904728118690754, 0.19199265016903802, 0.19103491768961955, 0.28478929412461096, 0.18864743531711642, 0.1418970116684514, 0.0952003061050369, 0.15295619565633037, 0.1411043098496814, 0.1968815015448678, 0.14131731293614835, 0.1488221094252602, 0.12478608547920182, 0.24008326803243932, 0.09102666675443612, 0.1147248306041283, 0.13146624960485967, 0.17214743360396356, 0.07588172902262981, 0.14852529631987696, 0.14825678250241667, 0.11741843405029467, 0.14213600045730992, 0.08704010607494463, 0.11743480534923655, 0.13149831804537004, 0.17019124341107186, 0.1370971643876645, 0.12853594797272838, 0.11843104140772936, 0.10698794011747646, 0.16080039973941543, 0.0928953543846165, 0.24016087273916892, 0.08788084160656699, 0.1280824009389166, 0.08902763692481865, 0.08503336173992965, 0.13554107127410753, 0.13113263363559402, 0.19442867187242355, 0.11293702653699345, 0.11031541237307173, 0.11355607920596678, 0.13686776701961795, 0.1548894491767691, 0.16506688128555977, 0.1650258496163353, 0.20989364283459805, 0.14458855433810142, 0.11562820148443985, 0.12042862333116994, 0.11999612839351739, 0.17585126953499933, 0.1528902508078083, 0.13613627562599798, 0.1552665942618924, 0.2854192635465053, 0.09369311238368673, 0.30647417890929407, 0.10244908367073345, 0.16329685045826822, 0.17488985983354433, 0.1119724605532904, 0.06450343110989179, 0.12582742113379702, 0.15005958657110893, 0.23985122000017475, 0.16516228987564965, 0.16661649329527733, 0.12115150389652099, 0.10559385161726706, 0.11225186048015473, 0.2482604752144506, 0.09673725468136611, 0.20186760012180577, 0.11446406959646171, 0.13607860452705814, 0.20554646158651, 0.10707954125058268, 0.17587052898541575, 0.17493599364834447, 0.19411387102257824, 0.17634919604226468, 0.13056160701859382, 0.17846833313665084, 0.09904406033456327, 0.16612627363253027, 0.23354136745535561, 0.1529390046433095, 0.12974092766882914, 0.11592216474274475, 0.20093609849291466, 0.13020917592990783, 0.19450641447497954, 0.08144746504483685, 0.1037349928951552, 0.11500212378920087, 0.09445986680446133, 0.13627665357724314, 0.1283139203705134, 0.20208196684477792, 0.12142045438409814, 0.1894383138466266, 0.19578791103295742, 0.08144220968167629, 0.15670611943689086, 0.2675529593421567, 0.1355676085598046, 0.13117634661255345, 0.11971686636247944, 0.12962782244768836, 0.2199433834081696, 0.09777336561631772, 0.15188583293028418, 0.06942610526757856, 0.1479424259835674, 0.18272439588702497, 0.16420605892856277, 0.1014355187033934, 0.12070388638324316, 0.05601478237358313, 0.15735321858477208, 0.17522563617075645, 0.2564037293796578, 0.12050309473828924, 0.11964176676326221, 0.0604364043852735, 0.14327980037177765, 0.13390095363701546, 0.22414182102487934, 0.3446739275128611, 0.06279652975800057, 0.20307817225975378, 0.14641748200501167, 0.09373451943599409, 0.15399827441621214, 0.1136883979122485, 0.143468932158524, 0.13286845097618719, 0.14869143014713643, 0.10918504197991664, 0.16825029836787334, 0.2687372393425434, 0.1428144479230527, 0.09578142209999985, 0.21205283100566558, 0.11062713354946145, 0.16095582365749345, 0.11841341372459166, 0.11465892406000246, 0.08558466159287961, 0.17244675947773844, 0.10876871915834566, 0.19702479063022524, 0.13628826747017522, 0.09609286748473683, 0.15848039439128292, 0.13675982523108685, 0.13970370194123638, 0.10341608581403572, 0.21318331631200932, 0.1375037732143556, 0.24871732408721603, 0.12628610095670148, 0.10360195406622465, 0.15297674213445958, 0.12691944882634187, 0.1018475284499507, 0.1642266820154844], [0.036309629663704865, 0.05911847651605645, 0.13056370609950635, 0.0028670459916259375, 0.032923988352018985, 0.040193040434631615, 0.010368666806889158, 0.0359854097628305, 0.06006575572574812, 0.039053097772862644, 0.06972241275493177, 0.040652202892928355, 0.04410995989136639, 0.04790593321705538, 0.03609605201129471, 0.03415493459831323, 0.03593378309761325, 0.01666684417174228, 0.03251839459182755, 0.04410790294528969, 0.051755593984477946, 0.05387435569578121, 0.05844985412794256, 0.01414698084831358, 0.06149758171710757, 0.029265964478855173, 0.01969186874527124, 0.012634072111048287, 0.029666720393804774, 0.03139332935754811, 0.04520853380522421, 0.020590007245059938, 0.049412115702345494, 0.021471496739034212, 0.03385906761151648, 0.013157286223084217, 0.01123526163639561, 0.027883405601906202, 0.010325070658338167, 0.042592358865564874, 0.02560847878245817, 0.03926398645665857, 0.009408249189296078, 0.05841672082521743, 0.038220750904011155, 0.050237989128236814, 0.05627947341230127, 0.02207016380834243, 0.024688472302870888, 0.03549605577943787, 0.015749275766974016, 0.022364450738795345, 0.040944844649563876, 0.05827833853301503, 0.04004115584276376, 0.09244278028246858, 0.01416814402722183, 0.016211619405376337, 0.043249677626356, 0.03983569872235099, 0.04018232669501055, 0.02694634217468481, 0.0248988208946802, 0.09443426414603188, 0.03192332813576345, 0.011065611465563698, 0.023856489325783426, 0.05498343267508092, 0.05385798056639972, 0.0498123545079462, 0.04047313750150704, 0.01805666556221343, 0.08389450309257354, 0.07711853201110518, 0.03873167409291191, 0.008996316051531223, 0.05923664940881634, 0.026996337072623354, 0.04764206189241621, 0.1014634732517504, 0.009906507987198571, 0.03438903957665448, 0.06360390599096014, 0.032576307008463534, 0.044822122886656754, 0.03529469722941999, 0.06613256304614967, 0.07750509231681786, 0.003505412215975324, 0.055436784356471994, 0.033011268749232256, 0.012269297430682327, 0.03363454256266837, 0.01749653271549652, 0.04451744205829117, 0.030208907630895416, 0.02811349819474403, 0.046783284990177046, 0.008588289004570294, 0.03633323666309157, 0.0443491057282494, 0.0761951815577284, 0.07562718864890837, 0.025246490746916785, 0.04182455490433401, 0.11840410575631166, 0.036197279039169514, 0.040417289691826994, 0.010137109070896141, 0.04446118056113201, 0.03998364945272765, 0.020376981175955267, 0.14063132716523064, 0.034724915505296765, 0.05969169414452007, 0.020005840304938537, 0.03809333899088445, 0.02259745829618506, 0.03304270899764473, 0.037126754365500905, 0.0596052372918254, 0.02606553641418296, 0.07065636586518058, 0.0730054212674018, 0.029847099626016234, 0.0369100166004031, 0.07872611389405305, 0.011893063032579039, 0.04253243929856727, 0.03128372707344111, 0.02408019466055257, 0.03945410266638764, 0.03131900925279385, 0.03848369526226194, 0.056977735742205576, 0.00885749517399217, 0.0028624413243960594, 0.046884236226399104, 0.03463217673162299, 0.0971997879265297, 0.0030882447824678236, 0.034027262215292266, 0.025196624168705557, 0.016187654259885033, 0.06740346460813476, 0.044428713754901004, 0.040533627804008224, 0.03303260429792347, 0.037728344060240254, 0.03953541140823115, 0.004622263311889144, 0.10326823084464959, 0.015973255935785993, 0.01032028739686094, 0.049078863624843864, 0.03851791640983955, 0.09022832652854343, 0.057371562391880064, 0.08358229928079151, 0.040919318599926854, 0.05212836087711396, 0.021633068512704585, 0.05228271227209799, 0.05389959829288626, 0.023511016230669715, 0.04247296406256576, 0.05299246975130612, 0.03589472027435418, 0.06502238673067863, 0.0414850055840948, 0.04719741680028458, 0.03398507758374176, 0.09476864620322183, 0.0404269194170352, 0.023911255036270427, 0.017948162614277775, 0.018454454801676255, 0.016713786209302566, 0.018052655091929822, 0.0494844573850353, 0.062466686771761995, 0.03205488075412089, 0.00023076200704963415, 0.025477956552358887, 0.03624174278229475, 0.04642983117411214, 0.049198767876312624, 0.060327416886725736, 0.007771486059702452, 0.12703137427207925, 0.02988882268959236, 0.023751029662126978, 0.033804924347467964, 0.02362766077802066, 0.04067130146488067, 0.020576746263090643, 0.023991083313200264, 0.009404880317649054, 0.09885862109161193, 0.016210797776077545, 0.03088671158278181, 0.1184613861504101, 0.08012928053616516, 0.026528368433637005, 0.044445100375601364, 0.01627139724610794, 0.029154898966812802, 0.029420132012737375, 0.016626274070492195, 0.01394126230039664, 0.022846957811364726, 0.015278720623633314, 0.028505168306911667, 0.019100504409101222, 0.08172100439908044, 0.02013826626352966, 0.030221532759887558, 0.025209260789016565, 0.0868343731628791, 0.03538226107916525, 0.03745707232625254, 0.024460283438524893, 0.02540042079354246, 0.020997629223030903, 0.014342204949277786, 0.06696255036419438, 0.04908509191966826, 0.02074079250075644, 0.0352830488625313, 0.05756778815280526, 0.02331677080702878, 0.03855859950905846, 0.06892812513415852, 0.031338157620461236, 0.04945467571697889, 0.015349372124840176, 0.02581722816572555, 0.06145244764704859, 0.014527153895957576, 0.017953724412608053, 0.008526655315842119, 0.02395405636859998, 0.014242993690253747, 0.07871444637496626, 0.022481957135061105, 0.04233243289373575, 0.11831316345882033, 0.025374804728574334, 0.005883908137724165, 0.06371416136502259, 0.045838913084158016, 0.03083563650087003, 0.06554557881768673, 0.022538597845742782, 0.09689731343138604, 0.07258946616803447, 0.01891940888468056, 0.011696908134786833, 0.0872938497172248, 0.03923559523818474, 0.02107314250972723, 0.04638231840104826, 0.0406315759755671, 0.02888852636510086, 0.03590047359466553, 0.037862294533800696, 0.004537579952739179, 0.06648109474730107, 0.015959812050324776, 0.026405062751784444, 0.03299927947321727, 0.007120238545711243, 0.028855900595625563, 0.02269449865355367, 0.008633849211037159, 0.04054131166588876, 0.08525987095650166, 0.10606775360722696, 0.014768556819387503, 0.07488985200442615, 0.05306771107678933, 0.019924573697930863, 0.04360414267848096, 0.09430967526690615, 0.03060597866292923, 0.07134769892980976, 0.06901779572569555, 0.022534685051669518, 0.08715334153103252, 0.05145047648599552, 0.0629110599026805, 0.05864394633399864, 0.05379572060079344, 0.04342372131143366, 0.037792285588840326, 0.035367272568926696, 0.036714242831353223, 0.01468949367277204, 0.06871134523422488, 0.042822043516583023, 0.017434550456762794, 0.05552549350766405, 0.029878482417834383, 0.1260759400564336, 0.05425030568374261, 0.0312193124855478, 0.031964424922461473, 0.020147568486150236, 0.02246839546358153, 0.028805806106256864, 0.0818366147277336, 0.01452827142671712, 0.01313334214501083, 0.061842290639516816, 0.005611821477706995, 0.08441761090990998, 0.033343758569249225, 0.03034647595467827, 0.032835616279513605, 0.03239249953279092, 0.023612430950085965, 0.011669976313808754, 0.06696913105946395, 0.02807109522813511, 0.05025811808844728, 0.055053311385094165, 0.01793027637646564, 0.06417686314952951, 0.07276405760597798, 0.007355447169468408, 0.03998565660308927, 0.031638048484080264, 0.034829306476298845, 0.013022927807704096, 0.05173038203088988, 0.020845035999833096, 0.07470235964583774, 0.05742079886277357, 0.011236537172789536, 0.03295512216526174, 0.01838484039199689, 0.07143029852980567, 0.020928629598910772, 0.08588031790549717, 0.07739253867898258, 0.02601630377372907, 0.06589960336925522, 0.022455278123098037, 0.04118056224298574, 0.02769461280906633, 0.07095046701931185, 0.019994498373219566, 0.2330852540269975, 0.0954002550532741, 0.16200072162093657, 0.1487967519149665, 0.16597423582307755, 0.12035535468209176, 0.18984225668734123, 0.13594573423747094, 0.14804138922162596, 0.24680572021151745, 0.09485799503783066, 0.21106718228228633, 0.15771099696716956, 0.22245556957298712, 0.162256303874235, 0.15494511312534734, 0.08041026626503275, 0.19578766588482166, 0.1909409340230688, 0.07989658132916497, 0.09068091595244986, 0.13392396691826083, 0.18772469773407907, 0.12272276555097873, 0.12886771000921726, 0.26610450158196114, 0.10714770009320591, 0.1598227030086902, 0.16819480295863845, 0.05916158045311609, 0.11971390926309171, 0.1698777449106978, 0.10787153826846231, 0.09657659838276525, 0.14561728784634223, 0.11707442226789652, 0.13928710332801267, 0.12407626671295975, 0.19739018392659005, 0.13610753200707898, 0.13610212342633357, 0.12705667815621824, 0.1522405776045015, 0.10250001319593961, 0.10903715636701354, 0.07137664939246832, 0.19543587830999207, 0.11604663104780259, 0.1974495097754463, 0.19412703241311735, 0.10435537089623752, 0.2183326988691284, 0.09233070928002558, 0.11950452211162738, 0.13788226661422562, 0.15092690535370382, 0.12824596837162971, 0.11432294853993001, 0.17121841409994712, 0.1517157460893354, 0.11170270567339276, 0.1339252845894906, 0.1315110504266716, 0.2278737877044947, 0.09842406537744308, 0.10999861203374402, 0.14973704823322836, 0.27321379751928393, 0.10372717879832753, 0.17843703078406473, 0.20664795812579895, 0.12793430848227394, 0.12819392801893334, 0.2287222760459108, 0.23751526470145873, 0.11689715718309726, 0.17367976267010937, 0.09460607468481026, 0.1900913118715248, 0.2077917273967497, 0.11931102362371261, 0.11169053253627594, 0.25538483244036475, 0.11811311491915297, 0.14127816584321762, 0.17014310244591008, 0.10594587667935318, 0.13477326731287664, 0.07459985708156902, 0.11221411532812542, 0.08179693903413512, 0.1908079871246892, 0.11781904440853866, 0.15788500617829063, 0.13040593795238004, 0.1683735006278561, 0.10858997552385254, 0.08448883410423033, 0.09050032604605922, 0.13594976385995267, 0.20005129758388768, 0.1574560582277275, 0.164733387890362, 0.16302824471025698, 0.15938928110464928, 0.19263827842810463, 0.11697283900913694, 0.21017162549880244, 0.07308040595343036, 0.10112781948860615, 0.17781590201681663, 0.12832938002482538, 0.3113010844155666, 0.16774455776378033, 0.18748109709591637, 0.3425588813279906, 0.14424189955236452, 0.10997384441115203, 0.15495160955094522, 0.13662183747416543, 0.1562254758731973, 0.09402983100904573, 0.16920816874311817, 0.23411443186623437, 0.11284041518886244, 0.1363367608357822, 0.15847146180608582, 0.14762773238603147, 0.1627144550964717, 0.13009427806302426, 0.09024066054412434, 0.1873304995317613, 0.0988949106765851, 0.1086394188384856, 0.2099908900357062, 0.09225634512521567, 0.16280062466619477, 0.2604241741280402, 0.15670978133716892, 0.21594164652689812, 0.1185828340690463, 0.1204455462134173, 0.16761211648343072, 0.14143450906680477, 0.09893129985298842, 0.09465087550662218, 0.2424909138391095, 0.20860989397812277, 0.1878266793585593, 0.13491510083117794, 0.0837326133924146, 0.17225379725137066, 0.23350660238535176, 0.15724699283319135, 0.24616456590592864, 0.10128793186478077, 0.1530366655318968, 0.18890122492467204, 0.141270321102873, 0.10377595561646646, 0.15570222249915525, 0.10788594838231803, 0.19965026587728532, 0.10699575421430411, 0.09435402409684274, 0.14603109789952157, 0.12187338088669124, 0.14228184827633444, 0.1982722422408481, 0.10721726853760982, 0.21939172349389524, 0.12035469584647687, 0.15952480205845448, 0.13574003962980163, 0.1517363078892231, 0.08076236793591131], [0.05980323654629531, 0.04251546279016522, 0.0019763399811176165, 0.018562563214330904, 0.018470462208854097, 0.15391579739028408, 0.019538541992885933, 0.04937820865081684, 0.027933402415064555, 0.06848316594597793, 0.0778785984843008, 0.043132757287352316, 0.022820822721827897, 0.10847675538952313, 0.06388027220964432, 0.029841811704118888, 0.027488952675353617, 0.06949378913568874, 0.01445292380653442, 0.047215665014640945, 0.048699910572219285, 0.017944663507683624, 0.043002139296262495, 0.06660606667038894, 0.10039503340639415, 0.036415951176276135, 0.06326460564929633, 0.044169641971107454, 0.02140921570601002, 0.034506350620499546, 0.013947807564099711, 0.03835280914039862, 0.06265926595416761, 0.06091522082926766, 0.04021521484959991, 0.007622146316158075, 0.020084092355964166, 0.04037205986077747, 0.05849016950495782, 0.02020275362977578, 0.04190572575035115, 0.055550766748286066, 0.02570423594255361, 0.038741445544386105, 0.013189358494034218, 0.003813536370158076, 0.010103113919256196, 0.05519943882621104, 0.079507140532857, 0.015064909314406256, 0.007478365498114258, 0.0570116006588984, 0.03066918091668237, 0.018740190275674386, 0.050896460851353985, 0.01245188586894543, 0.05909550153920728, 0.01997987758518467, 0.028381081215376337, 0.040996509619177356, 0.03305436502541265, 0.057492707705786156, 0.020029920363618482, 0.04157643817785767, 0.023177404091843677, 0.0916121724332052, 0.03512113617973463, 0.01947065702669563, 0.04622247032520752, 0.029494279747708674, 0.016894190339371562, 0.00916081811151197, 0.05517367145887787, 0.016853775370926145, 0.013716735336328707, 0.0810200875745185, 0.026016142895264972, 0.020180155951229316, 0.05307853206871979, 0.024074588812166647, 0.08388634425617995, 0.08913278249242614, 0.0819512291420852, 0.021762131345308116, 0.051010481547564275, 0.08306086919600926, 0.11597133226572506, 0.0287724697902318, 0.05468087774070521, 0.030020248903442296, 0.08812846420633216, 0.06507222841103232, 0.043499092871864, 0.04334440056775366, 0.05408496092704516, 0.04696073010563851, 0.042334351943986076, 0.12465275553686005, 0.0341794302596921, 0.05517586630078093, 0.07052000221465865, 0.026500693507372376, 0.08339065472565352, 0.01571791212735397, 0.0805633842584587, 0.041932324323082165, 0.11616012697378475, 0.03485101357763333, 0.04148928801559153, 0.04939485191097183, 0.05087309133922381, 0.005723428039345891, 0.042507821063120524, 0.08385157918617611, 0.04435661722034697, 0.04301697075847657, 0.02352984667184853, 0.03817997970468095, 0.02158140737353073, 0.052916270815917564, 0.03453571094019759, 0.047504077965934435, 0.055929240995957974, 0.03721356744908037, 0.03026750186578401, 0.03517610298830175, 0.020355151500552893, 0.03372550018191819, 0.05303502210506028, 0.07476573043893422, 0.019480524239160364, 0.05935072756162094, 0.04925254724859711, 0.022367695121154673, 0.04582102876156569, 0.021632666316544338, 0.03152752497924432, 0.06113183985073721, 0.02586112691900663, 0.06574719783759887, 0.05412841726454997, 0.057872426846335014, 0.055002837682202946, 0.024922820514128096, 0.030705575838745124, 0.05108550453798906, 0.07211176438197013, 0.016940609521923528, 0.04199570660749751, 0.04314349017917149, 0.05561968784839396, 0.04649566493988518, 0.07483927487966514, 0.03432488737387523, 0.048653887840168136, 0.041469844704073285, 0.034756853710860014, 0.049382851143637975, 0.05991378303376898, 0.10774215367893059, 0.016435970169221683, 0.07065329385260422, 0.043036027195593046, 0.0521650028625323, 0.027272609445536812, 0.0822229988332237, 0.021650539147817803, 0.037943607106083826, 0.044473074076156464, 0.02367737222342722, 0.05243936576129449, 0.01747971133989913, 0.01652036241496042, 0.003107311753293259, 0.0515908774198784, 0.03217699899969082, 0.015068455343885769, 0.05771802948607553, 0.029735279517368447, 0.015568614997450384, 0.02700417032164912, 0.12345493876285131, 0.05960920562727317, 0.04985349342948006, 0.05127492360770703, 0.06688222604533357, 0.02892152560243924, 0.05572089189363103, 0.01864618362648593, 0.057600791220583265, 0.014326662940513945, 0.05060884080106213, 0.017074740026146173, 0.02517904245084332, 0.020403411209342942, 0.0322378455330768, 0.05808024351755458, 0.08891332128475751, 0.07777483953583626, 0.015003476723758204, 0.09510369475690589, 0.01940576554906945, 0.02563120095029233, 0.021709196584960146, 0.026850073650899916, 0.06411342340851985, 0.05687229140030761, 0.018563873224681424, 0.06815308930292245, 0.07022825295045491, 0.029826011140680606, 0.014390119918501906, 0.0777547144060654, 0.03302591251990488, 0.08523270547870668, 0.030260748800731478, 0.026696718170217452, 0.027414341457188133, 0.008794853122033661, 0.04766016455006696, 0.037501792708832415, 0.036263767810117815, 0.017026254321418462, 0.043410261146604054, 0.03563525395527963, 0.026286039501428608, 0.02933849768352605, 0.0550180253753018, 0.0192097274796857, 0.08617072651583342, 0.04283999295664891, 0.023059978134809964, 0.020444613333130558, 0.02035686179184385, 0.03270850697111699, 0.028286658963488958, 0.03155929273024442, 0.07444489281624556, 0.05084526319537432, 0.040358706948257266, 0.029956715316661907, 0.023854838406306603, 0.031840776416262796, 0.008970323645870292, 0.04371135668348401, 0.016250191932363857, 0.005278546896372592, 0.02762526269972084, 0.03439879187593057, 0.012724693609221328, 0.02987570534910887, 0.04857526423649923, 0.04621004437907569, 0.05301809922281293, 0.04090110485952708, 0.06290500397763907, 0.06861494839071267, 0.06508078561314652, 0.021658763101684953, 0.03227601586390407, 0.06712879910464249, 0.053784754052157366, 0.04783849832752059, 0.032921563683738636, 0.03313315333798528, 0.058464995855765964, 0.012342142816182348, 0.023250215003387104, 0.02509759006751401, 0.054668911447327946, 0.05028556701877425, 0.029940951142400026, 0.07746057494753793, 0.08089021268871524, 0.04409492541585238, 0.06385397241120377, 0.02447942223009323, 0.015699638057530167, 0.009915391734290508, 0.11190434001506337, 0.05826091386317726, 0.01120835854371469, 0.057690530760033484, 0.03863698179503122, 0.01753291806146022, 0.05535137704423359, 0.023677521610572457, 0.04818612221448172, 0.0176820523976799, 0.04537067631439817, 0.016833746002145836, 0.06454825491434144, 0.013154283158421038, 0.06476953941126985, 0.04045714158564806, 0.04498207438436728, 0.04004086089891292, 0.04485200797658294, 0.06049605965193722, 0.02932593192634804, 0.010619630507614103, 0.05530935329114718, 0.0428972618594285, 0.055598892391689365, 0.04369671291281139, 0.06009051951790049, 0.024735967838956464, 0.0520959553579169, 0.04471454498988967, 0.006829873506625694, 0.07344270425458109, 0.039657426231931296, 0.01448828163706968, 0.022283325858053663, 0.07015173608857779, 0.06385603701815971, 0.012687350653352277, 0.040092131333245386, 0.0350139451573693, 0.060169292508714625, 0.04397728112376025, 0.03040175111363492, 0.047777387493800734, 0.09919770692865695, 0.026855687160165082, 0.040035666822786295, 0.07290710920407888, 0.047293032234114026, 0.04441399720587558, 0.04693719205416499, 0.022738357187218727, 0.047332520236171065, 0.03021976309678247, 0.021159275690273895, 0.05533362678702801, 0.022336856251762762, 0.005482519721432079, 0.03672198414982807, 0.0262545571181803, 0.04746303480539111, 0.025188591736819477, 0.025876305036006436, 0.06584229999251905, 0.043373622991625345, 0.03430047598216803, 0.04720253426761878, 0.015922163616895916, 0.028787663228990092, 0.02967577363784996, 0.00793661822700092, 0.03683643002483634, 0.023340709139442733, 0.10122328170485075, 0.15897323407473105, 0.09723057700020653, 0.13264245503852445, 0.12146056674781347, 0.17961725051845276, 0.13528806307623464, 0.09728676188857326, 0.13081893595235963, 0.1878503055101441, 0.2411050607840861, 0.11758818381255674, 0.09818804900973074, 0.16367758083487713, 0.12140063568949701, 0.14444894247478055, 0.21957219848709725, 0.2300663619873024, 0.147926889720463, 0.1654631019599976, 0.14240148056659008, 0.17349931832042434, 0.11628558919314416, 0.11982876116469984, 0.20791040973797922, 0.12642264080744597, 0.08132349669692979, 0.15573107337038364, 0.08038379026636963, 0.12143810504987357, 0.16611798456118954, 0.10150228326599445, 0.17767322580179862, 0.17414733677381472, 0.152064882999947, 0.09309564041154039, 0.14121298708261984, 0.11272367871096058, 0.1753044819399234, 0.12590890990630274, 0.1256385804604619, 0.16101844368442414, 0.14674832473599142, 0.23475915614155032, 0.09897026308481732, 0.15440166567362126, 0.1545121355523025, 0.07906643313265617, 0.15564979144161747, 0.130637556975407, 0.06050187808972213, 0.19002415660408237, 0.14014139861589478, 0.1828781956987035, 0.304353341099716, 0.08326052703083524, 0.0910381350906626, 0.07170748446256885, 0.1511444436806825, 0.11825523188998623, 0.09932480857617433, 0.1452200712576028, 0.13333444693876853, 0.13924789494804798, 0.1876521645294082, 0.17893880305270995, 0.11378369925002899, 0.11382103837545841, 0.1077785428553339, 0.10194909638695179, 0.0658659721093793, 0.10644706672117596, 0.17411634085639832, 0.1258155161274537, 0.08453580295486797, 0.13355575441833467, 0.20456065964554587, 0.12365230599478369, 0.2097992454805682, 0.09495836787766988, 0.223463955785959, 0.1609694140572702, 0.14136412090832187, 0.11159798911502285, 0.1728838739255744, 0.14807331976630997, 0.2193098746600651, 0.15905520548262905, 0.10526863963253076, 0.17073947125144545, 0.15986269279833765, 0.10798882632966965, 0.07537112376021762, 0.1392433137422608, 0.10448981166606951, 0.2875438092216369, 0.255052411568261, 0.15469138480482564, 0.14425847769504593, 0.14464571981901123, 0.10385366757550549, 0.08743877056986095, 0.10949863241084161, 0.2153587455470716, 0.15564240635402743, 0.16995018618481775, 0.1568810173100041, 0.16791446074362726, 0.2579194649813637, 0.16728827579607888, 0.18390610183198608, 0.16902944043038354, 0.0774825310274478, 0.23171009555939706, 0.13970195526076903, 0.2308482772880985, 0.11224998356474024, 0.16725852094109983, 0.09828961694673186, 0.08448276668787004, 0.14905490822369052, 0.17829605528423864, 0.24771669068403784, 0.25436441864698167, 0.1451799282503705, 0.20111312609045737, 0.12813943618487927, 0.16532390378415585, 0.10131945638286491, 0.14546555647205922, 0.14976145579449593, 0.09102658248476445, 0.16243648775402578, 0.09602088586337144, 0.13182808825325582, 0.14238726197471543, 0.06476898016708513, 0.11735599788446581, 0.15288404549562162, 0.114478939363072, 0.08870653883223573, 0.21700811752628898, 0.08703475878123315, 0.17415104463936823, 0.14372846742551174, 0.12825965836283662, 0.11322601788466978, 0.17603205096337105, 0.1523064918095066, 0.21783641179002103, 0.16658355151453327, 0.14599025009139893, 0.19924068462944802, 0.11813095710690945, 0.1674498897045851, 0.1764639406915634, 0.14106402894662273, 0.140704411953207, 0.1843109639782098, 0.18361362478425428, 0.07829233192868772, 0.13732930435047996, 0.20338768710292157, 0.16125562450578138, 0.1192621089097473, 0.13689508571499778, 0.20850639549955247, 0.12785814402084197, 0.13798250155823846, 0.11630877867461213, 0.10263666029899352, 0.08496400780014454, 0.11471241231887572, 0.11945524733633765, 0.13638611221986432, 0.14860487753345122], [0.047630700808499134, 0.05508282109193745, 0.004476805718901057, 0.05023189106835954, 0.05889660596186596, 0.055273266719473954, 0.03239239611092114, 0.014801230469358065, 0.030840819085677786, 0.030717861973830772, 0.08450148221586021, 0.05078503336276739, 0.035189498035657796, 0.033653281073296265, 0.032170019938700625, 0.012258826923977223, 0.02081057928021877, 0.02440521129286818, 0.11327893923847906, 0.04791523352445615, 0.03800965920691529, 0.032302606775755846, 0.0386301597820655, 0.03889058371104541, 0.07057901396746598, 0.009820559625363639, 0.023454530652792707, 0.05042854966896196, 0.039830485494026256, 0.03440061516519036, 0.06868582684546709, 0.07676119029882454, 0.0077453097929396945, 0.04162339936761607, 0.023658783099944555, 0.0445907719944033, 0.045219228392647165, 0.06170763536506604, 0.0030733769310773503, 0.02555163505847656, 0.01592236663019585, 0.08693486091590698, 0.038574522646564635, 0.06590991491271604, 0.01591467223460636, 0.041602431541128505, 0.055148122426603115, 0.06633029033940646, 0.03317363342390426, 0.08658703401564591, 0.028288723570444894, 0.03876678390248168, 0.015482754735726745, 0.031162399813653003, 0.06234140458306479, 0.024731528359435262, 0.048249623242525325, 0.016288634224404252, 0.026818284832481897, 0.024205595592878038, 0.03993032207231849, 0.0458309993959002, 0.043461983572811856, 0.04617496138258327, 0.06072688960440217, 0.04954835294835991, 0.08068335362740102, 0.05149667158782963, 0.024467339108307517, 0.04736716656254665, 0.021670189303075595, 0.04491761957685794, 0.06423209808887013, 0.03104131004112142, 0.029028205261115107, 0.055915068369358785, 0.051244632491180976, 0.020684237974966248, 0.05187636774574077, 0.04864186409019655, 0.049730777635329196, 0.03805603816985123, 0.03873864932346248, 0.05403541802098194, 0.06496216455895094, 0.04381233473278342, 0.042740026143409555, 0.05281464159188252, 0.048228203424162445, 0.04816422742160578, 0.046134167200615334, 0.024565235568931507, 0.012780840193191844, 0.016481883733743624, 0.02127635690774168, 0.043921931271230986, 0.04829180404363621, 0.04903548389613148, 0.007835124025962526, 0.06582094912206934, 0.018269957846871788, 0.0158443252533494, 0.00517528638386378, 0.054021042381082816, 0.03311934460315012, 0.050372617589610244, 0.019191247523732243, 0.1132649657947402, 0.01737294358111197, 0.06689679703765339, 0.03723294564312504, 0.028380497073334073, 0.0630293591999479, 0.028580940148282438, 0.037334168840560226, 0.13836284889088524, 0.031508943516640894, 0.0968204748125807, 0.07284641205783814, 0.03452221247097177, 0.04383816721759016, 0.01066900295911417, 0.05366594913685995, 0.0672820549938948, 0.06802111533620665, 0.03005156274734726, 0.029553693696676247, 0.030684056428952083, 0.032314132568576646, 0.07332648105558849, 0.013219481071216926, 0.012493384851803704, 0.028108187290208957, 0.02756611688152677, 0.05904616930732324, 0.02249475080339659, 0.052745310634735136, 0.035141943127758084, 0.060723235365003354, 0.0556288042946929, 0.023024830020843975, 0.04390763607056391, 0.09974012016168526, 0.04340220956251987, 0.05430386672096868, 0.0967436591764131, 0.04088212120076341, 0.008092108220162412, 0.014112635211448276, 0.056474488754306114, 0.013262478713577074, 0.036210834964989655, 0.061215033168874444, 0.061744595276972944, 0.026758621904938936, 0.001820908521861589, 0.07292680532461213, 0.03615934619559877, 0.04069084436782906, 0.07689570001656972, 0.04239921277809528, 0.06656408505213839, 0.06973398834346764, 0.01862190055450605, 0.053370695020402634, 0.022136564479179444, 0.06414700104224105, 0.07486156037738247, 0.05681030722635408, 0.05100586586782048, 0.04426357201150349, 0.0558741401220041, 0.06911043107749955, 0.03351793248927401, 0.012281916814015038, 0.05033059766696346, 0.11470437605655003, 0.03509984659631887, 0.040471241433894446, 0.031108622356588324, 0.04650806024250004, 0.04904002296708284, 0.036418881462586504, 0.04763464616130918, 0.045788466194344145, 0.04624435745720421, 0.02108491536590361, 0.07121089094829175, 0.008695423527951203, 0.01814325839551466, 0.07559911152648349, 0.05301267915074864, 0.03853149531829742, 0.02787870373727093, 0.044904086633675525, 0.032399616489607486, 0.007460076106531967, 0.04273205882899704, 0.0818389053306272, 0.06408294843089196, 0.026921877156822916, 0.09449029581681376, 0.018139529462543227, 0.02575197854199477, 0.022324790366955345, 0.018250340250350775, 0.01961087984513612, 0.005987230416071872, 0.029237322366586136, 0.027973058956464934, 0.08395264916602643, 0.030720794175360954, 0.015346469609217058, 0.03683927221103542, 0.024457962192114324, 0.07821989065456776, 0.08680426590745488, 0.07642781947769466, 0.10679892324391874, 0.07380725485422919, 0.04537635685635671, 0.0032618230691314827, 0.03104887515937369, 0.03790985710257965, 0.0336844110560994, 0.042965577750076214, 0.06619337510557906, 0.0024257115963395807, 0.03543558845957441, 0.09962209665607061, 0.0040084377565841765, 0.01621523917081856, 0.06303840286789403, 0.04123544478188119, 0.013199805060491688, 0.014231745604305499, 0.03777757287025452, 0.022373639963447087, 0.042352500566912275, 0.074327313641627, 0.029253942644103404, 0.03535765816547698, 0.014625466916890395, 0.030510480057508237, 0.0319663267357335, 0.006069039509090926, 0.07137697114939652, 0.09284902138695603, 0.05018916634482242, 0.0279346626297, 0.07673716578151911, 0.08029685460872228, 0.05451182894889386, 0.014186669948450742, 0.01284395243161388, 0.023634390860435464, 0.05594619069128268, 0.03198114479140889, 0.03698433095949792, 0.08130900997428164, 0.03391640546220926, 0.03874698819051828, 0.05607781608799293, 0.06819350044092826, 0.08640277454809797, 0.02750657652805169, 0.060771924083031, 0.03955937846894226, 0.02850720035513082, 0.06932591628884116, 0.02384537913566155, 0.048250864304962664, 0.0546918825937375, 0.02466573481327824, 0.033084820850842425, 0.04504029323617297, 0.03479437669739127, 0.06509063750385277, 0.014413694359151828, 0.00554132846093947, 0.046828250520892685, 0.011114078018093302, 0.023829685824532664, 0.03929229340546074, 0.032681770502559604, 0.01844760406041338, 0.04977735578112545, 0.022426377456154556, 0.031630642329072284, 0.01559917041431031, 0.030880353053010283, 0.06623327296467559, 0.022355324716397354, 0.0814229732138976, 0.040420599191659884, 0.007226185154004564, 0.005956269930221982, 0.09052920756080458, 0.07191213719066113, 0.05087864164623523, 0.09520350069168115, 0.019935687718492363, 0.022207395053438606, 0.014186584721169165, 0.008484361516762405, 0.05108851143309186, 0.06829638604915912, 0.030010247625590816, 0.024107187768564593, 0.01752950130931793, 0.03455355695839371, 0.042645490893553344, 0.06990453483717096, 0.015994439224502253, 0.057777125508554524, 0.02225390808176129, 0.039509670853975325, 0.02281973679219523, 0.07920169361656712, 0.0912286534965519, 0.03481010831291637, 0.02679419902814252, 0.0173015920670643, 0.012864247058337976, 0.048730370228088675, 0.04131812099066954, 0.032709828472786376, 0.053265537961476275, 0.03017234225426951, 0.0752775154767498, 0.013668205581545351, 0.017125822768937198, 0.03447555388594347, 0.08535590007781022, 0.0352211949235249, 0.07195957335493258, 0.03704209781942829, 0.03538611067098475, 0.05168245557034689, 0.04655251249430641, 0.033458016752716035, 0.010011508955710359, 0.06577802521567191, 0.054438353456076116, 0.045075889511574666, 0.030959016876295212, 0.02484375832512254, 0.038103665856103745, 0.09398080904277102, 0.0730035443519873, 0.012693088651905137, 0.06260590793024148, 0.2847943809484282, 0.11770017054532805, 0.17706800101985856, 0.18552559638215652, 0.19129436102605638, 0.1946638302216607, 0.20452022552490237, 0.16068865815477987, 0.13348567269502148, 0.1296252330705043, 0.2302426847839548, 0.10771719453435753, 0.10756409186269007, 0.1672507681313061, 0.16103417913038887, 0.09950149909503038, 0.1157405712611733, 0.11496096188502927, 0.16534955240786076, 0.15391326930013396, 0.13590050440642143, 0.16108155400762636, 0.12673848353686834, 0.1548900007600746, 0.1699854875163686, 0.16604376596308526, 0.14424985154501854, 0.14875562831519112, 0.09044759621423099, 0.09243009386644249, 0.14578728275674005, 0.11381944491257591, 0.09505814316892817, 0.1291696405819347, 0.1813479810352287, 0.15477173210632417, 0.11381334685269864, 0.14927111355768097, 0.13248592795383546, 0.13662120928206753, 0.233785305172205, 0.1621178104992836, 0.19321488216519359, 0.2082073913827058, 0.12206458111083317, 0.19680213483591236, 0.10442204352828766, 0.1711280310466405, 0.074860725341545, 0.17996254166768444, 0.11990617434944838, 0.08673538694218283, 0.16554407745359406, 0.1880622820387925, 0.17316369520079705, 0.10591845839254319, 0.1361348813459758, 0.12834202047557602, 0.14088729246249124, 0.07838332785233375, 0.1120160049909065, 0.08323515419878307, 0.14631913163729254, 0.140861980917473, 0.18239752149149296, 0.13885930450933595, 0.14482945834677066, 0.13561731234433191, 0.14284928960184898, 0.12762089425157155, 0.144277568606119, 0.15125647637872927, 0.18913192464218986, 0.12311986722652951, 0.1346176442119383, 0.1624960893945348, 0.15614362703936716, 0.08832243766875998, 0.13458120907025953, 0.28661209308812696, 0.13554929905841429, 0.10814355310773659, 0.09090576275822618, 0.2737291601877059, 0.1335123938418204, 0.10926205679894456, 0.13804631668233103, 0.21081057347116933, 0.26208064008143644, 0.18324524374498477, 0.17012617190278348, 0.11344140350458123, 0.0931356072185501, 0.18453651558487646, 0.06749778535337218, 0.1666217333366794, 0.0960328521567487, 0.16779734122176326, 0.1633128310523687, 0.1854362705301854, 0.1300241810179526, 0.2070198172042447, 0.1418141669203197, 0.17039727509742783, 0.11429631932368202, 0.14546405493972764, 0.09979304151549455, 0.13193423739604412, 0.08687725876488032, 0.167495793693008, 0.172633562357195, 0.08712549423498493, 0.10926688315286752, 0.12718111381775912, 0.06549458800544662, 0.24034736918345576, 0.09639228528906262, 0.20916045072578618, 0.1895972617691563, 0.09929052614156278, 0.2019426001295928, 0.16254130390382585, 0.15480075151689593, 0.201539408055044, 0.21510731549032275, 0.18996267038727963, 0.19865769171907058, 0.1437949485355808, 0.11834089584167927, 0.146919667961136, 0.20554580275089512, 0.12026568409055473, 0.16783287237969138, 0.0813074624766746, 0.12584949212689556, 0.1715205898208003, 0.09433728507569722, 0.20631385186026174, 0.18661771600525226, 0.14890434130305244, 0.14322165429832476, 0.16175629360781563, 0.20686267724921628, 0.1993492086448016, 0.1673112584338073, 0.23452602026443328, 0.06831308676590843, 0.12030617949823219, 0.15020194102919873, 0.21384956765799754, 0.1452655155932711, 0.1088363953655766, 0.11691077822639097, 0.15665831555041576, 0.10956392608462803, 0.0691501910407697, 0.19462434605004328, 0.11261929157039813, 0.07704646612006812, 0.23475538698896287, 0.09847586058200368, 0.12261880741965388, 0.2596786786471644, 0.16573756061975034, 0.14593814079078937, 0.12448039341477618, 0.1267288691334186, 0.1825621997516963, 0.14500081689367372, 0.13226615265011787, 0.13260937536195402, 0.14248144482412647, 0.23832307377409553, 0.21525371489265274, 0.12235746418516483, 0.10319343768060209], [0.01072685600393602, 0.04915141215127322, 0.0561703939832026, 0.018540197277381536, 0.0041576017787109225, 0.05436580492964676, 0.027818586902632832, 0.02061639705883159, 0.05493329222043676, 0.029247591775211117, 0.05668513228996627, 0.01864787476557878, 0.03588635842466066, 0.05395040524402454, 0.029611460556606614, 0.038702229503542185, 0.04081348355318751, 0.006377362127926562, 0.04441220456013276, 0.046538313054629875, 0.05849440980161871, 0.015370943245568104, 0.0457745693593977, 0.035711560142977584, 0.07282129969568023, 0.05208930571473414, 0.023432356237824407, 0.022697934557894067, 0.05800368835128123, 0.03865224226648289, 0.054031610563998266, 0.012574129561412961, 0.032555814156489025, 0.13740770578865083, 0.028143965511492668, 0.03393572236921999, 0.04993128582775112, 0.03189183617641609, 0.0287853917782946, 0.023712512676513964, 0.0499608836347057, 0.04703864124753783, 0.018234409451965364, 0.025876128835783854, 0.05619997263795907, 0.012525724295917298, 0.048286897250481194, 0.01504761775234534, 0.022776211506777236, 0.022184228554608363, 0.056832665502424204, 0.03545948274193272, 0.06438118645981436, 0.04416166316537608, 0.0536475055700829, 0.02113476279191673, 0.062282262595310334, 0.04823491052393952, 0.08367264402970191, 0.05126429796819726, 0.06715861524665548, 0.022990078357378804, 0.03969012669497921, 0.0305171316159108, 0.01460096263702238, 0.04637421319080938, 0.043084869131205544, 0.013872700304003253, 0.05607869708910585, 0.06828654948021136, 0.04940836187151652, 0.04121785923357933, 0.033166072136091615, 0.07329109545436598, 0.0203577121494398, 0.036252376082683765, 0.03771378455923931, 0.03004541680697472, 0.047981090272866914, 0.08794084927367588, 0.04699905365405064, 0.07227605959821133, 0.09624383277109555, 0.029791096683531523, 0.02737535715794131, 0.07372874616374893, 0.07328129718981444, 0.06031663036875187, 0.034058928459642396, 0.040814644176392786, 0.07508993884848972, 0.03445496527297843, 0.024037431632619233, 0.0068385614224919875, 0.026977188704955964, 0.03014324815012515, 0.04655792873593108, 0.05916861697070061, 0.018744903631628524, 0.00890590905797698, 0.02684043626481247, 0.03824749120300816, 0.036040640871731505, 0.04433797064026998, 0.017097676698599133, 0.03609680660790013, 0.07229259943649655, 0.02432722928783586, 0.017386549302647193, 0.007808345422569303, 0.020438781488806974, 0.03041939794897072, 0.06013978663231096, 0.017518461982329047, 0.03110800565580928, 0.03913828675004263, 0.03914681330863987, 0.01759897207751149, 0.08134713050939384, 0.057933909232698144, 0.040769081097096205, 0.06514924323006023, 0.03431803088695292, 0.057598956440004616, 0.056362050029659466, 0.04261114334146823, 0.01854566906038071, 0.005666704016602448, 0.0836170337072784, 0.033954338305780006, 0.02792505397190971, 0.05963110425058873, 0.03184444214698048, 0.05208871965747207, 0.027890846230870778, 0.02053866211715485, 0.012230419426134998, 0.01649873000719855, 0.03719957102270376, 0.02135508010284074, 0.010100193209044877, 0.0592565983383646, 0.04722293135860274, 0.022678301639614568, 0.018304692273358666, 0.048325067581308466, 0.04393528418375119, 0.1128121848488527, 0.018301869239357692, 0.03940972319293407, 0.073209629664498, 0.021965837954813917, 0.036288677158975796, 0.047430269224869634, 0.024307678724008224, 0.007214082880020743, 0.016988786876261715, 0.052951748347690994, 0.02636648447913749, 0.034783398657436335, 0.07963078712383587, 0.034067983618907394, 0.02569841367432908, 0.05906464734805688, 0.03782927997470383, 0.027106711190314065, 0.03821559130184112, 0.03843059004735082, 0.023307746291280757, 0.03676648619734953, 0.09262096467277697, 0.08716198300281841, 0.05002820744149147, 0.06287378972516426, 0.040321950049650286, 0.05935110294470384, 0.04846497821891981, 0.02532560273163742, 0.03365240390262297, 0.043075296862591664, 0.037301587121140574, 0.09304537738282835, 0.0413410768153206, 0.032917740904996474, 0.06473780804944616, 0.04262049344458407, 0.04337868683280484, 0.06378493639790724, 0.01775227776247888, 0.05020273759240105, 0.027647532875679677, 0.057012845551775354, 0.042323871861181916, 0.0726606510579586, 0.02231492315449061, 0.0411794820590125, 0.06707620716864063, 0.044477168816111745, 0.05091652852453051, 0.0148999581353799, 0.09716624093632545, 0.03674631893274285, 0.03141669886967829, 0.032224270455058546, 0.01796126080256316, 0.06585190673508952, 0.005601733536159079, 0.01545862488133172, 0.04945183353077981, 0.01715752157202411, 0.029907955735501264, 0.01026500266180524, 0.07030051802435229, 0.07617504110619908, 0.041636568419034445, 0.01862859807818407, 0.013645133886095739, 0.04983734429603623, 0.07181247681259148, 0.05337703056753643, 0.07426627941669957, 0.012789428996432935, 0.026075666011761756, 0.07093958857078707, 0.051549665719991734, 0.04257271637118632, 0.03072982635198822, 0.055966526495232705, 0.05108697159636406, 0.05525468908731015, 0.047240601176576275, 0.07469639948178684, 0.06794724147766829, 0.06241718600053461, 0.08424684225070862, 0.0599159702147928, 0.02715413969370627, 0.07400852147369616, 0.016366926495045904, 0.05473203709228866, 0.08264053973459429, 0.022965442884953755, 0.042870605830103166, 0.01298951584049651, 0.019408795426809983, 0.09842553626625769, 0.04035999014553043, 0.03029000186812013, 0.031567127894489996, 0.0305989574671032, 0.04203679190287667, 0.02479311799810779, 0.02003678834185966, 0.06625715192527541, 0.1378545035878497, 0.053778269117878336, 0.06964668496361665, 0.02455736976116896, 0.03919332633696256, 0.02924225022715907, 0.05003066275328879, 0.04983212723727188, 0.03581738369839807, 0.05768839720516436, 0.07037724172996898, 0.014934392829966402, 0.02321404033160258, 0.07331860567172689, 0.04854026550967847, 0.017122752671580643, 0.022706373016380017, 0.040474995264723417, 0.0622959487560776, 0.02068700546759271, 0.051829057985976826, 0.008378069690098206, 0.0044355686423518965, 0.024648756389656377, 0.05996431419325452, 0.02853194691030489, 0.019291599296153556, 0.048030173526175564, 0.018505359429024884, 0.03873646597287828, 0.02351113497429798, 0.019616746163416295, 0.006320036247357607, 0.0027090631004783416, 0.009452125917549336, 0.03534922353743065, 0.05026118627058403, 0.012052933133447604, 0.012041475330930085, 0.0426035322579405, 0.04191250562848103, 0.006469932362256993, 0.04886234802524409, 0.03376280483339102, 0.05241460579958174, 0.047140550093665246, 0.006147128766432646, 0.07053556146040078, 0.08020555224990653, 0.05623238581803538, 0.045661805047383236, 0.04858921852804, 0.014191546098088786, 0.05275311707068355, 0.027818462413345135, 0.08395893108700553, 0.045520377555681814, 0.05816843172895813, 0.043160815257579095, 0.027963302826749224, 0.011187412742254956, 0.015829866301388513, 0.06493974116540725, 0.04832440874569359, 0.02219637487864783, 0.049903530462254445, 0.025591787641807914, 0.15523706923329061, 0.014117523810015091, 0.08863941420831027, 0.079830797359107, 0.003682364880542962, 0.035418669407766674, 0.04201540272803076, 0.04384362942449028, 0.0643450424315468, 0.02886069439081175, 0.02386466539915531, 0.04250055471915872, 0.03655334521505622, 0.040139862441367684, 0.017197664579256408, 0.07899658123572027, 0.04115512429346, 0.016858299120119023, 0.022832147416568572, 0.011431456753803838, 0.0812074343764013, 0.025300386947609728, 0.08304542486345576, 0.0064296485863686095, 0.042226088398526755, 0.10426506445172334, 0.04947493491213649, 0.060127207468594276, 0.028541268285123572, 0.025077905438299623, 0.008467044099234045, 0.1405918736371302, 0.17755492650453122, 0.19141105153868276, 0.12619117500200389, 0.1344702948605822, 0.19044381956900322, 0.13734186819243815, 0.1625270853119512, 0.21322966463142828, 0.1675297313880536, 0.14227653162613993, 0.16807946076075878, 0.13728975889182862, 0.25176243165568, 0.09125882969988931, 0.07770726292003548, 0.15024645073759943, 0.2097044650825762, 0.19274003022620756, 0.11871619465490503, 0.11437792300937638, 0.08931485094851063, 0.11824344179683155, 0.1615585969580758, 0.19302668500571482, 0.13357928863936855, 0.12773901734861637, 0.08004363956710986, 0.13094639766120142, 0.16798581417289474, 0.1516829881696932, 0.10576420658898932, 0.15387516408678026, 0.2816361375153065, 0.25004567458264293, 0.07237375879119481, 0.1955915014109304, 0.1897177980431626, 0.07271046209479533, 0.10291340190076059, 0.13422700065758922, 0.18297864514733517, 0.2260389918040845, 0.12381401949472005, 0.1506124109390282, 0.15895256502253396, 0.18882979488661214, 0.13745869660089094, 0.10090595276485528, 0.15065525057575396, 0.14657206322637298, 0.15149273789457737, 0.11172601006804936, 0.19877363146553118, 0.19016013721064215, 0.12290809754162066, 0.25602424006548624, 0.11661408003419639, 0.22017996668094592, 0.1628667074105432, 0.1051612264446674, 0.14322646533048924, 0.13312980953243472, 0.2415324612370422, 0.14290503015921963, 0.09193141659301135, 0.21043653870301865, 0.15094360607045312, 0.11337140605093972, 0.15551833075381097, 0.13733143407490947, 0.14057563257313546, 0.16758695815599736, 0.16860772434982563, 0.11034356610428904, 0.096108396086962, 0.10865709248689875, 0.15238659396286935, 0.17982987056095756, 0.19253626616010744, 0.14382706294136663, 0.15663698766260378, 0.17244823036655305, 0.09557728265081683, 0.114881411314972, 0.15101451516872452, 0.12015182810324816, 0.11265749637518199, 0.11979287760632655, 0.08541164063518086, 0.09960624629691725, 0.21799575807827137, 0.09673654221959653, 0.17748334324888645, 0.14794824825179193, 0.09779557450524262, 0.1814073988146359, 0.1918399841674874, 0.15785987849437422, 0.10703959742621069, 0.08512468708138313, 0.11110499621398988, 0.12861229629526216, 0.11843922322676068, 0.10149810042592788, 0.18295071358161588, 0.19080279304856257, 0.14844499498365388, 0.13568330315812943, 0.20274919878330924, 0.09242862297762787, 0.06277216433156883, 0.15637136965749726, 0.09857438714994539, 0.18212169919523502, 0.1567252409914809, 0.1364635483872506, 0.18170696983654655, 0.12725294222153966, 0.1396962555666124, 0.19581260970763623, 0.11741615110828031, 0.09775648103846658, 0.17308494136218103, 0.11800152655210226, 0.17265476767093907, 0.11076758044861978, 0.0870956704320927, 0.2138355635707417, 0.11014719478665821, 0.1195207248712259, 0.13822498370803174, 0.1220288660918032, 0.1700714272597144, 0.20580276396245728, 0.1752063154333061, 0.13027380310720013, 0.0813069798412823, 0.18992473371326926, 0.13580584658249734, 0.14204908012142106, 0.15074456110596657, 0.1645576932858075, 0.1367999988818361, 0.12766197954695072, 0.25014155814724587, 0.14690287531383578, 0.22667366500583389, 0.16411356147258513, 0.08088787612054618, 0.1380103565151653, 0.14849322787936658, 0.12066329904501477, 0.2597161250249032, 0.1451931356061851, 0.14093563261051334, 0.10782029464720719, 0.12088000233615599, 0.1838650854845201, 0.16646391922427764, 0.22897724542886982, 0.10236212503044836, 0.14665164443994724, 0.1797765814849446, 0.10057955334383635, 0.14853700214335996, 0.11765477983581445, 0.15491079238633956, 0.11188119649887086, 0.11319906691149359, 0.14143780324487917, 0.18818805835420088, 0.15377086887676872, 0.16675860260523137, 0.16657256581369909, 0.1437333091011932], [0.046281049238337625, 0.01620184795390214, 0.030282896402622425, 0.0461422149542599, 0.05571947846141073, 0.001311083831223509, 0.040406771304626624, 0.04137008090413386, 0.008629511238165922, 0.045142232725817355, 0.007590101815895328, 0.0664113884070708, 0.053807303850208564, 0.019190749566581462, 0.04948449185899189, 0.017485512540705742, 0.07263376137181636, 0.04280159279944436, 0.01946423912510997, 0.027304488279285933, 0.06363868255228286, 0.02472863063186167, 0.04979970256587671, 0.0802083561317094, 0.07654461724263045, 0.040383509044805845, 0.022729865102578076, 0.09644727508026747, 0.04850075452498371, 0.04461499186412943, 0.06540874019265175, 0.01859502235968267, 0.053700289028065826, 0.016202439756823644, 0.03332139263229986, 0.01619928538979542, 0.035696157945259925, 0.06337007680427163, 0.005401111866963367, 0.04327996491244243, 0.04781597917298636, 0.012580674825116031, 0.03286474677283437, 0.05883506994934813, 0.0662023306734139, 0.04034251184953798, 0.07334887380561522, 0.08136166319731744, 0.018863614701155215, 0.058392071946253704, 0.01091769999719315, 0.009004333161658818, 0.03285715867194437, 0.0813081979210819, 0.03566447254871169, 0.03707572141842496, 0.025523783931989345, 0.021327039369592266, 0.045109252640677076, 0.022634460342927806, 0.04571858748433091, 0.06508755783039717, 0.02917330422919364, 0.029879384486365224, 0.04804354176045426, 0.050516508053988225, 0.04419652782681008, 0.0355661106896737, 0.008836842401163473, 0.04010142397976691, 0.05784920672135008, 0.04811144013318324, 0.022820209851488475, 0.04044711349471923, 0.017953479264472282, 0.019571043273073532, 0.022468713390070106, 0.08426512110858195, 0.038559147261924324, 0.01978578346390878, 0.028107762111410983, 0.08900512926160328, 0.0238400184354114, 0.04981437314962668, 0.03950612003644628, 0.05542462271067405, 0.02862284132730096, 0.05004791122290397, 0.09526213706140557, 0.06545130403772478, 0.036643789555396766, 0.024340019125731725, 0.05360180842539957, 0.02385433087305677, 0.024438564845871542, 0.07578705587694723, 0.0414288973045205, 0.04440896017777343, 0.038385643668833284, 0.031404104384203116, 0.027896162881065282, 0.07198523730039597, 0.011197610330137034, 0.06312086457206358, 0.012459360014256692, 0.17131108009526808, 0.040113585625564864, 0.046410744093478694, 0.034627821521773454, 0.0772649007699182, 0.012495762597198689, 0.05179277989232252, 0.06072955175993904, 0.04062710968296855, 0.054385700233040325, 0.09055053544861656, 0.04955736597278907, 0.04062205733310792, 0.030714025788549936, 0.016479139223754886, 0.021870337434173114, 0.0044865288110750344, 0.07330471649765968, 0.02542095386513299, 0.0239092632076673, 0.04346982831315648, 0.029984516647434043, 0.03154250582860362, 0.04840503566928449, 0.06207663310511459, 0.02303658372482225, 0.10475193631024131, 0.007697374235102607, 0.015768861762368153, 0.07774193605948841, 0.06620184037714236, 0.033970652148127556, 0.005617466109294084, 0.0014314702392796115, 0.03442024999868966, 0.016721376225412372, 0.04181644969409512, 0.054306751042003595, 0.04983201232408324, 0.09966957112473827, 0.03320061887103704, 0.016391209567025784, 0.05462184300526016, 0.04294152258925381, 0.037058246952872125, 0.04132354106273382, 0.060024061390469154, 0.04091698586219742, 0.04906324309206778, 0.05763614234784919, 0.037368458936051015, 0.017580861758981502, 0.05239150824866468, 0.028181074810544812, 0.02319606790889896, 0.04635799127901274, 0.004071356079000379, 0.06623815294475326, 0.04407178573009949, 0.06983827589259994, 0.07477369775334675, 0.08917290251702072, 0.015187005534948362, 0.0618065832813661, 0.03407688556058753, 0.07594411922318321, 0.04725378171931352, 0.01145586718790113, 0.03808248735543701, 0.08587773618919235, 0.008587939476954841, 0.03692137002344093, 0.019937304164012595, 0.03539689718895862, 0.03427004696981561, 0.05580248791844614, 0.037876172216549035, 0.05806267329101121, 0.008863248494303515, 0.05412826021652549, 0.008732031997022851, 0.02604435216785679, 0.09636893492913055, 0.025563193410034143, 0.0265051004281568, 0.0326702255575407, 0.014460066618818431, 0.0696342207130886, 0.08291136713758593, 0.04496698628269857, 0.006305256017273473, 0.04654049640521408, 0.0031736159449323054, 0.018339510969517213, 0.030106830245424664, 0.02875572693864665, 0.03653207095339894, 0.028500960568987557, 0.016664233727140293, 0.08730862755328418, 0.07112135825258109, 0.06789334719219516, 0.016974819178182273, 0.06505978714314199, 0.028216531274900324, 0.022719080499824018, 0.07236210659386651, 0.029109343548395464, 0.021544263600521994, 0.022870310086516604, 0.04212724007365685, 0.02846697307822685, 0.020247272914275527, 0.03726311035514359, 0.038010379329564116, 0.06834742282667468, 0.04950410370985347, 0.08082727090485635, 0.019813385611820607, 0.06294764443150451, 0.040736859439000975, 0.01787322389352466, 0.04965280137595631, 0.031998743746249426, 0.06663593643855664, 0.019588667125771606, 0.04165881561235555, 0.04113558139051161, 0.07465604196993575, 0.025738531783703836, 0.056518906532155896, 0.021995391711712848, 0.03046761169248531, 0.03324548481032252, 0.030330665815140934, 0.054283167025254625, 0.06581531071494665, 0.07139245378634623, 0.027545265883447665, 0.0037775738089675867, 0.03317595083987521, 0.040688454173505306, 0.04677940092440094, 0.05749581419231911, 0.10318340192879401, 0.0799999955380636, 0.013376817336275935, 0.009217147598974407, 0.0800676104582606, 0.047618903054465214, 0.05556440694377788, 0.06586678416257905, 0.07547888934852616, 0.04432779699263554, 0.049993947989517645, 0.06303139699382648, 0.04364105662511241, 0.035784591304799246, 0.07234535225096249, 0.04365037991515091, 0.017282717575829838, 0.07043091384994407, 0.049758578966101336, 0.025472950167773713, 0.03459031768744031, 0.05150217592956559, 0.04203477709163581, 0.04830801446411399, 0.0501839186425411, 0.02441906216253917, 0.06110665087978687, 0.03843556578841902, 0.029452439855724096, 0.05037062959144673, 0.030209120220294407, 0.03135834403726603, 0.11072521578640708, 0.03892906430748202, 0.06265618628071201, 0.04328951419841859, 0.05738626744958663, 0.010620939560354719, 0.039520495676345406, 0.0650218274864939, 0.05432972218841315, 0.030016167570025693, 0.01188094160639711, 0.021966452740373153, 0.09516061508967992, 0.03500291349125966, 0.038340203163604585, 0.03917913072772565, 0.015274413294279048, 0.05748159177000484, 0.03498535092559553, 0.01980705964078586, 0.005602856333773103, 0.0025785461372335354, 0.046836194852667476, 0.035333748561360186, 0.009688858577470866, 0.015240127029227874, 0.07296534720808268, 0.050069530224127155, 0.03154197531271606, 0.08738506780636889, 0.04304471846309401, 0.03815628460518295, 0.044573772503363515, 0.048009577252331286, 0.04206692597137825, 0.039525295217191024, 0.05026013289968814, 0.011448155555333342, 0.015846019265271963, 0.10424297047598709, 0.03469047602266073, 0.030557035220666762, 0.026639897428873568, 0.03946133453639285, 0.04627695449838235, 0.011186938725351807, 0.07102141442197947, 0.011506357170160741, 0.06367748107520804, 0.02103253218886112, 0.011534778074541641, 0.019254729399577748, 0.013966226233019224, 0.06563364828546202, 0.033360945751830455, 0.027125830829684294, 0.029098223782174533, 0.015726360161938978, 0.008270468810693392, 0.07834022008483449, 0.07042496134677241, 0.033145973819398114, 0.019686915986840765, 0.03478152940290109, 0.06748370465732391, 0.036868578904578765, 0.04166277245648446, 0.011584537400443469, 0.01140553999932543, 0.009982873546710659, 0.03551915716079455, 0.16617110509785915, 0.12477180560029323, 0.07630687717708849, 0.15251725791923462, 0.15495393845823505, 0.0906656937853944, 0.12480768915866652, 0.09787570730212236, 0.10591570047601577, 0.130727005401446, 0.09825780131523648, 0.1910358982821626, 0.06720222097130553, 0.15990686542805166, 0.2857607548996326, 0.11917998428426443, 0.22756894599766503, 0.18535986092061768, 0.13223724049185553, 0.15403011303034522, 0.10275106786960557, 0.09896413438142308, 0.13159519752427457, 0.1279988207463776, 0.16506110498261067, 0.2033983050815521, 0.12187816127533875, 0.1600302209056193, 0.2321064541296613, 0.20051720161591807, 0.2063271051813518, 0.13248735287737462, 0.1774280163789949, 0.1302936601061975, 0.09410021150664938, 0.20119345807019742, 0.17228065629399594, 0.1413369554305269, 0.09332440192660979, 0.15929027190131528, 0.12542323314494666, 0.10645201564916681, 0.09912381008748086, 0.0999107968903357, 0.11739964191351207, 0.10615776893832993, 0.17358882803349726, 0.1520476613434092, 0.1623958850940389, 0.23419885475549007, 0.07711040381822856, 0.10296849128339561, 0.23392880876218122, 0.2178796497924674, 0.14205609748680748, 0.11215259080692647, 0.19869912175401566, 0.19665254850781735, 0.09279013220821658, 0.13550973827800444, 0.14231923336703933, 0.1337729250231097, 0.08915728198424464, 0.12356809761014678, 0.12061580159370938, 0.15477471984922886, 0.2260770970174382, 0.08354738099320282, 0.1776095945388079, 0.10024346291057526, 0.1401834721646963, 0.17714479367338842, 0.12390899907557235, 0.1516848727459869, 0.18196295045556563, 0.07383502554148436, 0.14057276740429864, 0.2236122857298582, 0.10081824335840442, 0.07736968627620129, 0.23436472811285528, 0.16536199367575108, 0.11700842379321975, 0.1399057652921446, 0.12269830436355646, 0.09536077088165669, 0.10160551361379125, 0.10305682888194438, 0.1546182693733323, 0.16062657438939618, 0.13390862983801674, 0.17186284726185186, 0.10519553952279592, 0.1283765787018403, 0.37527380811591304, 0.09399339586736695, 0.10415882337838413, 0.17229374107574263, 0.10700612704479888, 0.08322208473879485, 0.15975141086645667, 0.15109984204173088, 0.19022836500117857, 0.16292056339162012, 0.07811562608807318, 0.26169198835569046, 0.21160951124564295, 0.22433544208686199, 0.09588530362253228, 0.15409038882822762, 0.0626624298972949, 0.2400578492351117, 0.16649831657207784, 0.22494442069963103, 0.13342118341355555, 0.20235618035639488, 0.12627406571541103, 0.1738907586062147, 0.1569147711439479, 0.1334946972107695, 0.08031750833916088, 0.10864654345618141, 0.14949358549089203, 0.11529625558684911, 0.10646562903158127, 0.17337816917607862, 0.07739038597191535, 0.21325554308151046, 0.1743406973659031, 0.1201253291219473, 0.17306457874515366, 0.24897951001842178, 0.12391778610406384, 0.10700295544079236, 0.32728189302067606, 0.12725067460128378, 0.1710371117317869, 0.10554189553424236, 0.13288619357251352, 0.10834494230127144, 0.09149336751790778, 0.1434471905832329, 0.18310632136079574, 0.18233269513134034, 0.20544636453832352, 0.16208473082271316, 0.1375810714859155, 0.19775484177854755, 0.11620535680483426, 0.10963951598011679, 0.10660304222255947, 0.11311174054900486, 0.28268852781864906, 0.1584147100126551, 0.20393303445269986, 0.0943192054006842, 0.09961894803470182, 0.1072031801806823, 0.12800173188048986, 0.10661467909812929, 0.11508278518674836, 0.1149247412479693, 0.10877710782111653, 0.11418676108963068, 0.1927341313491906, 0.2044086984448856, 0.2128233162746314, 0.13145480425127093, 0.2175669633452931, 0.12321748214984134, 0.13332519259664322, 0.2442079007385239, 0.10025377445403608, 0.19391410593544284, 0.14596838594203995, 0.10196305450893219], [0.01701730832968268, 0.0058713873882117055, 0.023418281287435564, 0.011718120151800255, 0.07698895589959237, 0.028626106777078206, 0.010579222242438025, 0.04158144839288246, 0.048881902419511354, 0.02037638554259414, 0.01358562034569801, 0.016596695415735725, 0.01643825694167566, 0.07494431319496325, 0.03446245378243827, 0.079467480161017, 0.0089364098910723, 0.05740949523545081, 0.026404467118423314, 0.07436214765954403, 0.050457189866011186, 0.03261578734964132, 0.07577869019681409, 0.05419216727116897, 0.052596743203579426, 0.005212554167355261, 0.013089200158813789, 0.0793427380643064, 0.021744949908386317, 0.04791414951004329, 0.02132445765328744, 0.07013547204194531, 0.11501782093076937, 0.04859546214462288, 0.08917707003532879, 0.042192024298973625, 0.040624635218973124, 0.08348718180411285, 0.021099003722831126, 0.008062857067993572, 0.10149455343883845, 0.027962222642775987, 0.03399504055719703, 0.021742462037852215, 0.022063288169222015, 0.012391751797329034, 0.017973746120509122, 0.026486953720450405, 0.07055978516056653, 0.029594715789801655, 0.06469817066024389, 0.035145758245621, 0.019400659573054122, 0.02911605830905178, 0.014948159429965722, 0.05142704951727102, 0.04061924195998619, 0.04696341141337349, 0.007543126261988355, 0.019452291983930815, 0.034538694852662664, 0.04053544726282839, 0.04614134161402622, 0.03161774332364721, 0.007904854785245394, 0.02018352673809615, 0.06390426225299317, 0.06016635839196463, 0.04382553059727915, 0.02963528972149136, 0.024188958078382478, 0.11525940675769122, 0.06712873781760854, 0.07667587874757667, 0.027970463833621437, 0.007334623463271607, 0.06262334792183773, 0.09684125877796643, 0.02451609868946816, 0.03994368264571794, 0.05652778166075868, 0.08616364786341306, 0.015285772462976317, 0.012612765290654235, 0.048016073677929184, 0.013154187397430501, 0.022518892149110476, 0.04617882629616126, 0.10428450776324158, 0.05984187802119602, 0.017862303310164043, 0.04152493408670829, 0.04948642240056107, 0.036594645015054175, 0.04646813557032616, 0.04677989122067248, 0.015898534592481393, 0.024365775001746033, 0.04689406513446762, 0.05804607982657129, 0.04758824804617513, 0.03986733432318415, 0.04307833823165105, 0.004131582559972641, 0.01723060636000047, 0.06282224349917905, 0.006047759501774225, 0.05689002250531509, 0.024551957349983916, 0.053986365411190264, 0.04702656770185117, 0.04800028077537014, 0.038649013205882043, 0.010544947468705717, 0.03407112074895732, 0.058491222875853704, 0.061280391960134434, 0.042741221240571434, 0.028047302452426766, 0.026902866684981895, 0.017272061292803096, 0.022594468638060555, 0.07582477804633879, 0.009332297317263101, 0.03367187402721855, 0.06723184559133745, 0.06747330118331217, 0.040613588231105, 0.020271159535754594, 0.10177050597004353, 0.03897971804103544, 0.02322526926535272, 0.026511137201000127, 0.08224253407529286, 0.02348642480830031, 0.05860322109994389, 0.04293740103622118, 0.0459028929171543, 0.027517211743660515, 0.03918048670335163, 0.04144927907374598, 0.005286628645168798, 0.05307500040338886, 0.010930936081304906, 0.027227710947514545, 0.023283991819968628, 0.03518277561412223, 0.030926484952590642, 0.03787766225756176, 0.045373468704882174, 0.018719837234746066, 0.018127798741202683, 0.054723717377430973, 0.04126619938160143, 0.008203167986545351, 0.04751968700739165, 0.09218053306422888, 0.0183301302228844, 0.041426652666902354, 0.029242633271121213, 0.08813436308334913, 0.07687489306854625, 0.07109811514495842, 0.03144860834694438, 0.02460492275384886, 0.02235214928195121, 0.01810427218104803, 0.005229198863925112, 0.08861574975232925, 0.02184430193606644, 0.04318200524956469, 0.0435626820000189, 0.024355733504278526, 0.03462487208326498, 0.011962278118927874, 0.05422615859236929, 0.02011103949870073, 0.012742613363380154, 0.024854569740953947, 0.018093663778516556, 0.07086286486517038, 0.011091684310456679, 0.042761442131332816, 0.06591162328878719, 0.05805977364821781, 0.044322403733648603, 0.03517342551100639, 0.0724956357190686, 0.03714601381591732, 0.04913400663363357, 0.034058039797650236, 0.054643990607151104, 0.03144411524126847, 0.02753386649513437, 0.023575061181139563, 0.04403182658396902, 0.06209121175831365, 0.017750431490581364, 0.05184789608803488, 0.003511440609731982, 0.02911580933047639, 0.05649513099342585, 0.024716036146386497, 0.018294752282541127, 0.008312660145513233, 0.03376283164646837, 0.034503730599798506, 0.09622264277910995, 0.03912142515482922, 0.031217450891891797, 0.03773247327415213, 0.13578712339362792, 0.04019333920892208, 0.042811448520590226, 0.05491885912394332, 0.025131782486794457, 0.03399774867800936, 0.07061287505371917, 0.04777249602240421, 0.017651577420052023, 0.05503952946333636, 0.05348006939335216, 0.07995019216210612, 0.08093115242738878, 0.034733859581812736, 0.062026017675957376, 0.053219614820855285, 0.07805819247638987, 0.0019105952730657716, 0.06624347725582701, 0.03828280402587787, 0.04883776043331431, 0.042883782542400786, 0.017205850228727344, 0.003684737837888421, 0.036106428672229095, 0.09664441248582256, 0.038822930486452197, 0.06322117995530849, 0.01678050480662815, 0.046424127649515874, 0.015573531366704453, 0.05027022610809054, 0.04702327735421639, 0.058603201947745785, 0.03221472116908239, 0.05854964474095933, 0.020592489369934606, 0.029925460844571074, 0.047995013920890714, 0.016857241918783517, 0.04355667204025292, 0.045033325666501645, 0.05421872370906415, 0.029227110414555477, 0.019510807694807168, 0.06739342119544744, 0.0321902753034186, 0.02976336813111219, 0.039710431855412266, 0.07245611324305497, 0.09651864383129344, 0.018278905753827384, 0.08549469222705211, 0.04519776643944844, 0.0716549844571179, 0.04425069407349633, 0.05700181771610534, 0.014124068116108257, 0.03548682825038991, 0.02487123789896648, 0.06856047953929632, 0.0654088397840819, 0.02247812286500008, 0.05282483439171507, 0.04480245357920085, 0.08656369131659308, 0.003986508729154124, 0.03656608908767662, 0.019283689438335357, 0.04003719516819523, 0.014777210740102156, 0.044523007687061064, 0.022311295728169145, 0.05655546424790256, 0.051035524961809, 0.05768678459008375, 0.05294420238163683, 0.04352430099501245, 0.007992588131943899, 0.02473969294148828, 0.05332793965334854, 0.016728435725634618, 0.04313830759436373, 0.021752752513895114, 0.01807136295904075, 0.017210134575443885, 0.022605316443068367, 0.011106305098491571, 0.03305790435162283, 0.023590005641322465, 0.06354217845646125, 0.06361466569585666, 0.05769751748190292, 0.05223418826297407, 0.06561042816047707, 0.03709371682376631, 0.01486624164822241, 0.02366529676252075, 0.030507254827347015, 0.02462836504433184, 0.07151634552546086, 0.026399169620426915, 0.04579087937130563, 0.052780654101121816, 0.01885734618671479, 0.04014767653819534, 0.018087374196658214, 0.015396161902425511, 0.03656015956714269, 0.007858918716890678, 0.03726432843494319, 0.05724837545365576, 0.04768968191778949, 0.06310754613349996, 0.026893411244776462, 0.1004277606825194, 0.054044614906512925, 0.039208441251708616, 0.0202123680332255, 0.01777535807641764, 0.035565363753947525, 0.05404247752120418, 0.03881371061828348, 0.06310029128085702, 0.01957138992785927, 0.05247887291554963, 0.014365325482832569, 0.023251998073030865, 0.011903781560249628, 0.026888247812166814, 0.022970117936511675, 0.03469772321442443, 0.022919443135540334, 0.10929148223611618, 0.035546360942985744, 0.005178594447281813, 0.07791380788530074, 0.07165192776630003, 0.04683290833547231, 0.03393407528018279, 0.014547008979735116, 0.1101126135777562, 0.12867810324795786, 0.10420966863391862, 0.1796179553193431, 0.209797851200546, 0.1342997177233619, 0.08719009076876026, 0.1612223609681091, 0.11980437658606999, 0.21296309667729565, 0.11437695007771255, 0.1921065061563446, 0.11566389352083208, 0.23973946309378072, 0.19873506659942292, 0.20852847415353024, 0.09658323270418952, 0.13956925351052515, 0.12635432108635866, 0.10241004383011211, 0.2567101798711285, 0.14935526065528393, 0.16350527233894796, 0.09921574829927376, 0.2268557334619184, 0.1502777530901855, 0.21156333146556733, 0.1541079782069691, 0.13616668931659193, 0.160831181152213, 0.08263167609731037, 0.1706319737939104, 0.20348609875767462, 0.15035011775551305, 0.1557031264829059, 0.2185040267725145, 0.19008786447586554, 0.13255198005466692, 0.10937445721919499, 0.07403580186467978, 0.18795544341687234, 0.12062887105369761, 0.14991815141852827, 0.11377854347829858, 0.2353811735707906, 0.1662276883519465, 0.15894685000661882, 0.16235869918619433, 0.1285193468474092, 0.19523873324355773, 0.18332764416212038, 0.149714540570013, 0.19368146035459735, 0.1888594424892818, 0.10350654547613475, 0.1176309161969731, 0.1848550396220338, 0.1128816766844642, 0.1233756333409298, 0.0993289914162409, 0.17974756207437287, 0.12542225255240358, 0.17326932340379686, 0.06348277216837292, 0.15595601210671087, 0.057949322921734665, 0.16071776949590252, 0.13621472302944432, 0.207930373989286, 0.1103637142166976, 0.1279658023568411, 0.16861301035650317, 0.10749525120181423, 0.25789930154719665, 0.08388887234633008, 0.11156746051124028, 0.11984981326085907, 0.19646281917249003, 0.10465191587084725, 0.12710547029611566, 0.1689083372513133, 0.15888432191023905, 0.17153024252864624, 0.18574647485248505, 0.1918099381990971, 0.18866520855695973, 0.11480747616939968, 0.14671126140221474, 0.16126156934807379, 0.17729905313782154, 0.22024759692290138, 0.15166731401076242, 0.08396823139440629, 0.09454999704875293, 0.1376293043816282, 0.14004890115991717, 0.10450521003334753, 0.1042914025545601, 0.24982694115850235, 0.13758655667545336, 0.2240504114137542, 0.12558707636931252, 0.1361610662312277, 0.15029474492034606, 0.12590537058009257, 0.14116227206203247, 0.10255910155753936, 0.14598173119368094, 0.22332328672130264, 0.17437555436645785, 0.18855020343776674, 0.15145211991283203, 0.14639885074669315, 0.0548946047802606, 0.12716789880106527, 0.11213861736318759, 0.1490341778844595, 0.09978940259785422, 0.16780504806628152, 0.1735283224092376, 0.11033644914747247, 0.08215633386205282, 0.17042323015630248, 0.10274477062686797, 0.1470653165973002, 0.14263297701554914, 0.18744374264872846, 0.15342407619520543, 0.19701856999628006, 0.17950950791278195, 0.15029664481839827, 0.08412280495488837, 0.15702704899013042, 0.17474706104445845, 0.10019791132259755, 0.1317999115394008, 0.16860277542183477, 0.08066081532066868, 0.11934889901068904, 0.06693261930899275, 0.08987383466334113, 0.2360737017325817, 0.21897656512596916, 0.1888168480006918, 0.0649868938771467, 0.08989215948648992, 0.13203197489342383, 0.11167806062486865, 0.11923100574002152, 0.14124896257154404, 0.16754129931571024, 0.12725168583734384, 0.1779226946734613, 0.1515499799842796, 0.1643328005147557, 0.18680441163239941, 0.21439880673443118, 0.07823841466057686, 0.09232828078130562, 0.12441756654410593, 0.18708006538931402, 0.079072990845288, 0.20338820804271007, 0.11805411082722488, 0.07459866964528639, 0.17772368035249173, 0.10760983497264887, 0.15365021002869453, 0.22371906306474443, 0.1498456948226498, 0.13873509101329312, 0.14040988178983813, 0.13649065257801166, 0.13917689391922566, 0.12568242367236845, 0.11380296636132464], [0.027595080750724, 0.03168932657929198, 0.01420923985630995, 0.010463740233512176, 0.01586585902729102, 0.02208859971424024, 0.020772050803286896, 0.01545221942867483, 0.06565063245474331, 0.029924788602417516, 0.036609185363857016, 0.029926138832384062, 0.05112952011967859, 0.03414653444422349, 0.06781036454823709, 0.013061282957243103, 0.011880113273828983, 0.07345454031301123, 0.024319145145014893, 0.048175994532122735, 0.033651201144581845, 0.01558455537193485, 0.0637990515679121, 0.009506801612705234, 0.06269266355722662, 0.010314377028525118, 0.010797937471990385, 0.014504180834328216, 0.0487252565911941, 0.050340001396234, 0.06128504977471406, 0.028719598232137582, 0.07154592418021734, 0.006578629705003433, 0.043617135529676755, 0.0485228561615992, 0.0514091843468768, 0.016495135139613863, 0.05432079343365566, 0.07213183588558628, 0.03904530282823309, 0.02187675342053896, 0.013460660871538906, 0.05635901632147932, 0.044399970135982, 0.0336051975647288, 0.028370070616684617, 0.07666741347601337, 0.02634952712293354, 0.024669569083339265, 0.05699492675522643, 0.1353962806564185, 0.02432512254604409, 0.02712661415458687, 0.044650055708423744, 0.04710036112115749, 0.009910873730757065, 0.03675444329517984, 0.037054592713473306, 0.015086109840100812, 0.018318043270659064, 0.03559508030453036, 0.05324965312836632, 0.15708157912858073, 0.01725095174004955, 0.023885198470745838, 0.04452698368338808, 0.036219591349964185, 0.02553636309570603, 0.06293025040518373, 0.023168854550608707, 0.09757694833341146, 0.03607248331630423, 0.031198268050267815, 0.05418932891540951, 0.07887504904741242, 0.022705470947849176, 0.08380179113197712, 0.04875896062942282, 0.029919761150414427, 0.1430957554088485, 0.038977461912098436, 0.006974496063776315, 0.04029094647135466, 0.025560709369939663, 0.039082890932237914, 0.017542059405616695, 0.02520720192772006, 0.03822347051614235, 0.10875962569468445, 0.02528376283965284, 0.020374156226734483, 0.028828670000357014, 0.02692034115053473, 0.03472722526038847, 0.07582954311322782, 0.016272506158378337, 0.05722415941436926, 0.012835918084507989, 0.02151943086045644, 0.041426430501404314, 0.03412367821100258, 0.020818362733529463, 0.007581035165311469, 0.011443376124295737, 0.019755151438256426, 0.08103703343940359, 0.031913405381924206, 0.025499119731267134, 0.06690858713080806, 0.018591806705620502, 0.011313878536795177, 0.011606808534012207, 0.07316224712638125, 0.02921099575506824, 0.01374118886287174, 0.07384148366268604, 0.03067970313432236, 0.058529894994271386, 0.039977344549110824, 0.027221317943786422, 0.00712981129313008, 0.029847685683278308, 0.032024896072764555, 0.02380118735374943, 0.03915239042872864, 0.05536076162130602, 0.03508789179426047, 0.03455437284203307, 0.025105927019349994, 0.04439688280164715, 0.036326529563314496, 0.060850509382303686, 0.027499246981836138, 0.09062103852028809, 0.019821000525787957, 0.05755362318708532, 0.028341279117270347, 0.019950796887578986, 0.03548270669735728, 0.0122871003564327, 0.028582899418148785, 0.046156272667670445, 0.09469666458185642, 0.01079156170524056, 0.0679234391258609, 0.053593906228460615, 0.015810153901486868, 0.01761303170614185, 0.051484712955331614, 0.02941959766641019, 0.014607546205121665, 0.08095565191920727, 0.011589977582315765, 0.04112873639490816, 0.009804977396983775, 0.048840472384566264, 0.01047980030923481, 0.020174088534869013, 0.0636018567057627, 0.002347999397898093, 0.019584108902622136, 0.03454225716151057, 0.0529452710742912, 0.03949532202715355, 0.021155157967680888, 0.017576121589950016, 0.03407647570354804, 0.050754646485250805, 0.07113206816176254, 0.09016221314067803, 0.03586471261036012, 0.04139478340925228, 0.03643920960565729, 0.09318125073707874, 0.024385256617660486, 0.0195966306097445, 0.02816673364460228, 0.03977837236297708, 0.02470588165095016, 0.015184141323721458, 0.027703035945793795, 0.02295486129549963, 0.037926596123725176, 0.1452175278456942, 0.03707145430868672, 0.010247305073144456, 0.05207693339475701, 0.033425883194732095, 0.02867064329855625, 0.06184753068091889, 0.03690688713123241, 0.04831174148186561, 0.058702601855921174, 0.06600548438127003, 0.04324430351956718, 0.017583125548797752, 0.05703251868967087, 0.05822275502366885, 0.018185381740031224, 0.02799468178812775, 0.0766600437101818, 0.04883168152563515, 0.03564851876768855, 0.03539359151956535, 0.0449026502188175, 0.04747503557272496, 0.01692373835061106, 0.030564730573866158, 0.0242664746850008, 0.029785324211022066, 0.09181619696919957, 0.02245310243339308, 0.033957908275507154, 0.039859137182394345, 0.04099808776030137, 0.08049605279079369, 0.04673378804938928, 0.03477823522482668, 0.050904171526311874, 0.044566245689507455, 0.017323186170429956, 0.013580398498884132, 0.0556509442357046, 0.02229369868854842, 0.029256712051949678, 0.0375061402578027, 0.03483092292181907, 0.04362007730730599, 0.030749715909722353, 0.06342739167232668, 0.047858010586952014, 0.053638745354668754, 0.041692121284863645, 0.026981856095634645, 0.012280986974796942, 0.031148255915350975, 0.015317265379933581, 0.02302775839193454, 0.12199466026598409, 0.048116764444256985, 0.0112246292936165, 0.036209099775841164, 0.10535330766992224, 0.06607145987330906, 0.02495091295831146, 0.03184595325541112, 0.052304262325408, 0.006531094428106782, 0.018545707364776925, 0.056639760732650764, 0.0449649140148634, 0.02657421688068538, 0.04033265612839211, 0.03523881494578335, 0.0488185546090526, 0.06520881422705228, 0.005112457119168775, 0.04799815105094064, 0.08550042256472573, 0.03436036107520904, 0.0565639371803451, 0.034068316867154454, 0.06859440191258347, 0.04858738374746135, 0.021443888845462954, 0.07956331009946524, 0.027253711971664624, 0.015183126257221787, 0.0056816944420608065, 0.015688573832683746, 0.04249364077564209, 0.0239334964839321, 0.06329392766459815, 0.0416541003411816, 0.04391296038163766, 0.03242274468404151, 0.046743551839984236, 0.03882487251934025, 0.017140093071746732, 0.026990618226268602, 0.04742389537333962, 0.03239344948181703, 0.031072070386501092, 0.039385327122985356, 0.004758474223631164, 0.027442259616368724, 0.026815509678976193, 0.03412679235841479, 0.03241706414208297, 0.09907971406655927, 0.010775538976304235, 0.08700536398757851, 0.08905287952192369, 0.01591499111870484, 0.00922163304377107, 0.0074504344111999445, 0.009324638353240107, 0.0433227509230135, 0.003993968510316805, 0.05683398317365397, 0.07543776574875079, 0.0882141281580252, 0.04262345437441142, 0.05871827218441233, 0.017813853994612733, 0.04423140781000257, 0.044477080716000456, 0.09429508129194861, 0.03691738253579505, 0.05040326493702108, 0.026836441116287347, 0.045002613201617234, 0.03603460409888818, 0.026619377763821717, 0.04539668882986711, 0.02754189509658083, 0.04669569049691481, 0.00458619972285364, 0.020800365412968303, 0.06690245076653457, 0.013101036217243922, 0.028752817719754194, 0.0572983511993962, 0.0069234683835548505, 0.03739514560889333, 0.025835139301395225, 0.03579631245004074, 0.019299662371556607, 0.041905162675726804, 0.031164841718911648, 0.006057252767570918, 0.06757309179632895, 0.041153519339258635, 0.028769832532552463, 0.04382899714513652, 0.056807258196415446, 0.006182945770917521, 0.030050371480625004, 0.029298756872454, 0.024103336261525273, 0.05602815443830145, 0.01662024687374792, 0.050225586164742715, 0.02994962517292269, 0.04642786232814674, 0.05069722819532599, 0.06283006525688595, 0.05078449327078077, 0.037340814653303356, 0.019246578224063404, 0.0663012862505932, 0.12492969632148744, 0.13484149510341306, 0.15630482726039427, 0.15440206403934187, 0.07411519921715222, 0.20797132904971802, 0.11704812246945598, 0.1658141540904199, 0.37014628970815294, 0.14768053116577287, 0.17764377738198928, 0.12655938750193005, 0.14431922846744138, 0.12734827420283712, 0.16177569095405842, 0.11635844415474324, 0.13662275677967456, 0.18255800158987123, 0.23574206227016067, 0.12908590717181084, 0.08777579563038965, 0.13412068297545757, 0.10673867042867408, 0.14314124570979228, 0.1629921160037479, 0.15599001108879046, 0.12135872301915962, 0.1996895815095594, 0.1190704107284546, 0.10567544764208217, 0.21772833210566353, 0.1222261107496677, 0.18891302267870597, 0.10907360683045081, 0.14459483625908054, 0.2200071832105037, 0.16984933837046548, 0.11330129368410957, 0.14619113366690376, 0.09903774777006719, 0.15247245709742271, 0.2420580894836495, 0.08900856133550407, 0.10122755647546823, 0.17226610062343461, 0.15586317757204657, 0.11114625004871238, 0.18957201151117203, 0.15791312160511173, 0.2062978253008858, 0.13767214401835395, 0.18856169475663095, 0.1315017807627878, 0.16365922536821137, 0.16844234128873195, 0.13070290427534811, 0.13169685739182657, 0.1708421423550575, 0.12194817405073874, 0.08170669387665488, 0.17040256110410537, 0.16184345909184025, 0.10138782206922771, 0.22377003855522604, 0.1729619995720925, 0.09236620213355749, 0.15833883666463439, 0.2431230436289503, 0.20469302431710307, 0.09341236414207567, 0.1267612593308572, 0.17190089118817162, 0.08298628287570131, 0.1227827349136914, 0.16182450607659357, 0.09573428471001888, 0.14762200204835785, 0.1307168930408455, 0.11399270335753119, 0.22253430808984467, 0.22620206127964684, 0.11658679198233352, 0.13769144943404582, 0.14080383484402012, 0.1433005000674917, 0.1282735245542661, 0.15339701796971983, 0.19910790627041172, 0.16348567580984485, 0.17276871558879653, 0.12020215241899414, 0.1267983609690301, 0.13916785408171917, 0.1337702743588917, 0.1542224164210981, 0.1957661234923909, 0.08137371376036637, 0.07764628232126275, 0.09591924131757791, 0.114337871932695, 0.23912954985374407, 0.12547727298712538, 0.0988796808486504, 0.11737429206409764, 0.12244583242723059, 0.15200829974585964, 0.18869824226825468, 0.1240414480168012, 0.13449272591500513, 0.08331041467646438, 0.13040543233435, 0.07877327426667176, 0.07463257669681504, 0.14625609792288274, 0.20125892794420644, 0.1910374304580112, 0.15478921423275627, 0.1514052812971415, 0.23490333388889992, 0.11758370219819969, 0.0983773953010959, 0.06496352053457691, 0.17744821045667897, 0.1157067254966786, 0.14502041342277683, 0.1744716371139211, 0.16219417414357587, 0.12513850124612932, 0.10520244963587293, 0.1802480473153053, 0.16675359239020657, 0.11972914675190566, 0.14020090832585289, 0.15369407622323883, 0.2357467966935327, 0.13262590753936, 0.17292651437943982, 0.09596746655241137, 0.13655242990822564, 0.1760746914172365, 0.09929133053388327, 0.20081997488535222, 0.10687405348665292, 0.19486266068152844, 0.09281208062724722, 0.10479228616121317, 0.12919781729578972, 0.12169979302392853, 0.11459622742427934, 0.21952725976945894, 0.13324220995268515, 0.10814286362860473, 0.20608306021219303, 0.1670732655592503, 0.07741092478916531, 0.08642123726707313, 0.11836916448608523, 0.17790605524374595, 0.08118509525252927, 0.11725528030506066, 0.15219439782442587, 0.16007534348435942, 0.19053663878190905, 0.17946527399603399, 0.09859069716185333, 0.1345043857732127, 0.08687334405558725, 0.1255414175290254, 0.1830848555771574, 0.23670682743672403, 0.18856563244856175, 0.1398412453671617, 0.10399998270816381, 0.084469482723263, 0.19508006111268075, 0.1375620112183594], [0.020513105424000852, 0.022472095668255802, 0.013658158338418411, 0.02779615776342971, 0.0511145239485608, 0.015327297301302034, 0.032821332570165396, 0.02845130849539513, 0.03600782549549495, 0.09747972411494102, 0.012886741315014662, 0.004448799938414126, 0.04368140264564464, 0.03583295060501945, 0.02385682831968992, 0.04804912271098264, 0.07344592182386307, 0.02734320636297907, 0.008032562121027901, 0.016878960511436867, 0.05337573970938402, 0.03636828135518778, 0.08471372687528211, 0.064926418896404, 0.04206501458200716, 0.029808308763970292, 0.032337456115431366, 0.002791965784009306, 0.047071196153880134, 0.03667893000848351, 0.035573978412656054, 0.048692318640889666, 0.013488511040416217, 0.036000731521316116, 0.06977149600824041, 0.0739821297447047, 0.07230862599587248, 0.06640723621052119, 0.051440180264293194, 0.005448994277450707, 0.10141061318497505, 0.014553469973766517, 0.023194139282549583, 0.035406515422847964, 0.03109929140567059, 0.04788899501304954, 0.04463133634999395, 0.030434208343766873, 0.0848320797987042, 0.03570304507569921, 0.04601664548259109, 0.004683307591720575, 0.0691355127961405, 0.03830805428386216, 0.014152542646643857, 0.06075431172165179, 0.028353456084826784, 0.06652710598803337, 0.07160479037631905, 0.019893077908143885, 0.04329623278951453, 0.04403124052670695, 0.04156635263033452, 0.06092960413004603, 0.045182387224368514, 0.023558011894384702, 0.007621852808722085, 0.01961211707713383, 0.008977797791181553, 0.004664378995526462, 0.1023118926452533, 0.07476050571929063, 0.03759108408684692, 0.054167901436167384, 0.012016723987706488, 0.04615111306550042, 0.025400081799635967, 0.043130010862143776, 0.025559994992950273, 0.037243927513519605, 0.08333401018453222, 0.08599507787655439, 0.009366911084901904, 0.06607335977136128, 0.05579743173814589, 0.05788565718478734, 0.042700415567284634, 0.05690297322167505, 0.049167423388890685, 0.0396334438494617, 0.0562945653444096, 0.0659564394323576, 0.0583378252603354, 0.04731498448358429, 0.024719575472596674, 0.06675929191612429, 0.05041658720602432, 0.018069417095713077, 0.036396293360139095, 0.08537480712778146, 0.004391386436538831, 0.07489965792985694, 0.03437758656218648, 0.08716417401428185, 0.03886753212540381, 0.01958004863662345, 0.045611676084057945, 0.08357715116994036, 0.002541908221657298, 0.009399121251678275, 0.04293931625603188, 0.054195200979349115, 0.030360466635395444, 0.04688619741148526, 0.04696394384448086, 0.08696695999993433, 0.020112814907465252, 0.02492841295597534, 0.05483379655127084, 0.06345305561779008, 0.09057480511405776, 0.07935154807543562, 0.058823390938942476, 0.059171037808541334, 0.04959618747835198, 0.03287044646699102, 0.0017619310036083805, 0.03946022753934226, 0.03374123562788291, 0.01838650854845201, 0.024538638911420302, 0.02690074653665145, 0.06591271113363967, 0.04995112750498999, 0.04604330151191643, 0.007711077154043221, 0.0904834261464496, 0.059516026353042935, 0.044025429749801274, 0.005212070574353059, 0.018492443186621514, 0.05033027591003526, 0.011270860784627017, 0.0912698690268782, 0.03174471090577784, 0.023078119096856926, 0.0378881385099263, 0.01929584725369369, 0.056259256351979516, 0.05338477571645091, 0.018112760435249058, 0.026406539386258494, 0.0664631299854767, 0.03702594485554484, 0.029487394532489202, 0.06144255745194613, 0.05977933843349738, 0.07035618197293052, 0.021501856803473447, 0.051959285272225264, 0.02674220081028198, 0.013441719347611071, 0.04008930446880479, 0.00914543027794289, 0.03728315121524277, 0.0335617603794221, 0.016228408222236944, 0.03711855339427148, 0.044868938519709536, 0.025007825630206256, 0.0838340204509516, 0.04414363711651775, 0.04435503141834371, 0.020158872113472993, 0.04612055764864049, 0.11285815778518878, 0.04364941081392669, 0.0194710094271408, 0.09342242287652147, 0.01515148969877872, 0.030715192157414653, 0.04552418501266549, 0.011691319523379208, 0.04896984931321875, 0.039933179580276056, 0.04823302211720617, 0.03524985810321185, 0.023276758034743612, 0.05306802900327791, 0.055508562964537454, 0.04945518133500892, 0.03793047635906166, 0.03198759142129171, 0.01684217871497235, 0.03130626538017344, 0.03589283186762083, 0.017212685648231738, 0.0790726307839636, 0.01671522262416059, 0.014811499877983044, 0.01781401104263721, 0.06390828421459564, 0.016247075869731845, 0.04614614498531146, 0.03385742052247928, 0.04399668230044265, 0.01518208150481505, 0.006236252083908767, 0.027211029382963336, 0.02256740658213535, 0.01626688307301412, 0.07846703061894064, 0.03409446344801015, 0.04462134656346133, 0.03564284971704887, 0.010042915687776141, 0.048543839309845245, 0.020601931403601365, 0.017778640763173183, 0.04060007060968107, 0.11326848979919188, 0.07182868723306926, 0.010525552995292651, 0.07079493584892443, 0.05277643295665903, 0.0608964363533643, 0.03219150487453707, 0.01106448244348529, 0.052254278918788324, 0.040407813184203646, 0.07859885136807158, 0.01690355384902608, 0.007921408030069283, 0.019040083054513223, 0.015306860948311947, 0.04096356017755405, 0.007773193956968645, 0.02265058266329429, 0.060999245352802746, 0.059045621554457375, 0.025372629038869374, 0.008763467457385795, 0.007054931465386143, 0.010591443260050109, 0.033131444961914135, 0.04246916426646133, 0.024688543166003885, 0.04480126997335784, 0.004949301458714951, 0.06601080869234378, 0.011388534762626214, 0.0202453883379818, 0.03790875010552906, 0.034113117688966375, 0.0038821326011055785, 0.04027678150563471, 0.030803985578278383, 0.060849379402615374, 0.02464655388687407, 0.05646895759949281, 0.024935799958785216, 0.06688936598478787, 0.05828618327335966, 0.07243280884839835, 0.02049095016123066, 0.02787488287374858, 0.014402744089884144, 0.10915032287518825, 0.05340691948790224, 0.023046598409212405, 0.06678084963031354, 0.04234365991226608, 0.015181381491974238, 0.026008529896517436, 0.050790135508343104, 0.04660125483848876, 0.041370544387328054, 0.047907944197856614, 0.04598237836973802, 0.09666055395838716, 0.0038962326887544366, 0.03163036270697992, 0.039522058495710936, 0.0425971239324539, 0.040387331823548006, 0.06867769099171124, 0.03197894611906621, 0.02129113474380105, 0.053044835691370314, 0.010637475568200312, 0.062168104003273675, 0.05382609598699117, 0.04815706832995338, 0.019323200423030124, 0.058145889591786175, 0.078163736409718, 0.08869952912772856, 0.11542894967621374, 0.06992466762782105, 0.008174215608666982, 0.07388330440247252, 0.03130915353164798, 0.04862631633577328, 0.009597070710433107, 0.015120085839542653, 0.021627297955414942, 0.017976099925656474, 0.05031635609245108, 0.03565543271120518, 0.052734769264897036, 0.07975614975176512, 0.025529717282962897, 0.04416928957066229, 0.017447273261965286, 0.02291212125020402, 0.09478908542904163, 0.030604542248071204, 0.04640513249943334, 0.07048378923847791, 0.0782839356050376, 0.03967720662213622, 0.012545706741812249, 0.015167018301003884, 0.0363996411643682, 0.027381468624357256, 0.03918920478392993, 0.026987000376046188, 0.09980925193597233, 0.011172305488388145, 0.04035154019572562, 0.030403380965693828, 0.010267751002233597, 0.045295932946065744, 0.045404502926694776, 0.035234279705271605, 0.09119631692526803, 0.010658557350266605, 0.021880905617088563, 0.06458506543910311, 0.05959631236750753, 0.053595492030463876, 0.02661345781938684, 0.08673703403122003, 0.010807094137905347, 0.03227939048121053, 0.04781703637432187, 0.03051144532829283, 0.026990759952534592, 0.020768245261523034, 0.044140434868994265, 0.05958598167184861, 0.0502055031698077, 0.12859026360655987, 0.10545467642406303, 0.22308711713600546, 0.14896371311718418, 0.13535776175558567, 0.061690651195784735, 0.28620484074757946, 0.2213958554690884, 0.12606804935081353, 0.2284269031858252, 0.15366789133798692, 0.1532006083476928, 0.2175552422000516, 0.11038999869337968, 0.1325184560471004, 0.1297198908944284, 0.22867143845125554, 0.08107444917362544, 0.1472541113053599, 0.13136204632539905, 0.1407589420916573, 0.2112984642266266, 0.2446985800540255, 0.20020882058287823, 0.13806481004482316, 0.13717849228170612, 0.08834025687387875, 0.20558036863803866, 0.11456788217108096, 0.26889241811248565, 0.09522480559685538, 0.14009414631272518, 0.15582167092830906, 0.11500999917306247, 0.12375693062260268, 0.1609258542978956, 0.17836777643570978, 0.10341689786723546, 0.1348228485233361, 0.1117550448003796, 0.17911671931224485, 0.11289037944328402, 0.0757114353379415, 0.14407090872766512, 0.12289791623310697, 0.20460213564576643, 0.13713232782338897, 0.19762440764855957, 0.16843236682395782, 0.16846365385478543, 0.16751905212238913, 0.1260127071591635, 0.21346407221449962, 0.18333210279383969, 0.14717577115422295, 0.09751086558906302, 0.09307581405606001, 0.12101440480159176, 0.1440759189426899, 0.13513306816739423, 0.11587380927296416, 0.16006898495458788, 0.12805717366357006, 0.19395086283404983, 0.17522540634437916, 0.13649583133237977, 0.11767350302468385, 0.09266652392163392, 0.13092506977338947, 0.0866745135957195, 0.24052306378801025, 0.16639008367013547, 0.09783655254831237, 0.24525293659779335, 0.12763574869642336, 0.14304985142042562, 0.13873847712191845, 0.2120781578724423, 0.09484686378029086, 0.14089823219804995, 0.1421780740061114, 0.14846308998042537, 0.13918608697431703, 0.14338447862575132, 0.13721580076361858, 0.24870698190023824, 0.12982685209041642, 0.1980063944093643, 0.1477072216690548, 0.1253029726625931, 0.24253194550833396, 0.1410737429415026, 0.16213786668114125, 0.10414665790214654, 0.2267323166973168, 0.12178853664907718, 0.18730436061178485, 0.09127783634129072, 0.15186882577836514, 0.1812700698933294, 0.24935334560371217, 0.1840397075659806, 0.10246278898369882, 0.24135653680611044, 0.12862781723660807, 0.09972174171238177, 0.18012562646500527, 0.3321315053730242, 0.16860835254192355, 0.22592072315033407, 0.11235668429083402, 0.10644364230815442, 0.14422178208347292, 0.0857475778508571, 0.10009586075020414, 0.1702002219615444, 0.1461750151769769, 0.1087865690069814, 0.12307322013282007, 0.14282701176501092, 0.17970954879157006, 0.20345369323847756, 0.2377305047646646, 0.1610098634996722, 0.15919705432268882, 0.09204498146690669, 0.1444603878283693, 0.1342964235452875, 0.06137619891594495, 0.2551327129044841, 0.1267180519719278, 0.11707006322760737, 0.20184492391924705, 0.11351445764904061, 0.1225928063955038, 0.07916182640098757, 0.17704837384723848, 0.17889623920763695, 0.11466326011765389, 0.22144468591338207, 0.28247589245438576, 0.08567404873188465, 0.14765773238914628, 0.1906862710752795, 0.1930167105409407, 0.07781627723166058, 0.1360777005433075, 0.1788414332775339, 0.16390900067504377, 0.11124692166284209, 0.12258353673162, 0.1974633912886343, 0.07114542873516198, 0.14330642958802564, 0.12672774298416992, 0.13952926372087773, 0.12354956594325843, 0.20063778385519984, 0.06262464644086939, 0.17706234729097736, 0.06344118125496373, 0.11626059940505414, 0.1254654445895745, 0.0970261311158538, 0.12916446182756655, 0.1297495844623735, 0.1591226518634827, 0.10820596629092771, 0.14762287538859153, 0.1449279006450407, 0.18669381917965028, 0.11139536651992991, 0.11470896492321646, 0.23720193474042803, 0.15354585353164904, 0.2570718346584228]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.034273444569759795, 0.0638463689885553, 0.003464276406673655, 0.034492970894901984, 0.055504487376780286, 0.05742512725954575, 0.03790266353697066, 0.00953391154912571, 0.08914031313672181, 0.06464024675228904, 0.06375601657876565, 0.04782219214605228, 0.053059866336444696, 0.04556750345434393, 0.026906848426968343, 0.009725201788598732, 0.032489838664449995, 0.04690097524754463, 0.035579218454058134, 0.009282838680871553, 0.06418199593862219, 0.016145377697783615, 0.046374883517743125, 0.06446236113627112, 0.022115303624060847, 0.06014493857360175, 0.04327350679124075, 0.019437772702545892, 0.021113664730482047, 0.049649105001721656, 0.012680701967779429, 0.03406022697867405, 0.04167916290762444, 0.05636023440127892, 0.08045082295974416, 0.024727910509212844, 0.014947782131663014, 0.0394297027659993, 0.09197433283852954, 0.019803729073535052, 0.021549430863571264, 0.06529159002727078, 0.0911020651279438, 0.06876060468775612, 0.014533952926285567, 0.07695102688646124, 0.03916662434236177, 0.018983495969986244, 0.04278569647501554, 0.02943821551819002, 0.08011086378246546, 0.03301914796353348, 0.033128269527467995, 0.013987172034478957, 0.055922587522335594, 0.08365994995279659, 0.04272289258698302, 0.0404847820379561, 0.0714882530812775, 0.02506744067725395, 0.004705505946936507, 0.09482598788435422, 0.01582725681439643, 0.02356086940234227, 0.04964999749415344, 0.11819482585715672, 0.013402290717368166, 0.019929681589166005, 0.06512134996873718, 0.03616231861674497, 0.05756228764150893, 0.03415136079814646, 0.05608959085938912, 0.08736989160458888, 0.06588702420553853, 0.0431487187292547, 0.026293296269291354, 0.034912220172343716, 0.02948738878682977, 0.030850896972321698, 0.09239827823494712, 0.02329747879787559, 0.04926633300079454, 0.050249392346989726, 0.01553577472335629, 0.017459298927156676, 0.01904971852538086, 0.03293468676988156, 0.02691792605835344, 0.08343809855080421, 0.01573098924822144, 0.019958679932319832, 0.047708830285456874, 0.017841323992357622, 0.02918357555303843, 0.024803423795909173, 0.06181713997296268, 0.008433626386367025, 0.009222148237900149, 0.049650495451304226, 0.04622866414607533, 0.026954792124489625, 0.047988061672977866, 0.017266844234038747, 0.053717909050324274, 0.03890968994387696, 0.06491193983463511, 0.01990647487071974, 0.03291850699292075, 0.05053561045638016, 0.05009089258589572, 0.0162021448129728, 0.04804213215867358, 0.005317253967551816, 0.019630319326214736, 0.015938859545595704, 0.02388121098309996, 0.03582165080813631, 0.007139155650586491, 0.046551168009999304, 0.11724887581001367, 0.14369557161004315, 0.07762898405593249, 0.05680520125033875, 0.03610807193082667, 0.050288608387833646, 0.04583595598477029, 0.03438149361060031, 0.03510984021329111, 0.027737862302831588, 0.03052204223950544, 0.016734570174688296, 0.0317001226733649, 0.05000787929842069, 0.030677956453855, 0.017618436456447648, 0.029386445211486954, 0.02552677933577328, 0.057242614472465175, 0.06495767528371466, 0.011186739542491494, 0.04228508099913598, 0.030758265450957323, 0.022479806343213688, 0.026069020199018623, 0.03184915933337423, 0.03996154398567254, 0.013082400170875894, 0.030442317384445382, 0.045124926799607855, 0.02902600084311299, 0.026306160800759832, 0.08132405594111451, 0.08194618828354344, 0.10161535018273901, 0.02564919252519406, 0.0334164526523842, 0.02178303405432211, 0.021994571997633865, 0.029472574561593995, 0.029837241989650556, 0.03595362860529173, 0.11428162575729432, 0.10125551102382523, 0.010775011333246386, 0.03190639950785666, 0.029449373588807164, 0.07595076120548672, 0.05170559525609978, 0.028495498362087437, 0.02511053312299473, 0.036975271969793305, 0.058829925668936585, 0.023175843187697956, 0.03278638746949934, 0.0833309841372313, 0.025049090956247626, 0.024959772765155763, 0.07108791851468625, 0.02596592966226801, 0.033949688152079625, 0.029316692905981215, 0.057537339988254735, 0.06223097300877976, 0.08749061173969701, 0.032140027596465046, 0.009539683064025258, 0.07344677218145902, 0.002194303008089323, 0.07160953246057034, 0.02550251541599151, 0.041199193501304236, 0.038963833207925486, 0.04092572309497384, 0.03413370247149179, 0.02879402558920124, 0.05965318290456649, 0.056025132221440156, 0.03597154357140103, 0.023577499255958586, 0.009500803144258118, 0.013373285670945001, 0.01817782811309782, 0.009996236035329922, 0.060989887588807655, 0.05670073750098387, 0.0413338449453154, 0.039150425413202856, 0.07453192040444383, 0.03292507619687146, 0.06545799964618298, 0.046451093944450544, 0.04350932780653239, 0.06906779828451334, 0.018330141714203264, 0.01946453789940044, 0.007584420316326883, 0.03174297188618972, 0.08819041773676874, 0.06837420526050753, 0.05198201127049904, 0.05285968756183021, 0.05412688125826178, 0.016684125200094237, 0.08732557341816925, 0.018179109395151178, 0.03562302719200811, 0.028361342960007252, 0.04710429498264867, 0.03789739668249123, 0.022829127114927097, 0.007110326325580959, 0.018528920463136127, 0.04268835734335646, 0.008519418657787384, 0.04232115224905072, 0.027823817367935856, 0.04697414430519266, 0.02904661818437519, 0.04962682333444396, 0.03697876150028841, 0.08783004231630795, 0.0637770533531664, 0.024040377240688093, 0.06785382471618152, 0.024554847416678266, 0.017648645218521837, 0.0457266045944585, 0.04735553351741645, 0.06266274016290423, 0.07459427996148026, 0.05279391891353073, 0.015486291189107205, 0.03228210243246248, 0.03147456723625862, 0.07730863672951538, 0.0485951250659362, 0.11523349000321281, 0.05549125703832796, 0.035276027666705276, 0.07055796187130675, 0.045777848215713624, 0.02205994419543253, 0.08395716142390044, 0.05683441601333119, 0.060266497574986956, 0.00955026273825957, 0.0019134263270497024, 0.029173700679694454, 0.05490783894915254, 0.009311813083777746, 0.04379246241202758, 0.10101601661693665, 0.04465336903869625, 0.00547878839443588, 0.016822587931528687, 0.032856798610619964, 0.035301457955351764, 0.08274976088995896, 0.05172942442098453, 0.019960545356415456, 0.004944671414822581, 0.09033232296426451, 0.09457022943083318, 0.02340971833966192, 0.06478872991377307, 0.02379105009529139, 0.027279825993783535, 0.05232091324644224, 0.03444362334125946, 0.0360847024186965, 0.019551816381393902, 0.058006021089010665, 0.026817767723133008, 0.008532422042692141, 0.010618819412024272, 0.061935266900447115, 0.009751783124351454, 0.004370193092918565, 0.06608980767909559, 0.048438103854536056, 0.020133250302845435, 0.03993841196079889, 0.02219041471459693, 0.025166356034817237, 0.05994848681673889, 0.031471742287037835, 0.07086221369043474, 0.037917062159507506, 0.08524193683819425, 0.022977853509327097, 0.06258901186107148, 0.10522897926069076, 0.01926918930914854, 0.026037689118135362, 0.05956933075081437, 0.03306947227927946, 0.07485649653620298, 0.02751006605854679, 0.03438348543920344, 0.014178840529864595, 0.03371059211091169, 0.06641963917401529, 0.030095306367823677, 0.0249921553017151, 0.05698006464949539, 0.023417655010557464, 0.07794418327149846, 0.055854964941259355, 0.038973443780935584, 0.09596244101562808, 0.038134171477248596, 0.013999241749725997, 0.018017403556094054, 0.05728812392560705, 0.039632256413179065, 0.037341132579791936, 0.07693792678295605, 0.01887810716946279, 0.0346378342909438, 0.040137058559564814, 0.03198000140518191, 0.05180064761530488, 0.05596660693446475, 0.025876590403758233, 0.027801958964236324, 0.04303354124027876, 0.03974127072480418, 0.07809516387961565, 0.04015512291281935, 0.015645128028887897, 0.04211244691583899, 0.08923949087939917, 0.11896950928794763, 0.28861783384796114, 0.11696721592377271, 0.21706946584726536, 0.11966392968691165, 0.18604650552715027, 0.08708683743832574, 0.163394496025097, 0.10798002397941966, 0.13012089195751375, 0.15170626192083284, 0.12340206337431747, 0.12082250743743875, 0.16629107446680147, 0.16318524676945903, 0.14540658302364812, 0.17247459911290677, 0.17948595836998957, 0.17212360826951845, 0.14239343664338514, 0.15102992885776106, 0.12154112089305155, 0.184891582016022, 0.15324865738230367, 0.13014163761850328, 0.11514938121000606, 0.09630374850765352, 0.16957890933319447, 0.15325005166232586, 0.14896952006365025, 0.16714414401400476, 0.18772750161588195, 0.06788262196125523, 0.14709021445483933, 0.1280345434262868, 0.20057600652498586, 0.13361828251471444, 0.19480938692727398, 0.12257897084759128, 0.1606280759217278, 0.12012220348321623, 0.1370334718376398, 0.11506951654389982, 0.1633022896825306, 0.10895604297759072, 0.08928366350911318, 0.07318897593405939, 0.13571147987198445, 0.15791975592653598, 0.12825477838275895, 0.13057593286277788, 0.10832644127790006, 0.12094048497777794, 0.15784072629626722, 0.20270626721603258, 0.11093742980231201, 0.16950518103136172, 0.12764425227238288, 0.11161052997434333, 0.11253839268559411, 0.14794143006926583, 0.16368648277655726, 0.10150045231585542, 0.1815081240549203, 0.22591839424304425, 0.17711516139247727, 0.0672820013677401, 0.15206782477757624, 0.2010572169937434, 0.11771690190559435, 0.17274625389085663, 0.16782397043801126, 0.15069703301114423, 0.1775286803322454, 0.2201769942597997, 0.11334389583357882, 0.1988311187033692, 0.13044758249194394, 0.10338135138754884, 0.1134026700991296, 0.2307578942347919, 0.22893625972492082, 0.1607137705169378, 0.16632122768750116, 0.14526622039416145, 0.1534197554593125, 0.2849072103779162, 0.11312582124505313, 0.1513002046774472, 0.10536952575127925, 0.03744084275357666, 0.11298587230304558, 0.1454293818002747, 0.05512509765403886, 0.1164850784886268, 0.151780603093005, 0.16454712127245244, 0.2091425395901165, 0.09603302069609204, 0.1205439119028949, 0.07097139654140319, 0.13577707232006136, 0.15944925046736197, 0.1486685854052344, 0.1340853203568728, 0.1700945171497522, 0.16947397060932654, 0.12095146301773288, 0.15614897433307864, 0.1666312021834235, 0.11487439394958558, 0.19546710405378573, 0.17979833838199416, 0.18624490697778043, 0.12057385827985503, 0.08255702082908924, 0.10962804764389031, 0.11247103823529137, 0.14655683339843828, 0.17873799608599755, 0.2226128321020834, 0.21835442512266098, 0.27463185691064407, 0.0621537015502972, 0.08608973570047848, 0.12682110611950198, 0.11301414860833077, 0.15702217667093202, 0.11791643716635243, 0.09586776020906626, 0.12432364416458916, 0.1976400205204564, 0.1586517376164275, 0.12783339938088772, 0.16481846961523258, 0.11976090109636707, 0.19577916230886214, 0.13674131654683622, 0.16846723914627107, 0.09634127149418478, 0.2088548276092737, 0.10056899665223976, 0.12300926711290114, 0.13843651590568407, 0.21323830610321415, 0.10820297854802302, 0.06733380423317994, 0.1077356955577289, 0.14348551030120543, 0.18153205664167482, 0.13688526446780852, 0.29510439223339485, 0.12163204786878441, 0.1663061663989098, 0.23799036178858052, 0.09989485460063142, 0.1585114056304578, 0.15520303960769408, 0.13093197988646646, 0.13223083599680854, 0.10746591769519354, 0.27584641270579835, 0.20685025130308446, 0.09708977770060302, 0.1124459718384089, 0.12892138212919235, 0.14035473878104843, 0.11492936075815272, 0.1168514370557762, 0.11855164662964883, 0.14565536241617896, 0.12754357299737393, 0.10542235517453764, 0.10820212052954782, 0.1750043440129488], [0.021742793370879466, 0.04168808017106306, 0.06404798800846742, 0.04967904754824216, 0.04346510921154292, 0.03914318588231841, 0.004984236504476999, 0.03932059269338366, 0.00966106107713835, 0.048519753505505865, 0.034998033511182, 0.04849246162320337, 0.04698180518443546, 0.042889206444904696, 0.03231206030074147, 0.06410642136489192, 0.033824076545574976, 0.04717916092504898, 0.04278028406383049, 0.012421521974066574, 0.06944559454437225, 0.061377819191904805, 0.09963789338906927, 0.042048486235040816, 0.052115724256802956, 0.06756236656538903, 0.01893649647583164, 0.03723142112815573, 0.01434059137658727, 0.06311744015904204, 0.04789615793514156, 0.0727112281827196, 0.031803580932319164, 0.038367981511738994, 0.03075945671767958, 0.030763292902960416, 0.06335268660839047, 0.07171356720068763, 0.022363690396530495, 0.013238090304507604, 0.02004534171353425, 0.03790127308738809, 0.041181163622006293, 0.17693724513294237, 0.01367996215835334, 0.05409697318569787, 0.021571881070192304, 0.06193344361118733, 0.055436385990751375, 0.06034397587720906, 0.05912733632290076, 0.03130666566111388, 0.07026333977738697, 0.0600620478601946, 0.1756759732961655, 0.06507519317129928, 0.05544343016921513, 0.031042533866580457, 0.010809737141244115, 0.04007370691866644, 0.0713189093456153, 0.02050247786927127, 0.04698992571643284, 0.11510820398407598, 0.008109519483461496, 0.023391100487882094, 0.027557988688650153, 0.0544863335427738, 0.053942778838738326, 0.09748204536135159, 0.038277575475794655, 0.0188795761430576, 0.057235727342025894, 0.07600179798300229, 0.046899021723337715, 0.07990901493617604, 0.014529916600534513, 0.11039990421024062, 0.05431816192163576, 0.041357700923277486, 0.012891810901853587, 0.05680896657248659, 0.03848459158513335, 0.05822615645405266, 0.044550632817610625, 0.046867060535136736, 0.03251467906539479, 0.031873070852710836, 0.03223836647286531, 0.02516994324152268, 0.04454101458372128, 0.030126612550849398, 0.07451614665408289, 0.02008435665629804, 0.01825163110850319, 0.06289714008509632, 0.10004316156189288, 0.06557090568446344, 0.06662298189175707, 0.08533033572377698, 0.024262755328128417, 0.02984760715926607, 0.03920607404002259, 0.04828873969193909, 0.018045292986977487, 0.03941442697278915, 0.058097407717498085, 0.0469941966566107, 0.027859934583126057, 0.0537729294850461, 0.0636156769319167, 0.037771988089286515, 0.04107593761516675, 0.06952038770841976, 0.020388212024925217, 0.023307707986884543, 0.047540896151575356, 0.05498719799722876, 0.03253442498164312, 0.07425448932354489, 0.04747908817784441, 0.023721410787754485, 0.0902897974235877, 0.04158049078297712, 0.008801002892845822, 0.022553572949442654, 0.050672288202951034, 0.02713930631627239, 0.002676264961220084, 0.0017037303463908874, 0.03427500355868571, 0.013694622208394352, 0.0212890854586036, 0.041204345442595026, 0.04826380353000376, 0.07700680574822812, 0.04498491274012674, 0.008884748751898448, 0.010492618875427833, 0.056301452474848884, 0.02066136067432742, 0.01102702170159788, 0.03144021776895369, 0.07806224508150932, 0.028929184566462235, 0.0682241133143825, 0.03356696977730721, 0.02548728175761719, 0.10195049832785323, 0.08116862436215724, 0.015431067741085446, 0.07220254580099737, 0.07049870497036366, 0.015774915772189778, 0.04504220462554405, 0.014741419112279773, 0.049065208107593565, 0.02526160949210246, 0.04844870268096847, 0.04743821738708404, 0.042410895618940556, 0.07503388419507012, 0.05682238077204074, 0.022523992379466375, 0.032138771212269227, 0.014620108131860054, 0.05044726902739175, 0.03511697249186616, 0.04438229648756885, 0.013386254581893164, 0.04171094789560284, 0.015529526318723877, 0.05060105734775144, 0.022573929820810596, 0.04975048907762093, 0.04941992979917315, 0.024747911149696, 0.023087808193879265, 0.02474501533734222, 0.026066405923977017, 0.022518859590373697, 0.032489160676637006, 0.09880860321103566, 0.04687293642951597, 0.044714931864291436, 0.0779062849018843, 0.037686937007932894, 0.006515584020469819, 0.05167051225960736, 0.01082668683656882, 0.04036983437535744, 0.08963657723319146, 0.04010457643157533, 0.009602366293209695, 0.04441189429452343, 0.020063047920684182, 0.048793932543166225, 0.0327282490569257, 0.05302269575035861, 0.03176905526479166, 0.023786767663794662, 0.08733534870008308, 0.06984458845709601, 0.07155373061616575, 0.008302199214907184, 0.029771957891963186, 0.036047945520089525, 0.0462549677749555, 0.037648172958964304, 0.05562671287465961, 0.018140935233884284, 0.07441611855380958, 0.06015112856402994, 0.0342140612643092, 0.028616358308241736, 0.05847386332348951, 0.0378856870285686, 0.044361608283173655, 0.04319511301394913, 0.03782417016824888, 0.03029033320114738, 0.04110037965039092, 0.036551893478439706, 0.020411129545180068, 0.016691573489938053, 0.06469850773893057, 0.06187468849783463, 0.04833518760278822, 0.05274123504697796, 0.03894558499356912, 0.08527035103930582, 0.060057049136488676, 0.032131393785558404, 0.019582025143468094, 0.09624870509029397, 0.022057308852973006, 0.06768820416783133, 0.029615264183150667, 0.053798309977977514, 0.06538833927122817, 0.08689782056476801, 0.036503231573489406, 0.07299231350301735, 0.006046245041708913, 0.010373965262495463, 0.02501881324626025, 0.031286908253546686, 0.03017196112552718, 0.06836164907942857, 0.02136376562468227, 0.021892282022764126, 0.027777438404999917, 0.058599735399888414, 0.018764754884966442, 0.04197557381684742, 0.008130921107236176, 0.0739559448594528, 0.039360808478968765, 0.03138730790646326, 0.05910782023302971, 0.024484685254133037, 0.042161208412219445, 0.030729270938243118, 0.05072278105804036, 0.024635434120653138, 0.024926706495124008, 0.02903145538913387, 0.056362260703838644, 0.03265595333951135, 0.07739503612561573, 0.04301876723465901, 0.07068071980029345, 0.037058725757824804, 0.034714692061947244, 0.03556188571477129, 0.04470795280330124, 0.05642919763622265, 0.030990405413772792, 0.04153481279049189, 0.0406924799655474, 0.05148450611159206, 0.040358212821546106, 0.006471959143621668, 0.034487125644039725, 0.011378759480712396, 0.028725234724040476, 0.040110915809148745, 0.04323989851400257, 0.020078796773187576, 0.10230001062154771, 0.0200313912524331, 0.047238475282586394, 0.05074017125392153, 0.0715451121270176, 0.039558386385080316, 0.0428073997459104, 0.052466569543485685, 0.013253041467959843, 0.070310415880334, 0.0461690433533682, 0.014366317566694512, 0.0050632776260646365, 0.0653207473336689, 0.05096349354472853, 0.017153453645146182, 0.027983000862502286, 0.06825491004893858, 0.03349561634803972, 0.02552321894214519, 0.01662529730838874, 0.06265352412517514, 0.05636831662888008, 0.03708781411630973, 0.0807699905107579, 0.0156688786697604, 0.03032480907295981, 0.05970993852843681, 0.041346075539026535, 0.05155204442299662, 0.09316055870224392, 0.049937977605769714, 0.005808686443244017, 0.018805001314068516, 0.050268667119164626, 0.04452239098628202, 0.045174511840506915, 0.015794634875360758, 0.040978307370096445, 0.049404956610693086, 0.03876121827371178, 0.024485926316570372, 0.026160910530316255, 0.009702050611526977, 0.0073330788384942764, 0.03548697380709552, 0.05277964286506177, 0.0566819338728824, 0.07222339105341705, 0.07100797723978758, 0.1100971692452027, 0.033729319130220724, 0.057401910965000434, 0.023864533248988372, 0.04664406383169755, 0.05328884618657251, 0.04066284385419661, 0.04325891664672283, 0.04068547409147986, 0.009917788631883601, 0.03064545134322778, 0.11394967219882435, 0.02184484394327287, 0.19255117423111395, 0.11084273367399171, 0.30783079804912694, 0.11350717981375995, 0.1179375505495456, 0.15851961809300608, 0.17623765364048943, 0.20232999547114297, 0.11224174811955422, 0.1263220458021087, 0.12286671347195104, 0.27213882294393354, 0.20350813144637694, 0.12073682050310797, 0.18169278188818888, 0.16892073255392814, 0.16098395440607302, 0.1194523745066216, 0.11758920270949604, 0.07491867223213758, 0.1959471194253814, 0.1246081309152707, 0.13731582120301264, 0.28978951936287267, 0.20326880557883173, 0.17624209695045026, 0.16705723899987437, 0.24618934118939986, 0.2205230361751972, 0.17200949181231762, 0.14642407036116048, 0.23488913061878375, 0.11188975370098507, 0.14475389143391965, 0.19865376934889825, 0.17693522266082226, 0.14623231855371308, 0.11446562475494801, 0.132538067897962, 0.0991910036593195, 0.13454710283587057, 0.07409758685577301, 0.08305741413947075, 0.26676768857625227, 0.09512377392140128, 0.10078101914616362, 0.17419852676891512, 0.12958895114641036, 0.16020894921835394, 0.09258934056326266, 0.15294942343907972, 0.1856852031403011, 0.20348095064682348, 0.1725704979992682, 0.26366147783494764, 0.2413784009554694, 0.15383546541054405, 0.10179404019107742, 0.23967285940964378, 0.14237042336213973, 0.2659096701010581, 0.11724188908814423, 0.11316037181043818, 0.18677143920813838, 0.1523708891604216, 0.21769477745458005, 0.17184858270470174, 0.1069624600331149, 0.14835474982617364, 0.1555376514912613, 0.20173194127217417, 0.13726547390462893, 0.13822467727286203, 0.16060552229323696, 0.11178483029887562, 0.17702903778802964, 0.1027421429452877, 0.220181989153066, 0.1567644340496871, 0.06911747908640294, 0.11131403096500905, 0.13927679178455185, 0.09324475942600159, 0.1846765104921595, 0.15307421916194502, 0.11007405637252717, 0.1548251590781635, 0.1265112158932513, 0.1339729659018978, 0.14721531661287432, 0.08360512870093507, 0.08061204616340899, 0.19101182779958173, 0.1785941247738177, 0.18140117818069074, 0.12516354466037405, 0.14878428000355923, 0.22605074359284294, 0.11006763655572169, 0.22025584002896664, 0.1760981030642025, 0.12918185202344773, 0.16223575739610582, 0.11098965401611022, 0.1999065529314741, 0.14413493835637647, 0.1203683398724083, 0.16404548689963358, 0.12692003871404356, 0.12730491362632285, 0.1376102287923136, 0.19490692524179337, 0.14544864125069112, 0.14540344206315858, 0.09005592610206335, 0.10515518201094483, 0.13718177113802205, 0.18767790508366403, 0.13517486592454298, 0.24134504548724622, 0.0971898211226348, 0.19266680754240484, 0.2623051957738015, 0.131288088197189, 0.1287271175533533, 0.08223838187874326, 0.12479726270201708, 0.1360585177016835, 0.10555153292032982, 0.12212330175022926, 0.139797271920308, 0.049874154820797906, 0.1181274943894917, 0.09049240469692216, 0.12405367478007272, 0.1861489008391096, 0.11499211868090976, 0.15096881036316195, 0.16835166712201413, 0.14536394256978266, 0.11820447090412341, 0.10983198024933377, 0.11968269884105652, 0.20069773789615403, 0.15558248295659022, 0.20108562353397572, 0.128077176219273, 0.2184398898914937, 0.16989879700685703, 0.14071702176044065, 0.13285605567357234, 0.18645502957365206, 0.16669975173088813, 0.1384299581930522, 0.10518643073737623, 0.09414141171521719, 0.2471988458907412, 0.12440623610370583, 0.10432886425405742, 0.15029270712646747, 0.17938612179169733, 0.19674953523903124, 0.1277229678066027, 0.10890811651704774, 0.11983368711005296, 0.15940169172902263, 0.13608491709155424, 0.14870822279443666, 0.20016863161037046, 0.10792622928537669, 0.1672820704838922, 0.13081769488992231, 0.16528596711014548, 0.19982111880615835, 0.20494195692721875, 0.1553753021383478], [0.04494259787362911, 0.032850646924587994, 0.060839569646744966, 0.07527364673273218, 0.03987008074839269, 0.07752023787508089, 0.024272691488506335, 0.003067442861896369, 0.07516681577169126, 0.04981332743961004, 0.07844041672445114, 0.02026688476513711, 0.013281622293194937, 0.053320849509609324, 0.04372781608253718, 0.030104526235992392, 0.09071699103280421, 0.040824116853576516, 0.03832026572537519, 0.07387424924320753, 0.02033263234601867, 0.03880972696107723, 0.04195710726743264, 0.060271396707262725, 0.09359627887005768, 0.049906188787351695, 0.022077828518024856, 0.023844591980319352, 0.029915764086669492, 0.058298934806859305, 0.034816451520929416, 0.01631252659154275, 0.03006748780007324, 0.016331194239037655, 0.02697138367370973, 0.003835282494096206, 0.0942753775105361, 0.03411479159108093, 0.06033480580475542, 0.08173782002901839, 0.03200634908411772, 0.05809846108839397, 0.05130378213981467, 0.04252098628409928, 0.04086860357933948, 0.07133576327994948, 0.020410376863794464, 0.033089543782895615, 0.033592583927055525, 0.01209918952231566, 0.0824821510562493, 0.10558927807235911, 0.06488304299813125, 0.05012010734888816, 0.06353998361455818, 0.06260229965611812, 0.06928202711165914, 0.11126187569912403, 0.05008781674287973, 0.012473440710304966, 0.10475356041664079, 0.06761826034034453, 0.058418505810081005, 0.0559374419671874, 0.029730818970429323, 0.06025368475445336, 0.004182508254739186, 0.047353085866498376, 0.034680888432288365, 0.05201755391974604, 0.021135844891109777, 0.028931358340947382, 0.11032510338531387, 0.027469695140157017, 0.014062364521856992, 0.035800253972411156, 0.08398272577793368, 0.03071231166681936, 0.029184569552120183, 0.08800032834011702, 0.059933923485298315, 0.02052314500624855, 0.1068429809604441, 0.035652019789502505, 0.07365077373481567, 0.04182013074657129, 0.037268013317858985, 0.04396201299142934, 0.049341026573411884, 0.014780073036109249, 0.0316963113859416, 0.07815019963609596, 0.06533636020556574, 0.026635459864572174, 0.03027263848531631, 0.04495667090879814, 0.035769671742473884, 0.12316824567894782, 0.0751426610194387, 0.05760244597049971, 0.02087246577796196, 0.011009594158930405, 0.01309567360177396, 0.03443158043908977, 0.062055948731159015, 0.08401942905038597, 0.043616718011758024, 0.03794438085488735, 0.03201225753723374, 0.0241202725503113, 0.05408863048820246, 0.01955437703028081, 0.04916141725956433, 0.08723801722930324, 0.007778686807385736, 0.053317819631868796, 0.09830235698891264, 0.06757662346165988, 0.05724200160212575, 0.1213659319065271, 0.032033347937789176, 0.0339080551038346, 0.05004558614605377, 0.012350878133738955, 0.030871374502537713, 0.10137577916705802, 0.025333604520006527, 0.08117153549626951, 0.04839475859978026, 0.005613127657617893, 0.05270118397029658, 0.11446732547013991, 0.0460268497737425, 0.010500601511598836, 0.022150675818744688, 0.059904597639556856, 0.0077737062782680085, 0.019376353518436515, 0.05596295652550556, 0.03125023370939157, 0.03215245737303649, 0.025948298148690693, 0.022452594900143244, 0.04507677051268759, 0.05148927117848108, 0.027604674086755807, 0.1029603094643643, 0.020683416345667456, 0.05326639597995147, 0.06586195780865609, 0.02506798076924057, 0.02360757969830546, 0.09135433788140936, 0.04581422207035846, 0.07162620253380268, 0.01954689618170021, 0.03790231879740473, 0.021313577289542845, 0.0134627360122038, 0.05603376220190718, 0.06342047772881004, 0.059457945397063616, 0.05890878675986202, 0.05925862847136394, 0.030419338577156587, 0.05769333847227597, 0.020090743914366733, 0.0578813364488944, 0.08427992958815829, 0.01903581402955517, 0.03154888159535345, 0.02478019984048461, 0.01806136168118927, 0.049490333279414524, 0.06417286417056477, 0.0009851343671588469, 0.07076095218860334, 0.006642264798433791, 0.04651513506448077, 0.0646598202987544, 0.04375923717875154, 0.0221729421642639, 0.021443649442986618, 0.009953886694875697, 0.08697396970444149, 0.03356252646734638, 0.062532298372037, 0.0377691037682516, 0.022681570919831435, 0.051406755848156835, 0.03178093728849725, 0.020136745578999964, 0.02534978046652771, 0.019346499072027304, 0.06298852288314412, 0.03009540595925383, 0.07245736196637154, 0.013813129307011203, 0.03685661644164113, 0.02151975644782426, 0.05970548755759674, 0.029065737823745417, 0.06687333176453268, 0.11019976374002234, 0.02538605856018201, 0.03639592563793544, 0.0485493972777359, 0.022114321116297957, 0.05222960705718687, 0.04969721532336647, 0.033289105856731054, 0.028987177422330267, 0.08139357842024296, 0.006377969731411507, 0.05486294236635009, 0.0365874016537301, 0.026687193782098835, 0.05439826790543814, 0.09198501976507326, 0.04635486564028167, 0.021853730563194524, 0.02720447933121074, 0.01913838362651727, 0.062484107611160127, 0.023269145035996072, 0.02315225725572917, 0.02717749579929777, 0.006830907725323473, 0.0756143260326597, 0.027920131856996207, 0.11389022377590019, 0.008205611807023807, 0.0049512200301603205, 0.11299158731896071, 0.04548997152596713, 0.022407146734035304, 0.028469658216401458, 0.05306408748090748, 0.03019140252182561, 0.018471199568481218, 0.03034871101619736, 0.04984538438880155, 0.07538480609054528, 0.05949674775042842, 0.026088095788333206, 0.00984084276076887, 0.015675517779234198, 0.028363461193117886, 0.06250687574426975, 0.06798946058317538, 0.04888583245056291, 0.036664481590231585, 0.02096648391846928, 0.029144508899339748, 0.032755939304948814, 0.055915830626843445, 0.0636011940397082, 0.02861814520832512, 0.01732866752952818, 0.03896360721198782, 0.019856265468162396, 0.020376423846990354, 0.02545084087027898, 0.05404625816511051, 0.05045230222505428, 0.01919645883683716, 0.04363503517402757, 0.057829648496643196, 0.045268817263985836, 0.07153998699880416, 0.018072129046965032, 0.006356532676070328, 0.08952244545423216, 0.017609553666965618, 0.03251769362137683, 0.0201558843705683, 0.04768654478773956, 0.027503521752453623, 0.03266480931591603, 0.027929006985598998, 0.0663969629714566, 0.05906431409980982, 0.009936565446907715, 0.020447984119997393, 0.06630302527018132, 0.025107819256522966, 0.017751883227197875, 0.052344313402089386, 0.023556659749198346, 0.03908320502828687, 0.02812335583110971, 0.03276026004084176, 0.05204248242080212, 0.05408814019193092, 0.010193783297924506, 0.01256906284740375, 0.09090114324804276, 0.035936912566783934, 0.024259526267527573, 0.08089443383317801, 0.03341473278499419, 0.06744097993378678, 0.0891232523586481, 0.08743569089640534, 0.0495167977867588, 0.040919494800149434, 0.021671761698540182, 0.11702992022037507, 0.0905648612928006, 0.0746655721037138, 0.023920333178173152, 0.03274108486009702, 0.01139718006485172, 0.032233137922782096, 0.03980602047616436, 0.024243991919642976, 0.010120991538579186, 0.0575124919264307, 0.04431655465234672, 0.03436755847125765, 0.016965126250720313, 0.015536346416469785, 0.025617880596508904, 0.03731160755119017, 0.022943806646752263, 0.05819159439734875, 0.0507555581298807, 0.026452575524848317, 0.038813584213775974, 0.027435899171377384, 0.031503565579412446, 0.03168142821279264, 0.008331386207212365, 0.011754618495732788, 0.008644235448070593, 0.04126597721610339, 0.04472737696262137, 0.05511689668280944, 0.04306406218318209, 0.005858642079176442, 0.09084365601020475, 0.07023172332875191, 0.07987019726105275, 0.02031843290634213, 0.07894888460155457, 0.052956796867112, 0.07984617274374732, 0.013353649879835788, 0.05733246126422479, 0.01114824170907659, 0.07816717614449802, 0.036625556662798896, 0.13851111754775047, 0.10629736547989231, 0.22271858287915108, 0.1428069862266702, 0.10786631354881872, 0.16311623756923985, 0.10530657630654112, 0.06602698846930458, 0.2066835965360365, 0.19299460124344597, 0.25922402078586243, 0.18068643346909555, 0.1193354158632217, 0.1472722063021314, 0.12640689003972277, 0.12982715852558613, 0.12416530911239887, 0.1438850098319592, 0.12277027832404261, 0.1265592189625867, 0.1647215748145696, 0.15640469448220345, 0.15355032748512684, 0.10923431675520637, 0.205477804786736, 0.13775120429213972, 0.09583461924546188, 0.15447974535486392, 0.1301934558057016, 0.09770277061409528, 0.14788947398624114, 0.1011901100977294, 0.11622063259804442, 0.14935532194231788, 0.1714613865460119, 0.14420607728102516, 0.18379590774495758, 0.1331889361984307, 0.18469627556060592, 0.216323480070118, 0.16134928641540391, 0.16045388284950488, 0.12843058790050207, 0.07827351680926739, 0.11332639838538824, 0.13634595389087356, 0.20768901032786216, 0.13186311379315394, 0.13555533583125762, 0.22686279679258026, 0.1210577423954683, 0.12215352391884213, 0.24719924425646184, 0.12335274263375229, 0.21309582907105648, 0.16410355636429402, 0.23221821103605533, 0.21398752477140198, 0.1526251384207318, 0.06727236398165265, 0.1893887019926502, 0.13302520788725347, 0.14715047493096323, 0.10085319995038933, 0.2404632782863994, 0.13237818534816467, 0.20320733468378746, 0.1533438208242578, 0.10294750813514957, 0.1471974667642386, 0.10995414062973954, 0.194793927272962, 0.28423250142124395, 0.11732736917873544, 0.12148542630095636, 0.16501995073931833, 0.1772459785664274, 0.16489097217638649, 0.14717020935589267, 0.21394434805598952, 0.16929349561612453, 0.10203882826552277, 0.25318378522511453, 0.17965504929663675, 0.31760163665298496, 0.09748997437136789, 0.15003802885691966, 0.09584926684657413, 0.22947440584821088, 0.09407397299524277, 0.12418458388457376, 0.1387988908156272, 0.18261400261713615, 0.18436564733424496, 0.17199176453774975, 0.1296278684129638, 0.21037474605104617, 0.28070230697912557, 0.1321846868602499, 0.18070697994722476, 0.11193915105034268, 0.13887264976097694, 0.18217762361370748, 0.0914685462691611, 0.14909662937204685, 0.25236851445609526, 0.08256429100349065, 0.14814084275595604, 0.16187561946290155, 0.1336228790422601, 0.1594094905040918, 0.15497574132056008, 0.10678823631737502, 0.19350285461593061, 0.05401924590490038, 0.17425127958338107, 0.14871666508336223, 0.2392598154443887, 0.1591826978349878, 0.22259341943408215, 0.22526559540100638, 0.11362921762009782, 0.12835489075270393, 0.12917353230859005, 0.1173327471159639, 0.22378321526752365, 0.1659457833175698, 0.10309373899813622, 0.1842949067753169, 0.0806400543379207, 0.09453007876272164, 0.30469618076759003, 0.18700318080523323, 0.133892925035569, 0.11649205754961699, 0.19425749718662233, 0.09455015026633778, 0.13378954913106658, 0.12944429842454772, 0.0933591593357344, 0.14609371792645226, 0.20688700820169142, 0.11837928450756496, 0.09740640183970814, 0.09280819656147112, 0.08268763882017906, 0.2623752468535977, 0.14333929475997725, 0.18695983555047743, 0.07840454848783632, 0.12705772003579524, 0.16241958785441615, 0.1398247438332727, 0.1372201521430285, 0.10097281691888649, 0.13037123416941013, 0.13941346187024348, 0.19689293157669807, 0.10350139736528359, 0.2682098031284348, 0.1623439443327727, 0.0853380885335707, 0.19159600048536257, 0.07532938729010283, 0.21478451668254792, 0.09876904243062581, 0.18001681133624048, 0.0914924941776741, 0.2718993438588035, 0.12987280204411478, 0.16688537483494129, 0.13327934989525428, 0.24314639398888235, 0.13511705692977677, 0.22064043148871393, 0.14220945296748994], [0.006251303796401068, 0.048639496878510526, 0.07653373113322644, 0.04956801842537619, 0.03537897456197008, 0.011258291197009386, 0.02358176445047702, 0.05449150846670232, 0.0736718794571296, 0.011826457433222283, 0.039436034482693484, 0.07978475547485775, 0.025401905088895754, 0.017427466058683012, 0.013610942424425196, 0.0185538278967743, 0.04685692136145888, 0.03989343110832476, 0.023028277416503238, 0.02680280028031238, 0.0957162510002813, 0.014986225381313313, 0.00609937611208748, 0.07484593984460639, 0.07223210147311611, 0.02407973883823762, 0.023754331501080625, 0.016493149056670167, 0.029864384484807813, 0.014114737165190521, 0.06027190232529275, 0.03330839595066444, 0.031250296911645326, 0.0775910780254391, 0.022570721827627673, 0.019615315494217703, 0.04230560066418783, 0.05712072988371215, 0.019807664850246043, 0.023068935617864616, 0.0880610867733917, 0.04707212312026851, 0.041838547500270995, 0.05907867058751084, 0.028109211932807684, 0.06898578091133988, 0.08930295360304656, 0.05340307372652235, 0.03296835250371406, 0.057314151762834484, 0.029721122212527745, 0.08302031250129785, 0.19107954997208812, 0.0434833612563389, 0.03425655233102941, 0.03192177680771678, 0.07812411434227422, 0.061546128708869226, 0.05507355525849327, 0.04284064796182417, 0.0526515414728032, 0.0690104106381055, 0.035358228900980566, 0.06111856737744905, 0.06035626775795414, 0.018146864754418214, 0.072744874764354, 0.07309259441230567, 0.02446038494517486, 0.022125601760982987, 0.07137319433592981, 0.05904582073731769, 0.03903357019167274, 0.05184300844707797, 0.03780607134103775, 0.0862272791264038, 0.041050158756514715, 0.025281453084561135, 0.023219550418997967, 0.07019848277371737, 0.025460859385108756, 0.04711321224608729, 0.03311506600209302, 0.029121803968483885, 0.024488716791834564, 0.07734918576334754, 0.04357773945817063, 0.016282076511772412, 0.0347666941102474, 0.03763873475573717, 0.02110192634826226, 0.0080787189184658, 0.02949724450797564, 0.02864986124839033, 0.04552518092696706, 0.02322611196206943, 0.05107836842897439, 0.013680132612916491, 0.04460558047397964, 0.07695704067666685, 0.04049101799365975, 0.014817311612498617, 0.015259160483706624, 0.012835776358241997, 0.005250081941936045, 0.06391236363279243, 0.05750886450010923, 0.039805488045056986, 0.054062671598888216, 0.09115343132326681, 0.04943447397841562, 0.07895064660378041, 0.08390908940665184, 0.036162475664769454, 0.02824427706429795, 0.05304062986866601, 0.027245928518353935, 0.09345583963177859, 0.08124758504451284, 0.027375554425581813, 0.008015474051071872, 0.07652791652588115, 0.005020556732967136, 0.0722466494827982, 0.025974848840926445, 0.025166783128835024, 0.01945233028832703, 0.016347232289732467, 0.07637664480435272, 0.03204612245392655, 0.023466113902207826, 0.027163746436276746, 0.08215359892816314, 0.01579286042420614, 0.009254155391376586, 0.04322559948289587, 0.07825958166992472, 0.01819203712887341, 0.06036322383630661, 0.03195924042243391, 0.03740297885791909, 0.03394915955141187, 0.03160470642239577, 0.0025534040891685554, 0.056430277820195884, 0.05373508091114702, 0.038531407218186126, 0.07847164246824481, 0.06676583430699765, 0.060326175824288404, 0.026574439046183423, 0.04073535790666938, 0.012459173280325149, 0.04067666024991101, 0.08023444142553114, 0.02305794608659081, 0.016784940455709736, 0.05399393052944253, 0.032215989044597076, 0.073220546417419, 0.0645197564435582, 0.034105797718849876, 0.01806119888750536, 0.005544750001131287, 0.0317167314595633, 0.03399559597094213, 0.027072061033498858, 0.032691450023482886, 0.03076268386306061, 0.058175993016770775, 0.013673566281795503, 0.054759141283049706, 0.0446213235808236, 0.06732237420134968, 0.023964699245088046, 0.0415157716751339, 0.039790714039437236, 0.05019175189156687, 0.007941713190502337, 0.02940701084181426, 0.03345057037809203, 0.02724351534139245, 0.009133019653569547, 0.05564191971995658, 0.07581288836175397, 0.03814688470635203, 0.001694412682310588, 0.0922154896562138, 0.03216410573992518, 0.03176500840533165, 0.015817066887393594, 0.013033510354768126, 0.024025122514895858, 0.04962820229270766, 0.0483569483302774, 0.05695309835456072, 0.06311609184429531, 0.03814399655487749, 0.05480217244175654, 0.10409008230893843, 0.04498942882844037, 0.055890247120612094, 0.03557374475583915, 0.02078312077379275, 0.048971285728076776, 0.031097109970306198, 0.023179867064520236, 0.07279567405461304, 0.016913526398580403, 0.022382149285066034, 0.06316437453572309, 0.028948748536828547, 0.043565815299629204, 0.06431538716799791, 0.04605128414808743, 0.03221612310998383, 0.10998672234915918, 0.009701181101732919, 0.05566112171377867, 0.03395915316838411, 0.025636398856858575, 0.015074110030376864, 0.036166987922643466, 0.03951464659504352, 0.01960648250045075, 0.06188907945949224, 0.02713573634654524, 0.05699716373196533, 0.031704205922001315, 0.0298520504692269, 0.024196138237452796, 0.02495388920989729, 0.11739937378273857, 0.01139666487072264, 0.07356372316397967, 0.048823212423632224, 0.039305033447641524, 0.02042806774918591, 0.009852950780412123, 0.024502611711561203, 0.03328334870598009, 0.03238874570196194, 0.08822283091684503, 0.026058289222419265, 0.059680176012578516, 0.07826904285578959, 0.047473438279402834, 0.051429807433798436, 0.0074269011477759534, 0.049986896150174646, 0.03251912237535561, 0.022976417094469074, 0.03910460952489127, 0.05406984984273872, 0.06653621477345306, 0.11491793838720168, 0.04405334982420168, 0.025308321703285463, 0.09179461627237259, 0.027986641695362427, 0.05864980690661938, 0.07320828134975127, 0.046255094179463004, 0.026778559343168334, 0.03270662622526288, 0.03728161137851496, 0.009494945444467088, 0.023101053854090073, 0.054862256717657855, 0.04412636949470447, 0.02698282711207867, 0.04952992087290172, 0.04084928284188913, 0.035188440834322286, 0.04302797944194848, 0.052698847402127526, 0.04459266040113665, 0.026408628891071966, 0.10063556969285974, 0.03258575670300953, 0.03155960874151319, 0.07702051872207273, 0.02535327765790205, 0.04909225867219991, 0.03765878710715521, 0.04194593770549663, 0.017714335342809077, 0.046703201989012386, 0.029049582944642154, 0.04763260836743059, 0.07140166216319607, 0.033821238189815514, 0.0630603934217605, 0.07957514615789538, 0.07287923126451432, 0.03636271572641788, 0.026364749289988994, 0.02374395867058587, 0.01968278102726946, 0.1135943299760261, 0.08382796835634979, 0.008581516787319655, 0.061946474766779336, 0.033927054084356756, 0.08045686739346675, 0.029295838077462492, 0.023505243758160262, 0.056954891000303536, 0.02797785849731055, 0.018758915379763614, 0.05403315423116569, 0.03211548980025034, 0.09770129972528066, 0.008085875137288484, 0.019194959219725385, 0.059589513337179545, 0.0253016165187282, 0.029803156822679505, 0.022168475871665344, 0.09643338590620026, 0.05645319917089036, 0.032869642074670524, 0.02052697161543033, 0.02499226063880469, 0.03959869027077671, 0.07847119813724872, 0.027482138323267142, 0.0538167956795904, 0.0743047983175324, 0.04874185388607364, 0.032229805440311475, 0.05713935731159103, 0.024890076001024535, 0.03546715511249439, 0.0036758387690379976, 0.06658880670945491, 0.03939490322203886, 0.009819644150294123, 0.051433538281989676, 0.045653565771757595, 0.06327301729470491, 0.04732272963249876, 0.026597143977039286, 0.03732298778730535, 0.052212393061528285, 0.026798858757941958, 0.04189600792503165, 0.004978392690029597, 0.02023541578842748, 0.00884095820853667, 0.028012326708243742, 0.04564844064354416, 0.1055614997242247, 0.08012862170055028, 0.14249330386519432, 0.1236505363316786, 0.14387768603140308, 0.17998386955549642, 0.06971983869950618, 0.15812229425195726, 0.16139640082274714, 0.07137159321216807, 0.13058129547824784, 0.21000777461355735, 0.12117527560481142, 0.10387897912052371, 0.05400599258381033, 0.10983644654193234, 0.16366337756476096, 0.16932577856125372, 0.2209966164082289, 0.18202498825567384, 0.22624911439995612, 0.09479961913800049, 0.15465211513782703, 0.1603500779357649, 0.22013714236597862, 0.11492817332187008, 0.1309157541442302, 0.10887898219328736, 0.1294611523588819, 0.0896694424051431, 0.0876914723325641, 0.14019235878461792, 0.14751805923879147, 0.1806860657468919, 0.15418854001308643, 0.07899501841635474, 0.16184794836707656, 0.12662522509814272, 0.1262675080027792, 0.10911271561898532, 0.19466641959884476, 0.07991007979839079, 0.15794537390672392, 0.14525387105682205, 0.11413360224856485, 0.15347644596570922, 0.14573376385434983, 0.16790941988508548, 0.16346276978090887, 0.2891874355414222, 0.13071255698319406, 0.10091097830163856, 0.30937005255010824, 0.1278494489229014, 0.11190241713437343, 0.08110685469282251, 0.18533508563714643, 0.13887188367305264, 0.10161601667923313, 0.1330999014598708, 0.11475073969772748, 0.13031598390831103, 0.08748743247481124, 0.12500980613572946, 0.11789684063724934, 0.20985509329024823, 0.1972569305930407, 0.19488158305325817, 0.12035555386495207, 0.1281920204600019, 0.17999120867781102, 0.17760732691855202, 0.11035804516605793, 0.1358685891834959, 0.15019254879124705, 0.24677336065759584, 0.0963766034692526, 0.1081427870198123, 0.10739777417432879, 0.2362200858131532, 0.10865985040342617, 0.16464505795269244, 0.1824309076032331, 0.16605875064288417, 0.17254244385948106, 0.11224244525956531, 0.12336618747682342, 0.1619875755521559, 0.07969608845850153, 0.1687470297779768, 0.09033387046187155, 0.17278699444666987, 0.15875327490991162, 0.08669260093161175, 0.10652131596279722, 0.19465122041442703, 0.12835341986388932, 0.14500939707842567, 0.14981764068286266, 0.14840947914748423, 0.12832906592877644, 0.10053612381940889, 0.12342730597142251, 0.1774673473330275, 0.16568220310634182, 0.2507768135758177, 0.1765782869751415, 0.14225341109258516, 0.14033685828889572, 0.1746533838130774, 0.15983071628837817, 0.14703320219151436, 0.1350285278092469, 0.190099616264624, 0.1487267927657212, 0.1603559002039894, 0.10902122173818851, 0.18176761335663258, 0.18209405874292697, 0.11928946590952336, 0.143003135378803, 0.2221061415489643, 0.20500119084552412, 0.26858184606798235, 0.2182924639313452, 0.09396470587460265, 0.2429511794640172, 0.07332087329198277, 0.1902798767532072, 0.14561998447583568, 0.07096069429310099, 0.08635671734209023, 0.15515258505700097, 0.06046848814754237, 0.1559894135402095, 0.13198159695152314, 0.23460382415402323, 0.08763753208181552, 0.17019983891758228, 0.22808878261956478, 0.07756110100496201, 0.10307650968071916, 0.10368645356427278, 0.193815985394101, 0.10748443404032339, 0.14358065842140105, 0.19871635873231197, 0.09832763789041389, 0.16185337226958046, 0.11472326012388354, 0.11903088825244097, 0.12280481356766917, 0.18169128035585727, 0.14979594507284705, 0.20023817707213665, 0.135654988548448, 0.15573404579152986, 0.20971713617684382, 0.11356845918682315, 0.24668480089354902, 0.15281603220970402, 0.08678224087963182, 0.19964000029909998, 0.07528536021709442, 0.12678470162134017, 0.14693149635868688, 0.21763322995074336, 0.1353359129279852, 0.17850792456057765, 0.10771952344164734, 0.16231535393143856, 0.1511036418378353, 0.1398197489400064, 0.15710623183798406, 0.13486778724097437, 0.16919083983427094], [0.019994303020798875, 0.01564481584805875, 0.017798233461836656, 0.025405293112740885, 0.033016719464813514, 0.06605749409044943, 0.012209935192649644, 0.04749070973165574, 0.047565625469771125, 0.040783349484685934, 0.014596548055358713, 0.02991348689031457, 0.04205239328345464, 0.03339572231315317, 0.019724094233806097, 0.0292886272748752, 0.06657259628897713, 0.015911238245485772, 0.02096771540480756, 0.08307751628660387, 0.0037611742605335053, 0.023898919105469704, 0.03197133120509886, 0.09017159005687123, 0.05403802271992449, 0.049047971129297256, 0.06351893151839895, 0.02919535415487424, 0.015055312147934832, 0.02280313375165626, 0.025675275903795997, 0.03983074979436013, 0.07223331955291572, 0.07102994864145595, 0.05442993414978828, 0.017924316212414734, 0.05070704561207564, 0.014918940836533666, 0.046964357531959974, 0.027947963831285318, 0.011548901863035657, 0.05455260780910331, 0.05573259771711404, 0.02661378532197447, 0.13226852752268314, 0.012522947227191782, 0.039174675926445954, 0.012126718891874678, 0.02870855698992889, 0.038732807903039845, 0.027824591116739378, 0.04219204345117173, 0.030010274438668164, 0.033213680670146024, 0.019137226833751606, 0.06274662679061294, 0.0614351263990806, 0.059253530156227856, 0.04781341277844003, 0.05362679438304998, 0.05177478065654155, 0.027325934910726164, 0.008995862144436087, 0.016045588042376744, 0.04716386981008034, 0.07156184348728388, 0.04591307422566799, 0.023480075854627837, 0.07880965578219584, 0.0432646393235172, 0.05754515791552202, 0.034832554689097794, 0.02137258138147093, 0.0070826413444123205, 0.020733365278330543, 0.042896920950302196, 0.010402523105092829, 0.08067490367759621, 0.04009500033252182, 0.0594920018357375, 0.02430176644045259, 0.03852995931200924, 0.020035650701292103, 0.04611161357212452, 0.03356347641637249, 0.05704523191877431, 0.04487837672293667, 0.08101378267090167, 0.07141523724121433, 0.045112060352919564, 0.08686582107217082, 0.0692960695033112, 0.019354903056556662, 0.013453820663984987, 0.06624535417124149, 0.02123950807858379, 0.030854514822544112, 0.01473007526534099, 0.031008634475931048, 0.03476796581620171, 0.050895304058588324, 0.11031012636639419, 0.12905701033530698, 0.056864266629300775, 0.012907775216585687, 0.026585420916577982, 0.05443264993147985, 0.04735751385470072, 0.05569543096146757, 0.015268093068903733, 0.007348398681760075, 0.022359453930309223, 0.06135382531811634, 0.06404490833501182, 0.07802109849909622, 0.04176642798307923, 0.011690538113696441, 0.06545255276104135, 0.03384522057228512, 0.01021048209945401, 0.06072605839900433, 0.05543020749164205, 0.03601771186015779, 0.030379226213441263, 0.010204633975762033, 0.06996809715224851, 0.027852764000154795, 0.04366433420669168, 0.05345465442646415, 0.038995093425675746, 0.043773563022935585, 0.046802241835863366, 0.025552935492728027, 0.06541970291084821, 0.018320205553825346, 0.0357855489147046, 0.05047001417786364, 0.016091680679950985, 0.02882160666969515, 0.03008094604968304, 0.036504633514390844, 0.07641125665677172, 0.011086332228695674, 0.02472844102510041, 0.04874805153738107, 0.08951522890598544, 0.0666673383825729, 0.036657406768250855, 0.019576030505460598, 0.0458035811090902, 0.02666906814181036, 0.0670511101282412, 0.029850953048275366, 0.03512418137923364, 0.03195787104026925, 0.052580310617603605, 0.04923174413101328, 0.0293821761865289, 0.03382992945731648, 0.028988870476642926, 0.01712056549055682, 0.025154514230727672, 0.01522959523548883, 0.05452594794933835, 0.031537321328576055, 0.05920284960959708, 0.028774448212296255, 0.013571809695643044, 0.04462613844342771, 0.04305975293860801, 0.019436738483848113, 0.07331377165692468, 0.02905937929397389, 0.01596467766625386, 0.058439270623268626, 0.033961792341283256, 0.02509985577255007, 0.05115172134772424, 0.039785991107384046, 0.021769529839436856, 0.02706471808074463, 0.04644514910215813, 0.0334998183403044, 0.04694217928655205, 0.04360632602906516, 0.07648816422349022, 0.02577309958606718, 0.029015741010587064, 0.06828155458694504, 0.053621129162849925, 0.02329729302155395, 0.0373754724709978, 0.07060631734108733, 0.015204650455064353, 0.03704181436689631, 0.03237286469929161, 0.026190523659029318, 0.033135788680444804, 0.020045856907663327, 0.044718723999516624, 0.08029248790755387, 0.0645174658406646, 0.0332609980907892, 0.05965519005492811, 0.06283663829127628, 0.12150685378019849, 0.024281919017554294, 0.05337375937209976, 0.08668504730467835, 0.043324294590180924, 0.027260704439193494, 0.04070768298040475, 0.02464322906528269, 0.07611702526769332, 0.09654911114804207, 0.05562723764488774, 0.02292615215053722, 0.040280025887994036, 0.044596889206478675, 0.04285282875982024, 0.08093085365309831, 0.05350633854827574, 0.09091602833641153, 0.03407757120927976, 0.05374289500797468, 0.04598163909489109, 0.023339839629648675, 0.03359542228281498, 0.00929514779859493, 0.020040862014397018, 0.015553058624537963, 0.023050442255372484, 0.040674787164936145, 0.03763459788094606, 0.07684133841746277, 0.05719913898276226, 0.022659260524256576, 0.07352770937065925, 0.015551497720392242, 0.016034942293058962, 0.04113956121727824, 0.01801356928603303, 0.05331935563815698, 0.1289921226881204, 0.051304490771144635, 0.09863944333647529, 0.06625509880963834, 0.009556488160254254, 0.046250195047187234, 0.01836200714141371, 0.011908363723646731, 0.026205627082456506, 0.05820409312183338, 0.0208351036698948, 0.03236057664898615, 0.02375169232818148, 0.017946708962441455, 0.07403614660424572, 0.08188634915577789, 0.04022976668972162, 0.13466252164254267, 0.08480748071545556, 0.034492277585330515, 0.032889690595648946, 0.03378530100528752, 0.013791756411533684, 0.10568066470084653, 0.0764984144799171, 0.030143977848873026, 0.0408554881540758, 0.023881463792114973, 0.019269748553333264, 0.015537379677557658, 0.030357055628912586, 0.03147058932471179, 0.03486440096411013, 0.041585788280973514, 0.07257647331683867, 0.15094578176015808, 0.07354174410143206, 0.021051799300156777, 0.046561759175552477, 0.11503777752119689, 0.06493963391309784, 0.027254162048320138, 0.014228710938515443, 0.031240466088356993, 0.04887087075340171, 0.12687074861699535, 0.030551523218051563, 0.02126654906709108, 0.08003472996455047, 0.024171719184866356, 0.027527875687566497, 0.06357488274994878, 0.0314982412683387, 0.055067901529612086, 0.023622489684531768, 0.017130905762314796, 0.07514295213284992, 0.038918159045879884, 0.009036454270713994, 0.05473939536680138, 0.015322014167454216, 0.05716232079712134, 0.026869438438405915, 0.01618180134814353, 0.008206128916372697, 0.025481327339225722, 0.05284496718236516, 0.025304535313719706, 0.02965924720610342, 0.052123611131983424, 0.029865422533945214, 0.021134245682567842, 0.04615085259560616, 0.0010342495806980878, 0.026910835914614222, 0.034079597511839484, 0.023543327904096054, 0.05117347441433419, 0.025187411961416085, 0.07663986495425625, 0.009730074107797157, 0.01507854759467826, 0.042721253158825065, 0.020219293468060996, 0.07472944085396106, 0.021231498629335436, 0.019383181277061665, 0.04664376505740708, 0.03268922070762323, 0.02058854210190475, 0.030697223565150655, 0.011940304802039699, 0.040868316296367876, 0.049030420054951986, 0.03367396927769146, 0.054933345846591465, 0.08719862498823674, 0.05118067947126204, 0.007751842607713996, 0.026065036541812366, 0.02815149041012891, 0.05414417952359204, 0.007527978788505519, 0.052795700067954685, 0.03832444856544176, 0.05994868216915958, 0.022878620225275238, 0.022667909656921705, 0.03277683052264395, 0.1376749785436738, 0.19217445815522827, 0.1380191205610191, 0.1661173716908501, 0.10331720684564884, 0.16003890834268064, 0.0968152117885409, 0.12447534489535517, 0.17065566123252915, 0.18720403373722108, 0.1917858983600332, 0.1247551202053024, 0.09044927394678516, 0.1469746883958578, 0.1290222759088201, 0.13925440669540437, 0.26545158016585535, 0.18017350696027282, 0.14358182287504598, 0.1605981372056469, 0.08859045352906951, 0.0982953166408885, 0.18422425814693977, 0.28359677101815906, 0.18048354274322911, 0.1332536553062739, 0.16535611012049262, 0.18115823637814293, 0.1303131187394742, 0.17596008466376414, 0.14909574071005469, 0.15337279426955408, 0.1951322010568073, 0.2274699521160895, 0.1278094667941332, 0.17920690318269117, 0.08462191889843634, 0.16098853561186022, 0.2010643416114392, 0.11715292329749755, 0.14609927972478254, 0.14168855914425466, 0.20665617058834723, 0.1219634498439489, 0.2515822630976477, 0.17417396599006268, 0.2146560437376461, 0.12049813048853991, 0.18629726142652575, 0.14250330897348543, 0.14565455036297922, 0.11576874797502834, 0.12442158850570842, 0.1187582298993103, 0.10584175766956423, 0.19993768674471687, 0.17386708648935442, 0.11583629394731215, 0.22481162701883625, 0.25095074617814633, 0.08254252644556184, 0.15612810609802125, 0.06514939644764509, 0.06367408730570348, 0.14861912676884284, 0.09703534715358289, 0.12364712724041556, 0.37119935416886884, 0.20641777934806965, 0.1667474023997784, 0.1726337615400553, 0.1417303722231619, 0.1874556016897963, 0.08848298671505145, 0.11805943513829863, 0.14420163397106434, 0.18444211823084664, 0.15012344766047694, 0.12193256117884191, 0.14018601557660487, 0.06952712162127418, 0.16915167741958173, 0.14801244641984665, 0.10760805764866453, 0.16353901085113326, 0.16886620241547787, 0.08059263349540773, 0.23650453425943854, 0.20560774862045245, 0.108280721150579, 0.2534999497114651, 0.16487693744561366, 0.15220933653894933, 0.08766514955148583, 0.15645347896122164, 0.14324327329954795, 0.06860480538659519, 0.14155594932456173, 0.09678256112120806, 0.15929767231066383, 0.20577982729000432, 0.1920562507885118, 0.31708170810053427, 0.16744921554721173, 0.1425932017305205, 0.15694071088106404, 0.20169535291291055, 0.09007392916828395, 0.14308322221040726, 0.14659305403549827, 0.10562800381693149, 0.11180245798201331, 0.19525331955763603, 0.07936268699385467, 0.15309479628359118, 0.21572597745445468, 0.11070316777594628, 0.12558042672612976, 0.16538972605861005, 0.06930789023998284, 0.18746415123103127, 0.08403997552851517, 0.11948044396816723, 0.17475842978925477, 0.18137595856622343, 0.18819150574986013, 0.08730650548973391, 0.11752322721745699, 0.12936992660885857, 0.21530724911680146, 0.15422744195788138, 0.09027125809582011, 0.15216594531891808, 0.08792391106967004, 0.15102304938820102, 0.10492204613382779, 0.204244832237882, 0.12367276820324122, 0.08941445003954634, 0.0831174141457004, 0.05934922985972897, 0.09482645519798803, 0.1403449481773761, 0.13889969266470403, 0.09057297416391874, 0.1668498896422886, 0.13209981963999812, 0.1534934071523528, 0.09942296742191238, 0.12460655277414669, 0.10939449041841492, 0.18171279210477106, 0.1374327721855333, 0.13759915116092852, 0.21290229993962476, 0.1265243543011527, 0.307554975752869, 0.1605171923555674, 0.11834124824212444, 0.14856871818342518, 0.1543395512647206, 0.10462943885114886, 0.2203020810960762, 0.1468984932909089, 0.17907604004346556, 0.24089803318342856, 0.1095362320061653, 0.14276425384225386, 0.21895393488868592, 0.1220245147123933, 0.14792502046592776, 0.2742881592242949, 0.18205576966847145, 0.09610815859970548, 0.1236088534877185, 0.14144325779090006], [0.07938787596480501, 0.008228787881953102, 0.013096525874589721, 0.021502756956784476, 0.009146648357742497, 0.06335613017361011, 0.004211882938585815, 0.005151432799926449, 0.059185195113382036, 0.05121925965912881, 0.05343086356597562, 0.032965211543224515, 0.06595682247631973, 0.04795939083241167, 0.023873687999683525, 0.06607401860697616, 0.049301833515205694, 0.012500536282576863, 0.037311439011846824, 0.02125411737529982, 0.044826068239466804, 0.03876205713998887, 0.08209052690935713, 0.01972134397815793, 0.10302850661138374, 0.016763212286957332, 0.07850135901882764, 0.04998965789714167, 0.042935474325091615, 0.09563407274864374, 0.015345592438543757, 0.05854853008302951, 0.023535132678526065, 0.03244747783267691, 0.00990579552542899, 0.05635271907874173, 0.06537277236460678, 0.053982393245302865, 0.026557083324258848, 0.008617024962610055, 0.03138584850896751, 0.009761055661064964, 0.04855255355998393, 0.006215472427767612, 0.0009689968447351168, 0.0347812804243257, 0.027986360158050255, 0.010466312373717947, 0.027116415609094887, 0.06959115891086479, 0.0368198327299568, 0.0008687792574017941, 0.12189771950004563, 0.049964963052902496, 0.010910313951993182, 0.05464149316051795, 0.06098870015252502, 0.0906771467998624, 0.03675233272294845, 0.08234175012236641, 0.11001129078889087, 0.04038998248776601, 0.08362154596515241, 0.07509619012595185, 0.003402565630348099, 0.025474394243510983, 0.06981004555259021, 0.09328457301542645, 0.013052790872602454, 0.01571124524719292, 0.035542507520726616, 0.0245022535654566, 0.05118329183108384, 0.039923795003203616, 0.044727101170968626, 0.036698346506924405, 0.024400534326090448, 0.03281287112904172, 0.0465416110631439, 0.041056494303648515, 0.034373874866193345, 0.02584714964482813, 0.03748200465774825, 0.07324434110834714, 0.1296230880243163, 0.0373154264994927, 0.012008780613541605, 0.03244895638237077, 0.04487177304502937, 0.04191351686454108, 0.021466287341149106, 0.021762772943944703, 0.01762901421546215, 0.03854788193899778, 0.025262392817005038, 0.07812933140103856, 0.06962481315337843, 0.03513999726443041, 0.0009219361832478054, 0.009951808681381086, 0.03329455657231231, 0.03497764791151689, 0.09419783409084044, 0.04456489737476072, 0.04871920449659229, 0.06670422551612701, 0.03839433110589462, 0.03160535951235122, 0.025300411845467267, 0.02486055863330201, 0.017236790604769223, 0.013187190465208505, 0.03705741574747428, 0.017151896571440083, 0.10201829710915204, 0.04220374544421512, 0.041683916483194604, 0.03311946717721801, 0.0105786629982533, 0.010701898774582773, 0.046604874603930986, 0.019522559483565634, 0.029813148524431936, 0.021515039261430505, 0.03976086725390727, 0.05748264131046111, 0.029940083547825777, 0.029561032818990852, 0.08415085143379628, 0.0659812989855005, 0.03326252643619815, 0.06838889882689522, 0.038725993550953366, 0.0109681612511556, 0.030374675651171038, 0.04169954850728955, 0.05334842101400418, 0.02525246240228655, 0.05046924425949974, 0.02637536535339971, 0.07911257460833558, 0.01283048460590503, 0.07501464772729144, 0.056372419029714606, 0.041490977239464565, 0.06042950193307573, 0.009360069919738078, 0.0346819686162616, 0.03628336816966053, 0.04297145364445545, 0.03200896335915933, 0.07222391199320555, 0.06684223625568614, 0.036174441958146716, 0.05606830893685261, 0.007328524924589382, 0.02617453348882977, 0.023176521175510945, 0.0766434885501381, 0.0588904389540755, 0.02235138510924674, 0.021400920889009873, 0.06383262920163332, 0.038624850792750236, 0.01312994167223693, 0.028008618842690226, 0.034527682338751135, 0.07488802105428712, 0.02238351292157125, 0.008971115589262018, 0.008405957205761826, 0.035478317013551156, 0.0028427641166584388, 0.07693343750771976, 0.10399798321868144, 0.05860101093628234, 0.09351501226305, 0.018844110102603034, 0.03453517084821098, 0.002371246814765337, 0.08795617869304073, 0.07428406031742212, 0.058116908485610644, 0.007744309090588603, 0.075481723873846, 0.08299116285577898, 0.03935027477000991, 0.03255016808848708, 0.06468025186369497, 0.06752177922716064, 0.015072054041910077, 0.008603277514808843, 0.016666566464869727, 0.027254209928815405, 0.008932530613345726, 0.05405299973884418, 0.043599837264346505, 0.025925058871507648, 0.05276752718453927, 0.009799059367768708, 0.07654369793712132, 0.017357298150478352, 0.03470901535042832, 0.020278404812298475, 0.05435260523471141, 0.03858409874561814, 0.013110141172223996, 0.05333478847939161, 0.020842324048581145, 0.10276549330521977, 0.027912802310780655, 0.002688732084577843, 0.09118841855876869, 0.02966094217563589, 0.009322941468487824, 0.030757007151541692, 0.06797020113275898, 0.01881627046743468, 0.03314306651572547, 0.04126179054559719, 0.02460792581851204, 0.033153243993799535, 0.021557978489586425, 0.033291032567860625, 0.03949857790083174, 0.05846408804157569, 0.05897544407015366, 0.10603250590183082, 0.11000681683541307, 0.03309718934037993, 0.03822917404073862, 0.014937246507484347, 0.012943990107986235, 0.024320897571141684, 0.06942791323507987, 0.07180155239879124, 0.07575138682319273, 0.05957761599171547, 0.0341390191216863, 0.025069526351627805, 0.01592576327253013, 0.029618158080284635, 0.052705837954436584, 0.02505020178373783, 0.013396384179471962, 0.03266896917334488, 0.019844071263627663, 0.11572038484436852, 0.007611269304048151, 0.0493024617073036, 0.03506562927918088, 0.03866498230866367, 0.019473723293612563, 0.014598619365583987, 0.01260428278211264, 0.048706334219464374, 0.04817027185532836, 0.03654091926892439, 0.011619586880589205, 0.07632129495182345, 0.01017667942740504, 0.027743805229904193, 0.036597571470924926, 0.013241548233875826, 0.016790151768814654, 0.05133941288917296, 0.04041175853701369, 0.008932933767115878, 0.027230388424809904, 0.038536291028703415, 0.0408884720696557, 0.017833827822018537, 0.027124057336139585, 0.04036297022755589, 0.01227759129007257, 0.03783303763597243, 0.042481222490389506, 0.02170691364294579, 0.03282188415347088, 0.027724555355586836, 0.01784861140373734, 0.0539546225580477, 0.047546764385075345, 0.0317367225239474, 0.027152986731380228, 0.016377446797466087, 0.01003719013815205, 0.029840850263773918, 0.044594476029517195, 0.0568976680627994, 0.09067307121210522, 0.02694420095893645, 0.032741368312629006, 0.09686005857562828, 0.03594971389599866, 0.0300458783749491, 0.03759135604806004, 0.03384944554718752, 0.08606764172474224, 0.02481852721933636, 0.04868790980488543, 0.025170423961695165, 0.05982056928558215, 0.012065834054092487, 0.02295624791464258, 0.06390444994453462, 0.02850499210668908, 0.035226614995589184, 0.05258719391760327, 0.052460318266023556, 0.06245704555523492, 0.0044074354997475544, 0.059546064660553975, 0.09736432063002741, 0.10491057013672207, 0.06473109711922946, 0.06435002200305462, 0.06137381638250044, 0.04535995108345824, 0.025703008286654953, 0.11972033674077642, 0.08402453119596166, 0.07702125416648004, 0.06282997715677466, 0.06330591694061315, 0.06715827816796881, 0.018658647877013972, 0.04733571099237569, 0.03874369784288349, 0.03995539229964057, 0.030520632637724764, 0.02631535960151063, 0.04456218159306915, 0.03339468426401577, 0.1379179509897386, 0.08022392303833077, 0.03391594197901507, 0.06333725759759545, 0.022490677130859227, 0.025293005690459284, 0.023316860822359883, 0.019228096352890134, 0.06243258053737302, 0.045962448592387864, 0.037940094592951, 0.03389945576688455, 0.017008260831296924, 0.026153207516237616, 0.009764135334520571, 0.06647867390946036, 0.03167880627687179, 0.0869992965712182, 0.304832544418112, 0.13654697536220475, 0.117420747635826, 0.11545370197704724, 0.19757560784778289, 0.14190208317051012, 0.09692802589627043, 0.10995064726880482, 0.2054669110164527, 0.20337952060564873, 0.1510304344757911, 0.11426892401950975, 0.13407404354262736, 0.15305785552388237, 0.10800004185688113, 0.20175158376655272, 0.17783578965933095, 0.14386003536562766, 0.12683586097292363, 0.1417418788637846, 0.16448525201168754, 0.13781517263381712, 0.16652534415404643, 0.13228309851500297, 0.2047305626253928, 0.12352092957664883, 0.18527559124894682, 0.10863675285250911, 0.13605113261409346, 0.17238245405737432, 0.05626428188876279, 0.1555382950051177, 0.07079685106873512, 0.2043195717757748, 0.12277530386082589, 0.1736917289634866, 0.23760926368976795, 0.08874118132817169, 0.12800670379111845, 0.08503359156630694, 0.10183272763125359, 0.079792209510361, 0.11480801243094668, 0.16016701356537882, 0.1232111389418283, 0.12247950965238195, 0.1118642736166235, 0.23345663813093018, 0.1283066885005082, 0.2001887184357451, 0.15941807068884373, 0.16693022162202867, 0.2372475322936812, 0.14332179731178668, 0.11013497568426595, 0.10155602433388272, 0.08159609376302651, 0.1640557831213359, 0.11178134459882014, 0.28001037636591547, 0.16686150353522072, 0.11529199613799011, 0.24096695045309685, 0.11248987633734943, 0.13694357908060475, 0.10625332308512543, 0.12927704610891882, 0.271844522606942, 0.11578938638370846, 0.09892630495972211, 0.3132171928882599, 0.18003113718042452, 0.12477611101442769, 0.11560601557815268, 0.10518252368896239, 0.09826022981395645, 0.11413182492458052, 0.17782203072021086, 0.08116300127679303, 0.10827058580734077, 0.13238820577821425, 0.11841895254028421, 0.08203605039706154, 0.259943132198626, 0.23868528014469534, 0.1801605294308355, 0.13079261317128135, 0.12473253593329461, 0.06791476701055804, 0.09265442739330954, 0.1776846251901119, 0.102354257307466, 0.12415259205285581, 0.15880297869443893, 0.10730621134561878, 0.1491276865764972, 0.14544179242464805, 0.14707308472885242, 0.11169730475352657, 0.10576510291186073, 0.1289378376978059, 0.09021358699688027, 0.13231623947860735, 0.09640498702684719, 0.15685328492714515, 0.1176337966875684, 0.10315396883074315, 0.14673744628746666, 0.06650146502520769, 0.12717384364335768, 0.17752690300826104, 0.12326868746670024, 0.13656815003243186, 0.19257806391725618, 0.20587028695210335, 0.12051430260462147, 0.07296006886228439, 0.14452872287121513, 0.08401724569980176, 0.15441553186505072, 0.12861968138285224, 0.12214494373409018, 0.1609940054796396, 0.12283944074184665, 0.11665049219323743, 0.09188575009184499, 0.24784796751074253, 0.117794728777822, 0.13915852313080143, 0.2887138706301489, 0.14530964225770968, 0.2707811925680407, 0.1731043540301823, 0.15619679354131222, 0.14770671605102478, 0.13373996792060713, 0.11079249362791739, 0.2011663385576779, 0.1892360359910996, 0.16552601310033954, 0.22532821542793707, 0.14943778364648744, 0.19895404517169923, 0.17171467053553752, 0.19022908512382738, 0.19500680778536106, 0.20839762633606312, 0.10115460958331825, 0.19554549017019812, 0.12105467038289194, 0.07133931792791813, 0.1528803682735851, 0.1884161993380516, 0.11576502478771633, 0.22308031427523783, 0.07136998442752708, 0.20001231903030028, 0.15452662993582988, 0.1997271657831246, 0.18672870682372203, 0.0980564963913733, 0.14743645555309712, 0.1102462882596639, 0.1272975515213705, 0.10183503355590567, 0.11068774642603052, 0.13383906905449208, 0.20069059795669972, 0.25584131359092654, 0.17352881270550913, 0.10215770978961261, 0.16622575781037732, 0.16964045683703116, 0.19152849281747497, 0.25946395952374707, 0.11273039730205653], [0.006810295172110801, 0.04053899808035743, 0.04974920971078738, 0.0290439713505968, 0.006595383569102495, 0.011838865184765911, 0.0391335561571102, 0.01646409134170221, 0.03941354980211585, 0.007814793967671933, 0.04505610529093012, 0.05215452661016776, 0.07242360813242775, 0.010384167638427068, 0.04994109558362154, 0.038992362322225686, 0.027123927101192456, 0.004670542172877299, 0.05379081380763843, 0.06625303037224278, 0.03864381146887618, 0.06303607013016459, 0.04613891694574587, 0.012055986951435766, 0.049467929038068945, 0.050939626075447574, 0.03697319587151851, 0.046981295735965815, 0.07997189543300098, 0.02242463843656644, 0.010650588120634278, 0.09126780058948264, 0.008649103936829395, 0.025209504021932522, 0.0323845858445331, 0.09307185338149149, 0.026199211096090656, 0.05959314842438025, 0.08318208728826816, 0.06175564609528069, 0.016240872472764987, 0.01836364848479148, 0.05246576132072557, 0.038719780577887455, 0.08612431690938051, 0.037743524092459874, 0.03973210448279016, 0.08603174284461045, 0.045962988684374484, 0.023245315871111328, 0.05943456822405419, 0.04857989140756188, 0.035090167075395584, 0.07531889188554018, 0.03263152279560605, 0.013447330941656425, 0.007427728043929224, 0.04827214239705955, 0.03452740271665877, 0.12061561773260757, 0.07569161664334036, 0.011967898331462376, 0.034875808013302666, 0.05908151660414954, 0.017511670612880302, 0.025080500561143124, 0.021909957586397088, 0.0212448611179547, 0.05532225804223169, 0.003977942669148287, 0.026247982168570164, 0.023475915997198993, 0.06746711119288398, 0.009118598048394967, 0.015913857308576907, 0.07867358324508514, 0.045948333422383, 0.03652180154477397, 0.04364393328526809, 0.021911976228077567, 0.0189824674969479, 0.016435108320306868, 0.083296173101952, 0.06905444537199314, 0.07212662648770117, 0.03593128182054047, 0.028442280149207484, 0.04507380575242062, 0.11026231481903985, 0.013708905917742561, 0.101462829737894, 0.0650696849991237, 0.07971348631526194, 0.039335638660216526, 0.05052280146628619, 0.05179629240545535, 0.05934309732589511, 0.007122259581416485, 0.06696411318355991, 0.0743317339689501, 0.02748884542304422, 0.07058207065828385, 0.02337811912800516, 0.016888733878130877, 0.024564607376833598, 0.00614653361187647, 0.02012740122154355, 0.06099074943772247, 0.01407630444924918, 0.06328647362909491, 0.04096186329280177, 0.021335041157961376, 0.0348930488220386, 0.08273870624121159, 0.027290457378952738, 0.0010923288608600777, 0.020171129520261483, 0.04956302353210988, 0.06448575746147864, 0.017463546884696812, 0.006865434829265841, 0.040983191180613734, 0.010584139569302, 0.019817637399800365, 0.03570636223641134, 0.07169298241816222, 0.012766031713615502, 0.11725871237896143, 0.1083555679407812, 0.010655036218644632, 0.044950350683422825, 0.0474393550276516, 0.03263913770957339, 0.049207183352160844, 0.022559042817222017, 0.10721522308285199, 0.05811556017086391, 0.005486037022614431, 0.017234779623967987, 0.026088835063180136, 0.03659694327882702, 0.02063028048723936, 0.02721191229929607, 0.0560197351320136, 0.03082599336912315, 0.012613492116572396, 0.03799802233134547, 0.023848751837748195, 0.03609535487128362, 0.03525391836921054, 0.04353496110847881, 0.032259770969469706, 0.040514004461827784, 0.039962509256457134, 0.07185291093323501, 0.031018765988729657, 0.04386619071386034, 0.04618747925926601, 0.06975747659922608, 0.1136684796262172, 0.008830517387738632, 0.033709228474406466, 0.03475653578437144, 0.06591196036747386, 0.038390044843958276, 0.04429236542613757, 0.0697147059104135, 0.09073643434432246, 0.04540687396882042, 0.036277446310005845, 0.04806863497041407, 0.02201771359860657, 0.038452519314183344, 0.011619231607314321, 0.024901601793845336, 0.01582215754165044, 0.07007940972764647, 0.021022571130625663, 0.03289957312987216, 0.05902302962157035, 0.042913357366717635, 0.04093317713047709, 0.04926106614631511, 0.10485593274596239, 0.06668385523822039, 0.007834907606123917, 0.02808598989260293, 0.06202769923895117, 0.05977168521513382, 0.03587454917930788, 0.04364558420474491, 0.047123677007132964, 0.06435911546671583, 0.026249960590634617, 0.03212940578739489, 0.03446027809273332, 0.002409567250945275, 0.03292713314294815, 0.04854940876905476, 0.020498273961786783, 0.04068661556248704, 0.024897692830211697, 0.04166413226255006, 0.023728711605672876, 0.024242837042097124, 0.05150851913757863, 0.0710221728490245, 0.02009151000229101, 0.016057878007902014, 0.08389498572796585, 0.03566718066952402, 0.05436126202825577, 0.0618380465124163, 0.05260040127341786, 0.023309958370162115, 0.06920973139424479, 0.0506601648615493, 0.027364561063868385, 0.05721903811659544, 0.051132454236428586, 0.05679094435406789, 0.08381120635256653, 0.04501806519504997, 0.07116791341573962, 0.031598275114271435, 0.041933737755302465, 0.08495885202841413, 0.08298403057720392, 0.015797051882761863, 0.0431765315513457, 0.043733079106576984, 0.08657981746739919, 0.03968193338462903, 0.05910555644321346, 0.04638955410149309, 0.018174840370193124, 0.021144260366957997, 0.007565216407284982, 0.06094090392692916, 0.005371224861817374, 0.019572177083201466, 0.02842429431996519, 0.009669454527958747, 0.03201415552006614, 0.06062874991086222, 0.0210821574493762, 0.04065012679465356, 0.033622170242691235, 0.04459929855300054, 0.04357044630113148, 0.03374102112326411, 0.05193070636220998, 0.02204205412718077, 0.02214220480152196, 0.04012708409479068, 0.025747757397531986, 0.00971460775021584, 0.024235857981106928, 0.018134450299605247, 0.04471576306968928, 0.028118615662078225, 0.061723079697619525, 0.04514719697556669, 0.009672613683036499, 0.02696769687557413, 0.017048267857922662, 0.05241238797504095, 0.05256611883880631, 0.052964676081413226, 0.028979529949626135, 0.029713643279166955, 0.07366265575852125, 0.02105929547049586, 0.012300468590711395, 0.027352077661142237, 0.06482521868160655, 0.03168510543482919, 0.029186490517590317, 0.05764941482113735, 0.016808625979108677, 0.024144925259714647, 0.062224112691417824, 0.018422641085400697, 0.028764590575930574, 0.0171834344960629, 0.034856912454650286, 0.021812141565005147, 0.03608908061118376, 0.03547741686024013, 0.04806573149718104, 0.05757318907267144, 0.045131974808511235, 0.03876161280899279, 0.020808263779467633, 0.01294105024557681, 0.04249921406529123, 0.02194887868339016, 0.10609616014745929, 0.03842598202848627, 0.05570868811299724, 0.05616397416639713, 0.050488511370795394, 0.06643666930857205, 0.03197067811514341, 0.026769444812089208, 0.03179315447566971, 0.028007264782284057, 0.05003982899530281, 0.022409471810885498, 0.01874413371326462, 0.06470541019112834, 0.02872349761967217, 0.04232281082940679, 0.03565215002444964, 0.013151970530499615, 0.055908954987723025, 0.053980707851869446, 0.01278820421336399, 0.026613923217800838, 0.09712350855190909, 0.003991158882854506, 0.021856655103845463, 0.0331597174367597, 0.03767243879396589, 0.01924098003655672, 0.03772181699112539, 0.042853437799720034, 0.012913371488872557, 0.05060636250662708, 0.028495360466261065, 0.03534170438445384, 0.058016175584447, 0.023781770855308543, 0.08735118373747795, 0.06891166190466574, 0.03191900931509032, 0.0364075165482298, 0.0721195248526431, 0.025251138985397357, 0.04392008499933347, 0.03483014917301555, 0.04577404458916957, 0.0418836854007696, 0.042084764328695116, 0.04365860003857844, 0.06404445251269687, 0.0667959109189049, 0.059130638161854404, 0.012684991102545493, 0.01945945299080303, 0.01779559811937713, 0.04109209057905021, 0.11252481760757585, 0.11357065785916583, 0.11797013226896526, 0.17013950183266596, 0.10161944109225467, 0.07290219858048425, 0.13768343615435785, 0.1493601176527239, 0.12585711470174213, 0.0845152258332218, 0.21521249936232645, 0.120618881267165, 0.15099105755648307, 0.16885746901314105, 0.15566854527400387, 0.24168253786140875, 0.16836429225100627, 0.09052882451684245, 0.22419088129555026, 0.3016626870920581, 0.16366446540961344, 0.12986178569976362, 0.1618734437731966, 0.06407125026828821, 0.16791499700517426, 0.1198672494220157, 0.1623529841702792, 0.1229919688475709, 0.1533512825206403, 0.1721983784509282, 0.10941885201440704, 0.13959490213423006, 0.1356070008008711, 0.11959962426654755, 0.14688691004149376, 0.19365020396728672, 0.1725263100477957, 0.12831277889950624, 0.17886866004236285, 0.1400742280266939, 0.1653568455648999, 0.09971555172195358, 0.11042763659309958, 0.19257268598002775, 0.2194861055261666, 0.15836040970058213, 0.14122711374394356, 0.1958945504720173, 0.261280445922767, 0.13696740441504987, 0.15693510311745829, 0.16746708071760594, 0.08398932179496174, 0.1344909332692623, 0.08187238337291826, 0.2426787279546261, 0.1177342537970793, 0.12693375168788817, 0.07781476037757051, 0.14429060742259026, 0.10032557987517889, 0.13492150532622493, 0.13786697549925697, 0.1899804742706399, 0.10150045231585542, 0.13154785329055402, 0.12697227824960025, 0.17578648914012218, 0.2227136799164357, 0.09355083453438937, 0.1521148319326101, 0.1458285595741003, 0.18351008034040853, 0.22967913518509558, 0.10594940834468412, 0.21655486926676767, 0.11717199122593289, 0.10257631555319795, 0.09249863575302786, 0.10155730370071628, 0.06030465258405574, 0.10910477128721054, 0.20169982686638835, 0.23087821600417938, 0.10612401510438613, 0.17009273982576786, 0.1081509841606021, 0.1395548357357902, 0.1761323012291424, 0.11277012662180971, 0.1888771084768157, 0.12349388667292173, 0.1252250461989353, 0.12994769479959242, 0.10533697467537657, 0.187036965282694, 0.13389696997980918, 0.1328613110367329, 0.11726439675135959, 0.23403685780302172, 0.18420541238400245, 0.13330532027588737, 0.126703166883559, 0.07452897862681458, 0.13933495317976322, 0.13682155659602535, 0.09776814089667413, 0.19736228300438774, 0.08870274669701055, 0.10218964033429662, 0.1376821031613696, 0.13916532599156903, 0.125503228046, 0.1305955906789149, 0.1279444131819952, 0.17954186746670356, 0.11539082914110153, 0.11406401848240245, 0.10142931339120674, 0.18808531064179637, 0.16542119695053947, 0.17504422655028684, 0.11116648243079263, 0.16068177868521985, 0.256300276866363, 0.16283974111560853, 0.1357474093956332, 0.14479210389958275, 0.1607681627595617, 0.11570073468911073, 0.17709363432180497, 0.12127480574793394, 0.11377164868698006, 0.11576324746373201, 0.15460682401974357, 0.22467612138678952, 0.10403261805373816, 0.11777972111538534, 0.1543150517729021, 0.11269080587812971, 0.17256893517990268, 0.11303358425896977, 0.14115721588173222, 0.1478480899165715, 0.106044280673227, 0.13653071897645153, 0.24586096526153628, 0.10872460015478635, 0.09737723687243077, 0.11258409749115668, 0.1332409842120063, 0.0988889505125342, 0.09089344406440374, 0.15266603219412989, 0.13223958472090383, 0.1863211786915218, 0.11609484096087756, 0.21253494545817378, 0.20681185497631951, 0.36322486917338065, 0.18442144917864955, 0.13149822611481915, 0.12988892053404164, 0.1631553386968951, 0.10248491360295205, 0.16423880152644652, 0.20781757520331492, 0.20963821379888445, 0.25302584853864485, 0.17040738745802836, 0.22517331244964756, 0.14217415163593908, 0.10533073871967294, 0.11472204970496316, 0.1121086786471067, 0.144251506294935], [0.030232275227805784, 0.04473150234609362, 0.0665809466473518, 0.06234013287711048, 0.08025378514561923, 0.04155846958559367, 0.03329746004554533, 0.02451607379161062, 0.056140608484706575, 0.01783692856289206, 0.0065919318641986585, 0.053758082701073545, 0.023454501924495545, 0.05772487448167898, 0.03941245812682375, 0.006164511301434569, 0.02883890110458578, 0.030130555988439632, 0.10054855742641997, 0.04548524859391394, 0.053822924382984645, 0.10233894320985965, 0.0402238026952311, 0.02961633670624466, 0.09165705752468879, 0.06098609928402209, 0.07239804377839451, 0.051214789536090634, 0.02798415765526795, 0.03558983643268866, 0.047753569820234855, 0.04833637886951047, 0.032144076371144865, 0.051490653967184406, 0.028461072285990083, 0.059535979113030824, 0.01994087604895955, 0.022167414839890216, 0.08420001129589735, 0.01793888528951474, 0.014228224472683525, 0.03036982056895091, 0.09775423640084845, 0.024316481074258208, 0.05226418826608889, 0.05424431104573512, 0.03364843556717519, 0.014060521122789191, 0.0764292214185961, 0.03189577769878651, 0.023226303484050498, 0.06320365569404056, 0.058327636290942474, 0.04145410542766895, 0.01846946246411291, 0.012881104823111767, 0.11003466413146067, 0.05182384858809171, 0.009000246082582783, 0.04847885207122853, 0.013064489035206217, 0.033491368390499585, 0.031706824027482546, 0.02289157860251444, 0.030885223456988894, 0.07962849652094227, 0.08916869669431642, 0.006829844778328533, 0.016078138160669518, 0.034161388889075286, 0.02488486085748, 0.057473394629215045, 0.06521613036672916, 0.01051202579776967, 0.026984633164360162, 0.01271972552903237, 0.02245314839866854, 0.016605740998901667, 0.09774909595087652, 0.050410125254383015, 0.03196875523445347, 0.03171749946270739, 0.07387450971310178, 0.02337147331526203, 0.03768116836586306, 0.03956716575269257, 0.04804259181142815, 0.022625110239811966, 0.059091406799252, 0.015610136962946386, 0.023155467164131905, 0.06746045388882199, 0.10316011285589588, 0.037425992139164484, 0.0076235042070038625, 0.03511076717967949, 0.03422569047899977, 0.032177562074315165, 0.058257110236633214, 0.05122617743308506, 0.0702113913552415, 0.01894760283551389, 0.03025019019391508, 0.06331160514345092, 0.03636958370465906, 0.061616244906139, 0.022904552301512133, 0.027574147398193038, 0.022111145681851817, 0.015818537776208213, 0.04355315569668047, 0.020955130495431445, 0.027528952041100112, 0.05333246723298104, 0.02585025421614128, 0.04636217028863969, 0.037093923667505864, 0.03168027142002698, 0.019001041298672076, 0.04431969178239665, 0.003005269559986529, 0.07035125602757739, 0.09021019322737571, 0.02813365013759223, 0.031538192753589926, 0.07503618245884296, 0.003755572960794633, 0.03787232262472953, 0.023585474231250347, 0.05078593351607842, 0.06970829375448727, 0.04143431737658478, 0.05523951671596977, 0.018291239769408302, 0.030390656245271527, 0.08912639331913765, 0.014264055362512029, 0.04269810581219293, 0.05325945905379711, 0.03668846397270118, 0.006619850023379249, 0.0554649725616459, 0.03337143349551386, 0.008143324070730278, 0.05674587157104285, 0.04685796707147553, 0.053774863857054905, 0.010222237718652093, 0.025209921539851257, 0.03734805418418781, 0.05538289773187811, 0.02788555639375362, 0.03976247986898788, 0.03515751003437946, 0.02428382083082632, 0.013278811708122734, 0.027163033974507166, 0.009534630714164627, 0.05825557039990541, 0.024752607268671838, 0.016486976303220276, 0.021435494437032653, 0.031131179815518762, 0.011205290361577946, 0.026896552205266013, 0.034241544668592756, 0.06646662334641142, 0.10512115238534828, 0.020094687351956964, 0.03449875102829068, 0.04952139431430448, 0.0059823494783843, 0.042416457417270834, 0.06540376828202317, 0.019215442495600834, 0.029458467052468372, 0.013815481196938744, 0.06885030592281012, 0.038815304081165986, 0.016912551551696756, 0.03805273250045796, 0.08842210570770888, 0.01659173691164582, 0.023259559360843514, 0.02878803478163337, 0.05590345064598707, 0.026107439508421287, 0.04680424132534573, 0.04455060600453327, 0.03928472062632923, 0.03544345618255677, 0.053343629134037805, 0.03885415239980625, 0.0130832601045709, 0.03247670791742783, 0.023645979855510018, 0.0502352848378641, 0.10533915036508154, 0.07686028377183023, 0.022286336583596085, 0.047755661240268144, 0.042175626186954404, 0.02957359091528962, 0.012744809162893124, 0.033434926862678224, 0.019835221032882412, 0.05907223161850726, 0.040996842867424416, 0.03761008306736908, 0.05943004447486132, 0.07657187465097635, 0.03326669778494585, 0.03372540442092765, 0.021680311239775152, 0.054002074044077635, 0.05546830504411652, 0.07639293949450217, 0.04640520144734652, 0.041521521165005626, 0.030677477648902326, 0.07908190810872663, 0.011766524459686012, 0.026955690362580845, 0.03839408595775885, 0.1113318654918863, 0.060191286893020716, 0.014620639605357524, 0.018083993833692327, 0.051793090157931855, 0.04785779608233322, 0.08538291233802035, 0.061012253525757024, 0.10599620099509917, 0.08034101957755704, 0.02187954389580315, 0.03498471124217876, 0.02693084996163605, 0.07860949232933984, 0.021820576193051475, 0.0345395605320171, 0.0501265041830559, 0.04829220240935684, 0.07683254372809203, 0.11312697037693956, 0.023754216587891983, 0.06113964245624601, 0.02266773154147931, 0.0795323601473243, 0.013887232034316948, 0.02677759407238374, 0.07530864928999255, 0.026456610892989466, 0.02639546750053283, 0.009985159361554731, 0.016377211225429372, 0.04043012549499831, 0.042973181172724695, 0.04318878512769457, 0.0356477948146001, 0.033450585699850516, 0.048940458350003734, 0.08495502158879273, 0.0500330452867333, 0.03420607479769857, 0.06540105633077122, 0.06855699383924085, 0.0254050096602089, 0.025449176544263482, 0.07333369760383522, 0.06813367663492119, 0.015793068225555602, 0.058098775184442925, 0.04931137130986299, 0.06268306064509577, 0.05757425010444657, 0.05151959676896373, 0.022218260095424713, 0.019509972658969706, 0.0649813627223334, 0.0542773639092282, 0.04435479010064756, 0.08261889775073336, 0.02887812289108913, 0.05391627985743746, 0.0732927808477994, 0.014946416579937984, 0.017755573855773095, 0.03192255247174011, 0.049002040327797015, 0.073105824750758, 0.036471308689684644, 0.02263637939317813, 0.02374213155088646, 0.04342198995272479, 0.04448663383241623, 0.012604063489444315, 0.027480267153512088, 0.02722002708563401, 0.03616259440839772, 0.03439786873998181, 0.05654431766860428, 0.01943962855054246, 0.05897252144472254, 0.0357535494221074, 0.03213195494496294, 0.08659036649811654, 0.021525255043900782, 0.030695995909251997, 0.032696801147633986, 0.05818852238477238, 0.12022131993885964, 0.036005075239846786, 0.03993836599552343, 0.030898168427689426, 0.042548933171577034, 0.034303731855846224, 0.09601943795719454, 0.030024964174616243, 0.02632242676261212, 0.023892123905581333, 0.028089588590627237, 0.013352251769373975, 0.01071896338309612, 0.03915300329906806, 0.05106867741673224, 0.05013196638995602, 0.03177488519389543, 0.052966189105063684, 0.03662646064654954, 0.06545474377250479, 0.02781667742848156, 0.04267992271531013, 0.03884042027376352, 0.09116224133439603, 0.042934478410790046, 0.022946099164865674, 0.036695381746657436, 0.030264242161666195, 0.013921774938822755, 0.037276095545460144, 0.0308979137034546, 0.026736474303047986, 0.0937922748046056, 0.04219311597426573, 0.04421518972864555, 0.025253186355374997, 0.012384632925292658, 0.03911677500112884, 0.04833596518203136, 0.08292979155216487, 0.017460022880245122, 0.03904267897709243, 0.1285795690191369, 0.16483066573498711, 0.18191603523108268, 0.15557782514201057, 0.14931661918038322, 0.1829781854945806, 0.09495510434311244, 0.17933457939615174, 0.15109037319498678, 0.11423880910320629, 0.09915512776182545, 0.1958646883647288, 0.12679697434988715, 0.08698698553827502, 0.12228918276847371, 0.16192451119422913, 0.13645090793649997, 0.10227266128265089, 0.1992823444907704, 0.15254681359135336, 0.13874748631590797, 0.27215659618377686, 0.22292557983629166, 0.13520193947178705, 0.09785143763668115, 0.11921352361358943, 0.12623618266755535, 0.21019238648155045, 0.11337811698115642, 0.11052640830917705, 0.1410274405873591, 0.18619429920950245, 0.1399231095227503, 0.11820093157791323, 0.10794928853189754, 0.13651761887294633, 0.1273964687941536, 0.11334702913318911, 0.19735313591457185, 0.11680574757197212, 0.1395933699583815, 0.08550878058397963, 0.1760811725210759, 0.17475303653026783, 0.16192535389094584, 0.12370967065855382, 0.11093530007788252, 0.10547795783608191, 0.24652640455432479, 0.19418041341968123, 0.15072914741693005, 0.1367781806977526, 0.16941249971428227, 0.10880097912083711, 0.1608809155802573, 0.17450419585070304, 0.21774547715340892, 0.13561812439753165, 0.08659951358793244, 0.09180079094104229, 0.11031139041146926, 0.22042381246724438, 0.12299514045157742, 0.14940819733085173, 0.15109725266454682, 0.13631382416332924, 0.20435913255618465, 0.1897963986641938, 0.14385522433346318, 0.17679685185993874, 0.06331088119036248, 0.18102492175755963, 0.1501195559338216, 0.07594194353347825, 0.17311786782116662, 0.13778163330449214, 0.11478657729082531, 0.1499592290530282, 0.18733629115646888, 0.12652453816225454, 0.16317530294820187, 0.15592642579107516, 0.18292489641856763, 0.1391943300803823, 0.15824790202802227, 0.20226987289084544, 0.15590865255123185, 0.10947217939481621, 0.17733248521483716, 0.1161702469952645, 0.1678586435774642, 0.19248737442877986, 0.23889745585620406, 0.1455169303282615, 0.07120558961985574, 0.13310307306387734, 0.15129910151083625, 0.13805485090180752, 0.2249152787149914, 0.15141778385206578, 0.20071699734657042, 0.12845944643260973, 0.16443021625520723, 0.1396503515781895, 0.11885471101249419, 0.2615853795601476, 0.108805361143764, 0.09735726496024479, 0.22090637125074866, 0.10703786606750182, 0.20449128272312306, 0.11194263675039816, 0.13616891097157233, 0.14441531121490464, 0.09804489782019969, 0.1594483311618528, 0.13221554488183992, 0.1440811436623335, 0.15416518965315434, 0.12636228073989192, 0.11338563996457285, 0.18332579022934362, 0.11061374999342427, 0.17157459901946207, 0.1250490451592111, 0.10150570001813675, 0.13680775169162981, 0.11413842860248782, 0.1321899881886859, 0.10288482682118494, 0.116375190836768, 0.12354655521771601, 0.111472986548418, 0.13349995257393008, 0.22325029386387718, 0.15773483762337318, 0.14773464761674404, 0.1848229098944895, 0.17837197459753484, 0.1904778951598752, 0.2634847873160916, 0.15561951564684992, 0.11230702647158217, 0.16200666646322898, 0.1427389576189941, 0.1198043076381568, 0.12140536245198981, 0.12186064084451045, 0.13189885945570085, 0.14590567398455837, 0.11609733840751073, 0.10229150704558819, 0.1406623384044055, 0.2167544658145597, 0.0826339207349285, 0.13964443737941404, 0.1795279706317571, 0.21212879628423723, 0.09123909527495985, 0.08581737612163828, 0.12519987254974344, 0.17841867531739897, 0.08855722063491422, 0.08609382660999414, 0.1857930683200398, 0.19995279399858368, 0.2342774094112458, 0.1905615059959312, 0.14676813576971331, 0.11781320681855564, 0.11187598710098576, 0.2840010815810773, 0.15874901546105263, 0.15250881563030905, 0.12731273538402973, 0.09614192775540775], [0.0120987854109356, 0.028055767723990065, 0.07631273774970924, 0.02649557220959856, 0.012332612682404298, 0.01955915741892832, 0.03860705840070883, 0.01793826092785645, 0.04124844912439585, 0.004986947498119046, 0.04525222762998554, 0.05801382752495909, 0.029656717200733484, 0.05386093383534782, 0.07338704796688211, 0.018675254747992562, 0.00774074869696051, 0.038495155937609174, 0.044250950712950966, 0.04652392592341189, 0.038105401045252243, 0.021693811624220783, 0.021863731841046005, 0.012428261632580432, 0.0274764750182869, 0.050126228391403155, 0.04988729705913894, 0.0446060746006908, 0.016499342877537976, 0.031503481309740775, 0.044545342980493466, 0.049930558044223056, 0.050665876047024806, 0.04424516291868302, 0.055379396710064144, 0.05452773293420192, 0.028436634081205534, 0.0477606829466118, 0.08182316222378323, 0.07347080435964369, 0.02336519713994236, 0.019767211577404412, 0.01370150167795439, 0.02344836556022206, 0.04458486162606747, 0.014278268208727242, 0.06465530804088039, 0.0757255390166275, 0.006253278388025901, 0.02771198385274939, 0.08812430434890332, 0.028656097204093973, 0.044399345774323716, 0.03627076985374574, 0.04062548557656907, 0.056190848530780886, 0.026596245738948067, 0.05200948701390336, 0.0721303726576509, 0.041156962904478275, 0.023451535249008768, 0.04067845672609345, 0.03177211770126897, 0.037177274033667586, 0.022589797416942257, 0.07923859607187972, 0.05584576805572837, 0.07733366482200162, 0.0268845054726567, 0.03263703862866087, 0.03638567155106895, 0.017350740437846512, 0.08094139502293642, 0.04700067776045011, 0.014830356174629303, 0.040220290182098266, 0.04053381166511005, 0.013266183706300875, 0.024373979803415078, 0.031958346014782306, 0.021415689148970192, 0.058877580168266455, 0.05030689873702584, 0.03369666463244827, 0.1167850555371373, 0.030533912771892165, 0.05727477484352647, 0.065962131465635, 0.08089061105443586, 0.048032142372140964, 0.06809619195278614, 0.07355125891345163, 0.08294187275873077, 0.028746782862130674, 0.04059185431669316, 0.041764087584470554, 0.05131087611399351, 0.06418506029031931, 0.0353858310488924, 0.022047659975566694, 0.015755187092919745, 0.028629642272848758, 0.013977280881766592, 0.027565607433057124, 0.012620186767420702, 0.03971888180521708, 0.031136094269553022, 0.017408662430581548, 0.051591195346366976, 0.04245983714598321, 0.030750110445003358, 0.03414028316676136, 0.05427881181540509, 0.04858161510539152, 0.029547812056637583, 0.02756658611038039, 0.0714872878104929, 0.024189515407347394, 0.05916788535673292, 0.054754640516494556, 0.07199679756717337, 0.035342681146557295, 0.08723283081405586, 0.06813283393820448, 0.0227452251654599, 0.01593886433364523, 0.021173478960390055, 0.011592972986099702, 0.038891916704033656, 0.07897346836304472, 0.03656310134477193, 0.0537239994493223, 0.055104183453706004, 0.06715125314170314, 0.04184096833811172, 0.07434879474702381, 0.0541919412752313, 0.08578395170550193, 0.0369583222744686, 0.08427471252939395, 0.0235148256028732, 0.02329817210744706, 0.012606720856931663, 0.04965043033383066, 0.005026726134782357, 0.030140394472607204, 0.021922038792962992, 0.03522067015329677, 0.047049247734849496, 0.004794515308833892, 0.06407928270017428, 0.04971226895107858, 0.0340424269257534, 0.062214195683238015, 0.06276618501531982, 0.03172611986707536, 0.09920929783895131, 0.07032943784349388, 0.017931251223349286, 0.013255211412005368, 0.032040229322569024, 0.018947825001011935, 0.07240621793654657, 0.06821571699073238, 0.014359719634446648, 0.04717001000479345, 0.05159553523445803, 0.03576789441848955, 0.08460324933572162, 0.042016505894641724, 0.07195139919678051, 0.039073123311203335, 0.08048478363742752, 0.026112966832794973, 0.02429300047937901, 0.02994449429904982, 0.030739862103796298, 0.06415735472053771, 0.027422986759413636, 0.013240481456441265, 0.040513575452590184, 0.05679680875712826, 0.020142602321181088, 0.07659825871908858, 0.03161497966146037, 0.024905160272253618, 0.017248785626443646, 0.05266378738827283, 0.03710674797935832, 0.03121010985435738, 0.02040520385508576, 0.0743183121085167, 0.014025232240167117, 0.021210609326860117, 0.03457274746089693, 0.06557282856515338, 0.05692061622657123, 0.022388908095778, 0.05412951277028169, 0.04645945579414407, 0.04535260046982477, 0.04684717289262241, 0.02369337005450601, 0.0322109826600119, 0.017694861387773868, 0.04196965578763236, 0.014856587982766572, 0.03118194654704102, 0.02824142913243944, 0.025847237744939425, 0.06463847708918395, 0.08813460057060565, 0.07799802393081688, 0.04858478670939804, 0.026936609027606827, 0.07041130199908249, 0.03638042767922725, 0.06394862640468825, 0.01880815568109674, 0.03289065586643354, 0.03414070451511972, 0.07375466291822734, 0.06950407003563258, 0.006779532911511319, 0.023607953166168545, 0.0104042898953682, 0.01723257329074606, 0.003065773029623914, 0.0040911589730380764, 0.02966623967363229, 0.03576012245649773, 0.04243767039189416, 0.008585917962444647, 0.03996768418038565, 0.09811049026827659, 0.020680480313697652, 0.022374231766368595, 0.03527064972947683, 0.1005252989970388, 0.02454426391200433, 0.01425768246859192, 0.011978719323392839, 0.060446359697849526, 0.026484176651724887, 0.06771448098363415, 0.03351250475633048, 0.02584599285206247, 0.008136457050099008, 0.07468023502658452, 0.02886615276727225, 0.10288126451233703, 0.019145140522009423, 0.05195170483221451, 0.07330827114562835, 0.016838417223264134, 0.0242246845887313, 0.038505448328871886, 0.0194006557426145, 0.031736963841643547, 0.05318821670727865, 0.06992777794479363, 0.06367807862378898, 0.06330239293616145, 0.074053414226059, 0.032162994912434975, 0.07282525270936951, 0.04787856089552084, 0.03460502274514687, 0.013970260643550466, 0.06013167759163245, 0.11478459312310142, 0.04442140910654299, 0.06470776974193512, 0.047791973807879036, 0.05135011513747516, 0.022282230352321943, 0.029950021623423504, 0.05039834282210758, 0.041673187421815056, 0.020722829654151877, 0.015536869271478106, 0.033682334957824606, 0.015615568526329534, 0.013280621590843845, 0.06143368998422258, 0.04502585630923991, 0.0179814740324453, 0.0830390433510465, 0.052463788644320546, 0.05496323476695726, 0.03736012389943485, 0.08614990424605147, 0.041267689422614155, 0.01136083781133376, 0.04048336477529618, 0.03614778209838175, 0.01764805150038052, 0.05113809264355129, 0.06843580639049893, 0.08948372737053903, 0.045930832143752806, 0.0459527001235514, 0.03225644614787833, 0.030086699369994384, 0.03083394344655737, 0.02984233647434702, 0.08203271791459092, 0.03432597904916733, 0.024032128388963403, 0.035713280010367596, 0.0207053130537632, 0.035599071622615865, 0.03566385967837226, 0.05105888298262031, 0.02777023334807206, 0.11990734646397254, 0.01502254369458364, 0.020476618571387186, 0.03608104817929768, 0.05567257089780704, 0.06422782714869227, 0.06273873225455323, 0.01939352537925926, 0.038572297161144596, 0.07782131809020236, 0.05657446705886433, 0.07065048997080134, 0.039945766404871984, 0.04553741918155744, 0.03270907387618096, 0.045956886794057586, 0.036272501212454615, 0.040270641310921604, 0.04838110691296959, 0.05082049940322196, 0.017368042533616387, 0.08012316715452941, 0.04146885262021134, 0.011409371396556739, 0.012703883788368155, 0.10533815445077997, 0.026073534372112444, 0.010170627332803224, 0.03830416638764643, 0.022457513184617126, 0.021805430634788448, 0.019426892338801297, 0.05234157463776008, 0.031032641756258188, 0.035180408402436206, 0.014785690375814035, 0.030630681168047652, 0.1388094321854653, 0.11668505041950172, 0.15781091015425422, 0.07475211705651975, 0.11766073999986534, 0.19445573009790915, 0.1351884563243197, 0.15722157403586373, 0.09956175191027504, 0.18667842081237226, 0.1292951717492073, 0.22155181564871343, 0.11028839245198235, 0.1363695493989414, 0.116981549428836, 0.16705794380076472, 0.08853036925316819, 0.135671520725854, 0.13491093331286985, 0.20939701867680396, 0.13995839553254266, 0.11297963634734193, 0.18943989198775063, 0.1562668752646254, 0.139616827570623, 0.1331709331322101, 0.12906675497370382, 0.14420345726032413, 0.10914017987107077, 0.19446234909757493, 0.19765783972557516, 0.20194201790277036, 0.0837529836703212, 0.09181033639657883, 0.13564700591227702, 0.2640311918672054, 0.10274536817544892, 0.14807194080804625, 0.16434818356027528, 0.2129622999458544, 0.1013988997006128, 0.1720731537188253, 0.12570716831232273, 0.09283310974076872, 0.1206072673742329, 0.16460149819331785, 0.14707691516847382, 0.11978592918885332, 0.050402360953270435, 0.1410946264983185, 0.10127474749160391, 0.1003398291105705, 0.15839134433096455, 0.10964123201706719, 0.13594358919128297, 0.18538682721555236, 0.10866312925974209, 0.15960066008471674, 0.2611836430526549, 0.13519821628447504, 0.11784796422768025, 0.14779339123877788, 0.2927876197763028, 0.1321378329228009, 0.07466943318685217, 0.19705744129755806, 0.32920639781701955, 0.09027855125285926, 0.177248016360306, 0.0838826287297472, 0.12048055643155692, 0.0720434063564866, 0.2334502336358832, 0.1009532586941796, 0.2521363285280043, 0.1419247593730688, 0.1858671796658347, 0.27058853677684264, 0.11258838758353265, 0.11910631726946562, 0.13382587702043597, 0.15116142018908454, 0.12891493166886991, 0.10914178865571177, 0.2368944730128973, 0.14343075033637787, 0.12381499242638389, 0.17240486979003877, 0.16914479795002169, 0.13502668919822863, 0.22604754134531946, 0.17198911387353175, 0.12633683895992656, 0.19471377915432378, 0.1690787764927072, 0.15418827954319217, 0.15481090984277188, 0.15576248297527914, 0.12208754076592385, 0.17094482878042808, 0.06400362002633272, 0.12596430572410747, 0.10738829766670543, 0.13697840543764253, 0.0744868131474622, 0.09115854112972176, 0.1487626763240945, 0.1352068730780194, 0.17106807700568633, 0.18463653602427055, 0.0904619680236905, 0.15410270752205005, 0.17210286260852892, 0.19773857007103582, 0.1584278254379188, 0.18747251691116443, 0.15230689017522722, 0.12683622869512728, 0.12569598342862823, 0.1789800798700702, 0.16609572204610995, 0.1460701377401429, 0.1868402185819803, 0.19925850383456678, 0.0980053447006691, 0.2576137652560588, 0.1315382005827081, 0.10843569307678169, 0.19060105145458253, 0.18856480507360351, 0.10705792991023873, 0.08367619101679133, 0.11825648061330281, 0.14868473453867823, 0.11070987870616299, 0.18829840565881423, 0.07823304438422765, 0.14757412155309033, 0.13616578533284127, 0.1886168837306961, 0.10415345310203492, 0.07218702485965145, 0.14406473405899542, 0.22150824056758037, 0.18330660738771964, 0.16495720813831977, 0.127889002042432, 0.10682231190824702, 0.17485322550900523, 0.14984256918391875, 0.22434846558157476, 0.1009645508301835, 0.13615656163423293, 0.16282621200286573, 0.1682957733470586, 0.14453243073676864, 0.226366923400952, 0.13976425353077152, 0.16571145234329088, 0.13640529506148832, 0.2048260631460336, 0.1713581178938189, 0.17650682629356462, 0.1583064464671958, 0.11331307611638501, 0.16414561459133703, 0.12867447199119678, 0.1976432993767723, 0.1505908072595635, 0.1404740033491004, 0.17782319517385575, 0.11035517999722112, 0.2361416230879484, 0.18106783800307782, 0.20140112918471137, 0.15345283513588293], [0.005597929909615027, 0.017272496047700127, 0.054157838871281956, 0.06418900564312935, 0.06176940120396115, 0.018512035885284987, 0.051961993393037594, 0.037231061066831314, 0.019342212810090954, 0.037016073812640486, 0.04693172984726487, 0.09151239714194691, 0.029948416669222138, 0.024829758068306312, 0.06942130955717257, 0.028634914872987617, 0.028869046664406216, 0.056355775769559614, 0.03444228268739197, 0.056462016842898824, 0.039000946337417255, 0.06859621754096401, 0.024591340014951366, 0.08332452601602963, 0.01652871085811527, 0.04113468889807982, 0.05868615011774725, 0.03865233802747342, 0.002365909336555389, 0.10208188240686733, 0.040672795336333015, 0.030259465603458307, 0.031099128611986677, 0.04077771873844247, 0.03639449305351704, 0.019732668672898607, 0.03978254371172479, 0.03520087444133336, 0.05719047835877827, 0.03040637445425795, 0.003165134872805568, 0.0020415402879382697, 0.00850984447395369, 0.027579619181192214, 0.04134008090101904, 0.010085521667685, 0.03729865300439058, 0.022706786703859127, 0.08493295059569421, 0.03985744412808169, 0.014359304031747726, 0.01577835263414008, 0.014685170064049383, 0.02041733102692712, 0.007493280272390093, 0.01630869998236097, 0.03418484650131676, 0.016881795036756707, 0.0798609352580482, 0.020405466240199826, 0.09303904183569456, 0.04919281920358058, 0.017217872063479116, 0.034593646339471304, 0.06697795639235167, 0.014491600713001625, 0.04918196756813315, 0.071663127971753, 0.05309884489003209, 0.034170938175051443, 0.056627668034765995, 0.0729920530331231, 0.03758893137977969, 0.03921666903601539, 0.031185066440112652, 0.03500338080489347, 0.03782572915717479, 0.012968710807692862, 0.025235487809104305, 0.06502814005098997, 0.028049730951146736, 0.02614669385366142, 0.038893333966693575, 0.06051858263691107, 0.03532295055206745, 0.08490452873370341, 0.04522495873032078, 0.026953395929247625, 0.06493705219679302, 0.01825775215101819, 0.06277776443429532, 0.0992478627050596, 0.02818921449474029, 0.013389772840685422, 0.0205195214103667, 0.036220231033380956, 0.050260044799576846, 0.04576544908265914, 0.04775936527538204, 0.06477085708249962, 0.05461274954159895, 0.03362291334797779, 0.011957559974924212, 0.07982643065793861, 0.09073836488589164, 0.014574038476923542, 0.041965254612507365, 0.045460664832423774, 0.02551737369128293, 0.012546161606517291, 0.0311813528288997, 0.027343786674581712, 0.027315805313147368, 0.002348615619872186, 0.1142429076736012, 0.018622540237922824, 0.035688677096679326, 0.04616225581435908, 0.02887561012269749, 0.037415454599766, 0.08274910205434408, 0.01425646917684184, 0.023817591211428086, 0.03593182574296671, 0.025225919370930043, 0.013384715702775265, 0.005594923493317179, 0.05000990560098041, 0.018546994392489715, 0.055451581344729474, 0.05385925993323327, 0.0481153893164329, 0.04591878924158312, 0.05943428094108259, 0.030360359383086045, 0.11468694755627264, 0.03310678842207117, 0.03465112591643007, 0.03884100633102559, 0.05820381349974102, 0.04360358726473586, 0.04726459505036474, 0.03445812155522647, 0.03296894622185538, 0.048785049753684195, 0.04691976355388761, 0.01133572066112632, 0.022468608052980517, 0.01709056357222219, 0.04725830929894601, 0.029851284381302617, 0.036305603871662775, 0.03914464911025378, 0.045640856373093786, 0.006445064190624943, 0.044374880756461815, 0.014008267223083926, 0.020020629632316773, 0.027680683415383104, 0.0917342332221808, 0.034922887946689324, 0.04032851542316137, 0.005683262528280818, 0.0499252490549078, 0.009230265897067805, 0.04385883243934762, 0.05083091436855255, 0.04528101338374038, 0.04974694975141076, 0.020815480327714356, 0.009044048117263424, 0.030081541683044166, 0.034888969403841806, 0.031261838026224606, 0.08878774415220946, 0.019037855653873375, 0.021306531195859277, 0.031739032279039105, 0.052860541749865785, 0.04206933531790011, 0.05546139876147913, 0.08577459011106722, 0.02912802268720923, 0.02111659693201223, 0.017371704433894446, 0.038855569662466165, 0.02876892088792257, 0.042744285592268554, 0.01572979032061994, 0.025770376143496365, 0.03615408700199858, 0.020897943947103717, 0.031719977757142435, 0.013322956567149491, 0.026939907036120855, 0.020536074655190594, 0.05155984702850542, 0.04147538351976583, 0.020838474456761635, 0.07899259757851401, 0.03176014757745209, 0.02043121445533489, 0.06080799916338536, 0.05615414142788899, 0.016812096357405666, 0.07535895062310081, 0.03495669540678782, 0.07094276783567283, 0.003976045404523311, 0.023014832573432117, 0.03324921182807415, 0.04001398270408954, 0.03211540361535886, 0.06464893418935037, 0.06373547010063645, 0.029622800573105776, 0.012077739060435806, 0.05151394687052216, 0.0855490614870383, 0.03875385999919907, 0.07092812789543983, 0.06219007157450242, 0.08096578726244551, 0.04744679757183598, 0.05426728985302391, 0.048121131145425385, 0.0354216265071544, 0.07264328384471518, 0.05767229020655636, 0.024929242246153376, 0.011000433662575821, 0.03707421988609337, 0.081805580505921, 0.010030598909173523, 0.02116215618086919, 0.057101918594731446, 0.06964254808882553, 0.007673161068645818, 0.03696516727007205, 0.08043185462273898, 0.032330952028954224, 0.03073383682227183, 0.05049990692866906, 0.04255178301865536, 0.033888588809678634, 0.03107705570366835, 0.047237575129275365, 0.06230587342513665, 0.04245900211014575, 0.03137156671483911, 0.01620800347037373, 0.010925403968881696, 0.022274479457748034, 0.09765790084437018, 0.06479285912768495, 0.0543511190241383, 0.009629987593319629, 0.00999872677869374, 0.06476216964543828, 0.006087820633359615, 0.018368580175804037, 0.026886970360553073, 0.020402951556588375, 0.07385682840380939, 0.02794196344761839, 0.049670080489088456, 0.054721342504865704, 0.055251996288256305, 0.041855374621527816, 0.016843875599724632, 0.05734571075487522, 0.006602376036631365, 0.025554823899461378, 0.01802320667212048, 0.017927623797027815, 0.021474367653530453, 0.031248634500849633, 0.05001236474321735, 0.0471128560152025, 0.03377460258742494, 0.07678658611351445, 0.05152559523741084, 0.05151554416384428, 0.033562334945365306, 0.035253788134263414, 0.08266555250532205, 0.04093907983793367, 0.010867471442437701, 0.0561850875495903, 0.042734502649475495, 0.0327764474786818, 0.04493035195815948, 0.02607455901471117, 0.007074542358637818, 0.026945811658797246, 0.06071360947023477, 0.04750405881373633, 0.027939598151152174, 0.020951143007785566, 0.053062313987362775, 0.03279131724529209, 0.020312244831133756, 0.00408871658897448, 0.025851008812746695, 0.04376965980496138, 0.062435319301702326, 0.0713749639990349, 0.0632745877749497, 0.006422213703063467, 0.007449727216284843, 0.022303370548592463, 0.06356796880643215, 0.006525143361349981, 0.010934302080122214, 0.013045627950510431, 0.041064530565974214, 0.012978329999192108, 0.023259319958367178, 0.006582859467955367, 0.01452969251981666, 0.04060190539025972, 0.03564359665277504, 0.06404400435126116, 0.06190005749944718, 0.04098299582819304, 0.05643528803522068, 0.024404345613513744, 0.1313890279420922, 0.03799962728554684, 0.046514139150179205, 0.016261135498362205, 0.07700217091628621, 0.029448044426258535, 0.01213337523832677, 0.03662319328155249, 0.05529467887695759, 0.030724492464815418, 0.016216545350729458, 0.023443188721073732, 0.024478975983877337, 0.0526138499469286, 0.03376501116661295, 0.05602863324325412, 0.026048458399130933, 0.03501858765019044, 0.03979710321272573, 0.05586875835433603, 0.025937431191484776, 0.05674375333793222, 0.05572712784933467, 0.05640399334351382, 0.03888438605973798, 0.0837053559840687, 0.10253212760172545, 0.154464224413518, 0.11316980235278608, 0.19188599540821968, 0.23476687830782708, 0.15155515873864775, 0.15901080302653775, 0.06716020870953798, 0.25467391816839097, 0.10192095031661373, 0.16376318349953622, 0.09703696359910312, 0.2015812670992267, 0.21022284613741984, 0.12079195585101844, 0.18768990202055824, 0.23696764973142456, 0.15651404587251527, 0.0858343985953158, 0.14430137861880565, 0.21603369965187966, 0.10663399217470039, 0.22186218851035644, 0.1696577857458784, 0.1384039878124191, 0.22996071846254412, 0.11516038989347797, 0.09771725733674343, 0.1246349210099828, 0.09848346783509178, 0.19486587825081042, 0.10274378237344566, 0.12976291439225598, 0.1599234282489746, 0.15127257954689766, 0.13804627071705558, 0.14268577579529057, 0.1619839596171533, 0.22376479851382397, 0.0565007234352731, 0.10990697259624159, 0.20252571561403815, 0.1701179441184767, 0.17976086136073838, 0.12033163659995604, 0.15808261089747952, 0.1475476302326687, 0.19989256416597675, 0.11471673305476866, 0.11598113819115585, 0.14096999931479656, 0.1257415426774852, 0.10712096362464851, 0.16154986355573903, 0.12584698701938316, 0.13264864502895263, 0.1956721091823232, 0.21708662621676925, 0.18792789489511522, 0.16420828058354317, 0.19697635855165221, 0.14104349779025202, 0.14795108277711178, 0.10517572082819478, 0.18310431421043413, 0.07948761295166709, 0.17282310783142046, 0.1366227261361576, 0.101880194439042, 0.12553045481082895, 0.20624945450934673, 0.13101036600287885, 0.14963891237012802, 0.22934867549807797, 0.09092662333240432, 0.1084456981850728, 0.17662501833852262, 0.0929334749197287, 0.16701720324495148, 0.09654792371175944, 0.15561170155002227, 0.11094939609568928, 0.12204129203793504, 0.0877027108424133, 0.23872211365209473, 0.09165069899491726, 0.12806607560525018, 0.16720854136491978, 0.13426605581996903, 0.17827261299375566, 0.22156214251393275, 0.1358465564947936, 0.09860951994215289, 0.0804685655560705, 0.11471232038832481, 0.22085568687367826, 0.11231124761604494, 0.11197660508896075, 0.196642788547662, 0.15972701862694758, 0.1915737992573169, 0.2163289959031728, 0.1257255620833847, 0.21873733118897487, 0.29087797708569035, 0.17437673414186125, 0.09737587323592556, 0.15053863667192, 0.18757480497081436, 0.14644901418397505, 0.0848623785761095, 0.20815007268421112, 0.11640061729497488, 0.17348024273110976, 0.15605155859262715, 0.12732058012437436, 0.21313416411078748, 0.09855381768917847, 0.11918408285465934, 0.15666796825826168, 0.09800418024702419, 0.10841570584283722, 0.14836653225844906, 0.1215075892246058, 0.08051896648060891, 0.057933388292909636, 0.09856919307381877, 0.08368337692152109, 0.1468023339346532, 0.09829124105313132, 0.15107477564484845, 0.09223804328470461, 0.11181585685980898, 0.13414999349944054, 0.2117726879735147, 0.13508216928570502, 0.1087955015921785, 0.0896168964344167, 0.14715252804660028, 0.12989255179080272, 0.12366547504620207, 0.11043578776861392, 0.12370254604085801, 0.23211155627523702, 0.08108493691730885, 0.16040918928000236, 0.19007124036790865, 0.12199624606798734, 0.19962170611946814, 0.10910815739583586, 0.19041320669554895, 0.11581009374030175, 0.19759957107805437, 0.1525798013373729, 0.20708781516840383, 0.1442988811721725, 0.07384887641115535, 0.270982091465304, 0.25575695198870474, 0.2066307517910196, 0.10575038636283529, 0.14526864123200217, 0.11785148057125269, 0.10834327989047575, 0.18375075452270048, 0.13125025877548804, 0.10951284334183702, 0.2097540003277602, 0.08578769021457242, 0.08906192702030943, 0.12618359839243273, 0.1367928742641403, 0.1765486087289549, 0.14139033643709076, 0.17172973182412887], [0.042294078701806646, 0.008847117555447885, 0.019931763433100238, 0.05296064645893151, 0.02223371591929707, 0.04480876614369693, 0.0531827315177408, 0.05617201808960207, 0.029073467650901408, 0.02446619572208053, 0.014408540502641232, 0.03878500147332107, 0.014201533011791688, 0.06443192446303946, 0.024096154187235142, 0.04858963604595873, 0.03495145919582537, 0.03560740665923204, 0.02530118367905098, 0.02581086772073421, 0.05660670786915768, 0.013196268607111228, 0.09075355640943013, 0.06741890894068826, 0.02514074763072835, 0.0656271288772264, 0.027986486562557762, 0.01688197506741891, 0.010905184993340124, 0.024653176716979475, 0.028514085570350293, 0.05060068196466854, 0.02922956764157261, 0.026676602616545655, 0.06768153920289009, 0.037013024782701846, 0.018056192502920187, 0.04299799476059214, 0.0343652946814414, 0.03363379179650257, 0.07486910634343663, 0.022298385231425206, 0.10628403555000983, 0.020268024320924477, 0.04856131377539808, 0.019444322754298488, 0.05244695386218448, 0.14434784951229251, 0.012111925734056821, 0.1314202383641274, 0.058231461612928304, 0.019585455302149057, 0.065840752494912, 0.057691660739721796, 0.025898783970924637, 0.047064109840580536, 0.04056903255742885, 0.07499831473274578, 0.04914765832044425, 0.02220180644203098, 0.04069776214178532, 0.01746785612927089, 0.022372776199312463, 0.07403325079189194, 0.028697866232945558, 0.01958715410212115, 0.08984489952244105, 0.02479106679769053, 0.03474001126784471, 0.04905855080353157, 0.032479925486709804, 0.049796197713623126, 0.09983887655600425, 0.010342014608003441, 0.05982566377027862, 0.03478658558320134, 0.10550490114837886, 0.04627801553015748, 0.06114807708429233, 0.034179437920571334, 0.05421378244195254, 0.01322808136577688, 0.038940421560959476, 0.05220526461339286, 0.03490684223511527, 0.03384951832554033, 0.06009918014188448, 0.0769029472083334, 0.044709806736077995, 0.017146846136799263, 0.06013574934895, 0.025501025374978784, 0.022211995411423907, 0.02454728995930524, 0.06311024276299343, 0.09559197621720453, 0.034365313833639506, 0.023643932485532378, 0.01598394765037923, 0.07009989491874172, 0.036438305621906635, 0.01721561593454211, 0.01906119643770639, 0.1258587005037454, 0.02733474109141577, 0.03635901169130399, 0.053451674344438704, 0.04436364224661262, 0.002164403793417038, 0.022813464447315183, 0.09801133550823697, 0.02151289996090195, 0.07106352627517716, 0.07781820777322977, 0.05782905477850188, 0.041312674105527906, 0.041452986939299497, 0.03863651831183703, 0.013234913912451556, 0.07712194876324746, 0.058599934582748724, 0.008974514146816106, 0.06053028846039407, 0.02871789943216549, 0.03216392187882335, 0.02955321106128395, 0.006375247246450595, 0.010452793794684114, 0.014713453072603914, 0.08389143107999718, 0.051938259989143386, 0.030480409191260417, 0.05737263874541368, 0.05216217982853132, 0.03766526055011538, 0.03160201745378154, 0.048485578323203715, 0.062429451068202337, 0.04149541671898577, 0.015841419864896567, 0.024872950105477246, 0.039809303162919904, 0.06201562186282489, 0.013904394319040642, 0.01529688552592791, 0.009268911202408133, 0.037650214583282514, 0.10221428538282072, 0.036336802802379095, 0.02397325836242207, 0.022712292960814895, 0.09913939231586072, 0.022643542315270153, 0.03363661483050354, 0.05129885236402193, 0.04489635297607991, 0.021553286201050206, 0.05733989614752993, 0.05654217645285591, 0.024741479841571663, 0.017499878604505813, 0.03869881658183952, 0.06332359824990554, 0.023328423004357085, 0.022101251656309735, 0.018600994015052434, 0.046598282417342554, 0.04303159537695108, 0.05115811052101274, 0.020952313207089904, 0.02074071206152439, 0.05593972873964137, 0.029284107356121945, 0.013231267333931982, 0.0639404560769758, 0.03155833512033907, 0.0642728080011664, 0.037651260293299155, 0.03295186246114393, 0.04201457918351216, 0.0740899796026849, 0.03370963833144596, 0.01389639731872106, 0.020289817607150446, 0.08476290972002092, 0.02596025103552928, 0.06976774217741144, 0.0135274522472173, 0.06897767570110099, 0.014043919997470034, 0.02407850352145972, 0.07992748531603044, 0.038723779556852196, 0.025105936595449047, 0.016641122769684564, 0.028193619500304905, 0.04263559303757164, 0.028156364644547145, 0.04616617818453139, 0.013348418456922858, 0.0495103741395137, 0.0777792675240386, 0.048306945771459615, 0.063329228996149, 0.06550116870071619, 0.028473224355688984, 0.056297170043352156, 0.04548498429358006, 0.061746805440634496, 0.029495599334158247, 0.01356307150525672, 0.06908033148295457, 0.018431701990325126, 0.09607414429586741, 0.0498086849467889, 0.038819153672985496, 0.05401394074602474, 0.043844874317367236, 0.016670046419265772, 0.005655223710252153, 0.03711675691808905, 0.015861701085081985, 0.013102911217438598, 0.05334678158584622, 0.03220125334337354, 0.16052738132496036, 0.035344872158020735, 0.06522208286990082, 0.01524646161875177, 0.028461558751822002, 0.06058316384892791, 0.02493378897798398, 0.06737262956918248, 0.03226987949963058, 0.03606214495976606, 0.05422910803087777, 0.017225680414647344, 0.020445909936942404, 0.02597778678811606, 0.0501139939672524, 0.010045921625269037, 0.028117194568978685, 0.07561833267250369, 0.08103960749482916, 0.02636501359032287, 0.04413187766688005, 0.004095165612882063, 0.11686447587224746, 0.06711770615149891, 0.014796378259967654, 0.006282350467142439, 0.014242372201425175, 0.016109865692053593, 0.022843594685377135, 0.07186214995360182, 0.016149884209998192, 0.04874492589865, 0.011906607467080317, 0.02035489486109826, 0.02339433529414237, 0.03435658043130271, 0.06472240968216812, 0.02664435606059288, 0.05979603148936745, 0.05061026955504091, 0.03273471100856701, 0.05449651868172711, 0.019999309405384046, 0.051155777783283306, 0.02794838134920405, 0.070284070116618, 0.05727523449628104, 0.008494937360557097, 0.05439426126559416, 0.007600722667355572, 0.023822224128150174, 0.024084743307602983, 0.027696947462015578, 0.04537895772485964, 0.031178056735605485, 0.025168863057549444, 0.07135567390510152, 0.014931251869476853, 0.08240516688073836, 0.04002265864983201, 0.04228005929279231, 0.032354252593171214, 0.04594797336105858, 0.006941327808289639, 0.03404182554673284, 0.006031559615005409, 0.07411518389539373, 0.0348521358964424, 0.08745629100068923, 0.08894967981764386, 0.03588523227541197, 0.07709106009814047, 0.05071985460216961, 0.03176140204642809, 0.012110012429465931, 0.017402968482084332, 0.030132814032596447, 0.014779002428235067, 0.04919078907058124, 0.01949476964411236, 0.039528321264491934, 0.04851599201379765, 0.034987285297604344, 0.021531320545041276, 0.0624743476510048, 0.019425377399931033, 0.028479655663813316, 0.043630358207249836, 0.013774092339219586, 0.04088558391818116, 0.016211404900757537, 0.06653577044245697, 0.05391455615960783, 0.017571408233995882, 0.09303937891438123, 0.033702145991546494, 0.022283525040913976, 0.03445963840931654, 0.007933853607204172, 0.05470664893847801, 0.011919287179837064, 0.0052937159160782975, 0.04974350618619112, 0.09196635786323779, 0.05665618948818696, 0.036837418278258656, 0.03182938085838912, 0.0879403513165251, 0.0663446851315037, 0.03233338052767419, 0.034489366451218244, 0.03670573925539371, 0.01557465655834324, 0.02449146896270254, 0.022882483223633423, 0.05779609384555971, 0.030601102513291185, 0.035166090219131405, 0.03920972444898179, 0.038055145677419445, 0.03698605082688793, 0.016181378084565365, 0.012477291259734381, 0.022315840544779936, 0.024725614160659815, 0.029010039401210608, 0.026217003488132072, 0.14774477529910304, 0.06665495074083728, 0.100550641185574, 0.17707069764935202, 0.13444596390810706, 0.12734399943221963, 0.11151637776844925, 0.29316459632208275, 0.1275541986368837, 0.1514432179711519, 0.19094513218489387, 0.10546500328928234, 0.19484666476566948, 0.13060470712521385, 0.09856189991677962, 0.1993879420502532, 0.10203536554810502, 0.0969463277367815, 0.09098074744425474, 0.13796345661244086, 0.1140544347224697, 0.14938849354943923, 0.10632157385829957, 0.21847031890384613, 0.10793801937853137, 0.21035239160541566, 0.11408235096643049, 0.09446581164675374, 0.19808522485677274, 0.15950376528405374, 0.23972519853663063, 0.2027179423959986, 0.14153079099712834, 0.12129073271587973, 0.1814289105635497, 0.2366604178302711, 0.1618229892225035, 0.135249896575847, 0.13957015749427581, 0.15227436208196227, 0.14267065321966527, 0.18233885447825157, 0.21876250483816673, 0.1086304173053753, 0.10757062659268418, 0.10801039170473815, 0.099808799944097, 0.24722512270654404, 0.12043775509922736, 0.25008243148124987, 0.11881947862885653, 0.2158090213854467, 0.13358921713886723, 0.1736227657285429, 0.10940920696744036, 0.19596807959098972, 0.15280003629384503, 0.13579461573352739, 0.10499101702965076, 0.08092425763607025, 0.09996181834609279, 0.16873273457730972, 0.17351254099799743, 0.19206150615167236, 0.12613372606856207, 0.1543368852787441, 0.1465467057160793, 0.1297917499417259, 0.0654590568475185, 0.12029690217346915, 0.11020031532332783, 0.25915111985898787, 0.1471855464361368, 0.07705987265874302, 0.10624052941678994, 0.09428116147436442, 0.09722601111617782, 0.224577127505214, 0.15631057291982636, 0.1504635600553405, 0.1714216572262587, 0.19276600060684068, 0.06660544613917029, 0.10171518676103124, 0.11064276940399602, 0.1125643783879857, 0.13124958461811467, 0.1947315523941671, 0.18501642370416274, 0.12492774279728053, 0.11311694228601073, 0.13240737329807975, 0.10297064399046284, 0.08211020004725264, 0.1626045827663714, 0.17169173386308456, 0.09701714490450199, 0.19443345226107106, 0.19999912699624417, 0.16152159491133306, 0.17934746499503815, 0.21591795908827938, 0.13710880892411356, 0.16060965916802808, 0.11753792844472394, 0.3177664068437392, 0.13214906377177085, 0.12379977792020767, 0.15049005137576213, 0.11723741513466644, 0.176172643419235, 0.18236389023161706, 0.14034333939273513, 0.16159061943331074, 0.11684762193791329, 0.19239418749367038, 0.10513483471567593, 0.19783938724187114, 0.15303139484697773, 0.2190968562518397, 0.30099560837111167, 0.14931000018071744, 0.17574084562159356, 0.07413167010752425, 0.13770928396092308, 0.13383788927908868, 0.11042174537696185, 0.21128531815784596, 0.1795741810553497, 0.1674816057446503, 0.1667618661397888, 0.16798658026081903, 0.166464593381651, 0.1592028459473964, 0.1392562759499396, 0.13981994812286672, 0.15733805004387133, 0.14678698153265063, 0.13023940575939993, 0.10953030248563136, 0.26885889410491914, 0.1603709308490638, 0.11292976402347127, 0.20042363163684646, 0.0996884398703133, 0.12804546784008705, 0.07514433875199288, 0.20550258007020722, 0.10304167566280212, 0.13848338516489153, 0.0482159536782532, 0.3039228303297874, 0.1928722110366629, 0.18223314966645934, 0.09505090363804372, 0.11285172264662482, 0.22394346553952466, 0.16258198317260514, 0.14986663966649963, 0.09295130944660596, 0.12848947707924152, 0.15696232988228723, 0.08910914101908285, 0.06797436865106707, 0.16755743312739557, 0.08083537611509524, 0.08490547102185027, 0.17531678531198733, 0.17743530953603406, 0.12390277844162718, 0.13647393653950385, 0.10702121131602796, 0.10211546770146779, 0.1568507721587535, 0.15765908684942032, 0.1123017174822669], [0.013265109267987072, 0.03749612748863236, 0.06246937957081584, 0.045336301949235706, 0.0454280792825645, 0.04245804833068002, 0.026062230744789687, 0.013553766409806428, 0.04795095237392572, 0.017503900566108285, 0.028765402629130313, 0.01976494395714854, 0.08286693403797765, 0.025211334972071554, 0.03707213229649971, 0.0402470343115349, 0.03314121258294871, 0.01707289566946847, 0.03490222655537148, 0.04608842409065655, 0.03392966644417855, 0.019796849603975014, 0.014287469882307755, 0.047416847364436236, 0.032457793206577344, 0.04312557521306219, 0.08357108375358005, 0.03582391076751294, 0.04820819703801986, 0.08342284574023179, 0.03875477164382896, 0.047781788668925726, 0.04767012369308261, 0.031703752014906175, 0.030486384677069805, 0.031153547667687943, 0.019897235850352916, 0.026583618694736112, 0.038652920254295876, 0.05455130929007165, 0.04709306413367872, 0.04034060429060652, 0.017222614147730412, 0.007212263421200577, 0.04483255700418546, 0.049649511028321526, 0.06098971904946431, 0.03396128672325323, 0.029536244128980947, 0.025579267849905357, 0.06439518288619096, 0.03609972157245202, 0.10199588903736684, 0.052034055453635035, 0.040665031035220435, 0.07407279625054329, 0.01951848772624808, 0.054962307800568884, 0.024398442906057163, 0.03560413163335573, 0.07008314057583771, 0.045512613254569234, 0.04979634327032874, 0.05160972701325532, 0.040889609710223256, 0.04103176498545274, 0.005652389184932315, 0.0419039101219706, 0.07705611882791405, 0.024801763300333294, 0.04647687280310258, 0.05772537626926938, 0.020190421529414675, 0.012267278789001848, 0.08466867324445518, 0.04464813665817342, 0.0444997645794384, 0.08560993483350163, 0.04677260572451257, 0.08509578258400002, 0.023341293281484998, 0.031326926771491286, 0.03800081089138985, 0.05354466975756711, 0.07490705067832625, 0.025274665545552008, 0.03971677889386493, 0.020399758885163936, 0.024480395161757068, 0.02151980815875915, 0.06842143458103941, 0.04548506856325173, 0.04506909814212592, 0.06692988437510307, 0.062111256448852445, 0.06608820655533383, 0.031511588435199474, 0.037260264338504885, 0.048938784447889176, 0.027321033863230582, 0.055092297599560795, 0.04133267666123087, 0.040719760356531035, 0.01281389018385521, 0.04077016894194869, 0.034779855500786536, 0.05155322419840002, 0.05075766487167247, 0.01156757812901971, 0.03385656250400409, 0.0409068160450026, 0.05218145843114584, 0.049412671116090594, 0.019732565251028827, 0.0529127161679489, 0.027972007500788862, 0.035484828760907534, 0.029400487603139014, 0.014787469615018176, 0.030754683989911314, 0.010147163017292418, 0.05750895260022052, 0.04266864590106472, 0.05176438867384869, 0.03626183343810901, 0.08087491391286736, 0.036461269107436946, 0.0278700182154294, 0.07067134288410026, 0.04929479699762118, 0.06373360467654082, 0.036281901111285535, 0.024555941007190177, 0.01352826142758732, 0.006310886284711981, 0.06165742979294831, 0.02518048269614097, 0.03370439829004388, 0.03569154226551614, 0.044722366747596574, 0.03386063043088202, 0.02450545198254047, 0.009516274289888962, 0.06366642259602105, 0.07193964740802204, 0.02203172343152185, 0.04137900965889135, 0.022020205299580292, 0.01231069777972035, 0.037057741334842104, 0.013078952775216632, 0.03953544971262736, 0.0713272673648692, 0.03854927621901997, 0.050264733257673444, 0.0142760235711091, 0.02053934776584708, 0.03445802579423593, 0.08173562135667571, 0.017639025069412687, 0.09115548443890388, 0.09071463148199743, 0.028408036018992146, 0.01521659472341379, 0.029873715435725548, 0.017088588980597355, 0.04156933654279959, 0.022414468619371616, 0.022865096858191877, 0.004173012594917729, 0.03058964375316376, 0.03897064372957234, 0.00816798348340296, 0.04683790322873862, 0.06766223378719823, 0.027376207515537262, 0.02584913189733221, 0.06321433495970503, 0.04898809752757511, 0.1096942299796689, 0.02903266389283442, 0.03650260721183112, 0.009484920226367972, 0.039613360854526686, 0.04188284270405289, 0.024810774409542644, 0.06832161332450568, 0.05849464728887524, 0.022344678009469664, 0.048526763210013035, 0.06094184238463641, 0.022485841200837207, 0.04836853541013214, 0.046316109252192324, 0.024747909234476187, 0.014322980930427871, 0.009950423019848043, 0.028224270678155368, 0.02113695380338017, 0.07809327164244267, 0.06298918937963825, 0.02861800922771856, 0.007371834747778673, 0.06968136576394882, 0.07858463277619693, 0.01377598266117275, 0.026618918111067147, 0.0448259609871574, 0.008418829398109548, 0.03562500752929238, 0.028107959379051483, 0.03545638008583938, 0.0166356529019052, 0.04662376250170412, 0.048018804781379244, 0.06433532843666692, 0.02274924329662275, 0.013950140301829145, 0.03596898866817355, 0.013942432499700978, 0.03196387142393618, 0.04505981698692326, 0.019209627888255545, 0.009475883261691178, 0.047367430862880526, 0.016540788234241547, 0.022326847313032038, 0.010653947416182247, 0.011566677018098775, 0.08975816304765402, 0.02795786168726702, 0.061137616153686285, 0.03858761891963021, 0.04681271042734866, 0.03975491475073561, 0.040638742728098746, 0.02561876542806145, 0.00022769247827396144, 0.05122889704521626, 0.08014126981218016, 0.11734184057962511, 0.08205013875398906, 0.03003645549348045, 0.06487493778789236, 0.045668657703865925, 0.011776724920397805, 0.031001523264773914, 0.03544826338428163, 0.036052212629827766, 0.03485140428247471, 0.07001980808713744, 0.021466921278906446, 0.0374087245173512, 0.055271880100331, 0.02460148684950846, 0.008209364680242876, 0.008920765418048588, 0.019772844238867684, 0.041634649368784124, 0.015021979662349388, 0.03533130091044211, 0.05583357959685307, 0.04241514740692031, 0.038950503278043, 0.02401797491456232, 0.04623906762008706, 0.01273085582896226, 0.04851815621218374, 0.019445351227336836, 0.023406939355716593, 0.005799100289286505, 0.049845246492975184, 0.024688257798252088, 0.06291295980073272, 0.06721680728538383, 0.02359851113250179, 0.04793466917509514, 0.017395863016586632, 0.025968737374510498, 0.006594021847817086, 0.05063401061981436, 0.044300271453516143, 0.03789936935889625, 0.014595423821329832, 0.05079872718441391, 0.1197476247926393, 0.021407139607735222, 0.0369755209483687, 0.04442993566514023, 0.026357687874546936, 0.028046884934508035, 0.031841563571604996, 0.042604685220266544, 0.029921040517247977, 0.017396182858295018, 0.021914914175267183, 0.06372827270458783, 0.024811477295213172, 0.019287288136359666, 0.02488290350283346, 0.03775849728093993, 0.0364255387666485, 0.011349181783565832, 0.03113483213969777, 0.015484187320145148, 0.05398453063061161, 0.0477755373914636, 0.046387726981793685, 0.11898714463196455, 0.02736721938896564, 0.01240594357612633, 0.03829396592693464, 0.02932801568550208, 0.09461511452231677, 0.04135423437542012, 0.05160996067007223, 0.04853155508997941, 0.021788674376664624, 0.05119135107604727, 0.014338736486200605, 0.022620630540674733, 0.03691987998242821, 0.04160795120462295, 0.04697589098566002, 0.055062849179751454, 0.03070849080329701, 0.0424195294298472, 0.05873296958123965, 0.04814343962578043, 0.04183299719325958, 0.06295613268570555, 0.07411768900290613, 0.028674236250921126, 0.019604211049755255, 0.033417348975255605, 0.037548665798479514, 0.04313116765490944, 0.05336936585785401, 0.021177133199788874, 0.029336281774205067, 0.036671418516385945, 0.07861883094113681, 0.07119749973137533, 0.037888410471139417, 0.04627323131107035, 0.04248132591225928, 0.0685625326549334, 0.031798877152464086, 0.04890465140042286, 0.03103588039295808, 0.055070881611637534, 0.017758498396424037, 0.13442213857366195, 0.16803603889721055, 0.16331215689499534, 0.11583341345671685, 0.10462170136311363, 0.0744327120182495, 0.14337966759358683, 0.14565451971946225, 0.1192753162655619, 0.1087486093503333, 0.18659087228438548, 0.10383170383471636, 0.22811524329646943, 0.15397524581320826, 0.15369275855200906, 0.15519510293679853, 0.12870643317939776, 0.11492068098197061, 0.0956406151395171, 0.2292556877458288, 0.10868830290893394, 0.14053579600107285, 0.11690502490607962, 0.22334977804172426, 0.2193844303368561, 0.07602363914972352, 0.14744197138615195, 0.1406675631240491, 0.18178583092747197, 0.13755856382270015, 0.19490266579293436, 0.12192051827667222, 0.17532015609885418, 0.12316347295117956, 0.09551202728142662, 0.07205220870673656, 0.13618221025793784, 0.179612715277941, 0.07820801629174141, 0.1785375568414888, 0.11405965178123406, 0.1097011017883497, 0.13447591794594643, 0.11513477957416927, 0.14928678771661175, 0.0916231964384356, 0.14705656787320492, 0.13416683211201622, 0.15328945922515086, 0.1042104730262391, 0.10963916357967163, 0.0479399590122123, 0.17556193344775708, 0.18579512143567686, 0.18036847633700218, 0.2263956823416295, 0.126816026956564, 0.18563638801776594, 0.17330753586945996, 0.1587676773628881, 0.08265806016542258, 0.0996491012554015, 0.18482675565586937, 0.14890936683983574, 0.1495402402454807, 0.11676797177642585, 0.1145927110807069, 0.13391578509922952, 0.1379219806122203, 0.09522159568845265, 0.2536271662721711, 0.15155154280364513, 0.2051024829908725, 0.12982579488908091, 0.182712628776508, 0.07346246932302752, 0.11252715417574491, 0.21196405673699997, 0.18535825213597668, 0.13617116327006973, 0.17140383802113995, 0.16546123270546237, 0.132116443747955, 0.10947138266337496, 0.15338157363716634, 0.102368644438684, 0.11579649567964578, 0.09424233613836189, 0.1672240776280242, 0.14171642942294, 0.20068218631129112, 0.14728938199339375, 0.11491445268714622, 0.15550097120144676, 0.15240202297366437, 0.10523128518534285, 0.18838607676086888, 0.13472580050508823, 0.14468990777048374, 0.09009776982448756, 0.21520413368219332, 0.08434271049355307, 0.0962956892626901, 0.06920234630665473, 0.19017067858048026, 0.1526193774395412, 0.14568294158145306, 0.13328051434889918, 0.1075860019773245, 0.11967686891195276, 0.24868623623924874, 0.19018132720262776, 0.15809960272764007, 0.09785904488976925, 0.2449526607749924, 0.11579415145059747, 0.10267062863755612, 0.0959506509224734, 0.09081009369824203, 0.08699597941050607, 0.10432118805305612, 0.1590022228417858, 0.13173848660963197, 0.140736878759438, 0.14544508660272246, 0.2461560929734861, 0.1638905685995856, 0.16867229024008398, 0.1374832420579849, 0.18983903911805924, 0.1442313888260434, 0.16433509877852856, 0.1706458399853399, 0.18090691357370348, 0.13137883897269928, 0.2539114768226301, 0.15902531273182363, 0.1431381353928197, 0.12911388470280555, 0.10625196710949945, 0.21625571193233614, 0.11556459320408684, 0.18630769554405444, 0.2279231084450599, 0.10411958435490247, 0.1686655639881088, 0.13807555059752158, 0.16825569162686027, 0.10267491106905284, 0.17006752021130056, 0.1906760514623696, 0.13984297672587057, 0.3072483873655719, 0.13907960075284206, 0.1391586457048693, 0.2439377781364226, 0.13014306254204244, 0.06566517280354615, 0.15508703857419953, 0.13792479981578168, 0.18987617906062834, 0.17433669838693835, 0.12249507655900334, 0.10960045315685774, 0.17717929827349801, 0.13735421752977756, 0.16894492561057692, 0.15906530252147108, 0.13788264965818775, 0.1386790899860282, 0.16678117155548067, 0.10484660945592389, 0.15107849883216043, 0.11519508601556863, 0.1428701425151479, 0.10600211519387462], [0.04434347881244556, 0.039280085794387326, 0.04857817920105112, 0.016668987302710454, 0.037604747264976465, 0.02150825172242138, 0.027131371560596654, 0.05134781304326269, 0.025190985761582855, 0.05552654687855994, 0.0345172597125413, 0.07149359271410974, 0.026074777349769592, 0.07292568683624268, 0.043779542339184595, 0.062357526903431264, 0.06910103117866863, 0.04350714828638781, 0.056440754072560426, 0.0286825004244043, 0.07667934146499442, 0.0359839235522574, 0.0982251046826282, 0.04547179992040319, 0.040068351964075724, 0.03217167468861707, 0.04424560724967911, 0.0822689947521975, 0.010809446027832887, 0.09711161886732425, 0.05072732778987096, 0.04332568887020311, 0.02875562160155706, 0.013712834991184215, 0.036122903393040744, 0.0530142458005538, 0.029665220776692997, 0.026705171950461886, 0.1106333695051651, 0.04149286564619791, 0.05984781903304881, 0.08244568527105355, 0.061368480580107826, 0.04341576548834001, 0.03519794415502298, 0.05868248438702957, 0.07519667787897973, 0.032472249285708514, 0.0235605170018971, 0.03303092273492967, 0.040299484521270766, 0.034228616934870525, 0.022434413718480258, 0.03022459902680449, 0.02032903173277455, 0.09932733666632446, 0.07870208171586837, 0.031871559744280194, 0.03671728803085224, 0.06700237927537772, 0.013504693690206737, 0.024574543537211516, 0.04035940408826836, 0.007077227496812421, 0.04422177042391512, 0.040166472505417564, 0.05864523336171143, 0.015419827316016441, 0.040846835190971056, 0.0505320558084115, 0.01563373342862413, 0.034326944319951924, 0.015089359010509668, 0.025834045710883317, 0.01978902976148792, 0.04234285935038521, 0.027370178403573173, 0.04074481526209463, 0.022041079280297124, 0.011316366407329278, 0.042819163025987726, 0.021472071304977424, 0.06944621507559093, 0.04544836146035983, 0.010002875144803717, 0.06524768552833027, 0.053015839263436296, 0.04082780939737155, 0.09743196619374138, 0.03324547331900366, 0.07605170861126916, 0.01600523627618508, 0.04300260277945669, 0.008017936066138528, 0.011367349558690143, 0.10352042698932272, 0.011379364690172577, 0.04065553154495936, 0.0028270447106596326, 0.09373193771968927, 0.08092739859655981, 0.05356905050575734, 0.03451505720975899, 0.06952464715727875, 0.01853550881928494, 0.014886713432778996, 0.04347661968260523, 0.018742212747794487, 0.06295073176583936, 0.037456930599986546, 0.024439043650824218, 0.022108171345485796, 0.016260593491155776, 0.016646996748843984, 0.0366220326583472, 0.05812479153035149, 0.0018943399646236833, 0.018113218172783815, 0.033396913579875426, 0.031209089042198275, 0.04144865471208769, 0.06614251452828608, 0.010429790089537781, 0.026044009343510675, 0.018234022577563604, 0.08468849193905631, 0.017403598589402054, 0.0304510182280454, 0.023526554408993934, 0.04992511498952105, 0.03128940186974022, 0.02140236304952733, 0.016872533033752156, 0.03120167522631105, 0.021240563364699486, 0.03352535205082067, 0.07760672920173214, 0.011676664261387722, 0.058094013947993524, 0.023476389056492238, 0.006600090700592245, 0.02993993224546073, 0.06391664223384953, 0.011139598322070895, 0.007462194818447555, 0.08422877023657484, 0.028539546502513752, 0.008558263145988027, 0.04972985449938044, 0.0407588959581429, 0.049738369566658815, 0.0242783049977715, 0.03078503064781187, 0.04156349129193733, 0.02495528157469967, 0.009270165671384143, 0.03142752177682856, 0.03170201108009825, 0.03459463459289363, 0.0339872149690505, 0.0031774499755908526, 0.02162543636175894, 0.012937644027143478, 0.04998404630309632, 0.062095436733216054, 0.019952244793755874, 0.050037224296360254, 0.04768018625796803, 0.10364179063828723, 0.03264226717874408, 0.055611479216285294, 0.03393381481028853, 0.005496740228526535, 0.04191204597572646, 0.09348552553884446, 0.051245471357458064, 0.03761042397649538, 0.03704215144558299, 0.08379583862880546, 0.03795836195950547, 0.03385161740645286, 0.006374101945003796, 0.05802183697420744, 0.03352967661715323, 0.012889233973598289, 0.08157295024683399, 0.02195529850019563, 0.053855057940968586, 0.06092908319025751, 0.06198718850951522, 0.04363485514336536, 0.03361560486918015, 0.015664664228566955, 0.03389022823783659, 0.06676459324456031, 0.017694824998597466, 0.04351674736807904, 0.029648772868958694, 0.042969105584967526, 0.021277442837374348, 0.09501630710738321, 0.05213749264517138, 0.020604120499844995, 0.05263834560830748, 0.050811923048909635, 0.041325755056834994, 0.03445264019612824, 0.09158392677143698, 0.05599276500663931, 0.05225160144149296, 0.07131083477889338, 0.00511530744505205, 0.01560756769557033, 0.04013552255327663, 0.009338180872521574, 0.11334109961265519, 0.05741921306077031, 0.03320933312117573, 0.04271468012443474, 0.049470487771736044, 0.03109109809532041, 0.09949101135134698, 0.05970337698536535, 0.04417115116431829, 0.02365488562762978, 0.031617749069306644, 0.05762755450221801, 0.045055787364441546, 0.040062100686613596, 0.025250311610439134, 0.036354219811337615, 0.03314267198044447, 0.02843157024002604, 0.030217828724773663, 0.01187020296891851, 0.037053619781809474, 0.03424357097115248, 0.01599930100999172, 0.022065910105142864, 0.021860732606822447, 0.03921795223328856, 0.04152219149193937, 0.012051862525573422, 0.035778443449206894, 0.009468435929457267, 0.056506530381739146, 0.07559878210867606, 0.030127610380370772, 0.028356654501910654, 0.03145962852173515, 0.05022939745216601, 0.042201941307153434, 0.02883526218694545, 0.02992683788761497, 0.01095290556775346, 0.06119745528145183, 0.029118609381839636, 0.04606151525231619, 0.05293980886739108, 0.06856796421831654, 0.019774405143013405, 0.0252846323494469, 0.040203152795232115, 0.01699448657041836, 0.045873505784378904, 0.07527233672238166, 0.06121304517071094, 0.06477215177109165, 0.02505757921044865, 0.05255243650847866, 0.022308426728892713, 0.01662275581169994, 0.015022972703821238, 0.04450168362968872, 0.0076241247382225295, 0.06232618624644895, 0.045545666118062315, 0.02254965824014958, 0.022330972696504286, 0.07155951457999407, 0.03099834591510796, 0.028585925465449694, 0.09688445081513736, 0.012177549783260593, 0.051841031940233324, 0.07629327911643252, 0.0253270314856162, 0.053195651590583794, 0.026249380279031974, 0.035976266503454216, 0.07218471893499936, 0.03977876306781846, 0.006498693218154292, 0.04644223413760624, 0.041782745655866406, 0.02883467038402394, 0.0994461109381049, 0.045464043280169855, 0.015489003140359156, 0.03471106846606539, 0.03482449544413436, 0.0253226820214261, 0.021387079595437935, 0.03539456445122919, 0.029632141100122567, 0.03996555062551652, 0.048934517338150935, 0.05761009918886328, 0.0225705839318013, 0.10238319244836608, 0.028292835547378468, 0.019420342287048697, 0.05311603207261332, 0.04773203508868333, 0.030475611565634612, 0.04280529300411863, 0.05511337650879737, 0.053099381151579084, 0.053004041509402376, 0.05429618668952777, 0.042862171202056834, 0.027063913688424136, 0.031138733442452167, 0.027381439896060095, 0.051880270963714975, 0.02466887194332817, 0.10137667548992943, 0.030344549243548707, 0.06209718724412303, 0.017378032320149003, 0.04566754687637572, 0.05054722434931225, 0.06291488651186228, 0.035138116518576304, 0.005538607891198369, 0.07873729877774754, 0.0878839059582641, 0.048779564564146345, 0.05769142708290489, 0.026166592987494606, 0.034719648650817336, 0.03903863403285223, 0.06971760938364653, 0.02497521709770926, 0.06396224361754234, 0.03781382032039185, 0.039366749490821557, 0.011164557466643953, 0.032977319562867764, 0.03131005560017882, 0.018582144421675516, 0.02483362298188431, 0.11715414137729716, 0.12000585004927651, 0.168366713088847, 0.1453462306169733, 0.11165535377879297, 0.10532022033247257, 0.17774487034447733, 0.16753913894776376, 0.21645337793855898, 0.15728324411376832, 0.12937079994909226, 0.21953646814630878, 0.1382836660430316, 0.20387363199505115, 0.14944936689590255, 0.19721485704423922, 0.1219738839614776, 0.16724604902969253, 0.14275925894898756, 0.11378300977089714, 0.13658252184189137, 0.15866709001843007, 0.12274701989466145, 0.1811277307569981, 0.21614050763028286, 0.16068370922678904, 0.180797225104705, 0.23026071849369237, 0.14473798744861158, 0.1456210416771712, 0.09642822247359062, 0.11548711873230436, 0.13953600529461138, 0.18949482049192154, 0.19922045990824702, 0.10617528170827897, 0.16000057330294964, 0.16573414386760804, 0.1346011733215663, 0.190895474365642, 0.2594921209158436, 0.17462333784468714, 0.17892430866918257, 0.1405699482007373, 0.14152901367314402, 0.18421031534671786, 0.16787454756277223, 0.10077521219969758, 0.08066832298232664, 0.15969651300580273, 0.16402918454860488, 0.1511280340773444, 0.2025308943684063, 0.20979630370293895, 0.0828157210602395, 0.16749223904503932, 0.17274354193960467, 0.09948364924639465, 0.1860274912248696, 0.2189455538867943, 0.1366774554574682, 0.10873163284193124, 0.18349949300529497, 0.15728468435906595, 0.13075901255492242, 0.152715444865246, 0.1462136566518776, 0.10467165795665596, 0.10425183411327102, 0.18094792992116945, 0.18740577533120112, 0.15413960231648338, 0.17465992620395077, 0.17590586096048358, 0.13746009088091313, 0.12443658850726583, 0.13874966200561295, 0.161391252711896, 0.16882967534324816, 0.0930625147696945, 0.13086896149381516, 0.09868023751844322, 0.1374489366407356, 0.19151736922081442, 0.12920238317981844, 0.15866240156033348, 0.1145517790029126, 0.19592819705365166, 0.10663380065271932, 0.15024648138111638, 0.17895337404502978, 0.178464426088237, 0.1533810680191363, 0.15515004164509236, 0.11451653129751645, 0.23963786451326263, 0.10195949220008428, 0.16439918969427386, 0.06553397258563388, 0.15848301441198395, 0.15589320821867836, 0.12204198151706688, 0.10302207913369903, 0.15902037912559125, 0.11339805824982543, 0.10134825362793862, 0.1372718937214344, 0.15613320824359694, 0.1476709244232024, 0.15204425991302536, 0.2129269373272696, 0.12747192079381597, 0.12968371622264385, 0.1569681061852363, 0.15374875957927397, 0.1602031422718879, 0.14421890159287762, 0.1575541174820354, 0.11903259662851212, 0.12729362149031895, 0.13135317502723587, 0.1690096906836956, 0.10303523286335892, 0.15886383671914378, 0.12988053953215, 0.1296935834351086, 0.11276532325052446, 0.05781092530777378, 0.26796410340935956, 0.21962651412092873, 0.13244727115717628, 0.14146349783385956, 0.10238001318348032, 0.2315516379331389, 0.14185164394157548, 0.21873158552954275, 0.1956689069347997, 0.10749496008840301, 0.12372154502138016, 0.11684482571698966, 0.13685861992980206, 0.22423638691825254, 0.1954064452119412, 0.12150006624118936, 0.16910824023427504, 0.17665546267263352, 0.15618793756490754, 0.07821559290131254, 0.26701917992003504, 0.09586269636788676, 0.15269417826446796, 0.17521157079646665, 0.1236642799490402, 0.08908778248775391, 0.16203875022549785, 0.13869618906849815, 0.17375401191173062, 0.07704596050203809, 0.15543370868169493, 0.25994671749011167, 0.12188595238952868, 0.16042998090626734, 0.15615219190236063, 0.1217360826089017, 0.12011949153196429, 0.12432035764739399, 0.1648906197759413, 0.09104981793150788, 0.2089340717441613, 0.1816573886260871, 0.0723527449994318, 0.08935402868495834, 0.059845670156421206, 0.18048757236571084, 0.24811586845786343, 0.2219215143592127], [0.045164671441119526, 0.023931236524555474, 0.01425240986845306, 0.029757394560522614, 0.04473845076356684, 0.023408283840023705, 0.017775204858832785, 0.058068020584722685, 0.05437521248935692, 0.03645628953592912, 0.06379110723613732, 0.021777740386765332, 0.0401459681621242, 0.04141391645516119, 0.036506039285731894, 0.05749345081107271, 0.03451303473763889, 0.06865508373706572, 0.06229883690755214, 0.03879304539652602, 0.016038103363356523, 0.03353508902833827, 0.1051837800731582, 0.05172527605487455, 0.0017841930398830184, 0.05450762312618956, 0.02876165645918058, 0.05149699717519745, 0.04494534046839803, 0.0532003592008785, 0.11647744825290096, 0.05372155562884385, 0.003645784660963522, 0.059488087126444426, 0.047872206196188934, 0.022737236783629464, 0.029332290456119566, 0.021156400945338032, 0.04585542610936588, 0.0193743999942296, 0.02758420230219922, 0.025434988595905806, 0.08669848448687023, 0.034490864153110215, 0.04776272840136963, 0.026426970951199055, 0.046384501751632466, 0.07541086074085006, 0.022616229365549745, 0.046613144523073594, 0.027110729321476915, 0.038189433229666565, 0.05360146368583364, 0.027406628867010438, 0.059197781937977964, 0.05843920167535544, 0.03227546428059859, 0.03251985015888368, 0.012194440106771166, 0.046816931571811445, 0.09997858801075529, 0.05738766172960882, 0.10687379301675867, 0.06266486988733373, 0.01909180548072102, 0.038326264193822304, 0.006828420812399277, 0.03926965167685863, 0.07409754855137679, 0.0103797884883299, 0.05266227053418275, 0.03831280019855307, 0.017500591066275394, 0.019204422320810058, 0.05696897552679143, 0.09542067895733541, 0.04719503043640045, 0.01460749353657687, 0.048970102122233766, 0.05242874778266396, 0.02060112509606106, 0.03722930289504509, 0.09388205264845202, 0.015583145770154174, 0.08651715913607229, 0.0485449233242581, 0.0308175012844825, 0.030083374548403007, 0.021088159748262936, 0.0050030770005598186, 0.039136317904077234, 0.044441652979942105, 0.06191531414045923, 0.03239111674408759, 0.012555055887318187, 0.0537822719272827, 0.01811165152297866, 0.005618282471738395, 0.043078162031428474, 0.03296986552736452, 0.022188068570328817, 0.05154611873290232, 0.037920226102634784, 0.04182493411785653, 0.050353549661174904, 0.026109659248181892, 0.0836971588432789, 0.018390651168902556, 0.00883144052368739, 0.08643884962845234, 0.14805139432991707, 0.043764324002568765, 0.041726307958484664, 0.034061253536492586, 0.05046774272716815, 0.04076030172948395, 0.07497959920475561, 0.07094425404624594, 0.023551684008130146, 0.07352134318000848, 0.008604729251425353, 0.053199022377450625, 0.049119680789449525, 0.03130487493059087, 0.033342728180991064, 0.05464451537737924, 0.025431167732383457, 0.07615572802962796, 0.0546279717086544, 0.03206890590879465, 0.022611895223118128, 0.04982965277327646, 0.025961970902919292, 0.03654854950465022, 0.03129717574695186, 0.023958626083068313, 0.02657481251404651, 0.02801472264822693, 0.01999148190201771, 0.036529152158407435, 0.05505002103745938, 0.03165061424125827, 0.005073577199401635, 0.026497960488702503, 0.0206705384076603, 0.04777610812696719, 0.022911661597449454, 0.04706698267029659, 0.0029101252702305154, 0.05106685029703283, 0.03469159834146981, 0.09664199164798183, 0.06656233071079178, 0.024059998667648724, 0.07079014013851843, 0.0633580415629812, 0.03904268280753205, 0.04679540833157878, 0.05993546332202612, 0.00897850259207189, 0.029277875230857925, 0.02768319043811531, 0.05344043966502913, 0.03384767971452206, 0.019224685346407276, 0.026766976093753215, 0.055022204384928754, 0.024915326259008823, 0.04558077209719247, 0.03569320850675145, 0.053279044091581344, 0.12117106212122787, 0.029589391478727904, 0.032633890007292075, 0.003313448297933886, 0.021134883450764804, 0.059190550067972754, 0.005489041523692469, 0.05268354862627964, 0.010469467698356077, 0.04109299839324048, 0.019816313982911168, 0.05004063721806292, 0.021159984321603854, 0.07249742070393217, 0.06288492864358329, 0.027775800892061768, 0.04093919475112231, 0.01799302472312364, 0.07627202017653374, 0.09700255859042368, 0.06384334677169401, 0.013611414526108534, 0.03325728639479607, 0.0797005930554963, 0.026422880041683396, 0.023817480128679066, 0.008634923649350963, 0.0388294460642482, 0.0344040778826081, 0.010454505043584975, 0.05186986748970324, 0.008264571848896243, 0.06466489180081314, 0.043694954741025166, 0.01859436926972722, 0.03132802419244282, 0.02101231895897898, 0.016971412002139034, 0.023964804582177632, 0.0004273121433676176, 0.023818024051105304, 0.02706491534838513, 0.030939060285867705, 0.05253239181793986, 0.01859049286483036, 0.0331374166172839, 0.0595359752825912, 0.054439904784122785, 0.019493160859471368, 0.009001530237465857, 0.0291775924063498, 0.05097107398473928, 0.07987257213361802, 0.011898497468791904, 0.05705293493285295, 0.06316908980689703, 0.054611240348388115, 0.004377049101035922, 0.04391046676544413, 0.049474559529053594, 0.08796265979688014, 0.06358741211795038, 0.06695814535862978, 0.016134146848813664, 0.03312885558473007, 0.04665129953214238, 0.021082879487244834, 0.128886632380947, 0.07433708126266157, 0.016920177956982967, 0.04180945914178606, 0.011298828739522686, 0.05764877130728095, 0.042199210203703374, 0.017996441475265933, 0.02997157933761276, 0.023939083180119915, 0.031378088038294547, 0.03921447419411233, 0.05622532631781313, 0.060654249147421894, 0.0285172188699606, 0.05575063908773084, 0.04546909179959086, 0.02940947956015026, 0.02334782992669892, 0.05775282136915673, 0.0820070846126445, 0.02774969836126172, 0.03768760733486664, 0.0517074415279973, 0.021429879012547677, 0.05703889254120089, 0.07738911426596104, 0.048133246825947884, 0.054140257153419725, 0.026839147321879867, 0.0441607017250311, 0.03276995871396315, 0.012946700144018377, 0.025015275835269885, 0.04488929730629729, 0.004475410481268961, 0.05847050019750192, 0.03403197365602659, 0.023443851387128237, 0.025659266581398346, 0.05603450147675411, 0.02577519866697971, 0.03676431433808419, 0.046684310260799625, 0.04993771330543584, 0.01945921167310688, 0.02923615408250161, 0.09331887077179649, 0.030236509778807243, 0.057969543812496055, 0.016076872200374643, 0.010213491867386527, 0.03812413955588014, 0.014005412587956076, 0.04638191620488802, 0.02692803841895394, 0.038051433981426304, 0.054488739058856046, 0.0049949751419556005, 0.08465050163889125, 0.03479324671770296, 0.055127664048585205, 0.024359981461818662, 0.09860868490631543, 0.036248365612400156, 0.03197796361130332, 0.02824235801404763, 0.06956108229895754, 0.0744034321377835, 0.06948612825644594, 0.04172610494518473, 0.043288116087956775, 0.05190090554195547, 0.056810399156904993, 0.011900859892428403, 0.025841415476714893, 0.030531513001469356, 0.029715916645082257, 0.04543147305206907, 0.06040734667030554, 0.03943178652515335, 0.02134120625053202, 0.00784651623220153, 0.10422596332406807, 0.05462264739758065, 0.06252949449023412, 0.04096389342580111, 0.0021185914961425888, 0.030580669033130815, 0.050899126837330486, 0.0325522480172015, 0.03876248614922647, 0.03459841523679995, 0.04220638844755389, 0.029694853057604165, 0.08769083647958695, 0.02497464444698586, 0.060795274442963065, 0.0632862935984327, 0.08460642093972814, 0.05352878492445715, 0.01851996106486167, 0.03513854935825352, 0.002465518961300052, 0.004434553575852225, 0.0402475705730819, 0.0241903581040641, 0.059887950548962246, 0.0632111978296551, 0.057539393103891806, 0.0498000051706068, 0.0495595186798563, 0.03255550006044007, 0.026073542032991687, 0.17246801075675797, 0.09004376062582578, 0.13697782321082008, 0.12468981120975749, 0.11904405730385935, 0.1093146104305502, 0.11957471108724994, 0.17928410952370014, 0.12446234438328013, 0.12873283256926846, 0.28919969294821063, 0.09019374531964142, 0.1592119623936953, 0.26203311198661405, 0.21017449066763927, 0.1800308460670133, 0.10336786057920226, 0.16620423073970503, 0.26891193803279634, 0.1359491969548887, 0.06760774195314416, 0.10555778419779194, 0.18268822121524042, 0.21391162077986428, 0.1140735103117843, 0.1583803586301304, 0.0928157272057668, 0.11442092352456625, 0.11346766499862557, 0.14477975456224335, 0.20680523597665373, 0.15165452034242694, 0.06665688128240647, 0.11926079123851754, 0.11314913330058898, 0.07598030155584698, 0.1516623037957376, 0.15188278390034554, 0.13391659715242926, 0.08682541759504427, 0.09048450633042282, 0.1384731961954986, 0.12152689464029767, 0.11264751424952862, 0.14108134253371146, 0.09612908046091757, 0.11723094169170627, 0.17310364922929197, 0.12089861827271602, 0.16986574797380358, 0.09661684864230695, 0.1591556855747777, 0.15567467397739812, 0.1702728470967662, 0.14118234356564863, 0.19675269152127928, 0.24097974412143233, 0.1300405599777737, 0.09155392676832215, 0.16669897032120537, 0.1483968693402506, 0.17602664238262564, 0.18080172970169978, 0.20005566428505606, 0.16957477245840336, 0.0807458127758676, 0.14071093902232187, 0.12746525582887475, 0.17026895537011086, 0.0977504519265025, 0.1105053332303801, 0.12643484458807977, 0.0926703313786176, 0.14528243081463924, 0.14393342658877373, 0.21981141710233307, 0.12899440563013478, 0.11822618949677675, 0.11345371453752441, 0.2558318600659409, 0.09104974898359469, 0.1569702359096658, 0.27827080519449326, 0.1292446712332387, 0.21839593176639852, 0.3130149763197668, 0.1541948525775825, 0.21589837788093477, 0.1027052021855789, 0.08265317252446568, 0.1705646959524001, 0.09119944256399909, 0.14633371795137085, 0.1318185427977193, 0.07272926955333642, 0.1395548510575487, 0.17672739832872347, 0.09153264484578565, 0.16882429740601973, 0.19136816593668154, 0.155582697461209, 0.11878880446836834, 0.1514088206233517, 0.14407674631764814, 0.11426240461127413, 0.1410798256796214, 0.20900050688895488, 0.06377288966529793, 0.06310477289521406, 0.1253665426385499, 0.24542000505232045, 0.18768043317381414, 0.1887095190825001, 0.14355018344377318, 0.11837720074841093, 0.19212291575968268, 0.13521844100567604, 0.207286185975517, 0.13239045807671163, 0.10560821576584732, 0.10868725336847768, 0.14096007081529788, 0.10461083823634733, 0.14507449923023102, 0.13021980923029686, 0.23486190385395483, 0.11092912540921282, 0.1576638825598263, 0.10656002638561111, 0.2683913046794553, 0.15197445398136494, 0.09053204208612443, 0.06741703968615302, 0.16363942965624795, 0.16697037995101946, 0.15883693171124305, 0.10652527663736575, 0.15385213548377638, 0.07984083311091508, 0.09349649591792016, 0.19342302825422059, 0.18201905873513993, 0.1368090540411011, 0.10185621588701203, 0.20315847359597686, 0.12554113407649342, 0.1820423937733135, 0.12778230131633822, 0.15001916777222388, 0.1127719882154657, 0.15298156848838254, 0.18372147464223448, 0.1706935366195056, 0.2297066990286112, 0.20556619601143947, 0.2083171717822552, 0.16857629942317165, 0.14388551544998923, 0.08196465866339785, 0.13923887043229996, 0.1179173258283446, 0.17475056972715164, 0.1797701003811052, 0.11058381893822264, 0.11960461915981387, 0.11007653849740183, 0.12703525833785534, 0.1096248607181253, 0.12146894008882585, 0.19853073562825882, 0.20156320274597217, 0.20604841771625704, 0.12088293645290599, 0.10799310110028713, 0.07224076592753972, 0.14017057124405138], [0.03543482620208975, 0.054692552920671246, 0.11675353101905316, 0.050478142370740255, 0.025492646288306966, 0.03653588607126186, 0.07324666235475771, 0.06292494141586846, 0.009379976714450506, 0.04615378288191654, 0.06426024798964781, 0.0415492573783042, 0.03602431936850471, 0.0077318735683577205, 0.03273677944596256, 0.030146385280175075, 0.058118712622672326, 0.030786997578557462, 0.0386438152993158, 0.029391886350969156, 0.06867468026616881, 0.016246051227133122, 0.07824268943119435, 0.045188722771502314, 0.05621387330334514, 0.0810255114770224, 0.006540518267185338, 0.046893831477650715, 0.04180707660834155, 0.03584143119834123, 0.03512777816203814, 0.03557175675767564, 0.026204642659473806, 0.062092655834050915, 0.05263828432127353, 0.030992485342487216, 0.09368283148374289, 0.023980731550123424, 0.02431367527723553, 0.05867030358903351, 0.036593944044603456, 0.05896360035084429, 0.036308338805552454, 0.037643189557016864, 0.027988761843692873, 0.11342868644503817, 0.019961717470939604, 0.03950679419381965, 0.04412441597049756, 0.06706070154905319, 0.019208599415217197, 0.05082549812692789, 0.037085247721763394, 0.022006365921228163, 0.06176200845549184, 0.00673908538432912, 0.019759899268167156, 0.0647364367520617, 0.022317807475525527, 0.037795989623954224, 0.0511573329417696, 0.03234847245978252, 0.01829359165933584, 0.05987741684000339, 0.060539374263176036, 0.013646010099159134, 0.057003288604919954, 0.007751327413584918, 0.06034614390603477, 0.024712634716002692, 0.05958304755509861, 0.06892364351980149, 0.04255693495994614, 0.03279276132102936, 0.02645728121992321, 0.01222771896620191, 0.016451849256672205, 0.04415711643354547, 0.08473576722486366, 0.07535607779338475, 0.019906122470274568, 0.057531812663881056, 0.00847362766733333, 0.0942801349165459, 0.021338229998946193, 0.049508746202674606, 0.012914289836771788, 0.06189027455665412, 0.07128896296865518, 0.028565112771766803, 0.1101980017377965, 0.03679364018382565, 0.02227951648585018, 0.07155369997264878, 0.07671108048769736, 0.02620159362953517, 0.018519401820676944, 0.02188696728778943, 0.025981272488171538, 0.08057276883553113, 0.04036549065682677, 0.02508660819711945, 0.026796119993612654, 0.025900542142710863, 0.035708491960840846, 0.06158526814092071, 0.020359441592928865, 0.03011077559823471, 0.024700164719815218, 0.015919743736665097, 0.04239840455533516, 0.05315728590733582, 0.12627891505197172, 0.038405745815966404, 0.04222441066597258, 0.051610914449537956, 0.01982174937673394, 0.042252104744435325, 0.05321013831323194, 0.06000305142914576, 0.03792313340630743, 0.06114439986225578, 0.04434478499235646, 0.028814907230797316, 0.034640366211533546, 0.019793381140897834, 0.0450162802101864, 0.012016877205291343, 0.007647546440092547, 0.017987384400781126, 0.06851001732772397, 0.03323761325690054, 0.03121412798552023, 0.003607689023708865, 0.04535499449458815, 0.008103112115584796, 0.09848490041951019, 0.026163486500961647, 0.0400224594669717, 0.010818910086527469, 0.06432878604579358, 0.029259964095188246, 0.012970207551974925, 0.04640798234651166, 0.03223791448098998, 0.036907955823886784, 0.06826262455433607, 0.025813474334896575, 0.01881932332781294, 0.030727485953379544, 0.042218389214887735, 0.02086143219663251, 0.01661180650004216, 0.049775383104720426, 0.04276277512432106, 0.0015131937459133746, 0.03401222390933864, 0.023854974386913162, 0.015499336708847795, 0.08967878867781932, 0.01879720828465877, 0.045299648472498504, 0.029168177185760393, 0.0338481700107936, 0.0580115752264617, 0.030720824818877928, 0.059330675210202896, 0.009179868802969015, 0.06571306862057218, 0.01294062793960855, 0.07520142762411026, 0.014292839201047056, 0.02574271079333079, 0.021754315333260645, 0.009901840596519893, 0.022684844030487924, 0.0627840616770329, 0.007097546542589103, 0.05868647953555469, 0.030306903682949565, 0.018853538729731115, 0.015456199255441467, 0.04938555926445031, 0.07187405495994514, 0.018867671136714278, 0.028677848355484106, 0.025472088318858898, 0.03930248620529329, 0.049059316891455845, 0.07119142465413579, 0.040070872393346606, 0.03619811024456736, 0.10624301920254385, 0.016069146203658274, 0.00907391788543112, 0.08318826195693786, 0.028766369815134717, 0.04419122266793444, 0.06498862523585558, 0.03744895945513441, 0.04132406200252233, 0.07820314397254298, 0.02776105561473918, 0.043313308889346744, 0.06399576379466923, 0.02971051764043589, 0.042550101455661564, 0.06606893944403817, 0.012233597733410857, 0.056453536249577045, 0.04083508340221259, 0.026382953454289707, 0.09669020922193605, 0.006231809252752893, 0.06743118166923523, 0.03134684505752258, 0.0654098586810212, 0.06167195098955305, 0.02420952753914941, 0.03508686906688156, 0.04231068365756543, 0.03622047618151673, 0.03823944344936359, 0.0492785137987906, 0.030054517931515173, 0.05739045795053244, 0.01448560607499413, 0.05931355697553485, 0.039364830440571236, 0.09077340574754823, 0.06661257841774533, 0.021386731025432388, 0.02342558593579358, 0.025514606198656465, 0.03184046232021384, 0.06914384783275666, 0.1807008512438305, 0.04357105917147091, 0.022961133640379678, 0.058404643449091145, 0.03112478298135102, 0.047956066010820295, 0.03871401959669687, 0.033823793093042995, 0.07415659094770109, 0.027424024808551037, 0.02864841142699363, 0.018669363531854846, 0.03164756712653945, 0.023118315730243925, 0.08943942450587788, 0.02144666591418847, 0.025249200782948927, 0.022598653393346938, 0.025231856552343217, 0.023614524285339063, 0.01829667516323107, 0.01911043482381971, 0.00676852805847903, 0.06291514698175654, 0.028452110972495812, 0.10689215614430367, 0.042259957145659194, 0.06150313202411898, 0.12532011004945925, 0.030745613508887833, 0.039227681549926924, 0.030463873183414824, 0.03799706472144012, 0.015344858909356258, 0.012611867052563017, 0.03418490395791108, 0.07592382555406901, 0.014393537628254103, 0.040433109407463384, 0.08048314420926957, 0.007079671796095828, 0.07006226467990107, 0.03071750765816579, 0.09413022683152268, 0.0521727709940845, 0.04369965086000101, 0.03000378567394951, 0.012501447927206756, 0.04126866235427799, 0.03841784234429079, 0.02288246981709475, 0.03401641824072407, 0.08049561612067685, 0.014503922279653771, 0.02160347070575001, 0.07930385144126993, 0.053050700094430685, 0.01393803898545523, 0.056803902731307095, 0.057968168684671965, 0.06023851621355261, 0.07852885391443007, 0.061896617764667164, 0.047048462494727106, 0.08980300217386215, 0.005869089603243817, 0.03714874108892776, 0.04338633622072878, 0.06549957523783369, 0.0340669110958134, 0.03851843351918844, 0.04799137883369, 0.024868767265410676, 0.04658440856503383, 0.029732353061497695, 0.03286368191061962, 0.0359177565382373, 0.01916520436474633, 0.039250242839296984, 0.029389371667357705, 0.021846180766700737, 0.027662575012072924, 0.060596244800235, 0.12941252109744858, 0.05224991987849917, 0.045456301961695, 0.028190197002503182, 0.03695490552232631, 0.005711628370092161, 0.047711546067148454, 0.041946864671885006, 0.041392404706247395, 0.04507139640589876, 0.010889463911523983, 0.010076796883837351, 0.0976898543716919, 0.0974611771262942, 0.039152827098845475, 0.05428846452325102, 0.05688322730542672, 0.024195875852338733, 0.09181982822596066, 0.012676853333569825, 0.03032568624363311, 0.019674863508572022, 0.004313318725419982, 0.10224777108599102, 0.05535410814768365, 0.06744042835048131, 0.07664058507690508, 0.023746670621837822, 0.05250491990497517, 0.059345449215822646, 0.07609508450954192, 0.05699854269022903, 0.03668385212339702, 0.14752161388676013, 0.21719715738248443, 0.19659331458951199, 0.18267669925285926, 0.14687819196091545, 0.1417713426053524, 0.12777346832257125, 0.1319067961265964, 0.07405103169261448, 0.1314488594089785, 0.12232362608154937, 0.1108788317369838, 0.11898374320158076, 0.1832051773465449, 0.17781138209806335, 0.08534017995360398, 0.24498442278033306, 0.13157691866640123, 0.12802867519278682, 0.12867704604662236, 0.17502950234038217, 0.12545321782630298, 0.1649439701389882, 0.1559808027119406, 0.14970862637123755, 0.15933338732969377, 0.09379894743042608, 0.10463093272260121, 0.17732788868729146, 0.09067847979285064, 0.19215784936902985, 0.15795645153810903, 0.08487655120270868, 0.17103606985220987, 0.2145314625193996, 0.0627531155553316, 0.15847783565761583, 0.07300670063423534, 0.13824340046173142, 0.14893621056070253, 0.17693012051524656, 0.1171167639474715, 0.1802612393493614, 0.1340825317968284, 0.14497886081376385, 0.1674488171814911, 0.14245519865184061, 0.10422403278249888, 0.13081112185553198, 0.13119485529680408, 0.0947002039080666, 0.13281335393267293, 0.12986998284055343, 0.16029855086197778, 0.15731079263552544, 0.1266025105911878, 0.10568491648882629, 0.11285330078774884, 0.24106027528403268, 0.13767124003460332, 0.288504085112964, 0.16006481743627982, 0.1321511322091664, 0.14409269626823165, 0.08853333401343516, 0.11547548951761377, 0.14668342176704638, 0.08295799124865763, 0.18541865050792697, 0.09635485423308227, 0.13583659735177794, 0.24603788560676962, 0.07832072314716156, 0.1191862968487605, 0.20416088432313936, 0.10029622338592045, 0.17121700449816643, 0.1730596451389213, 0.15363370849480554, 0.16084765204258505, 0.12745183396844134, 0.2355906066875304, 0.1057604450972811, 0.17445510493651514, 0.14741993869744963, 0.21054604331091528, 0.16333975138202791, 0.24205862574519652, 0.2183447417712981, 0.10231435178749024, 0.21390193742850136, 0.10602478373555407, 0.11558954468778065, 0.21486198349345118, 0.15258199234883632, 0.11565993284626354, 0.09439814310040205, 0.08652006260930531, 0.13981570399576618, 0.14013729238462064, 0.08590112485352062, 0.11774586769001139, 0.10823788917473248, 0.1708188532821594, 0.14830193572467373, 0.17072264796062825, 0.1724180618240949, 0.08572397468191001, 0.1085617988099975, 0.16747737693930828, 0.09574897827640658, 0.17981306259189883, 0.27794705643769235, 0.13424105071012052, 0.14711187942133797, 0.10931054250367227, 0.14652758416148925, 0.16311901080752575, 0.24895651205893488, 0.09659075568760596, 0.16297550721754953, 0.1675043738777599, 0.20781651800197942, 0.2360697180753754, 0.2713241650452537, 0.09846898111244363, 0.06823019605250129, 0.17478366472548054, 0.1146765594040194, 0.09150460602775698, 0.28048884423990406, 0.12201566639686785, 0.09357234628330316, 0.1524230597480651, 0.1575074780492052, 0.16602567096631374, 0.20170967875709458, 0.14996120555987283, 0.10094184398410783, 0.1376851062260328, 0.1563549447324007, 0.10423521766619337, 0.09956313086853874, 0.23036161227332008, 0.11360559146851303, 0.12461638168221521, 0.21558301012602546, 0.14960597058938396, 0.06045536889183906, 0.14398507623662873, 0.1832149832719757, 0.12187269906843863, 0.2561857773652, 0.12887425240009062, 0.12490308242699794, 0.15097014335615022, 0.26372123269304154, 0.14103326285558362, 0.18496115812130515, 0.14425461661190758, 0.1752030059334732, 0.17363526828346715, 0.13436348688217903, 0.07999674732526464, 0.1209044175583028, 0.10477010791580524, 0.1970835802175345, 0.08867113790925472, 0.17914751604680093, 0.10447117274687176, 0.21795428207805081, 0.09849260726402845, 0.0992117263376713, 0.19344691487569965, 0.1102541100173708, 0.16012072653299378], [0.04466570688471679, 0.010686488915985871, 0.0835110837473504, 0.05641580641930623, 0.031771125617407026, 0.0045493710035037615, 0.052303377493855455, 0.008536739905755366, 0.03251491655265132, 0.04438863203470265, 0.022822699637242386, 0.017068155500436985, 0.029360419289479335, 0.07798022004745661, 0.03547954275423, 0.05342571162468484, 0.05319501956804626, 0.07686195384350515, 0.020015826261031534, 0.031990291881224805, 0.060888963165662946, 0.008590329671278596, 0.03232780723802505, 0.06289462348626507, 0.0495153843545385, 0.03245890403406755, 0.03212326942312141, 0.06517442454013132, 0.04870817666092227, 0.11416744801305956, 0.009714152885510797, 0.04068129125141329, 0.009458168436052098, 0.0740763049332365, 0.0415970076386246, 0.055066399997280496, 0.021034263547569997, 0.014786368363627024, 0.05123422901716925, 0.019637740802981203, 0.06704358714482478, 0.031190268177118514, 0.046694395808322776, 0.05257988926924525, 0.016435755664602886, 0.030458859137950406, 0.10313851683731041, 0.03782876286535494, 0.06766277770962446, 0.025324677680468848, 0.05580667841939196, 0.06579389855746301, 0.02006924557199161, 0.040106303959844575, 0.0517137962273292, 0.012800540144164717, 0.08589378573120603, 0.10600615247723558, 0.049424453548366026, 0.04980722937973277, 0.025065538863981926, 0.04927504725093323, 0.0329205907520748, 0.013850120820044992, 0.028525534754378662, 0.10732532523932958, 0.042981079539224025, 0.08500301699724891, 0.038442709558312936, 0.03130827636097468, 0.051751843984088594, 0.0394036251330568, 0.05867247161785922, 0.00258523432421498, 0.02387615863323933, 0.010967524440568543, 0.07046983111649752, 0.04476960755944733, 0.029049977479923158, 0.05898753676803843, 0.06808557397415561, 0.012351384709378885, 0.018572445748554125, 0.05683819665723751, 0.13092707692375108, 0.006618888104229325, 0.06360929158906783, 0.14250615882056375, 0.006349906973135208, 0.003201418233314349, 0.05954400005359804, 0.09924946382882134, 0.05397935953712272, 0.04047007314980992, 0.010626764701408966, 0.034591972437356754, 0.0240060162820643, 0.03674164579640474, 0.019796416764297796, 0.025401801667025974, 0.06796142176514672, 0.025393277023648544, 0.02508652584266759, 0.029499115677730694, 0.07301582474141352, 0.04650893358273372, 0.04661221372624559, 0.041967909107165, 0.051004946562311346, 0.03424991417916552, 0.02320789247601023, 0.02490598764721184, 0.033193210800809246, 0.10203395594632435, 0.03130471405212677, 0.01635139980804055, 0.03503142728380138, 0.031624452338644096, 0.03194174105902353, 0.02786245309717713, 0.005400904544418859, 0.024715040232084935, 0.0725700535000332, 0.05553714570499236, 0.05650408273082107, 0.04529815077060654, 0.07158216779991504, 0.04162187485264675, 0.03698143897758376, 0.03596811149750025, 0.020090311074689515, 0.0360260890316098, 0.037563968404767015, 0.07789077928229686, 0.03402461155107425, 0.02687674117154412, 0.054794277905696825, 0.061076501489526806, 0.07508001034899105, 0.06849350813295572, 0.04188403780121477, 0.08808876553009595, 0.09421499446034433, 0.025557018741364443, 0.023342112995563977, 0.026477649582610018, 0.04613344707796651, 0.05593903926050952, 0.023695030550081885, 0.1120540182737093, 0.03864587990627174, 0.05035842581081295, 0.015020367047268779, 0.1113213241220482, 0.04437980670181494, 0.028513076249510053, 0.04192743668212526, 0.023359890065846906, 0.061774089662057746, 0.026684638878871358, 0.018697337232409947, 0.029311341781830116, 0.03960538587923493, 0.02733154458955171, 0.018344540336740114, 0.00852105904355525, 0.029071054473939924, 0.009890588680132022, 0.05009580320949036, 0.0195576501409373, 0.04790045185795715, 0.040044021011600574, 0.056529769658922195, 0.021666715094338984, 0.018750789102106806, 0.04089649684066254, 0.07901312107400549, 0.017569069750607014, 0.06799893709079874, 0.04652348542285543, 0.024607312948172613, 0.01835706395908229, 0.01201282268495209, 0.0958039833893699, 0.04885169174221735, 0.07451143521334856, 0.018125812658258987, 0.04148842616667671, 0.021982146051502036, 0.09060224638350549, 0.048103637527674444, 0.033025931672102986, 0.07424320484842024, 0.050463081082148906, 0.03707945992749545, 0.010500634070335618, 0.013735311053272699, 0.021826065213028944, 0.021884720734951478, 0.02342820787171443, 0.02879916220873354, 0.01633287580203145, 0.06992718805709193, 0.06993419010071986, 0.021050541000741146, 0.07853348108549273, 0.05139064884954884, 0.03387884034084217, 0.04157704721775748, 0.027984136587850032, 0.007534464680394459, 0.04177012052687426, 0.053190338770828904, 0.05130803775823405, 0.05038851774447868, 0.01960356945111867, 0.008459060505453137, 0.019368815213261593, 0.019602393506154902, 0.02859955033918302, 0.03067107506907515, 0.06124475738033653, 0.014077719796689288, 0.0683332885044717, 0.09934311041668539, 0.05095972439214107, 0.05380505921259042, 0.07672995689415163, 0.05603719044536833, 0.02700023071449851, 0.02997868863355008, 0.02555720451768608, 0.05868384802353479, 0.02686335570028713, 0.06411347703467454, 0.03596222411180216, 0.04032140612722405, 0.05176930312788294, 0.021458798831689264, 0.04692676559751553, 0.056195843424047195, 0.0311290922259251, 0.07115262230077098, 0.06543731527222742, 0.062288326181231014, 0.005387279670685531, 0.01713334192191401, 0.02106453742711775, 0.05538581269643, 0.06460432488951953, 0.04379913120740845, 0.01271417905246058, 0.04297469802681477, 0.017068864131766944, 0.005622031993322796, 0.03885683370754123, 0.019930451507529905, 0.01939786909778993, 0.02434027959562598, 0.041874519158755584, 0.036810379204971176, 0.02999034657653782, 0.05635243562620975, 0.06430604089532169, 0.029866416533026966, 0.022023604814744285, 0.03253623677958404, 0.030682256122330026, 0.0021188648937705665, 0.03481593058114091, 0.07619100637854108, 0.016555813133656498, 0.04082103718012091, 0.034390016338757934, 0.03468684859633927, 0.036659574797076565, 0.07396782688315838, 0.018478647858325033, 0.0303737027195072, 0.06395209678298523, 0.08824435798751731, 0.013605177612794984, 0.010429482696758164, 0.01995162426253721, 0.08657840786561852, 0.02444434306404043, 0.08948863033325442, 0.02799612777908483, 0.01582385442640272, 0.029648043170210817, 0.030375548991404717, 0.027861506978590644, 0.06640254009154535, 0.024590091291634787, 0.01866579739256732, 0.01690682695968257, 0.032160106760960434, 0.004822727933060378, 0.08928441427527897, 0.010977954727657621, 0.01582632218712881, 0.0779520126900846, 0.0536160959651874, 0.0856101646598789, 0.0291881337761879, 0.03477054753250653, 0.046261893209790995, 0.056140654449982036, 0.033231653092849645, 0.07636685420068041, 0.041575894255431435, 0.014784446440546986, 0.058380875571240345, 0.030939703799724102, 0.06712145998232788, 0.045169666334385836, 0.03229501484442623, 0.031065884226512526, 0.08062015137364788, 0.026430092759490497, 0.018297678738411878, 0.038351813226097056, 0.024278431402279005, 0.029799906694660747, 0.021028688342701045, 0.057080318745706356, 0.031000655670199665, 0.05186829700945847, 0.05490608077736632, 0.03226260932522916, 0.03942016114090239, 0.012094181222510676, 0.05536069650383246, 0.09416342142128176, 0.029651756781423767, 0.031981717442132296, 0.045770834680766835, 0.018764982796123913, 0.024021485512475335, 0.05032673658382508, 0.026277652753877546, 0.010216583032160997, 0.03707869767001079, 0.0526073879952873, 0.0142003896255647, 0.020905606741566333, 0.07216490024039823, 0.03094620405576162, 0.05196170611006599, 0.01716185188401611, 0.06829846214743392, 0.05533361146526952, 0.2499064304415257, 0.13492628571487245, 0.2437436820999269, 0.09131366627350931, 0.1087194750265729, 0.0900656860622187, 0.138006434144993, 0.17702886924868633, 0.1372602645067438, 0.16017504216682527, 0.09537355688911292, 0.14836899906156525, 0.13923081118733655, 0.19641268637872514, 0.0969272674692254, 0.24200129172494336, 0.1680681533029964, 0.15611682928377585, 0.08516950322495354, 0.15891576215865152, 0.07308647336979067, 0.0811713363134092, 0.12732711485436848, 0.24947907595384508, 0.10981540976753158, 0.13542039710427486, 0.16612290284566342, 0.1800718164492038, 0.23764986634975482, 0.16858225958722253, 0.1571158692240715, 0.08740485585745304, 0.2599704049287304, 0.20025991864742773, 0.14097295641418428, 0.18165695961684952, 0.07551500273327674, 0.1364840029348289, 0.1943951018995816, 0.08619448290236535, 0.18234568798253614, 0.16697339833744113, 0.07826857554215579, 0.09574476479282303, 0.10065653751934729, 0.1446802550626378, 0.16327654912827477, 0.19657912664115432, 0.15870277439394306, 0.23378627044298958, 0.1720073620878881, 0.13453818557243194, 0.0885764724244514, 0.12216395037549159, 0.06630084958047637, 0.1241890118727761, 0.2026719464770248, 0.21061483800651568, 0.13951648537430072, 0.17173343968968238, 0.11751122261968353, 0.11588075002955815, 0.09277238195101101, 0.12842365480478735, 0.11046850738385994, 0.22403680569221898, 0.1876899633075922, 0.18615593352625448, 0.1868189213376853, 0.07657300080022506, 0.11908972380502571, 0.10526543738500727, 0.1409068277045604, 0.1073241301421677, 0.15045375412990972, 0.1258683149071951, 0.19261108230679266, 0.21819785207269654, 0.1760200540264768, 0.173191458227173, 0.17204650918081885, 0.07809385386926514, 0.110895655027801, 0.16490470047198957, 0.33161623463515316, 0.16309880140808322, 0.1735515348733433, 0.20996741710170624, 0.09164722095574103, 0.09811959139281705, 0.18287715381912648, 0.2217707482557143, 0.16195792794948624, 0.1405801524918887, 0.15349685454801207, 0.1110096795544509, 0.07727529658305068, 0.119101659454886, 0.18242387491608822, 0.0910575707413016, 0.17128164699721724, 0.11368112007696783, 0.11852403682085777, 0.1189715624035847, 0.38822188913341493, 0.08608457992874807, 0.13855363542754806, 0.14262671041632854, 0.1671797517807253, 0.09462849807835395, 0.12065782151635616, 0.2206885877756342, 0.22588315419852736, 0.17879749047419718, 0.11640928941027773, 0.06630892414719829, 0.28508534114206996, 0.19083348253080923, 0.1296337519682223, 0.17181907299785845, 0.11677905706869018, 0.09672760963439943, 0.18398871675374048, 0.11446218502016799, 0.07084978774430291, 0.16084256521876783, 0.1560585453144966, 0.17761092753179614, 0.213639858749605, 0.13013272035506465, 0.21462918469502082, 0.15215014858591944, 0.1259012949923354, 0.15716618587893827, 0.1563949498438066, 0.1125098099451392, 0.14062179703145258, 0.10146930318085418, 0.20492151770139896, 0.13986736896537966, 0.2339731039659631, 0.14922104205095, 0.22433250030923277, 0.08677598194129045, 0.13970057630250532, 0.09013236635514806, 0.21413234603260795, 0.1650122285730416, 0.13778929418373492, 0.1744308812363494, 0.1290295077788253, 0.18940261414935514, 0.16883842406734345, 0.26350568619466597, 0.11826042596611286, 0.1434340291926938, 0.2219714479701173, 0.12546441803175595, 0.1629454918926762, 0.1052012468778318, 0.1622234233805249, 0.1289181492381519, 0.15175205865694633, 0.12417288572197, 0.12304472166203684, 0.12829170382070926, 0.22816497772451372, 0.16167734058633929, 0.11959335000644769, 0.18907889603607117, 0.1596663138198276, 0.09886753835505056, 0.12188478793588378, 0.09938912165741767, 0.1649885717779398, 0.14619553101158914], [0.05622697340685034, 0.030165200399595405, 0.06028430528878685, 0.034570024018326116, 0.014495864949910151, 0.05300157853672582, 0.030506105695460594, 0.06422133072309437, 0.08183263107052735, 0.08959310174348856, 0.06190209912376539, 0.011174513736829884, 0.013269204007942351, 0.0402934783919444, 0.026819294153322137, 0.06015429250715722, 0.1071049600479103, 0.05884344712080014, 0.02644572669880525, 0.015288402059776409, 0.01498333435700906, 0.025739508545807293, 0.033406535644204385, 0.037877811644707, 0.016048617920117275, 0.018825967225336263, 0.057365694158380075, 0.0752933351923862, 0.05154765856963012, 0.050686767264719934, 0.08105653803795576, 0.05900058707582855, 0.0677471699553632, 0.025645664690302748, 0.020264236016138908, 0.07586718101294772, 0.05537478486075998, 0.01878409094417528, 0.012882453137858501, 0.11999900122323345, 0.08826134981767786, 0.0710823796989937, 0.04108521110949017, 0.05266050853195691, 0.09407944286302214, 0.02989029932406641, 0.017912981941575007, 0.01750797806908527, 0.04211951407694048, 0.0514859463568897, 0.028677672155261524, 0.036274247892921975, 0.08278972769696867, 0.03765711320504066, 0.05947509044480901, 0.011364073575203939, 0.019947625283572464, 0.04093381681389386, 0.008482111133484831, 0.011431694241060365, 0.04912659856340578, 0.023017519626826532, 0.06777592889604069, 0.04355948741337465, 0.02936117580130456, 0.015812865852738823, 0.00724888002995642, 0.04982688336543018, 0.01885974978757722, 0.026367329091074008, 0.04433830005807742, 0.026536617285361695, 0.04994337852563589, 0.07099187407161921, 0.02328197700872777, 0.06243564871950977, 0.06811771902345842, 0.043623854120772694, 0.03222370354999458, 0.051000380678282636, 0.020482302943785346, 0.012318707228968702, 0.029202494094328537, 0.03896531558805897, 0.014287246759199809, 0.05354512557988206, 0.07406919563729918, 0.056712512272380056, 0.0010380339353427952, 0.042860742448078054, 0.06875362562676592, 0.058047477937033104, 0.08911617370622774, 0.08609550434254831, 0.02548985389782296, 0.022327193967817772, 0.06607627856635279, 0.008473365282219265, 0.015790954780494495, 0.026009092971141783, 0.05345770345640279, 0.017655982425616636, 0.015748343054926204, 0.02020297004961439, 0.01470940429792409, 0.019128068252616835, 0.02343766522713967, 0.008967888443880986, 0.030269922703624736, 0.039197700699010206, 0.046234080387699994, 0.04883644276208455, 0.018541288952673637, 0.054842882354052803, 0.020928085676484534, 0.006675264514577125, 0.04315149579798022, 0.054167016604614836, 0.043527863303860354, 0.021316632065140916, 0.02681444098632182, 0.035815947283540046, 0.03982500413492803, 0.09245552032464936, 0.04075108952219448, 0.03359487452994912, 0.045096642833443425, 0.017254581081590826, 0.03325200804899777, 0.07909995714022268, 0.057778822393306804, 0.039924902000254205, 0.04099840185635033, 0.06555960588758031, 0.04027873119940201, 0.03890094121978168, 0.03670044941827655, 0.06636630413272689, 0.04273827563250258, 0.02366797807025573, 0.020122163095361283, 0.032296677255221916, 0.047203645095108986, 0.02578653293781944, 0.039136896300460064, 0.03068500637797819, 0.025037245321718436, 0.04740870001936152, 0.05437574875090392, 0.02823184537250669, 0.004328115234872507, 0.005906276947503249, 0.0719314272845945, 0.038056578261837844, 0.06223088490866846, 0.022029835024788495, 0.023294305278649254, 0.07984867785125971, 0.042195383594521595, 0.002854689472212246, 0.05547600422775554, 0.035170223263482896, 0.014770515131643944, 0.12314998214283299, 0.012828677596013634, 0.04076474503944478, 0.029934671136640736, 0.027327712234710495, 0.042502247773471384, 0.03963560804784779, 0.04440881845150744, 0.05127585057409541, 0.059120058487620086, 0.06951943775939365, 0.051760416507961295, 0.021905885829079538, 0.06628103854675448, 0.01602579424563315, 0.04460110269006222, 0.04689678857703844, 0.11678608209495583, 0.026782280615260525, 0.1135732472363499, 0.11940104661569481, 0.026493632091930317, 0.05301488548397057, 0.02958113496612397, 0.0176856855696608, 0.015593112574049063, 0.032968191625249964, 0.0028759081924950047, 0.04984266860710998, 0.029020061746480006, 0.06623419993106397, 0.022262511249150962, 0.04955043670751395, 0.09706742325497252, 0.009890991833902175, 0.04703663792761584, 0.010150484008444174, 0.006941047707392324, 0.0351191443511315, 0.03214606436930838, 0.01364512526760659, 0.014302110780150661, 0.01452371799161718, 0.025782533958854697, 0.059855671434272686, 0.052211232438323, 0.020629926171574383, 0.07328028595375438, 0.06482200111232458, 0.06654230517245109, 0.02357684999644276, 0.01868748342648389, 0.036061639341736035, 0.027355906185543826, 0.1167042868872804, 0.053884985165730606, 0.018348769142082142, 0.06456293315897066, 0.04128344402077698, 0.028181961557317167, 0.04386494199054376, 0.027211927621054555, 0.04862276551824424, 0.055171740917308684, 0.059838465099493345, 0.01842302604458265, 0.023694256801278363, 0.028409843986493447, 0.009725387564920371, 0.02607641103226812, 0.10791858372789238, 0.06284711071320119, 0.04992911396848579, 0.02774780803930856, 0.035085873152579994, 0.039910078198919376, 0.031418317230418324, 0.07168476995561393, 0.0351588047229715, 0.025744752417648994, 0.03768252434148904, 0.021670892188746124, 0.06135969355161633, 0.11797991521175831, 0.056253414931556875, 0.0492467288108122, 0.010973522909015659, 0.06661656973583084, 0.06914655212312937, 0.06013919674460927, 0.012275771831252403, 0.03856080584228039, 0.011202234628369973, 0.03003966923232281, 0.05458253886430495, 0.017096537142811764, 0.009361343540912195, 0.021060479076338873, 0.03783918549156478, 0.061071989231652794, 0.012394008883875946, 0.09169058919313455, 0.06074913296728365, 0.011188273633559866, 0.04192264097171926, 0.012515250916382479, 0.039627977812121955, 0.016151125272435528, 0.08048836892891316, 0.0623134691869059, 0.07513807215277227, 0.05787888879797632, 0.02776904016612999, 0.07031566358261532, 0.08412583100218927, 0.061531377685887206, 0.04972137007561903, 0.01509400724899024, 0.01228091515405404, 0.010997196941095735, 0.009158078389572761, 0.04726490148553445, 0.03179827002778409, 0.025077943742695837, 0.0447807886127022, 0.07075838579405701, 0.06083453261864282, 0.02277586868243112, 0.00659294693069833, 0.04180030439109091, 0.015216663671326975, 0.047153087122546095, 0.007067008362707472, 0.06603541543647166, 0.03478655110924475, 0.02189098350373247, 0.04483281364364009, 0.02176047659539167, 0.008397410537356572, 0.031355589951178243, 0.015185110424945672, 0.03789548146268053, 0.001091915652185919, 0.00999146426517156, 0.03359035078075624, 0.05012007287493156, 0.048921919022236145, 0.010742608686879037, 0.038563192206164526, 0.03158008052606977, 0.044130632774003094, 0.054944025112255934, 0.0292190607456911, 0.0019132067949789006, 0.019668445606986364, 0.025730003309886784, 0.034565768399906736, 0.07094860542565584, 0.011528894519283166, 0.06739129913189719, 0.06706648551288151, 0.029867688238981272, 0.021295872997612725, 0.018420279619374105, 0.042924366050189545, 0.04010155804515366, 0.038645431744836034, 0.011141215725201032, 0.04250003760980983, 0.046826959662740274, 0.05560576420037016, 0.002199258639349512, 0.02331963406064578, 0.045383224834597884, 0.005187486334057946, 0.03093251789499435, 0.07215165458018742, 0.019467006617736433, 0.043256204695470875, 0.044640778383660706, 0.027382152357829675, 0.014321049431248779, 0.02238703692602294, 0.1373667507282188, 0.026889377791855126, 0.04469662236290113, 0.03982738283793292, 0.06450100261117182, 0.06084051193489183, 0.15035661418111096, 0.1108063828019846, 0.23355370147093651, 0.20830696749110378, 0.21284832138447993, 0.14436418250683816, 0.17006165197780057, 0.1816862701408325, 0.1679291083447395, 0.10162391504573245, 0.2382989113609637, 0.11727861534323424, 0.1120866995845591, 0.17782123398876962, 0.14196476448447476, 0.13584756773085366, 0.1599036172152527, 0.14913775297182222, 0.08586959267455725, 0.08189529706273349, 0.12462599608566492, 0.11502488426143125, 0.12578372347859607, 0.19579878948148222, 0.10820887742503997, 0.11505917435692203, 0.3044692042373842, 0.2195482812221012, 0.09176233332724341, 0.08683295590021918, 0.08145150232819781, 0.13517783834568917, 0.19334214469117506, 0.1178496726037514, 0.23326245016388356, 0.1995608787382803, 0.1549715278369765, 0.2537974063307047, 0.11143075978203167, 0.2052269569568096, 0.2366320112900388, 0.14127643448450874, 0.166249000918, 0.13508907939878204, 0.21624183041914818, 0.11732658776905268, 0.1136442635869307, 0.11531820400587975, 0.07812125683431664, 0.11261414345954696, 0.1258320712874974, 0.11103938078327526, 0.11626275211212136, 0.12113481084065092, 0.11670658515105325, 0.09696144265152755, 0.07271644524148396, 0.13149366023079043, 0.13984323719576483, 0.11233980737386212, 0.16252786672163397, 0.10701866024324011, 0.1775017446808277, 0.17113746924986764, 0.1458349181038718, 0.13927005021081817, 0.11787160570102355, 0.1056353276174876, 0.058837559735102046, 0.19127968278142715, 0.3299775725651172, 0.14825020946802633, 0.17500321020282086, 0.12801302401649375, 0.24368919792675206, 0.18129607091747946, 0.13869788978369008, 0.1005431794891915, 0.20739858639576744, 0.08115559320656524, 0.23810673054427872, 0.132024880919245, 0.10517927547616344, 0.0967708093324496, 0.10975623713626016, 0.17097361836462252, 0.15333836627823694, 0.1501172117047733, 0.10982139291422022, 0.13859964666828034, 0.16414815800324564, 0.1042827917262912, 0.18015456926678458, 0.141446506003699, 0.06911316601138923, 0.21522486402142435, 0.16807362317077576, 0.22238512012747028, 0.08830616596124827, 0.1494631411567811, 0.24241781372937465, 0.1262701433452387, 0.1670281583022687, 0.3116846799610123, 0.10579449004463612, 0.2336767964786099, 0.10213145595644751, 0.13819334427675894, 0.1794168265957025, 0.1577320490633288, 0.0671268685630733, 0.151785398803411, 0.16578898044122806, 0.20201177786915533, 0.09124788996433059, 0.12301989275241092, 0.16171815775094495, 0.21909849567999765, 0.13030907379523402, 0.13464292511343956, 0.11927730809416502, 0.0687909724130746, 0.09877365427992998, 0.25548117565772227, 0.12019796191804832, 0.07234019647923208, 0.11965087554868191, 0.16049843852318105, 0.10931376773383349, 0.1620483722898268, 0.1519145612274447, 0.11252348461458761, 0.10878830802656951, 0.16430794862249207, 0.13090516680911665, 0.11409450112090957, 0.14263847752684547, 0.1885913423593006, 0.18386804258390782, 0.1733730976740199, 0.1450490651111449, 0.07609432608249687, 0.10504546289842938, 0.08457888007885025, 0.15927179386058163, 0.06477743011688994, 0.10461528154630816, 0.151050245509513, 0.11529704465741113, 0.10229232675966718, 0.1206605487893666, 0.17652338911448756, 0.1619821669714105, 0.15526454114625532, 0.17276359812146233, 0.12533139452458392, 0.10152003352320003, 0.1257134655550603, 0.11925536733601363, 0.08897910525481548, 0.1302607336472119, 0.0888152237260534, 0.12253765572583485, 0.22916375719491514, 0.09342103625737852, 0.16366561454149986, 0.18167900762731032, 0.12931584080140437, 0.07999150728386256, 0.11749328084049687, 0.1538532692939043, 0.18357020292070605, 0.16391410282061947, 0.2591391995308861, 0.2587690871329077, 0.1860122613969349], [0.05938790197814665, 0.03603257396588883, 0.08642781030146346, 0.03317371386313631, 0.09893440250908175, 0.02774117180266448, 0.026303567593136144, 0.08180365762523106, 0.001997222580323597, 0.03000971327926363, 0.010540672698088232, 0.029479551707364382, 0.022265989288327195, 0.06585344657181733, 0.023637234961854357, 0.09656183586846437, 0.046701811539429816, 0.014826423270748028, 0.023319632145425966, 0.009244520878118855, 0.0413089509182159, 0.01689227128912124, 0.041518889652985724, 0.050064523839541984, 0.045244681663931384, 0.026248018557746566, 0.08091763863640447, 0.015326337776176873, 0.032951510060698755, 0.024837160392874674, 0.041919274015292045, 0.07005321718151532, 0.029198068021346005, 0.09955048275690886, 0.026192327796090997, 0.02206021807186546, 0.03153907950036228, 0.012400991775305762, 0.05267639336506686, 0.048714033403103395, 0.043948637096271406, 0.016380767788617842, 0.05446538486848435, 0.04945318950640579, 0.034777040127664804, 0.021785541077054316, 0.08596457991628878, 0.008799984953516434, 0.013312205480742119, 0.03320233490798743, 0.030467529338033452, 0.04719204269349576, 0.022033274759568518, 0.059343334813151634, 0.02365750564833082, 0.034188822497643774, 0.04502110656410937, 0.03062772023822031, 0.07039529076146503, 0.08212303968086358, 0.015450521586312643, 0.023559432987484242, 0.05034258694297845, 0.04059648148775582, 0.01578755143489088, 0.03041986334738472, 0.03746989280766538, 0.05216684147355057, 0.011447568540461363, 0.05585139880197183, 0.06711541554860531, 0.049635369045239304, 0.032161642767248616, 0.030752958376861872, 0.05178046119850009, 0.008972479225767237, 0.018638411664494106, 0.055588067569319284, 0.03562551697776203, 0.029604295719294783, 0.03608495522771151, 0.017044374216047507, 0.04431197727699915, 0.06635396245626674, 0.07953328711371269, 0.06399270327341172, 0.011745095065224075, 0.09990433876913402, 0.018141678339170835, 0.09079550738416373, 0.04941776943122668, 0.08522507524298084, 0.028566231260136254, 0.008359201902133084, 0.011976357857366244, 0.026024895449799877, 0.10337589684152797, 0.00864863758080549, 0.06087947516672074, 0.01293392179744138, 0.0006834336806693295, 0.05684748164287979, 0.02983050424635651, 0.07170601357375422, 0.0347272482430262, 0.08134018209192061, 0.04666297088166879, 0.03733314611318131, 0.050138604541819905, 0.03432406382935663, 0.06187543926400043, 0.038829989986674446, 0.025199717248699842, 0.0387458467195111, 0.03826509590350813, 0.045582334916558, 0.023594617490626635, 0.04396068765932033, 0.03960818210015855, 0.07677010756226317, 0.03564127157592485, 0.05928568286640991, 0.036624258143767234, 0.05633873414368399, 0.03781185147442645, 0.07273267098372022, 0.012410610009195104, 0.01721274502004587, 0.023335158832431323, 0.028896411325061516, 0.032658814677908536, 0.052005185430208524, 0.044098510707338015, 0.04284973376460614, 0.036282464185909885, 0.034774443089601495, 0.02262804627178177, 0.06214481493037555, 0.017337935278192163, 0.12611649675114503, 0.08639453144203271, 0.0694606175285674, 0.04110261662712982, 0.04602220345048174, 0.07622695122394832, 0.01714890499809577, 0.0659553132831089, 0.008295476793371623, 0.042043100636933124, 0.047235694383421255, 0.04913312180208103, 0.03401124331679556, 0.017415164601838878, 0.038078951859666456, 0.052795489393775506, 0.02992717113586203, 0.10283193611089261, 0.035186138740109826, 0.025715303997839653, 0.03416932939041046, 0.053145082126702034, 0.09037094911740673, 0.01262153029411791, 0.055089543513473005, 0.05540688394478733, 0.012638901337800969, 0.031264825769129305, 0.060947469300440246, 0.005704881050699061, 0.0432668226741014, 0.05041110201648647, 0.10444127999606634, 0.013875052193930794, 0.031002622600945256, 0.02260854741888902, 0.013313034770920152, 0.03684341674670577, 0.02465147217134795, 0.03745462084489484, 0.02149965238547133, 0.01668889026698326, 0.008740831474443118, 0.010169346050749864, 0.05254392910207953, 0.014154391791371089, 0.0389727121669679, 0.0208777709368376, 0.049131367460734425, 0.09719673123571182, 0.018524097939652782, 0.030484178343847878, 0.08696231750711318, 0.0808102407702996, 0.058777605694147854, 0.03211062322671135, 0.03723346275247393, 0.03412546702630578, 0.019162996116304593, 0.04017871842088719, 0.0561865009818106, 0.04579580531665876, 0.023563583268814033, 0.03434012486268917, 0.05628214705915702, 0.046671934110382875, 0.054661752355675546, 0.0738095990832775, 0.0335929018535441, 0.019783069597437017, 0.014026326788288933, 0.05912318795679077, 0.04156545247702349, 0.017231382024023804, 0.05731473782009656, 0.0014125426006954044, 0.02178250928409398, 0.10979418913202901, 0.06564626575357492, 0.07009870748245908, 0.045431898230867046, 0.020478618060869556, 0.03610678107267426, 0.0022741415793256416, 0.014970940012004108, 0.054867803194229646, 0.09831836056565085, 0.06720992015494455, 0.07189761982449601, 0.04426653677177045, 0.019194451686475548, 0.03804833515577259, 0.023226261349214662, 0.004361470224290726, 0.0357871079036305, 0.01916534417579251, 0.09872084783930933, 0.02456406345440736, 0.02722734322531089, 0.03532855448523357, 0.021322596059631438, 0.041855562313069264, 0.03688784601587442, 0.06469981008840185, 0.11145314487117915, 0.06552124020433234, 0.10708599937178435, 0.015862788929934465, 0.034990518188644806, 0.022313105610890255, 0.042330479369528835, 0.01822538685143715, 0.017817517810110605, 0.03973370177611228, 0.013931830800438841, 0.01669107361756746, 0.016036639177811243, 0.006949720301500132, 0.04044173938793041, 0.05621207299672308, 0.04185501072976378, 0.06840722365004402, 0.014287546491100183, 0.016730532891327338, 0.019044465077440106, 0.05144872597508854, 0.043560376075366815, 0.035122909673279336, 0.12938314928643166, 0.039500960434276255, 0.024118698239626906, 0.001247690175190538, 0.05584183036379757, 0.03377729155603917, 0.01041733349988898, 0.05422563382214116, 0.03636188835145966, 0.032766798601275494, 0.03112797756799527, 0.03161944020839949, 0.043283772369426106, 0.09773513016801688, 0.015887036570347846, 0.08175180879451575, 0.030569867193398458, 0.07410099594703606, 0.07808845294939895, 0.0775273624927767, 0.0173255208233792, 0.03699561543462258, 0.04972526946315362, 0.00845620108227576, 0.02640193711305338, 0.04564315080642701, 0.06734452180324063, 0.07704556213631746, 0.017249850488658396, 0.021549587911595742, 0.03744034479642588, 0.041695296719309785, 0.017965612181973074, 0.02000317814940166, 0.05399487664802902, 0.03435973671355075, 0.04605303465899441, 0.01659998576337051, 0.028063034067951867, 0.06301640082270869, 0.05420168974406777, 0.031813419416486736, 0.03732915096465619, 0.023056233880080046, 0.037467950774777325, 0.029183671314028964, 0.020383743817106854, 0.021052184259338726, 0.08030872897154863, 0.06017361707504719, 0.048625891156975305, 0.018048479912742492, 0.028882895618857398, 0.021086560539721, 0.06986821460868083, 0.04405885799637726, 0.05180982917907739, 0.037909903067855105, 0.01960553446664445, 0.03252156619583407, 0.037913446224504904, 0.07823571037020415, 0.010962006692293911, 0.04889380359541505, 0.10184336859252184, 0.09856481871177113, 0.00860906530907678, 0.025852730595356515, 0.03235508762900868, 0.040138449009147384, 0.055340667135052146, 0.019374024611146703, 0.05953406389322012, 0.029679801345111865, 0.04070035534940901, 0.01715847152105022, 0.0515137400267826, 0.031660422081908876, 0.07674101920377824, 0.05610385541653922, 0.09054917947299058, 0.03040861143099685, 0.01166162116738457, 0.02221306601929809, 0.05473155445689636, 0.17579007443160782, 0.11496760386733279, 0.20529719189770762, 0.18507078530326967, 0.21738014514407805, 0.1728473315315862, 0.10371521250495028, 0.11759880179118727, 0.10990390058366523, 0.14488087816824838, 0.0928800326261309, 0.1746973725816896, 0.09687104427646245, 0.14158124554782145, 0.10305412459157168, 0.1567736883918124, 0.23285395676089873, 0.19640827371228128, 0.09554898336289391, 0.12634947174979796, 0.10538159929696592, 0.1870532523119642, 0.0986416649914557, 0.1713333272885892, 0.10367989585164095, 0.16553322964858624, 0.13710381403084726, 0.18609648510333032, 0.14233838556514633, 0.10323791674548581, 0.13146850190335704, 0.13635560659871948, 0.13903363547738523, 0.24447103661875574, 0.07183911368971871, 0.06764392428580793, 0.12875547812831017, 0.23508532573619198, 0.11924330911208546, 0.10467184181775778, 0.11420577539191132, 0.23051435488366315, 0.16106263163589662, 0.13568834401667118, 0.09494776522079784, 0.14180816079099334, 0.16189821905666785, 0.0955388863240519, 0.15896120649431983, 0.26645543113831555, 0.0999917647230529, 0.12677575371438457, 0.13276979417329834, 0.0928520244516192, 0.15969421474202988, 0.09228993808069537, 0.06708602075495067, 0.16752487439061367, 0.11782093664571164, 0.17569668831363802, 0.15782448523227247, 0.08791379870906954, 0.1320575775518533, 0.14008077041756722, 0.08241415309209017, 0.16381276470999565, 0.1203581738856531, 0.17296563082885358, 0.10284635388562757, 0.22398500282677913, 0.14911026573709904, 0.2124251344151074, 0.1713823109504677, 0.1697579747246158, 0.10621872655446492, 0.09209801007302539, 0.0854285941609452, 0.125658682607595, 0.10335945659467291, 0.11282547647433896, 0.12174590385609096, 0.07271511224849571, 0.11146848961230248, 0.1856907342951144, 0.2257580060752169, 0.16916597262024882, 0.12537706102575027, 0.2023117625785451, 0.09916560018375035, 0.2121569270328168, 0.1687768459199898, 0.1570513799426056, 0.12451763294877545, 0.12475892000140683, 0.0701552983974257, 0.1947142694505953, 0.17280426206848315, 0.10223725269879065, 0.17580957903016, 0.08025005429742799, 0.1531127687062948, 0.22626964555632686, 0.09300253774610259, 0.16388908238901248, 0.1835022202783054, 0.17455560035042225, 0.136594595387578, 0.11731413117940388, 0.15653404076733898, 0.11223745036629901, 0.15856120134553603, 0.10728038652169128, 0.1306767347118547, 0.16101024654363433, 0.11590874288231136, 0.17129814853110623, 0.096041317428312, 0.1584454914254527, 0.20788371923469728, 0.09780184110446323, 0.19034574499293683, 0.13722700096907156, 0.10401622377215855, 0.08488161504388818, 0.12914101953708357, 0.1893221595955472, 0.10581921170195265, 0.190996092353617, 0.07922679065696656, 0.19176875331228782, 0.19045904939693792, 0.10117167036139196, 0.12242535489701456, 0.1499227019807985, 0.17296506392378963, 0.1986490349255262, 0.06436263947116752, 0.18230937541492526, 0.1184643202671601, 0.26272234597033073, 0.2073427232643289, 0.19056965717144553, 0.2606925194061572, 0.18163506482397357, 0.1765948957613399, 0.14896965795947661, 0.21630533910807104, 0.1318921178819672, 0.12776597598267178, 0.0882516741271942, 0.14934026065372652, 0.12004151910303101, 0.16767907256801284, 0.11039726886778109, 0.22002008413114857, 0.3519277995632541, 0.21743360275943435, 0.1433008984332123, 0.08475656651200787, 0.25794538939672135, 0.10311390243230328, 0.2177367590728306, 0.09384080647460877, 0.13781030031461872, 0.1426151271669134, 0.10097637922773439, 0.09447191736751026, 0.11121715148610455, 0.1364544779062271, 0.17049199420838587, 0.14760617467184223, 0.19078750193359392, 0.1337829301314008, 0.08531426319912558, 0.10651940840386576, 0.1497089940934412], [0.06479509610442385, 0.06454685297344001, 0.025999369400162852, 0.018383842562475515, 0.01772845434325357, 0.03149287865286873, 0.04451202964710613, 0.04114607679507425, 0.0458417016442024, 0.06950243826835387, 0.02576879608715254, 0.08836929160620897, 0.02201700496727661, 0.05719327074926227, 0.05709919898260025, 0.058129686832187645, 0.012943860830649013, 0.004969090467409021, 0.009338829174427497, 0.05928998061966512, 0.042001115188242934, 0.03266480931591603, 0.03866040876375572, 0.07058305125082694, 0.01782703262213017, 0.11987478006631137, 0.041563606205125975, 0.09343552298002666, 0.07093560491358081, 0.006135762894466039, 0.04096147258796039, 0.030587605959285172, 0.024084164911220153, 0.015014324528766016, 0.03755980088645893, 0.019013507464419932, 0.053881602887544906, 0.060431673792341066, 0.02024752572329054, 0.046037498395890004, 0.06939121762350683, 0.09100507073585065, 0.03650832988862549, 0.04282922942131277, 0.025816373977689974, 0.028683486762606812, 0.03354687912149295, 0.05179912310033556, 0.02857318925370853, 0.012823213473893704, 0.02802666212852684, 0.13278767466545105, 0.04854391974907729, 0.025423164028794538, 0.025019590825503393, 0.020850904233333085, 0.08809459545919973, 0.035368663018509265, 0.026957410229970852, 0.04475082308354397, 0.03644557579630806, 0.09988250526329202, 0.055793440420060396, 0.03839504739810382, 0.04180998008157458, 0.06724699114960048, 0.09517477239452063, 0.04006143419011947, 0.04094543836770519, 0.04659761209040881, 0.032245897117160985, 0.03666325967999236, 0.044437079435034145, 0.03033649957468433, 0.06338051092180033, 0.04964354320339138, 0.009635884555116778, 0.049539389719645825, 0.013036651315257676, 0.026101040759033738, 0.04998682337182184, 0.05354338656029394, 0.026637461269274357, 0.05011699703191558, 0.0526506451499318, 0.1200949767183873, 0.05187767009521204, 0.049891659929867715, 0.05269625802494345, 0.06358213377215209, 0.007925898741720425, 0.024867261902639465, 0.012249743036415068, 0.03210870417646103, 0.06626606918871403, 0.05537155196971952, 0.12612611881547398, 0.0167006018361257, 0.06306757932649025, 0.03756640073392661, 0.02649680561115665, 0.07873726813423057, 0.028255839246295156, 0.11543874027988604, 0.02310391519248726, 0.05548093400354828, 0.1809763058178848, 0.03487714483673054, 0.08044676269374548, 0.013789041587452014, 0.032407848104353876, 0.03516169287444603, 0.07109699665658897, 0.03942303397061844, 0.02035281684760365, 0.01314288855815727, 0.050983714435489914, 0.05650440065730965, 0.06098546726148456, 0.022635057891508745, 0.03599524250133865, 0.061123248174666404, 0.04440512590771241, 0.05786957316881707, 0.04796948404081407, 0.028672382318144365, 0.008854417415756372, 0.022578794479129777, 0.033799734101780964, 0.013490273042642062, 0.02796421830181874, 0.05243992883591883, 0.031465282250616344, 0.028539588637349587, 0.006975669135910369, 0.013466373014624321, 0.034867269963386564, 0.04329052926491826, 0.11143574701441873, 0.041938498991751866, 0.028144649244965087, 0.03156988772623722, 0.02478844486176968, 0.024361080797990004, 0.06630741495398745, 0.0427447222623854, 0.029663866716286832, 0.037768372154283913, 0.03002929831704786, 0.02552387777776007, 0.09791542130011706, 0.03335089084782428, 0.025817482889960372, 0.004239512857184896, 0.03243008380635612, 0.0782218135352577, 0.0223417668753574, 0.07823180332179032, 0.05554499427577662, 0.0552552521619345, 0.06609260390001921, 0.058099020332578695, 0.03780064360809423, 0.037116442822040095, 0.031067510248131813, 0.023999893324329488, 0.039793150199036446, 0.0489420096780504, 0.06840365368031687, 0.03784944723931052, 0.02188931343205754, 0.1037747068931499, 0.046659029359298373, 0.04325702440954986, 0.04698637872934342, 0.016939613607621962, 0.11723269603305286, 0.042876328506897536, 0.06030358006096175, 0.08536487096740354, 0.0702977447860664, 0.03483473803968199, 0.030834081342383742, 0.049261629220939455, 0.09321647545983715, 0.019018262955209902, 0.036586919018337806, 0.07006013495547157, 0.030063553938582063, 0.02563099985221221, 0.02622371250312896, 0.05081397233410709, 0.0159590641569887, 0.013645758247754027, 0.02636312709880933, 0.02406047172694197, 0.018780427128677408, 0.015407468402577985, 0.054757704868191676, 0.06289011888927029, 0.01161073569223405, 0.0987733172012433, 0.007908758003219602, 0.04930346145204479, 0.004636329643788838, 0.03749316272836539, 0.03179627819918096, 0.015324786448130205, 0.03686853293930331, 0.026533365242123127, 0.030874684002370607, 0.04929862360680296, 0.05529272152231105, 0.048942465500365344, 0.03652556686692181, 0.07086189193350655, 0.055835812743152344, 0.047437673464657805, 0.01739984667379289, 0.046027489457159274, 0.03550002794532526, 0.02149175976463143, 0.022317830458163254, 0.024698762778913783, 0.00645333219454774, 0.06541154407445463, 0.04955920075336772, 0.05455061215006056, 0.031893132780227935, 0.04405600048841969, 0.06756441202014685, 0.028845439665019516, 0.05532725676593762, 0.0660918684556119, 0.040266186509641914, 0.05809867942345239, 0.002434132099639805, 0.0048870443659383925, 0.04045314643712294, 0.049594965568112756, 0.05669848520248648, 0.07988084588320025, 0.03371611943528537, 0.04293219929921531, 0.011320914096769788, 0.0636290451661954, 0.0598216149955988, 0.018937860112336856, 0.00848848402740494, 0.054163101895321766, 0.037228080984805866, 0.03731471786816274, 0.021356037712746093, 0.05962726231964846, 0.041969253591472105, 0.039876086877719055, 0.03966242878607685, 0.04120655560625657, 0.07310127418848776, 0.05061195494847433, 0.01051683874515396, 0.019759248093431516, 0.01623542175718373, 0.02314228853661447, 0.07402842443796896, 0.025261814420622204, 0.040262559083320444, 0.054376782969601696, 0.031250250946369865, 0.08958146486791874, 0.029309039687617656, 0.0750021681550049, 0.13935595931064698, 0.02780006289662373, 0.04622987839543531, 0.02201047598294193, 0.07336456328630447, 0.022578428672145934, 0.03433054493319604, 0.03880014320114448, 0.01009316914038913, 0.030631060381570173, 0.038184020818481525, 0.04050443985409314, 0.07641392264274821, 0.022261500013090914, 0.057291314681811686, 0.010143862135948674, 0.08885772628409248, 0.030643605071330265, 0.05319180199876428, 0.07829468381861526, 0.02174053149628303, 0.020590759926445542, 0.09517897055634568, 0.013609031992664021, 0.0390530364858287, 0.031529643212354956, 0.05571333826669762, 0.04357113194982371, 0.028113593955734567, 0.032743747015633894, 0.03826091306344156, 0.05974792499816226, 0.050029697482504194, 0.02686904007268529, 0.07488483412852211, 0.023328087840890212, 0.05219999775891343, 0.04093128489330411, 0.11154619391046225, 0.037243866226485664, 0.00208030313989448, 0.02903408307071415, 0.11229352034147709, 0.03834395316399394, 0.09969862883970623, 0.02824238291190517, 0.015167790134587597, 0.022827593023858728, 0.07023576061211287, 0.05713637722956558, 0.0243242472905906, 0.09266263985585782, 0.01212559178501608, 0.055690344137650345, 0.035896980233730814, 0.012409085494225786, 0.029864815409265222, 0.013335544349355324, 0.08460457466783063, 0.07242965256615032, 0.029919807115689884, 0.04056909001402317, 0.031013215681718245, 0.003104555512583184, 0.038027643120937774, 0.020127577421766137, 0.04835995139494058, 0.02006676536233675, 0.04498036217785651, 0.020302984743349014, 0.07250840640476636, 0.017392459670983015, 0.04799837321643868, 0.023435985579365687, 0.03754981109992631, 0.11974380967477638, 0.0291728139329221, 0.0646526420549039, 0.04514971740483757, 0.03400725582914968, 0.3361768786224627, 0.1719353191794888, 0.1434943662776101, 0.24257498432792005, 0.16090363774809147, 0.14219699637784114, 0.09425188925477768, 0.15298912211531593, 0.14314977992926875, 0.1370611735769818, 0.08174481441176708, 0.1546019823440621, 0.07857941571743259, 0.18446778217631002, 0.0992398264427339, 0.13740683244841714, 0.08499204661817321, 0.133599589969362, 0.15378956142212116, 0.11324647243224806, 0.10606175513877984, 0.2576352157179387, 0.1603662423909672, 0.08947894698189152, 0.03967429931846358, 0.1608026520379128, 0.08949527997643718, 0.22523653002515917, 0.1887753107134373, 0.08493958491711848, 0.11686648302260907, 0.10795616034057834, 0.12221218327120428, 0.15766349951586417, 0.23351309881094964, 0.09326185084759228, 0.16918000735102162, 0.2657650633444709, 0.09654926436562693, 0.23367170965479267, 0.1567292859357211, 0.23161793518210613, 0.1595679328085915, 0.11861805113092547, 0.10180954581066486, 0.2298914334706722, 0.12456077135979168, 0.13605245028532323, 0.09994985205271553, 0.1395881758822549, 0.14175992789528064, 0.15659419399115349, 0.11215269805923586, 0.14728521447508566, 0.16998717290980203, 0.11987418251773042, 0.14220157758362834, 0.12393594238786929, 0.08352415320733864, 0.1214672470345132, 0.21122193204299097, 0.16251769307399952, 0.09964774527977552, 0.12813311595950397, 0.14006583170304376, 0.18238831311464312, 0.14319271149654544, 0.06544231016549372, 0.07521409105749861, 0.13343527943136232, 0.24802821267756725, 0.17665501834163744, 0.1842022867452714, 0.24098853881080307, 0.13533897727968233, 0.13621501414285553, 0.09088030565650233, 0.292836373611804, 0.10508565187093713, 0.1557383818491813, 0.08858466190436194, 0.1117342301914769, 0.18497664841913408, 0.10062246192847529, 0.1242589710220214, 0.25737373458762325, 0.19222192496301668, 0.2384935589807649, 0.14936661407832177, 0.16362305069642682, 0.14451974432074255, 0.16626053820213965, 0.19410084752786547, 0.18015268469049087, 0.1580023861700489, 0.2041231774755063, 0.2694380565756752, 0.15787054243828022, 0.18204692901382524, 0.11087294052084608, 0.14260645505161057, 0.14484235926741554, 0.10833125997094378, 0.2297460759479192, 0.16066475621154233, 0.1688241288666764, 0.2871143096877683, 0.19660796219062424, 0.1779942472855891, 0.09453872789538677, 0.1314160708458193, 0.11598818620005924, 0.19340546951899606, 0.09807318944724337, 0.14226255818240105, 0.18814540257857693, 0.10927334127406921, 0.19123996878343244, 0.19084947844666822, 0.18033201055180642, 0.13950104104174724, 0.1913131761454767, 0.14297624569266074, 0.1563767629164842, 0.13074482460656475, 0.23643613792955878, 0.1885737836240761, 0.15403400475700058, 0.09692836297495712, 0.25092367263090226, 0.25447548607424386, 0.09966570238072066, 0.10863525898105676, 0.09480249962859577, 0.23621214914225766, 0.08448570846549927, 0.11107869641554934, 0.11689942480335314, 0.24279028567815983, 0.1088977283647945, 0.1298212443268107, 0.11028512125654567, 0.1270824953192665, 0.1077382925957922, 0.19818651700212112, 0.12772038609029787, 0.21265433260029365, 0.17438505385671893, 0.11692995340713572, 0.1064402025733744, 0.20411904060071517, 0.16659184058587398, 0.12821223752032365, 0.07783495445525454, 0.23482364542301626, 0.15471324895418462, 0.09909643010506708, 0.1432332069042229, 0.13107569798106147, 0.19886776834966677, 0.14394467275950218, 0.08874762412761489, 0.1067325187426421, 0.15554708969448844, 0.13024971730286075, 0.12486151449622647, 0.18739144948701705, 0.12595823064686792, 0.174071969043824, 0.08954710582451475, 0.11721833188447262, 0.4359523537418535, 0.09494741282035267, 0.2189854670676493, 0.11250692179366467, 0.06194482384730251], [0.09550379183624061, 0.021307373892575986, 0.030905360078078606, 0.0514369780167697, 0.012758096000329863, 0.11539871218584238, 0.0745720787334346, 0.031958861208911386, 0.05497889743456918, 0.06245698426820098, 0.01265515389311458, 0.052120657863035325, 0.11001527444609713, 0.026984370779246095, 0.05649719176994217, 0.02904992959942789, 0.02408117908353527, 0.08380052708690205, 0.06308537554897128, 0.013110860337262914, 0.08740852541861036, 0.04936086442021113, 0.13056445686567214, 0.003191010928862999, 0.023443292142943512, 0.06428067572414875, 0.02692756919010032, 0.05407685188636665, 0.03270492551007098, 0.02912327294207869, 0.024256099939286232, 0.04211239328968429, 0.02316656394771511, 0.07439492090094475, 0.03968496709280918, 0.014403257368793412, 0.06203735577723673, 0.013636009778917558, 0.056853614176713654, 0.05153930821125546, 0.06143370913642068, 0.01332049550969274, 0.027642235377683278, 0.046764994640984846, 0.006977034687635399, 0.027840588947818167, 0.05410161184807939, 0.05765530220683544, 0.031741924260953264, 0.04663766316709019, 0.02059812777705731, 0.08745544830397253, 0.08128516931807803, 0.010650433945439516, 0.025655763644364574, 0.019863914856086337, 0.09167118418601253, 0.020867114653810862, 0.07749112653395823, 0.05070690771624927, 0.059817068263768196, 0.028374155780540842, 0.029448800938083764, 0.05522996742999362, 0.07013059206186764, 0.054176979578070106, 0.021215219260944475, 0.025883697784475745, 0.031962021321599046, 0.04606862837869314, 0.054335659369826324, 0.011855065071534727, 0.03184712920037489, 0.044694159390224565, 0.017242689481786182, 0.015903401166020383, 0.02780784443471461, 0.03731298650945387, 0.03127448230741486, 0.02713272370578301, 0.05474794107759672, 0.05398040907757898, 0.08663088488843172, 0.03287226975625081, 0.02736498049700693, 0.03238419897013134, 0.008899112900478706, 0.03837547768207808, 0.019662309242712877, 0.024987482165376988, 0.026147948322637428, 0.05742429605414791, 0.019960181464651422, 0.05014432721861428, 0.02986180659894261, 0.07458003838696788, 0.07046812274042638, 0.023354025662786538, 0.01104905151747047, 0.052231200520069375, 0.05710472247653431, 0.03126910053974679, 0.034860283241517125, 0.027654914132830118, 0.030730286004742792, 0.03041279427106342, 0.01633607421911532, 0.01821087714615128, 0.04280789004218194, 0.047561404325308344, 0.022508323966195027, 0.041411411347648794, 0.01194167418420435, 0.011987937276341743, 0.0008136938847582638, 0.0417142880389527, 0.033080664823853204, 0.04974742472592381, 0.03310221104672359, 0.0313464907418576, 0.04303704226209272, 0.01850956142128956, 0.06194937057913311, 0.016334683769532753, 0.05370584316551686, 0.020072897896170616, 0.04983113898384956, 0.06273933363357379, 0.1016064175975419, 0.04926811032477887, 0.01897709147493926, 0.048892750224519166, 0.04232345051282356, 0.08590910748969163, 0.09414677433068715, 0.03556951978093675, 0.03277524472064069, 0.05286842479460663, 0.017223767110056454, 0.0876882164588859, 0.0024530336433540912, 0.09637530878066056, 0.0732036695004471, 0.04380290035999591, 0.03559801825171998, 0.06386360213641198, 0.07143243591511442, 0.05549150601690335, 0.020535555630621892, 0.02791713836843208, 0.0388116191982502, 0.05247081750102582, 0.03801106497825634, 0.039753428540162505, 0.01834209843148147, 0.034956507715246374, 0.02874580993046684, 0.0528198816332846, 0.08364657405763866, 0.045495510341659676, 0.02326151480027024, 0.023784205099687945, 0.04113750427120155, 0.0245274348755277, 0.056730312325300715, 0.05260468370491459, 0.018865537581845157, 0.05209586725780561, 0.04960552992058858, 0.02345446553531914, 0.028198154740816647, 0.0624960585827789, 0.026356511929583167, 0.0296943761678713, 0.02161174637055205, 0.06089358267584636, 0.04501251488803856, 0.03417434726631449, 0.03408294914650821, 0.028049455159493995, 0.05916690093375022, 0.04345742534966238, 0.018662349996908058, 0.025001670113734664, 0.058733666721250744, 0.06751208055403925, 0.0027588320024792227, 0.12564300844866422, 0.008682174037300773, 0.04560626750331252, 0.01748288102868584, 0.017071191123836947, 0.03429610162012039, 0.0496359397807429, 0.047008851918602185, 0.051783487245801, 0.05459341348239011, 0.05608840725354611, 0.07423086317196008, 0.039990666818114064, 0.03688477400329806, 0.03596870904608119, 0.011985024227009667, 0.02630879997365898, 0.05060282701085653, 0.0488428587484504, 0.017858974658133044, 0.007433174929070858, 0.015067504437249756, 0.024750454561604608, 0.011494758598987135, 0.042308630541928356, 0.026031432095013803, 0.1023530928538211, 0.03879322925762784, 0.039060685873752644, 0.007851832403591084, 0.016646177034765, 0.06559370446109003, 0.020180784143327225, 0.018208670812929352, 0.043495607171808524, 0.0404291027676194, 0.006521630369412203, 0.1235602069045267, 0.012798328065283358, 0.017132792253828338, 0.11522372238217823, 0.05074328540133373, 0.07781454587295171, 0.03393869862080582, 0.009660776666996461, 0.0703396421346453, 0.005502032938473408, 0.052695085910419305, 0.02470676073684327, 0.03843997462442325, 0.02431599843886591, 0.024974163726813374, 0.024344653957673622, 0.007134596469827117, 0.14761722165971033, 0.015119324539667897, 0.025861017751477422, 0.0382367238372324, 0.041648783690987096, 0.051902862896602, 0.06293783850607372, 0.004412169444314655, 0.04362193507052237, 0.05089736866554426, 0.0163106209478311, 0.022574852956759355, 0.051753713238623836, 0.028936121492616595, 0.08969709817920962, 0.024734734437398376, 0.062128799862318465, 0.047610031756302046, 0.03870343609202293, 0.01526746966485535, 0.013143760940781044, 0.016376697946520104, 0.014428013500066535, 0.07586040879569708, 0.04146357427441305, 0.06029283567782372, 0.02861961418191993, 0.016942222137004137, 0.04450777019824713, 0.036660015297633027, 0.04057192836978263, 0.1030828528887322, 0.06369729976980917, 0.04070076137600888, 0.04007449598922845, 0.031912114523771795, 0.022598151605756536, 0.010192886975053097, 0.02977624032345991, 0.01850002171141246, 0.021670972627978173, 0.12114061778711697, 0.017933306254206166, 0.05012497583764696, 0.01769615416114609, 0.036668319690732226, 0.026091830466964075, 0.073386098017856, 0.01681699165924182, 0.01216502137286889, 0.03496931670534034, 0.01725429762905884, 0.0084361630950063, 0.02480809118658785, 0.015544330967860598, 0.045099607593710386, 0.03064783004623267, 0.07059588322355863, 0.059557973497336915, 0.11288569864606667, 0.05487797684186409, 0.008615027388347494, 0.05668681002252045, 0.031890095241608164, 0.010518867920543398, 0.05685635677148258, 0.04096427646976325, 0.03242883125259992, 0.042999197518633264, 0.014499597713321209, 0.05814899607831913, 0.044422167533588026, 0.042754915062217944, 0.027235821903412862, 0.07624771220669632, 0.027615426130773082, 0.12834231158898723, 0.02304108640659721, 0.017044558077149333, 0.038490122739946654, 0.005480921470500048, 0.014577031007877763, 0.05466743672807371, 0.028219160871700417, 0.04859978288051583, 0.08306523589717765, 0.060423442177594676, 0.02506227341420468, 0.025960409998773568, 0.01940296932814583, 0.016118315641858404, 0.028508558245976607, 0.04632742820127357, 0.10088587360035989, 0.04088173049592203, 0.0696349025313412, 0.05719089204625738, 0.008124465858864208, 0.02780339346387454, 0.005034092548979266, 0.025302074256262956, 0.02635562135237119, 0.05020914974832728, 0.020462878784465215, 0.026744859135379235, 0.03174123478182141, 0.027855221227171923, 0.031354358464839964, 0.06016762243703969, 0.04370017946066876, 0.02534148373430775, 0.2148337301708037, 0.1202435058451468, 0.1006788383388231, 0.19819073048570465, 0.13475518763786362, 0.21400684550885232, 0.10050902728952708, 0.09581125356377133, 0.13938669475816912, 0.19749241069920603, 0.17203677986418048, 0.22298839904608267, 0.16773177941720332, 0.15784794284451395, 0.08690235580527976, 0.08647358405493921, 0.0760551713286869, 0.12881134125974872, 0.18482814993589156, 0.12673461479285072, 0.28148457468036686, 0.09756778592183706, 0.20646653318357086, 0.1410322516195236, 0.10310056484154156, 0.1970983963579901, 0.12325358787371267, 0.0905414879502308, 0.11169784101507357, 0.1022111674049689, 0.12479517894286303, 0.2144257270640904, 0.10405062111995875, 0.10116541142305059, 0.16124905147139104, 0.11124948805738842, 0.1519917369249367, 0.1336971129621229, 0.1310072403641478, 0.2715898136938772, 0.0869893604108403, 0.060770303807071144, 0.0927584391507891, 0.10460909155587997, 0.08508422231722264, 0.17179684112629584, 0.13446614266403262, 0.08742872715717362, 0.16150133954661508, 0.12908857315778732, 0.1287052993692698, 0.1657498639918143, 0.12288166750823298, 0.2672244914837422, 0.07723159892784973, 0.10177093497928112, 0.19168834472375532, 0.1818820668925201, 0.159574858243427, 0.10394841732998049, 0.09601648085780683, 0.15668664548185565, 0.2144441591395486, 0.07951254145272317, 0.0942067207107621, 0.3503583305545392, 0.08642378067898174, 0.1455946116437835, 0.17936681637600546, 0.19248241017903053, 0.14129878893013925, 0.08881762924213564, 0.17350216816750266, 0.09327287485282268, 0.17315220388193286, 0.0904743173610299, 0.10721893860928475, 0.1603908338133366, 0.18216646937352998, 0.21460592626563965, 0.15243661950432486, 0.152088294646913, 0.1350237627423579, 0.1290295077788253, 0.1519651230304472, 0.1615028410789467, 0.11879280344733309, 0.08552836179132424, 0.13169028435743627, 0.22823193380909584, 0.15380309053486393, 0.20979130880967264, 0.12616728838052482, 0.25297508755278203, 0.09530482348054649, 0.1764760908460425, 0.13047038126857052, 0.12084258660193413, 0.1985015936436192, 0.1326780781270035, 0.11199444727671724, 0.15486568512935794, 0.10167313619486748, 0.16268673803537123, 0.11628077050010044, 0.21950960910368353, 0.21329386279948298, 0.18850650578256578, 0.12779465831455686, 0.13283662768381257, 0.10323299846101193, 0.11305557864327585, 0.24432927970924687, 0.0858112933835195, 0.07352744123988575, 0.1318194927467454, 0.085788938937889, 0.13038327707157982, 0.11128766987953456, 0.10899960273696531, 0.12748576400260772, 0.18979714943035958, 0.18600777212169864, 0.09528664421410331, 0.20855456710823123, 0.0870758593983708, 0.13474866056874876, 0.13546754215513507, 0.20612252906205195, 0.14505528574509008, 0.06375648006195984, 0.10858516449168806, 0.15372412219162912, 0.11711984362092712, 0.15053725771365628, 0.08160028426397233, 0.16723152400264818, 0.1640476166240631, 0.11405803533571382, 0.12982459979191904, 0.11250305304964704, 0.25366632868686034, 0.20067185944607183, 0.1298820563862401, 0.1953422470438865, 0.134290065015516, 0.12826250820991494, 0.19022658767719425, 0.08460717170589394, 0.10071229339847643, 0.22499262295182676, 0.1443993919078381, 0.13816280801209713, 0.0977924565273908, 0.07822621854082232, 0.11359158738125717, 0.06702690941071318, 0.13122258767966302, 0.15003208401462725, 0.1266724161142784, 0.15833692144482367, 0.18302326210804526, 0.12798843259412435, 0.10724864749898834, 0.18773433512016652, 0.1490824107801722, 0.06945579883552368, 0.18218744486089677, 0.173790876062647, 0.12853787851429757, 0.08582473056571138, 0.11703714442950104, 0.08801005765675537, 0.2167916210788873, 0.11835804855030392, 0.14200850810495116], [0.029674574710248463, 0.003909866180976913, 0.043050088739443215, 0.031960280386791114, 0.08375561901278074, 0.01128740732618157, 0.08537644655593941, 0.036059708800166845, 0.06883809448129709, 0.04426090219508737, 0.061188066873939774, 0.11350891117246882, 0.09979416766474325, 0.03377929104552154, 0.05578765645623208, 0.04868441644395071, 0.023926205242112763, 0.01830101505132212, 0.012454033787963132, 0.03809744905259821, 0.01877598381871658, 0.0025752521985616056, 0.05899355821912328, 0.014901849414942967, 0.06144336567470624, 0.0342630296044292, 0.06418996325303471, 0.04102290900904806, 0.025112609221269528, 0.025194433157242117, 0.022007252668000517, 0.05106259467861345, 0.015110834370247059, 0.020163081766616915, 0.03768227919335327, 0.0071246603094491994, 0.01754004842481546, 0.028287011363934127, 0.03174954492058004, 0.055261468965440035, 0.05419563764946596, 0.059485340701235886, 0.011944408160484126, 0.03000671212982026, 0.017302113006852807, 0.10045862636498867, 0.027477413475994143, 0.06254190128416785, 0.033155484800978054, 0.05887655744088754, 0.04735968571396605, 0.0232580176088959, 0.00734525484844081, 0.04254635145527221, 0.053263040514843124, 0.01363676533313288, 0.043462650069305976, 0.04319718528178431, 0.02366874032774039, 0.05751152665564611, 0.06692955495729562, 0.03811216943206326, 0.03571600728337804, 0.035358412762082396, 0.05854736179894498, 0.05954408049283009, 0.040390162518428224, 0.08047307015306528, 0.0070692994444060235, 0.030216903673605095, 0.027546886159407518, 0.07016948634578336, 0.0452032171550297, 0.032481319766732, 0.04340811993085569, 0.059068611853065035, 0.04295958311206872, 0.023002395135981422, 0.06342452267305025, 0.04680262104938588, 0.044015880463825124, 0.05294217224863749, 0.05135975635400222, 0.05871761717923707, 0.030311576819287676, 0.04406194150027248, 0.0376043948645313, 0.06755741763739817, 0.04473267829105739, 0.04852733777595624, 0.01321028418568594, 0.013470250377131086, 0.08011857062698373, 0.026630089588222966, 0.0360399590534789, 0.026495807781635274, 0.045576604578884385, 0.08757625270875231, 0.03626918405174248, 0.06263254480736871, 0.013863479478224633, 0.042424612423224796, 0.01200151905762933, 0.0509605709192974, 0.08870648520608103, 0.03275208205225007, 0.06201103299615845, 0.031583474295574336, 0.04021068726996741, 0.04244847223162652, 0.00902296441997732, 0.018074276008372827, 0.028340601129457358, 0.03875920729291055, 0.058667748685806036, 0.07203055140111717, 0.014761684053096802, 0.019573134693106817, 0.04584616410636133, 0.04954078399966802, 0.06975605167568692, 0.08973433005232966, 0.042049003344389706, 0.033071498581839186, 0.07696230370070666, 0.04393658653322247, 0.027059807457149993, 0.027156075980934887, 0.01685184482935696, 0.05772675522753309, 0.017044012239503286, 0.06690377609864359, 0.02256374468185729, 0.05184193209354436, 0.030017376073726246, 0.050716449341346184, 0.04746992193583039, 0.05194876305458527, 0.04421380693994222, 0.09040278007066058, 0.06942186114047805, 0.07254579149547123, 0.007117330284428693, 0.0449288159518713, 0.03126221532452732, 0.04078111250794703, 0.048866511713112556, 0.04397542336054387, 0.05173454954919796, 0.041658823273234794, 0.010220333032550351, 0.019552611197615345, 0.03818549170729615, 0.057404124959101605, 0.07125618972725446, 0.035273484254796664, 0.010653028110673111, 0.01576019251989501, 0.019684161900752978, 0.11818411594797527, 0.10862242700832506, 0.04020392654403564, 0.10137451512198295, 0.06815718787331736, 0.02188474946324864, 0.002042082055742222, 0.011601913232176055, 0.09528061510213921, 0.04307152387956458, 0.06836333447286198, 0.050443155135238366, 0.022084531787362312, 0.032450829467345635, 0.009320922826807345, 0.06886183554607053, 0.011383484327985395, 0.02287769517410667, 0.011607214560612075, 0.033129786381558064, 0.05815098407648264, 0.020532276774305972, 0.021174306335348277, 0.04184260010539044, 0.02861003042198718, 0.007667140575170878, 0.04633301681268119, 0.02335861069901336, 0.01739711557034283, 0.017466038585670533, 0.05555231424589312, 0.06357095271889722, 0.058276434804523186, 0.030451918381356427, 0.011542266584001483, 0.02708904711799997, 0.03477345483617918, 0.06823069400965207, 0.06671947832669943, 0.07552097821908613, 0.09190106418945136, 0.04519125852253168, 0.04251144848944199, 0.055861262183996944, 0.07320001526104827, 0.09085792056735485, 0.07728147125172039, 0.021841722134981426, 0.06749151109327232, 0.008390707268019118, 0.017903306251091343, 0.03304719444244139, 0.021671964711840117, 0.012130281200722582, 0.050196739123953935, 0.021434688129492348, 0.004918121680196736, 0.029930223996240287, 0.06498838774859905, 0.09621812286035669, 0.019779926721727657, 0.05172485470651619, 0.09535553850113385, 0.04092829715039942, 0.04838414445158936, 0.038378902095099615, 0.029706137532728816, 0.04279869698709057, 0.021750410200066624, 0.01879977084876549, 0.11008472797731239, 0.06977123553834616, 0.025782152830112367, 0.034678563355438174, 0.028474821649011106, 0.010249373510540014, 0.0752215680756396, 0.00896946083934557, 0.05246344390475462, 0.08847773135189088, 0.03490852379810906, 0.02593810151841852, 0.03642351246408878, 0.04367839192010222, 0.08892844386038282, 0.025347325154730392, 0.032809573120527694, 0.019990342346230344, 0.022689402253637393, 0.03595960792154074, 0.06592048692607111, 0.05125753341182586, 0.046388182804108634, 0.036943961956327966, 0.0686568534001708, 0.0635731513912399, 0.04453254165127874, 0.03491365275676212, 0.053576427932468154, 0.0470573376233299, 0.01332713174633682, 0.04598746136311562, 0.04609775504157428, 0.10061441800527035, 0.03780753073853351, 0.06701924853147039, 0.02486703973714142, 0.023265973431989554, 0.05227457258790251, 0.06050995648688367, 0.03376901780645694, 0.012573154714529314, 0.014247045337763286, 0.04331174223954159, 0.04525151133777634, 0.011385837175522842, 0.039139428221049814, 0.025333491522037697, 0.03770515840921191, 0.017607716971167156, 0.03593310510980026, 0.052890346400559916, 0.03956766754028298, 0.018472214634980888, 0.07330484673260682, 0.03714609808558899, 0.023090156253367182, 0.023285211814988046, 0.04388119071541775, 0.03514568929770782, 0.05263285275789038, 0.06655411824824349, 0.05488190687291565, 0.06917967776497526, 0.005439100251908625, 0.046007739710471326, 0.08655076741331047, 0.08105813916171752, 0.03264439307273396, 0.04081514213354357, 0.01417773353281401, 0.021635742159560326, 0.010758227304435306, 0.041122971583277955, 0.044470783473262866, 0.025810132276326902, 0.10169543701434329, 0.03691401174892822, 0.06537703947434503, 0.056279802830108715, 0.03115051204428798, 0.028780276226180217, 0.06579255024271627, 0.02950721514231015, 0.05616956277780476, 0.07264174400798737, 0.09169438132835973, 0.015343431112987381, 0.0828051950121599, 0.04362804845215813, 0.028720123002365715, 0.061664531428006396, 0.04336516538094129, 0.03213971733085571, 0.016964442517247894, 0.02401778722302087, 0.036873795963343114, 0.016307922403117823, 0.07396143004899064, 0.007515024720510889, 0.03230463690875519, 0.07418142751820626, 0.037008286528890176, 0.010456473889550375, 0.06144208630787269, 0.020488065840195746, 0.029970043331324577, 0.015734637741960825, 0.05618353239110401, 0.06577326014878289, 0.045209644632714416, 0.04758812930254687, 0.009918483856674886, 0.04418923083933131, 0.012778631944750107, 0.025870189739150867, 0.03246019489221996, 0.05222409505457167, 0.005745941927025636, 0.0014951475872470427, 0.03274428327718089, 0.029436357754973635, 0.015994322396093802, 0.12618357540979502, 0.18031685733266417, 0.15992258555225788, 0.3812572305961963, 0.21007598708233527, 0.11393716964390009, 0.1703692209576407, 0.12953045267251231, 0.13362197505850948, 0.1438138096202766, 0.14129687371032854, 0.1576840153504764, 0.15838281011148808, 0.08222386451257814, 0.1633910026641623, 0.192094340680107, 0.12452278872050586, 0.09807321242988111, 0.06638235367474056, 0.09864555671811105, 0.10530670654148826, 0.1253383046376609, 0.17780295513089628, 0.29417675168764207, 0.13139900240686633, 0.13058092775604419, 0.1429979106591594, 0.11806426915310084, 0.19596112351263725, 0.11985262480354118, 0.09424193011176202, 0.11420343882374226, 0.09304412865951177, 0.16865136071799264, 0.16597860252424596, 0.13442619883966062, 0.12911163240430817, 0.1224907941275066, 0.1403644527759283, 0.15986309116405828, 0.17502784759046572, 0.11523466977861621, 0.10769048104843787, 0.11835812515909634, 0.19282754811067737, 0.2867750553113799, 0.09579354161096197, 0.14523905491636646, 0.13872986629364953, 0.1062289078629786, 0.13704369145054973, 0.11312924565807467, 0.1435129056053777, 0.16350708030644925, 0.15319158383194478, 0.1748903041645404, 0.2953466905220863, 0.18557664848143057, 0.10296447698267237, 0.16946961922991663, 0.1237153780135897, 0.11670038749974583, 0.15325650212264832, 0.09511508648433993, 0.2163892717010552, 0.1194653673578174, 0.2112052772915171, 0.1777809990509864, 0.08271235281661635, 0.11447279533791928, 0.17060042629318853, 0.12147450954803538, 0.1354114185538023, 0.19920026583056297, 0.20222162467337426, 0.1267114865984167, 0.13086868570216242, 0.1718975050795463, 0.17603555964606424, 0.19007120972439168, 0.14195440697573847, 0.14561908049208505, 0.1860700091046672, 0.22165666244203047, 0.16207664093423277, 0.2629113551830092, 0.18280321101267494, 0.17668739321731752, 0.17347909359922334, 0.21512006319338278, 0.09773617970847315, 0.10573501097819499, 0.21833135055438166, 0.1716270453987583, 0.11841172833115825, 0.10726458978869262, 0.1932753265024193, 0.15032459170587603, 0.14655435127356362, 0.14285624568020144, 0.054202455831992055, 0.13672470776063783, 0.0908848638796518, 0.13111034047699746, 0.15087389206934362, 0.09043295627399799, 0.16657114089015992, 0.2448665218487863, 0.10670442629845873, 0.20040084818197837, 0.10826624974968935, 0.07785539368107434, 0.09238734616026764, 0.14586684864855584, 0.1272658737857015, 0.1458074768344241, 0.10162079706788064, 0.10793184470986167, 0.127958984174315, 0.14935791131950196, 0.17984592776385047, 0.19243506594530999, 0.10863870637671602, 0.21515928689510594, 0.11218924811410327, 0.09553767590513153, 0.1272353068775227, 0.16747828092305891, 0.09726021694199694, 0.16520894463023833, 0.07269109539206951, 0.26401945540020544, 0.10018148639750096, 0.13230793508550814, 0.1821124448531097, 0.20119840699818828, 0.1041455930399318, 0.10633956926364092, 0.07674542420934286, 0.1845916432719077, 0.09056931226364068, 0.20920537412166598, 0.17786145360479433, 0.12653741610026167, 0.11459556858866446, 0.09684133538675886, 0.12158140179611023, 0.18450466164898488, 0.22366680054655, 0.07863681102471967, 0.12858836370850765, 0.14295667980707463, 0.17239858786905968, 0.23581586718078584, 0.1959980336288291, 0.16019234043215552, 0.10224436965560722, 0.15373775855668131, 0.09100031332984086, 0.29357767093085474, 0.21237969007943908, 0.11814580389088201, 0.14919402979073987, 0.17850444652140143, 0.1590677080375533, 0.09540960898682957, 0.1396685538272704, 0.23953867144882682, 0.15726447495962345, 0.14589039819134822, 0.14878711452887905, 0.17132960410127718, 0.13350543776346793, 0.05003460044521959, 0.14728222673218097, 0.10448464823345985], [0.06318870165775861, 0.04064767531329586, 0.0867813598785189, 0.03341564442962408, 0.02203197624053686, 0.04219028527938551, 0.06481947302217446, 0.04956261750551001, 0.05115221164399578, 0.10493331528719395, 0.006258915358733747, 0.0760383480378697, 0.05368853723930736, 0.02221073711200828, 0.011305125024650368, 0.010656100123249477, 0.09178004528005278, 0.01962205515273156, 0.019844417918413397, 0.07111409573905891, 0.02974572129577639, 0.03984467344238393, 0.07091084495186806, 0.05854425531241202, 0.04659808323448224, 0.021805141436597033, 0.014631451021188931, 0.09381166448996914, 0.012431323111447836, 0.016707372138156526, 0.020796705427910053, 0.0382361147973326, 0.026299306229057334, 0.02205726671813717, 0.04587267457898106, 0.07283166486529574, 0.0449628570687867, 0.04624507374941342, 0.04050466201959118, 0.020710170051203142, 0.030716201478254893, 0.03335046949946592, 0.03951089659465417, 0.02050968484141894, 0.049744249291477666, 0.005786212296375344, 0.07439051589538014, 0.04658133655245747, 0.05113847185707381, 0.10181814131717529, 0.030242937256491957, 0.029385874475983363, 0.02650360655670445, 0.049792348121803616, 0.027287584549236684, 0.07770167813906748, 0.029530502299988465, 0.07608059012601454, 0.03482409707841373, 0.10261763067495439, 0.021669360012897564, 0.043224599738154686, 0.06469779527716099, 0.05323661814233469, 0.026349977199589054, 0.01828495593320939, 0.09410943520525772, 0.025117052531230356, 0.03778195872362103, 0.047478774081795454, 0.06581459825317706, 0.057471609644351475, 0.04096259107632984, 0.016074282823190573, 0.020405661592620517, 0.05035132800619449, 0.06262318704337363, 0.031102367248686574, 0.0460117808242719, 0.011746246112330307, 0.028424729074862216, 0.07258814083592546, 0.049710062617856654, 0.03791020184214558, 0.021980604299554424, 0.09860274772490225, 0.03994661676246793, 0.08871449082488976, 0.02213596118493907, 0.010194967861377425, 0.021757400752375686, 0.050928674848569985, 0.025782987865949833, 0.017076764413486087, 0.048682604646009785, 0.021168068464424823, 0.036214290021528164, 0.03683214759333961, 0.002660422981153393, 0.00855596009416566, 0.061009457304833405, 0.022617912843763348, 0.01759402697996026, 0.05021060148494379, 0.03945687973511316, 0.0643245495795723, 0.021452457538896033, 0.023767065797601978, 0.01970206537554341, 0.036831477266405864, 0.05530732698858746, 0.01486062335090772, 0.03805554787357969, 0.018399984035040104, 0.08641766729734598, 0.031196680333044742, 0.10096182355717306, 0.05530923837795854, 0.055859787464742704, 0.036896824566346985, 0.020747677715975913, 0.016553557004719492, 0.061749674439910925, 0.027946247794334928, 0.092430867615246, 0.05482242014559527, 0.06444739177823067, 0.049886182401209116, 0.06579805841489185, 0.02497708252180488, 0.025710318680672396, 0.033213408708932905, 0.05461360756007414, 0.06305544066333002, 0.053973805399671684, 0.017894097874241493, 0.013102100121848767, 0.055894280573533434, 0.06558794347989945, 0.020295067224651575, 0.011060087014019731, 0.04154177269928398, 0.0593427027906141, 0.02659111678029501, 0.04854229564267782, 0.027413286171072436, 0.04362802929996003, 0.002212038901146321, 0.0374862909196846, 0.043890307161716685, 0.0057610850912638975, 0.014454794976289475, 0.022562231658206835, 0.024394985934298848, 0.017005409068998792, 0.032927937535268646, 0.03383693533138402, 0.05189209170038662, 0.04226432767726722, 0.05811819168288381, 0.045388828767764, 0.03866996954105074, 0.04784861834900034, 0.017913265394106988, 0.010489039329601633, 0.025433893090174086, 0.06619002730134996, 0.06445094642619933, 0.047932202371978955, 0.02999638334938115, 0.03505596124957647, 0.043460914880157485, 0.03348684847174633, 0.03597006885214679, 0.056646084788465695, 0.04963498217083755, 0.029623654761141347, 0.025160947454071818, 0.023656053911714305, 0.019038072073711984, 0.025372922067500414, 0.014015776799961686, 0.023838886540503274, 0.039031088066798066, 0.05786067888801617, 0.04825334642983733, 0.010766976986140495, 0.07544720395197792, 0.044675765619162595, 0.042226988551837784, 0.018807155936355555, 0.08833950610771295, 0.07524115694386345, 0.019015865100006905, 0.02805744545654424, 0.06430271607373031, 0.019805786019611745, 0.06952349802539234, 0.0574372697531456, 0.10513382347961588, 0.033157231481445414, 0.020972769669888, 0.016513634247765425, 0.028239760975984317, 0.011582175934416874, 0.02608750015497208, 0.03993448192974733, 0.021139043308193647, 0.032735159170002706, 0.012642511527144141, 0.03636420576743061, 0.02442908259258876, 0.051217444030748266, 0.052016462244453936, 0.04040485608481592, 0.03458329649161428, 0.05836094196345057, 0.04279661705837615, 0.04003578556641456, 0.03168678316738337, 0.013979731405514383, 0.021224253352791555, 0.0431396444177916, 0.05206725004339411, 0.01448386609779611, 0.061238172854627335, 0.02946204085263514, 0.03819419829655559, 0.030327044134478898, 0.015025584106033128, 0.03651298770320512, 0.018069976339897802, 0.01727458172207398, 0.08270585639101845, 0.11594330110857565, 0.11587150334831207, 0.04789834128572576, 0.04515085121496551, 0.06812978490826584, 0.024203592272956046, 0.05710802048504834, 0.020817613882583477, 0.05563895495968962, 0.02976445980640429, 0.03777656929507371, 0.04252181365905751, 0.03519379961935263, 0.03564749987074926, 0.018550897610463926, 0.053817500480480736, 0.0649986150223882, 0.04023694110313251, 0.07126621015730404, 0.0014872623878839097, 0.03052027449162016, 0.026620434965157223, 0.004378393106538082, 0.046300841119861415, 0.039921837648557085, 0.08862386262344737, 0.07813945908339755, 0.026476285946104797, 0.004665438590886733, 0.036175070150244626, 0.019765832619140708, 0.01939010862711697, 0.05069815133127475, 0.00797073930434342, 0.04674727502729624, 0.026048014068134853, 0.05951570842655436, 0.012744180013185308, 0.009184656852495768, 0.0628350678110315, 0.027003270168338093, 0.04071225269487308, 0.019679149770508372, 0.04208066575830022, 0.053623205261124726, 0.08042934185434734, 0.05197738792987601, 0.032811381088028994, 0.040546183985087185, 0.006734893925773401, 0.052577307552940426, 0.07597795732679867, 0.023633138306679267, 0.0764172321425811, 0.01901620983957283, 0.04885611206954045, 0.07146118719491266, 0.028597945384981654, 0.07430354193333658, 0.06321180686955491, 0.07557197669220549, 0.0733947241678834, 0.050230546584052425, 0.04798254583992305, 0.029446902955251358, 0.09744591665484252, 0.010328783311941212, 0.028586097835232655, 0.017512147502613165, 0.03136454551901308, 0.05200854855619612, 0.023312691388831987, 0.0582651081945627, 0.02975821044416197, 0.060987179467995326, 0.047387912223536166, 0.024638998344720855, 0.023703269825707522, 0.031239089045313098, 0.02405034212936317, 0.08873491472895108, 0.01558969199146715, 0.05903816368851451, 0.010923519392587967, 0.04909348441287876, 0.017629029537220637, 0.026563947472060402, 0.03029773935615536, 0.037547348127249754, 0.0438672938804713, 0.035897336464615605, 0.02383664573332475, 0.025228824759382876, 0.050335171211871414, 0.05693635167253595, 0.04133129770296716, 0.029257684983613513, 0.023907294361701897, 0.0341048171263068, 0.03916437204386439, 0.057512365521923195, 0.018845596313176137, 0.02952865794331076, 0.02774499649662645, 0.029881868526459705, 0.05662993948546149, 0.0024522182385196853, 0.06885652655675527, 0.04653587306459104, 0.05921978015272368, 0.05619346089060268, 0.03441670301160024, 0.03294116787372097, 0.034770087879751964, 0.09207171027458484, 0.09989505378349174, 0.05430607305419061, 0.007305041456880469, 0.12107096507304138, 0.1173264115688301, 0.1733827963471413, 0.15338017935714415, 0.0482054659345698, 0.09224757341848266, 0.17710794484423054, 0.1328044519909928, 0.20796598175600653, 0.17884727086751692, 0.10837046069002922, 0.2113220903782114, 0.09541583728165397, 0.1419010566126916, 0.1176146827938576, 0.14235445808979774, 0.24101153677028997, 0.1297114792490198, 0.07723654785584058, 0.1570283666613602, 0.18891953442606235, 0.23663475388480773, 0.1772585424083856, 0.1613788880527981, 0.10014135105114791, 0.13951008087925373, 0.11336097959429027, 0.19595303362415684, 0.11497101295859584, 0.11717692483216526, 0.09149731287071783, 0.15992269280456728, 0.09141082154406656, 0.11258960566333226, 0.12924388982355595, 0.16052034863781545, 0.15066631288538057, 0.1903132015779134, 0.14881083261101477, 0.06829993303624854, 0.10620057027065948, 0.1817340740273076, 0.17616531961867887, 0.10137121328302931, 0.08187615252550572, 0.07321901424157043, 0.15185103721676335, 0.12287973696666381, 0.12996745986803887, 0.24288120499301344, 0.15209007197089736, 0.13083099417628782, 0.15308695154324656, 0.1368743247322498, 0.1205037842174211, 0.19337078105778466, 0.13744901324952805, 0.4167502679892125, 0.1874943504170064, 0.3095977338812044, 0.0959088761479624, 0.12899184689646767, 0.14856055168615234, 0.11546023670704135, 0.14965334546662148, 0.11964567381167605, 0.21178565018119352, 0.13823311956178758, 0.08546065494057634, 0.15135170110771734, 0.1084004530322648, 0.13196049889008846, 0.08577015446198565, 0.159621145275812, 0.17192991059874335, 0.1604001954077713, 0.16616954227849362, 0.07604322035706813, 0.1449545298612887, 0.22388285266295557, 0.09855450716831031, 0.11093363766708683, 0.16900215237852068, 0.15817147709669607, 0.1293082412091955, 0.2113217992648002, 0.11317102043258567, 0.1309780217707157, 0.12322895814694705, 0.09214857953690714, 0.12756316186559777, 0.13103101973331746, 0.13603913567719922, 0.09066154924972404, 0.1816001312146264, 0.09517198383447625, 0.07332887124991225, 0.14498331944548315, 0.09343946067195746, 0.15901398995230276, 0.14783646070188092, 0.21568365875751744, 0.10563866776083747, 0.15688129310165683, 0.15023276840727176, 0.11156696255408949, 0.1879956170676216, 0.11538012689279935, 0.08655513411447888, 0.20612433702955324, 0.1859141255338346, 0.1266034069140592, 0.13203537632380763, 0.13542061160889365, 0.21212496584461582, 0.1236077426602283, 0.2797573528462841, 0.13843182744758745, 0.35850438860154926, 0.10202565921410438, 0.09702369495625458, 0.1074876592704846, 0.1263555468270375, 0.14165004024342184, 0.10017724227040045, 0.1326088850656825, 0.14699191005239565, 0.09375887337110697, 0.11451672281949751, 0.09234415412309671, 0.11901153687147364, 0.15256518437977762, 0.18617343097444505, 0.19763865688395119, 0.15964998082528192, 0.0968671678715656, 0.19524651669686843, 0.13354291478472372, 0.18074223531350014, 0.15706696217098545, 0.18313558591950327, 0.09300675889056537, 0.13068788895203223, 0.19651227780888159, 0.15969603803128968, 0.11914349551643096, 0.1361967352849822, 0.17175223948734422, 0.10527137456642044, 0.11470097462616621, 0.10608441601958006, 0.15411190057714141, 0.15115176748123862, 0.1761919335131684, 0.16123527721051248, 0.10354448981102436, 0.13883514209620415, 0.19283971358691493, 0.14361994341015816, 0.1897348358385986, 0.14438655227422714, 0.1240997396469597, 0.11977086023938273, 0.15457598131991204, 0.10664884661955219, 0.185318538137982, 0.10575744203261792, 0.1357313675144988, 0.1811840535411912, 0.13662572920082078, 0.07715752588645106, 0.1862138344515716, 0.21106627829853566, 0.18948162845786543, 0.08402900514943946, 0.21689672834209858], [0.03734897732013657, 0.08796977675369672, 0.09653893750040762, 0.06013513647861058, 0.022933301666090568, 0.048079770058393485, 0.04396817233834056, 0.0788910985894261, 0.01150871767857743, 0.02627695178342683, 0.07832898923586454, 0.018165781380488508, 0.03613810257745847, 0.04414850177483694, 0.09698840128558298, 0.04858203262331025, 0.016291955215556007, 0.0932930842522652, 0.03557218959735286, 0.02665636640402579, 0.03743325848312628, 0.028791139352946516, 0.07686452789893074, 0.02426937241257439, 0.0673921954547686, 0.0057160204479230516, 0.008016859712604915, 0.051080846723409436, 0.07412174926890482, 0.009217530642936548, 0.033383235079987396, 0.0344486603693616, 0.061671399406247565, 0.01001381104992282, 0.02889043583925213, 0.0479922023782086, 0.01242567512822608, 0.05190765094612876, 0.03594602135220363, 0.04219470943714823, 0.0649989367793164, 0.038348752704839555, 0.01428719887870454, 0.03807441661915472, 0.03882375786141042, 0.1192709495643935, 0.00401554896774131, 0.01782463476692717, 0.06988636323160703, 0.03506481722598115, 0.05896554621417196, 0.01983798469506925, 0.060927577827486305, 0.015293957154837348, 0.08296163016629797, 0.018380456453850193, 0.03837374249292958, 0.035642313455501874, 0.06683226945179124, 0.0205835931739139, 0.025901787035587816, 0.03469106974080205, 0.09478504814568067, 0.0209409655297115, 0.04512260938363691, 0.03714981361202175, 0.013434596645135074, 0.025317118307876012, 0.06527982291675384, 0.07119390677901045, 0.021549294882964705, 0.08498782547371042, 0.029458149125979795, 0.03955531820294358, 0.10968763396264085, 0.0493410648778081, 0.028319068313125643, 0.03405079260588654, 0.09983673150981627, 0.06915491014238327, 0.024294297083190853, 0.029425621032714847, 0.015675008330764552, 0.08932824216542706, 0.009594804047787142, 0.04879002932519202, 0.02989401485049917, 0.03811984563306455, 0.03635749483721391, 0.031278837517264395, 0.0631985075831894, 0.0930782272330215, 0.04755849319119607, 0.016411428542567358, 0.07342622570332981, 0.010268423244387153, 0.13996659267333247, 0.04467007358588519, 0.008203829694989949, 0.050003026131420374, 0.006127332096859332, 0.04917518385956365, 0.030299196838431304, 0.03909851529545361, 0.03839224351630096, 0.03170680679050425, 0.012316125512663877, 0.03678107634186745, 0.039269146058828606, 0.034327449937981945, 0.11865725951089014, 0.03632330050271365, 0.04981004858329412, 0.0039705714669018505, 0.03669049793614015, 0.02372336622718121, 0.032017516730833924, 0.03161000583561198, 0.05180055185431435, 0.022217783205691847, 0.05050992352827903, 0.09340399846194253, 0.04263412597919664, 0.05275321666211371, 0.04816254202817236, 0.07453480089503912, 0.020579946595394326, 0.03722507025926344, 0.07490340409980667, 0.04574521670057889, 0.04100466462513132, 0.041124622502754775, 0.016826925904399926, 0.058280874284044396, 0.02659477868057307, 0.044150190998709975, 0.09019926115269623, 0.05165389198209009, 0.07317196878214037, 0.03253581543122569, 0.020758937293243025, 0.06537012936126801, 0.022943163132895867, 0.07255184359007305, 0.020921179393847144, 0.08558954157295727, 0.02416459265195074, 0.023192402178181276, 0.012162447317443308, 0.04920025408688573, 0.025470107981574633, 0.0702856635795005, 0.04332180480442701, 0.02083241661650039, 0.06436551996176282, 0.055517334671270464, 0.05441950003225958, 0.04167862281563782, 0.007934627356007695, 0.015731253548555316, 0.023275656783352458, 0.015365527961553346, 0.022536035281636065, 0.044660156577705376, 0.01558734010153961, 0.030058972732794863, 0.0486718334497944, 0.022224201107277505, 0.028657131422791752, 0.04068336734968809, 0.024928223349214084, 0.02406410681414268, 0.10385298575725287, 0.06493369673168467, 0.029038905594197494, 0.03792175444804373, 0.023506178385427883, 0.008708381905190406, 0.0405497845983313, 0.028054857994579983, 0.06487296894192696, 0.04928770302344234, 0.02812707135754247, 0.04140490726117165, 0.043307007816169536, 0.07320179258503261, 0.02643963055414779, 0.03826318451413705, 0.029889774553838278, 0.03297130577266216, 0.03511694184834919, 0.06379338634771205, 0.03302695822992152, 0.03806532698593313, 0.013305452415689588, 0.045867143424167756, 0.025935198045185497, 0.00941107222329705, 0.05295534130005587, 0.006192855118218089, 0.05466743672807371, 0.0731399922721809, 0.07911623650861364, 0.021740083334847324, 0.04460629676618884, 0.09837846016331066, 0.07199393239833655, 0.0357419700031319, 0.005198715267808087, 0.013076740696335272, 0.04198291676960165, 0.037678065709769726, 0.020539606320521524, 0.01732003180340173, 0.06669802786481958, 0.038731777514781685, 0.04004465686457773, 0.06466109966558796, 0.022353373107410247, 0.03932152732065128, 0.015245594981787427, 0.03157229707275908, 0.024185430243491166, 0.06254233029340545, 0.060560139076363664, 0.018495427099086584, 0.03915243639400409, 0.013532344676223735, 0.029320011981913162, 0.010155096815358247, 0.05864760440383708, 0.016735891676357677, 0.023460050316287145, 0.031253696426809315, 0.09324647546295198, 0.02594419191741655, 0.0706993050933365, 0.022414566295581962, 0.03445178600809267, 0.01601321316669665, 0.009979787169985715, 0.020031013954130393, 0.019233499187976122, 0.09136464176399094, 0.08053172184454818, 0.07557823563054686, 0.008538135143387462, 0.04187007201835514, 0.04902390064671636, 0.03999898653297175, 0.05327164368223279, 0.09033698843972338, 0.032872016947235794, 0.08453651541663755, 0.06373651964109271, 0.054400807486907135, 0.03733926332525669, 0.05554579483765749, 0.018589962348942796, 0.0861187321284125, 0.008104836771024332, 0.03116091934873933, 0.03743998090466184, 0.029737845911914786, 0.002363807861618097, 0.019052576033338424, 0.13224842537555004, 0.017588279405308348, 0.07378317671076906, 0.026867140174633073, 0.037054860844246806, 0.0613850319097119, 0.033515450364399346, 0.050785673046184164, 0.050585065262332085, 0.053533270369253816, 0.01996093989169646, 0.024268370752613393, 0.04792447254482297, 0.02449709396328657, 0.0019055599207809617, 0.04081672793554683, 0.08212494723979505, 0.02029980164802363, 0.049662408118526784, 0.04663157276809216, 0.08110113967690738, 0.024301383396490447, 0.011274887534279016, 0.07939079475979652, 0.05828405737936978, 0.018389752930811337, 0.012539758069080212, 0.0332915113728133, 0.03640754719174678, 0.011390944109148076, 0.05282982162410214, 0.11489398281780944, 0.05542384896187052, 0.025708945468068126, 0.12920218399695813, 0.0385849146292575, 0.02688354403231173, 0.026714543120995648, 0.07238828381823917, 0.02094159372180941, 0.027877479911811893, 0.04570284437748694, 0.08838069865540152, 0.04275548196728191, 0.014124183986906805, 0.04160854109232465, 0.07879112411530749, 0.06562467739586869, 0.04348854001070704, 0.04520778303905841, 0.03670353292217178, 0.0690642819409409, 0.045561968469091, 0.02614141933830275, 0.013927225654404012, 0.024307684469667655, 0.003309942248667921, 0.028954283522081473, 0.030033956131627484, 0.05466184045578684, 0.029974523030461806, 0.04247562238766302, 0.0324280038776417, 0.06361466952629628, 0.04313073481523222, 0.054962709996729135, 0.030122092632096142, 0.0479900726537791, 0.031694585772892164, 0.06151077375116368, 0.026469488830996618, 0.021721750850819295, 0.029963156200885296, 0.054463178535262426, 0.0034857024495009215, 0.0353249998372649, 0.00749036243500849, 0.027544377221455498, 0.03487928222203928, 0.022425615198669896, 0.10453366253885532, 0.04689545175361057, 0.0268020169554098, 0.04747909200828403, 0.0248480828914551, 0.03815010993651325, 0.14531204777379192, 0.16635499684320343, 0.20851779488786576, 0.13063672960044878, 0.14986041903255448, 0.11269222314078962, 0.09830499233137216, 0.18248791986655805, 0.10137621583717485, 0.14303103630100528, 0.1597774425341237, 0.1251718950187487, 0.08671195231257908, 0.1358210151233981, 0.19895288071805434, 0.12651349883526564, 0.06985319928536493, 0.2101058951548992, 0.12100364126625562, 0.18201084627259165, 0.0615578996498258, 0.11801160060830655, 0.21275190155833, 0.1292619541768105, 0.1725883938131794, 0.14384066866290185, 0.1545176513853573, 0.09350869969855394, 0.12889246997093, 0.15854796334620447, 0.10439198989901813, 0.10217841714620592, 0.1321951056560201, 0.1670646700527399, 0.09981137399952258, 0.1347237167459342, 0.05475795767720669, 0.10092890475906673, 0.14168560204486694, 0.15874218195676804, 0.1006344358827318, 0.11906638110597288, 0.12175135074123261, 0.0918011510023667, 0.14702223181243868, 0.14611025010385822, 0.1419455203558168, 0.12038955284703164, 0.14157458058288022, 0.09460261196739252, 0.14317404959470997, 0.07557628210633993, 0.15718470988494737, 0.1683324076715977, 0.1514572680236832, 0.06026127285534336, 0.14812435654382552, 0.1020064916942389, 0.17155058982391513, 0.1837496513560895, 0.20621053724279328, 0.16403070140269496, 0.20055320774835927, 0.08791588246822359, 0.11393910784634853, 0.18449661772577994, 0.11387957515375269, 0.2174199204291067, 0.19810630759644896, 0.2170065853504404, 0.1149141998781312, 0.2684655232775596, 0.10924592298725921, 0.12594475516027984, 0.1701052577024506, 0.23864073979277767, 0.14978079185370477, 0.1513681413545724, 0.18469705697028868, 0.17849906858417297, 0.12737268942498392, 0.19053873786282158, 0.08097558552699705, 0.1522318442021647, 0.13251246523953256, 0.20253504656495588, 0.07810694631189108, 0.11446940922929395, 0.10728319806437339, 0.1570183768748276, 0.1363303563407352, 0.1560794748365879, 0.11578378628098196, 0.08186527407698094, 0.18135357347707595, 0.14147155707882297, 0.23911335475502477, 0.1083654121706082, 0.10984184746179851, 0.14188840084018248, 0.06320769680784115, 0.16948072750481868, 0.10163880013410123, 0.19436738483848112, 0.23751097460908277, 0.08984475396573545, 0.15669652801607886, 0.14271222115043672, 0.13372715893051318, 0.12144309994313987, 0.24662458638270057, 0.06271885227291815, 0.20291580758508176, 0.11520050991807254, 0.2380748919301456, 0.09913175441925565, 0.1177923845487737, 0.11040414067646188, 0.09913104195748607, 0.12983123411334332, 0.13263415064542525, 0.22137621297470986, 0.152122400881302, 0.19331412119490488, 0.26485596212648577, 0.19305244088172915, 0.1740339404392627, 0.13216654589820293, 0.24964458158900663, 0.10683704377903093, 0.1429698105540968, 0.20537383133365264, 0.16767773957502458, 0.07700318215234626, 0.08320232733122765, 0.20584214088176528, 0.14402164927413388, 0.1303915967864375, 0.09884837083518506, 0.10965974836219704, 0.15363292708512277, 0.1383562758564949, 0.09177972352312458, 0.22848615242588907, 0.11861337799458735, 0.13633774142832528, 0.12391063850373031, 0.13951130661993258, 0.08830893153865492, 0.1773061164684834, 0.058544462156151576, 0.14512116930657817, 0.14792843721807003, 0.17653563119951757, 0.15771473547624004, 0.24379790580320745, 0.16798009915697962, 0.22202527330767727, 0.09709914695591697, 0.12326177735362323, 0.1703371525171303, 0.11966312529459117, 0.11352433252238459, 0.08729242479368564, 0.1332451364085559, 0.07160976994782686, 0.156076195980272, 0.09914619517662834, 0.12362835808627068, 0.11504283370149714, 0.1858120213352865, 0.24431352894152367, 0.1774477354821659, 0.19709989789032167, 0.12010442258249368, 0.12842432896216072], [0.04014193087876324, 0.06769309946966749, 0.07217627664607379, 0.0949926273296437, 0.040698455451356794, 0.02196015932807519, 0.06998312013644366, 0.024702183361495697, 0.007222345138284108, 0.04501911090506662, 0.054541591464752154, 0.05710973652199872, 0.04330493937877398, 0.07674863411774559, 0.12517068459982836, 0.032315032721887675, 0.029538260855441614, 0.016625950398344188, 0.045773515988501816, 0.062249956667543425, 0.11654308666625332, 0.025791751911803603, 0.09630346505512154, 0.03656107887265183, 0.03226009655683752, 0.0388089532122737, 0.042431105018383077, 0.03352357855727596, 0.015054556593719511, 0.05176627708058204, 0.0683996853448691, 0.039065853136801915, 0.016309481392043735, 0.02705346616435676, 0.032753116270947846, 0.026911121282366016, 0.03721025028836824, 0.02594328218800647, 0.02768573768046354, 0.06543461864273395, 0.006697243098319779, 0.022074915468692783, 0.06350045730810493, 0.06414934910172898, 0.05290452668803835, 0.015324015572156399, 0.05370710721059192, 0.0276258813157197, 0.05875083858207349, 0.01745575577050688, 0.022738496998264905, 0.027332820125945637, 0.08202647429800804, 0.017769394081927115, 0.0304197522646357, 0.019037231292215087, 0.06316851907139344, 0.013129835377537436, 0.055879862798798474, 0.05020743754181651, 0.03668839119434838, 0.04200092366626186, 0.06249100623291828, 0.06115446625758083, 0.03693065117864359, 0.056291144761827686, 0.034941017417417425, 0.10287622365379527, 0.0371602209164731, 0.024370754573253856, 0.0398190746143941, 0.04902221908372256, 0.07080531634029842, 0.0129430171763224, 0.07507216560864642, 0.04575663524109029, 0.02569675509397301, 0.013276748058776702, 0.012893609293255837, 0.05582439803308057, 0.05673094817827787, 0.026856405367594094, 0.04288832927423139, 0.014630197509822827, 0.026609765275591807, 0.11255951372966652, 0.01791714179900385, 0.02469817672165171, 0.026462917711826104, 0.03413903061300516, 0.053530895496688546, 0.04503234124351894, 0.07346334266326121, 0.03331558951627343, 0.0600703331010957, 0.048794055117234114, 0.017566034127207055, 0.03765310656519667, 0.025685484025387034, 0.05785685993971364, 0.028378373094564004, 0.03791191021821672, 0.06614530308833046, 0.052495282518887715, 0.07456316146999598, 0.03684471909617705, 0.02760703746800221, 0.03732810142419992, 0.05540345953176579, 0.05904855184076775, 0.05894267465919257, 0.13020683170085953, 0.018043485019476186, 0.06559771110093401, 0.03948383453872897, 0.04291562881741313, 0.03230548343591152, 0.07603374384944478, 0.0919107552016935, 0.09698546716883298, 0.040614040222980326, 0.054611623392350254, 0.03298104658061939, 0.035367579004096414, 0.03791575597959661, 0.0347884395159781, 0.020963220383911844, 0.035528794546881994, 0.02830504315845188, 0.051273529327684836, 0.0040473775269704, 0.0553799789368866, 0.0671249533432626, 0.05175875026672598, 0.06468228965757356, 0.08521445726435031, 0.059134832493239836, 0.010823523851051446, 0.05222969515729816, 0.04568738472317496, 0.08853889581176544, 0.013967425160620724, 0.03081219421038705, 0.013893620249995542, 0.024682161653594627, 0.022059903975816506, 0.009446382173337042, 0.07655005646689285, 0.03686807328654874, 0.023066884417447354, 0.013661770442981395, 0.05890599819981764, 0.01635227314827423, 0.05806186506825109, 0.07556430049120419, 0.047126492380254695, 0.05519044878441961, 0.011005097222814878, 0.010271317141521122, 0.021842340750980283, 0.018533254605567744, 0.01692589105767829, 0.03080343016453328, 0.01860745213625412, 0.018822805197428794, 0.059902100192923705, 0.017046779732129747, 0.05752230168230111, 0.022220100621662797, 0.07988492913183667, 0.027147049549967054, 0.01126040368446059, 0.023014934080082084, 0.05595660182617365, 0.0441523973319319, 0.062118109105335134, 0.04129852063112682, 0.04734022708068933, 0.028511275942887992, 0.0406965057575895, 0.024596145301456415, 0.037428328707333536, 0.0928827369165036, 0.025444277411987706, 0.05056739161391893, 0.016194847825494026, 0.04918599336017524, 0.060730444252370834, 0.013834129692235542, 0.043830100311747486, 0.09390780086358709, 0.01804325327787909, 0.005811383551542437, 0.007632668533798068, 0.003855748054188406, 0.08933562725301712, 0.06068583495253998, 0.09036780049603793, 0.04812037654881997, 0.01409079404472704, 0.06510872483974503, 0.04522103252970884, 0.04693328883619078, 0.016492160803247845, 0.0334735989810959, 0.06287531040969395, 0.08595325713676792, 0.040589866318529656, 0.020402658527957338, 0.02330841853343431, 0.030618090513012106, 0.041961638677504756, 0.03562356345355511, 0.01586690090686804, 0.029141337295333226, 0.049863647924916404, 0.05043775421537219, 0.02102387156487713, 0.026929744879805276, 0.017205511234820853, 0.0492470505677404, 0.04078355632842549, 0.039463786017750545, 0.03912313736133999, 0.047698396167928175, 0.012211759439519337, 0.009296576552573712, 0.015521162553810546, 0.08612732763492292, 0.05246210708132675, 0.09015933265008273, 0.0469160748405322, 0.030392019881776748, 0.02312620643586401, 0.03341359897486625, 0.04789489772050612, 0.01870391984289933, 0.002968803295985826, 0.05729197351742656, 0.035797794830174215, 0.014746730016814846, 0.03014844414147158, 0.079231632332648, 0.06044003564203459, 0.08468529735241206, 0.020113701654237606, 0.05189774159882819, 0.026932602387762843, 0.04923958121047867, 0.014279637590891892, 0.014569850848807443, 0.003718283631080281, 0.03249775235270781, 0.004862870940292675, 0.03117425502428124, 0.0246314006677318, 0.12218049787465604, 0.03040617718661745, 0.085111242238312, 0.026919283949199225, 0.09314935849679094, 0.02085323505584271, 0.10263404793917172, 0.06859863837880474, 0.017007130851608612, 0.05282650446339, 0.038239045083642974, 0.02791906507956165, 0.059103932336813984, 0.02908641262160194, 0.04426827962179819, 0.03460418004843016, 0.015942671790628905, 0.09679088083606574, 0.041589611059715675, 0.05357221061844499, 0.009684463148005307, 0.032772862187196175, 0.012197666294542293, 0.06456360731634402, 0.009905667205701673, 0.0671376780636849, 0.03115637644734835, 0.03069305604684257, 0.06717772914036628, 0.06942042855605965, 0.025498133393064625, 0.06925777276797641, 0.044834633102460254, 0.0723196346793444, 0.06008452871033262, 0.06430014201830472, 0.007793464643445107, 0.07576646343354257, 0.04276008232526722, 0.1299293086894097, 0.03864100758707331, 0.04447935599713557, 0.03958455977901336, 0.02460896386764944, 0.02196008463450257, 0.04476162875371595, 0.039090356459060026, 0.03132051461556506, 0.018458505491575888, 0.030237069022991968, 0.02825806281649538, 0.06850673081052881, 0.09916329425909828, 0.02383486840934042, 0.07785089674495882, 0.027006413044047453, 0.023616196272233804, 0.04808699809795907, 0.02051757554703903, 0.016276288717504472, 0.04253652637764331, 0.015631325997322077, 0.020879559752140796, 0.0871332930100541, 0.033713093387984464, 0.02298930077813566, 0.018716338128151915, 0.09745727007788035, 0.049035817144378546, 0.032084942044269656, 0.05530961376104144, 0.07225455551017677, 0.02110575295744404, 0.027295952144589637, 0.01713885775496883, 0.02650775109237481, 0.04568442762378724, 0.013746234509463032, 0.028590573703930266, 0.04570297844287369, 0.03767238516781119, 0.07828432630987898, 0.038565298947956295, 0.03309468040242791, 0.04316366893509704, 0.04986216937522254, 0.01852174413450543, 0.03608451472715505, 0.04703843440379828, 0.07533141742310218, 0.025899860324458252, 0.02581374438088988, 0.05404652629588401, 0.03780648502851686, 0.042485834339693676, 0.05439665912079716, 0.21860450686466312, 0.09634297987025592, 0.17505498242474374, 0.19964876434495374, 0.14119847737733396, 0.22517846056049873, 0.18427310391299187, 0.15123525574322672, 0.19276338058613962, 0.13657335943031695, 0.12008371522590039, 0.19289294137589394, 0.0591790855621859, 0.15877524631158, 0.20636666596176165, 0.1835280987283876, 0.08361990653699444, 0.10724005965335716, 0.09312109751326424, 0.13374813441787997, 0.15758696733222854, 0.2163033626012264, 0.16356381677812146, 0.22094714245007885, 0.10575662997941818, 0.0795093085616827, 0.1773225260718215, 0.0863896054966796, 0.14443086279976752, 0.1419139268898195, 0.20238280957264287, 0.16657642689683747, 0.10067205079981398, 0.08545956709572385, 0.14679763015479813, 0.13857058129243313, 0.17690248006293852, 0.12375456341091665, 0.10072949973325576, 0.1765525310991272, 0.1667689907574846, 0.10707133644891363, 0.16454791800389368, 0.2226241242380873, 0.15193887685816135, 0.16921690214545498, 0.26092029266780425, 0.08036879792569146, 0.16115030273795128, 0.09109848749733741, 0.12172959384418304, 0.1211813583429302, 0.1686034036139327, 0.09903341171241577, 0.13988526477929086, 0.1679122697321638, 0.21266576263212392, 0.1130144780261382, 0.14203064804596288, 0.12799512820258258, 0.19680481614364734, 0.13674269550509993, 0.21667155977939406, 0.2339820518729187, 0.07405669308237492, 0.1498881973806889, 0.1461052705323504, 0.28117807822362073, 0.13663213369586777, 0.13475350224443022, 0.13951366617073938, 0.20579715619885153, 0.17613951777738912, 0.09816895809865768, 0.15503780976418527, 0.1509523701163069, 0.09878431822383597, 0.11759155459942357, 0.12453049556502413, 0.1264326995418918, 0.25966314238405996, 0.11897840356874852, 0.1533833356393922, 0.09424535452478355, 0.1776270306999645, 0.16944666723570517, 0.21629421551141048, 0.17476875665447406, 0.13927335971065108, 0.1347082724133807, 0.15260529674349294, 0.11543033629535668, 0.18011073371575725, 0.1871133289269863, 0.1424432017149464, 0.11599178681330335, 0.08642699824826372, 0.18481290478619838, 0.09438559458020235, 0.1846890590123592, 0.09145631184501034, 0.14575418775841115, 0.13039599413112288, 0.1815024703260391, 0.10968987093937975, 0.20655354545001062, 0.12711137683401186, 0.09397618953258761, 0.104294964863408, 0.18916733322605012, 0.13017209727437268, 0.2261205495245034, 0.12457626931849988, 0.16892799506745032, 0.12182212960455688, 0.21929957843836279, 0.1279871685490493, 0.1781048550600967, 0.20193827939369988, 0.23696086219241544, 0.1500237183344941, 0.21365378622806844, 0.1425674458545062, 0.11247577265866342, 0.10385690046654594, 0.14888292148468957, 0.09414482846735947, 0.07633051865043179, 0.11447464927069603, 0.09412970589173418, 0.11635541044656308, 0.21851154975593093, 0.24134398828591072, 0.10893998577469781, 0.25550363735566217, 0.13135616277014056, 0.14134340589084934, 0.10834032279108802, 0.07535819219605577, 0.12365454297152259, 0.1769958815026668, 0.16708687128078553, 0.094495099188099, 0.10509629283220538, 0.13732270067257268, 0.08286524864454424, 0.1621830658686738, 0.16685667718129774, 0.29587044951415836, 0.08572512381379643, 0.13245402805266843, 0.14497014273318554, 0.14168482063518417, 0.11412986373949437, 0.2661136946370525, 0.15097944366355098, 0.13539631129993548, 0.2143409824179065, 0.19129212404931747, 0.13198197999548528, 0.11760803315067485, 0.1751106770168389, 0.12204791103760082, 0.2002576050618964, 0.13875998887083224, 0.1760657435102809, 0.09263346722770123, 0.11657206011154961, 0.1161514548584819, 0.14840828405032236, 0.20417254418134692, 0.053349175610609596, 0.1941800303757191, 0.08619808351560947, 0.1516619973605679, 0.10913374473250682], [0.07450592704117298, 0.054925102740526206, 0.022110222545903058, 0.027467239828359698, 0.03492179627139722, 0.0315045059523395, 0.020593814702043613, 0.03881225122078773, 0.02308285160500917, 0.06873723900606556, 0.020461407895650596, 0.024875732919862194, 0.03603694449749685, 0.008837377705100563, 0.03342249708610677, 0.06363188735239449, 0.03651368101277659, 0.006825400510757801, 0.01983297448004446, 0.05277142274163423, 0.03656364143675855, 0.025045723999820413, 0.07320949942955086, 0.05636900610801193, 0.09728610305295837, 0.04130412073385331, 0.027691316715772116, 0.06151211823547079, 0.01630040325014101, 0.007768996273948541, 0.018896146624859785, 0.055602385752624085, 0.046991703040417165, 0.07486048785428848, 0.0082737993779442, 0.030429590748803272, 0.03454219587447663, 0.07183988743852224, 0.08178336395611686, 0.009482304036106554, 0.04325194524661188, 0.02426017361182359, 0.0348740421806372, 0.0190177075414648, 0.045581316019618706, 0.00848628631267216, 0.04723490148241963, 0.04497462800974327, 0.02443776428399067, 0.012788547037710107, 0.06704461370264331, 0.049899251861197334, 0.030523091779961705, 0.027267476656444134, 0.042773167107013926, 0.037845823643428665, 0.0574957758879229, 0.014636734155036751, 0.04331775602974719, 0.05382794991976792, 0.08034626727983837, 0.05082883827027775, 0.019349178464542476, 0.04314044114923285, 0.015075096368579375, 0.01167909276010769, 0.05591245600953699, 0.009900649329797636, 0.031181737788081653, 0.05919685497158959, 0.07115072240271876, 0.08784758572977397, 0.0985629877616321, 0.07614023007091976, 0.06424480748753394, 0.02644165302626789, 0.0166041360447003, 0.032707553191651265, 0.07844026350686628, 0.04374004667624832, 0.05765463571034132, 0.08850063738082686, 0.017887354385288014, 0.0413736853478176, 0.062164840468716245, 0.004135684003197258, 0.09295084979385139, 0.028172755095687126, 0.06499931982327854, 0.01080767444950799, 0.01794156085159029, 0.011406435364586933, 0.013162899732349381, 0.025263181887567047, 0.05278944112961331, 0.037105989552313284, 0.013271615269684024, 0.03859562836887856, 0.0897667508932852, 0.03923173798548599, 0.040662767245404186, 0.05971496406522009, 0.04564524222646029, 0.03708477657768996, 0.020894609549413287, 0.07022987705685439, 0.09670862597563575, 0.05305255402720744, 0.030690233012841597, 0.026460502619644808, 0.034627855995730046, 0.0253290175685599, 0.024253196466053208, 0.04662990652685685, 0.04720533814942164, 0.11534287969792083, 0.054253887144788626, 0.037894841779263756, 0.04286521640155585, 0.010589391102022942, 0.0641163690165887, 0.04170503369682739, 0.018802793065626777, 0.039190407541971055, 0.017823711630978414, 0.027642120464494633, 0.03716018261207688, 0.04568026393591877, 0.05431409016431821, 0.05613410822866906, 0.07461877945329874, 0.04098495318283958, 0.031016232152920098, 0.05556578590204159, 0.09048215444049529, 0.04512068650294696, 0.030442501245547208, 0.07020353129313839, 0.06502971819211399, 0.0713824103736589, 0.05443882076970993, 0.02294412457324084, 0.013707189880792173, 0.06248202768244571, 0.03583444830691142, 0.025298511947415052, 0.055283241184248086, 0.030318500338903362, 0.057144045769687624, 0.04862234033944626, 0.014324525555205202, 0.06717392934426185, 0.019345043504971172, 0.03408338198618543, 0.006765203715692605, 0.06061774505782993, 0.03933399540161894, 0.02152024482887599, 0.07143398341272147, 0.04576439571176325, 0.027666418858233, 0.012351896073068342, 0.02090532520425416, 0.01836151684514217, 0.08626569077492723, 0.028425901189386368, 0.010098037629147932, 0.018104509668304555, 0.002161412459475199, 0.10442637958593907, 0.044970958448585965, 0.04890621421978839, 0.026489602469448603, 0.02796045489489071, 0.01889015581729191, 0.0552519426621016, 0.03277902919498663, 0.01605267627089615, 0.018996988693552635, 0.059675529689317754, 0.035448550667253234, 0.05775207060299093, 0.058616673603894255, 0.06049335536156451, 0.0335730180414694, 0.005790791108137778, 0.01685410861917321, 0.09397549239257652, 0.030042285422584223, 0.028082433329414458, 0.00883395329207903, 0.012052364313163826, 0.048916483628413374, 0.026814237973021886, 0.014490979224173053, 0.04319973635457216, 0.04866558217233227, 0.03200695812401753, 0.06157864914125493, 0.05283508081770232, 0.10455525089656154, 0.03405663402630918, 0.09016196033166302, 0.03330618578700289, 0.019112064675878615, 0.042266216084000566, 0.055379936802050764, 0.02284107425610625, 0.12637706623683054, 0.10970326215629617, 0.027880622787521254, 0.05120628596013112, 0.02172035082513767, 0.03311248045534857, 0.09953365946609168, 0.03357868709210907, 0.0042877342615787305, 0.031052190404866013, 0.022570432629436258, 0.022170844998571183, 0.04273728737908025, 0.016434204336556218, 0.010635114102173718, 0.037264090947686665, 0.08635879344036503, 0.06857324256411484, 0.06707341860859625, 0.030394798865722075, 0.02570786528409489, 0.01932062062194511, 0.009201029109047546, 0.07651676228570362, 0.036421018847895247, 0.02473300116346969, 0.007571540941904871, 0.017000753169638977, 0.09235932266399746, 0.03359934848342692, 0.03908329312839816, 0.014680918276069627, 0.013074060346210196, 0.0257305970280281, 0.047945857889229254, 0.028647585967255217, 0.054825032505417065, 0.01792123462373932, 0.0077653496954289665, 0.02599537425163773, 0.1050913745477315, 0.002658114662476545, 0.015452373603869592, 0.07529880506016555, 0.06301741205876873, 0.015530457115551878, 0.0820413057602221, 0.04508383384334945, 0.05725117167457939, 0.17738459451544672, 0.059595370079360666, 0.009467921692938095, 0.04093868530265266, 0.003849212845389341, 0.023535111611108148, 0.07000482340733852, 0.06436173548741687, 0.026972835410326242, 0.05404228216878349, 0.021016113009423982, 0.024065855409829848, 0.04222068364822096, 0.017186495017320398, 0.05453609861433507, 0.010815908937084099, 0.04895424410220116, 0.02669717782297202, 0.06873037485826401, 0.023704346179241137, 0.016740857841326826, 0.03232381208949993, 0.03149458894415969, 0.01511218747304332, 0.022870084090578943, 0.0729227910238889, 0.08436417627719142, 0.029516766343506116, 0.03848667151384777, 0.07867355260156816, 0.08592210034088743, 0.019671841291710734, 0.04049682494012579, 0.041046876069759174, 0.05062294064930851, 0.006262548530714647, 0.037673476843103286, 0.06360450353954109, 0.016873057803980285, 0.03504222912353373, 0.019298844572697437, 0.03403351732319401, 0.032939244993031025, 0.005156341029496323, 0.05320878233760596, 0.05956846124102032, 0.014953546943293225, 0.05387177014903677, 0.04937413306305966, 0.04557507240303582, 0.04539842018857599, 0.0066549823367818, 0.07202105191085609, 0.05741228379549519, 0.04798138138627814, 0.041218288242816925, 0.041676768882861065, 0.0482065576098619, 0.05631739476455316, 0.020589145396145123, 0.03187224347775262, 0.04190312871228784, 0.03774495284643866, 0.10020186433628683, 0.016223133706878272, 0.041640774241738746, 0.09405518085846017, 0.04326131833236545, 0.04411300892130502, 0.05514886553188967, 0.06373749640319618, 0.011097272921864305, 0.02612664341746319, 0.05110359953476056, 0.04096332652073714, 0.02581094624474645, 0.028560805442412535, 0.037371580744342464, 0.027614424470812086, 0.023178603019445174, 0.054104461695157716, 0.038677879398868936, 0.03719898496544169, 0.030816273628583843, 0.06014704531539352, 0.029395747434107528, 0.010671645962452937, 0.04781954531227389, 0.028424979968657418, 0.026249127470016963, 0.03309741150587797, 0.021515295900885138, 0.029827418827241468, 0.050095190339150934, 0.037121514324098825, 0.1386126701629931, 0.15766349951586417, 0.12657515359141175, 0.1639867739211167, 0.10987966922262024, 0.16017210038919605, 0.1302726539753137, 0.14218429464005655, 0.1525357053164513, 0.10981180915428747, 0.10648425262902053, 0.10812381868280711, 0.19124972874358778, 0.14657235433978422, 0.1421365520406154, 0.2973250359777482, 0.12888618804995092, 0.04584164035716846, 0.1055828505946744, 0.1128526496130132, 0.13141453866997074, 0.07179982104008237, 0.1500719512302068, 0.22004852131489785, 0.2661933371376607, 0.14736467311459203, 0.12976184186916198, 0.1156786636960122, 0.10551997009784946, 0.09061568356569737, 0.1519076204708507, 0.2144552367709337, 0.25301270246986424, 0.19342057677286287, 0.15848027181721505, 0.1348127361627356, 0.08928593112936906, 0.18313109664426697, 0.2089225651035386, 0.09767621800663973, 0.1648223613418879, 0.11118619387308437, 0.14461400377894604, 0.13565359426842583, 0.07794340186181568, 0.09021263704785416, 0.15421451039371953, 0.10599772551006849, 0.20665816241695037, 0.18074264900097925, 0.19708713486550317, 0.0996801354772141, 0.14534996912604378, 0.15212799332314922, 0.10949313189954528, 0.14985534753049576, 0.17991357332756444, 0.10561244457118935, 0.15826880090659665, 0.19396030103727696, 0.15674617051357226, 0.19790839644209032, 0.1936850303243245, 0.2076239234978153, 0.11239675835015313, 0.1291386446645183, 0.20738347914190064, 0.19598281912265286, 0.10991823408872851, 0.15696350965769063, 0.09964807469758297, 0.15093781444574558, 0.21720376106039171, 0.10521537353915554, 0.12611653505554124, 0.18465430926411383, 0.09721075830560538, 0.10308156586101941, 0.19868985209013187, 0.13859013185626076, 0.2892905509760303, 0.2460521501639197, 0.1361491459031259, 0.12621088644429562, 0.25471110407623554, 0.11971801549436585, 0.24791228825286513, 0.17288313848116707, 0.2716830925595376, 0.10525584596419528, 0.17319610071999414, 0.09799033703823244, 0.17449310289755945, 0.13357654604459965, 0.15718458731087948, 0.1655325554912129, 0.11605800745347816, 0.12450690771783553, 0.13604333383902428, 0.19145657248314352, 0.11163718217322904, 0.21607148310830518, 0.1662800581224503, 0.09532612838572073, 0.14784231361362243, 0.1442741671757352, 0.2043746381757721, 0.18453676073301226, 0.18482399773934197, 0.2091950319346882, 0.12871040151484553, 0.2266817548943143, 0.11061171986042492, 0.13540487616292893, 0.17041331697856227, 0.2535195155970512, 0.16167727929930534, 0.113123293154903, 0.12974621367550668, 0.12218242075534598, 0.1804476745066143, 0.11629192474027795, 0.08118458963449925, 0.11462146236050515, 0.11898757364120215, 0.12757544991590325, 0.13195211788819683, 0.19265263491580564, 0.13886486630766623, 0.12905458949746626, 0.21218055318440163, 0.14308640913617227, 0.09132642163744858, 0.1468500458905774, 0.18167491671779465, 0.13206241922753473, 0.16017122704896236, 0.11373181211491747, 0.11487549711619655, 0.22358021728934782, 0.07732172917214132, 0.2190951402148893, 0.11575295124202968, 0.16243034372887305, 0.16099550701197118, 0.23252348175212262, 0.12341099595951459, 0.10085820250453488, 0.2135928209510542, 0.14712787533719696, 0.10465794498281134, 0.2567833259461388, 0.15254030184399697, 0.10852792240198582, 0.191301133243307, 0.14855901951030379, 0.10854274620332065, 0.10149825364351274, 0.17817038622113968, 0.0817432439315223, 0.12926815948899717, 0.18102458467887295, 0.24538073538532182, 0.11170575470333138, 0.21276713138626469, 0.13504031024152233, 0.14768462207528854, 0.11099912286285432, 0.13128059585728954, 0.17930021269186852, 0.1466745811124002, 0.09386003528150821, 0.1878130429935071, 0.1234166190448788, 0.15825891837237344, 0.13315265427433676], [0.02440127551615719, 0.011936534691842334, 0.03946720276989284, 0.014395855044225052, 0.05231279271444487, 0.04178980898652827, 0.031108760252414696, 0.029744016750144864, 0.042887191633663835, 0.06594155434398882, 0.01995256272024445, 0.06609359981432077, 0.036117165394487886, 0.04380605281180432, 0.06090717307562309, 0.07462010478540775, 0.0542698294344929, 0.030135864977754896, 0.05732607975181553, 0.07282785740831206, 0.014309012274738523, 0.035532234281662016, 0.08550748589538759, 0.05114200735284437, 0.04048778510261928, 0.026916744367730235, 0.06027462193742395, 0.004489598908431588, 0.03219951432378542, 0.05713327457347224, 0.050366676577757445, 0.0010448111800454379, 0.08106380055147795, 0.07529153488576412, 0.04415291444128079, 0.06297263038915492, 0.039758362146394874, 0.026992703900642456, 0.06621128624124874, 0.04701730952928624, 0.019341149863096017, 0.03791844877865046, 0.025556639527841925, 0.04123637174826957, 0.08388367060932421, 0.05490846714125045, 0.07551353184446212, 0.013620286781881607, 0.11244607142983906, 0.03988673933030617, 0.04621770908875812, 0.01565042265405458, 0.061115315334210475, 0.029343670692234754, 0.016858689824960405, 0.012224461177303907, 0.03186194534083048, 0.018667883066941175, 0.01622542430977187, 0.05096257423921939, 0.05771679225407782, 0.039469592964216586, 0.0662612504956703, 0.034606830712648175, 0.04682369612818284, 0.08086720706834909, 0.02312025201747254, 0.01662874278882819, 0.06962726463473613, 0.04468978502817693, 0.008647427161885126, 0.017074579147682074, 0.026821803091274157, 0.03280200800227542, 0.02950453383457517, 0.024222328868364135, 0.0182229257939804, 0.043594731288331176, 0.03701761747980791, 0.07597733679558001, 0.028852947326677463, 0.023081095348442757, 0.04509891045369929, 0.026893884304069707, 0.03855839266531891, 0.009108246285318127, 0.12589035525677666, 0.03045157172657069, 0.10377532742436855, 0.0630333696702315, 0.024994794474614244, 0.08545140059845102, 0.012383444531400119, 0.022297013934040745, 0.05504740484719796, 0.0346797852656774, 0.03284493190867286, 0.016148455456019412, 0.02093205975759174, 0.051341508139645865, 0.07101142463544685, 0.03591025653745859, 0.04692620252289119, 0.03595810638920915, 0.0256324305214108, 0.03694511491865401, 0.05192269691296163, 0.04752919032809235, 0.06951075798321156, 0.020278918091207743, 0.002861766448815263, 0.07225319187367155, 0.01174203167113686, 0.042182739313331344, 0.05336958802335205, 0.02986112095025038, 0.034163457326470845, 0.05024965664732361, 0.06539603845486719, 0.04197264353053705, 0.018695611619360505, 0.009310074064189629, 0.046230709600833156, 0.04130803544314639, 0.009949175254141372, 0.047728415323241104, 0.024617452121850465, 0.047432161462042606, 0.03314033158183579, 0.05965986702170584, 0.01643211100130312, 0.05550924095235044, 0.031899617714506966, 0.025171714819847577, 0.0526302787024648, 0.037418733456081925, 0.015395272282823442, 0.05166635240217851, 0.020749167756988637, 0.025066245580092076, 0.019046759510773326, 0.006289342455866357, 0.06056218453112149, 0.025284400607849804, 0.009887078082219008, 0.02726659182489159, 0.025315928956373565, 0.11085787923225474, 0.045009584601728186, 0.0858978996233594, 0.07068828874898535, 0.05590743430319333, 0.03131926589224848, 0.06216576743510462, 0.015762688051308357, 0.0563616440030596, 0.04283692094407255, 0.04866446751440245, 0.006387345211189842, 0.08315306787769641, 0.0390263153390298, 0.031434945168814836, 0.042392969161512396, 0.029789468746692426, 0.03023529935988688, 0.04377649330924596, 0.02210817900636504, 0.04709534707569307, 0.05169854341675678, 0.04216865861728307, 0.035065253896097985, 0.041170779300192674, 0.021937218825182608, 0.032062922762106025, 0.03116974085118742, 0.00876869792268882, 0.012250501463460106, 0.03450720480853512, 0.09234675116116002, 0.06133718205796135, 0.03543633539530058, 0.033571045365064375, 0.049334357778031024, 0.10663853507609138, 0.017300870029195663, 0.036169328321252144, 0.03494579014518569, 0.04383925889288226, 0.007915828994760711, 0.02920646242977631, 0.017679250431096843, 0.015360974526453405, 0.029657642251902053, 0.02302682376466692, 0.03633298768451618, 0.04754710912464127, 0.032442429313255895, 0.014216594300383042, 0.013236289997885545, 0.023845580233741673, 0.03756047887427192, 0.06305256783361397, 0.0399072551649184, 0.04369832935833162, 0.038472123504165685, 0.03931368641074627, 0.029081551793722377, 0.04838578387974732, 0.053625963177652135, 0.028233230076429826, 0.03878985847076101, 0.03960678782013636, 0.018707321273283135, 0.02066471422421596, 0.10741023076397758, 0.022215695616098183, 0.04838958367585175, 0.02659016108560947, 0.028206807703921394, 0.03429631995517881, 0.03928429544753125, 0.05034648250007341, 0.047667852242387114, 0.025725613626080657, 0.04601702086567398, 0.06633603599883857, 0.06632180974608468, 0.04928155516784999, 0.031440715726104476, 0.02885203568204757, 0.03132283203153601, 0.051868523005396135, 0.05574149965879418, 0.02496795649940689, 0.019500174394418156, 0.027620842372397744, 0.04282284790890352, 0.020274666303227988, 0.09370410574540015, 0.09456535711163476, 0.0402668644974549, 0.045421150017289386, 0.02864188435787876, 0.03563716151421109, 0.012539404711025137, 0.026469856553200274, 0.02618198177867359, 0.06291754483695954, 0.0319730549029285, 0.010648572351783516, 0.03562928996078911, 0.032179998233914375, 0.022675610755780534, 0.0153081767043219, 0.058362412852265184, 0.08667428376934222, 0.01729965769505549, 0.014977356955979862, 0.03327983236240764, 0.02455916815257121, 0.09052429693720995, 0.009263829166640439, 0.06975739232955441, 0.019569059105349645, 0.03613259057484327, 0.0208525896267665, 0.004634849178875166, 0.09827712971356609, 0.043374852562743815, 0.012399216366541243, 0.06645528524513207, 0.02906980575062335, 0.03948005772526226, 0.04348647157331148, 0.043076365555246035, 0.01938888097121831, 0.038341972826709675, 0.034043070439609795, 0.08474246283332187, 0.05213378094917825, 0.06175452377647162, 0.07214970871685975, 0.10530891287471018, 0.04114149558928706, 0.04983820997539067, 0.09038867639197458, 0.03860213628579532, 0.09768692025494191, 0.033649799203680414, 0.08529678107269349, 0.06565460079019109, 0.04630326578814176, 0.036071311201780074, 0.02472423520239611, 0.06969609763473272, 0.08594289962803164, 0.016946498822841435, 0.017307297506880377, 0.04584167866156467, 0.026953313574795763, 0.02057839909778728, 0.05326030558095344, 0.06262617861671795, 0.02814534255453656, 0.03369554614407882, 0.04847548894524094, 0.05400428037729956, 0.024025580252430612, 0.05295466331224288, 0.03128045970844406, 0.11094330569669125, 0.02645564179176525, 0.04305528664600946, 0.14918658341611588, 0.028538328422714147, 0.051122146523407394, 0.031193029924085548, 0.04216522271294267, 0.011101635792593082, 0.0316744932018581, 0.04942120533556708, 0.0420347387872396, 0.0267813632249712, 0.07015824783593416, 0.030247005183369886, 0.05461971328083066, 0.0161939840613594, 0.06183214763539934, 0.06276138930491383, 0.04992590406008306, 0.023786262045764638, 0.04334446951566685, 0.013087819285330274, 0.03032412342426758, 0.03880771981071561, 0.01951473964107854, 0.025534495756390597, 0.021424412975207936, 0.03917550330140418, 0.03914089527942481, 0.049893950532761314, 0.06771723890016157, 0.05270239821965656, 0.07658114431486016, 0.04469332818482672, 0.06001188825335234, 0.025773128314364343, 0.029740496576132796, 0.03918742362950598, 0.02427243867949132, 0.04589957958688179, 0.032410456633736054, 0.13226200045356828, 0.14106792067327809, 0.21448160551728743, 0.24880301868242605, 0.20514201312776537, 0.2057552665111519, 0.1081078687322236, 0.26956780122653135, 0.1526474928663623, 0.1760658507625903, 0.12469487505093699, 0.17137167765007866, 0.08418020026217546, 0.1503475130565705, 0.1847894778174739, 0.1387634362664915, 0.16206688097407743, 0.18168110670822282, 0.10150636651463087, 0.1971879520363385, 0.112263543321, 0.14967724740985902, 0.20151006688754405, 0.10754056530253542, 0.09459886579744278, 0.14944501551649264, 0.16944337305763077, 0.10443121360074129, 0.10539417079980336, 0.1762234350486148, 0.0892391921051087, 0.10366925489037268, 0.22853723516868008, 0.11026965394135445, 0.07876130797329449, 0.11876353888862556, 0.09472520901791512, 0.07453862367378128, 0.12660326901823282, 0.08828669200621306, 0.2827692121988343, 0.09882730341726735, 0.10687789924803281, 0.12413792146910584, 0.15533690581158285, 0.10780500353223856, 0.12499374127195728, 0.14587463210186652, 0.23043020778606016, 0.13118724038283672, 0.2081520491910558, 0.11491729487334529, 0.09498585511239306, 0.1790609787548742, 0.19267927945381214, 0.10408891019441428, 0.19209132229368533, 0.0964378138944026, 0.11931431780178701, 0.16635147283875173, 0.15936611460581904, 0.18487276689660165, 0.15993174796383228, 0.23744476929066644, 0.09670871024530742, 0.1669754361313197, 0.09934157057995759, 0.1650198741305259, 0.15961904619489947, 0.1219749411628131, 0.10812305259488283, 0.14688329410649117, 0.13784206231995938, 0.12826593262293648, 0.12367218597641877, 0.1881249786745156, 0.08244407648641257, 0.16394883724710635, 0.15363769215201178, 0.18358056042944232, 0.15011992365602525, 0.11860551793248424, 0.09787673385994089, 0.06646381946460855, 0.1576488978800274, 0.09309888862433935, 0.20556484769669273, 0.15722707454716006, 0.30754679393383766, 0.13937572437909343, 0.09235330887379185, 0.19197216497794276, 0.13163048353406692, 0.09389313027983713, 0.09415507872378635, 0.09357291318836714, 0.28778760904265993, 0.14803584274505416, 0.11840272679804795, 0.13206913015775143, 0.11130584914597774, 0.1564087087829267, 0.2012861087437599, 0.18547624499807436, 0.11781643204871686, 0.18496733278997485, 0.21385583425721816, 0.22360414987610233, 0.167654435180368, 0.13482359928950188, 0.0892400884279801, 0.13811600003992358, 0.10555491136807589, 0.18010063667691525, 0.12522688480995356, 0.1351043245484752, 0.14702969350882117, 0.15794511343682968, 0.14787856489419937, 0.3936171399489526, 0.11650590841928798, 0.09358753780684165, 0.1442989731027234, 0.14831744134426117, 0.11654532364299221, 0.1464710162291604, 0.15208806482053575, 0.17594528384506705, 0.13897299195729917, 0.1329280679384547, 0.26718802569854644, 0.250490618449065, 0.10217573583847094, 0.13288481461424984, 0.18318311401432563, 0.12207181298083837, 0.1481878345892314, 0.28030372675388093, 0.1385661533042308, 0.1309896509854063, 0.14084236906661143, 0.1489363484565289, 0.165608030473513, 0.1381071440635189, 0.13536372191963658, 0.10315173951488349, 0.16304071662166428, 0.19920515347151987, 0.08947059662351686, 0.160857810368461, 0.15350186476303687, 0.13161114747485808, 0.14691239012585533, 0.21410187105498008, 0.09268484108390347, 0.14841402970975445, 0.10391045001245315, 0.10651224548177374, 0.23521618887541756, 0.17111097792944602, 0.16961396551660954, 0.11419979990610193, 0.07109416979214839, 0.19703180799561162, 0.10964937553170229, 0.23561631659826926, 0.11168088748930924, 0.141315535612164, 0.1011596121374638, 0.08876424057469254, 0.07562136638068384, 0.1416694682331816, 0.11951435868057514, 0.14703162405039036, 0.15571178327645027, 0.0786773907020688], [0.016360566050054568, 0.0269956112043151, 0.0520361966693834, 0.0018698189265823233, 0.036021350777798125, 0.019845471289309285, 0.08675480727106334, 0.07523990055966763, 0.026582904317746722, 0.017223665603406487, 0.07156020405912591, 0.05929389532895819, 0.07611029901571813, 0.008895071786678126, 0.029401638650245247, 0.039762629256133115, 0.04443183556319245, 0.03946049950055538, 0.030683702113287106, 0.06606470297781691, 0.006697577782981699, 0.022348629107939142, 0.06029949681232534, 0.019353792229066455, 0.018702056334023515, 0.025512070447627096, 0.04616474943055261, 0.03766769670971459, 0.07101948388041028, 0.037009788061221766, 0.03822802873929182, 0.03570324425855952, 0.026436589185088396, 0.07932384633609364, 0.08329064960801795, 0.027525847469786965, 0.025297814807403955, 0.008379687093228342, 0.06538594907690441, 0.01596203945096462, 0.03732200336432265, 0.02660226910525272, 0.020467030981014815, 0.05111144810554482, 0.03908785518198725, 0.004181055560512769, 0.011330722895030294, 0.019166746116693945, 0.07716013824627285, 0.005714102834087587, 0.03847096671140002, 0.06465697811255533, 0.06706734353135671, 0.058582475438954375, 0.026764467155801195, 0.06568064011873738, 0.0126531352514341, 0.08754553258298867, 0.052473368573813677, 0.02199229480127894, 0.04440846222062265, 0.024624915733452768, 0.0475343001345473, 0.020254041301086545, 0.04626535975764837, 0.02886910412100054, 0.03399157783977928, 0.06497757058710822, 0.061848591712694016, 0.0367283963057543, 0.05657122267650501, 0.09851351380348207, 0.04292061604980019, 0.027907456932288986, 0.015579935861751439, 0.0615017568962949, 0.03852400680883758, 0.045060675005398454, 0.05925411621348993, 0.021800113984593944, 0.02319617899164798, 0.028021835774603873, 0.029057776254992333, 0.014672049850736175, 0.017141577367100026, 0.037423027378897515, 0.06244425954777868, 0.009757624544774093, 0.006548029759282908, 0.07535790874352379, 0.07272141715211254, 0.015387875703914512, 0.007309247279584769, 0.0474085889366125, 0.04218421786302521, 0.02863639342268148, 0.058712296698602943, 0.020785982112189936, 0.026596111673561317, 0.013288107227473972, 0.083416763002113, 0.08129682151540633, 0.011189356690362818, 0.036643827859792984, 0.041726296467165795, 0.019547968704794205, 0.07010019369303219, 0.029453807322668935, 0.05945293901247844, 0.0711051095277071, 0.05384714425271077, 0.0086985731069299, 0.029597946765622305, 0.05680880569402249, 0.01095400969197433, 0.028673380147665743, 0.0213528354652226, 0.01839702885087219, 0.06651512437289761, 0.03863878210165328, 0.09734844728823631, 0.04852664063594515, 0.0043581276869161, 0.06826306888533216, 0.0364764568005358, 0.053795701448595336, 0.051913304675009944, 0.04586916589628785, 0.011552002603909182, 0.01479224330039635, 0.022442375287233342, 0.03167018395728402, 0.02827257635222087, 0.012249895296390019, 0.07149529342930164, 0.052494566226678516, 0.04921749489562166, 0.033387578798518065, 0.015068780931253589, 0.04991872964667217, 0.0903866769024922, 0.054445252077834266, 0.07176809733913792, 0.025285222237148595, 0.08561142104407472, 0.07391659858366174, 0.03477320585760378, 0.06661944256554689, 0.02075340422320991, 0.029315241169364705, 0.05108925836881803, 0.05830604027235701, 0.039775461228864814, 0.013858117820364575, 0.044223509443503235, 0.009013662197356744, 0.044173047231930884, 0.03151815189349075, 0.023428719235403885, 0.1567332083058934, 0.04047597968770612, 0.07807821035385132, 0.01839899386639797, 0.005688995738784152, 0.05593777138499483, 0.04528429607049592, 0.019777297124927564, 0.011044142809095643, 0.044129238493980906, 0.012814741499061066, 0.04865425939281141, 0.08656471021353238, 0.04967550439159236, 0.03152180613288957, 0.03183289911718138, 0.014618252283863485, 0.07975310072182648, 0.023376872319908395, 0.0385252095668787, 0.04317691459530785, 0.003279904659364313, 0.03088223188364458, 0.04506232592487528, 0.03937011644724877, 0.009889334211156014, 0.05579930099268114, 0.043244786154959476, 0.031504561493714014, 0.04869280127628196, 0.016143000909998532, 0.015663073638514165, 0.027723976959204002, 0.037435970434378234, 0.04989189741712424, 0.02748013883378477, 0.03241659682844916, 0.007811525645064972, 0.026013509468025258, 0.052722933206466906, 0.023685741733999986, 0.10242211737579877, 0.017013454907423547, 0.051902476022200245, 0.02608239609417656, 0.053890351611640186, 0.023527676727803006, 0.030234841622352123, 0.04328995469897505, 0.03213518975122321, 0.06993256599432038, 0.03288579120811436, 0.041279238198072686, 0.041613244872179725, 0.05604896904720415, 0.051028492274664106, 0.10048488019815377, 0.016582103355997996, 0.04867413554400687, 0.08362382890716677, 0.027296972956748742, 0.05961283305359464, 0.06548924071173515, 0.013966288477663073, 0.020646803088546283, 0.0163540753701161, 0.02585871565726496, 0.02832832265525095, 0.028760572444767724, 0.02786567258167892, 0.028343675057253534, 0.02772762545294339, 0.039817128751066425, 0.006500790862651963, 0.06332354079331122, 0.053641675640979124, 0.02101195698243476, 0.07786102442731781, 0.06780393707055239, 0.0134920695188245, 0.03857554154350393, 0.07244870517282717, 0.03165345642745736, 0.07166842930018902, 0.01701298950900955, 0.04844728924874817, 0.029882630783944365, 0.03329176801226793, 0.02032320180367078, 0.030294701817535588, 0.004967714381975032, 0.05554263089453021, 0.04638740139442586, 0.09394274979469278, 0.017568443473728917, 0.03227364482177842, 0.056515907297932336, 0.030813544440353592, 0.052786326982201114, 0.04899146831444195, 0.01805810772273089, 0.07882267161602936, 0.05459322962128828, 0.015422523945509909, 0.06238146715106503, 0.05113508957888811, 0.05658748672313749, 0.057611727125702374, 0.04413212281501582, 0.074867129836592, 0.038291954946133404, 0.03156100876719481, 0.014205944720625639, 0.020633565089214715, 0.02512052865518678, 0.06163661518404561, 0.04084433391389828, 0.10729178591000457, 0.03902476784142275, 0.02511219553379042, 0.0036103190993139102, 0.09100086491314635, 0.023687270079408924, 0.011646632657146022, 0.020447099288444848, 0.02528321700200679, 0.06326826371913476, 0.057385980166615023, 0.05662583708462696, 0.013440416998139793, 0.08125952835525237, 0.03620940238057125, 0.09296353620987746, 0.018135178083133315, 0.02672564373501847, 0.04848060258213551, 0.017340610840267712, 0.04628196088296752, 0.05287627336539088, 0.04442371120075545, 0.04891567923609288, 0.07172667496507207, 0.10927483514552155, 0.05459959198149943, 0.09171285170821414, 0.01450002384972909, 0.03088620021909235, 0.015974662664736954, 0.040152556518273014, 0.0168833865844194, 0.026149578174696337, 0.03870760744077064, 0.0219578170142467, 0.030916169578690204, 0.05582981427470523, 0.05173000281736736, 0.061754447167679194, 0.0793088922998117, 0.06516579839010393, 0.030157311609195128, 0.029113204631533836, 0.0722828931024959, 0.03595462068915367, 0.016853363598666845, 0.03560601620964947, 0.058352633739911744, 0.05273412575104064, 0.06472820896775493, 0.02741409439383255, 0.017543493905254913, 0.042337048573479544, 0.04115242766396653, 0.03768553889747109, 0.012739412073466568, 0.03018337583559896, 0.024568278853210713, 0.06512731779366732, 0.08207397941019266, 0.018748975388946074, 0.050750892654421835, 0.040356665323939056, 0.010029736102648802, 0.021251001312667807, 0.03474092674291423, 0.04077686838084652, 0.04638382376381948, 0.0621328869413945, 0.0643346619401728, 0.05598654054225453, 0.03290705780889238, 0.033687552016588955, 0.013097371444136146, 0.02446499296403941, 0.162935609358453, 0.07313403210813, 0.10267853466493469, 0.14503556664191908, 0.11589896760039753, 0.11845376357556352, 0.20383762586260998, 0.11142421739115832, 0.13722001424720212, 0.09959723710292771, 0.11338113536757809, 0.18819296131691626, 0.37554181631534334, 0.12169681294190308, 0.19117158777531118, 0.13440998841918286, 0.1493567928311325, 0.18402293024043884, 0.1944470273390893, 0.15283800361137237, 0.19121494835182545, 0.14128247125735208, 0.08767110971553672, 0.14235623541378206, 0.28355721023774916, 0.11708620470017196, 0.1773228478287497, 0.10911860683512305, 0.17877836891960713, 0.14310402915843073, 0.13756441673444164, 0.11584301253840809, 0.13148953867775778, 0.20288867275080374, 0.1650127648345886, 0.28592334940068187, 0.11871689945579537, 0.12344499494159415, 0.13139952334665483, 0.14636459129471935, 0.11022414065777295, 0.14898167021812933, 0.30549763131045526, 0.23751673559027336, 0.19745370793727138, 0.09149692982675568, 0.09012836737618332, 0.09321629925961457, 0.14516966267218515, 0.20819612989021888, 0.1032245102068109, 0.15400656348755284, 0.21795788269129493, 0.17566841966923208, 0.08541286637585971, 0.1651386024370309, 0.08675725875242103, 0.23846931995884066, 0.14357980040292587, 0.13791386008022294, 0.1606967173997433, 0.10066640473181203, 0.08487956958913034, 0.10261910156376901, 0.11476377851419872, 0.06529179687101035, 0.09355004546382735, 0.10529538376196738, 0.16683205511541138, 0.14040125563981073, 0.11503475147389597, 0.14605791097687137, 0.15032149671066194, 0.03761678633670654, 0.07889640757874136, 0.12137393752533583, 0.17922625456365848, 0.10260017153116004, 0.1358734768244528, 0.11073899004728564, 0.12229257653797827, 0.19899374384793544, 0.3000750771212963, 0.08110717644975071, 0.17038658051000488, 0.14609601619022508, 0.14305803323945693, 0.1408158777461898, 0.11181368117010403, 0.1523673651559699, 0.11868422580582481, 0.0741738279259974, 0.18996671533151982, 0.07458225238106905, 0.1267801970243454, 0.16976735164080897, 0.16407907219423404, 0.10434905067086221, 0.23424190889683463, 0.12243981097614574, 0.14867877437462731, 0.1736309628693327, 0.1145372309932305, 0.09495648330137615, 0.192274279411762, 0.0841062727774824, 0.09996910384225269, 0.17020423626226766, 0.12794073595995867, 0.12246521445171488, 0.20221681364120977, 0.1248742621992865, 0.1461743716631205, 0.11945559207590357, 0.15499356052567884, 0.11921218295972194, 0.09448592911564535, 0.11573038229178037, 0.24479711428284648, 0.1474982482050696, 0.24690780908830706, 0.1299554935746616, 0.14851691531798533, 0.1453904185684458, 0.1544705063344971, 0.16620205505000007, 0.20268916813356264, 0.18382308854451104, 0.11711143197551852, 0.08635602786295837, 0.07406881259333703, 0.07714383589524416, 0.12372814869928746, 0.07264061019785943, 0.13377837956913058, 0.1539026819650204, 0.11619452432158495, 0.13776769050427023, 0.12232638399807677, 0.14346102613114542, 0.14964315649722854, 0.2230473418509768, 0.1321674652037121, 0.10431874423257767, 0.19194659296303027, 0.22062667254959384, 0.11310246322424182, 0.20126592998783435, 0.09679838083684446, 0.1187172441953613, 0.17278917013637482, 0.15239033247193984, 0.13655193961195408, 0.07406799287925805, 0.11931781882360099, 0.11359446787185247, 0.10941414823455196, 0.14630114389283044, 0.17009874595509422, 0.2758291604057435, 0.1888643148084802, 0.15819101233876523, 0.10240668836500376, 0.27593224519683474, 0.15098889718853659, 0.08974117887837273, 0.1484792544356277, 0.0854932749643922, 0.17615690797327027, 0.09635247169963776, 0.15306042957930796, 0.19641366697126822, 0.07935159404071108, 0.10404658383659779, 0.16123543042809735, 0.17694276096599718], [0.030162442483067996, 0.012868474906070099, 0.058358659021436214, 0.05029038571181798, 0.030944698692990408, 0.028912771132684527, 0.11133078530791307, 0.0947110670348329, 0.062453942899141586, 0.01736971452051113, 0.026215651342945717, 0.05426164761546159, 0.04507802306644378, 0.07375551327582329, 0.005480738567008127, 0.061623373354274424, 0.08045863705657183, 0.1001912080532601, 0.06143707992328752, 0.026231543836934913, 0.05395789375348438, 0.06035438318166041, 0.035787127055828614, 0.042259957145659194, 0.05648931255564094, 0.021178699849594026, 0.05402017670172838, 0.07271904994042651, 0.02129933188459085, 0.012626753098541691, 0.07174582716317908, 0.025210746999589667, 0.06068578132638528, 0.03815799681169372, 0.04947095891580947, 0.03470078373568193, 0.06169456973551743, 0.017031004066549, 0.10135517906277411, 0.03665733782033767, 0.027300454826364597, 0.02037975249902135, 0.0543967204078311, 0.0251061606761669, 0.02287919670643826, 0.06194511879115336, 0.030408343300223354, 0.044746184421162453, 0.08076783014281143, 0.03944675588319379, 0.05293415896894951, 0.00698837997098904, 0.012004218559952514, 0.0249510987346331, 0.024017637835875637, 0.037691165813274925, 0.03411196855707996, 0.08010197716254382, 0.024808820885335727, 0.029197190850672704, 0.025477025755530885, 0.05212999264439268, 0.02118111302655551, 0.005384570592263293, 0.03755075338807318, 0.07547359568096938, 0.04344018071048683, 0.02860364699435811, 0.036471864103429744, 0.04798448021193186, 0.016765481822433013, 0.023876643183851437, 0.07390090144209324, 0.018474911264474356, 0.047948477909930294, 0.0373188624038331, 0.016129351138407667, 0.06908334220849699, 0.025041671394700968, 0.023021080020454623, 0.06366557606886472, 0.007918775081634521, 0.011714877684660738, 0.05643510034367923, 0.05039484563073324, 0.04270156852961068, 0.02278821801977052, 0.02439665792119359, 0.018654876809206702, 0.0536167586312419, 0.039960222484003154, 0.03698285240980406, 0.008458840255174906, 0.07095780614162646, 0.049258457616932934, 0.016848531499084447, 0.050172630336976824, 0.03354914674174882, 0.024734740183057807, 0.014119230270866426, 0.007679495658169711, 0.08441798629299288, 0.06380889196729948, 0.045656664597411314, 0.027680444012906764, 0.022204581595536683, 0.02244488422518536, 0.003440557606330502, 0.06890500460060374, 0.07651326126388966, 0.028472381658972274, 0.04747243087378241, 0.038206003711468754, 0.10213097332105522, 0.051243648068198276, 0.04653156382001696, 0.07554229844601885, 0.0721986310917043, 0.02467796540698938, 0.022262928767069694, 0.04184150459965871, 0.021966431672955235, 0.03593620393545397, 0.051327764522284276, 0.05878282658335182, 0.05402577680445487, 0.04132557885661241, 0.05944419411882278, 0.039762299838325674, 0.06767026238864468, 0.05513029556060511, 0.045699167155450394, 0.022722395745316343, 0.06452573959024684, 0.07107740012748588, 0.03018044937972821, 0.04701803731281431, 0.041009268813556245, 0.013267667044044263, 0.05814915312634361, 0.0346593651920557, 0.03404339219653799, 0.03607230328564202, 0.046414065084630446, 0.02173829834998375, 0.043412720288840995, 0.019996953685016885, 0.047576572866209095, 0.04128982553318624, 0.05936151791003443, 0.05766429990950612, 0.055444613775058146, 0.026494825273872386, 0.0412191424308525, 0.018830971694701625, 0.05613555996528557, 0.07994999297924581, 0.06111166109481166, 0.048493354115635164, 0.016108377566260677, 0.005281783139047724, 0.07223855193343855, 0.050485914332732085, 0.02239874274950595, 0.023911172681818568, 0.06246098707760535, 0.03366925400651751, 0.07211436908091269, 0.06882890142620572, 0.06327083011368109, 0.023315144785409494, 0.043598450645203554, 0.01938609432639374, 0.10461667582633034, 0.015488115435976897, 0.02415358779891845, 0.015127053409213982, 0.0053167100451255766, 0.039023902162068316, 0.011724879920122125, 0.09388071965546378, 0.031424183548698505, 0.06259648887921246, 0.08059418099301477, 0.04310879022664121, 0.024523704027336453, 0.031101147253667156, 0.03319036095373092, 0.08454541735831769, 0.050737681468167616, 0.035009589947519765, 0.028152511222288016, 0.044336116707493226, 0.025487515414434097, 0.06399168054603281, 0.044692374405360995, 0.05708653937965151, 0.04582702339957318, 0.040209400242254625, 0.022705356034660534, 0.005006973036459738, 0.01978272102743147, 0.08034904817900351, 0.0481940473940584, 0.0469160748405322, 0.047905209263966936, 0.09363383250010592, 0.06642186848987496, 0.027152077001970143, 0.05407545760634446, 0.025892931059183135, 0.013158559844258332, 0.005493064442904847, 0.023978858465148557, 0.043956979793766816, 0.04937310650524113, 0.06385935417887184, 0.05927547857525849, 0.0315797817517793, 0.0632596797039432, 0.04839909082699207, 0.08063525096663544, 0.028825168978543054, 0.02663397365399907, 0.08082649715605282, 0.060234318051727555, 0.05396125687947197, 0.022471038466920296, 0.012933595252463655, 0.03233017061927146, 0.03128095766559484, 0.01826796218782904, 0.019725457870311314, 0.03432131740414808, 0.023587360722763885, 0.04699205161042271, 0.03283567373610793, 0.058373521127167254, 0.02956438253843977, 0.010779159699356364, 0.018191282532267997, 0.05152454186651496, 0.028421319983599168, 0.08003208696121171, 0.05298940923004862, 0.010533465725940563, 0.013957206505320728, 0.009555317003340011, 0.05006753073464479, 0.027507922927578612, 0.029634171233121908, 0.08868744792116266, 0.021189926868124355, 0.014829227152550894, 0.04917477783296378, 0.01190806111891664, 0.017728697576169527, 0.03026597352037507, 0.024741127441126495, 0.028168156652921633, 0.06233115049619829, 0.05977474573639132, 0.02619269360307484, 0.03478036877969581, 0.019003847095694755, 0.03310968040398533, 0.033025575441218195, 0.06937503784654603, 0.0708585747727944, 0.028812448088560375, 0.04299258617984672, 0.033213435522010254, 0.08680968980995879, 0.02714950294654456, 0.036909491830174966, 0.0339506687446227, 0.031088349754892053, 0.04211710473041862, 0.041680300548191995, 0.07985164261152668, 0.03364411866172187, 0.02523487110832526, 0.017360140336677432, 0.040867515734487006, 0.041946692302102045, 0.03797097559717875, 0.020837154870312062, 0.06002401925563332, 0.058610648322369785, 0.07651478577885898, 0.03477475718565045, 0.031168938374086737, 0.07492516865773548, 0.05963894133005412, 0.019621742971902414, 0.07047067381321423, 0.05948833993545944, 0.015812373641247473, 0.0536814394346889, 0.02864406962368277, 0.007690901749752343, 0.03435706689713463, 0.06351121701300144, 0.022947707949506662, 0.04766979044483555, 0.04959454038931478, 0.11107069845761984, 0.00779571311150287, 0.022100154235358202, 0.058852866171829166, 0.017573327284246203, 0.07718580219173625, 0.04525054223655213, 0.03508584250906303, 0.04316548073303796, 0.023373869255245216, 0.02675959292138296, 0.07409590912321884, 0.02751441360751708, 0.05657867671200826, 0.06759785941892094, 0.03875257297148628, 0.10571857839221917, 0.07255619496948297, 0.010424397788160752, 0.059702653032276905, 0.08986011402861727, 0.044533043438869144, 0.026309169611082445, 0.03166609113254855, 0.04057469394718928, 0.03472806795710518, 0.023049731708822713, 0.05035728433980577, 0.025960262526848146, 0.037226556469836546, 0.03270746509153997, 0.032594455631389734, 0.052515629814156604, 0.030320509404484785, 0.06421473853650593, 0.048212912309193806, 0.03242495867814268, 0.07266258926040704, 0.04248279297063428, 0.04047534766516859, 0.04254829731859988, 0.030125193372969667, 0.041098835983223496, 0.0931151679927303, 0.05975111958480651, 0.008100223964110257, 0.07100713454307088, 0.09473455529059134, 0.1985142494161283, 0.07740012294943295, 0.1913088094443083, 0.14083017294685687, 0.16433445526467216, 0.21318395982586572, 0.22560639727500179, 0.10756095090220053, 0.0969732633881992, 0.15900259056398947, 0.22833901757915176, 0.1644358699840884, 0.1144697922732561, 0.18447144407658808, 0.20290474527545516, 0.28030093819383656, 0.1623559565914254, 0.1106412985151814, 0.11535265497983464, 0.3050191327929497, 0.09727620519697668, 0.13006404823353215, 0.18656439628572236, 0.07280526547542504, 0.09185833946591423, 0.12545399923598574, 0.14380542861838497, 0.16741497141699638, 0.27728077444818716, 0.18389580561028374, 0.203488917961236, 0.12763993153648992, 0.15325455625932063, 0.05731089588915629, 0.1321270923701025, 0.1080857287912119, 0.1915120678923784, 0.16012579803505253, 0.1428275633483164, 0.09654313566223269, 0.10298289373637208, 0.12706327417324628, 0.14289076560206954, 0.15057404525578022, 0.2215685470089797, 0.12354879219445492, 0.23608903881282578, 0.15637307037268916, 0.2882164650626721, 0.10812211030673598, 0.13893908490577053, 0.1700205283780252, 0.1005661774486784, 0.15746290705377058, 0.0676605637155233, 0.16700715217138493, 0.10503518199848552, 0.10110670610541299, 0.1897722975380959, 0.14814592957977327, 0.09069879644460256, 0.15568858613410305, 0.17755648932389675, 0.2303981240237913, 0.14021431486452782, 0.24670743113083227, 0.1223661209787092, 0.15576830524350369, 0.08552698283306054, 0.1332549423339867, 0.13597766478215495, 0.11573486390613741, 0.20686374977231028, 0.18211452861226377, 0.14605270157898628, 0.1651744553518872, 0.12371363899400159, 0.10145244158564076, 0.1267049518684226, 0.104989699358421, 0.10251638449488149, 0.14684112862713877, 0.1847779558550927, 0.16617724912301188, 0.11434321156552724, 0.09825756382797995, 0.14118038238056246, 0.12327191269686147, 0.12032982097157549, 0.13533761364317712, 0.10741160206136205, 0.22289202518520818, 0.13731038197875023, 0.1339310302489227, 0.16147998101528616, 0.1643896595604958, 0.14129336502763534, 0.08933971816253278, 0.12075873827862164, 0.13011462535829316, 0.1228978319634353, 0.176013465670328, 0.13817016245617023, 0.09737537527877478, 0.13551130109736997, 0.09424364614871242, 0.13382223044191638, 0.1970377068726286, 0.0994417978630912, 0.21693201435189094, 0.13858172021085216, 0.16981717799940418, 0.1107843884176785, 0.1064792730575127, 0.1991271044337942, 0.15608793244727198, 0.21924854166084723, 0.10338621604586802, 0.11762448105840914, 0.12393273247946655, 0.12424958644494896, 0.12605611370095324, 0.12298487487339205, 0.15780973037885082, 0.24521789573613675, 0.16584947074372924, 0.2805579147271572, 0.17853240873063767, 0.2540986014590148, 0.07739727310235463, 0.1840080681347078, 0.22687845562975253, 0.14018393181745084, 0.19999684405422982, 0.1819158207264639, 0.1515318849875081, 0.10120316423595914, 0.11695131193846466, 0.1389483852131713, 0.1430663529543146, 0.11953125858018476, 0.11229678387603453, 0.11845685090989837, 0.12653654276002801, 0.2221890016188545, 0.15666145651090532, 0.08632398240508572, 0.25120617521385996, 0.17210517619406024, 0.12528710698168125, 0.12026150125048815, 0.12845835858775725, 0.19914500024770537, 0.12291838610244375, 0.13920910025556243, 0.22203756135798272, 0.06636397522543708, 0.10028165239360064, 0.13611586704369516, 0.16059156417125658, 0.0928245525386545, 0.11510602063349179, 0.13186980940161214, 0.19751134839269424, 0.11393368394384462, 0.23048889012106005, 0.11664001211043327, 0.1932130435541753, 0.1417321801906632, 0.19339834490130026, 0.08272395138778994, 0.21228985860943797, 0.23724350267119948, 0.09082818869501354], [0.004938073003769763, 0.053133445251132214, 0.06034961428433176, 0.04343189930002536, 0.01298543737990962, 0.029184318658324982, 0.048476178424372796, 0.012568632880556247, 0.020802558339651556, 0.0828235428179464, 0.04145242003423553, 0.03395119351485083, 0.045183383138670076, 0.03291172711479087, 0.06921512465323172, 0.016524824877119353, 0.08308717665532905, 0.042146472710995905, 0.036388368180562417, 0.028506878598202622, 0.015419479703620799, 0.05121767768756517, 0.030883381015531, 0.04738696610494968, 0.010968666869185625, 0.0725325764787774, 0.10847922219263931, 0.03264619720979564, 0.03543432441449935, 0.07164609783719625, 0.09987240822445001, 0.03972189636119912, 0.05990435249142109, 0.021843219836873394, 0.04514441224596193, 0.02230338778557076, 0.047122060561612736, 0.02046518087867768, 0.05849523717657693, 0.03755476002791717, 0.03827842583339061, 0.022792762836381313, 0.006194107193169335, 0.0400333953720908, 0.06986753279042822, 0.06515356396595318, 0.05879226478657896, 0.029115131342663404, 0.06612270349456419, 0.03310773071021803, 0.08401697756902826, 0.04420937129086064, 0.018670604594292182, 0.018557832621398474, 0.039104123059059345, 0.01752469793803269, 0.0361428331703909, 0.006593479840610658, 0.04339825654883058, 0.056631283969768596, 0.046415271673111186, 0.010064273261495177, 0.062465667874822696, 0.04004631161449417, 0.038688229246725964, 0.048089392122722445, 0.07439035501691603, 0.030572316759536346, 0.06649120710790157, 0.03287647174851548, 0.02764563297762746, 0.0677874202149049, 0.03961223853571762, 0.07415003323506925, 0.02745631924499908, 0.02427246166212905, 0.03858832372052055, 0.01842206651945749, 0.05019815638661385, 0.03478925923005708, 0.035695763409978924, 0.02920010006956516, 0.07332273488563877, 0.028658655937761072, 0.024855410522450844, 0.016347329965942813, 0.07183411113557316, 0.07563533982442272, 0.03954989430043967, 0.011856485207024361, 0.02399888208826944, 0.05346488553069292, 0.021131447546424407, 0.020243469287731478, 0.07723464029690913, 0.002344020289338885, 0.03454313050174425, 0.037072771979916486, 0.050389689859002836, 0.03868821392496748, 0.05301147639270752, 0.013646249501635472, 0.04736821227256329, 0.02528689805448296, 0.03317147688639741, 0.03922335698359436, 0.009574437600320146, 0.11361404141831784, 0.062191377754413316, 0.033165704413887956, 0.10110055441938101, 0.049902335365092566, 0.018181587689586224, 0.012542902860009383, 0.011302093231690027, 0.04044126058297773, 0.05414733580584007, 0.021600017564431317, 0.03952868132581634, 0.0409131515921364, 0.03488111317217831, 0.016695026631256746, 0.1315726898610592, 0.05541212015574979, 0.06383827526963527, 0.045693275939312675, 0.031126290259342042, 0.0755092494129654, 0.032710567747633305, 0.022122889809731035, 0.011220560409128668, 0.009138329600494717, 0.06351468356085882, 0.05812223662712401, 0.022545525195798086, 0.043206543045779394, 0.02574479455248483, 0.0073386080780877706, 0.028309480722753272, 0.04801202107280974, 0.034000533407614116, 0.06356623361728365, 0.04057424195531396, 0.05611179591787439, 0.02610195431888344, 0.07010220850427305, 0.08376974567410447, 0.04445062769997505, 0.039805353979670235, 0.007596050009822414, 0.03611587070589585, 0.03330876750330771, 0.014135588163269625, 0.020025810301904718, 0.047041042933180455, 0.025573248314040325, 0.0686044683079085, 0.05700513104637785, 0.050871942207337394, 0.024716465155624097, 0.04838582218414353, 0.06339140852252323, 0.06558391385741773, 0.06874120734151333, 0.07415989278665475, 0.05119131277165106, 0.04334808928110907, 0.01651235679615169, 0.021414631947634682, 0.03050846716148719, 0.010192232927487744, 0.13567317547577043, 0.03732057461034387, 0.03371343429711077, 0.011434865845066887, 0.05147801351643378, 0.020864716798607862, 0.05618222621119311, 0.02751614113578633, 0.023379088229229374, 0.043547639863625656, 0.04201667443398507, 0.03162337023945105, 0.05007291633275248, 0.015812010707093344, 0.05423200767367117, 0.07467834278941154, 0.034948620840065905, 0.016922593049164263, 0.025470770647629135, 0.03484240274936442, 0.031997171350784843, 0.046590372559524355, 0.035183545532486135, 0.03943362896661124, 0.08132778678930576, 0.04197180466425996, 0.01570008238852625, 0.06334378466671033, 0.06817925886641588, 0.09956472433142124, 0.056311503548415444, 0.02315675993750413, 0.02884644132498051, 0.035583673255337823, 0.03936351276934147, 0.05471746226952923, 0.05019269801015335, 0.028446198688940178, 0.03284862062202827, 0.03590094473873896, 0.00656682045965065, 0.09050979489280332, 0.05737212929694403, 0.07069123818749382, 0.0017512276779950387, 0.05011838748149815, 0.036281617658753554, 0.0563269057461331, 0.04483589714753532, 0.04692827096028675, 0.0164528145274568, 0.030018439020721183, 0.03637616439992863, 0.04651233884355715, 0.03782598962706905, 0.027955965619654428, 0.04202464174839758, 0.015866906652527473, 0.00635522649615943, 0.03616533317272702, 0.04081341843571394, 0.0403881898420232, 0.033742514994716456, 0.0532652200349877, 0.04283795899320995, 0.04721552711881457, 0.02222139722547464, 0.033851326293041634, 0.06169700206467702, 0.016405355380547625, 0.04817170827018638, 0.019000478224047733, 0.03102219040175119, 0.014645719408778655, 0.06434170228819694, 0.04133718891910488, 0.039314739781642155, 0.02294961359321831, 0.07776137937100665, 0.05120946522501688, 0.011723333380124983, 0.0035717889465647, 0.0263820571314183, 0.0768563767234164, 0.028364449446540208, 0.025464392965659503, 0.024028045140326987, 0.04214697066814669, 0.021373464297803662, 0.023982692735209584, 0.030527814712014892, 0.01635510958881388, 0.07578477293493287, 0.01923401246688539, 0.04761991429052526, 0.03920715422399583, 0.04002034506430069, 0.04085867891028043, 0.01461302181856046, 0.07812767665112212, 0.016888954128409107, 0.08893897756934167, 0.03736900668891688, 0.058290607431122375, 0.04478625465004195, 0.006729842054717724, 0.007041694423664482, 0.04534212804789986, 0.010962566894088543, 0.0182761344307613, 0.03592698023684564, 0.04972027073944769, 0.027642695030437845, 0.021315345037428123, 0.015251842428809934, 0.06724953456150909, 0.017197653087937546, 0.01032686426169089, 0.057372803454317396, 0.01523500764667387, 0.06205873346076377, 0.024996857166350372, 0.018480951867757306, 0.011581707663173157, 0.016535695664764895, 0.04417220070477455, 0.02415127421338712, 0.01935632031921658, 0.07024688420877342, 0.03624180023888907, 0.02445696436259295, 0.01935686615686263, 0.06927467266758604, 0.024182557413775115, 0.14965072544592042, 0.0344478904509977, 0.03582148992967221, 0.043769809192106615, 0.07488592197337458, 0.039087430003189275, 0.014475985925884978, 0.03909523260869807, 0.04343032498934096, 0.020894707225623633, 0.03827209794713605, 0.042087660141048894, 0.04757607490905831, 0.012894225994034881, 0.04798358005862083, 0.053359077297030925, 0.07480453279229902, 0.03751590021795804, 0.0049769107887010665, 0.04555947485289747, 0.04204129649987144, 0.03157424293608675, 0.05719127892065914, 0.020399615243678133, 0.03181654888565742, 0.09630520407470966, 0.019228582818722053, 0.04465473650564109, 0.019625460413554986, 0.006912077613730705, 0.03700353678375964, 0.06927766807136998, 0.03139305356589537, 0.012747839998243558, 0.07871829213634615, 0.0245902904744951, 0.01309604228158752, 0.04065736632553801, 0.013041363713601905, 0.058344302533735196, 0.020297099272870732, 0.09005486890072785, 0.08533653337508441, 0.08792939625920788, 0.02037201501098612, 0.11052198798185396, 0.05171680312243201, 0.0708022136842051, 0.17853250066118856, 0.11450025192912548, 0.15928400530209466, 0.19130940699288923, 0.07158059731967027, 0.14360313544109946, 0.13506407428893352, 0.08025036839347693, 0.2347271489880739, 0.13484592309161542, 0.09454095721124642, 0.14103035172147138, 0.1448706279118215, 0.1666178109665071, 0.11486772898464434, 0.2154281837565284, 0.09333603114130036, 0.12399418805275234, 0.17307001796941604, 0.10541624179290188, 0.11477412836205576, 0.11970677698451666, 0.17340633056817517, 0.1461427322318477, 0.21424361264273045, 0.1618443630755909, 0.10543078214170472, 0.10540687253758793, 0.17485380773582768, 0.15564868827500652, 0.09141740990021537, 0.1464503318552048, 0.10373455622503835, 0.08364129571184035, 0.15353295261100416, 0.17866573867297944, 0.11057402067367109, 0.14532913153450336, 0.08125865501501868, 0.12738039626950218, 0.0663772591900441, 0.18468144409839185, 0.24890835577201462, 0.12586040887981653, 0.19842611866131907, 0.20478599674759373, 0.13260454900803106, 0.16766474672382878, 0.10362210217863323, 0.15126042939241857, 0.15152566435356296, 0.12942225041408695, 0.11384310936855693, 0.141377849203925, 0.11206023124677521, 0.11563262181176294, 0.16731993054911015, 0.11010839243329341, 0.21475744313530384, 0.17815374679142432, 0.06958067882806063, 0.1826973223397809, 0.18363343581797617, 0.14691717051450284, 0.10380037849949253, 0.09716896820933589, 0.14925206861188337, 0.18997846712027827, 0.16236392390583793, 0.10198310302991061, 0.17994816985822495, 0.09519227750359044, 0.19826614418097083, 0.1999358481336986, 0.08290794272456439, 0.1188871241925705, 0.1477760163646552, 0.21244348988177317, 0.19464021939183437, 0.11879446585812878, 0.08284988092078317, 0.17891753645193192, 0.11875167218667847, 0.07410989788871619, 0.12344340147871165, 0.10055798030788861, 0.2267763973964799, 0.11745123027433312, 0.1330644622324936, 0.14238286463003005, 0.18375268506426967, 0.13094625976537505, 0.14641794165776623, 0.22781691333699614, 0.12426277081812583, 0.11710960102537948, 0.10672588442121783, 0.15671355048975638, 0.1435073591288059, 0.09861538051477364, 0.11456287195605618, 0.16839200931210674, 0.0891235741155763, 0.17186601886585837, 0.19394209878819604, 0.11562309933886414, 0.14929677750314438, 0.19828315133288985, 0.05453829728667775, 0.16908142715692523, 0.08781260615515132, 0.09030684287990294, 0.11826571197279039, 0.15558118060711892, 0.18321101493652792, 0.13497303240001202, 0.09507050016714681, 0.08525825451098143, 0.19363270651909614, 0.19480308968453638, 0.10090198442940751, 0.26102175335249594, 0.09574903956344051, 0.16563257593060696, 0.09839882278033803, 0.07073132756857142, 0.14863938213356082, 0.09535564575344325, 0.25068627730492626, 0.11643705243665366, 0.11846122527194601, 0.1255691422510051, 0.1302461473331336, 0.21922635575456006, 0.18815870186494243, 0.10477290413672886, 0.10036009979704696, 0.1167567945536106, 0.218740364897155, 0.17430775558515904, 0.15430880049543996, 0.13446385972201824, 0.1435500761914638, 0.10191211732284677, 0.1803893292503011, 0.16545807642321433, 0.21085408726526847, 0.1759205238833543, 0.10326717364331407, 0.14916956094243836, 0.0966007684567763, 0.07522361353039742, 0.1091255092873208, 0.163206574657271, 0.1347925114415346, 0.13821773651626804, 0.11095248343002413, 0.11391488414618278, 0.17590236759954886, 0.18373606095631279, 0.21659908786175713, 0.19953683889921636, 0.14104268573705228, 0.07568893533560538, 0.12478990059706474, 0.12441222691127371, 0.171150416135788, 0.24044343660916054, 0.12213461686887088, 0.13533586696270974, 0.23663567319031686, 0.12580698956885647, 0.10984408443853741, 0.16258143158929964, 0.14900817686030943], [0.03599792380907363, 0.023309605969716946, 0.08785012148080334, 0.040872487645115585, 0.04916579162161197, 0.036240739207113945, 0.030950501809016834, 0.04413002373410329, 0.024179994849668398, 0.032754483737892685, 0.06441626562586715, 0.020751291735758706, 0.016661496878030802, 0.008195811627252449, 0.021296160280584328, 0.02158421317055341, 0.07160208608594633, 0.03174816596231634, 0.07846355257976441, 0.01208497763371035, 0.03434301684460333, 0.014159937310332974, 0.09874205315305341, 0.029055675258859995, 0.04997025672045927, 0.04653398082741807, 0.024314178980045745, 0.030232778930615996, 0.08710609688874214, 0.0018879744921803416, 0.08213732722065142, 0.016054114600973987, 0.05318581885207565, 0.05491767168766069, 0.03037134699914004, 0.05655481307316692, 0.03463709884653649, 0.08741839263107508, 0.020001031187993866, 0.04224830877877051, 0.052816959007853465, 0.04747437673711008, 0.018312529352824056, 0.06149589632367415, 0.02696802246294195, 0.0633222844091154, 0.05547586633192916, 0.07974986016990677, 0.07359301070532492, 0.06460661549241313, 0.056265568916475585, 0.05533298327317161, 0.032426471701793136, 0.0767841959191907, 0.039760664240607334, 0.03496409581613637, 0.04436879418790341, 0.04954168798341867, 0.07485987498394905, 0.034243992319510835, 0.03239180239277982, 0.04155801759371835, 0.029570875133598046, 0.06843599791247999, 0.04776142222145873, 0.09726947128412225, 0.07788118020060562, 0.03005043659809857, 0.05128748744966523, 0.04298495594412089, 0.050455738129394676, 0.015477886246967942, 0.09094942210903091, 0.0412536125570055, 0.023452538824189576, 0.01992757101693461, 0.01522647055436767, 0.02923918779068176, 0.04761589232892279, 0.022825315827503804, 0.03221082944242704, 0.024978589799795902, 0.018660166646323858, 0.01966663380904544, 0.04165058782804878, 0.029597389436657393, 0.03169525801504572, 0.07130179494138687, 0.04318933671100005, 0.11958598790149536, 0.09188635530130518, 0.05084732780233026, 0.04164407608069239, 0.06026532163002318, 0.05126716313703407, 0.03904368638271286, 0.05638647291268553, 0.1213249998287328, 0.036435352352958535, 0.03833721542069989, 0.029718634341993642, 0.006043468930593302, 0.03508671584929671, 0.01219189382203284, 0.02134603643489461, 0.01417109346573031, 0.07791026089821132, 0.030706845629479618, 0.03001502035335908, 0.06062807192304923, 0.05102520192702932, 0.030934423538706, 0.008593052156239508, 0.036726063568024866, 0.026179631803965858, 0.03401351093705143, 0.04243400466117648, 0.041785235441620314, 0.03836669448402621, 0.0277252467499385, 0.03466347142332985, 0.03219594435405827, 0.0484773965041724, 0.03407587049408786, 0.07249907545384861, 0.02685155794625321, 0.016307568087452845, 0.07549537556065668, 0.02406766146211134, 0.04376379923234063, 0.026611814560789256, 0.06166284220413335, 0.04850058215520075, 0.0340169238587541, 0.06338103952246808, 0.05484096330380248, 0.07247492070159606, 0.029729095272599693, 0.06041812935783979, 0.0673168660291741, 0.033607553285095966, 0.015382372319788463, 0.012858183472417297, 0.012392617476683472, 0.08477977897611358, 0.028647442325769414, 0.041331362820440726, 0.03219250461927826, 0.046986079955052946, 0.023122132763326652, 0.0958696294636015, 0.05804802568989897, 0.0719261642605547, 0.015297561598521088, 0.016569380550795508, 0.06753382212933033, 0.03832682343800703, 0.0264119632887624, 0.07747939006695825, 0.10026262276956152, 0.07267280887331694, 0.026255035923132976, 0.015426588041948215, 0.04150210849700436, 0.07734203050213476, 0.022267785764509634, 0.023106828241819338, 0.07893265885931831, 0.017095003051743392, 0.04125172798071177, 0.04123951270875912, 0.10185899678617717, 0.044756518947261, 0.04187033248824939, 0.0555439715483977, 0.04106078439602449, 0.015577009405880688, 0.026860752916564385, 0.08379193158039162, 0.03587105198793354, 0.03697959653612587, 0.10577403549705783, 0.02652054093027067, 0.056401020922367616, 0.0433395397398741, 0.0758453781506227, 0.03627596392987236, 0.02777427829231226, 0.045061766680690556, 0.009769345690015583, 0.02889188949108845, 0.11020715648849165, 0.037331062354027264, 0.031595668500109066, 0.07415753323584795, 0.026529124945462234, 0.08674395180517629, 0.01741063893742619, 0.022014335150860494, 0.04544390282864052, 0.02953759052850787, 0.032629439036452004, 0.026643189691728162, 0.01103664855397637, 0.09471780094768732, 0.05488879400335493, 0.07103937918380385, 0.04767081317221446, 0.03517611064918099, 0.004301184850309285, 0.038964400112989454, 0.0575082861037264, 0.00958369864571479, 0.014195150541772526, 0.033603573458329324, 0.005313277971224799, 0.06268258950102233, 0.04463670279590353, 0.02503629537269233, 0.03956502070650458, 0.013792858620534742, 0.061825417552984534, 0.09145265760561151, 0.0181757481843834, 0.03058448223577392, 0.07066693787853565, 0.07879808019365996, 0.009053138708094917, 0.0440925658650456, 0.020918923264910138, 0.07356677219391831, 0.024432175672583045, 0.06410311186505903, 0.032573181369732467, 0.03464963204497772, 0.030425088067028313, 0.051788478308627685, 0.0241650331525072, 0.020841017868670247, 0.04334545010820993, 0.05287949093467286, 0.09765796979228336, 0.042863155625039534, 0.0609149603593734, 0.03377686254680157, 0.01635002851065609, 0.08772023893412083, 0.013685146658380908, 0.007404226860437062, 0.008435970615415324, 0.02562602985680344, 0.05352302777370619, 0.01987304087848433, 0.033718505799169504, 0.02013488590056377, 0.004959553630361635, 0.04894040089340941, 0.03133241004580933, 0.020545579891111103, 0.058021779517613115, 0.011288781496395749, 0.017653718635800387, 0.053568284417833054, 0.021131330718015953, 0.018871315800014044, 0.05157943206628965, 0.043862750979080316, 0.03911563353012166, 0.028679935945077773, 0.03873281939435871, 0.08116343028603062, 0.029291496274151632, 0.029753640729693637, 0.016511408762345393, 0.07688977815691503, 0.017231433734958692, 0.020267292706956788, 0.041898999498375965, 0.022100866697127783, 0.027511525456042542, 0.035854922006687814, 0.04561708083436374, 0.05393994431341848, 0.046606881754292596, 0.04242964945132694, 0.06373013812868346, 0.058235912583768375, 0.07938775339073713, 0.035093254409730434, 0.009597588777391901, 0.030489987205533736, 0.013625488518887471, 0.15902319832915263, 0.03792267375355286, 0.03912118766757269, 0.003150080766288504, 0.017193636871994506, 0.004724696449439732, 0.02559033398997159, 0.035832605865453525, 0.022912308941745473, 0.03116496237775972, 0.04226960985350513, 0.03487891449983563, 0.044898245213252884, 0.0401508902770377, 0.016334342860406446, 0.07301263015476928, 0.0539283495726845, 0.02612748994461952, 0.015396983531724303, 0.029436430533326445, 0.0096567211890473, 0.016660280713451006, 0.07281524760107841, 0.03926204442377052, 0.043603591095175476, 0.006946981537170829, 0.013952398345985962, 0.0286141328228217, 0.026062439503749053, 0.013989679057211166, 0.07596283475117338, 0.02249508213642384, 0.05940351868048311, 0.06461444491099927, 0.03785904249056213, 0.03992479857838443, 0.008845033796293842, 0.029112871383286776, 0.026815634168263887, 0.0436387085656245, 0.020417827068858092, 0.032024762007377805, 0.023853195147709023, 0.04494620231731285, 0.061309216018285484, 0.02513556121548097, 0.039580396091144894, 0.045134640794487736, 0.03244074008938286, 0.03711130237206817, 0.08657343595498994, 0.03281453353983741, 0.026761647952239842, 0.07435404244930514, 0.11309258835089785, 0.034977873907454556, 0.03197936172176513, 0.1073923196283079, 0.07915077941311945, 0.04690230441009326, 0.11484691437574164, 0.14173322207024022, 0.19696310523056215, 0.1342094572441232, 0.11352691423868942, 0.22114640191918422, 0.1302365559123216, 0.13636291507751713, 0.11541533629379927, 0.1399827264850178, 0.11666290281761078, 0.1073565050178478, 0.10913860172994676, 0.10424618038438982, 0.09568676427607575, 0.10172388951985106, 0.1540127994432565, 0.13919302773091102, 0.20910575204799253, 0.11725209337929565, 0.18974044360220435, 0.14514177707174133, 0.12013504311682717, 0.10114132561871123, 0.09697763008936759, 0.11017299662794798, 0.0979892032281045, 0.1321460453853492, 0.23639924313512542, 0.1724657584582606, 0.1632225552513715, 0.09968810279162661, 0.11192002183487339, 0.11273241211329738, 0.17252752046671607, 0.15219801375942846, 0.12057594203900908, 0.22931030981483, 0.1971889019853646, 0.08288470727782096, 0.1332522610262517, 0.07853234727536479, 0.11637830115374058, 0.20541903052118518, 0.09033655943048578, 0.1620717992585513, 0.16167629870676226, 0.15474629798723807, 0.15352671665530052, 0.17912782758714693, 0.16669016031007614, 0.19021155703211987, 0.1328768779433543, 0.13052129547201818, 0.21043430172627975, 0.11781236412183893, 0.13702879870130172, 0.13313140299531723, 0.11369348473606572, 0.10715787374084035, 0.15137223226408805, 0.1257073291907868, 0.08072584086368162, 0.147806047011287, 0.11089956973709407, 0.19741687442987196, 0.20602584876600774, 0.2062046690092933, 0.10265865468329961, 0.124048856087029, 0.1526029831579616, 0.09175363822930283, 0.13835699597914375, 0.1425148615793836, 0.17311299550196818, 0.14842936678999855, 0.12155661885175975, 0.13642291508374677, 0.19625433600477635, 0.09407236421060178, 0.08886439124903373, 0.13457929385044884, 0.11945776010472929, 0.1256962668811602, 0.15882493477434884, 0.20365505178849544, 0.10028898385503601, 0.17661507451726546, 0.14615799270329938, 0.1329272099199795, 0.11226211839746084, 0.11646574242941796, 0.17481505900861757, 0.08652554779884317, 0.14507169534842815, 0.11416403892179651, 0.3092443528434923, 0.23448975366209787, 0.3079275089886881, 0.07910369564929316, 0.1112113445396385, 0.08529147208337823, 0.11207506270898927, 0.11106391857948997, 0.11468667942549914, 0.15525799875538196, 0.15505113969406775, 0.14889969881023132, 0.12428672638751807, 0.13483600991387523, 0.1374384872014484, 0.17603574350716608, 0.13091514127389078, 0.1446799333057096, 0.09653579653991808, 0.09585790065748077, 0.20801441383457955, 0.19715691015364664, 0.13516106102014744, 0.062320432926137606, 0.1177141363281877, 0.1487547856184744, 0.15563759532186294, 0.18365804256210405, 0.14512544407719566, 0.07406720380869604, 0.09161182003276003, 0.17288464001349865, 0.2360258518808311, 0.0924989651708353, 0.11575851304035996, 0.20023996971787947, 0.1336082314411479, 0.13270211796606743, 0.10547947469017199, 0.10703453358503119, 0.1850836402586391, 0.1855448711543314, 0.16965536490803765, 0.18992715455110998, 0.1322640229256884, 0.1361275269019027, 0.13720614805577264, 0.13750630130450572, 0.12372131519500287, 0.1585461094134277, 0.19700167009667044, 0.07353345503009136, 0.10498714828563314, 0.11604409529677323, 0.12375834022438335, 0.178162066506282, 0.1712474947975528, 0.15074946406868198, 0.1557401744949241, 0.156703821173118, 0.13045950282004573, 0.1984425895516911, 0.1652057883479903, 0.16205548158576413, 0.18869828823353016, 0.1241267825506868, 0.13133776133819935, 0.19455501509289588, 0.2546758027446847, 0.15060723218466007, 0.08471429378034608, 0.18027366529549324, 0.1516779932764269, 0.18715155671440786, 0.2331409332973342, 0.15374669114187842, 0.1491597243734906, 0.2192223720973538, 0.14430952979432, 0.10338005669895681], [0.029397555401608832, 0.019483209377334967, 0.011921809524327759, 0.006967021439660101, 0.0644402901431726, 0.025353884782582044, 0.06461446023275776, 0.07272343962423264, 0.030102882977394812, 0.03249304474241311, 0.025306071320007888, 0.009093621666843613, 0.05711488463284989, 0.045801443723781456, 0.07038527033141545, 0.06827540290091308, 0.0388831909625761, 0.01408925995365867, 0.059115925443268595, 0.003277215690750088, 0.07943731161855883, 0.014609035288524485, 0.029238027167476477, 0.06833193252884573, 0.09117603857791232, 0.019354179103468216, 0.03177048018833082, 0.06138781663931667, 0.07989023046027269, 0.03696176200924862, 0.035837799941580144, 0.026442244829189394, 0.017339624502065203, 0.014718280384136785, 0.0635881667145558, 0.07528444091158529, 0.019036986144079317, 0.0383833377441812, 0.05361328059206567, 0.03840235970734108, 0.024661186166227828, 0.035117914780013026, 0.005374877185996382, 0.05342630151238653, 0.02716206678850276, 0.0067859637408307005, 0.02596757675130521, 0.01858292200091866, 0.013803955404117945, 0.031264975156274535, 0.03176690255772443, 0.059400488802742575, 0.049437997982867306, 0.08350998058073944, 0.007293805341056038, 0.03419987714639114, 0.01987195111841204, 0.1276864790387692, 0.11839284426382474, 0.08636992469790482, 0.007663608909839945, 0.029263241036284356, 0.09622655748840302, 0.07339193560783902, 0.051453464228900216, 0.03303007237733372, 0.07397426968260158, 0.03612055533355282, 0.02499218403001226, 0.05604483600285265, 0.0404648790736833, 0.014581568163609313, 0.02913200634441549, 0.02541984495286259, 0.09582750228864532, 0.013804297270854155, 0.04777372559352268, 0.037094682094550906, 0.021383944380607818, 0.01150344507843857, 0.07690751309236211, 0.019292805884634296, 0.04356761177581164, 0.031554887724679806, 0.07321423385292292, 0.022674057512514056, 0.035666238381377155, 0.01861165604373861, 0.04319172690532381, 0.06887604647706594, 0.023792819758396477, 0.01576111182540415, 0.02785253608899732, 0.042745733498445446, 0.08134760548390689, 0.04248457795549785, 0.049293479326391415, 0.050683358173456886, 0.04433514760626901, 0.06378466443669412, 0.07160980059134384, 0.015297835474954018, 0.032999903834875555, 0.02076004429029361, 0.02329079468073624, 0.04240119694581917, 0.021355417181527423, 0.0390323827553901, 0.01572311099153012, 0.0271596038158262, 0.03516668393727272, 0.023813766517466115, 0.024345818411318526, 0.02631661407048664, 0.04224849647031196, 0.035037793474452156, 0.10449502106395461, 0.03731185269932594, 0.011775164016252084, 0.04706338588749209, 0.008160210563801229, 0.02002477608320694, 0.05046274400346222, 0.041541550533785936, 0.023917636548679684, 0.017035979807617205, 0.0333152792506641, 0.01911819720971248, 0.013343515494207462, 0.06757540538186027, 0.04430154315947045, 0.05278795491904021, 0.04169926122431794, 0.00799467859436728, 0.0315598615505282, 0.02867141513213996, 0.014376965231232107, 0.04744459506905368, 0.10286262559313929, 0.0608155757729565, 0.07645062591520048, 0.024177104782974048, 0.020740068547667998, 0.018169102371640263, 0.053661724161957546, 0.02215704009417565, 0.02278388196211909, 0.009796565751575175, 0.029530211186577237, 0.025371774850833802, 0.028506384471491463, 0.025302152780275193, 0.009352460751430163, 0.039044854666797385, 0.0262061805809818, 0.06459127841216904, 0.05187319231129462, 0.01652891004097558, 0.031765958354357755, 0.04378989218704162, 0.008175168430522807, 0.016625425628116055, 0.052450110144432516, 0.007777440478093923, 0.05474052534648969, 0.010136585258277915, 0.017025959377567616, 0.020894937052000916, 0.02971115157819323, 0.05087587223838895, 0.03226647040836754, 0.013773919011826717, 0.05903889530248219, 0.05145285901944003, 0.03904248362467174, 0.026736736688162052, 0.03045736335127825, 0.006958190361112958, 0.049120247694513494, 0.033688907992214925, 0.08661283585693567, 0.034221852378499125, 0.06274276187703495, 0.028507043307106343, 0.1008696938233991, 0.008155732779883811, 0.05961801946884202, 0.02133331362969212, 0.12277282939683046, 0.03659264169513218, 0.021648418999487357, 0.04398170911196259, 0.011872694669892232, 0.05699422961521534, 0.0520112298639311, 0.009023715186143115, 0.05104777853815787, 0.06186689355320508, 0.051698305929500254, 0.028463692306691123, 0.15443661460472694, 0.04551376238645566, 0.024264379434527892, 0.0817488287124903, 0.10877647196813937, 0.06617533373496225, 0.04879980460710583, 0.020426790297572172, 0.03310359766586654, 0.03798126032756221, 0.01610417365877619, 0.043699482320657665, 0.022608443997019244, 0.02499137197681252, 0.026998955178104585, 0.029995747496403997, 0.06303007166171748, 0.04483191349032906, 0.03473143108309277, 0.03247751614018794, 0.03128972362666842, 0.01557816619864635, 0.01969190321922783, 0.032567412727662635, 0.05272562217508113, 0.03117659733810973, 0.0265743815895891, 0.030378573123485814, 0.06337673793877326, 0.03149665929677506, 0.06144884703380447, 0.09510745624861411, 0.03046536513964736, 0.05577729894749581, 0.12182628946198572, 0.05988438824011434, 0.06479789998622672, 0.06405780159477746, 0.03289920540766851, 0.03776824191933678, 0.02022982909223966, 0.06257576237042105, 0.06751247891975988, 0.09350716752270538, 0.04919608273813802, 0.04857139166204199, 0.03651872570175798, 0.041212197843818896, 0.050540942428333145, 0.01829139873265259, 0.05115617997944356, 0.05960807564758486, 0.06688410296074807, 0.04123549840803589, 0.04447185216591724, 0.011127377304458811, 0.005289090660235455, 0.04382022160796389, 0.03456736186278924, 0.007248772777647021, 0.025500423995958223, 0.06078139292977511, 0.04502689052793769, 0.01947362944784184, 0.01510439157080386, 0.027807528423445842, 0.050437382662728916, 0.04108243021032503, 0.042319493668694655, 0.04995718343003143, 0.028650175344439286, 0.039568165497433756, 0.07207685375526067, 0.028174886735336437, 0.020208290530248516, 0.03472707587324324, 0.07756939773718197, 0.008420634492781133, 0.02585353115723739, 0.046503597780341105, 0.0293573702595407, 0.03002987096777126, 0.024880833150218093, 0.05223129628105991, 0.09060914883570326, 0.10298281712757965, 0.03369747668564801, 0.05866885568285662, 0.026742095473192395, 0.03758212851901208, 0.04257204221381296, 0.030032527377648704, 0.08351998568903055, 0.03797777845794636, 0.03381594452225874, 0.07928256185785418, 0.025156634379058115, 0.006269327451234624, 0.05541826035046289, 0.05539795135959022, 0.03615733138435791, 0.015164559158766943, 0.07737815920864383, 0.03716325845509287, 0.023325829796733397, 0.03842238141524215, 0.017803214948564287, 0.07554444349220685, 0.05787984257744205, 0.044281609551680666, 0.044572887671810967, 0.0400917214762059, 0.037202949470449845, 0.021309174199198044, 0.010217831755477575, 0.061348271180665305, 0.00973819655501434, 0.029433182320527496, 0.10355333046567056, 0.026358861904290896, 0.0320221477323362, 0.02091553907150463, 0.014351325226016344, 0.04997483409580685, 0.04513866275609021, 0.04191701788635504, 0.019032167451035593, 0.02277677458140158, 0.012907598058753198, 0.0043169739224287055, 0.048740750719462676, 0.070804703469959, 0.0568465699982499, 0.02556771715922702, 0.050820089546182466, 0.008004292519012047, 0.008273304293623135, 0.06581069886564248, 0.0617723812859866, 0.02524844810156332, 0.060737442465559136, 0.05886966264956902, 0.03352270521704228, 0.09154965199770466, 0.0461208985577668, 0.02530990175962929, 0.0279345017512359, 0.03847315389242384, 0.11438345416418969, 0.01437723815005513, 0.02107000154923768, 0.04882803494711557, 0.11163614795453126, 0.10013032704591752, 0.1087628202813287, 0.09463988214490876, 0.1765929958632877, 0.1603950932621956, 0.14346879426269762, 0.1582772891607977, 0.25479672206265314, 0.1495028857982928, 0.16461429186165333, 0.15034561315851827, 0.3359928949465675, 0.17514121328150073, 0.15977336694636654, 0.14907110332240983, 0.09678936398197567, 0.14118815051211467, 0.18060936502391295, 0.06305065261380327, 0.20356332042044212, 0.11514688376337291, 0.06722806877787076, 0.23284721518716506, 0.38865800766694936, 0.12594460194269497, 0.17487931846370622, 0.14485783424348603, 0.1640954205105382, 0.20355328466863404, 0.07918554448312329, 0.1447433040988061, 0.12285543665770562, 0.09351488202810289, 0.15353805475657986, 0.12223126652139811, 0.10321474258577633, 0.1639272642111586, 0.11852627379759667, 0.1286894260274787, 0.21204575235324524, 0.12999174485523857, 0.18522775671895475, 0.1662264166459922, 0.10503754921017155, 0.10843711800032085, 0.1153003694790025, 0.11436846948439076, 0.105966568714188, 0.22480900699813522, 0.09572760442331915, 0.1699721729082446, 0.13420565744801877, 0.17588856269515332, 0.1517295050284555, 0.16191959290975527, 0.15705565471322308, 0.31654296442866325, 0.3786100290956036, 0.24989988805065233, 0.11862230291890523, 0.15076432617441302, 0.14322188412470205, 0.1992751739077991, 0.1447256227895137, 0.10448466355521834, 0.29013618947036807, 0.1674546854149911, 0.19059734358902902, 0.23978406473273234, 0.07713435172674156, 0.10171069748579495, 0.1763546199447686, 0.06964894492299327, 0.12875601438985718, 0.15531415300023171, 0.13189758774974655, 0.12020435109133683, 0.1388068581300397, 0.05565340337794154, 0.17910171931068744, 0.08634825207052693, 0.15855746283646555, 0.12652747993988375, 0.11796572726340064, 0.12352171098633159, 0.13911485611911745, 0.13811505009089747, 0.10664685479094906, 0.10778100965845008, 0.15879571618091676, 0.10525671930442895, 0.17144388909782135, 0.12929796030925167, 0.16263836724383218, 0.1281402942033545, 0.2233404777343235, 0.1734864786868134, 0.22366911413208132, 0.14135468270509474, 0.24696603177055237, 0.2328566533903922, 0.11515138836036767, 0.11406846945324253, 0.0843189311243834, 0.09928171613043356, 0.05736102485248158, 0.19171653675936884, 0.1257107076385329, 0.18725367623471445, 0.21153538457808957, 0.1624843835710518, 0.12842693366110325, 0.14544952991268328, 0.11397469263043135, 0.16015674798719345, 0.20053004124952903, 0.10657039921610587, 0.19722950464535147, 0.15225628240694924, 0.10525114218434019, 0.12057241803455739, 0.15778728400266942, 0.181226295629336, 0.12483423410524284, 0.13954323716461658, 0.18946572447255736, 0.09036546392786889, 0.14755613380862823, 0.12531326122341618, 0.14540710396343662, 0.22066572771197368, 0.11470878106211463, 0.16521211623424487, 0.14920714521600356, 0.14352234380860485, 0.10307359854660689, 0.11513412073855439, 0.19793844241048061, 0.10994569067993473, 0.14734208884258426, 0.07713350136914561, 0.26557786209929374, 0.08562554770539846, 0.1595664159545014, 0.07573540622909224, 0.07440522478352632, 0.08727449067537824, 0.1304727408193773, 0.14498148083446488, 0.07962310326195533, 0.11217489928728151, 0.09705109026042685, 0.07484840664772258, 0.19703041371558944, 0.24246947869898813, 0.11710947079043235, 0.11091004215901899, 0.11826486927607369, 0.11759498667332435, 0.11437202413235942, 0.08975005783741513, 0.14361101082496106, 0.14159711888961254, 0.1881947386409006, 0.10587052427112095, 0.15102240587434462, 0.15971473057664212, 0.18109527927252556, 0.224245457399276, 0.09324456790402051, 0.08293610411666094, 0.2382908521160003, 0.18176974308106209, 0.10296092999558296, 0.1268826229798217], [0.017745199110058528, 0.016154524787599524, 0.020747062930416678, 0.04018835963741426, 0.06990612063917422, 0.052498883132131836, 0.1541363847472014, 0.05050979712377152, 0.02765459620634154, 0.05870399996638299, 0.03508897580867333, 0.07195677713400896, 0.013441043275017894, 0.04659284702351978, 0.03138943954611258, 0.04894959394850078, 0.023457646715424718, 0.029158072486039133, 0.0577069097198546, 0.03504416349554255, 0.09624560243420063, 0.05415210853360834, 0.04327835229736182, 0.05720673857497112, 0.02590761313425197, 0.02431321179404134, 0.03609791360495072, 0.03349685741047706, 0.0473829977695019, 0.02174417041392336, 0.027210067942618366, 0.034043782901379376, 0.011607906912573645, 0.03311349169140862, 0.023563192563972647, 0.06624120963557113, 0.0893620572864048, 0.0880512425435647, 0.03437165704165255, 0.03917907327113133, 0.04648774359074812, 0.05314076905168834, 0.03752476385524196, 0.052164229113728776, 0.01961575024911473, 0.057971156427576664, 0.052382487563356284, 0.021216092601178155, 0.08651333635733013, 0.017574911171029654, 0.016311997990874995, 0.06597258856580143, 0.01764633354821032, 0.02702426097746338, 0.013741112254079313, 0.07730635378750102, 0.08465639285502896, 0.029386496922421842, 0.019071636300894524, 0.08239712295753342, 0.036419666702708894, 0.06162477146473624, 0.07626918565121389, 0.05527464184729804, 0.0685669529822565, 0.020322797692290718, 0.07156938945333804, 0.04546870875562872, 0.031254948980565515, 0.044668089418161305, 0.00839360882603233, 0.040952409767816146, 0.023555987507044792, 0.027476055585148356, 0.02171155230532731, 0.03255510552515907, 0.03306045925485031, 0.014265468794732325, 0.01129969537648703, 0.020758717042964794, 0.006885707430962113, 0.02099786287984781, 0.08524363755338615, 0.04919433222723104, 0.022845433296395407, 0.04956131515603873, 0.015175361956109204, 0.033291959534249, 0.023376426073692502, 0.02457613125443459, 0.012530543946570927, 0.05898952476620194, 0.08109767695948963, 0.01893513092410661, 0.008168882679104084, 0.04007009098366384, 0.02195306343867654, 0.027218784107976866, 0.0172030501773641, 0.010634063604107548, 0.031248471707165725, 0.043284645709659786, 0.029885587883332086, 0.021249051618900512, 0.05654118436899397, 0.0463105206407847, 0.04213813767437974, 0.01832835098368026, 0.03735069718752657, 0.03623150784762637, 0.054337773772497336, 0.02380129460605883, 0.1421847849363281, 0.04018943216050825, 0.03897492616106907, 0.030247246501066034, 0.02051079949934877, 0.018792111884742495, 0.025053599383682016, 0.06331871443938825, 0.0894198279767748, 0.03483533941870255, 0.04230604116474429, 0.00277013898143665, 0.005489883262799272, 0.032545797556879065, 0.033424852806473934, 0.03988902610276015, 0.07110651146860854, 0.06925135295117094, 0.036317206273276004, 0.013359166670500511, 0.00838564629966934, 0.043097019285684636, 0.03801218729706542, 0.08357612461212181, 0.04078459820800251, 0.04273794238425551, 0.06867988966405392, 0.02276461676604325, 0.047074750801848794, 0.09757707856835858, 0.034861095294716864, 0.05344348486452814, 0.03731117088107332, 0.015542334351207943, 0.040832467211951176, 0.029561063462507822, 0.020690404982756705, 0.05028020057286467, 0.04807648354119832, 0.036885677987048705, 0.05454494309942088, 0.024863929420168844, 0.0179019560211248, 0.04233694515160976, 0.04288700394212239, 0.018520120028105956, 0.045744412308258396, 0.025890230599250046, 0.031331586501290726, 0.014798670778081063, 0.015046353707270277, 0.028328902966853593, 0.06482117373736636, 0.05427182892397527, 0.02292530562338089, 0.02428319646916803, 0.10728702084311556, 0.008139232203604714, 0.03445756997192099, 0.09005956501970369, 0.016090931829005, 0.12503402217501594, 0.03389517716582745, 0.01336123702311588, 0.08269976599202042, 0.014305508380094844, 0.09111542570134325, 0.024424558843395883, 0.04515746255375205, 0.038759552032476476, 0.03803314363223411, 0.02949828447233285, 0.00543503136742079, 0.03998467984098581, 0.048169402345534296, 0.1003968337130162, 0.0209588632588425, 0.028456546621577396, 0.012070454521885803, 0.013857127651722442, 0.041833958633604555, 0.049548663213969245, 0.0136479904364434, 0.07241400138985726, 0.11390146994662863, 0.10635512850938306, 0.02205836030864908, 0.026639939563709403, 0.00759026508838419, 0.019181855285780567, 0.024263293504895225, 0.017231167519405004, 0.035939658991992474, 0.04879665598573704, 0.053735609511814775, 0.07826734214059769, 0.010398463796704047, 0.005076653042417621, 0.03444720480230547, 0.046229575790705225, 0.05804987196179648, 0.06735101822883853, 0.03076063074742354, 0.042579526892833175, 0.046730746680329886, 0.06201312058575212, 0.031431430740462195, 0.033623154665673935, 0.038138944205016866, 0.02388411062589336, 0.059668673202395446, 0.028429168554383422, 0.045333141836548047, 0.027626666555842085, 0.012567000155667625, 0.04048929812626974, 0.01964614670273037, 0.05120398003547903, 0.048797291838714195, 0.05632874435715138, 0.06637791802565898, 0.03806898505577157, 0.030074072325782433, 0.022904772551790364, 0.008463816953853013, 0.026652045668132847, 0.13312807817372585, 0.04591229664642484, 0.013209658866417746, 0.038788659543159514, 0.04882697008490082, 0.045562642626464374, 0.028897277004415953, 0.044926709210079525, 0.0059198022298064205, 0.05734059328754103, 0.04862929641779873, 0.01600742154198909, 0.022673429320416143, 0.045001502374127034, 0.0028017592605113265, 0.03197520186433629, 0.012945302033556566, 0.04413889120182684, 0.045758324464963335, 0.004467224831798024, 0.0666060743312682, 0.0199494753859096, 0.015660870178121955, 0.03495058585559169, 0.046343259408228824, 0.025482200679459402, 0.023207013390117118, 0.0464339757097825, 0.01779816834436309, 0.044486013301197565, 0.034822886659493374, 0.052336675505484306, 0.013592321699815653, 0.032447642541580626, 0.0055396540800199635, 0.023350982378507336, 0.021906535088595365, 0.03349361302811773, 0.03117596723079201, 0.09187965203196773, 0.002020963645097049, 0.0575327702737864, 0.0663065645963915, 0.028132380346857735, 0.04698770789189204, 0.021893722268061775, 0.055315646703445145, 0.05439685064277822, 0.04259923067424567, 0.04262924599911898, 0.1113528409792531, 0.021492556496072682, 0.07900673956159623, 0.050625269556598324, 0.005199148586290258, 0.055245415592986735, 0.11662600036229819, 0.01777295447555521, 0.04501267959694228, 0.09084406203680462, 0.03477045943239524, 0.019294544904222413, 0.014179835486556254, 0.04997581851878955, 0.06021961299402099, 0.04786156906536029, 0.05036769930513636, 0.059698987301559224, 0.01746276930545367, 0.01911232514577287, 0.03607965006883587, 0.041369326307528445, 0.019255966631575458, 0.03386068788747634, 0.027675198225845254, 0.04181369177756771, 0.049088780633023674, 0.07042565082590427, 0.050742787444182945, 0.07949546535289095, 0.03736822910967373, 0.04871013018512919, 0.018834633594979684, 0.06879665678547275, 0.011898910198661109, 0.11173387779103172, 0.013385978790240423, 0.08089044251509252, 0.057275253648479144, 0.053952967808131254, 0.10472439544936342, 0.019056942734506824, 0.008191560796882597, 0.056803251556571455, 0.02113159693356964, 0.0059956679169479166, 0.025920021843405503, 0.04173691444579632, 0.02611639890669575, 0.06176421861915339, 0.03428090626614229, 0.03894121829240073, 0.017195193945700606, 0.04176034141452082, 0.01603196891430285, 0.015849753943902832, 0.03694499234458612, 0.05920012233658664, 0.0038373942633399805, 0.03858900936921278, 0.04415132863927753, 0.04769504070281983, 0.03854705073359994, 0.04216750182451741, 0.17237787285158712, 0.09361216753360727, 0.2250924442083605, 0.08387640809580203, 0.14189839062671508, 0.12615624905353592, 0.2630366565239045, 0.10360094283016459, 0.20455476076852894, 0.1227003881227105, 0.08746125525043857, 0.22859663762632879, 0.11703319141581175, 0.0738928575188883, 0.1577045618286056, 0.13545586697516904, 0.056132859505352475, 0.18515972811127865, 0.17144133036415424, 0.1511616959807373, 0.2559852615118988, 0.22943744976674357, 0.08943373247260049, 0.1370620469172155, 0.09115697831035623, 0.13207158163910912, 0.10636814434321658, 0.0977212256721912, 0.07957450264403898, 0.11730197336404555, 0.07448204041969392, 0.19492969337490298, 0.08958190919891482, 0.07402992597030056, 0.09469123301847328, 0.1591051850588091, 0.20978734047422487, 0.12807605007002432, 0.11267847186254878, 0.1368984871453816, 0.1577901798150232, 0.10201455093920232, 0.11672654174148075, 0.12357378198254494, 0.060379660252722046, 0.12317576100148502, 0.18783501439517547, 0.07495406549423933, 0.19603992331652872, 0.06931783406124001, 0.07080617435877362, 0.2060517731813654, 0.0994803857118372, 0.13570326740943617, 0.1001660114214305, 0.15291085857297146, 0.23522378846762643, 0.23530160767897484, 0.15700210516731586, 0.16322730499650204, 0.2357332982243069, 0.19732042396020508, 0.2131125297878058, 0.1727601200822861, 0.17545963006634868, 0.1257640043754251, 0.10904254962600048, 0.2137164215767576, 0.12807920635227235, 0.14473699153431002, 0.14039771631360054, 0.2034350313366421, 0.0950369225334256, 0.1373597180410739, 0.07761152491213814, 0.14402722639422263, 0.15474266673047699, 0.08918376564378701, 0.13345899751349805, 0.15138524043704235, 0.10916760581876002, 0.06974806903951591, 0.16395062989284917, 0.07290334005149142, 0.06604640113730585, 0.11104171735144432, 0.184723885369397, 0.11387366095497725, 0.2081502105800375, 0.16921566108301764, 0.09090198594475947, 0.07798856274495203, 0.10078321781850631, 0.1668955944478512, 0.06452924827294004, 0.1292521482513797, 0.07468267884706298, 0.12349531159646089, 0.1329080577218725, 0.18519152076013629, 0.15187000555376853, 0.14325030598669283, 0.06242389693075131, 0.11685696821058951, 0.21407776992888222, 0.11337152096412836, 0.0997804853344156, 0.09881321506033983, 0.10995088475606135, 0.1485178959105284, 0.1084850904261393, 0.15169735997915268, 0.28657795621022103, 0.16636481809039272, 0.14536300794251505, 0.127779328895192, 0.07824408371121654, 0.1312328379360899, 0.24932086347572266, 0.1659802572741624, 0.1288640481089392, 0.12408139184117319, 0.13439190874416984, 0.13054466115370875, 0.1593607213468321, 0.18913900329461023, 0.14779313076888362, 0.18268596891674305, 0.07526107522989474, 0.16597267300371202, 0.1213394788905017, 0.20855268253193748, 0.1558425085198495, 0.20412118564690315, 0.18846286941439877, 0.16352663087027688, 0.07599903240559563, 0.10087421374215234, 0.13110631085451574, 0.11502784136081896, 0.14567641451233818, 0.289562389615082, 0.08463874985013278, 0.1659806862834, 0.10445955885393966, 0.1872147742899195, 0.196940413706245, 0.14798863640716, 0.10572226327513495, 0.245641956045743, 0.11518417692352688, 0.21568563526436207, 0.2766498857207837, 0.11857416961462268, 0.1048834276415648, 0.23658348728091488, 0.1371395443716357, 0.16011194716538155, 0.10057825099436507, 0.15636073635710826, 0.16966040576657943, 0.1661249559613005, 0.08249996260048882, 0.08684285375620089, 0.1206321805535305, 0.12639841710728023, 0.12225305406196464, 0.11545442976057531, 0.15068549572700454, 0.21177434272343115, 0.11838735141340764, 0.14708790086930798, 0.10564547062160508, 0.28986815062742083, 0.1033381593503779, 0.16414589038298977], [0.08079966875694453, 0.010037361550325108, 0.04442231309029364, 0.01975294702025431, 0.022739102207725088, 0.053549346724344846, 0.01830667069542312, 0.022086073539309928, 0.06643482303667454, 0.019784352794710188, 0.018283172863565626, 0.027529024819452918, 0.03078922689441712, 0.025545042871888128, 0.05135461207359068, 0.007663661099579787, 0.07919208687399665, 0.020628449537100333, 0.05170686313161447, 0.027943260051430236, 0.025577055771024, 0.05994101362903753, 0.039420938720145536, 0.06281093987185629, 0.024975077286663077, 0.015426283521998315, 0.024692009713861252, 0.06261806957603944, 0.022881502631090345, 0.018278532285964297, 0.04746506110795083, 0.05711420281459728, 0.03157125327796225, 0.04525654836587849, 0.021730445948759877, 0.02307036628706321, 0.01564693312355948, 0.02229954393941068, 0.026504020244183562, 0.04462077582795774, 0.05662131333543409, 0.04198795379770379, 0.036241329094815644, 0.04658627015868983, 0.007483673529819616, 0.02034383063625184, 0.07273809488622413, 0.02470940182496223, 0.04192870455763994, 0.029434934746654286, 0.01232487806719878, 0.05213312977444261, 0.012529806586943809, 0.0485120466609876, 0.04639570961796469, 0.034552407826507286, 0.05612627114920367, 0.008294242434203625, 0.06736972609594946, 0.08877235344581066, 0.09095082404993235, 0.04925762258109547, 0.010903320526854407, 0.03626470626782506, 0.014826607131849856, 0.02166596815861281, 0.010867505916394295, 0.02010546620905159, 0.022959789156072566, 0.02970937042376928, 0.014398651265148676, 0.03018176513573816, 0.02445327373401773, 0.03681312946061935, 0.022967415561358777, 0.037406667571274504, 0.03681882149389675, 0.042382898935747725, 0.028797287208538865, 0.030823273756991953, 0.04272481546767297, 0.041299673593452865, 0.052216510784121296, 0.04569738983146606, 0.038015213344366326, 0.03135722363367677, 0.047654097133706656, 0.035409307813331965, 0.003665020649937252, 0.03978917037226981, 0.038879873801863966, 0.06104656660388555, 0.03687614019239142, 0.02516592894079945, 0.03373086279738815, 0.011345337937405754, 0.06843856430702633, 0.019553563061861262, 0.034404495400526834, 0.041994212736045165, 0.028278425433522755, 0.06349024152563465, 0.06255905399279249, 0.04648830283493285, 0.004896600833988839, 0.018620998485975208, 0.02680990383059027, 0.033966591882128874, 0.04583424760869915, 0.059126344239038814, 0.026935653332921288, 0.03379468558235996, 0.017768467115538738, 0.029003610008306084, 0.06676244819837232, 0.05168853064758643, 0.041757759698216, 0.06652549720339238, 0.07138814837221177, 0.055223926826710665, 0.031032777736864747, 0.032518624418204835, 0.03357567636656665, 0.013741964526895075, 0.03786739667937641, 0.05209962874951382, 0.04696890043335096, 0.01015512937409503, 0.04191945021551463, 0.06258080705940243, 0.04075967353738604, 0.03188258374951059, 0.032023015326910445, 0.05187611493672575, 0.037225732925317945, 0.029892678027071302, 0.04416763865118546, 0.03614524634735238, 0.013531543156732957, 0.0022131983273392243, 0.06475642398600617, 0.03604602263939958, 0.04466966755928532, 0.029286662259349422, 0.021834568788988457, 0.04106967484638576, 0.09945043933487709, 0.02493081272639815, 0.09769188450469125, 0.037757202592347903, 0.03696400664686676, 0.04901874104454633, 0.0627062616178826, 0.06694559683843006, 0.019557719088850484, 0.024710422637121334, 0.043878360020537535, 0.056064156740303, 0.06958450926768203, 0.06609645732227834, 0.012665209754730665, 0.04735297095330973, 0.05505284790189997, 0.0609665219071171, 0.03158306443853484, 0.06705525466391156, 0.031051968239367973, 0.05679809195440143, 0.005056285637340719, 0.010371371097261868, 0.03326198634421153, 0.045725738915104064, 0.1143430430261839, 0.035670310138694705, 0.007429085455970058, 0.07856583297853509, 0.09119077810957547, 0.005758620203367525, 0.050818059413183125, 0.055904726182380994, 0.034502784481212016, 0.05218133968751758, 0.07638106513167582, 0.012951888474485567, 0.0727725611819375, 0.04933706972928298, 0.04901720120781853, 0.06775153665653161, 0.05520575139070711, 0.0021445645102029366, 0.03277962674356757, 0.03750054398551583, 0.008440638006094002, 0.045899954969964685, 0.0389142251843887, 0.04041193090679665, 0.04263775723595773, 0.0203102836460476, 0.017774603479812225, 0.07739292172294471, 0.030476825814994595, 0.1288891911146141, 0.030148426904493285, 0.04885808091550585, 0.08091072086244822, 0.06545904918663925, 0.005757019079605779, 0.02438896065277438, 0.05229444107821873, 0.0324261078100291, 0.02332105515374532, 0.05914328627348427, 0.043973661358318025, 0.04019052000536073, 0.04004561447448308, 0.07028579381444762, 0.04538078484455905, 0.020847962455703847, 0.0594606267047986, 0.03028597224563841, 0.0906749098231235, 0.01612980121506318, 0.08450640050033409, 0.02049359316456943, 0.033326908465354674, 0.021351092615194862, 0.02507339318042561, 0.04787573020064062, 0.015445826424946709, 0.010008774021820677, 0.013083378848199163, 0.006445628222859195, 0.024874961086278482, 0.04101355890593222, 0.04259401744592094, 0.026514416057316047, 0.06150390577292251, 0.019194729393348098, 0.049653291672227845, 0.05474313004543224, 0.024402231210842732, 0.010401524317961548, 0.012938240618114511, 0.08083989603384849, 0.028092017089347207, 0.04186191318196155, 0.023669458535169403, 0.045050524340401736, 0.00737471571717892, 0.04303477081139723, 0.05784685483142253, 0.004524794424087891, 0.01960215027323894, 0.038021970239858476, 0.022586700506508354, 0.050130311640039574, 0.03793760863763671, 0.04296396896543522, 0.05094717587194136, 0.07613603190909471, 0.011812207240220762, 0.059245091697741906, 0.03093557841625185, 0.01020241423600143, 0.03792086961649118, 0.00934679936166973, 0.040271303976976106, 0.07885809552164809, 0.05827086917575329, 0.006419180952493222, 0.08295247541560281, 0.02683541072802919, 0.010059715995955612, 0.04115230508989865, 0.04775729300754686, 0.01773326729063786, 0.004483474035476965, 0.02963212194792446, 0.05646704237968211, 0.04965061802537211, 0.062496410983224074, 0.01972347370258743, 0.0436535821626744, 0.015951925175144308, 0.009373930365508123, 0.018716853322280992, 0.02697384281594667, 0.014390429226501335, 0.049307291891666195, 0.022427901971123876, 0.02010562517229588, 0.01817047749946435, 0.05186676100317029, 0.04095198075857855, 0.022751457290723923, 0.00929332067889552, 0.0654376523509141, 0.05046251417708494, 0.05332225145051076, 0.07720282466541376, 0.040778293304385684, 0.04636101732631365, 0.07464834278629673, 0.006572957781534041, 0.0397150743482334, 0.04720343442092981, 0.03180044954792867, 0.036678910856285406, 0.022015030375651775, 0.06844702191771039, 0.06297581348448031, 0.07760718119360747, 0.020168159014335083, 0.05552311863509878, 0.03986071532351836, 0.018248896174613508, 0.027952207958385832, 0.08841125790270106, 0.04254795640947358, 0.016050545588856744, 0.07255117709357893, 0.03337691868505171, 0.03499644770917874, 0.02426571434273595, 0.05641331663355232, 0.049444027094831394, 0.03835819473850631, 0.04759476362397114, 0.027113190378933668, 0.0037819666050059064, 0.014768134513419243, 0.028952697720078212, 0.01873993172099994, 0.04341920522312003, 0.0400411443514449, 0.0030784970318387837, 0.04309091356492812, 0.029000013225501584, 0.056964991869585174, 0.03822843476589169, 0.042697695955153436, 0.08463437548808514, 0.036106428672229095, 0.0975001939842778, 0.00764113093253165, 0.031302235757691727, 0.039110259423332835, 0.023530823433951988, 0.0841557237529947, 0.04301433158557742, 0.0354011336551799, 0.0703709444872314, 0.20196326918178992, 0.103747449484804, 0.12039009676945787, 0.1853428078034232, 0.11389449088563842, 0.1741456360586228, 0.249921016755604, 0.13338425797560524, 0.2034870793502177, 0.08555344350996517, 0.12471768148844281, 0.11524184036158747, 0.17293241325645678, 0.14262592900664578, 0.12394674422760164, 0.1108097842323684, 0.1707411106796034, 0.16918572236693677, 0.18820030043923086, 0.11417946793259152, 0.12307550307483443, 0.06190335933840083, 0.09698224193867176, 0.13757399283349514, 0.14310718544067877, 0.14741636872772249, 0.10964448789074537, 0.23865557125499173, 0.1894099073063943, 0.09316730027597758, 0.1600782392967132, 0.06985941991931008, 0.09865691014114888, 0.10101276840413771, 0.16377072180471114, 0.17710860367984543, 0.1847809435979974, 0.13309018746499093, 0.14727951478092902, 0.14094101054774177, 0.22527137170395545, 0.09198567860068814, 0.1612324733287096, 0.11451209564843487, 0.18256950823049392, 0.09317332938794168, 0.15488981689897277, 0.20010434151176484, 0.14198600044173582, 0.1687685262051321, 0.07887296528825838, 0.19330094448260723, 0.11653113569463454, 0.16764455264614475, 0.11972219833443243, 0.07063741284993387, 0.21658669255914229, 0.23751973865493653, 0.11977724941267122, 0.17939782761518033, 0.14852872839377773, 0.12989460490643978, 0.22345701502936505, 0.09495545674355761, 0.10488609362754131, 0.24535075070396548, 0.08963489183975805, 0.15091411168536834, 0.09265591360388264, 0.13252371141026098, 0.10182325112363023, 0.06467711090320541, 0.08941664105100978, 0.0940651553232343, 0.12908579991950145, 0.12620900186800188, 0.1678462942401248, 0.12112516579368424, 0.07984542197758153, 0.13806291014677094, 0.2301410249164028, 0.08847114299574206, 0.16939878674043765, 0.19777711961538563, 0.1358563470984659, 0.12179888649693421, 0.1329510658979416, 0.09607589863721402, 0.152438611332928, 0.08889253731937179, 0.17854838932473815, 0.12598208662483001, 0.1744151151468677, 0.08482271054339025, 0.1414768737290175, 0.10337161441003123, 0.15542132870083855, 0.11950785459409799, 0.13511172495782375, 0.11504710847211462, 0.07740651978360069, 0.11367223345704618, 0.15600919393041443, 0.22986365512253779, 0.15548149724641155, 0.08560248079799837, 0.14411558697540916, 0.12446719371984083, 0.13328823651517593, 0.10838046579832032, 0.12827368543273018, 0.07863349386400754, 0.1579882901522421, 0.1619016817740856, 0.11513952931929981, 0.2159011204757037, 0.16160327520581985, 0.15165547029145304, 0.22558024303326685, 0.10666641301565594, 0.2641262174133332, 0.10151150696460279, 0.1765441194537186, 0.14438613858674804, 0.2228685982164837, 0.17346056959321424, 0.2498736418783665, 0.0727524437130459, 0.1589558132353329, 0.12657267146653708, 0.1820506981664127, 0.13654515207294496, 0.17671400711180704, 0.11883623297176055, 0.16910342920211055, 0.167246094994968, 0.11735456530004741, 0.11424306855206529, 0.13415587705469903, 0.11564322446863498, 0.1036164254671143, 0.22004728025246054, 0.17518057487905028, 0.08572520042258887, 0.1316951260331177, 0.2663283524734359, 0.29983051121234894, 0.09161206518089579, 0.11559409525005088, 0.2700285265041936, 0.21416447576015227, 0.27338285780241417, 0.16123613522898766, 0.0845578050000533, 0.1529806338611149, 0.08491710789742009, 0.11170547891167865, 0.2655270245046385, 0.15716995503152573, 0.18322112729712842, 0.1986820533150627, 0.1289728785594625, 0.15816874982368562, 0.23983215973261865, 0.1025766832754016, 0.17811291430506015, 0.17957212793971264, 0.17161245908468, 0.2161990061041809, 0.20949444973901396, 0.1175971240586331, 0.08496646694238148, 0.2521294490584443, 0.1995811034594813, 0.06757239465631786, 0.12575890989072863], [0.0430889064145665, 0.036996220644082756, 0.020018216455355287, 0.056798662689905015, 0.025164034788406668, 0.020687894129584876, 0.025853441141906287, 0.05265496588582474, 0.027866701054717266, 0.04095439393554003, 0.008295993902720511, 0.026293901478751536, 0.03366727366923325, 0.012297207928983676, 0.0028577107314636274, 0.022810377112980333, 0.008426319822789201, 0.013981322953177076, 0.07292541104458994, 0.12025115140263112, 0.09366151891768941, 0.053674146277649756, 0.018759309915044618, 0.020833397209043467, 0.04481127508164895, 0.07237276287689325, 0.02795486053782365, 0.01832625956364697, 0.033627471571127256, 0.05154280157219018, 0.036138228981965975, 0.051188551024684024, 0.02978365796978676, 0.00971404754842121, 0.058710722387918544, 0.0211677601140353, 0.044599704579600406, 0.03336135560886995, 0.020094467101678736, 0.0025894887456219765, 0.022443779143354586, 0.007782188786809603, 0.05566556119329988, 0.04064015999075867, 0.008922776398849825, 0.010964913038356651, 0.038552922797539545, 0.03392241159153562, 0.08674288694296153, 0.07219933589259464, 0.022530283876544526, 0.05722230165115288, 0.028630475393466415, 0.02846409067241175, 0.015304575133467875, 0.011294667924483939, 0.029649418298034903, 0.04028869417285727, 0.04827276675871784, 0.05271804173507037, 0.016047034990943728, 0.09800152958280618, 0.04126372108716638, 0.07920678044038434, 0.03454765425093713, 0.045146844575121525, 0.018015409812271115, 0.08821757555368447, 0.02077318078297521, 0.041248560207144874, 0.06057348432800463, 0.029207238093799645, 0.04002878352278664, 0.009538419018950193, 0.036662056921951236, 0.020271272533723426, 0.06950328096507058, 0.04416162869141948, 0.04785203893158225, 0.03785975878277133, 0.021311100910327608, 0.010981935512034163, 0.022366691545973864, 0.08910135756577216, 0.06361960313252865, 0.07184018621281271, 0.08938929171211298, 0.06550283877239113, 0.03259733229154541, 0.05366810184392718, 0.03321384537904974, 0.08870769562500139, 0.052410790681718826, 0.04344451676813826, 0.05389040906823451, 0.0310611363966018, 0.07326229054841303, 0.14132955502117836, 0.0323267768497669, 0.04470019233262828, 0.023325498463706146, 0.05260572175405199, 0.01658542051671013, 0.024696443447723024, 0.04813048890942047, 0.02354066191811956, 0.020810885715388486, 0.03601513014385297, 0.013476742014679457, 0.018389867843999978, 0.024516152315622857, 0.024464742070244207, 0.020742190611218254, 0.03885470015267211, 0.012716671711044207, 0.03465391830691407, 0.10640044261010424, 0.054242805682963906, 0.036133908246073036, 0.06543369933722482, 0.02911070143924125, 0.058171415641423196, 0.05475453709462478, 0.04343787861627437, 0.01953628969438855, 0.003096074679858923, 0.042950420700494325, 0.025584101864707567, 0.05883945580271464, 0.052597543765460296, 0.03362925655599083, 0.01536345952415779, 0.05602962532711606, 0.014836335490878313, 0.039922293470872026, 0.09225974655559949, 0.059176228054228334, 0.04019808895405262, 0.04881191645718871, 0.06566285155713558, 0.012507570884941567, 0.018008449903479027, 0.003182406325058471, 0.0618165156113044, 0.05010800315968452, 0.04181245071513038, 0.05448047680059268, 0.010622973523793683, 0.028637848989737612, 0.03666633169256872, 0.022462192066614668, 0.08971584435071676, 0.03593010204513708, 0.030906032320232164, 0.03393867180772847, 0.02490010217673356, 0.03184355540020812, 0.02042468738622002, 0.08674160757612798, 0.04232564918516625, 0.010725913715789155, 0.02317875240659041, 0.05773746896715415, 0.1022088768020753, 0.05040151825655372, 0.020743992833060124, 0.04874565751261769, 0.03305360276792799, 0.028513283093249606, 0.016949072878267017, 0.04120387046808197, 0.07011702464472863, 0.12056354673639422, 0.06354984316614366, 0.06228909226915529, 0.06080722158414222, 0.046312232847295465, 0.03595068299722287, 0.017079303994955077, 0.08692923783054275, 0.017324115052038146, 0.007755504986797009, 0.00790000209705003, 0.0768388179881919, 0.021223311064644687, 0.0359916189054568, 0.013347161115117133, 0.03904840548432643, 0.04322251597900064, 0.03275596611802617, 0.033388241464572574, 0.02631000081648029, 0.034632617232179454, 0.0041195257724593246, 0.007791446001764628, 0.018482252302008773, 0.0337896638760163, 0.04162619175810007, 0.034267469083950404, 0.001766425186595429, 0.02371727582818318, 0.09012679689593854, 0.06226960682280122, 0.04595025247263332, 0.03618736969186895, 0.02979595942663089, 0.08121295787033536, 0.07514846796590476, 0.015908615351955018, 0.04710927072371687, 0.04350554333218644, 0.050892814272834416, 0.0415432435880986, 0.0456207963607965, 0.06558461099742882, 0.0963050508571248, 0.03460475078393375, 0.06529202669738762, 0.07021350575791252, 0.0530965925915347, 0.026364320280751394, 0.018630166643209035, 0.03818832240217636, 0.017714923315290964, 0.02912019901428252, 0.03980426996525738, 0.026921846513305942, 0.036729055141369184, 0.010199279021171313, 0.07033761966252519, 0.0490185916574011, 0.0338225060653302, 0.04589739240585797, 0.04855220882041801, 0.022852726453434558, 0.026119853963234255, 0.06333703543209741, 0.11613507589866078, 0.04271848758141841, 0.07172849059345261, 0.042912261860985915, 0.03613038807206097, 0.030268135803541353, 0.05868910338669535, 0.03606751140567564, 0.021883717159770673, 0.026001933879489382, 0.07979575649745042, 0.10157724496938529, 0.012415973582274973, 0.03786589131660519, 0.026855185372574676, 0.07396077121337576, 0.05228127968767959, 0.032017147093410456, 0.05207039100388366, 0.002338350281089304, 0.06481673042740553, 0.06017100854566502, 0.01945260416475996, 0.08568898744640813, 0.03884290622907781, 0.012786424016549945, 0.06336871316776642, 0.019330574019301324, 0.03251351078131026, 0.03336269626273744, 0.05769044265992219, 0.04673983248311185, 0.058716134799103585, 0.0675537174327239, 0.06911636059803349, 0.05054637016127667, 0.038490433005555984, 0.03599573279761019, 0.09239511429181985, 0.08164394361477706, 0.026757773462562796, 0.007499862404074521, 0.04257963414514258, 0.021082366208335566, 0.028837694516105038, 0.08176246507754249, 0.018227169921080914, 0.03791980858471605, 0.035307770519847834, 0.044517150944879944, 0.012247714818635536, 0.11055427092698314, 0.006597231277414868, 0.010763926040982048, 0.016086197405632947, 0.030523310115020123, 0.03359089087274286, 0.060624773914535204, 0.012508305371738972, 0.06702932258767468, 0.033135539701869415, 0.0865652694577171, 0.0037151110694638545, 0.0316539122497723, 0.03475773854241256, 0.02772369542189183, 0.03551007135801258, 0.07636885369016279, 0.08209238850301312, 0.08172179346964245, 0.04296732060010395, 0.03801294572411045, 0.03250807155704787, 0.020645113864673242, 0.054442858053070885, 0.04478817753073189, 0.045005497522652156, 0.05892515805880389, 0.04823263907324403, 0.031190727829873085, 0.011698808032839049, 0.008241264581409915, 0.014285546044007906, 0.06777345443204527, 0.05923924261644002, 0.05401636541430509, 0.015390732254262175, 0.08488404354260815, 0.04181734601696653, 0.04390296676466542, 0.09493027543348652, 0.031071294722477757, 0.07330265572114338, 0.060870795390538635, 0.02581539913080633, 0.03837771465881698, 0.014733482441384227, 0.0523370317363691, 0.007512187801166288, 0.042707341002120126, 0.04077315668485338, 0.06518396233478863, 0.020576031886101253, 0.04112260769151392, 0.04477520000129458, 0.01610401852597152, 0.05702616782077859, 0.03060994316793738, 0.0463286501115128, 0.03654728929001478, 0.011003629206829976, 0.08912990966271009, 0.04375020500212427, 0.012081223802881376, 0.03551042375845775, 0.15848758029601268, 0.13778259857527672, 0.10345469664541945, 0.14518798749533393, 0.11604624034296121, 0.13656520825480262, 0.14958263555121037, 0.18315378816858416, 0.1651476575962959, 0.15825551694198964, 0.09041088528089947, 0.09870489788872581, 0.18927132200089195, 0.130089221882724, 0.1562218446164362, 0.1019825284639674, 0.23121736312825836, 0.08285060104343199, 0.1402189880008659, 0.18906935058053465, 0.1575679683517064, 0.17864041180620271, 0.15116321283482737, 0.10798513378587463, 0.14013864069936738, 0.21454846967131863, 0.23523960052238357, 0.09813836820784116, 0.1816906215202424, 0.16884861303673637, 0.17981206667759728, 0.2093807010040168, 0.1360781142307866, 0.1552559456397449, 0.17617622871072064, 0.14451888630226736, 0.12368120283128754, 0.10201661937659788, 0.13472409978989633, 0.22523112144441376, 0.07663298548469621, 0.11583720559194205, 0.14331330905758566, 0.194455883315494, 0.08744215667848626, 0.1296257386885343, 0.1442237126250421, 0.08142766933287345, 0.20612115010378823, 0.14407352874836615, 0.20359286077080235, 0.14996062333305038, 0.1982417059761863, 0.2609036532380889, 0.11268349739933207, 0.1002420916131908, 0.12059355440038828, 0.21109771854694814, 0.0952632325671373, 0.1452419813722372, 0.13650713879014217, 0.2561676517249115, 0.19313799758111277, 0.22920189305178582, 0.20864507273560573, 0.23327141339259766, 0.154683540064481, 0.16147382166837493, 0.09211968270040329, 0.15335695157127996, 0.22284903233089756, 0.17467593744156823, 0.1894053261006071, 0.057902488136483785, 0.1460129569374746, 0.10981573918533903, 0.15637380581709648, 0.21665393975713562, 0.1967633094999098, 0.15434482194963964, 0.12015646293519006, 0.09830817159625793, 0.13424593835107743, 0.19393728775603158, 0.15828612981544388, 0.11522684036003006, 0.1848609078555338, 0.23620189888583076, 0.09403056645345303, 0.12847963284941452, 0.11475478464196767, 0.3065855068064505, 0.22945027407859603, 0.21135435800158212, 0.23677004501223567, 0.14914144551561725, 0.1658691132381078, 0.19762707363453605, 0.17889427802255078, 0.21097902088396012, 0.15432448997612924, 0.10100077146724348, 0.14782565886214857, 0.08878645712449666, 0.26415615612941407, 0.1809057031547831, 0.13096225568123404, 0.053150873751409596, 0.14169658774570112, 0.13329750617905972, 0.1744906973814772, 0.13238504949596622, 0.3664945324342097, 0.1542481110100785, 0.1304907285638394, 0.1332740792103352, 0.27578570789867835, 0.120379310251484, 0.24408823780475125, 0.1480705312062656, 0.19226350821554664, 0.2012680137469884, 0.12115093699145703, 0.10936609153906185, 0.06239657440493184, 0.1675764780731932, 0.10967148482919702, 0.1744406718400217, 0.1716679698156734, 0.13504208756550667, 0.19268733869877555, 0.11534536182279549, 0.13831450874286313, 0.15760774363673505, 0.08035870854772868, 0.17913916568842628, 0.12692980633507814, 0.10199065665684401, 0.1716910597057112, 0.21592322977319842, 0.10472022027017609, 0.12197651164305788, 0.11711109489683183, 0.14857044954213405, 0.13711745039589945, 0.10172382823281712, 0.1637960027062124, 0.06667287719826545, 0.11277106890995657, 0.2376242483695669, 0.0629631768641693, 0.2982760881704669, 0.1088713136531653, 0.11461575500546925, 0.16040826997449323, 0.16719613074054643, 0.15099896358386164, 0.10303360875695945, 0.2495846735133279, 0.07410425182071424, 0.1167640264236158, 0.12067525767751279, 0.16265992495802142, 0.12302300306938349, 0.1519673600071861, 0.1342958872837405, 0.1095780221024348, 0.15039972960948944, 0.1108224017004813, 0.1412179206888522, 0.0994763560893555, 0.08202599932349498, 0.2921322468788393, 0.18041922200110652, 0.15178907602544756, 0.13356911499173413], [0.09279869707121004, 0.06997133770416822, 0.03589154867034766, 0.03171258500867313, 0.04358161586306749, 0.008968201582320035, 0.042103793952734246, 0.047174369045082605, 0.019528602002068393, 0.030850887396222645, 0.028628516123600067, 0.037795284823063886, 0.06443960832491999, 0.039635738282794916, 0.04732117447401247, 0.05864094326933546, 0.014349392769227346, 0.009107770353195169, 0.007626821367715997, 0.05167217467040305, 0.033969001228650736, 0.04345952060013529, 0.01517931496979849, 0.04857966924206384, 0.05606782630146031, 0.08073789142673055, 0.021126291774694, 0.09414976207359184, 0.05883470222714448, 0.042660939056546464, 0.03914466060157265, 0.045541755239208864, 0.021493249805644158, 0.039855594025744547, 0.03339397563268581, 0.048554353866606, 0.01996268848738363, 0.0516620010227686, 0.05575860640214336, 0.03463663153290268, 0.04233657359896649, 0.06736165152922755, 0.023922173704411236, 0.08252807802730992, 0.01911649457930077, 0.06738665663907606, 0.05605201807714278, 0.06259466942039228, 0.032258001306364616, 0.022820116005717747, 0.032946427067321156, 0.04077715566381812, 0.01611526852713958, 0.040028890775096033, 0.03179246691175767, 0.01690825188322173, 0.07887329470606581, 0.10174352435335036, 0.03504075823471912, 0.03843285000672744, 0.027830949646510908, 0.07343584010677953, 0.042485849661452156, 0.04551004302958327, 0.03406583474227979, 0.015080473348197919, 0.03862998358184292, 0.05457167190709903, 0.006807098670246741, 0.013207694808501872, 0.011792921934336906, 0.04030737139645123, 0.010367044615709494, 0.027939741792637977, 0.09423016300124508, 0.08084474537040919, 0.06299603054480207, 0.00387042893224486, 0.039614996452245026, 0.06341757808601664, 0.025352055747662822, 0.036545856705596375, 0.0627423788330728, 0.07197150900479286, 0.0586246102747898, 0.060751504009409305, 0.062228624949291836, 0.028957259773667303, 0.0097308334924521, 0.014892792340458162, 0.021319179307489146, 0.02764940213021492, 0.01999062579876233, 0.04495110144958862, 0.025705321872186278, 0.06463439384054753, 0.038732896003151135, 0.020717876895721403, 0.06613707530402368, 0.020035223607274315, 0.006743150438377333, 0.05340799584143585, 0.03124277775866851, 0.02316146563257902, 0.035002587903891845, 0.019807810406951655, 0.02097058248886418, 0.03608773995731627, 0.04355253516546181, 0.03320262602139865, 0.04045889975743429, 0.04012878864042221, 0.07509359308788854, 0.053246764976891785, 0.03767559507621392, 0.021010656548183293, 0.013355205038322077, 0.04005824343391484, 0.027404501057800748, 0.03350584362182887, 0.04865528595062995, 0.0324799791128645, 0.004454148189735509, 0.0571124523036903, 0.03951621324484868, 0.04701609144948664, 0.025483579637723106, 0.06299126164747343, 0.03168389310068902, 0.0361373747939304, 0.03857965160521769, 0.06262681446969509, 0.04369455254486492, 0.007153654822163405, 0.04977304270611175, 0.053289979996700446, 0.03212379802378916, 0.008506976432287166, 0.015789680201710475, 0.03562353281003814, 0.011608543723160702, 0.06349852293609612, 0.012824484222238103, 0.07053307167464687, 0.01728198404664234, 0.006937712352091988, 0.030838744902622797, 0.026808630209416155, 0.04558801545851654, 0.05370019326707529, 0.08485533822808536, 0.04008226029034104, 0.08748874248516175, 0.03769796101316329, 0.013537889237575715, 0.09795164193717704, 0.06499341328538234, 0.046200410823427865, 0.04692342162372605, 0.01955415486478277, 0.023850994560146527, 0.06436855366994297, 0.03071586056912859, 0.035384739373600295, 0.0374742288653168, 0.0396113230606481, 0.010420822072774174, 0.027456501190881097, 0.07339673131824502, 0.060861774705230236, 0.024174153429245757, 0.031244987922330058, 0.03422566749636204, 0.04340862937932534, 0.09589830413460733, 0.010389373205872554, 0.05995099575469091, 0.017771887698120648, 0.07116614375263453, 0.02837234398259992, 0.019481623575331706, 0.031757985294285807, 0.037322903517633677, 0.05507248273539928, 0.02935605833397037, 0.018605362631440647, 0.019246532258787946, 0.045583380626574646, 0.025513508777704932, 0.067511031013583, 0.03198188406625583, 0.05256477818493882, 0.029145711657380866, 0.009651300159373112, 0.02553142182859442, 0.060981272930099126, 0.06418771095453732, 0.05521069265781872, 0.023287073408644048, 0.0727594074522776, 0.05331089036659368, 0.04599583853456763, 0.036530393220844774, 0.01629726420487127, 0.05437796657544471, 0.05638268460789996, 0.043114784864648696, 0.011700459909925779, 0.09573046193127671, 0.04096220037148845, 0.0030123146960601933, 0.031369107572602174, 0.045601736093240405, 0.022857688787964084, 0.036866966289498156, 0.030347678712719393, 0.09144702685936805, 0.03222944154854744, 0.01167062365810477, 0.05620385670373517, 0.03115029370922956, 0.056867721685839284, 0.03835648253199555, 0.08137046554756742, 0.03550739771115684, 0.01629032153305748, 0.047911138784500866, 0.04808403716813173, 0.04745405242447892, 0.023914441962035436, 0.0712119021843518, 0.036503193269093195, 0.03695623851531456, 0.04017656188338034, 0.04978512008223803, 0.07893721708246777, 0.02764341706830648, 0.07939345308489378, 0.08274403821316459, 0.060045653578615, 0.019241807411514947, 0.06575432245529468, 0.02287848999032811, 0.05258905934169889, 0.015507548213786176, 0.053156803271943526, 0.06639607430946443, 0.04556100319830641, 0.04009713005695132, 0.01954767376094336, 0.03975293058301172, 0.037871050918775226, 0.03962323189743104, 0.037293095036499926, 0.14975463761196983, 0.020984988772280274, 0.06034916995333568, 0.033347451113044255, 0.015118293193799835, 0.0501147638856163, 0.043114846151682644, 0.03774986730047292, 0.021036128971665617, 0.01625126828589747, 0.03221038894187058, 0.031686356073365576, 0.026237289496367017, 0.02249807945542759, 0.04190199107172028, 0.106040840938447, 0.05378956891476147, 0.06716970819979906, 0.012624813938483357, 0.017728728219686497, 0.05019757032935178, 0.016831970593381314, 0.08173559837403797, 0.02323354493015476, 0.021149929417597673, 0.06926508124677405, 0.0749713484378111, 0.04559346234365817, 0.0028886642746417035, 0.04999872837816516, 0.05391843256450469, 0.036714966784441666, 0.0857075957220889, 0.06079813578136026, 0.020994467195123438, 0.03990051742162436, 0.05439002479937288, 0.05555443247900375, 0.051330216003641974, 0.03705847677924941, 0.01525752392837838, 0.037179541653923454, 0.09526071213786641, 0.06710878888806028, 0.05505406215125996, 0.048418254516417944, 0.0857244190129061, 0.017607500551328543, 0.02437728930324797, 0.0711902831831286, 0.028006674894582362, 0.028463370549762924, 0.039381305161382885, 0.014542428731557824, 0.08793917920200095, 0.03819223328102981, 0.06212129603110014, 0.02161952599342312, 0.043906605682305755, 0.009766294744857138, 0.03649728290075737, 0.02974364136706197, 0.03281808818780607, 0.013168890539917254, 0.0283544079490727, 0.028505478572521, 0.009582104225222383, 0.03914226274636965, 0.034634965291667374, 0.05486560835232658, 0.05735783026583734, 0.017133554511312998, 0.00834384183925126, 0.019957816168185205, 0.1423223590057704, 0.048738069411727696, 0.07046154204515681, 0.019398137228563428, 0.021436817853921847, 0.02409754463681771, 0.08930412571757071, 0.021750392963088328, 0.017819710736793858, 0.015175388769186554, 0.008226345976694457, 0.04752901029743014, 0.04590830149789972, 0.04228828707709909, 0.03548363366374566, 0.024552495526750723, 0.039393298267837495, 0.0512633212060938, 0.1261033200388474, 0.03813893654413762, 0.04057770850317132, 0.06978323247524039, 0.015682244988819285, 0.0725207097768303, 0.19495229296866926, 0.12974774585135523, 0.14347139896164018, 0.14744420836289085, 0.16565963415609253, 0.11202666893481247, 0.20260514361002754, 0.14230411079141403, 0.11503220040110812, 0.13237242436697408, 0.09563459368843226, 0.15451391287628682, 0.17386089649892625, 0.09156334198891156, 0.21032102796579563, 0.14973586845782497, 0.11149118113661967, 0.07965406853585474, 0.09828611592491789, 0.166259634218389, 0.1406092331894944, 0.1348796922473177, 0.19612581709459906, 0.1894896570593119, 0.16646388858076067, 0.14635075574680684, 0.1590203331603158, 0.1520864100706193, 0.17617936967121017, 0.11508476935447225, 0.12243889933151585, 0.1435238606626949, 0.20637691621818852, 0.15880929125893503, 0.08534706708404326, 0.10568142312789157, 0.13122084099919568, 0.10404440048601359, 0.08867938867619923, 0.15527505187257645, 0.1667745065905394, 0.12284009957746153, 0.09664450441637347, 0.13612936551292099, 0.08941597455451566, 0.13064636698653623, 0.12002718559796773, 0.19394373821635402, 0.25344344306617017, 0.135761474769923, 0.11265001169616178, 0.15125531192508437, 0.1286255649381107, 0.07871911951130436, 0.12338812057409557, 0.20079210460666688, 0.13830621967152243, 0.2290450748536856, 0.20936055289160824, 0.24324935620590565, 0.17107091153100615, 0.21128746320403394, 0.12356751538332432, 0.19430753804983633, 0.1191036283008514, 0.12187204023282375, 0.13267041724776069, 0.18435395683252043, 0.17329443576595477, 0.16269116602357359, 0.12470137147653489, 0.08000992403756227, 0.08270401778000017, 0.09262397539831939, 0.1920194938899048, 0.17035308714595535, 0.1341306574402317, 0.158868923542961, 0.20540380069325048, 0.10565614988726955, 0.16102311682076226, 0.1750291346181785, 0.10761997797676634, 0.23449064232409003, 0.13323030494634183, 0.14688516336102642, 0.1474629928387942, 0.11284047647589639, 0.18276962571807448, 0.06492997354437267, 0.10606245227879095, 0.1280749545642926, 0.10922454913417179, 0.18207643872066853, 0.122858761479297, 0.164575282664549, 0.19354626115772033, 0.12511289092682062, 0.1809477613818261, 0.12167632008992857, 0.11119479704047404, 0.15629489876089558, 0.08007114978447076, 0.11230878081292876, 0.13362606596802512, 0.13552933480710755, 0.15266227836330093, 0.13440687810221028, 0.13617686296422638, 0.12877325136815349, 0.21949143749811958, 0.16078028227052382, 0.19563967301960916, 0.09355121757835151, 0.15516390783652184, 0.058194589801132686, 0.17446491086194593, 0.0812364308043353, 0.12100498192012311, 0.17187882785595235, 0.13263862459890305, 0.2283826233038018, 0.1374442635043975, 0.15160454076624688, 0.16568174345358727, 0.13355776156869628, 0.1497367877633341, 0.09640622042840528, 0.11134943188799006, 0.13525735827222948, 0.1321853456958648, 0.10957596132591849, 0.17554835836973884, 0.10252556222821436, 0.13557857893888028, 0.09427972888994603, 0.11530664373910236, 0.10913703891058123, 0.06293611863868372, 0.134440187605158, 0.08900139841341204, 0.13276168896305945, 0.1310472301537952, 0.08905351537490085, 0.09563011973495446, 0.09089212639317398, 0.12041176173595652, 0.12202749479441874, 0.148143554707208, 0.11637479247104739, 0.23490285891438686, 0.11231434261125904, 0.3001128605777218, 0.13504754211152756, 0.17631705099296185, 0.12443202262323712, 0.1588649858510302, 0.08553279744040582, 0.31674156506215373, 0.16804402153338158, 0.08726162039825032, 0.19723350362431621, 0.09641254065378059, 0.30641935765743256, 0.21954373065983096, 0.12000600326686137, 0.07598289859391029, 0.15550970460378355, 0.11793332940508282, 0.14970373873028064, 0.17069166736497035, 0.08724894164310348, 0.1210003624099397, 0.146714708797874, 0.2055935300285778, 0.15783507256738602], [0.05280644445109272, 0.0087740097848338, 0.033893457298437436, 0.10129512543038977, 0.053665083457505515, 0.05225610220804811, 0.021219967090855205, 0.06517641636873446, 0.018881098742807106, 0.039965006703090285, 0.06020455553586926, 0.027980543635485154, 0.021980669417027986, 0.062355358874605554, 0.07982439286406003, 0.0383784692554224, 0.03727982639365139, 0.055063021549534415, 0.07740187729077955, 0.07429853171831177, 0.019013101437820062, 0.03362218939488934, 0.07973882084291789, 0.04089586864856463, 0.02336353281392686, 0.025703435380672737, 0.026456852210685614, 0.030434733113995006, 0.04008050211855481, 0.08777306069649997, 0.06914790809875535, 0.07373557966803351, 0.06148624361582822, 0.044914432651092934, 0.03206370225656898, 0.03079376213492886, 0.04244607054598389, 0.03320428843219434, 0.03593682063623302, 0.06332141106888171, 0.04418024845841912, 0.03534946868556642, 0.02112796376158874, 0.06918106438411821, 0.020100689650843703, 0.03770477536524977, 0.012883253699739375, 0.05359513196913947, 0.03095939992025735, 0.10219602184670587, 0.09860156028861962, 0.02161450045663984, 0.031238204213760556, 0.04784318295517757, 0.04650142209063615, 0.027452804816646442, 0.015248519522438367, 0.04743898347500832, 0.01014387937292697, 0.044428663959185925, 0.013627648886833942, 0.05591938144437248, 0.03819866841959377, 0.10464545008876633, 0.04749571611624091, 0.04011579578922641, 0.01498636423474959, 0.021057399402883266, 0.02821952093302483, 0.010824895148435909, 0.03204389696850652, 0.019654730717921932, 0.06393616981503945, 0.011942517838530965, 0.025550708092088183, 0.10369357818196859, 0.023166648217386777, 0.04118839932245113, 0.04964360449042532, 0.06198117471930962, 0.028227606991065607, 0.05492522914503371, 0.043860766811356436, 0.03228529318866711, 0.0699568203380031, 0.011254503849833723, 0.03565180528488371, 0.04074566561969058, 0.03134521137502405, 0.05480750824414915, 0.027920204635349014, 0.022345765854322144, 0.024226299119031718, 0.02516005496164003, 0.10865398216992618, 0.07223743344506911, 0.028559708021461006, 0.025166020871350364, 0.04837736457345947, 0.040021126473983454, 0.09486175652953888, 0.021930708993046034, 0.01717946807583494, 0.01962789848837401, 0.08332546064329725, 0.013059749823784637, 0.03644362610254077, 0.13974827293667103, 0.03348073125967095, 0.03399710516415296, 0.03406225328123377, 0.04133879770374587, 0.01663008535791549, 0.05163026200006566, 0.012264644404152229, 0.03333048992640069, 0.04944201228359053, 0.011347670675135188, 0.04155768434547129, 0.09765237735043611, 0.0371978051900383, 0.020270856931024504, 0.06022913163648017, 0.040272334365234266, 0.01761674148691518, 0.05765765409676298, 0.02610921491718581, 0.03161858410514411, 0.004325093496816173, 0.01901448805696301, 0.013068592393650644, 0.030040370202773524, 0.025968953794349107, 0.04845532551107388, 0.0022470744959484307, 0.009708456064183867, 0.013532558223232629, 0.019696237361659447, 0.02773017078007181, 0.017266323294250235, 0.036507487191908786, 0.06157225230708719, 0.03298309203537722, 0.023766052646322117, 0.03575442276234108, 0.009625084630604233, 0.04187413228435382, 0.03339351597993124, 0.0496315730795745, 0.05619752115660137, 0.03588226368470538, 0.054642489074819514, 0.02423036704590965, 0.058920415974552595, 0.08015634642253, 0.08286331044209581, 0.04291488571212657, 0.034696734961002104, 0.018815971693144213, 0.04569491536747064, 0.028412751290166093, 0.020161614708241918, 0.05640520759287381, 0.02794938875482448, 0.010837708926579405, 0.035930910267897194, 0.06630949105226225, 0.04135229617297169, 0.034141769377334465, 0.03590048125554477, 0.047871482243100484, 0.0563965622906483, 0.029758771603566506, 0.021514878382966406, 0.025287323233280933, 0.05289909129421558, 0.05075425961084905, 0.00860832794944966, 0.02125781183431466, 0.022423447169844183, 0.03914469890596886, 0.03204091880170088, 0.03285249702692513, 0.026213431603185115, 0.04838117203044315, 0.07908200003927754, 0.03069786707900705, 0.0070579737920554424, 0.008319637291283618, 0.04972573677678743, 0.04156513455053491, 0.07614432864131467, 0.01968906677868818, 0.04838521697468335, 0.046813304145489974, 0.04150868919227393, 0.06285055810886045, 0.043015151299656405, 0.030303387339377118, 0.019247955267107295, 0.059167812578380115, 0.04596636713212056, 0.04086743529525496, 0.0152150931910822, 0.03158939615522902, 0.07095289551803181, 0.03822208772743902, 0.10228799070201575, 0.09090449871315111, 0.07254641968756914, 0.04342927161844508, 0.008794558178182811, 0.023172757768582915, 0.026179514975557407, 0.027719637071112954, 0.008458593191819326, 0.006408388210054968, 0.06495141634537328, 0.021769307673938816, 0.019824777339254657, 0.054099577884640426, 0.020186353602536747, 0.04150603086717668, 0.04304018322258227, 0.04214209834894827, 0.025231469677941456, 0.06675186086325877, 0.017948020888011784, 0.12663817964494228, 0.016765175387263298, 0.03221594690976124, 0.018819009231763984, 0.0271564360422593, 0.03968197168902524, 0.015865934678473543, 0.024266727494015813, 0.017904997390184193, 0.04879294428974391, 0.03559155246963905, 0.03735654243838884, 0.03153977472515356, 0.028100943928884885, 0.027973830790048646, 0.06108736844673272, 0.040397788923714435, 0.058427993809023214, 0.044949921674185225, 0.030798793417371573, 0.02645154322137035, 0.048209625791998646, 0.09110763458715332, 0.015494150293600416, 0.03099044563338882, 0.06604060185171905, 0.027944796057718418, 0.026264106404156457, 0.0491691432562807, 0.06025239006586133, 0.10112236494258528, 0.021830489370791663, 0.05790164160932745, 0.060087953123354146, 0.03305888494416591, 0.06512904149149695, 0.04513181776048676, 0.034204420047782125, 0.016758307409022125, 0.008982836734503508, 0.018312699807387207, 0.006375974551173709, 0.021499736655143, 0.04172944891897421, 0.05348022261093702, 0.024809906814968394, 0.025122451535876722, 0.08281215109051236, 0.04854896060761906, 0.0814287878212429, 0.006921512944128125, 0.033562924833067005, 0.01716824297252442, 0.02098754176028794, 0.07284487988198958, 0.08979831371576556, 0.059296166779653686, 0.007384954482286929, 0.022407342086455995, 0.04965905648385806, 0.03556172866674681, 0.030164625833652196, 0.008165613398887217, 0.020746344722987666, 0.03205681129569008, 0.024960895083964835, 0.02117968618779654, 0.08172263616635915, 0.008986946796217274, 0.029286834629132386, 0.03477121019856103, 0.0376193565616925, 0.0239883158205738, 0.03335695060330533, 0.00410117844547776, 0.05036441661838082, 0.018309237089969458, 0.039324568689710675, 0.05351222593397383, 0.08758763677530712, 0.06775458568647023, 0.04564416204248706, 0.032869542483240366, 0.08025842763844036, 0.02688015409324679, 0.04663941367799717, 0.08279557294783094, 0.028465684135294253, 0.03541565868222425, 0.009058543458400715, 0.02781249075797537, 0.05123046752546103, 0.02007268913721125, 0.028633137549003287, 0.018132257372921994, 0.03886033472935519, 0.018391447900343808, 0.04294219674662717, 0.01840809499093842, 0.007384625064479488, 0.050508625009247375, 0.016658911331286354, 0.008039236662068195, 0.04075289365925616, 0.1416053619956778, 0.03303892069285916, 0.002193832342820843, 0.02003704306609448, 0.040298392845978664, 0.044192260717071837, 0.02156793763260207, 0.006678910135486794, 0.03495714356822353, 0.017081429888944955, 0.05714525618860799, 0.0303264178576008, 0.033854202953197306, 0.0239927725370733, 0.050695646223762346, 0.010749722770865886, 0.027261206226783897, 0.03825185024329732, 0.03798272355549759, 0.046135615106792226, 0.08265468171767651, 0.08786607143138686, 0.19436427452150853, 0.2076804607866272, 0.11952447870205488, 0.18312513648021608, 0.05727059966433914, 0.16969829647531434, 0.07825708422329157, 0.1802740330176969, 0.18144780229176247, 0.09043739958395881, 0.15501524081393597, 0.2903256583358011, 0.14719778852116677, 0.15122112908190297, 0.11330421247910108, 0.11456394447915016, 0.2736313460815338, 0.20786907163358506, 0.17391168812830604, 0.09261736405953284, 0.1280823319910034, 0.11426929940259266, 0.11133701360273747, 0.09600862845658295, 0.1648177188490668, 0.1087562166034214, 0.13359398220575627, 0.18438640831699296, 0.2487535600460345, 0.22752484997674344, 0.16045135475935476, 0.13075507486299162, 0.1106550268107845, 0.08129174235246836, 0.2121369321379931, 0.18241282792822008, 0.19823079688414452, 0.1740428730244598, 0.15223621090333309, 0.19526416736264385, 0.07237160608412758, 0.2222633121475097, 0.06817542076591523, 0.06823633241677476, 0.07778035536889108, 0.11480312478998977, 0.12004412380197357, 0.17285741324866974, 0.12435442557738674, 0.0784265045677462, 0.15825148731950792, 0.09152976435519035, 0.1319225622160781, 0.08289104282495477, 0.12397465281068318, 0.1835657902542622, 0.1432113580766224, 0.15933352522552013, 0.08488418143843451, 0.18903317590875013, 0.09322617413295854, 0.26711677952158835, 0.149741139142744, 0.11907655475360733, 0.12346844489295637, 0.14697376909034868, 0.1893721851370027, 0.13538789965452688, 0.27897441098766945, 0.07298781656690183, 0.19370854922359992, 0.07473065127288142, 0.12768138455407274, 0.1329827972597653, 0.09450339592031895, 0.2025646328805916, 0.14078126589377082, 0.1285246251932075, 0.10089332763586314, 0.26240650324090836, 0.1452506381657816, 0.14893386633165423, 0.1491980594132216, 0.2232420814013289, 0.16641640645121375, 0.16689683551028853, 0.10856495509224554, 0.1537378658089907, 0.07097365650077982, 0.09015169475347766, 0.12214419296792439, 0.10257210206961441, 0.16994005850245877, 0.15341816199643, 0.162903678813769, 0.10604856310472374, 0.12229895805038753, 0.20638926555552792, 0.1465876760982698, 0.1287752738402736, 0.09054821420220599, 0.1558898680753285, 0.22586528902813313, 0.1835499322342296, 0.23983418220473876, 0.27706317483417453, 0.13116356826597644, 0.08508476623964888, 0.1394989419608347, 0.1599619624715659, 0.14050202684537058, 0.14137680732434796, 0.14637576085665535, 0.07853780948226491, 0.13497683219611645, 0.10220900703702243, 0.14498669023235, 0.19109068889050715, 0.10248736508430974, 0.08513217176040334, 0.18829103589298266, 0.13063741907958062, 0.051679249492383776, 0.14909981629781185, 0.09332229518481801, 0.11636630421684635, 0.127853348310436, 0.08038898434249625, 0.1513545203112787, 0.22370380259329276, 0.15072134864186087, 0.11001035616162325, 0.20312709463459833, 0.16631326037308863, 0.10649587418283187, 0.14564400899314112, 0.2210158911804038, 0.08572112483483169, 0.14444373307689545, 0.16529057895944965, 0.141980453965164, 0.09066677396936763, 0.08719890077988948, 0.07351033449653657, 0.11958794908658152, 0.13984925864684966, 0.1775852942298497, 0.24285581683920276, 0.12622963261580275, 0.1519363794115282, 0.1651396443166079, 0.15709930640314856, 0.11396214411023164, 0.20106981147921857, 0.25251183418496964, 0.1624466920451772, 0.08548769018342418, 0.1143548024758216, 0.17919892054652015, 0.11530879644616959, 0.1331207850166867, 0.11255919963361756, 0.10280440291089397, 0.09948175700922167, 0.19067413624255888, 0.09288517307610282, 0.22618343002132832, 0.1472541113053599, 0.1298394465758916, 0.17691832276121264, 0.11365684275064739, 0.08673102790189367, 0.07058239241521205, 0.13332890046219673], [0.03871722567465998, 0.026946602644579067, 0.09404616400359139, 0.026994670831388044, 0.032068716302033395, 0.010043565904901875, 0.04157716596138574, 0.05903413406603279, 0.028074923752536698, 0.02359005352181773, 0.05236223602907793, 0.05524273045481213, 0.04958776434162452, 0.022650841217968735, 0.02701066100158759, 0.0408516040882997, 0.19041706777868733, 0.05899521296903972, 0.004600576799167621, 0.021062746696594744, 0.031537173856650634, 0.032756946710569244, 0.026112610601910183, 0.046558832719681725, 0.013862801490411645, 0.01331946129099496, 0.033388291260287646, 0.007177022897878723, 0.0367614338474889, 0.06379286923836316, 0.06584278262791134, 0.04814322895160125, 0.03545538417153782, 0.035855473589993296, 0.04006183638627972, 0.03192300637883525, 0.002833940459588062, 0.044158407291697885, 0.03136430611653674, 0.017769305981815826, 0.0136552749749934, 0.04044047917329496, 0.03622021571162247, 0.035221076179896636, 0.04621134289810735, 0.07525112374775833, 0.04261946688676554, 0.02296587189419135, 0.01184282202889482, 0.02736206170201542, 0.07132680771211464, 0.05498055218448562, 0.004895876880900394, 0.0479558706583996, 0.03943925205197546, 0.022241564490081325, 0.05009864922612906, 0.0708055614884342, 0.05917294153703317, 0.02625513551456313, 0.027121703530992233, 0.03641622696792887, 0.11063096398908286, 0.03717782178653344, 0.01353021399418433, 0.04361964829806839, 0.016318251183556936, 0.01728432827569064, 0.04779102002841331, 0.012125356212979364, 0.03477823522482668, 0.07588534495763241, 0.07187597017975585, 0.08233728382976786, 0.051971956366492864, 0.015043648459287661, 0.04657602373270258, 0.01778601435944438, 0.014038811148624989, 0.05227480241427979, 0.06435546122731702, 0.09342116649232565, 0.012667487908695495, 0.037533619831646645, 0.03544626389479926, 0.02838377209921037, 0.01089196710381657, 0.007389744447033493, 0.04493968290907722, 0.0157665797779637, 0.038797270371428424, 0.06428843619482172, 0.04921016343418629, 0.028318419053609815, 0.025844441524015802, 0.015851669163713535, 0.028811071045516484, 0.02067239042521725, 0.026210267660057834, 0.025162280447060065, 0.024504254970158783, 0.024485880351294915, 0.02691737830548758, 0.04598368838008854, 0.01031529729164416, 0.010996185705035685, 0.02050039794055685, 0.01503918791234854, 0.046056727202789444, 0.03307181267788814, 0.028972363197094494, 0.025725688319653276, 0.05763231956910703, 0.05124192437036865, 0.019494683459220875, 0.032761953095154416, 0.030202152650623076, 0.05215030163526536, 0.03782833385611734, 0.0624686211437708, 0.039165532667069666, 0.048005976639087164, 0.038618637819684325, 0.03863117867900479, 0.02054928584144481, 0.05860879438959303, 0.057473344833499966, 0.12964453848619617, 0.04949872960306464, 0.055030681147810914, 0.021543823099965533, 0.029787155161161098, 0.027990000990910396, 0.04021108563568804, 0.03878001807137363, 0.07358584012235365, 0.03926282583345329, 0.048597890643342856, 0.02646173410598309, 0.04502477995570629, 0.02259844271916776, 0.09759163423891991, 0.11889400366213053, 0.05965261599950253, 0.07204183587624181, 0.04011101923101852, 0.02582133056656007, 0.004994484366879108, 0.02536101323071747, 0.014427453298271905, 0.028686694755789735, 0.11946455530461766, 0.02139277545915496, 0.03669942286045801, 0.025132426000650854, 0.009674120961027521, 0.042924320084914085, 0.0642820623432917, 0.06734485888192732, 0.04427200663954981, 0.04337038627014526, 0.061099936119130546, 0.04479726716395348, 0.024600383682897495, 0.042647122660832065, 0.00997559858425971, 0.02219260764128018, 0.04892541621361048, 0.016670226449927977, 0.07790330481985885, 0.03775256009952676, 0.03822603691068869, 0.05829402418326467, 0.08677023628185834, 0.011484791795092245, 0.01875104765678125, 0.048348647767617825, 0.029216337303120284, 0.021700725567737417, 0.02733840490691364, 0.0686207170327825, 0.04293749679721171, 0.05053929916973557, 0.05460400081750366, 0.05054455453289613, 0.030811169567788323, 0.020417229520277153, 0.07556166514874467, 0.028590525823434996, 0.14618584766022621, 0.012499254042913598, 0.009021651536797085, 0.07874587896249949, 0.03959935676727084, 0.019506230319459594, 0.026026753213016257, 0.043670256066346363, 0.05469636420809454, 0.0750970404835478, 0.05805261455656541, 0.023024697870677038, 0.042649451568121874, 0.019302680757978273, 0.006691115352535441, 0.036890351123386816, 0.06432320126482556, 0.03483839993996005, 0.05114660388039005, 0.07379981614048443, 0.0347811731720163, 0.04195778525524563, 0.030154140005188606, 0.07726071026897238, 0.05081393019927125, 0.02717495047216935, 0.03282704758608053, 0.04388841875498334, 0.03026469415354152, 0.0212780786903515, 0.0813714997662652, 0.053520771644769184, 0.028613627204791676, 0.01581603171108591, 0.012654333221425694, 0.04449016549774716, 0.04230990224788266, 0.009994352416646098, 0.03394878416832897, 0.028201661508290038, 0.07517407828521344, 0.039595116470609946, 0.04322761812457635, 0.047562534304996656, 0.024438620387246052, 0.046662396315725586, 0.014512425855613284, 0.04708507000618885, 0.08381241677148689, 0.03816872204263364, 0.041646259431276596, 0.04625152037929624, 0.029664673023827137, 0.05084533214328751, 0.051731718854317744, 0.05390510646506183, 0.018694874259733388, 0.07056133265817358, 0.03068685456509552, 0.02072037817279418, 0.028050525767368176, 0.05166761644725358, 0.01872257982951499, 0.04049921130400993, 0.06440332640082606, 0.04189691573922192, 0.03353281757764278, 0.07121957838535309, 0.06382325611587975, 0.021773107470043247, 0.08389453373609052, 0.04936582100908122, 0.016542829858559756, 0.023264617456363577, 0.03891290368271932, 0.02445480590986629, 0.03017130803557173, 0.053976931038402745, 0.06164476252912034, 0.05377951784119491, 0.03702958377318517, 0.0075136041062163015, 0.03575316637814526, 0.047372153794933716, 0.03437016700063983, 0.0340454874470109, 0.08664475874074044, 0.017253054651401697, 0.0819707184188789, 0.029859207645659486, 0.017383339394244458, 0.01061569951895264, 0.0718471116476482, 0.026061627450549317, 0.04690763638204625, 0.05410014095926478, 0.01743786953269474, 0.09511796697493523, 0.0326372952681155, 0.05643675509359568, 0.016446961615715298, 0.046529981848453326, 0.055865716985276634, 0.02663954311320859, 0.05051562322243568, 0.06598700634053638, 0.06692694259747382, 0.011516333550154682, 0.007761222396736905, 0.03585129841080597, 0.04369285566011264, 0.01749861072899113, 0.045188044783689325, 0.08375027171906926, 0.0424606760122603, 0.06504125547625365, 0.04887619889491508, 0.052785491946363644, 0.06836481302255584, 0.009880232129005656, 0.04974383943443818, 0.04104809031911916, 0.051182950921957536, 0.04440872652095653, 0.11537756815913225, 0.055493968989579916, 0.01971844433536453, 0.009796544684157258, 0.018374097924078667, 0.03806598965198763, 0.04268413236845405, 0.04189823341045169, 0.05118222696886909, 0.03562151416835766, 0.013452910934574904, 0.01346215091255163, 0.09055939908590048, 0.03703374746105364, 0.12597860858565377, 0.0326117922011162, 0.035733244261674346, 0.0480692133667969, 0.0848310072756102, 0.028005451069123326, 0.05753737829265095, 0.03501638131696851, 0.03783131010770317, 0.06424289992860248, 0.03237077327925832, 0.021077742867712534, 0.03449485930163534, 0.031681200301635175, 0.07103312790634171, 0.03831871822776814, 0.04138842487948076, 0.043838504296276844, 0.036004853074348746, 0.02254430711599848, 0.01728562296428267, 0.06756316329683028, 0.006131172591384741, 0.026054025943120642, 0.05292355248163785, 0.12856879782292152, 0.09341459345793532, 0.14684836049714398, 0.15119114440054665, 0.13486668407436342, 0.13959681735404078, 0.16613568119224043, 0.13701297132478607, 0.14447705790160165, 0.1499016192411223, 0.2081165486766446, 0.16644620727146828, 0.2258527405079334, 0.17532870564008915, 0.09950021972819682, 0.15263647652201115, 0.2823459026553939, 0.12877159661823703, 0.08534543531676454, 0.11789386055522388, 0.19510620003265722, 0.134994360287824, 0.16256180441667958, 0.19927059270201192, 0.11872110527849968, 0.2763861369702124, 0.09599160598290545, 0.07496591687442795, 0.15060358560614048, 0.1061610401337666, 0.1427508932688544, 0.10357851177574166, 0.11509506557617458, 0.18260954398541682, 0.1576338519131945, 0.1550845411275664, 0.15160944372896226, 0.09066126579719205, 0.11303751429002132, 0.09500517584984342, 0.14450940213376476, 0.18515277203292618, 0.20094452546008174, 0.1900480738690784, 0.17267675439436592, 0.1313132158811054, 0.13429890567016217, 0.06864623542154027, 0.15175634874932228, 0.16935990011740118, 0.13952935565142863, 0.15000252834250852, 0.09349669510078046, 0.2625908546390072, 0.1438944173916694, 0.14393837551676458, 0.15552634403349894, 0.13069106055603874, 0.09376257357578124, 0.1285583790271513, 0.135386168295818, 0.1126585535765175, 0.2338479098773772, 0.15732092031788442, 0.06669209834428565, 0.1519294539766927, 0.13940912581259204, 0.11003418149606836, 0.15592245745562738, 0.08122576686042933, 0.23612547395450456, 0.18163010057422424, 0.11021930664297074, 0.25834773877455347, 0.16598424093136865, 0.11118618621220512, 0.13609412546840408, 0.0799031007374006, 0.1536304449602481, 0.1566533819441834, 0.1842226953275742, 0.10991745267904575, 0.10605823113432816, 0.1578901542891418, 0.10048288836955063, 0.12485687966428458, 0.14855308998976985, 0.07030058697226547, 0.1078280474570009, 0.11690966739890077, 0.2348668527819457, 0.15306804449327532, 0.18730779268568565, 0.14189569399722163, 0.10039926987261542, 0.1058811805541477, 0.10123587619032591, 0.09590585010066148, 0.1318292986721762, 0.11286422520154908, 0.05834827086918297, 0.1468591929803933, 0.15599649219262987, 0.20430648699402812, 0.06286963752861466, 0.23110215882620505, 0.12003038018461197, 0.09829017619091658, 0.09773847031136675, 0.10855246785907977, 0.15779577225687044, 0.16566735632236929, 0.11427689133392227, 0.16977176430725283, 0.14281921298994174, 0.15811782029847946, 0.10715645647818044, 0.2644533676005179, 0.13593507029356497, 0.17455454314908675, 0.1279406899946832, 0.11944856704963792, 0.08267178080014645, 0.10245383341586399, 0.09034516259787545, 0.1663638681413666, 0.23637567827057457, 0.16227927119020494, 0.08980521616796333, 0.17144790339854457, 0.05524088035247499, 0.1690957989663847, 0.07657084043227858, 0.22099635593833464, 0.19811277337852987, 0.11064445479742943, 0.10169724498184458, 0.18621663833337446, 0.08771656171208428, 0.21666527785841497, 0.1327357798694603, 0.16639330123941745, 0.18796641379594806, 0.17822586630861606, 0.19242034173540531, 0.15800146686453975, 0.1393930992532161, 0.061769661673855406, 0.1329899065557026, 0.19704823292070822, 0.08457290459304087, 0.2151989396060667, 0.16180532323496957, 0.10830463841557504, 0.20195957663799488, 0.14907156297516438, 0.16898191233556117, 0.19334684847103012, 0.22092072773844967, 0.1544338566881995, 0.22974092783706807, 0.06961447096640064, 0.1105938546900307, 0.15387380045027504, 0.19905049564136615, 0.18752540762145675, 0.139137149277714, 0.14034225154788266, 0.09579331944546393, 0.17106066127457928, 0.06847590343245576, 0.0920040340673539, 0.1413152444987528, 0.19802686427870106, 0.13398234281809102, 0.13255576452901288], [0.05362560311632772, 0.039372583250364954, 0.032523619311471144, 0.030654630991780472, 0.04028731904503319, 0.11054867848513589, 0.09302043356001378, 0.06323396979320435, 0.022845753138103796, 0.03677580948738802, 0.042446376981153604, 0.06716870462461826, 0.03900561181287612, 0.0308817703156702, 0.06209481237155776, 0.021805093556101766, 0.04937327504458447, 0.028713306735059427, 0.05147518665199319, 0.037054960435676965, 0.013437163997291317, 0.04033760888682258, 0.09357826814295785, 0.044526907074595654, 0.018042715101112283, 0.013610285504030125, 0.03832409233455697, 0.05320497105018266, 0.015560798985402913, 0.07702612648567847, 0.03247599162521862, 0.02256077417593089, 0.07116820452915085, 0.014016786120801926, 0.04534728765006989, 0.07259383286920286, 0.03155944594782928, 0.018799083284853448, 0.04503086269382508, 0.010289871791047196, 0.06595646241499532, 0.08133799108045717, 0.04001679807721127, 0.02302338977554633, 0.055581437078334635, 0.027234862378287702, 0.030919421621928775, 0.044374719877997716, 0.01408705362043674, 0.036138903139339346, 0.019245218417997804, 0.06055334387647529, 0.029965071420695995, 0.05919118209051029, 0.02664497659181155, 0.014407242941219481, 0.053323159264701034, 0.021579746877954855, 0.0063354987744993025, 0.06066455303000347, 0.04555884283035994, 0.05205687338245973, 0.013147641176117525, 0.04415546551406865, 0.07722047533118918, 0.019644137637148944, 0.012021338709840372, 0.02217733759372946, 0.06396856001247803, 0.021203147630477627, 0.048513628632551244, 0.022389655031504172, 0.0267410401870767, 0.027233253593646714, 0.06492628100057764, 0.03155593918035588, 0.020089198331979495, 0.07323623589810825, 0.03529388900665987, 0.02339316701005784, 0.026106853451159213, 0.054157655010180134, 0.029001677551517085, 0.05371871344264477, 0.02742796250048184, 0.028284536899938702, 0.05513597993300327, 0.04350699506880295, 0.05990318420733656, 0.051741792910522034, 0.046662177980667165, 0.04164547036071459, 0.015616336529473624, 0.015606884919707815, 0.029021210878366427, 0.0758263178830666, 0.06521937091864886, 0.03329370238427674, 0.05483761933001299, 0.017559351925287518, 0.057807052733316544, 0.029891785534639514, 0.03257679347429545, 0.03029451795643376, 0.01571907658099888, 0.027519921779692657, 0.04124716592712268, 0.01716278651128373, 0.05217308125969383, 0.09788978799817064, 0.06684526230298704, 0.018283241811478813, 0.058764835008450096, 0.08213674499382896, 0.029085964460166234, 0.03301036859592123, 0.04926175179500734, 0.01418050964392962, 0.042045226530923, 0.023466290102430412, 0.01720258860938972, 0.021443611138590404, 0.056631088617347905, 0.014884928447915422, 0.057150461756053476, 0.0786570740503169, 0.052437033023565054, 0.07570573564378485, 0.05088338756092614, 0.07760633083601153, 0.11136329041854029, 0.02400180471370057, 0.01601269222690814, 0.03210046107039577, 0.008599203842271481, 0.02848818796806999, 0.03591811659956171, 0.04223017547760279, 0.04021808384887634, 0.0017583654628270458, 0.030955065777825735, 0.0407445777748381, 0.029722547136066906, 0.02375202366120873, 0.06141846015628788, 0.005835249584408538, 0.0413491475516029, 0.029096737571601427, 0.053667370229959495, 0.04217218262173476, 0.04137644326434501, 0.07362626658211793, 0.024613460803764965, 0.028586155291826978, 0.060533617112425074, 0.08990237143852058, 0.019180844049720515, 0.03405412508835716, 0.02504415926523507, 0.015775940414788504, 0.06446021609008312, 0.02068610339906187, 0.007132186165695349, 0.0718627704848205, 0.021075647617239627, 0.03941600511391317, 0.051844904514690565, 0.04145728086211509, 0.051583396571297804, 0.08018978616042484, 0.015392001087386763, 0.018848317840527144, 0.04597266054441852, 0.02744544845735354, 0.03817289339138135, 0.0921002853541605, 0.022708684686691533, 0.024115660701007135, 0.11028393382026304, 0.07036425653965243, 0.010015827776383488, 0.10600636698185437, 0.08735341305333762, 0.07813287072724874, 0.10593980160211364, 0.15564749317784465, 0.0749518591610174, 0.014299785703300469, 0.027234820243451866, 0.030631516203885118, 0.016569259891947432, 0.02497589891596187, 0.047736938051398725, 0.1266423548241296, 0.04153302014474908, 0.012851848882893402, 0.034677778115315784, 0.05593541183418805, 0.052476620617052244, 0.07058731836056517, 0.027524840064166535, 0.06896548724222569, 0.02272610744130948, 0.046263823751360185, 0.012493412622490959, 0.019557008542300715, 0.020010716454576583, 0.017249036520238847, 0.027263956482432065, 0.0650797054291733, 0.027041595631970033, 0.0762491754346317, 0.026469322206873088, 0.060255622956901796, 0.05009322532362515, 0.08965363801126519, 0.013137513493758537, 0.03597465005793399, 0.026924445466589064, 0.03543313314777709, 0.06133852654226846, 0.009382468415424228, 0.04843656401780825, 0.0280753891509507, 0.05208282461089473, 0.02286652178173104, 0.05510877615081207, 0.05128710440570309, 0.05181533735125296, 0.04796486453063065, 0.03814644803623519, 0.06708369184766086, 0.014887807980900811, 0.07579604974917828, 0.04023537445332735, 0.012817268631601287, 0.04039055322326961, 0.016073304145867308, 0.03469406514458599, 0.059761760546074766, 0.020903787282746167, 0.06351248871895575, 0.04780710021394396, 0.006270903198333878, 0.02559156356109006, 0.044587171381159175, 0.07024995622134979, 0.007727266028298126, 0.029367388774370475, 0.04620291210050064, 0.04313143195524331, 0.031265270100125385, 0.028781360240593076, 0.05140952142556349, 0.12509948438814572, 0.09615585523387117, 0.06639065040696053, 0.01603721853180398, 0.0495137372655013, 0.01951277654077257, 0.026141532336271582, 0.052445571073481155, 0.07815971444811552, 0.07118328880037993, 0.049258024777255716, 0.03189077705986077, 0.06176683863985443, 0.01610415067613846, 0.029481261998655337, 0.023262188957643606, 0.02275104551846462, 0.029690654895779107, 0.04155419098453657, 0.04225538360075124, 0.0476667031105007, 0.03814627566645223, 0.05196619155486265, 0.05568280583247543, 0.0783560244787124, 0.04645896166743291, 0.03213067366290958, 0.08858178141376666, 0.037178503604786056, 0.04322964059669645, 0.045105743957983876, 0.0390660829631792, 0.06514001953145189, 0.06889644739848953, 0.03989630393804081, 0.1038013744137941, 0.04419394228006563, 0.1107019880005429, 0.026838513384122523, 0.04595954894959446, 0.008932010631167121, 0.022520001061380874, 0.025527390290892897, 0.00946732510196706, 0.03470381361342246, 0.0035800820877475124, 0.08486645416386666, 0.1064535708076531, 0.09438099805265666, 0.04175965959626821, 0.02875655431360487, 0.08474999347761755, 0.05082576625770138, 0.07704242883670716, 0.045083787878073996, 0.06929878145456314, 0.0043517686783396195, 0.04473905597302703, 0.09750325833597491, 0.030487970479073066, 0.024278023460459326, 0.052227301132534786, 0.05608111026606733, 0.03905959419846054, 0.06482753226713789, 0.04610802061975964, 0.04366033522772693, 0.05718434965538402, 0.0283139240327141, 0.03568721769918357, 0.07545534746661302, 0.05093152469564831, 0.1304327050644544, 0.03953034756705165, 0.02438467247561822, 0.03317791202496136, 0.11162295592047515, 0.008275907077345877, 0.0255612169031895, 0.003387137577162996, 0.03579102261292358, 0.06869433042142661, 0.053221166148901954, 0.03767413567871817, 0.06055775654291915, 0.0639935574614473, 0.01629868529797081, 0.03369271161875898, 0.03206842901906179, 0.10075291138022177, 0.09491551291918564, 0.05416621221229435, 0.030309774597445806, 0.0466153470258559, 0.04772576082858348, 0.04070135126371057, 0.059960878288914124, 0.017988225182278023, 0.12109786242006287, 0.0807655701834348, 0.23993190438035997, 0.1731295889664081, 0.13624873733328235, 0.2107276674360037, 0.21180939890684622, 0.23909964178118015, 0.21079371953683518, 0.22073092179432993, 0.15812450058517918, 0.19448306411504748, 0.10944296080138415, 0.1441554695127472, 0.14354782389296641, 0.13718295091342542, 0.0926807118699916, 0.1424223181581305, 0.13095084097116225, 0.14616140945544168, 0.09018792305141689, 0.12773957659280108, 0.2023566859744249, 0.16818521153782645, 0.07324038809465785, 0.2172166619810366, 0.11879170028072213, 0.10675288902054872, 0.13560033583592984, 0.19911306970302137, 0.10831625996938637, 0.16398522642350968, 0.15760061901903924, 0.135119968063889, 0.10320905055249892, 0.1253861238458945, 0.13657158210633263, 0.11008194707814725, 0.15714712561138217, 0.18514514179720035, 0.13165869089143892, 0.19526625112179788, 0.06066051191620289, 0.09920247965642523, 0.1636236176014908, 0.1467130234044406, 0.13624259330812963, 0.10258032985392118, 0.10219286556445784, 0.11571213407742402, 0.14473535210615204, 0.12120390431054177, 0.2104453027488724, 0.11912969061203542, 0.145453559535165, 0.16653980789405687, 0.10769902292879359, 0.1705678981999236, 0.18892046905333, 0.15075963771631642, 0.17262217829064017, 0.10983597922829852, 0.14684307449046644, 0.22911872654672594, 0.14413296184953184, 0.22929151001716816, 0.0958355155683333, 0.0943277242984022, 0.2204768104298461, 0.22740886426500737, 0.1352697995401198, 0.11069698544639735, 0.06456282590666125, 0.1513477174505111, 0.1277583380860667, 0.15799184480021078, 0.10635913514922704, 0.1202753980854346, 0.15117419853566155, 0.16565629401274268, 0.20648177833326403, 0.1451584165014567, 0.1390819909471658, 0.1876737682088729, 0.1255294435747689, 0.19041697584813644, 0.2031307412131179, 0.16661016540902276, 0.10213701009389856, 0.10307889221416366, 0.13529751660122027, 0.12056919280439617, 0.0962071371595225, 0.09661716273835591, 0.17431244404325563, 0.09752942789946834, 0.1652571162389171, 0.14558330418602114, 0.13239718432868683, 0.13742927882459857, 0.12529495172202587, 0.1549484532686972, 0.14436847259921415, 0.1795621534749385, 0.12181731857239239, 0.11070915092263492, 0.18612000400260573, 0.15569594057817615, 0.13519895172888233, 0.19209938153864878, 0.136733548415284, 0.23221104045308408, 0.15146218630815708, 0.2397763119229386, 0.1498989532551458, 0.2543517169091971, 0.14916721671339006, 0.08121550128224396, 0.12126875365333212, 0.10690466636010718, 0.09150513462842473, 0.11372818851903563, 0.1468500458905774, 0.07816932885156525, 0.23840067848082513, 0.13920001445278046, 0.22884941599782438, 0.16176795346602318, 0.1594883822385342, 0.24873701254687003, 0.2826708465093567, 0.15616458720497547, 0.11604230265103041, 0.19443879955478255, 0.07766118273139, 0.09028074992520195, 0.13124537113453114, 0.22727335863296064, 0.10282425224901208, 0.06515583924708829, 0.08886404650946779, 0.10525679591322139, 0.20992805550415672, 0.12909589695834345, 0.14790298777722544, 0.11082750384605701, 0.15458060849097469, 0.14264114351282198, 0.1504685549486068, 0.13507784854981209, 0.2105609513819218, 0.1655160386355654, 0.25403927561015854, 0.18168587177511186, 0.2055721102102149, 0.1561062266269038, 0.09347539785648547, 0.11064830821968856, 0.11998957068088556, 0.1379804331208429, 0.11460332905933743, 0.17036863873081823, 0.15673622669231507, 0.242816194771759, 0.12514344251324094, 0.09827997956064441, 0.10882192396468694, 0.20525416839988003, 0.1686036947273439, 0.16705864860165506, 0.10210440539184118, 0.12987402778479362, 0.11649666939892116, 0.16762356183701949, 0.2149951448964496, 0.14375730297498165], [0.1020931898646297, 0.023348800943142945, 0.05445377480599189, 0.03434273339207134, 0.024413984914821003, 0.03753114919809084, 0.05242111754693812, 0.012491370040562846, 0.0403614342212677, 0.06964590355393387, 0.02241838332866469, 0.04474999953902537, 0.034414653726402795, 0.0275746415249042, 0.024000023559276617, 0.04031061577881056, 0.01757684745825827, 0.05048899783662731, 0.0205377045072495, 0.04648795809536692, 0.038867497651447216, 0.03903902856813323, 0.032419461997285966, 0.057396716888873815, 0.007611154869664461, 0.0421808700587961, 0.040566063966722264, 0.026971508162997426, 0.04399052678397106, 0.08290779716785877, 0.04138524944503461, 0.024331670682576877, 0.03693490296662335, 0.03819838496706179, 0.05667739863237066, 0.030053560321609822, 0.04953935907612886, 0.04623074790522937, 0.023409153349817764, 0.04791054506635955, 0.025152974393999866, 0.05788842276219399, 0.07123396551657109, 0.03512916478118108, 0.020847924151307633, 0.013516960673094278, 0.06257779633386001, 0.04238626206173532, 0.034396374868529464, 0.023781018173922936, 0.014522949030863182, 0.022808504028005466, 0.01229622254839107, 0.11433268551744762, 0.021366801248082233, 0.016827548350838405, 0.028412701494451013, 0.03872428900532184, 0.02420499038341786, 0.045719104593679796, 0.03910895324342194, 0.03162981495411406, 0.03521342296153307, 0.011844272807901426, 0.05036386886551496, 0.03666676836268556, 0.03934218871196912, 0.04322171924755939, 0.025790095246667345, 0.02335187487093912, 0.041583352121374303, 0.03414836539436252, 0.015780352123622454, 0.028747269327962593, 0.03593288294430222, 0.030604457978399533, 0.11713056885186704, 0.06829147542556448, 0.04912638405878698, 0.05245617756079282, 0.030121508490053878, 0.03141266350153714, 0.04716119233278498, 0.0818846331188275, 0.09349148570289535, 0.052267367530974655, 0.05993038415908814, 0.07757872102722045, 0.06750042835671095, 0.04793550804137223, 0.018867627086658633, 0.09763421340575142, 0.019521892987071507, 0.04370457680535413, 0.027133346152221485, 0.02329849386437526, 0.06982103891430363, 0.0699242999056174, 0.032686393843182636, 0.05128096421098998, 0.039260466282646504, 0.024725280912412752, 0.035888959293163596, 0.04204419231222522, 0.008455422545422711, 0.04431321833943648, 0.028746696677239194, 0.07813874662162797, 0.02742610090682584, 0.019087978871539235, 0.057624382898211486, 0.0385568528285911, 0.014722690177750925, 0.018641634979435516, 0.05694316602462242, 0.03966340171774069, 0.048053830321277344, 0.032088743755593896, 0.04350936228048898, 0.03776444212323235, 0.05513716353884628, 0.06397624387435856, 0.11160781802309137, 0.04067905044423477, 0.030363561630609538, 0.05775870109397558, 0.018880549074721434, 0.04762536500610652, 0.10199513827120105, 0.050088199786841876, 0.05958511599249417, 0.02872951524031739, 0.06466218751044044, 0.016691494965925813, 0.0505746158230449, 0.03434143104260007, 0.08469158693427041, 0.04209928935573947, 0.004641562981921579, 0.02404777381959702, 0.07642996452388263, 0.019781091175372564, 0.03288099932814798, 0.0449716632494763, 0.059902839467770634, 0.0683660923893894, 0.048341293323544726, 0.0419025847898616, 0.011669990677957334, 0.019309554481878877, 0.017725956896620414, 0.03272702331624685, 0.07911336367889758, 0.0394844129351118, 0.0179460194833096, 0.025296047059518677, 0.11917223913534997, 0.05070613779788537, 0.07420143007390922, 0.02272092294128191, 0.0397702863049363, 0.03774832363330549, 0.08038417331033176, 0.03672658450781338, 0.03964672781406872, 0.03748559761011312, 0.07333854694039592, 0.07251189210482183, 0.028932976701687423, 0.016913229539509744, 0.03867199967405008, 0.0560087992268945, 0.00956827825340893, 0.06881351071980692, 0.03175467579445291, 0.0021140818716958165, 0.021140519942667697, 0.024079060850424633, 0.037289528897212404, 0.03578257266311877, 0.01194638658254858, 0.08394662771494159, 0.01392162363645771, 0.03303792094811797, 0.03372704001864599, 0.04172022138992625, 0.06242286271205353, 0.025571340755108866, 0.023211269008536494, 0.033462850767518246, 0.03314866661845196, 0.05745560989805287, 0.008896112708645243, 0.07173656516017453, 0.04164566188269565, 0.07050196084404184, 0.019837906171057015, 0.055252417636614655, 0.030542439330489408, 0.03519399497177332, 0.011905736042066448, 0.08144197219441976, 0.025935042912380833, 0.13536647983616398, 0.053311495576053865, 0.04492504679928384, 0.0356132519100943, 0.004928501692765783, 0.02172491096350695, 0.015103059535425518, 0.023985917965370803, 0.054991177823995395, 0.0027350461694426956, 0.03950970149749229, 0.10939923250266623, 0.021644672829537623, 0.017428130639957327, 0.02750026779399524, 0.05447466219324739, 0.029291674389594027, 0.04909123211438137, 0.05296052771530325, 0.09904538566667227, 0.018045013364885124, 0.010054689501562427, 0.03636463477666821, 0.0479441648349166, 0.006334566541256444, 0.002987543003626108, 0.026073130260732387, 0.029669505123409535, 0.05027584153257551, 0.0787633304454146, 0.036966350875915065, 0.07167035218087897, 0.04606655228041834, 0.07023896285963636, 0.029642623098146532, 0.019644219991600802, 0.038208439871067965, 0.05987763900550143, 0.03238589968532324, 0.03887119402568187, 0.05751880449092677, 0.025925380628435843, 0.01012032121164544, 0.03461182560591448, 0.034880496471399264, 0.02311966979065009, 0.02304982172415382, 0.04583583724114203, 0.04615356071641849, 0.10494625451223505, 0.06832955765628046, 0.04834592049460738, 0.054700504913325274, 0.07678228836025923, 0.030037196683547193, 0.08207321332226838, 0.081561497232366, 0.019785842835722912, 0.036747640434412226, 0.009144984031726998, 0.03379709875932144, 0.06675389865713735, 0.03982940914049264, 0.05768063290405178, 0.04730448524858202, 0.035353850708493305, 0.023325029234852523, 0.03787464770157972, 0.05042687576684741, 0.07291377416902012, 0.01787882782669077, 0.03367313041141437, 0.018709889583049283, 0.018683708528237, 0.08960217222451203, 0.0055995037414944705, 0.025406719951499856, 0.011481554116002254, 0.04612718813962514, 0.019364195703078183, 0.0916761560966411, 0.01839735060780039, 0.11406941174138939, 0.05947558074108055, 0.012911632469284439, 0.02055447800235162, 0.02858591397413083, 0.06431578553371853, 0.10598864736816577, 0.05346439523442138, 0.06532268553611732, 0.052884999106848435, 0.07069854666629145, 0.03899300966652171, 0.03426656126976013, 0.08045342765868672, 0.02470079482713294, 0.049372711969960126, 0.028418272868880344, 0.013887773083913472, 0.047479463560927304, 0.06891056639893402, 0.07169586290875751, 0.057633043522195476, 0.07981709204614162, 0.023019773840543725, 0.004216967368378274, 0.053766953999236713, 0.06286283849828667, 0.04377791057190588, 0.04049042427551843, 0.01241634896535787, 0.05328448714628335, 0.059966780996370705, 0.05233980880509462, 0.047802925034756624, 0.0666156504303217, 0.04387269480033748, 0.03765031417471267, 0.009398258445153554, 0.03194174105902353, 0.03561304889679436, 0.010281477382616892, 0.01370836678336585, 0.03893706226541151, 0.032281462749045704, 0.07884681870740268, 0.010230704905435203, 0.0456137445214535, 0.07011736938429457, 0.0223136150593599, 0.06285926852855953, 0.029652438599676378, 0.016477193360427217, 0.04744716529403964, 0.034692008198509296, 0.04743089358652792, 0.03666163557359288, 0.07803717868462687, 0.0592942362380845, 0.02696721040974221, 0.0382427912535927, 0.04873788172018625, 0.04954513537907793, 0.0202615681149426, 0.011465866550532802, 0.06534734590639991, 0.03162851835030221, 0.03548638391939383, 0.20113105254788555, 0.06913831667794336, 0.12431110330526868, 0.16283620178939837, 0.21218855114233112, 0.16931422595535556, 0.13146362958415864, 0.11443228460848333, 0.1914917205971095, 0.12311513280315746, 0.19138526501915148, 0.11811256333584748, 0.1401564905480031, 0.08170919132328804, 0.09383262465557746, 0.1491647345885154, 0.0610096718094522, 0.21636178446633203, 0.1197292463433358, 0.13932032090040947, 0.11685185074325531, 0.14721750762433777, 0.10364090197629507, 0.20952356108013662, 0.10809833859844555, 0.1874432523524569, 0.13931193989851784, 0.17546922148716065, 0.2350511275712521, 0.19062996361284487, 0.19207898827810443, 0.12902710226274308, 0.09434705269673178, 0.14811395306981381, 0.23098807301252122, 0.14870249245676304, 0.1362373226232106, 0.16937470093609827, 0.19496614383834024, 0.1518901843096941, 0.061132414416680415, 0.14159348763285146, 0.13933126063596818, 0.19958602174395518, 0.14067781338047597, 0.13586238387130922, 0.24121398316516032, 0.09242057139354368, 0.11916997917597333, 0.13006994711054912, 0.11453818094225661, 0.09273985385774605, 0.0837141276908017, 0.25525888758561305, 0.07843382070742308, 0.1421353875869705, 0.28382981496472515, 0.1972197600069546, 0.18835080607283503, 0.17966136186113282, 0.1094089464975461, 0.13322131107411078, 0.2175983576284301, 0.11472385001158523, 0.1474917364577132, 0.10997937556596533, 0.10517107833537365, 0.15975332608626736, 0.09568230564435644, 0.09350848519393513, 0.13521153089259902, 0.10271775070577861, 0.09546830664358794, 0.1458191826579071, 0.14442427444361872, 0.1389586048260812, 0.3245430980478564, 0.1926313070279937, 0.10329948723196022, 0.12485863400563119, 0.11367682232371262, 0.1779376333879848, 0.14975076120707298, 0.15699062917021014, 0.11892950417654169, 0.23021326700766243, 0.09653980317976206, 0.15581102230616156, 0.15434920397256652, 0.16064969492295098, 0.11434033107493194, 0.23953415153007354, 0.14407119984107633, 0.17585251059743667, 0.12151774755048177, 0.17959652017922173, 0.16564052792326098, 0.1985492749560264, 0.13156528945171064, 0.16007624746811006, 0.09331150866684415, 0.15418233470089976, 0.1742395431163811, 0.18386214370689086, 0.07982532749132765, 0.19379566874234908, 0.15668561892403712, 0.19894595528321884, 0.13205800656109087, 0.20357868814420318, 0.12229692791738819, 0.11702451163962965, 0.07427386368714994, 0.18333499860619346, 0.2243818516933149, 0.19208831922902217, 0.1328163723190946, 0.2778941044403661, 0.08665477150991079, 0.2148268353794852, 0.10981241436374765, 0.1058015380535395, 0.16474559933187502, 0.09884445612589199, 0.1869300653737399, 0.13866860990322408, 0.0936483268836333, 0.1629186634935679, 0.2168142053508951, 0.3000548830436122, 0.11974575553810406, 0.15420145625548978, 0.14875762014379426, 0.0852694700381929, 0.1873264699092796, 0.17096309231654291, 0.15314316707513026, 0.1105608669440112, 0.0438911498584334, 0.1799001974324065, 0.2130983724829651, 0.1723499872511433, 0.19687046987875817, 0.2032194235512326, 0.08305127777519726, 0.18739235347076771, 0.12918971208555083, 0.15926529743498372, 0.2570377743893093, 0.13414391076132176, 0.12650946155190468, 0.08918694490867277, 0.19180739478718853, 0.1909117613949122, 0.1476118284007234, 0.1017053195485665, 0.17726335344055008, 0.1280904372012423, 0.21510507851358385, 0.11517288478752298, 0.16621089570464628, 0.06503872738610353, 0.1809291454452661, 0.132770698157049, 0.15068309021092233, 0.13746444226032303, 0.20838694707039865, 0.20454789662072737, 0.17210424156679263, 0.11343752709968437, 0.09319838046306565, 0.14805182333915465, 0.10212096055188488, 0.1904191362160829, 0.10943381371156824, 0.11077433734411195], [0.0824503124421162, 0.030042678042645418, 0.03631219605825121, 0.02476589506371848, 0.02784331047516917, 0.06859639374118659, 0.06904306130543833, 0.033967564813792706, 0.1490773086345965, 0.013193355557779151, 0.06175081208047848, 0.04582845215355197, 0.0537829882194919, 0.01255577217952739, 0.0038113714535645544, 0.054225806191924124, 0.009348845774037464, 0.11554140372261887, 0.047828477897471, 0.024965905298989628, 0.057796388789410555, 0.05284174961308318, 0.0580918076147716, 0.045384048379116484, 0.10494258495107775, 0.06271702898365837, 0.01687547289616158, 0.05507727461536566, 0.03299755960582726, 0.0783228069063156, 0.03925360596528457, 0.050536142887487534, 0.02809163787582469, 0.026608393978207346, 0.03847725629325836, 0.02314982109612996, 0.01406981855736024, 0.07007365640733512, 0.05345848486608556, 0.06437368645903564, 0.05973075313733951, 0.10628457947243607, 0.06123331968762702, 0.044116387369051095, 0.04643405231857493, 0.08881084170312652, 0.018433963864921563, 0.03790436042172294, 0.042286387179046876, 0.05632039399877672, 0.031321807388937285, 0.08164574392139912, 0.040238936762175256, 0.014080132973650772, 0.025575598288748055, 0.02833168578123854, 0.03457136850263323, 0.01788917575932799, 0.08620943693864731, 0.03840518657178168, 0.06687053554360906, 0.027813636059422168, 0.03125787352121646, 0.029212612200588472, 0.021047457496845917, 0.04989598449620028, 0.10276779156899261, 0.05535388981262523, 0.0808615533394679, 0.028606138695331833, 0.02905768240922161, 0.03555386860464369, 0.08179398959562664, 0.062347349425357204, 0.009464217657824198, 0.03651678366886993, 0.04427441598607167, 0.013147958144996197, 0.04552628409357802, 0.038508723354748184, 0.04071308773071055, 0.02581167977393395, 0.031450165420650475, 0.008649565504803773, 0.018747404908701297, 0.05955233125977459, 0.04774420439536053, 0.019721179269254208, 0.04831168019483167, 0.023303502164180243, 0.020509535454273708, 0.021672313281845663, 0.01870474338741793, 0.04239793341126173, 0.05101525044489292, 0.03458714608343379, 0.014312817816502385, 0.044205904743003274, 0.06411982024268759, 0.04398045655820639, 0.07997953332960606, 0.015969723312845154, 0.04815156781865705, 0.030640404739026583, 0.024637954549924023, 0.0679210412706579, 0.03551015562768425, 0.04789880859935957, 0.07513896847564368, 0.12727630024235095, 0.07092175404390982, 0.12152912395615732, 0.01734210854215968, 0.06020638648600829, 0.013894363355282095, 0.03832029636889216, 0.08800672517428476, 0.026832798368207393, 0.0423313488793229, 0.03642349714233029, 0.04127522772778908, 0.0870126111793422, 0.07260127158294763, 0.04353260538811165, 0.056297369226212465, 0.03074293411637266, 0.039119008147428115, 0.03528268114032765, 0.019043938391992164, 0.014144123340356014, 0.01820569456134352, 0.060206072389959335, 0.08479447254250128, 0.028958839830011133, 0.07831074102150817, 0.028548936825245622, 0.03425895018623241, 0.027025027065387657, 0.00256447070803974, 0.03033712776678224, 0.007205273826501423, 0.0705429925132663, 0.03288987062631115, 0.04746899879988163, 0.04504195564696866, 0.0530692815570341, 0.060700294862110774, 0.004663599501063507, 0.04045827922621562, 0.028573771480530984, 0.035291196207606026, 0.014660886992069503, 0.07084178212549418, 0.025227570290406866, 0.07955050110937127, 0.027143732389254917, 0.07828624152968969, 0.05497442348109138, 0.00497884611831978, 0.025767752292355704, 0.030485863737281294, 0.05639444405753767, 0.00816939212757373, 0.0721139936978298, 0.0069007122205690516, 0.029995559804862546, 0.015626854916673996, 0.02884221060441867, 0.07479993626475334, 0.036907971145645264, 0.013627930424146116, 0.01842094611586823, 0.031070963389450507, 0.04357483598493761, 0.045605049423512914, 0.06040849963263158, 0.008723121436853564, 0.017492508838674235, 0.00432287902391005, 0.029872200496855284, 0.0693683575598463, 0.06270818066813293, 0.05078027595675761, 0.03176047699525952, 0.04606816106505933, 0.03529038032396667, 0.044952024585537376, 0.015587414795112227, 0.057283692106965094, 0.056006225171468915, 0.034001935348515554, 0.023531028362471732, 0.04827329918982522, 0.02518117600571244, 0.04202737285184764, 0.02693224232643843, 0.01815690816710553, 0.010894621598474201, 0.035468514918559985, 0.03269094057501324, 0.026374695026465965, 0.0641561711146947, 0.0984699234005905, 0.06206084786343479, 0.05722259659500373, 0.08435745002521623, 0.06540075755648075, 0.03463386212505641, 0.054832999819829586, 0.04804112475305315, 0.00658349005407804, 0.028425182981957352, 0.049630014090648586, 0.0418986470979308, 0.0249590813708041, 0.091062190251485, 0.07612068716797137, 0.11495602061791767, 0.03392728008029442, 0.037209518674400546, 0.038091473566788825, 0.061235464733815005, 0.042237441821564595, 0.05054454304157727, 0.016750801662583987, 0.03379174380473072, 0.08319238350997049, 0.04525265663922314, 0.05877593945291254, 0.04103560308595339, 0.05804655097064473, 0.013371333104347991, 0.035793795851209474, 0.0492548186992926, 0.05638962536449394, 0.005772130642717164, 0.011991406697028828, 0.02162993329787447, 0.0709671753969404, 0.04425401123420847, 0.022417843236678073, 0.046198246625041774, 0.13577865046118537, 0.034275930525074084, 0.0256802516448642, 0.02532289844126471, 0.01307328947023639, 0.06194591935303423, 0.058567900616194934, 0.05675387718985158, 0.046560901157077283, 0.020769698913359357, 0.04882732248534599, 0.013518940052768637, 0.05191313996610623, 0.07269545443235867, 0.011873694414633417, 0.014689936088548313, 0.10380148932698274, 0.0027536218863866866, 0.029530096273388595, 0.05235896866408087, 0.04415588303198738, 0.024966518169329054, 0.09738606986619773, 0.05001421484555449, 0.055687325751228686, 0.035947503732337106, 0.027669632597075357, 0.005851192352917767, 0.07013671310438264, 0.0925230356534162, 0.02121673803025436, 0.01991661212917778, 0.045843095924224586, 0.04069626060945373, 0.07760898150022953, 0.04688494485772906, 0.006925328540795994, 0.06490440152946018, 0.05934403195316273, 0.10723718682364111, 0.0056496868097794155, 0.017854617533063697, 0.025374002251473647, 0.1947782990793067, 0.04275033768687037, 0.0548092893985731, 0.056839897372429414, 0.02643100248890058, 0.034187945326970476, 0.02959918782805964, 0.050391179900015556, 0.04074275065513869, 0.0506481028071815, 0.022970338186789906, 0.011543439656135537, 0.032180787304476384, 0.02769564319732449, 0.03333340489095257, 0.059778430619307106, 0.01931405907887365, 0.07720614948700513, 0.06210662927778979, 0.0772371071000253, 0.08160048344683263, 0.009626709694613614, 0.017473362386226654, 0.0505527286910482, 0.028286950076900186, 0.03949387412097666, 0.01718315870441016, 0.034528754861845125, 0.021366630793519078, 0.03393058191924807, 0.04854992204796403, 0.01517768607534949, 0.06622549717224414, 0.07298564087719688, 0.04421436618412695, 0.027264368254691366, 0.040952988164198977, 0.01918984749805062, 0.00621964042488065, 0.010876663539919161, 0.04221869181961783, 0.028732581507234324, 0.009241777325740025, 0.051137495094970356, 0.028930986788304105, 0.1531224673794162, 0.0550994758434113, 0.06683249161728928, 0.060982295657478036, 0.028191547232469725, 0.10033881021363121, 0.055765531836978854, 0.07836445144587949, 0.04334551139524387, 0.02157689894609634, 0.04713576970501773, 0.0775656975325077, 0.0732558247663321, 0.03534831189280076, 0.005897030745062136, 0.04432766292724879, 0.05898746398968562, 0.011442517148210637, 0.05468519464615853, 0.06886849285013254, 0.03393221368652678, 0.023280778081126274, 0.22289073815749538, 0.1620729637121962, 0.15689450045747144, 0.08851680183602918, 0.20092322821578673, 0.128359341723544, 0.1854741918824373, 0.15098088390884862, 0.1838548505498517, 0.14452431020477127, 0.1137384924016172, 0.18542067298004705, 0.12704154025883446, 0.135042286748367, 0.16257416907577746, 0.1534379423866349, 0.07779989061096022, 0.13531034091307273, 0.0777321071514199, 0.1995144384883104, 0.1748565350088381, 0.06222813082258068, 0.17070127410754082, 0.16219184523628605, 0.3483815172747258, 0.17538502842428225, 0.21388067082772333, 0.18787258334698217, 0.12852781977985175, 0.137709912153021, 0.12941233723634674, 0.15167859082500781, 0.14429201702437094, 0.12833059044374576, 0.1575822329088565, 0.20741084380255592, 0.10178686960810616, 0.1207864017135674, 0.16753630442244394, 0.17058525775228778, 0.13628359433383713, 0.18057358871784904, 0.10930567784535308, 0.1554495054146936, 0.14472687917370952, 0.09416655472089207, 0.09277729257460564, 0.22899864992547422, 0.07779334822008688, 0.2387392740215986, 0.17336241840835542, 0.24933558768562733, 0.14193464190729205, 0.11725774710817684, 0.24221650114463222, 0.08046986024466254, 0.09558531891314254, 0.20049308516806175, 0.18532517245940625, 0.15990652834936497, 0.15024364685579655, 0.1356185840502862, 0.16567821944913558, 0.128382500561495, 0.07953484227219898, 0.16048092575323197, 0.24253856450799974, 0.12402730603371898, 0.1394751166263896, 0.08787807602916034, 0.17221966037346473, 0.12350831210853593, 0.11962146543326879, 0.11645479503298, 0.15169261023402214, 0.11046622444184558, 0.10964507011756783, 0.1448870068716426, 0.10982661763386381, 0.10951498072714576, 0.12009080920007922, 0.12915468654565274, 0.21456417447376638, 0.06970602613423141, 0.12756342999637127, 0.12451204050692821, 0.12265990803679153, 0.1156072719623485, 0.16803081417756696, 0.2802825520836538, 0.15204053672571338, 0.10513386944489134, 0.07627885368081831, 0.1215398032218218, 0.18352183212916698, 0.21317729486092446, 0.08736903358611368, 0.10368312108180217, 0.17751679064766054, 0.16422829080012538, 0.185215238842272, 0.14932887658717173, 0.15421342254886705, 0.16355655426459928, 0.10883535348599958, 0.2323316533358828, 0.13266654084286383, 0.08919112774873934, 0.1466800050149041, 0.29775294204873426, 0.11036336947713168, 0.23731882443591473, 0.1555291325935433, 0.1672517334020907, 0.16566029299170743, 0.17521820511789093, 0.10212476034798931, 0.09084803037225239, 0.20284917325742785, 0.0922496188732405, 0.1383012554217731, 0.15862726876812597, 0.0921399457260005, 0.08604662027209999, 0.11318955209947403, 0.14771295200672843, 0.22487910404320688, 0.11005688068126479, 0.14486387101632936, 0.10509145881740317, 0.09979635867620669, 0.14287371248487504, 0.17596486505241166, 0.14944774278950307, 0.1747664737124597, 0.08013331781952612, 0.1474961031588816, 0.16021881643081867, 0.15274850922005792, 0.12657549833097767, 0.08972312984687668, 0.20151507710256886, 0.09017558903583596, 0.1519196633730204, 0.10508873154439273, 0.18851623509920415, 0.20260301388559804, 0.10970877032847175, 0.11630924598824595, 0.12036503037257541, 0.12031526530101416, 0.08121140271184907, 0.2141862939442358, 0.09965380503525657, 0.19266273195464767, 0.1744994461055725, 0.18667670477542186, 0.13951496852021064, 0.13974672543906397, 0.2444261438663929, 0.08632650283435661, 0.19067868680482913, 0.13472426832923967, 0.08389372934377001, 0.0988259704242791, 0.14413069422927596, 0.14695449431817378, 0.10240687988698484, 0.1743532765296198, 0.15922258037232584, 0.11364785653929557, 0.12638687216226133, 0.1322313262930801, 0.19685131768065114, 0.15274581259056447, 0.11297479467166048], [0.014396694868112044, 0.022029743094237584, 0.037913913538138715, 0.0951675022201192, 0.05185014072565302, 0.04968071378947747, 0.015797728912964944, 0.03304088570838494, 0.03361800655482277, 0.0644597640982078, 0.027647341353698607, 0.0599686234378286, 0.06869167209632936, 0.025741891079251806, 0.11357892394786882, 0.035605801705030665, 0.006797053342339613, 0.08046714063253134, 0.09217545390129091, 0.08077175251298374, 0.038424737135609316, 0.03685263278443487, 0.060866896003004045, 0.07392070481493589, 0.035700241193896344, 0.04191610624172515, 0.001533840174576448, 0.03033401361937004, 0.022025897332857695, 0.01035888099126638, 0.023552235591435627, 0.03382989115292027, 0.052635078243310415, 0.012821288677983949, 0.011991229539196338, 0.03303514004895284, 0.04223666424232145, 0.02859425284118662, 0.014534548559646695, 0.053497731550446445, 0.04052002591291263, 0.03500606594306808, 0.05322984209464443, 0.0777171454542587, 0.051133538250841444, 0.03509107105914624, 0.013838897631954283, 0.03083643323231128, 0.04817281526723697, 0.0049508647568854355, 0.08703744774984737, 0.05663687641161585, 0.051946112390367255, 0.05584112939334685, 0.04738848678947938, 0.08085214577975773, 0.06285571388059086, 0.07271168783547417, 0.02592219944833027, 0.02921837701221868, 0.03995033994977994, 0.038214331087205684, 0.03510179629008617, 0.017847782113559304, 0.03302932544160755, 0.02894965826623863, 0.07485623606630872, 0.024199162369533896, 0.06765401366377069, 0.0914980942804006, 0.014226105281962984, 0.06337537047182841, 0.06653916421196153, 0.02226547983985755, 0.0267161097708008, 0.058828719080455845, 0.021048533850379532, 0.03604422233277752, 0.032293122607253255, 0.04565984386229708, 0.015797212761225962, 0.046820601132968744, 0.02386309683413035, 0.050558386250369014, 0.04096244551962422, 0.03161018586627418, 0.01583684631998861, 0.07929479628200493, 0.056333547728436614, 0.04199782101016852, 0.022569836996075128, 0.06453856390209929, 0.05106193584299857, 0.06583260131939765, 0.035113486791810686, 0.06233734048662647, 0.04252389358777193, 0.02246217482963637, 0.021421440554061727, 0.02821475203569618, 0.10885521048499693, 0.08400467419696432, 0.027707894858453545, 0.016534356926117214, 0.026394848884533972, 0.05513367017791156, 0.03852425195697335, 0.04618866669554864, 0.024817797520588485, 0.055317332096878565, 0.05175532968414407, 0.044445268914944706, 0.02317952232495431, 0.04179920505491957, 0.02218824285533159, 0.0338378622977724, 0.07050567637047461, 0.03781249115784322, 0.0411107563113253, 0.025881129474709594, 0.06378253088182499, 0.02082299373503174, 0.015851585851651768, 0.04253005293468314, 0.059703082041514505, 0.06978000724507917, 0.0699557631366676, 0.10115683123829866, 0.06356519173770663, 0.012537187844094251, 0.009717063062013158, 0.0433598525611864, 0.057682513649905884, 0.02836825115786445, 0.02274541668744097, 0.0660178107359717, 0.00810221962315301, 0.04323581526536615, 0.05055035764892256, 0.10827715118085185, 0.07606847827593166, 0.007681340014847417, 0.029357762879601894, 0.04302358975814235, 0.011356076574884357, 0.01277262102737422, 0.01948551147154743, 0.03632708114661998, 0.007856250336889418, 0.046428728007501176, 0.056515819197821046, 0.01656985361008875, 0.011816127695173267, 0.016676477727390105, 0.030826435784899422, 0.0421598754192312, 0.008623365297793381, 0.032938195452574766, 0.019865441286275466, 0.04076711608157043, 0.03081176520114945, 0.03460301176434563, 0.019442378806190628, 0.04772918141116539, 0.030284373037096475, 0.05028923274949194, 0.011547126454271136, 0.03569340385917214, 0.015907161700118695, 0.04748334762670341, 0.01735002606085712, 0.03683180285377368, 0.015602410008620112, 0.08430160221553619, 0.030176348894113497, 0.029031880567931843, 0.021524680477957574, 0.01764234031490501, 0.018229140682266127, 0.024220769879438227, 0.02751338513447873, 0.0486884767099494, 0.09143305341562918, 0.014446062531562583, 0.050647547393436396, 0.03217680364727013, 0.046524841398481405, 0.03423363864121418, 0.013814715109014464, 0.015592850188934996, 0.04366573231715349, 0.019122661587091225, 0.0630369856052341, 0.08226020006282676, 0.05442101305591003, 0.10897062929166902, 0.01975236670865167, 0.004167844853063505, 0.013731303455818807, 0.06281326494870648, 0.02243303284499674, 0.04731892217551509, 0.05381393817163283, 0.04046813494736149, 0.05776885941985154, 0.01583758463722564, 0.028726726680273013, 0.030468406508706754, 0.07773730888842575, 0.030232031994889823, 0.05812604025366807, 0.0530887172076731, 0.024247238217222116, 0.015912951409606444, 0.03493058329988872, 0.09720538036837693, 0.04452687260063906, 0.03319559333425376, 0.031830595107749104, 0.04937203398214714, 0.008250719064005442, 0.03711750385381522, 0.005981975052911308, 0.013022199066566124, 0.06188200846795113, 0.022331918815090772, 0.03470540707630496, 0.03544748197459886, 0.011475999978551222, 0.03290112445791883, 0.03321250855562187, 0.04202495967488616, 0.0475747840509059, 0.12778181102006667, 0.02042740891357103, 0.0655144679870817, 0.02931675610823497, 0.008139565451851776, 0.045420705686293306, 0.04295436988374399, 0.02905525199528183, 0.054653470945214076, 0.08236772050299952, 0.07210236448313921, 0.028242614653502262, 0.05643180999604445, 0.02301860747167901, 0.04899884574115277, 0.021206332641022823, 0.0121959138684155, 0.02071216187980627, 0.05648133758034918, 0.02094787947322813, 0.028319721403081092, 0.036373203470101284, 0.052826355076244766, 0.01950424806695552, 0.039276086815422585, 0.0020671381583181963, 0.02332442211017253, 0.021182626050205964, 0.043879834739791776, 0.04088887809625557, 0.00450363076637469, 0.06660307126660502, 0.051762113392713575, 0.03883772747470968, 0.02584459282638085, 0.01364793489506889, 0.017717958938690926, 0.025698233643666874, 0.04623455153177342, 0.016882287248248057, 0.048380903899669654, 0.041194654430352876, 0.012846674916574792, 0.08900007308130303, 0.03806857519873208, 0.020387756202610272, 0.017205216290970004, 0.025060419481427922, 0.05215973983849249, 0.03384008778319244, 0.03434706561928315, 0.030271292085789388, 0.029456975096235835, 0.06357479464983748, 0.028886929071778734, 0.032746022296769005, 0.07950356290225061, 0.05700813028060141, 0.07241852130861053, 0.011032814283915346, 0.008222040562560002, 0.03818716177897107, 0.0316319887285992, 0.058753876120693264, 0.02304570017112119, 0.01927741709345531, 0.049482002073237975, 0.03215145379785569, 0.01673311077719254, 0.01944124116562307, 0.06520237908848832, 0.026291017157716617, 0.024573704670934428, 0.018920755284207485, 0.02724911352889913, 0.06395864683473784, 0.07685623882759003, 0.046387726981793685, 0.05949028579878712, 0.027331506285155495, 0.07623166266468263, 0.06469918955718318, 0.09821438711256751, 0.017455282711213636, 0.05489338287002137, 0.0192377548063955, 0.022096722161457426, 0.021006613519162904, 0.005113719249024026, 0.023007451316281673, 0.05619385925632331, 0.017686135646316315, 0.049782392809227596, 0.01549703078419571, 0.03970843619636951, 0.03515758281273227, 0.021883941240488522, 0.04443265527727143, 0.03880942818678675, 0.07291879204492416, 0.04791289695628709, 0.06085649252899232, 0.03374709237006403, 0.0667448511587516, 0.041114866373039065, 0.039284735948087714, 0.029724462355877605, 0.030693720628116882, 0.046267393721087326, 0.013146083144801519, 0.06918094947092956, 0.00996202350624146, 0.09951040103671052, 0.041578613867562626, 0.03172829938721994, 0.01877631515174383, 0.08404221250525407, 0.04537344955268406, 0.04182335214629289, 0.10675044520007027, 0.08832459037582721, 0.20004768164888506, 0.1475207099030095, 0.11934908287179087, 0.1283257487680643, 0.22290491078409458, 0.2370761124597442, 0.1827015511451229, 0.08671405139349161, 0.1899955662027482, 0.14437023460143997, 0.13575384453419717, 0.10417132593330838, 0.18968081131817835, 0.10729925526726632, 0.11413174065490884, 0.13857022889198797, 0.16509636034888608, 0.21252748376179129, 0.13970180204318416, 0.11566294357180597, 0.06095902573677802, 0.19725827890778744, 0.10981583877676919, 0.13187195444780012, 0.16716999182056996, 0.08363316751896374, 0.15596145133097328, 0.06302063728892995, 0.13584189868021396, 0.11189165359903729, 0.18246740403194583, 0.11873195308350748, 0.1725613509094523, 0.11800643717569691, 0.10710744217278496, 0.126386672979401, 0.09787100352226727, 0.2501141934865906, 0.12931459973896706, 0.14208910055458546, 0.15203800863556324, 0.1601212474727823, 0.0734358324459003, 0.1422164090458424, 0.09909368751029815, 0.08184752381977536, 0.10503443889319898, 0.11346977940129657, 0.18667213889139314, 0.1703393894938692, 0.14937024533508286, 0.1129054100883584, 0.1164359875744389, 0.16304480753117995, 0.14603043906390667, 0.22639664761241407, 0.07402237234336716, 0.1745046861469746, 0.10698685993350322, 0.06877025739560205, 0.1627376828823359, 0.11120737620419073, 0.13594709787397616, 0.24590185903493436, 0.1821546103324621, 0.19905132301632436, 0.11930243577808143, 0.14158260918432666, 0.07757066944313627, 0.12274721907752177, 0.2295625366030201, 0.10041030919960431, 0.1473708937485372, 0.15789219208302038, 0.13010140268072007, 0.07847240855616909, 0.13471463094315222, 0.1823525674520962, 0.16430692206467354, 0.11831099542999461, 0.11559902885628325, 0.15417611406695458, 0.13421750116732814, 0.11930150115081381, 0.09941319980087782, 0.22725868038833144, 0.20364759009211295, 0.11426320134271538, 0.16055226386074098, 0.11259638554146213, 0.13240570322640483, 0.2336796922909637, 0.12211218581444795, 0.15047033227259113, 0.2884763220865881, 0.08178612187264428, 0.1503044895587429, 0.12357640966412523, 0.30191160438041537, 0.12781788610042105, 0.10720095086482265, 0.10973823407003958, 0.10800423235782694, 0.17112469090329063, 0.1370593656094805, 0.10056585569175021, 0.12402101645186064, 0.2695017644474583, 0.1858199120409066, 0.191069039245767, 0.11238748102539009, 0.1422740035359898, 0.10657828226084672, 0.16717628906330756, 0.08730937065857072, 0.10882403836735796, 0.17579277106110128, 0.16073215662712054, 0.12526203292391955, 0.15236730386893596, 0.16191842845611035, 0.17797177026589073, 0.13317701587032887, 0.14639696617039943, 0.1259570278888268, 0.23873607177407513, 0.1279721532257334, 0.18638864039413391, 0.10704071591458014, 0.19338856961938644, 0.2624618454325584, 0.20981229961879794, 0.12566648904354344, 0.21387443487201968, 0.09893993366389506, 0.2539117679360413, 0.2300798911000452, 0.3012367422061582, 0.113123293154903, 0.14104401873004052, 0.16537791298281762, 0.18249076971363637, 0.10526330766057777, 0.15210125685459183, 0.09633963206602682, 0.1068172250844298, 0.10649425773731164, 0.11315081869402241, 0.10639819031160687, 0.1369988906287378, 0.11575282100708255, 0.06835385796523864, 0.09323195043590762, 0.1772692982828425, 0.09155922043587893, 0.17844565693409215, 0.19822281424797353, 0.05785643093047604, 0.1289745792746544, 0.10657852740898248, 0.10364608839154245, 0.11633241248707618, 0.1195316952503016, 0.14389127643117983, 0.09701792631418475, 0.1819435071440474, 0.07079583217179583, 0.15394789647431145, 0.1270208941892751, 0.1628690516395915, 0.12283823032292629, 0.26048460314350746, 0.09148923830399591, 0.1782541502747805], [0.02398872376239348, 0.024133861034868226, 0.05108033727493979, 0.009181347352662876, 0.0893381630040465, 0.02161937086061845, 0.01193671663772435, 0.029012224667014617, 0.01426650780147963, 0.04098459695195479, 0.017134569577812668, 0.04806969217174957, 0.0398073879431092, 0.009437943714851094, 0.04203555467087896, 0.052579548360118945, 0.04344652774893949, 0.01980348009495966, 0.020515246639749216, 0.03242613079266683, 0.00615265800602614, 0.09890553631609487, 0.0669599226826141, 0.04447973138021846, 0.03004311279754245, 0.07466855984661849, 0.032695326428379745, 0.018699809781185562, 0.060754139351868824, 0.04694455415911732, 0.0727235392156628, 0.032710050638284416, 0.03423371525000661, 0.05749090356872447, 0.027227438986301426, 0.004824757587254769, 0.08044743685111885, 0.025643805011866555, 0.022103461819971283, 0.04161294226744964, 0.007307028976239025, 0.05831594195877833, 0.06813928439852691, 0.05459291552523932, 0.08930348986459356, 0.09151172298457354, 0.03667485825116596, 0.03667329543180043, 0.03385488477144991, 0.028938940696177945, 0.01804049153091206, 0.03472065605643777, 0.0674289217098586, 0.07611338635005298, 0.05612401885070628, 0.0282054842870322, 0.007061319681064737, 0.05937957843284934, 0.01083556771083104, 0.014602030372066845, 0.038952824524453575, 0.010335833236064402, 0.007102852180269697, 0.05370634495310726, 0.044035664684469664, 0.040538706966946204, 0.114578768280485, 0.012042889720760288, 0.03662426580464648, 0.05268187855460471, 0.02020652661280286, 0.07442678249771557, 0.033984403426368395, 0.034387679770588875, 0.009149435960176972, 0.08750456986167739, 0.07877981665754512, 0.038580245323359005, 0.06659039251145817, 0.017975985012467832, 0.072575063715058, 0.07306497694263536, 0.04047455093372734, 0.06985677691597132, 0.031125403512569687, 0.023278872437414624, 0.018520851642073646, 0.01690445591755692, 0.02699738278264, 0.016230187461441083, 0.025825965398501967, 0.0481827361058564, 0.009060661691511351, 0.012291958311482543, 0.0252423768547634, 0.07253533439530481, 0.04740977254245551, 0.0575655933109022, 0.041518682809246164, 0.08940387036531203, 0.01655168775018425, 0.01928942935210803, 0.05327936967894916, 0.04165808016794824, 0.019400525507667375, 0.048355983059492805, 0.030925998486758723, 0.009973587603458475, 0.02604603756129021, 0.02971272588887763, 0.029144495492801074, 0.020194661826075568, 0.08177941094242758, 0.08996175091353156, 0.039445407568447055, 0.04027816046389841, 0.030666986074779305, 0.021330327802007238, 0.03796631012171988, 0.02383866245978542, 0.08450332082687848, 0.031503837540625565, 0.037853082326511224, 0.029030197089718237, 0.05889731459319592, 0.019799718603251443, 0.06129719992919315, 0.00729814570795204, 0.016580304964595748, 0.04132221956106444, 0.033561266252710935, 0.032157126678934986, 0.02067255896456059, 0.01822649959414717, 0.027534994559602875, 0.03767062699602496, 0.01704457914456725, 0.018773174191254283, 0.024595245148145387, 0.0754380185577658, 0.03883825607537743, 0.06721018828571805, 0.010716644051905361, 0.04515220719059149, 0.08287948255817737, 0.0634085688920271, 0.05707481057353078, 0.042975333879791924, 0.056314518104397485, 0.021211994030783256, 0.05321930072480633, 0.011911113979294898, 0.0653902238475219, 0.02347437424525138, 0.06591972083814683, 0.06943011956830179, 0.06400131027124102, 0.028681500679663116, 0.05171296119149174, 0.11470135767012836, 0.013190078616683042, 0.016051394031232884, 0.02877362275255784, 0.036428767827249346, 0.0414598242740237, 0.0392198023356257, 0.04073167685419321, 0.020734217551146305, 0.02168894122024217, 0.014357022047343274, 0.015573322607745087, 0.08160904064894685, 0.05420937743638793, 0.021887139657572396, 0.003659647740160806, 0.020112359085150307, 0.04197727836247894, 0.031834887115344886, 0.004502349963126284, 0.030078640125030955, 0.17863344040609178, 0.018988111649730036, 0.02859670623776413, 0.03150786333266766, 0.035352483241548466, 0.024279620753781452, 0.013238710835726272, 0.07611112639067635, 0.04323172818629011, 0.01042395728760429, 0.02862765235946544, 0.025258727086287354, 0.03210922320102973, 0.0481357021377452, 0.054350467849402666, 0.01902945741500345, 0.03249384530429398, 0.028483773386406324, 0.03404755205396683, 0.026151347837801424, 0.03924984447357636, 0.06771465718385673, 0.08735499119446163, 0.05715651385065529, 0.019098298075879296, 0.0126392288403886, 0.10792976095070762, 0.032292299062734654, 0.018552916252144405, 0.03494328120723367, 0.05185873623216345, 0.01775413552569526, 0.03738381516849322, 0.05309988676960911, 0.06672882459937565, 0.022833671931537892, 0.05263852563896968, 0.10638985527499069, 0.024346276148853284, 0.019468377915120894, 0.0436400338977335, 0.03053528981493606, 0.03313409945657177, 0.03188467516954387, 0.010608782702606293, 0.010568217389405736, 0.021269753229834383, 0.003457514483729498, 0.052832529744914467, 0.045268844077063185, 0.0938578672526825, 0.0569388835931257, 0.028255753061403672, 0.008304462047113527, 0.017247793542581703, 0.011231110397455914, 0.06136516341939569, 0.020980367346877055, 0.02536051144312707, 0.08293057296184764, 0.04013080345166307, 0.05318417176303845, 0.030423833598052303, 0.03108178629660078, 0.051599373334958676, 0.011939491791230057, 0.06045266843190598, 0.11465810434592348, 0.04774946741940034, 0.03717452760845904, 0.02946881498510559, 0.0929904948439329, 0.04674848927665622, 0.024775727802226623, 0.04729177968035783, 0.030179022540969234, 0.09356231819237433, 0.02895326079470256, 0.05643884268318934, 0.13000463045412494, 0.005949309063819988, 0.007121596915361982, 0.053546753516721154, 0.049669613175454645, 0.021464571304198717, 0.03866310156280956, 0.03341241153858362, 0.013641720964393068, 0.030483276275317037, 0.06972545412399116, 0.06482027741449495, 0.019166395631468585, 0.03227441857058195, 0.047684300150121414, 0.04532471869982058, 0.03188119713036764, 0.04610667996589215, 0.016544168597207438, 0.016751479650396976, 0.030061891527786374, 0.056283047212468046, 0.04500305753261332, 0.06775699120255248, 0.08602471015746556, 0.0663780635823646, 0.04526395643610628, 0.03621451984790545, 0.02240169601845405, 0.015511282892417044, 0.030846197022906238, 0.027864902663315018, 0.03393739244089492, 0.07480645567298898, 0.02655244849231695, 0.013624561552499092, 0.05637278292147864, 0.010326957149851707, 0.039979581525849725, 0.0515486391621732, 0.036366856431648616, 0.04466297578126673, 0.013596794695683546, 0.07150799516708621, 0.039673613669771346, 0.03687672624965349, 0.05255021485349825, 0.04422056000499476, 0.02054108870065501, 0.03250328733796074, 0.004864966190765582, 0.036796110817381454, 0.06146616828177245, 0.05998588339876264, 0.043396000419893575, 0.02370019781313116, 0.03666016851521788, 0.024976578818994667, 0.032608046031166474, 0.03199865373091833, 0.03569892352266658, 0.01666766197060145, 0.05966259046427666, 0.074427931629602, 0.0441823207262543, 0.04619269248759074, 0.024991921644898194, 0.019963964023777557, 0.03230615759328489, 0.03711441651948037, 0.0425103951185461, 0.01165627004323347, 0.07330907553794884, 0.05334482806163931, 0.03417591391611965, 0.06182193185292906, 0.028169018501836448, 0.05119101399736059, 0.0032705729902391474, 0.05110192563264601, 0.011137865048142211, 0.03446451072851497, 0.0366337193296321, 0.07445716554479254, 0.05177490706104906, 0.035658585163013595, 0.02760708726371729, 0.02126786482310103, 0.043927914417919614, 0.026870913157660156, 0.03397992181201135, 0.06367155538511372, 0.015847759242469988, 0.15744099693913616, 0.1641688730207182, 0.10251489062342914, 0.08996645469338664, 0.21440986904405782, 0.20186770737411516, 0.0763856616592215, 0.15038837618645162, 0.17366914469147884, 0.16366353078234583, 0.1133724402696375, 0.10380640761145662, 0.0878532088151382, 0.15728643103953333, 0.11035722545197896, 0.09969348072885506, 0.13126640790893188, 0.16742905211304465, 0.12366851641526147, 0.15209469914196, 0.15928688579268996, 0.20032157340357382, 0.21859555895770752, 0.1158362862864329, 0.16769384274319296, 0.2453744687861012, 0.22544616232475928, 0.08117479903082694, 0.11249387531631416, 0.12435687705874444, 0.1696923822765389, 0.14181911584831056, 0.11229352034147709, 0.08615383427710303, 0.16565820923255337, 0.10698554226227346, 0.16563611525681712, 0.11329684271326951, 0.1511494538957073, 0.09472519369615663, 0.10477517941786398, 0.1964717977229626, 0.17009505341129919, 0.09515247923592407, 0.1450080794071959, 0.11304656944928632, 0.1503863537143315, 0.10264268175007836, 0.08076720195071352, 0.13548959016559586, 0.05642314937206046, 0.16109197280339657, 0.13249889016151428, 0.18868601550498318, 0.12112302074749624, 0.11670732059546056, 0.09757469603491407, 0.12525151453671918, 0.13395134690067462, 0.15829870897916057, 0.09191539769451465, 0.08103954620779523, 0.06673227965591416, 0.11341669716902318, 0.12140635836629138, 0.17895599406573082, 0.3082451290420948, 0.13891818602719616, 0.12775810059881018, 0.08712751670710503, 0.15454584342097083, 0.1531958279590453, 0.1670142155020468, 0.07669411164017455, 0.1398715977707217, 0.2628275758076099, 0.15658890798447594, 0.13233997288250154, 0.14694847286708895, 0.09584622547751474, 0.19832474990717827, 0.11325081615077873, 0.10862256490415144, 0.2789008665469385, 0.14192400860690302, 0.10591697218197008, 0.15366401493309007, 0.10963772333437398, 0.16177893916685737, 0.17578823582058953, 0.12178722663872665, 0.185771020309579, 0.19053427923110225, 0.23076305766740154, 0.13373846638827555, 0.1016705085132872, 0.09635803349796804, 0.21941490531448396, 0.10104372601715789, 0.19811943834347112, 0.12557887156764347, 0.16592624807550063, 0.19210213945517618, 0.1447529721284105, 0.21290652874496677, 0.10923152053428274, 0.10081395326602845, 0.22695673449385553, 0.10343789633723999, 0.21738547711603104, 0.13026267951053958, 0.15958207479167372, 0.12118605446190604, 0.1875932676897895, 0.08867129878771883, 0.10243512554875306, 0.343098237870201, 0.10071824590164809, 0.09914433358297234, 0.1947970069464176, 0.18022667346221788, 0.14953815648632665, 0.15813635962624706, 0.06672069640649904, 0.1391217968757114, 0.05660066343543511, 0.13854074982866166, 0.13574167905795959, 0.1285218136505254, 0.1465610775255388, 0.2078664669346425, 0.11892756597409326, 0.08282337427860306, 0.1283636701203162, 0.11422355629263387, 0.10816187793088537, 0.16759071198682632, 0.205858948850824, 0.15468499563153715, 0.15346385148023406, 0.0733443079215865, 0.12741020475063594, 0.1845830171218803, 0.12852778147545554, 0.18345812425738384, 0.1434889423751062, 0.2833351673137757, 0.12430784743159048, 0.27870698501506164, 0.14504456051415013, 0.10636085118617743, 0.16701827576804548, 0.12788949233870353, 0.08797323181023521, 0.18408360440404187, 0.20642171704000045, 0.13451986074928315, 0.08683950595197179, 0.12237562812984952, 0.26394695283905156, 0.17735140758656687, 0.07487738009301886, 0.10201992121555152, 0.15349627232118962, 0.10724390541473705, 0.10703413521931057, 0.11395482030967552, 0.15951527192467646, 0.09884298523707737, 0.1363224656351151, 0.07203221381191285, 0.1423753722901306, 0.13289439071330333, 0.15387131832540035, 0.1536463183020392, 0.08928627586893498], [0.04500585375353695, 0.05986028328357686, 0.09567345732883101, 0.042728994477299914, 0.011008803173148585, 0.10185335837905446, 0.06194901817868795, 0.015830339360681754, 0.026638397811761787, 0.01015853176208874, 0.039479804916247245, 0.028808311213769262, 0.0719252526159248, 0.02921558653695449, 0.07449635094211948, 0.08080058806245366, 0.019968514586047783, 0.04418494074695534, 0.06147835291020813, 0.04630957835263783, 0.010046713568660761, 0.06668630671957809, 0.06100034851941371, 0.03303250470649331, 0.044414996950616764, 0.02198826900923685, 0.09663158051309087, 0.045104652282691775, 0.024180940968254884, 0.017970854138594963, 0.01818413301671465, 0.02947102897920676, 0.04591515415438241, 0.04520860275313739, 0.027800313790418932, 0.07773843503767446, 0.0660296927596773, 0.0824769799627604, 0.02800890995610145, 0.05898143870816116, 0.06713275977921102, 0.017011045560901685, 0.02712169970055261, 0.0200403219224104, 0.02887484786521283, 0.06074287019850266, 0.041657517093323895, 0.03779178763168954, 0.035504681929465265, 0.028560795866313483, 0.03468085395833177, 0.015208833295130923, 0.004396819436336838, 0.02662039857598082, 0.07144231844933764, 0.03567030247781546, 0.02004545279628327, 0.04919715526123201, 0.08007551648563917, 0.03087815629588741, 0.051619329925386176, 0.06574591847076532, 0.013813222195172023, 0.07136530363030973, 0.021772770391356562, 0.02871300221510953, 0.03455523469094788, 0.05712355291771312, 0.0210080269513832, 0.08559285107279017, 0.034909389477463505, 0.04168872368491946, 0.01153854531190929, 0.09078641392050252, 0.031104675088558468, 0.04299879915291264, 0.051340412633914145, 0.015336639743538634, 0.022050201472255494, 0.05849422977095651, 0.04289662983689097, 0.013918201138655988, 0.09900280649984076, 0.05104144299102407, 0.035225178580731153, 0.03534070847015228, 0.03106422947659608, 0.004790486165157129, 0.025084099259167433, 0.02363856029396336, 0.06685575004667044, 0.06132137383364382, 0.02127327531906626, 0.06847725940808173, 0.003990325522834375, 0.02686521920916294, 0.03630780637444508, 0.02365740222646104, 0.03899115190330533, 0.062497686519618, 0.04197548571673613, 0.025523460259841337, 0.0252388873242683, 0.027684896898966645, 0.1990885548894444, 0.028189306425291206, 0.05078805174918906, 0.027097263410987876, 0.019850985207144293, 0.015252877605117619, 0.05903831690609936, 0.012730499598077469, 0.030991535393461108, 0.05428227836326246, 0.031311735247952804, 0.012566080850158489, 0.05704304090731087, 0.011655761552373729, 0.016987942264325196, 0.03457942008671742, 0.07804892281250608, 0.07275973687008505, 0.014874276952938208, 0.0180548346120744, 0.04435694280771479, 0.039833461745612087, 0.03444044790681332, 0.08261085382752842, 0.02972081386213822, 0.026469938907652136, 0.014917711265415195, 0.08210367297813778, 0.004729686075851562, 0.02327910417901172, 0.011406829899867937, 0.026948552338346362, 0.027341971046201168, 0.044858496741301594, 0.015511254164119883, 0.03485404728581348, 0.036012973606346116, 0.020892123594098998, 0.033494394437800494, 0.04950653986945268, 0.02369840708260815, 0.08053860131410823, 0.05621440190401289, 0.020495426029928272, 0.05725137851831894, 0.11837115631468835, 0.034757907081755905, 0.017835957546448036, 0.044061864891480056, 0.051699056695666046, 0.02765334173736553, 0.02994708176101408, 0.02875848868561368, 0.021774691356826695, 0.03531367705774403, 0.010231244997421821, 0.019330907267548384, 0.11125010092772784, 0.017798808027779865, 0.03374850197184471, 0.07089374586939812, 0.06108980460633194, 0.0016913090686073468, 0.048801375087350614, 0.048978827863691315, 0.016077749371047945, 0.037093835567394574, 0.06804117917894356, 0.026468630812521425, 0.023603509856207718, 0.04793682188216237, 0.026402143956792933, 0.02766684978269041, 0.0178639063491456, 0.032130491717027566, 0.08287133138266303, 0.06020585405490091, 0.023888523292337215, 0.03764328148756777, 0.07452515584807243, 0.017478451125263687, 0.03504956441540872, 0.03291535454111234, 0.04475548855900284, 0.03896988147208768, 0.03308650241383622, 0.011240898128298503, 0.05337040390699141, 0.015934647977231972, 0.017162420704299887, 0.05942989508771609, 0.03387470346605105, 0.03980372604283114, 0.0222714131908311, 0.020845160489120794, 0.010828969778583176, 0.04221579600726405, 0.038032404357387174, 0.04243850925817125, 0.06266781166496296, 0.031836901926585746, 0.048362280302230394, 0.05906869229229708, 0.06773893451017719, 0.03553186655945836, 0.03629374100015529, 0.02584086389340941, 0.030580734150604378, 0.04558571336430408, 0.06943509147893037, 0.022883860266677315, 0.025278555356987545, 0.006936008764070369, 0.031116934410566767, 0.029062635167652083, 0.013430590005291086, 0.021257202794414856, 0.0823851106988807, 0.06275464007030092, 0.03670803368872693, 0.0681930790925699, 0.029374752794542623, 0.06021962065490023, 0.013434022079191863, 0.06452323448273443, 0.08244447485213319, 0.04936401304157992, 0.0484554365938229, 0.033399238656725616, 0.09202861782884406, 0.027266666518464207, 0.04263359737852889, 0.019070033261912967, 0.060887339059263475, 0.008639479957280621, 0.04914688457164073, 0.0397227160752781, 0.014135495275108805, 0.04759789309314182, 0.0406308596833579, 0.008986503422831096, 0.04315503129375078, 0.03942025690189293, 0.05300072434869024, 0.05569450782551881, 0.029245423746385404, 0.03322107724905495, 0.041201962909150514, 0.070091353038386, 0.03506547223115641, 0.0451124778708383, 0.04678967799390516, 0.07606338379123519, 0.038941888619334473, 0.04573395520809197, 0.05399695274630382, 0.07978454097023896, 0.10609404574478827, 0.040670604324869575, 0.01807263658021487, 0.07227338595135559, 0.055282210795989925, 0.023780296136054303, 0.026072381409786405, 0.05478449496290377, 0.025718178742775516, 0.04669891955751566, 0.02028270831121312, 0.006599710050654868, 0.029314362083471594, 0.041905848324419036, 0.0058661301098313304, 0.028704320523707617, 0.01984007228466292, 0.03644039704193992, 0.03832441409148517, 0.04245683791175966, 0.07850030181749214, 0.043080575208389954, 0.037314204589253476, 0.04438285573175357, 0.05075432855876223, 0.07645336850996941, 0.04209506821127669, 0.0404813461336157, 0.04256055089494875, 0.060969662867606654, 0.03408262738958001, 0.062476136466307994, 0.013665168042925578, 0.03772526821722427, 0.03141523755696272, 0.04441691217042747, 0.03878593227014907, 0.040847390604716156, 0.0061212680321337, 0.023197492832438122, 0.030482826198661522, 0.09881512261927129, 0.04461199262990587, 0.053950899370735696, 0.05075566921262972, 0.020917980976763274, 0.09637360806546866, 0.030722738123468818, 0.06582143175746165, 0.027021144914831367, 0.041167136552112724, 0.02391850222803412, 0.028057213714947144, 0.007961701382056721, 0.08125182917161335, 0.010382183470703181, 0.05274724117630432, 0.08548806556650708, 0.04338385792629373, 0.04261494696801228, 0.04057886529593699, 0.047126538345530156, 0.008775032512212714, 0.016062868113118797, 0.11525892412229893, 0.007480877787700945, 0.034487286522503824, 0.019758269416108247, 0.04254304578587894, 0.028510484957106175, 0.0569356813456022, 0.06940392702217064, 0.040255078234739845, 0.04612217409416072, 0.021738319417401668, 0.04419639376142333, 0.022119566903359467, 0.02391540340238041, 0.010029180688903698, 0.042992540214571266, 0.03817027337068031, 0.00831437043680419, 0.04575105812100153, 0.017346159232059316, 0.038684218776442354, 0.004940651368439919, 0.1104829251585949, 0.04569314570436555, 0.05127118509863654, 0.0361119062008877, 0.08437883920006214, 0.16802614104122887, 0.17079283693625083, 0.15764915834992163, 0.1413773282641365, 0.13279057047780485, 0.17366819474245274, 0.1903244937139173, 0.12822733711331122, 0.13311658685486163, 0.13452626524433015, 0.12174382009693693, 0.17738485498534096, 0.1374332931253218, 0.1143808264826094, 0.12970415544846367, 0.12021601094954437, 0.17459390474663627, 0.17411105484972078, 0.15595593549791845, 0.1505661085848847, 0.13097172452797815, 0.2548268599615943, 0.18187397700403968, 0.08926960579570263, 0.1099867759753139, 0.1043337825385313, 0.22310521213277695, 0.12601007181670398, 0.1956076811878912, 0.15439887711357686, 0.1190529975499357, 0.11907079377241674, 0.13477591797709465, 0.1604790871422137, 0.1103457800983902, 0.1543948934563706, 0.15968090013390587, 0.2553942706435919, 0.07564235718980913, 0.14394214466935204, 0.1593252821194549, 0.1048004909628822, 0.16651903158955036, 0.078567786502742, 0.09109191446294708, 0.20223071047615623, 0.17582333796928007, 0.1655485360853134, 0.1499834987184694, 0.19219249186496581, 0.11787892950157966, 0.08427265941375688, 0.16024330060087866, 0.12442612374622015, 0.10057565395630176, 0.19126460617107732, 0.13979531073522183, 0.2101190871889553, 0.1459554696996366, 0.14033462131215682, 0.1000534731053537, 0.1727787513406046, 0.133409017937318, 0.16986490527708686, 0.15691939831501053, 0.09674268624474926, 0.214865890541865, 0.17991743441070282, 0.13496950839556035, 0.17201703011749253, 0.07981332289355417, 0.14711318177080926, 0.10366825131519188, 0.17243473189732722, 0.0862205298917909, 0.11955139137083486, 0.18463812948715302, 0.1352886606248156, 0.14709884060486672, 0.2016395970337814, 0.15919699303565488, 0.12608927764719532, 0.23728493270614456, 0.16185351016540683, 0.1838339057060019, 0.1793336600906426, 0.18732158226832268, 0.18258162774145606, 0.10110403245855724, 0.20186133352258515, 0.12641085837517055, 0.07615346807025133, 0.11773046932273334, 0.18392997313170664, 0.11896953227058535, 0.12794534014838357, 0.1796583894399866, 0.14764700715820636, 0.16553825518536955, 0.22743540155070446, 0.18671379875271552, 0.21538122256676998, 0.12733467614218114, 0.07993573608297495, 0.2402471189176844, 0.1299417499573, 0.1452013480687334, 0.11568767289000174, 0.17913600940617824, 0.12774073338556674, 0.1738622294919145, 0.12493935669021261, 0.1720164325689116, 0.13620268012727463, 0.11191174808529117, 0.14895925448546488, 0.26777521677074895, 0.0881260357076122, 0.1489558224115641, 0.0981953804711661, 0.1554740815153045, 0.17300206597053236, 0.17332700982449517, 0.09256866385018633, 0.13169633645203807, 0.1249612438222093, 0.21466888337125703, 0.15374486785261862, 0.11949902160033105, 0.08425018239405849, 0.08708585684578266, 0.16788271406004507, 0.13657233287249843, 0.20949126281324895, 0.09480506602314212, 0.16687848004362277, 0.16266275948334127, 0.1319324447503013, 0.11859912875919573, 0.17556211730885893, 0.09675192526511608, 0.09030461356404329, 0.12579690019089368, 0.17926282760116363, 0.12622097582225839, 0.13532906410194215, 0.11571983326106303, 0.08132751099765301, 0.09473303077562202, 0.29627779378525676, 0.08842882429880482, 0.1724315602933207, 0.10791926554614499, 0.1669029182484073, 0.12492778110167674, 0.11467049198765909, 0.13294279214835938, 0.13469350223820056, 0.224712893607155, 0.12390915995403645, 0.16308536422589134, 0.11133200338771267, 0.14518794153005848, 0.14920339138517458, 0.11987798231383485, 0.12173321744006489, 0.07548930048341713, 0.3006394694168722, 0.18426018767058852, 0.14043124032116708, 0.21095450607038316, 0.20960784607356597, 0.1475086670008398, 0.17634706631783517, 0.13661799171278555, 0.13841065277736034], [0.0541004856988307, 0.011394018036944252, 0.027766427806308194, 0.025120113052487857, 0.012869470820371664, 0.02889377215216237, 0.037063057985036604, 0.024789122849582665, 0.02816615716343926, 0.019096415414805376, 0.029833168317113194, 0.07913194131106138, 0.05602431250736118, 0.09368660063633034, 0.0603994827777628, 0.0373768859032181, 0.027192470902997642, 0.06808231043959818, 0.045309021558252074, 0.01869671095553185, 0.022769303308920037, 0.08680576743978648, 0.045835358436189355, 0.03847337605792188, 0.10118937465332209, 0.02443361017222126, 0.06460415635017619, 0.016623269090609207, 0.02809409893328144, 0.02205046385736956, 0.11793777271504365, 0.04871953774483935, 0.031296785042110475, 0.02570549041152962, 0.08855799438371774, 0.058859228532040314, 0.06766145237751546, 0.05287105630662653, 0.024583072011028568, 0.10589937514234936, 0.031871178615537864, 0.033570984078030434, 0.037379896628760526, 0.054370052887186895, 0.024774779768420324, 0.04711964738465125, 0.03951411799437577, 0.032964230950681433, 0.06312834925108379, 0.010413979950000443, 0.020583328873580022, 0.023990372766650492, 0.0224634867552067, 0.03280584227233645, 0.05205002455641666, 0.027331393287186662, 0.07211794671151908, 0.09293113835155965, 0.03454654342344692, 0.07442890456126583, 0.0580713875411499, 0.07000631727879086, 0.038250291254371405, 0.025757258803012873, 0.039132824543142514, 0.05767715103443592, 0.07375712972134352, 0.027280971295230334, 0.030817047377387365, 0.044631470415380695, 0.019054180987539793, 0.07204534455893502, 0.013656889505293823, 0.0434821087025827, 0.03948512156644175, 0.0862169522611845, 0.12886642298150447, 0.00532485403856563, 0.028027600586234082, 0.008786152278433644, 0.03981724749469469, 0.039168941758332715, 0.033164053494411136, 0.033049033053459666, 0.02668248234136451, 0.052239834330976016, 0.026506104003337604, 0.023352213864845615, 0.01734593323612165, 0.06984569162370698, 0.04121555330892725, 0.06268854200419399, 0.047552264896371675, 0.01172732565582039, 0.01299632061648393, 0.03727444462598332, 0.08151670407143333, 0.012906137703647538, 0.040632307589534795, 0.0033288665356174594, 0.023341465651267962, 0.0895235256382054, 0.02149855879495942, 0.087875762443629, 0.015070307361442718, 0.02077501364833405, 0.01004628168659345, 0.06397269688726914, 0.015006642582105293, 0.04506595718163637, 0.011446142659312295, 0.07552124634985963, 0.01598052515257751, 0.03220006973753053, 0.08170147681789053, 0.05867175915608964, 0.02461642939447155, 0.10809508272476735, 0.03356439572188162, 0.03076312053317745, 0.02275366936960528, 0.02212722586738246, 0.009572093371271847, 0.03229031106457114, 0.050429131895784414, 0.045711275175093644, 0.02872677264554847, 0.028358922122166525, 0.03611367203355317, 0.039114063049876885, 0.02931864259974851, 0.06712109226012422, 0.0243255534705015, 0.03436845479412906, 0.028485964397869767, 0.07256673633932106, 0.009799450072610091, 0.009361101265606141, 0.012077188434740229, 0.05145818333051378, 0.014711282170948484, 0.09198361016329258, 0.039876197960468075, 0.0572630039025699, 0.029620699576973438, 0.04898375380904444, 0.0499166956832332, 0.01347291253266796, 0.07094418509833275, 0.004318581270654836, 0.02795373055813534, 0.05521085353628282, 0.04004048934626964, 0.027300809142029574, 0.032976112974387024, 0.02682416455730075, 0.06727599523841374, 0.04357765135805934, 0.05702371250898127, 0.02142424060542497, 0.01973697025659344, 0.03862023511300645, 0.011913530986696001, 0.020009931214454196, 0.09645056159746263, 0.03379961152771308, 0.038729291559467395, 0.06133304518317023, 0.11128006262644646, 0.04530445184378375, 0.06261590920809297, 0.018707537693121744, 0.007939212871039467, 0.024045082935762983, 0.02490019219206466, 0.016718422956464273, 0.030806092320070155, 0.10676793498738159, 0.08871265987475073, 0.04694122167664671, 0.02746121454683523, 0.024068665037292148, 0.03891366594020398, 0.0324723718597764, 0.011931161542663412, 0.029574176972551696, 0.01793096585559749, 0.022503239057597615, 0.0133721039803218, 0.015952008487206074, 0.05708914407859406, 0.05942373957124449, 0.03657743868027483, 0.05686366908071984, 0.05197081106504606, 0.009956631204864431, 0.041011176372487704, 0.01123980741061631, 0.06423225130645499, 0.033730192470454404, 0.028735822059154034, 0.03695669050718989, 0.06021475216614143, 0.035736009839081, 0.019709339380384456, 0.03384130203255242, 0.11768423591650302, 0.049387842206464666, 0.053045103822143815, 0.01115201086166405, 0.018740895076564724, 0.050964018314956665, 0.04770466276714879, 0.051160722880834536, 0.0297329448644192, 0.05293269574101414, 0.024528380994114186, 0.017473029137979594, 0.06229301080888799, 0.031061209174954606, 0.031545723397885604, 0.0189346463734945, 0.02107710318429576, 0.03331191612467651, 0.03602215900055824, 0.020690789941938657, 0.0982353625999343, 0.032781116784580296, 0.018659502065049547, 0.02329903970202131, 0.02901578889108233, 0.07033948891706045, 0.09050802522969824, 0.04344017688004721, 0.059333467600686904, 0.03580239901859914, 0.02241205352719032, 0.019914476659088846, 0.06904195047794812, 0.010363051382404183, 0.04920029622172156, 0.05072693708502958, 0.06457290762374479, 0.03901704567514601, 0.023006997409186537, 0.03484092803011018, 0.033203533835588925, 0.013162847063804587, 0.0032935417426239342, 0.016152213117288008, 0.06275723710836423, 0.09200735122806604, 0.008412762939359152, 0.01129859125226616, 0.044037913152527426, 0.054714206395851034, 0.0749316344398164, 0.029886085840482867, 0.03935415117490677, 0.049599113934222734, 0.0326580562508635, 0.02685246001478405, 0.022793040543253866, 0.05081582626688385, 0.06235050953804486, 0.11896908793958927, 0.06972559968069678, 0.028297186926788384, 0.05931969717024796, 0.030714491186963937, 0.02485924287729206, 0.030226016289464412, 0.044375125904597586, 0.027601422043517235, 0.06803729511316746, 0.05821899353196064, 0.016008312119201066, 0.03043176643850823, 0.012128906072898498, 0.02258532920912389, 0.036687598293346745, 0.048966746657125415, 0.06135505871967443, 0.03638274126475857, 0.020714303095554634, 0.10080274539969622, 0.008723841559502387, 0.0606956638606085, 0.07098444301875369, 0.03853742866927097, 0.03363981707802704, 0.02624756465065143, 0.04808439339901652, 0.05723028045688426, 0.029291731846188346, 0.040757513169439576, 0.03436081689752398, 0.009133464942175535, 0.05521667580450735, 0.06623346448665665, 0.0498818310217992, 0.06615844915711111, 0.04047074347674366, 0.05100796494873301, 0.03379122286494221, 0.025329643845437996, 0.03433843180837651, 0.05677712412791387, 0.029409360816521995, 0.008308113413682629, 0.030300165939655517, 0.03970621071094948, 0.012386728175765565, 0.027686532496684985, 0.06259898632584561, 0.035210940836658405, 0.030202280970350392, 0.051822477290707256, 0.06701482820414728, 0.04806359028143268, 0.01888657627146571, 0.03805704557547166, 0.0797267243145935, 0.036948983662671624, 0.012845163808144149, 0.07041042099796957, 0.01997099288048283, 0.04448283020587218, 0.056483528591812625, 0.05371271880463727, 0.025619138895924536, 0.03551384817147928, 0.015051881989253866, 0.01870157561385103, 0.04135250301671125, 0.03949799184356967, 0.007159754318455535, 0.009538512864720919, 0.032778117550356735, 0.025293448106235555, 0.02692134855615516, 0.06527996847345945, 0.04466053962166752, 0.0036695132768082045, 0.011075596464046789, 0.02751313041024391, 0.05513182773645367, 0.07574164984567512, 0.019543439209941896, 0.04234808023958918, 0.10981617585545587, 0.003998977528329218, 0.11923256855938705, 0.2066023452507873, 0.2512816348744016, 0.14810635347760495, 0.05064883825158881, 0.2565571767908912, 0.1396004179672849, 0.1351420160743498, 0.18185317005601623, 0.09555790062633254, 0.08811093611462463, 0.14942914217470155, 0.09716451723849583, 0.30148817226290703, 0.15900485818424534, 0.12773150968695843, 0.08822815522791878, 0.1801952332138054, 0.1591573403246941, 0.12630631801702324, 0.14307215990078065, 0.17802358845308905, 0.15524692112399688, 0.19856825861479008, 0.16014308097862429, 0.14803818697410245, 0.20081931604973732, 0.14645537271374656, 0.11528258857827996, 0.19957932613549695, 0.33059451849229876, 0.17164627420565776, 0.12541669841495254, 0.09463443525976713, 0.22172257664703557, 0.17941040677889702, 0.1240095557765134, 0.10965961046637067, 0.1493591370601808, 0.23024058570304226, 0.18973266014889364, 0.09376561494484063, 0.15720026146981025, 0.20785307571772607, 0.08473298632569852, 0.11723642688124411, 0.09792145807296039, 0.20648259038646377, 0.14968561308999218, 0.06472581877343117, 0.12544048544500144, 0.09554537508877055, 0.1417056582267246, 0.19799389185444002, 0.15910020548730128, 0.158349898974261, 0.12815657357174542, 0.15980071628526335, 0.10576897165587834, 0.18687362001547891, 0.13890358439135936, 0.19519506623187374, 0.1359822000226667, 0.10726199275062931, 0.20326186482223774, 0.10407116759808795, 0.13300916600611903, 0.11674911069173007, 0.12806524823029197, 0.23020585127655538, 0.15371545007632625, 0.1522973140761737, 0.08037050630176261, 0.1708114835163278, 0.2095761759987762, 0.20554235535523585, 0.22621767415154367, 0.11655930474761034, 0.12329272730576417, 0.12795071808561204, 0.09729685126653603, 0.18427235314682608, 0.09774243864681452, 0.16621369958644913, 0.11891571459390464, 0.1733156870449743, 0.12158424398230931, 0.13525726634167856, 0.1273118160785206, 0.17563149423128174, 0.2619919883868387, 0.11021634954358302, 0.16401948587548348, 0.11867736165802326, 0.09731126904127099, 0.14040039762133552, 0.26336294869261406, 0.1903030892173129, 0.180188752109966, 0.13001282759491475, 0.12976994707940087, 0.2678985569265581, 0.06390476404058357, 0.15443810081530004, 0.10714762348441348, 0.07330724458780981, 0.1680865700566961, 0.12075746657266734, 0.12861177535547366, 0.18465800180790887, 0.10844397448724317, 0.18043227613933627, 0.16659620728704239, 0.2190722341859533, 0.14069086751870571, 0.12938241384202434, 0.17012365913439184, 0.13765886005374695, 0.12212072003392443, 0.1206505436810755, 0.15388904559996822, 0.09296737431037812, 0.09760957601810656, 0.10691537626928861, 0.12177328383850476, 0.17380394552263523, 0.09636628426491253, 0.13694400808984233, 0.09151771379214141, 0.14451122542302455, 0.09042147261601302, 0.13566983533242058, 0.11284455972453279, 0.2041700926999892, 0.21439324493610093, 0.18491154626732875, 0.09505151650838314, 0.10244115466071714, 0.08019003896943985, 0.09565556917579905, 0.123032579168437, 0.17159850096269963, 0.15207239066160497, 0.19825638422081548, 0.10442001339528831, 0.15015390731634634, 0.2503359912624282, 0.2556973656699542, 0.18257664816994823, 0.1296373372597079, 0.09872400412155737, 0.10354803679811378, 0.1521711547168032, 0.1882322309839149, 0.15133904533520823, 0.11189870160794067, 0.1027046122978772, 0.12511905027373185, 0.18941091854245434, 0.10661184457280945, 0.08446077230356394, 0.09357596221830576, 0.10580435725710086, 0.10125737261748123, 0.20713401027023795, 0.12264186666617471, 0.14031378372061637, 0.15841985812350629, 0.16481178932853285, 0.07488213749902864, 0.14373916201293468, 0.1250428398470244, 0.10285137176153161, 0.121031986519454, 0.10996776933391249, 0.09697569188691917], [0.010415808027309757, 0.0664409364183103, 0.03457421068883231, 0.0493495837755261, 0.0823266581902581, 0.030264496885901018, 0.049690316701608325, 0.008489270225137232, 0.041241362811096256, 0.014738690881659428, 0.08625457483914592, 0.01305617985405749, 0.03113492023980906, 0.007142702158870957, 0.028397603816683256, 0.007116961125810181, 0.06829450913374463, 0.058952890441662846, 0.0461558704715102, 0.014096866249136869, 0.005358650007345264, 0.03809978179032764, 0.06227820615975126, 0.04641671957928808, 0.03559263265361229, 0.02764575938213497, 0.044896027388712095, 0.03313670415551432, 0.030479442005256013, 0.046640378948781765, 0.034687518923273014, 0.05216322936898759, 0.08515886992456452, 0.004276439731550073, 0.020925059629183625, 0.04091195649497452, 0.01723642288256557, 0.06883211899548769, 0.038499606908449245, 0.10564095836373107, 0.0933509468731861, 0.00565367333981539, 0.06206529117339562, 0.02332002476548716, 0.028015728138627547, 0.044215844733820814, 0.02787952728178953, 0.03349388498933085, 0.036362623795866966, 0.016291062723124222, 0.017571063494429957, 0.02046289602144351, 0.0522647092058774, 0.0272378865103688, 0.009572783808013605, 0.02687527411316912, 0.030734367338159395, 0.019652610569591486, 0.0538033201930023, 0.05855789167746421, 0.045700235848104766, 0.01869564800853691, 0.022953189308604887, 0.044708833804414164, 0.06921546939279764, 0.015461141480162982, 0.021684425131928538, 0.013245025315442154, 0.05559803820365379, 0.02718749707714925, 0.1042068187868403, 0.043895903434003555, 0.046921016107643806, 0.04753275646737987, 0.058907438445115284, 0.011278934393739028, 0.013674728820220599, 0.02236241486013657, 0.013597521521601708, 0.04877950710755202, 0.10646989614131952, 0.040195648964013786, 0.08548669426912263, 0.04470059452878852, 0.037370339681905125, 0.012389242859377016, 0.022388856384843107, 0.013508555730955015, 0.050460242726389444, 0.028438449709586082, 0.01078518306566102, 0.03877351015445687, 0.028126732363635977, 0.06534976674424064, 0.007187471379556003, 0.018821767148291393, 0.026372898550283526, 0.08651374238393, 0.1050441069228034, 0.07843034266824685, 0.03293870490104441, 0.07073058446328487, 0.031676098156059464, 0.029433550042731148, 0.0046726063010282815, 0.005409480419926225, 0.060369417657174414, 0.07831257963252646, 0.056732905532924406, 0.08680778991190657, 0.032834899987304406, 0.06533609973567148, 0.023092929491653078, 0.049827051904773524, 0.06627786694274795, 0.02176566875629848, 0.06305803387095371, 0.019325272690865303, 0.03739801460816976, 0.07360155258568064, 0.05039869905299237, 0.052080518686242645, 0.03669727015339079, 0.01632990338088524, 0.024215581548971035, 0.06657974388931068, 0.019482113871603243, 0.037386787589639425, 0.03153785567490324, 0.041096549210769516, 0.026529869965968594, 0.020617911997701854, 0.08522716666301412, 0.07777515363188521, 0.051899377196546526, 0.008871256985941963, 0.07048885307965741, 0.007678133936884303, 0.05277085583657027, 0.028748885773482825, 0.10688701569433175, 0.007555508158064538, 0.027717262198547685, 0.06861718536745157, 0.04153357172805456, 0.03708781028587011, 0.04086137170933428, 0.11591022143200522, 0.0035637572328860484, 0.05680941856436192, 0.0409194526653136, 0.04625229412809976, 0.0846390026591478, 0.031695740650438016, 0.0022093611844484847, 0.016324180704090866, 0.013132679478956327, 0.05889130463342994, 0.017183683474638292, 0.02292959188531724, 0.018410590522351767, 0.03827990438308447, 0.06379345529562523, 0.025121495841191183, 0.05457994948712088, 0.03308804991144327, 0.02606893592934695, 0.03143791567474123, 0.04160679058141766, 0.0444041031803335, 0.01855769089513248, 0.03419245758484449, 0.09552398591392464, 0.04731642089844231, 0.07859241622950762, 0.031075875928264954, 0.06751483847056666, 0.06382663456362582, 0.07399364404620663, 0.06010939975479438, 0.04397213301290909, 0.06219505880688948, 0.08432977892939122, 0.06527311964741637, 0.042261699995686935, 0.018302010965623686, 0.08859481256935867, 0.034504592448713324, 0.04121238936579997, 0.025215851060385187, 0.02329028140182697, 0.04308543603626951, 0.04616707833784242, 0.0879409412042268, 0.0102234739930399, 0.025031262175029805, 0.09126851305125222, 0.046040551256268256, 0.060431168174311045, 0.02811600713269605, 0.08370023085585526, 0.049428291648866675, 0.06049363115321725, 0.04108048817743698, 0.04601976729088253, 0.014042115860408353, 0.04677766956569207, 0.03679246423886188, 0.10205587372183801, 0.012295199821012156, 0.08204409432026648, 0.0682911230251193, 0.033862384772228624, 0.0488684882199572, 0.036973414206576925, 0.02785403379088929, 0.02061971230432391, 0.03549191124376751, 0.03616088603232657, 0.039607159372779636, 0.04605940084964518, 0.03220722882918293, 0.053077827267829454, 0.011432141444886164, 0.03468710906623352, 0.052333542205874, 0.03857825349475588, 0.1064650085003626, 0.02207146998825333, 0.06009759433988122, 0.03508588081345924, 0.015013828486835044, 0.05447680340899576, 0.0499590220410497, 0.13786176610137188, 0.11848574774640223, 0.0788668136022264, 0.08302127011120321, 0.012033344265223752, 0.017010612721224467, 0.04664299513904318, 0.04427207175702338, 0.011060714248507734, 0.05456648932229127, 0.0246346756936081, 0.05530048582342364, 0.039608013560815204, 0.025644285732039043, 0.06458559403977086, 0.05471580751961278, 0.06641806869377052, 0.032856342788305015, 0.05347772133386424, 0.034173236438824285, 0.07114273976654777, 0.04151328188937999, 0.06645261925915558, 0.006940815008185323, 0.0515092469211067, 0.07849217362461552, 0.0128937462314723, 0.013249997226070735, 0.017425863019701456, 0.040759451371888, 0.0527322756487035, 0.03125261624283608, 0.024541954156912626, 0.020125041670736768, 0.047904868354840625, 0.04858707348185201, 0.009413387724048188, 0.0199446605233055, 0.006237755052655215, 0.08816360465941891, 0.011956249964573692, 0.10156590686810595, 0.048915989501702214, 0.0598614362459029, 0.04898697903920566, 0.0653519424339456, 0.019607051320734526, 0.009377918810763908, 0.01095181197724155, 0.09680522966288752, 0.020792036122011564, 0.03366663015537685, 0.039176775007358486, 0.010784484968040018, 0.01871050628382833, 0.051722119772626515, 0.031041210449691263, 0.012534462486303622, 0.06760692223906517, 0.0289329728712478, 0.030705685006274335, 0.10759868839335059, 0.06477910784944411, 0.040065927295795375, 0.04359979512951067, 0.03430366290793304, 0.07617691036073432, 0.023067108498165206, 0.022278110714509122, 0.03867709032830693, 0.034042802308836294, 0.03131083126420216, 0.035701934248209, 0.07375560520637421, 0.011621268443583, 0.03483303349405047, 0.05635781739387782, 0.07245170057661111, 0.05305798559059059, 0.08464684739949242, 0.047154132832562735, 0.03267228250361739, 0.13956508599221706, 0.03418473158812812, 0.08251668629987587, 0.029240484394493605, 0.054129558735557144, 0.015164523727200447, 0.03150878646861642, 0.06493427895850713, 0.0160406046404293, 0.026848401664005175, 0.044852789386265704, 0.03834520188731052, 0.07970698988966404, 0.023011607343270894, 0.04515483487217177, 0.022319489038519325, 0.028733309290762392, 0.015270859603920292, 0.009351098072534848, 0.03652547110593127, 0.09992768146818685, 0.04370468788810315, 0.06942518596206942, 0.017958903166976188, 0.025500839598657146, 0.04482606057858756, 0.053661747144595276, 0.05684488460481648, 0.02314521882292484, 0.05313829458769291, 0.027858961651462223, 0.043133435275165305, 0.06239202384266162, 0.029675183750148264, 0.015087501247293286, 0.030170463423635212, 0.1205930564432375, 0.15221741110567125, 0.1710220044779201, 0.09539543636023037, 0.20853864780116468, 0.1514887848808881, 0.18453951864953966, 0.28625478968024254, 0.1433078391898063, 0.08617232763959516, 0.26641801540409366, 0.11393757567049996, 0.13418501903933866, 0.06934198115261332, 0.15371462270136804, 0.2288509022083975, 0.2430246779394727, 0.11701049223061531, 0.07668943084295719, 0.144576235644279, 0.13073408405386633, 0.08338860161001645, 0.13482598948382563, 0.19182852349214016, 0.13415434487885045, 0.16420823461826772, 0.17740330238255764, 0.1286838029421145, 0.1538170639786028, 0.10592627248937085, 0.19415033680777397, 0.11983416974544527, 0.2315178840991951, 0.11766368943837383, 0.15210462764145868, 0.15445838682353497, 0.1284924495003877, 0.22420989559783092, 0.12097099825980202, 0.17418873616524283, 0.18650238912913109, 0.10107486749127989, 0.10187975776892516, 0.19920319228643374, 0.08264201828428815, 0.1356142326708763, 0.16321687087897332, 0.11092544818717627, 0.07142687411678415, 0.14756344228742585, 0.17847703589547068, 0.16496448597360044, 0.13077355290372528, 0.2099916561236305, 0.07684725261623822, 0.07555624890712, 0.16195939883830088, 0.16213647240111906, 0.22673841475719408, 0.2725625002095776, 0.20947306056416806, 0.13118489615378842, 0.0773206872925643, 0.11576364582945263, 0.15412325400017923, 0.10744677315796576, 0.13735541262693945, 0.17916380307607113, 0.126537615283122, 0.14375558693803128, 0.22082789320378537, 0.1426031149082607, 0.1986936365644778, 0.18675473849138907, 0.14991597572882331, 0.08481084384144315, 0.18419444200492677, 0.10512430100671707, 0.16283410270848583, 0.17090577361804826, 0.18067075931016477, 0.17446831229232973, 0.2587534282957354, 0.27415721947627686, 0.1356724553531216, 0.12346340403441461, 0.07640279904608765, 0.1436285389166686, 0.12179091918252169, 0.14246439170693198, 0.18241460525220443, 0.09073405181087794, 0.18342303743045177, 0.18131539165492983, 0.09656024240558186, 0.18400750122964385, 0.09347463176856119, 0.20853334647272864, 0.17720235752001887, 0.16936216773765703, 0.2607203130760501, 0.22721807772834457, 0.13344245001433358, 0.14063154166984942, 0.06686701920003661, 0.1198794225591325, 0.1039345128341548, 0.17428455844281182, 0.15674828491624326, 0.16447395987568364, 0.1566254963437396, 0.13108058562201838, 0.08485643373381707, 0.16079453150591544, 0.10540662738945215, 0.09324986923245654, 0.15912626779848532, 0.10928168397156462, 0.09343852604468984, 0.16632602339790714, 0.215975844691838, 0.10502015135341114, 0.18547517247498038, 0.15152385638606164, 0.1008456233408182, 0.15973242720769298, 0.09971847051694509, 0.07508896591682589, 0.20485584864452963, 0.09630805392178798, 0.11189919190421221, 0.2112186072213996, 0.13618156674408144, 0.13107965099475077, 0.1668006148669989, 0.13704761382072203, 0.22256646846090594, 0.16636506323852848, 0.1009884068081456, 0.1107971131381008, 0.1611733926279891, 0.07907223241824297, 0.16706670784661848, 0.1638646901495034, 0.19800159869895828, 0.1562794544283421, 0.08154709477938953, 0.21890303600699673, 0.10088563611310336, 0.11129195231103128, 0.09453272176606041, 0.12789094790575967, 0.3070563750882303, 0.09774158828921857, 0.12810018183963914, 0.09807191774128907, 0.17660626450613623, 0.17142133546933053, 0.07551316412225847, 0.1208347954877442, 0.1163320217822348, 0.16429638069483543, 0.1503224926249635, 0.14086521380851347, 0.12319305926681527, 0.15165925476579897, 0.10434503637013898, 0.122110799195305, 0.09637864892401042, 0.0912603848583756, 0.09335306127585712, 0.14576256876030277, 0.22416190785025397, 0.24390578630470464, 0.20468050644042032, 0.11673466227347813], [0.14102273680750402, 0.020428548469358397, 0.03094382726797654, 0.04587710639762302, 0.03229480033980743, 0.04165577807373578, 0.027704675373951757, 0.0166063193952845, 0.013336681032312975, 0.06264407826106876, 0.03797465281921529, 0.03850187452870511, 0.02533749241622225, 0.03524995769464201, 0.047045830982707204, 0.058121114308314945, 0.01788928684207701, 0.04745157796048349, 0.036255317860313004, 0.021170276712866563, 0.038470537702162425, 0.042083756923074686, 0.03981538973147831, 0.026817566625052885, 0.047783179118508295, 0.05673650614616852, 0.06673761162786715, 0.03767164589296426, 0.02859790516536563, 0.0452648910633739, 0.06460805573771078, 0.008301858305780879, 0.028379361347986326, 0.012847660297167399, 0.07167392215060611, 0.04557159436385959, 0.013103396725660611, 0.10051946906793503, 0.01833428624987362, 0.013223384289191136, 0.042255942844935966, 0.010518054909733756, 0.03550407288956546, 0.04521088569515175, 0.011763298271914885, 0.06880533656165486, 0.03807636248248239, 0.026332738306072932, 0.029006017439608133, 0.031061555829740344, 0.07829306737309502, 0.03499908305163826, 0.03164615752475877, 0.045686224099969676, 0.019659819456958966, 0.027373049318069415, 0.072229826191981, 0.11144088746439065, 0.04911242593680659, 0.049228392496344545, 0.03363772948843337, 0.06300336583667705, 0.04429049617160232, 0.047605431398316744, 0.017129283571135134, 0.029113319544722478, 0.015411196377939515, 0.08607661261433557, 0.022086998590478496, 0.046138235127493266, 0.027645045005145575, 0.02122039035443337, 0.05945964994269514, 0.02034721291443754, 0.06414614685420549, 0.061621588369410854, 0.015448468470675571, 0.02042041453082235, 0.06520711351186037, 0.03238363589550699, 0.028748699997161186, 0.0724390984302567, 0.05789257112830397, 0.02652802177885127, 0.0048710350435407414, 0.0036554538875803234, 0.0211250928470925, 0.05000531290387435, 0.033395599739085284, 0.02796624077393884, 0.0729330106367988, 0.04834567534647161, 0.05507670387986207, 0.02299984597841338, 0.11607357436009955, 0.07436374112242654, 0.0724300432709917, 0.07807210463309482, 0.0563260822016145, 0.07405120789283708, 0.06897336262608729, 0.021035671234130863, 0.0038065211593939535, 0.034134043380618095, 0.022089787150522875, 0.02651341439735505, 0.02896539179698354, 0.022248560788049813, 0.05493955498921776, 0.027521641647082665, 0.02935390371168333, 0.010103348533683007, 0.047642004435821894, 0.03206148060158857, 0.07807647899514245, 0.03592344091063546, 0.03518519262152334, 0.06283566919005205, 0.06438179166927453, 0.010607179663624736, 0.04648637612380328, 0.03249947222009782, 0.030884210305709033, 0.020660173238044786, 0.044558508201472224, 0.013718120040251844, 0.04892902448773385, 0.03036643062988597, 0.13183458467885373, 0.06534720034969431, 0.028662578307933388, 0.041424917477753856, 0.03048871741479924, 0.03423261208339565, 0.04941379343489966, 0.02228582521990663, 0.13232497288094414, 0.0026213433997209876, 0.04904124104688245, 0.029478576860480735, 0.028075969462553342, 0.04614532144079286, 0.06832490750258008, 0.03246505955053914, 0.04101340568834736, 0.07182595996005882, 0.01499632242015533, 0.04562360407303899, 0.015471165740652191, 0.03666470758616924, 0.13429138268674576, 0.05348040647203884, 0.0293845204155772, 0.07271368732495655, 0.09420995360180255, 0.0735132226480111, 0.06127283450276141, 0.027879236168378306, 0.056284054618088476, 0.031109811708090768, 0.017838703971656582, 0.04338706017381722, 0.02148607156179365, 0.04545179736470023, 0.048152847185490594, 0.09209850036929693, 0.04383057911670016, 0.029783889711383852, 0.006168508843984456, 0.036795766077815525, 0.020127305460553017, 0.03232632868833119, 0.016940841263520624, 0.04590278949528452, 0.004383794505209212, 0.08052555483675773, 0.008737185853533447, 0.0847690077798982, 0.042878075187364896, 0.030993306971786004, 0.018845012171133872, 0.0646021185562976, 0.03970677378557382, 0.041327612820051374, 0.06007727002725006, 0.01186303717399677, 0.03006169234492606, 0.034242678478720694, 0.034883396114192666, 0.03506058842063912, 0.04553973276708876, 0.0359807366264924, 0.025341876354368947, 0.039805714040994644, 0.03290429989236497, 0.04703252020502283, 0.053036014188922224, 0.03763046100615494, 0.010280146304848454, 0.03473528833579152, 0.021106314116848574, 0.03717964507579323, 0.017646174584966035, 0.05544485126231467, 0.03986130138078044, 0.06964222633189733, 0.02912301630262406, 0.05039039082945355, 0.03184502628902274, 0.020079126190995018, 0.0051657457163767715, 0.08737256525144463, 0.014625654608431845, 0.08307458216985388, 0.033387046367410696, 0.011046648874217945, 0.06876445811001525, 0.05219484581762264, 0.051993939259480086, 0.0144585219940411, 0.025282567742490963, 0.013740485019591308, 0.043056018259977145, 0.014521825754444205, 0.019710545968865196, 0.06791661328245556, 0.04461725182350605, 0.025894869261631565, 0.007084228582830439, 0.06652882968586299, 0.028178106219838225, 0.032316239310368415, 0.016205664986984867, 0.05049346412922587, 0.0968507582682275, 0.1123155530301794, 0.01484317186799261, 0.03882055178344731, 0.0336204810188182, 0.04931160113624027, 0.004845146538554541, 0.08372849183938197, 0.019630311665335493, 0.047203166290156306, 0.0542359683482397, 0.06238160121645178, 0.10718836404022672, 0.018081511708817655, 0.039265166232061964, 0.03772917143519848, 0.021306605889431892, 0.007285465037585387, 0.03562823658989322, 0.027246407323306607, 0.1207697009968181, 0.026219196414815325, 0.026844929370488373, 0.01918650352426114, 0.03521647199147171, 0.03780250520175023, 0.024956139593174862, 0.04429150740766237, 0.0495387576971083, 0.08237417862420121, 0.08673060655353532, 0.022960576311414762, 0.0816093011188411, 0.03801143653089962, 0.07024803334065984, 0.026518503136392084, 0.038449045105446736, 0.05390925100073219, 0.034875206634282105, 0.02534478174282178, 0.014104879528824842, 0.11639773680437958, 0.10914829274218892, 0.044114675162540334, 0.03856571263543541, 0.06725046918877671, 0.07985153535921728, 0.05266886655121081, 0.06290927874825655, 0.045210276655251944, 0.017299979451983687, 0.018093525882690184, 0.039957219419339975, 0.060168664316616716, 0.030196251858386303, 0.04247707412427953, 0.04062127975386478, 0.034567833006862676, 0.010581151826397307, 0.053122482532935764, 0.08405506746062348, 0.0409869603332012, 0.021491836373423858, 0.03880692307927436, 0.03753766094544723, 0.0033045319921051666, 0.015630278372085624, 0.07759488548242277, 0.03414262356537004, 0.020304020877266606, 0.07965790663635539, 0.01667701207371729, 0.04772418651789908, 0.038468384995095195, 0.025531023462873795, 0.010619681260939087, 0.015536569539577732, 0.06904722116286717, 0.09806028086571925, 0.024488128819352677, 0.0360104110422394, 0.02373716155547769, 0.04604150503573399, 0.029171973151425203, 0.032834409691032865, 0.10455129788287225, 0.05336786432552242, 0.05966229552042581, 0.03374266055142207, 0.061566564104249405, 0.06072184108498116, 0.0326672722885926, 0.10727907651134076, 0.10430492400642365, 0.04678765935222468, 0.0725164503279713, 0.035411678855457616, 0.05461987032885513, 0.06339197542758719, 0.008881974556002646, 0.04600637990440573, 0.02495965976718693, 0.003357514632948404, 0.02548408525575313, 0.024856887156924894, 0.04650210773932838, 0.03272363720762153, 0.0738458963291299, 0.014281527912845055, 0.09230139875604261, 0.021022860328817082, 0.06540634233744876, 0.05891359013114726, 0.03489719718814858, 0.09573481331068663, 0.012230895358257958, 0.09045388579608933, 0.026240309798008492, 0.19657002551661384, 0.30001480132341385, 0.11839019359960673, 0.1526581261667513, 0.142439371275325, 0.13940005533156857, 0.22185009964291127, 0.09096503498092776, 0.21542395495118635, 0.1566626516080672, 0.10479698994106824, 0.1669590265279816, 0.18820918705915252, 0.11369536931235945, 0.1237892059068526, 0.14855137395281948, 0.15540403043550832, 0.13938451906846416, 0.1991757356952275, 0.12206953003882401, 0.15540634402103964, 0.16571701414162116, 0.12638118778986315, 0.1395640900779155, 0.1083787267787322, 0.15639856577880923, 0.2604003334718366, 0.12992757733070082, 0.1170573461680643, 0.16101663571692285, 0.07783401982798692, 0.09193653406034555, 0.11133031033340002, 0.11499037966132165, 0.15453867283799957, 0.17124053871920034, 0.11318333146552886, 0.1984772014041101, 0.13330878299330512, 0.10704110661942152, 0.13349169414610634, 0.144453247888915, 0.115367716268426, 0.09319448107553106, 0.09479427950516825, 0.13483639295783736, 0.1420661638821325, 0.06084858650161375, 0.1030605903736526, 0.1587067733729078, 0.11702671797285158, 0.10767604029106517, 0.07739786299005633, 0.16135610459793, 0.1031544974314109, 0.10884116809334486, 0.15268578194081783, 0.2188767591911939, 0.2527131161261951, 0.17643320524404127, 0.13927605634014453, 0.16700051784996064, 0.1445205563739423, 0.11046269277651465, 0.11122335679829122, 0.1747148393863632, 0.06772360509081234, 0.12024162126885307, 0.10963403079057894, 0.13408697510678924, 0.16569637573294102, 0.11765882478005464, 0.11019402574146948, 0.11701410816561793, 0.19926838636879, 0.12184069191496219, 0.13741971804730355, 0.18284002919831585, 0.23077313938448507, 0.11801324003646452, 0.13355414563369367, 0.15268788102173037, 0.16206361743952, 0.08359823390961656, 0.09815102398035028, 0.12904482953731092, 0.18767684788232852, 0.1884377264087239, 0.18721517265564014, 0.17320700981203588, 0.2114719065326837, 0.10015401448453627, 0.1683180511838967, 0.10246105762498994, 0.12419336325218602, 0.18954207279509117, 0.16788078351847588, 0.18370653592771102, 0.11952513753766976, 0.15735986822795484, 0.2752860653544626, 0.1089247176423669, 0.11202437067103964, 0.14005734344884274, 0.17931211769821184, 0.14449397312296977, 0.16738981308956302, 0.09508892458172576, 0.10382829474345331, 0.18728009094634365, 0.11321049694332386, 0.16103707494274264, 0.10755282270932391, 0.1370425269969048, 0.16091204939350007, 0.09614470099369365, 0.15178297796557028, 0.12612595027613063, 0.17104716280535345, 0.09612472142062842, 0.10180344008990835, 0.11974514266776463, 0.15380914262946577, 0.14770458632659528, 0.24731049554482584, 0.14401411096895897, 0.16438805077585483, 0.14594989257954782, 0.2627144399429521, 0.2241668874217618, 0.07380668028828598, 0.10529267181071544, 0.13211498818089887, 0.11160281546894582, 0.26250594145348, 0.12987741389341895, 0.3181513200604147, 0.110564268374395, 0.11245050707892065, 0.15309953070696325, 0.16306812724759503, 0.14563809479436568, 0.16893830661091114, 0.225346387033501, 0.22797553950259763, 0.19982605241239074, 0.15423533266350148, 0.11998023206908857, 0.10931909970578649, 0.1847428230628852, 0.23664733304852442, 0.16342379122732148, 0.11605303554284958, 0.1410060360907547, 0.11971145778173402, 0.21137430693113038, 0.24719670084455322, 0.15776414814735615, 0.1196557402070011, 0.13338114765863265, 0.0912893046775172, 0.21466275466786278, 0.12576449467169662, 0.06977568650918622, 0.1724199464003886, 0.2912149638418229, 0.12537636388573917, 0.11978571468423452, 0.05681015783920885, 0.2934981816478314, 0.1040890557511199, 0.13248543765756393, 0.212315890277105, 0.24901301870422982, 0.18098562144704405, 0.21678829625729593], [0.0324998437727411, 0.06403123366556342, 0.022959754682115974, 0.02193075112788187, 0.05637137715013758, 0.030790588615702528, 0.07651607280657177, 0.02441274576760348, 0.01997077454542441, 0.02938632455263888, 0.013252184407094554, 0.07228143753543978, 0.015910431937945467, 0.036205062492480206, 0.06569209313320537, 0.02055759598020344, 0.09892121813590489, 0.0828080755027552, 0.03593658697941611, 0.06316370803922897, 0.03285900877428151, 0.05635647290957071, 0.05252385376802376, 0.05320150067188567, 0.03182418295182288, 0.04254101948331922, 0.029339859404811458, 0.04566187399529642, 0.0495185176541488, 0.03802609945377035, 0.022027862348383474, 0.09120930977646383, 0.04490512851325255, 0.042492637200461286, 0.028299598188530055, 0.06537374529627062, 0.08740074196529966, 0.022075850095960404, 0.020464656108449546, 0.03125648881729332, 0.03355897564981734, 0.0580399779362544, 0.025310215855678244, 0.015953100162498172, 0.10440138979784905, 0.0802137264080586, 0.02017762403063957, 0.022985449271096338, 0.03262670410256232, 0.0547877584974612, 0.04097418964750344, 0.022332137150149194, 0.009519310870898828, 0.01454228317485221, 0.03275968547489855, 0.018856223867905718, 0.027631657618668773, 0.037251875675734014, 0.039631038333379456, 0.045720180947213404, 0.01806082541964227, 0.051396597522280874, 0.03285731955040847, 0.045010285572178906, 0.015400384962108108, 0.04730565736310617, 0.05434353858412755, 0.024716543679636334, 0.0414140620118668, 0.1255347602249634, 0.05597018073463152, 0.031020591193209254, 0.026611783917272286, 0.040719193451467066, 0.06938215480336259, 0.045707555818221265, 0.042680317250591134, 0.04776354045456937, 0.029462973564682953, 0.06520626315426442, 0.15895235051791515, 0.15501675766802606, 0.19063587781162034, 0.10226182113852232, 0.03294753789481136, 0.041837835038501414, 0.03637893763821452, 0.02736167674283347, 0.04566367430191848, 0.06194675055843207, 0.05968743852610069, 0.047038066681594624, 0.045400703130590345, 0.12710111891670575, 0.029608649013924505, 0.050923879138163985, 0.023302885463401195, 0.060540259094728585, 0.10140211726989477, 0.08381709756870424, 0.06774942991473983, 0.020929514430463318, 0.021735663007524227, 0.08201882874052371, 0.04598212173028339, 0.0399712005239581, 0.032686849665497585, 0.06972856444096373, 0.06308058749944453, 0.037128217593436284, 0.04750318930394227, 0.07719227563469641, 0.031586808693264766, 0.08139065196437222, 0.06628709830223553, 0.011430901340058735, 0.04511286091480044, 0.02840645787786813, 0.020647766444111065, 0.042635167858773665, 0.06986036986833619, 0.042480023562788, 0.04098792177354617, 0.012161265626820105, 0.026347456770318172, 0.07980409153406659, 0.021443477073203654, 0.03497488999498948, 0.02832254826752169, 0.05395646499950559, 0.005510264074414848, 0.09377010422007692, 0.0739513636536656, 0.056968584821950045, 0.040994728464753404, 0.05405020351792055, 0.07362088098401025, 0.009545474688732817, 0.0040409012111805144, 0.04886606355167685, 0.043020341545343406, 0.023891641270189036, 0.08048480662006526, 0.03250435220017549, 0.03921856127318837, 0.008893705277343192, 0.08874279011281268, 0.012936179841598196, 0.044880146386041764, 0.03257790430178566, 0.048125448050878705, 0.02911012878851785, 0.030299959095915964, 0.014770843591841479, 0.01789976884010098, 0.025176186858105565, 0.03210625652554295, 0.04633610414701604, 0.017462711848859346, 0.05824455405555426, 0.019240143085499446, 0.06815334977281672, 0.04035912829661562, 0.06869496627440376, 0.037039106246083975, 0.03214347882256393, 0.03558324424610023, 0.07097870502020083, 0.020331008239619194, 0.05334344144249636, 0.05687146019490977, 0.048759424112617016, 0.04225500438722872, 0.04321894600927349, 0.050323756501799634, 0.022293183494419343, 0.0910989318283335, 0.1087454607289645, 0.024198315842377565, 0.018852830098401156, 0.016285663718477856, 0.03182670912675319, 0.07628644561214794, 0.024209295797552315, 0.07545641998970702, 0.02018464139602598, 0.04329272410682133, 0.08461768243221507, 0.02594017187103389, 0.008085011373153858, 0.08721504225245408, 0.04276696562526688, 0.1362016229259391, 0.01294100715313107, 0.002817296720628116, 0.02328863431278977, 0.05390984088843388, 0.04323679968834885, 0.020587383393919276, 0.08563181430461907, 0.0572810797471433, 0.027073790476987922, 0.03553620644754941, 0.06437498880850692, 0.04178453830160922, 0.04393480920923814, 0.041000880150785374, 0.03478265172171016, 0.02532658906983993, 0.01783875759781128, 0.011017721394197115, 0.05943197501643051, 0.04468699263769292, 0.020492101208336895, 0.048511069898884145, 0.03590823406533849, 0.020390314936277368, 0.01084555079409432, 0.04959081720200278, 0.022034609667776574, 0.07324539064880341, 0.010454750191720744, 0.0731283400748526, 0.03866401703787908, 0.0253349413434344, 0.009093996092316606, 0.02501083635574868, 0.037107659623988216, 0.00894241602039866, 0.0359907608869816, 0.04079702415413434, 0.011987905675214867, 0.00467660240716331, 0.019504230829977223, 0.026267896624161836, 0.05221016374566863, 0.049992312391799305, 0.05841580918058754, 0.025669633666233673, 0.05459617905979676, 0.04913779876885876, 0.025436762089450515, 0.0719173772320632, 0.00863783669868304, 0.04140678417658614, 0.07268109028377841, 0.1387358724229759, 0.017026505215213667, 0.016827577079135566, 0.01663841656409204, 0.012613784187593529, 0.0506153142440223, 0.05589369834671098, 0.09213203969862192, 0.03281747531746665, 0.19976462748262191, 0.20496322352799679, 0.25681517988203034, 0.1667612073041739, 0.34115807423668526, 0.013842504948467739, 0.15295841731131077, 0.12596252073924388, 0.09612637617054487, 0.046710081458572424, 0.05293067709933366, 0.034144990777056065, 0.00936418668472118, 0.08789793302815768, 0.05227964025952163, 0.04510250723650379, 0.02560497393020459, 0.03779445744810566, 0.07491409868722962, 0.05525909026243514, 0.03978011521300481, 0.06369687842145082, 0.03767457234883501, 0.006439307997483881, 0.032125169321173624, 0.028022672725661148, 0.09211569138231779, 0.021814976090324983, 0.055049883141633005, 0.013531116062715171, 0.01581032244083021, 0.017939636055680535, 0.06585489447799421, 0.043819152915309516, 0.04477950158498941, 0.057315193642411506, 0.0730223518105284, 0.030435470473622123, 0.057294367542189945, 0.05507175878231084, 0.03591461557774775, 0.06677992266392516, 0.04930374107413715, 0.05446024058807281, 0.029808868008155017, 0.020093024941161275, 0.08292883394225951, 0.053868196348869996, 0.042373901233077056, 0.025478448763850237, 0.030430000605842764, 0.02552800507645213, 0.04408822597695455, 0.05676050768083623, 0.046212725686810674, 0.009078296077918381, 0.061761150437016646, 0.025287125965640433, 0.00978804206580765, 0.040037057272368864, 0.02871423370144781, 0.014188163819903088, 0.023072306404731447, 0.06805548204048988, 0.03101811289877421, 0.02938656778555484, 0.05664718412463704, 0.03270563797184056, 0.06796548969202465, 0.030958423158153895, 0.03199300383247676, 0.00592219673337475, 0.034490297248046246, 0.02045341376816073, 0.037522963548619906, 0.02854678028773877, 0.018820907214596387, 0.026260858191357508, 0.015107704901076375, 0.06085146316176942, 0.024577217184067256, 0.010253221187139712, 0.10269142026382108, 0.03394459366738316, 0.05241777740358826, 0.04953624875915628, 0.1106605043394431, 0.08039588679469402, 0.03372059338876317, 0.026331294230335665, 0.05300154789320884, 0.026210179559946544, 0.07804471698980178, 0.011702965975048081, 0.03137126411010902, 0.043462833930407806, 0.027414464031256018, 0.15913785104790043, 0.21734332695843714, 0.11534465702190516, 0.11193096923131136, 0.14923982652685336, 0.18296280244906105, 0.20350814676813542, 0.08592013915580127, 0.15658014393862218, 0.11263449841569509, 0.17814610123393998, 0.1552764614743571, 0.0793093596134455, 0.05547067991668179, 0.1326476337928926, 0.12851676513110438, 0.2972688664111399, 0.18165896676721113, 0.14347395769530727, 0.09387416194283194, 0.1231221195250269, 0.16850624834337544, 0.16289266246941783, 0.25195761553702817, 0.1715551863514608, 0.12737298053839516, 0.0989041803404689, 0.290149029103979, 0.11728592382203187, 0.13244796063630812, 0.2323870108492913, 0.18949046911251163, 0.08035562121339383, 0.07425741577941565, 0.2085029481038932, 0.12274696626850676, 0.1881576906288824, 0.08639738128911104, 0.16560406213806522, 0.11807792083991152, 0.08798094631563272, 0.12223002545896078, 0.14750767108653823, 0.10189899423670384, 0.24437633282955618, 0.101275444631615, 0.17714689275430096, 0.10665061628265728, 0.13350159200208803, 0.11659184050175453, 0.1478540500806224, 0.1592024935469512, 0.11060717695903395, 0.10347179572788939, 0.12953606043611804, 0.08984350524241887, 0.06744589055738143, 0.270816034246837, 0.1150194526980481, 0.13010281228250073, 0.1774234658167247, 0.14872299296961677, 0.16052523627877235, 0.10660144875967696, 0.14099440687606413, 0.1345026697362623, 0.1787395589053631, 0.13359848680275102, 0.13131937522801662, 0.18194943666458133, 0.4487397401563583, 0.12313412412280038, 0.11979679997649886, 0.09000921006044073, 0.16736902146329805, 0.20276577692599068, 0.15005666011523816, 0.17401694860910216, 0.11062348697094188, 0.25242551139766173, 0.4226699519541956, 0.35816130378553945, 0.41358482332960256, 0.4433640399046483, 0.2488483098005095, 0.1729670863959097, 0.2011727430527249, 0.26287050737488654, 0.1339378484314488, 0.1167103696253992, 0.14084895742276024, 0.16130411787138832, 0.18171037126693035, 0.17986592265867418, 0.0999871452128695, 0.12034490524280457, 0.15113724245419427, 0.21664134527166046, 0.19579520418999657, 0.20714602252889067, 0.12274630743289187, 0.10767633140447641, 0.11703823227435352, 0.14639612347368272, 0.1573186067323531, 0.37978315485581277, 0.11993238987821726, 0.1497039838784164, 0.16125599222798503, 0.11576002989445003, 0.13744996319855415, 0.17741698471288528, 0.08219705143522832, 0.1245362718679732, 0.1313499421361954, 0.21578726448839713, 0.10513567741239264, 0.14989472444980376, 0.1497902453786904, 0.1629941537976265, 0.17775219414503346, 0.15336743165408412, 0.14182274710507164, 0.11917397815493808, 0.12270705308765174, 0.17957346093270088, 0.10489485001251583, 0.10303736258778842, 0.12004861307720985, 0.22235063084911919, 0.08772328030318023, 0.15193933651091593, 0.14955718611036578, 0.10511508496898798, 0.17792362930072894, 0.14772306436732893, 0.12762306228039727, 0.09189941710041416, 0.09776912148921721, 0.11323077529067956, 0.1473550050849876, 0.1324881036435404, 0.304338417706951, 0.07580005638902226, 0.10027533216822533, 0.19627290597606092, 0.1679480766817447, 0.09308452447575909, 0.1043701334105384, 0.11269779259999914, 0.18610420726960708, 0.1122751035877774, 0.20172613432570813, 0.15920577240326714, 0.12190538804016768, 0.10277650198869168, 0.0769864354703215, 0.14636402438965537, 0.19623933600321894, 0.20551911224761318, 0.21386839809917638, 0.18103223023635728, 0.09968675447687989, 0.09008618657507243, 0.17029886344267478, 0.14962182860941659, 0.13882582646704492, 0.1987871452565155, 0.1611175907835845, 0.12231930534565642, 0.08691482771668704, 0.24724579175874112, 0.10454343782076914, 0.15250268692691482, 0.13250903316563176, 0.14222400863805126], [0.023415084785571503, 0.040541166109183145, 0.022837343407915007, 0.007557012563225844, 0.012779050420278744, 0.040863087746284665, 0.024217406753450636, 0.07964567987308388, 0.0549100146388575, 0.018668756407174854, 0.05341417434054518, 0.07123625611946469, 0.0515455977931138, 0.023759360868303527, 0.0032824387345763467, 0.05132074715689786, 0.03201395442198602, 0.03659038556619518, 0.06210589383338248, 0.011183133183587945, 0.07654064124630344, 0.054405978580396024, 0.05654542083521524, 0.01879255813095839, 0.007263397396121535, 0.037602755436373335, 0.027816817239527742, 0.0518075232544253, 0.0545117293574637, 0.012430446898384441, 0.02809754441372089, 0.04468317751983001, 0.11845220075619799, 0.0314228754535678, 0.06058431681125395, 0.060864164899553985, 0.045983726684484756, 0.03872629615568346, 0.028556266371461175, 0.018024194925542802, 0.041585589098113204, 0.0385430172806786, 0.008812200225469087, 0.023942028788188775, 0.04603246519822748, 0.050002413261080944, 0.02456365168214806, 0.027330546760030335, 0.06064955302844606, 0.06837989729378494, 0.07963464820697423, 0.005373285159528737, 0.040388097911472284, 0.023518596670680472, 0.039133253552380114, 0.03584107496745644, 0.04320812501734303, 0.060526496325168884, 0.07987445670991175, 0.04810246158271067, 0.02269882321988623, 0.061856011274240674, 0.0434574636540586, 0.07594222698601023, 0.08867421758271034, 0.10011589394942408, 0.01546003352550249, 0.056891033741375135, 0.08151229906586871, 0.020925138153195865, 0.04989876539536542, 0.08256693400682942, 0.050728097708234866, 0.04940971401670287, 0.07569107272091412, 0.09784582221219618, 0.13713621955004432, 0.5561581374176088, 1.8840305939797435, 1.3429553181894365, 1.859439416758476, 4.037605975904773, 4.30827207142307, 4.1235441257876735, 4.485024857905604, 3.608348893542444, 3.855563137800463, 2.4534376398209603, 1.2891998478481848, 0.493805107450293, 0.23598751684110011, 0.26821424643839564, 0.10782889015371762, 0.2796512649905297, 0.08448042245882173, 0.3642650940004857, 0.4043705629244928, 0.3983702865098754, 1.4630645441432155, 1.196115997529799, 0.7090187253009889, 0.2560161654987643, 0.09022137045019096, 0.0346439898074154, 0.04150932121481146, 0.03649979566914901, 0.03015248525527216, 0.04850908956159988, 0.010545122711318395, 0.03354194551526058, 0.04821108901993402, 0.008546974840423754, 0.04260088542416211, 0.023113843691985936, 0.027622778659626365, 0.07165178220959441, 0.03516457336504133, 0.06354097569842013, 0.028170937552086772, 0.021190407588296843, 0.055634197553679834, 0.04099211610493161, 0.029580464639190226, 0.024510383673553026, 0.02590919893625523, 0.08829594634833836, 0.03987084300587735, 0.08605296348011301, 0.02566130246005712, 0.053636952708925933, 0.07312058726505888, 0.007737646998477079, 0.042237943609155, 0.012374220832791782, 0.03492206823261034, 0.047032481900626616, 0.04956261367507039, 0.0683548538795402, 0.0026342021855300353, 0.02742846045763262, 0.05839622414280331, 0.02581233860954883, 0.03953893158224322, 0.04112384875395125, 0.03803736477669689, 0.01057603052862349, 0.05430114710883749, 0.008746417213021027, 0.016872433442321998, 0.10164946407800722, 0.0607084958333402, 0.06288941025794034, 0.03445343309712987, 0.030190251474719376, 0.03134975236119523, 0.01902486854833701, 0.03394920551668733, 0.04856075836165298, 0.013712559199531474, 0.07181760194080491, 0.03765861856781187, 0.06822573742078197, 0.08813421752664351, 0.0442789473961438, 0.04168304697340054, 0.02293682950098188, 0.01636489253160694, 0.04895155896402655, 0.07940048577203866, 0.05654307277572732, 0.02385110947333517, 0.0418718378510206, 0.04499389512103893, 0.07317828134663644, 0.08364939326120001, 0.04733865277000493, 0.04814428998337639, 0.03680644917391962, 0.04978955956175924, 0.0678303747648193, 0.07397637642439335, 0.05336329461105409, 0.051866397111406254, 0.0705433678963492, 0.042862316758762446, 0.018282640432458253, 0.08512525398644709, 0.10910081827352125, 0.03757334532096021, 0.01616287514597418, 0.04101696416675564, 0.04070616229587505, 0.024681776694412676, 0.02904356532399693, 0.0241660539646663, 0.026867931160414894, 0.007465260606559535, 0.10160648654545508, 0.053145599236050924, 0.0026425807933969005, 0.009472752834910588, 0.06389115065816911, 0.03814548276545059, 0.030181636816010843, 0.07341861845024171, 0.021070181579899885, 0.06934348268494492, 0.03007092178919383, 0.020072503360889612, 0.029798862899863915, 0.0599867529085567, 0.03958362515174574, 0.019668631383308002, 0.06339394427355259, 0.023811408881879142, 0.0355661298418718, 0.049879306762088696, 0.03096445227011798, 0.02081156370320147, 0.0407222424814057, 0.040746703668827974, 0.02412706966541948, 0.006620395861025299, 0.044923916819595525, 0.04983816784055484, 0.04829541614819919, 0.04211741882646757, 0.039148360806246923, 0.051076813270488096, 0.04070443093716618, 0.05969778837395772, 0.012072103526142818, 0.02670414156220373, 0.02808060620971505, 0.04253592116818313, 0.10820109397172929, 0.030257134780948682, 0.05106115826375542, 0.07044480302401128, 0.062415378033033306, 0.03278542602915437, 0.06599482043736404, 0.0717519328839356, 0.02271015749072596, 0.08441969466906402, 0.04218006949691523, 0.0916638603854564, 0.06957742295438243, 0.02545601196376787, 0.05150787179328261, 0.08552485310863103, 0.14390937142795132, 0.1322246306846219, 1.3503596499081583, 3.453751860126373, 3.1168815493583684, 3.2922445910592235, 5.866137483427602, 7.297891339948101, 7.059168046520603, 7.65244173426782, 5.588621948995899, 5.2661849798694735, 3.2406426245166413, 1.5993491343913542, 0.7734513775475564, 0.3433624156300099, 0.3921315728897049, 0.1262036852178074, 0.1766592165034625, 0.07760114442076414, 0.3700156870388216, 0.5689242878748525, 0.5607951756927275, 2.0187983301378067, 1.7963766522945899, 1.9011007489696627, 1.2042924233021275, 0.27688409412099474, 0.04036064898114532, 0.07558620294495937, 0.0439667129408448, 0.03821831857485156, 0.08971243525945372, 0.048312335200006926, 0.027944445572493058, 0.04527221486393002, 0.011848748676599035, 0.04652791341105777, 0.019463455800207394, 0.06142432455934825, 0.053430564791685155, 0.0006703557218931946, 0.04877066262246621, 0.030057036445566246, 0.009089715576039688, 0.05331507320666025, 0.024335167873951218, 0.09087652884303563, 0.029325232871117133, 0.0694100940299611, 0.03561104940731199, 0.047456925254194975, 0.06472751948862307, 0.005797227683116592, 0.0942591977335753, 0.03437979289540841, 0.02454358017853191, 0.033226401560128696, 0.02423462649476865, 0.030250691981505484, 0.09456939439499572, 0.07948159150058225, 0.017194711310308308, 0.0940748386745972, 0.056949206627905376, 0.05748336909398918, 0.13687198050320148, 0.04371637072894843, 0.028347742984131463, 0.024203607594714533, 0.041537835007353176, 0.023573569224907026, 0.07009644752308246, 0.07073077598526593, 0.06182523369188271, 0.03521000237895116, 0.03624979436637894, 0.048448453702393084, 0.05619306635532168, 0.04872938197466636, 0.02534434124226532, 0.031147539623141773, 0.0529853604553688, 0.0343230027975815, 0.02645796112295601, 0.08510650015406071, 0.023965185710919962, 0.04834870522421214, 0.06274809001854832, 0.12211699684661244, 0.04492751360240002, 0.0364283311571325, 0.01407735686253516, 0.022538172666944807, 0.01251710006110971, 0.012072160025127234, 0.024374324542981003, 0.027078475104644898, 0.005012732102430516, 0.04248358587163591, 0.04539785711395164, 0.27187458389709074, 0.11622920512191712, 0.16574470055920465, 0.20284563393121768, 0.17526703556218456, 0.12410821257940224, 0.07895242392776475, 0.1875212247813902, 0.20110145091049134, 0.1350861376211528, 0.1791922862250959, 0.23874351814869912, 0.14810236982039868, 0.1017384298686539, 0.12333869258122099, 0.16482556358941142, 0.16583552794350734, 0.127698935628418, 0.19080401878924141, 0.09382095713649066, 0.2265682513074529, 0.21255579837147268, 0.13835102049333436, 0.1767536445010093, 0.120328480317708, 0.18347575960140075, 0.11704722614658457, 0.17686887944657959, 0.1580888315314247, 0.06073163168865347, 0.149843902176907, 0.11492026729449151, 0.16004610956916887, 0.15663577724368344, 0.2142545523782892, 0.12439512016792452, 0.15064354475227096, 0.10465797562632831, 0.1359454584458182, 0.10195738545829251, 0.1094251799006616, 0.12031957837602786, 0.08339617055870834, 0.11308383962680256, 0.14382831932556245, 0.15560880573766847, 0.0933575122466972, 0.09984084540196966, 0.14349165432635816, 0.2121905889362097, 0.1400072566203533, 0.10663429094899086, 0.19526583743431877, 0.18593127058158, 0.1287043647420022, 0.08535214624698124, 0.09859527836764052, 0.10883112468065755, 0.16385997104788982, 0.16587515001095113, 0.09481230555402656, 0.1609677133420783, 0.10396131825062538, 0.1861837118743889, 0.10819333350105632, 0.14437408036281987, 0.11794396270547183, 0.15582502639341742, 0.1857578129537644, 0.205262717941115, 0.2050708588813582, 0.2691970759582135, 0.12055750996355089, 0.16140036915819492, 0.22407460447040298, 0.33797491762426596, 0.6805632780155828, 1.7406894146434724, 4.205903603184608, 4.172125622149437, 4.634342626217873, 6.5476071353881595, 8.136028301331306, 8.763935046811259, 9.55752565014747, 7.438971640602236, 6.5333988397352165, 3.882491925070363, 2.664960521844126, 1.2522399665847903, 0.586962165130723, 0.600216773248488, 0.33338899273545514, 0.40038837660704896, 0.21216454194678416, 0.7419722118685323, 1.2072408199310303, 1.2142993702042488, 2.41593683919599, 2.7853061931748546, 4.188352467552308, 1.8844393784961395, 0.689465097121654, 0.11936312526344292, 0.11818379419104708, 0.20218807002229078, 0.16482616113799234, 0.15318781467935733, 0.14056210346039266, 0.17286835298422845, 0.09724394523448522, 0.07550043940183616, 0.20093464292585853, 0.22407271989410926, 0.11242324200969551, 0.14383633260525044, 0.12046311260952104, 0.2205058758056933, 0.1401544833976415, 0.16375665643042134, 0.16599458311834644, 0.07262970876669692, 0.20388650227217905, 0.13098854781879535, 0.144880740272422, 0.15409739087185553, 0.1595065844876151, 0.13230704642351598, 0.08390000360386987, 0.29475983652857046, 0.14518852375688093, 0.13232880332056554, 0.09440512216139225, 0.09126243797401268, 0.18717391116003837, 0.09674228021814939, 0.2646484442295567, 0.14140423327203722, 0.19445243591983474, 0.14136960609785973, 0.26191059920576315, 0.2242741397311611, 0.37310467612358833, 0.09979502568321844, 0.18771882950057908, 0.19231429984492643, 0.13150021794342226, 0.19044231803667164, 0.11503788477350628, 0.28399786401179533, 0.23421727150918978, 0.12831580494680714, 0.11649762700882652, 0.21113666645701856, 0.22479290382996683, 0.09090433783468702, 0.1268366577043649, 0.15916857117366406, 0.12792009755127853, 0.1867114851671842, 0.12589395587002078, 0.16355243271156666, 0.25375231439548157, 0.15913135462230252, 0.23283083622734393, 0.1614248839717719, 0.11294489425997581, 0.11434277489541039, 0.11859285449909589, 0.1496015732446986, 0.08429340507474639, 0.1759796199058333, 0.15880618094196244, 0.1637465900350963, 0.19687474464937565, 0.10804706433367346], [0.04172655310662043, 0.01962684511747812, 0.03326008644615931, 0.028923015643451965, 0.052872707226103356, 0.04891460671299889, 0.06267573684453964, 0.049663856024703676, 0.01902951295637796, 0.05110050836998609, 0.03286402665018555, 0.029988178547712106, 0.04251283127814532, 0.025634182947537592, 0.03445560112595558, 0.03342437017108164, 0.025024371214150905, 0.024756949071982698, 0.01795158702729931, 0.013032421552305742, 0.028782375307092746, 0.06528897766744898, 0.10214476290369227, 0.0108408221163817, 0.08826222315791153, 0.0028170728793127406, 0.020108400325801586, 0.011137524139015906, 0.10555720963184873, 0.09062190419964253, 0.06162711952422416, 0.07699684660521246, 0.06922887593147255, 0.03620655636393255, 0.02753717024930783, 0.0957435620347819, 0.08080202830775131, 0.07373660622585206, 0.02394012889013656, 0.0184955190296375, 0.02438128253655328, 0.02225209628382037, 0.03940974234513218, 0.11007917383986135, 0.009615737400318106, 0.04896011233570115, 0.048050187573197393, 0.05358004769791038, 0.03523633282090868, 0.027291679289191965, 0.04618487072988384, 0.04132981149239406, 0.09091592874498138, 0.02485203973558401, 0.08229639771724902, 0.011693239531239435, 0.0380397281579433, 0.05203017521829856, 0.07490686681722442, 0.0729203931686859, 0.05165431716088807, 0.032377093504633636, 0.06227891096064161, 0.07079279080273644, 0.05604505433791107, 0.017831606167038123, 0.048550619187975125, 0.04049701263166724, 0.020848575326043273, 0.03859530661195036, 0.03915753087870056, 0.06873802807662757, 0.2735662286079699, 0.24418248194119624, 1.6564693854701136, 4.348547458648682, 6.477791397802292, 14.856204525116953, 23.946411148194347, 33.115975164598034, 34.47633943250103, 27.246120745135894, 43.70323673371346, 39.505327901532574, 43.218055232878655, 38.99056780722834, 26.82154182464846, 24.10341578145181, 16.03179181775739, 8.54101792458565, 6.722120248502301, 5.6687893117627794, 4.370497042132962, 5.393877250532951, 5.0162579263410265, 7.608755846177378, 9.225868659634745, 10.479800393504481, 11.065588728074106, 12.640363477891492, 19.790557969001032, 17.758232855027725, 10.99960171407269, 4.393723847404603, 0.8135260497370075, 0.185838635229776, 0.05359222466546682, 0.04917883426852284, 0.06748191201158109, 0.016422695780713713, 0.017244424670934677, 0.03167502180252585, 0.037984734536298824, 0.10128372604207647, 0.03650568688528673, 0.04014465815177368, 0.05935178093251683, 0.025472676291340784, 0.016943555129992387, 0.05779292607199281, 0.027670934946546634, 0.0802820231465082, 0.0982377221507411, 0.040738916385077664, 0.03821697792098407, 0.005146355073403327, 0.05837894119923154, 0.0349296486726211, 0.0371601672903184, 0.004197491976928207, 0.051144680999700105, 0.026698315463539575, 0.021615122903078314, 0.01907695295108903, 0.04949476892849611, 0.016436131047685782, 0.035387386207378684, 0.05211432997678077, 0.009775953198362504, 0.0599896180773935, 0.04941084016595156, 0.04413277782019108, 0.023120638891874302, 0.039258497436681104, 0.04827762375615778, 0.035688259578760595, 0.016455503496071024, 0.03290237318123541, 0.031798635834767934, 0.00678032964295257, 0.0258013624848137, 0.025119373777640924, 0.04891563710125704, 0.059447924967014024, 0.0007921596320116923, 0.030965291136395068, 0.0582743970106446, 0.039135984655830174, 0.031860326980090434, 0.038466220796709104, 0.00961184184322314, 0.037171409630607215, 0.01695154734226244, 0.02020059517704912, 0.01925094875567142, 0.021042297894675887, 0.08270278437844208, 0.013237263887159288, 0.06601695271749651, 0.06835631710747558, 0.05851424381797833, 0.01281434504856025, 0.05861024612620954, 0.023692130907288483, 0.037134886388817144, 0.04012292040692222, 0.036451884530364506, 0.0437493508140887, 0.049855558036436, 0.05582173970798331, 0.08104755182660396, 0.03636291107883857, 0.018431483655266704, 0.04600944808654247, 0.05974427841964269, 0.09097746092705958, 0.04717427328409207, 0.050045969190015915, 0.04028453431542843, 0.04478389126879554, 0.016283260117615425, 0.04010701259117454, 0.05135630129746372, 0.03892194352022583, 0.1361382827763596, 0.032573587396332336, 0.01656212569815257, 0.09348959346572239, 0.01981636569384606, 0.04142297927530543, 0.08604904877081995, 0.02908010963320492, 0.036090513195602164, 0.0669282066425489, 0.031190588018826904, 0.06189844488436657, 0.03458656385661133, 0.05476085348956047, 0.010007889190268134, 0.05640302424228961, 0.055265364522535, 0.035361331557073904, 0.07363891469374781, 0.10847353015936191, 0.04340586380191869, 0.036241930473836205, 0.06046495648221143, 0.04772952615073131, 0.048575578332548185, 0.04855552981156976, 0.02686665753924078, 0.03778298145099994, 0.08896716194407595, 0.06904446324633975, 0.01647017982548043, 0.01786535425532249, 0.04381890393673413, 0.015610700995180637, 0.07294706835020935, 0.09022263449526603, 0.0051156761248656105, 0.036648098799970844, 0.06606515496969223, 0.03196527911049705, 0.01345004863856781, 0.020679762106268637, 0.042959104307116046, 0.041397706034683415, 0.020822110818699006, 0.038283087478409854, 0.05091626039375702, 0.03559777693402383, 0.04093660537393824, 0.029738232786316546, 0.07794848868563291, 0.03849189240305174, 0.0335212764630635, 0.03645700965857795, 0.27453477824887923, 0.8042952418327333, 2.7771932607696903, 6.121846600886315, 10.4135182211476, 20.048394972278228, 31.787505649751235, 43.83125897376768, 46.06086754029798, 41.76227538816391, 56.22118303852697, 51.706138810803814, 54.00201582139539, 49.183776301722375, 36.22997622336111, 31.077797874327633, 21.989440648786484, 10.027610928781572, 8.220176379526816, 6.750175981752335, 5.869222427568128, 6.312895446054398, 6.105658488888895, 9.023504757112073, 11.803416955855585, 13.894727653072728, 15.87445084125765, 18.903374710390647, 28.95918061656337, 24.96799638194423, 15.905500323541704, 7.575718212512232, 1.506860994042889, 0.27398209177678634, 0.048282308383814754, 0.041392381723609664, 0.05385966212939351, 0.025855482766224493, 0.07612454059023051, 0.05607468278838262, 0.045354607620186387, 0.10429756190147131, 0.07954331520464152, 0.04399426146260193, 0.008337156764502007, 0.016721290040520892, 0.05279958030329116, 0.030718524639885274, 0.03199159231547627, 0.02658764448677821, 0.08034722488974372, 0.05034822918054077, 0.0138818540970885, 0.09854788816864453, 0.02339174400173849, 0.012911223569854855, 0.031731269893146334, 0.02886018302712229, 0.05219336343748916, 0.03628325708691151, 0.034927622370061376, 0.06376355105350096, 0.051370489245821396, 0.0460674217902124, 0.04768079912830745, 0.008661632347221096, 0.019004888975271778, 0.09305997901866514, 0.02126745305084173, 0.020830296468169942, 0.06020207724143421, 0.026571248289978793, 0.07765332266928689, 0.09057325761645071, 0.025146476053182158, 0.06025916994399121, 0.006371897048196726, 0.019122475810769587, 0.04770076721005383, 0.051103411843219114, 0.10141183892565389, 0.11068341802925834, 0.00985343150058461, 0.03443539938739231, 0.01764184810341366, 0.038787529563471194, 0.034010385298320366, 0.04220730009218378, 0.06350837865724199, 0.010044775366212332, 0.056317444560268236, 0.0022827186518453906, 0.04302058286303955, 0.022038792507843148, 0.018934217364256902, 0.08709120413949413, 0.04612890417657552, 0.020591642842778278, 0.04552803077404538, 0.0698003085750726, 0.09605467800171145, 0.05568331145050545, 0.038810738197137276, 0.03725052353054766, 0.2037389077726872, 0.1753748547766478, 0.12579961214214563, 0.20191469920739052, 0.17643525835967835, 0.2121527748362672, 0.17441315396178156, 0.1396441769095198, 0.20228188514949816, 0.21741466506594614, 0.15422365748353545, 0.17320393013858026, 0.1662353645529478, 0.09783645295688222, 0.09740172104249079, 0.14175329357385635, 0.12424183363515524, 0.14557060244823658, 0.18210061645555883, 0.10027130254574361, 0.1614556347410525, 0.22214945616020312, 0.3100929024719423, 0.14667098049915608, 0.22112689732063204, 0.12566026840959826, 0.1277970102044844, 0.1393813934297331, 0.18872726167882645, 0.2358645750510116, 0.20077201778129225, 0.1642823459640626, 0.11284103572008111, 0.11653174856497396, 0.13406907929287804, 0.1902660258835362, 0.22328654514445415, 0.18327092301220665, 0.1247609194908892, 0.13178739366271805, 0.07017608236281142, 0.14152610253903175, 0.13457828261438878, 0.222914042552152, 0.10804051428192085, 0.15018606768740764, 0.15328539895915216, 0.18796796129355509, 0.11495672541880801, 0.154453560469612, 0.17881128005683425, 0.10575626225721453, 0.21009330066942403, 0.13464594349986123, 0.18452257278465456, 0.10659705141499158, 0.20242828455182815, 0.13210535079481142, 0.1730655746594552, 0.13652909487005205, 0.1604269165545702, 0.1722333120602754, 0.10189821282702108, 0.15445754412681828, 0.23138869103164444, 0.16297596687030408, 0.18702869153311177, 0.11699366893979812, 0.2012312874918984, 0.12891427283325504, 0.14097088797678872, 0.19086535178845931, 0.461777453461001, 1.2308650103307541, 3.879075540650276, 7.975853902678336, 13.830588075422472, 24.926425141672937, 37.62033093360163, 49.586693932933194, 54.58359349158503, 50.43580078309583, 62.16986533134215, 58.661838654548895, 60.51574691649407, 57.01868326433244, 43.864481449127204, 36.8382260107225, 27.51190054801203, 14.142031131252168, 11.355573477283603, 9.518356861606721, 8.160780908599977, 8.361470449355341, 8.099612526355251, 12.740574152238908, 14.826158189004468, 17.79601900808273, 20.76541404570303, 24.752179730323054, 34.418225596027995, 29.220200623235396, 18.637037930950044, 9.146477926161982, 1.6990375206355126, 0.36938963998709956, 0.13808512669657508, 0.1197574153963116, 0.12309378193270777, 0.15923702879057777, 0.1259722270732445, 0.13063142827201274, 0.1356895084703161, 0.23430515711586322, 0.17672882325226263, 0.29520818182537634, 0.14431614879398577, 0.13432841537700546, 0.14957980102589055, 0.11466251701236733, 0.12575963767425669, 0.18764338516179593, 0.16704799997950756, 0.19802677234815014, 0.1053849241185573, 0.15672910207461926, 0.24447670566939542, 0.1116560202752871, 0.1470704340646344, 0.11826396529232303, 0.20242154297809448, 0.11000336177887456, 0.2137107831696349, 0.10937572126427006, 0.15540683431731117, 0.13718897236451028, 0.16840648837387565, 0.1246174542053092, 0.14782113894339532, 0.23136815987527373, 0.13437243478913463, 0.17659232170591432, 0.20064385127156012, 0.0745987998802335, 0.24131907510661313, 0.17145092178496624, 0.09657949419511903, 0.15396084336023177, 0.07599137918723207, 0.11816832687585585, 0.19006808408566062, 0.10955919932213523, 0.19569783441482053, 0.17249952761396287, 0.11984106453676378, 0.12253968585883418, 0.1530667881090795, 0.14368021920804055, 0.11420838775173311, 0.11765703213431182, 0.09194794877041733, 0.10403962775824532, 0.1661440009070981, 0.0983865577126703, 0.161085675560659, 0.15480669635918834, 0.2678091391440361, 0.17941258246860198, 0.16864135560970153, 0.1440676451931077, 0.1864114391707605, 0.1160648869230382, 0.20648049130555124, 0.12338379983820262, 0.1323335224221791, 0.11167659739693327], [0.02534005689554878, 0.023355071372803182, 0.10742312402374322, 0.06932944029329285, 0.039837610111722065, 0.05947168135354596, 0.06233647480727204, 0.0571101617007967, 0.0692200965638603, 0.06701335731533266, 0.05260138952684018, 0.00948866926914742, 0.02444689413682828, 0.045723425329572735, 0.06045019396791055, 0.06675531591979728, 0.03246090352354992, 0.00991932559578169, 0.03166663888541441, 0.0416382078471924, 0.03831958007668296, 0.08117964836738764, 0.10884784838004459, 0.0316605887060324, 0.03982157589146688, 0.04609407015865849, 0.015901349965603124, 0.025052534521467267, 0.014339771662508289, 0.06322733164134045, 0.03753145563326055, 0.03455065731560031, 0.07238528075357599, 0.02825107417940613, 0.02985390823244328, 0.038643179446338646, 0.07587589909352603, 0.024615241958188917, 0.044918144347086075, 0.0064611659223784606, 0.043874598528829314, 0.01748667699435065, 0.04011644313352243, 0.01130131182200726, 0.06425851280049932, 0.02901536945794379, 0.08024522028262578, 0.030697583626475067, 0.021095958523332112, 0.04850785999048141, 0.02370592240514534, 0.05631615753255545, 0.03024696496375386, 0.05079270956376868, 0.03466557816512162, 0.026354192598392407, 0.0665130635963813, 0.052561009032351357, 0.037863018486889145, 0.04059304941385504, 0.05365159647959856, 0.04074553921518307, 0.0667009849642073, 0.055760632704703085, 0.008931632375254506, 0.0553788872615945, 0.04819179509556101, 0.15907138525958986, 0.17463953294340642, 0.4379358166648496, 1.2149260914133442, 5.921617448329926, 7.419946184081416, 16.782137309351278, 24.733124856025945, 33.38248452832622, 48.332068920135505, 55.74481902583953, 60.51261686509656, 68.13131886143839, 74.98657072744062, 78.05580969779723, 70.85086284145233, 76.62746291006766, 81.32313620659613, 78.15000933985557, 72.25691487712245, 64.78847495971188, 56.5833511660176, 45.841979672831876, 32.04069660555932, 38.41741146579866, 26.360235791052542, 26.15107147924362, 36.905216170895486, 35.874142723698775, 49.252755103572724, 48.518106937408454, 57.3747403390946, 58.803620569167606, 62.81166707315753, 62.52043108786307, 45.08689203569966, 38.7541312556113, 24.87242783269575, 6.541712793611712, 0.1502436008905211, 0.07784241615163703, 0.058499477473237825, 0.06610364322700808, 0.026273473744250597, 0.060774076790098226, 0.02417784022738136, 0.03709921350462302, 0.04167988686071288, 0.052498603510039474, 0.021263978842105118, 0.023163108891176603, 0.024724463113553585, 0.03700321502683144, 0.06540958288936846, 0.011577992136740397, 0.02229265872419121, 0.05499208180774605, 0.033830791306231296, 0.0135450990825531, 0.07595508194137966, 0.03800036272995415, 0.06812699634822146, 0.06529746592165002, 0.03400933192742448, 0.051102684059691046, 0.055109235803566636, 0.00814607528398835, 0.10233934923645951, 0.0846075394280976, 0.019083610255151026, 0.05420228729264871, 0.02423250251599858, 0.02117185485399058, 0.037032042915422114, 0.011984067574714222, 0.02516699763345382, 0.03227420789640277, 0.050614823947750756, 0.049297918805912624, 0.019569430657992923, 0.06170200078838295, 0.09468920288547393, 0.007263538164777622, 0.01986958007628639, 0.023921405701267145, 0.03537483385673935, 0.016900198383917733, 0.033191318563636274, 0.02917068229327279, 0.021643138738469254, 0.01852280325106075, 0.052935694975237695, 0.1360991050399119, 0.05074266870055468, 0.02024574839930621, 0.02624071199416874, 0.04794118475289114, 0.008315881545234832, 0.03398145781829953, 0.05650153548847284, 0.030973239298609477, 0.010837510701328998, 0.04590543249862329, 0.007861831287417801, 0.01038858509292045, 0.013075537938294152, 0.005377329624963985, 0.04683631742673536, 0.041171599014271656, 0.03534338594744763, 0.02441790920021313, 0.023475318448618058, 0.014476499204794246, 0.019123655586172978, 0.07836174715550677, 0.01345517280917134, 0.04369659799962275, 0.07052083725049611, 0.09001055837518747, 0.035750121178646246, 0.06464544082841565, 0.014442354666009067, 0.0438952675810264, 0.05026041635222012, 0.0056281659635715195, 0.03055678049643194, 0.017292102152902274, 0.030358528432947014, 0.03279048603989425, 0.05705339458560752, 0.02845831245424286, 0.03752582105657747, 0.07010657520544145, 0.03841468223160313, 0.022185465786606077, 0.05657396527127393, 0.037328783242452535, 0.04040759867958484, 0.036514424118063146, 0.02766712748956296, 0.06714825773791921, 0.05159527476456377, 0.012534745938835606, 0.01950848070273717, 0.0776779523960525, 0.014475272506505493, 0.011862062327113124, 0.015701756290640804, 0.05028793040002066, 0.03406080154461726, 0.04666437665300985, 0.022251019930286754, 0.03952367877167079, 0.09609690476809779, 0.02935065549888438, 0.058367208562671184, 0.03786792911048378, 0.06529521362315263, 0.05334400068668108, 0.055418363772332675, 0.02579568002763535, 0.022104561156142625, 0.07424110576750771, 0.007277813734441636, 0.09532392205249879, 0.03490487338914987, 0.10586407381079851, 0.021461217754310178, 0.03991622605451173, 0.04862385336309672, 0.07886279164062393, 0.07009318398852503, 0.024425075952744773, 0.03460021937386163, 0.1003965272778465, 0.030578271177927815, 0.23885060191875507, 0.3201840577587005, 0.5525483924054331, 2.126259505748749, 7.938802703734368, 11.727672065457991, 21.628019732813684, 33.14930746632238, 45.075477938498224, 64.79574703401136, 72.45573982115715, 74.0555569433397, 81.06920980638074, 87.33995791404479, 91.19417298224666, 82.2904162253103, 90.3071132782967, 95.62355656777659, 88.20904531786519, 82.8984542046824, 76.09021586756553, 65.73588817350327, 54.31753912279683, 39.780462557269686, 45.80193227337253, 31.640314786664902, 32.66360821262483, 44.09375575280959, 44.24049162095593, 61.67237543290662, 62.61866292645855, 73.33685321192588, 73.50728804065336, 74.97576067524572, 73.61496494662377, 59.066431137823294, 48.68327402299451, 33.09890108723795, 10.098372447875239, 0.5689692725577663, 0.053142370175450086, 0.04084348355630233, 0.01210648650979443, 0.04760004963064867, 0.11526353597160309, 0.0378154942225064, 0.028436913703297897, 0.09746090133464146, 0.03155544888408434, 0.03296383258496081, 0.0076662231848815526, 0.00534383578210949, 0.021247975265366897, 0.01246075908232841, 0.035841254998118646, 0.06709857693602962, 0.05424300486582422, 0.07859546525944626, 0.04727239765587354, 0.03711042903183449, 0.09336646781453202, 0.1206142464352231, 0.003710093432962294, 0.07472635351962621, 0.03111248918538613, 0.0015333832749503575, 0.011914574781492835, 0.020035687090468504, 0.0212621498071859, 0.03200787934474647, 0.0425844528381863, 0.015312135463670619, 0.05644622394033978, 0.027184541892981338, 0.02187046575390043, 0.023430921738186193, 0.05846354411914945, 0.017422902089874112, 0.01984933620288728, 0.03686324310218615, 0.02722526712703609, 0.06878366393427696, 0.033344991970807314, 0.002980094953184767, 0.03820986096416751, 0.005245859361058402, 0.04202589813259341, 0.0655154715622625, 0.010089569484754916, 0.058319588537297906, 0.03689627681348113, 0.051358224178153666, 0.034029575800823594, 0.06418678398814893, 0.03750565379197079, 0.07409041627280175, 0.06759186095047383, 0.06863915676911993, 0.04481298728815971, 0.08465447763521826, 0.027043891980523066, 0.0335750405135895, 0.012413422509487118, 0.07509542403802758, 0.03928143410913406, 0.03891650429596344, 0.02912670501597947, 0.01839306817630366, 0.04803163675411094, 0.12877024830349032, 0.06262922764665659, 0.14729097545627626, 0.17505262287393694, 0.2714009576987836, 0.14821172121071047, 0.15920663042174232, 0.21462616630859915, 0.11149488900217319, 0.15565565967511746, 0.18513279245986095, 0.1677233984153117, 0.12647380015902943, 0.14783730339859763, 0.23332700073238344, 0.18165178086248138, 0.12791714811277005, 0.10283428033994091, 0.11064800178451885, 0.10744491156430976, 0.22333856251451278, 0.18366095369621632, 0.24729912680002952, 0.11750452701122531, 0.17936473261685143, 0.12230689472128307, 0.13247684215105351, 0.08167742931794736, 0.11545419227331878, 0.15923129845290415, 0.10397156850705225, 0.17571685174780508, 0.15202487788854108, 0.16340807110311525, 0.20277484740701415, 0.2768339306837128, 0.1164424303738821, 0.07969159918326525, 0.2106320596630535, 0.21714624317903675, 0.15077845283573674, 0.09338819406806462, 0.13469394656919664, 0.14168636813279123, 0.30077629272014866, 0.11399550723933405, 0.16590389362987013, 0.15926387251144455, 0.13953690927836204, 0.13928434541148527, 0.18669596422583828, 0.14436910079131204, 0.1259043899875495, 0.12399362880856761, 0.1145653464200516, 0.12205374862758384, 0.18699040245865622, 0.19332476981705238, 0.13479329285121736, 0.15219888709966214, 0.1760210192972614, 0.2533125492834276, 0.1710949207265531, 0.15283654804431623, 0.2777727254696431, 0.2696143487288106, 0.10425543472651513, 0.37086785260227423, 0.5479546227762776, 0.9289161127901847, 2.879662975188225, 9.714569507106658, 13.797454833984377, 25.055604480927993, 37.76001830254832, 50.55594690384404, 73.93925866773053, 82.62576318556263, 86.44393167188092, 91.55879651346515, 98.90165390506868, 103.51949168789773, 95.49903700428625, 102.89503466698432, 106.56179181991085, 102.12656390282416, 96.00917262415733, 87.61621829002135, 78.06743560298797, 64.40865616644582, 50.477291614778586, 54.960376370337706, 41.76266370281097, 41.811469754865094, 56.042417095553496, 54.73883698063513, 71.81787613899478, 75.25358999929121, 85.36518573760988, 85.85028094630088, 88.66776650951755, 83.87811322366038, 68.79074773480816, 57.72524333769276, 35.35991607173797, 11.387113255839195, 0.8695830320638995, 0.22334502829659372, 0.1216452015984443, 0.12002156251260351, 0.1424953416590729, 0.2571395261874122, 0.14975589399616565, 0.12168251774123601, 0.1566110172819707, 0.1581152155995369, 0.1287680419702684, 0.16037299928645934, 0.12418542658129048, 0.14900970903615798, 0.11839732587818178, 0.10379534530183, 0.2732487924156651, 0.17344226009182392, 0.18947045889592942, 0.18133861944079402, 0.11811572727897476, 0.14326682284234032, 0.1988309961293013, 0.14056245586083782, 0.16117015973694865, 0.1441629005656127, 0.17056526285746407, 0.09888466808103746, 0.16195720782683742, 0.19013055089500644, 0.08772449838297983, 0.12295885086660424, 0.11125092830268607, 0.13675735842797065, 0.11162448809632372, 0.12924707674932095, 0.11734400860845082, 0.1393658724883872, 0.11189019803198115, 0.12495490061419627, 0.12339316909351658, 0.16418915902895315, 0.3532450724272959, 0.0829191505908966, 0.151304678630925, 0.12021846243090208, 0.106919742970457, 0.16333003738714805, 0.15013466318768842, 0.12391934126255014, 0.16188753979100337, 0.16583938902664572, 0.17936937510967257, 0.19334405991098574, 0.14173956527825327, 0.1674794606984623, 0.18181941622207243, 0.10415666301043765, 0.18749222069257693, 0.21059419959783557, 0.1292656773641225, 0.2063165638115137, 0.08528699046902119, 0.12224634313174795, 0.15272998521404882, 0.15448293228062893, 0.16058028735701116, 0.12202980837995007, 0.1004603653845768, 0.20628138505403074], [0.04955502557418039, 0.02608125270794957, 0.052909575207459356, 0.05545471464433978, 0.02860707906825889, 0.06304595266438781, 0.06667326790310683, 0.01219469866144561, 0.06609612024359166, 0.03772761244627257, 0.02668969888961123, 0.05554634259052335, 0.07341471140182788, 0.024920503098157146, 0.01718857686125463, 0.041559262486595305, 0.04831029740612834, 0.005054499694867241, 0.014897465476796273, 0.039768313628531275, 0.03789433616123373, 0.040120227607868375, 0.07143292621138596, 0.026094373878872684, 0.03244680750574316, 0.0498859832183488, 0.0337672749564292, 0.0217838020574662, 0.024056445934899875, 0.0183634014214359, 0.04034798554775696, 0.01976228180161167, 0.07846154542940278, 0.018452926456267317, 0.007607672042438701, 0.060080238617956645, 0.020592625350541165, 0.026374536063221675, 0.06098202752670454, 0.03201571259377224, 0.037435097094144554, 0.017241544180339383, 0.09048417691261539, 0.011312381792513114, 0.028452877060420094, 0.04583912758877681, 0.02788769377906236, 0.017641890238249497, 0.07045867687632, 0.07244726492752952, 0.02692328101294416, 0.042372108587334235, 0.06789389877550064, 0.0385711518596978, 0.015556760744432048, 0.07964436986273335, 0.07461837342669887, 0.028894354378984823, 0.10414878762657605, 0.1207446805652111, 0.041614597017366084, 0.06019573403342117, 0.16542279041342198, 0.13119264896358215, 0.09616992060816097, 0.14859893269115879, 1.9467158303145442, 3.641112696739935, 5.592716903455797, 8.45568480030183, 17.37418966908609, 32.24425388920692, 48.54302967748335, 60.59805785456012, 68.90925038245418, 72.73474585625434, 72.52871944058326, 75.11500481636294, 64.97623881986065, 66.92742578444943, 65.291464021129, 66.64557210860714, 66.71149930646344, 63.051959314653956, 50.67305711007888, 66.35665032171434, 62.166864718160326, 70.4655997983871, 68.40721053461876, 74.79315865424373, 70.62749170487928, 68.2981215753863, 71.84229681568762, 66.10961160352154, 66.63236156586679, 76.34615052130916, 77.2894177898284, 73.77140475857642, 73.8369083404541, 72.72489286238148, 71.63827865354477, 73.75482097748788, 73.0324302181121, 67.56918830256309, 62.749760304727864, 38.108262015927224, 13.577443207463912, 2.6709835663918526, 0.2916911028085217, 0.15303704857585892, 0.05961844464764, 0.004387662291616923, 0.06393767134737104, 0.05522172049348874, 0.05263145464742857, 0.06974243063239322, 0.02473327887034224, 0.0486679838579749, 0.03763851259023913, 0.02906626642441317, 0.00928162634673138, 0.047068576133179094, 0.06690314024566643, 0.030896038703259923, 0.032790589461764025, 0.05544502746253725, 0.04489297452833384, 0.12962864982264657, 0.024201426159350142, 0.017585052259927316, 0.09236203461524942, 0.0017919086225916662, 0.013924398789963415, 0.05611053953367857, 0.025603081693031618, 0.08081798591921407, 0.056924446666192625, 0.027334626178227128, 0.003773967928868989, 0.03842062324345593, 0.03442223033597393, 0.06663254266905208, 0.03474555391397688, 0.058019377831970496, 0.019188018463131402, 0.026090792417826674, 0.05779933439747942, 0.04169869814969359, 0.052338606047053496, 0.11465295623507231, 0.05497597097869843, 0.02985853348828612, 0.09637130980169582, 0.01111654194837977, 0.0505414174028462, 0.061806889716535814, 0.025568663277813507, 0.04638464347789845, 0.06174266856584338, 0.023273297232545676, 0.020339699507120158, 0.00916822043608033, 0.024912259992091887, 0.021483418982355826, 0.060969613071891575, 0.10377289892564859, 0.06838440955165895, 0.01921857387999133, 0.03464915707046467, 0.03731625387445092, 0.02539440891855667, 0.08279551166079699, 0.05241676233708859, 0.009570756547843978, 0.012726654794307487, 0.07464473451217336, 0.01755672998936667, 0.024300527293235067, 0.052788935511583285, 0.04526626236075836, 0.017585450625647942, 0.08240178843299228, 0.037978655628619656, 0.06364537816074106, 0.05285183899104596, 0.028697374021454204, 0.015571026259192057, 0.011102755238572437, 0.04594440339133144, 0.033354043299632694, 0.04269286960123047, 0.012184584385625297, 0.011106591423853271, 0.023994113190940792, 0.04903068052484624, 0.044676642789835894, 0.045205009800772515, 0.05329297540048438, 0.00873043374609082, 0.020573773841944434, 0.025281596726046938, 0.10876240659384959, 0.05276842350741068, 0.01648155048549656, 0.07815376960582311, 0.02366335856007232, 0.04100530047810847, 0.017972934067309383, 0.026716425782069567, 0.009931696958148913, 0.016457200380823305, 0.02918982108484113, 0.04450465988127455, 0.040553025150251006, 0.0286141864489764, 0.025595122039498343, 0.07464603686164464, 0.060027861186573585, 0.08278344577598958, 0.007033946880725243, 0.02687398325501671, 0.04894656407076025, 0.03863818072263272, 0.014089891018586294, 0.03471897066300435, 0.03067368359845733, 0.03920756408103532, 0.06147072650492192, 0.07214104426243613, 0.07324140699159715, 0.0003308332745819503, 0.01597391189857116, 0.055829450382941195, 0.01563336283359076, 0.04378015903996364, 0.05902878294188169, 0.04077615591907694, 0.08385305007499072, 0.13597715916412492, 0.14173299224386293, 0.25645530241872033, 0.30239892823080866, 2.804583907127381, 4.667175806337788, 8.458002921073668, 13.390591298380206, 23.338671268955355, 42.26414657408192, 62.27240001001666, 73.22006856241535, 82.19416910602202, 86.9873603697746, 86.33542322343396, 85.4865203365203, 77.69150780093285, 79.98013234907582, 74.97421526139783, 75.48951272041568, 78.60676934642177, 72.46251767681491, 63.6309717547509, 78.52663532380136, 72.20530433039512, 81.85201291115054, 78.39301586151123, 84.25919502012192, 80.33750734021588, 79.00201089920537, 80.84890596328243, 76.68014818622221, 77.53671538445258, 87.69772514220207, 88.2119478717927, 83.75832403859785, 83.42445188953032, 82.80226984331685, 82.60175828010806, 84.36309076124623, 83.83511620183145, 78.72648008408086, 72.5435067761329, 49.58349720124276, 22.507974063196492, 6.202813636872077, 0.423620299346024, 0.22597431866151674, 0.06730343650786147, 0.040579240679019885, 0.023323859035548185, 0.05684752760815525, 0.07210011984552107, 0.09907082744663763, 0.031366217505907824, 0.03060550943407561, 0.06405014454597427, 0.034789079199394876, 0.11522071931751506, 0.02381818109912978, 0.034832861124267506, 0.03719985447523575, 0.02102144306615716, 0.03531706699680898, 0.09703409843026631, 0.061175146801096786, 0.08903851537334342, 0.07686589153543597, 0.04899726760002875, 0.024096240372126623, 0.039106436644590674, 0.05767678714267189, 0.044037924643846295, 0.13131497788333124, 0.0433421520996959, 0.024536771572104866, 0.04212446300493133, 0.0526000680251708, 0.05059399401708957, 0.11220039469340157, 0.07794452801106438, 0.07453777331618533, 0.042335152505866946, 0.03579912782316247, 0.1420989830888087, 0.045712477933134765, 0.032331503612259706, 0.06458570129208027, 0.016355216841123277, 0.04132222722194368, 0.0554706645949233, 0.01229549955291253, 0.06802177417182154, 0.0186842811789604, 0.026936712449476607, 0.04352061994253628, 0.03839572538591681, 0.04253433919661949, 0.034428297752334226, 0.03611822259582339, 0.013833773461350752, 0.013673443707727618, 0.08517313448171462, 0.12178070723049103, 0.08641496300697328, 0.03870567689920145, 0.01450529644986795, 0.03790454811326439, 0.006485238798984117, 0.06653312743911821, 0.05020313212768205, 0.07892099134023152, 0.04767922864806268, 0.01718769202970209, 0.15158842227632, 0.08995101036083314, 0.19658646576346891, 0.178730595676649, 0.1634336890833032, 0.21324310181362016, 0.17241213230356095, 0.11563099770536346, 0.16796250977823812, 0.2211406562597521, 0.1870489928631052, 0.1806219901529051, 0.20374161972393914, 0.09016640364162384, 0.12211040082958438, 0.18655143407804353, 0.12068924644301016, 0.08691626796198469, 0.10452275344681357, 0.12365551590318642, 0.1348583796812642, 0.1754712286375223, 0.13692070369518575, 0.08317382119956516, 0.1184107707212529, 0.17766630036696313, 0.2268714842296416, 0.11812072217224107, 0.14466565342680102, 0.12690166792561933, 0.14417727237507222, 0.07690100134500573, 0.11011028467046638, 0.12002461154254214, 0.11493367383316641, 0.15582107337972811, 0.19135154182872466, 0.17172706583815237, 0.18021649981458343, 0.09627320458211246, 0.10470404049321529, 0.12198850857995211, 0.1528947247612861, 0.08856727170848078, 0.14150632214882683, 0.19997710962930035, 0.15572371892631054, 0.10895523092439098, 0.17818722483371535, 0.1512410167244173, 0.09998697667352616, 0.15203290648998755, 0.30855904122994793, 0.25860379600236494, 0.08601071373108896, 0.23170663284197932, 0.12048578881207975, 0.16479047676247938, 0.18499172502948394, 0.17975873163630887, 0.15427048077746747, 0.17495980366103112, 0.30923350503848446, 0.35267902538180357, 0.335822057339453, 0.4649608552215561, 4.047348407968398, 5.928533567536262, 11.634156876994718, 18.95811923088566, 28.400972427860385, 49.31991392566312, 70.71290523775163, 82.07153228021438, 93.63826459453952, 99.74166870117189, 98.4014654159546, 101.18318680794009, 93.09246678506175, 94.94854804008239, 88.98145414167836, 90.63368981884372, 93.23771215254261, 87.25259104082662, 76.2046863186744, 91.30954557849516, 85.59822159428751, 92.01157923667662, 92.14992123265421, 98.04468662508073, 92.27124014208394, 91.2305804221861, 93.77721063552364, 88.5586775502851, 89.56590298683413, 99.87305241246378, 99.6118696274296, 96.0213476611722, 92.84470635075724, 95.67126043381231, 94.35127304446314, 94.04137442188879, 97.61859955326204, 90.14718255689068, 84.37958040545064, 57.35841543443742, 27.703969209424912, 7.000255027124959, 0.5203741704744678, 0.37962794544235356, 0.10778010567469944, 0.12673648404738597, 0.12432993374644749, 0.18743502456815014, 0.18976782358461813, 0.23449241964807435, 0.13390113749811727, 0.10730978131534592, 0.1635547309753395, 0.08620897728589275, 0.1695997622464934, 0.10458560330012154, 0.2666017539318531, 0.13354309864582556, 0.1798594109113178, 0.11805709090925033, 0.14884895314612698, 0.17188725482311942, 0.16354867888073768, 0.13410257265692757, 0.15347387191028367, 0.12532146602508523, 0.130131280109767, 0.19993813107571295, 0.18078067760554054, 0.2761362084457951, 0.18692767517941614, 0.12410625905519533, 0.148397512854107, 0.22492666278154622, 0.15565987315870103, 0.21302024683644696, 0.24807575609414811, 0.22882776635308422, 0.10245082269032156, 0.13022776122295088, 0.26034131405815003, 0.13486355843563236, 0.17009444054095976, 0.32664708192310027, 0.10075420606881381, 0.08901397757712873, 0.20363951552539103, 0.12878230652741848, 0.1346835737387019, 0.12250008677402813, 0.07571031684957205, 0.12489537558247968, 0.16340030297156305, 0.11843310984512491, 0.1513406694416077, 0.12270444072782995, 0.08572478673510975, 0.08189050901320674, 0.1285356108940417, 0.17608345546309026, 0.17807853227901846, 0.12142626133056418, 0.1638382754378742, 0.14008938124583614, 0.09040687098017625, 0.25505265671639676, 0.13738850762526836, 0.18273369619442573, 0.1903572822770765, 0.1353062346817986], [0.017941413379664865, 0.02801133845482142, 0.029787836979413708, 0.009323767885836142, 0.02523071699655585, 0.020151615345610246, 0.04366452572867275, 0.08738551213736497, 0.016485966982380036, 0.07230566889648476, 0.05273529786556479, 0.01152859095694317, 0.11672954480614393, 0.012267679069942285, 0.036790437936302156, 0.06952702202984402, 0.03883845142779812, 0.010194247738728601, 0.05430428423888741, 0.034909427781859716, 0.06688132972246216, 0.04546928332157193, 0.03735297629910131, 0.01457472699844549, 0.05134108296084789, 0.0727444074507202, 0.02731191550171183, 0.0463704593599804, 0.012195719473604715, 0.031525104141403595, 0.03055017873374445, 0.023040308827354063, 0.05640311617284052, 0.0487148224736654, 0.03393548871240309, 0.043806091116200534, 0.04010780932261579, 0.05445928297816746, 0.029143265921682603, 0.03020847287599839, 0.015312559684858689, 0.044305967317233165, 0.03194497011962437, 0.07240832467833835, 0.04589933443874602, 0.13513616316260832, 0.07809128747471879, 0.04453933685116711, 0.05535324246832921, 0.04156017030078558, 0.06241388799202058, 0.012193534207800704, 0.04700517852700526, 0.028957405330372915, 0.1623499044968236, 0.10785166594770648, 0.14775182330800643, 0.09427577587625674, 0.5291347842543356, 1.2280763277123052, 1.3951158547593703, 3.2735714124095057, 3.341419836205821, 4.38532458197686, 9.305399617841168, 12.633117879590682, 21.632895238937873, 23.412837405358594, 38.35785027473204, 53.7676267470083, 61.60923311787268, 65.51762396289458, 71.49414723919284, 71.40114784240723, 67.20043059318297, 65.2743624871777, 55.76368954873855, 46.7895144800986, 53.86320706336729, 51.7089472278472, 48.351986715870524, 51.71648602331839, 63.15019115324944, 42.99849271774293, 50.54333256136987, 55.88013295204409, 41.1179986307698, 43.24926553233978, 55.74799614567911, 59.15692806243897, 65.99894585147982, 68.87922856115526, 66.68783172484368, 67.30207489382836, 60.63974872712166, 64.72415201125607, 67.85182645243984, 67.03372986085954, 61.76654761837375, 59.08221083302652, 56.36547527005596, 63.96221591580299, 66.26207413211947, 68.8272414668914, 67.15038899452456, 65.48963392934492, 62.261923359286406, 39.234123460708126, 8.757681808164044, 0.9616079650098278, 0.6678134299093678, 0.18680206740335112, 0.0268035740291159, 0.12457340414966307, 0.0425510207611707, 0.06481535913002107, 0.008316628480961007, 0.06167003576974235, 0.055934408259007244, 0.08180448500018928, 0.024481691765568914, 0.03697167135654919, 0.0538843761258308, 0.05220850899575218, 0.045201340239615216, 0.07405706846545781, 0.05932447755889547, 0.05567936226725579, 0.06184140963840389, 0.005176185579564904, 0.027651807646297162, 0.02173091134717388, 0.017448715422482743, 0.04895907428656374, 0.009687355129919466, 0.020133671651203788, 0.01822237995633435, 0.06244646205056099, 0.01706223938644173, 0.03524512751027942, 0.04062845416727566, 0.14556347783054077, 0.024271657269808556, 0.023095850201864398, 0.04147437611414541, 0.025286593534533056, 0.0141794141381979, 0.04582572871098115, 0.04489136191325323, 0.01909197785050398, 0.028709696545716257, 0.04325050117087461, 0.0934181327841455, 0.012846569579485203, 0.01920882924159448, 0.04154067719355226, 0.05802015924165326, 0.05715706160352115, 0.04080874529937583, 0.03232676152800841, 0.04169646883383394, 0.020941294947518937, 0.05878242055675196, 0.022886376865508578, 0.01066470424824905, 0.11419465179525076, 0.07547862887863191, 0.0676860131563679, 0.017052529222001473, 0.09328399844948324, 0.10843908684628625, 0.05254404784570779, 0.012649668703576731, 0.04148927269383304, 0.04127405561326493, 0.01847785112688378, 0.01792261549722283, 0.025510973026675564, 0.007560431709392898, 0.025345090093211304, 0.09248633238096392, 0.04480095204686926, 0.08453574166783402, 0.0671312352642417, 0.031536139637952855, 0.026833189073048776, 0.03650132401455795, 0.029925983699579394, 0.042431193118494366, 0.028069522832670522, 0.09038909007945369, 0.04575490771282104, 0.0077952036630332235, 0.045518297626967394, 0.04294325394796268, 0.09031717740600148, 0.01994723649395089, 0.024339230055169716, 0.008868432994331083, 0.024568552729643645, 0.039045122797570886, 0.03199850242855328, 0.022375356000397476, 0.04770147584138378, 0.02862008724121317, 0.0470232620324579, 0.1577058335345599, 0.020876464756926703, 0.04487334352527415, 0.024240462169531855, 0.05208690785953114, 0.03446297089178716, 0.009287279118002664, 0.02698132174930746, 0.038746930733923955, 0.051776925702729536, 0.07222398860199798, 0.08675129858837013, 0.009647533879615366, 0.05812925399251043, 0.07338218330856293, 0.054139816652863264, 0.02220921451225877, 0.032400650708305265, 0.008764811941692907, 0.057367279960383336, 0.06543490209526594, 0.03662529236246501, 0.017260091168986216, 0.07385046987403786, 0.03888547007415084, 0.13438870649664633, 0.1888553822232831, 0.19669096015634077, 0.5484540508158746, 1.4300325488851917, 1.9366464932118694, 3.411195614645558, 4.151628296221457, 6.020816641469156, 10.813211664076775, 15.431505422438345, 25.947639711441536, 34.448514138498616, 52.5521352214198, 69.46989044066399, 76.48133108692785, 81.06946868281211, 83.84521238265499, 84.32990750958844, 78.50404247160881, 74.7909229032455, 65.98816717824629, 59.702929835165705, 67.73317475472727, 62.58503252460111, 59.95918612326346, 60.58743215376332, 72.62461354655605, 52.698059158940474, 57.262631154829464, 66.27345685035952, 51.91850769904352, 50.51764495911137, 66.38740954860565, 65.8562421798706, 75.3317863710465, 76.96104480374244, 76.70926786238148, 76.95082310707339, 70.11076650311871, 73.98517393296765, 76.58151626586914, 77.97555015933129, 71.15353645816927, 68.99739388496646, 62.81894306982718, 72.50004691462364, 73.90754238251718, 78.28726091692525, 78.09683768979966, 74.91217121001213, 75.11896641023698, 53.178133733810924, 16.482921261941236, 2.767808254688017, 1.3814318083947705, 0.2924629823575097, 0.12955288372693524, 0.03145394223411718, 0.04781648096057677, 0.05078715542631765, 0.05741672710545602, 0.08729895186280051, 0.09519303593063548, 0.0613035814416024, 0.04744714231140191, 0.05303559667100349, 0.034500459404361826, 0.08246019497633943, 0.016762352353262327, 0.030483347138450034, 0.06791308161712463, 0.03503251129821424, 0.046630205301147316, 0.04102545625139629, 0.01240155676514992, 0.06602422289189792, 0.0647681527921269, 0.07193176436328119, 0.05478974649562471, 0.03287814565063004, 0.04344880686051423, 0.07147426431578013, 0.019763620540259347, 0.06238069723270113, 0.009752019653998075, 0.08220504173227856, 0.03295915561818308, 0.10492721722731668, 0.032614465847971945, 0.014925500464385316, 0.09845231870009054, 0.08193327204114007, 0.03971657971100461, 0.0651371926670113, 0.038151753195110834, 0.05209020586804517, 0.0802505752372165, 0.04773833999230016, 0.03696201864870326, 0.04176474642008544, 0.03880736357983082, 0.017028602380906383, 0.03286959610939507, 0.0639490822270032, 0.08703766225446617, 0.039228838342692585, 0.03822091561291487, 0.07819264856798035, 0.04886206840315173, 0.049549674450029293, 0.08759505250641415, 0.02539187125230749, 0.061059563285520965, 0.17476789863599887, 0.0552743852078434, 0.20061852440478342, 0.06756341610584529, 0.024273133904282606, 0.10426712522823965, 0.07223619238263176, 0.11418006548117246, 0.08353414299387125, 0.20704713589962453, 0.05796048482279143, 0.1860910612008264, 0.11679301519067058, 0.09431776515538655, 0.2834930733567284, 0.13017712281115595, 0.18929841086989452, 0.13317995764795812, 0.15308984735560033, 0.19462845228131742, 0.11386499650055364, 0.190456843063716, 0.17490804676086674, 0.15499780465277935, 0.15721783552679325, 0.14622458106567784, 0.18529760861589065, 0.12968552419014517, 0.12844330496004513, 0.13361296586451993, 0.0962218996738234, 0.1586084996139811, 0.1558757260922463, 0.11052586438675081, 0.15642565464781177, 0.11382079322732265, 0.10375432129348479, 0.15237009242898034, 0.07767367762543502, 0.13236592794137617, 0.20501735530072646, 0.18202527936908508, 0.14691064344538798, 0.07488157825484391, 0.21552851063109216, 0.10340031206367478, 0.14922959159218496, 0.19382289550717802, 0.16623591613625327, 0.07072904462655706, 0.19932207381052358, 0.1757878527766274, 0.229819237344688, 0.162357488767274, 0.14531016319749818, 0.16299039996679754, 0.13712940136751822, 0.16599898046303183, 0.12013315854053344, 0.17393335309480468, 0.1393950297947853, 0.21543233595307798, 0.37093499254795814, 0.4404953777069046, 0.7561450223288229, 0.9934519111148774, 2.46480712006169, 2.9286700487136845, 5.161508687080876, 6.591575924427279, 8.71913569588815, 15.608835777928753, 20.342702173417617, 31.66603376788478, 42.288653542918546, 61.989102901950965, 80.76048789485809, 89.11490886442124, 93.66100649679862, 96.96862359200755, 100.42329034497662, 93.76338035829606, 89.07331605111399, 81.1025970212875, 68.75048068261916, 76.5980137548139, 71.77851123194542, 70.89378141587781, 70.93224417778754, 84.53613788850846, 64.56738272020894, 67.21209572207543, 75.77013477202385, 64.96142402771981, 61.79183906124484, 79.28877538250339, 79.2738389968872, 85.56688970135104, 87.65431234913488, 86.30941006445116, 88.61763077397501, 80.1168740180231, 83.7814111094321, 87.37041119606265, 86.35188933341735, 83.04480568055185, 79.45263631882207, 76.65118540486982, 86.32699012756349, 85.45986390882923, 88.59066055667016, 88.93578206339191, 86.96308089840798, 84.68040266344624, 60.11977580285842, 19.1808549434908, 3.203421292766448, 1.2355478300202278, 0.3757635221606301, 0.21943635577636383, 0.21647777017806807, 0.165519654570568, 0.11301303011996132, 0.10349498520935736, 0.17950196960760703, 0.18616811432425054, 0.16271820892730068, 0.13234720475250675, 0.120280553857165, 0.14843235453290327, 0.15990646706233103, 0.26470626854608137, 0.14960963248966203, 0.12991406353971652, 0.15467997009475387, 0.17828487040054414, 0.13341747554800204, 0.12032877143111922, 0.23229518755068704, 0.13889616866025234, 0.1815108819714477, 0.16338574730100172, 0.09839046476108414, 0.11842013997656685, 0.13452562173047375, 0.19026936602688607, 0.12744729106705036, 0.1287675823175138, 0.21098533344845619, 0.09429144237430827, 0.1653089344261154, 0.15256213534983898, 0.08900711342932717, 0.1181013095042398, 0.20744735555302715, 0.1741377759965197, 0.11249998869794993, 0.11562786440575316, 0.16864392966512712, 0.2540574165722055, 0.1508935039202052, 0.22384012027853922, 0.17605633595057074, 0.1579308335579211, 0.1337254275718043, 0.2151304666673945, 0.11898950418277134, 0.1532241732122437, 0.11104743236735945, 0.16524910295922912, 0.12023811258615986, 0.1265047041458949, 0.20956476128870444, 0.18724701126977322, 0.18853039240404484, 0.2844813574225672, 0.2027514817253236, 0.16382220291322278, 0.2543836780973981, 0.14513094458849202, 0.07890399951007097, 0.18618429410121135, 0.15448801910444615], [0.09216350292967213, 0.027816212030067563, 0.01548286869130548, 0.05812045164226044, 0.06788528794723173, 0.006202322049742385, 0.044878031983370745, 0.028219197260876818, 0.047158120320208614, 0.019036673963250175, 0.02477547690843142, 0.014252143652899372, 0.06419427249760878, 0.014261320428622347, 0.028940953592198993, 0.07579392768562802, 0.019958938486994277, 0.03405830409798411, 0.023435658076778058, 0.04765164565234896, 0.03790590025845074, 0.017471493131691412, 0.010234655046294774, 0.10209492888421783, 0.052810424277859355, 0.030976430054814107, 0.043459367382550435, 0.06807045905940956, 0.012689512936518559, 0.0223127551256649, 0.036297705505163445, 0.04682761849835516, 0.02631808878974088, 0.008806127063449352, 0.07224566889025512, 0.0376442161148354, 0.06188206975498508, 0.021060362247930422, 0.07552287811713834, 0.08100311872699568, 0.035331649480447654, 0.041750520167331544, 0.054434404272826455, 0.014662929573997617, 0.030819640585011056, 0.021617689297624657, 0.047547909686522144, 0.03697651686267026, 0.103253950965741, 0.048622830635717804, 0.08477731983387664, 0.004386398725346813, 0.1006639302678166, 0.2703951148977203, 0.6302630480739378, 1.2186652133541724, 3.3614325042693847, 6.8226986450533715, 9.5110632142713, 11.880726871951936, 12.265670241848117, 19.431290434252833, 19.881543228703162, 30.033176560555738, 37.54900263201806, 43.42647429435484, 52.51061693314583, 66.21812789670884, 71.50218809804609, 68.55458182673301, 62.37680565926337, 61.160200180545935, 63.0111195964198, 49.245906645251864, 37.155894848608206, 43.6654015510313, 34.39810383704401, 32.68207277021101, 30.29633425897168, 39.56531270857781, 38.65150244005265, 37.105978765795314, 38.29674366981753, 44.71719687984836, 51.05821424914945, 26.747454135648667, 27.16054443390139, 28.549385109255393, 33.452263493691724, 38.212126378090154, 49.56291652494862, 45.11416819787795, 42.07852432804723, 38.01456051488077, 44.21627098514188, 44.53507338800738, 40.40790842425439, 34.340868611489576, 36.95910169232276, 42.689837486513206, 36.099792757341945, 42.41911157484978, 43.262978138462195, 47.91707431116412, 51.3693876420298, 57.092192403731815, 68.35838487071376, 71.40772173481604, 59.670091752083074, 32.61862647148871, 15.564566927571452, 9.179683731448266, 2.030881314027694, 0.43623761424133856, 0.040234336404189955, 0.023667911037562356, 0.009700491622601067, 0.08758065771431693, 0.055856466473590945, 0.10018043685704471, 0.07863197700991746, 0.029078834096810995, 0.05053210177368695, 0.06955640916261943, 0.03996346303592286, 0.0015204059849155227, 0.0786964126652287, 0.019682838483863783, 0.05035324705644481, 0.025610585524249944, 0.009039116426250868, 0.03687275791420572, 0.013255797469267442, 0.06654932253783749, 0.05864681533327507, 0.04346429715834318, 0.00886693625004902, 0.062191806763650916, 0.05188058889020355, 0.10200751059117819, 0.02909448144266442, 0.04316624682096224, 0.03649255996870418, 0.05832219323624046, 0.040216218424780716, 0.031083684279433185, 0.016146467457855904, 0.0381283377177052, 0.044940115748754436, 0.06341142639998468, 0.007465046580745689, 0.012396091685420083, 0.026611318518858285, 0.028956554972776966, 0.065577233570718, 0.014813514689223902, 0.019145056252337752, 0.0512147474012548, 0.02129331617916544, 0.08714113008951949, 0.025067241494393638, 0.03385510693694796, 0.034364490289120905, 0.0548837416534943, 0.0359429570005065, 0.049072305912212025, 0.027963936764506564, 0.050338921212260766, 0.03238230290251874, 0.04336122002813124, 0.12769432377911386, 0.025029258855107813, 0.036883919815262484, 0.05311305582102749, 0.07636883070752506, 0.08340953879298703, 0.11973140671128228, 0.015654781694343735, 0.04962483150584083, 0.027926183951598023, 0.02559407441426189, 0.016896682040345286, 0.017074653841254693, 0.035229380572995836, 0.020467875592951334, 0.035232111676445896, 0.029943864191732103, 0.05427098239681894, 0.06627339298927015, 0.0442504565862398, 0.03507074674651508, 0.11199777975918786, 0.013450742905749189, 0.06020451723147304, 0.031895731733511054, 0.05402645479226786, 0.061039461138387846, 0.029533007407500863, 0.036158687359983885, 0.028644866355124022, 0.05918994102807296, 0.06539098993544618, 0.056809449207878886, 0.011190906103189674, 0.023968144725527496, 0.029528234679732594, 0.043332265735033064, 0.03696639684119052, 0.05236359966558315, 0.013364075378875339, 0.06688780316542234, 0.039993976317946954, 0.04108012045523332, 0.027841699775308374, 0.04683662386190507, 0.03315268091917519, 0.014234840599519592, 0.016444739960734884, 0.05510277385192533, 0.0093086548863099, 0.012038141890849558, 0.07597321524254738, 0.07415939482950396, 0.020603524866483865, 0.03462201457530741, 0.031057734966217995, 0.01769224902795207, 0.04749502280666944, 0.008666919311508536, 0.23094019251725367, 0.7418261648666474, 1.74151593158322, 4.570914468457622, 7.6480908451541785, 11.81518602755762, 14.541864798915002, 16.342711237169084, 23.40330016228461, 22.503010303743427, 36.853695838682114, 45.6464102960402, 52.43223228762227, 63.346164534168864, 77.48529311149352, 81.44846377834197, 80.68157765173143, 74.17777799790906, 71.7332157011955, 74.41360658214938, 64.25193394384077, 48.64847475482572, 57.90210300876249, 44.46353720080468, 37.32650226162326, 33.24270694486557, 45.63135231694868, 47.977859281724506, 54.69379640394642, 53.31526371740526, 56.95729817113569, 66.09069008981028, 45.255436282004084, 40.29794869884368, 37.22204954393449, 49.15151872942525, 50.71044122019122, 58.10806274414063, 53.171414713705744, 53.163711178687315, 48.4524582278344, 52.01958717838411, 56.65051783284834, 52.99562192732289, 46.32131291973976, 45.129641948207734, 57.29548492739278, 48.51676156443935, 57.24689460569813, 54.072587105535696, 58.9142902435795, 59.274301067475356, 66.90544482200377, 76.50481823951968, 80.00330571205386, 71.6763727126583, 48.30034479018181, 24.980549927680727, 14.373143065360285, 4.3325647807890375, 0.8449979222589924, 0.23919079092241105, 0.04271531597741189, 0.03445293130953947, 0.016541707539750684, 0.01545905963622875, 0.10277149177366689, 0.04207457152886256, 0.03395648718240761, 0.07749312602344059, 0.014169598636668057, 0.04958659988797961, 0.08634736340853476, 0.035062990106281736, 0.00924133107952413, 0.07790810053026484, 0.01578310237927062, 0.04188519076354081, 0.010439537600764345, 0.054276674430096344, 0.057873545334704464, 0.0357161988053591, 0.022863802169599844, 0.017043075697015853, 0.07926343264238489, 0.0719049895903276, 0.061860178792548765, 0.03353128923223384, 0.033424665114932486, 0.06239140714188257, 0.08598626786542517, 0.03271571585848447, 0.010076518219354893, 0.0390835497678528, 0.042864212826375044, 0.06429680187495486, 0.04472249315210408, 0.09393963947772019, 0.03172501478524458, 0.02506186738760481, 0.05845758012465893, 0.07104662637556754, 0.06804079613498143, 0.05442756310766263, 0.014511204902983963, 0.015022167353890838, 0.08981310687358342, 0.037145205593157204, 0.09454861042960998, 0.10302184930732174, 0.02930037331797423, 0.013070523892829736, 0.03299667094383509, 0.02366630991380061, 0.027095330954198877, 0.03717977914117998, 0.01808676515675841, 0.011044793026221376, 0.017843256449146618, 0.017350552746305065, 0.030166089061587572, 0.03632033574244669, 0.04552533031411229, 0.22857223006506122, 0.15247564402318772, 0.09992843989523188, 0.15568637980088113, 0.1984369664663269, 0.13150711273474078, 0.19795224731487615, 0.18369127545625935, 0.08966551237409154, 0.12821828961492548, 0.07525189749656186, 0.19114076039723812, 0.12119019133669716, 0.09044100785808218, 0.08796393916371369, 0.13078452328280096, 0.18062223530104085, 0.11140895691970665, 0.1329971690692248, 0.17769067728471372, 0.1673143381072629, 0.08607888023459143, 0.21228146228578784, 0.16071367858638688, 0.2107737859290454, 0.0894344142908531, 0.12121803097186551, 0.16444800481680902, 0.1833320874720812, 0.15269538868338833, 0.16662030841314024, 0.1663664268750337, 0.15483280463564783, 0.10736286354761933, 0.2594896387909689, 0.09382052812725307, 0.139534289257661, 0.11317053779719338, 0.16317311193673842, 0.1058007872873737, 0.05415797293666871, 0.20554626240364968, 0.12747456379715474, 0.10439802667186146, 0.08534384185388204, 0.1329466991967732, 0.14999322803510776, 0.19636664449447588, 0.1902956275209304, 0.0809516299576048, 0.10701239364401949, 0.15976187562750233, 0.33926718537845924, 0.5418582789359555, 1.189076201088967, 2.848617905570615, 6.544467768361492, 11.45491534663785, 17.187302458670832, 19.088145802097937, 23.669160373749275, 29.37189240609446, 30.70294087932956, 45.844795934615604, 55.38140358463411, 63.26968223817887, 74.96653526060044, 89.78624605363416, 95.06861179105698, 91.97525024414064, 88.19184180228942, 85.51804050322502, 87.16456520941951, 70.71150887397029, 59.431854832556944, 64.95683093224802, 54.36365835128292, 50.61868129238006, 47.36200401859899, 58.00481027172458, 55.628163814544685, 56.20467770484186, 57.358725301681034, 65.72603910200058, 66.6516282481532, 44.737185278246486, 43.21379946124169, 44.45506880360265, 54.30984735488892, 57.664477978983236, 69.26608408651045, 62.939501039443485, 59.65365702106107, 55.93018239544284, 61.97404492285944, 63.49047637754872, 57.89734909611364, 50.368634116265085, 53.48022683974236, 62.49171933820171, 57.41279909687658, 62.39157338296214, 62.25868740389424, 69.79587862568518, 70.36025278029904, 78.96057498070502, 86.9985705037271, 90.91193491412749, 82.14075426901542, 59.08594885180074, 31.80266953283741, 16.462907368136992, 5.109518160743098, 0.9054305536612388, 0.46488139658204974, 0.1742548801966252, 0.1815253763549751, 0.18517684251550706, 0.21564396008128123, 0.20713635449928625, 0.14101377357878994, 0.11175745031646184, 0.20363251348176312, 0.1996704293114524, 0.15136512296815074, 0.17386002315869256, 0.14891713497138795, 0.089114572582466, 0.15772970483428048, 0.06455213898011754, 0.14276359500663896, 0.0787632768192599, 0.09449304607246192, 0.1615071924583566, 0.13435262375541274, 0.10690335634975665, 0.08880229216189155, 0.1896085539051602, 0.1624954305589199, 0.14148602081883338, 0.08481553996041899, 0.11082521324316341, 0.11508140622848466, 0.20434670661005283, 0.15805394388735294, 0.14824003582039189, 0.19570364136128657, 0.1799782617918907, 0.15179528133763423, 0.13792073954978298, 0.13028085111610352, 0.12861603480433265, 0.13586949316724656, 0.14159638344520523, 0.218203230009925, 0.14613003049406315, 0.09490255837238605, 0.12645975776737736, 0.15385824886541213, 0.1275157563448433, 0.10192535532217833, 0.19855328925674964, 0.22625579468665585, 0.1365225524791787, 0.11379178913850939, 0.11792301020074276, 0.06407424950251175, 0.14519580159216158, 0.10565192108192753, 0.11351324723012025, 0.23734146999495648, 0.12608512545064574, 0.1289189000043177, 0.18556293550758593, 0.17254152455397193, 0.12836647400211904], [0.040491381885423776, 0.035184483990193374, 0.03822772230412211, 0.034367466540706736, 0.020900811031160337, 0.04706668772644574, 0.036288949120188915, 0.04201318107305035, 0.028864637828401984, 0.02699875599524427, 0.08724655910965898, 0.013809483686101534, 0.014686650528963056, 0.014723650660485992, 0.02976184170092306, 0.030737044815454754, 0.01862854253680956, 0.04811694064447957, 0.014179681311361493, 0.05794021030587535, 0.03573992837881369, 0.06128174793576041, 0.012613901973611886, 0.040836703678172444, 0.0502248315681373, 0.049926421169431946, 0.10546196192022293, 0.040094479392733307, 0.03454799132962381, 0.08320244990529553, 0.012625994671496653, 0.041211224912155064, 0.04781467682351509, 0.009732809999296743, 0.04924145046501391, 0.011108817866883211, 0.027679541944375927, 0.0033900175889533374, 0.053789304614427595, 0.06157753065288548, 0.01801244888244377, 0.03511059480989653, 0.03508134174250788, 0.046897301855947704, 0.03968482919698281, 0.023901148421329357, 0.026030401706755645, 0.009553195897399658, 0.05883276785513567, 0.05268554811576202, 0.019415192260977723, 0.2583353281501801, 1.6897031376438758, 4.9942936339686, 12.683463461937444, 16.492272192432036, 19.07982253259228, 29.25270530485338, 39.275606447650546, 43.502642800731046, 48.41761581359371, 47.16021768508419, 56.62809756494338, 59.7313238728431, 68.02915680793025, 67.98070769156179, 67.0372207703129, 68.01069813389933, 56.32894623664118, 58.02575180607458, 46.678315285713445, 39.780701821850194, 31.745775553487967, 16.24069333076477, 21.578854783888787, 27.54121045912466, 30.913548623361898, 46.265399532933394, 40.90432359326271, 34.454201575248476, 24.792517385175152, 15.377311994952542, 12.25494157883429, 15.01857299958506, 14.743278507263431, 16.048834516156106, 21.675400003310173, 19.577675250268754, 16.822337681247344, 13.936146901499841, 20.107130504423573, 20.12969982239508, 12.58454324737672, 16.882465654803863, 15.958833771367228, 19.738510077999486, 16.625668079622333, 33.24778641423872, 46.82807530126264, 17.10952970289415, 21.819921693494244, 21.114371630453295, 26.07914305502369, 32.878891421902566, 35.292965135266705, 50.90630085237565, 55.30694523165303, 55.54587248832949, 67.01942105447093, 63.82956527894544, 58.03335335946853, 45.073571666594475, 32.450466617461174, 15.612033490211735, 5.918273137461755, 2.2318357373437574, 0.2362950398556648, 0.07955262317292153, 0.014463915253028035, 0.14870482136405286, 0.08000571055397873, 0.0685257374519302, 0.019843287938725085, 0.08904006287095048, 0.021792962553820783, 0.061394133034252354, 0.020394806126733462, 0.04689170558366084, 0.08341827985620306, 0.07822755153381056, 0.00762020715609974, 0.07272059743803355, 0.08141102224227884, 0.016348218627934976, 0.06615863301821294, 0.021582370729095513, 0.035273706420294704, 0.03160197148850608, 0.04396501988653214, 0.050496382924217376, 0.01840631766695409, 0.012869384635480182, 0.1238208989642801, 0.016471863303694035, 0.08223655092860423, 0.04777198274349494, 0.047983377045320894, 0.06925332945801559, 0.06245483156113375, 0.040093456665354396, 0.03842895444963248, 0.08682635222231189, 0.048694865883237896, 0.04086628999380816, 0.04615215494507744, 0.08068453340280442, 0.0191278116131622, 0.03789104964403856, 0.05322993019475572, 0.0611140666108939, 0.11112666884136778, 0.02212587755263573, 0.03465789047280147, 0.03638443048863161, 0.03212672831009954, 0.03812343858542942, 0.025198418729668184, 0.041668613876907096, 0.051503175674306775, 0.02703041074827554, 0.030522928986277793, 0.03717195355303345, 0.026455999937869852, 0.02140727367312197, 0.056198157009578524, 0.033353281042148034, 0.03288930755168681, 0.04780850981572463, 0.03695331972032305, 0.019429479800765554, 0.022481585582417828, 0.03735767241807715, 0.06870668741964525, 0.029863739055731607, 0.09582518870311399, 0.05280576646327973, 0.018843976037216284, 0.007642399286851288, 0.059536358326553344, 0.04761508410616268, 0.08861270838326986, 0.08158494718372822, 0.04742840380077401, 0.027561993413274328, 0.025548859904970855, 0.03815126672927891, 0.02521119133058575, 0.05433382841968729, 0.04785985302840991, 0.046784491578657786, 0.03399571471457039, 0.045547117854678826, 0.042007489039772944, 0.039519327392260876, 0.053368860239823984, 0.06699352329897304, 0.04591783163167777, 0.10292296267805562, 0.015429819975378773, 0.05234567703859461, 0.02427907108569578, 0.03706913689271577, 0.0401402761288468, 0.07623357788449334, 0.06240782057566028, 0.012976254858527214, 0.0367499080546681, 0.049143927472253005, 0.06324560283833454, 0.012461864164159184, 0.10591907126288261, 0.07501352157804274, 0.0379218042437588, 0.010891257514876705, 0.07214918777707123, 0.061311671330082806, 0.020142885773713072, 0.6942038718731173, 2.5233583008089377, 6.583023196266544, 15.874204712529338, 19.635602774158603, 21.741648835520593, 35.24639091184063, 45.52635831217612, 48.951956379798155, 54.754279352003536, 55.318316182782574, 64.97871775780955, 68.45409854765862, 76.56075908291724, 79.61738371079969, 79.26287989462577, 76.51843670875796, 66.02703786665394, 66.08195889380671, 60.363194173382176, 47.25686096375989, 43.41930420167985, 29.669300240855065, 31.07366957972127, 34.34385745756088, 46.636420449902936, 62.6399927754556, 51.611986237187544, 46.390982058740434, 35.29640113153766, 24.998565373882172, 26.092543832717407, 29.653459748914166, 28.143005986367505, 19.375394698112242, 30.684099774206842, 32.46988431099923, 28.258866917702463, 24.524688143883985, 31.697261718011674, 33.04263468711607, 22.806862592697147, 27.123583939767656, 25.236362987949004, 29.698051214218143, 29.003776004237515, 41.76524462238435, 57.73310376751808, 27.39487467273589, 36.44670286486226, 32.06598412606024, 38.25998321656258, 45.25469103167134, 45.83367601517708, 59.93624418012558, 63.3551702960845, 65.33232335121401, 72.9114172535558, 72.7199036075223, 70.07228805172828, 58.34177717085808, 42.79778503602551, 22.071849646106845, 10.01240291903096, 4.181769259514348, 1.04708505253638, 0.1594621973532823, 0.03580902567914417, 0.18159208729142146, 0.04824853539767285, 0.04319607062385448, 0.06271627821749257, 0.10107133582594896, 0.03618755355297077, 0.03735423268329713, 0.01216471685291899, 0.0853649705588337, 0.037731381598860025, 0.02326493346763234, 0.025725650015257062, 0.015318082221182845, 0.03573052847998277, 0.01943476197700347, 0.00377462939791111, 0.07166806923886461, 0.029999675612235745, 0.0360736056351133, 0.03062394917041304, 0.04182993284156246, 0.05737034814252008, 0.03376766949171021, 0.07312096264814177, 0.0480570440601197, 0.05534118807484066, 0.05928506999607048, 0.05849850837201361, 0.006802297214181313, 0.03376838195347979, 0.007927788584868634, 0.022523165004508152, 0.060167656910996285, 0.041500733369180275, 0.064202293438176, 0.06286647358548737, 0.04339002493408419, 0.0294815780099241, 0.059527697702569354, 0.025365992802225297, 0.06859447086049665, 0.12663955094232676, 0.06737620719978887, 0.039591071526369745, 0.055160054246023785, 0.016133474606660106, 0.07518497971637596, 0.018385303875191078, 0.03329580146518927, 0.064142802880416, 0.04366835616829415, 0.02342981857157523, 0.025746152443330617, 0.021901745123848803, 0.03293970847622522, 0.04871811282130019, 0.0608062869568746, 0.143737246793124, 0.31242689658557216, 0.09301060465194526, 0.14914668555701935, 0.1414930535059783, 0.13893703179013345, 0.2026782283980039, 0.1529314816598931, 0.16849504813792246, 0.08683241963867219, 0.20117476552484498, 0.1850758874488454, 0.17369752058819418, 0.16446681993622936, 0.19782811042762574, 0.1265633864808948, 0.10090617493035332, 0.25120825897301396, 0.09440689948537657, 0.1042166630166673, 0.13285996272198616, 0.2397086970027416, 0.3010948014355475, 0.154735725973883, 0.11296275176949079, 0.1913267971887704, 0.23588234829085492, 0.14492609267753942, 0.1608098992296765, 0.18493883431919161, 0.1171469018464127, 0.14097402893727826, 0.15732681919490138, 0.09568551555275918, 0.08863247345171629, 0.08416654857536478, 0.07367354952880452, 0.12707260512416402, 0.13003616263308834, 0.20513775367890635, 0.1090760583118085, 0.14166215975438395, 0.14034723111939046, 0.12073253807161125, 0.1480188662366521, 0.16391750425100327, 0.10329038610741978, 0.1868051623985652, 0.11268140597929878, 0.1559900570540659, 0.14123802283598533, 1.2761724307652444, 3.5071666971329725, 9.129599967310506, 20.83237674928481, 27.349194749709103, 29.060524855890584, 45.04893525954216, 55.83039729825912, 59.509458926416215, 68.90754022905904, 69.0758805121145, 75.53556134623867, 81.7859366632277, 88.366057795863, 90.58072213203677, 88.73829072521579, 86.71579899326449, 76.95992300587316, 77.93829548743464, 65.0256802958827, 60.47215369439895, 47.93005735643449, 32.10111483450859, 37.11861272012034, 43.33715015842069, 48.7212464886327, 62.802880963971546, 55.670172399090184, 51.123600159921956, 38.10397094295871, 24.366496993649392, 25.23124625605922, 28.623935637935517, 25.937992642002722, 25.6295786365386, 32.57193849932763, 32.95477359525619, 25.91160293548338, 26.572326191010017, 35.733090369932114, 34.14755459754698, 25.40222433305556, 31.959782031274614, 30.58959810964523, 33.39279643950924, 31.057948720070627, 47.01873779296876, 63.68686160733623, 30.8005412163273, 36.45373175221105, 35.20556688308716, 42.75854172245149, 49.590792809763265, 53.18880258067962, 69.36255870326873, 74.22061028019075, 77.41757731283866, 84.55865229329756, 82.2313061068135, 80.93571585993614, 69.27385822419198, 50.564258406239176, 27.697210965618012, 13.617337634486537, 5.365125296577331, 1.8334689135513, 0.1782690736675455, 0.15270110369930345, 0.38352337996325186, 0.1590671870977648, 0.13269292491097606, 0.0970787153909764, 0.17212037537847796, 0.12158934612788501, 0.1883803311014368, 0.18194595862540508, 0.15023279905078873, 0.18061327207232677, 0.1493156079443232, 0.07279300040775731, 0.19107309951176568, 0.1142454510855098, 0.17029305649620874, 0.12296796731290319, 0.1077291455059763, 0.1716083375316474, 0.12356425950964614, 0.14055730774998665, 0.1397766181898694, 0.19255871253628887, 0.16318204452193555, 0.13724783856061198, 0.13181112706661224, 0.1531110679911029, 0.14245846218639804, 0.22094994633188172, 0.18403851246881872, 0.13063810855871247, 0.1139340363442898, 0.1550350058823824, 0.22283916511843282, 0.22741796538954784, 0.13738887534747202, 0.16828204505145553, 0.27454798560469384, 0.14352459610710222, 0.1643603030712374, 0.059059388154456695, 0.14382119470786664, 0.34257760451686, 0.13061301151831306, 0.253691149935607, 0.21052286149032656, 0.08109839708213845, 0.22956814436662584, 0.14914084796703633, 0.21091243252158168, 0.17772090711420585, 0.09994804408521422, 0.1412236816700428, 0.09889104193256748, 0.1188627855792161, 0.12427512781634448, 0.10260455355408693, 0.17238521197390172], [0.06131429901166309, 0.059750912741066954, 0.034226843441325816, 0.09210701160613569, 0.021155937462143844, 0.03819469242326675, 0.02055132938098283, 0.0550180253753018, 0.024176823245661876, 0.01350590602434691, 0.012361516222177495, 0.02026566477011769, 0.039030758648990624, 0.04154917310863253, 0.08608332354455225, 0.02690534497941694, 0.05545750320438416, 0.04743495768296623, 0.011310816100317866, 0.04635739756087142, 0.044150685125421134, 0.06911190196631417, 0.04511354273305305, 0.025480273968329834, 0.07071874840485473, 0.06069226626066431, 0.05141727040491758, 0.0125765887036499, 0.06407351788854407, 0.01608621081217162, 0.06342969376653915, 0.07809200759736762, 0.052735998836015506, 0.06297397870390166, 0.039690161168935804, 0.021463106161043532, 0.03568463981331837, 0.05104575989647739, 0.061671556454272046, 0.013274716968167455, 0.008103524845454001, 0.025175696561834025, 0.0036449709319464505, 0.009619570712769225, 0.03557469470486526, 0.0498521757582503, 0.06822658011749869, 0.07355786259135894, 0.11528171523804627, 0.7646895380270097, 2.8049415782574685, 9.965836540345224, 18.23186689807523, 32.40942685834823, 35.86420343768212, 40.63291126681913, 49.18773789559641, 43.32401021834343, 55.63929550109371, 58.59509560369677, 62.0509704466789, 60.56021874950778, 63.24938789490731, 58.63481352406164, 54.291322000565074, 50.73961580953291, 46.31020868978193, 45.11745122171218, 36.559988760179095, 30.56854282656024, 29.776335839302313, 14.63493872073389, 12.664405645862704, 25.313900401515347, 54.92700876728181, 43.68782181893626, 15.626655105621586, 13.868492880175191, 12.47403831251206, 18.606598377227783, 20.108083640375447, 31.698132484189927, 24.065853203496626, 22.115242827323176, 33.82464939548124, 41.924371257905044, 50.491702402791674, 23.57186402043989, 26.618931793397476, 26.01587522414423, 14.662294310908164, 14.830529670561514, 14.838733307776915, 15.64418221673658, 18.976879927419848, 23.495897516127556, 17.076874010024532, 24.912151636615878, 24.201229887623942, 18.520478817724413, 16.9253195101215, 21.674725355640536, 23.420325210017545, 15.59978981171885, 21.533441582033714, 37.95082984432098, 28.336602410962506, 49.855431202919256, 48.62989448731946, 54.76054729953889, 60.65466157851681, 56.389676294019154, 61.601074587914255, 52.86168867541898, 38.395222617733864, 30.730911301028346, 18.54840217098113, 10.47479642975715, 2.144697342188128, 0.4537923658086408, 0.07252633286219451, 0.07564657067339267, 0.04422322216053163, 0.05977682949554536, 0.04247423193808045, 0.05774383898824454, 0.031984831589544495, 0.1233577375270186, 0.04750939461612894, 0.0640037426004006, 0.05078512529331831, 0.05632179210923853, 0.015613527859621232, 0.01156431746729199, 0.017931906228524544, 0.014919884082290434, 0.02496006004812737, 0.043431589034416025, 0.010475765898703568, 0.04032942323735164, 0.06239974983937799, 0.013252378801905341, 0.06349657707276844, 0.13067656617251136, 0.050834017024645885, 0.04322156602997453, 0.04969237747812464, 0.04138955102872945, 0.03921483425543674, 0.040174661985328125, 0.08460944698702905, 0.026009184901692697, 0.0144317654156757, 0.08022031476420742, 0.09202677155694655, 0.03882568074210036, 0.03792151313034758, 0.040091514632466345, 0.046924176220331466, 0.04403655334646183, 0.0332666709718685, 0.022456419594105215, 0.03829101265798654, 0.0694898437828787, 0.06702952943141423, 0.0641472078859806, 0.0057453587425932776, 0.02865453246950863, 0.03790294315906302, 0.025891354833278927, 0.02116098023590542, 0.03141490430871566, 0.06916695304455296, 0.020620014909054005, 0.03923300203056105, 0.06792463422302278, 0.05299999656516218, 0.025262369834367308, 0.039136019129786766, 0.04819407420713575, 0.03341243835166097, 0.07706607031005044, 0.056442431805114594, 0.08342798619020371, 0.03334803333986671, 0.05547283262374902, 0.025055372877226725, 0.030635587961202672, 0.03271943138491723, 0.024493964494115884, 0.07299095752739138, 0.09982944601365637, 0.09869516857208745, 0.013452859223640014, 0.002957622003328476, 0.08194082566807348, 0.014465070130573887, 0.04923572395777991, 0.041711399887478164, 0.054319506405942866, 0.01993712030291077, 0.028838127355782256, 0.10219504891504204, 0.039149540581650315, 0.027438785407632112, 0.05720657769650702, 0.019585891972265897, 0.07690664741300768, 0.040779783345398404, 0.013198686572122238, 0.0132319864989709, 0.04739316375625711, 0.04859103798686017, 0.09359237182164386, 0.0015747606413506513, 0.07323796725681714, 0.023432323679087624, 0.01918058166460645, 0.046225101837227424, 0.012664466649444114, 0.05842739243000265, 0.03204949324079339, 0.01801208690589955, 0.016592516406108777, 0.26799490014391564, 1.2044896449773543, 3.8460077537644297, 12.918118276903707, 22.4920335508162, 39.07942125874181, 42.94860409152123, 48.81804273974512, 55.977772512743556, 52.57036247561055, 64.79082445944509, 71.3494510035361, 69.65917618043962, 70.19084561255671, 72.84372498912197, 69.43542065158968, 64.4141161057257, 60.530189083468535, 56.19171034905219, 56.87250829512074, 45.82537235752229, 40.34054563891503, 42.83507500925372, 34.55886217855638, 26.021856838657012, 28.281216582944317, 53.19006950624528, 56.99873408963604, 27.064850368807395, 21.11075520515442, 26.75572837552717, 27.95214149259752, 20.2409755029986, 28.16335132045131, 21.13313428817257, 25.420039738378218, 28.385971323136364, 36.84086576584847, 54.339461249689904, 28.94289101323774, 29.902708722699074, 27.852521134961037, 24.405907007955737, 24.494168181573194, 23.90186086777718, 25.360588373676425, 25.98372747821193, 35.679424501234486, 28.16187062571126, 30.517652034759525, 35.485773163457075, 24.65602086436364, 25.509607061263054, 29.439710186373805, 33.01329143585698, 27.36278380117109, 29.215766383755593, 49.900593373083304, 40.281541424412886, 58.48307663394559, 58.710221090624415, 63.14984598467427, 68.65113489089474, 64.17261185184603, 71.00046988456481, 63.56267152294036, 48.53977411024032, 38.951759876743445, 25.525524039422315, 16.00160917928142, 4.3667212705458365, 0.8744090182646629, 0.31455131968663586, 0.09969584027966184, 0.042900341532884106, 0.06799119960276351, 0.030350938416837208, 0.04840639930578971, 0.050040349935091315, 0.0552980458333848, 0.03958497729693209, 0.0793335909744905, 0.06328339778607892, 0.03167617859529152, 0.09437489999277938, 0.029402500499160062, 0.029546425437494635, 0.014496004760956333, 0.03137750198103247, 0.03654742718584115, 0.08828070885952442, 0.06106364270371776, 0.021822767204514915, 0.022995647816588322, 0.05034030400096409, 0.0715475482866168, 0.05113104463464791, 0.04360400095221497, 0.04280590587445805, 0.09687983130495395, 0.055225512628713926, 0.025753309619763208, 0.01705533118858453, 0.10324843513268618, 0.03693108401832081, 0.07141257125523783, 0.05315998253682929, 0.0576456111945933, 0.013082164598839178, 0.003592535565164121, 0.04669747931221801, 0.04431704494861826, 0.012698074926682299, 0.0251118699464226, 0.02859082842816509, 0.021945245511409257, 0.05601799228198587, 0.014096040789398455, 0.041220770367691596, 0.042190254635868535, 0.0201159194787784, 0.056532033448738445, 0.032720147677126436, 0.06480402868962096, 0.011357654716008374, 0.03647081456297348, 0.06889500715319188, 0.00789627077005383, 0.12293870275419568, 0.09120258352448864, 0.13333190352685992, 0.2927644532774725, 0.1258110958001306, 0.22845048337213456, 0.13176845596922984, 0.20750069059431556, 0.1853988088306881, 0.15605024092139738, 0.1274287747219205, 0.10909501898793444, 0.09363026253037876, 0.13032522292867785, 0.2465850562458077, 0.20330487299830685, 0.1542360681079088, 0.2563670797333602, 0.08894092343266934, 0.14712173131204423, 0.23188991171698417, 0.1627559770619677, 0.11019056302405174, 0.11980142714756152, 0.13358157158138292, 0.09991060536835464, 0.20049348353378235, 0.14941274789312195, 0.2768521635763107, 0.15865900012994968, 0.17423575864203517, 0.16928785720900183, 0.12055732610244906, 0.16797081417133733, 0.07921878503815782, 0.15777871913967595, 0.1696667183310755, 0.23061981454731958, 0.17682579466171805, 0.1424850454373706, 0.1854369140440418, 0.1422237634899155, 0.12362939996584771, 0.13091665812798087, 0.20560551164371355, 0.16822746894772977, 0.2988986112177372, 0.21222661039040935, 0.31366042071773165, 1.95895595415946, 5.626438990716012, 17.35495436576105, 29.387774082922167, 47.643516448236284, 54.33374635634884, 61.18069456469629, 68.0066502478815, 64.0018436216539, 74.61261195521202, 79.04878124114006, 78.94175544861825, 81.33429927210655, 82.06736672309138, 79.52243097366826, 73.62070729655605, 70.97594722624748, 66.10264547409551, 67.27788171460553, 55.383258865725615, 50.669056292503114, 45.53619561656829, 31.833175766852598, 24.225415222106445, 35.267399126483554, 70.41691533980831, 61.58309444304436, 28.98914948586495, 22.96531261936311, 24.542748697342414, 35.244920023026005, 33.59611249739124, 47.100809466454294, 38.535600323830884, 37.40911914456276, 48.185148700591064, 59.13694358641102, 64.72921186877836, 34.43465248230965, 36.779672868790165, 39.377121310080256, 26.3828972847231, 27.539568947207545, 26.201917163787353, 27.302312620224495, 33.306104213960715, 35.73757363903907, 27.266428816703062, 35.37615860662153, 37.423267133774296, 28.625155495059108, 27.71373002759872, 36.892597906051144, 38.477317825440444, 26.650583359502978, 34.84812913402435, 55.817033783082046, 45.22417106936055, 69.77190509919198, 68.4305957055861, 74.5885129128733, 80.32576376391997, 73.27811179622528, 79.20000430076354, 72.24374355808382, 56.741340314188314, 44.76960366772067, 29.447878522257653, 18.458162161611742, 6.354070526938285, 1.1742556479669388, 0.4109807679009053, 0.19918436184525493, 0.13324000361946323, 0.19573859029239227, 0.1568258589794559, 0.17942352220416072, 0.29143210380308093, 0.200711588765825, 0.13988272136738225, 0.16298972580942417, 0.1323773886167234, 0.11056431433967046, 0.19412084242268918, 0.2007599595573641, 0.13583903351137716, 0.12937240873373326, 0.11502529028803112, 0.11324140859106857, 0.1845940028227145, 0.17433521217636525, 0.09313581406228966, 0.10305655309029164, 0.12493019427863822, 0.19622502548079337, 0.17339402719611124, 0.14560314586326, 0.1792396304588164, 0.13263811898087302, 0.18244681158854117, 0.1462577526727992, 0.20109996469991825, 0.12969274073839188, 0.1576759407837545, 0.1329510812197001, 0.19751746177433, 0.2531711447743639, 0.1293650083243847, 0.1312228481495573, 0.12127002535928642, 0.1240029674203646, 0.14231492795290487, 0.28329790479713873, 0.1389136967519599, 0.1349736912356269, 0.17267565122775494, 0.2024713693366897, 0.2042838107914694, 0.17594954329392604, 0.11881783153981933, 0.08988852056884959, 0.09978413957381442, 0.12261925175064996, 0.12018228775911755, 0.12383560785242628, 0.19493556160840297, 0.24882128221854088], [0.05910978524855549, 0.01200010849823875, 0.01732741114533236, 0.06698062237832816, 0.011374694426664183, 0.02864079459780647, 0.028894218398378264, 0.05668820047210302, 0.0521174326328741, 0.03371682806661533, 0.04173692976755481, 0.04049853331619694, 0.05197621581535186, 0.04326724402245976, 0.0596067043502004, 0.08296899993212954, 0.03699669561859581, 0.07173617445533315, 0.06767530324718646, 0.05472657488538854, 0.04735784327250816, 0.03304250981478441, 0.016186855613223968, 0.01535854698534334, 0.020390142566494403, 0.035031929071391785, 0.1001601048835343, 0.018802161043089245, 0.03022879527340974, 0.03506577866632612, 0.049444628473851955, 0.0786265607682928, 0.023522565006128242, 0.04938675819205181, 0.03315946079730507, 0.054373205338995305, 0.0432198959582996, 0.06097817410444541, 0.037867128548602906, 0.04730754960027914, 0.044445517893520095, 0.014847612305123721, 0.04918767492316904, 0.05395228598987865, 0.05575474914944461, 0.021845617692076394, 0.16105259588408857, 0.5083741079415045, 2.2680943723647826, 11.302641091808196, 31.097958857013335, 42.312226987654164, 52.59132362181141, 62.225766951038, 55.94671126334898, 54.54984149625225, 54.05824299781553, 62.93496677952429, 58.69730472564698, 56.53234074192663, 55.54599015943466, 53.37498964801912, 57.793943651260875, 47.15018033981324, 43.65738030402891, 29.981334593988237, 30.084477240039458, 19.631235214971728, 23.22779174773924, 16.558483762125817, 12.929782425203632, 13.708983813562702, 22.815911500684678, 51.63340630069856, 72.25396525475287, 29.363794672873716, 39.82513835353237, 56.509590994927194, 38.018404437649636, 35.46073667464718, 35.6872300178774, 40.58962006722727, 56.016729493294996, 50.79022222949613, 49.091745730369325, 39.23261334819179, 43.34068421394595, 54.756299372642275, 54.35637058750276, 39.41255600221696, 38.641053245913604, 40.03593437133297, 35.48797753549392, 42.85534581830425, 32.82842620726555, 31.103809072125344, 32.305715468622026, 38.872531921632834, 29.247174762910415, 28.31816727115262, 29.298006719158543, 22.329488569690337, 28.922551562709195, 16.423540499902543, 22.94754820485269, 16.458520197099258, 15.620846075396384, 27.242467057320383, 27.903919873699067, 43.02021480375721, 42.30623752840104, 59.40453160193659, 58.2730297888479, 61.14407139439737, 54.01547739582678, 64.33250334955031, 53.93580621288669, 51.01239704316663, 23.792697383511452, 12.202652462067144, 5.256403569252261, 2.110761485753521, 1.2165368372394194, 0.4160926581150101, 0.05383883985961157, 0.09154175363120534, 0.026347439533339876, 0.07001018602280848, 0.0633198520799558, 0.049855604001711455, 0.04251172811153435, 0.09465268347412349, 0.042810651789148974, 0.04235108330425236, 0.09614961927816754, 0.07160852888538953, 0.04970328273972677, 0.08379439838350781, 0.03651224076747894, 0.03623023997211168, 0.012921088867099776, 0.019010014103485212, 0.06787592635279702, 0.04721993978525843, 0.05620723132104163, 0.02666946076187155, 0.026622574265685775, 0.004130783434506626, 0.04028035530580148, 0.06579225912930504, 0.01131855741879272, 0.04575429867292124, 0.00516614456090235, 0.06939148575428032, 0.09241471848180217, 0.11387995053683558, 0.057928826239320545, 0.08189072351782553, 0.07748084563401438, 0.037705238848443956, 0.05413555337356464, 0.014735622699522685, 0.023072702855232264, 0.06272202004648506, 0.0021467629431431456, 0.053690264767576615, 0.02488022219509848, 0.044459514319896705, 0.0651732907300034, 0.01529269406737219, 0.012382429464900447, 0.07556001805970747, 0.019138092513106043, 0.08653170714575438, 0.04297565563672012, 0.06024595109685775, 0.04459143083001818, 0.03979368646058344, 0.05593433931109406, 0.0381499222449718, 0.04317757726136235, 0.038965273453223134, 0.017900718789127086, 0.052375696193907535, 0.040657883434886896, 0.02167228072310888, 0.05461676001188256, 0.049533843243074034, 0.042479012326727954, 0.07110086540060659, 0.004730201748785593, 0.016892177443350517, 0.028192173509347825, 0.06420086851463684, 0.022399367111164237, 0.12846167574846937, 0.06307611737640635, 0.07837156074181681, 0.01172564888087612, 0.02778110796615722, 0.05709544132133165, 0.04686367442651142, 0.015297142165382544, 0.03678077756757698, 0.0389061352959083, 0.03598068683077732, 0.003221610635181048, 0.016646876089995908, 0.052114632581510854, 0.016780725056906382, 0.025647815482150164, 0.04389630563016381, 0.02044858358379814, 0.06215561293966829, 0.01951125202580325, 0.024623758940687104, 0.028544200486653758, 0.048146335438134215, 0.030758727018931703, 0.013448954090445995, 0.022455550084311156, 0.05505632211063659, 0.03117130367055295, 0.8577485670966487, 3.7057864521780326, 15.766314037384527, 39.67604906328263, 49.100429857930834, 60.42612468042682, 72.22475144170946, 64.1063081064532, 65.09005423515075, 65.21358928372784, 73.43553220072101, 68.43416506244291, 63.789404130751095, 62.77189423961025, 61.440402538545676, 62.72872855586391, 57.15240863061721, 51.45979827450168, 42.26699813719719, 39.71164065022623, 35.12200470893614, 38.0651943914352, 32.952451552114184, 20.553974759194162, 9.95159931721226, 12.95090340798901, 38.464644647413685, 83.4785335294662, 42.04126181141023, 36.49288092890094, 40.79575630926317, 24.886646424570394, 30.110945393962247, 31.010084036857855, 33.4383822256519, 44.31058437593522, 42.76269943483415, 41.683957422933275, 42.87487137702204, 37.216758266572036, 35.50347482004474, 43.00555298405309, 39.644332778069284, 29.478920159801362, 32.33479003752432, 33.39545580648607, 35.82740768309563, 36.47999202051471, 34.10255716693017, 30.677729845047, 39.917243449918686, 29.33756970590161, 29.349481944114935, 26.065565770672215, 26.842136229238204, 31.920069994465, 20.039957954037575, 29.26295053574347, 28.608765871294086, 26.521633478903002, 40.091357461867794, 39.185274262582105, 52.299546349433164, 49.75160998682822, 66.86047877034834, 65.63426740707891, 67.86601758772328, 62.93733196873819, 74.4216395962623, 64.95022566087785, 61.363853562262754, 32.78763159628838, 19.49475830601108, 8.839668170098337, 3.379596265092973, 1.5347674320782385, 0.5056289084736378, 0.11698567098186863, 0.03482053476956583, 0.024939816174728256, 0.0925106863160768, 0.028376850494814497, 0.044592890227513934, 0.015744246399751114, 0.04377589576066502, 0.042556831538076365, 0.03194517887858374, 0.07330869249398671, 0.05150587996467949, 0.05833568787502666, 0.09145280316231713, 0.13417437041719116, 0.04345290926134875, 0.006332104047384835, 0.025303370860074798, 0.04336372896608326, 0.018838701521857612, 0.0731764120921012, 0.03157632478002099, 0.04589870624664811, 0.03539752921149616, 0.0547468264196669, 0.03288468804150339, 0.049049154735140266, 0.008853881154209375, 0.03375129819276833, 0.033036990151289976, 0.047443112688920194, 0.08710477155663314, 0.02288913861247561, 0.09165953964956346, 0.0799987085103508, 0.02802130525871631, 0.039950638724070404, 0.024137881081250888, 0.010897859277564191, 0.12079682817021686, 0.03600053999933504, 0.013658073111136836, 0.003387358545648655, 0.03417922341595254, 0.028643242248724547, 0.05062595137485093, 0.00521261114514463, 0.02176241288262029, 0.047803062930583, 0.07235187932007736, 0.13687622463030202, 0.012118729552434338, 0.17423548285038243, 0.1197464450172359, 0.16897225962771525, 0.1717492823879565, 0.1609374681908277, 0.11367257819661211, 0.052787372692217754, 0.16297023653263049, 0.17250485958591585, 0.1764043237292959, 0.26393739206175654, 0.10448407366751664, 0.16556537469788907, 0.09488061761423465, 0.1385736150006133, 0.19335545929929904, 0.13896557622619216, 0.12152552334291321, 0.1316723425782496, 0.19112274200925905, 0.14575087825857824, 0.15031401969252095, 0.09286402904939267, 0.11511446292241735, 0.16951152423937477, 0.08470423504590027, 0.20239551131042743, 0.1241884219850744, 0.18565333388265104, 0.17020936905136033, 0.17687831764980672, 0.1784317447773872, 0.2270370664735956, 0.17683910926984203, 0.12737531710656422, 0.2866327468185656, 0.1993712413335039, 0.21068897999582753, 0.10338720429929034, 0.07446744644473638, 0.059585257718760165, 0.10212620059328695, 0.14304732333027548, 0.2273234454614501, 0.11621343903243543, 0.10467097613840334, 0.19679468846128834, 1.5026313306823855, 6.166519945667637, 20.047432030400923, 48.342624018269206, 57.04651248070502, 69.66832314768146, 82.15912665090254, 76.70940122296734, 76.78667191536196, 73.17862479917466, 82.8343391418457, 76.80958640190863, 74.02868086291899, 73.31367200420749, 71.12733502541819, 75.2005595545615, 65.29719460395076, 63.233843541914425, 47.01360341041319, 45.23116465537779, 37.76336016193513, 37.34891468478788, 30.148506010732344, 23.16602618463578, 20.536555513258904, 35.34007280103622, 65.93622715242448, 83.92297729369133, 40.28493819698211, 56.93368942506852, 75.2033209031628, 55.811973925559755, 52.68065168011574, 50.97170637499902, 54.23124697900588, 71.70446472783243, 65.93514457825692, 67.80036495577905, 52.702675788633286, 55.99183813218148, 69.81440005763885, 70.9686202387656, 54.7693726324266, 53.901316811961514, 54.50957052169308, 48.31200207433393, 56.93281473652009, 48.016977079453014, 42.721914629782404, 45.05536010188442, 54.26579913785381, 42.9586688933834, 44.06966063284105, 43.276118078539454, 39.36640931713966, 43.03710845208938, 28.270855642134144, 35.099866851683586, 28.323515422882576, 27.848296742285452, 42.48233625965734, 42.099481551877915, 60.48270487016248, 59.218124881867446, 78.63278250540458, 75.80078417255034, 81.23973877199235, 72.0431221685102, 83.08309585817399, 72.95972516459804, 67.78674648654076, 38.711153845633234, 23.286148771162956, 11.024088090465916, 4.065880871588185, 1.9169896576673755, 0.7486420797724879, 0.138249192086439, 0.17866869577236716, 0.10102301099968534, 0.242638906704322, 0.24263300782730504, 0.08633181182367188, 0.30388394370675087, 0.1194765522415119, 0.10469089442443465, 0.17478803142664895, 0.16272324978584246, 0.2148242460023011, 0.2860100399101934, 0.2764926538352044, 0.22627531460696654, 0.12047812793283694, 0.0600282940262508, 0.07785154791969447, 0.13754641366822107, 0.11036280257206772, 0.14986340677545917, 0.22628335853017148, 0.07609462485678735, 0.12160977003194633, 0.16214105360690625, 0.10296532734026832, 0.1556317730536384, 0.08650297118771462, 0.20623877524368225, 0.19524746664589454, 0.1480827579695371, 0.16459118664985703, 0.13174343553762283, 0.25867458252656844, 0.31314315815125743, 0.12823766397853054, 0.17107017608659883, 0.1008573827904559, 0.13812939125684, 0.23091606074763885, 0.1592561809886848, 0.14231950915869207, 0.1362029099536519, 0.1472311746329069, 0.17582238802025396, 0.26838686136949447, 0.09048064524728446, 0.17766861395249445, 0.07864198977908782, 0.15755632381525733, 0.22470589156352708, 0.14275987181932698], [0.06619666162277422, 0.04174293972732079, 0.007111466838978232, 0.010755853389479942, 0.0886631169686875, 0.015133563241350557, 0.045701764193513704, 0.011587980008053203, 0.03289800648006701, 0.08136806769236442, 0.06155809117180686, 0.025822414580972928, 0.02077910838828933, 0.10119106770763475, 0.09502949148056009, 0.07433629985297881, 0.07403613894336647, 0.04457038256429857, 0.04477534172756057, 0.008735882546452266, 0.08070225301649302, 0.07488710174877798, 0.09325880181765364, 0.09753921850314064, 0.043752748414032885, 0.054594068487565366, 0.030153733978588736, 0.06209418800989948, 0.027266197289610584, 0.006500060685099133, 0.02652100058302524, 0.034416576607092735, 0.011765231686313788, 0.017672838275170615, 0.055270179385139104, 0.03845905787461708, 0.009796447965556817, 0.11452407726357061, 0.04512145259087125, 0.025792879976272106, 0.021231000672184655, 0.019012534532756097, 0.09111636798949012, 0.050661003727826386, 0.03353697743507163, 0.1373760203921026, 2.9886703000914667, 13.17427944752478, 25.960322695393717, 48.40470729335662, 63.39528829820695, 73.46278482867827, 69.84533186881774, 67.79413623194542, 65.41783494334068, 58.41553341957831, 61.7711603256964, 46.608230375474506, 40.74546367891374, 40.708460038708104, 27.957336671890754, 30.218326160984656, 32.16748722137944, 30.09837615874506, 21.403497380595056, 17.273622059052993, 24.9461527024546, 17.890175504069177, 11.14106591670744, 14.711522017755817, 31.159226279104914, 55.85001699386105, 57.40324812550699, 56.83636757635302, 27.67028389438506, 40.64154048119822, 47.927833372546786, 33.36988979770292, 42.24276181190245, 25.16651734229057, 23.01375977454647, 24.3451867565032, 15.534771623149997, 23.63069368946937, 23.624425741934008, 27.2823202994562, 36.63249377281436, 39.081496192562966, 41.69913699550014, 35.18240136484946, 44.079419489829775, 49.50654422083209, 60.54415664365215, 53.63568213678176, 44.71639279396304, 55.57752209324991, 58.987650332912324, 44.85370712895548, 48.6066387545678, 50.58636880690052, 41.738725477649325, 39.92543728120866, 39.388947256149784, 32.00635821588578, 19.567730080696847, 24.083992204358502, 21.316883602449973, 14.312450270498953, 21.610316115040934, 17.56964921951294, 34.797699220718876, 37.8857655679026, 44.18395457729217, 46.042526537372225, 49.57231844625166, 55.57145810896351, 61.85309863859608, 64.59441961780672, 60.24629969750682, 57.36135721206666, 44.09109246346259, 23.947732986942416, 12.70375584402392, 3.737248028478315, 0.6623219890940575, 0.1329134663026179, 0.11745422567811706, 0.043080908456637014, 0.09504770139052023, 0.04100677136692309, 0.04026966454881815, 0.044757844279370004, 0.015925619631044326, 0.07860419100090381, 0.06800485895045343, 0.020593088833735358, 0.04058995058820133, 0.028587752585149104, 0.038496324221693703, 0.01705385455411048, 0.052347155588288466, 0.026556196577486493, 0.023481426084594383, 0.010255055967718363, 0.05778531115802546, 0.024377187796598, 0.004582259158093122, 0.03954783735436298, 0.06044296209790534, 0.0268409610350406, 0.06516539236350406, 0.076479890473908, 0.09783287532627584, 0.044182937427033345, 0.04288203969237305, 0.07458829681479162, 0.09160679449597675, 0.02853855441865181, 0.017074029479596405, 0.0646159004780554, 0.034309056166919975, 0.02521482067212703, 0.05864361308575158, 0.03562136861165205, 0.01809031980472707, 0.020485133638665564, 0.01889277966843257, 0.046319368956310135, 0.012174998710472739, 0.055016497029892864, 0.04340450782629271, 0.017303417271543896, 0.03155420973686682, 0.036269547943506515, 0.03244405341965537, 0.019572353283424052, 0.11089311927677163, 0.04468796556935676, 0.046014837515089786, 0.015513242162283392, 0.010873902750562036, 0.04153398541553367, 0.03998888949412973, 0.032860537119690454, 0.021175936187407183, 0.052775659207855506, 0.07367566393147554, 0.013198270969423316, 0.046728632277658874, 0.07960908385294099, 0.05376448719612053, 0.033086816509885174, 0.048046360964015614, 0.023778302392231363, 0.023410133942360842, 0.03209556768377943, 0.05764728509670785, 0.07958688262489536, 0.0837932875560176, 0.027966349941468047, 0.02668899025828127, 0.08961374015216866, 0.02561308680132272, 0.020169802272932667, 0.051731063849142486, 0.015545144936280146, 0.011763331788261572, 0.09421216759590373, 0.011798787295007178, 0.02730097959659273, 0.14796372322786241, 0.07828051885289532, 0.014121103355841292, 0.08547140315415398, 0.014184477979377394, 0.01703359152851326, 0.03354764137897761, 0.03256118443283824, 0.0634212936124494, 0.08490495008206175, 0.01812176196835935, 0.08805913324918478, 3.8523622385917173, 19.07660815023607, 32.75501120475031, 57.29918372246527, 72.5797337870444, 81.33844129500851, 79.790250409034, 76.36638210665795, 75.37712112549814, 67.44918730951125, 69.50350515304073, 56.09021509847334, 49.18086198068435, 48.48135432889385, 37.8224467462109, 41.337470931391564, 43.29865601754958, 40.2059926525239, 32.51670172137599, 23.578710517575665, 28.137993197287287, 16.00043050704464, 13.144252723263158, 15.731667741652458, 23.199397710061845, 45.97132767400434, 60.67839976279967, 67.16808672874205, 41.821303136887096, 30.564041906787505, 43.396421094094556, 34.48341538829189, 30.649890822748986, 18.489243022857174, 16.442366896137116, 14.270425015880218, 10.71032593327184, 13.456707750597309, 16.04566720224196, 14.531184184935785, 21.402430495908185, 24.99420762062073, 22.64291144186451, 22.19228602224781, 28.24031214560232, 32.88749710206063, 38.11042716426235, 43.07946220521004, 37.25529555351504, 40.97891530682964, 44.930715022548554, 42.770246075045684, 49.01473391440607, 42.843253151063, 40.605729241524976, 41.12856157364384, 40.065183485707934, 26.74647746547576, 21.072816079662694, 32.70583056634472, 23.177548147016957, 22.553081320178126, 31.648057545385054, 29.96812209006279, 47.54104452748453, 50.13894011897426, 51.2084920175614, 53.463529309918805, 57.25696725230063, 63.815181947523556, 69.80700246749386, 72.87800650442801, 71.12637796709615, 70.6838640089958, 54.47861125392299, 34.241016834012925, 18.891527191285167, 7.248393970151102, 1.6886121058656325, 0.47271547298277583, 0.032148171111100146, 0.035514077997856566, 0.027017707095271157, 0.056850327659518494, 0.06479915637042254, 0.12690894576089998, 0.047922323668195356, 0.05974763005431141, 0.015328465585386562, 0.023022426419981548, 0.04465332690386042, 0.011188074450699553, 0.07126528319091567, 0.04012900697548063, 0.09691792119654918, 0.024560231099566145, 0.04678609653285915, 0.022721340459200646, 0.07532233928119944, 0.07841030180814766, 0.04384703468531371, 0.03305352998957519, 0.04616565341430326, 0.029851228839928107, 0.053221744545284784, 0.05349393558478164, 0.01965920658661954, 0.01722973876542622, 0.031782099826922344, 0.06735144723807612, 0.028531684525190826, 0.05003864538945979, 0.054862256717657855, 0.018348908953128323, 0.02304406457340285, 0.005494734993384731, 0.03819815897112412, 0.012338869705525859, 0.010765620052904613, 0.052108480895478884, 0.012183185317553582, 0.06810229767354266, 0.04225654422395653, 0.07856617005722177, 0.02760711790723426, 0.010428580628227322, 0.034555031677647945, 0.05346234211878431, 0.07740506421654456, 0.05466623397003259, 0.28171538165019405, 0.1147616794332862, 0.12621225008080084, 0.1442026452071244, 0.1956283655618468, 0.2275549265886507, 0.1316472148943332, 0.08970222330742306, 0.12182320212765087, 0.18953055083270998, 0.36680905749240234, 0.08782735334769373, 0.18052576950961546, 0.18716016754267678, 0.18457129597663882, 0.2581298327253711, 0.18992983585884496, 0.1257596529960152, 0.24048687379446723, 0.07128670300927854, 0.16517250948855955, 0.1538402764427085, 0.3109360588414054, 0.16389729485156077, 0.17117365924341066, 0.10445760532973275, 0.14548838589220278, 0.1274663972998819, 0.19414688941211472, 0.09663324292388656, 0.11141577510223274, 0.15215434674774447, 0.139964968566933, 0.11073507533799257, 0.18805550982154187, 0.192919478661591, 0.1197250405206315, 0.30472854032151164, 0.10489900220906544, 0.1071103992721727, 0.10166473221033813, 0.12628096050672954, 0.19159511182337038, 0.12705686201732005, 0.11120235066740744, 0.45437664574673103, 5.45152775702938, 22.7447126373168, 40.5846857255505, 68.75565821124663, 84.00533137782928, 91.55423871932491, 90.69143495252057, 86.993424354061, 84.62804686638617, 75.1898907076928, 79.46243439951252, 61.90859625416418, 59.657681372857866, 57.96089541527533, 41.88004063021752, 45.92014466562579, 46.73478564908428, 45.88278408973448, 33.522685727765484, 26.055714737984445, 34.89426405199113, 26.834899456270282, 19.83596920967102, 26.174223269185713, 50.24634638140279, 73.07001436910322, 74.75988911044213, 68.12290145504859, 37.70763897126721, 54.82341504866078, 63.50318093453685, 44.043314072393606, 51.71749407245267, 32.00863907414098, 29.616207038202596, 31.512004252403017, 20.57357288176014, 29.30593775164697, 29.725535262015562, 33.75319557805216, 46.80314079407723, 48.07536940420828, 55.41934074894075, 46.37055827725319, 59.38445691139468, 61.72488028003324, 75.7832904015818, 70.11366905704622, 61.07085251039075, 72.81632331109816, 79.03663758308657, 58.276771729992284, 62.74393558502198, 67.06167282596712, 59.19560655470818, 57.24509816015921, 55.76071246977776, 47.99125809823313, 32.94313200058476, 35.872197228093306, 33.448019489165276, 24.412767233387118, 35.071327686309814, 31.950915513500092, 51.09148379295103, 54.94960554184453, 61.336773518593084, 65.15530286296722, 68.63734383736887, 73.49451680337229, 79.73005771636963, 83.05927922648769, 81.02673053741455, 80.9621291006765, 60.81229771337202, 38.06965412632112, 21.644005352450957, 9.047493973085958, 2.0493793343344042, 0.5276496768478425, 0.33596173048980776, 0.1695228470188956, 0.3310162652163737, 0.1611231372601563, 0.13663697537154923, 0.18329517735588938, 0.13536750639398254, 0.15309214561937318, 0.12470517893351855, 0.12548648136397525, 0.11186616585379648, 0.12794929316207287, 0.17670928801019348, 0.11857550260761093, 0.1385046211221526, 0.15031869282885907, 0.11928386580679687, 0.17680730129922592, 0.2578749705947215, 0.1327834918253845, 0.1303997019966764, 0.13947910028359584, 0.08475426824823504, 0.16972808197381037, 0.18773110222912606, 0.14611783437430859, 0.1314553558345764, 0.11553190423235779, 0.09479583466365453, 0.17799758742893898, 0.17695314911825044, 0.1794266171993748, 0.08193033026351083, 0.2500367419974458, 0.12287317925403196, 0.11856835500727739, 0.15523136953913397, 0.09458768091374829, 0.1611435918077346, 0.1757332460293847, 0.107185659749854, 0.24481778333504356, 0.07762754381063484, 0.17938155590766863, 0.1759780111211923, 0.18405296088707063, 0.1339668984855375, 0.11433600267815976, 0.1763636291387581, 0.1795441504087179], [0.021717659941303636, 0.01936115050357917, 0.10634360654700188, 0.0375454060943617, 0.02777400441587933, 0.11343781821309559, 0.033023384429754755, 0.10700195186561155, 0.07698814384639263, 0.07476743881500537, 0.019253040175704707, 0.03147181889583026, 0.05572519730776549, 0.05036744266568173, 0.08766362503651651, 0.03183396206417632, 0.039963911197358565, 0.13993838531596048, 0.06000479810961312, 0.04924300179306058, 0.06164218081281551, 0.03196450344647371, 0.032505374927554405, 0.07450901437550783, 0.03578751393023037, 0.04350872642751183, 0.06532663854980661, 0.1472256434780936, 0.07078092410078934, 0.036974804656159495, 0.026371667063945246, 0.023803056608284676, 0.034530302359452175, 0.040891923295754584, 0.0958468996348881, 0.03166713109690576, 0.04079708544116828, 0.01632121785904371, 0.03806558362538776, 0.04959979575247534, 0.04001943341967079, 0.006085894401035002, 0.022951595845722386, 0.06722357184175523, 1.8412958806560886, 9.573358297348022, 29.186097575772195, 54.01772099156534, 71.93691222898423, 71.11762323687154, 68.34038903636318, 63.33891599409042, 65.6510433843059, 56.45302649467223, 49.132342261652795, 44.05334357292422, 28.222147649334325, 37.2717930424598, 34.17395607117684, 35.60771572974421, 23.94261625505263, 24.74487235469203, 25.941764000923406, 26.801170995158536, 31.15938513509689, 44.23960908766716, 50.13286828994752, 76.99374952623921, 53.18380940345026, 46.424243757801676, 55.00392644636093, 26.516659913524506, 20.529775696416056, 16.264937500799856, 30.454819586969194, 31.909612955585605, 17.749672282126642, 9.514648260608796, 6.174390671714661, 4.381671384457619, 5.2649518847465515, 3.372249910908361, 2.9420222870765196, 2.998772854766538, 3.7977652972744362, 4.778314203985276, 3.9026350119421562, 2.1197218952640413, 4.625103483276983, 5.57182586962177, 3.530229743449919, 7.191028325788437, 11.93074885875948, 9.59530984201739, 16.2545745988046, 21.840325863130634, 26.38066153372488, 25.9054369695725, 27.052416455361154, 39.302207962159194, 39.2360258102417, 40.049062544299716, 47.356748042568086, 46.079055570787006, 53.64236977792556, 41.49821750579342, 54.239993864490145, 44.232795930677845, 30.664134910029752, 23.039704292051255, 16.797095268003403, 17.779048873532204, 28.97310503067509, 32.214945939279374, 29.48139321419501, 40.7864720590653, 46.016215278256325, 51.992722865073915, 58.14973008248114, 57.95299968411846, 61.956406024194536, 61.122984732351, 55.69557759069628, 39.91641190744216, 27.50246136419235, 9.164428653255586, 2.2435329806420112, 0.4006872734715862, 0.028761779033248464, 0.06686918722886233, 0.03776865943725552, 0.02953147906209192, 0.025367515401974804, 0.008945153827118057, 0.09434384278832905, 0.03597676063016538, 0.058000053264080524, 0.023885426381903312, 0.0316377860989662, 0.06464661294293982, 0.06111395552814488, 0.01577073676256283, 0.0832369851489221, 0.049208412923279314, 0.08654489917981048, 0.041856163692089825, 0.017366000909298178, 0.015138740080498881, 0.0070187974920225965, 0.016412529793958512, 0.03760263286230545, 0.031169296520191337, 0.04887845885429171, 0.05390521754781085, 0.08946166403831975, 0.03383253032581941, 0.04716641705242857, 0.07597487765334307, 0.08514554765556129, 0.11031105333278257, 0.022405729471375386, 0.03742309249637108, 0.08222728126472043, 0.032945404339942246, 0.04059414108914714, 0.004819403590273954, 0.017602199222892523, 0.016455311974089955, 0.058459510666228114, 0.06334318711812939, 0.020200713920677384, 0.0324393343180418, 0.07010267581790686, 0.0396077799039983, 0.038555454718129295, 0.04467995995054803, 0.077963825765877, 0.0635485408166724, 0.03653857887031571, 0.09967254354588448, 0.08217628279160108, 0.10047639194395273, 0.12651206625084724, 0.08089906100424067, 0.0606188137504843, 0.07650821274446865, 0.040339075945197575, 0.06033598174971919, 0.02092556524721365, 0.08118075919487784, 0.09717315104940245, 0.06431888052893263, 0.03825802491196702, 0.07283789316012014, 0.07202573270807344, 0.016567434687467835, 0.07099787254006633, 0.037102346804233334, 0.037992694189832095, 0.07906757460366334, 0.07537572794864256, 0.006746891341472586, 0.04245625951537683, 0.1331639923756161, 0.07112026274684938, 0.03681679902177665, 0.028639854224879416, 0.022131412537888657, 0.05796822231082667, 0.031182867767769965, 0.08090904312989405, 0.03373008904858463, 0.07173393747859425, 0.033607480506743156, 0.06006988877009961, 0.0761327377310203, 0.024494081322524338, 0.05956156644970179, 0.028031923237346837, 0.09106712385771737, 2.97291315851673, 13.897420360196023, 37.74259121187272, 61.9205790950406, 83.03694525072652, 82.00038833002891, 76.19585314104634, 72.38133245898833, 73.84037571568643, 66.64188508064517, 59.977942897427475, 53.69467850654356, 35.793396811331476, 43.07091928297474, 38.04305653418265, 37.923416399186664, 23.969653152650405, 26.036852059825776, 27.185416183164044, 24.70090258506037, 27.057643013615763, 39.580955120825, 56.15891148967128, 68.97148270760813, 39.733829498291016, 38.26403502495059, 61.71104608043548, 46.648222861751435, 32.529066993344216, 23.145090533841042, 18.970919885943015, 21.222289762189313, 13.328153048792194, 5.985449610217925, 4.5108360148245294, 3.2826482672845168, 3.0514228295895363, 1.7736492137755118, 1.986694833444011, 1.5550395894435145, 1.3463759927018997, 2.35126847701688, 1.492682116166238, 1.2063121987927345, 2.71870312190825, 3.435974943061029, 2.828071059719209, 4.77500323326357, 6.714201963716938, 7.737293877909261, 14.309316296731273, 16.56031550899629, 17.160542088170207, 18.619553965906945, 18.92329642849584, 30.47140140687266, 31.311471116158273, 36.39036978444746, 44.44098357231387, 40.309821713355284, 45.20901503101472, 34.51097396112258, 49.86938307362218, 49.45602409301266, 36.26317908686977, 27.21260016964328, 25.689479112625126, 29.864783325502952, 39.395732956547896, 43.062788209607525, 41.94477542754143, 49.75216304102252, 57.24037562647174, 59.604733297901774, 65.98892811805972, 65.99640415560815, 69.15033494272541, 68.85184257261216, 68.80322871669647, 51.559642207237985, 35.548676213910504, 13.402122086094273, 3.5117414064945716, 0.37836711793657274, 0.00907181688929878, 0.0438776552196472, 0.03811089389566933, 0.06622732812238318, 0.004649311482470724, 0.06060866308548759, 0.01115918048702541, 0.04280187625197634, 0.010031423411302028, 0.05387848874013271, 0.04141609597530577, 0.017673244301770485, 0.061824345029890544, 0.18098853258115633, 0.11771243561299578, 0.04293041814479136, 0.168080318779234, 0.020829562938982443, 0.03646136103798786, 0.05920812412495575, 0.06876281102097805, 0.056616065633152766, 0.054032866948194085, 0.021256266251927423, 0.028287164581518982, 0.10436320031482367, 0.05745566352420757, 0.015741146616487494, 0.07951763593741963, 0.07077319427363335, 0.06888016036921932, 0.04742622428062943, 0.02084973786446837, 0.05058811812271034, 0.02158738668977974, 0.06934570433992533, 0.048843801036597266, 0.016705342005157185, 0.031486060470342636, 0.06781070162692378, 0.05208134989164049, 0.0428904245247043, 0.005227694937568759, 0.013340858126720114, 0.024407273984604308, 0.03626679768785834, 0.03957968745981494, 0.06839971598838607, 0.24459027054329074, 0.09802270425303329, 0.19731210424534737, 0.1774164331295798, 0.16531742268031643, 0.22564677010861137, 0.22288140720657765, 0.16019329038118163, 0.16408397515694942, 0.1919463478148945, 0.26438625829835094, 0.15532201306233484, 0.11099446504827469, 0.21661342902769967, 0.25769114013641115, 0.2263824596640564, 0.18151711792715136, 0.3364120982587338, 0.18743753733654178, 0.22342295476025154, 0.1980470736781436, 0.11372621967307023, 0.12777085596274945, 0.17889380304803773, 0.20070955097194643, 0.20277273300434315, 0.14468759418495242, 0.3515532744988319, 0.10991557576363126, 0.14895206858073512, 0.18597099990133317, 0.09538220602177805, 0.07336228800516936, 0.15081773782449384, 0.33533387547058446, 0.1472287537950662, 0.15010236492080076, 0.13554827250059576, 0.11409545873081493, 0.12268513531213808, 0.18933320658341532, 0.2513930853456259, 0.25319942874052837, 0.2155722236080516, 4.0513953133936855, 18.359026216691543, 45.028554624126805, 72.62159332152336, 94.10705058805405, 90.13049679417765, 86.5409867994247, 80.38193210478752, 82.43650882474839, 74.60031140235164, 65.05993043222736, 62.31369080082063, 44.88865152482064, 53.43011463842085, 48.78289830300116, 50.65216656654112, 35.38462700382356, 36.36196790202972, 38.425993611735684, 39.48053067730319, 42.46771758602512, 58.59149879024875, 63.876370922211684, 87.05164801689887, 68.8945101153466, 65.44633096264255, 70.05535910206457, 40.07565621406802, 30.214452820439494, 26.688118480866958, 40.90310765850929, 40.154182064917784, 20.63369889413157, 12.003754954184256, 8.147567424081988, 5.79742883482287, 7.343700210894308, 4.59781212191428, 4.434162503288639, 4.688695399991928, 5.8871927665125945, 6.824754947616208, 5.334001289260003, 3.2960306588680517, 6.336976347431061, 7.8501434095444225, 5.125407682311151, 9.451888376666654, 15.383022965923434, 14.120482610118005, 22.160357929045155, 27.601340393866263, 32.69765242453545, 32.79781406925571, 35.240711319831114, 50.20238837888164, 52.050554290894546, 54.804917150928134, 62.48642806083926, 63.05874109268189, 70.23317583145635, 54.608182830195275, 72.93331192385766, 58.262223659023164, 44.39019280095255, 32.69351040163348, 29.230534107454364, 32.593178133810724, 43.80578710186867, 48.613883372276064, 44.74445735254596, 58.684051036834724, 63.24095479903683, 69.41854661510837, 76.33994533169654, 74.39663840878394, 79.39596591457244, 81.53022166221373, 77.31121832324614, 59.96333599090577, 41.316219529797955, 17.46885411200985, 5.481624593657832, 0.7764801827649918, 0.10924536374307449, 0.27506917054134034, 0.1427363069547761, 0.14107265509665012, 0.10766912251710893, 0.1292193596882205, 0.1959562971587143, 0.09125281590968372, 0.12345611087737546, 0.10127688487691265, 0.15914854563532338, 0.16001310650139086, 0.16321014462699815, 0.2504004652221357, 0.2415700455106074, 0.14326682284234032, 0.26336570660914144, 0.0988116522409743, 0.12731565417902124, 0.2147415238282373, 0.08990048686222685, 0.18657705205823147, 0.13773444228835646, 0.11080953908423263, 0.16724915934666512, 0.181726704261476, 0.23487639823748221, 0.09933923401178853, 0.27544351174466075, 0.288813891069543, 0.19255019363857087, 0.16274952660164527, 0.12725131811514018, 0.17105589620769027, 0.2440011029642436, 0.13265728650073852, 0.17714244944434013, 0.09802508678647781, 0.11228771339501105, 0.13834205726462026, 0.2727130211649403, 0.19637451987833748, 0.09070078827320568, 0.09000315796583892, 0.19280243574851946, 0.20330744705373244, 0.10145117754056569, 0.11432752974571721], [0.02802389846634, 0.04604554231909495, 0.06769486147189333, 0.04452038766636003, 0.06123961309992498, 0.06958706800134913, 0.06278748609005444, 0.04863400402809343, 0.08665915353283768, 0.02750603452084526, 0.07070836791348073, 0.12337515070553749, 0.020277226952114896, 0.06699758356497174, 0.0558486370550048, 0.02539818381680356, 0.029489621933129047, 0.03301535199786867, 0.060320257795073336, 0.024682244008046486, 0.04556214849975321, 0.04161445912153971, 0.06533754764184838, 0.057567945200829744, 0.05705853503557944, 0.0562558893955523, 0.0939519198671464, 0.07250967044984141, 0.005674353883331341, 0.02804790766188695, 0.0008144754739928871, 0.05375815930986597, 0.036644222395073985, 0.007933955592659093, 0.03602545700907227, 0.014772239787083481, 0.01797456200414848, 0.03712941652103778, 0.03613357116738635, 0.04777778585952136, 0.02619394615683104, 0.03582540080852566, 0.7069730253950243, 5.461815153398822, 27.922256954254646, 48.268208811360026, 71.94657694908881, 79.05617098654471, 71.58126308071998, 71.6702538151895, 60.07568443975141, 56.438866738350164, 40.69237047626127, 38.50016955406436, 34.55753249506797, 32.627102713431086, 32.35522950849226, 21.64560175711109, 35.90379976457165, 34.665146643115634, 24.980661715230635, 31.79546610001595, 47.683771733314764, 48.49599653674711, 50.711649310204294, 40.176586643342056, 28.844982770181474, 33.26003205391669, 37.03750594969719, 30.525945886488888, 20.9011084418143, 17.246769512853316, 18.140654140903106, 14.019443335071688, 11.568556216455276, 2.4972282061653757, 1.0566631127749722, 1.4472696497555704, 0.5409064300117955, 0.06067556937435462, 0.1837062141707828, 0.21856825558408616, 0.03520183588167833, 0.051243724676990704, 0.044770798826169585, 0.0254596317292101, 0.1159568225604392, 0.11459938370652738, 0.13896136274260862, 0.14601363109484797, 0.09662641708048121, 0.056828432866642554, 0.14622890180157078, 0.6232855192595913, 0.13773324719119456, 1.1284895553704233, 2.2957385018948586, 3.0736455080970644, 10.375759524683799, 8.605503651403613, 15.041057986597862, 20.19888847104965, 26.69956199584469, 25.634689484873128, 36.80818065520256, 56.765564872372536, 68.65047593270579, 44.33285167140346, 33.05120506594258, 40.3578785927065, 32.13672014974779, 17.81718411753255, 17.63237576330862, 23.59030112143486, 26.74291006980404, 29.06525327313331, 25.101329511211766, 46.000223775063795, 38.93689801616054, 47.08369616539248, 52.77157222071002, 60.02634102298368, 58.7078990474824, 59.3499400538783, 61.19452876429404, 46.69272607372653, 22.351914721150553, 4.866279238654721, 1.0823651787734803, 0.26139443980589994, 0.0382676508067356, 0.013036875395975527, 0.014832348960842338, 0.016896161100556775, 0.06223847300955846, 0.06824931760709133, 0.014757018577637932, 0.050756492757148323, 0.025134021378753167, 0.020733926437735077, 0.03266470206360663, 0.007159357389149767, 0.0251920678607759, 0.07879735241013189, 0.03258332437384994, 0.020882700712630348, 0.1523394795555261, 0.0767787030687736, 0.140382869529628, 0.009646869298341054, 0.10032750275586882, 0.11285147749848905, 0.02363446172356846, 0.07802708930666409, 0.03468428603223255, 0.05952712696706576, 0.1432462763642111, 0.10655290942879454, 0.08866782840942183, 0.04607455789922707, 0.030398244346161524, 0.021037358542784088, 0.07767026087329273, 0.03463883786612461, 0.0377725588247901, 0.053918175925050056, 0.04528614617283306, 0.08219392579649726, 0.010154347964412263, 0.054640493415776765, 0.03404839475068354, 0.05341341208306052, 0.059321497476870017, 0.03869980866570146, 0.029373496410346804, 0.032811469188140284, 0.016967152553280036, 0.03343935868132018, 0.10848002658495981, 0.043857828864166816, 0.020923144409372922, 0.011655303814838971, 0.021102439627171527, 0.03134465596127895, 0.013553646708568259, 0.027410907468067545, 0.05819136457097146, 0.08381178091850974, 0.020001082898928754, 0.03057325904768321, 0.025483003156560085, 0.018806368781013355, 0.13555288434989993, 0.025881129474709594, 0.057385057030666264, 0.047619458468210314, 0.03920060417224323, 0.03199032827040121, 0.06521465947791454, 0.08092145375426739, 0.02302019327368227, 0.06334754998885817, 0.02343709449163608, 0.113746942351422, 0.05071296364129071, 0.019400988990861564, 0.06390729213073369, 0.013735281367365633, 0.013272608311155872, 0.036258849525643934, 0.027305746578701565, 0.06772491510116285, 0.06284932470730235, 0.07073134289032991, 0.01108957278061538, 0.028770328574483434, 0.0016927190294917375, 0.043740728494500926, 1.0475102619778727, 6.707187785256294, 35.302088568287516, 55.31871626454016, 82.33703751717844, 86.92531631838891, 80.56312207252749, 77.93583223896643, 69.27985160581528, 64.44884084886121, 51.2622598678835, 44.28604210576704, 43.18951606750489, 46.680060740440126, 39.26586328014251, 26.727857974267778, 45.75880581332792, 47.71479768137778, 36.806090031900716, 44.365470101756436, 56.70740004508727, 56.674695322590495, 64.57902823725055, 50.071832287696104, 35.84956515219904, 51.75983998083299, 49.0029707262593, 40.59843363300447, 26.744431949430897, 15.57707928842114, 11.821286293768114, 7.948005074454893, 6.670236606751719, 1.5521972193833322, 0.9185873476728317, 1.1203136198943662, 0.3163932095612249, 0.036199470050632954, 0.12215226753464631, 0.05035388673986158, 0.005801934814606343, 0.06369734190464502, 0.04161694124641438, 0.05387553547118461, 0.0998902504122065, 0.1417751883667323, 0.16010027198541552, 0.11506492001635414, 0.10198774552273174, 0.13713764447358348, 0.02255044156505216, 0.14501832966362277, 0.05424819894195084, 0.46500492059896076, 1.1479241641298419, 1.896406162169672, 5.625646181644933, 6.340130423345874, 10.899423399279195, 14.169547538603506, 18.593621215512677, 24.789110806680497, 35.68995606514716, 41.530318183283654, 57.80974295831496, 40.690950578258885, 34.58794655338411, 42.05784167012861, 34.381359238778394, 22.27883900365522, 28.925042267768617, 38.414226501218735, 35.9968932982414, 39.72446287831953, 35.343665692114065, 54.125998020172126, 47.611725637989665, 54.336797960342906, 61.97072659769366, 69.00030428363432, 65.34476118703043, 69.88090776628064, 72.29566004968459, 56.43028459241314, 28.81107976359706, 6.6662725613963225, 1.2005530562131637, 0.38512284897508164, 0.03361490772916906, 0.03011806684005405, 0.0074258439464404465, 0.05561185076892857, 0.04641086283710696, 0.04475618952945356, 0.020838068430161765, 0.025941499118362705, 0.018049385811712955, 0.04342958188405441, 0.015362092057212949, 0.03417149358879655, 0.03816582239984024, 0.12326502556642219, 0.03465915834831615, 0.012875882976297891, 0.03297801287243924, 0.009518806210478709, 0.024128915937316996, 0.016019908775154863, 0.019637118356542724, 0.08763311941537165, 0.03278846739821377, 0.0564628710309344, 0.0561954144148096, 0.04665823645829674, 0.052658202607304826, 0.05367806481738245, 0.03775064871015568, 0.03873590672869356, 0.015559488017442486, 0.02319071869996767, 0.0542779193229733, 0.062247363459919734, 0.02606270188886312, 0.04598029078014436, 0.045350735045729146, 0.06970758129271769, 0.028813488052917585, 0.06288204432254837, 0.10929801696611029, 0.02600326495725782, 0.02753599047390444, 0.029506167517073696, 0.027298206358306834, 0.08447627792315138, 0.13125464079841492, 0.20563240132985577, 0.21137827526657813, 0.1761633584335927, 0.05462372375111427, 0.11969396033354344, 0.11675834971209688, 0.18879222593480544, 0.25125123650556613, 0.3248526894998166, 0.19994082770520644, 0.215397724100659, 0.15837035352183929, 0.1365687475810128, 0.1753679293418123, 0.1543351845635522, 0.2092414262193826, 0.11882112571789373, 0.16380265234939514, 0.11919347509261101, 0.10516805994895198, 0.20765551696381263, 0.1723270965439658, 0.14912460690304158, 0.1973930031301514, 0.22471975775495653, 0.09668833230652156, 0.2878866795330279, 0.24528667510997867, 0.06834460362311333, 0.20014924958588617, 0.1414173333755424, 0.112948150133654, 0.1965673288871204, 0.09846010981428047, 0.18724802250583328, 0.1890568327038519, 0.09067182248878865, 0.12764990600126405, 0.1486828193188675, 0.12529863660494167, 0.1315135019080293, 1.9236314561097854, 9.673158103419889, 44.20163662202897, 67.1584455428585, 96.2388038635254, 96.99139687322803, 90.7077520124374, 89.45125210669734, 78.05793562243062, 75.10159815511396, 58.49752272329023, 54.24387308859057, 48.32238458818006, 46.42667562730851, 47.702489283777055, 34.62777037774363, 49.96752077533353, 48.35964710481706, 40.510580385884936, 46.485130709986535, 61.633324315471036, 62.24103281574865, 66.66748246838971, 55.40528689661334, 41.81967927563576, 46.376163344229425, 50.87009737568518, 43.42308536652596, 31.202142892345307, 25.93976947569078, 25.585957957852273, 17.972353081549368, 13.831443152120038, 3.3662771217284666, 1.4061366117769674, 1.9625680893659594, 1.2918043016426026, 0.3917599589593949, 0.5014037190666122, 0.5042806856574551, 0.15296215582038128, 0.20082997999364333, 0.18786463135432815, 0.11488002469582904, 0.33380197541367623, 0.619315467774868, 0.2266854627598678, 0.23623482534481635, 0.4972046685795631, 0.26733563551979683, 0.6098302573926988, 1.0151546917134717, 0.4002322478880806, 1.6762755162292913, 2.999563457504396, 3.702036175997027, 12.875966525846913, 10.23962680370577, 19.412733700967607, 24.379891887787853, 34.262068194727746, 34.68020462220715, 47.74423114715084, 71.24564155455559, 80.4588419391263, 53.98380033431515, 48.577087617689564, 59.50142983467349, 47.14590103395524, 27.107972906481837, 31.616908042661606, 36.285438537597656, 39.725000243033136, 44.08272212551486, 38.85831725212836, 63.24153923219251, 55.065880283232666, 65.53594535396945, 70.31840109056043, 77.14854978745984, 75.37650923575126, 79.20225574124244, 80.32428110799482, 64.1337372410682, 33.47635469129009, 9.205039893427204, 1.646309343557204, 0.4611062991522974, 0.15897914827350648, 0.13018666826669248, 0.09137054830188714, 0.1544675185915924, 0.19116054078744305, 0.1375903411497993, 0.1390291768456659, 0.08664995281686706, 0.11394299191212463, 0.16539344924592203, 0.15417971468019873, 0.15070585834403194, 0.10763721495506265, 0.2374701421227186, 0.0988018080111473, 0.14715910108099062, 0.21411357687846308, 0.1630213958842139, 0.22353662688645626, 0.13126185734666165, 0.21904837820799122, 0.27499182630450497, 0.12043925663155895, 0.12047343181386111, 0.15132583797939364, 0.18655109699935685, 0.20920292264030826, 0.16752796938582776, 0.19367157782037414, 0.13227290954561005, 0.20917143642662034, 0.08989130912889397, 0.12559769434794305, 0.2105875652764113, 0.13125724549735748, 0.1955511592208378, 0.18139776142854847, 0.19304784435418346, 0.08157786853130787, 0.1435771344169494, 0.18467353807101328, 0.10829624975280416, 0.19420938686497752, 0.1310630268867939, 0.13486550429896002, 0.1691565190952632], [0.034771240842078006, 0.007270319958127314, 0.06536033875759571, 0.07002251237751016, 0.023761892788893273, 0.011358349940799659, 0.06413441804808474, 0.030599501389529438, 0.008750059003491075, 0.024732191025489764, 0.07661312848569886, 0.0415417037513708, 0.03686634958871911, 0.05534265896365528, 0.09509247156881517, 0.09804210159927608, 0.023706257568612218, 0.04114802648884155, 0.029510871296928778, 0.11772934317348466, 0.014745980208258958, 0.07444664715759217, 0.05128596293469591, 0.032221282712153854, 0.04818065234670236, 0.015351494188390434, 0.049209531411648764, 0.046059626845582846, 0.05773715870154481, 0.028218392868556326, 0.036159694765604315, 0.04227975668806223, 0.036899475230565, 0.04624815725330864, 0.044213324304549925, 0.07600241085334171, 0.03386967409882815, 0.06792173074978976, 0.0550037952921083, 0.06998330399754547, 0.2893841975638944, 3.2843277771626753, 19.109763945302657, 40.60307771928849, 69.79092859452771, 80.86410907007034, 73.62213503929877, 66.82309858260616, 61.269806892641135, 57.0711684996082, 45.63954614823865, 33.46158304522115, 28.84886003309681, 25.17128694442011, 28.086986695566488, 16.500091437370546, 18.13770647971861, 19.129913160877845, 17.377541334398334, 15.867112086665248, 18.33947124019746, 21.6648409828063, 20.114331976059947, 17.86349161978691, 20.424854255491688, 25.746349557753533, 30.929242026421335, 18.873135197547175, 12.005300368032149, 8.032640016848042, 8.104285049823023, 8.710473141362591, 2.6285962279765838, 1.1254533957089148, 0.07466763288023011, 0.19468806924358492, 0.029884544088535255, 0.06591391389168079, 0.12024274741810177, 0.08947016761427926, 0.06728079094881974, 0.1455543767060003, 0.06422636775119651, 0.14587162903720333, 0.11506134238574775, 0.1498011851142491, 0.11152423016967312, 0.06606507836089981, 0.017863435205072165, 0.08028324888718706, 0.0177449252336256, 0.08815497084851227, 0.11750142435513197, 0.10035704310622909, 0.058179275703526316, 0.08333227882582335, 0.01893997259978806, 0.02842577670009867, 0.0458357606323496, 0.5248523527576078, 0.3888135235155783, 1.8708068132400515, 2.3682969568237184, 4.510814932084853, 7.421721056584389, 14.929565595042321, 26.830645645818404, 43.64210659457792, 44.97847772413685, 40.83139104227866, 41.28311864791378, 40.79885105932913, 35.438030073719645, 29.89331464613638, 23.03726653898916, 23.621542799857355, 28.74764915435545, 18.21303952124811, 22.424184391575476, 25.980579776148645, 26.245800641275224, 39.31071950543312, 43.47594714933827, 55.245038463223366, 63.82779236762755, 62.336373867527136, 50.485999276561124, 25.090197824662734, 5.7811289352755395, 0.7391431410947155, 0.16080301976011646, 0.07344496421395771, 0.06586924330481599, 0.037019482903903535, 0.10960829789720236, 0.04942181054502726, 0.04777735301984414, 0.028052343310968533, 0.059068393518006614, 0.06938801537598334, 0.04288536451396443, 0.044734949741752884, 0.03043463735300447, 0.10340296272789279, 0.02550393842431086, 0.04199870967216069, 0.05811758264298401, 0.02928537523163663, 0.02454844100641147, 0.036603772952671976, 0.037266304941787835, 0.1020966602429267, 0.022783215465624968, 0.062409448512499376, 0.036462908535594904, 0.047063481648482626, 0.018836079585936763, 0.011962166078568948, 0.12081264788585326, 0.042396799601133794, 0.02992446684548932, 0.08883127326806707, 0.04261129655905309, 0.04356658521799311, 0.021701269490163655, 0.02754749711452713, 0.03344144244047423, 0.023769756681436015, 0.04848748205169555, 0.0742041113816442, 0.029833057234364174, 0.023437312826694503, 0.009683316888948603, 0.07746475778760449, 0.04275720949555117, 0.05127056839785749, 0.0259541510604322, 0.05946657537753063, 0.049249452253383015, 0.03179980603407227, 0.035296708210221225, 0.042835055519976926, 0.04131378110257849, 0.059091016094410614, 0.010814154595737497, 0.0154022628351325, 0.03914515472828381, 0.030145308926641464, 0.05165885240139981, 0.06014534843064124, 0.046280984120864066, 0.01708652628886123, 0.034906011029717424, 0.04882688581522915, 0.02727101789787412, 0.04663394381021781, 0.033991256082851085, 0.01804156788444567, 0.047281441323819666, 0.064229175463439, 0.03477153195548923, 0.06817141412607125, 0.031182967359200123, 0.0638746108198839, 0.10671721230591498, 0.014126669942221094, 0.009551563172511036, 0.03220611034081348, 0.02223319306428875, 0.062338999066982544, 0.008416635513816391, 0.06298886379227042, 0.052206524828028296, 0.05519918984763565, 0.023981116509305376, 0.05030102667308623, 0.46010968004984243, 4.174040229089798, 22.213598220579087, 47.87576390850929, 80.16158119324716, 90.56959829022809, 81.86216400515649, 76.03689516744306, 70.01625307144658, 67.79650534352949, 56.88152582414689, 44.35640942665839, 35.76714438776816, 32.312946358034694, 30.44574518357554, 19.188074065792946, 28.823480336896836, 27.784926929781516, 26.291704139401837, 24.968141509640603, 24.53383314994074, 24.090520989510324, 28.78764360181747, 25.387707641047818, 24.96295809745789, 26.453068487105835, 23.35173276162917, 15.708939567688974, 11.57833174351723, 7.318503885499894, 6.869382204548006, 5.635872781276704, 1.9285170133075409, 0.7551044910665482, 0.04461479651170873, 0.1318943395369476, 0.0651798790861522, 0.06823689932183874, 0.13160149476701213, 0.129022398482888, 0.0212443248564077, 0.1172465009374484, 0.027818380058893276, 0.02048209610004579, 0.14438014777918018, 0.1414772874164966, 0.3465875232171628, 0.41551824538938464, 0.24095628650919085, 0.2932747291220773, 0.13231976348305904, 0.14571848806113968, 0.07100192514518577, 0.044230668535155636, 0.20643961285391163, 0.01887780647995251, 0.04756664819715004, 0.0950554618611932, 0.028477186945477323, 0.17220053881887468, 0.334606091942518, 1.1864728504611601, 2.303659483309715, 3.631765933767442, 6.729232976513525, 12.091610162488877, 23.747874498367313, 30.541825602131507, 34.96244269032633, 36.6007225744186, 35.47562599182129, 29.452283343961163, 28.890815665644986, 31.39764755002914, 29.812886445753037, 29.810999785700155, 34.39679376540646, 28.42764062266196, 28.2939427129684, 35.74437895128804, 35.00268228592412, 46.5279943712296, 51.69949431573191, 64.71006285759711, 72.81251076729068, 70.86995693945116, 60.126098663576194, 32.63176248919579, 9.10429185436618, 2.043060641134939, 0.11460797155215857, 0.0788742216724542, 0.06782708824762414, 0.030368397560631557, 0.17184764807743413, 0.03805117734197167, 0.051175596477884444, 0.03962417035513828, 0.09584928982921186, 0.03750395307677888, 0.04371525990145822, 0.0563813133105155, 0.027939408544390917, 0.07506875651738337, 0.0766730901875323, 0.03908665625438575, 0.01099898575639893, 0.015119166534033515, 0.015537514700554313, 0.014646939403798073, 0.08168533534532593, 0.026029721803722844, 0.031391659285873175, 0.0021852667616199585, 0.04387873540362043, 0.05499535300318272, 0.06031213343263634, 0.0006370972116729396, 0.03374223920306371, 0.08359704647333392, 0.03668112101994696, 0.07927734479908982, 0.014814456977370768, 0.0944864577163131, 0.02737139456815297, 0.04167481152821453, 0.025281688656597853, 0.03759994389369123, 0.051751188978913336, 0.03440918768906305, 0.005632473771730739, 0.06432713895675636, 0.022278798278421167, 0.033780700647302216, 0.022833658524999217, 0.024138095585869688, 0.10897129578816314, 0.21844819428459292, 0.10984338729852632, 0.22898656105802906, 0.15129568475869395, 0.18093288395433657, 0.12139485938654793, 0.16146488908317783, 0.08574004720656142, 0.11176706471991156, 0.193921935354029, 0.09164771125201257, 0.19934488790890864, 0.09769852648699477, 0.17330889950596517, 0.19482824801196977, 0.08925789997221963, 0.11081497064761578, 0.12346492088850468, 0.2858531451033008, 0.1531342957769671, 0.10733558315663569, 0.11199925064800248, 0.20593146673373638, 0.1900531760146541, 0.11673119189518115, 0.2171421216260041, 0.21200386266554558, 0.2622305788099766, 0.18478581591719584, 0.11798738456902005, 0.10616865504773394, 0.140092752032703, 0.15482955642284887, 0.09929239539609802, 0.16793269363622512, 0.08616563203113695, 0.16812121255263207, 0.1694488735689271, 0.16280650822145326, 0.9099061006019193, 8.116180127666842, 30.524818205064346, 59.72107079721267, 92.3249295450026, 101.38467111895162, 90.77580513492708, 87.42839951669016, 81.82619587067636, 76.23118585155856, 64.50973956815659, 49.403754588096376, 42.908395874884825, 40.82873952004218, 40.1499576722422, 26.42031865735208, 30.982482317955267, 30.756196860344183, 27.6762576641575, 25.134593171458093, 28.12440218464021, 29.625304975817283, 30.084922429054018, 30.037663752032866, 31.831083182365667, 39.25329600611041, 42.34408840056389, 28.4035494250636, 18.551959760727424, 12.271191958458195, 11.818936794034897, 11.371900343125867, 3.5430990399852877, 1.7508584044633375, 0.31585468039397274, 0.5557334795594215, 0.18675366596829507, 0.15269181871366116, 0.24227663904668825, 0.40723177874761246, 0.31768532409783334, 0.2860604791391281, 0.4151568051067091, 0.48160782324210294, 0.6112822085138291, 0.6339764907475441, 0.4302184614202669, 0.42249267920851713, 0.37131723977865716, 0.3873927981382416, 0.27051367466488196, 0.37099600379024783, 0.14322654193928167, 0.22893973776409704, 0.47679541211935783, 0.22029864902217544, 0.241531603218567, 0.3944782534193608, 0.17556930321358866, 1.0243539367952654, 0.6164931998618188, 2.6574195200397126, 3.3860770012101824, 5.770670915803602, 10.439177386222347, 18.37573943599578, 32.342636739054036, 52.23364268579791, 55.68475577139086, 52.19152035251741, 55.40866013496153, 56.37162162411598, 51.65922334117275, 42.58238023327243, 37.943259669888405, 36.6098891535113, 41.853772517173525, 31.018921136856083, 34.78300209968321, 41.17022891198435, 42.24755102588285, 56.10984656118578, 62.491001544460175, 73.0919639525875, 81.00846798189225, 80.67816518968152, 70.70764141698038, 38.19302835772115, 12.143184427292118, 2.649065361868951, 0.25434192630552477, 0.2030722733827368, 0.1818499065214588, 0.07413442802405165, 0.2259184708518367, 0.14842031163073358, 0.16863838318855534, 0.09664784455972333, 0.18481103553166314, 0.09413821712857294, 0.11492019068569907, 0.1250269282008371, 0.06314421876243527, 0.1629310281526658, 0.14810209402874594, 0.11872018597299054, 0.12717477060974608, 0.119196409209361, 0.10635563412741308, 0.1321915203645345, 0.17101072766367467, 0.23788982040939793, 0.14465707324204907, 0.16746864353697147, 0.1661575146980824, 0.19378057681024077, 0.10917674524769669, 0.0750954470206653, 0.17326059000146005, 0.2052945718770066, 0.09508477238517615, 0.2197581127045616, 0.18976747118417295, 0.18750706747654947, 0.11026601502371412, 0.12628019441880528, 0.12373679783195259, 0.21051593605549107, 0.14531134297290157, 0.09530361306162612, 0.11098409987865918, 0.19796301851109152, 0.15631207445215795, 0.2514303478622629, 0.158969005269389, 0.10651095845406094], [0.07866961490963736, 0.023178411497464104, 0.039658927764262886, 0.03318850319051454, 0.09125440937256621, 0.05462555853169292, 0.015792282985433215, 0.023660286547495954, 0.06613205742811964, 0.04967395306354569, 0.052457158153335896, 0.060326309889675155, 0.058152225138919975, 0.0705408244844406, 0.08379609143782048, 0.038405056336834546, 0.07279826343179711, 0.04728541732014668, 0.07588424179102145, 0.04149879133629222, 0.05767348913415786, 0.06027287908739621, 0.014910053259002106, 0.030217836385652907, 0.037125892516586094, 0.04229385270586899, 0.07295983137502786, 0.02213693794704253, 0.023683474113744114, 0.06180025156467192, 0.027408252973409913, 0.06943178963997672, 0.07974444392828212, 0.06353251425729645, 0.07269736199129014, 0.05649983094284131, 0.026625584991228197, 0.0623708491724345, 0.0347302015119743, 0.2711254111941784, 8.263820102137904, 35.996783471876576, 63.39188760326755, 72.39044804726878, 70.06535330126363, 69.43653460471862, 62.54096469571514, 65.07258007603308, 48.240505110832956, 40.36907303717829, 26.907051455590036, 26.63820435923915, 36.24822308940273, 25.173677629040135, 49.025390994164255, 71.00039143716135, 31.16478623882417, 25.311344977348085, 25.606773976356756, 39.50579466358308, 43.90270886882659, 52.09067621538716, 36.513657723703695, 27.144711786700835, 26.27698152296005, 17.87106767777474, 11.144234211214128, 9.189983875520769, 5.369958146925896, 2.706510434227605, 0.8815564347370979, 0.23474499883670963, 0.021605521906167272, 0.01348872458742511, 0.049776934432767095, 0.04043618908091899, 0.023041852494521488, 0.03903473464531764, 0.04640233244807009, 0.09105294357023894, 0.17019527303355356, 0.030883616587567716, 0.04174447190316935, 0.0702652243536807, 0.037786344576987534, 0.16761527276567875, 0.09895451997797336, 0.16197398515237918, 0.1481056333549561, 0.11891605933347058, 0.08201044007775285, 0.10648652791015564, 0.058337966986601396, 0.03912472316334325, 0.006670529612400119, 0.05246420616223928, 0.036466398066090006, 0.07074160846851527, 0.3255291144934393, 0.061020431514348716, 0.03821484053567533, 0.03261789792187272, 0.056880948193851984, 0.24276541846413768, 0.5733428991610005, 1.3463216923898267, 1.4234820681233562, 5.821471002794081, 10.804601080956, 18.38276832334457, 28.6236551884682, 50.185643780616026, 64.37182511052778, 65.7599283802894, 56.45166150985226, 61.004544842627745, 47.31158195003387, 46.56481366003714, 36.21982905172533, 25.235203927563084, 25.47884979555684, 27.080404527725715, 30.840569003935787, 45.298292098506806, 57.41068886172388, 57.63853150029337, 64.20273565476941, 53.385081906472486, 45.95471643632459, 12.29470068408597, 3.263754455312606, 0.6521856652632837, 0.040272751883153, 0.07982988571447712, 0.06847521395332391, 0.06908186365880313, 0.05058405019583241, 0.049443326124380675, 0.018036990509098096, 0.011087216102638313, 0.041621656517588326, 0.05932999339195029, 0.03988826384527549, 0.03308253024794883, 0.06069575196071979, 0.014755509384427101, 0.031073366990312937, 0.015971896129720393, 0.009812589438121406, 0.0341694634557972, 0.07903546019787751, 0.016951765677320863, 0.037514210994085, 0.016016460421885696, 0.018905732300012343, 0.012532752195012667, 0.02377638525720085, 0.04891067285150771, 0.07043852110303218, 0.06674838282408253, 0.014978544392262497, 0.03820509206683886, 0.038971268091230624, 0.06044905249690337, 0.06839639116679469, 0.0326909520663321, 0.020481420027452613, 0.03586414187485653, 0.013851108115857408, 0.04258296279717357, 0.029270388636617895, 0.03356949786745733, 0.03475850463033684, 0.01605999624101265, 0.045860195006694526, 0.04025378354614781, 0.04715635831798277, 0.05308403641045575, 0.017877312887820507, 0.024285454513324846, 0.03216350819134424, 0.060672995318929036, 0.04933869000524283, 0.006666443012129035, 0.03737852533137606, 0.013161218169355586, 0.11047314987668108, 0.04107326779875063, 0.04426695045924956, 0.07522974223379167, 0.02300544225070025, 0.0625184283501679, 0.02829780745800705, 0.03364772693584523, 0.07277236965995643, 0.046779569463744286, 0.025329477221314466, 0.0687435285879239, 0.023193706442872365, 0.0337898439066785, 0.1039447860732194, 0.02692844827599343, 0.02365663805375657, 0.028432343988829566, 0.021461045384527217, 0.027516035798696742, 0.04456809962228422, 0.054509381297975786, 0.059882871386024265, 0.1236156180440899, 0.03163679976076369, 0.04420987307845105, 0.02490224722292154, 0.012853354245664613, 0.033400701884660995, 0.6595892615375981, 10.576520158398537, 41.49193386877737, 71.07217081131475, 82.49145338612219, 79.79482389265492, 76.0299917959398, 71.14824910317698, 72.39293482995802, 61.07882276658089, 48.80789556810933, 36.233914283014116, 31.750768730717322, 36.885208160646506, 24.699506221279023, 43.82808185392811, 66.08597540086316, 29.949288829680416, 24.568771662250644, 23.802844555147235, 34.46489003396804, 36.11224628263904, 35.06678950402045, 23.742875437582693, 18.177830365396318, 16.225147016586796, 12.042672711033976, 7.679727702371537, 5.363281782596342, 3.476244446731383, 1.6132838447247784, 0.5076450680292423, 0.16145805557889326, 0.08413323907241707, 0.023085402677797025, 0.03135826168281417, 0.03661531023681164, 0.061499730593735175, 0.40507545574538173, 0.2743916117375897, 0.12010023974242712, 0.05251490203062854, 0.021090193711701902, 0.1565687292285504, 0.12842081261858826, 0.07223603916504691, 0.3819703358796335, 0.8688008256496922, 0.9519233879062438, 1.091942258419529, 0.24973566944320358, 0.3070749144159979, 0.32334778638136, 0.05175059909121164, 0.07778008723811758, 0.1218529339999922, 0.09901160885009075, 0.01879378578685705, 0.2116218146177069, 0.7362245299643086, 0.2171470245887195, 0.07019450677739036, 0.06686188641094393, 0.05556988064199687, 0.18803166916533826, 0.24799242104974487, 0.9844903984377462, 1.6164864599704745, 4.700695401237858, 7.303114466128811, 15.422141744244485, 23.17027803390257, 42.951804745581846, 54.341598941433816, 49.30801345456032, 43.316055651633974, 60.03091842897477, 46.861003598859234, 45.874429441267445, 39.706267003090154, 33.975103670550936, 38.27073051083473, 37.28414458613242, 41.26432657241821, 51.22949630983415, 64.48506785977271, 66.77267259167087, 76.53043131674491, 65.34270978743031, 56.051297341623616, 18.821185365799938, 5.3959065868008524, 0.87687588266788, 0.0377691573944063, 0.06528547664563503, 0.03634822900376974, 0.033468224874307076, 0.06823295396902869, 0.03795650419628909, 0.08746474095049404, 0.04062126826254591, 0.0688583575068943, 0.010812681791703067, 0.059805714840730356, 0.07913987798195693, 0.10440960226039733, 0.05983247812236509, 0.004335588901378816, 0.06127835799669547, 0.0666444476753954, 0.028386574065793427, 0.02257524174638093, 0.05515778279532829, 0.07173748446568366, 0.0020742843222368752, 0.03760715661149833, 0.022491925854175802, 0.03895974229840983, 0.052536183953165054, 0.10782659955082402, 0.03782405525506024, 0.0467293524003077, 0.04630055000645019, 0.025112622627808202, 0.04659111566481091, 0.025921247584084352, 0.058941054383232716, 0.056896718113773295, 0.016325306853339557, 0.03796781165405147, 0.06331181198719048, 0.10719898967973648, 0.03958239175018765, 0.01953706152797226, 0.025373586648774725, 0.02223612143537931, 0.035913194484648206, 0.15109791150016172, 0.11442799451610736, 0.11656108207159466, 0.13718431454993066, 0.11869868954583523, 0.14591960146302177, 0.10485364214306879, 0.17417319990213842, 0.14086524445203044, 0.1215952679875397, 0.22866930872682603, 0.18294913544049188, 0.20209117522162778, 0.14987037817557014, 0.23920124036169824, 0.18630322159057666, 0.1276319412394397, 0.21266731012973095, 0.2772815405361114, 0.15084870309839327, 0.18269450313621954, 0.2540091989982513, 0.1302443700091493, 0.11828322474273945, 0.29831034762244074, 0.155541175495713, 0.13446255737254698, 0.17892093788231575, 0.1254840375434968, 0.12226050043658865, 0.29712119530285563, 0.12661200242056964, 0.2083881728110775, 0.2677784956270649, 0.1914192180359556, 0.21279196795676986, 0.1418988196359527, 0.11057981229837864, 0.17996638742906435, 1.2898689796847682, 16.532470603143018, 52.52511793567289, 87.10154841023108, 91.89284124682027, 90.66425292722641, 87.15944259397446, 83.68011982210221, 83.13573406588647, 65.84205104458717, 56.40216904301798, 41.016013083919404, 40.67052287440146, 49.08224967218215, 38.06845780341856, 63.7955661742918, 82.81342506408691, 44.457430070446385, 37.556549272229596, 39.325295032993445, 53.23699674298687, 60.921170942245, 68.23261799350863, 48.35523836074337, 38.93813356276482, 35.38951819942844, 23.770363407750285, 14.501903691599447, 11.44996629607293, 7.090799510478974, 3.8478698990037365, 1.3316737235553804, 0.6019633924288135, 0.22680449750154252, 0.1189654796654659, 0.1808459023314138, 0.1661794554562338, 0.20385029695687756, 0.41096415911470696, 0.30946657962856755, 0.2307518268184316, 0.3254066629996223, 0.28765532097989516, 0.21137997598177005, 0.4973262620549049, 0.1656394400784085, 0.49843705890159457, 0.49631300352273455, 0.878351551871146, 0.7174886546788678, 0.3037280601359183, 0.36753515562703537, 0.4409270835739951, 0.2191150431791621, 0.1737324082322659, 0.14669517355580486, 0.23657743518631305, 0.1465302041821903, 0.2926916442811489, 1.0775735133117246, 0.3352849990610154, 0.26150558384195455, 0.32196076887269176, 0.17397893532629938, 0.6278480325014361, 0.6653702223012525, 2.108672333340491, 2.213759739552775, 7.880508928529679, 13.749716647209661, 24.453291200822402, 35.6246486017781, 60.315666814004224, 76.2021916912448, 79.82799929957237, 68.82294254918253, 73.0184587355583, 58.580253354964725, 60.13027598780971, 51.04555676060339, 39.40918668623894, 40.028168078391786, 43.94197571662165, 46.09756915800033, 63.050963032630186, 74.80437663293655, 76.62732170474145, 85.13976712380686, 75.64392074461907, 65.50298175504132, 25.176223247281968, 7.0789966083342035, 1.1722975272324778, 0.1166971622695846, 0.2535622479814676, 0.1283809300812502, 0.162449557214014, 0.18340868094275076, 0.17140958368057208, 0.13588755752050108, 0.11612436598947934, 0.183726255030882, 0.14754802859838934, 0.20544173736726085, 0.13675947283064166, 0.34923328447245783, 0.24945342733014017, 0.1749293746486787, 0.23485920722446135, 0.13512007531619843, 0.0991237641222054, 0.12709951779294398, 0.24055222109440835, 0.15500043999523888, 0.036368296676946264, 0.13927126062973855, 0.0669883062402087, 0.10068819993325781, 0.12134285733824778, 0.1925976298028423, 0.09987855991048199, 0.12204346006676076, 0.11784003521766394, 0.18515952892841833, 0.1100487218448712, 0.08725192172512894, 0.1561628558462666, 0.20909956205756436, 0.1386116129616576, 0.13185586660139023, 0.1644003541479188, 0.20755601746420707, 0.11563868922812325, 0.10703870110333928, 0.1128890004850203, 0.09575329135142027, 0.17958084602029095], [0.04404963429776892, 0.05595141158048665, 0.025141739714590293, 0.09740618733508934, 0.03569520799623382, 0.048294301490269365, 0.052975573682136116, 0.044702808522889693, 0.0448098348363513, 0.06770472102347883, 0.00938006672978161, 0.04047576518308732, 0.03698218974374956, 0.1150605992804612, 0.021715618316985427, 0.01664242128871622, 0.03890498233358226, 0.050542735074075966, 0.021363648796273817, 0.004874762540097319, 0.04588477876818469, 0.026783366544893192, 0.08975714415071473, 0.03642702880766123, 0.03733236087305892, 0.01910391541558408, 0.02729723534186281, 0.08478544802675325, 0.03558586426680127, 0.010266492702817966, 0.05888122674678603, 0.04034191813139666, 0.06536795367156306, 0.0571708511861582, 0.05378983704553497, 0.1013482689496971, 0.050779356651248476, 0.14564312033114896, 1.7209416291406079, 12.595028723439864, 41.45785239435012, 58.14586654786141, 66.71739070646225, 66.76862470565304, 59.90004462580527, 62.75878567849437, 46.14790101205149, 46.908742766226496, 29.871914194476222, 25.913544508718676, 29.634789266893943, 30.871904819242417, 53.841128041667325, 42.33508656101842, 32.736995758548865, 28.301728617760446, 36.38347033531436, 57.644760224127005, 57.17000830558039, 43.56990360444592, 35.40376817026446, 20.153934186504735, 17.751860964682795, 8.314691282087757, 4.735034771503941, 1.333367206877278, 0.7271787476155066, 0.08977189900413637, 0.0827402460779394, 0.05893602884644943, 0.15000717083532966, 0.06173661647124156, 0.031210268817601666, 0.03353334617831054, 0.059392123122609435, 0.05156191546590098, 0.07111716775163528, 0.11996111817537777, 0.1575758590573265, 0.10640873168144496, 0.01216509798166132, 0.10844195967600231, 0.03660235569001206, 0.08820956993487575, 0.059021447650006706, 0.09043556097294055, 0.579089661759715, 0.5561051854202824, 0.36296124299687726, 0.36938544182527455, 0.13926134745199836, 0.0989817314210438, 0.07598718868628626, 0.06876726199181811, 0.11335518030870347, 0.07747814900452092, 0.07981661707162857, 0.09515526779596845, 0.06012272585423724, 0.10325302399935261, 0.09102549463991197, 0.030554039816882823, 0.2843461582256902, 0.0705490216252304, 0.014125174155548937, 0.08290742178477588, 0.0420428823018747, 0.08157102736614405, 0.6955618699712138, 0.9671963006258012, 2.9980680538762003, 5.869249884159335, 14.491755539371123, 36.01864676321707, 62.39653518123012, 68.57726881580969, 60.860083949181345, 60.453083130621145, 36.88618875318958, 14.791776653259033, 14.50838246653157, 16.997497004847375, 17.488632663603752, 38.54693205125871, 38.45356787404707, 53.08427533795757, 59.51582885557606, 67.48609681283274, 61.100564464446045, 50.76560935666485, 28.12232528963397, 5.465938545042469, 0.5896212256723835, 0.022822046547286937, 0.04938531794675416, 0.005918719173003469, 0.09150609989920933, 0.024240760943822326, 0.02835252528799878, 0.018600354331635663, 0.04052164618887248, 0.05976834890222358, 0.08391351739485418, 0.01795606481121673, 0.08966567325255564, 0.04277381445130995, 0.04884154873809988, 0.06094749994395722, 0.031005378602252855, 0.017729651355635256, 0.024911765865380728, 0.04916013789273078, 0.0765014022228218, 0.005914668961908789, 0.017683728215014263, 0.06505493780658131, 0.13391987600874516, 0.047556359636326956, 0.04207414635006459, 0.04066790386493649, 0.03269042346566435, 0.007804616010792915, 0.03616074430606058, 0.057218260537352295, 0.028601877331253023, 0.0371248736196468, 0.02489909285589332, 0.008933926808587726, 0.010131209236269277, 0.004126543616650686, 0.07582250276520368, 0.05261233692327815, 0.04194175486543006, 0.03563431166713277, 0.0386939442626411, 0.057649123707726124, 0.045805304806919835, 0.07160790069329162, 0.010882808522681796, 0.0680940545674774, 0.048464246604952126, 0.06836501986629541, 0.04926273238755042, 0.07703446918317387, 0.030809491835234147, 0.02594215795397759, 0.03574009308771741, 0.020360745857619954, 0.03365127009249503, 0.03976905673381783, 0.04145096446717939, 0.025629243595645796, 0.026811303856271892, 0.039107578115597855, 0.053037845139061256, 0.05307574350867541, 0.06656647524646213, 0.0271591920435669, 0.044314478554071925, 0.04039884229461032, 0.059917590490752654, 0.020980206468412956, 0.024125616013583158, 0.053083779771001115, 0.008882483046862387, 0.04267313900674063, 0.035572166614715135, 0.01921841683196685, 0.005013460364763535, 0.08391170176647364, 0.02025694860475919, 0.03426586029930942, 0.053845305641692494, 0.1688670144686776, 2.03968899624963, 14.943243880425731, 47.67273810602004, 66.35184934062343, 77.47598140470444, 76.10422657382104, 70.90270873039, 73.8312993511077, 58.90561003838816, 55.958376392241455, 39.73182516713297, 41.51829611870551, 37.66734054011684, 41.802836618115826, 65.68077887258222, 49.98086467865975, 42.113347130437056, 38.19879816424462, 45.25653062328216, 47.47462311098653, 47.66397553105509, 32.287741207307384, 25.85293016126079, 14.346373869526772, 11.479206585115003, 4.754429911413501, 2.4980575423086844, 0.6213261727844516, 0.2746758610010147, 0.0645422181414981, 0.12468407321120463, 0.01649173562444987, 0.05105084672029461, 0.1513961495290841, 0.2065033054039363, 0.6547808647155762, 0.23259638267899715, 0.2821325012032063, 0.45130631856379977, 0.33869733853686246, 1.088040235542482, 1.0919111246062865, 0.11701989212944625, 0.08008227338113132, 0.028974251603827845, 0.1836679097745688, 0.2795809381190808, 0.3273205957826107, 2.7519427576372704, 3.07622054411519, 2.6553703267728133, 1.3113777868209349, 0.43080363002034927, 0.25495796824895567, 0.48639314549584545, 0.30931274917337204, 0.8083084393893519, 0.4207672040549017, 0.5034122483864908, 0.4302464695947786, 0.19914506153473932, 0.443185480131257, 0.3377008113649584, 0.2554014105830462, 0.34479377430773556, 0.19810350371464608, 0.09736572257092885, 0.06025841151694618, 0.12350035245500265, 0.0789157972641049, 0.3684500178262111, 0.923822302251093, 2.866283525382319, 6.60369114529702, 16.392872468117748, 36.705234127659956, 60.21028841695478, 73.00190633343112, 62.58609940928798, 68.97601696752733, 48.59627585257254, 26.37692351495066, 15.586768523339304, 26.490460441958522, 25.284049203318936, 48.48945010092951, 47.03378792731993, 60.94368534703409, 67.92068758318501, 76.78440478540237, 69.90535197719451, 58.107756799267186, 37.63944464345133, 8.80513072013855, 0.9049905740445661, 0.05074387911947505, 0.062455149487622326, 0.04497294261630985, 0.050179701328517935, 0.03637087073237185, 0.10216523277302904, 0.035994545361327554, 0.03677435775077151, 0.046180109493434436, 0.02309714297523662, 0.06238760734577814, 0.011327134730714944, 0.017491168184806744, 0.0859719573429996, 0.05221269566625838, 0.05289003613495058, 0.06902299746270142, 0.011529828188940884, 0.01871389813811308, 0.06293280530841121, 0.021781890668095123, 0.022736139362677935, 0.02589259398049645, 0.04507352613032826, 0.0024934287413939716, 0.03726343211207179, 0.014832254157461708, 0.07652011008993273, 0.05945574289428131, 0.0174041080378717, 0.04335026880125365, 0.014623219406442537, 0.0023168789911940093, 0.059165303640428095, 0.017443228317725084, 0.036913146069573785, 0.0806207642439873, 0.02340854814035758, 0.016503002862596226, 0.06672284145268702, 0.030435721367417328, 0.0023236950190978186, 0.047522494719634135, 0.15229143052091523, 0.17033166732759247, 0.10339393055126553, 0.22828741389657223, 0.23304431428832395, 0.20578745752573016, 0.10049127703232151, 0.14349231316197303, 0.16478800995936319, 0.13557140835590903, 0.15270623648839612, 0.1900670268843251, 0.10652918368577959, 0.2266044259792374, 0.129860314810949, 0.1694196090102196, 0.22708226566112813, 0.15194043967752688, 0.1928325123604267, 0.11398689641106514, 0.1929264347399435, 0.16804101846871838, 0.22364977807287248, 0.10140810041658341, 0.1953330080235197, 0.12754703571479167, 0.08368158427577826, 0.22531850143305718, 0.15035197168828981, 0.0977811643913869, 0.14817275797888158, 0.1269742011302902, 0.18163698004378429, 0.17400784748456172, 0.25792206968030623, 0.30546870383043445, 0.16294025185127414, 0.3587315183493399, 4.046598009524807, 22.57965341691048, 59.5823012628863, 81.45248813013878, 89.72857936736077, 89.67396428508144, 79.74434298853721, 84.55192150608187, 64.95506978804066, 63.77458149386991, 44.35644080561977, 38.54541017163185, 44.164052471037834, 45.279962862691576, 65.93135556867047, 55.545637146119155, 43.92331307934177, 37.89265717229536, 52.09052324295045, 73.48817825317383, 71.08059606244488, 57.09131379281321, 43.21239525272001, 25.966463165898478, 20.774578663610644, 10.797827147668409, 6.245774867073183, 2.0641350457745213, 1.3286011593957103, 0.27385271484813384, 0.22424942573472378, 0.13236330792067513, 0.3350610562389897, 0.24160151640253685, 0.24378777812084845, 0.4585026727328378, 0.3445242339324567, 0.25718981219876197, 0.33239047373494796, 0.2648840009445145, 1.2614704067668607, 1.1514269632677878, 0.3211200026975524, 0.311209000647068, 0.5304142123749179, 0.3786880781333293, 0.6371951631961331, 0.29175704765704374, 2.7677864365039335, 2.672387774913542, 1.7867659873539403, 1.045848893061761, 0.3814060968016425, 0.18133377776511256, 0.38809667972307055, 0.15746868335671965, 0.44763381562886706, 0.35832429665230936, 0.33241443696521944, 0.638250403346554, 0.13988944761935743, 0.42891372175466635, 0.2731778833173937, 0.2748488742978342, 0.6575650733805473, 0.3884255153036887, 0.22012623327393688, 0.32449887945286693, 0.3259377457922505, 0.32148812326692766, 0.9883112772818535, 1.478592962507279, 4.086580444728175, 8.050886392593384, 19.228060668514622, 44.601781137527965, 70.90840401188021, 77.32507213469475, 71.10420873088222, 72.1061860361407, 51.65284556727256, 25.556842204063173, 23.79720222565436, 28.346153382332098, 29.243738766639467, 56.208827572484175, 57.46058533268591, 73.02911973768666, 76.93399613903415, 84.9746588737734, 78.09271135637837, 66.64376781832787, 45.66542594663559, 10.82613097083184, 1.1961039852711464, 0.16479482814188928, 0.1659047516483453, 0.12427655273988364, 0.21329727955162528, 0.13467807322740555, 0.22152636620786884, 0.11566870455299655, 0.17216096271670636, 0.08706556317666847, 0.1513048931355438, 0.10121429549349893, 0.14005633221278269, 0.1386041665870336, 0.1831581242262356, 0.198460791800772, 0.13841287443234077, 0.18050531496203717, 0.16239199336738358, 0.13198913525669806, 0.21156362257897857, 0.10818578753500216, 0.09099911823267899, 0.14826390712011248, 0.20648099692358127, 0.15271176764320943, 0.2032039026098867, 0.1408965774481335, 0.1688326017991189, 0.13986931482870735, 0.1365850192885245, 0.09584870760238941, 0.10886298627742838, 0.09030862786476651, 0.21801805123686793, 0.18957538229803886, 0.1934277933211096, 0.1488811901259807, 0.12886021766931782, 0.20846199304346116, 0.10039343228263241, 0.11050325713210529, 0.14322962161273728, 0.176734829381589], [0.03529668905802312, 0.054115186926097646, 0.0036921753546208026, 0.07542982907785524, 0.032231372090116624, 0.06340221036225557, 0.03968117495758399, 0.052740059102014195, 0.03182117797193989, 0.07976123657558234, 0.06519826519633494, 0.06543799709048002, 0.05479111396256955, 0.022734672304302938, 0.027255359060701825, 0.042635324906798146, 0.057196718144921534, 0.039011246389559204, 0.04195554061762748, 0.015954778852662253, 0.019383074024752266, 0.021460848116886713, 0.03960894818808283, 0.06622340575221085, 0.063345335994757, 0.06127333245991219, 0.051782855223263466, 0.05569988576274726, 0.020319808034166213, 0.04128355127308638, 0.05502277512043234, 0.006472638089044561, 0.06439241730878431, 0.048089009078760306, 0.031248607687772285, 0.07642015859845185, 0.341342517565335, 3.456779194454993, 17.969593694133145, 44.54996662755167, 60.921716151698945, 67.61017707086378, 63.531269027340805, 60.51455843833185, 49.6539508142779, 43.37673079582953, 53.310474503424864, 29.78999745461249, 25.998483434800182, 19.19623455693645, 22.79178107938459, 21.90920856691176, 26.882293455062378, 27.77256165781329, 19.619587736745036, 35.79074921146516, 37.918905673488496, 40.01121167213687, 22.23652643542136, 20.771836926860196, 11.422517549607063, 5.668285777491908, 0.826274365667374, 0.19310743067293398, 0.039840475280558875, 0.06357267641672684, 0.04143896753028516, 0.17476432866627173, 0.2218244356974479, 0.27015410363674164, 0.05408057507367865, 0.15126606779954127, 0.06828995857147441, 0.0924089958050078, 0.05143184905811664, 0.014559434925866945, 0.08610358657014948, 0.6196175515651703, 0.47774459505754135, 0.3207892059318481, 0.116138301128822, 0.0953782759907265, 0.07149363867938519, 0.11814736671024754, 0.13624584152092858, 0.5676044715989021, 2.242775227754347, 1.1103517802492266, 3.174444292822192, 1.1849720535739776, 0.4109503082450359, 0.28771176633815615, 0.14579839103164213, 0.3544035199428759, 0.5161288176332751, 0.6032849247417142, 0.25258804461167705, 0.3688357277743278, 0.8175367958122685, 0.28821471838220475, 0.1653388731421963, 0.34450082228549067, 0.09669742577018277, 0.04661762996787026, 0.02095481639938249, 0.029754916266087564, 0.03235749314509092, 0.05931330416651984, 0.026722793887940147, 0.09918915738742198, 0.12083236698902423, 0.8389094231590148, 2.0315066869220426, 5.244822771318498, 12.108274352165962, 23.217540633293893, 35.01203713878509, 28.506184124177505, 28.05964973665053, 36.70166084843297, 76.96310797045308, 20.90580155772548, 22.339988754641627, 18.621293537078365, 38.53637303075483, 43.02737705169186, 51.634645769673014, 54.470264450196304, 60.783864451992905, 58.73133520926199, 58.8092177914035, 36.38166604503509, 13.700885099749412, 2.597872792713104, 0.25919463365308704, 0.09481388369515058, 0.03897369275951097, 0.041316910571749174, 0.020908619382328564, 0.07061400886384711, 0.07480804913587148, 0.048571678945013595, 0.07347748464634342, 0.07864269457997815, 0.015720842413664345, 0.015091206240017089, 0.01479197325440304, 0.04333275986174422, 0.02406907489433164, 0.048706985394200014, 0.012158038481439074, 0.07734768423101596, 0.07118200177266713, 0.06738572967268767, 0.036210674086525556, 0.08314683958287201, 0.04950447143205712, 0.035498369364969196, 0.06543828054301201, 0.03797064234893169, 0.03438623952529123, 0.035181270251351024, 0.05833268481036348, 0.08353061132854031, 0.029669101012029478, 0.016118692940161113, 0.027777078343675505, 0.03116648306228942, 0.06385593742672956, 0.05863034444290304, 0.041335434577758276, 0.057320632866673896, 0.05891878037683426, 0.05461052405617891, 0.08173269490080495, 0.0386509016126154, 0.034513965534466895, 0.016560696944173788, 0.029561837211311347, 0.018061290818056273, 0.06124422877966877, 0.04465864738449455, 0.055613593618956306, 0.08636565758816658, 0.0595153215521526, 0.05319685434862491, 0.03868554793899098, 0.05833723537263371, 0.08013266664479049, 0.038308280279799815, 0.05448430724021408, 0.05003194212012234, 0.027371557361836878, 0.044948420141853636, 0.017160495908390132, 0.030376778562523188, 0.05990020412531111, 0.044329447912112366, 0.011982362071472791, 0.02684327845101155, 0.0035261830142248544, 0.07042091640253222, 0.01366458485849322, 0.03172945426476579, 0.03375512097151049, 0.045279975334602984, 0.01210909216634689, 0.025361400105119235, 0.07911900974689953, 0.028151057570451693, 0.017162112353910363, 0.0994240246232479, 0.2779542883076976, 3.7049786890706713, 20.535925972846247, 52.92157150083973, 72.46938182461646, 78.17219426555019, 72.17700050723168, 72.83529973799183, 58.940330859153505, 54.51175920424923, 58.72121549421742, 44.0434984237917, 34.64147906149588, 22.14353096100592, 30.866544900401948, 27.203192364784982, 36.85343696225074, 36.38678081573979, 28.42807208338092, 27.91063497143407, 34.18959063868369, 38.34665975263042, 20.947378681552028, 14.455668753193272, 6.751998412993647, 2.2921593391126205, 0.6723618471334059, 0.12761726299481047, 0.10125808507925081, 0.11147844875531812, 0.15071883587346924, 0.24275264011756068, 0.4379584928674083, 0.7470180959470811, 0.4679130516465633, 0.6715233792220393, 0.595356343734649, 0.577769416474527, 0.5014393881203667, 0.9360963791128128, 1.2397402308640944, 3.121657035043163, 2.241582582073827, 2.4124160216700647, 0.6588060132438137, 0.09255210869014265, 0.12271600865548658, 0.17644391515322272, 0.1653617638493738, 1.0886966196760055, 4.827840010966025, 5.541079390433527, 6.2374040388291885, 4.107751437733251, 1.6359307520812558, 2.3433048398263994, 1.4387843373321718, 2.3667998371585726, 2.246449262865128, 2.69802610239675, 2.383123270926937, 1.654051979703288, 1.9931611058212098, 1.1025890419560096, 1.1879601642008752, 1.8258532641395446, 0.5088148230025845, 0.665702888321492, 0.6047801445088079, 0.2873500809073448, 0.10002105226439816, 0.1868735434066865, 0.05492480779667536, 0.1332802692007634, 0.09662986447614047, 0.28954841617134314, 2.0113947338634923, 5.735282801812695, 14.866625282072253, 23.091408975662727, 35.09273990508049, 32.50682715446719, 31.20643984886908, 27.068600154692128, 70.34584199228595, 29.42539353524485, 27.14452547411765, 25.24426264147605, 45.16111896884057, 53.39031827065253, 59.761082895340465, 62.72680659447948, 71.3992964836859, 71.46744374305972, 68.31405424302625, 46.64624598718459, 18.787841296965077, 3.804229363318413, 0.23892547935247424, 0.04687814965784069, 0.09207140383941513, 0.00855550044141109, 0.014955261065023802, 0.029047453220212655, 0.04770296205195689, 0.046127915923153205, 0.13914058135161478, 0.08523999097486658, 0.027678645621504516, 0.025558353649572502, 0.06000479044873388, 0.04066976545859249, 0.03072346016133745, 0.027084498470949552, 0.015599023899994792, 0.032692200789648684, 0.08132024848413083, 0.05377832274403303, 0.06938125081961194, 0.04453634144738317, 0.059277615960567236, 0.04415127884356245, 0.017565472967802517, 0.04178077297946138, 0.03903410262278011, 0.02539711320892938, 0.012786816636611138, 0.042254981404591, 0.05789582317154254, 0.03373034951847888, 0.07410831974759217, 0.020456133380291924, 0.04789367197982727, 0.0780764866560217, 0.09907602152276425, 0.041525198387042175, 0.058911261223857446, 0.05082868122225327, 0.014672360116345508, 0.11499331377807165, 0.10884365787909878, 0.13239346114137482, 0.10876462058795076, 0.11986635309914428, 0.16250338255157395, 0.16493198852385246, 0.09464564312609935, 0.11763945041644959, 0.12523666009186737, 0.23399818568460404, 0.12856959455436276, 0.16207497086255782, 0.11931015794435818, 0.15936951603620284, 0.11352016500407651, 0.19332970342328473, 0.1457498823442767, 0.14079684812215068, 0.09728247945707652, 0.08536703899622926, 0.18845850271323036, 0.12478922643969137, 0.09029227188758313, 0.1442274358123541, 0.13303236314846625, 0.1541428811727993, 0.14613706318120803, 0.13760580080411128, 0.13036383376006158, 0.22887189301752278, 0.12217004843536886, 0.10298444889485837, 0.21213449597839387, 0.2464025741022441, 0.11645782874116015, 0.24745678769484644, 0.777724615989193, 6.447973539752345, 29.7382104012274, 65.88349480782786, 89.17354045375701, 92.40302393513342, 85.65944194793703, 82.64699889767556, 69.83717333885932, 60.602607803960005, 68.97155331027123, 43.88381873407672, 41.03844511893488, 29.1511433739816, 36.318798295913204, 35.39913977346113, 36.77409525840513, 40.36112239283901, 30.655886165557373, 48.94812030176963, 49.253747463226325, 49.31315568185622, 27.470898051415723, 25.196037100207423, 14.083249511257296, 6.548109689066488, 1.2986825454619624, 0.3505614664285414, 0.20846208497401209, 0.2909363836290375, 0.15245728855652196, 0.4469370739834924, 0.5159703906505338, 0.6814631555349596, 0.3178019533234258, 0.47043780165333904, 0.4171895121614779, 0.47819900777070756, 0.31746260701648654, 0.6045771005653566, 0.7756176903363198, 2.361488457648985, 3.2463636465611, 1.5178931504487994, 0.5690368108691708, 0.3355811992960592, 0.23335788939749044, 0.44808819769851627, 0.40571875509715855, 1.016677980942111, 7.444742427718255, 7.061280733154667, 5.545177286671055, 2.4324625201763648, 1.5042008916216514, 2.1121948669033666, 0.8409263794460605, 1.9317397307003699, 2.0770938213794463, 1.8672721448444554, 1.2747820731132262, 1.4813724520706362, 1.9753405523876992, 0.7068720243630872, 1.0918286322586, 1.475734902966407, 0.39047041847821207, 0.4636806610130495, 0.2965457100541361, 0.3090107573136207, 0.2651147772708247, 0.323131749586713, 0.21231953685562457, 0.39660534250640106, 0.36911231615851003, 1.1893698885556192, 3.0817969287595446, 7.415812005919795, 16.92314651704604, 32.376086711883545, 47.45167724547848, 38.68505439450664, 38.564123799723966, 46.62909738479122, 87.4111803116337, 32.05892778212024, 34.17825106651553, 32.76126542399007, 54.53736051436394, 62.097266181822754, 70.57948189397013, 72.6623938160558, 82.765101463564, 80.87510739603351, 78.08900863893571, 56.19694671323223, 22.05603268838698, 4.79316920042038, 0.7782676191099229, 0.317090564076939, 0.2473394077030882, 0.1387866487305972, 0.13062793491107802, 0.15354479633031354, 0.16068433741888694, 0.16011354062826405, 0.20625703877979712, 0.18252789433444702, 0.09916853430050035, 0.19664531663781215, 0.11050311157539969, 0.2295987265965631, 0.10557033271799166, 0.15203266134185178, 0.08047653287048302, 0.1732860087987877, 0.19698029624358301, 0.17373925705830898, 0.1219037639337682, 0.21423860242770565, 0.2638928057445634, 0.12744977319192502, 0.1905075274407864, 0.1260460166621112, 0.18240677583361828, 0.15151768171739194, 0.15358725292307718, 0.14963892769188653, 0.17001907281096906, 0.1188311231653056, 0.22837424230191017, 0.1046095435477553, 0.1297030676036112, 0.1847728690312755, 0.14202810463405427, 0.20229765123897986, 0.16861628921281907, 0.14131466227193035, 0.14502122547597657, 0.15115290129136655], [0.02548203597055568, 0.06413517647512978, 0.03719038562849164, 0.0472998810601571, 0.030378883389095147, 0.07952196433419183, 0.08646979958059327, 0.031399124812695293, 0.04362577700146264, 0.057184663751432975, 0.09699129709793676, 0.039875301637596665, 0.009891533841108604, 0.04871806685602473, 0.048670002499655377, 0.06781741255714048, 0.030191143967151165, 0.06202270434568487, 0.0258113848300831, 0.06270521590786596, 0.051372779848714994, 0.04768685505334889, 0.024682784100033106, 0.03988393161806368, 0.02563187319244589, 0.07660346045609444, 0.03775167909841384, 0.0468057926533924, 0.014593164819563109, 0.06861922316133015, 0.13894936580571438, 0.02099991408026507, 0.029337183842735908, 0.06223887137527909, 0.010047548604498227, 0.12224311024070748, 1.2385364309433968, 20.562325485291023, 45.18260179027435, 46.28050065809681, 63.38721213802215, 59.475495123094134, 53.34620729569466, 50.750351336694536, 38.709545673862586, 32.384468816941784, 49.003386497497566, 21.348229223682036, 23.025542574544108, 46.05572923537224, 29.895399385882964, 27.09483884995984, 48.6991439327117, 38.66473259464387, 44.603263793453095, 45.56704113560338, 36.80286976598924, 14.292145140709417, 7.778508182494872, 2.372587294347825, 0.5579840007328218, 0.05815183060363897, 0.05460605393314073, 0.025286836767449014, 0.05634298593166375, 0.10761355815996086, 0.042933049656811266, 0.14650725218797886, 0.2645460029523219, 0.22172372577892197, 0.1801535886742415, 0.6726793139692276, 0.7986945262359035, 0.8811876706538663, 0.6349682988178346, 0.9975956500537935, 2.0357915086130944, 2.963175384267684, 2.4614007867151693, 1.9591895803328485, 0.3538004555288823, 0.3488298319280148, 0.17080575317865418, 0.06030159206279825, 0.218960247453182, 1.547471008473827, 3.5602135667877817, 6.383838374768534, 6.95483398052954, 4.036592288363365, 1.0053529950880236, 1.9681438611399744, 1.746446841186093, 2.784641596578783, 3.7301223076158956, 1.4687977010203948, 1.5629621643212535, 1.3232314346298095, 1.0193011885689152, 1.8911340063618076, 1.4450835412548435, 1.5307121916163353, 0.35932566549989486, 0.7287632013040205, 0.5847042895132496, 0.06774277261067783, 0.24889018416645067, 0.19130574509261117, 0.2143157474816807, 0.049648059291705016, 0.04037974755309763, 0.014603078954913204, 0.03173135990847743, 0.5623250839210326, 2.3448338287491954, 9.319378945135302, 18.240307838686054, 43.5003403694399, 64.62812454469743, 80.0854479882025, 42.576806545257575, 28.33542569991081, 26.801676980910766, 20.71571369324961, 25.777877569198612, 30.870506494275986, 40.98900756528301, 49.52156689859206, 41.53117325998122, 54.7819124498675, 64.11234463414839, 58.14313265585131, 45.98559333432106, 24.285086239537886, 5.378023520592721, 1.2376237444339262, 0.20398776377401046, 0.0797072350377998, 0.08653281031236534, 0.09240413114668862, 0.08435469976956807, 0.0847771512945333, 0.03794350751465367, 0.09728255606586896, 0.028764429697466475, 0.027309161415624044, 0.04305275472541971, 0.06733627869717537, 0.01337860806679894, 0.12502764832348595, 0.01008523151188368, 0.049321085304742864, 0.012742598041621669, 0.01511603898008264, 0.002590691743065573, 0.11474195266923598, 0.05011746051510976, 0.055650622478776404, 0.061201929234929626, 0.04149099256122305, 0.039605979597376245, 0.06409651584803097, 0.04454581795500652, 0.042993857885801026, 0.032799533538279996, 0.02155348921435014, 0.01471255962256222, 0.0755095175437389, 0.02426778852579094, 0.04089308774939949, 0.025732824428667946, 0.05409076404307158, 0.05601696955460695, 0.007786408494857531, 0.025207929711248127, 0.00994208223757244, 0.008883235728247993, 0.059167444856176456, 0.03339006475383236, 0.02273364957692402, 0.046037176638961806, 0.01974445493561366, 0.020734372683950973, 0.02830566943532998, 0.061608733414041425, 0.07791372361562907, 0.025071462638856425, 0.03501328632175442, 0.027776781484604846, 0.03752196380387872, 0.03341770903658002, 0.022243337983626033, 0.04777873963898709, 0.040514188322929606, 0.05537563904879555, 0.07241508923470974, 0.004750687897490759, 0.02831249719395513, 0.0391191843476507, 0.027093879217582367, 0.04291562881741313, 0.049467856259716135, 0.014933268595937521, 0.08133271273465888, 0.03350892329528447, 0.06583448589569138, 0.04150034649477851, 0.06452447554517178, 0.08981593373802402, 0.041456300269572005, 0.08475426058735579, 0.0889965950421268, 1.8213179010537364, 24.477290222721717, 51.591393793782885, 58.738426854533536, 76.43845173620409, 72.55361864643713, 64.6544397261835, 62.01570049408944, 52.58640496961532, 42.33243503878194, 58.99651096713159, 26.726124286651615, 32.14491398103776, 48.05269810461229, 33.84634794727449, 32.262975362039384, 40.90329200990739, 34.713372184384255, 32.3509305907834, 40.04732493431338, 28.4470740056807, 13.351846125818069, 5.345800759330873, 1.869799989846445, 0.5167451813336342, 0.15374558797526747, 0.11433424833681315, 0.030565333868106528, 0.36472793368081896, 0.5810205097640715, 0.5067022895861057, 0.7202240175777866, 0.5165683069536763, 1.2326321606674504, 2.062806833174921, 3.2158912429886484, 1.4964175608850296, 4.018701132266752, 5.062999340795702, 3.7909087490650917, 4.758874937411278, 4.380771690799344, 3.4036575546187744, 2.477697499336735, 0.6855820732251291, 0.10219530172405705, 0.15073340686578907, 0.04611075938408894, 0.3052606037066829, 1.0100409628883487, 5.783558843597289, 7.275645127219539, 10.691002376617925, 9.580184202040396, 4.944619267217575, 4.92866502654168, 6.208769265682467, 5.291144982461007, 8.444196178067116, 5.3675125491234565, 5.814431819223589, 4.197046891335519, 4.00491179477784, 2.2363170452656287, 4.062830738482937, 5.52788257598877, 2.235934369025692, 2.454542522468875, 1.5992139351944772, 1.2633256878583663, 0.9018195216213504, 0.5300112501267464, 0.8523584950354792, 0.430444058992209, 0.054337823568212415, 0.07631078422550233, 0.08485351493882556, 0.36218436855462294, 1.6196347749040974, 6.618948674971058, 15.36397691695921, 33.77664350694226, 50.30642532533216, 72.88549823145713, 50.09617843935567, 25.40623691774184, 27.262300522096698, 29.75395283391399, 41.24997069758754, 37.18967430053219, 49.44189963802215, 56.91595638951948, 50.340859813074914, 64.60482566587388, 73.90199615109351, 66.30578502531975, 57.10315150599326, 32.664673136126616, 10.175975561141968, 2.253406321810138, 0.4440656845127383, 0.17580611631274226, 0.04238392549356626, 0.04980267881746254, 0.07928148167388094, 0.04716622936088712, 0.037782529459124616, 0.06071061023601121, 0.03426040575328854, 0.014954511256467913, 0.03581728027652829, 0.026229138320852673, 0.0025305926242107225, 0.04295253510316534, 0.007176223293607755, 0.02794412381556486, 0.03877320371928715, 0.04906574819958018, 0.024307485286807342, 0.025779959903429114, 0.04971019285280378, 0.09019072693321975, 0.050622932988429264, 0.039572068715407964, 0.002665163868392307, 0.039394378451810735, 0.05523803050539667, 0.046809822275874116, 0.005288327923945842, 0.029766173928134868, 0.014123588353545677, 0.05286667811413927, 0.08486128307037777, 0.053549607194239096, 0.0074909528015151385, 0.029785324211022066, 0.014391135942611485, 0.024721699451366742, 0.021334640877020937, 0.08153484503348028, 0.12354920588193402, 0.11944936378107918, 0.12295676710745021, 0.16563781597200902, 0.1300996560002527, 0.23368113253626133, 0.13352619874621593, 0.12778511285902033, 0.1602643373752794, 0.18098480939384431, 0.1285173780014438, 0.06281093987185629, 0.1744411927798102, 0.11246668685588146, 0.18798185812850154, 0.14829913184287088, 0.13891083158312306, 0.13430322640605513, 0.13533457993499695, 0.12460698944426353, 0.168724981767516, 0.27117100874743155, 0.09702159587534205, 0.1287147835377724, 0.13510463098364492, 0.1489002503935368, 0.20708715633278896, 0.17232587080328696, 0.08562714116828096, 0.21248004759751984, 0.2117195521150866, 0.09442362318476362, 0.22612453318170964, 0.1794893444786149, 0.132062143435882, 0.3318729047333041, 3.979224192519342, 33.30264468346873, 66.60630918318226, 74.71611545931908, 88.9435326668524, 83.37642638914048, 75.3529828594577, 69.3239704255135, 56.97137948005431, 49.29980785615983, 63.24228448252525, 32.70802709364122, 36.960325471816525, 61.337197134571696, 43.580639131607555, 41.457471924443404, 63.58517416061894, 54.55060243606568, 61.122976887610655, 58.018636626581994, 45.533928486608694, 18.44418675668778, 10.133454126696433, 3.186184927340477, 1.0353521401843717, 0.1596357469116488, 0.31312946049917134, 0.10392870588768875, 0.37844565727057, 0.26741926167761126, 0.32087592708487667, 0.4493692499254981, 0.4485392702683326, 0.6045447410114351, 1.0253220880704543, 2.312305367762043, 1.4999289402077276, 3.776162353254134, 4.855438297794712, 4.167771300961895, 7.3457981886402255, 6.29967313620352, 3.9461559153372243, 3.440867364406586, 2.6186503229602693, 1.2009461512488704, 0.4478557666222896, 0.4073933007255678, 1.1957493784927553, 7.143884868391099, 12.797953524897176, 12.579053890320564, 18.914157305994344, 15.871321770452685, 5.090855523463219, 7.170367731202034, 6.42397451785303, 9.73583463699587, 12.235618022180374, 8.254580959197014, 7.209815008025016, 4.4869438775124095, 4.659710065011056, 5.1056860050847455, 3.8433076921970617, 5.2740282493252915, 4.080703263321231, 2.205081495546526, 1.5948164679350394, 0.6662350436372142, 0.5949777124389526, 0.421685774119631, 0.8590788021683694, 0.38303369656205183, 0.1799436346177132, 0.3369456938197536, 0.18668621958744142, 0.8399194947654202, 3.157487641419134, 11.486414920899177, 22.79926496167337, 54.75985304001839, 75.944044820724, 92.67951965332033, 51.957919674534956, 39.518813010185, 39.3905750397713, 35.87840634007608, 39.77235894049368, 44.205088307780606, 57.402185163190296, 65.20208497201243, 59.957122956552816, 74.95977309442337, 84.23937920601138, 76.76759350684382, 66.69602947850382, 37.71333425275741, 12.388994463028448, 2.9700223716997334, 0.6603586589617114, 0.3115459261161666, 0.21062320368664883, 0.1783961982977006, 0.1550546024114855, 0.26996723947025114, 0.11294205973465597, 0.2776666376138887, 0.0969931127263173, 0.16028232511974153, 0.19104380430954118, 0.21476562495433518, 0.16772738207251797, 0.21184797909471298, 0.1100985635252249, 0.1611561556496928, 0.09557324536745587, 0.16022577250917114, 0.10287461486915428, 0.28384590281113503, 0.25506564956759253, 0.2648404871504153, 0.127561338576338, 0.15222723235286054, 0.12169568679265438, 0.26740430764132933, 0.16306832643045535, 0.08243931908040278, 0.10608589456927393, 0.15119045492141478, 0.16793675390222382, 0.17097167250129486, 0.12483898385037338, 0.21486501720163131, 0.1227215781146961, 0.1048239715577614, 0.14627166482950413, 0.14707964244148425, 0.14794250259235983, 0.1253822551018769], [0.022715652256362864, 0.0446208217932332, 0.09423219313424441, 0.07392573035171918, 0.04448313281060227, 0.06035336811516074, 0.04823243989038372, 0.05274687728454029, 0.03503628428124132, 0.03434243844822049, 0.04857462455308245, 0.009281777649096424, 0.016753458072461428, 0.021468250441455075, 0.0913676601504126, 0.04228442599396071, 0.08723884460426147, 0.06752140384407775, 0.04800392735388972, 0.06277123353474083, 0.04769052844494582, 0.04516305116515967, 0.07212185375993291, 0.06114448796236708, 0.02216655107575559, 0.02555379159598341, 0.03359872029132901, 0.05387892924068917, 0.03649530639391273, 0.0629902197678964, 0.07669194361134883, 0.031091191941091133, 0.023321968713595022, 0.06638011669800167, 0.058095071149329026, 1.583918407559395, 12.906146222545257, 40.858710350528845, 58.09134168009604, 56.9384394153472, 60.89762103173041, 53.19581185617755, 45.99771738052369, 42.25739225264519, 29.93788257721932, 23.6882838895244, 23.69620511608739, 35.26133121982698, 35.99805824218258, 30.80356340254507, 36.63261928865987, 31.13975955593971, 52.762739043081964, 43.77074856911936, 32.81714154827979, 12.340058972758632, 5.301560836453592, 1.8758264664680728, 0.7938434123512238, 0.20329653796169067, 0.07020335509291581, 0.007498632354151098, 0.1276556439998169, 0.12133169543719101, 0.32651926781381335, 0.7195779909529995, 0.4368310565910032, 1.6354051544781656, 0.33715489711011615, 2.6325690986648684, 3.310331865664452, 3.4593819322124606, 0.9864583250976379, 2.809162784007288, 2.4887433840382487, 2.359569928338451, 3.0902883698863373, 6.125755733059299, 2.7566623495471094, 5.035137274572927, 1.1974052315758121, 0.17384509976592757, 0.3522300672146582, 0.32752060601788185, 0.204284239800707, 0.6048052721927243, 4.141611053097633, 5.758123253622363, 10.53232289129688, 8.198166979897408, 5.0735377688561725, 3.2085956344681406, 5.644153395006734, 4.029738191635379, 4.189910138806989, 5.526435221395185, 6.645506062815267, 3.119881181947647, 2.7120968699455266, 2.4042587174523264, 2.4051493406295776, 4.701556851786952, 2.3138917213486088, 2.7306759117111086, 2.369221410443706, 0.8955412165772532, 0.39350008171412254, 0.27746748539709276, 0.32356740846749277, 0.1381025781794902, 0.08897279269031941, 0.047026330214594646, 0.19939342723979106, 0.010241367891731282, 0.07270784207409428, 0.11599113563856772, 2.0219584121819465, 7.492827744253221, 23.08144615542504, 27.15002855946941, 46.64408083884947, 58.723345341220984, 39.70978144676455, 17.72136453659304, 12.574099936792928, 24.425316856753444, 21.323110365098525, 48.07288262151903, 37.99006139078448, 42.343990341309585, 55.633360955023, 60.764668372369584, 61.67394830334572, 58.375925325578265, 41.220780418765166, 20.8610688870953, 9.26650147284231, 1.339093009310384, 0.2514130036316572, 0.05219650439797871, 0.012820291806072479, 0.07398805160435938, 0.05010854325167114, 0.10100395073212924, 0.04626240648870026, 0.0715459548237343, 0.05103162174383479, 0.06770121234078562, 0.021505813647602356, 0.07529415490646517, 0.04057843628669939, 0.021728634150818955, 0.03081113700905154, 0.08946795362017809, 0.012722323524705585, 0.0017722153748881313, 0.07729161425583786, 0.05849694555264808, 0.06796552799642086, 0.03530493216408837, 0.038255381908628254, 0.03367463194374596, 0.007741679972593463, 0.02123601471764907, 0.04017892909506637, 0.0209043120529743, 0.038118907175357306, 0.00647700479021296, 0.06197833253311054, 0.017645333803469138, 0.04779036885367767, 0.05649980796020358, 0.04066632572381247, 0.0419139497042183, 0.011808978179619919, 0.025850876662579757, 0.08061693380436591, 0.049357585563895204, 0.07672994157239314, 0.04035961476244754, 0.016630748023969993, 0.03890724995383813, 0.09261053821612751, 0.026821287897145076, 0.026582911978625966, 0.020232422299863353, 0.02747751881308373, 0.037518623660528855, 0.09304209852651243, 0.06920886571489035, 0.09214039771787583, 0.04764953124967795, 0.06505324475226865, 0.03514897581490298, 0.03377273716332932, 0.040697199067160975, 0.037086232144746094, 0.005890078018344338, 0.08144514379842628, 0.030888555939459515, 0.10117179293545986, 0.019455130339690277, 0.035304223532758416, 0.0357594023338489, 0.012845609096750137, 0.032604947205512755, 0.028900891024198745, 0.06778761939776522, 0.028479218993696476, 0.04984918801534561, 0.044831530446366924, 1.5465631023530038, 15.325599466600726, 46.354590308281686, 69.08647091157975, 66.46443705404958, 73.3960182436051, 65.81948172661566, 57.20492916722452, 50.80275420219668, 41.81076372823408, 31.867239590614076, 33.20344401944068, 35.598772725751324, 36.54362855419036, 36.72766616267543, 38.69520941088277, 32.41063690954639, 53.476645715775035, 42.52627072795745, 29.326590991789296, 11.780164164881553, 4.6131735943978835, 1.4586011320352557, 0.616199144672963, 0.2383695293458239, 0.09814906279526411, 0.13572605086430428, 0.39404575082082904, 0.9643923575359007, 1.1017264882403037, 1.7875959363675888, 2.6513371496431293, 3.755324761713705, 3.199102272910457, 6.212919623621049, 6.207962728315785, 5.62684593662139, 6.887244188016461, 6.835676297064751, 6.5657873211368445, 7.247744327591312, 5.7974685488208655, 4.955567582961052, 3.9145335218598767, 3.1717268257371845, 0.8443472991066595, 0.26315843386034815, 0.03643991823698725, 0.10623327456414701, 0.33269660246949045, 3.0691950888403, 4.713776505762532, 9.185634947592213, 8.690657327252051, 9.310861518306117, 8.181351778968688, 7.945495738137153, 9.850687519196542, 5.96667665627695, 9.040693563799705, 9.523948200287359, 10.010009292633304, 7.9127424763095, 6.111179224906429, 5.5974409080320795, 6.903987805689535, 5.969009485936934, 4.61594327803581, 5.414210817506237, 6.217351411619495, 4.914772971983879, 3.188344437268473, 2.4354236645083276, 1.562993543282632, 1.394826579959162, 0.770997689856637, 0.26048748363410273, 0.3555313239414846, 0.06294410127485472, 0.03326301673246968, 0.06351690521583923, 1.5008206665515902, 6.985925628292946, 22.062498715616044, 30.699757875934726, 38.06240950861285, 45.15405478016023, 36.216389133084206, 25.903061974433164, 16.071188103768133, 36.326764629733184, 33.77437245461249, 53.38150470487533, 44.622428494115034, 52.02365859862297, 65.22539954031667, 70.69978098715507, 71.03003671092372, 71.0882446842809, 52.290183651831846, 29.958263212634673, 13.313830514107982, 2.3468746869794788, 0.2391177980649856, 0.07057460130102212, 0.025202511554403652, 0.04101856529051739, 0.019326921695122318, 0.04372052675593765, 0.061161272948788065, 0.03773672506213188, 0.049237665990667964, 0.04631502906821909, 0.07872747753055827, 0.06245256011043826, 0.031149521875645847, 0.037977169418046554, 0.07125695581517874, 0.0247326813217613, 0.01796232757999772, 0.013454511100726744, 0.02842373316056065, 0.012168340448800836, 0.08234514389187098, 0.00778079211276265, 0.02518196124583483, 0.07524061302143721, 0.03848516232063694, 0.012774994942329585, 0.07330437941897301, 0.07034614622112244, 0.05019734816385373, 0.02672274026178545, 0.05250276719790794, 0.07941767678505952, 0.01733702171834246, 0.017190626146452084, 0.021708951436824376, 0.0405679868474122, 0.05074710051919665, 0.015526950348078486, 0.13995490217160794, 0.1523707819081122, 0.2652643482771612, 0.23270889035155698, 0.13925747104710148, 0.14301880953773377, 0.14100574497734347, 0.16541350542777972, 0.08519622437175244, 0.13370717935744794, 0.16870107982427845, 0.12202124351695662, 0.22828655587809704, 0.12978677037021807, 0.288153737783432, 0.0667257372650408, 0.1623035868209216, 0.14049655697759122, 0.10505457934472831, 0.19275271664223365, 0.11200006270120222, 0.12935987553529202, 0.1664987762248324, 0.14619009178732673, 0.31703865395918973, 0.15032820764087862, 0.13473804259011823, 0.1569946128274164, 0.09794375123155695, 0.09813099078113034, 0.1462852092640054, 0.11908840613379595, 0.11231857907748032, 0.24839215040687593, 0.21975316377657078, 3.461791983535213, 23.735366059887795, 62.115254171432994, 82.97443051492014, 81.44567889551963, 84.00784169473957, 77.07743721623575, 64.62457479969149, 56.96548023531514, 44.5175874617792, 36.754318667996316, 36.200750643207186, 50.164612031752064, 48.782211888221006, 43.65991415516023, 51.39706388596566, 45.24009589226016, 69.19643848173081, 57.833508599189024, 41.36753589876237, 16.266323078063227, 7.11753438557348, 2.633738700420626, 1.4152747536859205, 0.3320599527608964, 0.2553178763557827, 0.1812744212727393, 0.39287627163913946, 0.4748221228439962, 1.1261063477685376, 1.5309695971588937, 2.65666397348527, 3.555621206760407, 4.210710958127053, 6.468686105743532, 8.598451229833788, 9.932143380565028, 7.347712795580588, 9.326633368769, 9.854803066099844, 11.719694945120043, 9.55357680397649, 17.55181420233942, 10.125103400599572, 11.117596414781387, 3.4751324547875315, 0.40654836703212033, 0.8391963077648994, 0.8854530030681241, 0.5816679459906394, 3.806703643452737, 11.380705083570174, 15.33600845644551, 18.966954369698804, 21.78736798224911, 18.790771307483798, 14.676142238801527, 18.22025864355026, 12.405016364589816, 11.556806756604104, 17.223841298011042, 19.093601819007628, 10.890713776311568, 8.807847942075423, 9.757718520779765, 14.220258881968839, 14.123342017973624, 8.825510374961361, 8.525978576752449, 8.140083051496937, 5.810176537882898, 3.0445827063052886, 1.4457133268156361, 1.224936715537502, 0.9250716997250434, 0.6641678319823358, 0.1976248979448311, 0.5391733552659712, 0.2159120602112624, 0.2110533773778908, 0.2851434718937643, 2.908799811717003, 9.821756116805538, 29.50297997843835, 37.011700676333525, 61.88882750849571, 74.53509023112636, 55.584217579134055, 26.219609014449585, 19.27457017283286, 36.424282596957305, 33.93801766057169, 61.62592280295588, 52.910745759164136, 60.7100611348306, 72.70497506664645, 83.36370222030148, 81.03283374540268, 83.68626225379207, 62.431275613846324, 36.34056745036956, 16.086525551734432, 3.2303562087397424, 0.4335975833237172, 0.28784984602562846, 0.1449594328240041, 0.1392774965854422, 0.16743876610792455, 0.1554316249225409, 0.1547079323039901, 0.18548497840041117, 0.1091153969267203, 0.09824896066059029, 0.10487478616977892, 0.21403090066967473, 0.11484754256783955, 0.19392286998129663, 0.14645610815815388, 0.24773352929661352, 0.11403368906148019, 0.08360652298095726, 0.2794352281958826, 0.11558958299217686, 0.17663531456022494, 0.11597231285826815, 0.14462934085919013, 0.14292212924168957, 0.0977480004451448, 0.09667589869951049, 0.13268802194826065, 0.22234342962263093, 0.14906319729503126, 0.08467914566638009, 0.2722169026251762, 0.1607717786945643, 0.16504207535857157, 0.10682392069288801, 0.1821349218728081, 0.17270825592981232, 0.1474600050958895, 0.15101535786544124], [0.059033456078219804, 0.034448817417386084, 0.016528521251354008, 0.05261714029456339, 0.10788590241704257, 0.03235553962088401, 0.026904814463529377, 0.06498880909695741, 0.018737016756448056, 0.06456471814383423, 0.05005424293959814, 0.04063398915252859, 0.024030737939380833, 0.058519418741906845, 0.09221813265955256, 0.013777150945257277, 0.07293051319016565, 0.02564089962341372, 0.04319031347310351, 0.0215563811962643, 0.07073357220618956, 0.03493431797851959, 0.05568129280882497, 0.034942472984473553, 0.03500004832242285, 0.03760576999235538, 0.042996998846290574, 0.06290227287418901, 0.025324888354648026, 0.017958460751199917, 0.031755922602549676, 0.045658139316665555, 0.04695185880747534, 0.060119784076608, 0.5653716623783112, 8.043329456160146, 32.750553431049475, 59.28666830062867, 60.41798576231926, 62.22570811548541, 53.504706351987785, 40.9860618652836, 44.17237966291366, 35.92458440411475, 21.48748513190977, 28.31248179558785, 43.51264876704062, 36.786376199414654, 19.485854525719922, 28.042338355895016, 38.3127861638223, 53.95452768571916, 31.291729827081006, 20.17438934695336, 5.695330519830027, 2.7801990220623636, 1.0682332467648292, 0.16157200349675072, 0.028214639037727352, 0.024958742376897606, 0.07095006865359123, 0.17413746956134998, 0.6573351857162292, 0.7916831669788208, 0.9405269413705796, 3.117200241934869, 2.7938625985576264, 4.013322091871693, 1.508009758207106, 7.176359641936518, 6.178286565888313, 5.0491092474229875, 3.7174241244792943, 6.361104807546062, 6.718611688383165, 4.256267326493417, 5.330373587146883, 2.707605510950089, 3.319930150624245, 2.7280824895828, 0.09903828403161419, 0.11178676850132405, 0.12860013081902458, 0.2760926027211451, 0.2357678947549674, 0.23391895687147496, 3.008629280713297, 4.906715443057399, 7.247182448064128, 7.982103218955379, 4.7628056426202106, 4.658366162930766, 8.005170187642499, 2.4907827713797173, 13.745554031864291, 4.468616112585991, 6.977507731606884, 5.173611160247557, 5.165020188977642, 1.5475613455618582, 6.239325509917352, 6.066210231473369, 2.028915716275092, 3.308683489599536, 2.8285954315816206, 4.972088606126848, 3.895632845740165, 2.431038454655678, 2.2326474228212914, 1.0079912793251777, 0.1557100519177414, 0.12488298794074405, 0.11178282314851401, 0.10507504921406509, 0.04260936218704428, 0.0957640165823602, 0.05172598085576489, 0.7060627903669112, 2.2639925537570833, 16.838917539965724, 42.19308107129989, 45.02571482812205, 42.03994389503233, 29.388550712216286, 31.992225916154926, 13.861113921288522, 25.600817857250092, 84.37626992502521, 35.720644689375355, 24.7004730855265, 45.403980362799864, 48.153522629891675, 54.47503405232584, 62.730022938020774, 65.64210822505336, 60.624588766405665, 41.14971491598314, 18.084821162685273, 4.8347340668401415, 0.567288353077827, 0.17402269426853428, 0.09919154758174574, 0.0019327305457291885, 0.04308831652686481, 0.03801280399784446, 0.04997150161333623, 0.012122994746952769, 0.027883189182067593, 0.06235147097838983, 0.033626942970459504, 0.016934844710293318, 0.15920840774572667, 0.012216447897615933, 0.028366575340530085, 0.028363767628287597, 0.018242055009449684, 0.019155622520033392, 0.021087169579620806, 0.03331038777926757, 0.022181505112037547, 0.021004912803971, 0.08350799641301555, 0.07412944845254384, 0.07091171829210174, 0.04903158067815727, 0.020206400208295356, 0.03705266600234374, 0.014980336080395408, 0.031688223412681016, 0.06845538759784353, 0.06439210321273535, 0.03879734698022085, 0.017493483685557882, 0.05619804975726912, 0.02104962744089144, 0.05715927942806194, 0.01651400196996908, 0.038416704703723235, 0.033045493727249485, 0.014142556690550862, 0.10623959478952232, 0.02649568903800701, 0.04390056124858318, 0.030789575464422667, 0.019643427090599172, 0.0486841827871338, 0.012317877938790668, 0.04075176751000747, 0.0013676766614099185, 0.00525604066957209, 0.06679191193994015, 0.025448588571781595, 0.039896460986065294, 0.014149172817386929, 0.026541139119334763, 0.022692263592034582, 0.02626985397880837, 0.033347190643150004, 0.02604981437475691, 0.08060554207693185, 0.02690468614380206, 0.07218299523716973, 0.09417014767325695, 0.021249800469846498, 0.030989512921341007, 0.04528378662202628, 0.060677227954710686, 0.031542404321953654, 0.04350237938905916, 0.04355767561543373, 0.489907221448037, 9.537481357974391, 40.48291983142976, 69.49547213892784, 72.6531840908912, 73.44090584785708, 62.192289521617276, 51.91090614564958, 52.727794647216804, 42.792105444016, 26.899471475232033, 35.290807831671934, 48.08375543163669, 41.80868879441292, 26.90448622549734, 37.782826885100334, 39.15793142011089, 44.87556257555562, 28.382090137850856, 18.83210720554475, 5.896897200615176, 2.511462977816982, 0.3331752848480979, 0.1557593266930311, 0.10312845810286461, 0.12977800632436431, 0.4614273819231218, 1.5017170507100321, 1.71106313986163, 2.0636420528734885, 3.1153160333633427, 6.04725488731938, 4.966799780245751, 5.744721985632374, 5.523973934112057, 8.777715313819147, 9.905083929338764, 12.124349205724656, 9.5984467575627, 12.830760229018427, 10.807014319204516, 10.14222356580919, 4.602112020215681, 1.9010425262874173, 2.878697336681428, 2.571154832839966, 0.801693362093741, 0.4263298910471701, 0.5823176498374631, 0.460990681162765, 0.4286984510479435, 0.3500856338970123, 3.8404833405248584, 3.3936376148654572, 5.838407306901871, 5.652662977095574, 6.292149539916746, 6.784384933210189, 9.219212397452324, 6.294400980395656, 7.348367831399364, 6.99127427031917, 10.690126707476955, 9.831259039140518, 6.641408166577739, 7.199925241931793, 6.673510314956789, 5.806647385320356, 5.471893683556588, 6.4843692125812655, 9.17753231140875, 7.479469622335127, 6.0707248795417055, 6.247935602741857, 4.384185623738074, 2.4401449724551174, 1.231972344460026, 0.9839860061483999, 0.8357214555144311, 0.4335699735149261, 0.2711242773840504, 0.03376232985887797, 0.00900041940997565, 0.5196036085967095, 1.9751636780077413, 13.31673699040567, 38.891500503786155, 43.74753990480977, 44.81280073042839, 24.796753544961255, 29.77498850514812, 23.004946208769276, 26.773065251688806, 86.18051313584851, 45.967009144444624, 33.05926161427652, 53.65116373185189, 58.26968400709091, 63.51885472574542, 73.1831512143535, 77.16484331315564, 72.72837592709449, 55.76170090706118, 25.225264641546435, 7.614003487171666, 0.8811103877040648, 0.16822206036698434, 0.025887204551949136, 0.05533443884022775, 0.0438900045569866, 0.03501402176616173, 0.02964272843523612, 0.06945527023485593, 0.03760741325095296, 0.01212203905226723, 0.05543221081156404, 0.01686509815044701, 0.055051346369568384, 0.032333878484824975, 0.005164933184372081, 0.0701667360901352, 0.10175965050415647, 0.03787708386117893, 0.053615027272533027, 0.02487509706688504, 0.03100213805033315, 0.08521788933825108, 0.10221522767096759, 0.022678236522141005, 0.008355837818535586, 0.04262687112655371, 0.04226804320369998, 0.04361839957475182, 0.0423621877487148, 0.0440999049873602, 0.07841031712990615, 0.09454674117507474, 0.053549028797856266, 0.01622411429942135, 0.04044647764174208, 0.040750664343396505, 0.06645654162932789, 0.16989459884503197, 0.18630463119235732, 0.13703046877297664, 0.2640079947248582, 0.23146385957877483, 0.09220283388370469, 0.14186999940824124, 0.1794829399835679, 0.16878288269283312, 0.1285101461314386, 0.1629700986368041, 0.12821498011509258, 0.15090219135726654, 0.10673233488154028, 0.23019302696470292, 0.12762110875619034, 0.1316684355298358, 0.1462425228448645, 0.15019892264277707, 0.08682776948497181, 0.16189668688081926, 0.15253808018901657, 0.17471767391168302, 0.1927005920198656, 0.23725940665650755, 0.18204643871755372, 0.15388034284114838, 0.22455160145557698, 0.1289998295326387, 0.1527962518194991, 0.08376564710370957, 0.17772760272266405, 0.22183595765982905, 0.19270051541107316, 1.279182604724361, 14.081334414020663, 50.77756081857989, 80.83764091614755, 85.15478980156684, 85.43290938100508, 75.30592226213025, 60.00354812991235, 62.10862928821195, 51.50624305971208, 35.49632041685043, 41.19870531943537, 56.32798525594897, 52.50541979266752, 33.21300675792079, 42.87937818035003, 54.819304404720185, 67.41216013508459, 39.63328738366404, 24.878203522774484, 7.146961967791281, 3.6573437096611148, 1.3747028597900945, 0.3633839396699783, 0.22982846104329635, 0.14994514835697992, 0.38536772131919866, 0.8121375306960076, 1.4126564490218319, 2.350078037669582, 3.4948960523451533, 8.221177074217028, 8.30272020832185, 10.75554007484067, 8.20098618345876, 16.020597373285604, 15.682281178812827, 16.63980822409353, 13.407822270547191, 19.447978158150953, 17.79572875268998, 15.90064246808329, 18.24916062816497, 15.217658781236219, 13.241630465753618, 8.27058913246278, 0.9513034082708821, 0.583960632643392, 0.819341944110009, 1.4067776741520053, 0.7093065904994166, 1.8588758211943412, 10.23876094049023, 14.913658422808494, 20.65337154173082, 16.956757307052612, 13.910927041884392, 15.306496543269004, 21.07357309710595, 13.853932061503011, 28.708448986853327, 13.931320425002808, 15.698425654442081, 12.795573626795123, 15.755351993345446, 8.628482857058126, 16.073589574906133, 16.085681261554843, 8.857643412005517, 11.793687516643155, 12.723171576376885, 13.887375170184722, 10.913097762292432, 7.4859464360821635, 6.223751739148171, 3.5749383895627918, 1.1645422659574018, 0.9669663516744491, 0.4507167985843074, 0.3320577464276745, 0.23880330365031, 0.26924889414541187, 0.256784689582644, 0.9794116645090043, 3.4588318197957935, 21.21238381631913, 52.307642121468824, 58.50783071210308, 58.4349452295611, 42.26650391855548, 46.12279784294867, 22.30553073267783, 34.85757420139928, 91.2231828320411, 46.31077743345692, 40.80722139727685, 63.415551262517134, 67.8303946218183, 74.20166523225846, 85.27788162231447, 87.63705392037669, 83.48261279444542, 63.717165839287546, 32.99117711282546, 10.340842585409842, 1.17204416663416, 0.3143146598050672, 0.0971346091659319, 0.13901017786514375, 0.17326304148281776, 0.09562430512760917, 0.13347814971160504, 0.18435512128616535, 0.20921095124175473, 0.1178721343016913, 0.10631611931227869, 0.23563061179893635, 0.2146452878631892, 0.16069477153641565, 0.13422058084078375, 0.13748327270150185, 0.22156499236101107, 0.10965546593070032, 0.16738679470314136, 0.12874611653387547, 0.16011672755402906, 0.1262000386392878, 0.14698083242101057, 0.17949973263086813, 0.09197611782339313, 0.13560822654154994, 0.15183796775677513, 0.1791864026698374, 0.1279766808053659, 0.15993419944519, 0.173970278532755, 0.22070230074947883, 0.16351176876454585, 0.07416160882360513, 0.09243978487868464, 0.141130295552073, 0.17275408330944278], [0.05180168183400266, 0.02035070819059207, 0.026554126224871126, 0.062289394873885386, 0.0760595533516138, 0.017556511654308247, 0.050635021855874415, 0.02063303265810734, 0.01679290393968263, 0.03908020579406331, 0.09221251723506758, 0.011194458835938526, 0.030564826334856694, 0.06671400079804082, 0.06188263282960942, 0.04678156129234741, 0.054461634868095, 0.033579238675414555, 0.07337084520728358, 0.0163300393614918, 0.03882741593124886, 0.022962704120624452, 0.08769615312978145, 0.0355503790741486, 0.06267173786557491, 0.04373025607257601, 0.04890353674249304, 0.033062814975217465, 0.08477100726938055, 0.021398568999082334, 0.027534061847555063, 0.06700008867248412, 0.04360410437408475, 0.34534164974766396, 4.18103430540331, 20.124522293767622, 54.47847397096696, 73.81409583553192, 67.6467021819084, 52.38546586805775, 50.0294275437632, 32.89600668414947, 32.345925646443526, 30.318195589127082, 33.011212579665646, 19.137759862407563, 26.475518172787083, 33.97632352767452, 36.71236499663323, 34.60966863939839, 39.80658162024714, 30.261501650656427, 17.91583564973647, 3.770238593701394, 1.5668150349970789, 0.08932166913103673, 0.02978868733700966, 0.01342095836486307, 0.05275255016561958, 0.33176485569246356, 0.969487761537875, 1.9329880250077096, 2.642646893378227, 4.366433466634443, 2.4066511181093033, 2.3444688031750345, 3.3817881345748906, 4.170931260431967, 3.776397695464473, 7.83870626841822, 5.664462447166444, 6.0099472634253965, 10.105836718313157, 5.174149995849979, 6.693054014636624, 6.0638636735177815, 4.81634158280588, 1.832064459881475, 2.3477841865631843, 1.922493723611678, 0.19186387078896647, 0.18632012149018629, 0.2244249671216934, 1.1087635880516422, 0.9969502975863795, 3.459845752485337, 4.414074084451122, 4.870334479116625, 6.277186678301904, 3.140115954222218, 4.623903238004254, 4.578247339494767, 4.676964571399074, 5.505309825943363, 3.2717700639078697, 6.150506379142885, 6.261338831916933, 8.082150624644372, 5.174409852873895, 6.401922952744269, 3.3865486662234034, 2.71742933219479, 3.7025914365245454, 4.328945904008804, 6.762103419150076, 4.687658913673894, 5.023565301972051, 7.798289675866404, 3.677516704605472, 2.200765907764435, 1.4578995180706826, 0.9239738650860326, 0.5745482312575464, 0.22937285323296824, 0.10723910204345181, 0.08765608673134158, 0.04352869067881857, 0.06350164091394794, 0.12044631230134158, 1.089449959897226, 3.937967967602515, 22.33027892728006, 36.652380189587994, 43.16434621810914, 33.21428937296714, 30.438835928517005, 57.33090393004879, 34.167723424973026, 16.76603401860883, 25.490424709935343, 29.433942341035415, 34.37378514197565, 49.80285183075936, 54.2935852081545, 63.3338326023471, 66.29262939576181, 63.528546902441214, 56.22372473439863, 37.43103342671549, 13.502430819695997, 1.5080862444254661, 0.027061567544156027, 0.06874594942576463, 0.07122144763988834, 0.06896487437188625, 0.024117302044384906, 0.02875911304727197, 0.07334104438702907, 0.05609347492516522, 0.03321153562395804, 0.07828991875172624, 0.04007965559139848, 0.09029840059097737, 0.07549873868664427, 0.030113401364595182, 0.05040377055505111, 0.04526623171724139, 0.05306046005458601, 0.07641629751531348, 0.08057738834571454, 0.06685720561372657, 0.08997894192655241, 0.043685853616484714, 0.058807031131319465, 0.060256856358459884, 0.019949511775086005, 0.06494606139078256, 0.036384277271046754, 0.032336437218492074, 0.008287499902860053, 0.138194355512819, 0.049606652239397656, 0.05904092543548154, 0.01993344116565441, 0.06358656942123367, 0.031878448789939284, 0.030860074705654578, 0.025222291944608576, 0.014855845835089925, 0.03270332821674886, 0.0880155581680517, 0.03472906387140674, 0.0004428525960153615, 0.004850705464055101, 0.05643884268318934, 0.0074041751495021735, 0.07489065639674664, 0.012235437302039036, 0.04683611441343542, 0.015919647018064656, 0.021776953231423132, 0.04577859132100017, 0.026484519476071004, 0.035417083605763414, 0.057316327452539444, 0.06704677407058977, 0.035604311664017944, 0.04636235798018114, 0.03646975353119835, 0.03576921975059855, 0.036585310233696815, 0.005522175784027505, 0.02886083611707774, 0.05769471743053967, 0.021173367877641035, 0.007314065015018588, 0.04367799738482122, 0.0238398575569473, 0.035163703855247266, 0.3796033999852596, 4.822643360783977, 24.347520566755726, 62.86032015277494, 83.76002634725263, 76.73401017342844, 61.59178249297604, 58.39521161971554, 40.74843291313418, 42.86160199872909, 40.95735011562225, 34.075888972128595, 25.171483062928726, 35.30319859904628, 41.518225516042406, 31.759788220928563, 30.029958255829353, 40.474867205466, 28.886605001265004, 16.734951196178315, 4.230216414697709, 1.3272820172771331, 0.12735012813561386, 0.011472958609491829, 0.11433784128917802, 0.5430091881463605, 1.081932982610118, 2.9786795329663063, 3.329256811449605, 4.2449208901774504, 5.945837103551434, 7.226613538880502, 7.117960453033448, 7.699527336705116, 8.227323428277048, 8.688617694762446, 8.631177525366507, 10.159117214141354, 9.400320976011216, 12.0256035366366, 10.141070388978529, 11.200683982141557, 6.976659519057121, 6.384576270657202, 3.033037699999348, 0.9072245477188019, 1.87812497538905, 0.76013021171093, 0.7194657743938508, 0.19551362091254806, 1.6064394313481547, 0.5192513920126424, 1.3868755678976736, 2.7725182858205613, 5.571621906372809, 4.270313824376752, 1.562368660684555, 4.537142861273981, 3.7797348970367066, 5.9703676066090985, 8.707166583307329, 7.141987421820241, 6.408893494836747, 10.312886872599202, 6.776840254183739, 9.192544202650748, 8.94821290046938, 6.92196108641163, 5.913098550611927, 7.333419188376396, 8.432812479234512, 8.859681083310036, 9.096631465419646, 8.0409770146493, 9.580908859929732, 7.01238593747539, 2.6791621984974032, 1.6735461594596988, 3.3119265542876337, 2.2623049539904443, 1.6315097506007843, 0.5635638787381111, 0.4133200020559373, 0.18356477901820215, 0.17903939039716799, 0.24731141485033498, 1.0489485460904338, 4.651753537116512, 22.641185598988688, 36.91970540631202, 39.606642723083496, 36.0834913869058, 26.217133998870853, 47.14534797976094, 44.94207812893776, 27.1843316478114, 33.772042566730136, 45.81967315366192, 46.423208252076186, 58.19453923932968, 64.2694002582181, 69.36298231924735, 74.48601353553035, 71.56754262985723, 70.01424481791835, 46.92959408606253, 18.180209282905825, 2.1641785290933426, 0.048225767264563235, 0.03420836923103179, 0.02485258557323006, 0.012955565696522113, 0.04141529158298527, 0.02923508347462743, 0.03446438815444708, 0.05623041314163035, 0.1233620506020323, 0.04233087390480984, 0.018217007764765335, 0.03195626225562827, 0.06097710924223066, 0.03534633155551649, 0.07923629014722763, 0.003494436570045148, 0.03316710252434977, 0.08692343088407671, 0.022099474332325404, 0.018664165625288602, 0.08872702402333099, 0.08634344103836245, 0.022739506319105145, 0.010270407412111038, 0.025202791176496014, 0.06063693172989353, 0.036861481099960305, 0.033861028796602646, 0.010068016558615191, 0.10053257683231946, 0.014412105684318851, 0.02033561051282431, 0.04115945269023219, 0.11175881395296705, 0.05023411655377957, 0.12070577862041613, 0.13279515168359204, 0.11686767811977095, 0.1771712237067761, 0.17872743939440097, 0.08177580266830423, 0.13435558085480045, 0.1413772976206195, 0.0894599020360939, 0.13336412518495513, 0.20902287665634386, 0.14209924355870293, 0.16271437848767928, 0.12666195901411195, 0.1652187811991861, 0.16236681971819172, 0.1376063064221413, 0.22892069281829944, 0.167950390267276, 0.1558133205699344, 0.17016473676889174, 0.13338522324638982, 0.1188327166281881, 0.13740670987434928, 0.24298838069362028, 0.16326358692059595, 0.11232681452266632, 0.11800872011771125, 0.13204512096220447, 0.1314624804522722, 0.10252817458803616, 0.19108088296507636, 0.1338186145069138, 0.8718444010423076, 8.406631638926845, 34.082094161741196, 75.70579221171718, 94.27182935899305, 86.81123025955694, 71.97452775893673, 69.6227922747212, 51.4422692022016, 47.43916096225862, 46.019247270399525, 47.52817523094916, 30.417417826191073, 40.178049687416326, 47.33470432219967, 50.58777301542221, 48.08838382844002, 54.45806195659023, 38.45684305314095, 21.753735619206584, 4.595083132866891, 2.3302516821892034, 0.35537305017632825, 0.12409560277216858, 0.11912424372689379, 0.3869493251606342, 0.8894194999048788, 2.6763621164906413, 4.806288057757962, 8.251294993585157, 10.89152668752978, 11.49657582083056, 11.066559514691754, 12.189435055178981, 15.638600683981373, 17.051457051307924, 19.2217025064653, 16.99715183627221, 15.638558518502021, 24.230447623037524, 16.265181668343082, 19.1121095226657, 18.00262201216913, 13.258438802534535, 8.478204108053639, 8.409268452275185, 4.6623199120644605, 2.2219508742132494, 1.1227468377159489, 0.7050917586011272, 2.426993755563613, 2.4100464197897145, 11.866975042127795, 8.130349689914334, 10.34415698820545, 11.725218622915207, 14.396378205668542, 11.263952793613559, 12.607859776866052, 14.891192067054012, 14.267118457824955, 14.842043788202348, 19.44505403118749, 21.07062347473637, 18.285083655388124, 16.03978462757603, 18.708099511361894, 12.159291640404733, 11.287790998335808, 10.873093508904981, 14.685192127381603, 20.110289973597375, 17.079005818213187, 14.741314380399643, 19.203145773180072, 13.58607340243555, 11.213998467691484, 4.615515739687027, 5.439542464671597, 2.15140680151601, 1.2554200282019954, 0.8045671111153019, 0.26300389860426227, 0.23227260327867924, 0.2990476306407683, 0.48835650627170846, 1.671651777240538, 6.389040418209569, 29.31836185916778, 49.23742648093931, 59.29522691234466, 45.98214164856942, 41.1247137285048, 66.57118828065934, 42.15791702270508, 26.749891888710764, 37.087422032510084, 45.280264885194846, 51.148436607853064, 65.52579818233367, 72.14216201536118, 80.1313397192186, 85.9787307247039, 83.70858838481288, 82.35066383115708, 57.840851276151604, 22.95085672409304, 2.6572236466792325, 0.28618296127646203, 0.21219607412574754, 0.1307543547403428, 0.1872892073926426, 0.1249252147071304, 0.15646316231258456, 0.19664436668878604, 0.13283743973701231, 0.19359031121336645, 0.1347362805878924, 0.09465513495548118, 0.10746083087137631, 0.15871641075899526, 0.16023357128424032, 0.19255414665226014, 0.13080778171218213, 0.09485761199386851, 0.31670666209632353, 0.19815185918442665, 0.11495585207857432, 0.19417610800554677, 0.2080632136353562, 0.1554387342184782, 0.15209356533183208, 0.09380826305958534, 0.1899871545573396, 0.09860090145300474, 0.17924292463689082, 0.10038839908496988, 0.4124441796973829, 0.1192062687609465, 0.16525990479896147, 0.1466703369852997, 0.13188153054685364, 0.2772983025398947], [0.10334129264998822, 0.00914874839626493, 0.03388289294596161, 0.0653165798153608, 0.02421780703439107, 0.09729180274711502, 0.016350783107261506, 0.04491539792187753, 0.10407920386041365, 0.0349078496407357, 0.034896990344409025, 0.02348319574769947, 0.049366169579086766, 0.03497256491813929, 0.1196797417416688, 0.02973528334780807, 0.14902244141745954, 0.03923104467591451, 0.04355767561543373, 0.050342062172750314, 0.08260476342853039, 0.03532999473053121, 0.06954857974403328, 0.0878452108572087, 0.1554779579202014, 0.16490716727510576, 0.03638102139736857, 0.051836217077629226, 0.06144350357053261, 0.037619383374769846, 0.02220430197344432, 0.08751357905566694, 0.08350418129515264, 1.4506850535831144, 19.34601418433651, 60.113319581554784, 72.93214305754631, 71.15286181049963, 58.99791909802345, 42.36768145715037, 38.204693486613614, 32.06598412606024, 26.28062540485013, 21.093018247235207, 24.794211849089592, 43.238055398387296, 39.63639390084052, 31.9931221777393, 45.97348889996929, 58.05095303443171, 25.065377066212317, 11.624298980159145, 1.4024378167044733, 0.30726113506863195, 0.07923879525474004, 0.06792022155657892, 0.08576227907812403, 0.1704118307679892, 0.4572502109071901, 0.2695727961197976, 3.072900748060596, 5.20843739471128, 5.073330373533311, 1.1231377264184337, 3.377598798082721, 6.309109868541841, 5.451146306530123, 5.363078309643654, 4.309803266679087, 5.139409072937505, 8.855890112538493, 10.079266582765888, 7.72671377466571, 12.325141218400772, 9.972627143706045, 6.473546412683303, 1.2203715669531976, 0.41253344426232, 1.133889923653295, 0.6218548347392391, 0.3323438649456347, 2.1164925588715464, 0.24318721115348801, 0.29305473931374093, 0.9262609746186965, 8.640144063580422, 15.975590136743362, 17.0257027687565, 16.143403841603188, 10.433995935224718, 3.7197287621036654, 2.1896805542130626, 6.298889152465328, 3.316589762126246, 3.734718344865307, 2.4648865480576796, 7.897497204042251, 7.233082507887195, 3.2066388620484263, 6.548269035354738, 4.140369622938095, 2.9647519319288196, 3.6809083290638465, 3.8689090023117685, 7.896818143706168, 9.501151384845857, 4.748481146750912, 6.626371270225895, 3.1975840705056346, 0.23175645920057453, 1.2691593554712113, 0.7114945376111615, 3.7592883167728304, 0.4685766370065751, 0.3671398849016236, 0.4633697518898595, 0.0813815048745563, 0.07513811811804771, 0.07077769887062811, 0.09764043403969658, 2.102036908749611, 4.979798024700535, 18.425598644441177, 37.56420573880596, 42.24574673560358, 55.8408151134368, 55.56964989631407, 22.89528850586184, 17.70168600543853, 16.019718762367003, 13.13425067932375, 23.3972793240701, 35.78330063050793, 39.70185041427612, 44.80501090326617, 50.09773169794391, 59.18741272341821, 67.07325950745614, 63.451366424560554, 45.369016355083836, 11.275929750934726, 0.8878777019919888, 0.08166714075712428, 0.0704326528695322, 0.024716852030025858, 0.03846535511735467, 0.06549879382815092, 0.02693396410904825, 0.072196823124203, 0.1716028063768341, 0.08372036364650534, 0.1471152655299633, 0.19428705285874107, 0.2730119793165115, 0.09547748437692082, 0.07252156013442625, 0.034166073516732266, 0.0445887495222832, 0.09327131203345715, 0.005949289911621881, 0.019946366984156833, 0.07440207616215752, 0.04119865723975724, 0.023175594209122564, 0.00810083108879025, 0.07539776063734487, 0.017271042395863804, 0.03869289855262445, 0.020652853267928286, 0.00964027711175262, 0.05626237432983133, 0.05910924898700849, 0.02498234554584469, 0.12003740521087763, 0.14414987707089993, 0.11861709352102011, 0.009150721072669952, 0.045205622671111945, 0.017434060160491257, 0.03556221513257873, 0.06298155914391242, 0.1004088229890312, 0.04017424829784901, 0.02517442868631934, 0.13494695476706953, 0.11095373981421995, 0.05155980872410921, 0.06713124292512095, 0.057421541968060125, 0.022000468959431016, 0.03734112108847307, 0.0315494810591542, 0.055635871455794385, 0.04614972644635747, 0.01364385451926219, 0.07279228794598773, 0.058567590350585605, 0.01734309104992257, 0.09498806910649424, 0.08735637781360457, 0.09209889873501756, 0.08233684715965102, 0.048815402157244184, 0.07572775301072868, 0.00676623362514581, 0.07675311573210263, 0.04978901180889338, 0.11178542018657732, 0.11366801231258339, 2.2009615359767793, 23.70553839591242, 68.76421682296261, 85.13281668386152, 80.21181106567383, 66.49601213393673, 51.564309827743045, 47.255088052442, 38.06311553524387, 31.529139126500777, 27.942537569230605, 37.43191988237443, 42.42488530374343, 39.46204846905124, 37.703967632785925, 47.397999609670336, 42.375561498826556, 22.326956679744107, 9.507778229251985, 1.4871608898524316, 0.19709217572404494, 0.06678362286859943, 0.30713028725116487, 0.5225390123744165, 1.0335914862732734, 1.828673570867508, 3.2420497748159596, 5.212144034524118, 6.153623682837333, 5.021228549941894, 8.563519581671684, 8.059062573217577, 8.76892626285553, 7.530792855447339, 8.604386756497046, 7.174987792968751, 6.444150209426881, 10.562582996583755, 11.66890319316618, 8.941472307328256, 5.989251367507443, 10.203849884771532, 8.959180828063719, 4.2075622754712265, 1.9868697466388827, 1.1718686405689487, 1.423192425600944, 0.9457292912467834, 3.1518592853699965, 0.6651779035887411, 0.5960827789479687, 0.9346677170645807, 8.396918869787648, 16.39887075270376, 18.117276814676103, 17.388749507165727, 10.214742306740055, 1.7215537640356249, 2.6040421906978857, 2.427256064068887, 2.351430274786488, 3.911059282479748, 6.268349578303676, 5.727632218791593, 5.710117365083387, 4.969674387285787, 6.421977541139049, 5.8244010133128015, 4.550513240598864, 7.232670659019101, 8.935833900205552, 9.331852082283268, 11.485350977989937, 10.402310048380206, 8.11689546992702, 5.981280130724754, 5.885824839914999, 4.2385671407945695, 3.2365785587218503, 7.704938736654098, 4.47505223174249, 3.8167164739101165, 2.330450987623584, 1.0011270089495568, 0.3247789305544669, 0.08123684449181443, 0.023999332164924954, 1.2288066240087634, 3.774107521580112, 17.747968012286773, 35.2825943885311, 37.91121390558059, 40.36929268990794, 60.34056601985809, 29.123571072855306, 18.894568989353797, 27.313491375215595, 23.401809661619126, 33.21966694247338, 52.29465515382829, 52.56673428320116, 54.409110776839725, 57.249542205564445, 68.26459315515334, 75.15429127600886, 75.09616959479548, 54.48886432955342, 14.633354083184274, 1.128893314350036, 0.0668210769072175, 0.009495024926089233, 0.02450725228916253, 0.04452511825929246, 0.09021691181847165, 0.015017636901428624, 0.09713988751173021, 0.04716224953412049, 0.022145749873391563, 0.13212349175685836, 0.03334511837531482, 0.2262816118497041, 0.025851424415445617, 0.04933120532622261, 0.0368460712413634, 0.06258433106385412, 0.023405334401515224, 0.03218589328049171, 0.0374739607345433, 0.05205000540421856, 0.054116286262268984, 0.04637059342536715, 0.012821037784188747, 0.05351156326791933, 0.03316700293291961, 0.00597328091258063, 0.05053321260117716, 0.029246381356290756, 0.02395998971957353, 0.07310290595576649, 0.06387286413941654, 0.1381859438674104, 0.16208667668604082, 0.0720046269857595, 0.1947724308458067, 0.23507047895221944, 0.1265773522637544, 0.18019688796372185, 0.10036772237189355, 0.17623648918684454, 0.12129801055116039, 0.3633511204633021, 0.16608576290309432, 0.18269788924484484, 0.2166679132008745, 0.14932225758750595, 0.17032081952258465, 0.2978849543198463, 0.34203113867871227, 0.11596475923133474, 0.3081776213742072, 0.14857130756060924, 0.15137670621756585, 0.19730839637979386, 0.21848341900735133, 0.10177014590871912, 0.28007981457537223, 0.1796626642106041, 0.2041052663398366, 0.3361790236686507, 0.16021192163950013, 0.20561934719162606, 0.172049542888999, 0.2049407311865399, 0.23538209287629974, 0.23236994241033834, 0.36527807674100327, 3.5687582050600364, 32.658109049643244, 82.11725927168324, 93.48259356714065, 90.65318399860014, 77.60570987578362, 60.80569244200184, 55.41267271964781, 48.81932535479146, 39.80715036392212, 34.258592974755075, 38.38252198311591, 59.200446759500814, 52.53083282901395, 46.84633785678495, 60.34104062664894, 69.6305585676624, 32.234640159914576, 14.044983848448723, 1.9118533139267277, 0.5494818956621232, 0.20545908159786658, 0.3416634471185746, 0.4362855713453985, 0.765059711712022, 1.4458237660508004, 3.2604003385190046, 8.442997893979474, 13.717116848115, 12.067143397946513, 12.246207441053084, 14.116758319639391, 18.2359089005378, 16.953346806187785, 16.20861030394031, 14.247262439420147, 15.836311674887135, 18.582377741413733, 24.131662730247747, 21.119074552289902, 27.35389571036062, 24.048033875803796, 19.877463963723955, 8.776318950037803, 2.8718150479178277, 2.9539695814732583, 3.3362577519109173, 3.5723991451724886, 4.812632491511684, 1.7444265753992143, 0.8123014122247697, 1.6939788888539038, 5.929396488974172, 7.2878098680127055, 7.672260980452261, 10.164903690738063, 12.927547654797955, 11.280050200800742, 12.594857119744825, 17.0792019367218, 11.646048522764637, 11.599691990883121, 12.275430079429382, 17.856301915261056, 20.38923913432706, 15.2076586984819, 18.175647566395423, 14.764346538051484, 13.161059098858988, 13.164624533345624, 14.75028778276136, 19.06937529963832, 17.903482144878758, 14.218025092155704, 17.65480387595392, 13.02706995318013, 6.552480190030991, 9.524148241166147, 7.9049859892937455, 12.580003103902264, 5.146401678362201, 4.688986635977223, 1.940538710163486, 0.6803720011826485, 0.3149875607942382, 0.1475830847818044, 0.2992125234055904, 2.587994548582262, 6.254967431868277, 23.891837250801828, 49.499401584748306, 55.375484728044086, 71.94439611127301, 66.498977445787, 32.64789519771453, 28.69216722826804, 26.293263281545332, 23.031061349376557, 34.25769082961544, 52.617972204762125, 56.09065832630281, 62.88417208579279, 68.40667709227532, 78.40694027562296, 87.17449665069581, 87.56046572039205, 65.75098929866668, 20.261758181356615, 1.8996989919293312, 0.2850279764782998, 0.12894799602368187, 0.08901023906805823, 0.20290811606232198, 0.16933642718340122, 0.1465049386024475, 0.1851213317845137, 0.2195877807154771, 0.18089425780119436, 0.24887682359305122, 0.22597677014287443, 0.4672817339099223, 0.14321865123366156, 0.10981958494671892, 0.1919668023624728, 0.15252651226135994, 0.19716573548653435, 0.13321211801901942, 0.11187957239247139, 0.1936149639227698, 0.12248491823312738, 0.1379788549797189, 0.15495315704855228, 0.1566901235210319, 0.17200740805316359, 0.09476815590695029, 0.09840476762263045, 0.12901977846218696, 0.1631721773094708, 0.16065974599651753, 0.20119187992907342, 0.29563121557716404, 0.2996659555262135, 0.22968532517552379], [0.20178018948964535, 0.08137664787711636, 0.10342298826623349, 0.045832037445037596, 0.11941642966121437, 0.09412497912924137, 0.034151709368152004, 0.06459782080304238, 0.054062955051420204, 0.05941782920290867, 0.058820391704718915, 0.0507519421948781, 0.07289301318627212, 0.037914959248155355, 0.06436506796988749, 0.03530974319625286, 0.03583322639667219, 0.10898181417536353, 0.2701491700305093, 0.07413262005655036, 0.2654824381874454, 0.16454059420333755, 0.09348668999248937, 0.10677299882856109, 0.2895926960533665, 0.12809349389206018, 0.05755496767139243, 0.031155736763931574, 0.03333902797631679, 0.04119520218321874, 0.10635530470960564, 0.08083611155950254, 0.56757039600803, 9.611108168478935, 52.940343964484434, 73.92513029036984, 73.17209797520792, 61.342206001281745, 60.63851710288756, 46.551093209174375, 27.84938520000827, 34.040007129792244, 28.18091961645311, 25.604987336743264, 23.500843624914847, 25.156870272851762, 38.72450167132963, 51.71439540001654, 33.656893545581454, 15.954590747433326, 5.8836729295792125, 0.7565951755931302, 0.44622531701480195, 0.13663334411478814, 0.03767957107254094, 0.1778045179502618, 0.5344276550796725, 1.1724480481878405, 2.3234615691246527, 3.4055059715624783, 5.8645494138040855, 3.7025181372319502, 2.5960856628033424, 7.6572677204685835, 5.312102696587963, 6.562424869306627, 5.1666759194866305, 4.673834520001566, 7.630997155943225, 4.731349214430779, 8.197611964518025, 6.9249631704822665, 8.509009422794465, 4.118827965951735, 9.403754030504535, 7.1520688937556365, 3.2638667331587885, 1.5031957842649952, 0.6409993106799742, 2.12915642126914, 1.0146195333330863, 1.3068753961593875, 0.563459629493375, 0.6817301831418469, 8.605211434825774, 37.36595346081642, 59.988925533909956, 55.93294766641433, 53.31347903897686, 31.790859276248565, 12.998318979817054, 3.7016172178329962, 4.0956215079753635, 3.6523941687999235, 7.195887161839393, 3.516728945316807, 4.029518048609457, 1.9801132188689325, 6.7993811349714965, 5.622484260989774, 2.5974665822521334, 3.335597322833154, 9.161422156518507, 7.43983603292896, 3.47036432354681, 7.528531118746727, 7.236716093555574, 5.324229684568221, 3.554395466081558, 1.6437267079468698, 1.4641037270907433, 0.7279858365654946, 1.8697520633859022, 3.15583338179896, 0.5870175686094069, 2.704855929459295, 0.5197164993132315, 0.4728735935303473, 0.1213677935001831, 0.09364914659771229, 0.11765938402423937, 0.8606969024385176, 2.907905511317715, 12.065356758333023, 30.22488828628294, 43.46569407370783, 31.4441825497535, 29.30819311449605, 37.031061495504076, 17.777154368738977, 23.840589523315433, 22.230321245808756, 15.891013049310255, 12.91241515067316, 33.04191689337454, 40.63017737480902, 43.130374570046705, 58.61267566680909, 64.8146410911314, 59.091903009722316, 29.251285406851, 6.132224702065991, 0.24503446364354706, 0.11070849974789929, 0.06900035956453893, 0.122984147089864, 0.1300367448599108, 0.13746386003350058, 0.2515762876118383, 0.21114892386380704, 0.07508461453741597, 0.30092748783288464, 0.24833093998172592, 0.32335609077445926, 0.08475889541929768, 0.10384401486765954, 0.05387320656389479, 0.06693645740949339, 0.02732627581985247, 0.12485572287151891, 0.028850438388725443, 0.19865349355724551, 0.1462291775932235, 0.08331386973300288, 0.030309010424741337, 0.04023095029556463, 0.00962796703641934, 0.0139076262524712, 0.05295934410946024, 0.07380109550731798, 0.15534531745699146, 0.2152071367468565, 0.0885494678251205, 0.15783151791941735, 0.11936206806210742, 0.19462391704080567, 0.13941841079823433, 0.05105553900883083, 0.004777709733799942, 0.04227588028316537, 0.060130087959189574, 0.013910270213419873, 0.028732029923928842, 0.03633113758217904, 0.03423804747721842, 0.05702669259100672, 0.11509083677083255, 0.058945965006827354, 0.06695228478600902, 0.060641627848869374, 0.05077778234056408, 0.07329975990878959, 0.0061090608998652434, 0.059552783251649914, 0.13609429400774742, 0.10645246764104213, 0.155670537102607, 0.09547559980062709, 0.060120182442328626, 0.09311857708399335, 0.1115439645946026, 0.07451538822703785, 0.01339192363253284, 0.015508670532595248, 0.04795685891182192, 0.08580949307689745, 0.09798269148074812, 0.1052631161385967, 0.5876787944186119, 11.993788211576401, 62.00486298530333, 82.9537517793717, 82.70090010858353, 71.71273308415567, 68.7555326954011, 53.90059117347964, 35.786250252877515, 41.48266923043036, 33.18380078961773, 28.98931618659727, 28.882694398203206, 35.286936452311856, 44.85204404400241, 48.73479827757805, 32.15738319581555, 17.18290940407784, 4.594397208383007, 0.9123960089298987, 0.1318053201201462, 0.24667416759316, 0.48998189969889583, 0.4127035770685442, 1.448271815334597, 2.548208477035646, 5.086495809016689, 4.422959723780233, 6.547678718643804, 7.096579122927881, 6.311870236550608, 5.721660410204242, 6.52549232206037, 9.384469697552344, 10.247332299909285, 8.310716940510659, 8.783080135622333, 10.230049356337517, 7.3893776824397435, 6.872037649154664, 7.76693081663501, 8.43509235689717, 11.21250698643346, 7.160630937545531, 4.53662657930005, 2.851220888476218, 1.7047495947730158, 2.947363329510535, 2.511974847124469, 3.6381986208500403, 1.069871939478382, 1.3402867581575149, 10.131700827229409, 39.88345223088419, 68.04337147743472, 65.77818309107136, 63.86691408772623, 37.644088729735344, 13.34892592122478, 3.791262007528736, 2.305330903299393, 6.679891030634604, 6.96692027391926, 5.967188525584437, 4.672286164376044, 2.9242836131203562, 4.587420782735271, 5.415719949430035, 4.756494058716682, 5.453759095361156, 11.23848778586234, 8.778841034058603, 5.818826835001669, 10.756585386491592, 8.26048412630635, 9.984983590341384, 6.538620985323384, 6.470915973186494, 5.459174907976582, 6.80488569121207, 6.9038823919911545, 6.651196931639026, 4.8255125745650265, 5.602871429535651, 3.4807093297281577, 1.1946676623436714, 1.0209919139742851, 0.17714295506237016, 0.11944366408692253, 0.5945089279163269, 3.227200416787978, 12.777537588150272, 29.079136502358224, 43.472103226569395, 40.20649471590596, 29.1037219185983, 30.896827559317316, 18.671180202114968, 26.85822383049996, 29.792260662201915, 23.162929473384736, 24.59683818201865, 41.648303078066924, 51.29505872726441, 51.19057855298443, 64.99141054768717, 71.7717255315473, 67.23647717506655, 36.737346572260705, 7.189473596311386, 0.22614676505327228, 0.047094128995893464, 0.03440972012017043, 0.09168747887616197, 0.11652502997387802, 0.042870364512407014, 0.21372350022917797, 0.10245631554073865, 0.09301164653152229, 0.19628862610026715, 0.2445297342755141, 0.2118158034018932, 0.0354692695151654, 0.07645015094068743, 0.018865466718712164, 0.1001385548302243, 0.057085106795233105, 0.05227644184243776, 0.03549573019207005, 0.07577047007338655, 0.07982180348687595, 0.03356571339311139, 0.05337692331522704, 0.011745760604108294, 0.03511829399353555, 0.021659565578785636, 0.05626016416616979, 0.0382962680211471, 0.026727095471634984, 0.22929141808661724, 0.05912499592429208, 0.04065399170823155, 0.0495220608107986, 0.06675715453081554, 0.2817338903344447, 0.2111185254949716, 0.214924450302797, 0.18154523335397246, 0.21959380216656194, 0.18149765929387462, 0.15418162990000941, 0.1631412273573299, 0.22985312907445818, 0.16494936339797514, 0.2388590901729561, 0.25780130357992265, 0.21635341878619888, 0.1394896876187094, 0.15629633900619325, 0.25370815708752603, 0.1468854851179546, 0.25262023562625535, 0.3091026572210174, 0.22142006384749569, 0.4143183371953426, 0.2090793833016388, 0.2033764868974686, 0.23593549947104148, 0.37911190861655825, 0.23470614285719013, 0.09754092687921179, 0.16105878587451675, 0.1499111800184173, 0.16066228940842614, 0.21802620241238227, 0.2568858591539245, 1.7459800791355873, 19.396573535857662, 74.27751602665072, 92.99395253581386, 94.15753149217176, 80.9125268074774, 78.17798368392452, 62.109300013511415, 43.69772580362136, 48.76589482830417, 42.12041916385774, 39.211001088542325, 34.00442338758899, 37.90279257682062, 54.69962504602248, 66.64735286466538, 46.17578121923631, 21.100398186714422, 7.472121061817293, 1.1406191174061069, 0.6718483843630361, 0.3529532848586959, 0.4280328125722947, 0.4134233932821982, 1.077959499051494, 2.838485197674844, 7.9830230147607875, 9.945642217513054, 15.606335266943901, 12.086744462290119, 9.238038793686899, 17.478495297893403, 15.377621862196154, 12.779481122570655, 16.006279741564107, 15.078362668714217, 20.378848775740593, 16.1603121988235, 18.7239811881896, 17.753082782991473, 20.48275628397542, 16.402662704067847, 22.91738517822758, 18.84130124122866, 12.37491217351729, 6.800307794924706, 2.2373687307680807, 5.328008397932976, 2.7210930710838688, 3.6005715689351483, 1.624422027699409, 2.04290644295754, 11.27450102759946, 31.260511682879542, 52.11653247956307, 47.93673715283794, 46.74826683536653, 26.212221230230025, 18.039584467487952, 9.205540976216717, 12.272984481626942, 13.51439110694393, 13.559591520217158, 9.869087357674877, 12.619398409320462, 10.004522877354777, 14.253179334825086, 14.257563564085192, 9.980945510248985, 11.024542104813362, 18.495609029646843, 16.814112470995997, 13.882730103308155, 20.542905830567886, 18.60760054280681, 15.606944214913154, 13.885659133234332, 9.041518242128435, 5.874898587503742, 9.126501294874377, 10.787077892211176, 11.064461046649564, 6.068690640311088, 7.354809834111122, 2.8558370278727625, 0.6885369049925959, 0.43122356877692286, 0.24640614407197123, 0.18031098909916418, 1.424023968077475, 4.268814988674657, 16.315287986109336, 38.65209471794867, 54.33588797046293, 45.92455733206965, 45.423301958268695, 52.40738407258065, 27.43087810854758, 32.52541330552871, 32.89103900232623, 26.5872194305543, 23.953267451255556, 46.912057169022106, 59.00860363437284, 59.59455866967479, 77.83944391435193, 81.60069096472957, 80.84110829137987, 47.226391992261334, 10.666186521130225, 0.4389032937826649, 0.2907311333523643, 0.12266645808854412, 0.18452090271297963, 0.25925999627478663, 0.2200006561413888, 0.3557146028164895, 0.4090843632096245, 0.3119717484279987, 0.538787124378066, 0.48148037685501965, 0.3471096887463524, 0.22157352658048754, 0.1819758513762105, 0.1340886145349472, 0.21748588059938725, 0.13992027499743048, 0.2621542151656843, 0.14641625626433283, 0.27105879218828294, 0.2951192236956089, 0.16537380675154348, 0.10587442365865554, 0.1178169223449884, 0.08917053530533468, 0.08585119890349527, 0.12968684186137494, 0.21278334180674247, 0.20474810603885882, 0.30983571143400285, 0.21492671792305287, 0.359075369253274, 0.2233494103195206, 0.3693307737909979], [0.3624134288439828, 0.18940344152431335, 0.038261828538511074, 0.026249590953211152, 0.16715960366831673, 0.08821012151818122, 0.022993031626326904, 0.0673281964695742, 0.16741828091682928, 0.04026587624403258, 0.041728732626765005, 0.014720428303154487, 0.05864900634473851, 0.039028724685551665, 0.041862487747904756, 0.007018922938920197, 0.010617824455332613, 0.09929765075925859, 0.09830896066681993, 0.2277260246656595, 0.31246854112513606, 0.10315213788060412, 0.1748134349022181, 0.17124205557329042, 0.3202038534706639, 0.3771407337438676, 0.20291206907601128, 0.09780050045059574, 0.08792020320411652, 0.1579149448943715, 0.12019247672851048, 0.7657969947303496, 10.81139168431682, 48.33438311853717, 71.67782398962206, 77.13244453553231, 71.62674688523816, 54.95392799377442, 43.894613096790934, 32.38564748917857, 28.165787112328317, 28.0556587250002, 31.101010461007398, 38.330511354631, 34.53084468841553, 40.20765181510679, 42.031695150559955, 40.899467698989376, 21.958822627221387, 6.031176601686786, 0.6386249896980102, 0.030366951569674477, 0.02115853258498734, 0.03825797511625194, 0.2635055636205981, 0.4775770975937767, 1.366688109213306, 2.569309602822027, 3.829358272975491, 3.2966736824281755, 4.198465318449082, 4.217761418511791, 3.8928616912134237, 4.014039640465091, 4.8717308428979695, 7.754602316887149, 6.6772056779553814, 7.553506320522678, 5.395392756308279, 4.256801259133124, 8.065211378758955, 7.170753104071464, 5.153213364462699, 6.383268650501005, 12.343416521626136, 13.216062495785376, 6.100303963307412, 8.012967369248791, 11.012925024955504, 9.90285994545106, 10.018481612205505, 11.190718220126245, 4.735873668424545, 7.174174391454266, 27.041043543046523, 60.41954294327767, 56.746933614054036, 65.05392136112337, 59.1234584777586, 75.34409476864722, 31.059739282054288, 17.187137719123594, 7.9123325886264935, 10.201562162368528, 8.812845041674953, 8.808965817574533, 5.931136550441866, 2.179860410190398, 1.358791274889823, 2.434357270117729, 1.6578271384200745, 2.1544238396229285, 6.746615940524686, 7.0002447309032565, 4.402067709353663, 9.311246891175548, 8.286826764383624, 6.094983758464937, 3.5652167950907065, 6.428959850342044, 2.064476537127649, 3.1275692726335222, 6.757773122479839, 5.36245612367507, 4.5939328978138585, 3.795533468646388, 2.629361580456457, 1.588685067911302, 0.43245035133534865, 0.39782446418558404, 0.22695615226703308, 0.020520072993672183, 0.4596408342401828, 2.674467856845548, 9.157958703656352, 19.88556758049996, 33.87838194447179, 53.940536591314505, 45.19227435511928, 48.990572114144605, 38.02856337639594, 38.200323966241655, 42.18457737276631, 29.781497678449078, 26.453266566799535, 24.862435594681774, 44.01539464150706, 48.29745792573499, 55.57821635277041, 63.44198411510837, 45.84916937735773, 17.91043454600919, 2.4239705887533005, 0.19906157327275123, 0.09240289774513052, 0.11798779825649916, 0.06953857463574217, 0.2171553596253357, 0.16018590529359159, 0.28659625038985287, 0.3059636272730366, 0.2692720606442421, 0.30818430166090693, 0.6450886880197834, 0.0698268152172527, 0.14530610293149948, 0.05270778381776425, 0.13761597445174573, 0.04888145425807565, 0.00851991182688864, 0.019233495357536504, 0.032222711466132634, 0.1046462698028453, 0.028593364179194457, 0.014049688639539867, 0.021358393433113253, 0.009026521940775698, 0.025879241067976243, 0.07941707923647859, 0.0963054798663624, 0.12632936960266483, 0.045370231983402086, 0.05498946561748463, 0.16263144180899666, 0.24975019447024793, 0.3054187855412883, 0.15291626715371687, 0.1709957736273927, 0.01843813712888908, 0.0401281068221696, 0.1569591582782807, 0.06623596193328982, 0.024122815962219914, 0.06776551010027047, 0.07976204096790283, 0.03639327114327781, 0.03709366702805123, 0.031513494078911124, 0.05293106397373542, 0.15322113950406352, 0.056017555611869024, 0.05423101558980923, 0.0498678882215773, 0.14742173134319245, 0.026952779228468577, 0.11388545104813193, 0.20829136994096542, 0.056245845982864986, 0.03054722163435673, 0.02331286184339514, 0.10845056284339198, 0.3130332092123647, 0.03949003219003639, 0.09930101388524618, 0.15362305987265804, 0.07707180064772406, 0.06997984894100698, 0.8857137793975493, 13.005166457545373, 57.55689520989695, 84.98592392090829, 87.32318585918796, 81.06600915232013, 64.65779335268083, 52.379021413864635, 42.19035502403013, 36.3003239324016, 34.492248565919944, 39.093937950749556, 39.8506219925419, 34.76861876826133, 34.48645130280526, 37.69641314783404, 40.74533031832787, 20.02708669631712, 4.7892752674318135, 0.5218785832966528, 0.09300019351705428, 0.09874799033446659, 0.42371768444295854, 1.0964553130249823, 1.850479865266431, 3.7883910777107364, 5.337280881020331, 8.227843142324879, 7.75460280718342, 7.901518123765146, 7.207495906660634, 7.706941596923336, 7.1910685300827035, 9.740340459731318, 8.029094194212268, 10.115892694842431, 9.896391957036911, 9.53021320604509, 8.144893838513283, 5.933266397445433, 5.4075545553238165, 4.7608135688689455, 5.364839453851023, 8.509425194032731, 7.9642069147479155, 6.041018318745398, 8.918247953537973, 10.892599455771908, 12.724054109665657, 11.697437455577235, 13.189024617595058, 6.941469484759915, 8.149412408951791, 30.365881804497015, 69.48941599938178, 69.01768038349768, 76.67118164800829, 73.4915122678203, 89.39365602308705, 37.95781950796805, 16.73095233978764, 8.289295896407097, 9.413654092819462, 8.943253063386488, 8.599089595579333, 6.71145385311496, 3.4650335773344967, 1.9598622668174006, 2.0482221125595035, 3.1284361164416037, 5.800228426533361, 5.0913105184032075, 7.904072077043596, 7.463016750351076, 9.773419768579545, 9.729883420851923, 9.47010386374689, 6.706397917962844, 10.873336695855665, 8.044435564548738, 8.513539760343491, 11.435406457993293, 7.883726252663521, 9.591009943715989, 6.579643584066822, 6.132464456942774, 3.2971132330356108, 1.8956862846689841, 1.1388245104782044, 0.5627008960131676, 0.03545572891110375, 0.2848238600117545, 1.5881959973804414, 7.754434635562282, 22.01901924225592, 36.49193171531924, 51.729775013462195, 48.627125293977805, 39.73644179682578, 32.9191388622407, 32.85878927476945, 39.08596377218924, 31.749448853154338, 39.30877400982765, 34.70403694337414, 52.403842172315045, 57.998401118863015, 63.71291006765058, 72.59701575002363, 57.15910019413118, 22.97346918813644, 2.8250844199811262, 0.18141107603667245, 0.04461525233402368, 0.07749868782177087, 0.11345359196345653, 0.1797465508383128, 0.13887598990432679, 0.1464870734320533, 0.14410153692287786, 0.09714277566320474, 0.25313562893819425, 0.34981474520698674, 0.06748329096984479, 0.10616766679431162, 0.03778557465862363, 0.03272267959771618, 0.0705436896532774, 0.03151400352738077, 0.038723695287180525, 0.1559716403003662, 0.07451047760344322, 0.04221192343280681, 0.0746814301237464, 0.022317453159860546, 0.06306048152187178, 0.009023418327072456, 0.06391208401070007, 0.05350290647437496, 0.07004864363660736, 0.061424037276376645, 0.08549505228837652, 0.06266991457631511, 0.06601742769200956, 0.08912019566783021, 0.6303082779049873, 0.5530261248350143, 0.15556604270973515, 0.15813153327232407, 0.3215167749552958, 0.1517540964508249, 0.1707077705331387, 0.1492015374523978, 0.20927459782650396, 0.11057979697662015, 0.14559721634272607, 0.1340325828641653, 0.12933834846461975, 0.29871714031023366, 0.18754668954399326, 0.14403988216673175, 0.22991080017339802, 0.36389203982487806, 0.3264810553481502, 0.2746627149322341, 0.5238210758374584, 0.30393085893123384, 0.40657815253061635, 0.45619202897913996, 0.4926634832255302, 0.5875985084041473, 0.3633719580548425, 0.23370846655339966, 0.3439424667627581, 0.23911359990316056, 0.343340995811647, 1.7177379107283008, 20.669325782406716, 70.51309970117384, 95.08425420330417, 96.39272551382743, 89.680600935413, 71.94808313923498, 58.60008878092612, 47.591882367287916, 41.36977949450093, 43.5076791240323, 41.01480499390633, 50.32108714503627, 46.87571640937559, 52.88929431669174, 54.57905530929566, 51.38148815401139, 27.386521985453946, 7.466552767061419, 1.1956238626472413, 0.2059701082086371, 0.19557049528004664, 0.42258555970845685, 0.5662910291744817, 2.2021409436579678, 3.4674740270260846, 8.247549130070595, 11.473905501827119, 11.258283988122018, 12.910479460993121, 15.101933171672208, 13.996788705548934, 13.381228600778888, 15.627435657285876, 19.2570097215714, 17.74086852227488, 16.822014085708126, 14.924837177799596, 16.2033131430226, 18.785438845234534, 18.234473313054732, 12.043841577345326, 12.498506057646967, 22.521166955271077, 25.457392469529186, 12.077552387791297, 13.885341421250375, 19.567245667980565, 18.685522348650043, 17.046895334797522, 16.9724860114436, 8.892947685333992, 9.950546160820993, 36.85869293828165, 68.28185942865187, 65.34538484388783, 71.3560405854256, 70.27149738803988, 81.97646971671813, 39.44102456492763, 23.584276360850183, 12.496937109578042, 15.296350352225767, 13.735812825541343, 14.569610664921424, 8.997470025093325, 4.400515431357968, 6.297569765198616, 6.859042346477509, 7.143758862249314, 9.944917559623718, 16.287813744237347, 17.60818454527086, 14.523598321022527, 19.419523323735884, 17.551412159396758, 17.023676864562496, 13.691290982307928, 18.65496316263753, 8.539198925418239, 8.916041620316046, 15.290961996201547, 15.662179031679708, 12.818624415705282, 12.271317474303707, 8.094377142767753, 6.181343563141362, 1.1811548519519068, 0.6987758846052232, 0.6209821073758988, 0.2563938008801591, 0.8650508559038563, 3.4808468578323244, 11.836107950056753, 26.438396861476285, 46.38166642958119, 66.72493734667378, 60.80313113427932, 62.38183413782428, 51.737584452475275, 54.02237684495988, 59.68853473663331, 41.05336973744054, 40.97183935103878, 38.47176767164661, 60.28606860868393, 65.64682291400048, 76.68585131245275, 81.88027751061225, 69.90026074071085, 30.451991558074955, 3.9563729541917003, 0.41246244323349773, 0.16636713167592404, 0.19621875888157278, 0.28896946820520586, 0.46269654446551883, 0.5011215842058582, 0.4285847635999803, 0.7786323382489143, 0.4198820354236711, 0.7080525352108864, 0.9247732931567777, 0.22486586604387532, 0.28657939645551866, 0.1795302229302545, 0.2883480483245465, 0.1226844764765232, 0.20423200792602955, 0.12082818414895766, 0.2728786187306527, 0.20321698739163338, 0.16113554788452966, 0.12776169355117506, 0.19389121522826536, 0.1784939357950803, 0.26332516523618854, 0.21141884728304802, 0.1676109826733028, 0.3125209108956399, 0.24014149071468463, 0.22747669368982318, 0.2443601224090784, 0.36347243814699115, 0.5285043858232037], [0.2559261808111783, 0.07395726253068255, 0.1389633852147287, 0.1694264118709872, 0.16166011892980145, 0.165470149968901, 0.050954139611173066, 0.0871685866807257, 0.1234277886068148, 0.04045946283205863, 0.051614924919821566, 0.0585654951001127, 0.07784030940984527, 0.1497588357737949, 0.03597646951675415, 0.0770085754113332, 0.025245079229916298, 0.1290794567114884, 0.06592134494454631, 0.05386107939205343, 0.11943529840678939, 0.42009497722310407, 0.16725507354544056, 0.2574415180471636, 0.12266330946717532, 0.35425554239942186, 0.2172794811908276, 0.18658026962751345, 0.08994061454770066, 0.12492372849655729, 0.1655736484474713, 5.973281437350858, 38.04975202006679, 69.44263781270674, 76.4663476328696, 67.64107750308129, 70.21587817899643, 49.20576903127855, 43.550989935475016, 28.519349559660885, 36.38293297060075, 41.79790619880923, 26.449518742099887, 32.861250562052575, 42.42535598816411, 54.965424460749475, 43.04188982132943, 19.431610107421875, 3.2033965328047356, 0.5643282506254412, 0.15804217677683602, 0.10212309793719362, 0.2536984737361631, 0.6422351024323895, 2.476703423646189, 0.6409160828878803, 3.568191912866408, 2.93565284821295, 4.033073432022526, 2.6088343464559127, 4.677991251791678, 4.86797958612442, 5.974155635603013, 3.3818508924976474, 5.663416154922978, 8.661660225160661, 9.281184865582375, 7.381307405810203, 8.770694271210703, 10.033300326716516, 2.2382056665035988, 4.453313965951243, 5.331933709882922, 15.909284430165446, 23.33059314758547, 20.5665930240385, 27.14906953996228, 27.268615538074126, 28.41138239829771, 27.313389393591113, 25.10701890914671, 32.9885648142907, 23.094558638911096, 21.06939381168735, 32.41852675714801, 46.688034919000444, 47.62122169617684, 61.30411194216821, 47.89012762808031, 56.476054729953894, 45.44780892710532, 47.42883336159491, 22.69930139664681, 20.49902235308001, 21.232925268911547, 26.448081193431733, 21.702505542385964, 22.817245106543265, 8.71222742142216, 5.299345187602505, 4.601436882249771, 3.56845201503846, 5.866795461024008, 6.384912123603206, 5.379065400169742, 5.266596828737567, 5.401604810068685, 8.755303871247078, 5.591018026874912, 6.209037948039271, 7.243889618304468, 8.32699183494814, 5.34285407873892, 5.647536929576628, 7.510382311959421, 4.63779382167324, 8.975468470204262, 2.4441131853288223, 5.010767588692327, 1.6070416377436731, 0.5178072243448227, 0.022625761414547602, 0.07287607498226628, 0.1112120953058043, 2.0782254251741596, 5.3838129389670595, 18.54467591931743, 32.92901539033459, 34.99258610510057, 45.15554135845554, 68.35108926219326, 81.92941696413102, 77.63620238150321, 55.52695881935858, 17.906068948007402, 20.848807557936638, 24.993585924948416, 44.8397474135122, 61.414216795275294, 56.163418292999275, 59.44786594760034, 34.49219365273753, 4.521215096596749, 0.17919786334518464, 0.027381930192331635, 0.07820833804866961, 0.17734019205935542, 0.150932053464555, 0.1412433854514553, 0.20500348910929697, 0.2005771250133553, 0.1902810258850936, 0.1348093960193857, 0.24810197162291697, 0.16537875567953433, 0.0524911801180532, 0.038992523200689785, 0.040301158423385317, 0.04514655729214992, 0.049115804384552667, 0.029700338247142015, 0.03270361933016008, 0.05998738110065461, 0.10966329534928645, 0.03832723329504652, 0.04490246252727605, 0.013415131308589012, 0.05647010673137923, 0.07516404253340538, 0.05719833459044176, 0.022817802420186422, 0.08315455408826952, 0.08339643102860259, 0.010974961239093495, 0.09052004514923019, 0.1751559374914054, 0.12890117272974985, 0.049032622557734294, 0.041726357754199736, 0.046725100612327944, 0.039545420346961874, 0.1052927024542324, 0.08821013683993971, 0.09394631210354068, 0.10619859376381482, 0.01828493678101128, 0.042392429069525776, 0.028283431818107926, 0.03317434205523422, 0.10026980101341203, 0.05908887104822263, 0.055954472101744146, 0.0352682480438342, 0.04011233307180866, 0.0405457396540911, 0.09835032175385183, 0.06243687446018862, 0.17465594254674452, 0.10490274837901516, 0.20866879081774145, 0.15082657847914005, 0.14310770638046727, 0.11213006016107337, 0.11616130674918813, 0.0354481867754892, 0.09966508184950199, 0.3047639948706473, 7.611480422558324, 45.56256963360695, 80.91961845274895, 84.84300059656944, 76.0524748217675, 77.3796558380127, 53.42000276811662, 47.37875253923478, 32.12136407052317, 39.199822333551225, 42.99415065396217, 26.606982292667514, 39.74387468830232, 38.87625032855619, 51.27094007307484, 38.79690077997024, 17.076128759691795, 3.557793954687734, 0.47646630074708696, 0.15488152782763207, 0.3592983008392396, 0.7530335409025993, 2.0423772907064808, 4.823507753110701, 5.269538116070533, 6.507191523428887, 7.271343758029323, 8.19896763370883, 6.223377643092987, 7.887022024200809, 7.4996418818350765, 9.181729247493129, 5.369280067182356, 8.77324773419288, 13.006290216599742, 11.399316730037814, 10.357887244993641, 7.8976168363325066, 6.6855681711627595, 5.090051437577894, 1.422478186507379, 2.9651449043904585, 9.759393372843343, 20.087957959021292, 22.236728437485237, 25.691683484661965, 27.55522116538017, 31.0303097386514, 31.171132633762976, 27.781043783310924, 34.0515467428392, 25.916364692872573, 23.361183712559363, 39.24557678161129, 57.85225360624252, 55.62639482559697, 68.68115671219365, 58.35905128909696, 69.0652822679089, 55.022400809872536, 50.05754309315836, 25.435015347696122, 22.74258279031323, 22.34722552760955, 27.966042372488207, 22.06235751028984, 23.086627606422674, 8.752385627838875, 4.935900328620788, 3.676355437886331, 3.64881010305497, 3.655899051697024, 5.641535212916713, 7.213908001299828, 7.5229652754722105, 8.658161470966956, 11.843271178583946, 9.755284690087842, 9.400471987262849, 11.368092702281091, 11.52683690670998, 7.0840785291887105, 8.383031718192562, 8.97370340362672, 9.129367566877796, 7.535310445293304, 7.242621221849996, 7.92908012866974, 2.80896445916545, 2.1029841611462254, 0.5836181606977218, 0.2035489486109826, 0.16724687640465077, 1.1339778092599686, 4.857739258197046, 17.139016120664536, 35.55663862536031, 40.69357856627434, 38.38632668218305, 52.36457140214982, 74.86746403478807, 73.43679520391649, 56.29840666247953, 24.226313444875903, 27.95539902102563, 33.32847349105343, 49.69773623251146, 67.61312669323337, 64.2612809519614, 68.07559767077046, 42.66232205975441, 6.044479810422467, 0.19652550048645467, 0.10996142612589944, 0.020017580602378137, 0.051204148574822375, 0.13814342598761284, 0.12466259976668705, 0.12153178228125458, 0.15195608319294068, 0.17695370070155592, 0.10241588908097438, 0.1830104224744343, 0.1571388671835584, 0.04261539129900836, 0.06942774469573652, 0.05858773463255456, 0.0625272536830556, 0.03530705805807825, 0.053709026260842244, 0.06560532601490136, 0.01889235832007422, 0.09428121510051912, 0.020483283536328424, 0.05672131462263004, 0.02094312972809759, 0.049465286034730174, 0.07148400895417699, 0.09728484666876255, 0.12191887884851425, 0.07429882283172301, 0.045660134975708304, 0.05656540806915972, 0.001826022757262352, 0.03789859561009273, 0.7091341900729364, 0.2731760447063754, 0.21609247391743047, 0.31330912343917355, 0.253912610632758, 0.22486698453224477, 0.115858280670739, 0.23995464186995263, 0.2805343805061233, 0.1361839569384052, 0.17277607003286963, 0.12664763316992791, 0.11887061499780226, 0.24039649074116062, 0.147842267648347, 0.20017446920035348, 0.15024971427215686, 0.29383320721887773, 0.2494379370323112, 0.28798259374114776, 0.20225384633146948, 0.6457190251638812, 0.43456984083017997, 0.6890889785943494, 0.3698060240957045, 0.6650821119546891, 0.2869454026222229, 0.39206645541614105, 0.23060590239061465, 0.31468857199914996, 0.6150497063513726, 12.54396926972174, 57.809562529287035, 93.37433615038472, 93.94806123548939, 86.36282490145776, 86.63099735013901, 64.44291806990101, 53.99010358318206, 40.574801352716264, 48.88398954945226, 56.28981667180216, 38.473662176439845, 44.566750449519006, 56.770914985287575, 70.91362076420938, 53.691191519460375, 24.70056330004046, 4.32335848769834, 0.9753529306861662, 0.39319775277568453, 0.3038653124484324, 0.45834375545382505, 1.8414209062053313, 5.63140667253925, 5.4148290811046484, 10.331033718201423, 11.639387357619501, 14.189060349618236, 11.465451813513234, 13.122379625997237, 14.402796183862995, 17.99318478953454, 11.09861606551755, 13.642481007883626, 20.90053773695423, 22.174227429974465, 17.22463950034111, 21.469530482445997, 22.531270980834964, 10.04595095111478, 12.173391580581667, 12.760893010324049, 24.89000593462298, 34.8888982495954, 26.977677652912757, 34.58969593048096, 32.617834152713904, 32.802836664261356, 35.017854013750636, 37.26933371636176, 40.20640842376217, 27.84092856991676, 27.829179110065585, 47.88835471676242, 59.37958532764066, 55.845329761505134, 71.47488840164678, 62.43989698348507, 77.18926398984848, 59.405892664386386, 56.75373500393283, 29.767222212206935, 30.05520066907329, 26.64257387961111, 31.90362349633248, 27.018289873676917, 27.44542225714653, 13.385590276410504, 10.118886443876452, 9.21088912794667, 7.8205888405922925, 13.554965084598912, 16.009078352682053, 14.514976951383776, 12.791436506855874, 15.48545664356601, 18.28211049879751, 16.0130173929276, 14.917726901269729, 16.45339758165421, 17.988517169029482, 15.292306388578108, 15.505350905079997, 14.232467259130171, 17.876207943885557, 16.61885492263302, 11.697314881509351, 13.063976514723993, 3.5653437818250353, 1.4206812506721866, 0.601126027684058, 0.2756478733593418, 0.2143975043849599, 2.4728156193610165, 6.646534704392956, 23.96899223327637, 44.056332418995524, 50.05109471659507, 58.4997663190288, 76.63863382031842, 85.3989887237549, 82.23749560694542, 66.30524373823597, 28.973558064429994, 34.82877615959414, 38.46751582237982, 61.30823435321931, 77.86846160888672, 74.12922689991613, 77.5909068507533, 51.74460157271355, 8.279525272307858, 0.4418071653814085, 0.30264223775556015, 0.20895711566892364, 0.2899664243863475, 0.2963678244381182, 0.25708945468068123, 0.36431161085924796, 0.3864300401220399, 0.47276416553124306, 0.36867098822709055, 0.646277166181995, 0.26818439965286567, 0.23815739959959062, 0.2023738463439288, 0.18483510601424402, 0.17714139224300463, 0.321696468538815, 0.22150902197726313, 0.18643737890787665, 0.18802154148297925, 0.22997486044562634, 0.17578504889482455, 0.15827948017226112, 0.08952544851889534, 0.1530634786092466, 0.1643486738565468, 0.2481316651908621, 0.26946385841696496, 0.2710986594038625, 0.2965428908505748, 0.20892670197832972, 0.20509125214190255, 0.41823114659036364], [0.07714916786719715, 0.07890981411741627, 0.11036675558575701, 0.10255633598013271, 0.12827131056016491, 0.07087440214931004, 0.00590391643908656, 0.0834865995772904, 0.08844908732440203, 0.05330900579029995, 0.05295282853166423, 0.05517951287930051, 0.05781457188629335, 0.13109664282491132, 0.053901582460610144, 0.08724125778122295, 0.10438352462745483, 0.12169800803906496, 0.1418719759150859, 0.0783015096620206, 0.10915854299861578, 0.07920114969414088, 0.19716417266716882, 0.07105480819459885, 0.06622759625315666, 0.23964917197102503, 0.2380822463742187, 0.07988087652671723, 0.07567413451690828, 0.08428684736211454, 1.5573681290111236, 20.415546471072783, 60.259647523203206, 80.55232770981328, 72.61768664083174, 64.23445586235293, 59.985454236307454, 62.36865105167512, 49.300372677464644, 48.11129439261652, 43.51719479407034, 39.129890395749, 29.94606660258386, 27.017360271946078, 48.93931850310295, 36.93033895184917, 13.670271981147028, 4.005534716190831, 0.46665617715447183, 0.10054599103187362, 0.069811332580303, 0.520185528983993, 1.2369501999308987, 1.7971585522736273, 3.43510098995701, 3.983638575000148, 4.258086815957101, 6.27869826170706, 6.332269993520552, 7.709321985321661, 6.786198048822342, 4.99533502324935, 3.8234374552003803, 5.362004560808982, 8.237113664227149, 5.69982506575123, 9.033403838834456, 11.34978602009435, 5.471373969508756, 5.037499522009204, 5.730525457089947, 13.908589309261693, 20.835283225582494, 25.922767962178877, 35.07019019895984, 47.600315463158395, 48.603861716485795, 52.102882631363414, 46.299339802034446, 51.06413310573947, 44.69390976813532, 44.62052614458146, 43.351302070002404, 33.22266755565521, 40.25268454705515, 39.4246643589389, 54.552967625279585, 56.807957849194935, 43.26988543233564, 36.701864811681936, 40.52672878388436, 55.031351658605764, 36.31370705942954, 27.374896080263202, 41.280616175743845, 43.25265838253883, 41.08630980214765, 39.38049847079862, 37.84606725938859, 22.343283545586374, 16.54966627397845, 13.312370411811337, 6.0898758519080385, 11.156653415772224, 11.849750934108613, 8.543586096455975, 7.976434413463839, 6.113115404882739, 5.004675167222177, 11.440691851800489, 12.038002148751291, 10.810778813977397, 10.502264788073878, 3.5287311528959586, 8.999593007949091, 6.665127229306006, 5.429381564740212, 3.0755000537441624, 4.824860480523879, 4.432956864756923, 1.4467697927067358, 0.5782167505352729, 0.09486730300611067, 0.07449943061557508, 0.13817259861576942, 1.049615716741931, 4.825264974947899, 17.194433327644102, 36.25434590924171, 49.77330853862148, 79.07284105977705, 84.72103841843145, 77.13834378027147, 62.44121882223315, 41.1626705046623, 20.36240816116333, 22.598657300395352, 40.14980862217565, 53.478340179689475, 59.77989850505706, 64.2561818707374, 49.72903282411637, 15.11027507243618, 1.4115491148925599, 0.025534089729790727, 0.14244781356425057, 0.0929778237496653, 0.09900198678576178, 0.1184521854344395, 0.11171832620616882, 0.1911770116778151, 0.058672720596434615, 0.0965142158430911, 0.15448670143321638, 0.16114523123589256, 0.049196247447041735, 0.13502089757352106, 0.014011738558990822, 0.12010751757770778, 0.0805899981529482, 0.0314049604874585, 0.014671287593251515, 0.040834819101878715, 0.054559230639208714, 0.010428577755397607, 0.04811885969472989, 0.035287890538212754, 0.033042268497088266, 0.035180124949904225, 0.046983697421608434, 0.07179613615716658, 0.026728824915124044, 0.0986239990039218, 0.035864567053654504, 0.05649403548769413, 0.09862380748194072, 0.07430567931864532, 0.07793993914439794, 0.061676578160615704, 0.055980197334241484, 0.1758929447180802, 0.11498232807723746, 0.03470039303084055, 0.03148234302869007, 0.048921919022236145, 0.0792318085328706, 0.0426351563674548, 0.01835345376973912, 0.021427511800861648, 0.13010590727771484, 0.2365430071949959, 0.038294609440791036, 0.04726911113867837, 0.14847609815337967, 0.022678092880655202, 0.05926510191432411, 0.053328054566537185, 0.12551013049819779, 0.0884056807826123, 0.04093788474077179, 0.05178505006516653, 0.1403400605364192, 0.06396786670290655, 0.08383818030838044, 0.0376084934349262, 0.11665314285745544, 2.006508196073194, 26.778895854949955, 73.03057885939076, 91.50158482213175, 80.80070003386467, 72.42530222861998, 69.98820027997418, 70.85526374078566, 54.613513331259455, 49.97050569903467, 43.64890406208654, 44.33624452160251, 32.379195190245106, 25.792978694362027, 43.038238094699004, 35.49015052856938, 16.798105278322776, 3.941613320381411, 0.2827224501919362, 0.14598657286936237, 0.5332677979623118, 1.303076825795635, 2.113838585153703, 3.95077720284462, 9.052907824516296, 8.290018593111347, 12.015127866498887, 11.725747162295926, 11.6837062181965, 8.323708811113912, 8.412521077740578, 9.614743225036129, 9.875525928312733, 10.268045356196742, 6.755850670799133, 10.59306569637791, 7.519653324157962, 8.589456254436124, 8.21246450947177, 6.259159955286211, 7.537335368894762, 12.16750410295302, 20.258792869506344, 27.947012993597216, 37.65574993625764, 46.89914472641484, 49.163109333284446, 52.90342661642259, 49.18926761996362, 55.86494945710706, 49.40914392471314, 49.47349825213033, 46.79897131458406, 35.65924782906809, 43.968808650970466, 46.99918477765976, 62.54521262261176, 61.167562469359375, 52.105412560124556, 42.98126566794611, 47.42723303456461, 60.08275255080193, 40.260399849184104, 31.16211118236665, 45.550418130813114, 45.46079197237569, 43.83914293781404, 42.33780868591801, 40.49230214088194, 24.16545787165242, 20.09372776554477, 14.960189500162679, 8.794575622004848, 7.587774597829388, 7.543289036520067, 7.77684509754181, 10.411576647912304, 10.115020948071635, 10.914134248610466, 13.390621696749042, 11.445743864582433, 9.156881032451507, 12.20955583357042, 15.096963528663883, 19.180656863797097, 9.70882127361913, 9.202891415165318, 7.253744573362413, 8.560596435300766, 7.066696545770092, 5.223025179678395, 1.6293213131927675, 0.9669436141848565, 0.16677770883806292, 0.2129512069927108, 0.6036147102713585, 3.7711792270983424, 14.853434351182754, 29.861849392614058, 48.01013646587249, 74.68418736611643, 79.45652731003301, 79.75330168201079, 61.6205216992286, 42.962559884594334, 31.60684520198453, 28.8314623601975, 49.52271615305255, 60.10187802776214, 69.08628263781148, 72.08150648301648, 59.84659448746712, 19.363223583467548, 1.5403750731099037, 0.08308907655338127, 0.04139052779083291, 0.07782257447439818, 0.0658744373809426, 0.08826069864294223, 0.09409784429496336, 0.10092909628104779, 0.06802718275256696, 0.03730449825525284, 0.07626637410853179, 0.0900637555206495, 0.07609146091366008, 0.041560028574519584, 0.03099883429615969, 0.05673780083476056, 0.021456778274788972, 0.07642084041670447, 0.01601412385371664, 0.021265727437792287, 0.02192859650559483, 0.03525564972791941, 0.030514574797463515, 0.008359671130986705, 0.025449595977402022, 0.046057661830057064, 0.01131967782238198, 0.05197441167829018, 0.06663713153571853, 0.03452024745544599, 0.034960368798384746, 0.031165475656668988, 0.08532225349617582, 0.21913565094432524, 0.3024311652106624, 0.19442828882846142, 0.18260444183984112, 0.2383111687677522, 0.2712686696360188, 0.12820239329049665, 0.20902453140626032, 0.19847781427444952, 0.2068807569242293, 0.14176257855949864, 0.10409341479140906, 0.20354527138894607, 0.2647794759081256, 0.4069152005737828, 0.157163274744826, 0.28227171470080653, 0.2868954843330768, 0.23466203151451004, 0.19883577651794881, 0.21997580424912516, 0.3102544550934146, 0.28622871204730005, 0.2770254833082999, 0.19170041826944198, 0.3900748719611476, 0.3290555704264872, 0.28749753751101037, 0.33255251665269175, 0.24458504582364715, 2.8918966026075426, 35.54303584560272, 85.1776336854504, 101.8747869614632, 89.47015008618756, 83.23482098117952, 76.20591794290851, 77.40383332775485, 62.24839118219192, 60.9782688848434, 57.70821632877473, 52.42721557617188, 43.463638751737534, 37.96385603566324, 62.89242083026517, 46.54959094139838, 18.90753438395839, 5.482517913464577, 0.8094738123397675, 0.3228401765227318, 0.3354656425935607, 1.1090542111665973, 3.1389059030240585, 5.523009521345939, 11.392638894819445, 11.050245396552548, 15.514555727281879, 12.669283113171979, 17.435992494706188, 20.128405440238215, 18.584448752864716, 15.550943555370456, 12.86768836359824, 15.067479072078584, 17.502813992961762, 16.3520101962551, 19.248894337684877, 18.0202099200218, 14.412717819213869, 14.549853686363468, 12.51109294352993, 20.706788339922507, 26.42975784117176, 31.160648138292377, 41.209319253121656, 50.88783825597456, 51.807253591475956, 56.33384919935658, 52.34266888710761, 57.73733992730418, 51.027078474721606, 57.342000315266276, 48.54471237428727, 39.93936561769055, 53.339566722992934, 50.08230893842636, 64.2260855244052, 67.28883297212663, 56.83861901683193, 51.22679771915559, 50.825064643736816, 68.29334412851642, 46.199613540403305, 34.59235921982796, 47.67934337739022, 46.07163444642098, 44.21904017848354, 44.25189395104685, 45.503977267972886, 28.597249792468165, 22.487624806742517, 21.39696663425815, 11.99646326803392, 17.220672022911813, 17.559647175573534, 17.054177215022428, 14.91079705376779, 13.06883829255258, 13.660131673659048, 20.69959863539665, 19.68303011309716, 17.0243279780111, 20.271277773764826, 14.960461124297112, 24.080862152960993, 12.738374683164782, 17.562051588489165, 13.173872501619401, 13.408992117451085, 9.432264758694558, 5.087743613027758, 1.3622895387872573, 0.852616452161343, 0.1807101209077143, 0.3482281464722849, 1.4706024815959315, 6.219014986868828, 21.619882775891213, 46.48146329387542, 62.59376764297486, 83.9812009565292, 85.5809945444907, 81.27354175813737, 69.95469539396225, 53.37295786026986, 31.038142711885516, 36.12169135001398, 56.01044193390877, 69.73814133674868, 78.89215315541914, 82.95626994102233, 70.47134214831938, 28.18006257857046, 2.3936126693602535, 0.18761899292228684, 0.3239624646882857, 0.2032349751360955, 0.3000246685358786, 0.26717429740294335, 0.3121940365001079, 0.31958080948360507, 0.15522579241904522, 0.3796358514697321, 0.4881949230067192, 0.4088736277434134, 0.22780742916849353, 0.2002828553198807, 0.21063360716066054, 0.3445256128907204, 0.20206371863042155, 0.1645445931823023, 0.1460621244604549, 0.18808161809800134, 0.2067172277959124, 0.15408193121754354, 0.20437679854371857, 0.21697745868755927, 0.11407832134394877, 0.11237359951220213, 0.13596013669044743, 0.1571245106958574, 0.21295618656421864, 0.31912088093738405, 0.10130840939499679, 0.12051632507674157, 0.3838428079841599], [0.06661496095118985, 0.09091871730502575, 0.009523251435659345, 0.10634618060242747, 0.20908230975750955, 0.03428090243570266, 0.050806817072894306, 0.05440298317661209, 0.06682944258735066, 0.030834855091187264, 0.022920988717927568, 0.0579076630604123, 0.07543566666783826, 0.04727952610400896, 0.10108678015850245, 0.11739622516136979, 0.05591742408972594, 0.06722564794003003, 0.1306999471759604, 0.17343513547412812, 0.20900012384499275, 0.15852134945171495, 0.1443184777012756, 0.06927404447548813, 0.08451262879515849, 0.10036568457801497, 0.10900036882488959, 0.08545890059922973, 0.09206309944631592, 0.2028187748885924, 7.9104581859803975, 49.953200201834406, 75.48009903200212, 78.31834177817069, 69.71346962836482, 59.21406915110927, 44.32424991361557, 23.39036418545631, 32.393627551294145, 46.14693218661893, 51.64353386048348, 28.92284377928703, 28.788473183108916, 52.58708353965513, 41.69537544250488, 20.4513047587487, 5.065641057106757, 0.41025813248369003, 0.036596441491236614, 0.05827233240368867, 0.33769076029139183, 1.0885648525530294, 2.426436778999144, 3.964292955014014, 7.63809125269613, 8.211440770856797, 7.292064168760854, 9.31675389889748, 8.60850916754815, 3.050585158409611, 5.684810232731604, 4.154257264829451, 7.5880138624099, 5.3052233496019925, 5.174252958067003, 11.998155770763276, 5.912745537296419, 6.504079122697154, 5.856004530383695, 9.762149818481939, 21.92219945692247, 31.648602754839008, 38.555298466836255, 57.844432400118926, 60.20070214425365, 66.11655419872653, 64.54388772287678, 66.16239886130056, 66.1627204956547, 69.08565505858391, 70.88905888219034, 66.50743407587852, 60.338016479246086, 38.71235801327614, 49.970035014613984, 41.62406283040201, 52.72825356452696, 59.492839843996116, 40.995169608823716, 38.03867916907034, 47.47181861631332, 52.39316940307618, 43.22699823687154, 45.78041415060721, 62.01872856386247, 59.86687706362817, 62.59719579450546, 58.65386447598858, 61.15629742222448, 58.902358393515314, 50.21173538700227, 39.30418875909621, 30.717955712349188, 21.083365294241137, 18.456434357550837, 15.637414167004248, 15.212634225045482, 15.105988902430381, 7.294436712418833, 12.896523667920022, 15.41977753562312, 14.18981638646895, 5.137875426200129, 10.327084872030444, 8.14971443145506, 9.11604033362481, 6.3474902606779535, 6.88411315602641, 7.397106712864292, 4.227837497188199, 6.002347671216534, 2.4872158660042674, 0.4471947246741864, 0.08668339255476191, 0.08263101726169549, 0.2254240070619891, 0.21958339869255022, 3.6790834463411763, 14.24145438978749, 29.83983901239211, 44.85427587263046, 59.90634395230202, 46.26248521189536, 48.315238029726096, 30.284565187269646, 20.2470257589894, 17.981080355182772, 24.90416765213013, 45.28237904271772, 60.003724636570105, 63.18072288267074, 60.453051751659764, 26.787219124455607, 3.2186668101818334, 0.23746588267385962, 0.17784205625855154, 0.08646888793596337, 0.16372310177933785, 0.15705504184288366, 0.09500233366364434, 0.1494771299222785, 0.07168145279490179, 0.12339391985968237, 0.0861792071091552, 0.04624359903015918, 0.11798066597792412, 0.04469325540647392, 0.056138551538629886, 0.1978614658958489, 0.04116418711360424, 0.01730886798712515, 0.029031334730285793, 0.10347849133634761, 0.028225268507676742, 0.058633259407454924, 0.05870772315369499, 0.04568507496808325, 0.003287390056591962, 0.033018366553850716, 0.038691944773158723, 0.09420111294715636, 0.05269875547157661, 0.095887471651358, 0.02942767797879154, 0.0877209130914942, 0.11779049231160073, 0.1466004697666053, 0.04818163293924543, 0.06748948862115223, 0.0921911127384632, 0.12047472650245314, 0.04759770157116075, 0.034427608273202376, 0.015556470588630727, 0.059765073876347274, 0.041142261677211335, 0.07409759451665225, 0.05141381534837908, 0.12578504881070507, 0.08523689597965249, 0.09752705302690307, 0.059960445449236906, 0.08966198070876061, 0.031653314701191364, 0.09286346980520795, 0.11030330818386809, 0.021828152802622607, 0.1502372117172326, 0.07168154472545271, 0.010399748909197027, 0.08456380346850043, 0.09419160579601604, 0.09834292134450329, 0.08910769311290595, 0.04117153389679809, 0.1857034207111405, 10.535257804778315, 58.991141242365686, 83.06896748081331, 85.50926223877939, 79.09228032635104, 68.37638070506435, 52.83872319806007, 38.54226050838348, 45.99113564337454, 47.425813136562226, 48.988556015876036, 33.50069299820931, 30.899461430888024, 42.10922079701578, 34.847328970509196, 21.57479120839027, 4.438753147279063, 0.2538136933599749, 0.18848526982530472, 0.24649298779906767, 1.420672302765231, 3.890510475443256, 6.627844610521871, 8.61545176275315, 11.136094312514029, 10.447188827299303, 10.415902041619825, 12.078489834262479, 9.467745538680784, 13.324677828819523, 13.08940229877349, 11.173666696394644, 9.297340127729601, 7.54954178487101, 13.134378156354352, 17.53689350620393, 9.495355102323717, 6.636689064964172, 4.637361380361742, 8.01041978982187, 19.479113932578795, 33.071452340772076, 43.636124980065134, 58.25425732520319, 62.815385480080884, 68.57414660915252, 66.64631735893988, 70.40325764686831, 67.88408402473696, 69.63357094795474, 76.8333794993739, 71.39547609513806, 64.43489290052845, 41.10913407418036, 52.58331021954937, 51.05736701719223, 59.146051329951135, 64.8042271983239, 47.62809761108891, 45.447071521512925, 52.94218747846542, 57.56180209498252, 50.20052133067962, 50.96028835542741, 67.37277953855454, 63.33188318437146, 64.34496471958776, 60.444548053126184, 61.39254570007325, 58.710668240824056, 50.81376821764054, 42.11697924521662, 34.109727259605165, 24.751636482054188, 20.142720130182084, 13.539442304641971, 12.29730906025056, 10.676578840901776, 9.253719449043274, 14.345574686604163, 11.861315061969142, 10.717446015727136, 11.25470776711741, 18.184115963597453, 15.635604973762268, 14.044782826977393, 10.985663571665365, 13.157054358913054, 9.539960295923295, 9.769706264618906, 7.775103565185302, 4.704968823540596, 2.2591158218922156, 1.3870225342050677, 0.30310057283889863, 0.182079640968192, 0.22715170387058492, 2.926461018862263, 13.966702165142184, 32.93449494146532, 52.56835422208233, 72.021925680099, 61.44997312176613, 49.82568002516224, 37.546280507118475, 26.37508784571002, 25.981289725149832, 33.269206477749734, 52.67712154696065, 65.89488537080827, 70.57885431474256, 68.36054217430853, 34.581604080815474, 4.376746358410005, 0.29007373798278074, 0.12475453031760071, 0.0496864824315473, 0.11432281830498289, 0.03333988982523161, 0.006424081521183854, 0.14655016843349705, 0.09974192046830732, 0.021847674638153087, 0.02515072209550248, 0.07657104727601813, 0.049721917828484896, 0.08647097935599667, 0.048335153128831625, 0.13379052972360966, 0.01582522189334756, 0.021889246399364164, 0.042347294999466795, 0.059816516680462714, 0.029162389391492453, 0.0683526858507145, 0.04663970862184802, 0.07683275823271082, 0.06977354912387748, 0.032549379017925074, 0.03514331059470292, 0.034835140235842235, 0.02055480550493925, 0.04814258926818448, 0.042078011263642585, 0.03341885816846644, 0.10362810830795958, 0.2506560627971926, 0.20106158369491178, 0.24366023980321425, 0.18071951314566598, 0.3176700329828647, 0.21795198381427797, 0.26909821997246436, 0.15583665560810797, 0.2355791306904247, 0.2345221745030534, 0.2406756838242854, 0.17646133599262084, 0.23354513660794307, 0.293952195995277, 0.17216195863100792, 0.26213261148621964, 0.15693792232101964, 0.11549034396246557, 0.2867198969808317, 0.21447118672151722, 0.36113222339941614, 0.4124907271996622, 0.27126759711292486, 0.21910018107343107, 0.2764530317677606, 0.2679652065759705, 0.26723990517277874, 0.22487735736273953, 0.22672687747305442, 0.35646932199597364, 14.959269704357272, 70.3518275291689, 94.25958371931507, 95.0848033351283, 87.77221879651471, 75.38121607995804, 60.61272751900458, 38.380705925726126, 46.682720107416955, 60.198729192056966, 65.12942698694044, 43.207888449392016, 41.81439976538382, 68.56611359503962, 52.04756936719341, 25.879918029231412, 6.722818430392974, 0.8118222089063737, 0.1940033858221385, 0.19858517383615817, 0.8111492159866518, 3.986958371054742, 9.001465939706373, 10.239211032467505, 19.952332204388036, 16.875776052474976, 19.006799767094275, 19.88975667184399, 17.150977388505016, 10.850658532111876, 15.1324599981308, 17.607492246935447, 16.423823891147492, 13.415109053734811, 16.300146656651652, 21.485878921324208, 13.7166138041404, 16.562425744148992, 15.599937881192854, 16.05359333176767, 29.74464308831, 37.13492193529683, 44.708061679717034, 62.05334348063316, 66.34949591852003, 72.02133732457315, 68.33740803503221, 70.71334454321092, 67.03069394634616, 70.56874244443833, 76.16419176901542, 75.49583558113345, 69.55864583292316, 46.78708653296194, 65.99980092817738, 54.760751262787856, 65.90567188878214, 67.67655926366007, 51.14626753714777, 48.57549121302944, 58.1274353304217, 65.71044375819545, 53.98146260169245, 55.083393666052054, 66.68836516718711, 63.648685178449085, 64.07153237250544, 62.76179021404636, 64.06221282097601, 64.60859898597964, 56.56919533206571, 46.21316532934866, 38.25424478900048, 29.514099897876864, 25.29542407681865, 20.4713108078126, 23.262487073098463, 23.12392150202105, 14.749957323074343, 23.142031085106638, 25.57741503561697, 26.261986301791286, 13.527460444358088, 21.79655417319267, 16.052151860729342, 18.184417986100723, 19.27784731311183, 16.63990039979258, 19.44366158977632, 15.469348449860851, 16.5659244983427, 8.427202509295556, 2.7733760591476195, 1.1091851202710983, 0.25639056798911863, 0.5695633890648042, 0.5518834893741916, 4.654190799882335, 17.45299793058826, 36.68544577014062, 53.86310115937264, 68.98974526313044, 53.885058587597264, 57.914458474805286, 38.048661601158884, 29.426362360677413, 29.614689080945908, 39.11993934262184, 61.86954121435843, 76.49192933113345, 80.09169240151682, 80.71401565305649, 45.41746154908211, 7.683825598609063, 0.5452021607948888, 0.2949638917080818, 0.17974299619034415, 0.2781205600307834, 0.23791045881807807, 0.26000975120452147, 0.3844247283714433, 0.23257600474021128, 0.2627957984805107, 0.31514758123986186, 0.2575089950715342, 0.25438999066189416, 0.2576169521818238, 0.2862293862046734, 0.3786907134757888, 0.1666786996347289, 0.1269313768153229, 0.19460269640530312, 0.18504096916125667, 0.24779610335826877, 0.18386857884545482, 0.2670932453005545, 0.29948846827591624, 0.18252381874668985, 0.13990461616025818, 0.17200912409011396, 0.21362377090319512, 0.29147999962010696, 0.18240242445420835, 0.12659443602446588, 0.26441766790324644, 0.3577174630857283], [0.07887367008914871, 0.04910221781521555, 0.10840570839542536, 0.2123291129546781, 0.05566804714861417, 0.022580872492624388, 0.025408537495100213, 0.05041341943245742, 0.05455797042457327, 0.022001282927850564, 0.05851928850695972, 0.06835692231693576, 0.043193933238545736, 0.051784184385812095, 0.06180179906227897, 0.016330541149082205, 0.08059887711199061, 0.12699667814998858, 0.07576407323921881, 0.08027955634339203, 0.13840838515710446, 0.22403853705092786, 0.07828861640225496, 0.23018810868022904, 0.08854156945862117, 0.08596726888490301, 0.053674663386998646, 0.11024353034313648, 0.13357916606530068, 2.8284380464784564, 29.948237634474236, 69.94647410608107, 73.05168121091782, 64.73164766065537, 55.27733133685205, 56.992677950089984, 35.61037117435087, 21.468406723391627, 39.009614836785104, 77.09310316270398, 60.696344606338016, 40.74902126866002, 53.49923856796757, 43.23751411130352, 20.096440084518928, 3.6436318389831053, 0.376782541673991, 0.08518071109128576, 0.2572056242535191, 0.3669384650645718, 3.0364893857509863, 3.9726640284061436, 3.8971981165870546, 4.815535045439198, 9.797385450332396, 7.754495922596225, 11.726539481070734, 14.87370712141837, 11.979770641173086, 13.672896046792308, 7.194116702002864, 11.538475559603784, 9.396977155439316, 8.617616911088268, 6.55634617613208, 11.731157091356094, 6.050596256409922, 10.988392560712754, 21.735863339516428, 31.84851223422635, 50.898377664627574, 59.08554484767299, 67.54823500110258, 69.63930545314666, 65.57724791188394, 65.98444877132293, 65.87875658465971, 71.37764500033471, 68.27248496394004, 72.02951154401227, 72.57633701447519, 75.68696483489006, 67.69680653848957, 47.605434156233265, 36.3919936456988, 37.56118943614345, 45.56793935837285, 60.408795649005526, 46.623833564019975, 54.96498907766035, 48.07016834135979, 51.707935256342736, 45.00584802319927, 56.679790481444336, 61.99440986879411, 58.24613409657633, 67.09342049014184, 69.72053773941533, 74.83489267287716, 66.46966949585946, 68.28622894902384, 58.606980385318884, 55.52033001376737, 45.288239063755164, 33.815702469118186, 24.256945194736605, 28.019229712024813, 22.95110579459898, 16.09750524643929, 16.620990653191846, 12.352001609340792, 7.251892724344808, 14.872091104907376, 23.303162051785378, 21.73953271681263, 10.787491702264356, 6.571086443239643, 7.533565971159167, 8.992743569035685, 8.126866625201318, 6.373313184707396, 3.6948677993589834, 1.677764423431889, 1.8319331830547703, 0.6618722648389879, 0.02489918095600461, 0.1275964177423908, 0.13414697511301887, 0.9881488053548722, 6.4679688022982695, 23.825992422719157, 29.8309568051369, 23.672890547783147, 27.810914593358195, 41.160721086686664, 30.922238634478663, 19.48155756919615, 20.961779663639685, 31.113679716663977, 52.67162630634924, 63.43506113175423, 58.26962517153833, 47.76487458136774, 17.538968440025084, 0.6191988998363095, 0.09498445317149164, 0.12777173696386238, 0.07504974221510273, 0.0841645490858824, 0.08538059109160978, 0.10145195895024847, 0.17815855782358878, 0.09219574757040509, 0.00831094123573313, 0.06008537140704932, 0.05211126179464402, 0.05639809829693648, 0.04984173014940274, 0.12235561791326731, 0.19847695625597433, 0.024363041983076164, 0.037931319055778366, 0.06565511406910035, 0.06620584701698634, 0.0006693546005877697, 0.033554237396005666, 0.08102249309060075, 0.06558221314222583, 0.03403177447316628, 0.07419334784630807, 0.06261688597019642, 0.018102119473980802, 0.029212926296637427, 0.034106249710725206, 0.08834870682368356, 0.02496547628975203, 0.04528305500805859, 0.04958563461719502, 0.1199842080654156, 0.1150514368688868, 0.09424050518822286, 0.02772773845091222, 0.0829695285327973, 0.0131564243741694, 0.08200554477591669, 0.028661176367031953, 0.05540770748930593, 0.08662783585849308, 0.029402538803556276, 0.14324229270700486, 0.029237919915167075, 0.04601068914897981, 0.059826629041063215, 0.03298942758251102, 0.08213423988631657, 0.083693313081899, 0.11739221086064655, 0.14495831433563464, 0.040157539920220454, 0.10716335126949895, 0.0720561157551504, 0.09973355478817418, 0.07681519183660708, 0.10799091774970294, 0.11554992262033686, 3.7988348785907995, 37.55352512482674, 82.17699696940761, 81.87695134070613, 74.76014014213317, 61.69794536405995, 66.20642354411464, 49.448202886889064, 30.027322423073556, 37.81044821585379, 69.918884154289, 59.71404190986388, 43.83428704354071, 46.221398384340354, 42.4738129492729, 20.8562659448193, 4.515292317636551, 0.4291182978739662, 0.3689886695675312, 0.5703876383842961, 1.7214352349119804, 4.751513138894112, 7.525394693497689, 6.005796415190543, 7.716787236352121, 15.009313264200765, 13.104188653730578, 12.589008865817902, 14.989781821927718, 14.581073791750017, 15.03014006922322, 13.96516263484955, 9.453545578064459, 8.9850478787576, 5.977518087433231, 8.506045091536738, 11.348523997491407, 5.561078085053352, 8.367907058808113, 16.315389967733815, 29.769228504550075, 48.14414816517984, 60.2812127144106, 69.77860450744629, 74.0542390269618, 70.12209430817636, 69.15855623060658, 69.9735463050104, 71.58988445035874, 71.6301279683267, 73.54951627792852, 73.94996673830094, 76.01780106944423, 71.26897965708088, 50.71658757425124, 41.32757086907664, 43.38429704789193, 53.10524432889877, 67.81538763353902, 52.67371300728091, 58.16067741763208, 52.3084109060226, 57.68427810361309, 51.75338375952936, 60.80924610937796, 64.24672503625193, 60.4023394277019, 67.66838504422095, 70.14525982641405, 75.89601932033416, 68.94038615688201, 67.61031827619, 59.66920921879431, 55.48288706810244, 46.72722331939205, 36.13034409861411, 26.65613155211172, 25.097767999095304, 19.812817419728926, 13.580127089254319, 13.220276101942986, 11.638991198232098, 9.779220954064401, 11.807617814310136, 14.817338739672016, 18.32122829652602, 13.28817625199595, 11.293154839546451, 11.807573687645698, 13.311364323862138, 12.775335177298516, 11.763534295943476, 6.88569926446484, 4.674108105321085, 4.613377557646844, 1.519705530616545, 0.3257495026674963, 0.023824361513458917, 0.15521097627858962, 1.2354429066181183, 9.227031642390836, 28.987986503108857, 38.554855239006784, 29.05037376188463, 31.32513273146845, 36.34468201668032, 27.53440122450552, 23.482188832375314, 30.540513569308867, 39.82100025300057, 58.77408904414023, 72.22401403611707, 67.69189573103382, 54.28753299097861, 20.83548915001654, 0.7674186496484665, 0.10536988581260366, 0.15800165072564157, 0.05666348647566573, 0.0321669019608488, 0.0910718352984517, 0.1509400207789675, 0.1526376103321391, 0.0436567499362413, 0.0283021301091198, 0.03609724710845659, 0.04793170058438855, 0.06957898577374798, 0.038430069107562304, 0.04815861199712081, 0.037504144598759954, 0.0015646132082873657, 0.013542774963312814, 0.046091637829498905, 0.032888388246177666, 0.03419874333626321, 0.02873447757484692, 0.04418566086960416, 0.050395289961729324, 0.061781053401289455, 0.04572587681093043, 0.061170377903768135, 0.015414278924224839, 0.06847319914208305, 0.04672573263486547, 0.0654798714564212, 0.016670199636850628, 0.20195033761762804, 0.21337165136731442, 0.24849255389023214, 0.42787377271921406, 0.18578143910534922, 0.2740755238600316, 0.21979208104312423, 0.09668270922115735, 0.1620855275541544, 0.1767102073157026, 0.1796796866842816, 0.2050931060746793, 0.12746063631869134, 0.2239022346874399, 0.11269689627712774, 0.1466298415776222, 0.1388799122744991, 0.27349314381999357, 0.1498810727629931, 0.29973131814791315, 0.2529139230929075, 0.3758340328931809, 0.18195950305990635, 0.4150147724055475, 0.18954280823949846, 0.20350450018961586, 0.2099039084127834, 0.2800754938394793, 0.3423014451419154, 5.247872904423745, 47.719229959672504, 93.87851761233424, 90.91260171705677, 84.76806763679751, 71.59942365461781, 73.2552129991593, 49.97523215509231, 34.348627059690415, 51.125577034488806, 86.96887816152265, 71.09778388853996, 54.38268184661866, 68.92430443917551, 55.124198082954656, 25.50631227031831, 5.003875984299568, 0.5862691313509019, 0.4238032717858592, 0.5181742723911039, 1.1764623489110702, 7.087625822713298, 10.525247916098564, 10.857679574720322, 13.793503046035768, 20.635422775822303, 19.51976929941485, 20.848050540493382, 23.706771981331613, 25.130211883975615, 25.94315448114949, 14.372925373815722, 21.10019814583563, 20.058732378867365, 22.33166744632106, 14.014580576650559, 23.41514768139009, 14.5690683972451, 19.510218328045262, 29.37640117060754, 38.86228276837257, 57.36702111459548, 65.34780886865431, 72.66410396945092, 73.46582858793198, 70.76573171923238, 71.07155107682752, 69.51471528699322, 72.23636165741952, 70.73284656770768, 73.20366521035471, 74.86903298285701, 77.39685150884813, 75.33913689274942, 55.66810531000937, 47.02398200188914, 50.31530557140228, 58.77174346677719, 74.27702965274935, 54.333730666868156, 60.335113925318566, 57.538573818822066, 64.2788923940351, 54.86055204945227, 61.3274068986216, 64.70206122244558, 58.91891079564249, 67.81291654033046, 71.27804817691927, 80.02314506038543, 70.96297202571746, 71.76390432542371, 60.918488041047134, 57.871214343655495, 50.53487593127836, 40.65124050263436, 31.4239784209959, 36.15168179235151, 30.8793318271637, 21.694515674344956, 23.574739117776197, 20.236315727233887, 13.641008157883922, 24.624683087871922, 37.54948508354926, 34.68767673738542, 22.2245769346914, 13.739083101672511, 13.9242866346913, 15.632553369768205, 19.618975846998154, 14.518798320524155, 10.504866300090667, 6.2461656332016, 4.40348074320824, 1.5291619973797954, 0.46849181575159876, 0.3909225329276054, 0.2237042622460473, 1.5870287245319736, 10.467880310550814, 33.29460382461548, 41.481735706329346, 34.601623858174975, 39.30887206908196, 52.85275743853662, 44.7947774394866, 30.414574107816144, 35.003435380997196, 45.582652168889204, 71.0463616155809, 83.59484749455606, 75.1522751777403, 64.0902538453379, 27.3118047560415, 1.428419229003691, 0.17345902209560718, 0.2056948834609601, 0.14322925389053362, 0.20288602208658574, 0.19936780925960312, 0.2972920022664532, 0.27883222506892297, 0.2000670177080939, 0.14190536202682605, 0.10876195460197427, 0.20321157881088797, 0.16851099808850598, 0.19758342194461054, 0.28844580114368473, 0.41381320946158906, 0.13346016196714294, 0.12377203787646948, 0.2413801169924198, 0.14332156748540942, 0.1230406154307627, 0.1590536733067805, 0.1368398354538987, 0.1739998801701492, 0.17110720877685856, 0.13993285416114715, 0.25804853547484646, 0.10227698201854384, 0.15576157899152848, 0.0928912558142216, 0.2162838733244327, 0.11171828024089338], [0.04575359770247052, 0.05459488437120473, 0.07681903759798697, 0.18086255708288762, 0.07353726248707503, 0.1119865642319764, 0.0691114423135596, 0.055928122507588524, 0.06721774957353069, 0.07717634866675062, 0.0736488125497295, 0.07729235736112441, 0.04889493357510336, 0.051856897621145176, 0.0483168934231564, 0.049305794189774224, 0.11188679660159735, 0.018469397346639348, 0.07636886135104202, 0.0984873902052641, 0.06580204207209811, 0.15208538351280076, 0.10309832020392341, 0.10947450830210602, 0.22518350141904048, 0.0149622046944475, 0.1770618723164643, 0.10710057802498342, 0.20704534325388171, 10.825118018734841, 54.97263377712619, 83.35816383361816, 70.82150782308271, 62.1444679844764, 47.0853082595333, 36.04955111780475, 23.95704273254641, 32.32950856608729, 66.13745258700463, 77.27775266093593, 66.6263524947628, 34.05076226880474, 36.271439598452666, 21.73458660802534, 5.856615439538033, 0.9123725972829327, 0.3549072074313318, 0.15521757995649693, 0.645800230483855, 0.8961032799655392, 1.9198589940224926, 6.798630491379769, 6.418982811512486, 9.505170833679939, 9.302117574599482, 7.880449602680822, 5.3252333210360625, 10.381815664229855, 5.966188321190496, 17.242809880164362, 23.894447588151504, 9.034709007509294, 10.491604766538067, 4.635435986903406, 22.203288270581155, 29.211298804129328, 20.985337418894616, 28.568898900862667, 38.78459630473968, 55.35660243803456, 67.76711110145816, 67.33230067837623, 67.53156492787024, 69.23870594270768, 66.12249266716742, 61.52156422215124, 64.16373945051625, 64.8135781288147, 69.97549180061587, 67.44490408128308, 73.74154767682477, 67.97298846706268, 75.02177792210733, 53.882560037797504, 49.202991993196555, 35.00863644384569, 28.432545546562444, 54.257448411756954, 49.66980895688457, 55.078828027171475, 45.8115852263666, 49.024320187107215, 57.27792447613132, 63.79734693035003, 60.82078180005474, 64.06341698861891, 70.76246046250867, 69.85421211488786, 67.86560181648501, 65.73964580412834, 66.05491807383876, 68.04416379620953, 65.6970606311675, 67.44746146663543, 58.71533193895894, 47.310056148036836, 36.390852235978656, 31.086774218466978, 24.315533638000492, 19.64558912861732, 13.683597253214929, 8.768184934892963, 13.758800856528746, 17.17621587937878, 17.680242407706476, 14.855472022487273, 10.278867175502162, 17.732202045379147, 12.74442199737795, 11.313046159282809, 7.146525604109611, 4.892378199485041, 3.1348908668564213, 3.242940397993211, 1.31508810385581, 0.15833641582679364, 0.17870629536769084, 0.2234707892902436, 0.16029933227166054, 1.5303819770774536, 8.174040480967491, 28.81842440174472, 46.87201369193293, 35.529684097536155, 40.10767059941446, 44.92840082414689, 25.774837732315067, 22.78016301893419, 24.570256279360866, 34.99025229484805, 54.00707567891767, 57.5463048104317, 51.9210611620257, 27.29619372275568, 4.178208727990428, 0.03450892850636475, 0.045015736287760164, 0.09132593134117704, 0.05073989163182917, 0.05644656484946609, 0.06221829808407253, 0.09487000729648337, 0.07539183877769016, 0.046756245916889566, 0.01735526418703939, 0.09988140975756031, 0.07457911908145874, 0.03819273889905984, 0.020523997279064312, 0.09250267303638882, 0.004009569651492301, 0.05651439044384226, 0.08451172481140784, 0.017860612171071193, 0.05086597055196763, 0.040314239374692404, 0.03926920734586255, 0.040904816555520224, 0.03326723404649285, 0.01038253395592854, 0.07911943109525789, 0.006030703032945073, 0.03819436300545931, 0.03432329774143235, 0.00880405383800427, 0.08266079509931226, 0.05273934280980499, 0.061208337560416236, 0.09837265321684462, 0.045083787878073996, 0.12270399639683387, 0.05410498646538585, 0.09647595741215254, 0.0686711715834756, 0.08023777390800177, 0.016107554021742077, 0.07114885314818352, 0.04201421146130851, 0.05104833012146335, 0.033611000680755225, 0.0455044467572964, 0.07450925952364361, 0.035861429923604575, 0.1014023011309966, 0.13849100007885887, 0.13588579551827523, 0.027784978625394648, 0.0968366699113, 0.049562000804730964, 0.052618542235464826, 0.0673386305871029, 0.06066052340752175, 0.15982170709438864, 0.06458387034194124, 0.288587098400439, 14.369527620653953, 66.7119150777017, 88.47736681661299, 80.43759838227304, 69.47191438367291, 59.61523740522323, 47.190498382814475, 33.51678648302632, 31.869241960587043, 57.65098502559047, 78.88841121427475, 63.449444463176114, 38.85330446304814, 36.54436203741258, 22.37038516229199, 5.122127600254552, 0.815612382946476, 0.39051908038316235, 0.2277971482685497, 1.8186493410218147, 4.801719477099757, 8.81497783045615, 13.25448799517847, 11.51028254339772, 10.759858604400389, 14.372661594421634, 14.038613919288883, 13.183402880545586, 15.168230052917236, 15.162927989036808, 20.66873742688087, 20.44636453351667, 13.771514238849765, 6.060132518891366, 5.880932663717578, 8.496298001658532, 11.910888917984503, 13.280751205259754, 23.716730879199122, 40.04210033724385, 57.5826887161501, 68.79190091163882, 68.8958437212052, 70.02303092710434, 68.9536359233241, 68.2425102110832, 65.41148854840186, 67.62933392678538, 67.38238150073637, 70.80072710590979, 68.96439890707694, 75.59620903384301, 68.49406749971452, 77.08521135391729, 56.465605535814845, 54.48538518721058, 39.66578814291185, 35.6591615369243, 61.09462207363498, 58.58735676734679, 60.065341149607015, 49.16628253075385, 55.513159921092374, 62.54589511502174, 67.15379361183413, 63.187583108102125, 65.59131745369204, 71.34319874548143, 72.27779757591986, 70.91640564703172, 67.5254774093628, 68.23336324384137, 69.27866705002324, 67.23811672579858, 66.28792255155503, 60.75663535825668, 47.52191120578397, 36.0857859734566, 27.367667152035622, 22.645576692396595, 18.14834002525576, 16.449843914278095, 9.620411049935127, 11.051569196485705, 10.118268670574313, 20.855834484100342, 12.63676372266585, 11.753540096744416, 14.052384380371342, 12.605310236254047, 8.568615721118066, 12.82334989117038, 9.674521127054769, 5.214365566930463, 6.873145718728343, 4.585629730455337, 1.3393321513168275, 0.5238173986154219, 0.2521117677491519, 0.14316853376165514, 1.848373920206101, 8.402106204340535, 26.02845818765702, 37.53406232403171, 39.639002277005105, 40.67644957573184, 38.27901063426849, 25.90299333295515, 27.93236097981853, 29.03931856155396, 41.45576961578862, 61.638046849158506, 65.27594320235714, 61.6493393528846, 33.67131217833489, 4.8153938401129945, 0.021986914948830684, 0.06087087199933106, 0.08359624974189267, 0.013305583608246619, 0.06322402980238681, 0.04422386950482765, 0.021912031769452077, 0.03661331457776889, 0.02566982135777512, 0.05108509851138919, 0.08413752916479304, 0.04605161739633449, 0.05903505720198155, 0.04703672219728751, 0.003978538781314368, 0.059372120566906474, 0.03645618611405935, 0.020924948546434605, 0.06960187648092547, 0.028846810962403976, 0.058427266025495146, 0.10419864462868822, 0.023863418591058543, 0.031024216704310912, 0.051288747664300666, 0.02668428647842619, 0.05205577787672801, 0.05791699018089041, 0.020750477767339157, 0.051045530070100105, 0.02683445311812384, 0.1378902492503966, 0.16844490002239906, 0.22179160116901322, 0.2494831055763268, 0.25617592547449375, 0.16568177409710425, 0.20130279413875074, 0.2159345525527193, 0.17735004395006165, 0.18239618849850472, 0.1366438088758338, 0.10988068811955953, 0.2064772124492353, 0.09217244317574848, 0.20336589956235504, 0.1799648399314573, 0.19911683885560882, 0.21002683488111343, 0.2668519582479231, 0.18498311420121502, 0.2331392325821423, 0.2865881298578555, 0.24376808966119445, 0.19855872848101203, 0.35567565490641906, 0.13741276196895108, 0.4747859328504532, 0.3006472222266659, 0.5744736449372384, 20.786490901823967, 78.09635916063863, 101.58856376524895, 90.18785753557759, 79.05254671650549, 63.172270174949404, 49.25511244804629, 33.528745789681714, 46.206850313371234, 80.29625185074346, 85.07606783220845, 74.10107212681925, 46.84968363854193, 48.71809682538433, 27.079720074130645, 7.927114040620866, 1.4190904844191767, 0.6150930362843698, 0.13949442204208146, 1.2520968000735007, 5.177986073878504, 12.087314186557649, 19.57095426897849, 16.95387044260579, 22.658575427147653, 20.92816887363311, 20.12836621653649, 15.50011257971487, 21.10205734929731, 13.626901353559187, 26.9421370567814, 35.38539186600716, 19.53291512304737, 21.36477574225395, 11.807591338311473, 32.575964812309515, 38.865777600196104, 26.437243684645622, 32.295582025281846, 45.58859455970026, 60.750865551733206, 71.26664192445817, 72.14143245450913, 70.67098294534992, 72.6609346943517, 70.78744596050632, 68.15703392028809, 69.34742619914394, 68.19089966435587, 71.75066240372198, 69.7821189511207, 76.12683511549427, 68.90776772652903, 79.13919971835229, 60.92946283278927, 57.66104590508246, 47.83562237216581, 40.4445041379621, 70.71042629980272, 58.81985918168099, 61.91620957466864, 56.70068102498209, 62.028146174646196, 63.648312553282715, 66.62591318930349, 61.754090170706476, 65.33558676319738, 74.91679176207512, 76.07813496743479, 71.81882535257648, 70.11320621736589, 71.22512755855438, 72.44023861423616, 69.31852617571431, 69.18185510943013, 62.439187034483886, 51.068294740492306, 44.14219702443769, 37.92408320211595, 30.461568024850664, 24.71533298492432, 20.27474711018224, 14.580042208394698, 24.41733483345278, 25.148329311801543, 24.135557643828857, 23.6287344655683, 15.827796209243038, 30.012344852570568, 24.01663334138932, 21.043827802904193, 19.05308177394252, 15.05954803959016, 9.827149375792473, 10.536057968293468, 5.419896783367281, 0.5179958045482635, 0.6217179807924456, 0.6166801866023772, 0.4190011875283334, 2.2210099956681653, 10.450035487451862, 37.22864304819415, 55.97527396294379, 49.11868849108296, 57.734719784029075, 60.193539896318995, 36.19225871178412, 33.125330017459014, 37.889150573361306, 49.52592857422368, 72.20093481002316, 74.02687657263972, 75.07656558867424, 40.59997512448219, 8.458027435887246, 0.203428749415663, 0.17824376212252727, 0.22152065119195372, 0.12253236205827807, 0.27296840423537844, 0.3835410612725443, 0.19157151631530256, 0.11640537470098465, 0.19225526510948138, 0.22515062092533036, 0.3290765918791294, 0.16437387814925564, 0.17145619246988528, 0.302708397108701, 0.2671284853450714, 0.1755475463165391, 0.15066778377419518, 0.24463861069131285, 0.17989768466401487, 0.22642627989332523, 0.17875414521944138, 0.21258045108087603, 0.11796710622166434, 0.10099596809595825, 0.19008967244336683, 0.22619075382188444, 0.2486113281620126, 0.15284506694203423, 0.26025113018770374, 0.198222829569732, 0.18672570375905884], [0.10196741354922134, 0.059634252871957526, 0.024599834014811826, 0.08148965350682698, 0.096679353756049, 0.031186525837608406, 0.06999045925875826, 0.044995182148751714, 0.020646536872992595, 0.01663502087936767, 0.03468756488854847, 0.02147427955341916, 0.0217220917599456, 0.05924998699957806, 0.09023339803060217, 0.050261201592342514, 0.07915361393843928, 0.13259477372611725, 0.06507844904497748, 0.08042765646091393, 0.13853912572226218, 0.12007092921844414, 0.053913146557827155, 0.012508757363614297, 0.07505442301232008, 0.04866481991484762, 0.03186736924333438, 0.016014602658669316, 0.22852482454430675, 28.69539337773477, 75.70365844234344, 71.89239332752844, 62.153618874088416, 48.54494379412744, 37.03115563238821, 26.23694589061122, 24.15667372365152, 58.04827013323384, 64.87718720589915, 74.10685370045324, 54.30876478072136, 36.25032547981509, 26.81284396879135, 8.301560167343386, 1.5602085378862198, 0.056229941997556925, 0.07381274770464628, 0.5303615668127614, 1.6701524512421702, 6.888422860253242, 7.614432006112992, 9.012104388206236, 6.921916959747192, 6.6514004045917146, 17.585217106726862, 14.402678512757825, 14.47431177862229, 16.8451266519485, 26.69209968659186, 14.71503253906004, 18.17605745407843, 12.565026513991818, 9.621038629162697, 14.48720657056378, 23.922827897533296, 29.36583822773349, 36.028837080924745, 49.242933488661244, 63.5569840861905, 69.46667409712269, 69.58560820548766, 66.78038397142964, 67.39575678302397, 60.00930616932531, 60.43048635605843, 60.92460693851594, 64.26008462905884, 66.12792122748591, 68.74561694360548, 65.56750082200574, 70.75864791870117, 71.35112977796986, 69.48947875730454, 67.43170138328307, 62.80561877835182, 41.39813430847661, 23.128822503551362, 46.20776422562138, 43.32006039157991, 51.09681037164504, 43.57218250151604, 56.52304080224807, 66.00636697584584, 63.55452868246264, 60.492393124488096, 63.4758145578446, 65.1589467448573, 62.39262850053849, 61.237733671742106, 63.376358939755356, 63.399147910456506, 66.31163720161685, 65.21697036681637, 63.08135355672529, 64.08781020872055, 63.394939207261615, 57.444476158388206, 48.43938496805007, 38.30536503945628, 32.268894218629406, 28.118018527184766, 23.905267446271836, 16.394357085227966, 17.108078425930394, 39.697316154356926, 14.07265518942187, 13.72576371315987, 9.771433088087267, 11.195991846822924, 7.189133330698937, 12.347187880546818, 9.024936422224968, 5.232313842542711, 7.568645688795275, 3.20607306015107, 2.073149387874911, 0.4510382184338185, 0.06479266760570389, 0.07279562808933758, 0.3043692144415071, 1.0523241133459154, 8.38835241333131, 29.841366775574226, 37.74263043557444, 37.619342496318204, 34.05853248411609, 30.92299565192192, 21.33760548407032, 27.062661686251243, 42.33262331255021, 50.056048670122706, 53.47894422469601, 62.54750328679239, 48.31644219736899, 18.510180634837, 1.112083506680304, 0.04606755968603877, 0.09524611816290887, 0.023702927001361406, 0.04539366278256621, 0.07984642555276233, 0.1560296637997512, 0.09041807118562922, 0.05541705376198215, 0.03544198146330253, 0.12910407877737476, 0.03684105336545937, 0.10040019683900381, 0.03140309314814306, 0.014485696090325234, 0.04698937030268773, 0.0576802613514085, 0.08241308822987542, 0.056932368015329686, 0.02407462520134305, 0.03984357793665221, 0.06749321180846422, 0.047577580271829525, 0.0431504002922485, 0.00252189944148995, 0.0032539230268148166, 0.050193713076653025, 0.06385581868310129, 0.03560581702678915, 0.027855410833933184, 0.06230947786882039, 0.051124605665644335, 0.0983460546441136, 0.03889139576424514, 0.018184012357866573, 0.15885113498135922, 0.05626311743511789, 0.039175434353490995, 0.10361932127946809, 0.04792055400509027, 0.06886820173672131, 0.02141025183992761, 0.0320758045305528, 0.03750304526258861, 0.06942579883240885, 0.03664944711471758, 0.1079474039556038, 0.03750397988985624, 0.0918585999358085, 0.0744611492019988, 0.06371184777949127, 0.03542400904059891, 0.016804977485369292, 0.025983036405617194, 0.1260838154402952, 0.11283021855859027, 0.04400582172937932, 0.07529672896189075, 0.10062433118301053, 0.9919494594777785, 37.13333729774722, 85.37217540125694, 82.64347660926082, 70.95441341400146, 59.19910138653171, 45.95837208532518, 38.1103487168589, 26.159098609801262, 43.0526763393033, 67.45012083361226, 72.20663009151336, 60.90901551708099, 31.485288989159372, 24.35509466355847, 6.998025159681998, 1.5388599350567789, 0.06797241512686014, 0.23116272573749866, 2.163811787482231, 6.264053602372447, 8.700331853282067, 9.420950681932512, 14.897186429269853, 13.734147779403196, 13.074267833463608, 15.65761241220659, 12.478905973895905, 16.8580194827049, 13.826767686874637, 14.166658712971596, 12.079815595380722, 13.07920805869564, 14.249105953401136, 11.097443276836026, 12.059806604539196, 21.92289567762806, 24.309204893727458, 36.615294179608746, 50.31773744090911, 64.98969254955169, 71.52541637420654, 71.85054948253017, 68.15867347102012, 68.76471888634467, 64.4012938776324, 63.429475676628854, 62.67446256452992, 67.50208439365511, 67.82400900317778, 71.36904716491699, 66.99613002038771, 73.13454520317816, 69.98897690926829, 69.75647449493408, 69.15832088839623, 68.52232425443589, 43.40094358690324, 30.65671966921899, 52.57366511129564, 50.829806789275146, 57.80946054766255, 48.3414629966982, 61.59503413784889, 70.05120138968192, 66.3910573528659, 59.7231339639233, 66.39403050945651, 68.2075854270689, 66.75205661404517, 63.04382431891657, 64.27921010601905, 65.73087538442304, 68.94626186740014, 67.94930519596224, 65.67040028110628, 65.44539351617136, 65.30240743390976, 59.17488467308783, 48.507343953655614, 39.11010596059984, 28.49507008829425, 25.853906831433697, 23.79401137751918, 15.415509016283098, 12.351839811571184, 7.750057270449977, 10.53532938803396, 13.723164162328167, 11.524105956477504, 12.404198550408887, 13.66255569842554, 13.287732043573934, 15.10518873891523, 10.2344512362634, 7.605033516883851, 5.533215038238033, 5.167085316873366, 1.6160498511406685, 0.22185665735554314, 0.0352517273577471, 0.13228536613525885, 1.0817537793228704, 8.083963249960254, 27.399110832521995, 37.365659283053496, 35.63886719365274, 39.208667278289795, 35.494602418714955, 29.176476001739506, 36.251710076485914, 48.55542828959804, 57.88234995257471, 62.358284227309696, 72.49182562674247, 58.9422449757976, 22.479219167463242, 1.7320153381555312, 0.06447724622463988, 0.044326360577777515, 0.08886785396645147, 0.03763319594004462, 0.0902513168271511, 0.13708740442750916, 0.08502661250531675, 0.030666373204439882, 0.042328537336640784, 0.04590506860685926, 0.026446992659100124, 0.08795895193132662, 0.046381686378510735, 0.05122566798461541, 0.021731650622020808, 0.016005995660840024, 0.060369808362015796, 0.04102418837588161, 0.021926436137648362, 0.018860944884739096, 0.03548978918021725, 0.01186084999297295, 0.007387010949558669, 0.019307926545039784, 0.047389501855979045, 0.03803359945454905, 0.04500716376388746, 0.05237822428405766, 0.030057151358754888, 0.0963734548478838, 0.11117117854976848, 0.1950669456874171, 0.18285021816770877, 0.16285494030002626, 0.2993217369000758, 0.1291611216842167, 0.16410651346368177, 0.20276049091931314, 0.14556614381651725, 0.16791911855820688, 0.11442968757042002, 0.08701616582731087, 0.19872757425952345, 0.2565863187755308, 0.16151681452268557, 0.26440841356112116, 0.1296461013055617, 0.14566748192714107, 0.18929880923561512, 0.16626211634326368, 0.2880987326704687, 0.5138687663260968, 0.15413102213173144, 0.27413230629697927, 0.16821841378846478, 0.21841460898999246, 0.16071539462333725, 0.17057827103041834, 2.4768142306035568, 49.45228999660861, 96.4854189657396, 91.31352286184989, 80.37391478015532, 66.96917549256356, 52.36173945088541, 38.6705377024989, 36.91299423094719, 72.33084371013027, 74.23112223225256, 80.90110486553561, 63.494206551582586, 48.68169330781507, 34.29971902601181, 10.621444044574615, 2.206756102461969, 0.13378889029545168, 0.20687111953814186, 1.787891830167463, 5.1573151830703985, 16.449548755922628, 15.94855716151576, 19.23266553109692, 16.203614184933326, 15.409735287389449, 25.125822751752793, 26.0649166184087, 26.71610066967626, 27.90821094666758, 39.56286514959028, 23.583750763247092, 27.288790249055435, 22.291282723026892, 14.705493334800968, 22.083942313348096, 28.854782812057007, 32.69686010576064, 40.262910166094386, 53.46152497876076, 65.99635708716609, 72.0135788763723, 73.3888481509301, 70.33795018349925, 71.03421011278706, 65.06242898202711, 64.53012412594211, 65.73631963422223, 67.77476756803452, 68.32608807471492, 73.36794191791166, 69.67099035939863, 74.32641229321881, 72.60511152205929, 74.73587636024722, 73.06805318401706, 68.62279968876993, 49.14914177310083, 35.94673010610765, 60.20411852867373, 54.107657017246375, 61.61019409856489, 56.652102470397956, 68.43016424486714, 70.93266779376616, 64.83545710963588, 60.29101863984139, 68.02814483642578, 70.8589429240073, 67.95999757705196, 65.55147009511148, 68.30973179109635, 68.50442255696943, 72.77085519606068, 71.1491120246149, 66.57612262233611, 68.01847227158086, 65.6850189547385, 62.15157924159881, 53.711109315195394, 44.54709153021536, 35.820033627171675, 32.878720798800074, 29.002365912160567, 20.375151941853186, 24.307073085538804, 50.760886822977376, 23.251202414112708, 20.73796529923716, 20.102388358885243, 21.18754932957311, 16.252602627200467, 23.428148377326227, 20.232142325370543, 19.70130443572998, 19.477813666866673, 10.361516417995578, 6.436026980800014, 1.6285775337488422, 0.4518545617259318, 0.17797887956182804, 0.4856500402092934, 1.4979214221239092, 10.77781423445671, 38.159048864918375, 48.56912912860994, 50.94545002906553, 47.76596107790547, 42.62715016641925, 30.351533774406683, 39.78124310893398, 57.667451135573856, 67.6374218540807, 71.62855902025777, 80.51778731807586, 71.63546239176105, 28.455071718462055, 2.639081704039728, 0.30105432134962856, 0.24396275260275413, 0.1803118317958809, 0.24917215048786134, 0.16182534877331028, 0.31148083928611975, 0.13581753708422184, 0.09756769399128615, 0.12275836565682005, 0.25613303987249253, 0.16548541044035267, 0.17680779159549745, 0.15066307999434012, 0.10745790441550555, 0.19069485126003144, 0.10508582041028047, 0.12706031707385856, 0.1382012809476545, 0.14272892186718603, 0.10956307572703208, 0.1452009956682882, 0.07772174198180437, 0.13231876756875746, 0.10985366053759091, 0.0861156371331984, 0.12468842459061455, 0.18922226173022103, 0.20619555256299435, 0.10631693902635768, 0.18989027507843512], [0.044695266387275154, 0.07933334582635472, 0.07055410844904762, 0.037552772029753656, 0.09604741548818928, 0.05990606469793185, 0.06223255498034339, 0.0898225527376898, 0.09852713484677578, 0.022033299657426054, 0.0364799999571856, 0.051871269430604675, 0.01875083123694264, 0.014975761577877549, 0.042187240079886494, 0.049394338632062565, 0.016429148156255964, 0.02960407738423636, 0.05402981025737621, 0.10011734185560096, 0.03441336286825038, 0.11043199563338874, 0.05646507353371671, 0.014691147465078581, 0.0534653834878437, 0.02347991306094393, 0.06156623468644196, 0.043793010164893446, 13.202900002079627, 50.60889105642996, 79.21596050262451, 62.13626630844609, 56.9308025606217, 35.95901889185752, 31.017059972209317, 23.412213748501195, 54.82057917502619, 69.46861174798781, 81.933103992093, 57.359097926847404, 26.24526719893179, 36.090202562270626, 9.661179184913635, 2.4763459976642364, 0.09484445060332937, 0.20795213088633555, 0.36547793375868953, 0.9610162386971136, 6.933112384811525, 5.448587450288958, 8.646455157187678, 15.102543100234001, 13.41710848193015, 10.585286655733663, 10.651304068103915, 13.392969235297173, 13.825041843998818, 14.423870098206306, 12.717705753541763, 30.267324409177228, 27.349167293117894, 31.161720906534505, 27.08460342499518, 36.547550924362675, 45.75453827458043, 51.68471482492263, 59.65797555062079, 66.32293362771311, 67.13790801263625, 63.59510952426542, 66.61673484310028, 64.11148171271047, 62.313596663936494, 59.47717781989806, 58.13438184799687, 64.65782865401238, 69.82986988559847, 69.26756674243559, 67.14845134365943, 64.19336511242774, 65.68630156978485, 69.29645892112487, 66.1421751206921, 68.5500083431121, 65.5173650864632, 53.51725401416902, 25.02808120942885, 48.18339147875386, 43.102023678441206, 40.049027242968165, 47.906550591991795, 58.422189681760734, 67.18564325763334, 69.11530033234628, 64.34320357538039, 66.21979098166189, 66.06645768688571, 60.996841307609316, 55.57782411575318, 59.72852722291024, 62.06543222550423, 67.10000222729099, 64.51960432913997, 65.94402482432704, 64.12069143787508, 65.7099848408853, 63.912950946438706, 63.451103625759, 54.872660406174205, 47.23444069585493, 40.82609976491621, 34.733729285578576, 28.549885211452363, 20.949033921764745, 31.637231803709465, 19.539981272912797, 20.346689262697776, 12.17895350148601, 8.524276268097664, 6.2700165856269106, 11.710398927811655, 8.999953866004944, 2.0048487883421684, 2.9841230473210736, 3.4842453464385006, 6.182005463107941, 1.040529546237761, 1.0123158763012579, 0.004785540588800946, 0.022426367880055503, 0.03736768518724749, 0.7370415474137952, 7.7616856271220795, 37.73514263091549, 46.97575646062052, 42.43879010600429, 35.404909579984604, 20.16531494355971, 13.647970364939782, 23.493346014330466, 38.58994476256832, 41.78558603409798, 59.37041874854796, 56.99231316966396, 37.97918073592648, 7.96802043914795, 0.052537945955390894, 0.08542936790974871, 0.020949637645014355, 0.03191518653634816, 0.03798847687580893, 0.049442575358214884, 0.04367830765043055, 0.05328692713632219, 0.0396885677060533, 0.01818745209264659, 0.020203987031333873, 0.07183557436350854, 0.03335552184932655, 0.07078878416289246, 0.044923928310914386, 0.052379028676378156, 0.02558216174703933, 0.03965448828474168, 0.02788104605109942, 0.012074368273568972, 0.15595555245395631, 0.046233586260988835, 0.06787580377872914, 0.06483411296240746, 0.017069051823308392, 0.01563490745836809, 0.10057255896108766, 0.04943422499984022, 0.050878817846457806, 0.08002832546950349, 0.04133081506757487, 0.013433702237483476, 0.014431667739465354, 0.02249461099235041, 0.03570035610708498, 0.04537764771450912, 0.08378197243737598, 0.04043020976466998, 0.021093288706915996, 0.10048496446782544, 0.029234250354009773, 0.03949056079070415, 0.08766209286066794, 0.060193550682836966, 0.06736331394002323, 0.06497601542862193, 0.054145290351082245, 0.019700144410073277, 0.08368438815758114, 0.029434277826259216, 0.03169703150859043, 0.096888825177185, 0.03646793024193856, 0.020059230887601455, 0.02900270410933562, 0.08282744986636024, 0.03799438724414476, 0.0420594183097203, 16.648005977753673, 62.355562102410104, 85.91799674495574, 70.92269712878813, 63.20433162873792, 47.15143157589821, 41.035566099228404, 30.49422960127554, 42.18720143841159, 70.71766699514082, 78.94267328323858, 72.97856823090585, 31.344348422942627, 26.76035284996033, 9.324242684148974, 1.9628215725383453, 0.0662853209782512, 0.55247497053877, 1.1806079264610045, 5.117219734576441, 6.736581537031359, 11.50286534140187, 11.186738975586431, 13.121778522768329, 15.981719820730149, 16.661449901519283, 16.310055544299466, 16.12908522928915, 17.92422167716488, 14.196490299317146, 9.51347743311236, 15.052222032700817, 17.63950663228189, 25.61636613261315, 25.702846550172378, 33.577508695663944, 43.53684194626347, 48.59228287973712, 59.31759618943738, 67.51490269937824, 69.77938898148076, 65.0653080017336, 68.27909023531022, 66.22172863252702, 63.4084439277649, 60.15428873800463, 61.496472820158935, 65.88312610503166, 71.54483210655951, 71.47978351962182, 69.48926694931524, 65.86570293672624, 66.27690069137081, 68.87314888738817, 66.55625189504316, 68.27060222625732, 68.88373144211309, 54.8729153602354, 34.23388988740983, 52.8012724076548, 48.0885995587995, 45.23081948680263, 53.071021649145315, 62.93079730003112, 68.02659157783755, 68.95786423836985, 63.2380836240707, 68.79817670391452, 67.90363311767578, 62.34923531932216, 59.10563522769559, 62.420453794540904, 63.0869350894805, 67.52972925862959, 66.3555363685854, 67.66191313343664, 65.31423730234947, 69.63622247019123, 67.01876994102233, 63.39841050486412, 55.691761124518614, 46.623100080797755, 36.50370667057653, 33.505784234692975, 28.431947385111165, 22.934282748929917, 24.539114621377763, 16.559578103403894, 12.706708408171131, 11.189187515166498, 9.278478430163476, 12.719493373747795, 10.248602167252573, 15.299545122731118, 11.489292960013113, 12.33773987139425, 9.302285255924348, 10.60167137653597, 5.622764710457095, 1.5797581211213143, 0.6400382074136889, 0.08084983985510566, 0.053093865318524266, 0.9677359329596643, 6.903649501262173, 32.014006837721794, 43.704864517334975, 32.946838640397594, 30.108962635840143, 23.24533650952001, 21.866848930235832, 35.81441287071475, 47.57810700324274, 50.874345302581794, 67.34907273323306, 66.6672549709197, 46.727450816862046, 9.875826970223459, 0.1571787190773795, 0.02516251793431659, 0.03067503191320406, 0.03852612504194822, 0.033203288687453154, 0.07965329478705123, 0.05204547782458606, 0.06212305803332598, 0.07952924216947249, 0.08398043517504009, 0.03806953280863743, 0.10994641080258355, 0.013253413978213025, 0.047828328510325764, 0.047934416366080125, 0.038678105394806594, 0.04217745330665381, 0.037099516109353116, 0.0034868767186473576, 0.04948376790590344, 0.041303094176034776, 0.07035836532351471, 0.03781202384420941, 0.03919908731815316, 0.040728888294148835, 0.023377345379201636, 0.07278308723001711, 0.039136597526169596, 0.03304580782329844, 0.06483538466836176, 0.1564077588339006, 0.21009483284527258, 0.24658704807441084, 0.2001958583751994, 0.15518836136306488, 0.21614082938721105, 0.16211669201091414, 0.1551750161114239, 0.16303972070736272, 0.2373410256639604, 0.1399449430285923, 0.0697363249116367, 0.16858356193669383, 0.17269693315029147, 0.12765845554249902, 0.17679599384146352, 0.10888504960964765, 0.08169350184259877, 0.16632951675884186, 0.2797158308807881, 0.13186224045292025, 0.2173726221606616, 0.16551271381397403, 0.18268448270616994, 0.19426353395946566, 0.19332588830542183, 0.16454975661491195, 0.17302777588127122, 23.831113076979115, 77.4762559706165, 95.9179461386896, 81.8817444770567, 74.77182096050632, 54.284548067277484, 45.52578564613096, 34.867603701929895, 70.18629566315683, 80.37310677189981, 87.97755487503545, 66.4489201576479, 37.13171343649588, 44.257522552244126, 12.52588616263482, 3.382322312362733, 0.17872547820931484, 0.525101239402448, 0.9757201625935494, 5.4427323322142325, 13.96834759942947, 19.284895812311483, 19.019435682604392, 26.900824692941484, 25.13845866726291, 20.322245051783902, 21.06263556788045, 23.14601032964645, 24.534294028435987, 29.6850367899864, 27.658663872749578, 44.007608736715014, 32.95135721083611, 38.537220262712054, 30.51694012457325, 38.75736721100346, 48.993333462745916, 53.90294067321285, 62.441779721167784, 69.27320711074337, 71.23132490342664, 68.50548159691596, 70.38628162876253, 70.97075400813934, 67.62949082159227, 63.68110356792327, 62.898296540783306, 69.48583879778462, 75.65361684368503, 73.77331887522053, 69.50929457141508, 66.82726413972917, 69.28825332272437, 72.61436047092562, 69.14203520744078, 71.88113612513389, 68.97329484262775, 59.044607070184526, 39.490885734558105, 60.95275778924266, 52.89557010896745, 52.341778509078495, 59.610220693772845, 66.59745247133317, 66.12746623254591, 69.94453645521595, 64.98374623637046, 70.42208502369543, 72.8066978146953, 67.57919819124284, 60.79104238940824, 64.57792605123213, 67.03100773595995, 72.11818064412763, 69.61817956739857, 70.69873763668922, 69.18530679518177, 71.2174867814587, 70.77658883986935, 67.68466288043608, 60.214383371414684, 49.97062729251001, 44.13945921005742, 39.99728333565497, 35.406258875323886, 29.702873768345004, 41.51018073481899, 27.42680080475346, 27.13972645421182, 20.12437520488616, 21.55040583302898, 22.804669987770822, 23.854249177440522, 23.62272147209414, 13.357756157075206, 15.007476614367578, 11.621482718375422, 18.0962372210718, 4.507401489442395, 2.425319393796306, 0.8770437478538483, 0.14495195580586312, 0.20289516917640166, 1.1850894795310114, 8.968579807589132, 46.35007566021335, 58.81231646383963, 54.03778391499674, 48.442126704800515, 30.69752996967685, 23.50234197032067, 35.53598342403289, 52.89025921975413, 59.247440676535334, 76.86653137207031, 76.81625443120157, 55.63780500042824, 14.116566123500949, 0.42778168895071556, 0.20835619630111804, 0.17006612593127837, 0.163210297844583, 0.12830199238153236, 0.18357277697613164, 0.14203930483950725, 0.18187005463386738, 0.15798847401334395, 0.24758763551231355, 0.17572006931708706, 0.1668642920952651, 0.07764032215721185, 0.2360949836551182, 0.18054086144172377, 0.16354403638791654, 0.16104164082677136, 0.19804986223818796, 0.07746490334431011, 0.14965909112605358, 0.2194422393316223, 0.24249511200093457, 0.15435968405537068, 0.1655685156583786, 0.0852029123193314, 0.163085731948095, 0.1909201730403208, 0.21926872041677276, 0.20453156362618172, 0.20039796769138307], [0.029007764120075493, 0.022139395174059658, 0.058087544335472974, 0.041232257856116186, 0.06582661051182978, 0.01697631304963462, 0.08098539145242784, 0.07756911428464998, 0.04225578579691149, 0.08400507256268494, 0.03699217953028218, 0.06327086075719807, 0.05094324967132942, 0.01272854703148046, 0.029646039850288824, 0.04055974757178657, 0.018190598798795574, 0.1103064951096331, 0.06701951666224389, 0.08275428846959146, 0.0022673971327622573, 0.02357687872473992, 0.08331973796650287, 0.13044379801759798, 0.0772300361084842, 0.014932194157623717, 0.045194613987640034, 1.3890831268602803, 30.780937210206066, 65.76693373341715, 65.71431121518536, 61.84949398040772, 46.28667054637786, 37.82497275260187, 22.676547727277203, 46.67980578637893, 79.54667122133317, 71.37167515293245, 59.28096517439812, 22.142515067131292, 36.58760616856237, 13.185481736736914, 2.8640654250498745, 0.031096859076510996, 0.06327965927700843, 0.11256867614124091, 0.8687193138945488, 4.236403463348266, 6.965653838649874, 7.306334732040283, 6.952477616648521, 13.74899983406067, 14.362598753744557, 17.797515392303467, 11.790097567342944, 9.221907065760705, 22.439877794634913, 12.317003280885759, 4.810955187966747, 23.539643710659398, 35.335467938453924, 49.12051631558327, 52.65282246374315, 53.92954611009168, 61.980901225920654, 60.42313975672568, 60.98588612771804, 64.67437321139921, 67.93716938264909, 64.76381109606835, 64.01923148862778, 57.2928177156756, 59.00273184622488, 57.00136600002166, 61.160863061105054, 66.77175475705054, 69.1547279973184, 68.21881909524241, 67.88786518958308, 64.88155280390095, 65.29730835268575, 68.58642362779187, 69.6537946885632, 66.81179431176955, 68.49325164671868, 61.31670275042134, 31.219285611183416, 42.54312123021772, 41.54841992162889, 40.20332544080673, 51.66939404702956, 62.91132665449574, 65.31466091832807, 64.5447624114252, 64.3433447807066, 64.83982270763767, 62.49486507907991, 55.10119338189402, 46.85156245385447, 53.01237044795867, 57.08159023715604, 59.42538684414279, 57.7383009079964, 58.973114029053725, 57.28160758172312, 64.2852819350458, 62.47379410651423, 64.97962774768953, 63.956740287042436, 58.373611127176595, 53.09429307137766, 55.033991413731734, 46.791507044146144, 37.37390802752587, 25.026339677072343, 29.821515660132135, 26.242266585749967, 18.02534430257736, 13.509390084974228, 18.404115823007402, 8.463811951298869, 10.589969965719408, 10.105775921575486, 7.165802092321458, 7.782474679331626, 5.506542430770013, 3.6333964140184465, 0.8234870313636719, 0.3143099407034536, 0.29545213486398425, 0.01823917068841477, 0.030711294685099876, 0.9448685761420959, 9.907624644617881, 34.33311016328874, 55.84270177348968, 46.73032591419835, 41.099249701346125, 27.939417323758526, 20.00309944152832, 26.434084215471824, 39.53940545358966, 56.68987881752753, 58.893835083130874, 50.55884945777155, 15.896278831266589, 3.1799162443607085, 0.10913233513072615, 0.14389411095649968, 0.019054722994746223, 0.06613123005316143, 0.02995035295645076, 0.03375146290167205, 0.06983207058041327, 0.05355690418171787, 0.0962408526890701, 0.027735858982909593, 0.1039086497058311, 0.08336175788914965, 0.0503243770330183, 0.05393045631447627, 0.08103652016049431, 0.02433031279173109, 0.03380970473611548, 0.04118950248906209, 0.12973194911835656, 0.033401218994009885, 0.04027288211810012, 0.013552195929561653, 0.0846884536346601, 0.06284729840474264, 0.034569116204135844, 0.04751193036715831, 0.05566898560632141, 0.018671071907925992, 0.07650223725865926, 0.03806955962171478, 0.06507107927914589, 0.0493016917889397, 0.08985329584609117, 0.030721472163173943, 0.054473903766202356, 0.03782744136368556, 0.061620102158837745, 0.061881767150254986, 0.017072876517270363, 0.004558099617791032, 0.02091037563889498, 0.0919229589823273, 0.045793545357282125, 0.06593098999151299, 0.019490586804045786, 0.022426258712526292, 0.0502551150237841, 0.08793039983438869, 0.08700806827795121, 0.06282999247853314, 0.07839380027425867, 0.08415341782834261, 0.03744494132397156, 0.0022892687035979886, 0.04187784781078658, 0.0898850884949488, 2.0920583990312394, 40.497067820641306, 76.1072781778151, 76.94333922478461, 71.13093576123639, 59.79285801610639, 47.70536830348354, 30.6940802451103, 34.403697136909734, 69.20796240529707, 72.66811263176703, 69.34674370673396, 29.696727414284986, 25.058877698836792, 12.163836686841904, 1.7547953609497318, 0.12033907531370079, 0.2789045131254581, 0.8645380672908599, 3.98233340632531, 9.70055683966606, 12.102820296441356, 12.691444504645563, 12.445992385187457, 12.284153430692612, 13.505688348124105, 15.947756998000608, 18.518856917658162, 14.385061187128867, 10.883748627478077, 14.876855804074196, 10.366067347988006, 17.81966697785162, 30.683935034659605, 42.46729789241668, 49.29895277946226, 52.327783492303666, 62.72144079208375, 61.77290970279325, 62.55771321635093, 67.35288527704054, 69.48461501829087, 65.65274177059051, 66.12067268740746, 59.272488932455744, 60.383786616786836, 60.9475096579521, 65.07538064833611, 66.98949337005615, 71.20818291940998, 69.66229838709678, 68.50479125976562, 66.68813766971712, 65.21335001914733, 67.22517290422994, 69.81260361209993, 68.3494104877595, 69.17911729504986, 61.003850583107244, 37.80290549801242, 46.16811690791961, 49.38786506652833, 46.50490730039535, 57.56165304491597, 66.50357446362896, 66.26703985275762, 64.83962266675888, 64.55093622207642, 67.06468520625945, 65.08963846391248, 57.10473614354288, 52.179062904850134, 55.42461241445234, 60.45253007642685, 62.55388890543292, 61.52548659232355, 62.02337265014649, 61.25993820928759, 65.28370165055799, 66.46315051663306, 67.65775542105398, 66.15074157714844, 59.11245622942525, 53.91122864138696, 49.83656460239042, 45.08156153463548, 36.14844583695935, 29.14318684608706, 27.991526011497747, 20.314510137804096, 14.095074476734286, 12.276228281759447, 15.231049753004505, 10.841100696594486, 11.864891282973751, 10.622451113116357, 10.854516183176349, 6.32518619298935, 13.445515267310606, 9.189721076719223, 3.4689787462834394, 0.8367260725748155, 0.25704293782191895, 0.04651529977338449, 0.052403041702364726, 0.8555457272356557, 9.524845442464276, 31.91030525392102, 52.850455007245465, 41.29419149891023, 30.44457631726419, 25.995090584601126, 26.184082146613832, 34.85134939993582, 48.69129134762672, 63.83839845657349, 67.7351280950731, 61.42830987130443, 21.253998202662316, 4.104326718276547, 0.06172148623473703, 0.039587666265546315, 0.022666530698658, 0.0496315922317726, 0.03848010230989706, 0.012452686430826303, 0.028280911388837045, 0.039496915490036054, 0.044771928805857904, 0.04435767442168248, 0.04048293959649821, 0.03402033678045677, 0.10229768937513714, 0.07987800369700117, 0.04169660672966031, 0.023979450268070066, 0.016772173600451603, 0.08345369610094255, 0.052498932927846916, 0.08535589241693098, 0.058931030122743505, 0.03430778829140529, 0.009470228575200084, 0.04456851330976333, 0.044889630554544355, 0.06060756757975586, 0.018299360301405675, 0.004239183439377455, 0.0895731374921818, 0.10266561076165208, 0.17912407375631795, 0.1524477431009854, 0.1380269499796052, 0.1557273961483471, 0.1140761609760023, 0.14659270163505309, 0.15479819278322882, 0.12307233913170716, 0.10800756484029755, 0.13827369157825747, 0.09859725487448516, 0.2238636544995731, 0.18197632635072356, 0.19841654256226557, 0.12333419564510546, 0.2904030945031874, 0.14838102664197647, 0.20019558258354667, 0.24990670623317843, 0.14730225227052166, 0.16827709612346467, 0.1467093921476795, 0.18187462051789607, 0.17013660602031216, 0.1149343709731775, 0.13843339026695298, 4.025082338240839, 53.1276685191739, 88.67648201604044, 86.39535703966695, 79.26509211140295, 64.18777965730237, 53.112151622772224, 33.547965403526064, 59.44399064587009, 88.53843027545561, 78.47851568652739, 69.32459016000071, 32.581822872161865, 49.068639047684215, 15.833040418163424, 3.344591807934546, 0.2287873322324407, 0.34899929057686563, 0.59127101133908, 3.5663496246260986, 11.189316953382185, 20.576706855527817, 17.599769100066155, 21.581078767776493, 25.819650811533776, 22.24859949081175, 29.68055744324961, 25.12487549935618, 22.207661713323287, 33.65183368805916, 21.282421658116004, 11.388669456205061, 28.979055266226496, 38.171318038817375, 54.718609317656494, 54.37043620694069, 55.118051728894635, 63.678530493090236, 60.60242737493208, 61.81164703061504, 68.34222470560383, 72.47321790264499, 69.58116023771225, 68.41337650052964, 63.16728092009022, 63.27277306587466, 62.81601698167863, 65.99352513590168, 70.8431593064339, 73.0907166388727, 72.17405872960245, 70.46796890997118, 68.71027638835292, 68.52514051621961, 71.05333558974728, 73.99283039954402, 71.4497773878036, 69.70475412184193, 62.669120296355224, 41.93705620304231, 50.968799898701334, 52.257612289920935, 51.37835418024371, 62.09750152403309, 68.56393275722381, 67.46221742322369, 65.5359963447817, 65.46797852362356, 69.79966763527163, 67.10605836683705, 60.44467749134187, 52.38566198656636, 58.31708585062335, 62.31182375261861, 66.46715917894917, 62.54722872088033, 63.87273880743212, 63.55374420842817, 69.37097610965853, 68.99483649961411, 69.63958786379906, 69.26472694643083, 60.543403548579064, 58.120198557453776, 57.191334232207275, 50.82018913761262, 42.75508611432968, 29.15102570287643, 36.73699748131537, 31.663468537792085, 25.157099731506843, 21.481266214001565, 27.250482420767508, 17.020223217625773, 22.20746559481467, 20.907231261653287, 14.510931026551033, 17.839078787834413, 15.591345929330396, 11.271826951734482, 2.740524738065658, 1.1239377673595183, 0.51824027852666, 0.2042429323398298, 0.20411383120283005, 1.4825327381972344, 11.771121140449278, 43.51698298608103, 71.0512488888156, 65.20181432847055, 56.172384831213186, 39.43938893656577, 29.29208197901326, 39.877199972829516, 57.12243387776037, 73.27087894562753, 76.05758174773186, 73.67842889601185, 30.552110056723322, 6.614674272075777, 0.30398886710886036, 0.1749700385956995, 0.12294725229543065, 0.11739100810260543, 0.20023796256751786, 0.24924563364155833, 0.20208611904132753, 0.16089855092427424, 0.1991857867687941, 0.16653642178543154, 0.15151800347432015, 0.14202203721769396, 0.2938119712616167, 0.1588024883981674, 0.17262947144767932, 0.09148929959102985, 0.13834847708142575, 0.14933670600575788, 0.1294551002642801, 0.18375921213338453, 0.1453925636146338, 0.17514182615184015, 0.12773900202685787, 0.11027202115304048, 0.19922412180852508, 0.1149623255215345, 0.15445864729342923, 0.09441519621759654, 0.17334110584230195], [0.05793855555595891, 0.023248554507811225, 0.08113627246911488, 0.10463943629856072, 0.039482765846074595, 0.04298944904979679, 0.028343717192089366, 0.06441281056932865, 0.045423842816343235, 0.007214767571103069, 0.04116158624510131, 0.01900593660050823, 0.06327885871512756, 0.03871174431556175, 0.034403744634361036, 0.04868398360427349, 0.036983354197394465, 0.07139999975240038, 0.07188510960869252, 0.0448044837122002, 0.030996493897551013, 0.04618600070957215, 0.07535020955988476, 0.020033833157691746, 0.03302903432819632, 0.07567618763254536, 0.017690979237217578, 11.622181880858637, 52.26684554930657, 65.21239688319545, 59.971188575990745, 56.00462113657306, 39.563300532679406, 25.28987196183974, 29.04814193325658, 55.48057679207095, 69.5362961676813, 80.63818054814493, 42.75620398982879, 37.599157979411466, 19.36302158140367, 3.082683874714759, 0.1488306130012197, 0.03460144128410086, 0.1835325726818654, 1.6186106685669193, 6.032390575255118, 9.383026265328931, 5.452956970660917, 8.911474020250383, 9.87422860437824, 7.414515172281574, 12.431025601202442, 17.68985809818391, 20.874614792485392, 19.557098496344782, 25.230973651332242, 33.369450492243615, 35.722515659947554, 42.65859188572053, 53.08580506232477, 62.98260396526706, 65.03060287044894, 62.27047412626205, 68.93225900588497, 65.05801239321309, 65.5347764876581, 64.16129581389889, 63.8612933312693, 58.67882251739503, 56.440223878429784, 52.45218146231867, 56.547920396251065, 62.13906295837895, 65.33432768237206, 66.57616969077819, 68.96543441280242, 68.0098509019421, 69.02440332597303, 63.36931436292587, 61.755980753129535, 65.13622837681925, 67.8350700870637, 64.34166600627285, 64.34769861159786, 62.22042076049313, 39.015835715878396, 38.52216228362053, 45.69220396780199, 42.25998101695892, 58.509207464033565, 60.07615512417209, 65.48379744252851, 59.99401284802345, 64.53989082767119, 64.42394164300734, 68.14312519565706, 50.69398687731836, 48.361631824124245, 47.92030634418611, 55.01801952239006, 52.42728617883498, 54.24047239365117, 53.243558868285156, 56.271365842511585, 58.68127792112289, 61.054319720114435, 62.38327364767752, 64.75498576318064, 63.68711656139743, 60.344205979377996, 58.89404296875001, 58.11998674946447, 53.88413683060677, 54.045456071053785, 46.54680213620586, 31.533132099336196, 25.615824845529374, 19.215752270913896, 19.033067880138276, 13.014240860939028, 12.207880000914297, 10.775013662153675, 14.615930914878847, 6.296208212452551, 9.978624447699517, 7.385246446055751, 0.7799229818967082, 0.6887878753965901, 0.12136565611487436, 0.021178937336850553, 0.018823573200572884, 0.013316246594542698, 0.8527715696442513, 11.212394218291006, 30.453562467328965, 38.83738356251871, 53.400520355470725, 22.29526000638162, 15.063995026773023, 23.577573030225693, 39.17963389427432, 43.047812600289625, 44.249838629076564, 57.28215671354725, 42.083521427646765, 15.285094130423763, 0.9517486585724739, 0.13045965603763057, 0.018093987450664564, 0.060633852056437926, 0.026422378254092993, 0.06812043097471038, 0.035765412293614886, 0.04623215367657043, 0.019818292404975624, 0.04335096977170437, 0.03482225463695584, 0.032266133329680854, 0.010757756160361873, 0.04100732295022857, 0.061576971408700755, 0.03528088466414521, 0.04485108484063418, 0.0050103356836423765, 0.051649984933676264, 0.06935710372823863, 0.02888205100692088, 0.0604295862027474, 0.031551063030717835, 0.0566824701344294, 0.018030731570756724, 0.039552112124980464, 0.051215233867086714, 0.017966102478244615, 0.048885702215615785, 0.0033904724536583794, 0.010087693526950336, 0.04643088837544765, 0.021623343026505846, 0.01422237826421136, 0.023885711749655106, 0.05611224790974971, 0.04524476210316343, 0.08703617604389306, 0.0314847121555959, 0.048411941951921875, 0.024959460584326618, 0.026057603573727033, 0.02809580156369315, 0.050930302785409075, 0.017331333515504678, 0.016580201542725968, 0.05701481056730113, 0.02192527742966289, 0.038622192467652985, 0.03644970884065955, 0.009055552842666306, 0.03858646212686454, 0.06886267824278725, 0.1299478480171773, 0.07166130468249321, 0.09483269881457092, 14.051721499812219, 61.894075639786266, 75.64648597471177, 69.96636052285471, 64.10816730991488, 50.27066115410098, 38.24487424665882, 36.00415752780053, 53.28816013951456, 70.5356062612226, 79.54195653238605, 44.706437818465695, 27.48363987092049, 20.01791423366916, 2.805305132942815, 0.3405034674271461, 0.02302797864221277, 0.6535742455913175, 1.906107777068692, 7.33027050572057, 12.571328782266187, 13.004457489136728, 16.12709168464907, 14.956791747000912, 13.436002539050195, 13.955888190577108, 20.865901247147594, 19.931424010184504, 16.114644042907223, 17.405580397575132, 24.632937715899562, 34.75793423191194, 38.91872175278203, 52.479143834883175, 59.887591100508175, 63.34001818010884, 64.03530536159393, 66.43385825618621, 62.17218737448416, 63.38906741911366, 66.55637741088867, 65.50988120417442, 62.20973230177357, 58.53576583247031, 55.17460446203909, 59.30649195947955, 63.06597002090947, 66.68043413469869, 69.77376430265366, 70.2776555092104, 68.51524829864502, 67.84778641116235, 65.89445391008931, 63.815181947523556, 64.87646156741728, 66.96754378657188, 64.90554201987483, 66.28631437978437, 63.374299695414884, 43.15770172303723, 45.053885290699625, 51.02012411240609, 47.66393238498319, 63.39109528449274, 60.736694028300626, 65.14241787695116, 61.05179763609364, 64.62700274682814, 66.47068931210426, 67.70420412863454, 53.38343451100012, 51.17020968467959, 50.93728365436677, 55.76982021331788, 54.681915544694476, 57.328503439503336, 56.55313714858025, 59.06258329268425, 61.4489572278915, 62.93536293891169, 64.15191350444671, 66.88987301241967, 65.78099150811472, 60.854647544122514, 59.67858760587631, 58.1268116735643, 54.38681994715045, 49.54849789219518, 42.21052777382636, 32.92640701417, 23.917181645670247, 14.694928430741834, 10.354101177184813, 9.9626378474697, 14.192858184537581, 7.415314355204183, 12.150178013309358, 13.717827777708731, 15.024803684603784, 12.558012335531174, 5.906004944155294, 2.7655653943938594, 0.5934940146342401, 0.18381466157734397, 0.054458873121127974, 0.09936217834512073, 0.9708308668867235, 11.942414968244492, 33.83548298189717, 45.12806123302829, 44.348411713877034, 31.570335780420614, 21.149502338901645, 26.524781180966286, 42.78701420753233, 51.196646459641, 52.321884247564505, 66.50876768173711, 50.34801421626922, 17.817068407612464, 1.4640322664091665, 0.0669581683412675, 0.015091248374852925, 0.012544254047585832, 0.01302773405181905, 0.06423992367701666, 0.06891854137422578, 0.03555588724632417, 0.044183672871440656, 0.04509876489699368, 0.030507023085749922, 0.01343004129481532, 0.0371238355705094, 0.05095105993771746, 0.0517067788619428, 0.07423509963818135, 0.043423629380882754, 0.03350050015855701, 0.026777640037659197, 0.05318524811657206, 0.05060454304780691, 0.009487388944703965, 0.07579036537678012, 0.025194316328833663, 0.06829398819395611, 0.044447865953008016, 0.036370005053017414, 0.027845526384490154, 0.04656416469163472, 0.11644378634950808, 0.09992615695321753, 0.1723544765263796, 0.19157258883839656, 0.1679913912929835, 0.17315738263630098, 0.20027928535015355, 0.11926028562048752, 0.2590853282280507, 0.09465040053210913, 0.1238190756750203, 0.08487311146792867, 0.18437684753969794, 0.11067582609792871, 0.10629134402880747, 0.16200936309272246, 0.18912037203629173, 0.1585194035883873, 0.12081059477021619, 0.1360067761232776, 0.11496342102726621, 0.08790111229304345, 0.22676879780427103, 0.1251501304608199, 0.3398678289546121, 0.14591955549774632, 0.1804953864625385, 18.93399077077066, 73.01861563036519, 84.98772821118756, 79.08128984512823, 72.47587726962182, 55.96642901820522, 37.86221565738801, 42.4131574169282, 71.84933354777675, 78.89950367712206, 91.36018337741976, 56.21349127061906, 50.09214624281853, 23.971863408242505, 3.9083150942479414, 0.48595619958735287, 0.13296523852454079, 0.5926451279271034, 2.321957830459841, 13.644827565839215, 15.729098589189592, 16.09382410203257, 23.20635207237736, 24.523599686161166, 23.78773754642856, 21.90523716711229, 25.94884191789935, 28.14117031712686, 28.879187799269154, 32.80901831965293, 43.30122909238262, 44.32903520522579, 46.182531618302875, 59.10796119320778, 65.2317302457748, 65.78398427655621, 62.3754132178522, 66.4861277611025, 63.650701276717655, 64.44902127788913, 66.6829836753107, 68.29544651892878, 64.39779120106851, 61.59479095089821, 58.03045865028136, 64.06860628435689, 66.93169332319691, 71.17951039345034, 70.87197303771973, 71.53510462853217, 70.48531363087316, 71.49409232601043, 68.55156160170033, 67.01663617164859, 68.46398292049285, 72.61663544562556, 67.6472826926939, 66.78327083587646, 63.5037261439908, 50.06315208250477, 49.33652908571305, 54.94134503026163, 53.733196181635705, 66.2291419121527, 62.97768139070081, 63.93643809903053, 62.944368700827326, 64.89859942466983, 69.67444988989061, 73.7032731886833, 57.27506899064588, 53.34101799995669, 52.85101198380994, 59.526023095653905, 58.369367122650154, 59.15634755165347, 59.92914861248386, 62.2477989042959, 64.68802698196905, 67.46009149859029, 68.93088617632466, 69.54740432000929, 67.71790889001662, 62.11802336477465, 60.45261636857064, 61.35237670713856, 56.87195131855627, 56.36572237937682, 48.158692313778786, 38.49547839933826, 29.939626070760912, 24.67347345044536, 23.392503838385306, 21.115397330253355, 18.85129544042772, 19.351632979608354, 31.96380246070124, 15.06305758030184, 21.99728342794603, 22.198469638824466, 6.566644849315767, 2.2680360271084696, 0.4731993341157514, 0.18996101563736317, 0.21754114618224485, 0.14838873348649473, 1.462147199819165, 13.97601975548652, 39.305349780667214, 54.38710628017303, 68.67866208476406, 34.18044367144185, 22.763765550428822, 33.07948535488498, 51.28712769477598, 59.679215185103885, 61.32578303737026, 75.30441607198408, 61.683903278843054, 22.83679812185226, 2.652710959795983, 0.1667168354915996, 0.29558708891272545, 0.1787627560477103, 0.07530343989210744, 0.1760237006049964, 0.1519438257861522, 0.11648147021450343, 0.11590950897023564, 0.10876773090492334, 0.12748574868084925, 0.1335934153006923, 0.10238611124335759, 0.1333725674738807, 0.2120692099654867, 0.20221174213915102, 0.10658892322211497, 0.09542768866184259, 0.12627614181368582, 0.1679605026278765, 0.09648465251009311, 0.1463861643306671, 0.23110640295330556, 0.19452354420096646, 0.13721068329628439, 0.12887607568935042, 0.14236283909168937, 0.10353339685788078, 0.2184707019478083], [0.016832112319647305, 0.031264421657749245, 0.0454551030340935, 0.07916427022146602, 0.01525224270975037, 0.022969790433924046, 0.07219517603516579, 0.038769652901758114, 0.012043846373055733, 0.025817111337317095, 0.010013173281725858, 0.06682725923676645, 0.03633046342480568, 0.09058709316436322, 0.023608380260186333, 0.07422493365142616, 0.0628403116828732, 0.018426814349368215, 0.06985675393333358, 0.06632862026773154, 0.03013112672394322, 0.02832911172581296, 0.03781595770570059, 0.05293053154262805, 0.08073802932255691, 0.06378782454938178, 0.36982385862258177, 29.352766929134248, 70.05951681444722, 58.37392491679038, 62.88965948166386, 51.614998617479884, 31.290902206974646, 21.1682395012148, 27.133995871390066, 37.94639364365609, 67.6949316455472, 66.74754588834702, 34.83926457743491, 25.0181987977797, 3.6565474685161345, 0.645058105789846, 0.045369113495032636, 0.009310182274108934, 0.3066734843436749, 1.5469134190390188, 3.8745273072873396, 15.682653803979198, 13.167402552020166, 14.376369214827015, 11.652528278289303, 10.682590853783394, 16.639229674493116, 19.02602722567897, 30.981119294320386, 29.830331187094416, 28.07377419164104, 43.29106623126615, 52.29384714557279, 49.547736952381754, 63.08139278042702, 60.420194056726274, 63.15308978480678, 62.73730285706059, 61.39102774281656, 57.74717723169635, 61.67576043836532, 63.171352340329086, 62.63805904696065, 59.303330529120664, 52.33523991800124, 50.21334355877292, 58.35775298456992, 61.94017917879167, 63.62280538005214, 65.69548383835824, 67.20670638545867, 65.3104914388349, 64.07590973761775, 59.57316606275497, 59.468399555452415, 63.99486572511735, 63.54228304278467, 64.62066811899986, 61.84745434791812, 64.71533844547888, 40.897883061439764, 38.685250513015255, 49.22104666309972, 52.569464252841094, 61.207590256967855, 59.54903956382506, 64.34019903982839, 57.119021415710456, 64.48873527588384, 64.13310966184063, 62.78990968581169, 49.04917624688918, 45.0765722797763, 49.84950450158889, 54.55887079238892, 55.262136074804495, 53.55490484545308, 50.75186929395122, 50.31057911534464, 55.208580032471694, 57.047802940491714, 60.43884884926581, 61.02038337338356, 60.068063274506606, 64.05281874441332, 60.53376236269551, 60.8398013730203, 58.51119610571093, 58.37530951346121, 54.2341769895246, 47.24212854139267, 41.89063102968278, 36.16333515413346, 30.763637596561065, 19.353653000247096, 15.92947679181253, 8.707771608906409, 6.80909586529578, 5.089982305803607, 17.813210756547992, 11.367730863632696, 6.9829073644453485, 2.08644058435194, 0.3099263549572037, 0.12480357526651314, 0.07806589166002889, 0.056207491790935885, 0.06407988790963447, 1.2537111005475445, 16.272730269739707, 38.93025352108864, 47.340128960147986, 36.58284048880301, 33.465815282637074, 58.125423154523304, 76.2254435016263, 57.47850664200322, 36.25731906583233, 45.63884012160763, 57.780109451663115, 28.37213516235352, 2.915798055548822, 0.171649215983287, 0.0653279255775194, 0.025112220431647958, 0.04710252531954358, 0.018092732981688554, 0.07561295473527524, 0.018124991028960195, 0.030137699758333546, 0.05444737414138452, 0.007030699146731247, 0.036279307903661843, 0.009946187511236678, 0.007606250470534208, 0.06507785915727578, 0.017929720962720535, 0.0370390564503689, 0.031947743357910265, 0.018030649216304866, 0.03301885301968263, 0.04392036079098621, 0.08024786328596455, 0.05189291524490522, 0.04615246138024715, 0.03176782569367319, 0.01155721200179429, 0.01081932568922639, 0.03107469232242194, 0.019722858917028196, 0.045053795535838416, 0.01950553892510793, 0.041393661090443214, 0.066847437992692, 0.0251088994404962, 0.048896209111497294, 0.04579860919846162, 0.06872501990367329, 0.022544088780940063, 0.03656276043564562, 0.01705956573958599, 0.05339129512468654, 0.015415062249127417, 0.049533889208349495, 0.02460358976086061, 0.02935892924846661, 0.03505633663265936, 0.04877563836353441, 0.11889765790152935, 0.08963332902039252, 0.022529665260545673, 0.017336937448670788, 0.05076326114395934, 0.011271856698928582, 0.020818180787647446, 0.033314861732745366, 0.4092377646555824, 36.40776941853185, 80.2562201407648, 69.03154203968664, 71.19608632979855, 64.80928705584618, 42.869580099659586, 32.365525730194584, 35.44694954349149, 41.3107164444462, 69.81571797401675, 69.52030858685895, 37.21729563128564, 26.19739663216376, 4.921948948214132, 0.39005421823070896, 0.028284105975481293, 0.45824836218549364, 2.5205398326919926, 7.755288241371033, 9.116170752433039, 14.125543448232836, 16.20870738260208, 15.678394109972063, 11.418827579867456, 10.177350351887366, 12.500671205982087, 16.523131439762732, 18.447006940841675, 23.39099764823914, 26.373797385923325, 41.83838505898753, 51.64713067393149, 54.56824133473059, 62.74483380779144, 62.86692150177495, 63.16177391236829, 62.55834864031885, 61.471781499924205, 59.55393075942994, 62.75449460552585, 67.02848172956898, 65.18216717627742, 61.82721491782897, 54.165151119232185, 51.467254700199256, 58.941005506823146, 65.83365717241841, 66.63666832831599, 65.23381694670647, 66.07076444933492, 67.03483596924814, 64.60655150874969, 63.167826129544174, 60.280420395635794, 63.87062464990924, 63.199507113425966, 66.00688472870858, 64.61504736254292, 65.11234898721018, 43.67075166394634, 45.49961559234127, 53.76894858575637, 57.27658302553239, 64.12129156051144, 60.625624272131155, 63.611869812011726, 58.36987703077255, 65.74036359786987, 66.35031961625623, 63.70026826858521, 52.33027027499292, 47.99040302153557, 51.95398553725212, 57.12483436830583, 58.17959108660298, 55.07389760786488, 53.14974754087387, 53.58809986422139, 58.00671262125815, 59.085611527965916, 62.6194199439018, 61.61137473198676, 62.72359025093817, 66.77322956823534, 62.00791851166756, 60.796474872096894, 58.376956908933586, 59.54002595716908, 55.027342996289654, 48.048214835505334, 38.77814400580622, 33.10407077112506, 22.7431966412452, 18.655494643795876, 12.636893160881536, 5.8445007089645635, 7.825759014775676, 9.613286064517114, 14.682997561270192, 13.944618240479501, 10.400430252475124, 5.917036610264932, 2.785556979717747, 0.4173503599820599, 0.15725480693001903, 0.08965271104487682, 0.07947207668856268, 1.6098669700084196, 16.66957901370141, 36.57383472688737, 50.83163853614561, 29.249063384148386, 15.259352595575395, 47.86070200704759, 73.99763922537528, 64.96764882918328, 41.48317521618259, 54.03178268863309, 66.78309825158888, 35.48223910793182, 3.8546823205486422, 0.1145012555043063, 0.11095594614744188, 0.05218910781906978, 0.02591340475895953, 0.039761755915899435, 0.05127413836758464, 0.024433598680902394, 0.04437219178784759, 0.00997177005985812, 0.014675455111559602, 0.005835350612253552, 0.026546141673480312, 0.05886360289408796, 0.10459387704970376, 0.04711105953902007, 0.0133939566383619, 0.0601168308076599, 0.052153825639717044, 0.05775683183944034, 0.04710087823050638, 0.047128656578640786, 0.035436101738483675, 0.0447708179783677, 0.020306125703838565, 0.04971452124957597, 0.017568395593233647, 0.027367225134625073, 0.050683714404341676, 0.15853135456000605, 0.13102121380788664, 0.15540323370406706, 0.2293570411782111, 0.10580170659288284, 0.1137019270249913, 0.1610580963953849, 0.1413391924072658, 0.07722406062267481, 0.11750364601011239, 0.12190766332130279, 0.10501262070911546, 0.09029063245942516, 0.15823858639886304, 0.12242490290513924, 0.18192049386280199, 0.1417080943863238, 0.08889399288642792, 0.2537467219536343, 0.2473089480472188, 0.1219974718086662, 0.12788135648494767, 0.1648433521510132, 0.09229094165587619, 0.22003759690109762, 0.16595442478935565, 0.7481657569446872, 46.068327888365715, 90.84868277272871, 77.26314575441423, 81.1648371911818, 68.69919177024596, 44.20178959446569, 30.943609668362527, 37.942706615694114, 51.25770991848361, 74.34847954780825, 76.8427304298647, 46.14519065426242, 30.891095015310476, 5.061895683888467, 1.074706996160169, 0.12393412675948874, 0.35590719732065357, 2.4296612124289236, 8.294560697770889, 11.099957516116481, 30.931365989869644, 23.363003692319317, 28.872092231627438, 20.959224239472423, 21.197402323445967, 29.684905390585627, 27.568104190211145, 39.556365782214755, 37.55123053827594, 35.23877366896599, 49.50530867422781, 56.508500576019294, 52.55899544685118, 65.57027001534739, 61.61530494689942, 62.54429871036161, 62.49199390411378, 60.863433653308505, 58.60114389850248, 63.237820825269154, 68.6348335204586, 68.52799600170505, 64.8809487588944, 56.87958817328177, 54.60063226761357, 61.07278231651553, 67.72126643888413, 67.98892897944297, 67.00606146166402, 66.13600915478122, 69.02103793236518, 68.48516371942335, 64.99251273370558, 65.03832209494807, 66.32781305620748, 67.80170640637799, 68.92078999550112, 64.91707771055161, 67.15075769732076, 49.22997397761191, 50.15969730192616, 57.53534570817025, 60.918578255561094, 67.28622067359187, 61.274513736847915, 64.32756508550337, 58.8312065985895, 67.81949827747961, 68.68821697850382, 66.68701587184783, 54.664539444831114, 49.554883510835715, 53.80085706710816, 58.50024484818982, 60.9364289622153, 58.28207085209509, 54.51724267775013, 55.89972126868464, 60.185146024150235, 61.32651652059248, 65.9464253148725, 65.4087350445409, 65.32815779409101, 68.01674642870503, 61.02167383317025, 62.47560624153384, 60.204295035331484, 61.47035375718148, 56.67760179888818, 50.70563239435996, 44.15135968116022, 40.036142256952104, 35.1631699838946, 25.556604900667747, 23.989243430476037, 15.440186608222225, 19.275709621367916, 17.692189947251354, 23.93093347549439, 18.236499217248735, 19.288565189607684, 9.611483735422935, 2.619263928744101, 0.423301974491727, 0.27718087658286095, 0.21132426606791638, 0.26414166174588666, 1.9864974891947162, 20.573741543677546, 51.28880254683956, 59.69018605447585, 46.52336597442628, 43.64717429684055, 67.46378637129261, 82.21984494117, 69.37791086012318, 51.590785826406176, 64.45467341330745, 75.38414216810658, 42.67269280649001, 5.540441024687983, 0.22116733144127557, 0.20356148180942382, 0.16136788703020544, 0.18790223094965183, 0.1090712089752478, 0.3364698919317415, 0.12034958604002192, 0.10904737597992344, 0.10392829220020965, 0.10838408939420216, 0.10988693939702165, 0.07490471411015719, 0.11805715219628428, 0.16453933781914173, 0.18893595935115892, 0.09218843909160745, 0.13402101493650867, 0.10300399179780677, 0.16290191681154315, 0.2730895993449996, 0.1343686196712717, 0.09120849006238485, 0.1444331457417819, 0.08443593573305877, 0.08482655630477014, 0.14311794131513567, 0.1791086907107984, 0.1479623289478402], [0.053606332174592444, 0.03641972415930322, 0.02426462075222404, 0.037381064912845055, 0.04608334109727894, 0.048568392427818435, 0.0802879450061629, 0.03289539028980559, 0.005452277921816154, 0.09904245921080151, 0.037851147954502416, 0.03386401270906772, 0.026285771370655107, 0.0343561667438236, 0.017640160794760433, 0.02752686445150645, 0.01364569600311018, 0.04080535919075051, 0.04578001624453933, 0.04096533750153838, 0.021236717603319598, 0.03169529248900231, 0.018265135323388443, 0.0242211414320815, 0.02636631977023377, 0.08475865793204115, 2.727188434331648, 34.85892741910873, 65.3157199582746, 53.628347304559526, 59.50650145930629, 48.36559734036846, 29.75156411047905, 34.173371638021166, 47.254844865491314, 39.37216343418245, 52.40814501239408, 59.047297816122736, 25.68456046042904, 7.555235105176126, 0.5417046323418617, 0.08280313423564357, 0.059391360865124775, 0.346024080870613, 2.9866997993761495, 6.165318229506093, 6.351233182414886, 10.666265949126213, 16.071389125239467, 14.781843250797642, 10.028064943129017, 10.626927518075513, 19.333884254578624, 42.72274224988876, 46.95996499830677, 48.86420119193293, 49.28069022393996, 63.08764896085186, 68.71807406025549, 66.09228257210025, 64.40888366391583, 62.059827158527995, 62.0284717313705, 61.95630404257006, 62.21207003439627, 62.38095160453551, 64.06168722337293, 63.742641633556744, 59.013745861668745, 54.71465949089297, 47.72924377072243, 49.1327815671121, 55.88634206402687, 65.53173665077456, 61.797628479619185, 63.434264890609256, 64.23371453439036, 63.19111324125721, 63.2942754991593, 59.841628766828975, 58.50628922062536, 61.14074914686142, 64.41430830186414, 62.13899235571585, 60.43271426231631, 62.276616557951904, 49.752880834764056, 35.59032786277033, 50.01748392658849, 52.498488964573035, 63.52120422547864, 60.123117662245235, 61.181875198118156, 58.63239734403549, 63.39533928901919, 62.17486635331185, 63.087868613581506, 48.34784861533873, 46.22983932495118, 53.853891434208045, 55.40541241245886, 53.95824217027234, 51.987357062678186, 51.341048517534816, 51.25337962181338, 51.09566111718455, 53.77409865779262, 56.24682749471357, 58.77459110752229, 58.39132455087478, 61.6749288958888, 61.326767552283506, 59.69228060014787, 58.66666316986085, 60.21004130763393, 61.64905301986202, 62.80712496849799, 54.099812276901744, 42.19490497343002, 32.74268711766889, 35.27451430597613, 31.31606225044497, 4.613088282846636, 8.060568273067474, 17.143014977055213, 18.113656467007054, 11.565111394851439, 6.511850318601055, 3.967362454821987, 2.9210898232075477, 0.5612372390685544, 0.10404038618529036, 0.11200016229263238, 0.023964013596395814, 0.12970985514262032, 4.27827819701164, 27.838435903672252, 47.187540915704545, 66.15341663360596, 77.42761858047979, 92.26296394102036, 66.19279723013601, 33.93472286962694, 39.25478258440572, 45.47549301578153, 54.55004938187138, 39.71112681973366, 8.602832517316266, 0.4131119019321857, 0.10467004917201497, 0.018216523214153225, 0.027261993382126096, 0.09506549761300126, 0.08622501916702717, 0.017912175634034702, 0.021022933107169888, 0.03878115188150156, 0.017565819622588255, 0.025596163919075363, 0.05653458452152629, 0.04488605675437758, 0.01717578319291915, 0.05713346992589294, 0.03599166104029264, 0.01726543271703826, 0.08307085898254188, 0.07145596247526907, 0.0400752199423169, 0.05896936133203488, 0.08635879344036503, 0.030971666903144894, 0.06628746602443919, 0.03028932388030714, 0.04249232310441233, 0.025941826620950334, 0.016442200379265894, 0.011340523074801651, 0.016467762818079323, 0.049218904497402335, 0.021211722069570137, 0.059846191096209714, 0.050693443720980044, 0.10467905836600451, 0.06494627589540136, 0.0028815635971935287, 0.1215771193646135, 0.027258030792337754, 0.042459795011147376, 0.08107426531252362, 0.06634374284335683, 0.04346389113174331, 0.05520498147234321, 0.032518957666451895, 0.10900816759995877, 0.08796013936760926, 0.014899654573039904, 0.031178983701993863, 0.021418320660990094, 0.01676266261887166, 0.047233966855152, 0.044483837611492605, 0.05349632194866577, 3.2493198879303473, 45.070072912400775, 76.41416442009711, 62.42047732876193, 67.03314150533369, 52.89912769871374, 31.56641733261847, 26.834901417455367, 30.197665076101984, 34.67229320156959, 57.86111031809161, 63.30991398903632, 30.190634227568108, 10.855138859441205, 0.8538616208299514, 0.14217035183983465, 0.32690543741468464, 0.7317985642340876, 4.7033547682146875, 10.805028619304782, 11.118879029827735, 16.949634282819687, 16.395957412258273, 15.609061314213662, 17.356815530407815, 10.617223574269204, 13.18715560820795, 26.01609487687388, 34.749167734576815, 41.360499166673236, 46.71018454336351, 60.05231495826476, 69.29503117838215, 65.88873509437808, 65.35335117770781, 63.07577202397009, 62.964655199358546, 64.32276018204229, 62.832251671821844, 61.23321117893342, 64.90864461468112, 65.86264348799183, 61.28690058185209, 58.673743048021876, 49.247954122481815, 50.78870819460962, 58.30458917925435, 67.21223692740163, 63.851361889992994, 65.22640758945097, 63.75489904034523, 65.6836304356975, 64.60807731074672, 63.08424042117212, 60.350532762465946, 62.74263728049494, 64.54100478080012, 63.63254070281983, 61.58974286048644, 63.82827481915874, 50.92259437807145, 41.384249118066606, 52.96968329337336, 57.83467746550038, 65.70658022357573, 60.82498658087946, 61.67543880401119, 59.35925960540772, 64.40739316325035, 65.42323604706796, 64.96107493677448, 50.15970906903667, 49.542245634140514, 54.02802113563784, 56.820905593133745, 55.88873078746181, 53.66230718551144, 55.29847291208083, 54.11447801897603, 53.172105050856075, 55.51293242362238, 57.860572953378, 60.93767235355993, 61.2921408684023, 63.21088983166603, 62.79888799113613, 58.38387596991755, 58.55118466961769, 59.433972912449995, 63.256875699566265, 61.034264641423384, 55.5319441518476, 43.57834846742692, 37.33763002580212, 29.761860332181378, 20.562833432228338, 9.240228456835593, 11.868265501914486, 13.88718395463882, 15.903535216085373, 15.75500584417774, 11.176018157312948, 11.77065339780623, 3.996189669255288, 2.2708228711159, 0.8922603990762465, 0.21265540512338763, 0.06215787672948453, 0.15667990390812198, 3.939497691969718, 27.732367169472482, 43.28459039811165, 44.19475678474673, 64.21829177487281, 94.69296639965427, 78.49226751635152, 45.66984253544962, 44.420132252477835, 53.19573733114427, 61.83281214006486, 48.80664825439454, 12.579108803502976, 0.5180600333598353, 0.07101039807762831, 0.0448583013888809, 0.018770715049017343, 0.09848490041951019, 0.05641598644996843, 0.0022646030664609205, 0.04185966471390378, 0.06120130487327134, 0.06006973938295438, 0.048860559209940896, 0.06098026169403907, 0.047104520978586334, 0.0856152821272131, 0.026271278902347532, 0.06317312325981837, 0.08049534032902411, 0.0073832532882900734, 0.03331571975122056, 0.07052768607653918, 0.042660843295555924, 0.06479924830097346, 0.060096931673826716, 0.04569889136379765, 0.06221572019820733, 0.03085021898450871, 0.0391765988071359, 0.02931670056686046, 0.10879592294053686, 0.16526771889578912, 0.12220346519062597, 0.1295277866865358, 0.16511172807264715, 0.2587559104206101, 0.18337877287018686, 0.15934193687092874, 0.14559812032647673, 0.20569091512551232, 0.1338192273772532, 0.1527293876654679, 0.20340302418316566, 0.18294585658417595, 0.1939538812204715, 0.15942278979045732, 0.09955760737460467, 0.18937414632208888, 0.1588292248667248, 0.12130849829484379, 0.1788282412434778, 0.18604095905057846, 0.10167672914723236, 0.14399950933312217, 0.054297128977674636, 0.15428879027885778, 4.971199698986546, 54.20682630231304, 83.5813545411633, 73.34410175200432, 73.50858242281022, 60.90626985796037, 42.85507909713253, 45.6539334020307, 62.64233835281865, 49.97693446374709, 63.20437085243964, 70.17178289351925, 33.70295001614478, 9.954175333822928, 1.3326809146711904, 0.23098424257289982, 0.2672530512415594, 1.0129864177396222, 4.703274849922427, 11.818063086079015, 20.48673160614506, 26.5574231455403, 29.95633536769498, 21.74001712952891, 23.239784394541097, 19.159811427516324, 28.30266606423163, 52.552390175481, 51.197803558841834, 53.171469626888154, 51.15564984659995, 67.4302657958, 71.9241645259242, 68.82525674758419, 65.58510834170927, 63.752035710119436, 62.645923399156146, 62.84699978366975, 63.51166894358974, 62.00482376160161, 67.21848134071597, 67.54965489910495, 63.57196754024875, 60.44303401823967, 52.449871186287176, 53.724355159267304, 60.682439804077156, 71.23938929650092, 64.57736515229749, 66.69338580100768, 66.61846068597609, 67.25841891381049, 67.73442206844207, 65.01638820094448, 63.49423008580362, 65.0388986833634, 69.33776147903936, 66.38966098908456, 63.466051778485706, 66.15914329405754, 54.68907779262912, 46.40209805580878, 58.012145103946814, 59.92448491434897, 67.31505793909874, 61.23966740023706, 61.42479542763003, 60.39320422757057, 66.87374422627111, 67.76555784286992, 68.73632877103745, 50.98084157513034, 51.605530015883915, 59.0186409796438, 60.59141728185839, 58.560002157765055, 55.37391185760499, 56.51506662368775, 57.04304902784286, 55.9313081156823, 59.07115759388093, 61.80625377162811, 63.821281233141505, 65.01467804754934, 66.32539687618133, 63.38103832737092, 59.611970070869695, 59.670413386437204, 59.909540683992454, 63.779739410646506, 63.500894192726385, 57.0961186962743, 46.59993848493023, 38.692644180790076, 39.876415498795055, 36.28846268500052, 8.99246213897582, 17.03682072700993, 31.986050144318614, 31.153427054805142, 22.54484042044609, 15.13072434932955, 14.239968792084726, 6.237099564844563, 1.7536651054697654, 0.7630849821913628, 0.2975845865664944, 0.22566443609614528, 0.5364528238292664, 5.642281934138268, 35.40747873244747, 59.52039841682681, 81.83062814897107, 86.01727977875741, 93.58580681585497, 67.54605416328677, 45.25185515803676, 54.19679287941226, 63.923741386782744, 70.23104206208261, 58.75529696864467, 16.578827135024532, 0.8258750806412389, 0.3149545270829432, 0.1696355079090403, 0.14172240490874938, 0.2972934118682339, 0.2167942717431053, 0.2307100750265583, 0.08591743486542856, 0.18557194470157548, 0.09057340317315633, 0.1418062762146996, 0.15073161422004624, 0.0900729715583786, 0.19992144568072212, 0.18919175610907618, 0.15699254439002083, 0.14369227743196872, 0.20704682946445482, 0.14944395831515714, 0.13651106116031447, 0.08739668936018022, 0.12516481636632837, 0.1230384320801785, 0.1465458630193626, 0.194283390958463, 0.16017099722258507, 0.10890153582177817, 0.1514492547439952], [0.07310589369867118, 0.0696182937451428, 0.04170264350250364, 0.051453012237024885, 0.013164010559839588, 0.09615052326191818, 0.030930926347331657, 0.031061201514075362, 0.08688824446571451, 0.03731413564134029, 0.03578290591136583, 0.027120123474648403, 0.08530485563941541, 0.027784875203524868, 0.07832881303564196, 0.04854461688908839, 0.03470274109032846, 0.09663684353713067, 0.04401270119893936, 0.029702600121738452, 0.03431194048795489, 0.02801145145279025, 0.05892764018367856, 0.15369110380209264, 0.02680760939725705, 0.20501666582159458, 10.212530089962868, 61.945031150694824, 61.94023409197408, 62.38463078775714, 48.43441140267157, 55.40103112497638, 45.48247091231808, 71.74659882822345, 83.68925894460371, 54.641217031786525, 60.32937549775647, 36.6088693372665, 10.803182163546163, 1.8601991308312265, 0.10559009012555885, 0.031359945161027775, 0.5142321065068245, 1.0453907111960075, 6.2256673266810765, 13.312360605885907, 8.908930363193635, 8.73466435940035, 15.077741953634447, 14.076739357363794, 19.49632529289492, 18.667000916696367, 26.62761788214407, 46.172121647865545, 55.00282033797234, 61.323206040167044, 65.17070993300408, 64.78396815638389, 64.03381093855828, 61.436892017241455, 64.77804145505353, 59.40168003882132, 61.67059467684839, 61.438892426029334, 61.01622958337108, 62.48830295378163, 62.27252944823235, 63.06637402503722, 57.74547492304156, 51.73176757750973, 47.296237637919766, 51.068726201211255, 59.32546838637322, 60.67032752498504, 60.32526093144571, 61.186264330340975, 61.63356358005155, 62.858366812429125, 62.28833660002678, 57.270652401831846, 58.33409717006069, 57.7945633857481, 59.94332798065678, 61.74668865819132, 60.05773175147272, 61.31078781620149, 57.818795788672666, 35.60975928460398, 45.92176460450696, 57.457031665309785, 60.255352527864524, 60.35466301825739, 61.50953039046257, 59.179458156708755, 58.198661650380785, 63.81493876057287, 59.9649323955659, 46.50856687176613, 48.309946752363636, 55.51830214838828, 58.20271345876879, 56.351131162335804, 53.50083889499788, 52.49211511304302, 50.523277482678814, 52.42727048935429, 50.08627837704074, 50.51572692009711, 55.446122692477324, 57.9886697184655, 59.2824282184724, 62.39988488535728, 61.06627510439966, 58.108325542942175, 58.35943175900368, 56.91980031228835, 60.679070488099136, 60.13231169792914, 61.167668373354026, 54.19345102002544, 44.23515719752158, 27.111663856813987, 17.335222882609216, 9.897816758002005, 6.090614238092977, 8.851155811740506, 12.174542796227241, 8.52798584968813, 5.869126819795178, 5.8436524964148004, 1.8700049336879485, 0.2771498040566521, 0.19972426997077083, 0.035864655153765794, 0.0786506312508737, 0.4843752392597737, 9.301280148567693, 32.69504208718577, 39.27556330157865, 32.528196227165964, 26.717553907825103, 21.194548799145608, 26.03195105829547, 38.151953297276656, 44.44800853729249, 55.45616003774828, 54.85437823880104, 19.56178180633053, 1.6139523636910225, 0.07689863413331971, 0.03762890967810827, 0.057528319302946336, 0.07156404215962657, 0.053152754497263706, 0.032106495928019285, 0.05381997111403654, 0.01332063532073892, 0.05461598626307903, 0.061248779341939, 0.07987267938592742, 0.034465483660178806, 0.04406793613827998, 0.023307112353523413, 0.026709067507556854, 0.06468674828929287, 0.07514679789422982, 0.043268983042047876, 0.036722091402137474, 0.03422850202168188, 0.09025307116849769, 0.011031798259805768, 0.0626614110003556, 0.057948277211718024, 0.026628231825006586, 0.03570688700663947, 0.027156755883967685, 0.03008456198468564, 0.010264641642870923, 0.062314024600651, 0.03571976494464663, 0.047531289409004876, 0.0860256677673709, 0.018252278452799208, 0.014795723254792394, 0.06342284111005646, 0.013653284104000176, 0.021398392798859748, 0.015081414678734879, 0.09007399811619714, 0.05743973272582216, 0.07950813644715855, 0.026795846117179722, 0.058640035455145186, 0.08315018738710112, 0.027011549663579753, 0.01273939292126846, 0.014482796447531832, 0.11063066521479238, 0.03481864636283248, 0.04696011723529908, 0.07358593971378381, 0.3104096951503908, 14.656788283778777, 70.73705919327276, 71.65669810387396, 69.18052150357154, 58.07871557051136, 62.55665809877458, 51.91817429757888, 57.445064513914055, 64.09478418288693, 57.21237774818175, 65.49651768899733, 45.29015710276943, 15.051346363559848, 2.5136671047056875, 0.10170867501367485, 0.1084352104413894, 0.6366082172720664, 2.5191993626856037, 9.118789915115602, 12.487514595831595, 11.92766881758167, 11.1162628089228, 14.612351752096608, 16.517863696621312, 15.441301541943705, 16.146198530350965, 21.63089483014999, 38.25476254186323, 47.724878172720636, 57.54581451416016, 64.73129856971003, 68.76958262535834, 67.30034120621221, 63.459230776756044, 65.67718990387456, 61.43648016837336, 63.63168954849244, 59.86343714498705, 61.32991721553188, 62.89437417061099, 64.1995350007088, 63.68419439561906, 61.333059034039906, 54.33333058511057, 49.26211780117404, 53.364265887968, 62.715580771046305, 64.8373241578379, 62.869027814557484, 62.500783935669936, 63.30827051593412, 63.50169827861171, 63.35540956066501, 58.91220354264783, 59.48762701403711, 59.40368436997937, 62.69804777637605, 62.54501258173297, 63.66289200321321, 63.00705602092128, 58.250723269677934, 40.25755613080917, 51.04048121360041, 60.47038470545123, 61.430886868507635, 59.59546473718459, 61.22193828705819, 60.45982960731753, 59.52426587381671, 65.34760098303518, 62.069311449604655, 48.36964130401612, 49.35338351034349, 57.61945309177522, 59.297301846165816, 58.549839296648585, 56.72246194654896, 54.53895691902407, 53.8911461061047, 53.88880445111183, 54.77844899700534, 52.95073824544107, 57.240756096378455, 59.17490820730887, 60.53406830756896, 63.501000096721036, 61.494746977283114, 58.889183152106504, 59.006226678048414, 57.90193434684508, 61.63638376420545, 60.457166317970525, 60.42111581371677, 54.15299961643835, 45.81800614633868, 30.174376003203857, 19.36023081502607, 13.450305461883547, 7.8494795483927575, 16.912046209458385, 16.19671473580022, 9.40226843280177, 9.316392060249083, 9.405412212494882, 5.521241022694496, 1.6894845880808371, 0.7677331134196251, 0.0846786630309878, 0.07902905570283052, 0.4559455018851065, 10.05850939981399, 33.38681874736663, 48.14013950286373, 45.04827237898304, 48.69228762965049, 32.14891675979861, 27.259868652589862, 46.482792977363836, 51.556488621619444, 63.59494086234801, 63.92198808731572, 27.567747254525464, 1.9041278381501476, 0.12509672647161832, 0.03101260089615901, 0.04515166326816525, 0.1148299378673396, 0.039361559245134556, 0.05636216877328773, 0.03291152793193056, 0.06020992964265808, 0.087774102576077, 0.07298492075454804, 0.06939058177052967, 0.018086380197576458, 0.004759876164532597, 0.06791456782769772, 0.040735595393925905, 0.019825832625370354, 0.068955558742727, 0.0643145827756774, 0.010780650697978995, 0.047381185971560984, 0.08868184781843617, 0.0880178487709453, 0.03202508759474562, 0.054227637142063155, 0.03360020267146249, 0.053423172043215846, 0.018282538925808285, 0.14339852867828262, 0.15946210542273137, 0.1415073027413699, 0.1774280623442704, 0.1356781090820028, 0.1526091425048728, 0.09343217517579756, 0.10181814131717529, 0.17954529954060433, 0.1250979062470217, 0.10519301909352503, 0.17794596842460095, 0.3191604417177939, 0.18303127538773323, 0.1805292169052747, 0.18528824702145594, 0.19763700213403473, 0.23245295569781335, 0.15164598612295044, 0.1173285949194143, 0.09992988014052953, 0.33019538668374865, 0.19598510206466724, 0.19870826884383158, 0.22396948188543322, 0.5022534637922241, 23.055468297773793, 83.06424494712584, 80.60723304748535, 79.54063861600815, 64.3533899707179, 68.51934325310492, 57.78461233262093, 91.996791901127, 98.19405832598287, 62.80087663281349, 72.37121274394374, 44.93740658606253, 15.070622851771695, 2.68283476271937, 0.32716486542936296, 0.48012881389548706, 0.737430474931194, 2.7512092744150474, 12.742933457897557, 22.991563081741337, 22.9608509232921, 21.16099488350653, 27.117876891166937, 22.02594222561006, 32.165006322245446, 24.725589982924927, 32.575135231018066, 49.84342875019197, 61.50721619206091, 66.59762505562075, 71.01713995779716, 70.39905286604359, 69.36056613922119, 63.738934993743904, 68.3713286922824, 60.59257830342939, 63.403709626966915, 61.24644133352465, 60.41382020519626, 63.892735050570586, 67.18259165363928, 66.62668981859761, 64.37860296618554, 56.156287424026004, 51.98283456986951, 57.150816148327245, 65.71516236951275, 66.97406276579827, 63.05986681292134, 63.08928851158389, 65.44129071697112, 67.40855155452606, 67.01936614128851, 62.43899091597527, 62.0662166995387, 61.060073837157226, 64.73864909141295, 67.23919929996615, 64.626088834578, 64.19474186435824, 58.6170098858495, 45.54471108221239, 57.94358991807508, 62.14615852602067, 62.6785457518793, 60.30102460615097, 61.52500414079236, 60.065643172110285, 61.27596501381167, 66.5869483640117, 64.49949825963667, 50.16077203135337, 52.351086293497396, 60.78911650565363, 64.01828227504608, 60.08296435879123, 59.68489085474322, 56.313374427057084, 55.27380120369696, 56.758645811388575, 57.58211605010494, 55.07046161159393, 60.48739210251839, 61.99271932724984, 65.43570133947557, 65.31864996879332, 63.38796523309524, 58.56521106535389, 60.99077732332292, 56.99668269003592, 62.49722634592364, 62.77560480179326, 66.1944289361277, 57.77755991105111, 49.655770794037856, 30.407657008017267, 28.242930327692342, 18.09028894670548, 11.522058479247555, 19.766649161615682, 24.293142787871826, 20.020148023482292, 16.651092883079283, 18.894055158861224, 5.224829960253931, 1.2401498733989655, 0.7252726595728629, 0.20030896359634018, 0.29850441301541947, 0.6343497900712876, 12.06585587993745, 41.90914069452594, 49.797505640214496, 43.164926728894635, 36.060961292636016, 29.49565299095646, 38.87899991004698, 53.824512881617395, 60.743718993279245, 70.59160986254292, 74.51696888093026, 37.311926734062936, 3.137665943753335, 0.43354699087719767, 0.10956924273482255, 0.18155016696020482, 0.21055042533384216, 0.12376186422883503, 0.1377047793639283, 0.15962569583808223, 0.12267671600585023, 0.16165319349496596, 0.17555067195527016, 0.17929586131245862, 0.09658542371565297, 0.1610325090587139, 0.08730126544833185, 0.14322654193928167, 0.10351432892944544, 0.23322232247840977, 0.15079896867034898, 0.14274522421821473, 0.1497752300553745, 0.18831265489420584, 0.13755074972587247, 0.13204018735597212, 0.21220989435190157, 0.17929598388652648, 0.11895544391365782, 0.07128447369341889], [0.0007700530876454358, 0.06787480020354833, 0.0581746906672995, 0.04710146045732883, 0.04141649817146602, 0.024121594051980687, 0.049095606476429014, 0.013777969701726352, 0.04126425351827376, 0.04477517701865685, 0.07070214727953558, 0.030005540015296112, 0.03614291744006257, 0.016083632926306417, 0.0540504984617714, 0.05040406932934158, 0.07819562098912655, 0.028016513378749934, 0.015605201441494208, 0.08934233052235457, 0.022228508436631773, 0.04494808306316695, 0.031072545361014146, 0.015395181309882433, 0.06963052816929356, 0.26390883230393936, 26.681260216620664, 63.14944198054653, 63.715149741018976, 53.19665908813477, 47.77404116046044, 33.0493890085528, 26.15074984488949, 61.80998786803215, 59.112499375497144, 65.33741458769768, 43.3099171423143, 16.84229862305426, 4.392740803380167, 0.33309705194927036, 0.04046878995253675, 0.07054133776334987, 0.43640308923298315, 0.902093535950107, 7.463311908706543, 11.62935785708889, 8.210896541995387, 13.918474662688471, 13.290771880457479, 31.75341044702838, 37.950602346850985, 37.48729198209701, 43.85058841397686, 55.652302080585116, 57.944488140844534, 66.74518462150328, 66.44053413021949, 61.525643487130445, 62.59490513032483, 63.85588046043151, 64.29958289669406, 62.41155001424975, 60.11249196144843, 61.04820866738597, 60.95023570522186, 62.876303811227125, 62.561294340318256, 61.598685864479314, 52.81049389992991, 47.16760350811867, 47.170533518637384, 51.63497524876749, 55.00829596673289, 61.075610345409764, 62.14083979206701, 59.667416695625555, 64.9008273309277, 61.154693172824004, 60.46365784060571, 55.05419554248933, 57.09748368109427, 56.39780344501619, 60.44985501996933, 57.766494904795, 59.71605408576227, 58.21353527807421, 63.20511610277238, 37.042922742905155, 42.797220214720696, 57.50411579685827, 57.045912358068655, 59.741596560324396, 57.423209067313906, 57.94348401408042, 58.34238906060496, 64.11955002815493, 57.9435153930418, 47.1602019956035, 48.46940678934897, 56.74129716811642, 56.917619474472545, 58.33744687418784, 55.88860134924612, 57.703678146485366, 51.80061301877422, 52.9391594086924, 48.981174115211736, 50.6972542116719, 48.60129256402293, 52.98812627792359, 58.14097535225653, 59.35134818477016, 59.26552280302971, 60.84650862601496, 58.457506702792266, 59.735571799739716, 59.31604293084914, 59.26096108651931, 57.218684919418834, 60.341742730909786, 57.729691305468165, 46.564272372953354, 28.097641814139585, 36.190324983289166, 19.95386585112541, 14.033756063830468, 16.092753294975527, 10.63150296288152, 12.309867508949774, 2.7567564864312453, 5.595433635096397, 3.4225442572947475, 0.4302645799133086, 0.10333283503930416, 0.11277356635658972, 0.09494837809113726, 1.8043855193161198, 12.518200278282167, 34.35586775502851, 41.13391168655888, 25.198066926771595, 21.214223407929946, 27.358986946844286, 22.33996522042059, 37.36127015083067, 52.38365373303814, 53.97311972033594, 42.32337436368389, 4.714297200402906, 0.3148069172616928, 0.03802994904558986, 0.03429152041433319, 0.05082629485836914, 0.040310167617374854, 0.09936952512831458, 0.022331273386014566, 0.046749481360518166, 0.035261303456800605, 0.02770216260556012, 0.04297785813950243, 0.02465518769778071, 0.011266994913439117, 0.017399703032307087, 0.04377326041820549, 0.014043531207848462, 0.02258787453625231, 0.03948214914529555, 0.017074360812623656, 0.035043650216633276, 0.05437836877160496, 0.04431204239447271, 0.07535440772170983, 0.027680317608399257, 0.03486568799182292, 0.07261414186007555, 0.035471403070034525, 0.022742612805638104, 0.04409202577305898, 0.026219169601737976, 0.02962472728423534, 0.058379423834623835, 0.026255547286822434, 0.021750142069293127, 0.015329676961916831, 0.06344408089775713, 0.04867962839442396, 0.01514063519050157, 0.059773757482968995, 0.055592028243887814, 0.02937540779971788, 0.044715893304636406, 0.0876906679402436, 0.06275701494286619, 0.0046603498518496995, 0.0321073213877577, 0.01674447377632943, 0.049237911138803735, 0.11102372194610297, 0.07935927790259162, 0.046246123289869684, 0.059684619322539344, 1.0255423536704433, 34.89772358248311, 73.82178368106966, 70.8468855580976, 60.85312566449566, 53.79121588122461, 43.930287053508145, 36.365792212947724, 65.32334112351941, 65.35963481472385, 72.22699503744803, 53.99696773098361, 19.43994318285296, 4.199903847709779, 0.3588760025318592, 0.007705006864853204, 0.4209001049880059, 1.941349660196612, 6.380398456127414, 10.334346159811943, 15.877156296084005, 10.460367010485742, 15.755986436720818, 16.264360912384525, 15.525564839763028, 23.088824133719168, 30.82067866479197, 41.5175037999307, 49.917616459631155, 58.16591378181212, 68.65750482005458, 67.35255579794607, 63.31016894309752, 63.99611303883215, 65.15080390437957, 64.89404947526994, 63.012563028643214, 61.17830976363152, 63.09730975858627, 60.87098813826039, 64.7508123613173, 63.5494335236088, 63.48235707129202, 56.5034838645689, 51.10532191491897, 48.97088181587958, 54.393048670984086, 59.11650411544308, 61.80835616204047, 62.941693644369806, 59.337023688900864, 63.68644975846814, 62.40538404833887, 62.484490409974136, 58.10574854573896, 58.28940960668749, 57.9182670962426, 60.36451601213025, 60.474585563905784, 62.66008707784838, 59.535464240658676, 63.23272566641531, 41.05011024782735, 46.57797713433543, 61.50318791789394, 58.96193135169245, 59.69568129508727, 59.2071500901253, 58.85245015544277, 60.434043945804724, 65.2054189866589, 59.8618289732164, 49.85751005911058, 49.19613176776517, 59.75725858442245, 57.57245133000036, 61.94416430688674, 59.376404285430915, 59.16518857402187, 55.56251510497063, 54.962623888446444, 52.30613593132266, 51.28000074817289, 50.00089622312977, 55.122472240078835, 61.11284148308539, 61.82486149572558, 60.668805645358184, 59.2479976530998, 58.32347146926388, 58.544045955904075, 57.91183048678983, 59.3259233813132, 58.00980344895394, 62.273066812945956, 56.05001864894744, 44.78627374095302, 29.11163922279112, 25.671328344652732, 12.333534109976984, 13.12620589810033, 13.953198425231443, 10.127988303861311, 13.809010136512018, 9.652763739708933, 9.410189659364763, 4.536054403551163, 1.8412257682892585, 0.13102996253198193, 0.05199283992330875, 0.026523884904060154, 2.0010659074591053, 14.423496492447393, 35.488130507930634, 45.87989330291749, 25.77685186939855, 24.932085121831587, 36.507362319577126, 32.26483260431598, 45.21926810664516, 59.42746177796395, 60.647263988371826, 50.679897723659394, 8.196181279997672, 0.08910963131535439, 0.03749672120677368, 0.0456325366582361, 0.04673498697699078, 0.09087013966974714, 0.05360719402350726, 0.01002357196768806, 0.00974625388475796, 0.05941966781392694, 0.03503086037873741, 0.046975009984547095, 0.0265227472634926, 0.036876216801183845, 0.06018602386898091, 0.045273000104052406, 0.052122469660976244, 0.04364178057820086, 0.022781252365319, 0.020661965883787603, 0.03987214535534863, 0.03399605945413632, 0.07237421844394938, 0.06785551010961495, 0.03664496933080016, 0.010527293930100578, 0.07603530666881031, 0.07146425154660979, 0.22518549324764361, 0.12714903005549025, 0.15683059340282796, 0.17967412488595133, 0.1516981107453185, 0.12802061594782338, 0.14492244609901983, 0.04517430882720698, 0.12905362422668165, 0.15487185979802764, 0.1901907654058549, 0.18701335445286768, 0.1104804200510825, 0.14905699198284458, 0.16941063045974702, 0.15954890318455237, 0.16034053248022834, 0.10420680346508181, 0.1975013892496786, 0.15241213533426487, 0.14933013297136755, 0.24916649675898014, 0.11192749119213513, 0.10219206117213735, 0.22645031973238916, 2.4621146580865307, 45.12367602317564, 81.36122242096933, 81.91170354043284, 68.65124471725957, 61.34774046559488, 44.47387656857891, 36.95881535930019, 75.78543201569589, 68.22816218099287, 74.59369044150077, 52.46812197469896, 23.003989150447232, 5.263991884646877, 0.6688233176546713, 0.19450151151226414, 0.493296149276918, 2.632648281512722, 7.4365216301333525, 16.988430446194066, 23.7660821407072, 16.33338874386203, 20.999501097586847, 24.522946611527477, 43.34452029197447, 46.37970524449503, 41.15767340506277, 47.832170686414166, 58.565693516885084, 62.605668114077666, 69.14391010038315, 70.58472218052034, 66.3190112575408, 67.7125430876209, 67.54696415316674, 67.1487808227539, 62.45590417615829, 61.478610346394206, 62.4276513438071, 61.674807302413456, 66.27209186553955, 67.1360174302132, 66.5957344731977, 58.46286858281782, 52.18604864612703, 51.77535295486451, 57.659374975389056, 61.09698726284889, 63.41262125199842, 63.7936677471284, 60.245962373672, 64.89920739204653, 65.5674498311935, 64.07017523242583, 60.38338653502926, 63.37691983868999, 61.39684461778211, 62.380359326639486, 63.59918878924463, 64.58029516281621, 62.005721984371064, 63.31463260035362, 45.340222235648866, 50.888324629875925, 63.27984902166552, 61.413302883025146, 60.51463296336513, 59.79796494207075, 59.49714660644532, 61.97639834496283, 68.00330838849469, 62.73634579873855, 52.98041489816482, 51.05291120467648, 62.008997163464954, 60.566184674539876, 64.31817885368102, 61.08758926391602, 61.491001113768554, 57.70659246752339, 58.73052327863632, 54.58627247041272, 53.53428886782739, 54.14415859406995, 58.27464972772906, 64.16258235131541, 65.48682158993137, 63.96455364842569, 61.95250718824325, 57.98960324256652, 59.38791644188666, 60.904281216283, 60.55695533752442, 59.74433829707485, 66.01471377957252, 60.04965559128792, 51.52222671816426, 32.45134326719469, 39.966892811559866, 26.924596217370805, 19.746988281126946, 24.166991518389796, 25.561631418043568, 22.643605701385006, 10.920790510792887, 16.97234284493231, 9.72506086672506, 1.2292549999490863, 0.21960883281163632, 0.3589505582086502, 0.08178488081020695, 2.347289232477065, 16.682724837333925, 44.140373122307565, 56.3643495498165, 35.448138021653705, 32.979994435464185, 38.24670207115912, 35.629575098714525, 51.71119082358576, 69.01484843223326, 68.44823068188083, 61.18265182741227, 12.986299857016533, 0.4416016393130826, 0.17681770477323763, 0.1292188234266735, 0.09519213960776407, 0.20943759069327386, 0.20188846835686317, 0.13550825206743133, 0.08354433196326418, 0.1246122984335788, 0.08635058863869599, 0.22980914030584598, 0.1770881950975426, 0.11632231544823417, 0.13981435568101946, 0.2617783111429984, 0.16130966434796012, 0.1629668197804882, 0.1802847735703953, 0.12279549027763068, 0.1600463853608216, 0.14111947839058217, 0.25493172207666986, 0.1586448275033505, 0.19261066861931356, 0.09247622002036342, 0.14163894729027826, 0.10592005185542569], [0.02791000992029665, 0.10384144081223397, 0.030371299118644772, 0.023894763078480482, 0.0356693065635139, 0.0789229755079554, 0.01556099721065332, 0.054344454059197064, 0.038976408541202545, 0.009932141289144996, 0.10260036305314112, 0.06221930548969296, 0.05109372466141659, 0.05849586919911447, 0.06284330708665714, 0.053370423059189515, 0.039248886863671006, 0.03307108489436007, 0.03216508250202864, 0.0009525537849009608, 0.02370413933550158, 0.04072813369754342, 0.05594807909801603, 0.021008356369190642, 0.15970262638743848, 3.9525356504224964, 47.79010718868625, 65.69075345993042, 59.91937014364428, 43.766128017056374, 41.39189381753245, 31.74430270348826, 41.67627742213588, 65.03579608855709, 66.367523131832, 51.731610682702836, 20.695172240657193, 9.176947878253076, 0.6413493209308194, 0.04740735936549403, 0.06717422811855232, 0.39516402468565975, 0.6955051794648172, 3.666298725912648, 10.381072375082201, 10.286787421472612, 11.051977122983626, 16.80992926320722, 21.011085817890784, 29.75986384576367, 34.01744565656109, 47.59367489045667, 55.758719905730224, 61.24579806481639, 64.00137293723323, 67.84505644152242, 61.53095045397359, 57.354340091828384, 55.57025001895044, 59.2810671560226, 63.85085982661094, 60.64948404988935, 60.996966823454834, 60.583317587452555, 60.96421111014582, 59.426932257990686, 58.36974759255686, 56.431877074703095, 51.424022336159986, 47.76210931039626, 48.44947722650344, 53.74442984980922, 58.27231591747653, 59.91211768119567, 60.05223258849114, 60.18709544212588, 62.725190577968476, 61.4888830338755, 60.75652945426203, 54.96558920029671, 51.4207197004749, 52.80376703508439, 54.97270830215947, 55.542895409368704, 59.97878620701452, 57.16267739572833, 64.60999534976098, 40.424382378978116, 38.71539785015968, 58.39007723715998, 53.720856405073604, 65.3264437183257, 58.5128709577745, 63.72000955766248, 62.782990624827725, 63.72464187683598, 51.94598782447077, 44.656643329128144, 46.62719503525765, 57.660947845828154, 57.32548321447065, 57.89399154724614, 57.17417778507356, 55.903859369216434, 54.97024505369125, 53.21290946775868, 48.155828983553, 48.44917912637034, 47.04043634476201, 46.983534520672215, 53.46201919740247, 56.43218301957654, 56.3407172695283, 60.856961742524184, 55.0429501072053, 59.8731214769425, 58.13679410565285, 59.354478236167665, 59.04457961359332, 61.92148516255041, 56.33967784143264, 52.35148637525497, 45.85346829506659, 33.73478005009313, 15.85971841889043, 24.409042942908503, 15.751407069544639, 5.903580429092531, 6.28990545388191, 10.417940693516886, 5.968339741230012, 3.1587263749491785, 2.331804450481169, 0.3706341344983347, 0.08219502130222898, 0.0549476525385774, 0.09553620501631692, 5.053643507342185, 20.824108392961566, 49.44196631831508, 54.71854655973373, 27.246718906587173, 10.537727917394331, 20.934676085748983, 36.1312383990134, 54.11672553708477, 54.34905928950156, 51.63049982440088, 20.445954645833663, 0.22668555469041873, 0.018520918674767017, 0.03634982629709187, 0.034799268168787804, 0.04353192740029866, 0.032149320242986563, 0.04317145238840773, 0.012917215335032633, 0.021709514511448723, 0.05740141300784965, 0.05371191058187716, 0.020921206206924493, 0.028254010211375934, 0.07635033734503292, 0.08399668389991408, 0.036032137295771996, 0.03953334680127521, 0.0710166416942112, 0.023489295722796552, 0.03686253064041657, 0.051384167745709426, 0.0295052022462891, 0.061880449479025226, 0.03072670454369678, 0.05192232536031835, 0.01158310960407459, 0.041191950139980164, 0.057075243413208, 0.05884785595680437, 0.022221879860866937, 0.03759345129853295, 0.021686344182178862, 0.0194182125626192, 0.035406289426910306, 0.04963901179331926, 0.02054693778195689, 0.0666476499229189, 0.04654120886698366, 0.0302137186630599, 0.08961931727225743, 0.07756918323256316, 0.06186904626027231, 0.08895020841831162, 0.008231533349551743, 0.046941351911593834, 0.012921491063260024, 0.03198154890278895, 0.032303146867742466, 0.04764382006420244, 0.01848454290490237, 0.06767301264429285, 0.05562489341583945, 5.95746644081608, 57.92367604471023, 72.3647565226401, 67.64474099682224, 52.780401475967906, 50.888108899516446, 40.823287425502656, 40.76258874708607, 63.04060797537527, 68.16524736342892, 59.445704721635394, 28.03343849797403, 8.568966773248489, 1.1067428319684922, 0.04780832978506242, 0.1839047075519639, 1.1044033833088414, 4.730164658638739, 9.354407671959171, 11.002713134211879, 18.53915322211481, 13.669174698091323, 13.000210542832653, 25.48787909169351, 26.747242327659364, 32.70102566288364, 47.20714492182578, 54.178330283011164, 61.73956563395839, 63.07887069640621, 69.50530944332, 65.48607633959863, 60.822409583676254, 59.312402971329234, 62.34414016046832, 63.79383248667564, 61.71089703036893, 61.24217771714734, 60.00926694562359, 61.950204756952104, 62.16717458540394, 60.49274221543343, 59.762224305060606, 53.62984957233552, 49.55821360311201, 51.02217551200621, 55.5176628020502, 60.797537834413596, 63.030602009065696, 62.7855440878099, 60.716246712592344, 62.14899832202543, 62.41494678681897, 62.056030304201194, 57.387197786761874, 52.74486872457689, 55.13711837030227, 57.75219394314674, 58.131612654655214, 62.239585461155066, 60.378562019717315, 65.2203945959768, 43.22799451889531, 41.759353222385535, 61.24016161887877, 56.002965896360344, 65.85191188320037, 59.814215321694654, 64.2649640575532, 63.17536100264519, 66.34877420240834, 55.21092953220491, 45.55613302415418, 48.28687144863991, 59.66108206779727, 59.48833696303829, 59.58784357193978, 58.46071912396339, 59.76147120998752, 57.13568756657263, 56.083652973175056, 51.08543549814532, 50.73790173376761, 48.62152414937174, 50.02115526506978, 54.30987481148013, 59.53655073719641, 59.0583118315666, 62.10146311790713, 54.32026517006659, 59.99167511540075, 57.422346145876, 58.219238404304754, 58.35103396446475, 62.641110650954715, 58.95861694889685, 55.072246290022335, 45.677408787512014, 35.73715786780081, 17.662672150519587, 13.539485450713867, 8.074652033467448, 12.22233001262911, 12.972205800394859, 7.415242771948538, 8.360635965101181, 5.658495541541807, 5.9976486717501, 1.1496343175249717, 0.13238612201906022, 0.11085971018239377, 0.2132115543128983, 4.4638489619378126, 21.976351699521466, 45.58464473293674, 47.4597220267019, 29.283089945393225, 16.12411460568828, 27.828306382702245, 43.04706734995688, 59.264036224734404, 62.03854437797301, 60.73777268009802, 26.716506634989095, 0.16824035454661618, 0.06760976442526426, 0.011044576606382767, 0.028159315998275435, 0.010792866927541552, 0.0267184903890255, 0.07168883788249186, 0.0357516533544948, 0.08532987607102241, 0.07103335007183975, 0.023920810067906015, 0.005443168178786554, 0.011282457440580812, 0.004652475425598002, 0.024587628318958228, 0.055359623980738466, 0.008257489366036269, 0.024789551858820265, 0.06836522671003496, 0.006026897012376257, 0.06491222328716709, 0.05120087354894608, 0.07159371274493395, 0.054019211430943785, 0.20102585335412335, 0.012614821279121023, 0.028565909503208056, 0.11181640078223522, 0.17892323614608857, 0.10281931098190047, 0.11453549963452163, 0.0987030516168283, 0.12148046205120704, 0.10094051865199882, 0.2008865326042137, 0.14249753267053636, 0.23151475846046404, 0.31298160552978516, 0.12153922099499934, 0.27003422619835027, 0.13352022326040652, 0.17168833243270076, 0.2836895902310648, 0.16861400627080472, 0.11261939116182829, 0.15221751835798064, 0.10215961734854406, 0.17760268442573088, 0.19749821764567208, 0.12476515595711048, 0.19361353899923064, 0.2466627682048467, 8.808432375231098, 71.83700946069533, 80.07943891709851, 79.86380269450527, 60.00625064296108, 56.33420221267208, 42.780569753339215, 55.75559377670289, 76.06886248434745, 74.76382717009514, 64.16331191216746, 30.558948709118752, 11.518296926252305, 1.371845780841766, 0.14605562803485703, 0.3159071727385444, 1.0984973969959444, 5.598972103288097, 15.35735301433071, 22.90511796551366, 19.156836309740623, 18.46203354097182, 29.541156407325502, 27.672009737260883, 36.549845510913485, 36.62080903207102, 52.152473157452, 55.474861898729884, 59.90923081674884, 63.63648660721318, 70.25287397446172, 66.37252807617188, 62.01346866546139, 59.670429075917895, 63.168147763898304, 66.67287180500647, 63.13596079426428, 62.297079563140876, 60.916346426933046, 63.08099662103961, 64.68475572524532, 63.716381365253085, 62.570300102233894, 55.669454605348655, 51.83887573980516, 53.74035058483001, 58.01103507318805, 63.45219796703708, 64.37984635753017, 63.12872009892618, 62.48795386283629, 62.59100629437355, 63.59762376354587, 65.19968840383714, 61.11496348534862, 54.80615661990259, 58.1070899963379, 58.8853156951166, 61.77993074540169, 64.26791367992278, 62.79047450711651, 64.99581536939068, 47.08986213130336, 48.060852712200536, 61.956260896498165, 57.432979691413145, 69.2806988377725, 61.828540678947206, 66.63033762285787, 67.794308816233, 69.02744708522674, 57.59389885010258, 47.965362610355506, 50.896808716558645, 62.55541078505978, 63.58048300589285, 61.91115363951653, 60.43285939001269, 61.6150813717996, 61.39284772257651, 58.87373685836793, 53.721499673781864, 53.916931767617505, 52.76976793043075, 51.84577518893827, 57.04725773103776, 60.70143976519185, 62.39204014501264, 64.88325119018555, 55.5775377827306, 60.54034409984466, 58.36313055407617, 59.18311772807952, 59.68857003796486, 63.257664095970895, 60.228358776338645, 57.14053953847578, 48.39967097005537, 35.85403665419548, 19.248215767645068, 32.777668776050696, 26.93586518687587, 16.334444842030926, 18.18227441080155, 26.28307688620783, 15.359478938964108, 9.723555657171435, 7.497952320883352, 1.265421336696994, 0.23230739899220007, 0.31973460929528363, 0.3813465564481674, 6.070056115427326, 26.301541443794008, 61.636893672327844, 71.75858559147005, 36.88531798701133, 17.415380439450665, 32.3392281993743, 51.58416094318513, 70.32626152038574, 70.0800778788905, 72.62844962458458, 34.78312761552873, 0.8431375543436698, 0.17691355769432363, 0.05713474929272648, 0.0939280792109428, 0.08117162742682042, 0.13469622951121102, 0.15628697741175854, 0.14324633765124506, 0.17629039113319692, 0.1723898238232059, 0.15553794260467255, 0.12775585596119204, 0.17602405300544155, 0.23633440145321433, 0.17548247480825072, 0.1350566279143095, 0.22913729651801049, 0.17630791922490444, 0.1446892182913519, 0.10039899408096269, 0.15949805026813862, 0.09247786710940062, 0.14664985179420442, 0.1712142619033975, 0.3388933957584443, 0.15309577687613427, 0.0856644266675557], [0.05305816179081317, 0.02646634404006745, 0.06910106948306484, 0.07727725776813685, 0.01794120653592531, 0.05138595656101262, 0.02313098682451152, 0.07063738220641691, 0.016456662204056498, 0.0883164085567959, 0.05427328066059178, 0.01554338101883449, 0.09245316843472182, 0.06335801858034346, 0.033305170720503215, 0.12784399437688052, 0.06203207360099881, 0.029777485216336868, 0.07820197951889808, 0.04183585853165677, 0.08636194206173382, 0.040768793814124606, 0.021907268617782864, 0.053871417748591596, 0.029680318454460754, 13.896870247779356, 58.78359686943793, 63.083322586551795, 54.73261610154183, 31.712910013814128, 23.664155429409398, 23.78114208098381, 41.88039364353303, 58.91485898725448, 73.34731809554562, 41.574903765032374, 15.728156239755693, 2.6073874821585994, 0.005509745049846149, 0.07931005675345659, 0.12911632086240477, 1.6824534943988247, 2.1262215077877045, 7.979267835617066, 6.8767655761011195, 17.36412290603884, 13.11882988099129, 17.030609653842067, 41.37304682885447, 29.339530890987767, 48.27941894531251, 61.19547797787575, 60.63124502858808, 64.87042503972208, 65.04906546685004, 63.46580074679468, 61.35427121193179, 55.68211993863506, 58.05859773389755, 62.29081161560551, 63.816629302117136, 59.84891653060914, 60.960669209880216, 59.67570466379966, 63.55554849870744, 59.77217928055794, 55.736401619449744, 50.518154867233775, 48.170620241472804, 47.43318719248618, 52.234646812562026, 54.24835243532735, 56.4166739679152, 61.12731895139141, 59.81586271716703, 59.080653652068115, 63.04883318562662, 60.508761175217174, 61.817310933143865, 53.61634092946207, 49.79723107430243, 48.522527448592655, 53.930428643380445, 53.63532912346625, 60.38859936498827, 57.714719618520434, 65.71029863049908, 36.26731718740156, 36.57777278654037, 58.04481452511203, 55.59977369923746, 62.99454366007159, 58.58080640915902, 60.14295701057681, 57.47263877622543, 57.0866540170485, 47.422977262927645, 46.69406752432547, 46.20954105930944, 57.4844607999248, 58.31097087552471, 58.41837713795324, 53.94623187280471, 60.18792306223224, 58.980354724391816, 57.771393945140225, 53.762268789352916, 50.98184177952429, 47.20486602475567, 45.15926761011924, 48.318968203759965, 53.78146486897623, 53.85309519306306, 60.431333588015654, 57.93128152047434, 56.69204788823282, 58.50336705484698, 60.28664519709926, 52.12750727130521, 56.35042905807496, 58.63146774230465, 66.36301240613385, 54.0732382189843, 47.72169713051089, 29.898486291208577, 26.860798866518085, 8.679794323059822, 1.4625269342814724, 17.468479525658395, 4.851468859180327, 7.806639421370722, 3.7853022112000376, 5.456698911805307, 1.551636320448691, 0.08356891572475435, 0.016420581378042698, 0.026838808327973373, 0.23651152098130798, 7.450702959491362, 30.23039725518996, 46.0920346936872, 40.65885382313883, 31.468242368390484, 18.987713513835786, 29.97772012987445, 51.3842926486846, 53.360316061204486, 49.75556765833209, 29.748173221465084, 1.627878248691559, 0.01019783590304395, 0.0396210945121223, 0.03821581729777879, 0.09985173917225293, 0.05668257355629917, 0.07564638681229084, 0.052984249627878593, 0.016325919723678983, 0.018089837169334776, 0.1697663863700244, 0.03405552319881897, 0.03366913526288925, 0.04647961156743188, 0.031233446807750774, 0.032843227363041336, 0.03200755950303809, 0.11686374042784015, 0.04853263910439226, 0.03706829036555944, 0.043173107138324174, 0.08832522622880437, 0.0406640581035566, 0.03887062329017828, 0.04747713465363749, 0.05057267379015685, 0.05998962956871237, 0.07475617732251845, 0.04522032006793926, 0.105022166164652, 0.10800337433935174, 0.04713100846856833, 0.07029239749235493, 0.08526833622806496, 0.03816518654686309, 0.03249277278119999, 0.04276624550261805, 0.013123267131196636, 0.013658813343593671, 0.021341236894048994, 0.1033522094029092, 0.021871622546666095, 0.08283577724209717, 0.15472480156008275, 0.0650003846854933, 0.014317752380344658, 0.05608350046039109, 0.11046878317551267, 0.047538130574168704, 0.017934631586315173, 0.030652294423611417, 0.07206856468391996, 18.35304460217876, 69.0090041006765, 69.8813392269996, 62.35148675980107, 41.06980446846255, 35.496834247343, 29.413979438043413, 39.840639560453354, 65.22547406534996, 74.04424482776274, 46.72136329835462, 17.23600260673031, 2.7117517013703627, 0.1158380023233833, 0.1579077283461248, 0.44201082219519927, 2.7764340369932117, 7.03657421373552, 10.242510726374965, 9.818454461712992, 17.003153062635853, 11.928494476502943, 20.187437111331572, 28.176420657865464, 31.132265867725497, 46.28458776781636, 59.581552090183386, 61.25201109916934, 64.56033814337947, 66.0208091428203, 67.11291466989826, 62.59221438438662, 59.01960980507636, 59.83364674352831, 64.55844363858624, 65.36353365067514, 61.476256924290816, 60.90947051202098, 60.49919843673707, 64.31494289828886, 60.91155721295265, 58.199038197917325, 52.80379841404577, 50.23375949551983, 49.18121891637003, 51.875679339132006, 56.46904153208579, 59.12357222649359, 63.597380576595185, 62.71184667464226, 59.11369177602953, 62.87735892880348, 62.574081267080004, 63.813114858442745, 55.732392957133634, 51.587973486992624, 52.08022702124811, 55.63483184383762, 56.57456505683161, 61.62852333438013, 60.31292507725378, 66.38693101944463, 38.64274770982804, 41.25589739891791, 60.980955708411436, 56.05524324601697, 63.75601691584434, 60.08983242896296, 63.196600637128284, 60.30930472958473, 58.05793877570861, 48.353500750757036, 47.91080636362876, 47.32704001088297, 60.159470189002256, 59.15166816403789, 60.484246361640196, 56.143206319501324, 61.30033862206244, 60.4470544476663, 59.38122880074286, 54.69871897851267, 52.1571917687693, 48.8051655984694, 46.713220457876886, 49.7617297018728, 55.97193994829732, 56.90163973839053, 62.46513743554393, 58.10471304001347, 56.31962668511176, 59.6184733606154, 60.64240417172832, 54.31036903012184, 57.785208532887125, 58.29112760482296, 63.80248131290559, 56.207152720420595, 46.29034188485915, 30.878355156990793, 19.241322202067224, 13.79399432289985, 11.48361042622597, 14.776019511684297, 13.614873405425781, 8.170615271214517, 10.841004598525263, 8.121672426500629, 3.4793007085400247, 0.36931324569929036, 0.16462719278229823, 0.019509773476109393, 0.35942164099504875, 7.549982561219124, 32.01237120935994, 44.19190914400163, 32.338271141052246, 28.618505116431947, 24.82445332311815, 35.93376667268815, 57.86761753020748, 61.56027409338183, 57.576495293648016, 37.61314907381612, 2.7137994237484473, 0.02491802671894191, 0.02019275426714411, 0.022669462900188182, 0.034946900972675894, 0.038171817037847736, 0.08674350747418019, 0.02314600214782742, 0.06474806596675227, 0.05803438166396753, 0.08519312937653835, 0.04285418856588583, 0.03083626660818775, 0.0314957725500027, 0.06711016018544474, 0.02640013680643132, 0.03307462422057025, 0.032069013161104054, 0.07696290891016684, 0.03809305553835246, 0.01595602374553921, 0.12645506164840153, 0.03229771913479894, 0.03598571619800022, 0.1203415650994547, 0.029614009714174657, 0.03268324905225346, 0.2079584740943486, 0.10971696746926154, 0.22352841442390797, 0.2406836511386979, 0.17240160625548134, 0.1399054588569749, 0.20212335091444755, 0.14483724180008137, 0.1427448258524941, 0.25732326471517164, 0.14287715988053432, 0.14782578143621647, 0.09972803895511936, 0.21403960342849457, 0.2563493371370339, 0.29495169558832723, 0.3715374134480954, 0.11647037726135985, 0.19149430997429356, 0.159151089047232, 0.30721014425639187, 0.15304622630919182, 0.1384343095724621, 0.11869813796252975, 0.27308101916024763, 25.337032579606582, 79.88878819250291, 77.57786889230051, 72.705351614183, 45.602581731734745, 37.816986806931034, 34.66282067760345, 55.41157445599956, 69.48168108540197, 82.35849288202103, 52.74251530247351, 20.338385605042983, 3.419039864693919, 0.1790650543426314, 0.3110275297395645, 0.35144948490685035, 4.40571012035493, 8.616443141814202, 18.47125111087676, 14.878062913494727, 28.566408195803245, 24.00782762035247, 25.485449183371763, 51.88965474405597, 33.811893847680864, 51.20345961663031, 64.85027190177672, 61.362461120851584, 64.7716832930042, 65.0599814230396, 68.58750620195943, 64.44775435232347, 60.64978607239262, 62.878261073943115, 67.06078637030818, 66.74901285479146, 60.95587607352965, 61.50074035890641, 59.96615225268949, 68.01578937038299, 63.06210256391957, 60.00312843630391, 56.66759191020843, 52.77081128089659, 52.29682814690375, 56.57627128785657, 59.2876841945033, 60.70538174721503, 66.52644188173356, 62.670583340429495, 59.80674712888656, 63.83565279745287, 65.30507072325676, 66.4076489786948, 57.667098122258345, 53.7100032068068, 53.263049125671394, 58.54634838719522, 58.12130858821254, 63.332753950549716, 64.54477025616553, 65.14127646723102, 41.47709162004533, 46.76461135187457, 62.669261501681426, 57.6083763184086, 65.09149374500399, 63.16335070517756, 65.57902082320183, 63.78283808308264, 60.71143396439091, 51.60130170083816, 50.47125508708339, 51.09863427377517, 62.617184192903586, 61.73839676764704, 62.39334237190985, 56.82453770791331, 63.14585301183886, 63.34349340008151, 62.959132502155924, 57.55760908126832, 55.67524010135282, 51.66813104383407, 49.421581760529556, 52.55388459851665, 59.15961096363684, 58.52155116296584, 66.57978611607706, 58.14272080698321, 55.805082321167, 59.34216591619677, 61.241083375869266, 53.296048025931086, 59.28745277466313, 59.36628457038634, 67.23308824723767, 55.306243127392186, 55.01433641679826, 34.834141961989864, 31.70417097307021, 15.645420705118488, 8.720125113764118, 33.61605774971747, 16.918659325568907, 17.57509150812703, 14.095281381760875, 14.034592509269716, 3.3360976701782596, 0.7369350918358373, 0.21514232570846237, 0.23831388071900417, 0.4640648081418007, 9.805332172301508, 38.45934944768106, 59.54587028872583, 51.92880392074586, 43.81554988122756, 28.00619959831238, 42.72370715295115, 65.80121132635301, 68.73513637050506, 66.33357109562044, 46.210509884742, 4.98628709585436, 0.19989504629085142, 0.12955662223600573, 0.14689215008289586, 0.21098314243699276, 0.10129398395938259, 0.2178202626565772, 0.12043500484357919, 0.1310810912400484, 0.11602542573405851, 0.20353066975310927, 0.14682015313977195, 0.1389777417024297, 0.2460480132891286, 0.1409601627458488, 0.08751116587870544, 0.07769574861853354, 0.1825743345844169, 0.14692950453008377, 0.17152247439709403, 0.1443422264269283, 0.24029711381562296, 0.09587663916810867, 0.14118649576219822, 0.30709464884092735, 0.09758572004014447, 0.15346749805875365], [0.024509690363981554, 0.014581206187065092, 0.026908319315782962, 0.006675063895301954, 0.06933933048839531, 0.050827815542898835, 0.059212260999746864, 0.035665342058505745, 0.054074852396884275, 0.029646373098535888, 0.1269118339123745, 0.015153710396149227, 0.03027031340846612, 0.04394464960862552, 0.052404409169309565, 0.06034317148488857, 0.024317542106033336, 0.05717849674364252, 0.10290965573081087, 0.046845326620724895, 0.05936955034192051, 0.038264839264053496, 0.03362774736278, 0.027104395689562927, 0.5932035140933529, 32.5761079788208, 67.75882705565422, 63.00242762411795, 51.450392430828465, 49.76820161265712, 26.11702922851809, 40.51866439081008, 48.50487678281723, 47.462455918712, 64.40445530799128, 25.30449259665705, 10.255790891185885, 0.2239669231517661, 0.2245067393467311, 0.0238787307734451, 1.2999524128052498, 1.1012357016724925, 8.003886592003608, 6.45451948527367, 8.72275016000194, 26.94107213327962, 17.02773259532067, 23.271820352923488, 48.13069835785897, 54.02872716226886, 58.13735892695766, 61.34424955614152, 63.0967959280937, 63.26262981660905, 65.16519900291198, 62.54244735164028, 58.5665132922511, 53.755730198275664, 58.10728219247634, 59.838867418227665, 60.58955807839671, 59.23703855083835, 60.01683319768598, 59.215791071614916, 60.22253797900293, 54.01843878530688, 50.530298525287265, 47.23140870371173, 49.13145580599385, 50.54829828200802, 55.303054240442094, 56.6034846921121, 60.6150064160747, 58.53845657840852, 57.95403518984395, 57.834661776019686, 61.31634189236549, 59.257776121939386, 60.41867217709942, 50.5689024925232, 47.65180049404022, 48.24675736888763, 52.85452642748433, 55.9891003178012, 60.091350386219645, 56.44205170293009, 66.9625545317127, 37.676962114149525, 34.336444177935206, 58.456812443271765, 52.253799746113444, 64.94780555848153, 57.604877564214895, 59.238646722609005, 55.26972193871775, 54.05977664455291, 48.85075530698223, 43.97381751768051, 41.51533080685524, 52.1725360808834, 56.76099138875162, 55.881611685599054, 54.65618479636408, 57.64122224623158, 59.357459237498624, 58.75498317903089, 54.52243589585828, 52.14380471937118, 46.66650895149478, 42.049086939904, 43.345881354424264, 49.75203752517701, 54.72160600846814, 57.45488220645536, 53.69846751613002, 56.09879724441036, 54.61332113512101, 52.82081757822345, 59.11770436071581, 58.79445006770473, 58.48864247722011, 56.6224846532268, 60.28654321547478, 58.59131443885065, 43.76249590227681, 25.880931961920957, 17.53680721406014, 32.853411705263206, 11.334373066502234, 7.224564590761739, 7.335280843319432, 4.273134008530648, 4.929117570000311, 1.9591995088323473, 0.7791820216563441, 0.05642099283455361, 0.035327956936652624, 0.10034658600606265, 1.8171647239115931, 11.119657620306938, 44.69031687705748, 51.266990246311316, 37.17086261318576, 17.66903031256891, 27.78627230275062, 50.53429934286302, 50.11910469301286, 59.98470898597472, 44.006216295303844, 6.988073125962289, 0.11957168503994904, 0.04440149465095132, 0.0537981107951172, 0.020951953145765492, 0.05092694732030073, 0.047423711512237794, 0.07014605937705887, 0.00820007299133126, 0.0701472468133415, 0.0685831327592173, 0.04121333931482608, 0.01909771393383703, 0.03959811187439388, 0.022942364486234806, 0.03717392239899885, 0.014106337968710692, 0.0525903310476532, 0.08226321844924843, 0.03766383562657622, 0.013585237301735869, 0.0649354357512728, 0.05604261817831186, 0.05103475121300548, 0.034679325612922834, 0.03275185988675202, 0.03283480805675349, 0.012204344666022207, 0.047234598877689535, 0.07663650182826866, 0.037221182363047715, 0.0848112651898015, 0.029194848536844217, 0.022229161526587222, 0.025642435629701903, 0.02199234459699402, 0.06411721554374503, 0.08107085622126058, 0.017518954193820397, 0.07149844971154967, 0.08733108925122408, 0.049781423708003376, 0.06938171813324576, 0.06346759596659292, 0.047915842564355944, 0.09241663370161288, 0.038890112566971974, 0.029557351766514684, 0.0827593599716502, 0.026433344802729068, 0.04944902581853732, 1.2753036257720765, 41.12389787550896, 75.82423994618078, 67.54463426528439, 60.26397389750327, 54.40543551598826, 35.80945107244676, 36.051155367205226, 41.22394577149422, 54.501588498392415, 69.327806503542, 29.92785699905888, 8.752067915854916, 0.6099385515816751, 0.18768427893519404, 0.03572213215633266, 1.3612278022112385, 4.516642593568371, 7.9933207073519315, 12.719639482036715, 13.349999670059452, 20.98750452841482, 11.564596583766322, 19.176767833771247, 37.91178657162575, 48.457310199737556, 59.77510144633632, 60.89549902946719, 64.80840060018724, 61.85804474738337, 66.21178150177002, 63.721154889752796, 61.070472040484034, 56.329256103884795, 60.66229451087214, 62.92725932213568, 61.81874652062694, 58.79668581870295, 61.41175354680708, 60.38161754608155, 61.83356523513795, 56.52692394871866, 54.45066044407507, 48.2199126674283, 50.24615810763452, 51.844696537140884, 56.973497559947354, 57.86719783659905, 62.671885567326704, 60.90312411708217, 59.76917474500595, 59.30156154017295, 61.152751599588704, 61.15136700291788, 63.16242894818706, 52.352604250754084, 48.66407794337119, 49.37341505481351, 53.74067221918414, 57.005927716532064, 61.818907337804, 57.81171198814147, 66.70625901991322, 39.17245987922915, 37.44741716692525, 60.79259564799648, 54.97723471733832, 66.41635664047735, 59.34835541632868, 60.01148700714112, 58.1852275325406, 56.537722233803045, 49.29042946907782, 46.039392563604544, 44.225610148522165, 54.51137873434252, 60.064376246544626, 58.34707629296088, 55.20017047082224, 58.42655527976252, 60.96693323504541, 60.72042011445569, 58.22530631096133, 53.65281112732426, 48.50222918295091, 45.84112851850448, 46.52166366577149, 52.569570156835745, 56.87261027674521, 60.04784345626832, 55.806141361113525, 56.41482653156404, 55.13939334500221, 53.34293996134112, 59.69767778150497, 58.158194557313, 58.74378088981875, 58.94959941987069, 62.77003895851874, 58.27228453851516, 45.29616225150324, 27.19987992317446, 23.37117006701808, 23.6584170018473, 14.03066425554214, 10.682818351253387, 11.031142473220827, 13.506646387038694, 9.321369547997753, 5.3581125890055015, 2.1018368678708232, 0.6184024135431936, 0.1445424971320937, 0.09254697590104996, 2.0484646866398473, 13.280270714913646, 43.894722923155754, 47.00360528884396, 36.30053181802073, 22.51996082644309, 33.59263727741857, 56.918333345843905, 55.867204819956136, 65.41836054094377, 51.88255525404408, 9.841918080083786, 0.1020634962966846, 0.02285360745454748, 0.05437404420527239, 0.044525895838535605, 0.01041436778201211, 0.031187561971525994, 0.10669039922856516, 0.01130193618366555, 0.07900870074668238, 0.049390994658273076, 0.06762918475414477, 0.04341089316914159, 0.03565592300747672, 0.04331844167843942, 0.02912829847886197, 0.008639850552313992, 0.030169869705493894, 0.03957967596849607, 0.08870652351047724, 0.009800381827047996, 0.009068662522270555, 0.022922034427944212, 0.029638932469571312, 0.020179629265781374, 0.04294983847367187, 0.024115174235175216, 0.1052938822296358, 0.10888734021254125, 0.10494638474718218, 0.05617200659828321, 0.16152957754750408, 0.11907033411966217, 0.14156664391198467, 0.14163638855661118, 0.13634607646494143, 0.08386625743080532, 0.17519125414471473, 0.11163852282709653, 0.119605538465323, 0.23961175623680317, 0.1647315799228607, 0.11367744285493128, 0.09862903220158431, 0.12442676726007655, 0.28048535087896936, 0.14370439694293086, 0.10025562838681283, 0.1484701226675703, 0.13047937514080157, 0.1701585161349466, 2.119004101522507, 50.26015704677951, 86.68131351470949, 79.02946749041158, 66.26268602186634, 62.427263029160045, 37.906946366833104, 55.171443031680205, 62.61863154749717, 58.37524283316828, 75.84476963166269, 31.48195105214273, 12.696068979078724, 0.5348099635974054, 0.5807727875728762, 0.17635975273386126, 2.7276637765669056, 5.781450079333398, 18.343750546055457, 19.77252487213381, 18.13399003398034, 36.546833130621145, 28.79742599302723, 28.391835266543975, 52.10083907650363, 57.33227283723893, 62.022599943222545, 60.97752755688083, 63.7155851241081, 61.51264867474956, 67.54336341734856, 67.17100497215026, 62.81118069925616, 57.674942862602975, 62.577878121406805, 64.820732532009, 63.17664754006171, 60.21394014358521, 61.924905469340665, 63.395190238952644, 65.14096267761724, 59.52652515903596, 56.16546577022922, 51.443559661988296, 53.51204902895036, 55.306121533916844, 59.68557726952338, 61.59676390309488, 64.90878582000732, 62.18431142068679, 59.19255887308429, 60.4819086290175, 59.4563578790234, 61.667998067794315, 65.42192989780058, 56.020773456942656, 51.14531047882573, 52.77816180259951, 56.68091227931362, 61.52268994239069, 64.53756093978882, 62.07733661897721, 65.67081605234455, 41.01442844636979, 43.132402435425796, 62.67514113456973, 56.730926421380815, 67.80535421063824, 62.80187291483726, 62.6654528802441, 59.63451585462017, 58.58123002513763, 53.356825151751124, 48.08495175453925, 45.82140684127808, 57.74918548522457, 62.373424576174834, 61.731630679099794, 57.61722518551735, 59.05791174980902, 62.00497673403833, 63.70184506139448, 59.275195367874645, 56.28594137007191, 50.96214363651892, 47.49288174413866, 47.61394569950719, 55.40665972617365, 59.25786241408318, 62.12030226184476, 54.71205503709855, 55.91725426335489, 55.83071893261325, 57.343000519660215, 60.879374165688795, 58.982551251688314, 57.796265694402884, 59.97072573631041, 64.88024665463355, 64.06073800979122, 48.54846216017201, 32.15624963083575, 22.202623428836947, 46.9673704331921, 19.389723116351714, 15.469731861545196, 19.980212411572857, 12.537091393624584, 16.492325144429362, 7.365107526702266, 2.536989517750279, 0.7814611638745954, 0.31742041089361717, 0.27506892539320454, 2.667186712065051, 15.801425133982013, 57.75318630280034, 65.00941030440792, 49.427755571180775, 27.11469977132736, 39.22950290864514, 61.40463052257415, 66.24400769510578, 73.71340074846822, 61.63059826820128, 13.981991564073871, 0.6566406810475934, 0.16368822945702463, 0.23059706173596844, 0.10405581519608537, 0.17486480875842034, 0.2759349111828112, 0.2613320496053465, 0.17663010516233985, 0.21123146217676902, 0.26504245857077263, 0.14830481621526903, 0.1347076135777658, 0.1355927209219625, 0.19191147549258125, 0.17681894583567498, 0.12214027825863132, 0.12417839389414558, 0.14584394261961983, 0.12733351934941547, 0.13656280273872037, 0.174960493140163, 0.09314263224481575, 0.158772565003845, 0.0769101407739424, 0.15581157388946704, 0.1316933180656164], [0.040010791947884906, 0.03370222260033892, 0.07233733897127452, 0.04576775500731123, 0.05334122361795557, 0.03343054483975134, 0.03048125954885637, 0.018126145906506047, 0.05819953106824429, 0.06975007618987752, 0.032063932082946264, 0.05973695461908656, 0.08160408406007676, 0.043930595725654595, 0.05303399171680213, 0.012713714611656483, 0.029142637729584694, 0.06587840571639038, 0.06916111545456995, 0.00954245055665172, 0.04553603256241449, 0.1205011718575993, 0.08685474344078573, 0.06018142351099561, 3.361260900574346, 49.64912237659578, 62.701730881967855, 61.51416663200625, 50.92302583879041, 34.23978128740865, 21.523557209199478, 51.54314471829323, 59.34321711140295, 72.95434367272162, 37.946181835666785, 14.520471211402649, 2.8207178413867955, 0.14995043436365743, 0.08243320569876703, 0.2943272113559708, 0.6265961835461279, 4.494060037597533, 5.867760854382669, 8.903889136929667, 9.098591669913262, 16.237681931064976, 12.266996983558903, 37.15077615553333, 45.673749216141246, 52.758385212190696, 63.31643296826271, 62.08733866291662, 63.6926039572685, 61.05515518496114, 63.77513062569403, 59.66132917711812, 57.90003591968168, 55.026950759272424, 62.3081131904356, 60.01102808983096, 59.8118148311492, 60.89116873279695, 62.28033888724543, 57.943860561616965, 58.15684526197372, 50.58789068652738, 50.12374093455654, 46.94529925623248, 51.159042696799006, 52.29677323372134, 57.77254319960072, 57.331111815667924, 61.46151273481308, 58.679960004745, 59.05850795007522, 60.637410994498964, 64.89573217207386, 59.66725980081866, 60.026831319255216, 46.633262941914225, 46.30716100815804, 46.19052148634388, 51.88392416123421, 53.60345594344601, 58.01654208090998, 55.53166566356536, 64.4193995383478, 40.9232529517143, 30.52569877716803, 58.026014604876124, 57.36926863270422, 62.04875822990172, 55.85948559545702, 58.03278461579354, 56.82896606383785, 59.728225200406975, 59.41886786491641, 51.196607235939275, 41.427073555607954, 46.280461434395086, 55.537239351580226, 56.6357030407075, 56.45330890532463, 55.465801223631836, 57.860961268025065, 59.30683320568454, 57.47066974639893, 53.71266257378363, 48.07012911765806, 44.15849839487384, 45.17259582396477, 49.059233204011, 54.015806874921246, 58.531866996519035, 59.0032535214578, 55.79903794873146, 58.32824499376359, 60.34513950347901, 59.02830177737821, 58.096578044276086, 60.090460008190526, 57.16217533234627, 59.31611745588241, 56.05164643256895, 58.39085778882427, 41.22768379026844, 47.67629569576633, 29.77965024209792, 16.85088861373163, 16.30833068201619, 5.543720616448311, 16.847876233439294, 8.336719312975484, 6.0530134170286125, 0.8849533298803914, 0.33865247642801655, 0.05117743508890272, 0.04202598240226508, 0.11115222553452177, 5.30857305372915, 22.1896658789727, 52.973287951561716, 40.59908866882324, 21.44137570934911, 21.886552956796464, 38.31341374304987, 45.9191523059722, 50.18505150272001, 46.735421073052194, 13.005817570993978, 0.5610628161699541, 0.016208131790101048, 0.06508669981192197, 0.0494814160159759, 0.027826249697095448, 0.021249392528026816, 0.057580742699604844, 0.026583465477151257, 0.058600781109905055, 0.02873608635948791, 0.031883194704630205, 0.07943018700086302, 0.055003871900900725, 0.031426041311914885, 0.020383343536166415, 0.003119346515778753, 0.004636026081448842, 0.11007449304264401, 0.0694119019974624, 0.027746651246542894, 0.013492515765040392, 0.01609576967424683, 0.03992590557543501, 0.029516630362899556, 0.03587404739171748, 0.08112141036338384, 0.005873706719402465, 0.0616137589508247, 0.08313229923406917, 0.014661023930285969, 0.023272284081265814, 0.08105632353333697, 0.036177176892036395, 0.08799669708335593, 0.03607762759671577, 0.022406386391770457, 0.07364788558334112, 0.004371768840017819, 0.03659969736491481, 0.02941266265547564, 0.05528493040812112, 0.03367797974797507, 0.042307278396742004, 0.04574381859011708, 0.030865588623489586, 0.031230474386604565, 0.012375889946856808, 0.08363496016470656, 0.02893359340246647, 0.11307535903348077, 4.85832320105645, 58.66100318970219, 71.99413176505797, 67.66543542185138, 57.893462027272875, 44.98506730602634, 24.904908980092696, 40.46653609122, 62.54807595283755, 72.70153122563516, 47.23837091076759, 15.479047490704446, 2.932251172681009, 0.0775596147943889, 0.012829902379082577, 0.9513121723167358, 3.772454732848752, 7.367078027417583, 15.220734900043858, 9.146630898598703, 13.641290568536329, 16.076770617115884, 13.341109618063896, 25.497912514594297, 43.21297968587568, 55.24613672687162, 63.378484864388746, 63.45244507635794, 64.48220452954693, 63.4864128020502, 63.67899725514074, 62.9627057813829, 60.362268494021514, 56.391547264591345, 62.637353020329634, 60.58594949783818, 60.28028703504994, 60.02836888836276, 63.22117428625784, 61.63015896274198, 58.5461248120954, 52.03271927372102, 50.73106504255726, 48.82433422150151, 52.89383642135128, 55.62030730708953, 59.85911077068698, 58.47018772555936, 62.810262864635845, 59.261078757624475, 59.80933981557047, 61.49062064386184, 65.8214193774808, 59.82759060398225, 62.970221042633064, 49.295646221407004, 48.55010171090403, 48.918722137328125, 52.3515255989567, 54.726540350144916, 61.254348831792036, 56.92176541974468, 64.12419411443895, 42.62882109611265, 33.40652081274217, 60.36673607364778, 58.810331744532434, 63.17113268759943, 58.30315751414145, 59.51743310497653, 59.58834955769201, 61.380555014456476, 61.175101264830566, 51.72775499282345, 44.4681106844256, 48.54883478533838, 57.70003034222511, 59.384943285296046, 57.168411900920255, 56.49738850132112, 60.053699554935584, 60.58904817027431, 59.02444608749882, 55.56681794504966, 50.03528756480063, 45.21059966856434, 46.28831401948006, 52.20635867887928, 57.127709465642134, 58.92329600549514, 59.63748901121078, 55.42500857383975, 59.95618943245181, 61.2234248653535, 60.60780102206815, 59.84477843007734, 59.28495814723354, 55.95454815895327, 59.520975005242136, 56.90121612241192, 55.16571244885845, 39.410677186904415, 36.29482084704984, 23.18203533849409, 12.0823053198476, 17.997295433475127, 13.329098340003723, 11.342041300189111, 7.705310871524196, 7.221280096038696, 3.4136093431903474, 0.6995797253424122, 0.08952883462752066, 0.03181342899258579, 0.245107471822731, 5.476062672753488, 26.292853393862327, 46.63589877467002, 39.26930319878363, 22.988248678945727, 27.75043752885634, 44.83248318395307, 52.283711741047526, 58.63906537332843, 55.818108512509255, 17.70732637374632, 0.6219764282145809, 0.015211757835781863, 0.04554609129686029, 0.043992913147855195, 0.049960672960526524, 0.012499317245167351, 0.030195190826611176, 0.05549772665084851, 0.03165015841894333, 0.051853591951751904, 0.037494522534430995, 0.055236241690093474, 0.0303830087725674, 0.03015890124163801, 0.03167037356404528, 0.04428637844900932, 0.028727226552643606, 0.07938882591383112, 0.038219793294105804, 0.038024724325946266, 0.0060500419649836285, 0.019578707982755957, 0.017131826983043746, 0.05470366502601293, 0.08664493494096302, 0.016953278700971318, 0.23989520876878695, 0.15897637503522058, 0.13081694412375652, 0.1712382404554275, 0.10199249526786228, 0.1652487965240594, 0.09786024764781037, 0.1398182474076748, 0.2272518009187714, 0.15138626699486088, 0.17487839915819708, 0.09654590890051858, 0.2270464127462718, 0.10545819276763548, 0.08756938090007152, 0.09039297414522979, 0.08974868654003067, 0.20145968894564337, 0.1724659423193624, 0.07915680086420429, 0.11719653668302683, 0.18849389597533212, 0.2650997619475088, 0.16896078363060954, 7.55195600371207, 72.95884655367944, 78.78278963027462, 76.73014271643855, 64.98953957711497, 47.350472250292384, 30.725318001162623, 65.60549682186496, 67.60391696806877, 81.71885628854075, 45.04813509602701, 20.02714945423988, 3.076189655450083, 0.2708241854223513, 0.21239848987710094, 0.8671588847233404, 3.0887324146686064, 11.425116119846223, 17.04834661176128, 20.196440912062123, 25.134842241964034, 32.67683444484588, 17.523661390427623, 41.976593694379254, 50.56394461662539, 58.13775508634506, 66.51603975603658, 64.75474649860014, 63.30119063777309, 63.04968433995401, 64.97786268111199, 65.92287540435791, 62.01431589741861, 59.05706059548163, 65.97618825974004, 63.15496860011932, 62.174995791527536, 61.68553890720491, 64.35161705940001, 63.103660075895256, 62.3110039772526, 54.20504554625481, 55.03638405953684, 52.31868359350389, 54.73675420207363, 58.37971825753489, 62.935543367939616, 61.38839583243094, 65.47158710418209, 60.63856024895946, 60.87409857780703, 61.78408845778435, 67.00853255487257, 61.70952420080862, 64.22849778206118, 50.96784676274946, 49.490242850395944, 51.59502590856245, 55.86349425777313, 57.61772332652923, 63.75528735499229, 60.35227037245228, 63.31708015934114, 44.22561799326251, 38.597232526348485, 60.78218567755915, 60.72208319940875, 64.98237732918032, 61.10360430132959, 62.437390588944965, 62.47383333021595, 65.12353558694163, 64.40338057856407, 53.82153580265661, 47.14422225952149, 51.560352156239176, 59.81775329959009, 61.93080863645, 59.33175986812961, 56.432018280029304, 61.74804187590077, 64.31832398137739, 62.13647027169505, 58.21668886369275, 52.53962286057011, 47.796657546874016, 49.106313413189305, 54.22115472055251, 60.25948278365597, 61.7908820029228, 61.14339282435756, 56.25374263332736, 61.845034245521795, 64.24471678272371, 62.8741112063008, 62.02933465280841, 62.46697310478457, 57.79251590851815, 60.35139960627402, 59.44385336291406, 62.65080675002068, 43.82505378415508, 60.32886951200424, 39.0608488359759, 23.519365056868523, 30.88315417689662, 15.173985150552566, 32.457522961401175, 18.46093527732357, 14.10592963618617, 4.069558093624731, 0.9377604446584179, 0.26024417410935125, 0.25262841744528663, 0.4055654455817515, 6.947460905198128, 29.444901443296864, 66.34722878856044, 55.401140951341205, 29.825959705537368, 33.352050858159224, 52.27306642839986, 61.29480808011947, 66.6047167008923, 64.27580941107966, 25.818099514130626, 1.3357824063108814, 0.14063206260963795, 0.24390744105462106, 0.11623216222130484, 0.18313806804437793, 0.07866839682983776, 0.2706050842760071, 0.14016102578851486, 0.16232992492375836, 0.09417472121816489, 0.1883798101616483, 0.22404553909455577, 0.13715564753980408, 0.13578572911360573, 0.0959344175193579, 0.09156079091612371, 0.20079523024539794, 0.2339600038624579, 0.11628693750789089, 0.16217594125097798, 0.09134462388652949, 0.17985683685589224, 0.0952585977351954, 0.13376638263223634, 0.21049974095677176, 0.10666961526317943], [0.08329231967969287, 0.01527619636392281, 0.052301209465029745, 0.09451908540100822, 0.004128329080319212, 0.045469865548394384, 0.10059907326414701, 0.02548886564440064, 0.030201331021324284, 0.024704393525157246, 0.11411060428907795, 0.05577812249201441, 0.05538233082681414, 0.0380956027807007, 0.03913213506401066, 0.019210403552278876, 0.07076497415020581, 0.11107822910191552, 0.02407809174920042, 0.11807542339327837, 0.02983438448169299, 0.008633537030208015, 0.017972143081527565, 0.8542995779745041, 18.52239097318342, 53.569139126808416, 59.68311402105517, 57.32311410288657, 40.38426437685567, 21.060739101902133, 41.50887850792178, 64.91486549377441, 61.04702411159393, 57.001601342232, 18.67492018207427, 9.16249394416809, 0.23209108640590023, 0.1568689744078344, 0.021662649082680865, 0.541371169590181, 2.5008323740574623, 5.649295132006369, 8.647938793705357, 8.931353572876223, 13.542532151745213, 18.601595394072994, 20.00706691895762, 32.097263066999375, 52.98139156833772, 63.53351654544954, 62.9972344060098, 65.06276238349177, 62.09238675332839, 64.01534049741684, 63.29345180142311, 58.34043572025915, 53.37842172191989, 54.48842502409413, 59.547611821082334, 59.172805816896506, 62.17915742628036, 59.84214259732155, 59.12407036750548, 57.99743229343046, 52.676894049490656, 47.97382316281719, 48.83467751164591, 48.6738250332494, 55.43381037250642, 57.443499488215295, 61.017449440494666, 59.333403341231815, 58.48090364087013, 55.25294596149076, 56.19250659019717, 59.82413107349027, 62.07064113309307, 58.3890966446169, 52.26195435370169, 43.1867939426053, 46.981055582723315, 46.11217606452204, 48.604877610360425, 51.67144544662968, 58.78888814680038, 56.46322857949042, 64.27195764357045, 41.71877238058275, 30.53991148548742, 57.75851288149434, 54.13754155558925, 62.080094045208355, 55.99956127905077, 60.25764711441533, 58.92290376847791, 60.93926483584989, 56.813876705784956, 58.03614608703121, 46.700708097027196, 41.39653005907613, 49.80428741824243, 57.05222737404608, 56.960086976328206, 53.35126715321695, 54.10244810965754, 57.990321036308046, 58.39261893303164, 56.859486026148645, 50.12237987210674, 45.74480295181275, 43.95435079451531, 47.871515981612674, 52.05070726333126, 56.93004162080827, 55.12443734753517, 57.233342816752774, 57.640084758881606, 58.298446747564505, 57.032737116659845, 58.0131531530811, 61.249253672938195, 59.276854530457534, 57.95968340289209, 56.61872702260172, 57.356124770256784, 48.60839597640499, 42.076139526982466, 32.87536913348783, 22.15080891886065, 11.328411063840313, 11.622024005459203, 14.032572488630972, 4.7599261326174584, 4.867735418581194, 3.6992596282112986, 1.0882836676413015, 0.04776163289563791, 0.048680769865431135, 0.08001298072838015, 0.7244240180138619, 11.57202555287269, 41.46300638875654, 43.08558502504903, 25.28507882548917, 14.304305468836139, 22.460631055216638, 40.00901122247019, 50.119979381561286, 47.36340822712068, 32.687562127267164, 2.5374624085041786, 0.1383066640025185, 0.08383687029802993, 0.0032729232043493543, 0.015595773771976032, 0.11265657706967286, 0.06783356935146355, 0.07738082519462032, 0.031860091408053716, 0.08264016435151139, 0.04310636555836086, 0.0437622900391298, 0.02212844394718207, 0.052277506704652504, 0.047652967154018344, 0.060190007526187174, 0.046880911404807726, 0.03135768328643134, 0.028603819364141074, 0.056912292681273915, 0.015780153898372045, 0.038320679412854296, 0.07666327660122225, 0.014071683981455864, 0.07622395582016438, 0.025991089904921192, 0.02564248159497736, 0.075199841822107, 0.03424532148205946, 0.05992647711067431, 0.02504181503618677, 0.04006930574354145, 0.0506553691511433, 0.028615751183561744, 0.030953954950335528, 0.0334225200687445, 0.04725475465097735, 0.07338501783388277, 0.031000153882609262, 0.043579666169300195, 0.02123093555471109, 0.04779082467599262, 0.04006204323001927, 0.08041139241428145, 0.0269534457249627, 0.04382051655181474, 0.02872846569986113, 0.06082981351702925, 0.04019920744242207, 1.034407339269115, 26.62425248853622, 63.34156751632691, 69.20815067906534, 63.61906343890775, 47.86098834007017, 24.985031235602595, 28.018107914155532, 62.891153904699514, 66.55647154777282, 62.07233167463734, 23.049541596443426, 8.602680525472088, 0.3273220666714253, 0.1094089464975461, 0.2334691866511299, 2.003077470487164, 5.868900302917727, 8.791605407191861, 12.946184796671714, 10.26968490692877, 8.996007961611594, 14.002317286306813, 19.192724035632228, 34.45830829681889, 53.6530464695346, 64.31195797458773, 65.49749435917025, 65.72611362703385, 62.003741187434045, 63.795342599191976, 63.904541384789255, 61.24227577640165, 56.48019675285586, 57.32020370421871, 61.23622355922576, 62.29887993104997, 62.26066035609092, 62.21569038206532, 60.51855925590762, 59.40599072364069, 55.77756297203803, 50.67673237093034, 50.62465113978232, 52.2303282830023, 57.828464431147424, 59.54210873573058, 62.60181242419828, 61.25137175283125, 59.98592492072814, 56.91142997434063, 57.37192799968105, 61.10277275885306, 64.20748956741826, 60.42483029826995, 54.65153286533972, 44.28499483293103, 48.53529868587371, 47.81256275792276, 49.7586545636577, 53.67423119083528, 62.945776831719186, 59.193413949781856, 64.3182102326424, 42.19544233814363, 33.0665179990953, 58.3008276262591, 55.88597336123067, 64.60320964936288, 58.24053687434043, 62.849259068889005, 59.89480433925506, 64.16819134066182, 59.2455187151509, 59.559076909096014, 47.31255862020677, 43.44381509288665, 51.78799475392988, 60.14553400778002, 58.18052068833382, 55.14693998521375, 55.38029747624552, 59.77164976058468, 61.20131838706232, 58.83368945890858, 51.80697902556389, 47.581382182336625, 44.995728308154696, 50.22107455038255, 53.880277218357215, 58.7986195471979, 56.254589865284586, 57.73017767936953, 58.64819272871941, 59.82253074645997, 58.04696790633663, 60.70151036785495, 62.89610393585698, 59.70705616858698, 57.30187446840348, 60.047937593152454, 59.567792415618904, 50.80770031098397, 41.80297390107186, 27.74377146074849, 15.623716269769977, 15.13470555505445, 13.628791935982244, 16.23737500559899, 10.335691532781048, 6.914168807768053, 5.912372421833777, 2.7800668872171834, 0.33191660238850507, 0.022505970161047675, 0.05881877142875906, 0.8635278118233528, 12.658561314305953, 44.884823291532456, 47.31683792606477, 23.44904676560433, 18.37656705610214, 29.8011605201229, 48.528289410375784, 58.1717816475899, 55.60269194264566, 38.850570571038034, 3.579370177561237, 0.11504569887033395, 0.05037920211531943, 0.010689779263620657, 0.022004182570643967, 0.03824945621853394, 0.03903525175466653, 0.018777899038527283, 0.05731944543039126, 0.03279082694902055, 0.08350335392019442, 0.03784479708561013, 0.0301583803018495, 0.03247547451586973, 0.03540364259313192, 0.04091001446208647, 0.045235519252356984, 0.018927016137768666, 0.018296441506414164, 0.02435538301905317, 0.01627770023450496, 0.04748032924028174, 0.03867142893854649, 0.04691510956974761, 0.036637725969476086, 0.02422009572206486, 0.16802384277745602, 0.1715463610185731, 0.11545370197704724, 0.15573992934678832, 0.13333705163771106, 0.19535701721906665, 0.34574825857435504, 0.1301337162693662, 0.12371696381559297, 0.1523977022377714, 0.2517234531020926, 0.16444354618508972, 0.15164122105606143, 0.18280184737616972, 0.13400952361764448, 0.10537658908194113, 0.12901938009646632, 0.2345515769575873, 0.13309081565708886, 0.2812350445216702, 0.12901489082123005, 0.10339608325833276, 0.11946419524329326, 1.05605649371301, 34.33769149165, 71.1979769122216, 80.25185846513318, 72.74965870764949, 54.28202598325668, 31.479379938494777, 58.24244314624418, 74.25825718910464, 69.13081722874796, 66.56955657466766, 25.94135803561057, 11.463755388413707, 0.4380004131986249, 0.331061678908525, 0.24357002528925098, 2.0323404357317956, 9.185163282578992, 14.940610008855021, 19.038094397514097, 20.638948986607215, 29.17339497996915, 30.59721927489004, 25.276127976755944, 38.5287832444714, 57.22794955776584, 66.0592326810283, 65.0488026680485, 65.37886619567871, 63.9526649444334, 64.06308750952444, 65.28489797346055, 63.52852336822018, 58.06478723402947, 60.501006649386504, 63.10722551038189, 62.728438300471154, 64.44593045019334, 65.61494581161007, 63.479427060773304, 63.2642379883797, 57.93826726175124, 52.70717866959111, 52.41463261265909, 53.17736887162732, 60.17654818873252, 61.59035475023332, 64.2705338231979, 62.996802945290845, 61.20298147201539, 57.3878449778403, 57.00441368164555, 62.685794291957734, 66.11013720112463, 63.681115335033795, 57.84777425950574, 45.88154462076003, 50.785385947073664, 50.694477173589895, 52.27654164837253, 58.435796383888494, 65.50656287900864, 62.69503539608371, 64.21737786262267, 43.57742671043643, 37.416720697956706, 58.84460149272796, 57.28763626467798, 64.69461656385853, 61.347646328710745, 64.55913397573656, 62.05348860832953, 65.75603738907846, 61.12567940065938, 61.74665335685977, 51.44984329900434, 44.903791873685776, 54.63200338425175, 63.3017986051498, 61.4475961654417, 53.56143951416016, 56.77689267743019, 61.13060981996598, 64.31697076366794, 62.65662754735639, 53.740201534763465, 51.475354394605084, 48.44197765473397, 52.023654676252804, 57.26722425030124, 61.361480528308505, 57.7731119432757, 59.354529226979906, 59.90411604604414, 63.1507912758858, 62.69365472178306, 64.96840976899671, 65.96092239502939, 60.98919660814347, 59.88047592101559, 59.7012589054723, 62.09585020619055, 53.810568855654815, 52.84090795824605, 44.846662552126, 31.914039350325066, 17.716251727073423, 22.527062277640066, 24.158462324450095, 14.805022497330944, 15.036151101512296, 10.26393961521887, 3.0830172761794064, 0.6055950781991405, 0.31523755060568937, 0.16544014996578618, 1.253150446761039, 15.205326849414458, 52.8082150028598, 55.120526744473366, 36.41834020614624, 23.378610803234963, 33.86019391398276, 54.67699689249839, 66.56583032300396, 64.32998518789968, 47.46649988235966, 5.017105158298246, 0.27965635181434695, 0.11685806371632124, 0.11470846696606568, 0.09155806364311327, 0.14560395791645975, 0.12822382843061803, 0.1262531898194744, 0.14087615354407218, 0.1867079611627325, 0.2478096631145285, 0.15667930635954105, 0.11923524220624279, 0.1069832056941044, 0.2331715921360639, 0.2460559806035411, 0.16750363843335261, 0.0644745112907502, 0.15200405561875913, 0.1540193877994053, 0.1413523997630804, 0.1139663805764529, 0.16609674860392848, 0.10243633596767342, 0.14723244633886123, 0.1239529648615468], [0.04438460624266056, 0.04117298180297498, 0.054908765915540926, 0.05407305209026222, 0.012763209637224436, 0.054054551066890846, 0.04421712793109398, 0.07181862849862346, 0.0289357288725554, 0.030243090474076813, 0.04828500501330822, 0.075693593150185, 0.011715954995804257, 0.06141769789880323, 0.07879523800746088, 0.02260355252562271, 0.09602293131812926, 0.07535531170546048, 0.13031466623708127, 0.09179032617999662, 0.1003882228847473, 0.07940118291204976, 0.06475318343408647, 2.0306340821327704, 31.799470839961884, 55.64382976101291, 53.23803224871236, 48.94677100643035, 37.32008526402135, 26.818205848816906, 66.26452169110699, 71.93874789822486, 78.2237655885758, 37.76247370627619, 14.449044850564773, 2.1079724354128686, 0.07384349081304765, 0.06516959818620836, 0.056010174354718584, 1.9553129302878536, 5.706789724288448, 6.738933488245934, 17.790002092238396, 3.6532526775713894, 6.644434765461953, 18.34848680803853, 28.80085414455783, 46.752248041091434, 58.40477828056582, 65.9384785929034, 65.02486836525702, 65.4052637469384, 64.66435940034928, 62.232901742381436, 60.662153305545935, 57.77996040159657, 54.41845778496035, 54.548856981339, 58.928151899768466, 57.997699014602176, 58.34405999029837, 60.29055187779089, 57.19497026935701, 49.85863185697987, 48.56237872954338, 48.46341733009585, 51.48258332283267, 53.21019910996961, 54.49060193953976, 56.174314637337964, 57.80759742183071, 56.49030862316009, 57.74238801771595, 56.692322454144886, 59.021484698018725, 58.95566732652726, 59.49270256104008, 50.51628781903175, 45.85497056284259, 42.559391221692486, 44.553112368429865, 44.236094643992764, 48.039832730447095, 51.80815573661558, 58.02944275640673, 55.60426481308476, 63.77581311810402, 43.210991044198316, 28.032316700104747, 56.94005935422836, 52.00303869862711, 57.5409782317377, 52.127915197803134, 58.247687355164565, 55.35349199848791, 59.164749268562566, 59.34848877691454, 59.62916574170513, 53.895233215824256, 42.05094222099551, 42.3689954511581, 54.86628655464419, 55.65137640122445, 55.63706759483584, 53.71451785487514, 55.641519484981416, 58.11995144813292, 59.48549324466337, 51.19754076004029, 48.41113605806905, 44.53500670771445, 43.58221200204665, 50.56833767121839, 56.918047012821326, 57.00702205781014, 57.75346479108257, 57.69948121040099, 55.958517597567656, 51.59803828885479, 55.74092018988825, 54.027836784239746, 60.674316575450284, 58.693303908071215, 58.031454932305124, 55.94246333645236, 54.19737731256793, 48.04643800181728, 33.41326728943856, 18.681927496387114, 27.153511624182425, 15.790856307552708, 4.506675850960517, 5.2792660843941475, 5.2052347794655836, 3.376348052294024, 2.3785755278602725, 0.03143019159324467, 0.07098937662498606, 0.15817423501322347, 0.11320562462412542, 3.0485690601410407, 21.54042143975535, 50.46011947816419, 45.65360000056606, 27.468546590497418, 17.457100729788504, 26.793161515266668, 41.22744452568793, 48.33892522319671, 37.51567817503406, 10.239320858832329, 0.1575426261631712, 0.047771959760857206, 0.14325401385224637, 0.015273483455060952, 0.026175686451155814, 0.022560182373009385, 0.04634214091985937, 0.05852872671018686, 0.09328825789834223, 0.05221319362340916, 0.05487896509528641, 0.05131166901499514, 0.044860760531117844, 0.04050406830144986, 0.03535609917655107, 0.06055677211993645, 0.036179996095597744, 0.03557303612450919, 0.05761730424579113, 0.015054837173421778, 0.03137336319102155, 0.018753104602857944, 0.022671715198685567, 0.08263859387126662, 0.0429794822459019, 0.050155454645714456, 0.07668733942292391, 0.11279480231385078, 0.0560883344751933, 0.036122558653474815, 0.012252285490713775, 0.04629383907623349, 0.01711725790594374, 0.01572288212276274, 0.05906094714338261, 0.02876963718013177, 0.04698318414269917, 0.024661772223489902, 0.018947009117372574, 0.03697191650468496, 0.022675359861985333, 0.025447399220279148, 0.02234039749319275, 0.07926109607421583, 0.02561682147995359, 0.07732179045917527, 0.023970745594030427, 0.05377621983268088, 2.586054201087644, 40.5732951625701, 64.53377977494272, 63.126590251922615, 54.93247262893185, 46.25518960337485, 29.71619805982036, 65.10902281730407, 73.56182467552924, 76.49782857587262, 43.524211914308616, 15.243942583760909, 2.526567044758028, 0.10472567481619698, 0.035222432155522614, 0.2838194268124719, 3.1742023316121872, 8.61318757457118, 9.37640138210789, 17.996960070825395, 13.516752373787666, 10.637172748965602, 17.75104707287204, 30.78373582132401, 49.212817530478205, 61.59204136940741, 68.20807180097027, 65.51472140896705, 64.60018550196003, 64.34565113436791, 62.53114308080366, 62.66476646546395, 60.269916288314334, 56.31459428418068, 56.92220080283381, 61.31039557918426, 60.52023803034137, 60.62532617199806, 61.29767533271544, 59.553973905501834, 53.217749672551314, 51.31148561354607, 50.469203687483265, 51.96811391461281, 55.79066368841357, 57.37628183057232, 57.890445724610366, 59.95155319090813, 57.21967727907243, 55.92256907493838, 56.87393211549329, 60.82889326157109, 61.67984362571471, 61.308654046827755, 54.12027135972054, 47.193852009311804, 45.44855417743806, 47.04082465940907, 45.87488835857761, 50.237277861564394, 53.82100628268335, 59.79828657642488, 56.644940222463305, 64.24202211441533, 44.46379999960623, 30.794918498685284, 58.196661241592906, 52.5243648405998, 59.13457055245677, 53.93912453805247, 59.75832546910932, 55.52498586716191, 58.67237806320191, 59.83865953260853, 61.84532842328472, 54.952919944640136, 43.80918779680806, 45.14569620932303, 57.01625923956595, 58.91052869058425, 58.03681288996051, 53.56823305929861, 55.86052502355268, 58.3828914550043, 60.75230506158645, 54.11942020539315, 50.80446435559181, 45.949181972011445, 46.18266497888873, 52.55819136096586, 60.24654680682767, 57.656970562473425, 58.157978826953524, 58.96322573384931, 58.66775358876875, 55.517580432276574, 58.02455548317202, 55.13690263994279, 63.87533149411602, 60.49046331836332, 57.98285676587013, 56.02152262964557, 57.693801618391475, 45.87047176976358, 34.406423184179495, 14.32532839236721, 15.19688198643346, 10.92350479095213, 8.001077194367687, 10.764236950105238, 8.835117240105907, 7.754461601857217, 4.561643456259082, 1.0819057711670477, 0.06979850826845055, 0.050030383131196426, 0.10437708182801163, 4.311308476232714, 24.75743570635396, 47.28159150769634, 38.84378094826975, 29.856711087688325, 21.493906051881854, 31.18308213449294, 47.30683588212537, 55.48726443321475, 43.78732450546757, 12.714460972816715, 0.22340559520788733, 0.03256597631280461, 0.028119023603897904, 0.014708762699287507, 0.03700633683512288, 0.016256437464166554, 0.0725519968076579, 0.09138571684278789, 0.06868950406750364, 0.04907229059045354, 0.04337123662774121, 0.05533610891190268, 0.043735109239576325, 0.02373227391452078, 0.02974134693372875, 0.06003286374071914, 0.018531799038511612, 0.045505377554124406, 0.03801999373301383, 0.07793708929731961, 0.030068751845148303, 0.010639303645509626, 0.046392365644175204, 0.01021294315691076, 0.10316638711599574, 0.15243353983086927, 0.1666062890041259, 0.13210582576932448, 0.17985319027737265, 0.1456000815115629, 0.08383444179930995, 0.1629341231478799, 0.19012587775866832, 0.19582710409116363, 0.11932720340067342, 0.10712488599482084, 0.10725522819425791, 0.08670942422242896, 0.1967879468875547, 0.20504871894034649, 0.14431604154167638, 0.20959106874802422, 0.12442509718840161, 0.18430362485589522, 0.19302080145045636, 0.23383566779234718, 0.15964035876095295, 0.12136440739155778, 3.4567250167169883, 47.87378703394244, 75.2313187814528, 71.25041900142547, 63.053277231031856, 49.923413722745835, 38.90823333494125, 78.40010750678279, 76.61169498197495, 84.69499388048726, 46.87501822748492, 19.02228528453458, 2.795740678425758, 0.31829108514132043, 0.19537233897755224, 0.48527588286707485, 4.922213217904491, 14.35915687391835, 15.058147753438643, 29.05398234244316, 13.452147014679449, 15.248917129731948, 21.1727874894296, 34.391553478856245, 49.87321915165071, 64.1899291161568, 68.38948926618023, 67.52699928898966, 65.20121420583418, 65.15576570264756, 62.75401607636483, 63.317813642563365, 62.47815185977567, 58.011572437901656, 60.09346454374252, 65.06916761398315, 62.23633773865239, 62.64464470647997, 64.85000910297518, 63.33122814855268, 55.041067369522594, 54.406031716254454, 53.43889682523666, 54.89600635343983, 58.07861358888688, 58.27255518205705, 60.17400649286086, 61.03559040254163, 58.20118373440158, 57.233664451106904, 56.75279363509148, 63.18130731582642, 63.203715816620864, 65.40238472723192, 55.44968420459379, 50.748872603139574, 46.111807361725845, 49.301168918609626, 48.66729820928266, 52.87768802335186, 58.43790269667103, 62.01544161765807, 61.61258282199983, 65.11874637296124, 46.353664628921024, 34.76932871726252, 56.61610687932661, 52.472083568573005, 58.85279532401793, 55.52455832881313, 60.481147689204064, 56.60182552952921, 58.838584576883626, 62.158270805112785, 63.91576328585225, 59.19881113113896, 47.0821350620639, 47.978577075466035, 59.652778410142474, 60.948278442505874, 58.74928005280034, 53.17525863647462, 57.699936205340975, 62.31817014755742, 62.838751039197376, 55.81013433394894, 53.27632634870468, 49.017612934112556, 47.87244558334351, 55.55896535996468, 61.74367235552881, 59.638622576190585, 59.21930943765948, 62.34315956792524, 61.520454191392474, 56.93720779111309, 60.10868726238128, 58.964382833050145, 67.26325911860313, 61.51281733666698, 60.08712991591423, 56.65721724110266, 57.05285103090348, 52.9771436414411, 38.50089911491641, 23.38578481828013, 33.20255364141157, 23.667552201978623, 14.010380698788552, 17.442411453493182, 13.508764466931744, 12.246067216319423, 7.699580778998714, 1.397748255441266, 0.26539872009908, 0.5213251000931186, 0.2503864764566383, 4.297508107077691, 29.366138289051673, 62.30839560108801, 57.597695704429384, 40.03398103098716, 28.11121713730597, 38.95885152201499, 57.318254286243075, 63.491833517628336, 54.14940672536051, 17.785556085648075, 0.38903290045357525, 0.12117074036429967, 0.2537966862080559, 0.07892784782715383, 0.13255121396674266, 0.16635423075527916, 0.21645728498697284, 0.34629959673170124, 0.1883899991310412, 0.1257036596296295, 0.21593484366613053, 0.15899054766181978, 0.08629490170748004, 0.14951434647364004, 0.15696531762519192, 0.19336322743085124, 0.11002937046390389, 0.10728814699236425, 0.17423310797781716, 0.16570051260773214, 0.13136138748978415, 0.09837394024455741, 0.15317977075615238, 0.12462589649423478, 0.18349449811202867], [0.03670429517965644, 0.012868866568521388, 0.05473869439635066, 0.04709456566601031, 0.06273513164130912, 0.01853553563236229, 0.05993980321011717, 0.033633607935400746, 0.005304583830894122, 0.03862442178351264, 0.025244391666004257, 0.025665627026389685, 0.039586149411456245, 0.04609206300829688, 0.058844266834879116, 0.020467550005583514, 0.10325418079211827, 0.06492268804821276, 0.042326323342539614, 0.05600386562066213, 0.02563474602216194, 0.09353383504334958, 0.08191602740196452, 6.931841046579423, 44.72325301939442, 55.774648651, 55.9059186135569, 53.18521753434212, 30.56242196790634, 40.399887177252005, 56.47961624207036, 64.80537645278439, 57.167388162305286, 25.3095857943258, 7.687208642882686, 0.1450446984099765, 0.09226907750651722, 0.12717554435854958, 1.1755774867150093, 2.466027222333416, 7.407687796700386, 6.686586026222476, 15.243977885092459, 14.674293821857823, 6.720297817260989, 21.739228733124275, 39.30328661395658, 55.120491443141816, 61.38849781405542, 66.65361296746039, 63.73578925286571, 62.46467067349342, 56.22028089338734, 64.05391308569139, 59.71198266552341, 58.24694602720199, 52.76654766451929, 52.231673655971406, 57.64840018364691, 59.159528593863214, 57.29990151620681, 52.67121053511097, 49.271221622343994, 47.08610057830811, 48.92534309817899, 50.173774688474595, 52.15919217755718, 54.63679259823215, 55.4826242693009, 58.36284422105359, 59.58352504238006, 56.559008936728205, 57.02285666619578, 55.31771606014621, 59.32540955082063, 57.4142699856912, 50.64311765855359, 43.666162490844734, 45.06143977565151, 43.318424763218054, 50.29836485462804, 52.23042241988644, 54.0871940120574, 52.62430683259041, 56.353676780577636, 55.84461981250394, 60.952161588976466, 45.2257086384681, 27.91310214227246, 56.72007714548419, 52.14473039873185, 51.59869332467356, 52.16233399606521, 56.51416840091829, 55.44093731910952, 54.736279595282774, 52.482211128357925, 59.42126051072152, 55.13170942183464, 46.551418765898674, 39.33400661714616, 49.92045625563591, 54.94227463199247, 57.26262331008912, 54.041000258538034, 52.72716706798923, 54.64547280342349, 58.872207134000725, 53.9016306015753, 50.96859593545237, 43.742107422121116, 42.089624635634884, 44.96855412760089, 53.414495760394686, 58.276858022136075, 58.57573870689639, 58.32133377751997, 54.12228353561894, 50.310445754758774, 55.24741149717762, 55.34786731966081, 57.39767443749213, 58.07973538675616, 62.57107673152801, 57.39295190380466, 57.80880943421395, 48.76830316358998, 44.04185102831933, 26.042814062487697, 25.492252534435643, 15.347998161469738, 15.067569286592546, 10.266684293746948, 4.780976512739736, 6.716733853663168, 3.474540176891512, 1.2233925274302884, 0.19077863063543074, 0.06325058240984237, 0.14718802856101146, 1.2606752687884917, 13.131430495169855, 43.29270578199818, 49.53473037289035, 29.658105796383275, 20.81442209982103, 23.050955610890544, 46.819065616976836, 48.9893404899105, 46.17320029966293, 18.92417896178461, 0.340159677810246, 0.022374769943135402, 0.03483110295248128, 0.008644567738707748, 0.034546394036301685, 0.03469718312243781, 0.02435554772795689, 0.06162013280235472, 0.016993392979906454, 0.011954709170235982, 0.02874854677957633, 0.029853364310017037, 0.10416069263291937, 0.03799238009378314, 0.05003373476586515, 0.0214146166258762, 0.03059868742110989, 0.03554229684654744, 0.030348908283837864, 0.04698696095616587, 0.009361687322868215, 0.040915691173605384, 0.02750243007716152, 0.07862994687691813, 0.021114367616152572, 0.023303042511425676, 0.018726940785023957, 0.06790627109547777, 0.049350288576416435, 0.02909215636581423, 0.07648430314035186, 0.019553735431644226, 0.03482145407507497, 0.1002138153079056, 0.04889786386141374, 0.07898115222492526, 0.03752116324199784, 0.016967916725984505, 0.03168626605803448, 0.06637099259082349, 0.006560782250392461, 0.07028866664416368, 0.015576595718401576, 0.05722058944464211, 0.03790632543724872, 0.05153196908894086, 0.09102876583534865, 0.025364131208569295, 8.773822361423123, 53.51798357502107, 65.25230307732859, 62.51115860477571, 61.159702039534054, 37.59738506809358, 41.707723063807336, 64.92501658778038, 74.25812382851878, 68.79735300617834, 30.087479814406368, 8.092167377471924, 0.44398585815102826, 0.05816003157486839, 0.020897966929741447, 2.703740260293407, 3.3260056568730265, 5.921341901825321, 11.390486494187387, 17.693082286465554, 13.745202979733868, 12.590924943647078, 21.76146268844605, 38.2187081152393, 55.35075026173746, 64.5941254400438, 66.00847721099854, 67.27064101926743, 62.74418269434283, 58.76585206677837, 62.05498303136518, 61.81892694965486, 58.847229480743415, 56.52977158946376, 53.304551724464666, 60.24823342600177, 60.03106355667115, 59.96244561287665, 55.713526356604795, 52.18509158780498, 47.71080470854237, 50.8927490634303, 53.63290117632959, 56.18399896929341, 56.672341900487105, 57.59158465170092, 60.0139267213883, 60.42937632529967, 57.71287218216927, 56.6235319260628, 55.72314793063749, 60.44982364100795, 60.3314543539478, 54.866294399384536, 46.13522391165457, 46.98442097633116, 45.08801775593912, 51.013244275123846, 53.8059090798901, 55.33955973963584, 54.95995667672927, 59.179850393725985, 58.42938723102693, 62.223276245978575, 45.40265067931145, 30.75359044536468, 56.6122119657455, 51.26555858119842, 52.57783066841864, 54.13703556983702, 56.28407824424006, 56.48169902063186, 55.396186997813565, 53.0775837744436, 60.200670765292266, 57.46171105292536, 47.24963988027265, 41.48435977197463, 53.61146542333788, 56.74046954801006, 58.46785783767701, 54.82894559060374, 53.74990940093995, 57.186752903846006, 59.38865776984923, 56.739339905400435, 52.10606759594333, 46.01836081474058, 43.62324783878942, 47.85563822715513, 56.05872631072999, 59.2590352027647, 60.933173394972286, 59.35925176066738, 56.25060473718951, 53.218298804375436, 56.82618902575586, 58.53484407547982, 59.87873046628891, 60.480041580815474, 62.561529682528594, 57.59882926940919, 58.461805620501124, 50.9003427720839, 42.62727568226476, 24.67811949791447, 16.87643304947884, 8.828475686811633, 11.13279854097674, 11.472749383218828, 7.858862348141209, 8.259179938224054, 7.035122446475491, 2.45841684360658, 0.5219738846344333, 0.08233343040750873, 0.05394649053473146, 1.1464989954425444, 14.357289825716327, 43.0763086195915, 55.65276492026545, 33.32107590090844, 24.698376578669397, 30.695074565948982, 51.295270535253714, 56.221269330670765, 53.42954197237569, 23.934063526891894, 0.39583107276308926, 0.13048741906400652, 0.05530819649838152, 0.014347732273651468, 0.06626020095521404, 0.03877699968495196, 0.08096659931564525, 0.04659618333643002, 0.04491197350885599, 0.011708222295818551, 0.029413903717912977, 0.05080866717523144, 0.06534471822481963, 0.056203791586261605, 0.03502356722169826, 0.01932982708357515, 0.06043666102472813, 0.007710817641758872, 0.0815784660798888, 0.08006402516677495, 0.07957432644381639, 0.03501237850756415, 0.0810647045352286, 0.01542379852429393, 0.011367719196113608, 0.11965190210650045, 0.14047829344147636, 0.192122042419449, 0.18024011064440976, 0.16071154886195738, 0.17804280193823, 0.1243546324211263, 0.176612347244255, 0.31273241244977523, 0.12104361573414457, 0.3548804862845329, 0.08078050889795826, 0.1550496075182192, 0.13887081114995864, 0.20064316179242828, 0.10772000607703963, 0.152501430542719, 0.11448709053858636, 0.17079269904042446, 0.2085284128664963, 0.10195257442612803, 0.2589389135039622, 0.13001143331489257, 11.189329701085246, 65.21118879318237, 72.12169508780204, 71.9610034265826, 67.35870607437627, 43.82528520399525, 51.37591054362636, 67.87267777227586, 69.2172113541634, 68.64021501233502, 32.60580228221032, 9.726011060899305, 0.41975523255044417, 0.19371691490373305, 0.13768935035313332, 3.9266994883937225, 7.179337211193578, 18.069925961955903, 20.035978709497762, 25.8671114906188, 25.88042009261347, 14.291985304124895, 26.13372087478638, 43.492444638283025, 59.83089323966735, 66.90779039936682, 68.64919724002962, 67.3408200663905, 62.693619420451505, 59.22744051102669, 62.929463694172526, 63.567590175136445, 61.83160012768161, 58.29461851427632, 55.37522977398288, 60.710269020449736, 62.77891528221869, 60.87147058979158, 58.08667013722082, 53.542592525482185, 50.71250830927203, 54.145864825094904, 56.411284631298436, 56.676978142030784, 59.704608609599454, 59.51342052029025, 62.27773443345101, 62.28469664050687, 58.90083651388846, 56.06437060140795, 56.29381748937792, 62.85725678167036, 62.274408263544885, 56.685281799685576, 47.31346861008675, 48.67596272499331, 48.40654688496744, 53.679604837971354, 57.69825350853705, 58.40264058882191, 58.53636595510668, 60.0587829466789, 60.31361933677428, 61.4564371878101, 48.05105463151009, 34.77122714442592, 56.60983108705091, 51.60044662414059, 53.63905537512995, 55.46215734174175, 58.22991901828397, 56.25129115196967, 56.64756428810858, 51.9373272311303, 62.995379124918294, 60.30147960109096, 50.03056503111317, 43.117160104936175, 57.49849504040134, 59.4181186922135, 61.29200750781644, 55.35662989462576, 53.29764050822104, 58.253696426268554, 62.7853754258925, 57.999005163869555, 56.07284292098015, 48.44486059681062, 46.04821005175191, 50.32894365249142, 58.06377918489518, 60.912427979130904, 63.08532299533967, 63.18781845031246, 60.604215975730654, 53.981862683450025, 60.86907402161629, 61.94931437892299, 63.30972571526805, 63.58324435449416, 64.62973271646808, 58.8921170849954, 59.97824099756057, 53.03095856020528, 46.969951352765484, 30.089764595031742, 36.692329529793035, 21.312512120892926, 24.647717206708847, 22.98290837195612, 14.573948806332005, 15.898383182864036, 8.310473753559975, 4.057833884031543, 0.7702545845700849, 0.34481537798720024, 0.232033308054651, 1.973793667650992, 18.19330019335593, 53.41557833456224, 61.134418441403305, 41.30328355296966, 34.12105898703299, 37.33910483698691, 61.05159759521485, 62.98909548790225, 61.57060953878588, 29.918033422962313, 1.0011371213101572, 0.14840636883051167, 0.13882185813159714, 0.13213171954116515, 0.1421657093470135, 0.16385853080259216, 0.1631703693419695, 0.12177087066154327, 0.25201634383730354, 0.0942546701539428, 0.09264131196804586, 0.09874753068171202, 0.17896584595643705, 0.1496601330056306, 0.12085059222074286, 0.15173272259773748, 0.1417038655809818, 0.16665236153189214, 0.23749163854987393, 0.15154150705183708, 0.1503789379832245, 0.1392906732977398, 0.13593770563602448, 0.2043748373586324, 0.1794460758326515], [0.032975511595366463, 0.0949202856469539, 0.03592322640601666, 0.07196730318208856, 0.11426415895262074, 0.03293836016147848, 0.03430044150821144, 0.009607589097633477, 0.008385894320634826, 0.031083896868832173, 0.018509396712385842, 0.04633497033688811, 0.00718793629916505, 0.034704089405075196, 0.0530929766565321, 0.02378195280119056, 0.04253221713306923, 0.047294250313913634, 0.041256902904640284, 0.012692297666123318, 0.10178454836169559, 0.05761345465397162, 0.037263803664715066, 15.465894802924126, 43.94075978186823, 50.10657664268248, 47.655134508686686, 29.16767224188774, 31.686379101968583, 39.731334870861424, 50.68901723431003, 39.20002237443001, 24.836141986231652, 17.86937713623047, 2.346312072007887, 0.15050237006958456, 0.05495472736055813, 0.06388240959495306, 1.5981863967833982, 3.2527808893111447, 2.4829745581073146, 6.343084948678171, 16.744266825337565, 14.740457342516992, 20.15883714922013, 32.45731899815221, 42.079689271988414, 58.01027805574479, 65.07866367217034, 63.71382790227091, 63.734942020908484, 60.69503845707063, 58.416168843546224, 56.497447336873705, 58.80039638088596, 58.597919710220836, 54.157145561710486, 47.327455782121234, 49.84223242728941, 50.707299401683194, 48.32758172865837, 45.58571161762361, 47.76771045500233, 51.661082544634425, 54.16102478581091, 56.30072086088119, 56.859517405110026, 56.661163145496005, 57.22575695283952, 57.598676296972464, 58.40611580879458, 57.21121280424057, 55.84034442901612, 58.5951191379178, 56.77884994014617, 52.36926647924608, 43.88608194166615, 43.51289979873165, 44.14563694307881, 48.7694328061996, 59.59985779177759, 55.91255134151828, 57.56232377021544, 57.52312752508349, 58.083634222707445, 57.29315896188059, 60.42424978748445, 47.985884451097064, 24.690745607499156, 54.41712417910176, 48.3989727881647, 57.28298433365361, 56.16818789512881, 58.8931369012402, 56.46683323767878, 58.78759376464352, 54.92404737780171, 53.62875523105745, 57.82422434899115, 49.677402665538175, 39.74889924449306, 47.15733082063737, 54.392605443154615, 57.79015071930424, 52.8742677165616, 53.025380949820246, 54.7071873757147, 57.82019999719436, 55.90750717347669, 51.08161903196766, 48.99138404477028, 42.40588142025856, 43.62921376382151, 50.956730765681115, 53.692368230512066, 56.779489286484264, 53.68833603397493, 47.60303758805799, 46.71937465667725, 49.953808169211115, 52.79076045559299, 57.10714447882868, 55.24465799331666, 61.53817938220117, 60.77475278608261, 60.8435982273471, 53.40525465626871, 49.262576718484205, 31.16334084541567, 23.893355208058512, 11.78857078475337, 5.630880094343617, 7.964536884138662, 7.6184024253199185, 5.594360376557996, 4.7236496017825225, 0.9468494956531833, 0.398038447864594, 0.2176232708077277, 0.01326100878237236, 0.19422173620231692, 3.391896082508949, 25.331896235865933, 36.66981120263377, 32.569965547130955, 21.832749805142804, 25.395132687784013, 40.16158749980312, 49.01068210601807, 46.190427349459746, 25.795420369794293, 2.3380674950538145, 0.1695550073899569, 0.0890519525555353, 0.03883261766825472, 0.031285508227865064, 0.016856510304815827, 0.04777857109964375, 0.01560031763097692, 0.05786474298445448, 0.07654033481113373, 0.040442888519816825, 0.0218525986682864, 0.011406681470332608, 0.027052054647356275, 0.013978210720984686, 0.05210183508273575, 0.015843023861488028, 0.020073979995363665, 0.016000930862050625, 0.04362447082155174, 0.06752880425342629, 0.06297212860156452, 0.03572978537469622, 0.020479569925115477, 0.07955017169156382, 0.04424294892458185, 0.04305004660460738, 0.027707149837947184, 0.039959410430803415, 0.012145712126737401, 0.020826058086728858, 0.06575530304783775, 0.02664711397712029, 0.004822434904429341, 0.08026506962074388, 0.019877317564321623, 0.005165746195181724, 0.058586708074736024, 0.05091120421345677, 0.05240094645189182, 0.08596847930382337, 0.02918879835746221, 0.03126383368526736, 0.022631531971837246, 0.069931102766385, 0.04488770384341479, 0.02320789630644985, 0.16727364351672513, 19.951126075560047, 52.69488596147107, 58.86155789898288, 56.01380732751662, 37.102005404810754, 31.191326956595148, 38.69795114763322, 57.964774639375754, 48.44058129095262, 33.740879335711085, 18.826462914866788, 2.7189960739304944, 0.08069297569172998, 0.03887288324955491, 0.5901465168403042, 2.533441979077555, 6.594686854270197, 10.776379627566184, 10.914697108730193, 22.522504483499837, 12.671400212472486, 20.454199467935872, 33.31421175310689, 42.97351114211544, 61.88100238000194, 65.67389511292981, 66.87754108059791, 63.20431593925723, 60.2450837627534, 57.998809045360936, 57.13265557442942, 61.025184354474476, 61.814941821559785, 55.505079838537405, 49.947402938719726, 53.966616430590236, 52.79438080326204, 51.18143158574259, 47.54318221922844, 48.76665969048777, 53.054959543289684, 56.69501320008309, 57.11762505192911, 58.965998849561146, 59.12250534180672, 58.90933236768169, 58.105187646804325, 59.51977083759924, 58.27921536660964, 55.51876106569844, 59.50700352268835, 58.397180649542044, 54.6610838367093, 45.80210878003029, 45.306580066680915, 46.536458846061464, 50.70860947332075, 60.82348823547364, 58.2873817413084, 60.484156147126235, 59.25813697999524, 59.63578278018583, 58.099570812717566, 59.71636395300589, 48.79822692563457, 28.36790292493759, 55.06847296991656, 49.81982392649497, 58.222250784597094, 57.71362919961253, 60.992044248888575, 58.259438776200824, 61.582443329595755, 55.49550141057661, 55.60115045116794, 59.663364887237556, 51.31119928052349, 42.31551785622874, 48.972207576997825, 58.052400389025294, 59.748315580429576, 53.44566683615408, 52.54481607867826, 55.12963056564332, 58.84537812202208, 58.43769088868172, 54.261264877934615, 51.48066920618857, 43.89629579359486, 45.25098831422868, 53.73026617111699, 56.610529268941576, 58.04750919342042, 57.10128053542107, 50.20779732734927, 48.92782203612789, 51.24842959065592, 54.4124016454143, 58.36250689721877, 58.04736798809421, 61.309352228718424, 63.981521821791134, 60.59833242047218, 56.90686433546005, 50.958029070208156, 37.71096121880316, 23.109245954021333, 10.933758847175106, 9.329478067736472, 9.8042211609502, 10.21287820031566, 13.02636000417894, 7.344369955601231, 4.419739457868761, 1.0912850162675305, 0.39179314588827474, 0.0484256549257665, 0.2372715108457112, 4.408025789645411, 28.914191030686904, 36.09586254242928, 28.452784976651593, 25.57889965272719, 28.32260935537277, 48.135515028430575, 56.0225385235202, 52.812070692739184, 32.269337446458884, 3.474363179937486, 0.2102657010959041, 0.09349482584624522, 0.07275538549067513, 0.09580097266382749, 0.023252480708423163, 0.06384582889656867, 0.048942277808823896, 0.050299915845596024, 0.09265876345096097, 0.09179528276886671, 0.022437190787205775, 0.033773407490263065, 0.0423930419398652, 0.05148632940085185, 0.011805598774263936, 0.02016115697070716, 0.045818014205583645, 0.055575074718123486, 0.0550898461182031, 0.0437284098006785, 0.0598911642878046, 0.02662222378046042, 0.03899741467208632, 0.04075353334267293, 0.10323688252678803, 0.16660400606211156, 0.08218614234318657, 0.2149370141447552, 0.225832975439487, 0.09032121468936244, 0.14203460105965215, 0.08723741968072231, 0.12487633063668206, 0.15668538909765983, 0.13132679095912364, 0.13939910538254247, 0.13189889009921782, 0.15000759984456724, 0.2585716509530621, 0.12114065609151319, 0.1033555189027421, 0.13086232717239088, 0.09597689709475926, 0.24720295212201535, 0.20579790696501735, 0.16806053838902907, 0.39995970444813855, 24.98572353393801, 62.91945380549278, 68.42185666484218, 62.66937917278659, 41.860797482152144, 44.99615192413331, 52.20810021123579, 58.69675167145268, 50.10008119767713, 35.800802246216804, 24.601158672763457, 3.08636894149165, 0.3969065376347111, 0.20876973056264464, 0.7180778682231904, 2.2509462602676886, 10.517135473989672, 16.56317687803699, 18.351673733803537, 29.52552772337391, 28.55697685672391, 27.252951552790982, 37.341399423537716, 48.60332042940202, 63.49534011656239, 69.68904895167198, 66.93573336447439, 65.86959392793717, 60.60887182912519, 60.077782907793605, 56.96658634370374, 64.11028538980793, 64.19280813586327, 58.91343124451176, 51.37673424136255, 56.04932831179712, 55.573376147977775, 52.54517693673411, 49.88375071556338, 52.63465796747516, 56.43296357124083, 60.40452811025805, 60.48149285777923, 61.44794133401687, 62.41418584700554, 60.1096913891454, 60.517374700115575, 60.176336380743216, 58.83388165504702, 57.312904173328036, 60.85388268193891, 60.25017892160724, 57.3830008506775, 47.25974782820671, 48.602896813423406, 49.773845903335086, 54.18641821030648, 64.9724772668654, 62.272662808818204, 61.28272325761857, 62.236467176868075, 62.44292113088793, 61.167276136336795, 61.1768820208888, 50.95591883505545, 32.75119866094282, 55.30716096201251, 50.88069561989077, 59.409532623906294, 60.59965818159042, 62.47330773261286, 59.46113924826346, 64.00994331605973, 56.93274021148682, 57.24406265443372, 62.77809942922285, 55.11714958375501, 44.26047609698388, 52.0057176774548, 60.58143484976984, 62.78536758115215, 53.9992936964958, 55.20625798932968, 56.80916986157818, 60.649923355348655, 60.30894779389905, 56.0089082871714, 54.91876002280943, 46.66739148478354, 47.789008925038004, 55.89533998120216, 58.44047577150407, 61.38680335014098, 59.63342543571227, 52.18297350791193, 50.225777472219164, 54.864211620823035, 58.149937968100275, 61.66685665807417, 60.410972564451164, 66.36337326418969, 66.84761339618315, 64.04220088835686, 56.70267358902962, 54.39892830387239, 36.490947200405984, 30.248708840339418, 17.385844992053126, 10.888473122350632, 16.92966353508734, 16.12196416624131, 14.867649020687228, 11.938278828897785, 5.37414723826993, 0.973567761961491, 0.6669993542375103, 0.18717191933143526, 0.33611531579686754, 4.66612902379805, 34.22396629087387, 46.90283959911716, 46.61006604471515, 33.2801067444586, 35.99923495323428, 53.64870048338368, 63.765787539943574, 61.33070168956634, 40.76138457944317, 4.595766115573145, 0.4094030864296421, 0.23038074914966863, 0.12157890434947707, 0.2025612314502078, 0.0955230129822608, 0.2529424675289662, 0.24363638382525216, 0.18353667891313954, 0.11600561470033662, 0.15302275337519186, 0.12949674480384396, 0.13785363024761602, 0.12345662415628472, 0.11034987100790586, 0.093386186917703, 0.1085585046319231, 0.1522192803602065, 0.11314731767220844, 0.14361545413492188, 0.15092578686533437, 0.13653621948774786, 0.10384445919865563, 0.13246627013769843, 0.15882361710311907], [0.05459574238967992, 0.0035203626612201337, 0.013838813362282612, 0.02944950190853448, 0.08204470719060591, 0.05569059694666536, 0.05479490992823436, 0.0908356274087583, 0.10259215825147207, 0.054353424948790384, 0.01576944111636089, 0.09288165673253038, 0.050535062703514294, 0.006916422768676233, 0.044588879757230325, 0.019054341866003893, 0.06884973135686691, 0.0537095203875534, 0.032579815691156734, 0.0413929256460359, 0.06647264479749626, 0.03172613135839422, 0.26750815852034476, 22.23260602643413, 47.79342159148186, 51.757839572045114, 47.37302195641303, 32.511757573773785, 35.52415355559319, 41.1683814756332, 38.77531989928215, 43.20123610957977, 40.41248190787531, 10.467144866143505, 0.42059020710087597, 0.13905605121004966, 0.09652056671198338, 0.3639145628098519, 3.0398900806903844, 4.086950618413187, 5.085349986630102, 8.637826923401125, 17.38990660636656, 10.37635866672762, 35.3174485698823, 40.23471616929577, 53.56556976995161, 59.60718477925947, 63.008495530774525, 61.78105254327098, 57.34473420727638, 59.52480716090049, 61.485031266366285, 57.33575197958178, 61.94015956694081, 57.01169360068537, 57.077256018115634, 51.392184457471295, 47.13165498548939, 44.74102527864518, 46.334448937446844, 49.198857815034934, 53.98232552313036, 56.38245913290209, 57.35472840647544, 57.35531676200129, 57.18485055431243, 57.58044119804137, 60.40077832437331, 56.68409332152336, 56.47697256457422, 56.47873763115176, 57.0304621419599, 55.20298673260597, 56.4655270884114, 46.93046877461095, 43.095092850346724, 43.09362588390228, 45.89711250797395, 52.837515108047, 56.549042194120354, 57.6167780353177, 58.83754514878797, 53.61817659870271, 60.15448093414307, 54.71103914322392, 56.68709001233501, 47.09652231585595, 23.66271395837107, 57.083033669379454, 51.12638896511447, 60.39735409521288, 55.51669397661763, 56.573003953503026, 54.31966112506006, 57.93156393112675, 56.00799045255108, 59.06503477404195, 55.95353618744881, 50.01731526467108, 38.94857491216352, 44.8544680687689, 52.9081295382592, 57.846362206243704, 53.46615337556409, 53.662417011876265, 53.20577467641523, 55.31820243404758, 58.3786827518094, 55.6613156872411, 50.570714627542806, 44.60406003459808, 39.65122438246204, 40.89401560444986, 44.26282167434693, 48.04524167891472, 43.07169983463903, 43.09875242171749, 46.38172918750394, 50.22128635837186, 50.486744526893865, 53.67900471533499, 55.106335609189934, 56.96670793717908, 57.975635682382894, 61.11057827549597, 57.960032493837424, 58.44054637416717, 48.52893267908404, 33.7534583768537, 22.286617063706924, 14.03454642142019, 7.277755362372245, 3.8321056481330626, 8.887761331373646, 10.59863252024497, 3.2732593388326707, 0.5398020376601528, 0.29500581203929843, 0.0620262360110158, 0.04998433358606793, 1.3304510472282287, 14.617172345038384, 49.639834204027736, 66.01419602670978, 47.57859337714411, 40.8297985599887, 43.384171532046416, 55.992767733912316, 50.272434065418864, 34.72347228757797, 6.110553606863945, 0.10723142584245052, 0.04755245258791312, 0.035154231178063544, 0.08763541001826526, 0.035286411988518895, 0.024273459491650426, 0.013521499744045639, 0.046771598318892146, 0.01804647467760069, 0.05399111898676042, 0.027996847901733655, 0.025961358032579866, 0.015480491903520402, 0.018837042941501545, 0.04260758103262033, 0.009817178304787847, 0.06470962367471188, 0.02310347660715061, 0.022548024557651054, 0.013559908519739346, 0.027400944494612278, 0.026606036342620373, 0.012732952037045072, 0.06293840924157731, 0.03904229976356991, 0.027364072682816657, 0.01757276612484167, 0.03440096756563552, 0.014717236589339953, 0.017079769393369075, 0.042218507958516, 0.07239400649503355, 0.05060016485531965, 0.07442292907545645, 0.11350429932316465, 0.11509134238886257, 0.05961059607685574, 0.05089153490600087, 0.07008766049459096, 0.05927971504147976, 0.057007195653333786, 0.0312729865207427, 0.0304573901643556, 0.02263217357047383, 0.008320126629945251, 0.05391369431069302, 0.4687048494815827, 26.523500527105025, 56.46432684313867, 60.332619297888975, 52.923544453036406, 36.681990162018806, 44.331435695771255, 43.41739400740593, 44.681224822998054, 47.610333196578495, 35.213788170968336, 11.308232430488834, 0.6186685218445717, 0.06692839050365072, 0.17718769459714814, 0.9021221569949581, 6.535183027867348, 8.462337140114077, 7.06855574923177, 9.217728760934646, 16.611276903460105, 9.391696664594836, 26.582736161447343, 42.25598019938315, 55.6682151363742, 61.893777539653165, 66.20760025516634, 64.72683491245394, 59.49200045677924, 59.14097578294816, 61.51162101376442, 57.64093983557917, 61.67464256286622, 60.97245593224803, 59.17167617428688, 54.494135995065015, 49.18359979506462, 47.6470701156124, 49.22647522341821, 50.261522031599476, 55.17074484978953, 56.74797696451987, 59.42621054187898, 60.457342824628284, 58.37454857364778, 60.238003884592366, 60.23331272986628, 58.28180805329354, 57.544708405771566, 56.28731419963222, 57.242199528601866, 57.70554127231721, 59.44455154480473, 48.30613420855615, 44.72059757478776, 45.16741829533731, 46.751020339227495, 56.8402232662324, 60.18586774026195, 57.86820980810351, 60.30972834556334, 57.57252977740381, 61.64959430694581, 56.52879884166103, 56.63368694243893, 46.99650972120224, 26.308621321955037, 57.952348570669855, 51.90428518479871, 62.56790353405861, 56.291711176595385, 59.01320849695514, 57.02475117098901, 58.499174041132775, 57.807938668035696, 61.08805602596652, 58.569823772676536, 54.877834012431485, 41.64954646941155, 47.47486237556704, 56.94254221454744, 59.136276783481726, 54.33153806194183, 54.2521139883226, 53.29820925189603, 56.75604135759416, 58.84243242202267, 57.437968946272335, 51.83331381890082, 47.64084531414894, 42.07955198903238, 42.47339325566446, 48.14841178155715, 50.734089189960116, 46.52655486137637, 44.50803256803944, 47.947394232596125, 52.31694990588773, 54.51593260611258, 55.21725631529286, 57.167105751652876, 59.115688262447236, 60.544490045116795, 61.81027027868456, 59.128365362844164, 58.141873575026, 50.26434221575337, 34.64979056389102, 19.758300396703905, 8.76179833565989, 8.103275529799923, 9.389541322185147, 9.535906526350207, 11.27652693179346, 6.18045416570479, 2.432274001259958, 0.35525062932602824, 0.09112088790824337, 0.021513545389978156, 1.614786602797047, 15.810269098128042, 44.42532939295615, 55.48462860045895, 41.65769323225945, 41.258988226613695, 48.01778508770851, 60.76420945505942, 58.38809644022296, 41.302240202503825, 8.659373483350201, 0.11632043853281968, 0.01651749150046418, 0.07034996899986459, 0.06617352576746095, 0.06749361017418486, 0.00928488222040957, 0.06366148132890945, 0.07825881558200044, 0.10707216382387186, 0.020665853780003327, 0.01851371744827878, 0.03727260601496504, 0.04743824803060101, 0.05734115253172575, 0.04365197720847303, 0.021114886640721274, 0.038172445229945645, 0.048958480568422426, 0.015622138687890145, 0.04979829296409603, 0.02946346194573468, 0.023615324847219933, 0.02740267776854096, 0.07267946617737894, 0.08929723858713143, 0.1699268051813687, 0.14850030653178692, 0.08025504152981505, 0.1307495743516953, 0.16487249413565283, 0.18825651597111456, 0.2464182176176579, 0.1701214374794114, 0.21311133469064392, 0.1984476150884744, 0.22178931822699888, 0.18291919672441098, 0.10997006759768534, 0.10619965096515034, 0.128412822321538, 0.12836972987579723, 0.12003287763124514, 0.11269159494869171, 0.1604576826456093, 0.14871931574758024, 0.15053338130875943, 1.115160728654554, 34.8802690352163, 69.45940986756356, 70.28629256832984, 62.24768907793107, 44.62464071089222, 49.02021738790697, 51.79358020905526, 46.625704534592174, 55.97070832406321, 50.05677430860458, 12.712684139128655, 0.8914886114578094, 0.2999840045888578, 0.3420226810680282, 0.5882937485171903, 7.745007709149392, 12.21078843839707, 11.078931650807782, 18.28683891604024, 27.45154115461534, 19.13362176187577, 43.33240801288236, 55.59993451641452, 58.927747895640714, 64.69495388769334, 67.83347760477375, 65.29815950701314, 59.26857832939395, 58.35683122757943, 61.986443534974136, 57.407448983961544, 64.6650222809084, 63.311396644961455, 61.202098938726614, 55.562554328672356, 51.28881823632025, 49.10032003156601, 51.492961914308616, 54.231474476475874, 60.16200796250374, 60.80549632349322, 60.22445994038736, 62.6395534699963, 61.41336956331807, 60.944034437979425, 61.34244918823243, 60.22428735609978, 58.121716514710464, 57.01308211972637, 58.26116461907664, 59.3289279168652, 60.17449286676223, 50.85720454492877, 45.5307395996586, 47.875940415167044, 50.345813766602554, 58.087788012719926, 63.098349186681936, 60.08563941524875, 63.351420510199766, 61.24911638998217, 63.97537939010128, 56.658025249358154, 56.60879165895524, 49.330323896100445, 30.76627931287212, 57.45505479074294, 52.52708696549939, 65.02727277817266, 59.677544255410474, 62.22211914677774, 59.259490197704686, 62.13822357116207, 60.12294900032782, 62.61410905468849, 62.370231766854566, 56.90251442693896, 43.22460559106643, 49.68438056207473, 59.463335775559955, 61.94402310156054, 54.98701710854807, 53.13072404553814, 53.203644829411665, 57.85292825391216, 61.03090709255588, 60.757639485020796, 55.06737078389814, 49.45393739208099, 44.91515890244515, 44.27787965343845, 49.09691933662661, 53.22960699758222, 48.30456918285739, 47.46487209873815, 50.71267697118944, 56.44743319480651, 57.04633205167709, 58.86879859432098, 60.28578227566135, 61.092311797603486, 63.641271898823405, 64.59162689024403, 60.952428310148186, 60.14759325212049, 53.84088485471664, 37.180503799069314, 28.9571645182948, 21.49849718616855, 17.23902283176299, 18.232792577435895, 20.490106805678337, 22.549835558860533, 10.146430307818997, 2.9411245546033307, 0.6535836225075107, 0.24371688434433555, 0.13069211775737424, 2.0961383994548553, 18.52269691805686, 63.0524064648536, 77.77183009732154, 56.09829518102831, 52.94867115636026, 55.92683269131569, 68.5851449351157, 65.93400709090695, 49.454674797673384, 11.360779443094808, 0.40955152362585073, 0.08883549441252986, 0.13707410514114365, 0.15688035847438922, 0.09734872307988907, 0.09463829634290549, 0.17491331744578578, 0.1794135017741111, 0.22273745928560534, 0.17970286850487033, 0.12670122868111058, 0.11577545124436579, 0.10747092024933909, 0.11414097201439644, 0.13217601474494706, 0.20745193675881435, 0.10484651752537298, 0.13232409954071045, 0.06924541576975776, 0.141170775637992, 0.06929466756240976, 0.07014200677193942, 0.09640079652590137, 0.2233171273743914], [0.019658287281110402, 0.03658110824143214, 0.06936428963296837, 0.033459269306472236, 0.044916301905628175, 0.04213219283208732, 0.02023192625793238, 0.049312053128115596, 0.09678325826121915, 0.028186408697717616, 0.018078290309096058, 0.055448245031819235, 0.06011696870348627, 0.026037386513405272, 0.004782944029542588, 0.05777336401684631, 0.028520488150177464, 0.06788734872374805, 0.044186024761368195, 0.02589925703021788, 0.06960160835015197, 0.033105279228860335, 1.3360027944849384, 29.143010339429303, 47.782623306397475, 50.70643648024529, 46.16137827596357, 22.68661645150954, 20.465770459944203, 35.11590934568836, 30.208379030227665, 34.187299974503055, 26.291506059708137, 2.5307956049519205, 0.29061456541380576, 0.03384023717033767, 0.20986908205574561, 1.345776360361807, 3.9435877434669004, 5.68347123361403, 12.04394159778472, 6.688298631098963, 23.886983317713586, 18.428862056424542, 33.354565097439675, 49.42516288449688, 55.84106222275765, 61.21075560969692, 62.15915333840155, 61.842963234070815, 60.71372462857155, 59.05272245407105, 57.5313998037769, 56.4870491335469, 57.16946701849661, 60.41900165619389, 56.08593579261534, 54.72428498729583, 54.2940951162769, 49.10373249361592, 51.658713433050345, 56.15420072309433, 57.98011502911968, 58.41407429787421, 56.346585135306086, 54.21903664065946, 54.8082943116465, 55.07999297111265, 56.02975960700743, 55.5736271796688, 57.37914516079811, 55.1765303457937, 56.988308429718025, 57.00903815607871, 54.09664300180251, 41.71393609816029, 43.03688879935972, 41.146604476436494, 47.02725325861285, 54.35152253796978, 58.45757730545537, 54.062690965590946, 53.72822653862738, 50.61083262966525, 56.81052307928763, 50.438020844613355, 58.44314690559142, 44.74215099888463, 17.562949811258626, 55.93859980183264, 53.6344152112161, 58.677100596889375, 54.570904624077585, 52.1965802100397, 49.909363792788604, 55.579510734927275, 55.39630074654856, 58.358741421853345, 56.62273176254765, 53.80868219560193, 40.936891032803445, 44.05287681087371, 52.20591545104981, 58.55973151422317, 55.27681750635947, 53.694811867129424, 52.136222777828095, 55.65415343930645, 57.35095900873984, 57.09007040146859, 53.3387783265883, 48.30051737446939, 43.862987026091545, 40.646949429665845, 37.65233747420773, 40.387319903219904, 40.295218729203754, 43.14238878988451, 44.58501300504131, 48.161830209916644, 50.93960569750879, 52.86668577501851, 53.1814246023855, 54.85029897382183, 57.37748992058539, 60.51962614059449, 62.26427285901962, 58.498393489468484, 49.85139508401194, 42.08608273536929, 26.735916483786802, 14.990641801587998, 7.857323798441119, 8.972571799832007, 13.582711931197876, 4.706565718497, 4.977679944807484, 3.404340292176893, 0.46238771910148285, 0.22371687205328097, 0.009721339747850454, 0.3108203489213221, 6.871363491781297, 41.279953295184725, 63.302485019929954, 40.191424969703924, 24.67215161169729, 37.35979141727571, 44.913064356773134, 46.979667063682314, 38.72282289689587, 12.953359792309424, 0.837723273904093, 0.020915274771170753, 0.03690975613050884, 0.04123894197325553, 0.05661631844216778, 0.05527591738369196, 0.06865883756789469, 0.04133773667197074, 0.027236948052661556, 0.0793318902592986, 0.060820455753034165, 0.005711533566711531, 0.02628399596189059, 0.036701770919945934, 0.03781328788928447, 0.050309855836413564, 0.05774939695613519, 0.02895339677530912, 0.07719948452206389, 0.02663429732614708, 0.02646904833044016, 0.05966752790094865, 0.08439103531981669, 0.06937162875528298, 0.014623230897761403, 0.11476978464352508, 0.034719280928613684, 0.057024409648992365, 0.013690515019510303, 0.030404599045493433, 0.0708949945927147, 0.027861420793699163, 0.0812549548103444, 0.027522838659464356, 0.04837527315342619, 0.0465597941600267, 0.051378169277262305, 0.03217881079763174, 0.05991771689526016, 0.05460768953085907, 0.04058465692064455, 0.02832642850285817, 0.06712518316963989, 0.030618758924726038, 0.06883106945503144, 0.03988329576508653, 1.96616625112872, 35.80406958057035, 57.200485121819284, 58.4954595565796, 54.35990856539819, 28.854467061258134, 26.202562393680697, 43.38134742552235, 33.048435872600926, 37.11602395580661, 29.36438891195482, 3.353740981509609, 0.36249472609450745, 0.0440879310331037, 0.28795023418722615, 2.356753421406592, 6.702561349638048, 10.27686970849191, 13.653479333846802, 10.916245464355717, 13.188615710504594, 18.990580766431748, 32.61704183393909, 48.4872418065225, 57.307503069600756, 63.31135742125973, 63.97933313923498, 62.42923205898654, 59.459593834415564, 58.99052150787846, 58.05744847943706, 56.67063959183232, 58.98713258004958, 61.34400244682067, 57.242179916751006, 56.120276143473966, 54.999223524524325, 51.765947111191295, 52.98973444969424, 58.325868037439164, 59.78025544074274, 59.79680784286992, 56.864616486334036, 56.452163573234316, 56.16506568847164, 55.44382810592652, 56.146304991937455, 55.755436881895996, 56.045131375712735, 55.074654625308135, 58.915514023073264, 59.11357802729453, 56.25646083585678, 43.92369747161866, 43.64768812733312, 42.96005349005423, 48.91523122787476, 57.17943376110446, 59.604874503227975, 55.63516132293209, 55.31138143231792, 53.592281110825084, 56.60461825709189, 52.60005089544481, 57.56107645650064, 45.92324333806192, 19.823819668062274, 56.686497734438994, 56.32115248710879, 60.573888209558305, 55.56408405303956, 55.39729702857233, 52.3571071317119, 57.175876171358176, 56.96780227845716, 61.744539199336884, 58.46027589613392, 55.756189976969075, 42.35721265116046, 46.18015858434862, 55.11948731637771, 60.320408959542554, 55.404439664656124, 54.34262660241897, 51.773097592015425, 56.21760583692982, 58.28342014743436, 58.022770804743615, 54.8223207073827, 49.486606813246205, 45.0096841012278, 42.281095135596495, 40.6742295142143, 41.41201557651643, 42.238039278214984, 45.0245185052195, 46.87885822788362, 52.11052733082926, 52.150610031620154, 55.489088335344874, 55.60592397566765, 56.88402437394666, 58.93208995942147, 62.24077786168745, 63.39958721591581, 60.64836225202007, 52.21619206090128, 43.98690646694553, 31.237354009382187, 15.489774192533186, 8.378950492028268, 14.349336239599413, 12.820112955185676, 6.600804771146467, 9.819327189076333, 5.117594811224169, 1.3852650672197344, 0.3468508123149795, 0.0941947850609018, 0.21369199869373154, 7.245163408017929, 41.866645736079064, 66.89607035729193, 46.027570539905184, 32.83621995679794, 45.60435464305263, 52.06188209595219, 54.582475616085915, 45.40038747172202, 17.037058030405355, 0.8810895501125244, 0.06806906477938737, 0.02917062866711809, 0.043960028823705456, 0.0323184916088658, 0.05675415681194394, 0.09263643964884744, 0.03015600542928423, 0.08043365492936104, 0.11352748880463262, 0.02920793906425036, 0.03908086079923857, 0.05057739289177041, 0.04174475535570134, 0.02761822809735614, 0.052476927052221956, 0.10584188024363211, 0.036675306412601666, 0.059902506219523574, 0.011845149020964821, 0.03631799151339839, 0.032667414014858585, 0.0005487320219887601, 0.050971380419909, 0.11299256791150379, 0.21295545111981132, 0.1666282450840358, 0.2407626807689667, 0.18129628542209827, 0.12818953833512722, 0.1716868921874031, 0.10892251130914497, 0.16523597221220696, 0.09557673106751136, 0.14655689468547223, 0.2323464388328214, 0.14834679783351962, 0.11490188118430877, 0.20883169175396044, 0.1631455634149813, 0.111422692876189, 0.14735603164280617, 0.11204435790498411, 0.08218893090323096, 0.16601454736965318, 0.08546681428748755, 2.977387357142664, 46.36777339443084, 66.00753584215718, 67.12260292422387, 58.222340999111054, 34.820692154669, 30.960487627214004, 44.52115289626583, 41.67744236607706, 46.77985368236419, 31.50331424128625, 3.922637138635882, 0.7756039620407167, 0.2698507941057605, 0.45558816783370515, 3.075883955724778, 9.33235610685041, 16.155084659976346, 24.88916066385085, 18.69586956116461, 34.10150597172399, 25.154371723051995, 39.75712445474441, 54.98695042825515, 59.56399948366227, 66.08442998701527, 64.9454011455659, 63.84514493326988, 60.28275812825849, 60.864826094719675, 58.597853029927904, 57.36834687571372, 59.56006142400927, 64.62461794576338, 59.46682276264314, 59.39038753509522, 58.81532492176179, 54.89908933639527, 56.17843704838907, 61.640565010809134, 63.32053576746295, 61.41345585546186, 60.1771326218882, 56.81013868701074, 55.88075660890149, 56.28089720203031, 57.17460532342234, 56.203748103111025, 57.026582917859486, 55.75194205007246, 59.579810557826875, 60.23596032973259, 60.34633582638156, 45.90361579771965, 46.24319107301774, 44.86820028674218, 51.50791791177566, 59.62105428018878, 62.32343789069884, 59.597312173535755, 58.53030589319045, 54.63695341540922, 57.73791651571951, 52.14098845758746, 58.26458100349673, 47.701508691233975, 22.795713255482337, 54.05811355959985, 56.972171798829116, 62.30326121853244, 58.95329821494318, 57.61179662519886, 55.46777809819868, 57.58633259804019, 60.28725316447597, 63.49404181203535, 60.589095238716375, 58.33530526007376, 45.81622539028045, 49.04999994462537, 58.12981228674612, 62.78421440432149, 56.670627824721805, 54.36305038390621, 51.87884861423124, 56.681092708341545, 59.83616882754911, 60.427426907324026, 58.25541442440402, 51.72340508430235, 48.11750742696947, 45.717060027583955, 42.28236598353232, 43.73722407125658, 46.46183575353315, 47.56863055690643, 49.668577332650464, 52.318887556752856, 54.47091556364491, 56.535902254043094, 58.02334739315895, 59.38497074188725, 62.98794623344176, 62.802990790336366, 67.09025121504261, 60.86432010896745, 59.19838751516035, 48.297375555961366, 33.04811031587663, 21.19885163922464, 17.535257877842074, 19.72885516382033, 21.930350142140544, 13.794444414877123, 13.379150725180104, 7.497901820367383, 1.7366372385332662, 0.5525657979230727, 0.17956920148384187, 0.5845063323936155, 9.086348972012921, 49.19337434153403, 70.41925307243102, 52.93036153239589, 34.70831232686197, 50.47692683435256, 57.87400707121819, 62.45645723035259, 55.010370900554044, 22.365288042253066, 1.5308198116479383, 0.1472489938380257, 0.11547204978283375, 0.2749547476489698, 0.1657419886079527, 0.22083491056917176, 0.2194752270776418, 0.15666579256855673, 0.15643855556845665, 0.1657114063780154, 0.15186764600296176, 0.045322454910004334, 0.12417561299498044, 0.12054113866460901, 0.11900543881159638, 0.1964272114057695, 0.23239758286264636, 0.08591191903237375, 0.17241227019938732, 0.10862206694700065, 0.07544568709788785, 0.16738261186307477, 0.14607243600391573, 0.2444445759418511], [0.08288054742039212, 0.015468372392558284, 0.03801399526456672, 0.005044525708898061, 0.08204373425894207, 0.11991136076469576, 0.042362180087835564, 0.04338814418823008, 0.06581739447410069, 0.059438682116207585, 0.030931024023542003, 0.005679671969940706, 0.0756221477903666, 0.040606536391761996, 0.08147591755034463, 0.055570635238602284, 0.04553112193881985, 0.04809247179617805, 0.01247605402773667, 0.05322918325902955, 0.048574360252748576, 0.03434488226869895, 6.09429047953698, 37.147324469781694, 53.67485484769268, 43.67116351281443, 44.52105091464135, 48.437612056732185, 31.387486650097756, 21.702148606700284, 30.377144890446818, 46.61999356362128, 11.034043065963253, 1.118165264206548, 0.0482149692552705, 0.09339420785827023, 0.35935719767885826, 1.5889591435270927, 8.100772077037442, 8.417112212027273, 5.8745573412987495, 8.256582348577439, 16.379352058133772, 22.74567165682393, 38.90625646037441, 53.66909680827972, 61.62914699123752, 60.8175576117731, 59.69259438976165, 60.08589044693978, 57.13720160145914, 58.04213162391417, 57.09095293475736, 59.011019814398985, 57.41072416305543, 57.13091011970275, 57.409802406064934, 57.65243630255423, 55.48254582189745, 53.074410576974195, 54.038144773052586, 57.08842300599622, 58.10441886225055, 54.90201150217364, 51.50696085345361, 53.02294515794324, 54.34909459083311, 54.80020638435118, 55.88197254365491, 56.91502678778864, 55.307917979455766, 57.185984119292236, 57.13165537003548, 56.00935543737104, 45.68521038178475, 40.73668149209792, 42.01628023578275, 43.36808589196975, 41.78591551319246, 50.08285022551014, 55.683363329979684, 56.457780407321074, 60.33768700015161, 59.1952496190225, 61.21446617187993, 54.35079297711773, 56.58914842913228, 47.38419286666378, 18.98896082755058, 56.13258846344487, 56.15220815904679, 59.233296609693966, 52.49885766736923, 50.69723459982103, 42.64575396814654, 44.16744139886672, 48.820953138412975, 54.989080275258715, 53.35033755148611, 47.822592258453376, 38.67212234004852, 42.55466868800502, 49.366390089834894, 57.6593122174663, 52.65161437373008, 53.49279019140429, 53.68062857658633, 54.524244108507716, 55.1295050497978, 56.98057743810839, 51.89924101675711, 49.49667161510837, 45.291110238721295, 42.65306918851791, 43.22491938068021, 46.32498425822104, 45.76512867404569, 46.7053835622726, 46.74978087025304, 53.22094248187158, 53.97975244829732, 53.32055891713789, 55.78384660905408, 56.71865332511164, 56.53490204964915, 56.602613925933845, 57.72569441026258, 55.96842158225275, 50.240356922149665, 45.23005462461903, 31.30983941016659, 15.52606200018237, 7.043773233890534, 8.247897240423388, 5.916006497798428, 6.297493278980256, 4.703089517931785, 2.284610982864134, 1.2804773546034292, 0.23993814033606362, 0.07129002783086992, 0.16688218790917628, 1.671913472875472, 19.943681416972993, 35.20564925286078, 25.608015406516294, 23.773987677789506, 38.88330275012601, 42.657748576133486, 43.708735896695046, 50.124921567978404, 24.760526534049745, 1.7006059784081675, 0.08130127248624641, 0.02114847002010192, 0.01255458570085466, 0.027257506022109624, 0.017914389628135872, 0.031032821786920392, 0.029542374747595, 0.04862983267934573, 0.02516103746940292, 0.09068041799529906, 0.06458951640994319, 0.025274866643632134, 0.02211347841958125, 0.007168164048644324, 0.033985698114960425, 0.023048555763858943, 0.031134853207115686, 0.020791109155623183, 0.003560205936552056, 0.014727861271239819, 0.03212182917782376, 0.05528835865158228, 0.04948381770161852, 0.05734831928425739, 0.09150334198268191, 0.036726921586500066, 0.042323959961293206, 0.004185447638343659, 0.02003853885276664, 0.039631854217018814, 0.04847453516577521, 0.034288034714277715, 0.06677108967015821, 0.05586102469674042, 0.04908728676157133, 0.059302467852830894, 0.011426183196055073, 0.06464330344310691, 0.03070409154339183, 0.04926869638204094, 0.05846269759199312, 0.03646340649274569, 0.015278267674148084, 0.08361816751740633, 0.08921429424756959, 7.3712646672802595, 44.555179457510675, 61.25355651301723, 50.922555154369725, 48.95686718725389, 46.56755931915776, 31.786525057208156, 31.50979791918109, 28.192990710658414, 41.84918334407192, 12.670190161274327, 1.4055914023230154, 0.15366680349313444, 0.27271795477117267, 0.2500949953232081, 3.883739729081431, 6.5955316347460595, 13.740914848542984, 11.483026973662838, 9.263429276404842, 15.721917709996625, 23.471472917064546, 36.628273302508944, 52.29114071015389, 62.734533663718935, 62.50158802155526, 63.609163376592825, 60.461571139674035, 60.45517375392299, 57.59418518312516, 57.94551580182968, 57.568544649308734, 56.78343911324778, 58.972168737842196, 60.5425210152903, 58.949120890709665, 57.21755527680921, 54.25041560203799, 56.65357335921257, 58.22283914012294, 59.55665288432952, 56.154683174625525, 53.935186478399466, 52.992593857549856, 54.60681784537531, 55.099451849537516, 54.400356046615116, 56.444212928895034, 55.7823835649798, 57.09380449787263, 58.398655460726836, 57.4331561980709, 47.432732197546194, 41.64073682600453, 43.70213062532487, 45.57114393480363, 45.1434604583248, 52.11990179554109, 57.207686593455655, 57.28474547786098, 62.096658214446045, 59.76353829906833, 61.02905181146438, 53.488538342137495, 57.09810341558149, 46.240029642658854, 20.290424823760986, 56.10390024800455, 57.442769927363244, 62.745602592345215, 54.57133608479654, 51.62501242852981, 46.27242449791201, 47.05802817498484, 50.3454803651379, 55.749914184693374, 55.66247278644193, 50.72610324428928, 42.29108149005521, 45.02257300961403, 50.39853826645882, 59.27354797240227, 54.089449374906486, 53.84980040211832, 53.086138463789425, 55.37285281765846, 55.23794681795182, 58.88995193666028, 54.99408129722842, 52.35656584462812, 46.50257349014283, 43.58529498500209, 46.08543726705736, 47.79333529933807, 47.71968103224232, 49.485869407653816, 48.993604106287805, 53.974339577459524, 55.051320445153024, 56.318081271263864, 56.908868666618105, 58.605678158421675, 58.17491954372775, 58.05331037890527, 59.414561102467204, 58.119061070103804, 53.4214932687821, 48.0679992706545, 31.611330432276574, 16.027314432205692, 5.958689730013571, 12.943668596206173, 9.16248708002029, 8.211525101815502, 7.88434696774329, 5.87289180486433, 3.3874152648833493, 0.2538578966332059, 0.09826818180661048, 0.1527952865487145, 2.068052758132258, 22.245130154394335, 41.84475891051754, 31.675861266351518, 28.92513836583784, 44.82410892363518, 47.454834753467196, 50.56876913193734, 57.78844448827929, 30.618425569226666, 2.7551630235487417, 0.020678881105155717, 0.04161958808019277, 0.043508450635859085, 0.014038952874890981, 0.019171530335781076, 0.05410235112292632, 0.026210786684626536, 0.010469020494530279, 0.04650987970132021, 0.015701585836077652, 0.055952664134242845, 0.04014544339189607, 0.05141654262138952, 0.03307617937905654, 0.014258553893605789, 0.09374960370722318, 0.07350026044033228, 0.03154828787721213, 0.015085015291978997, 0.06223733919943052, 0.05301348354306914, 0.0643181604062838, 0.02945431677113858, 0.15384229891482862, 0.24011683800528127, 0.12315248725034537, 0.09631350080692962, 0.1437748310666892, 0.3330921489865549, 0.08531174276985469, 0.14263371245995646, 0.17954059576074924, 0.21842559469082665, 0.16829491532858343, 0.16993368465092876, 0.14868167018698109, 0.11546576020097542, 0.19044237932370556, 0.19453624593875102, 0.08908156185380875, 0.09423780855872939, 0.18958128117505582, 0.15325035809749557, 0.22912885422908494, 0.2568565639517, 9.994839525991871, 52.56511826669016, 69.90446552153557, 58.32362836407077, 55.36196039568994, 61.73720044474449, 44.40354454901911, 33.02840432813091, 43.199031737542924, 57.01165045461347, 15.285792312314435, 1.6844205630402413, 0.39695090944728545, 0.4165703292575575, 1.0428446026579028, 5.320974117325199, 15.647556435677314, 15.271449185186817, 14.350855177448643, 15.342044003548162, 22.666867317691928, 27.834844973779497, 43.567785524552875, 58.25634010376469, 65.2451604412448, 64.14446884585966, 62.904615479130904, 61.22239720436835, 60.25822762520083, 57.28697730648903, 57.455156772367424, 59.059637592684844, 56.366110694023874, 60.26336593012656, 63.3834505850269, 63.95641473031814, 58.93538082799604, 58.58288526535035, 58.91424317513743, 61.0036309303776, 62.74985836398218, 58.927171307225386, 53.376954755475445, 53.23590240170879, 54.42384319920694, 56.793445079557365, 57.27632807147119, 58.72128217451034, 57.07471432224397, 58.66833802192443, 59.2413531580279, 60.07866544108237, 50.08007318742814, 43.92374061769055, 45.85427238095192, 48.22506273946455, 46.94639359751056, 53.597843031729425, 61.27100713791386, 58.898079087657315, 64.68777987264818, 62.602192894104995, 64.06118908236104, 55.60282530323152, 56.80469051484139, 48.93809472360919, 24.330642607904252, 56.30976584649856, 58.32116511560256, 63.354130867988836, 55.942239761352546, 54.47674420572097, 48.892461869024466, 49.360679118864, 52.54568684485651, 59.60940091840683, 57.87332065643803, 53.50516526929794, 42.99448013305665, 47.120095760591575, 53.14633507882395, 62.61564270142586, 55.355253142695275, 54.23893090217344, 53.92931469025151, 55.21318489505399, 56.61764837080433, 60.82706935944096, 56.76065014254663, 53.29817395056448, 49.97155689424085, 46.586143509034194, 50.26893138885499, 52.294055031191924, 51.53789658700266, 52.06362755067887, 51.00970629722842, 56.92697432733352, 59.23287691608552, 59.135939459646906, 61.267453470537745, 60.479115901454804, 61.179149150848396, 60.61794427133376, 61.22591949278309, 59.04160645700271, 54.981164932250984, 48.81584229007844, 35.59642714838828, 20.661263350517522, 11.466760904558244, 16.11061086577754, 15.365400737331761, 19.950600477956957, 18.810910717133556, 8.951227241946805, 3.3656566517968334, 0.5291683695489361, 0.1989725078906744, 0.38598414630659167, 2.0249748374185255, 24.875165647076024, 46.880576226019095, 38.61248270157845, 36.036269972401286, 51.35975822325676, 56.14362209073959, 59.1093183332874, 65.67307925993397, 37.74777658524052, 4.31382320580944, 0.2175236180905373, 0.11712387324340882, 0.14988131791112885, 0.17543655549806936, 0.14010116367811157, 0.16896663654235103, 0.08156198752863754, 0.10345356283529152, 0.14680513781645607, 0.16817923605201707, 0.18580747077301626, 0.1485986109342306, 0.11284222315636375, 0.1836869547203664, 0.1525257002081602, 0.09953255629948071, 0.11167158718190848, 0.13812272629189876, 0.08484275906436867, 0.11807368437369024, 0.1702479492392271, 0.1496092494456999, 0.15410469935065316], [0.02785627076762819, 0.04177364070088633, 0.0919108777757614, 0.010950944382667301, 0.0332963262354174, 0.04268468395175953, 0.04047177386500182, 0.031896605073744734, 0.06739918217663804, 0.06358976400787793, 0.03802297381503928, 0.05584694017025252, 0.026183035149569475, 0.042288405820727355, 0.03472846249238618, 0.05958842166188744, 0.05488248143885886, 0.08278392841138187, 0.04445450027443228, 0.10105970661125838, 0.04836329536873007, 0.4079111761623814, 9.263828377569876, 41.040010144633634, 53.922458387190304, 44.53254738161641, 47.416219019120746, 58.08850972883163, 21.643987701785182, 23.35207989138942, 46.082817123782256, 30.305545945321363, 6.943033529866127, 0.142140704237165, 0.09786983906862237, 0.1860037884644924, 0.33157183217906183, 2.859822155967836, 5.024781236725469, 10.703811857008166, 11.919167080233175, 11.475789220102373, 19.874212318851104, 33.49151072963592, 43.32070366028817, 58.0807081345589, 58.72092916119484, 59.78328351051577, 60.773011253726104, 55.294974157887125, 57.104014427431174, 59.20913088706232, 58.4784992279545, 54.19979741496425, 51.005791771796446, 55.05295215114471, 55.81877923780873, 58.87648251748855, 57.453662349331765, 58.29999608378257, 55.75663320479855, 56.483899470298525, 52.983325296832675, 53.795059803993475, 55.1190911569903, 54.04018832791237, 58.40242485846243, 58.25963881707961, 57.218292682401604, 55.98643310608403, 56.35783057059012, 56.23350712560839, 57.06959955153927, 51.65585010282455, 43.342990567607266, 42.126738102205344, 41.21820342156195, 42.91819395557527, 43.48899295253139, 45.99258299796812, 52.63286544430641, 53.87791595151348, 58.326185749423125, 52.86893329312725, 58.47465530518563, 52.695972458008804, 61.82701487695018, 40.40994805674399, 22.232808028498006, 57.93925569903467, 52.72127959036058, 57.2561082532329, 52.59623050689698, 53.72209979641823, 48.534223956446496, 45.69509867698916, 39.60764684984761, 43.87889615951046, 43.17975328814599, 42.64092553046442, 40.86695909500122, 39.89901619572794, 46.44065887697282, 55.78566266644386, 56.221398768886445, 52.684613273989775, 49.90689269958004, 53.67583936260593, 53.99150386933358, 55.87108012168638, 53.11556408482214, 51.97431910422541, 49.77823111318773, 50.87665950098346, 51.1422824090527, 54.998513575523134, 53.50676951869842, 53.033849347022276, 53.062196316257605, 53.80936468801191, 53.840751494130785, 56.89985113759195, 58.27060184171123, 61.061611406264774, 62.19576081921978, 62.21177977900352, 60.946654581254535, 59.739454946210316, 54.64289972859045, 48.86216155944332, 36.654372753635535, 22.09026321288078, 7.325428339742846, 15.691286940728466, 9.530551510472453, 4.367128706747486, 10.082042640255345, 7.4672141767317255, 2.814232937751278, 0.6794838907737887, 0.19102555609518485, 0.04940489149321953, 0.3309942018841544, 7.961341623337039, 35.31462054098807, 46.29516247780093, 22.963582854117117, 26.125605490899858, 31.751192346695934, 45.427973501143924, 51.39631079089258, 31.094305169197824, 7.411617031020503, 0.3929535852324578, 0.06742958820635273, 0.03293002512486231, 0.003815414243182468, 0.034860183650086966, 0.09497730557115809, 0.026327323979668082, 0.01301563177783523, 0.02279780369492308, 0.05521538111591532, 0.01961231242955452, 0.013034336772116442, 0.04729418519644007, 0.015099900380347767, 0.01630152173851046, 0.06200470510990389, 0.013742330333878918, 0.08909601793293992, 0.021911403577354167, 0.05021508692974045, 0.04690117059996532, 0.011781270694618505, 0.03413749077627736, 0.0206486857496202, 0.019494980318291534, 0.01756291614935523, 0.07920167829480865, 0.03699437054174562, 0.018678064375454863, 0.09898514051230685, 0.04028759866712555, 0.08284467152289807, 0.075501695786032, 0.05902943028617771, 0.06585126322123312, 0.022951429221598853, 0.017741770866597374, 0.0721165524314969, 0.04684437667169879, 0.021916046070175308, 0.06291297129205158, 0.05984780754172995, 0.09206651619845822, 0.057533892592595476, 0.3069524016351469, 11.71553134918213, 48.48406076431275, 62.28609692665839, 50.19659111576696, 52.499932396796446, 65.52384091961768, 25.797614935905706, 27.01828399012166, 45.211505736074145, 33.783954804943455, 7.250670906036132, 0.35266664540094717, 0.014707369376875222, 0.1751747985761012, 1.249792285023197, 4.86773737976628, 12.590555260258338, 13.56442289967691, 8.39954979958073, 5.836113210647337, 17.24761478362545, 28.760985212941325, 42.88268081603512, 58.4922000669664, 62.44659639173939, 61.299687508613836, 61.937005981322265, 57.03684383823026, 57.474266559846946, 59.12865954060709, 57.91613332686886, 56.590442811289144, 53.269540648306574, 55.15483963874079, 57.7843613009299, 60.86362977181712, 59.68848374582107, 57.921648179331136, 57.284415998766505, 58.02428091725996, 54.47342588055519, 54.74081777757215, 54.276134583257864, 53.953998165745894, 59.34963803137503, 59.8083435335467, 59.81030079626269, 58.24434941814792, 57.50312735957485, 57.90429561368881, 58.2874523439715, 54.170967994197724, 45.36592160501788, 43.83015678774926, 43.3008917685478, 44.44773789375059, 46.10399007797242, 48.74094463163807, 54.494814565104825, 56.28537262639692, 60.44366159746724, 54.98842916181011, 60.66243571619834, 55.400835006467766, 60.53968121928554, 41.60567083666402, 23.555911740949078, 57.98049157665622, 54.0847856767716, 59.13060503621256, 54.756511180631584, 56.63517744310441, 49.567368415094194, 47.946394028202185, 40.81370507517169, 44.685504128856046, 44.87840629393055, 45.57667055437642, 42.55259375418387, 42.284107515888834, 48.423903372979936, 59.671762681776485, 57.16943563953523, 54.62048730542583, 50.44806603462466, 54.523804803048414, 56.01813370181669, 58.08517963655534, 54.49155507549163, 54.82033991044568, 50.53219695245066, 52.37658562198762, 53.95216249650525, 56.565512226473906, 56.01725509089809, 55.08894381984588, 53.656317726258315, 57.12892147802538, 56.01555670461347, 58.25628911295245, 59.223745638324374, 61.30419038957166, 61.81058406829835, 62.44765543168592, 60.31488233996976, 59.95293778757895, 56.55634172501103, 50.592750503170876, 37.836967360588815, 25.055018086587232, 7.836936789174234, 11.085096636126119, 11.346354926786116, 7.9810986018949945, 10.171856091868493, 7.654129334034459, 4.105119772495763, 1.6815840765353174, 0.2651135515301459, 0.04930649516022494, 0.3073509512168746, 9.251987722612197, 37.372099814876435, 44.78020191192628, 30.750525113075014, 33.78233486606229, 37.92497750251524, 49.547132907375214, 58.22645948779199, 36.01048823325865, 9.78577523462234, 0.18062372151161396, 0.06816506325717896, 0.10529959724555094, 0.013791645328784663, 0.05828697234392167, 0.1018121658313659, 0.02818874143544705, 0.03678333247080445, 0.03874864294043472, 0.014842073489431173, 0.033873738195266456, 0.033416498617659655, 0.03862800324455865, 0.037944373194008105, 0.02231200244427929, 0.08208684202644133, 0.03128586637396966, 0.04497186626277624, 0.09905090149972709, 0.04700187285761199, 0.010199812409888593, 0.05240441299974919, 0.046872476776761395, 0.1086478841100489, 0.1896433649404395, 0.17717137692436097, 0.1458443103418235, 0.17437239808420982, 0.15152845291360734, 0.23518810409211346, 0.16566634508630923, 0.20026338136484548, 0.12831388206611719, 0.15048543952645796, 0.14866654761135578, 0.06259159740781592, 0.10426367017170114, 0.12887699499485955, 0.22171909860785932, 0.11766352089903048, 0.29501197138620966, 0.15696891823843603, 0.2346707036298129, 0.14867699705064297, 0.5643517235594412, 15.604289750899039, 57.31527328491212, 69.76401329040527, 59.20362387934039, 59.592283694974846, 67.65587268337127, 31.45102904688928, 32.2313924374119, 58.096095592744895, 37.86338452369937, 8.991798277824156, 0.4572304764822607, 0.22112037025151715, 0.3435314759131401, 1.1463617124865133, 6.344109177589417, 14.774104414447663, 18.574399640483243, 22.470984151286466, 20.537494920915176, 21.17664514049407, 40.33224198126024, 46.5215773736277, 61.38870569967455, 64.74589763149139, 62.24229189657397, 62.76171568901309, 58.44265268694971, 59.64354515075684, 60.583725513950476, 58.98641086393788, 57.010430597489886, 56.93121048711962, 56.26940073505525, 57.710758024646395, 64.23014909990373, 61.651257391898866, 62.12766847302837, 59.7938072296881, 60.161878524288056, 55.67611478990125, 54.51314772329023, 54.13533718355241, 54.25938606262208, 60.546341403838134, 62.78153934786397, 62.16668036676223, 59.948956581854056, 58.22094071295954, 59.18509852501654, 60.14257654067009, 56.682077223254794, 46.70123761700046, 46.39771284595613, 44.454739324508175, 46.29939079284669, 47.49999300126107, 49.99588735641972, 58.04801910154281, 58.17421351709674, 63.83631960038216, 57.84211035697692, 65.14967033939978, 57.27313526215092, 61.92234808398832, 43.059363980447095, 27.34503507614136, 58.31757614689489, 55.595804260623076, 60.623184557883974, 56.93868652466805, 59.16211343580677, 53.250976070281006, 51.515994071960456, 42.44922753303282, 46.74359137012113, 46.793025001402825, 46.415814584301366, 44.824473704061205, 44.84943959020799, 50.884880788864635, 63.16303691556377, 60.36463368323542, 54.81435045119255, 51.17404576270811, 54.92178809258246, 56.779756007655976, 59.27343814603744, 58.6032659007657, 57.026178913731734, 55.93285745190036, 55.00691137006206, 56.93107320416359, 59.613217384584495, 60.19222590231127, 57.99685178264495, 58.41687094780707, 60.03367585520591, 58.180728573952955, 61.36674827144992, 61.67606246086859, 64.57129332327074, 65.41617970312795, 64.7643013923399, 64.48752326350059, 62.88374846981418, 58.7991726013922, 53.18641385724468, 42.177744603926136, 28.452902647756762, 12.71107106439529, 26.902468166043683, 21.614116891737908, 10.482021435614556, 17.740131116682484, 19.616877378955966, 6.003969080986516, 2.440090794717112, 0.5956220843138234, 0.14537742571725001, 0.6237102996918463, 10.977343243937339, 45.68497896194459, 59.5263643418589, 34.09671675774359, 35.76746602212229, 43.10227078776206, 58.65584919529577, 66.47498038507277, 44.43252694222235, 13.546250558668568, 0.5389019762796741, 0.20888861208673448, 0.15533007230729828, 0.13716565264809516, 0.2671247468360009, 0.2752180061032695, 0.12058275256065593, 0.11862411854728577, 0.15614142070614523, 0.07840971958132521, 0.11110210040163611, 0.10040239551134648, 0.14694504079318818, 0.15176362658460296, 0.15334037342859855, 0.17458109575654232, 0.10964307828896469, 0.11628535936676687, 0.1721757022483695, 0.12688004126351687, 0.21187725897517898, 0.1262052633589314, 0.14228158780644018], [0.08913551742631583, 0.08572156150494853, 0.08652142624581054, 0.045098427818306995, 0.026725603515402447, 0.03322029583937219, 0.026928593832699042, 0.03581644907113045, 0.010512767945446316, 0.052173150207607016, 0.03482806158342189, 0.06397838509010692, 0.0028345447114383384, 0.06725521893390725, 0.044185067151462844, 0.056233768606738704, 0.0266590170682438, 0.04941026560000835, 0.0796360195043587, 0.021984679887311596, 0.07706322812385137, 0.5263001363604299, 14.238673429335318, 46.80706708661972, 53.31971168518067, 49.721752905076556, 37.26237150930589, 28.350012994581654, 21.020636789260372, 35.43355464935303, 40.969070157697125, 23.16211165920381, 1.9376106608298518, 0.22734670389083125, 0.08503723048394726, 0.4239903198134515, 0.35335903566691185, 3.627519232611503, 6.779446669163243, 17.721646947245446, 8.97107933798144, 6.659407433002226, 26.30112567255574, 28.72032396255001, 51.50792967888617, 58.10332844334265, 65.74498022756269, 59.49730742362238, 58.93784015409408, 55.21584033966065, 60.033518960399014, 54.53916480464321, 58.77599531604398, 52.7821586978051, 53.25762056535291, 54.91506907247729, 56.927511692047126, 54.82829839952531, 54.96141972080354, 52.834569408047585, 56.2646899684783, 54.587825729000954, 56.33920715701196, 54.35939865727579, 54.204088487932765, 54.54355001449586, 55.648913152756236, 52.30901887339931, 55.01142994050057, 53.25967196495303, 56.59761682633431, 54.281959302963756, 54.55151242594565, 42.23901202601772, 41.19017024194041, 41.37013250781644, 42.32359793878371, 40.8263272623862, 43.75345091665945, 42.117646048145915, 43.74798313263924, 42.46783133476011, 50.90829733879336, 50.80957912629651, 57.14656037669028, 52.4137814583317, 61.86581104032455, 35.5528849171054, 23.1603701268473, 60.05140889075495, 50.04160650314824, 61.46013990525277, 54.6644570750575, 55.26645460436421, 53.671705184444306, 54.230066345584014, 48.774708394081365, 44.323932201631614, 40.37497620428763, 42.00934548531809, 40.72765611833142, 42.46771758602512, 42.30291920323526, 53.33658572166197, 54.50161595498362, 53.241279971215036, 51.598936511624245, 52.711536422852554, 52.2604795425169, 55.35955598277431, 53.376236961733916, 53.233615659898334, 52.633889182921386, 53.31668361540764, 52.621321908889286, 55.31293861327633, 55.449919546804125, 56.62325343778057, 56.08889718209544, 57.045947659400206, 55.35925788264121, 57.072670767384196, 56.31578668471306, 54.98649935568533, 52.96049318005962, 57.29914449876355, 58.91149359364664, 64.21949202014555, 62.87199312640775, 61.60821330162787, 39.90397014925557, 25.258434164908625, 11.600680428166545, 13.269639130561584, 6.994824995917659, 5.143052464531315, 3.9144734605666134, 3.823189610435117, 4.800136800735228, 0.32788152536076887, 0.1953373594029296, 0.11361486113239681, 0.12184775524562406, 3.2990996683797533, 25.021617143384873, 39.558507396328835, 24.66686033433484, 22.977236624686952, 31.036673784255985, 49.49565179886357, 49.60953389444659, 36.94888391802388, 14.356018977780497, 0.8572381073909422, 0.10604484757829098, 0.06362992616730832, 0.020756662012107914, 0.008828214335916264, 0.045910201395951936, 0.06667076279559443, 0.051038026238881776, 0.05937814967887056, 0.025125165402348486, 0.033656640368844234, 0.017479456615664305, 0.015729552833363414, 0.06571219528033849, 0.031156749915211435, 0.06599033116212775, 0.01820060582230649, 0.04266038364280136, 0.01557888727890508, 0.05076153361569009, 0.05445671658362112, 0.01899366961762069, 0.007263180976282926, 0.0763519614514324, 0.045119621640732216, 0.01812229822990635, 0.017198225738660946, 0.01176004718628622, 0.03897843484376227, 0.03834997461507878, 0.060815744312299844, 0.04592295292945159, 0.03646688836236154, 0.02515082360215245, 0.016059791312492903, 0.046649089368480834, 0.020663605311945565, 0.08119890015692481, 0.04181459193087874, 0.024348110929431937, 0.022235318958278627, 0.025627008534126708, 0.02962256500106906, 0.02290130217349337, 0.5403303931797705, 17.38004380656827, 53.82363819306897, 60.71399134974326, 55.27473472779798, 41.253194885869185, 35.180824572040194, 26.32295758493485, 33.82128400187339, 44.55872135777628, 23.677793510498542, 2.701591046587114, 0.03525003430343444, 0.013338066693846018, 0.07694841452663945, 1.7765625542209995, 5.836198522198585, 13.877823218222588, 16.657823670294977, 8.818100037113313, 8.920671978304464, 18.11750235096101, 28.463722505877097, 51.005987890305065, 60.24817459044918, 65.71336200160366, 61.18642906988821, 58.92788125622658, 55.391421318054206, 59.28653886241298, 54.76725455253355, 55.95810574869956, 53.86937695164835, 55.18496736403435, 56.076831971445394, 58.320733654883604, 55.11058745845672, 55.56377810816611, 56.92415022080945, 59.06208907404254, 55.96770378851122, 57.57684830696353, 54.90811078779159, 54.02052156386837, 54.963741763945556, 57.49598864586123, 54.915684884594334, 56.21803729764877, 55.95000605429373, 59.12654538308421, 57.02140146686185, 58.24598896887995, 44.56929606776084, 42.95105165050876, 42.871098056916274, 42.574119721689534, 42.92688985024729, 45.342473676127774, 43.40349312751524, 45.159824586683705, 45.557760807775686, 52.22056942601358, 54.76597193748721, 58.31239469589726, 55.92809569451117, 63.090398542342655, 36.873633246268, 25.23476658328887, 59.39703987490747, 51.599415040785274, 63.08311470093266, 56.029779218858295, 56.19752330164756, 56.694397387966035, 55.79681004247358, 49.47983680232879, 45.31700180422875, 41.79421917084725, 44.44996972237864, 42.59277843659924, 44.351118149295935, 45.59022234332177, 55.286827395039225, 56.645583491171564, 53.025294657676454, 52.46004189214399, 54.33824923730666, 54.038034946687766, 58.03072537145307, 55.60446877633372, 54.700193789697465, 54.615474516345614, 53.87336207974342, 55.230976766155614, 58.68789103723342, 58.74333766198928, 58.74760127836659, 58.069709808595725, 58.52805837508171, 56.798865795135505, 58.93893057300199, 57.24764770077121, 57.03574165221184, 56.96535471946963, 58.23439444265058, 59.28763320369106, 64.53279133765929, 64.0994204244306, 60.7059387237795, 41.83869100386097, 26.159086842690748, 11.070182804138431, 9.332712061943548, 10.889850854873659, 10.726185056471056, 9.595171578468817, 10.640280246734621, 4.819257374732725, 1.8116964495951131, 0.723300626681697, 0.11225400552634271, 0.22605602959952048, 3.7116751555473577, 27.788784580845988, 43.530899555452415, 25.722893784123084, 26.830057290292558, 37.20179050199447, 56.445424941278276, 57.54323359458678, 43.60571876648934, 17.48280598271278, 1.0732287529014772, 0.16519656464938196, 0.060345561679212324, 0.06456140864400134, 0.0391230492612287, 0.007581360273874335, 0.029355556546379964, 0.022095216798686215, 0.0199717034270326, 0.026266668968263174, 0.0368738112851016, 0.04929625256467731, 0.05837856581614864, 0.06735105653323474, 0.05144880641432059, 0.05694338052924122, 0.0892577161111178, 0.014952242678602137, 0.01699917311329515, 0.04884267488734857, 0.07979904301464558, 0.038004292761005705, 0.09138020100973307, 0.17794215330673804, 0.19690747192550093, 0.14607718574904627, 0.07705739819474759, 0.0925355841736159, 0.11171778994462184, 0.15202910669388311, 0.18348349708943598, 0.10632438540098169, 0.11270464908692146, 0.06584367128990351, 0.1813160658123032, 0.1458912562098234, 0.12930102466094878, 0.1643875451578248, 0.1618995214061391, 0.07504179788332793, 0.21489088032995501, 0.1451078546984542, 0.10964997308028322, 0.20130558269879512, 1.3092187671892106, 21.750421216410977, 61.8761896318005, 69.13125653420725, 63.24264141821093, 49.35652140648135, 40.76018041180026, 30.591500459178803, 48.343730126657796, 52.252230798044515, 29.777014409342122, 3.1205094966196247, 0.41905318957663357, 0.35289420415797546, 1.144494419136355, 1.7282512111048547, 11.033925394858084, 16.57498517344075, 29.051305324800555, 19.461329906217514, 11.88563964059276, 29.369919453897786, 32.41061141414027, 53.71038367671352, 60.80053060285507, 67.78502848840529, 61.47861819113455, 60.916864179795795, 56.65902545375209, 60.225020839322006, 53.90379967228059, 56.63072555295883, 56.82658126277309, 55.43379076065556, 55.15141933195053, 58.30924503264889, 54.65607889236943, 56.589811309691406, 57.58033137167654, 59.58780434823806, 55.79199729427215, 57.25164067360663, 56.022683651216575, 54.6183809926433, 55.3696168622663, 59.78327174340526, 56.47425043967463, 58.57650356907999, 57.91406231541788, 62.706025877306544, 59.92008009264546, 60.76792001724244, 46.97155952453614, 43.68319342213292, 45.92404742394724, 44.21287813494283, 44.716828177052165, 47.55983660298009, 47.06824202691355, 47.71797480121736, 46.04267950980894, 55.95274779104418, 56.46555846737277, 59.51187118407219, 58.39791805513444, 63.25547933578492, 38.909723835606734, 28.3192753407263, 58.94107218711608, 53.564330300977154, 64.81295839432748, 57.71459018030475, 60.65853688024706, 60.01414245174777, 59.55995944238479, 52.450765486686464, 48.421424435031035, 44.819837462517526, 47.2291454961223, 43.31795407879738, 47.071195571653305, 47.09827953769315, 57.77897196431314, 61.397938959060184, 54.94855042426817, 51.05468019362419, 55.298735710882376, 54.13840055465699, 59.374321506869414, 57.832955544994725, 58.383326838093424, 57.957749674397135, 57.03693013037405, 58.3608869583376, 61.75495309214439, 61.35609119169174, 61.83133732888007, 61.68990842757687, 61.292540950159875, 57.545959641856534, 60.97566050867881, 57.416470435357866, 57.4334111521321, 56.14779157023276, 60.176999261302335, 61.15155919905632, 66.65146350860596, 67.35505827011602, 64.56910071834442, 47.30865586188532, 33.080097244631865, 16.77477894290801, 23.655865500050208, 14.060034963392443, 17.526363903476348, 14.653704320230792, 10.905391285496375, 14.408589524607505, 2.3437480676558713, 0.7883785088216105, 0.46460977244761686, 0.49965103246992637, 4.349144149211146, 33.67783115756127, 52.514445166434015, 35.73771484436528, 32.827753520780995, 44.545765769097116, 63.817841314500384, 64.42187063155636, 54.45281774766984, 23.41918576148249, 1.8528938389593557, 0.38796475938250946, 0.25036439780266057, 0.07552341437868534, 0.12475729589500736, 0.09540773973229433, 0.21951800542733363, 0.19712963742354225, 0.10330142543440866, 0.06279924553969214, 0.10322860111632656, 0.1581271665711557, 0.11930972893512058, 0.18287854809914866, 0.18562385481932472, 0.1593827693572929, 0.1917080791486848, 0.1517157614110939, 0.08517269015071854, 0.15162660409846615, 0.19300341125457518, 0.10710145902609634, 0.1737486033309852], [0.053851549258275386, 0.01906468596820149, 0.10841714608813487, 0.048463767799999447, 0.05630672315976793, 0.09208108719077804, 0.03716528475765259, 0.03530792373743269, 0.08174386446274097, 0.09638516833224604, 0.02684478572900257, 0.06945484122561832, 0.04937473444208022, 0.05018956471054305, 0.036749570975981416, 0.1467486618146781, 0.022616916929461786, 0.053564270117109826, 0.020027223734125014, 0.0591753623748739, 0.03355285460730234, 0.8528775962129717, 19.702528215223744, 48.53245104512861, 53.75599299707721, 40.90835186742967, 28.356883025938465, 17.939889584818197, 16.192996328876866, 36.95322205943447, 35.68886172386908, 14.043059925879202, 0.7301230380131353, 0.05510845822432349, 0.18002621889595063, 0.09230563522226388, 1.234987666529994, 4.4601555601243055, 18.12050884769809, 15.183042883872988, 2.541971418165392, 8.057324472934969, 18.977295698658114, 34.045172891309186, 50.22516166010211, 59.868371486663825, 57.019275542228456, 58.638229908481726, 56.378356333701845, 57.76435721305109, 57.954611778259284, 60.52693743859569, 59.091887320241625, 55.87878365670481, 56.22304616435882, 53.786356064581106, 53.8922090684214, 54.739452792752175, 54.38327804688485, 55.4940854349444, 55.62394334423927, 54.23513797021682, 52.626424912483465, 51.065247058868415, 53.825866099326845, 55.006338704016905, 52.52311752688501, 49.41493726545765, 46.47206137257238, 44.66809665003131, 47.716731409872736, 45.48471058568647, 42.39462814023418, 41.63682622294272, 42.15437512243948, 40.868520198329804, 44.87882598753899, 46.76302671432496, 50.06465435028077, 48.530085855914706, 47.77568463356265, 44.793738011390936, 49.29428123658704, 46.64444954164567, 56.67252232951503, 50.59194249491538, 61.03860670520414, 32.384515885383856, 26.868500440351426, 60.420296038350756, 46.91688168433405, 55.8299893717612, 53.485882897530836, 60.01274216559626, 54.616557090513176, 59.61219756833969, 55.50000429153443, 54.448746327430975, 42.16423203868251, 42.54307023940548, 40.9124428995194, 40.026046076128566, 41.12752606791835, 52.974641169271166, 57.47924012522544, 57.90790027187717, 50.858141991399954, 54.30539938711352, 52.40166133449924, 53.736706702939934, 54.671023122725956, 56.37275126672561, 52.700251763866795, 57.047422470585, 57.16314415777884, 57.5865287165488, 53.68143266247165, 54.785356290878795, 55.64111940322384, 54.04560512112033, 47.33252348438386, 51.15655591410976, 51.3185223456352, 54.284242122404045, 56.5347529995826, 55.275985963882945, 57.4118616504054, 53.72043671146516, 46.05526639569191, 44.78023721325783, 43.263103654307706, 35.872236451795025, 13.81237356893478, 9.029012745426549, 14.822103438838838, 9.08599497810487, 8.325521926726065, 7.9380991285847085, 3.2805289616507873, 3.01822756567309, 0.25682872431653164, 0.07849323848683028, 0.11773897289869287, 0.762095503028362, 14.32112753391266, 40.744275200751524, 42.99274644544048, 22.55712724501087, 21.564198847739927, 37.70954524317096, 52.482673968038256, 50.69796416067308, 26.20683385479835, 1.291421502828598, 0.05587250452428576, 0.023792949993343606, 0.07087657017813576, 0.04552361810760153, 0.03253080521620089, 0.007378910527369309, 0.06622769584458682, 0.10765986817498362, 0.07309811790623973, 0.061366733899640466, 0.052639199796343045, 0.02507912543331904, 0.08909165123177153, 0.08515949811666243, 0.01446390567692898, 0.0346641417502636, 0.08778118122849735, 0.09142550744957502, 0.026987161254510287, 0.058384150597116644, 0.03254591630050733, 0.09094172292539189, 0.09304947595322326, 0.030638257777618787, 0.06633333170846586, 0.019359938169438994, 0.040860333660196875, 0.02081155221188261, 0.05763160327689783, 0.011203767761828439, 0.027745295270916917, 0.016779288642048355, 0.08377248060799415, 0.02772610476841369, 0.10380031721245858, 0.05032293295728103, 0.02710891369309637, 0.04077645469336741, 0.03128795396356333, 0.054020931298333796, 0.03388964218057452, 0.01987263293666465, 0.047610280734877435, 1.1566842876134382, 22.67564558213757, 57.893210995581846, 60.40443789574408, 46.875900760773696, 34.02871854843632, 26.678626345049953, 24.59443376910302, 36.33276585609683, 39.82393418588946, 16.442900338480552, 1.079717211184963, 0.01713020287664427, 0.05836738859333339, 0.6029901341084511, 3.9536569579955074, 6.905370931471548, 11.924017090951244, 15.350594770523811, 8.123816982392343, 9.793601343708655, 20.581250921372447, 35.31823304391677, 51.313435031521706, 60.46856472569128, 60.1384815862102, 60.766362836284024, 58.36967306752359, 58.35219106366558, 58.26360433332382, 57.58644242440501, 58.00938767771567, 56.13967618634624, 56.81657921883368, 54.41851269814276, 53.43404877570368, 55.629607246768096, 54.59143038718931, 56.950335964079834, 56.726380394351104, 54.30035521907192, 52.324841714674434, 51.84426507642193, 54.48607944673108, 56.77737905133156, 55.20570101276521, 52.66996322139617, 48.83567771603985, 47.16917245618759, 50.07414648609777, 47.64481867513349, 43.57166474865329, 41.422794249749955, 43.57117053001158, 42.89915084838868, 45.77645255673317, 47.94764918665732, 53.06823676632297, 49.00097031747141, 48.737681219654704, 44.955100397909845, 50.53036520558019, 48.36475795315158, 59.06077115766464, 52.36987052425262, 60.72797852177774, 33.35113694590907, 27.35382510769752, 60.96956122306086, 48.17207544080673, 57.26144659903742, 54.97405759749874, 62.04233338755947, 56.36028989668816, 61.132692598527484, 58.862205090061316, 54.02459298410724, 44.470891644877774, 42.864343735479544, 42.81141527237431, 43.450498811660275, 42.875145942934104, 56.12298257889287, 59.92044487307149, 58.07599344561177, 51.507207962774466, 54.77205945599464, 53.80378707762688, 54.805646711780184, 56.02096173071093, 57.00790851346908, 54.86430968007734, 59.06909050480012, 58.53720926469373, 60.05914772710493, 54.00430256320585, 55.8769872111659, 56.75036961032499, 56.77517075692454, 49.292720133258456, 51.71271270321262, 53.23890301489061, 55.53013593919816, 57.29981914643319, 57.20243061742475, 60.207731031602435, 57.44031844600555, 48.92477043213383, 45.72198260215021, 44.86703926517118, 34.193218831093084, 14.823786135642761, 8.19009131000888, 8.665661042736424, 9.330861683814756, 10.911649427106305, 8.107081699755884, 5.752850607518227, 4.5070146456841504, 1.4625934920003338, 0.037651999568146084, 0.08815196012296984, 0.9305787074469751, 15.999922560107326, 44.18336622176632, 41.8712309868105, 25.473011347555346, 27.600499045464304, 44.61073983100153, 57.356462094091604, 59.29503471620622, 31.926463457845877, 2.74678336997186, 0.1362531653214847, 0.046345618959035606, 0.0290973408658418, 0.05870903699448513, 0.041043715957071514, 0.04154915395643442, 0.05608374177808723, 0.007542557441704577, 0.02996750758029521, 0.023794097210010214, 0.030223786973604755, 0.1126057394750176, 0.05101588629787007, 0.016806848655124346, 0.02517808675615778, 0.0733726914791811, 0.06269452132044301, 0.04904875253898002, 0.039457783718863805, 0.07953874165973357, 0.04440768081093988, 0.07835450762462232, 0.15081245181781633, 0.08330834623906883, 0.17282100875050793, 0.183278001664627, 0.15670296315464283, 0.20509368830150176, 0.13135760301543822, 0.13176791970768284, 0.2441920273967328, 0.10953013394628802, 0.17041953761250744, 0.13458474839646972, 0.21266141125271398, 0.2284539614113108, 0.14443294655892158, 0.3697453499321015, 0.132139319133374, 0.1775612543907858, 0.1426510260470452, 0.07590912432680208, 0.17207367465861384, 1.776233075126525, 29.893406821835427, 65.30226230621338, 66.86555431735131, 54.14633943188576, 41.855714090408824, 30.125524843892745, 26.035443928933915, 47.011202919867735, 46.93303400470365, 18.899740634425996, 1.3655730529177574, 0.22795712274889793, 0.244911537175217, 0.4960460984899152, 6.445126879599787, 12.811402351625505, 26.98642061602685, 25.839384255870698, 9.622590907158392, 12.4838726751266, 22.34451516982048, 36.174725717113866, 52.13263380912043, 60.847516675149244, 59.953679115541526, 62.07714834520894, 59.679003377114576, 59.22302392221267, 58.640300919932706, 59.911909795576534, 60.68209855787216, 55.72679965726791, 57.678543598421165, 56.26715713931669, 54.26242589950562, 56.29530014530305, 55.57075208233249, 57.96893235175841, 55.5376394333378, 55.23669165949668, 53.328474260145626, 52.97285256847259, 56.2175940698193, 60.207734953972604, 55.91326129051947, 54.84647074053365, 50.911392088859316, 48.89308160351169, 52.20021624718943, 49.412207295817716, 46.105178556134625, 45.38425868557346, 46.59009333579771, 45.6699445170741, 48.324973352493785, 51.46480321884156, 54.67887570781093, 52.49234261051301, 51.73168913010628, 49.18642390158869, 53.711960469522786, 50.29190471095424, 61.430172997136275, 56.37337884595318, 61.40283407703523, 35.54526375186059, 31.293051665829076, 59.48891355145363, 48.1896908052506, 56.590097642713985, 56.889825559431515, 64.76364635652112, 58.416553235823116, 63.52689558459867, 61.28088366600775, 57.80082348854312, 46.01449728012086, 45.72069214236352, 45.25764849878127, 44.4382300684529, 46.02427967133061, 59.106721724233324, 64.62204879330051, 61.18789603633266, 52.08008973829208, 54.527801698254, 53.72086817218412, 55.80014405712005, 57.937639682523674, 59.13345659932783, 57.727271203071844, 61.69822777471235, 60.909717621341834, 61.13939592915197, 56.30110133078791, 56.257747373273304, 59.36237004495437, 58.021339139630726, 50.04452866892661, 51.76204043049967, 52.04741639475669, 56.693769808738466, 57.12294378588277, 58.18701613333918, 60.93438540735553, 59.68380043583532, 49.79421869401009, 47.66056306900517, 47.64555215835572, 43.91119687787948, 19.71196347667325, 18.888795260460146, 30.464066574650428, 19.125769176790794, 18.096837343708163, 17.028399398249967, 9.005160812408693, 5.706595566964919, 1.671592206243546, 0.2521875185231047, 0.25543459751192604, 1.5041698803824763, 18.592923033622004, 51.47143202443277, 56.85927029578917, 33.21546216164866, 31.46624392078769, 49.560931805641424, 66.070584020307, 66.18783150949787, 39.86932777589367, 3.826484646527998, 0.23781690416076492, 0.20350666055756234, 0.17548598349094394, 0.08481405374984588, 0.21785461403910192, 0.15595169137081794, 0.15223922928975475, 0.18523466683203177, 0.17390068710571335, 0.11789248925783943, 0.1362627260987797, 0.20260342757307714, 0.17436430819572943, 0.14882914211240508, 0.18709230747434402, 0.14037376840508756, 0.17492856259547895, 0.154977947653782, 0.19300209358334544, 0.2118598841010563, 0.09104991752293803, 0.20935925054213694], [0.030494658426652034, 0.038722783642550634, 0.043329189892017075, 0.02821312984451652, 0.12027538276367611, 0.02155020461237479, 0.03082497638740367, 0.016955550151666807, 0.06840665674498005, 0.02287587380006669, 0.05480232948978102, 0.05712677431743472, 0.16353803025859018, 0.05899185750393137, 0.029635224604017796, 0.09193205244598851, 0.029872711860544743, 0.04399063020584084, 0.04420890397722683, 0.0725969355252962, 0.012507145706143592, 2.4329172699682178, 23.544021075771703, 52.83447134879328, 55.68619920361427, 48.258136164757516, 30.697098508957897, 17.581353572107133, 21.38739016748244, 49.709989716929776, 34.62589940717144, 8.020876338404994, 0.19216298215812255, 0.049897574128643166, 0.08953697814215576, 0.4070047715738897, 2.6550611949736074, 4.465713068362206, 14.760932114816482, 11.908605117951671, 6.720744477164361, 9.12852817966092, 19.098740123933364, 35.46862063869354, 52.44036336098948, 57.5251514680924, 58.73593614947412, 58.2672913612858, 58.82953174652592, 55.17970746563327, 58.65211117652155, 54.02089811140492, 54.67652228570754, 53.18615890318348, 54.58906127560524, 57.487461413106615, 56.53294870930334, 55.053709168587964, 55.46776240871799, 54.7521298931491, 54.42031698842203, 51.169844904253566, 53.449263649602095, 51.99774349889448, 52.99030319336922, 53.456731842410186, 52.23466250204271, 48.116048305265366, 44.05933695454752, 39.78368282318115, 41.61369600603658, 38.86769563921037, 41.77950243796072, 40.4691287779039, 42.13184110579952, 45.59311313013877, 54.45369635858844, 52.92237558672505, 54.30981989829771, 51.57842643799321, 54.412786037691184, 52.591943356298636, 57.11088641997307, 52.118270089549405, 57.721207218785445, 50.64023863884711, 60.41125889747374, 25.226988523237168, 27.116468760275072, 59.22405158319781, 48.61312243246263, 55.49710173760691, 48.64115168971401, 55.82339586750154, 50.03662901539957, 53.54299652960993, 52.80428478794714, 56.93512109018142, 50.7056127825091, 42.20829986756848, 38.516451312649636, 42.869760528687515, 38.97737295396867, 47.428076344151656, 56.10320598848405, 60.24675469244681, 53.63338755023096, 53.737185232100956, 54.12938302563083, 51.66403608937418, 52.703585778513265, 52.26206418006651, 52.125773583689046, 52.37634243503694, 51.68742126034152, 50.51200066843341, 52.81742865039457, 54.819853536544315, 53.63976532413114, 51.06842025633782, 50.65612031567482, 51.55202496436335, 49.611706887522054, 50.472267058587846, 51.92185348080051, 54.36122255940592, 52.1891983093754, 51.48470140272572, 44.57124940810665, 33.267884639001664, 24.63241800185173, 20.72793972107672, 16.815042072726836, 6.751485072797345, 7.634251742593705, 7.280462288087414, 7.346314470614157, 9.601933744645889, 3.06813923581954, 2.4538531659110903, 1.9518579350363825, 0.2620364521299639, 0.09195423069139642, 0.4195266625573559, 5.927840778904577, 31.971247119288293, 35.35164379304455, 28.82261545427384, 22.423001796968524, 38.299461872346946, 47.560111168892156, 48.90162060337682, 34.22800240978118, 5.978470733088832, 0.3513552254486469, 0.09747163422646062, 0.05955678606105428, 0.060295999620950995, 0.06154489147687151, 0.018620498613604618, 0.03794361093652345, 0.041743407040954604, 0.032974994486017574, 0.03931581613517577, 0.0284436974118674, 0.06573712378139458, 0.03971638435858392, 0.01154716092822773, 0.019582325832978375, 0.05312501445352551, 0.08332831815125481, 0.04240370205333156, 0.0471254543311173, 0.012256184878248361, 0.05927579267130745, 0.0510107190348208, 0.05859033167061787, 0.05780521412229827, 0.0609314427410643, 0.024932622609119263, 0.09593625613037618, 0.11506812226387764, 0.09065352830915682, 0.01064902242843903, 0.03812359180301428, 0.0361332034451827, 0.0264278021565969, 0.030200428952793443, 0.08491926060448732, 0.03798271972505796, 0.04567298610063811, 0.0739871399597295, 0.07514359564670632, 0.06672245840872489, 0.023594184650949413, 0.0516217852371835, 0.03640022722163028, 2.770651973062946, 29.01461547420871, 58.473733548195135, 61.88512479105304, 53.112367353131695, 34.24229160431893, 22.921158498333348, 22.038250623210786, 40.50450855685819, 36.08981816999374, 8.682922413272243, 0.2954582942108954, 0.023555671495776025, 0.25201675752478264, 1.5267938663882594, 6.242842405073105, 6.487445331388905, 15.130779262511963, 9.759061932563782, 12.947747861185382, 11.537588123352299, 23.821446395689442, 38.8237258695787, 53.33647981766732, 58.10215173229095, 58.376070453274636, 59.24860562047651, 59.125317681220274, 56.39721116712017, 58.157763096594046, 56.49359949173466, 55.62706162852626, 54.01103335042154, 55.13062684766708, 57.13149455285842, 56.67153389223161, 54.97231998751241, 54.58014572820356, 53.16842586763444, 55.02144767392067, 52.11694432843117, 53.93230353632281, 52.660580911943995, 53.36357162844751, 54.231454864625015, 55.408236518982925, 50.69015864403018, 45.22181372488699, 41.4167381102039, 42.483210948205766, 41.821754209456905, 43.3312548360517, 42.823033332824714, 42.63750522367416, 45.8338721336857, 56.42490702290689, 54.545052282271854, 54.990366812675234, 53.26519466215565, 56.243964164487785, 54.029182157208844, 58.542728039526175, 52.62946082699684, 60.91798205529491, 53.77561661504931, 61.74295456178727, 27.386261147837487, 28.117604717131588, 60.23463849098452, 48.746130005005874, 54.07197129341864, 49.558554849317, 56.034917523784024, 50.9843756306556, 53.75142343582646, 54.951519658488614, 58.03827201166461, 52.51013840398481, 43.60684056435862, 40.065269777851725, 43.60221608992546, 41.35199154576948, 50.095362586359826, 57.74143095939391, 62.01639083123977, 54.94634212986116, 53.580231589655725, 53.72568484275572, 52.92373272680467, 54.03605022738057, 52.608025074005134, 54.29678586221511, 53.81591112382951, 53.845764283211004, 53.532449276216575, 52.65572894004084, 54.25731112880092, 53.93127195296749, 51.757145312524614, 50.4640418483365, 51.194238124355195, 49.55139652375252, 52.01794370528191, 54.14749653108659, 56.68854128929877, 56.12625775798675, 57.56366522081437, 47.583362979273645, 34.64535044085595, 25.352443572013613, 23.438130809414773, 15.809482662908493, 10.078889054636802, 7.994881320384241, 9.689800720061026, 13.28377829444024, 14.236473960261192, 5.266585551923321, 6.98517841677512, 1.537723796021554, 0.2515123805571949, 0.05456223753431151, 0.2925406330295148, 7.991471800111956, 35.88406239786456, 38.499514518245576, 31.03907035243127, 24.94774126237439, 43.036276909612845, 52.385105010001894, 55.066492172979544, 41.72234173743956, 8.12585416340059, 0.4332247742962453, 0.06189065377017664, 0.03271791836126678, 0.04796762244715806, 0.11792570683023623, 0.0428516413235376, 0.020090598357661117, 0.09739396057181782, 0.02247107677131651, 0.01363621949548683, 0.012918122191613, 0.06499981011955008, 0.013660575345819517, 0.06909072729608706, 0.062544793266082, 0.10822193922414895, 0.03277359763160348, 0.04999231622223893, 0.0390196925089244, 0.009644298115745187, 0.02888434927069372, 0.046735347038315195, 0.22407720916934554, 0.11616301512525928, 0.20235576666891578, 0.09376155467884195, 0.3123518199689927, 0.20460253401148706, 0.1567494034046127, 0.15812132898117268, 0.14348400876887385, 0.18076860405985387, 0.2468476098992171, 0.20820968964647865, 0.2862594474948222, 0.19662899896502498, 0.09635493850275394, 0.24458518371947352, 0.1459860212860569, 0.2979866295091568, 0.14144472867971467, 0.205577350251617, 0.14884829431051208, 4.1672074602496245, 36.2985667105644, 67.20571010343491, 69.38940340472807, 60.300671592835464, 42.36214699283723, 26.48573006353071, 30.563745767839496, 61.696345037029644, 44.246320263032, 10.691360292896148, 0.4761081393207274, 0.20683341269050876, 0.37908665835857397, 1.679410348015447, 5.24234579455468, 12.055283131137973, 28.80318403244019, 23.54235995200373, 11.611571869542523, 12.875155575813787, 21.74897582300248, 39.833736188950084, 55.65012516513948, 58.87153640870125, 58.17479402788224, 58.0091719473562, 59.90535551501859, 55.68560300334808, 58.96604591800321, 55.86997401329779, 56.69058484415854, 54.28135918032739, 56.2316636116274, 57.63445223531416, 58.198912682071814, 56.093458898605846, 55.70166510920371, 53.96754995469124, 55.07799648469495, 52.39646419402092, 55.998294353485115, 53.28008397932976, 55.87710095990089, 58.63530774270335, 57.841243513168834, 52.59448897454047, 46.45279469028596, 44.38513686580043, 45.56215778473885, 43.10811904168899, 45.913417800780266, 45.305979944044545, 44.72453955681094, 48.851245603253766, 58.3581530663275, 55.805517704256125, 57.56821517021426, 56.46959066390992, 57.288514875596576, 57.58789370136877, 61.54658502148044, 56.026998258406124, 61.22514286348897, 56.36824054102744, 61.90995731661397, 28.86669505027033, 32.50556022890153, 60.03171074774958, 50.09605684588033, 55.90413785749867, 52.22071455370996, 58.738050306996996, 50.94931748605544, 54.690850703947014, 56.9844292056176, 61.270179517807506, 55.42019582563832, 47.50944983574652, 42.30562171628399, 46.749769103142526, 42.43674262877434, 52.00424678864018, 59.89758922207741, 64.68615601139685, 56.17855079712407, 54.49324169466573, 55.526754856109626, 53.41118135759908, 54.6488852654734, 52.672187205283876, 54.253541731065326, 53.893523062429125, 53.348784292897875, 53.32235144030664, 52.83115694599768, 55.023914844759055, 54.02602464922013, 51.17686202449184, 49.74763270347349, 52.92293256328952, 49.79810968522103, 51.15976833528089, 54.59067729211623, 56.355269262867594, 56.24860432840163, 58.2508566302638, 52.291470189248365, 38.32945623705464, 30.2119444647143, 27.146419978910878, 21.16394058350594, 14.094234108924867, 19.859319079306818, 19.32926566370072, 14.745328926271009, 20.993133129612094, 9.189416112438325, 6.719414793675946, 2.9348323374025287, 0.8055671929351745, 0.27577982434341985, 0.6154650485804004, 8.834977015372246, 42.75299549102784, 48.0018328082177, 41.1639884210402, 31.68271953059781, 50.31533302799348, 61.73277208881994, 64.14221348301058, 49.04523818723617, 11.28565134540681, 0.5196468159556389, 0.20918312692834487, 0.14204642945720306, 0.16488813765106664, 0.25553688557157594, 0.16745353628310466, 0.09244038242726557, 0.1972830388695002, 0.1360253154510452, 0.08458988110144293, 0.1452296473566563, 0.1128803896567514, 0.11036748336928506, 0.1455900610815133, 0.09713976493766231, 0.13480214882762204, 0.2896291311950453, 0.13360024880497687, 0.1984494996647681, 0.0689145194126233, 0.24419697632472365, 0.13732394173501], [0.044729104490890625, 0.04916034473647033, 0.04687409322228163, 0.1410931402877454, 0.035762696511923306, 0.023677602049804503, 0.02879018940392041, 0.028868839820666663, 0.0582947634581116, 0.05990608001969034, 0.12287402961162791, 0.02050037304269931, 0.03482860167540851, 0.06711337775472673, 0.05000805932908289, 0.03491255342059078, 0.05483138337430935, 0.025390137978378805, 0.03315098786486253, 0.05866418637695813, 0.04308072459553519, 3.88674107770766, 30.875948782890077, 53.39994768942557, 54.17545126330469, 40.31008451215683, 23.571699280892652, 15.713261039026323, 27.985038411232736, 46.3401795202686, 27.77648206680052, 3.8271394371986394, 0.08923598985758521, 0.04180813380967706, 0.1923575531691313, 4.53311066473684, 9.898536512928626, 5.141532546089542, 6.614375191350137, 8.470851625165633, 12.762317811289142, 11.790193665412165, 29.878013480094175, 44.907302394990005, 52.28190745076826, 57.777277500398704, 57.611596584320075, 57.763780624635764, 56.560397455769206, 53.28535172247118, 55.98586044003887, 52.32264126500776, 52.54975826509538, 53.52965654865388, 57.430959670774406, 53.29117644217707, 56.044397892490515, 56.64925875202302, 56.411143425972234, 54.331541984312004, 54.725547990491314, 53.42316027610533, 51.602592160624845, 53.8510634053138, 55.19636184938493, 53.70155442145563, 53.10191423662248, 48.119021461855986, 44.14853165226598, 38.65575428931944, 40.97503216035905, 38.36105092879265, 39.756347825450284, 40.85146965519075, 46.075619574516054, 53.96603199743456, 55.50185565025576, 56.2245798110962, 57.3601608891641, 55.4611728268285, 57.421122366382235, 54.99860771240727, 56.55209772048458, 52.780138677166356, 59.06390513143232, 50.34667668804046, 59.117453329024784, 25.673581746316728, 27.657944117822957, 57.404895520979366, 51.670566835711085, 57.436133277031686, 51.12779709600633, 56.00596650954216, 54.37224049721995, 56.992285713072754, 51.7164703338377, 55.68014698643839, 50.30822177087107, 45.78661934021981, 40.00837187613211, 40.879361629486084, 37.943863714894945, 42.87309454333398, 48.965096319875414, 55.327922067334576, 54.34807085221814, 56.26359170483005, 50.897397072084495, 50.861154371692294, 49.85157551303987, 52.61191606521607, 48.733543119122906, 50.92839164118613, 48.02874026759979, 50.915726307899725, 49.902762443788596, 48.93829084211781, 53.48098777955579, 50.18227054226784, 52.86748201616349, 52.4509302262337, 54.71467910274383, 56.197578214829974, 52.066749757336034, 56.23080069018949, 55.09381932597007, 53.841128041667325, 47.455870259192686, 46.65115679464033, 37.086496353149414, 24.12316687645451, 15.038928139594296, 9.946887570042765, 4.041257947683334, 7.240975297266438, 14.051890161729629, 7.699937714684395, 7.35019761708475, 8.35034562695411, 1.8914951095657966, 0.1464237179607153, 0.06098766210338762, 0.12593792931687448, 2.4746745776745582, 24.44170451933338, 41.484697095809445, 20.574049449736073, 17.717742227738906, 39.0647868956289, 52.35471840827696, 50.031981006745376, 44.670869765743134, 10.858310095725521, 1.2339864815435102, 0.037904218695456945, 0.11181580323365428, 0.0644017942249775, 0.02169054234400392, 0.022199203658308235, 0.14634021437696873, 0.07269508671015501, 0.0714342745261327, 0.030356126747304396, 0.02009770573837863, 0.06690890888773626, 0.025729867329280225, 0.05054161275526689, 0.06725594671743532, 0.07347031406337216, 0.018853542560170737, 0.004537332410578646, 0.05527900471802681, 0.05535015513399436, 0.062144914521805705, 0.027858839077394337, 0.06867029824324193, 0.0660140875486597, 0.024091718538153558, 0.027323527479424115, 0.04079160791250967, 0.04393645629827534, 0.08559247568970726, 0.03569359538115321, 0.031079150954141255, 0.035123380817352765, 0.08375115272018217, 0.031775737466711196, 0.1038030215028313, 0.05754845209359642, 0.08929494798423783, 0.027384732158914692, 0.05898616547065397, 0.04522126618652575, 0.016329476286867456, 0.050946390631818966, 0.08892429932471245, 4.6371103486707135, 36.867204481555575, 59.51490317621539, 60.09672795572589, 50.05409925214706, 34.25306243281211, 19.538608443352487, 25.13211815587936, 46.240688600847804, 29.675519158763272, 4.76599354897776, 0.05035606626000616, 0.030411457447635553, 0.2231487106051176, 4.787152774872319, 10.806054319104842, 10.437774158293202, 11.177918545661434, 13.651169057815308, 16.99896985484708, 12.823223394732322, 29.42216738577812, 45.26469307561075, 54.704504474516845, 56.694307173452074, 58.175935437602384, 55.746866503069484, 56.13831904626662, 54.55911397933961, 57.310907686910326, 51.87795431383195, 54.35826509229599, 56.30750263890913, 58.926049509356105, 56.501491300521366, 57.3359324086097, 57.32185502206126, 56.53578066056775, 54.78555240938741, 55.36624754628828, 53.20231906829342, 52.987785031718595, 53.95596327320222, 56.59716575376449, 55.27080843525549, 54.79023179700298, 49.55139652375252, 46.35400195275584, 41.07052226220408, 43.78186848855788, 41.68452616660826, 42.654630291846495, 41.91714232967746, 47.933556110628196, 54.9263733433139, 58.76924491697743, 56.70329332351685, 59.48552854599492, 56.84931532029183, 58.39993023103284, 57.6202493329202, 58.00697149768953, 55.03143010600921, 60.546784631667606, 53.40903189874465, 60.0109653319082, 27.152507497418313, 29.564700434284827, 58.18796926929105, 52.30538675861975, 58.93206250283026, 54.12538220805507, 57.46514704919631, 55.853296095325106, 56.56086814018988, 52.58311410104075, 57.41169691085816, 52.66853547865345, 46.90113729046237, 42.63060969691123, 42.84395133295367, 41.027862564209975, 44.461050418115434, 52.443756211188536, 58.380012435297814, 56.767761399669034, 56.57519263605918, 51.21581508267311, 51.32365280582059, 51.45560918315765, 52.36969401759487, 49.86924186829598, 51.18059219852571, 47.314139335386216, 50.081653902607584, 52.07675180127544, 52.200400598587535, 51.86101751942789, 50.594586172411525, 51.885379360568145, 52.83968025638212, 55.45877233628304, 55.92342415163594, 51.99092641953499, 54.84600005611297, 55.14699882076633, 54.282567270340465, 51.26267956149194, 51.71557995580858, 40.91238798633699, 25.7203834672128, 15.845457661536434, 11.287535063682064, 5.432240482299559, 11.027805516796729, 9.76413453778913, 12.301549142406834, 15.589382783059152, 6.7515007622780345, 4.097182366155809, 0.183221586949883, 0.2100279380477244, 0.038218896971234394, 3.1716866214429182, 25.323278788597356, 43.71591383411039, 28.953077408575243, 24.084553103293143, 42.89677389206425, 56.49323078893847, 56.843867148122484, 51.46003361671202, 14.508342262237305, 1.2869127383155208, 0.023609201889485124, 0.08425077994263942, 0.03812442683885175, 0.05263806215577549, 0.01004631233011042, 0.017179841543698025, 0.054673484992235906, 0.03357571467096287, 0.022437773014028228, 0.01576137516812812, 0.05579891028783976, 0.0316312532841919, 0.059170298533694404, 0.026281939015813896, 0.022908352097616564, 0.042348294744207975, 0.024319581815131733, 0.06479482797365035, 0.06376268154370689, 0.0476979709891302, 0.028519683757856972, 0.1990645916591729, 0.21792999709085112, 0.10615413002068959, 0.15544172196138292, 0.1809787572992425, 0.09744400909591107, 0.1696969634823261, 0.14093230778892196, 0.11695088292922705, 0.18147663784123239, 0.3357556834816933, 0.1302195640821611, 0.21433142164061147, 0.13930086226713273, 0.1725235521312683, 0.11708978999165759, 0.13034747012199896, 0.22960761321648476, 0.11584485114942636, 0.14768172626293477, 0.21203038462948418, 7.154016350546192, 42.279506575676706, 67.34284400939941, 67.46304112095987, 54.824023016037486, 36.412268377119496, 24.286553205982333, 40.18989916770689, 57.68105391533145, 34.67861213991719, 5.460307492363838, 0.2604881577914761, 0.20894675816018737, 0.3457109347706841, 7.038193662320414, 18.09181474870251, 12.88208640390827, 13.290184505524175, 17.043337745051232, 21.176568654275712, 15.246664708660497, 31.57738231843518, 46.55887911396642, 53.65219139283704, 56.98072648817494, 57.22408210077594, 58.112071406456735, 57.13390288814422, 55.52018880844117, 58.53936264591833, 54.23920546808551, 54.713992687963675, 56.763070244942945, 60.7447466542644, 58.466940003056685, 59.43123902043989, 60.1189285709012, 58.79436377556094, 54.8677025302764, 54.23031737727504, 54.64516685855005, 53.28985068105882, 55.336939596360736, 59.73638373036539, 57.33532051886282, 56.68401487411992, 51.769798878700506, 48.56969394991475, 42.687131051094305, 45.44898956052719, 43.257808454575084, 44.07064122538413, 45.97000583525627, 51.138716974566066, 59.42193908076133, 59.554456357033025, 60.08519226504911, 61.258702662683305, 60.357259627311464, 59.34647660101614, 59.506925075284904, 59.719580296547186, 57.36762908197219, 61.890816150173066, 53.0955639193135, 57.72454515580208, 29.725552912681337, 31.57456997902163, 57.8458954441932, 55.131740800796024, 61.13446943221554, 55.38236064295615, 60.38140966046242, 59.00348886366814, 57.97685161713631, 54.93951328339116, 60.491859682144664, 55.174067097325484, 48.170530026958836, 45.62554328672348, 45.4862795337554, 42.87037241843439, 46.75247161619125, 54.215655557570926, 61.561497872875584, 59.438091401130926, 57.51671444985175, 52.03261729209654, 50.66968387173068, 52.25130511868385, 53.70280957991078, 49.166482571632635, 51.433651754933024, 48.30763255396197, 50.006560125658595, 54.370942192692915, 54.59054393153037, 53.351529952018495, 51.11335885140204, 52.732980020584606, 52.47870452942387, 55.34661216120566, 56.96593130788496, 53.290897953894834, 57.201799115827015, 56.287023944239465, 54.828125815237726, 51.808579352594194, 55.49298717129616, 45.96072550742857, 30.869773011053766, 19.432753478327108, 15.591429279696559, 8.139202969689524, 14.762754055761523, 26.964520062169722, 15.822998169929752, 17.696592807769775, 17.12493088937575, 4.905981959835176, 0.4378212711984112, 0.5629276580387547, 0.35745904630711006, 3.9233730733394627, 31.61189917595156, 53.20566877242058, 29.44629780707821, 28.32953626109708, 50.38747326020272, 66.5659950625512, 63.21346290649907, 58.85226580404467, 20.077273422671905, 1.9328446133482842, 0.08607827502513125, 0.2742747373638615, 0.09530368967041855, 0.12925954866072825, 0.19117440697887253, 0.21312399046315303, 0.14848256393546058, 0.22151747958794718, 0.0785439458465384, 0.12912871616501964, 0.1643243275823132, 0.16627898559935633, 0.2147022388394802, 0.1592903485101077, 0.15547395894123664, 0.2477684782277192, 0.1995113434930963, 0.13392700062644097, 0.20518940332676136, 0.16104027719026612, 0.1241604827584759], [0.01967597242084242, 0.013138979594523629, 0.047211482174574375, 0.036212776997877706, 0.04736818928992556, 0.023638874390012315, 0.05050890463133974, 0.01477063962093164, 0.11459413600424606, 0.10311891264732807, 0.04042239949828194, 0.029474809623113083, 0.06316105737501095, 0.09706053612453323, 0.12666716075111784, 0.04308779175663668, 0.025523276398739508, 0.07141113867081943, 0.01480948027869266, 0.08672995537879967, 0.036774890181878885, 4.0312041774872815, 33.01633519511069, 49.93637323379517, 44.69986000368672, 26.057626893443448, 16.565953916118993, 22.034224310228904, 41.94511667374642, 42.624804589056204, 17.57011794274853, 1.3655351775307811, 0.024295618584860238, 0.046412958087579864, 0.2732647270444901, 2.0354036842623064, 8.376898111835603, 6.701663126868587, 8.959825077364522, 10.102119291982344, 19.58679868328956, 18.44169212925819, 33.95206759052892, 44.392322647956114, 57.87905516162996, 58.53663659864857, 57.250883656163374, 58.90409208113148, 57.69696304875036, 51.85289036843085, 52.31747550349082, 49.29059813099523, 54.32338737672376, 55.71444419122512, 55.49024151217554, 54.0446323733176, 54.43952483515586, 55.42805233309346, 55.56401345037646, 55.78916534300774, 55.5736271796688, 51.173680982282086, 51.7621777134557, 55.90312588599421, 55.12195840958626, 49.01650290335379, 50.956338528663885, 44.36371287991924, 41.30954365576468, 38.98642970669655, 39.665564567812034, 37.846114327830655, 42.09635150048041, 42.54704360039004, 51.80067969906715, 54.961643295903365, 58.69079359116093, 57.544990816423976, 53.52351411696404, 52.99499827046549, 53.84523084086757, 54.86002645184917, 55.4998670085784, 54.30409323784613, 55.143790321965376, 50.208177797255985, 53.021011429448286, 21.19973417251341, 33.91429908813969, 59.21628136788646, 50.480590328093506, 55.35540219276182, 51.08453335300569, 53.939202985455914, 52.25974605929468, 56.054243041623025, 51.722040099482385, 52.256576784195445, 48.80844862230363, 44.481423208790446, 39.0946400550104, 39.56131581337222, 36.760025716597035, 41.214759580550655, 42.66549917959398, 54.839610515102265, 54.000741051089385, 57.03215268350417, 53.953445111551595, 52.96187385436028, 49.01064288231635, 50.90933284451885, 51.79888325352823, 52.95475083012735, 51.112668514251716, 53.58021982254521, 41.203843624361106, 48.00124445269185, 52.50521975178873, 49.16598835299092, 52.905846718818914, 57.01783995474539, 57.92779061102099, 56.95643132732761, 58.89066580803164, 59.43950737676313, 59.04677221851965, 59.34480959369291, 60.34919131186701, 51.096720157131074, 44.86136751790201, 35.54555008488317, 21.67651983999437, 13.538466615061607, 5.185689118600661, 10.980494868370796, 14.147136096031437, 16.419560274770184, 6.294052870042863, 7.26134269468246, 1.967705536273218, 0.045742002961736535, 0.06494611501693726, 0.2209293385667186, 0.8885575590595123, 15.08803621415169, 40.08634859515775, 39.777222679507354, 26.308336950117543, 35.92668679452712, 41.427963933637066, 42.75952623736474, 44.68267609996181, 23.47938237651702, 3.4472870586379885, 0.09101650842856016, 0.0818014283093714, 0.04953239533689715, 0.0018130101553622574, 0.06624664885983353, 0.030628200958392797, 0.01409356632540303, 0.022068089625287442, 0.05157835571275604, 0.04511782133411016, 0.018824887041363026, 0.021621234369494265, 0.07204337571296962, 0.052673493722273465, 0.0430590519681573, 0.03453144383045935, 0.044727825124057076, 0.028056606590267152, 0.03740990812319421, 0.09203670771732446, 0.02529637456210631, 0.018770125161315647, 0.012317930607335463, 0.011682269152163739, 0.029037045915761305, 0.020649651020404794, 0.015345561795026786, 0.04443354010882397, 0.011598571173606381, 0.07301031656923794, 0.08099561106533774, 0.03992765225590237, 0.0406357090199186, 0.045369569317347584, 0.09822836055630639, 0.08373059858117374, 0.03956855237183552, 0.06040905504637669, 0.08199514130190497, 0.05474610246657845, 0.012888114527618934, 0.05028692299440023, 6.3231622499804345, 38.73424876120783, 56.530897309703214, 50.88070738700129, 32.15154867018423, 19.22424812470713, 19.63207656337369, 39.59952362122075, 45.91274315311063, 19.737162743845296, 1.5822203889969857, 0.02765554424014784, 0.09269439420031925, 0.639520577125011, 3.681657256618623, 10.058589808402523, 9.21065378573633, 9.870163067694634, 12.083134901139045, 14.394047337193644, 16.335863759440763, 36.50425188003048, 44.117266439622455, 57.67562927738313, 58.14257175691667, 55.63314522466352, 58.218646126408736, 57.50868535810902, 54.19448260338076, 55.51965536609773, 51.458841216179636, 55.39645764135546, 57.45061859007805, 57.40977102710355, 56.386805119053015, 57.11452245712281, 56.209184508169855, 57.42411513482371, 55.651250885378936, 54.674784675721206, 51.22037679918351, 52.06602411885416, 56.033328963864236, 56.25322880283479, 51.02140672745244, 52.43142427936677, 46.932684913758315, 43.232583691996915, 39.87393656084615, 42.370893878321496, 40.089604162400775, 44.78292795919603, 43.89113395444809, 54.84170898314446, 57.038193133569536, 58.44983454673522, 58.200689515759876, 56.48806502742153, 54.4549907407453, 55.09637671132242, 55.87060551489554, 56.67610737585253, 53.82203002129832, 54.77316948675341, 50.27668591468565, 55.43788179274529, 23.219025250404115, 34.00207388785578, 58.34202820254911, 52.77447085226736, 58.49356897415654, 52.40702713689497, 58.26195693785145, 53.729026702142534, 57.51410215131698, 55.24358326388944, 54.55611728852796, 50.6544650754621, 47.263956531401604, 42.219498234410445, 41.66169797220538, 39.25145641449959, 42.390541030514626, 46.98345607326877, 56.62093531700873, 56.873975261565185, 58.50698740251603, 53.03821102265389, 53.44959705106674, 48.87125361350275, 51.837797088007775, 51.024458331446496, 51.10537290573121, 52.44228532237392, 55.02656244462537, 44.11670554068781, 49.742027636497255, 52.97822229323849, 50.47527551651002, 53.5853502827306, 57.6282274338507, 58.15615100245322, 59.406567312056026, 60.742809003399266, 60.950722079123224, 59.29624280621929, 59.61917938724641, 57.173789470426506, 52.91230686249272, 49.49050172682732, 38.99256037127587, 22.69422781082892, 11.065000372548258, 7.6016499823139565, 10.839614118299178, 10.802415340177475, 16.49629262185866, 11.813085598330344, 14.43427614627346, 7.750425973246175, 1.1456819167060237, 0.0967944508057929, 0.19792140461504462, 1.275658600272671, 17.476834174125425, 41.56063810471566, 29.74486666340982, 26.840671223978845, 41.36353900355678, 49.063645870454856, 50.09171478209957, 51.700718095225675, 27.83735332950469, 4.204078230165666, 0.09046638835101359, 0.05091107014807002, 0.044675654536413575, 0.024954281829958482, 0.0994520174760011, 0.07240637115413144, 0.05105642384038337, 0.08433805267897346, 0.024744073049195354, 0.15650235537079074, 0.12374005370563078, 0.03764459915879754, 0.0873206934380916, 0.0365777719285219, 0.026226294219433784, 0.021777286479670196, 0.0782093033194542, 0.006709048992037894, 0.0655055354018846, 0.061431552598913836, 0.002367883928180222, 0.13193953872448014, 0.15173437734765394, 0.14100271126916333, 0.13531349719532076, 0.13361466657971183, 0.11977868199708963, 0.22369686183669876, 0.09551183575944555, 0.2801335326606228, 0.15734601735828385, 0.18179051938556856, 0.09376257357578124, 0.11404010887828567, 0.22996016687923865, 0.26698341893572963, 0.11002702623485558, 0.18783653124926553, 0.1312619033119371, 0.16241785649570728, 0.18223800666389928, 0.20487477101625937, 8.426657299841604, 46.84009344347062, 65.08682612449893, 58.106454572369984, 38.28676516009916, 26.679777560695527, 31.531873018510883, 53.28566158971479, 55.391193820584206, 23.888199252467004, 2.049447608090216, 0.15764410216962138, 0.12534313865246313, 0.9019822386964675, 5.971536963216721, 14.494144262806063, 15.048631102808061, 18.526225090026855, 19.591532984087547, 29.175791548144435, 21.620255401057584, 40.02519492180117, 45.08424051346318, 59.25021379224716, 58.150526323626124, 57.31091553165067, 59.17397076083768, 59.00430079429381, 54.734710647213845, 55.370997536566954, 51.68028254662791, 56.623633907687285, 58.97229033131754, 59.73616407763574, 59.341573638300744, 59.45181185199369, 59.42947003149218, 59.728350716252486, 58.00011519462832, 57.019028432907604, 51.76408790772962, 51.759157488423014, 58.597460792910674, 58.445955322634795, 52.469039809319284, 55.59698881641511, 49.71337472238849, 44.519242701991914, 42.82759112696494, 43.41908847132037, 42.018202197167184, 47.608517139188706, 45.66414725395941, 56.94049081494732, 58.88678266156105, 59.70193747551211, 57.686419717727176, 56.06005991658857, 54.88162694438812, 54.663421569332, 55.77950062290315, 56.90482470297045, 55.30334057346467, 55.28463086774273, 52.056049531505955, 58.05456553736041, 27.436190958945986, 38.10045649928432, 58.74749537437194, 54.88396859938099, 60.32546489469467, 57.06626161452263, 59.04805091119582, 56.774531410586455, 58.79231237596082, 57.734755085360625, 57.3478054231213, 52.68236183351087, 49.282153268014234, 43.83136487776234, 44.66406445349417, 41.40233908930133, 44.420595092158166, 48.583716423280784, 59.73961968575755, 60.09112681111982, 60.35074457045525, 55.361634838965635, 54.94798952533353, 50.44372004847373, 52.0469339432255, 52.701181365597634, 53.5753050927193, 54.42616131997878, 55.68972933676935, 47.097459762327134, 51.55468040897001, 52.516869191200506, 50.02579150661346, 54.19183500351445, 59.7788159308895, 61.002101206010394, 60.90629731455157, 62.36938453489735, 64.00977073177215, 61.86448527920631, 62.896017643713186, 61.825704805312625, 55.92342807400612, 52.974535265276515, 43.49917542549872, 25.3495547463817, 16.146046538506788, 10.172338543399688, 19.746297943976618, 22.696767545515492, 30.13173591706061, 15.176687663601292, 14.287950165810125, 6.598746997694816, 2.2277527951425125, 0.21574989471945072, 0.4551491381660585, 1.7658818176677151, 20.638446923225157, 52.25247006262503, 53.23918542554302, 36.64687318186606, 47.1378876316932, 55.94041978159259, 56.816606675424886, 60.85521236542733, 34.888031405787316, 5.489372745636971, 0.16513877097637425, 0.11386082132136631, 0.13485185261214935, 0.06160753831687955, 0.16520113053341068, 0.14927410130058566, 0.1414948614734796, 0.19350916718042668, 0.09753162657181103, 0.33358115823038165, 0.20456885678633568, 0.15176290646195412, 0.2223448698679286, 0.18450673008638044, 0.15414145624926015, 0.12546342977833363, 0.15574094058284838, 0.14826406033769732, 0.18154622926827402, 0.1946087791434219, 0.2056843574128805], [0.10367458686232568, 0.05296406704151342, 0.08677753709977673, 0.0902213934328287, 0.042641775367120584, 0.06283445111025246, 0.019812100499327627, 0.018439696117814992, 0.09193005295650614, 0.05568355659864122, 0.11614357181374105, 0.039618282969440186, 0.05903388125701778, 0.06243809637042785, 0.05042770314180563, 0.020222495715584488, 0.021352057885979454, 0.032511292956769466, 0.06198890071602599, 0.054939225571410316, 0.034397458882942315, 7.646312050281033, 36.30596822307956, 50.080033963726414, 42.4937621239693, 32.881874384418616, 18.55313451059403, 27.25660720179158, 35.36193609237671, 35.465772997948434, 11.670642764337602, 0.6347383498664826, 0.030681269784127514, 0.05789990258973934, 0.09211117912444378, 3.546122451943736, 8.57814904182188, 10.657172914474241, 14.180114403847726, 16.341730644626004, 18.813789736840036, 17.578109771974628, 36.77813137731245, 50.43703240732993, 54.72764253616334, 64.07355239314418, 57.377478153474875, 57.633765820534, 52.94224239164784, 51.4449481810293, 53.38919255041307, 52.4264193350269, 56.52669645124867, 55.50730382242511, 54.63903619397072, 51.702443938101496, 51.74990853955669, 52.247186630002915, 55.897865987593136, 54.93985845196632, 56.27602954064646, 56.027264979577836, 53.3567427819775, 51.8403583957303, 54.65868726853402, 50.07020058170442, 48.37970218350811, 44.61633705323742, 39.996279208890854, 37.36075239796793, 38.00511544750583, 38.71627646107828, 41.00407338911488, 47.08949735087734, 54.95649714623728, 58.05768774401758, 57.16175563873784, 48.99621640482257, 54.68979166400049, 49.91216828746181, 55.892861043253255, 50.794368174768266, 53.56277312001875, 50.24735443053707, 54.67809907851681, 47.98750046760806, 49.28948810023647, 20.134700844364783, 42.2771845325347, 61.818609237670906, 49.96415145935551, 52.52603577029321, 49.97453789557181, 48.5738242057062, 46.63412194098196, 51.820879905454575, 49.80468750000001, 50.527592089868364, 45.30045724684193, 44.43140514435307, 38.979608704966886, 37.41153140221873, 38.628944889191665, 39.070513556080485, 40.046462012875466, 45.15192885552683, 51.38659115760557, 56.88532660084387, 53.25209002340994, 56.73646088569396, 54.49728565831339, 52.48021071957004, 55.14563383594636, 55.28744712952645, 53.76688149667556, 53.29313370489305, 54.43102113662228, 53.695506126649924, 53.81918238055322, 55.181550979614265, 55.23937848306472, 55.377508671053, 55.36002274482481, 52.845732473558, 54.74646991299045, 56.13053314147457, 54.107978651600504, 54.580745850839925, 55.47934516783684, 56.071191603137606, 52.77299996345274, 43.298369684527, 34.583529964570076, 20.318599208708733, 9.38837637824397, 8.938027485724419, 1.710114539150269, 11.320704587044256, 20.024766614360196, 7.535419781361857, 8.11799422387154, 0.8849095709381566, 0.07689168571584648, 0.03541183207304247, 0.21830024738465587, 7.0846306027904635, 35.1932349512654, 43.53386094493251, 25.435327176124822, 21.164362238299464, 33.649531256768014, 50.2853504303963, 52.306606615743334, 29.1596588396257, 5.012901848362339, 0.16423995065833294, 0.040985156196139516, 0.07396634067258528, 0.03804855732127063, 0.05726058306472917, 0.09947521461834831, 0.027457079587263927, 0.02755585321856122, 0.04072920239019779, 0.09119761927473931, 0.025373067624206026, 0.05237560426335662, 0.0625805159459912, 0.00973224213662287, 0.02173471688893774, 0.07134494867416159, 0.04922759959534292, 0.03737110576982941, 0.04125931608160177, 0.04701526407452841, 0.007520810120754065, 0.062342714593415303, 0.06325753082731558, 0.07267027312228758, 0.025913768650723562, 0.011619090838658233, 0.05745718420873727, 0.05366865725767228, 0.04296353995619763, 0.06877598773327566, 0.021194534886988903, 0.07221632772275517, 0.045951118151987755, 0.03331315718711384, 0.033909943510567954, 0.04819423125516023, 0.012024018102355543, 0.0369278434664011, 0.06685545893325921, 0.01900211190654626, 0.050390183985713995, 0.08215942119638767, 8.88027842967741, 44.327658453295314, 57.028030272453066, 47.45479552976547, 36.9619728672889, 23.754948492973085, 32.940860948254986, 38.00740218931629, 41.257281995588734, 13.036774877578983, 0.6629545325713774, 0.013511431433500783, 0.18117656120129172, 0.9723150549877075, 5.5025170983806735, 11.192658812768999, 12.34864111869566, 15.96107638651325, 11.698864217727415, 7.2511425710493524, 19.261473378827496, 35.21567483102122, 51.01692738071565, 56.01541549928727, 61.47359363494381, 56.354555391496234, 58.8146581188325, 53.386188014861084, 52.842841686741004, 54.38785153050577, 52.60391443006454, 56.95435639350646, 57.271260369208555, 55.884373034200365, 54.461635235817205, 53.30750526920442, 54.912044925074426, 57.42336203975063, 57.17239310664516, 58.0134081071423, 55.84553372475409, 52.24632370856501, 54.00846419795867, 57.078754363521455, 52.94681979763893, 50.503606796264656, 46.20851339832429, 42.341405499366026, 38.502456295874815, 40.61052237787555, 39.65569196208831, 43.293909949641076, 49.16899681091309, 56.59671075882451, 59.4932948389361, 59.60374486061835, 50.33190504197152, 53.14464845964986, 49.44246838169713, 53.896806086263354, 51.44092775160267, 54.73985287450976, 51.15868183874315, 54.48074110092656, 47.94419357853551, 52.48792209932881, 22.05992367959792, 43.44854939368464, 61.97983434123378, 52.812317802060036, 54.858402590597834, 52.148056568637976, 50.00047260715116, 49.83062221157936, 55.04961813649824, 51.36953276972617, 51.58572989125406, 46.958843200437485, 46.37219782798521, 41.29344624857749, 39.89156761477071, 39.799360536759906, 41.778090384698686, 41.96885878039945, 47.45564276172269, 53.69703192864695, 58.80258506344211, 55.00912750920942, 56.97687472066572, 55.13430210851855, 50.9947463773912, 54.86709848526986, 57.388158767454094, 55.318151443235344, 55.10935975659279, 56.69383256666122, 54.22467308659708, 55.63927588924285, 56.15100399140389, 57.69968125127978, 58.22860110190607, 56.91361865689678, 54.97238666780534, 55.700311891494266, 56.544547157902876, 57.46007150219333, 57.63174972226543, 60.20382435091081, 58.610420303960005, 56.78593766304755, 46.028409927122055, 38.100185855742424, 19.09832239151001, 9.33239729173722, 5.029393453751841, 5.7728669528038274, 11.379294010900683, 12.683255576318311, 11.699079948086894, 9.771545856229721, 1.680271798564542, 0.33876432526496153, 0.030064126589305462, 0.5135010441224421, 9.35866246300359, 38.48643733609108, 46.34670242186516, 29.615657906378473, 29.35711487647026, 38.21276180205807, 56.649576464006984, 58.378690596549745, 35.41217773191391, 6.2028401128707396, 0.21408570659977777, 0.0731526633664485, 0.02094940398819745, 0.024165215098389217, 0.0450998604027254, 0.06379893665472347, 0.0380750754547696, 0.04337176905884858, 0.002672200864781776, 0.0654319449958782, 0.027291715678368366, 0.14638411121503, 0.02486321312795964, 0.038016274376141454, 0.08295989114670985, 0.05328441436793055, 0.06741995082026528, 0.06305092840545601, 0.09615097525379351, 0.02683416775037204, 0.029697819733090942, 0.12137526285744484, 0.12758853469764994, 0.29517153217907877, 0.12153405756238969, 0.16630216741994505, 0.18602373739404066, 0.10414434431661522, 0.11551162588500208, 0.1423862354168969, 0.13494136232522227, 0.19797161401760197, 0.24744488268850312, 0.22658927276009516, 0.10559352986033886, 0.1621211966079089, 0.2814522457699622, 0.11260148768703784, 0.1362625575594364, 0.1665670193371273, 0.23293709262244164, 0.16561170769554956, 12.336924998990952, 53.651987429588075, 64.71318898662444, 55.386326159200365, 46.33208374823294, 29.46956922931056, 37.79753577324652, 46.177236418570246, 45.83127552463163, 15.774176428394934, 0.8212803917065744, 0.1407381657871508, 0.3810180885897529, 0.9158546201163723, 9.104970424405991, 16.23266718079967, 20.163504769725186, 24.244297512115974, 27.528003838754472, 26.022580515953806, 20.850694217989524, 38.31218996355611, 51.85824832608623, 57.238849824474705, 60.51704129865093, 59.34995574335898, 66.46093829985588, 54.94947218125867, 53.91267991835072, 54.798692349464666, 53.45852828794911, 58.1165821321549, 59.809112318100475, 59.2762073393791, 56.25073025303503, 55.4311078594577, 56.96112640442387, 61.19758036828811, 59.89318832274407, 60.22117299418296, 57.61380487872709, 53.869490700383345, 56.39929394568167, 59.31463872232745, 54.306313299363666, 53.14737450691962, 49.07190245966758, 43.68640584330405, 42.02530168717907, 42.320993484989295, 43.132782905332505, 44.61263433579476, 50.981441697766705, 58.39829460267098, 61.45773156996697, 60.91054524144819, 50.43198039454799, 53.841767388005415, 49.89250544578799, 54.08583294960761, 50.8080925480012, 55.22736426322691, 50.606051260425204, 55.85369617708268, 48.95496483772032, 52.87023552002446, 26.510945020183442, 45.25030582181869, 63.984981352283114, 56.2647605711414, 57.913320987455315, 55.514760248122684, 51.57195844957906, 52.008604541901626, 56.40041182118078, 53.16149896191013, 54.56048680889992, 49.828617880421305, 48.25675156808669, 43.611268920283166, 41.95283197587536, 42.796812288222775, 43.64454238645492, 44.19845165744905, 48.229828419223914, 56.024362425650324, 63.01646970933484, 57.829456790801025, 60.494985811172, 56.37934477098527, 53.08114136418989, 57.275555364547245, 59.33343472019319, 58.526057966293834, 57.98148393630982, 58.94593984849992, 54.81002799926266, 57.456388396601525, 58.45687520119452, 60.71141827491022, 61.18078477921025, 59.14616115631596, 58.055306865322976, 59.44370039047734, 60.76071854560607, 60.74858273229292, 61.10729917403191, 62.3629871491463, 62.798570279152166, 60.04990270060878, 52.5334608170294, 40.522119998931885, 24.59508292136654, 13.512252434607475, 17.271254908654, 11.2876223364184, 22.304534450654064, 33.402578830718994, 15.09711257873043, 16.14052874426688, 2.372167600739387, 0.5323887580344754, 0.13086749060500052, 0.7208383588060256, 10.877652283637754, 48.59773889664681, 57.128780272699174, 36.049872752158876, 32.31663142481158, 45.48434188289028, 64.80348979273151, 66.46966165111911, 43.13593256858088, 9.05275583267212, 0.4488074929723817, 0.09705728025085504, 0.18883190928928315, 0.12016063045349815, 0.22090119249638052, 0.17848576929780746, 0.1949150764173077, 0.16440131941870337, 0.10558465090129646, 0.16399644195072113, 0.18259022324796648, 0.2613607012937146, 0.11113252175310928, 0.12070028576999904, 0.16534763718805007, 0.22657817980695158, 0.1609703486845378, 0.1775679653210025, 0.1574482900961753, 0.11852164662653401, 0.11495548435637068], [0.03618135207122372, 0.0663297234343425, 0.029587202382484273, 0.03427640549958714, 0.012797829150522669, 0.007068871392778332, 0.02061598528657229, 0.04604917740629566, 0.11381904654685529, 0.05084182346059431, 0.038709989974215146, 0.020228116885728894, 0.034794399680029, 0.04403873669704603, 0.017343008695470712, 0.08731773633870386, 0.03179588366389996, 0.058182634999074286, 0.03139389243217246, 0.07503937704548722, 0.07481987753342237, 12.026191892162448, 38.09523582458496, 53.08083541931645, 44.260374115359404, 28.751832362144228, 22.255206723367017, 21.166945119057935, 42.702247865738414, 31.88112281983899, 6.154627809601446, 0.2563985353035312, 0.025808121295525663, 0.1482181869927914, 1.1932173659724574, 2.861879684271351, 9.251750419216773, 5.95094402951579, 9.4281639206794, 6.889323534504061, 9.71489114146079, 25.180569233432895, 39.62599961988388, 49.11389143236222, 66.71509219754127, 61.463015002589074, 51.10455313036519, 52.55204892927601, 55.21279265803676, 55.74006903556086, 57.6405240643409, 53.625515353295114, 56.59918185203307, 56.39510877670781, 55.785356721570416, 50.96910976594495, 47.093439332900516, 45.420183673981704, 50.64417277612994, 50.1660946876772, 53.36549751220211, 51.63716393132364, 54.44971515286354, 50.29511320975519, 55.581613125339636, 48.07578517544655, 44.55504609692482, 39.62360305170859, 42.17693267330047, 38.07455708903652, 38.85879970365955, 37.27956718014133, 43.33143526507963, 48.8411533448004, 57.92216200982371, 56.769950082225186, 51.15748943821077, 52.3714316275812, 52.74719861245925, 53.06901731798726, 56.079644310858946, 52.45091061438284, 53.59910603492491, 50.619724642845895, 55.54691583879533, 46.42245123463292, 55.58856356528498, 20.83926639249248, 36.376398301893666, 57.42526831165437, 50.78789234161378, 50.3320776262591, 43.008357478726296, 41.53383654932822, 40.62510967254639, 43.87591123580933, 42.53367616284279, 42.61489668200093, 40.89897740271784, 40.30606016036003, 38.10129588650119, 40.4186321843055, 38.72792197811989, 39.252684116363525, 38.59180004365983, 41.5183824108493, 41.413827711536044, 48.12725451684768, 50.793599390214496, 54.54336566309775, 54.33076535501788, 55.241527941919145, 54.49282200105729, 54.136074589144805, 51.23384229598507, 51.85324338174636, 52.936774607627626, 50.78510745879143, 55.1299443552571, 55.27533485043434, 54.42827547750166, 52.451369531693004, 50.13919899540563, 48.11074918316257, 48.858980517233576, 49.93288624671198, 50.46821132782967, 50.54717648413874, 51.86701482342136, 50.76961801898096, 53.62845713092435, 44.72574764682401, 39.5766483583758, 24.35328645090903, 14.169237671359895, 7.445163592215508, 5.284946166699933, 10.274985990216656, 7.191308775255758, 17.864097625978534, 9.376788716162405, 0.5873597954069415, 0.26262254003555546, 0.1445253520843483, 0.12514376427016913, 3.9868340809499068, 25.017945804903587, 29.57992707529376, 30.42236197379328, 30.588682236209994, 41.02963939789803, 46.12175057011266, 51.99560580715057, 27.977105417559226, 7.963876945357169, 0.8175985731424824, 0.05380077678109369, 0.14644326852454295, 0.028812697067135767, 0.026457784922733426, 0.06770705759164787, 0.030087241377200813, 0.08958893422518047, 0.047586574144060576, 0.0504237424672371, 0.026979465901310888, 0.026137970027423678, 0.0770124594771093, 0.06621878624202744, 0.007818649783955828, 0.040216674247095664, 0.08596437307254923, 0.06246713876363732, 0.04857825580984355, 0.01322675316083816, 0.09178134762952406, 0.036717808970640746, 0.10133051103161228, 0.052423526893459985, 0.027771675508589517, 0.02554695809169883, 0.008372269446901497, 0.04286781343961916, 0.03156685401805707, 0.03408308321189496, 0.0587117336239786, 0.07200865660824123, 0.049614960462936473, 0.04295831140611441, 0.02163800211893695, 0.02718809271051038, 0.06852542335588126, 0.050563009590992046, 0.03347684719389485, 0.04185038738914075, 0.10463320800373632, 0.09279383241289085, 15.170638388203038, 45.82609015126383, 59.98124553311256, 50.64721261301349, 33.77082270960654, 24.195169825707715, 25.05309416401771, 41.646306591649214, 33.45367946932393, 7.7665444631730365, 0.24125066345497487, 0.060883083440844095, 0.13384930398916045, 1.5108388902679568, 5.357517369331853, 11.08302072171242, 10.824123697896159, 13.475114453223444, 9.71882135637345, 9.939546854265275, 24.6798296513096, 39.09372222039008, 49.75982735233922, 61.577756097239835, 61.84912527761152, 55.85140159053188, 57.474160655852295, 54.69556539289413, 56.92225963838639, 57.077558040618904, 54.60654720183342, 56.687529317794315, 57.924233021274695, 58.12303443108836, 52.597983806364, 50.45156478881837, 48.18985554479784, 52.66312653018583, 51.989604580786924, 56.65848024429814, 54.873072255042295, 56.40232986019504, 51.50680788101689, 56.80414138301727, 50.95246322693364, 47.62939983798612, 42.79717314627863, 42.88559121470298, 39.19426433501705, 39.58262997288858, 39.51818543095743, 43.84500295885148, 51.22200458280502, 60.03277371006628, 57.34334961060555, 52.06949541645666, 51.33415691314205, 52.02772217412149, 52.76764592816753, 56.79230759220739, 52.21055953733383, 54.34015943158058, 50.335184143435576, 55.48390296197707, 45.59878879977811, 55.61468262826243, 22.031951296714045, 38.131003918186316, 59.704283052875155, 53.48134079287129, 53.425694127236646, 44.95496311495381, 44.58455016536098, 43.324288706625666, 45.764873719984486, 43.21146565098917, 45.99737613431869, 42.7948393360261, 43.43021623549923, 41.119571501208895, 42.199976598062825, 40.630691205301595, 40.527148477492794, 41.419001317793324, 42.50634116511191, 44.08770745800388, 50.5866551399231, 54.33391109589608, 56.90951978006671, 57.68766703144197, 56.46984561797112, 57.08225311771516, 55.68727001067131, 52.985678718936065, 54.06699772804014, 55.23978640956264, 54.279005758224, 57.069552483097205, 57.65386012292678, 56.90563663359612, 54.787423379959606, 52.28788906528104, 51.96892584523847, 53.217428038197184, 52.73605908116987, 52.5804586564341, 51.94128098026399, 54.64224469277167, 54.17796550258514, 59.08511730932421, 49.511364813773866, 42.60598113459926, 25.761846842304355, 13.00700310737856, 5.674662080503279, 8.514621353918507, 12.418407336358102, 8.58704399678015, 17.170359780711514, 9.847950685408808, 5.5032373436035655, 0.7791828183877854, 0.39667634353522335, 0.11360545357268666, 5.023047549109306, 26.982080513431182, 36.08346393031459, 30.318107335798203, 31.721539228193222, 46.344537273530044, 52.7310109907581, 59.61658277819234, 35.5350616670424, 10.005020037774118, 1.0309453572957747, 0.03790031164704311, 0.103518795222044, 0.02852146299706111, 0.028191721517472502, 0.0814911243956416, 0.06413026202109552, 0.05697785448583384, 0.030359570312524037, 0.047667201067651474, 0.04051590819031962, 0.016958809855784622, 0.04222533380192134, 0.019218637082245082, 0.08819808627689078, 0.022269093859640342, 0.0741738815521521, 0.059502960723494334, 0.04085443861361954, 0.012400391353895108, 0.029663832242330237, 0.16290859709824287, 0.20245328966167667, 0.12441175959763989, 0.08257383645902719, 0.10543924741326802, 0.12351636369262012, 0.07362307199547369, 0.11610797936877898, 0.17750053426190732, 0.2059772481480914, 0.17265190250210224, 0.11693011428559981, 0.17217898110468544, 0.04625807809192808, 0.14308273191413573, 0.15992463866789497, 0.16359717224634465, 0.11297571397716961, 0.17790346586656186, 0.22835576426117654, 0.33534432490987165, 19.206777887959635, 53.93287620236797, 67.23956015802199, 57.79614802329772, 40.507893562316895, 31.15100891359391, 30.861451702733195, 55.32155998291508, 42.521685477226015, 8.602481465185843, 0.45591568574309355, 0.20130676247419851, 0.38388138817202666, 2.256150264893809, 8.514810608279321, 20.755343360285607, 19.41048029930361, 18.553489485094627, 15.925787802665466, 13.634799045901145, 30.053280668873942, 45.26438713073731, 49.83630572595904, 64.86083484465077, 60.23273221908077, 58.41705529920517, 58.47762846177625, 55.435426389017415, 56.36767571972263, 56.91043369231686, 54.689991704879276, 56.600601750035445, 60.22637013466128, 61.06627902676983, 55.289859387182425, 52.05638293297061, 49.83549771770355, 55.84526700358237, 54.04618170953567, 58.812689089006, 57.89008486655451, 57.12007261091664, 53.146040901061035, 58.691303499283336, 52.2611306559655, 48.63540149504139, 44.59459535537228, 47.12973694647513, 41.86048761490853, 41.80686096991263, 41.44410448689615, 47.275739331399244, 52.78279019940285, 60.586737894242816, 58.93328235995386, 52.346042125455796, 51.541795422953946, 52.31487104969641, 54.64581404962848, 57.35545404495732, 53.759185806397475, 56.42349889201503, 52.10014481698313, 56.93781183611963, 48.4880772713692, 54.682547046292214, 25.29488867329013, 40.735998999687936, 62.01062494708646, 55.49384224799372, 54.666194685043834, 47.740661790294034, 46.06888486493019, 46.12261741392074, 48.194617302187034, 46.66589313937772, 47.70373267512168, 46.518808180286044, 44.39786887937977, 43.798679767116425, 45.32864339890019, 44.02513780901509, 42.70486408664335, 43.13543050519882, 46.377359667131984, 45.73844086739325, 53.06790728722849, 56.16539124519595, 59.108145544605875, 59.5281490202873, 59.870724908767215, 58.08794098515665, 58.16579218833678, 54.84323870751166, 56.60186083086076, 58.355285813731534, 56.94997118365381, 58.12555651510916, 60.18870361389653, 58.51343970144949, 58.01374150860695, 54.109402471973056, 54.70096649662141, 53.65248557059996, 54.681295810207246, 54.6743885163338, 55.85277834246236, 57.08335530373358, 57.70096386632612, 61.36239444055865, 54.5096528914667, 45.094587725977746, 28.491573295285626, 17.239185610125144, 14.757887374970222, 14.309973293735137, 20.561480214518888, 16.184827012400476, 29.199935697740127, 18.26028839234383, 4.465612067330269, 1.0161757949859866, 0.32239069741579796, 0.3707631437047836, 5.883782755944037, 33.41274169183547, 41.55717857422368, 42.24088691896008, 42.46562696272328, 54.0396313513479, 60.824798307111195, 67.89476071634601, 44.537136554718025, 13.424802211023147, 1.5982592057797218, 0.18608674046493348, 0.3720471070658776, 0.07101512484012112, 0.14285220073596125, 0.15121945901022804, 0.14008647011172387, 0.2077740460874573, 0.11692003256851628, 0.1487379623276572, 0.14405298227023694, 0.09181322454805337, 0.1921469709205051, 0.13134352231938995, 0.08021668350744633, 0.1178419427765954, 0.16615684054070906, 0.2677547469014122, 0.08277743198578397, 0.2067040051183393, 0.23533516233005833], [0.04223404422162041, 0.04920496169718043, 0.023228950317828886, 0.053492947331359314, 0.06629698083645875, 0.03876067818172517, 0.013807210320186232, 0.09512476983570284, 0.1002271835421843, 0.0690576246368789, 0.02569926211670522, 0.0733106766617106, 0.04061310942615232, 0.028778067977738478, 0.02381235117002601, 0.02437307965010405, 0.07667290632643046, 0.040950073199647094, 0.07488324832651885, 0.04806874222272346, 0.07329920066460487, 9.24832324827871, 42.72358163710564, 49.933819770812995, 44.324038105626265, 32.17656554714326, 22.15149925601098, 27.803303234038818, 38.579205313036525, 28.779279147425008, 3.6178049925834905, 0.04794613751132162, 0.027570171401866024, 0.277455565068991, 1.784139592801371, 5.438698174492006, 11.917202953369388, 12.32217884832813, 17.703974708434075, 7.852195299440815, 8.362948202317762, 26.8664784585276, 44.30849767500355, 70.1282210503855, 60.877660089923495, 51.495299646931315, 47.573290332671135, 50.14681623828027, 50.63797150888751, 52.91017309311898, 53.476896747466064, 56.55295279718215, 53.6063192736718, 54.01370840687906, 53.609378722406205, 51.263263994647616, 48.644117001564275, 40.45892669308571, 41.92331221795852, 47.16616007589525, 52.77775779847176, 55.134215816374756, 55.18084495298324, 54.56647234578287, 55.6993430660617, 50.94533628033054, 44.338252775130734, 39.88506040265484, 41.67429662519886, 36.74407343710623, 38.66055134804019, 37.88113324872909, 41.92069599705358, 52.12558530992078, 56.51070494805613, 44.07782308516964, 52.77063085186867, 53.28450841288413, 51.46630548661756, 54.42361962410712, 56.29403321973739, 54.97541081520819, 55.82622389639578, 50.16862853880852, 55.151976308514996, 49.95829536068825, 56.801682056919226, 24.105420112609867, 32.60320763434134, 57.28170171860726, 51.120748596806685, 52.00084217133061, 46.25670363826137, 43.78186848855788, 39.6411713477104, 38.84547933455437, 38.874245997398134, 40.2694252229506, 38.05132489050589, 40.51545196963895, 39.25572787561725, 39.85612507789366, 39.1630030447437, 39.42437018117597, 38.8312921216411, 40.83643128795009, 38.91679194665725, 40.190746399664114, 43.2964712573636, 49.3746349119371, 55.47817237915532, 54.468405246734626, 55.729804192819905, 51.857624669228834, 50.89491813413559, 47.93275202474287, 51.004866092435776, 52.55116639598724, 52.816593185547866, 50.17921893827377, 50.254297025742076, 45.921031121284734, 42.999445853694795, 40.84998307689544, 43.87100042835359, 41.424057252945445, 45.59679623573057, 43.62003149524812, 51.598257941584436, 51.95320890795801, 57.57060781601937, 48.175327085679584, 42.56797336762951, 28.98332084378889, 15.863227959602112, 4.676455153572944, 5.586917679156027, 8.871907111137144, 6.912784701393497, 10.020977220227643, 7.980706855174034, 4.419419294403446, 0.6554405583489327, 0.2009601230102201, 0.072195750601109, 1.925567636086095, 19.516146990560717, 41.405700560539, 39.65886908192789, 30.003725444116903, 24.819817081574474, 45.76605435340635, 51.45258111338462, 43.41749991140058, 16.35209060484363, 0.8788164753106333, 0.23160356337264662, 0.04779371665790678, 0.05590282245388916, 0.03876513298300486, 0.00681601306085565, 0.06909902402830702, 0.01724778396648265, 0.06371825227453824, 0.020368780204725843, 0.0038210179369461035, 0.01993049364236574, 0.009040645729269712, 0.05110189115868942, 0.02376715006727365, 0.039396669054704334, 0.022586851808873397, 0.07214701208736628, 0.038774869960522464, 0.04917418411482246, 0.046662913425074476, 0.0583917846632821, 0.03223056003691689, 0.046743084526350426, 0.08097393077708061, 0.05689505187253799, 0.07421097552944576, 0.059021191010552074, 0.003949175349384126, 0.013833205598676878, 0.05148213123902679, 0.024939844903025418, 0.03606099582787964, 0.011825211582735423, 0.044782803423943064, 0.021220729348339865, 0.033107098687680504, 0.04533380450260255, 0.07477169060298512, 0.08481698786659587, 0.014653762374373694, 0.1537535093244045, 13.49976949153408, 48.5368166431304, 57.09972727683283, 48.941848431864095, 37.413712240034535, 26.795862067130308, 27.474749818924938, 43.350588198631044, 30.875066249601304, 4.06152728584505, 0.21153487896005954, 0.058672919779294924, 0.6429517317202784, 3.8581308193745154, 8.558627405474263, 12.900078315888683, 11.022548560173282, 13.127504202627367, 10.113357863118573, 11.327577560178696, 28.466730963799264, 44.311545356627434, 66.44666087242865, 62.681173739894746, 55.63099184343892, 49.90259378187118, 54.014881195560584, 53.984447525393584, 54.52568754073113, 55.230631597580455, 55.27517403325727, 53.66757492865286, 56.207207633603005, 55.81504906377485, 53.58230652347688, 51.16426337149836, 42.87984102003036, 44.912224969556256, 49.49170589447022, 54.382477883369695, 57.658288478851325, 58.33715269642492, 56.395630451940725, 56.773817539215095, 52.27897744024954, 45.89591618507139, 42.58077598387196, 44.549546933943226, 39.35164159344089, 39.7354612042827, 38.73802992605394, 43.24557065963746, 52.71399182658042, 57.96005995042863, 45.80800410239927, 53.0318057921625, 54.318488336378536, 51.87180795977193, 57.881945948446955, 56.261618752633375, 56.064366679037775, 57.41453670686292, 53.27250988252702, 57.216884551509736, 50.598759574274865, 56.75679053029707, 24.83488290540634, 33.63133538153864, 55.77991247177125, 54.8840941152265, 54.72480666252875, 48.17864933321553, 45.023098607217115, 41.76318145567372, 40.694339506087765, 40.70717742366176, 42.274662448513894, 40.62848291089458, 42.56234476643224, 41.11647675114293, 43.03352340575188, 41.478793928700114, 41.020041358086374, 40.716265555351015, 42.44157891119681, 40.57189879878875, 42.89606786543324, 46.596804511162546, 50.9151497194844, 57.540162378741854, 56.68949050288047, 57.55084299272107, 54.871805329476636, 53.47105633827948, 50.24179250963273, 52.30314316288118, 53.96128985189623, 55.45752894493842, 52.38739175181235, 53.26744610263456, 47.788114624638716, 45.79190669521209, 43.46556463549214, 45.05170837525399, 42.71865906253938, 46.458297775637725, 46.395041711868785, 55.58918722214238, 54.33471125941123, 60.86812873040477, 49.718026653412856, 47.931759665089274, 30.062951272533788, 16.245175619279188, 6.787652267563728, 9.912879640056241, 12.899866507899377, 8.498942659747216, 11.138793883785125, 7.757088118983854, 5.810077988332318, 1.70858456963493, 0.09296993304404522, 0.049683762819416104, 2.10992528546241, 23.57199541984066, 47.61250226728378, 47.448096121511156, 33.876201106655984, 30.829288267320205, 51.15140584207351, 58.82649975438272, 50.49071004313808, 21.614395380020145, 1.2224413526635016, 0.19111115875984394, 0.04546934077816625, 0.047091332774969845, 0.017376906170900312, 0.011976309019261071, 0.04508789793978776, 0.010485685779713096, 0.010371511865917955, 0.03388227241474294, 0.049899382096144466, 0.025035579080483126, 0.025958762909736366, 0.1448204644745396, 0.017221551200735475, 0.03396412890945231, 0.03376222260656857, 0.01610466970070716, 0.019059095441574053, 0.05076781936710881, 0.033076248326969725, 0.15704416339435887, 0.20733919925987723, 0.14056552021253493, 0.21418050231952823, 0.17043813822730897, 0.31628169780296667, 0.14798155775473965, 0.10298739833336684, 0.12185923124272978, 0.1245567647199477, 0.09544898590613758, 0.16667453211642083, 0.09872781923942028, 0.07298695854842663, 0.1457425432219621, 0.18148691874117623, 0.1361640539741324, 0.19264621509900018, 0.18015315966500392, 0.13235903315005765, 0.48000394156382936, 18.477268026721095, 56.13098029167422, 64.57512155655893, 56.52006372328728, 44.456786801738126, 31.010792024673957, 38.6420730621584, 49.92750083246539, 35.87808078335178, 5.372451793762946, 0.287099692730173, 0.19033521894485722, 0.675874145761613, 5.581369486547286, 14.959722738112173, 21.47073661127398, 18.0858802026318, 30.073100405354655, 15.756103127233445, 13.116095988981186, 31.24085080239081, 46.40475742278561, 68.60595703125, 61.74173078229351, 58.91313706674884, 52.82413198101906, 54.222755047582815, 54.23786793985675, 53.18491158946868, 54.344505417731504, 56.38661292291457, 53.16237757282873, 56.38790730507144, 57.61666820895288, 56.24271292840281, 53.73943275020969, 44.17411335052983, 45.26461070583713, 51.892882854707786, 57.46980682496102, 60.46318323381486, 61.1523985862732, 58.83657240098523, 59.115900070436545, 55.6948519522144, 48.02358627319337, 44.2161690035174, 46.826380837348204, 41.631860502304576, 42.374318107481926, 41.492361407126154, 45.68647730735041, 56.239900588989265, 59.81856915258593, 50.69069208637361, 53.10229078415902, 55.78065772210398, 54.250709779800914, 60.32722603890204, 59.63785379163681, 58.11988476783999, 59.78005932223413, 54.53082976802703, 59.78278536950389, 51.93220069331508, 56.87598743746358, 27.308090271488314, 37.05683146753619, 59.96681513324861, 57.89255595976307, 56.65078063164988, 51.61992119204614, 48.412336303341775, 44.428953662995376, 43.69529785648469, 43.13049224115188, 44.27527519964403, 43.97511189983737, 44.2507682308074, 44.13640368369318, 44.82772142656388, 44.52542043501332, 43.34206096587643, 42.51117744753438, 44.417814131705995, 42.42808203543387, 44.67911851021552, 47.01504292026643, 52.49776724846133, 60.967337239173155, 60.647197308078894, 60.39122343063355, 56.84028994652533, 56.57695378026655, 51.812070262047556, 54.70733642578126, 56.02481742059031, 58.03469481006746, 54.95946245808756, 55.352793816597234, 51.21138280437839, 47.05154057471983, 45.05332439176498, 48.93563147514097, 44.96506321814753, 50.11954399847215, 48.86180854612782, 58.57789601049116, 57.490387501255164, 63.79973565378497, 54.495865760311005, 51.338271479452814, 31.746336452422607, 19.242167472839355, 8.89096002424917, 13.714461403508341, 18.69765031722284, 16.160784844429262, 18.814582055614842, 14.408991567550169, 9.464312484187465, 1.622962660847172, 0.4860769044007025, 0.15219992897923917, 2.738830029003082, 27.59480768634427, 55.09818492397186, 50.81482725758707, 39.508799199135076, 34.943980093925234, 58.52186495257963, 65.21313821115803, 59.92511249357655, 26.2440610701038, 1.7972627402313295, 0.5445858583815637, 0.25329451557369004, 0.11349554293819013, 0.1530162109843185, 0.10319477833446958, 0.16877830148704592, 0.12029539298025832, 0.1858387271603269, 0.16175123742751538, 0.22199024776777915, 0.0867905069683348, 0.0827200596611346, 0.1424127267373185, 0.14391390666846307, 0.13682216946636477, 0.1489935139374387, 0.25669922481381124, 0.11861800516565, 0.13354288414120674, 0.19094292585167194], [0.03192550765590803, 0.013468778530706563, 0.025284653416864818, 0.011555844534849449, 0.02392281913348744, 0.02897167563318245, 0.033344302491675464, 0.019936239301797845, 0.03223386187587054, 0.028273735060206348, 0.08481576212591703, 0.05189875283488824, 0.01148543147850902, 0.024763968352588917, 0.03193392504697606, 0.07335622058880907, 0.04854229947311744, 0.01813442157130809, 0.052298160435091105, 0.06636006817702325, 0.2881813782357401, 13.07964736415494, 40.52305744540307, 52.92001431988132, 36.445679126247285, 20.422273335918305, 13.205586825647663, 29.91429344300301, 40.68541611394575, 18.155655245627127, 1.6895706350764923, 0.13366930397047153, 0.15425742663923772, 0.2865296007404404, 1.1507248590069434, 5.0169438508249105, 10.450826825634127, 6.8635996503214685, 8.757787712158697, 7.722707073534689, 18.659332683009488, 34.67492903432539, 57.549630980337824, 50.42057414208689, 41.06530158750473, 44.748065933104485, 51.19108453873665, 50.089812432566, 53.05951341505974, 55.206944404109834, 51.21605042488345, 50.739921754406346, 49.1245210555292, 49.602520696578495, 54.735973650409335, 51.76287589534637, 50.36090312465545, 44.094391176777506, 40.26777782747823, 38.49706695925805, 42.50099105219687, 47.37836030221755, 51.78848897257159, 54.469731007852864, 50.33381915861561, 43.31461221941056, 40.59630770837107, 38.50080497803227, 42.27627846502489, 39.51169783069242, 38.897988104051166, 35.86845136457874, 41.58962442028908, 55.196491287600615, 53.999976188905784, 48.91395645756876, 55.997066651621175, 54.16538646144252, 55.9306138561618, 52.25482740709859, 55.533783743458415, 49.33865893271662, 53.13480331051735, 45.804203325702304, 51.23783526882049, 49.49905641617314, 59.53064364771689, 24.472775574653383, 30.924986254784372, 54.359677145558024, 50.62814989397603, 55.1603505688329, 50.24021571682346, 52.65623884816324, 44.91215828926333, 44.822406614980395, 40.60213635044713, 38.61119224179176, 37.363631417674405, 39.64382679231706, 37.56340165292063, 40.59999865870322, 41.224494903318345, 43.62274185303719, 42.47525638149631, 39.7639964472863, 41.240964935671904, 40.01474180529195, 39.54136271630564, 39.53798555558728, 46.182515928822184, 49.934945491052446, 51.48854924786476, 47.496717822167184, 45.33959073405112, 42.21275568008423, 42.5677066464578, 41.912604147388095, 42.29449002973495, 39.82045896591679, 43.264405881204915, 39.95015998040476, 43.668908149965354, 39.08548132065804, 43.9181943862669, 45.27628760184012, 51.63423392080492, 50.961739632391165, 53.54750333293792, 49.84470352049797, 57.874509134600245, 47.07497281412925, 42.80393531245571, 30.225535477361372, 20.493415324918686, 6.793613289633106, 11.23113432238179, 13.092322503366779, 6.172316228189777, 12.608841350001674, 9.189236664002943, 11.478819251060488, 16.82348301333766, 5.977132714563801, 0.43965102624027963, 0.7824693968699825, 12.284765320439494, 33.01355031228835, 21.169098500282537, 27.51291448070157, 32.934353736139116, 38.444369915992986, 49.44411185479934, 53.496508598327644, 20.523156696750274, 4.201933674273953, 0.2546869569848622, 0.09444554096027728, 0.12104687160782276, 0.09518224175178236, 0.018821859078842307, 0.044679948459229166, 0.01932703660831096, 0.03151999433494864, 0.12398449704051019, 0.018699618259204492, 0.034824016639181686, 0.065874828085784, 0.04103323587426736, 0.049854987300932414, 0.06576585973943434, 0.011467604612511013, 0.04359144094069639, 0.003844729794617442, 0.016534416297931346, 0.04461290044409614, 0.040491255480916276, 0.020075127212030273, 0.04926069842411145, 0.024721919701644973, 0.06674651356954729, 0.04680512615689828, 0.06726706265321664, 0.08562846650038997, 0.0319455121268308, 0.03499575056916764, 0.05565879280648886, 0.03414706304489124, 0.03651254720264866, 0.029259579136006297, 0.01842696182129364, 0.05247674702155975, 0.014904533595507665, 0.06990471869827279, 0.06933648830219623, 0.051565424148594184, 0.34065512219263666, 16.01563165264745, 48.25915598100232, 58.338953064334014, 44.51112339573522, 25.718712537519394, 16.073036520711838, 30.511515486624937, 39.129725656201764, 22.189230495883574, 1.8150650301287252, 0.13054375716995809, 0.062243843285907666, 1.0273053977758655, 4.259496417737776, 9.505314000191229, 9.607416237554244, 8.911238678040045, 8.285398041048358, 8.410007819052666, 22.92040736444535, 36.18042099860407, 58.17655124971944, 53.44430185133412, 45.71443203956851, 49.629816470607636, 55.37134662751229, 52.3323412864439, 55.13755767576156, 54.93389252693423, 53.77423986311882, 51.428713490886075, 50.5802930555036, 51.68096503903789, 55.72922760440458, 54.62484898105745, 52.6678059178014, 46.0124223462997, 41.16048574447632, 40.69987789277108, 44.978132555561686, 50.13742608408774, 55.568724216953406, 56.02256990248158, 52.92040263452838, 45.65186631294989, 42.82629282243791, 41.14576901158979, 44.869204413506296, 40.131683349609375, 40.02959974350468, 38.38247883704401, 42.85615382655975, 56.88069035930019, 56.390178357401204, 50.865304239334606, 55.31884962512601, 55.272549967611994, 57.18174795950613, 56.004464241766165, 56.89239078952421, 52.0680441394929, 53.994712368134536, 48.8709359015188, 53.22487269678424, 51.180400002387266, 59.57053415236935, 25.344432130936656, 32.426179301354196, 57.18139102382045, 54.04626407930928, 56.68215567065824, 51.47571133029077, 55.00003545514999, 45.96929980862526, 46.6466696031632, 42.118983576374674, 41.16168598974905, 39.26591427095475, 41.83364683581937, 40.30397738179853, 42.31200341255435, 43.316502801833614, 44.81243595000237, 43.76062100933444, 41.917683616761245, 42.607153923280784, 42.402288529180716, 41.11872426925167, 41.666004734654585, 48.452913222774384, 53.09752510439966, 53.94753802207209, 49.79448541518181, 48.027979327786355, 44.81205155772548, 44.19541966530585, 45.27938627427625, 44.536763929551654, 43.2504383210213, 44.78442238223168, 43.662969681524466, 43.96691806854741, 41.49284778102752, 45.33939853791268, 47.55687913587017, 52.51579446177329, 53.22504528107182, 54.81573112549321, 54.062302650943884, 59.50483837435323, 52.602016002901145, 44.65308181701168, 31.6520328675547, 17.685319915894542, 8.764055659694057, 11.828725068799912, 10.578821609097144, 13.395825701375163, 16.4557510037576, 10.745479195348679, 6.428365120964666, 12.21850177934093, 3.54990239104917, 0.20827846902032054, 0.67608816008414, 16.052320522646752, 37.56092271497173, 29.18877067104463, 31.81302066772215, 38.300265958232266, 44.43585311212848, 54.44871887083977, 59.062489155800115, 26.350555381467267, 4.545607826402111, 0.1559730192586299, 0.0899299199602777, 0.06876495606716602, 0.04072918323799968, 0.04700856080519096, 0.03838584668213322, 0.02383505801610168, 0.06296548278882139, 0.08738820110597918, 0.04301772918552161, 0.020793821106875138, 0.023911908126225876, 0.021101616082652923, 0.016946108118000052, 0.0704612892361418, 0.013578281223383403, 0.025263294885535876, 0.03103283710867888, 0.010346487603871333, 0.08923925339214264, 0.12600955853779472, 0.08646861214431063, 0.15300917829717361, 0.13574206210192175, 0.11494149559087331, 0.1163476116714939, 0.1686215752194966, 0.1581541941531243, 0.09077167438883936, 0.14346209865423942, 0.18507178121757123, 0.1635476063576437, 0.12362941528760618, 0.10626975567110124, 0.1672540623093805, 0.223685447126627, 0.17805830755781743, 0.18904676630852685, 0.11331872218438696, 0.19802854967213449, 0.9515075553809443, 21.533355289889922, 56.24144600283716, 66.45242675658196, 50.927226697244954, 30.881787230891568, 21.725465136189616, 42.602674576544, 51.54803199152793, 26.165564637030325, 2.6081052759001335, 0.284648732312264, 0.3889974459044395, 1.280211368876119, 6.146771302146297, 14.051140989026717, 20.468439632846465, 15.902175134228123, 16.336179510239635, 12.813769502024497, 23.738082301232126, 36.74997268184539, 56.340023010007805, 55.17225888467605, 49.94399047666981, 54.317280246365456, 54.884427516691154, 55.9615574344512, 56.30492564170592, 54.772592898338075, 52.99342540002639, 51.69476001493393, 51.257686384262584, 51.27568221861317, 58.84752365850634, 56.056878874378825, 55.46877438022245, 48.38265572824786, 43.54563197781963, 43.9089846611023, 47.00768455382317, 50.852415330948375, 56.315225785778416, 59.77591337696199, 56.38283568043863, 48.37593670814268, 44.65146580050069, 42.972612919345984, 46.440400000541445, 43.118481943684245, 41.721114035575624, 39.31619905656384, 44.96239208406018, 60.581552520875015, 59.370771761863466, 51.920731682931226, 57.52455919019638, 58.683603886635076, 59.63241346420781, 57.75744599680747, 58.426331704662694, 53.280801773071296, 57.43554492150584, 51.25067318639448, 56.346887157809356, 55.81255835871543, 60.4566603322183, 27.891342793741536, 36.833330892747455, 60.352140934236594, 55.37171925267866, 59.874792406635905, 54.03624634588919, 58.96171562133297, 48.6650546135441, 48.8694336337428, 45.08656255660519, 44.028267860412605, 42.338287215079035, 45.99366557213568, 42.79605134840935, 45.83913987682712, 45.882842925287065, 49.10709004248343, 47.33598693724602, 45.19951505045737, 45.34880830395607, 44.76864268702846, 42.92784298619917, 43.640953417747255, 50.123442834423436, 54.36395645141602, 56.52769665564261, 52.303935481655984, 50.88628107501615, 45.77907662237845, 47.14374765273064, 46.62177431967951, 46.69651116094282, 44.25357272548061, 47.58213919977988, 44.349353082718395, 46.63616549584174, 44.186084424295736, 48.93680818619267, 49.55181229499079, 56.55276452341388, 57.68664721519717, 59.50461479925341, 56.40330653036795, 63.06582881558327, 53.91351538319742, 50.35018328697451, 33.19464222077401, 22.345297682669855, 10.416023635095167, 18.646310414037398, 21.830488558738463, 17.106705596370084, 23.6771188628289, 16.587579904064057, 21.74178807966171, 23.191382346614716, 7.477915383154347, 0.7973454147577287, 0.9819162204380959, 18.03772722521136, 44.68428819410263, 30.48217223536584, 37.52981831950527, 46.8893741023156, 52.169845334945194, 61.959916545498764, 67.27519096866732, 34.76668503976638, 6.066938321436606, 0.3682341036056319, 0.22797949251628694, 0.2028085552756825, 0.12789151481082364, 0.14371161349117756, 0.10921507262654843, 0.10108934655304878, 0.09290750453909559, 0.18711558122548366, 0.0716935186797092, 0.3035860274347567, 0.14909921874923093, 0.11696644983584843, 0.09267865109347528, 0.22600957402779212, 0.09138226178624938, 0.13513358910718273, 0.09260354383337883, 0.09180213925578902, 0.2988405111095598], [0.03296582441356394, 0.029661474606743263, 0.05244200876463325, 0.06606753750313675, 0.039169075823719465, 0.04132560183925014, 0.02090876110859456, 0.03792528228293504, 0.06190792905286916, 0.03215971605611905, 0.0577819710146756, 0.036140600024091626, 0.10311533501672168, 0.052253060838988716, 0.030814262647782604, 0.04161552781419408, 0.02216496718897214, 0.015267971452445754, 0.05826984644837438, 0.03522108384077588, 0.29832585324202815, 15.131825554755428, 44.70418637798679, 50.304966203628055, 40.325522961155066, 27.658467754240963, 24.79988555754385, 33.052091521601525, 43.47860259394492, 15.117665798433366, 0.7167498394846917, 0.14950337609456432, 0.03134041566461806, 1.3491080461009857, 5.155625131822402, 7.220941791611334, 7.899431913129746, 11.764597258260174, 7.707333833940568, 17.52028815207943, 27.823748588562015, 38.220218227755645, 33.26241685498145, 30.005876864156416, 42.889493973024436, 51.180349011575025, 57.64089668950727, 51.877409104377996, 53.949989503429784, 51.05298180733958, 52.98592190588675, 46.77096166918355, 49.168161346066384, 48.882032286736276, 53.250995682131865, 53.86425041383313, 50.91704030190745, 48.99587908098775, 44.78920375147174, 38.81120566398867, 39.54824255358788, 38.23136952615554, 38.61922133353449, 40.96130778712612, 43.05074653317852, 40.48969376471735, 38.86605216610817, 39.002821291646654, 43.16986891531175, 39.00095424344463, 38.15654247037826, 36.853621313648844, 41.48001770819388, 50.26409510643252, 57.98407662299372, 55.48527186916721, 56.747043440418864, 54.34472507046115, 52.874765857573486, 50.884382647852746, 52.13970976491129, 47.773872498543035, 44.639078955496515, 39.96901873619326, 49.47748730259557, 46.369762036108206, 62.88416816342262, 28.49317950587119, 27.568584680557255, 55.18545373793572, 50.043771651483354, 56.31420204716345, 52.49402138494676, 52.849117479016705, 51.6704373974954, 52.8749894326733, 45.357712084247225, 42.64932332500335, 38.7827096446868, 39.026908566874845, 39.62605061069612, 43.67248535156251, 45.69094488697667, 47.02588435142271, 46.10943432777159, 47.46605665453019, 40.89118365318545, 41.58803586036929, 39.084708613734094, 39.763157060069425, 37.96387956988427, 39.03697336873701, 42.64506755336639, 41.57377412242275, 41.461198176107104, 41.43951531379454, 39.7600152415614, 37.97239895789854, 37.15906804607761, 38.10517118823144, 38.71072238491428, 40.80139667757096, 46.36133678497807, 49.01019180974653, 52.39520511319561, 53.29123135535948, 54.572599087992025, 53.11417948815131, 53.931621043912834, 55.63078788018996, 52.837330756648896, 48.455654959524836, 47.282830976670795, 35.855954693209746, 22.177239810266805, 8.320722906820237, 13.128949596035866, 8.650547169869947, 10.93887459847235, 7.122689360572446, 9.389170658203865, 5.343047745766179, 3.493200117541898, 8.10969203710556, 0.560980997979641, 0.18429738890019157, 8.206099973570916, 47.05036778603831, 34.478771302007864, 20.94596858947508, 21.800513805881625, 35.49509663735667, 50.25364983466364, 48.67837106027911, 26.425839393369614, 5.588588608849434, 0.4094796645785532, 0.023454145693610755, 0.07478987753030754, 0.016463076275202538, 0.040171612955389485, 0.09050015750671588, 0.028975075148346446, 0.06095033446927706, 0.049571691816973115, 0.02822151850728739, 0.07306008930167845, 0.03288936500828112, 0.02325345747052662, 0.03902047774904678, 0.08298881862673067, 0.0451407733283216, 0.06598540521677464, 0.06503726415816816, 0.07912690045251962, 0.027986628288823753, 0.006862947916341646, 0.04407375074562527, 0.01983499695216456, 0.05215050464856529, 0.07103479797801665, 0.06913535957855564, 0.03435987843981674, 0.05710148575505423, 0.0219251720925733, 0.05614268075254175, 0.03442411874270728, 0.03548457595189253, 0.06279549170886317, 0.0304949208117661, 0.01305166280813395, 0.07094427702888366, 0.04396957810968161, 0.016312298680385275, 0.0387646388562937, 0.032568358846249125, 0.838358820446076, 18.83938712458457, 51.18244747961722, 57.67486049282936, 44.75477710846932, 29.47640003696565, 24.925328839209772, 34.383496930522305, 43.967471122741706, 16.840872841496623, 1.0509533675447589, 0.14302432537078857, 0.06090480586393707, 1.6471956766420797, 8.563762768622368, 9.10419967866713, 13.449799476131318, 10.191031579048405, 7.124526010405633, 12.493408937608043, 27.20311587856662, 38.43405800480997, 37.36057589131017, 34.47018131133049, 48.27750090629824, 53.569766706035985, 57.78374156644268, 53.12333430013349, 54.36178738071073, 51.626769650367, 52.06001504775017, 49.59157728379773, 49.40335842870897, 49.47170965133175, 53.813243912112334, 54.42993071771438, 53.06207080041209, 50.446846177501065, 46.767047143751576, 39.9498579579015, 41.869658116371404, 41.14072092117802, 41.74871183210804, 42.747319821388494, 45.62384097806869, 41.85633382489605, 41.29834921129289, 40.78145534761491, 45.6321995489059, 41.40251167358891, 40.967928747976984, 39.40152237492223, 43.752360497751546, 53.05714430347566, 59.57856716648225, 57.39375206731982, 58.57085143366168, 55.43245715479697, 55.92980192553613, 53.35605244482718, 52.33058798697687, 49.55058459312686, 47.10999957976803, 42.57521406296761, 52.34440257472377, 48.082637556137584, 62.817895796991166, 28.93832341317208, 30.122926273653587, 55.89474378093597, 50.8640726151005, 58.80671531923356, 55.20743470038138, 55.40157633443033, 53.44800849114695, 54.48082739307035, 46.65168631461359, 44.057866065732895, 40.611346075611735, 41.61811651722078, 40.400193122125444, 45.0612985703253, 49.053894858206476, 49.516354068633056, 48.1523576859505, 49.94346487906672, 43.23164232315556, 42.69512091913531, 41.14457661105741, 40.71710102019772, 39.94163274765015, 42.15112347756663, 44.80103754228161, 43.884414934342914, 44.085730583437034, 43.34578329516996, 41.83919306724302, 38.97914978765672, 39.35434802885979, 39.6100434180229, 40.343640388980994, 42.3946673639359, 46.612584206365774, 49.4033545063388, 52.93216190030498, 55.3649413970209, 55.94880188665083, 56.89411663240003, 57.02042087431877, 58.20255264159172, 55.002667365535615, 49.89369784632037, 49.13998696111864, 36.835523497673776, 22.887449649072465, 14.832363378617073, 11.679756391432978, 11.17029247745391, 14.714732477741858, 11.16746150678204, 10.29473610462681, 9.094861495879389, 5.106985780500597, 9.416948883764206, 0.535786695057346, 0.2727811110596503, 9.135781622702076, 46.16289623322026, 33.87616580532443, 28.031000744911935, 29.870060874569802, 40.265926468756895, 56.041565941226104, 57.120288341276115, 33.21092005698912, 7.449111457793944, 0.3264935272595575, 0.03184923402694685, 0.04601713577886263, 0.018322277821660526, 0.015201606213175243, 0.005092038960766889, 0.005139756183545556, 0.024345732226427046, 0.05427511927161006, 0.010608763550408186, 0.052643505210477504, 0.020579772310391552, 0.024842523008344636, 0.06204605087517731, 0.07510254865572338, 0.013766774284322898, 0.05995636603104011, 0.03129066783003509, 0.12929298073774384, 0.05441391142085195, 0.07958770233897433, 0.13728090291542394, 0.12090961929530868, 0.2128784899269381, 0.12076145022987358, 0.18832299708118364, 0.10975786890353888, 0.15311656850239924, 0.18892030051398664, 0.09190058155405907, 0.15908322897889923, 0.12326782944822505, 0.19109713935082961, 0.12514381023544457, 0.11191573174249743, 0.16170818328617081, 0.17323635097953582, 0.07911417573209732, 0.12260957606016629, 0.1661967230780471, 1.413097960814353, 24.500651859468032, 58.46322159613333, 65.38375346891343, 51.81769101850448, 38.7754258032768, 35.70278221561063, 42.943391261562226, 56.053791969053215, 19.296480532615416, 1.711663630220198, 0.2667152575187145, 0.23760063753974056, 2.3818016773270023, 10.858026704480572, 15.722175605835455, 17.413970347373716, 22.010986228143018, 15.474504405452361, 24.551338688019786, 30.850814234825876, 40.99253769843809, 39.35865871367916, 42.21605439339915, 52.11910163202594, 55.68199834515972, 57.809915542602546, 56.580330940984915, 55.526829381142896, 52.38493634808449, 52.616709201566636, 50.13021284534086, 50.147381059585086, 50.35900469749205, 54.8233405236275, 58.277909217342255, 56.085994628167924, 54.60989690596058, 49.583960040923095, 42.06547460248394, 43.922763947517645, 42.89811534266318, 41.96614842261038, 44.3803947202621, 48.298858211886504, 45.038944982713275, 44.14829631005564, 42.70272247252926, 47.623582963020574, 43.10918200400568, 40.68154865695585, 41.763526624248875, 45.30052784950503, 54.93220198538996, 60.511487222486934, 58.2684955289287, 61.264099844040416, 59.1469495527206, 56.833508168497396, 55.48860980618385, 55.611619257157855, 52.26197004318238, 48.366946635707734, 45.39409598996563, 54.209830837865034, 51.231049568422385, 65.13815818294403, 32.60650634765625, 32.9513729003168, 54.953814245039425, 51.988639677724535, 59.73987463981875, 57.633204921599365, 57.310766481584125, 55.21466755097913, 57.21486060850082, 51.43132186705067, 46.905765687265706, 42.8045589693131, 43.025486469268806, 42.59919543420115, 47.524884362374586, 51.415463724443995, 53.14401695805212, 52.87729578633463, 52.70933205081571, 44.33255357127036, 44.90478815570955, 42.57745765870617, 43.49792811178392, 42.87506357316048, 43.86580721024544, 46.261865477408136, 45.627790804832216, 46.04232257412326, 46.771734376107496, 42.70449930621732, 41.38543759622882, 41.45239245507025, 41.24868023780085, 42.78463725120791, 45.280551218217425, 51.38682649981592, 53.04884456819104, 55.66505762838549, 58.734665301538286, 59.62269383092081, 58.91476092800018, 60.055605826839326, 60.99669225754277, 56.59363562060941, 53.02630270681074, 53.301700161349395, 38.826950057860344, 25.78688725348442, 14.13544939410302, 20.70742964744568, 16.50532191799533, 18.628140034214145, 13.577743268782093, 19.69208686582504, 13.499959726487438, 5.559895490446399, 11.207236301514412, 1.018664845295491, 0.418680074113992, 11.920307509360775, 57.67351119749008, 45.69069777765582, 32.86273125679263, 33.65850956209245, 49.25966239744618, 63.97777595827657, 64.59165434683523, 41.55622936064198, 9.809160405589688, 0.3948395404844515, 0.13626842579293635, 0.13914147001360694, 0.12261994889066105, 0.15721481714037158, 0.08000703588608774, 0.10862159963336684, 0.15381603742078429, 0.13155116279038692, 0.13644680170522583, 0.1728065450104975, 0.1318007542361175, 0.12533916265613612, 0.10860477634254964, 0.11082424031149958, 0.10153196151218108, 0.21228846432941578, 0.15617780988254856, 0.21075133955286396, 0.22563221443805004], [0.02763948512203511, 0.03620448792653699, 0.018782020591559912, 0.06978176924730502, 0.042656610659774274, 0.059918866027146585, 0.04906707353168919, 0.009912444211001839, 0.07974965332616722, 0.010153768610419526, 0.03379819043461354, 0.04331237809251874, 0.0582039705477655, 0.019317305376452786, 0.030777609171045404, 0.04552666713754016, 0.0782171940250743, 0.028581809658076496, 0.019094339316530574, 0.03243904320463058, 0.3760495793915564, 16.38890597128099, 48.37058267285747, 47.47287765625985, 40.51846827230146, 23.62428649779289, 18.589008508190034, 37.89463012449203, 30.94360378480727, 8.577485180670216, 0.3816052796619554, 0.090204838272785, 0.13169428333640099, 1.0108734246703888, 3.5773854582540454, 8.182553004833961, 6.420526754471564, 4.98763737178618, 5.988714493090107, 10.833835486442814, 31.449844491097238, 23.602662471032914, 28.825825914259884, 40.680144448434156, 54.43594763355871, 55.153580557915475, 58.55808019638062, 47.56679096529561, 51.78043242423765, 49.67191919203728, 49.662960498563706, 48.820027459052305, 51.4493686922135, 51.78398609161378, 49.916318155104115, 52.79844045639039, 55.346765133642386, 50.81266210925195, 50.628746094242224, 41.82466853049494, 35.21991491317749, 37.201194301728286, 38.56377470877863, 39.23585322595412, 38.288071309366536, 38.87050405625374, 39.037691162478545, 37.55390167236328, 41.02801553664669, 40.183258595005164, 38.186450542942175, 37.19949591544367, 39.420157555610906, 45.421219179707194, 52.97113849270729, 53.0112329606087, 54.23969576435705, 52.27466675543016, 49.01361603890696, 44.13812168182866, 42.4472035900239, 38.63692691249233, 38.54235072289744, 40.632491573210686, 49.657700600162634, 47.34281186134585, 58.84485644678916, 29.072356685515377, 31.992839767086892, 56.80576132189844, 46.092983907268895, 54.43393938003048, 51.6653500833819, 54.60055382021012, 50.28167516954484, 54.33499367006364, 47.58844637101697, 46.6591937311234, 38.100397663731734, 39.25242916230233, 39.875172107450425, 44.479999388417895, 47.96522532739947, 49.80310286245039, 51.80013841198337, 49.57502488167056, 46.185857788209, 41.32752772300474, 37.09892242185531, 39.960656242985884, 39.10407727764499, 40.89048939366495, 40.326452562885905, 39.68333290469262, 38.833151325102776, 39.21425665578535, 38.97629037980111, 38.71589206880139, 38.79138592750796, 39.82855866032262, 43.48302310512912, 50.26277326768445, 52.567342250577866, 53.33827626320624, 53.22868131822156, 53.342347683445105, 50.49256924659976, 51.66553051240983, 50.161325085547666, 51.6600235046879, 54.66539844389885, 55.809977439142045, 52.02741230687788, 40.59122431662775, 25.273023420764556, 18.01650720257913, 13.652438925158593, 8.543143849219046, 17.102840100565267, 18.02459316868936, 6.473824410669266, 9.422742224508717, 2.343545820443861, 0.021173151457802426, 0.10882352508844868, 0.2265018161626593, 4.714036362786447, 30.042260769874822, 47.0059940122789, 29.008247506233957, 26.745016382586574, 37.29972031808669, 45.64402549497543, 50.16825591364215, 34.79302375547348, 9.391301485799975, 0.4480795255832134, 0.03558672994615571, 0.04117863553185617, 0.08110684703194326, 0.03673662409006107, 0.10093061313513788, 0.005423890533781941, 0.042484409416154514, 0.06327412429175551, 0.04124844146351661, 0.07438838617095063, 0.026989949814554666, 0.014220673718579836, 0.057488662761545954, 0.06495601287291897, 0.02586281231244005, 0.09576319686828122, 0.020178549081808137, 0.05563384515323466, 0.02345167697527476, 0.0522908213127765, 0.02089664159763244, 0.016905463323177352, 0.062710770045317, 0.038689604374550046, 0.08879683761587066, 0.06006014413170277, 0.061854019445637544, 0.06057746415477126, 0.016180397492022287, 0.042602938539799184, 0.01408064242212042, 0.02746796186622833, 0.031357915028028434, 0.07149282662618546, 0.046046909786039786, 0.058842504832653277, 0.00925585993700811, 0.0621101571126811, 0.031494822600976594, 0.4723696915372726, 20.350405708436046, 56.05047364388743, 53.05876424235683, 45.29230656162385, 27.160868029440604, 19.795578602821596, 35.61077910084879, 36.71662469064036, 10.0853786160869, 0.45684185540003164, 0.08341245758797854, 0.16261328552519122, 2.6432908975308944, 6.41463339328766, 7.96442803836638, 10.776174683724681, 10.306738557354098, 6.303207682025048, 13.010669542897134, 28.109656033977387, 26.071098273800267, 30.733872690508445, 45.98447153645177, 54.8035325542573, 55.75734315379974, 58.19668869818411, 51.220549383471095, 52.25881253519366, 50.844272490470644, 49.756128557266734, 49.45693016052247, 51.21056302901238, 52.185801536806174, 52.38808601133285, 53.83376967522406, 57.829209681480165, 53.31329468757876, 52.19652137448711, 42.78114634175455, 37.509269022172504, 40.555887683745354, 39.499295296207556, 40.88817127289311, 39.32645997693462, 40.93900519032633, 39.44126382950814, 40.00359050689205, 42.574386442861254, 41.67223345848822, 41.017040744904556, 38.57224702835083, 41.4920005490703, 47.63309078831827, 55.40231374002273, 54.01013512765208, 55.85035431769587, 53.764857553666644, 53.40425837424494, 46.63107425935807, 45.01822310109293, 40.82290303322577, 40.17235048355595, 41.93657767388129, 52.66355406853461, 49.60749818432716, 60.232798899373705, 31.20395894973509, 31.540308075566447, 57.22230526708788, 48.4025146884303, 54.78343825186453, 53.32115511740408, 54.93278641854563, 52.658674640040246, 57.01529433650356, 49.687279193632065, 49.35869832192698, 40.092659688765, 41.551549973026404, 41.96376362154561, 46.95279098326161, 49.000911481918834, 52.76147996225665, 53.22114252275037, 51.42526572750461, 48.26829118113364, 43.80828565166843, 38.495701974438084, 40.78080031179613, 41.702878936644524, 42.42025298456992, 41.334721349900775, 41.84131506950625, 39.633581561426965, 41.59286429805141, 40.81035537104453, 41.300192725273874, 40.430038436766594, 41.71657193091608, 44.392710962603175, 51.973362045903365, 55.146422232351, 56.85241007035779, 54.99512072532408, 55.85017388866794, 53.78287692223826, 53.8872355030429, 51.9527421459075, 54.20342168500347, 54.095466290750814, 57.74842062304097, 52.085734028970045, 44.48804416964131, 24.892086751999397, 19.082807456293416, 10.271415652767306, 11.451356776299017, 12.354076543161947, 14.102264181260141, 8.483257101428125, 8.002863343684904, 5.773432264404913, 0.30419028694591216, 0.30747815245582216, 0.13393271564235612, 6.4296776440835774, 32.569175189541234, 44.19698861337478, 31.49564012404411, 27.94550091989579, 40.54723101277506, 51.96101834697109, 55.746595859527595, 40.74102355587868, 11.744800075407952, 0.617308562561389, 0.07268151929301601, 0.02559380053782896, 0.07081155995688132, 0.010337416165237947, 0.03878909621327635, 0.0856101110337242, 0.016378391000832764, 0.041004656964252074, 0.026068116215267972, 0.011252918047830464, 0.04264387061759349, 0.024955679940420295, 0.04387046931491744, 0.0375927809715992, 0.07314650401953729, 0.05722511702427461, 0.013421171911871962, 0.06513358439288794, 0.03277778813254929, 0.10665039411715924, 0.2053013440942572, 0.19155184317740703, 0.15165450502066843, 0.09103384499828662, 0.14420250731129802, 0.17046371024222146, 0.10891028454587345, 0.16657814293378786, 0.15932721266102406, 0.08303718941826975, 0.15555219184006416, 0.10373954345742542, 0.11749079105474296, 0.17973093796641598, 0.11505637047511917, 0.1182024101276071, 0.12069910599459564, 0.10894093572372392, 0.0796863821245009, 1.1273693509640232, 25.8323279119307, 64.16508874585553, 61.39210247224378, 53.48934635039299, 34.80919176532377, 29.0607209743992, 49.51576179073703, 43.39735854056574, 12.13744599973002, 0.6789033187012519, 0.20963343341023694, 0.2790743394965126, 5.001002357852075, 11.37491076223312, 16.974496226156912, 13.077904851205888, 11.576690231600116, 12.538886858570962, 14.080643096277791, 34.427137221059496, 31.658353767087384, 40.355670298299486, 50.41260780826692, 56.63501270355717, 56.23365617567494, 59.10763563648347, 51.15808563847696, 54.08541717836934, 49.89783986922234, 50.92101758526218, 49.88089523007793, 52.234007466223936, 52.1565406553207, 52.82492037742369, 55.34267802392283, 61.12179625418879, 55.99249709037043, 55.89846218785932, 45.85727299413374, 39.26818532328452, 41.356670933385054, 42.46487386765019, 43.05688112012802, 41.71092764023812, 42.76686499195714, 41.79710603529408, 41.44912119834654, 45.486679615512976, 43.33592245655675, 43.53086817649103, 40.9610410659544, 44.15872981471401, 49.41054421086466, 56.154914594465694, 56.25771599431192, 58.340180766197946, 57.186596009039114, 53.959061945638354, 48.36380089482954, 46.44531473036736, 44.17637655811925, 40.88915578780636, 45.46534976651592, 53.856335070825395, 51.65823098151915, 62.70205643869216, 36.020368683722715, 34.15741151379001, 56.52239753353981, 49.01391806141023, 55.52546831869311, 55.5224363265499, 57.758077498405214, 54.36515669668875, 58.973063038241484, 53.00285085555046, 51.16342398428148, 42.06989119129796, 44.10400098369968, 44.24394330670757, 50.02858423417615, 51.30768875921927, 53.84326181104107, 55.681810071391446, 53.775502866314305, 50.25024913972425, 44.75489870194466, 40.71537909969207, 43.39518946986045, 43.537124356915875, 45.1889560299535, 44.61343842168009, 44.08454602764499, 43.55623022202523, 43.77280781345983, 43.54297653321297, 43.75239187671293, 42.59077802781136, 43.173053879891675, 47.6001585683515, 55.503812912971746, 58.31298697379328, 57.69735528576759, 58.241980306563846, 57.228408475076, 54.47143331650765, 55.73439728829169, 53.95783424377442, 54.63601596893803, 57.39523864561512, 58.123124645602324, 54.67765977305751, 46.83712028688001, 30.606350552651193, 22.54446387290955, 17.68071113094207, 14.499049186706545, 28.47413443749951, 30.015933821278235, 12.628354161016404, 15.846400991562875, 4.326045801562648, 0.32457858324050903, 0.5119970603094948, 0.4752372505684053, 7.619091781877703, 39.674142791378884, 58.839847580079116, 38.61329463220412, 35.54483621351181, 48.806208948935236, 59.0922167993361, 64.50646046669253, 49.49420052189981, 15.449021747035367, 0.9039687966146778, 0.10760575172401245, 0.1412794375491719, 0.2821098250006476, 0.04060340309215169, 0.20855594606649494, 0.13628995286360865, 0.14234817616881865, 0.1847034461435772, 0.16189907707514303, 0.17398000784939335, 0.12855343009916045, 0.06756376084541121, 0.0716029747479385, 0.22839947723813597, 0.24643825847775708, 0.2442950662225485, 0.126023355781311, 0.1413553721842266, 0.07775327416076776], [0.025509862199185357, 0.061138853385684, 0.07789682371601944, 0.09322459599183452, 0.01305668642969742, 0.013834348027293962, 0.029596303507024725, 0.029979071677512223, 0.08744571132645493, 0.0499213841413298, 0.028279155132270632, 0.07223547992086218, 0.0642523151491919, 0.07639772754402892, 0.014286827326061265, 0.024491049529563998, 0.018351092303712523, 0.04224138717437464, 0.003116312807598602, 0.05243777995929123, 0.30783726383120785, 18.018609592991492, 47.660590525596376, 49.33043764483545, 33.22513864886376, 24.519979338492117, 24.346618421616096, 35.92748695804227, 31.79428742777917, 6.3354069090658625, 0.14535522448920435, 0.04619566873917657, 0.015852342363476993, 1.583152687357318, 9.078175733166358, 6.834470658533036, 19.29788670232219, 11.791989130358543, 5.564397390811674, 21.060323330663866, 20.25681991730967, 20.41954532746346, 39.87601933940765, 48.720101156542384, 57.56227670177337, 49.706086958608324, 50.34254643224901, 50.08886714135447, 45.29239677613782, 48.92513129018968, 48.05673814588978, 50.295230880860366, 50.84662983494421, 50.59243279118692, 51.04763169442454, 51.2007414141009, 51.272964016083755, 53.336570032181285, 51.00757252785468, 51.60169001548521, 46.06960265867172, 39.46000099182129, 41.42630869342435, 38.881482770366055, 38.96424478100192, 37.878881808250185, 40.14037532191123, 38.414367706544944, 38.60482231263192, 41.38103277452531, 41.154355079896995, 37.55609819965978, 39.48420201578448, 38.19913548807944, 43.410008184371456, 45.65923644650368, 46.528731776822, 44.31807610296434, 42.021657805288996, 35.89736707748906, 38.2373393735578, 36.72118248478059, 39.117228984832764, 39.215048974560155, 49.23499068906231, 47.421655424179576, 58.11536227503131, 34.155403260261785, 33.66210637554046, 58.910626749838556, 51.48065743907806, 55.7845800922763, 50.6431451151448, 53.18888102808307, 51.25412487214612, 55.67354563743838, 52.3744636197244, 48.38311856792819, 41.468454560925885, 40.792779230302386, 39.95895001196092, 45.586966776078754, 47.97800048705071, 51.417585726707216, 52.834710613373794, 52.40870198895855, 45.68637140335576, 42.87849172469109, 39.032682295768495, 38.6967783589517, 37.59678102308704, 40.29785848432972, 41.83567862356863, 44.26684210377355, 39.94531193087178, 38.424605092694684, 36.11488996013519, 39.67182859297722, 36.88831860019315, 42.254834867292836, 48.98644185835316, 55.369420743757686, 52.76766161764822, 54.09228524854107, 53.249089410228116, 50.57854367840675, 51.896240403575284, 54.191309405911355, 53.622820684986735, 59.59666498245732, 55.09777307510377, 55.82572967775407, 56.76753782456922, 49.615021290317664, 27.4261575360452, 26.59244598880891, 12.821867235245245, 16.999032612769835, 10.077634876774205, 11.164854111209994, 6.963344543210923, 10.499835860344673, 9.449026027033407, 0.09458184332376528, 0.023814141900549014, 0.033237425565359094, 2.8520311030649372, 25.96421172541957, 41.19326499200637, 25.10633053318147, 25.398035241711526, 28.001408423146895, 49.72538109748594, 46.457960451802904, 42.7439897291122, 15.048715433766766, 0.7256887372462981, 0.11824393209310309, 0.07153246401538772, 0.0736376966139482, 0.04598770651125139, 0.04322010280203916, 0.006650975696937812, 0.0029180181304728917, 0.0577194927140109, 0.024627507025856647, 0.026058666520721974, 0.04044287319805834, 0.027875354017822013, 0.02359840196497258, 0.05122934903709158, 0.013422343068786207, 0.044811960730341174, 0.009146236585483197, 0.10860075438094717, 0.025366094308875264, 0.0368401647034672, 0.021869368332948898, 0.03320370237493227, 0.04733486063477974, 0.05886897700087679, 0.03620360309498445, 0.06461051487994772, 0.010014053325228875, 0.07388488254359654, 0.025894022734475233, 0.04491710629794867, 0.024972966714431683, 0.028501115701792222, 0.034462890452555114, 0.09028872490049371, 0.016202870681281054, 0.07329830434173346, 0.046064020359828595, 0.025712818042525364, 0.020377718535582387, 0.2253796965364487, 22.157143546688943, 54.538796101847005, 57.02434716686126, 39.622081172081735, 27.75281252399568, 30.177617842151275, 36.05196337546072, 34.30946611589001, 7.10079518056685, 0.1722479136961122, 0.05867283550962325, 0.14066023932349297, 3.218160334133333, 10.311979824496854, 8.416866083298961, 10.717012593823096, 11.891365320451799, 9.245741348112784, 17.053290759363485, 19.788059419201268, 22.01111762754379, 42.26543311149844, 51.76517048189717, 56.780987631890085, 51.50063407036566, 50.317855112014286, 50.95590706794493, 48.7163435259173, 48.323624057154504, 48.319917417341664, 51.2352268926559, 51.14589098961123, 52.57038600983159, 51.42615218316355, 51.77827119827271, 53.866070393593084, 55.769651551400464, 52.9638115052254, 52.80485353162212, 46.62168410516555, 41.49247123349098, 41.93893501835485, 41.08410150774064, 40.05202001140964, 40.45635361825266, 41.7800437250445, 40.26645206635998, 40.363358143837225, 44.1550898551941, 42.30511965290193, 39.85434039946526, 41.954557818751184, 41.205738129154334, 46.5288023794851, 47.93597229065434, 48.95439217167516, 46.227909518826394, 43.599290001776914, 38.79400607078306, 38.81371205852878, 37.696550430790076, 41.734089236105646, 43.63925110909247, 52.22793563719719, 48.86924535997453, 60.385339875375074, 36.3009750458502, 34.95542164771788, 59.33241490394839, 52.829772349326845, 56.5591658315351, 51.7933762458063, 55.09849479121547, 52.725762859467544, 55.881592073748195, 54.16642981190836, 50.90020941149805, 43.42046130088068, 41.73105724396245, 42.05937923923616, 47.37511650208504, 51.06745535327543, 53.40429367557649, 55.44051370313091, 55.230792414757516, 48.14694089274253, 44.227967492995724, 40.69120945469026, 40.20662807649182, 40.00119786108694, 42.12856592670564, 43.894393444061286, 46.51093990572038, 41.606208201377626, 39.84438542396792, 39.25739488294048, 40.45229004275414, 38.785247418188284, 42.96717259191698, 52.56366306735624, 57.119974551662324, 56.71345226226315, 56.01844749143047, 52.73790651752103, 51.96330116641138, 52.3609471321106, 54.61691010382868, 55.00807631400324, 59.91698926494968, 57.12024519520422, 58.57734295629687, 59.766946838748076, 49.767291622777144, 32.05772557566243, 20.960346037341704, 10.73101741652335, 6.738952609800524, 15.64045008151762, 16.195360537498228, 7.692935793630539, 14.902555173443211, 8.442292847941, 0.6291368375382116, 0.007817009398187962, 0.05134257683230024, 3.4624418712431386, 27.568937693872762, 45.37350746893114, 29.500883471581247, 31.170346198543427, 34.42224210308444, 54.51519520052018, 53.40211283776068, 48.79751697663338, 18.319682882678126, 0.6613299358756312, 0.07740291150947733, 0.009666311652249387, 0.0485025969664416, 0.01734836173484162, 0.041114054319839326, 0.024366184858785524, 0.01132181999574025, 0.06499892911843716, 0.011849917918293467, 0.024810898898830338, 0.002825265471455491, 0.020250463670480157, 0.011554763393266308, 0.008550402126275003, 0.05790671694182581, 0.01908460233901297, 0.021819708598477226, 0.041345512464402184, 0.022982268090990764, 0.17402938987699249, 0.13384391073017352, 0.1773205955302523, 0.26553603369862805, 0.12439700474421825, 0.21537509386337575, 0.15742097140079545, 0.13709934007736946, 0.223695007903922, 0.16967741291849844, 0.15631739110235246, 0.19168649079097858, 0.21090650300104774, 0.10733711533248426, 0.14097753761997148, 0.13588021839818648, 0.09970431321210439, 0.13408794037757382, 0.09014581885909842, 0.14200011178130104, 0.8793989472812223, 29.050238440113684, 60.890137149441635, 64.15908751949188, 45.47052729514338, 34.25674161603374, 34.24271914266771, 47.231185128611905, 41.48263392909881, 8.7679672433484, 0.37467322582679413, 0.18656404388527717, 0.25016071034535287, 5.0058817863464355, 15.92386878305866, 16.848248858605665, 31.056775931389105, 20.761234760284424, 11.208969989130575, 23.971898709574056, 23.83421371060033, 27.35018907054778, 47.34877386400777, 54.76160633948542, 55.83883431649978, 52.35487138071368, 55.14708119053995, 51.76101669188469, 50.32852395888298, 49.14712567483225, 50.021982885176136, 51.22009046616093, 52.0517506137971, 51.90075112927345, 50.866716292596635, 51.8034920384807, 55.16549671849897, 57.768507080693404, 54.49797991783389, 56.63351828052152, 51.12541229494157, 43.08793060241207, 44.27416124651509, 42.595135781072806, 41.81826722237372, 42.78438621951688, 43.05466498098066, 42.68895495322443, 41.9373268465842, 45.99457948438583, 44.79243186212356, 43.29125058266425, 42.81933453775222, 42.70382465854768, 48.156927247201246, 49.53427145558019, 50.605121658694365, 49.043429974586736, 46.86275297595609, 41.61042867168304, 42.545329524624734, 39.089486060603974, 42.65217488811862, 44.8994537322752, 53.4582027312248, 53.55059808300388, 60.52961249505321, 39.27100550743842, 37.67816628179243, 61.28732027546052, 56.63731513484832, 57.90248740103937, 54.1819663201609, 57.19291494738672, 55.6017937198762, 59.78635080399052, 56.99489408923734, 53.33401264682893, 46.972975500168346, 44.28668929684547, 45.034473480716834, 49.6553393333189, 52.66305592752273, 54.02287890834194, 57.44902610778809, 58.4651670917388, 49.65840270442348, 47.67156139496834, 43.04623188511018, 42.35768725795131, 41.897126474688136, 44.298024946643466, 46.44287109375001, 49.71816001399871, 44.23161529725598, 42.04987925867881, 40.509282081357895, 43.0630470860389, 40.65494322007702, 45.78088875739805, 55.19409471942533, 60.16178438740393, 56.7784498583886, 58.260756692578724, 54.01367310554751, 52.937292360490375, 54.530257101981874, 57.220289168819306, 56.27848886674451, 62.379680756599676, 60.82414719366259, 60.984289723057906, 61.483121072092366, 54.20397866156794, 36.48987639334894, 33.92425406363703, 17.195260947750462, 24.859380068317538, 23.866953734428655, 16.557952280967466, 17.070706082928567, 17.82811184083262, 15.584731832627329, 1.20069119718767, 0.2818810405029405, 0.16265569615267939, 4.455987061223676, 33.13286096818986, 53.370875081708355, 35.41114222618842, 36.22563023721018, 40.36083213744625, 63.32525830115042, 59.89575355283676, 57.48922255731399, 22.990404021355417, 1.2330674211825094, 0.3056485812750555, 0.17706513585102174, 0.2184516263584937, 0.22251782187771416, 0.170522193394361, 0.11669625062495471, 0.1742865043061395, 0.19518604171612572, 0.10641407897515644, 0.1510768287604855, 0.1361865156720723, 0.14342384022330085, 0.11963004561802072, 0.1478931358865192, 0.1701033731261569, 0.17016686649332124, 0.1524443263488431, 0.1269606720175474, 0.09866522219512733], [0.06332986484912616, 0.09979368502935095, 0.07825739831934053, 0.03586597282499556, 0.1238564071395705, 0.011470728336022267, 0.03453839224793258, 0.025546157529817957, 0.027187146591923894, 0.020765820593242685, 0.08243005707739823, 0.023235375880293792, 0.022521780300585013, 0.046304445563545155, 0.06726702434882041, 0.050004673220457575, 0.08277206170943477, 0.011861132487895028, 0.07667043186243504, 0.056097615630395954, 0.188752236145158, 25.769564105618386, 49.021664742500555, 45.840838263111735, 33.54772221657538, 15.03978027451423, 12.476076964409122, 33.4647915440221, 26.95686555677845, 2.8514334319099306, 0.15762871912410184, 0.04095955353771006, 1.5752829419028376, 1.5255312309149773, 5.019512022695234, 5.451868022641828, 5.33555111577434, 9.74607692610833, 8.42352234548138, 14.605226766678596, 15.107926553295506, 31.122885519458404, 42.65105701261952, 52.93686482214159, 52.780676041879964, 52.659580707550056, 54.038944936567745, 55.34155622605355, 48.02945413897115, 50.7352384444206, 49.543814582209436, 50.77064960233627, 50.52449733980241, 53.526675547322924, 53.529150562901656, 52.53391188959922, 51.3056295148788, 54.152034713375954, 54.045652189562404, 50.652531346967145, 49.834783846332186, 47.034717529050766, 45.34947510688536, 43.66143211241692, 41.62109359618157, 38.147336667583836, 37.31198949198569, 37.14752843303066, 39.72201139696183, 37.0546623968309, 37.60708508952972, 38.72945562485726, 38.66871772273895, 36.596486414632494, 38.41934519429361, 36.64397062793855, 38.645689487457275, 37.72676444822742, 40.14607844814178, 36.0734030508226, 40.342746088581706, 36.70924278997606, 41.2381878975899, 42.42073151373094, 52.01540593178042, 46.79981854654128, 60.80639062389251, 36.2784763305418, 35.669799004831624, 60.9912048616717, 49.48713633321947, 51.69402260934153, 47.361772598758826, 49.43491389674526, 49.067697678842855, 51.911498423545595, 45.7344243603368, 44.870526252254365, 40.33792157326975, 39.38537397692281, 38.006119574269945, 41.95144345683437, 45.86940488507671, 53.72159773303617, 53.5633183294727, 51.26710791741648, 49.80037681518063, 46.261441861429525, 40.21240180538547, 40.609796739393666, 41.473585021111276, 49.637857329460886, 52.29807546061855, 53.278718994509795, 49.449234470244384, 46.94068262653966, 40.31928247021091, 38.925429005776685, 39.88114979959304, 46.841285844003, 51.76081272863573, 54.586394063888065, 52.743142881701075, 50.491769083084606, 51.77982837923112, 52.84546183001611, 52.386936756872366, 55.83923832062752, 51.89881347840833, 51.36989362778203, 51.25123800769929, 58.712860845750384, 52.84436356636786, 53.489267902989546, 35.326050327670195, 26.828213776311568, 12.166838280616268, 8.666244495299555, 7.215780442760837, 15.667764486805087, 5.75945980125858, 3.5439575487567536, 7.799592883356157, 0.8653026843263257, 0.2267610756379943, 0.15301895357908743, 1.624368953128015, 16.351010972453704, 45.56504857155585, 28.046150899702504, 18.551855817917858, 28.220229610320064, 45.09554478429979, 49.90454319984683, 46.374182547292406, 15.615858781722286, 0.6168659476022567, 0.08008405836599489, 0.07619071526512985, 0.037222312342736034, 0.02976288166528027, 0.023218996920472672, 0.01156155763554477, 0.10085489300470199, 0.021561581018050353, 0.05355045755183505, 0.02624570114177562, 0.03482490913161347, 0.03549264668817482, 0.04988562315702439, 0.027528689655986045, 0.029782041524266525, 0.03171281291983061, 0.07206758409137688, 0.05396805207936033, 0.041254819145486246, 0.05847036613211517, 0.08353118589448352, 0.07968498018359946, 0.0032438793747250234, 0.08039012581350342, 0.016078138160669518, 0.040671676847963564, 0.05780980681940433, 0.05479687877419976, 0.03677189477809495, 0.09772564599951429, 0.10224535790902954, 0.06616041034219727, 0.0475798134181288, 0.01711709128182021, 0.035604916873478124, 0.043620039002909776, 0.040250979664344946, 0.024895591834079356, 0.051612699434401534, 0.5991004299252265, 31.96084107122114, 53.927094628733975, 53.217530019821666, 37.5356783405427, 21.10980599157272, 15.87420863489951, 35.32707798865534, 32.07366608804272, 3.4495164357846786, 0.35208683941633473, 0.06163950716595977, 2.3896363665980678, 5.173837677125008, 11.857665296523802, 9.783784631759891, 13.040979658403705, 11.828927070863786, 11.708873125814623, 16.95417638747923, 16.671461751384122, 35.113277435302734, 45.582012822551114, 52.4966376058517, 55.32359569303451, 52.6481822998293, 57.04845797631049, 54.81564091097925, 49.875239172289454, 51.57875591708768, 50.81634129247358, 50.957601531859375, 51.34346077519079, 52.45070665113388, 54.11271295239849, 52.61532852726599, 51.799856001330966, 55.02213801107099, 55.13092887017035, 52.71245817984305, 52.90485435916532, 48.408574750346524, 46.31300533971479, 44.74217453310567, 42.83668318102437, 40.431834882305516, 39.76236081892445, 38.871731758117676, 41.55269922748689, 39.43844364535424, 40.474055274840325, 40.061578827519575, 40.344687661817, 39.44220519834949, 40.42458634222708, 39.39557213937083, 40.92648890710647, 39.50862661484749, 41.0223477117477, 37.5015890213751, 42.00244603618499, 39.39614872778616, 42.966070405898556, 44.07889389222668, 53.71745963250437, 49.09414622091478, 62.54403198918989, 38.35119009017944, 37.007997958890854, 63.02827604355351, 51.59406100550006, 53.44028534427766, 49.27701888545867, 52.47640209813272, 51.6921006479571, 55.04671558257073, 48.82451465052944, 47.159711699331964, 42.2593181363998, 41.179207217308786, 40.15627268821963, 44.52209818747736, 49.51939782788677, 54.21766381109915, 55.79682573195427, 52.80075857716223, 52.13596390139673, 46.933649816820704, 41.805190040219216, 42.4552091475456, 43.371015902488466, 51.436432715385195, 53.476826144802956, 54.59203050982568, 49.93298822833646, 47.12878381052325, 41.051667428785755, 40.68189774790118, 41.27700759518532, 48.964437361686464, 54.26154336621685, 55.72387749148954, 52.47954783901092, 51.96734120768886, 51.84772852928408, 54.3990969657898, 55.32225816480575, 56.864953810168856, 54.62393114643713, 52.33614990788122, 53.63453288232127, 58.123979722299886, 56.88188275983257, 55.92226313006494, 40.17952842097129, 26.83019849561876, 11.63611904267342, 10.670667829052096, 14.810302007582882, 13.788110767641376, 11.349575192697587, 11.489712653621552, 7.312540411949159, 1.6530273830698383, 0.06989079121980937, 0.033156576476270155, 1.7890082347777583, 19.14357085381785, 45.63974226674726, 32.87081330053268, 24.949824040935887, 34.37325562200239, 50.928383796445786, 55.859717015297186, 52.987428096032914, 20.326183111436908, 0.8341033552442828, 0.10187091711427897, 0.17510946659791857, 0.09546904974887449, 0.07492883055801354, 0.02360282420751549, 0.011452188050644773, 0.0637760880823818, 0.021306615465530948, 0.03557678612489854, 0.06589097721922783, 0.06872970070089064, 0.04019838772834309, 0.011193665934936895, 0.01402032161657248, 0.027041306433778618, 0.043586292829845226, 0.04370560336317267, 0.06414597831486214, 0.06592987150314354, 0.17231750512315383, 0.2198013660287665, 0.16129089519381523, 0.0977702629602244, 0.19204621503670372, 0.12846573601446806, 0.23114694432625849, 0.2632646442901704, 0.2835933695877752, 0.13109768470448832, 0.30724688583324034, 0.2337761427606306, 0.1883983341676574, 0.1326946715914434, 0.1331752998333785, 0.16982729036000468, 0.17077518627047542, 0.07726647891104221, 0.17388614675691053, 0.23646308890273496, 1.286199112092295, 38.25702574945266, 60.87879365490329, 60.1622276152334, 44.30768574437788, 25.07580860968559, 21.366683975342784, 45.034967699358546, 37.36547100928522, 4.322668640844284, 0.36780432828011056, 0.19457131744392459, 3.031771755026233, 5.435853475524533, 11.169735500889441, 10.832092973493761, 13.644874634281283, 16.301139996897792, 12.290533165777884, 17.91644753948335, 19.82003850321616, 38.79444145387219, 48.46078149734005, 54.94874654277679, 56.66131219556255, 55.354021518461174, 57.67307973677113, 58.69211935227918, 53.157254957383685, 53.05990957444715, 51.12138009840443, 52.791156614980395, 51.50714912722188, 54.637616295968336, 55.596110205496515, 52.89736263213619, 52.45608029826995, 56.386844342754735, 58.03564794601933, 56.545445380672334, 54.804415087546076, 51.89284363100606, 49.6881107361086, 48.72346655015023, 46.383886491098714, 42.63632851262247, 41.45233754188784, 40.827605955062374, 43.510079614577755, 42.744338820057536, 42.157242375035445, 42.54846742076259, 43.081737179909986, 41.01093361454625, 42.67038253045852, 41.37240356014621, 42.34357457007132, 41.11065203143705, 43.91666073952952, 40.525681511048354, 43.791458683629195, 41.983187198638916, 45.980003956825506, 48.17415429699806, 57.15087498387983, 51.9504475593567, 63.76329291251398, 43.06389824036629, 40.280474539726015, 65.17246715484127, 55.34301142538748, 56.242630558629195, 52.60718176441809, 54.24855639857631, 54.58732758798907, 56.83187254013554, 51.06330156326295, 48.74174087278305, 44.68122874536822, 43.33594206840762, 41.7011687832494, 46.19188647116385, 52.28412751228579, 58.885186256900916, 57.35930189009636, 54.04768005494149, 54.20866981629403, 50.48011572130265, 42.967886463288345, 44.51095081144764, 46.34948338231733, 55.64942306087863, 56.86172569951704, 58.3226046254558, 53.82011590465423, 50.097606182098396, 43.22586859426191, 42.55628078214584, 44.98968001334898, 51.928133195446385, 56.90552680723129, 59.07053785939371, 54.09606641338718, 52.259412657830026, 52.34051942825318, 56.06859107171336, 54.61527055309665, 59.3916230816995, 57.38387553922592, 56.65534627053046, 56.03392124176026, 63.84458011196506, 56.874336119621034, 58.97646373318088, 41.169330689214895, 34.31681271522276, 16.182107829278518, 14.98563587665558, 13.402938919682658, 22.496865910868493, 12.703132187166522, 7.288286926284914, 14.616910526829383, 1.8055882160702061, 0.8484740615371735, 0.29510917262204234, 2.6900413824665934, 21.93054626064916, 57.65594682385845, 38.37035479084138, 27.91669111098013, 39.805765767251295, 58.733649407663655, 63.64709269615912, 60.73605860433271, 26.104663956549864, 1.4718600915324305, 0.25060332530448515, 0.2013327328548316, 0.24203774218838064, 0.10943664823688808, 0.1183917640798515, 0.10433185965784135, 0.1582682186797742, 0.13693311431955907, 0.16393232039145886, 0.11458065285677872, 0.10592698495114043, 0.1448679772476035, 0.1648642203860706, 0.11136203403434447, 0.16437780051942796, 0.15418317739761647, 0.2519596992961822, 0.17479026840338785, 0.09419429476463026], [0.07082403952916784, 0.053923550031838886, 0.061848825369510925, 0.02013559453189373, 0.09405530343252806, 0.03198396782540987, 0.07867746731086124, 0.05271584306272769, 0.05064527977318053, 0.035752400290220976, 0.049383774279586734, 0.011920881600329473, 0.021542612681045167, 0.10287001068072935, 0.07968134126595913, 0.0671352419040857, 0.03158094620542421, 0.04730547350200434, 0.039704984970270626, 0.010074266878467415, 1.125185081074315, 23.873054981231693, 44.89043228087887, 46.01228898571384, 33.92219089692639, 19.06378984451294, 32.338518250373106, 33.14319641359391, 22.323291224818078, 2.503817297758595, 0.25038934162547516, 0.40378456694945214, 5.565135776996613, 20.823733806610107, 11.288521539780403, 11.792250948567546, 9.840138304618097, 13.064873756900912, 15.49541554143352, 14.326987554950101, 21.954898295863984, 41.31502712926557, 50.62391373418993, 57.17861790810862, 52.96492153598417, 57.48721430378576, 51.159654586545884, 54.79993574080929, 51.00525048471267, 50.84934803747362, 52.90898853732694, 53.235200297447946, 51.766998306397475, 53.541988480475645, 52.3066105381135, 51.87427905298049, 50.74340481911936, 51.19265348680558, 51.91845670823128, 52.18231847209316, 52.476594294271166, 51.288614273071296, 51.21071992381927, 51.735497751543605, 52.39171812611242, 48.45276417270784, 41.38097786134289, 36.918054088469475, 36.634137245916556, 38.179998244008715, 39.132059466454294, 37.78625111426077, 37.369958200762355, 38.542068312245036, 38.58792081955941, 37.373433420735026, 38.512619156991285, 37.36315681088356, 37.841442784955426, 37.04447600149339, 38.50835554061398, 36.50622875459733, 42.63964291541807, 39.441169692624, 49.237100924215014, 47.216546843128825, 55.557886708167295, 38.3750145666061, 38.575839919428674, 56.17258879446215, 48.82122770432503, 49.13597437643236, 41.25546986056913, 40.93532992947487, 37.603919736800655, 40.40529612571963, 39.98287254764188, 39.21338196723692, 38.30236442627446, 40.52415963142149, 38.660802379731216, 37.74416015994164, 45.813687616778964, 52.83093729326802, 53.664892027455, 54.01510869303058, 51.71030044555665, 46.488127400798184, 44.30022539631013, 46.31035381747831, 50.159795361180464, 52.069577786230276, 55.17099588148056, 55.05779627830752, 55.490567068899836, 50.739545206869806, 48.67209919037358, 46.196240302055116, 45.5980827731471, 50.29806283212478, 52.88836863733108, 55.95118276534542, 51.78515495792512, 51.476793904458326, 49.76727985566663, 50.70780538743543, 54.04666023869669, 51.800820904393355, 51.02794531852969, 53.36693702205535, 53.860418258174775, 53.574752038525, 60.002512624186856, 52.96682780788791, 43.08577722118747, 27.68840132221099, 15.34153409542576, 7.231438054192451, 22.404643143376997, 20.52103469448705, 7.10445131986372, 10.97205981131523, 11.474910609183773, 0.5966257820686987, 0.06302825986377655, 0.1322480270098294, 0.6619313455397083, 13.582892360225802, 39.35837238065658, 32.27612314685699, 23.978872683740434, 30.629157174018125, 45.39031874748969, 51.42923908848917, 48.55049394792127, 20.106612751560828, 1.8164341824669994, 0.01282712722557687, 0.02903995704987357, 0.028797940298494314, 0.04236915148794652, 0.04483362569683983, 0.05091266744139214, 0.06284389314391921, 0.06569931734233134, 0.030266864097587047, 0.07866460469461257, 0.025522146419051196, 0.1202404261716912, 0.012587519820719477, 0.03661887637609917, 0.09949936170972164, 0.04802073915338805, 0.0461363620425184, 0.01974609244855181, 0.05956559224174388, 0.11766385031683792, 0.024705264950171116, 0.022172135856723594, 0.06639521629098924, 0.029662842073688106, 0.04841807448575574, 0.03446737589735178, 0.0028634645305799264, 0.0662560947239399, 0.012977155011838243, 0.04408607326988732, 0.02402125760131786, 0.027421263061584007, 0.055346818821084116, 0.06876885545470061, 0.03888627446647133, 0.08751560152778703, 0.042085469129585454, 0.06403312207229676, 0.044145085022694645, 1.8438351250463918, 29.142376876646473, 53.024706302150605, 52.40164956738872, 37.776672686299975, 20.2031030577998, 30.87210289893612, 38.965719592186716, 27.168195016922493, 2.714121058102577, 0.3258938949194647, 0.38789979512653044, 7.637773540712173, 18.41764211654663, 11.96008622646332, 10.42423217527328, 9.134679436683655, 9.462051237783125, 11.691348956477258, 14.704048921985013, 21.594130454524873, 43.52046212842388, 51.21079052648237, 58.900663929600874, 55.955383623799975, 59.0351894594008, 53.43449592590333, 57.831312071892526, 54.246732496446185, 53.3269053120767, 54.66846965974378, 55.01804697898127, 52.62741727213706, 53.84561523314446, 51.653131900295136, 51.95857471035373, 51.03470748470676, 50.706989534439586, 54.83695899286578, 54.55416787055231, 53.94683591781124, 53.41101661805184, 51.97863371141496, 53.543396611367505, 52.880064979676284, 49.05598155913815, 42.40289257418725, 38.713381751891106, 40.03470274709886, 38.86644048075522, 40.13511542351016, 38.987433833460656, 38.70832581673899, 39.36208294283959, 40.48546937204177, 38.1151653874305, 40.97804846302156, 39.48411180127052, 39.29089976895241, 38.86036080698813, 40.0274149833187, 39.01543171175065, 44.205857092334384, 41.6756929889802, 51.36072312631915, 49.47410229713687, 58.27353185222995, 42.00781183858072, 40.79907463442895, 58.75410456811228, 49.808472587216286, 50.82182084360431, 43.446093989956765, 44.056081387304495, 41.20396129546627, 42.26057721722511, 41.55927311989569, 42.155551833491174, 42.13947796052502, 42.61660683539606, 40.84019676331551, 38.69609978891189, 47.04470780587966, 56.00685688757128, 55.61312152493385, 55.3266433746584, 52.87515417222054, 48.98735184823313, 46.854672893401116, 47.55301167888027, 51.87205506909279, 55.04573106765748, 56.97582352545954, 57.26622796827748, 56.44208308189147, 53.81452260478851, 50.850348241867565, 46.72105735348117, 46.22337133653703, 53.34808218863703, 54.25651096528577, 57.075773362190496, 51.81376864833217, 52.65190462912283, 52.10052528688985, 51.596528176338445, 54.40075612837269, 54.77578178528817, 54.178396963304095, 55.42410250632994, 54.99448922372634, 56.416650433694166, 61.12340834832961, 53.86007308959962, 44.345077699230565, 29.788877617928293, 17.296554196265436, 7.13359207876267, 10.451541677598032, 10.989812458715132, 10.070154916855598, 16.96615726717057, 8.143623480873725, 2.0464579040004365, 0.08072944913780497, 0.13118213823726102, 0.6998012779701142, 15.626158925794787, 44.437072969252064, 32.59817131104008, 23.923163260183028, 33.39686393737793, 50.859938436938876, 57.451575648400095, 56.22702737008372, 26.075279520403956, 2.313472272888307, 0.04096256426325248, 0.035774816022885424, 0.023137933326764934, 0.07717022762423562, 0.044742530181763635, 0.1132893963386455, 0.025907611219032158, 0.009724552529082905, 0.06493954964342617, 0.057435197485310424, 0.08291941872167011, 0.03586457088409412, 0.052986930935613574, 0.0446286971770948, 0.008933846369355677, 0.09160490225880377, 0.022708885784771655, 0.02327011796765991, 0.010713188995366857, 0.158110864220127, 0.12121882770330676, 0.14733439731982448, 0.20489746254057656, 0.11676156728137886, 0.23029833341077452, 0.15147004637026018, 0.09185409533881372, 0.12252942794152807, 0.15794492957572784, 0.16736716753052128, 0.13226399228217142, 0.1736592621572556, 0.19579877415972372, 0.2143428057071663, 0.2167117793954188, 0.22535432370439654, 0.21392439912644126, 0.18097478896379474, 0.13788404393820994, 3.048548467697636, 35.60507597461824, 61.84291616562874, 59.27649367240168, 47.069355980042495, 28.251255558383082, 44.22344892255722, 43.861469068834865, 30.503923739156416, 3.3687359575302374, 0.5322796671140579, 0.3999234225240446, 9.499813856617097, 29.338285538458056, 20.54585741412255, 20.511395469788585, 16.983245072826264, 19.727698064619496, 21.096369912547452, 18.9331631506643, 26.868906405664262, 47.397254359337595, 52.34950557831795, 63.19114069784842, 58.28516952453121, 62.37405607777258, 55.95225749477264, 58.83558788607198, 54.98223966167819, 56.4499984248992, 55.451845430558734, 57.32835046706661, 53.68898322505336, 55.5718425012404, 53.20207980371291, 53.935880737919966, 51.58203109618157, 51.85991533340947, 54.478128802391794, 56.01144213830271, 55.73114956578901, 55.295672339777795, 54.803901257053504, 56.71936327411283, 56.36660883503576, 53.47850491923671, 44.34472860828523, 40.08148485614408, 41.541422413241484, 41.3672338762591, 43.33321209876768, 41.25513645910448, 40.4047469938955, 42.73776100527856, 41.91553023553664, 41.19280607469621, 42.36233134423533, 41.51411879447199, 40.632064034861905, 40.45020726419265, 42.230943710573264, 40.7766818231152, 46.74468571139921, 45.074744455276, 53.6856766669981, 52.00654529756116, 57.90513892327586, 44.696180820465095, 44.397704139832534, 57.74398442237609, 54.46722069094258, 52.779334591281035, 44.93836756675474, 45.07969840880364, 42.72311095268496, 43.75303122305101, 42.99708066448089, 42.89365560777726, 43.429831843222345, 45.400858156142704, 43.67956130735336, 41.35793785895071, 49.37646665880757, 58.229146311360026, 56.540483582404356, 56.89646613213324, 56.371531409602014, 51.69302632731777, 48.92026362880584, 51.01364043451125, 55.47988645492062, 56.740697045480054, 59.367900586897335, 58.2832161841854, 59.52746260550715, 56.029049658006244, 53.604514983392534, 50.62147794231292, 51.09075815446916, 55.871378221819484, 57.178766958175174, 59.07194599028557, 50.91798559311898, 53.37631933150753, 53.71698502571353, 52.780832936686856, 56.29832037033574, 56.6214491475013, 56.184477498454434, 59.04033560906688, 59.09308756551435, 58.75639523229292, 63.9044080242034, 56.017286469859464, 47.845236101458156, 34.21937711777226, 20.30152709253373, 9.798073826297637, 28.429021296962617, 28.76412114789409, 12.301860970835532, 20.614655786944976, 16.650286836008874, 2.853049203272789, 0.1474139019246063, 0.3621440723298058, 1.0738479970924317, 18.240198012321226, 50.16898939686437, 43.14474613435807, 34.895111283948346, 42.279384982201364, 58.96136260801747, 64.46487549812564, 62.67037153244019, 30.89855144100805, 3.7670778987869142, 0.16159377571555877, 0.13397906396177509, 0.11272101272498408, 0.19852802367700687, 0.20158462256433504, 0.15985256511597865, 0.1267104293970812, 0.16312506290212755, 0.08463772329231424, 0.1271790377194843, 0.15782754958396958, 0.21731593165426485, 0.13385057569511477, 0.1913405254843735, 0.2332043040904307, 0.18257257258219106, 0.1433387278549133, 0.18717251688001618, 0.1265144411234125], [0.021479619186251395, 0.05632031738998429, 0.0488698480260228, 0.03932550714741792, 0.04049060047574101, 0.0038738916496626075, 0.024317854286862478, 0.02451550114088722, 0.039674391249014486, 0.03011026614976506, 0.04631217539070114, 0.039313065879527605, 0.1261110345442449, 0.028821675617608334, 0.03514988362909325, 0.05674879419647398, 0.042561638739801226, 0.04517928073783556, 0.09952422126286453, 0.07850406330920036, 1.461891632887625, 21.66258954232739, 46.748557090759284, 44.128194162922526, 32.675800900305475, 20.96459004186815, 20.198553108399917, 37.21179254593388, 22.398437953764393, 1.0868544540097638, 0.15611125216368707, 0.21279377592427118, 4.583686686331227, 15.306472028455428, 16.650826161907567, 6.634046368060574, 11.757373232995311, 11.419543412423904, 9.335057639306592, 16.6565881236907, 29.828564159331787, 45.06305971453267, 52.98560419390279, 53.90383889598232, 50.53833153940017, 51.344013829385084, 50.71438712458457, 50.15253113162134, 48.40932392304944, 51.84066434060374, 52.390643396685206, 52.930181103367964, 53.02235680241739, 54.838186694729714, 54.77190648355792, 54.85325644093176, 51.71265386766004, 51.32220937359718, 47.716358784706365, 50.49315367975543, 51.93791166428597, 51.06717686499319, 51.35628692565426, 51.39891524468699, 54.38980094848141, 52.85564822535361, 49.43490605200491, 42.29278379871, 37.08135412585351, 35.743264998159106, 37.61880905397477, 38.27806142068679, 41.02897651733891, 37.86425921224779, 38.425738657674486, 36.4537239074707, 37.89251596696916, 37.84627906737789, 36.99595236009167, 35.994998793448175, 38.644332347377656, 36.24719935078775, 42.17800348035751, 41.215257721562544, 49.11866103449176, 47.192177157248224, 55.71460500840218, 42.21874121696719, 40.1107967284418, 58.17276224013298, 47.6641716495637, 48.91384270883376, 40.26911535570699, 41.61615140976445, 37.317241545646425, 39.703521343969534, 36.32333647820258, 35.55113946237872, 37.8208464191806, 38.97974206555275, 38.64818803725704, 38.156428721643266, 43.41918653057468, 52.28994438725134, 51.91616212168048, 52.32775995808264, 53.05100971652616, 52.1902887282833, 51.41761318329842, 51.71836091626076, 53.57131211988388, 54.23421229085615, 53.326732727789114, 50.2538969439845, 53.344595201553844, 55.95496393019154, 51.1463773635126, 50.538339384140514, 51.704154091496626, 50.17581039859403, 55.10535893901702, 50.562752216093, 49.11518581451909, 50.5926916676183, 52.61732109131352, 53.902007149111846, 55.37384125494189, 52.017786810475016, 51.03598225501276, 48.855968136941236, 54.103609131228545, 55.837681139669115, 53.35220067731796, 54.150944294468054, 51.16181973488101, 32.543393450398604, 25.10978221893311, 14.867090082937672, 17.526738489827803, 5.350771873228012, 19.814178482178722, 14.054510305004737, 12.621132096936627, 8.837141183114822, 0.2148214880857737, 0.1983581819841939, 0.22407949211135988, 9.688554386938772, 31.96520078566767, 58.09843724773776, 52.84878015518189, 38.475360562724454, 41.92120198280581, 48.49386668974354, 50.29261073758526, 25.9825841073067, 1.2602484658841164, 0.0653680685847517, 0.008103664656500182, 0.02113451955900077, 0.00817579758023062, 0.03427567771605907, 0.046396069679289095, 0.08300450810741994, 0.023854974386913162, 0.0981852681105656, 0.040353539685207995, 0.07088099050545885, 0.04688885573658252, 0.019752414589146935, 0.06413162948804037, 0.016502056744009737, 0.02272714549044688, 0.021072315134769006, 0.019131509902616663, 0.012687991294378956, 0.07399514557853823, 0.023367606486464222, 0.0431427049390491, 0.028730796522370754, 0.04246489332628347, 0.06043618221977546, 0.04567560612133915, 0.012846677789404508, 0.03332193272428648, 0.037039768912138483, 0.037040630761053295, 0.007171432850056238, 0.018757448321388617, 0.017348650933033036, 0.13362856341465829, 0.02848904215610556, 0.023359784728757316, 0.041758514294821414, 0.06318134721368551, 0.025285543994076794, 1.770519897822411, 28.960798594259447, 53.826917294533025, 50.638320599832845, 40.54183383141795, 26.71312947427073, 22.766411189110052, 34.945423526148645, 24.09357455468947, 1.499353700107144, 0.20067395852698436, 0.07880394842715994, 3.197976797819138, 19.44859200908292, 10.963304100498076, 12.206343412399294, 12.127148797435146, 10.503133593067046, 11.161222977022971, 18.468815318999752, 34.05992492552727, 48.1310474488043, 54.828718093133745, 55.505456386073945, 53.55850950364144, 53.31925669024068, 52.15477558874315, 52.872310453845614, 51.89565989278978, 53.954135448701926, 54.744767604335664, 55.550010588861284, 54.46243539933236, 55.76639990652762, 55.43448502017606, 55.03830209855111, 52.035849325118534, 51.119783693744296, 48.54154309918804, 50.930580323742284, 52.57508893166819, 52.975821802693034, 53.18745328534035, 53.69076005874142, 54.799174800995864, 54.61460767253753, 50.976730931189756, 43.71082651999689, 38.56535934632824, 38.12588130274127, 40.77563455027919, 40.12992220540201, 41.24052955258278, 40.26666387434929, 38.06539050994381, 39.006512241978804, 38.72778077279368, 39.244074513835294, 38.72225415322089, 39.003625377531975, 39.84945312623055, 38.738857546160304, 42.857993418170565, 44.138572754398474, 51.02575271360336, 50.782675589284594, 57.1568448312821, 44.60773529544954, 41.25924318067489, 60.69852152178365, 50.11393108675557, 51.54588645504367, 41.78979473729288, 41.889748496394006, 38.83706192816458, 39.15087899854107, 38.4479235833691, 38.44156542131978, 38.93040649352535, 40.6715230787954, 40.744487008740826, 39.51114085412795, 46.22065705637778, 54.19903647515082, 54.1460923225649, 55.92488327334004, 55.073426923444195, 54.50384778361167, 54.032633842960486, 53.95518272153793, 54.8356959896703, 56.17181216516803, 54.418634291618105, 51.994723273861794, 54.518439000652684, 58.39365836112731, 54.28110422626619, 52.936025434924716, 53.56045107687674, 54.60744542460288, 57.39929045400312, 53.16282472302837, 51.20012952435402, 50.95770351348385, 52.71279158130769, 55.815664875891905, 57.44761797689623, 54.20411594452397, 52.855820809641195, 53.17141863607591, 56.334425787771906, 56.68981998197494, 53.819076476558564, 55.580636455166726, 50.774564127768244, 32.422096114004816, 25.426831322331584, 12.857733388100902, 6.240146265875909, 8.386402014763124, 8.835467311643786, 13.15496765798138, 17.870757810531124, 7.068964656322234, 0.0557433114567351, 0.13043806767992436, 0.21330487914383414, 11.110870530528407, 32.63087995590703, 45.653141083255896, 44.3005274188134, 40.878039790738015, 47.46572717543572, 53.74923475327031, 57.30971136400777, 31.691686068811727, 2.3770328106418734, 0.12397438467990969, 0.02258003745678692, 0.038483469266324274, 0.009366848840258055, 0.06964476208292669, 0.06935067625055391, 0.033530695514092525, 0.004286007212114431, 0.07695531697883722, 0.02409805217006755, 0.04321299733654146, 0.07538948688776263, 0.07836830486813862, 0.01873145687333759, 0.03407051553949714, 0.04040259229499967, 0.0445616721445995, 0.011886152919502029, 0.025780287406016743, 0.17243626407317578, 0.19020181239372302, 0.16039026690827263, 0.1160260692479149, 0.08999841588158762, 0.18436884958176844, 0.12860783766354286, 0.09755562044559948, 0.10629315199630876, 0.20547985790237305, 0.12162353663194565, 0.18674307863318151, 0.163966779026293, 0.0950486436786671, 0.2044776003927954, 0.18214996783964096, 0.18145204641886298, 0.13055636697719175, 0.2915226247522139, 0.1875957344929057, 2.86210693659321, 35.769686083639826, 63.84111665910291, 57.25053848758821, 47.039016446759625, 30.057710985983576, 29.022332737522742, 49.183666475357555, 29.925680083613244, 1.8826472230495948, 0.3527908742187485, 0.4564939595518574, 7.197047202817856, 17.246520442347375, 31.972496394188177, 16.70718473772849, 20.560760459592267, 16.513523594025646, 13.459057250330526, 20.96706505744688, 35.85691175153179, 51.08179946099558, 57.66973003264397, 59.210660611429525, 55.776460786019605, 56.59531047267299, 53.458979360518924, 55.4304135999372, 52.08317272124752, 55.458780181023386, 55.67109023371051, 57.467759347731075, 55.48317732349519, 57.210997073881096, 57.541519518821474, 56.37493994928176, 52.869686388200336, 52.17048075891311, 48.71752808170934, 50.867716496990575, 53.30850547359836, 53.27517709424419, 53.90854181781892, 54.61959692739672, 55.94798995602516, 56.768185015647646, 52.49389586910125, 47.86121975991034, 41.10537252118511, 40.05465976653561, 42.395016454881244, 43.00649435289445, 43.81717766484907, 41.581536492993756, 41.5393082557186, 41.151021065250525, 40.83392881578015, 41.52781571111372, 40.499417320374526, 40.654417622473936, 43.30675571195541, 40.96854063772386, 46.59809889331941, 47.26396437614195, 52.15705056344309, 53.90498030570246, 58.796870170101045, 46.535619458844586, 44.4030071843055, 63.75576980652348, 52.74729274934339, 53.13734892875918, 43.63002177207701, 45.241025493990996, 42.05752003577448, 42.781903359197806, 40.15937528302593, 39.45073243110411, 41.93666788839525, 41.94929792035011, 43.17955716963738, 41.64085449710969, 48.27140554305046, 56.32220760468514, 55.61116818458804, 55.903631871746434, 58.3355680588753, 57.515863295524355, 56.16263774133498, 56.248690620545425, 57.220787309831195, 55.93970591022123, 54.262888739185954, 51.81472178428404, 55.816355213042236, 59.991424083709724, 57.6937270933582, 55.08126774141866, 56.3669853825723, 55.54995567567887, 58.82751957062752, 51.77394874634282, 53.19421937388759, 53.00957772039598, 54.43397075899186, 56.06089538143527, 60.02001423989574, 57.63239691334387, 56.30539240375642, 56.664599141766956, 58.41601194873933, 58.82286763960316, 55.671239283777055, 56.38874276991814, 54.26084910669635, 38.22012016850133, 31.47428477964094, 18.448285633517852, 25.553751376367387, 13.197566559237819, 31.830663488757228, 26.728554194973363, 18.035677786796324, 14.093271167047563, 0.30646780505776405, 0.37888091778562916, 0.4983965788156756, 14.358843084304565, 42.5306559378101, 69.84901105203937, 62.688234006204915, 52.05930509874898, 53.46297233335434, 62.54980571808354, 64.72974531112179, 40.359220043305434, 3.317958179020113, 0.3116915747523308, 0.15649480174385733, 0.21136253982061343, 0.13560926842112697, 0.119983242794631, 0.19571189978911033, 0.11181230987271956, 0.07289652186896532, 0.27539668845072873, 0.14916787554900493, 0.19473406516255873, 0.20158705872393426, 0.1615644651915758, 0.16475437869948728, 0.15370377489636022, 0.20920813203819338, 0.13982786947200376, 0.1042974163447657, 0.0889427237392914], [0.010641883446594641, 0.014440254627486632, 0.04308725166465006, 0.029789652607794252, 0.04989344491473129, 0.04019986627803695, 0.029558627302908612, 0.03161963747603999, 0.010986260078366726, 0.024238397562575918, 0.0620125804937655, 0.029387178740674452, 0.07589979337588434, 0.007636051769593671, 0.0494017007370149, 0.07414187439867566, 0.19184078089892867, 0.03344227747631169, 0.04858212072342154, 0.05559655582352031, 2.221312508467705, 30.428720135842603, 46.92407923360025, 48.313900501497336, 27.901552723300075, 15.684687552913545, 35.03566157433295, 46.29920251907841, 18.79821204370068, 0.8949171919976512, 0.06120951350538, 0.061561630498017036, 5.167503049296718, 8.27499101238866, 4.382767686920782, 8.328168545999835, 7.398966406622241, 6.536610770610071, 13.863730142193457, 20.710504785660778, 34.712497495835834, 48.790648906461655, 54.42980127949869, 51.63994096940564, 51.13270005872173, 49.93200763579338, 46.05250112472042, 46.40409454222649, 45.34980458597983, 47.04662192252375, 47.598530784729995, 47.98817903764787, 50.93946449218258, 53.18734345897552, 51.4571036061933, 52.77936597024241, 53.654627184714045, 53.89197764858123, 53.14205969533613, 54.460976277628255, 52.88797247794367, 51.047639539164884, 53.68749272438788, 51.93738998905305, 53.42522736518614, 52.572653139791186, 55.19086660877351, 46.74045739635345, 39.17788451717746, 36.28255951789118, 36.36175217167024, 37.35185254004694, 37.52620973894673, 38.978471217616914, 40.474318073641875, 37.4747835436175, 38.62064515390704, 36.103715127514256, 37.631231200310495, 34.608558608639626, 37.842442989349365, 35.14624495660105, 38.71195008677822, 40.13819056172525, 49.59839044078704, 47.65363616328086, 53.52855436263546, 42.6772427558899, 37.30860840889716, 56.74856139767555, 48.38135350135065, 48.16979262136644, 43.77834227777297, 45.66301761134979, 46.442416098810014, 47.13696979707288, 43.20089878574495, 39.2111893623106, 38.09895030913815, 38.66471690516318, 37.58944619086481, 37.652231570213075, 42.11958762138121, 51.63677561667658, 51.260855659361816, 52.33517323770831, 53.430655925504624, 51.771120717448575, 51.966999961483864, 51.38544582551526, 51.806206318639944, 51.58895800190588, 49.16609817935575, 50.09435453722554, 49.71204896127024, 50.1650748714324, 54.859861712301935, 55.863478568292436, 52.13765836531117, 55.202017907173406, 50.93160013998709, 49.55279680990404, 53.91390369784448, 56.1515688127087, 54.93640284384451, 53.18495473554058, 51.08871459960938, 47.74527449761668, 47.93534863379694, 52.52076802715179, 53.14253822449715, 55.89024482234832, 54.02351433230985, 45.36662370927873, 53.902403308499245, 34.306712612029045, 22.6907447461159, 13.397386804703745, 5.614817007895439, 4.101665880410902, 5.366662375388607, 10.828157855618386, 4.547834261771172, 16.859513905740556, 0.7999508491446896, 0.01378418363240217, 0.3842847794294358, 6.976849754010478, 39.300297767885276, 80.77946432175176, 57.98130350728189, 31.276438466964233, 46.446514975640085, 50.35867521839757, 53.14981814353697, 30.029946488718835, 3.1661166106500938, 0.20263569519644786, 0.061223889145279126, 0.021340668073765213, 0.014546112656863707, 0.02797875673540177, 0.05204245560772477, 0.01585890103371874, 0.10511147669486462, 0.02570207365938733, 0.03127524264967971, 0.02352370456191561, 0.028495389194558227, 0.06227370922363574, 0.048151885745145624, 0.03529449804655967, 0.02388812492661659, 0.0840505781853872, 0.07896098112987895, 0.02196237715261598, 0.03816181959043588, 0.01901858279691829, 0.04665036490487476, 0.03546478407036874, 0.05109221163776614, 0.03516870640939282, 0.013348659774619005, 0.00543998364704631, 0.015376167965211697, 0.036575554103981105, 0.05048320238148013, 0.01772761164653686, 0.05599032501660048, 0.043219003465867815, 0.012352538629314833, 0.05671298724689311, 0.09714508158785683, 0.03492550030651112, 0.01781034148147991, 0.032088217070145954, 3.214362744362124, 36.873142949996456, 55.33909297758534, 54.53417162741385, 33.42184159063524, 17.67485110990463, 33.041516811616965, 47.685497576190585, 21.65499975604396, 1.0359456438210703, 0.16550946560117508, 0.15528856566356075, 6.879959856310199, 5.59209373689467, 4.310815238183545, 6.953696983475839, 8.402198380039584, 8.648560489377669, 7.444999833260813, 22.002351130208663, 36.979866720015, 49.6397400671436, 57.71024419415382, 53.802496617840184, 53.100992479631984, 50.75039056039626, 48.715072677981475, 49.49806013414937, 47.996435626860595, 50.84586889513078, 51.09882646991361, 51.45426773255872, 52.24446058273316, 54.3687770443578, 53.43413899021765, 54.85873206969231, 54.66116228411275, 54.695985086502574, 53.98326689197172, 54.220382013628566, 51.64738955036287, 50.22118829911756, 52.7075473723873, 52.12255331777757, 53.96107804390692, 53.34338711154077, 56.2778808993678, 48.109811736691384, 42.66104336707823, 37.600122882473855, 38.2186806586481, 39.75714406659527, 39.75665377032372, 40.119735810064505, 40.625396005568966, 39.49598089341195, 40.66391368066111, 37.495646630564046, 39.664121135588616, 37.46296544228831, 39.72182312319356, 37.7365860631389, 40.477491271111276, 44.15304237796415, 50.04889818929857, 50.09774346505442, 56.13606368341754, 45.01597166061402, 39.339168456292924, 58.092298738418094, 51.2081939174283, 51.07051872438001, 45.341434248032115, 47.864922477353005, 47.20399133620724, 47.69413071293985, 45.77848434448243, 40.405362806012555, 40.72825231859761, 40.39796913823774, 38.83333567650088, 39.33288481927688, 44.090719838296216, 55.22192393579791, 53.15028098321731, 53.40263059062343, 53.868494418359575, 55.04077711412984, 53.477681221500525, 55.114556897071104, 51.967262760285415, 51.801570077096265, 50.62933444976807, 49.06830956858974, 50.782832484091486, 53.10037274514475, 56.90459720550045, 57.891747951507575, 54.17439222335816, 56.981248163407855, 51.44651712909822, 50.719811762532885, 52.74164845866542, 55.21269067641228, 55.617130187249955, 56.29733977779266, 53.92353703898769, 50.41957786006313, 49.16090103887743, 54.93601845156763, 55.74774903635825, 57.63011801627375, 52.887340976345925, 47.68940033451204, 53.94313712273875, 39.72001098817395, 27.198352159992343, 18.963516412242768, 8.760860889188706, 8.364100398555879, 12.553449638428228, 7.621807042629489, 8.316694632653268, 16.91018308362653, 0.639495020431857, 0.028580411547614683, 0.45772172270282624, 7.26013558526193, 40.103654092358006, 79.7681203965218, 67.4123719430739, 40.864829247997655, 53.03448477099019, 56.197437009503766, 62.07751704800514, 36.88167802749142, 4.30015423605519, 0.16568186602765517, 0.013244808895603545, 0.03046329478703199, 0.05528219164379182, 0.037294646364546595, 0.048433001708960345, 0.060522865068407795, 0.0377783389581788, 0.02110523393287534, 0.04173804059504502, 0.028344642243257938, 0.06984212931485907, 0.03657328648372524, 0.07150603398200005, 0.03171694213374248, 0.032971052963647156, 0.060072367064534664, 0.0593782109659045, 0.05174215680228607, 0.16138046619392213, 0.12646679045452228, 0.07630452528716096, 0.15194210974920183, 0.16878315848448586, 0.17896435974586397, 0.09665369747146484, 0.16490417953220107, 0.16698551784840324, 0.10500508240394055, 0.14818846278132933, 0.10149082259064722, 0.22225240305546792, 0.18492896710672688, 0.12968111152370132, 0.1895600298960363, 0.3399136103689671, 0.11937133006511197, 0.1387001880474629, 0.14375200164654564, 4.507227434265999, 44.69367442592498, 62.55688559624457, 62.02667528583158, 39.451230572115996, 25.547559915050385, 46.433265209198005, 56.839105390733295, 24.805769112802324, 1.3733882529120292, 0.28452379869357236, 0.8508067073360567, 10.199788270458098, 14.567798529901813, 14.095354926201606, 18.866188679972005, 16.113782102061858, 11.811544106852624, 17.855197768057547, 23.43008210582118, 38.80795009674565, 50.976252402028734, 59.02640335021481, 56.97729833664433, 55.689133136503166, 53.70747720041583, 49.59890819364979, 50.67706185002481, 49.500405711512414, 52.133457506856615, 51.63521059097783, 52.64938254510203, 54.08754310300274, 58.329468773257354, 54.51687789732411, 56.24487807673793, 57.38452665267452, 57.01006973943403, 55.56847318526238, 56.04855952724334, 53.79554617789484, 51.67823899176813, 54.50961759013515, 52.09372389701105, 53.21023441130116, 55.6509017944336, 59.72559329002135, 50.76331869248421, 44.53500278534428, 39.51916994587068, 39.61421289751607, 40.900338465167636, 40.90917556516586, 42.926634896186094, 43.823194580693404, 42.004972042575965, 44.011829207020426, 40.60475649372224, 42.26753157954062, 40.02965465668709, 42.80389608875398, 39.3170266766702, 42.27212075264224, 45.967789696108916, 53.95690464204358, 52.13599135798793, 56.493725007580174, 46.895889159171816, 41.82360164580807, 59.92077827453614, 53.187492509042066, 52.68838659409554, 49.07699761852142, 50.41110554049092, 51.27707073765417, 51.07282115567116, 49.22054852208784, 42.95962987407562, 43.8571858406067, 42.511185292274725, 40.76359287385018, 41.74405205634333, 46.59483940370622, 58.976361751556404, 56.533156594922474, 54.91177428153254, 56.17018045917634, 56.600652740847686, 55.62650072959162, 55.907350278669796, 52.540458325416814, 52.02674550394858, 51.36518678357525, 50.64540832273422, 50.70391831859466, 54.27302806608139, 56.79119363907845, 58.64412130848054, 56.522389688799464, 58.04222968316848, 53.05534393556657, 50.88309218806606, 54.13662372096893, 57.95103457666213, 57.92734346082134, 56.97681980748331, 57.500264029349054, 52.09009178223149, 51.99003996387605, 56.41926273222893, 57.858145006241344, 59.394427576372706, 56.501032383211204, 50.837424032149784, 57.008700832243896, 45.17931876644012, 34.73279576147757, 21.617137116770593, 12.348594050253592, 11.088352203369142, 14.74369231731661, 21.829253012134185, 9.082375611028365, 22.443496181118874, 1.3095150287112882, 0.11584570916790156, 0.6506724883952449, 9.477475958485758, 49.07693878296883, 85.19244455522107, 63.239566279995834, 44.41697474448912, 60.160344877550685, 63.08519747949416, 69.58427459962907, 43.50206228994554, 6.220648163749326, 0.41807023748274774, 0.17008083481942454, 0.18525199574087897, 0.14649450448491882, 0.1491118132347061, 0.12548655031188843, 0.19602780380556661, 0.15984525663718102, 0.24343609779832825, 0.1258151024399746, 0.14137489210453727, 0.3038692348186047, 0.17628069246007552, 0.18136590749265688, 0.16761747909890068, 0.14125823223542783, 0.15478380565201083, 0.15450366261985995, 0.09566762739972723], [0.12044177706082983, 0.05387412969984355, 0.090737713711156, 0.027369927509777972, 0.019395180129175706, 0.04386452447262503, 0.058654541329991434, 0.04909405131794272, 0.07901470687600874, 0.12074523214851657, 0.038942455524398435, 0.006613655244901537, 0.0577670629436691, 0.018229539047986753, 0.049999923475327036, 0.08357283809492666, 0.04906050049729886, 0.021748466251958764, 0.06659465962119641, 0.018443633809745796, 4.089833560489839, 31.67195458565989, 47.56268816609537, 44.02765597066572, 32.01611118931925, 23.613719632548673, 33.5377162502658, 36.84301130233273, 14.451659110284622, 0.3950549337652422, 0.8350758578988814, 6.2535313540889375, 23.113052614273567, 40.923645188731534, 12.481245667703691, 6.274188026305168, 10.910607057233012, 7.733999086964515, 9.765763302003185, 25.735162958022087, 42.798910756264966, 52.103223877568404, 54.82882791949857, 50.7856918919471, 48.32685216780632, 45.36988319889192, 42.60718137987199, 43.10591859202231, 42.45839018975535, 41.48200634987124, 41.714285189105624, 45.02002739137219, 47.54421772495393, 47.7681968289037, 50.398263700546764, 50.3510775873738, 50.832360252257324, 50.38919518070836, 51.432169099007886, 52.92775707860147, 52.3420609197309, 51.305554989845525, 53.42032048010057, 52.506333704917665, 51.18313781676754, 51.36924643670359, 53.03093894835442, 47.52895970498362, 37.509712250001975, 35.4810937758415, 38.58025258587253, 37.419097654281124, 39.54535568914106, 39.9589107882592, 39.44584123549923, 38.70654506068076, 38.5304973202367, 36.58171084619338, 35.54195719380533, 35.850894835687455, 38.79395507997082, 37.32046965629824, 37.323015274540076, 41.61475112361293, 47.35964275175526, 47.00540173438288, 55.506076120561175, 43.729312650619015, 35.50148617836737, 55.875959550180745, 48.537914906778646, 51.671798459945194, 47.263168134996974, 52.8438340463946, 50.95262012174053, 54.729270319784845, 52.92311299231745, 47.54044048247799, 39.01485904570549, 39.52615568714757, 37.42502827798167, 35.92789880691036, 38.84815831338206, 51.4108863184529, 53.95373536694435, 49.45696546185402, 47.82111352489841, 49.73326898390248, 51.046439293892156, 50.418624724111254, 49.54383811643047, 53.95771657266925, 52.880421915361964, 52.982576124129764, 51.35509844749205, 52.01703371540193, 52.789815164381466, 53.24350395510274, 51.28288761261971, 50.1716919099131, 51.02745894462832, 55.45533241764192, 54.41557876525387, 55.34270940288421, 52.45328364833709, 51.93532682234242, 48.44682178189678, 46.35684959350094, 43.8698511738931, 47.35085664256927, 53.163409156184045, 53.549138961299775, 52.043160623119725, 48.65273837120303, 47.96703354004891, 40.064147979982444, 27.04348521847879, 21.075430339382542, 8.285659859257361, 10.025303594527706, 6.474035238066028, 6.249798238277436, 8.042807780927228, 20.206235070382398, 5.941043476904593, 0.1807176745346477, 0.23606648518433496, 3.4223437261196876, 31.38585690529116, 42.076394481043664, 18.39693396322189, 15.186523987400918, 39.84928054194297, 44.44101102890507, 53.69474518683649, 30.63059472268628, 3.198497247311377, 0.11380246074329461, 0.008620373724449066, 0.029767018540071386, 0.02909804949717176, 0.017298251923714435, 0.044073796710900726, 0.07132328370766294, 0.015190967167126796, 0.051196706030637994, 0.030724040472940094, 0.06458317320193015, 0.029001476453436963, 0.029550698292892308, 0.03480321735203747, 0.14338420283409858, 0.020831623715498758, 0.05462516016597229, 0.013709512084812648, 0.01221865231561805, 0.04372902267101792, 0.03107676459025712, 0.06298106884764088, 0.01979325856682995, 0.06430003476599533, 0.05102520192702932, 0.07038099556079797, 0.02301257261405549, 0.04260255166539743, 0.04614373180834998, 0.058034818334084366, 0.05052052618515107, 0.06259858796012498, 0.040676154631880984, 0.023298287020635702, 0.0807254271762025, 0.07566732399526142, 0.04393087151730734, 0.041573029086594625, 0.06500163340880986, 5.787648895094472, 38.653977455631384, 53.51239811989569, 51.98733352845716, 35.836291851535925, 29.403290979323852, 38.21305990219116, 41.41837766093593, 16.658090391466697, 0.498467487913947, 0.7633678218530071, 7.553875023318876, 27.58241103541467, 37.00368335170131, 9.537147956509745, 6.648978831306581, 16.04335594561792, 7.73533808608209, 9.574045692720722, 27.724738159487327, 43.11941154541508, 53.737883413991625, 55.7028143636642, 52.88233210963588, 50.9295291285361, 47.390209782508116, 45.40521198703397, 45.14187582077519, 43.58413004106091, 44.644836994909475, 45.04996292052731, 48.32018413851338, 49.59875522121307, 50.66316097013412, 51.699823794826386, 53.03154299336096, 53.48810688141854, 53.358825560539, 53.42512930593183, 55.6926554249179, 53.23926387294647, 54.24246103532853, 54.19785584172895, 53.068899646882095, 51.439853022175456, 52.74946966478902, 54.15758878953996, 50.55020063154159, 40.090569065463164, 36.658063703967684, 39.08250816406743, 38.98175424145114, 40.61335432913996, 41.31702753805345, 41.72329095102126, 39.7036390150747, 40.28668365170879, 38.76549043963033, 38.033148627127375, 38.97050096142677, 40.82961028622043, 39.29649306881813, 39.84945312623055, 44.07741123630155, 49.1366058780301, 48.57925668839486, 57.25728888665476, 45.661648704159646, 37.695212902561316, 56.70223036120015, 50.4750087953383, 54.49293574979229, 49.7085698189274, 54.45440630758963, 52.52423932475429, 59.48179837196105, 54.2008525325406, 47.84746008534586, 41.09775527831047, 41.491843654263405, 39.232891836474025, 39.06359449509652, 40.41499222478559, 54.1278297670426, 55.786996272302446, 50.15540230658747, 50.09399367916969, 50.72325952591435, 51.14625184766708, 50.70988816599692, 49.91391766455866, 53.73028578296785, 54.44726367150584, 54.32805499722881, 53.794824461783136, 53.081129597079375, 53.62641749843475, 53.47294692070254, 51.444277455729825, 51.92248498239825, 49.21610839905278, 54.990759049692464, 54.38192090680523, 56.56509645523564, 54.35091849296324, 53.16219322143063, 50.09554693775792, 48.58436753672939, 46.412319752477835, 50.64247046747516, 54.64452358984179, 56.991356111341915, 55.67813873291016, 51.39473792045347, 49.51892322109592, 43.15085718708654, 31.276222736604755, 17.966081211643836, 13.388661492255427, 16.882871620116696, 10.741957887526482, 9.489308768703092, 9.118504562685567, 20.224811415518484, 4.955520514518985, 0.13136275112628937, 0.251687401004376, 4.21850961062216, 37.154773050738925, 58.695688709135986, 28.245322973497455, 21.35739384158965, 44.78822315892866, 49.12998099480906, 61.39482067477319, 36.50301241105603, 4.424759601393054, 0.12695730123068058, 0.05430161825291092, 0.033326119394792665, 0.0960044839209126, 0.02301674779324282, 0.007398335165494392, 0.06270870543836106, 0.02177658167877986, 0.04520519749231396, 0.04876683601328442, 0.020942656668804346, 0.03186575471303396, 0.04759659074367054, 0.01183398424707834, 0.04734669669320987, 0.007986389523026565, 0.08389932178561726, 0.030168724404047095, 0.05586739854827043, 0.16423726935059796, 0.17195526810903705, 0.21604460874392142, 0.09748013780242014, 0.15763742188292165, 0.1286850899698273, 0.13394267478537175, 0.15649975067184818, 0.1945376402187732, 0.37940510578693887, 0.14308634784913835, 0.13715036153312654, 0.29392188955699244, 0.15518626228215235, 0.16497732560721137, 0.2320976287967736, 0.15672778440338953, 0.096799123942131, 0.22605428291905313, 0.10172744416781973, 8.083469031318542, 46.785603877036806, 61.33358855401317, 57.54510456515897, 41.38920307159424, 35.1272528402267, 45.225751784539995, 49.35912586027577, 19.04156373393151, 0.8279804741182636, 1.088616088513405, 8.260785168217074, 29.015649018749116, 50.2681782937819, 22.522290714325447, 16.650755559244466, 20.612457298463394, 12.794644025064285, 12.58738402397402, 31.58082812063156, 47.218951256044456, 55.13654962662728, 59.67664211027084, 55.139726746466856, 54.65683983218286, 50.13725349980016, 46.98521721747614, 49.79491687590077, 46.0935644180544, 45.25772302381454, 46.94464029804353, 49.27999204204929, 51.52237576823081, 52.41136920067572, 54.30845883584792, 54.50033726230745, 54.907071359695934, 54.68485339995354, 55.27378551421627, 59.11350350226126, 54.352722783242505, 55.00726830574774, 57.78540072902557, 55.30456435295844, 51.979124007686494, 53.58272621708532, 56.5486813360645, 52.307069455423665, 40.7537987155299, 37.926162058307284, 41.68283170269382, 42.26144406103319, 43.30504948093046, 45.230278199718846, 43.43943772777435, 42.37001134503273, 41.901511684540786, 40.811414410991055, 39.192942496268984, 41.73950602931362, 42.546678819964015, 41.79722762876942, 40.99220429697345, 48.053992486769154, 50.39325091146654, 52.82122550472137, 59.17948953567013, 46.501549751527854, 41.387900844697036, 57.8032906593815, 52.43977892783381, 57.29135074923116, 51.65207286034861, 59.18267842262023, 55.65577337818762, 60.57143280583044, 57.90324441848263, 50.96918036860805, 43.809572189084946, 44.20741819566296, 40.78546008756084, 40.4754908623234, 43.02043837885703, 55.889452503573516, 58.03802097997358, 51.935958323940156, 51.5438703567751, 50.99075732692596, 52.805151631755216, 50.72458136466242, 50.797027541745095, 56.07775765080606, 56.254593787654755, 56.236978423210886, 54.60518221701346, 54.51494809119932, 55.840340506645944, 53.75197256765058, 51.44711725173458, 52.40082979202271, 50.90577917714273, 55.00705649775844, 54.06267135374008, 57.98968561234013, 55.758237454199026, 56.87186502641248, 52.49321729906144, 51.435075575305575, 47.661771159018244, 52.477166960316325, 58.155358683678415, 59.372501527109456, 57.614965900298095, 53.76972913742066, 49.66674166340982, 48.81271616105111, 34.3715964594195, 23.784395687041744, 10.51532922252532, 15.702389209501206, 13.08460916242292, 16.377399698380504, 15.794939494902088, 23.963736257245465, 7.453620222307022, 0.296388233020421, 0.522283016433639, 5.351639207332365, 39.01467077193722, 52.29254491867558, 29.502552440089566, 27.093695479054606, 50.52963564472814, 58.53902532208351, 67.81938060637444, 43.599129184599846, 5.60466101092677, 0.27381487010467437, 0.12689256680107888, 0.05656481052057878, 0.1496851687589961, 0.10327704085577881, 0.14440660845608483, 0.18484976893711477, 0.11065285112107955, 0.21901133019597302, 0.20403132353338505, 0.1531161854584371, 0.13625040740495728, 0.11394298425124538, 0.127863161896746, 0.4028311552059266, 0.09267745599631341, 0.16787286216933883, 0.12121503556808158, 0.16579440434373197], [0.024333034319082097, 0.06409455083250519, 0.012138165203073334, 0.06208735833605451, 0.03617904997701126, 0.054489616229529345, 0.06033400524287455, 0.05948347527714026, 0.04453503143703265, 0.04001538847543059, 0.05472700772506576, 0.09641396557731975, 0.027104931951109922, 0.01878272347723044, 0.061086552563093366, 0.04521078227328197, 0.04929765833601837, 0.056542452244508656, 0.04603922975459888, 0.051639880233955, 3.017658821998104, 31.378349488781346, 48.95893035396453, 43.11059405726772, 26.923931375626598, 23.468564479581772, 45.68581050442111, 46.151956742809666, 12.905792228637203, 0.545846103660522, 0.08309120627781076, 0.47594591254188173, 2.92090890388335, 9.50571604313389, 9.580784324676761, 6.481344084585867, 7.844915380400996, 4.216397414284368, 9.886345786433067, 30.399551430056174, 40.95930345596806, 52.5888172272713, 55.77286397257159, 52.2950787698069, 50.216630504977324, 47.39458714762042, 43.628797992583245, 44.036685266802394, 42.44099055567096, 40.494785001201016, 38.78240369981335, 41.0589159688642, 40.768664498482984, 41.96357142540717, 44.09414406745665, 41.74376572332075, 42.67228880236226, 45.617220017217825, 46.82319195039811, 49.15504886258034, 48.173687534947554, 48.71564534402663, 50.51022775711552, 51.854035700521166, 53.78881931304932, 54.59337588279478, 51.937613564152876, 44.60852761422434, 36.215016303523896, 39.31738753472605, 38.08084464842273, 43.27946386029644, 45.19470622462612, 44.96310203306137, 44.37943766194005, 40.499366329562285, 39.36331848944388, 36.24565785931003, 37.1651045737728, 36.691721562416326, 37.141742937026486, 36.85637873987998, 37.805823741420625, 41.49022371538224, 49.83079087349677, 47.723724995889974, 53.64762575395646, 43.61909797114711, 31.852350273439964, 53.95766558185701, 50.320016337979226, 53.78093142663279, 52.297208616810465, 54.65640444909373, 48.20036749685965, 49.74017627777592, 50.89087417048793, 49.17978332888696, 40.42496681213379, 40.23564577102661, 36.67909545283164, 42.33665550908735, 37.43987837145406, 44.72496317278954, 53.85071823673864, 53.39773155027821, 52.472491495070926, 52.62712309437414, 52.19659982189056, 52.62861751740979, 56.246054787789625, 53.75813068882112, 49.66735747552688, 50.292559746773016, 49.081351449412686, 51.71823540041524, 53.58336948579358, 51.00792161880001, 52.61610123418993, 52.17513268993747, 51.18019211676813, 51.79349783928164, 52.33869944849322, 53.98036826041437, 50.09866522204492, 47.559471822554066, 43.03344103597826, 42.89196898860317, 42.727366724321925, 44.586362300380586, 48.95734963878509, 51.981850054956254, 52.4832348669729, 57.60119838099326, 56.94658225582492, 50.8968008718183, 34.897982458914484, 21.650265455245975, 17.854709432971095, 20.929908444804532, 17.48282559456364, 5.497534217373018, 5.0046991917394825, 9.467363107588984, 10.013248189803093, 0.09253124045508523, 0.06014306931906651, 2.8522012358711613, 21.691893569884762, 26.443558700623054, 26.150620406673802, 31.52923130219983, 43.69758067592498, 49.73801897418115, 54.64366851314422, 31.352297106096824, 1.9220269615611725, 0.17778145870374096, 0.03471288792488556, 0.06118648490237613, 0.052784442405907385, 0.0610485086367736, 0.07997931116410802, 0.03501661880422504, 0.01666703760894316, 0.048948084755289945, 0.041260396265575004, 0.0631433492526412, 0.08615257023202796, 0.057283263097727494, 0.059995222010559617, 0.04469952583613415, 0.11205231755851738, 0.019467585014119264, 0.05111080842212804, 0.0461483359967749, 0.04233800235294527, 0.05489201923351615, 0.05921259424799393, 0.039822636923242005, 0.04133698973624457, 0.022484031318116094, 0.04072987654757115, 0.008337573324810834, 0.06485807619267894, 0.02982269589518828, 0.039790495704378814, 0.0409680073179545, 0.014088536000570223, 0.07230111833421454, 0.04494661600479195, 0.027326015349958214, 0.027514164628941688, 0.0918628057585128, 0.07174312287280638, 0.06614348745994991, 4.810274166445579, 38.09969948184106, 55.865082817692915, 48.81413998142366, 31.94335122262278, 26.78134733630765, 41.48623074254682, 49.95567129504297, 14.768019837717857, 0.5452855111610505, 0.21987527819170108, 0.7602907837398591, 4.515554626141825, 15.158162309277444, 10.56464812447948, 7.990500032901765, 9.599343999739617, 6.825304569736605, 10.419984248376663, 30.902187478157785, 42.324488316812825, 55.44500089460804, 58.572769472675944, 54.506169826753684, 52.95183650908932, 50.39421189215876, 44.851789089941214, 46.32148158165717, 44.039862386641964, 42.00876105216242, 41.826053127165764, 43.799052392282796, 42.5295929754934, 43.616924978071644, 47.348205120332786, 44.84729013135357, 46.50881398108698, 47.68306178431357, 49.79868627363636, 52.80426517609627, 51.74256586259412, 52.383230117059526, 53.087978055400235, 54.132650359984375, 54.688497281843624, 55.53807481642693, 54.82967122908562, 47.76521582757273, 39.61327937341506, 41.041826202023415, 39.825036371907885, 43.99877555908696, 47.215177935938684, 47.12237465766169, 45.42410212178385, 42.457484122245546, 41.61832440283991, 37.37763820155975, 39.737873461938676, 38.62367714605024, 39.05508687419277, 38.196280002593994, 39.6257407434525, 44.17936932656073, 51.17566962395945, 50.149455993406235, 56.100974159856, 44.041215604351414, 34.37865672572967, 55.71233003370224, 52.75380388382943, 56.06795957011562, 55.23453043353174, 55.77932019387522, 50.78965348582114, 51.156583370700965, 53.730164189492505, 52.05416679382325, 42.738368972655266, 41.00479118285641, 40.04420272765621, 42.218031267966, 38.38582069643083, 47.494988056921194, 55.4477700879497, 55.20649725391019, 53.642714946500725, 52.914817179403, 53.42984791724913, 53.06163541732296, 57.89707845257175, 54.937022578331735, 52.31000338831256, 53.07079415167532, 52.45628426151892, 55.050461446085286, 54.35078905474756, 53.17057924885904, 52.88624663506785, 52.701338260404526, 51.33026984430129, 50.1318641631834, 54.710070317791356, 56.7808856502656, 53.52838962308822, 49.815744661515765, 46.42494978443269, 44.34821559536842, 45.019980322930124, 46.82899313588297, 51.0988147028031, 54.860057830810554, 56.48652745831398, 59.784134664843165, 58.71068785267492, 50.836961192469445, 38.37520676274454, 20.58656769414102, 11.190125942230226, 13.674417926419167, 10.26727362986534, 10.38936524621902, 8.933079415752042, 14.035366196786205, 8.526232550221106, 0.08732367352011704, 0.10944911248741612, 3.552637753948089, 29.897313502527055, 33.17636005340084, 26.43560805628377, 34.79592238703082, 47.50152272562827, 55.37580244002804, 60.349646306807, 39.03470623877741, 2.9092729476190384, 0.36547122282847283, 0.07188715506345034, 0.07496532698672626, 0.005593859588712334, 0.010450310712199538, 0.037617039145721544, 0.03448006231337786, 0.019394551937077797, 0.04652925023448564, 0.039597418564822406, 0.07517172639528591, 0.053752708594284715, 0.04944680416355691, 0.013132108743452739, 0.0547442868381979, 0.0433500083313594, 0.03890848718583584, 0.06918941474249286, 0.055381411521305005, 0.11379239434796957, 0.30510211543690774, 0.14593489257799042, 0.14984235467929996, 0.13051962540034326, 0.14993561822320187, 0.2038404603879298, 0.19427217543125155, 0.17358033977929624, 0.06395741726361936, 0.16055854578172007, 0.2399578747609931, 0.11386920998413717, 0.1788264332759765, 0.07915942088490532, 0.16424056352867236, 0.1741931181881697, 0.13580624494821797, 0.15141249784538824, 0.27659080502006317, 6.928554590671294, 46.31088725982174, 62.46585522928546, 57.831869048456994, 37.32177188319545, 33.38010364963163, 57.43191672909645, 57.362557457339385, 16.37554833965917, 0.7712917450454928, 0.30507309602633603, 1.0782910619051227, 4.120802879333496, 12.116267161984599, 12.954205063081558, 13.127462037148016, 14.828460620295617, 8.88554911459646, 12.248985459727626, 33.4541932998165, 42.81043467983123, 56.72310913762739, 60.51463296336513, 58.51225514565745, 55.04972011812272, 53.61177529058149, 48.163289331620746, 49.054557738765595, 47.07744782970798, 44.50271775645595, 43.99364509890157, 46.057647274386504, 44.3005705648853, 46.5649744772142, 49.20420008320963, 46.2299060052441, 48.80864081844207, 50.5196532126396, 51.57054639631703, 54.83988508101433, 55.1985191529797, 53.440171595542665, 54.78843535146406, 57.61751936328027, 56.57203512807047, 58.73966632350799, 56.888593935197406, 50.34935566686815, 41.23555598720428, 42.898605638934725, 41.959990301439845, 47.00153427739298, 50.62115630795879, 50.974201002428615, 47.6467171022969, 44.10760171951787, 44.29584018645748, 41.133813627304576, 42.0846353807757, 41.37085422392815, 40.83540362696494, 40.58368552115656, 41.25498740903793, 45.92652636189615, 53.83955517122823, 53.680565818663574, 56.55406675031109, 47.76988737044796, 38.45181457458004, 56.62820346893803, 54.949554551032286, 57.721905400676114, 57.43620387969479, 55.554803725211855, 51.375192749884825, 54.012010020594445, 55.835704265102265, 53.79659737310102, 44.55028433953562, 43.40013557864774, 41.62777731495519, 45.83045182689544, 41.52579961284515, 48.03246259689332, 57.70935773849488, 55.93228870822538, 55.73332648123465, 56.9258289952432, 54.84355641949562, 55.55354856675672, 60.905061767947295, 58.29501467366373, 54.81594685585269, 55.93545798332461, 54.88634947807559, 57.9135210283341, 57.01469029149702, 55.85550046736195, 56.141131385680175, 54.27214945516279, 50.62105040396414, 51.0769514114626, 55.23065905417166, 59.81544694592876, 56.43379119134719, 52.47637856391169, 48.214974403381355, 46.59955801502351, 45.6444412662137, 50.989925784449426, 55.052355950878514, 57.91592151887956, 59.70379667897379, 63.05506190946026, 60.1919944824711, 52.77809119993641, 38.840866627231726, 25.05052305036976, 23.951349412241292, 29.90721944839724, 26.894933292942664, 11.98740847649113, 10.360378930645606, 13.74076383729135, 12.273796412252612, 0.14774132790344377, 0.19002562749289698, 4.148351155942486, 30.978452082603212, 40.48358271198888, 38.99377238365912, 42.311262084591775, 55.92449103632281, 64.3115225914986, 68.41749498921057, 47.98872816947199, 5.105261898809864, 0.5449384426878345, 0.1989364098276823, 0.11955041843917101, 0.2151082041523149, 0.23450869135558608, 0.14909043938161867, 0.12151394775437734, 0.1489087692912548, 0.14162927926067384, 0.16747371503903022, 0.14711213989123223, 0.14344040304422379, 0.13900545876353018, 0.14909414724717218, 0.11485200886043812, 0.11932272178631638, 0.08933438619057979, 0.20343593532039275, 0.14350627128395343], [0.05280210456300167, 0.06721875314871151, 0.025559430003106117, 0.012385542654702741, 0.04841504843845483, 0.07773156322899365, 0.030558598040032293, 0.10133581236004831, 0.02687378790259602, 0.024454759944590832, 0.047386142560431076, 0.07949944901009721, 0.07672020459487554, 0.035145229644953244, 0.034816746464780265, 0.046484640934654785, 0.01587499271056825, 0.012869951540544149, 0.02863044474994944, 0.07150209629006925, 4.539201125021904, 39.36693099237258, 45.70809348937004, 50.69960371140511, 25.54076833109702, 30.550639167908702, 62.76111948874689, 41.10223070267708, 10.589457115819378, 0.2797288237319839, 1.8067304838088252, 8.270718570678465, 19.188427079108454, 12.217311339993632, 1.4500772087804734, 2.424175287446668, 15.015398821523114, 6.686122696245871, 13.944717280326353, 35.15919662291004, 47.53036783587548, 51.63652066261538, 51.33758506467266, 51.147899243139456, 48.739516888895345, 48.06879551179948, 48.93655323213147, 47.14433208588631, 45.68146059590001, 42.269296646118164, 37.46952364521642, 37.524903589679354, 39.13312242877099, 36.63831457015007, 38.36482817126859, 36.71557349543418, 38.28094828513361, 37.79374284128989, 37.220453139274355, 38.78668300567135, 39.287730493853175, 38.43813726978917, 41.07460152718329, 41.90875630224905, 44.5980627306046, 45.186528082816835, 44.13238717663673, 37.12408442651072, 32.89500451857044, 36.65051314138597, 42.498437589214696, 48.6698712841157, 51.51349159979051, 47.58267264212332, 45.03596398138231, 43.29812649757632, 40.48504183369298, 38.96753172720633, 37.3518721518978, 37.71030618298439, 37.43372417265369, 36.98520506581953, 42.34895606194773, 45.70623036353819, 48.130882709257065, 49.21552004352693, 56.20991799139208, 45.92381600410708, 31.114726989499985, 52.3210213261266, 46.30799647300474, 53.51660682309059, 49.96316302207209, 52.05480614016133, 53.211007118225105, 48.700026466000466, 50.41219595939883, 49.05433808603595, 39.6620265899166, 38.15855464627666, 35.93803421143563, 39.541515688742365, 38.261850264764604, 36.73515004496421, 44.74415533004269, 49.223313793059326, 51.36147229902206, 51.600615286058, 51.51175791217435, 50.671535230452015, 49.81130061611053, 48.51501218734249, 47.547422301384714, 46.38386295687768, 45.65428641534621, 48.508552043668686, 51.53533135690997, 51.9918324870448, 53.79909592290079, 51.990243927125015, 50.817918085282855, 50.260431612691576, 50.814407563978634, 52.599129138454316, 50.36672784436134, 47.32884037879206, 43.56770707714943, 40.864182056919226, 41.190280068305235, 44.642734604497115, 45.64693589364329, 49.66382734237179, 53.468855888612815, 55.65444761706937, 58.476675325824374, 47.56293527541622, 34.01652782194076, 17.746924661820938, 14.576819000705598, 16.276654601097107, 7.515054345130921, 9.03991791509813, 7.783570981794789, 2.2135295454532873, 9.154396210947345, 0.3095120239642359, 0.049584202032776616, 1.5087662853540913, 19.17488313490345, 47.12090769121724, 31.078637261544507, 19.984046528416297, 33.70090253891484, 47.63985295449534, 52.295623979260846, 28.81765953956112, 1.7067121281739206, 0.044719942079316226, 0.04288634893694713, 0.06355163198144687, 0.03624545447828789, 0.019488665838575652, 0.03802117350841722, 0.01924405779479252, 0.02156028824467813, 0.0034247208931182903, 0.02580382928792988, 0.01537823736021716, 0.025496679741228302, 0.025980339776123726, 0.01841355719783854, 0.026521979260348508, 0.07716459687799215, 0.06371418434766031, 0.08565901042593103, 0.037617747777051506, 0.017077308335912325, 0.01812686028349544, 0.033494440403075955, 0.02214027617517258, 0.03957134859275915, 0.027027627933890592, 0.06612502474097476, 0.055253965134221705, 0.04826912401063789, 0.03450089607447867, 0.024760363908905177, 0.0676532092714502, 0.0504099796976774, 0.06300424683778998, 0.041504448895613034, 0.029560910244922967, 0.055071617056044846, 0.014070870013036316, 0.05196653629442857, 0.05707294131899553, 7.262543920547732, 44.78585012497441, 51.25326195070821, 54.88379993746358, 31.741533510146606, 33.07486480282199, 60.41556173755277, 46.44000384115404, 11.743263486892948, 0.2868381809563406, 1.6257100360047434, 9.278299962320636, 9.673618001322593, 10.62692359570534, 2.7396914795521767, 5.702549151835903, 10.54170225897143, 5.318883494023354, 16.80592844563146, 34.527887221305605, 48.52189594699491, 51.74826506645449, 55.53150876875847, 52.43981422916536, 52.093916093149495, 50.50645051463958, 51.556900470487534, 48.61785281089045, 48.163218728957645, 44.47107991864605, 39.236547485474624, 39.40511918837024, 40.92981507701259, 38.632455410495886, 40.8334267523981, 38.93371305158062, 40.59957112035444, 39.76266676379789, 40.65563747959752, 42.42838405793713, 42.2175488164348, 40.82271083708733, 43.39500119609218, 44.39430344489313, 46.90007825051585, 48.46462149773875, 48.38804114249445, 38.70024573418402, 36.058988340439335, 36.395578692036295, 44.673168274664114, 50.90742657261511, 52.412608669650176, 50.2843306141515, 47.153792842741936, 45.087798103209465, 43.08802081692604, 40.56217524313158, 40.3621853551557, 39.23609249053463, 40.021751080789876, 38.61261998453448, 42.01100857027116, 46.815076566511586, 51.165675424760394, 50.704267409539995, 55.84453352036015, 46.749039542290475, 33.85645589520855, 50.79838468182472, 47.87479508307673, 54.05511294641803, 50.65708914110738, 51.70870011852634, 53.70024434981808, 49.981598161881976, 52.259020420812796, 50.792316775168146, 41.79069296006234, 40.22924446290539, 37.565943348792295, 40.97695412174348, 40.11281282671037, 39.084653700551684, 46.37025233237974, 52.821696189142045, 53.95555142433413, 55.72758805367255, 53.56757410110966, 55.001365138638405, 52.03748495348039, 51.107267410524436, 47.903855923683416, 47.8205055575217, 48.51385116577149, 51.40324554135723, 53.75869158775576, 54.489378160045995, 54.308619653024984, 54.52579344472578, 51.67020597765523, 50.0946722492095, 50.643631489046165, 55.728752997613725, 51.47653502802695, 48.94201709378151, 45.37063237159483, 41.352693650030325, 43.07105656593077, 47.09085056858678, 47.02422518883982, 51.30568050569104, 55.44631488861577, 58.511313776816095, 60.092009344408595, 49.35784324522942, 35.90514121517059, 24.823923803144886, 14.62522202922452, 17.339490421356693, 11.02748780481277, 14.068536700740939, 7.411304221999261, 5.872990844711181, 11.549940647617465, 0.07654788843806713, 0.0624021859989772, 2.0023544060607112, 20.625571743134532, 45.51053154853083, 36.67805602473598, 26.81133189508992, 41.217360111974905, 53.880669455374445, 58.801839813109375, 34.39961787193052, 3.1614798788101446, 0.06271494139406471, 0.02444226505054582, 0.007812446386988967, 0.025796095630334272, 0.0412993939713605, 0.021222816937933528, 0.015421679333573388, 0.0696560005927759, 0.03602050808108142, 0.06208980598697259, 0.05598255305460865, 0.06234715024249689, 0.05376684674692731, 0.030151148431844292, 0.020775961682140347, 0.012140721063910714, 0.06760171284118006, 0.01814830308449605, 0.08019228360705799, 0.11118798651882719, 0.16794015533260762, 0.12171703000222484, 0.12624290125865129, 0.10798809088526234, 0.15052092471911063, 0.11321424311327358, 0.19054970824189726, 0.11126137008109402, 0.09012400833589417, 0.1783806467128377, 0.1842147433349202, 0.12816084068148367, 0.1664766362838207, 0.19039885020784794, 0.1170393584236022, 0.17442591698660007, 0.11213294065166866, 0.1117211837141264, 0.26015818840073, 9.368374251550245, 51.95385217666627, 57.27383344404159, 60.803229193533625, 35.54085500778691, 40.8370392553268, 71.33476564961096, 48.093996740156605, 13.020712771723348, 0.5106243533232521, 2.2834347621087105, 12.675693246626086, 24.137642383575443, 19.50571740827253, 5.148162332273299, 7.716132690829616, 24.35642630823197, 11.389839303108955, 17.662789821624756, 37.87393962183307, 51.08106990014353, 54.86808300018311, 57.1590688151698, 54.52188284166398, 54.03799572298604, 52.798679720970895, 54.78068082563339, 52.91042412481001, 50.75382263429704, 45.65582398445376, 40.017687505291356, 41.6634669611531, 42.75938110966837, 40.4237469550102, 43.65769017127253, 40.06128857212682, 41.85974628694596, 42.48060257204118, 41.24445192275509, 43.9357626822687, 43.424481730307306, 41.92397117614746, 45.20304518361246, 46.385255398288855, 49.40721804095853, 50.439711386157626, 49.893944955641224, 40.778184090891195, 35.85329532623291, 39.59533452987671, 47.05161509975311, 54.38373304182484, 55.05092036339545, 51.198015366831136, 51.12577315299742, 47.77172303968861, 44.59665459971274, 43.649009966081195, 41.13648083902175, 42.833749248135476, 41.82335061411704, 41.29126541076168, 44.79045498755671, 49.91173682674285, 54.50187875378517, 53.327050439773075, 58.343514780844416, 48.385526903214, 36.87764583095428, 51.701694765398585, 48.94090706302274, 55.09048923369377, 53.055869533169655, 54.26432432666902, 57.560876415621856, 50.65264901807232, 54.82775711244153, 53.96977001620878, 44.581263219156575, 42.834553334020804, 40.37128917632565, 43.72792805394819, 40.63127563845727, 39.99363160902455, 47.77782624767673, 53.86001425404703, 56.11867581644366, 58.60844735176333, 56.910257185659106, 55.71722122930712, 54.752267176105136, 54.03185721366636, 52.45839057430145, 51.14738149027671, 50.62884023112636, 53.13538382130285, 55.835292416234175, 56.66331260435043, 57.35933719142791, 56.053136933234434, 53.42421147131151, 50.60976182260821, 51.479770983419115, 56.99638851227299, 53.59359118246264, 51.23489349119125, 47.73387216752576, 44.28002911229288, 46.17528700059461, 49.60451326062603, 49.33632512246409, 54.97983132639239, 59.344331064531886, 62.570335403565444, 61.63848223224763, 51.46745866344821, 37.85044070213072, 23.695281397911813, 21.317673960039695, 20.927074532355032, 13.563313849510687, 18.57178734194848, 16.69191102827749, 4.646592678562288, 12.687887895491816, 0.6887534320835145, 0.1933095093456007, 2.7581572628790334, 27.101679463540357, 59.98116708570912, 42.03226781660511, 28.71474046860972, 46.176667674895256, 60.538288777874364, 67.32455007491573, 45.08554274036039, 5.13050627323889, 0.27597845562042733, 0.11255720780501444, 0.14564898856464895, 0.09115664889254878, 0.18366516717979986, 0.1248668694508172, 0.07495641738416688, 0.14811286522496134, 0.08299035846345848, 0.098075196597605, 0.12609827151942637, 0.21816336279434545, 0.16105863265693188, 0.12114938949384998, 0.13153443143012064, 0.18113093300452157, 0.10908666862955979, 0.1323753661446033, 0.1250113919377327], [0.03668879339050862, 0.022210118496009422, 0.05329059669747949, 0.01722096322825359, 0.028966466235297344, 0.04310228997060368, 0.04753596637578261, 0.04476588820257495, 0.07281476496568612, 0.01402461362416826, 0.03074586248746322, 0.04282013978809119, 0.0805331927333628, 0.03382083599365527, 0.04964575719749255, 0.04255968138515469, 0.024218283924123934, 0.032045256774572116, 0.04747368725797823, 0.0350913506812386, 5.694598507496619, 43.41613492658062, 48.46797120186591, 32.67737180955949, 19.91200827783154, 46.44219252371019, 53.02890716060516, 37.035823252893266, 7.747756800343914, 0.49536795745934215, 1.4756139223614049, 5.679557688774602, 34.94275631443147, 55.86903656682661, 13.430310199337622, 4.1532090114009, 6.671096586411999, 6.716044497105384, 19.489531747756466, 26.60215581617048, 43.58968803959508, 49.208361717962454, 55.652557034646314, 53.69211327645087, 56.04328393936158, 51.70879817778065, 51.285056683325, 50.860193391000074, 50.9688469671434, 46.68710923963978, 41.20000754633258, 34.64340494525048, 37.88185104247063, 34.9717975431873, 38.400262863405295, 34.66715097427368, 36.91285302562099, 34.77280393723519, 35.501376352002545, 36.61532555857013, 36.01832512886294, 35.10867649509061, 35.29399279625186, 34.81560091818533, 39.908665226351836, 37.946825104375044, 38.213781618302875, 33.83079574954125, 34.75075237212643, 40.147796446277255, 48.29232354317942, 52.27609842054306, 52.276404365416504, 46.73773134908369, 46.825325719771854, 43.737353509472264, 44.1703910212363, 37.46859404348558, 37.850111223036244, 35.692191816145375, 36.780527945487734, 39.87214796004757, 48.61779005296769, 46.274648481799716, 51.210084499851355, 49.19505311596779, 52.54637718200684, 40.05328301460513, 31.39351533305261, 49.59777070629982, 47.300869957093276, 49.088968692287324, 49.8742115113043, 50.738066473314845, 51.87588722475114, 51.83438070358769, 46.726274105810354, 44.34014335755379, 39.58877240457843, 38.463860173379224, 37.27005935484363, 37.48280479061989, 37.20051573168847, 36.40043850867979, 37.3266238550986, 37.23169465218821, 37.18178249174549, 41.75278717471708, 42.63683057600453, 42.0982656171245, 43.06536520681074, 41.33839268838206, 40.79431287703976, 41.72110619083528, 43.79989962424002, 45.79966122104276, 47.77188777923585, 46.551089286804206, 48.1162130448126, 49.3880807968878, 51.785276551400464, 53.48476502203173, 49.92531607227941, 52.87073366103634, 54.046346449082904, 49.29245733445691, 42.96271285703106, 39.02955224437099, 47.00673534024147, 52.721911091958326, 54.453186450466035, 50.21477130151565, 53.72783822398032, 53.807964401860396, 58.45019932716124, 47.64939215875442, 42.53928907455937, 25.425819350827126, 10.8540415763855, 11.806439142073355, 10.777072906494142, 12.746847983329529, 12.104005832825939, 2.6064993104627057, 3.7467828200709437, 1.0517694656887362, 0.07003616406432084, 1.668979172264376, 17.078288024471654, 41.93594617228354, 27.18154480380397, 30.003035106966575, 39.72273703544371, 51.93260077507266, 51.87067439479213, 31.497152197745542, 1.3801482127558802, 0.061375137884169824, 0.009121214238656385, 0.04777985812735654, 0.06647919484924886, 0.09450236936250041, 0.022187857896149642, 0.05582340594921863, 0.05798620239440953, 0.08530133163496371, 0.013129719506738888, 0.10821386465742704, 0.0838822533466643, 0.15481734498133584, 0.0389102338663032, 0.06380414222216894, 0.05865061129893988, 0.07829386410453627, 0.006298006431485016, 0.06253872968016133, 0.051609133295114004, 0.003212469291024571, 0.06984802819187604, 0.03285565713961278, 0.034640316415818474, 0.08553180152610426, 0.06058157421648503, 0.07338956073527375, 0.09413884532067085, 0.007388413369265055, 0.061792510246197065, 0.022988603638124563, 0.047659314192471006, 0.02672571842859109, 0.08578530768112791, 0.09479654712542411, 0.03448087819701722, 0.04810911888677267, 0.07192115404552991, 0.052577269248544216, 7.6278690657308035, 50.06220679129324, 53.22240160357568, 41.043536355418546, 23.609848253188595, 43.51591610139416, 59.87084650224256, 44.30165313905285, 9.87947085211354, 0.5106886740653745, 1.977072891689116, 7.99342857253167, 47.09194883223503, 60.86237461336198, 18.327141269560784, 6.627017971008055, 7.685339633495578, 6.0421298203929785, 17.997877905445716, 27.682715846646218, 46.905232244922274, 51.58148980909779, 56.993446734643754, 55.02558577445246, 57.109093896804325, 54.03504610061646, 54.143954630820986, 51.66026276926841, 52.44770996032223, 48.22728672335225, 43.328054181991085, 36.86694952749437, 39.93207000917004, 37.557725983281294, 39.386268277322095, 36.34280320136778, 37.13158792065036, 37.66443406381915, 37.03166554051061, 37.26747843527025, 37.99349346468526, 36.46800525726811, 36.86289771910637, 38.509218462051884, 41.69796028444844, 39.84345582223708, 39.43013606532928, 36.91481813307732, 36.23347497755481, 40.754814609404534, 52.36116678484025, 53.84794119865664, 51.90047656336139, 49.23969361089891, 50.41042304808094, 45.80497995499642, 45.302802824204974, 39.62258715783396, 39.867841197598366, 37.92016475431381, 39.87610563155144, 41.35414884936425, 49.12814924793859, 48.28531426768149, 53.02274903943462, 52.65101425109371, 54.19324313440631, 41.84768107629592, 33.00758830962643, 49.362059793164654, 47.138087672571984, 50.82185614493586, 50.19702649885609, 52.80109982336722, 55.54529589991416, 54.205833942659446, 48.6336285837235, 45.16058160412697, 41.369595143102835, 41.22410658867129, 38.39031181027813, 38.7711896434907, 39.11052957657845, 38.69622922712757, 38.90405993307791, 41.55119695971089, 42.54822031144173, 44.14795506385065, 44.5661424821423, 44.148108036287375, 45.18220170851677, 43.95642965070663, 43.12069023809126, 43.66993188858033, 46.23455009152813, 49.31856855269402, 50.262839947977376, 48.217398428147845, 49.870834350585945, 51.825406320633434, 55.77352293076054, 53.27866015895721, 49.83883957709036, 55.440882405927105, 56.553176372281975, 51.33146616720384, 45.98080412034066, 41.869783632216915, 48.70115610861009, 54.64997960675148, 55.60472765276509, 52.9765631306556, 56.66245360528269, 59.365727593821866, 59.49381259179885, 51.10922075087025, 41.95345563273276, 27.305299505110714, 13.446684133621956, 14.381823270551621, 8.027593397325086, 9.851623985075182, 9.772574497807412, 6.717548235770195, 7.165085279172467, 1.1810358325319907, 0.028449711202073003, 1.63305381613393, 20.685538899513986, 45.8512992243613, 31.40982847059927, 28.520971459727136, 43.6246677367918, 56.757025872507405, 60.34821071932393, 36.899995496196134, 2.5360881080550532, 0.21810009925355836, 0.11960912375680863, 0.0290972336135324, 0.03775211193809106, 0.03711821248514518, 0.030838926848504814, 0.03940809142565535, 0.04539797968801953, 0.05119780919724896, 0.0014706211626499652, 0.049264877433738405, 0.06482558640381021, 0.06728036193958215, 0.029614310403684938, 0.019831168427762967, 0.056697504609943404, 0.03043149639251492, 0.04253589052466616, 0.012278957799407504, 0.13232391567960863, 0.18812082647796602, 0.113403313612986, 0.2210845633019363, 0.17789909916539348, 0.14988999002643172, 0.10322742134092316, 0.17297669313848021, 0.1939557657967652, 0.12489818712516178, 0.1454943460562537, 0.09681315101202458, 0.12357945869406387, 0.1599143884114681, 0.24390843696892264, 0.1222754697946291, 0.109014579755885, 0.18972870713520437, 0.15721215115439507, 0.2392009645700455, 10.955290698236036, 57.80648346870177, 60.53260526349468, 47.27295052620673, 29.576528341539447, 56.10288827650009, 60.392255013988866, 48.28225089657692, 11.41150647594083, 0.976969498780466, 2.080987999516149, 7.479538754109414, 42.17159040512578, 67.4746827156313, 23.803115198689124, 14.312093334813273, 12.042360882605276, 10.26768155636326, 22.473957307877082, 29.881341611185384, 49.14487815672352, 53.03396701812745, 56.77054236012121, 58.10043373415547, 59.62502371880316, 55.313244558149776, 56.08370004161712, 54.96378883238762, 55.593027222541075, 51.55931272814351, 46.39082516393354, 37.36002283711588, 42.14289434494511, 39.1441011428833, 42.69662318691131, 37.74917294902187, 40.58255195617676, 39.654495639185754, 39.87659200545281, 40.565673997325284, 40.99519706541493, 38.85014695505942, 38.51234066870905, 38.54731644353559, 44.103502842687796, 41.57514302961288, 42.51969683554865, 39.507838218442856, 38.51055599028064, 44.245598546920284, 54.6772793031508, 54.67345499223279, 54.4786387105142, 52.50493341876615, 53.33550706986458, 49.13163231265161, 48.53492606070734, 42.001049672403646, 42.522987704123224, 40.31838424744145, 41.71916069522981, 45.141852286554155, 53.963553059485655, 51.31823601261262, 56.15793481949837, 53.41760619994133, 53.60560932467061, 42.69315188930881, 37.49663899021764, 49.22383939066241, 47.261238328872196, 51.51781012935024, 52.25901649844263, 53.4543352742349, 57.856858468824825, 56.35173128497217, 51.033283664334206, 46.93953729444935, 43.31816588678668, 43.317797183990486, 40.98744253958426, 41.941861106503396, 40.56496404832409, 41.60298793546615, 40.72033697558988, 41.687722898298695, 43.03857149616365, 43.969577435524236, 46.50715481850409, 45.99477560289445, 46.89230411283432, 46.10767318356422, 45.57276387368479, 45.97406548838462, 48.43271693875713, 50.3370080455657, 53.74778739867672, 51.11628493955059, 53.51652445331697, 55.71817044288882, 58.08327336465159, 54.30443448405112, 49.615519431329545, 56.44131821970786, 58.67351555055188, 54.237287429071245, 48.72748697957685, 43.5711822971221, 51.71368937338553, 58.69934043576641, 59.18576140557567, 55.91902717467278, 60.746762752532966, 60.90847815236738, 61.91576634683917, 52.352102187372026, 45.90316080277967, 28.790681477515932, 13.860671674051593, 20.088891483122303, 24.189201939490534, 23.34374289358816, 18.53414631658985, 8.636658057089775, 6.107764801671428, 1.8232075028842496, 0.2682235314240379, 2.4464913673939246, 23.186267575910016, 55.04132232358379, 38.262575903246486, 41.14884414980489, 51.797110342210345, 64.95359889922604, 65.65936665381155, 44.394440727849165, 4.115314993166154, 0.32148294451255954, 0.23983176136689804, 0.10201976799796666, 0.2772304577933204, 0.14287510676489723, 0.15069764588148366, 0.16281626818160858, 0.10946136989420462, 0.1898949788582902, 0.18093406372973997, 0.11299727169135887, 0.2286474139339501, 0.2975534527532516, 0.15444576169454283, 0.13412601494741055, 0.19151019863784316, 0.2253209375926564, 0.09756653719852049, 0.17203722419517656], [0.025586938305247216, 0.05711160960697359, 0.06278788062533544, 0.060228227652729525, 0.07761088139828175, 0.021741510173606298, 0.01532324278096278, 0.004250439186204946, 0.06525903129048886, 0.08316724050429561, 0.0415380724946097, 0.034699240068514506, 0.07579847824789825, 0.09974197409446202, 0.028367668931041996, 0.07145792366035524, 0.11830904956666694, 0.04292227463015626, 0.06527210841135633, 0.039569605742731405, 7.942974634708897, 41.09227572717975, 43.502627111250355, 31.4919864362286, 32.83621603442777, 35.507185382227746, 33.27766703021142, 31.527344642146943, 9.840204984911027, 0.1119404457389347, 0.015853905182842527, 1.582207273571722, 4.218567465582202, 29.632312290130127, 11.879273633803091, 6.395178437232972, 9.172095906349922, 4.146653259954145, 17.862344326511508, 32.747544973127305, 47.196934992267245, 54.432845038752404, 54.2920829403785, 53.5885940828631, 54.714737938296416, 53.887851315159956, 52.59125301914831, 52.436982277900945, 52.31768731148013, 49.04419091440017, 41.401527158675655, 36.03558355762113, 36.09990650607694, 37.6898588672761, 41.68810336820541, 41.16515728735155, 39.879824038474794, 37.94129456243208, 36.08102421606741, 35.67305457207465, 34.722479927924375, 35.26325710358159, 36.60769654858497, 36.311416395248905, 36.27628764798565, 35.83990435446463, 34.42363846686579, 34.22638639327019, 36.10759435161468, 45.47942323069419, 52.83426738554432, 52.92172447327645, 47.58684212161649, 49.46767745479461, 43.5352926100454, 42.12253724375079, 39.03285880242625, 37.11582391492782, 37.22573657189646, 36.889310959846746, 41.72982169735817, 47.18958054819415, 49.19194659879131, 49.322353639910304, 51.765660778168716, 49.35850220341837, 49.27809361488589, 45.319829833122995, 31.23062518335158, 48.94508830962643, 46.060447846689534, 48.38366769975232, 50.10744348649056, 49.767774074308335, 46.50909639173939, 45.332397107155096, 44.463882369379846, 42.44036297644339, 39.03294509457004, 37.6304937947181, 35.89200911983367, 38.279194985666585, 38.12612056732178, 38.234087728684955, 36.48069804714572, 34.99945025290213, 34.15118278995637, 34.55140575285881, 34.61468535084879, 36.49763876391996, 37.362454706622714, 36.52849605006557, 38.51688277336859, 38.29394309751449, 41.647287184192294, 41.01002754703645, 42.054715541101274, 43.234525265232215, 43.461320630965695, 47.69952397192679, 48.74847558236892, 53.170041884145434, 52.0034780040864, 51.30010681767618, 53.37020827877907, 51.580964211494695, 42.3558045202686, 40.42007561652891, 53.504165064904, 52.95205616181897, 54.44441603076074, 54.900352339590754, 53.91973233992054, 55.79377412796021, 54.34698435568041, 50.897879523615686, 41.15516701052266, 34.44812974622173, 19.119105069868027, 23.627985292865386, 9.159881645633329, 11.282173183656509, 5.93304576412324, 5.432540543617741, 4.049143137470368, 0.356793652979597, 0.08431163796734426, 0.9936487037808666, 14.837659558942242, 39.640069161691976, 41.11591192983812, 34.30407677927325, 33.715870303492395, 49.70370215754355, 51.86187259612545, 26.971158673686368, 1.711866980598819, 0.0337095195878177, 0.029227365138790304, 0.05696285831471605, 0.021272105119761922, 0.053085227677178, 0.06985127640467498, 0.07898397142848662, 0.08831224869936706, 0.06921765274338185, 0.07680085067066454, 0.026262242895280643, 0.09127120201986644, 0.01922453021360261, 0.04761293522953507, 0.06626508859617096, 0.016644702315510764, 0.09533925147186365, 0.011066419688323814, 0.056318394509294344, 0.0606679582908269, 0.023711692962434985, 0.02046898067478211, 0.04120667051944522, 0.041142732821284764, 0.0325727753431326, 0.0786698907012901, 0.034652665753157876, 0.03862750911784749, 0.054675407872925845, 0.03712288179104367, 0.0213135868656419, 0.048052485836970235, 0.011190864925963745, 0.018856436457304705, 0.010926577041015751, 0.087388132158066, 0.039741542686017296, 0.042470684950991024, 0.03206396464168305, 10.43085019434652, 48.472823173769065, 50.71661895321262, 38.06523361513692, 33.21162608362014, 44.30319070816041, 44.26422980523879, 35.14882979854461, 10.449453015481273, 0.2438121243950821, 0.021698375593029687, 0.7663243696574242, 5.730061636817071, 37.48273418795678, 11.965522631522148, 7.726657390594483, 10.071975877208095, 7.9076630069363505, 19.570289427234282, 33.489773119649584, 48.94332324304889, 54.248391659029075, 55.74999263209682, 55.18564593407416, 55.09001462690292, 54.65236440781624, 53.14392674353815, 54.355613570059504, 53.94107003365794, 52.178172526821015, 42.68460504470333, 38.80868357996787, 38.71972030208957, 39.5415823690353, 42.60374538360104, 41.59666115237821, 41.68900943571522, 38.657405607161984, 37.89091171756868, 36.997140838253884, 37.97923172673872, 36.03804680608934, 37.746615563669515, 37.05013990402222, 37.460706157069055, 37.342305491047526, 36.94207076103457, 35.47949737118137, 37.49738816292056, 47.62173552666941, 54.44214890080114, 53.49454349087131, 50.66010936614006, 52.22531549392208, 45.77773124940934, 44.3339656245324, 40.802930324308335, 38.56797948960335, 39.190267439811464, 37.937415338331654, 42.59280589319045, 49.487854126961004, 51.61285308099563, 51.944607150170114, 53.16364842076456, 50.40100543729721, 49.34878257013137, 45.52564051843459, 32.787070697353734, 49.62443105636105, 47.972830803163596, 50.115492190084154, 51.15451235924998, 51.405571506869414, 49.149133928360484, 48.294523992846095, 46.276664580068285, 44.915488381539625, 42.34617902386574, 40.02073126454508, 38.34503196900891, 40.242270654247655, 40.32699777233986, 39.88443674579744, 37.249545358842425, 37.678903687384825, 36.52984142303467, 36.676479231926706, 36.639416756168494, 38.96462917327881, 40.03797008145241, 38.9073194226911, 39.314402611024924, 39.90238551170596, 43.84773685086159, 43.054319812405495, 44.68367238198557, 45.304548278931655, 46.81344878289008, 52.193650199520974, 50.672743320465095, 55.076811928902906, 51.98202656161401, 53.30923111208024, 55.210113679209066, 54.45910138468589, 45.46598911285401, 42.76004399022749, 54.09190085626418, 55.515328991797666, 56.61129413112518, 58.331610387371434, 55.61475323092554, 57.7812312495324, 57.06703432144658, 51.83712636270831, 40.02345338944466, 32.00331249544698, 16.166827255679717, 10.757798379467381, 9.182879482546161, 10.262610912322998, 10.496098822162999, 5.589403971549004, 2.887335376393411, 0.5279520670733144, 0.02175695067572017, 1.1058471832544574, 15.95236284117545, 43.8644108464641, 39.09839376326531, 40.30738592147827, 41.23787803034629, 56.61238062766291, 58.34147122598464, 33.6951131205405, 2.737802368017935, 0.061484684626902306, 0.05501288109489026, 0.04119050223380327, 0.016367112271367543, 0.03859565518195591, 0.08279424761572192, 0.0989628320319518, 0.06882372267183758, 0.006239341333463428, 0.06023882264872232, 0.06237574830471028, 0.03999371967849232, 0.04159909905865789, 0.0548009850054739, 0.021075040492559635, 0.017934495605708613, 0.027307993131539515, 0.03184868435886118, 0.031089347584413427, 0.19486396303099973, 0.14583407540715512, 0.22537580480979336, 0.14079156211547314, 0.23268216920475807, 0.10381292701969225, 0.12486329948109005, 0.1254638358049335, 0.11587531080529576, 0.1412690340751602, 0.15495150229863583, 0.10270716337066504, 0.19497008153027107, 0.16726296425106066, 0.13978965700634066, 0.18511598449080222, 0.16413256045310728, 0.11825120992838375, 0.16107208516088226, 0.16545378633083838, 13.721311823014291, 54.80580360658708, 57.3892060402901, 44.25214106036771, 44.18686497596003, 44.03383762605729, 41.78491138642834, 42.019998642706106, 13.05028057867481, 0.49540111374470497, 0.13946023919890005, 3.061518765264942, 5.412589407736256, 32.171990102337254, 17.53027254535306, 17.448359727859497, 20.598381873100035, 9.182071474290664, 19.445495297831876, 36.88140738394953, 50.522563611307454, 55.57348989671277, 56.68884723417221, 55.52794725664201, 57.06969761079358, 56.37686191066619, 53.486400650393584, 56.74774946704988, 56.39563829668107, 54.64019329317155, 45.37885365947601, 40.405449098156346, 40.697457790374756, 42.91249082934472, 46.06821021726055, 45.381030574921645, 44.82972968009211, 41.9029825733554, 40.29499123173375, 39.895105592666134, 39.26934634485553, 38.39712496726744, 40.392842600422526, 40.429089223184896, 39.20243855445616, 40.262588531740256, 39.34587570928758, 39.02064061933948, 40.23806979579311, 50.65304125508955, 55.0928661900182, 55.17034476803195, 52.181753650788345, 54.495759856316354, 48.88244805797454, 46.281155693915586, 42.5773831336729, 40.42938732331799, 40.44762242224909, 40.581590975484545, 45.771180891221576, 52.53971307508407, 53.250960380800315, 54.40883228855749, 53.90542745590211, 51.81631034420383, 48.98766171547675, 46.2845406993743, 36.6528194950473, 48.73656334415559, 49.040723539167836, 51.14862095925116, 53.14228719280612, 53.31267495309153, 50.49815077935496, 50.125152987818566, 49.09285576112809, 47.94884158718971, 43.42491319102626, 41.93548333260321, 40.133071868650376, 42.00183022406794, 42.73609399795533, 42.21696046090896, 41.07172642984698, 39.473533168915786, 38.29823809285318, 38.53012077270016, 37.917803487470074, 41.970227687589585, 42.05268767572219, 40.42980701692643, 42.04937719529675, 41.09827695354339, 46.20100598181448, 45.567837376748365, 46.90709537075412, 47.442090972777336, 48.676904093834665, 53.55989802268244, 53.32193959143854, 58.31656025302026, 54.31452674250449, 53.81072575046171, 56.33623400042134, 58.114138495537546, 47.89892158200664, 45.95841915376725, 57.98216250634963, 56.65464024389944, 58.12449355279246, 58.25531244277955, 57.19854747095416, 61.307351819930545, 56.80550636783723, 54.5173603488553, 44.53799947615593, 36.473602479504, 21.515957616990615, 30.184866382229714, 17.60854148095654, 20.87522472104719, 18.548610056600264, 14.537748271419158, 7.82583010773505, 1.538935440682596, 0.2278279143595888, 1.661903216473518, 20.17885692657963, 53.54962925757132, 53.28922702420143, 46.610195482930834, 45.752537865792554, 63.02487142624394, 65.29889691260554, 40.50374369467459, 4.401953470322394, 0.1600473812751232, 0.1896538297014852, 0.14596188951644207, 0.10943235048363287, 0.12608816681970514, 0.20672409194371394, 0.2008718543595845, 0.1961167006483001, 0.12762231917511072, 0.1473632328692944, 0.09359198111680248, 0.21833061510997437, 0.14885647612954342, 0.19080467762485628, 0.1709788430842661, 0.14630045441369857, 0.18914108705376426, 0.23148229165423304, 0.26050246831390167], [0.04401341366070894, 0.03225861800714366, 0.0867619778540346, 0.051477121024001996, 0.017774940558498906, 0.027445515490046916, 0.041249766795625614, 0.05833627776272836, 0.051594332476416906, 0.01009741805553917, 0.06536395469259831, 0.05022346410119245, 0.023739500038866556, 0.048866055890797615, 0.07657408864507753, 0.02635996890134148, 0.04360005559940492, 0.06354624255289955, 0.05964312800056031, 0.04375399713734946, 13.192674383040398, 34.65585062580724, 40.287197482201364, 31.923174550456388, 29.904577732086185, 18.657500936139016, 34.67538795163555, 33.85244723289244, 8.977628715576666, 0.20260958691998837, 0.07926777636091556, 0.24317717540167996, 5.164012630139628, 1.1658864131858273, 4.0299093050341455, 6.68051076512183, 3.1166077188907133, 5.209716087387455, 16.467127838442405, 28.953920718162294, 49.33100246614026, 54.97573244956232, 56.260567557427194, 54.082659752138206, 53.18859077269032, 51.334258894766535, 50.04732531885947, 52.510722837140484, 50.831128628023215, 46.9692414037643, 39.62080640177573, 34.42074768004879, 38.644901091052645, 46.12724581072408, 49.396929663996545, 47.89983157188662, 49.61538999311386, 46.88400829991987, 45.99935693125571, 44.39898675487888, 44.406851107074374, 43.560886075419766, 42.85998205984793, 44.09962361858737, 42.19308891604024, 40.24048205344908, 36.40922461786578, 34.20862590112994, 38.42407165035125, 47.963244530462454, 52.50641607469129, 47.90106319612073, 52.0031249907709, 48.89655682348436, 42.82271169847058, 37.94276937361687, 38.2630269758163, 38.723830946030155, 37.26869437002367, 38.900192476088, 45.10578217044954, 51.91034524671493, 50.72645625760479, 49.54711721789453, 50.55109100957071, 48.98922281880533, 48.71105224855485, 44.047773807279526, 29.909472850061235, 47.616130459693174, 47.24764339385494, 48.19423683228032, 50.927258076206336, 49.05975487924392, 48.807083637483665, 45.2587075387278, 43.48730633335729, 40.14643930619763, 39.29613613313244, 36.48144721984863, 37.110489491493475, 40.07644461047265, 41.969800149240804, 44.41769646060082, 41.81008515819427, 40.54161025631813, 39.349417609553186, 38.49748665286649, 37.364204083719564, 33.78631999415736, 36.4923474865575, 37.78803971505935, 37.059714409612845, 38.02523328411964, 39.7908176145246, 42.418444771920484, 39.81792903715565, 37.14722641052739, 38.85833294160905, 43.31636551887759, 47.64157487500099, 53.31789170542071, 53.90101871182842, 52.50439997642271, 53.74886997284428, 50.6374772902458, 43.783025587758715, 40.68749889250725, 49.219787582274414, 55.401588101540845, 56.93477984397643, 55.742673489355276, 55.54385246769075, 57.21286019971294, 54.87110322521579, 53.62574285076511, 44.60442089265393, 32.38426681487791, 21.092310259419104, 8.91160051668844, 4.04634403605615, 5.895162532406469, 4.652289430941305, 4.11315425749748, 1.3315592393759759, 0.6055278463229057, 0.07456519160299532, 0.4363758777899127, 13.755427618180553, 34.58290630771268, 36.67664004910377, 19.514413302944554, 26.573289132887318, 54.65898144629694, 52.225005626678474, 28.30525875091553, 4.456479808976574, 0.055712323200197957, 0.07035638115579082, 0.039747633085015326, 0.05896535086175127, 0.0575828992371117, 0.041665124346412, 0.023425547631397363, 0.06755891916972977, 0.03256424878453536, 0.07351431049286358, 0.025882661650558154, 0.032727383377571265, 0.02104536990725225, 0.06428425335475514, 0.053613970071197524, 0.04985648117238476, 0.014471889270709888, 0.04863563196493253, 0.08691520309976994, 0.042257026859348824, 0.015602166775704153, 0.02964534271027773, 0.028342244388054938, 0.018706107023923148, 0.06399755260997242, 0.026176580858807412, 0.03632707731618035, 0.12056921578703389, 0.034000855164542314, 0.028166775779438116, 0.017786225033623558, 0.018286834763843688, 0.06896875843766236, 0.04390441084040269, 0.08263212808918569, 0.0215219110701113, 0.03891181583786684, 0.03859324966587367, 0.06995465230917738, 15.235290815753324, 43.42259114788425, 46.338924361813454, 38.07529841699908, 35.93055425151702, 25.900973312316406, 38.35727760868688, 38.135804899277225, 10.205258015663395, 0.34842080226348293, 0.07380585291332777, 1.088212697255996, 4.179691383915563, 3.116987453353021, 6.521535631149046, 7.990005323963781, 8.915470915455973, 10.260006458528581, 20.60706207829137, 32.30522517235049, 49.06276333716608, 55.813899809314364, 56.173902788469874, 54.47149607443041, 53.90105401315997, 52.26455880749611, 51.82293522742487, 53.09419108975319, 52.8164323683708, 50.50999633727535, 42.600752615159564, 36.819198593016594, 40.45502001239408, 46.567249451914144, 51.7176038988175, 51.199921638734885, 51.366453709140906, 49.08071994781495, 46.59032083326771, 44.49921507989207, 43.5968973559718, 42.8779229810161, 43.7827863231782, 44.29973117766842, 42.591837067757886, 41.0855096386325, 38.169176424703295, 36.060341558148785, 40.004476962550996, 49.769076301205544, 54.65963648211572, 50.66962111380793, 53.18887318334272, 50.40292739868165, 44.454578507331114, 41.021516169271166, 38.19129859247516, 40.416361131975734, 39.76284719282582, 39.66835337300455, 47.21269115324944, 54.15713771697014, 53.39049869968046, 49.425417838558076, 50.875180767428496, 48.87584278660436, 48.44757487696987, 45.88964039279569, 32.7043322209389, 48.051941087169034, 47.44344026811662, 50.069533778775124, 51.03097731067289, 52.1129160542642, 50.148440099531605, 45.51281436797112, 45.387808430579405, 42.983826975668634, 41.787433470449145, 38.03001465335969, 38.097134251748365, 41.01203972293485, 44.39669216832807, 45.046024860874304, 42.80700260593046, 42.0839842673271, 39.33867423765121, 39.05410235927951, 37.67708370762487, 36.776782081973174, 37.68947055262905, 39.66812195316438, 40.4564477551368, 39.82478141784668, 41.90785415710942, 44.62036532740439, 41.955765908764256, 40.42917159295852, 41.33799260662448, 44.423889883102916, 50.61372341648225, 55.10402925552861, 53.739256243551935, 52.31671064130722, 55.67952332958099, 53.74109975753292, 44.86894161470475, 43.83655809587048, 53.684076339967795, 57.28972688797982, 56.80424728701192, 57.01946381599673, 57.799383978689875, 58.445382656589636, 55.503102963970555, 53.53691293347267, 44.71630257944907, 35.89868891623713, 18.702916099179177, 12.082097434228467, 10.818033237611095, 10.14248832579582, 11.88089063090663, 6.691023207479908, 2.7218069424552302, 0.5954433713228472, 0.11277443969682341, 0.7997859870233844, 15.055123606035787, 41.68248653411865, 40.49559693182669, 22.977264081278157, 31.1350429058075, 59.44252367942565, 59.42037797743275, 35.23742437362671, 5.2357096345193925, 0.102587171019085, 0.07165200437509245, 0.03414256610877572, 0.022466937981305585, 0.010461726379881223, 0.07487721155367552, 0.04921410112611709, 0.026539018971004316, 0.028934581655888792, 0.010673015344617589, 0.018784609968743978, 0.016364773787978678, 0.026021737252332033, 0.05221650312324205, 0.05071297513260957, 0.01586178248192394, 0.02594658594217993, 0.025301040037565177, 0.07090071726950907, 0.151454801220567, 0.08848406689902467, 0.1472185188603978, 0.1766685627761387, 0.12509784495998777, 0.10247137682933001, 0.0793164459267451, 0.1068914283607756, 0.20978472045352384, 0.1121607036780446, 0.16728352605094834, 0.06398899540785821, 0.18358305787607548, 0.19254627126839854, 0.21445951154155118, 0.12222617969758089, 0.10549236028905838, 0.13854618905292404, 0.13538301201356998, 0.20825350987574748, 18.557223581498672, 51.80948934247417, 53.07180220080961, 45.84341133794477, 40.393379965136134, 30.01673790716356, 45.383046673190215, 43.22564894153226, 12.195780469525246, 0.5633082505195373, 0.2333161835708926, 1.0630251971944686, 10.456816284887253, 3.7245319495278024, 6.418954374328737, 16.437948346138, 8.59555063709136, 11.69469669941933, 20.293384252056, 32.96591704891574, 52.83372609846054, 57.45617658861222, 56.973976089108376, 55.345376614601385, 55.37198989622055, 52.4372725332937, 52.20533101789413, 55.78500763062508, 55.37864615840297, 52.73041086812174, 45.430758383966264, 39.45291719129009, 43.4525227546692, 51.72507993636593, 54.000721439238525, 52.38344976978918, 52.66981024895945, 52.040144320457216, 50.18946416916386, 48.79488506624776, 48.737536091958326, 46.95081803106493, 45.270121635929236, 47.37730910701137, 46.46889994221349, 44.02061139383624, 41.87080344846172, 39.015749423734604, 43.06432577871507, 52.38865475500784, 56.62993323418402, 51.791673937151515, 55.04329919815064, 54.19998176636235, 47.36795033178022, 41.99360109144642, 41.41506325814032, 42.820358276367195, 40.607051080273045, 43.074233685770345, 50.210672424685576, 57.48834786876556, 53.9117895403216, 52.46396426231631, 52.699533970125266, 50.065466280906435, 48.545328186404326, 47.06549244542276, 37.4746423382913, 49.5079876530555, 49.07963737364739, 52.09620675733013, 52.872734069824226, 54.23934667341171, 52.42205373702511, 48.19267965132191, 48.487394778959214, 44.4795875395498, 43.549585726953325, 39.85078673208914, 39.714468679120465, 44.538313265769716, 47.77254281505462, 48.65354245708835, 45.78577603063276, 44.65513713898198, 43.914299472685784, 42.790783605267926, 42.50518798828126, 38.63303592128139, 40.456459522247314, 41.894380815567516, 42.06632575681133, 42.7171685618739, 45.3220106709388, 47.191518199059274, 43.440296726842085, 41.829810757790845, 43.02899306820285, 46.59323515430574, 52.553296242990804, 57.25918731381817, 55.137906766706905, 52.890961324014974, 57.265753361486624, 55.655279159545906, 48.03722043191233, 45.861160062974506, 55.159322907847745, 59.97991977199432, 61.39169062337568, 59.47113344746252, 60.59218214404199, 60.824300166099306, 56.62212379517094, 56.53086985311201, 49.27827796628399, 35.5099545755694, 23.671788361764726, 16.881871415722756, 12.301696231288295, 18.395347364487186, 16.281958626162623, 12.198327068359623, 5.046718562802961, 1.5267264506509228, 0.42049303650856024, 0.9266511278767741, 18.97050803707492, 47.41787425933346, 49.53926071043938, 30.15087316113134, 39.54856811031219, 66.41747843834662, 68.32456619508805, 43.95146000769831, 6.862501876969492, 0.22991951825397633, 0.16896384798230665, 0.12145591659411309, 0.12171090895970985, 0.18132115263612042, 0.22794265900888752, 0.14428587299921822, 0.1652840518903348, 0.10411500314911527, 0.1055698577434786, 0.10597555492553981, 0.1010219844418668, 0.1369862195344702, 0.1367929815164497, 0.14193749175437037, 0.09557706814619804, 0.15037132306925713, 0.0976326352646274, 0.14506256358037073], [0.09165805343899036, 0.008503708109680203, 0.10346821043640377, 0.05510538238130751, 0.06423743772170236, 0.03881294069991958, 0.07318441005003068, 0.01396460021139994, 0.07738678535867123, 0.04588566359973723, 0.03700917136044272, 0.027857797197817315, 0.08595341035435278, 0.07387683862039159, 0.08712992222318727, 0.05339776473720709, 0.03583722920607656, 0.05753685735286244, 0.03655340267165053, 0.1104116943033953, 13.494845936375281, 38.75159740447998, 47.82264324926561, 40.747381717928, 25.49382540487474, 17.3026515206983, 30.592379070097405, 34.122620090361565, 7.829478402291575, 0.28367010095427114, 0.03643903723587433, 1.114784793988351, 3.8285720829040777, 3.5348402444393408, 1.9368177291847046, 2.5053320680895164, 8.397248348882123, 7.78129110413213, 23.981630109971572, 35.48050542031565, 52.08944851352323, 54.76293994534401, 58.26688343478788, 51.38631266932334, 53.012899967931936, 50.84075020205591, 52.63151614896713, 50.23312407155191, 49.229824927545366, 44.72519851499989, 37.82330574527864, 35.83692727550384, 40.48008395779518, 51.42737988502749, 52.75365483376288, 49.00593603810957, 48.00583754816363, 51.025419312138716, 49.02084496713454, 50.59433121835032, 52.97782221148091, 50.33571758577901, 52.199745562768754, 50.47598938788138, 49.57009838473413, 47.60467321641984, 44.201252229752086, 41.32624903032857, 41.40167620874221, 49.48812477050289, 49.973796567609234, 50.22672668580086, 50.46557941744405, 46.52818264499788, 41.09562543130691, 36.878206729888916, 36.87081698448428, 37.24937669692501, 38.34856994690434, 38.611478574814335, 45.79121243569159, 52.23023806848834, 50.52204193607454, 53.04758548736573, 49.65384491028325, 50.138218402862556, 49.02177456886538, 46.71241637199156, 29.91497789659808, 48.453874203466604, 46.33295451441119, 50.45266697483678, 50.68738945068852, 49.367747229914514, 49.30741725429412, 46.20883503267842, 45.31254991408318, 40.12766684255293, 36.578941652851725, 35.48774219328357, 38.305506244782485, 41.29872183645926, 46.08177377331642, 48.56532835191297, 49.45692623815229, 50.04092793310843, 48.55352201769429, 49.58509360590289, 48.33123737765897, 43.98298017440304, 35.10171036566458, 36.29940609778128, 36.90413359672793, 37.2301806173017, 38.4569215005444, 37.43389675694127, 38.508445755127944, 38.68151249424104, 37.029692588313935, 41.267672354175204, 46.89423784132927, 53.359963047888975, 53.37874335627402, 52.54718911263251, 55.1117524023979, 51.32925395042666, 44.33408721800774, 40.979570342648415, 43.089758426912375, 48.95110522547076, 51.94872956122122, 52.96536084144346, 50.828920333616196, 54.22931325051093, 53.00244292905254, 54.397971245550345, 43.833679076164, 42.09082095853744, 26.341245635863274, 11.391581816058006, 11.930380155963283, 11.031149337368628, 8.328479393835991, 3.5489117474325242, 1.1259458983136763, 0.1088436272355818, 0.10488194143099171, 0.4793752591696478, 10.240457365589759, 37.40605969582835, 31.98244940850043, 27.02537759657829, 41.66116060749177, 53.63377978724819, 48.46894002729847, 22.24431626258358, 4.890625880610559, 0.13497393638376268, 0.06284632930351843, 0.1059493164141332, 0.07679795485831077, 0.04693516958204489, 0.015071670997947937, 0.044447425452451554, 0.05573026880982423, 0.023693559661267266, 0.023516999377358346, 0.014101472352781605, 0.06323735973226928, 0.03486807435570705, 0.08784059900790454, 0.14496265039328607, 0.0552964523705023, 0.046560269134539756, 0.04960820739788394, 0.009041222210432734, 0.02601443643441364, 0.06365567821288301, 0.007208711167256679, 0.08522764929840643, 0.08666745792593687, 0.03224001356190251, 0.030400998432249315, 0.0606459102803661, 0.04787242453124735, 0.04082979739553506, 0.04888089884433055, 0.005741678647727015, 0.031642832703167395, 0.06744949117062554, 0.06006698529686659, 0.002242657520260001, 0.12021383525983942, 0.031347161068791346, 0.06995295925486474, 0.23984507597502203, 17.29805254167126, 43.82043715446226, 54.53048459945187, 45.885447379081484, 32.17295892776982, 24.26576464406906, 36.37135805622224, 36.63368225097656, 10.014436667965306, 0.3975292445430833, 0.056270107987426946, 0.5627126631236846, 6.442190985525809, 6.4732904780295595, 5.706916220726506, 8.179114557081654, 8.406241363094699, 17.791398456019742, 23.64357279193017, 35.583687290068596, 52.076214436561834, 56.888935181402395, 56.89534041189379, 54.11152055186611, 52.83831919393232, 52.540670133406124, 53.36840791086997, 53.61865120549356, 50.862272247191406, 45.53473649486419, 40.08599558184224, 38.27596687501477, 40.58730586882561, 53.17832200757919, 52.2736979299976, 52.261016907230506, 50.6878875917004, 53.152657939541726, 50.785166294344016, 54.123224904460294, 55.27657039703862, 52.98789093571325, 53.23709872461135, 51.15896424939556, 51.0542683447561, 49.75867417550857, 45.704900680049775, 41.7436872759173, 43.172967587747884, 52.104431967581476, 51.20077279306228, 49.5034965392082, 52.947455221606845, 47.314009897170536, 42.300079407230506, 38.326898851702296, 38.458564973646595, 39.394807277187226, 40.55054541557066, 40.319145187254875, 48.98149967193604, 54.1797423362732, 52.77539260925786, 54.93642637806555, 51.707170394159135, 52.39624846366144, 48.71939120754119, 45.92036039598527, 31.711446969739853, 48.15182424360707, 46.6271165878542, 50.41259211878623, 51.98688245588734, 51.30429198665004, 51.71638404169391, 48.03290582472279, 47.297006422473544, 42.54690631743401, 38.55108976364136, 37.33513539837253, 39.94202890703755, 43.67287366620956, 47.21693123540571, 50.78992020699286, 52.37512650028352, 51.54142672015775, 51.0255212937632, 51.29519208785027, 50.405163149679865, 44.45424510586647, 35.71874626221196, 38.15681703629033, 38.25319751616448, 39.440377373849195, 40.520402000796416, 39.45367420873335, 41.63339414904195, 41.174449382289765, 40.33455617966191, 42.91773896063528, 48.72417649915142, 54.841940402984626, 53.80674454473681, 51.66126689603252, 55.488747089139885, 53.08301625713226, 47.150886366444254, 42.35081526540941, 46.851229052389826, 53.20333496216805, 53.97300989397111, 55.675177343430065, 53.876856911566954, 56.5822882037009, 54.997925219997285, 54.626492454159646, 48.790986230296475, 40.3353798773981, 24.484075923119825, 13.11914170941999, 12.896664873246225, 6.123562637836703, 6.700898754981257, 6.516642474359082, 3.5886012306136474, 0.31823206572763385, 0.04589854919862363, 0.5438658583068079, 12.839714019529282, 41.90762273726925, 43.090884147151826, 33.97287184192289, 44.73514564575688, 60.49612329852197, 55.44402030206496, 30.96002478753367, 6.422311923196239, 0.12741388197267248, 0.009639542624955217, 0.06152617977932096, 0.02952668909734536, 0.020653335903320583, 0.01832101377658546, 0.017682531202632575, 0.07015205784550599, 0.059489799332955194, 0.07004481319698595, 0.062039991119696256, 0.0151808557641362, 0.0483498964909344, 0.0752696937190429, 0.023506406296585357, 0.022184475617963943, 0.031735454648432714, 0.09783384825793967, 0.026319923570319533, 0.20058081755715035, 0.1422459800397196, 0.18316756242946272, 0.14677127673020288, 0.1569248835045484, 0.1346622611726484, 0.13729533601191737, 0.1636278617285913, 0.11374996839872292, 0.19495400900561966, 0.09230679201502955, 0.13540228678574487, 0.21199983304306386, 0.20818808596701394, 0.17126045700523163, 0.11739260922636717, 0.198272870432946, 0.13740534623784406, 0.11610318365837298, 0.5002465279352281, 19.605253434950306, 54.00669520901096, 61.86510501369354, 52.76875988129647, 37.44561287664598, 28.313072112298784, 41.619363830935576, 43.17869817056964, 11.643072424396394, 0.9530841030420797, 0.17185262764894194, 2.3135303729964845, 8.641455115810517, 10.034621184872044, 6.841396583664802, 8.787674211686658, 13.633241864942736, 12.88061845687128, 27.105425327054917, 38.09554961419875, 57.04648894648398, 56.31974435621693, 60.03393865400746, 52.72955579142417, 55.71483642824235, 51.366277202483154, 54.80792953122047, 54.97578736274473, 54.55889824898013, 49.62492135263259, 41.770198575911984, 39.09855458044237, 43.39474231966081, 56.84014481882895, 54.33117720388598, 51.72780990600587, 52.09641072057909, 53.91794373912197, 52.68445637918288, 56.3182460108111, 58.65705336293867, 54.81330317835654, 55.88551836629068, 53.48751068115235, 54.138071075562515, 52.29583186487998, 48.23696713293753, 45.21267068001532, 46.61247045763078, 53.54815052401636, 54.089578813122166, 51.56560813227008, 53.54937822588029, 49.88000485204881, 44.92436862760975, 39.28993878826019, 40.372716919068374, 41.55883381443639, 42.68994339050786, 43.5844438306747, 51.54982843706685, 57.97318027865503, 54.16770850458453, 56.50374666337044, 52.57061350730158, 54.9404703417132, 50.20624406876103, 46.17119989087505, 36.043404763744725, 48.59487164405085, 46.652341350432366, 51.25097520889775, 53.642522750362275, 54.14329959500221, 54.756260148940555, 49.04612856526529, 50.80255808368806, 44.77752293309858, 39.93323103074105, 38.59874263886483, 42.840860505257886, 45.43950134708036, 50.02618374363069, 51.63499093824818, 55.29557428052349, 54.97637964064076, 51.45290274773875, 54.93863467247256, 53.77665604314497, 47.570485837997936, 38.80917387623941, 41.22616191064158, 40.16462341431649, 41.98869028399068, 42.46963562503938, 41.82789664114676, 44.55954113314229, 42.70411099157026, 40.910289518294796, 44.84626247036842, 49.85017914925852, 58.380949881769, 55.66577542212702, 53.12161237962785, 59.780443714511016, 56.7741274064587, 48.815214710850874, 46.01740375641854, 49.00703822412799, 55.18652846736293, 56.39432430267335, 57.60430489816974, 55.18892895790839, 58.793175297398726, 55.56888895650064, 55.73668403010215, 48.74988371326078, 50.16658106157857, 29.650606224613806, 17.67031292761526, 18.515140471919892, 15.730388068383741, 12.412796385826605, 12.451839658521838, 5.004881581952495, 0.31983349592454974, 0.21270022126695803, 0.6629150024344844, 14.975680901158242, 49.48161755838702, 48.00704956054688, 37.29279733473255, 55.37975226679156, 64.8160727562443, 64.16894443573491, 39.11584438816194, 7.739662499197069, 0.25913199830439787, 0.2484179522481657, 0.15105988289560043, 0.17563150955304024, 0.059446197438744776, 0.1608123660327927, 0.12681575116491126, 0.15973205948548932, 0.15642897946940315, 0.11436655426458006, 0.11493794094290465, 0.15227419354261892, 0.14742203777836216, 0.26189671769257516, 0.2542819722645706, 0.09866366703664103, 0.13167589722621825, 0.25741289700231246, 0.12113309480370053], [0.06807789011227508, 0.06273603179462015, 0.025033625556276213, 0.03544200061550064, 0.017455809396661578, 0.004610719803285095, 0.05223526461650768, 0.03534995515139834, 0.034660541137019475, 0.027148608538892963, 0.041220981041870774, 0.05309461991512968, 0.0017703403746934549, 0.061567632796903776, 0.06152650153624916, 0.054642301383278066, 0.03864968353281579, 0.031097039107173204, 0.030368481830303228, 0.053056801984747576, 9.662238224860161, 33.51506848489085, 43.847352458584695, 39.74738520960654, 24.406752278727872, 21.02358445044487, 34.580337155249815, 33.89112572516165, 8.59368751125951, 0.37805899737342713, 0.1156645983217224, 1.317910616916995, 4.115985718465621, 2.9053645508904613, 6.59282127695699, 7.725433611100721, 10.301064848899841, 17.462645000027074, 18.99193202295611, 38.73292692245976, 48.136275968244, 56.181374903648134, 52.45377002223846, 51.61951718791839, 52.15730159513412, 51.4446775374874, 52.069722913926654, 49.60135183026714, 47.50672378847676, 39.92067552381947, 37.9274485957238, 37.19124324860112, 35.71710278910976, 45.22413969039918, 50.36396649576003, 53.24845790863038, 48.191695136408654, 49.418659594751176, 48.218347641729544, 50.6824198076802, 51.32628079383604, 51.6427807654104, 50.589930319016986, 51.508882814838046, 49.942413683860536, 52.1211334197752, 51.43577767956642, 48.911430451177786, 47.23760604858399, 51.57938349631525, 49.677379131317146, 50.44454766858009, 50.29683120789067, 45.548331429881436, 39.09508328283987, 38.0049781645498, 37.41739534562634, 39.162116589084754, 38.9516108266769, 37.60191148327243, 40.8390082851533, 47.61518909085182, 49.40918707078504, 48.90225602734474, 49.40106776452834, 51.125843755660526, 51.66731911320841, 50.936173623608006, 28.225803298334924, 44.68593166720483, 46.081342312597464, 45.58781400803597, 49.05880566566221, 49.041617839567124, 49.75146485913185, 50.865072819494436, 46.39086438763527, 40.141383371045514, 36.077988301554036, 37.54961844413511, 39.45546280953192, 42.21259486290717, 45.05073562745125, 48.32305531347952, 51.37309820421281, 52.288814744641705, 51.59516319151848, 50.75203403349846, 53.70767331892445, 54.14084419127434, 40.21196642229634, 35.89442137748965, 36.72554808278238, 36.5007923495385, 37.45210832165134, 36.9768778739437, 36.97314769990983, 36.52126319946782, 37.54789652362947, 35.0710609651381, 43.85201223434941, 50.82571575718542, 52.95094220869003, 53.86532906563052, 51.59255873772406, 53.34631712205949, 47.84131373128584, 43.729846092962454, 42.514966457120835, 44.633960262421645, 48.42296592650875, 48.31622646700952, 51.79908329440702, 53.13301470971877, 56.51293285431401, 55.80095206537555, 51.595386766618304, 45.32249704484017, 26.91375674739961, 17.642097357780703, 18.14206031060988, 4.103446636469134, 11.144801974296572, 3.890123876833147, 4.200161253252338, 1.2235738144766901, 0.04191671145118533, 0.6700424393338542, 8.781186611421647, 36.85293882123886, 30.204841052332235, 20.691422454772457, 38.91380310058594, 48.524951473359145, 54.861285532674486, 27.792814816198042, 2.422290098282599, 0.07897526100878755, 0.05963294669204663, 0.057192684692000194, 0.14211811996515722, 0.00814272843736915, 0.018224245380429972, 0.06690506312635637, 0.03886190904003959, 0.0406441742914819, 0.13663083134639648, 0.034243406262248755, 0.06786427415546871, 0.03875628466747942, 0.0361169891942653, 0.02326047483591303, 0.047366469422535556, 0.1206315906658288, 0.038416187594374346, 0.010490583954378964, 0.05059075346516986, 0.07916421659531132, 0.06645404418269474, 0.06699527764031965, 0.05296055069794098, 0.030227621243665778, 0.05810462809618443, 0.014397448507107556, 0.06368875405901382, 0.07393706845299852, 0.01167244024409522, 0.012638696409281225, 0.060620514465676206, 0.07704627459808704, 0.06822019860508942, 0.03513401028730216, 0.06068347157129358, 0.040668658461541905, 0.014659694767737342, 0.1294146201783611, 12.087695637056905, 38.957588518819506, 51.44234764960505, 46.904840007905044, 29.800929100282733, 20.98020499752414, 36.86403128408617, 38.954897772881296, 10.071262986429277, 0.49152483142191367, 0.09387209350543638, 1.0360701790740414, 3.110269904136658, 5.681607617485908, 6.635849677747296, 8.463537385386806, 9.228666290160149, 21.471972157878263, 21.915900130425733, 39.40586836107316, 52.3644458863043, 57.938710489580714, 54.023812432442945, 52.683648370927386, 52.312062632653024, 52.31413364410401, 53.9155863946484, 52.482246429689475, 48.571074624215406, 42.46218312171198, 39.65319733465872, 38.503558481893236, 37.279802522351666, 47.70098701600106, 52.29247431601248, 53.041235170056744, 49.04807798324093, 50.25235937487695, 50.40096621359549, 51.50264232389389, 51.85588313687233, 52.812855166773645, 49.89176804019559, 51.496405755319905, 51.778765416914425, 54.06106318196943, 53.24300189172068, 49.88111488280758, 50.18337665065643, 53.584526584994414, 50.568486721284934, 51.030734123722205, 52.36763869562457, 47.83113125831851, 40.63909684458087, 37.632858983932, 38.202104722299886, 40.939366048382176, 41.01423232786117, 39.06214714050293, 44.46302337031211, 49.839051385079664, 50.365551133309644, 50.973863678593794, 50.4260144695159, 53.513876853450654, 52.63046103139078, 50.88707731616113, 31.13329548989573, 45.035595278586115, 46.272083251707016, 47.47012415239888, 49.842416778687515, 50.21480268047702, 52.860260932676255, 53.49794810818088, 46.674981271066976, 41.747856755410474, 38.20654092296478, 39.24248987628568, 41.511753605258086, 43.77465132744082, 46.296864786455714, 51.47596236198179, 53.123491194940385, 54.65153678770989, 53.903740836728005, 53.05314740827007, 54.99029621001213, 55.62373938099031, 42.218427427353404, 37.421572669859856, 37.94427164139287, 38.774496201545965, 39.350688457489014, 38.98077364890806, 39.567885783410844, 38.632122009031235, 38.76585129768618, 37.74617233584004, 46.65818568198912, 53.54689536556121, 54.36665896446475, 53.84166932875111, 52.53428451476559, 54.18896382854831, 49.399534117790964, 46.63963287107406, 44.707112466135335, 47.60003697487616, 50.53351486882856, 51.277776764285186, 53.159074937143636, 55.63236859536941, 58.83135172628588, 55.7509732246399, 50.40588878816175, 41.38398631926506, 26.16661975460668, 18.163731405811927, 12.217315262363805, 5.7702399453809186, 9.5036107109439, 8.034444307127307, 5.017690081750193, 0.6985384586357302, 0.0020433255122043192, 0.5725930523007148, 10.910887506700332, 43.056014276319935, 35.80566206286031, 23.227758407592777, 45.85862621184319, 55.18610485138432, 60.46718012902045, 33.65539127780546, 3.5757571843362626, 0.040297492692667636, 0.03306958719246811, 0.004078210650702878, 0.06828905458772375, 0.012890924155081232, 0.035037096334441055, 0.030889348840461146, 0.047768673243662046, 0.03156387585125143, 0.06686561725913517, 0.09318429210613813, 0.05583980406123785, 0.022849660186517625, 0.0796281977466518, 0.024181663006123517, 0.04516637598675105, 0.11797315831626616, 0.04547024093147728, 0.01764807639823806, 0.1896620115205165, 0.17828785814344886, 0.14407898329438704, 0.14616752283707743, 0.20637144635040916, 0.10219223737235993, 0.21590090597108488, 0.16345291789020264, 0.12787356537075775, 0.10971104560960686, 0.11751539779887085, 0.1597374067792008, 0.1349742428189324, 0.11788891162723304, 0.20364780459673176, 0.1502406284693749, 0.15739253421704616, 0.14225246114355905, 0.1039211445998761, 0.2758705291536547, 14.978598163973901, 46.81127186744444, 58.95705976793843, 53.66310734902659, 36.094462256277765, 31.344558269746845, 46.26058678473196, 44.11478357930338, 11.64062290422378, 0.6538880352051027, 0.24050450913848417, 2.189761207949731, 7.91336662346317, 8.331586891605008, 17.009921112368186, 16.64447976696876, 19.908972363318167, 21.411855951432262, 21.634379856048092, 40.04888996001213, 53.34583074815812, 58.51522045750772, 55.69618948044316, 55.16712450212049, 51.580018920283166, 53.95571224151119, 55.0599378924216, 54.57315214218632, 50.845072653985795, 43.68110672120125, 42.39607157245759, 40.486783366049494, 39.2983954183517, 49.2539200475139, 54.344415203217544, 55.808906632085005, 48.67406429782991, 50.854929570228826, 50.38857544622114, 54.427777336489775, 52.04980119582146, 53.376291874916326, 50.58774948120118, 52.806096922966745, 51.714140445955344, 55.32061861407373, 57.86939044152537, 54.08940622883459, 52.41990820054085, 56.345122091231815, 50.98024929723432, 53.04683239229264, 56.719743744019546, 50.046874246289654, 43.55800705571329, 40.697347964009936, 41.361821005421305, 43.017696642106586, 43.502164271570024, 41.42688528183968, 45.87885387482182, 51.49226373241794, 52.529954218095355, 53.032460827981275, 53.06614614302113, 54.916198715086914, 54.0621026100651, 52.793921885951875, 35.989256443515906, 45.39300557105772, 46.620425024340236, 47.020083165937855, 49.22993867628036, 53.50812665877804, 53.79516178561796, 55.41719521245649, 51.62285512493503, 44.58966885843585, 40.19379015891783, 40.99041569617487, 44.08739759076027, 45.8836313216917, 48.63456995256486, 53.36844321220152, 56.1601274244247, 56.96725314663303, 56.21951995357391, 54.625582464279674, 57.79845045458887, 58.52938805857013, 43.95043626908333, 39.663995619743105, 41.48422641138877, 40.032196352558756, 40.760407909270256, 40.616139211962306, 41.27680755430653, 39.744184555545935, 40.76308688809795, 39.560609786741196, 49.56208106010191, 55.15643604340092, 57.81472044606363, 55.81385666324247, 54.275597218544256, 57.055804575643236, 53.5138415521191, 48.441785458595525, 48.61142796854819, 49.783655751136045, 53.66042444782873, 53.247202750175234, 56.04147964908231, 57.667831605480565, 62.09935680512459, 57.23142870010869, 55.06072628882624, 46.19489100671584, 30.014182482996297, 22.004712397052398, 22.951207776223463, 10.873025848019509, 22.98549713626985, 12.196728702514404, 8.870866702448938, 2.425940844320482, 0.1226792134524834, 1.1274187483133808, 12.841817390534187, 47.77025607324416, 41.439248592622825, 30.66390741255976, 52.70999100900466, 64.58302513245614, 69.72701749494, 41.47977059887302, 5.4406127814323675, 0.17245255110244598, 0.2543896229396905, 0.04326308416503091, 0.2022057206880662, 0.11149491198481092, 0.13953513195437772, 0.14787671096142263, 0.1298011421796776, 0.182536443875682, 0.31832871538016105, 0.193256480739482, 0.20282046028202583, 0.14911484694288624, 0.1852352797023712, 0.1220304748764442, 0.1274019463228122, 0.3341625576778766, 0.10573004672844565, 0.15134178792997716], [0.03815155784269014, 0.04332900986135487, 0.07521435918827211, 0.03478011980112042, 0.03323658286864239, 0.03261902790156103, 0.04817058978181693, 0.10348004649483389, 0.029159307802817034, 0.03489203758597855, 0.014299244653703946, 0.003911240590593568, 0.09560115395053741, 0.02912196293172817, 0.05057738523089117, 0.03088526750704454, 0.013282045556773103, 0.014274788254331199, 0.03567802081365259, 0.19528701210454588, 9.704210527481573, 30.41788458824158, 48.519758255251, 42.07929703497118, 26.37867093086243, 28.38295698165894, 30.145162190160445, 33.32007961888468, 9.61841260233233, 0.38774268581501903, 0.10557456918421293, 0.07487356497515595, 5.506407108999068, 4.644902137018019, 4.4682336814941905, 9.115847156893823, 6.754431263093026, 38.38005481227752, 26.688314599375573, 45.47628141218617, 50.27794891788114, 57.87157912408152, 52.13454792576452, 53.13077895872055, 49.1651842671056, 54.813581666638775, 51.606655736123365, 50.04153197811496, 42.29770245090608, 35.93977574379214, 33.46561131938812, 35.07236711440548, 35.984192663623446, 41.90468095964001, 46.309451672338675, 51.89708371316233, 49.25612834192092, 49.58684298299974, 49.08994144009006, 53.5442752222861, 49.758603572845466, 51.66770742785547, 48.551392170690725, 52.39645634928058, 49.98134713019095, 50.90047221029959, 49.33746260981406, 50.690770533777055, 51.01127916766752, 50.765162206465206, 49.33712136360907, 52.59147659424813, 49.44490025120397, 42.19457941670572, 36.98717017327586, 35.29827210210985, 35.87970072223295, 38.33899544131371, 37.21660137176514, 37.31814761315623, 38.26072062215498, 42.598685526078754, 44.54155314353205, 46.205618689137125, 45.85708864273564, 47.51068145998063, 50.03995910767586, 54.443007899868874, 27.950611768230317, 45.41186824921639, 46.924965689259196, 50.59449988026773, 49.25919563539567, 48.687243461608894, 49.69821868404266, 50.07005545400804, 45.33243633085682, 38.326565450237645, 35.82223799920852, 37.411892260274584, 36.15802818729032, 40.27789362015263, 44.74079385880501, 46.86592617342549, 50.58772986935031, 50.741384798480624, 50.91476924957768, 51.068404566857126, 53.846368328217544, 49.449430588752996, 40.2011053792892, 38.34408275542721, 36.89389228820801, 36.76392455254832, 36.78950232844199, 38.20694100472235, 37.36434921141594, 37.02939448818084, 36.897010572495, 36.72734060595113, 38.40919017791748, 46.67988815615254, 50.774987743746856, 53.69647102971231, 52.655411228056884, 53.077921098278416, 51.34431977425852, 48.781195994346376, 47.26542349784605, 42.500971440346014, 45.186743813176314, 47.038333954349646, 48.62291659078291, 53.520399755047215, 54.130065518040816, 54.56308734032416, 49.52376734825873, 43.723072159674864, 29.40437355349141, 22.92495535266015, 13.427109545277013, 4.486511436200911, 2.2535602748394012, 7.154005073731946, 3.509001385781073, 2.101871924054238, 0.07315658573662082, 0.4011716249008333, 9.41731954774549, 36.8330406373547, 43.77108981532436, 45.428848189692346, 36.54971215032762, 45.59303076036515, 51.38028006399832, 34.8819988004623, 4.981077207672981, 0.06187647348269821, 0.029862233692960396, 0.0126878917029488, 0.009733971580111933, 0.0654815721716131, 0.06827239217537065, 0.032997394896923535, 0.05570867662167838, 0.050832320139893604, 0.03041219097682305, 0.033677945274018475, 0.036172921273617015, 0.031660831938948364, 0.0201062552796136, 0.025030927011562933, 0.044939476065337665, 0.03571706448471354, 0.02190567323968055, 0.01416141490241693, 0.03842988524646048, 0.052486020515883164, 0.07661126689204285, 0.08117667594624144, 0.01034859721849282, 0.06997201952242083, 0.0726305821069306, 0.10000421365182247, 0.025791730844385685, 0.05158324718415257, 0.047419333319750526, 0.0431231428839026, 0.0722386515248687, 0.046371662118021524, 0.0353972151154472, 0.05455502864694404, 0.0008538553858318577, 0.023189006493456905, 0.06384177246100961, 0.07122053599525845, 11.832519961941628, 37.76902798683413, 54.81389545625257, 48.96827736208516, 31.149308566124212, 37.02793536647674, 37.41862304749028, 35.8642073600523, 10.708681479577097, 0.4729584760723576, 0.07965714054843111, 0.654509547016313, 4.43156736512338, 7.449271294378466, 9.861820186338118, 11.874936472985054, 7.785634148505427, 21.76103318891218, 25.928094540872884, 45.74528540334394, 52.530417057775686, 57.30993886147776, 52.29076416261735, 54.30212028564946, 49.82908856484198, 53.83920215791272, 53.66129913637715, 51.908074194385165, 46.16410040086316, 38.64815273592549, 35.55057856344408, 36.164507942814986, 37.00127893878568, 42.30883021508494, 50.133511558655776, 53.0229647697941, 51.346414319930545, 48.898827875814135, 50.21660304838612, 52.965749156090524, 52.09508495946085, 52.46628630545832, 50.832768178755245, 52.438590449671594, 51.26333067494055, 50.97725652879285, 51.86441036962694, 52.692442324853715, 51.83252934486636, 51.629260355426425, 50.84456666823357, 53.06579705207579, 51.96167730516004, 44.01975631713868, 39.22240341863325, 37.40839350608088, 36.26610517501831, 38.72103821846747, 38.71275417266354, 39.49458845200078, 40.030541112346036, 44.55486566789689, 46.771789289289906, 47.87350854566021, 47.971497197305005, 49.96970553551951, 51.490239789409024, 54.23351803133565, 30.846558463188913, 46.45951763276131, 47.41543454508628, 50.24556975210867, 50.58769456801876, 49.249130833533506, 52.98261927020166, 51.26618616042599, 46.955450350238436, 39.36741344390377, 37.91528140344928, 39.34781728252288, 38.852653349599535, 42.578202909038914, 46.505028893870694, 50.25040603453114, 51.55442545490881, 53.3454934243233, 51.660780522131155, 53.33483242219495, 53.75466331358879, 52.532664575884425, 42.58890313486899, 40.31417162187638, 40.55595828640846, 37.805054956866854, 38.22484662455898, 39.73315877299155, 38.85284554573798, 37.99148128878686, 37.430378390896706, 40.00045653312437, 39.729922817599395, 49.18900482116207, 53.74950147444203, 54.34941230281707, 53.16143620398737, 55.84059938307732, 52.50400381703531, 49.48093898834721, 47.31726546441355, 45.3819013410999, 47.77804590040638, 49.67331163344845, 51.49993196610482, 54.01314750794442, 56.03170118024273, 55.416159706731, 52.78728523562032, 44.87853573214623, 31.008450369681086, 19.744028852831935, 12.330251086142756, 8.264250582264316, 8.162929877158135, 6.810974680608319, 4.4159793757623245, 2.3834819226495685, 0.08264538141027575, 0.4298579404431005, 10.059080104674063, 39.845609203461684, 42.92032772494901, 40.176645478894635, 42.940892711762466, 51.935848497575336, 59.66476517338907, 40.304416687257834, 6.389877353945087, 0.007838156776532771, 0.02292334252307492, 0.04108146110910081, 0.034295293397360274, 0.08084273055916832, 0.05218404397789029, 0.03239045024759347, 0.09287107705829606, 0.030855888035148386, 0.03821444983083395, 0.016230528370567387, 0.011355199404211055, 0.013839603390454525, 0.04387670527062109, 0.030060847732989542, 0.04295409792253087, 0.03087289518706741, 0.05903453243175342, 0.052552310103971156, 0.12543310801829063, 0.12275074308197345, 0.15579965356136524, 0.17978039660280754, 0.1214340141403579, 0.1268613563790437, 0.13110450288701442, 0.19046217503566898, 0.09419921304910414, 0.1557234431346578, 0.20549916331806492, 0.2282760451517759, 0.10952588981918751, 0.1334704275453283, 0.07024732087889025, 0.1380658212808832, 0.20721777432387878, 0.11979060998607068, 0.18839519320716783, 0.29629624118247344, 14.699398952145732, 42.90479906143681, 61.553578607497684, 54.57194405217325, 37.98592721262286, 38.94863767008628, 40.581932221689534, 43.61095905303956, 13.917765694279826, 0.6930899187441796, 0.313491820087356, 0.6641202732439965, 10.723296230839146, 14.170909581645844, 12.302339499996556, 14.330418648258334, 15.872801484600192, 44.95899531149095, 28.473412721387803, 48.95465497047671, 52.07919543789279, 58.179340054911954, 52.91467989644697, 54.60191096028974, 49.30824487440048, 58.324424605215754, 55.533713140795314, 55.42394953389322, 47.074564887631325, 40.460448572712565, 36.931672557707756, 38.0425387813199, 39.571310012571274, 45.343505259483095, 51.427944706332305, 55.22516381356024, 50.67218634390062, 49.73783462278305, 51.903739975344756, 56.3721432993489, 53.56274174105737, 54.61949886814241, 52.64160448505033, 55.83783803447601, 52.33459272692281, 51.697097747556626, 51.90600318293418, 53.14348743807886, 54.719766416857325, 51.15913683368314, 50.11593149554346, 54.787388078628055, 53.986906851491625, 45.56824138087612, 40.45124669228831, 38.272742686733125, 38.02932823857954, 40.923017609503965, 40.81771373748779, 42.35613792173324, 42.76912819954657, 47.55364710284818, 49.633719228929095, 50.425700679902114, 49.66567477872295, 52.74195832590903, 55.03418753224035, 57.03536902704547, 33.634375218422186, 45.422376278908025, 46.77252277251213, 51.473404976629446, 53.515889029349054, 50.962484882723906, 53.17898096576814, 55.608304854362245, 50.01379689862652, 41.68750324556905, 40.085626879046046, 41.56624709406207, 40.56285773554156, 44.02248236440843, 49.57859031615719, 53.06375741958619, 56.49788664233301, 54.65046205828267, 53.84876097402265, 53.19231702435402, 56.69575452804566, 53.867760935137355, 44.73034858703614, 42.08786741379769, 41.7518340387652, 40.59497410251249, 39.703623325594016, 42.35077211933751, 41.2545951720207, 42.13865426278884, 39.708365471132346, 42.08205053883214, 41.67575182453279, 51.23733712780861, 56.26383881415091, 56.91914527646957, 54.12042825452743, 56.72250509262086, 54.25170606182468, 53.008895227986, 51.02983982332292, 47.194636483346265, 51.64497729270689, 53.03522609895276, 54.401481766854566, 58.39240320267216, 57.918455370010875, 57.90031833033408, 52.9340720945789, 47.317363523667865, 32.451166760536935, 26.160357690626576, 16.99821872095908, 9.645028825729124, 10.947478317445325, 14.92179734091605, 7.398640359601668, 3.504317830647192, 0.34817167047050696, 0.817640493473699, 13.591735343779288, 47.33900323990853, 58.90758691295501, 58.401208923709014, 51.296745346438506, 59.81986745711296, 67.80287527268933, 48.311154842376716, 8.603530699206937, 0.16848102872890813, 0.07246344470449033, 0.16838411860648664, 0.11271596420556308, 0.20480517958921773, 0.10994526167069713, 0.1473005055900543, 0.22516752082494, 0.13027964069718315, 0.10828795302058421, 0.10507366259492214, 0.2628507729499571, 0.14052264993229222, 0.18853914112814013, 0.23527697029133, 0.10327504902717569, 0.09883210678855259, 0.11259259340623695, 0.10362231668325202], [0.05722533918977265, 0.13858440151858714, 0.016808018854428685, 0.02253807690595427, 0.043686838039467414, 0.06310670726722287, 0.07362405258801676, 0.07045283928633699, 0.04424260418501593, 0.024809767003922213, 0.14520962181831562, 0.032290713260731393, 0.07526029382021197, 0.048248711597895434, 0.014554596123015209, 0.06051331578243164, 0.014221534609884746, 0.04480710373290124, 0.02974094665278831, 0.3163714526641754, 6.619141851702045, 26.19696713262989, 50.22898204864995, 44.076764045223115, 33.550048182087565, 21.120370895631854, 31.926422272959066, 41.29013969052223, 9.817133603557464, 0.5349259186656244, 0.08098639502760865, 1.317598665914228, 1.7920582453089378, 4.789982764951644, 7.605639523075474, 6.794918948604215, 4.580396798349196, 16.135568907183988, 25.640867217894524, 43.92355626629245, 52.5158650644364, 53.19616879186323, 52.32275109137259, 53.37496219142791, 53.54448703027541, 52.47129517216837, 49.83436807509392, 47.77202898456205, 36.92009764332926, 35.26591254818824, 33.31680051742062, 34.36053929790374, 35.494865217516505, 39.799650792152654, 47.16188077003726, 50.29579570216518, 50.312775642641135, 50.23210033293694, 49.865433246858665, 47.22493679292741, 45.37237782632151, 44.93966587128178, 45.9810669191422, 47.67994742239676, 49.85124995631557, 52.686645061739036, 49.8562039098432, 49.75216696339269, 47.77273501119306, 50.06117520793792, 53.46538851338049, 49.79273603808496, 45.612230762358635, 42.757588586499615, 35.37878267226681, 36.38660038671186, 37.23906086337182, 37.913453578948975, 36.98554631202452, 37.24878441902899, 36.258923315232806, 36.576839262439364, 37.76809838510329, 40.57335792049285, 43.54160370365266, 46.9996044712682, 47.4076957087363, 53.80679945791922, 31.666965330800704, 45.68740690908125, 51.11808138508951, 48.88482501429897, 48.507343953655614, 52.548228540728175, 52.16950016637003, 50.34956355248728, 45.78244593835647, 38.748753686105054, 37.46499723003757, 36.50102769174884, 36.63194464099023, 38.39387332239459, 38.43068476646177, 43.4836506843567, 46.98060843252367, 49.29042554670765, 51.05837898869669, 49.259438822346354, 52.29121523518717, 49.2068672949268, 43.12553828762424, 39.56983520138649, 40.78272227318057, 39.95996590583555, 44.94553765942974, 46.495364173766106, 48.74112506066599, 48.09802893669375, 44.41793180281117, 39.80154137457571, 36.515297274435724, 38.950155627342966, 46.529680990403705, 51.875020380943056, 52.08162730739963, 53.215753186133604, 51.56269773360222, 51.217913550715295, 46.67540096467542, 48.54262959572577, 46.148799234820956, 45.492739677429206, 47.986653235650834, 53.66125991267543, 54.05193582657845, 56.87977644705004, 50.51980618507632, 47.475552712717366, 30.663626963092437, 24.06694362240453, 12.599013851534936, 7.727792426463097, 7.423694008781065, 8.01330126100971, 2.449589304385647, 4.6184393763542175, 0.17313761756785456, 0.4396445298146817, 7.032932783326796, 34.11717584056239, 36.162656584093654, 21.85794318875959, 39.4141798634683, 47.84587544779624, 49.48294331950527, 37.69145919430641, 3.878163099288941, 0.04846578261124031, 0.07258522970181319, 0.06525799707179109, 0.002285051868379777, 0.036501917732699264, 0.020527496385658463, 0.06780798967567182, 0.010557110072113575, 0.011369441936333335, 0.03851351140427493, 0.014054230583320945, 0.03443315091933455, 0.06567188373376286, 0.04540661732936579, 0.06931559708450111, 0.05625767438041587, 0.0945395399485865, 0.03045957543015961, 0.05490284405588623, 0.07504270186707859, 0.02799064067432717, 0.0529433022283258, 0.011719032754040053, 0.008032277232081058, 0.04962925566360355, 0.04321577057482735, 0.018022285451391534, 0.01785197261450512, 0.061632141230567816, 0.03404678979648217, 0.015787358955299903, 0.09972294447042289, 0.01976271847172851, 0.13719027471398154, 0.05378116876067174, 0.023711633590620854, 0.033776567602950724, 0.02640055815478967, 0.2348934513546767, 9.210563571222368, 32.41985055708116, 55.85163693274222, 52.71516069289177, 39.220858004785356, 24.35599876988319, 36.420936815200314, 46.06861814375847, 12.134421852327163, 0.6138988584280014, 0.018979238436347055, 2.1231755422007654, 5.090344634748274, 9.660144659780688, 12.393819958932939, 9.749425649642944, 8.860257671725366, 17.922238919042773, 29.750760024593724, 45.093556142622425, 53.412789529369725, 54.539404069223714, 53.20023628973192, 52.25319962347708, 54.41818321904829, 55.754730855264974, 51.86804640677668, 50.153409742539935, 40.23913668047997, 37.20811728508242, 36.54116138335198, 36.46497718749508, 37.85139776045276, 41.35840462100121, 50.47769169653616, 51.925136504634736, 50.11040487597066, 50.00481859330208, 51.953055935521284, 49.18253683274793, 48.61367156428676, 49.01669509949223, 48.392544023452274, 49.51775827715474, 51.61540262160763, 54.43361774567635, 49.2073066003861, 50.295897683789654, 48.635326970008116, 52.58920946428853, 54.387216106537856, 51.6554892447687, 48.27335888339628, 42.93675461123067, 36.77437766905754, 37.20980390425652, 39.223478148060465, 38.92109086436611, 38.07931100168536, 38.20422280219294, 37.94434224405597, 36.546527185747706, 40.90325670857584, 42.76244448077294, 46.345698295101045, 48.575440222217196, 50.57178543459985, 55.20035482222035, 34.11476750527659, 44.77429482244676, 51.481481136814246, 50.73050414362262, 50.58603540543587, 55.209580236865634, 54.31302447472849, 53.53439084945187, 47.502158149596184, 40.93207043986167, 37.50344822483678, 38.22485839166949, 38.805231894216234, 40.43651034755092, 41.753544192160334, 46.438634933963904, 48.50515919346964, 53.03914062438473, 53.505494748392415, 49.9718040035617, 54.202754882074174, 51.82750086630545, 43.970118722608014, 40.76125514122748, 42.79727512790311, 43.0313661021571, 45.344627057352376, 49.21572400677589, 50.10141088116554, 49.26334942540815, 44.51533994367046, 41.86190751291091, 37.012810707092285, 42.45324796245944, 48.84155342655797, 55.90490664205244, 53.74474363942301, 55.69659740694108, 53.8892476789413, 53.01751267525458, 47.748451617456254, 49.09886875460225, 47.92030242181594, 48.24873424345448, 51.169201635545306, 56.42610726817962, 57.77037020652526, 59.23991364817466, 51.90186116003221, 46.76004179062382, 31.855796075636345, 18.681672542325913, 12.727492067121691, 9.000413763907648, 7.054453847869751, 7.98880409809851, 2.2431993340292284, 4.764852139257616, 0.11489898537195499, 0.43041887002125867, 9.470299982255506, 41.29675672900292, 46.26672529405164, 32.964485383802845, 43.24314663487096, 54.35958693104406, 57.31441820821455, 42.882096382879446, 5.3027297027649425, 0.07824311077955269, 0.08628566268711321, 0.01258638026493211, 0.061842305961275296, 0.05613858218214685, 0.033238023113940036, 0.026634151769441464, 0.012776636285707356, 0.07868641521781683, 0.014299172832961045, 0.0496531576068411, 0.031057510885500142, 0.025219457419288736, 0.08961747100035991, 0.042581445943083496, 0.04649594073153792, 0.029032332559807167, 0.04189788484044614, 0.06560498893621468, 0.10964314723687787, 0.28414780274033546, 0.13871998375942632, 0.11245548665042847, 0.10052576631067262, 0.11671603867603887, 0.23378616319068019, 0.1576752972698981, 0.10436359868054429, 0.1231411261664283, 0.161236840029878, 0.12637443855525027, 0.19521817144367004, 0.12008832707520455, 0.3082329022788233, 0.14926239547710266, 0.0847665026723858, 0.14920167534822418, 0.06115042897421987, 0.4651203853709083, 10.720793758669208, 39.18596067736226, 65.60860333904144, 59.959476378656205, 45.6664300733997, 30.87786093834908, 43.7615623781758, 51.44994135825865, 13.536647615894196, 0.9584376480310195, 0.15012579188952524, 2.133805900812149, 6.665339527591583, 14.105492291911958, 16.73365289165128, 16.534427865859, 10.873075858239206, 18.323026703250026, 28.43614628238063, 46.375449472858065, 53.42809461778211, 55.61874620376095, 54.23566749019008, 51.6540301230646, 55.13775771664035, 56.27916743678432, 55.975995679055494, 52.70268363337363, 40.94760694811421, 40.08781163923202, 37.88129406590616, 38.28531780550557, 40.06545020687965, 45.60544898433071, 53.3118159540238, 53.81332235951578, 50.52189288600799, 52.14414596557618, 53.80306928388534, 51.65080593478296, 52.20737065038374, 49.3843113991522, 50.949548905895604, 51.8215427860137, 53.913009397445194, 55.837787043663766, 51.408356389691754, 51.11423746232064, 48.92536663240003, 52.95442135103288, 55.74594474607899, 54.77503261258526, 49.78664459720735, 46.07776511100031, 38.086343811404326, 38.963883922946074, 41.63978761242282, 41.668981813615375, 39.74667918297553, 40.572871546591486, 39.42683342964419, 39.36217707972373, 42.383359170729115, 44.86095959140409, 48.628607949902936, 52.090833110194055, 52.70699824056318, 59.578629924405014, 37.99234813259494, 45.9416510212806, 52.085145673444195, 53.59926685210198, 52.08147433496291, 56.97239537392893, 58.989874316800034, 56.63699350049419, 50.989533547432195, 43.55210388860395, 40.17297414041335, 40.26168246423045, 40.81108493189658, 42.48769421731272, 43.37202002925258, 49.68159567925238, 50.43410239681121, 53.69603172425301, 55.8986504616276, 49.759639078570956, 56.34878558497275, 54.927271566083355, 47.51476856970018, 44.643005248039, 46.677926971066384, 45.93399455470424, 48.46480977150702, 52.11129611538303, 53.62978681441277, 52.08274910526892, 47.81268042902793, 44.828607882222826, 39.84249876391503, 44.510197716374556, 50.43470644181775, 57.86940220863589, 54.86928324545584, 57.30288251753777, 55.05987121212868, 55.99821982845184, 49.623681883658136, 54.170967994197724, 50.82170317249914, 50.45869173542146, 52.87731147581532, 59.37973437770721, 60.01004357491771, 60.83856190404585, 52.07450820553688, 50.54572520717498, 33.43774287931381, 26.64262487042335, 16.054424874244198, 17.45401578564798, 15.46098497606093, 13.930377094976365, 7.329584581236686, 7.994730799428879, 0.36853235695631276, 0.7818279667727409, 10.738527774810793, 45.720676452882834, 47.886813225284705, 33.89935878015334, 52.92030849764424, 61.81817777695195, 68.65798334921561, 50.52333239586123, 7.700007336754953, 0.30178023562315975, 0.2531829578501563, 0.16888520139600002, 0.1709544968100325, 0.17458484958737128, 0.10085483937854729, 0.10952852516164703, 0.10065692822418867, 0.10251086100094742, 0.23673406952331144, 0.14618362600524581, 0.15182711995176731, 0.08022062119937713, 0.173696662569719, 0.13761343103983711, 0.2208942823833035, 0.2812681395199991, 0.15336442858942095, 0.15697657911767884], [0.022961888236985094, 0.042585429600289756, 0.021824759033118046, 0.018750264331878676, 0.052658363485768925, 0.03903153239779415, 0.014477126439282251, 0.04479401512071491, 0.0451204068808546, 0.05711043749244944, 0.1435673284915186, 0.05061262144496845, 0.027742138988668882, 0.02875625362409459, 0.06703426385478628, 0.06449002457121689, 0.07242415971573322, 0.0843637089635576, 0.05775156881540053, 0.2187261922705558, 5.384137515098819, 26.797327072389667, 47.71678240068498, 40.813501111922726, 46.01189674869661, 44.63630976215486, 32.6966247635503, 36.25380462215793, 11.520562095026817, 0.7490755016765287, 0.10498721723354633, 3.8020458288731116, 7.870257323788059, 8.218027410968658, 12.128842280757043, 9.42908763885498, 7.555203235918476, 21.603495113311276, 33.72771586141279, 43.8031473467427, 53.75215691904868, 52.07713619355233, 53.87547231489613, 56.1938480407961, 51.43804088715584, 46.38330598031321, 47.02350739509829, 39.444958702210464, 36.800936037494296, 34.45690801066738, 36.16562189594392, 38.004052485189135, 40.61864560650241, 43.759028527044485, 48.15789999500398, 51.2122457258163, 49.320780769471206, 50.1266787898156, 43.4996461099194, 43.83196107802853, 44.45627689361573, 43.61970986089399, 44.370000439305464, 45.36408593577724, 45.39822624575707, 49.719368104011785, 50.497334926359116, 51.23162615683771, 51.77337215792749, 52.53441787535145, 51.490612414575395, 46.81494320592573, 44.25904835424116, 37.43150018876599, 35.9855733379241, 36.1110342702558, 36.846219801133685, 39.04173120375603, 37.5724740951292, 37.65607157061177, 36.78645856918828, 36.58802586217081, 36.76901186666181, 36.814134813124134, 39.53143127502934, 45.11397600173951, 45.67359624370452, 53.419834106199204, 33.65504610923029, 47.93398364897698, 52.58298074045489, 48.23497456888999, 50.74788416585615, 45.95861919464604, 48.67071067133258, 45.578306182738274, 40.44318229921403, 36.98084731255808, 37.44083150740593, 36.078886524323494, 36.414547274189616, 36.24840351843065, 37.237480148192375, 38.126155868653335, 44.17539596557618, 47.506951285946755, 52.735749213926255, 49.538625286471465, 52.80813263308618, 50.01828016773347, 46.49759992476433, 45.684896592170965, 45.33178913977839, 44.780904016187115, 49.392830787166474, 51.86976048254198, 51.10975027084351, 52.912047986061346, 55.51806680617794, 47.712981623988, 41.251837745789565, 34.09467712525399, 38.219523968235144, 45.375613781713675, 51.42898805679814, 52.841700277020855, 51.962147989580714, 50.26482858965474, 49.84164799413374, 45.55412869299612, 44.98305905249811, 43.31560850143433, 47.667670403757405, 51.413859475043516, 51.936578058427386, 56.59622046255297, 54.68510050927439, 48.3619652255889, 31.504020267917266, 17.473511926589474, 11.26349485689594, 8.366173371191948, 6.84464430616748, 3.3867641514347446, 3.7463253736495976, 5.810676149783596, 0.09687085275448139, 0.12709571799683955, 7.020286571594977, 31.16712397144687, 30.850176849672874, 30.589962890071256, 41.08927119162775, 46.25117701868857, 51.23580348107123, 35.459658022849794, 4.4875234077053685, 0.04104155558912505, 0.06750540792821877, 0.039256306425217664, 0.04131617512734186, 0.029505319074697556, 0.03241375464225008, 0.017640419349434878, 0.0652077800083545, 0.07856295248793979, 0.027599702176127224, 0.024408080292144613, 0.06113106227149406, 0.05800820443959487, 0.01380906425296299, 0.08447411755520491, 0.030921740953119534, 0.021669854139608723, 0.051343170550441554, 0.044647631040143396, 0.013684284809466093, 0.05791537373537018, 0.028147267350446314, 0.007957301643346588, 0.012590137926200706, 0.06773102848279862, 0.026816919280756867, 0.0017189015207188807, 0.03365754052215526, 0.06442100771011845, 0.06421936187712897, 0.015473134586617593, 0.007723409254404326, 0.04787286120136419, 0.056486137121194796, 0.004915730049458123, 0.030427713833388784, 0.06407546375187174, 0.030087837010561943, 0.3314010865024982, 6.785104688136809, 34.10285134469309, 56.565018007832194, 46.22322228647048, 51.04854560667469, 46.45239853089856, 40.43068562784503, 43.77098783369988, 13.294096089178517, 1.0349231309467748, 0.19089798713403364, 1.668121031215114, 1.7453059217622204, 8.465961410153298, 12.359136400684235, 9.413566820083126, 9.027826228449422, 15.198580372718075, 30.98127030557202, 44.74427300114786, 53.893895687595496, 53.65396038178475, 53.69592189788819, 55.851107412768954, 55.139781659649266, 49.52996469313099, 49.9190559694844, 42.077033827381754, 37.15621256059216, 36.443596347685784, 38.119366245885054, 39.45686309568344, 41.4188640348373, 44.91500200763826, 50.07353851872106, 52.26622581481934, 49.573801102176795, 51.64950370788575, 47.53819296436925, 47.06413138297297, 47.44448361858245, 45.89400991316765, 45.76464622251449, 46.769416255335656, 49.49038013335198, 51.30469206840762, 52.30370798418599, 53.578819536393695, 52.46221880758963, 53.684060650487105, 51.80357833062449, 49.29313590449672, 46.371456500022646, 39.569972484342514, 38.11283157717797, 38.282940849181145, 39.29893670543548, 41.2753523549726, 38.59187849106328, 39.08852507991176, 38.10550458969609, 38.31880307966663, 38.304529574609575, 38.38738572212958, 41.749276653412856, 47.81117816125193, 47.93151647813859, 55.27749999876946, 35.273600393725985, 49.698830573789536, 55.3251842529543, 50.52380308028191, 53.2069121637652, 49.14953793248823, 51.11284109853929, 48.61128284085182, 42.95224405104115, 38.71995564429991, 39.563677080215946, 38.457121541423184, 38.96990476116058, 39.652550143580285, 40.04315153245003, 40.28292602108371, 47.08422176299557, 50.12932246731174, 55.09890271771339, 50.891266407505164, 53.50400032535676, 52.73402337105044, 48.60014330956244, 46.67290633724582, 46.59656132421186, 48.95973443984986, 50.87525921483194, 54.498450602254565, 54.095729089552364, 56.22323836049726, 56.488998551522535, 47.943707204634144, 41.76675081253052, 37.004914975935414, 41.58334862801337, 49.57098484039307, 55.009009838104255, 55.50591138101394, 54.48672663780951, 52.360817693894916, 51.13466516617806, 49.67022472812284, 47.314441357889486, 46.70854499263149, 48.70875373963387, 53.600839722541075, 56.08986208515783, 59.14249374020485, 54.17397252974972, 49.488689591807706, 35.49023682071317, 17.841808757474347, 11.371323754710536, 9.1067119567625, 11.893453982568557, 6.459225839184177, 3.289120178068838, 5.652455091476441, 0.09822372572436448, 0.45753669714735407, 7.980465629408437, 36.313946324010054, 38.611188319421586, 33.02278357167398, 48.572659261765025, 55.44815055785641, 59.41549854893839, 40.518707536881976, 6.23197449791816, 0.015727043895411397, 0.05312142916203988, 0.03945006538302668, 0.02474146643503299, 0.02760040123135813, 0.0138639391309792, 0.07058020140374861, 0.0801345665428427, 0.034232665709550344, 0.03654779107760518, 0.04248563132639374, 0.036517266304262226, 0.0867080529250445, 0.02535202701936566, 0.10733334617989679, 0.060248835417892666, 0.0394036787592115, 0.07562654513505197, 0.047442212535609166, 0.164257999689829, 0.19477880469733672, 0.11044252168146834, 0.12751980894996276, 0.17347863394646876, 0.16659383241447712, 0.1630021670773145, 0.06906929215596569, 0.08907241476399284, 0.1479425332358768, 0.19954613920661712, 0.2761002329568709, 0.14562626639681478, 0.23929853352808186, 0.2536664665826867, 0.11943250984674501, 0.13437505480983566, 0.3043598375253139, 0.10800819303239546, 0.5641906612342404, 9.185358420495065, 39.821114001735566, 61.89327155390094, 51.58596915583457, 53.899210499178984, 53.0368499602041, 44.11508560180665, 46.99373268312024, 15.736210826904545, 1.2873591530707575, 0.4374463784117853, 5.465035909606565, 13.984622493866953, 14.929320446906553, 19.559838271910145, 19.904220411854407, 12.88618233896071, 25.285816231081565, 36.197812787948116, 47.02225223664315, 54.92556925742857, 54.722119838960715, 54.56053779971216, 56.88188275983257, 55.86468665830551, 50.43195293795679, 51.45518164480887, 43.7724155764426, 39.70854590016027, 37.64230797367711, 41.8971735431302, 42.46871386804889, 44.56064724153088, 47.48206776957358, 53.32350853950747, 53.903968334198005, 49.041260903881444, 53.146507663111535, 48.53019175990936, 49.25732466482347, 49.937871579200994, 48.801054954528816, 48.84358521430723, 49.44399810606434, 51.36961513949979, 54.09219503402711, 54.8400458981914, 53.16293847176337, 55.29391904031077, 54.42880499747492, 55.8284871039852, 51.112386103599306, 49.14238352929392, 41.50351662789622, 39.33023721941056, 40.79767042590726, 41.18167831051735, 42.52187375099429, 40.053859603020456, 41.22405167548887, 40.11054961912094, 40.2495191943261, 40.93648310630552, 39.389653282780806, 43.832090516244214, 50.832772101125414, 50.66554184882872, 57.76616150333036, 38.61735820770264, 50.689382014736054, 56.85102547368696, 55.129599186681936, 54.50030980571624, 50.4676974973371, 53.10485209188154, 51.81615737176711, 43.11179038017027, 40.65752806202058, 40.54236335139121, 39.306769678669596, 41.41886795720747, 40.68286265096357, 42.442296704938336, 42.16891534866826, 47.84080774553361, 53.25585157640519, 58.4911802507216, 51.260126098509765, 53.8649211391326, 55.79875161570888, 50.179065965837054, 50.01727211859919, 48.63825698052683, 51.42374384787775, 54.51644643660515, 56.52131495937225, 56.76082664920438, 55.987794168533824, 59.69591663729761, 51.43952354308098, 44.961113391384, 39.12046101785476, 43.050577871261105, 50.92664618645945, 57.570113597377656, 57.38021204548498, 56.12142147556428, 55.143056838743156, 55.112929113449596, 51.16516551663799, 49.370739998355994, 49.85323075325259, 53.14167138068907, 57.138833307450824, 57.53996233786307, 60.489329753383515, 56.66901573058098, 52.14152582230107, 36.874927628424864, 21.517877617189964, 13.945888107822789, 17.423144771206765, 15.547547763393773, 10.556464099114942, 7.925708361210362, 8.2267350727512, 0.22591310823636673, 0.5907750153733838, 9.65559078801063, 42.64070980010494, 43.205166324492424, 42.89329867209158, 53.97407677865798, 62.10889993175384, 67.8895753429782, 47.41869795706965, 7.796540298769552, 0.1399182372035519, 0.23251856346764874, 0.15298918340234988, 0.154591440974224, 0.15613189057236718, 0.07991883618336532, 0.10651421432773914, 0.178566652860853, 0.13408599451424616, 0.09685040586778233, 0.20211400464177134, 0.10698628536756001, 0.1366779763972567, 0.2454943768680096, 0.18310376262712866, 0.13794206743759496, 0.1986119715917495, 0.14165984616885263, 0.15143371848089082], [0.022074733522810766, 0.044384636886177525, 0.09593320710043754, 0.09252538754334373, 0.0441450773618154, 0.004246254430918564, 0.05909288534894586, 0.0193239837479327, 0.01866366192247839, 0.06321922643110156, 0.07289266078582696, 0.03542045439263025, 0.02508325081679129, 0.03511133025430384, 0.05998184228496206, 0.05440639226787514, 0.030061956645259937, 0.0918186178070403, 0.07034317379997623, 0.23345688327906594, 6.8189557233164395, 23.098104461546868, 43.38375968317832, 45.223468965099705, 31.03998818705159, 20.65503070431371, 30.709575568476033, 42.38386515648135, 15.118884674964415, 0.976576648892895, 0.8051584084187785, 3.2824514133314935, 0.32619383366357896, 6.791193677533058, 14.201810994455892, 5.338218327491514, 7.221208022486779, 16.763292281858384, 31.932839270560976, 46.58059335524037, 49.83519569520028, 53.97798738171978, 55.86278038640177, 53.43464889834004, 50.1120993398851, 47.23160089985017, 40.45820889934417, 36.6657829284668, 35.18790052783105, 37.89577937895252, 43.489502860653786, 47.746078583502005, 47.41884700713619, 48.13654268941572, 53.41069498369771, 46.81643762896138, 49.153981977893466, 47.09600064062303, 43.83804859653596, 42.60195678280246, 40.49661282570132, 36.47879177524198, 38.62193169132356, 41.50614461591167, 43.70264445581744, 47.79288422676825, 46.37129176047541, 49.8611774752217, 50.447811080563454, 47.03722784596105, 46.986507677262836, 42.398797619727354, 37.89399862289429, 35.79992363529821, 37.05663534902757, 36.39137391121157, 36.06561322366038, 35.3387862636197, 36.68044867054109, 37.874551511579945, 36.60746120637463, 37.24034347841817, 36.53984346697408, 39.48369210766208, 40.640136272676536, 46.42475758829425, 46.49740380625571, 53.46886373335316, 32.556704013578354, 46.89785818899832, 50.75338725120791, 45.63293303212812, 45.058752952083466, 43.21138720358572, 42.296357077936975, 39.11782126272879, 38.78445902178365, 38.419913937968595, 37.86382382915866, 37.4928186016698, 37.61127025850358, 34.458445579774924, 36.57696870065505, 36.956524695119555, 39.67196195356308, 46.85341381257581, 49.197967437005815, 53.46403529567104, 50.655288773198286, 51.012479412940245, 50.90874841136318, 48.92103633572979, 51.82846184699766, 49.446080884625836, 50.95288292054207, 50.12464307969617, 52.801280252395145, 51.68358125994283, 53.83596228015039, 54.158412487276145, 48.355748268865774, 40.60381512488089, 36.94862896396268, 35.316032594250096, 41.237360277483546, 45.57257167754635, 48.56493219252556, 50.55728835444297, 47.78120733076527, 45.919054246717884, 43.871004350723766, 40.80233412404215, 45.8593322384742, 51.13751280692316, 53.53885450670796, 55.36481195880521, 55.787278682954856, 48.819654833885934, 36.86072080366073, 15.201479004275415, 13.716880525312117, 5.042176948439691, 8.098140166651818, 5.721572156875364, 3.619880661849053, 5.497385657602742, 0.16069293292539735, 0.39573344251801895, 7.334774367270931, 35.538991881955056, 42.072366206876694, 31.579145423827637, 34.47817510174167, 47.882377024619814, 50.59357812327724, 27.530045432429162, 2.7887027205959445, 0.08354108375046523, 0.02703587870083509, 0.01837287984427906, 0.06499552002717411, 0.06187076612766232, 0.006661794294843511, 0.05082272871908161, 0.0389632624724219, 0.003483616775127068, 0.031035669718778906, 0.014958042921798845, 0.039282889676190196, 0.0689574356581415, 0.028853112035581184, 0.002569714340478963, 0.01826198478679984, 0.015239729621117155, 0.015117619994036375, 0.039797876961529255, 0.035773165103408604, 0.03956582509882508, 0.06099097926409976, 0.061511980339644425, 0.021492476056840633, 0.011683414453610538, 0.02847865400385232, 0.04391007989104237, 0.05328433775913812, 0.03494967421096179, 0.03863422770894343, 0.028833502099939415, 0.04515501107239435, 0.013830047401209033, 0.013728712163414928, 0.05485354246751917, 0.043002729183964195, 0.10251088398358515, 0.019248663898437254, 0.29920808009562955, 8.342231223660132, 28.8271693260439, 52.9447409414476, 49.69839519070041, 37.89055085951282, 26.90383315086365, 34.08181959582914, 45.8802306267523, 17.253192394010483, 0.9293069402056356, 1.0050485211033975, 1.1897254759265532, 2.2916893901363498, 9.44446038815283, 12.082488690653156, 7.711474876249991, 11.119074167743808, 17.702403799180065, 32.69303579484263, 48.31946242240168, 49.949670068679325, 53.91802610889558, 54.89463352387952, 55.47780759872929, 51.15300224673364, 49.329912047232355, 42.86891329673029, 39.0409977205338, 38.821811752934615, 39.62733714811264, 44.53445365352016, 49.49960947036744, 48.71935982857981, 51.315788453625096, 54.38899294022591, 48.260454285529356, 49.33298326307728, 50.595939390120975, 46.409503490694114, 45.736350244091405, 43.43846105760144, 40.529529356187396, 40.32640549444383, 44.51978791144587, 47.3489111469638, 50.14267029300813, 48.49769884540189, 51.77020680519843, 51.053483870721635, 49.58656057234734, 49.91040322088426, 44.942623338391705, 40.045300991304465, 37.258049057376006, 38.3745321150749, 37.97841979611305, 37.75786884369389, 38.03538830049577, 38.3138059800671, 37.808600779502626, 37.22481481490597, 39.18984774620303, 37.76956535154773, 39.26650654885077, 42.31677693705405, 49.52776424346432, 49.061637616926625, 54.734942067054014, 34.40698016074396, 49.94468473619031, 52.82698354413433, 48.540946898921845, 47.11934266551849, 45.43996026439052, 45.18954830784952, 42.13719514108474, 41.05898264915713, 39.81087269321565, 37.80776923702609, 39.23238192835162, 38.55705961104363, 37.67165122493621, 38.453054043554495, 37.421105907809356, 42.64664826854583, 48.83509328288417, 51.26235792713781, 54.59381911062426, 51.05447230800506, 51.44873719061575, 54.511017876286665, 51.23166145816926, 53.29443593179026, 53.02883263557188, 52.74306051192745, 50.81137164946526, 53.16240110704976, 51.39124308862994, 55.21731907321561, 57.082021697875, 50.82418603281821, 41.918005251115375, 38.468312063524806, 39.07548712145898, 44.57483053207398, 49.39809460793772, 52.14129832483108, 55.39815602764007, 50.73380285693754, 49.82850413168631, 45.7953623033339, 43.911942128212225, 48.472505461785104, 54.46982122236683, 55.00586017485588, 59.91562428012971, 56.24964767886747, 49.96199807813091, 35.5025452183139, 18.25454996478173, 8.406131536729875, 11.463748524265906, 11.652986215006921, 4.864899544946609, 4.864944652203591, 6.2155981121524695, 0.10029282961641589, 0.5284747841858095, 8.37142542485268, 39.33469695429648, 41.625800440388346, 35.79838214382049, 40.37092047352945, 54.978364359947946, 60.39836606671734, 35.70989739510321, 4.549778776784097, 0.08174843034676968, 0.03432205667899501, 0.05586089829223291, 0.06932407001694364, 0.04293121104579299, 0.03545533054538312, 0.07742827668065026, 0.07497820492473341, 0.012136538223844143, 0.053077509341340874, 0.030078483077006477, 0.06978589846121688, 0.012812805211832447, 0.02131943211650416, 0.07147639404020964, 0.022801015518545624, 0.0407097322656022, 0.044307380749453465, 0.011250375593531758, 0.11674886554359429, 0.12866523297082993, 0.2048723808219356, 0.2792302230673452, 0.13620880883066885, 0.1586622943080241, 0.20213999034416294, 0.10303216085078255, 0.11112779499061647, 0.20321075143592976, 0.217760308615623, 0.09289586766352577, 0.1507494487469235, 0.19165184829504261, 0.12036979543946444, 0.2108531832815178, 0.20464862186101176, 0.10985081835139184, 0.21264173811481846, 0.42776976862261373, 10.719640581838547, 35.20331544260825, 58.507214899986025, 57.0586286821673, 42.49340518828362, 31.13207563277214, 43.967828058427386, 53.06676587750835, 19.33605136409883, 1.6769208686967052, 1.156068965792656, 4.450902198591541, 2.9883972050682193, 17.23124869408146, 25.703093659493234, 9.663612035013015, 17.515630337499804, 19.225379728501846, 33.48534476372504, 47.31119363538681, 49.61183632573774, 54.52416566110427, 56.168183972758634, 58.75472038022934, 53.25852663286271, 51.70222820774202, 45.91777947641189, 40.82723332989601, 40.951505784065496, 44.13648997583697, 49.2743516737415, 52.09235891219109, 52.3128745632787, 53.634372065144206, 57.35777608809933, 47.83692067669284, 50.13430779980075, 52.88644667594664, 48.76874246904927, 48.10375559714533, 46.900203766361365, 41.76585258976106, 41.21942327868554, 46.71465604535995, 48.84105136317592, 53.379951446287095, 49.825479984283454, 54.093395279299834, 55.10125221744661, 50.24890768912531, 50.8999740692877, 47.52431169632943, 42.12571828596054, 39.16509759041571, 40.77736431552518, 39.8332655045294, 39.57818592748335, 38.533278280688876, 38.44952783276958, 40.599920211299775, 39.52806588142149, 42.88006067276002, 39.39325009622882, 42.92113573320451, 45.065581798553474, 52.13764659820065, 52.19243034239739, 58.22486308313186, 39.96492770410354, 50.848387056781405, 56.19612693786622, 50.77947493522398, 48.466068852332334, 47.510642236278905, 48.046339942562966, 43.7687167813701, 43.463725043881325, 41.365104029255534, 40.10354034362301, 41.14626715260167, 40.059103811940844, 38.96382508739349, 39.786852098280384, 40.63919882620535, 44.47061315659554, 51.24620952913838, 55.163794409844186, 57.657009786175145, 51.938594156695956, 53.30694829263995, 55.71118470161192, 53.82278703874158, 56.79878342536188, 55.304140736979825, 54.87178571762578, 52.51122490052254, 55.10657487377044, 52.98612979150588, 55.196385383605964, 60.8197815956608, 53.23230558826078, 44.73636942525064, 40.98306517447195, 40.30376165143905, 46.30104211068923, 50.16239981497488, 54.32546623291508, 57.3807337207179, 51.978496428458925, 52.87822538806547, 47.86660909652711, 46.44194933675951, 51.01665281480359, 56.798195069836034, 57.37252027757707, 61.144192987872714, 57.65560557765346, 53.113951990681315, 39.2015834777586, 18.883545167984504, 17.558597941552442, 12.502865772093497, 15.324015809643655, 11.728759542588266, 9.20206771742913, 6.430750412325706, 0.2502221199533632, 0.787676343273732, 10.615567353463943, 46.52188724087131, 54.287097607889486, 41.8712035302193, 47.94064775589974, 61.89153786628478, 68.95547943730509, 41.092899384037146, 6.651783325979787, 0.2220576941486328, 0.11671631446769161, 0.22986457442804692, 0.15385018962044872, 0.14875420339165196, 0.10400337647766837, 0.13363089232194808, 0.1418804794910454, 0.13016956918422254, 0.10147167039254021, 0.13835561702088003, 0.15733507762272514, 0.19786676722428492, 0.18218139276629497, 0.17101507904308458, 0.1305150288727976, 0.11390912316499219, 0.07129438687115908, 0.10707944165915252], [0.0895865057264605, 0.04474671302183021, 0.08961607672033772, 0.036738907032075434, 0.03507643877979248, 0.025489018861985496, 0.005271964285883212, 0.09683034202504544, 0.0533140619706002, 0.01965958196970244, 0.05357630918883989, 0.03872309773859959, 0.028551914992051262, 0.06684216730777295, 0.026107173292867603, 0.10527600939836233, 0.024706308744967948, 0.03325652413731141, 0.02025989421282805, 0.06128863889663931, 2.760442533800679, 21.132098782447077, 44.11510913602768, 49.58766275836576, 44.94894227673931, 35.19021472623272, 34.46160701013381, 42.10460808969314, 18.26569930199654, 1.5214842029156224, 0.17909994198670312, 0.996050174918867, 1.329847247369828, 8.082279572563788, 6.108546824224534, 8.072775669636266, 8.80272924900055, 14.018009708773706, 35.019956404163, 47.773641078702866, 51.026007667664565, 56.585700665750814, 53.34212018597511, 51.575578797248106, 48.00473143977504, 43.1784628283593, 37.452680987696496, 36.43572807312012, 36.2166166305542, 44.61284222141389, 48.57383989518689, 49.0792961274424, 48.84285565345518, 50.71798786040276, 49.316415171469416, 50.322530577259684, 46.685838391703946, 47.17642099626603, 43.22466050424884, 43.011103137846916, 35.82129270799699, 36.132756356270086, 35.1049227868357, 37.14616737058086, 36.62860278160342, 40.22916993787212, 42.191935739209576, 45.30827060822518, 42.858048331352975, 41.903563084140906, 38.75637092897969, 36.7363699020878, 37.107069184703214, 36.27013737155546, 35.217694851659964, 36.02462445535968, 35.96603208972562, 37.83337446951097, 36.529237378028135, 39.0494151269236, 42.5177199609818, 44.162589426963564, 41.625906344383, 44.63514874058385, 44.29564799031904, 46.037788314204064, 46.22235936503257, 52.45790812277025, 33.06381940841675, 46.38260387605237, 51.09913241478705, 44.51508106723909, 40.88175035292103, 39.14727434035271, 37.26811778160834, 35.85345614340998, 36.62353900171096, 36.10491929515716, 36.65461594058622, 39.253574494392645, 36.31133402547529, 37.59188982748216, 36.83500574481103, 38.40212598923714, 37.63703238579535, 46.3296244221349, 50.491004220901004, 51.80357048588415, 52.48729844247141, 50.632456656425234, 50.66725592459402, 50.09719041086013, 50.95276132706673, 50.18978580351799, 51.57363330164264, 53.20686901769331, 52.07197435440556, 49.5466386887335, 51.3887131598688, 51.35890706892937, 54.714043678775916, 51.44517960086946, 44.68045211607411, 40.02051161181542, 33.55751245252548, 34.76291956440095, 38.880325671165224, 41.91789542475055, 43.776604667786636, 39.27790495657152, 39.12672112064977, 41.092158056074574, 45.642585985122196, 48.991446802693034, 54.104001368245775, 56.60903876827609, 57.244643165219216, 49.234586684934555, 37.223536122229795, 18.85904996625839, 5.84305678644488, 9.322546259049448, 13.093037355330683, 4.10202820935557, 3.762155324220658, 8.051675279294292, 0.03702578397708074, 0.427276561216962, 7.632936277697164, 32.74531902805452, 42.86207268314977, 41.750924048885224, 39.73868539256435, 53.33822135002383, 43.723801720526914, 27.03074339897402, 3.5099952163234835, 0.022053020675816846, 0.023600296117365364, 0.06036131244693553, 0.00933130236057144, 0.026685449016851284, 0.03294152410460576, 0.04504812265475912, 0.056150054348812956, 0.024697378074990648, 0.02398355841456402, 0.04022377588215374, 0.03260288259855682, 0.05972687673244265, 0.0351561923631497, 0.06381522751443329, 0.04714075310696517, 0.024927053149909745, 0.048231585702348145, 0.014550183456571353, 0.08185881595577925, 0.02055026643398789, 0.04910669559913297, 0.04346372642283959, 0.06283180810691369, 0.031547592652420846, 0.08630321376145848, 0.038576556610003594, 0.055808501708651745, 0.01136224837072434, 0.024464740155024395, 0.07149553091655816, 0.03789406420002061, 0.008258512093415184, 0.07653289609738896, 0.0734562180455654, 0.04139483320496736, 0.034639048540303786, 0.015711249077632543, 0.10523744453225406, 3.9815246626254055, 26.41025189430483, 51.746605903871604, 54.56330307068364, 45.51081003681306, 37.29368771276167, 41.65575165902415, 46.94405194251768, 20.083149133190034, 1.5242926199590008, 0.41624559990821347, 0.7168061009818508, 1.641606544294665, 4.978297718109624, 8.455598508158038, 10.729863259100146, 10.972248085083502, 16.125640407685314, 32.9610925336038, 48.82825659167383, 52.04567878477035, 56.15185514573128, 54.59712959104969, 53.71929922411519, 49.035161618263494, 46.486126992010306, 39.28117229092506, 37.0448721608808, 37.70225355702062, 46.72297931486561, 50.461680581492764, 51.14520457483108, 50.45314550399781, 52.83973516956453, 51.128342305460286, 49.90490405790268, 47.765972845015995, 49.835682069101644, 44.97678718259258, 45.79029852344144, 37.91010779719199, 38.182708601797785, 37.62022895197715, 38.61759747228315, 38.66231249224755, 43.50227802030502, 45.80679209001603, 47.643516448236284, 46.189984121630275, 46.13053667929865, 42.49275407483501, 38.49305437457177, 38.09600068676857, 37.7597947274485, 37.02811187313449, 37.555670661311, 37.72159476434031, 38.5080260615195, 38.40127483490975, 39.96184079877792, 42.838365877828295, 45.137839701867875, 43.52973853388141, 47.07035226206626, 46.015375891039454, 48.13067482363794, 48.56000177321896, 55.10671607909664, 35.126931205872566, 49.599257284595126, 51.42367324521465, 46.84835395505352, 42.978476862753595, 40.960240902439246, 39.68454099470569, 37.02346778685047, 38.051187607549856, 37.81078946205878, 38.33472005782589, 40.707828537110366, 39.40644494948849, 39.152204759659305, 39.07173341320407, 39.25108378933322, 39.71486483850787, 49.509799788075114, 53.5181208579771, 52.38339877897694, 52.38293986166678, 49.888967467892556, 52.63503843738187, 52.61792513632005, 51.47211059447258, 49.92200951422415, 52.71692968183949, 52.654913087044996, 52.856817091664965, 49.543014418694284, 51.26371506721743, 53.49617127449282, 56.13729530765165, 53.46612199660271, 46.684143927789506, 40.15442132949829, 36.64767726775139, 37.58468835584579, 43.114740002539854, 44.96318440283499, 45.74325361559468, 41.91871127774639, 42.9500828250762, 43.10549497604371, 47.61280428978705, 51.89547946376186, 57.59889594970211, 58.32433046833162, 57.85956490424372, 51.01202441800026, 39.63210675024217, 19.28136371797131, 9.877486132806348, 7.09365499596442, 9.364440114267412, 7.605919972542794, 6.793076415215769, 9.09413879917514, 0.03863991208134159, 0.4663279544441931, 8.412345551675367, 37.85912090732206, 42.90366157408684, 42.244974028679636, 45.302873426868075, 58.99868788257722, 54.446534110653786, 32.12493342737998, 4.3189639622165314, 0.04965362492047491, 0.02885555777127945, 0.08132567238663474, 0.02074304479925383, 0.0843747865949427, 0.06536496592865837, 0.0451410950852498, 0.05935652301676812, 0.04131498769105923, 0.01769906721047817, 0.07561185922954353, 0.0453852856111142, 0.028797953705032988, 0.020909358657175497, 0.029059304600401275, 0.052398640527239734, 0.045368803229423306, 0.07732130782378298, 0.030030263587832454, 0.17051911372090542, 0.1696969481605676, 0.18947779801824402, 0.20001688491432898, 0.11034410236583603, 0.11879911601182916, 0.3072209614178827, 0.16100235583801425, 0.12137944569751141, 0.09481443527845607, 0.16755352607898175, 0.18786178150724983, 0.13749392132364935, 0.12129086295082686, 0.14557927456353942, 0.1870235587440191, 0.0733880285594252, 0.09778604437146457, 0.08510954918399935, 0.47575169393131816, 4.875711068030327, 31.348617922875192, 58.902605502836174, 60.653453488503736, 56.737574838822894, 47.227313749251834, 45.85879879613077, 53.124805188948116, 23.68017831156331, 2.055852961155676, 0.503965609015957, 1.8804318193466434, 3.7319388553019497, 14.339885288669219, 13.120725366377062, 18.509849194557436, 16.18829732941043, 17.537466172249086, 38.521464101729855, 49.41690629528415, 52.986745603622936, 56.3232901788527, 55.65561648338072, 55.479105903256325, 51.83243520798222, 47.57413364225819, 42.07426855641027, 40.40767308204405, 39.26020329998386, 49.45393739208099, 53.78070785153297, 54.08028279581378, 52.18345595944313, 53.797464216909106, 51.118767799869666, 50.823409403524096, 49.74925656472483, 51.33754976334111, 47.995153011814246, 47.70923968284361, 40.543885231018066, 41.111856199079945, 39.02175065009825, 40.44587304515224, 40.54414410744944, 43.34605001634167, 46.213679159841234, 49.347798055218114, 47.39798784255982, 47.19828428760652, 42.848458136281664, 39.53641268514818, 42.187048465974875, 39.57562461976082, 38.40565612239223, 39.949563780138575, 39.688082894971295, 41.4383307580025, 39.35189654750209, 43.82357897297029, 47.13372991931054, 48.947802589785674, 46.09954211019701, 49.61552335369972, 49.201568172824004, 50.238721293787805, 51.13291578908121, 56.13005461231355, 37.599157979411466, 51.3864891759811, 54.397594698013805, 49.6308990447752, 44.41899084275769, 44.61445039318454, 41.10288181612569, 39.36132984776651, 41.02794101161342, 39.42285614628946, 40.017346259086366, 42.67847045775383, 40.92107995863884, 41.797506117051654, 41.67508502160349, 41.78193822983773, 41.519155117773245, 52.09332381525348, 56.51132468254336, 56.19348718274025, 54.96347112040366, 51.87074499745523, 53.575128586061545, 54.16578262082992, 52.16807634599748, 50.09914767357611, 52.99682609496578, 55.060157545151256, 53.2424331480457, 51.80275855525848, 53.145421166573804, 53.463580300731046, 59.020504105475645, 56.932493102165964, 49.805817142609634, 45.007303222533196, 37.888421012509255, 37.73134185421852, 44.20149149433259, 46.1550122691739, 48.96203687114101, 43.494531339214696, 44.38395231000839, 45.65143877460111, 49.85955361397036, 54.57340709624752, 60.56398814724338, 60.50989474019697, 60.237501821210316, 51.55146798779888, 42.71805109516267, 21.90748468522103, 9.090781250307638, 14.551385371915757, 22.346854863628266, 9.4246220204138, 7.748433409198639, 10.419965617118343, 0.14298701688887613, 0.6321889318285451, 11.128224076763278, 44.69075618251678, 55.1882190089072, 53.02906405541205, 52.774341414051676, 66.34238073902746, 63.56481313705445, 39.552055097395375, 7.120412424687417, 0.20257670642627826, 0.09139519335041124, 0.21556535946025004, 0.12531552884367206, 0.24280292612891047, 0.12201560510983392, 0.19822509718998788, 0.2411758013430142, 0.0948427192446205, 0.11889504554170756, 0.09821069456877247, 0.06707708050887431, 0.21200939382035888, 0.09206923581058941, 0.11427475394861353, 0.09092399565082404, 0.10732262860983612, 0.17489333787272054, 0.08422213591515057], [0.02250884873642316, 0.02247036239432712, 0.07420240300557307, 0.003304145835910834, 0.03787933615967631, 0.062206607582348014, 0.11626036191779761, 0.031174678287859407, 0.0059466382897939655, 0.05931752914142224, 0.01893399711397867, 0.06682310704021685, 0.03826370545392556, 0.039956725292628816, 0.042782750866946676, 0.09579812281674917, 0.013354377663363854, 0.0608921769045053, 0.042085664482006145, 0.037408705365153096, 2.394084334373474, 14.241644624740848, 41.69496359363679, 48.79821908089423, 41.33458798931491, 18.32049677448888, 26.62403479699166, 39.98202139331449, 21.37102603912354, 1.795644885109317, 0.2090575651175553, 1.4107473579145249, 2.6609307767883426, 3.527272031191857, 8.57867169764734, 7.388203913165678, 9.70707287711482, 20.289901187342984, 31.05237307087068, 44.502780514378706, 51.25678423912295, 55.14218999493507, 51.11216645086966, 50.043697126450084, 43.352027708484286, 37.88344352476059, 35.80852931545627, 37.06669622851957, 41.2784549497789, 49.01493395528486, 51.00918854436567, 47.40148659675352, 50.12065402923092, 48.28972693412535, 48.97911879324144, 46.40566349029542, 49.108486406264774, 49.1815915415364, 43.45531155986171, 42.001657639780355, 37.05397990442092, 34.778087369857296, 34.954872515893754, 35.05625009536743, 37.024558205758375, 34.42829432026033, 36.95569707501319, 39.62017490017799, 35.108248956741825, 35.502749181562855, 35.505086914185554, 35.42396053191155, 35.586256442531464, 38.44263230600665, 35.94138783793296, 36.655427871211884, 36.74614052618704, 37.33222499970467, 39.99138409091581, 46.293691588986306, 46.85672821537141, 48.20043809952275, 47.013611255153535, 48.75133106785436, 47.93709801089379, 50.65487300196002, 52.02261524815714, 51.177979899990945, 28.99419757627672, 46.79868105919131, 49.262341376273866, 43.93313469425325, 38.74786723044611, 35.956743917157574, 36.22985462988577, 36.00897419837214, 36.11461147185295, 38.272974106573294, 35.882540518237704, 35.446070932572894, 36.09931815055109, 36.05109653165264, 37.06790431853264, 37.99513693778746, 37.39610079796084, 41.20090969147221, 48.40540547524729, 51.88625404911657, 52.42241067271079, 52.48439981091408, 48.0394640276509, 51.44103757796749, 50.958354626932454, 52.075535866522024, 49.1622660236974, 50.77043779434697, 48.60574445416851, 50.283091145177046, 50.40934047391338, 48.96023258086174, 51.61189994504375, 51.99685312086537, 52.68990455135223, 50.19082130924348, 42.74370339608962, 35.820767110393895, 35.20193869067777, 37.30183447560957, 40.004778985054266, 40.845750839479514, 38.56430815112206, 40.594213162699056, 45.536011265170195, 50.13338604281026, 51.99371130235734, 56.47144594500142, 56.94695488099129, 48.851406420430834, 36.29808818140338, 19.49538196286848, 7.835016298678614, 9.84577278937063, 8.586612536061196, 5.158508564195325, 4.294343244644904, 6.45918220281601, 0.03225538894654282, 0.36480739232032533, 7.84939717861914, 36.97126103985694, 46.73052595507714, 28.900476463379402, 32.93840946689729, 49.931058422211684, 50.20627544772241, 28.58128378468175, 2.421605154391258, 0.06228425825435308, 0.025734647717927734, 0.0274057095615013, 0.10972120393548282, 0.013358706060136038, 0.0340165829496278, 0.07624270199167152, 0.055766822695131266, 0.006233223163778143, 0.007284226847977768, 0.014361872341513876, 0.05232585451355385, 0.0313618297373215, 0.043031599207390706, 0.06191592701079865, 0.052138852451236985, 0.05650047828713733, 0.022030451725567543, 0.0371304392484167, 0.034615985463343324, 0.08628892622167066, 0.03131333828693436, 0.0916415595659806, 0.013419038357002842, 0.046561858766982635, 0.07652591703639877, 0.023877355645621018, 0.062196495221747514, 0.03723033711374287, 0.047282314664053346, 0.05337622617521594, 0.04945313588025109, 0.08481837448573883, 0.008092785250365494, 0.07694433127800304, 0.006565593761361896, 0.04398201171669268, 0.030278024083424, 0.07104454261641349, 2.848198211962177, 19.99875737774757, 48.73967378370224, 53.87369940357824, 49.57842165423978, 26.83606832258163, 31.76457743490896, 49.704502321058705, 23.82026380108249, 2.674028551386249, 0.16090492477580426, 0.9707097637076533, 3.0393134922750535, 6.6888036362586485, 10.443792054730078, 13.507764262537803, 8.523057391566615, 21.3446637891954, 33.03124020176549, 46.09072069967947, 51.608244296043154, 54.86984022202031, 53.366074100617446, 50.451513798006125, 46.39225290667626, 39.714841304286836, 37.375751541506865, 39.10949799322313, 42.848207104590635, 51.08957359867712, 52.59703851515248, 48.87388944625855, 51.179917550856075, 48.95628275409822, 48.26471397953649, 48.06980748330393, 51.16340437243062, 50.785789951201416, 45.67048972652805, 44.18657472056728, 38.73212675894461, 37.07910660774478, 37.32895766535113, 37.66379471748106, 36.80591744761313, 36.47822303156699, 38.93511333773213, 41.53152235092656, 38.50274655126756, 37.719802241171564, 37.07008515634845, 37.12151135167768, 36.73990003524288, 39.38188698983962, 36.11338769235919, 37.31779067747055, 36.58467223567348, 39.80010970946282, 40.702466657084805, 48.19193047861899, 48.1493962964704, 50.635284685319476, 49.59775501681913, 49.662940886712846, 50.43139203902214, 52.152022084882184, 53.19841630997197, 53.28523797373618, 31.720007542640936, 48.14217129061299, 50.69500277119298, 45.166523994938025, 40.39531761600126, 38.07197616946313, 38.3764305422383, 38.95088126582485, 36.60360551649524, 39.35552866228166, 38.025660822468424, 37.300893106768214, 38.20081818488337, 38.69128311834028, 38.688156989312944, 39.58682690897296, 38.430108178046446, 45.429099221383375, 51.74408774222098, 52.9353625543656, 53.88257180490802, 53.553202536798295, 49.58397573040378, 50.35467047845164, 51.7950197189085, 51.58674578512869, 51.793262497071304, 52.03989328876619, 50.92547339777793, 52.79880131444624, 52.497849618234945, 49.82578592915689, 52.87184761416528, 54.74193565307125, 54.79292254294119, 52.57346899278703, 43.47833979514338, 37.80267800054243, 37.476603523377456, 38.7750296438894, 42.34208014703567, 43.59892129898072, 40.2775445292073, 42.39131373743857, 47.07796166020055, 52.35957822492046, 53.724033524913175, 59.16012087175923, 59.56082628619287, 49.258815165488954, 41.30733143898749, 19.561428793015022, 7.360333021610015, 5.995602665408965, 7.888416426797067, 9.862737040365896, 5.938388032297935, 9.956059052098183, 0.017487776330521992, 0.5738303149419447, 9.553009040894048, 42.33360390509329, 49.1970064563136, 37.084492021991366, 39.236465115701, 57.82647578947006, 57.24067764897501, 33.835016219846665, 3.951757059943292, 0.07961607823568968, 0.0579181163301391, 0.040347981717317336, 0.06242742859608224, 0.023535211202538302, 0.056707911914394754, 0.07043181783369473, 0.028028812920374256, 0.02788110350769374, 0.08830188352975153, 0.019821358671892556, 0.0520151675558619, 0.020351460871977672, 0.025348518336672458, 0.07592423924154813, 0.05502207414998163, 0.11320600000720833, 0.03263390532905056, 0.03177646333501945, 0.138103865207203, 0.15637809590947244, 0.11893480550497772, 0.1371447690912793, 0.1566313186119641, 0.17527635119134383, 0.1997833813150083, 0.14708566389256908, 0.12400032441702583, 0.11678257341226263, 0.09726661377616468, 0.14737432582243798, 0.15521546555382593, 0.2797373426297019, 0.2264564637575419, 0.167758209450591, 0.1313194058715336, 0.2453707302770307, 0.16505623266341227, 0.283009059006168, 3.4989608535843515, 23.318957436469294, 54.29680939643614, 60.915852208291334, 54.33451514090262, 28.752981616604714, 37.15897390919347, 51.47208313788138, 27.77270482432458, 3.4050990256571003, 0.522887735597549, 1.6902604819305482, 7.043939934622857, 10.525646036671056, 16.820496128451442, 17.242935396009877, 18.575923481295188, 22.50114913909666, 31.42325866606928, 46.82661225718837, 52.0971324366908, 57.34340452378797, 55.103111420908284, 54.40294873329901, 48.34615415142429, 42.41520881652832, 39.77393573330295, 41.66580077140562, 45.18330389453519, 53.63272466967183, 54.616510022071104, 50.294430717345215, 51.303821302229366, 49.978393585451194, 49.109969062189904, 47.7704914154545, 51.89227488733108, 54.75153369288291, 47.873406564035726, 47.19395006856611, 40.32311070349909, 38.38285538458055, 39.99644394843809, 39.813163357396284, 39.77139795980146, 38.7539469042132, 40.04555594536566, 44.21894996396957, 39.91257582941363, 39.70285454104024, 39.23452746483588, 38.118044407136985, 39.03454542160034, 41.88904246976299, 38.89559153587588, 41.16035630626064, 38.30706734811106, 41.089730108937914, 43.08846404475551, 51.780856040216264, 51.52497237728488, 53.837699890136726, 51.74322482078306, 53.39664897611065, 53.06021159695041, 54.25596575583182, 54.00431040794619, 54.727183618853175, 38.20092408887802, 51.154033830088956, 52.32033883371661, 47.517722114439934, 42.9811401521006, 39.77105671359647, 39.99446315150107, 39.844722747802734, 38.978914445446385, 43.2415266959898, 39.98873256867932, 37.89801512995074, 39.782749299080145, 40.61246002874067, 40.47715002490629, 40.82502895785917, 39.592486889131614, 47.102194063125125, 52.63937657879245, 54.989111654220096, 54.97681894610005, 55.59196818259455, 51.327590865473596, 51.541014871289654, 54.052159401678274, 54.84915364173151, 54.33416997232745, 55.02456988057783, 53.883450415826616, 55.7325969203826, 56.10555941058744, 51.410635286761874, 53.21900875337663, 55.351185644826586, 56.678186232043856, 55.76932207230599, 46.71525224562615, 40.487956154731016, 39.15843348349295, 41.799753635160386, 43.72113450880974, 45.756283729307114, 43.23401535710981, 44.727952018860854, 50.128330107658144, 55.30554494550152, 56.13274535825176, 61.06562791332122, 59.462570913376354, 51.84991328947006, 42.7295514845079, 22.310614124421154, 11.683356146658621, 15.983088727920288, 20.08573985868885, 13.171239610641235, 8.386339256840369, 8.957366731859024, 0.13978794096939026, 0.8068911154423991, 11.248511402837693, 48.98796373798002, 59.07588404993857, 41.77419939348775, 45.21725200837658, 65.33396290194604, 66.12604633454355, 38.9935488085593, 5.357670832064844, 0.17259367981985693, 0.11342782842656297, 0.13385823657435755, 0.21059205455164756, 0.13230618840504077, 0.055976677160229416, 0.1221111745783879, 0.20229210476240805, 0.07142364888662292, 0.16104121181753375, 0.09284430228534246, 0.1724438943089016, 0.0819319696916688, 0.11860557155863893, 0.15463389756698764, 0.11196427107337983, 0.1656870141385063, 0.08064150990497682, 0.1606302975767082], [0.03510528965102088, 0.03972839278679702, 0.008033655711539812, 0.0059509154544362146, 0.0412207895198897, 0.09717862857806106, 0.045082937520478046, 0.0698800583279902, 0.04644798745791759, 0.06892222625714156, 0.02016348204755735, 0.023439729834095608, 0.07430298268915185, 0.0025524955567708544, 0.07423908329538761, 0.05876794149498305, 0.062158642817408814, 0.01126067756089352, 0.030285112311943408, 0.057962189368422956, 0.7926592855684219, 14.442574900965537, 42.953040292186124, 48.85730958754017, 38.07153686400383, 27.16784200360698, 37.429648830044655, 39.603077288596864, 24.792784106346872, 4.00250100801068, 0.046367417990921006, 0.6852221957618191, 2.0646280386755547, 4.779732140802569, 8.01492904463122, 12.738718871147404, 5.828982341674067, 13.852638659938691, 21.73051322660139, 42.38518307285924, 52.793898351730846, 55.89366120676841, 50.40674778722948, 48.13509925719231, 40.06659553896996, 36.32902391495244, 36.24340641883112, 39.43685900780463, 45.997815439777995, 50.977695834252145, 51.194163599321925, 47.61813479085123, 49.605321268881525, 49.16925176497429, 50.72292220207953, 49.51103533467939, 48.06155481646138, 48.02182120661582, 45.142554390815, 44.43477446033109, 41.393717719662575, 35.65939295676447, 35.87212270306003, 34.77171351832729, 36.116568734568936, 36.72436352699034, 35.679314674869666, 35.481054552139774, 36.448675817058934, 35.450526745088645, 35.36906303897981, 35.98314931315761, 44.669190991309385, 47.215515259773504, 36.801281206069454, 36.48981363542619, 36.57146953767346, 39.60333616502824, 48.66378768797844, 50.32052232373146, 49.198822513703384, 48.64752554124402, 47.833845538477746, 51.751395117852, 49.57233805810252, 50.492894803324056, 43.48453714001564, 42.937452793121345, 30.821467061196607, 46.94578170776368, 51.082187775642645, 44.80239468236124, 44.423591782969815, 41.162909769242816, 41.04215960348807, 40.644901952435895, 41.349006622068345, 38.542358567637784, 35.43527656985868, 34.160416049342004, 35.49166064108572, 37.1879445352862, 34.959991208968624, 36.685751715014064, 36.27487559472361, 37.045291854489236, 43.93173440810173, 48.16754510325771, 48.88732356409873, 50.04741945574361, 51.81756550265897, 50.773328581163966, 50.99280088178573, 49.122783445542865, 47.42252226798765, 44.2962481129554, 45.74266526006883, 45.497877982354936, 47.72697271839265, 54.53552092275312, 50.909999647448146, 49.94437094657652, 52.98256827938942, 53.05901919641803, 53.378468790361964, 45.01342604237218, 37.18342596484769, 37.538878994603316, 39.5931262354697, 38.501793415315696, 41.44625002338041, 40.301188576606016, 45.384670534441554, 48.67413097812284, 56.34420033424132, 55.24080230343727, 59.24254163619011, 50.154213828425256, 36.964659690856934, 16.24128855043842, 8.177831942035306, 1.851019558887328, 5.558531486218976, 6.9861702861324435, 2.161985679018882, 2.8696202366582813, 0.19338928974203526, 0.20025735991376065, 8.97146176907324, 32.93454593227756, 42.34561812493109, 33.56093668168591, 39.57283973693848, 51.3063237743993, 57.269103065613784, 24.651384622819965, 2.305861158717063, 0.05971076590339503, 0.028754121984445283, 0.01930038440942524, 0.03265051411524896, 0.03614198664323457, 0.04523398707650843, 0.013182640860548184, 0.047860274376768264, 0.019117059569144924, 0.017868368811304533, 0.033759257846301606, 0.07997858338057995, 0.02040493763953207, 0.04118015621638587, 0.05654160188691271, 0.09053544351650823, 0.03457961926957773, 0.05213626307405291, 0.10963228411011158, 0.06240747583609435, 0.04230146378939671, 0.021974429630884723, 0.01861940885353233, 0.013083188283827998, 0.07081345985493354, 0.009818754530692054, 0.03607291232554182, 0.027479901346528245, 0.01609216523056309, 0.05443500182140739, 0.06442157461518241, 0.05429627095919944, 0.053158511648014675, 0.05988969339898998, 0.03970911035374288, 0.0375238943454479, 0.02444926900939355, 0.05994164565157506, 0.04317926265479576, 1.2106661522580733, 17.389161356033817, 49.559770784070416, 56.178001665299945, 42.25185778833205, 26.709548350303407, 40.053467366003225, 44.54844867029498, 26.97788553853189, 4.659624753459807, 0.02933680462921339, 0.9645297630659997, 3.073597949358725, 4.599922847363257, 6.801122177031733, 13.267280805495478, 8.601294948208718, 17.691336831738873, 26.599978900724842, 42.17713271417926, 54.53509338440434, 56.251797137721894, 52.62616603605209, 49.666651448895855, 42.55702603247858, 38.2440270147016, 38.6418612541691, 40.095083713531494, 48.34407137286279, 54.09492108129687, 52.22158531988821, 48.95811842333887, 49.20977377122449, 50.58316815283991, 51.287853333257864, 49.425617879436864, 50.44542627949869, 49.19349593500937, 47.82836598734702, 45.74952940787039, 42.5468082581797, 37.830495449804495, 37.364949334052305, 36.966848373413086, 37.66574021308653, 38.00406425229965, 36.445357491893155, 36.518023321705485, 38.04489220342329, 36.04713886014877, 36.49280640386766, 37.39911710062335, 45.658385292176284, 47.51298389127178, 37.32626691941292, 37.948299915559836, 38.73788479835757, 40.12872588249945, 49.064273449682425, 52.646177968671246, 51.597171445046705, 50.25109637168146, 48.48618668894614, 54.45107229294316, 51.05559802824452, 51.878550514098144, 44.28865832667197, 45.09862776725523, 31.897606580488144, 48.97191732160507, 52.74546884721326, 47.64410480376213, 45.45573603722357, 41.057319564204064, 42.24642138327322, 42.051448206747736, 42.23416397648473, 39.05918575102283, 37.94388724911598, 36.967777975143925, 37.115196335700254, 36.53227721491168, 37.81094635686567, 39.40546043457524, 38.30018751082882, 39.278320727809785, 46.8837768800797, 50.77953769314674, 50.69749739862258, 53.95097009597286, 53.768744622507405, 52.99084055808283, 51.996802130053126, 52.4005199247791, 48.30439659856981, 47.10596346086072, 48.82868413002261, 47.83821898121988, 50.41185863556401, 57.36778597677908, 52.00445859662948, 51.36069174735777, 54.73605602018295, 55.1267280117158, 54.48499687256352, 45.594540872881495, 39.412312815266276, 40.2623414224194, 40.83790217676471, 41.17371197669737, 42.830736867843136, 42.865873459846746, 49.38587250248079, 50.72806835174561, 59.217254115689194, 58.65081287199452, 61.0023836166628, 52.49826538947321, 39.21648456204323, 20.369227201707904, 10.865486071955774, 6.074874256887744, 6.883026169192407, 7.29885281093659, 3.866899032746592, 4.01770681142807, 0.06079098435058709, 0.3242441398962852, 9.344733145929153, 37.99099883725567, 50.288033331594164, 33.34395116375339, 43.31735395616101, 58.400636257663855, 63.009672241826216, 30.150129871983683, 2.770938551233661, 0.03188290550643879, 0.029584691529312444, 0.026471105276516853, 0.008327969455070073, 0.031201975915821332, 0.05171154775927144, 0.06254996819001052, 0.04133635388326742, 0.061099273453076045, 0.03783549294776974, 0.08136171682347214, 0.058957467817010424, 0.033480624007361556, 0.051962594772058154, 0.0056805749960814516, 0.03716357638158145, 0.056637362877447764, 0.15079677765888555, 0.08993008083874181, 0.17021319949098174, 0.09348392441508271, 0.14078849776377603, 0.10678933948398599, 0.21864766825831708, 0.19017817092037972, 0.11761169505095291, 0.10041871318413366, 0.1469676863522299, 0.1200646396365858, 0.10647680625439652, 0.24410666988020946, 0.15120966840655575, 0.10965436276408935, 0.14950519938382412, 0.1285574137563667, 0.16133068580060236, 0.08215126235999408, 0.17955539657944636, 0.19926403498938008, 1.617421700108436, 19.811224937438965, 57.488088992334184, 61.295266997429636, 49.1597713962678, 37.80669058522871, 49.36768447199176, 50.0839327996777, 33.339463972276256, 5.214423421890506, 0.22242146333859814, 1.3943362836876225, 4.8754065940457005, 10.310073552593108, 14.750172072841277, 20.08280788698504, 12.554870517023149, 18.838688942693896, 25.496657356139153, 44.00680857319986, 55.51658415025281, 59.21290028479792, 55.23891956575456, 51.8782720258159, 44.8128556436108, 41.04756070721535, 40.9157023891326, 43.25785552301715, 50.86702615984025, 55.545656757970015, 52.90139482867334, 49.61139309790827, 52.063694230971805, 52.6882924572114, 52.71366234748594, 50.905273191390506, 51.30268773724956, 51.60548294744184, 50.02512470368416, 48.34878998418009, 44.32277902480095, 40.85086168781404, 38.358383717075476, 39.00807334530739, 39.64908276834796, 41.20479676031297, 37.76885540254655, 39.158837487620694, 39.93252500411003, 38.78385105440694, 38.878721421764745, 39.557754301255756, 47.118507200671786, 50.130036338683105, 39.222466176556004, 40.31748210230182, 40.20889128408125, 43.241640444724794, 54.24321413040162, 54.291074891244214, 53.195603970558416, 51.89101972887593, 51.78616300705941, 57.92652368545533, 52.835495087408255, 53.01166049895748, 45.541145647725756, 47.74683560094526, 38.23040462309314, 51.13829728095762, 55.37625743496803, 51.06474107311618, 49.706514496957105, 45.54191050990936, 45.81293452170588, 43.96652190916, 44.65304259330996, 41.732967438236365, 40.59264421463013, 38.101750881441184, 40.1469962827621, 38.829832999937, 39.66865931787799, 41.561069565434615, 38.76287029635522, 40.712625595831106, 49.064379353677076, 52.98523941347676, 53.58822930243708, 56.26310925329886, 57.126371937413374, 57.04945033596408, 55.37396284841723, 53.912173932598485, 50.59695136162543, 49.01100766274237, 51.9637365495005, 50.936922796310924, 53.57703485796529, 60.017633361201135, 53.163369932482325, 51.02170090521536, 54.56750785150836, 56.52524517428491, 57.943915474799375, 49.14867893342049, 41.41700875374579, 41.79825136738439, 42.633594620612364, 42.91910786782542, 46.320238190312544, 45.641895647971864, 51.88253564219321, 53.78400656484789, 62.8758958847292, 62.797946622294766, 63.33760984482304, 55.15743232542469, 42.19332425825058, 20.101437184118456, 12.506772452785123, 7.313011096369836, 9.343888855749562, 15.22958278656006, 6.200844116749303, 4.144943596855287, 0.3784649013992279, 0.6286962450511995, 12.630965478958624, 42.30667291149017, 57.44361715932047, 47.44928459967337, 52.02527461513397, 66.39608583142682, 72.45316674632411, 35.93897558027698, 4.293546513203652, 0.1610817378687282, 0.10389396380032263, 0.09891579423340098, 0.1059100850515308, 0.14589450442262236, 0.1167370371460434, 0.1981546937097465, 0.14653705300823336, 0.22197938464101286, 0.12999067233214456, 0.1477900664171865, 0.21446367905985927, 0.2148316004463742, 0.17516673933113777, 0.14660151164618232, 0.1404055610539452, 0.15520732970007006, 0.19377492308135957, 0.1927016798647181], [0.0368009869670195, 0.10142815659844107, 0.06954250466679374, 0.055052698514754736, 0.020002007950097322, 0.08325618331230457, 0.08506320852545962, 0.03955277096059534, 0.080825240771857, 0.02947269139000245, 0.06226722045891708, 0.04656591137210208, 0.042873559099051266, 0.050608293048196265, 0.04252967372116062, 0.017447508834002, 0.005335435628019755, 0.03673921729768476, 0.0435416528864974, 0.07505869012205832, 0.058475571699560656, 12.29170693505195, 41.74243211746216, 48.77817969168387, 48.48299387962588, 23.398061836919478, 32.58512943021713, 47.555690657707956, 25.915788104457242, 6.734216838113724, 0.030111717886381575, 1.387718509762518, 2.3808782042995578, 4.80458967147335, 4.720812257259123, 13.996954425688713, 6.41624205535458, 12.96118982376591, 25.93624914846113, 36.07736856706681, 51.84895230877785, 53.965851568406634, 50.8881010547761, 47.77083658402967, 41.82519020572786, 37.19218853981265, 38.05417253125099, 44.6918583685352, 48.97652610655754, 49.82418560212659, 51.74520561772009, 50.25015500284011, 49.24051338626493, 48.896403851047644, 48.423671953139774, 51.05022438110844, 50.22298866702665, 49.20756547681747, 46.80058733109505, 47.1243986006706, 43.478186822706654, 39.35971383125552, 36.05641134323613, 35.07842717632171, 35.758707369527514, 37.01521904237809, 36.114113330841064, 37.14109574594806, 36.696695127794825, 35.2807822535115, 34.82221795666602, 37.708141034649266, 38.5390833885439, 40.11868069248815, 37.55099127369542, 36.34879266062091, 36.19591043841454, 41.98691737267279, 49.41170523243566, 53.61575257393622, 51.215183581075365, 52.668284446962424, 51.01926119096818, 53.468216542274725, 47.88846062075707, 49.360737954416585, 46.02743325694915, 41.81498419853949, 31.805172005007346, 39.2256119174342, 52.01038529795986, 43.8234495347546, 46.2811674610261, 41.72534235062138, 46.75384836812174, 48.32419280082949, 47.40567961046773, 44.42651002637802, 36.56355419466573, 34.03540618958012, 35.000917219346576, 35.28015467428392, 35.65875753279656, 37.30325437361194, 35.66931263093026, 35.48745978263117, 37.621393895918324, 40.83078307490195, 45.567237254112, 47.318046016077844, 48.89284626130135, 49.23095849252517, 47.735864731573294, 45.739127282173406, 44.14304033402474, 43.97358217547017, 42.246915601914935, 44.80134740952523, 45.180075783883375, 48.0803821932885, 54.45809725792178, 51.70614273317399, 51.313525246035674, 52.76673593828755, 54.70908188050794, 52.84783878634053, 39.859141380556174, 39.59000010644236, 41.09175405194683, 40.160293117646255, 41.629526692052046, 41.21084505511869, 43.36306918051935, 48.74145453976047, 51.55504518939603, 54.6341646102167, 58.88694347873811, 48.554777176149436, 31.13463890167975, 18.27957272529602, 4.690294256133418, 5.074929719971073, 5.264046307533018, 7.632456767943598, 1.2597467702242637, 1.5762232075775824, 0.05220251435774469, 0.41478123816270984, 8.711589055676615, 39.76626749961607, 49.37371315494661, 39.31812101794828, 38.316618319480654, 47.60684228712513, 49.42690441685338, 28.418776066072528, 2.7003743763892882, 0.07124777042096661, 0.01901213233659585, 0.06032430656975316, 0.07430519668325301, 0.07230814336048019, 0.013894968564742276, 0.036865181304634585, 0.03572229303479676, 0.006715080976831697, 0.01457490990193741, 0.06125172495000786, 0.07746769190435449, 0.046604296207548156, 0.04795830298755919, 0.022353551222852642, 0.06249127436369177, 0.06723798961649019, 0.07347800558613193, 0.06715613312178081, 0.01952397483100574, 0.033271267499414184, 0.01422941190896616, 0.02110526649161212, 0.03301744341790196, 0.03737690505541621, 0.05711025363134761, 0.012818541295165497, 0.014811673205375913, 0.09440339846356262, 0.03138456339647453, 0.0402474824729706, 0.06844472365393754, 0.007148196445702906, 0.05736024344279882, 0.03824577899649739, 0.031083056087335272, 0.03847312324890687, 0.07261084002112189, 0.049022544671090386, 0.3287793191209916, 16.632032125226914, 46.67575397799092, 53.65788667432724, 53.58438537966821, 29.951097042329852, 36.170877871974824, 50.66161555628623, 31.387259152627763, 6.255708759830845, 0.16150766743286965, 0.9487345622431849, 3.5525200828429195, 3.021975390372738, 7.100794690270578, 10.71502689392336, 9.591935623076655, 13.476588283815692, 28.352036937590572, 40.519370417441095, 51.39545179182484, 58.5815320476409, 52.68018099569505, 49.46894438036027, 42.91995509978264, 39.97049354737805, 38.41928243637085, 47.16046871677522, 50.935036136258034, 52.362104231311434, 49.4660496711731, 51.30948912712836, 50.2266364712869, 50.95851936647969, 51.02295214130033, 52.74748102311165, 50.034620761871345, 50.96506580229729, 49.66418427805747, 48.902267794455256, 45.30653692060902, 40.25376319885254, 36.785819222850186, 37.129069758999734, 38.15094524814237, 38.16064526957851, 36.517403587218254, 39.281584139793154, 38.180621900866115, 37.385663370932306, 36.12240129901517, 39.48768115812732, 41.33796122766311, 42.64996267134144, 38.16865474947038, 38.12882308037051, 37.34043059810516, 43.43247944308866, 51.49051827769126, 55.4063420141897, 52.487686757118475, 54.154454815772276, 51.140682082022394, 51.92634067227764, 48.45542746205484, 50.13227993442167, 46.01699975229079, 41.70830749696301, 33.60059968886837, 42.08342336839245, 54.27362034397741, 46.45877238242857, 49.24106251808905, 43.646334909623675, 47.85115103567801, 49.177253400125814, 49.138814172437115, 46.63837379024875, 40.19096605239376, 36.45953686006608, 37.17592639307822, 37.03312466221471, 38.04995990568592, 38.31115053546044, 37.43787011792583, 38.664658069610596, 40.41273686193651, 44.07053139901931, 48.87256368514031, 49.857427689336966, 51.81013653355261, 51.11970524634085, 50.006564048028764, 47.855061638739805, 46.315562725067146, 46.832260470236506, 45.12213060932775, 46.645226170939786, 46.24633681389594, 50.56347000983454, 55.01938450721003, 51.71222240694108, 51.274301544312515, 53.42298769181775, 55.57928323745728, 54.43140552889917, 40.10570156958796, 40.76730343603319, 42.45795480666622, 41.444116254006666, 43.50849889939831, 42.82706160699168, 45.747901624248875, 51.88217870650753, 53.85002005484797, 57.64963573025119, 61.740216747407, 52.396440659799886, 32.706842537849184, 20.87490308669306, 7.649629885150541, 7.099411074192294, 9.379986428445386, 6.384239927414925, 2.6578247499081398, 0.5939437388893097, 0.06691993289296666, 0.4667476786961479, 11.340440973158806, 39.20599614420245, 55.49027289113691, 52.66445621367424, 43.54122715611612, 56.03289358077511, 57.10190026990829, 34.29400805504092, 3.5567765899242896, 0.06254124244855297, 0.09114414633762452, 0.10696969956399933, 0.048362942968284896, 0.04889096140921597, 0.030538285218719995, 0.032664905076906565, 0.03635369504110948, 0.04506253659905446, 0.05199701893293569, 0.03575447255805616, 0.05431018694634399, 0.043933729025264906, 0.012702794985905772, 0.01216952596986366, 0.018310943550820795, 0.05262023145933786, 0.01309902236361297, 0.05202863921201037, 0.13622324192716231, 0.2286286907450807, 0.11967646288535289, 0.12762155308718645, 0.17517098345823828, 0.13066254676349703, 0.12188551571941185, 0.1252765732727224, 0.15151713013408646, 0.14660074555825803, 0.15189471955020584, 0.1457807556876252, 0.10845644639865046, 0.11528054312352212, 0.0843656241833683, 0.20866045578112527, 0.17257766858223947, 0.13176860918681468, 0.182132899400688, 0.14974182862187588, 0.6115608806571653, 17.488091376519975, 52.75419219847649, 61.46280319459977, 59.72471075673258, 34.502533020511756, 42.552205439536806, 60.258094264614975, 34.880880924963186, 8.684040288771353, 0.2699191904356403, 1.6284060526278712, 4.1120273115173465, 10.774208595675807, 16.99556915990768, 21.743227589514948, 15.964586907817473, 18.001359008973647, 26.811455449750348, 39.452466118720274, 51.01990053730627, 59.270790546171135, 55.62161345635691, 51.535927557176166, 45.40846363190682, 40.746181472655266, 41.29636841435587, 50.069474943222545, 54.41225651771792, 53.53794843919816, 51.71725480787216, 52.93586461774765, 52.95656296514696, 53.398559170384566, 53.009871898158906, 54.09679597423923, 51.41213755453787, 52.83252585318781, 52.06845206599082, 52.47817893182078, 47.93912195390271, 41.47191801378804, 40.23111935584776, 38.96393099138814, 39.559185966368645, 41.38792830128824, 39.365730747099846, 41.16711847243771, 41.602301520686, 38.932952111767186, 38.18071996012042, 41.070777216265284, 42.18041181564331, 42.49483293102634, 41.6914060038905, 40.492290373771425, 39.80824862757037, 46.39960342837919, 54.1119598573254, 57.85772923500308, 54.697373605543575, 56.68842754056377, 53.25766763379497, 54.78425802723054, 48.22640811243365, 51.45701731404951, 48.04916404908704, 41.465493171445786, 36.81832390446817, 44.35604464623236, 55.873837547917525, 49.84574294859364, 50.47129431078511, 46.708446933377175, 50.64312550329393, 53.92423129850819, 51.04308566739483, 49.315775825131325, 41.854859013711255, 38.8921594619751, 38.152063123641476, 39.478279236824285, 40.01311794404061, 40.77653277304865, 38.507571066579516, 41.384182437773674, 42.60766383140318, 44.38621159522764, 50.62393334604079, 50.99138490615353, 53.08470679867653, 53.14815505858391, 52.75168972630655, 51.407603294618674, 48.50079751783802, 48.246176858102125, 46.9074954525117, 50.02951383590699, 50.21355536676223, 53.64208344490298, 58.113424624166186, 52.6771568482922, 51.672512331316554, 53.68772414422805, 56.90272231255808, 56.13420055758569, 44.074732257473855, 43.54950727954988, 46.542554209309245, 42.620474292385964, 46.21185133534093, 45.60401731921781, 47.5903408758102, 53.58927657527309, 55.964577659483886, 60.76314649274273, 64.61116029370216, 52.89289505250993, 36.80146163509738, 22.434323718470914, 7.3713156580925, 8.754889080601355, 12.55121780980018, 17.32422651783113, 6.382961725035022, 3.671106326003229, 0.30120229889308253, 0.7661293543154194, 12.9469447558926, 49.55135337768063, 60.75776892323648, 53.33620917412543, 52.59023712527368, 62.45303300119216, 63.452095985412605, 42.707543065471036, 4.894784573585757, 0.29256704774114395, 0.13091100439909967, 0.1383115822869924, 0.32525788872472705, 0.19483782411102327, 0.14417843682871712, 0.1033037773243362, 0.0903503260304851, 0.2816304684646668, 0.16729636568455927, 0.1626874275145031, 0.2634192101897732, 0.1857314135638937, 0.1502502964989793, 0.07581127957711298, 0.17623532473319964, 0.12727558778058137, 0.07469853686709559, 0.13189254689120478], [0.08345956433444254, 0.043054815501936024, 0.00806565233130729, 0.06115566901562195, 0.051538714493114146, 0.015439700594382181, 0.038305288706455505, 0.018077403562323704, 0.011924363469945328, 0.07145851354805693, 0.054778209211485046, 0.050475150797395944, 0.09853484169129403, 0.04858467179620939, 0.04268359610690706, 0.015248236069906385, 0.04866293916899351, 0.022362845784593976, 0.033863825017526265, 0.06671210089998861, 0.14256643461844615, 6.361927524689706, 32.34139138652433, 54.14330351737238, 40.21440613654352, 36.41704974635955, 31.28922539372598, 38.75097374762259, 38.08737147238947, 8.641173685750655, 0.2073038672848094, 0.489924228599956, 4.083217012305414, 1.7866815338211677, 5.779439374323815, 9.095812670646175, 5.871944552467716, 6.005045771598817, 18.2028825436869, 33.28034993140928, 52.93845730443155, 52.93582147167575, 50.606161086790024, 46.044275914469075, 38.05087774030624, 37.95717231688961, 42.60381206389397, 49.650746237847116, 52.66547995228922, 52.31123893491684, 49.90110328120571, 47.97162271315052, 44.83922966064946, 45.51584636011432, 45.900830914897305, 49.0656933476848, 49.602167683262984, 50.160285657452, 49.6865378656695, 48.1788101503926, 46.4869350002658, 43.24156199732135, 37.31835942114554, 35.29487532954062, 33.61490065051664, 36.909993617765366, 36.45897988350161, 38.101001708738266, 38.072085995827955, 37.5082766625189, 36.565021161110174, 37.80252895047588, 35.52563228914815, 36.3784065554219, 35.475488708865264, 36.43910915620866, 34.850415875834805, 39.36874704976236, 45.64623771175262, 50.348006371528875, 50.487705507586085, 49.98674431154805, 49.321141627527055, 52.39000012797695, 51.23897275617046, 54.408526343684045, 46.91050391043387, 50.044501212335405, 30.815871800145796, 39.36167893871185, 53.28459470502792, 46.12229970193679, 47.31300577040642, 46.31619814903506, 48.94110318153135, 51.9428381612224, 51.204295081477014, 48.42702165726693, 41.35646697013609, 35.97325317321285, 36.362438586450395, 36.16704963868664, 37.00038071601622, 35.75024289469565, 35.777464143691525, 37.686607222403254, 35.442097571588334, 34.831717937223374, 36.14737110753214, 40.82261670020319, 43.496206191278276, 43.45872009954145, 44.133614878500666, 42.36729706487348, 39.37369315854965, 37.64056251895043, 38.546324083882, 40.77981579688288, 44.978493413617535, 47.17212992329752, 52.31420424676711, 52.29700073119133, 48.45302304913921, 52.2529838931176, 53.91273483153313, 50.1656985282898, 40.04143353431456, 39.18904758268787, 39.08938015660932, 39.30098418266543, 41.19302964979603, 40.36252660136069, 42.941822313493304, 45.86479610012424, 52.243938907500244, 54.197706791662405, 57.793339606254335, 51.01751181387132, 34.25376453707295, 17.044673312094904, 10.102732162321768, 8.10725526463601, 7.420352149394251, 5.098217321980385, 2.2220923246875888, 0.2437134063051593, 0.045022316983029734, 0.6133317082158981, 8.877460206708601, 40.36999479416878, 49.03220807352374, 26.032402130865282, 39.43644323656636, 52.00975771873228, 52.63493645575739, 26.169910623181252, 1.7342285355252607, 0.11705799734279995, 0.05610271394553204, 0.024734443323987148, 0.012054788981444173, 0.052052518172610196, 0.018510277713498762, 0.029982522903611104, 0.05634823746438469, 0.09503034183815603, 0.03311981191678393, 0.05560762962446578, 0.05632995094563212, 0.010644670091419211, 0.08017767431034196, 0.043424835969363494, 0.02603410382664973, 0.08364376251495655, 0.031615190335639545, 0.05795093553681528, 0.05056051980523814, 0.08766260613957721, 0.09952849603348202, 0.06959128914581192, 0.06850673081052881, 0.08624922754543443, 0.01432988912828507, 0.05717991783674206, 0.04068735100689434, 0.13291427835581765, 0.03902484061977556, 0.03044660173116192, 0.0352423312893558, 0.024732187195050142, 0.0517811430167527, 0.07617569994181395, 0.018555840792795344, 0.04971908713360468, 0.07842952295416787, 0.0530698714447358, 0.23095038148664662, 8.38644123846485, 38.79495920673494, 60.0477179404228, 47.38398498104465, 33.68158878818635, 31.289092033140122, 44.533751549259314, 37.7156602182696, 10.284918412085503, 0.14501066878437996, 0.7901478042044948, 1.0996508189747412, 2.7912654992072814, 4.782800414869863, 11.700624381342243, 12.679561684208533, 14.000311974556217, 24.304398029081284, 38.89768215917772, 52.64485220755301, 56.7175393719827, 53.306779630722545, 49.26103522700649, 40.075785652283706, 39.68150900256249, 44.4055724143982, 50.32252665488951, 54.515316793995524, 52.72835554615144, 51.86903092168993, 51.141643062714614, 48.07588715707102, 47.65761344663559, 48.25991299844558, 49.87093633221042, 50.66776583271642, 50.91354547008392, 51.90924698306669, 49.557633092326505, 48.128635191148334, 43.75143874076105, 39.354069540577555, 37.33047954497799, 36.396633809612645, 37.02472686767578, 38.13930365347093, 37.78213654795001, 38.343141386585856, 38.732566064403905, 37.12276651013283, 37.85291964007963, 37.045507584848714, 37.88201578201787, 37.160280058460856, 36.724187020332586, 38.19928453814599, 41.20806409466652, 48.21886539459229, 52.566271443520826, 51.93306361475299, 53.59870595316733, 50.88771274012905, 53.818374372297725, 52.445631104130904, 54.847663141066036, 46.07044989062894, 49.180101040870916, 33.11422970987136, 41.484622570776175, 55.422160933094645, 48.32990769417056, 49.74023511332851, 47.859803784278135, 50.815639188212735, 53.61924348338958, 53.72002486259707, 50.07089091885475, 43.75813030427502, 37.07313283797234, 39.04840707778931, 37.48573087876843, 37.9136771540488, 37.20948226990239, 38.20159481417748, 39.26152121636176, 37.96514257307976, 37.43760731912429, 39.581417960505334, 44.14594288795225, 47.12955259507703, 47.09491022171513, 46.826412216309585, 44.49447293435374, 42.519653689476755, 41.55251879845896, 41.34364081967262, 43.31217642753355, 47.794676749937, 50.48894105419036, 55.05392489894744, 52.35385548683905, 49.992655323397734, 51.258164913423606, 54.76515216212119, 53.51125671017555, 42.13533985999323, 41.26032183247228, 41.77743927125008, 41.63612411868188, 43.91105567255328, 43.8725144632401, 44.97688524184689, 48.49476099014283, 53.698946045291045, 57.21216594019244, 59.99644079516011, 53.21021479945029, 33.279471320490686, 16.834987325053064, 8.829631805419922, 6.782594371226526, 11.942871924369566, 6.210216620276052, 1.9517150136732289, 1.0696213980836253, 0.015054614050313832, 0.5913498877517639, 10.499689752055753, 46.47003350719329, 52.85113357728528, 31.476771562330185, 47.0932706709831, 57.32455753510999, 57.97418440541914, 31.234961363577078, 2.4564688965197536, 0.02972294358656772, 0.07488834281121531, 0.023437176846087943, 0.04740277815970683, 0.03631423002169017, 0.028634441813694376, 0.09557259419272024, 0.0845872610807419, 0.07074893226907139, 0.011093356297351422, 0.027001400913802848, 0.05525905578847855, 0.03630226755875253, 0.06261630374337397, 0.14637216024341124, 0.032540783511414643, 0.02446112230480198, 0.02872191947854815, 0.10085457124777379, 0.1689614271444659, 0.13464407424532598, 0.12860615227010944, 0.1862439723505128, 0.15651882626116276, 0.17206518640441282, 0.06882327067996226, 0.1175190750209074, 0.14237154185050918, 0.3351356732028146, 0.15791338207500596, 0.1410941974890809, 0.20562463319830357, 0.1486554699799707, 0.09771875120819577, 0.2074488877288757, 0.0851358489824399, 0.1094767222962072, 0.1471918283571159, 0.22625495198993917, 0.3469792699381229, 10.124643502696868, 45.67494161667363, 65.7261489283654, 53.413801500874186, 47.250691075478834, 42.69482674137239, 49.76571482996787, 47.36347882978378, 11.668968892866566, 0.49621632322669035, 0.8073108703378709, 6.744458146633641, 5.688039814272235, 13.1746236355074, 19.38134297247856, 15.903377340685939, 10.44598073728623, 19.756331366877404, 37.09193668057842, 54.82480356770178, 57.907366829533736, 55.79595496577602, 50.55022416576263, 42.113704066122736, 42.450251271647794, 46.478643109721524, 53.788713409054665, 55.89803072714037, 54.17536104879072, 53.32729362672376, 53.10400485992432, 50.214990954245295, 49.889767631407715, 50.10141872590589, 53.58233790243826, 51.68109839962375, 52.6265190493676, 52.94429379124796, 51.89649143526631, 50.723859648550714, 47.06617493783274, 41.04010428151777, 40.16377618235927, 37.72817257911929, 41.28650757574266, 40.168565396339666, 42.39976644515991, 41.10379180600567, 40.71910927372594, 40.12657250127485, 40.261149021887014, 39.68110499843475, 40.43997380041307, 39.47031290300431, 38.95692171589021, 39.52445337849279, 43.38526587332449, 49.244608340724824, 53.411734411793375, 53.17972229373071, 54.86538048713438, 53.37754703337147, 54.83598624506305, 55.04289127165272, 55.77555864087997, 46.218542898854906, 50.49754281197825, 37.93034330491097, 45.79972397896552, 57.625364103624904, 51.84852084805889, 52.43875126684866, 50.79981634693762, 53.12237724181145, 54.898548049311486, 55.64404549137239, 52.424018844481445, 44.63971045709426, 39.528913113378714, 39.86109864327216, 39.89104593953779, 40.21890509513117, 39.78300425314134, 40.70152528824345, 42.900590358241914, 38.57613017482143, 39.337313175201416, 40.50943505379462, 46.16965447702716, 47.81122130732383, 49.07864893636396, 48.95487462320636, 45.895339596656065, 44.435021569651944, 42.086573031640825, 43.28884224737845, 44.53907028321297, 51.307833886915645, 52.49324083328248, 57.65073791626961, 53.55285344585296, 50.199140656378965, 52.62299283858269, 56.71233438676404, 55.360599333240145, 44.307211137587025, 42.427893761665594, 43.90531332262101, 43.2919801435163, 47.10243725007581, 45.59470169005856, 47.62683460789342, 50.06661161299675, 57.083833832894605, 60.02869444508707, 63.12802583940568, 57.32915847532211, 38.507182751932454, 19.483601124055927, 13.634920639376487, 15.019704603379774, 17.43575519131076, 10.273537655030529, 7.346591978303849, 1.0222392276890817, 0.1510919513361108, 0.8681519798213436, 12.164993786042738, 51.275760666016616, 57.21081272248299, 38.32115650177002, 54.04057272018925, 68.0517182811614, 67.93494932113155, 40.58813741130214, 3.1790665609221307, 0.2081605221234983, 0.3038649447262287, 0.165933296084404, 0.10675661986873997, 0.13751783858864539, 0.2678122341392502, 0.1976400051986979, 0.08833977423848645, 0.1940081508890275, 0.09936147354423039, 0.10289788095941467, 0.14819929526457865, 0.18595672002242458, 0.16582720822864966, 0.2183766876377406, 0.14995853957389632, 0.2331859639455234, 0.16296184020898036, 0.16199980231542743], [0.07303766590813476, 0.056560964759198896, 0.053778962427449804, 0.12121416988872713, 0.02681596933173076, 0.06516730758331477, 0.03212340157328835, 0.005213947010962594, 0.052241535046167915, 0.021862787637679328, 0.03325450549563093, 0.08177663004326244, 0.0703163224182302, 0.10479040158491944, 0.11725403158174408, 0.06945815072545121, 0.061003650358367356, 0.06891367671590659, 0.06722092117753721, 0.12710221442243747, 0.08184873423869572, 4.800586892712501, 29.439280686839936, 51.31547074164114, 49.030042925188624, 43.86448537149737, 29.359348666283395, 42.400574453415416, 41.630118969948064, 11.709496782672021, 0.3229263154489379, 0.4536062064430406, 1.2367376564971864, 1.1967319322209204, 2.9041410165448345, 7.9327387194479675, 10.64155697822571, 12.28852883461983, 24.44012772652411, 37.14774024101996, 47.86767598121397, 54.33488384369881, 49.3619264325788, 44.49984265911964, 40.91105045810823, 37.9797298677506, 45.48396141298356, 52.134508702062796, 51.595116123076416, 50.08401124708114, 51.59843052587202, 46.19594220192202, 43.47639429953791, 41.838439972169944, 43.90871009519024, 45.424780691823656, 48.54469668480658, 50.49853517163185, 47.804361081892445, 49.027779717599195, 47.414865801411295, 42.12200380140736, 36.11809845893614, 35.42593348410822, 35.04609900136148, 38.107630514329486, 38.2677024410617, 40.34965338245515, 44.14491522696711, 45.03936467632171, 42.006933227662124, 38.91048477542016, 35.60602126582977, 36.56215783088438, 36.77336961992326, 36.37967348098755, 36.8181356306999, 37.38785205348846, 41.63777543652443, 46.807855483024355, 48.92770436502273, 49.51771905345302, 48.37306553317655, 51.62698538072648, 47.98753184656943, 53.03236669109714, 47.963401425269346, 53.83705662142847, 36.10167549502465, 35.870808709052305, 49.370739998355994, 47.94864939105126, 50.08843960300569, 46.777868963056996, 51.51988898554156, 52.044886465995546, 51.181615937140684, 47.54286450724448, 44.13059857583816, 35.4680871963501, 36.08928080528013, 36.035505110217684, 37.41681875721101, 36.37217783158825, 36.5863823890686, 35.00652228632281, 36.04785665389031, 35.769317380843624, 36.0802318972926, 36.166116114585634, 36.005714708758944, 35.24277448654175, 39.28490246495893, 37.83810484793879, 36.353417135054066, 37.45122578836257, 38.709141669734834, 38.672946037784705, 43.085377139429895, 45.2225628975899, 50.949670499370946, 53.494300303920625, 50.681180338705744, 53.28973300995366, 51.90206120091101, 46.8761400253542, 40.31966686248779, 39.224584256449056, 39.430285115395826, 39.991552752833215, 39.63052603506273, 40.31740365489837, 42.025364445101836, 47.76188965766661, 52.217517822019516, 53.66866142519059, 57.332461111007206, 51.48633703108757, 26.78534030914307, 16.939871503460793, 5.743218737263834, 3.7350044327397502, 10.60743529950419, 4.633101686354607, 0.7246447126230886, 0.5643863507336186, 0.10107605492756253, 0.566226861649944, 13.059753102640952, 32.513326521842714, 46.84982876623831, 41.443061136430316, 39.72418046766712, 55.65843274516445, 51.329191192503906, 25.37314780296818, 1.8533303252150937, 0.0330788032301972, 0.04104463909302027, 0.018941025970683947, 0.02515398946049954, 0.014821162161928032, 0.005968702579623149, 0.017334790487262993, 0.030904797003454262, 0.09116591089555333, 0.04701303092822914, 0.07596927755061658, 0.06352928902713523, 0.03719534987824098, 0.03967734068752297, 0.07583096803676698, 0.0619653856471902, 0.07823085337276421, 0.037506186223078164, 0.01215458534012038, 0.010914927716517161, 0.049625007706063415, 0.04295296028196331, 0.06656558658446997, 0.018772614947069558, 0.01776027955084799, 0.028459700988605622, 0.015671627967798665, 0.0433524789649152, 0.019992841708083308, 0.09995302365672204, 0.09351986926048995, 0.10207539364214867, 0.026844310754489516, 0.01478701379270323, 0.059874164796764814, 0.06945890915249625, 0.027118786651220535, 0.04788134179468598, 0.008799309838533161, 0.1672175505589093, 6.157828463662056, 34.87037289527155, 58.40157370413504, 52.4850901480644, 49.02730511080835, 32.0864490924343, 46.531022441002634, 47.50429976371027, 12.416078429068289, 0.7033181118388331, 0.537966123271373, 1.3057084910331236, 2.216834632619735, 6.295781654696311, 7.67536896851755, 10.675069708977977, 14.7691543832902, 25.924260424029445, 36.543252006653816, 51.90606986322711, 56.71775510234218, 52.17711348687449, 47.48460554307508, 42.680423798099646, 41.14371761198967, 47.38245133430728, 56.17320068420903, 54.32631346487231, 50.073271797549346, 52.79820511418005, 47.10934062157908, 45.453719938955004, 44.18408009313768, 45.87413526350453, 48.184956504452614, 51.61514766754643, 51.38512419116113, 49.742706206537065, 51.455436598870065, 49.4767891207049, 43.71434096367129, 38.38902919523178, 37.202943678825136, 37.27065163273966, 39.76141945008309, 39.549682063441125, 42.468486370578894, 44.77653841818533, 45.46592635493125, 44.00068575336088, 39.37314010435535, 37.660825483260616, 38.374700776992306, 37.57719662881667, 37.924287165364916, 37.25721751489947, 39.75921900041642, 45.00381231307984, 48.66323071141397, 50.69157854203255, 51.71095155900525, 49.971207803295506, 54.012578764269435, 51.05318969295871, 54.7387271542703, 50.35437630068872, 54.4529511082557, 38.05332922166394, 38.15727987597066, 50.74012571765531, 49.6261529768667, 52.08661263988864, 49.94720682021111, 53.43593543575656, 51.379311238565755, 53.599839518147135, 50.786099818445024, 46.99518788245417, 36.953743734667384, 37.288251307702836, 37.256036881477606, 39.07127449589391, 38.91026120032034, 37.686964158088934, 37.00986108472271, 36.88991108248311, 36.922702097123675, 38.22112429526545, 38.49760040160149, 38.31118191442182, 38.755884555078325, 39.95577681449152, 39.94637881555865, 38.64548552420832, 38.49745135153494, 39.702164203889915, 40.31511691308791, 45.27414206535586, 48.85730174279983, 54.01386922405612, 54.23261980856619, 50.62580823898316, 55.62603788991129, 54.086374236691384, 49.928763835660874, 40.90040122309039, 41.583780088732325, 41.76683710467431, 42.61725010410432, 42.52838488548033, 42.8221704113868, 45.244932174682624, 48.74798920846755, 54.39562959055747, 56.14140595159223, 59.590663756093676, 53.19112070145146, 30.954631528546734, 16.021263195622353, 6.750094592571259, 8.0225438360245, 7.144131977711955, 3.532275994939189, 2.2037388192069147, 0.231826740106748, 0.0857801519093975, 0.6814035845379676, 13.640910098629615, 41.03527192146548, 46.50855902702578, 42.01877486321234, 45.544091347725164, 62.188673096318404, 59.21979581156085, 29.86878218189363, 2.2945225671414406, 0.02049052881287231, 0.0560310808941722, 0.08136396912196953, 0.03702009577424296, 0.0527256528185981, 0.03312252003759627, 0.04567859386424384, 0.03179284421006038, 0.0901343428619927, 0.044072433074395505, 0.03508763515480584, 0.0427082488163104, 0.04654719967455153, 0.01814341352831933, 0.0196457943022852, 0.0645917916910783, 0.022580311333219853, 0.029069001358302853, 0.020837375120590293, 0.11344313486329011, 0.24355741548201731, 0.19822906552543565, 0.13995736897472413, 0.08077491645611103, 0.0896646466947371, 0.18156876757500634, 0.08468358897634091, 0.1476515423987181, 0.12469687454041936, 0.16115332112437294, 0.27986460515568334, 0.23698389079541932, 0.18810362014318668, 0.21080222311279467, 0.1847218628972769, 0.1812153405720188, 0.15863468449923301, 0.15622150753774952, 0.31792523219220103, 0.29124946844193245, 7.783401339284836, 41.28597413339923, 65.67547582810926, 61.376793461461226, 54.84446640937559, 39.956910379471324, 51.29292888026084, 49.94965045682846, 15.19161718506967, 1.0231585331982183, 0.6451150414443786, 2.933311193220077, 6.019947346179716, 12.380961448915544, 15.913727494978136, 15.987865194197624, 17.340882862767867, 30.690867823939172, 42.97209124411307, 52.70861817944435, 59.674210240764005, 54.3050189172068, 48.801019653197265, 45.515454123097086, 42.62676185177219, 50.83656111071187, 57.539915269420995, 55.08013417643886, 50.981743720269975, 54.62353890941989, 50.01189454909294, 47.02420557698896, 45.32078689144504, 47.860858901854485, 50.42974464354977, 52.87082387555031, 53.59577986501879, 52.12163156078708, 53.0847107210467, 53.90961262487597, 46.83929720232564, 40.87021858461442, 39.126191600676506, 38.949869294320386, 41.44808569262105, 41.48894502270607, 44.40434471253426, 47.5962911113616, 49.35874931273922, 47.097028301608184, 41.32330725269933, 39.22092860744846, 40.379647747162856, 40.96551256795084, 39.994333713285386, 39.09081182172222, 40.6237486100966, 45.87442159652711, 50.305574171004764, 54.405670858198604, 54.52475401663012, 51.98088907426404, 56.20639962534751, 53.18903400051979, 56.504170279349054, 53.423254412989465, 54.428440217048895, 39.99170572526994, 42.67328508438603, 53.67367813664099, 52.318903246233546, 55.481102389674035, 54.02975090088383, 55.977364586245635, 55.30302678385089, 56.432822365914625, 51.8396641362098, 49.227455815961285, 39.08566567205614, 39.91864373607021, 39.80878991465415, 42.02063406667402, 40.186090546269575, 40.07112587651899, 38.07487872339065, 38.612780801711544, 40.0267207237982, 40.184113671702725, 41.239039051917295, 40.67680651141752, 39.4446135336353, 42.214328550523334, 41.75385798177412, 39.47468242337627, 41.16583585739136, 43.34239828971125, 41.99444047866329, 47.48857498168946, 50.98742331227949, 54.61099124723866, 56.691114364131806, 49.951686166947894, 58.13500550485427, 56.46063589280652, 51.503054172761985, 44.0061378479004, 43.231316766431256, 44.9163277687565, 44.44176412397816, 44.53645013993786, 45.258483963627974, 47.22355611862675, 53.544428194722826, 57.098040657658736, 60.15830916743125, 62.45335463554629, 53.49823051883329, 29.627279889199045, 20.023413396650746, 8.31888625698705, 8.217186062566697, 19.244883714183686, 10.012501958877811, 3.5498111959426635, 0.9589063712666113, 0.2029406747991039, 1.0171084610685226, 17.35690574492178, 46.50212241757301, 59.74101212716872, 54.55889040423978, 51.94144179744106, 68.55673913032778, 66.38891573875182, 36.109065240429295, 3.368465068840212, 0.15696262099569844, 0.16781139127429456, 0.18527484048278103, 0.08743251929239881, 0.1803538747011654, 0.3155013299997776, 0.1791173321825843, 0.08534545829940228, 0.15802745256693135, 0.2004694896599939, 0.13662191408295787, 0.15114778382403238, 0.14398912118086893, 0.05954381236205659, 0.15120911682325025, 0.14703553109880418, 0.16941105946898463, 0.13252553469952078, 0.09304292590147065], [0.023053970090263796, 0.05137966314871466, 0.017589269573950482, 0.0118344965683777, 0.05027741967369953, 0.0550719847782485, 0.08571812943104776, 0.05654271654484253, 0.03934674310467897, 0.030856238520373742, 0.037469712777003165, 0.03957332893004341, 0.05197407843004312, 0.08969817836318286, 0.03918769176027948, 0.0631910458868069, 0.09533536740608754, 0.05074718478886832, 0.005762056586512875, 0.05124039985539933, 0.012499399599619212, 1.9239568902600197, 24.200584657730598, 53.35915503963348, 46.28462306914791, 27.88374516271776, 23.825321697419692, 23.338630084068548, 35.685096248503655, 19.83684389821945, 1.2496426220863097, 0.38685908000315394, 0.34237992318887867, 1.5444053084619584, 3.415356513953978, 6.132996918693666, 17.198873450679166, 17.4530351931049, 21.37620552893608, 33.00704702254265, 47.96601764617428, 52.50413717762117, 50.032000618596236, 44.2462771169601, 39.60420300883632, 41.18091344833374, 46.14180172643354, 51.761561901338645, 48.387374339565156, 51.85384350438272, 48.20245419779132, 44.19866738780853, 41.5038029609188, 38.273703667425345, 41.329677181859175, 42.65494015909011, 46.97203020895682, 46.81975595412716, 48.87649782242314, 49.40716312777612, 46.80267403202672, 39.017526257422666, 34.18010242523686, 33.69699978059338, 34.41351482945104, 37.746329230646936, 38.422859637968, 44.70614364070278, 49.12489368069557, 51.57219771415957, 49.90059729545347, 48.1684668602482, 40.39147761560256, 34.99470418499362, 36.40586314662811, 36.240958859843595, 36.430507398420765, 38.998502762086936, 37.634314183265936, 38.49233658083024, 40.665474783989694, 45.08151054382325, 45.366949266003026, 48.27883058978666, 47.13484387243948, 50.13242113974787, 49.66640826194517, 57.857623331008426, 39.16292459734025, 34.03484136827531, 47.840121330753455, 46.08810055640436, 49.45196051751414, 47.40973926359608, 51.43592280726279, 49.12041825632895, 52.970150055423865, 48.63572312939552, 49.2628748186173, 40.23395522948235, 35.473653039624615, 35.44003440487769, 35.861410710119436, 36.34392499923706, 36.92166266902801, 38.67086718159337, 37.36847162246704, 36.584503573756066, 38.00577440569478, 34.92619214519378, 35.36311280342841, 36.69260801807527, 40.02801510595506, 37.772020755275605, 35.71531418831118, 36.269015573686175, 37.57497656729914, 37.436689484503965, 46.32783582133632, 47.40290257238573, 49.710154456477014, 51.48393654054212, 51.23432082514609, 51.070404975645005, 51.581893813225534, 46.18654812535932, 46.8325585703696, 46.70550907811811, 46.61613395137172, 43.18671157283168, 41.759353222385535, 40.784942334698094, 43.831129535551995, 46.3485106345146, 51.465509245472575, 55.703292892825225, 59.047905783499445, 47.89952170464301, 25.614212751388553, 9.08970848206551, 4.496707637463847, 6.3953034627822145, 7.989050717123094, 3.3324336861410453, 1.6652679972110258, 0.7253701672438653, 0.03343431782277842, 0.8115939147049381, 12.72262538633039, 41.57851626796108, 45.53386180631576, 28.311652214296405, 34.883199045735026, 50.91745999551589, 50.84709267462454, 23.527594189490042, 2.16416185902011, 0.03993250925334231, 0.0767235447382254, 0.020648999845669157, 0.016284141118728345, 0.014936677687200568, 0.042274432376988476, 0.03617520038519175, 0.088081794129985, 0.026590808429905487, 0.04068070902459083, 0.025410724676124034, 0.038585485364761085, 0.05458615479930755, 0.0070337318973014915, 0.04141616492321895, 0.04753497429192067, 0.02320696742484166, 0.07557327138079752, 0.05813188550453033, 0.042489343022386876, 0.009300440508541803, 0.05112838630955066, 0.061422191004479126, 0.03341533416401475, 0.014905452901016802, 0.05166351404641906, 0.04700317137664364, 0.024811592208401814, 0.05272880143996689, 0.056389839869112744, 0.031417453466283704, 0.030232685084845272, 0.045702438350887074, 0.010961012693212159, 0.07395415987458921, 0.14877212984908014, 0.04102496978556437, 0.11422898785601701, 0.04218002353163977, 0.054680942858178774, 3.108832355468504, 31.217953966509913, 58.24895820310039, 54.28015501268449, 36.21291783548171, 31.36141661674746, 30.47464324582008, 40.73478698730469, 20.66202036796078, 1.1761061486697968, 0.44960287609888666, 0.24612665987543522, 0.4425161950770886, 4.783174020628776, 6.423562668984936, 10.505221274591262, 13.011740349954175, 19.31831244499453, 33.40671693125079, 50.48564626324562, 54.17723201936292, 50.63222915895524, 48.1122043824965, 42.93120053506667, 42.678372398499526, 49.884813677880075, 53.73470629415205, 48.70520399462793, 52.66409143324822, 51.27532528292749, 47.19159664646272, 44.50931910545596, 41.52208120592179, 43.528973671697806, 45.50504023028959, 49.09395010240617, 49.91613380370602, 51.08351353676089, 51.978727848299094, 48.93693762440836, 43.00687090043099, 35.900261786676225, 36.62573552900745, 36.591352032076934, 39.8093351241081, 40.00592431714458, 46.466479839817175, 51.564627539727, 53.381979311666186, 51.348575545895486, 47.95131660276844, 42.60383167574483, 36.83932035200058, 38.34565170349614, 38.364486925063595, 38.86963329007549, 39.775100677244126, 38.1974841702369, 41.88530445098877, 44.000638684918805, 47.96925360156644, 47.844812485479544, 51.77636884873914, 49.223313793059326, 54.041619993025265, 50.778906191549, 58.13347185811689, 40.58386987255466, 36.77196541140157, 50.13441762616558, 47.3119310409792, 51.468274516444055, 48.53701668400919, 52.61974119370984, 50.70814663364042, 54.508593851520175, 50.29572902187225, 49.41114825587119, 41.7471311169286, 37.82050909534578, 36.329294558494325, 36.77240863923104, 37.3107421782709, 38.31376675636538, 39.34481274697089, 38.96240126702094, 38.664371736588016, 38.85881539314024, 37.71032187246507, 37.363984430989916, 37.83546117044265, 41.01482068338702, 40.579151261237364, 37.25587606430054, 36.24166096410444, 38.90589167994838, 39.750601553147845, 48.39153205194781, 50.147067269971295, 52.787249934288766, 52.185550505115145, 51.54181895717498, 53.417013922045314, 53.813024259382686, 48.64703524497248, 49.86774744526033, 45.78658403888826, 48.2288242924598, 44.449369599742276, 43.782994208797334, 42.721698899422925, 45.708481804017104, 48.88758636290028, 55.33412333457701, 56.3860284897589, 62.256075105359486, 51.09903043316257, 30.936949483809936, 14.751142859458925, 10.154659440440517, 7.2103587465901535, 7.367504094877551, 5.819872636948863, 1.060501397136719, 0.4995170283702112, 0.12706654536868298, 0.939251987203475, 14.9691197564525, 43.6286489425167, 50.03119261034074, 35.72940726434031, 40.93518872414866, 57.083547499872026, 56.70005736812469, 29.223979826896425, 2.8514790294631838, 0.041502476219208016, 0.06725531852533741, 0.012143701145936166, 0.02790244288682457, 0.047378516155144865, 0.025348480032276244, 0.03225816601526833, 0.02244493402090044, 0.022896590732759046, 0.028903668092924262, 0.055407198040836284, 0.05319489316353875, 0.062410325683172674, 0.015083511844427596, 0.06103869505046357, 0.054241675703275594, 0.016292363157375686, 0.09818418792659238, 0.018785167297708894, 0.10798612203929694, 0.08877549440630021, 0.15714424512078687, 0.13064871121558452, 0.17224681052950122, 0.21506334204346905, 0.14216411588413103, 0.1253796274202966, 0.1145853566366338, 0.20285254404429467, 0.14500761975444135, 0.13558161264706042, 0.16069156928889214, 0.15287911188938927, 0.168881508852205, 0.0581964360730302, 0.2729461263985403, 0.1348092121582839, 0.15866339747463504, 0.1496247857088043, 0.15209626196132553, 4.322609805291699, 36.850353979295306, 64.40399246831095, 58.88257003599598, 41.29522308226555, 34.54907978734663, 35.0374109514298, 47.07243111825759, 23.855400393086096, 1.95542962080048, 0.5978458843404247, 0.5544260432643275, 5.613364260042868, 9.834650908747028, 11.99812243061681, 27.184502270913896, 25.866403502802697, 26.343687311295543, 34.64932380184051, 51.96846692792831, 55.52253046343404, 53.60718219510971, 48.691185443632065, 45.709858555947584, 45.645943533989694, 51.35909534269764, 55.34217988291095, 48.64094772646504, 54.70845037891019, 52.46144610066568, 50.51592303860573, 45.640915055428785, 42.097324248283144, 44.80633666438442, 47.46039275200137, 50.61561399890531, 53.07225719574959, 51.78819479480867, 53.65404667392854, 51.29896540795603, 44.46697319707563, 37.486307467183764, 37.79245630387337, 38.38690719296856, 40.541747539274155, 41.755003313864435, 47.90976301316292, 54.511680756845784, 56.67223991886262, 55.18402207282282, 52.06353733616491, 45.160358029027144, 38.477498254468365, 39.824106770177046, 39.295469330203154, 40.4369378858997, 43.96113649491341, 42.02795713178573, 42.76786911872126, 44.508809197333555, 49.7177363980201, 49.51584416051065, 52.13290837503249, 52.05816761139901, 55.30669812233218, 53.91224453526159, 60.54000285363967, 43.690924413742565, 40.97634615436677, 52.40119849481891, 50.21983508140811, 52.818217046799205, 50.52262636923021, 54.389891162995376, 53.61117124557496, 57.36165923456992, 53.01928950894264, 53.27156066894532, 44.74607336905695, 39.76446713170698, 39.72273311307354, 38.798869809796734, 39.97882073925388, 40.44899132943923, 41.49928439048029, 41.34431938971243, 42.07557470567765, 41.98622311315229, 40.232998171160304, 39.51158408195742, 41.03442861187843, 43.49318596624559, 42.98028507540303, 39.903997605846776, 39.711738709480535, 41.725840491633264, 42.46205760586647, 51.3057432636138, 53.55477540723739, 55.224857868686804, 52.78027203775222, 50.1520251458691, 53.421434433229514, 57.71022065993279, 53.703601898685584, 52.495209863108975, 49.9482697825278, 49.280937333260816, 47.89482662754674, 46.434692951940725, 46.55496851090462, 47.45820014707504, 52.79991918994535, 57.739803175772394, 59.63501007326188, 62.64067919023576, 54.65445503111809, 30.330729523012717, 12.190489192162792, 7.521752772792694, 13.2241278694522, 15.847772840530643, 13.668229406879796, 5.560833917510125, 0.9510410384785746, 0.24799370807745766, 1.2438692609148643, 18.55728045586617, 53.30864667892457, 56.973764281119074, 38.73287985401769, 50.08665492457729, 65.12477897828626, 67.7465892607166, 34.48936954621346, 3.6910851636240563, 0.09342701940406715, 0.2286117602019541, 0.06207895052108554, 0.1526328299434916, 0.11622037212815016, 0.22270971158098793, 0.33381803261656917, 0.2325415767488941, 0.12769535799781162, 0.07404339379600941, 0.18566819598838208, 0.11777098005216931, 0.1799818624051348, 0.07044016819206939, 0.14501695070535908, 0.15532533788392622, 0.11762664908723486, 0.22232320490142993, 0.16203226912165844], [0.03167968536276491, 0.06430976408263368, 0.012268110952009598, 0.02571551084157921, 0.07502015589946702, 0.0190775026191747, 0.018016834735810276, 0.023756103079405524, 0.02220189071170265, 0.04637465752180546, 0.06733833181281244, 0.01980656359885489, 0.041675049015471054, 0.06316775681390878, 0.03291691353003825, 0.03747435526982431, 0.03591408314664037, 0.09906934889694376, 0.04765716914628302, 0.039960379532027634, 0.025515169273280812, 1.992641146625242, 23.32124613946484, 51.86283749918784, 45.052869396824995, 32.96565817248437, 24.507894515991214, 40.145191992482836, 45.6277084350586, 22.861840494217414, 3.737992298218512, 0.011688546285093313, 0.37109905793782205, 0.6973982133692311, 5.2536667354645274, 5.054513292927896, 4.781540843748278, 6.5178790015559045, 14.557986720915764, 24.514362504405362, 45.41991303043981, 53.37446405041603, 49.27775629105107, 45.6026444896575, 40.27508128073908, 43.862257465239495, 48.72838520234632, 56.63704449130643, 49.18158761916622, 52.22576264412173, 48.17713922069919, 42.99164425942206, 39.56265726397115, 38.07469437199254, 38.85464591364707, 43.14738588948404, 46.18858383547875, 47.63317708046206, 47.91504252341486, 44.090578632970015, 42.053162282513036, 36.03048447639712, 34.42568594409574, 35.251423312771706, 35.48298043589438, 35.42498427052652, 37.7311182791187, 46.53445059253324, 47.67140842253163, 49.62274835955713, 51.440445300071474, 51.37435728503812, 49.086234800277225, 41.142587969380045, 36.09144203124508, 36.81772378183181, 36.24260625531597, 37.243504908777055, 37.471598579037575, 36.54092211877146, 35.548370269037065, 37.67679737460229, 38.46520554634833, 42.324605987918, 44.05407313377627, 48.49328617895804, 46.979749433455936, 53.68054228444254, 43.48666306464903, 34.10340832125756, 49.70596928750315, 48.522637274957475, 52.593551528069284, 46.83093078674809, 51.32766931287704, 50.55291883407101, 50.60894596961237, 50.69042144283172, 47.851939432082645, 43.93242082288189, 37.061071549692464, 34.750611166800226, 37.80902831785141, 35.7836732556743, 36.57095178481072, 37.66985477939729, 40.337756833722516, 37.538792702459524, 38.22226570498559, 35.46255273203696, 35.47592409195439, 34.71703175575503, 35.58592696343699, 35.35512685775757, 37.304117295049856, 37.17487912024222, 37.47092785373811, 41.21488901876634, 46.86505540724724, 46.9374898172194, 52.448753310788064, 49.13453878894929, 50.80293855359478, 50.986591769802956, 54.911864496046505, 51.17585005298738, 52.02728286866219, 47.43804700912968, 51.2006276653659, 49.02796799136747, 46.602829271747225, 40.27076667354953, 43.42549370181176, 47.99018729117609, 53.964568953360285, 55.034344427047245, 56.32826766660137, 43.02392536594022, 30.169210241686915, 12.108962728131203, 11.969021385715855, 8.472954015577994, 3.4420283859775913, 2.2989063061052755, 0.8138926074870172, 0.18005914535493622, 0.010212833031771645, 1.1480410997906039, 13.702484446187174, 37.35863431807488, 39.41350129342849, 26.70926005609574, 28.004399230403287, 53.58058068060107, 50.94471654584331, 19.459539344233853, 2.6530602958894547, 0.0478129607865647, 0.04425904443187099, 0.033286485836030014, 0.03143105152693968, 0.059874521027649605, 0.05777657775568867, 0.035475229679216305, 0.06778214952998585, 0.037056718607463186, 0.11712051011742124, 0.05865998438469345, 0.04450610395701182, 0.09124526994362955, 0.06356665113520238, 0.01971500077014489, 0.04077531705279985, 0.005529569490106717, 0.0628452529499848, 0.031204502090751648, 0.06489533870931595, 0.04304118679776307, 0.031752477122110226, 0.03180072150914179, 0.07737655808488209, 0.05130324587826768, 0.08949440663620349, 0.029967337125732057, 0.029518627937162117, 0.02589848711185398, 0.06354257299174225, 0.015670577469732494, 0.05941592930485645, 0.017231406921881343, 0.006308873388690935, 0.021496120720140396, 0.016415084697185986, 0.061501327887057304, 0.023574049945079514, 0.04858017486009387, 0.016651840339745247, 2.6695423405016623, 27.92856412549173, 57.52868944598783, 52.27184657127627, 37.4153047223245, 28.16155879728256, 37.17810723089403, 49.567615524415054, 24.530061791020056, 3.4222991091589776, 0.10428993932662473, 0.12422987500265723, 0.7978770797771793, 3.2143068505871684, 6.6636563404913876, 9.199088677283257, 8.550038395389434, 11.65507193534605, 26.557762430560206, 47.51927929539835, 55.97933361607214, 51.69280275221794, 48.10670129714474, 43.318475754030295, 45.75571498563213, 50.21315920737482, 56.60508109677223, 50.15163683122205, 52.82159812988774, 50.40903845141011, 46.329130203493186, 42.150503743079405, 40.14156380007344, 40.81348542244204, 45.228152275085456, 48.01863231966573, 49.373395442962654, 49.8218321800232, 46.668780003824544, 44.47489246245354, 37.42325928903396, 36.829643864785474, 37.22327724579842, 38.318705020412324, 38.861694412846724, 39.44505283909459, 46.49536809613628, 50.495816969102435, 51.84426115405176, 53.66391927965226, 53.306246188379106, 49.40918314841486, 42.67957656614242, 37.726897808813284, 37.348993132191325, 38.481275496944306, 39.95719279012373, 38.900467042000066, 38.53837343954271, 38.27449990857033, 39.32199239730835, 41.17492791145079, 44.72035438783708, 46.49303820825393, 49.34748426560433, 48.78823272643551, 56.20851770524056, 46.01391284696518, 37.265077944724794, 51.849313166833696, 48.51463956217612, 53.79793882369996, 49.44970907703523, 53.96916204883207, 52.88467376462875, 53.62763735555834, 52.22394266436177, 50.75948261445569, 46.754264139360004, 38.55719297162948, 37.345251191046934, 39.003641067012666, 39.13938645393618, 37.48364025546659, 40.002943315813624, 42.15090382483698, 39.15673901957851, 39.27112317854358, 37.57490204226586, 37.79538239202192, 35.98968005949451, 37.63243929032357, 37.666297189651, 38.59631469172817, 39.69401351867184, 40.18226623535156, 42.404249714266875, 49.19129156297254, 50.19324533400997, 54.88281542255033, 50.054377740429295, 51.59617908539311, 50.8836805435919, 55.57638068352976, 52.841645363838445, 52.777855857726074, 50.55054187774659, 52.630774821004565, 51.17638741770099, 48.42969671372445, 42.36315111960135, 46.628862042580884, 51.138148230891076, 56.18295169645741, 57.072333443549375, 58.75180998156148, 46.09584723749469, 33.35129776308614, 16.040464178208385, 7.111832239935476, 8.129117575383956, 7.904730054640002, 4.916143840359104, 3.0062108943539285, 0.23924668469736654, 0.014310928452159128, 1.2997251604833913, 15.983004396961583, 42.70334612938666, 44.57488544525639, 28.810938558270855, 34.18596636864447, 60.2118730545044, 60.35995821799002, 24.13734820581252, 2.7277927244863203, 0.03318524348639673, 0.05949549519667222, 0.05999757007004754, 0.0275450571244883, 0.04398902142119985, 0.0313104099158438, 0.05739488210829516, 0.0413657754899994, 0.058571524212076786, 0.024032789139798092, 0.05264945005276992, 0.08690503711301474, 0.04959394284073384, 0.05800487195712425, 0.02559773822975976, 0.07338125634217456, 0.02975585089335519, 0.05382597341292328, 0.026937853920483784, 0.19819229330507018, 0.15583279452496962, 0.22187047758169715, 0.12649758718907833, 0.17062874090286995, 0.12502631533049768, 0.1866580428735864, 0.11551473620197467, 0.12912128511215412, 0.15349179836771182, 0.1714786388460667, 0.1130433978452798, 0.2070903892238294, 0.1595749348522194, 0.09718991305318572, 0.11647692731311245, 0.1839172407504051, 0.18655170986969627, 0.08936553532558103, 0.14087449879415576, 0.20579395395132805, 3.6468832387078196, 33.3705722901129, 64.92534214450468, 58.565799420879735, 43.98499627267161, 34.94862025783908, 51.22431878120669, 55.42659321138936, 29.57836008840992, 5.061751046488363, 0.2953805209648225, 0.675101132402497, 2.092621994595374, 11.815615527091488, 13.09941512923087, 11.745709084695386, 13.406641637125324, 16.94057360772164, 26.67321151302707, 50.94578735290035, 56.69697438516925, 54.93633224118141, 50.54041431796167, 45.07119078789988, 47.85837211916524, 52.71735329781809, 58.94102904104418, 52.265849267282796, 55.10672392383699, 53.516814708709724, 49.067325053676484, 44.31674249710576, 42.90827428140948, 43.394087283842026, 48.11028634348224, 50.83140319393527, 52.05164078743228, 52.2819584415805, 49.94028775922714, 46.387412701883626, 38.54297437975484, 37.31098144285141, 39.664121135588616, 40.851261769571614, 40.68123094497189, 41.43643625320927, 50.08118321818691, 52.1998240101722, 53.142706886414565, 56.09158792803365, 54.93204509058307, 52.09575960713049, 45.81977121291622, 39.34367133725075, 39.62258715783396, 39.666007795641505, 42.68688394177345, 40.83113608821746, 40.46730487577377, 40.66619257773123, 41.349610667074884, 43.32319828771776, 46.49978860732048, 48.93088932960264, 51.54665131722727, 51.85224709972259, 57.122002417041415, 50.656932246300485, 41.25892546869094, 49.98645797852547, 50.31280309923234, 54.660593540437766, 52.108017013918975, 55.98624875468593, 54.793220643074285, 55.62387666394634, 56.09505922563615, 51.134245472569624, 49.73877599162441, 40.495032110521876, 39.49667515293245, 41.80858681278844, 40.436808447684015, 40.384676225723766, 41.912333503846206, 44.488271667111306, 41.48846257117487, 41.58802409325877, 39.21009502103252, 38.62676012900568, 37.249972897191206, 39.64549379964029, 39.76345123783235, 40.842718847336315, 41.63921494637766, 42.48990643408991, 45.1603070382149, 53.35052582525438, 52.997626258480935, 58.60758050795525, 49.464570937618134, 51.88395554019559, 51.37857383297336, 57.32545968024962, 55.53849843240554, 56.65487166373961, 52.034331367861846, 55.356253347089215, 53.61086137833134, 51.36263724296324, 44.33897056887227, 49.151275542474565, 53.701997649285104, 59.67435536846038, 61.2135208806684, 62.19008907195061, 47.84795822635774, 32.262336015701294, 14.984458185011341, 15.59976725809036, 13.78602602789479, 10.98108518508173, 6.677445432832164, 4.18642952557533, 1.2177475013079182, 0.1381117405910646, 1.8462948188666377, 19.23417172124309, 48.550929331010394, 52.01215428690757, 38.80959749221802, 42.778126116721864, 69.0615560162452, 67.37424650499898, 31.008458214421427, 3.3846745087254435, 0.2921599792616983, 0.12106990787170588, 0.12067894256042859, 0.12546968105579578, 0.1512572118231366, 0.3121526983957137, 0.12086637363198305, 0.15606779965662188, 0.12846598116260383, 0.2378953209206943, 0.18754405420153372, 0.23253285866831583, 0.2072406037440223, 0.1745312693979471, 0.15897282038725194, 0.23830582147404072, 0.17202415473518834, 0.19909655284737388, 0.149790138126381], [0.06201540352776647, 0.011524140943713006, 0.023853756307113557, 0.12180433338207584, 0.04338030710876469, 0.10740900502329874, 0.07953680345728513, 0.0536974928071422, 0.050450145687547424, 0.05193242622959999, 0.04354427290719844, 0.03955321529159143, 0.011126395754305827, 0.04847912403244165, 0.030475203623814933, 0.06556655430505354, 0.11400784891579421, 0.05200410907667491, 0.019809532189561475, 0.06273107520575005, 0.057397590229107495, 1.1593171785916052, 21.646690214833907, 50.912443284065496, 46.43515186925089, 37.38912682379446, 35.25587912528746, 26.983947561633205, 35.28114703393752, 32.765793800354004, 5.327969174231253, 0.1146506809539372, 0.06635023160807549, 0.08464703892147349, 2.537653624050079, 5.089995543802939, 7.630260730943373, 7.390420052313036, 7.263225432365172, 20.9763002780176, 41.50564647489979, 53.65095976860293, 51.06392129775017, 49.59441707980249, 43.794988816784276, 46.229976607907204, 48.48786154100972, 50.81205021950507, 45.47840733681956, 53.78078629893642, 46.417097199347715, 44.729183643094956, 37.043597390574796, 36.168022386489376, 37.72569364117038, 40.49257278442383, 42.27591368459886, 46.47882353874945, 43.35637369463521, 41.98023365389916, 35.86919661491148, 34.05229983791229, 35.07049614383329, 34.792796258003484, 35.664307686590384, 35.994037812755955, 36.66217434790827, 39.99585167054207, 46.29159312094412, 50.38842639615459, 50.8737491023156, 52.32162929350331, 51.90043341728949, 49.453725584091686, 39.25468844752158, 38.188396038547644, 37.11074444555467, 35.563667512709095, 37.98316586402155, 40.547752688007975, 37.668458415615945, 37.7818541372976, 35.07703865728071, 38.83269633016279, 40.07593862472042, 46.76566254708075, 45.984981444574174, 54.124342779959406, 45.62074622800274, 34.31155673919186, 49.41647875693537, 51.37762461939166, 52.70063615614369, 45.96582066628241, 47.96737086388373, 45.31452678865003, 49.09251059255293, 50.15671237822502, 47.86385951503631, 46.39459456166914, 41.33532539490731, 35.961270332336426, 37.34478442899643, 35.31502454511581, 39.700846287512014, 37.43991367278561, 37.615561331472094, 37.88133328960788, 40.40572758643858, 38.20202235252627, 37.75358953783589, 37.70621515089466, 36.45648917844219, 36.47591667790567, 37.209113567106186, 36.63474129092309, 40.57108294579291, 44.61481909598074, 48.42297769361927, 52.840664771295366, 52.36438705075172, 46.948233189121375, 52.15347336184595, 48.86901394013436, 53.05357102424868, 53.08094524568128, 50.7969137930101, 49.66271731161302, 52.333741572595414, 50.485336396002005, 47.51236415678456, 44.8545112148408, 44.77801715174029, 46.451916079367365, 51.397903273182536, 54.250564652104536, 59.32926524070002, 46.042828559875495, 32.63641834259033, 14.420849873173623, 10.884628218989219, 4.373755551153614, 7.08204330936555, 6.919402230170466, 0.9180808716243314, 0.6036584692135935, 0.14211154693076689, 1.5341626516272946, 15.50590592045938, 40.52490880412441, 43.91831205737206, 39.0156513644803, 44.72523773870161, 50.397836162197976, 45.236628517027825, 18.156988851485714, 2.4745176828676656, 0.05624569659571975, 0.00937246043430341, 0.04657023976887426, 0.09329830897190879, 0.06747479505476452, 0.06233976898534645, 0.05861209239810706, 0.03058700458026461, 0.049629067972062096, 0.023314652573918144, 0.0533390096238544, 0.0334278175667409, 0.03917284880674655, 0.06493190408594186, 0.13797709297749305, 0.03795014949695718, 0.01731348175164913, 0.037683466629635905, 0.03956120175820205, 0.02683710952800128, 0.016918611307177815, 0.08724065257176276, 0.04339521901021081, 0.05650833451880082, 0.0217536986324816, 0.06840820424258709, 0.01718751199903988, 0.04080786812870253, 0.045169899991202744, 0.03583076342399563, 0.026097156693257635, 0.03333179227587196, 0.00991446859834175, 0.10770089218332883, 0.09604357738768864, 0.04572146414448658, 0.04591628796451035, 0.022054958878265276, 0.024118991268257943, 0.020748777052147255, 1.9556151979392575, 25.59265736610659, 57.41733335679578, 51.3461083750571, 40.59085169146138, 35.98740900716474, 37.35199766774332, 45.57214806156774, 35.80843910094231, 5.771564235610347, 0.11911693524809615, 0.08114577195937596, 0.2839256985293281, 3.5160491495363178, 5.2764880657196045, 12.713853986032548, 9.408189250576882, 7.817181771801365, 21.821982899019797, 45.72863494196246, 54.66544158997075, 53.32305354456748, 51.93008261342203, 44.177008059717, 46.862231300723174, 52.35640894982123, 52.18264010644729, 47.83730114659956, 54.80631743707965, 48.71723782631659, 46.55774947135679, 38.8540889370826, 38.325745674871634, 39.74279211413476, 42.71942000235281, 45.26116686482584, 47.23848858187276, 45.93064092820691, 44.703652935643355, 37.85979947736187, 35.99218645403462, 37.20091973581622, 36.12783378170383, 36.370977586315526, 37.505362341480875, 38.23041246783349, 42.81264689660842, 46.56463323100921, 51.359628785041075, 53.665817706815666, 51.134708312249955, 54.672768577452636, 49.56211636143346, 41.77023779961371, 39.48193880819505, 38.94394651536019, 38.05569441087785, 39.605160067158366, 42.24222444718884, 39.185576285085375, 39.12081403117026, 36.669987709291526, 41.358792935648275, 41.60565514718333, 48.311103851564475, 49.22778529505576, 55.00305960255285, 48.44817499960623, 38.07420015335083, 51.27009676348779, 49.45596525746007, 52.797251978228175, 47.998577240974676, 50.722969270521595, 47.97075979171261, 51.91531881209343, 51.7079980142655, 51.10130933023269, 47.8373521374118, 42.19314382922265, 37.44978627850933, 38.28866750963273, 37.66705420709426, 40.68028565376036, 39.266075088131814, 40.16194051311862, 40.53302026564076, 41.019182359018636, 40.08202222085769, 38.3439846961729, 37.34483934217884, 37.450370711665, 38.082123341098914, 38.83836807743196, 38.31283715463454, 41.57460958726945, 46.07256012578165, 49.60323064557968, 55.41381020699778, 54.04095319009597, 47.97375256015409, 52.777106685023156, 50.89936217954082, 53.43475872470487, 55.09468616977815, 52.91588406408987, 53.10946872157436, 53.9140841268724, 53.22179755856914, 49.37845137811477, 48.17388757582634, 46.60078963925762, 51.6331748808584, 54.12668443495228, 58.56992967667119, 59.53573096183039, 48.790291970775975, 29.943689646259433, 18.767511652361964, 10.178092660442477, 9.057287150813687, 8.633972214114282, 3.7931555317294214, 2.192996427897484, 0.4619742767705072, 0.13763518793688667, 1.6041673984258407, 17.367437308834447, 46.35917948138329, 50.37763203344038, 42.193453696466264, 51.08106990014353, 58.48152729772753, 55.32123442619078, 22.91396094906715, 3.0964619353894265, 0.04496414792693911, 0.11486428924986433, 0.03347289801064519, 0.06969710120991354, 0.04047297662304294, 0.04101858444271549, 0.06143239529563054, 0.0215698758350505, 0.016270341959992246, 0.014577004194800413, 0.039077095477090734, 0.02183747800788091, 0.041410683564120726, 0.05366697186423887, 0.07961670642778759, 0.04736754960650879, 0.06586554310014171, 0.07342978801217771, 0.015924418788223017, 0.09136883226493675, 0.12570119282651332, 0.1404591105998524, 0.20256124677196627, 0.18277239895636038, 0.21227442959864296, 0.2199050636901971, 0.15139378997827732, 0.10910780499539069, 0.17284503326781336, 0.15683911230054595, 0.0764488026259407, 0.13791683250136916, 0.10404299088423291, 0.15058412697286377, 0.2007761240125664, 0.2275711982961624, 0.09806572008998164, 0.11614262952559418, 0.07048841640954057, 0.18414889041694904, 2.501900729633147, 29.660633763959332, 61.728936010791415, 58.87070486622473, 48.47960887416717, 46.11206231578704, 36.531606489612216, 44.54563240851126, 41.231872881612475, 7.030952966982319, 0.48835163395251, 0.39798154285357845, 0.6712608255686299, 8.38078910304654, 13.062901785296779, 16.329708580047853, 13.772409519841595, 9.449033871773752, 23.854672793419134, 45.84907916284377, 58.21400596249489, 56.63927631993448, 54.771824113784305, 48.95672205955752, 51.38922699036137, 51.79740451997327, 55.53805128220589, 50.05811183683334, 55.69673861226728, 51.710398504810954, 49.22873058626729, 41.21022139826129, 40.9386404099003, 42.04238753164969, 44.47789307563536, 47.05880088190879, 49.95505940529608, 48.01347048051896, 46.446189418915786, 39.6652860795298, 37.720943650891705, 39.948638100777906, 37.2497610892019, 39.21586090518583, 38.39016276021158, 39.47417251525387, 45.58371120883573, 48.716131717928, 55.54372695184524, 54.29856661827334, 55.25328720769575, 56.852009988600216, 51.93467570889381, 44.19201897036645, 42.06002643031459, 42.07458234602406, 40.06315954269902, 40.752774976914935, 43.97076199131627, 41.85012863528344, 41.41214501473212, 38.94935154145764, 42.44917261985041, 43.643075420010476, 51.173214220231586, 50.60367430410078, 58.52437134711974, 52.338036567934104, 40.32901387060843, 52.41115739268642, 53.50910725132112, 55.756809711456306, 50.98457959390456, 53.35120047292402, 50.4987822809527, 53.782825931426025, 54.79583686397922, 53.74022899135467, 50.87635355611002, 45.50402825878513, 39.91144226443383, 40.604838863495864, 39.84075330918835, 44.06132951859505, 40.73249632312406, 42.54832621543638, 40.24916225864042, 44.353028343569854, 43.13720733888688, 41.13559046099263, 40.30977464491322, 41.75520727711339, 39.863546202259684, 41.935404885199766, 41.794619252604825, 44.42762790187713, 49.09375006152738, 52.27646320096908, 56.983942831716234, 56.82213721736785, 50.04243804562477, 53.68096982279132, 49.81696451863935, 55.90517336322416, 57.30358069942844, 56.804804263576386, 55.01743508923439, 57.439714400999016, 55.51781969685709, 52.18797060751146, 50.91377688992409, 49.333618687045195, 52.81993896730485, 57.38986892084922, 62.7090500247094, 61.99998747917914, 49.79078269773915, 35.33151418932023, 17.40546468765505, 15.605333101364876, 11.868859740995592, 15.17224754056623, 17.022115761233916, 4.173730852142457, 1.3265567465174584, 0.32059449702501297, 2.2596325941624182, 21.22247019121724, 53.7709136932127, 58.73880340207008, 51.3199108646762, 60.04912607131466, 62.71792634840935, 67.2735200389739, 30.18577244973952, 3.341898365366844, 0.24647883049422697, 0.31088767272810786, 0.1424791772038706, 0.17847755683525918, 0.13288987079455009, 0.14181758367246197, 0.2191396652450485, 0.08131805747266739, 0.2725059322772488, 0.12755474255930993, 0.20518172712576008, 0.07056274225995426, 0.06718841606690999, 0.1786577866803254, 0.3325604533235873, 0.1834825318186514, 0.22287215286445236, 0.21880528318785855, 0.10889562928388197], [0.028776181486224937, 0.031160609083129998, 0.03083317544341328, 0.04430229392563624, 0.015953390318299496, 0.05015695234760643, 0.0457331737984092, 0.07135761210754996, 0.03770233154477131, 0.023250688062680346, 0.07155749976875321, 0.028672763446886695, 0.049170177474978476, 0.03287749830633402, 0.014953429157274866, 0.022503779149584235, 0.07807633343843684, 0.0754953985432944, 0.09932667783070957, 0.027771637204193303, 0.00945645622954133, 0.1815470872867492, 12.10511782476979, 46.809816668110514, 50.63463749424104, 43.1554816615197, 24.794598202551565, 23.982102755577337, 38.4983495743044, 34.63472866242932, 9.876942884537483, 0.2969757918148272, 0.10259969655664698, 0.38773649582459085, 1.4108831699817412, 4.3576900132240795, 9.652357774396098, 4.7915786793155055, 2.1290461046080438, 10.873253345489504, 32.770104485173384, 53.33230641580398, 51.29624720542662, 49.57728808925998, 44.47555534301266, 47.597499201374674, 50.66319627146567, 51.924975687457675, 53.63639600815312, 51.677913435043834, 48.40321679269114, 44.54775441077448, 39.00277422320458, 35.7255554968311, 35.74224125954413, 37.08460577072636, 38.68847862366707, 40.80627218369515, 42.23715282255604, 37.366734012480705, 36.69291004057854, 35.756491230380156, 35.20845374753399, 37.230384580550655, 36.29862946848716, 37.00570729471023, 39.497624366514145, 43.815220402133086, 46.12355093802176, 49.54446961802822, 52.3938597402265, 51.438535105797556, 51.10683594980548, 49.80840590692336, 47.002040263145204, 39.58550899259506, 35.79453429868145, 35.297064012096776, 36.7585862067438, 38.81224116971416, 39.461981788758315, 37.23382842156195, 37.48585639461395, 37.335833580263206, 36.520306141145774, 44.186421748130556, 44.97653615090155, 53.935865048439275, 46.6968249505566, 36.78338735334335, 53.917229867750606, 46.88470255944037, 50.55605280783869, 44.458300836624645, 46.07129320021599, 45.09960443742814, 46.48238897323609, 47.147571963648645, 47.219292502249445, 45.07707826552853, 40.90417846556633, 36.20677148142169, 36.49108056099185, 37.48881386172387, 37.750663449687345, 37.44721320367629, 41.185286891075876, 46.67977048504738, 48.46238574674053, 44.83985723987703, 41.174363090145974, 37.43475967837919, 36.89260182842132, 36.50386356538342, 36.814075977571555, 36.19787554587088, 41.011678864878995, 46.821744595804525, 50.71015488716864, 48.4984480181048, 46.43373981598885, 51.89543239531979, 50.98875691813808, 52.58892705363613, 51.13916804713588, 52.46801214833414, 52.536320224885024, 52.79798938382057, 51.044211387634284, 53.964157104492195, 51.015476103751894, 46.36898932918426, 44.03094683924029, 44.43148359175652, 48.19668831363801, 53.641040094437145, 56.86675810044812, 48.056679310337195, 28.382974632324714, 18.224741912657215, 2.9158389952874955, 11.541385958271643, 5.3435527509258645, 1.8971125565228926, 2.545273808702346, 0.08320955920123285, 0.06262970645160926, 1.879754229899376, 16.884997544750092, 41.22083140957741, 37.1434138667199, 30.119598142562378, 35.07543440788023, 53.9312994095587, 49.167482776026574, 18.15981491919487, 1.161744022561658, 0.1660966107081021, 0.07840942846791399, 0.04523275750538996, 0.05694331924220728, 0.056448135329710866, 0.0643925781872484, 0.05035888546356752, 0.0007789429993511389, 0.09199713927603538, 0.05016614923313741, 0.024701543678078922, 0.05750074396811186, 0.04192572064517487, 0.01614140361667641, 0.06697814025345349, 0.07074439702855964, 0.015110920555138541, 0.049717972475674846, 0.041232912861291444, 0.015253465577599504, 0.024723651060353846, 0.03614058853277276, 0.09023886023750229, 0.04376477216400447, 0.019214599798884124, 0.02810778509404871, 0.07654359068481192, 0.02864943990003198, 0.09090141903969551, 0.09997572284191848, 0.05217502329258188, 0.025560301428119984, 0.006143803944841268, 0.06774007598118437, 0.015548864293152527, 0.04586993198421213, 0.027534115473709764, 0.009673600978848916, 0.03994321533208413, 0.05151869278521307, 0.2602196592957743, 16.611916249798192, 52.70306410328035, 56.916693795111875, 48.11589925519882, 30.711993709687267, 25.212118817913918, 39.57695038087907, 37.929068534604966, 10.459539390379383, 0.4981244030979372, 0.04620351730996082, 0.28481362507708613, 2.36735166561219, 2.8399764337847313, 8.104842026387493, 9.552527569955396, 5.531327397592607, 15.036441356905046, 35.69681629057854, 56.751177618580485, 54.64856755348944, 52.32149985528762, 46.48290672609883, 49.818902169504476, 52.53328431037165, 52.09667351938064, 52.91505644398352, 52.98900096647201, 50.03061994429558, 47.652228032389, 42.04618438597649, 37.31679047307661, 37.59441975624331, 39.127815461927845, 42.02700007346369, 44.49183317922777, 44.028683631650864, 39.44124421765728, 37.59054053214289, 36.715204792637984, 36.725438256417554, 39.21371536870157, 37.25814711663031, 38.256500151849565, 40.0991355219195, 45.315370098237075, 47.99496473804597, 50.82657867862333, 52.56551442607757, 52.63798805975145, 53.0143080988238, 52.18810789046749, 47.90555430996803, 40.496102917578916, 38.26654926423104, 37.717331147963, 38.361721654092115, 39.9355609186234, 40.79324599235289, 37.89164912316107, 38.797897061994, 38.49647860373221, 38.707176562278505, 46.92375367687595, 48.71042466932728, 55.70519916472897, 48.09799755773237, 37.69634646754111, 52.886960506439216, 48.92315833799301, 51.97959469210718, 47.91417567960678, 47.43200263669414, 47.595075176608184, 48.15376581684236, 49.17646892609135, 49.191601430216146, 47.27060887121385, 42.418456539031, 37.464004870383974, 39.40571538863644, 39.21182478627851, 39.43997729209162, 39.00309193518854, 42.543611526489265, 48.146376071437714, 49.280262685591175, 47.006550988843365, 40.41663569788779, 39.67404473212458, 39.122877197880904, 37.40478884789252, 38.597208992127456, 37.882592370433194, 43.20742953208185, 48.8632833573126, 53.08258871878348, 51.82689682129891, 48.24918139365412, 52.03144842578519, 53.677573050222094, 52.63177894776868, 52.647762606220866, 53.87433090517598, 54.57053592128139, 53.27065460143551, 54.17956190724527, 55.16462595232072, 53.09666610533192, 48.40131444315757, 45.87609252622051, 47.40229460500902, 51.593813896179206, 55.84727917948077, 61.04734966831823, 51.84479067402502, 29.18480319361533, 19.919990301132202, 8.642967189511946, 7.1366838870509985, 11.881877107004966, 6.214930328630633, 3.504117544620268, 0.1669753442007688, 0.09502415184772785, 2.225191732568126, 20.06867950962436, 47.080322927044286, 45.44105068329842, 36.94901727860974, 43.952464134462424, 59.413862920576534, 56.837128516166445, 22.843268071451497, 1.9071163164992488, 0.03943814122448525, 0.06223751156921349, 0.03607258290773438, 0.049145674152720364, 0.05643230029231599, 0.04365976449222334, 0.0649363857002989, 0.02717008964428979, 0.07127877399926225, 0.04925831589066694, 0.06151102272973907, 0.0058041914223483015, 0.06441351537021898, 0.007275277504607314, 0.04859900530127268, 0.10292844020671423, 0.04844015697017313, 0.06455433765246023, 0.05081704051624383, 0.14138583184009598, 0.14906327390382368, 0.1062001259396634, 0.14569596507616583, 0.1689736998730129, 0.17572060557863406, 0.16701433807611468, 0.24689599601251466, 0.1801762801985587, 0.10118591959678358, 0.2289382821970409, 0.16384737656241463, 0.15729501122428527, 0.1273546250717294, 0.22380146348188001, 0.12223467561266116, 0.1707403599134376, 0.14397939186423056, 0.1565184891824761, 0.14196660309549303, 0.3198596654880432, 0.6638767798581432, 20.10517324170759, 60.46328521543934, 63.40188964720696, 54.82038697888775, 37.09207396353445, 32.36860675196494, 49.4265474811677, 43.55566932309059, 13.23709620583442, 0.7425184019150273, 0.31427090086283227, 0.7514791791477512, 4.646585324118215, 12.00033268620891, 17.78820368551439, 9.75034446485581, 4.2221044628850875, 13.510508941065881, 36.198079509119836, 58.918294983525435, 55.534552528012185, 55.6857991218567, 49.024445702952725, 51.68267127006285, 56.15757396144252, 54.41359796831685, 52.59205318266346, 53.949628645373934, 52.6385058126142, 50.08075175746795, 43.754662929042695, 39.30213343712592, 40.84041641604516, 41.52146931617491, 43.45089497104768, 45.920391774946644, 46.6425471921121, 40.63931649731052, 38.83588129474271, 38.916250659573464, 38.321144734659505, 41.55917113827121, 40.31770959977181, 42.01218135895268, 43.53193113880773, 48.86853148860317, 50.387920410402366, 54.12985371005151, 55.914500759493926, 55.48274978514641, 53.80818405459004, 51.22402068107359, 52.126397240546446, 42.33303123904813, 39.63636644424931, 40.055765874924205, 41.127682962725245, 42.58614963100803, 41.90725011210288, 39.450414719120154, 41.88857963008266, 41.25420685737364, 39.288483588926255, 48.24973444784842, 51.18057258667485, 56.93841980349634, 52.13008034613825, 40.70108598278415, 52.907894196048865, 51.66366346420781, 54.56827271369196, 51.06704350440733, 50.45331024354505, 49.834309239541334, 51.073382054605794, 52.75645148369574, 52.22164807781097, 49.692237069529874, 44.3409356763286, 39.1601828605898, 40.49994684034779, 42.7441309344384, 41.59545698473531, 42.556163111040675, 45.28965503938737, 50.379153913067235, 52.13521472869381, 49.06966670866936, 42.54796143501036, 42.482999140216464, 40.76965293576641, 39.149353196544034, 41.215653880949944, 39.7727668669916, 44.442827086294855, 52.57849747134794, 56.28544322906002, 53.07914095540201, 52.32004073358352, 52.15119446477583, 53.0904491486088, 54.60311120556247, 53.749344579635135, 54.86914204012964, 56.12612831977106, 56.06071495240735, 54.235267408432506, 57.318234674392215, 54.773538189549605, 50.83066578834288, 48.21316619073191, 49.888841952047045, 54.098459059192294, 57.93005774098059, 62.989154323454834, 53.57779579777872, 32.29749025837068, 22.72121960116971, 7.560937741110402, 17.97522229533042, 10.11394327686679, 8.68349802109503, 7.577297947099132, 0.5773416942646427, 0.24344431026087654, 3.0028177990067393, 22.930613371633715, 54.154042966904186, 49.31015114630423, 39.99816979131391, 47.497396392206994, 68.16103473786386, 69.24328727106895, 28.889358505125973, 2.575881288897607, 0.28072565733905763, 0.13737169965620966, 0.1820005500508893, 0.13630840026082533, 0.1618519473460413, 0.13636401824412808, 0.20779571105395594, 0.09497140669414113, 0.22791043735079228, 0.239730101499346, 0.10364163742070237, 0.17342295467613206, 0.20347212531393577, 0.11591222858236683, 0.1306022250003392, 0.147139519873646, 0.12057438688052279, 0.15543274341091035, 0.18802983055432], [0.02613716180466356, 0.047311188517919475, 0.06225168419581267, 0.07299721646573275, 0.020393599538252722, 0.04159865855810143, 0.052667024109752915, 0.052560246774866703, 0.07812789881662016, 0.047732778193969885, 0.060456253723391605, 0.061534736981435176, 0.041701743349192605, 0.07251697892863905, 0.059764514632162556, 0.07089777549187984, 0.018032482081663706, 0.03857733035880712, 0.047831955936647234, 0.14046361519684716, 0.024650983790296222, 0.16069996561254227, 9.83086778271583, 40.55084351570376, 54.61252489397603, 44.22874412228985, 33.867054139414144, 32.445775462735085, 40.12585862990349, 42.15459477516913, 12.775482266179978, 1.3607634916420908, 0.025829809244662046, 0.5215602584423558, 1.6422618252615777, 1.473344953790788, 10.112501805828465, 14.344976525152884, 6.683023043217198, 8.196485263686027, 25.435746869733258, 42.615869429803666, 55.23184753233387, 50.746232848013605, 47.70119490162019, 50.37723979642315, 51.41795835187359, 50.79877691884195, 51.00177526474, 52.14744467889109, 48.62090833725468, 45.3955590340399, 39.94635135896745, 36.224626110446074, 35.81870786605343, 35.30543827241467, 36.56589977202877, 36.92553012601791, 37.341379811686856, 35.43819481326688, 38.70255601021552, 36.782646025380785, 36.165225736556515, 36.08478576906266, 37.48048274747787, 46.70456378690658, 48.63606437560051, 48.76407877091439, 48.78236093828755, 49.49654217689268, 48.933007409495694, 53.43411545599661, 49.98681491421115, 50.84856356343916, 50.16768324759699, 44.602746040590354, 36.86297616650982, 38.01481546894197, 37.96779409531624, 38.730836299157914, 36.71242383218581, 37.649913449441236, 34.76339024882163, 37.91626591836253, 38.35783850762152, 45.07632909282562, 46.66721890049596, 53.691975993494836, 48.084598741223736, 37.378869825793856, 50.20401616250315, 52.968459513879594, 50.04654476719518, 46.22702306316745, 47.39282208104288, 42.89909985757644, 44.40785915620866, 43.17050826164984, 45.513426257717995, 43.61956865556779, 40.228620806048, 37.933061507440385, 37.25346772901474, 36.136627735630164, 37.407522739902625, 36.39938339110344, 46.875171199921645, 50.9079090241463, 52.57503794085596, 50.90669701176306, 48.16419147676038, 41.95032558133526, 39.02008756514519, 35.898959559779016, 36.38535307299706, 34.89914348048549, 40.15385258582331, 48.02459432232765, 52.51695156097413, 49.35839629942372, 50.174825883680775, 53.979168015141646, 54.13003806144961, 50.65568101021552, 49.645258841976045, 51.75339552663988, 52.80763841444447, 53.59109263266287, 51.948439305828465, 53.796362030890684, 53.678945879782404, 49.715924263000495, 42.871219650391616, 44.029413192502915, 43.709234037706935, 50.54771384885235, 53.6801931934972, 49.89712992022115, 27.843070184030843, 26.118139259276855, 12.694791266995093, 5.961955103182024, 15.698980669821463, 1.9790426569600261, 0.7315833241708818, 0.12267165216467074, 0.13506401300189957, 2.221504459458013, 20.01388595950219, 41.49800962017429, 36.186834073835804, 33.396083385713645, 40.13541352364325, 55.90925262820337, 52.485666736479736, 17.31827824346481, 0.5643576684017335, 0.14246048465851816, 0.028935462657001712, 0.06807573740520785, 0.020179608198363456, 0.04166255795186566, 0.08880072168164677, 0.02840196477219222, 0.05310044601379384, 0.04239184684270332, 0.07884698724674602, 0.06668060702542145, 0.05865584750990233, 0.019929049566628474, 0.08358122675769752, 0.027743245985719468, 0.02303710274939095, 0.031058918572061008, 0.013915004636791926, 0.04734087825542496, 0.030870830580111475, 0.023568518790266207, 0.02560942298582485, 0.037298928796043324, 0.013419136033213187, 0.04785356344655157, 0.090950119249042, 0.015650644819552622, 0.0596541328535926, 0.04126899177208543, 0.11405857925814007, 0.038275135485755826, 0.03344456424876567, 0.018692621961236, 0.07141752018322868, 0.01231284378351824, 0.03431993844588438, 0.09565305640740741, 0.04213024313832003, 0.01930341428716577, 0.03642604438467853, 0.16911662123616666, 11.88499343010687, 45.062443902415616, 58.6934058896957, 49.256638250043316, 36.16877548156246, 33.27491744872063, 41.563866215367476, 48.68574903857324, 14.378024455039734, 1.3356328659480619, 0.08166278937771436, 0.32139073816999314, 1.9134683498451788, 2.1546091716135702, 8.258158160794167, 8.465352462184045, 6.623003915432961, 12.031499839598133, 28.432084668067198, 48.42092629401915, 56.43201043528896, 53.59714092746858, 50.07557030647032, 51.11729691105505, 54.2556558885882, 51.557645720820275, 51.63026840456071, 53.372051792760054, 50.7017021794473, 47.74969500880088, 41.38887751486994, 36.86345077330066, 37.471131816987075, 37.7258191570159, 38.687207775731245, 39.82485202050979, 38.63123555337229, 37.70334005355835, 40.49520077243928, 38.13982140633368, 39.003927400035245, 38.70595278278474, 38.959282982733946, 47.08277833077216, 51.8933770733495, 50.07957896878643, 51.1403133792262, 50.41580061758719, 50.6344727546938, 54.82676867515811, 51.53430369592483, 53.15168126936882, 52.5247766894679, 45.854868581218106, 38.206223210980816, 39.30296497960245, 40.454317908133234, 39.08086469096523, 37.59636917421895, 38.92991227488364, 37.253044113036125, 39.838607772704094, 39.72341952785369, 46.831530909384455, 49.154303612247595, 54.53085722461824, 49.92812448932279, 39.913105349386896, 51.53622565730926, 53.72929734568442, 52.037116250684186, 48.42801401692052, 48.917474823613325, 46.46217307736797, 46.28429751242361, 46.483275428895034, 47.70786293091313, 44.82796461351457, 41.58392913879887, 40.592859944989605, 38.828946544278054, 38.59297675471152, 39.108842957404356, 38.65167110197006, 48.41051240121165, 53.46158773668351, 54.67290586040866, 53.277185347772416, 48.77478291911464, 43.54931116104127, 39.21661400025891, 37.38836588398103, 37.24759594086678, 37.48234195093955, 41.9458854583002, 52.04520025560933, 54.4073143313008, 51.86399459838868, 53.69812626992503, 53.59296752560524, 53.775534245275686, 53.44488628448979, 51.51168730951125, 53.41280129648025, 54.70770120620728, 54.01521459702523, 53.42450564907443, 55.3733705705212, 55.75732746431905, 51.898640894120746, 45.220456584807366, 45.781296683895974, 48.252217308167495, 54.326995957282286, 57.42302471591581, 52.30716751467798, 30.2404228333504, 22.836866763330278, 9.227552337031211, 9.148665628125592, 18.720415753702966, 7.397498459585252, 1.3759499283567553, 0.15330714053444325, 0.010459258619155134, 2.6465280786637337, 21.69478435670176, 45.95187664031983, 36.97844682201263, 32.6848360799974, 43.10324745793497, 62.750062327231134, 58.42017358349216, 20.18436001193139, 0.7768645137548448, 0.09329393460986116, 0.044273649898147395, 0.07286591665639032, 0.026181181216792717, 0.010240187158717984, 0.014704824049746799, 0.08175642830469916, 0.05134835696568893, 0.07942444900231016, 0.00892189156729728, 0.022029172358733994, 0.03254398958937776, 0.06097110694334392, 0.1044016502677433, 0.0404914393420181, 0.01952375458072751, 0.06923996888461613, 0.04691461544303645, 0.054834972496234605, 0.14739402960385048, 0.10947515947684165, 0.21714846483401715, 0.24613807458550702, 0.09509724429658345, 0.1637643939184566, 0.1509690861548147, 0.1855925984320141, 0.15887177339003933, 0.17208868998192972, 0.22963474805076278, 0.18871106658010714, 0.18380019783733353, 0.1431256788031709, 0.1801724191154203, 0.16000981232331646, 0.07789758980394372, 0.20231865736986362, 0.13040275102661503, 0.17343633057129, 0.13061307280534698, 0.31294621226768343, 13.735484327039412, 51.68194955395114, 66.40244791584631, 56.659115668266054, 45.18947378281624, 42.385763583644746, 51.46402266717727, 53.55161005450834, 17.03390444478681, 2.198204845190048, 0.2858343299838805, 1.32468540822306, 5.095922245133308, 8.085638102023832, 20.73292701475082, 22.096525276860884, 13.094434699704571, 10.43668471997784, 29.580619373629172, 47.049194997356786, 61.080077925036036, 55.40572620207264, 52.584490852971236, 54.030096069459, 55.79449584407192, 51.1469578742981, 52.15197501644012, 56.02094211886006, 52.51037374619515, 48.99420422892417, 43.719824437172186, 38.97546668206492, 40.08947472418509, 39.559182043998476, 40.040974617004395, 41.705973686710486, 40.76059226066836, 38.86430671138149, 42.82666936997445, 41.463728104868245, 40.64210922487321, 40.75180615148237, 41.11805354395221, 51.12890320439493, 55.50851191243818, 52.464023097868896, 53.67103445914484, 53.04783651905676, 51.72117717804448, 56.03978910753804, 52.85324381243799, 54.552469484267704, 55.204296804243526, 47.92820599771316, 40.24189018434094, 42.348159820802756, 42.458484326639486, 42.408368202947806, 40.45944052357828, 41.61741441295993, 38.431461395755896, 41.04097504769602, 42.697913646698005, 49.64541965915311, 51.57672412933842, 58.020433072120916, 54.023541788901056, 44.97180969484391, 53.17537630757978, 55.27148308292512, 53.70022081559705, 50.04352846453267, 51.51747672788559, 48.272452815886474, 49.62484682759931, 48.65152635881978, 49.8463156146388, 47.277516165087306, 45.48169428302396, 42.89978234998642, 40.379722272196126, 40.166251197938, 41.394090344828946, 40.15340935799384, 50.731967187696895, 56.099844517246375, 56.97494099217077, 55.41997225053849, 52.35943701959426, 46.02639775122366, 41.753901127846014, 37.74753732066001, 39.82385181611584, 38.485880359526604, 44.01100550928424, 55.03714892172045, 58.11222830126363, 52.34872894902384, 54.363473999884825, 57.2445607954456, 56.569560112491736, 56.45123397150348, 53.91022451462285, 54.059666818188084, 55.433088656394716, 56.3408741643352, 54.56229894391952, 58.32502080548195, 59.55411118845786, 54.91548092134538, 47.78617697377359, 50.49396168801093, 50.419675919317434, 55.90050182034893, 59.70591083649666, 54.0919126233747, 31.06051983371858, 30.424095661409442, 19.00634869452446, 14.424994837853218, 32.137492856671734, 8.240077995484876, 3.9316671702169605, 0.4956457715842032, 0.33435680693195713, 3.2983857970083914, 26.723617892111502, 53.54518128979591, 49.27926640356741, 45.71864858750374, 52.358362290167044, 70.07691644853162, 68.59379768371582, 25.31840524365825, 1.3151886145914755, 0.2875775170903052, 0.2089063700048193, 0.24246434590989546, 0.06873496372493045, 0.14650654738708851, 0.12059251252081125, 0.14091333945191678, 0.1471101480626291, 0.13227182170075755, 0.0957106125931586, 0.22807592766419535, 0.31258035931856404, 0.12013970859228604, 0.1939726350528579, 0.09008224888314163, 0.07587620552869574, 0.1635171467017743, 0.10904511602054681, 0.09829033706938067], [0.05157482787786473, 0.006943089810515484, 0.04765137369113584, 0.03834421746432781, 0.08418829015065586, 0.0728510239071423, 0.07949635401488313, 0.06417588255698643, 0.04436618565852123, 0.04745841912564732, 0.03193695875515621, 0.005882662766042256, 0.010638997210339915, 0.04965291245870533, 0.07502852157960016, 0.06787377364572979, 0.02153212685258158, 0.046446639143170855, 0.014067089369129992, 0.03642597160632572, 0.01623247231867525, 0.13985151094534706, 5.1660238254454836, 32.33063428632675, 52.05718701885593, 52.29382753372193, 37.63403961735387, 25.20336408768931, 31.50773475247045, 33.63996459591773, 22.434466884982204, 2.9260633885860448, 0.09348860521230007, 0.1485452758929422, 1.4576579245828813, 2.01572846260763, 2.4033622107198163, 5.444813149590646, 5.828184629640272, 4.114834012523774, 13.264237046241762, 39.753739449285696, 50.21745812508368, 52.30028375502556, 52.33467509669643, 49.468967914581306, 49.8145640280939, 52.081756745615316, 51.5662004101661, 51.94537985709406, 45.587782629074596, 46.54245615005494, 40.88153854493172, 37.489017824972834, 33.723252204156694, 33.95798252474877, 35.775804981108635, 37.4899003582616, 35.412805311141476, 36.819555528702274, 34.98264289671375, 33.9471960067749, 36.035505110217684, 36.948146512431485, 45.45473191045946, 49.28605602633569, 51.96417193258963, 50.47107858042563, 49.97129017306913, 47.91272440264302, 47.85383393687587, 48.83253197516165, 50.97784880668887, 50.52189288600799, 51.12205474607406, 47.8280286635122, 40.74133734549246, 38.16684653682094, 39.64621159338182, 36.37377815861856, 37.5867279883354, 37.512830534288966, 36.91317073760494, 38.24450554386262, 40.68558869823333, 43.39480507758356, 48.13755858329035, 49.326491740442094, 51.35511021460257, 26.2138117513349, 42.2758234700849, 58.26112539537492, 49.1294083287639, 51.81548272409747, 46.83200943854548, 46.43855648656046, 42.36205677832327, 41.95878613379694, 40.016620620604485, 41.19247659560173, 37.19095691557854, 37.970320101707216, 35.1574590129237, 37.4763838706478, 35.67720051734678, 41.14516496658325, 51.11679877004316, 51.10513756352087, 53.957081148701334, 51.85686765178558, 49.17883019293509, 44.76381424934634, 37.31834373166485, 37.042652099363266, 35.28415156948951, 35.54012936930503, 37.344235297172304, 43.8526084346156, 49.805675937283425, 52.90605852680822, 51.56000698766401, 50.861903544395204, 49.678398947561945, 48.789276076901345, 47.551999707375806, 48.35251623584379, 48.754045348013605, 52.55045252461588, 55.17513005964218, 55.612650840513176, 54.16500206916563, 53.41925359541371, 50.64781273564985, 46.745328980107466, 45.665912320536954, 52.26251133026616, 54.94223148592057, 49.62732968791839, 28.865881158459572, 23.44331422159749, 8.162522440956485, 5.141680615563547, 16.098062223003758, 7.877682370524253, 1.9111053669644942, 0.15310952049349585, 0.08919979220316296, 3.6934964406874875, 21.702062314556493, 42.54018729732883, 37.473328344283566, 33.3755027094195, 51.86349645737679, 51.89247100583969, 42.26178138486801, 12.810259961312818, 0.43245942181637215, 0.036279610508391937, 0.015692100709965153, 0.007619690046750851, 0.037830544019778894, 0.1052057361530681, 0.020691515810246912, 0.08530716922494673, 0.01981956602614974, 0.050099840492851315, 0.056371840633331775, 0.018753481901160652, 0.04901127934816384, 0.07537012784591607, 0.012782189465548485, 0.014841451042992695, 0.04232642293396977, 0.0405094079342821, 0.02579442747387915, 0.04161210723161217, 0.06139284600653957, 0.048459190424651875, 0.014335968035964236, 0.028961000197957602, 0.053159913588916106, 0.027778687128316493, 0.1008512617479409, 0.009880299161699031, 0.011692362360566134, 0.035855228441857526, 0.05362101424966128, 0.022531419601892273, 0.07131995888607157, 0.04064634998118685, 0.10406277893531708, 0.051227828352561885, 0.11787101581332185, 0.07948133103068798, 0.049122844732576804, 0.016716275995056477, 0.03172347303329697, 0.11909220592990039, 6.908828991074716, 39.21011855525356, 59.13737896950015, 57.09400061638125, 45.42847948689615, 28.648511248250163, 38.38260435288952, 43.81954285406297, 22.445735854487268, 3.5599975912801685, 0.04657561004522347, 0.1860789263681058, 2.1833902981973465, 2.9749177348229194, 8.719382805209007, 7.48947068568199, 9.541290960004254, 9.489499984248992, 20.2664924821546, 41.72709957245858, 53.808019315042806, 54.206885137865626, 53.3387077239252, 52.734090051343365, 53.541772750116166, 52.437299989884906, 51.051091224916526, 51.98431722579464, 47.180284530885764, 47.71084000987392, 42.85244326437674, 38.48556656991282, 36.42277248444096, 37.10325664089572, 37.82737324314733, 39.778348399746804, 36.94387505131383, 36.906820420295965, 37.25253420491373, 36.25734260005336, 36.98359689404888, 37.99159895989203, 47.99191705642208, 53.190147953648726, 54.04927253723145, 52.54617321875788, 50.46094317590037, 50.040508239499985, 49.21199383274202, 51.420135267319225, 52.7013421827747, 51.899931353907434, 53.830145405184844, 50.055303419789965, 42.594833758569536, 39.807887769514515, 39.53940153121948, 38.038279087312766, 38.37912521054668, 38.798991403272076, 39.17643716258388, 39.63576239924277, 41.65721078072825, 46.18216683787685, 51.60937001628261, 53.12804114434027, 51.625624318276685, 32.52767062956287, 45.14549224607406, 58.176857194592884, 52.76976793043075, 52.978944009350194, 51.14116845592376, 48.209271277150805, 44.27753056249311, 41.61901866236041, 43.01535106474354, 41.42679506732572, 39.11465198762956, 39.99034858519032, 36.75504038410802, 38.49687084074944, 36.83407614308019, 41.78820617737309, 53.75359642890192, 54.81762955265661, 56.48228345378753, 54.51179842795096, 51.90805066016413, 46.79822998662149, 39.35829785562331, 37.75698238803495, 37.60653203533542, 37.04576253890991, 40.00978392939414, 46.24579552681216, 53.50325115265385, 54.456175296537346, 55.31637853191745, 54.840218482478974, 53.851981239934126, 54.31905315768335, 49.1925859451294, 50.77477201338738, 51.68530710281865, 53.96561230382612, 57.92028319451117, 56.576141849640884, 55.90466737747193, 56.19212612029045, 52.516829967498786, 47.32774603751398, 48.36292620628111, 56.39686992091518, 59.82327207442253, 51.9401748718754, 30.178357208928755, 13.502837765601374, 9.320218332352178, 8.435051172010361, 10.094424582296803, 9.334228058015148, 2.651464136377458, 0.35052159921296183, 0.18180098414661425, 3.9227957494797248, 24.598669928889123, 48.70644738597255, 43.57393187861289, 41.07033398843581, 55.99666264749343, 59.735379603601274, 50.8428055240262, 16.52032498390444, 0.5833644323772, 0.03077399132082299, 0.025266485641740506, 0.06343817435986092, 0.06973951183740171, 0.10258737786282456, 0.01794150147977616, 0.08961931727225743, 0.02518540672627428, 0.03703197396750893, 0.06410940910779661, 0.02498232064798715, 0.040887211855020256, 0.09808749996966894, 0.018895081762645035, 0.037872985290784034, 0.016265216831778808, 0.05453849263909844, 0.0027969896449752513, 0.0475134318994899, 0.15576548603994234, 0.10134929550751563, 0.16012064992420136, 0.2402159544609247, 0.2571647151583626, 0.151286032050848, 0.22338201502157798, 0.17453284753907114, 0.1841437269843394, 0.22252663188884336, 0.2078034332202327, 0.15933951603308802, 0.17937075406793626, 0.16088767247574945, 0.15197817716867695, 0.2596554508613002, 0.24373554624617103, 0.1812594365929404, 0.173735533870997, 0.2151779487969414, 0.17619718887632893, 0.18953343132330527, 7.978941788596492, 43.23291317109139, 65.04426056338896, 64.58481765562489, 50.49938240358907, 35.81635444395004, 43.24766912767964, 45.978611515414336, 28.120426862470566, 4.31537107113869, 0.3071343015518881, 0.5094219936478523, 4.857824569748295, 5.494844942323623, 10.51055177565544, 13.691859725982914, 11.173736318465203, 6.714532913700228, 16.83586201360149, 43.76727727151687, 53.2305169874622, 58.16533719339679, 55.4035218300358, 54.93485742999662, 54.31684486327633, 54.447016562184984, 53.3821048275117, 54.90116034784625, 49.806315283621515, 50.75977679221861, 44.91977160976779, 40.86186001377721, 39.025551426795225, 38.98644147380706, 41.09731597285117, 43.08248243024273, 38.94348759805003, 40.3519558137463, 39.245804279081284, 38.04864591167819, 39.129506003472116, 41.44617549834713, 51.8950205464517, 54.560777064292665, 55.4679036140442, 54.52768010477866, 53.25523968665831, 51.46807839793544, 51.90419104791457, 53.091614092549975, 56.12354347782751, 53.684664695493645, 56.16675623001591, 52.40146129362045, 46.33911263558173, 41.28651934285318, 42.0367746199331, 39.196382414910104, 39.342879018475934, 40.58461120051723, 41.141183760858354, 42.54966374366514, 45.56492305571034, 49.32608773631435, 53.41430748662641, 54.969809670602125, 53.89216199997933, 35.66156987221011, 46.646744128196474, 58.195225654109834, 55.30860047186575, 58.64032837652392, 53.012774452086425, 50.148989231355735, 47.48572341857418, 43.698059205086004, 45.113721047678304, 43.37569529010404, 40.439965955672726, 43.1180347934846, 38.57438472009475, 41.2462366011835, 39.59144746103595, 45.43056618782782, 56.38439286139704, 55.63049370242704, 56.97821224889448, 55.812507367903194, 53.77558523608793, 48.153146082355136, 41.17185277323569, 40.59389937308527, 37.805572709729596, 39.07397700894264, 41.06290894169962, 47.13208252383817, 54.77211829154722, 57.013019361803615, 55.83619848374398, 56.48479769306799, 54.40583559774584, 55.252455665219216, 51.74493889654837, 53.239052064957164, 53.505208415369836, 55.866012419423754, 58.635343044034904, 58.39688647177912, 55.83456677775229, 59.46081369153915, 56.17753098087927, 51.155587088677194, 50.0058933227293, 59.029274525180945, 62.361692766989435, 55.83240947415752, 32.39271952259925, 27.851456211459254, 14.216555183933629, 12.367079200283175, 29.00774936522207, 16.2225680581985, 3.2269969438352897, 0.4826059438768895, 0.34171842158802096, 5.358440597211161, 29.513905740553337, 56.12662646078295, 47.7234661194586, 45.72972536087037, 66.10874083734328, 68.9051083595522, 59.337184506077925, 20.130054796895674, 1.1532577295457165, 0.11257297389449612, 0.16562094671591637, 0.16457773414590668, 0.14404735918487274, 0.23983307903812778, 0.23831407990186448, 0.18816400319337848, 0.11450187603552496, 0.1668714167129609, 0.1210483808010336, 0.12046845224235328, 0.17407636638850937, 0.2127868198459187, 0.12078844716832524, 0.11123068825972658, 0.16514508354087032, 0.10764278441427216, 0.14888780912564648, 0.21913551304849888], [0.015253929060793694, 0.06299659361942642, 0.01112730739893572, 0.01931862304768255, 0.08214571588342229, 0.021931854294492834, 0.05006139820081092, 0.042377103480600545, 0.047672391313338475, 0.02942279033783463, 0.07064130457658922, 0.07311796724435783, 0.014565972528690773, 0.03962129752542223, 0.05983789053355014, 0.0038263774401838743, 0.02139574979552098, 0.058857071994533466, 0.0829812343562803, 0.035888541775244864, 0.05425558402954091, 0.04107718250804371, 2.064616516713173, 21.262570542673913, 47.588513051309896, 49.00858363797588, 32.54341306224946, 33.67223785769555, 37.46789978396508, 45.539023645462535, 26.10932569349966, 5.02432280971158, 0.24243292098324148, 0.08352894891774462, 1.2406396793742334, 1.5904089496020348, 10.763679973540768, 4.934952585927902, 4.956357940550774, 10.717968671552597, 13.206842964695348, 24.5937708885439, 43.21747472209316, 52.53113485151722, 51.728417873382575, 47.87310061916229, 52.67429744043658, 53.994912409013324, 53.04662058430334, 47.703838579116336, 47.03439197232647, 41.65603014730638, 37.27494662807834, 35.86459959706953, 36.189454217110914, 36.51783897030738, 34.281911465429495, 37.50768830699306, 36.13933024867889, 36.29265177634455, 34.140894412994385, 36.56231864806145, 34.3439398273345, 41.50991793601744, 50.03183195667882, 52.279306919344016, 51.30960679823353, 50.04085733044533, 48.89164993839879, 45.017426859947946, 46.68426552126485, 45.5013688918083, 48.75061327411283, 50.9221903739437, 51.01111835049045, 49.57111427860875, 43.04472177259384, 40.206612387011134, 37.627524560497655, 36.58498210291709, 36.176757504863126, 38.90256943241243, 38.5028406881517, 42.40540681346771, 41.91181967335363, 46.19058424426664, 48.561751150315814, 50.34717090668217, 49.847280517701186, 38.397234793632265, 39.28262356788882, 42.85537719726563, 55.354809914865804, 49.819419922367224, 50.7876060085912, 45.243331847652314, 43.668445310285016, 37.00128286115585, 39.674476192843535, 35.417527844828946, 37.52665688914638, 36.41269199309811, 36.85363308075936, 35.55927053574593, 37.83671240652762, 46.387859852083274, 52.04389802871212, 53.0119978227923, 54.53900398746614, 50.80417802256923, 50.68723255588163, 44.79029024800947, 38.40415385461623, 37.479588447078584, 38.258496638267275, 35.56181615398776, 37.09363506686303, 39.30327484684606, 45.56269122708229, 48.48057377722956, 50.365872767663774, 47.72765128843246, 46.18134706251083, 44.65128537147276, 44.97341786661456, 45.31726852540047, 47.761622936494895, 48.303706261419485, 51.91400089571553, 54.0594236312374, 55.200272452446725, 54.87705738313737, 53.91124825323782, 51.74725309495003, 49.32243208731375, 52.69487027199038, 56.08144075639787, 46.004926696900405, 29.944817327683975, 15.785097287547206, 6.719716816179215, 7.811851761033458, 9.585259749043374, 9.102717022741995, 1.5341589744052582, 0.09540670551359655, 0.0973946730335874, 3.623168343497861, 23.752065550896432, 43.193269775759795, 31.843636728102165, 27.19739902404047, 50.19098604879072, 52.89266363266976, 39.2772420760124, 10.467924437215252, 0.3215130364462253, 0.01589115908099038, 0.02580496884371725, 0.01839529749216332, 0.03139641477666315, 0.0331515547699265, 0.039554916006783326, 0.010032854080500623, 0.050509559636514996, 0.03786128329774065, 0.10421557517181482, 0.02590687002896542, 0.009802960670523105, 0.025029940673360423, 0.04871532809169543, 0.016992510063573718, 0.07313518124001642, 0.06010649628156136, 0.018696017645960374, 0.03160564679532282, 0.04611005841363822, 0.003686960211076263, 0.048610416180904836, 0.067386970735125, 0.07467556189024642, 0.05461820791805944, 0.06452960833426445, 0.021270396743690776, 0.09838487998011614, 0.032588495467338836, 0.032348074094061895, 0.029707056838237954, 0.04884736717588479, 0.023079921318698796, 0.03917756024748087, 0.022237975368156068, 0.05916407789974924, 0.018859768939775326, 0.046080085223600756, 0.02560926785302018, 0.020348632092317267, 0.057759011359584916, 2.9131173606841796, 26.416902272931992, 53.53013900018508, 57.05772653702767, 38.16545801777994, 35.459065744953776, 36.801579306202555, 45.92212546256281, 30.569927423231064, 5.1269967325272106, 0.34464637899110395, 0.03242758252928334, 1.0471706092357635, 3.0505339224492354, 6.114006763504398, 4.815764504094278, 10.292969076864182, 9.560168347051068, 13.965720592006562, 30.115348254480672, 46.65496933844782, 56.29160135023056, 52.20471128340691, 52.30053086434641, 53.97935628890992, 53.93296249451176, 55.58478632280904, 51.75467029694588, 49.55613082455051, 44.07974504655407, 38.25447620884065, 37.561899385144635, 37.52649999433948, 36.280876821087254, 37.11242321998843, 38.736539425388465, 39.142167414388354, 38.44210670840356, 37.288572942056966, 36.249101700321326, 36.92855819579094, 41.6458829756706, 51.59958762507285, 53.62928082866054, 53.73484749947825, 52.87935110830492, 51.209441231143096, 47.47429363189205, 48.02513168704126, 47.342505916472405, 51.370380001683394, 52.61367328705327, 52.904595482733946, 51.29370550955496, 44.973092309890255, 40.75603054415795, 40.46778340493479, 39.508050026432166, 38.946146965026855, 39.4638253027393, 40.46333935952956, 43.249877422086655, 43.552221559709125, 46.95449329191639, 50.66698135868196, 52.923724882064334, 51.08187790839903, 41.04141043078515, 41.16160361997543, 45.07377170747326, 56.61653441767539, 51.91024718746063, 52.03906566865983, 48.559915481075166, 44.835601468240064, 39.23237016124111, 41.455953967186716, 37.953312704640055, 39.88862583714147, 38.747828006744385, 39.21058139493389, 39.624465973146506, 39.496228002732806, 47.71875927525182, 54.668622632180494, 55.11333703994752, 55.31420553884199, 53.2304463847991, 52.4286158623234, 46.657279614479314, 40.54091599679763, 39.28293343513243, 40.816466423773, 36.460956758068455, 38.593204252181515, 41.71767803930467, 49.01700104436567, 52.08008581592191, 52.13151201125115, 49.897039705707186, 48.965861182059015, 47.69184397112939, 48.37367742292343, 47.09320399069017, 49.72792671572778, 49.65972062080137, 54.47145292835852, 56.362455045023275, 56.09083483296057, 55.318261269600164, 57.4849981646384, 53.867462835004254, 52.8324003373423, 54.10560169527608, 59.47882129300026, 49.16410169293804, 31.732849382585098, 12.188333849753104, 8.962669776331994, 11.294166811050909, 8.625650905793714, 5.76341207950346, 2.738070560078467, 0.15576346356782222, 0.19571197639790275, 4.6152931451797485, 26.86927510846046, 48.85958063986994, 32.33575886295688, 32.24526978308155, 58.12698033548171, 61.791493892669685, 44.03211570555165, 13.01061757149235, 0.4022637598456875, 0.04187303294818248, 0.0298094732176152, 0.05736295156361115, 0.04910952629401319, 0.00937251597567792, 0.06543911557884947, 0.08719317044221586, 0.050177031512101816, 0.059607194646471934, 0.0414732652866552, 0.08895222322955247, 0.05422749924623678, 0.0761241652071476, 0.011007517103045698, 0.03963374262375217, 0.12821019206556583, 0.08820468229391883, 0.046180925377073793, 0.016072237368432746, 0.11344819104359036, 0.2329173428757537, 0.17888162225004167, 0.1001377504379038, 0.1740010599455526, 0.12350435909484664, 0.1520919259036741, 0.10764220984832895, 0.17503157077777773, 0.1366309385987059, 0.16280586470759686, 0.17688185697601688, 0.12690985740552987, 0.16166563476285628, 0.12016746395778273, 0.10165080473187471, 0.12571220917086448, 0.2559368600768428, 0.16676788759087363, 0.09560788786339183, 0.1934698362263941, 0.1919102650736609, 3.820845749109022, 31.086427088706728, 61.05925013942104, 62.148217770361136, 44.29449089111821, 44.25302359365648, 48.73684967717817, 57.075326211990856, 33.28561767455071, 7.126457777715499, 0.5137907479318881, 0.34365420319860984, 2.8990228137662335, 6.643770904310289, 23.22338496485064, 13.393525231269098, 15.31511006816741, 16.400719169647463, 16.913030724371634, 27.305328922887004, 48.862957800588305, 56.29455489497031, 55.951320048301454, 52.40600339827999, 54.30493654743318, 54.428797152734575, 59.18774612488286, 51.54016371696226, 51.45891574121291, 45.72515972198979, 40.597853122218964, 38.62608155896587, 39.695409882453184, 39.081708000552275, 38.13607946518929, 42.08832240873768, 41.2685509650938, 40.64887139105028, 38.53879313315115, 39.80976266245688, 38.86816240126087, 44.54105500252017, 54.52397346496583, 56.390531370716715, 55.98214987785586, 54.09452884427963, 53.17013994339974, 48.703717416332616, 51.31790261114798, 49.46435912962883, 52.19203418300998, 54.80073590432444, 54.63118753125591, 52.78573197703208, 47.114855474041356, 42.976425463153475, 41.66005842147335, 40.23908568966774, 40.60385434858261, 42.60034076629147, 42.4626341942818, 45.68451219989408, 46.77359750193935, 49.75645803636121, 53.09177883209721, 54.34920049482777, 54.56096533806094, 43.404089327781435, 41.88994069253245, 48.7065964360391, 57.73599847670525, 54.46654996564312, 55.33629632765248, 50.67020946933378, 47.01391720002698, 40.13523309461532, 43.184503278424664, 39.96424913406372, 42.6955053114122, 40.40273481799711, 41.44518313869354, 40.18688678741455, 41.41602423883254, 51.3111129883797, 57.93204638265795, 59.633543106817434, 56.20085731629403, 52.746727928038574, 55.449794030958614, 49.33326959609986, 43.040234581116714, 40.96335526435606, 42.915616958372055, 37.99447405722834, 39.848194045405236, 42.775043133766424, 50.11045194441273, 54.04003927784582, 56.612670883055664, 53.06097253676384, 51.58103089178763, 50.101587387823294, 50.80125585679085, 49.02052725515058, 51.329818771731475, 53.335612973859234, 56.43601517523489, 57.53356102974185, 56.73535477730536, 57.44155007023966, 59.234885169613754, 57.63400116274434, 55.80301130971601, 57.28824030968451, 63.207191036593535, 51.90351247787476, 33.4128789747915, 18.92708936045247, 10.484417023197299, 17.31331644519683, 21.391118380331225, 14.255020887620988, 4.587387932885078, 0.4355853363390892, 0.5035427284817542, 5.599458477189464, 31.39115994976413, 55.192780725417606, 42.255180035868, 38.68272450662429, 64.88205094491282, 71.41519777236446, 54.63081882845972, 16.03851966319546, 0.9274432015034461, 0.37619296040746475, 0.1082035837574832, 0.1341482314972147, 0.11085251661678476, 0.21245472073074312, 0.09847746936664467, 0.18391149509097302, 0.15667504691068204, 0.16428401603573756, 0.35832049685620493, 0.1319721740700545, 0.18287474830304423, 0.17619763320732504, 0.2360482369699786, 0.12029710135632947, 0.3175219635088598, 0.1704735774546862, 0.16603530835240118, 0.16237115577584313], [0.030309611803761898, 0.029579851768850803, 0.05875888633571806, 0.014569213080610481, 0.030737897088270516, 0.05000835044249412, 0.01824496997400157, 0.04133219402583857, 0.05822554741415286, 0.062247041702991536, 0.0162822891011714, 0.033169408449001854, 0.11110607639796312, 0.05108073181022079, 0.05270874525810923, 0.04916903217353168, 0.050856800479513985, 0.09300052293486173, 0.043856465227661595, 0.0534129792433833, 0.023159868339256897, 0.0572087572166516, 1.0791278750665727, 14.907823897177174, 40.80007091645272, 50.39665160640594, 37.521836296204604, 37.61707928872878, 39.08526166792839, 37.37356285895071, 31.749786176989158, 8.729440742923368, 0.8773213168305736, 0.049632637941789244, 1.1398383205936802, 1.0049369787016222, 4.198199577869908, 2.9170485561893833, 9.34289453491088, 10.290211650633044, 5.206631143246928, 15.109333703594825, 32.99651153625981, 46.509037556186804, 52.70266402152277, 55.37426879329067, 51.404571302475475, 54.64903823791012, 48.97172120309646, 46.71708791486679, 41.687648373265425, 37.779508559934555, 37.162649170044936, 37.83384123156148, 34.464278144221154, 34.27889124039681, 36.203661041875044, 37.319041913555516, 37.60420999219341, 35.75821707325597, 35.96555748293477, 35.52593038928124, 34.43818653783491, 44.59434040131108, 49.725110453944055, 53.13900809134207, 49.669216678988555, 52.12990776185067, 47.805376975767075, 46.50902578907628, 42.12146643669375, 43.456319608996, 44.461297527436294, 49.88188758973153, 50.941143266616336, 48.75104081246161, 43.27378819065709, 38.706548983050936, 35.55937643974058, 37.44368699289138, 35.07803493930448, 40.472753047943115, 45.13981265406455, 44.56180041836154, 43.97203283925211, 45.60050679791359, 46.99413668724799, 51.467882279426824, 50.394608051546165, 37.78327795767015, 50.677932616203066, 51.00635659310126, 54.11547822336997, 51.61693234597483, 49.31182207599763, 46.5390750669664, 43.33351019890078, 41.20333763860887, 41.470019586624645, 35.62196570058023, 35.84534075952346, 36.154596113389545, 37.232290852454405, 36.2659090565097, 40.39185808550927, 47.84756206697034, 50.1273730493361, 52.35985279083253, 53.73597321971771, 51.54096388047742, 51.88556371196624, 45.56190675304782, 39.97958560143748, 37.97833350396926, 38.48573130946006, 36.412468417998284, 37.251365338602376, 37.38872674203689, 38.840070386086744, 40.451552637161754, 42.74457808463804, 43.177137067241055, 42.64772692034322, 42.20407155252273, 40.83618417862923, 39.9885521396514, 42.1878800084514, 44.31781722653297, 50.034067707677046, 53.385529056672134, 58.336634943562174, 53.451279747870664, 56.40214158642677, 54.97377126447616, 53.225233554840095, 55.167465748325476, 56.50817501929499, 42.49728441238403, 25.37158081608434, 7.57508671091449, 9.726695514494374, 7.897868358319807, 3.5799367149030012, 4.045123198340017, 2.8536834015000254, 0.29717010235594166, 0.11036562943650831, 5.476106309121655, 25.31174113673549, 41.062810882445305, 39.258081297720636, 48.01158774283625, 46.22409305264873, 53.74061730600173, 35.87737867909093, 9.1347510199393, 0.06862647801397309, 0.06690638845846539, 0.031553005063605886, 0.05007370540331449, 0.04563027286841985, 0.009330840792597063, 0.02115778756448098, 0.03633299534539542, 0.05675728245067501, 0.10617304473154007, 0.036238632465322176, 0.07674415250338855, 0.027316512029257514, 0.058934477518402764, 0.01950843473746171, 0.03712825972827212, 0.11365986879794829, 0.031611783159596306, 0.025987470139478965, 0.02544286781020703, 0.038783086253510374, 0.01728627605423812, 0.03742726767555841, 0.05644176913906009, 0.024621964379724477, 0.05296317071864202, 0.02659544134662757, 0.06709754271733184, 0.08145160191962797, 0.03254866272571587, 0.07116992056610123, 0.05639920912442669, 0.1647086585721662, 0.07488822789802667, 0.03732570356899693, 0.01837366891484107, 0.03580479304336252, 0.04377679591397605, 0.020365595194180647, 0.06063841794046664, 0.06721057899055943, 0.05070137273099634, 1.6225234779619402, 19.270775279691144, 47.48198147742979, 56.094568929364605, 42.39204329829062, 41.209625197995095, 45.66128000136345, 45.54876289060039, 34.46449387458063, 9.390730780939903, 0.6406600256600689, 0.05860793637111784, 0.5425503321232334, 3.125304839303417, 5.704518181662406, 7.728471977095451, 7.161785094968735, 6.614110431363506, 8.473976773600425, 18.213043443618282, 37.31309952274446, 48.92498616249331, 53.58230260110671, 55.74216358123287, 53.52354549592542, 56.067751684496486, 50.342620957282286, 48.94799478592412, 45.95916832647016, 39.66354454717329, 38.28795756063154, 39.72813421680082, 36.91408857222527, 35.85429553062686, 37.64473592081378, 38.50841829853673, 39.40498190541422, 37.18438302316974, 37.212396590940415, 36.62860278160342, 37.47285765986289, 45.97145318984986, 52.60893114151494, 54.16633959739439, 52.13670915172946, 54.69516138876639, 50.009376387442316, 47.14774454793623, 43.5751909594382, 45.14670425845731, 47.715252676317775, 52.264782382595925, 53.10211035513109, 50.83840854706303, 45.5243775152391, 39.953948989991225, 37.935807166561005, 38.195617122034875, 36.26259073134392, 39.77541054448774, 46.89611273427164, 47.30416474803802, 46.51122623874296, 46.98982208005844, 49.45566323495681, 54.167237820163855, 51.949596405029304, 39.82764474807247, 49.479507323234316, 51.61154693172824, 56.376253943289484, 54.31628788671186, 52.702460058273815, 48.156911557720555, 44.408596561801055, 42.10624371805499, 44.406211760736284, 37.54868099766393, 38.15693470739549, 37.27276186789236, 39.3028159295359, 39.12858424648162, 42.89705238034649, 49.402581799414854, 52.530723002649125, 54.60699042966289, 53.51576743587371, 53.68433521639917, 52.879778646653705, 48.23409595797139, 43.161094573236284, 39.79957234474921, 39.378443148828325, 37.4910064666502, 39.26063083833264, 38.897705693398755, 40.872211148661954, 44.47239391265377, 47.02462919296757, 45.71997042625181, 46.69294964882636, 44.10030218862718, 42.170849077163204, 43.101188213594504, 45.39575515254852, 47.91659185963292, 53.703692113199544, 55.86851489159369, 59.00561086593136, 54.88080324665193, 58.57314994258266, 58.69036997518232, 55.199876293059326, 56.97229731467463, 58.91083855782786, 45.81576647297029, 27.248595760714625, 9.42038684122024, 6.595083503953873, 9.728293880339592, 8.774262647474966, 4.199326768998177, 1.6905159262880203, 0.3117046901775945, 0.2825823480323438, 6.540394877233814, 30.69809086861149, 48.064951589030606, 40.028136699430405, 45.802865797473544, 55.528790566229056, 60.44242997323314, 43.190990878689675, 11.022754484607328, 0.3327287168752763, 0.10675144111437183, 0.040789623744785786, 0.04984990430755481, 0.07241066890738665, 0.025957106244600108, 0.006270129449530355, 0.08887849492771972, 0.01805969927039358, 0.0068740897075904, 0.03071870658576729, 0.048993268621064005, 0.05236025186135404, 0.10557554211587676, 0.045500727400424025, 0.006075703995227213, 0.012408129799540245, 0.04227994054916405, 0.045372740921354106, 0.030969950866194505, 0.12853797044484847, 0.08120004162793198, 0.1180191082699645, 0.12858779680344368, 0.09907805931664283, 0.12965340978435932, 0.17302319467548402, 0.11758022415902346, 0.26127005777051376, 0.18275385962859278, 0.1213054032996297, 0.09975338114365455, 0.2658251246377345, 0.16803573246204084, 0.1778131441002892, 0.22104092693376928, 0.16661759646188828, 0.16445306099710927, 0.06746853611642314, 0.21148250918955575, 0.17473278116554986, 0.1492448060983612, 2.0593446060534446, 22.22548496338629, 53.86586643034413, 64.79913596184024, 48.938463426405384, 49.19215056204027, 53.117929274036044, 48.86054554293233, 40.948301207634714, 11.181046635873857, 1.2499837457172334, 0.19769288058723175, 2.90338792147175, 4.234905117942441, 9.809216299364644, 12.25582411212306, 21.801794459742887, 16.067152965453364, 8.885397122752282, 18.861297484367125, 36.613101574682425, 50.477723075497536, 55.19776998027679, 56.8196661241593, 54.23125482374623, 58.57665654151671, 52.897892152109456, 51.47950033987723, 47.74016364928215, 41.25323803194108, 41.043771697628884, 41.47182779927408, 38.459898579505186, 38.04724954789685, 39.71913237725535, 41.681890333852465, 42.14402006518456, 39.1114003427567, 39.43100683150753, 39.69434299776631, 38.729479159078295, 48.882334309239546, 55.41771296531924, 57.25680643512357, 53.705382654743815, 56.57853449544599, 52.06921692817442, 50.60338404870803, 46.34304677286456, 47.88081592129123, 50.40765385473929, 55.532799228545166, 54.353040495226466, 53.485063122164824, 48.796050010188935, 42.569055941797075, 39.324263449638124, 40.657308409290934, 38.52597090505785, 42.85098414267264, 49.937600935659106, 49.042861230911754, 48.9964242904417, 49.893176171087454, 51.65763085888278, 56.874245905107074, 54.708924985701046, 42.83675770605765, 51.34740667958414, 54.80525839713312, 57.69357804329165, 56.66060616893154, 53.730838837162146, 50.62334891288511, 47.322748937914454, 44.05138631020823, 45.68686562199747, 39.380188603555005, 39.298858258032034, 40.228436454649895, 41.76433463250437, 39.97528668372862, 45.995905245504076, 53.5300644751518, 54.761841681695756, 55.52524866596345, 55.206301135401574, 54.076246676906464, 58.21273511455905, 50.34429188697569, 45.091967582702644, 42.53989704193608, 41.093938812132805, 40.053235946163056, 41.07475842199018, 40.8299123087237, 43.1487940203759, 46.36094847033101, 48.19052234772713, 48.09482828263314, 48.343337889640566, 46.96689190403108, 44.91984221243089, 45.2692626368615, 47.38571474629064, 49.251645072813965, 55.59210154318041, 58.9711489215974, 60.79205828328287, 54.550472997849994, 62.48516505764377, 61.087091122904134, 57.58723866554999, 59.37145425427345, 61.06493365380072, 47.93808252580705, 28.192051303002145, 9.730978742722543, 14.59689369124751, 19.07863993798533, 13.30955218884253, 11.45716384533913, 7.166577741023033, 0.5999696639276321, 0.4546830809164432, 8.132401089514456, 33.607259873420965, 54.12772778541812, 50.52791372422249, 60.13792460964572, 61.21117530330535, 71.60233405328566, 48.346440484446866, 12.982150969966767, 0.4549894241556045, 0.17292775544187716, 0.14469430511516912, 0.1380173738805517, 0.21100856123432038, 0.0888630812386832, 0.27137622838058784, 0.15668912760673032, 0.2547956188960422, 0.21114425072746895, 0.10570229136294897, 0.11899682798332746, 0.1748494257129008, 0.16515519590147082, 0.10327204596251251, 0.1534808433103946, 0.17195589630113495, 0.14990102169254135, 0.17069175929552124, 0.09919478047278621], [0.05222749265451586, 0.026482016283778415, 0.021705270384348208, 0.005396704467373991, 0.1408141770309979, 0.048142413067961895, 0.028054158939349077, 0.037298388704056704, 0.07993475549043187, 0.03598282804652568, 0.0239251920908329, 0.07971237548777173, 0.04743681544618261, 0.07645014327980819, 0.04183973876699325, 0.02975965643511905, 0.03744627431695981, 0.05435029164918008, 0.09139493288051698, 0.06133637383520123, 0.05026051594365028, 0.09392008125301331, 0.6095815546089604, 10.123942379028568, 31.769835372124952, 52.97985792160035, 39.955074710230676, 37.39208036853422, 34.381786777127175, 42.41522450600901, 33.80267235540575, 13.817946276357098, 1.4297344487520958, 0.2126149863245026, 0.45860621717668354, 3.8975197509411847, 3.834968488062582, 4.69486823005061, 5.535732219296118, 3.418833204815465, 5.644915805708978, 11.870815042526493, 21.387378400371922, 38.33689697327153, 51.998535817669286, 51.728759119587565, 52.85659351656514, 50.97105133918024, 49.076825034233835, 44.86103019406719, 37.51092818475539, 36.826643251603656, 35.806093523579264, 37.199166436349195, 38.16706618955059, 43.17698409480434, 42.94835698220038, 43.01238967526344, 41.429823137098744, 40.2132764939339, 35.62666470004667, 36.47280231598885, 37.40656960395075, 42.701326108747914, 49.440534653202185, 49.24214116988644, 52.96579230216242, 52.19308930058634, 49.06634838350358, 46.31705322573262, 40.56307738827121, 38.081958601551676, 41.01369888551774, 45.33106742366668, 47.764776522113436, 46.35641421041181, 43.102847376177394, 39.44075784375591, 36.74048839076873, 36.93786598020984, 35.38822381727157, 43.25484314272481, 47.92299316775414, 48.33665417086694, 48.003535116872484, 46.724775760404526, 50.52450910691292, 51.534927352782226, 50.56562339105914, 37.752353991231615, 54.135133220303445, 50.015365846695445, 51.29485476401545, 50.11061276158979, 48.62323038039669, 46.68548930075861, 42.616814721015196, 38.61941745204311, 37.67491855928975, 37.07209340987667, 36.6692110799974, 35.306744421682055, 38.37961550681822, 37.357712561084384, 43.2998013496399, 49.38533513776718, 52.19583103733679, 50.99031409909649, 51.70015719629104, 52.3875839479508, 49.74685607417938, 45.97832126002158, 39.689361587647475, 38.218237430818625, 39.009379494574766, 37.1928043519297, 35.685429649968306, 35.10228303170974, 38.555302389206425, 37.6746989065601, 37.69089437300159, 38.16861944813883, 37.23709183354532, 37.70048456807291, 37.56803397209414, 37.76168138750138, 39.219038025025405, 42.0322403600139, 48.32461249443793, 50.07318158303538, 55.887993381869414, 53.27582036295245, 53.64797876727197, 57.070874321845274, 58.02898776146674, 55.619483609353345, 53.570974796049065, 35.12251461705854, 22.78726839250134, 9.244236138559158, 7.106574302719486, 9.933654473673913, 5.73779704109315, 1.0985753541031191, 1.3220049585065534, 0.1647765952492914, 0.3032636576362195, 7.150972591292474, 29.301281898252427, 46.10445291765275, 34.95341339418965, 33.51973610539591, 52.72527648556618, 56.943624788715, 23.758957155289192, 5.19055825087332, 0.1960242031923225, 0.031599927948968064, 0.04171736771240831, 0.06664796401896785, 0.007812419573911616, 0.08624744256057086, 0.013019220899760485, 0.05988140049720964, 0.01335593760989967, 0.006156321342719058, 0.03339446209851773, 0.07024912118551231, 0.03117823676626769, 0.01193824881357291, 0.0034140160113888527, 0.07569278875786452, 0.019900242745455717, 0.03886475122623867, 0.08333810875492711, 0.04549104404906112, 0.058102341323730454, 0.041372145511089795, 0.01987547703808354, 0.04113732424053935, 0.08600455438417774, 0.008801844631952625, 0.04153444506828824, 0.03566434231376456, 0.07151385573970695, 0.05288807878030404, 0.03338065336368257, 0.011997328556683517, 0.09500242559419525, 0.03883460949685785, 0.006624163098392949, 0.030699837840192264, 0.05403049973650806, 0.055779811715887445, 0.07950959967509394, 0.091830377256678, 0.05331686585240307, 0.04573700040759099, 0.9451235302032964, 12.961150600064187, 38.00363279158069, 59.700560723581624, 45.270749215156805, 42.99488021481422, 38.753119284106845, 44.91690827954201, 40.02914474856469, 14.512416624253797, 1.6986547218215082, 0.04404878777061259, 0.5287477566349892, 2.2694958842569783, 5.704705965134406, 7.246489169136171, 7.063241918240824, 6.804999930243339, 6.991587569636684, 12.129434558653063, 25.572143370105376, 41.67743059896654, 53.85819819665725, 52.31433760735297, 55.26469738252702, 53.98469463471444, 51.931141653368556, 46.512426484015684, 40.422189774051795, 38.29582191282703, 36.61364678413638, 37.84916593182472, 38.18683493521906, 43.84404197815926, 43.80463000266783, 44.17954975558866, 43.44052030194191, 41.136155282297445, 38.39021767339399, 37.42969197611655, 38.55853834459859, 43.916056694522986, 52.35334557871665, 50.95873901920935, 54.6659161967616, 53.455751249867106, 51.29469002446821, 47.773495951006495, 42.147008911255874, 40.29895674797797, 42.85175292722641, 46.701225849889944, 50.1782658023219, 48.933344733330514, 46.73225179795296, 41.04438358737577, 39.35394794710221, 37.477662563323975, 38.004158389183786, 44.22242126157207, 50.61383716521725, 49.97884465802101, 48.85200262069703, 48.78492616838025, 53.42256407583914, 53.06282781785535, 52.366309012136156, 40.53000004060807, 56.289910808686294, 51.646522706554784, 53.70952467764578, 51.79667495912122, 50.516515316501746, 49.16154822995586, 45.28686231182468, 40.75039409822033, 39.175793893875614, 37.42967236426569, 39.05218039789508, 37.963099018219985, 40.69178212073542, 41.11218175580425, 45.32349332686394, 52.4022614571356, 53.95118582633234, 52.94396823452365, 52.826599151857444, 54.33969266953007, 52.364889114133774, 47.81957203342069, 42.59438268599972, 39.513831600066155, 41.037280174993704, 39.483017459992446, 37.68948624210973, 37.850232816511586, 39.585834549319365, 39.43316805747248, 39.74210962172478, 41.31083803792154, 40.53476572036743, 40.1199907641257, 39.767004905208466, 39.48852839008455, 40.714676995431226, 43.65679194850307, 50.22583630777175, 53.803845913179465, 57.11404392796179, 56.695664313531694, 55.55133634997953, 60.11823823375087, 59.27843524563698, 57.521942969291445, 55.32487438571069, 39.55170600645004, 22.34528591555934, 8.289783250901008, 7.2200651418778214, 8.250701735096595, 7.595825262608067, 4.311632562068201, 0.9364999542313238, 0.21374170247825885, 0.49898364731381023, 6.580308916107302, 30.89518016384494, 48.059283764131614, 40.613115064559445, 41.65492011654762, 57.708832140891786, 61.91524467160625, 31.32429530543666, 7.4068493900760535, 0.2976639839189668, 0.03049975099612869, 0.04256929578860441, 0.03293510428780029, 0.02023602099788766, 0.03506321993265902, 0.03584714238381675, 0.06291642634859008, 0.07519915234297514, 0.0069560304719714396, 0.013202566807458719, 0.09751204536446641, 0.0448976936299474, 0.02743804613278518, 0.06482142654638137, 0.05105209161317156, 0.05022269035238893, 0.07308301065237292, 0.029497031918576652, 0.03400869607444733, 0.21499037982956057, 0.12174928230383705, 0.09779682322855919, 0.17610752594567117, 0.21071438347139668, 0.12428163190282161, 0.1293083637832634, 0.1483622421660731, 0.22556450758730212, 0.20135442846484725, 0.11494506556060045, 0.14885269165519746, 0.2109723559190189, 0.1602181422734453, 0.13071333839287683, 0.12698516384848665, 0.10479358851068443, 0.17365904765263682, 0.1742115502636279, 0.12802169613179662, 0.12357437953112588, 0.1255916728968582, 1.1086032611708487, 14.931439507392147, 44.197855457182854, 67.10895307602422, 51.77070494621031, 49.685188570330226, 43.68171076620779, 53.38874540021343, 43.419527776779674, 18.53193017744249, 2.0975945793813278, 0.36564304102813044, 0.8057419835559784, 7.383353412151338, 11.8643460735198, 8.689729686706297, 10.538407468026685, 9.66426314846162, 9.041229947920769, 13.577596179900633, 25.409147316409697, 41.15491205646146, 54.24626965676585, 54.19856579073014, 55.68382224728985, 57.24306637240995, 55.059800609465576, 49.2290835995828, 42.323468500568026, 39.75301773317399, 38.841600110453946, 41.265495438729566, 40.08895304895217, 47.378462283842026, 46.49709001664193, 47.299218639250725, 45.769898276175226, 43.65330496141988, 38.73963809782459, 39.770609563396825, 41.97096117081181, 45.022882876857636, 55.182657088002856, 52.518422449788744, 54.11245799833729, 56.86027050018311, 54.46176859640307, 51.30259360036543, 44.127821537756155, 41.544419104053134, 44.05296702538767, 48.46764564514161, 52.48822412183208, 50.84855571869881, 48.13571899167953, 43.20811594686201, 40.49403190612793, 39.38809217945222, 39.48206824641074, 46.78694925000591, 52.605032305563654, 52.97171115875245, 53.077885796946866, 48.639645499567834, 56.24295611535349, 55.19619710983769, 54.627382832188765, 43.45999094747728, 58.42503732250583, 54.45512017896099, 55.97851384070612, 55.46303595266035, 52.791152692610225, 51.74382102104926, 47.253895651909616, 42.20294975465344, 40.94990937940536, 39.56757591616723, 40.79161036399103, 39.25995226829283, 42.98811804863715, 42.8523491274926, 46.78119121059295, 55.31804161687052, 57.260230664284, 53.5326297052445, 53.187708239401545, 57.54357484079177, 54.40426272730674, 50.17590453547817, 43.565216372090006, 41.2967881079643, 43.665629048501295, 42.53315840998004, 39.15969256431826, 38.26618840617519, 42.552421169896284, 41.80970468828755, 41.20364750585249, 42.44682312011719, 41.87714984340053, 42.73787867638373, 42.403641746890166, 41.53679401643815, 42.03886916560512, 45.764752126509144, 51.34699090834587, 55.66226097845263, 61.533378401110255, 57.68309354782105, 56.207258624415246, 59.81379170571605, 61.99725750953921, 59.29324219303747, 59.00204543144473, 38.57021524060158, 25.97762623140889, 10.706304523252673, 13.695694823418895, 19.634055399125625, 16.46444493724454, 7.261480958231035, 2.4548511639718087, 0.8691336142439997, 0.8036415543287032, 9.093055244415037, 36.72291225002658, 58.92546507620043, 46.54834362768358, 47.853441699858635, 67.47691846662953, 71.81624443300309, 38.8881782562502, 9.382810534969453, 0.4330403922546295, 0.0812842883169651, 0.1181257400481451, 0.11306932226063744, 0.09005446287412798, 0.267784777548044, 0.15547680878831496, 0.18816711351035104, 0.11817799490546027, 0.2296382414116975, 0.16055454680275533, 0.25320909677013276, 0.08318549637953121, 0.13287528448047178, 0.14063443748220322, 0.15461322851479053, 0.10662311372617561, 0.1264740989333199, 0.18375953389031274, 0.19213367163413958], [0.019429077604605306, 0.03450587181554687, 0.022750815692087336, 0.042745438554594596, 0.0223681835022064, 0.0472304581724588, 0.04985168546197876, 0.044953686996333064, 0.019094890899836056, 0.014110620400207418, 0.061227972393915545, 0.021052674555610267, 0.041735581452808077, 0.034882660669785355, 0.05600731301632139, 0.04663251505623903, 0.04298991253299098, 0.058243048692783045, 0.006018576818713618, 0.03776529248082831, 0.06154168156846877, 0.06768297944818774, 0.10374871352987905, 6.747164091756267, 26.84679404381783, 47.40589534082721, 40.21841087648946, 35.82326566019366, 33.103811894693685, 35.47043277371314, 38.365322389910304, 21.68747501988565, 3.280074702155206, 0.12104258917632604, 0.24271655737632708, 1.021975754730163, 3.230911469267261, 9.52521316466793, 4.070898563631119, 5.8115425032954064, 3.545178386472887, 3.498102835109157, 12.879919294388065, 29.5230213288338, 40.2634749873992, 52.161753485279704, 52.35140008311118, 48.830460963710664, 43.86370874220326, 39.44026754748437, 35.87673541038267, 35.61251671083512, 39.43703551446238, 43.80017026778191, 45.190222955519154, 47.0290457817816, 47.455854569711995, 48.08529692311441, 46.95810187247492, 45.07297938869846, 41.28347166122929, 37.977094034994806, 38.352217751164595, 44.93217022188249, 48.030399430182676, 50.43129005739766, 51.79763986218361, 51.24273823153589, 48.28760493186213, 44.345485625728486, 39.80054117018177, 38.48408783635786, 38.16480298196116, 42.525392117038855, 42.947686256900916, 43.737600618793124, 40.40984999748969, 39.47533353682488, 37.758504267661806, 36.69574591421312, 37.91649341583252, 48.01875391314107, 49.749499751675515, 49.25464568599578, 50.78572719327865, 52.09569292683756, 49.27053520756383, 53.17576462222684, 47.275056838989265, 38.92351096676242, 50.44676773009762, 48.16796871923631, 49.711240953014745, 45.837845494670255, 46.86330995252056, 41.8090888761705, 37.704701116008145, 36.04075324150824, 37.5414599141767, 36.886906546931115, 38.16053544321368, 36.53224191358013, 37.117941994820875, 38.36371421813965, 45.682649074062226, 49.16602757669265, 52.02706713830271, 52.51708884393015, 53.2780521915805, 51.24714697560957, 49.875274473621005, 44.9722921463751, 40.20822840352213, 39.892336399324485, 39.69184837033672, 39.1786297675102, 40.0377582734631, 39.25486887654951, 37.17058412490353, 36.94021547994306, 36.616506191991995, 37.203857591075284, 36.78499160274383, 37.472865504603234, 38.16419893695463, 37.928672375217566, 37.56213864972515, 39.21912039479902, 41.97709183539114, 47.668152855288604, 52.38417933064123, 56.30376854250508, 57.37472857198408, 58.142536455585116, 58.615217362680745, 55.61156042160527, 44.102898797681256, 32.1627607653218, 14.105563875167602, 5.25401484581732, 3.637259703490042, 5.559008544491184, 5.527341779201262, 4.616680193331934, 0.4620221725875332, 0.12820902761192093, 0.7854696423296006, 8.816232988911292, 34.11956064162716, 49.17951660771524, 41.69286904796478, 43.96902045895977, 57.03568281665925, 51.797447666045166, 21.346911307304136, 3.7317993660126967, 0.1511145202863601, 0.14997165499916001, 0.012862696687901213, 0.02045871701181656, 0.041193758107481465, 0.055796665650221615, 0.04716100081080391, 0.02667614679423071, 0.031494217391516414, 0.056908427767695925, 0.13282460010340139, 0.06616177397870249, 0.039573849869831916, 0.04825562937185169, 0.029727823566645387, 0.030660541360116297, 0.10676464847018642, 0.07279370520864764, 0.04013644951966502, 0.06273869778059664, 0.03969106515268645, 0.06091191515987439, 0.04424383758657402, 0.004624862743977217, 0.018280510708028753, 0.01982199452486971, 0.0387867596451073, 0.05178160266950727, 0.01891077315855411, 0.009572736885128243, 0.06339557987127094, 0.03539816889491293, 0.04309947842792158, 0.06272570492940084, 0.09973802108077273, 0.05313273278936263, 0.1063048271762748, 0.04628034060700767, 0.023865937105109616, 0.037829793253613096, 0.07282997947186232, 0.06296166767095847, 0.161696293601586, 9.00389192565795, 32.56074013248567, 55.617487122935636, 46.707281989436, 42.20239277808897, 39.663050328531575, 43.704888051556004, 39.92168749532392, 24.490298763398204, 3.1226050228841844, 0.37298020215765126, 0.3893790802647991, 1.6525271582988001, 3.1619302159355533, 8.127356431176587, 7.4437235920659965, 7.769057721860948, 6.329596898248119, 7.757390631783394, 19.36025238806202, 29.568709096600934, 43.73576887192265, 52.35347893930251, 57.571949266618304, 50.330732253289995, 47.8883154930607, 40.93755783573274, 39.58909403893256, 39.01333324370846, 41.4059986606721, 45.400822854811146, 48.66246977160054, 48.25107589844735, 49.758215258198405, 50.19391998167961, 49.735234091358805, 46.22153174492621, 42.00993776321411, 38.95100285930019, 40.59417001662716, 47.26542349784605, 49.79701926631313, 51.43174940539945, 52.377079840629335, 52.18911201723161, 50.82313483761203, 46.63266674164803, 41.55726486636747, 39.09216503943167, 39.965272872678696, 45.532822378220104, 45.24762292062083, 45.8028579527332, 42.56482370438115, 40.022606157487445, 39.263435333005845, 38.913202977949574, 37.792197427442, 49.43361559221822, 52.50450588041737, 51.73739225633683, 52.05940708037346, 53.15435240345617, 50.14266637063796, 54.87738293986167, 48.83921961630545, 41.66067815596058, 52.55173121729205, 50.02303800275249, 50.8904819334707, 48.11719363735568, 49.06141011945663, 44.789635212190696, 39.27444150370937, 37.67911549537413, 38.257888670890566, 37.695981687115086, 38.619841068021714, 38.06637502485706, 39.87736471237675, 39.42881422658121, 47.81389244141118, 50.400883843821866, 54.042318174915934, 52.298546145039225, 54.14314662256549, 54.64151120954945, 51.781973915715376, 47.611188273276056, 41.09362502251902, 40.44078965340891, 41.064199401486306, 40.028438721933675, 40.994404746640114, 41.214096699991536, 38.338387473937004, 38.8799608907392, 38.92269119139641, 37.639001415621856, 39.47349786758423, 39.536169498197495, 39.25066017335461, 38.632478944716915, 39.20334854433614, 41.809736067248934, 45.25636588373492, 50.005650135778616, 54.242060953570956, 58.747413004598315, 58.097397819642104, 57.74271749681043, 62.381641941685835, 57.87428555950042, 48.95862048672092, 33.80216636965352, 17.229848407929946, 4.468877440498722, 7.089165353005932, 7.630039607324909, 6.994988754872353, 2.937586576707902, 0.5125916058257703, 0.14256782889846834, 0.5125088376864311, 10.273048339351531, 36.21217258514897, 55.49907468980359, 41.153711811188735, 48.598425311426965, 62.95300183757659, 60.73652144401305, 25.704033067149503, 5.295188946108665, 0.17115538038553732, 0.07635193080791543, 0.04746742831963686, 0.05520871615097408, 0.04636526145341416, 0.059957457706332214, 0.013956645345916192, 0.04739863362403647, 0.021069145445982297, 0.09260587274066864, 0.09638704524766054, 0.020835180278687228, 0.08135849925419016, 0.1011456693372419, 0.0459549026263337, 0.08939145208005944, 0.057299105796001615, 0.09433274217430623, 0.073296933044349, 0.05303138318741995, 0.09051379387176807, 0.20785011861833835, 0.13628016225993633, 0.07622075357264088, 0.11997047210893325, 0.11210625014838674, 0.11453045877597987, 0.12582897629228332, 0.1895774967007099, 0.07813593507894585, 0.15498923978978588, 0.10885793775800737, 0.15437060846917092, 0.09474998430138636, 0.20819049148309618, 0.1614062373916949, 0.21707547197659172, 0.12292675944345614, 0.10894410732773044, 0.17966102478244614, 0.1730467442182764, 0.1493253679044785, 0.28008162254287355, 10.569961955470424, 37.934383346188454, 61.185852481472885, 53.282198136852635, 48.41616061425979, 44.92944025224255, 46.77546455014137, 50.006987664007376, 28.23075529067747, 4.347854179720725, 0.3807870671153069, 0.9996160997017738, 3.536060837007338, 7.691360962006354, 22.626380612773282, 12.943567595174237, 12.699286303212567, 7.110098062023041, 5.284651988937009, 13.834897779649305, 32.695146029995335, 42.421829777379195, 54.59462319650958, 57.80981748334823, 54.53306159665508, 48.91080287195022, 44.37473866247362, 40.93814619125859, 40.714233767601755, 43.990758234454745, 50.018401761208814, 51.27421132979855, 52.471514824898016, 52.12098436970865, 53.92181511848204, 51.50022222149757, 48.37871766859486, 43.706202045563735, 40.729546700754476, 41.546184170630674, 49.24185091449369, 53.040089837966434, 53.04516538496941, 53.58839796435449, 53.66978322305987, 52.96962445782077, 47.8267970392781, 44.177239479557166, 41.56403095491471, 41.52707438315115, 48.20327005078716, 47.07430993357013, 48.448186766716745, 43.938806441522416, 42.37723635089013, 41.4517766429532, 40.409120436637636, 40.70992308278238, 52.799554409519324, 54.5203923409985, 54.65474528651084, 54.62753972699566, 55.59418039937174, 52.19210870804326, 57.78305515166252, 49.76019213276525, 45.18707721464096, 54.73391440606887, 51.243334431802076, 54.17291348980319, 51.81558078335178, 51.97664899210776, 46.29131463266189, 41.686616789910104, 39.31591272354126, 40.79186924042241, 39.93647090850338, 40.94887779605004, 40.35282657992455, 42.04382311913275, 42.70975920461839, 50.763404984628, 53.86638418320687, 56.63706802552747, 52.98055218112085, 55.06600187670801, 56.969449673929525, 55.473222347997854, 50.127063182092485, 43.35781320448845, 44.3576410508925, 43.710289155283284, 41.933518225146884, 44.86584294226862, 43.96018335896154, 41.07906126206921, 40.47900530599779, 41.91494580238096, 40.94568890909995, 40.98040580749512, 42.575472939398985, 40.39435271293887, 41.44961933935843, 39.91992635111655, 43.961842521544426, 47.67899428644488, 50.47675817243515, 56.64872923204976, 62.11738794080673, 57.52890517634731, 58.81697623960434, 61.308301033512244, 59.21624214418473, 47.92422086961808, 35.840327970443234, 16.463774211945072, 8.22051223247282, 7.207712617612655, 9.69329261010693, 16.193764132838098, 9.319717249562665, 1.5517823061635418, 0.23272078003614183, 1.5217076554413766, 11.9942275170357, 42.82317061578074, 62.716243651605424, 52.96219156634424, 55.36310965015043, 70.83084306409283, 67.28788375854492, 32.51952582790006, 6.965022827348402, 0.3455199643729195, 0.2677231840789318, 0.1456885493450588, 0.13953836484541818, 0.15075674190396263, 0.17103300550051276, 0.1673857834670813, 0.16162172260303653, 0.09356386568998137, 0.15951108908460987, 0.26645092654132074, 0.13558553501723275, 0.33094109666924326, 0.22041000756284884, 0.1481271451038699, 0.22870600433839908, 0.31124059411306537, 0.11146636754875222, 0.13103815967277174, 0.12664574859363417], [0.028763828318445917, 0.05835786228999496, 0.01159937460831697, 0.06398084806278348, 0.033389103313487385, 0.05604131199840096, 0.06544091588547153, 0.014797022731433955, 0.023778534133828456, 0.08328764654335477, 0.05509333947913782, 0.029714294453902595, 0.050603148767784725, 0.06254702641238129, 0.04646788276131115, 0.04887532938512103, 0.01654219209036279, 0.07703536550604528, 0.04687375997403457, 0.08392317010270012, 0.01563277773393859, 0.03444942645728588, 0.06475137546658516, 2.790142720745456, 22.18863037324721, 47.21607615870815, 47.81083691504694, 36.04209469210717, 23.20171779201877, 39.332355299303615, 43.5104287055231, 28.75969083078446, 4.776211323276644, 0.6142396756237554, 0.1822832364949488, 1.5593924397422423, 2.1873695427371613, 6.000066322665061, 8.43435004834206, 5.861791987572947, 5.420813147098788, 4.083542814177852, 10.289284010087291, 17.75483412127341, 33.414306717534224, 46.556262893061486, 54.345788032777854, 47.04777902172458, 46.399160200549716, 40.11451905773532, 41.18293739134266, 43.44528598170127, 48.46456658455634, 45.91650078373571, 50.22712284518827, 50.04175947558496, 50.840636453320904, 49.723090433305316, 50.27987872400592, 46.847698919234745, 45.95267288146481, 42.53611587708996, 45.499521455457135, 44.35410699536724, 48.961209251034646, 48.54477120983986, 52.96452537659676, 50.61050315057078, 49.639512569673606, 45.997478115943174, 38.807871649342204, 34.704240906623106, 38.60841520370976, 39.44695911099834, 38.654173574139996, 39.48172700020575, 39.125654235962905, 38.057541847229004, 37.45579534961332, 35.67025399977161, 39.55480467888617, 49.355246636175345, 50.74157699461907, 50.66753049050608, 51.09768898256364, 51.35579270701255, 50.37719272798108, 51.70358142545147, 48.35573650175526, 42.869227086344075, 53.20568446190127, 47.24348568147229, 45.922278434999534, 42.62234134058799, 40.324169743445616, 38.32459642041115, 37.38911113431377, 38.01035181168587, 36.8956651995259, 37.386647885845555, 37.17035270506336, 36.56953580917851, 35.73733829682873, 38.03135610395862, 45.66039354570451, 49.5097880209646, 51.09806553010018, 49.586368376208895, 50.92779936329011, 53.054728123449514, 47.32139964257517, 48.14862751191663, 42.2807970354634, 39.84615441291563, 43.067244022123276, 45.026471845565304, 46.85243322003273, 47.45055152523903, 43.721750320926795, 39.27879533460064, 37.92681709412606, 37.5556981179022, 38.14296714721188, 38.790472015257805, 38.378909480187204, 37.71405596886912, 39.18616856298139, 37.26325404259467, 41.096982571386526, 43.55324922069427, 50.252979109364176, 52.03174652591829, 57.14056699506698, 56.34766770947365, 54.86985983387117, 47.83421816364412, 37.24478360145323, 23.335199971352857, 11.036193505410226, 2.1512072509334934, 6.231545978976834, 7.4407720085113285, 5.119698672525344, 2.845508936912783, 0.45387684998493044, 0.06870838047395791, 0.48586632215207626, 10.285119433556835, 33.21184573634979, 43.45844161125922, 37.12871674568423, 36.60909683473649, 53.10092972170923, 43.62593466235746, 20.669249296188354, 3.5009188517447445, 0.020356865622283473, 0.03862014318245553, 0.01089253975453997, 0.05735986039883668, 0.05037853944926493, 0.03733234938174006, 0.017357658211802764, 0.022986140665448, 0.033995611292700616, 0.011143959277579862, 0.045476017234426354, 0.061635002568965, 0.052464267449273225, 0.015518024466150712, 0.09195040791265427, 0.022038403718221574, 0.06200704550851257, 0.06413399286928677, 0.06694117651110695, 0.022190435782014843, 0.05418701532987818, 0.02471598826589123, 0.008847553267954819, 0.015291129332786847, 0.021988404989843408, 0.07324044172081255, 0.08724202386914723, 0.001491497058586608, 0.012913210610408458, 0.017501299697605353, 0.08951046383909642, 0.0428766081289899, 0.08606941904872657, 0.026606294897294817, 0.029840405932777835, 0.010830693476412807, 0.05624693382771746, 0.0416273600421846, 0.02544893331134752, 0.036874853164678624, 0.008657910117519, 0.03894136384910634, 0.03504455420038393, 4.411922174115335, 27.36606094145006, 52.556736161631925, 52.94906731574766, 39.741509499088416, 28.067590575064383, 41.9609591268724, 50.453831918777965, 29.705425270142097, 6.001674984731983, 0.16885650374235647, 0.12362817422516885, 0.571780447517672, 1.6239823545179062, 6.9018574683896965, 7.699297878050036, 9.024099976785722, 7.656203287263071, 5.762487871031608, 15.226870467585904, 22.322420458639822, 35.52666779487364, 50.46871339121173, 53.84905515178558, 49.70936998244255, 48.41093601719026, 42.20947265625, 41.27030426456083, 44.265861511230476, 49.84499377589072, 48.1485176855518, 49.9354200978433, 51.76321714155136, 53.218820479608354, 51.57420204531763, 52.30951701441119, 49.83728239613195, 47.6015902334644, 43.46448206132458, 46.91606190896804, 46.99093603318738, 50.44501835300077, 49.74268267231603, 52.90475237754084, 53.20815163273966, 51.75988312690489, 47.25269932900706, 39.986222251769036, 36.800990950676706, 40.02800726121472, 42.08603958929739, 41.248205631009995, 41.52763135971562, 40.81664293043075, 40.12655288942399, 38.71813566453996, 38.44598985487415, 41.02297136860509, 51.326751478256725, 53.35698204655802, 52.79171751391504, 52.929145597642474, 53.348195937372026, 52.793596329227576, 52.33156857951995, 48.793339652399865, 44.98691082000733, 54.968256412013886, 48.570258771219564, 47.10472399188627, 45.396402343626946, 42.50445450505903, 39.54581068408105, 39.56058625252017, 40.25528115610923, 40.025532245635986, 39.05757757925218, 38.24825925211753, 39.08690121866042, 38.14896837357552, 39.51500831111785, 48.9838570164096, 51.84790895831201, 52.92503887607206, 51.077979072447754, 52.70869270447762, 54.984247915206424, 49.91800477427822, 49.94982304111604, 43.48680819234541, 41.855804304922785, 44.715600475188225, 45.94610291142618, 48.300282032259055, 48.3939560767143, 44.418704509735115, 40.712468701024214, 40.869124243336344, 39.50311568475539, 39.66820040056783, 41.25277519226074, 39.547916996863584, 39.584555856643185, 40.487297196542066, 40.18278398821431, 42.00486613858131, 48.13755466092018, 53.197157229146654, 55.822470188140876, 59.79396412449499, 57.195884181607155, 56.48136561916721, 51.32801055908204, 39.00197798205961, 28.700106105496808, 14.057364809897638, 3.7517786939297957, 9.857144721092718, 9.161451574294798, 6.201270674505542, 4.011660722955581, 0.8613756563394301, 0.1169640289980077, 0.669576290153688, 11.6097685598558, 37.828177329032656, 49.490564484750074, 43.041019055151175, 44.60527204698132, 59.52557986782443, 52.615528568144775, 25.044953284725068, 4.462258440832938, 0.06263931702461935, 0.05885727883827302, 0.04320902134021444, 0.04590412248827277, 0.03688634065310321, 0.012170010520475767, 0.0480077539630715, 0.011342900820196638, 0.004619157304161139, 0.02577590729830967, 0.024524774635210637, 0.0376744995704822, 0.06349747722607947, 0.025289075659407724, 0.02252695139407391, 0.024870536928515763, 0.05801800653458603, 0.049838232958028396, 0.06288131270858069, 0.07265705810559374, 0.14518841650457154, 0.13757238404885416, 0.1146421620562192, 0.15197751833306206, 0.138547322863052, 0.1701505334987756, 0.22263517122595544, 0.16573979759648924, 0.15396651241087145, 0.16414633471398585, 0.27511918076103736, 0.10192858055233957, 0.14826061294203804, 0.1626959464122211, 0.1137045776892093, 0.1100934996840454, 0.10191951007131608, 0.15897383162331197, 0.09552443024492073, 0.1703495018544697, 0.07097903443800826, 0.09356409551635866, 0.11668563264632419, 4.8982676382987735, 30.60982185025369, 60.86603418473275, 60.05753955533428, 47.964935072006725, 34.19117919860348, 51.417173877839126, 55.2924559962365, 36.68507706734442, 7.18200050054058, 0.8553056659237032, 0.33691943232570926, 3.971704028306469, 8.125935062285393, 13.004225088704018, 14.792656244770175, 14.94794386048471, 12.201604208638592, 7.351928362923284, 14.883289471749338, 19.473469641900834, 37.976117364821896, 48.231256161966634, 58.59671554257793, 50.901268451444565, 50.83932245931318, 43.70610398630942, 43.96598846681657, 48.27943855716337, 53.6313126164098, 50.55447993739959, 54.069453131768014, 54.71350239169214, 55.0899048005381, 53.509075872359745, 56.008865141099506, 52.927078508561664, 51.656018764741965, 47.572839260101325, 50.94641493212793, 48.02643783630864, 53.87267958733344, 50.77613307583717, 53.889122163095784, 54.821708817635816, 55.10393511864447, 50.04561908783452, 42.02206573178692, 37.73861785088816, 41.87633791277486, 42.92842741935484, 42.938829545051824, 44.087621165860085, 43.72873998457386, 41.00328499271024, 41.94434788919265, 39.7880405764426, 42.89063930511475, 53.63072818325412, 55.69651111479729, 53.252388123543035, 54.82993795025734, 54.11578024587324, 55.45618749433949, 52.17895700085548, 48.93532945263771, 49.680446424791896, 57.96808904217136, 51.877389492527136, 50.19028786690005, 47.40181999821817, 43.99467668225689, 41.20913490172356, 41.960955204502234, 41.9166402662954, 42.68404022339852, 40.12118708702826, 40.20746354133853, 40.801981110726636, 40.83196370832382, 42.136987255465606, 52.432934391883116, 54.020086180779245, 54.972496494170166, 52.92725109284925, 53.32526576134467, 59.84300944112963, 52.12047446158625, 52.6199451569588, 46.336994555688676, 43.6832679471662, 48.4082805725836, 47.67894721800282, 52.00721210049045, 51.68260851214009, 46.91283772068639, 43.4336639988807, 43.19707839719711, 42.01202054177561, 43.39072973497453, 42.52172862329791, 42.59146052022135, 40.800251345480646, 42.53530002409413, 42.22945713227795, 44.429008576177786, 48.68074801660354, 55.013218541299146, 57.02976396006923, 61.37498524881179, 56.45492099946546, 57.19635094365766, 51.042571836902255, 41.35353695961737, 26.69413539671129, 12.60700862253866, 5.416877538927141, 13.777109499900574, 20.019257645453177, 13.060179660397193, 9.605737463120493, 1.9075546413660052, 0.4006345359788787, 1.017479676633112, 14.155807475889883, 42.84124881990495, 57.063794443684245, 49.67166816034625, 49.94657531861336, 67.76351036563997, 60.03049089062599, 29.279316625287457, 5.344665233165988, 0.21757540563421868, 0.13877056088418732, 0.1438089985881121, 0.09034054308769204, 0.09318186360741816, 0.15163959694966195, 0.13507930411686822, 0.07417597297218538, 0.19657102143091543, 0.12352345000591972, 0.10521227854394144, 0.1356215717931909, 0.15538745229282688, 0.17493729599781577, 0.11792222879106, 0.07764146362821903, 0.14384688929684702, 0.2301176898782292, 0.17236252044958456, 0.18215879317252867], [0.014976061309777923, 0.03174321128866606, 0.07270545187977052, 0.02568828024631066, 0.03009993545410614, 0.009438818970304585, 0.02060293880922179, 0.03297936884806522, 0.03697631384937033, 0.04403103751340701, 0.06796358979397243, 0.03931739427629979, 0.04386143713829018, 0.046288759913295514, 0.05875184981813354, 0.005991014890417818, 0.03979841322307626, 0.06510595160145914, 0.05991698911173209, 0.042638795285095135, 0.03482196735398423, 0.14246538762123356, 0.12814861391821217, 1.2291096271045747, 15.458374638711254, 45.76662309708134, 50.717191619257775, 38.07425506653325, 36.70109210475799, 33.90692110984556, 34.14382050114293, 33.463473627644206, 8.269563432662718, 0.5757829811303847, 0.045356626261866866, 0.3068546794595257, 0.976545698940754, 3.4723855699262316, 4.115940120912367, 5.385273531559975, 6.925446112309733, 4.909747435200599, 10.804347107487342, 11.76360195682895, 26.99489881915431, 44.51632838095389, 51.48739999340427, 47.63514611028856, 45.661931114812056, 44.88215215744511, 46.59432165084347, 46.378214743829545, 50.86992086902742, 50.388171442093395, 51.17244543567781, 48.67894764869444, 47.9462645899865, 49.578382430538056, 50.69336714283113, 51.04141081533125, 48.97543176527947, 47.1430298589891, 49.40858694814867, 46.85804613174931, 49.980178263879594, 51.047278681109034, 51.27125778505879, 52.413930508398245, 48.86176932242609, 43.190739846998646, 37.531320587281265, 37.86895821171422, 37.17881717989522, 38.995474692313906, 37.95808230676959, 41.45374959514987, 37.456050303674516, 38.97847513998709, 36.68000936508179, 36.315676089256044, 38.308236214422415, 49.02661869602819, 50.65592027479603, 52.566196918487556, 51.35767544469526, 51.20215346736293, 47.932897152439246, 49.35282653377902, 45.64883824317686, 40.418498823719645, 53.1741133043843, 47.91484640490624, 46.76332481445805, 39.87678420159125, 37.75542912944671, 37.40602831686697, 38.17408330978886, 35.534555681290165, 35.96676949531802, 36.96763676981772, 38.339752458756976, 36.851730731225786, 37.200307846069336, 37.83972086444978, 43.67104191933909, 50.44966636165496, 52.05228013377036, 49.752206187094416, 50.21271990191553, 52.562866826211255, 49.906131759766616, 47.95940453006376, 46.16755993135514, 45.56793543600267, 46.72577596479847, 50.96008831454862, 50.49474616204539, 49.96125282779817, 49.05569522611557, 47.227792278412856, 44.19653754080496, 44.03319435734903, 45.436536035230084, 44.5303665438006, 45.07575250441029, 41.83238775499406, 40.887806492467085, 39.17194997110675, 39.81508139641055, 43.31105462966427, 48.268440231200195, 50.26806062267673, 55.62145656155002, 59.80327975365424, 50.32076551068214, 41.8647276970648, 27.418440272731168, 18.337355121489495, 8.665369806751128, 2.035820436093115, 9.277945968412585, 7.819818094853432, 3.2361495494842534, 1.4911750680015934, 0.5751132364234617, 0.20895057327805028, 0.86957402286991, 13.24951344920743, 36.85979512430007, 43.841716012647076, 34.40538375608383, 41.2392508599066, 54.681331111538796, 43.10038020533901, 14.987825539804275, 1.482451226442091, 0.04303722995363417, 0.002080961017899456, 0.0643740541812393, 0.10735611431300641, 0.061382626393629666, 0.10621912492018555, 0.061538812569192344, 0.05577092126552617, 0.04035834305649323, 0.07253383286297321, 0.01051734532079389, 0.05085457882453358, 0.048910799256015214, 0.037537381323354865, 0.034760209175968365, 0.04874881379486573, 0.028121477000475414, 0.05625920272582481, 0.027724585999103806, 0.01086892988232355, 0.007469310817654215, 0.06366467974599331, 0.06431879625926096, 0.019446310752461997, 0.05308512808574785, 0.058073310421839844, 0.045948325761503754, 0.08669577253561828, 0.07102661615898533, 0.04032548937586047, 0.001979253269852169, 0.04385782120328757, 0.05480579603763838, 0.017762290531649225, 0.0127711855701261, 0.06615088020841922, 0.025391666323787747, 0.06981864105910063, 0.023007426418424137, 0.01400367548358777, 0.07182401409673114, 0.033386249635969444, 0.043539511670749036, 1.603592158325257, 19.875359612126505, 51.244083604504986, 55.75503680013842, 43.1991062625762, 38.42887655381234, 40.5810732226218, 44.867388356116514, 39.490387593546224, 9.824761632950077, 0.5896198160706029, 0.06814322209045773, 1.134686164798275, 2.2716414207412354, 6.064029393657562, 7.190261992716021, 8.442876300504132, 7.7709684064311375, 6.992088162129925, 11.974885329123467, 14.497364528717535, 32.31578027048419, 46.76986732790547, 53.35127107558712, 49.27260229664464, 48.089125156402595, 46.48586419320876, 47.94085956388905, 48.07349451126591, 53.2048725312756, 53.03734025647564, 54.03931363936394, 49.62782782893027, 51.10068567337529, 51.91389106935071, 53.18592748334331, 52.47938702183386, 50.74009433869393, 49.005226089108376, 51.13971325658983, 47.47255994427589, 52.394071548215805, 52.77878545945691, 52.383551751413655, 54.12018506757675, 50.0572528377656, 45.5623774374685, 40.33346183838383, 39.67220514051376, 37.82725557204216, 41.081685327714496, 39.80613054767732, 42.7648175147272, 40.03696595468829, 40.65662591688095, 38.51381547989384, 37.99910637640184, 40.831077252664876, 50.11869284414476, 52.12575004946802, 53.273588534324404, 51.57499436409243, 53.617011654761534, 49.69825006300404, 51.71044165088285, 47.140739194808475, 42.94202235437209, 54.122954260918405, 49.08072387018512, 48.686725708746145, 40.3889359197309, 39.0604801331797, 37.834135409324404, 39.41857684043146, 37.57173276716663, 37.89728556909869, 38.90667223161267, 40.462107735295454, 38.20741168914303, 38.993995958758944, 39.55225906064434, 46.88948392868043, 50.76923754907424, 53.51909360577984, 51.209943294525154, 50.60390572394095, 53.96907575668828, 51.83210180651758, 50.33319550175821, 46.82254083694951, 47.77437456192509, 50.57146772261589, 52.03015404362833, 53.55299465117916, 53.16094198534566, 52.09257072018039, 49.94044073166386, 45.645617977265395, 45.42016406213084, 45.69371015794816, 45.44358845679991, 45.24388490184661, 43.38771343231202, 41.89633415591332, 40.928112768357806, 42.28777100962978, 44.67060696694159, 50.74772334867909, 54.09233231698313, 56.98660219869306, 59.47416543960572, 51.441206239884906, 45.21103112928329, 31.862656301067723, 20.569193555462746, 10.789380323502327, 5.301398548387713, 9.230830457902725, 4.8132679154795985, 7.363598394778467, 4.746132627610238, 0.7701068828182837, 0.06553244040978533, 0.7984192861664681, 15.268384833489696, 42.00989069477205, 48.58200234751548, 40.95543992134833, 43.37624442192816, 65.1059437567188, 49.51171782708938, 18.705673525410315, 2.371547621104025, 0.022218162419214364, 0.08620631896079549, 0.00848191578106414, 0.022499764848861004, 0.0240468755815058, 0.03335306653752923, 0.05936200054542673, 0.10066656561027612, 0.019325121388500257, 0.04842845880756936, 0.011790675381498953, 0.05542777516248246, 0.08191015916846453, 0.06597330102757101, 0.07662325616805785, 0.06347860081962521, 0.039932367527076316, 0.034363957858013536, 0.07099928980272624, 0.02048327396022937, 0.08588910493398867, 0.14066989203133892, 0.25126055213472537, 0.11749273691807063, 0.18084899732662787, 0.1201703597701365, 0.08910465940472581, 0.13963305331285925, 0.26170666660031966, 0.12363128454214144, 0.10591922448046746, 0.13804043312707256, 0.08522319832756635, 0.1178555255154929, 0.10773247798844691, 0.0966614579421378, 0.15802797350671985, 0.19278732849465263, 0.12507631788931547, 0.17150914446721155, 0.14826406033769732, 0.23502368630180437, 0.2358110101833459, 2.09165733668112, 22.808053032044445, 57.25057378891976, 63.07931784660586, 50.5220615479254, 47.585324164359804, 45.142385728897594, 45.88600435564595, 44.66954008225472, 11.48760045728376, 1.1393181162495767, 0.18348034080718795, 1.697888266175024, 4.300760242246813, 12.1020064046306, 11.909933820847543, 13.97377125678524, 14.189135855244054, 11.472305174796812, 17.724220022078484, 14.651143993100813, 32.34252299031904, 49.31371658079086, 56.87473620137861, 51.23657226562501, 50.26771937647174, 50.673719990638, 52.283978462219245, 51.50639210977862, 56.147642520166215, 55.040192680974165, 54.692278446689734, 52.56624790929979, 52.107718913785874, 53.50798545345184, 55.17540854792441, 54.88532573946061, 53.94000314897107, 51.837016536343484, 53.0838321101281, 49.86269935484856, 54.76930595213368, 52.78486905559417, 54.29326357380037, 57.90948490942679, 52.68546835068734, 46.55768279106387, 40.807295922310125, 41.53996329153738, 40.32967282879738, 43.217910105182284, 42.92512478366975, 45.54970425944175, 40.47224706219089, 42.55559044499552, 40.431101399083296, 41.04252830628426, 41.7437304219892, 52.802139251462876, 54.17127786144134, 55.443557462384625, 53.758420944213874, 56.32081516327397, 50.98100239230741, 50.341589373926965, 48.43814549907562, 47.90025126549506, 57.83590124499414, 52.373765437833725, 50.35890663823774, 43.529613018035896, 41.45577353815879, 40.45628301558956, 41.90066053021339, 38.94252269498764, 40.05559329063662, 42.326841738916215, 42.97895146954445, 41.258615601447325, 41.16715377376926, 42.21706636490361, 49.32692712353122, 53.372408728445734, 57.43894169407507, 54.81004368874335, 53.87670786150041, 55.61867167872768, 55.180911633276175, 52.61823500356367, 49.134338748070505, 50.99863344623197, 52.371949380443944, 55.24388920876288, 54.62290348545198, 55.41767766398769, 54.21483578220491, 52.74637491472306, 49.01131752998599, 49.84202061930011, 49.253143418219786, 48.33252783744566, 49.741352988827614, 47.28980887320734, 45.507950628957445, 42.60215290131108, 43.55583014026765, 47.63383996102118, 52.88326955610707, 55.94845279570549, 59.25905481461556, 62.499591535137554, 51.3079397909103, 45.257911297582815, 31.01439079930706, 22.359679052906653, 11.447390279462262, 3.9622104216006497, 20.5169750413587, 15.937941266644387, 8.230120078209909, 4.75495845079422, 1.7590469650683866, 0.5481899036995826, 1.5748493974247288, 17.9625157771572, 46.42802100027762, 55.78413294207666, 48.08688940540437, 54.12342886770926, 71.22178569916757, 59.02534038789811, 22.283145766104422, 2.902514948960274, 0.18492377303060026, 0.16072299421554612, 0.18043316480132843, 0.27676859870553017, 0.12191281143215396, 0.17224540092772053, 0.08652194718559904, 0.1736582049559201, 0.1277273574904088, 0.16367586479792673, 0.17285601896864755, 0.09923100110984619, 0.32792617296499593, 0.15977420964308325, 0.12976964064423116, 0.20647480693315307, 0.07218464232620693, 0.1186541032286421, 0.18827739952793046, 0.18072957954099103], [0.0610200331486281, 0.0284301127577501, 0.04514942629142635, 0.04328219422830209, 0.0410940938989722, 0.11351580596378735, 0.08458899243945077, 0.01883011750666605, 0.04907087715823324, 0.017383222565836003, 0.026709184335965305, 0.09331255054642117, 0.0299490544374191, 0.054362392007944085, 0.011213775742949258, 0.02414596139363224, 0.11290028496014495, 0.034317180529356964, 0.03700792263712614, 0.04624459494446074, 0.04262517424180143, 0.008710953087786273, 0.01962290742554732, 0.36565318403224795, 9.30670282533092, 37.962428292920514, 49.349182651888945, 43.21545862382458, 26.948073564037202, 25.47528632225529, 39.79389667510986, 35.32581106308968, 15.974906663740835, 1.6595675676099717, 0.1322585990231845, 0.5471903734630155, 1.2415626621054066, 5.102752562492125, 6.715468889282596, 8.019597645728819, 5.920519674977949, 3.8596019533372696, 5.439864099025727, 10.95037498781758, 22.001111661234212, 38.352304043308386, 49.83618805485387, 49.010160430785156, 48.7884602239055, 46.748184465592914, 47.27877916828279, 48.46152674767279, 51.3984327931558, 50.49848418081961, 45.690960576457364, 47.93671754098708, 49.61265610110376, 47.0640137118678, 53.02366295168477, 51.32862637119909, 51.315662937779585, 49.897988919288885, 51.70525627751505, 50.653900254157286, 51.95919836721113, 49.49363962296517, 50.575354791456654, 48.068211078643806, 47.09383941465809, 43.649833663817375, 39.0645750876396, 37.20074322915847, 35.51777185932283, 36.765768066529304, 38.44316574835008, 43.29177618026734, 39.87445039133872, 35.95621047481414, 37.97552116455571, 37.531822650663315, 38.690314292907715, 46.48683301864132, 49.76348300133982, 51.670959072728316, 51.82651635139219, 51.653241726659964, 49.23323738959528, 48.805016548402854, 48.187984574225645, 37.63259618513046, 52.77793430512952, 48.7037762518852, 47.57476122148576, 41.98849416548207, 37.75985356300108, 38.1645990187122, 38.02125207839474, 35.850129973503854, 37.56512749579645, 36.63727121968424, 37.12394714355469, 36.67459257187382, 36.41639863291095, 37.112525201612904, 43.318475754030295, 48.5160320035873, 51.18131783700759, 52.64490712073542, 49.80420897083898, 50.35254847618842, 54.01925071593254, 51.65736413771107, 47.98726512539772, 50.09013014454996, 51.414161497546786, 51.23129275537307, 50.95955094983501, 50.24437735157628, 52.37103154582363, 52.205750711502574, 49.93305098625922, 49.216885028346894, 50.08765120660105, 49.773794912522845, 49.81829812449794, 48.72272522218766, 45.12948897577102, 45.30328919810634, 41.012620233720355, 43.445364429104714, 47.119491715585035, 52.81698150019492, 54.800567242407034, 52.95582555955457, 41.81184630240164, 31.668691173676525, 20.211498891153646, 13.30819602935545, 6.632526939915073, 5.958088626784663, 8.651111010582216, 3.065636028205195, 7.933528096445146, 3.953721431955215, 0.7516738267675523, 0.059650344548807036, 1.6380849913243325, 13.600391034157047, 34.59240236589986, 32.811169739692446, 27.773040186974313, 45.727097372854914, 54.61158352513468, 43.30700674364644, 12.984004289873186, 0.9907399598629245, 0.09776658573818785, 0.05516897533990203, 0.05205521863254328, 0.08680502433449992, 0.012964506900208372, 0.06793922053710108, 0.017219314223996574, 0.05012440127170375, 0.040274330024277015, 0.0671206938944036, 0.045689522108483704, 0.037574643839991866, 0.0069059608804602785, 0.05640319278163295, 0.0718272623095301, 0.0020060453994853065, 0.02391882206974251, 0.03185194214775918, 0.042853954909068924, 0.03577110815733191, 0.029298122934696656, 0.07049872795300138, 0.013797521223163894, 0.07982435455966382, 0.04430747268000438, 0.09281848512229421, 0.015143906385938247, 0.05967977764685789, 0.006960760107293966, 0.04436240884505453, 0.0320618617303309, 0.11322552758839824, 0.024127086902397777, 0.033205870403757984, 0.027518462382196903, 0.03480719334836449, 0.10314024819601929, 0.04300081779459312, 0.05106893022574725, 0.10329602451454248, 0.030453709111879432, 0.05115355612830289, 0.03772734048505945, 0.49195874362222614, 11.255927624241, 43.08223532092187, 54.764038208992254, 47.13570679387739, 31.986860113759196, 29.810968406738777, 42.90050014372795, 40.115381979173236, 16.369346091824195, 1.1747810004218933, 0.14917861610170335, 0.3966239431212026, 1.8897555383943745, 7.6888810434649075, 8.286969930894914, 7.100073464455144, 9.024173521226453, 9.227968108269478, 6.510252443052108, 14.56753965347044, 25.858113573443507, 41.60421955970026, 51.42026470553491, 50.85240356383785, 50.60616893153037, 50.40229981945407, 50.431941170846265, 50.36862627152474, 53.203962541395626, 50.465995188682314, 49.18441172569029, 50.047388076782234, 50.94602269511069, 49.70163506846274, 54.38938517724314, 54.70508498530234, 52.739240123379616, 52.81635392096735, 54.24786998379616, 52.90013182547785, 53.70922657751269, 49.93067402993479, 51.04278756726173, 50.107416029899355, 47.96375051621468, 45.761037641955966, 41.195575268037864, 39.302564897844874, 37.32693764471239, 37.96319707747429, 40.750853015530495, 46.131187792747255, 40.96109597913681, 38.44520145846952, 40.333869764881754, 37.880580194534794, 40.22320009046986, 49.020860656615234, 52.21028497142177, 52.768316653467, 54.038913557606364, 53.45613956451417, 49.88796334112845, 48.82768784799884, 48.43599604022119, 40.93404339205834, 54.75436564414732, 51.596402660492934, 49.174523430485884, 44.851232113376746, 39.96428443539528, 39.27427676416213, 39.08002530374835, 37.93627785098168, 40.169851933756185, 39.42683735201436, 39.031756616407826, 38.9594163433198, 38.94609989658479, 39.21715920971286, 45.147378906126946, 50.38969332172025, 51.09894414101878, 54.93278249617546, 51.52816126423498, 53.31811135815036, 55.708231156872166, 52.65952187199747, 50.17226849832843, 51.45465604720577, 53.04079978696762, 54.26159435702909, 55.384278681970414, 52.66214593764275, 56.05393317437942, 55.49511701829972, 52.86326546822825, 52.35102353557464, 51.02854544116605, 52.354989051818855, 51.94129274737451, 50.552385391727576, 48.09502440114176, 44.63585868958504, 44.4533900291689, 45.06769203370617, 50.80625687876056, 53.71874224755072, 57.45570198182137, 55.1467477890753, 45.102506991355654, 34.43746874409337, 23.742528307822443, 13.863237884736831, 7.987592085715264, 7.348478638356732, 6.176857842553047, 5.981127158288033, 8.359547507378364, 4.083861261606216, 0.5257169289454338, 0.06551805327856733, 1.6329093013078937, 16.215486218852384, 37.340344305961366, 36.98505993812315, 33.290901107172814, 52.16047479260353, 60.66436159995295, 49.32143580528998, 15.167799572790823, 1.3744421447477033, 0.07021703742324345, 0.04281334841864244, 0.046467492056469765, 0.086528382324163, 0.03760373219847679, 0.052169361902821454, 0.014877848837885165, 0.04103081503642663, 0.036900314096842086, 0.02157429233193398, 0.0454362572711562, 0.043776451174410126, 0.016865793375238296, 0.05314964034985151, 0.09640383789496076, 0.08076576936629512, 0.04627690470266727, 0.040187643345205054, 0.02780013950541616, 0.012125675097077846, 0.1806931903645877, 0.21117668689018299, 0.12228029614855206, 0.16774356184947878, 0.14335326820371613, 0.19943076636522047, 0.22958210248860622, 0.105322158534921, 0.13196691870689392, 0.10892510068632903, 0.08309502139567368, 0.14306301281096476, 0.11100705953374987, 0.20099498001077484, 0.15216606789298598, 0.15050906567804276, 0.19175926914378522, 0.17619666793654043, 0.12914805222422848, 0.23677185297973696, 0.1399730431336549, 0.1324479912798251, 0.13622030014953307, 0.6634260137234965, 12.533909370822292, 48.77757564667733, 61.90656838878509, 55.05190880067887, 37.63298449977752, 35.83747248495779, 50.79591358861616, 46.35923439456571, 21.1750683476848, 2.553336730887813, 0.22002967555196057, 1.228814468749108, 3.2143654409916174, 10.429336159460007, 13.167174073957629, 17.36793152747616, 14.566149173244355, 8.765876620046555, 8.862673851751513, 16.03376869232424, 25.662752082270963, 42.43770360946655, 54.36126962784798, 52.74733589541528, 53.40648235813264, 53.81080812023532, 53.70498649535641, 53.64236977792556, 54.10655875359812, 52.475527409584295, 49.53720538846908, 50.25747806795182, 51.27016736615089, 49.55002761656239, 54.56600558373236, 54.81262460831673, 55.90078423100134, 53.65949484609789, 55.82085809400005, 55.00151026633478, 54.734675345882295, 48.523637479351414, 53.69913431905932, 52.40832151905183, 49.99498128890992, 47.46747655253257, 42.32324884783837, 41.099339915860085, 38.913963917763006, 39.21369967922088, 42.298494769680886, 46.723630428314216, 42.53048727589269, 39.39635269103512, 41.89243531996205, 40.5097488434084, 42.703012727922015, 49.85020268347956, 54.68540645414784, 55.28838849836781, 55.90143534444994, 55.63261178232009, 51.46035525106615, 48.87382276596562, 48.816320819239465, 43.66845315502536, 56.11691859460647, 53.741378245815156, 51.43941371671615, 47.622527845444225, 41.667503080060406, 42.00143406468053, 41.225079336474025, 40.536789663376354, 42.50483105259557, 41.93596578413441, 40.866449186878825, 41.756642864596465, 40.601575451512495, 40.85696097343199, 46.857218511642955, 52.0520487139302, 54.99705445381903, 55.91308870623189, 53.173607318632065, 53.858864999586544, 59.601077648901175, 56.02026747119043, 51.89769560290922, 53.99484180635022, 55.75461318415981, 56.27633156314973, 57.50997581789571, 54.73680519288587, 57.335959865200905, 57.76103888788531, 54.61681596694454, 54.73059608090309, 55.11465103395524, 55.228227184664824, 54.112881614315896, 54.72749348609678, 50.121838585022964, 49.42535508063532, 46.01477576840309, 48.39972588323778, 52.03529234855406, 57.22400365337249, 59.11880262436406, 56.1521650129749, 46.452578959926484, 34.53391982663062, 23.20347305267088, 15.691651721154491, 9.3238494665392, 11.34923198530751, 17.309982430550363, 9.68769048490832, 20.73829673951672, 8.48137044137524, 1.8637296317085144, 0.18388485055296652, 2.386886294811003, 17.955710464908233, 44.32044521454842, 46.78195607277655, 41.342903414080226, 58.56221437454224, 70.58676181300994, 57.059103288958156, 19.784342973462998, 2.0268862574331226, 0.13924217993213286, 0.14751459652137372, 0.08757464392411132, 0.24584906025519296, 0.12366987239088743, 0.16321204452505036, 0.0885764187982967, 0.09763065875778276, 0.1321573068778361, 0.13805707255678792, 0.11939994344908385, 0.17101789824664596, 0.051287970085057526, 0.15518773317096696, 0.22307050834980705, 0.12485830458782374, 0.1319203252393392, 0.10774223794860226, 0.17001666729488682, 0.09521193531972748], [0.06434223854974394, 0.07581494147739104, 0.07302379971670528, 0.03801601007580757, 0.008017055543830559, 0.06332088629865358, 0.018629810412324244, 0.05876838582597914, 0.053629410573311394, 0.07980800624335967, 0.059744014119308804, 0.04719796072271082, 0.03729109937745718, 0.04719691118225456, 0.026126517012955684, 0.001505728578194976, 0.031245443744645007, 0.020135159776996703, 0.05228519056653304, 0.09090962384136454, 0.03998914996402399, 0.02844057751879577, 0.07049397820787084, 0.06280717838014807, 4.332410337463502, 29.861839586688628, 48.08218256119759, 47.92396199318671, 42.69551707852272, 27.860571799739716, 36.174584511787664, 42.87036457369405, 22.30646033440867, 2.7602346481815463, 0.12634967093265828, 0.5164298595440003, 2.368415363373295, 6.55787491990674, 5.753641945700492, 5.314099673301944, 6.530136898640664, 8.843206147993765, 5.1133679670672265, 6.8941706034445, 17.77872920036316, 32.208509329826605, 50.1138997077942, 50.93211004810949, 51.25717647614018, 49.07959030520532, 52.26550017633746, 52.24679831535586, 52.219620212431884, 49.74797394967849, 52.52636524938768, 51.39181183230493, 52.635520888913064, 51.17618345445203, 50.72378120114727, 48.87429737275647, 48.2574301381265, 49.99823293378277, 51.23496801622453, 49.44956002696868, 49.89716129918253, 49.83517216097925, 50.42553594035488, 50.47794272822719, 48.01622006200975, 48.43560380320395, 44.7305525502851, 38.86541281977008, 36.59714145045127, 38.42103965820805, 36.39234665901431, 38.59446333300683, 38.05981289955878, 35.64023610084288, 36.13734552937169, 36.445875244755904, 37.15875425646382, 45.26821144165532, 49.79333223835115, 49.25064094604985, 51.261553841252486, 52.72495485121205, 48.641336041112105, 49.01110179962651, 48.46914006817726, 36.13048530394031, 51.72958281732375, 51.30758285522462, 49.777132849539484, 45.031527780717425, 39.64612137886786, 39.591612200583185, 37.25247536936114, 36.82908296585083, 36.55548980159145, 37.27171851742653, 36.32225782640519, 39.51062702363537, 38.72822007825298, 38.02753571541079, 38.581950972157145, 46.92797022481119, 49.33040626587407, 48.67034981327672, 50.99182028924265, 50.626533877465036, 49.4863244025938, 53.88528216269709, 53.630614434519124, 49.92663398865731, 53.55166496769075, 53.189116370293405, 49.7082011161312, 51.26738248332855, 48.79473601618121, 51.23380699465352, 51.03232660601216, 52.526835933808364, 52.07537897171513, 52.62444803791662, 51.285962750834805, 52.081917562792384, 51.61554382693384, 50.924849740920536, 47.46631160859139, 47.716343095225675, 51.12476902623331, 52.02201904789094, 56.63697388864333, 51.37811099329303, 36.63962464178763, 23.69015289891151, 14.534824144455696, 6.212285180245677, 4.226436720740411, 9.049639509570214, 2.960710664910655, 2.417213325538943, 7.259876218534286, 4.45600078951928, 0.28390881395147693, 0.21343817844265894, 1.825017186422502, 17.828058888835294, 37.64465355104016, 40.89485499166673, 34.81263560633506, 41.81341132810039, 57.43057920086769, 42.69895699716384, 9.114783213984582, 0.6182899518359093, 0.039410642498443206, 0.04446835880498252, 0.016396999276513537, 0.07505601647520259, 0.018518497836926294, 0.04215976433648218, 0.05928723036401695, 0.021905140808573174, 0.04490358867652474, 0.0496759946878639, 0.07000209613432808, 0.012336917138928849, 0.07050199914843806, 0.01713620900597063, 0.011637348629113649, 0.05547909539253001, 0.006942438635779846, 0.029689245293998433, 0.044588090686668316, 0.036482505064698, 0.05778855937082441, 0.03455834883836008, 0.031550999828464085, 0.021462926130381324, 0.06061256247302217, 0.04259163491247643, 0.06810841105517841, 0.05410528907011594, 0.05319089418457401, 0.013605064614826154, 0.022286413192388513, 0.04333637962718645, 0.002388089257780643, 0.061377570213329416, 0.056910396613661325, 0.037695593801477266, 0.07269269651583127, 0.14451091898785484, 0.022277495928949887, 0.05764543116393109, 0.01968138483202746, 0.06829776500742282, 0.0503463905695225, 0.04578173228148972, 6.212745568444652, 35.35317743978193, 55.84896972102504, 52.99308023145122, 41.23414001157207, 32.74028662712344, 42.560214919428674, 46.060075221523164, 25.845811059398038, 3.5560771822929387, 0.30349363723108846, 0.23353307838401488, 2.0527770874961733, 5.202621010042006, 8.800077726764064, 10.239671910962752, 13.397225006934136, 14.977587173061988, 6.9315797186666925, 9.222948455041456, 19.644355543198127, 36.114105486100726, 53.33689951127576, 52.44397978628836, 52.17051213787448, 51.47003173828126, 54.39484119415284, 53.12265573009368, 53.16318165871405, 50.974985476463075, 53.7354633115953, 53.72953661026494, 53.80346544327275, 51.484838685681744, 50.045156248154186, 49.675657210811494, 48.76309033363096, 49.96294336934244, 52.393593019054784, 50.47424001078452, 50.7618046575977, 50.20249820524647, 50.606941638454316, 52.22258552428215, 49.7189837117349, 50.67847390328684, 46.5271589063829, 40.95795808299896, 37.706070023198286, 39.373006743769494, 38.086916477449485, 41.092295339030606, 39.39552899329893, 37.48936691591817, 37.86355710798694, 38.352876709353545, 39.02584952692832, 47.46764521444998, 50.70145114775627, 51.75883193169871, 52.61040203032955, 54.11711385173183, 51.2509399075662, 50.70516170993928, 47.32744401501071, 39.62535242880545, 54.156274795532234, 51.66954701946628, 49.81619573408558, 46.68787802419355, 41.698807516405665, 41.40562211313556, 38.68233226960705, 39.43988707757766, 38.407789891765965, 40.27086081043367, 38.31978367220971, 40.22707146982993, 39.481381831630586, 39.46373901059551, 40.07510708224389, 50.02760756400324, 51.14555366577641, 51.311583672800374, 53.97667731008222, 51.772222903467, 51.35132120501611, 56.8090953365449, 54.917320512956195, 52.32096249057401, 56.0656100703824, 54.9581249298588, 51.808269485350586, 51.63344552440029, 51.027929629049, 53.78382221344979, 54.34675293584024, 54.10011429940501, 54.397704524378625, 53.708646066727184, 54.141903231220866, 54.467354051528446, 52.960434344507036, 52.45359351558071, 51.46801564001268, 49.85406621809929, 53.42655704867456, 55.00251831546907, 56.898599901506984, 54.43504548841908, 38.750518752682595, 26.40905361021719, 17.913748948804795, 9.266880962156481, 5.286928924822039, 8.35235191929725, 7.055106922503441, 6.576370366158025, 6.285840897790848, 2.136784940958023, 0.42224829716067164, 0.14734663940485448, 2.1132813634410983, 17.850110453944055, 42.35674196673978, 44.46501201198947, 35.36592514284196, 47.313696107556744, 63.8356057290108, 48.10202583189934, 11.162220239639284, 0.9404258177645746, 0.04560729406113106, 0.011426837243620428, 0.03348757242483478, 0.06589103084538253, 0.040828621450571284, 0.01729588662724822, 0.05697506975622908, 0.040300691109751506, 0.03807729327931039, 0.056138555369069504, 0.04816485178326407, 0.051662173392551566, 0.029774859449976397, 0.03473732996010973, 0.08197225825560671, 0.11456828819768083, 0.03972181592196707, 0.05262563620964366, 0.02723384539656822, 0.04239671916190175, 0.11493399559009461, 0.16056890329045637, 0.2243798445429533, 0.118490252343397, 0.21303656450923414, 0.19968412696353852, 0.14887216561023267, 0.17049075314594855, 0.2294222046170504, 0.09712697893020608, 0.11587950130624157, 0.11732610513366039, 0.10778021292700883, 0.12988584086058602, 0.16882258136906933, 0.20993311168445697, 0.20615968432637954, 0.29513154238943134, 0.16411662582428227, 0.2123433928335867, 0.12756474766760104, 0.18603798662943227, 0.14972109828264485, 0.1916086256143547, 6.340837430569434, 40.664403976932654, 61.80687742848551, 61.433663906589636, 54.08550739288331, 38.39311238258116, 46.476521107458304, 52.531950704513065, 28.9869039289413, 4.504010600428428, 0.36899412411355204, 1.1907047201548855, 4.180373386029275, 12.144263079089503, 15.016063663267321, 13.211850850812851, 14.272036129428496, 16.22211894681377, 10.969240607753878, 8.911525011062622, 22.765913048098167, 37.55020679966096, 55.6308820170741, 54.18621816942769, 55.13376474380494, 53.25649876748362, 56.15325150951263, 54.13700811324581, 54.03106881726173, 51.27696875602969, 55.49039840698243, 53.14429152396418, 55.98134971434071, 53.88659615670481, 52.90560353186823, 50.00905083071802, 49.18457646523753, 50.47369480133057, 52.786163437751036, 51.37398858224192, 52.50741627908523, 50.54973386949109, 52.954013424534956, 54.47865439999489, 51.619277923337876, 52.596920844047304, 49.84945743314682, 42.37051340841478, 40.20241545092675, 41.48044132417248, 40.32300479950444, 42.30317415729646, 40.835909612717174, 39.82059232650265, 39.11286730920115, 40.65870869544245, 40.743561329380164, 50.04062983297533, 53.73589084994409, 53.28129206934283, 55.16080556377288, 55.44242389740483, 52.384422517591915, 51.96533295416063, 48.226439491395034, 43.61928624491538, 56.021432415131606, 54.676679180514434, 53.67432140534925, 49.839172978555005, 44.21488246610088, 43.594265445586174, 39.53826404386951, 41.05131833784042, 41.07744132318805, 41.52874923521473, 39.72144265328684, 43.210532126888154, 42.93888838060441, 41.1097381191869, 42.997751389780355, 51.19402631636589, 53.80441073448428, 52.88471298833048, 56.359493655543176, 54.028393760804214, 53.01164088710662, 57.39608587757234, 58.03273754735147, 55.74432480719782, 57.738516638355875, 57.04670467684346, 53.11417556578114, 53.50059963041737, 51.90318692115046, 55.00354597645422, 55.52923379405853, 56.66619554642708, 57.66189705940985, 57.15019249146985, 55.98725288145004, 56.99668269003592, 56.447033113048924, 55.359850160537235, 53.454452945340066, 52.96097955396099, 56.688584435370664, 58.02881909954933, 59.9117019099574, 56.176699438402736, 40.08577200674242, 26.0923320247281, 17.67853225431135, 9.360919787037759, 8.119614653048977, 13.52212602092374, 14.28639102366663, 14.216820924512803, 16.480165796895182, 10.220237547351468, 1.4608569851806088, 0.35004196688532835, 2.9297984655826323, 22.07059252646662, 48.85219481683547, 54.11242269700574, 45.79328344714257, 54.94705207886235, 72.31636231945407, 56.64899203085131, 13.58557624201621, 1.2248804540403428, 0.20568478642211807, 0.19226243569245263, 0.15406757472984253, 0.2521954858375173, 0.12009634801577176, 0.14605582721771734, 0.13979630664952342, 0.1235171297805444, 0.12185987475658618, 0.13312475335213447, 0.20420075153871892, 0.14728619506762874, 0.16016571121590753, 0.07117935110844913, 0.14995765091190416, 0.1371884054594463, 0.12310885088217836, 0.1273301102581524, 0.10161937214434148, 0.1810078226750897], [0.023925940941778884, 0.051817470906122085, 0.044667687222001054, 0.05476126334659996, 0.029620337600429213, 0.0856774578231477, 0.03332544906785892, 0.030426618327657064, 0.05698415938945067, 0.04152322954107677, 0.026965061533114603, 0.05628297826455486, 0.007846576561625566, 0.04638511845241151, 0.04823162783718398, 0.029811610602923942, 0.011571990795463566, 0.10450467377180055, 0.06725699625789158, 0.009512875732334872, 0.055589247344722675, 0.019622782936259624, 0.07466375647533326, 0.02035822542834907, 0.6491294034546422, 19.114768889642534, 46.018423572663345, 49.255838086528165, 36.9225138233554, 27.94971158427577, 26.1610911738488, 35.60446800724153, 28.25489747908808, 5.103968006949271, 0.6700444618059743, 0.2780595487884937, 1.108627408262222, 7.307109890445587, 6.148805051080643, 7.9618858521984475, 13.902217418916765, 17.288546677558653, 3.5630236998681104, 10.330997436277329, 16.14787534359963, 30.045275111352247, 48.81305348488593, 56.093392218312914, 52.120992214449, 51.36578690621161, 51.75354457670643, 51.833910019167014, 50.57257383100448, 52.18862956570041, 49.06909012025403, 49.28755829411168, 50.98312047220046, 49.55699374598842, 52.95411148378926, 53.766049954199026, 51.78028729654128, 52.55860320983395, 51.761189276172274, 50.8890934144297, 50.533526635939076, 48.73450017744496, 49.08102589268839, 51.35063086786578, 50.381577937833725, 48.452305255397675, 48.67544889450074, 47.22965932661488, 38.825145767581084, 36.5415693098499, 36.051728033250384, 37.57101889579527, 36.076882193165446, 37.14310007710611, 36.43264901253485, 34.353988939715975, 35.989613379201586, 40.25026052228866, 46.42739734342022, 47.58186855623799, 50.02087285441738, 50.73451280593873, 52.8232180687689, 51.51893584958969, 48.17301680964809, 36.648720618217226, 51.68658187312465, 53.516010622824396, 49.554812908172615, 49.152342427161436, 41.59560995717203, 39.25609265604327, 37.219523537543516, 37.792573974978545, 39.48918342590332, 45.237660100383145, 40.19659857596121, 40.632562175873794, 39.14510919201759, 37.770294912399784, 38.39748190295312, 40.22250583094936, 47.78056406205701, 48.687776903952326, 48.28975439071656, 51.82411586084674, 51.91542471608808, 50.378875424785, 52.57621072953748, 53.07730920853154, 50.90197447807559, 52.84798783640708, 49.61640196461832, 52.18137318088163, 49.41467054428593, 51.25671363645985, 52.53866972461824, 54.83382109672793, 53.74242551865117, 55.35524529795493, 53.34235552818545, 53.50559280764673, 53.856440974820046, 53.61219106181976, 50.53900226469963, 51.676348409345074, 49.651922948898815, 55.279892644574566, 57.05500048975791, 46.174616275295136, 32.1452199259112, 19.97528591463643, 8.952103891680318, 4.935628704486355, 2.663106711641435, 7.229773008054303, 3.8422177635854293, 4.394146482790671, 3.5238791809928034, 1.383277773857117, 0.28222498333742546, 0.1331063212766763, 2.2822244657624156, 19.202633903872584, 36.05355978012085, 40.260576355841856, 33.90742317322762, 39.35653671141594, 49.589667089523815, 35.77977441972302, 6.0512218744524064, 0.14143357443953716, 0.046784790352948254, 0.0688510720107344, 0.045171102749243866, 0.06372857147887831, 0.07267402695311655, 0.02490265324952141, 0.07843460977798508, 0.008796800900581143, 0.06317353694729748, 0.05288233695131156, 0.04881952754071644, 0.014858656420162129, 0.08696339769108642, 0.02583996565531819, 0.025214891535260027, 0.09982031424559894, 0.02264121915363977, 0.004680526692555437, 0.020329181119919788, 0.043811388614196936, 0.046723698671426506, 0.0665052954648291, 0.06494478202394902, 0.04467556643630228, 0.04768289054834074, 0.04057161044329405, 0.10065256152302028, 0.03545956701160439, 0.041713108263549306, 0.05156654646740325, 0.01883246748137378, 0.04015774293352039, 0.041019381174156745, 0.018602551088758537, 0.020509167732070052, 0.026215588140691963, 0.05195746964384472, 0.03180410187210768, 0.11276797391474248, 0.021456770613909732, 0.036584999968087485, 0.021356460976324255, 0.08731602030175348, 0.041704620009348284, 1.30507760230572, 22.965043937006307, 52.88465415277789, 54.24535182214553, 44.38644301506781, 31.400202974196407, 32.74904527971822, 43.844265553259085, 31.07727619909471, 5.282952622059853, 0.8446284227313534, 0.16593291304044186, 1.3804697245359423, 3.437687057641245, 8.08692709092171, 8.40942632767462, 9.264895262256745, 13.247710139520708, 8.934329671244468, 13.107419706160023, 19.078100612086637, 34.77657725734096, 49.16376044673305, 56.1584839513225, 54.193674595125266, 53.051645140494074, 52.51698686230568, 53.8034301419412, 53.78763083488711, 55.357163336969194, 51.70455025088403, 51.342758670929946, 52.25279561934933, 51.79308991278372, 54.34706672545403, 53.62062023532007, 52.338087558746345, 52.1958859505192, 53.44798887929609, 52.09437501045966, 51.37222351566438, 49.98000960196219, 51.01564476566931, 53.12560927483344, 52.438355107461255, 50.691068633910156, 50.17759507702243, 49.01833857259443, 40.50170013981481, 37.70718397632722, 38.859431205257295, 39.46622579328476, 39.139723777770996, 39.05939755901214, 38.11720109754993, 36.55081433634604, 37.72250475422029, 43.37889594416465, 48.64858065882037, 50.61367242567001, 50.87308622175648, 54.53141812355288, 53.185852958310036, 51.55508049072758, 50.107557235225556, 40.80698605506651, 53.46920890192832, 55.22985496828633, 51.85709907162575, 50.518496113438765, 43.23311321197018, 41.43642448609875, 39.22176407229516, 40.168263373836396, 39.230789446061664, 46.778010168383204, 41.65169592826597, 41.1744729165108, 40.81477195985856, 39.68515680682275, 39.83949815073321, 42.755341068390884, 50.83100703454787, 49.799219715979795, 52.3321569350458, 53.28614404124599, 51.699255051151404, 50.74000804655014, 54.30785479084138, 54.84263074013495, 52.76329994201661, 54.012402257611676, 51.625643930127545, 52.764072648940555, 50.03116123137936, 51.152978712512606, 53.18344854539441, 56.42140434634302, 55.025648532375214, 55.982055740971724, 55.10942251451554, 55.03637229242633, 56.0569533994121, 56.65517760861305, 54.06528757464502, 54.670972131913715, 52.81101165279266, 55.85005621756277, 60.3476066743174, 48.94477452001264, 34.387148657152736, 21.8444110116651, 11.040623822519857, 6.615922566383116, 5.873749333043253, 7.324399207868884, 5.878256626667516, 6.807906406541025, 4.259059563759835, 1.8870710437336278, 0.16406123766735678, 0.20200414763342953, 2.6482409286883573, 21.756928428526848, 42.361338984581735, 45.56220485318092, 40.21169185638428, 45.747187752877515, 58.73053504574684, 43.12860165872882, 7.968187630176545, 0.387267895163067, 0.011467744423557195, 0.05407801634001155, 0.06885363840528073, 0.028495707121046803, 0.04439183811266576, 0.03080717058882358, 0.06371364808611332, 0.042841084631941015, 0.02784811384645441, 0.02186134930760149, 0.041401111295506846, 0.011049793665147117, 0.04982510987188547, 0.016888756860768604, 0.0634880658359297, 0.060809443239122636, 0.04698390043490837, 0.019206619077932932, 0.06974544135793563, 0.0673875223184305, 0.13981072442425838, 0.15766544537919183, 0.1632840567899327, 0.1106498557172956, 0.16082615561542973, 0.17961597881249844, 0.22825871624292868, 0.15023391753915818, 0.12496522747941556, 0.12634601669325946, 0.14521732866283388, 0.20575713576568713, 0.16090670209978858, 0.15428877495709928, 0.12563102683352848, 0.08643489661476306, 0.11169954173026547, 0.17328372585677332, 0.19779991839201222, 0.14899593477527942, 0.29251532148449655, 0.17019378682298048, 0.18691098978442533, 0.15850625751960665, 1.5887147308357301, 24.796977120061076, 59.43599293308874, 61.03999130187496, 50.39410206579393, 38.12156277318155, 36.794840674246515, 45.85808492475941, 35.72063292226484, 7.7902752930118195, 1.108860789287475, 0.29908918324978123, 2.8390539413498295, 14.842996924154221, 15.634061521099461, 18.74835675762546, 20.973840951919556, 28.67934500017474, 8.733814185665501, 14.018850076583124, 19.355853449913766, 36.52809596830799, 50.569647742855935, 58.01402784162953, 56.2494162590273, 53.096909292282604, 52.78034656278549, 54.82200691776892, 55.45882724946546, 58.47932292569069, 54.74190427410988, 54.34161855328468, 54.91219397514097, 52.93464868299423, 55.63679695129395, 55.823419401722575, 53.68324871986143, 53.76752084301364, 54.01367310554751, 55.11252903169202, 53.785536289215095, 49.849284848859234, 49.09597796778525, 54.55668603220294, 55.29838661993704, 52.76278611152403, 52.545643698784616, 52.59605007786905, 43.50378813282136, 39.5891018836729, 39.71326058910739, 41.70743280841459, 40.02401036600913, 41.82095796831193, 39.788217083100356, 37.26185375644315, 39.088736887901064, 43.99097004244405, 51.197481924487704, 51.56867542574483, 54.45241374354209, 55.71601706166422, 55.81624930904758, 53.41358577051471, 49.41588647903935, 43.634073580465014, 55.27651940622638, 57.03598483916252, 53.59212421601819, 53.03790900015062, 45.841210888278106, 43.24193070011754, 40.675990658421675, 41.79512131598688, 43.58024689459032, 49.93079954578031, 44.523804418502316, 43.729167522922644, 43.952805380667414, 41.261004324882265, 41.56177559206563, 44.98010550775836, 52.722730867324344, 53.381555695687574, 54.50535397375784, 56.276747334388, 52.314270927060036, 53.21530603593396, 54.49495184806086, 54.66028367319415, 53.25205472207839, 54.037344609537435, 52.9580024750002, 53.245920135128884, 52.43915134860624, 51.860829245659616, 54.67288232618763, 56.923557942913426, 56.788094966642326, 57.59800164930282, 55.07172069241924, 56.88773101375949, 58.38763360054263, 59.7531714747029, 56.70809430460776, 55.42877797157534, 54.011817824456, 59.381573969318026, 62.66014199103079, 49.475282930558734, 37.29659026668918, 24.49298166459607, 11.759323631563495, 7.848847556498743, 8.133030139630842, 14.38851091169542, 16.2280015214797, 14.692639727746288, 10.805645412014378, 5.037732412738185, 0.7406690656658143, 0.35786473582829204, 3.44590368770784, 23.575225491677564, 47.96359362140779, 55.13147015725413, 47.25269148426671, 54.06891968942458, 65.91540721154982, 50.741220058933386, 10.84551630481597, 0.5157281842923934, 0.15442049611480008, 0.14573073014616966, 0.13955999916839984, 0.1570952308153914, 0.18278813440232508, 0.16319212623901908, 0.13724336460713418, 0.10878153580931887, 0.12251946113763318, 0.1529344387592808, 0.17226720379004556, 0.08072028672623058, 0.22005101876153102, 0.16711559957794606, 0.20347502112628954, 0.19248006594998224, 0.1306122301086303, 0.12187230070271801, 0.10962724325156982, 0.13413413547940795], [0.06030114773180216, 0.04103482933714986, 0.05348649304059725, 0.06562257831495616, 0.02738907779266517, 0.026465060842794277, 0.01949251159995554, 0.034312231601366115, 0.0217341193403568, 0.0495358235803583, 0.035885653623770324, 0.10217196668588346, 0.013836909633790775, 0.027953111942136483, 0.014706209711279842, 0.07445062315391918, 0.02575370032460459, 0.02701984065014028, 0.09142345433393795, 0.005299551590841505, 0.037495189030925115, 0.0473532161014455, 0.06900197601005917, 0.08525316002628497, 0.4780253509600317, 12.26097124238168, 39.58676022868003, 50.28766070642779, 43.289650255633944, 27.530421979965706, 37.786600205206106, 43.050734766068004, 30.099319488771503, 8.448878507460318, 0.910423853464665, 0.1006590273051012, 1.1212206679967143, 0.728242077654408, 6.5885645247274836, 8.045863797587733, 9.469033056689847, 13.000371360009717, 8.476215466376274, 8.82837272459461, 19.564086198806763, 36.16851268276092, 48.28325110097086, 48.83959224147182, 47.412959529507546, 52.446446957126746, 53.02860121573172, 52.902524471282966, 49.5565858194905, 47.53650242282499, 46.42027824155746, 46.86249409952472, 46.95869022800077, 51.021038024656235, 49.27080192873555, 51.57769687714116, 51.12429834181263, 49.442962600338845, 48.73391182191911, 50.21923103640157, 49.76100798576109, 51.11317842237411, 49.91881670490388, 49.36327965028825, 52.28796359031431, 51.47588783694852, 50.673602319532826, 51.19896850278301, 47.89997669958299, 38.41407352878202, 36.822258041751006, 35.38515652379682, 36.01000185935728, 36.71043911287862, 37.53927907636089, 37.54952822962115, 36.48840550453433, 40.12999280806511, 43.3899962517523, 45.277613362958355, 48.369743285640595, 49.305471758688654, 48.043468767596835, 52.35468310694541, 49.9570402022331, 36.168198893147135, 48.71989719329342, 52.40272429681594, 52.23724734398627, 47.80060737363754, 42.824123751732614, 37.8387834179786, 38.56996813128072, 38.74603548357564, 40.253092473553075, 41.04153594663067, 39.09110992185531, 37.01239101348385, 39.23992072382281, 37.509269022172504, 35.90385860012424, 36.68438280782392, 40.88501768727457, 45.922152919154016, 47.96532338665378, 51.20103951423399, 52.61239851674726, 47.28673373499225, 50.40579465127761, 52.80968589167441, 52.33411812013196, 52.032746730312226, 50.88337852108864, 53.76553220133628, 52.66560546813473, 52.39395387711064, 50.92357497061453, 51.681659298558394, 51.681000340369444, 54.84685121044036, 54.55814515390704, 52.74347236079555, 54.89946196156164, 55.212643607970215, 55.442129719641905, 56.941032102031095, 57.75894041984313, 57.72315271439091, 55.773377803064164, 45.749113636632124, 27.505883632167695, 15.86467041123298, 7.057295605059593, 3.9499228615914626, 4.271654784679413, 5.370031201070355, 3.474493108449444, 2.1066236303698633, 3.388721904447002, 1.2049130158078287, 0.06340030280332412, 0.13429950321874312, 3.6500797252501216, 19.23656240586312, 40.23548103147938, 41.18504370412519, 32.96609747794367, 41.03487968444824, 49.042523907076934, 28.293009188867387, 5.201001561457112, 0.1308137878415085, 0.07223774754111806, 0.08052457424421465, 0.06949975696061889, 0.045551863769369746, 0.08609034090993867, 0.06409869919861517, 0.030381796438427224, 0.01658416030207469, 0.06446825235240883, 0.06271043679706993, 0.037434419106331565, 0.033363393402748534, 0.10738861942363363, 0.08742023124209336, 0.06145615168216248, 0.03241326817641816, 0.08401630341165489, 0.032371324862563805, 0.060631599757940545, 0.05891129952825366, 0.04184348110650336, 0.02988832664766139, 0.03369050145509743, 0.06268279251432227, 0.06303674811797758, 0.09621687413704011, 0.0016243070187497764, 0.03520732107121618, 0.03057609548822286, 0.028664047281528195, 0.1050963158148431, 0.09550671063123212, 0.08057332807971586, 0.02903881557886639, 0.005111480357065316, 0.04465641806863489, 0.03536303227226581, 0.027109254602222677, 0.048091077516155864, 0.026249192587490526, 0.035962461599058686, 0.027439584054293174, 0.08526766973157084, 0.046018518567565954, 0.5181846911868742, 15.310505205585113, 47.37294350900958, 55.8077024644421, 46.31283275542721, 32.62196048613518, 33.62522432881017, 45.57752955344416, 34.81799748636062, 10.332208468068032, 0.8539477903996745, 0.08609534346408422, 0.8161540377524592, 2.8463213578347237, 5.012429693052846, 6.618613312321325, 7.995629022198339, 8.518930077552795, 11.375619730641766, 12.152187247430126, 19.027245121617472, 38.6768997869184, 48.80928800952051, 53.2647200553648, 49.710774190964244, 54.084334604201786, 53.951052465746486, 53.99477904842746, 51.09835186312276, 50.01834292565623, 49.288158416748054, 49.78404406578311, 50.205094814300544, 51.27350138079736, 51.72192635074739, 53.133026476829286, 52.923352256897964, 52.269198971409956, 51.48203026863837, 52.31267060002973, 51.76349955220377, 53.254847449641076, 49.12969073941631, 50.60820071927963, 53.505455524690696, 53.58340086475496, 51.45486001045474, 52.02382333817021, 50.314881955423665, 40.269299707105084, 37.398360083180094, 37.29104403526553, 38.26348589312646, 38.57697348440848, 38.24367007901592, 38.49558038096274, 37.612992179009225, 41.03535821360927, 46.130724953066924, 47.25583330277474, 49.44536309088431, 52.39103563370244, 51.51504878074893, 54.430456315317464, 50.72482847398328, 40.17018141285066, 49.55238888340612, 54.10927303375737, 54.88234473812965, 49.60481136075912, 45.21058397908365, 39.77785810347527, 40.36224026833811, 40.290688391654726, 40.71925047905215, 43.4760412862224, 40.68675364217451, 39.75626153330649, 41.45972336492231, 38.51081094434185, 37.47907069421584, 39.32791125389838, 43.50445885812083, 49.33584659330307, 50.994934651159475, 53.59557197939966, 54.28035113119311, 49.614931075803696, 51.30827711474512, 54.054242180239775, 53.97739902619393, 53.87661372461627, 54.39535502464541, 55.45921556411251, 54.28805074384136, 54.5004000202302, 51.0206183310478, 54.816127284880615, 52.614210651766875, 56.20088869525541, 56.22765887168146, 53.609217905229144, 55.511249726818455, 58.04392414708292, 57.33079802605414, 59.23299066482052, 58.747107059724875, 58.44530420918619, 56.110787930027136, 46.50093001704062, 29.877727147071596, 17.943507971302157, 8.082502657367337, 5.968438290780591, 5.878234073039025, 7.226425755408503, 5.5500013116867315, 6.589595617786531, 4.630668345958957, 0.39178864129128, 0.2706248493444535, 0.2847074146472639, 4.0500509210171245, 22.002037340594878, 43.97161706801384, 47.38930763736848, 38.460349652075, 46.801246289284, 58.27797589763519, 33.777388757275, 6.581131142954673, 0.18055952334355924, 0.026681379174753547, 0.026731548357694864, 0.05607363324792636, 0.029210938298473918, 0.12050216011102162, 0.04256140508298432, 0.0237506581094837, 0.01670779540173469, 0.024662159097891663, 0.1523656491190195, 0.03719813460784574, 0.034499451998741396, 0.037127210187815854, 0.04426217007060205, 0.042355859862460245, 0.05666557406525939, 0.016811837802731225, 0.035148412740278634, 0.048113566027173114, 0.08203279452338334, 0.1727822753450563, 0.16130394933204498, 0.10536619326880864, 0.14143093909707763, 0.12013882759117311, 0.1630840159111446, 0.12665514849246512, 0.14858282952299043, 0.11483380661135721, 0.1933078086304088, 0.31319424089404846, 0.2808991609321487, 0.18501329806543168, 0.07406135855783379, 0.1669006965934269, 0.15858787652705947, 0.17329350113868716, 0.22185351639505357, 0.21328758087850389, 0.09503065593420498, 0.1441566186446336, 0.142643763533523, 0.21043909743668573, 0.23148109655707116, 0.8743855453306629, 16.8059225620762, 53.6995618574081, 63.7529339328889, 53.3544050493548, 39.73726941693214, 46.58816352967293, 52.14705244187386, 39.07379265754454, 12.940222794009795, 1.449845666366239, 0.32298128991838426, 2.35825912125649, 5.530808173841046, 13.971094239142634, 19.507507970256192, 20.163310612401656, 22.761253272333455, 16.732178080466486, 12.920716847142867, 22.43246647619432, 39.99756574630737, 52.244668468352295, 53.531135282208844, 50.749621775842485, 55.14629279413531, 57.44056555532641, 56.52347226296702, 54.880575749181936, 52.65665854177168, 51.17329266763503, 50.563317037397816, 52.66727639782814, 55.55216004771572, 53.337499633912124, 55.77147937590077, 54.92226269937331, 53.81658577149915, 54.19879721057031, 54.29660543318718, 54.17799688154652, 52.53381383034491, 50.2980314531634, 49.75827801612116, 54.40347433090211, 54.676161427651685, 53.949416837384625, 54.22430046143071, 52.20361301975866, 43.27837344138853, 41.06838457046017, 38.692934436182824, 40.576170259906405, 41.5333148740953, 39.700897278324256, 41.38885790301908, 39.24127001916209, 42.72828455894224, 48.80458116531373, 49.065234430374645, 54.35936727831441, 53.777087503863925, 52.67093596919891, 56.7458902635882, 53.35427953350929, 44.057042367996715, 50.616355326867875, 54.29249086687642, 57.83859591330252, 51.684652066999874, 47.11038789441509, 41.117629927973596, 42.09467272604666, 41.96424999544698, 42.609754454705026, 45.03175527818742, 41.55990069912326, 41.63283325010731, 43.071484104279556, 42.16215710486136, 39.54864263534546, 40.797136983563824, 45.67376490562193, 51.114688534890455, 52.96130118831512, 55.089865576836374, 55.546456921485166, 50.75185752684071, 54.666637912873306, 55.832942916500954, 55.98111829450054, 56.24958099857454, 55.103805680428785, 58.31180634037141, 55.89876421036259, 55.99741574256651, 53.3108510509614, 56.64336342965403, 54.385705994021514, 59.00984702571746, 57.972242832183845, 54.66546512419178, 58.57965323232836, 60.12057596637357, 60.819718837738044, 59.431615567976436, 62.61107706254529, 58.580343569478686, 58.48244513234785, 48.31494777433334, 30.68731611774814, 17.57293616571734, 9.550974311367158, 7.232757931755436, 9.462948479960042, 13.21287262824274, 11.64947961607287, 12.416788378069478, 10.128333472436475, 3.4504323092199143, 0.7392619766535298, 0.4813346056447875, 4.811905872437262, 24.728329758490286, 51.453977477165964, 54.98937837539181, 46.754119011663626, 55.38662425933346, 65.94396991114463, 40.283628125344556, 8.662273095500085, 0.39550352421018387, 0.13089543749247828, 0.19173910570961816, 0.15293759504152885, 0.11990597516658807, 0.22327568201768785, 0.13101090226442585, 0.07518767634586943, 0.14106502486092432, 0.1308876387174091, 0.2917268331493101, 0.11281482019131223, 0.09868648113502611, 0.2976208991341053, 0.1667533319203123, 0.16772612568832215, 0.12722113425092352, 0.17172888912741216, 0.13394888009755843, 0.1894650656369425, 0.2984711647995057], [0.020499497787245823, 0.07917533253109263, 0.019039768958464265, 0.05113359570743577, 0.06987717017651567, 0.03422732224627849, 0.04741400900867678, 0.044179172104885506, 0.044799017674860456, 0.09391402149753225, 0.07763940285170272, 0.03279540432436812, 0.027762605027566035, 0.06543955990984555, 0.01398233323162722, 0.005676361991302861, 0.08962374526045977, 0.044685253618104805, 0.05187507305714873, 0.033401820373030446, 0.02000065197447135, 0.09399484377354385, 0.02581973710367757, 0.05534046795219184, 0.07267254074254344, 6.90198298423521, 31.47014864029423, 53.66131482585784, 37.30907124857749, 30.267198893331713, 31.706353772071104, 39.61317739179058, 38.05498446187666, 11.373917421986981, 2.7995713631952963, 0.014650898163146792, 1.1213365004908655, 1.3186651828788942, 4.923393361030087, 1.7966791650941296, 3.4378505714478034, 4.43946554776161, 11.54394236303145, 15.988766358744716, 15.285527552327803, 28.5397635352227, 39.68254450828799, 50.68439668224704, 53.578250792718705, 53.52828371909357, 51.273034618746856, 51.05561764009538, 46.16532025798675, 45.253188763895345, 41.45351817530971, 41.927473852711344, 44.57356360650832, 45.04355769003592, 48.607301635126916, 49.388712298485544, 48.47893030412736, 49.56288514598724, 48.02302929662889, 47.27549614444856, 48.84647600112423, 53.26297067826795, 51.31525893365183, 49.174970580685525, 46.82187795639039, 49.58990635410432, 52.53111916203653, 51.43429894601145, 50.265762113755756, 41.937617101976954, 37.09133655794206, 37.41382206639936, 35.65479201655234, 37.58880684452672, 35.387043183849705, 37.539502651460715, 37.21520108561362, 38.359921286183024, 41.673123836517334, 44.22599454079905, 45.030868822528475, 47.14069997110675, 49.29961173765121, 48.86280875052176, 53.50221172455819, 38.78441979808193, 48.494215780688876, 55.3569358394992, 51.29594126055318, 47.474128892344815, 40.38057342652352, 37.1255749271762, 37.36219583019134, 39.413995512070194, 38.078165669595045, 38.79311569275395, 39.29974471369098, 39.125477729305146, 38.29210742827385, 37.757684492295795, 37.17250608628796, 38.226015490870324, 41.28752739198747, 42.942877431069654, 50.551761734870176, 50.0884945161881, 53.33143172725555, 52.33852686420564, 53.16908482582339, 52.96529416115054, 49.73697562371531, 49.21013462928034, 50.13059331524757, 51.364978897956114, 48.54688928973291, 50.2771330648853, 49.35866302059543, 50.04085340807515, 49.19581405578121, 48.6651958188703, 51.48778438568116, 53.99994873231458, 54.98586000934724, 49.956141979463645, 49.22742443699991, 53.588041028668805, 55.75253825033865, 56.444726759387606, 54.160146174892304, 39.46650035919682, 23.672739536531513, 11.096095942681837, 5.587702643486762, 4.04459098173726, 5.1718362877445845, 4.8409265087496856, 3.363289991694112, 5.903552972501324, 2.1734174268860973, 0.7229357849686378, 0.284777588301128, 0.08154871122490975, 4.462434947490692, 23.606767231418242, 38.55744008095034, 35.561278789274155, 32.65144494272048, 47.66821169084119, 49.228824723151426, 26.51550477550876, 3.425215146233959, 0.11749614600933368, 0.027592989330690716, 0.025349920277573892, 0.018422930283592116, 0.08536404359244532, 0.03490616041686266, 0.042305765373091546, 0.01308751093494075, 0.03816526698609514, 0.01104378945104057, 0.037978349193449945, 0.030497092671031435, 0.03832859310111211, 0.019952645074696313, 0.10132891756872978, 0.027478265748809905, 0.04139536946651436, 0.11370354347051152, 0.010906297736050142, 0.018067367810515628, 0.041975933878171834, 0.04972378325258052, 0.018271806033989115, 0.005266450846853156, 0.092760676127528, 0.033051361960749474, 0.0759361365870122, 0.061628536786884076, 0.014761210036193653, 0.06640058656733844, 0.03153677166049038, 0.017827634001150727, 0.11069105592586341, 0.014888485011103895, 0.023661159887729634, 0.02356133671597608, 0.09622828884711189, 0.05304473993037978, 0.06629911056088825, 0.03112603553510722, 0.03724120024050917, 0.06793461634867615, 0.01382498547524935, 0.04886358142680219, 0.00888516435459737, 0.34884340700603306, 9.08949863526129, 36.835809830696356, 60.18689932361726, 44.51185295658727, 31.809149288362075, 36.787403860399806, 44.657623921671224, 39.93948721116589, 13.67707827398854, 1.9670126250674649, 0.06491885760859137, 0.23282930405149538, 1.7049410554670519, 2.872940032712875, 5.773428832331012, 6.771162623359311, 7.857291929183468, 10.77868107826479, 12.318116253422154, 16.381534857134668, 31.742308178255637, 44.621502814754365, 52.779942558657744, 54.811796988210375, 56.65147489117038, 54.11729820312993, 52.80162934334048, 50.425775204935384, 47.7966889258354, 44.60017296575731, 44.611893007832194, 45.24226496296544, 49.117096008793006, 50.91464765610234, 52.66713911487211, 51.066870920119754, 51.62515363385601, 50.401154487363755, 50.531475236338956, 51.07380174821424, 55.34374883097988, 52.41999841505482, 48.90577439338931, 48.22010486356674, 51.60682439804078, 54.94663238525391, 53.728987478440814, 52.22589208233742, 43.883559857645345, 39.15499356485183, 39.9019971970589, 38.533890170435754, 38.77195058330413, 38.68020634497366, 39.00700253825034, 39.0556909191993, 39.45647478103638, 43.81190207696731, 44.94897365570069, 48.1347462438768, 50.07678231885357, 51.836373267635224, 51.07562957271453, 54.32441111533873, 43.4132049160619, 49.271362827670195, 55.300143841774236, 52.925560551304976, 50.64574564656904, 42.889533196726155, 40.103960037231445, 39.36515808105469, 40.913427414432654, 41.48541096718081, 40.78047083270165, 40.74721697838076, 40.87108935079267, 39.30282377427624, 39.248314595991566, 39.58035499818864, 39.642704994447776, 43.953232919016195, 44.80707799234698, 52.02883612725043, 52.07270783762778, 54.11665885679184, 52.53062102102464, 55.44662475585938, 55.20763081888999, 52.9611050698065, 51.37843262764716, 52.872632088199744, 53.52322386157129, 53.385348627644206, 52.11630890446325, 52.4802734774928, 51.73720398256856, 52.29311758472074, 51.54079914093018, 54.1244290721032, 57.50081708354335, 56.735629343217425, 53.05530078949467, 51.99050672592656, 53.81633866217829, 55.84425503207792, 56.81630465292162, 55.02946499855288, 43.37672687345936, 26.381593096640806, 13.696920564097743, 7.85896138798806, 5.740040146535443, 6.735271955690076, 7.690859879216841, 7.901735325013438, 8.54476280750767, 2.87568201461146, 1.4307600259780886, 0.2317659586908356, 0.12853990098641765, 5.1734096484799545, 23.986860590596354, 43.372765279585316, 41.98486989544284, 38.904785571559785, 54.350687073123076, 56.07618085799679, 30.68409389065158, 4.4190476498296185, 0.06943469311320974, 0.011607387888004944, 0.03894500276674667, 0.07185669540758095, 0.017668326017296603, 0.11542226172863476, 0.053545225171312216, 0.03187392695596622, 0.020994323553637634, 0.0272487860263115, 0.04140161308309725, 0.016051861344866695, 0.10286215061862623, 0.026560946322617032, 0.038504574988638206, 0.04118826525706438, 0.03101462336827911, 0.018762008459757895, 0.03042630423160811, 0.019585983902816812, 0.015314131122713369, 0.14345750212669373, 0.2576634383970692, 0.1308763465814052, 0.26206911811905526, 0.15720468945801258, 0.17021692267829375, 0.22607826147108312, 0.1963101838144564, 0.21102045091890523, 0.11782207045583956, 0.15608761069034377, 0.18004514126768037, 0.07328561792570738, 0.06714277254838137, 0.12900056497704598, 0.14948397874832153, 0.1550367219193328, 0.21755914924846542, 0.1093089720234275, 0.13342827738773438, 0.1758396096767918, 0.23469304275368494, 0.15392970954698904, 0.17157792384105344, 0.3495636215854076, 10.569189248546477, 41.528321696865945, 67.68782431079497, 50.62154854497602, 42.464724817583644, 42.80209964321506, 49.904445140592514, 46.52207943700975, 15.017049158773116, 3.2100363700620593, 0.17391642255167808, 1.5337156240017185, 4.940038429152581, 12.240757307698651, 9.080597796747762, 11.33715206576932, 10.737445200643233, 19.03910440783347, 21.77614215881594, 19.25108890379629, 34.59104130345006, 45.17902851104737, 53.49245678993964, 53.15570954353579, 58.85622347554853, 54.68948964149722, 54.07995723908948, 50.178995363173954, 49.69280581320486, 45.86832231090915, 47.89316746496385, 49.137657073236284, 49.91339991169591, 53.76213935113723, 53.881061692391675, 53.000991652088786, 54.144189973031324, 51.43353800619803, 52.31730684157341, 53.0480993178583, 58.74251396425309, 53.892134543388124, 48.94070309977378, 48.32309845955142, 53.455072679827296, 56.35001328683669, 57.02093862718152, 53.63345815289406, 45.02059221267701, 40.76658564229166, 42.949506236660866, 39.39665079116821, 41.58846339871807, 40.134727108863096, 40.165451034422844, 40.8409773149798, 42.50215991850823, 46.40054479722054, 48.325651922533595, 48.59919409598074, 53.09519129414713, 52.581674591187515, 52.138772318440104, 55.51218325091947, 46.171195968504875, 53.05512820520709, 57.70373698203795, 55.59303506728142, 51.95240874444285, 43.55889351137223, 42.6165872235452, 39.79423792131486, 42.99260916248445, 42.73621559143067, 43.01635126913748, 41.83387041091919, 44.750595861865634, 42.59440229785058, 40.808135309527, 42.73419164842175, 40.84382103335473, 47.16506573461717, 46.83777532269878, 55.32188161726921, 56.11827573468609, 55.969876781586684, 53.24449631475633, 57.57208262720416, 58.36327960414272, 55.2485764411188, 53.15767465099212, 55.283834626597745, 55.2146008706862, 53.01134278697353, 54.712976794089045, 53.60640948818576, 54.88865975410708, 53.651218645034305, 51.83629482023178, 56.26642365609446, 60.26851992453299, 57.855556241927616, 54.75479710486628, 54.08436598316316, 53.26897190463159, 55.49653299393193, 58.15331512881864, 56.80378052496142, 44.22528066942769, 28.7265879877152, 15.940299591710492, 9.72285649468822, 9.147450673964716, 11.711739397818043, 12.949205021704397, 10.746464690854474, 15.081126959093156, 7.4534907840913345, 4.271083589523069, 1.1403744595666085, 0.38762394218675555, 6.14850498976246, 29.779320763003444, 52.19247348846928, 47.12812092996413, 44.52627943408105, 60.98409360454929, 64.65168229995236, 36.93573221083611, 5.800289223271032, 0.2897702139471808, 0.09136379906727422, 0.2308592629889327, 0.16870785204152908, 0.1454271601452943, 0.22210764308129588, 0.16192558371732313, 0.11241203414336329, 0.0815466427875142, 0.13963450887991538, 0.1214930565366822, 0.10702455912025706, 0.2242057587230398, 0.1043064715040307, 0.2649310387430653, 0.12023511718237594, 0.13318482996715655, 0.14622145542694678, 0.10867350975111609, 0.10542357325433724, 0.14583370768495146], [0.015246618666776247, 0.018135917357980244, 0.04291254914395752, 0.01129409718898035, 0.039242739008078655, 0.051774160125322884, 0.031699310620165164, 0.02774529718613673, 0.011590259119627938, 0.018383271826971925, 0.014681478477864256, 0.012141988939425398, 0.009206182007948238, 0.015059383905252383, 0.05500537726367193, 0.09420640661471313, 0.028735446676071134, 0.05437381054845549, 0.03699418668064379, 0.040191182671415235, 0.038850892695688435, 0.10692921181720112, 0.060590721306300936, 0.04781058208355981, 0.042988062430653846, 3.702139628510322, 23.546349002468972, 44.67960880648705, 42.57656335830689, 37.33441368226082, 24.73931827852803, 37.24026503101472, 38.07489441287133, 17.653101567299135, 3.016582866830211, 0.3062733719425817, 0.02506552354222344, 0.7975809408291694, 1.4195594528029043, 4.43005774290331, 6.005948407034721, 7.710662945624321, 7.743909935797415, 8.15727872233237, 12.011503596459667, 30.08347507446043, 48.24852243546517, 56.053917484898726, 54.41681038948798, 49.370081040167044, 49.1407439785619, 45.505636430555775, 40.49414173249276, 41.276835010897734, 39.80605994501422, 38.47135190040835, 38.9908855192123, 39.36165932686099, 41.198728853656405, 41.86822645125851, 45.08046327098724, 42.75634519515499, 45.409220649350075, 43.858440999061834, 48.986418324132124, 50.223478963298184, 52.96382719470609, 48.966947678596746, 49.13876318162488, 47.263293650842485, 51.56797332148398, 52.23481939684961, 52.9110634711481, 43.36538337892102, 35.726473331451416, 37.057749302156516, 36.720084221132346, 36.38220733211887, 36.61410570144653, 37.91783094406128, 36.748795970793694, 36.961713990857525, 39.016404459553385, 43.85319286777128, 45.9824554381832, 47.325188652161636, 47.97636093631868, 47.7559825681871, 52.544074750715694, 39.296983365089666, 47.54166426197175, 53.451601382224794, 47.14196689667241, 48.3143594188075, 41.08572536899198, 41.571585439866595, 37.53218350871917, 37.908476091200306, 37.141029065655125, 37.63547912720711, 39.37736841940111, 38.62642280517086, 39.74314512745027, 37.7292473085465, 36.66475526748165, 40.1742842120509, 45.0969176138601, 48.15110252749536, 49.2897391319275, 50.83458423614503, 52.223899518289876, 52.87916675690682, 51.84418270664831, 50.043112693294404, 47.76467846285912, 44.56582084778817, 42.86696780112482, 44.60949251728673, 42.61224123739427, 41.65216269031648, 43.225845060040875, 42.36985445022583, 41.558806357845185, 46.696142458146625, 49.0117411459646, 51.63495171454645, 51.49653519353559, 54.18880693374142, 55.068218015855365, 55.956238700497536, 55.05930639082386, 54.980807996565304, 50.308817971137266, 40.45550638629545, 25.528534458529567, 15.026051978911124, 5.124126047857347, 3.6244467910259, 2.6597087133315305, 6.444383590452134, 4.560271607291314, 5.7723040926841005, 2.127947105515388, 0.44513575612537326, 0.045758029521112485, 0.39821185952713417, 4.7341816559914625, 25.783327702553045, 40.99710333731867, 33.363974863483065, 35.72312362732426, 45.421379996884255, 51.62540074317686, 18.211219541488155, 0.7717946051589905, 0.02322176824353876, 0.01648520664011519, 0.05284245441397352, 0.05046604967285549, 0.042510663249319604, 0.04189388586148139, 0.06747920772120838, 0.05794661097048272, 0.0355515435277935, 0.05550226189136025, 0.02243382191555875, 0.0742255695044033, 0.014595712061911343, 0.04937042902794577, 0.07945732183514104, 0.056522966798154585, 0.04591960512522248, 0.09527860029089837, 0.042296553165802074, 0.04010169211054041, 0.06375287944871573, 0.14664438192642507, 0.0728004467823813, 0.05075823177673644, 0.09202393703162672, 0.005102589427899089, 0.03601629076705825, 0.03907133066546052, 0.019895347443619565, 0.04327203973286575, 0.04726712697095448, 0.029283908173261635, 0.033000593314007405, 0.007533136954260691, 0.028352270563763958, 0.07894950513277324, 0.035774429148483666, 0.016240950996777224, 0.0631571273439594, 0.03274799497317403, 0.06893244587005147, 0.07893242137206179, 0.09315079874208859, 0.016810018343911055, 0.06457745818601501, 0.054727789134748524, 4.462732557327517, 27.832334656869214, 51.56234472028671, 47.59842488073534, 40.982990649438676, 27.024324440187026, 40.63127563845727, 42.77117959914669, 18.975487486008678, 3.8728666738156354, 0.23163184733881106, 0.11581206258626715, 0.9630772603615638, 2.419827585258792, 3.5300878026793083, 6.964785523952977, 8.476090931123304, 9.200200669227108, 8.954726976733054, 14.531294011300611, 31.72949379490268, 49.00753636513987, 57.1006529561935, 56.33029945435063, 51.91466377627466, 51.834106137675626, 47.93272849052183, 43.53317060778218, 42.8169418919471, 42.01136942832701, 39.63029461522257, 40.73124508703909, 40.766220861865634, 43.485117650801136, 45.687928584314164, 47.52487651763424, 45.46226678356048, 47.54062091150592, 46.64806988931472, 50.06624291020055, 52.25777702946817, 54.71637356665827, 50.089781053604625, 49.2356300354004, 48.056306685170824, 53.04125870427778, 54.29279288937969, 54.46442011863955, 44.577176109437026, 38.50128742956346, 39.48316651005899, 38.954846782069055, 39.43897708769768, 38.34279229564052, 38.77012275880383, 37.85571236764231, 38.52866165099606, 40.95392196409164, 45.12287585966049, 47.658437144371774, 47.79809705672726, 50.57751209505143, 50.667522645765736, 54.2078814198894, 42.62902113699144, 50.71748187465053, 55.96496989650112, 50.22527148646694, 50.32124011747299, 43.05994841360277, 45.05604651666457, 40.12022218396587, 39.517855951862956, 39.946731828874164, 40.11994761805381, 40.37192852266374, 39.302353089855565, 39.98539070929251, 39.85180654833394, 38.10134295494326, 41.689291846367624, 46.36890695941064, 50.285397498838364, 50.64591823085662, 51.83611046883368, 53.29350633005942, 52.385509014129646, 54.52939025817379, 52.767571403134255, 50.91937018978981, 46.6532003495001, 46.741838070654104, 47.414140162929414, 46.30725122267201, 45.165774822235115, 45.81324438894949, 46.10052662511026, 45.328604175198464, 49.38645693563646, 52.39347534794962, 52.21505065118113, 54.19989547421856, 54.72792494681574, 56.42584839174825, 56.23717061934933, 54.11576063402238, 55.17020748507593, 52.000085153887355, 44.718863887171594, 28.66856436575613, 15.986538452486839, 7.090714198927726, 5.466430802499095, 6.0721697826539325, 5.291893664867648, 7.02641184291532, 9.115733408158826, 4.3210114394464805, 0.5800365464341256, 0.16837193780849058, 0.16234587487434188, 5.658970638628929, 28.508363000808227, 48.90415053213797, 40.58318738014468, 38.55598095924624, 51.33932659702917, 57.82748776097452, 24.5577831422129, 1.83592836222341, 0.1484319714889411, 0.04075935178045784, 0.0664305023007816, 0.0452992539372175, 0.033239229702420776, 0.02650000594346033, 0.023713374525428783, 0.03030656085860345, 0.071883263336795, 0.06265414465639381, 0.021741535071463838, 0.024862839660096555, 0.04123669350519776, 0.04805596387614647, 0.05426694894389761, 0.09679861832410099, 0.045399117328587084, 0.016240240450227456, 0.09593322242219603, 0.0634671631269157, 0.01700111131574358, 0.2157804616276295, 0.21026669701020564, 0.18091184717993583, 0.2621497105686896, 0.10826022063772525, 0.07101542361441159, 0.14833233409350918, 0.18049773069158678, 0.12726602700328635, 0.07891435701880725, 0.07564279385992596, 0.12547453805323572, 0.14497097010814375, 0.18680531561615007, 0.16133882165435823, 0.1563586679197127, 0.0890905557260398, 0.11947983875870706, 0.11897002256685689, 0.1259768082790317, 0.18162291466949448, 0.18177213327538583, 0.17535904272189065, 0.17877562632483823, 0.2722279342912859, 5.155747215594015, 32.77101643623845, 57.10838002543296, 55.379199212597264, 47.70676074489471, 34.20997127409905, 48.056769524851155, 48.695747160142474, 23.224118448072865, 4.807937904711693, 0.5554245316213178, 0.2603677287697792, 3.124910641101099, 6.485419427194904, 11.14394199463629, 16.90271685200353, 15.936860653661913, 12.733598216887444, 12.306687447332568, 17.802290877988263, 35.18349570612754, 50.865731777683386, 60.93672313997823, 57.17775890904089, 54.27305944504277, 53.979183704622336, 51.61480642134144, 45.11021837111443, 45.57653327142039, 44.36039847712363, 40.79350094641409, 42.94752936209402, 43.39422456679806, 45.169822708252944, 46.6360007562945, 47.57609874971452, 46.248819674215014, 49.03062343597413, 49.034228094162486, 51.82738319520028, 55.590728713620095, 55.70011577298565, 51.05948509708528, 49.533671332943825, 47.45338347650344, 54.62109135043237, 55.32641195481824, 57.44740616890692, 46.810832561985144, 40.07207116773052, 40.48711284514397, 40.8944352980583, 40.675971046570815, 40.28686800310689, 41.820220562719534, 40.26443596809141, 40.1665492980711, 43.234454662569114, 48.94544524531211, 50.24765645304034, 49.80128288269044, 51.404610526177194, 53.40705110180763, 55.61364712253694, 46.86607130112187, 52.33779338098342, 57.30029767559421, 52.72738279834871, 52.095253621378255, 45.874001902918664, 46.393939525850364, 40.633130919548776, 43.164087341677764, 40.027509120202836, 41.351626765343454, 41.132448642484604, 40.71390428850728, 43.117073812792384, 40.21909336889944, 39.29471231275989, 44.076740511002086, 48.47734958894792, 52.0564692251144, 53.511786230148815, 53.86445045471192, 54.84439188434232, 54.82774142296084, 54.626453230457926, 54.2109840146957, 53.20719849678778, 47.640484456093084, 46.81793205199703, 47.69004752559047, 46.39928571639523, 45.54885702748453, 46.923702686063706, 48.00206815042804, 46.36408244409869, 51.32473145761798, 53.697647740764005, 55.31295430275702, 57.01027762505316, 57.49106999366515, 56.6583586508228, 59.995507271059104, 57.11512257975917, 56.48230306563839, 53.97581438864432, 47.10971324674545, 31.096013361407866, 16.488020343165246, 7.796987939265467, 9.536276209738947, 10.015637893830577, 14.65051837505833, 13.837352202784631, 12.600243514583958, 6.948492978849719, 2.184305436188175, 0.4294395032188585, 0.5926280288446335, 6.8580715598598605, 33.72695099922919, 52.061360420719275, 46.17182354773245, 50.03547191619874, 60.22943350576586, 67.13828456017279, 28.658954558833955, 2.836164870569783, 0.37297168325993324, 0.14858548018720844, 0.23754949350991558, 0.07588982657198945, 0.11448374273435724, 0.1591294547242503, 0.12427805427221522, 0.17448708144647462, 0.3060546691619581, 0.15932195729786353, 0.13062053450172947, 0.1647618097523528, 0.11244734313579337, 0.1644393939885401, 0.19271436628074418, 0.20626201835130492, 0.30888683493098906, 0.2587023149094274, 0.180331933943014, 0.1432667309117894, 0.17573022764296303], [0.016395811840230902, 0.09495036225886115, 0.04735701589754993, 0.01947959344233236, 0.024061507860859557, 0.016213117107268304, 0.03332489748455344, 0.02064308564689371, 0.08061524841093248, 0.031204053929315943, 0.06230377434422413, 0.0350233948519153, 0.08640501918571611, 0.08534020293624171, 0.026209015106301636, 0.10057842719458765, 0.022339332630978, 0.08487867326625893, 0.07500240564226143, 0.037480192859807325, 0.0447535120521582, 0.04285030450010973, 0.07259330426853511, 0.028717587251336347, 0.06348535388467774, 1.6769387645106164, 19.068014237188525, 37.99125771368704, 45.648347946905325, 37.112525201612904, 33.42459901686638, 37.97442682327763, 39.53838955971503, 25.895844813316103, 8.65145617915738, 0.4205165707295941, 0.07250823786542301, 0.45069314178920566, 0.8975465283278496, 2.1707458025024784, 4.770474366603359, 6.569767055972931, 8.888914508204307, 7.429521670264583, 18.347580740528723, 37.408201309942434, 47.80290196018834, 53.442172004330544, 51.78912047416934, 50.29761175955496, 46.582150536198775, 43.63449327407345, 41.31737270662862, 42.65774073139314, 44.43699059947845, 42.14360821631647, 41.100657832237985, 37.30017139065651, 36.09282662791591, 38.97545099258423, 39.384342393567486, 40.6986423461668, 42.124208173444195, 44.125381823508974, 47.456152669845096, 50.34948902745401, 53.589680579400834, 50.23282204904864, 50.11500581618279, 49.94006810649749, 53.346113158810525, 51.59868547993322, 50.37453728337442, 40.70165472645914, 36.81360529315087, 35.63281889884703, 37.488103912722686, 37.20513236138129, 38.07855006187193, 36.89918748794064, 37.56397824133597, 36.49217097989975, 38.50970091358308, 42.03296992086595, 43.943175961894376, 46.312283623603086, 49.338792293302475, 48.17797076317572, 52.30143300948605, 38.51365858508695, 47.71160487205752, 53.63211670229512, 50.583532933265936, 49.61360531468546, 43.61017065663492, 38.24617255118586, 37.2652466066422, 36.10600971406506, 37.497643116981756, 37.69158863252209, 37.12443743982623, 38.12687758476504, 37.19011360599149, 36.456732365392874, 38.26164630151565, 43.52943258900797, 46.62351977440619, 49.02475557019634, 51.038861274719245, 53.365721087301935, 53.3484548138034, 52.11820340925648, 51.71186939362557, 53.05019386353032, 49.08205355367353, 41.067141179115545, 38.71680205868137, 37.41535571313674, 37.681261031858384, 36.037215263612815, 38.64004911914949, 41.72244371906404, 40.23673226756435, 39.46455486359135, 44.53889769892539, 47.94376604018673, 49.829261149129565, 52.57554000423801, 52.37536184249386, 53.60482877300632, 55.18502227721676, 56.99204252612207, 51.952800981460086, 42.79753008196431, 27.00422621542408, 14.799423313909962, 7.364973675820136, 3.7530375296069733, 6.013174883780941, 4.6443794811925585, 6.853205859661103, 8.649472440442732, 2.246768936034172, 0.5505876976155466, 0.23849414120758736, 0.21835332195605003, 6.432900361476406, 24.00127333979453, 37.06884960974417, 30.14784509135831, 36.60400167588265, 55.84018361183905, 45.073567744224306, 12.158075705651315, 0.7382677171018817, 0.03506834889131208, 0.02038018150825895, 0.0241883892580987, 0.08256287374083074, 0.023820042692785783, 0.05512872891079995, 0.04987286779308512, 0.004084579714183366, 0.029687688220292333, 0.04634702856081628, 0.05630150227056396, 0.06997554352687252, 0.06445557359726199, 0.02969830236848324, 0.023349235698039976, 0.08123278422581573, 0.03421956560604515, 0.0762612949455938, 0.0402350603572784, 0.02728857471787882, 0.03287193650800375, 0.03767094875295316, 0.07552148383711615, 0.06576929181333512, 0.07070930254074835, 0.03169631521638123, 0.0286460614522859, 0.04378551399455436, 0.002538905396396595, 0.06378900432478517, 0.0721963404888107, 0.021596221598766504, 0.0018161849913022091, 0.0692442589769921, 0.010350009693103212, 0.023487978051566792, 0.12668282724916935, 0.08973384741693737, 0.045434288425190796, 0.02969940361987439, 0.047928069327627464, 0.022892710497422565, 0.05791905095740672, 0.07326141720817936, 0.08600359677427238, 0.02276390047383405, 2.2167777582522366, 22.897483071973248, 45.76370485367314, 52.365473547289454, 42.147561965450166, 33.34042103059831, 39.695441261414565, 41.63278225929507, 28.167144252407937, 8.266102921578193, 0.4544963393240206, 0.0300166157314614, 0.6111603698903515, 1.5559244516395754, 3.355428581276248, 6.839188289257788, 10.862400147222704, 7.635458361717963, 4.797769650336235, 17.912999776101884, 38.18040224813646, 50.726032641626176, 56.577620583195845, 53.19374476709674, 52.85154542615337, 47.842404150193744, 45.52979823081724, 42.484693604130904, 45.186206448462706, 44.56799384086363, 43.50476480299427, 42.01912003178751, 40.566364334475615, 38.78341959368798, 41.77925532863986, 41.5263448222991, 42.49914753821589, 42.89867231922765, 46.35737519110403, 49.4391579012717, 52.063035272782855, 54.76001777956563, 51.293948696505645, 48.966198505893836, 49.41468231139645, 54.129657591542895, 54.09736864028439, 51.58486696981615, 42.44306941186228, 38.712024611811486, 37.068861376854684, 37.81241332331012, 39.17587234127907, 38.615879474147675, 38.1249556233806, 39.461056109397646, 38.78793424175632, 40.21457087609076, 43.434432783434474, 45.386439523389264, 48.150773048400886, 50.6786504099446, 51.64294942732781, 53.882932662963874, 41.92635597721223, 49.084061807201756, 56.68392073723578, 51.619972182858376, 50.604749033527995, 44.28214719218593, 40.858463241207986, 38.86500489327216, 38.06681825268654, 38.59317679559031, 38.27901455663866, 40.11532706599082, 39.871818480953095, 40.29114338659471, 38.488873127968084, 38.76664361646099, 45.901736982407115, 49.098790307198804, 52.68021629702661, 53.07939590946321, 55.88032122581236, 53.141620389876834, 52.52737329852197, 53.31769950928227, 52.47441345645536, 49.747946493087284, 43.94863590117424, 41.83159543621925, 39.951936814092825, 39.99864047573459, 37.95053958892822, 40.31850584091679, 42.786202276906664, 41.60433330843526, 44.177812145602324, 47.88666417521816, 50.53555450131817, 53.90758475949688, 54.84312888114683, 54.268180016548406, 56.80506706237794, 57.07963297444006, 58.4220955448766, 52.308583490310184, 43.913973915961485, 28.644918357172322, 15.313667616536542, 4.606638925690805, 6.3071859459723205, 6.742107176011609, 4.594263357500877, 6.728396040778007, 7.764126812258075, 6.098961041819665, 1.0897105523655493, 0.12510489296889113, 0.5068774479291132, 6.560574000881565, 28.14848553749823, 40.730064453617224, 34.031766230060214, 42.37455737206244, 62.62733920927971, 52.1945248880694, 15.692010618025257, 0.7973810838114831, 0.024643546991771268, 0.10215721949334107, 0.09662902177942377, 0.017411577395133434, 0.1289074086854535, 0.05356039371221297, 0.037060644808075124, 0.0537192918390276, 0.02894818929264382, 0.03657573030420369, 0.030151895367570465, 0.0587601465503535, 0.04287675368569551, 0.0020494357816078852, 0.02717064314281508, 0.07016989237238323, 0.034043491787968144, 0.07941010017548839, 0.04725100082014838, 0.016320386653645866, 0.03595059106667196, 0.14926984185172668, 0.16870501751620925, 0.13386116303022833, 0.1401525681778308, 0.0841310097565574, 0.09635298497854702, 0.08302971240012877, 0.11836351075720404, 0.14392780350340953, 0.12863042193555063, 0.14630272203395445, 0.1279304014338601, 0.22428213768909055, 0.16114126290044478, 0.15857807060162868, 0.21677153425351267, 0.3037789896611245, 0.1738445328608636, 0.15311206390540447, 0.1548950875838918, 0.15726511847347985, 0.08367445965808246, 0.15487400484421562, 0.19020080115766297, 0.1472804953734721, 2.5686810430019134, 25.33554796249636, 51.45744485239829, 59.175590699718846, 49.22680078014251, 45.12475075260286, 48.39212040747366, 51.320930680921, 33.729469160879816, 11.107901296307965, 0.6537956756449516, 0.19052105655352916, 1.4823127177453812, 4.080200709642903, 8.33841573807501, 12.324495988507426, 14.109021444474498, 19.043481772945775, 11.838221126987088, 21.444907803689283, 41.38679081393827, 51.815298372699374, 57.95248585362589, 56.57258033752442, 55.36449816919143, 49.36516238797096, 47.90744881476126, 45.29566803286153, 47.33334718212005, 48.69837514815792, 45.95487725350165, 44.42341527631206, 41.40169974296324, 40.02821906920403, 43.00600797899308, 43.912083333538426, 43.456664777571156, 45.463969092215265, 48.38797053983135, 52.50327425618326, 53.151873465507265, 57.08198639654345, 52.388454714129054, 50.56643924405498, 49.343177503155125, 55.3670241755824, 56.74601185706354, 53.70883041812528, 44.281817713091456, 41.79139506432318, 39.439930223649554, 40.61948891608946, 42.19023343055479, 40.01636566654329, 40.456137887893185, 41.221764933678415, 41.05990440614762, 42.66396945522678, 45.50320456104894, 47.992744676528446, 51.40990572590982, 53.68566097751741, 52.90414441016413, 56.809436582749896, 45.01774064956173, 51.166122574960035, 57.98799899316604, 55.120691484020604, 54.69012114309496, 47.34910334310224, 42.40168840654435, 41.86820291703747, 39.08899184196226, 41.62996207514117, 41.54931422202818, 41.53144390352311, 43.19410131823632, 41.09879078403596, 39.950312952841486, 40.75221800035046, 47.622833790317664, 50.6633060978305, 54.031868980776885, 54.945792998037035, 57.19455057574857, 55.57347812960225, 52.92399944797639, 54.85837121163645, 56.63049413311867, 53.476716318438136, 45.083942413330085, 42.751010771720644, 41.1254785906884, 42.0773946854376, 39.343518364814024, 42.387689467399355, 45.33242064137613, 43.95864186748382, 46.10784184548163, 48.736378992757494, 52.686056706213186, 55.602491901766875, 57.5019153471916, 56.16810160298502, 57.95542370888495, 58.208769598314845, 59.89382766908216, 53.89411534032514, 48.64227348758329, 31.841085226305072, 21.440469641839307, 10.759676214187376, 7.115529073822883, 13.023134835304754, 10.5772408939177, 15.02170697335274, 16.950340309450706, 7.285323085323458, 2.4219441942630278, 0.625275876973906, 0.5030505323121625, 8.270998039553243, 32.22047059766708, 48.44614713422714, 42.7143209211288, 51.598614877270116, 70.53922268652147, 59.52533275850358, 18.693096445452785, 1.5971638839091025, 0.18790532594486592, 0.22678578963443158, 0.15703768229051945, 0.1474331920185397, 0.24107791062804962, 0.17380987504316917, 0.1572490612705869, 0.15478035825635159, 0.15013660905101608, 0.1481817824946296, 0.23425692422015054, 0.2892086102116493, 0.29265615908849624, 0.13439691895919462, 0.12842826665409152, 0.24935496971011165, 0.10499472489520427, 0.15142781960387386, 0.0785606082588915, 0.07478750265774227, 0.17116311787357255], [0.05532176774596015, 0.0558503186179986, 0.042959008546125506, 0.04465914917208495, 0.020350811612461845, 0.009683443293456108, 0.04612664804763852, 0.022540796518085465, 0.017765833688299024, 0.026338091345443845, 0.040698750395207636, 0.02246760064736009, 0.08153535065151031, 0.01860725869905324, 0.06843244326451133, 0.03030899893342247, 0.024200043370646816, 0.08964473606958505, 0.034374637123678005, 0.04545899859118847, 0.01170367460637804, 0.040007582039482174, 0.028304301968385136, 0.04282729121886435, 0.07941805216814242, 0.8443700978832861, 9.761909573308884, 31.70412586581323, 51.76389571159117, 45.2581113384616, 36.48785245034003, 35.85469561238443, 44.31496958578787, 34.15348522124752, 11.070953549877292, 1.357717893777355, 0.17839365488579198, 0.34261333485764844, 1.1586251254043272, 1.0316113022065934, 2.9177268810810584, 7.186798539853866, 4.258098583067618, 4.443090308097101, 16.000479536671794, 35.59193603454098, 49.31670934923234, 52.21238736183413, 53.412734616187315, 47.18858426617038, 45.197012578287435, 44.857382389806936, 45.57001821456417, 48.622132116748446, 50.862703707910356, 52.44765504713982, 51.67107674383348, 45.11775716658562, 37.37007194949735, 36.659420844047304, 39.65732366808, 38.97498423053373, 41.8225622177124, 47.40721325720511, 49.25256290743428, 50.6636316545548, 51.39838572471373, 50.50085329240369, 49.89838900104646, 50.52623887215891, 52.366630646490286, 49.91555721529069, 46.593278300377634, 38.25412319552514, 35.62503691642515, 37.72478757366058, 38.76305857012349, 36.72772107585784, 37.243881456313595, 37.297378663093816, 36.67860907893027, 38.24322685118645, 36.54494647056826, 39.72072093717514, 43.895393648455226, 45.52897453308106, 47.662430117207194, 49.501935435879616, 49.57062398233722, 33.39634618451519, 47.051619022123276, 52.07174685693557, 49.71750890055011, 49.231429176945845, 46.91197872161866, 46.45751722397343, 41.65230781801286, 37.16213141718219, 35.84940433502197, 35.978791559896166, 37.191659019839385, 37.109202954076956, 36.91690875637916, 37.31737882860246, 37.807227949942316, 46.24548958193871, 49.552243755709746, 50.46375159294375, 49.46726560592652, 54.63728289450369, 49.386641287034564, 49.85055177442489, 53.38583500154557, 51.30227981075164, 48.90375045038039, 42.806920236156834, 37.63929559338478, 37.35233499157814, 39.97956598958662, 45.14184051944364, 46.345039336912095, 47.79253513582292, 45.65823624210973, 43.732772181111, 42.75572938303794, 45.0045693305231, 45.08147132012152, 49.78618175752702, 51.000088645565896, 52.384206787232436, 55.44661691111904, 55.817747654453406, 53.28798363285681, 41.89061926257226, 28.661929676609656, 15.550796466488993, 4.266337521614568, 5.637074497438246, 3.886063733408528, 1.7413161358525677, 2.657895107423106, 6.765149629885151, 5.438855069298898, 0.4334010970928977, 0.14886065896960998, 0.6904887131625607, 7.426408288940308, 29.082597994035293, 48.7407563578698, 41.339891033787886, 35.213521449796616, 57.28967197479741, 34.205358566776404, 11.194647454446363, 0.48185667924342623, 0.20853279488942317, 0.024982136786885323, 0.06086665085486828, 0.03197686427513198, 0.07165925922773539, 0.035121090214459166, 0.12834100923951597, 0.05128523132072822, 0.03221777402946065, 0.04848029997740542, 0.023488320875912908, 0.045921282857776656, 0.11891626617721013, 0.04590958852561251, 0.011150243113778774, 0.06975520131809097, 0.06121150916442276, 0.047177778136345654, 0.06338169452764335, 0.016733135675050078, 0.027232826499628927, 0.03231782128193206, 0.08166305750848786, 0.040489068299892454, 0.06441410525792068, 0.05017209790586945, 0.06186348446194203, 0.024763983674347404, 0.024518460155494755, 0.010224727504406004, 0.07368427475974446, 0.03534289948161572, 0.025729018886904084, 0.07551194604245887, 0.03626671341818668, 0.06205776435953956, 0.06651533887751641, 0.047642594323523586, 0.03895704183847674, 0.0238797688225825, 0.021766182035207752, 0.023594977551951044, 0.04570762476613445, 0.02863620764635984, 0.06765061989426613, 0.05071211328369476, 1.0584343080559084, 12.76924373642091, 37.6788213176112, 55.302050113677986, 50.11805349780668, 39.53107433934366, 38.586744108507716, 47.27713961755076, 35.260927215699226, 13.039788238463863, 1.282326997287812, 0.1835856012879841, 0.5239721483761265, 1.4950014626787556, 3.5199791193008427, 7.728156226296579, 11.709698784735895, 6.151574244422298, 4.9443902988587665, 18.01083153293979, 37.64120186528852, 51.88503026962281, 54.46128614487187, 54.33850419136786, 49.72272565287929, 46.53712172662058, 46.07887514175908, 47.81168022463399, 49.886060991594874, 52.470769574565274, 52.91633513665969, 51.53804171469904, 45.681205641838815, 40.070706182910556, 40.23974072548651, 40.16660813362368, 42.470926084826075, 43.21151664180141, 48.801949254928104, 50.93886829191639, 52.95996366008636, 53.65009684716502, 50.93416929244996, 48.220803045457416, 50.42532413236557, 53.524675138535045, 52.730340265458636, 48.87710971217002, 39.98378645989203, 38.40748002452236, 40.17442541737711, 39.89441525551581, 39.15324811012515, 38.149639098874985, 39.08804262838056, 39.15014159294867, 38.79316668356619, 37.977360756166526, 41.741404456477014, 46.754566161863266, 47.87028043500839, 51.696344652483546, 51.79739275286275, 52.37507158710111, 36.93685793107556, 49.63195023998138, 53.752105928236446, 53.28888970036661, 50.41884829921108, 50.15541799606816, 46.44047844794489, 41.70912334995885, 39.33609331807783, 39.402436287172385, 38.7202262878418, 38.39533244409869, 38.45767067324731, 38.22748637968494, 38.50479795086769, 40.604587831804835, 48.25801849365235, 51.060897150347316, 53.56220045397359, 53.58572290789697, 55.73170654235348, 51.23907081542477, 52.6680608718626, 54.83393092309275, 54.234859481934585, 50.81207767609627, 45.759684424246515, 41.55544488660751, 37.74223427618704, 43.09500655820293, 47.20182618787212, 47.420627763194425, 47.810385842477125, 46.993536564611624, 45.558262871157744, 44.86889454626268, 47.62419485276746, 47.96549204857119, 51.941610459358465, 52.2168117953885, 53.205962950183505, 57.06506921399025, 58.3230007848432, 56.486182289738814, 44.88012429206602, 29.909753299528557, 15.67846961559788, 5.512642696980508, 4.7116839212756005, 6.4274850391572524, 6.566539925913657, 4.5777894027771495, 7.136231833888639, 4.525490970380845, 0.8319133243733837, 0.15751455670162556, 0.43634814540705374, 8.482536365908961, 33.393698584648874, 48.70211708930231, 41.7089468433011, 41.61334691509124, 66.39422662796514, 42.049808656015706, 13.940168311519008, 0.742529372294103, 0.12971612174184094, 0.06622206509834336, 0.10885980701254261, 0.03466521044291797, 0.01826782620722248, 0.011047707990773264, 0.019042940562470786, 0.04078716460254885, 0.02383410040619633, 0.01899640072107075, 0.018851868658056183, 0.02121325807585832, 0.07086409826672847, 0.04822362221837525, 0.008167631082957792, 0.06043162016618637, 0.02395207220087609, 0.03334306142923813, 0.03354291844692442, 0.017297704170848575, 0.027976638502291137, 0.1759135984485188, 0.13588017243291103, 0.13656764441440183, 0.17095730069183535, 0.23368652579524826, 0.23748535662889483, 0.139649799994884, 0.11886381979791388, 0.12124620002484131, 0.18371228158714312, 0.11737206274823797, 0.09137794871123568, 0.14860504607279457, 0.17537171381615824, 0.2569801645774034, 0.3108003387047399, 0.108597467863752, 0.18899634240135071, 0.08835754747832976, 0.1322423732809482, 0.1640394041615148, 0.18131536101141285, 0.16808980294773657, 0.18448866573312592, 0.15498257482484465, 1.2320067877731016, 14.53023595194663, 42.586636004909394, 63.887349636324, 57.50994443893433, 48.086485401276626, 48.14938060698971, 55.73319704301896, 42.3816764739252, 15.514860691562777, 2.0011160402528705, 0.5065126675030878, 1.5126142530672013, 3.8644627505733125, 7.209279114200223, 12.245976021212917, 15.273069124067984, 9.809266309584341, 7.01131905278852, 18.173133327114968, 39.37543861327633, 53.13463857097011, 58.04426147091774, 58.00761868876796, 53.31181203165362, 48.82144343468451, 49.516624712174945, 49.71727355833977, 52.76326464068506, 56.04133844375611, 56.92577408206079, 54.81833557928763, 49.77211221571892, 42.195395269701564, 42.34836378405171, 43.13519516298848, 43.18356583195348, 46.97049656221944, 51.688770555680804, 53.19693365404683, 54.21646748819659, 54.71083910234513, 51.59191154664563, 48.91493312774166, 51.94001405469833, 55.50843738740491, 54.91415908259731, 50.11428410007108, 41.3922272189971, 40.28438122041764, 42.32351164663992, 41.80692372783538, 41.15570829760644, 39.54200206264373, 41.562924846526116, 41.79211678043489, 41.38586121220743, 38.62300642075078, 44.28817979751095, 49.10430908203126, 50.695779400487105, 51.806045501462876, 54.799833759184814, 52.70271501233501, 42.281561897647, 51.65447335089407, 55.19727968400525, 55.94637393951417, 53.50730296104185, 51.49084775678573, 50.93222379684449, 45.763736232634514, 41.254316683738466, 40.00048791208575, 40.645164751237445, 41.355372628858014, 40.44130740627166, 40.85681192336544, 40.4254335741843, 42.751846236567346, 51.020571262605735, 54.097533379831624, 55.581118906697924, 54.22324534385435, 54.834652639204464, 50.24018826023225, 51.716682141827, 56.875728561032204, 55.6802725022839, 52.287759627065356, 47.82675781557637, 43.562866872356786, 41.122603493352095, 46.04142827372397, 50.92062142587478, 50.67094687492617, 51.33445109090498, 50.470717722369784, 49.85848672928349, 47.69308736247402, 49.53033731829736, 48.7790112341604, 54.342579533976895, 56.091536937221406, 56.036623754808986, 60.11046017369917, 60.305233309345866, 59.3858415080655, 46.4038238986846, 34.708626116475756, 19.980853719096032, 7.491402943288127, 12.429388992248043, 12.759545676169857, 10.82757636424034, 9.930136107629346, 16.230139213223612, 11.700952879844174, 2.020001149465961, 0.3678928267571234, 0.9896293775208536, 9.745423851474639, 38.7584105614693, 59.796599957250784, 55.18671281876103, 50.65501028491605, 74.20324986980808, 50.351658098159305, 16.72489816142667, 1.1383951335184037, 0.34889939271153947, 0.14356021919558126, 0.35832138551819714, 0.11065074437928778, 0.17431366978393448, 0.09473184333933939, 0.21796007370275838, 0.20434583326981914, 0.1698403598199929, 0.2098711045278657, 0.08723933490053301, 0.09336435341186101, 0.17834398174478164, 0.20713183458053297, 0.21154325996195117, 0.1982165476487529, 0.11387027484635193, 0.10253105507863146, 0.08126691344284243, 0.1477695352608158, 0.162058791085597], [0.012973306377628639, 0.03362724174474997, 0.05203216704690168, 0.04369297057330128, 0.0376742122875106, 0.024855439250748006, 0.027306625664594675, 0.07902773037072151, 0.02642198371881199, 0.042262278392069766, 0.006141727367761515, 0.01588103810190073, 0.03389609264089696, 0.09918997710150096, 0.03143125070979999, 0.05468682641343725, 0.004173507200433843, 0.043583354882655606, 0.028948608725782365, 0.04307159665791739, 0.031311955498231035, 0.046841434894069556, 0.0470495350178211, 0.07965959202978881, 0.043086094871884396, 0.31517886827068947, 5.900957344039794, 24.21015524095105, 44.98861312866212, 44.38093600734588, 44.918285031472486, 33.53158950805664, 34.77427874841998, 39.71622197858749, 16.866976214993386, 2.1083769298368886, 0.0903973408463982, 0.4737946150764343, 0.6584782501862896, 2.751148722825512, 6.301151379462212, 13.099068980063162, 2.593893057877018, 4.587788014642654, 17.670891477215676, 35.345450370542466, 46.07689826719223, 53.35196533510762, 50.88818342454972, 49.719795642360566, 50.72841744269095, 49.92795190503521, 50.64673016148229, 50.930293990719704, 52.421724257930634, 53.89574312394666, 51.715407371521, 50.79081450739215, 41.378475389172955, 37.62810114891299, 38.539914931020434, 40.38718262026387, 46.50021614566926, 49.66629843558035, 49.84944958840647, 51.94784702793245, 51.8311918166376, 49.01673824556413, 51.76512341345511, 52.86829394678916, 48.201552052651685, 48.25335087314729, 41.90289628121161, 36.13494896119641, 37.38337270675167, 37.40823268890381, 36.772718506474654, 37.321642444979766, 36.093160029380556, 36.18864620885542, 36.677146034856, 36.501227732627626, 37.377571521266816, 36.97663860936319, 42.69130445295765, 45.375021503817656, 48.69090303297966, 46.3550139242603, 52.01221312246015, 36.95402222294962, 44.981184159555745, 52.15801154413531, 54.5121749754875, 52.90663903759372, 47.40185529954972, 50.30371496754308, 48.658166931521514, 45.36002236027872, 35.62850429165748, 37.81300167883597, 39.37648980848251, 37.095674699352635, 36.05370098544706, 36.4492327936234, 39.38946108664236, 49.1554646338186, 49.73843082304924, 49.73406130267728, 49.735591027044485, 53.09555215220298, 48.3326925769929, 52.506600426089385, 52.37975881945703, 51.70410702305456, 48.63010237293859, 42.188354615242254, 37.253914879214385, 40.351983270337506, 48.32314552799348, 51.31372528691446, 51.62062721867716, 52.109978199005134, 49.87692579146355, 50.41711461159491, 47.04734363863545, 46.99212451134959, 47.74427429322274, 47.745097990958925, 48.44267191425447, 52.00860061953145, 52.86854105611002, 56.766153227898386, 53.337609460276944, 44.674647008219075, 24.119868163139593, 12.9132241395212, 2.2598669557802142, 5.870794317414684, 4.986513612731811, 4.678938994484564, 3.2534670589431642, 4.261222260613596, 3.8079043790217373, 0.8648122041936844, 0.1345564337867883, 1.0657523476308393, 10.705171938865416, 33.776094375118134, 38.235833183411636, 41.8836295989252, 48.58875666895221, 50.00551677519276, 35.22569256444132, 7.937380844546904, 0.2116869780565462, 0.01509480014999187, 0.024629029625606154, 0.010121455021773376, 0.017076218575840036, 0.05564664265200977, 0.016708551913559917, 0.02939080425177611, 0.01911595257209434, 0.07507522996034353, 0.019534286374466556, 0.018960001968568372, 0.055751520088843765, 0.06282182215082069, 0.010709337488327537, 0.05149974743084562, 0.0162575731895143, 0.06698557896719826, 0.039093003292838414, 0.055171039946857965, 0.026719453744590286, 0.05395287204714072, 0.064570011811391, 0.02214289619587362, 0.023144324415273244, 0.04381976195520932, 0.07473460428657071, 0.05353431224883084, 0.056866725771537716, 0.048760423857358196, 0.042498988069353566, 0.030691818814844857, 0.03824030146783879, 0.03098936736463539, 0.05174025690423385, 0.05177583785787706, 0.018804516763456406, 0.01682073208353212, 0.06403234449305362, 0.044729230895398125, 0.08440874727262605, 0.024469652693838845, 0.039058494862289204, 0.04650854670833196, 0.03004837007592282, 0.051706560526884375, 0.036095615341177875, 0.2615023356291556, 7.840242856933226, 30.001256312093428, 53.16008298627792, 48.79267284947057, 49.053839945024066, 38.51202295672509, 41.26010217974263, 42.33722425276234, 19.6599018573761, 2.1555914801936, 0.0778503375007741, 0.06792010664339028, 2.0035335685937636, 4.134759162702869, 7.085030194251769, 10.869720270556789, 4.504342040707988, 4.572730035551133, 19.381974474076305, 36.32577227007958, 48.604434382530954, 54.09236761831469, 52.3063987301242, 52.72093442178542, 52.61545796548167, 51.238325565092026, 52.4557194402141, 52.86111600937382, 55.38947582244874, 56.680433750152595, 53.77856231504872, 52.82456344173801, 42.93079260856875, 38.3847616564843, 40.89323897515574, 41.890070130748136, 47.64948237326838, 49.784581430496715, 51.791387604128936, 54.026377662535644, 52.45797872543336, 48.66721976187922, 52.145954178225615, 54.28535999790315, 51.04981253224035, 51.053377966726984, 45.743708610534675, 38.8155085040677, 39.860690716774236, 37.98449946988014, 38.277520133603005, 38.85111970286216, 37.56167973241499, 38.16128069354642, 39.719799180184644, 38.515400117443455, 39.462660358798125, 39.87943964619791, 45.70208834063622, 46.39080555208268, 50.893655130940104, 49.35751768850511, 54.27467546155376, 40.65849688745315, 46.49529749347318, 53.95529254790276, 55.47512469753143, 52.80343363361975, 49.67217022372831, 51.13856007975917, 50.174057099127005, 45.749572553942286, 37.1687602227734, 40.134727108863096, 40.847959133886526, 38.99529426328598, 38.32624773825369, 38.32289411175636, 41.68991550322502, 50.78834341418359, 52.64979047159995, 52.518689170960464, 50.873486303514056, 53.22583367747646, 49.6732763321169, 52.100242876237445, 54.22246086981989, 52.88870203879572, 50.95479311481599, 43.136822946609996, 39.23559434952275, 40.894317626953125, 49.34711164043796, 54.54026699066163, 52.78561822829708, 53.327391685978064, 50.94488128539055, 52.399794286297215, 49.906135682136785, 49.132730576299856, 48.388958977114775, 49.36657444123299, 51.80868917895902, 53.76392402956563, 55.19770722235403, 57.38746450793359, 56.909794345978774, 44.38521923557405, 28.52777284960593, 14.030352427113442, 4.0716310662607995, 3.308147840922879, 5.562551425349328, 5.796678191231144, 5.397121540961727, 4.138909030345179, 3.089745611913743, 0.7165761520304988, 0.06846765266551126, 1.1073683274369086, 11.14104042130132, 35.754804611206055, 44.54196107002997, 48.746235909000525, 53.01166834369783, 59.90368458532519, 40.69062109916441, 10.35546616200478, 0.17006617189655382, 0.0768447092043296, 0.04836389674775062, 0.006623240441249143, 0.028530954826442946, 0.026043459675425006, 0.05223943596525539, 0.025589102503633308, 0.017308029120848063, 0.03488942905659637, 0.03040120336076906, 0.10847554497060277, 0.027131645437029582, 0.008577187432937564, 0.03102371683194032, 0.02308310249880437, 0.031012731131106138, 0.028431217839580872, 0.11598317598503445, 0.04380954617273904, 0.027411399679558895, 0.006605004675821552, 0.07610697419412675, 0.08241730171345896, 0.16615851061238399, 0.1301246764318597, 0.23610037691410513, 0.2108457522286523, 0.08441958741675462, 0.16175617103374776, 0.15928302470955158, 0.2528045563808372, 0.12550342722886032, 0.13259042234670732, 0.15156353974053938, 0.17293077382829883, 0.12520966315341572, 0.08908763693104829, 0.1307856264494119, 0.10632305240799343, 0.16377943988528945, 0.16050095129157269, 0.12490506659472182, 0.13302658684551716, 0.2358856577906878, 0.11810757610346041, 0.16372926112624908, 0.49045479045279566, 8.58490042148098, 33.62778171416252, 58.67115428370815, 57.022252621189246, 55.52944167967766, 45.603632926940925, 46.46796249574231, 49.23224502994169, 22.35997126948449, 3.08213621377945, 0.23752729228186995, 1.4755803370668044, 3.435327751982597, 8.069176895003165, 15.10153308991463, 24.415199102893954, 8.728943582504026, 8.010660525291197, 22.580110373035556, 37.30589412873791, 50.06135563696585, 56.698386438431285, 54.37553136579452, 55.25310285629765, 56.453465800131525, 53.88559987468105, 54.74678370260424, 54.26512449018417, 58.344193350884225, 60.793117323229396, 56.27473123611943, 55.18684617934689, 46.08897524495279, 40.717920795563735, 42.340087582988126, 44.46237617923368, 50.94172377740183, 51.493977808183246, 52.2935490454397, 54.94644411148564, 54.42973459920576, 49.05509902584938, 52.81532625998221, 57.36491872418312, 52.26596301601779, 52.55198617135325, 46.52178525924683, 39.9417817977167, 41.44323372071789, 41.61368423892606, 41.294517055634536, 41.48246918955157, 39.75825017498386, 41.09710416486187, 41.80426828322872, 40.57673508121122, 41.910340939798665, 42.02894164669899, 47.279642089720696, 49.38880643536968, 51.682353558078894, 51.09556698030042, 54.45552810545891, 44.46319595459969, 47.94593511089202, 53.87723345910349, 60.17064502162319, 56.04184050713816, 51.38577138223956, 52.81806407436248, 53.76144509161673, 50.460072409722116, 39.93354482035483, 41.334223208888886, 42.32783017619964, 42.03292285242389, 40.07309098397532, 40.068301769994925, 43.74902256073491, 52.33959767126268, 55.17810713860297, 55.382580295685806, 51.35067009156751, 54.590728282928474, 49.84661763714206, 54.439669962852236, 56.226172293386156, 53.86178324299475, 53.504800488871915, 43.92569395803636, 42.03426038065265, 43.72833205807594, 53.5045337677002, 54.887620326011415, 54.63665139290595, 54.93106057566982, 53.61480336035452, 54.516740614368075, 52.575634141122144, 50.82741022109986, 51.99640597066572, 52.537155689731726, 54.73084319022394, 56.430143387086936, 56.86570690524194, 60.6220196139428, 60.29258758791032, 47.47904362217073, 28.3837983300609, 16.39130744241899, 5.236979992158952, 11.036363147920179, 10.716371286299921, 11.079296431233807, 11.740120687792379, 10.028103186238198, 8.718611078877604, 2.494086632805486, 0.4523480755667533, 1.6384089545857523, 13.837817984242594, 43.20282074712938, 49.81189289400655, 54.88209762880879, 60.35894232411539, 67.97722462684878, 47.24677262767669, 12.631119431987887, 0.5022469980101432, 0.18341128564169332, 0.22494866482673154, 0.09200309944008628, 0.15202711486527998, 0.09876600106156642, 0.2023436011926782, 0.10410388721333397, 0.14693241566419601, 0.19621077624540176, 0.12215129460298246, 0.16165140084922314, 0.1618640668570034, 0.14329800262085854, 0.12456335307609652, 0.15046054166891884, 0.16158660513258752, 0.15286578195950679, 0.1885558724884064, 0.190869381410941, 0.14587850850676337, 0.1728690424633603], [0.04376274203100512, 0.095981968596818, 0.02194997227390207, 0.02296065292020719, 0.04409435468034879, 0.023487909103653604, 0.029350398859429746, 0.04744538413961569, 0.10319153012167062, 0.10417312623993044, 0.04864728799270046, 0.039723179558472294, 0.067758301212903, 0.06655224899370825, 0.07317830432927416, 0.046120956014361114, 0.01662920818724219, 0.034499881007978996, 0.06929136572345611, 0.047676302192191926, 0.06093436153605581, 0.05270536681036315, 0.08368497804528283, 0.029825325491988373, 0.02301934291608632, 0.08118679596772117, 2.0120046624252876, 15.400620679701529, 39.45956953110234, 50.05555837385116, 38.905746552252005, 31.465239794023578, 39.388676612607895, 34.76717141366775, 20.63599544186746, 4.827398744321639, 0.2235568056423818, 0.060587683767681165, 1.0182832109351312, 2.998774325655353, 5.027383729334801, 8.878227030077289, 2.5687141380002423, 3.1407092127107807, 14.519077789398933, 30.091474748426872, 48.164540567705714, 55.45980391963836, 54.427706733826675, 53.800566811715406, 52.11119805612872, 50.96337133838285, 53.94371763352425, 53.67000287578952, 49.78501681358584, 48.996738080055486, 51.929164778801706, 49.65045990482454, 40.846574537215695, 37.47071996811898, 38.77971687624532, 44.87138917369228, 51.11868543009604, 47.84883291490617, 51.66051772332961, 50.2384114265442, 49.92914430556759, 51.307818197434955, 52.390663008536066, 50.63439038492019, 49.034392833709724, 41.19184509400399, 37.059141743567686, 36.36192083358765, 36.75281640022032, 36.13794172963789, 37.61606731722432, 36.77098874122866, 38.90267141403691, 37.81664948309622, 38.47447018469534, 36.56821397043044, 37.25984158054475, 36.34033995289957, 40.719689784511445, 42.997449367277085, 48.76537707544143, 47.58311586995279, 52.33595771174277, 40.852261973965554, 44.00396093245476, 49.0377111588755, 48.03465520181964, 50.748268558133034, 49.45497289780648, 52.51763013101394, 50.25659553466305, 52.32031922186575, 45.832052153925744, 38.309055989788426, 38.46225984634892, 37.314335069348736, 37.43153549009754, 35.415778467732096, 39.1615007769677, 49.36596255148611, 48.89187743586879, 49.79749779547415, 49.843185563241285, 50.10526657104493, 52.29152902480095, 54.191023072888775, 50.513075397860625, 50.57460954112392, 46.55936941023796, 41.275583774812766, 38.43108092584918, 40.513243675231934, 49.99271415895032, 53.28985068105882, 52.1928108123041, 51.284248675069506, 52.44761190106792, 53.48738516530683, 53.086875869381814, 49.51843292482438, 51.7798597581925, 50.130765899535156, 50.971863269805915, 53.150496713576786, 54.28496383851575, 53.59484241854761, 52.396440659799886, 43.42520344641901, 26.83893361399251, 11.581821672378048, 5.190547954651618, 0.9671356264621982, 3.519840365455997, 4.185487176141431, 2.061897578739351, 2.533831274317157, 1.3169625065019055, 0.44865629785964567, 0.07806997490866531, 1.3697756274092583, 11.128475108454305, 36.88936979539933, 42.00719602646367, 33.77257600907357, 43.16226343954764, 51.21154362155546, 29.08381392878871, 4.1772928545551915, 0.020665821221266544, 0.03510831569832179, 0.014130105846561493, 0.07728780679885419, 0.10590441600089112, 0.06427827786894576, 0.07596784496619817, 0.02073007684591557, 0.028227823410904216, 0.01716303357463931, 0.05114878340053463, 0.06311031554134623, 0.04910243998071359, 0.02781817321515372, 0.019975788590888825, 0.018093983620224942, 0.03625123844211621, 0.09214205246779228, 0.010425643638647612, 0.061377302082555915, 0.06100912022614672, 0.024726184896163406, 0.030700494760587334, 0.04683372038867205, 0.014426337682732172, 0.07340842181996954, 0.0739898978762569, 0.058254808142420754, 0.028260025916801348, 0.031158125043035518, 0.12773448210810462, 0.02264942778574844, 0.04390193637640726, 0.015003115704823888, 0.018881156199401426, 0.025845872193214395, 0.016604103485963518, 0.05372185440313432, 0.07405045712667127, 0.035713387262677, 0.030321520640544837, 0.055913049727678306, 0.03406638632558527, 0.04190770225719579, 0.021137256408110264, 0.008199783793139842, 0.024387572118411624, 0.06858759905181586, 3.2540181519523745, 19.63398675764761, 45.89424917774816, 56.5706701432505, 44.82211635958764, 35.800766944885254, 44.815652293543664, 42.40810932651643, 21.914021315113192, 4.7882485870392095, 0.20679144639401667, 0.34624269172068567, 1.4093251310048567, 3.062243913450549, 5.772597780150752, 8.400742200113113, 3.5260063313668777, 4.6362518398992485, 15.702287227876726, 33.02168530802573, 49.28101578066426, 56.41503833955335, 56.63801723910917, 55.21134922581335, 52.56503197454637, 55.680633360339755, 54.61878107440088, 55.40839341378982, 50.55559389052853, 51.256097824342795, 53.46321552030502, 53.467522282754224, 42.36680676860195, 38.696409656155495, 40.104011028043686, 46.87632829912248, 51.58721646954937, 51.48022205598893, 53.295726391576956, 52.172967541602354, 48.56298669692009, 52.792549056391564, 54.70400241113479, 51.76429971571892, 51.08187398602886, 43.54579671736687, 39.6012298522457, 39.208667278289795, 38.103143322852354, 37.98471520023961, 39.44832801818848, 38.519553907455936, 40.34124382080571, 39.86153794873146, 40.326703594576934, 38.06513555588261, 38.543978506518954, 38.69999862486316, 42.88361041776596, 46.19377313121673, 51.155743983484086, 50.339808617868734, 52.92920835556523, 43.83279654287523, 46.177326633084206, 50.382146681508715, 49.687471389770515, 52.92194804837627, 51.27056352553829, 52.93342882587064, 51.93672710849393, 54.20153502495059, 47.76539625660066, 40.34587613997921, 42.24337370164933, 38.560005311043035, 40.13079689395043, 36.80520749861194, 41.57799459272816, 51.198552731544744, 53.862053886536636, 52.14537366744011, 51.027023561539195, 50.607941842848255, 52.550585885201734, 55.52902983080957, 51.86552824512605, 52.979936369003795, 47.65531886008478, 43.40315580368043, 40.16256416997602, 42.626938358429946, 53.16787281344014, 55.21598154498685, 52.68912007731777, 54.733624150676114, 54.38149336845645, 54.779331530294115, 55.555568587395456, 51.6955013428965, 53.52897797861407, 52.6039065853242, 53.13331673222204, 53.61112025476272, 55.96921390102756, 56.945719334387014, 54.60324064377816, 44.77335345360541, 27.385751239715088, 12.112273208556637, 5.0868537252949135, 4.168355243821298, 7.8640957705436225, 7.700280431778201, 5.668580445551104, 3.189813119749869, 1.720015091761466, 0.556671109891707, 0.17176085031561314, 1.409448195369013, 14.321170679984556, 38.80436505040815, 44.893181862369666, 40.34582514916697, 50.1268631412137, 58.44353522023847, 36.03816055482434, 6.176713205152943, 0.07297683852694689, 0.1094997738818488, 0.02449118742539037, 0.08726802489329731, 0.017267133432230162, 0.02814204263080272, 0.06539630658564068, 0.06482187087737745, 0.013099363272739275, 0.05151196270279827, 0.03619254844623708, 0.04818143758682474, 0.03385914422030892, 0.03343154841493214, 0.04665872292412866, 0.05128864424243089, 0.01809512509123212, 0.014728987420488511, 0.027650074372368477, 0.03523747429191586, 0.06070522463790352, 0.08075783269539957, 0.06338255637655817, 0.1539926819743649, 0.08946737905423488, 0.09864132791276901, 0.11854475949920955, 0.21774530861406557, 0.15109997993755728, 0.10967116307226882, 0.1829654990785545, 0.2240879037567685, 0.1486291778424094, 0.08659202124803297, 0.1258074415607318, 0.15369704864438505, 0.1676376731765847, 0.15877861709844682, 0.18033107592453881, 0.1418144580337309, 0.12981937507227545, 0.15896762631112532, 0.1097144547008699, 0.15599264643124996, 0.20269566455916052, 0.11290041519509209, 0.17159892997193724, 0.18911179185153978, 3.187815897887753, 21.750966425864927, 52.40388531838694, 62.306175539570475, 51.94752539357832, 42.47602124367991, 51.56115231975433, 46.97694493878273, 26.716849842379172, 6.487572318123234, 0.7146844664408315, 1.1298415473391934, 2.7263566467069813, 8.179206732780703, 13.190317038566837, 19.194604812129853, 8.24853168379876, 5.627238173638621, 16.414558272207938, 34.580423447393606, 51.228770671352265, 58.76755045306299, 58.93942871401387, 58.162760196193574, 57.74909919308078, 56.897332975941325, 55.76436027403801, 57.00263684795749, 52.737973197813965, 52.97779475488971, 56.87174343293714, 56.09035238142937, 43.982313371473744, 40.415133430111794, 41.45227870633526, 48.66737665668611, 54.45459850372807, 52.634265730457926, 54.7032924621336, 51.77870265899166, 49.52677580618089, 54.53233203580303, 56.57185469904254, 53.42203455586588, 51.94755285016952, 43.839468494538345, 40.114977975045484, 40.98224932147611, 40.33585840655912, 40.38928501067623, 41.37903236573742, 38.82363957743491, 42.446470106801684, 41.19275116151379, 42.48635668908396, 41.3458255798586, 40.91250565744216, 40.178747869306996, 44.63399164138302, 48.06871314202586, 54.327658837841405, 54.44375707257179, 54.295797424931685, 47.472450117911066, 46.81236228635235, 49.56685850697179, 51.26988887786866, 55.541467666625984, 53.32175131767027, 56.64707399183705, 53.2586129250065, 56.35480250081709, 49.42629644947667, 42.96064576795025, 44.37024754862632, 41.83062661078669, 40.87994998501193, 38.026480597834436, 43.389631471326275, 54.34492118896977, 54.65540032232962, 51.66993925648352, 50.397691034501605, 51.8881485539098, 53.68383315301711, 57.07853471079181, 51.88891733846357, 55.473634196865945, 48.600829724342596, 47.56279799246019, 42.99421341188493, 44.38252456726567, 55.58053839591242, 57.798991741672644, 54.08826874148462, 55.32169334350094, 56.4488217138475, 57.03468653463549, 57.682379676449685, 53.759491751270915, 56.96603721187961, 54.82285807209631, 54.783732429627456, 56.954901602960405, 58.37914166911956, 57.51320000617736, 56.35898766979095, 48.00956379982733, 30.28697744492562, 13.827350158845226, 7.038423611271766, 4.7366865796427575, 12.074781233264554, 12.360624940164628, 10.613164901733398, 9.606444470344051, 5.323511400530416, 1.9886956099540958, 0.3910276708343337, 2.088157356746735, 13.781505496271196, 46.93754080803164, 54.91709693785637, 45.17885592675979, 57.61913537979127, 67.3645817848944, 41.09959486992129, 7.539700067812397, 0.19872342206297383, 0.16681293356082133, 0.11622038744990865, 0.16580549729687555, 0.09221433286344813, 0.12315362872135256, 0.18295531010916158, 0.11200554022986083, 0.1178403493137129, 0.12715959440796606, 0.12602176997930775, 0.13063090733222424, 0.13561654625640762, 0.11613505291602305, 0.12709363423768552, 0.12998739347582863, 0.07813146112546807, 0.20377448489589078, 0.1183290904267661, 0.09523140927476269, 0.16226261643873108, 0.2376998152824179], [0.026611642191006292, 0.017918750583644838, 0.041407239998901085, 0.024052711256269007, 0.05145288200207776, 0.10274736000405205, 0.0908890160762014, 0.02229287705924963, 0.01659689268337623, 0.06113477013704758, 0.026571031870140184, 0.017506959172145977, 0.029776140732029756, 0.12454803897849015, 0.03936050204379905, 0.04651824538145335, 0.03381672976238113, 0.03607570471602582, 0.015539731567485199, 0.027601770613522782, 0.06145741572723754, 0.039356280899336266, 0.032464546271629875, 0.022878482329448866, 0.09869699952222648, 0.046051215200174245, 0.6913861392005798, 9.940520582660552, 30.884087700997632, 46.456870032895, 46.6057788941168, 31.550508199199555, 33.2379844111781, 39.68937335475799, 29.455605591497115, 6.455928106461802, 0.9423731519810615, 0.06927456541527664, 2.048182153413373, 2.1280581576208917, 3.888211231077871, 5.116052829450177, 3.330873073108735, 4.436333535179015, 11.899663094551334, 28.724513053894047, 41.60798111269551, 56.34162333703811, 55.98234991873465, 57.54055853812926, 53.13284604780136, 54.499784208113155, 51.93942569917249, 54.41686530267039, 51.913871457499845, 51.80999140585623, 51.39226682724492, 48.914007448381, 39.0246767382468, 38.88369106477307, 41.48523838289323, 48.57454984418808, 51.597901005898755, 52.06940912431287, 50.411866480304354, 44.9827060391826, 51.37162339302802, 52.04855388210666, 49.6725389265245, 48.46777116098712, 43.136791567648615, 36.458960271650746, 37.12269590746972, 35.610892849583784, 36.41875205501434, 36.968770334797526, 38.33757162094116, 39.946551399846236, 42.016954883452385, 44.22160148620606, 45.7566406649928, 42.87797004945817, 41.75845892198625, 38.64944711808236, 39.125713071515484, 40.7185915208632, 48.58800357387912, 45.234949742594075, 54.91695965490034, 39.39480335481706, 42.62673831755116, 51.80052280426026, 48.47545508415469, 49.24059967840872, 48.39212040747366, 52.0944260012719, 50.94033918073101, 51.76706106432023, 51.085521790289114, 42.67142195855418, 35.148453251008064, 36.76480708583709, 35.605119120690134, 36.38191315435594, 40.166392403264204, 48.41127726339525, 49.99688363844349, 56.087634178899954, 49.43364304880942, 48.345244161544315, 53.41743361565375, 51.04094405328074, 51.74855924421742, 49.736873642090835, 40.465171106400035, 36.98575812001383, 36.24797598008187, 39.7545749141324, 50.696563874521566, 50.24382429738199, 49.883048611302534, 51.305790332055864, 53.03564187019102, 52.73728286066363, 53.51625380977508, 53.483133316040046, 53.609343421074655, 52.82515179726386, 54.212164648117565, 56.26945564823767, 59.616284678059245, 55.68789758989888, 51.10528269121724, 37.61608692907518, 24.094270775395056, 9.611871069477452, 2.9491176095701035, 4.481789883105986, 4.576768605939804, 5.2801760742741255, 4.138635935321931, 0.7603225917104752, 1.4918363550978324, 0.4615495576252861, 0.08638614277926185, 2.3026698202856126, 12.120881830492328, 43.17031998788157, 49.28192577054424, 32.29839632588048, 40.67098963645197, 51.39703642937445, 21.869200391154138, 2.4737704713498396, 0.04265663747285162, 0.06602111257492535, 0.04800590386073436, 0.005865055192712575, 0.03671874742834799, 0.016658520626444972, 0.057593582333215786, 0.0358842172089123, 0.05682747908717683, 0.004029382600434004, 0.03733082103633112, 0.018076380834944786, 0.04756001004528615, 0.022980927437123273, 0.036692761725956397, 0.01618772703823784, 0.008717439937285118, 0.08155232715991237, 0.02249866168225004, 0.014721357184762677, 0.013819775119754336, 0.014997902476499158, 0.06334178517722795, 0.05657051404517505, 0.08859639837136192, 0.06030335023458447, 0.04493548857769178, 0.06468842602184703, 0.031838160226001375, 0.04204649057599806, 0.031185889984631253, 0.02918451018030605, 0.044616336348436536, 0.05192403756682912, 0.06778729764083702, 0.14001401351584544, 0.019736001155369227, 0.010851144193551474, 0.04235148933085223, 0.04835953004658223, 0.008627288625575602, 0.09339691214864293, 0.01373134176021502, 0.09611316115385103, 0.054510109081503846, 0.040962705989518476, 0.08071703085255238, 0.04045008208542582, 1.0351321197325185, 13.777128131158891, 37.232024131282685, 54.669971927519775, 50.25084926236061, 35.917767324755275, 39.62489351149529, 42.46504645193777, 33.19921570439493, 7.390896620288973, 0.6689873217575012, 0.0627201852659064, 0.5971655369766298, 1.86005461600519, 4.532128111008675, 4.7644618634254705, 3.6546443835381544, 4.717315954546775, 14.104264590048022, 31.12117340487819, 43.969828467215265, 57.027245798418605, 57.557103095516084, 56.729639883964296, 55.092713217581476, 55.54047138460221, 53.4054115510756, 53.98568699436804, 52.9561471939087, 55.184673186271425, 54.07026506239369, 51.140627168839984, 41.886308577752885, 39.442499376112416, 44.08762508823026, 50.244389118686804, 54.37802991559429, 53.51711280884282, 52.95994012586532, 47.618503493647424, 52.275211964884114, 55.04911999548636, 51.49034569340368, 51.152304064842966, 46.52224025418682, 38.59075277082382, 39.82939412516933, 38.20831383428266, 38.251479518029, 38.555067046996086, 39.4756708606597, 41.046603648893296, 44.92443138553251, 45.13765535046978, 46.11576503322971, 42.39895059216408, 42.56943641170379, 39.55644815198837, 41.15533959481024, 42.223706937605336, 50.773724740551366, 47.656009197235115, 56.16324570871169, 42.23764704119775, 44.936880988459436, 52.08715000460225, 48.7084517171306, 49.34470722752233, 51.1371244922761, 55.03704694009597, 52.83189827396024, 53.29468304111112, 54.09194792470625, 43.1786471797574, 36.44448280334473, 37.75862586113715, 38.11702066852201, 38.61538525550596, 42.68962960089407, 50.771265414453325, 53.70355090787334, 56.00186763271209, 51.26225594551333, 49.0693489966854, 54.823850431749904, 54.315872115473596, 53.36826670554377, 50.303648287250155, 43.79753443502611, 39.637041091918945, 37.55894976277506, 42.11738717171454, 52.886164265294234, 52.756604456132465, 50.85412156197333, 50.38311550694127, 54.09028483975319, 55.16442591144193, 56.409146939554525, 55.5579847674216, 54.60821028678648, 55.54815923013995, 56.804055090873476, 58.121791039743734, 59.45886819593368, 57.66590964409613, 52.74397050180743, 40.7837656236464, 27.943639755249027, 11.655506337842635, 2.561347926816633, 3.7155102529833397, 8.940178905763934, 6.559154102879186, 4.328822349348377, 3.173367847358027, 2.3222949091465246, 0.3659926222697381, 0.09577168512248224, 2.6384749624036976, 13.574169989555115, 45.931617598379816, 52.72740633256974, 37.980769295846265, 47.837662004655414, 59.6622666235893, 26.476000624318278, 3.662186120786975, 0.023286006631209485, 0.01819601695564005, 0.09448952206801023, 0.06996958336282162, 0.027309843233876654, 0.03252592906656285, 0.048823813802652785, 0.029280960649972963, 0.03752443826787415, 0.05780057929035637, 0.03562017734492979, 0.030031826407197985, 0.09194746613502504, 0.02040296687834686, 0.032820447738612854, 0.016337776849527034, 0.03764299037415655, 0.033463540246650096, 0.031197940547680183, 0.0034109042580014156, 0.049754511039223404, 0.07018106193431924, 0.11996401398773156, 0.17435958909411586, 0.11014258293735404, 0.2077984383269664, 0.1571421613616328, 0.23830061207615563, 0.157219720103087, 0.1400608827750529, 0.12115243086290937, 0.1056334123976769, 0.11472496849995469, 0.14786099083721638, 0.15226651734161764, 0.17663320015755393, 0.09704208106643732, 0.1562921102008512, 0.09917571254435087, 0.1135027135211614, 0.07422692548002928, 0.159649888894731, 0.14304405979571805, 0.15772771300567737, 0.12374728557563598, 0.24927699728117836, 0.26110234580213026, 0.15470658398924336, 1.1211235893349494, 15.257241379830146, 43.44073603230138, 60.942661608419115, 59.1337586218311, 42.65341435709308, 45.36160699782833, 51.075374618653335, 39.295182997180575, 8.67698198364627, 1.1969981630963664, 0.20890163558144725, 4.593292080586957, 6.192818457080472, 10.549532290427916, 11.833268154051996, 6.204632636039488, 7.019907082280805, 12.83935316147343, 34.139819683567175, 44.301680595644065, 58.31175927192935, 59.74481290386569, 59.03753503676384, 55.383368692090436, 55.69306335141582, 53.59937275609663, 55.67825640401533, 53.755137920379646, 57.013748922655665, 54.90488267713978, 53.754733916251894, 43.668586515611224, 43.10782486392606, 46.42188641332811, 52.22263259272422, 55.91603048386113, 54.44306673542146, 52.700749904878684, 48.93668267034715, 52.6606083685352, 57.04947387018512, 53.02550646566576, 54.60578233964982, 45.93599104112195, 40.29088058779317, 41.34340155509211, 39.94103262501378, 39.39515244576239, 40.92310390164776, 41.5311614928707, 43.35059212100121, 47.52098944879348, 46.84765969553302, 49.20751448600523, 45.87741436496858, 45.72042149882163, 42.92752135184504, 43.484599897938395, 44.84783534080752, 51.897220996118364, 50.199411299920854, 58.24632629271477, 46.20761125318466, 44.77287492444439, 53.76041350826141, 48.147976398468025, 49.07595819042575, 50.82693953667918, 55.06741785234021, 54.426777132095836, 57.319842846162864, 55.681221715865604, 46.98608013891405, 39.38361675508561, 38.87196710032802, 39.78450652091734, 41.26718598027384, 44.51392004566808, 53.17021054606284, 56.08314698742282, 60.20285552547824, 50.564615341924856, 48.67500958904144, 56.158997781815074, 55.71112586605934, 55.79535092076948, 54.091116382229714, 44.82155938302317, 41.76005532664638, 39.39525834975704, 44.84709009047478, 53.469793335084, 53.8323615443322, 53.93724964511011, 52.262715293515114, 55.60096609976984, 55.150889811977265, 57.63430318524761, 56.207423363962484, 55.49545826450471, 56.18202209472657, 58.83638020484679, 61.24539798305881, 60.90285347354028, 57.38426385387298, 53.662648431716434, 41.57808480724212, 27.680201607365763, 12.908616335161271, 5.882972296207182, 7.868034810789171, 12.314965609581241, 13.588099306629552, 12.092259314752395, 9.19950640970661, 5.722464986385838, 1.7235229164361956, 0.46338320439380987, 3.421012571742458, 16.070559543948022, 49.693323566067605, 61.10421619107647, 46.40577331666024, 55.423267041483236, 67.27611664802798, 31.940752652383622, 4.2087110396354435, 0.12113309480370053, 0.14559010704678876, 0.189172251510524, 0.15268726815139094, 0.12856098372609387, 0.10861094335034009, 0.2018084734558098, 0.09257734362636844, 0.19987391758589976, 0.1629948126332414, 0.1599743118089053, 0.11520924332040934, 0.18620906938468257, 0.0837145030738846, 0.12423913700566178, 0.18179693920237405, 0.1592659869141156, 0.1472115168167699, 0.11270099484752263, 0.07623124897720353, 0.11225959796818996, 0.20894734038700982], [0.04637651145458222, 0.02291738044380421, 0.009888689739689713, 0.019134511052060033, 0.034113106197647514, 0.06604599511070598, 0.017237231105325684, 0.03397251757222318, 0.02737276395031762, 0.07346483653471356, 0.001909281911080583, 0.07374848824955764, 0.03229324135088152, 0.05647903548613672, 0.025825325715085192, 0.022723964310341307, 0.07342840905391401, 0.04038619801342007, 0.025865524263692, 0.0915667510801746, 0.0048767012213507014, 0.045178422719360366, 0.02535390393478015, 0.08228915052548533, 0.05562859745095334, 0.07488231369925123, 0.07265043910592794, 4.141768438200797, 24.90962366903982, 46.05904363816785, 47.18825870944608, 41.021182767806515, 45.21668718707177, 39.53868765984812, 27.61675923101364, 13.638621395634068, 1.0469719166717222, 0.19768390203675917, 0.28362376795661065, 1.5025170916511168, 3.6477373348128412, 2.7680769370448206, 4.7773032130733615, 2.458869141917075, 9.694043743994929, 26.247673573032504, 43.88730964353008, 52.97060897273403, 54.30474435129474, 55.244595235393895, 49.21507681569746, 51.23157516602547, 53.76710899414555, 53.158270851258315, 54.679546433110396, 52.193328565166844, 49.58154386089694, 42.566647606511275, 38.13013315200806, 38.534953132752456, 43.99629269876788, 50.09413880686606, 50.8642412770179, 53.74443769454957, 47.37524594030073, 50.97985706021709, 51.770402923707046, 49.49311794773225, 49.01549093184933, 46.22308500351445, 36.9891627373234, 37.0133755283971, 41.63608881735033, 37.018972750633, 35.296620784267304, 36.6008206336729, 36.945596971819484, 42.35504750282534, 48.197057016434215, 46.968594212685865, 49.03151381400324, 47.19692322515672, 44.89862611216884, 42.7566707518793, 43.64590737127489, 44.40329351732808, 47.09388648310016, 47.3247964151444, 50.48922738721294, 37.83332740106891, 46.89185696263468, 52.68735501074022, 48.90469574159192, 52.631539683188166, 50.54228921090403, 51.12749507350307, 50.55212259292603, 51.41223561379218, 52.38733683862994, 44.56419698653683, 36.34088908472369, 35.833224558061175, 35.57447364253383, 35.94504740930373, 40.01277669783562, 47.64441074863557, 51.77105403715565, 53.34298310741302, 51.45253404494255, 50.86013455544749, 53.582561477538086, 51.621093980727665, 49.11227149348105, 45.42108974149151, 41.045748572195734, 36.35544500043316, 37.12883833915957, 38.21958280378772, 47.21142422768378, 51.941987006895005, 53.55206504944832, 54.085907474640884, 52.174018736808534, 51.06077947924214, 51.89249846243089, 52.71507047837781, 53.42032440247075, 52.637580133253536, 55.70549726486207, 58.002409781179125, 59.54104185104371, 55.77304832396969, 48.45538431598295, 35.755102711339156, 18.691841286997644, 8.525349036339792, 3.035268302886717, 3.3856614751200524, 8.219288943275329, 4.931332728555126, 2.205364151347068, 1.5267716804819724, 1.0928510225588277, 0.08143902275591128, 0.1452855564533703, 3.2461631153860404, 21.32585994658932, 33.713979721069336, 43.335447849765906, 43.03546497898717, 40.264251616693315, 45.5804281850015, 18.772712715210456, 1.701202791544699, 0.07574190265469014, 0.06915864865145377, 0.055216897970005396, 0.008194145386017138, 0.049312815385600256, 0.040627312696268486, 0.020095949481812217, 0.05156559268793753, 0.07289870521954953, 0.06560674327756129, 0.05023322789178741, 0.04389950021680805, 0.018828133338942163, 0.008562584839490874, 0.010856197501022008, 0.02973425295954991, 0.05155716572077044, 0.04817306807625198, 0.04117355253847857, 0.03053990357946004, 0.0050603535642186484, 0.026606068901357152, 0.024546707732482784, 0.04964831210072002, 0.03157185082654319, 0.034398477779881614, 0.06011678101194482, 0.04428941981806871, 0.0032478797901046253, 0.03558797866947228, 0.041667173631609454, 0.0305734544001039, 0.004775942464719617, 0.05794018732323762, 0.06380218869796203, 0.018163197748963873, 0.02499313397903837, 0.05268296256901757, 0.05597037225661259, 0.011468743210688475, 0.0310781569550595, 0.06288823431297656, 0.03662530385378388, 0.00795360479030698, 0.04462959349996621, 0.03455234270903372, 0.03035379209435515, 0.021942746149556294, 0.17951962027338245, 6.78780573029672, 29.5217171407515, 54.4497347647144, 53.93194660063713, 42.917915467293035, 43.139482313586825, 48.605873892384196, 32.261245596793394, 14.050472224912337, 1.2299446016550064, 0.035439679369090066, 0.5486588107962762, 2.0992365815947136, 3.536776669563786, 6.288670887870174, 3.8532457524730317, 3.696395072244829, 12.46368129407206, 26.75301213418284, 43.76268025367491, 54.21913862228394, 54.40283498456402, 54.74055105640043, 51.77867128003029, 52.18194192455661, 52.54249795790642, 56.03533721739247, 54.928193323073856, 54.455057421038234, 51.789089095207956, 45.11873383675852, 40.388300495762984, 40.4190008871017, 46.097639760663434, 53.395939027109456, 55.13165450865223, 54.99334781400619, 49.599845640120975, 50.11011462057791, 53.97468474603469, 50.5193551125065, 53.45757515199723, 48.62456790862545, 40.446328040092226, 39.45626689541725, 41.573209301117934, 38.75735544389294, 37.78907522078484, 38.239045604582756, 39.202803334882184, 44.42176395846952, 49.10416395433488, 49.06571295953567, 51.20791542914606, 49.21528077894642, 46.3395558634112, 44.10627203602945, 46.959360953300234, 45.908867851380386, 49.29446558798514, 48.935058809095814, 53.34690939995551, 41.38131126280754, 46.91987445277553, 51.031518597756666, 49.44579062923309, 51.07013040973295, 51.18167477269327, 51.87208252568399, 50.25721919152045, 53.974014020735225, 54.26627766701483, 47.08180558296942, 36.265932590730735, 36.71099216707292, 37.07512540201987, 38.44327949708508, 42.27526257115026, 50.07417394268898, 53.028307037968794, 54.43196642783381, 51.0248544908339, 50.70319268011278, 54.97294756673998, 52.89950424625028, 50.35512547339163, 47.73956744901596, 42.535645192669286, 37.9172896569775, 39.277712760433076, 39.97952284351472, 49.297572105161606, 52.45708050266389, 53.63270505782097, 54.5703084238114, 52.02190137678578, 52.51177795471684, 51.754948785228116, 54.099992705929665, 55.29104394297446, 55.900529276940134, 56.43065329520934, 57.87012000237742, 59.54849827674128, 55.70881559002785, 48.2859928377213, 36.82836909447947, 21.787360137508763, 10.179974417532645, 4.134741512037093, 4.884359403964012, 7.454027168212399, 7.36804832373896, 6.57582417611153, 3.4040767579309406, 0.8082590420399943, 0.08785901576160424, 0.2642998742240091, 3.679704406569081, 20.614614602058165, 41.01616213398595, 49.27312397187757, 44.5380033985261, 46.83870100205945, 51.51779051749937, 24.836559718655003, 2.386133444886054, 0.1277835730222925, 0.04059714798424994, 0.029218135694522532, 0.00499776178678017, 0.022693420384800243, 0.03397046445658611, 0.08896650310846106, 0.05846542869544318, 0.012427047383220447, 0.01775121673070375, 0.004185459129662524, 0.018591377696382905, 0.02909535095245848, 0.05340583547348938, 0.030765064481285312, 0.03587229688081049, 0.04919643513858319, 0.009971602478124683, 0.029460288426508347, 0.014407573316636828, 0.071705186198796, 0.03858956095251826, 0.11918019112800399, 0.19732141987450663, 0.0879221490674442, 0.10481372130133453, 0.150284678525021, 0.11190524399881402, 0.07950570794843859, 0.11339986621732674, 0.2078383515078214, 0.1387409745685516, 0.08673776947562734, 0.20723825951497402, 0.24010459592025127, 0.13318633149948814, 0.079422487817224, 0.13056160701859382, 0.16675748411686192, 0.09928239028780692, 0.17356880249515658, 0.20631696217723433, 0.1267132409397633, 0.13151388495199143, 0.2253064585308875, 0.21844574280323523, 0.14748232889800303, 0.19311348276753582, 0.26229759618159265, 6.720210054228383, 33.6377876804721, 61.58440843705208, 58.40650804581181, 51.449035290748846, 55.50458954226587, 52.439582809325195, 36.77392267411755, 18.372291672614313, 1.501157132367934, 0.6324885641374897, 1.6193468484186357, 5.1792662374434935, 8.503572037143092, 10.01558788361088, 9.998137258714246, 3.3688239657109786, 13.014105539168082, 28.991202846650157, 46.28252067873555, 57.761411513051684, 55.37815586213143, 57.08092343422675, 52.19074764559346, 50.136743591677764, 54.85661398979926, 57.579841075405, 58.989446778451246, 56.69540151473015, 53.86479562328708, 47.36171376320624, 41.76920229388822, 43.66786479949952, 49.1903188151698, 54.50276128707394, 56.216884120818115, 57.45518030658845, 49.174719548994496, 51.30424491820797, 57.40886888196392, 52.63556403498496, 55.58774378991897, 50.44207657537153, 40.88516281497094, 41.78664507404451, 45.323932632323235, 40.32427564744027, 38.99998934038224, 39.553070991270005, 40.229307220828154, 46.79582949607603, 52.04480409622193, 51.177230727288034, 54.514457794927786, 50.73031979222452, 49.26176871022871, 47.79172712756742, 48.02764200395154, 48.2612701385252, 51.09974038216376, 51.54057948820053, 54.6196557629493, 44.91407240590742, 49.88040101143622, 51.740632134099165, 51.265954740585826, 51.44570519847255, 52.954856734122004, 54.05255556106568, 50.142054480891076, 56.47729812129852, 56.158001499791304, 48.76345119168682, 39.33443023312477, 38.618193672549346, 38.68004945016677, 40.04122564869542, 43.19152824340328, 51.741663717454486, 56.65840964163504, 56.1114586553266, 51.21291645111577, 50.9057124968498, 56.852351234805205, 56.29983440522225, 53.858688492928785, 49.14797290678948, 43.942371876009055, 39.502986246539706, 42.14624797144244, 42.682675238578554, 50.92583817820395, 56.3406035207933, 57.66284235062138, 57.473238898861794, 53.727665639692745, 54.73774656172722, 52.07809325187437, 53.88955754618491, 54.47568908814461, 54.986401296431026, 55.89789344418434, 59.65221358883766, 60.65213949449601, 57.64045738404798, 50.63459827053932, 37.93811352022233, 23.615096384479155, 11.230633239592276, 5.140357796222934, 8.699479718362133, 14.87604191226344, 12.89171778386639, 13.236805950441669, 6.48108716933958, 3.1832497687109056, 0.8412779218727543, 0.5168711874754198, 4.831218642573203, 26.117005694297056, 43.66002790389523, 50.36368016273745, 56.09898551817864, 53.61303829377698, 61.715764691752774, 29.423932452355665, 3.1681013299572856, 0.2011154703195057, 0.2231059016119088, 0.138511638487539, 0.06975556137941538, 0.11446683517386837, 0.13517711822304035, 0.1972351890177496, 0.1909541720224004, 0.2091714977136543, 0.31252808147861116, 0.12403809255169285, 0.10060559267238264, 0.11884859763085844, 0.15442077190645281, 0.1642940517875456, 0.1755590529571618, 0.1361909896255501, 0.20345513348377522, 0.20960421481680488, 0.07354267106782045, 0.20414419892814853, 0.16475820913910866], [0.046642742330028165, 0.03414860671205867, 0.04005864946051471, 0.01443094761681653, 0.015947592947932503, 0.03970472066993675, 0.010883874342506452, 0.04219494309396513, 0.01484026169149025, 0.016881942508682128, 0.09315841365605594, 0.054406997477335316, 0.02093717530970612, 0.01992980033279427, 0.038925272172256824, 0.07250325063303595, 0.030242881715117447, 0.0294585972874155, 0.11707694269716741, 0.011195460495899522, 0.04933680925938872, 0.05361044606674583, 0.01712064592978887, 0.033220410752560825, 0.06476641377253879, 0.03195440066197226, 0.0020198128373932938, 1.886931309296239, 18.981131776686638, 41.837569205991684, 49.6495577596849, 47.176577891072924, 31.996883730734552, 35.571437728020456, 49.91687513166859, 17.166025561671105, 2.4987473891627405, 0.037830850454948606, 0.18182906892991837, 0.6817728389174708, 1.583528622023521, 4.622776046875985, 3.605261252772424, 2.671611390767559, 12.194881266163243, 24.14251788969963, 38.84194527902911, 52.17069256690241, 54.35738648137739, 50.54693721955823, 52.76695166864703, 52.32941127592518, 55.27646449304397, 51.154316240741366, 52.04715751832532, 46.62643017307405, 44.16311894693683, 37.35125241741058, 38.51347815605902, 38.498392720376295, 48.19717076516921, 51.86122540504702, 54.14084811364451, 50.08965553775911, 48.207243411771714, 53.301327536183024, 51.534237015631895, 47.5934434706165, 45.68641454942765, 40.11478970127721, 36.75541693164457, 35.940642587600216, 38.261226607907204, 36.66038966947986, 36.578498425022254, 37.0047620034987, 37.479333493017386, 43.28058173579555, 49.957569722206365, 49.630706848636756, 51.23220274525305, 47.63642480296474, 49.28968029637491, 46.19519695158928, 46.163617949331964, 46.94506783639231, 49.6706130427699, 51.78713967723232, 56.98408795941261, 41.09920655527423, 43.59979206515897, 50.23605015970046, 49.191499448591664, 52.78061328395721, 48.62352848052979, 50.41862080174108, 50.9783822490323, 52.00783575734785, 50.40196641798943, 41.88189198893886, 34.956908226013184, 36.9591958292069, 36.39310759882773, 35.993833849507, 41.42381406599476, 50.762455771046305, 50.64374916015133, 52.10360042510494, 50.787806049469985, 51.10013261918099, 52.011660068265854, 51.16933891850134, 48.55889174246019, 46.86900131164059, 39.61784108992546, 36.709619337512606, 36.36610600256151, 35.3401041799976, 37.971928273477864, 46.37582994276478, 49.91206630583733, 48.911450063028646, 48.81624237183602, 53.84015921623477, 52.125934400866115, 54.27236518552227, 54.81825713188418, 51.798361578295314, 51.98475653125394, 51.41813485853134, 54.0093114299159, 53.96630264097645, 45.811012560321444, 34.22779844653222, 16.709391070950417, 5.166259167655822, 1.5317174215470593, 2.5697199808013056, 6.84616667609061, 5.130330747173679, 3.417918802269044, 1.8149760413554408, 1.0339584730325206, 0.2371723790683093, 0.344097982611387, 3.379224620519146, 15.230186831566597, 32.70930970868757, 36.27032564532372, 36.750113887171594, 46.30798078352406, 46.15508679420718, 15.2256525716474, 0.3396990444631346, 0.07957785810914733, 0.0709653138032844, 0.02801502716817683, 0.05815124454637689, 0.017810640255770376, 0.062264841755912195, 0.03685246807553115, 0.04513662879265124, 0.0510271669425551, 0.02617436877992605, 0.03733256771679848, 0.03877609187076169, 0.03262955778008027, 0.09984141230703363, 0.05100934773743634, 0.046036713155767614, 0.033359432728180004, 0.02685581931033202, 0.019863715673226024, 0.027331201765205593, 0.051400925919053056, 0.026271671522408727, 0.01570676842088541, 0.01309850142382446, 0.043269676351619345, 0.05589064548633272, 0.013912498571669624, 0.10847922219263931, 0.015811398794363826, 0.015403908008949892, 0.021417387948942282, 0.05801520648322279, 0.11620364076788388, 0.05353734595701099, 0.05952134683367707, 0.05843413400373632, 0.08334963837818754, 0.036864334777478254, 0.019602372438736984, 0.04234636803307841, 0.03750305292346785, 0.07368886362641089, 0.029306881234890995, 0.07001274475647558, 0.08260684718768443, 0.041221697334079974, 0.022674867650493983, 0.024245621771701885, 0.02022827393375337, 2.4782804616035956, 24.893873391612885, 48.788577895010675, 54.60345245176747, 51.60489851428617, 40.84337388315509, 38.933948393790956, 46.05245013390818, 19.220602281631965, 2.28876746950611, 0.1918844938758881, 0.09288331914332607, 2.4292410285242143, 5.726461391295157, 4.7198282326421435, 3.6752684510523275, 2.233580211477895, 11.446973527631453, 25.87635651711495, 42.80261739607781, 52.08150571392429, 54.74629732870287, 53.72043278909499, 52.679694621793686, 53.759530974972634, 57.55555768166819, 51.448968610455914, 53.817789939142045, 50.53775887335501, 48.269813060760505, 39.19130686790713, 39.69795157832485, 40.85318373095605, 48.330394068071925, 53.55211996263074, 56.60379455935571, 50.916961854504, 48.23457448713241, 53.225649326078354, 54.504600878684755, 50.28850401601484, 47.939067040720296, 41.5510832109759, 38.918690373820645, 37.714860054754446, 39.52330804640247, 37.97507793672624, 37.49887081884569, 38.622724010098366, 39.052380438773866, 44.62870036402057, 51.863429777083866, 51.834408160178896, 52.514158833411436, 49.451929138552764, 52.27787133186094, 49.054820537567146, 48.92634330257293, 48.80361233988116, 50.99344022812382, 53.44916951271796, 56.39970579454976, 43.198623811045, 44.72227242685134, 50.781118408326186, 51.64947625129454, 54.822065753321496, 51.48151251577562, 53.792012122369584, 54.2429474092299, 54.357304111603774, 51.84889739559543, 45.79736663449196, 37.50487204520933, 39.01324695156467, 36.08311091699908, 37.587379101784, 44.03818753457839, 52.79303150792276, 52.63466188984533, 53.67958130375032, 51.77461947164228, 52.366826764998905, 54.25700910629765, 53.73587908283357, 50.46603441238404, 48.60530907107938, 42.048726081848145, 38.96938308592766, 39.002609483657345, 36.942066838664395, 41.470023508994814, 48.90541353533345, 52.7080298239185, 51.54748678207398, 53.203001560703406, 55.56139722947152, 53.20500981423163, 55.30773755042784, 56.43551703422301, 52.5712332417888, 55.59265851974488, 54.435641688685266, 55.66157848604264, 55.06462512477752, 46.86052506969821, 35.38538794363699, 17.190393286366618, 6.029413986590601, 4.177947400077697, 3.6843791363700746, 6.727420351197643, 9.07227550783465, 5.154855366676085, 4.347566375809332, 1.328956011322237, 0.29745799819788626, 0.5646105387037801, 4.142555363716618, 21.371802668417654, 36.79632725254182, 41.17524562343475, 44.75333367624591, 51.74488790573613, 53.26053096402077, 18.078751294843613, 0.6775697741296984, 0.09944626415568976, 0.04442472243681551, 0.05341729997927624, 0.022283766358610124, 0.08555656914869625, 0.04479572349678605, 0.02703960763380653, 0.016070756903519074, 0.02523320103665033, 0.025140759122047215, 0.02644900363990136, 0.05124862380926648, 0.04515779963243873, 0.03187890844269386, 0.044914022794053446, 0.04663748313642798, 0.0693140036216186, 0.024046988579474633, 0.048764530088632345, 0.09713773480466298, 0.06274973710758552, 0.007801307468569928, 0.05816349429228614, 0.11954872538485836, 0.10507631325914014, 0.16089453662355102, 0.09708420058051426, 0.28315890580415726, 0.09141028528251956, 0.15899364265703386, 0.1320756725486248, 0.14046160804648555, 0.226087944822446, 0.2565991890526587, 0.1904544835129092, 0.2199353241632062, 0.17221324055665926, 0.1595681319914518, 0.09779208880518714, 0.09998072539606404, 0.20285960737495654, 0.17488927760672185, 0.16723005311383357, 0.14094453455219347, 0.14000391647700342, 0.16531147783802402, 0.1214359829863233, 0.20019094009072552, 0.062407946980167786, 3.428443992330182, 28.739810297566077, 56.130882232419914, 62.63816495095531, 58.91976979471023, 43.10168243223622, 46.57030497827838, 59.063822761658706, 22.382856338254868, 3.6456981926195087, 0.3174304926107007, 0.8415283406934432, 5.35668533655905, 6.980727997518356, 8.924874797944101, 7.755527505951544, 5.551516327165789, 14.816780782515004, 28.14002302385146, 44.672913320602916, 53.77809163062803, 56.65192988611037, 53.25720871648481, 54.45542612383443, 55.333323171061856, 59.147600666169204, 55.297594301162235, 57.51769112002466, 51.67546195368613, 48.23436660151328, 40.48124105699601, 42.41959402638097, 43.48239160353138, 52.67536824749362, 56.43104945459674, 58.68870689022926, 51.860527223156346, 48.10594820207166, 54.85218955624489, 55.48763705838112, 52.40529737164898, 48.81136686571183, 43.60448714225523, 41.65058197513704, 37.86494954939812, 41.168887461385424, 40.32179278712119, 39.5588957109759, 41.54075168794201, 40.75837219915083, 44.88617258687174, 55.69900181985671, 52.95075785729193, 54.92951123945175, 51.6405136354508, 54.18294299033381, 51.8619785001201, 50.22797399951566, 51.86555962408743, 53.00725567725397, 57.760819235155665, 57.587638747307565, 46.1659792161757, 45.633835177267756, 49.38489975467805, 54.92130956342144, 57.19218538653467, 53.53012723307456, 54.357394326117735, 56.34025835221814, 57.449273217108946, 54.67547501287153, 45.654408008821555, 39.029583623332364, 40.75663851153466, 39.99785600170013, 38.92836293866558, 46.10391947530931, 55.26287348039689, 54.8321109433328, 53.37475038343861, 51.83546720012542, 52.505639445397165, 56.2730485393155, 55.06590773982387, 52.541223187600416, 52.389792242357814, 44.62187151755057, 39.48696728675596, 41.162662659921956, 39.415666441763605, 42.52916543714462, 49.8815228093055, 55.17533794526131, 52.86432843054495, 55.38804807970601, 57.49272523387786, 55.5205810454584, 58.137743319234545, 56.635757953889915, 51.095449309195246, 56.83517517582063, 57.26780868345692, 55.089594933294485, 55.80454887882356, 48.96031495063536, 39.15502886618338, 19.085457017344815, 7.055585451664464, 4.000202253941567, 5.251032373597545, 14.84339112235654, 13.280467814014806, 10.249473914023369, 6.284059651436345, 2.5035618534011226, 0.7545385665951237, 0.7408944793766545, 4.7952882609059735, 21.319699864233694, 43.44290510300667, 47.03068533251363, 48.36475403078141, 60.71639968502907, 59.29458756600658, 22.093069668739073, 1.296571574864849, 0.18283736321233934, 0.18917557633211537, 0.13892924833682277, 0.12724004130089475, 0.20379916824881109, 0.15197728850668477, 0.1369345698866152, 0.15335693624952149, 0.13343668903314299, 0.08591492975791616, 0.1346224705658613, 0.18813018807240073, 0.2927625840229373, 0.15532497016172256, 0.1542436064130837, 0.16504160038405852, 0.11643169748206293, 0.18749315531984453, 0.11279191416237624, 0.16914017077895904, 0.17707984473916794, 0.0927266541628107], [0.024486069958056175, 0.0872738931267973, 0.05826785845021087, 0.04165260646972926, 0.07158493337732169, 0.026692445314819777, 0.03044504657267563, 0.0686287532951082, 0.008709334727046231, 0.03451603014142283, 0.04428909423070089, 0.0628110318024072, 0.028037406511664874, 0.014152147153752946, 0.09388252762296508, 0.03456245506963423, 0.04570230811593994, 0.040201628280262795, 0.08000381831680575, 0.057296903293219306, 0.030508403959233436, 0.08403444437370186, 0.04836686150801759, 0.04146335593935463, 0.013525239210726034, 0.030826504732812607, 0.08013619064924218, 0.621472710082608, 14.275619214580907, 38.931257647852746, 50.369026353282315, 40.91831861003753, 41.078300322255785, 72.13434080923759, 57.61027082320183, 28.314746964362364, 4.185675940205974, 0.27436620826202057, 0.27556838407631845, 1.4583803761389948, 6.0468768688940235, 4.06641137215399, 0.842432385731128, 3.185426929304677, 6.5175500127577015, 20.337836473218857, 36.62576298559866, 50.36421752745106, 44.70421383457799, 52.53090735404722, 56.575529959894, 55.591779908826275, 52.917594217485004, 52.24285633333268, 49.048423151816095, 42.648872252433534, 36.84945967889602, 37.982157814887266, 37.21005493594755, 39.06231188005017, 48.119954985956994, 51.6835145796499, 52.24489596582229, 53.24058178932437, 51.52864763813635, 50.94017836355394, 49.94575554324735, 49.30943335256269, 42.46695664621169, 39.18723152529809, 37.9238360927951, 36.91278242295788, 38.705748819535785, 41.87567110984556, 39.01106611374886, 41.461535499941924, 40.971262762623454, 42.734521127516224, 50.26695059191797, 48.90707269791634, 51.78588451877717, 49.00985056354154, 48.81173164613786, 52.52993068387432, 49.64972249923214, 49.7659933182501, 51.17131187069801, 57.01762422438591, 42.28289942587576, 31.948187505045247, 46.44052943875713, 51.4245440113929, 50.91685987287953, 50.200905722956506, 48.412991339160556, 49.08389314528435, 48.449610587089296, 50.678238561076505, 45.11955753449471, 37.9891239443133, 35.80503056126256, 35.96628312141665, 36.667532305563654, 36.579337812239125, 41.23543047135876, 49.30161606880927, 51.17174333141696, 52.27188579497799, 48.54808169026529, 49.531584632012155, 51.51149903574298, 51.701714377249445, 50.25017461469097, 49.631405030527425, 44.51742664460213, 41.48618367410476, 34.83593448515862, 36.474649752340014, 34.30475927168323, 38.09853453789988, 40.42623373769945, 45.72551665767547, 44.61826685936221, 48.85343428580992, 49.7801060061301, 53.927788888254476, 55.22301435470582, 56.82918571656751, 40.84267570126442, 53.62548789670391, 51.154480980288604, 52.982058371267016, 40.97701687966624, 31.179546117782596, 14.819086155583783, 6.346155183930551, 3.7408088051503707, 4.042875680231279, 3.746102288846047, 5.829628552159956, 4.29294688086356, 4.228982829278515, 0.35667417390692624, 0.04659546704422082, 0.28726489193016486, 7.446623204215881, 21.66712772461676, 32.861285863384126, 37.830248340483635, 31.214135539147165, 47.305635636852635, 33.291720882538826, 9.78662540835719, 0.5218128223092325, 0.03981308763726585, 0.05543533261985548, 0.09855076865923983, 0.01961490180673859, 0.05380151605594063, 0.04057264849243145, 0.039209080935125394, 0.05656243564801351, 0.020125229362278216, 0.05409442594334964, 0.025464952209844224, 0.06374174053029669, 0.0494829903266603, 0.04383746241669982, 0.044515465551446524, 0.10634590481077472, 0.054668949751724163, 0.03583849708159124, 0.01749566129048265, 0.02375821939729635, 0.08161249570548534, 0.06662606922609192, 0.021072060410534183, 0.02564744775994651, 0.05898148850387624, 0.07457391734445289, 0.010089488087912962, 0.03770412802095375, 0.010173007951027924, 0.05910006742323599, 0.028226718329073443, 0.09306996114431851, 0.08443970488564623, 0.028890121743203174, 0.0399375194683671, 0.06076583751447259, 0.044686356784715775, 0.03380116668619937, 0.0955931330099702, 0.020458368441811012, 0.05110068457020868, 0.027685749171782407, 0.02667839143184885, 0.06608284393986387, 0.00233087565697309, 0.037224966837393667, 0.02793898145037313, 0.042710010818536245, 0.03234645764854166, 1.0457280350308265, 16.38166723712798, 48.97339605516004, 57.82892727082776, 46.51025349094022, 39.643705198841715, 63.93098208212084, 59.9134865883858, 30.047465755093484, 5.5834105899257045, 0.19598160870373252, 0.029610405270490917, 2.0455953502847306, 6.709720655795067, 6.13289934973563, 3.2752288589554452, 3.136523553440648, 9.340973554118987, 24.749583121268984, 39.796567809197214, 52.708896667726584, 51.53748866050474, 54.77333814867082, 57.01026978031282, 56.87300251376245, 55.28219507586572, 53.90560788493003, 51.65337116487565, 45.3451055865134, 40.00526535895563, 39.49490616398473, 39.03718517672631, 41.46967834041965, 50.646451673200055, 53.83311463940529, 54.57823553392964, 54.20430029592207, 51.057370939562404, 52.97329579630206, 52.60729943552325, 51.912282897580056, 45.81833562543316, 41.177144050598145, 39.72116416500461, 38.107916847352065, 39.84050227749733, 42.18433026344546, 40.17105217902891, 43.958308466019176, 41.616626016555294, 45.15065016285066, 52.414236453271684, 50.12502354960288, 53.99303359370078, 50.55105570823916, 51.29770632713072, 53.791259027296505, 50.87869128873272, 50.20908778713596, 52.34967031786519, 58.82793534186579, 45.17529049227315, 35.736243955550655, 47.42796651778683, 52.30036220242901, 53.212489774150235, 52.44214411704771, 51.67901169869208, 50.81228948408558, 51.57087979778167, 54.452864816111905, 47.452661760391734, 39.96064839824554, 37.89427711117653, 36.774499262532885, 37.944114746585974, 37.25478564539264, 42.95968086488786, 51.047153165263516, 52.87220062748079, 52.74076200300648, 50.149652111914854, 50.38229573157526, 51.91273397014987, 54.53295177029025, 51.10665944314773, 50.56667066389515, 47.13855443462249, 42.17442627876036, 38.26701210391137, 39.76027411799277, 37.26364235724173, 42.09505319595337, 43.656768414282034, 46.37905805341659, 46.667187521534586, 51.50675296783448, 52.52153288933539, 56.75412724095007, 57.01090520428073, 56.005852760807166, 46.650180124467425, 54.930174120010875, 55.07550185726535, 54.956297105358495, 44.187692596066384, 33.82566921172604, 15.710786023447591, 4.847184650359615, 4.821566670171676, 4.802184277965177, 7.725213958371071, 10.002700936409736, 6.250010046266741, 4.000908280572584, 0.9683296204574647, 0.2461005056337003, 0.3907310415900523, 6.93260443787421, 20.519871711730957, 37.515187878762525, 40.48879946431806, 37.95941983499835, 54.43217431345294, 40.341745884187766, 11.962910332987386, 0.6510144087576097, 0.040626895178349755, 0.12900879276135277, 0.02834945136020261, 0.03364100834474929, 0.11563679699095027, 0.025935466175958998, 0.036944210934903354, 0.038360856894043185, 0.05033721666662924, 0.021151928907080043, 0.06260167912489946, 0.023800762174951456, 0.049385743125552134, 0.03516594083198617, 0.08298086663407665, 0.05786775754043653, 0.04007268802172715, 0.030683727011144645, 0.03815521591252858, 0.05954765812343648, 0.026031255894791216, 0.08685956213382945, 0.1393890849524929, 0.23404565249239248, 0.1914310464335065, 0.2048601693804226, 0.11217645444576779, 0.21664601840799858, 0.13156179609077592, 0.154392886306009, 0.18163235287272161, 0.17240840911624894, 0.23569205205046365, 0.11966340874712314, 0.12386202256405547, 0.10185014080977249, 0.17880230150636167, 0.1676784903411904, 0.3326039977612034, 0.12029359267363626, 0.1994195661597675, 0.12080294155185262, 0.15216547034440503, 0.10342543208671194, 0.09023122234089721, 0.08356323135235617, 0.15183424456946312, 0.12350209147459078, 0.16061822403102152, 1.36077047836396, 19.88815046125843, 57.41291676798175, 66.88429540203464, 52.943423025069706, 52.650135640175115, 79.88740751820227, 66.56976838265696, 34.11003712684878, 5.885607148370435, 0.5642133374367991, 0.7095362330155989, 4.105460528404483, 11.762663529765222, 11.907218560095757, 5.570449117691287, 7.254009823645315, 11.678654205414558, 32.33229541009472, 46.27772362001481, 56.91887463292768, 51.75019487257927, 54.575536943251095, 58.67368029009912, 58.92607696594731, 57.34805253244216, 57.058157997746626, 54.956705031856416, 45.99918042459796, 40.01944472712856, 41.548341474225445, 41.304256300772394, 43.32986239464053, 53.17975367269209, 54.66441000661543, 55.26232434857277, 54.42998170852662, 50.97115724317489, 53.829164812641764, 54.84574902442194, 52.25801237167851, 47.05979324156239, 44.10237712244834, 42.998763361284816, 40.87711411137735, 42.64144720569734, 44.768960399012414, 42.16377312137235, 44.23793423560358, 43.448482713391705, 46.6268341772018, 55.141738922365256, 51.26305610902848, 56.10279413961596, 52.01269949636152, 52.94844758126044, 57.91484678945234, 52.545541717160134, 54.90525530230615, 55.0160308807127, 59.44733642762708, 47.148623158854825, 39.8428713890814, 50.133154622970096, 54.68217442112585, 55.37940317584623, 55.33339377372496, 54.402321154071444, 53.97284515442387, 53.55723865570561, 56.109328808323035, 48.83896858461442, 41.13676324967415, 39.611953612296816, 38.13984101818454, 38.920259321889574, 38.804537634695734, 45.21372579759167, 53.22205643500052, 54.457657952462476, 55.05908281572404, 53.38039859648674, 50.212531628147254, 54.14002049353815, 56.07018355400332, 54.12855540552447, 52.68877883111277, 48.59349489212037, 45.64312727220597, 39.99277653232698, 42.665397197969504, 39.02914824024324, 43.109978245150664, 45.13182670839372, 48.41909454714868, 49.632315020407404, 53.11013944687382, 56.00263641726587, 58.66988343577231, 59.09403677909606, 59.174308084672504, 47.80660075526084, 57.519801355177364, 56.738606422178215, 56.22202634811402, 46.05989871486541, 36.68110762873004, 17.897469151404596, 8.04309166246845, 7.671605454337213, 11.177036992965206, 11.507749672858946, 16.336689418362035, 12.594943411888616, 9.783096255794648, 2.3364556460611285, 0.3880996827877337, 0.9483630402434258, 8.749425218951318, 28.401182274664606, 44.516191097997854, 48.62188892979776, 44.73947594242711, 61.54472189564859, 45.821928516511, 14.456787609284925, 0.814906356315459, 0.14000480513899557, 0.21262693729612137, 0.18362747565392526, 0.16262168184884135, 0.15543680367690904, 0.204292222436878, 0.17664222467330196, 0.1392062504084841, 0.15223644072971038, 0.16821674371678985, 0.2017517216623791, 0.18641445755718217, 0.1208173976309838, 0.11011963860402185, 0.22783798075491385, 0.14075503504324344, 0.154642554360532, 0.16822078866103005, 0.13483429387692483, 0.17848000831661687, 0.25018619042971446, 0.15158051624894142], [0.02913317654371983, 0.07901630033889125, 0.030038010651966738, 0.07765338395632083, 0.023688298552447272, 0.066686934911676, 0.07427648370785099, 0.04190977835547059, 0.04731103913077424, 0.052033427261537125, 0.03601386226833828, 0.00841605903265337, 0.045054914024207866, 0.07761887169533199, 0.06270955962639663, 0.05092884338791332, 0.00675502815283835, 0.0511070430999802, 0.040577382915803505, 0.046065399318092295, 0.05395902756361231, 0.04661482225562777, 0.09843399387694175, 0.011474672731222406, 0.02750972131898086, 0.1320012394459017, 0.08465774883065494, 0.21224695768567825, 9.070095650611385, 32.701563027597246, 48.710526650951756, 47.91483071542556, 65.32789499528947, 77.4741457354638, 63.71554590040638, 25.971742676150416, 7.435254214271423, 0.866686545552746, 0.12469489037269547, 1.6023154268341682, 5.619736150387795, 6.146069197885453, 3.729373870357391, 0.6575976167955707, 13.855140151516085, 24.058900802366196, 29.1113587733238, 33.58278820591588, 54.45128802330264, 57.861981084269864, 55.776029325300655, 53.48884820938111, 52.54312553713399, 46.0347092536188, 42.11173895866641, 39.9200754011831, 41.13898331119169, 39.18040267882809, 38.78149370993338, 40.66231335363081, 48.26554552201302, 52.02330166293729, 54.84509398860317, 52.72898312537901, 50.75694091858403, 53.25556524338261, 49.88395075644217, 47.33885418984198, 43.132402435425796, 38.27597471975511, 38.1043121891637, 38.965021410296046, 39.403742436439764, 38.83633236731253, 37.1256886759112, 35.45245262884325, 37.23984533740629, 43.28377846748599, 49.78302817190848, 50.58196006282684, 50.01825271114227, 49.79194764168032, 52.07142130021126, 53.418688774108894, 51.15610484153994, 51.99875547039894, 52.06566718316848, 51.88253956456339, 33.58202334373228, 31.339408197710593, 47.212522491332024, 53.21321541263212, 50.05930423736573, 48.68802009090301, 46.16781096304617, 42.38683439070179, 40.91635742495137, 38.68410125855477, 36.55920428614463, 36.701445118073494, 35.57683490937756, 37.10557083929739, 35.74479864489648, 36.29725271655668, 37.319030146445, 47.302297699836, 52.047471307939105, 49.72087037178778, 50.467509223568825, 50.2347557775436, 50.77820408728815, 50.73290855653825, 51.760546007464015, 50.03526795294977, 48.66527426627375, 47.49665114187425, 38.68262644736998, 35.65070882920296, 36.828251423374304, 35.75384755288401, 36.44816983130671, 39.25364901942592, 40.41700832305416, 41.5850587814085, 47.70632928417575, 47.745796172849595, 51.03542920081846, 53.59663886408652, 57.22798485909739, 52.52566314512684, 50.37066982638452, 46.862678450922814, 38.83444178488947, 19.92393424434047, 8.949217027233495, 1.0818989070192462, 2.698788267950858, 3.3174377295278736, 6.570212244987489, 8.132039741162332, 4.983821395904788, 3.6982224064488567, 0.9796093151934686, 0.31412047183802055, 1.1071503907442093, 9.113034817480273, 27.488485959268388, 34.482015102140366, 29.464723140962665, 42.722785395960656, 48.38002381786224, 29.594847771429247, 4.279299484145257, 0.167767800871403, 0.01821066264153248, 0.03698628448370484, 0.047432161462042606, 0.014988777411711073, 0.008033641347391231, 0.05976883919849511, 0.051981440534995454, 0.033705907483254714, 0.0050321093388652855, 0.0743506716624383, 0.11489340825186622, 0.04441635675668236, 0.03344209744564949, 0.025349623418503234, 0.05716277278899666, 0.04392725175186511, 0.043688940950819564, 0.10631254934255155, 0.013763687907597952, 0.019153548336978403, 0.06414665247223551, 0.039529378465827436, 0.06332109697283277, 0.036886907558167176, 0.022283170725248998, 0.06799380430170605, 0.046472793384905786, 0.0688287022433454, 0.06532705223728573, 0.03284256852742645, 0.06791381706153193, 0.08140302428434934, 0.05792236428767924, 0.010808148466411137, 0.005263844711495744, 0.04077424069926624, 0.05904837181010555, 0.06610252473863863, 0.05014659483887015, 0.0427100912577683, 0.06264106753552634, 0.026356050361608787, 0.03431150764827767, 0.03683884703223744, 0.061891017661940675, 0.06394285010173917, 0.06552661814156079, 0.06051629203401747, 0.06542508084807666, 0.3029216759868207, 12.574146024642452, 40.06531292392362, 56.32231743104997, 52.7002086177949, 64.56315440516319, 78.3437430474066, 69.479610073951, 34.36543049350862, 6.976219233005279, 0.7981274985978681, 0.04535902028663024, 0.8627559016308478, 4.393377698236897, 10.666175734612251, 4.880980772356834, 1.8448680567164577, 14.714073519552908, 25.294902401585734, 33.262412932611284, 40.45760093196746, 54.45775601171679, 58.62893781354351, 58.64748277971822, 54.98871549483269, 55.17220004912346, 48.21048721190422, 44.579125527412664, 42.35117220109509, 43.03315470295568, 40.811720355864495, 40.80313036518712, 43.06965627977925, 50.80097344613845, 54.13968709207351, 55.91350839984033, 54.5511947139617, 51.33635736280873, 55.10600220772528, 51.667805487109774, 50.74451092750796, 44.86123023494598, 39.85202227869342, 38.53376073222007, 39.91639621796147, 40.77360276252993, 40.66931086201822, 39.17732361824282, 38.451630223181944, 38.69080851154943, 45.209419035142474, 51.29575298678491, 51.51297776929794, 50.56054784405617, 50.14008937343475, 53.729022779772365, 53.09426561478646, 51.47689588608281, 54.32618402665662, 52.71775337957567, 52.08840124068722, 36.72776814429991, 35.67686319351196, 48.66754924097369, 54.07096324428436, 51.28990865522816, 50.27423835569813, 49.2175361417955, 46.544927243263494, 44.19645124866117, 40.78931185507005, 38.98555109577794, 38.30699674544796, 38.804984784895375, 38.04002061966927, 36.741998503285075, 37.986546947110085, 39.90737476656514, 50.005548154154134, 53.277738401966715, 52.20091835145028, 53.12319309480729, 50.85469030564832, 51.67546195368613, 52.873722507107644, 54.76325373495779, 50.82831236623949, 51.38167642777967, 48.724203955742624, 39.0908000546117, 37.464416719252064, 40.067230962937884, 37.52315029021233, 38.08557502685055, 41.353266316075484, 43.201008612109774, 43.70885749017039, 50.88218219818608, 50.05380507438414, 52.377472077646566, 56.39534804128832, 57.941189427529615, 56.76896556731194, 51.61335122200751, 49.92512779851114, 39.8315514287641, 23.352815335796727, 10.337930225556898, 2.3357133375060175, 3.7928003120806912, 5.6762594657559555, 8.870015548121545, 7.017475212773969, 6.226784221587643, 2.9885482163198533, 0.658189220534217, 0.1608204559212731, 1.0161906877352347, 8.784759890648628, 28.960959411436512, 36.69890342220184, 35.64393489591537, 46.252577304840095, 55.33542948384439, 34.358483975933446, 6.551491752747567, 0.19352618965410417, 0.04185753498947428, 0.013157630005040237, 0.021579511305918137, 0.04427631205368427, 0.027172929915269057, 0.05004626030342714, 0.021941139280135115, 0.05393153266800989, 0.04899357505623372, 0.03315625854978158, 0.15379477082000625, 0.045720510365020846, 0.0939659316152815, 0.048427294353924455, 0.06146037282662527, 0.01096820434360134, 0.053858773467401345, 0.013830630585641391, 0.01172788585761502, 0.06664268567316955, 0.02300621025384434, 0.06214782182547835, 0.13028730157642596, 0.25730726879931265, 0.07754502081943136, 0.15847449551426596, 0.1757977353108506, 0.24348731843694565, 0.13977015240778848, 0.12652463009280543, 0.2369606936530721, 0.14026090833208255, 0.1714193589624859, 0.10559660187291522, 0.14710431047264608, 0.21183218236171433, 0.09602946604812339, 0.16578013978658185, 0.18480941142526366, 0.11372038974396645, 0.1986234782323722, 0.11437920237620992, 0.09758720625071757, 0.27129251029222246, 0.17608589162268948, 0.11957350832920884, 0.21780860279836964, 0.2001083558124881, 0.17345344497551843, 0.49735353478500927, 13.713898543388614, 47.03977738657306, 66.58488519730108, 59.76020036205169, 75.0367456866849, 81.8608460887786, 70.65397554828276, 34.17051223016555, 9.370354067894722, 1.2988377242319047, 0.5343045294284821, 3.2037041937151267, 9.508249894265207, 14.59030116758039, 10.44563066574835, 3.5892219456934162, 18.696240225145896, 28.560816857122607, 34.5244865263662, 42.00719602646367, 55.09009307430637, 58.36251081958894, 60.65970182418824, 57.03233703490227, 57.98020524363364, 51.267562912356475, 45.10106748150241, 44.94097594291934, 44.35209481946884, 42.06133650195214, 42.72679013590659, 45.89693992368637, 53.488734460646114, 56.435140486686464, 57.625430783917835, 54.97843104024088, 50.454192776833814, 57.51967976170202, 53.95289990209765, 52.19032402961485, 47.39127666719499, 41.79438391039449, 41.37448241633754, 42.99748859097881, 43.68064780389109, 41.71108453504501, 39.67675508991365, 39.07456928683866, 39.690075459018836, 46.41494381812311, 53.14860613115373, 52.55126837761172, 50.648534451761556, 50.580108704105506, 54.894429560630556, 55.110540390014656, 52.5703977769421, 56.715291853873964, 54.967668056488044, 53.07493225220711, 37.29445257494527, 40.85078324041059, 50.93680904757593, 56.09372169740739, 53.85846491782896, 52.48641198681247, 52.11264148835213, 47.07916975021363, 45.980341280660326, 42.23136732655187, 40.693637401826926, 40.87516469340171, 39.489191270643666, 40.334995485121205, 39.6522795000384, 39.889896685077304, 42.47338148855394, 51.287621913417695, 56.257821898306574, 53.7465714639233, 54.36451735035066, 51.6756933735263, 50.68516938917099, 53.73301967497795, 56.53788697335028, 52.44618808069537, 53.52073315651187, 51.774129175370746, 42.714120880250015, 37.94748014019382, 42.01942989903112, 39.79039792091616, 40.73658343284361, 43.354369363477154, 45.45000153203165, 45.15017947842998, 52.454205405327585, 52.95471945116597, 54.68130365494759, 57.828142796793294, 60.43391450758904, 55.38742442284861, 55.223214395584606, 51.6744460598115, 43.03954816633656, 23.730164997039303, 11.113811327565102, 2.2016190232769137, 5.870797749488585, 8.969337805624932, 16.04642814205539, 17.951448809716013, 11.700204687733805, 8.374675108540444, 2.62979255087914, 0.799028356709788, 1.7605938498050937, 11.992190826323725, 33.45790778436969, 45.91695185630552, 40.57077700091947, 56.06829297158026, 60.59301368651852, 39.50859915825629, 8.247114727574012, 0.3834174453250824, 0.13792942698684432, 0.14092588797211647, 0.23181537136195168, 0.1224591317135961, 0.060339241453837004, 0.1978991574217235, 0.1379208161585754, 0.2223544612887406, 0.16363901596876884, 0.2016390760939929, 0.23144518235518088, 0.12695208417191622, 0.2128655277192593, 0.18707117876939236, 0.15941454668439206, 0.11077358657794614, 0.08702620157911893, 0.2073020439955496, 0.08973911044097717, 0.1354993348039927, 0.10399219159397388, 0.17890661203813168], [0.001958086978711729, 0.060962316084412806, 0.029742892516115983, 0.029066818007718653, 0.013686228757573953, 0.02257710525525674, 0.015515197601710117, 0.04592956043779851, 0.06491734075450128, 0.030499961670307867, 0.032406653007192, 0.11718995598775726, 0.050021553967869094, 0.024536294682372003, 0.027170047509453954, 0.03473343057257514, 0.021426146249136618, 0.06777316331863403, 0.04947886877362767, 0.019791944726039807, 0.06507698581704209, 0.07436512008069024, 0.06540288728091025, 0.0542266603799597, 0.03417089987065523, 0.07120526786292754, 0.026990430534727154, 0.1268850897829379, 2.976770074136796, 24.14275715428014, 48.23150719365766, 47.13589114527549, 57.68903201626193, 65.5354001445155, 30.818333087428925, 29.655926919752556, 13.156548373160824, 1.307891780330289, 0.09963445365428926, 0.8626635420706965, 3.106491435920039, 3.61323150896257, 3.70277603307078, 2.052425912791683, 6.202858744129059, 8.66263101177831, 21.86313444568265, 43.248610496521, 54.592120724339644, 56.56926201235864, 57.43245017143988, 52.54249403553625, 51.739027884698686, 47.08875994528494, 43.818205325834214, 42.710465231249415, 43.24991664578838, 38.25973218487155, 41.447430656802275, 40.41759667858001, 47.09767157031644, 51.02983982332292, 54.940462496972856, 52.96603941148328, 50.33286602266374, 51.07649249415244, 51.65634824383644, 50.265887629601266, 47.16026475352626, 43.01921852173344, 44.43355068083733, 39.49294890126875, 39.489136357461255, 36.62243289332236, 37.336245429131296, 37.59513362761467, 36.181197627898186, 38.68791380236226, 50.33869858710997, 51.90772902581, 51.11161339667536, 47.70660385008782, 50.3966280721849, 50.20471042202365, 52.57586948333248, 51.2969296978366, 52.15085321857084, 45.20603010731359, 52.846265915901434, 41.27639570543843, 44.146291978897594, 53.122412543143, 46.02158500302223, 48.283168731197236, 40.75126486439859, 39.84699380013251, 36.80324631352579, 36.900705445197325, 36.635796408499445, 36.308027467420025, 36.91224898061445, 46.29537036342006, 37.78190905048002, 34.587060097725164, 37.389052298761186, 40.57202431463426, 50.1139977670485, 50.85725945811118, 52.62200832366944, 51.91546393978981, 49.919024590523016, 52.192347972623764, 51.75189718123406, 54.52633865417973, 50.83381545159125, 48.825146152127175, 42.16220025093325, 37.64612443985478, 38.760254075450284, 36.0208942813258, 39.16045350413169, 37.73048285515078, 39.59017661310012, 38.85040190912063, 41.49240455319805, 45.84505873341715, 49.65380568658152, 52.563204150046076, 54.34645091333697, 55.04529960693852, 48.76467497118058, 46.73012979568974, 31.768372328050678, 17.29722688274999, 3.8540272847298658, 1.7865997769178885, 3.1502964660044643, 3.5355612251066395, 4.9855428261141626, 5.669585062611488, 4.384244459290659, 1.591316978296926, 0.6563017637498918, 0.019519267220711036, 1.7757116450417427, 9.501991752655277, 27.21060564441066, 40.90705748527281, 33.02903582972865, 40.41026576872795, 41.450858808332875, 20.09341789830116, 2.2130086056647764, 0.03420821218300731, 0.03892985337804403, 0.07992904813539597, 0.07817824611500387, 0.017108359794703223, 0.03363133648470525, 0.040930070643944126, 0.06780543860288397, 0.06388482277191455, 0.04278281215398062, 0.04988184634355768, 0.0921523486894946, 0.050979301769046054, 0.06005312293587674, 0.029810601282083703, 0.03574770800168476, 0.06801008367009702, 0.018679606127402475, 0.028346913693953427, 0.048301973860831036, 0.05226901462001186, 0.056346548240511656, 0.08389206693297432, 0.02017079627201442, 0.03365014011280672, 0.036097427139118794, 0.06346479974566929, 0.06777625065296888, 0.018908798566929275, 0.029506655898125424, 0.016917849049693155, 0.01144853285363605, 0.0700427447595904, 0.034549397100964864, 0.0352642375735506, 0.03184428892939562, 0.026677426161064256, 0.06033321617231254, 0.0431793392635882, 0.025151032361111818, 0.050855816056531285, 0.015725813366683022, 0.03319610661316303, 0.07459469364895936, 0.05972631748825793, 0.03466601866567808, 0.032022168799754114, 0.03124386560352099, 0.06060437299311162, 0.09523871009268108, 0.2207825867639434, 4.125121408893216, 30.528701351534938, 57.015513989233206, 54.01101766094085, 64.85462965503817, 71.94754969689154, 47.297363358159224, 31.48742864208837, 13.538908862298536, 1.5291298829740094, 0.09844206844366367, 0.5912895200233306, 4.962544989201331, 5.914907253557637, 4.135450970742011, 2.0759151491426655, 7.2977285615859495, 12.402421716720829, 26.168612318654215, 43.13422633755592, 56.7034423735834, 56.8138570939341, 59.4486229650436, 54.822920830019065, 54.138176979557166, 47.08093873916134, 45.440921245082734, 45.30476008692096, 45.2900472764046, 39.09984111785889, 42.03152256627237, 42.04363484536448, 48.71120914336174, 51.91755456309165, 56.392527857134425, 53.55262987075314, 49.88035002062398, 52.522289906778646, 52.60077653392669, 51.10265078083162, 48.266788913357644, 44.23189378553822, 44.302429768346975, 41.549941801255756, 40.206773204188195, 38.37162956114739, 37.2080349153088, 38.64590914018693, 36.72835257745559, 41.58822805650773, 52.041034698486335, 54.2563226915175, 50.72982949595298, 48.218167212701616, 50.83978137662334, 49.259191713025494, 53.499952439338934, 53.22832830490605, 53.68622579882222, 47.66338325315907, 53.37626834069529, 43.05049550148749, 47.061068011868386, 55.05358757511262, 49.35068884203511, 49.86346813940233, 43.56320811856178, 42.530530421964585, 37.762748272188254, 37.62186850270918, 38.273723279276204, 38.93170872042256, 38.062209467734064, 46.03854140927715, 39.59025113813339, 37.95314404272264, 37.4754346570661, 43.4858746682444, 51.585243517352694, 52.38013536699357, 52.62189849730461, 53.617168549568426, 51.18836633620724, 52.60968423658802, 53.593799068081765, 55.02454634635679, 52.08792663389637, 50.468097579094675, 44.083075138830374, 38.93012408287295, 40.2771326803392, 37.8861342706988, 40.866225611779, 38.4659743309021, 40.11107521672403, 41.4074852389674, 43.541866502454205, 47.17209069959579, 52.05334701845723, 54.834687940536014, 56.75603351285381, 56.544959006770966, 51.8108033364819, 48.94740643039827, 35.535944200331166, 18.805560604218517, 6.2732182202800635, 1.884378091462197, 4.512263757567252, 4.602689589223554, 8.101639901438068, 7.636892968608488, 8.099138409860673, 2.683214497181677, 0.6401962053871925, 0.2341820161429144, 1.6009966524377948, 10.304836207820523, 30.368735328797374, 44.26871307434575, 35.88296413421631, 47.54905008500623, 50.10185018662484, 24.659911855574578, 3.2722314326993884, 0.034709674186043205, 0.08310127267313581, 0.06203561675764861, 0.06602759367876476, 0.06763557392743326, 0.013100652215671877, 0.04369190954152615, 0.05749130959532434, 0.007566614517746794, 0.01999562643768807, 0.06022223684516165, 0.08202265918014512, 0.016165730738711935, 0.02481598189220794, 0.015236733259723313, 0.05973359915397822, 0.037568331275495796, 0.04939932586444963, 0.1102551672187063, 0.04452093541922589, 0.03817837092003996, 0.012645242630594201, 0.04780521946808985, 0.12143191505944538, 0.08536099456250669, 0.2867542177198395, 0.14472318662991449, 0.12119385323697522, 0.12307859807004853, 0.10810971500412112, 0.1229976072546936, 0.13995479491929855, 0.28795388076574574, 0.20085985742269025, 0.17270339893237238, 0.12977059059325727, 0.11807897804124702, 0.1630498637114802, 0.0872338190674782, 0.10919112471803542, 0.13651717454195023, 0.12275170069187881, 0.1149520369607114, 0.15757311646255756, 0.1616468809304699, 0.11108011367820925, 0.2277055547963227, 0.1297727969264792, 0.10260954844735323, 0.23091786871514014, 0.2771285068123572, 6.064307391643525, 36.663966871077015, 64.89320224331271, 61.31465135082122, 67.97185882445305, 72.25267871733635, 42.484387659257465, 39.707424102290986, 17.537697592089255, 2.0009519135759724, 0.4178032405193775, 1.9191508836323217, 8.179067978935858, 12.269860313784692, 10.29060879061299, 3.699753111408603, 8.530419680380053, 10.489962274028409, 26.20479226112366, 45.91599479798348, 57.48648866530388, 59.15861075924289, 60.97394251054334, 57.11117275299565, 56.8798392049728, 49.53726422402167, 48.61172606868129, 47.165775683618364, 46.776817767850815, 41.77818844395299, 45.74226125594109, 44.108190075043716, 50.437220681098204, 54.45522608295564, 59.59177378685244, 54.77443248994889, 51.27689030862624, 54.80380712016937, 54.81904552828882, 54.337711872593054, 51.19898811463387, 48.11887633415961, 46.31778670895485, 43.234505653381355, 42.84552812576295, 39.93643560717183, 39.82283984461139, 40.89540804586103, 39.07311016513456, 43.77696944821266, 54.30770966314501, 56.524029239531494, 53.433664383426795, 47.974580180260446, 50.166353564108576, 49.800827887750444, 55.0899048005381, 53.615152451299856, 54.2192013802067, 49.61649217913228, 53.77418494993641, 44.694274548561346, 50.21348476409913, 55.46340465545655, 51.43286335852839, 51.61286484810614, 45.50715438781246, 44.353079334382095, 39.55680508767405, 38.99059526381954, 39.496584938418486, 40.969999759427964, 39.063457212140484, 47.416328845485566, 41.65989760429629, 38.14291223402947, 40.67268410036641, 43.62668775743054, 53.68205631932905, 54.790133737748675, 57.23892042713781, 56.209537521485366, 52.21476431815855, 52.58517726775139, 55.2406846323321, 58.76038428275817, 54.31799411773682, 52.814584932019635, 46.97849819737096, 41.533793403256325, 43.99099749903525, 40.4644533126585, 43.60357323000508, 41.09154224395752, 42.27010465437367, 42.965627178069084, 45.77189084022276, 49.11526426192253, 53.13482292236821, 58.061135507399044, 59.063073588955795, 58.2559714009685, 53.12811959174372, 56.87178265663886, 36.72700328211631, 20.420416093641713, 5.669516911429744, 3.208804010383545, 7.545562540331195, 9.31903475715268, 14.259137415116834, 14.317861180151663, 15.32697327675358, 4.7548442117629515, 1.358502735534022, 0.45833054809801044, 2.4912252637647816, 12.015519122923575, 35.224256976958245, 52.44889451611427, 45.23936633140811, 53.91404882554085, 54.32486218790854, 27.562738387815415, 4.133882022673085, 0.2814027258465367, 0.11112299161933123, 0.2064457109137889, 0.3149370296347526, 0.07709930320420573, 0.1275318978174079, 0.08727930936842196, 0.2887541974984831, 0.12375357515749433, 0.09535556148377158, 0.1387017815103454, 0.18247910985542884, 0.09511694807799594, 0.18861878362874832, 0.08389968950782092, 0.2245198547719948, 0.14729046983824623, 0.07699444108913023, 0.22885542212715074, 0.15968252424030535, 0.21157021093512737, 0.11913533668003737, 0.1396093658742405], [0.033633795626942194, 0.04266622123278437, 0.0262364448844305, 0.017040677841812853, 0.01795877293202906, 0.08589651300421647, 0.11343211085805971, 0.013827226282427869, 0.012650889656206053, 0.07595351146113488, 0.035322655608216603, 0.06878002501663662, 0.05472326921599527, 0.039378240809685765, 0.06937196583396966, 0.019506833613699964, 0.03356719960368449, 0.009420116848853088, 0.06409246707335114, 0.02017426665031141, 0.07082829897802684, 0.08240629302998705, 0.054044771954537406, 0.062275199264648466, 0.041195355400803595, 0.06270051978889012, 0.08994419217830704, 0.04067815795180298, 3.340674585873081, 19.013165773883944, 39.487030044678725, 49.021394098958666, 41.60670634238951, 40.97958995449928, 27.098051271130963, 29.84913895207067, 13.881307263528148, 3.139651398504934, 0.16652277009862085, 0.18411268510164755, 3.4556355784016275, 4.688379649193057, 1.969399632465455, 1.743026902118037, 1.380392257725039, 4.410936188313269, 18.54153802317958, 31.015836192715554, 49.393077896487334, 56.85183348194246, 55.839406982544936, 51.45413044960269, 52.04706730381135, 47.96652755429668, 44.03551640049104, 41.126082635694935, 41.46665811538696, 38.97072061415642, 42.95886108952184, 42.6750462285934, 46.675267604089555, 49.59051432148103, 52.53114661862774, 51.40895258995795, 51.03999876206922, 51.56251730457429, 50.944802837987105, 49.50742283175069, 50.37035603677073, 49.18062663847401, 50.933675073808246, 47.0025933173395, 44.18707286157916, 38.26004205211517, 38.23299730977705, 37.24968656416863, 36.78060639289118, 36.280304155042096, 47.04456267818328, 51.16675799892795, 51.64123535156251, 50.20291005411456, 50.733414542290475, 52.566502863360995, 52.47258170958489, 49.89780064552061, 53.44914597849692, 51.1759755688329, 49.16358394007529, 38.0905838935606, 44.7512665871651, 53.19093635005336, 47.48580971071797, 47.86805252875052, 41.221054984677224, 40.14520375959335, 38.103912107406124, 38.00848476348385, 36.23756208727437, 37.1002991737858, 39.008955878596154, 36.92523987062516, 36.269321518559615, 37.194173259119836, 36.520466958322835, 37.33859100649434, 39.206031445534, 44.67679646707351, 46.865314283678615, 49.19091893780617, 50.851866199124245, 51.82164869000835, 48.76939750486805, 50.42332372357769, 53.534943903646166, 49.71194697964577, 44.850467251193145, 37.322979973208525, 38.1627005915488, 37.68140223718459, 38.68174391408121, 39.36889609982891, 39.49786363109466, 39.8557799093185, 41.556327419896284, 42.06376052671864, 47.29452356215447, 50.24224750457272, 54.56456607387912, 54.54428349771808, 54.30694872333158, 37.228529299459154, 24.175267719453384, 11.076945950908046, 4.486658525082373, 0.9731489263715284, 2.627496003143249, 4.381757186305139, 5.674171293935468, 4.21751578007975, 3.673186407935235, 1.8338188625151113, 0.8630313868484191, 0.24410398857247448, 2.764741696657673, 12.157722692335806, 30.66795922094776, 31.460789865063084, 42.35086625622165, 41.14703593715545, 31.735595041705718, 9.497498677622888, 0.649731242127957, 0.023382834399179108, 0.054400834299984484, 0.03194675127404832, 0.030161971338994564, 0.07221014539320623, 0.03037424664193344, 0.023361115806525754, 0.01136941416564608, 0.010462356487198943, 0.04925942671815715, 0.00209155697150216, 0.025826838738735647, 0.03253375082426975, 0.05720716758420872, 0.04225266781905967, 0.04162539119621919, 0.037113010748139316, 0.03909618255772418, 0.011583051189870365, 0.017772389485711054, 0.01986566536699332, 0.06586905944371416, 0.07352703521328588, 0.049548149935059974, 0.02630727545868966, 0.07015073251339697, 0.04025737649851269, 0.039259186915812955, 0.03263510425665206, 0.017718585215569023, 0.049390623105629805, 0.10516586893748854, 0.043332104856568965, 0.04154244302621773, 0.03564175038087753, 0.025822456715808764, 0.03837336327940707, 0.04674845480269963, 0.044271458886683955, 0.014215860771195543, 0.04227881823035498, 0.08713471793359326, 0.08867514454909871, 0.04315338037427395, 0.036354058932873516, 0.07414951995615998, 0.07883084577418144, 0.049031354682219606, 0.04493006467518788, 0.020287659154423786, 0.06741723120813409, 3.797817268679219, 22.123267996695734, 47.94047517161216, 55.701327785368896, 49.45756558449038, 50.05691159156061, 28.25553878661125, 34.402018362475985, 16.300643817070995, 2.9327667192105324, 0.1410384262881933, 0.441343528969634, 3.3801186757702983, 1.762170274892161, 3.396527421089911, 3.298742977842208, 2.655588753761784, 5.959307013019439, 20.44469556500835, 34.80353178516511, 50.39385887884325, 57.99867568477508, 57.762105772572184, 54.73068629541705, 52.8983118457179, 49.74631870946577, 45.37963813351047, 43.997940094240256, 43.03641419256888, 41.901248885739236, 43.020442301227206, 44.997340402295514, 47.66131616407826, 52.590998065087106, 55.03403455980363, 53.57537177301223, 51.43143169341549, 53.024651388968195, 53.82068072595904, 51.22928057947467, 51.23399134605162, 52.301880159685695, 52.97604145542268, 49.47019561644524, 45.082875528643214, 39.9721448652206, 39.348362491976836, 39.25973261556318, 38.57918177881549, 37.191054974832845, 49.544783407642, 52.25098740669989, 53.43795153402513, 50.6032742223432, 52.47904577562886, 53.81003933568155, 54.522161329946215, 53.29021153911468, 55.19580487282046, 51.956888091179636, 50.928364184594926, 40.94722255583733, 47.74654926792268, 54.99636411666871, 48.83277123974216, 50.549533828612304, 42.78476276705342, 41.23146103274438, 40.28061182268205, 40.4280262608682, 37.798457530237016, 38.33420622733332, 40.65382534457792, 40.23770109299691, 39.29353167933803, 38.207046908717004, 38.1341653485452, 39.40000441766555, 43.25635717761132, 48.83811743028703, 50.75717626079437, 52.44886313715289, 52.62135328785066, 54.22746973652994, 49.63801030189761, 52.757067295812796, 53.859633784140314, 51.69682710401474, 45.93931721102807, 39.055985096962225, 38.61968417321482, 40.367708052358324, 40.51213756684334, 41.10378396126532, 41.07239323277628, 42.42719165740475, 42.821538909789055, 44.38510548683905, 49.1869887228935, 51.30715139450566, 55.67131380881033, 56.198680400848396, 53.72327650746992, 42.620721401706824, 25.545885062986805, 13.42073961611717, 4.010725727965755, 3.336673768297319, 5.56018574583915, 8.927850896312345, 8.448346045709426, 8.579965099211663, 4.328680653725901, 1.4995727399664542, 0.46787171354216917, 0.34294367197059816, 2.7337588946665488, 12.949522733688356, 33.538139866244414, 36.48670711824971, 45.987354478528424, 47.471614653064364, 38.34379250003446, 13.435675021140808, 0.6434539176764027, 0.0387860088789415, 0.0549940774667888, 0.024128439047584133, 0.04280246613967804, 0.06614681994242054, 0.01128185031590082, 0.054258698176953106, 0.09927085300366725, 0.08294908164609825, 0.057500165571729024, 0.05260526593173704, 0.03284676668925151, 0.0343313071906807, 0.046885933111151384, 0.040834485853631655, 0.0629390144510375, 0.04147996472555303, 0.016868738983307156, 0.013448563385604611, 0.0362946373230267, 0.057860958510108536, 0.04923038049450806, 0.09663791606022466, 0.15600424500242357, 0.19806021974692423, 0.08105004927323711, 0.16938344966019356, 0.12271138914530316, 0.23406932460925273, 0.1784632463128336, 0.14552324289275756, 0.11989171060943797, 0.12905894087687617, 0.13900732801806542, 0.2571119776656551, 0.178161530244735, 0.07604497469841473, 0.10911496025660347, 0.10840696477962118, 0.13865604606126586, 0.10550391289495653, 0.15936194708751095, 0.1576781624387349, 0.15956065497331082, 0.12661852182880526, 0.15704862202607817, 0.24177678199785374, 0.2638166566048899, 0.16378883212324113, 0.18969784911361434, 0.22482524806212997, 4.5163253718806855, 27.0681510433074, 57.16424634379726, 63.477520788869555, 52.72477442218412, 50.74181625919958, 39.19919083195348, 40.89282320391747, 18.617512372232255, 4.380761884873913, 0.3321133337674603, 1.4725137790364604, 5.321107968207329, 11.921360665752042, 7.333735429471539, 2.621533755333193, 2.6928284716221595, 6.408818969803472, 21.873318879835068, 34.811851132300596, 52.257879011092655, 59.866610342456454, 59.637088929453206, 55.72047287417997, 56.314154978721376, 52.167315406184045, 46.802093521241225, 45.33599392060311, 44.61965930077338, 42.938417696183734, 47.13615002170686, 47.30331359371063, 51.39984092404766, 54.48061166271087, 57.45281903974472, 53.32648561846826, 51.19154737841699, 55.2659603857225, 55.628489371268984, 52.47517831863896, 55.069273133431714, 53.62953186035157, 54.49272001943281, 52.591162804634344, 48.750374009532315, 42.56028944446195, 41.65537118911743, 42.24123600990542, 40.231052675554835, 39.11744863756242, 50.894223874615086, 55.27272255189958, 54.67560052871705, 51.035264461271225, 53.4337624426811, 56.225317216688595, 57.65176165488459, 55.87563399345645, 56.86342800817182, 55.18755220597791, 51.28511944124776, 44.32923132373441, 50.19087622242589, 56.364145586567545, 52.319515135980424, 53.10289090679538, 45.95635206468644, 43.92587046469412, 42.4848073528659, 41.25920787934334, 40.68409819756785, 39.91411732089135, 43.647068392845895, 39.8367368021319, 40.243141420425914, 41.19056247895764, 40.16542357783164, 40.36572333305113, 44.55952152129143, 49.36046338850453, 52.57816799225346, 52.507263306648504, 55.74072014900946, 55.746564480566214, 49.054126278046645, 52.62485988678471, 55.60673198392315, 54.13196002283404, 48.604787395846465, 41.761761557671335, 42.20471089886081, 42.18985688301825, 43.00270142093782, 42.55788503154632, 43.89440913354197, 43.09803855034613, 45.86086980758175, 46.74273629342356, 51.731273358868016, 55.283764023934644, 58.95944064663303, 59.1878245722863, 56.518396715964045, 42.623498439788825, 30.223892004259174, 14.196388317692666, 6.309254505941945, 3.1280031848338345, 6.853240670696382, 14.089520400570287, 11.844004661806169, 15.358162003178752, 11.336740216901227, 4.5981896500433646, 1.705884508067562, 0.8042247617436994, 3.6009388008425316, 17.230681911591564, 40.000017227665076, 42.19339093854351, 54.650756236045595, 55.41853274068525, 42.75437224295832, 14.608462722070756, 1.2966031989743634, 0.15800148218629823, 0.18896880920135206, 0.09927037036827496, 0.15451699254974244, 0.13265052960524637, 0.10612756975235478, 0.15955314731165288, 0.18330637756134235, 0.2266261675545285, 0.23551415111268723, 0.12460142764593325, 0.164721115161815, 0.1121567506643553, 0.08832121958896037, 0.09845712973225502, 0.17782627484731137, 0.13025785315661662, 0.06712453199490424, 0.0581501528710848, 0.10926788672804834, 0.11895916710096983, 0.17273027329675614, 0.18866424328617512], [0.041124166680439826, 0.045245899743730986, 0.03628768507511385, 0.04808223686150966, 0.05902085010142577, 0.0367094777644642, 0.03490825566733557, 0.027698274709344394, 0.03044080627601474, 0.04378667461775965, 0.0231658112663295, 0.021741205653656396, 0.04219170254204543, 0.010061853381264354, 0.028730151093294545, 0.05230076513403366, 0.04396302805792901, 0.061540892497906764, 0.13652342581941238, 0.0646696645285814, 0.028856019339253827, 0.017201537153713645, 0.021224921764505487, 0.10299061590264882, 0.03139720001678554, 0.07235097533632671, 0.03516685630705568, 0.01983819345402862, 1.0877884684070465, 11.62261236098505, 36.99376367753552, 50.593354548177416, 40.15705323988392, 31.84492522670377, 30.51940141185638, 27.837278804471417, 17.67834201935799, 5.549433058308018, 0.2645562685305073, 0.20495430626455816, 2.334778342516192, 1.8703423800968357, 3.576665948475561, 3.103242977972954, 1.0400215993004462, 3.0170194756600166, 10.248071666686766, 24.539928513188517, 42.02958491540725, 53.399881009132635, 57.82931950784499, 55.35939908796742, 53.67764757525537, 48.95818510363179, 46.67253371207945, 44.01921895242507, 44.5561678947941, 47.37783078224429, 48.59720545430338, 47.04284468004781, 47.152737725165586, 50.21080578527143, 52.615085340315304, 53.07536371292607, 50.59912827707107, 51.35888745707851, 52.62682107187087, 51.020622253417976, 52.97096590841971, 51.200266807310044, 52.64516599716679, 52.652438071466264, 51.50225400924683, 47.15982937043714, 38.89672902322585, 35.77507934262676, 36.721374680919034, 34.98208199777911, 40.49692269294493, 49.425398226707216, 52.21503496170045, 52.34303758990381, 51.3257630409733, 48.574051703176195, 49.751100078705825, 47.35057030954669, 49.12081833808653, 46.98361689044584, 56.75883408515685, 40.97205508139826, 42.56066206962832, 53.55215526396229, 45.42477676945348, 48.17733926157798, 40.26542048300467, 41.31424657760128, 37.89525378134943, 40.34482102240286, 39.50353537836383, 43.46220316425447, 37.99798065616239, 36.14702986132714, 36.846615960521085, 38.34215294930243, 35.676678842113866, 36.62179354698428, 37.28061837534751, 37.56764957981725, 43.850290313843765, 48.03053279076853, 47.9150660576359, 51.282785630995235, 51.10163488695699, 50.64017588092435, 52.67808252765287, 51.01562123144827, 46.107210343883885, 37.52073018781601, 36.532108552994266, 38.2358096491906, 41.920127253378595, 45.83369562702794, 43.75176037511518, 45.91394339838336, 43.22196975831063, 45.23883288906467, 46.08160118902884, 51.16574210505332, 52.61868999850366, 56.36672258377076, 49.01411025754867, 39.476996621777936, 18.145596327320224, 7.332991650027614, 1.5572954425888679, 1.5672294579205976, 4.207834880198202, 4.1713347742634435, 8.947336250735868, 5.333859593637529, 2.930385350219665, 1.7883630048844124, 0.023506080709217538, 0.8329784930233033, 2.7270393842651, 15.827826607611874, 23.994169927412464, 31.117394201217163, 35.307513206235825, 41.87883254020445, 23.514197334166496, 6.582925137012236, 0.3689317032694817, 0.01744786506488679, 0.04635937789815568, 0.039145442011255416, 0.023900265504996625, 0.03102579867587455, 0.01900943379188257, 0.07708690024071163, 0.01641835014696323, 0.037591988070597576, 0.02983233136605592, 0.029374346767942754, 0.04839635206266277, 0.04417969687511364, 0.05031547892177778, 0.020994419314628168, 0.051710053887819095, 0.030222639756938143, 0.08717491456698026, 0.02614511379731759, 0.05710592140413581, 0.013900670174118734, 0.05668738841890328, 0.024755847820591544, 0.030205902651012428, 0.03419005972964149, 0.06118305665891498, 0.06208517115503069, 0.04782409970498374, 0.0375451379635882, 0.07636352937908904, 0.030956433244770577, 0.021234233563225118, 0.06796300756714999, 0.05393458169794852, 0.0395088434790171, 0.020370559443929986, 0.055834690424343275, 0.018223008148432262, 0.05192023010984544, 0.04853774508040759, 0.06805981043726206, 0.02532027650534386, 0.04983373602191287, 0.022029653078906482, 0.04090758979380612, 0.017319177615366155, 0.12377017628281348, 0.025430746384025104, 0.03195651697986309, 0.023515214392494772, 0.019407133016014294, 1.3663303155091502, 15.544045086829895, 42.672547678793634, 56.37037038803101, 44.86226574067147, 35.69170544224401, 32.32994591036151, 32.203741688882154, 21.33711518779878, 5.597571326840309, 0.3142696444786364, 0.045864550216544064, 2.301284243022242, 4.4167829713513775, 7.533878780180409, 4.47795037300356, 2.256197823632148, 4.552411667762264, 12.498670797194205, 26.829772918455063, 44.404929145689934, 55.08559019334855, 58.014639731376406, 56.82818158980339, 55.12613181144961, 50.05858252125402, 47.640339328396706, 46.682092528189386, 45.21590271303731, 47.78937370546403, 48.17303249912877, 49.2386620275436, 49.42350372191399, 52.2995698836542, 54.291070968874045, 54.74670917757096, 50.64667524829988, 52.343437671661384, 54.3157583667386, 52.514413787472634, 53.68906167245681, 53.829196191603145, 54.64919121034684, 52.92723148099838, 52.398170425045876, 47.860568646461736, 40.38579410122287, 37.07707089762534, 38.55313331850114, 37.20627377110143, 43.31088989011703, 51.649903789643325, 53.53814455770678, 54.32652135049143, 52.29550630815568, 53.03253927538472, 51.602517635591575, 49.450411181296076, 50.96788206408101, 50.53524855644473, 58.20896963919363, 41.58942437941029, 44.7171066653344, 56.10683418089344, 49.39574903057468, 51.2109278094384, 42.58013271516369, 43.224558522624356, 39.20312496923631, 41.46004892164662, 40.36733934956212, 44.10527183163551, 40.04380656826881, 37.438937002612704, 39.114938320652136, 40.73780721233737, 37.25609963940036, 38.55580053021831, 38.38883307672317, 41.00435972213745, 45.638828354497115, 50.7309591385626, 51.476813516309186, 53.01489253197947, 50.376117998553866, 51.41502834135487, 54.490268538075114, 53.2511604216791, 48.16963180418938, 40.05393412805373, 37.75350716806228, 39.571462985008, 45.21067027122744, 47.68728617698916, 44.97908961388373, 45.72599910920667, 45.28878427320912, 48.44994791092412, 47.48036938328897, 53.98100760675246, 54.16099340684953, 56.977843546098285, 52.11739147863081, 40.61367204112392, 22.78162410182338, 8.815708371900744, 3.5812999836860167, 5.677675931684433, 6.308136140146564, 9.163450021897594, 10.894920518321376, 5.790775024121808, 4.941574037075043, 1.7226731104235498, 0.11388013439793741, 0.5188918822715359, 4.328822839644648, 19.347212468424154, 28.59834021137607, 35.2901606405935, 44.15515653548702, 46.72449334975212, 29.73566870535574, 7.888610093824326, 0.5634130513475788, 0.048200313993279016, 0.017655055459228255, 0.025201536707520008, 0.01463704346303618, 0.04315782368423478, 0.0177524424713826, 0.01722364453598857, 0.08495961811633841, 0.0570559686410331, 0.016896321979020874, 0.026910288161748362, 0.031170434160758893, 0.08115354009092816, 0.04488845077914096, 0.038224159995274204, 0.036529519880611094, 0.014413722129839083, 0.04496129424942117, 0.057343979396166346, 0.04840094859020845, 0.016840947228634072, 0.08055442102974461, 0.01842327693837785, 0.1308970462771193, 0.20618087431836515, 0.14544487209810367, 0.1721558912146476, 0.14438126626754963, 0.10424444136480171, 0.14252377884282222, 0.10561468154792825, 0.14169387579444917, 0.21044570111459304, 0.19474820714564095, 0.15057467344787814, 0.11125495026428854, 0.2671107121052281, 0.19181813533988692, 0.11369768289789078, 0.09120856667117727, 0.14437123051574155, 0.19264177178903935, 0.19989676232780182, 0.08332980436182792, 0.19269193522632125, 0.09922772991440951, 0.22397876687107549, 0.1605907827615738, 0.16175702905222294, 0.09649414433947495, 0.19833913703839626, 1.881224383269587, 16.61898632203379, 47.757347553007065, 64.04613894800987, 53.40750217437745, 41.68947227539555, 39.17050261651316, 37.984785802902714, 24.980069437334617, 7.017643874691379, 0.6180697475229541, 0.5651968717575073, 6.245295357319617, 6.46869198929879, 8.818769781820237, 9.309838760283686, 2.487516172470585, 4.076680137265114, 12.14652922845656, 28.655767633068947, 45.33367579983127, 57.908437636590776, 59.828833995326875, 58.913595984059, 59.74889609121508, 52.22857890590545, 51.917472193318034, 48.89812184918312, 47.58268833160401, 50.927917034395286, 52.08413370193974, 51.27068904138381, 50.735093316724225, 54.21317661962202, 56.5746944950473, 55.15555351011215, 52.3504194905681, 51.16156085844963, 56.82957010884439, 54.10274228742046, 56.161135473558986, 55.14702627735754, 56.44646044700377, 54.871695503111816, 54.397324054471916, 52.10133721751552, 43.44731384708036, 39.68148939071163, 40.79165351006293, 39.97714980956047, 44.36758818164949, 53.783182867111705, 56.56985429025466, 56.9153876458445, 55.280394707956624, 54.70415930594168, 53.044996723052, 53.282912008224, 53.3003390988996, 51.87049004339403, 60.72629190260365, 46.30720807660011, 49.71726963596959, 55.946287647370376, 52.07589672457788, 52.98590621640606, 44.37066331986458, 44.66075005069856, 42.366845992303666, 44.60036516189576, 42.83987599034464, 45.18566516137893, 41.96443826921525, 39.65801008286015, 40.702839282251176, 43.57524979499079, 40.80730376705047, 39.94357039851528, 40.63085594484883, 41.90906616949266, 46.91682677115164, 52.67718822725358, 52.855338358110004, 54.67811084562733, 51.85578899998819, 50.43846015007266, 57.07170586432181, 55.208007366426536, 50.26384407474149, 41.654755377000384, 41.06948283410842, 41.27780383633029, 47.583092335731756, 51.375122147221724, 46.841713382351784, 49.798274424768266, 47.750785427708784, 51.388418982105875, 50.56048900850358, 56.66172404443064, 56.80285876797092, 60.001763451483946, 53.42855745746244, 42.9823443197435, 22.41245846594534, 9.695867646125055, 3.4510861192980125, 4.733001512865867, 12.51304824506083, 13.278172246871456, 20.82160395960654, 13.345317340666249, 7.760468221479847, 4.140853545358104, 0.2500666194264927, 1.3547500078716588, 4.89819017148787, 20.818579812203687, 34.05058183977681, 43.94428207028297, 49.969156403695386, 54.45537121065202, 33.77178761266893, 9.14113663857983, 0.7489654914506021, 0.14464932043225537, 0.16135529254473027, 0.1595124373993566, 0.1841091151319204, 0.19631481098551906, 0.08586734037605986, 0.15938886741717018, 0.1530531364222688, 0.13424189340683723, 0.07172508916306881, 0.13037124949116863, 0.13184291971546988, 0.2480360420961534, 0.11352247858960783, 0.1511632741218613, 0.12624092475180665, 0.11353589278916199, 0.1735427095404556, 0.19734267115352616, 0.14157283390241285, 0.1627878309978593, 0.23294262377725494, 0.13877659765703065], [0.023195485682076505, 0.015991429456569735, 0.10268170626894121, 0.02252586354922143, 0.017346074962387645, 0.035059213292815035, 0.0231324328154686, 0.03914513940652532, 0.029130276900926427, 0.007714979893212477, 0.02122080404191248, 0.03221521146535393, 0.019617981480194197, 0.03353278693412581, 0.043845996636176304, 0.07322030893016247, 0.04000177126257651, 0.061316604936315175, 0.057438074145466096, 0.03213517825990435, 0.019295965997321952, 0.05449596709842163, 0.02109364876824041, 0.019813090667969758, 0.03587704279550141, 0.05890397572769754, 0.014657726879381846, 0.10825360163805947, 0.11976293889024567, 5.095252500426385, 23.531420461593136, 40.90284878207792, 46.39589678856635, 33.47783734721522, 25.85805473789092, 22.108111958349905, 19.144378862073346, 6.916441330986639, 0.9654885987120291, 0.10614837670037824, 1.7748132996982144, 1.4514730822655464, 4.742825579258704, 3.4602289190215454, 1.0490018658099636, 0.8526034593101471, 6.104767130267236, 17.41385659863872, 35.10463253144295, 50.09687269887617, 58.02917995760518, 54.479156463376945, 52.339468233047, 49.99494990994854, 46.620640754699714, 45.74114730281215, 48.84210648075227, 49.275430325538885, 49.63257389683878, 50.938848680065526, 52.92557231841549, 54.46861313235376, 54.242472802439046, 50.4793861604506, 49.64256809603784, 50.679128939105624, 50.47612274846723, 55.21190620237782, 51.416660047346554, 53.16689614326724, 54.41675939867574, 53.35248701034054, 51.18780935964277, 51.099516807063935, 50.26357735356977, 39.07081165621358, 37.35989339890019, 36.45552819774997, 37.38324719090616, 40.26461247474917, 48.03394133044828, 49.569255075147076, 49.443570567715554, 46.0933526100651, 45.24834463673253, 43.39421672205771, 49.16353294926305, 48.71565711113715, 54.11192847836403, 41.24364391449959, 39.82082766871299, 55.17152147908365, 46.04029470874418, 50.81946349913075, 44.756428426311864, 44.4471142368932, 40.48171566378686, 38.92813151882541, 39.521582203526656, 38.94470745517362, 36.16466875999205, 38.70172839010916, 36.72330448704381, 37.95607013087119, 38.056235697961625, 36.72594031979961, 35.87462909760014, 39.264106058305316, 36.78627814016035, 43.58723263586722, 48.07574202937465, 51.04964387032294, 51.91505209092171, 51.16469090984714, 51.78941465193226, 49.56510520750477, 45.50359679806618, 39.777222679507354, 35.76589707405337, 40.44979541532455, 46.61372953845609, 50.793120861053474, 48.56583041529502, 48.277963745978575, 47.6886119381074, 48.07330623749764, 48.93452536675238, 50.23921159005935, 53.19432920025241, 53.333506661076704, 45.7631008086666, 35.08032560348511, 16.264171658023713, 4.076664938080696, 1.203394445680803, 6.9968087346323085, 7.8547124804988995, 9.225977505407027, 6.915927990790337, 4.503600222449149, 4.880123244177911, 0.7413983813697292, 0.5895454136113967, 1.206312934237142, 7.466577281874995, 18.098812257089925, 38.94251877261747, 34.97870091469058, 39.024892468606275, 43.766928180571526, 15.531563124349042, 1.9933602886815227, 0.05787148072774853, 0.05218403248657143, 0.03559509562628885, 0.10922482492582453, 0.02002712414269486, 0.005461641910275625, 0.007318024253172259, 0.020581042101126046, 0.09051485873398282, 0.016039157691862316, 0.06314888423789414, 0.036813654230847474, 0.019010818495805708, 0.01300026884212369, 0.019430669152268, 0.03619371673032161, 0.04016487521209544, 0.041878181059033646, 0.06849595961431343, 0.006517310112324213, 0.007497657986072403, 0.040126402276538076, 0.04330310459819533, 0.0476021487115612, 0.027923125345560334, 0.05196683123827942, 0.02431021064459797, 0.018709590808758815, 0.025239766410161412, 0.010141054423706186, 0.01591857928302019, 0.042120111625521414, 0.1099208617703088, 0.009495719193270611, 0.06396606256584488, 0.011596115861809062, 0.053407191449115356, 0.01908847874390983, 0.013902930133495361, 0.031721084754193024, 0.10635916579274401, 0.040978786175049124, 0.039963849910324624, 0.0033929066980377806, 0.04763409074756408, 0.04085553028891164, 0.014749249488475823, 0.03424825559880945, 0.025519039932518237, 0.059061575335480516, 0.0062322310799162, 0.024819934905897227, 0.14866662422014823, 7.201417703782359, 28.83413349428485, 48.32971157566194, 51.27912213725429, 37.108834251280754, 28.575653222299394, 28.68751333605859, 22.897437964716268, 7.533273264285057, 0.8056133420717332, 0.03849569219915617, 0.5345961331359802, 3.127679098998347, 8.612514888086627, 8.001875886994025, 3.783470709477702, 2.111471925050982, 7.37327144991967, 21.256908601330174, 36.017552421938994, 53.22205643500052, 59.47598934173585, 58.67197405907416, 54.84237970844392, 52.28906969870291, 48.44756703222952, 49.465155370773815, 50.37231329948672, 51.94370108266031, 52.28550818658645, 52.579336858564815, 54.099651459724676, 56.81240581697034, 56.75524903881935, 52.902991233333466, 50.78772367969636, 50.862739009241906, 51.53506463573825, 53.61751371814359, 51.496048819634225, 53.484086451991914, 55.73635455100767, 55.15631052755541, 54.662911661209606, 52.74406071632139, 50.14890293921194, 41.1796582898786, 39.58161800138412, 37.880721399861, 38.32307846315446, 43.67786292106875, 50.83967939499886, 50.984081452892674, 51.8085636631135, 49.21196637615081, 48.69389972379131, 45.16233490359399, 50.4290739182503, 50.600967868681884, 56.030081241361565, 43.43808843243507, 43.37906852845223, 54.71286304535405, 48.340647143702355, 52.471514824898016, 47.08816766738892, 45.13537253102949, 42.78959512710572, 40.63222877440914, 41.96481873912197, 41.021171000696, 38.66621525056901, 40.19431967889109, 38.662175209291526, 39.8501826870826, 39.70075999536822, 38.46881412690686, 37.41677953350929, 39.732382143697436, 38.73535094722625, 45.9554656090275, 50.2657699584961, 53.97433173271918, 53.348372444029785, 51.94874525070191, 52.23307001975275, 51.01229506154215, 48.387856791096354, 41.82625709041473, 38.043688035780384, 42.21794105345204, 48.342643630120065, 52.46408585579165, 51.59067600004135, 51.05885751785771, 49.94732449131627, 49.62387015742641, 50.688809348690896, 51.575825906568966, 56.604002444974846, 55.118745988415135, 49.12532121904435, 35.934060850451075, 19.82111127145829, 5.858080444797393, 3.5800546311563064, 8.734375084600142, 6.6166462436799085, 9.776865570775925, 8.930517127436977, 5.772473735194053, 3.6649697778686403, 0.9193924754377335, 0.16991326074686744, 1.4264434576034548, 6.768477760976361, 21.417596340179447, 38.04344877119988, 40.068603792498195, 43.25123456216628, 48.60098661914949, 21.032311724078273, 3.2606234233225546, 0.07618553651076171, 0.019373436638664816, 0.027905438290608507, 0.043063522091195475, 0.012359609620855942, 0.041742951218639655, 0.004951259770971393, 0.05385205487630541, 0.04409243946053809, 0.03926687843857273, 0.09002368146133038, 0.041490793378362735, 0.07209484149972278, 0.026005706862516464, 0.06599389347097566, 0.07039039545962888, 0.060396403104307196, 0.025546075175366095, 0.03704629598125335, 0.010169080792806082, 0.00445021815868395, 0.09707991814901752, 0.029371012370252324, 0.012874030001131038, 0.17015015045481344, 0.12480493890301836, 0.19182493820065455, 0.12495957375053438, 0.0717770069416973, 0.07450457872642625, 0.09973244396068397, 0.23081377268798892, 0.3116670292952369, 0.10435249806652147, 0.14502733885761232, 0.04945538817874847, 0.1712684856066781, 0.09858429266680634, 0.16627863319891115, 0.1281543289341273, 0.14325275746805055, 0.1472604698351314, 0.12030475457469303, 0.12474995677269275, 0.15735079774693136, 0.11780377627620775, 0.17627830226575175, 0.28751264476487715, 0.28157325701848157, 0.10437825394253578, 0.09735138140498631, 0.18158857860872823, 0.3670527653828744, 7.745908873696481, 32.160483829436764, 54.1205184690414, 58.97820526553739, 45.0134378094827, 37.37925421807074, 32.89656169952885, 26.95049954998878, 9.10688061867991, 1.433107074229948, 0.25768194708131975, 4.531352952603371, 6.334287072381666, 11.984957975725974, 10.275798901434868, 4.421616311996214, 2.833182643498144, 7.468701245323305, 19.889739021178215, 37.116533863929014, 54.02032152298958, 60.31555306526923, 58.9461124327875, 57.60942359124461, 55.269976892778956, 51.37671070714151, 51.026066503217145, 53.499305248260505, 54.367623867527136, 54.38398799588604, 55.52883763467112, 57.32926437931677, 59.484085113771506, 58.00656749356178, 53.67889488897016, 52.12730330805625, 51.09091897164622, 50.35323489096857, 55.66091168311335, 51.35116823257939, 54.068437237893384, 56.37306505633939, 57.72401171345865, 56.07211728249827, 55.74852958802254, 52.92525460643154, 43.879472747925796, 43.3763385588123, 39.16137526112218, 40.669593272670625, 44.723551119527514, 51.81585534926384, 54.2600057971093, 53.289309393975046, 51.73072422704389, 48.987575423332956, 47.45396790965911, 53.35139266906246, 54.316389868336344, 57.15026309413295, 47.11690687364148, 45.543534371160696, 57.06763444408294, 50.273285219746256, 53.99854060142271, 50.800432159054665, 48.47376454261042, 44.940164012293664, 42.08613372618153, 43.374063584112356, 41.572264009906405, 40.911466229346495, 42.46774112024615, 41.027862564209975, 41.83148168748425, 41.60729077554519, 40.208165645599365, 39.74806770201653, 42.854949658916844, 40.818172654797955, 48.05210974908645, 51.855820378949566, 55.40462793842439, 52.66582512086438, 52.81148625958351, 53.02418462691769, 53.40013596319383, 49.28079220556444, 44.20175037076397, 39.57425179020051, 44.09220641659152, 50.70748767545147, 54.121828540678955, 53.47080922895863, 52.817169773963194, 51.64118043838009, 52.900100446516475, 55.03997302824452, 54.83473893134825, 57.76942491531373, 56.576977314487586, 50.01343604057066, 37.434269382107644, 19.734038576003044, 6.235390882338248, 3.578416061016821, 12.520828266297618, 13.386340429705958, 17.647808328751598, 15.347380388167599, 10.33460601683586, 10.633938754758528, 1.970297364938644, 1.022504048962747, 2.0758935761067177, 9.71536280647401, 25.825132323849587, 50.59804962527368, 47.45353252656999, 50.50527772595806, 53.79994707722818, 23.845886684233143, 3.3894495041139665, 0.24360687411840887, 0.14218472364929416, 0.13120700545128317, 0.2133636687311434, 0.153877554281104, 0.1183269760240951, 0.13770971297016069, 0.1973270889251463, 0.12156565102838701, 0.13496419174536584, 0.19772844238867684, 0.08462833871524181, 0.14715994377770733, 0.17038509429943177, 0.14364456547604454, 0.18455709270652265, 0.15385078716902964, 0.10556620350407978, 0.20293803945664438, 0.08801372721791269, 0.0937408013569732, 0.16523649315199546, 0.22195212723266697, 0.1457956331151147], [0.04299605655814371, 0.11704667456327908, 0.05135324843708546, 0.025503377264906323, 0.01708797802547774, 0.03565657418221235, 0.05232134225567984, 0.07621555949651426, 0.03088490936093994, 0.06265428255222018, 0.06302500782053798, 0.02113525691862789, 0.05160859320312739, 0.016901370498441884, 0.010252581503722939, 0.011186204238554404, 0.03770613134087574, 0.04326378896592125, 0.06046604049662429, 0.11050866571285071, 0.04550999706430782, 0.04264325774725407, 0.06535312987022823, 0.058140883207201004, 0.05219358177254758, 0.014864799487704953, 0.07620595275394379, 0.04649127908651868, 0.027416812090743935, 0.8423999036031385, 11.083892468483219, 35.231332932749105, 44.59137901183098, 42.43244763343565, 27.666351718287316, 18.64296070991024, 20.42164771787582, 10.101267157062408, 2.385638245651799, 0.0879220954412895, 0.5477203224455157, 4.102564593476634, 9.085741004636212, 3.9942299550579445, 3.1281465964932598, 2.741728170264152, 4.80996233801688, 14.201654099649, 27.572907132487146, 44.52978211064493, 58.08530515240085, 56.36276098989672, 53.12619370798911, 51.22260862781156, 48.61435013432657, 49.087701766721665, 51.17322206497193, 52.61683079504198, 53.80876456537555, 53.3210531357796, 52.92988300323487, 54.57983586095995, 53.667088554751494, 50.189938775954715, 54.24371619378367, 52.07653999328614, 50.85397251190678, 50.323883794969134, 48.756485062260786, 50.057852960401966, 51.39475753230434, 50.08146955120949, 52.9816779013603, 52.26594732653711, 52.999587443567094, 46.62817562780073, 40.77128071938792, 37.130419054339015, 37.547582734015684, 36.62141307707756, 36.37877133584792, 39.3412120111527, 40.73488896892917, 39.352108355491396, 38.73906543177944, 39.40003579662692, 50.12785942323747, 46.44740927603937, 58.16965180058634, 41.06318742998185, 37.827820393346975, 54.44340798162646, 46.69544035388578, 50.71151594961844, 44.39398965527935, 43.679926087779386, 39.85585443435177, 38.28396066542595, 35.86653724793465, 36.33155776608375, 39.212997574960035, 38.94979476928711, 36.932100096056544, 37.63795806515602, 36.82063025812949, 38.381674751158684, 38.292601646915564, 40.35936909337198, 38.297575212294056, 42.91754676449684, 47.511944463176114, 49.114389573374105, 50.93202767833587, 52.611947444177446, 52.38703481612667, 48.95651025156821, 48.908025833868216, 40.06488930794501, 36.488162317583644, 39.80299265153947, 49.36285603430964, 52.13563442230225, 51.865430185871745, 50.563093462298, 49.146243141543486, 48.83444216943557, 50.53565648294265, 51.586843844383, 55.86883260357765, 51.71525047671411, 43.21873380291847, 31.359016126202, 17.828772760206654, 3.65105860175625, 3.272842832149998, 8.469652360485446, 2.9366559943845196, 6.76118754571484, 8.500236061311538, 4.808432613649677, 3.0439176194129454, 1.0050366314188128, 0.5867281712351308, 1.953632317243084, 10.35242142215852, 26.613338493531753, 33.62274539086127, 37.26332464525777, 40.94599093160322, 33.038951581524266, 10.738425793186313, 0.9115762948509186, 0.12653786043125775, 0.03865916387087876, 0.11314583146163534, 0.016176768150481007, 0.0216141538018541, 0.03510444312386456, 0.03866356121556413, 0.03567719343869436, 0.021229330600509723, 0.01535847899504006, 0.01744846644390735, 0.07453575850494447, 0.04771349576091574, 0.02813318282395842, 0.03794561042600582, 0.045905168198289416, 0.02765019886165617, 0.028622531061691624, 0.0321210132941844, 0.033480945764289755, 0.04597529971731767, 0.021588497517269947, 0.03687403728103927, 0.04869154489208614, 0.050262442654779846, 0.06598498386841628, 0.03355581170669006, 0.029294759808709065, 0.022963184840796937, 0.03580098941681847, 0.006489555225632484, 0.04984471789230743, 0.022397591702399716, 0.04763496408779775, 0.030548068161513058, 0.028861621357200128, 0.05113626169341226, 0.038909130699692235, 0.027053803243043444, 0.05103590800577114, 0.03661801069674473, 0.03892084418405448, 0.06768564543416423, 0.053324672288351485, 0.022005383413465276, 0.06834918482890052, 0.05857746139348996, 0.07134100332135154, 0.05298547153811782, 0.04053679557757513, 0.1291934659163798, 0.07032933059118449, 0.039489166510681954, 1.4229655410012891, 14.94451080599139, 39.33267301128757, 48.84899024040469, 46.37959934050038, 29.910673095333962, 20.339223031074773, 26.46097206300305, 11.32408174776262, 2.192928521863876, 0.05365551118889163, 0.08282120624977736, 2.507020893596834, 9.024391212771016, 7.326774693304493, 9.215897014064174, 5.196221172809601, 5.905850500829759, 17.43908920595723, 32.09075781606859, 45.59455263999201, 59.475334305917066, 58.68263898357269, 54.38482346073274, 53.410667527106504, 51.84158217522406, 51.869121136203894, 53.63637639630226, 53.826521135145626, 53.54818974771808, 55.569312572479255, 54.62630418039138, 54.46625971025037, 55.54569990404191, 51.368450195558616, 53.50597327755344, 52.684134744828754, 49.74689922025127, 50.145921937880985, 50.03617794282975, 50.7750661911503, 52.163071401657604, 52.33661274756155, 54.83056160711474, 51.747531583232266, 54.83254632642193, 47.48102049673758, 41.527639204455966, 38.12031938183693, 38.49680808282668, 37.95442273539882, 39.54195107183149, 41.79225406339092, 44.13137520513227, 41.09446833210607, 41.84328017696258, 41.88137423607611, 50.61686915736045, 49.635684336385424, 59.185271109304125, 43.541435041735255, 41.25008444632254, 55.25329897480627, 49.57657421788862, 51.94377168532341, 47.00557824104063, 44.52506349932763, 42.10021503510014, 40.215527934412805, 37.554890109646706, 39.23099733168079, 40.12212061112927, 39.746824310671904, 38.50807705233174, 39.37074353618007, 37.68863508778234, 39.035996698564105, 39.83475600519488, 41.58076378606981, 39.7244668006897, 45.27968829677951, 48.80348682403565, 51.51005168114939, 50.31039476394654, 51.94370500503048, 54.34470938098047, 50.431866645812995, 51.78033436498335, 42.12361589554818, 38.98748090190273, 41.63654773466049, 52.21234029339206, 54.01339461726528, 54.26699153838619, 52.666393864539366, 51.6149672385185, 51.94513667014338, 53.549315467957534, 53.678941957412235, 58.059958796347345, 54.22187643666422, 47.888346872022076, 33.70731561414657, 18.932253160784324, 4.054323607875455, 4.661051515609988, 7.072594319620441, 6.970393532706845, 10.125305402663447, 8.326459373197249, 4.8831493527658525, 2.9840389615105045, 0.6300888090364395, 0.4620931736163555, 2.098386162711728, 11.20386012138859, 28.96671941203456, 46.25100051203082, 44.160875351198264, 47.793535340216856, 39.824145993878766, 12.592834157328452, 1.1942436786428576, 0.11520250174667566, 0.04852449175931754, 0.045513241446667144, 0.022748902387496446, 0.04037499780796709, 0.09278933547677533, 0.028139729045271396, 0.018721790758952982, 0.028649263699809392, 0.04239338667943113, 0.0437728314089679, 0.06752429199555228, 0.017906067998058373, 0.008014795584453931, 0.02920622302729997, 0.07045884541566334, 0.048490856669002005, 0.004312375479663212, 0.01641189968664079, 0.1127609795319938, 0.05011354963625631, 0.0015849238749773753, 0.021421714430494655, 0.035941133711246714, 0.0821841964798589, 0.13422091791947044, 0.12319511238245234, 0.13413234283366512, 0.12045498441664443, 0.14669515823404636, 0.14200758879944203, 0.1782775925652635, 0.09817467311457281, 0.22946927305911818, 0.16519112542511957, 0.10784948259712228, 0.16775824009410797, 0.11892628660725972, 0.05987581188580202, 0.16360170748685637, 0.1512247296951471, 0.1612361965160216, 0.1702447469917036, 0.19560273225990035, 0.1805978890268072, 0.20575160461087383, 0.20895074181739362, 0.20983139052987101, 0.11896566352656773, 0.17961913509474647, 0.218673853143569, 0.16224010877551573, 0.11380586983455766, 1.458353532418128, 15.744097732728529, 46.671525662945164, 56.617593457621915, 55.203837886933364, 37.845078822105165, 29.262073886009958, 30.158996389758205, 14.36268896825852, 3.0160116716738674, 0.3069582851904054, 1.458975473238576, 7.751667893701985, 18.072436278866185, 12.762028536488934, 9.976446551661338, 7.459481714233276, 6.742386154590115, 18.841732701947613, 32.32552539917731, 46.78621968915386, 60.71406195240637, 61.01879873583394, 57.937086628329375, 56.77118955119964, 53.46533360019807, 54.792702890211544, 56.82861305052235, 56.456925330623505, 57.23346048785795, 57.281136897302446, 56.18471284066477, 55.22241030969928, 56.76787122603386, 50.59450772500808, 55.774648651, 53.38726666665847, 49.109521911990264, 48.634550340714, 49.690122912007, 51.22847649358934, 51.91987268386349, 53.59947866009128, 55.6910119518157, 55.148752120233354, 57.64053583145142, 50.725538422984464, 44.96436111388668, 40.984936145044145, 41.48766633002989, 39.07680111546671, 39.88737067868633, 43.80183335273497, 44.969617089917584, 42.403700582442745, 42.387352143564534, 44.09122582404844, 53.40097142804054, 51.46587794826877, 61.14000389652868, 46.094262599945075, 44.45408821105958, 56.64489707639141, 51.49153024919572, 53.98264323511432, 48.944327369813, 46.42710316565729, 44.370322073659594, 40.65729664218041, 39.41211277438749, 40.20799698368196, 43.231246163768155, 42.180682459185206, 40.52820359506915, 40.83126944880332, 40.27499106622512, 41.58789465504308, 42.369466135578776, 45.75610722264936, 42.77940480939804, 48.31677952120381, 52.02609439049998, 53.6625111487604, 52.70837107012349, 52.61994123458863, 55.19980176802605, 54.47706976244527, 54.25085882986746, 44.43591979242141, 41.89697350225141, 44.21899703241164, 54.03346146306684, 56.34076433797037, 54.81937500738329, 55.24331654271772, 54.472864981620546, 53.44708673415646, 55.44188653269122, 54.57507802594093, 59.48901553307811, 56.00830424216486, 49.2468793930546, 37.80738484474921, 25.280536720829627, 6.892550174267062, 5.444958277287022, 15.342895157875555, 11.875723888797145, 18.496173850951656, 18.730670790518484, 10.18039313054854, 6.255805348196338, 1.9964862951347906, 1.0210339568795697, 3.274091126457338, 14.234095042751683, 34.78312761552873, 47.11912301278884, 50.24703671855312, 53.959536552429206, 43.6116180112285, 14.503741322025178, 1.7498979140673916, 0.39866375947190874, 0.09341391163968271, 0.14051224645828048, 0.10981733264822154, 0.14455283931907148, 0.15969161004308732, 0.11068284346331513, 0.15150881041922878, 0.204123989528706, 0.07736522764448198, 0.1623941997006055, 0.1989254241268481, 0.153494801432375, 0.10744122668139397, 0.13454212326436274, 0.16584479760739113, 0.06331398384645581, 0.09009170240812725, 0.11522908499764821, 0.1421828697165174, 0.20610625735454022, 0.1924066440833192, 0.10341194127836537, 0.15765194690996603], [0.04864354182275073, 0.015659970024810926, 0.04162297801925771, 0.04700312158092857, 0.027708683929015553, 0.02084408413558718, 0.01374255441459677, 0.03341468298927911, 0.03501116042776454, 0.10928493984524282, 0.08167570562011774, 0.028775262180715803, 0.08127707942959764, 0.07309284722132069, 0.0491961516860512, 0.04116429053547402, 0.04275367783022024, 0.017928884011663256, 0.062074059049689004, 0.012644131803103994, 0.03876285387143012, 0.059005873082506086, 0.057285549870181474, 0.015938843266227316, 0.08136061365686117, 0.022517026725014853, 0.03918613277135357, 0.03963930059164282, 0.024032756581061313, 0.04757437419386641, 3.3437156484973047, 26.208000759924612, 51.38780709235899, 44.80601503003029, 24.37323170323526, 28.03931813086233, 26.801590688766975, 21.46237804043678, 4.90634968203883, 0.09662850083963526, 0.12394089131586014, 1.2902165997412898, 5.858461895296651, 9.818884941839404, 3.444480112483425, 1.8161784929613916, 2.7141953379877153, 10.986449026292371, 24.99071474998228, 42.74522527571648, 51.25056336002966, 57.3426200497535, 54.29842541294714, 51.15275905978296, 51.17000179906046, 51.7726190628544, 55.008350879915305, 52.3763620468878, 52.3079284544914, 53.463435173034675, 53.33403225867979, 55.38278818130494, 55.555568587395456, 53.29607156015212, 52.7541333629239, 53.9523821492349, 53.97690872992239, 54.15070502988754, 54.37829663676601, 50.876553596988806, 50.593609502238614, 50.273912798973825, 49.71946616326609, 52.17629371150848, 52.38696813583375, 50.45718946764546, 43.181808610116285, 37.5065625867536, 37.71509147459461, 37.58910494465982, 38.22796490884597, 36.64853626681913, 38.13920167184646, 36.42798923677014, 40.567792077218336, 40.2582464679595, 49.864346750320934, 48.03063869476319, 54.86638069152833, 41.04521905222247, 36.48463610679873, 56.48728055338706, 48.07818174362183, 49.54643080311437, 46.797339608592374, 44.695949400624926, 40.65142877640263, 39.589011669158936, 36.82977722537133, 36.923972945059504, 39.721258301888746, 36.67086239783995, 37.8345041121206, 40.369881045433786, 45.08285591679235, 46.809138098070704, 45.92327863939347, 45.1873831595144, 45.39596696053782, 48.601147436326556, 50.16539650578653, 49.73609701279671, 53.455111903529016, 47.960192926468395, 52.110923490216656, 53.95049941155219, 48.23253485464281, 43.8299959705722, 36.87571994719967, 39.203317165374756, 47.434034424443404, 50.402040943022705, 52.17821567289291, 52.227233532936346, 50.87973856156873, 53.22317431049963, 52.691477421791326, 51.09447263902234, 51.81507479759955, 43.02126599896339, 30.898982901727003, 17.64336428334636, 8.193429737321793, 3.2903459187476867, 7.320672956205184, 7.9926847930877445, 5.004791857734804, 7.434405021129116, 5.247236009567015, 3.6664264480913844, 2.3985058261502177, 0.7114130871430521, 0.7694275773340656, 5.320200920104981, 15.652946752886619, 18.2425965416816, 19.247360690947502, 34.40601918005174, 38.65054538173061, 23.187842407534202, 6.084504656253323, 0.1642543531113094, 0.0793947477734858, 0.030257322472490134, 0.0459607555380752, 0.06407763178069746, 0.023731134358733415, 0.01003980824363328, 0.018560705451114524, 0.007645665694238439, 0.015402375833101332, 0.05490197071565255, 0.06458429935117883, 0.035793979712311304, 0.020016184407136133, 0.04066064901229355, 0.04815608007653106, 0.06070887504686272, 0.0252014639291672, 0.009424025812486728, 0.059693892816862756, 0.04805756116946859, 0.0540527354385103, 0.039822797801706104, 0.05659299872575268, 0.01153428203261067, 0.033293851771421974, 0.023948823988077142, 0.07423641730941112, 0.036580414931860664, 0.02497046926779853, 0.03653335415067212, 0.058413104890214826, 0.04403230921936132, 0.07710468880231343, 0.0511525372313636, 0.060010785086741375, 0.020025773912728317, 0.07042247922189775, 0.06747791303261634, 0.050754018293152896, 0.013120127128316991, 0.11432600523074789, 0.05177771860373117, 0.06753227463172329, 0.014180115108648616, 0.05915824797064547, 0.066819483444335, 0.10989944195194591, 0.06010331318623597, 0.126362725070888, 0.027923110023801847, 0.029528845634852207, 0.02993539317450937, 0.04715860678604053, 0.07850383348282307, 4.844105099478076, 33.947972636069025, 54.641966204489435, 51.650190122665904, 28.390185909886515, 26.211927052467104, 26.775679511408654, 19.97147729319911, 5.378824174404145, 0.28075237848585655, 0.1557096995172962, 1.296992003917694, 6.099809254369428, 10.479953365941203, 7.5992288993250945, 5.691010519381493, 5.3347440881113855, 12.032379431109275, 27.886598687018118, 43.81514587709981, 55.3055763244629, 58.62478402353103, 57.13374207096716, 53.57162983186784, 54.539776694390085, 54.32903951214206, 56.09143495559693, 54.66549258078299, 55.06484477750717, 54.14075789913055, 55.89301401568998, 56.34981716832807, 56.931473285921165, 54.442698032625266, 55.057557013727006, 53.774643867246574, 56.10590065679243, 54.720837223914366, 55.47866659779703, 52.19768239605812, 52.324253359148585, 50.65508088757915, 51.53283672948038, 53.62914746807468, 54.632787858286214, 51.589024682198804, 45.847329785746915, 39.2380379861401, 38.99486280256702, 37.918474212769546, 39.173381636219645, 38.46267561758719, 39.2201715900052, 38.75705342138968, 40.46057801092825, 41.010290345837994, 51.7237816318389, 50.744161836562625, 56.24864747447353, 43.949930283331106, 39.154554259392526, 57.34649927385392, 51.479327755589644, 51.93716249158306, 48.37490904715754, 46.239692318824034, 43.221812863503736, 42.58500429891771, 39.344389130992276, 38.889774660910334, 41.85401962649438, 38.09461216772757, 38.703524835648075, 40.77808210926671, 46.99825517592892, 48.65936325442407, 46.70551692285846, 46.57499613300447, 46.628611010889855, 50.47990783568352, 52.63921968398556, 51.22784106962143, 53.36202621459962, 48.307059887916814, 53.82732914340112, 55.269859221673784, 51.2929916381836, 45.099027849012806, 40.22737741470337, 42.38521837419079, 50.74943742444439, 53.84888648986817, 54.163601783014116, 53.8069445856156, 54.56080844325405, 54.86004998607021, 54.347000045161096, 54.411679929302586, 54.1419267654419, 47.09022298935921, 36.531751617308586, 23.69380266435685, 11.754044121311559, 3.0895467967756334, 1.909175315691579, 5.253699095018449, 5.097716239190871, 5.578296799813548, 6.28896898800327, 1.9123260821065597, 0.6249812089147107, 0.5319382370479646, 0.7474368702500098, 5.236106284203069, 16.260414027398635, 24.640915816830052, 22.580314336284516, 39.691181567407426, 43.038630331716234, 28.94637211676567, 8.287012096374266, 0.3945018795709456, 0.019815076750913457, 0.03127618685304638, 0.003936600734314491, 0.007367821404665349, 0.025485971747266672, 0.003145211798724749, 0.09214164644119241, 0.039440768906065536, 0.045864634486215736, 0.019415464222190842, 0.04488392702994808, 0.09802787534652219, 0.0019465355698259608, 0.018551853305149465, 0.05875735032942988, 0.021320945140154614, 0.019220699773981206, 0.025196672049200824, 0.03316347126758868, 0.0412353566817699, 0.014826528607837617, 0.04616546955320143, 0.04713762746823411, 0.03141988004978386, 0.17736001841483579, 0.11429493270453908, 0.15111455092987708, 0.1698179134438115, 0.18961370201601138, 0.12083337822508429, 0.16825457313849082, 0.20736064972175708, 0.13819026460330333, 0.15373002106864608, 0.15740661491309443, 0.17168128442379738, 0.19727441271947277, 0.16200671242850442, 0.09777186408398614, 0.10720952338869534, 0.17147111586265026, 0.05961653325826891, 0.12877617782402423, 0.09710604940811474, 0.23132726610187562, 0.23810564269942625, 0.1824782824804706, 0.10747310359992328, 0.18555435532283399, 0.09939961706198032, 0.1390748816512285, 0.10338355005989153, 0.1534075899830749, 0.23394671989785087, 5.82185245329334, 35.93188785737561, 61.72947729787519, 57.0105129672635, 36.97563056022891, 38.12772873909243, 36.15023443775792, 25.936696298660774, 6.266745328903199, 0.46121336760059484, 0.42991836945856776, 3.951877917974226, 11.704695801581106, 20.341925544123498, 14.068605342218953, 4.950467521144498, 4.135859877832474, 12.45789775925298, 27.584183946732555, 47.16092763408538, 55.56109912933842, 62.44741224473523, 58.39716888243153, 56.05216026306153, 56.1226805563896, 56.952171633320475, 58.222066433199, 55.17773059106643, 54.33153021720148, 55.19535772262081, 57.02007178337344, 58.15652754998977, 58.40251115060622, 56.33448854569466, 55.687834831976126, 56.11402388541929, 56.93341093678629, 57.515451446656265, 56.64835268451322, 52.74157001126198, 52.454115190813624, 51.86486536456693, 50.63398245842227, 55.831954479217536, 55.86186255178144, 55.55985966036397, 46.940353147445194, 42.26413088460123, 43.13314376338836, 40.50972923155754, 41.65788150602772, 40.5906085045107, 41.83256818402199, 39.84853136924006, 44.200581504452614, 42.94295195610293, 52.83165900937973, 53.3025630827873, 58.557240809163744, 48.23955589725126, 42.74602151686146, 58.512278679878484, 53.91567268679219, 53.45128759261101, 51.76574707031251, 49.94641842380647, 45.559243463700824, 44.83720964001071, 41.13972856152443, 39.918188741130216, 44.10688392577633, 39.0736279179973, 42.064054704481556, 43.07495932425223, 48.55663637961111, 50.65138209250666, 48.71511582405337, 48.980997608553984, 48.83879600032684, 53.17884368281211, 55.15799714672951, 54.12065575199743, 54.954567340112504, 48.206329499521566, 54.488091622629476, 59.355709860401774, 54.40528254355154, 48.76895427703858, 41.85964430532148, 44.049680079183275, 52.97502163917788, 54.79720184879919, 55.00707218723913, 55.72792537750737, 55.536886338264715, 58.03427903882919, 56.97487431187784, 56.3730925129306, 54.686657690232806, 48.14657218994633, 37.75770018177648, 23.291422397859638, 11.467310036382369, 5.303743145158214, 11.454127930825758, 18.680038875149144, 13.549166840891685, 18.210495864191365, 12.099554923272903, 10.515524360441393, 6.720023251348927, 1.3368184023326444, 1.716907348844313, 7.208769206077823, 20.791615478454098, 29.449423936105546, 28.59817154945866, 47.67516997552688, 53.0206976398345, 31.285348130810647, 8.8233442460337, 0.5542180350711269, 0.23345063200160382, 0.1460283859482696, 0.13982641390494763, 0.1929722161542985, 0.14396843680691335, 0.06608616110057601, 0.15861697254642365, 0.16665659033723418, 0.13959387557641154, 0.16266933251773158, 0.13262480437274904, 0.2374964802255554, 0.1124449146370734, 0.17706793973282461, 0.1553717628121376, 0.12148099831275402, 0.18969869181033105, 0.24034537735485265, 0.11632558664367085, 0.1201092029711412, 0.11564308657280861, 0.15933211562373947, 0.2265073319957141, 0.17419287304003395], [0.05297526341652679, 0.026404560964194038, 0.0349940958192512, 0.05043048021053115, 0.02263443736029008, 0.06240729197499253, 0.05526945926249028, 0.07840385900870447, 0.07888583556538628, 0.12180392735547597, 0.006683313704636549, 0.037270587373284564, 0.0027558887884351277, 0.013063804344123891, 0.05617797442321336, 0.047449559318803014, 0.010570558745624318, 0.03116324634080933, 0.04823351241347771, 0.03821268016772886, 0.12924612680029485, 0.04695814072845444, 0.07418783201325325, 0.08127140271807871, 0.07745223991092175, 0.028000291466953296, 0.06818741004193021, 0.033553996078309514, 0.11550316827431803, 0.04795577872784869, 0.7817101118064697, 10.391536278109397, 37.9670488449835, 50.012212261076904, 35.120459295088246, 26.770509827521543, 30.36580727946374, 28.9327242297511, 7.110875671909702, 1.446791856038955, 0.05206501689709483, 1.3783697856049384, 7.447755298306865, 7.694918551752645, 7.434106920996021, 3.5679815757659177, 3.0770726790351257, 6.695013728833969, 18.23593047357375, 27.166278939093313, 44.301060861156834, 50.69766998291016, 55.55023024159094, 56.02178150607694, 55.780826384021395, 56.230824224410526, 55.02108289349464, 53.31693072472849, 56.40585214860978, 54.562079291189875, 53.248555967884684, 52.15182988874374, 50.30841396700952, 50.392540962465354, 51.97361699996456, 52.829788038807536, 51.61678721827846, 54.80497598648072, 53.17692564379785, 54.63377629556964, 53.5135591414667, 52.7086966268478, 51.28369169850504, 51.62372981348346, 52.77108584680865, 51.779338082959576, 47.096510548745435, 37.12288418123799, 40.283326102841286, 38.47734528203165, 38.99589830829252, 40.73969779476043, 42.81469829620854, 41.24095316856138, 41.9520200452497, 41.719152850489465, 50.75727432004867, 48.33034699962985, 56.795229757985766, 43.67066144943238, 35.51703053136026, 55.75444844461257, 47.91090442288307, 50.78810807197325, 44.52607154846192, 43.357785747897246, 40.313708782196045, 38.71306796227732, 36.97637973293182, 38.486229450471946, 34.85426764334402, 36.61011665098129, 38.91850994479272, 45.65425111401466, 49.63888499044603, 49.935286737257435, 50.44485361345353, 52.680302589170395, 50.40075048323601, 50.181850848659394, 48.238653752111624, 53.92649058372744, 50.96178670083323, 52.94398000163417, 52.015005850022845, 50.36978337072557, 49.27711694471298, 42.860335073163434, 35.84906701118716, 38.6822263656124, 45.22665000730946, 51.07631598749469, 51.325433561878825, 52.30706161068332, 50.55863372741207, 53.932672239119015, 54.31259693637971, 52.985765011079856, 49.73178240560716, 38.84072149953535, 26.05954101008754, 10.399634011330145, 4.3372005320364435, 2.8420631347164034, 0.7276502900546598, 1.7516582002562864, 3.5653766316752282, 4.8102275882997825, 5.703762144811693, 1.7841339543942483, 0.6783240949434619, 0.695681992557741, 1.5580466990509343, 8.043638342811215, 15.208410812962441, 27.49322222125146, 30.657925798046975, 40.859439911380896, 34.09159414229855, 12.948275419973559, 1.2108064995658014, 0.02121479982780593, 0.05636165166393884, 0.07164304114637837, 0.03898886513085135, 0.0059197916960974616, 0.0051483129068548164, 0.07358410876364478, 0.02048696075836497, 0.060957432273895516, 0.05036681447358382, 0.04077218375318954, 0.022541177646827795, 0.10685834868420517, 0.02778111371181665, 0.08264703616019219, 0.030167791691999284, 0.049774536577564095, 0.05627253648614692, 0.028791108709429542, 0.038269784361604726, 0.02250904408884385, 0.03823691152877385, 0.0924885846794613, 0.023638215554397435, 0.04466543875394329, 0.030312065200339404, 0.02876200502918613, 0.01101632807178483, 0.026980810385618, 0.018386087200093656, 0.02425755359112255, 0.05638052040951387, 0.08587220503437905, 0.03439028063909181, 0.07676989305764437, 0.010655672071621785, 0.04120166030442042, 0.05361110107192109, 0.046467258399652864, 0.11350674314364312, 0.04322960229230024, 0.006913955007950145, 0.03258282641669916, 0.03251167600073161, 0.07920227584338958, 0.04338316461672226, 0.05313182497517236, 0.020795925933447097, 0.05942210014308653, 0.052303607320232745, 0.013143835634353661, 0.10125535014536112, 0.042594438794279293, 0.03431532659658021, 0.034643193075974146, 1.1548279033553217, 15.329681673357564, 46.89194717714864, 56.222163631070046, 37.68994908179007, 29.9979732882592, 30.928763497260313, 29.07202328405073, 7.432768412174718, 1.123514519103112, 0.08724907953892985, 0.8051733624550604, 2.6853789100723886, 8.324092222798257, 8.991637460647091, 6.720488542510617, 5.7715343275377835, 8.775030451436198, 22.950807694465887, 33.463810951479026, 48.797171808058216, 54.253259320412916, 58.122230345203036, 57.140045319834066, 56.94964170455933, 57.850872931941865, 55.85550046736195, 53.22567678266957, 57.642512706018266, 55.210435313563195, 56.67426386187154, 53.775094939816384, 53.70397844622212, 52.37432633676837, 54.61507051221786, 53.390326115392874, 54.12296210565875, 54.244755621879335, 54.125256692209554, 55.92512646029073, 54.0842757686492, 53.141585088545284, 52.67048489662909, 52.67505053550967, 55.151407564840014, 53.644177990574995, 48.37930994649088, 39.140523941286155, 40.72893873337777, 39.269244363231046, 41.00771727100496, 42.12382378116731, 44.25420814944852, 42.382963011341715, 43.07092712771508, 45.11368966871693, 52.7015971368359, 50.5620304999813, 56.5427585571043, 44.557944728482155, 39.00844204810358, 56.03578436759211, 49.103120603869044, 52.934742819878366, 47.01964778284873, 44.316981761686264, 42.18653855785247, 41.30447203113187, 37.89360246350689, 39.64343455529983, 37.66319067247453, 38.541931029289, 40.57802946336808, 48.28568689284786, 51.14842484074255, 51.46884718248921, 53.546459982472086, 53.635011411482296, 53.306834543904955, 50.995934855553415, 51.39219622458182, 55.45947051817372, 51.55390770204606, 51.846069366701194, 53.36394425361387, 52.49202489852906, 50.84251526863345, 44.805846368112874, 38.24993018181094, 38.625363765224336, 47.82443969480453, 51.50057131244291, 53.76599111864644, 52.80674803641535, 51.526568781945016, 54.00162750674833, 56.003056110874304, 56.054490150943884, 53.203036862034956, 41.473177094613355, 28.554040962649932, 10.711687976314176, 5.2593556431032, 5.011659927906529, 3.4316390079836694, 2.914310741809107, 1.8615535742813543, 3.9266396722485943, 1.2291600050464755, 0.3687123569750017, 0.25862757537153463, 0.5315436098364092, 1.8271947147384768, 9.056397753377116, 20.351596147783344, 28.567378982420895, 30.386066321403753, 44.695525784646314, 39.44713954002627, 17.32164755944283, 2.139865472432106, 0.005547299637504283, 0.06907732075741214, 0.06692322707104106, 0.034854775069341544, 0.03839343861346284, 0.09365241013226971, 0.021600391032294403, 0.05545579099787339, 0.05242545360458955, 0.020177227580138755, 0.05510663110462408, 0.030183636305493214, 0.04140609086701467, 0.05250232669735148, 0.017598407087667335, 0.03434920683503151, 0.054173264051637346, 0.03448129954537557, 0.053675908279875596, 0.036547258646497806, 0.07290186150179756, 0.04323050244561127, 0.038531368913789915, 0.060220329286230195, 0.03167120285422331, 0.14428349812665295, 0.1735080976880366, 0.14986334548842523, 0.07884005415103129, 0.17516508458122132, 0.2077604250441636, 0.1073516020551324, 0.1645038219829721, 0.16515887312350735, 0.32240669333165695, 0.14951780919105778, 0.17664236256912833, 0.0956595681547638, 0.09992249505293947, 0.1452293409214866, 0.12567722959624184, 0.1446863224789981, 0.14619067401414917, 0.1700655743479729, 0.16978941497302827, 0.18487262900077528, 0.09082484855166367, 0.14831163439779513, 0.16453877091407776, 0.21388781076717764, 0.18066818525473918, 0.25860018006736235, 0.10649132362056164, 0.15409204357814404, 0.14538824287874086, 1.6508309783474093, 17.237163628301314, 49.84025163035239, 62.79323585571782, 45.12513906724992, 37.87582628188595, 40.46247643809165, 35.10816658696821, 9.306552794671829, 1.7808723810218998, 0.18784717987141303, 2.503251005564967, 12.944636441046192, 19.796906325124926, 15.710924286996166, 9.496521026857438, 6.4385980944479675, 10.168067082282036, 25.924878197331584, 36.66886591142224, 51.27597247400592, 54.18787733201058, 59.49810758713753, 59.91563212487006, 60.01382473976382, 58.78931960751934, 55.81018532476118, 54.19079949778896, 60.5142407263479, 58.21404910856678, 58.60188522646504, 54.93546147500315, 54.50255732382498, 56.306188644901404, 56.43865493036086, 56.07245068396292, 56.538149772151826, 59.69581073330295, 55.80807901197865, 58.00787364282916, 54.722084537629165, 54.10716672097483, 52.4086941442182, 52.44567817257297, 55.84516109958772, 57.25962269690729, 50.672194188640965, 42.53046374167166, 44.56647196123677, 42.06329376466813, 43.608542873013405, 44.094379409666985, 46.07012433390464, 44.725010241231615, 44.58797831689158, 47.03766715142035, 55.79269155379265, 53.37007884056338, 57.541566587263546, 48.33211991094774, 41.089016237566554, 57.712381885897734, 53.30968610702023, 55.10388020546206, 49.34227928038567, 46.11209761711859, 45.30252433592274, 42.73959275214903, 40.611149957103116, 41.744895365930375, 38.88338511989963, 41.32025564870527, 42.36373947512719, 50.38630831626154, 54.728948685430716, 54.08484058995401, 55.073069987758515, 57.596424856493556, 54.8160017690351, 54.07681149821128, 53.07855652224634, 56.333303989902625, 51.4808496352165, 51.75701195193876, 53.684986329847774, 54.01866628277687, 52.3637241701926, 46.87103309938985, 39.24623573980024, 41.4235395000827, 49.12652146431708, 54.80298342243318, 55.27348349171301, 52.890298443455855, 53.49921111137637, 54.79912381018362, 56.6085288601537, 56.28317609910042, 53.47635153801211, 40.95163522228118, 28.997247219085697, 11.114970387951022, 6.843842181467242, 4.835492064875941, 5.782500784243307, 8.54911369662131, 6.725664109952989, 11.945036092112142, 15.611893265478074, 6.502029193985847, 1.935817402216696, 1.3565503757807518, 2.4510109184249758, 10.73660385224127, 22.287770240537583, 39.98348443738876, 41.28620163086922, 53.59665847593739, 43.602376907102524, 19.90580112703385, 2.632289874938227, 0.14323135297144615, 0.12794467365188947, 0.19101161329496294, 0.15743863738832936, 0.13628132671358126, 0.1433830383804537, 0.133821556284543, 0.1668031889224245, 0.19886597570392395, 0.17542811320914378, 0.10869734274644045, 0.16637725935828301, 0.22350814373743152, 0.12991965598156377, 0.14763825843411107, 0.15499031231287988, 0.1279363386152733, 0.1488701124945956, 0.1480493258925215, 0.099116210495272, 0.11388650824946743, 0.1004003040913132, 0.20895898492345888, 0.14585370257977517, 0.08682020053627991], [0.04737123065898496, 0.06302228820840679, 0.07728714796323931, 0.12150617196194588, 0.036318631196815165, 0.005864449025642488, 0.06617394711581931, 0.005618804369136812, 0.017217249617040638, 0.047454060085358164, 0.036151413355142846, 0.03707221273573176, 0.025029339294339863, 0.014544232868619505, 0.06288866715265379, 0.064642675251009, 0.008157828987966622, 0.09934414463538317, 0.044863821052375345, 0.08128585113633065, 0.06659676636298818, 0.1108894267329766, 0.07257086555323294, 0.03695507789210927, 0.012914000638580371, 0.020833037147719054, 0.0327765892049478, 0.05845031761113675, 0.013427328385953462, 0.05622088300785231, 0.07340426962341993, 5.09464894571612, 29.670578933531242, 41.590204931074574, 37.09384295248216, 26.75350243045438, 23.825874751613988, 23.91223357569787, 9.640280796635537, 2.0597817051795224, 0.28008863990825994, 0.8855022778434138, 2.2009568781621995, 4.842564588592899, 3.578791382812685, 5.35722662364283, 3.336057956180265, 4.7806563492744205, 9.720642316725947, 18.756627075133785, 34.69665504270984, 49.902213311964466, 58.57746847214238, 56.394849900276434, 56.00251482379053, 55.179895739401545, 53.39614691272859, 55.418399380099395, 53.265547675471154, 52.85789574346235, 51.21901181436355, 50.74913540194112, 49.29703081807783, 46.813221285420084, 46.463487071375695, 47.37070775801136, 51.38050756146831, 50.81876923961025, 50.909254397115404, 51.4675174990008, 55.1885877117034, 52.98417252878989, 52.495445205319314, 50.9767113193389, 54.273228106960175, 50.009341086110766, 51.34220561673565, 41.737603679780044, 38.87439112509451, 44.57554832581551, 43.184887670701556, 40.1547037401507, 40.30273006808373, 38.54800678068592, 43.94864766828476, 46.66728558078889, 50.032290873988984, 47.37785039409515, 52.905097546116004, 42.333796101231734, 36.70833280009609, 54.388628159799886, 50.71760346812587, 49.69887371986143, 47.86167475485033, 42.607632452441806, 40.80193796465474, 39.52919160166095, 42.30230731348838, 39.345016710219845, 34.66078496748401, 37.30191292301301, 44.109884538958156, 49.897698663896136, 54.099263145077614, 53.78447724926857, 51.671512126922615, 51.79072472356981, 50.1153588294983, 49.12168910426479, 52.206860742261334, 49.62123432467061, 53.827505650058875, 50.870015005911554, 48.45393303901919, 52.07043286292784, 49.341483039240686, 43.59787402614471, 36.863517453593595, 38.29375090137605, 43.17998470798616, 49.21141724432669, 49.66847535102598, 49.462464624835604, 50.0670156171245, 49.51096473201629, 53.862446123553866, 52.13097072416737, 43.746194531840665, 27.70328671701493, 13.91582412104453, 2.8586905521731225, 2.5066146831358633, 1.4212737737163421, 1.123002404647489, 0.9341060213984983, 1.2739211128604029, 2.290780871145187, 0.8471701186030143, 0.11621525466081598, 0.07369395045022811, 0.2599662680539393, 3.9226800395596415, 12.539288901513624, 22.05841552826666, 26.18712394468246, 40.268530922551314, 37.65320431801581, 26.238136329958518, 7.208728511487284, 0.3355766640555474, 0.05088087096209488, 0.048002640326176925, 0.03260701947334794, 0.033000198778726404, 0.038821773693686536, 0.025691773607245377, 0.07997230145960085, 0.04377970704808832, 0.030590639667465325, 0.02419982886602802, 0.05885724053387681, 0.03758425441300196, 0.014008555463665437, 0.04828074556444922, 0.08629318567052965, 0.04630318534890971, 0.03127899456528887, 0.023268419167687817, 0.03626657935279993, 0.037045870802455375, 0.07262217812240124, 0.04402576682848796, 0.04708978910780242, 0.041905312062872034, 0.058852375875557625, 0.05049730989060575, 0.097785048457163, 0.06138051965183789, 0.03158611346847348, 0.028602419338459452, 0.042558172191943855, 0.05719602483535006, 0.0225099480725945, 0.04010058894392945, 0.032301231647931763, 0.03952939761802554, 0.037173451254925424, 0.04901087332156397, 0.03747818953988533, 0.0679658191098321, 0.05286126953339385, 0.045502474080891385, 0.07095773719371327, 0.0016200335648459113, 0.06181851127034715, 0.0350543218214185, 0.06304916257279054, 0.09455568908203034, 0.03282401004746076, 0.07767990592025942, 0.05770519751334383, 0.015102429428107798, 0.07844389476362737, 0.04815579279355946, 0.0194134877153462, 0.18490949315169167, 6.3945390908948845, 35.80934909082229, 47.76626702277891, 40.49769932223905, 27.305517196655277, 23.800308742830833, 29.040495272605654, 12.84510531733113, 2.80957585861606, 0.1244319843188409, 0.5131172034288607, 2.139038097473883, 3.1822397583915345, 3.984620393283906, 8.629013357623931, 3.2799290841625584, 6.165114266257133, 15.158918346128157, 22.904898312784013, 39.12179854608352, 53.86159889159664, 61.43367567370015, 57.742992062722486, 56.900168849575905, 55.98771964350055, 54.44777357962824, 57.6127968295928, 55.19268266616329, 55.63858555209253, 52.32062908910936, 52.63694863165579, 51.15377495365759, 49.82834723687942, 50.31768645009687, 49.469579804328184, 54.39589631172919, 52.87221239459131, 52.86950203680223, 53.432256252534934, 54.632430922600534, 53.77647561411704, 53.58981001761652, 53.86792959705476, 55.82781245631557, 53.43089911245531, 55.19665210477768, 43.57368084692186, 40.51290635139712, 45.66563383225472, 44.848490376626295, 43.05384912798482, 41.884543511175345, 41.23107664046749, 45.36388981726862, 48.42085176898588, 52.99104844370196, 50.0572253811744, 54.45602624647079, 45.31172621634699, 40.236167446259536, 54.2377188897902, 51.88878005550754, 52.5647456415238, 48.85312834093648, 44.189724383815644, 42.42797613143921, 41.12617677257907, 43.8208293914795, 40.712147066670084, 36.94614218127343, 39.86050244300596, 45.93137441142913, 52.72006365560716, 56.806306531352384, 55.975117068136896, 53.733729623979144, 54.992806526922415, 52.41671539122059, 51.75932615034042, 51.62360429763795, 51.14157638242168, 52.79387873987998, 51.55507656835741, 50.576649173613525, 54.13962041178058, 51.75435258496193, 45.06890796845959, 39.87774518228347, 40.973008217350134, 45.08715091213104, 51.505136951323486, 52.02565508504068, 53.15843166843538, 51.064945036365145, 52.72947734402072, 54.32807853144985, 53.929428438986506, 46.73270287052278, 33.035099814015055, 17.32676233014753, 4.747931034334244, 2.683610901717217, 2.8468182731059293, 1.9349255532987657, 0.5980839231802572, 0.20606760055788104, 0.7203390533404966, 0.6325171851823408, 0.11900294902584246, 0.1348957494502106, 0.32382000297788655, 3.3599243529381293, 14.11423231324842, 23.64619685757545, 34.09936043523973, 44.787607346811605, 43.583404402579035, 32.111212976517216, 9.011986717101067, 0.5713492319468529, 0.04492565583918364, 0.04290891405675681, 0.02126513371965097, 0.05878412510238348, 0.017098519395315842, 0.021675992419102022, 0.022661300233354973, 0.09570775508520105, 0.015033427888767855, 0.06033017097281353, 0.06762935329348811, 0.07314343966784016, 0.04476075158304265, 0.13824306338304473, 0.061029927174170176, 0.06894589071312258, 0.014867352475712617, 0.05296455733778496, 0.04320202695746576, 0.02941604301844153, 0.02411830561956571, 0.06653561722487211, 0.05069437451780804, 0.017504819871617422, 0.03831668426432917, 0.10307822571766954, 0.18346550934497388, 0.20622711538547472, 0.18973456004694586, 0.06894749949776358, 0.1343661528681555, 0.17395157066564407, 0.09659776539211312, 0.20879530257755713, 0.12320510216898496, 0.17359466562348028, 0.21698752508288432, 0.12818367010162723, 0.10850122423782464, 0.24029195038301332, 0.15903793786081577, 0.10816220734869281, 0.17985487567080607, 0.21871666213677776, 0.2333169036935414, 0.12463110589211988, 0.1827753407339896, 0.1670048232640951, 0.19315688930932554, 0.23420375771820548, 0.09961764568523054, 0.13445386993548564, 0.1312429656184489, 0.13736721038097335, 0.12293944585948222, 0.25880923014014, 8.307251526463418, 40.666961362285, 52.46052434367519, 47.90892754831622, 36.533069533686486, 33.62846028420233, 33.55159359593546, 14.134843387911397, 3.147231378862935, 0.5866415113691361, 1.8308164107222713, 6.735738717740582, 13.406803434894933, 11.051210299614938, 16.402697024806855, 8.027254112305181, 7.464206699402102, 14.953266516808542, 23.834366683037054, 37.70319884823215, 52.6915519468246, 62.26873259390555, 57.8643423511136, 56.23468383666008, 56.42049043409286, 55.949982520072695, 58.358953229842655, 57.1573547394045, 59.480256880483324, 53.992613900092344, 55.63847964809787, 52.075912414058564, 51.14093311371342, 50.46282199121291, 51.521081386073945, 53.963247114612216, 55.28312859996673, 54.8768259632972, 54.13226204533731, 57.58788193425825, 55.16142137588994, 54.37442133503576, 52.768803027368364, 57.33674433923537, 55.36923246998941, 56.110023067843535, 45.9761090432444, 42.509792850863555, 47.71738252332134, 46.146465424568426, 44.95051122480824, 43.42281864535424, 43.5210544063199, 47.73367604901714, 50.26426376834993, 54.18716346063922, 52.54101530198128, 54.4270360085272, 47.14746998202416, 43.97337821222121, 56.83155875052176, 54.89023262454618, 53.23153288133683, 50.85151710817891, 47.017976853155325, 44.621824449108495, 43.209598602787146, 45.96667574297997, 42.03526450741676, 38.630796247913, 41.44062926692348, 48.96546110030144, 54.48296900718443, 59.27212022965955, 57.942879969073886, 54.386133532370295, 55.97357949902935, 52.382053406007834, 51.5847179197496, 53.54993520244476, 50.55726089785176, 53.117301694808475, 52.68822577691848, 51.723373705340975, 56.828891538804584, 53.9413877456419, 46.92650325836674, 41.41895817172143, 43.03585329363423, 47.762909473911414, 53.60464049923805, 55.10074230932421, 54.167916390203665, 51.705777952747965, 52.01382521660098, 53.82465016457343, 53.49519852669009, 46.0289708260567, 32.03818824983413, 16.627652798929525, 4.551880186603916, 4.331827375196642, 8.171930245814785, 8.75810444355011, 2.311949657817041, 2.297156438712151, 6.685338222211407, 3.989971241643352, 0.4572178819967855, 0.3106498177493772, 0.64754746253452, 5.8955493761647135, 18.221099991952222, 31.033049514216763, 38.50243276165378, 52.41615056991578, 50.70825253763507, 35.47360597118255, 10.515823441167033, 0.824530381829508, 0.2736435728448053, 0.14976081228063953, 0.08141063919831669, 0.23364292007059823, 0.13059822602137444, 0.10648331800175291, 0.11882198373636893, 0.15211181354618844, 0.1460036106647984, 0.12569154777954664, 0.17446302628565222, 0.1903380075049016, 0.14756888151168823, 0.17733400206892722, 0.23663156695904272, 0.12055914939170885, 0.10011598587997499, 0.13100705650304595, 0.1360191407823755, 0.2511240352666186, 0.1580810633998725, 0.14391079635149048, 0.09374898317600451, 0.13439295062374684, 0.10223506168732721], [0.03354032906974035, 0.028099168520120364, 0.03849538576398646, 0.047810290970148585, 0.034102978515288526, 0.026738632755774646, 0.013326652941384144, 0.036352400352517446, 0.04393647162003383, 0.0659343531175006, 0.039923377485284885, 0.004545758898940779, 0.0035457024557305683, 0.013101915303137035, 0.07269233645450685, 0.06519052770829971, 0.05852704514719306, 0.01933094174150498, 0.015470869839191439, 0.02200014528728301, 0.02570718155062247, 0.04398747009315318, 0.06303122462404352, 0.052169829216455264, 0.05519490741613892, 0.1104489414982738, 0.00780174796912639, 0.07066936637725561, 0.07517492864280939, 0.09882744897397296, 0.04132134239039114, 2.2326121214897405, 16.223607486294163, 38.7676045971532, 42.93345589791575, 36.86335663641653, 28.82435110307509, 19.572678150669223, 15.11223037396708, 4.174985520301327, 0.6701829705026843, 0.10233702032916969, 0.2060201643936096, 1.401796018885028, 1.951637056566054, 5.013913329570524, 1.8823888369144934, 2.395438287527331, 4.542157121243016, 13.707975764428417, 27.038078231196252, 39.150082757396085, 50.61587679770685, 57.938177047237275, 55.036325223984264, 52.39912748336793, 60.77842020219373, 54.649736419800796, 54.53079054432531, 50.571302983068655, 47.83116655965006, 44.628472866550574, 43.5259142229634, 43.86978841597035, 46.02748424776139, 44.01760293591408, 46.58753202807519, 47.395665799417806, 48.43150884874406, 50.389226559669744, 54.46617734047675, 54.27679746381698, 56.31799890149025, 51.76148737630537, 52.56102331223027, 49.746036298813365, 52.58298858519524, 45.6852456831163, 38.91948269259545, 41.30553499344857, 39.280085794387325, 40.38681391746768, 41.91063119519142, 40.95207060537031, 44.26957991815383, 47.51321138874177, 50.72579337704567, 48.20937325877529, 60.363319689227694, 42.437123098681056, 34.21436825106221, 55.21940969651746, 48.800411685820556, 51.18041176949778, 46.104143050409135, 45.35881034789547, 40.532188723164225, 40.069403956013346, 38.40628762398997, 35.67341935250067, 36.77771952844436, 39.209698861645116, 46.45881945087064, 51.94283423885223, 50.094895824309326, 51.098999054201194, 52.63461482140326, 51.1082636925482, 49.382597323386904, 51.32337823990853, 52.00695322405908, 51.360036711538996, 52.500179506117306, 48.64391696068549, 52.22456632121917, 52.03741042844711, 48.25808909631545, 41.311493073740316, 36.06703312166276, 37.96497783353252, 40.683458851229766, 48.24149747048655, 49.55583664678758, 52.67031231234151, 52.29671439816875, 50.02260261966337, 50.6556417865138, 48.07143918929562, 33.685864171674176, 20.67218715144742, 7.353407096478247, 4.162492281006229, 4.82245949968215, 17.565273815585723, 26.52745035386855, 6.021148081748716, 0.7568098640730305, 0.5499923553678298, 0.04016952919623545, 0.05269178024102604, 0.0777338614927665, 1.583240205241788, 4.308949170574065, 15.902931171078837, 25.332182568888513, 27.470158684638243, 42.197203482351, 34.61815664845128, 15.277977970338638, 2.0822583571557076, 0.1151269271729454, 0.05676334986703531, 0.030684690366709427, 0.04580414418371455, 0.04445284169407622, 0.03250201180156681, 0.027765069915462407, 0.11870956033348076, 0.09320085492706107, 0.024342066495709365, 0.07100374077356632, 0.07421770944230019, 0.015808509685279384, 0.06795326292875313, 0.02920921843108391, 0.037450744439997984, 0.06124746933158848, 0.045725505258287155, 0.020067217354212078, 0.07049002519418156, 0.03966919334244825, 0.05405578829888856, 0.09537126628621932, 0.017401440136675394, 0.08060060847069948, 0.03172395758390908, 0.016255493260799878, 0.03048372252153293, 0.051548030122273394, 0.033110752927079316, 0.05173631538186343, 0.015760664621578352, 0.036472193521237185, 0.03539611194883624, 0.02332874093084566, 0.025350852989621704, 0.03101099402673783, 0.05425784398891753, 0.002883036401227958, 0.030194081914340778, 0.04900466417893768, 0.009245643196927925, 0.04885833755496049, 0.03865924814055043, 0.04949801331085544, 0.1034451665116414, 0.01941679338473947, 0.05939703374620407, 0.015811662137087797, 0.0701876579513473, 0.013726771088136781, 0.06882148569509869, 0.0214869755455443, 0.10034203544379243, 0.03766459022318164, 0.04397507862097794, 0.06597658754476617, 3.0101362063038737, 20.932634492074293, 43.892345966831336, 49.01473783677625, 36.93777968806606, 29.340348705168697, 29.338130604836252, 16.4897697202621, 4.221665157425789, 0.44048839098503517, 0.05793138114254802, 1.6179204539906595, 3.442535352322363, 1.7851503385651497, 6.051875929678641, 5.538390605680404, 2.495394252961682, 7.144417820438263, 18.753008688649825, 28.198605583560084, 41.48024912803404, 51.102760607196444, 57.91467028279459, 54.94924860615885, 55.78131275792276, 60.45371855458906, 56.22876890244023, 55.900007601707216, 54.24893294611285, 50.89528291456161, 48.883616924285896, 46.158146242941584, 45.45620279927408, 46.95255956342144, 47.109936821845274, 48.91302685583792, 50.22662078180621, 52.38639939215876, 54.2296427296054, 55.60472373039492, 54.73142370100945, 55.47970210352252, 52.840201931615034, 53.1877003946612, 52.08223527477634, 54.63735741953696, 47.65288306820778, 39.54049587249756, 42.86493993574574, 41.35086190315985, 42.310297181529386, 43.707061044631466, 43.00873010389267, 45.26386545550439, 50.16274498355005, 53.18759841303672, 51.87790724538988, 58.34402468896682, 44.01893261940249, 38.413708748355994, 54.95392799377442, 51.0641723294412, 52.62664848758329, 49.3220555397772, 45.74363800787157, 41.38998362325853, 40.83698826451456, 40.19260560312579, 37.55794563601094, 38.29639065650202, 40.64673762167654, 47.28909500183598, 52.746959347878736, 52.323865044501524, 52.54979356642693, 52.4874278806871, 51.30835556214856, 50.32744138471542, 52.06824025800152, 52.32390819057342, 52.9403910329265, 54.099329825370546, 50.795282087018414, 53.87896322434949, 52.97372333465084, 50.223443661966634, 44.55793688374181, 37.352005512483665, 40.999233184322236, 42.14114889021843, 49.64980094663559, 51.00617224170316, 53.989942766005, 53.95504151621173, 51.71672921026907, 53.685080466731904, 50.5203043260882, 36.791918508468136, 23.260839677626088, 8.18308791806621, 4.640404649319188, 3.8624429750827054, 15.285670718839093, 21.232254543612083, 6.309353055492525, 0.4593932652665723, 0.29588028608310607, 0.05499515382032241, 0.052826098436790134, 0.030199802675915342, 1.8528195590742174, 6.393693329826479, 21.36463257574266, 31.665847455301595, 30.32368494618324, 46.35664955262215, 39.00775563332343, 19.662184676816388, 3.697110904801277, 0.12043210137034617, 0.020547175269213416, 0.03222636570553145, 0.049781362420969436, 0.022779691461173278, 0.015101791659910834, 0.05182985471741808, 0.09146538232603381, 0.10863282282145754, 0.041068380157793724, 0.03783404121115323, 0.06975235913189189, 0.05833342025477079, 0.05235765865373035, 0.03279144748023922, 0.01458380801317793, 0.033564066304074186, 0.010927762562078575, 0.04383415291686693, 0.00892268446829891, 0.05170075741085795, 0.10066313353637535, 0.009731319958284017, 0.026407483589625167, 0.013716045857196855, 0.08661180929911715, 0.1042185246103233, 0.14151706270152523, 0.14964540879572594, 0.08027859107260743, 0.13676296619157638, 0.16587496614984928, 0.1821566481263407, 0.09342656741219182, 0.1303397479557222, 0.2847758416206606, 0.17019115148052094, 0.07729080220263812, 0.07545068199115415, 0.10499637964512072, 0.1521206848443516, 0.15396085868199028, 0.16159167663464624, 0.10822025383071554, 0.11794557149011282, 0.16404657474448606, 0.17568738800623726, 0.22013754073169925, 0.15273116498945222, 0.15325794236794596, 0.1146440236498752, 0.18288004963148027, 0.14508327859784328, 0.17695927782164467, 0.1736636441801825, 0.17466764837022752, 0.18134569809321435, 3.355745312667662, 23.486756432440973, 51.79621211944088, 53.874907493591316, 47.270314693450935, 38.82421224348007, 31.315832791789887, 19.29363681424049, 5.930763434979224, 1.0484581272448263, 0.40244198254039215, 2.4279365952937835, 7.653699344204319, 11.569552498479045, 13.599305518211859, 9.21723650347802, 4.665340627393415, 8.534849997489683, 19.32008339512733, 31.418243915803973, 42.1603371251014, 50.9908083177382, 57.74387851838143, 55.21887233180385, 58.630424391838815, 64.47870577535322, 59.4660069096473, 59.152040789204264, 55.45202978195683, 51.27787874590967, 50.281577110290534, 48.08874468649588, 47.23698239172659, 50.106168716184555, 49.33209680741834, 50.78355027783302, 53.19395657508604, 53.422913166784475, 56.07670253322971, 57.68329751107001, 55.964083440842174, 57.770676151398696, 52.654093311678984, 56.333339291234175, 52.73534128742834, 56.51984407055763, 50.180066170230994, 42.727080391299346, 44.65885162353516, 42.95466415343746, 44.7200955114057, 45.87279773527577, 45.929962358167096, 46.74280297371649, 52.48413701211253, 55.00100035821238, 54.34903575528053, 61.90532499744047, 46.502475430888516, 41.75206545860537, 56.226619443585804, 53.70368034608903, 53.85274610211773, 51.796400393209154, 48.71233094123102, 43.676003717607074, 42.127506886759114, 42.91703685637444, 38.721155889572636, 41.09421730041504, 43.45421329621346, 49.80175748948128, 55.36386666759368, 53.806862215841974, 52.19798834093156, 54.06002375387377, 50.50996495831398, 50.2822046895181, 51.63486542240266, 51.27792189198156, 52.75949524294946, 53.65313668404856, 52.62899014257616, 56.00398963497531, 55.67338089789114, 52.3649283378355, 46.53247371796639, 39.176699961385424, 43.2615033272774, 44.177259091408025, 51.73691372717581, 53.80679945791922, 58.61662157120244, 52.6783610159351, 51.04011643317438, 53.74345317963631, 50.589844026873195, 35.772435665130615, 23.785162510410434, 9.317909036913226, 6.07762776074871, 8.784989349303707, 28.94722523227815, 34.89975929260254, 9.179810227886323, 1.890016743733037, 1.4131663571442328, 0.23531856886561842, 0.2005351740386217, 0.2334637474268675, 3.209093530331889, 9.750813188091401, 21.047956097510554, 39.61968068153628, 37.80875767430952, 55.39559471991755, 44.617882467085316, 22.405113827797678, 4.030641807663826, 0.19345034694960042, 0.21703655471003827, 0.08325583857273863, 0.09288266030771118, 0.10906734789210944, 0.18356410486082878, 0.11026183218364755, 0.17649937991894063, 0.2735060140971215, 0.11213936812935338, 0.13452635717488107, 0.12183339875792304, 0.12959929333338815, 0.13111674497204442, 0.13927412579857534, 0.12403440000789782, 0.11449056091688334, 0.1738671171328714, 0.12738811843577894, 0.12712492892939237, 0.20480116528849449, 0.2125033979574519, 0.21176729471452777, 0.13695436559857863, 0.13092807283805263, 0.14985576121797486], [0.04581227620703079, 0.07094654464913953, 0.0499462245422746, 0.03649738249218753, 0.07340731099247932, 0.024973702158838994, 0.008989241229550493, 0.0207633710271048, 0.0343628240478856, 0.05511293217780129, 0.06356649025673829, 0.057875314997809554, 0.026423462268505848, 0.01861788433856301, 0.037495901492694696, 0.02632919897986276, 0.08684347428741955, 0.05369475787325252, 0.049947040425913955, 0.03567703639066989, 0.04115705483502919, 0.07050064317281209, 0.050527141354377234, 0.0769045023668197, 0.05780991024127411, 0.03439178983230264, 0.04533188162191261, 0.05398994687223627, 0.03518841019080531, 0.04521122660427805, 0.059766042977571494, 0.21924265810558874, 5.6386047121017215, 26.54174739314664, 42.41488718217419, 37.39042905069167, 21.758075721802253, 21.11049044516779, 37.46300074361986, 9.359491063702492, 1.8475514482105933, 0.17811378764529384, 1.6401023153335819, 2.195880840862951, 2.706605061408012, 4.877146655513394, 2.9562001843606276, 6.905935752776362, 1.5977198798810284, 5.446720402086935, 14.86334716120074, 35.34506597826558, 47.072462497218964, 55.06772379721365, 51.728774809068256, 56.958572941441695, 55.84597303021339, 54.72393197398032, 50.711253150816894, 46.885028116164676, 45.60443309045608, 45.08313832744476, 50.19861505877588, 50.8308893634427, 50.71912534775273, 48.83747808394894, 47.49237575838643, 47.13269441358505, 48.79729340153356, 49.50339455758372, 52.84126097156156, 52.60584031381915, 52.856083608442745, 50.717081792892955, 52.69947513457268, 52.02336442086005, 52.50373317349342, 49.33519155748429, 42.80826168675577, 39.5504508479949, 40.322494891382036, 39.99949947480233, 41.18308251903903, 38.08344517984698, 47.822913892807506, 48.52394342422486, 54.07740769847747, 49.73897211013302, 66.9817663008167, 50.42252356006254, 33.11578296845959, 54.168540047061065, 49.197057447125836, 52.00506264163602, 47.51513727249638, 51.50720011803412, 42.07298201899375, 40.012411917409594, 35.02168224703881, 40.45725968576247, 38.67600548651911, 41.98860006947672, 49.56210067195278, 49.57762149072463, 53.10349887417209, 51.92769388998709, 51.98349352805845, 50.872709674219934, 52.265994394979174, 51.819181519169966, 50.87922473107615, 50.45419669920399, 49.74972332677534, 52.49015000558669, 49.04741510268181, 48.98453558644941, 46.28605081189064, 40.32856672040878, 39.46122477131505, 42.05426446853146, 42.47716265340006, 48.434689890953806, 50.16391777223157, 51.165000777090754, 51.449572655462454, 55.59296838698849, 48.65541342766055, 38.014109442310954, 23.570752028496038, 10.028674871690813, 2.7798847421523067, 1.7977497270030363, 0.686124095753316, 6.980957456173436, 13.07246550436943, 3.695564265212705, 0.3907565982832063, 0.06157958376852255, 0.09885141986512369, 0.13994788480622156, 0.5330080635124638, 0.46327944544534533, 7.309405947885207, 16.39511606385631, 25.484692165928504, 34.553645426227206, 42.883292705782004, 20.691504824546076, 7.596122382148621, 0.23381325205968273, 0.041026478978775205, 0.07187780112989488, 0.019255114358759696, 0.043137346154018756, 0.08733224604398974, 0.017465764709237604, 0.08144589456459207, 0.021967902561769854, 0.009579409510948727, 0.022088473309732733, 0.019186788892012932, 0.04172541546605287, 0.013102529131086364, 0.030136077567153884, 0.07665836597762762, 0.04022703941671118, 0.11188079813315023, 0.021211838897978588, 0.023992067736182964, 0.09326755820262818, 0.060719780308464845, 0.029319433585530328, 0.012953909031385857, 0.036685246403419206, 0.03666635467520645, 0.07432724469371381, 0.07063555891715712, 0.016531817344648224, 0.09797804898792699, 0.00975598990466566, 0.04316574503337184, 0.015318290980142212, 0.039193211423773924, 0.06579592102958311, 0.01601551621851902, 0.028247979184192036, 0.04710915581052823, 0.05029905782712083, 0.07311130994029584, 0.024894798933077725, 0.12275147086550152, 0.016526196174503818, 0.027230959160313494, 0.017760179959417834, 0.027472914624658805, 0.048418829082361156, 0.05966860425448226, 0.004332744799959924, 0.06505198070719358, 0.028466712608332598, 0.06681191449564311, 0.030765231105408845, 0.06361479210036416, 0.06683944003476251, 0.0675368941419067, 0.016793930497501167, 0.05691993823875824, 0.3547790255998412, 7.554330998851408, 32.642776504639656, 48.51169386217671, 42.26068704358993, 24.430204129988148, 23.207626842683364, 29.28310955724409, 9.608077156928278, 1.8131592485212513, 0.1666824381437994, 0.2684026734242516, 0.7281103105314317, 2.149393154728797, 5.810433453129185, 7.556326014380302, 2.9231588734734446, 1.1370280649392837, 7.821555704839769, 19.78918710062581, 36.883341112444484, 49.69918358710505, 55.904267295714355, 53.07782696139429, 57.09259248548939, 56.57309024564682, 56.43870984354327, 54.15239949380198, 48.71679067611695, 47.512403380486276, 47.29054235642957, 50.86317831470121, 51.06911451585832, 52.910282919483805, 50.74344796519126, 50.08559196226059, 48.643779677729455, 51.26986142127745, 52.397758576177786, 54.42094064527943, 53.64407993132069, 54.816507754787324, 52.31438859816521, 53.86539966829362, 54.36255224289433, 55.08922623049829, 51.6347752078887, 43.59235525131226, 39.77671669375512, 42.14143914561118, 40.80123978276407, 42.1259928518726, 41.62580828512869, 50.24775451229465, 50.592946621679495, 54.62419786760884, 51.91704857733942, 62.476312268164854, 49.85632942568872, 37.477984197678104, 52.61075112127489, 50.578771175876746, 54.3188609615449, 49.94702639118318, 52.63270854949952, 43.09317481133246, 42.836263487415934, 38.01986355935374, 42.416852289630526, 39.70331738072057, 43.04782436740014, 51.33221533990676, 52.31807170375701, 54.641197419935665, 51.37593407784739, 51.16573426031297, 50.92612451122653, 52.24150311562323, 52.34089205341955, 52.27429020789362, 52.7511013707807, 52.106573581695564, 53.808611592938824, 51.6824516173332, 52.010550037507095, 47.82178425019788, 42.86424959859541, 40.84149506784255, 43.38200638371129, 43.51109943082256, 51.05018123503655, 53.06633833915957, 54.40316838602866, 53.58245165117326, 55.00187504676081, 50.660642808483495, 41.415949713799264, 26.157653216392767, 13.43092110849196, 3.1792327713581825, 2.3317434085953623, 1.6121473379673499, 9.53142619902088, 17.62983210625187, 5.290482101901885, 0.5112775198874936, 0.04860563579225733, 0.2011469718549521, 0.18214106589796084, 1.0518743890908457, 2.47782644725615, 7.79880742872915, 18.204361277241862, 28.379332711619718, 39.96385297467632, 48.47713385858844, 27.716230538583574, 9.388811761333097, 0.6757944113304538, 0.10602170406209846, 0.03304333335930302, 0.0396102850115107, 0.00468445576599709, 0.09195015510363926, 0.06942753785199697, 0.020433836391255743, 0.022623650842316212, 0.05271634485031809, 0.03788662165583622, 0.0312307846522139, 0.05071292533689449, 0.05349510386886616, 0.020377921548882322, 0.03747148627054788, 0.045454597416063475, 0.05728352356762175, 0.02654834417626262, 0.03923834932427253, 0.08707022099124809, 0.00838766685656963, 0.04944912157952786, 0.061150321721910476, 0.013046546298409662, 0.02514276818762864, 0.05534094675714451, 0.16869819933368316, 0.13569837976847926, 0.1587513903336179, 0.0948493229225278, 0.15324110375537028, 0.10626945689681078, 0.11970724429815047, 0.13908736888439427, 0.17476609066849755, 0.11130780267018466, 0.18914007581770423, 0.09760085027664901, 0.16967966521699585, 0.0958313480500252, 0.1788527254135378, 0.14725979567775804, 0.19775534739657757, 0.1600111606380632, 0.09435752511865671, 0.19573629202861942, 0.11998587047621129, 0.15604057289179296, 0.1777909122287266, 0.13588420205539273, 0.16588969035975396, 0.07380006894949945, 0.18656070374192732, 0.23815041287772118, 0.1434885286876271, 0.1087502564393705, 0.11718124556805819, 0.4170135570870292, 8.390151800647859, 37.64599500163909, 56.30487465089368, 50.01140033045123, 29.65798224172285, 30.808909593089936, 43.803739624638716, 12.28952217486597, 2.4516434006152616, 0.41524518100965413, 2.8375452997223025, 4.727229254861032, 12.147213682051628, 13.066301499643634, 8.829292520400017, 13.387278856769687, 4.838352453324103, 7.740854899729452, 19.732767728067216, 42.613641523545795, 52.46345827656408, 57.71488828043784, 54.179522683543546, 57.92719833312496, 57.78817776710757, 58.887629893518266, 56.29919113651399, 50.082705097813765, 49.073789119720466, 48.80902128834879, 54.003078783712084, 54.969397821734034, 55.22408908413303, 54.09847082630281, 51.231979170153224, 51.624180886053274, 54.24052730683358, 54.6652219372411, 55.91086079997402, 56.3795252000132, 53.65062636713828, 52.77410214947116, 54.362846420657256, 56.442875400666274, 57.62045329616916, 54.12002817276986, 45.99498348851358, 42.59555939705142, 43.855373705587084, 43.94466254018968, 45.264563637395064, 43.234948881210826, 51.58069356795281, 52.633234147102606, 57.746255474705855, 53.87585278480284, 61.514068572751945, 54.20680669046218, 41.127329949409734, 53.7228960375632, 53.713148947685, 55.471884819769095, 51.459002033356704, 56.10987009540681, 45.88696925870834, 44.95450419764365, 39.555153769831506, 43.56831896689631, 41.93407912408152, 45.90089759519024, 53.76687757430538, 53.42174037810295, 56.08453550646382, 53.29718551328106, 52.283390106693396, 51.22346370450912, 53.70699867125481, 52.92922404504592, 54.332969727054724, 53.54900952308409, 53.58008253958918, 55.268196136720725, 53.199263541929184, 53.212897700648156, 49.44585338715584, 43.934009382801676, 42.86331999686457, 45.757456517988636, 45.86024615072435, 53.57214758473059, 55.17187841476933, 55.43076269088253, 54.168630261575025, 54.68228424749067, 50.52953366310366, 42.24202048393988, 27.978080126547045, 12.802026906321126, 3.651365282074098, 4.791883153300132, 4.019035269175807, 10.256078204801007, 15.12253934337247, 6.194139805532271, 1.3212311484159962, 0.17532306723296645, 0.5071843121080629, 0.3436682992164166, 2.311916562818712, 8.3919100030776, 16.818601623658214, 25.106897315671368, 38.483825037556315, 46.16037807156963, 55.00816260614703, 29.4276253638729, 11.11844756910878, 0.7499938265931222, 0.2207724744033429, 0.15025109323042055, 0.1331275878774543, 0.12394191787367868, 0.22575060566586835, 0.20998503712396469, 0.21563167203097575, 0.20371912738248227, 0.10844846376247945, 0.14014515244672376, 0.19753123603520856, 0.10389462263593752, 0.16002524133411147, 0.09783930280396054, 0.16926450684906977, 0.16142941921228365, 0.20289886172019667, 0.13801987132718488, 0.11909648836139711, 0.16165564497632368, 0.1406711943808102, 0.08758710817463937, 0.09488231832942656, 0.1807830524781058, 0.059927859899377635, 0.1676165138281161], [0.036051228206845067, 0.06530618400222833, 0.04694814328104258, 0.0487333809536311, 0.03581394779405767, 0.0810195130085753, 0.016749372908605203, 0.051549481858889905, 0.057605636726704344, 0.013154920926618, 0.03165409802609394, 0.07728977564481959, 0.07145787769507977, 0.051115477728026534, 0.03368547591831415, 0.06817044885528666, 0.024810782070421887, 0.03227422321816126, 0.03263142320417589, 0.058087245561182506, 0.033197087205706105, 0.027379631928558794, 0.0803757846475609, 0.01684774625896206, 0.02890128364425994, 0.022353618255546017, 0.04908391597470449, 0.03229977608087563, 0.08074430358265677, 0.10392237034055496, 0.049042244622063254, 0.1267865325714792, 1.1116444463691404, 12.4983952506896, 34.88499941364412, 42.84812865718719, 27.334507434598862, 47.72490562931184, 37.95320287827523, 14.472017192071485, 3.9088284344442434, 0.283568088686274, 0.34737429551539883, 1.8100317711791687, 2.3761022283184916, 4.950226295378901, 6.624158563152437, 1.6803865278920822, 1.3648447178063856, 2.056342276834673, 5.360555245030311, 15.031522704708962, 31.28494804905307, 44.8204218956732, 56.72977716692033, 58.3537325551433, 56.15697776117633, 53.14434251477642, 50.566721654707386, 50.96702698738345, 49.79218690626083, 50.348076974191976, 52.11833284747217, 52.7694502184468, 52.84495192189371, 53.32451266627158, 50.61644161901167, 48.47739273501981, 48.85993365318545, 47.63602864357733, 51.263856272543634, 53.73892676445746, 53.51630872295749, 52.24899484265236, 49.80895896111765, 52.14412635372531, 55.29555074630245, 51.12976612583284, 44.746708793024865, 37.78167370826968, 38.598138593858295, 37.47027281791934, 41.611554391922496, 42.97524875210178, 48.16008475518996, 51.6215842769992, 52.019822520594445, 52.36716016646355, 39.522527494738185, 38.673961931659335, 35.670579556495916, 52.08958971884943, 49.03500080108643, 53.53544204465805, 50.337788597229995, 51.29053623445573, 49.04996464329381, 44.218498891399754, 35.643770156368134, 39.81932147856682, 37.80125025779971, 45.13615308269378, 52.103294480231504, 52.38787812571372, 51.16959387256254, 52.45981831704417, 51.827241989874075, 51.614406339583866, 52.161149440273164, 49.96189609650643, 48.39957683317123, 47.68112021107828, 50.24500493080386, 49.45427079354563, 48.649106256423465, 47.43794894987538, 41.56972623640492, 38.751193400352236, 43.902277408107636, 44.524090751524895, 46.328545770337506, 49.25934076309205, 51.06947929628434, 54.34803555088659, 53.40962809901084, 50.7328732552067, 43.81354162769933, 28.549781268642796, 12.522768858940372, 4.863478666351688, 1.7544007950252103, 0.20935353552622182, 0.2503675234413916, 0.702293944214621, 0.5230306569607027, 0.4324227415265576, 0.24416781901832552, 0.02745913461812081, 0.15927847414728136, 0.12042108502599502, 0.010291488236567427, 2.975980697139617, 13.791815446269128, 23.643170748987508, 32.0494278015629, 38.5599111741589, 33.4786335883602, 12.597233095476705, 1.9445742162004596, 0.10489802927740159, 0.07054846238104567, 0.15405766155210235, 0.010133771800375994, 0.05829890416334233, 0.03532966914316339, 0.044714667563957554, 0.02983145802582224, 0.019498678607745998, 0.01460362575016916, 0.05157067185087551, 0.06294691281753682, 0.023865004393061804, 0.056823805695579904, 0.046093644979860515, 0.06673954216943634, 0.0683605612345761, 0.1080240204089111, 0.024050995219318617, 0.014897884909934817, 0.03552642350475635, 0.02599741587595594, 0.08813463121412263, 0.023266881246179826, 0.04704295432255153, 0.017236660369822097, 0.12006486180208384, 0.06847908269734153, 0.04252144210641423, 0.022745945288108724, 0.05100785386598399, 0.04359791821409618, 0.056651569978003545, 0.04160981662871857, 0.02963417314834172, 0.01611368655557594, 0.030862861350479148, 0.056622427993363915, 0.011894864296811003, 0.021382766520424236, 0.036972318700845205, 0.05559098636431079, 0.04072519191991418, 0.006125653885500205, 0.04582060358276771, 0.07365290345924516, 0.047147958163893035, 0.10124442573156088, 0.06641830618102705, 0.006945485271693718, 0.02157954577987473, 0.03836313983605754, 0.012830223178400869, 0.05907951711466717, 0.02900997428373704, 0.07084496139037995, 0.0391147103941729, 0.08075001093769267, 0.17991714329729158, 1.8607730226170633, 16.2949328461001, 42.856977524295935, 47.0733214962867, 26.785061820860836, 37.398822922860425, 43.80003690719605, 17.89562563742361, 3.8887701688274263, 0.3142263451891561, 0.19429092926363792, 2.5326084754159375, 2.761884249987141, 5.901110316476514, 6.959044644909521, 2.675951248215091, 1.5657287836074831, 3.8857325382771033, 8.001182608066067, 19.75340920109903, 38.736951274256555, 51.14429066258093, 55.25845296921269, 60.27647056887227, 58.07937452870031, 55.06251881199499, 52.09536737011325, 51.66526379123811, 52.63022568918044, 52.910537873545, 55.15002296816919, 55.4997532598434, 55.54080086369669, 54.52997861369964, 51.84428076590262, 51.26344050130537, 50.56505464738416, 49.93685960769654, 53.47953650259203, 54.222770737063506, 55.42933494813981, 51.33889905868038, 51.333886269600164, 54.460282018107755, 56.63231019050845, 53.26836393725488, 46.74277943949546, 40.206702601525095, 40.88997948554255, 39.47133664161929, 42.662973173203014, 43.275906270550145, 50.32313854463639, 54.07389717717325, 55.204998908504365, 53.74121350626792, 42.30051479031963, 42.88481850777903, 39.23378221450314, 51.228731447650546, 51.71636050747287, 55.16164887335993, 52.297102712815814, 52.1930657663653, 50.79000257676648, 44.14724903721964, 37.3958654557505, 41.784974144351104, 39.58007258753623, 47.141790390014656, 53.00471398138231, 53.436143321375695, 52.618635085321245, 52.917092154102946, 51.81799304100775, 51.423253551606216, 53.30291609610281, 51.36877967465309, 51.21329299865231, 49.08071994781495, 51.85661662009455, 51.082187775642645, 51.517331600189216, 49.81769800186158, 44.24987000803794, 39.4707247518724, 45.41584161020095, 44.531433428487475, 47.41985505627048, 51.11380600160169, 53.480015031753055, 55.67880945820963, 55.904573240587794, 51.229288424215014, 45.43327654561689, 32.86920512876203, 15.874191964826277, 6.950351692015126, 2.575676835352375, 0.9151015250432877, 1.3455628363355514, 1.988162903055068, 1.042062947827001, 0.25049814143248145, 0.20503405601747576, 0.11026590011052548, 0.14495540320152236, 0.2972274363761948, 1.1337597499932013, 2.335388025929851, 17.296030559847434, 23.6202189999242, 34.833549684093846, 42.704695424725934, 40.299372519216234, 14.981192811842888, 3.732186454919077, 0.12161421334190715, 0.06858281866316834, 0.04606326193278355, 0.017800767297646212, 0.03623475606042532, 0.05211368646292437, 0.09184844160993254, 0.037525426521296465, 0.02750635436255365, 0.013706361548224045, 0.014246783910259126, 0.09100762946951775, 0.0219126982659462, 0.03549791354265425, 0.0471623950908261, 0.051990308002719, 0.02902139090902863, 0.023560254616783034, 0.012519712420931507, 0.03050199563374683, 0.18261783305675755, 0.04497573883723348, 0.029916482294098507, 0.045515432458130584, 0.04651641826175394, 0.09119089302276412, 0.038473552258144465, 0.11079474592641478, 0.15903825961774395, 0.1319149932673862, 0.14418583723806566, 0.1109451749512265, 0.15957508806980428, 0.11862250210176553, 0.12713035283189628, 0.27490924202626754, 0.1453346320457997, 0.18541521843402617, 0.20451287108082927, 0.18369729690734418, 0.2500420433258818, 0.24545965776328119, 0.1428207298440318, 0.0639556322787558, 0.10659518216045634, 0.15709379057009376, 0.25181265637999584, 0.18076000855334345, 0.20676201329596583, 0.18065453356792852, 0.10146675210806633, 0.1325133692232832, 0.13359188312484374, 0.13981565803049073, 0.15439196700049987, 0.1956317669922306, 0.22836819020730836, 0.20885873465768753, 0.2341690079699601, 1.710200708719992, 19.075860938718243, 49.537931026950965, 55.06186377617621, 37.26190866962556, 59.02881560787078, 45.93811304338517, 19.485901594161987, 5.17097189541786, 0.7352409343565665, 0.9542358702709599, 5.016788917203104, 7.712661393227116, 15.866159931305917, 15.931167333356797, 5.290158506362669, 5.155023538297223, 4.901205003261566, 5.959639924187814, 20.336265563964844, 39.76028196273312, 52.54583589492306, 58.88121681828653, 61.795004413973906, 59.5731346837936, 58.112369506589836, 54.47981542156589, 53.843748184942434, 54.866992581275206, 53.533178837068625, 57.08703840932539, 58.62989487186555, 58.00826195747622, 56.51208954472696, 55.12579840998496, 54.0951995695791, 53.25671057547293, 51.58175260789933, 55.59576111455118, 55.89292380117602, 56.782717397136075, 53.63684315835276, 52.30777155968451, 54.273510517612586, 58.48776386630151, 54.91706163652482, 47.70097917126071, 41.694528210547666, 42.56804789266279, 42.27985958899222, 45.94109012234596, 45.245948068557254, 50.658948344569055, 57.260489540715376, 56.3368772691296, 55.07562345074069, 44.814707002332135, 46.48283612343573, 41.73149262705157, 52.25049318805818, 53.25051323060067, 57.067873708663456, 55.64504569576633, 55.1888701223558, 52.82625006091211, 46.80748678022816, 40.31226927234281, 41.85767919786515, 40.44049155327582, 48.630839778530984, 54.908922718417266, 56.41628957563832, 53.55332413027364, 53.86999668613557, 51.10077588788925, 52.14715050112817, 54.584468180133456, 52.22021641269807, 52.76376278169694, 50.01067076959918, 53.757742374174065, 55.62670469284058, 52.501838668700195, 52.719400775048044, 46.666567787047356, 41.31637250223468, 48.18196373601114, 48.250436552109264, 49.33100246614026, 53.396527382635306, 56.316724131184245, 57.84757029625678, 55.729396266321984, 50.97014134930026, 48.02648882712088, 32.80868099581811, 16.60832924227561, 7.4016949053733585, 3.0129058899418, 1.545619404604358, 2.890573047822522, 3.2972615476577514, 1.5865370799456875, 1.4814870588241087, 0.9655799163926033, 0.3249031593722682, 1.0188748146737776, 0.81047187168752, 4.52492565877976, 8.735002663827713, 22.791588883246146, 34.32062918140043, 42.083188026182114, 50.45328670932401, 45.496787563447036, 19.18397911133305, 3.510817688318991, 0.2578430094065205, 0.21383856663540488, 0.33032111703388156, 0.168365104304206, 0.1362627260987797, 0.13680620419402278, 0.2285553148436931, 0.08138387208624233, 0.10406687750571197, 0.11024087201803924, 0.11036438837407098, 0.19198783913687353, 0.09203073989239433, 0.16860055376685437, 0.19940304930412, 0.16306929170123993, 0.17753031976040334, 0.11650632210676709, 0.16816149345569073, 0.08693662291813282, 0.2535149190695055, 0.16811157516654462, 0.14854241072410537, 0.14920320752407276, 0.15997212079744186, 0.2049949242463035, 0.20901300944387916], [0.03402831175574853, 0.02927218511280033, 0.0495926826260984, 0.029116180883119666, 0.0714877168197305, 0.05090969118980631, 0.05204654651724043, 0.034200509168928674, 0.05862603902876858, 0.04093330353498459, 0.031050210067581747, 0.0647767789421543, 0.03913712229639773, 0.04857643635102338, 0.011736603938193332, 0.052408507739704464, 0.049343903233567556, 0.06319249762342342, 0.0352400406864622, 0.0037770804004638547, 0.053509207547552166, 0.09527729028054784, 0.0187498927792354, 0.05294930835765216, 0.04270474396405682, 0.12151027819322002, 0.0359351352427996, 0.06012420823437072, 0.024273109006425066, 0.03830908084168069, 0.07447942805987212, 0.08254452593504422, 0.1786144720690866, 4.39394889339324, 21.597474275096772, 44.092379000879106, 36.16673584907286, 36.20952106291248, 24.054817615016816, 20.845595136765514, 9.429231785958814, 1.7300361346813942, 0.06906932279948266, 0.43059087208201813, 1.8355011915968311, 3.74018588373738, 8.9866913518598, 0.15430201295643084, 0.6114380614411447, 1.213234446702465, 2.4011355302026196, 7.5084333842800515, 19.18669535267738, 39.1104236725838, 52.33017613810878, 57.581896397375296, 58.27811710296139, 55.20721504765173, 53.52726390284877, 53.996340151756044, 54.74842325333626, 51.19019416070754, 52.58045081169375, 53.48908747396162, 54.868883163698264, 52.720793216459214, 51.971687193839784, 48.73497870660598, 49.566042653975956, 50.50897259866038, 51.529741979414425, 53.84667819546115, 54.12165987876154, 49.54015501083867, 53.32585411687052, 55.27375021288472, 53.486883101924775, 49.20770668214368, 43.13095508083221, 39.539193645600356, 41.747515509205485, 38.1563110505381, 41.83768295472668, 46.1320036457431, 48.5693762379308, 49.60278741775021, 55.884141614360196, 49.99835060488794, 53.4879852879432, 41.9442694417892, 32.84129354261583, 52.822284544667895, 51.824335513576386, 52.028204625652684, 51.375796794891365, 53.80434013182118, 52.49427241663779, 49.78339687470467, 35.83742149414555, 36.82768660206949, 36.44688721626036, 49.668949957816835, 50.84424503387944, 55.050516359267704, 58.06868999235092, 51.106467247009284, 50.90500647021879, 52.53206837561823, 51.62119596235214, 48.239650034135394, 46.300073285256666, 44.699765866802586, 46.160605569039625, 45.50350266118204, 41.27732922953945, 39.95258792754143, 38.87901559952767, 40.72722465761247, 43.751207320920884, 47.59876220457016, 49.474698497403054, 51.07691218776088, 50.054695452413256, 54.09137525866109, 52.44168127736738, 45.33972017226681, 32.33898893479378, 17.105417097768477, 7.212353271822776, 1.6946927602252655, 0.11368479729900438, 1.153692622338572, 1.2369438260793686, 0.6894867314446358, 0.3938036670367564, 0.046802762775651874, 0.11856427175864098, 0.11026675812900068, 0.06586935821800463, 0.04048558259983698, 1.6571979657296212, 8.07292717118417, 11.159487328221722, 20.45206569856213, 35.89838297136369, 34.24899493494342, 25.6776806231468, 7.0485546031305875, 0.6109328111333232, 0.022109128955391147, 0.0107840521283628, 0.017247142367846063, 0.10534024587081325, 0.05949934478849173, 0.05259130014887741, 0.05701843416318298, 0.023668669464607394, 0.06041058339178563, 0.03095221210030779, 0.012612658038344837, 0.0324518253816472, 0.014316518978786566, 0.034364367715053024, 0.07120267848574346, 0.05697479396457634, 0.02296141900813147, 0.00598486751363042, 0.030342634023738005, 0.07486319980554043, 0.02801912190813211, 0.038941088057453596, 0.05535345697294801, 0.04676590245517512, 0.017529221687225566, 0.016278738283642357, 0.033277687316219655, 0.06547063243605437, 0.06265181574910399, 0.044401808747000275, 0.0547096366813827, 0.023797676755836415, 0.05763827207227869, 0.0026725762478646735, 0.025626401409446716, 0.05000492602947259, 0.03207047830425924, 0.050109064191459655, 0.01742584769794297, 0.012600182296497928, 0.03787656675183004, 0.029450358011789864, 0.03520158690310294, 0.070786340342414, 0.05008638032802171, 0.020622069939910885, 0.03290362190455198, 0.04008077024932831, 0.11713944781090944, 0.005099718034597895, 0.044024958605727846, 0.06717368419612608, 0.0692553902345319, 0.03773518522540408, 0.09240005555893145, 0.12692593759106052, 0.01844979507187682, 0.025007406197067712, 0.023360483783988223, 0.23037019245807203, 6.4732179141813715, 27.724318465878888, 50.53724504286244, 37.464801111528956, 42.18866840485604, 32.46606392245139, 25.923168043936453, 10.825072911477859, 1.1849707052592309, 0.12466217075744945, 0.5032800828977939, 1.471470918866896, 4.576883335267344, 7.39490234082745, 1.5232992797128617, 0.6643434193345809, 1.5864999400031183, 4.1076065551850105, 9.716862132472377, 21.608013683749785, 42.9382098105646, 57.15503269626249, 60.96137915888141, 59.61563748698081, 58.00453570581252, 56.67284788623933, 56.97672567059917, 56.68998472152218, 54.12104798901466, 53.399308343087476, 55.21837811316214, 55.99737259649462, 53.9633059501648, 53.292537504626864, 50.9364442671499, 51.886218747785016, 52.4821993612474, 54.03302607997772, 53.96535734976492, 55.24600336628576, 50.78293054334579, 52.542631318492276, 56.47083405525454, 55.467158363711455, 51.54882431030274, 45.02224353051955, 41.19157837283227, 42.68886473871047, 40.57696650105138, 44.853660060513405, 47.6672036417069, 49.12708628562189, 50.75238704681397, 57.01290169069844, 51.99521749250351, 51.87844853247366, 42.55239371330508, 34.94450176915815, 51.26008295243787, 50.35819276686638, 53.01421396193966, 53.4134602546692, 55.02604469176262, 53.60771171508297, 51.51713155931043, 37.097384852747766, 38.703720954156694, 38.48701000213623, 51.229998373216205, 53.55916061709004, 55.632297992706306, 57.807938668035696, 51.67319874609671, 52.42220670946183, 52.630382583987334, 51.750477283231675, 49.879667528214, 47.87904693234352, 46.185995071165024, 46.83966590512184, 48.6444111793272, 45.83034984527096, 42.42322614116054, 40.74490277997909, 43.015700155688876, 45.4533237795676, 50.03142403018091, 49.740027227709376, 52.543862942726385, 52.49437832063245, 56.28067754930066, 54.206120275682025, 47.626791461821526, 35.694611918541696, 19.86254915114372, 7.504829216387964, 2.6537430334475736, 3.1261268210026527, 3.1557627791358582, 1.7878034542645178, 2.179399286547015, 0.715740196887524, 0.10131466067245892, 0.041856653988361366, 0.14537586289788448, 0.4218514636158944, 0.3545499040234474, 1.711549758911133, 8.584577806534307, 16.41157432909935, 24.558659791946415, 41.05003964516425, 40.041260950026974, 30.964892448917514, 9.827322940672598, 0.8048003695664868, 0.01728785611058195, 0.01878171032595058, 0.05305429687723518, 0.036209321941339204, 0.02467023941027301, 0.05343923307654839, 0.018098310101777315, 0.016271491091878667, 0.016692533015063214, 0.02323264286162392, 0.011285365701863363, 0.044895977592997016, 0.0268903756213765, 0.019800162934247526, 0.05767181523204331, 0.03392532272564788, 0.057218957677363395, 0.056221698891491666, 0.039378980084532694, 0.07458186167622767, 0.04057280937089555, 0.0577034738155142, 0.06560216973265333, 0.09670136346211357, 0.04376575658698717, 0.01949799487427358, 0.045993509627277815, 0.14362893728238924, 0.15695742691957182, 0.11745467766999237, 0.15228557760917372, 0.10812621653801012, 0.15100018932454048, 0.16282058891750154, 0.07303642484569743, 0.18808822177590864, 0.16993091141264285, 0.15445670143010157, 0.15273205365144438, 0.18137062659427045, 0.10298138454316125, 0.22522482420167617, 0.18355745521764602, 0.14452781888746447, 0.16482154928868817, 0.15169123127575845, 0.165518612690991, 0.20047060814836334, 0.17796257721079936, 0.11922321462583159, 0.12687882318371727, 0.13897663853581876, 0.15817823399218822, 0.16633535434882488, 0.16467963916159448, 0.2760697426574846, 0.12360339128081838, 0.18252435500823683, 0.2571782289493469, 0.3735194054822768, 7.400705977793663, 33.12464360267886, 56.85291997848019, 46.96083184211485, 50.785735038019, 35.090613980447095, 27.038225320077714, 13.224174937894269, 2.217775756312955, 0.2797011219926419, 3.7064284951456137, 7.537049035872183, 9.691613835673179, 18.072112683326967, 2.4878456515650598, 1.44933563566977, 3.2634227698849094, 4.81084781308328, 10.085924806133395, 21.54077249188577, 42.919821739196784, 55.094568498672984, 62.354773706005474, 62.04755013988864, 59.30167921127812, 58.47520443700976, 58.662230891566125, 58.16692183094641, 55.42820922790035, 55.88620870344101, 55.83245262022942, 56.33245283557523, 56.685536753746774, 55.49671342295986, 53.089668596944506, 55.35153473577192, 54.62062066601169, 55.38880901951944, 56.98884187206146, 55.61044254610616, 51.21773704405754, 55.74038674754482, 58.723004095015995, 58.089215755462654, 53.00392558497768, 46.14746955133254, 43.54608305038945, 44.6303673713438, 43.48031666971023, 45.275954200375466, 50.41341973889259, 51.7412361791057, 53.18048323354414, 58.84578997089017, 52.64033755948467, 52.93988896954445, 47.08353534821541, 38.25283273573845, 49.1352173589891, 52.68244420328448, 54.33702153544272, 53.52468298327539, 57.348115290364916, 56.05067368476622, 52.11763466558149, 39.484986489818944, 40.943253117222945, 40.9287364252152, 53.134650338080625, 56.09658502763318, 58.06351246372346, 59.0662467864252, 51.46011990885581, 52.07679102497717, 54.28507758725075, 55.2781746464391, 51.750418447679095, 51.23793725044497, 47.82449460798695, 48.69631590381746, 48.89960842747843, 46.10498243762601, 41.76694300866897, 42.06627868836926, 44.354130529588275, 47.53786740764495, 51.59771665450066, 52.59389669664445, 55.43901928009526, 54.32816090122346, 57.2897582669412, 56.07230947863672, 47.72662362744732, 35.915127569629306, 19.21949617324337, 10.424978406198564, 3.080658215668894, 2.142730518694847, 4.7510846199527865, 2.613095021055591, 2.6129699955063486, 1.0899078966148439, 0.7686969133154039, 0.1873963218062155, 0.2601981781903775, 1.0389029883569287, 0.9695894367271854, 4.056594905353362, 12.226537735231462, 24.347451925277714, 30.62966904332561, 48.64603896294871, 45.21642046590006, 34.92163042868338, 10.854245539634459, 0.9990419014807671, 0.18401536129174695, 0.09746395802545933, 0.14430065849615684, 0.12542196909987158, 0.14127804326914972, 0.13485943688259971, 0.15432029181430418, 0.13824068851047946, 0.1481897651308006, 0.17949734243654436, 0.10693845849844719, 0.12412782443026382, 0.15390251342567707, 0.21990584509987987, 0.15934467946569766, 0.1592721309392683, 0.20535123173988637, 0.11786484880553139, 0.1968632839740284, 0.2045118904882862, 0.15742231971554219, 0.20686100717754136, 0.18872546903308363, 0.13955394707379803, 0.13616115816177862, 0.11322457763937213, 0.1315166888337943], [0.01940026886821274, 0.03162936679267835, 0.05849391950534717, 0.09360094434551655, 0.05485712009812555, 0.16225543053400132, 0.050969296660754955, 0.02841351546287056, 0.04026620949227964, 0.016428659775204236, 0.008515169742637345, 0.025328056128214926, 0.07146777555106149, 0.02295783754708546, 0.08567561921212943, 0.022865317108470107, 0.04126953186407205, 0.0411106490590159, 0.06887232328975393, 0.04027309662271892, 0.06623415396578851, 0.07784457651958351, 0.02003726523159252, 0.010091594829704734, 0.04588915696067195, 0.03043064795013878, 0.01656218315474689, 0.015946263785383875, 0.03977497859347252, 0.018885252854576515, 0.04177917568613926, 0.04142286819255641, 0.023500639569735336, 1.1344823241233826, 15.86028127901016, 37.52579789007864, 47.08971308123681, 29.766014122193862, 20.37142961255966, 21.69412539851281, 16.359053792492038, 4.310602449601697, 0.30203316721224016, 0.8370815373716817, 0.2776563413921864, 2.9641383261449876, 2.8349008867817544, 0.49032906010266275, 2.0564106731645526, 0.4498318751012126, 1.6392317943034636, 2.1718933409260166, 9.791992191345463, 27.669281728806038, 42.11448461778703, 55.07300330746559, 57.68180701040453, 58.01644794402584, 58.23800302320912, 56.4764940354132, 58.410387269912235, 56.99692979935677, 54.87597088659964, 51.157940510780584, 54.346160657944225, 54.020015578116144, 49.62352891122141, 52.644361911281464, 51.72740982424829, 52.47694730758668, 54.850020485539595, 56.23455832081457, 53.74790506978189, 53.72262931639149, 54.997262339438166, 53.12223995885542, 51.59635166968069, 46.53972225804483, 40.64247008292906, 42.237737255711714, 43.56291786316903, 39.461056109397646, 43.09605775340911, 49.099841502404985, 53.699785432507916, 52.6722695750575, 54.25332600070585, 50.980833730389996, 53.010283747027, 44.158235596072295, 34.151269082100164, 54.81605275984734, 46.27409150523525, 51.38949763390326, 50.568286680406146, 53.541682535602206, 50.733253725113414, 50.5390493331417, 37.12921488669611, 36.81224423070108, 37.283564075346916, 47.46468382496988, 51.11351966857911, 51.72741374661846, 47.19669572768673, 49.93291762567336, 51.62098415436284, 50.2753758430481, 50.19785411896245, 48.598778324742476, 46.870715387405895, 45.983106551631806, 43.12360455912929, 40.215080784213164, 41.23870957282282, 39.310797952836566, 41.17926997523154, 43.38253982605473, 48.211463882077126, 48.670161539508456, 50.89237643826393, 52.02729463577271, 54.2055711438579, 55.536313672219556, 49.318415580257295, 38.53113666657479, 21.122341886643444, 10.145334005355835, 1.2969970294544775, 1.926156359334146, 5.247952822716006, 2.189637653289303, 1.5035578680615274, 1.5183318430377593, 0.20942844360345797, 0.0032201751779329275, 0.11476426881047026, 0.03193042594038191, 0.03969949595029316, 0.44450057730559384, 4.626899928815903, 10.482927503124362, 20.643330274089692, 25.439904582115915, 35.421881675720215, 27.346904085528468, 14.133206778957, 0.7874001226117535, 0.3033311346605901, 0.021598590725672343, 0.026986289829496416, 0.06356312330031107, 0.1612239544309916, 0.027827341372387546, 0.016020469934559398, 0.012270946434939341, 0.07389961441438045, 0.027640094161934914, 0.044691658113151796, 0.041641157285700885, 0.0690595398566896, 0.045401281526973175, 0.1056476386504308, 0.10875640812540248, 0.038173142369956746, 0.01622960714983844, 0.01973314556263147, 0.02153396546359985, 0.028802508097742836, 0.04829292636244528, 0.04128735489963044, 0.061837793703401284, 0.015569733485819833, 0.04557104278055411, 0.044758556741139585, 0.025854073164443818, 0.050570869653095166, 0.02039335439011695, 0.016481075510983507, 0.059193376932413354, 0.08880000921987719, 0.09884979575872423, 0.10035357272793209, 0.011454640489612377, 0.05499331137886452, 0.02114358429436482, 0.02686287306489483, 0.047752056796584404, 0.06437531822631437, 0.05932825820280179, 0.008911182615725745, 0.049506382821428205, 0.025575083094618978, 0.02216045876153775, 0.029889609844934557, 0.028415049553938934, 0.06335894554673184, 0.02154873372356017, 0.036845906532459685, 0.018064280476180777, 0.058703448383077506, 0.03985604218718025, 0.03371625733111174, 0.05781152668679434, 0.08009540412815348, 0.033400717206419475, 0.028067107740489226, 0.02063374320465711, 0.11795230540296725, 1.8803797253677923, 19.42661693019252, 44.65986359503962, 49.246228279605994, 34.759762056412235, 22.487236492095455, 22.58316589939979, 19.42608544903417, 4.58756051717266, 0.16172872976430003, 0.2377590185572063, 0.10992237096351963, 1.1262514754649133, 2.3313928467612115, 4.6460862025137875, 1.9870743227581826, 1.1859398984139966, 1.6800029936336702, 2.4269503643435817, 12.952375277396172, 30.319356610698087, 47.211965514767556, 57.82423611610167, 60.61475930675384, 59.30585653551164, 59.95983723671206, 57.64687045927971, 59.634947315339126, 57.145944564573234, 56.409856888555716, 51.51962618674002, 55.7666862395502, 57.03650259202527, 53.21513345164638, 53.080596154735936, 53.832604731282885, 54.15134045385546, 56.36991147072085, 57.29878756307787, 54.347839432377974, 54.1553726503926, 56.60478299663913, 57.287753935783144, 54.82506636650332, 49.44049542950046, 43.357346442437944, 43.158584256326, 45.202539197860226, 41.3126148716096, 45.04214171440371, 50.429462232897365, 55.453288862782145, 53.4076786810352, 56.40000389468286, 51.989926215141054, 53.887890538861676, 46.845918163176506, 36.48367904847668, 53.834259971495605, 47.996718037513, 51.02889060974122, 52.691053805812714, 55.4574897212367, 52.32168420668572, 52.50342722861998, 40.061292494496996, 38.40685244529478, 39.6325421333313, 49.23264118932909, 53.70774784395772, 54.65394120062552, 51.31663960795249, 49.46172329687303, 51.28207960436421, 51.02002605315178, 52.47120888002458, 49.7987372644486, 48.836928952124815, 48.07941729022611, 45.27195338279971, 42.24130661256852, 42.710892769598196, 41.56186580657959, 41.8792365443322, 44.16173827263617, 49.27673647480626, 50.361879794828354, 53.677106288171586, 52.220318394322554, 54.53590923740018, 55.901243148311494, 51.60069373346145, 40.27655609192387, 26.17629820300687, 12.91895962530567, 2.6253865034349504, 4.080261016084302, 5.252628287961406, 2.497614069331077, 1.7509451869033998, 1.5945126068207527, 0.13149617299918206, 0.11463415643741047, 0.06213774010839482, 0.04147536436756773, 0.11987062786976177, 0.41151565048963795, 4.557708828679977, 12.600966211288208, 21.86331291352549, 29.625716824685377, 39.71383717752273, 32.27988077748206, 17.54249857318017, 2.1303145010625166, 0.37742102999360333, 0.032728639761767084, 0.019782224985500498, 0.052731187803851026, 0.05591569273101707, 0.10608821581568449, 0.05695729651638577, 0.0033284418356244365, 0.024471814977005128, 0.05237322556035173, 0.07727245439685161, 0.033487442189887646, 0.06425325360689914, 0.015805505663006297, 0.04525305500494377, 0.08417186522555929, 0.03790819852222358, 0.05632394864674538, 0.019386831686020862, 0.021357393688372067, 0.0655472565502409, 0.0221444494391401, 0.10473695163044239, 0.049598757703337944, 0.06159365680369158, 0.04584764265605519, 0.055435106623917825, 0.02439946180299646, 0.10552616008827764, 0.14892000014022475, 0.18243639279277096, 0.2626497514786259, 0.1880308877556555, 0.20975703403594034, 0.23720466201343846, 0.060735477450033354, 0.11080991446731553, 0.06331280790149205, 0.15979622701002708, 0.19636062304339102, 0.1372295137374632, 0.12475147362678282, 0.19078765515117876, 0.1740418158231243, 0.14840154247658868, 0.07538479076878679, 0.1219767108259182, 0.12911180094365152, 0.13010368562273442, 0.2198958246698303, 0.09915410886488615, 0.12801372115650486, 0.15681651270677968, 0.09407850823575452, 0.17929414527550822, 0.1546773500740528, 0.20569770266452145, 0.22931942626112894, 0.13361478915377972, 0.15924229947549684, 0.25806342822409445, 2.2042033749241985, 22.940460481951316, 50.45504393116121, 58.169816540133574, 41.43298064508746, 29.44690577445492, 30.464374480708955, 21.838248968124393, 4.781105950955422, 0.6966825033868513, 1.7592217556891905, 2.3895861112302352, 10.12666646511324, 9.902285318220816, 9.397650822516411, 3.5525137089913894, 4.550211218095595, 5.1511399015303585, 3.1975649489510447, 11.834834160343295, 29.69241672946561, 47.35812479449857, 57.21986947521087, 60.26400527646465, 62.414962476299664, 62.25725966115152, 60.78754755758471, 59.390226717918154, 59.58361133452385, 55.93928621661279, 54.93128807313981, 58.55943733646024, 58.828602144795084, 54.394601929572325, 57.3900415051368, 57.28289019676947, 55.423851474638916, 56.653212501156716, 57.700226460733724, 54.74835657304334, 56.08268022537232, 58.98002132292717, 58.10135941351614, 56.425244346741714, 51.26673529225012, 45.09940047417918, 45.774640421713556, 47.34871110608501, 44.19233275998024, 46.350809143435576, 53.662075765671275, 57.564622279136415, 56.519855837668146, 56.23296191615444, 52.09832483722318, 51.23318333779612, 48.47538448149159, 40.41506674981887, 53.14281279040922, 47.29601798519012, 51.984544723264634, 53.91380171622, 57.933274084521884, 54.26867423519012, 53.39928480886644, 41.97394217214277, 40.72964868237896, 40.554707050323486, 51.47666054387247, 55.196048059771144, 54.91371193239766, 51.18897430358395, 48.61714678425943, 51.499186715772076, 51.56175636476087, 52.62895484124461, 51.107236031563055, 50.98146523198774, 50.02593271193966, 47.046253219727554, 43.988173392511186, 45.17438050239317, 42.4685138271701, 44.61017108732655, 45.944082890787435, 52.39711138509935, 52.88783519498764, 55.91235914537984, 55.83442557242609, 57.65451515874555, 57.639445412543516, 52.173716714305264, 41.26849605191139, 24.554806063252112, 14.08120595639752, 2.7851137518882756, 5.267854438674066, 11.536548695256634, 5.402045096120527, 3.617186483836943, 3.9598476838681007, 1.394608275544259, 0.3663381585671056, 0.272083021099529, 0.16523744310102156, 0.36499686118575836, 0.8226711783678302, 5.783372040717833, 15.022655206341899, 29.46674708397158, 36.6130898075719, 45.3453605405746, 38.926770456375614, 20.749095024601107, 2.803203477974861, 0.49166337076214056, 0.11909071971932728, 0.07600751299891742, 0.15759199286901182, 0.23447211831808093, 0.22641569255821167, 0.12963441080383717, 0.11682465462194336, 0.14109119442441773, 0.14256099539418376, 0.18421757786024004, 0.18102663779451003, 0.17857088166619503, 0.26724342917723043, 0.26224056859650924, 0.16693866391095424, 0.1824684152680059, 0.1293339204764174, 0.10935943423499984, 0.18813882954418662, 0.2092670748430875, 0.1838984103092263, 0.20677307560559244, 0.13755706229036854, 0.23370474336608765, 0.12441339902579786, 0.1645116973668337, 0.17294269415640062], [0.09087168716735418, 0.05065416256266256, 0.08224922202287183, 0.026976319195161906, 0.011833675896688815, 0.11495707781925318, 0.033425798925060424, 0.045537120407266964, 0.0071788418778939355, 0.06284096285760885, 0.04369826807129768, 0.031259106922774546, 0.035737810145703056, 0.014208162545166431, 0.09657821482828549, 0.04260049088888111, 0.06619722852783819, 0.040443577998948675, 0.040753613781904986, 0.04656379696943107, 0.050083147436981244, 0.01744833046330079, 0.047265793977966236, 0.04348405073547075, 0.0639974951533781, 0.005269711029775922, 0.007170420656386282, 0.051917376432327494, 0.0116690359408817, 0.01340701460703126, 0.019417766316403306, 0.03250862697079297, 0.058865020156747876, 0.21369644200369237, 4.795002418179666, 23.274848422696515, 43.043427390436975, 36.061286849360314, 30.793045566928004, 24.8912787437439, 21.926637618772446, 8.861504985440163, 1.110045712801718, 0.06969526259889526, 0.4809059641293941, 0.5911989377871637, 1.2650825419733602, 1.8005490735653908, 0.26045153878869554, 0.80444349516784, 1.1838223088172175, 0.20479188030285222, 2.97088602858205, 14.50467876849636, 30.380959395439397, 44.13747056838005, 57.981048553220695, 58.647431788905976, 61.0280006162582, 56.350684012136156, 58.3726893701861, 53.7672580442121, 54.27296138578846, 51.06053236992129, 53.84892571356989, 54.28656024317588, 53.2877286787956, 53.05759537604548, 54.64662990262432, 54.80979265705232, 55.07095583023564, 56.13010560312579, 54.016979663602775, 52.91216957953669, 52.98379598125335, 48.77291587091262, 45.611230557964696, 41.49655442084036, 40.919558079011985, 40.74525971566477, 42.901300307243105, 38.639927525674146, 45.37171102339222, 50.41551428456461, 53.78269649321034, 53.505655565569484, 53.24341766295895, 51.46878834693663, 54.55597216083158, 45.46503205453196, 34.32162154105402, 54.353954407476614, 46.98883756514519, 53.24838730596727, 54.09476418648997, 53.02569473943403, 50.914620199511134, 46.17704814480197, 36.2877841149607, 36.575184022226644, 36.98565221601917, 49.60136751974783, 48.50420997988794, 52.424626811858154, 46.57530207787791, 50.07926910154281, 52.64049837666174, 51.53858300178282, 52.596885542715754, 50.96723487300258, 49.329915969602524, 47.12185298242877, 48.29060946741412, 44.75384358436831, 42.11129180846676, 42.17970186664213, 41.307092174406975, 45.69294529576456, 46.230545351582194, 50.649797454957046, 51.66531478205035, 56.148964358914284, 53.10098463489164, 50.357525963937086, 38.35100181641118, 23.27957291756907, 10.565593415691007, 2.2297924276321166, 0.9002140464801943, 4.204386626520465, 5.877421652117084, 2.216174448690107, 1.3046335164577731, 1.7020521072610733, 0.14485032658182806, 0.06804415926096902, 0.04489434965615792, 0.028456019936129454, 0.23713609714421535, 0.9490962783175131, 7.782887999088534, 13.60139810269879, 24.24399352842762, 33.97280516162996, 34.2596951607735, 25.29687927615258, 8.152987649363856, 0.7263647332306832, 0.01729347919594617, 0.07955835351059515, 0.11292575738362728, 0.07654886136973098, 0.007063632308986159, 0.023333632402242194, 0.05533870978040561, 0.010516708510206833, 0.060867520364662336, 0.08111169636850396, 0.014387440525986736, 0.05327524046503729, 0.026524547570114656, 0.006168741064386503, 0.04488511446623072, 0.03836434259409866, 0.021982716787005627, 0.025080060060586662, 0.028312479956976833, 0.08473970491679446, 0.015479502692488174, 0.05399135264357733, 0.03288762981913263, 0.08105519738408827, 0.04433045148729317, 0.043593283382154284, 0.04050635890434346, 0.05259646358148706, 0.010703422331942186, 0.06034812807375866, 0.0336528405727398, 0.05266983565243502, 0.038644975922521085, 0.07165171326168122, 0.047415445423534805, 0.02970830556155453, 0.005486342021369286, 0.007158923113057691, 0.08316325684708935, 0.036904807202517986, 0.03241318007630687, 0.04822070342338374, 0.08159272297615967, 0.08096303700679734, 0.01782364651350485, 0.03031126080801891, 0.061073195820133534, 0.031368197843192086, 0.07013880452441593, 0.006574490436187555, 0.04945978169299422, 0.05208443339553572, 0.055870252225788376, 0.036819116437747594, 0.010535926783397313, 0.0595688519458617, 0.04615461408731438, 0.059045610063138514, 0.013364323399840825, 0.051502195081763694, 0.052769618604572556, 0.2702712844456396, 7.278217711756307, 30.1014454134049, 51.509239750523726, 40.475337889886674, 27.99370881049864, 26.727903081524758, 25.213381821109405, 10.693334225685367, 1.7255968696648076, 0.06841881456033838, 0.2572114158782267, 0.5087879792817178, 0.5693373624836245, 1.783068663170261, 1.038124397877724, 1.3669665974955405, 1.970227865442153, 0.5015425341984918, 4.002053122366629, 17.986481458910053, 32.71493634869976, 46.96379323159495, 59.674778984438994, 59.51227911057011, 60.214650092586396, 59.99013362392303, 59.64276459909255, 55.75521722916634, 55.377159580107666, 52.736137528573316, 55.81320162742369, 56.73546460367019, 55.68653652744909, 55.07867897710493, 54.34904360002088, 56.308294957683934, 57.236692520879934, 56.91201832986648, 56.11170576464746, 55.99194403617613, 54.06960218183456, 51.498774866903986, 47.53893821470199, 42.64130992274131, 41.79239134634695, 43.44184606306015, 44.753745525114, 41.13995998136459, 46.513493368702555, 51.07939897045013, 55.344980455213985, 55.454857810851074, 52.921426373143355, 52.13823103135633, 53.323273197297134, 46.36409028883904, 37.92686416256813, 54.244430065155036, 47.12636763049711, 53.507899161308046, 54.29222414570471, 55.37043271526214, 52.548373668424546, 48.71937159569033, 37.974924964289514, 38.6421868108934, 40.19935207982218, 50.81645111883841, 50.78583309727331, 53.88195991516114, 46.97107707300494, 50.74085920087753, 52.707594440829375, 52.245076394850216, 54.394476413726814, 53.059148634633715, 50.977107478726296, 50.02152396786598, 50.52100643034905, 47.335657458151545, 44.18420953135337, 43.78508090972901, 43.300009235259026, 46.40880138643327, 49.76916651571951, 52.0738100236462, 53.36601526506486, 56.826965655049975, 55.49577989885884, 52.88800385690505, 40.94372772401379, 27.988199841591623, 14.963337202225963, 2.5041869811473356, 2.3270314162777317, 3.8421407870707975, 6.756820967120509, 0.7613488430938413, 0.45125042478884425, 1.2280993716370676, 0.2114768094953991, 0.27724136688536216, 0.13730557094658577, 0.15301187492666707, 0.25400253403331, 1.4065027405177395, 7.718086521471701, 15.070759154135182, 29.11883284968715, 37.361599629925145, 38.0357373914411, 29.898156812114102, 9.741964320982657, 1.105938133212828, 0.06883323748385714, 0.05955151537613523, 0.06239318829630652, 0.015298323856005746, 0.02037250722247747, 0.03048248528953522, 0.050507602281868465, 0.02194186131800375, 0.08102353497017777, 0.053022308875956846, 0.02533415993375163, 0.038683812749842485, 0.021265666150758346, 0.0765074006912689, 0.06618147009923574, 0.027742914652692217, 0.05076791129765972, 0.03412241416592752, 0.012505753341341212, 0.03812452259984228, 0.049573587884585706, 0.022166556821415023, 0.004212006470263606, 0.045838660275143, 0.05226354858267212, 0.024860277095989838, 0.06678816576999042, 0.061948049077463735, 0.1668768559372233, 0.10108913204843, 0.19566363624988065, 0.14096357949799107, 0.1176923564485004, 0.19169119457083364, 0.07822531455707166, 0.07698795998529082, 0.13418650524991174, 0.1351218066749073, 0.26680504302344016, 0.15919452623253869, 0.12226316642256514, 0.13232953876497286, 0.23956782875522492, 0.1621211812861504, 0.137021045891508, 0.139712082943128, 0.15490492415283957, 0.1322192833909104, 0.1856196106922242, 0.17668665777291023, 0.125479816399034, 0.07450068699977092, 0.16571846970867726, 0.14406796695003588, 0.09172779042273761, 0.10640798857615841, 0.10564795274647976, 0.11948678717618028, 0.07042881476903154, 0.07126427195485562, 0.09895851129605886, 0.42780534574581736, 8.230793745287004, 37.06908495195451, 56.845718506843816, 46.72722331939205, 41.632205670879735, 37.68130417793028, 31.538813652530795, 13.200718183671276, 1.6178589218085813, 0.45437621673749345, 1.0573312640190125, 3.1344275368798167, 5.680884430485388, 4.350650829653587, 1.1781050865688634, 2.4453234816751173, 2.898957604362119, 0.6300559591862464, 4.070153558446515, 17.28225519580226, 32.7206120183391, 46.7347542701229, 61.76419419627037, 59.90484168452602, 61.739777441947695, 59.26928827839514, 60.87317682081654, 54.113081655194684, 54.71578128876225, 53.30064504377304, 54.560988872281975, 59.417640163052475, 58.59213421421667, 57.64364627099807, 57.38930802191458, 56.43189668655396, 58.95596934903053, 59.4104386914161, 57.65631944902482, 57.62366179497012, 57.11702492929275, 52.841323729484316, 49.59682541508829, 43.63564252853394, 42.99553132826283, 44.5251811704328, 46.56146395590998, 43.5656556775493, 48.91998514052361, 54.73864478449668, 57.01208191533243, 56.13511446983584, 54.23959378273257, 52.82892119499945, 53.70410396206764, 48.496125974962794, 43.478057384490974, 53.76377497949908, 49.03078033078102, 54.78701153109151, 57.45545879487069, 56.61810336574432, 53.87650782062162, 49.89830270890267, 39.41692944495909, 40.19236241617511, 40.4021974532835, 53.528883841729936, 52.55667340370917, 53.812973268570445, 49.44582200819447, 52.601462948706846, 52.62563651607883, 51.59842660350185, 55.28774915202972, 55.798547652459916, 53.37091430541008, 52.4901774621779, 53.135219081755615, 50.545591846589126, 45.691223375258915, 46.13900899887086, 44.20916365038964, 49.0534241737858, 50.53995540065151, 53.84870213847007, 54.7021588971538, 58.69092302937662, 55.20486554791851, 53.8084037073197, 43.29735771302254, 28.493614888960316, 14.341340488003148, 3.9711117504104494, 3.372414895603734, 7.032021322558004, 11.268225235323753, 7.741069649496387, 2.161312257089923, 4.37298039274831, 0.625423762586809, 0.5239825058848627, 0.2730075972935846, 0.2586265641354746, 0.5909659244841146, 1.886072187654434, 10.855261433509089, 20.43076918971154, 35.500411448940156, 43.900480962568714, 44.97533198325865, 34.218086657985566, 11.201965616595361, 1.2028933628912897, 0.1930269148320921, 0.13721857400190446, 0.29206385054895956, 0.16042668672819294, 0.10588782253645121, 0.1314144773829368, 0.12062890169721459, 0.10258547796477234, 0.16024374493187474, 0.19654618486041026, 0.16509285166619286, 0.1691206202151314, 0.11619262442353273, 0.17301199447003104, 0.17254330187795625, 0.13313083609025325, 0.10123879498531742, 0.07842786054337218, 0.09300984622490022, 0.21453543085484736, 0.1414259748473283, 0.17867629536457602, 0.18151489627217093, 0.23508826751382123, 0.1259549900949482, 0.12224284977081323, 0.12834872374491346, 0.15284618543040368], [0.03288740765363459, 0.07076044657057332, 0.04138399689127842, 0.07189174393011678, 0.031048698959151105, 0.05742414666700268, 0.0673475401896623, 0.040598193694266586, 0.06445011139036187, 0.05261082773006732, 0.024546468330006448, 0.051040339824413104, 0.0067013522024236384, 0.007915722700061217, 0.024710081727995027, 0.03679874615984098, 0.0842893984349024, 0.06834578339851673, 0.05057763037902694, 0.07918572068334588, 0.05035952131654467, 0.025805256126688856, 0.05559789264694818, 0.027323416396675092, 0.05842524738381467, 0.059124536271537506, 0.05920311007949133, 0.0853305732110335, 0.033206460291459676, 0.04890192412741242, 0.039326644787985476, 0.04065882189259414, 0.026509210489870563, 0.024579375636793917, 0.9432290866971017, 12.028260942428345, 36.291718252243534, 37.8384147151824, 37.172906168045536, 13.75098063099769, 16.113322204159154, 13.709951658402721, 2.884896887886909, 0.7177932512375617, 0.2312644928573601, 0.10869270791449856, 0.5969943622908285, 2.057392736596446, 0.026755186000598535, 0.1162360386262017, 4.2890632440966945, 0.030144678819323742, 0.7641524184615381, 6.044932353881098, 15.441280949500301, 28.58450601177831, 41.526944944935465, 52.99431185568533, 58.80691536011235, 59.85253687827819, 58.28375354889901, 58.15788469006939, 56.38917030826692, 53.61920818205803, 54.65181135362195, 54.21239214558756, 54.26371635929231, 54.16555512335993, 53.3879844604, 52.01581778064851, 53.934582433392926, 53.8291883468628, 51.11110741092313, 50.32574299843081, 47.423314586762466, 44.13105357077814, 41.414918130443944, 40.62524695550242, 42.65174734976984, 41.62517678353095, 43.185138702392585, 42.9324007803394, 44.27411025570285, 49.38333865134947, 53.38150862724551, 54.46524773874591, 52.85184744865664, 50.82388401031495, 52.8312667723625, 46.62157820117089, 35.97575956775297, 54.29948445289366, 51.86258254512664, 55.754479823573945, 50.95169444237986, 50.696206938835886, 47.99290549370551, 43.322809973070704, 36.18582210233135, 36.975175565288914, 39.658967141182195, 46.45319084967337, 51.09205253662602, 53.998748487041844, 54.26414782001127, 52.82008017263105, 50.35077556487053, 50.75570537197975, 53.12289891704437, 53.888388679873565, 51.8889134160934, 50.22103140431066, 49.44064840193718, 48.855701415769516, 47.37581468397572, 45.137784788685465, 44.65370155149891, 46.15214501657794, 47.666901619203635, 50.26561306368921, 53.49383746424029, 52.33911914210166, 51.67487752053046, 38.07621625161941, 22.75366544723511, 10.20341254049732, 3.7828075837704445, 1.5277489635252184, 3.2714400945171236, 4.003957187937153, 3.2260653809193647, 0.6533129176785869, 0.8622429904437835, 0.5776034511866108, 0.13069202582682335, 0.22734511042794875, 0.1634648535400629, 0.21316687606515425, 0.5322034260438335, 3.848806610030513, 18.167459618660715, 32.96065715051467, 29.07608489836416, 36.71046656946982, 35.315538375608384, 17.314238202187326, 2.492876091311055, 0.09259854894011252, 0.04836888014969807, 0.06752488188325398, 0.027778392184465647, 0.10653299114276325, 0.12723259492627076, 0.07893052147400957, 0.05397672419466319, 0.056851729600419926, 0.02016695051063453, 0.11878419261906417, 0.012222045127512708, 0.030928333139707966, 0.0034149702696595345, 0.05215454576236587, 0.046661909849893664, 0.1053182591473864, 0.05144022622956865, 0.029692742485372774, 0.05258874141521031, 0.053804128415762424, 0.037090365189097585, 0.06304710945715347, 0.03715839762721331, 0.09822505871735274, 0.06886589581206923, 0.03227639507742659, 0.029296563945770748, 0.046707472929190245, 0.0530776740502446, 0.04232053554827168, 0.03482403579137979, 0.03669112229779844, 0.040353397958942, 0.045187688552804535, 0.03350975833112194, 0.02071814119605528, 0.027232717332099716, 0.006874418167787935, 0.07244659077015615, 0.019643806304121693, 0.007034389775306468, 0.08103108093623193, 0.042043445376499046, 0.022346821140437838, 0.043974132502391454, 0.09123007842009107, 0.01141627672158422, 0.014940131786129168, 0.05678587668244878, 0.04416373926365087, 0.03555017606084866, 0.023767554178653706, 0.014626140116653858, 0.04782681548667531, 0.09012062222726884, 0.08928102050577441, 0.0637986034064764, 0.014995713380255528, 0.0370388419457501, 0.05915454393553157, 0.024381983507003997, 0.028674328181472038, 1.2926357215450657, 15.773067378228712, 43.41379719395792, 43.90308933873331, 41.07087527551959, 16.049788632700523, 20.072162574337376, 17.98573620857731, 3.535855893165835, 0.6288411888864733, 0.029937886790702903, 0.12745525072058364, 0.19221377378750235, 0.691150551842105, 0.2146957730573993, 0.1664873768365191, 2.940187353280283, 0.4789912346149645, 1.2852941477491011, 6.794122707459235, 17.58780587104059, 30.481601530505767, 44.86917695691509, 53.82253600705055, 60.19217491149903, 59.66552219083233, 58.963649349827925, 57.80486745219077, 56.23100465343845, 53.90011264431862, 55.48764882549163, 56.132113856654016, 56.644991213275546, 55.15284315232308, 55.41486532457414, 54.21522801922214, 56.37241394289079, 55.418760238155244, 54.47468888375067, 51.451369101001376, 49.46211945626044, 46.05290905121834, 43.22284444685906, 42.129879920713364, 45.12217767776982, 43.76892858935941, 45.42279205014629, 46.03534859995688, 46.98021227313627, 51.16187072569325, 55.33283287479032, 55.95941974270729, 54.83468009579567, 51.477346958652625, 53.48412959806381, 46.89604605397871, 38.65479330862723, 53.652524794301684, 52.09899164015248, 58.145231123893495, 51.92330868013444, 51.97602141288019, 49.83521138468097, 45.531273042002034, 39.61799406236218, 40.28063143453291, 39.8863979308836, 48.47390182556645, 52.51189954819218, 55.53371706316548, 53.82796064499886, 51.963897366677564, 50.78796686664705, 51.396208809268096, 52.52275666882915, 54.32862766327397, 52.87625243586879, 50.904618155571725, 51.0541545960211, 51.303523202096265, 48.206651133875695, 45.94426331981536, 45.36882808131557, 48.03115252525576, 50.01045111686953, 51.76144423023347, 56.22323443812709, 53.428961461590184, 52.687931599155554, 42.3388441916435, 27.204461251535726, 12.397124555803115, 4.541844312221774, 1.2006183881913464, 2.5847176534514276, 4.006961968637282, 3.714170518421358, 0.15283971964832277, 0.46741941523167396, 0.799511666259458, 0.5065350066269598, 0.2720849209975812, 0.37269313369066487, 0.30410577212610557, 0.5141097163000415, 3.7385831052257172, 17.375809607967255, 31.89621610026206, 32.0098118628225, 42.21064544493153, 40.1933273192375, 22.32827263493692, 3.959147050496071, 0.2370996313590196, 0.039691635888190045, 0.10179800086564596, 0.059282721936582565, 0.0710311207559801, 0.06793299990315592, 0.06978463441614183, 0.07515467327809142, 0.030311180368786862, 0.042503894862508586, 0.04194080491640395, 0.05273176236979423, 0.006819572975678791, 0.10356102964930958, 0.020913723443124085, 0.05154288201142223, 0.12615487775615147, 0.016477555336971438, 0.06872007097568243, 0.06551369423827817, 0.04745711677617604, 0.03247531746784526, 0.07744940538560191, 0.02190419852042631, 0.042136839155348084, 0.06001024116431514, 0.013454346391823024, 0.07490748734844309, 0.04529229785886504, 0.12045495377312745, 0.18599275679838273, 0.16785210118659083, 0.11434743270999002, 0.15146699734032154, 0.2969329521781014, 0.16290360220497654, 0.1376856118440628, 0.19581568938109184, 0.14762595506204715, 0.15269043975539748, 0.15513360139823731, 0.15187363681052962, 0.1349084511879952, 0.1614458747808972, 0.18792305321943378, 0.1494204700593987, 0.14562756874628607, 0.17701149437456362, 0.13277149488849024, 0.1733616982857066, 0.12404387651552116, 0.10324664248694336, 0.12389384585643008, 0.12772685953325805, 0.1507869104464208, 0.20136326911949343, 0.1713900637602614, 0.13232529463787235, 0.1076309253732043, 0.159247416942831, 0.09174060707371082, 0.136437593328376, 0.12793953320191753, 1.9342195266677489, 19.977215720761208, 52.26183276022635, 53.01002094822546, 50.121481649337284, 24.18337525859956, 28.41089406321126, 18.759864991711034, 4.44042113519484, 1.1743912148860194, 0.43439897257954846, 0.18799943218548454, 1.4098079502582552, 5.178495001408362, 1.5591705806793705, 0.3562238061380002, 6.540988135722376, 0.8685250339969512, 1.5086937215059035, 7.008726366104619, 17.6917016121649, 30.249373682083625, 44.29723262786866, 54.00132548424506, 59.46832110804897, 59.232727866018976, 58.95620861361104, 58.49008983181369, 56.54126805643882, 54.04629153590049, 56.16470090804562, 57.38645645879931, 57.801109821565696, 57.78676963621571, 56.623971231522106, 56.01512524389452, 58.99118831080776, 58.59509560369677, 55.77407598495484, 53.90487832407798, 50.92717962880289, 47.054549032642, 44.75717759901478, 44.21230546889767, 46.54844953167824, 45.9453772729443, 46.688172201956476, 47.54709282229024, 49.58381491322672, 53.913491848976385, 58.37084193383494, 60.478829568432225, 55.7290118740451, 54.06451486772107, 52.26475492600472, 49.93465131328952, 43.82391629680511, 53.22138570970105, 53.77518515433035, 59.223796629136615, 54.10393861032302, 54.044797112864835, 51.36325305508029, 46.809636239082586, 40.33368149111348, 40.9855088110893, 42.36122131347656, 50.402484170852176, 54.72246892990605, 57.72884015114077, 53.674882304283884, 53.33224758025139, 51.76559802024595, 50.63722625855477, 55.73787250826436, 56.048818403674716, 54.89766159365254, 52.63576015349358, 53.607633267679525, 54.01739935721121, 50.910180076476074, 48.463123152332926, 47.79472381837907, 50.24465976222869, 50.734806983701645, 53.89422516668997, 57.12080217176869, 55.17726382901592, 54.02997055361348, 42.05824959662653, 27.018735062691476, 12.381732194654404, 5.004686444036422, 4.59697812795639, 6.600582176639188, 9.303864009918707, 8.28161491501716, 3.5483611447195855, 3.2724209322083384, 2.5836635164676176, 0.7206577459169973, 0.3750539715251615, 0.173705181467437, 0.4269771434126362, 0.9722450651949452, 4.719342349037047, 20.930426197667277, 39.20888693101945, 39.281686121417636, 47.42161620047785, 45.92112918053904, 24.607004965505293, 4.205394185358479, 0.3282062240665959, 0.18413343076263705, 0.18023149981614084, 0.14391543884431163, 0.17135807192854344, 0.31867293400629876, 0.208128361752437, 0.3372092280657061, 0.23552958012348224, 0.1950408374109576, 0.18476491703862147, 0.14760652707228739, 0.10949397459626199, 0.15050675209251144, 0.11726382218541638, 0.14990382557434423, 0.23863081129327898, 0.13438455430009674, 0.23242249604194398, 0.19354607729661852, 0.12810327683485326, 0.12785991368394706, 0.14979462740161728, 0.10945225344790567, 0.24855164991271114, 0.1428173437354065, 0.1266153808683157, 0.1683537968464436, 0.14175185332855872], [0.05298926750378263, 0.057505723539619684, 0.08184936243079363, 0.046212147290427844, 0.027150987241897854, 0.05548155453476695, 0.03266648321803058, 0.024758640211075548, 0.03855260487105097, 0.051198491015501564, 0.015002294075525096, 0.09130075769198519, 0.00729795610119078, 0.04929715271798834, 0.01769712709280993, 0.031283575771076065, 0.03442187027464952, 0.03139128390279028, 0.01324627212353892, 0.024351966266910878, 0.07934922682902507, 0.04604683317724736, 0.04039043447964134, 0.06705887825979341, 0.04832784081959436, 0.035437587949056784, 0.01175615450202097, 0.052611544022276524, 0.02701481702857681, 0.01110974100283197, 0.0376890322584058, 0.025551589093201106, 0.04368853875465932, 0.1126174069941044, 0.23153243976975643, 4.642786998902598, 22.990376564764208, 42.47532698415941, 36.19078390059933, 27.253067262711067, 19.606412495336226, 15.980857879884782, 9.02146218284484, 0.6126983067201031, 0.10498367790733615, 0.30132122638244785, 0.0814777025352082, 0.49465693593505894, 0.1249122754820893, 0.2462281665254024, 2.9766683376604512, 3.773499554203403, 0.0952419353228423, 1.303432658314705, 4.398306156358411, 14.996506725588153, 25.794435854881044, 36.92854642868042, 46.18720708354827, 54.56799030303956, 58.75502632510278, 58.95638904263897, 55.74997302024595, 55.63957006700578, 53.13656837709489, 54.36987923037622, 54.661593744831706, 55.22356348652994, 53.58782529830933, 53.90777695563532, 50.76899436212356, 47.70825909030053, 46.78987533815446, 46.59451384698191, 44.306065805496715, 43.59963517035208, 42.93676637834118, 45.069759122786984, 44.036995134046, 45.37763772472259, 43.337538473067745, 43.96261522846837, 43.52518466211135, 44.86832972495787, 50.57193840703657, 51.76690809188351, 56.68996510967132, 54.21489854012766, 55.25975911848007, 49.909791331137384, 35.135666324246316, 52.90408949698172, 52.62522858958091, 54.219083709101525, 49.78821354527628, 48.95237999577677, 43.011636580190356, 38.81390033229705, 36.440921291228264, 38.604469299316406, 38.44484060041366, 48.30727561827629, 51.36903462871429, 50.73861560513897, 51.251838130335656, 50.05916303203952, 52.42720773143154, 52.629849141643895, 51.53973225624331, 54.1911760453255, 52.85020397555444, 52.40936879188784, 51.275019338054044, 51.00701162892004, 47.628509459957, 48.34886058684319, 46.628148171209524, 48.03305095241916, 49.171915054321296, 53.384242519255615, 52.10073709487916, 50.51495813554334, 43.65107313279183, 29.13276314735413, 13.092158744412085, 3.2803485326228605, 1.2139550596475601, 0.9432498630016082, 2.723433500336063, 2.2703274267335094, 4.426855617953885, 0.11620983075831207, 0.2878789573667511, 0.523886469102675, 0.15248931103175686, 0.382543737369199, 0.6775619906763877, 1.074056373007836, 1.8369713449670424, 9.6402435341189, 17.10249689317519, 38.333712008691606, 37.88133328960788, 31.272731827151393, 31.01044293372862, 10.38306591972228, 0.921982404205107, 0.07413727787112998, 0.024846780541983825, 0.04028747609305767, 0.10303677270008672, 0.1323525826897352, 0.017282729067148703, 0.0704619327499982, 0.03476523854319127, 0.026858860679391413, 0.07617438993146343, 0.08346282786899999, 0.04503436754607866, 0.04896325712663032, 0.047777567524462945, 0.03637254080404678, 0.02105493259976708, 0.020179723111552098, 0.03470963971208661, 0.017726052657610947, 0.027020748464330554, 0.045464560389518745, 0.05506681368475961, 0.12134441249673406, 0.07851101938755282, 0.08567062431886312, 0.04545582315674232, 0.07852487025722381, 0.050360191643478415, 0.07862429314803693, 0.023008577465530367, 0.09656562034281031, 0.04212280825501488, 0.02613688026735139, 0.02059129618799254, 0.05955760577513326, 0.02315031330762131, 0.059084542651450446, 0.07803534773448784, 0.0436087851713021, 0.0583591225046304, 0.07669163717617912, 0.038436734072503545, 0.05302969396354691, 0.051064168989297845, 0.03145816720901959, 0.017847077312668966, 0.022848183552043575, 0.042102920612500566, 0.02978554637652011, 0.04231062237053149, 0.013080599864253835, 0.045265741420969854, 0.02877815607784977, 0.06528618910740461, 0.03332327337815397, 0.039523571519361395, 0.04473814049795751, 0.039806771242330154, 0.0014148758172297911, 0.05643970453210416, 0.03414600967399536, 0.03068699246092189, 0.06664248649030924, 0.04970186164662723, 6.3006532384503275, 28.85824626491916, 47.948712148974025, 41.13641023635864, 22.735987324868482, 22.901385830294704, 19.48782943910168, 10.228022471550974, 1.7720240042094262, 0.11970367432842333, 0.3837580480162175, 0.142605459137309, 0.061117824272162495, 0.532537195230684, 0.2739776791103425, 3.9089701300667183, 1.7659771802925297, 0.2680411718545422, 1.738097218255843, 6.891926027113392, 17.1137305613487, 27.196891077103157, 40.648961605564246, 49.2014269674978, 56.46932786510837, 58.13766879420127, 58.487959984810125, 56.171871000720614, 55.01096710082024, 54.48267482942151, 55.11680833755001, 57.261132809423636, 56.28824380136306, 55.25968851581697, 56.31544936087824, 52.0637373770437, 51.08848317976921, 48.497232083351385, 48.65335418332008, 45.940231123278224, 44.070205842295, 43.90758437495078, 45.5019925486657, 44.757067772649954, 46.92376152161629, 46.66489685735395, 45.764979623979144, 46.136447691148334, 47.44186347530734, 52.86565026929302, 54.14167573375087, 58.20977764744913, 54.3081921146762, 53.751717613589385, 50.110840259059785, 38.480063484561065, 51.992346317537375, 53.79112958908082, 55.85980330744098, 51.212065296788374, 50.328445511479536, 45.99100228278868, 40.45449833716116, 37.782379734900694, 40.52699942742625, 40.09211055694088, 50.5501143393978, 52.81005067210044, 53.938928419543856, 52.11878392004198, 50.36391942731796, 51.58885994265157, 53.33886069636191, 52.15550122722503, 54.65340775828208, 54.21028583280502, 54.416959439554525, 52.590660741252286, 51.7136932957557, 49.88107565910586, 50.17579863148351, 47.32040336055141, 48.786836362654164, 49.87748669039819, 54.252102221212084, 54.010884300354995, 52.864661832009595, 46.77721000486805, 32.558520070968136, 13.661410366335224, 5.88454173457238, 2.9781872755096805, 1.7667810210297186, 4.211727342297954, 2.869933535975795, 4.334299939294016, 0.3155382554377279, 0.43762962664327315, 0.7818372824019002, 0.16938033934322097, 0.4555277694617549, 1.3879517682137028, 0.16334226415041955, 1.7783278659466775, 10.985092866805292, 23.69198856815215, 43.0086830354506, 42.56223494006742, 36.483349569382206, 35.47550439834595, 12.712876335267099, 1.1422954403585004, 0.12471203542044088, 0.03258994337351572, 0.022799393327365962, 0.06268384588521815, 0.06513366866255961, 0.03232360141532075, 0.06129995401528093, 0.05739885044374293, 0.028164282163244583, 0.026348372245387688, 0.05312309157283557, 0.04045622994101817, 0.014222948999714949, 0.0675696827050659, 0.010821016828319239, 0.027213455966463494, 0.0394929509850279, 0.0546010896833914, 0.07564418047906891, 0.044874718653098236, 0.03933859575960425, 0.013293970672924434, 0.03570324425855952, 0.028645720543159593, 0.03877750913342161, 0.06598274689167738, 0.05241026974193031, 0.04273878891141184, 0.09296463171560919, 0.17989553961782687, 0.13477443176652157, 0.1467223696771168, 0.1342061630660488, 0.14063664381542515, 0.17403872082791022, 0.149101271864868, 0.14373142452489945, 0.1828656471785038, 0.1567382338426767, 0.1501724772876309, 0.23311894657390736, 0.10463399707429832, 0.16118401060661963, 0.10456137193907654, 0.14156471337041548, 0.10175582006453507, 0.11509372492230709, 0.14648860560790186, 0.11267815776649984, 0.14210391669504105, 0.10968444703687584, 0.18443018258098634, 0.24960888189173516, 0.11485743276294201, 0.19811119523740586, 0.0966147112569982, 0.1819132313492798, 0.14947150683691426, 0.12704534771581813, 0.09005103080022721, 0.08705762650577292, 0.14592761474270977, 0.16153279511678606, 0.29902078691990147, 7.621164264217501, 34.470106786297215, 56.42520512303999, 48.71158176852811, 37.953136197982296, 32.22497740099507, 25.51938945247281, 11.402770376974537, 2.169860327436078, 0.2763759939660949, 1.2187640080528876, 0.3500142038589524, 1.6701991519620343, 2.3445908869466474, 0.6686259121183427, 5.828243955489128, 5.080442120951991, 0.48371447310332333, 2.401794243243433, 5.144358123502424, 16.652418644197528, 28.651319665293542, 39.48406081045828, 48.865009200188425, 56.45072798575125, 59.293454001026774, 59.2998827657392, 56.64344972179782, 57.193832782007036, 54.553285337263546, 56.22565061815324, 58.154040767300515, 58.11100844414004, 58.550286446848226, 58.81898057076239, 55.110242289881555, 50.99840987113215, 50.24915872081634, 50.924426124941924, 48.6339972865197, 46.76452505973078, 48.513509919566495, 48.81069614041237, 47.637915303630216, 49.15855938388456, 47.839266254055886, 48.55754636949109, 47.988202571868904, 48.9013695716858, 55.15641643155006, 55.57957741522021, 61.41570729594077, 55.85438259186284, 55.74041812650619, 51.385104579310266, 43.34140200768748, 50.87606722308744, 55.839783530081476, 57.18613709172895, 53.717557691758685, 51.436699436556914, 48.08395939488565, 41.68917809763263, 38.866275741207986, 42.46562696272328, 42.138630728567804, 52.76186827690371, 54.9612275246651, 53.468357747600926, 53.64262865435693, 52.367913261536636, 54.21851104305637, 55.150211241937455, 53.776891385355306, 56.76552172630065, 54.50848794752552, 55.439078115647845, 54.549045255107266, 54.23507521229406, 51.0775044656569, 52.89760581908688, 51.25095559704689, 51.662792698029556, 52.47327204673521, 54.89629268646241, 56.89730944172029, 55.532477594191036, 48.06774039422312, 32.81639629794706, 15.868338807936638, 4.609190917784169, 3.7393501737425408, 2.725768291181134, 6.515527540637601, 9.205491946589563, 11.119809612151116, 1.1072706359048043, 0.7575693329976452, 2.026371691496142, 0.6293189213160546, 1.5539426741100129, 2.2297956145578817, 1.6731021961858197, 2.226854817521188, 11.860371731942701, 22.718885790917184, 46.85059362842191, 48.47102280585997, 43.4310007095337, 39.594573590063284, 14.50082209802443, 1.4972058347155972, 0.17683901733929114, 0.08096600942794355, 0.14238753776636817, 0.26343535932321704, 0.2549565739689335, 0.10526205127638195, 0.17969733735005702, 0.16878916461381221, 0.1853630478463827, 0.14975290625326096, 0.15470339706347835, 0.18052995234968203, 0.16713602348200737, 0.14333707310499685, 0.16737340348622493, 0.20847394401507996, 0.20053552643906689, 0.14330759404167054, 0.17362461966131965, 0.07845235237431142, 0.16045060399318897, 0.09135877353049095, 0.2634071979311205, 0.1804044365041679, 0.1404487684128746, 0.1867914494247206, 0.1724416726539212, 0.25101624669567235, 0.14475402932974601], [0.013208751052227474, 0.04639651401028518, 0.033607668198284604, 0.06355189628178073, 0.07663924442303759, 0.07043089852818558, 0.04452887975100068, 0.074572185985744, 0.030394708850390972, 0.06423118644424024, 0.03570550038749653, 0.03733429524506773, 0.034906784778520945, 0.050316497818717075, 0.012074195903786009, 0.056873283484169555, 0.04317546285869133, 0.021413168719699307, 0.043143892375331734, 0.04831595879588877, 0.02692429799466364, 0.028126117578076742, 0.06754480783016452, 0.05593709339718184, 0.04293019597929332, 0.03677026684125585, 0.056391264792651906, 0.04238845307319876, 0.02029497337888085, 0.08825684522068308, 0.09565108756144201, 0.11731274456026093, 0.01178521796264836, 0.02978915656586328, 0.04338210358494713, 0.96616686231667, 11.237530727540294, 32.43978796466705, 43.560780171425115, 31.283808600518014, 21.71113475676506, 16.13731534250321, 11.611543432358774, 5.000661601943355, 0.35530388775852423, 0.2871857703693452, 0.16563300493984454, 0.06720916938877876, 0.0939039014760525, 0.11011383165755581, 0.8401278093937905, 4.920801654938729, 0.715390860794052, 0.5947825745228799, 1.2231721392562314, 4.823956864495432, 10.9334833006705, 23.062924723471365, 31.834326982498172, 40.15904188156128, 50.64261167280136, 55.05979276472523, 56.004146529782204, 56.393531983898534, 56.85627360497752, 55.31280917506064, 55.158695328620176, 51.46702720272926, 53.74261771478961, 52.338448416802194, 53.92269765177081, 49.73132741066718, 48.09920564774544, 46.98992798405309, 43.4215634868991, 44.51532817655995, 44.98866019710418, 45.91149976176601, 46.31677473745039, 45.235589088932166, 45.76849799002371, 41.57681395930629, 41.59373506422966, 41.186628341674805, 43.92872595017956, 50.284373760223396, 53.43883798968408, 53.13059068495228, 54.44633014740483, 54.09871793562367, 37.93638375497634, 53.109872725702104, 55.334519493964414, 51.432435820179606, 50.18605955185429, 47.93727843992172, 39.59324782894504, 39.80748768775694, 36.774550253345126, 37.20372423048943, 37.15398857670446, 42.159313386486424, 51.7364469651253, 52.74691620180684, 52.832835720431426, 52.801284174765314, 51.76488807124477, 51.7309360350332, 52.31199987473027, 50.596300248176824, 51.71644287724649, 52.69847493017874, 51.19244952355662, 51.608773816016416, 50.34890851666851, 48.30507124623945, 49.20754194259644, 47.7182101434277, 49.85665106004285, 53.02245878404187, 52.83340446410641, 42.422382831573486, 30.428678950955792, 17.07910779983767, 2.508080423839631, 1.7152339676695487, 1.621727481965096, 1.5205166032237392, 2.309025776001715, 1.8246106082393279, 1.2248428238015021, 0.24455850853795008, 0.037469107567542986, 0.026948736199448188, 0.3592796389374041, 0.16339798938603173, 1.0238715465511046, 0.5130990624668137, 3.3445324820856897, 7.026117665152396, 12.574322531300208, 27.634631510703798, 36.03578359849992, 32.79485856333087, 21.50117616499624, 5.4364624234937855, 0.226747531203493, 0.07641511007903085, 0.025402590737587986, 0.029744131663333506, 0.053459951924460555, 0.041911287548681425, 0.04547840742875011, 0.03270395640884677, 0.07639544460201457, 0.044779187488940456, 0.03160779567195043, 0.02027617741165863, 0.01532350037802732, 0.034161159062698, 0.02285819823643373, 0.07333402702164266, 0.028892362550381693, 0.02394004462046489, 0.08387401024059904, 0.013612238070627135, 0.02753473408970862, 0.05310054943566361, 0.03732136368090588, 0.0419741565541875, 0.07501636376424183, 0.013183291077673917, 0.029087067626777197, 0.05272272253228773, 0.03480008788286679, 0.00263054124286188, 0.05073400041569145, 0.059898717914738005, 0.0587308666698875, 0.024618900028027357, 0.05104764830321074, 0.08539025146033495, 0.06194848574758057, 0.024738884718728163, 0.0316630401873901, 0.010562433425577418, 0.009748373075478501, 0.08971700880436168, 0.0809655727578267, 0.04274650724724897, 0.015400275794578897, 0.020729661243216648, 0.025335010291347583, 0.030513500359149712, 0.01093834606675251, 0.03196669445793716, 0.06123877806408752, 0.025792445221375075, 0.003211515511558842, 0.010480434246992153, 0.0261114327417266, 0.03725125514451535, 0.05759166711340508, 0.03933039861881445, 0.0847378509840177, 0.059900993195873116, 0.031193838146845662, 0.08950315536029878, 0.08211789157001242, 0.05467931109090006, 0.028537958785290682, 1.482980501267218, 14.798100494569349, 39.45773386186169, 49.201799592664166, 35.668551691116825, 25.05156247846542, 23.00829787408152, 16.640312248660674, 5.929465620748459, 0.46494384806963707, 0.3856507754854618, 0.12283518129298765, 0.05212894310393641, 0.10174425979775768, 0.1027838794154025, 0.7745345032984211, 5.622508285507079, 1.1301456536016157, 0.7683138693532636, 2.8030840908327415, 7.215107756276285, 14.146049599493704, 26.140220242161906, 33.47993581525741, 41.7619655209203, 51.13817568748228, 55.65718150907948, 56.88641701975177, 56.462557854190955, 57.45010475958548, 56.08552394374725, 56.76159543375815, 55.303015016740375, 56.26515280815863, 55.82150528507849, 56.51516076057189, 51.55169548526887, 47.87811733061268, 47.29504915975755, 45.83107940612301, 46.62399438119704, 45.1305401709772, 46.952049655299035, 48.807495486351755, 46.95651331255513, 48.437059002537886, 43.705864721728915, 43.949271325142156, 43.26991681129702, 47.80552210346345, 52.89123588992704, 56.238296339588786, 54.83687270072199, 56.06940300233903, 54.1941648913968, 40.48374352916595, 52.740110889557876, 55.076364778703265, 53.11785867137294, 51.933142062156435, 49.773030050339244, 41.2489273471217, 41.14671822517149, 38.399654896028586, 39.42187947611655, 39.65005159378052, 46.11534533962127, 53.339303924191384, 53.47348036304597, 53.369086480909786, 53.48475325492121, 53.550119553842855, 53.06550287431287, 52.13366539247575, 52.817828732152144, 53.46753012749457, 53.874911415961485, 52.32368069310343, 53.54553822548159, 50.69104902205929, 49.98148833551715, 49.83725493954074, 48.229808807373054, 51.75943205433508, 54.56886499158798, 54.17986785211871, 46.14718714068013, 34.107589567861254, 18.792197089041434, 6.644698544856041, 3.3150124790207034, 0.8986089390612418, 1.3269792593294576, 1.8347023763964254, 3.6806702902240143, 3.66739968619039, 0.37568838425701667, 0.2735792521026827, 0.6468501386623229, 0.25428411731075856, 1.0965842609443972, 1.5449013657146886, 0.6769311632360182, 4.56729264989976, 10.02415826243739, 15.595487952232363, 36.47217865913145, 42.09040910966935, 37.34724375509447, 27.182680329968854, 6.914790993736637, 0.4786330731886049, 0.050742431213298154, 0.03754297376520211, 0.03543818549763772, 0.011686519024923686, 0.03965623879564866, 0.0149230097210215, 0.05755327844751939, 0.07518648124870754, 0.04404587663650032, 0.046125985381584016, 0.045985806613199176, 0.010291221063403834, 0.0097955142958991, 0.014324217204815679, 0.02397145997101982, 0.0077503506514814595, 0.010946251136521179, 0.03161255690839983, 0.06062881502833578, 0.0501138330887883, 0.050776001186140125, 0.010673884854411647, 0.05894398083910347, 0.031450152014111804, 0.06188552481152358, 0.04975659479837745, 0.04138993790313121, 0.14495020912539575, 0.03171975176120478, 0.10766875479490527, 0.2220142416415676, 0.2647625606867575, 0.12203293401868114, 0.1608539952505981, 0.1875245802464985, 0.1701979083760131, 0.2389811739445694, 0.2138653643909962, 0.13228564192691158, 0.14172320164019062, 0.15565716120744907, 0.11843218287873654, 0.1665876883893244, 0.15531282000724347, 0.17035071227339008, 0.16733600307376156, 0.11810664913707203, 0.12822320789939937, 0.09835304136598304, 0.10936341023132687, 0.1359063879616799, 0.1476206690553696, 0.11715659285865485, 0.1340313264799695, 0.19393102115681096, 0.13190560102943452, 0.13203349174751391, 0.151550623498136, 0.15052990326958318, 0.21242292808188548, 0.19060523429464912, 0.21632223900768066, 0.15812785605028754, 0.17427527345716956, 1.9243819771274444, 18.559826074108003, 48.47580025272985, 57.151706526356364, 42.58907964152675, 32.36436863099375, 27.445665444097212, 17.30785454473188, 6.4537104964256296, 1.5079409941550226, 0.8464419060657102, 0.5703098038511892, 0.29569084786119004, 0.23348754211779565, 0.21753419010389238, 1.6400771876496654, 8.080545884947623, 2.4401584556025844, 1.0310392490317746, 2.386463659424936, 5.750737920884164, 12.414514383962079, 26.45885398311, 34.77261958583709, 40.718975913140085, 51.33987572885329, 54.803987549197295, 59.12847911157916, 56.43424226391701, 57.79275517309866, 57.70167773769748, 57.670216406545336, 53.38170082338395, 58.34316568989908, 57.67137350574617, 57.49669075012208, 54.16459022029754, 51.909517626608576, 51.09348420173892, 48.62741554937055, 47.33155073658113, 49.069870671918316, 49.784957978033255, 50.72284767704625, 49.36462110088718, 51.60445920882687, 46.50061622742684, 46.531304851655044, 46.26656447687457, 47.870323581080285, 56.60422209770449, 59.53603690670383, 58.3439423191932, 57.575714741983724, 56.91587009737569, 44.514249524762555, 53.6962317651318, 56.94457007992653, 53.970613325795824, 55.08799460626418, 51.46572105346188, 43.415283772253225, 43.84506179440407, 39.32423207067674, 40.512510192009714, 41.60125032547982, 46.525793921562936, 55.82028935032507, 55.50617417981548, 55.89764241249331, 56.37638338150517, 53.051005794155984, 54.843980035474225, 54.971504134516564, 54.42057194248323, 56.13314936237951, 56.49335630478398, 52.82343379912838, 53.95182517267043, 53.63314828565044, 53.23742035896548, 52.618187935121604, 52.292768493775405, 54.13581571271343, 58.15524493494342, 55.20554411795832, 46.8005951758354, 35.46626329421997, 19.2635130113171, 4.089861017081046, 3.2165940826939, 5.755240311545711, 4.435495618850955, 3.881028145551682, 5.1801482804359935, 3.5731083587292707, 0.6254067860784069, 0.2805322967469692, 0.42134915508570214, 0.8562436026911583, 2.3678826564742677, 3.2132826216759223, 0.7668162593918463, 5.061444611318651, 10.60708228618868, 20.213868002737723, 42.23399531456732, 49.891497396653705, 43.61220244438418, 30.756036043167118, 7.335772120183514, 0.6702761267942767, 0.12149728534202422, 0.2596914569937414, 0.14818403479312697, 0.1316395693368489, 0.15161135894877298, 0.16482043080031872, 0.12882565178217428, 0.12698106527809175, 0.10700182163066442, 0.15680879054050292, 0.11143069849499773, 0.2774673628230249, 0.16759661086384328, 0.11106050182734767, 0.1928750149184658, 0.10550375967737168, 0.09579823772993781, 0.22333123871395666, 0.16072756009957484, 0.20606663528709643, 0.12935386940596566, 0.12554414480203582, 0.30187667077106817, 0.18434928369618234, 0.0896951063506065, 0.14013238942190526, 0.1043550797828263, 0.15500215603218925, 0.08725353050976993], [0.07697140482524711, 0.0324963006160913, 0.017587806346015106, 0.05019371690709264, 0.01967498991307953, 0.03878769810281454, 0.039973740105427084, 0.028503630385403673, 0.03691069075777646, 0.04827115031319761, 0.08673240686015737, 0.0038695998814693025, 0.04173047164635312, 0.025324602986896233, 0.016202650431002823, 0.04086648534622885, 0.04668866164020954, 0.08097419124697486, 0.03455479419039142, 0.04489264128008678, 0.016173876168566848, 0.045148434207564404, 0.0878527798059006, 0.068178852839816, 0.04155237918659564, 0.009084295503975404, 0.03165962726568743, 0.08622655900375498, 0.034365574303533764, 0.025609896045118093, 0.03467745252794797, 0.05247358690887209, 0.04680247549268027, 0.08028624429097099, 0.05334098996113866, 0.0849185941079932, 2.1774099094252435, 20.676631196852654, 41.03780577259679, 31.295154056241437, 21.996120445189938, 13.95454772057072, 14.994243517998727, 7.934177248708664, 1.20851460964449, 0.07277525781143097, 0.14923185921244084, 0.05328665517510907, 0.10118410396840304, 0.026349190044246858, 0.11221845138577685, 1.3957184288770923, 1.3375219774823035, 0.14359614871923002, 2.1894231486705045, 2.039507464055092, 2.531174113673549, 6.859938608061883, 14.788650524231697, 26.461858518661995, 35.82410896978071, 49.9594916835908, 51.832968650325654, 55.818661566703554, 56.46300892676077, 53.7992645848182, 56.072905678902906, 56.96779835608698, 55.35948538011121, 54.138141678225615, 54.19910315544375, 53.14949258681267, 52.378095734503965, 50.82768086464175, 49.6825998060165, 46.25754694784842, 47.212749988802024, 48.23276627448298, 48.915819583400605, 47.64140621308358, 47.07328619495515, 43.1238438237098, 42.32138179963635, 40.0299802134114, 39.86708418015511, 43.202683464173354, 49.30781341368153, 52.85661705078618, 53.0747361336985, 52.324253359148585, 37.96906886562225, 52.68708044482816, 54.3082627173393, 52.562278470685406, 50.822126788477746, 46.53137153194797, 39.815053939819336, 38.728945716734856, 39.16873754993562, 39.379153097829516, 38.61372609292307, 39.75787362744732, 44.470236609059, 50.96093162413567, 51.643467180190555, 50.94507740389917, 49.75444978283298, 51.78301334381104, 48.77501826132498, 50.299910268475934, 48.87390121336907, 51.00137518298242, 52.303182386582904, 55.02720179096345, 51.45320084787185, 52.41918256205898, 50.94179438006494, 51.939684575603856, 52.108675972107925, 51.34380986613613, 46.85510435412007, 31.896990768371094, 17.361045806638657, 5.665027268471257, 1.5450566670586987, 2.3553977522157856, 0.5785096412704838, 1.5584193242173043, 1.9334520904287218, 0.9701749117624376, 3.78306572475741, 0.3181854569383206, 0.3461324363466232, 1.022727562775535, 0.01787697006347439, 0.26948687169821034, 1.0359092393229086, 1.3419580555731252, 4.7138593658324215, 14.044630835133216, 22.493102396688155, 28.297272805244695, 31.735963744501916, 31.101783167931345, 10.786613091345757, 2.334436360866793, 0.07356473440003973, 0.05603304590969797, 0.030247664018984766, 0.07862668334236068, 0.042046065397200086, 0.07066534441565314, 0.05171754239727894, 0.019979990583153504, 0.019945629624529712, 0.05890330540076379, 0.02077105488898533, 0.010393027445271371, 0.012504851272810372, 0.0329715087859621, 0.041431276007525386, 0.057948238907321814, 0.03672759574387343, 0.06163926967870324, 0.03832093222186931, 0.06271314874832189, 0.07393461697164082, 0.07227558462369828, 0.11551105131905888, 0.030980632047078786, 0.038734485635594014, 0.023558867997640086, 0.06469773399012704, 0.06023581575361952, 0.08020975041173159, 0.04632092794523605, 0.062131825909619375, 0.05805827977676546, 0.051911642264214256, 0.049198855976423914, 0.008814351017316504, 0.016554003250935388, 0.0710670426187496, 0.007712222934294973, 0.04546662499647468, 0.029896809156202984, 0.09183214691978309, 0.050385005231345856, 0.026095793056752414, 0.03725469870973499, 0.03055632275889718, 0.009176462584535682, 0.03725159988408128, 0.07151953245122587, 0.05142261003774982, 0.014316989165250094, 0.032792179094206904, 0.054605188253786296, 0.0850181931990289, 0.03813237117062654, 0.07597125405746122, 0.030683422491194743, 0.053214014718128796, 0.06757859230762528, 0.015938620143119368, 0.01060851361422289, 0.041824328908396345, 0.03863625018106353, 0.09052812737683136, 0.07287726241854892, 0.022638444000134067, 0.21912936902334615, 3.63384013214419, 26.662942747915945, 47.00672357313095, 33.372588388381466, 24.969084839667044, 18.14136212871921, 21.561321789218535, 10.5910054714449, 0.7601921729022457, 0.0904038372719961, 0.12715629256901242, 0.08807089269882248, 0.019604080814808127, 0.038095338480366815, 0.1384785128456931, 3.3873490748866915, 2.5651048219973043, 0.5614393024194626, 4.633706221657415, 5.592899293668809, 5.128068029880524, 10.285577370274453, 19.384388692917366, 29.239202545535182, 38.18207317782987, 49.889147896920484, 54.2624847350582, 55.47270067276494, 55.298559204224624, 54.085138690087106, 56.30234079976236, 57.371971145752944, 57.659339674057506, 56.53645138586722, 56.61038021887503, 55.00243986806562, 54.89699479072325, 52.56516141276206, 50.318961220402876, 46.963922669810636, 49.731064611865634, 50.19882686676518, 50.93034890390212, 50.10057933868901, 48.96348030336442, 45.24070385963687, 44.03874843351303, 41.8476693091854, 42.826904712184785, 45.682190156752064, 53.176294142200106, 54.393335004006666, 55.27138110130064, 53.69068553370815, 41.58518429725401, 53.24985035004155, 56.31707322212958, 54.60876334098078, 52.63866270742109, 47.33930134004163, 41.24561686669627, 39.93551385018134, 40.11720980367353, 40.949352402840894, 39.47498836824971, 40.3584316469008, 47.98252690222956, 53.04573020627422, 52.874055908572295, 52.97102866634246, 52.06802452764204, 53.051825569522, 51.85076836616763, 51.44977661871141, 52.48343098548151, 53.62005149164508, 53.2801781162139, 55.211823832604196, 52.3202133178711, 54.868938076880674, 52.891616359833755, 51.43818601485222, 53.49138206051242, 54.34335616327102, 48.5519766038464, 36.19700085732245, 21.15228133816873, 9.329510427290394, 3.8296517152940077, 4.565291750815607, 1.6576991710932025, 1.4154100754568655, 1.8617743301776148, 2.8661241790940686, 5.513999346763858, 1.448081457807172, 1.212429747946801, 1.3078338027961793, 0.49737952048740086, 0.23104341520417124, 0.35165657379454185, 1.6203319762022266, 6.306791747770002, 16.298082509348472, 24.81781863397168, 33.65956860203897, 39.12092777990526, 35.639149604305146, 14.347776116863376, 2.8472845448601634, 0.037926339484270544, 0.03519584507411046, 0.10933768499882952, 0.009839954098776705, 0.06852862560340474, 0.04532225955758364, 0.0016751437754963616, 0.05246598731666323, 0.039617287055138624, 0.01210614272783841, 0.022285231501765312, 0.03865290876297701, 0.005611273246036182, 0.07607497470152956, 0.05859472901530324, 0.01773987096854516, 0.031790047989136754, 0.047962485827625766, 0.03300081164906583, 0.02490890835742316, 0.014347652792029325, 0.0397233595891345, 0.14266896782623184, 0.05663435215190534, 0.03455753295472072, 0.06173329548008981, 0.020895509702724316, 0.11979735155980434, 0.025644766452211528, 0.026973247182585543, 0.14179928949283016, 0.14019997369858528, 0.26890513517202874, 0.15600548606486092, 0.1624405173765075, 0.16206937842071056, 0.15913578261050487, 0.2486448368478206, 0.18114927314942886, 0.30897750909770694, 0.15635741153551688, 0.1554162725205383, 0.15637291715510432, 0.1292165711281761, 0.11709283136071698, 0.10225898661320248, 0.1482180644187235, 0.20236932642517552, 0.143917721786326, 0.09174442985245297, 0.1250587821367287, 0.1903047746107463, 0.21143046117598013, 0.15885249861786443, 0.13929799709829593, 0.09654678224075226, 0.2900579259280236, 0.1561478558447092, 0.09440514514402998, 0.15357855016425734, 0.17463872089020668, 0.13688557090297823, 0.23543449329032054, 0.19341686890730936, 0.15107082263115915, 0.24991145597830897, 4.362920003552591, 33.680317940250525, 54.49824663900561, 42.919943332672126, 31.99717986968256, 22.949272086543424, 22.65366069732174, 10.554714722018089, 3.655793392850507, 0.3065102156852522, 0.45445766720560293, 0.3680425203375278, 0.22681464050565997, 0.23603378855172666, 0.3564562372142269, 2.7563610624882484, 3.6731393394931673, 1.0298658474799127, 4.321640489562865, 4.097140445824593, 3.9706712192104714, 9.207907146023167, 18.349963580408406, 29.320909438594697, 38.87348897995488, 50.604144988521455, 55.1135802268982, 56.545472837263546, 56.73103624774564, 56.70670970793694, 56.942083297237275, 57.9277749215403, 59.58843192746563, 57.75348832530361, 59.58602751455, 57.91191677893362, 56.45426596364668, 55.63143507126839, 52.744468642819314, 48.5576444287454, 51.714160057806204, 51.5030227938006, 52.61708967147335, 51.62574591175203, 51.49479758354926, 46.611301591319425, 46.63772659917032, 43.57618724146197, 44.29951152493877, 46.62022890583162, 54.67049360275269, 57.233021182398645, 56.60760318079303, 53.3680352857036, 44.51686182329732, 54.36865152851228, 59.45812686797112, 56.15845257236112, 56.14796807689052, 50.283718724404615, 43.92907111875473, 42.05105204736033, 42.57260960917319, 42.73022613217754, 42.749955654144294, 43.08864447378343, 48.8625890977921, 53.44500003322479, 54.95401428591821, 55.353186053614465, 53.59198301069198, 55.6753420829773, 52.92465840616534, 55.72694086259412, 53.851487021292414, 55.769059273504446, 54.556819392788796, 57.167654883477, 51.58416486555531, 56.80436495811709, 55.31177759170533, 55.3221248042199, 56.86972341229839, 54.9965210114756, 50.04492482831402, 37.64328856622019, 20.337797249517134, 6.764444093550406, 2.6342758199860974, 5.018534371929785, 4.254352229256784, 3.992887769014605, 2.8032510367132004, 3.590714897840254, 10.00839033434468, 0.6961837495046278, 0.9700270874365684, 3.416890896135761, 0.7680980164197184, 1.170227496374038, 1.238778147005266, 2.5308370349868654, 7.367079008010126, 20.564394535556918, 33.44421479009813, 39.3427417355199, 44.57751343327184, 41.13324488362959, 17.098960876464844, 3.1180558089287054, 0.2043649548244092, 0.134396520593474, 0.16833611553715122, 0.185936066291986, 0.09606829138412591, 0.20355067996969148, 0.13932125552767707, 0.10718916077166797, 0.17916556507829698, 0.22845583066584604, 0.12786716087571076, 0.0928900913605767, 0.14000226172708696, 0.14415710894090517, 0.18039116786131937, 0.14678799276871068, 0.17813712268346743, 0.13531787921824764, 0.17516503861594587, 0.09066885772852168, 0.17458693334652534, 0.1621405786323932, 0.2888260565457806, 0.15228219150054842, 0.13377041225471806, 0.16007894409760354, 0.12856216350149724, 0.1957034115349093, 0.09076531585906783, 0.10359626969382649], [0.04868138273577056, 0.012945842125543184, 0.059203083266413985, 0.0465907747556846, 0.038053954410697186, 0.03284205524851719, 0.07350951478245758, 0.040976644959300756, 0.044179604944562724, 0.024006631067623536, 0.07003372024384237, 0.05475706135433528, 0.04398570809092733, 0.01777904295933343, 0.04298167708780497, 0.06442952660783645, 0.11064830821968856, 0.08799495806376781, 0.038730953970263084, 0.06252454556224328, 0.024023580762948242, 0.0960348746288688, 0.026587140783967993, 0.08045459211233162, 0.03885441670014013, 0.04893169430414996, 0.02227249912046377, 0.00903480526645698, 0.120079601333747, 0.07035857982813351, 0.010366824365431264, 0.07356682582007301, 0.1026468416075072, 0.04289058157272878, 0.06403721681225204, 0.0326995054380067, 0.4273976950395492, 11.863167401283018, 34.838538938953036, 44.999423180857015, 29.925980144931426, 26.742239344504576, 16.628286261712354, 8.2298308034097, 6.021036294198805, 0.5146343333105887, 0.04334098381561138, 0.02961835917836476, 0.013403105643397618, 0.03629890443276494, 0.03051928049253841, 0.28438516742279457, 0.5225690430210483, 1.9150446523581783, 4.71034590275057, 4.576886767341245, 1.8734911853267302, 1.5651648203211448, 5.238347428460275, 10.547775068590719, 20.27061685439079, 32.52231463309258, 44.41310336512905, 49.30059233019429, 55.645728188176314, 53.140318162979625, 55.0551918245131, 57.92781022287185, 55.555105747715125, 57.23035789305165, 57.60869795276273, 55.32605501913256, 54.29095722013905, 53.84445421157345, 51.925030600640085, 53.282570762019006, 48.81484600805467, 49.973725964946134, 49.19283697682042, 49.578880571549945, 44.805897358925115, 44.36405020375406, 41.73158676393571, 42.135708562789425, 42.93340098473334, 42.35642425475582, 45.866157162574034, 52.51696725045481, 52.84864679459603, 56.37752479122531, 38.09983284242692, 45.580302669155984, 54.357700270991174, 52.06317647810906, 50.829830323496175, 45.247391500780665, 41.74631526393276, 45.458265965984715, 40.78482074122275, 40.052431860277736, 36.82792194427983, 37.75817086619716, 38.85921155252765, 40.65204066614951, 44.735490814332046, 49.512243424692464, 49.082610530238, 47.813504126764116, 47.559346306708555, 47.74800838962678, 46.588210598115005, 50.96888226847495, 49.25218635989774, 54.563024582401404, 51.90735247827346, 52.41139665726693, 52.28026397766606, 52.05243310620708, 51.103062629699714, 41.37711432672317, 30.576058087810395, 15.822709875722087, 7.193523443514302, 2.8247166977774714, 5.430681340156063, 4.792230773356653, 1.1041778470239332, 0.2922287433137817, 0.7817924202930543, 2.4436400494267865, 4.770666072445532, 2.064636128564035, 0.4147808704405062, 1.2644944315956486, 0.21066634975854429, 0.5845898053338451, 2.033164010893914, 6.909119246467468, 11.766431946908275, 15.152626864371763, 24.27940860871346, 30.704072483124275, 33.59908173161168, 19.967956965969456, 5.821675456339314, 0.7458930498649998, 0.08944374524177083, 0.08388068286641952, 0.09258425373944545, 0.017303714130614555, 0.03205681704134951, 0.056088188918487686, 0.022670322833883188, 0.03363832703701431, 0.05708978376201084, 0.008371502401367312, 0.07505543424838013, 0.04008358945288966, 0.0841569035283981, 0.07162823266680203, 0.021652509909003012, 0.0030453407464759246, 0.013684474416227351, 0.04770105832346505, 0.02569674551787396, 0.0647445802666968, 0.07263016841945148, 0.057837228936653946, 0.11421699091912278, 0.07302471902221441, 0.05718153428226229, 0.008117176532264679, 0.042131143291631055, 0.014115982058067477, 0.002811635091465207, 0.06002734790766432, 0.012847679449365506, 0.03443918003129863, 0.08244060610811557, 0.04843244246477562, 0.10184393549758582, 0.052796167381588495, 0.031133939647265983, 0.003649927999621498, 0.11296624513042551, 0.04261521509878578, 0.05833784058209389, 0.07434896328636716, 0.0700051604860252, 0.040777002446233265, 0.04938981871330931, 0.04266391147769267, 0.038756303819677526, 0.04863367077984637, 0.04904396065901365, 0.08434531519249563, 0.022243776568962682, 0.030162091997842637, 0.008284745816772264, 0.029064169258720456, 0.050614678391045144, 0.06453933765090282, 0.02079612128586779, 0.048963904470926335, 0.0748847421979712, 0.013088868825786538, 0.05145871576162116, 0.05127358678427916, 0.05029891227041522, 0.05424323086176188, 0.04509203481457887, 0.03850709158746946, 0.7324993201801855, 15.695478973850129, 42.42610516086702, 50.10751016678349, 31.075214993569162, 21.18429376233009, 16.371917205472148, 12.374892561666428, 6.898682800031478, 0.7014041790558446, 0.0925284595559201, 0.09973892506452338, 0.00720571528466779, 0.08539585156306144, 0.21449691195401455, 0.559988699613079, 2.493397031099566, 2.526247126440848, 5.428082769916904, 7.853312684643654, 4.975348586036313, 3.8090587815930768, 8.049065922537158, 14.128816666141635, 24.08681042732731, 35.27648333580264, 47.190823939538774, 50.868748080345895, 53.90279554551648, 54.85560986303515, 55.66991352265882, 56.666995709942235, 56.46010245046308, 57.53722844585296, 59.11835547416442, 56.22041033160303, 56.127658044138265, 54.750255000206735, 52.82566562775643, 54.316429092038064, 51.05670805900328, 50.27616423945273, 51.44538748648859, 51.15534782409669, 47.77093856565414, 46.26141440483832, 43.71723175048829, 43.88740378041422, 43.93804550170899, 44.06821327824747, 48.6781317956986, 54.668383367599986, 54.21753437288346, 56.65464416626961, 41.37671424496559, 48.35262606220861, 55.9188114443133, 54.867243612966234, 52.73200727278187, 45.46194907157652, 42.75073228343841, 45.338119845236506, 42.57499048786779, 40.94086047141783, 39.49746747170725, 40.81616832363991, 40.94825413919265, 42.796133718182965, 47.37146085308444, 51.10880105726181, 50.15356271497665, 50.399173690426736, 50.47875073648269, 50.58353685563611, 50.12350951471637, 52.633771511816214, 51.961147785186775, 53.42818483229607, 51.968686580657966, 53.6763963391704, 53.581318086193455, 54.40709467857115, 52.60092558399324, 44.221793682344504, 34.76830105627737, 19.930590506522886, 9.815134175362127, 5.070455766493275, 4.174403048330738, 3.503107289152761, 1.8087664390763931, 1.5376176468787657, 1.2761785594686386, 2.501849248524635, 5.407219682970355, 4.952781229249893, 2.229788014965673, 0.44785049593737053, 0.6105511767729637, 0.11801971347942469, 1.225915101747359, 5.181448546148116, 12.278111019442159, 20.376008979735836, 28.349067703370128, 34.78285697198684, 39.219183152721776, 25.553280691946707, 8.648303574131383, 1.0652482004896289, 0.06828457297336671, 0.021270496335120934, 0.07636746707101984, 0.009005488039204671, 0.04313059691940585, 0.10086790883853551, 0.03588402185649161, 0.0361406498198067, 0.04038277360039853, 0.06391243258070561, 0.02950241177102491, 0.0205123623187143, 0.012443835242471148, 0.014963091441219854, 0.03038699817543309, 0.002944944684596492, 0.0198255721554761, 0.022839199255911574, 0.033575890871185454, 0.005263352978809347, 0.03997665123953935, 0.0309512295925449, 0.03664631381510727, 0.050157768231245785, 0.040103193642872, 0.03096647474223808, 0.03783555806524331, 0.03636782170243321, 0.039906979373265664, 0.06318634976783107, 0.10282727063543375, 0.09865813588182773, 0.12750669352469907, 0.10631018979174477, 0.17698751582253366, 0.0955458500632836, 0.1722102221702376, 0.18136524865704198, 0.2041807413221367, 0.19581123074937254, 0.14895848839754058, 0.20324288116347408, 0.16025601766042172, 0.1178983191869432, 0.1766216322298973, 0.17264270944701088, 0.18165732733905318, 0.17204234166251076, 0.13162459997880843, 0.15979014427190827, 0.17791374676650573, 0.1572865689353597, 0.10790140037575077, 0.1173512174958183, 0.13260303215394098, 0.18103140286139904, 0.11958111558229693, 0.10685087932694344, 0.1478046527312648, 0.13620036654174328, 0.11010631633501862, 0.22065789829338753, 0.15765870380545818, 0.13218487072135174, 0.2555417425690159, 0.13715144937797902, 1.216417817819503, 19.38156262520821, 51.12138009840443, 58.506944256444136, 39.756469418925626, 35.77172571612943, 27.35254445383626, 15.298027165474432, 9.803063081156823, 0.9751793045190074, 0.2320745235849773, 0.23438012648013332, 0.12233380739006305, 0.1793239767392797, 0.18718175590038302, 0.969392950496366, 1.8996166221557127, 4.1830224567844025, 9.172931371196624, 7.381999213849345, 4.861083569065218, 3.193460924010123, 7.169157680003875, 11.75558953515945, 22.41618863997921, 35.63047724385416, 48.270220987258426, 50.94601485037035, 56.112360800466234, 54.7690902217742, 57.322317861741595, 56.79454334320561, 56.60499872699861, 58.945018091509425, 63.46749128833894, 58.77562661324778, 57.95585516960391, 57.44559795625749, 55.76113608575637, 57.61686040509132, 52.9593909940412, 51.988388646033506, 53.92612188093124, 54.10679017343829, 49.90744967614451, 47.101805748478064, 45.42819315387357, 46.84924041071246, 47.14847018641811, 46.38861686952653, 50.011325805417954, 58.9780052246586, 58.494325991599794, 57.883605111029844, 45.72298672891433, 50.1191556838251, 58.24950341255435, 56.59426712220716, 54.59407014231528, 48.597605536060954, 45.79758236485143, 47.61381626129151, 44.37744117552235, 41.778059005737305, 42.46601527737033, 41.572695470625355, 44.1052443750443, 44.02821294723019, 47.730141993491884, 54.5923678336605, 51.06555692611202, 52.35961352625201, 51.77353689747473, 51.67884303677467, 50.45378877270607, 55.27701362486809, 53.22748107294883, 57.296610647632235, 52.40088862757529, 54.45763049587127, 54.102236301668235, 55.52157732748217, 54.17767916956256, 45.79208320186984, 34.91524873241302, 19.876202921713553, 8.791441648237168, 4.038822155806327, 8.937564646044086, 9.954641115280891, 2.5768839447729053, 1.6175711178971877, 1.1653067604187997, 5.977879435785356, 15.587292159757308, 8.082736038392591, 5.673467228489538, 3.567098552180875, 2.465505547100498, 1.385083167302993, 3.234431306200643, 8.369002380678731, 15.825403563437925, 22.38931844311376, 36.43766964635542, 42.14569883961832, 45.790561322242986, 29.108656260275072, 9.442261899671248, 1.1545076173159385, 0.17156208114277932, 0.09852446119992003, 0.1845633286622263, 0.12496220143211466, 0.16563194773850903, 0.12988547313838236, 0.14748786005281633, 0.180931382422005, 0.1438884265841015, 0.17786300110240139, 0.11047344865097154, 0.19077263982786288, 0.14393557163496173, 0.19038642426171612, 0.08397151791160146, 0.07395611339879614, 0.09107013458325978, 0.19492515813439124, 0.1638877953612997, 0.13121828226552856, 0.15934104820893658, 0.1832868269975147, 0.1731734551609524, 0.14885855988869745, 0.11974285972575027, 0.15712742182996967, 0.12065538535675696, 0.09309416952272577, 0.11888996637876957, 0.2024436829191062], [0.02921301439674872, 0.01839921220145639, 0.05343873894983723, 0.015852463979934974, 0.05592339957553533, 0.061720689503295775, 0.05739677051502851, 0.027738703084328485, 0.027930610024580554, 0.06990673350951365, 0.014786520623601975, 0.03848290619169993, 0.04061526213321955, 0.07417981873356527, 0.015711158104691536, 0.06580676883459091, 0.05046342582171483, 0.042180349119007594, 0.04266719033400859, 0.022097545705976027, 0.054488432623686335, 0.029500678497096224, 0.032703458451695984, 0.06188436035787868, 0.024582129722881704, 0.006934384657670894, 0.06095571623694512, 0.04236045255956631, 0.12255014295900062, 0.019503236830895467, 0.052903572908572616, 0.04911133426151449, 0.016544367780067747, 0.018910313505799543, 0.08794796623049245, 0.06944626870174563, 0.11187131396464764, 4.126396179199219, 20.60618150618769, 37.77173049988286, 38.06100922246134, 23.817473034704886, 21.130339599424794, 15.002567768096926, 7.62736504116366, 2.1610131763642837, 0.05865732989003582, 0.041789713225537733, 0.14457839601222547, 0.1164341259807829, 0.21684302557860652, 0.6328813527380267, 1.0698682622563456, 0.25957072153687477, 3.353636303255635, 10.01348941556869, 3.6894676762242473, 2.410913508745932, 0.622627848098355, 3.316827065521671, 8.258409192485194, 19.01453075870391, 31.741890445832286, 44.858343370499156, 49.45388640126875, 52.56407099385416, 53.292647330991684, 58.148941686076505, 51.378703271189046, 56.389174230637096, 56.00465251553444, 56.64373213245023, 54.133062208852465, 53.507048006980654, 56.12449269140921, 52.689308351086034, 52.68620967864991, 54.41910497603878, 50.77954161551691, 48.82770353747953, 47.06521395714053, 45.640899365948094, 43.04029341666929, 42.40900362691572, 42.06134826906266, 45.05410886579945, 44.41589609269173, 53.90205029518374, 52.4982536223627, 54.39515890613679, 36.823670095013036, 46.302395328398674, 50.8936276743489, 52.1615416772904, 50.191723454383116, 45.20297065857918, 43.24881838214013, 43.959614615286554, 39.68079513119113, 43.11244933835922, 44.548209405714466, 45.40314489795316, 41.07491923916725, 38.268286874217374, 37.45331248929424, 41.09608827098724, 40.37208149510045, 42.806849633493734, 43.97590029624201, 46.360226754219305, 47.69216168311335, 50.13507658435453, 50.44843865979103, 53.60409136741392, 50.72980203936177, 53.832220339006, 51.39675794109222, 50.78565266824538, 38.92699010910527, 29.437680359809633, 16.14925503730774, 7.734909076844493, 2.8020422112557197, 3.5384529925161794, 1.8020644567666517, 2.6833534961746586, 1.819742701707348, 1.3110654680959641, 1.385683902809697, 2.003252261107968, 5.311145147969646, 4.63742119650687, 1.5231252245364653, 0.10190010506419406, 0.30951257554754136, 0.46747797499260596, 2.8284672191066127, 6.557094368242449, 15.270369552796888, 17.77880568658152, 30.75769912812018, 29.694370069811423, 28.751098878922004, 12.330602138273179, 2.944579427280734, 0.3082695825686378, 0.017822840205964544, 0.07932851947243176, 0.04533881854806696, 0.11944384794802436, 0.03314056523865269, 0.02106484003184784, 0.04686351354804732, 0.06703411063720142, 0.07256204022034522, 0.06898100052269236, 0.021698787365288987, 0.07549190518235968, 0.0205427338744724, 0.0931375224383608, 0.04508109507902015, 0.032475026354434035, 0.012496348654460764, 0.0854008004910523, 0.01721217619976209, 0.0696804311366812, 0.05722927305126383, 0.02748281248064051, 0.02113544461016934, 0.12698478080452452, 0.09110087769166117, 0.03802267504074881, 0.011218111800600686, 0.0203927721632945, 0.026512824509653355, 0.026085380006641633, 0.018009859505259705, 0.019922363534269315, 0.02476701546730774, 0.05913474056268892, 0.03511969210399735, 0.019663605846524723, 0.03751765838974426, 0.055102432942799026, 0.03270494849270871, 0.06368490829763394, 0.018264461166015076, 0.02034470780692514, 0.06093630739938348, 0.03827955964351854, 0.04109634619746958, 0.052507842530406294, 0.01692928291196304, 0.0722566545910893, 0.05367385899467815, 0.03580790719077472, 0.003988168985327526, 0.08136492673187487, 0.09273361024116317, 0.052360849409934976, 0.07712817705807186, 0.012047105119563641, 0.02144273013747748, 0.05261525188783004, 0.04055625421085185, 0.054059990291153236, 0.01170613183339517, 0.09655261983073528, 0.03216976712968561, 0.056488071493203604, 0.05660535572397132, 0.09519606197793638, 0.0643993963697745, 5.444398849241195, 25.34482829032406, 43.27017176535822, 41.22334564885786, 27.17217818383248, 22.085372017275905, 22.484643805411554, 12.564819608965228, 2.2021676648047666, 0.1637113499905794, 0.12773711745056415, 0.12865361907789785, 0.14710947390525572, 0.2936886617493245, 1.3105738235096778, 3.2818498198063146, 0.9950141176100701, 3.4315066279903537, 10.275919514317668, 8.884325335102698, 4.944301555233618, 4.383485480662316, 7.1985435870385945, 12.463316513646035, 21.769532965075587, 34.07227646919989, 45.08893166818927, 51.33549836374099, 53.85857474419379, 56.67817446493334, 58.93789898964667, 53.03612824409239, 56.847232541730335, 57.68857309895178, 58.13072619899627, 55.633725735449026, 56.28604727406656, 58.4356394890816, 53.88680796469412, 53.83307149333339, 55.28048884484076, 52.0368456071423, 49.72840132251863, 48.36851558377666, 47.36505170022288, 45.65463550629155, 44.02145470342329, 44.29561661135766, 45.48784063708398, 47.20922377801711, 54.30053172572967, 55.03294414089572, 56.502581719429266, 40.358062944104596, 48.6467489119499, 52.99192313225039, 54.90261162481001, 52.287473294042776, 46.53908683407692, 45.140852082160215, 46.19056855478595, 42.056476685308645, 44.5949326792071, 45.81462506325015, 44.64477423698672, 42.19879204227079, 40.76793886000111, 40.167745620973655, 44.12592703296293, 42.87172955851401, 44.29889963519189, 44.94030913999004, 48.849692344665534, 49.5159932105772, 52.49231123155164, 51.21144556230115, 54.97398307246547, 51.51955558407692, 53.047914966460205, 53.39533105973275, 51.27703543632261, 43.08453382984285, 33.16782497590588, 18.848367391094087, 10.464727705524815, 4.669201710531789, 3.815218373652428, 3.9346153216977275, 4.862383344481069, 4.057578929970342, 2.1601382426677214, 3.523957383248114, 6.246237706753516, 3.3467464148998265, 4.489591477378722, 2.198908910635979, 0.30749963356121895, 0.08930089282653025, 0.411929766977987, 2.4453403968964857, 11.54400610154675, 19.186316843955748, 18.76774307220213, 34.48208570480347, 36.71279645735218, 32.98358732654203, 15.604935961384928, 3.9558924638455917, 0.3546219775753637, 0.05890919278646189, 0.039384810013636466, 0.060537148777756004, 0.07068547720630323, 0.02135882627279047, 0.025051281967711066, 0.06383696908972437, 0.06525484078954305, 0.020262745975126183, 0.06511057111164255, 0.039900433151952686, 0.029042868183985836, 0.05791008389825302, 0.06443766246159231, 0.03901462100686566, 0.0078503854550241, 0.03346145265705643, 0.04788527948661678, 0.03528594084444546, 0.03885944989780265, 0.019189085240565965, 0.056993923180045626, 0.02758266438069123, 0.03618356989576452, 0.05355363681672081, 0.057479090492932074, 0.019683642876184276, 0.021937502277714592, 0.03144518967958228, 0.03277162495519846, 0.14539098547350976, 0.07466725749714721, 0.13247826707459268, 0.19546742581071394, 0.16009595124952256, 0.1451799282503705, 0.17856197972451487, 0.16211287689305123, 0.09104471578593216, 0.2841623277673798, 0.15434042460495426, 0.12454543427954759, 0.12922092250758602, 0.158671410754323, 0.12193124350761214, 0.12749967615931265, 0.1536739893978642, 0.11435912321171454, 0.1705420044280829, 0.1651133521790466, 0.1159971647505318, 0.16028800949213967, 0.17194943051905404, 0.17239008429310015, 0.1390806273106606, 0.14281982586028116, 0.09058348489023986, 0.28219470754265785, 0.16134582369798617, 0.11814353627062614, 0.13623055040595994, 0.22305457372098203, 0.09359265527417583, 0.1359531346468195, 0.16970715245171902, 0.28933075527029656, 0.28037120377825153, 5.952795388237123, 33.50777287637034, 51.77596092224122, 49.87541960131738, 36.14152285360521, 33.31891075257332, 21.960997581481937, 11.506533738105528, 3.5902192083097275, 0.4392036615360168, 0.24053475428973478, 0.41084097217648263, 0.2542396229241164, 0.9031878772281832, 0.8812173948653284, 3.9384060473211355, 0.8789612965718393, 9.814674277459423, 18.52996114761599, 7.480467865543981, 4.577909525363676, 2.1724890508959374, 4.918162390109032, 10.23985332058322, 21.480644518329253, 35.0696724460971, 48.69305249183409, 51.49918279340191, 55.185940111837084, 57.38939823642854, 57.44833184826759, 53.75508300719723, 58.663956734441946, 58.30511085448727, 59.49105124319754, 59.378510598213445, 58.20791844398745, 60.81967961403632, 54.89691242094963, 55.92353397800077, 59.217430622346946, 55.810852127690474, 51.07451169721542, 51.107804775238044, 49.1664590374116, 48.39797258377076, 46.97914146607923, 46.92338889644992, 48.53676957468833, 48.67103230568671, 56.820921282614435, 58.20007370364282, 58.13656268581268, 44.07168849822014, 51.64594219576929, 54.14579814480197, 56.514737144593276, 54.03861937984344, 48.56973317361648, 46.457678041150494, 46.701920109410445, 43.14457355007049, 45.8653256200975, 48.79193936624835, 48.202230622691495, 45.52204370498658, 43.744092141428304, 41.215736250723566, 45.133058332627826, 43.72007154649304, 45.78521905406829, 45.75755065487277, 50.75542296132734, 51.23501508466659, 53.52509090977331, 54.83533905398462, 56.441647698802335, 50.609098942049094, 53.340978776254964, 52.86521880857406, 52.14569137942407, 43.540756471695445, 32.219205633286506, 18.593480010186475, 10.732817784432443, 3.9309187329584554, 5.435051841120567, 6.5813233390931165, 8.002400994300842, 8.350867302187028, 1.8637700811509166, 2.4906447529792786, 11.25150417127917, 13.268079988418087, 12.623249196237134, 6.725055652280008, 1.7114662859709033, 0.6758523275775294, 0.8048784492477294, 3.819152020638989, 11.254298860026944, 21.896021558392434, 26.13491523650385, 41.01460887539772, 42.75561563430294, 38.3776347098812, 18.589298763582786, 4.213629201535256, 0.6688593544306294, 0.1114617097341726, 0.1748905186691592, 0.14709370781577405, 0.20832708495999538, 0.11153905397100795, 0.13117956418183543, 0.22608716341276325, 0.20472356058176489, 0.16788930241619388, 0.2848482522512636, 0.10836477631763106, 0.12141406521080964, 0.16235103830695152, 0.2874996519136814, 0.23470310914900996, 0.12215307958784605, 0.09003747104396743, 0.09316854133841493, 0.07348621804868022, 0.16238267773822432, 0.1177529923077072, 0.12079845227661634, 0.07675794974690484, 0.20629721243054638, 0.22909840989497401, 0.1618041434595662, 0.12470926218215497, 0.1671267231746066, 0.1823669392615557, 0.16894339343472836], [0.01093727928931795, 0.009133214048380333, 0.02437882913997577, 0.015459468535658334, 0.014758610125300626, 0.018259020026532874, 0.07216044926955816, 0.03059606165474942, 0.04838805916088243, 0.04684824924615603, 0.09049863299174656, 0.03910559394787397, 0.030829915739295465, 0.10547660952133518, 0.023298673895037463, 0.028840419873895667, 0.08858317569378885, 0.017901588298921144, 0.03731568696938696, 0.08367762360120974, 0.04331363447671456, 0.08461073401474184, 0.02372880353622379, 0.016668615750067176, 0.013809585192751501, 0.018444514810858716, 0.0750241089131563, 0.043491523923172105, 0.02936813571009665, 0.05673251482808302, 0.049028056673705585, 0.10252142535342325, 0.036898065628784324, 0.028036912384953712, 0.007095260248940078, 0.05823131988666231, 0.013033549616774245, 0.5669901303706631, 11.195913399419478, 34.624142185334236, 41.72534627299155, 30.918290768900228, 15.791485847965365, 16.897913909727528, 18.390544422211185, 6.263759424609523, 0.8950343728065492, 0.021659035062898072, 0.04863983778763683, 0.2048871969623912, 0.3805485379792029, 2.139486473414206, 3.102277339466157, 0.9113696962594987, 0.8532149813348248, 5.682000344799412, 11.73965588692696, 5.548436285987978, 6.352701619748147, 2.256372859401088, 3.129980794845089, 7.983419664444463, 17.835868327848374, 28.824904157269387, 36.44426315061508, 45.096815632235625, 51.16699334113829, 53.66466060761483, 56.90531107687182, 48.48504920159617, 58.05453023602886, 54.8050348220333, 58.70664388902726, 54.498179958712676, 54.82181472163047, 55.828891108112956, 55.46167489021055, 54.95691291747555, 53.47714385678692, 52.51271147881785, 53.085926655800115, 53.06487921745547, 50.63373927147158, 45.75341647671115, 42.77904787371236, 44.7445789460213, 46.83731640538862, 50.944944043313306, 52.02257210208524, 55.28180676121866, 37.94191037454913, 44.95529259404829, 54.429130554199226, 52.08913080153927, 51.93728016268823, 45.847773013576386, 42.52357605964907, 40.15377806079003, 44.20702203627556, 49.375658650552076, 51.19932936083887, 51.353937425921046, 49.11336583475913, 45.49998429513747, 44.16276985599149, 42.71109673284715, 44.020140709415564, 43.45587245879635, 45.06011009216309, 44.33435786154963, 48.522315640603345, 47.62277103239491, 50.41634974941131, 49.90009523207142, 53.82375586417414, 51.66060793784357, 47.49701592230028, 38.34269423638621, 26.59266564153856, 13.76729671032198, 5.766255797878389, 2.3297650631397, 1.8684370887856332, 2.099610677649898, 2.551994299696338, 2.5707317071576274, 1.6670470372323067, 3.4178383936805115, 3.7797329358516203, 2.2273353078672966, 1.286523810798122, 2.0613795807284694, 1.402076100630145, 0.02888514983257459, 0.38911306389397193, 2.353579978789053, 8.946944013718637, 10.988319016272023, 17.07001574577824, 23.414869193107855, 27.024359741518577, 27.815686156672818, 18.599897007788382, 6.2948628394834465, 0.8192426591150223, 0.12214180277360064, 0.10361383608993023, 0.02582329749730566, 0.018745618008617914, 0.04968071761991709, 0.050114419146050374, 0.10852806029781219, 0.05824290696651705, 0.03064454544425732, 0.0414237798371863, 0.007625322229409171, 0.016923014397522616, 0.023821249281266527, 0.027046504340344862, 0.05163034626973733, 0.029423904995764458, 0.02159180701710284, 0.03370830533845771, 0.05133585441076467, 0.019698686927797335, 0.03557870517514887, 0.011338545610347103, 0.009459272560272968, 0.049349932345531644, 0.0119772091725721, 0.0730967159653383, 0.007489958323628432, 0.05302223992804366, 0.009327170273829854, 0.05644761822036198, 0.08254585126715322, 0.04100056988517604, 0.042080374644888986, 0.018332472536712885, 0.049182626403748035, 0.07045165951093359, 0.022398706360329545, 0.03433276658817645, 0.007123759677333217, 0.02239713396486496, 0.05248138568394127, 0.026538312254894166, 0.024005675372937997, 0.010187961029699974, 0.01289936931683652, 0.05535444139593071, 0.0789783866475186, 0.023746726163212332, 0.022321626423828067, 0.019694641983557134, 0.0626565425115968, 0.05158972445755236, 0.07264173634710812, 0.11637101565758068, 0.07209366938519864, 0.02712151009379135, 0.0445988618828837, 0.027930721107329574, 0.02902160158320781, 0.04849937556672001, 0.06760177412821401, 0.038469197048294934, 0.046122380937900276, 0.022815544376029603, 0.038002377541195, 0.07884974516327344, 0.019493965251791864, 0.035374270782115004, 0.9950407774698351, 13.83767972069402, 40.358325742906146, 47.97797695282967, 33.10335297738352, 18.439468145370483, 16.288771783151937, 19.19927243263491, 10.068910544918431, 1.3153587473976998, 0.07733273785561323, 0.11320469765773705, 0.3868431147308119, 0.4551135610428549, 3.9370099286879268, 4.327536302228128, 3.81693882326926, 6.87385174535936, 7.234282262863652, 12.690486465730975, 9.228116177743482, 6.91790045269074, 3.9958832340855754, 4.692585410610323, 8.933708956164699, 19.27840232849121, 33.2482139525875, 38.6441989867918, 46.88189022002682, 51.94277540329964, 55.79276607882593, 57.52520638127481, 50.583532933265936, 56.70428568317045, 56.75837124547651, 59.42934843801684, 56.46073002969065, 56.08744198276151, 56.04556283643169, 54.51767413846908, 57.04151538110549, 54.147877000993304, 53.806485668305434, 53.74683818509502, 54.36941639069588, 52.16094155465403, 46.6817081359125, 43.746371038498424, 46.17424757249894, 47.60665793572703, 53.97973675881663, 54.725814711663034, 56.866240347585375, 40.997895656093476, 48.70676902032668, 55.84828722861506, 53.795412817308986, 52.22160885410925, 46.62530837520477, 43.76278223529939, 42.22949243360951, 45.07006114529025, 50.94393207180885, 52.52927172568537, 52.24455079724712, 50.050274941229056, 46.66218257719471, 42.692547844302275, 44.314663640914425, 44.51688143514818, 44.02487108784337, 45.577070636133996, 47.77625337723763, 49.89543937867688, 49.86858291010703, 51.61112331574964, 51.04483896686185, 53.880563551379794, 51.537622021090606, 48.79028020366546, 42.02942017586001, 29.54723215872242, 16.201630446218676, 7.268426985509935, 3.6004193319428355, 2.5333167083801764, 6.551559413633039, 8.087839041986774, 3.940787416312003, 5.0765501491485105, 5.875425655995646, 7.911004376026892, 7.131953998919457, 3.664579747184631, 2.440886300417685, 0.7714472915376387, 0.10022459416500024, 0.5667490271791336, 2.299440238744982, 10.920789530200343, 12.045790995320967, 21.346377864960704, 26.646580580742132, 33.076657325990745, 34.98896575743152, 24.97828083653604, 8.846609784710793, 1.3429912323913267, 0.16220853063127688, 0.132641872811702, 0.021472756953669653, 0.043352540251949144, 0.03137957233364784, 0.0671171315855557, 0.037460094543113824, 0.019794982264659578, 0.006081199239669067, 0.07367789324733519, 0.01589351384374764, 0.05933002403546726, 0.07923772273164603, 0.06697174341928575, 0.011928085699647427, 0.022383493769373146, 0.04859787915202399, 0.008523250055018692, 0.04976235194912842, 0.022819593150709427, 0.032528514613307295, 0.08912183509598817, 0.05788382240420869, 0.0366567709152737, 0.04166228599065254, 0.03566412397870614, 0.06278798404720522, 0.07327406531980923, 0.04594072616929489, 0.08412099698738706, 0.02852323074494639, 0.10403889997471726, 0.19287921308029085, 0.10825491930928924, 0.14516367186461726, 0.1555499242198083, 0.1632117993769146, 0.16979866931515356, 0.10466145366550454, 0.13412734794039882, 0.1873885230311463, 0.16861880198121074, 0.13572513155879515, 0.09057368662568832, 0.14485800278282937, 0.19849312071117664, 0.19142254285754698, 0.16375471056709368, 0.1392310410137138, 0.10748270268161451, 0.237034804998867, 0.13142302692417177, 0.13245445706190603, 0.26633233613064217, 0.18602887018313333, 0.15691775888685258, 0.10279049841506828, 0.22054880737296997, 0.07698288082235283, 0.14344925902062847, 0.1723527911329462, 0.1457893665158941, 0.24093727220691022, 0.10305755666547245, 0.08210612445949547, 0.2306303559171577, 0.08428872427752904, 0.1673463759042563, 1.1110927404895907, 16.24691911282078, 47.90030617867747, 55.799390962046964, 41.54234417023198, 25.382716425003547, 26.162462042224025, 25.305873270957704, 9.652554873497257, 1.5597273120957038, 0.4884433193552879, 0.5149329237399564, 0.7109288582878729, 0.4853664038162078, 4.658433823816238, 6.402881481955129, 5.175122253356442, 8.775688429032604, 15.338894340299792, 22.116499946963405, 12.620833996803531, 11.238288725576094, 4.354782066037578, 4.964865071158256, 9.494233304454434, 18.760231733322144, 33.09145250628072, 40.29809774891023, 48.53541243460871, 55.23672696082823, 55.95756838398596, 57.79754438707906, 52.651830104089555, 59.19487307148596, 55.92823689983737, 60.63111166800223, 58.43890290106497, 57.86788032900903, 58.43056394207863, 58.65109528264692, 60.492557864035334, 55.41637935946065, 56.809369902456964, 55.837947860840835, 57.17168315764397, 55.88183526069888, 49.60176367913523, 46.06369949156239, 48.62139471115605, 50.952898610022764, 54.353899494294204, 56.662998814736646, 58.24556143053117, 45.14682192956248, 50.10711792976626, 59.39658095759731, 55.219166509566776, 55.50644482335737, 48.54250407988026, 45.07778429215954, 44.46605144008514, 47.40649546346357, 53.43930082936441, 54.94594597047376, 55.439725306726274, 52.35866823504048, 50.75790974401659, 46.53394068441084, 46.34764771307669, 47.666834938910704, 46.717790019127634, 48.97152508458784, 50.30782953385384, 52.127071888216086, 51.73880823196904, 54.40464319721345, 52.48956557243101, 55.31175013511412, 52.22470752654537, 49.2579875453826, 41.0968021423586, 30.126944741895123, 16.69021264199288, 8.030978402783795, 3.2693340268827256, 3.1668822082781025, 7.414576459315516, 10.18662283497472, 7.8952232099348505, 6.656960364310972, 10.71132907944341, 15.969804640739197, 11.480240129655408, 8.01042861515476, 7.148612305041283, 3.0728387255822462, 0.6536360842085654, 1.134188146360459, 3.2561254453274513, 13.163087944830618, 16.09328281494879, 26.283900583944014, 33.53558248089206, 38.57560065484817, 40.958903374210486, 27.800834102015344, 9.469643965844186, 1.2990505128137528, 0.2622661252896632, 0.516167305890591, 0.1001778934451361, 0.22423603451780735, 0.16900933828325043, 0.1969081307611158, 0.22229508947460885, 0.1749854982500115, 0.13443416615407314, 0.11208452389485414, 0.2278662493993198, 0.14336408536520698, 0.11881989231633565, 0.12015673106596356, 0.08642532051570954, 0.169208888865767, 0.27922289926678906, 0.17465408861396775, 0.22715144340069066, 0.0976079365899486, 0.12084024237288583, 0.2651134595995949, 0.15222167055453026, 0.17205708119417393, 0.1619794090548831, 0.16699615114879224, 0.13971381430183688, 0.1254887643059896, 0.09417610783730784, 0.18262953888024056, 0.22475925724833246], [0.007675089216190241, 0.08361362461601535, 0.03969289993326511, 0.02658655855714554, 0.013465824304148557, 0.060184204410160744, 0.055678335709437254, 0.07627409627480854, 0.02730092597043803, 0.044632722969136895, 0.02909461359283136, 0.05888229160900078, 0.017162512634850798, 0.119173533823942, 0.0156796345442173, 0.008556991440033721, 0.05101153874889978, 0.02423538875225331, 0.04759457976286931, 0.04247802024286601, 0.02877070204234652, 0.022582916032162406, 0.07455485707689678, 0.04211672168645648, 0.07764258211658848, 0.052558871647042614, 0.04972753708340949, 0.05505938646233371, 0.0389447576186109, 0.0670400478186146, 0.06643192722432076, 0.026959635715390888, 0.0935133268696166, 0.06510386018142586, 0.05618196957173848, 0.039223682570962176, 0.07007823761312232, 0.05195723215658819, 3.5374184673832314, 16.23133259434854, 41.49911180619271, 40.55750370025635, 24.674506994985766, 32.42246481680101, 30.5736772091158, 8.71203620587626, 2.7892447431241316, 0.7354512714570569, 0.17720704597811546, 0.6648915092791281, 0.5213961930524919, 6.328566785781614, 3.6002947966898646, 2.3859275204520074, 4.028806383571317, 6.092180734680546, 9.77777458006336, 6.899663882870828, 6.447620526436837, 5.173226277674399, 1.839724971402076, 0.7657597935007465, 4.56447099485705, 13.041468974082703, 21.74194105209843, 30.561519822766705, 38.21295792056669, 46.200821630416385, 52.4409987849574, 53.92753785656345, 50.31889846248012, 59.58232087473716, 55.780363544341064, 56.866275648916925, 56.085363126570186, 56.84995074425974, 56.34030542066021, 55.663480835576216, 53.65074796061362, 57.243552746311316, 54.97646593278455, 53.61380315596058, 55.72458744049073, 51.55272706862419, 41.34865753112301, 41.82948127869637, 45.747842788696296, 52.90874927274643, 53.39960644322058, 55.304101513278106, 35.96653807547785, 45.09022212797596, 55.024005059273016, 54.00095678144886, 51.35601628211237, 45.940697885328724, 42.824833700733805, 43.97774773259317, 49.27794064244917, 53.14592322995586, 53.70592786419777, 54.12850833708241, 51.23726652514551, 50.635202315545854, 48.610247335126324, 47.082746951810776, 45.974179237119614, 47.432551768518266, 48.211962023089015, 46.39768931173509, 48.81747007369996, 50.78827673389066, 49.46667725040067, 50.59954012593916, 47.908900091725016, 43.882508662439164, 32.37491980675728, 24.698098090387163, 14.685849124385467, 7.847994931282536, 1.6456574946641924, 1.4614426440769628, 1.708398011903609, 6.300933687917649, 4.132878876501515, 4.8785636117381435, 4.279624060277016, 3.482422179752781, 6.485376281123008, 6.439251169081658, 2.582826090435828, 2.2714249549373506, 0.5030183872628597, 0.39300500505393554, 0.8569957784587338, 3.812591611377655, 9.588463344881612, 12.666323684876966, 18.630365979286935, 24.99405857055418, 30.357595797507997, 17.22059161432328, 13.092436252101777, 2.29308428302888, 0.22281213753646423, 0.015713199729009742, 0.05055242225587849, 0.059973361691640276, 0.019515138006799167, 0.02198597840634325, 0.03531740024505604, 0.03602689342393029, 0.03553007391371554, 0.014789109043176136, 0.026407968140237277, 0.11791039273262986, 0.08038707678356478, 0.06231779758367808, 0.014131588226694976, 0.029039999184709404, 0.06883964197890413, 0.07642663970229126, 0.02722387859267333, 0.05156407966428707, 0.03144364026675542, 0.06217921993905499, 0.048483057893932834, 0.05154711464720388, 0.03595383544903129, 0.07212200697751776, 0.04666049641767337, 0.017771052662283182, 0.004444720520217333, 0.02077066226892414, 0.04946615171408461, 0.0678202624042188, 0.024972120187275355, 0.025411856571032156, 0.013400316125743333, 0.13548246554790006, 0.05560465337287995, 0.07603310033558838, 0.0493946144237153, 0.028636707518730434, 0.012657510571091646, 0.010625064943826968, 0.02037674751913836, 0.033655295884537126, 0.019831679791452426, 0.037505213291414326, 0.012278324819260068, 0.057971462862746376, 0.007447307814858975, 0.02307597022022932, 0.016086233794809352, 0.06562595676270223, 0.045608232518838304, 0.01643473676766359, 0.0707491314519317, 0.03424051044989498, 0.015588566799828363, 0.016713893461611964, 0.007750051398386038, 0.03431997675028059, 0.060171763142270435, 0.004744835943359161, 0.029088048219320276, 0.06894206793438043, 0.079092962757474, 0.03596258800356619, 0.008232876876248948, 0.03023518636191805, 0.07051604920096936, 0.055758173562466144, 4.283741078069133, 21.697839883065996, 47.11729911065871, 44.415429330641224, 24.718519910689324, 24.216962514385102, 31.310025722749774, 13.632983969103906, 4.151628786517728, 0.3886230127705682, 0.017065414820887873, 0.1890585334190438, 1.0676065255557339, 1.771439816201887, 4.196330568482799, 5.8012845247022575, 7.887806007939001, 5.352077532199122, 11.742793783064812, 11.172344857646573, 9.87210758270756, 6.0356025061299725, 3.458073331463722, 1.9389101910975672, 6.3696423365223795, 17.873938852740874, 25.51818528482991, 32.75480331913118, 42.208374392601755, 46.72372064282818, 54.07832161072762, 54.459921160051906, 52.53727336083689, 58.830080878350046, 55.673004350354596, 57.997773539635446, 59.00675227565151, 57.6446621648727, 58.03437317571333, 57.157601848725356, 53.96771469423848, 58.195225654109834, 57.36132191073511, 57.031344675248675, 56.145485216571444, 53.6036128382529, 43.32884257839572, 43.96756918199601, 48.131482831893436, 55.80531766337734, 55.585998335192286, 57.46542161510837, 39.94018539305657, 48.27565346994708, 56.21632714425364, 55.675942205613666, 53.11189666871102, 47.63220433265933, 43.688198366472804, 45.70614014902423, 50.25211618792627, 55.03635660294564, 55.64234710508778, 55.14621826910204, 52.923689580732784, 50.69534793976815, 50.56855340157786, 48.40752747751052, 47.467978615914625, 48.56986653420233, 49.02795622425695, 47.43095928622831, 52.396354367656095, 52.109119199937396, 51.30834379503804, 52.582066828204745, 49.92808918799124, 46.69096100714899, 35.1134813985517, 28.87102926931074, 15.666981973955709, 11.254592057197325, 3.4848207091131522, 1.8844596032173404, 2.0891046091433494, 7.492298224279958, 8.723458147818043, 6.55695757558269, 7.582189142704011, 8.071305271117918, 7.84099595200631, 4.069119033313567, 2.9547768542843484, 0.8260672154926485, 0.44413110842147185, 0.10649025875834689, 1.3911416357563389, 4.38288486772968, 12.93447946348498, 16.50200947638481, 22.446343821863977, 30.19513906971101, 34.70228756627729, 23.38244688126349, 17.209791368053807, 3.6161399464453425, 0.40552802984752967, 0.017951203983337168, 0.014573918775685374, 0.030402846619366642, 0.03740880112614363, 0.013079213245110887, 0.02122926931347578, 0.03743158075057211, 0.023725856012935122, 0.08848908477492871, 0.09916619007145205, 0.05623159674747337, 0.03143944402015017, 0.033380419706865665, 0.01056690067578588, 0.02623051919433619, 0.04900562561928265, 0.053165452404608654, 0.018959189915368636, 0.06844677676957461, 0.012843775273781392, 0.04163212893951324, 0.04559877133297344, 0.04524918626092615, 0.028693323331554572, 0.04046015231119048, 0.08261581807727776, 0.05186339021630345, 0.1033980980695736, 0.052846664067117445, 0.029033941344448158, 0.060277483275821137, 0.09144264483644117, 0.12900808796046243, 0.16118119140305828, 0.24858730364470716, 0.15118892274556622, 0.19867327394745044, 0.14552175668218445, 0.15680644631145463, 0.12128679502394893, 0.14810410117910755, 0.21977030882431617, 0.13047609628448564, 0.1085957288441639, 0.18850667432190912, 0.10151947427901531, 0.10038679796120814, 0.09130625054240228, 0.1086381854369275, 0.11202014186569761, 0.1594775037900094, 0.2200912690210727, 0.11652326797165218, 0.17276848576241927, 0.15898936788641638, 0.1385547539159175, 0.1352187014755703, 0.19419256357416032, 0.16999481846728634, 0.16542514996422877, 0.19266074012604453, 0.12813124670496873, 0.10734178080794313, 0.22442173423065295, 0.11161183232381461, 0.14117722609831443, 0.11058626275870109, 0.17520211727148102, 0.3880458421284153, 5.028415802986392, 25.614383374491048, 55.49353630312028, 53.401908874511726, 35.30427332847349, 41.783868035962506, 39.18663924740207, 14.16759321766515, 4.557267562035592, 1.6562087930017904, 0.6720929809155003, 2.0974732310541215, 3.189283109480335, 12.04100864548837, 10.493546339773363, 11.303833492340582, 17.164744907809844, 14.669901747857372, 21.064396712087817, 17.52165117571431, 16.23609729351536, 10.72889345307504, 4.227938007923865, 1.2990458549991732, 4.734980838914072, 16.483933233445693, 24.123474782513036, 31.463796361800167, 42.98488601561516, 47.622723963952836, 54.3740330203887, 54.4674599555231, 53.49647329699609, 60.33184266859486, 55.707446682837706, 58.2546103385187, 59.61747315622146, 60.58272530955654, 60.9525106799218, 58.06036672284527, 57.436011683556345, 60.643180801022446, 59.814195709843794, 59.03515415806925, 58.92717915196573, 55.26244594204811, 45.72845451293453, 44.786767959594734, 50.98124557925809, 57.33952922205771, 57.831849436606134, 58.321070978718424, 43.62294189391598, 50.61687700210079, 58.69863048676522, 58.621151908751465, 53.985765441771484, 49.64199150762251, 46.03396008091588, 48.07922117171749, 53.52646766170379, 58.05362416851906, 57.02056992438532, 57.719854001075994, 55.457619159452385, 53.64564495701944, 52.8685292889995, 50.671088080252375, 50.645129834451986, 52.60473420543056, 51.77620803156207, 49.62396429431055, 54.979544993369814, 54.72929385400588, 54.006608916867165, 52.21433677980977, 51.966250788780954, 46.874994693263886, 34.24331926530407, 28.24180852982306, 16.865654376245317, 9.927731694713716, 2.4730041382774233, 3.0848674091600605, 4.60081567687373, 14.332078791433766, 13.43308331504945, 12.460310997501498, 11.095539946709911, 12.436478676334506, 16.09745131384942, 15.743931031996205, 7.57214101091508, 3.9492038421092497, 1.5059163157017001, 0.8476476671714938, 1.735142570349478, 5.929546029336992, 14.580429542449213, 20.752654575532485, 28.811915228443763, 35.5851464117727, 41.5543270111084, 29.801586097286595, 20.798181526122555, 4.598190630635908, 0.4334185945410883, 0.08725082621939721, 0.16291972069490343, 0.25670555270006584, 0.17913839960050199, 0.12606627968770842, 0.15894913294863316, 0.19501149624345765, 0.11995665954365847, 0.21325894451189428, 0.1622063855850889, 0.21505990996956828, 0.13635415103166335, 0.14505329391648694, 0.11887161857298306, 0.14930305942412347, 0.13377137752550264, 0.1663572797852178, 0.14170823228215018, 0.1085383182151183, 0.17309399652144603, 0.15446638478146446, 0.1778933075406859, 0.16211200355281755, 0.14783186417433525, 0.1180413554632856, 0.13004233730175804, 0.14232945297994923, 0.23237372688468427, 0.1348569087924496, 0.1772078733530737, 0.1977925945914561], [0.056603225999541824, 0.014105014551821497, 0.01763139291846704, 0.025067308527087013, 0.030946355358126666, 0.06730282363752205, 0.04279982696677889, 0.03395500863271375, 0.06361439373464355, 0.01649438820388769, 0.03952935165275009, 0.04484757615794097, 0.04357719936618402, 0.06421182357195405, 0.024495990796675606, 0.03303654582029389, 0.017065866812763196, 0.03894707120414223, 0.03172142757853914, 0.03295187395246279, 0.01463611841186761, 0.06650250690478472, 0.11922368193946539, 0.0650797973597242, 0.03327593297487305, 0.03407273336403793, 0.05268113161887854, 0.09873606234548554, 0.0153818418039009, 0.037223802383748755, 0.05407702425614961, 0.06903451176420336, 0.056814026583226464, 0.05148024283229344, 0.0412215402860555, 0.03633854565240684, 0.04178847599354002, 0.041306342388833725, 0.4073318298305235, 7.642593153061406, 25.42510940182594, 38.347561897770056, 40.46393163742558, 18.296870377755937, 18.378426259563817, 25.316581341528124, 8.521137391367267, 2.0990894927132517, 0.21489222864470175, 0.05795202338166776, 0.20591332577168944, 1.9988267243869844, 0.4542869215290393, 4.826788815759844, 6.64367284505598, 2.565222493102474, 9.678306214271053, 8.858652441732346, 4.883971579613225, 4.354361391836598, 2.535560304118741, 0.6118738735395094, 0.7810694784406693, 3.3440671909239987, 9.985758258450417, 15.387297368818714, 20.526392652142434, 28.31824964092624, 38.671020154030096, 49.21938750051683, 49.7721435946803, 52.899068863161155, 58.62829846720542, 57.06810512850362, 54.4865305193009, 58.20234083360242, 57.55798562880486, 56.508626091864805, 58.011129210072184, 55.9815772118107, 56.77746142110517, 59.672837411203695, 54.982537761811294, 56.21224003453409, 46.46087477284093, 43.71330938031597, 46.60585734152025, 53.08805650280368, 54.314087437045195, 56.231914643318426, 39.384915059612645, 44.540294062706735, 54.9003601843311, 53.90177965164185, 52.66747643870693, 46.40521634009577, 44.8477804276251, 46.77148334441647, 52.28431578605406, 55.54887702388149, 53.625868366610625, 52.99597494063839, 53.69833415554416, 52.3147573009614, 50.726479791825824, 50.27113576089182, 50.01521679662889, 49.967391337117846, 48.34967251746885, 48.67226392992082, 50.28967680469636, 49.86913596430133, 51.00120652106501, 49.57340494278939, 39.16479949028262, 28.675907042718705, 18.987546813103464, 12.788153483021645, 6.2874039623045155, 3.109557748802247, 1.7098181550541234, 0.844280741387798, 1.1329810369399287, 7.003070798612411, 8.583043179204388, 2.558235771233036, 5.879770171257758, 7.685817182064057, 5.239952168157024, 0.8807508166759246, 2.517787064275434, 0.8376962463221244, 0.35495924012314894, 0.47795428864417544, 4.046811288402927, 9.781021321973494, 19.129138492768814, 15.125817464243982, 17.858898524315126, 26.194688235559774, 26.271915781882505, 19.614833824096188, 8.704331690265287, 1.107590554221984, 0.04987155395229498, 0.027535381434004635, 0.04573872027498099, 0.09732002542624552, 0.02814332199763627, 0.031792507131373694, 0.11152025417334611, 0.03154331022092412, 0.0022591521114771885, 0.02860741614694557, 0.04031646102967282, 0.09383143721929482, 0.014189571506463954, 0.04790414823219181, 0.021413264480689843, 0.033047462573214885, 0.06761963929860823, 0.06083543660239347, 0.012734294606132374, 0.06294113268414814, 0.04190913101117458, 0.01934372774896122, 0.05451241883659556, 0.06213274138468889, 0.04835076983116808, 0.07245672611339439, 0.014340954310741397, 0.09133112541730366, 0.04915027834114529, 0.02369310575417213, 0.039577638174617485, 0.038821440445439476, 0.06682993288362218, 0.02387785168755199, 0.021861766825520226, 0.019315947485607, 0.06328763808273981, 0.027441173686736056, 0.012303463994495332, 0.043950766820700905, 0.0034710560454010607, 0.05084525553449508, 0.02947924144175505, 0.048884556914168986, 0.06482190918177366, 0.04309689288117713, 0.030416440849582997, 0.017707377349236803, 0.025280610387844425, 0.05497350417558224, 0.0375776928699305, 0.09175051259057176, 0.004808511735210496, 0.03235964585215815, 0.05949041603373424, 0.038696261678612044, 0.1022201689380792, 0.04248354373680007, 0.020378040292510585, 0.04288903407512173, 0.03651229056319402, 0.04850160105214004, 0.045897112783765605, 0.04711176050947078, 0.03026116631865021, 0.04642777805847507, 0.07448821508836362, 0.045162986047686114, 0.10045980614039207, 0.036764459894789804, 0.6404116905985341, 9.87713606126847, 34.222758200860795, 44.213788124822806, 44.7423824187248, 24.035166540453513, 24.331882076878703, 23.044803373275265, 10.446826008058364, 2.9666895827939435, 0.09496605173955042, 0.026045757939197847, 0.2723890272600036, 0.9511543582043341, 1.7815265588222013, 2.3337769123815724, 5.2018036861573504, 6.687891194897314, 9.937503299405499, 8.426642590953458, 8.48052320941802, 7.151598209334958, 5.78845396157234, 2.5133991577932915, 1.6442763300672656, 5.53271052337462, 11.835741208445642, 17.992578783342918, 24.149003528779556, 32.88513387403181, 41.10769064195695, 51.0888950286373, 51.686185713737245, 55.620138645172126, 58.386605939557484, 56.63722884270453, 53.81591112382951, 58.75541856212001, 58.71047996705579, 58.80875102935299, 58.92411185849098, 57.82456951756632, 57.57357705023981, 60.62149793870988, 56.99770642865089, 56.09834617184055, 49.25254329558342, 44.71833436719833, 49.29695237067438, 55.9401491380507, 57.375054128708385, 58.39434869827763, 41.46011560193954, 49.876306056976325, 57.606877973002774, 55.016470186172, 54.440595642212905, 47.71043600574617, 45.96258078852008, 47.7165941269167, 53.432326855198035, 57.95425876494377, 54.58352288892193, 54.80314423961025, 55.258107800637525, 54.721511871584006, 52.522964554448286, 51.976037102360884, 50.77239897943313, 51.270610593980365, 49.15000469453874, 51.07627284142279, 50.496832862977065, 51.823856984415364, 52.05279396426294, 49.86861036669824, 41.835996335552586, 32.85224283895185, 23.2558366944713, 15.690193580042934, 7.978882953043907, 5.600636659129973, 3.949545578610513, 4.122849866267174, 2.4401138386418744, 6.138378900866355, 8.79820675619187, 6.916233445367506, 7.5286056437800015, 6.533437082844396, 5.819070021952353, 4.045357559957813, 1.7763344438806659, 0.20837346392293132, 0.18171098413726977, 0.5286822407957047, 3.745482799506957, 12.210306967458418, 19.85972700580474, 17.86477227364817, 23.041975344381026, 32.53357575785729, 33.73142250122563, 22.2065124588628, 11.67514858707305, 1.4261751429688547, 0.05729064818531756, 0.02075652028584192, 0.034144178723856326, 0.0704710262136594, 0.012467955520767118, 0.1063862240182296, 0.054398030418181614, 0.010968757842126633, 0.009053934481926262, 0.0413033316632913, 0.029060145381898172, 0.043876257109185385, 0.03672498721449125, 0.0479836643282925, 0.06804065823915505, 0.02376480200778573, 0.09179855396430339, 0.03514458230065723, 0.020052899170907277, 0.05422244306593653, 0.0238215844447334, 0.05453139866491961, 0.07302275783712826, 0.053794410590442925, 0.007531575571310016, 0.03164885223903243, 0.0860638955547925, 0.036761885839364225, 0.02681238404024513, 0.011237302303103911, 0.02749677251784071, 0.06773790795235865, 0.1522575081476281, 0.12137566122316545, 0.19283196077712123, 0.1049869261201351, 0.2266033840996604, 0.1441662100654456, 0.1548636933007548, 0.12971788374406676, 0.15827224830225592, 0.14960437712650146, 0.1263399262942614, 0.16030224340577282, 0.11317903371227366, 0.19355500988181562, 0.10030371572581992, 0.14846774779500502, 0.11196397995996861, 0.2426699945522893, 0.10273737787839868, 0.16670293865665314, 0.11910135301971629, 0.1728053805568526, 0.16137234566192474, 0.175414017191337, 0.13664132675095914, 0.09656033433613279, 0.1508607919658384, 0.22788872641901817, 0.2660318151597054, 0.14336551028874614, 0.21688529831026832, 0.1172876092154653, 0.32049055421544664, 0.20483324905076336, 0.17053206060682574, 0.18744630138239554, 0.15199673181820303, 0.08911071916020687, 0.8551051347486435, 12.135836847366827, 41.35163853245397, 53.32172778344924, 54.87172295970302, 29.045847346705777, 29.81486724269006, 36.1160784382974, 13.138959484715617, 3.2306815203159087, 0.5219301869792323, 0.3791814694000829, 1.22730239504768, 5.76366065971313, 5.806269366894999, 11.857555470158978, 14.480921952955185, 13.408002699575118, 18.929378063448016, 20.809819198423817, 14.721578974877636, 9.574343792853817, 5.483866228211311, 2.206530075880789, 1.4423996594644364, 4.3953893838390234, 11.482588648796083, 17.19015794415628, 24.60452994992656, 31.59385038960365, 40.30955891455374, 49.63792008738364, 54.6834844927634, 56.678778509939875, 59.86841463273572, 55.99539572192777, 54.7912633803583, 59.236242309693374, 59.51629169525639, 59.024728498151234, 60.85542417341664, 59.125670694535785, 59.95167870675365, 62.122867491937455, 58.29431649177306, 58.274720330392164, 52.29342352959418, 47.7993247585912, 52.19615659406109, 57.07281589508057, 60.79232108208441, 58.55551496628792, 47.90466785430909, 51.24360899771414, 59.040382677508944, 57.055749662460826, 57.45811816184752, 48.87461508474043, 49.71249611146989, 51.88426540743921, 57.22452140623524, 60.0087413480205, 55.60976397606635, 54.33215779642905, 56.42826064940422, 57.27351965442781, 55.153239311710486, 55.45010389820222, 54.18700656583233, 55.3215992066168, 51.695650392963046, 52.86451278194305, 54.983286934514204, 54.17040709526309, 55.87792858000725, 51.933549988654356, 41.55845726689985, 30.27442389918912, 21.71244090603244, 15.990146052452827, 8.69464147475458, 4.5694215163107845, 3.5291849220952685, 3.7625357941273725, 5.200884380648214, 12.012990174754975, 18.153648953283987, 10.268125764785275, 13.907843078336409, 16.684876257373443, 14.40157436555432, 8.252571725076246, 5.724698776198972, 1.7347410177030873, 0.6397035189213292, 0.9205210148807496, 5.436390840238141, 14.72751057917072, 26.996408931670654, 25.032537021944602, 28.21274768921637, 38.360952869538345, 40.28222783919304, 27.443284565402617, 12.285906730159638, 1.6651233598109216, 0.28740297161763717, 0.10703961274796918, 0.09683345234201801, 0.17742413997409806, 0.148666333106737, 0.2367887682011051, 0.16785003274919527, 0.09595749208763724, 0.08047447975484595, 0.13032928319467654, 0.13247196983185508, 0.19653800304137892, 0.12132015815305135, 0.16257459808501507, 0.1321101618269759, 0.1467009805022709, 0.11649470055295576, 0.10254052392537556, 0.09526486433441601, 0.20610270270657158, 0.1184433447797933, 0.345629085936854, 0.12266622826216683, 0.182031775794683, 0.09541923105115853, 0.14618250751687636, 0.2308258155901586, 0.1687132606222745, 0.14037937616869328, 0.059954787889916095, 0.1830661170665295, 0.0769825514045454], [0.07594273260404026, 0.06692699622362852, 0.012964798971229504, 0.0759295482308634, 0.07513472434854315, 0.04348841360619953, 0.08703314999659216, 0.027046615423093882, 0.04868755357400064, 0.10708599171090512, 0.03432500611750349, 0.09055386793108718, 0.058833062798986514, 0.02472546094307496, 0.05597774585288379, 0.11992337302334848, 0.03270481442732196, 0.0381216804136432, 0.014415851854268583, 0.08183528173474536, 0.0246512308536518, 0.022447487008908105, 0.025215713164558815, 0.02544595705976169, 0.030958015216334216, 0.04147247238565357, 0.03138101066372568, 0.07560884084312186, 0.03861214905496567, 0.030837266352928938, 0.0650941691691837, 0.06474566045067003, 0.042305137180993636, 0.03655244506174519, 0.08704110965012543, 0.0380741446579416, 0.09655326334459167, 0.02241344780721251, 0.036992041634455804, 1.4636726340939923, 11.18181542042763, 29.403324319470315, 40.38126376367385, 25.246592529358406, 21.793398626389045, 22.180377706404656, 15.369800656072556, 5.613392206930346, 1.4819415634678257, 0.4157600840253215, 0.13706754742851182, 0.09871743108716705, 2.162577711766766, 1.3419363599631096, 3.600549750751065, 3.0755397677421574, 10.705271959304811, 5.662288963794709, 8.65909303388288, 4.7176586716405815, 5.445723139470624, 3.363968806882059, 1.1238664292520093, 0.7507310483244158, 1.157550886273384, 4.013454471865009, 7.735284643788492, 15.879957848979583, 23.289290589670983, 34.05627319889684, 44.28289636488884, 44.20319380298738, 48.72068166732789, 60.509561338732325, 57.72526294954362, 54.22569290284188, 54.48818968188379, 58.37540365034535, 54.668689312473425, 56.43692516511487, 56.661928007679606, 59.82536269772438, 58.52253567787909, 55.847447841398186, 47.621798284592174, 45.79292258908672, 49.04645412198959, 54.14182870618759, 53.890616586131436, 58.18656506076936, 38.26745533174084, 44.94987580084032, 56.44361672862884, 55.93601888225925, 54.91858351615168, 49.09505228842459, 47.926480154837336, 51.083258582699685, 53.32866645628407, 52.467361034885535, 55.96746452393071, 51.58612997301164, 54.394194003074404, 53.89986161262759, 52.49907339772871, 51.375173138033965, 50.759337486759314, 50.60948725669615, 50.389685476979906, 50.80730807396674, 49.795689582824714, 52.77585544893819, 49.94037405137093, 39.1979552853492, 22.70386311315721, 15.49493407049487, 8.064241572733849, 6.078635809882996, 1.3679799173147449, 4.443356538972547, 2.7689641281481716, 3.79098768676481, 0.9748472513691072, 3.5304942582884147, 5.160817859634276, 5.229092105742424, 6.472397158222814, 4.674769514991391, 4.476090188949339, 2.099942853373866, 1.5692290086900036, 0.3966699083966594, 0.6853650558379389, 2.2070505253730284, 7.165227465091213, 10.418809498510054, 12.480622991438835, 17.026961849581813, 19.935507197533887, 22.265875570235714, 23.788653419863795, 13.728558401907645, 3.001524642590554, 0.3341507599238427, 0.040843912565539923, 0.06179475105337559, 0.054255798534159703, 0.04141393943779892, 0.01553205728170372, 0.030300518340100686, 0.06481673042740553, 0.039500508442400925, 0.0599386808913081, 0.037998558592892466, 0.004254936122320472, 0.07077108753184158, 0.06606470297781691, 0.030155128258610928, 0.04038155552059893, 0.036822471902855945, 0.02721590170216176, 0.03210887271580437, 0.04496471483200308, 0.014192384006755968, 0.03146659034574705, 0.07067094451837963, 0.06823442485784331, 0.018741540505640933, 0.02636233994346713, 0.02133716322151163, 0.0431250581037133, 0.07793506682519952, 0.010293364194372009, 0.056500692791756124, 0.014420683953850983, 0.08565138785108443, 0.050457044309305574, 0.01259834272786975, 0.014947867358944591, 0.0639810472456438, 0.049976465863085566, 0.05738813670412187, 0.05432435957294318, 0.07157805390776166, 0.03725993492069744, 0.09668577357285446, 0.09634431286324417, 0.014876900804078868, 0.012892286833976547, 0.05222353197994733, 0.051133561233479174, 0.0649500756915058, 0.054070225225821625, 0.020837840519004294, 0.048849600322184064, 0.03434407787637846, 0.006649805497633474, 0.028328495025033915, 0.05197886264913025, 0.04892307198456219, 0.0773758456231125, 0.07232039310638944, 0.05705771915194008, 0.0060573303339732515, 0.07349651427038255, 0.0419571187587515, 0.029107679222379963, 0.036629333476265596, 0.03751169439525374, 0.0406160397124627, 0.04988393776359097, 0.01135006565750847, 0.07746777617402616, 0.05692437388783982, 0.03990962620704405, 2.1601029413361705, 13.940734113416365, 37.338916563218646, 47.8789920191611, 26.325764040793143, 24.378530825338057, 31.549747259386127, 21.019711109899706, 7.942907954415968, 2.3659945255325687, 0.24184931520252462, 0.06729174600613695, 0.08324519761147038, 0.15536494462961153, 2.0902107175319427, 3.7659480110291517, 3.5979705472146315, 7.709777470557921, 8.33522096756966, 10.430348130964465, 9.250423677505987, 10.124139478129726, 4.5752011287596925, 3.4339044219063175, 1.9805696846977359, 3.207927605798168, 5.435265610294958, 11.696892246123284, 17.8940821847608, 27.01607373452956, 36.739374437639796, 48.01636126733596, 47.56940718620054, 53.103039956861934, 60.7837507032579, 58.016616605943256, 54.82834939033755, 55.589587303899954, 58.58532497959753, 56.095745640416304, 57.9913761538844, 58.2296601418526, 61.426729156124985, 60.35947184408865, 57.65013779363325, 50.11819078076271, 46.00294197759321, 51.33812242938627, 57.00086785900978, 56.97683941933417, 58.472070463242076, 42.33142698964765, 48.101715964655725, 58.5464935148916, 57.51536907688264, 56.29042071680869, 49.89744370983493, 49.72957411120015, 52.01992057984876, 56.10942294520717, 53.423521134161184, 56.05817717890586, 53.72716357631069, 54.903839326673946, 55.16810509466357, 54.251529555166925, 52.75140731565414, 52.76331955386747, 51.27942808212773, 50.95933914184571, 50.40612020800191, 51.33207805695073, 53.121730050733014, 52.975821802693034, 41.773595348481216, 28.70704281714655, 20.419506103761737, 11.146427796732995, 5.912037549480315, 3.0400332472016736, 8.95148023482292, 7.493064067056102, 6.587293186495382, 5.112678120213171, 6.422232985496522, 7.501480002557078, 8.743767199977752, 8.42597088506145, 4.813419417027505, 4.148695834221379, 1.7898086434410465, 0.6474976361759248, 0.2104374120432523, 0.5148081433388495, 2.9541377530943964, 10.334387344698753, 11.819282943202603, 18.67236868027718, 22.11946918118385, 26.186902330767726, 29.462038278579715, 28.656428552442982, 17.69808723080543, 4.3608303608432895, 0.5265504326070509, 0.05495095820797067, 0.05783581167399403, 0.021087364932041497, 0.0385553129918633, 0.10089885879067645, 0.015983615359742076, 0.025353153168614355, 0.047390091743680744, 0.022077610182966438, 0.05434318235324276, 0.05562174479447066, 0.03698812309472311, 0.05732640533918335, 0.015900315746905345, 0.05616497008069869, 0.0293121614959091, 0.030982813482443174, 0.04020769952706272, 0.025095977452433398, 0.02013537236639569, 0.04491644363189417, 0.007418468913754389, 0.03575327746089428, 0.011807062959809218, 0.04809427210280011, 0.07180702226657061, 0.05017187957081103, 0.04042221180674049, 0.03313584613703913, 0.011449952989125685, 0.04728275516460981, 0.04419374692764494, 0.1697750891288442, 0.10085067952111845, 0.0634818566933034, 0.17727401738445606, 0.16415368915805895, 0.15908062427995667, 0.203555996619886, 0.17715121349019392, 0.1720912793591138, 0.18727036162970528, 0.37356484981794513, 0.17445933374185718, 0.11100272347609844, 0.19334013754081344, 0.1270391883689069, 0.3082807674523323, 0.13675951879591713, 0.07542301855620838, 0.11356351791971153, 0.1119134564613623, 0.08184023066273621, 0.13716847185165654, 0.18687271603172828, 0.12359894030997831, 0.22428267395063756, 0.13850429936522438, 0.13049759271164096, 0.09341650867774602, 0.13839988158114497, 0.10985222795317251, 0.15129041407377491, 0.1280644668206092, 0.11645245846481093, 0.10319855514793627, 0.2349253665776022, 0.08957263187415178, 0.425676264830174, 0.12924733721921522, 0.20812215644025034, 2.341053889643762, 19.148528729715657, 46.24378727328393, 54.70501830500942, 34.964050862096975, 32.514024703733384, 32.975307203108265, 24.432181004554998, 9.01123950558324, 2.4824945580574775, 0.7055504307631524, 0.7538455328153026, 0.9921709508184464, 4.007285073880227, 6.029656683245014, 9.965433516810018, 9.298995367942318, 20.95042440199083, 17.900477609326764, 17.16971847318834, 14.46685927529489, 13.350392887669226, 8.592927552038624, 3.432016536112755, 1.5392022844283813, 2.0297191892900774, 5.80131100070092, 10.24129871399172, 18.771447750829882, 26.658655597317605, 35.55123359926286, 46.638275730994444, 49.427539840821304, 53.76402601119011, 63.889667757095836, 58.798219465440326, 54.90153297301262, 53.34617199436311, 57.934678293043575, 55.3684832972865, 57.19559000384424, 57.73636717950144, 61.67028480960477, 62.6479983329773, 59.74436967603622, 53.28503401048722, 48.490779784417924, 53.50220387981784, 57.88140858373335, 59.68120382678125, 60.13596734692974, 46.02784118344707, 50.70026266959406, 60.18631096809142, 60.037919859732355, 58.55504428186725, 53.117733155527425, 52.83629132855324, 55.30148921474334, 56.43627012929609, 56.14042535904915, 57.13157300026187, 54.215373146918516, 56.8511196105711, 57.29446511114798, 54.44856197603288, 54.71678541552637, 54.43949737856465, 54.95876819856706, 54.49111184766216, 53.37783336639405, 53.58995906768307, 56.808730556118874, 53.24590836801837, 42.04152461021177, 25.846309200409923, 19.032683487861387, 9.960401115878936, 7.3777297139167795, 2.577973383088266, 7.652241693389032, 6.501572237860772, 8.408463385797317, 5.812975149000845, 9.31414552273289, 12.128185283753181, 13.493022034245154, 17.614791777826127, 11.916262565120576, 10.606898915383125, 5.2865352169159925, 3.613090058488231, 0.7624152374844398, 1.126937277374729, 2.884549022682252, 11.1439263051556, 16.14210161470598, 21.88536055626408, 27.32240496143218, 31.22843061724017, 33.952377457772535, 34.05858739729851, 19.453406718469438, 4.498315318938225, 0.7369555617051741, 0.17236016089877776, 0.12444395061221816, 0.13423219473371584, 0.09179775723286214, 0.20009559278766956, 0.10922776670345377, 0.1978374107350265, 0.10762024610753983, 0.2138702979972286, 0.22933761318845136, 0.08713448810721598, 0.2757121941014644, 0.18202155618177307, 0.22153021196924874, 0.08825479976592526, 0.13524237359243055, 0.11664750445033274, 0.10363853476460903, 0.19592928489850414, 0.07526115949956641, 0.08990625550429668, 0.15407679842845087, 0.1582659970247938, 0.09935436424829307, 0.10809852245954737, 0.1719982303198307, 0.19703982127529962, 0.20886115549552828, 0.09418327842027911, 0.13740065777974744, 0.14901413702436034, 0.28672250167977426], [0.03496371277217423, 0.04391127115776462, 0.021404630669783202, 0.04008562724676825, 0.03405798617149553, 0.07386875639279043, 0.0537164458223889, 0.02102774605455418, 0.05435359348813373, 0.06404566293161723, 0.055998905201352416, 0.048531524446462436, 0.02610556450822661, 0.020462064816045667, 0.03628497695430152, 0.07978531471904247, 0.02638965480840735, 0.018994889612640106, 0.04708769385732951, 0.028702960717642022, 0.11166993243199204, 0.04547875982919528, 0.03742511496849118, 0.0694789270299577, 0.04378727216634058, 0.047121570265341195, 0.01692655180851298, 0.0740207175934507, 0.0038040253885781336, 0.018855720165095503, 0.022507831754703677, 0.031715758527899464, 0.0183494413842357, 0.06599596190837122, 0.07362526300693713, 0.040310891570463296, 0.04223433916547126, 0.031950989655489405, 0.057007517410261985, 0.10269005662731587, 4.368513793714585, 24.212979347475116, 39.17237750945553, 40.13380927424277, 22.096678249297604, 17.0776722123546, 23.79329162259256, 11.31057506607425, 4.99609302128515, 1.8162988606960544, 0.2603037757498603, 0.3724664635956288, 0.25573280489733147, 0.6988778662297034, 2.3911744260018875, 4.722028192012541, 3.938997099476476, 3.796125991690544, 7.313032669405784, 7.224129207672612, 8.871148132508802, 3.0930837940785194, 2.394932056626966, 3.997422519230074, 1.2167503612656747, 0.5164939044944702, 2.7606840047144123, 4.079767532886998, 9.589065428703062, 20.49148551879391, 27.177173322246922, 38.307345836393296, 39.94870870344101, 47.110917414388354, 55.97963956094558, 58.55345572194746, 57.65272655794698, 55.294989847367816, 56.888150707367934, 55.85108387854792, 57.439447679827296, 57.517483234405525, 56.8473502128355, 54.57624296988211, 47.3338217889109, 47.5500306775493, 49.87438017322172, 54.835578318565126, 54.32892968577724, 56.13117248781266, 39.54037035665205, 45.18024836817096, 57.30581645042666, 54.80994955185921, 52.51331944619456, 48.6156915849255, 49.53271427462178, 51.70225566433322, 54.67095252006285, 55.19977038906467, 55.68643454582461, 50.56024189918272, 55.20606971556141, 55.048272763529134, 55.38869134841427, 53.78801914953417, 52.60842515576271, 52.25921261695124, 52.832925934945386, 51.041697148353826, 53.01133886460335, 49.48871312602874, 39.715806207349225, 23.2434537718373, 13.335784019962436, 8.26622941801625, 5.4123187641943655, 1.5312847350874257, 1.6231944484095422, 7.146478535667543, 7.258632827189661, 8.676404414638396, 3.1561297658951055, 3.388750586778887, 7.80705274112763, 6.357343254550812, 4.971442395640958, 3.1261368720762195, 2.3801866414085513, 2.2455973730933283, 0.15036091959524542, 0.19044162855753977, 1.6226003319025042, 3.4839131707145325, 15.385752935563366, 33.155634249410326, 25.002189643921394, 27.38049134131401, 24.986782573884536, 22.27263773641279, 20.912593141678844, 8.507919984479106, 1.1459629790436838, 0.09877923906089799, 0.027582166423540444, 0.07329740035798281, 0.010247494679905716, 0.007762987271792466, 0.0108733952173122, 0.042359736267357104, 0.07186440225209921, 0.04828693938531703, 0.05795140285044909, 0.026864581440965977, 0.020411541317439368, 0.021702276895784085, 0.04079433901595973, 0.03773264947437471, 0.03548903841405146, 0.04701738996851829, 0.009025611253755709, 0.07078701449978737, 0.041526872289156726, 0.07563391490088356, 0.03656739526758752, 0.03914954441208993, 0.0027952412886905575, 0.016596172560727405, 0.05129186564215249, 0.04114646366947601, 0.04837186789260276, 0.046335284432937066, 0.038684969542608146, 0.032556109100339875, 0.019615537659715743, 0.03984141373826612, 0.023039065849696918, 0.06320812198663912, 0.09033794604962872, 0.03131528606548185, 0.04882707733721022, 0.037833137227402586, 0.03229588818465991, 0.03222947602250403, 0.03886542538361203, 0.03965721938819174, 0.05228203811472463, 0.04619135566416287, 0.020134780563474185, 0.01596070454275656, 0.030324650109715523, 0.08009910433282776, 0.05045001162216068, 0.0853371768889408, 0.03190536528915888, 0.03431253420609621, 0.04460496377320059, 0.07380314862295505, 0.021087140851323644, 0.04690975461515689, 0.10544167591198798, 0.043695433545977845, 0.022346284878890843, 0.02243214992866401, 0.0338183538687806, 0.06644493539727504, 0.030477377398300077, 0.04653306918278818, 0.05793527669964298, 0.05360081634153763, 0.024339446475008325, 0.06372967847592889, 0.034915679059321844, 0.018962168082174276, 0.012096865403075373, 0.25809146704212316, 6.639636235852396, 29.200814308658725, 45.69642051573723, 43.74319391865885, 25.843632182767315, 20.331233163033765, 28.128834462934925, 13.660264053652364, 5.117998815351918, 1.6979377860984497, 0.07352888914606265, 0.16079071638805253, 0.11355826255655098, 0.5047540667076265, 1.3456253491101728, 1.5609569751447248, 5.025276435959724, 7.0846139327172315, 7.093076936660275, 8.620594970641598, 6.872277404031446, 6.638515418575657, 4.622990796642919, 4.540449419329244, 3.0350037880482215, 2.155891541511782, 4.611746832247704, 6.782481603084072, 12.824706050657458, 24.42451277086812, 31.845737157329438, 41.993883502098825, 41.674794766210745, 53.578839148244555, 56.49834555964316, 57.60503053665162, 56.87477542508034, 55.0876376705785, 56.13299638994279, 56.1682035846095, 57.843396894393436, 58.95686757179999, 58.79819593121929, 56.167662297525716, 52.42938464687717, 50.594390053902906, 52.56466719412035, 56.19950017621441, 57.479404864772675, 57.45512931577621, 42.41420861213438, 48.69648848810504, 58.03836222617858, 58.06805849075318, 53.61620756887621, 50.14234473628383, 51.24652331875217, 52.13514020366054, 55.38611827358123, 55.36234086559665, 54.36986354089553, 52.3427551792514, 56.390213658732755, 55.32292104536488, 55.907283598376864, 54.942105970075055, 53.594332510425204, 54.05441868689753, 53.051354885101325, 53.18352307042768, 53.36281461100425, 52.37581683743385, 43.44791004734655, 27.704763489384806, 16.56631673535993, 13.012364006811573, 7.134117186069489, 2.5436984867818895, 1.9601126856380895, 8.597979564820568, 13.492111063772633, 5.1078511534198645, 7.815778053575947, 9.47802116793971, 8.2937301358869, 5.864126778418019, 6.27271076363902, 3.6969885758815275, 1.6258269716655056, 0.25539463836579557, 0.15139279406397574, 0.0676474482902596, 2.4745868146419525, 5.434099685761237, 10.46331859404041, 25.723660607491773, 22.88058550127091, 27.364252728800622, 30.23874798128682, 28.579612854988348, 24.748469168140044, 10.190996277716852, 1.4306975132034672, 0.09302764244738126, 0.10140419336816958, 0.04447724542490417, 0.028146654480106892, 0.014013123262913959, 0.04866460924066844, 0.0224075929802512, 0.04277786705642939, 0.05447639738239589, 0.04057926749209723, 0.060523075742586974, 0.05047361862154738, 0.026287307376943292, 0.0639534680803697, 0.05556745597371652, 0.05109429156648056, 0.04593968045927825, 0.03258820818436723, 0.0874394064228381, 0.028547042672852838, 0.04251187749867959, 0.01640348612601238, 0.04228785423742187, 0.01126789027870062, 0.05760975444929735, 0.03482794667023324, 0.027260790624084975, 0.036293499682459145, 0.029236933576964566, 0.06827065315578254, 0.00140043206732615, 0.006862168900683643, 0.056869012543991695, 0.10659104528566522, 0.13760161796404471, 0.20386128265771175, 0.16196347442605805, 0.09954106753631946, 0.16609651877755122, 0.17099830171754285, 0.1560050876991403, 0.1433819352138427, 0.14890473966877307, 0.15307984224730922, 0.14986935161775158, 0.13127792987131304, 0.11309910775913347, 0.14064013717635987, 0.20622782018636504, 0.19768508181216257, 0.1627517329348672, 0.08839227424393739, 0.16004143643283075, 0.14048483583234972, 0.1310881392489518, 0.17564030424241098, 0.10098859066924742, 0.15016133836921186, 0.10430123146262862, 0.10289038861951522, 0.17256328145102148, 0.13111168879174417, 0.18215913025121536, 0.10225693349756541, 0.13112417602490994, 0.12768889221573068, 0.13233027420938015, 0.14479959623948221, 0.1550674880103719, 0.2413720117821809, 0.12718928797591117, 0.1335552947655801, 0.358239536684367, 6.954688362536892, 36.34991445849019, 54.681935156545336, 54.55690568493259, 32.071832379987164, 25.046718351302612, 35.56684463254867, 18.250213784556237, 7.697003781795503, 2.898817624776594, 0.4707617342712418, 0.6945879577148346, 1.4113354682922366, 2.4761287964159444, 6.445640219796089, 11.945545019642001, 14.262428283691408, 11.429670972208823, 16.585328463585146, 15.044656761230963, 17.46131335535357, 9.123453613250486, 6.0061371710992635, 6.774893777985727, 3.477264508124321, 1.5687368738074459, 3.8801907195198924, 5.027133187940044, 11.636660329757198, 23.64538492694978, 31.75100603411275, 41.08521153849941, 43.193967957650464, 54.309078570335146, 62.02933465280841, 58.97133719536566, 57.28962490635534, 56.011579421258745, 56.73570779062087, 55.069304512393096, 58.77208079061201, 60.28542926234584, 62.133257850523925, 59.689785972718276, 54.920336815618704, 53.1816364103748, 53.74082911399103, 59.19283736136652, 60.31558836660078, 56.587567713952836, 46.75653911405995, 49.967430560819565, 60.821311320028, 59.9118431152836, 56.0804013283022, 52.01482149862474, 54.130547969572014, 55.24177112886983, 56.724187789424775, 57.49540029033538, 56.11223528462072, 52.37320061652891, 56.63340060941635, 56.54335083500032, 57.571219705766254, 57.18482309772123, 55.39690086918493, 55.8482950733554, 56.65826059156849, 54.58758646442045, 55.75321289800829, 52.13253574986612, 42.976248956495716, 26.97626363846564, 17.505812644958496, 14.06076648542958, 7.498313178939204, 2.4753141691607814, 3.503255603774902, 13.696587162633097, 13.491760992234754, 12.19453609758808, 11.866378841861604, 13.616294284020702, 15.610887177528875, 16.39618000676555, 13.163637076654743, 11.519485404414516, 7.312514426246767, 4.835065507119702, 0.6374126095925609, 0.47084189771163854, 2.5573841266093718, 5.8570135601105235, 19.931739760983376, 40.22671453414425, 34.9023441345461, 39.40564478597334, 39.78013307817521, 36.06054159902757, 28.26856301676843, 11.823654424759651, 2.0365482809082156, 0.26081809653870525, 0.3531399958076016, 0.18885755791298806, 0.0650390797865487, 0.10642678071294101, 0.1584236885631277, 0.47969827248204144, 0.1433703519644276, 0.11468061967001808, 0.14830516861571422, 0.14634850344830944, 0.18485543798775445, 0.15132786045151372, 0.11631353608062191, 0.11841429472570458, 0.23901241501012158, 0.10342536313879876, 0.14326394235174503, 0.2683350738258131, 0.10936489644189996, 0.16679788759398848, 0.12597406568426278, 0.16233329571062521, 0.07469292910348985, 0.1941595758281408, 0.08769056068793421, 0.10098866727803985, 0.15465965344300195, 0.13569165351650408, 0.22929393085500888, 0.11460695265521927, 0.1080681547342289, 0.19047296155364285], [0.014952013809834758, 0.003248628162245657, 0.050849331122252255, 0.03467648725716337, 0.030407611686255664, 0.058743407529207974, 0.02215308325004674, 0.019017799472015713, 0.050008744977775126, 0.044765937998290026, 0.016953075687671383, 0.07659522501090843, 0.06435163078769561, 0.07206370002560078, 0.031273193364482255, 0.05546782623916384, 0.055508697029924205, 0.05839380330496258, 0.04567200933853465, 0.032205095274313804, 0.040715209794260805, 0.06090852522080945, 0.03874617996775816, 0.007516137942025859, 0.04087979612391322, 0.05390280437084937, 0.02157520780700349, 0.07930231160454213, 0.032610876726046685, 0.10668066225104755, 0.05212295229636854, 0.06659744818124079, 0.04362073231248125, 0.04903436540776203, 0.05443570279185811, 0.02545545463480296, 0.02074712613267043, 0.08511312681460574, 0.022373706996140462, 0.024999513576227813, 1.049255839278621, 14.679514496557175, 32.79923004488791, 45.186688899993904, 32.46657775294396, 22.91431788475283, 19.310040166301114, 24.786912318198915, 16.852555621054865, 8.83768835375386, 2.058065668229134, 0.0819073246431447, 0.10858791474733623, 0.7546700885699642, 0.8765890593490294, 0.6653112641745998, 2.832183909993018, 6.358611651005284, 4.8026186804617605, 6.910781350827987, 6.837757604737436, 4.951901637738751, 4.0677177665695075, 3.1003651840071527, 2.854426935795815, 1.978265537369636, 1.1221396057836472, 1.0909462215438968, 3.465998725545022, 7.837464347962411, 15.99700039432895, 21.927161255190452, 32.275940756643976, 38.887079992601954, 43.68036931560886, 53.641181299763346, 60.05650404960879, 61.13135114792855, 56.19685257634809, 57.452873952927135, 57.37055909249091, 59.001178587636645, 55.812224957250784, 53.797507362981, 49.09280084794568, 51.43961375759494, 53.35131422165902, 56.544566769753736, 54.01636385148572, 57.703642845153816, 38.03665130369125, 44.764163340291674, 55.53060270124867, 55.76822773102791, 55.112917346339074, 52.1280328689083, 53.91214255363711, 54.767066278765284, 55.13763612316501, 55.3418190248551, 52.90811777114869, 55.11005793848346, 55.58433525023922, 55.33550400887766, 54.17020313201412, 53.85429543833579, 55.823454703054125, 54.634172454957046, 53.14362472103488, 55.26375209131549, 51.67042170801471, 40.47427492756998, 25.869692410192183, 10.439327416881438, 4.685167718318201, 4.026018068675072, 2.069841358930834, 0.6929652609171406, 1.4226909750892272, 10.821361368702306, 17.43850281161647, 4.238501441094184, 6.810809941061082, 8.823907106153428, 5.789975350902927, 6.6599688222331395, 5.556841925267251, 2.120281078161732, 1.8051234152047866, 0.27425114185579363, 0.40450818295921054, 1.3909616970246839, 4.062796662892065, 21.39427588831994, 47.29693189744027, 34.59157866816367, 39.15326772197601, 38.313374519348145, 30.092992705683557, 24.329420789595574, 12.1306053861495, 3.0970309242125484, 0.19391038274813086, 0.044526696400416475, 0.0814958511581344, 0.046057010655321425, 0.03478857358136485, 0.008991260828840877, 0.01297609493767302, 0.02742422590663116, 0.10506148945780532, 0.04664443921478045, 0.05421602707957068, 0.06539288217261915, 0.10789302703473838, 0.047195543715309714, 0.03242669003685156, 0.056993126448604374, 0.008267193784817092, 0.0871420264123909, 0.08651049417113105, 0.05573981809580038, 0.041238658520723545, 0.05735891044981057, 0.033616118148089416, 0.038732647024575746, 0.050552901060831164, 0.040376755979753313, 0.024810586718001196, 0.09911709149638492, 0.020513741276978005, 0.044057915708230394, 0.023129381870310155, 0.028004102754376592, 0.05552135663287294, 0.06566436075034641, 0.07585062585290402, 0.093985635396694, 0.02548697723766729, 0.019004710859829382, 0.03760699573303423, 0.03129124622641793, 0.04129430714754328, 0.06912861034394273, 0.07328842180751025, 0.028586229985399593, 0.03320390921867183, 0.0662375170917761, 0.050876259112790714, 0.05049097817391158, 0.021141176863062768, 0.0385087080329897, 0.030282641678387602, 0.08318053212978187, 0.04953177097523886, 0.026792272317012953, 0.039711626952574144, 0.057636602000603755, 0.08312076194992951, 0.021259211859996283, 0.07298126651514923, 0.05072636634952599, 0.03390365392870961, 0.13852122990835097, 0.05758773708235353, 0.059033996170206424, 0.01842742147404821, 0.015211934993614354, 0.04488088183044907, 0.008053495473558865, 0.08620590527331637, 0.012328400156430662, 0.06680590070543752, 0.06518351800379253, 0.10333733197541968, 0.024792558753923066, 1.5054151103381188, 17.585062173105058, 38.03185424497051, 48.82480882829236, 33.89996674753005, 21.033543348312378, 22.51314178589852, 28.72737834530492, 18.63613578581041, 7.919041312509968, 2.033177248893246, 0.21156918437730884, 0.0784967854739197, 0.0691132502810609, 0.508199991478074, 1.2103138743869721, 1.8636973947286608, 6.2138021569098205, 7.457097403464779, 6.121277857211329, 8.544464707374573, 8.102409666584384, 7.384022176265717, 5.791947812803331, 6.904402596335258, 4.049252963835194, 3.248167201395958, 2.9614169366898078, 4.822607569156155, 10.67324580684785, 17.24344334294719, 24.953230619430546, 35.492586320446385, 43.12934690906156, 48.93996177181121, 57.156982114238126, 59.90040548386113, 59.8632174922574, 55.59103858086371, 59.01432637245425, 59.11853198082217, 60.32269177898284, 57.325102744563935, 56.35899943690146, 51.57266839858025, 53.219279396918516, 55.037784345688365, 57.96314685575424, 56.1684153925988, 58.54286140011203, 41.957962436060754, 49.50705412895449, 57.87947877760857, 56.96394266620759, 56.350381989632886, 55.13542390638783, 54.66044841274139, 55.520714406044256, 57.52712442028908, 55.96471886481009, 54.027930921123875, 54.085479936292096, 56.5615741668209, 54.7269678884937, 54.30923154277187, 55.34423128251107, 56.646991622063425, 56.18609351496543, 54.75232993402789, 56.142237494068766, 53.647908164608864, 44.95259792573991, 28.223628344074374, 15.503542692430559, 7.634315481109004, 6.5045297049706985, 5.645291372652977, 2.3854632098828596, 2.4542287328550896, 6.753408014774323, 20.85119235900141, 8.568872636364354, 6.644715705225545, 7.920858840788565, 6.807276866128368, 5.770114919831676, 4.835476865691524, 2.7117700874805455, 0.700590409819157, 0.1933615880026933, 0.14405632241358682, 1.4359337548094413, 5.2076107551974635, 12.518913169060985, 42.34161338498516, 42.03757086107808, 43.878747109443914, 44.05031158078102, 35.65809465223743, 28.41326121361025, 15.995233366566321, 4.806777373436959, 0.31711241290453945, 0.07028525755290063, 0.06989170286443926, 0.06995685864239931, 0.01651623703148817, 0.0392408506013453, 0.042263990598580534, 0.07144585777554782, 0.006356367967166608, 0.039136045942864114, 0.012760377027124408, 0.08181343290714488, 0.05636963813054947, 0.12936557522944866, 0.05285266253556456, 0.032643423971509745, 0.007773446287178705, 0.07406305927302569, 0.02694983936605915, 0.029795197169146234, 0.060218892871372165, 0.038181485067452156, 0.004021986979134982, 0.04577320572289248, 0.03166451107620472, 0.05368528902650841, 0.07357500763910432, 0.04203395737755684, 0.05059603181096816, 0.020429820175312703, 0.02259430967481627, 0.04740364000862164, 0.019245867677513632, 0.04715438947201737, 0.16408872490207996, 0.18903961104731407, 0.15127506167177232, 0.09634021429284927, 0.10713884411680122, 0.11609163105247483, 0.1648779486816737, 0.17086817402272456, 0.1882306221992739, 0.14676013781178385, 0.11086650538228213, 0.17589925728257627, 0.14522924899093567, 0.16787315328275004, 0.14038055594409668, 0.15090570003995973, 0.11803888866016943, 0.21569901115952, 0.15830394902056263, 0.14199965212854648, 0.28597293061114126, 0.1670132349095037, 0.16894978260801685, 0.24842542926630667, 0.17025706568552604, 0.14328307922809355, 0.11389459047706858, 0.17375266359698388, 0.12355308994771012, 0.3168960696747226, 0.14330319669698516, 0.19407021933265273, 0.10236282217045946, 0.10282301118657475, 0.23089880844758404, 0.21715571202578085, 0.13617796613083732, 0.1948244635376238, 0.1833637115815955, 0.08414329780686287, 1.8278837035740576, 21.245831827963553, 46.02788040714879, 56.85759152135542, 43.811176438485425, 32.47872533336763, 30.00660054145321, 36.52702123888078, 24.12131747891826, 11.096075350238431, 2.5089038764276816, 0.3803782825989108, 0.4340813525261418, 1.8582081602465723, 3.139843349495242, 4.567887869573409, 9.053570705075419, 18.19801684348814, 15.265418541046882, 18.579941949536725, 17.690275830607263, 13.695945855109924, 10.50432893537706, 10.147731554123665, 8.052584288581725, 5.168691037162658, 3.1423056173709134, 2.284979440512196, 4.983715982206407, 9.289969013583276, 18.85865576805607, 25.74826171321254, 33.96004176908924, 43.70612752053046, 49.39672962311776, 58.17370753134451, 61.804386723426084, 61.57619107154108, 55.93501475549514, 58.3044126725966, 59.674276921056936, 62.24210754517586, 60.524078030740064, 59.19189599252517, 54.82296397609096, 56.288090828926336, 58.94408064503824, 60.149272026554236, 58.73577925466723, 58.926410367411954, 46.14220180819112, 52.333596444899044, 59.28999839290496, 59.8892306512402, 58.92131520855812, 57.6735229646006, 57.95029324869956, 59.87092887201617, 58.90295851615168, 56.45437971238167, 53.58973549258325, 54.77632307237195, 54.73441646945093, 54.8004731055229, 54.88735752720987, 56.1945423003166, 58.255159470342825, 58.80420500232328, 56.938965012950284, 60.20039227701003, 54.7912359237671, 44.68098163604737, 29.161604335231168, 13.998933261440648, 6.804819991511684, 6.8559691694475, 4.558385437534702, 2.7034924155281437, 4.468164549719903, 19.037978687594016, 30.037687286253902, 10.34771457795174, 16.553518041487663, 16.17301675581163, 11.587343388988126, 14.086516845610834, 12.645480209781278, 6.786064197940211, 3.3057196486380795, 1.0136727099457095, 0.891249469451366, 1.9792147509513365, 5.951731935624154, 24.76859288830911, 52.20262066010506, 42.68892357426305, 47.92953568120157, 49.95088600343274, 42.453667656067886, 34.73001480102539, 16.33560586360193, 5.162452017107318, 0.5568248177728345, 0.13054527402404817, 0.13927786430764583, 0.21443090581845856, 0.136946520858234, 0.14451130203181697, 0.1253101509064436, 0.12915555988588642, 0.14011852323047577, 0.10112779650596843, 0.20477824393780003, 0.1704337255608651, 0.26152580856315555, 0.257787146275082, 0.11385161294451646, 0.11953434591451961, 0.1411679870779476, 0.1521841322462405, 0.10287029413326133, 0.10220742123501916, 0.11991640928411677, 0.21362021625522645, 0.07662409120389531, 0.1989341728509434, 0.11563960853363238, 0.10815245504941672, 0.1794452331359348, 0.10081093487960678, 0.14562899366982524, 0.09005977186344324, 0.0781645408020385, 0.24457645031713673, 0.11800721858537967, 0.1334196665594655], [0.02692503918473038, 0.03936863023667567, 0.04856032552197576, 0.029695640212946364, 0.01730356282824951, 0.043637639872970126, 0.010656926540597793, 0.10239572564680731, 0.03784004351003997, 0.08027760281918511, 0.019535221001734177, 0.019539062932674444, 0.05555100423554259, 0.04022499396195335, 0.05753610275625702, 0.013673568197015314, 0.023126189198885715, 0.05600833574370031, 0.03746825337950741, 0.02515571507354898, 0.019287862702302875, 0.05179155032120405, 0.04168315039527032, 0.020525381982987447, 0.017028638770082788, 0.007135166726525754, 0.027939931399399237, 0.019047851186065425, 0.03970130391779446, 0.09536092409924155, 0.03376871520172685, 0.0633662233820125, 0.10228485740240544, 0.061780651205129204, 0.013583690761738728, 0.03191744649572478, 0.042201336097693255, 0.03101655582506811, 0.02458769918209122, 0.10340130797797635, 0.14338786473437665, 2.735403838657564, 20.871557304936072, 43.12455377271099, 46.16302174906577, 31.042620097437215, 23.14235075827568, 20.309822905448176, 14.613530424333389, 15.733313175939745, 7.414005754455444, 1.8936318207171656, 0.49157248209080395, 0.015287669488198817, 0.25107180339194113, 0.2951916956132458, 1.3129135173174644, 4.94110482354318, 4.4942179129969695, 3.59543816697213, 3.836336659808313, 6.524460738705051, 7.137143784953702, 4.392641273237044, 4.679937237693418, 3.5372294581705526, 2.477629593303127, 1.98873593682243, 1.1344677378093044, 2.7360605905132913, 4.421944320201874, 11.658409872362691, 16.177718697055695, 26.754902716605898, 35.614921123750754, 42.76656296945388, 48.399031623717285, 58.53086679212509, 60.48925130598007, 59.934945875598544, 57.31885833124961, 58.75023711112238, 55.1573185766897, 55.06293458323325, 51.78943818615329, 53.944706070807676, 53.76404562304097, 58.513027852581395, 56.092372402068115, 55.10060894873835, 43.03944618471208, 45.74270056140038, 55.26698804670765, 56.285949214812256, 53.90008518772741, 54.77860981418241, 54.270815849304206, 55.9000664372598, 57.13723690279069, 56.53671418466876, 53.02938568976618, 55.04241666486187, 53.33243977638983, 53.48544359207154, 54.52880582501812, 53.67580798364455, 56.01576459023261, 56.93483475715884, 54.95996059909944, 51.70409133357387, 40.03919778331634, 23.804754749421154, 11.36133740025182, 4.3333845561550515, 2.51270440797652, 2.6619064663687064, 4.108714134462418, 1.8589467915796467, 2.0798632598692373, 3.5831079511873187, 17.474998504884784, 6.112359858328297, 5.321475690410984, 7.5770214200019845, 4.568118308821033, 1.6384202313999978, 3.3839086659492987, 1.5475143996938583, 0.1688562585942207, 0.1909744580306353, 1.0367979013150739, 2.1324683725833893, 21.036373338391705, 24.62717575411643, 11.468812304158366, 19.567806566915205, 24.876601234559093, 29.52040706911395, 24.601686231551636, 15.309339281051392, 5.618100522025939, 0.9993689903809179, 0.08208588441653598, 0.07044326318728347, 0.04579574019918519, 0.030585181291004827, 0.05761847636031528, 0.0847534561950353, 0.07787178796265395, 0.002983781511917891, 0.029741892771374796, 0.08638002173674685, 0.04665383145273213, 0.022941920155238722, 0.04867860183660542, 0.05329106018067368, 0.06323578925202451, 0.015871109602402057, 0.13210394119303073, 0.06974862828370064, 0.0867280248372305, 0.09537538783925195, 0.0765692163258791, 0.07083229029611235, 0.05067202007217754, 0.015417033010312628, 0.04251101181932515, 0.042113822043663075, 0.0864761044842101, 0.026648703609563174, 0.04093023535284785, 0.034579289851770285, 0.020365922696768277, 0.03472067903907549, 0.029277689454536286, 0.014027545825698444, 0.04697907025054578, 0.05030384204620796, 0.04324575908662331, 0.032208918053055965, 0.02023242038464354, 0.07018211913565475, 0.056969936967136404, 0.0962139017158939, 0.018637298921784087, 0.05583022796218434, 0.008446657541959036, 0.047050144057720907, 0.10887433203958696, 0.03411697494166513, 0.021666410574389082, 0.08283829001048881, 0.04012742500391699, 0.07118168767661819, 0.0029674118887933515, 0.043406346437310984, 0.04979402968479742, 0.053147920482461496, 0.04056231013589329, 0.05867709495848226, 0.06640951915253555, 0.04346222106006838, 0.041681775267446236, 0.04821386608865954, 0.05076952391274033, 0.06543958289248329, 0.03278807669337238, 0.03727274774123104, 0.030289007869038372, 0.07861481664041359, 0.026619082819970868, 0.018438449309718226, 0.08398146173285861, 0.05697428451610669, 0.014083813068517035, 0.09729515055134412, 0.17923078980417023, 3.6354661997287505, 25.99224098267094, 50.438342478967485, 50.923229802039366, 30.63953772667916, 22.002586472419, 26.175998141688687, 26.095130635846047, 21.35926873453202, 6.762124011593481, 1.3710074967915014, 0.35053364211513155, 0.07151462182763123, 0.09101391139049685, 0.5091034236454195, 0.9094221168948758, 2.9323048601227426, 5.060619442693649, 4.963840351950738, 7.551508853512426, 8.518839863038833, 6.6044123711124545, 6.93308198644269, 5.940228604501294, 5.01469535212363, 4.708644084392056, 4.3175308262148215, 3.3068546845066935, 5.640035396622074, 6.8891048623669535, 14.591302352566874, 20.51519624648556, 29.309405126879295, 37.83823820852464, 45.75161610880206, 52.623051674135276, 58.92042875289918, 60.87214523746122, 58.47218421197707, 61.18278126562796, 61.638278268998675, 57.92200119264665, 56.635149986513206, 54.151211015639774, 57.383914762927645, 56.364200499749955, 59.24848402700117, 58.95623999257242, 56.71057324255667, 44.8219947661123, 49.15982238708004, 57.891340025009654, 57.00304085208524, 54.910585803370324, 55.914469380532545, 55.46153368488435, 56.748129936956595, 58.584658176668235, 56.559918926608184, 54.09262649474606, 53.8703889231528, 53.33317325961206, 54.431864446209325, 53.3121415107481, 53.77684823928341, 56.881447376743445, 58.020739016994355, 55.37890503483435, 55.289431848833644, 44.23984050750733, 28.32528441183029, 14.581582719279876, 8.143253307188711, 5.200817700355284, 4.42784748731121, 5.63830170900591, 2.6895496153062393, 3.5801632317804524, 6.1904223792014585, 18.971696515237134, 11.156188614906805, 5.438474599392184, 8.669693239273565, 4.7118398354899504, 5.017339029619771, 3.3181332147890523, 1.0420204146254448, 0.3713799670578972, 0.11078879342324312, 1.3738767105725505, 2.6174265434665065, 13.840148852717492, 29.33218821402519, 25.63964539958585, 25.208614180164954, 30.948734244992657, 35.94237627521638, 30.457196543293616, 21.411642182257868, 8.222471946670163, 1.2008648846418628, 0.08239673991357127, 0.05624116901608725, 0.06148204545400316, 0.028054365783088633, 0.042429251085606315, 0.014227781099297348, 0.043147826236822916, 0.0512309271782156, 0.017684419609365926, 0.018534426720091896, 0.03519886346053212, 0.023507105351816264, 0.07020499452107376, 0.04954715402075841, 0.03408450047455488, 0.07400499746924447, 0.06656791549175978, 0.07836752345845585, 0.10036913197367422, 0.03708404113328265, 0.051249121766417265, 0.015567643981006359, 0.11708006067501923, 0.02489085549548749, 0.031417865238543, 0.08634203143658177, 0.020342321443041007, 0.05056372588320125, 0.04841275017468199, 0.036418008122352824, 0.06032110815266929, 0.05766335379091963, 0.01942271907483378, 0.04639331942364093, 0.14972310543300646, 0.18000844565610732, 0.19268226719671683, 0.1075220029921301, 0.13004910951900867, 0.12476217587508502, 0.1522739943597586, 0.17788365483284, 0.10545262330842596, 0.1398807295387791, 0.1285228861736194, 0.0998727453031367, 0.1908799534242961, 0.10729413013905288, 0.1564325494391303, 0.20351432143680512, 0.19941832509733018, 0.14290169001586978, 0.10786012355839053, 0.1200590012294631, 0.15782198778563933, 0.10346663229527975, 0.14947815648009702, 0.09281833190470935, 0.1038793161992104, 0.22338002319297484, 0.10955248839191853, 0.2216173468097564, 0.08571180920567244, 0.11722793096616385, 0.1491653627806133, 0.1261542035987781, 0.2225886696889516, 0.22169672884047034, 0.079768797863395, 0.13700344119100802, 0.2005654038681138, 0.1122233620093715, 0.1281284658058036, 0.20305974018429557, 0.24486535739514137, 4.696361182197448, 30.972731305706887, 56.413528227037006, 61.5128840169599, 41.380256145231186, 32.53959855725689, 32.24620919073782, 23.64039763327568, 22.18693590933277, 9.899814225012257, 2.5607061289971877, 0.8341741417684864, 0.3123564164965384, 0.8968397049653916, 2.4561433397954513, 5.945406133128751, 12.16502614559666, 11.786236974500842, 12.702688959337051, 14.94002361451426, 15.54045415693714, 14.555696056735131, 11.590336157429604, 11.656548707715928, 8.916474061627543, 7.242875685614925, 5.350500739389851, 2.345857322216034, 4.421121112761959, 5.973351549717688, 13.890057090790043, 19.93472076231434, 29.251911024893488, 37.41921140301613, 46.09497254894626, 52.87191429445821, 61.41886480392949, 60.94987876953618, 60.661188402483546, 61.397691849739324, 62.12184375332248, 59.139277396663545, 59.78678618707965, 56.441643776432166, 59.750578788019, 59.324958478250814, 62.94687117299726, 60.60893066467778, 56.245713541584635, 49.24507118040516, 52.428427588555124, 58.80816659619732, 58.709511141623224, 57.42021629887243, 59.21396716948479, 57.317524725391024, 59.304687669200284, 58.841475363700624, 58.5882902914478, 55.670556791367076, 55.67328283863684, 53.45621801191761, 54.33615469163465, 54.56338544045725, 54.70404947957685, 57.73010707670643, 59.128079029821585, 55.83840285578082, 56.08671634427963, 43.854055789209184, 27.38503540715864, 13.690370205909977, 8.08902261718627, 6.186592184728192, 4.220744871324109, 7.119824069161569, 5.040575640816843, 5.727148786667855, 9.384483425847947, 28.392890384120328, 13.650543439772822, 11.91600957224446, 17.533957612129953, 13.410569890852898, 8.400295049913469, 8.707210709971767, 4.775606297677563, 1.1447166459214304, 0.3926090908146674, 1.5707135032261572, 3.8738416279515917, 23.559692905795192, 30.580784543868038, 22.857478818585797, 30.836530923843387, 35.59439536063902, 42.17370848501883, 33.91471878174813, 22.679320842989032, 8.669595180019256, 1.4494020708145634, 0.2330034971237183, 0.11236331861225829, 0.15576962291473345, 0.18354686788253247, 0.12330850871700434, 0.13597263924537167, 0.16631025730842547, 0.12554973724388307, 0.07119550024189296, 0.1320894008442279, 0.1232439275049875, 0.19731169055786826, 0.21861031381112916, 0.13902658746848184, 0.11475961099589065, 0.25023302904540495, 0.26662311246318204, 0.17126827110205928, 0.3004477942182172, 0.19483912646049456, 0.1404480329684673, 0.15060629755739244, 0.15920158956320057, 0.10804074410829814, 0.17073107492779532, 0.15588832057772145, 0.24901775312760185, 0.10315585340703688, 0.15661020522877095, 0.19906532710358021, 0.15438275862365, 0.1835337371355103, 0.06349523641890095, 0.13245767463118802], [0.06952116911810252, 0.02667087036365223, 0.03355717151275566, 0.06988496895158483, 0.09238754534312794, 0.013603206851609774, 0.12415215538273897, 0.12195113115012647, 0.04068131040361139, 0.011274613657846086, 0.013384930207394065, 0.00494671686958041, 0.05058224605877073, 0.024009247257884954, 0.05787634538606771, 0.1013881974523106, 0.072311008529317, 0.03241719054659048, 0.0368223569896673, 0.009820566328632976, 0.025334606179967526, 0.03518246917895252, 0.023648331745437557, 0.04230338283964703, 0.045230819302941525, 0.012316264366100152, 0.06967935095270796, 0.11232889828182037, 0.03705073929121418, 0.07710246714733301, 0.03537448911717342, 0.02819486247796205, 0.005782754845812076, 0.022533399939176538, 0.07043508136825216, 0.013756630322595519, 0.054245429534104564, 0.05794953742635347, 0.039073663403189955, 0.019047282365781647, 0.010668563416167613, 0.4577923560094449, 5.880999834306779, 25.695715681199108, 42.05009891140846, 41.960060904102946, 29.903332379556474, 20.15064920148542, 16.819723421527495, 22.360367428871896, 23.063107113684378, 8.008170310528048, 2.2649341677465746, 0.2574067070118843, 0.24939852946948624, 0.5351025478974466, 0.22785915542514096, 1.3249877984485319, 4.81235743530335, 1.804067807332162, 6.113325251686958, 6.271579159844307, 5.961516288018996, 4.68096980164128, 6.904623719953722, 4.029315556249311, 3.727439651566167, 3.8201610503658174, 2.8496168842238765, 2.6357940223909195, 1.4345242756028331, 1.9875223309763017, 7.720970934437168, 10.817459590973394, 19.235003263719623, 33.010090781796364, 43.60525592680901, 49.278015167482444, 58.00119384642571, 61.937935583053104, 58.72290211339151, 59.13311143075267, 58.34909239122945, 56.12823071018342, 55.138267624762754, 55.8972893991778, 59.63777534423336, 60.284785993637584, 56.87112762082008, 52.704276115663596, 46.43605401439052, 49.326793762945364, 55.99193619143579, 58.49926033327657, 56.33575154889015, 55.794648816508634, 59.484391058644945, 59.278352875863355, 56.686497734438994, 54.07819609488211, 55.45042161018618, 57.96075420994913, 57.198700443390884, 56.80683212895548, 55.587265260757945, 54.8168372338818, 53.519721185007405, 54.35415052598523, 49.16869871077999, 39.24925204246275, 23.526792064789806, 12.239869871447164, 3.7500754046824674, 2.0308690566209058, 1.5005883886929483, 4.002997187837478, 4.687939853437485, 2.5303577703814355, 2.6137265226533337, 6.390635842277158, 18.47324759729447, 9.70010184472607, 2.715203141973865, 4.381788565266517, 4.063044507657328, 5.361920229850277, 2.8460406632192674, 0.7848242898621868, 0.28459574967142076, 0.4318232624040496, 3.8425384173470163, 15.149738038739851, 16.714052807900213, 5.964526216829977, 17.175372569791733, 31.254467310444003, 34.4784261334327, 28.649509491459018, 18.206649980237408, 7.034788064418301, 1.4143377975110085, 0.1819671486173907, 0.01790976820273265, 0.02511998090232092, 0.04180010137779098, 0.021508046793901635, 0.07395445098800045, 0.0520526445771177, 0.07075714473161968, 0.04745963720544692, 0.06987450419053917, 0.03160624242868395, 0.04946400666789663, 0.02790085708482131, 0.022564646750388127, 0.008972567325878528, 0.07386101124387595, 0.09470073250873436, 0.01867372065692419, 0.023387794818488822, 0.012468531044320235, 0.046164220829884854, 0.019287257492842696, 0.02516054717313138, 0.031013707893209595, 0.0280944494185068, 0.03153040163939999, 0.023403784988688368, 0.02989450131633109, 0.04302682264918282, 0.0793194183478913, 0.026044221932909666, 0.07286167252928981, 0.1147621620686785, 0.08821718484884308, 0.04633782401440605, 0.025849942035312136, 0.008875554739197176, 0.05900939708695777, 0.025764806684286847, 0.030423450554090164, 0.004539772400617479, 0.05448338793470495, 0.034799563112638654, 0.06971152664552774, 0.009065288862574005, 0.03547576977120292, 0.06955007361548562, 0.06121573413932516, 0.03355403438270573, 0.03582501010368428, 0.003101247209762674, 0.075874604404934, 0.02657787495052382, 0.01883795458613144, 0.0341182045127836, 0.0560397261963977, 0.05527979378858882, 0.04713001255426676, 0.04938282050012101, 0.042207821031972285, 0.019397631610533404, 0.04934380747257702, 0.014888077069284215, 0.005511272437645183, 0.05621527524424657, 0.025010307755080924, 0.04354451805533421, 0.06441655673927839, 0.04797270544053567, 0.019312586274839217, 0.010209829967108466, 0.02198276083706127, 0.030401607472149116, 0.02687529901102666, 0.018190215754833435, 0.07721400954910825, 0.625268338668731, 8.374680011503159, 31.09416396387162, 48.71579831646335, 44.448820467918154, 31.411387612742764, 19.676646455641716, 15.398696757132008, 28.792456350018902, 25.294351308576523, 9.786891148936364, 2.5752127699313627, 0.2684645733285335, 0.047659092026972966, 0.21869030871218254, 0.33385884978117486, 2.0427821528527046, 3.0068556339510026, 3.399184581733519, 5.445283834011325, 6.55283026156887, 9.121872898071043, 8.850135995495705, 9.60974024188134, 6.93972550092205, 5.771252407181648, 5.543448011721335, 3.8074682604882026, 5.01390254305255, 3.1406744016755015, 5.067163427029887, 13.32683022945158, 14.864788632239065, 23.00673677075294, 35.680887545308764, 46.3586695732609, 51.68298898204681, 59.31224999889251, 61.491805199653875, 58.945018091509425, 61.510663955442375, 61.113861299330196, 58.40789656485281, 58.102516512716974, 58.04364173643051, 60.407085495610396, 62.496951780011585, 58.24762459724181, 53.88658046722413, 50.194327908177534, 52.6837738867729, 57.17990052315497, 60.1982428181556, 59.040508193354455, 58.579323753233886, 59.881174102906265, 59.62734576194518, 58.36751968629899, 55.516901862236764, 55.716856448881096, 57.26426286082114, 56.9408046045611, 56.1641792328127, 56.258516157827074, 56.563786383598085, 53.98734615695093, 55.578545831864886, 51.78483724594117, 41.869587513708304, 27.978750851846513, 14.475542422263855, 7.12056000386515, 4.445164261325713, 4.7535503199023585, 4.8626711483924625, 6.363745543264574, 4.299137851884288, 4.549786621524442, 7.715281046205952, 16.624993431952692, 13.749938261124397, 6.523416407646672, 4.792876983842542, 4.416884952975858, 2.9665574479487637, 1.2417139185051764, 0.5711635935210413, 0.2835374145257858, 0.3463758378019256, 2.880340074339221, 9.76277151415425, 21.989336705976918, 12.830954386341958, 15.006832365066776, 33.966800012896144, 37.480906363456484, 33.81020330613659, 23.490921989563976, 9.037321306044056, 2.0909782763450377, 0.3271522096568539, 0.057529997035500505, 0.012615226348110986, 0.027066187054339438, 0.018412637892329407, 0.01579080539334926, 0.05378521753535156, 0.055934714694176955, 0.06780346209603934, 0.01138266557151632, 0.043308291013442704, 0.030732069074386553, 0.07277990796513135, 0.02056433180827768, 0.008134185599403517, 0.022830532886268153, 0.07323663426382888, 0.014464398846030237, 0.01384984311317244, 0.04094900450699272, 0.07472899652296498, 0.05313566690611263, 0.034598848076477166, 0.01866814162161562, 0.04298823480043681, 0.03255635807891527, 0.030301215480111783, 0.030280138486095017, 0.015410752046943433, 0.016235624770483664, 0.032140805175708186, 0.03159215407175643, 0.07940842244293421, 0.0816235120498365, 0.039762962504380175, 0.20678167111210286, 0.14733710927107643, 0.14710167513018654, 0.1393599889331287, 0.18230398215593832, 0.11355453936923897, 0.2091100727838855, 0.15191419350524105, 0.15429380049388255, 0.23163573906546642, 0.11120153095332846, 0.1619334897447017, 0.14313220587228576, 0.16931131482124331, 0.13870545873238196, 0.0985724029822215, 0.15787507767879194, 0.09244674861791635, 0.08563031277228748, 0.10099206870842366, 0.20713286113835153, 0.19269403430723375, 0.11899981572623215, 0.169241891933545, 0.08808753978941711, 0.16279599749513213, 0.12783925995350848, 0.23236398224628743, 0.10027627445637219, 0.18839625040850333, 0.18252804755203186, 0.1281028937908911, 0.13212649482152156, 0.22550974762247455, 0.1675978672480391, 0.11977161866642776, 0.12140391454581292, 0.16899374073311207, 0.07861249539400302, 0.07487959408712003, 0.1861537884800665, 0.737140832408782, 9.218482836600273, 37.0887085699266, 54.93657150576192, 53.27904847360427, 41.13564537417504, 31.028352475935417, 24.60921129872722, 32.54771590232849, 29.298138118559315, 10.618658181159727, 3.2222668105556123, 0.4797142683979004, 0.6259569597821082, 0.9333809344999252, 2.2144000664834054, 6.260156727606251, 9.87505034092934, 7.77288007159387, 13.67866095035307, 14.472147610879714, 16.209893899579203, 13.020072444792717, 15.685200402813575, 12.149824999993848, 8.708463907241821, 9.555835108603201, 6.2795719696629435, 5.360372854817299, 2.8800299619474723, 3.6217891400860207, 11.057947950978434, 13.13578530665367, 21.103698861214426, 35.298472142988636, 46.052050052150605, 51.88189629585513, 61.987428049887384, 64.85375104411956, 59.3805855320346, 63.467342238272394, 62.98049373011436, 59.81847109333162, 60.6780271376333, 61.13296716443954, 64.18829741016512, 63.052853615053245, 58.604732867210146, 54.45702252849456, 53.25312552913543, 55.04494659362301, 58.64762006267425, 60.326841646625155, 58.59019656335154, 59.773901201063595, 62.34148471586166, 59.96113946360927, 59.14809096244074, 55.095337283226755, 56.40311433422951, 58.463209829022816, 57.056024228372884, 57.332555247891335, 56.59000742820002, 56.821258606449256, 54.40572184901084, 56.52598650224748, 52.634195127794825, 43.087424616659845, 27.44712260461623, 13.528124305509753, 6.824068532836053, 5.052619768727211, 4.990251631506029, 7.632630823119995, 10.369602384105807, 5.672131661445865, 7.742279700694546, 14.762761900501868, 31.50858198442767, 17.681646616228168, 11.494661704186472, 13.05340474651706, 13.23406127191359, 12.446766072703946, 5.896182838947543, 3.270992454021208, 0.9278125784570171, 0.8440123041791301, 5.193398537174349, 17.42782415882234, 22.28189649120454, 13.43598783016205, 24.457705828451342, 42.1518648055292, 45.40755756439702, 39.817262234226355, 25.21622750066942, 10.437731012221306, 2.434561723662961, 0.33052232236631457, 0.1687888581786425, 0.15603858106318982, 0.11721691462181269, 0.18755073448823345, 0.08874373240095955, 0.12628273016983463, 0.17196662153207487, 0.1263140631659377, 0.15781705417940695, 0.16729553830960106, 0.16015959783427178, 0.16366733057845026, 0.14528957075409352, 0.15807792243938293, 0.12032769890802524, 0.1566349651904837, 0.1199030640324758, 0.11919634792232707, 0.13336130598139379, 0.3060632187031931, 0.16918491031373703, 0.12022934087942685, 0.10383765633788802, 0.13998738429959745, 0.16207215165899647, 0.19604003056883815, 0.1660930254166165, 0.12903854761633182, 0.1644605839805257, 0.1331378228121227, 0.277189364837062, 0.3512186779370231, 0.1893413117936542, 0.15061544464720836], [0.04109696289824863, 0.01864353104704811, 0.018486281924490488, 0.03398700429487132, 0.02695837933119507, 0.0325943062442445, 0.009323198107942458, 0.03826283211369188, 0.05940133149945929, 0.03224416958889173, 0.015111898274851904, 0.07953276617392417, 0.07127318921829424, 0.056182593933396766, 0.028348210297765273, 0.034322872562634374, 0.08603074693030889, 0.027160775930350347, 0.06057855966050298, 0.03837115694618514, 0.025918960811630375, 0.009913036971533251, 0.09452177436962243, 0.08194886193039917, 0.07981176773506789, 0.030288954242883675, 0.0162348969869556, 0.03382746648463992, 0.05036704046952148, 0.11610371991991998, 0.019248796048604192, 0.05441190044005072, 0.03845015976337656, 0.02556600112227663, 0.0732673850331095, 0.022416824339738777, 0.10267797542074997, 0.0446333856351914, 0.05847506225109101, 0.07081152931336435, 0.05554680224327792, 0.05813986814070133, 0.21841517589505643, 9.71234062025624, 30.332406336261382, 40.02693645415768, 36.60850455684047, 27.796699923853723, 25.91594303807905, 15.429062766413535, 17.22781858136577, 15.570003332630282, 10.279242742446161, 2.714762365625751, 0.4047226569344921, 0.21753798989999681, 0.4919424719147144, 0.9422575646350462, 1.6269218032398534, 3.36408059443197, 3.881022752292695, 4.24336027714514, 3.5769655194974717, 5.488425493240357, 4.203140293398212, 3.905296340104073, 4.363685846328735, 4.134141879697, 3.95360523173886, 5.165173161414362, 2.3331750737082575, 3.902138096670951, 4.757363354006122, 4.963721700253026, 6.933554141752182, 14.31033415179099, 26.88884577443523, 42.514272197600334, 47.943667980932425, 53.06119218949349, 62.158255115632095, 60.95363247779108, 60.29248560628584, 59.23108439291678, 57.921146115949085, 60.33980508004466, 59.70660901838734, 55.57879294118574, 54.289396116810465, 51.32994036520682, 48.23830858353646, 47.560687757307484, 56.4268329066615, 57.774602443941184, 59.08658427576865, 59.58134812693442, 57.37264187105241, 57.50301361083985, 55.82302324233517, 55.84520032328945, 56.03068920873827, 56.47243830465502, 54.376715921586566, 56.78126219780215, 56.49114801037697, 55.80747496697211, 52.31700481907014, 51.81088178388534, 37.83312343781994, 23.48302821959219, 11.313328569935216, 4.283895031098397, 2.1293625908513225, 2.7267143178370694, 3.7352552192826427, 4.610402439871143, 5.694144493149174, 2.6662446077792876, 2.8403956370968975, 3.3212262488180593, 12.139260095934715, 12.491119254019953, 3.9513984082206606, 4.346021942553982, 1.8132634364789533, 2.1276933771948663, 1.0897910835281497, 0.16406171264186983, 0.30427425018241333, 3.1787883177880323, 14.38336770380697, 9.41405809694721, 9.132436821537635, 23.031406517951723, 31.88740057329978, 31.32557007574266, 31.28532067421944, 15.126895135448827, 7.048882611336247, 1.7964536288092214, 0.19492802330322806, 0.009017945586463377, 0.04290237549632307, 0.033026119363644434, 0.0393927083801358, 0.027218175068077062, 0.04440230670415106, 0.03605324301808592, 0.0694898974090334, 0.10381884121846768, 0.012355856747636873, 0.03532424524065948, 0.033794995847969286, 0.04644549001128443, 0.06292478436784399, 0.08959662574794024, 0.03336648839796263, 0.018851253872496948, 0.06129783961260992, 0.01210049953266618, 0.061720099615594076, 0.08948833155896395, 0.06520339032454837, 0.14242714451205346, 0.066118375097792, 0.009501177569731109, 0.04589561891231326, 0.03715293542031319, 0.03571806805989435, 0.07855780437708863, 0.08436896432671817, 0.05546155963994323, 0.020838901550779422, 0.06308860460957212, 0.05985677077044403, 0.07319506633305743, 0.02948836937937285, 0.07664030928525233, 0.05336420242524436, 0.031834850726168484, 0.06543437349459817, 0.06336410131846225, 0.015000357788296477, 0.016438071165354024, 0.05166436057357539, 0.04267315049805949, 0.03630984416832367, 0.05646388992787369, 0.042591435729616114, 0.022184021710868806, 0.05144886387091491, 0.011834212158235812, 0.034395095501695915, 0.024540561792110244, 0.013060117545988292, 0.0075852673222881655, 0.0667355814948678, 0.08326023591742401, 0.041556435622154705, 0.05761331675814525, 0.021122488148149945, 0.048571299731491074, 0.018302194826725512, 0.028715907603562362, 0.05228422912618807, 0.05904820710120182, 0.045924657475083105, 0.006935493091136338, 0.03494868595753947, 0.04392232197607237, 0.060151833364920276, 0.07093803341230077, 0.09200910556941264, 0.024272833214772326, 0.06740938646778946, 0.06571726678239723, 0.056237495624490326, 0.06827740239039545, 0.6674208251699325, 12.52964085148227, 36.88354115332327, 47.3406231787897, 40.912462511370265, 28.255009266637988, 18.226585426638206, 21.183615192290276, 28.415087076925463, 17.57790384754058, 10.139809346968129, 2.4426523475877704, 0.5260485530860963, 0.167279634324293, 0.02143035015662111, 0.07511944855533301, 1.0555486693497629, 2.2192319362394275, 4.5563006977881155, 6.911089256886513, 6.946837248340731, 10.112071325702052, 8.05184639269306, 7.5113006368760145, 8.428645941518969, 5.838529880969755, 5.929518572745785, 3.91540551377881, 3.5814625169000323, 4.243867733786184, 6.615967673640098, 7.225059299699723, 10.790452111151911, 18.070618260291315, 33.65168071562244, 43.60491468060402, 52.1986629886012, 55.977792124594416, 64.09705915758687, 62.36103773117066, 61.5340805053711, 59.68566356166717, 60.52438789798368, 60.80811646676833, 61.278224299030924, 57.94344086800852, 55.9670409079521, 55.366608404344134, 50.719294009670136, 50.751261326574514, 56.642904512343875, 58.04324949941328, 60.18084710644138, 59.86892454085812, 60.775827515509825, 59.86695551103162, 56.07695748729091, 56.02790040354575, 55.45717200925274, 56.7830821775621, 56.600919462019405, 55.55362701416016, 56.93308538006198, 56.09190171764743, 54.27835072240522, 51.18249062568911, 41.57183647155762, 29.557422476430094, 14.630790814276665, 6.53039038181305, 3.8506486531226867, 3.4505629731762797, 4.365449442017463, 5.1578785334863975, 5.632301953531081, 5.689315074874509, 5.829152474480291, 6.591243503555176, 11.309770980188924, 12.27471620805802, 5.135415119509544, 4.982062212882504, 3.335181061298617, 1.3387754199004944, 0.7265364594997898, 0.13080012083293932, 0.16554429195821285, 1.8623945549611125, 11.037877182806692, 15.331302592831275, 12.423751565717883, 17.631340257583126, 29.819599582302956, 34.74295470022386, 37.445605031905636, 20.036827902640066, 10.39922804601731, 2.729834073012875, 0.23668442702581807, 0.008579814156907941, 0.048042978685829914, 0.030968822801726, 0.02452474016125404, 0.045552591552897814, 0.08437757515498708, 0.03089346464783434, 0.02395318494358611, 0.038579617131261096, 0.004283023299649358, 0.045728063991954254, 0.03288030984901613, 0.02325974322194534, 0.024791526450445096, 0.13568670458851323, 0.05520389362749073, 0.056506641464488166, 0.048842425908773184, 0.12884820541066508, 0.03982997221511699, 0.015745649298262453, 0.020090332142107432, 0.04396641033611471, 0.030030600666519136, 0.08058521776430069, 0.15627111939172592, 0.012445814622145508, 0.027645156087894595, 0.061608032443590706, 0.0300656013085597, 0.034360824558403225, 0.011206818706986886, 0.07067586280285351, 0.023223371282520316, 0.02065766621531258, 0.1611766101972711, 0.18421512637888232, 0.12791030694760624, 0.08991264467758518, 0.12740168585291795, 0.13737070374190807, 0.11094214890392558, 0.09414836779356965, 0.22017204533180884, 0.08901395459449099, 0.1556701080933694, 0.20430547575796806, 0.20460722246958366, 0.18847043836309066, 0.21610007350963933, 0.07126004314951359, 0.12141162139033118, 0.17991676025332945, 0.24022539266415183, 0.12080926177722794, 0.21422888843282578, 0.1265481413312016, 0.11734957806766035, 0.2224914684531189, 0.17639269451460532, 0.13517658196149335, 0.09777852904892738, 0.07326062813761734, 0.19989354475851984, 0.16931287764060884, 0.16911599304406874, 0.20182715067940377, 0.1702375151216984, 0.17666059546172622, 0.13397944700573722, 0.1660166924158412, 0.1392825987310179, 0.21054250398470511, 0.27436326648439135, 0.2205632557912219, 0.20524963315936828, 0.1868438498387414, 1.0641091196767747, 14.211623784034485, 41.14684766338718, 54.470440956854056, 49.6806150867093, 38.38623646766909, 35.268913161370065, 22.147249367929277, 25.691336354901715, 21.268326620901785, 12.56167386808703, 3.498280077211319, 0.752996646108166, 0.6351102395884453, 1.2711046059285442, 3.086964406313435, 6.422879686278682, 9.430393788122363, 12.398103187161109, 11.10482027453761, 12.803051625528644, 15.126802959749776, 11.973611539410008, 9.514366830548934, 10.68465990404929, 10.436024781196348, 10.020532031213085, 10.468365703859638, 6.231965182289001, 7.132699249252197, 8.42321640060794, 6.580349120401568, 8.782248593145802, 17.577182131428874, 29.422910674925777, 43.9088709123673, 52.81856613774454, 58.2985604962995, 66.4840175259498, 63.98896255800801, 63.28445388424782, 62.16013393094463, 59.415984922839755, 62.79931552948491, 62.931836728126775, 57.62497186660767, 58.62469380901706, 56.616557951896425, 55.80186989999587, 51.59229201655234, 58.25084878552345, 59.27563075096377, 62.03644590993082, 60.68428331805814, 59.55813946262483, 60.070381395278446, 56.849499671689934, 56.27278574051396, 55.68724255408011, 57.06486917311146, 55.16296286736765, 56.702163680907226, 57.934592000899784, 56.42138865686233, 54.16518249819356, 53.768619106661895, 42.33327050362864, 26.819906196286603, 13.272327915314706, 5.9188953234303385, 3.9549003493401313, 6.271289885044099, 7.6899797974094275, 9.26420492510642, 11.699688896056145, 8.218250005475937, 9.826073665772716, 11.28249187623301, 21.808329128449966, 20.60696598022215, 9.562514905006656, 13.409695202304473, 6.876247332942102, 5.962471875452227, 3.086323343938397, 0.47546462546433177, 0.8301958778212148, 4.218764564683361, 17.02913288147219, 14.3494588136673, 16.7699916901127, 34.15588963416315, 41.99338928345711, 44.35874323691092, 42.9688984347928, 23.92890953248547, 10.825036629553765, 2.6907939872434063, 0.4857225734139643, 0.07094434597679684, 0.0787373983691777, 0.13115409941923234, 0.214705640269864, 0.10756948512167701, 0.12365505625043186, 0.15065803913579834, 0.22734808284909497, 0.12664161937972232, 0.11185062192981282, 0.12113744618311045, 0.2742984860895142, 0.12505485210567713, 0.21150867875304916, 0.25598893873393536, 0.1869609233953299, 0.11011317282194093, 0.13549749619297444, 0.1548348577512849, 0.11498072695347572, 0.1457288915351514, 0.16557948603745432, 0.24817251299898474, 0.2703130515592714, 0.11865881466937643, 0.2684729696521836, 0.12236399891515895, 0.09600335777166391, 0.2997691322478556, 0.13209506989486758, 0.14710412661154426, 0.0906060231969722, 0.12124970870753451, 0.155238249008694, 0.15035351918589684], [0.005491015157707397, 0.050974463923804225, 0.010925007518380882, 0.03529378941522972, 0.018748123116130312, 0.056039687892001484, 0.050631528494939695, 0.07115305131000858, 0.09115871732994434, 0.046093671792937864, 0.054047591158098755, 0.03440946731115541, 0.07242100343348519, 0.01603157725185156, 0.11837108736677517, 0.09582468308508398, 0.051229191989067106, 0.04156410799271638, 0.10011859823979678, 0.027731028798547004, 0.029346878685417677, 0.0055452967963872425, 0.051617544940522606, 0.0550811127158663, 0.0494820786820304, 0.02372831323995225, 0.06204274137534442, 0.070320260110161, 0.07215230575492305, 0.052632458222609375, 0.05085883061251333, 0.019315552950325995, 0.018696235981018796, 0.049989014383285284, 0.047835426314944224, 0.00881059718648753, 0.06577939651305638, 0.04529475317066235, 0.06677358711679136, 0.014178291819388828, 0.02419818752265025, 0.07802341974550679, 0.06651127095063848, 1.2541798237831363, 11.831077510310758, 35.61219115411082, 41.36568061767086, 31.19420401511654, 27.10415840148926, 20.593298481356715, 29.701279324869958, 38.86124334027691, 16.443172943207525, 10.527645464866392, 2.733070273553172, 0.7146279597955366, 0.2125054357513305, 0.29904073584944973, 0.459463867929674, 0.5878560365207735, 2.5367519692067177, 4.559540085254177, 6.890402676597719, 7.685548990003525, 8.076023392138943, 5.841718277623577, 6.964078026433145, 5.253228410597771, 3.46696142227419, 3.2054503838862143, 1.806311280496659, 2.3139177070510004, 3.41374074259112, 3.028834144915304, 4.275666879069421, 6.358406216867509, 15.511675726982856, 23.408895423335416, 43.305610379865094, 47.64443820522678, 51.30454694071124, 53.71856574089297, 58.58011999437886, 58.36189500747189, 58.02904267464915, 52.60896252047632, 57.56312785610076, 54.01499886666575, 54.74416355932913, 59.34470368969826, 48.28122715796194, 46.48903739067816, 57.16503081783172, 54.64627296693864, 64.45344178907334, 58.12251275585544, 55.434783120309156, 58.980213519065614, 56.491457877620576, 60.188491805907226, 58.43367830399544, 57.11031767629809, 58.24886406621626, 57.03014050760577, 55.08070684248402, 53.31633060209213, 43.466058854133856, 35.49570852710355, 21.92149539147654, 13.015798041897437, 3.460605221409952, 1.8506412953138354, 1.8419561871597845, 2.3286565032697495, 4.071101791435673, 3.722635973845759, 3.9405532998423425, 5.001727506037682, 3.8959270235030887, 5.473087064681515, 7.018994150623199, 12.147412742337874, 4.387494142978422, 2.3667976308253507, 2.565100654478996, 0.952181896615413, 0.12206079663648722, 0.5667074745701206, 3.1621425142211304, 11.214154381905834, 13.076378068616314, 16.00768198890071, 25.688306323943603, 24.445352323593635, 33.698380454894036, 33.37318458864766, 19.16558711759506, 7.209745385954458, 1.3748197954508568, 0.16253408735557912, 0.10592949771953207, 0.01559326770685373, 0.051362460644374934, 0.02503432652672693, 0.06870029058547751, 0.08650876281242217, 0.024904325236416152, 0.018007099673512484, 0.008662811165014583, 0.029832072811381474, 0.04077517149609424, 0.040744290491866494, 0.051767303638400576, 0.02683615383331574, 0.03387032910400341, 0.04017268547848348, 0.047735375232033195, 0.008127129929620893, 0.03282872914907432, 0.03629440749664942, 0.14965431073740607, 0.05669064429258147, 0.05912462820208842, 0.05545269217221968, 0.04567331934888517, 0.033984380443730665, 0.03285547710895058, 0.04273719161808972, 0.03681221015511021, 0.0751212565228343, 0.0709372136982218, 0.01168760974260588, 0.026839742955240994, 0.040247118581206574, 0.040321287383595784, 0.11520755792697591, 0.02834492761100973, 0.06535127593745148, 0.03516402944261509, 0.03717478424791367, 0.044903040923658884, 0.019132444529884288, 0.0396848636709394, 0.041787744379572334, 0.07473861092641469, 0.025426791455116005, 0.027721335871085048, 0.02638795792365507, 0.04713154473011533, 0.02977568874015443, 0.07079331174252496, 0.038161838742633986, 0.046822539335417176, 0.010637957245982703, 0.047597571336213625, 0.015369081651912102, 0.005042985872170258, 0.09054044607065379, 0.029617830577697006, 0.01864099146557912, 0.06808924353531293, 0.0388462502028673, 0.07142114377911053, 0.08449294799638372, 0.055947876084716096, 0.02285330293459758, 0.01826166111465183, 0.02665950927973515, 0.10418687751817127, 0.026666572610397014, 0.08276846109619064, 0.041738940748356046, 0.006697524635631952, 0.05543200013738486, 0.04967562313522062, 0.07089479540985438, 0.014704399828558729, 0.042887149498828, 0.018043988722286398, 1.965794483980825, 15.360085925748272, 42.09018161219936, 45.67616539616739, 36.19978181777462, 25.052448934124364, 15.607098167942418, 27.622446667763498, 40.47494957523961, 22.67311369219134, 10.702591999884575, 3.1969738967957038, 0.5883432684406158, 0.15964877040636155, 0.20609354029499716, 0.6438200464171748, 1.22241132201687, 2.6605083865504113, 5.498119631121236, 5.414258866540847, 9.513998127752735, 9.340087098460044, 9.063523719387671, 10.560394314027603, 7.081497609615327, 5.546301045725423, 4.4847620591040585, 3.4675777246875152, 2.3842109932053477, 5.958427421508297, 5.1171001022861855, 8.102672955682202, 9.06545352551245, 20.261593441809378, 31.2211722712363, 44.833589292341664, 50.633292121271936, 54.629006693440104, 58.161720768097915, 61.69911815274147, 61.047224152472715, 59.10292879227669, 57.04349617804251, 58.899612734394694, 56.59071345483103, 56.318383293767134, 59.55360912507581, 50.06909447331583, 47.54885788886778, 58.787040710449226, 56.410747266584835, 59.81071656750095, 62.44744362369661, 56.80480034120622, 58.991356972725164, 56.65796249143539, 60.88560681189261, 58.818827598325676, 57.49815379419635, 57.79732081197924, 58.23428853865593, 57.09612654101465, 55.78869465858706, 47.57807954665154, 40.13355824255174, 26.400159635851463, 16.57695028089708, 5.66872900532138, 3.0152477900828085, 3.9309741364371393, 2.3028139673894454, 4.258339318536943, 5.736028542441707, 6.010117396231621, 7.495118408433854, 6.345058391171118, 7.11198030940948, 8.50459969812824, 9.914613327672406, 6.335249033666426, 2.7340542981701517, 1.8502201308165829, 0.6043228819485634, 0.1356415820097731, 0.33019327228107764, 2.386496509275129, 9.392122241758532, 16.732154546245454, 17.198310590559437, 24.58001905871976, 26.041160783460064, 37.90857022808444, 39.186843210651034, 25.399659102962865, 10.081034591121059, 1.9655778956028724, 0.1681535261412782, 0.09784687941353168, 0.06536177900289336, 0.016405516259011724, 0.011132191209453008, 0.057758635976502014, 0.02227146873220561, 0.018669422903668978, 0.05929615528833482, 0.06724879145622253, 0.033822096208290714, 0.07371451991099505, 0.08491098685490509, 0.017539927765967387, 0.04635562789776633, 0.04260973373968755, 0.05072711711569179, 0.061698683627670815, 0.0515010153063603, 0.06888562257611944, 0.056661065637825005, 0.022662723241674326, 0.05295893425242074, 0.04302749680655618, 0.00781727226210698, 0.06731436092166171, 0.04503242168275099, 0.032853634667492686, 0.02006765210910911, 0.023531796365615823, 0.0114790030432144, 0.051659997702846606, 0.06889604137188966, 0.05221322426692613, 0.02316532097005796, 0.03920232403963324, 0.0744789760679968, 0.11379357412337296, 0.11959894244829494, 0.1350153357751908, 0.23967610762244274, 0.18093109130859378, 0.1778918213301128, 0.2527993623047106, 0.10057287305713662, 0.1803742066746758, 0.17893020754619954, 0.17965290425044877, 0.06456391375151373, 0.1437667258564503, 0.16365560943320875, 0.3215571018236299, 0.23149929880615205, 0.25256538373087684, 0.16799643215152527, 0.1258890529073054, 0.10031530663611428, 0.11108597425083, 0.18816335967952208, 0.1684555792880635, 0.2278683791237493, 0.14137066329919523, 0.11321724617793677, 0.19300229276620573, 0.2423933908463486, 0.1760721480053279, 0.12070069945747815, 0.12924537603412906, 0.15117392274400882, 0.18875326270297652, 0.17438591187519414, 0.19017443241130924, 0.15592090995802035, 0.11639707030788546, 0.1948962612978874, 0.15427930611035517, 0.1012827301277749, 0.06248860071683603, 0.24979997486356767, 0.12847856798719975, 2.511222487495792, 18.726979840186335, 47.95829842167516, 56.364843768458215, 44.66709252326719, 36.18470030446207, 29.860182385290827, 38.0990130670609, 45.631873992181596, 23.975134664966216, 13.890082586196161, 3.750627478284221, 0.9880736674512587, 0.6309686456957172, 1.0265937940247598, 2.4176820487745347, 3.3285770156691155, 8.2510478842643, 12.975770254288951, 15.729063287858041, 19.019335662165, 19.316429707311816, 13.244504582497383, 13.491946324225395, 14.134684531919419, 9.841664106615129, 8.89707794112544, 5.210881521624904, 5.662695419403815, 8.323315593504137, 5.33616594729885, 7.431791742001811, 8.988615274429321, 19.773421133718184, 27.788045214068507, 46.59165836149647, 51.74358960120909, 56.62957237612817, 60.426732647803526, 63.63055990588281, 62.075481337885705, 62.762966925098056, 58.28448310975106, 61.82419861516645, 57.73717126538677, 57.71031087444675, 60.94339901401151, 56.33283722785212, 49.580947660630756, 60.7711128265627, 59.11512344114242, 58.58475231355237, 60.817439940667924, 57.35198274735482, 59.49926860870854, 58.34760973530432, 59.618387068471606, 57.66596063490837, 56.90477763452838, 57.070584066452525, 57.64951021440568, 57.37215941952121, 55.62770097486435, 45.84198751757222, 38.86430278901131, 25.619753099256947, 14.6594839326797, 4.977540700666366, 3.3819820467502844, 4.122177179782621, 5.394102786817859, 9.383321423684398, 8.555311041493571, 9.927141378002784, 11.916998990120428, 9.373918521788813, 13.873404668223474, 17.0408627294725, 20.38279271894886, 11.86204952578391, 7.003505691405266, 6.9485665232904505, 2.798620923872917, 0.4472670433742385, 0.9791448820502529, 4.253229450794959, 13.501620850255414, 19.666275708906113, 24.360338872478856, 38.37753272825672, 32.643657076743345, 45.44454551512196, 47.43924333203224, 29.175385582831602, 11.621575874667014, 1.7716652299127273, 0.33421321141143, 0.23834499921048843, 0.16898091642125962, 0.07090950429800057, 0.0946992539590405, 0.1368189672188413, 0.16379453181739778, 0.16854032393424742, 0.2045346586213958, 0.1578957926962645, 0.1349409026724677, 0.17342048787301587, 0.18414109164187986, 0.10860687542346217, 0.11747444273843882, 0.1288671737476703, 0.16690901630828459, 0.15330848884919, 0.09672460656973625, 0.12281540090278273, 0.11259031046422259, 0.16379102313470456, 0.12506017641675088, 0.15962483781960704, 0.11189961325257056, 0.17110766842961314, 0.13371971255588916, 0.09481688675981376, 0.1063385810102186, 0.10980215644644153, 0.14815717575050172, 0.18345308339884206, 0.13154273582321982, 0.1336717860953462, 0.12406859051195845, 0.20371207937357888, 0.13653412040683532], [0.038006311402686184, 0.04423724539998559, 0.03713031284390919, 0.037145983172400344, 0.06346760745791179, 0.06735029044531046, 0.08502094345467706, 0.05436158378518397, 0.026840844206632148, 0.05697618441415891, 0.043501092361346375, 0.017665838146762505, 0.03479496658509297, 0.0657120880280291, 0.019065069012163628, 0.019926762794174498, 0.03434412384165391, 0.09166824240838328, 0.023313670066155256, 0.05001282822641154, 0.025147885654962836, 0.018512740686175325, 0.05546866893588055, 0.030327118828051516, 0.05922488612873901, 0.02069995618395267, 0.0259186428851418, 0.007744579615386864, 0.016458504645514394, 0.029123443396641847, 0.016531792446790684, 0.047676880588574756, 0.014105466543696822, 0.0349532020458531, 0.038977956038809596, 0.04874177344684159, 0.01452952589569313, 0.023492216433007872, 0.04523361935430477, 0.020365183421921347, 0.009936119200691823, 0.014720286576888494, 0.06295092328782044, 0.2849870673831432, 3.0871820978579985, 14.520380996888685, 32.10767107625162, 36.66809320449829, 34.42728234875587, 26.384099491180915, 34.854499063184186, 20.755206077329575, 16.312322674259065, 18.980704238337857, 8.184312187856245, 3.9378326458315698, 0.7670300285662375, 0.34509797250070884, 0.15712529210554016, 1.7482999159443764, 1.9839397361201627, 5.646864733388347, 3.5657384703236246, 8.466934157956032, 5.158100637697405, 10.0953600675829, 11.463513182055566, 4.633684158325195, 4.719757629979042, 1.8445836848789647, 2.420436533228044, 1.6183231098036615, 1.6014869487093342, 3.00744864729143, 2.6887344977548047, 1.1545609370354684, 4.2515536181388365, 13.033093733172263, 21.820651254346295, 35.91134640478319, 46.00961392925632, 49.67891277805452, 51.80067185432681, 55.86631836429719, 57.22413309158818, 55.616506530392556, 53.35537387478737, 57.42184016012377, 56.199331514297, 57.16550542462257, 50.427469668849824, 45.753000705472886, 49.22442774618826, 57.35197490261447, 61.84185712568222, 49.56898443160519, 55.01210066580004, 55.02367165780837, 59.97522861726823, 59.279278555224025, 57.96661423098657, 58.20084248819659, 56.38462820360738, 55.26050436881281, 52.923426781931234, 42.68416181687386, 31.487477671715524, 22.104256268470518, 10.613604207192699, 5.207802951335907, 1.747122592022342, 1.5747494995594027, 4.698898955698937, 1.1042847316111288, 2.913022978651908, 5.461644530296327, 3.7371183451144927, 4.399533367926075, 4.125576403833205, 5.788070549887996, 5.819618663480205, 8.113685990533522, 3.8418995613052003, 1.9724568748666396, 0.9543247364701765, 0.5972056186968281, 0.45633059896288386, 2.6785682045644332, 4.963527052633224, 10.167803302887949, 14.337600508043844, 22.171968144755212, 14.418328769745367, 24.992817140394642, 26.49826595860143, 21.256259449066658, 7.356190018115505, 2.4359249924459765, 0.09356465476054339, 0.08878549185371207, 0.02281749215457709, 0.058502231559325615, 0.05045971795616131, 0.01495203391964277, 0.005039341687675445, 0.03716981233728509, 0.05837520269016105, 0.059382638954106844, 0.06067858393033666, 0.05403557889944604, 0.0285204230327039, 0.09184647276396714, 0.09405163387137075, 0.008953937025169932, 0.030155038243279825, 0.020605597134319045, 0.04833025016611622, 0.03699587207407721, 0.05864191237055968, 0.06429028246671924, 0.03463897576195098, 0.029539237617545074, 0.05157259090112583, 0.028331628324644222, 0.05989668012085942, 0.038980196845988115, 0.05498892552549801, 0.044155074809227264, 0.024033348383982817, 0.009047436141108554, 0.02428442412506669, 0.0322573003359139, 0.0359199054148649, 0.06388908988165279, 0.014515766956573053, 0.08516189597186544, 0.02081453037868825, 0.012828561725215086, 0.0593506126484323, 0.08944097966436418, 0.0997746707270703, 0.027048507660266854, 0.05991140050032447, 0.030347808947666522, 0.04440708326235895, 0.013469543661020938, 0.020253125826017033, 0.03473844461803956, 0.042304830745823925, 0.0281747545851695, 0.046458942515234795, 0.047787166606154174, 0.019543243857521205, 0.05012793293703468, 0.008490159844739303, 0.033733819896775874, 0.0216850265109491, 0.0437789524514829, 0.04328426649613727, 0.03376593430256171, 0.06464490456686867, 0.028576768799534732, 0.043686566078254295, 0.012141154861197838, 0.010105169907722984, 0.0297065282375702, 0.0543402022712173, 0.04811132138955498, 0.014135732762365332, 0.057647522583964377, 0.0575612266097338, 0.015206183588522819, 0.009301479515289108, 0.04870546470967032, 0.10392551896192374, 0.07797357806515309, 0.038740599017229774, 0.03031401872454632, 0.024305876502166354, 0.2520556901130946, 4.620791327568793, 19.483805087304887, 38.24087342908306, 42.979186811754786, 36.59354855937343, 23.329330144389985, 29.97539024199209, 28.22937265519173, 25.727859504761238, 24.34761274245478, 9.793107125066943, 5.518353177655128, 0.9056758856581104, 0.16797283664345744, 0.11189486350744002, 0.5046962117475848, 1.104531473209781, 3.2389219297516734, 2.307244284499076, 3.896376870332226, 6.881349355943742, 11.506172880049675, 9.996435930652003, 3.7650429241118895, 6.428771086277501, 5.939328420546747, 6.951521048622747, 3.9535588987411994, 4.571003702379042, 5.654170147834286, 5.898063125148897, 4.513738078455772, 7.558179824582993, 15.173473281245078, 27.64228601609507, 38.63091784138834, 48.908649490725615, 52.05517092058736, 54.76143767756801, 58.50129996576617, 59.88528474684685, 57.18176364898682, 55.5742782931174, 59.65248815474972, 58.78890383628107, 58.977554152088786, 49.09402462743944, 47.51896158341439, 55.97052397266511, 58.353265793092795, 61.95999891527238, 52.08930730819703, 53.79000779121153, 57.284078674931685, 59.69261007924234, 60.53447623406688, 57.939706771604484, 59.17230375351445, 57.57217284171813, 57.17016520038728, 53.385901681838504, 46.27915136275753, 33.69901587886195, 26.608588503253078, 12.473184216407038, 7.92812159945888, 2.87098448603384, 3.2581182545231235, 4.329325883619247, 3.669768797774469, 5.4643720484549005, 6.920204354870704, 6.0948964857286025, 8.2346337456857, 8.078038019518699, 6.743236328324964, 6.649630925347728, 8.046733583173445, 4.014307097081216, 0.9449236118985761, 0.6404661747717089, 0.33398252701567066, 0.4143759776507655, 2.281090900782616, 8.406762057735074, 13.689743607274949, 19.256741039214596, 22.26148839919798, 18.705234219951016, 26.568295955657963, 33.53057361418201, 27.04635247107475, 10.657330789873678, 3.1469754442091915, 0.22988841508425054, 0.10901595105326946, 0.008154788576517134, 0.03810104966584233, 0.07655304420979754, 0.04358518583279464, 0.01243961888605789, 0.06083347158686769, 0.03505920180149617, 0.006998405189088156, 0.039694393804717454, 0.05122305945523324, 0.05698442368978455, 0.0597015422047867, 0.07193538795916304, 0.012942919500112053, 0.056077230030730854, 0.03205882993737056, 0.067905489685795, 0.015599142643623056, 0.060176551191797184, 0.04401964961641258, 0.006839059858447722, 0.023300401423306718, 0.02797963007563545, 0.03517267857528022, 0.06316271595536702, 0.03644729949413769, 0.026639261575896415, 0.0856906651789623, 0.08667543290122863, 0.06740107441381102, 0.019723623089732665, 0.032841162756085396, 0.015621382176064917, 0.09851598826747748, 0.006835180580721147, 0.0016662318986134545, 0.1276536751538515, 0.1430996931007793, 0.2974704088222596, 0.11249693966801129, 0.1688281278456411, 0.11052908961691203, 0.1651137965100427, 0.18185232735929951, 0.12016254567330885, 0.2361554433141024, 0.15334117016003979, 0.1385406885416277, 0.14634776800390215, 0.1571039488959697, 0.15457864730588852, 0.12071804368808386, 0.13317663282636674, 0.19258195564391153, 0.09506837810359656, 0.14281843158025898, 0.1132477671208401, 0.25933130373877866, 0.13058863460056244, 0.10915121153718042, 0.102510784392155, 0.11251387021113789, 0.10337516139712065, 0.13367063696345977, 0.08720663060704548, 0.09535985157614756, 0.1547556136163973, 0.14948181838037508, 0.10458974017491264, 0.12375213491219668, 0.14774952504423358, 0.11712450143550673, 0.09310070425271989, 0.12196168018084382, 0.2535409200936556, 0.1427705817285084, 0.1608978461233839, 0.10631850950660245, 0.1977106231835581, 0.4134963248525897, 6.326985090009629, 22.707087301438857, 45.907781354842655, 51.82309996697211, 45.93928190969652, 37.39674798903927, 43.05224095621417, 30.216749368175385, 23.083783888047744, 27.055389611951767, 11.743520402139234, 5.079219812347043, 1.445304419725172, 0.6541896899861674, 1.0023519528969642, 3.8374903269352454, 5.551631056493329, 12.161725471096656, 7.523890464536606, 18.52038468084028, 10.325683605286384, 19.633365061975297, 21.46092284110285, 9.305994837514817, 12.427825927734377, 6.601789286059718, 9.031710355512558, 5.986413042391501, 4.790376472857691, 7.02180992211065, 5.873824348372798, 3.1090385250506865, 7.2428418551721885, 15.487286429251395, 25.288428529616326, 39.45514117517779, 48.90375829512074, 52.50691813807334, 55.217460278541814, 58.82177722069525, 60.8200640063132, 60.028486559467936, 57.9536743317881, 59.9616454493615, 60.91377335210001, 62.39597820466565, 53.90303873246717, 47.51623553614463, 56.09601236158802, 61.66655855794107, 62.56091387041154, 54.80800797862392, 55.61095245422856, 55.06777086565572, 59.50617198021182, 58.7592742519994, 58.756324629629816, 59.250523659490774, 58.05765244268603, 56.84924471762873, 55.734616941021336, 45.16171909147694, 33.50335236518614, 25.31718734771975, 12.630176101961444, 7.492851278474254, 3.6954769924763715, 3.5029753994557167, 8.533009425286325, 4.881566676401324, 8.326658433483493, 11.588686800772145, 11.192218526717156, 13.410520861225745, 11.064051158966558, 11.947187512151658, 15.655444322093842, 16.24204949025185, 9.000965837509401, 5.508867905985925, 3.284766837473839, 1.42970870819784, 0.8965366405825462, 3.8842888609055555, 7.730837656605629, 15.845193882142345, 23.09666495169363, 32.44112549289581, 22.78221049616414, 35.20511973288752, 40.73533219675864, 34.13138266532652, 12.615175977829965, 2.948819999733279, 0.37963465637257027, 0.28653621974010623, 0.1044436012424769, 0.11794189426807627, 0.18010365506333692, 0.11522173055357511, 0.10479161966471903, 0.17496660652179874, 0.17303241837409236, 0.11426289490754567, 0.1480587794175071, 0.17775410936484415, 0.1454729568814078, 0.25829959780939166, 0.21181402607790886, 0.1198488709727122, 0.1423841056924674, 0.08299323895405378, 0.1512033251985427, 0.2068612829691941, 0.2014485806707413, 0.15265959705556595, 0.09049270347121263, 0.10834983760310758, 0.1937331559677278, 0.11570245072606111, 0.2957385291735972, 0.15920727393559872, 0.19359769630095652, 0.1213981842081393, 0.23278317023669523, 0.12800691829573724, 0.1107362091481205, 0.1353738189584786, 0.11371840557624256, 0.16608901111589325, 0.05906192773592569, 0.17256052353449408], [0.046871710688837116, 0.015666440594941378, 0.018185745631795258, 0.03493170944913741, 0.07187770153846472, 0.032026091169926434, 0.01878406030065831, 0.006899104872342921, 0.04637398336443209, 0.030982428523261222, 0.05719988974892805, 0.04637444301718666, 0.046326738722141714, 0.04582957830280066, 0.06915841882507648, 0.04850135973444389, 0.04711025514669957, 0.009988363524298034, 0.038427629117523475, 0.023917473754995776, 0.011307531498342512, 0.07897367520678429, 0.011441477183853428, 0.1063822863262988, 0.03234447348081777, 0.06093958242525978, 0.025557407530986016, 0.042873915329936056, 0.04683729801927844, 0.10289164500371104, 0.017872798714726683, 0.03341232726891195, 0.00936824407789015, 0.05017957875445005, 0.11911518090674955, 0.02492466870124542, 0.08644258813752283, 0.04019117501053599, 0.028687066308433012, 0.022718827690809004, 0.055768998384836226, 0.06403973724152293, 0.01486103512316702, 0.05330193479875884, 0.20652359141217125, 3.9023557882155147, 14.928926248704235, 32.121246399418006, 35.54131392509707, 30.7287500750634, 31.926898840935003, 24.28491169406522, 18.90602623262713, 14.637262725060987, 14.287739338413363, 9.066975405139308, 5.396357659370669, 1.7411577701568606, 0.4046986324171866, 0.185690090781258, 0.4479450311872267, 1.8794861604129116, 1.7404537047109299, 2.293492699823072, 7.926749750491112, 7.3424460330317105, 8.172923095764654, 2.9321859632768943, 3.7287014290209743, 6.284655361406266, 4.143108908207187, 2.0497550238524718, 6.481555402278901, 4.141681655760735, 5.13901585532773, 2.9466072926598215, 2.6129805368761865, 3.6096310182925198, 11.95051662383541, 19.919786337883245, 32.45804659781918, 42.20808021483883, 53.311541388111735, 57.40302455040717, 57.10398304846979, 60.58052485988986, 61.7356118848247, 58.90114638113207, 57.2952691970333, 54.187563542396795, 45.589143691524384, 43.01587666234663, 42.8106660996714, 56.870429438929406, 55.24852545030656, 56.677707702882834, 59.98971785268476, 56.10778731684531, 58.057585762393096, 63.52711915969849, 64.85327251495855, 63.93541436041556, 58.98194720668178, 51.67924704090242, 39.65140481148997, 27.677734436527377, 16.586063907992457, 8.006129697445902, 1.9327524376492349, 3.233858149859213, 2.339443266391754, 3.8667379704213913, 3.93994729365072, 3.877390147216859, 4.960726480330191, 3.786391404367263, 4.701076851737115, 8.786858358690816, 6.809949961400802, 5.407232430673415, 4.366858063205596, 6.111510174889719, 3.016895675851453, 0.5323329255465539, 0.520000196993351, 0.517847306065021, 3.2498386213856363, 3.8954041225294915, 6.172254450859563, 13.89090040037709, 20.76399414770065, 17.376107708100353, 25.615499288805072, 32.24319681044548, 27.216136186353623, 13.57634102144549, 3.1062193214893346, 0.20773367325384773, 0.006248527685285456, 0.1363880734049505, 0.016800488210133007, 0.029728920987596916, 0.13071119334668885, 0.04237219668744553, 0.01704416737230795, 0.04680234142729352, 0.03116528221946811, 0.11136781033729354, 0.10613505443137501, 0.021668523061840285, 0.04510507746148975, 0.03395495117611943, 0.049861495217849175, 0.039042859007754636, 0.07706626183203152, 0.060409097181212526, 0.04266142552237838, 0.08170912237537485, 0.07694161932675109, 0.01619961480760286, 0.035482304501197034, 0.025396603760459734, 0.04637166594846114, 0.05736829885732263, 0.034211199925912004, 0.06011342554683647, 0.01959021653859846, 0.10231115720084599, 0.10127054932977884, 0.041758686664604375, 0.020197689788596287, 0.07562083778001609, 0.028859376719581987, 0.04580601343824979, 0.011072495723173264, 0.032909007502659675, 0.049616347082079425, 0.019254254425064694, 0.02539236346379884, 0.02277772069998807, 0.07158107995506256, 0.041334748929066044, 0.048916249971596465, 0.029508412154691837, 0.03181252309361533, 0.08271459745423448, 0.08321397952855596, 0.05342717102218059, 0.054248562833714875, 0.023435435911280014, 0.06345133575040006, 0.07416831975382182, 0.031589003535167824, 0.0409002315192934, 0.027594136547357328, 0.032818356318579565, 0.051305869729408336, 0.012366695934155536, 0.030712901554521055, 0.08531357371999372, 0.01952168039767252, 0.0909467331404167, 0.04182027247283728, 0.0960117157909178, 0.013055822665562794, 0.07123731332080019, 0.02966168528092244, 0.06702274955328434, 0.08818117105552266, 0.05396091597034566, 0.015692475135438144, 0.05381216467808812, 0.03917842592683531, 0.03925521474992556, 0.0449533001219313, 0.04267994186750824, 0.03910986488805183, 0.08635229701476713, 0.02811646487023081, 0.024880702915270964, 0.6548073407142394, 6.0814182412239814, 20.421404530925138, 38.67836283099267, 42.323758755960775, 29.082825491505286, 30.617023321890063, 18.91283546724627, 13.843806462903178, 25.23744752330165, 19.16132546240284, 10.031287170225575, 7.53422640023693, 2.226394674470348, 0.24054253774304546, 0.16541494567307735, 0.1606899145389757, 1.1321814862951156, 1.0196280936079642, 3.5721927304421706, 3.6266869546905642, 10.22052780274422, 7.312220738780114, 5.047069614933384, 6.816498358403483, 6.315490093923384, 6.555315083073032, 5.701453829965284, 6.995347651743121, 6.15875953628171, 4.251093720236133, 4.3301829215018985, 3.230610917652807, 6.337803477241147, 14.467452533783453, 23.799951807145153, 34.70018517586493, 45.13519602437174, 57.157766588272594, 60.266448913082, 56.54583761768957, 60.68920981499457, 59.644098204951135, 58.45934629440308, 58.39206587883734, 56.165454003118704, 43.48742400446246, 45.973551657892045, 49.81992198574928, 61.69471725340813, 56.27768870322936, 54.78523077503328, 59.86499824831563, 57.96121704962946, 61.37447926305956, 62.7521921742347, 62.57898815216557, 63.119514296131754, 59.948211331521314, 54.70603419888405, 43.14143565393264, 31.3417733869245, 20.977200461972146, 11.608552625102382, 4.432978437792871, 3.9549238835611655, 3.833404442956371, 3.825207424740638, 5.278192335559476, 4.884063265016002, 5.460554111388422, 11.748745979801303, 7.501223087310792, 7.465826147986998, 6.6954648014037845, 5.956803560256959, 5.586698026426378, 5.840029206968123, 3.1097178305349047, 0.2703053293929946, 0.45385546081008454, 0.5192290835322872, 1.8833265285338125, 6.976715903128348, 11.615404025200876, 17.36548592967372, 20.196705672048754, 16.12788204223879, 24.414953954758186, 35.54046277076968, 32.08216390302105, 17.40115204165059, 4.715866148471832, 0.5021502870705821, 0.03984942701795409, 0.12081963460772269, 0.029077631338769873, 0.06171396325132059, 0.100120498137849, 0.0916291949068827, 0.05299195647239686, 0.047397721979406574, 0.05522385021791824, 0.07445220895592244, 0.024488822128924153, 0.04489502381353129, 0.025568965882543596, 0.09384362567817012, 0.0253965980148003, 0.0371593437457998, 0.07531971926049841, 0.04971423396660436, 0.04868304131612663, 0.062248458965651454, 0.07157803092512392, 0.028676720291015603, 0.03626642613521507, 0.00914148396752294, 0.04990935273047897, 0.027292987384322672, 0.03073365296117, 0.030233621627332705, 0.029913283877014637, 0.08622381640898605, 0.04086906323209405, 0.029071973779449062, 0.07000566610405523, 0.03776575979446212, 0.07470944595913734, 0.04933432330407443, 0.07074871776445259, 0.030979595913161195, 0.09341706026105151, 0.07734271232038736, 0.1515260473975251, 0.12395209152131312, 0.2370240338026516, 0.12713988296567433, 0.17629527877415382, 0.24905418826928064, 0.14842509201938106, 0.2386990544055739, 0.2325193448773315, 0.17199403215800563, 0.12684563625483744, 0.06429612771758149, 0.1480641113894601, 0.18537089258672731, 0.17824129531941107, 0.1747472295838018, 0.12008564576746956, 0.12138919033590825, 0.19964439764378533, 0.12550394816864885, 0.17302926209184433, 0.17191218332417552, 0.15062909633401902, 0.1943261999516718, 0.11558337001911095, 0.21133963379167744, 0.09131986392481674, 0.22702398169184887, 0.08365470225051527, 0.16993376125972118, 0.10965902823954822, 0.20678283556574778, 0.16682103877106022, 0.08689102536487965, 0.16978711670925542, 0.1382146874863294, 0.125381879718794, 0.10805362970718455, 0.183316872965905, 0.17015237210979386, 0.13981234853065785, 0.13107742933977035, 0.5816387120754488, 7.026380463953942, 22.886370997275076, 48.04360212818269, 50.417926542220584, 41.00897635183027, 43.60019999165689, 35.367807880524666, 25.90094977809537, 25.06075651414933, 20.973238868098107, 12.515738010406496, 7.355374165119664, 2.378143821993182, 0.6527615182342068, 0.46026072194499357, 1.575843473115275, 4.060917357283254, 6.628415315381943, 7.9760666912601845, 17.65656109779112, 15.00355326360272, 18.353715327478227, 9.120096064382984, 10.957719625965243, 13.839518331712293, 10.12025829284422, 6.809927898068582, 12.5130453032832, 10.643760369670007, 10.885599005606867, 5.511985209680373, 4.725355832807479, 4.545723536322194, 12.857325461602981, 22.914025668174993, 34.15778806132655, 44.447322122512325, 56.99211312878517, 59.18470236562914, 58.50367299972042, 62.984820104414425, 63.07331662024222, 62.169116158639234, 63.349314197417236, 59.619010725329005, 45.279464721679695, 45.831142164045765, 54.267344551701704, 61.450102559981815, 61.11735613115373, 58.53687586322908, 63.597360964744325, 61.14799768693986, 63.77309883794477, 62.54817008972169, 62.174478038664795, 64.85383733626335, 59.41516122510357, 54.46652250905191, 41.94889391622236, 30.047189227996338, 20.34758944665232, 9.444433912154167, 3.248746241292646, 6.981658089545466, 4.513204145816065, 6.375442541414692, 8.072998754439816, 9.96674358844757, 12.324215539040106, 9.660656529088175, 11.478731978324152, 16.771182129459998, 16.824122359675748, 13.962378732619749, 11.312355822132481, 12.777402266379326, 8.155314595468584, 2.6260275658099883, 1.2546707329250153, 0.9396873090055682, 4.118911316317897, 5.975926095439542, 13.03680625654036, 24.182637853007165, 30.46274473590236, 25.553266963651105, 36.08244019169962, 43.051589842765566, 40.63886150237053, 20.313759003916097, 4.9295181420541585, 0.4662640627113081, 0.09085399819718254, 0.35861231506832186, 0.11533203955379226, 0.20498231443906986, 0.27989013120532036, 0.14667226752686888, 0.11390943726104115, 0.11272252191819492, 0.14708440750837326, 0.15854480706395643, 0.12902135660331096, 0.15374682903770479, 0.09213454480613432, 0.30131301391989956, 0.19361122541369932, 0.13633274653505895, 0.22833713300285802, 0.1419243610073482, 0.13943233827669776, 0.17242618235609225, 0.16282172272762946, 0.10367566704629891, 0.16420510897953666, 0.13450441641672967, 0.13765991725508245, 0.17604887425418825, 0.15640947487085097, 0.15894162528697522, 0.06334252828251451, 0.21864736182314737, 0.19238643468387667, 0.14547735422609315, 0.16818723400994656, 0.2984209094316729, 0.258671885897075, 0.1346508004973012, 0.16449389348347343, 0.1151748919378846], [0.04605138373951759, 0.05270104607447021, 0.038617197574386676, 0.018318512499512687, 0.05068122078814814, 0.03485755979894631, 0.040215356575865904, 0.04625201067556778, 0.07672662441168102, 0.05676206666976214, 0.023011385177772854, 0.017763326665566816, 0.0655666922008799, 0.048121510358947905, 0.0725592439994216, 0.027809744332766825, 0.05905844203587021, 0.07357204287883735, 0.04123006684465274, 0.03700879980779944, 0.04025123630379958, 0.035790854073580236, 0.1205948644107388, 0.04940560395498911, 0.09676001515359649, 0.06418386136271781, 0.04629979157940515, 0.03302012089519732, 0.054074718331497525, 0.065648571678227, 0.014700977330757006, 0.04965901817946185, 0.059612224013694835, 0.016525127481849446, 0.07953066709301165, 0.05185469894880249, 0.14429033163093752, 0.06988806394679893, 0.018162567641646154, 0.05209868646136696, 0.09577753037334451, 0.0622820595820104, 0.020082883852263613, 0.09518774992395794, 0.02509537798863265, 0.5404512512107049, 4.454635314403042, 17.319700102652273, 35.51571261498236, 41.57161681882797, 33.80245662504627, 31.07855489177089, 36.74082963697372, 26.798368461670417, 17.914278468778058, 17.273523999798684, 8.411804264591586, 4.697011315053509, 2.318162201873718, 0.5608994862244976, 0.2728327760292638, 0.6786943912025422, 0.4439021400626629, 1.6203117514810257, 1.9125863068526792, 10.263976877735509, 4.64373327070667, 4.034842175822105, 7.119661290799418, 4.993387566458795, 7.220442179710635, 5.992934473099248, 4.471409330444952, 4.858322710760178, 3.685420035354553, 4.255053843221357, 1.1159306163749387, 2.3443834916237862, 4.238145486001046, 10.655528460779498, 17.463362793768606, 26.4716193368358, 37.56971666889806, 47.872947646725564, 54.95345730935374, 65.26902414137318, 58.44518653808102, 58.87620795157648, 60.99582149136452, 53.308544697300086, 48.78318855839391, 32.23698573727762, 38.622457288926654, 44.00995823644823, 48.43037136139409, 58.14297576104441, 54.185135595260135, 59.010356933839866, 58.546595496516076, 54.982341643302675, 55.16221761703492, 57.95460001114876, 50.973934281256895, 35.800472767122336, 20.131049117734356, 12.139800402425951, 3.548953667763741, 2.5891999419658416, 0.8557070347089922, 3.8217694672846028, 3.5003790355497792, 3.169901207570107, 3.8100141238781715, 4.058419542927896, 5.330265721967144, 18.631221055984497, 5.519194035760818, 6.5987229731775106, 5.780005666517443, 5.6038505511899155, 4.003050139834804, 4.2477768659591675, 1.2621924906007707, 0.1531433356144736, 0.47998071377796514, 3.378312179157811, 5.680232826740512, 5.942963967400213, 18.196100765658965, 14.306848145300343, 18.40411190063723, 30.432471882912424, 34.87561318182176, 26.288285793796664, 16.973658800125122, 3.038017394081239, 0.23366596399536058, 0.09595334755196687, 0.029767177503315673, 0.06525232036027216, 0.03231497526529335, 0.06033058466029264, 0.020838589369950276, 0.033239612746382916, 0.12942557523567833, 0.03164421357665091, 0.0884817456526141, 0.031817763135017406, 0.02301645284939197, 0.04588201702121766, 0.03595963090417847, 0.0078090679392428895, 0.013799484323469863, 0.04221555085912828, 0.040409230446863564, 0.037189270970561815, 0.1405170421686865, 0.010158083600653036, 0.01734925614249322, 0.005160614842503903, 0.07724071537414867, 0.03469072500123613, 0.08506531526725139, 0.0023685650282254025, 0.12574428527225412, 0.03822725116004867, 0.05378822060001474, 0.02939377667292232, 0.0814014231605876, 0.05179499388642369, 0.05622815318225373, 0.15361602718551315, 0.023542270702760548, 0.023995924988881718, 0.038514725653634924, 0.04459434579457006, 0.03351127518521201, 0.03593337707101338, 0.03207127886614011, 0.02199002143536364, 0.039540942563044454, 0.0287207109748476, 0.033956441217132156, 0.04176534779910599, 0.055248391844572566, 0.016864012220814344, 0.06941430751354465, 0.014316368634031426, 0.059613748528664155, 0.04249594670029418, 0.058656628919585105, 0.043083390581511685, 0.0056557939669507895, 0.005213951320207168, 0.02553045655780983, 0.017691982812398387, 0.05582547438661418, 0.05571730277170578, 0.012889349844396837, 0.04041912830284527, 0.03717317163283306, 0.06376336719239913, 0.016169222184426842, 0.06530106653489413, 0.034910006178242546, 0.03592934361809204, 0.015655402225562404, 0.021855433193606236, 0.03733943952547927, 0.07045953489479519, 0.03975753094099703, 0.09795999995643094, 0.058653962933608604, 0.015121859333087361, 0.021968802715080882, 0.036259780322471936, 0.009245707356791583, 0.09496652671406347, 0.011685470442077326, 0.056143339588156635, 0.042142868267312165, 0.9965118501455554, 6.578969916989727, 22.941242994800692, 42.16724834134502, 46.455367765119, 38.983939001637125, 37.03579579630206, 27.187173405001243, 21.1963354387591, 19.85517901758994, 19.596033903860278, 11.127771043008375, 5.755232466805366, 1.8340834999276747, 0.609579777284976, 0.18500842574623325, 0.13665194472958966, 0.1780712238002208, 1.1316746425244117, 0.6208287059299408, 7.372311449819996, 5.454312149555453, 2.41203555176335, 7.409333721283944, 7.657952664359924, 5.054906510537671, 7.173732144217338, 6.326601678325284, 8.834430825325752, 5.494866515359571, 6.509203209031013, 3.9394952404883603, 4.209869119428819, 6.861051580598278, 13.338016829183026, 21.18867308862748, 29.501848374643636, 42.53895175072455, 50.919025021214644, 57.70283091452814, 63.53144161162838, 63.58405628511983, 61.709614415322584, 66.57463996641098, 51.767680798807454, 45.41224087438276, 37.55299560485348, 43.26733981409381, 50.19827773494106, 52.79827571684315, 59.236599245379054, 59.23651687560543, 62.95361764969365, 62.907753375268754, 59.106027464712824, 58.37329733756281, 60.25788637899584, 54.70910541472897, 40.00703042553317, 25.253366462645996, 14.18039877568522, 7.156017249630344, 3.6734523936625454, 1.7472266574059765, 5.909550276494795, 5.203437843630391, 4.758910238742828, 5.705844433076921, 5.588089487245006, 5.317876425481612, 14.318122017768122, 11.445756612285493, 8.838928803320854, 6.59290756910078, 4.452679032279599, 4.657183568323813, 1.895077336699732, 0.5730946253864997, 0.12865682132542133, 0.3505368903279305, 2.183141963135812, 7.976183381772811, 10.348065630082163, 17.074944203899754, 18.372050446848718, 17.54952746052896, 29.340166314955685, 39.89127343700778, 34.149696211661066, 21.76223735655508, 5.41368620049569, 0.4966597962042978, 0.08820915624739663, 0.060407304535469705, 0.03165421485450239, 0.06065102008682105, 0.08226082059404544, 0.05527009128502781, 0.00998600397349125, 0.08501732751967446, 0.019130831914803675, 0.044363626924854134, 0.015005083593179383, 0.0687047262345591, 0.029166838447112712, 0.028457396979173346, 0.028663306091461453, 0.03476524620407051, 0.01959048849981158, 0.015210274498038476, 0.06587692716669652, 0.13838564766751182, 0.004373677356559183, 0.0871558772820619, 0.0237980138345231, 0.06806827570882536, 0.013470445729551778, 0.06058725858888319, 0.048864113857909564, 0.09467503791975398, 0.06580188885451325, 0.07142115143998977, 0.054039003312467575, 0.07099486947540315, 0.10680591762666741, 0.03590462196077551, 0.09985044448366089, 0.036549901649836576, 0.03184794891445387, 0.009504053272276877, 0.03659831457621148, 0.09838916241161286, 0.11720219807278727, 0.13746827269994444, 0.1421297491798478, 0.1938691059307706, 0.12195911378629747, 0.14348621510209578, 0.13696512147303552, 0.1539199495868337, 0.10277581250955982, 0.08763421492110338, 0.1772817242289743, 0.21468886294432227, 0.1539634020938989, 0.2423600660216424, 0.10244921390568057, 0.10269495192915203, 0.19072986147817106, 0.1441062866680084, 0.11325424056380026, 0.15932402573525906, 0.1361917557134744, 0.19640511743003325, 0.14278381972783996, 0.2686241341214026, 0.1930267156492318, 0.14195391667946694, 0.10479577952214789, 0.08256906373125893, 0.21467375569045546, 0.14404119983796151, 0.09770074814197519, 0.18910786948136746, 0.20958437313956602, 0.25976919959629735, 0.15627715616456925, 0.14761616445837483, 0.26857868978573435, 0.20220048064666413, 0.13952952419077197, 0.23561486103121312, 0.14920302366297092, 0.13512877807501825, 0.14666917253165476, 0.16669035949293645, 1.092574863183883, 7.438561752919228, 26.49468679581919, 49.721615622120524, 55.00821751932944, 44.733392346289854, 41.571608974087624, 48.84533851377426, 36.33579784824003, 27.629810917762022, 25.06864243938077, 12.845781926185856, 7.4340446533695355, 3.3783246817127353, 1.0360987388318585, 0.7240700853928443, 1.9166569916471359, 2.622360394847009, 3.688777829370191, 8.706481149119716, 15.407336758029077, 13.129461465343354, 9.242585801309156, 19.32739273194344, 10.93320579298081, 14.418668054765272, 13.943841611185382, 13.25863099867298, 12.31433508857604, 9.876865417726579, 11.649486480220673, 3.8809313120380526, 4.569192057655704, 5.658299423033192, 12.224204905571478, 20.207770678304858, 29.330356467154722, 41.80530771132439, 53.238891247780096, 61.22531937014673, 70.51244858772525, 66.68970661778604, 64.78206972922048, 67.5099918919225, 57.90508793246362, 47.328950205156886, 38.501491392812426, 47.70365422771823, 56.340736881379165, 55.03623893184047, 59.87287044525147, 58.420887454863525, 64.04446017357611, 66.18132037501182, 67.1322911785495, 61.36958414508451, 64.37597497817009, 58.67493152618409, 41.97256542021229, 25.097387529188588, 15.904909026238228, 6.483234667008923, 4.418814268804366, 2.263298539384719, 7.523814468614518, 7.67390396325819, 9.44532330959074, 9.179970064470846, 10.039493749218604, 12.950670026963758, 32.52815308109407, 16.662965897590883, 13.975017589907493, 13.93330514431, 13.7750796733364, 10.690865093661893, 7.6723183451160315, 2.644435003880532, 0.5108678773526223, 0.8385489941123994, 3.8092529389166065, 9.168317683281439, 10.811606434083755, 27.106539280183856, 23.505789733702137, 26.025163396712273, 40.093475541760846, 49.47284713868172, 41.568573059574256, 25.067222541378392, 5.725291544391263, 0.7495085558583661, 0.23737099502355824, 0.14661450449737812, 0.09993601650480302, 0.16419020090853015, 0.3682623875717963, 0.23355077501506577, 0.16815200928718815, 0.26752547210743355, 0.19844294195213627, 0.17594827158797174, 0.08136594562881416, 0.1312488951389828, 0.14094179195742454, 0.13225593303720798, 0.08311043508471021, 0.1834086349774753, 0.10694163776333294, 0.1825551517427929, 0.12154353407001305, 0.25891675824119204, 0.11272891875236266, 0.1982074158806955, 0.17254098829242492, 0.18120294526940395, 0.18374995779125922, 0.27125065124803976, 0.19206250206597392, 0.40878721302555454, 0.22163712719996131, 0.1351608924808041, 0.1461012102663517, 0.15832521562134066, 0.2104097562691858, 0.15337003635302668, 0.2873423587410681, 0.1232299310786109, 0.17978621887103205, 0.17802227078185928, 0.11753920015067824], [0.09872143006613178, 0.017692272010589802, 0.08432332080818954, 0.01549220730310246, 0.026278983831645984, 0.004862575517636874, 0.06085077368263757, 0.06680809937778019, 0.028103500747332172, 0.07205559481536189, 0.08846877578405604, 0.03359856707374415, 0.061272888128916105, 0.028498984062142914, 0.03954427887595469, 0.009052459762672023, 0.03635522721695804, 0.037502486018403884, 0.06447556083120647, 0.03516495257856385, 0.006024392383668813, 0.03183496755457694, 0.018735180060649594, 0.029159575933590535, 0.07090805639182368, 0.01729503626965227, 0.033343758569249225, 0.13611724600195885, 0.018878404028533448, 0.02074461336427879, 0.05981181673104725, 0.08769572412054386, 0.03673299666373961, 0.014146122829838386, 0.05978679246900063, 0.021465331646463564, 0.03162605729284546, 0.02270758152008057, 0.02665082950355305, 0.028659713139096578, 0.00378463929425174, 0.10947244752558971, 0.01739429828200129, 0.02994415913558295, 0.03343635944709663, 0.09611070201161409, 0.5371253264527167, 4.552768603447945, 16.744984619079098, 30.77928589236352, 34.466341310931796, 27.726301224000995, 23.48708983390562, 36.95687378606489, 42.89436947914862, 26.637851345923643, 26.888720258589718, 13.931789148238398, 5.971566871289284, 3.3664965293099804, 0.36029363291398175, 0.08896602047306877, 0.11330906181566178, 1.9784528305453641, 0.3515337239350042, 6.383486342045569, 4.935766477738658, 2.857322870723663, 4.163731259684409, 4.1935770646218336, 3.8202323884733267, 4.871130229965334, 3.7416969768462645, 5.745844764094199, 3.576445560301504, 4.405747382871566, 2.689537848195722, 2.15008667880489, 2.712899975238308, 4.5372281728252295, 7.428540097128961, 13.116600013548329, 23.089969465809485, 30.550807829826113, 45.264987253373675, 66.00139341046734, 71.60842941653344, 64.6018603540236, 60.77707090685445, 55.02604076939245, 43.49830073695029, 31.27768381949394, 42.61418281062957, 47.12991345313288, 45.553344218961655, 64.37801461065969, 55.06576653449766, 51.88312399771906, 48.3428789723304, 52.62602090835572, 63.48250612135857, 56.5913135774674, 38.91809417355446, 24.421486662280177, 9.874132506309017, 3.498049883111831, 2.098089288319311, 1.8052066429968805, 1.8522690789353464, 3.754617019045738, 5.353395938873292, 3.1656098894534574, 5.16223922852547, 3.8895183609377955, 2.1535099273727787, 12.619671994639981, 8.60723537783469, 6.227182342160133, 4.103653786643859, 3.647395843459714, 2.9925115262308433, 2.2093255000729717, 0.2749814994392857, 0.26230651344503125, 2.0393893026536514, 10.789784327630075, 6.0980422266068, 16.569735080965106, 21.043327700707223, 19.78778877565938, 23.225557957926107, 31.52261034134896, 34.624267701179754, 21.83536014249248, 5.144056100999156, 0.7875402247713459, 0.11012200581570787, 0.09368646274050398, 0.11445868399835403, 0.03749225491417512, 0.043909424885867104, 0.01892096978882628, 0.03199989096291604, 0.039813819251233534, 0.046301465481519706, 0.07936043469535728, 0.011859504551055932, 0.023906951537355784, 0.020337677035000057, 0.06702541553926084, 0.017046791223448612, 0.049618978594099326, 0.029293242954618992, 0.0289173485080321, 0.03701402452744303, 0.08328954644140699, 0.023566057732809457, 0.04970994387422839, 0.0359564324870946, 0.015006904009609454, 0.029898940795852296, 0.04985751539108254, 0.06684155443743353, 0.07403475232422352, 0.05894336796876404, 0.00828897270689448, 0.03500064970144341, 0.01815600609857469, 0.1019561673784929, 0.06622542822433096, 0.03555298760353077, 0.03676158323463413, 0.07630721425577518, 0.05001909482563215, 0.07129754315340711, 0.061355257902534745, 0.022117287791784734, 0.08775288960145367, 0.059522028651929675, 0.03871404257933459, 0.03333120238817027, 0.02555619711206565, 0.03737164586181602, 0.04315685841345018, 0.04284087778820146, 0.05951487722115652, 0.0386883250077165, 0.06891342390689158, 0.07284908570469388, 0.01827856101426146, 0.024412496789028088, 0.030556904985719634, 0.07105074026772092, 0.03331263624732533, 0.0832186220213771, 0.014482975520584133, 0.07154744103430741, 0.0038687978831735714, 0.024027464828724344, 0.010809726607535156, 0.07819789627026166, 0.10252863424079073, 0.06003890817444171, 0.08109933170940607, 0.028929109872889616, 0.03154975685080694, 0.08943727179881066, 0.03314040436018859, 0.04681304750603534, 0.03758575594533355, 0.1284092370300524, 0.005422316701902498, 0.05481744440452707, 0.08642745024013905, 0.056933992121729164, 0.05163652093840703, 0.0372429775644935, 0.07353533194550584, 0.07282092431259733, 0.042082649926024104, 0.03999017652184252, 0.1136691767662283, 0.898489613206156, 7.146520701146896, 22.126264687507383, 36.378092765808105, 38.38550690681704, 31.352481457494925, 30.455910005877097, 35.87716294873145, 32.6415233073696, 25.831602273448823, 20.203528634963497, 14.306717726492113, 11.283595042843974, 3.942178631982496, 0.6509913035458135, 0.2203271168494417, 0.09374126100972777, 0.29426463729431557, 0.3910662203786835, 4.792821580363858, 5.454086613270545, 1.8881166005326857, 4.686983775707984, 4.302460589716512, 5.645100647403348, 6.375287117496614, 7.331203539525309, 8.275973566116827, 4.707184472391683, 6.525569298575002, 5.714816364549822, 3.9182019185635353, 5.347284395848551, 5.460138830446429, 9.461962003861705, 16.61155539174234, 26.541717975370346, 35.117909754476244, 50.375796364199736, 65.18852533832674, 67.50478298433366, 64.34385076645883, 62.85023181669174, 54.66224485828031, 46.274562189655924, 34.41205963011711, 46.909958700979914, 52.15512467968849, 48.29007210270051, 65.16440668413716, 60.77228169287405, 60.155355622691495, 55.093234892814394, 55.702951646620235, 60.72429933855611, 59.22965272780388, 42.882672971294774, 26.79885679675687, 15.074126508928115, 5.454994641965436, 2.456763074282677, 3.5284372202811705, 2.6718303080528014, 6.502578816106243, 6.704223944294838, 4.917522553474673, 5.75017947343088, 5.457826102933576, 4.778641231598393, 9.575533251608572, 11.790017158754411, 6.601804485244136, 5.011202481485182, 2.3534559338323535, 1.9045729045906377, 0.61116827591773, 0.15623031754887876, 0.34525646077048394, 1.944883593147801, 8.952427487219534, 10.46712721547773, 14.980189665671318, 17.29002344992853, 15.546378897082423, 22.254677203393754, 36.21994280046032, 39.54802682322841, 27.495724693421398, 7.377859642428737, 0.9473549298221066, 0.0606882902643373, 0.04212847730565456, 0.09046473360109715, 0.03836868631262933, 0.04987177611779302, 0.028805379012239077, 0.01648057180817329, 0.051968635375341105, 0.04823930786862489, 0.07980279684547456, 0.040369248318095366, 0.01613512552613693, 0.044834556493667826, 0.058965454283621044, 0.02935215511599616, 0.038959738467970205, 0.027770685339947383, 0.002588684832106435, 0.07257554635045028, 0.0686352497207061, 0.032893222260979876, 0.08034413755540887, 0.0491255451925099, 0.11177103305535932, 0.055837176379657565, 0.028687451267614964, 0.027944355557161956, 0.05681069027031622, 0.05661641803359794, 0.03937372089093251, 0.04769357747488445, 0.008276702851177225, 0.05335155814405411, 0.02038622019632209, 0.05355670116841794, 0.09761149123791726, 0.08573286130183166, 0.08733913317442903, 0.09205872508426828, 0.06942822733112881, 0.1419443865456889, 0.10459797562009866, 0.1615337757093291, 0.11623089051535053, 0.1758365146815777, 0.14777972423020871, 0.13622033079305004, 0.13341818034889238, 0.17614950756392173, 0.12281773747095179, 0.13454262888239277, 0.2153145575955991, 0.16273397501678238, 0.18007583074992706, 0.10760725325634403, 0.10397641784361294, 0.22238988519435932, 0.1263692904443991, 0.184263926179659, 0.1802276846982779, 0.12808546529061374, 0.11411711603643433, 0.17914351706783618, 0.1726309729800109, 0.1488316702025552, 0.26331609475516504, 0.12193105964651033, 0.22817562634666122, 0.15096222200701315, 0.107109273122924, 0.18274204655280038, 0.08787670473177588, 0.1039620766776704, 0.12542155541239247, 0.22574950249925738, 0.1638486942336444, 0.20371243177402407, 0.18496316527166676, 0.10507547056242343, 0.14293363588231225, 0.061100920542113246, 0.19304568398623698, 0.22766864468013087, 0.13307239890338915, 0.18981179703147183, 0.16986944051759859, 1.0323574105578086, 8.214250168492718, 25.92303272216551, 43.87358134792697, 48.29719512693344, 38.89946683760613, 34.57815631743401, 48.46767702410298, 54.78153982470113, 36.80350518995716, 36.51357927630025, 18.60374289174234, 8.85195597525566, 4.416423584184339, 0.9630727251210521, 0.32997089227841747, 0.5611495373229827, 3.7857444584369664, 2.7558641472170433, 11.746213109262529, 12.344230413436891, 8.140663071986168, 8.949432757592971, 10.342896926787592, 10.443676344809994, 11.49930480987795, 11.026906313434726, 15.468292351691955, 9.481434610582168, 9.687962109042752, 6.96411430835724, 4.8898619990195, 5.323437856089685, 5.209193431561993, 8.846221470063734, 15.991858167033042, 25.98472179905061, 35.84517994234639, 55.66500271520307, 71.8231007360643, 72.31962573143744, 67.52612067807105, 67.07454604487266, 59.11329169427196, 46.45340658003285, 40.186023865976644, 51.18051767349244, 58.17961462082402, 53.460014866244414, 67.66349777098625, 62.97557900028845, 64.83971288127285, 57.48059334293489, 63.035202949277824, 68.51861369225287, 62.65918493270875, 48.967167331326394, 29.461808819924634, 13.170605167265862, 5.462157870492628, 3.769729175875264, 4.594867402507413, 5.2227118803608805, 9.152680173996957, 12.227622270584108, 8.929384543049721, 14.203271096752538, 10.750023261193308, 8.388358296886567, 25.380512052966704, 18.799284811942808, 13.065324829470727, 10.907656454270887, 8.30033834903471, 6.891105761451106, 3.7543105838760256, 0.9444490663947599, 0.7494485558521363, 3.108767636360661, 13.343496380313752, 11.456693160918451, 24.39013319630777, 30.763496391234863, 26.491827387963575, 30.58725645465236, 43.26307227534633, 46.88969573666973, 32.48714273975742, 8.787409451700027, 1.230859739645835, 0.161753780839424, 0.19281444800717218, 0.29901815157744194, 0.25462962296460906, 0.16644842892644868, 0.13995730768769019, 0.09610648852803054, 0.13215621903298364, 0.14950769683045728, 0.20214008227471383, 0.09424237444275811, 0.162502248741446, 0.25475788140489214, 0.20172939786026556, 0.17623690287432364, 0.10123114942783311, 0.18082458976536028, 0.11562194254609848, 0.16753765273719065, 0.21107672773782285, 0.1662304769119909, 0.09307603622155805, 0.09356706027662562, 0.18038343037328414, 0.16795152407740394, 0.0949246523481223, 0.14261497394932857, 0.19902686948978132, 0.213914041617705, 0.22128921603002857, 0.11327140859418339, 0.07481011757326704, 0.25596414812870566, 0.11639172301417398, 0.1073292859138981, 0.28295675052269814, 0.16162247336920232, 0.1648416514358213, 0.19554362091566288, 0.14311945816922572], [0.0427253057639445, 0.028637983055124362, 0.04067473353878145, 0.042133920360356576, 0.1264564865719407, 0.017014086929961078, 0.01728714364881237, 0.050469037415760185, 0.04901371550776305, 0.06978032900200737, 0.041107990733918645, 0.0443260541426078, 0.015922891400423984, 0.018286011219325087, 0.053924109276023605, 0.005876085901212308, 0.019724333636282433, 0.027257128723806916, 0.05837932424319368, 0.084084332019331, 0.04728205036371947, 0.006689681331702178, 0.031010461595630458, 0.04935174414347257, 0.06540684029459953, 0.05835516183006187, 0.07569717844167063, 0.07805634620449237, 0.08028306502608523, 0.05034366329651206, 0.1074503431276929, 0.02570630437994917, 0.03390404080311137, 0.013980116364696335, 0.0676764753617106, 0.02424337138842431, 0.05925441881822002, 0.0495628664840854, 0.0444705919512818, 0.022983828995136485, 0.012536018602399817, 0.0418421098091189, 0.04926624873112287, 0.010706932929855202, 0.04842872693834286, 0.03531280754794998, 0.04869398488212497, 0.6680108967327303, 4.843181381302496, 22.03158259391785, 35.28088815750615, 43.572723788599816, 32.38640254543674, 20.998942159837295, 29.712842472137947, 44.861465577156316, 25.04032292673665, 10.30311526790742, 9.706925788233358, 10.34604266766579, 5.3369592466662015, 1.4061780418119123, 0.14813181824020802, 0.2646880356534835, 0.2453871398803688, 3.9095776071471557, 4.286568616667102, 0.128821131863421, 3.936602982782549, 4.937828173560481, 3.4120769221936507, 4.858589922228168, 4.676418381352579, 8.070090807253315, 3.3613410640147428, 6.406723443538913, 5.573701252860408, 4.85114771512247, 2.255096127909999, 1.4704705918988874, 2.03140948568621, 3.0798558458205196, 5.9738658705065335, 16.204543786664164, 26.974784904910674, 51.8347337169032, 65.12781097042945, 64.55773761195522, 63.26679537373205, 39.01925210029849, 35.51925059287779, 39.981942945911044, 61.03356253716254, 44.34450111081524, 49.851653960443315, 56.25396228605702, 48.564567412099535, 38.658719601169715, 52.3515255989567, 55.61043862373599, 62.48842846962714, 47.87542658467447, 25.400955446304817, 13.493928101754959, 5.310526394074963, 1.0001381426568956, 0.9650274750686462, 2.244213266718772, 2.386123884108759, 7.36088558550804, 3.4881498207969055, 3.682967083108041, 3.2769804423855198, 4.10072255038446, 3.315340977522635, 4.074108533320889, 13.629918636814242, 9.085271300808076, 4.135109234240748, 1.2549207840235004, 2.1741935658839444, 0.40824286159007783, 0.7672198345103572, 2.259132246817312, 12.081073695613492, 12.134464998399059, 10.779073315282023, 19.19669347424661, 26.222860659322432, 34.98478058845767, 33.50218349887479, 34.3752521084201, 24.23092615219855, 8.459415954928245, 0.7770224504413143, 0.07385912666758222, 0.08674128581919978, 0.08759502952377643, 0.024577682582481254, 0.0634040949385493, 0.07338621293104465, 0.026394676514751008, 0.05102579564517064, 0.041152730268696626, 0.07323957604145812, 0.07246046462246487, 0.02873953567036698, 0.019095293095996304, 0.02531765648464282, 0.02456740168253741, 0.05191725768869923, 0.030454839091567747, 0.062393406631364945, 0.043847065328830676, 0.017191537791081977, 0.045774649798629746, 0.05531737806215402, 0.028768936209681056, 0.04724822375142286, 0.025606410345062617, 0.03501980572999005, 0.011448633402676113, 0.041772859291203564, 0.03292933564573046, 0.07249387371684275, 0.041542745630947814, 0.04527154453699628, 0.01558410816810905, 0.06674596964712105, 0.04922075076929985, 0.02280348998254105, 0.021188668568708727, 0.07085673616177614, 0.06203987620650761, 0.028984172442447276, 0.014862985774544219, 0.04595252009288919, 0.012339061227506928, 0.021311771237261353, 0.11275696523127057, 0.05814854408644381, 0.04135246854275465, 0.01441973687765459, 0.03099630046035013, 0.05924812157548243, 0.048090349732627796, 0.054629534528019934, 0.04961550438536271, 0.06386509983830395, 0.014879165551505022, 0.013335187160860629, 0.07165852378332807, 0.023254476367465915, 0.007430652584580164, 0.007996623978889998, 0.015740508848290532, 0.027633768190900167, 0.07851534778432501, 0.020026739183512908, 0.07571937200883705, 0.10697922203689815, 0.1334278483784968, 0.01658889281022693, 0.08155284043882163, 0.04127983957709324, 0.05434846069904105, 0.04741548755837064, 0.020910417773730813, 0.03659216672061913, 0.04501826437791029, 0.03712123853244609, 0.08042855278378533, 0.05072848841307625, 0.09329551275098517, 0.02551749051969138, 0.05896572624483417, 0.0042035766302668046, 0.061130434079396154, 0.054428378991301984, 0.03402510567778542, 0.06726851822027276, 0.07798130789230909, 0.1392168071000807, 1.178412134608915, 6.327399880655351, 27.040653267214378, 40.943343331736905, 47.8707471970589, 31.209713066777876, 25.740993561283236, 38.09623210660873, 47.819528887348795, 36.66217042553809, 18.06226557300937, 15.412176962821716, 11.838497654084238, 5.749791649080092, 1.2301119152576694, 0.19520485683554606, 0.17082534970775728, 0.20331296288678724, 1.9809842301953224, 1.6625823993836681, 0.46897040619965524, 3.4468955570651643, 4.2275604797947794, 3.5519525649086123, 5.594259865822331, 5.250441076294069, 8.584539563425126, 8.895116756039283, 6.79021014321235, 9.120586360654524, 5.146557102280279, 5.852891639355691, 2.338403102851683, 3.6908748265235656, 4.898130355342742, 8.697508727350543, 18.930123313780754, 32.462978978310865, 58.72694999940934, 71.98651452218333, 68.34987332743984, 64.69335748303321, 45.328545339645885, 39.856164301595385, 45.09529767497894, 61.32639100474697, 49.76623650520079, 54.95302584863479, 63.25946054150982, 53.822492860978656, 47.57798148739723, 55.7205395544729, 63.72843873116278, 66.11736220698204, 57.20070477454894, 32.928117167565134, 17.724486743250203, 5.503304514192767, 2.018036409731834, 1.937315747622521, 3.3986928145731654, 3.3214848801012966, 7.670666046680943, 6.76722260252122, 6.203250490850018, 6.247881179855717, 6.570230876245807, 4.795402499937243, 6.403117804758011, 5.951070525953847, 5.366722681830007, 2.541929497834175, 1.3533024081299383, 0.1902211790964488, 0.3596464418355496, 0.6371444175320288, 2.207299841027106, 8.56665551662445, 16.641490920897454, 15.556879082033712, 18.117467049629457, 24.57592606544495, 30.402271593770674, 33.95079674259309, 38.26140703693513, 28.97485048540177, 11.01847812052696, 1.293757641988416, 0.0868514109583151, 0.017575985609343456, 0.04724351231068854, 0.04091722334945395, 0.06367679925695544, 0.0804434378721541, 0.04506515661975549, 0.030704696752852013, 0.04984120154873498, 0.04733376895948764, 0.04562650754627201, 0.0547907117664093, 0.023461356496198044, 0.03292569672809013, 0.02888410986821738, 0.05663683810721963, 0.021287078308241985, 0.031028049059152126, 0.032578249041351585, 0.06974772429994999, 0.03854840287878629, 0.028505932479616136, 0.024099174488876617, 0.0456264692418758, 0.04952248215915696, 0.029477793535578157, 0.03955485088930976, 0.020264008104981437, 0.025887116451837847, 0.0764197908762482, 0.029526237105470032, 0.05949039688153614, 0.040414370896835486, 0.009560947749583472, 0.02899305714714912, 0.004839500949357547, 0.0064651342578262334, 0.04500897939226801, 0.04770692655696504, 0.06934706797643055, 0.06794710358184192, 0.12993347620771778, 0.07345031150766919, 0.09699211681201574, 0.24960160405645448, 0.16505526739262766, 0.0849203484493398, 0.15038377965890593, 0.18484587721045942, 0.15560332054813064, 0.12763806228195468, 0.12103399366981561, 0.0989257840199336, 0.13691724097776797, 0.06755578587011946, 0.15136818731984786, 0.11714206783161049, 0.1903522873838102, 0.11051716928881024, 0.11928331422349138, 0.1416998053149831, 0.12711683904091198, 0.15640336148921521, 0.1499546325254825, 0.10913834126005251, 0.2662966977204046, 0.25463500090183755, 0.18313397713486226, 0.13755677117695733, 0.14202409033333102, 0.23262604560342529, 0.21031227924170035, 0.18004354780479787, 0.13037773059500804, 0.17479429802586957, 0.1698173771822645, 0.15399395368031918, 0.14500670044893219, 0.19451407535422235, 0.11205467710932417, 0.11639354630343376, 0.07075842409845322, 0.16307062469422817, 0.25386062390621633, 0.10014191029533263, 0.18098603513452316, 0.1401616080153373, 0.22650201534551961, 1.1853841475902067, 6.63976812554944, 30.471134685700942, 46.066507908605764, 55.39105653762818, 42.185071591408025, 29.876411191878784, 40.398228014669115, 54.18257820990778, 34.645287682933194, 19.20058838782772, 16.13143865139254, 13.882419255472, 7.5001052118116815, 1.9194792595601853, 0.4661139094781491, 0.8243979405491584, 1.0775157809257507, 7.5115913825650376, 9.888658023649647, 3.4276185785570457, 9.873363721755243, 12.013168642597815, 10.231077997915207, 13.122032496236987, 15.26137653858431, 16.821204116267545, 13.345302631778102, 14.29664311870452, 12.998823984976738, 10.538311369957464, 7.061410661666625, 3.556287764541565, 3.3638839856270826, 3.8255557802415665, 7.388869245206156, 19.447262325594505, 34.417315606148016, 61.59948995036464, 78.28784142771076, 71.97068383616786, 70.74566487343081, 48.56843879145961, 45.105107522779896, 49.15870058921076, 64.74197526131907, 53.90856535203996, 59.5097021133669, 65.83561051276423, 61.544557156101355, 55.62446501947219, 62.50477298613518, 63.89153088292768, 69.26796682419317, 63.12269141597133, 40.92775583267212, 20.036410170216715, 7.840959179785944, 2.3576197749184025, 2.591197654124229, 5.328897305073277, 6.345611935661686, 14.293583669970113, 11.776677177798364, 9.223433848350279, 8.802672374633051, 12.564758812227558, 11.273955818145506, 12.131735028759127, 22.75025494637028, 17.64923018793906, 7.640965369439895, 3.281411494939558, 3.8112773722217934, 1.1523101094268984, 1.3674150960099314, 3.6116689347451736, 14.030709362799122, 17.773579128326908, 19.38565561848302, 29.641714211433168, 36.78898849794942, 42.096127925380586, 42.984893860355506, 44.53999988494381, 33.68833134251256, 12.244899330600617, 1.3586400184900531, 0.14001286438395902, 0.2814792120648969, 0.1566277333204785, 0.08121801405063561, 0.1606270800074262, 0.14878795722559576, 0.10412170641845274, 0.1637605634788352, 0.17564365970751933, 0.16544712136589712, 0.18493227660655978, 0.12346787032701316, 0.16965738738015776, 0.20689402556707784, 0.12420787295747189, 0.1877904740432578, 0.15967691647669963, 0.2526785042737761, 0.10980840772390367, 0.12099483891600564, 0.22745754149171615, 0.12131427459779287, 0.19051990742164274, 0.16858555376529696, 0.13755410519098082, 0.18405029490109415, 0.12098021429753113, 0.1797857592182775, 0.08811094377550387, 0.2031124317117276, 0.09182448604054029, 0.12295765576944237, 0.20608240137657813, 0.2922031559771107, 0.1423041261131725, 0.16398925604599138, 0.19124223640368831, 0.25186657364810666, 0.1180855051103619, 0.13487400787491954, 0.18702820123684022], [0.027097431950331218, 0.021946953887480403, 0.0016822713857231242, 0.0829287037073124, 0.05881542362452996, 0.02524555611964916, 0.044124247431154215, 0.040239270010422316, 0.02811562025829429, 0.05503161194463892, 0.07445770946721877, 0.03774550059930452, 0.02936783119014675, 0.02569418295376724, 0.04696521171999555, 0.0701293663211888, 0.031958089375327674, 0.015558685540341803, 0.06542281322782079, 0.07565206352380976, 0.06854984623890731, 0.059463323334292065, 0.012391800635434207, 0.041183829607982794, 0.03848553770371983, 0.032226691292899276, 0.026416891149335334, 0.011869052879422182, 0.02431315816788664, 0.026351894334619565, 0.042886318293430155, 0.045069090481246674, 0.03291634279453466, 0.07340506635486119, 0.04638329516315172, 0.006337430273678395, 0.04255303940285118, 0.039207774755214496, 0.05288346310056025, 0.01024996531346152, 0.04817438574748174, 0.051646575842413216, 0.055930558667187734, 0.01678107171169212, 0.07188483381703978, 0.07551447413260899, 0.002531781975713168, 0.06608528776034232, 0.3166921064257622, 4.345770910862954, 15.575273036956789, 30.786869795091693, 43.46163049820931, 35.138698316389515, 20.887860636557303, 21.001350495123095, 12.145353497997409, 20.950141991338423, 21.23627301185362, 17.784459783184914, 10.768942813719473, 6.345413855967983, 1.8887597466668777, 0.7776923177223053, 0.11720239725564757, 1.7255801995915754, 1.3472669836013549, 0.7504548889494712, 2.1904461518410714, 1.6018734247453752, 2.6344035421648337, 3.516439670516599, 3.3362356885786983, 6.309713423252107, 4.830220399364348, 5.205767241216475, 8.727129486299331, 3.071892208630039, 4.188629484945729, 1.3755100100271165, 0.5720765864656818, 0.7226225469381579, 1.4967094097406635, 2.6846236086660817, 6.093575137276804, 15.251806935956402, 33.11403359136274, 44.057438527384114, 38.01171679650584, 34.275549381009995, 32.64439448233574, 39.431979579310266, 55.94780168225689, 49.965324248037035, 46.17790322149954, 41.95745645030853, 51.69359114862258, 55.11691816391484, 50.101940401138805, 32.85351957044294, 41.23466560917516, 28.775794121526904, 15.752177815283499, 12.263186400936497, 3.0376330018043523, 1.6957607480787462, 1.9911268665905923, 3.182486132267983, 2.6015644784896605, 6.016350042435431, 7.37309935592836, 3.206341252211602, 3.788402599673118, 4.30836767919602, 2.331786064370986, 5.599559968517673, 6.746484541123913, 3.4646854669817033, 2.2285745316936127, 1.4803221148829309, 0.14640134819332631, 1.098941850566095, 2.5863309733329283, 14.401146827205537, 15.940833034053927, 9.274998307228088, 15.519990171155623, 14.957859612280323, 20.193383424512803, 30.536930484156457, 36.75445202858218, 23.97852751516527, 11.339914394963174, 1.3057629139192644, 0.10295629516364106, 0.039534017128208955, 0.020383695936611584, 0.0899775782900472, 0.029323248703393246, 0.0030997794331802477, 0.03755322402162898, 0.049428134600842194, 0.024593383554489385, 0.03862041131322903, 0.03833705071179617, 0.02988469730612011, 0.10180070515601866, 0.05490097097091137, 0.04215508353926482, 0.06070456580228864, 0.028445624122996966, 0.022706078072529168, 0.04841712836716925, 0.1008966831009715, 0.024206189311019356, 0.06464466707961214, 0.038813936614221146, 0.0915315263574162, 0.023128186773148277, 0.08571635210706342, 0.04118761408232874, 0.010333348238360017, 0.002454124839841238, 0.046519463461252956, 0.05877995758407539, 0.06221768138329349, 0.02803944430554346, 0.08568357120478347, 0.0930764728916749, 0.09694985174123319, 0.04775490664366273, 0.021364606406179168, 0.03814254481826098, 0.04175464938124342, 0.06687594412435448, 0.04364237046590255, 0.01726567978039384, 0.01167287691421206, 0.03639245909007807, 0.03842177620578197, 0.04661601352235002, 0.021855818152788187, 0.017999151511298075, 0.06063405123929824, 0.035377373438208334, 0.020697912644414652, 0.07922174979842479, 0.021669848393949292, 0.004630928245117708, 0.01358624853779592, 0.032089913954898235, 0.07402631003529796, 0.054144309758539164, 0.03920350381503663, 0.012785713470000173, 0.03146981366068846, 0.007201251864898951, 0.08048441591522387, 0.035574330813101226, 0.05192734706666201, 0.041249287990672935, 0.061909457398278106, 0.020487136958587556, 0.005555926266336633, 0.025380979397244034, 0.025236631195331295, 0.07219188185709138, 0.044490981381386525, 0.014181201038281284, 0.035417252145106756, 0.05131823821894584, 0.0649878591479313, 0.004326428405024231, 0.11033245016850772, 0.030883043936844316, 0.047081208923050476, 0.056628629475110964, 0.007744292811220212, 0.024272591897076177, 0.04476005061259193, 0.016195941416005936, 0.016182879616896954, 0.042971924788528876, 0.08871521094753858, 0.545503263992648, 6.692316118747958, 20.786012372662945, 36.94267872841128, 48.119296027768044, 32.97096121695734, 22.0300450248103, 26.311172823752127, 14.934118486219838, 20.09793450755458, 19.01667041163291, 21.38251466135825, 14.694556786168008, 9.13886558625006, 2.2119397597928203, 0.6083594298651142, 0.05885613353682622, 0.36107577804115515, 0.48600838549675485, 0.5411985240155651, 1.0263746315913818, 1.8577260764375811, 1.5846309306160098, 3.314899220581978, 4.391307177082185, 7.716352833855537, 9.231750253708132, 6.382077230561165, 9.818353460681054, 6.94762368356028, 7.480144270004765, 4.064892924601033, 3.0648966614277136, 2.42120924015199, 2.410347951996711, 4.456975008210828, 9.424074849774762, 23.692947587659283, 42.10478851872106, 54.705206578777684, 50.599257715286754, 37.13380405979772, 38.5726196535172, 43.9601755142212, 60.347379176847404, 54.47030367389802, 53.93835967586887, 50.32193045462332, 59.59880659657141, 56.938910099767874, 57.54681864092427, 38.90474242548789, 52.217125585002286, 38.17855873415547, 26.352394973078084, 15.1353007747281, 4.579236267074462, 2.9509130745164813, 3.523107944957672, 4.286725511473994, 5.145552485219894, 7.614644304398568, 5.263255459647025, 6.0612915792772855, 6.609196682130137, 5.062360975050158, 5.165903702858956, 2.284788960410703, 4.199306666851044, 3.175571729098597, 0.5439718848755283, 0.29661435153215165, 0.2589968603945548, 1.2060409423805054, 3.5050106192788775, 12.47392946673978, 20.383600727204357, 17.43728099330779, 14.239072530500351, 18.757576288715487, 24.501506936165597, 34.35245921534877, 41.7898339609946, 30.475859180573497, 13.511958256844553, 1.9404912739992144, 0.06913738971155498, 0.04076247741918891, 0.0300734403032449, 0.09887736726311908, 0.032382877468461954, 0.020281021002559893, 0.07209983639298909, 0.08437946739216005, 0.06975114105209228, 0.021657841880956007, 0.05293434283005134, 0.006845578309073444, 0.04800899119506921, 0.008661182270565582, 0.010243045624285456, 0.007727768294693483, 0.014794220764850898, 0.04783095236146643, 0.018235114252855702, 0.06910315324221888, 0.03480346633061286, 0.03990221430637664, 0.03223689941449031, 0.09825492082464118, 0.007938750345455183, 0.07882540654991904, 0.03178535570060054, 0.0427486599543162, 0.017529221687225566, 0.03454578499640188, 0.03303481829202464, 0.01556501342659636, 0.016405194502083525, 0.04940531284157788, 0.08494995774761324, 0.06985660837662798, 0.0384657190091187, 0.04882709648940833, 0.044040127146628597, 0.06876855668041014, 0.008204976911656559, 0.01953149015354293, 0.10588995992175995, 0.22016213215406866, 0.1449055308776517, 0.1532371354199225, 0.18210475333034995, 0.16364981780850119, 0.10404375697215719, 0.12098499468617863, 0.10333200766434593, 0.2781402331686789, 0.18821061198269168, 0.15441946955698152, 0.09895744643384412, 0.06938915684699051, 0.1928552958152948, 0.17494828169864995, 0.13440251140104187, 0.09661301820268554, 0.17873271007932004, 0.08053617281538826, 0.11863074520783079, 0.1876218274476067, 0.18745992242568926, 0.0956608398607181, 0.1533177431913153, 0.16088088493674033, 0.14913936175646322, 0.16637894475171644, 0.08574618357083491, 0.08788787429371188, 0.21869761719098016, 0.09309596216846859, 0.16276935295712563, 0.21110844377788807, 0.1496223342274466, 0.22566230637171578, 0.12395195362548675, 0.19588013269728233, 0.1432135031228104, 0.13687502953314012, 0.3304119137746673, 0.1254845967876815, 0.1338975981719071, 0.15770689073589542, 0.14747328906049653, 0.2809097942325377, 0.16430612533323227, 0.14284588817146518, 0.5338597694231618, 7.119012628832172, 23.105466750360307, 41.86957574659779, 57.14459919160413, 45.08902188270323, 30.413736681784357, 27.96428122828084, 19.728345255697928, 32.44461051879391, 29.496388435363773, 24.160513724050215, 14.841258333575341, 8.755410755834273, 2.9805563870937597, 1.0893544746983437, 0.46115137576576204, 2.474109511221609, 4.010167280512472, 2.488128552513738, 5.367531180381776, 6.7246344877827555, 8.261612788323434, 10.545873699649688, 10.248793382798473, 13.458969977594192, 12.999211319031255, 12.590796486023935, 17.891917036425685, 10.84960831749824, 13.537114377944702, 5.720284638866302, 3.3739848242652033, 2.1136883093464762, 2.539853338272341, 3.554266763310279, 7.9230882179352555, 19.29187959240329, 42.46065339734478, 57.673515119860255, 58.663458593430065, 44.23622408220845, 45.40355674682125, 51.48809425292477, 65.12044083687567, 61.17454821063627, 57.3510649127345, 56.003216928051366, 63.00041152584938, 60.31432144103512, 57.36349490381057, 44.913468360900886, 52.40113965926632, 42.96572131495322, 33.419190068398755, 17.746536347173876, 6.639063569807238, 3.9556860491152737, 5.277207330349953, 8.840254564439098, 6.6669923163229425, 11.477437596167288, 11.576297994582884, 11.71542936755765, 13.60800729643914, 12.612615650699986, 11.148937133050735, 12.202913299683603, 14.67583727452063, 7.650505063995239, 6.552300251299336, 2.7845472145465116, 0.7002602565673091, 1.9611137480505052, 4.436344811993261, 16.896429292617306, 21.67052645837107, 17.524863596885435, 22.272306296133227, 23.43269636554103, 31.410265814873483, 42.37445146806779, 49.03538519336332, 34.841927866781916, 15.576200677502541, 2.194299880535372, 0.176309451400753, 0.09698804122425857, 0.12315903730209797, 0.19113311483975381, 0.14934781428065994, 0.1632654714968897, 0.0936457145238115, 0.1618848584832684, 0.19543537269196204, 0.1385012809788027, 0.16430119172699992, 0.14195452954980636, 0.24457810506705316, 0.14164530582004978, 0.15220474001140366, 0.21141785136874647, 0.09517904716513811, 0.1243220047364312, 0.11530936335123355, 0.18566638802088078, 0.06771383746977776, 0.17997171940101733, 0.20155583298014057, 0.2320245899740727, 0.13356304757537382, 0.16278905673853813, 0.11988352879040665, 0.066536812322034, 0.10518258497599633, 0.11920446845432443, 0.21973594212003295, 0.1318088594463564, 0.12978831786782513, 0.26476231553862173, 0.14346943777655402, 0.16718277016714697, 0.14162031603195976, 0.12961801652225757, 0.14458498436837428, 0.30125209460816077, 0.20036344776951498, 0.1319024447471865], [0.04096575118901749, 0.04867272594222619, 0.015262387629087656, 0.03105056438324673, 0.08026257983498997, 0.08163835883380906, 0.041635844465946, 0.0502867927594531, 0.007530895189472264, 0.11170423784924131, 0.07216761985252942, 0.05596723129612304, 0.009302524267695844, 0.02803152104118659, 0.07422722425431975, 0.11422382442340737, 0.0814912852741057, 0.13642769547239428, 0.031888767994279345, 0.07985200267285109, 0.018757777739196055, 0.017203195734069716, 0.043646744827950196, 0.04629547850439145, 0.03173089834050306, 0.020020120183847124, 0.011028805728851548, 0.023339236335408305, 0.03655784215117174, 0.05176219766238525, 0.03566078000491665, 0.026734806146592866, 0.023406405009389408, 0.056597625896815336, 0.05762795669837825, 0.06470066810687704, 0.058013069097914045, 0.04055055834713482, 0.052205318239547556, 0.04903071116836322, 0.03262420282548955, 0.014873492670425726, 0.03266264511752994, 0.04651726095847065, 0.05363476552790212, 0.04896192030320245, 0.030474280487866174, 0.011440562666393818, 0.013002514437351738, 0.19583718580824716, 2.3938404119783834, 19.15723443031311, 30.58065118328218, 39.71969327618999, 44.56363608760219, 28.84537304601362, 29.453614988634666, 23.274420884347734, 21.096226746036162, 16.620494473365046, 19.54196991459016, 13.741759138722575, 6.055779668592638, 3.8371177017688756, 0.6858604389332956, 1.2151028432192341, 0.0847437038957592, 0.5415349898319091, 0.4225197987210366, 1.83612423558389, 0.42398333309158204, 2.733753746555698, 1.2632216224747321, 6.319929726662175, 9.019214664736102, 3.6756837319943214, 7.568376025845928, 4.205406442765267, 5.921033505470523, 2.5367227965785615, 2.1133139681431556, 0.43759248670070405, 0.33683375305225777, 0.7627208146356768, 1.878324035675295, 4.685807064656289, 7.992660278274168, 3.234420519682669, 13.338274725021856, 23.43302780582059, 22.027177772214337, 24.378501407561767, 33.89975493954074, 38.20552110671997, 33.485262393951416, 33.75757686553463, 41.91773460757348, 36.92411807275588, 30.952150629412746, 22.419030397169053, 14.915172457695009, 7.0406667167140595, 1.8498944515182127, 1.6830114515558368, 1.226305745301708, 3.3299929913013213, 3.565284210828043, 2.3001496974499, 3.8619019331470614, 6.082373828657213, 3.559922575950623, 5.862436236873751, 5.2005485277022085, 4.176023967804448, 3.4648899205269355, 1.7624746263027193, 1.7470996706716477, 2.1959006978619486, 0.5843989575101484, 0.589136261372797, 1.1668518065444886, 4.065467306683141, 8.836897015571594, 31.72769342699359, 12.758682754731948, 19.438997891641435, 24.66630728014054, 16.554027949610067, 30.174442683496785, 33.72358168325117, 25.541790108526907, 10.809763900695309, 1.3380928049164436, 0.10629458458072717, 0.0634239251244693, 0.07380888662150792, 0.03381305254034458, 0.05965805522376492, 0.08900197297935525, 0.040658649522811174, 0.07317606735253528, 0.04589081937146764, 0.01795245653709337, 0.0424307870918945, 0.050783344138894355, 0.018445903345221476, 0.02895695142327778, 0.09151435066615382, 0.02587319471903386, 0.051186310217505505, 0.017311993625856215, 0.039777223231090654, 0.04321359488512239, 0.0367342492174958, 0.02054376426273056, 0.040915664360528035, 0.029388201468053366, 0.051370071727902665, 0.07514530402277747, 0.005828067988923361, 0.04417158017355589, 0.07333006634707413, 0.09387918747961523, 0.100583927705884, 0.05128625404810713, 0.01215483048825615, 0.009278953657485545, 0.013013937765912665, 0.036592097772705945, 0.04759902690326975, 0.014670419998677268, 0.05540750064556638, 0.05871469838424556, 0.03638355331795831, 0.05301688880389256, 0.04645280615096131, 0.07333961180261067, 0.04565197996975434, 0.06498372993401944, 0.06693473371166377, 0.04814293400775041, 0.06308646339382376, 0.04970959147378322, 0.0274929229260212, 0.054713888469362454, 0.008183724675027114, 0.01703364706988777, 0.014770427989142557, 0.046992526584935766, 0.025009317586438793, 0.019671362486758062, 0.08307781506089434, 0.08787117357696257, 0.09243122001569118, 0.0696635005935546, 0.027041268129382404, 0.032209890984719804, 0.035227748805717114, 0.0703442769665872, 0.047186561334397525, 0.028590355368871844, 0.04235317089384602, 0.015430281543353153, 0.010080403242740902, 0.04199506692408074, 0.11355916654030163, 0.047608445954298785, 0.030672999864984906, 0.04036858182160124, 0.11997207323269499, 0.0419936458309812, 0.034326603410825614, 0.0206593879979224, 0.03748961957171559, 0.032660660949806054, 0.08860559142645329, 0.02172952472803093, 0.012312048009686894, 0.05774685354422658, 0.03333805504465296, 0.02963993604475212, 0.019224334861181917, 0.0484348020155824, 0.09006547155759989, 0.025335571450752117, 0.38996746643416347, 3.9935280959452357, 22.597470783418228, 36.29601324758222, 44.91604928047427, 43.890333790932935, 23.634243434475316, 24.106171246497865, 22.88789091571685, 18.90307661025755, 20.462828682314967, 22.82531734435789, 16.58128449993749, 7.749807709647764, 4.544392872241236, 1.024784723356847, 0.3484187797913629, 0.08603042517338069, 0.20138718638448946, 0.4479263079983573, 0.8158467445642719, 0.7538186278074019, 1.2624951259743784, 2.148173542753343, 6.093154463075823, 4.651557908904168, 5.820729674831514, 7.162994165574351, 4.207994716782724, 6.103417834927959, 3.772776122054746, 3.0960375839664094, 3.319516830867337, 1.3725124611969919, 1.06254237794107, 2.212754632196119, 6.067859097834557, 17.9676168195663, 10.337777253120176, 21.755057457954656, 30.606436844794985, 26.40143244497238, 31.247161895998065, 39.093012271388886, 45.40399997465072, 39.029030569138065, 40.31906281748126, 44.596721280005674, 42.21861962349185, 40.41151700481292, 34.25804384293095, 20.219779014587402, 8.87050094143037, 3.3205454724450267, 3.9703736093736466, 3.1187262890800356, 3.5884401682884466, 3.024893633780941, 2.727829496706686, 5.789762562321079, 7.7369060535584735, 6.8860763022976545, 6.648094827128995, 5.823842565859518, 3.149447027714022, 2.8186095674191756, 2.302915213569518, 1.0125844973710276, 0.6181332408901185, 0.26888383792773374, 0.39684108308246063, 1.1273502294094333, 4.9018821024125625, 9.92403191904868, 30.594283380816062, 18.751575062351844, 19.178611347752234, 18.56100670752987, 17.046754129471317, 31.39614332106806, 38.0433036435035, 29.58207065059293, 12.831198553885184, 2.005148359364079, 0.028992329363621054, 0.08918114562308596, 0.0754520686102971, 0.046447868714289325, 0.05974835017696024, 0.04571946848544382, 0.048175960058166135, 0.06909122525323784, 0.05470748397431547, 0.029205499074211525, 0.02959325447708609, 0.024083758884620284, 0.0160970701084983, 0.03683383298677303, 0.07718041659362855, 0.04513251107005824, 0.060729915651703076, 0.03516176565279884, 0.03034292130670961, 0.16073742731203958, 0.05385066442672284, 0.0075975520209589555, 0.047561036603104685, 0.04005783740731497, 0.009735373521013366, 0.05105313732318821, 0.05615727089705968, 0.03489492190701347, 0.12355662161304105, 0.002867963142512787, 0.040516329538677974, 0.024650303887263424, 0.008308481135886283, 0.0755260727037826, 0.017042231085079334, 0.07502383312150356, 0.06562137555691504, 0.017165008166264144, 0.039440240305397785, 0.020860828902392138, 0.018608547641985843, 0.02756339343895595, 0.06250071256691891, 0.1397164343225379, 0.23989180733840312, 0.17043835273192776, 0.18230315478098008, 0.2068458386366406, 0.17008645790478877, 0.16434599254881183, 0.13511946244585898, 0.13325914049581175, 0.17359324069994111, 0.20361801909823574, 0.12889118294321722, 0.21175420993278105, 0.07020527797360575, 0.14579589358500897, 0.1965617670887901, 0.15481743691188676, 0.2578554506744108, 0.2580580962521415, 0.21911914941043625, 0.09908300058375444, 0.15208006686260625, 0.11410961603565563, 0.16033763666787457, 0.08761376037352508, 0.09304397544192691, 0.1538292141330819, 0.10746841514182669, 0.2596159513679243, 0.17759320025722827, 0.12217307448266976, 0.12980725556131334, 0.10788154337675342, 0.26855343952775, 0.19361865646656484, 0.14833676208171154, 0.1341197943134654, 0.0982526838479023, 0.1609935611486435, 0.18826419217211587, 0.07801018940705447, 0.19983475517121055, 0.12495593483289405, 0.11784677679139761, 0.18813484588698035, 0.12190995392419639, 0.20102798307855285, 0.2453756638832631, 0.2008516296383835, 0.5177392570241806, 4.346061166255705, 26.657380827011604, 42.6614865949077, 53.433950716449374, 53.888016054707194, 40.12468976359214, 38.89710949313256, 34.53823443382017, 30.95804987415191, 25.877701890084055, 27.24202971304617, 18.454569270533902, 9.144956046535123, 5.150505948451258, 1.2277962459671883, 1.8098514647253099, 0.48068551466830317, 1.3258367464427026, 1.8487991296475934, 4.21699361455056, 2.806523274029455, 6.874098364383944, 6.298324331160515, 14.955954320969122, 20.341447014962476, 10.658081923761676, 18.17014644222875, 9.312516758518836, 14.815589362575164, 7.107095977952404, 6.250087022781373, 3.555994567371184, 1.0716910612198616, 1.596510809275412, 3.184488011944679, 7.782553126735072, 17.848410106474354, 8.186219440352533, 21.739162052831343, 30.72287436454527, 31.473041388296316, 34.03029534124559, 42.48810998855099, 46.55129325005316, 41.73245753011396, 40.87751419313493, 45.08651548816312, 44.11446978968959, 47.303494022738555, 45.62536285769555, 28.082852517404866, 8.22033670640761, 5.900407231623127, 3.029282520855627, 2.836357802152634, 7.819091966075282, 7.835634562277026, 7.10829230085496, 8.304719636517188, 14.205743170553639, 11.681848975919909, 14.879097438627674, 11.917074495746244, 10.503174777953856, 9.359562646958137, 7.100379409328585, 4.535433198175123, 4.052224159240723, 1.1577419792452168, 1.1499977496362503, 1.9199049592979494, 5.958509791281916, 12.000380735243521, 37.331005142581084, 20.629547065304173, 29.09075260162354, 33.01819439857237, 25.288218682812108, 39.8361837479376, 47.53728689685945, 35.962231313028646, 15.492799320528585, 2.7248894351143993, 0.34693532713478614, 0.1559043624588559, 0.20382435721976144, 0.1425289116319149, 0.2501230954282707, 0.15848287651615758, 0.15025311570254066, 0.192198176237364, 0.19055088801730066, 0.14943767639417804, 0.1957941163451441, 0.11964884541568258, 0.12323520942440919, 0.17327073300557752, 0.1626960536645305, 0.18285315994533802, 0.20084194628702057, 0.12443227543225213, 0.15031040375751836, 0.29743293180100383, 0.11671667452901603, 0.13843794082922323, 0.20370745220251624, 0.115443566633809, 0.17043695845190557, 0.17164756123337055, 0.1551229527760898, 0.14874876416738958, 0.22063657040557555, 0.16872643733457213, 0.21944125873907921, 0.15016048035073667, 0.1743207790798718, 0.17523725006368854, 0.14491639400441803, 0.19035191966160653, 0.21514747381931354, 0.06564710078941238, 0.21176323444852907, 0.21747708591001652, 0.13563814993587234, 0.16882633519989831, 0.17869229128043498], [0.02151622669771314, 0.014526485484243642, 0.020971049802497994, 0.031445268203594515, 0.053318447823966705, 0.06617347214130626, 0.044408427746666056, 0.021167859705465458, 0.06914930237877755, 0.006621472693363866, 0.0849272049362621, 0.05236209813325156, 0.005663423245066718, 0.03504984403750108, 0.05978131877078165, 0.10882819056390755, 0.06964325288971586, 0.02601527913113035, 0.0382639812455783, 0.021364552780024467, 0.06390666010819616, 0.07693408868245541, 0.0508217059917027, 0.04655456944038311, 0.050741163337783474, 0.030958942182722594, 0.06278967710151788, 0.01249465847297782, 0.0473673542540881, 0.09102511925682907, 0.047487890528094386, 0.024639377558243372, 0.0603574245507198, 0.05206101025725084, 0.04294557136393363, 0.053224337752908475, 0.028249499868721734, 0.00928717090808336, 0.03260755190445531, 0.09123281335398074, 0.04758688824010953, 0.014037809488663991, 0.0848189260690443, 0.010368650527520767, 0.027557260905122085, 0.023722816559095538, 0.01618027683317421, 0.12701050603702185, 0.014800626217507789, 0.021875585136454434, 0.11486052009727686, 3.083150881913401, 14.302828696466262, 30.616442811104562, 34.62550324778403, 43.59568142121838, 30.47377444082691, 23.837381024514478, 26.69664767480666, 20.268504658053, 21.620865329619377, 24.733407266678352, 18.737944826003044, 9.736052328540433, 5.958250914850543, 2.0666112870939317, 1.047181886050009, 0.3201434857422306, 0.27834346097323204, 0.27969235794678815, 0.11656911067304113, 0.47764080546555987, 2.2067205559822822, 4.449741177020535, 4.606219722378639, 5.2029588241730975, 6.836202384964113, 4.755189870634387, 4.495924144021926, 2.6077137743273093, 3.928168170875119, 5.514032686910322, 1.1357780545949936, 0.3154686640106863, 0.25790527703300603, 0.6403635189898553, 1.2940288984006452, 1.4354093829470298, 3.4966375847016615, 6.955485584274416, 9.597353396877166, 12.987115710012375, 19.310397101986794, 17.932019349067442, 17.46209979057312, 22.674596348116477, 17.643934988206436, 16.248903832127972, 24.961528393530077, 17.71755591515572, 11.86213875970533, 7.2736741362079504, 0.4073000525034243, 1.7225839990761973, 1.6793551896848988, 1.7367799147482843, 2.0951948242802776, 1.2848200312545224, 5.104421040704174, 4.148336447054341, 3.929507415140829, 3.8364288355073626, 3.6422744537553484, 1.8556654837823685, 2.267522441764032, 0.7503786478792468, 0.9366313536320964, 0.8337948363154166, 0.6100756506766043, 1.8481412746252555, 4.878242957976557, 8.638588843807097, 24.42784678551459, 44.31957444837017, 19.761873675930886, 19.168995657274802, 23.32511163526966, 36.10660983670142, 33.613233643193404, 23.63926995185114, 10.093829362623154, 1.6803211959138995, 0.07330420321875042, 0.07258838598406123, 0.06455546380170891, 0.0743873059869774, 0.08545336178353719, 0.07933492396747874, 0.05389419737302008, 0.02270691119314682, 0.02546862177100153, 0.018967687745668718, 0.053963742834786256, 0.11538489962056761, 0.10107433122973289, 0.10648144108633842, 0.028979340342864878, 0.025716221388128978, 0.05253649804921401, 0.03739405776404085, 0.029530808735158176, 0.028149538801141807, 0.019160745733027017, 0.06255268780214172, 0.055548606380339594, 0.040607570610459776, 0.03957300717311521, 0.0574466658215369, 0.026801689452822172, 0.0267068209547189, 0.03875207884477512, 0.05987429120127232, 0.06099845245180111, 0.03241719054659048, 0.008675070487022882, 0.11934311504686072, 0.038337039220477306, 0.02009100821470061, 0.06985341378998372, 0.060303147221284534, 0.05552971465212684, 0.05902343564817022, 0.0266136301891698, 0.031236128115485755, 0.046010436339964794, 0.062440325686287504, 0.022210763925085628, 0.01848235572387855, 0.04938927479088307, 0.09443925137841895, 0.017130287146315943, 0.06266507290063367, 0.014241846473587137, 0.02992708495097055, 0.055566463889854575, 0.05248479860564394, 0.04863122695936792, 0.0328378877302091, 0.03903563096818905, 0.03157292526485699, 0.02734621708852149, 0.02490283711062324, 0.02950967045410747, 0.08295382373034954, 0.04003928658822852, 0.0055445216111688605, 0.028024769891353867, 0.04921562947152604, 0.08288768735984642, 0.035735596151601885, 0.07246991048657125, 0.018759627841533195, 0.06358725123948629, 0.026682610661091826, 0.0912211534957732, 0.022404921248615272, 0.054314450225642616, 0.10229118528865999, 0.04417887333059504, 0.03900361998427299, 0.06596173309991438, 0.006293507101344726, 0.04060778511507858, 0.0685028620665112, 0.02888557692659238, 0.0472465843232649, 0.02861353144380114, 0.03776190637220298, 0.01527616955084546, 0.003751771010067915, 0.01981450984584949, 0.06934945050987505, 0.03604383162793613, 0.057351877762665676, 0.008228186502932541, 0.04158276989455185, 0.1398413526194711, 4.357988603653447, 17.60324432003883, 36.43253134142968, 41.26152600011518, 47.094121825310495, 32.36072671028876, 24.963266003516413, 25.572184554992187, 21.85232243230266, 30.17685886352293, 25.659855411898707, 21.921571877694902, 13.923037359791419, 6.412487856803402, 2.718573928840699, 0.8130477044370867, 0.2797119085106158, 0.11388894440906663, 0.26839954778552055, 0.36095994554700395, 0.9456095363824599, 0.8526917739260582, 2.430302029655826, 2.0502434815129926, 3.4071604763307883, 3.3878214753443197, 3.2037478300832936, 4.2842936419671585, 5.3902171888659085, 4.683664960245933, 5.85283721646955, 4.530124760443165, 2.5381588743579004, 0.47441597367005967, 1.1366205061635664, 1.8683865882696646, 2.1266029582869623, 6.300872400883706, 9.979199074929761, 12.78929195096416, 16.17793638860026, 24.52109525280614, 23.610171848727813, 22.302496779349543, 27.49307513237, 27.5366565873546, 23.289472979883996, 31.253119976289813, 26.441117025190785, 19.267441265044674, 9.544579867393741, 1.402491381572139, 3.987014509977833, 5.340931627058215, 5.993350734633784, 5.16192396802287, 5.282152948840972, 7.04531668655334, 5.798230959523109, 4.994442193738876, 4.4178876088511565, 3.540546802743789, 1.2092327711082276, 2.3388210804231706, 0.7167011775797414, 0.8336001274085815, 0.417326825761026, 0.840608544888035, 1.753945677511154, 6.8750804278158375, 10.83343638527778, 21.41503111008675, 49.20293315764397, 22.290443335810018, 19.031189064825735, 26.173842799279, 34.74571604882517, 38.9919759381202, 28.77999890235163, 14.073936823875675, 2.3659611853861042, 0.1521226000641623, 0.05981924395347315, 0.040410191887208534, 0.08372689837649946, 0.03486624723600765, 0.023893487542086554, 0.05575977085578827, 0.0659292739545626, 0.023680928786615693, 0.04970321762225321, 0.05750327205826199, 0.05913088714042979, 0.06354796242028957, 0.06315413960105469, 0.06544083161579986, 0.02051482146095124, 0.08873652351359207, 0.02035981123035233, 0.030252925127804763, 0.03184161145210026, 0.024320857351525657, 0.035119332042672945, 0.03494657538530808, 0.04916691777086066, 0.03750449699920513, 0.11318471042379258, 0.051467541094508865, 0.061378715514776215, 0.04674498442440264, 0.06320698434607157, 0.03693528218014586, 0.0209290643538078, 0.01332059414351299, 0.08864918949022409, 0.0712363863544118, 0.030790368365424297, 0.017309417655210824, 0.013425467749907365, 0.12044972905348386, 0.06301384974992083, 0.009587852757484203, 0.026815940603433598, 0.09053809418072624, 0.04580245495984151, 0.073134284917145, 0.15846251389913021, 0.09740781910236805, 0.1381299121966285, 0.1684955231124355, 0.12982104514395038, 0.11364106900028645, 0.2037788362753007, 0.1910137736629094, 0.15341595566320806, 0.272137260124568, 0.14389544394948792, 0.10917425546194277, 0.18563428893685344, 0.07504386632072349, 0.16773154959082606, 0.26445330631348396, 0.18362206707317985, 0.09980125397804285, 0.08924447811178624, 0.2317483080250602, 0.15242247752124263, 0.270197402926222, 0.28523298160683724, 0.2586386989681952, 0.10387376206175936, 0.19555947893569547, 0.08560990418998465, 0.20971238643171328, 0.15864337193629435, 0.1769463769009998, 0.1826788596208057, 0.15782162006343567, 0.13167709232338015, 0.18199347139846894, 0.11188726391523116, 0.0974619661968562, 0.17292453787259518, 0.09646639663485751, 0.24918836090833912, 0.14067125566784414, 0.13718684264008077, 0.15864124221186485, 0.06853598004747784, 0.07446802867155883, 0.13433440618457335, 0.12128388388983666, 0.20789461300498058, 0.12259657554809125, 0.1948818588449109, 0.33264398755085084, 4.912898079041512, 19.64296506297204, 43.99315480263003, 49.862475779748735, 54.20616342175392, 42.13699902257612, 36.21340813175325, 37.08749655754336, 28.84674587557393, 32.73304004823008, 33.67372835836103, 25.392708663017522, 13.257232673706548, 8.443288149372224, 2.851887446257376, 1.4657047895654556, 0.7543570344005862, 0.9917459865250896, 1.0425140203968173, 1.6337519980246022, 2.2561419298571925, 5.504981327441431, 11.415317058563234, 13.33888759536128, 13.90861088229764, 15.980289136209796, 12.615911422237275, 12.880190918522498, 11.875768996054127, 7.808852618740452, 10.996440283713802, 5.0863683319860895, 2.1325340722837756, 0.9488177287482447, 2.2031068273129004, 4.597367913492264, 3.9624820457350824, 5.464088657209951, 10.259326907896227, 12.815207050692651, 18.890991787756644, 27.34284639358521, 23.6039823485959, 20.50510398803219, 26.065255903428604, 30.084167372795847, 26.73665192819411, 35.82201834647886, 30.101017875056115, 22.709589773608794, 11.352830759940609, 0.9631387312566081, 3.4350161687020337, 5.249000095552014, 9.605017708193872, 8.370425220458738, 8.951484157193093, 12.59053368722239, 14.2654328192434, 10.414115402006335, 10.194094950152982, 11.54398060614063, 8.329073632917098, 7.955423747339557, 2.911360383995118, 1.9091351113973127, 1.2859486932716062, 1.3901911964339595, 2.6794220555213193, 6.716600493077309, 12.459749117974313, 29.384622458488714, 53.34963544722527, 26.598623721830307, 28.03947110329905, 32.24262610558541, 46.22641901816092, 46.1146903038025, 32.36465300283125, 15.1778555493201, 2.9620023504380257, 0.30783680417845327, 0.2060879784966669, 0.22194901691569438, 0.14809838616319243, 0.1810405959164904, 0.19477952481998553, 0.1719390270450423, 0.13531895174134162, 0.17076024755595193, 0.2265065812295483, 0.20560442379886107, 0.21039316280474588, 0.32238046248112956, 0.2285130421120313, 0.1198790624978081, 0.09364775231769008, 0.13899951392123777, 0.20995675315780027, 0.17015267854496358, 0.13283580030885436, 0.07705336857226587, 0.22474609585779332, 0.14544683328318983, 0.20067484718897652, 0.1161756708977684, 0.17815534025430682, 0.13360795564949512, 0.1431408013787962, 0.15718927576897607, 0.17652343507976304, 0.1861332573236958, 0.12150106215549093, 0.09984702007063936, 0.34715547016070736, 0.2020516604064934, 0.10060661156932194, 0.13603412546217442, 0.14149905963530465, 0.1543792499409568, 0.12954724531981254, 0.12108125363386447, 0.10516035310443371, 0.28116419671043275, 0.18264335910639456], [0.011185152782878328, 0.015015149988504428, 0.01468841444640871, 0.011465161749642464, 0.04847653082481796, 0.026152583154579325, 0.06273335048688516, 0.06520447050852161, 0.02844601291261854, 0.06575298946230643, 0.036011755526546514, 0.05280553663690245, 0.0207242833059882, 0.06106624740266031, 0.02997464177409007, 0.056677597815230976, 0.04281289642676712, 0.038924755062907934, 0.06016860686002239, 0.05361773539334536, 0.014410797589188142, 0.06057859030401996, 0.004468827870779581, 0.05621560083161439, 0.027421100267900095, 0.08217497278125056, 0.058192785664071, 0.05626298336973114, 0.0595583833543764, 0.05138226018677797, 0.053665550771139325, 0.07404374619645458, 0.03566304762517253, 0.05198581106660347, 0.04038666149661426, 0.04366478236812738, 0.05447278144739328, 0.06453566042886627, 0.0360487652341685, 0.023021771414806286, 0.0996629904294687, 0.052096028136269706, 0.02675852805916821, 0.05746677945998888, 0.029780130134895447, 0.017659586869300376, 0.04602659696472749, 0.02210755272948694, 0.029392328766745426, 0.05842617818064267, 0.019860936689280698, 0.09846069204110293, 2.6103444589722544, 12.923130085391383, 28.65760918586485, 41.83821639707012, 43.744017616395034, 32.89074678574839, 23.046972443980557, 23.36634162933596, 12.072434675308967, 18.378381152306837, 21.80940385787718, 16.32409566833127, 11.406802573511678, 7.472080857523027, 3.962334711705485, 1.7946539963445358, 0.4997838414724797, 0.34912866750551813, 0.12616121330328528, 0.2916112764468116, 1.0100613714706514, 1.539337851347462, 0.6453636216540491, 1.7391308853703162, 1.0502137556191415, 1.441006237460721, 2.7787430872840266, 2.734490416703686, 2.533981304976248, 4.417046750745466, 3.229303297496611, 1.6770047093591385, 0.8483857469212625, 1.4277341625382824, 17.489238669795377, 2.3591362612862743, 0.5156401148246181, 1.3451089445621738, 2.2771437706485873, 3.8919492498520887, 4.445578071378893, 6.832269228273823, 5.810852166145079, 6.93719998482735, 3.6675568261454186, 21.707828198709798, 3.3547272124598106, 0.7922937084109553, 6.272342060842822, 3.23147016186868, 1.2173877464186762, 5.016371184779752, 6.468321815613778, 3.3895284418136846, 3.022290650875338, 2.1777165897430915, 7.3247174101491135, 5.803602645474096, 3.970133854496864, 3.4030248272803525, 2.322815113490628, 0.7711452077473364, 0.6286013114356226, 0.9796246982389881, 0.887536762222167, 0.968575258889506, 2.463354127060983, 4.502188169187115, 8.691620269129354, 10.611231173238448, 37.393759142967966, 48.19315033574259, 18.67881705684047, 21.63184012136152, 28.608944339136926, 31.169651939022927, 25.150514071987523, 12.877324646519078, 2.0920645277346335, 0.11522919991083684, 0.035617967181268244, 0.09621512745657275, 0.10970592814227266, 0.011121459275243745, 0.012202689916105762, 0.1340221793901536, 0.02977809617145648, 0.036430112311556455, 0.07344834266170379, 0.03803554531787673, 0.06679876842686246, 0.05614384520618666, 0.01674144006814928, 0.017862391410275333, 0.02188327665921421, 0.056048850303575884, 0.015653632562457314, 0.004675568667270484, 0.0440005204009433, 0.02458591228200784, 0.08423657667252325, 0.05648541316810635, 0.05119223207716019, 0.03350656374447769, 0.037966245004246314, 0.08538241438086956, 0.040194664541031086, 0.03309831165918901, 0.0020438979235252426, 0.015548400809958339, 0.009257234107222288, 0.03744258177316478, 0.05620995859405207, 0.04211443874444212, 0.021771981320794553, 0.1183665827697804, 0.026900336679611957, 0.09175754527771667, 0.024444630347012032, 0.02114044333387527, 0.03568413419528835, 0.042366853224173676, 0.01703841788243623, 0.08656089509566946, 0.041267804335802794, 0.05737656494602562, 0.02770646227403514, 0.03968066933955397, 0.0746656257298685, 0.03680944074726394, 0.06196070101953322, 0.04089356655435216, 0.08227552948219162, 0.07564347567817858, 0.028420329814957037, 0.045712834164019556, 0.03580000116339615, 0.10126203043206085, 0.00929494191246528, 0.04481296047508236, 0.02981531846847746, 0.023357243232068517, 0.03385369733516728, 0.06116522979291697, 0.06832774202789992, 0.05762161349036521, 0.020828235691653627, 0.04908693819156578, 0.05452436214733509, 0.10391928300622011, 0.08796751679432008, 0.07187367957686225, 0.055723102057292584, 0.02176161998161866, 0.03981025694238563, 0.08514409974938439, 0.04594586661926681, 0.06679496863075803, 0.02938162268800361, 0.03252505572632917, 0.06356349485295434, 0.05289459435810005, 0.03410852116142069, 0.026162986628591057, 0.008609421539961571, 0.03937247982849518, 0.06866010161296976, 0.02656948628775295, 0.02076247470423339, 0.08357097650127066, 0.023738454328849915, 0.05155295606762652, 0.034471884324786164, 0.017300734048589103, 0.060283807331636075, 0.22210747454195257, 3.459608203941776, 16.144906109379185, 32.68482039051671, 48.031952688770915, 44.46143481039232, 36.273404705908995, 25.707727939851825, 22.400067698570993, 16.100953009820756, 25.679361358765636, 31.212211616577644, 20.067257650436897, 14.636165442005282, 7.536596002117281, 3.625967935208352, 1.920195950135108, 0.4146726988255978, 0.11220082370263916, 0.09509523714622183, 0.1203962944207653, 0.32295999267408926, 1.1406153176100025, 0.8197567347557315, 3.0252000689506535, 1.2208286456523405, 2.5468001009956485, 3.8372390500960813, 3.7712022710231046, 4.383315838152363, 4.485936318674396, 4.6619737628967535, 5.04121792893256, 3.6093248282709434, 3.3107976471224143, 15.315885716868987, 1.735650517286793, 1.558957179227183, 1.8606662606039357, 2.8476260362132906, 4.3372784891436185, 7.356039006863871, 10.271368584325238, 9.92358280766395, 9.553287529176282, 10.586910516985002, 24.1826182411563, 6.041798870409689, 1.387048887629663, 8.01270260926216, 4.308965840647298, 3.079095396303362, 5.994047445635642, 7.240021180722022, 4.8876679232043605, 4.478944693842243, 4.5165783647568, 5.493472112763313, 4.546552137021096, 3.29089799234944, 2.489590615995469, 1.681304485086472, 0.3283356009952484, 0.7813246776500057, 0.40523461817253026, 0.49916171679092997, 1.0260714446344683, 3.1824486246032104, 5.607685158329626, 12.483971714973451, 16.271258400332545, 34.7660300039476, 54.32572118697628, 18.59413504600525, 20.126520741370417, 32.01126313978626, 37.20157869400517, 30.638996439595378, 15.649498989505155, 3.0030644180313235, 0.16054789715957257, 0.04747868981212378, 0.017669860108364976, 0.06789896261668013, 0.02410614588898757, 0.07072758139862169, 0.06185821377702298, 0.033767209838955634, 0.02027076308525378, 0.024953917938194452, 0.08015994703577412, 0.10133797272799477, 0.0385015680935354, 0.07778598611513454, 0.08453071613105075, 0.08253798354417086, 0.0368504379425318, 0.028288256256811084, 0.06111846012513965, 0.038354398772841504, 0.035686991703245914, 0.0555586114886307, 0.05019640587570687, 0.05063376164123897, 0.03921633961820795, 0.050640277219034975, 0.061875914238513484, 0.02496869577425382, 0.04389298846945167, 0.031929052727777636, 0.06495690919579038, 0.058698530098603624, 0.06950564051587736, 0.03254302431859317, 0.06960118700179362, 0.05410584448386104, 0.033942590347461166, 0.04050496845476089, 0.217631988888306, 0.038295080584864465, 0.034230964994358445, 0.09774358777870094, 0.05303987144162098, 0.04518767706148567, 0.03816465028531609, 0.1270866858202123, 0.11569135777291753, 0.08860681716713215, 0.13995416672720065, 0.14511378421898813, 0.15682258012314, 0.25830695225346473, 0.13748964655303186, 0.09645420051510296, 0.13262776147213676, 0.18525810912251475, 0.09493167737438794, 0.10422685198606023, 0.146910076540324, 0.08879787949544769, 0.14002502986019658, 0.1884767662493452, 0.07972587395699755, 0.1474154953874888, 0.24000653666594338, 0.15302165020858088, 0.1750762183820048, 0.12788348620937717, 0.12560052121238363, 0.25280702318395337, 0.2279214843386604, 0.2308007951585516, 0.174222091633466, 0.18349938575298558, 0.16992394001253192, 0.22230294953671195, 0.2235541396564053, 0.1388724812216336, 0.15286037337876138, 0.15559447989348443, 0.16738348520330845, 0.14312754805770614, 0.13845404399739158, 0.144101383705293, 0.14133038239613657, 0.1792515661086767, 0.1291085374090941, 0.1964317772897982, 0.20910316267080847, 0.10699812142599015, 0.19985190021895594, 0.13937071416406863, 0.09192431495795328, 0.20139889220797247, 0.13932572948115488, 0.09984046235800752, 0.2477097192839269, 4.089429556362091, 17.647361178551954, 38.45948280826692, 55.83131121050928, 55.88265111369472, 45.08586437471452, 33.85918586484848, 33.57191147342805, 20.400486530796176, 28.648909368822654, 32.505254284028084, 24.22872570253188, 17.090998465015044, 10.367887327747962, 5.656904530140662, 2.748521225106332, 1.2800830338270435, 0.5988074779029816, 0.4481128044426442, 1.52633543937437, 2.9747306867953274, 4.5968732045542815, 4.4779729266320505, 6.731815857271995, 5.95186774769137, 6.6551433263286475, 8.844876097094629, 9.218965288131468, 10.112966606693885, 9.726042439860683, 7.276649744279924, 7.276220244746055, 2.8670488778621923, 3.791419882928172, 21.160692861003263, 3.914328823166509, 1.1420168295021982, 2.0429982509343856, 4.120819059110457, 4.670617195867724, 7.581096762611021, 11.066705622980672, 8.15763859979568, 9.559989879208228, 14.581266968481003, 44.96427089937272, 7.511466357015795, 1.9643201630923057, 8.83833162246212, 4.354932586992941, 3.1966199028876523, 10.880801946886125, 14.182086375451858, 7.881191420939661, 11.152548655386894, 7.427182466753068, 15.78320670512415, 9.379051923751831, 9.994521814007914, 9.694927257876243, 6.159877411780819, 2.718455522291122, 1.850665074683005, 2.302998318787544, 1.4668151880464246, 1.8572123685190756, 3.648472288923879, 6.780782726503189, 12.345037441099844, 17.082826206761023, 44.194482218834665, 56.09903650899088, 25.16647223503359, 29.677437197777536, 39.550643044133345, 44.14054178422497, 34.993472560759514, 17.408004422341627, 3.692049086093903, 0.2360705914156091, 0.14563549009542312, 0.13769555566532, 0.1945660774025225, 0.14819005624421183, 0.1032658866156013, 0.27075281667132534, 0.10112337617864532, 0.12568964788149442, 0.19227671557136122, 0.12471602673852637, 0.1832987779691335, 0.14793055162074106, 0.23262622946452713, 0.20900013916675123, 0.20465847375171803, 0.1680231073330487, 0.17983632102128, 0.19735885093048697, 0.1311073067688173, 0.1634995726447913, 0.15955069583029519, 0.17723295507171463, 0.20258735504842576, 0.10149128224340179, 0.10596575666098826, 0.11060618104473238, 0.10147272759387571, 0.3402444990652223, 0.1852739211772719, 0.15941301450854348, 0.1451216749246082, 0.13927270087503618, 0.1119450958926351, 0.1787212340822143, 0.11228556068794382, 0.1351757852300521, 0.15206016389833343, 0.3394609749797852, 0.1040761165260788, 0.1198354108078826, 0.14012921781789872, 0.12299229826537833, 0.2110431577649809, 0.21194619156660574], [0.06916219563854319, 0.1100006498276226, 0.09486015540577712, 0.0977156408912232, 0.005930345036059378, 0.017867616129918926, 0.02900564588696486, 0.037180227302615686, 0.026978724711244146, 0.01800372888664565, 0.06423828041841907, 0.019789996947492325, 0.020075945010889443, 0.037611772291242115, 0.0720253879685075, 0.050674808632221915, 0.043409223097466657, 0.0308805713880687, 0.054830188277147474, 0.031923925684344386, 0.08652500387641691, 0.06350455970893945, 0.02217215309370189, 0.03298224167778127, 0.057014163223005114, 0.04399269864323639, 0.1037153427398974, 0.016303563362828666, 0.014120998018751703, 0.017196339247147405, 0.02312070400934787, 0.07086230562098565, 0.03462370379918045, 0.04582402416534963, 0.030206641925859357, 0.037683918621511235, 0.0504374516106421, 0.023174617447019107, 0.019332316869329062, 0.027682236658649582, 0.03196607967237792, 0.012572666333477586, 0.022577796649608402, 0.05290304047746524, 0.050915624540779865, 0.031051755649968985, 0.03910390855444055, 0.03771027204610648, 0.029082942243304946, 0.05439668210343488, 0.026999998972901416, 0.05716659939817845, 0.07526331220663364, 1.8712091013308496, 9.969194089212726, 23.07303463259051, 41.539194506983605, 42.53151493687784, 39.04082121387605, 31.759599947160293, 24.791746639436294, 18.62215057496102, 22.168430166859782, 25.53240779907473, 19.75039682080669, 15.471177254953693, 9.978410678525126, 5.377769056827792, 2.856382972771122, 1.6708196218936675, 0.37453364460699023, 0.4890288556775739, 0.2533947505177029, 1.0244271748008267, 0.9280416081028601, 1.7768908075747953, 0.7054062223722858, 0.9638993646348677, 2.1896195123272557, 3.541319999964007, 4.056834660230145, 3.684454396847756, 6.082232133034737, 4.667457236397651, 1.8482426433793961, 2.1708870078286817, 5.080865736930601, 1.0929300828326134, 1.3420118655889266, 0.14596982618733761, 0.019941153755832105, 0.18773856392550856, 0.6111483576316988, 1.4087598194037716, 1.0499829486493142, 1.063739436288034, 0.40329577221024426, 12.594733565084397, 6.160022049180924, 0.18556477411860423, 0.270760630768153, 0.8585418664639997, 2.7700096849472295, 5.363005745795466, 6.933144254069175, 5.515202533814215, 3.4568515131550455, 4.903167659236539, 3.827527261549427, 2.783960084761343, 2.664020133595313, 1.0934782340641946, 0.957939874741339, 0.15327009252242504, 1.016774875742774, 0.549538524881486, 2.295343077951862, 3.0361045031778278, 8.51767001613494, 11.791251724766148, 19.130585847362397, 22.096089893771758, 44.92729471575829, 51.34940316600185, 26.999209503973685, 30.14973371259628, 33.96414849065965, 29.707080510354814, 12.202013115729056, 3.365967009336718, 0.15325173705575929, 0.060587710580758514, 0.05246805958449841, 0.14995925969654514, 0.02996366181891532, 0.04540357212986677, 0.013037865564617659, 0.034932590450250336, 0.04621661741346602, 0.07163037005211077, 0.023375512513842796, 0.00450987869220215, 0.05666492289052375, 0.006487134387791758, 0.01371818898816503, 0.01695681802718149, 0.024288199023313584, 0.04331274581472239, 0.037467303430481304, 0.019315913011650407, 0.0239049501326536, 0.01637671709871821, 0.02302792310083826, 0.016113452898759036, 0.06392569739311453, 0.02024268787804871, 0.01865756769304074, 0.017836828971461906, 0.057199820801014864, 0.04944557076199882, 0.057057205873030814, 0.03457686135305032, 0.02804485480150869, 0.023333969480928876, 0.024402662135300138, 0.07531061047507871, 0.04013742245132885, 0.02987563257075606, 0.0556958484793863, 0.034091996644893964, 0.029640309512615207, 0.0985662283135518, 0.06467500416141364, 0.01684624281141066, 0.07321898359805346, 0.02800516378615172, 0.04851738246338022, 0.017217783963367823, 0.039668733689693675, 0.05570703719352042, 0.040994988934647654, 0.022089813963600227, 0.02096323570567033, 0.009095617325886363, 0.060726311208019336, 0.09117204725982682, 0.03207995289666278, 0.057134733970968, 0.03711085421063247, 0.018890852957303007, 0.009911526820712514, 0.01787819580415324, 0.025588217672080766, 0.025136467114451434, 0.04372266414124639, 0.004418307723807953, 0.01654745702962241, 0.0234032717097791, 0.03868190902135065, 0.022875243692748973, 0.09463144751686244, 0.10327568488015283, 0.07978865486239234, 0.009520453299515912, 0.03963150564701327, 0.030075026105248162, 0.029327374086865497, 0.08878959808498622, 0.042594963564507426, 0.00827965707773523, 0.09849516599769555, 0.035460455673596555, 0.01631583992181526, 0.052532889775090644, 0.04540325420337819, 0.02131740772916425, 0.03405088836687707, 0.02909731596798426, 0.06012219342312986, 0.025957834028128176, 0.006884911178325814, 0.01655856721974429, 0.01888619514272338, 0.00696248428392855, 0.05801762349062389, 0.02770230433182611, 0.03951527478714143, 0.053447997122402155, 0.1279501052152726, 2.5024268175325086, 13.551179016790083, 29.283699873955022, 48.362184878318544, 45.933331674145116, 40.79904325546757, 33.01311492919922, 19.949902296066284, 18.788033493103523, 23.096535513477942, 26.598870831151164, 25.054100251966908, 17.968456206783173, 13.199359082406568, 6.244554519653321, 3.248367977719153, 1.8972763154775867, 0.32667692870863024, 0.1855081448992414, 0.08565991440968168, 0.30549435245413936, 0.1731543029628454, 0.27449386915372265, 0.7585656150214134, 1.473144545189796, 1.2134624344687308, 2.189973015939036, 3.444280071604637, 4.939570196213261, 3.695238953636539, 6.30724968448762, 5.204273308477094, 3.395960638600011, 4.725716690863333, 3.300785306961306, 2.5410386295087877, 1.2748581916093826, 0.39736180836635254, 0.5330009542165265, 0.8483884435507559, 2.0089243760993405, 1.9748489078014129, 2.1856870910813733, 1.4202218430657543, 22.13639616966248, 4.947634589287543, 0.31960655003786087, 1.7138096570007264, 2.5571936465078786, 3.958239757245587, 5.481392683521395, 4.963509892263721, 4.919475403524214, 3.399052692036475, 2.450604217667734, 2.9136924782106957, 2.186592423146771, 0.7459843062585401, 0.8311030484976307, 0.3965130442332837, 0.328786397773412, 0.4772373222775998, 0.5941315223613094, 1.7960862743277706, 4.177662047647661, 10.706048588598929, 12.26164589005132, 16.100536257989948, 17.2632356228367, 47.34805214789606, 55.39744215626871, 24.50430358609846, 31.545877841211137, 38.33869341881045, 34.32167253186626, 16.263001811119818, 4.476881527131604, 0.20776166610660093, 0.06806223127510279, 0.02699703038219483, 0.053525176650333794, 0.05450471582251692, 0.07829738810898797, 0.08358142594055784, 0.05897594202730445, 0.13795112259685993, 0.07079983881163983, 0.03007158445524833, 0.0017084566300787454, 0.03121193697405679, 0.053191024419521137, 0.03075481805529806, 0.021819467280781078, 0.06225157311306365, 0.10128191041369593, 0.042942476368719534, 0.007246822126269822, 0.06148320607720845, 0.03931578166121918, 0.025999714139728777, 0.10710764901652452, 0.05823238857931668, 0.05526444138658624, 0.04827353284664212, 0.03260183688854018, 0.013967385898614603, 0.051024152386573055, 0.05862613862019874, 0.054444156572102546, 0.03233243057864808, 0.027842063667072404, 0.0678654692526306, 0.051753724729942704, 0.11150772097490488, 0.018361558979978005, 0.08068210490408444, 0.029017604519462878, 0.016918942640205065, 0.07602311054905576, 0.041902247711174914, 0.034598786789443225, 0.03501360807868262, 0.014452044720641308, 0.2265639918585939, 0.2623843479781382, 0.16187001169929582, 0.1604527950046524, 0.08145996759976111, 0.0977918130135344, 0.12152005347513384, 0.11821931768809596, 0.20768924015423945, 0.11512950888925022, 0.1794613363041032, 0.10523130050710133, 0.15279619053246515, 0.19917411158882803, 0.24693071511724304, 0.12639260249993495, 0.16227265219053916, 0.13993072443671767, 0.17051030370977618, 0.08943826771311222, 0.21621236667758037, 0.21611564041626072, 0.1063757899007009, 0.16020508813521556, 0.20080975527244233, 0.13416114773961807, 0.19271119467673764, 0.21190388819142697, 0.09609633020215458, 0.08725443449352058, 0.13766961592820384, 0.2641878415259623, 0.10701113725982367, 0.15689682936476124, 0.17236717826416417, 0.13045053959133165, 0.10628976588768345, 0.1329640587491374, 0.09631936137955036, 0.09214408260079161, 0.23727613801677383, 0.06556609465229897, 0.15795050669581662, 0.19101582677854648, 0.12302383044434172, 0.13716142384275315, 0.1251465911346097, 0.15148041920075495, 0.10572421679934187, 0.1827102998692182, 0.11081939097493888, 0.2201275969104421, 0.2249819283644038, 3.025720273294757, 13.708409186332458, 32.18281388282776, 52.37408707218786, 55.49845495531636, 51.602164622276064, 44.21389402881746, 33.01740600216773, 28.502293132966567, 31.904054957051432, 36.66673998678885, 30.823506693686213, 23.26586031144665, 14.364307926547143, 8.056150213364633, 4.185732324277201, 2.7401067604941707, 0.8825278342250855, 1.0541795170114887, 0.5733391606519299, 1.7611840439419595, 1.887072882344646, 4.710545453333086, 2.534549313206827, 5.89532187869472, 4.335346721833752, 8.103527051787223, 10.157795375393285, 11.572174602939237, 13.24068517454209, 9.208462161402549, 6.035696152717837, 6.237202036765314, 10.9715469614152, 5.093019200909523, 3.869550309834942, 0.7637047779656226, 0.26497344937055345, 0.856116064373524, 1.1529126835446204, 2.1609842488842625, 1.7177364398394863, 1.946295401261699, 1.3797507050537294, 25.86648979494649, 7.723963702878645, 0.3092401853251842, 1.5672441668087438, 1.3509127041024547, 8.2035058159982, 10.988443551524993, 15.019245686069613, 14.811488524560007, 10.93709776478429, 10.996386351123935, 9.665020165904876, 10.070575591056578, 6.991747406221206, 3.3815861325110164, 2.2396017851368075, 0.9798682529118754, 1.7526471278359814, 1.069310917969673, 2.9617770593012533, 5.004185361246909, 10.692227136704231, 17.27728359160885, 25.53756767703641, 31.086015239838634, 53.64511935941635, 57.52139775983749, 35.261495959374216, 40.84700992030483, 45.98817425389444, 40.29656410217285, 17.17343491892661, 4.592188423679722, 0.305797110401815, 0.1951798823692145, 0.20862356098669194, 0.23262311914755454, 0.21467075262579227, 0.13199305762687039, 0.13474326730976183, 0.20091233444550347, 0.24555422365665439, 0.13947307883251098, 0.16009821886977843, 0.10202565921410438, 0.1571535607499461, 0.2571558591819579, 0.12992305741194757, 0.15018410650232147, 0.19043764490033352, 0.07901371862258642, 0.10719923482787226, 0.11782661335723055, 0.11049555028758704, 0.11453648022706471, 0.13196272054506888, 0.25208326927836866, 0.1665325453805347, 0.10252853464936057, 0.17959445174182617, 0.0984144586348726, 0.1457173848945287, 0.2217757737924976, 0.16931577345296261, 0.15925089498200726, 0.14324157258435605, 0.2619124378167814, 0.14885187960199772, 0.11295429415880673, 0.2393600044231261, 0.12268741825415243, 0.20261442859566983, 0.10457503894764571, 0.15517152275048918, 0.25181745209040185, 0.20287633873522284, 0.10458826928609803, 0.31281959325555836, 0.12873994186520576], [0.052388696705982576, 0.025256819527355895, 0.035351537122961976, 0.04178574105965034, 0.03907804159567722, 0.011223491653048945, 0.06806803822156883, 0.029812769310909416, 0.038659209836154215, 0.0262892417489521, 0.04722208100100679, 0.05803030990664998, 0.03740298268835872, 0.10112826381960224, 0.0091785597502284, 0.046278942496545857, 0.020158810826439052, 0.07440642754156744, 0.0026912448529694834, 0.04767175929080095, 0.04975920332775963, 0.021090088374612313, 0.01847217441536486, 0.026102268414932395, 0.02016916067429608, 0.04849665595458881, 0.03652290854182455, 0.021069379102799202, 0.030989323314579747, 0.022060455559121988, 0.043645687626614686, 0.03740923396582085, 0.014155256513115621, 0.007838934834580868, 0.04784846130097586, 0.03635369504110948, 0.04551884154939363, 0.017042813311901786, 0.04217581004805623, 0.0389146541936263, 0.03588212961931864, 0.057814606360249945, 0.023836090319579648, 0.042370457667857415, 0.037099627192102136, 0.026622300389252847, 0.009789972607376836, 0.049882838427419626, 0.01281528637909721, 0.06788759387188381, 0.04112780176764054, 0.032748297577904116, 0.024631674544164733, 0.03227093287052647, 0.4141982452523324, 6.517142086259781, 17.97720701463761, 37.76567828270697, 43.10411430174305, 45.79504459134994, 36.24382611243956, 28.20059814760762, 26.47357071599653, 27.402540945237686, 22.29789976150759, 11.513266486506309, 14.247967485458622, 9.716367913830666, 10.69938644286125, 8.360056434908222, 3.766534405369913, 1.9226362772526282, 0.8001060892016658, 0.551575276880495, 0.45123773837281816, 0.42021010491636496, 0.4667339504005448, 0.7227890638093795, 2.1763334639610785, 1.2348870332202604, 1.916841343045235, 2.0307371669238616, 2.6391790278496283, 4.3883663800454915, 9.590894233795906, 2.619221272968477, 3.6429407663883704, 1.7837940565040036, 2.044420355269986, 1.778118754586866, 0.7358891673145757, 0.6853381508300382, 0.388947956624531, 1.1306685545752126, 2.608707114573448, 0.3625039497931158, 0.9400843876984812, 25.620006092133064, 16.784257350429414, 2.795294018522386, 1.8137135284562267, 6.004067140240823, 2.54231805762937, 2.4367111825173904, 2.768280164849374, 2.8440458928385093, 1.8994729653481517, 2.036467259449344, 1.5347549295233143, 0.35707542011814736, 0.318098766428809, 0.5284144164573762, 0.36374819915621515, 0.6279383695894672, 1.7222677579810544, 3.8317420934477164, 7.366854452317761, 10.615990969442553, 13.51755940145062, 10.675868891900587, 17.35227538693336, 23.381156421476796, 39.9748356111588, 37.853853164180634, 30.30133724212647, 37.76370140814012, 30.464068535835516, 14.728839282066593, 3.5686910344708354, 0.14515132252727786, 0.08947798171110692, 0.08169753912595973, 0.07388030133780933, 0.06820705253630877, 0.022594512688116204, 0.03949826380478279, 0.009470906563013071, 0.019801882801637537, 0.03253881849588887, 0.040776937328759706, 0.03940083657301242, 0.048193756280647176, 0.03603887120862642, 0.024180975442211476, 0.0750085726500519, 0.016223329059298963, 0.020049120442220764, 0.01887203975310249, 0.037851580794179635, 0.0052136362665483075, 0.02462117913960209, 0.030565467933493278, 0.05300647000812235, 0.03437709243547532, 0.043880378662218014, 0.021929255341209715, 0.07514024018159798, 0.027404106522519744, 0.04423631077271797, 0.004156783022241847, 0.0323291402310133, 0.020712037390518575, 0.039122451712647756, 0.010609080519286856, 0.022002537396826574, 0.006007582978195241, 0.010424782747342702, 0.032841702848072016, 0.022685872503526272, 0.041130869949777285, 0.006277774049404768, 0.04742640048085202, 0.06086187046622077, 0.10357462770996556, 0.028105580676046592, 0.02489158327901556, 0.020997328533520623, 0.009309349153491278, 0.01691999984154057, 0.05567753131711676, 0.01193166237264391, 0.04345597361304587, 0.0013227325572159083, 0.05960688055042298, 0.017772967882093885, 0.05158114427280042, 0.023126080031356504, 0.018002731057124275, 0.10254300605025023, 0.03427809089302056, 0.023932360758584355, 0.02868954651808787, 0.08779539215949275, 0.0009962188215145182, 0.07655679037974727, 0.017569148274619254, 0.08028340976565115, 0.053645992546432444, 0.04407654313610927, 0.02999024123944823, 0.024981839927814664, 0.07670846812787556, 0.041558550024825724, 0.04581097768799913, 0.04017341709245117, 0.03503002534289995, 0.01407335309552089, 0.04064257699815978, 0.013292373379602308, 0.0143221985631352, 0.029898371975568515, 0.024112688279860926, 0.004090199447912915, 0.05803793631193619, 0.022497303791404254, 0.07675103963382783, 0.04731390813005067, 0.062140953847237175, 0.04135792308877553, 0.04543595849686573, 0.023894615606555057, 0.045488301454292196, 0.05123318713759223, 0.04965661649381922, 0.0463038633367227, 0.03979927124155145, 0.07797656580805779, 0.0558761625941242, 0.026590168746488712, 0.03227005953029279, 1.0791299588257268, 9.063745333302407, 24.45797843317832, 44.14188715719408, 49.31988646907192, 47.71704127711635, 36.87656717915689, 27.11230516433716, 23.77022808597934, 28.97664300857052, 27.466897233839962, 20.034864756368822, 20.141157065668416, 11.900688794351394, 11.257740739853153, 9.283757940415414, 5.187760620347915, 1.5214221804372727, 0.6097452522766206, 0.5028878458805623, 0.27198012016953965, 0.21197842854645946, 0.2527535349250801, 0.06099246547467286, 0.6352208013976774, 1.0832279776373217, 1.317029922239242, 1.9759172633770976, 4.326013442008726, 5.545255734074501, 4.3257423081705655, 3.572771525190723, 4.239578622002756, 2.1660870073303102, 2.292143649631931, 2.4902157437416816, 1.2893050163984299, 1.5333672685007897, 2.2134949795661436, 2.4651696941544934, 2.8839219337509525, 0.689468406621487, 1.38841902056048, 34.79084291765767, 20.75709273738246, 3.9598479290162367, 2.9400912552110614, 8.07188823338478, 5.266531129037181, 4.180106664857557, 2.2632774566450427, 2.9695845371292484, 2.4160545103011595, 1.2981341490822456, 1.062000723135087, 0.09959121565184287, 0.2549503993002638, 0.2664280971211772, 0.42760398719579945, 0.2682993128415077, 1.2015318101452244, 3.7916542445459678, 8.859694811605639, 12.173702428417823, 17.043804507101736, 19.972622625289425, 17.335579818294896, 22.69167827021691, 45.905910384270456, 44.52249042449459, 31.73495177299746, 39.94972067494547, 34.541062462714414, 18.65272545045422, 5.033666385758308, 0.29833918317191066, 0.05322518044962518, 0.021286250933283762, 0.04729416987468158, 0.028887551518217213, 0.034797456370846885, 0.021635251863288785, 0.026678732340975155, 0.019086636302451936, 0.052237379019178694, 0.05992946102313938, 0.050506594876248034, 0.009747719027913146, 0.015128472587093713, 0.06524645212677217, 0.02567409804361242, 0.1579551032233623, 0.01028289464527681, 0.0352526236806185, 0.0615220160914525, 0.013851026719015454, 0.010941086746301624, 0.006138817191259155, 0.015070110093802215, 0.018314909971048756, 0.061084939948012756, 0.06005752794144135, 0.028693530175294128, 0.03909048669400715, 0.0537888411312334, 0.013720778365349098, 0.029356282414688222, 0.007552689433308139, 0.06630590576077662, 0.035881961079975294, 0.042267323081051154, 0.022313785513923056, 0.04009237265094154, 0.02302647902510099, 0.056725489801817366, 0.07153866166669516, 0.037786566742485574, 0.016065793611379643, 0.011948227108786664, 0.09796884061107713, 0.05801738217292775, 0.028271296985387325, 0.19078744064655997, 0.11313022625061775, 0.1331781803239738, 0.23362756766859563, 0.1188971829270163, 0.17624251063792937, 0.15500543488850518, 0.11419148785212349, 0.11582176125938855, 0.15333824370416904, 0.08470677845780888, 0.19415930003648807, 0.17622858315946596, 0.16190489934336755, 0.2536238874158552, 0.158280169651393, 0.09066930972039701, 0.212029465323975, 0.13385256752371788, 0.16644720318576983, 0.08918503734974131, 0.11301348211183665, 0.11767798463904089, 0.09233037986221815, 0.06328656555964582, 0.24710190512480276, 0.1785560808474979, 0.10551785569517844, 0.11132218980140264, 0.09389031873715502, 0.11715982574969531, 0.10730187528796735, 0.11878984634794536, 0.12644677257706083, 0.13587321635455857, 0.09996255379050009, 0.11437851289707808, 0.135229104949582, 0.09847640450442992, 0.16562059431547121, 0.13785687846041497, 0.10082123110130911, 0.12278734676299558, 0.20727622683250135, 0.17767267421849314, 0.1299799011359292, 0.193317721808149, 0.2305663416102048, 0.14650765055369946, 0.1794376948307599, 0.15106743652253382, 0.14316130189164994, 0.14709240546630276, 0.22765035050049906, 1.172316526213, 10.154795742804005, 26.181503188225534, 49.510635252921816, 55.67503221573369, 59.1066118978685, 48.66984774989467, 38.31857165982647, 36.68099387999504, 38.11472215960103, 34.458339675780266, 22.717081500637917, 23.02963164544875, 16.965939575626006, 15.000385949688575, 11.467626767773783, 5.795966281044868, 2.5709422894062537, 1.4816954347395128, 1.0286792079287193, 1.081277211346934, 1.366444554540419, 1.4486776580733638, 2.487214885411724, 4.8633958062817975, 5.759335266005609, 7.2402540714510035, 5.727739103378789, 8.03149909742417, 10.337789020230694, 19.971638110376176, 8.585453475675276, 9.833007435644827, 6.127506581044966, 6.10205481129308, 6.66690553388288, 3.790923703101374, 2.2268891382601956, 2.5888734046489965, 3.203903989445779, 5.372094367780994, 3.0069274623547835, 2.4786244044380807, 37.44599726892287, 25.233984070439494, 4.848399114224219, 5.923764455702997, 9.929610510026256, 9.962642750432416, 10.3457720241239, 8.165196516821462, 8.965577233222223, 5.005002194835294, 7.588683116820551, 5.125810705846356, 4.160251136749022, 1.2016342820659762, 1.5135492480570272, 0.7510625498910105, 1.2299848059492728, 2.3281456145548054, 4.763734263758506, 10.74061349514992, 14.780845988181332, 18.913206131227557, 19.58681437277025, 25.362849620080766, 30.8853958114501, 47.517804484213556, 47.84257673448133, 39.317183571477095, 49.35252451127576, 39.44136973350279, 21.396637155163674, 5.794396352383399, 0.48141222567327563, 0.2292442883575155, 0.1666850888080174, 0.13153959486273029, 0.13362032030859303, 0.14851762011887568, 0.1331981752187975, 0.09889359300535533, 0.21719746381765415, 0.2074462370646577, 0.1382052186395853, 0.1474524514689561, 0.0682919427391983, 0.12931630045415896, 0.13842487136923498, 0.16012631897484103, 0.2118064264857, 0.21621429721914956, 0.18335936020218557, 0.15131774809091322, 0.10591040680845899, 0.11110107384381757, 0.07636888433367976, 0.17256898114517813, 0.17798791939933456, 0.1333692886175648, 0.09990307472405896, 0.09109076533106067, 0.1759995381918646, 0.18214857355961878, 0.0662938935021239, 0.12534376684456103, 0.12379590151531082, 0.12265246932304676, 0.1783838489603612, 0.10994871672723563, 0.14041328322022192, 0.18661946268571963, 0.10085087104309952, 0.13024282251154223, 0.16046934250381686, 0.14914112375868907, 0.16234610470071917, 0.20468707947481066, 0.2044365840453294, 0.17392101907922378, 0.12118528071310251], [0.08889530289677844, 0.021489482568276506, 0.013220042230621462, 0.01661393622447166, 0.04979080062419657, 0.03965083787578248, 0.08870455466451184, 0.05507639361425273, 0.09114541038269959, 0.034378957859570944, 0.03992461088684298, 0.05152287945571927, 0.06406310292321347, 0.06546396747111313, 0.049958566218734755, 0.06265411784331645, 0.01784208433462247, 0.04321407752051469, 0.0369231358561064, 0.034900472214024876, 0.01264827059311492, 0.050602390340739684, 0.0891926599245879, 0.09813091417233791, 0.020424457559842738, 0.0348444213910449, 0.07355070733014615, 0.017545261653140187, 0.03870990187410386, 0.044747299079092286, 0.013601097236988286, 0.024659613770763242, 0.038873699133194266, 0.014881144931179383, 0.05881552321596011, 0.011385185043177298, 0.11009911510853038, 0.08755765209395079, 0.0411441883883409, 0.07256237729903191, 0.050140335900528785, 0.04272343650940926, 0.052064541922581774, 0.04811923124737317, 0.04442684450036576, 0.03877112379057273, 0.04216372118061108, 0.035845142894334374, 0.0532975068105565, 0.04882565241367106, 0.01649900196841167, 0.019499686013366428, 0.019406464604300358, 0.038637621478447993, 0.042596468927278634, 0.23682048424117028, 3.7805973281783447, 15.356608744590515, 31.827092170715336, 39.551996261842795, 38.356371541177076, 39.311139199041556, 34.90508194892637, 24.897360378696074, 25.0458417015691, 21.07583434351029, 29.971310977012884, 29.27732013886975, 26.041268648639804, 15.416741621109749, 10.64054500672125, 7.595629144099451, 4.659162894372018, 2.290242280690901, 1.248542519827043, 0.7548829384388462, 0.4038963851428801, 0.36689492062695567, 0.11493378874635506, 0.5743189564635677, 1.163938220950865, 2.406526092560061, 2.94946204270086, 6.597261890288323, 2.2738889388499723, 1.9904432710139983, 1.574919509791559, 1.7751862925867883, 1.8792681011461445, 2.559187436296094, 0.9186292067170144, 1.3198329460236335, 2.29852240412466, 1.8553790281857214, 1.7663697850319648, 1.1082562539846668, 0.7125473262802248, 3.8424665889432355, 21.660222391928396, 2.8735156405356626, 1.3582506006763828, 11.168427390436973, 3.2346301213387525, 4.577419229092137, 1.20086157514203, 2.2068610258640784, 2.3593956280139188, 0.5814657600656633, 0.6806118173464653, 0.21175899032142856, 0.7375413431755958, 1.3202288602629018, 1.6783448116433237, 3.7577666822941076, 7.468509539481133, 7.403766897416885, 10.939242320676005, 16.89987901718386, 16.20151375570605, 8.158663809299469, 9.5865806071989, 16.71775748652797, 35.295263644187685, 37.82464719587757, 35.11931004062776, 31.723845581854548, 15.012603152182797, 4.077001036174836, 0.24859353960041078, 0.044526229086782665, 0.05542341229175368, 0.053691050007699005, 0.05560882472162766, 0.062169456148460034, 0.033263614281050624, 0.02842512361014322, 0.08367779214055308, 0.03133861918843562, 0.03760448679508221, 0.06289041766356077, 0.04933706972928298, 0.060742169228051944, 0.05321982932547408, 0.024883761521308653, 0.05576119577932743, 0.04916473442027646, 0.013489194773888637, 0.02140440084340592, 0.039979826673985495, 0.04032320260340649, 0.033808992274345896, 0.04062613675130471, 0.023667077916944702, 0.035688110191615365, 0.06322679537979346, 0.027715088424062537, 0.0738254417815516, 0.05440972091990614, 0.02289449548228614, 0.08063774075238936, 0.061895016640905416, 0.018274784200794755, 0.0568402344511161, 0.029906232037671635, 0.03962190656532203, 0.027251157068437146, 0.044504050841374744, 0.024075600048226696, 0.058765930514181816, 0.012915480145884138, 0.044720953315376274, 0.09682248196294231, 0.06635973109833657, 0.0280310039318377, 0.05157968870574429, 0.02528319210414925, 0.030585064462596373, 0.013855461410487132, 0.016117530401736017, 0.0167700438760221, 0.02434426899849167, 0.05779490257883745, 0.03807980221726241, 0.08577866569882439, 0.02851255722494135, 0.039994121874652566, 0.13641517759571153, 0.02401051321817983, 0.07506768399428937, 0.01974478243820129, 0.03749818443470905, 0.0268540439015675, 0.011765723897805138, 0.026120464918353868, 0.02343443808175864, 0.051884993895768165, 0.04161710212487848, 0.014686160232691516, 0.010496933865661343, 0.040429171715532584, 0.00680730599279125, 0.04676472651021135, 0.06870014502877189, 0.025612826331428466, 0.06271638546980197, 0.07441988770639704, 0.046836884331799326, 0.03258928070746122, 0.01832712141256179, 0.0266021580225037, 0.09321553317169029, 0.04855390570517029, 0.06361335951594577, 0.046369214467103445, 0.033488104855942155, 0.01153718167540407, 0.00590502966060153, 0.01232910687254081, 0.06252446512301123, 0.06222624241584732, 0.01040396430800038, 0.0539472489617765, 0.012061991165542315, 0.004679116611969808, 0.03181409931951954, 0.00939488957350653, 0.03524684354722981, 0.022802517050877217, 0.005453098593505039, 0.024437856214541583, 0.03631961178935824, 0.3804082213149917, 5.313153401497872, 19.718976674541352, 37.398893525523526, 48.72703982937721, 42.86224918980753, 39.53821305305728, 33.95522509851764, 24.802654750885505, 26.033088545645438, 23.001653379009618, 30.598309693797944, 35.44802035054853, 29.365163580063854, 18.850301119589037, 12.828171464704699, 10.010787883112508, 5.412743851061791, 2.2544695292749712, 0.9787376909967392, 0.325059900961576, 0.14637395288915406, 0.16383550219958828, 0.44170665464574294, 0.20642991418079024, 0.5438282280679673, 0.4470870127120326, 1.475801215537133, 1.5504236951951058, 1.3738711947394957, 1.8624942076783029, 2.2310694042713415, 2.38216229023472, 2.3072491874617915, 2.661590715569835, 1.9917725867802099, 1.1784463327738548, 2.5153784838414963, 1.706721198654944, 2.5581220224980386, 1.8636791311925458, 0.97514669981695, 4.905159732987804, 25.188863085162257, 4.036190490568838, 1.7917318305661603, 6.788996169644018, 4.963796715582571, 1.7957381639749774, 1.6268855213157594, 0.6500327743349538, 0.6554183111556116, 0.7889797346245858, 0.3137996955023658, 0.1720366572901126, 0.2618229281037085, 0.41711970622981753, 0.9816256586101748, 3.77054478372297, 7.450871621408771, 11.478134797465417, 13.686750838833472, 18.121901289109264, 15.645699193400723, 9.704912631742417, 13.115748859220936, 17.89415474860899, 38.17216919314477, 41.26511104645268, 38.97658063519386, 36.47444578909105, 19.712334140654534, 5.360536123475721, 0.5156248543531664, 0.0654077289565917, 0.053035052748577255, 0.07814314396631333, 0.0157394832480819, 0.019933695889889233, 0.07934025593943174, 0.01621941435000589, 0.039332516851925084, 0.07118574794261687, 0.0818014283093714, 0.0381999094820311, 0.024459346896037463, 0.07272625882779399, 0.028668747230943654, 0.011233991845661115, 0.03387764524368029, 0.022601175737837632, 0.004956858916087978, 0.01943840280986361, 0.10684062907051657, 0.08252466127516762, 0.02070337102087515, 0.017668088530040076, 0.030161456144865484, 0.024251641307566917, 0.030989150944796783, 0.024549549918681867, 0.052538152799130454, 0.017884682653652086, 0.026169751184962453, 0.020822091666500897, 0.005465575771766805, 0.037970718957724116, 0.011167891864334385, 0.04244649189434225, 0.024996518172443877, 0.03359438423367758, 0.033272631135919405, 0.051749652972625154, 0.05507206904792017, 0.07691797785340779, 0.02082911286232693, 0.025715282930421735, 0.02248751893339138, 0.03501648090839867, 0.02302781776374867, 0.06958786473279038, 0.1530043979085261, 0.16322162062410386, 0.07610305182395444, 0.08236524603900411, 0.20341301396969827, 0.14345207822418984, 0.29677054153815396, 0.26496885284300775, 0.22599465063502713, 0.16574998656588216, 0.20405337154384584, 0.09778645039806444, 0.14230441722658374, 0.09639852124476626, 0.24774768660145424, 0.2466961236730699, 0.09294760924193168, 0.14319395255898276, 0.09930367221034343, 0.12423026570749861, 0.22923382359646985, 0.07410938460980693, 0.2187609420188012, 0.31709549768317136, 0.0871563445956957, 0.14153469804554217, 0.12473890212394538, 0.1064447301530069, 0.16635141155171781, 0.16464230003616503, 0.101146083024721, 0.09708940997839936, 0.14801777839179964, 0.13463270550052966, 0.1766793339723541, 0.13778601532741902, 0.15352755935201723, 0.2579358286194263, 0.20731442397640598, 0.1188989372683629, 0.09562674128720838, 0.16922529846910508, 0.1905411433789038, 0.09774835284558997, 0.11844926663944799, 0.1894059389709465, 0.13851200620974266, 0.1638871518474433, 0.1607096949291806, 0.19950136902832216, 0.06584163349602493, 0.09076271882100452, 0.06645710853439185, 0.1601578817973214, 0.18924613302994162, 0.43398629633649705, 6.075213051611378, 21.965208245861916, 42.22846085025419, 53.81704861117948, 51.457182053596746, 50.66465931553995, 46.992897218273534, 34.37758199630245, 36.360351885518725, 32.550649835217385, 43.404830655744, 41.024512860082815, 35.992308047509965, 21.641591133609897, 14.470320766971959, 11.04012764269306, 6.043765939051106, 3.9236785279166315, 1.5395659616877957, 1.3531239402870978, 0.8883757817168391, 1.0309229262413517, 0.7307660002862254, 1.4701477318040788, 3.141329682642414, 5.01385792609184, 5.838931923912418, 13.749340099673118, 6.882858978163812, 7.208334313284967, 2.7595921149176936, 8.298042781891363, 6.345248626124475, 7.338583479004522, 5.65754387647875, 3.2829814236010275, 7.049013030144477, 5.792422419594181, 7.837271171231424, 3.703840711424428, 1.7010281234979632, 5.561493856291618, 30.062049127394157, 5.964373244393257, 6.378342643860848, 22.92576139973056, 10.006031028686031, 10.519372205580435, 4.2842656950796805, 6.49288320733655, 4.6864522945496345, 3.264822565740155, 3.1532323600784427, 0.5037894087933725, 1.3358591376773774, 1.8148116695304073, 2.295499972758755, 5.247438501927161, 9.706931671788617, 10.518600479249033, 16.651118378485403, 24.41203178897981, 23.740037602763024, 14.932499527931215, 18.206589183499737, 25.96805564818844, 47.231149827280355, 47.312444871471776, 46.46417740852603, 40.116382183567175, 21.42600590182889, 6.497991113893448, 0.48980389150881004, 0.1740940936630772, 0.2473994536745933, 0.1395671850731296, 0.10344845302883657, 0.11055923517673247, 0.12476591438415552, 0.10095361109462478, 0.14073301767629964, 0.10950021821284488, 0.10398311345207115, 0.1647905380495133, 0.1573186067323531, 0.20679126253291485, 0.10378802916215313, 0.10965823150810697, 0.12415065385040738, 0.14637668016216449, 0.16566049217456774, 0.18684974871575835, 0.29478306431443463, 0.14047026484002992, 0.1842518985992478, 0.10990147208494526, 0.20621493458747867, 0.12931525857458193, 0.15907028209297888, 0.1890712045133114, 0.24233830912459284, 0.09214864082394109, 0.07549256401797456, 0.2359314392050428, 0.17494057485413167, 0.19530821741828996, 0.11754274713776766, 0.08786781045097498, 0.1799382107152093, 0.0769264278032126, 0.09969289850203261, 0.16387630404243547, 0.17318280143362863, 0.13584945230714737, 0.13413539186360376, 0.16776729525337297, 0.1527455521206702, 0.07894999542904478, 0.09850449694861328, 0.15804648219097048], [0.011673046411165308, 0.035282723275163484, 0.029678462606464184, 0.02109718234879115, 0.09482708339008594, 0.02120260370805139, 0.05857832324240477, 0.037910194181266336, 0.03332242302055801, 0.020958244642843644, 0.08356109396704743, 0.05397177526667234, 0.05302188369715887, 0.07447936677283819, 0.049007659582721616, 0.0984089121583008, 0.04254230651103201, 0.028304016600633343, 0.09784768380585218, 0.026365256823238828, 0.04626637865458766, 0.026022894045097694, 0.026182050726586775, 0.03760982259747483, 0.017821239082202796, 0.024699938723877556, 0.03584150397669404, 0.0325407758505354, 0.048555855398937586, 0.0330405026644228, 0.08078084597664495, 0.0350439413300445, 0.05578875962284304, 0.010046250085466573, 0.011974801741270049, 0.05949605444085695, 0.029649676852709347, 0.03713213613316898, 0.03590146184808785, 0.021580562761594212, 0.05170501302927733, 0.04238794745516874, 0.020814741052867427, 0.01310819626650623, 0.06908252249441801, 0.02022493570562332, 0.06930396786981052, 0.03676405769862956, 0.013337520856199967, 0.03740881261746249, 0.056726891742718805, 0.06086099712598709, 0.04986070231684754, 0.028761610493905125, 0.03310980297805321, 0.03008400274050092, 0.25715907675123983, 2.359120571805585, 10.437653545410404, 22.621897343666326, 38.31452769617881, 45.04212602492302, 43.53930911710186, 41.48923135572865, 27.846200235428352, 30.467549639363444, 21.487228216663485, 18.58573332909615, 28.172149196747814, 32.572652370699, 24.361017442518666, 14.52616943467048, 11.896100601842328, 11.21905146106597, 6.504040879587974, 4.029486424499943, 2.079672779767744, 0.9563478214606163, 0.48973145023469006, 0.3633397210749888, 0.23991503512426732, 0.6435120177845801, 1.5886237808773596, 1.3159103307031816, 0.5646477399333831, 1.2258963479149727, 1.970964780738277, 0.8178060910394116, 0.6574297516096024, 1.4562255240255788, 0.9410903530736124, 0.7330525582355838, 1.9137523539604682, 2.6804749667644505, 2.1657702759388955, 0.5538360942755977, 0.43846846227684333, 1.0708269140412732, 0.61056355675382, 2.2851324129489163, 1.0608173930837264, 3.7608116672885035, 6.065212968857058, 1.424486317461537, 1.2290037231099222, 0.4628242972877718, 0.9047226884192037, 0.6475092807123739, 0.2775644721283067, 0.9097729238771624, 1.6184211690579693, 3.614348649017273, 7.445539649455779, 9.11740335725969, 12.300518539644058, 11.221751032337066, 14.250001234392967, 16.834434270858765, 20.410110066013953, 23.773675849360806, 22.916443809386223, 31.843885798608106, 35.92716924605831, 32.96321061349685, 27.35775532261018, 16.67679813600356, 4.4234882631609524, 0.24401414178071484, 0.02392770294400473, 0.02140071979092975, 0.026287121600621653, 0.03397964218991899, 0.0462437292651063, 0.026994714881443692, 0.07035123304493966, 0.03465546963496074, 0.06052341282127365, 0.0834247992644387, 0.03091880109071011, 0.05399930080579174, 0.02413400467635403, 0.07876691573690023, 0.025549817514876207, 0.0384623903570877, 0.014127180348300647, 0.04322572588740338, 0.024271182295295502, 0.0868785611143516, 0.11392327280895365, 0.028487734060974854, 0.07042700680153025, 0.03203161849430011, 0.03968111750098967, 0.009750707728427746, 0.02385792191020183, 0.025867046863441507, 0.012768498516731687, 0.041750677215356025, 0.02285052586587206, 0.03643963478445526, 0.007437095384023363, 0.036370495349288955, 0.04732245384084602, 0.05652162231384747, 0.038381771094376044, 0.03718830569977722, 0.04769924269508451, 0.05725718546478499, 0.09225203971108122, 0.06534556092153634, 0.02233761084836818, 0.09296927420843033, 0.036989034739353006, 0.08451822889788498, 0.050198903322340026, 0.07614159370742499, 0.012608223346873157, 0.014818577572793491, 0.05785548864232917, 0.012046524807960998, 0.03615820855503121, 0.07538635358815232, 0.02731027224311425, 0.02035849355912257, 0.03866963246236405, 0.03323590871126902, 0.048999259428631876, 0.019428694560643167, 0.01752361200840002, 0.05138603700024467, 0.02292683588400964, 0.05331403515752285, 0.062071052154586207, 0.06004838085162544, 0.04907019533998063, 0.05850830280612554, 0.02887459697141763, 0.07387833249184393, 0.02996652890297194, 0.03491704652626668, 0.024135766678579876, 0.02816920810859771, 0.02980832408572878, 0.04550581422424124, 0.04076689391607239, 0.02241898087724563, 0.06673049467105059, 0.020108781454543916, 0.028403611861229427, 0.09171647530409599, 0.03275849037773667, 0.004561546055840388, 0.02926846384070814, 0.02523064038776342, 0.047083744674079844, 0.05022612625672933, 0.04274880168058219, 0.0417446059685561, 0.022135103166463877, 0.03515996151573716, 0.047022541909809076, 0.012305310266392847, 0.04314814033287187, 0.018644479080854405, 0.02656537048037975, 0.04087619168022948, 0.03926113277914063, 0.046124411070899624, 0.07034249198172363, 0.006190876217348682, 0.04418733860215834, 0.05866133269944018, 0.4099140670751372, 3.7946367167657424, 14.756286067347373, 28.584898248795543, 44.92782815810173, 51.05309947844475, 47.51177972362888, 40.06714074842392, 30.642169637064782, 29.651596623082316, 28.66683852288031, 27.080353536913474, 37.779437957271455, 30.31302002168471, 25.123473252019576, 16.16221650954216, 14.527594235635574, 13.396043392919726, 8.762087610460098, 5.184763929536266, 1.9686562207437333, 1.1223257957927644, 0.3337965208676554, 0.11332776968277271, 0.156495675084091, 0.340407706436611, 0.15449194147461845, 0.6435022118591494, 0.2645486076512645, 0.35595892357730097, 1.1233573791480835, 0.5951827175674901, 1.2272907505112312, 1.279480827431525, 1.5474007735329292, 1.2304537743330002, 1.4390320595233672, 1.2201611072786394, 1.3759616954672722, 1.0332718131042298, 1.5695218381381806, 0.7169606668814537, 2.2586046880291355, 1.4937249763358025, 1.0453829890297306, 1.9534972406202749, 1.3069421990263848, 1.23000061800403, 0.8908074673625731, 0.2864872820435032, 0.338455009604654, 0.18634998359747473, 0.2214022752858939, 0.9449703126184402, 1.646378597905559, 4.748052137513315, 7.504664476840728, 12.29301896787459, 16.078051270977145, 13.467323645468682, 18.422858868875814, 19.470039529185144, 22.21710481951314, 20.56557713016387, 22.69499855656778, 31.807647020586078, 40.42783406472976, 37.6428492607609, 31.606996213236165, 20.292927295930927, 5.8478087379086405, 0.672556433466173, 0.02343107495577105, 0.021907381615751696, 0.03164121625764716, 0.05110271853364764, 0.07508197153407721, 0.06889154443577414, 0.04553582188823531, 0.12311660369197208, 0.05775689312647428, 0.0270183410330285, 0.05830107219216805, 0.034033130448792255, 0.028123748451170903, 0.08908250414195562, 0.05905640424199163, 0.04075330351629565, 0.019359853899767323, 0.02316389796173861, 0.038789383496247956, 0.049106209133301056, 0.05138715548861412, 0.05960969209310509, 0.027397251950817245, 0.05715851717057729, 0.06116329925134779, 0.010855418006559054, 0.015580275813267838, 0.02902318355477145, 0.04765416225118022, 0.05799741409118137, 0.07307069961942973, 0.024306700046684955, 0.05512909663300361, 0.06000816889647996, 0.03346260178894286, 0.10906537138526479, 0.037110057479191216, 0.0057342384975673935, 0.04665373186130197, 0.039640836597931, 0.039442515586532896, 0.06955149853902479, 0.039289792128387964, 0.058409833694778146, 0.05228814383548114, 0.08323710006211074, 0.04177040397940625, 0.06503288213524126, 0.06775767302080508, 0.12558566676753183, 0.14862409101859217, 0.10074352680314934, 0.17090131498632893, 0.15989621680590416, 0.1869242277837569, 0.13543188842313905, 0.08315717410897056, 0.07264345238405852, 0.20422543489163925, 0.2261846404402487, 0.14172795138532115, 0.21184770330306024, 0.20045485738064014, 0.18521713874032422, 0.16279756031449766, 0.19343001497609003, 0.17666405817914396, 0.14878503076972502, 0.10454472484848193, 0.21670958838395535, 0.158264709997081, 0.14739430539550322, 0.13854071918514468, 0.18576875268932314, 0.08902035142865874, 0.11705638855815896, 0.11928477745142677, 0.1599258797303323, 0.16204495553768453, 0.11010167384219748, 0.23716769061021267, 0.20424723775396425, 0.15349870848078884, 0.11712324505131091, 0.1949790907242606, 0.13311644895903527, 0.288416720446079, 0.14246773185028186, 0.18350024377146076, 0.13455902316397236, 0.20976210553799907, 0.11428384741227474, 0.1301773986028087, 0.08427319567530386, 0.20736641070294767, 0.18408479950120374, 0.13008747520225664, 0.1368239621121076, 0.1408541361771284, 0.1648288884110028, 0.14445042868535365, 0.10209977822077852, 0.16913943533455172, 0.17070833743820268, 0.5013231879040119, 4.059920094666943, 15.983607461375577, 32.46428904994842, 52.02006570754513, 58.663187949888176, 55.78858875459241, 52.83471845811414, 38.677405772670625, 41.29416011994885, 34.368168307888894, 28.412561070534494, 41.199160314375355, 41.60835373786188, 33.618564144257576, 20.793655110943703, 16.2598305748355, 14.793042598232148, 8.992752394368573, 5.117728662106299, 2.8255514271797675, 1.6205756534491818, 1.0839375589163074, 0.7492241227338392, 0.7353864910621798, 1.2218909950986987, 2.7056678600849646, 2.7936355913839033, 2.4549097543762577, 4.010837025219395, 4.587832141307093, 3.0232334906055085, 3.284027715844493, 4.110222285793674, 2.5599015528155915, 6.724973772802661, 6.073814726644947, 6.466292479345876, 5.931442495315306, 2.9790563256509843, 3.142861858490975, 2.1386213456430743, 1.6567882006206822, 5.165951751893567, 6.12282621283685, 9.714568526514116, 12.442892732158786, 3.1981876252159, 3.1155298025377336, 1.4969501452099894, 2.417525399115778, 1.2424900575030235, 0.7198919031408526, 1.8557677105549846, 2.293423322900649, 5.068409269855869, 9.460960818875222, 12.995112442201185, 17.840406510137743, 17.05220426282575, 24.18085317457876, 25.342555276809204, 30.102022001820227, 34.024011704229544, 32.370707181192216, 41.67149213052566, 48.25365681802073, 43.714419411074736, 36.8346841104569, 22.55396777583707, 7.302060819441273, 0.809134527319862, 0.13724187839656107, 0.16521677404882448, 0.13572652583881734, 0.10984906401004522, 0.13344038157693802, 0.12522450227650905, 0.2066501338155039, 0.20914650792556427, 0.14539015809855155, 0.21406771885531567, 0.23784405431680142, 0.08644115555310443, 0.14913983673097628, 0.160895609146645, 0.09904931569772382, 0.1352768322272647, 0.09581476990734378, 0.12955777136789215, 0.13788254240587836, 0.20351038374487432, 0.22436156568507995, 0.12287971398402607, 0.16149539470432267, 0.12180975728457975, 0.21859649358497513, 0.07361871295518453, 0.07660400437852068, 0.08413840250502672, 0.22015151417543813, 0.1900807551799282, 0.12197201470694236, 0.14273647549411944, 0.15786282027200346, 0.13197914547016545, 0.1327026695493729, 0.3316203715099443, 0.08402435499573908, 0.1280020612982973, 0.14486618460186068, 0.09909682080990846, 0.17999916067046506, 0.12630831750650562, 0.06126783577905548, 0.16491833683704177, 0.169274895001323, 0.22134192287921908, 0.18509488642936756, 0.26495276499659787], [0.06083034977857625, 0.020831652443795916, 0.05707650362784344, 0.024589081970794548, 0.04987705829403093, 0.03697457866022184, 0.03503809607918224, 0.11691907495861092, 0.032424483703629624, 0.07417792649639231, 0.043255381150952274, 0.06468493266091233, 0.03982552124427692, 0.042004754105883266, 0.053540084721340295, 0.05293675983745245, 0.06419657076138162, 0.014546742764181428, 0.011072189288003551, 0.0265190968545334, 0.037495250317959056, 0.030061587007836472, 0.057438683185365894, 0.03393214856905322, 0.04307772536131163, 0.023409894539884502, 0.025015168582960486, 0.03804425190713617, 0.0851644317228948, 0.009762985245024246, 0.021722850186990637, 0.024650669694247267, 0.015946069390573088, 0.05175825997045444, 0.052243308539712624, 0.12389342450807173, 0.025806543154401645, 0.05565009387810865, 0.04594328873340161, 0.04245677662472572, 0.048913197111218214, 0.025928904632887533, 0.05414405694952416, 0.0839811552976889, 0.029698055305127657, 0.040037907629964814, 0.06798124045974786, 0.044142955298265146, 0.0114320227012579, 0.03932145071185885, 0.02233949733988172, 0.0249961466198006, 0.03990145204889198, 0.050730928403115085, 0.04221780315762566, 0.019821871950801824, 0.10158015610349756, 0.09838695607839093, 0.8963067529182281, 7.155316616258315, 19.286113708249985, 33.31574147747409, 44.9656476513032, 41.27976894378662, 38.6996966023599, 28.33788698719394, 21.07885652972806, 28.90635217389753, 21.807813336772305, 46.613031356565415, 36.85567663561913, 28.42726407512542, 23.161925346620624, 19.30364474173515, 13.715095846883713, 9.621817219641901, 8.990697072398278, 6.213724199802646, 4.031267916002582, 2.6556797037201547, 1.6910819733335127, 0.807583413777813, 0.4666788533570305, 0.46346551288039456, 0.16510797424181817, 0.3930028293642306, 1.089416742324829, 0.38286092841336805, 1.364955034467482, 1.2596471175070734, 1.4397329380435329, 0.4422333554154443, 0.43085658201767557, 0.5440503322789746, 1.0936487345926225, 1.9934111569196948, 0.389342982201807, 0.8044225962892656, 0.72741151577042, 0.22615531459450725, 0.40506702877821466, 1.099943893571054, 1.1834461290028788, 0.6438371454996448, 0.7942986524393483, 0.5385192387527036, 0.816884640484087, 2.355713503014657, 2.9197167484991016, 4.749953996750617, 7.353769425422915, 10.454931586019455, 16.032957742291114, 18.863764655205514, 16.511827168926118, 16.75578486534857, 13.104918214582629, 17.474257176922215, 20.066461409291914, 30.789070244758364, 33.1707275298334, 34.20233049700337, 31.821492987294352, 23.89068211278608, 13.8799540458187, 4.283438074973322, 0.2705790985736155, 0.04658897827950217, 0.06615535416189702, 0.05373176758087451, 0.05253029656746695, 0.04495870870267672, 0.02949383350149278, 0.028491022493389827, 0.022676872885635784, 0.04840562172654656, 0.029089932795614008, 0.024899085195014076, 0.02512858981537002, 0.06786943758807837, 0.054985298099176544, 0.028887423198489897, 0.021902997677605, 0.028391647483071977, 0.10560584089328205, 0.06233436806548027, 0.03826407317612921, 0.05253559789590297, 0.05730230038264587, 0.015408463359269646, 0.04424880566676298, 0.03542541864237959, 0.022657182510761965, 0.0069638517508733904, 0.0488313865817843, 0.049681962512794046, 0.006613393338592423, 0.08394524109579864, 0.030812925824354735, 0.0678707859028251, 0.009512951383517395, 0.06506822943206757, 0.04563847383964927, 0.019177542210766868, 0.016019614788913922, 0.040256740645535534, 0.032902928594980514, 0.040995540517953136, 0.032441383603239254, 0.10678313417179931, 0.007625010048580026, 0.02074756280278727, 0.030227259267121557, 0.04597320446684476, 0.05477669235739497, 0.06050718324859777, 0.06144472548077184, 0.031093300598102714, 0.008842052756658485, 0.057088611647486694, 0.02945778523421576, 0.10880664051059755, 0.025397971227404573, 0.0325686959249358, 0.04325032880109164, 0.05509209075582124, 0.02894859148880407, 0.08257687016720734, 0.026649115381822474, 0.035190616524027246, 0.05519602207406875, 0.0428302176747351, 0.061556796483214826, 0.02272640813081976, 0.026310121475328362, 0.03393916210400001, 0.05895936771506264, 0.014897351521217536, 0.05789741663442505, 0.07899876458630448, 0.03706666625915997, 0.051132971345777475, 0.05383636539561614, 0.06637197318336656, 0.04666540704126801, 0.06067692918042022, 0.02664323948744324, 0.006495028923851468, 0.03155936359337742, 0.0621282865834092, 0.07699125416336522, 0.031481620990821434, 0.005937371498739888, 0.027656457799997543, 0.032393729103909384, 0.0341209969032676, 0.034483348830573024, 0.002282314301062856, 0.06626494303946534, 0.08117189555759392, 0.011909262919347855, 0.019658867592713045, 0.11788080641699415, 0.08520664316752265, 0.010207469458691776, 0.024236740897439664, 0.04588182932967621, 0.024036994962502393, 0.023516279254709522, 0.04179539759793589, 0.025543993331431866, 0.01141855679076886, 0.03603517483439177, 0.1993128960771907, 1.6399864828394306, 10.814863962511863, 26.002421494453188, 39.89034775764712, 50.43177643129903, 47.76334877937071, 40.85012428222164, 30.81663273995923, 21.37465423153293, 24.58951903927711, 33.371446978661325, 54.1316266213694, 38.865244157852665, 30.986540009898526, 31.96069790470985, 25.173452092755227, 18.820118481113067, 12.270625175968295, 9.239103717188682, 6.491218161198401, 4.14810698839926, 2.1125944583646716, 1.5532204677020351, 0.4143566722350736, 0.39529113399405635, 0.1987187795701527, 0.04760532797644696, 0.06524219267791317, 0.38979809971586354, 0.25347324388642467, 0.3564683107599136, 0.07262862092184444, 0.1902311075959475, 0.41325105414275204, 0.5902526659830925, 0.46279074263668835, 0.877989529361648, 0.6306674199238901, 0.41730194322524533, 0.1307051872173625, 0.18523272096870408, 0.4074399708019149, 0.12289075331101496, 0.14355062777476926, 0.33945276251723694, 0.3216093490200658, 0.34059463189013545, 0.3174446499155414, 0.7797354435728443, 1.7040668572148971, 3.0113371870210095, 4.720591133640659, 9.228761407636828, 11.627011299133303, 20.703979922879128, 21.44628651680485, 18.299019836610366, 14.927741692912194, 17.012906036069317, 20.048447924275553, 22.309912020160308, 32.44808181639641, 35.58633881230509, 39.01128576647851, 36.93845825810587, 27.45209420880964, 16.866554560199862, 6.087316505370602, 0.48838886582563007, 0.0494201711168693, 0.09192221587704075, 0.04982390711384435, 0.04336853999824774, 0.0296973294368194, 0.0540099072931034, 0.01858852593408477, 0.01877944653613433, 0.06833332680886792, 0.03738711317700725, 0.03007318557901008, 0.022783271006999478, 0.015121287639973866, 0.008673673334170975, 0.050219744744320075, 0.02195765039012317, 0.04143090445488211, 0.040389821609301914, 0.018338122435154456, 0.0236533323843633, 0.051223668495133046, 0.07933398934021112, 0.021348723488289024, 0.05570111533386573, 0.035029826160039634, 0.01917997837036608, 0.00941699599817155, 0.048045284610482, 0.07686560808290398, 0.018514537162357764, 0.04935452504263771, 0.046690753060242826, 0.03821954048509079, 0.09006649045453918, 0.03329752133257928, 0.025878367727742563, 0.01500926930607567, 0.05368771369478876, 0.030595632645511822, 0.018179402423782215, 0.013569337146867429, 0.06776338037584098, 0.07120326837344516, 0.037752291968753265, 0.0586620872960456, 0.10857777940409799, 0.11547374283714641, 0.039405636113858035, 0.03170827001843962, 0.17133706579765967, 0.12137306418510214, 0.08600152833687683, 0.12564705339290444, 0.12972900734072731, 0.20576257498994951, 0.06987993575392232, 0.16094208004013186, 0.25603796836108933, 0.13847356391770227, 0.11554920249768805, 0.16527096710858807, 0.2992105009334703, 0.13258780232600628, 0.12228893762033795, 0.13732361997808182, 0.20740517475191625, 0.1436065981585172, 0.10351052913334101, 0.1324557747331358, 0.10582478116116217, 0.13931577033813924, 0.19176677680544316, 0.13375777180396742, 0.13144816992984665, 0.20765902564650585, 0.11758338044127149, 0.09213841355015194, 0.12975949764011369, 0.10144714791808399, 0.07156521427415072, 0.07373888150698717, 0.08235154072603873, 0.18155845603154552, 0.17527092728883992, 0.27061672881245613, 0.14056899825171118, 0.1508933813461373, 0.1290050542522823, 0.13104048858006156, 0.1161808266694988, 0.08207021791848444, 0.1917699330876912, 0.25435668115894644, 0.16121186556354647, 0.19937850384702607, 0.17052511985023178, 0.125913966086603, 0.1753542163679677, 0.10154346049192453, 0.06631804825437647, 0.12334076101861655, 0.10517991132914059, 0.17099341407658594, 0.12779846577154053, 0.09046897006731841, 0.23516145955410697, 0.2529409813183931, 1.6321096280890128, 10.877377717725693, 27.652799929341963, 46.0025889642777, 58.21668101895241, 55.6105641395815, 51.09642597936815, 40.89309776982954, 30.674056545380626, 39.995118187319854, 33.33347059065296, 60.249649401633974, 48.751283999412294, 40.816725300204375, 33.49363665426932, 27.61575314306444, 19.785125486312374, 13.887916457268501, 11.948878053695926, 8.001649370116573, 6.205139112087989, 4.170047746550653, 2.351553829446916, 1.1965971007462473, 1.70206853218617, 0.9568273925012158, 0.7604469431023445, 1.3568070458789028, 2.2338096701329757, 1.5366375446319582, 3.5454414304225677, 3.316201202331051, 2.984209094316729, 1.0350712004207796, 2.1611379567653906, 1.5832983053499654, 3.99102145625699, 3.943840246046743, 3.164188030265993, 0.8201300340794748, 2.746778957305416, 2.005495489124329, 1.3603559328663735, 2.743162286858405, 2.4851512284048143, 1.5573029196070087, 1.4937315953354684, 1.0463356346853319, 1.7987757945253005, 3.7395122166602843, 4.305451887269174, 6.445090107379421, 10.13198127669673, 14.170423207744477, 23.455142128852106, 26.72526332639879, 24.69431692554105, 24.43850386527277, 21.908910466778664, 26.37417393345987, 30.13589559062835, 41.015797353559925, 43.43472303882722, 47.15680130066411, 44.243758955309474, 32.61330969872014, 19.158152264933435, 6.971717332640003, 0.7889626968291499, 0.17637496724003748, 0.12596860347736266, 0.15485696704877963, 0.2145330559822821, 0.12121424649751956, 0.1086008156679811, 0.10023467588208376, 0.10875980955578628, 0.24183051540486275, 0.13697540237297937, 0.13461485565189393, 0.1496565936794204, 0.08795408727300745, 0.14070928427240542, 0.13589088234209246, 0.11071229954400372, 0.1588982187451855, 0.25168922429363577, 0.1468423850113346, 0.0773314431670212, 0.1021626663784827, 0.22132787282668778, 0.15521663000747082, 0.16007197269749257, 0.09381711137511077, 0.12363986472689337, 0.1261581566124674, 0.14761219612292706, 0.1990326611144889, 0.11513887814456418, 0.2148581224103128, 0.13729475378509493, 0.21527064543577934, 0.1641223561619559, 0.20299479125007508, 0.16622059437776768, 0.12006573514231753, 0.20442527658756704, 0.17408093227253807, 0.10386270741301198, 0.09123613817557212, 0.21566752494583208, 0.17586415513388573, 0.15156668070102894, 0.19356827852466416, 0.16788784684913774, 0.20019686961125946, 0.163129398959779, 0.1196169761580325], [0.03538786118189174, 0.04964170842281273, 0.043114106876835714, 0.05387486131381124, 0.025544952856557026, 0.04550525498005652, 0.01985504738836279, 0.053171221046678485, 0.02564269801481597, 0.06902984628874449, 0.027629049089286598, 0.022749484614318898, 0.04929251405560682, 0.040553588224875356, 0.04230923192094892, 0.0162095011722657, 0.030075095053161346, 0.026819365016455134, 0.00622328604579032, 0.042349275336751056, 0.05945988359951204, 0.0794754091710333, 0.05126591441371749, 0.032685853751196016, 0.04791126518900837, 0.07918477839519901, 0.007851196071808978, 0.021542003641145367, 0.056766885362805865, 0.040888000925582264, 0.04009646739089682, 0.08306152037074489, 0.04156889987268275, 0.0060632790067052895, 0.016134650551623875, 0.023877709961285996, 0.04385061231592009, 0.06759366125709589, 0.05173696272615945, 0.10718925270221888, 0.04138559035416092, 0.06711730778577828, 0.05339345549263301, 0.04037796639867368, 0.046921671112819065, 0.016145113397449735, 0.03536692399892115, 0.03052807518190915, 0.014414026649788985, 0.06385185800853276, 0.05752944928263465, 0.00627707451536891, 0.00413573810815691, 0.05233538081689228, 0.024591332354072123, 0.04304923838184726, 0.015155773087885353, 0.05999460147934095, 0.06395251813134359, 0.8025533417540213, 4.36550239401479, 16.480836522194647, 26.073938069805024, 40.16385070739254, 42.41843300480997, 45.37519408810524, 37.17453395166705, 32.383086181456044, 24.692883299243068, 25.14028649176321, 51.48241858328543, 28.23099651644307, 20.333043336868286, 28.843572678104525, 21.644899652850246, 25.753272541107673, 17.542596632434478, 11.381768045886872, 14.800851056652686, 12.801128683551667, 8.179236150556996, 6.392892676015054, 3.817062132781552, 2.764263657792922, 1.6930244045872844, 1.1312130285847573, 0.8269438039391273, 0.8428170231561508, 0.8072790623672548, 0.810316447769442, 0.5827040032994363, 0.5512657773590858, 0.9735540949529218, 0.4886671396032457, 0.48970344206017835, 0.43637912600271167, 0.8107449667107675, 1.0195482978897712, 0.35767401057866316, 0.40819772368957924, 0.4098072744184925, 0.7468110070593896, 0.4143912687657341, 1.6133350806851543, 2.4591304698298058, 3.904052458463177, 6.057692314347913, 8.105999615884597, 8.833559078554954, 14.514267002382587, 11.67932983367674, 18.401705526536514, 16.058120727539062, 18.708415262160763, 21.957216416635823, 23.47010204868932, 24.257939515575288, 28.943193035741007, 36.23293761284121, 35.27551451037007, 35.41370745628111, 25.328205285533784, 15.005629178016418, 10.457394834487669, 2.3127765424789923, 0.17806613697640358, 0.09481576827144432, 0.05281403638242234, 0.05067577390300651, 0.02890601423719237, 0.08415700311982825, 0.03354157779305693, 0.048798678457857146, 0.01832418155015236, 0.019288684331601667, 0.045604934510324276, 0.007753999145220846, 0.01529140895487921, 0.03438186516324359, 0.04228143825105602, 0.10651500339830115, 0.031219302909448746, 0.028917528538694306, 0.05429504138808097, 0.010969612987772112, 0.0271355141810472, 0.04587838193401695, 0.09753491308900619, 0.004642380301975796, 0.0735466700467852, 0.035149163506444425, 0.020068678666927645, 0.041099452684002544, 0.002343492646281037, 0.028023611183368394, 0.03646310771845522, 0.047013513563621434, 0.010115766818935593, 0.04240838285054892, 0.02849957394984461, 0.05325126191300731, 0.03174410186587803, 0.0654656068992711, 0.01238891056873986, 0.03875354590315012, 0.008405423817044545, 0.08924322938846965, 0.03675785621688251, 0.13957380407279538, 0.030539807818469503, 0.022937193392745914, 0.0055408937060424405, 0.05153456229656454, 0.041694404226878, 0.02450580629820545, 0.06817442485161367, 0.018533833001950578, 0.06822016030069321, 0.02530992857270664, 0.01760101944748913, 0.03524089870493739, 0.021563988449352405, 0.04956234554429689, 0.05177442442565676, 0.06869542592715833, 0.0946811436405105, 0.009779388145092997, 0.055239401802781134, 0.05482482566167751, 0.036838119248709375, 0.03749773244283373, 0.05771835890388297, 0.04835484158848563, 0.027084695738590053, 0.018861209185072975, 0.03908323184136422, 0.031217364707000317, 0.11668752488349715, 0.056941729609764395, 0.06361525558355836, 0.05323180327973059, 0.06628848492137848, 0.013472820602117047, 0.028320223190671498, 0.01731700384088101, 0.031163252086468765, 0.03466181284297378, 0.025535911103830706, 0.036406428703377326, 0.05349518813853783, 0.04836555915854631, 0.015563376871268115, 0.02464561734438664, 0.003971577196704945, 0.016473966215046185, 0.037812766949495966, 0.04825517737997636, 0.06809832933809488, 0.05659820046275855, 0.04782870389340867, 0.022531341077880036, 0.02462486402251788, 0.08013552415274805, 0.020801054892100154, 0.041057317848167116, 0.023544072924602418, 0.032688301402114095, 0.03232905213090201, 0.06340724739035772, 0.027035725483250235, 0.012962239279952503, 0.039952408387175495, 0.0811010707289942, 0.04222855137120332, 0.10288907860916469, 1.0647268929789144, 6.830063385348167, 21.834871807406028, 33.84641462756742, 45.36328969463226, 49.41831834854619, 47.35996830847956, 36.93768947355209, 33.861331401332734, 24.973148415165564, 35.77898994568856, 50.37988739628946, 34.273800003913145, 29.06840489756677, 32.91283169100362, 24.408164331989905, 26.602098941802982, 23.459386133378555, 17.073192865617816, 16.534247436831077, 13.629314591807704, 10.00074367369375, 5.515910521630318, 3.7706202893487872, 2.5018808726341497, 1.503302423704055, 0.7779431655522316, 0.6698867089806065, 0.6829497338302675, 0.3954004394190927, 0.4183592671348203, 0.12663552898072428, 0.5355849994286415, 0.4032291225608318, 0.30091565943533377, 0.09461596487991272, 0.09305369709768603, 0.35183320302636395, 0.3920939120073473, 0.4290344878550499, 0.45939439907670027, 0.2601996490791921, 0.3523989436366866, 0.43760526504728103, 1.2721349635431844, 1.8142256429118497, 3.21360670751141, 5.981567444339876, 10.026582287203881, 14.143633419467559, 15.807242989540102, 17.18737502251902, 23.711490592648907, 22.681232998448035, 22.99928426742554, 25.080478191375736, 22.800855482778243, 23.784244675790113, 30.938098738270423, 37.45279473643149, 39.207557247531035, 39.406456716599, 30.712868398235692, 20.77201735588812, 13.267312184456857, 3.3208913764645978, 0.26257856658870177, 0.04903398236379989, 0.04853866438591673, 0.03300489106726262, 0.046832238008538564, 0.026679596105109782, 0.0405180340843095, 0.07125450433382104, 0.02320831382436858, 0.011247905917585859, 0.04301784792914987, 0.02637698371413975, 0.00912499488256271, 0.02130500859610977, 0.018726804804417397, 0.06169920456745933, 0.050953465453799696, 0.020012181597731767, 0.02348650524753236, 0.03188991712616577, 0.03410903827076958, 0.025401175390147877, 0.0387434488643081, 0.06767688138831048, 0.03817635993923872, 0.028633158616421205, 0.0208333493285482, 0.028049773085982572, 0.028191893887255463, 0.03585204917697176, 0.021944192140513373, 0.05579655073703297, 0.047433908142509966, 0.015774666793614386, 0.02052543943958177, 0.02304122238720377, 0.015812677203587467, 0.05378874537024287, 0.0637226840931802, 0.03302023197794634, 0.057165618805635365, 0.03535953891133109, 0.02743773778239566, 0.016081604708526886, 0.03600605200195024, 0.049609628490983486, 0.018393353544055455, 0.05158905030017899, 0.05619117411814871, 0.08928788465357597, 0.030620279609255736, 0.17433865957202452, 0.10573923212265778, 0.11378569873951136, 0.1911609238314052, 0.11702910050629609, 0.14662987222113918, 0.09186937879290312, 0.12870392041100612, 0.18232115784720068, 0.2268741348938596, 0.1851241969533505, 0.10259613424779908, 0.12707411431737486, 0.12444231884493945, 0.1234170480541164, 0.28043616803423055, 0.11962316614846069, 0.12014579133040483, 0.1341900752196389, 0.11776723388221957, 0.15897364776221015, 0.1921070424178916, 0.20986255498663073, 0.16378916920192782, 0.11900852614593123, 0.16060915354999805, 0.10568518461959978, 0.10138025312053581, 0.17201188200664136, 0.14068285423901775, 0.13850892653628705, 0.15030441294995048, 0.12495280153328374, 0.13078911981034663, 0.14990258451190688, 0.08241988342976378, 0.19662668537949363, 0.15624769242300143, 0.09147422298068002, 0.15498108861427154, 0.1109377668809987, 0.08439976106127424, 0.11204837220570735, 0.15287114457497675, 0.1072629043952592, 0.06937684581404732, 0.1888188704728119, 0.13202494220627894, 0.10463747511347456, 0.1663885821378039, 0.11682205758388005, 0.0877238472082442, 0.17966589710164457, 0.24292079641694025, 0.1456725687509583, 0.14905584285095816, 0.2176133882735045, 0.11967325297695015, 0.1310168011414428, 1.0183630679403584, 6.841089167902547, 22.432495893970614, 35.774683183239354, 52.250716763158, 57.31379062898698, 57.75041710945868, 50.809147665577555, 45.05588962185768, 34.76803825747582, 37.66719933479063, 61.528942200445364, 40.765452077311856, 30.071243163078066, 42.05236604136806, 32.91626376490439, 35.316479744449744, 26.157108006938813, 17.272570863846813, 20.191896846217496, 15.980895142401419, 11.075907503404926, 8.059227803061086, 4.533770113222061, 3.881413518421112, 2.2541883443632433, 1.6293846839858641, 1.3019935161836687, 1.8503734709755069, 1.283190286447925, 1.2497406813406176, 1.1546190371436458, 1.386320307370155, 1.7618863933509397, 1.4991993793556768, 0.7644319486233496, 1.0675682824465538, 2.179860410190398, 1.6704652602634125, 1.6132104228581152, 1.1012453850238555, 0.9314234879228377, 0.9563082300366895, 0.6771023379218194, 2.549330274904928, 3.047242318430255, 5.2646782994270325, 8.662937937244292, 10.818721613576336, 12.03061926749445, 18.63549251710215, 19.022716745253533, 26.796956408408384, 24.24688039287444, 27.530325881896484, 33.01134201788133, 33.842860960191295, 33.52791816957536, 39.99147430542977, 48.95816549178093, 47.342768715273955, 45.731427669525154, 34.30278239711639, 23.022732196315644, 13.986023760611012, 3.825062297044262, 0.3513126309600569, 0.25262630304261563, 0.16724522165473432, 0.1299412290175115, 0.15135309538773953, 0.13434494755441143, 0.15145228845217537, 0.1886133750480029, 0.09629260192835525, 0.07404134834125158, 0.13419182190010626, 0.09860601892033893, 0.1045376691786993, 0.14270918744225658, 0.0909340620461491, 0.20597165570624415, 0.1328923988847002, 0.09212415665388109, 0.1281217395538284, 0.06262761503157598, 0.13335670945384812, 0.15390979126095772, 0.15624200805060326, 0.13690280788127454, 0.21034944982778644, 0.13214321086002936, 0.19626288554601132, 0.10700315462365266, 0.0540212722074601, 0.13854530039093188, 0.1195558193590372, 0.09681729554769494, 0.2631801294703638, 0.1491660062944697, 0.1466056638427319, 0.15491770249941658, 0.15563362698641517, 0.11889925136441186, 0.1466755157396678, 0.1578461655205296, 0.15339465841891306, 0.12792919101493974, 0.1087713928052014, 0.2388153159089627, 0.1619529943432539, 0.19843931069537518, 0.16658656990095494, 0.15662592535297717, 0.10816138763461383, 0.19525299780070784, 0.18608559133304706], [0.034792036298782594, 0.031226868027701016, 0.04450582816535908, 0.07809059799558694, 0.11581380926673451, 0.04569160969807737, 0.028335267242284554, 0.03318571463047016, 0.034302881498250275, 0.05967728020022473, 0.00947162572805199, 0.04676915449841369, 0.02329109345502671, 0.045429036892469854, 0.014816716936747394, 0.07361050049263625, 0.01875978680477748, 0.0104067777659023, 0.05517991507546075, 0.020690615656935883, 0.023497688216007045, 0.07102081687339852, 0.04291148045130315, 0.06133823159841761, 0.033037311908218174, 0.052702651028671575, 0.04227321812762849, 0.10624863462702883, 0.014098661767709401, 0.08230406625737106, 0.08448196229554954, 0.08699383436431808, 0.0730421475224918, 0.014742419814630864, 0.04889777576130244, 0.045428274634985194, 0.038028979944365646, 0.04262912342505109, 0.025043429566487193, 0.01676878366138666, 0.022626563891648285, 0.05434677147516801, 0.09018917177473346, 0.03461627274631493, 0.044280870276833736, 0.05376645221164631, 0.04102041922329415, 0.016118717838018652, 0.032341677259894154, 0.036015398274626464, 0.024331389145264705, 0.05593632347881795, 0.03877229590509688, 0.07209319441068558, 0.020718156517813766, 0.014768875703485984, 0.05229093239552552, 0.006273926851610023, 0.01440314437082458, 0.022479961476018353, 0.5284863674352246, 1.8495036853897957, 8.87029109462615, 20.60570101584158, 36.04261244496992, 45.342842378923976, 42.74775520447762, 38.104837786766794, 38.60504981010191, 26.717028310222013, 59.615696322533395, 29.512132829235448, 26.680713045981626, 28.36709099431192, 27.40489632852616, 23.55002034095026, 17.026506854641823, 22.42532187892545, 20.46155587319405, 19.55781629008632, 22.646853423887684, 17.11841191014936, 14.71886077234822, 10.232166455638025, 8.773780195943772, 8.241542020151693, 6.9333815574646005, 5.034777887405888, 3.8091573311436564, 3.4468281413278277, 3.0580886525492517, 2.748228273084087, 2.584979226512294, 3.3011106185374723, 2.949620653544703, 3.1614129533690796, 2.4565402346272625, 2.3808424126717354, 2.6608677737174498, 2.9050154599451252, 3.232187710462078, 4.487333663048283, 6.124785436737922, 7.557103133970692, 10.103825523007302, 13.99924607046189, 15.69066720624124, 17.18409788224005, 15.845920501216767, 16.313781795963166, 21.372710697112545, 13.227941393852236, 19.76343477925947, 19.245721140215476, 22.31473849665734, 28.94534641696561, 37.038780720003196, 35.07260245661582, 32.29157140178065, 25.144495194958104, 17.022453085068737, 9.601821957095977, 3.518509456226903, 1.003397816131192, 0.1605528767310804, 0.12442537298005436, 0.005843964792157133, 0.02220796195850257, 0.06371334165094361, 0.037044392252761515, 0.11402312470900436, 0.03718272857968846, 0.02100867429567922, 0.06602839807108526, 0.07450603429348239, 0.06764668986321458, 0.013928215823046142, 0.029267963968337547, 0.030971429415888367, 0.07153523725367363, 0.02501729256173055, 0.0674878032277188, 0.04316380300048379, 0.04934522090479732, 0.05552434820621725, 0.07649006412154244, 0.04715187670362573, 0.01905021265209202, 0.060752882967673005, 0.07112526530099493, 0.07255991049591573, 0.03534190356731415, 0.07325235438803512, 0.09803044174106852, 0.012012746076159661, 0.02027171877993932, 0.06031832725350415, 0.053540318378157196, 0.033827236658262635, 0.11342673292083126, 0.03252867932221101, 0.028163594599332542, 0.0207118631055158, 0.08726661529151664, 0.07976106037535975, 0.048746730035711686, 0.04906438839351458, 0.0481281676630099, 0.05828973792132832, 0.01264790191330136, 0.02141246200358916, 0.05687572347420839, 0.005312148470341439, 0.03197830260520981, 0.009071326593027241, 0.05271180577936673, 0.037365907863263166, 0.031021405161628803, 0.056530076094091906, 0.008575589182005535, 0.014167838549662023, 0.040894202407329314, 0.0355020389261265, 0.08736652081772205, 0.04936419307224212, 0.0409611163570756, 0.019869122338751634, 0.03668885850798219, 0.06341690009820365, 0.12389710939098751, 0.006862854070570921, 0.050810517277568586, 0.05255540892962487, 0.0879746950381706, 0.048359993529776414, 0.028163816764830586, 0.0734913508377729, 0.09260037222937231, 0.03273430881240676, 0.10477264366683461, 0.06571943481122294, 0.00740235616948696, 0.036288393706443815, 0.04410943129069863, 0.038694281341327776, 0.0879175142355023, 0.05557018707716658, 0.03519673756654224, 0.0773533839251726, 0.040547329286533984, 0.05346788476491648, 0.013821437530550025, 0.03362791973256296, 0.031857389032900814, 0.01364470487685814, 0.057993644938593915, 0.06965521918309313, 0.04057793832954861, 0.062406583343662565, 0.1131727058260191, 0.009538442001587922, 0.02849313881128065, 0.025965370418083285, 0.0039098142306395476, 0.057285549870181474, 0.08509035868149611, 0.02293606915871703, 0.068989634333599, 0.01976786658257967, 0.0579124242968617, 0.03494190224896997, 0.038913493570421016, 0.04417989605797395, 0.023499714518566767, 0.03301640536876456, 0.016165259594638503, 0.7702561167459335, 2.991324518957446, 12.468997086248091, 27.359728274806855, 42.68245166347873, 51.385281085968025, 48.21285240111813, 41.74833920694167, 36.55454058800974, 31.23656757416264, 61.754180385220444, 31.531851445474935, 20.43602908811262, 34.20560175372709, 27.208438534890455, 30.4814269850331, 28.158879818454867, 24.099895454222157, 27.797851139499297, 28.70798222480282, 23.20210022311057, 18.42923075922074, 15.356937243092446, 11.050743537564433, 10.480335797033003, 9.226617832337658, 7.503624558448792, 5.250510208068356, 4.3156956472704495, 3.4945378909187936, 3.265382238934117, 2.1783875601906932, 2.9047384425517055, 2.344793869603065, 3.2535425645689813, 2.9000215472713595, 2.7602000822944026, 2.25373653634902, 2.0449328374478126, 2.7677447613208526, 2.9219203850915356, 4.6936763198144975, 5.688606596762135, 8.11529416230417, 13.170697342964912, 15.742730786723477, 17.433070328927812, 19.751812796438895, 22.362165835595903, 22.660956305842248, 22.294383356648108, 17.989801745260916, 20.420980914946526, 20.355924483268492, 25.272952818101455, 34.705296024199455, 39.28972305790071, 40.53770749799667, 38.32994261095601, 31.56658011098062, 22.58717260053081, 13.307846938410114, 5.486324083420539, 1.5749191420693553, 0.22477157594215488, 0.0922993379795263, 0.03370684977140158, 0.04581856195844951, 0.029702063860191457, 0.02361496478589552, 0.05120925838127733, 0.08285450043096658, 0.06880474667395316, 0.05034963112144221, 0.07776691052581995, 0.06709277765044282, 0.03520841274650828, 0.018893354234375784, 0.024897941808787086, 0.07490738009613368, 0.053042162044514576, 0.04677097012679424, 0.016128207752180677, 0.03317502387348683, 0.02308866429713465, 0.11755551016258618, 0.007203223583694067, 0.013609625710805338, 0.02408519529947831, 0.08237397178046166, 0.029537192162787242, 0.026013710566105384, 0.012287225803330302, 0.11508676884395462, 0.012495419772852574, 0.05641574130183267, 0.09460621258063663, 0.037939317013707854, 0.016024746620396695, 0.09533726730413976, 0.07175668262906613, 0.009381030085346392, 0.00831389067424161, 0.0760043413949109, 0.0392660319114164, 0.02724099682734138, 0.06637339044602648, 0.01783282807727735, 0.01722247433668423, 0.01396826594211762, 0.03732261240422245, 0.0598400853754532, 0.06228329298356849, 0.05809343555161069, 0.04305000063933192, 0.052863311157712055, 0.2292047888641396, 0.1415440443182184, 0.14960911154987352, 0.09612566370877529, 0.1444053367501305, 0.1612465387029994, 0.1355806933415513, 0.1888375017311304, 0.12065019894150958, 0.16197510364074863, 0.11439706754660416, 0.1868609795647283, 0.1902367460030702, 0.2710163815607948, 0.19833558239042762, 0.26386259123682976, 0.10008374890012127, 0.11445320646969542, 0.11918251237441456, 0.07262188700899001, 0.1438908780654592, 0.2122297666726574, 0.08816908984895676, 0.255643846767564, 0.1850817403605869, 0.17722720941228254, 0.0939468713477254, 0.16586087013204254, 0.21202689126854946, 0.2289549063049978, 0.1912590903380225, 0.21170254496316757, 0.15767468439955867, 0.15360847355857973, 0.21353868917832453, 0.17908166312882978, 0.13114533537337858, 0.16398378617821202, 0.11472028004185808, 0.10096031436396223, 0.20437897423342352, 0.1772610858202942, 0.2080689746165468, 0.17310718855550214, 0.10533708192768598, 0.12177720620867707, 0.15031463256286037, 0.14348485146559056, 0.18267219465586448, 0.1716207941212962, 0.13901325753859936, 0.22304821519121049, 0.055449719751073476, 0.1903548154739603, 0.09373390656565467, 0.15860212576245108, 0.17223933351136025, 0.0647602237821106, 0.1016356974780079, 0.17631737274989007, 0.7055507984853561, 3.212450098606848, 13.380064637430253, 28.82188589342179, 49.29994121674569, 57.56217472014889, 57.978448021796446, 50.87770285144929, 51.73923577031782, 38.92434643160912, 67.9931886734501, 40.32107499337966, 40.37787875821514, 43.66198516661122, 40.420828711602, 35.16407997377458, 29.952254141530684, 32.72563853571492, 30.759219046561952, 30.033764916081584, 30.575497188875755, 22.594762386814242, 19.373029508898338, 14.113944019040755, 12.467046687679908, 11.799170990144054, 9.456625619242269, 6.476463675498963, 5.511098263725158, 4.989323010367732, 4.8800531318110805, 4.35049295425415, 4.0825786465598695, 3.902535481799034, 3.9463664975858506, 4.659445305024424, 3.449672349999028, 4.077251822717728, 3.35827328024372, 4.120176280698469, 5.242262444188518, 6.760611447595782, 8.583758031168292, 11.147767286146841, 13.51825366097112, 18.504308846689042, 21.42775135655557, 24.277945564639186, 22.62662772209414, 24.024272157299905, 32.264367803450554, 20.748222297237767, 30.15713914748161, 28.712490989315896, 33.72712358351677, 41.969745236058394, 49.09562103209957, 48.26228603239983, 43.36772503391389, 34.55086054340486, 24.811501656809163, 14.80485873837625, 6.3713103244381575, 1.6802898169525209, 0.39025772182691487, 0.2823983337129316, 0.1364163726928734, 0.138009084809211, 0.21825058956540402, 0.1268636852863335, 0.2157110693834482, 0.14290988715665956, 0.15605693652985558, 0.20663568539725197, 0.19903226274876826, 0.1426470883551144, 0.11694047945521532, 0.17629607550559506, 0.13027893589629283, 0.19282918753883532, 0.16795736166738695, 0.16913444044128542, 0.10102995175627932, 0.17463663713105265, 0.1247747703605602, 0.18614148510800255, 0.10227947946517699, 0.14889128716482272, 0.1274995229417278, 0.21019119138438858, 0.2721549720773774, 0.22388458402166445, 0.24370019894934472, 0.23835682760803933, 0.10551717387692583, 0.09718255860911262, 0.11362895715020357, 0.15993593080389887, 0.07794334057478175, 0.25445907647090577, 0.18792185812227188, 0.1704390575328181, 0.18216826201927278, 0.19981929551689856, 0.1598972586854812, 0.2521292958408594, 0.22127377169747509, 0.17769228606935472, 0.18167085645179595, 0.15057053657308703, 0.10909418395209698, 0.11752304335635518, 0.1139902901805697, 0.15040333022273358, 0.15661058827273308, 0.1605419216737632], [0.047303535299555916, 0.01779156083601617, 0.03558625880208227, 0.07465221919119358, 0.026777222519740466, 0.018381107628585833, 0.04863796470266196, 0.07721435428867418, 0.016509583557865793, 0.1162677163618707, 0.014237416570164986, 0.021106666517293742, 0.08020731425213237, 0.013649346412069375, 0.06243945617649344, 0.04130438886462681, 0.06276681320741773, 0.017343765207295938, 0.040236071593338446, 0.11799894483579744, 0.016351562601724462, 0.10720076700372082, 0.042109577916562564, 0.026658570822027904, 0.05097037301428857, 0.04031846434959481, 0.034761955856435725, 0.030081788746399746, 0.06207487110288874, 0.014071159211227731, 0.08398968185628615, 0.06001722022530533, 0.04340159286174082, 0.019624382144801562, 0.037391893565654755, 0.07205937928970783, 0.027426595033536998, 0.029177724556516738, 0.04790594470837424, 0.0536849098129859, 0.06329067562135958, 0.031830890051599954, 0.02929862089184744, 0.04106416284377056, 0.04634984776437764, 0.07284075832895695, 0.03397038401735406, 0.041125740991124225, 0.03192443130237441, 0.04564901903992699, 0.018255886726922566, 0.09572417234941837, 0.04299708694640187, 0.02956540143537906, 0.05253706495427797, 0.025343215093016628, 0.008173172771480055, 0.011898513748160294, 0.11738376091084174, 0.077568294570571, 0.11198599732691243, 0.10923879070868416, 1.5097528840264969, 5.1332833113208896, 14.367968478510457, 29.79018572838076, 44.5427926125065, 43.35307890369047, 46.41012322518134, 36.70225704869917, 48.40339722171907, 34.38439515329177, 29.137150318391864, 27.399034346303633, 20.421159382789366, 22.46997217978201, 22.03315546435695, 30.800003851613692, 24.96076157016139, 19.36465524858044, 30.939730444262107, 22.872676041818437, 19.657450376018403, 19.566847547408074, 19.23497188475824, 15.927544043910121, 14.63987502359575, 12.714490390593006, 12.402551154936514, 10.518951531379454, 11.258791935059334, 12.344864856812263, 10.33845680375253, 10.51525567808459, 8.93701453362742, 9.688226869029384, 9.416413480235684, 10.399379057268943, 11.292499803727674, 13.606149073570007, 11.474798821633863, 12.97779223611278, 17.69913450364144, 19.930519903859786, 19.226425040152765, 25.19979669201759, 27.049129509156753, 27.27825672395768, 25.35625219345093, 18.303471726755944, 21.987475541330156, 21.652546313501176, 24.460808423257646, 30.341439554768225, 33.28388398693454, 35.83398942024478, 39.065179132646136, 24.56310187616656, 15.50275625721101, 10.631897161083838, 4.274708840154832, 1.5011780925335423, 0.1577739693945454, 0.029827759736367775, 0.037027381270402865, 0.0542908049218597, 0.04627619224089769, 0.010665251043505006, 0.04270783895927091, 0.03614400145447543, 0.03599055021280243, 0.02307233896346823, 0.010701587551363535, 0.00840024697789622, 0.010880638578636272, 0.07336444837311584, 0.012624978647387076, 0.01764417318026385, 0.028352228428928122, 0.0712981483628673, 0.05501450903172936, 0.028045785598336693, 0.02081776326972871, 0.023060441618004156, 0.13347520793397583, 0.07839309547336833, 0.040342975332732164, 0.08117181128792225, 0.03419803087449363, 0.05650775612241799, 0.030298243058965574, 0.04486900746762272, 0.04013936065377728, 0.0496187411068428, 0.028653212883059057, 0.06461546380793856, 0.0320553844569311, 0.037929319566296, 0.03142783970331713, 0.009206345759242052, 0.04578088192389377, 0.05893379570015016, 0.027163148887695807, 0.02705146475965458, 0.016505892929290573, 0.0660283521058098, 0.013500066519144082, 0.016826154070816213, 0.030502501251776854, 0.06243493242730057, 0.04575534055249826, 0.05122524280581744, 0.04217699365389924, 0.039633194870886304, 0.07065435871481895, 0.03705067417374061, 0.055410526692867286, 0.018831831628396627, 0.11255402087924943, 0.0448308639498728, 0.017665181226367434, 0.018797587498181292, 0.058929455812059106, 0.04724288794903025, 0.038461042042340965, 0.01953868754959155, 0.07277757905784153, 0.045688281046046365, 0.09386506847917073, 0.067378199028392, 0.08904688105347658, 0.009021882320784273, 0.02982919232078618, 0.042628859124717214, 0.056761200990407705, 0.06731091352600245, 0.02682722316333844, 0.10317924207136517, 0.025867280520258412, 0.0482989248308924, 0.008910230751479826, 0.15357243678262159, 0.02206595415519851, 0.07187709632900453, 0.013490247187174618, 0.047605937016346765, 0.07469512011495329, 0.12098224443053046, 0.015429636114276947, 0.08420558075510687, 0.037083179284367836, 0.1858913114354495, 0.04255597735004079, 0.03356151523128633, 0.06707212392000422, 0.021982988748218746, 0.012716188118042005, 0.07093444812081515, 0.03832966562420611, 0.06033441893035366, 0.09303672825016322, 0.024858141625900904, 0.06233344109909189, 0.013895933835526869, 0.012274365102301442, 0.011239613015805523, 0.05136064118555477, 0.07194476487535624, 0.06366767131933762, 0.05326566819642341, 0.020588296953768983, 0.025830902835173954, 0.03300259280348978, 0.02411359992449082, 0.038145639813475074, 0.018461533454096606, 0.029552757154188813, 0.17953483477955867, 2.5115953578102976, 7.505562699610188, 20.82478107944612, 36.25646398913476, 50.01925291553621, 49.878412369758856, 52.72683758889475, 40.00354736082016, 54.167881088872115, 35.35451496801069, 27.968776264498313, 31.207055660986136, 25.177676485430812, 25.79703050275003, 26.45704773164565, 31.20163102303782, 25.853887219582838, 25.469408650552076, 31.612642465099213, 34.59271223314347, 28.89792888395248, 23.847161454539147, 22.710952797243674, 21.77870935009372, 20.128950649692168, 16.629631634681456, 13.463768016907478, 12.343220403117519, 11.593256362022894, 14.593778348738148, 12.314386079388282, 13.274610734754994, 10.347532187738727, 13.318216704553175, 11.061741863527606, 12.61127616128614, 12.453662580059422, 13.702272638197869, 11.664243417401469, 16.447284567740656, 21.225515911656043, 25.194993749741588, 22.17343511119966, 32.48562674368582, 33.351588018478886, 30.051160627795806, 20.00383096356546, 20.83614222465023, 23.88225882284103, 17.24592620326627, 28.09458432659026, 33.619897750116166, 36.22632449673068, 38.89351267968455, 43.97342528066328, 29.89117891557755, 21.133452000156527, 15.443278416510552, 6.166196840424692, 2.77734917498404, 0.45899830097633026, 0.05494551132282904, 0.052397828474039995, 0.07689540890315849, 0.02322330424982694, 0.029112101464922872, 0.03048328010575666, 0.0682063937006939, 0.052765857112864335, 0.055327455948797934, 0.03417810875802271, 0.05053647996617421, 0.06324681708769453, 0.014434586534456862, 0.05467542319468433, 0.04850785999048141, 0.03942840807740727, 0.04895455819825011, 0.07092945322754883, 0.02202869163856151, 0.009171370015059029, 0.054776883879376036, 0.05160673543991101, 0.06247651567983051, 0.00940806724341406, 0.029640114160194516, 0.05918592672734972, 0.03367165186172051, 0.04072067583160054, 0.030935723972957463, 0.04330580888856803, 0.03320930630809838, 0.02380957218608068, 0.02521897669911625, 0.06253673019067896, 0.020700189840769576, 0.01707521691587904, 0.02226097715808259, 0.0757655747715504, 0.012230664574270769, 0.03873371571723012, 0.0015494704031528185, 0.06693163871644967, 0.11638125059224906, 0.017611715950131897, 0.02850801240833056, 0.019919515602410804, 0.06643989453873327, 0.04717628426489331, 0.037979394903466586, 0.015216436717779407, 0.041434512729005474, 0.07972864719528346, 0.04607414804218758, 0.11077423775268179, 0.19037549984791588, 0.30315882616466094, 0.3950173035264016, 0.08375492953364888, 0.15719931152078415, 0.12348427993035126, 0.14213518840411019, 0.13395805783089132, 0.23557946776911137, 0.1982383658328364, 0.11773773949713477, 0.17827658132920343, 0.19103064291900207, 0.1639809363311337, 0.1479590500915243, 0.15107168064963433, 0.09710415717094176, 0.11673748147703948, 0.31627854152071866, 0.1612066102003859, 0.19207512719496606, 0.15140325882502143, 0.07986396896622835, 0.11954548483293866, 0.21337267792513295, 0.12006834750213932, 0.1142988933791076, 0.36716562545587944, 0.15189982169578153, 0.13737592846155167, 0.22875466624334936, 0.076432783727444, 0.1300948602898467, 0.15588735530693687, 0.22936831799245652, 0.11135729195009317, 0.09800372059426962, 0.19519305908151213, 0.1316325213279455, 0.15173960206729753, 0.133456913754344, 0.11116279754787685, 0.12744451016788522, 0.17435960441587434, 0.16622125321338255, 0.12737096572715428, 0.20264122635126117, 0.11663412089429556, 0.29241876376252024, 0.0827794238143871, 0.22971154070429264, 0.17676815420629519, 0.08831468485896626, 0.22065970626088882, 0.18983799723848221, 0.1236440552278392, 0.08439072122376773, 0.31252746860827174, 0.09951688214054993, 0.20074223228279622, 0.27537631051194283, 2.4547246675337515, 7.9732769054751245, 21.958332330949847, 40.678736317542295, 57.338936944161695, 59.83907138147662, 61.728418257928666, 49.60476036994688, 59.12876544460174, 46.66834069836525, 41.72182006220664, 41.86151527589367, 33.52556866984214, 34.62062381928967, 34.22316220498855, 44.45351946738459, 37.95375201009935, 35.02418471920875, 46.07412907385057, 34.91482511643441, 29.281213091265773, 29.85876052610336, 27.531902674705755, 22.830912605408702, 21.66571371016964, 18.31863364865703, 17.553373344482914, 14.754065025237301, 15.53790951928785, 16.248621421475566, 13.611493302929787, 14.48148383248237, 11.60345942743363, 13.428467665949176, 14.525213356940979, 15.625168527326277, 16.4076921632213, 18.047338993318622, 15.618782908685747, 18.747109443910663, 23.784617300956484, 27.15582190021392, 24.906379868907315, 35.561525898595015, 38.71283262006698, 39.55890355571624, 33.85658141105406, 27.033363542249127, 31.349867197775076, 31.210217091345022, 36.61423513966222, 40.29972553253174, 44.67081877493089, 47.323086261749275, 50.535758464567124, 34.273568584072976, 22.872854509661277, 16.284258115676142, 6.614238398690378, 2.826314083030147, 0.4642158806804688, 0.31259249415128465, 0.14503510698916453, 0.20242807004720936, 0.11574960343780057, 0.05864406124718728, 0.13744737382137007, 0.14685465773988157, 0.14279128142422245, 0.13336743468478804, 0.1019839074222311, 0.05826229665188059, 0.19204564813163974, 0.10663819033652545, 0.10271906837700837, 0.17384457882613907, 0.10212607801921907, 0.24077165931943925, 0.20571339214521073, 0.19547828893748023, 0.09936654504628913, 0.126130600429831, 0.3148200939739904, 0.17232876661564075, 0.14221882988368312, 0.19742320231612653, 0.15251215577365893, 0.14008673058161814, 0.14667678744562213, 0.11936417480389919, 0.12335381515684629, 0.2652037660441091, 0.1290665557908435, 0.1545772070605909, 0.15095143548903928, 0.13935454970886632, 0.09844571502218324, 0.12826138206066626, 0.13501933475415553, 0.11640588797989393, 0.17013170305759678, 0.06061769143167523, 0.18570092326450735, 0.22811254666697597, 0.15492809065166982, 0.14938751295689615, 0.11561368411827473, 0.1661891541293552, 0.10411416811327781, 0.2180588530797151, 0.16468506306409836, 0.11411769060237754, 0.18650603570765067, 0.15792876512052553], [0.012587400119481309, 0.0453130703329319, 0.06235026055946947, 0.10513616004778494, 0.05241783486018258, 0.017600379764072357, 0.04497798347485162, 0.016663722363450838, 0.03867994783626449, 0.045925243532345186, 0.023694400442764166, 0.024387901536219066, 0.07308600605615685, 0.04270755550673893, 0.0305921565215554, 0.03867594502686012, 0.013020731050581222, 0.049174900407031666, 0.02914934291414196, 0.011272714717403777, 0.021737260300846353, 0.021359511921482704, 0.03192581792151736, 0.024747658340680986, 0.0480989222565005, 0.07515931577091256, 0.08471173504667898, 0.052428272808150905, 0.020846516464746768, 0.05876265931874514, 0.0375787845452226, 0.03112320292500719, 0.06623322699940012, 0.04524933947851101, 0.019072900345969587, 0.04772316379052016, 0.05966442524485531, 0.057790037920518275, 0.026361694514390924, 0.013179076636480469, 0.031481460112357335, 0.047583065461367376, 0.060512664607696, 0.0239948658723264, 0.03336497537431217, 0.04746242959593092, 0.021499259765410138, 0.023981805988437226, 0.012473549877834177, 0.005146828132696571, 0.02561147610146192, 0.024515926319685195, 0.024596311925579945, 0.06569425350115185, 0.03852820114022301, 0.03016496865799831, 0.033288623221338756, 0.0510433811934725, 0.07802977061439907, 0.05591124559061662, 0.013024595964159216, 0.012545972957365937, 0.06737636807825297, 0.41468988983861865, 2.2478203763884883, 10.55026283187251, 20.412620382924235, 30.72888343564926, 42.92134361882364, 43.85125913927632, 50.25502266422395, 45.72711698470577, 34.25839293387629, 27.740221715742543, 23.63881103454098, 28.053107223203106, 24.62806417096046, 25.984782595788282, 28.019204216618693, 21.464119572793287, 27.834748875710275, 18.87327640287338, 23.628506968098304, 25.90674508002497, 21.482133057809648, 17.561465194148404, 20.384265568948564, 16.357450523684104, 22.51484017218313, 16.649198378286055, 17.250962526567523, 17.028609245054184, 20.201747878905266, 20.44059080462302, 23.339385140326716, 16.307753113008317, 20.476656998357466, 16.899951581032045, 26.465894637569306, 29.92836298481111, 20.15512658703712, 19.698652913493497, 22.361316642453595, 19.531040230105003, 25.93737094633041, 22.31536215351474, 27.33163037607747, 38.979593015486195, 35.543110370635986, 23.891617598072177, 25.15095533863191, 34.062607826725134, 31.58304818214909, 35.962215623547955, 39.85423449547061, 26.278728938871815, 16.62471886604063, 8.69507783843625, 4.251514884733385, 1.3553208353057986, 0.28652236887043525, 0.07981778152527348, 0.0894908290055971, 0.0814914997787245, 0.062041852713352254, 0.08727841304555055, 0.018919588915342768, 0.04773742068679102, 0.04070495570739431, 0.049143065623338186, 0.05414561593845006, 0.01801550557326165, 0.06072000630440251, 0.03659391340108649, 0.034869031965612404, 0.008325449025799191, 0.01797092117128834, 0.0535921672088725, 0.1059476156989413, 0.045529819589348576, 0.014327237506457155, 0.056036673336019444, 0.06520764211252814, 0.03578482879205577, 0.0049240009262106355, 0.019065247127606023, 0.006614736386484677, 0.05377395604286463, 0.029898040642541264, 0.0337905410466896, 0.033198378063858516, 0.05041195237408242, 0.03138582361110997, 0.017228547498703967, 0.02605095393054428, 0.049726150464266546, 0.03438090372289862, 0.05244678532284114, 0.03203814173297536, 0.0687825071415113, 0.012897292260951813, 0.01656398346136895, 0.06425710319871865, 0.052181626970489184, 0.051863934138729695, 0.013815272437979378, 0.03720869129944233, 0.012998801783748693, 0.03464169154364256, 0.02201561834813366, 0.041138519337701226, 0.0678727011226358, 0.05370140368599565, 0.05495241760546642, 0.08084011053846729, 0.018237142470635233, 0.017154966668796637, 0.03920801607291064, 0.08248172204701171, 0.025255199251396042, 0.07243504582513725, 0.012748304439047653, 0.008822820119319424, 0.060951924101719936, 0.047460790167772965, 0.020248851055399548, 0.06960475697152077, 0.009905160630061742, 0.014432321787030708, 0.027825774722582394, 0.02140661483750709, 0.028041840245526646, 0.01121727676476322, 0.031249287590805083, 0.04772593702880606, 0.025754868608689117, 0.009679700953946, 0.0865420186892152, 0.03792538187436519, 0.07176618211932721, 0.013697434708686366, 0.06549729995669858, 0.027800020761787895, 0.041367012721997116, 0.023909085092224905, 0.02748910206249885, 0.01309182784039407, 0.039678252332152865, 0.03279148961507505, 0.07436040097907667, 0.022403569103428916, 0.034721042930839524, 0.1295207693211494, 0.08698852537500282, 0.05066590669054178, 0.021483924600385854, 0.02314512306193431, 0.022201051845425562, 0.02715338318188104, 0.04403145120088612, 0.11067620148101162, 0.060286048138814594, 0.03716130110044633, 0.018606580711240252, 0.056794541136872385, 0.03520262112180072, 0.06657328576810899, 0.02096066165024475, 0.022423866602982727, 0.08269452595061834, 0.02947919164603997, 0.032557993676633604, 0.0612962423192878, 0.040052704618222294, 0.014079659914357529, 0.03121333125407898, 0.08866896988042901, 0.020755221766810265, 0.0749801890924573, 0.965322633424113, 3.627072817856266, 14.58092179990584, 27.06803141101714, 37.12382162770918, 49.00968190162413, 47.53992665198542, 56.13358474546864, 48.49406280825215, 37.96535045869889, 31.988595762560447, 27.230764665911277, 29.53565332197374, 21.96536514066881, 26.59766274113809, 32.128390996686875, 25.24424695199536, 32.44246105993948, 21.478901024787657, 25.497402606471894, 34.002085654966294, 28.653706427543398, 24.335918195786018, 28.657005140858313, 23.76466028151974, 29.06250173045743, 22.03421646548856, 27.7506277638097, 26.378602289384414, 23.994721020421675, 27.069051227261944, 26.009099329671553, 23.237305456592193, 23.571628678229548, 23.24426962483314, 28.589583519966375, 31.337396021812197, 29.621506160305394, 27.670699665623328, 28.635647835270053, 27.946856098790324, 29.386171794706776, 27.8088455430923, 36.14647288476267, 41.79461140786448, 32.6264064927255, 22.893956861188336, 26.606052690936675, 33.57593974759502, 34.63076314618511, 40.24003882561961, 43.636850618547015, 33.16365549641271, 22.177355520186886, 12.477530202557965, 6.268272111492773, 2.585275120312168, 0.5793889876334899, 0.13636035634385002, 0.051926799313796144, 0.10685150751904135, 0.07214264538619788, 0.05781824144745066, 0.027726169885887254, 0.016556372377841223, 0.06312515466443955, 0.04024342986785116, 0.06220365048296029, 0.04439248162652216, 0.04389686487434853, 0.059744588685252016, 0.0667789803757783, 0.033752048958934126, 0.04878567411534248, 0.02082417542565494, 0.161286344631545, 0.07167464993413418, 0.014773733658535827, 0.06784952696292632, 0.05282287703706853, 0.054590969661911654, 0.01909672568041471, 0.059456386408137704, 0.07222198145163637, 0.009181117526285592, 0.027368211472827583, 0.03464690094152766, 0.059080287033031066, 0.05005071127426721, 0.03153501731914378, 0.06561850272719899, 0.03425168001183099, 0.037562045524077076, 0.009778000568340143, 0.03713070737919019, 0.032791462801997705, 0.025273508752786347, 0.043083168416013645, 0.04965028094668543, 0.019250931518693126, 0.041930489542503516, 0.0433652036853375, 0.09764009696100989, 0.04842342944034646, 0.026205556219323512, 0.03844578540132892, 0.017184773234710578, 0.01939783845427296, 0.032789976591424595, 0.02052901898540797, 0.024860434144014315, 0.06475173552790958, 0.01850724017487899, 0.2086854455692153, 0.1601826877243096, 0.18454158708693522, 0.26324699362439496, 0.13646233796833024, 0.09681007899944821, 0.08039693633515028, 0.11714477978286245, 0.09054269836915117, 0.1016556540684354, 0.17335106498531758, 0.10972331833815384, 0.11977522694055112, 0.1350665717355667, 0.10139923677929949, 0.15071065405443793, 0.09795755613595249, 0.16771621251058194, 0.1222145504828903, 0.1400588756246913, 0.0749784883772654, 0.13163569293195201, 0.1718565959843897, 0.11370083151925957, 0.15761788664085252, 0.18700092850673586, 0.22492755144353838, 0.17717365986637532, 0.1062022403423344, 0.12932547818749182, 0.08365981971784946, 0.1383582063980641, 0.15798154857850846, 0.1249205798751885, 0.1036082283263245, 0.22331086077517082, 0.21132451121605214, 0.324478562801115, 0.13282752655927213, 0.06305862375865541, 0.17454228574229827, 0.09208621997987071, 0.11090914583614758, 0.10418590458650744, 0.2379762198054983, 0.20046631805598739, 0.13277537129338712, 0.16741694792384104, 0.09077254772907303, 0.06627428165126233, 0.18722739941891164, 0.17464224489465838, 0.09956074833509423, 0.1957440908036886, 0.15738714095805922, 0.14694816643191924, 0.23432944210306292, 0.12339582741861382, 0.2260765760776497, 0.165256135646374, 0.21807213704432213, 0.08527045829161521, 0.23984360508620742, 0.999318857587153, 4.1611008201876, 15.7512354658496, 28.368626602234382, 42.4159344550102, 56.753562419645256, 59.22717378985498, 63.49025672481906, 57.41038683922061, 47.061228829045454, 41.95454997401084, 34.80955654574979, 41.519849377293745, 36.7716633888983, 38.628089812494096, 41.31354839571061, 33.63827013200329, 39.70215243677939, 28.09222305974653, 36.476591325575306, 39.97088186202511, 35.73046238191667, 29.679298362424298, 32.61030516316814, 26.139072948886504, 33.62703646382978, 26.182991727705925, 26.22216639980193, 26.856764708795858, 27.13801826200178, 30.18800427836757, 32.58765739779319, 22.881048340951246, 28.188023028835175, 24.656126768358295, 34.370125570604884, 37.82922460186867, 30.873110948070405, 30.776536310872725, 33.50116760500016, 28.96715871749386, 37.75286782172419, 32.61436873866666, 40.28080794119066, 54.084393439754365, 48.103053492884484, 32.783758255743216, 36.17567885306574, 44.786254129102154, 44.590017949381185, 50.451517720376295, 51.953911012218846, 36.86494519633632, 25.063751243775894, 13.828180720729213, 6.66576853682918, 2.3338663914511284, 0.7831291517903729, 0.20501917858998622, 0.1874189673652572, 0.21074133444457285, 0.11096736085751366, 0.17166895040821645, 0.10870278963158209, 0.13410922230011033, 0.30376305503229944, 0.14704195091560965, 0.18493048396081696, 0.09903856748414618, 0.23284864011070422, 0.26792267337441444, 0.1784407080061013, 0.10827070072052941, 0.10378874162392271, 0.14745602143868325, 0.24511133290586934, 0.14846065382082618, 0.08829577780899503, 0.23766990720985398, 0.2489860677310536, 0.09616826585824452, 0.12189820979631717, 0.13663908977422023, 0.11418283871945836, 0.1795895334573523, 0.1302833179192197, 0.12843233458096945, 0.16294939894109003, 0.13043458964074814, 0.14009895734488964, 0.08848212869657625, 0.11352206490212872, 0.11088033326931539, 0.16482268309881612, 0.1368126699761037, 0.13022373160046916, 0.17101216790897233, 0.12612596559788913, 0.11300753726954423, 0.15349239591629277, 0.16796315329209452, 0.1296733587139076, 0.2100534947408784, 0.12185056678830616, 0.10720640541084352, 0.09939913442658802, 0.09759998459729458, 0.14063077558192516, 0.15756677325454452, 0.16328286169277084, 0.11039917642671256, 0.16040773371294623, 0.15800157411684915], [0.023497571387598594, 0.04548283541695245, 0.06776423073343693, 0.022251540870075266, 0.021918759936647072, 0.007846894966919095, 0.010399306493420756, 0.01886384835797212, 0.07244582468223187, 0.013485767488037387, 0.05349443354193242, 0.028758027117639303, 0.016438655307396285, 0.019054355272542567, 0.030811008689324224, 0.029220029846915317, 0.04201626457694558, 0.037626485009827924, 0.02522875006581026, 0.030398681016278364, 0.03365785844864384, 0.01815102844228668, 0.05858927063884274, 0.04427149336064055, 0.06894467263332299, 0.026265609851707856, 0.0526229587323483, 0.041551402424492186, 0.004393792910230977, 0.030939747849779747, 0.012855447580917709, 0.11267575991129684, 0.006191410563675868, 0.04845819451035031, 0.0944890700761349, 0.045592217450781215, 0.012117452100820601, 0.04163526990000279, 0.0530036163306044, 0.03396021420015924, 0.035564850475038254, 0.017374822411746267, 0.01691308589802394, 0.05010708002373577, 0.02151134480241566, 0.04896031534900108, 0.1322073477410501, 0.03629917639397806, 0.025926972176098538, 0.03878449968573067, 0.0320656385437976, 0.020780479685673793, 0.016870943401309273, 0.025646308204159144, 0.03864008828156418, 0.058121520334914814, 0.017267351767288584, 0.035043159920361736, 0.05019364795917946, 0.06652809424145568, 0.029446010462819572, 0.1440159802234942, 0.055871018313712655, 0.07494549297036664, 0.04018872735961791, 0.777945984755793, 3.3305989974929444, 8.304259738614483, 23.407010724467618, 33.840629131563254, 44.418167145021506, 48.59176512687437, 45.67162329150785, 44.05355538091352, 41.76745291679136, 43.45101656452302, 41.580053837068625, 43.239730250450876, 27.6208737973244, 23.789532030782393, 32.19034287237352, 32.55490756803943, 36.5160229129176, 23.950370780883297, 24.804980716397687, 29.27869296843006, 24.92674873721215, 26.079858887580137, 23.391181999637237, 18.509460879910378, 15.443978559586311, 28.367563639917684, 27.963653649053267, 22.912486137882357, 20.431247718872566, 18.74637596068844, 23.019913973346835, 19.30352314825981, 45.29002766455374, 57.921573654297866, 20.51889111918788, 24.149672292893936, 24.682751817087976, 31.983777130803755, 24.362092171945882, 27.664000257369015, 25.380237487054643, 35.52895061431393, 33.06930288191765, 36.18714394107942, 39.02968168258667, 39.039813164741766, 35.73299231067781, 27.050372900501376, 17.378100272147886, 7.999924017537025, 2.7517804695713908, 0.8218798401855654, 0.24668942806461167, 0.0995913305650315, 0.12979459978880423, 0.039516266871003375, 0.03322769624872073, 0.042986932450965534, 0.03481022322610502, 0.035333882626746936, 0.007935967531070233, 0.02485381131390891, 0.028514118129087072, 0.09948266099297232, 0.027190710815991607, 0.05027902079746128, 0.011817013484335715, 0.06516458031030432, 0.047168282476524194, 0.06444917676309425, 0.05394337255687964, 0.059632582800282594, 0.05386607428531974, 0.028732550863717354, 0.04255137699205549, 0.047057801106524084, 0.011651284726066215, 0.03686017875048903, 0.028120538542768168, 0.08653811164080136, 0.01937407249164197, 0.030506672600524563, 0.030591218063848156, 0.043290709295580466, 0.05927454777843049, 0.026762314448733966, 0.03851855992369595, 0.0043730711894890955, 0.04048442580707131, 0.023053121647887656, 0.03675478420430615, 0.022156270175811746, 0.015526384400624423, 0.04134109979795833, 0.024293289677570426, 0.02511641284781358, 0.021760193142859686, 0.02481237553330439, 0.05089459542725837, 0.05404264989098715, 0.025602526279286515, 0.044854999549927256, 0.05508296281820344, 0.022407604471570062, 0.02576374756773153, 0.037766882113271186, 0.03461414302188543, 0.07258370518684387, 0.02163963771665529, 0.021603738836523508, 0.03414816621150221, 0.060896309948856794, 0.05190198955636832, 0.02547181635764578, 0.040643071124870936, 0.041648055907459035, 0.03565158311938567, 0.05881686770026723, 0.0009403704133282807, 0.07186268621514882, 0.06789997385274019, 0.08256154074784249, 0.026949485050394174, 0.07693807233966167, 0.046440587048569036, 0.044376332493078326, 0.09361656487829263, 0.05393774181063618, 0.03445862717325649, 0.03176754032592139, 0.026480187248859196, 0.03457390808410222, 0.05483880293585601, 0.047333071819476547, 0.09471504303115992, 0.043002851758032076, 0.07664208660923666, 0.06548667431718881, 0.04156641391736846, 0.04691497933480048, 0.04293221845141342, 0.046169817102171724, 0.025950378077405117, 0.08155892317694041, 0.06851086768531991, 0.08615771834287914, 0.08201970974163664, 0.015155523151700056, 0.025779151680668997, 0.037374840448460275, 0.047528830266767935, 0.0233030827310417, 0.005599897319165569, 0.048513801002334205, 0.039307557707352024, 0.0377728269555636, 0.0457414054131556, 0.07923761547933664, 0.04684726482317333, 0.033722102581974, 0.052476521025622086, 0.026556275101498734, 0.03964027735374628, 0.016326911807540926, 0.041095158761186946, 0.060521256283766804, 0.07098221370289404, 0.05575242024215479, 0.13530252681624505, 0.03063968653159757, 0.02025907641396888, 0.04760987853871719, 0.06559753490071144, 0.01778852521261621, 0.1211857786702533, 1.5227914553496147, 5.4860661875817085, 12.574271540487967, 29.184010874840524, 40.27918407993932, 50.647396964411584, 54.424855170711396, 50.58780831675376, 46.02435419636388, 44.45157004940895, 46.24878829525363, 42.44101801226216, 43.89417379133163, 31.104856344961355, 24.628044559109597, 37.04388764596755, 25.819764560268773, 33.26125975578062, 24.909733495404645, 26.962017589999785, 24.914399154724617, 25.89868460932086, 23.691649283132246, 26.920026656120058, 22.591302856322258, 20.942301173363965, 28.362607725204963, 32.602456500453336, 28.765433180716734, 28.531922717248243, 21.272019532419023, 28.581299474162442, 19.69373426129741, 50.515142486941436, 59.91782080742621, 28.37719894224598, 26.007789258034002, 25.434268136178297, 25.967857568494736, 27.67417096322583, 26.71640269217953, 26.203515529632572, 42.94324221149568, 37.233004723825765, 36.208454178225615, 42.20124744599865, 43.322135325401064, 39.60604260044713, 33.582619543998476, 22.827996323185584, 11.000616627354777, 4.253376049380149, 1.8462612335720372, 0.42690767455966244, 0.07912297042146807, 0.03921176607329999, 0.03466757382416437, 0.058943027059637734, 0.037191090429381984, 0.06632110494519435, 0.022706101055166895, 0.02797888888556871, 0.05953611700885719, 0.06065639419360988, 0.04369245346395239, 0.03786244009050631, 0.04260767679361086, 0.01621780939580452, 0.02219033427536488, 0.020786007010047475, 0.07784233188196536, 0.00579217485445101, 0.004036556535039939, 0.026839436520071282, 0.0557391056340308, 0.03488094846327459, 0.08037122642441143, 0.027539738559073983, 0.03360025246717757, 0.06266988393279814, 0.07450661652030484, 0.04677010827787942, 0.027544494049863952, 0.017141583112759456, 0.009603499145727725, 0.01289624655093517, 0.011245301218643304, 0.06853722110991517, 0.036281629150072416, 0.015194178990749343, 0.044032282406283964, 0.029902330734917236, 0.01584948677073924, 0.08928661294762166, 0.043900542096385074, 0.016982550920558073, 0.028846527509871992, 0.07396841677086008, 0.04982455828857999, 0.05757148452703992, 0.072689249120172, 0.04858646827239183, 0.010218135317817572, 0.03384700172670907, 0.0058608967716985896, 0.01240401590738686, 0.025350282254118114, 0.036216458050353874, 0.05255117629384322, 0.03773473706396838, 0.028140462574458895, 0.09146956516610039, 0.11964615644706834, 0.203211548167371, 0.10595807279910772, 0.16245465935958972, 0.18544569341165407, 0.14078019337067682, 0.13337923243882197, 0.16700522162981574, 0.11174177615753106, 0.1596564159638459, 0.12667504379585867, 0.14455651654110802, 0.1667049917722902, 0.16076313722277843, 0.07817231659446994, 0.1474020888488139, 0.10007650170835758, 0.11135598960062189, 0.14169148560012543, 0.12848073601602547, 0.16741094179451468, 0.13193929357634437, 0.2406121291700871, 0.20189304956265036, 0.12786473237699078, 0.15441638988352593, 0.1387749275853557, 0.13928822181638212, 0.132924038315973, 0.1071492016255375, 0.16885821977930685, 0.10775012865422234, 0.22054076344976503, 0.1542998066232089, 0.16884095215749356, 0.1826208820866962, 0.11903013748627518, 0.26513230536253224, 0.1608036019869389, 0.06729767552667087, 0.11083327248812684, 0.11768631967565707, 0.19535645031400267, 0.09324090600374246, 0.11672376084231562, 0.26803268360034116, 0.13795098470103356, 0.12037375611403298, 0.15783375489615625, 0.1418547389367896, 0.1006754215866808, 0.12274318179416081, 0.1077844493932301, 0.13964148028002632, 0.1411584109788941, 0.1269591168590611, 0.1400764496816743, 0.18635932987015094, 0.20529835635135252, 0.10029343482587608, 0.23227663290116096, 0.12274322775943626, 0.2470726712096122, 0.25694112473678205, 1.4212258472557993, 6.275982020362732, 14.947151541709902, 32.30142439565351, 44.40090087152297, 56.44452671850882, 63.242013838983354, 61.817008910640595, 58.81422665811355, 56.85075483014507, 59.377655521515884, 54.77547191804456, 55.54365242681196, 38.95121466728949, 33.806575113727206, 46.62250388053156, 44.782598480101555, 51.45722519966864, 35.093998985905806, 37.43690913723361, 40.05460093098302, 36.35378976022044, 36.94901727860974, 37.50261275999008, 30.15042797211678, 26.852887445880523, 41.33874962406774, 39.38460126999886, 35.535485283021, 34.88887863774454, 25.481012982706872, 36.3040776406565, 30.426296111076113, 58.16944783733737, 67.40921835745534, 30.71174660036641, 34.71012446188158, 37.076345259143466, 43.546840067832704, 34.55328064580118, 39.46031870380525, 36.29905308446577, 49.73709329482048, 46.38777355993948, 47.8922966987856, 50.917044224277625, 53.29168635029947, 44.85944555651757, 37.252243949520974, 24.89700932656565, 12.58694766029235, 4.626998968662755, 1.9804520135925663, 0.4159074486984361, 0.16988425665805418, 0.27694455377997895, 0.11808604903278813, 0.09894208637096229, 0.2360429203197841, 0.18752669464916955, 0.18088947741254685, 0.16328808641241443, 0.2746484963403594, 0.19288279837177646, 0.16384595163887547, 0.1155882653209471, 0.28663063241589454, 0.18649839015016634, 0.1465241214440715, 0.1335221691237342, 0.10629777150649218, 0.1615778870520092, 0.18099395648366023, 0.13156901263902265, 0.1275886879152348, 0.13058521784842014, 0.2110571924957537, 0.18667930947436442, 0.16199949588025772, 0.14122288493860152, 0.19981515864210747, 0.13599545334375676, 0.08817542539609056, 0.08987564263084243, 0.11847300770422144, 0.10752977878456155, 0.10383839944317456, 0.16174627317776605, 0.14988694099649308, 0.1661808650580145, 0.11768382988990315, 0.07551716310122321, 0.08153530468623485, 0.19306448378389884, 0.1101418398320675, 0.10035044708920103, 0.11295281560911287, 0.16315360733818624, 0.17422063606640986, 0.14145481039679822, 0.20652587435418562, 0.13081266935313904, 0.10626784045129054, 0.14646093451207684, 0.06954763745588642, 0.1386929714992162, 0.14402200167457904, 0.15480989860671182, 0.1755542572467558, 0.1495030696593946, 0.12846072579944326], [0.06891431256888375, 0.011369352878612137, 0.046694139168868144, 0.007693875128508456, 0.024798317819893844, 0.06068395037624625, 0.02084074973789675, 0.0672481939076416, 0.047592913521634, 0.011585086110919234, 0.11544329084215627, 0.1065155319989689, 0.04398845068569626, 0.04259494441230932, 0.0359131753324501, 0.013814591577336674, 0.016387003744321487, 0.024641097425633383, 0.05959298754591615, 0.1246366217251747, 0.07692307233810425, 0.05564001982190436, 0.02863568670657133, 0.030300077839544227, 0.04504399727128687, 0.07472564105785663, 0.038140556820097475, 0.04744648730622665, 0.040424801183924566, 0.047057146101348826, 0.1006858557042095, 0.014893854329843196, 0.06612985875577697, 0.044681538091672045, 0.030619136223028746, 0.03142244452911039, 0.01320685689983469, 0.04441505057677146, 0.04958756898920383, 0.04346921544281706, 0.04088407089453071, 0.024246474044517647, 0.01809957031641276, 0.04445921554560623, 0.0792465940298092, 0.0277596460129585, 0.042228041922733675, 0.07691092218362516, 0.029289816626377647, 0.03413946345268238, 0.021975799013049375, 0.04388921931686421, 0.0029045328283832683, 0.04069957777016586, 0.017428816288649555, 0.03182146908535111, 0.014858035888943463, 0.024308144122422225, 0.03847776957216763, 0.02577883375418042, 0.013464498972039551, 0.036883019661951455, 0.025233158901814493, 0.03480471122348982, 0.03688005873212411, 0.05255316429200673, 0.18027833843183133, 1.2535995581457693, 3.834729223482071, 12.371906657372753, 22.392828964417983, 29.499853849411014, 39.45235629235545, 43.36434395082536, 54.49069999879407, 50.82652376544092, 56.00034183071506, 57.321211753353, 48.436968788023925, 43.44784336705362, 50.971545557821955, 39.03299216301211, 37.89410060451877, 36.20490443321967, 24.79074643504235, 32.762022441433324, 29.262844631748816, 26.315846327812444, 26.83524070247527, 22.43511799843081, 29.81958193163718, 32.93544023267685, 25.11420076893222, 19.62388469326881, 18.956871917170865, 33.905669873760594, 21.566875865382535, 25.16622708689782, 64.34065011239821, 76.04308466757499, 22.59400929174116, 26.145815503212717, 33.1051415781821, 43.67670974423809, 31.387733759418612, 39.43328965094782, 43.209171064438365, 43.23630209892027, 40.45478467018374, 41.76558194621917, 32.37885394404012, 26.757981777191166, 17.044994946449034, 7.696396795011337, 3.027629977272403, 0.6626588226326051, 0.22423667803166375, 0.03577335279495005, 0.050251974063294555, 0.03181243307828423, 0.10365695151830874, 0.00829426828967107, 0.07162116933614016, 0.058135014973701014, 0.018464892749644576, 0.01636450757242499, 0.01720468577508244, 0.05852188554502303, 0.03276550391268346, 0.06091753441479899, 0.058057586467193986, 0.03093636748681386, 0.010814575944095852, 0.013460204091614053, 0.02717855874629271, 0.05397236132393441, 0.03599014418620256, 0.06321638424490249, 0.03447235929929922, 0.02305054184680264, 0.06136953778144333, 0.011905059011863365, 0.038678522912725326, 0.08399593313374827, 0.050744154911127784, 0.057869695742884954, 0.03678671857942978, 0.02101865450611278, 0.061928395091766314, 0.04626480051346364, 0.032331151211814534, 0.0445708881823286, 0.01694886603452746, 0.08219866788074856, 0.055295165342789505, 0.0149193765490406, 0.06136381510464896, 0.03018378569263845, 0.06253241711566526, 0.06827752496446333, 0.009526847260853937, 0.04584773075616649, 0.024172140533224713, 0.06498009867725835, 0.05188155416098814, 0.030889808493215713, 0.05882127270583184, 0.03158453915778908, 0.03581695085872085, 0.04371589575443537, 0.02494375961231849, 0.020257961756039052, 0.022576053799580664, 0.023315418661842426, 0.03647005613592844, 0.03380104411213148, 0.02170461729439276, 0.013898664938976929, 0.03440556026274159, 0.004566785618437514, 0.048732411852406884, 0.09849901175907544, 0.03799378203468458, 0.037829264652945345, 0.03056307199351009, 0.04947953143968217, 0.025014867893450206, 0.08359445709614985, 0.07854469661270419, 0.03982418059040943, 0.07531496185448862, 0.04622577982504041, 0.042051133068819205, 0.036564323255011154, 0.08455865535764925, 0.024958818985690034, 0.04005399164593509, 0.017413574969395995, 0.028154614133640166, 0.041520835516313394, 0.05510520618108492, 0.020491651131681377, 0.04974440633950215, 0.07107091136276722, 0.074533061875451, 0.06339402854322426, 0.054334897112341664, 0.022740136426422867, 0.0365338176338663, 0.04326946950787979, 0.026483435461658145, 0.021317210461523746, 0.03030659533256004, 0.07090074025214681, 0.03504319822475795, 0.06444531567995587, 0.04446866524015223, 0.008055655841505336, 0.020690157919401125, 0.019186986159653436, 0.040149836906141816, 0.04390456788842717, 0.017498553272396807, 0.048058013161343914, 0.05404795888030241, 0.04769188442057179, 0.02164460962728387, 0.03632613119759387, 0.053397320406211, 0.04284499168035485, 0.05919924133547372, 0.0621146310661589, 0.019598193429110032, 0.040548892105899514, 0.028311650666798797, 0.02469173583742832, 0.054966264644697796, 0.026883421458243847, 0.119217170192109, 0.019951373368742007, 0.07921090199341697, 0.03599703131664184, 0.32689017694323297, 1.866730490038472, 6.315414098001296, 16.016123910104078, 28.517282470580074, 37.505809491680516, 46.951531902436294, 51.9393668636199, 59.89632621888192, 57.34439688344156, 60.32415874542729, 61.897939174406, 49.94157037427349, 41.95882143512849, 52.191755694727746, 39.82349095805999, 40.67933251780849, 35.4832471570661, 24.68509739445102, 33.39409866640645, 26.489675967924057, 26.503731781436553, 31.069247107351984, 25.892161707724295, 26.779639144097608, 35.71375700735277, 27.627031918494936, 22.7395409922446, 21.61384624819602, 21.742903993975734, 22.552187019778838, 24.520614762460035, 68.94353974250056, 79.23076352765484, 21.123218536376953, 21.585738543541204, 32.71997071081592, 39.39048874762751, 28.70566410403098, 42.76623741272957, 44.58480119705201, 48.57680520703716, 45.48064701018795, 45.825062490278675, 38.00967324164606, 31.51405957437331, 22.533057620448453, 11.404766863392247, 4.623652206313226, 1.4683384159880302, 0.36590075300585845, 0.05099822031033616, 0.040832988151739684, 0.05406019713489279, 0.09993259209178149, 0.015186045052213295, 0.014481798618010458, 0.02310928738405628, 0.027540895351839643, 0.02392406977202383, 0.011021248271478521, 0.06892147549097577, 0.06921484120069973, 0.06573177648768311, 0.03591407165532151, 0.06085334390762353, 0.032640225554425875, 0.014380133962408911, 0.045813421508477586, 0.05386850661447933, 0.0824005397096757, 0.07413078144553208, 0.021484229120335752, 0.020272798963912556, 0.027827224543979092, 0.032202544201525955, 0.06724394211966185, 0.03386608114646327, 0.04807087194715296, 0.02764751563870138, 0.04482733228454187, 0.026980498204788855, 0.07404823547169086, 0.0600293665493448, 0.03085628640086901, 0.0413273676719156, 0.055258688066274896, 0.04182110750867475, 0.040919222838936314, 0.03556833617509373, 0.04632814449348277, 0.050252246024507674, 0.04983837851473401, 0.10658601974888195, 0.03421333731122075, 0.029773409628579696, 0.03377674763361293, 0.01719348748484927, 0.03463019639433872, 0.018078234767721548, 0.13255259292500635, 0.025272869069369572, 0.03448378167025024, 0.05502916812416046, 0.033257301716554555, 0.09321421550046052, 0.015407856234589653, 0.017478776712631507, 0.042937121414128816, 0.03836722308469396, 0.1158618046751907, 0.08207797072827816, 0.09462351850684612, 0.07667370305787172, 0.1565812011399577, 0.2983820228086364, 0.1129965975339855, 0.1387513014337709, 0.16301797913207164, 0.13269732225566142, 0.21057198304803143, 0.24057243049385088, 0.12476193072694926, 0.13382576976812657, 0.10799331560490594, 0.09804487483756197, 0.11439065539067793, 0.19088543861383395, 0.207381502635056, 0.17127053872231515, 0.1419953620361705, 0.21699195307108665, 0.0974702705899554, 0.13629392119905642, 0.199449397623539, 0.15485100688472872, 0.1639203694198401, 0.1704520503840139, 0.16017839763193362, 0.22031340387559709, 0.2194897061394107, 0.09884488513512958, 0.13463806811599963, 0.1827193703502417, 0.1252457918599248, 0.12687627211092942, 0.16182573181727242, 0.15014338126826673, 0.13335485552107135, 0.1279019795718693, 0.1189263019290182, 0.09036135769659474, 0.15817066504349633, 0.12376407822293621, 0.24157180751283325, 0.09168479756842698, 0.10783392335138015, 0.1425604284891198, 0.14664182319275795, 0.11536128112986205, 0.13513790984307567, 0.0882623763754964, 0.08837927373186236, 0.18242358380267698, 0.1548969108731516, 0.21191406183906142, 0.09455098530217525, 0.09531963196012283, 0.10689977105827102, 0.152598325343382, 0.1364272358196397, 0.0683206710363588, 0.1347188291049773, 0.16882797462805627, 0.14973334036767483, 0.19765604707983234, 0.2813597023487091, 1.5438446546754532, 6.627409717729015, 17.704908232535086, 31.142405194620935, 40.89954614639282, 51.11717531757971, 58.13014568821077, 68.00135504814887, 63.976689461738836, 68.67790898969098, 70.60221595148887, 62.12296162882159, 55.845792601185465, 65.90765660808933, 50.681533352021255, 53.32518339157105, 49.52998822735202, 38.07398834536153, 47.20468559572774, 42.31695344371181, 40.32662122480331, 40.780482599812174, 34.61220641289988, 43.156744664715184, 47.74302305713777, 37.68314769191127, 33.54858513801329, 31.003135558097597, 45.40283503070955, 31.93311775884321, 36.24207281297253, 72.39274655618976, 83.33024440273162, 31.971247119288293, 36.3885498046875, 44.327336818941184, 55.75255001744917, 41.91692267694781, 52.580713610495295, 53.707167333172215, 58.826158508177734, 54.05350869701755, 54.340869380581765, 44.59356377201696, 35.48376490992885, 24.194042144283173, 12.191016750950968, 5.029818540619266, 1.5175683291689044, 0.39167072503797473, 0.15144243656146913, 0.15649192125326203, 0.14340275748362466, 0.25125189534118103, 0.1830369597601314, 0.21229361244026693, 0.15283080238488414, 0.09495309719275083, 0.048534439411014325, 0.09786726501319679, 0.12118639154059273, 0.17083728535761758, 0.16053173270437027, 0.11274862253377516, 0.19333659821460325, 0.1383105097638984, 0.12339359810275417, 0.23440241963872988, 0.16636630430096583, 0.1933344378466568, 0.22019741816386101, 0.1084463416989292, 0.1437075379034204, 0.13315361954512137, 0.19629536767400083, 0.14098659277923647, 0.13693182729184628, 0.2206288788828158, 0.15215623132403822, 0.17713740858579838, 0.15251895863442652, 0.17788207669171596, 0.09257987171651856, 0.1121442404485518, 0.1048733152809643, 0.1646734185276493, 0.2182113352201639, 0.1512502710665426, 0.0916308036915237, 0.08448642858814809, 0.13033430873145982, 0.13843545870434854, 0.20024062855349434, 0.10819747803672668, 0.07483380501188579, 0.07864536822683389, 0.21195766756371145, 0.1397470165524752, 0.10664053456557375, 0.21739321460406627, 0.17065464999646912, 0.1565066607849252, 0.2375643862591636, 0.17826217887622697, 0.14328946840138207, 0.07412798522460846, 0.15677531249821186, 0.13927882957843044, 0.10263088399604445], [0.04188623264311783, 0.09782316133139596, 0.03996929296502664, 0.026852389151651054, 0.03368635308898745, 0.08419159965048875, 0.007108127174433322, 0.024950675471054933, 0.05071804280422869, 0.017981406999751925, 0.0519051534994956, 0.09407392702996732, 0.0188323812964823, 0.05647119457623171, 0.015253466535209408, 0.02446559434305997, 0.0059779502184791194, 0.0731882787940483, 0.011124466170346545, 0.06335750913187381, 0.03135360578345436, 0.017901339320345752, 0.05284124782549278, 0.019137958447719296, 0.09160707794850872, 0.059639286069620046, 0.031306679067652554, 0.045837265995120814, 0.08633038690013271, 0.04285262957695992, 0.014327162812884538, 0.04041149040624019, 0.03658068689307378, 0.0214767923218108, 0.05399833936544676, 0.04587192764325489, 0.04843655252648939, 0.06144044304927511, 0.0873175448167228, 0.028476652599150137, 0.038710085735205686, 0.03429749590014258, 0.052871454672347155, 0.038787146519509055, 0.04647657785925173, 0.06940682283452443, 0.09659875364553544, 0.027747654821723703, 0.07042889903870321, 0.04636179490555679, 0.010086233171844676, 0.001811179085521989, 0.09471496642236749, 0.020724490149727753, 0.038992423609259634, 0.06911773955629719, 0.00477037348431505, 0.013748270388121807, 0.034530007415601326, 0.038332745297661716, 0.035287017197979074, 0.12009142973129788, 0.022501040385254932, 0.1132399989892879, 0.023220674653026848, 0.0918548078005833, 0.048295914105349974, 0.05144609063262901, 0.22282981884575662, 1.2841046889943462, 2.5647086626099003, 8.681897694064725, 15.347044044925322, 24.14693840088383, 33.397832762810495, 33.80446095620432, 45.50314964786653, 50.98450114650112, 56.2827681726025, 56.24759235689717, 55.60512773452267, 48.4455587787013, 54.863246717760646, 43.370337332448656, 50.76170267597322, 40.76949211858934, 43.10352202384703, 37.55839670858076, 31.46158414502298, 33.4726127501457, 34.27551800204862, 30.060309556222734, 32.681292218546716, 35.41723366706602, 33.55436671164728, 38.09460040061705, 32.053483532321074, 27.96524024778797, 61.718310309994614, 74.1398016099007, 33.171362953801314, 43.0720724598054, 39.371614302358324, 36.54349127123433, 46.93107674198766, 43.94591377627465, 38.67318530236521, 40.44786953156994, 30.14858053576562, 24.378946596576323, 13.030349054644185, 7.9972930877439445, 3.182936469393392, 0.8008843732457008, 0.15985483273623452, 0.04517895898090736, 0.034259972913611325, 0.04959308099181903, 0.025748998459969318, 0.014537082395456253, 0.13579314484471275, 0.020432888357449445, 0.059850714845402594, 0.08539597413712934, 0.08352685749771134, 0.04207745584989748, 0.05506690944575014, 0.041018986638875744, 0.029007752628756628, 0.025306695681666175, 0.06636094917813617, 0.03323258388967764, 0.03589762757802683, 0.05479936855995367, 0.022335251297561393, 0.019960516628118295, 0.03690061670157217, 0.04045110864324435, 0.01876631387389235, 0.013644086260859285, 0.02491298011474071, 0.09395896787604979, 0.04826776803501191, 0.03270999701212972, 0.07025883518039219, 0.020051943476221735, 0.043167794318569284, 0.04884658576620202, 0.07694499011361793, 0.028432510612953096, 0.05113420857777519, 0.033580046898174676, 0.01998826241751592, 0.056408995897659374, 0.0626707687643507, 0.06500450623852592, 0.0408023331434496, 0.023251088343620784, 0.028265650917385376, 0.07040925654432467, 0.06506970798176143, 0.03729152455625515, 0.06723098757286226, 0.01092063507155305, 0.07925186471472825, 0.036264847994091055, 0.08048201806002087, 0.05198224875775557, 0.02202978522907342, 0.017306142629334526, 0.027781774462651343, 0.03113633558724917, 0.08266057293381422, 0.05118670475278651, 0.05091068327366825, 0.02857455289021375, 0.030399966128771345, 0.03712403858380933, 0.10814549131018501, 0.059331372350214, 0.01036607551448528, 0.006445415154655254, 0.004616058957312377, 0.077540087213199, 0.018182769380209428, 0.01825733846353908, 0.022570432629436258, 0.029868103841680194, 0.01750434681232418, 0.02668240190213246, 0.06765595186621913, 0.050542589517370354, 0.038441173552024754, 0.03065875446003291, 0.03865345651584287, 0.026082850001271696, 0.03657430921110415, 0.03175823044242158, 0.06173755109850919, 0.045074794005842946, 0.018633803645629558, 0.02743231771033137, 0.020453597629262556, 0.04979542779525922, 0.04073310177773237, 0.03989120179246511, 0.023303722414458473, 0.05637778547562419, 0.010684479850404447, 0.021377313889623172, 0.0381868438524825, 0.0845440230782955, 0.0519427913992155, 0.10453294241620649, 0.051721051079972144, 0.03309237064733621, 0.08091017694002198, 0.09376230544500774, 0.06522914620056268, 0.036897586823831645, 0.04844726626611045, 0.03625169043399153, 0.02497274263371383, 0.03885907451471975, 0.05754445311463168, 0.03593037783678982, 0.03413246140905446, 0.005266123823070478, 0.08302224304286704, 0.011148752115156141, 0.10385781977205508, 0.027595502099082358, 0.03230755953418632, 0.0073843171928949175, 0.0061715071205981084, 0.053663987951773795, 0.034149418765258406, 0.036277450140445464, 0.03164651567086337, 0.12199687426008525, 0.02942418461785682, 0.058400077565062436, 0.0042858889472911195, 0.039725577413675286, 0.45221060874962044, 2.260574943596317, 5.361329422843072, 12.232233016721665, 21.185566571451005, 30.080246963808616, 41.294524900374874, 40.647306365351525, 54.55807062887377, 59.68538899575511, 61.446697942672245, 60.428552627563484, 61.84152372421757, 51.775576529964326, 57.70545105780325, 48.246067031737304, 48.366836809342914, 43.88981603807019, 44.38257555807791, 40.86529208767799, 33.912463418899044, 34.4205907852419, 36.46576166152954, 34.92115189952236, 34.01348798505722, 36.38934212346231, 35.057505253822576, 39.93345460584087, 30.92279168867296, 29.426209388240693, 65.16255140304565, 76.60508971060477, 29.787559701550393, 39.168353157658736, 41.67330034317509, 41.72279673237955, 48.91860054385278, 50.29982397633214, 45.67224302599507, 47.16945878921017, 36.03858024843278, 31.664541306034213, 17.12652925522097, 10.840110298125975, 4.862607900173434, 1.3197205456033831, 0.308148019736813, 0.07662952276727847, 0.06154660368338228, 0.04518560096321087, 0.06319322540695149, 0.05969129194835982, 0.06517496846255756, 0.03936050970467829, 0.031106379634189992, 0.02325689529008683, 0.05161384473584833, 0.002517842527125932, 0.010360741627312476, 0.027488778390350844, 0.05444812873798994, 0.080110565008175, 0.03006735181946668, 0.06294108288843306, 0.013576554652724056, 0.08279558060871017, 0.05096103823293121, 0.06397738534536573, 0.044047102377179174, 0.01067525615179611, 0.023621782968421618, 0.015936631187345954, 0.05738799497785588, 0.03649695348294993, 0.06375411668071343, 0.014870003139930628, 0.06560914113276428, 0.028499208142860766, 0.05929261979256427, 0.07088341900417883, 0.050602930432726304, 0.019960413206248515, 0.020805279867002563, 0.07743096564926448, 0.014241937446528146, 0.041927019164206526, 0.05954273600852298, 0.02565640332778135, 0.03624120269030814, 0.06862820937268196, 0.042314720940926386, 0.01700007901226561, 0.020077532728112513, 0.07560255892214275, 0.04911664708126937, 0.10393556237461106, 0.026162502077978947, 0.07389709398510956, 0.036489652665031534, 0.015943861142131352, 0.0260728640451787, 0.0327046075835824, 0.021557919117772294, 0.023421087084458243, 0.03735432461384804, 0.035579195471420404, 0.029904596439953295, 0.021385601045744076, 0.18929352322893758, 0.14838789078977802, 0.18068975829068692, 0.19875575097337847, 0.13887122483743777, 0.24290647057275622, 0.15750370889661774, 0.1634707370953214, 0.15967847929606516, 0.20424886186036373, 0.17466953294652124, 0.1451568383603327, 0.1719891904823242, 0.1855294421435364, 0.17931159675842334, 0.12653606778551496, 0.11082807841200022, 0.11954828105386227, 0.0991305286785768, 0.13270559600524365, 0.10475771261319038, 0.11291696269425655, 0.1261318874575438, 0.14024941701321833, 0.2340149630101458, 0.2543353992364099, 0.15075629757296655, 0.11847937389487222, 0.29033669000191076, 0.14277822728599274, 0.0939991338659198, 0.15401178820719644, 0.14982743128653497, 0.11791325024058742, 0.17018451715909666, 0.09414038515739864, 0.20558455147810523, 0.20043567453901615, 0.18089323124337583, 0.11606517803644943, 0.19182886057082685, 0.13799338000676326, 0.14382769113346455, 0.07734531701932992, 0.08810998616559852, 0.16081391353039973, 0.16281479729279397, 0.09890185143317907, 0.11400062470666825, 0.1263247807359984, 0.0974665320808849, 0.13171925780273255, 0.3035241888175088, 0.1444654133651526, 0.32387221953080547, 0.1492025333666994, 0.09440779580824799, 0.1650869681109344, 0.12082498956231341, 0.10266651474540273, 0.17733872117054078, 0.1791862188087356, 0.11769562764393708, 0.24361648086097934, 0.19082537732057034, 0.1992578449989519, 0.15416189547507994, 0.279131367081596, 0.41984704052728994, 2.1755874781839313, 5.604896353137109, 13.033477144856608, 21.58293208768291, 33.22562502276513, 44.94357255197341, 49.008434587909335, 62.46464713927239, 67.30250635454732, 70.35355337204473, 69.82299789305657, 70.80333940444454, 62.51030352807815, 68.69662654015326, 58.31788209176833, 65.98109122245543, 54.23756199498331, 56.67026696666595, 51.20226329372775, 44.413770168058335, 46.37389621426983, 46.79482929168209, 44.06771905960576, 45.1917330680355, 50.09135000167355, 47.70262656673309, 53.236039684664824, 41.46095891152659, 38.69689210768669, 69.94252820168772, 82.02198490019768, 44.00594172939178, 55.14654382582634, 52.169296203121064, 51.39247863523422, 60.9339225676752, 56.97974981800203, 51.76102061425486, 53.818413595999445, 40.823165832027314, 32.294022883138354, 19.548159414722075, 10.65075199450216, 4.845898603239368, 1.3628615919620761, 0.27861104016342475, 0.17750312363909138, 0.12416089644595502, 0.10814887741881032, 0.12399952768558457, 0.19559422868394083, 0.3598193632018182, 0.119704294859642, 0.1063549752917982, 0.15647001113862763, 0.39174518878421477, 0.10753961535350931, 0.11765721599541365, 0.13884373760271457, 0.14964006150201445, 0.2505005163050467, 0.08343137995970827, 0.12184387117984796, 0.10715398201418501, 0.14371087804677027, 0.09096977706517904, 0.1455931407549689, 0.14368676159891391, 0.13060639251864728, 0.06209239919459628, 0.12159096257340525, 0.138115034769139, 0.12754636921829757, 0.1834525931025705, 0.0939106124062692, 0.26108478706690574, 0.07783172922509332, 0.19292707825379987, 0.18792734331180974, 0.159271395494861, 0.20588338705560855, 0.12384277843539754, 0.17473553908207726, 0.06671131949030584, 0.19092437120214586, 0.12926253640363294, 0.1057956161938848, 0.14421022947757475, 0.14643763011742025, 0.09686237982203884, 0.1577958182221459, 0.1791792780521416, 0.12108191246947936, 0.14047182765939545, 0.18633961076697997, 0.1649060794302533, 0.20488088439789512, 0.1759846147990996, 0.18307501900820963, 0.12890629019708405, 0.10056360339325282, 0.11957703233366052, 0.09911965023005202, 0.1587911043316126, 0.12799201788561, 0.09918662163639262, 0.08291864497286659], [0.10129199213077945, 0.06582291796803474, 0.1295726487953817, 0.04468269488443771, 0.04578978386557391, 0.024385752659591458, 0.0455845718932969, 0.028466545984209068, 0.05863746906059885, 0.02017323626205325, 0.025295074127854842, 0.017328560277218782, 0.021096584800210212, 0.1005686442517946, 0.06151497574342836, 0.06267159996974854, 0.030778530391774354, 0.08824356125607606, 0.039463452769503485, 0.028093568417393876, 0.015574940010875225, 0.08803910004996485, 0.050876925609284834, 0.07593540880348414, 0.03331527158978485, 0.06769699885720207, 0.06284980734269466, 0.03348567635722218, 0.01685372749043088, 0.07445253837372988, 0.022180924800434904, 0.014828394989543145, 0.059616073605514346, 0.05351188502484753, 0.04066190539648937, 0.04457698241176625, 0.05800625474582757, 0.03520034584066561, 0.05609215725393546, 0.01643148472442502, 0.01847068628957195, 0.03670639043012935, 0.03711103807173429, 0.012362695997580888, 0.02459870403512351, 0.01224223345953731, 0.030334220463109594, 0.03150630242852194, 0.01757698343886483, 0.010943344790458439, 0.030551331696070494, 0.026421179326491493, 0.022211575978285363, 0.059442623638578, 0.01451963570059067, 0.03125560973140021, 0.024095730923656977, 0.06772198098441286, 0.06553126063438193, 0.017207047241109035, 0.03731549544740589, 0.0520538435047192, 0.046689929515724225, 0.043408855375263004, 0.0736861976404344, 0.04414198619704093, 0.004471123740527659, 0.02185724690676697, 0.03280213823722255, 0.0462615714528628, 0.03393131736365538, 0.685089264185198, 2.984062005435267, 5.77191234596314, 10.19763586982604, 11.419145291851414, 17.950721210049046, 23.939519543801588, 33.96311690730433, 39.476996621777936, 41.51535434107627, 50.06973381965391, 48.8005332792959, 53.120776914781146, 58.696010343490116, 48.900290919888405, 52.02927543270973, 49.64530591041812, 53.472029086082216, 54.24900354877595, 51.2895909432442, 49.314599114079634, 49.07829592304845, 49.434027441086315, 48.56520283606745, 44.52267085352252, 51.60435722720239, 46.71065915015436, 56.88309869458599, 56.67934333124469, 42.516551094670454, 47.71849255408011, 46.04488780421596, 46.61438849664504, 37.678264341046734, 33.26375046084004, 22.363691637592932, 15.950854689844194, 7.92415657351094, 3.1988429061828123, 1.3816585704203577, 0.1913590494903826, 0.044613566940590266, 0.10791356585198834, 0.07737277361053614, 0.0969022470376184, 0.031108647254445863, 0.034277761475213116, 0.038573047927310394, 0.10583346859822351, 0.06583433267810652, 0.026339573725577325, 0.04773550546698032, 0.08270106834149168, 0.035678392366295865, 0.09947349858139792, 0.07372795709318693, 0.032038526692157315, 0.0325751731983356, 0.0246318833031241, 0.005236799892548833, 0.030871043169510462, 0.0222852832127002, 0.04415789784322824, 0.03976518798980021, 0.047703119099981366, 0.015508702133722125, 0.021022810533102003, 0.08149458711305935, 0.03359031630679965, 0.024346000357200543, 0.029896864697577494, 0.04748705549225692, 0.02552843408568973, 0.020726181288820603, 0.11996128671472112, 0.01878660371256692, 0.029925931988644506, 0.029917121977515282, 0.10179820004850627, 0.0026918143914606905, 0.0274276330826744, 0.019679379596885656, 0.06376877577314455, 0.05074681706666466, 0.0056702337667135705, 0.03868124635529615, 0.019266199651024035, 0.026795323262171402, 0.033410641875478535, 0.009662664116119907, 0.04867821879264328, 0.017827371616036664, 0.02511547822054596, 0.050537077514755155, 0.06511458541236578, 0.011716872386093582, 0.03956536927651014, 0.026821965884958065, 0.008438640431831441, 0.02709989683822759, 0.022234390076670437, 0.05769020517266566, 0.034846788602730924, 0.026937413419927322, 0.07653090426878584, 0.06106809367455783, 0.07965362420485866, 0.07688499010738827, 0.015272444448313646, 0.012513917923394232, 0.07820585592379493, 0.022149168540753668, 0.04362034926851911, 0.05293103716065807, 0.03860859440699701, 0.04198385905774851, 0.02699350637774314, 0.0651700884824799, 0.05993255218791385, 0.09480384794334251, 0.06083672363010626, 0.03886684264627196, 0.08222374193851026, 0.009158859799255528, 0.00862506697059519, 0.029941429947352702, 0.03541999473987568, 0.05095525043866327, 0.07387961185867749, 0.03226273956017629, 0.0455301107027598, 0.060653287707076925, 0.09645527303819695, 0.012319840081486733, 0.022090880741034786, 0.061470194073814544, 0.015921482756253214, 0.01826357441924272, 0.020975609940867272, 0.004572833403794756, 0.07268678997793505, 0.044967231430834344, 0.05971792882548706, 0.057102883865516034, 0.021990772201529434, 0.010531812891243927, 0.08984847715304745, 0.01892689356370078, 0.06536132701101803, 0.007664740804748069, 0.05838370243568094, 0.008534288424397669, 0.0550032054044066, 0.045561830573264635, 0.021187080851485653, 0.05096424814133395, 0.05532721846154141, 0.0029084008541934553, 0.03274476208213357, 0.07290763780474663, 0.07233469596793575, 0.03342440081459861, 0.032179063606646754, 0.05566594040682239, 0.02551882542789944, 0.08143179088590607, 0.057753108652128335, 0.045464916620403535, 0.07250711171617431, 0.017742573343698057, 0.0642242533485255, 0.025085284780230255, 0.020557437016959154, 0.053289056860751687, 0.058411764236347335, 0.07977332544302748, 1.3360824676290637, 4.468159156460916, 8.683922617666184, 14.485402280284514, 17.010252552647746, 24.013309132668283, 31.531335653797274, 41.89415724046769, 47.07662805434197, 50.7216238975525, 56.74528621858167, 56.972085506685325, 59.38626904641429, 65.5772675237348, 54.72843093256797, 55.14845402010026, 55.37296264402328, 56.79465709194061, 59.72789179894232, 56.88702106475831, 53.22555126682405, 52.59752096668367, 54.56329522594329, 51.59103293572703, 48.208678999254786, 51.98260315002934, 48.59250645483694, 59.92388086934244, 63.24856027480095, 44.799852986489576, 52.24526859098866, 51.06323096059984, 52.26583750017228, 43.2113048338121, 39.72443542172832, 27.899944551529426, 20.83566369548921, 11.898454023945717, 5.581867137262899, 2.23446715743311, 0.579166270552143, 0.0410105137064332, 0.11398867373504948, 0.05616381711837265, 0.034564389441643036, 0.027884671562201077, 0.027266637790167046, 0.04837675553355967, 0.05041191790012583, 0.004678669886948962, 0.048770302561141794, 0.023051641182973984, 0.0784269335769838, 0.03100891409802341, 0.025598466013287826, 0.049006368724569205, 0.01747878054307113, 0.03894079311360275, 0.060639475141802145, 0.010733398394809376, 0.019815325729488846, 0.036846890955442385, 0.05508376721052393, 0.03180390077402755, 0.025420814054086808, 0.04802368476145691, 0.027642223886364413, 0.10816267466232662, 0.015721336540375507, 0.024520465390636556, 0.017653689907503226, 0.02945065295564071, 0.03294007619842887, 0.05299615846466153, 0.05843707195092594, 0.02404553492763831, 0.0403257460153151, 0.04698340247775759, 0.052058114444897066, 0.01114393725255204, 0.031890181426499645, 0.014746575841620086, 0.003365607873063475, 0.03880948181294146, 0.028740144710266785, 0.031211519456138054, 0.048133246825947884, 0.047151574098895636, 0.03279270386443504, 0.0683725351888326, 0.02234367634950867, 0.02704679928419571, 0.035613968202303496, 0.05193595789493092, 0.02821395530425493, 0.033891430995877714, 0.04526543115536052, 0.021107465163954807, 0.003360471971738603, 0.0477063634823407, 0.07284504076045367, 0.04213654804193685, 0.05295381295464693, 0.05057848839750213, 0.012546056269427702, 0.18382213859548494, 0.1155488730798806, 0.2679925099495919, 0.15310760527368517, 0.08894078553684297, 0.12914339440964884, 0.10206021744036868, 0.10199326135578657, 0.23428753709360478, 0.07438600363750612, 0.1240608300412855, 0.11859467778835567, 0.11312661797649438, 0.12559835318355791, 0.1457718997112205, 0.22651635651146212, 0.2152834850693903, 0.2618718658003115, 0.11946968809371034, 0.13452799660303902, 0.1960373032958277, 0.2547133563747329, 0.19081785433715392, 0.17012658559026259, 0.1831569444508322, 0.19984856007560609, 0.2161944555419107, 0.14215613324796, 0.13012305232546023, 0.12768424972290957, 0.16748324517280827, 0.09333095963924162, 0.182392158876023, 0.09450804607401933, 0.16573982824000622, 0.19885643024838742, 0.13539919179053078, 0.16543593648220264, 0.1492811033442136, 0.11189878587761234, 0.13647560661117877, 0.11784130692361824, 0.0594749448881034, 0.11395691939058805, 0.10888677330747729, 0.12301643003499317, 0.14425141436438407, 0.08982812985777856, 0.17946979391478723, 0.23027990133531634, 0.14024387053664655, 0.1666867742014508, 0.10483115746249115, 0.1268046965161639, 0.10066086591611947, 0.13895641381461776, 0.1670351756676551, 0.17768833305566542, 0.13517330310517742, 0.0777573267658872, 0.25481196721234634, 0.16629614596886022, 0.18748419209113046, 0.2249166423514966, 0.1614341689574142, 0.13674237374817172, 0.11447199094559878, 0.13363882899284363, 0.1401493812520658, 0.1927173080583734, 0.2350143859944036, 1.2250340393474026, 4.232689959387626, 7.977108570837206, 15.922596954530286, 22.882666318647324, 26.016612629736624, 33.45728412751229, 45.45778743682369, 49.58114377913937, 55.74005726845034, 63.71357687057988, 65.02090284901281, 67.82278522368401, 74.28128934675648, 64.32540385953843, 67.94315491953205, 64.1923099948514, 68.15090717807894, 68.49023926642634, 67.1859884262085, 63.71584792290965, 64.80146192735242, 64.33287597471669, 63.40929900446246, 58.73709324867495, 65.44751944080477, 60.45290270159322, 68.28487180894422, 68.40208791917371, 56.16811729246571, 61.72049114781042, 59.82031460731261, 61.499936273021085, 51.94272833485758, 45.6760085013605, 34.887176329089755, 24.039163435659102, 13.287496701363596, 6.885064821089468, 2.1771024936629884, 0.6947347401611267, 0.14451880969347494, 0.2022794030246235, 0.19649611335367928, 0.20831038424324608, 0.1263061494776799, 0.22055919552522324, 0.19308932035440401, 0.16442462381335998, 0.20954663564841594, 0.06824789268355216, 0.10615714840711125, 0.2073864975283223, 0.17776696432021358, 0.18529169441711518, 0.17506247476464318, 0.08706069851834929, 0.10889148474821161, 0.13828945766773917, 0.09885756389027643, 0.12617357030150392, 0.1866636966024676, 0.23500900805717517, 0.10994176064888317, 0.13903458542641134, 0.1133082957277375, 0.10322506179011638, 0.24356172089615177, 0.09248738958229942, 0.1384719244895443, 0.17159657042113044, 0.14711328902311865, 0.05232830599491155, 0.14060213921531556, 0.22535466078308322, 0.11127361982700326, 0.1404380278601762, 0.1336649525910616, 0.2604879432868573, 0.07914748523504504, 0.07697958664427842, 0.10826544535736884, 0.09079031330803711, 0.12087299263164883, 0.08921301488073603, 0.1276319259176812, 0.11254714907056863, 0.09283340085417995, 0.11719302800033363, 0.1116478614388935, 0.08712977666648165, 0.13137724550981678, 0.16572960862709632, 0.23239320083971948, 0.17486503858479763, 0.09171813771489168, 0.20093334057638723, 0.1481873136494429, 0.09318979261743446, 0.11859169770633021, 0.15064608816417957, 0.23690953430148864, 0.10604289405408407, 0.09666863618598831, 0.14459652165251394], [0.018228901279789787, 0.03309044010576702, 0.04415281868029026, 0.02683724742382765, 0.10916158436767517, 0.02748174187276633, 0.056735763040881966, 0.09780062302466362, 0.012590837939041517, 0.019372335387273662, 0.07059965237614609, 0.05991266071495991, 0.03382799508530767, 0.03055334459209154, 0.036216442728595394, 0.02854122806550755, 0.04994558485885782, 0.028337312697042382, 0.06980655219165549, 0.01963352540417785, 0.036040039492710944, 0.037192320000500455, 0.04093339929597513, 0.050623913580972346, 0.012313284284074702, 0.052130444636268, 0.061863821540628715, 0.023054454640875903, 0.06286028742549882, 0.027325517392807433, 0.026844720611529007, 0.04795645671566168, 0.009356750843806133, 0.05002561040342816, 0.056229509157879706, 0.03510513260299641, 0.04851794936844418, 0.0806849241076458, 0.05214006670059697, 0.03504151666176415, 0.009638243148313656, 0.1110129737325253, 0.02520917268890527, 0.015969572010480108, 0.058204568096346436, 0.05473048959468162, 0.09154245077121644, 0.01718755796431534, 0.024865057484637347, 0.07202295946978754, 0.004219519877580986, 0.028934616129845384, 0.06990489489849537, 0.03260032386488972, 0.03168102410141259, 0.027909718806885427, 0.009508006285966165, 0.025284511690598824, 0.07424207869917154, 0.059599453327997085, 0.010475365617763131, 0.05263135888643804, 0.019187679469224908, 0.04404532122275522, 0.02426153916354862, 0.05935474186234417, 0.045341653073386806, 0.042085036289908236, 0.017777641018431996, 0.03980807742224105, 0.013868350839813151, 0.07667032461012564, 0.05339501831199854, 0.1359684564053051, 0.7223531904239809, 1.359747597767461, 3.125674032395886, 3.191030525392102, 8.584135559297378, 10.515070346093948, 15.170733505679717, 22.104452386979137, 25.658882664095973, 28.849603322244462, 31.972776843655495, 35.27210204832016, 43.84879981317828, 40.68249394816738, 43.13715634807464, 41.02003351334603, 42.7782908562691, 47.08649673769551, 44.240797565829375, 42.949808259164136, 42.684169661614206, 46.68593645095826, 44.46174860000611, 45.28883526402135, 42.74543708370578, 44.79986867597027, 45.21214508241223, 41.35586292512956, 31.75157673897282, 27.831305034698982, 22.63944995018744, 11.8837922042416, 4.397305951964471, 2.776161432266236, 1.0470112629475132, 0.49713921402731254, 0.03587402440907975, 0.024238665693349416, 0.04335848509424156, 0.029062288512866345, 0.02675691927452722, 0.04672299004009655, 0.04859784850850702, 0.05184251432036681, 0.055908058664851615, 0.06738450393200883, 0.02916365918222695, 0.07973374934085915, 0.044059432562320464, 0.023566325863582954, 0.04035658871514663, 0.045298070331374486, 0.0869575601011034, 0.047348190564662225, 0.0734715934302057, 0.05727395895988711, 0.04556708976686482, 0.011365275375635154, 0.011239393723137196, 0.055359846146236506, 0.043481729489060185, 0.0954557351407505, 0.010795325112168588, 0.014631720109572335, 0.014469443535011624, 0.04474724162249796, 0.04406129798641609, 0.06353779643353435, 0.055445464132654096, 0.009081678356104081, 0.013623914208203075, 0.042434598379317796, 0.06116325711651195, 0.0901594169197544, 0.020582497668182178, 0.03552163928566921, 0.01734983262365624, 0.04261349906183539, 0.03937888815398178, 0.023108404467723543, 0.025312676913134997, 0.06368540625478472, 0.050236353530518474, 0.048910860543049155, 0.09947077896926673, 0.036266843653133804, 0.03748205445346333, 0.015525753335696797, 0.05040886503974757, 0.032518651231282183, 0.04423136567516674, 0.08096779441280712, 0.029776734450171073, 0.06783340847299946, 0.054014622564277345, 0.03554187549818908, 0.09620660089797552, 0.04960765581457846, 0.009942646269806692, 0.053457159533976555, 0.05706310475004777, 0.08586035365419042, 0.018234759937190724, 0.08712543294795098, 0.038929845717164784, 0.013240734265456277, 0.07086098794975589, 0.013998144328774465, 0.048543827818526376, 0.12034009421064008, 0.03778852026669249, 0.013257706943418712, 0.0459676809729107, 0.024607324439491478, 0.04142257707914518, 0.06120152703876938, 0.03264243571808742, 0.07256529609402342, 0.05039425957347116, 0.03565132264949141, 0.015919859607463643, 0.08947536169040589, 0.04008792168010147, 0.024883001179043806, 0.03143007859527584, 0.019625973692464254, 0.03268854271981024, 0.04643784828423973, 0.09007601292743798, 0.01639548050720365, 0.049165182581712166, 0.035050935712793184, 0.021719988848593448, 0.04948929906071675, 0.005938594845393974, 0.07630174438799582, 0.012139290394712121, 0.02704054417629396, 0.0021604979420155887, 0.0650424275907778, 0.02349326597346414, 0.035923996324380564, 0.012888173899433066, 0.007442235355190332, 0.020250817986145135, 0.027027338735699177, 0.028066496785369613, 0.03010280636860238, 0.03211962859026127, 0.026557045019862634, 0.012989434443654553, 0.05140595528627596, 0.05132073949601862, 0.00042794359732426765, 0.07817894325501497, 0.04423421552224506, 0.05166529520084301, 0.058918608007051294, 0.002816645545892478, 0.05142721039573512, 0.047713771552568486, 0.023332171089526628, 0.0623009053449477, 0.031749816881793166, 0.03132054334386222, 0.04809915208287778, 0.01940936616231357, 0.03490195076371874, 0.07540966564368817, 0.09814712459281569, 0.0413451217595608, 0.04998177485240083, 0.01896540288843455, 0.02430275086343529, 0.03243270382705716, 0.27899886451421246, 1.1426398734892569, 2.045934267582432, 4.31137123415547, 5.789256086272578, 12.40908190127342, 16.339443902815542, 21.19471157750776, 28.006642826141853, 31.88910092076948, 36.43390417098999, 39.68302303744901, 41.543403210178504, 51.01066335555046, 49.44868926079043, 51.65256707899032, 48.85592106849917, 51.66121590522028, 54.970751039443485, 51.62172940469558, 51.098822547543435, 51.89201993326987, 53.107852705063365, 52.42647424820931, 51.066604198948035, 48.63490727639968, 50.27146131761613, 50.706248206477014, 47.77854011904809, 38.19856674440446, 32.13652599242426, 27.021986707564327, 15.956036140841825, 6.445125899007244, 3.7990989031330233, 1.5425003848729597, 0.5425705568444344, 0.1114066586559338, 0.062108180605836456, 0.048191852552155336, 0.03343840490185446, 0.02589627886341224, 0.031349476569542484, 0.08805894938808295, 0.029310903196493467, 0.06710482821349176, 0.04358391029640071, 0.017771948985154593, 0.0051771120671483305, 0.05554744192669469, 0.02056508065922366, 0.02252010256803084, 0.022882736032648433, 0.0379895264162652, 0.026978607882835695, 0.07724283743769893, 0.04390576681602867, 0.046899044705975446, 0.012920495148958459, 0.02328085277469889, 0.05900824029419211, 0.05188347704167809, 0.040919847200594606, 0.02632065518428722, 0.014990253088575219, 0.03586184361108369, 0.055590258580782724, 0.04729253044652362, 0.10427290919206797, 0.051403300791618325, 0.0300759817999337, 0.02019953797571361, 0.04709257383740718, 0.038197588235620535, 0.04671075561594579, 0.025074546142751654, 0.06486145464042503, 0.028545261518428885, 0.053877554112865086, 0.007312852680878414, 0.049147286767800974, 0.05254795489412162, 0.06062996799066182, 0.013254235607511817, 0.02712525051808165, 0.061909472720036586, 0.030678452495785973, 0.04375079105938635, 0.01797038490974134, 0.04616294529349093, 0.019269783027289857, 0.041217353615549304, 0.027728864600160913, 0.024616523240242275, 0.05556602721973773, 0.017519134224482605, 0.01060866970463746, 0.10329688253301768, 0.09840358018634782, 0.05297629763522456, 0.036530925651952144, 0.0342198069237413, 0.07534925194997942, 0.1212527500765939, 0.1414402394044784, 0.13918380403230268, 0.14471192513742756, 0.24059021905545266, 0.15321763082137033, 0.09777131250068065, 0.2374256477360764, 0.08782559134546788, 0.1337435378903343, 0.1532912059056182, 0.11361275439060504, 0.1975226558504566, 0.1665748793992304, 0.1288461676167865, 0.14831313593012674, 0.13095146916326017, 0.14870567938252804, 0.16432017538576357, 0.12459901446897177, 0.10792571600646743, 0.13578594361822452, 0.16814203482241402, 0.13586449827398026, 0.09990417789066992, 0.1481229162985279, 0.2680603546961662, 0.1848361938590965, 0.17281036012836043, 0.08431177586317064, 0.15352964311117126, 0.11594137822788571, 0.10197439261021153, 0.1307288133689473, 0.09641352124632367, 0.10469158390356649, 0.11495851806455082, 0.16404735615416882, 0.13806632689891324, 0.12391151184396398, 0.1922013478413705, 0.12333164457231761, 0.08895391628386513, 0.10860126765985643, 0.19556606729184428, 0.126829341564688, 0.10356326662604848, 0.10732694934572905, 0.18067259792118304, 0.11106599467776476, 0.16154152851912285, 0.1333943090491718, 0.13056074900011863, 0.10657845080019006, 0.15380315182189788, 0.1637835461165636, 0.11298463890148748, 0.097338940137096, 0.23315870653717752, 0.08000755682587624, 0.15481921423587108, 0.12866693368602183, 0.16612317863731615, 0.13409527949988842, 0.05559706527198996, 0.09184055090431245, 0.16065219236958414, 0.17844646898729188, 0.06918239737710646, 0.169028413872565, 0.13730138810651918, 0.14564918774750926, 0.1498493260794109, 0.33516426360414875, 1.2189780223754145, 1.7222655516478325, 3.838662870468632, 5.557770546405546, 11.304086485216695, 16.24995404674161, 21.434613543172038, 28.517806106998076, 35.81320478070167, 38.27754366782404, 43.78246861119425, 46.4821889323573, 55.88630284032514, 55.505754486207046, 57.72538062064879, 55.99229312712147, 57.6878749170611, 60.63228445668375, 58.750390083559104, 59.23742686548541, 59.336831492762414, 58.26007027779856, 60.19449695464104, 59.752222261121204, 58.79530906677247, 60.195963921085486, 60.29276801693825, 55.94107873978154, 44.431864061663234, 38.197311585949315, 30.111002268329745, 17.2518725164475, 7.366867690317093, 3.8677536191478854, 1.3261368077608848, 0.6178310958127822, 0.2088069471140062, 0.13235676552980177, 0.13759473849448467, 0.1969005618124239, 0.05707825796919004, 0.13447801702685896, 0.1604378869336459, 0.14230253265029, 0.14833803378766583, 0.1649607014992545, 0.16764329626194893, 0.2702408247897702, 0.1764556362984642, 0.12072527555808907, 0.1247299388952313, 0.11613284658280112, 0.15244259499013424, 0.21708855675833844, 0.17507358303954526, 0.20407610903343848, 0.1087788928059801, 0.05749935351852929, 0.11578688127619606, 0.25625006746380563, 0.16048651819507923, 0.16189446522583886, 0.13104007489258243, 0.08464907671535209, 0.10518670652902896, 0.18280230702892428, 0.20360511817759086, 0.20630888761051241, 0.093085152667857, 0.16653587020212607, 0.11351428910969727, 0.10257022515419992, 0.1363947843351672, 0.1701908756888682, 0.08768364291397795, 0.137496970353588, 0.0783888666680263, 0.1439468790927241, 0.12226773230659387, 0.20782178868689846, 0.2159359161892245, 0.14409154713634523, 0.15749761083674046, 0.11362661292115528, 0.21727716760529628, 0.18177556534928663, 0.09558701962833444, 0.2060052256790861, 0.2654259928291844, 0.1657427087306015, 0.1417039728332912, 0.25251652264306623, 0.18348224070524016, 0.18102787885694735, 0.13203464087940034, 0.09505956043158809, 0.19982614434294163, 0.2579852872558179, 0.12291539835953906, 0.1357993961221749, 0.1498438102463561, 0.1699758041650057], [0.049692925230990496, 0.06936619719189983, 0.05847310489644447, 0.06729902384141762, 0.029532053628035133, 0.052003634102161855, 0.0464806342948108, 0.01333192841435272, 0.03157134329329335, 0.03059234995875628, 0.061510677990173145, 0.011259236357985966, 0.00842168977889683, 0.06821196315990341, 0.03748499623109256, 0.05194869027623246, 0.053697780090113806, 0.021167491983261802, 0.0209427198710581, 0.020184848239765536, 0.06834798973173865, 0.013664154891645717, 0.08555708242760551, 0.03467317009645124, 0.026689821463679115, 0.01376626292063344, 0.07465861602536134, 0.05697026255450422, 0.03772010478461462, 0.07119067388796999, 0.027238064625811194, 0.06292197282516188, 0.031438635797390056, 0.07024571209424926, 0.012692742954729306, 0.027914114236350984, 0.048543077052360585, 0.005937097143502005, 0.014432429996950012, 0.016788188668508685, 0.021583902904944077, 0.060068394898647265, 0.02362511353567243, 0.06500318856729616, 0.061737064632677266, 0.047435474792315115, 0.018093826572200464, 0.017390816412385435, 0.05085486610750518, 0.03364000093912886, 0.11628617141996661, 0.09421900110018831, 0.024139811622820074, 0.043089442676113504, 0.029553613257444197, 0.014768653537987944, 0.07158235932189612, 0.010077787052479484, 0.07329661894830004, 0.0231563788087618, 0.03663315625500776, 0.030336840483810634, 0.04991672249631055, 0.03838757804084209, 0.07327111588130075, 0.01290005305030894, 0.06745050240668558, 0.04284670388686561, 0.016909079258179954, 0.0201730658074901, 0.026680858234965035, 0.09897600874424943, 0.044653966587277195, 0.016825985531472874, 0.03841544065864817, 0.06546874785976065, 0.004092468504583643, 0.11032012381380606, 0.10153365456649374, 0.5131726069075446, 1.177690173349073, 2.3198272480118662, 4.180647461645065, 5.14953222005598, 8.550468875515847, 10.084159739555853, 11.749116643782585, 13.336685184509525, 16.968471465572236, 18.78115757819145, 19.176595249483665, 16.372294733601233, 17.665674724886497, 16.051672350975775, 19.125726030718898, 17.91853620160011, 18.87471983509679, 20.903422640215968, 18.82246405847611, 18.570412551203084, 17.150051709144346, 12.608081390780788, 8.85057726214009, 4.606610488507056, 1.9983794516132725, 0.2898148309078909, 0.07535083009110344, 0.028913747894787983, 0.011244420217530382, 0.04838005737251332, 0.009143062108646958, 0.06449691170165617, 0.04590650119127766, 0.05695328604610217, 0.03746205189776036, 0.06020506115389928, 0.01443945598082557, 0.027023627039706035, 0.014185931631213716, 0.01432113561614026, 0.05986233639921393, 0.10064773516909731, 0.020780569701004895, 0.027034110952949813, 0.02919021178968251, 0.03901141109846292, 0.05539847996025797, 0.051915748495488405, 0.02008549621208541, 0.04072754380984172, 0.041065779289290796, 0.06870107199516028, 0.024987284897736488, 0.018227010957836624, 0.06840628136189715, 0.04972584019865721, 0.045165939316634214, 0.0017768534387634588, 0.0421128069771634, 0.01753428361318525, 0.03019364141378432, 0.03445083605906656, 0.01412791100465843, 0.026816934602515354, 0.03722020177050464, 0.007394434341544947, 0.06602339551693971, 0.021524871999938643, 0.02528300058216818, 0.035713597936856176, 0.028495517514285543, 0.09421114869896444, 0.10565221985621799, 0.024407565098015532, 0.06341343355034629, 0.032151534237087734, 0.013456840008016557, 0.0751557074967892, 0.02185656508851436, 0.039541582246461225, 0.05361557885583851, 0.03892069862734887, 0.08705625520838846, 0.0390627543111482, 0.021806420803430582, 0.03794626543118108, 0.04381623795075763, 0.12042275509766995, 0.017642162199462616, 0.051170011696916436, 0.05367111639990922, 0.09063208550815621, 0.12176727004829915, 0.07016690462947854, 0.09559843433840622, 0.049925869586126465, 0.06811477724582919, 0.06190318313817825, 0.0703583270191185, 0.057202597869740385, 0.035876315011973345, 0.037828031251387256, 0.06367832377192474, 0.04769751516681525, 0.02746426549199368, 0.04772127155334719, 0.04074529789748692, 0.06590853595445234, 0.048565370210957144, 0.010726562975304983, 0.05425267672586826, 0.047571677564372944, 0.02159822683390831, 0.09640678733346925, 0.04596622923629419, 0.02677892706537199, 0.026438138597915252, 0.014574302777257419, 0.03933607533033337, 0.07015642454667438, 0.05523769725714961, 0.041376914408418446, 0.028851062750383735, 0.024641294693273884, 0.016627683672272874, 0.05442357562001675, 0.07947198475801176, 0.020820586303729686, 0.015002914606743764, 0.0822584533823594, 0.01616025321005333, 0.030591869238583796, 0.033526056851711006, 0.03425253803030618, 0.029000038123359124, 0.048248190658106926, 0.08850464402067085, 0.025871063079384547, 0.12121951718243862, 0.058048462360015804, 0.008272838895209134, 0.01087221927234843, 0.05487760528922082, 0.022899515273409988, 0.059626603484033584, 0.0165852002664319, 0.07012016560521818, 0.05651534422330799, 0.030231001606631665, 0.015144232930915972, 0.044024897318693905, 0.03956228960305452, 0.05860874076343833, 0.04155059420173207, 0.05884661106392742, 0.04301610890956175, 0.03662715778656064, 0.035243947734876026, 0.06631259370835559, 0.05034639439996212, 0.030614126008003954, 0.04171138456571968, 0.0258812558792171, 0.06260161017698627, 0.019342004051131588, 0.0668374865105556, 0.060646055837071715, 0.06290416511136197, 0.06541724376861127, 0.03864783726091828, 0.0548742919589483, 0.025188838800175056, 0.045723544073201, 0.29096350314155706, 0.3149519223840006, 1.1325395251474073, 2.1796360996461686, 4.116383839038111, 6.341048257966196, 8.150684237480164, 11.996527987141764, 14.004451055680553, 17.138967091037383, 18.004728324951664, 22.025706883399717, 23.93844481437437, 24.942224448727025, 21.68944993326741, 23.473475287037513, 22.444274771598078, 24.430204129988148, 23.450994222394883, 24.257792426693825, 26.283108265169208, 23.43702862339635, 23.861762477505593, 21.455915935577888, 16.03183202205166, 11.292212490112552, 6.435040994997948, 3.0607355169711576, 0.660863847982499, 0.20469832564553908, 0.03607750119220826, 0.014924791833055357, 0.048343411556655363, 0.05054581091709195, 0.06801192228111529, 0.03394318023516286, 0.009136614521154234, 0.02982087069070868, 0.06711741503808769, 0.019618385591574257, 0.041512504310136845, 0.053866365398730964, 0.019539612600760117, 0.02932629007245264, 0.028043096629722465, 0.02395283445836075, 0.03854361482925954, 0.03266854782498652, 0.053016341051026705, 0.038905277277433106, 0.07272736199440495, 0.017858922947198153, 0.060081839741718386, 0.06537660280422819, 0.019547373071433078, 0.03746583254166669, 0.028772651736113816, 0.029648008696254224, 0.04996674037688682, 0.057933775167311394, 0.019582469474464174, 0.024675795462943857, 0.007279358838023919, 0.052398257483277595, 0.02453825012179873, 0.010834657023811053, 0.07706947940131349, 0.018791566047096447, 0.037193231645130345, 0.08147928833721146, 0.032344802898625215, 0.03897817054342839, 0.0005883103386299956, 0.005890234587563863, 0.06781367404807, 0.10777155613346447, 0.0325718981724593, 0.04501018598074875, 0.06869803828698012, 0.03324581805856959, 0.09304530843491517, 0.03459712820908716, 0.060339681954393466, 0.03825278487056494, 0.030523187540952238, 0.01333153292146181, 0.07182206823340348, 0.02397552215223832, 0.014939525619059082, 0.061021488715684226, 0.11646519850699172, 0.0107319887930287, 0.06170391217775403, 0.07815420627593994, 0.05955457972783235, 0.1017437082144522, 0.0589892489745492, 0.0731991955469693, 0.03523008537388617, 0.1169260157152049, 0.1852792531492249, 0.16691663122225195, 0.14356121510988282, 0.12991510541929355, 0.21022758056079188, 0.19898435160998376, 0.1664549100302881, 0.22492133080959323, 0.1852915565212888, 0.2113376419630743, 0.1907354539200183, 0.10787438811554063, 0.16987481845482705, 0.1811591097183766, 0.1627516103607993, 0.20247034277887116, 0.2970065579058663, 0.15442242665636927, 0.10073396602585431, 0.16141314750477193, 0.12558943592011929, 0.16878539546122476, 0.2686032965298622, 0.20797344345238902, 0.1417630535340117, 0.07781357294128788, 0.12811030952199814, 0.09873828400046596, 0.2270174393009755, 0.26529039526658676, 0.18087553461232495, 0.2715988841749007, 0.15214426503066095, 0.07708384354989375, 0.17564939004519295, 0.18738188870972206, 0.10867687287710368, 0.10531797569485442, 0.10284259239391935, 0.21891091139085833, 0.07936088668723261, 0.20287119062437167, 0.13455168404165777, 0.18373486585915091, 0.14848005116706894, 0.10998349711899796, 0.10669277410113043, 0.2532431263957293, 0.0647119372602432, 0.22695897147059443, 0.18268743980555766, 0.12981960489865274, 0.09232395238453343, 0.20095990850560128, 0.1722914428119698, 0.16282569106307723, 0.10151637928380121, 0.14252872777081307, 0.17878518710213323, 0.14901343222347, 0.14948322798215574, 0.16667099279021064, 0.20232821814715865, 0.13325713334545014, 0.22010570211756617, 0.156150215395516, 0.11907074014626204, 0.09998951242455553, 0.09534550274932578, 0.10916986577813664, 0.24118234373388753, 0.20138484215544117, 0.15794931159865472, 0.16914017077895904, 0.17222145301920755, 0.11904799499579015, 0.34959659400966864, 0.4321429049295764, 1.1166118830442429, 1.860137843797284, 3.174445763711007, 5.655207124448592, 8.043172071056983, 11.721304097483236, 13.11288062603243, 17.280221446867913, 18.17602607511705, 22.7566562544915, 24.637993651051676, 25.481936700882454, 22.48879171186878, 24.675130651843165, 23.095447055755123, 26.49054281173214, 25.774572972328436, 26.41952829976236, 28.518343471711685, 26.915766962112922, 27.25943719187091, 24.728712189582087, 18.712231728338427, 13.427055612687143, 7.8764404500684435, 3.6233568624142682, 0.943054112215196, 0.3594034387459678, 0.106784796582595, 0.1705950483559601, 0.18321300676513105, 0.17882329231548696, 0.18936863048903405, 0.09034602061635064, 0.06460459302029302, 0.10137990072009065, 0.1447887637562329, 0.15164402493786427, 0.11487916667735386, 0.20670844842830013, 0.09841992850265197, 0.20258514871520383, 0.17649744937737144, 0.0705361896524987, 0.14570863617043342, 0.1583686068413719, 0.21775830146526137, 0.19967027609386753, 0.1663007578181644, 0.11802223390869557, 0.15989025664185325, 0.12371402203796372, 0.09903329679922712, 0.14324039280895265, 0.2669741033065704, 0.2608789545634101, 0.1048333331521961, 0.10557070044019531, 0.0865507367697935, 0.09816471397155717, 0.19465203246762677, 0.1398738194257021, 0.12676931857582063, 0.1339347381144762, 0.16733119204159708, 0.0857523735612631, 0.1628683161951842, 0.17512258202318223, 0.09008201905676434, 0.16814813288229127, 0.15853169163869274, 0.09571253547384855, 0.2395416591917315, 0.23881203705264678, 0.13329572885507537, 0.13470159212668098, 0.16785519618180492, 0.1840113623127822, 0.30232011310515866, 0.09848507661973277, 0.21680488972173584, 0.11775744327854727, 0.06125796856659074, 0.2688166060514989, 0.1189457758840534, 0.13255823133212905, 0.12019450686150983, 0.09568292617557511, 0.3060122891779869, 0.1571895515606288, 0.12987528416898944, 0.23681286932720294, 0.20535400497817224, 0.22819833319273689, 0.15768098164229624, 0.22467212240782478, 0.14035887565583954], [0.03992589025367652, 0.007708284763559219, 0.046121224145134615, 0.03799388928699397, 0.018834419090360887, 0.054006000244689566, 0.05197179931846838, 0.019456246912839915, 0.014800649200145517, 0.012917872255427704, 0.06003078381200472, 0.028611242756127354, 0.02434659024490224, 0.022307034364090334, 0.045276715630485166, 0.045869016509142616, 0.08424288923701934, 0.006544764309505662, 0.006028279322274631, 0.062446010058685664, 0.06967163644731045, 0.04313001852302302, 0.035146420911675504, 0.02771063745322247, 0.07873599642827626, 0.060911103106674656, 0.011691283134202804, 0.041394101590999675, 0.06702621993158134, 0.01832940052413652, 0.03105929012470428, 0.053535250706538084, 0.030459621395435066, 0.018370545191329815, 0.049568692582749554, 0.0399527492963018, 0.01686238619919506, 0.053536468786337686, 0.07500203025917854, 0.015526705199942715, 0.022599743153419227, 0.056162541581978725, 0.045846505015487635, 0.08001112679560339, 0.028169470493711775, 0.05608089959188815, 0.034679559269739736, 0.027808210241698453, 0.02331002348763568, 0.05483470819590073, 0.03614412785898294, 0.042760124460103056, 0.027723741387167287, 0.013779134155371258, 0.02078844316964669, 0.03891949586930775, 0.07032545418628762, 0.06840811231203618, 0.029536395431345994, 0.037913247041644595, 0.09122954215854408, 0.04349070420909313, 0.0435514779641263, 0.005144211942435153, 0.0719936183022876, 0.05336797540827144, 0.05752081547172801, 0.05333858444505642, 0.002076786556919556, 0.05305842609114705, 0.051913212744459036, 0.03897105741705145, 0.0568841542718151, 0.04012383588199173, 0.06134849717660297, 0.00492147283606051, 0.07678359070973051, 0.049534862140013326, 0.05474648934098021, 0.065429508836279, 0.02921880793667609, 0.037897343056336526, 0.056623841425584215, 0.06300253463127921, 0.245793120514962, 0.49819987808023736, 0.5019351389379271, 0.6160429853104776, 1.3398242861993852, 1.498716805250414, 1.13896559323034, 1.170048660808994, 1.3611323170123564, 1.1793258017109287, 1.2550132048706855, 1.6333407620268485, 2.485202709513326, 2.457323237772911, 3.6633385621732284, 1.836406523662229, 0.8007658441220561, 0.6109289500501849, 0.3272238541995326, 0.1182856149370632, 0.030567011600660703, 0.04706898982065821, 0.02413266593770635, 0.035115233472278046, 0.028593214792049224, 0.011190224284937066, 0.028183761863939227, 0.017536612520475062, 0.04061546514651949, 0.04862705178018059, 0.06054287528499, 0.015281854880853527, 0.03939072038197229, 0.0374806180386053, 0.06207504730311133, 0.04376726961063762, 0.0457944531714724, 0.02269939395538982, 0.05774110788479448, 0.04706908941208836, 0.015401732319244936, 0.050107110667252736, 0.0012264302776818494, 0.023127780746548407, 0.02178816684341479, 0.011686971974408916, 0.06497749397831579, 0.062467215372429746, 0.03773709278433554, 0.07021646285730024, 0.01529491859518232, 0.05000634329213251, 0.0049031906265525095, 0.03217617928561184, 0.030145349146257487, 0.021961452101447412, 0.059691506452978625, 0.07697132821645468, 0.05124259852774201, 0.0226257250253712, 0.03207750907618433, 0.04801909589479047, 0.017195609548399528, 0.08657718212493966, 0.07144496911355565, 0.03272882745330853, 0.01822871358824834, 0.10170896612708608, 0.011793055042113748, 0.01880909222358417, 0.009928819340383335, 0.04467035703841717, 0.03233413129383999, 0.02017333010782398, 0.07630116216117337, 0.016877533672677896, 0.020422440833382068, 0.029071847374941555, 0.013459844030289641, 0.02495462273908479, 0.07312439472204255, 0.016639251599929506, 0.03456227886941164, 0.07774218886850343, 0.006773410911386412, 0.029337700952084798, 0.024244125985029726, 0.02767605241388083, 0.01440231220781683, 0.019091045138456168, 0.05024009587002858, 0.07245004582669466, 0.028919686991420966, 0.06700975670208854, 0.10691772049833691, 0.11618522401418417, 0.028347501666435314, 0.006637741528045867, 0.044715376195287516, 0.004052138763419803, 0.034227509937819936, 0.07163153450575567, 0.06520556601425333, 0.03346793759133547, 0.00848974041160076, 0.02067780666684191, 0.014674426638521256, 0.03129053376464835, 0.0699544761089548, 0.01387733513594515, 0.06073499098420144, 0.03192243947377128, 0.05993239513988938, 0.01377326783709108, 0.039644119284686544, 0.039970514875265865, 0.0651079664127, 0.06882075025069137, 0.049463389967117584, 0.018927171270573334, 0.08358454391840967, 0.026797659830340458, 0.050235181415994326, 0.04861755995079876, 0.02086476276388332, 0.02782729540711209, 0.021728310478670944, 0.01111162366390589, 0.033883283650802995, 0.08466249091490623, 0.07070982348053687, 0.05367927523630281, 0.038884734629743525, 0.08240578741195702, 0.02904173245863809, 0.06871524462175947, 0.07876345301948248, 0.07826208677743712, 0.029974312356282628, 0.02864343760114524, 0.024327817260317748, 0.0682408293528903, 0.07826263836074261, 0.06131607633564742, 0.08993748124809035, 0.007717647794408785, 0.013257410084348054, 0.03195461133615144, 0.029665615311974, 0.11348060422366667, 0.03390754948580458, 0.09433003022305428, 0.0635953258062082, 0.08157412236135814, 0.06265171232723421, 0.019100682524543618, 0.015018781245265518, 0.029390461427429994, 0.13246472264009138, 0.061019814813569676, 0.008838410966188438, 0.08275811124833361, 0.0283016647107058, 0.05273470414742347, 0.030273283914392515, 0.0009008142414161065, 0.022657046530155406, 0.04866534851551537, 0.06864592898637056, 0.03786781036685552, 0.05552329100488175, 0.03447997038282695, 0.01384986992624979, 0.03194849603929587, 0.0805817473860037, 0.23483217964249276, 0.5789540948406343, 0.9765888450126495, 1.0662952281775013, 1.3600129706244315, 2.3714674576636288, 2.5619242700838276, 2.49053517176259, 2.4035720575240354, 2.8033150203766364, 2.0480751462521094, 2.9063809350613625, 2.8939200553201863, 4.174439820551103, 3.706956299081926, 4.634275455628672, 3.0551174571437225, 1.5886577338941636, 1.0464333262174361, 0.3556595057729752, 0.17508605495095256, 0.0913008496225361, 0.053304842102431485, 0.0877181398532083, 0.03070414708476634, 0.03463281641503976, 0.06664081641863431, 0.014571135003690519, 0.06180630365927374, 0.03844416895580869, 0.01884945931153432, 0.07686605241390006, 0.023431925313367, 0.015393837783185225, 0.038689186856631315, 0.007534725629093667, 0.009172534468703935, 0.060838922302448945, 0.04539323377332861, 0.03954308760923244, 0.12940063141286373, 0.0076801343839765805, 0.023108492567834836, 0.07776891767618158, 0.034052780604050044, 0.02262444374331784, 0.04921804264848752, 0.038813040291349736, 0.013146750598905549, 0.02512712084177521, 0.022252268653603333, 0.03464328500652506, 0.10466299350223235, 0.04253875186306335, 0.004967699539021499, 0.0503875179997375, 0.048131404384489984, 0.030032749543146744, 0.04189703448285018, 0.05841274099845079, 0.03421971882363001, 0.017179592565122633, 0.062038332539340185, 0.035193033531428344, 0.09802845757334464, 0.05254942578293624, 0.03996825874632886, 0.04015428787698189, 0.01998648317831178, 0.030339364743521138, 0.05890086158028534, 0.02177743969725505, 0.03797453790602665, 0.013903581308231, 0.014480865905962646, 0.029256949539206205, 0.03432752654677437, 0.007178728879925105, 0.04395234496182492, 0.04121239319623959, 0.03366502520117549, 0.07303386611203033, 0.014785848381448419, 0.053429714434089205, 0.040821791776726325, 0.04091761405429533, 0.032731298086864334, 0.018423805539045605, 0.015857108387975924, 0.04766638518401212, 0.0570743853947328, 0.035657799922891205, 0.04001541145806832, 0.1332581445815102, 0.13844367116689682, 0.1770814688455674, 0.20557112961767182, 0.20509546562548608, 0.13223198512869497, 0.10000863397914557, 0.21325906708596215, 0.09731554381188848, 0.13454816003720607, 0.13860643420728946, 0.10789523336796031, 0.15740673748716233, 0.12777610366503078, 0.20600870371826235, 0.08363093820310409, 0.19867488273209144, 0.06321090671624388, 0.12372202765677245, 0.11055458502303209, 0.18206442646201582, 0.11449673558555304, 0.19416035723782357, 0.1306797224547594, 0.22991345083761602, 0.1592003791442802, 0.1254557995426078, 0.12717989573795951, 0.19369328875214825, 0.08298842026101005, 0.1349517811209925, 0.13252702091009388, 0.09467562780745568, 0.1295529296922107, 0.19867742614400005, 0.11637158256264464, 0.07706056979875411, 0.16877093172121435, 0.21067053259861088, 0.08163046812818897, 0.14551406515942467, 0.20184187488930844, 0.10321961490497475, 0.25726779994945376, 0.16215544073812424, 0.1964475433792799, 0.09232757598041527, 0.1497662974701774, 0.14053136801287053, 0.2278382105812911, 0.18322996795177462, 0.09673484916528387, 0.14647188956939405, 0.09163035169964837, 0.1411723691008745, 0.0750192748983541, 0.09921361857484426, 0.24668722173138974, 0.14696642996803408, 0.20888833629508174, 0.13536631129682064, 0.1548473909497261, 0.18733747093187225, 0.12130099063318585, 0.11702628130273474, 0.13434902314216862, 0.17963088688350495, 0.16123374503466392, 0.12614948449716454, 0.19052744572681768, 0.13824733815366222, 0.2143294604555253, 0.1796202995483914, 0.10609987567389205, 0.14955389193229138, 0.1996718848785085, 0.14473236436324735, 0.15001860086715993, 0.10252956120717911, 0.18312692912595888, 0.14485172086185025, 0.10787374460168424, 0.13511874232321017, 0.3878841056458412, 0.5999008385885147, 0.8795802956146579, 0.8255973278034119, 1.115636561186083, 2.1958881953070244, 2.330763061200419, 2.343004288211946, 2.12949717717786, 2.2499475267625626, 1.9998249675958388, 2.627386667074696, 2.516310782201829, 4.572108830175092, 4.021108977256283, 5.260173457284128, 3.4560998889707752, 1.7529909480963985, 1.1405420183174073, 0.6754608872917391, 0.39176458613045756, 0.24341472394524083, 0.10725176547684016, 0.16628693759201035, 0.20310777389714796, 0.14303675131692042, 0.1767211930165368, 0.17252122322397848, 0.14934193072540147, 0.12909669368978471, 0.1695211616254622, 0.21108199842274192, 0.10874587441644362, 0.13181379305258875, 0.13315349697105347, 0.1560483869886206, 0.10635624699775251, 0.25414904068794947, 0.12894054964905785, 0.12640062344050215, 0.23722307876713816, 0.09608789557410825, 0.21696995102590133, 0.18980242011527862, 0.06976284687557528, 0.16848950166135065, 0.16700850048613164, 0.15751516957196499, 0.09428420284342381, 0.11397356648118266, 0.18624372720237703, 0.09869506131977805, 0.2100449911649189, 0.08902064254206997, 0.1357479456571802, 0.11746309697628023, 0.1318420616969947, 0.2916900915724616, 0.14650590387323212, 0.18045256214757122, 0.07706070769458048, 0.1345921028405428, 0.16415178926000673, 0.11778035696836249, 0.2236825666360317, 0.18048637726854894, 0.1031162160178346, 0.16200066033390262, 0.2237108812457131, 0.0921613885270011, 0.12900510021755773, 0.07924054959608663, 0.15469189042285567, 0.06340371189458717, 0.10360128756973053, 0.09949549296570402, 0.16552048194552624, 0.08065086383853229, 0.17526930318244044, 0.09645197119924331, 0.0818215994044177, 0.15266284526836488, 0.13683252697510107, 0.1589636886191945, 0.22785840465897517, 0.15080762546389334, 0.1165130177152253, 0.08478894904856721, 0.09324200917035343, 0.14366224678533693, 0.17432177499417337, 0.15553296303316472, 0.15129865717984017], [0.13166799119883968, 0.06481977945734417, 0.047461552425257625, 0.04428769612023908, 0.08988714927146513, 0.02897369235964312, 0.027839692624946757, 0.017340156933172576, 0.02473591804324139, 0.031720544662206404, 0.029503342567852912, 0.05266351159662009, 0.0414152073133136, 0.08775095905988448, 0.038686222096364346, 0.015111131229317717, 0.027427703945807395, 0.02954783120883569, 0.02055625532633595, 0.044931458955210064, 0.0756671937603143, 0.06884655975286039, 0.00566361716107255, 0.006405341574141095, 0.02207600522876507, 0.05237047530470356, 0.038641394461475076, 0.040399278964727156, 0.03958445635714358, 0.021532992531936017, 0.06689396251233355, 0.02311920247701628, 0.007923932289779789, 0.0490760252690844, 0.003585731986189081, 0.04228370587131189, 0.007839049747769512, 0.04518014258675037, 0.05354723232167383, 0.021154307610084935, 0.058626897047243776, 0.028392850241113095, 0.005460668978611789, 0.04492665175348521, 0.011260069478603621, 0.03651764168734512, 0.046344573249018965, 0.060941727471447764, 0.03252910833144861, 0.08562884954435211, 0.0347272482430262, 0.06346744657944768, 0.058047857150555625, 0.020505411986021266, 0.0010905262799144934, 0.03098029113795248, 0.04893676197576908, 0.06354387534121353, 0.08142517954711953, 0.03914280283835627, 0.0285178987729934, 0.07485105731194058, 0.023928344542641315, 0.011876477229018367, 0.010997922809403992, 0.04449401508956667, 0.030333257107544812, 0.06442227175519352, 0.007522076081048938, 0.0504841638218251, 0.033488392138913754, 0.016082501031398293, 0.024909538464740883, 0.0635937323433257, 0.033005722272660465, 0.09627128170142252, 0.05811542227503754, 0.024728429533781546, 0.02461517492549554, 0.03876922772296014, 0.0013155722685511254, 0.030279726713835716, 0.03310812907593866, 0.06242058743091841, 0.08823642131662177, 0.10256953567506806, 0.08622747830926411, 0.03666864910853967, 0.027561895737063982, 0.022430255776271227, 0.06070783699772531, 0.04511793241685918, 0.046235861542123946, 0.026944277567728877, 0.041459265029838974, 0.03199139887827539, 0.007986662441849588, 0.03245765148031135, 0.03365208214569477, 0.0333713875302384, 0.06906101840638346, 0.0610170454057234, 0.03889967334426699, 0.02125043249238403, 0.04807104814737555, 0.03773354962768574, 0.0536645088915623, 0.009979851329849373, 0.027099935142623804, 0.11033825711497378, 0.012090242572969968, 0.032319855245371024, 0.04364089574664832, 0.07324136868720094, 0.02658155408778018, 0.00891278182426768, 0.022944904067703796, 0.007901877097244705, 0.019312140028623324, 0.04746830165987054, 0.015952076477509354, 0.04184679443677587, 0.03049548771683007, 0.06755688903673042, 0.05440707791656737, 0.03525257771534305, 0.039205698656939694, 0.05229072555178597, 0.07379468335139175, 0.06427643159704824, 0.005664969785063858, 0.033532319620492, 0.04393180614457496, 0.018476112107295665, 0.03969940785018187, 0.04971855853293693, 0.059258291392677256, 0.06971353379588935, 0.0579590101035372, 0.10095918821471353, 0.03208699132946711, 0.10551243945355378, 0.040373258788378975, 0.020660232609858917, 0.09501013243871351, 0.07479396077894396, 0.07124972394517354, 0.034804902745470885, 0.03863687454272182, 0.024896107028208436, 0.06429402863666897, 0.01960422828673355, 0.057910152846166206, 0.055314773363211465, 0.030607037779484546, 0.05170076124129757, 0.05340908751672795, 0.04075928283254466, 0.027798172574670568, 0.02675683500485555, 0.041630968316307956, 0.04416324513693971, 0.0532057294772277, 0.00907995465827445, 0.04411296295602957, 0.07982473760362595, 0.04037452283345404, 0.009702752539587599, 0.045683224865746115, 0.022126741316770355, 0.033123312938597896, 0.0477041456577999, 0.06538898278508457, 0.04164948849187743, 0.028447824710559462, 0.02370632268608578, 0.04554123429942035, 0.024381642597877694, 0.06763107699131773, 0.03403790700700014, 0.018337913676195087, 0.01536010214382963, 0.0338857734365569, 0.058789242569717674, 0.037315955100160454, 0.05555530198879781, 0.022827319147425796, 0.0594277500415281, 0.026783826197647763, 0.014335259404634277, 0.002866746977932992, 0.05446324748317561, 0.030956653495048805, 0.018958475538379243, 0.02507379537658586, 0.0055582384154531025, 0.0927728645864033, 0.029120739106269136, 0.015665513628553, 0.034392153724066676, 0.029105036219041196, 0.04167783374507581, 0.0370733120719031, 0.027384324217095014, 0.023880690043311448, 0.06464564767215522, 0.05974340507940901, 0.025564892210006237, 0.03328580401777741, 0.0069745803334479856, 0.047887286636978395, 0.01917116069835761, 0.029217003799614408, 0.0569493368628525, 0.05558982191066589, 0.047389302673118736, 0.04653082837560966, 0.0681827905317468, 0.02902780114973505, 0.030823448041994727, 0.049435366470847404, 0.0551747861168077, 0.01692337637406684, 0.04302769215897687, 0.009767128823084698, 0.04141736002038083, 0.02074998938628743, 0.047350025345240875, 0.05496103226417496, 0.016376835842346473, 0.010813700688642361, 0.05793599299185219, 0.04084709183042569, 0.036982392757049495, 0.050758262420253414, 0.0595370133317286, 0.026119087875309973, 0.0914555917223615, 0.016765160065504815, 0.06252620797303897, 0.016859335254036614, 0.05266314004397681, 0.04346525093780891, 0.07605381535306092, 0.01699553994131425, 0.05622259521436307, 0.07674143289125736, 0.026791149998203884, 0.02922572762585215, 0.04404147163093571, 0.06010311783381528, 0.10474261302020281, 0.028281405515548204, 0.05050841816550782, 0.020509033666683302, 0.018436371296223615, 0.058619764768668724, 0.05783478511617549, 0.020045196156828635, 0.09408249189296077, 0.04909541495444794, 0.019560802592745712, 0.0915690416830682, 0.05042967581821065, 0.09954942555557336, 0.04596122668214864, 0.058581123293768016, 0.0045749162053388935, 0.10996141080414096, 0.07182859530251834, 0.14493157786707725, 0.04434165935362539, 0.03146647734777822, 0.012316069971289367, 0.08100704109716801, 0.11443574732590107, 0.046192439678575725, 0.0382276495257693, 0.03887639193224811, 0.016026216551601406, 0.044061876382798924, 0.037469984738216285, 0.045919229742139585, 0.019193394485140042, 0.07691044720911211, 0.013491399191890754, 0.024501954791166132, 0.05767309842931648, 0.012500609060929669, 0.11631837775630337, 0.05490141147146783, 0.051824005636116194, 0.004745881174570851, 0.01738206194263072, 0.03222712796301611, 0.03716063077351259, 0.0611852974660935, 0.02441192413830469, 0.018572798148999294, 0.04313730401918293, 0.041690424400111364, 0.02879309479237324, 0.08677634200261486, 0.09292534672685208, 0.05615369326645329, 0.038132796349424514, 0.05290846437996915, 0.07510650166941267, 0.006669436021888208, 0.017956399974683603, 0.013895422471837412, 0.04137971445978169, 0.036444993569485606, 0.06255960557609797, 0.021375278010964397, 0.09069501963113585, 0.013581070741037688, 0.0421087620329232, 0.040279635183152654, 0.02169672467355286, 0.04391748413083054, 0.09771744885872449, 0.04860278211473938, 0.07006850829648395, 0.033871600809957714, 0.01382021945075042, 0.031443310848947977, 0.04608538272159715, 0.042667952591493245, 0.01731170059722518, 0.017433039348332152, 0.016262698317727736, 0.07301312811192005, 0.02109961850839036, 0.020669833606769963, 0.03257879679421744, 0.007461480441458164, 0.05908438943386559, 0.00284956171057157, 0.05642323747217175, 0.04412824641011896, 0.06866056126572433, 0.04274342757379336, 0.04820324044914977, 0.02497245918118185, 0.04498747147379383, 0.03228046683474414, 0.02824770913819873, 0.028214604563770757, 0.07049969322378598, 0.042091394819679766, 0.04368682271770893, 0.27645508488339765, 0.10255313373260921, 0.2961464863150351, 0.12185827363282443, 0.19556303358366414, 0.0803156314237464, 0.12343230086468882, 0.08531283827558642, 0.13008814935963, 0.16066135478115853, 0.12024860032984327, 0.20614368841052058, 0.09238574503650589, 0.2018260475127928, 0.22305488015615174, 0.13608637265861034, 0.16347312728964514, 0.06870065064680192, 0.132720657293835, 0.1405459696487073, 0.20584826958515953, 0.1831561936846664, 0.07580023258924484, 0.0948558729742804, 0.11912847253223581, 0.1428802548757484, 0.11425282851222063, 0.1620686123327863, 0.10240072820095286, 0.12371160886100224, 0.13514652067134458, 0.22338458907700356, 0.1284643953606006, 0.17130243862348218, 0.11845152659882462, 0.12243326092439315, 0.13903029533403535, 0.13630973325381357, 0.14053775718615902, 0.11131612238504233, 0.1385550756728457, 0.2830737168269773, 0.17311313339779455, 0.11670529812334046, 0.19540344214727803, 0.15446471470978954, 0.1480477171078805, 0.16286911292662545, 0.17260143262965066, 0.22344866467099037, 0.12423067939497771, 0.21177170738097162, 0.10601288639009, 0.1557867832842373, 0.07510378971816072, 0.17536907847369873, 0.11394526719325974, 0.16453998133299813, 0.1613211556668243, 0.1751263664975282, 0.0906792612025334, 0.25200609358087667, 0.05582093914610244, 0.14208119452720688, 0.11811254035320976, 0.12724991617423873, 0.14511473416801424, 0.24518408061515903, 0.171540615359141, 0.1860594524130706, 0.1766685627761387, 0.1446865523053754, 0.05692497143642076, 0.10226475525527232, 0.16256620176136494, 0.18154023846070613, 0.16441679439477383, 0.16373724376242008, 0.13269975841526063, 0.08096342005075947, 0.15303127227290986, 0.13260283297108066, 0.1824212242518702, 0.17847383364794717, 0.2815602028802518, 0.2325327514160064, 0.14243151121322187, 0.10864889534610896, 0.1317972608751828, 0.1051936396247437, 0.19028404427151527, 0.09460392197774303, 0.20290757980077498, 0.07895293720667401, 0.25264246749781794, 0.1444084470671031, 0.10704699017468, 0.18548862497893073, 0.16887495113957315, 0.19273900366838903, 0.14504333477347128, 0.16064514436068075, 0.1657765698168547, 0.11135434251158469, 0.11928554353935104, 0.1554434533200918, 0.11222933749518088, 0.15603462804950055, 0.10636891043114086, 0.1446531202283598, 0.1057679450980598, 0.09734143758372915, 0.1860511326982129, 0.14380142963942022, 0.22783039648446346, 0.08789150555047297, 0.13680078029151888, 0.19367073512365743, 0.11352504498415417, 0.12279713736666788, 0.08816086972552924, 0.17462149923366888, 0.09343700919059977, 0.1361386045332878, 0.247854417971065, 0.09256209081579601, 0.15403860128454624, 0.1484101686266161, 0.1542969720978891, 0.16167118123942809, 0.09364308684223122, 0.16284361752050538, 0.15260315169730496, 0.11467771619678506, 0.18337428359495056, 0.21182541014446368, 0.23909290020744647, 0.3372624252111681, 0.2155705995016521, 0.15054559275027246, 0.14798699697900206, 0.16364574222074402, 0.10153802126766213, 0.11309758324416415, 0.14234131202101707, 0.18046607593855551, 0.1558631469285296, 0.12991176527594367, 0.09909607004374267, 0.09601306410566454, 0.22494697943329814, 0.27239530918098265, 0.15477035314806048, 0.20033378484508685, 0.14998256409120175, 0.18695119407869157, 0.12278354696689114, 0.15306373907914086, 0.16510258098283123, 0.11469960332878175, 0.11637220309386331, 0.18143908421118415, 0.10770948002896003, 0.20777700318684503, 0.16057112494543677, 0.17771031977909227, 0.15828182440130942, 0.145818232708881, 0.10088175970820651, 0.17041173883743826, 0.12520134343855804, 0.116761414063794, 0.25333205388197977, 0.16402376064610097, 0.10102409884453782, 0.1167844809711941], [0.025440062013184352, 0.08900247093650604, 0.018999298448644338, 0.05058187450612745, 0.03416444557989317, 0.015891662783800595, 0.04205109476442299, 0.06372408986452126, 0.06026541739101372, 0.030037179446568894, 0.00397119774377995, 0.02454855591960011, 0.02228678474503179, 0.030115678560950106, 0.033277599216108365, 0.03757527586252939, 0.04440890272117911, 0.06695969285623682, 0.07827748514471516, 0.0207511653312512, 0.04599488092466228, 0.07108821728897673, 0.029620793422744162, 0.027208210179401983, 0.04126024687842977, 0.01978020634382002, 0.0771964967791592, 0.024472226749264428, 0.036687054370920506, 0.04906611592178384, 0.03752680930999979, 0.09232133236383239, 0.06851710364102356, 0.018117209490869316, 0.026323183274437344, 0.030086921535492427, 0.04540292478557076, 0.031559195054034074, 0.03262932412326336, 0.023778315798770037, 0.03640383166531402, 0.06493263186946993, 0.05158163456907196, 0.05005776311361021, 0.01813262892556527, 0.056671151185348156, 0.03921741597174157, 0.005896282372921105, 0.03943989939627148, 0.03210004546769685, 0.03786725495311041, 0.1014613435273209, 0.04515079758881081, 0.01966433746049241, 0.04979741196298311, 0.025668540075721762, 0.02575064937944614, 0.060632181984762994, 0.10526346853904187, 0.024773678517029173, 0.021479377868555246, 0.05017198299268081, 0.021079951116154273, 0.02308301056825346, 0.015560026194209294, 0.04203247499742335, 0.023905220178646908, 0.016177865571432536, 0.09984235459518048, 0.017317651185177026, 0.11456371465277289, 0.03570799400369006, 0.03464129317792193, 0.04527977232130305, 0.029869337243238286, 0.023163654728822654, 0.01850557201842387, 0.048891413401091294, 0.06716721841404516, 0.10166208154612011, 0.02176820259210804, 0.0400300475678617, 0.020167113304318442, 0.07045859260664833, 0.07834278647938082, 0.061531381516326825, 0.04833584643840309, 0.03889853187325982, 0.04352039777703824, 0.056199336784981915, 0.0375488956248568, 0.026210127849011656, 0.06614455232216467, 0.043545000690726504, 0.042213172156123385, 0.05540712526248348, 0.04646762995229614, 0.009917023501569226, 0.03772609559218249, 0.023792189651078755, 0.02594096860247514, 0.05130125021922493, 0.033303741966524435, 0.02775183000091103, 0.060646733824884703, 0.034344683085838636, 0.09340286465181459, 0.05020554147420391, 0.03319192377309645, 0.01557426106545233, 0.035805271848315195, 0.002371219283480558, 0.03040259955601106, 0.04827835153968585, 0.029458560898239096, 0.017814327053905978, 0.024105146144246383, 0.06787952696604115, 0.014298494845148058, 0.07617750024843602, 0.048837664672323776, 0.0790543595869695, 0.02799104670092704, 0.046363101085467685, 0.024922136780655673, 0.020549877644366315, 0.08398712312261905, 0.04711495892655465, 0.032688079236616055, 0.049979871123908996, 0.05100710693025782, 0.0062910115699313825, 0.057789068819294055, 0.0629159092392412, 0.026557037358983394, 0.017520359965161453, 0.026337118413780006, 0.03551252283937028, 0.07265234666485941, 0.00787759306765492, 0.008914486369899204, 0.044371375904208234, 0.03218451815266763, 0.04195717621534582, 0.030691129335713004, 0.033132184236761064, 0.08655662798593122, 0.018340874606022434, 0.05389589808821198, 0.09289544631516741, 0.026378197963499737, 0.04000900313258171, 0.013048840731742882, 0.01293821188981735, 0.059068133048112356, 0.050614605612692334, 0.03254267957902724, 0.03958131922709365, 0.17958539658256117, 0.03665232377487325, 0.008591771831796055, 0.05304537195291731, 0.011227164087035965, 0.02455721079792467, 0.02678882300613388, 0.035401053215947845, 0.11893052307348098, 0.03307747406764858, 0.02360152377326402, 0.012497066861889776, 0.012121407029729699, 0.02335124093318178, 0.023139467417833307, 0.07012784946709871, 0.01067234789051356, 0.014915549939858818, 0.008017470188919575, 0.04984591298946931, 0.014766354316605196, 0.028328525668550885, 0.01741764672671355, 0.042765785849863486, 0.031219074998291272, 0.04806255223229528, 0.02287379195613246, 0.0034459702569180203, 0.02450708949547862, 0.03433785341199368, 0.07066433317959309, 0.04607123690807531, 0.07425503324597113, 0.023570117998808145, 0.037499172688131376, 0.05168202273066967, 0.008778264445643271, 0.03837406041941816, 0.03314950931516867, 0.08049905585545687, 0.04144669352700153, 0.0642713600949895, 0.06076618991491776, 0.02526889881870199, 0.021409882202504144, 0.0724420325470067, 0.03131015136116936, 0.041351487950211575, 0.024190750724125295, 0.05511643703005487, 0.04106966335506689, 0.038920817370977134, 0.07854753113802403, 0.06425844002214652, 0.0412046633690836, 0.03229860396635148, 0.058481244580639954, 0.031067962240007137, 0.01531421539238504, 0.022271662169406493, 0.047703096117343635, 0.007012967562918822, 0.028977329362063643, 0.005131963154135813, 0.06429284120038634, 0.04583809337007903, 0.011304127195128992, 0.044962175250534094, 0.029710416133785923, 0.07882205874568994, 0.0799161472147511, 0.02486159285199979, 0.03963802122480927, 0.02332624731465213, 0.0197590661475495, 0.07201089358498013, 0.050850081888418046, 0.10490158392537026, 0.024879988538281574, 0.062248160191360986, 0.023067531761743372, 0.10411004656024518, 0.021633807787551515, 0.030649611200656623, 0.0519221376687769, 0.010422307325737372, 0.025334918360796668, 0.06178657306478389, 0.010876391578706042, 0.03172344047456019, 0.00488360415235342, 0.052446088182830045, 0.028271243359232624, 0.037547114470432845, 0.02741322105359887, 0.016917188298858462, 0.01277038213541551, 0.052986743244072126, 0.07686369286309327, 0.0349875993936533, 0.09223134001536716, 0.08018516665024143, 0.100079228981368, 0.038688018572546785, 0.035480887238537116, 0.10773548105311011, 0.06812778541878348, 0.05468995588260794, 0.02274208228975054, 0.06818931760086168, 0.05825055635444099, 0.021201203682369763, 0.07019026265028985, 0.04068731270249813, 0.07572046751456876, 0.032569052155820594, 0.0204852121626778, 0.042768972775628494, 0.012178083171977872, 0.02612293172147005, 0.006801951038200529, 0.034121579130090056, 0.029070786343166427, 0.08954773401661266, 0.017585012040311293, 0.03292837803582511, 0.02977424274919735, 0.08345122163694713, 0.011369921698895915, 0.050079225066808924, 0.020319375194488995, 0.030662209516571417, 0.04325419371466964, 0.021440393569308425, 0.03004532870686343, 0.02436552602317064, 0.02547023247086233, 0.022899838945557995, 0.02817940473886988, 0.10514880049853556, 0.010407210605579519, 0.02210342734601469, 0.04816605071086557, 0.022177063717296528, 0.055579855106771, 0.08390365018238945, 0.053328238427639015, 0.05539326290149362, 0.03266005190990625, 0.06163994766651623, 0.08357790193610615, 0.04371429846111325, 0.010858276472126525, 0.04987837979570032, 0.031571703354617765, 0.03982126179541792, 0.011611016271936317, 0.02537209852298181, 0.0013766027827401676, 0.031446189424323465, 0.07107753802331225, 0.054847122650713696, 0.057902032314168836, 0.06452466706715285, 0.05028654378087771, 0.06546618912609355, 0.015909023293774697, 0.06756952948748104, 0.02557929466298271, 0.06718683792578597, 0.029521573545230977, 0.05309853462442275, 0.06149527196201587, 0.03278767066677252, 0.03839411660127583, 0.014730179644820672, 0.016202660007101875, 0.056262653951923695, 0.008904412313694916, 0.038022954662841175, 0.033251877814050645, 0.02865160409841807, 0.02137220408316822, 0.03646146062941801, 0.05211542548251249, 0.08553236077028899, 0.005860211123006359, 0.03688284346172887, 0.034834929561663064, 0.06336557603771649, 0.06138738379963945, 0.04158565421558676, 0.03487745893277949, 0.031832929760698354, 0.2561828662310877, 0.1557848987079436, 0.11967880711440118, 0.1607670902364677, 0.11972545420811062, 0.11373725133917986, 0.16290306594342957, 0.1553413337997852, 0.21522903153973244, 0.07091794658692614, 0.1755877812543223, 0.11933698634346647, 0.16924759162770164, 0.1223957226161034, 0.1465297751729527, 0.11655865357287469, 0.16766180494619956, 0.09373936877255479, 0.1517267471119281, 0.09763155508065417, 0.18758228198895532, 0.31954363889751897, 0.18078409435768283, 0.15571656366509778, 0.13087983994233993, 0.2359422870100506, 0.1967124565834961, 0.11708560715159101, 0.14035887565583954, 0.13578119387309398, 0.1573542604643491, 0.14767853933716976, 0.1808481239863942, 0.11301747342992215, 0.16688514500856402, 0.1848500447287675, 0.18172527933793683, 0.06620881177725331, 0.14272601073307378, 0.18964819129436247, 0.104183177313497, 0.1966235444190041, 0.17139479818363346, 0.19733992855875723, 0.14692449431505897, 0.11282971294056024, 0.1747500641091216, 0.0929236843160564, 0.13087737313922376, 0.07560818966838621, 0.18230955927602707, 0.142921669588935, 0.14363273707849367, 0.1666108855316716, 0.17089809741704695, 0.08155499314588886, 0.1497980135102426, 0.2246941397747686, 0.11280401069070063, 0.16945854159853152, 0.11326231513052218, 0.1389703106495642, 0.13199351727962494, 0.16980352631259352, 0.10033773002965797, 0.11843625080561447, 0.12668291917972027, 0.1170250019359012, 0.22621436465171077, 0.1207097469558639, 0.2235345737708192, 0.13071408915904262, 0.11814971093929584, 0.15098672149883163, 0.12593180061348025, 0.12100330418756894, 0.10870511087799266, 0.2345777618428392, 0.14247367669257427, 0.14918607779808585, 0.18865800733047147, 0.23742201647931532, 0.18045245489526182, 0.20204669615674406, 0.2457202961968799, 0.13841319618926895, 0.08585625508379552, 0.13149111681888181, 0.14018855898851348, 0.1873246466200198, 0.14241382990392948, 0.1285008381631586, 0.222693654378095, 0.09399086777721682, 0.14885331984729538, 0.17603810305797285, 0.16720098773798636, 0.08907740965725915, 0.18855725144667013, 0.09867528092957313, 0.11979286228456806, 0.20708335653668453, 0.23055547848343852, 0.07092798233873422, 0.1058879297887606, 0.16124811684412343, 0.2059916046357924, 0.17686126453261222, 0.07140527043731944, 0.15007766624612195, 0.14109447328073366, 0.17472326635353028, 0.13593206722890178, 0.2007000055164099, 0.13425102517489465, 0.14678485180822112, 0.15375753894688624, 0.13419451852959974, 0.13413519268074345, 0.21692997655801236, 0.16287911803491656, 0.19588874352555122, 0.07697623117917007, 0.09745005352963364, 0.09155703708529474, 0.1886770522762691, 0.21414057381691473, 0.18932487154679914, 0.09845716803665124, 0.09197168983519079, 0.19033797686138462, 0.20814080302032734, 0.0952601375719232, 0.15026989302808239, 0.10418904554699698, 0.10769237328561083, 0.12349053120781338, 0.1821134407674113, 0.18092739876479874, 0.13944543838020296, 0.09391101077198984, 0.11115018007976395, 0.1474460776174261, 0.11823889123456133, 0.09039652113231922, 0.1357652132789935, 0.3679523058235646, 0.2024795664774795, 0.10828914811774608, 0.1330304019633801, 0.14685122566598077, 0.11121424035199227, 0.10563736541136619, 0.13309732740444521, 0.2498958737499291, 0.11730411841023354, 0.1465097649563705, 0.14617590383896906, 0.2050730958580971, 0.11583050998348383, 0.10640608101722696, 0.1145852493843244, 0.1596707724515469, 0.12595561828704613, 0.12198721389136008, 0.1182968381251539, 0.1785790021981924, 0.15721104798778412, 0.13067281234168238, 0.13949302776205924, 0.1406164650594996, 0.19675028600519706, 0.18383076474551233, 0.11178434000260408, 0.08182870103947579, 0.21253327538649883], [0.03783632798360721, 0.028793948980408813, 0.016287086726797205, 0.06421035651357905, 0.042024450226416515, 0.04297760150004779, 0.028619181342242707, 0.0779596888910859, 0.032630201293936664, 0.03451182048827891, 0.02131008775904775, 0.015411946186495405, 0.03534104937927858, 0.02449349335004245, 0.07638993642983899, 0.031881585919989214, 0.038908169259347265, 0.03299040051417486, 0.060261491190401785, 0.0035300472095954206, 0.023357478804105235, 0.0493790436866543, 0.04066138445670086, 0.02281613809417092, 0.02289553161620373, 0.06751105399622072, 0.03315900497499012, 0.018081618961127057, 0.051426022959452485, 0.010502836573117924, 0.04694635063529976, 0.0869120468175219, 0.03776530014170754, 0.025069901734710704, 0.052956877306344054, 0.09033655176960653, 0.02685126683284198, 0.032457203318875645, 0.04923321501982789, 0.027476406070373716, 0.03421723286831572, 0.11062794560266119, 0.0532400195727185, 0.04526969443465914, 0.009509808507808035, 0.06395935163562817, 0.019754423654728362, 0.013669588370248677, 0.0304449699638832, 0.033037189334150285, 0.07553423154017619, 0.05107594759113366, 0.08850351021054292, 0.0656122591106161, 0.009814518064470782, 0.059529555465785734, 0.034338753565304705, 0.031263596198010835, 0.038440817321139964, 0.051773064619591164, 0.07216859278419326, 0.027743914397433404, 0.043061518771273476, 0.017194565753602696, 0.03696516343963243, 0.010144411804034345, 0.052354513862801176, 0.007693157878689349, 0.03340374708416001, 0.10203787831649666, 0.05812967151042916, 0.04255522275343538, 0.046434079131652276, 0.03990858049702741, 0.07297156784202784, 0.06648300996711178, 0.07057470855333152, 0.016752058046779806, 0.09076238940319709, 0.02498994705327336, 0.09664245896161565, 0.06685185065913586, 0.01758413486963799, 0.08186617806073158, 0.03438073518355528, 0.05895512741840175, 0.03543262752974707, 0.06024112857337441, 0.04639536870883838, 0.09261878132219277, 0.06853653929166256, 0.057223496748314756, 0.04438529189135279, 0.057550612461542895, 0.055351357892035484, 0.04859542767066629, 0.02092993194838205, 0.04066292429342866, 0.06874725943611515, 0.02227741740493765, 0.09630284452390286, 0.062215513354467775, 0.03061531727472621, 0.02355290208792975, 0.04539506472346764, 0.10438124168544047, 0.055457767504718036, 0.044881035048033924, 0.11753101067076768, 0.03103543223152238, 0.04480607334464308, 0.055860496096072666, 0.06659416932492487, 0.03480954523829203, 0.04129321164181156, 0.03278492807200359, 0.022997222127272718, 0.02515325784653185, 0.012926026303771765, 0.03286224932620122, 0.0028264002391933316, 0.04273381700078326, 0.02766786484919008, 0.07599743894271313, 0.053189243265097184, 0.0671944298571156, 0.038795450912608255, 0.06738579862060086, 0.019439048238939816, 0.03825646975348073, 0.037662134911384315, 0.05652457558279557, 0.020346552163602847, 0.03292942374584175, 0.010854446032505122, 0.016416369809678966, 0.018326797740413778, 0.023564175071735537, 0.04838783699538439, 0.03103464316096037, 0.02165582706971515, 0.05594168609428791, 0.033482236622442166, 0.007793488104887788, 0.02269229232033174, 0.04687081053552609, 0.06359880767582406, 0.010684088187953158, 0.04097995062869403, 0.04166207531647336, 0.06988152921680482, 0.046384256603496696, 0.02363194129429758, 0.03754484301973735, 0.014758838994068005, 0.0300263163198026, 0.12801166037998854, 0.05247488159746413, 0.0246265858051277, 0.05427571682019099, 0.05746826950100161, 0.08793214651485605, 0.07188318672800256, 0.041715594218863596, 0.030324458587734453, 0.08853783094955069, 0.003817611479110295, 0.010134033227880156, 0.034306141202368086, 0.07416258941614821, 0.07336734418546961, 0.04639746395931129, 0.05593809314192303, 0.03162652460647927, 0.038404133200885794, 0.038439894185191205, 0.019805021846907276, 0.03924998619984235, 0.044224539831761396, 0.031333691327862685, 0.11078871681445068, 0.05844908037913903, 0.0819031034986819, 0.03990693723842983, 0.029377797994041638, 0.009029723230689284, 0.031327851822659854, 0.03222399466340581, 0.006876795434377968, 0.05645768844612664, 0.03916499257508305, 0.04667628165935317, 0.0046350699079583495, 0.023088662381914836, 0.08431301692560797, 0.020892307455200824, 0.00595384621955154, 0.03441185750547917, 0.021730710249093753, 0.08334110415871106, 0.013657923723991602, 0.014589641772721325, 0.05442307000198672, 0.033512363030064496, 0.012147955806745638, 0.02990977136388181, 0.023597400305011583, 0.07292336558983212, 0.06491110479879765, 0.01673857106887285, 0.04703481463835605, 0.06102670194400896, 0.02417443688177774, 0.0284656573222169, 0.025955591305729844, 0.06728111270574794, 0.04948768261519652, 0.05270470031386903, 0.026221084821548675, 0.009150007653290467, 0.02243969397949836, 0.04812567787725599, 0.02490322206980519, 0.004693952383428452, 0.03683302476401291, 0.057910018780779456, 0.03654402958589696, 0.03825104585097682, 0.0496739185895891, 0.015694549318493133, 0.047078060301681685, 0.032126105863661054, 0.02495071760589077, 0.04096214674533375, 0.027491206889070814, 0.010200134166816791, 0.027787788252856944, 0.01935692169823714, 0.01365836039410844, 0.026097955339918696, 0.034967049085084474, 0.049776087905610764, 0.06514263955215294, 0.014407627900401431, 0.01740806679722042, 0.045598131649556665, 0.049810822332097646, 0.06718846203218545, 0.041033209061190005, 0.0027233018021609995, 0.05738098144290909, 0.07945954349012145, 0.011961467980947948, 0.04446350946842183, 0.052820931173740863, 0.042393390509870746, 0.051430906769969774, 0.07002029072252974, 0.009735911697780174, 0.06400577273339995, 0.028462908981788545, 0.10228200755532711, 0.04329274325901943, 0.04572682675995654, 0.08608618105250983, 0.04985136753549019, 0.06680466730387942, 0.046656493608269005, 0.016907719452114358, 0.08218705398781646, 0.0240606383510655, 0.03580284718003485, 0.05063888293901279, 0.09496133263793685, 0.03071078523663023, 0.08971464925355489, 0.011746730662942415, 0.04063798813149333, 0.01766279869292292, 0.036714560757841797, 0.01849959461739467, 0.03990884096692166, 0.038596114834710475, 0.06032240284126132, 0.012791774183091138, 0.05291792556583401, 0.06974174115326136, 0.13370463594553933, 0.09670382260435051, 0.06261072279284559, 0.03002314663101589, 0.05061453666477915, 0.036465084225299864, 0.03557828382679051, 0.027012947774041566, 0.026839547602820302, 0.07489422636647379, 0.01638500042439949, 0.01977272549523942, 0.02343583236178083, 0.018326046974247983, 0.016013799223958725, 0.02926297290551086, 0.04201329215579937, 0.038276591052811955, 0.023723077028989795, 0.00984144030934981, 0.10722971746637937, 0.029172164673406272, 0.024246391690065785, 0.07362800560170606, 0.07100357223422298, 0.0215328642122087, 0.007983979697699749, 0.055627593875772534, 0.026640992934605288, 0.03003434683646887, 0.03840530531540994, 0.058138730500133774, 0.05677598265690669, 0.05638953343394303, 0.04875959265196035, 0.045046969692433075, 0.04648104415185029, 0.03283156367439417, 0.033019082846059915, 0.05276395721481212, 0.07013555631161698, 0.021002897992730144, 0.03251452201737031, 0.08948234075139608, 0.0586352588969373, 0.024607288050315073, 0.05771336401061666, 0.045393042251347535, 0.025309478496051124, 0.01624555710042196, 0.10568591240312784, 0.025898730344769937, 0.009837587844700584, 0.0181280170762611, 0.0663665569417419, 0.039563086334495776, 0.0652768275129699, 0.050988808920186375, 0.051606436665620536, 0.11451872230897989, 0.07535132038737498, 0.005251245916775999, 0.058902761478337555, 0.04150944761931897, 0.03507520154779477, 0.14742963737057102, 0.09199111016407129, 0.12111281645634484, 0.1931114756171742, 0.32177203545166605, 0.13389684740574131, 0.23015070826776568, 0.12401731624718636, 0.21952188183223048, 0.15294258993479515, 0.08182068775978782, 0.10172274038796464, 0.12630650187812506, 0.06796235639241434, 0.20346637965450365, 0.1517102149345221, 0.19860044962936835, 0.21303792814573935, 0.1621393988569898, 0.11284102039832263, 0.1052565660868441, 0.21035519548721854, 0.14440169017161095, 0.11195699323809917, 0.139178134981663, 0.14955222186061645, 0.20191192596910462, 0.1850759947011548, 0.18182108629374735, 0.11224078284876962, 0.07670168824974569, 0.26277915905079535, 0.13084948753877995, 0.11005727904698542, 0.1606855478378073, 0.15395940311493414, 0.23174760322416985, 0.10471942353873484, 0.12726632577757682, 0.14512714479238759, 0.15169451013207436, 0.1668277803447939, 0.1073599064482316, 0.11412797916320064, 0.10104486748816506, 0.2156194912329797, 0.1034847732573267, 0.11590098241163839, 0.13621155142543778, 0.2589385764252755, 0.09217294113289926, 0.09562137101085917, 0.21938700439228168, 0.1383752441935001, 0.1392410767655219, 0.17858277135077985, 0.1846851059986699, 0.1279026613901219, 0.177867122655434, 0.18642617870242367, 0.1552662725049642, 0.08374999592741651, 0.13526481996861198, 0.11350436827107785, 0.07426882282860818, 0.16363146234183543, 0.23333668408374633, 0.0688965852943159, 0.09814196116020603, 0.16706980284183257, 0.17709522778468748, 0.13883230757088433, 0.11271176604373802, 0.17483335318824939, 0.12118355701527289, 0.3027059456273433, 0.21884890423426706, 0.1604384385169514, 0.13424998329531762, 0.12436883569124246, 0.19593098561369604, 0.13300023342092193, 0.09851558990175686, 0.2226947115794305, 0.12393779632064605, 0.14829752305822988, 0.1301507693865607, 0.1621211812861504, 0.19268389130311628, 0.1525941425033154, 0.1975512156082738, 0.10720515668752695, 0.16568422557846194, 0.13227104029107478, 0.15870799911358666, 0.14546405493972764, 0.10762729411644321, 0.1353208822829108, 0.1374764238754588, 0.17630369041956243, 0.17431316416590445, 0.11486752214090479, 0.1502561494107208, 0.1618999657371352, 0.07229498963082029, 0.2139015850280562, 0.1552443470685713, 0.09780577879639403, 0.21887685112174482, 0.16899410845531573, 0.09369169512102682, 0.208995052342934, 0.19436375358172003, 0.17237877683533778, 0.18239217419778148, 0.12486539856200257, 0.07649333531697912, 0.1431643049563131, 0.0963871448390907, 0.09124690171090827, 0.11542230769391022, 0.08054039395985105, 0.15348858079842984, 0.1563040458507115, 0.14346694032992088, 0.1295831595217028, 0.31133632446008347, 0.10841532279887509, 0.14918031681689525, 0.11655259381739363, 0.14974377448520354, 0.26595701433477864, 0.09618524236664658, 0.19321649094983456, 0.15583262598562628, 0.1686815292604508, 0.1461080284488778, 0.06918969819502485, 0.19424174641889913, 0.1293606263014578, 0.13163648966339328, 0.17101673379300103, 0.15378481167699062, 0.1339338034872086, 0.11702700142538357, 0.30039429063758544, 0.1605877030881182, 0.09761585027820642, 0.16437291287847106, 0.12261488504948155, 0.20791135968700533, 0.2153562787439554, 0.11397074727762131, 0.11129628836868272, 0.10782062406501464, 0.19610303363973097, 0.13990392668112633, 0.17537692321404336, 0.12779105770131274, 0.12297905260516752, 0.1293755650159813, 0.17492278629252989, 0.11237524660123933, 0.1308630472950397, 0.15295074111030948, 0.2501144692782433, 0.06714375314092444, 0.11749699636692963, 0.1268208073452115, 0.13573904371550008, 0.25493477110660845, 0.17634058521399576, 0.15888704918324947, 0.12286436924290274, 0.15231332531379116, 0.10895606596022846], [0.01091826881747693, 0.017512249009263132, 0.06179898751959686, 0.05042851136456575, 0.027671785304142583, 0.010843234335733278, 0.06439202660394293, 0.03638625760833102, 0.021438995458846612, 0.019824681578264124, 0.048148032322886496, 0.03911031304948753, 0.02213257699153356, 0.00621165635229479, 0.010796867821726107, 0.03709637514886357, 0.0719751479224332, 0.11418022635963657, 0.02865286622827332, 0.05589493557870869, 0.03218857841866632, 0.061038331158699534, 0.035676507790002136, 0.05804722129757847, 0.030838082236568296, 0.060470989424615144, 0.006368195885912546, 0.05131967080336425, 0.07274223176101524, 0.03876646214555349, 0.015875614199396825, 0.043114168163869655, 0.03170730283243522, 0.03849232907316858, 0.03443003677192234, 0.08351892848769504, 0.018097457828961553, 0.06561884746676491, 0.06196180801658381, 0.024535827368738192, 0.04982927355975394, 0.015044656822517996, 0.048509012952807455, 0.04459164533463698, 0.05169141496862135, 0.04764469340443612, 0.07756810304858992, 0.04368165545465966, 0.029932024302862348, 0.030962173158543247, 0.016682748157050342, 0.029250636974710132, 0.09686075571563937, 0.05420537462698356, 0.05060135995248153, 0.0481629595460911, 0.0289845171820132, 0.039156611573191426, 0.056811356766810345, 0.051528111836242105, 0.05979692398179924, 0.038360795607009245, 0.038763217763194156, 0.029682664598728863, 0.04722497298292095, 0.046701505104260105, 0.034722295484595725, 0.03590686276795403, 0.05701879422450739, 0.02975829279861383, 0.04442219051622576, 0.06226556187856102, 0.03650788172718979, 0.096410786312434, 0.024671637520734823, 0.010569070619831403, 0.034845018939625834, 0.04425912870154266, 0.012639781381303986, 0.04260244058264841, 0.013742149345606807, 0.032033631390321164, 0.013861472327863018, 0.04449038766324521, 0.03240987823735322, 0.016570146638719786, 0.0791345919752794, 0.022167020304609212, 0.02813738864666272, 0.009556198004452933, 0.03756120665779999, 0.03268450926688891, 0.028586693468593785, 0.027520896626576304, 0.027572138332611615, 0.06008188187655422, 0.13153954889745484, 0.07944912469435124, 0.014967014769002076, 0.05471421022629065, 0.021257417299033656, 0.018817737525809678, 0.0283828106588654, 0.024507564469991673, 0.046421545933211045, 0.014022911951366453, 0.032090678127602704, 0.031757916346372615, 0.11566004009857295, 0.029507739912538283, 0.03957027606966515, 0.10402638975891376, 0.02200040001151783, 0.029318265301445802, 0.05094041514600958, 0.016549762954274495, 0.039497283212239706, 0.027819084859783613, 0.06681088793782458, 0.0740630975774219, 0.05104292154071793, 0.00996016382780527, 0.0388519422361447, 0.0344970541435384, 0.04247571048777431, 0.038929121764076334, 0.024038994451984767, 0.04849974711936328, 0.03945878346360499, 0.029034962156607263, 0.05515005679861192, 0.0075954778379039665, 0.007062103005967314, 0.09093655183190301, 0.024098682277385267, 0.06209539076794059, 0.05920170047771066, 0.06975333206355572, 0.016528875567018986, 0.06642839555898983, 0.06757853868147058, 0.04207996095740988, 0.013559067738242449, 0.029092635170766906, 0.017133983520550594, 0.05478974649562471, 0.09079323976390785, 0.01328164048778314, 0.06879491776588463, 0.03235023446200836, 0.1036104806248219, 0.026477695547885476, 0.011338310995920291, 0.0026987151678411233, 0.005781676577058651, 0.02376464112932163, 0.04575700296329395, 0.00196700448155283, 0.03916606892861667, 0.021892580797054598, 0.05976897709432149, 0.017503515606926336, 0.02746041015451474, 0.04751492194050262, 0.02168082643390423, 0.008693700787731478, 0.01263454708556134, 0.047393669374287135, 0.06049223304275544, 0.03978544718495781, 0.046882512528569474, 0.07637588637730769, 0.011472671326520223, 0.04426728753793625, 0.013968841465670737, 0.03585916230334871, 0.02088756920138915, 0.06871390396789198, 0.11175183489197686, 0.04801617709979896, 0.03524944824617236, 0.048032605855335156, 0.01984158339309356, 0.004234315908228558, 0.045043955136451035, 0.025740830047476678, 0.008527902123938886, 0.09235649579955686, 0.05379391263329214, 0.02069025368039166, 0.05288654277401586, 0.037857878036917224, 0.009213142874350232, 0.019265818522281705, 0.0065445378347630465, 0.0790781083126222, 0.005787386326119305, 0.07720077921065592, 0.03505812161752293, 0.012359574189289443, 0.023399738129228357, 0.0495351609143038, 0.02917196549054596, 0.11052576479532066, 0.027862774854105328, 0.008137024912772881, 0.02978893440036524, 0.03146040227053867, 0.072869976922389, 0.01676252280782548, 0.0193452809922277, 0.05504704861631317, 0.020884252040677016, 0.018090105300108274, 0.017883384134620428, 0.019495135451096202, 0.036322679971494985, 0.04481206032177133, 0.03253272809689084, 0.018262025006415866, 0.054445439769375714, 0.06492155423808484, 0.10652307796502307, 0.02904782094241631, 0.010024652151661295, 0.02885277878733412, 0.019370981326867497, 0.016637889878644098, 0.0747393616925805, 0.04196270353971951, 0.03587241945487838, 0.018505441783476743, 0.06273492862800918, 0.01108940615649185, 0.07329808217623542, 0.045886437348540754, 0.10647507489568765, 0.04198162591144924, 0.03356223918437477, 0.027098288053586602, 0.033795179709071116, 0.0401038563089265, 0.016804443139042106, 0.013481309813927981, 0.04412725432625702, 0.013716387723933065, 0.05173548417646558, 0.01003656194605414, 0.06092438324084205, 0.0721801453900914, 0.024882317445571386, 0.07848815932389229, 0.04585845215666679, 0.07511715029156016, 0.048098508569021384, 0.021524896897796183, 0.10488935716209874, 0.028631875419148037, 0.06259605220909562, 0.05604192869918001, 0.05633976453194215, 0.01629605570117072, 0.05942015044931924, 0.026252530815620578, 0.015431400989332508, 0.028158634180022825, 0.01051204399235787, 0.03252641553239476, 0.05212664484016357, 0.07563199968107286, 0.07325901169209711, 0.02569834281119608, 0.03448845863702797, 0.03115804843424309, 0.028436168682791536, 0.03222471861649425, 0.05301138063171699, 0.02429666237965707, 0.022048738244320118, 0.027201018529012803, 0.014037236837940592, 0.014698637889758235, 0.034124559212115504, 0.03768466172679778, 0.037715006469478535, 0.05325508852218909, 0.026360200642938578, 0.0709792566035063, 0.032701638992875814, 0.004767392923484647, 0.026213789749289715, 0.042957962836108865, 0.08493684232234956, 0.06977841378219667, 0.11426339286469644, 0.04910902067598316, 0.019294579378179005, 0.0650102672197165, 0.04626693023789314, 0.05758801287400627, 0.056130262467289166, 0.030614060890530388, 0.008321159891033126, 0.02101643668157199, 0.019444226993307955, 0.011021300940023316, 0.008918166464765467, 0.04893051069830695, 0.03880680816608571, 0.057597730699325764, 0.03880891873831711, 0.03697249490106779, 0.056596741065262794, 0.012675958925918227, 0.047903845627461715, 0.05019572405745426, 0.047873202110490495, 0.025273995218618263, 0.04339806119640989, 0.008598234741047265, 0.028149330042182442, 0.057395441352479884, 0.10750592280659946, 0.02394755419734265, 0.05282508337029046, 0.03877260234026659, 0.03106010409312383, 0.018306597917070313, 0.0599239873249204, 0.04009243393797548, 0.018377943685458555, 0.03393643100054995, 0.03752073423276025, 0.01916894287381682, 0.029666450347811468, 0.02857870891720297, 0.05006103430904689, 0.048037305804750616, 0.08763412299055247, 0.09127296402209228, 0.018670154517636667, 0.050560512144358895, 0.03393974433082246, 0.08785710820267278, 0.015213047736324372, 0.013382221128971828, 0.03506826845208003, 0.027177091687917713, 0.016258486749364004, 0.023345376530121413, 0.019489004832482146, 0.02569871436383936, 0.18517397734667027, 0.3094295929035833, 0.3300380935111354, 0.12266796728175496, 0.06376604083925486, 0.2265536649933746, 0.11787061744760122, 0.09688525520745786, 0.11598407230790585, 0.19710277838091697, 0.13340982999051773, 0.22693980395072894, 0.10180026848590183, 0.0637633097358048, 0.14347879937098873, 0.12392854963939999, 0.1676662482561604, 0.1934750762677962, 0.15739861695516497, 0.1370658620350784, 0.12134465764486983, 0.18500237365163144, 0.1365912399224697, 0.2570896078982661, 0.1507982025824247, 0.16347749399081354, 0.17810500827768158, 0.16743979266574308, 0.11377204705270068, 0.11265876042025705, 0.17531114690486463, 0.19816721158642925, 0.14633362602081992, 0.08302941362583831, 0.1629946900591735, 0.15790933713076577, 0.11166653866248746, 0.18142578492481864, 0.10973104816530982, 0.1036797273122976, 0.08546469988481653, 0.09242208058675451, 0.21862992566199074, 0.1278166450379837, 0.1433734469596417, 0.18200318539334884, 0.1748220610522455, 0.10156101922714904, 0.08817419199453247, 0.13630109178202768, 0.08857963636757867, 0.18018067754324407, 0.14874154761914285, 0.09002246338153079, 0.11282964399264706, 0.10934988111858407, 0.12174096258897936, 0.14468754821967694, 0.1914191107836462, 0.14765402452359278, 0.21221053786575797, 0.10668948758393527, 0.1602643526970379, 0.10499801907327869, 0.1252224338391135, 0.1061352689359938, 0.12767476555440696, 0.17846510024561038, 0.10859048880276181, 0.09609807688262194, 0.16002738638029945, 0.1358549528184437, 0.2428314092779352, 0.24244664927884457, 0.11800000969801219, 0.14829243623441266, 0.20314214060143118, 0.18223837438610294, 0.12254393764681394, 0.12547601660292956, 0.3555751748142704, 0.13826016246551467, 0.2563374934177245, 0.19474384044447254, 0.09624131234182466, 0.08543894400880223, 0.23414555035771864, 0.1460455463177735, 0.058456886815087455, 0.08056644094927658, 0.10116406310830386, 0.15005192569186612, 0.18147196470489427, 0.12911674987164237, 0.14230429465251584, 0.1636138269978185, 0.11326613790926435, 0.14344224165524208, 0.08570648489459869, 0.12539763814739643, 0.07130743334850959, 0.17702638712381163, 0.1554637699718437, 0.12149204530062215, 0.29923418837208904, 0.1349687882729115, 0.07445664460500402, 0.12403966303193763, 0.22208565635786903, 0.1814526592892024, 0.0865333389130331, 0.29562959147076456, 0.12520154262141836, 0.12014534699940875, 0.08902045102008889, 0.11794598517759193, 0.38879385037768277, 0.12366103939712049, 0.15941355077009048, 0.07690796508423745, 0.10304955870754297, 0.11243454946745789, 0.11802984116178368, 0.10391845563126188, 0.13848997352104034, 0.0795644668922309, 0.07150343694393674, 0.1531255623746303, 0.22222995667928652, 0.1254629931082168, 0.16012218210004991, 0.11839009400817657, 0.14220623539820795, 0.24609255364104626, 0.1215883961788589, 0.14977614936088363, 0.10263765621329508, 0.14457416720688343, 0.1448506176952393, 0.12328753322963754, 0.12412081472575666, 0.08227030476254803, 0.1677616262027333, 0.10019701499972614, 0.08517399250018982, 0.16044263667877645, 0.12963189803544553, 0.09697451211151578, 0.15587715101578545, 0.1373795137530373, 0.2615374530996046, 0.11096390580097515, 0.14968366722666449, 0.09158041042786452, 0.13935027493824884, 0.08564014934123525, 0.139751490505953, 0.07626413713179289, 0.12249193559851378, 0.24932463262831014, 0.13675784872424218, 0.11200080580648877, 0.22700735758389198, 0.28726277752749385, 0.11582468005438006, 0.11056061413499618, 0.12224078133341768, 0.11867731569274781, 0.12670020212329206, 0.10429019979651898, 0.12190246924517617, 0.07842621345433497, 0.12597467855460223, 0.14637733899777935, 0.10679223529633977, 0.15987937819332848], [0.04457256591488277, 0.07278683339996685, 0.03630889804973718, 0.00695221487530357, 0.03641370653865799, 0.030169095956690373, 0.033176900788901315, 0.05204773778396268, 0.03053507914075688, 0.047263679575295224, 0.011621136293416063, 0.05642495733956176, 0.07168939712667657, 0.04091014852747321, 0.05708557793930654, 0.012264379146208447, 0.1013633378991677, 0.04380126093183795, 0.023674717728769588, 0.09672518113567945, 0.0295961560350993, 0.02941522713480217, 0.010305002027551734, 0.011218664341516072, 0.04873335797099337, 0.03954667290071807, 0.02349961109669699, 0.04699572117158002, 0.051322279332746426, 0.05388716085543556, 0.03333366919128645, 0.03633942665351975, 0.031074437598187118, 0.04577695572328183, 0.04697311774737412, 0.015291218390508045, 0.04583351599473146, 0.026394465840571833, 0.020384517565910375, 0.02817939324755102, 0.02134669335528968, 0.010279947121988141, 0.0087459470265575, 0.08663995536945521, 0.009969517761360734, 0.010072704059101883, 0.012697252339773603, 0.09290218022802184, 0.022145610062345382, 0.029520937692253824, 0.07710258206052166, 0.06659331896732892, 0.00588552697726916, 0.01759607051949828, 0.023948088543669834, 0.0380598992529896, 0.024534766336963065, 0.023556690392715317, 0.03401028187645059, 0.01938522290137987, 0.04832546977746872, 0.06044752415149443, 0.04479883764419825, 0.03186643844650638, 0.028879262446876497, 0.039067756865293755, 0.06468079578612121, 0.03660298005167035, 0.007175512268253032, 0.05417534014991215, 0.025749036764365532, 0.10814037384285081, 0.03734544565480563, 0.0290467637410808, 0.04797346769802032, 0.030107048580483086, 0.05392932633478796, 0.029681925323881933, 0.0564776910018296, 0.02041329565878597, 0.028613843624630285, 0.0135566430699621, 0.051020620721242124, 0.02776259353624717, 0.07972239591782132, 0.05486272020085205, 0.05106776577210234, 0.04928018387046553, 0.010620021212455488, 0.050908821680012255, 0.05804078998945414, 0.09968881525339619, 0.05360352446234996, 0.009789115546511547, 0.06521308899766977, 0.042372920640533975, 0.03783127563374658, 0.029476470118688963, 0.004923864466799123, 0.03219737310803706, 0.03476385958492756, 0.0062004322065941754, 0.05482825007469905, 0.09675379451965133, 0.021244451260915207, 0.03312443525740697, 0.026795543512449633, 0.06685800234516782, 0.08077221216573831, 0.03748028862079786, 0.047331240869337515, 0.060872430988256974, 0.008173040621313117, 0.023267746925534263, 0.056742466310219425, 0.014603548183766826, 0.019756356111517357, 0.02141621391919832, 0.008905236815823423, 0.02127403757655092, 0.08217367809265852, 0.05816568530374958, 0.059914537630374395, 0.01612764084711671, 0.05433520737795099, 0.028847019721363342, 0.026966199173682162, 0.054817773822334506, 0.004616875798561641, 0.05655870863026189, 0.05536921540155046, 0.05191358046666269, 0.052463788644320546, 0.029547746939164017, 0.1345979557522843, 0.05401438507702082, 0.03590131629138224, 0.049631626705729195, 0.06210119771440664, 0.02384521059631821, 0.031896049659999634, 0.04930242340290739, 0.021883946986147956, 0.029895208032441237, 0.08529816769183644, 0.025032215954495535, 0.05044896591214403, 0.06765543092643062, 0.0482036579670685, 0.030934978952451102, 0.048634279819746176, 0.016382642788812518, 0.13686943709129287, 0.024450948657167536, 0.01945008948114851, 0.022642504266132752, 0.03469717163111895, 0.07140081946647937, 0.1323946562385367, 0.018742509606865146, 0.02816651147910424, 0.03546181164922253, 0.0779093798970984, 0.14883747714902126, 0.0636166613548994, 0.0020441208072307132, 0.05106411536314315, 0.028667190157237555, 0.05675033403320178, 0.03279202204618243, 0.01757050425024523, 0.051095218532868934, 0.02029177113135736, 0.01780464370254307, 0.03983466067321358, 0.018614260742681164, 0.012424580580104264, 0.020987388542703083, 0.06189841807128922, 0.015385783326271323, 0.04326886812885923, 0.019579728794915062, 0.025183181240854245, 0.0568941057539515, 0.037992223045758666, 0.050834951651913506, 0.03335402031699496, 0.03685057583835818, 0.02636444093959947, 0.045652543044378685, 0.09392706797488275, 0.09343910061063306, 0.0474514362342175, 0.015904795446042574, 0.011546585404674613, 0.04324901112986188, 0.015556990570809334, 0.0069187483243313775, 0.050110063936200835, 0.01085734854812824, 0.08915979475263627, 0.05508365229733529, 0.07273797997303548, 0.021076867612259045, 0.019151949128436468, 0.05374174204564864, 0.03788904249367695, 0.07226881240644763, 0.002646711204321154, 0.04321586250537827, 0.010049161219578839, 0.012720863169599927, 0.017039645538334886, 0.025838140450838595, 0.02141287952150789, 0.007900869691624277, 0.06855176145871801, 0.008377456819758782, 0.019930817314513752, 0.028639791022625663, 0.022873016292109125, 0.02837553665402436, 0.05208208916648742, 0.05650280336398752, 0.04122398793697357, 0.01378598393902423, 0.01723412461879273, 0.08319081302972571, 0.024943476159786506, 0.04172467619120594, 0.04078411940304984, 0.03079887194138381, 0.029949010387363455, 0.022521592609043566, 0.03620875120583562, 0.0175821679388924, 0.0384702121147946, 0.05429680722074644, 0.016144341563866023, 0.06386118895945049, 0.041045363046108715, 0.017000622934691848, 0.017349332751285647, 0.051031763470100786, 0.07193034710062128, 0.03348880199595325, 0.052841178877579595, 0.012798276354348468, 0.07975149193718549, 0.006708672651345091, 0.0482599807512616, 0.05046891867213192, 0.06259276186146083, 0.06851522672560907, 0.04598212173028339, 0.009822751594436987, 0.022267136504993807, 0.019588456451592427, 0.030881201495386423, 0.05018324065472811, 0.04561555631939442, 0.07214960146455035, 0.06659865860016116, 0.017245481872270187, 0.032134998229242144, 0.05802410842490293, 0.025814851377940467, 0.023893349646260182, 0.054407614178114364, 0.01706633987205644, 0.021970725595770825, 0.050266809355948246, 0.019509572378029267, 0.004837737510716844, 0.008057433165489666, 0.019053610252036203, 0.050786385507953745, 0.019170840856649222, 0.0573800161721245, 0.10562239605332575, 0.06098886103098912, 0.05952946353523482, 0.022064814599411144, 0.03843648126348853, 0.024391540453859398, 0.01985300576404458, 0.02747456171369601, 0.0685608319397415, 0.031434048845943426, 0.0662509925783642, 0.06222238516314857, 0.018406288938656933, 0.047404509518415704, 0.07438539842804594, 0.024813340804088983, 0.028245510465856043, 0.08596367593253813, 0.04819211685248921, 0.040391146941410924, 0.03006371290182635, 0.06546072691919343, 0.015577476719514498, 0.0535940824286832, 0.03257925644697201, 0.015765876892293175, 0.027873605422134844, 0.08598770044984357, 0.08418784581965978, 0.03507222529620894, 0.03569328511554388, 0.05119503978940268, 0.10504556248985952, 0.06208174674200916, 0.05535066458246401, 0.029812826767503738, 0.023711878738756624, 0.03272858613561238, 0.023165995127431328, 0.05488818113301551, 0.06425422270812335, 0.05442582408807451, 0.0492657354522136, 0.0758982305565188, 0.0544447579511231, 0.0419744783111157, 0.023098401274652253, 0.039499485715022015, 0.04199133224544987, 0.09028404410327635, 0.05362214422934959, 0.05012984049596614, 0.05255044084943591, 0.044242194327976436, 0.03115078017506148, 0.04497612571163524, 0.02938995772461978, 0.029639999247005874, 0.040134668365241065, 0.026272048820711436, 0.11301154390938821, 0.07885066446878257, 0.02809005207382143, 0.034003030854247274, 0.025281094938456535, 0.07686887927834066, 0.010183320452098646, 0.05975358638792269, 0.12035464222032217, 0.017322906548337593, 0.03222209093491397, 0.07270422613909168, 0.02092321910294554, 0.18675850764397653, 0.17231608019961467, 0.14063419233406746, 0.11215105097019866, 0.1503015171375967, 0.12987960490488237, 0.14293362056055378, 0.10701231703522707, 0.13345386472440537, 0.15613647177815437, 0.12545239045134476, 0.13705715927625858, 0.10636787621244308, 0.13225279207671845, 0.19068273174906933, 0.1776795536880532, 0.2314889259756573, 0.2154515954034944, 0.09207091354314359, 0.1573632390148217, 0.12271254593806884, 0.17496893542908853, 0.08354761848045934, 0.09912274522526611, 0.1731108504557802, 0.11051259574390228, 0.13098174495802772, 0.17148308215602753, 0.14813423907804876, 0.17087257136740994, 0.16107992990122688, 0.1744534655083572, 0.12502289091747615, 0.10555227602561636, 0.13573490684070896, 0.09265779818017637, 0.11669885532389726, 0.12340145050397805, 0.09577340115943263, 0.08844603063358415, 0.13393738877869424, 0.11944489748848063, 0.08609314479174153, 0.22694366503386731, 0.07537205072660601, 0.1194239373228723, 0.12219722923492232, 0.2572582698156757, 0.06798861788645869, 0.09295911588255437, 0.1869006782409645, 0.18698375281547347, 0.14272538254097586, 0.14798590913414955, 0.09266126089759412, 0.12954531477824335, 0.14846336577207814, 0.14731469353841198, 0.19162345707656878, 0.21459255037048172, 0.13037918616206418, 0.1364000856636032, 0.09962568960843549, 0.21027238138260382, 0.1971865424345578, 0.1259285907050775, 0.18515951360665983, 0.1205656381564275, 0.1666321827759666, 0.1448796830710865, 0.1428307502740814, 0.14934891744727088, 0.10669452844247704, 0.09972476775968268, 0.1358973328024149, 0.12357156798844376, 0.19037520873450464, 0.11813607457424365, 0.17517921124254504, 0.0702037304759987, 0.0908853848194403, 0.14924741079730375, 0.10452885916757007, 0.12504418050089192, 0.16347740206026262, 0.11789671806318146, 0.20161678293539634, 0.1367792225773296, 0.10795036105499153, 0.14622986707235539, 0.21838254054948208, 0.15676297848263096, 0.11832961136655462, 0.08695794314506554, 0.20858861205558624, 0.13784964659040974, 0.10593433173433428, 0.11368909505225959, 0.1380198253619094, 0.07604007939657859, 0.12604626947112624, 0.09817948414673729, 0.10412624931984371, 0.1657774278353299, 0.10879165583079863, 0.14745599079516628, 0.11335797652962709, 0.1688826426623329, 0.14979174691102198, 0.11109233278060153, 0.0665411637014439, 0.20516501108725227, 0.102252597439914, 0.1402294374401531, 0.17114152951586634, 0.07108372801374044, 0.1443607351111789, 0.19589163933790502, 0.14424395266800158, 0.07849967362539423, 0.21229632439151888, 0.19742565379748422, 0.15754274873723909, 0.1071864641421745, 0.25725885204249815, 0.13045420149160972, 0.11131585425426883, 0.16649894476417573, 0.12037280616500687, 0.1416950096045771, 0.21841355178865696, 0.1913520168032377, 0.13350517729357367, 0.19115130176707623, 0.17395435922568844, 0.146357512642299, 0.1648441182389375, 0.1751677658889563, 0.12768363685257014, 0.10310821039902587, 0.12763620834917794, 0.11374846686639133, 0.14809411139257495, 0.13428459514773664, 0.10133211981625327, 0.12438378972752441, 0.1625117329099486, 0.1296175721912615, 0.17625311329480142, 0.16329691174530214, 0.09980660127175432, 0.11847227992069338, 0.2116457931697369, 0.0596156714093541, 0.15810332591495208, 0.1758874135632669, 0.10429311093063125, 0.1812121230027368, 0.29441806938379045, 0.10156583025931351, 0.15828766199129243, 0.0961708399136701, 0.23396407945021508, 0.2847278538730837, 0.24421292627530716, 0.14393374834570194, 0.10325823339723772, 0.11519952166465022, 0.17953314938612525, 0.11401747098012317, 0.15642236046973737, 0.2855862094269645, 0.10877274111994814, 0.11199827771633865, 0.11459628871131329, 0.11651034406836956], [0.07055126626284854, 0.012430070557691639, 0.052954146202893994, 0.008756316984222542, 0.02518793673164422, 0.08077578213546546, 0.08289364752389732, 0.028381479581096963, 0.033239233532860395, 0.07076151909366732, 0.019142903545270526, 0.04038354734920206, 0.02214745250380328, 0.016134051087823127, 0.019651698924961592, 0.02210457839312092, 0.04485808305382248, 0.04104039496591976, 0.024265723918835004, 0.03520644390054288, 0.0269124964101901, 0.024953686196597356, 0.041491842918819, 0.025914504095130873, 0.04610330917902532, 0.014039359859100754, 0.05053543425615757, 0.030524317520640554, 0.07361842184177331, 0.04440096988072319, 0.04504512342053556, 0.04515646280901087, 0.03802531421364796, 0.054766438270528475, 0.04370628901186489, 0.03492373064340603, 0.034482758942871325, 0.02418237355267329, 0.05805254560865222, 0.028328571633826342, 0.03225082306251411, 0.07056821978861286, 0.013422326789417816, 0.009346654762574022, 0.04385466109059992, 0.06603385261710613, 0.026590639890562144, 0.0478714132951873, 0.06064243990206911, 0.037396149184074134, 0.02669636385455247, 0.05006286908962554, 0.07162952735539406, 0.028916473252578612, 0.03509250364356464, 0.0694875531799851, 0.05807853514148344, 0.053309170499203674, 0.016633373790330464, 0.058264020349710226, 0.0225289547139959, 0.029967823591563972, 0.042121854475549156, 0.03849902468162679, 0.015988214760117473, 0.007260149183322586, 0.028443007932735548, 0.010287887623323309, 0.0620996502167996, 0.03130628644759136, 0.06530442966088172, 0.05674222499252327, 0.026414380296163505, 0.05702070178343885, 0.0600724819777233, 0.0037216453206530145, 0.05549992915363081, 0.04016401719362025, 0.019750999241706826, 0.008555101118080558, 0.04555429226808971, 0.035818337477863796, 0.051509867452325366, 0.040398210272072785, 0.03380747542025582, 0.027874271918628967, 0.009059997110237038, 0.050929031079454776, 0.033038123961417906, 0.10357683404318749, 0.029725504235454628, 0.062341653561640176, 0.08651840019850962, 0.0723524232425036, 0.07796029410054607, 0.09054077548846122, 0.07723518421933537, 0.042367014102637775, 0.08201530473607202, 0.04823968708214741, 0.04113701780536964, 0.04906913813864512, 0.006411874388915397, 0.023268197002189777, 0.035021050622867006, 0.04224086623458613, 0.06653915655108229, 0.007869324106122217, 0.03308024730593447, 0.03294149729152841, 0.08447820846472057, 0.029650879610750466, 0.04027143421192323, 0.04221098880553919, 0.07672316169426327, 0.02873837887760132, 0.043190439877611016, 0.025194482952957193, 0.0394596797864764, 0.003895535788145818, 0.05460789254415901, 0.0567065061430537, 0.06687384504344195, 0.01381359757825492, 0.04686115016680091, 0.010307904543174852, 0.027727696316076383, 0.03812126289572447, 0.018271675799041986, 0.00785361260040513, 0.04894251529608042, 0.05342236765089536, 0.01654624661070205, 0.03902050456212413, 0.02826975906387933, 0.018697486619555184, 0.021762393730422182, 0.04154268434391387, 0.09308981814331586, 0.08358877272375169, 0.043551849516769575, 0.053089770578568986, 0.04154347341447588, 0.058501362049531554, 0.02612036532692371, 0.09936731879509265, 0.0657777724066569, 0.02254585269838572, 0.06667287719826545, 0.042903651032717004, 0.026024341951274586, 0.019491509939994545, 0.030291451689516826, 0.0800852764457945, 0.049121695600690386, 0.04102942075640444, 0.026567821961737452, 0.07116543129086494, 0.04740226488079756, 0.08283582320737262, 0.042745982477020834, 0.11539197061210872, 0.06442044080505449, 0.050906806868771394, 0.008120332814512715, 0.03337717532450634, 0.05504055219071527, 0.03237658405616399, 0.016040605598039204, 0.030072714434936646, 0.03280550136321014, 0.03999329066925472, 0.020524175394506707, 0.01936238582035707, 0.0356275700933991, 0.04992779629725603, 0.11706505301258258, 0.035005809303613446, 0.012480311561375858, 0.04319871745763287, 0.04763399881701316, 0.009008167431719841, 0.05571101318984743, 0.04790115665884749, 0.054658714817055774, 0.028729792947189945, 0.03254247273528769, 0.04585452978649447, 0.02757871902788118, 0.04060093628903551, 0.02393149507922992, 0.015046150693970342, 0.094898613019576, 0.03187812320257147, 0.004804760777211238, 0.024602122702485612, 0.04355309824008615, 0.03948740450845611, 0.015080488669956404, 0.01857931564201511, 0.038866156997579726, 0.032611244448250344, 0.05542363828769135, 0.0520184962078929, 0.05628590088998599, 0.07820660668996074, 0.07579297007572267, 0.028225747312629418, 0.0404367636468622, 0.02376649506209839, 0.04694000742728672, 0.03223173215144104, 0.016751914405294003, 0.10926121410222785, 0.0374176915765049, 0.06062521058465205, 0.0285707320266914, 0.05757598146315544, 0.08252327465602467, 0.0527203553206017, 0.015257872498383927, 0.023398336188326922, 0.05253951260519605, 0.025985219756201394, 0.026050147623003974, 0.039486431576792276, 0.06629136541197378, 0.05123282707626781, 0.09900808484563905, 0.028009716263641755, 0.017485554675541578, 0.03587791996617471, 0.03565717939167254, 0.053937492832060785, 0.0015269377223786809, 0.06624931484581002, 0.01922174548399785, 0.02289818228042174, 0.016076498732511556, 0.032442417821937033, 0.06411066932243205, 0.06855101835343146, 0.011573741306370545, 0.06846347748632393, 0.061593013289835186, 0.016988587693401405, 0.006998002035318003, 0.0424298562950665, 0.01187279809176201, 0.03567545058866663, 0.06158017748666387, 0.04330735255573546, 0.04538106063621179, 0.026047265217188868, 0.026728256094840266, 0.018875448844365535, 0.09067028265206084, 0.08564992462314906, 0.05457737926213492, 0.06956557923507306, 0.02743398012112706, 0.09118422805782288, 0.05722196840290582, 0.08032013602074116, 0.044773219664010315, 0.05659277656025464, 0.06506374015683128, 0.044814642038076155, 0.05860408677929833, 0.06535427900211466, 0.09609263765835956, 0.019436112206970012, 0.05955960143417601, 0.036996837344861803, 0.10517988834650287, 0.09577058961675053, 0.0444774829121607, 0.08585682964973873, 0.050395918153827234, 0.04262872888977009, 0.005080471511915206, 0.022356265089324406, 0.024386457460481795, 0.06979441735893488, 0.02730276075101668, 0.038490318092367345, 0.04940038306578513, 0.03724243364206726, 0.031004957253894502, 0.034064934588968754, 0.053990092428941885, 0.025104400589160865, 0.026199523276919802, 0.06759988189104103, 0.011098947781588764, 0.022989469317479, 0.046407227749906244, 0.026672348913346088, 0.038033166614871834, 0.03400106583872149, 0.03127888731297947, 0.03776387521816838, 0.03837238651730361, 0.03044102844151278, 0.013799167354591193, 0.03992660654588573, 0.029069256082537676, 0.037606582045555115, 0.08689697786805131, 0.035957244540294336, 0.06310622463183058, 0.035867064500287656, 0.029692899533397252, 0.04030671639127597, 0.069616753908415, 0.04733187672231467, 0.04091990465718893, 0.06126168792346313, 0.02431632594145354, 0.09296856174666075, 0.0564261103018878, 0.073220799226434, 0.02127739687209889, 0.03702392238342474, 0.10564975305310181, 0.0269599421505606, 0.021557631834800688, 0.06187872578119559, 0.03902506661571322, 0.07424076868882103, 0.1489647549967612, 0.08127611415881304, 0.027587247501698234, 0.00898583118067754, 0.026729238602603157, 0.05474730139417995, 0.026857449162390926, 0.08249818527650449, 0.028009423235010718, 0.03252060092504948, 0.05090653107711866, 0.012976510540371942, 0.07039279331483188, 0.024630538818816987, 0.03050355653789255, 0.06297259208475871, 0.04797029226357418, 0.014290753526673203, 0.03507014153705489, 0.016602596207972498, 0.03132246430933235, 0.028737886666109966, 0.17833296540043048, 0.1639815798449901, 0.1261251382229309, 0.0945079847869854, 0.09617620252914007, 0.240187410024866, 0.20877601248362374, 0.10817012869782987, 0.2448178446220775, 0.1479051787886889, 0.0905472489314214, 0.15492776889474164, 0.08667809122632589, 0.12083967546782187, 0.13218508522597053, 0.09599241037522593, 0.1554638925459116, 0.10399806748835311, 0.10363179319087537, 0.09683912905353693, 0.1396271237923253, 0.1994834578926525, 0.14853510224530775, 0.11806910316790305, 0.34534100623380753, 0.09142447323087724, 0.17301861346969682, 0.12611209940645965, 0.16192661027514166, 0.1622530250179191, 0.24424409073206688, 0.17097810763985882, 0.11503174840923279, 0.1641288372657953, 0.12428384589692279, 0.17393198945829946, 0.17059261219636088, 0.1776152176241721, 0.17071150904220922, 0.11588114839527877, 0.0964387255390325, 0.13131027410347618, 0.2333581345456262, 0.14401245621904252, 0.09902621814680677, 0.15670912250155405, 0.16552771381553144, 0.16006648750795474, 0.14724283449111447, 0.10473795520562319, 0.16940771932563475, 0.12092425157466244, 0.16576590587294873, 0.11241335181459305, 0.13222158165468326, 0.1097654608348685, 0.10159902484907259, 0.1023743900981161, 0.11496432501101687, 0.23927797172819418, 0.11173897227572818, 0.12286662920227936, 0.16677294377117388, 0.11358172016879244, 0.2007251025568093, 0.19081426904566828, 0.08435802459115944, 0.1824026083153102, 0.23450826234634847, 0.14317480036087576, 0.1630346338835455, 0.1293134659288391, 0.11228313985010309, 0.1342339260924247, 0.2310086194906504, 0.134234155918802, 0.13777562717516578, 0.08993758083952051, 0.1592914057114432, 0.10586680108380896, 0.15462536334751115, 0.19897918817737412, 0.1416297542351869, 0.19013467244803908, 0.08858479980018832, 0.18127504946483722, 0.20384931636433448, 0.19375621521424866, 0.17258284733660761, 0.14376975956463045, 0.17976905850152816, 0.12458664214899465, 0.19692097039472675, 0.21328109977466447, 0.2557885454547021, 0.14742804390768852, 0.20756651286876973, 0.13359716913152125, 0.1512137593160714, 0.1708636541039713, 0.18696449336505708, 0.13024783272656704, 0.11293096678151239, 0.09077529798472121, 0.14093900339738016, 0.08643463614486879, 0.13800957510548253, 0.19102517305122269, 0.16936373055702256, 0.1631002110098639, 0.13375161245705622, 0.09788275531102573, 0.11631201922653184, 0.10515602470766153, 0.11895725188115913, 0.03757430676130518, 0.1742701253463184, 0.15459093535619398, 0.2093752617797544, 0.0820464232275563, 0.14326731313861188, 0.21363579848360634, 0.14206089319721346, 0.12175931039476588, 0.13012380309162602, 0.08171971737136764, 0.13305695457083563, 0.09979327900275108, 0.20902992466524725, 0.1004406616031643, 0.10850186775168104, 0.19976398396876552, 0.1303161218041374, 0.1871023432261521, 0.13064517188937436, 0.13201590236877242, 0.1104749272006654, 0.10097213510063388, 0.14629460150195708, 0.15641301419706116, 0.09385163129697885, 0.1265957307130579, 0.11167153355575378, 0.16768990505126216, 0.17601703564005514, 0.18900415649817837, 0.15074929552933863, 0.12031796959138687, 0.13205838960505303, 0.18677245044419843, 0.10314718129173403, 0.14995556715275013, 0.08711977155819055, 0.2295409329235554, 0.31517846990496884, 0.15866074681041703, 0.11647094416642383, 0.16311378608788216, 0.10071970146870422, 0.13345066247688187, 0.22400876687419033, 0.2655447058139309, 0.1355621693355422, 0.11971023970193441, 0.1152415032829008, 0.1533886522895867, 0.15172156835755995, 0.1644593275963299, 0.08611120914499606, 0.12503144045871112, 0.11942870238976133, 0.16109134461129868, 0.09242375831930869, 0.14563579653059283, 0.10333285036106264, 0.18936628625998575], [0.004161618473458915, 0.03321428971004582, 0.05102484569614453, 0.024643186930446856, 0.037357201274003715, 0.042151965561413, 0.032869504178844156, 0.03657107248962407, 0.016851195569841132, 0.05283397765109136, 0.04754497556977215, 0.06918965989062864, 0.021795504050509586, 0.08814190904940329, 0.020574729536629973, 0.031094336732020302, 0.01257284253370017, 0.03428336923881885, 0.027336016627809694, 0.02491966231666025, 0.0550895243612749, 0.07428993621180136, 0.026783067770602725, 0.01756894334609951, 0.011565977005257962, 0.040480507267338615, 0.0191999196390351, 0.02977107306041064, 0.039141803093615084, 0.059805385422922915, 0.07534388167363021, 0.012771785991536755, 0.018265932054829695, 0.027164114158480402, 0.019507628429921407, 0.05078104970556113, 0.05291052132604584, 0.07656978323094307, 0.05248384482617821, 0.034950834834167076, 0.05080882422325592, 0.031311426897563284, 0.04605930508865465, 0.056366217547967556, 0.06157969485127157, 0.0476171104087224, 0.018171672596626224, 0.04897662919134863, 0.020335673715078065, 0.0963100993765458, 0.042681412756322853, 0.037443102712953286, 0.041826370532714555, 0.030662563832236395, 0.019479062926444798, 0.055339142620082826, 0.07523446133540523, 0.0763154497009612, 0.06228428506743043, 0.07078758140485134, 0.021339229743687377, 0.051837573053255204, 0.1083028227871945, 0.04626875352715293, 0.12392195362237193, 0.04352995855433326, 0.00834524856820222, 0.06637978728019422, 0.0360611145715079, 0.07234468575446837, 0.05569226318790067, 0.017668954209394513, 0.04706643108699111, 0.015781515619657453, 0.038154445994164676, 0.03337018477219728, 0.05391920248286859, 0.027484047797418414, 0.011075659666300542, 0.013996276031849126, 0.03283392322520095, 0.0845974653718933, 0.035029420133439765, 0.07336514551312694, 0.10907168394976086, 0.024993739188498548, 0.04444386314360365, 0.041940161402547554, 0.061818430831115094, 0.013453564982140257, 0.050371893636521795, 0.04229539637303641, 0.025569973288164027, 0.06788412349358683, 0.09364260420683893, 0.049046657288507114, 0.013467962647067204, 0.06683949366091721, 0.04162698082866208, 0.03456933070875464, 0.03307818652941816, 0.042248377726683696, 0.004307156026874099, 0.030514343055866422, 0.01801500761611087, 0.04381642564229908, 0.02151497414395694, 0.05133343740336357, 0.013769875982806329, 0.033904492794986696, 0.0036397344815815172, 0.08910518034451431, 0.021957198398247845, 0.06324561049921379, 0.06058643887480421, 0.06921927684978132, 0.10125333533412027, 0.04808989007987323, 0.017881135666562666, 0.010882110425060796, 0.08458294800572819, 0.0236556229872569, 0.04187851047684108, 0.023243532801467567, 0.14148361530275116, 0.013804794270395031, 0.04488149087034887, 0.09916087342125755, 0.10548456151398922, 0.02787722135713745, 0.11913971870296425, 0.016287245690041495, 0.01676932566859309, 0.03239089074814993, 0.03360147054697718, 0.08468714362430958, 0.022801228107944615, 0.07481195618428531, 0.02643439434318533, 0.04169110238792435, 0.03409889526665211, 0.03236194028549137, 0.010470881130576376, 0.025529757502578923, 0.024009032753266157, 0.05117307221817394, 0.01655838144342265, 0.1211672546642442, 0.009101725919472595, 0.02728071848621532, 0.02813179812003528, 0.05094205840460716, 0.029601022608638294, 0.06838427165583258, 0.028564949978082895, 0.08710566787950455, 0.10734793249397509, 0.023909309172942757, 0.015649682421597744, 0.052479118063685395, 0.034489251538029606, 0.05213285398278987, 0.01088878496610109, 0.009375251867177506, 0.04429668999247013, 0.007270600537829582, 0.012034024168256552, 0.002891743229889882, 0.0030610517733880593, 0.06628493793428906, 0.040768292026534196, 0.015059698001301337, 0.01789963860515385, 0.0278189929292327, 0.025712040463282217, 0.02307716723261101, 0.03544947380320199, 0.047971111977653164, 0.045882499656609954, 0.06002977257594467, 0.05823198255271681, 0.05110347696069268, 0.03399700557272281, 0.027722561611763896, 0.05835608113557101, 0.016989160344124805, 0.06325465799759954, 0.02981294359591219, 0.042709164291379914, 0.02613071709000055, 0.038535846697707335, 0.015220096702837657, 0.02564944150376945, 0.1090391175520997, 0.03571051826340056, 0.02424692220595335, 0.09077727449156585, 0.09112825767407495, 0.00700980649262126, 0.058019381662410115, 0.01243685043582152, 0.13528951864329078, 0.06736018830129216, 0.04506404196182567, 0.0524898739381423, 0.019121292204926574, 0.032107551214134986, 0.02955097791498467, 0.038755530070874004, 0.012199436915257286, 0.030678785744033037, 0.04722084376900908, 0.04813935254670439, 0.05328859720799712, 0.013573498919516081, 0.04962197399788326, 0.046304774981352596, 0.06024885073965115, 0.02411947964930967, 0.010516875134330365, 0.03824390208108291, 0.036194793083855224, 0.051321049761627956, 0.08269068785011768, 0.050553253461276336, 0.03795953407402962, 0.030152992788521998, 0.12483467843623892, 0.09553345476066875, 0.05796358747888477, 0.034375598564022974, 0.04153249920496056, 0.07789584312347636, 0.05017319724204079, 0.02996229243675067, 0.05258831623641234, 0.0100804923004621, 0.02101140539912928, 0.028372066275727366, 0.06831396776702135, 0.07349368740594195, 0.0666076677941507, 0.032517900465116385, 0.05776119854060873, 0.042528402015206315, 0.010740533546214143, 0.09204095184442498, 0.041718742840232394, 0.033904902652026184, 0.013937079460330069, 0.054058270423763224, 0.032333054940306374, 0.0025449062588684744, 0.03221618056657814, 0.04339692738628195, 0.04243672044286805, 0.0441278786879153, 0.026328091982812173, 0.028936669245482455, 0.10733115516843335, 0.11054463354089569, 0.07426032691352791, 0.04111336101026785, 0.013747571332890902, 0.04823555786823554, 0.034970124928100456, 0.009367931897061007, 0.031436546292576584, 0.009523295485714992, 0.030153214954020038, 0.08099437000290041, 0.04512484636037581, 0.028318152838056127, 0.05614851451208515, 0.0281836852551468, 0.023271360945317055, 0.02831914300669826, 0.041479045420043895, 0.0414692739685697, 0.07510281678649687, 0.061452060772646824, 0.022968715995610244, 0.02510750707569382, 0.037795506988561926, 0.05120234826820032, 0.029771145838763446, 0.04968403478062922, 0.10444874169244882, 0.028087156261467648, 0.028370551336857102, 0.05352631429090135, 0.05594928568649677, 0.0070022040275826815, 0.01739275269961405, 0.06527521106744967, 0.03199228945548736, 0.044428870802925485, 0.08218167605058802, 0.018406344480031443, 0.014521045302371345, 0.07386204546257373, 0.02268264152770562, 0.03387219069765941, 0.03785590919095182, 0.021431627608234846, 0.03724593849432084, 0.006941709415836921, 0.03157742794663195, 0.03037930282223369, 0.03836527722136628, 0.048206025178754525, 0.04284628636894688, 0.03318744598917904, 0.06544854612119737, 0.038988240769193064, 0.07848521754626306, 0.017880216361053528, 0.026853457844305425, 0.04221804064488219, 0.06311631784023297, 0.01004202415295426, 0.05533490232342193, 0.03863541514522607, 0.06759594419911023, 0.033543512165065736, 0.015514845201264948, 0.06858995860262264, 0.02756232474630158, 0.020165891394079215, 0.03790981113730419, 0.021316476932336247, 0.06246312446291409, 0.07858028905766626, 0.061359490538316394, 0.02999477456474016, 0.048469808403282404, 0.022385441547920628, 0.027956760435875867, 0.08444876770579046, 0.04987080318612918, 0.035541231984332684, 0.0696411308261656, 0.03781294698015817, 0.02174080154227634, 0.008981017275683342, 0.023894234477812727, 0.006689478318402243, 0.046577345234371965, 0.05209357665491201, 0.02609976713785962, 0.016876934208877144, 0.011210859820787466, 0.12562230875295016, 0.09174372505156264, 0.22011962959602957, 0.11950947870049747, 0.170557877769874, 0.08435512111792642, 0.06492508590341577, 0.15981957736995914, 0.15898314725247123, 0.09951276824839654, 0.12037926428620854, 0.09858786263653348, 0.10745041973648534, 0.15610446462467795, 0.1072065279849114, 0.16877972641058508, 0.11334185803970022, 0.18808989184758357, 0.17767222988749706, 0.12138722148994285, 0.17414088631349225, 0.1380297691831666, 0.10371935704062063, 0.18365174531936648, 0.07084435618091976, 0.19276627639849342, 0.1920386767315288, 0.155987820077327, 0.1964562614598582, 0.1592348837443898, 0.09885207103985934, 0.10387661190883768, 0.09872323037275384, 0.07025300525128841, 0.1423201986378239, 0.10757391310987935, 0.10872691374031768, 0.2626258801789053, 0.13735383448581542, 0.13329085653587697, 0.13522237869760684, 0.13700874251944406, 0.1588046487661139, 0.10456049093796362, 0.14693949431661638, 0.19882017896781046, 0.15244876965880394, 0.13302392085954068, 0.08487457469586404, 0.15884341281508246, 0.1527132078885071, 0.15446068508730781, 0.23721791533452852, 0.11995528058539476, 0.15570560860778057, 0.29356182823258065, 0.1202406943024647, 0.12129116172511732, 0.16720166189535973, 0.09481487960945215, 0.10623430112196554, 0.12093869999291436, 0.2309275214229861, 0.1556727587575874, 0.23400796096651788, 0.15796516961868734, 0.1553276055041821, 0.19153863582159245, 0.1685655895139902, 0.14617588851721058, 0.2098900422213539, 0.14024863560353557, 0.16997863869032553, 0.16088928126039045, 0.21736264769588748, 0.1070266045750149, 0.15060597580046425, 0.10335502860647056, 0.09434787241081077, 0.16309376054954144, 0.20296696693666522, 0.1618272486713625, 0.14752012767618702, 0.15722833093135588, 0.30482803982111717, 0.15137382572697056, 0.20579844322656432, 0.08651357384458666, 0.13903820136141393, 0.07916779422591771, 0.179325784706781, 0.13995945273387816, 0.06407429929822683, 0.18124701064680854, 0.19432456052351385, 0.1195476758444021, 0.16152377060103804, 0.21196738155859135, 0.17438306202811582, 0.16347430706504854, 0.08038674736575735, 0.2921331968278654, 0.1274052251791281, 0.1350664491614988, 0.13183820061385632, 0.11741268072998333, 0.08816484572185625, 0.10076895326135621, 0.16076097685483196, 0.1191356124716901, 0.13912481526213308, 0.35438617571227016, 0.18518945232274073, 0.20932637004842683, 0.13111502893509405, 0.16779410833072278, 0.10812594074635737, 0.22646786314585518, 0.15679003670811653, 0.17603332266932534, 0.16848623812679323, 0.16329268293996013, 0.12648494673832772, 0.08210842272326832, 0.14200628644997074, 0.06691694515006197, 0.12094836036163954, 0.30559115532425146, 0.17317008437408557, 0.1431054387602114, 0.1942036565273039, 0.11153436551291136, 0.07393125384565323, 0.08861333657536777, 0.20898213610053065, 0.23391676586001153, 0.1338658821318419, 0.1407098511774694, 0.14750512767462962, 0.112067892126018, 0.08507096899613258, 0.10864547093308742, 0.1290304730496099, 0.24839149157126106, 0.09564193281074686, 0.14724666493073588, 0.14737354441275521, 0.3100065490411174, 0.10018088118804079, 0.11334120686496459, 0.17513171379123965, 0.11563705746084453, 0.07766305198592525, 0.16216952143417251, 0.11821216242688319, 0.18218755211320617, 0.20169136925570427, 0.17006911367418306, 0.13083735270605934, 0.16079132925839196, 0.08687377306482486, 0.1543395512647206, 0.18030315968057803, 0.09899023499700332, 0.1682418101136723, 0.10518368048172806, 0.10765334110586874, 0.11251475121225081, 0.13582777201889024, 0.12124797734882563, 0.12537663201651267, 0.11009259570029475, 0.19407902934378196, 0.18100561634186776, 0.10388602712942709, 0.1387146824309903], [0.05460097860064238, 0.012518611169540355, 0.04668217287549088, 0.04336704995723502, 0.041060615856681144, 0.08345160468090927, 0.055526179156356284, 0.023140875104394172, 0.015335442731156947, 0.044295831973994934, 0.006015510072991733, 0.020660280490354187, 0.05124900685322862, 0.07389739275940004, 0.056303015294214415, 0.03324826953992729, 0.010497440441301274, 0.037494166303546204, 0.058247687355164564, 0.07104818153405382, 0.02257549455539594, 0.054934912496396614, 0.03181109242441674, 0.015243619432552688, 0.07018050269013451, 0.03328201188255222, 0.031002312335335923, 0.011236486419464552, 0.053540774200472145, 0.03795766481949437, 0.09168551769107582, 0.03925378216550716, 0.02621319986158802, 0.0485911337478507, 0.01695645796585708, 0.044043769894708554, 0.026992734544159427, 0.028632990077077865, 0.030384948890235637, 0.03482552966283214, 0.021375444635087927, 0.021205488029086304, 0.009172340073893148, 0.005702377858406474, 0.010549304593775061, 0.014728668536390028, 0.055987184056110924, 0.04236350541994457, 0.009080929505158096, 0.03294417859926339, 0.024808261641151002, 0.029110356699675325, 0.05727689690707673, 0.017766578708805384, 0.048196318844753894, 0.04729119362309576, 0.05619515011447573, 0.024400679882796063, 0.006803108309771145, 0.02083165435901573, 0.02373202876638501, 0.05033193449039133, 0.01962916444866888, 0.021098785387772708, 0.024472872178340634, 0.03857363398457247, 0.02840685049792932, 0.051696241322544315, 0.01856880491569398, 0.020831368991263935, 0.016202897494358402, 0.0753578934217653, 0.01705454020280271, 0.03214789914988703, 0.05489119951943717, 0.022781740746370727, 0.08955744801149254, 0.03538828636068971, 0.008469960979005743, 0.056768609060635494, 0.03701766727552299, 0.05586259517698519, 0.050822943223700415, 0.08361334116348336, 0.0748613152292467, 0.022935289664254076, 0.0346634982364072, 0.07183418774436559, 0.030340864360632918, 0.04525016685346923, 0.026291503623548537, 0.03539777435963193, 0.060568236625723304, 0.09438349549928982, 0.0025644855509932727, 0.0418580559292628, 0.05428382203042988, 0.100399446072838, 0.029548275539831772, 0.03151119773035809, 0.03503247299381802, 0.035334269501148693, 0.04895618230464959, 0.02162453237800829, 0.03393011460561426, 0.012250390380711086, 0.015983033132919624, 0.020731846509020657, 0.036414204495808775, 0.044351495922573154, 0.010649433243088426, 0.05543702184372852, 0.016503431871833823, 0.03680521577236153, 0.021339053543464794, 0.04895401810626349, 0.024682178890572923, 0.033857845701277256, 0.04137587635928104, 0.05720025364069208, 0.055354104317244024, 0.02124972577627388, 0.046582684867204203, 0.044078385577567165, 0.039480011759986805, 0.02563034867747657, 0.13169114237591145, 0.061630459667574015, 0.0077772446468682786, 0.03926102169639161, 0.03646046088467683, 0.06743848248715363, 0.012367296355566191, 0.05118263682590858, 0.05483981800235568, 0.015261229878712087, 0.036559929740765405, 0.053254219012395035, 0.02413777382894149, 0.07875034525509804, 0.09083303037069498, 0.055768224636032704, 0.01796123781992543, 0.0322028391453768, 0.03263032003756493, 0.06446385500772346, 0.0053235765869518925, 0.0388975627720356, 0.04046118269944864, 0.03156497135698315, 0.07071893226595656, 0.016184655025661472, 0.036869758679982156, 0.00873163075847251, 0.012044344330206515, 0.05527008745458819, 0.010886969337720546, 0.016738195685789953, 0.07725086603914538, 0.008144071964066356, 0.0325958269287742, 0.023208099319749785, 0.013952554436400534, 0.009980379930517126, 0.037322079973115076, 0.010662587930358226, 0.014818664715294878, 0.03596245776861906, 0.00389692671653334, 0.06583126066553016, 0.008744632228157453, 0.03911522367308217, 0.06008129198885253, 0.06001793651751453, 0.03931170990390163, 0.07313415468219789, 0.03230081029957341, 0.005503667578581842, 0.02479548904023344, 0.001472343184662262, 0.03193465857616356, 0.09889939229094213, 0.06968983869639135, 0.04681423494231798, 0.08857054290391746, 0.06501169214325567, 0.07701431340988606, 0.06270780528505003, 0.016365564773760496, 0.10811533042860609, 0.08277524863519976, 0.017924170655709122, 0.04489612314970263, 0.008919030228900093, 0.0345957569117027, 0.01727469472004281, 0.057928864543716756, 0.02003087031264459, 0.06206888412576049, 0.034782391251815904, 0.05119839908495065, 0.030066922810229085, 0.03993800976463864, 0.023583583909297184, 0.026795989758665525, 0.06117540344055142, 0.056368435372508345, 0.03555106472284083, 0.010089937206958572, 0.010008800834898027, 0.07976281471670636, 0.06480022889351653, 0.014235649779889614, 0.06909947602018233, 0.022466344263164267, 0.04848590008013191, 0.021407133862075788, 0.0712498082148452, 0.045115109382858204, 0.014264545658783568, 0.023535462096333507, 0.032391894323330735, 0.05734132873194833, 0.02796326835279263, 0.026944218195914745, 0.047392466616246014, 0.03900416773713885, 0.03522835784561692, 0.016813042475992156, 0.031800022453910885, 0.06258883949128852, 0.06066168786116666, 0.03559180910909369, 0.017458304928074923, 0.03648883678139218, 0.05679351074861423, 0.03556425292645732, 0.12515995170800917, 0.029068509146811503, 0.0580418931560651, 0.010402520232263112, 0.032478040910416076, 0.02720647882069311, 0.08419615787363822, 0.03852745037405722, 0.04223247757181526, 0.04635901783683127, 0.07248009945596419, 0.04128923181504492, 0.01741667379504971, 0.0790743851253102, 0.06680887312658372, 0.03118142752247232, 0.03285290688396462, 0.010684633067989302, 0.04786043908567198, 0.07829674459513157, 0.025832184117227316, 0.04969296736582633, 0.07334812303944942, 0.0411479115756529, 0.04577028309746135, 0.014012738303732009, 0.05571889240414866, 0.02999190748068354, 0.014540715567437152, 0.07328637635275241, 0.05302291408541703, 0.050407555029397054, 0.09094692466239776, 0.048892026271430716, 0.03315290308467323, 0.013857663913269438, 0.020207298446386572, 0.0035253628213409217, 0.07981827948242426, 0.024110196578887202, 0.057360048090378125, 0.045744596169360226, 0.025778676706155943, 0.011957147245055005, 0.04033408871281051, 0.041878407054971305, 0.00588797367057733, 0.04435978116347425, 0.05238940916775216, 0.03859633700020852, 0.034338669295633034, 0.04253000696940769, 0.038460459815518516, 0.009936268587837057, 0.046712260978717, 0.04835049786995496, 0.007725172214240077, 0.04167163226332876, 0.08539085666979514, 0.07510265590803278, 0.0693491900399808, 0.02001417725677452, 0.03900044838026647, 0.0823493880189715, 0.06439922016955192, 0.0755898418625997, 0.015833503303809032, 0.02017946072643803, 0.023053422337397936, 0.01559597582766606, 0.07603037306257794, 0.024320022315688195, 0.059611044238291444, 0.05283078306444711, 0.008641421990168673, 0.05573295777843845, 0.07967566455444021, 0.005596040066466817, 0.0650937554817046, 0.025074249283680995, 0.055039583089491056, 0.03806499373768607, 0.03175170911896614, 0.010745514075331872, 0.07677620562214045, 0.02856450181664719, 0.025540586155388626, 0.04910254723302299, 0.008933326387177072, 0.031124210330627622, 0.06812203975935137, 0.011734133304637528, 0.013764572739150497, 0.019345049250630603, 0.05107067307577499, 0.0393091626615534, 0.04971551716387753, 0.019614241055903897, 0.021336462251060916, 0.013730698246358624, 0.009778097286940584, 0.016798379553121426, 0.00957656636713974, 0.014406889583164407, 0.0468679491971289, 0.019409889017321894, 0.026633002637555043, 0.009507868390139795, 0.06615972086306542, 0.02309090701953298, 0.035297558567817175, 0.10118144564330579, 0.012374805932443951, 0.06933971353235745, 0.03666976759690912, 0.10312177015528565, 0.10789079771887873, 0.14280341625694307, 0.13286097395804622, 0.20273995976294243, 0.24932205857288456, 0.11938217020924054, 0.14895704815224295, 0.1653193991871611, 0.2123942457500004, 0.11790096219028197, 0.12329528603943125, 0.14453209365808195, 0.2341751979603883, 0.17729451789730982, 0.1546024266750582, 0.10226113932026971, 0.10223167557870189, 0.1659458599263622, 0.22520749529282894, 0.09868563077743016, 0.0872026622715977, 0.2679897826765814, 0.16521853605105033, 0.1105929047410046, 0.11710747130094998, 0.0884236838488329, 0.15257535802741207, 0.12427567173877072, 0.1894731248819059, 0.2161840061026235, 0.13012757224421348, 0.22493973224153443, 0.10906304247797498, 0.14467411103748506, 0.1755498905455874, 0.12188398354356328, 0.1664985463984551, 0.11973868454656295, 0.11493792562114616, 0.12332455059813878, 0.18014707692688514, 0.1278507359506142, 0.10893240150424743, 0.09706492580833936, 0.14492135825416735, 0.09139338538290993, 0.09941244137383277, 0.1124629713294487, 0.2403479667320367, 0.1412758522576863, 0.11851056899514892, 0.31946062561004396, 0.061459491825512344, 0.15082904528225624, 0.1573558845707486, 0.15189642026539774, 0.05584836509379168, 0.11476966973033645, 0.29162981577457925, 0.12451463754499152, 0.2495534784130512, 0.10694134664992172, 0.1832360506898934, 0.09743889162857687, 0.13502978419344272, 0.1846848148852587, 0.21135235085122048, 0.13083683176627084, 0.12892231675646, 0.12506894046260467, 0.17891450274375179, 0.11160574192481656, 0.10367094794468534, 0.13917986634037188, 0.2447753727075554, 0.17982746504487532, 0.0907846212747597, 0.1424538350153354, 0.1443746779114008, 0.22208179527473068, 0.13820241475778242, 0.12271787024914257, 0.3117569986610644, 0.13140534561487938, 0.11174283335886656, 0.087635149548371, 0.2626330507618766, 0.20428641549041196, 0.1726442109793425, 0.08327961028102907, 0.12832292956450295, 0.15663865773427874, 0.16471532353710744, 0.08256565463999588, 0.1000724797467551, 0.12007397058750353, 0.15838667119462646, 0.12126677714648748, 0.2249426280538882, 0.10366494947623822, 0.1399611381273116, 0.1517388666228902, 0.09836018896631657, 0.12832519718475882, 0.12471528363323982, 0.15015375409876147, 0.09069702678149746, 0.10299530436074543, 0.1802006417945508, 0.2177038785791205, 0.1579343115970973, 0.11764397033520284, 0.08338958220255953, 0.049805938521580356, 0.1562455933420889, 0.15133708415012206, 0.09025163092320004, 0.11307746577527254, 0.14822877432790496, 0.12848839689526828, 0.10762778441271476, 0.17295063082729617, 0.10342195404753571, 0.20567269755467293, 0.2038955114661686, 0.20831530252771996, 0.10303458934950252, 0.14311447859771792, 0.13808495815723174, 0.12842138718453147, 0.16415142153780307, 0.11106119896735876, 0.1593482647571833, 0.2044881417626335, 0.08476661758557444, 0.1519172425351797, 0.22397535011893321, 0.11797084473073484, 0.15940002165734768, 0.11887169518177548, 0.19039534152515475, 0.09342105924001626, 0.09157706262363542, 0.15120833541356749, 0.17429804159027917, 0.09333933298025401, 0.1536958075819477, 0.07314412148609277, 0.05416603984251138, 0.16915144759320444, 0.18644375275940667, 0.23022855812263107, 0.09852125895239654, 0.1161059798792966, 0.2254184605854173, 0.08864631666050804, 0.1042630879448787, 0.15594968422045632, 0.10346663229527975, 0.10589940578586633, 0.08783470013088758, 0.16943373567154332, 0.0897205021652964, 0.09294370219351784, 0.18992191450970788, 0.08080649460034986, 0.09366832177845702, 0.11749344937984021, 0.11612187620372542, 0.08897836214952892, 0.1276091271410546, 0.13537841548602428, 0.15570502638095812, 0.14334945308585323, 0.14985306458848138], [0.03238511061476123, 0.04256465329578327, 0.013459849775949074, 0.10055646345379854, 0.04176434039348557, 0.028535377068985856, 0.02401997057360507, 0.15180493404548015, 0.04534193652591879, 0.0424736880156542, 0.03130027265738576, 0.022032328640982028, 0.04258265636200386, 0.029272935878966126, 0.005564605563713779, 0.03615307193549891, 0.030082732949766423, 0.08738617097297985, 0.04474509274587036, 0.05283801493445232, 0.050105436765138185, 0.007035253539441094, 0.02123386009536203, 0.08386120125050507, 0.0545597285963595, 0.03175204811287263, 0.032241346554890755, 0.10130863922137408, 0.041536739501621456, 0.045119464592707735, 0.09461256344952891, 0.07909880800833625, 0.0065201637898421585, 0.021152116598621495, 0.02396722542001836, 0.031057332770057747, 0.02910747429386022, 0.016130046363198952, 0.015012257048980364, 0.07100108244846906, 0.055171740917308684, 0.16971668258549708, 0.056836093745885365, 0.03776870923297059, 0.006025930305176805, 0.02633699583971212, 0.02747032907791436, 0.007624051002259817, 0.03989797784015536, 0.013675641422460397, 0.0289955948133983, 0.09784883293773859, 0.06046680275410895, 0.037346709699880694, 0.06656408505213839, 0.04841805150311801, 0.038911969055451696, 0.05667216625184782, 0.016093785506522944, 0.01671869491767739, 0.015582418944236013, 0.05525951927167274, 0.026336218260468978, 0.02289946930813453, 0.010389057194603788, 0.04980478172881469, 0.014323979717559152, 0.04376880944736543, 0.07419386878609657, 0.011404026975674976, 0.020607887737212643, 0.033745701920481465, 0.022780283264094786, 0.01847596463537024, 0.03886916772312215, 0.007136408746572993, 0.04849289446288059, 0.08082755435738834, 0.012889459011926046, 0.0465218345033786, 0.019127597108543403, 0.04790708617938142, 0.03168039399409487, 0.019452673112673145, 0.022063213475649397, 0.05780403434689488, 0.020474812519105694, 0.08444928864557898, 0.04988217959180475, 0.067435150004683, 0.010908824868590362, 0.046336418243065, 0.022820782502211874, 0.04173272777529013, 0.03748703402497115, 0.06751966482448964, 0.09039689651540211, 0.03674484421348861, 0.06221662418195798, 0.07564870039782218, 0.004282895937531946, 0.016286473856457782, 0.06963482592254877, 0.015248079021881907, 0.03380630330573167, 0.04946144027335029, 0.07628567186334441, 0.055106665578580676, 0.02476239595712433, 0.09658848806735008, 0.027154951746906006, 0.06030384436129563, 0.08110759779810905, 0.041955781935323636, 0.09084331893151806, 0.032725314940175707, 0.027360880011392218, 0.04143748131971206, 0.03745876155012558, 0.043887932289151416, 0.041558450433395566, 0.022313048154295936, 0.032168629489118056, 0.052532640796515255, 0.07441154500890164, 0.02500316398518701, 0.11958633264106129, 0.038471043320192445, 0.05158293691854324, 0.027438521107298233, 0.02874138768792393, 0.04094880915457203, 0.04484279193885384, 0.008400086099432122, 0.028090889024878704, 0.07403647602205315, 0.008344436515002482, 0.06959773960613436, 0.012964586381830517, 0.02444091099013965, 0.027298978191890547, 0.0760419103467176, 0.011390310171390734, 0.03210975180169748, 0.011108022093051865, 0.02964337577953214, 0.033954342136219624, 0.034295538545496045, 0.04153835594714169, 0.038680430471656785, 0.08243352745569522, 0.04758067526704362, 0.014838297633574376, 0.037303824097879475, 0.03884323564688525, 0.03690256256489985, 0.09522854410592588, 0.03447713968794673, 0.029913285792234446, 0.03961440656454333, 0.020598459110084563, 0.043201686048339454, 0.016462139732715105, 0.027871418241111022, 0.05401103344235209, 0.061569739538695545, 0.053490660558905334, 0.023454622583343618, 0.015189844848317726, 0.0735193053861299, 0.06226554655680253, 0.07438502304496304, 0.030075874547624303, 0.0169447387358354, 0.03566199042383702, 0.027329213767042084, 0.04388025225771051, 0.054313209163205284, 0.026001160130685857, 0.05385731790034522, 0.022838239730786414, 0.03472570074541915, 0.043599837264346505, 0.07858907608615776, 0.07511818451025794, 0.014226984367856096, 0.05374587509000013, 0.02676481189536712, 0.011074294114575512, 0.019804564109372518, 0.06614202423201454, 0.02063362829146847, 0.018511028479664557, 0.015107859076271135, 0.042656384663836616, 0.01386951050540853, 0.026415422175740524, 0.02193787574557768, 0.04195895353933016, 0.08114034805687205, 0.01622105186294404, 0.034406437433414885, 0.012610874968701074, 0.03833477926110068, 0.037727761833417806, 0.016631851190580957, 0.021216284123159224, 0.12699017406351146, 0.0365690385261851, 0.048464985879799055, 0.03519050544127822, 0.0501613688444899, 0.03410837177427546, 0.016296731773763895, 0.05340846315506966, 0.05364747109612631, 0.024529221775611083, 0.10015374635376277, 0.025778485184174874, 0.00669313399421592, 0.06260388545812139, 0.054953781241971644, 0.06006425036297691, 0.036257332671553864, 0.009541028505942274, 0.043994046957983125, 0.02891890175129858, 0.061959774053144845, 0.01096539758896876, 0.019220839585027388, 0.027155275419054013, 0.008097087791670234, 0.04637153188307439, 0.08860913075266347, 0.02528278607754938, 0.05200105238585703, 0.01705169801660363, 0.06531404406433144, 0.008228089784332102, 0.04304302540878135, 0.0366394458368661, 0.028432428258501237, 0.0026161950494673464, 0.079939145174238, 0.02126496518030763, 0.05184584680283743, 0.02178000034614196, 0.06301416384596979, 0.011300802373537614, 0.021872493971679962, 0.030752973698620355, 0.0752869843234939, 0.022022898098634138, 0.024103642696694984, 0.06872672827974444, 0.014169298904767681, 0.016432471062627532, 0.0689160745711096, 0.06101947773488299, 0.03118063462147069, 0.028568399288961967, 0.018945304571741053, 0.024674788057323427, 0.05921538280803831, 0.007901607051251397, 0.07924140761456183, 0.0338698081642149, 0.057485797592709144, 0.030792187824244463, 0.031278826025945526, 0.03673309242473014, 0.04931656538598961, 0.07843377474214762, 0.036884835290332, 0.047168933651259834, 0.044019301046407035, 0.04338002748667233, 0.01950610774539171, 0.031291610118181955, 0.03994600772256813, 0.04756116300761219, 0.032208979340089906, 0.08645062439984853, 0.0780957461064381, 0.06896270634306055, 0.1067697429548829, 0.011789261949278656, 0.06683389355819072, 0.07673841450483569, 0.029510813840334455, 0.07478796231049685, 0.01265432556054645, 0.060816410808793964, 0.021492334330574642, 0.011815445876920657, 0.04159810697479595, 0.05064048023233491, 0.049439388432449875, 0.03692506256723597, 0.06672486392480713, 0.02119971364135704, 0.07904384119976914, 0.08469255986593424, 0.011799902910546911, 0.034875168329885894, 0.02871385448792529, 0.07555154512726492, 0.011348717342761737, 0.06603774434376149, 0.019246827202638792, 0.04372812251770689, 0.03634411894205598, 0.008540894017524777, 0.07005965998095852, 0.07387542901861091, 0.0314405050519253, 0.03724205442854474, 0.0674252138443051, 0.044811738564843134, 0.07099432555297691, 0.05225169337204388, 0.019207565196519418, 0.038040421467514775, 0.023889787337412278, 0.06559051753532502, 0.04441467136324895, 0.049327321260446505, 0.06251367094415812, 0.06924464968183348, 0.028282108401218732, 0.017631622744844328, 0.04055532341402385, 0.02005889763935439, 0.009500821338846319, 0.02645886702192647, 0.01048909774380586, 0.03233060345894868, 0.016910910208318985, 0.022656025717996305, 0.04612697363500634, 0.05970151922214897, 0.07820483702685564, 0.056301280105065916, 0.011749472300101434, 0.056872027099973736, 0.015194854105732616, 0.04031731904814801, 0.05281439644374675, 0.02240216716252748, 0.044547472704922965, 0.015526190963423541, 0.018707485982186852, 0.14271110266206727, 0.19317656244722106, 0.06491221562628785, 0.23348680667338834, 0.1330536910362782, 0.11886915176986687, 0.0968815933071798, 0.3259864996277517, 0.1536042447532377, 0.11278753213944936, 0.15124087882859094, 0.11637493802775299, 0.11246426601804073, 0.11285523132931803, 0.09222756320190045, 0.10672313416556967, 0.13634583131680567, 0.1466278191055021, 0.18312122943180223, 0.24244936123009653, 0.16508732051137956, 0.14671028080967166, 0.13427285868073666, 0.15129612908969003, 0.08729014951255053, 0.22913705136987472, 0.0616702234612838, 0.17366223457840183, 0.12026750737981451, 0.16497645226697769, 0.28116891581204634, 0.21950093698838066, 0.12071527044979796, 0.13324870637828304, 0.12667610099719417, 0.16629724913547117, 0.11146665866216345, 0.08208006214831146, 0.16766332180028962, 0.17273857768985534, 0.11661826287426295, 0.23452385989648683, 0.09843213228328575, 0.1994865528878666, 0.10859951331850984, 0.16174873998088224, 0.0928934927909605, 0.09485661607956695, 0.1541214000674025, 0.09599624847572658, 0.1991700206793124, 0.31472629416854153, 0.09405357973469843, 0.12745398667550858, 0.14570425414750654, 0.13519866061547112, 0.17801200520367394, 0.23330663811535607, 0.11594704727852538, 0.1288913361608021, 0.10800858373723685, 0.13691315006825233, 0.16368151852680793, 0.1369667302576765, 0.13925390107737434, 0.10741705660738292, 0.11093363766708683, 0.1762340836707623, 0.12107998192791017, 0.14268448876757778, 0.15626650754242175, 0.17991899723006835, 0.08389704650448215, 0.11463011915404951, 0.1416131454489885, 0.13550504981990785, 0.14490527040775747, 0.14883894803783587, 0.12436354202368569, 0.08293814191053953, 0.0906873664127723, 0.18751158739530271, 0.13995222086387296, 0.09176155191756065, 0.09681380218676022, 0.12291817159782495, 0.2088389849109996, 0.337921597904736, 0.1965591011028136, 0.24490468834917395, 0.23703380908456542, 0.16493336748211615, 0.17819473249537332, 0.14299761954574816, 0.22551547796014818, 0.13983045884918782, 0.09804171855531393, 0.0844167375696763, 0.13909725141861748, 0.22628029417847434, 0.12509803648196882, 0.10913108640740957, 0.1587840869662262, 0.10114804420980716, 0.12031632250234967, 0.2402878135082222, 0.18840024938746808, 0.1473831511553257, 0.20431909680126176, 0.2158869478491045, 0.15956586437119594, 0.1862066025815664, 0.29795696658472864, 0.19658700202501592, 0.12810590451643353, 0.11783359241822075, 0.11322170480965607, 0.10445377489011134, 0.14976730870623745, 0.08809762916737988, 0.12528988788084638, 0.09166144720849492, 0.1290714434318004, 0.15524266167513787, 0.1385238652508105, 0.13501398746044407, 0.17805807773144017, 0.11279684776860861, 0.12305063586081229, 0.0885214749723673, 0.21059386251914888, 0.2948304391916721, 0.1825716685984404, 0.11094588741299607, 0.08268981450988401, 0.1850027413738351, 0.09549062278482223, 0.22929206160047363, 0.1261563869493623, 0.15948245271800027, 0.13925387043385737, 0.11180924552102244, 0.09583762997100431, 0.11695356423696203, 0.1572343983477162, 0.11056158706666001, 0.18349419167685896, 0.17007536495164519, 0.13079394616426962, 0.10210268935489078, 0.1730073519772099, 0.13835606135187611, 0.1252367903268145, 0.07099293893383396, 0.11821967008854113, 0.11925846233122772, 0.13765682225986836, 0.2242344104114079, 0.14210377879921468, 0.1281680572297304, 0.08792011127356561, 0.14633017862516065, 0.1160784543401772, 0.15446117538357937, 0.14615986195783462, 0.17200733144437114, 0.15162609848043612, 0.21398657482237587, 0.11939092659421506, 0.22126008936714744, 0.10407663746586732, 0.1839901876425551, 0.24184205268900244, 0.08443495514051569, 0.11711386047423848, 0.09909008689705404], [0.043086527711561615, 0.02979461685754359, 0.04813918017692143, 0.07576040367806151, 0.03126243940524517, 0.03238955775516168, 0.08225023325893187, 0.0438605101719018, 0.05206665632525279, 0.03115723063538392, 0.0331089411291384, 0.038393480748298674, 0.04186122370282969, 0.029915744934471387, 0.04675184091132495, 0.032618552927047975, 0.02773142524904782, 0.04246073729929425, 0.06562059414723227, 0.024947752845623804, 0.0571124523036903, 0.01775462773718661, 0.052263973761470094, 0.016702074640160127, 0.0844697125496403, 0.020818514035894506, 0.031305865099233006, 0.04840283316650218, 0.02924998005431506, 0.03347335000252051, 0.0932483600392457, 0.05965409454919639, 0.07212001514891464, 0.056218944805403875, 0.028591644311804446, 0.017922548464529457, 0.05103616464522578, 0.02247358187882891, 0.06078281785331427, 0.07585978826447841, 0.07331041619181633, 0.034296902182001265, 0.005812124262804226, 0.04911945479351187, 0.020816052978437756, 0.058631891940510085, 0.032558480142465526, 0.02773167039718359, 0.03268117678441829, 0.023632347320897445, 0.04134208422094103, 0.062292669899761684, 0.031076762675037308, 0.012531366533479624, 0.020440463051800768, 0.06534936837852001, 0.0719539043042929, 0.012507981699590963, 0.04665543257649388, 0.027400224371963454, 0.00244139485256446, 0.07015271668112086, 0.05163960061186264, 0.07130314325613361, 0.01491230172705987, 0.020809058595689076, 0.03135391987950331, 0.018279535861145106, 0.014077660424875156, 0.0363876863623098, 0.048585234870833736, 0.01860674158970435, 0.020225226819034547, 0.06532993272788103, 0.07397724976462704, 0.037177718364663666, 0.021747592911725084, 0.05452591347538176, 0.06423085319599317, 0.008581014999729252, 0.030117352463064656, 0.031453164654874036, 0.008184119210308118, 0.037804244221338344, 0.03851560665474784, 0.009583645977169998, 0.033558006548593124, 0.022386510240575, 0.011291179351598747, 0.024430519007446787, 0.021264901978053877, 0.0116584409448889, 0.049534900444409544, 0.05191121708541628, 0.1223232200549495, 0.005062968796870161, 0.0400169283121584, 0.06987549244396149, 0.06243650673798496, 0.04171185570979311, 0.03664089757348261, 0.018705107279181964, 0.07388796221705214, 0.02132533482396074, 0.05043599221314635, 0.015634716893996925, 0.01789954667460294, 0.045107716634388895, 0.06513812729427892, 0.030858795338821028, 0.04037881292583, 0.08051707424343595, 0.03564243219913014, 0.0190096176529844, 0.06867003777334768, 0.02279259046659835, 0.008698276247859241, 0.06301047130217476, 0.04445680236864475, 0.06313089649343202, 0.02888753811167854, 0.08145594563815864, 0.06087751398163457, 0.04365904436957452, 0.03732494897239151, 0.028632986246638244, 0.057533264400497566, 0.01672377025017575, 0.025286695041183024, 0.0327703609101234, 0.007177606561116033, 0.02960505606155963, 0.05524443883088328, 0.028895890385273005, 0.05067603054246114, 0.011454221056473833, 0.039907814409103126, 0.03530259559591932, 0.015304210284093936, 0.03721904497773897, 0.03896603954114741, 0.05675215732246157, 0.024191053328855384, 0.04739224828118759, 0.06768252745631241, 0.022531201266833854, 0.021073703669131767, 0.013628973261333041, 0.06466575748016758, 0.013671121503707143, 0.06431933252080795, 0.06546746849292709, 0.09358434322019739, 0.04427946067505306, 0.042917406141397454, 0.07117218052547786, 0.03708370405459597, 0.05127581226969919, 0.0717877474943957, 0.041540033679695866, 0.1063127561862911, 0.03428732608294776, 0.048905647314724424, 0.06475720539568894, 0.029072975439410058, 0.04626822492648517, 0.026316278907019767, 0.006522425664438596, 0.04655432046180771, 0.027677887194459478, 0.07581227549141453, 0.0722100687844138, 0.033425837229456634, 0.028382115434074116, 0.03782020566324073, 0.03207681768183266, 0.012400911336073713, 0.058682338830323956, 0.041250394987723524, 0.11251704947602366, 0.03343858493251666, 0.053095098720082355, 0.05636982965253054, 0.020765546716809757, 0.0023518971096153462, 0.04143114577257826, 0.03683326991214868, 0.06086572771891952, 0.01675206953809867, 0.010062416455888701, 0.05298402363194093, 0.040953248634093234, 0.04536931267789295, 0.0025560183642101626, 0.0577852460405519, 0.039810260772825255, 0.031608462168444554, 0.037525093273049405, 0.006540253009241556, 0.04809463982500377, 0.022049538806200992, 0.0306094988369413, 0.021568994833937576, 0.017220153090273662, 0.025518356199045817, 0.04574037119445782, 0.0417712543370022, 0.021714909685655467, 0.03313389644327183, 0.11277384214824247, 0.016980817646629388, 0.04563262092790777, 0.023243006116019625, 0.03318893219975214, 0.0727226811971876, 0.05746756086967165, 0.014891158657959633, 0.03682856996273322, 0.04525164157272347, 0.0072452631373439115, 0.030951892258599404, 0.022924987696892312, 0.023983355401264086, 0.03417159318022671, 0.04197464302001942, 0.010701043628937295, 0.02801043447107077, 0.07848641264342493, 0.04250346968371061, 0.04854192409003454, 0.01473360118501249, 0.02941082404445737, 0.04537740639681297, 0.03936857661052097, 0.02244906323481231, 0.023704334687922272, 0.04503340610573369, 0.016542716860590924, 0.05776437014461525, 0.011423902169260527, 0.06631086234964671, 0.056206361811247565, 0.02610394806270638, 0.02547660057673291, 0.08149723011639812, 0.02065089208284213, 0.024281625988923257, 0.050020404835982676, 0.020434663766213966, 0.02994115224048015, 0.0585080806406275, 0.058664588573118376, 0.03496567395726039, 0.09003651343406209, 0.075143932725393, 0.07974172431615092, 0.046768549288953506, 0.023383669435016574, 0.03514942397633868, 0.04053815921408035, 0.032990297092305075, 0.03508558970004801, 0.047164873385261145, 0.05009741965501059, 0.022803465084683512, 0.03328292352718211, 0.027583263844491977, 0.029893898022090717, 0.024243490132052573, 0.051139869967535626, 0.08447017986327411, 0.01908080062768873, 0.020283549092710018, 0.06065904868826751, 0.02069071333314623, 0.0420209760176799, 0.03728402072503682, 0.032605042966503295, 0.05698727353686287, 0.05172834806745091, 0.03660122187988412, 0.0137044204729459, 0.032428578443584904, 0.060326375007148714, 0.057423660201170755, 0.05574027774855495, 0.05174793693567476, 0.031863496668877146, 0.08521142355617016, 0.03200836964101801, 0.09293255561421956, 0.016971584371921998, 0.040252921697233, 0.013635206344206969, 0.009850987680106154, 0.012398748095297526, 0.0828836577373647, 0.08790431454056695, 0.042876734533497406, 0.012044786745982786, 0.058888443295032754, 0.011865917664592066, 0.06975133257407336, 0.04176239069971827, 0.005399145415022729, 0.08528195727135866, 0.05336939650137098, 0.04910731229991202, 0.06041960790753365, 0.030261292723157716, 0.021545498917299895, 0.012945378642348994, 0.026027950225397948, 0.043288016496526624, 0.07314644273250334, 0.07587890981906846, 0.03426017975735088, 0.0603138073347509, 0.06955331416740533, 0.009515442126881211, 0.012771120452652536, 0.02367247692159107, 0.062473033810214657, 0.04266729758631799, 0.014936129934334708, 0.05256171766368132, 0.05466212390831882, 0.0452640138927006, 0.052064132065542286, 0.07322554897156454, 0.13070224543973324, 0.0031317896988888785, 0.06613260135054588, 0.0340766289211329, 0.010959811850390848, 0.005795921024400742, 0.04793769139195642, 0.03872072286603432, 0.05193211979443028, 0.00674636226199988, 0.02169618075112662, 0.13337607615657393, 0.034026036474613414, 0.029064762976861773, 0.02112571720875079, 0.027506231788485765, 0.05275286043122892, 0.03470993082549784, 0.027149068191647533, 0.04284342886098931, 0.006749352398929337, 0.034738988540465796, 0.18202584627414906, 0.12406816150272086, 0.1998418185018724, 0.1856765769902737, 0.07874619305854844, 0.1602054865009362, 0.24196715484703743, 0.10301035798845753, 0.14568894771077942, 0.14006488175401766, 0.11308773901433715, 0.17170233651995662, 0.07113476479125601, 0.15419267688787755, 0.12940585613250732, 0.15920344349597731, 0.10271234978591243, 0.19841514828224338, 0.18920286438397824, 0.140457930824449, 0.12595184913445867, 0.06194413436817066, 0.23712494290403782, 0.1535511242165681, 0.20068074606599348, 0.11333956743680662, 0.16545475160162296, 0.14447004053621523, 0.11323784628222067, 0.1231219050204081, 0.2187320605040558, 0.1022908635317318, 0.10176823834978765, 0.18776986627809464, 0.12804847090475022, 0.122006458020018, 0.13549769537583475, 0.103680623635169, 0.22422104983800845, 0.10262174456710778, 0.22535846057918765, 0.2017793927582041, 0.1414557756675828, 0.14885842199287108, 0.12214580175256538, 0.14472994352540663, 0.13672401828150596, 0.11067070863059453, 0.11949002006722075, 0.10115485473145401, 0.18314484026162856, 0.13623510096823016, 0.11593217751191509, 0.08514049913614027, 0.08180982463302151, 0.18394796087616877, 0.15468350942096404, 0.09449565077140447, 0.12444597308433826, 0.09936548784495362, 0.1064566658028672, 0.14311953477801817, 0.10471604509098877, 0.2761036343872547, 0.21448304576258506, 0.08376887233387079, 0.17671973744948066, 0.14926990313876062, 0.1919622364784441, 0.10736102493660105, 0.08937145718523572, 0.1262779804247041, 0.19798572535716719, 0.14172134770741387, 0.24024695037834107, 0.11931837806778571, 0.19194404955112165, 0.29650617991724326, 0.1370469243415902, 0.15706757504132488, 0.15228340191946876, 0.09576983885058472, 0.07279147589278799, 0.10212431601699322, 0.14785000513638222, 0.07985287601308477, 0.1574236833520474, 0.09185345182495733, 0.10301387433202998, 0.11234038960068457, 0.13722946777218772, 0.08945656955362329, 0.0990159678903799, 0.1437636615047532, 0.21437343390237903, 0.0959101478539167, 0.127470312009175, 0.15501399975149863, 0.12342130750297539, 0.14026060189691283, 0.09517136330325758, 0.23686171509325507, 0.19731412671746748, 0.13071343032342772, 0.12154167247635704, 0.20503666071641832, 0.05860021803528071, 0.16287913335667503, 0.10626554984839694, 0.2488557561751335, 0.17876258750836696, 0.143936873984433, 0.2031775798288084, 0.16579569137144476, 0.22325544197472835, 0.15867213087697185, 0.23149396683419907, 0.1143822054408731, 0.17029728530155075, 0.14800192037176702, 0.18304733259062614, 0.13654141356387448, 0.15343736015981244, 0.1087778892307993, 0.17751372629596343, 0.1429480536570472, 0.13055832816227791, 0.17584984461146017, 0.11832387336800176, 0.18759694491182605, 0.10787398974982002, 0.1300727356705935, 0.1535302559815107, 0.1752683685551728, 0.09465839849003861, 0.11580965707018492, 0.09261311993243233, 0.13029275612244684, 0.1790609940766327, 0.1794310758310941, 0.1729853192885076, 0.2142377903745059, 0.19085956016375175, 0.17913734239916648, 0.18651668432979815, 0.09020810180734243, 0.10642003913920735, 0.11250869911764899, 0.19243779321832044, 0.14882757929303955, 0.12580808507458818, 0.14302893722009274, 0.2790075059859984, 0.1686687815573908, 0.12971714829965947, 0.12986154055162785, 0.3059598887639661, 0.19132079105944405, 0.10910610428019878, 0.13467559110253088, 0.16187252446768746, 0.10561796806512341, 0.1435739015259089, 0.12105104678701009, 0.09665444823763064, 0.2923920426157213, 0.09985334795689392, 0.08456381112937966, 0.15379443374131957, 0.0855106728211526, 0.1486073596583259, 0.14694835029302106, 0.10119962490974896, 0.13438388014272337, 0.1644048893884305, 0.19135220066433956], [0.05223227687360299, 0.035738756264289545, 0.07226244621579686, 0.043475271367858496, 0.09089545121476536, 0.04428252502675018, 0.08965068091187747, 0.03840515975870433, 0.10370321556805603, 0.05168583784853259, 0.015896091729612843, 0.033408661538194266, 0.002383781449621423, 0.07887040655459128, 0.05565872385857567, 0.03633042128996984, 0.048315200368843736, 0.027079999619614215, 0.06106521701440216, 0.015752888829146904, 0.029735878981169195, 0.053687729016547246, 0.03264580650495426, 0.014217791312764731, 0.08558540469816617, 0.030500718182133093, 0.034700952275025274, 0.09151101052280396, 0.06058840005989037, 0.042309170633914976, 0.11024290215103857, 0.01349241330078052, 0.0785142905829895, 0.05462057129930585, 0.06478819365222609, 0.008987079903994118, 0.057764676579784964, 0.023628352172372323, 0.086662792450478, 0.029667662681951642, 0.07087025761363969, 0.038846993308153846, 0.019564112092578606, 0.07243991814433567, 0.05141928521615844, 0.047215213022765615, 0.06922010422473954, 0.05685107459524467, 0.045475312433536016, 0.07024912884639156, 0.044589484966690504, 0.01858546349760746, 0.037629055234813885, 0.06778522920344146, 0.058034151837590246, 0.03266152279872087, 0.07665635882726601, 0.012165589235542763, 0.0696743483985624, 0.042997918151799715, 0.08677726896900324, 0.017630165262568383, 0.019349452340975404, 0.041927762269493074, 0.02857698713459315, 0.043076430672719594, 0.03128452763532198, 0.025764258931420987, 0.04828683979388687, 0.033135876780556094, 0.053192219516683015, 0.04367590596478793, 0.04291713801062396, 0.03776733410514651, 0.008618097485704048, 0.030773945355547533, 0.043613113568074284, 0.01938036398872012, 0.02337800613003633, 0.03427273976886946, 0.011111741449924247, 0.05953587569116105, 0.08507914315428465, 0.04604931913256165, 0.13134589719195522, 0.027210119653553255, 0.01940256713198558, 0.02080159306886696, 0.08086388224675771, 0.050547975115478046, 0.022500992504759662, 0.03330045161888965, 0.06677911827160467, 0.041710388651418115, 0.03164776247896014, 0.025627577354410486, 0.05997398605329856, 0.011178822023794057, 0.03728604319715693, 0.0919801934111503, 0.0855391636310566, 0.04158446294886451, 0.029592021075527997, 0.014565512875936206, 0.05266079198448889, 0.015777835524791194, 0.02490216678368949, 0.06954510170485705, 0.002938947652564234, 0.036965638414145484, 0.08612507533642554, 0.07162064839635165, 0.012221110500245085, 0.04092574607761156, 0.024828486362352006, 0.028717886025626815, 0.01437192628791015, 0.030647477645787503, 0.012122932502308921, 0.06562650068512847, 0.052833747824714075, 0.040690618371891404, 0.058881000750848365, 0.03450245506340458, 0.07934884378506292, 0.06577801755479266, 0.03340562783001411, 0.05103017000721828, 0.02518406607240679, 0.01981246439109166, 0.03659254976458127, 0.05107308242229685, 0.07864191317029538, 0.01821262957227807, 0.034204075308216196, 0.0368184192977365, 0.03037910172415357, 0.042741910719703284, 0.017450218870034142, 0.04340350042067228, 0.03764196381633801, 0.01854700013814915, 0.06028219854699508, 0.07232110556815902, 0.06420045865759735, 0.044323150669374776, 0.007736053535594575, 0.0693401348807158, 0.04307138981417783, 0.015897038805809234, 0.02177325494196867, 0.11502694503794755, 0.06508494547057538, 0.029248476606763663, 0.02258729422464967, 0.04497624062482388, 0.028951719042754946, 0.019206536723481073, 0.09139207537255942, 0.02517704870702038, 0.1401312709335358, 0.05005219748484031, 0.015423193314833748, 0.00822983071914003, 0.06751505297518547, 0.07392450461104032, 0.015241463852655745, 0.005180335860894693, 0.05755433947929452, 0.059839054987195044, 0.05298657853516841, 0.05871748311385032, 0.04006714154515536, 0.03401539934378478, 0.044141235430875135, 0.030889042405291434, 0.037013997714365685, 0.031549597887562654, 0.05348864574766448, 0.008162381465456659, 0.03457825180263289, 0.062448580283671624, 0.04082183391156216, 0.03937628345503923, 0.05074645700534025, 0.03345808570062922, 0.03958818720533483, 0.01610991165732905, 0.0054659808407567685, 0.021881271424072406, 0.026971649889263417, 0.027396769315424948, 0.04266184304029711, 0.010600161340628422, 0.023346590779481396, 0.044357103686178886, 0.03696725485966571, 0.08441454655821286, 0.0250405854650683, 0.022993420415948478, 0.015664250541087842, 0.06782633748145835, 0.053985185635786866, 0.024225877770673365, 0.035816724862783186, 0.07266075064938876, 0.051627730079475916, 0.015008494599662242, 0.023659353835448146, 0.055519778491748925, 0.04702664814108322, 0.04008951897342359, 0.030275390656184287, 0.07202511983773402, 0.08641151561131401, 0.08018351956120423, 0.026886185120430686, 0.060943508625871716, 0.07513499247931665, 0.09845494638167082, 0.06059539827307867, 0.028472469759083567, 0.08048872899023757, 0.06728385530051685, 0.04052059281797659, 0.05075596032604095, 0.136194804743413, 0.012202557765938824, 0.10286726808596043, 0.04506958460795783, 0.03121442867503051, 0.13655457495441362, 0.021855092284479932, 0.08150579497939156, 0.051603153978864995, 0.025710303358913913, 0.08900007308130303, 0.03772028098483721, 0.009966219752846707, 0.05862357988653164, 0.016180826501259883, 0.02808703177217995, 0.012142326018112081, 0.07773860357701778, 0.02747443147874888, 0.05015054785255944, 0.04716607997374189, 0.0038519542431458835, 0.026279370706047744, 0.012478340800190646, 0.024691050188736092, 0.03470657152994987, 0.03575904610296411, 0.043990354414188096, 0.1472504647268403, 0.03482411240017222, 0.011224439686855242, 0.07495054148978765, 0.01779642549433535, 0.023172434096434907, 0.03170119519645889, 0.05237186575428613, 0.1437059291187794, 0.0435030841899495, 0.04596519884803603, 0.008233999195058019, 0.03963872219525999, 0.0781252404915229, 0.07163059221760881, 0.038772717253455234, 0.028497572545142427, 0.05493649063752063, 0.02270482743399278, 0.019466550795421488, 0.05668365374027241, 0.08552097670373418, 0.10995314471543798, 0.058127622225231705, 0.02113809718960716, 0.0503191140089785, 0.02992695280080361, 0.02949203127965091, 0.017332285379750595, 0.039450536527100115, 0.04908802220597864, 0.0257255676608052, 0.10432660429468078, 0.055040655612585046, 0.04791994496519047, 0.007898030857059864, 0.02408705306269469, 0.049513269951867486, 0.0549301665817057, 0.06156646451281925, 0.04264888849349753, 0.025262134262330593, 0.060986624054250226, 0.07690612647321916, 0.02858166218615107, 0.035107089957642945, 0.007835206380414387, 0.0845588622013888, 0.03336905862294859, 0.008441908754438402, 0.027907527795421983, 0.01929182912253084, 0.0445415010495532, 0.07538092968564841, 0.04247124419517575, 0.05824001498460289, 0.020385745221809037, 0.014606316634003195, 0.01755872947884904, 0.07761131806839859, 0.02795619161559209, 0.05718852866501097, 0.060835478737229304, 0.017582049195264137, 0.07159224951699858, 0.008905169783130048, 0.02479025474449079, 0.04093743274889646, 0.052169419359415777, 0.06400220659411242, 0.011090539966619784, 0.01744078641246644, 0.09073352321021019, 0.054624267673540505, 0.0506750920847539, 0.031956769788878105, 0.040954960840604, 0.04163944507919012, 0.0289589777258375, 0.020593253542639075, 0.05501208436344901, 0.03837351649699192, 0.04306480911890826, 0.04890963480237031, 0.004185704277798293, 0.062396984261971336, 0.05909259806597426, 0.04177260648218855, 0.018030383000751177, 0.0521124568918059, 0.022037120520948403, 0.03270540431502365, 0.05148272878760773, 0.02776974879745995, 0.04951813461018666, 0.04106129384449413, 0.027109986216190363, 0.012185893438365913, 0.166722780333892, 0.15604193652829818, 0.17333778102071057, 0.11486832653322529, 0.2082373147770282, 0.1468574922652014, 0.12103731849140699, 0.1433340547185752, 0.18854906962763882, 0.1406380687389643, 0.11320029265217244, 0.13780548928245423, 0.1158358189727991, 0.18547825214843597, 0.17237175946995137, 0.10337403524787196, 0.18775567832973697, 0.12061103652682036, 0.13655693450522038, 0.1657385565340519, 0.10272797797956776, 0.19828388677729716, 0.1219520504556356, 0.06194195101758646, 0.1421553058730018, 0.16872456808003689, 0.11511401859142127, 0.1659180815782278, 0.150406593757291, 0.11393659507795689, 0.22036637119468183, 0.21512830629944804, 0.2113600117304633, 0.2720285982133881, 0.17036946610577647, 0.11115040990614122, 0.10285380026025158, 0.14519541854819945, 0.21578222362985536, 0.18026821074947236, 0.15889052722242572, 0.2462982329269571, 0.19433655746040807, 0.19277749192570487, 0.13364535606195851, 0.16710222368278813, 0.2568089286045682, 0.16503173317159378, 0.18641781302229052, 0.14833758945666975, 0.3160029030855625, 0.10952041995140815, 0.21010955705517725, 0.13408257776210386, 0.1548067116809468, 0.19605193557518144, 0.11894298732400903, 0.19406836539987596, 0.19956498496955444, 0.12874734227455434, 0.22993824144284572, 0.14671060256659985, 0.1186156226322055, 0.13844791529399736, 0.12984430357333154, 0.13790849746475298, 0.10973191384466426, 0.14219941721568186, 0.14423667483272093, 0.1415905611769807, 0.1860173941860276, 0.06240384457933326, 0.07943227076001706, 0.14208410566131915, 0.18094172460898278, 0.14013750688923945, 0.1287534403344316, 0.06546162324206484, 0.2444910928006134, 0.19629627165775146, 0.22957205141503967, 0.19124946827369352, 0.07924952048567996, 0.15305811599377664, 0.28841491247857776, 0.11253240187802624, 0.23956355398460744, 0.10712772818101991, 0.24395144514499173, 0.07959578456657548, 0.1814115510111855, 0.13845363030991248, 0.0917363246422141, 0.11370548167295995, 0.13672150551311432, 0.1748695278600339, 0.1813708870641647, 0.132784012765173, 0.14839585810419054, 0.34886062866257084, 0.2770553913808638, 0.08441535095053335, 0.06428667419259587, 0.13461634186246704, 0.17436288327219027, 0.11856813284177935, 0.11547837000820907, 0.23855682252155197, 0.17585303153722517, 0.14383023454537316, 0.1820416583289062, 0.18628339523509627, 0.08755526956050627, 0.19690094485638604, 0.1361553052500371, 0.17938288890065687, 0.14258626097392652, 0.11658992528194383, 0.09432903430875271, 0.10974360434638877, 0.12407165486365558, 0.160256247486799, 0.18305787396046425, 0.18279872173743864, 0.2139069170000092, 0.3008604704612686, 0.14010910034900712, 0.11483505533467378, 0.11506272134401145, 0.13057510548781964, 0.16782898065303603, 0.12502199459460475, 0.10266505151746735, 0.11912805118387747, 0.15198213018236623, 0.08820029261011271, 0.0553367754083968, 0.21697111547954623, 0.19557774247181034, 0.14486641442823797, 0.16978690220463663, 0.04949889431196836, 0.11359163334653263, 0.1594062882565683, 0.10721834106070381, 0.1099726569748694, 0.17612520725496356, 0.12683427517092036, 0.11364296123745943, 0.11172058616554546, 0.17750574365979244, 0.1454858271585357, 0.15087252843283838, 0.1397766181898694, 0.12228238756858534, 0.07782513320806526, 0.1731438535235582, 0.18949765501724136, 0.23831144455940495, 0.08176830266752551, 0.31467665167104814, 0.16795014511914025, 0.11371675848720536, 0.17708700000038072, 0.16829909816865, 0.14612264540647307, 0.06859234113606714, 0.11820030338581532, 0.15725609395773182, 0.1668670500117925, 0.1626526011574653, 0.17444321525193032, 0.0893773407404942, 0.10080390985334113, 0.19721980597223007, 0.07998771514863738], [0.04722508406566997, 0.03868765085034313, 0.04889370783442452, 0.05099124891022521, 0.062029242906118595, 0.01626145342485078, 0.04636787764367558, 0.1502820431825615, 0.11579806615989055, 0.014547213908254862, 0.017060569314766797, 0.006743178209064589, 0.02680029517279998, 0.03226935855984207, 0.016780202201898062, 0.00553941707156839, 0.08312657655727479, 0.11340670738249056, 0.03320506218099787, 0.0579911015266853, 0.08689667909376084, 0.0471029045330661, 0.060603848222883484, 0.05781853639130151, 0.035100436484020565, 0.08615608657560042, 0.009504276395384825, 0.018654530154420965, 0.04290525598691837, 0.06446171762241472, 0.042131740840212, 0.012131002280981311, 0.050616509341184175, 0.01577885537934039, 0.07202070717129015, 0.018575015973540086, 0.05064104713739888, 0.005316072276928613, 0.03934072548403375, 0.021327123639263937, 0.040222343297735344, 0.07108961156899891, 0.07150858505478791, 0.05215801614066286, 0.03611263781485539, 0.01689893433884267, 0.04014949982745513, 0.03164813211638361, 0.061091704504384156, 0.06670732817222035, 0.03138218086303002, 0.029719023131615216, 0.06626069125148558, 0.06482461347214638, 0.04040824219344124, 0.14610960659000183, 0.036395776250790206, 0.058779164683073766, 0.03177365753799677, 0.03474930008392661, 0.0422002712354785, 0.06263329940397414, 0.03436744355806901, 0.004904394821008487, 0.028066686392130873, 0.007733370791444736, 0.05826529588610415, 0.1559153175161731, 0.03778138032723819, 0.03579536250101463, 0.051506718830956574, 0.03223021529735096, 0.038241320364778085, 0.02843746528660338, 0.05921850461632975, 0.059439003873135776, 0.014001781331194986, 0.06685710602229641, 0.024234226213828213, 0.02572781229842334, 0.03257687008308788, 0.03925290499483386, 0.0024444687803606355, 0.041739273996603106, 0.013708294962622948, 0.031691779975869486, 0.009445202397933651, 0.028854694007144823, 0.06202117983071555, 0.054347089401656584, 0.07057940467230736, 0.02583304213570251, 0.07945781213141258, 0.056034260159057964, 0.06866043869165644, 0.043872346230331934, 0.02333309805591501, 0.0676919196942641, 0.003220329592530165, 0.04917178625961946, 0.1367047281875726, 0.017325723836679133, 0.10014496698615052, 0.009440480423490367, 0.043632422814205776, 0.04012393547342189, 0.01868499364072998, 0.002596146049683974, 0.05812186890492036, 0.012732859148884253, 0.02639038067671561, 0.05216472707087955, 0.08254699273816041, 0.041250728235970584, 0.027033180156121814, 0.020565804612312107, 0.02268306479128378, 0.08772027723851704, 0.0649253233906723, 0.01587524456197336, 0.03616427980183113, 0.014413817890829619, 0.0045269978844801025, 0.02698624769466058, 0.005435181233370978, 0.013793872729424509, 0.05519369699721856, 0.03759695615078654, 0.04204115477360545, 0.018210406002077847, 0.03356415057374585, 0.012002665316686036, 0.05240800978255369, 0.07917373140733089, 0.033430621448543765, 0.010246649110359291, 0.008636564992728734, 0.013874967924259124, 0.04225896506179725, 0.035254431648119804, 0.019133827318587614, 0.09021615339142662, 0.015984659154538908, 0.033535797659668236, 0.0777504702789649, 0.03578114390913998, 0.02058004427160467, 0.051171340859465064, 0.01483884251361052, 0.003322643028842586, 0.04249290533123478, 0.012660380527977983, 0.08772557856695307, 0.02665273706248451, 0.07189378938487462, 0.08944943727504823, 0.06901637846303564, 0.009808928495453251, 0.005164896795195678, 0.03710317800963118, 0.02796905997750019, 0.05297731270172423, 0.05949606210173619, 0.04581530991521093, 0.035471736318281585, 0.0839593907397601, 0.029559845382708217, 0.02890188119284088, 0.052585979668243285, 0.04032768804820315, 0.018516325977660956, 0.04848646698519588, 0.02555476644286706, 0.024737285510186228, 0.042210981144659945, 0.053462621740876674, 0.01746627607292706, 0.02287233830429614, 0.017760350413980986, 0.05153828931431617, 0.026112158610034856, 0.04047543193484026, 0.09197445541259744, 0.021116688862563144, 0.07102388122509565, 0.03841298151641123, 0.06259953790915108, 0.057544349692761905, 0.03489268876071419, 0.06550887554523445, 0.07251768372952938, 0.008024867725438409, 0.011030473885306669, 0.028868521894178087, 0.027898869086657802, 0.014218944275090772, 0.0701583780708813, 0.030154381322884755, 0.06363780538160956, 0.044740388966015274, 0.09094382200630442, 0.07238620771996437, 0.03407516952363714, 0.07251003051116582, 0.04964576868881142, 0.01815001912144644, 0.030457947493320515, 0.013391168078317518, 0.02694346359930933, 0.045363023096034606, 0.03677077245928588, 0.014550483188471727, 0.058472154947418364, 0.029784883710465608, 0.03717492980461928, 0.004505895513800844, 0.08122397421468651, 0.06201814995297502, 0.04717353783968476, 0.04677459372267608, 0.08497283313303225, 0.015667078363138343, 0.04493985144842056, 0.03893074970091543, 0.0880025270124597, 0.034916207659989595, 0.012211148484399723, 0.0009518503605748618, 0.024275587300860116, 0.04104435181004867, 0.018782853712177566, 0.044961359366894736, 0.039092842414374315, 0.05529125829437568, 0.03256951180857516, 0.053078344377178344, 0.04454725436986454, 0.021661662744478356, 0.0629123469303933, 0.050648160263775825, 0.016805586525269093, 0.028173128563550212, 0.09687122047668505, 0.07380042134994462, 0.02651382233917473, 0.11185475880460394, 0.16437928673000107, 0.0118573508863788, 0.03967129625380039, 0.025744829026441422, 0.06211245920689357, 0.055480845903436986, 0.012774589873339622, 0.05066697921363577, 0.045975648287323215, 0.03145152522671608, 0.0578280741859588, 0.03396596752047058, 0.005302059092378665, 0.08003872894351521, 0.08421239127675373, 0.060842388850306316, 0.03966876816365027, 0.03604552851268842, 0.008711735455078945, 0.045023852989317915, 0.0488108401036551, 0.06443968493371241, 0.039761353719739184, 0.07762861633372885, 0.028935713550796913, 0.04889904363681713, 0.04018555575561139, 0.06353290496213783, 0.04151258857980852, 0.028165992454535542, 0.03805665487063028, 0.02659636639779614, 0.04346085742356316, 0.04271579478236456, 0.03171584854323057, 0.05213682614867726, 0.04365485769906833, 0.03094177606755928, 0.029032137207386476, 0.03808886886784627, 0.047137769194500106, 0.06592877599741183, 0.03410074536898925, 0.03562794930692162, 0.06906520890732927, 0.07289365670012851, 0.032495791167621656, 0.029290285855231267, 0.06017734026235919, 0.024218714848581343, 0.06024418143375267, 0.03259632105548536, 0.016460684165658972, 0.020312756194823214, 0.009341906932663293, 0.008921117818493758, 0.011871640341386441, 0.02122495049280265, 0.041827328142619906, 0.04752259814150391, 0.034052910838997176, 0.0634815694103318, 0.022880983606521643, 0.05169043437607827, 0.05255948068694242, 0.04992768521450701, 0.030210487687239246, 0.0334446408575581, 0.045853932237913536, 0.023194441887279673, 0.03814916381792676, 0.052666679370186986, 0.04675010572217646, 0.08905228963422199, 0.11031499102471337, 0.05671975563370413, 0.04358250069462004, 0.02646408216547101, 0.03639258549458558, 0.02012698753406444, 0.049788548325699185, 0.009659712762391616, 0.009543361243671708, 0.023302511995538108, 0.03622960028869491, 0.017884454742494612, 0.05794503665979832, 0.007025143572865355, 0.04814715132177357, 0.05492625570285225, 0.029007517056719914, 0.029099288644389282, 0.14148655708038038, 0.05794599810014329, 0.059125198937592015, 0.01083067815465432, 0.011775545144994414, 0.04371700275148596, 0.05348140238634041, 0.02263788284072953, 0.026084345787943854, 0.02766421060979126, 0.009569616992056612, 0.020850498206733216, 0.018067792989313602, 0.01501958851041573, 0.11739971086142525, 0.09820150917456036, 0.16338904147907612, 0.12939916052404912, 0.11282648771039902, 0.14395282393501652, 0.2504427073102805, 0.25071405565306065, 0.16668067614157356, 0.21604465470919687, 0.13307154088491394, 0.12438008952285014, 0.12453202007999345, 0.1990307458946782, 0.10488256962308962, 0.046269236162545226, 0.09991923917926128, 0.16767573242466297, 0.09704801824785049, 0.11343152097035801, 0.14144166432801755, 0.19736228300438774, 0.11247722056484032, 0.09716228792263616, 0.11945832700979327, 0.16887208597073633, 0.0998069536721995, 0.1623333876411761, 0.16985732100663647, 0.12430105223170212, 0.11710452952332075, 0.07559139702108598, 0.1357895748749856, 0.07154071478233223, 0.20322683928233964, 0.14890446387712034, 0.13660181193582474, 0.1043332462769843, 0.11750272670460325, 0.08506179892367895, 0.18704891625431277, 0.19891168050948652, 0.22672324621629333, 0.11566363305093781, 0.12593954576239472, 0.09277044374856258, 0.1742882969518823, 0.14045907995633541, 0.16323599243356338, 0.15894927084445953, 0.1926106073322796, 0.15303703325410045, 0.15733693155550188, 0.09201671282250075, 0.12523155028541244, 0.2235751304655306, 0.16662997644274466, 0.24335178216138195, 0.07482121052641062, 0.13298615272487366, 0.13030070811510086, 0.18991181747086588, 0.17456304672504627, 0.09314212662678573, 0.17012684606015685, 0.06562712121634715, 0.17078192784420906, 0.19817068962560547, 0.16673923590250556, 0.29623366712081817, 0.23578307861762665, 0.12330319972768908, 0.19243975440340658, 0.12817316703618536, 0.2142032244873624, 0.115021942483802, 0.06991511451140528, 0.19999695130653922, 0.08219664540862845, 0.09723376392597154, 0.09639226230642489, 0.12271839884981034, 0.11351590555521751, 0.10936639031335231, 0.08026116257233006, 0.12457407064615719, 0.07270644013319286, 0.13673831348217305, 0.11437184793213684, 0.14878463240400439, 0.22954183690730603, 0.08971831115383296, 0.13233543764198982, 0.21387425101091787, 0.1837676544223101, 0.12105978018934689, 0.08705593345146026, 0.20956126792776972, 0.1680975557575303, 0.1194563121985524, 0.1947275993804778, 0.08016116511557372, 0.27239874125488345, 0.08838298159741587, 0.21221714154366525, 0.12519192821796865, 0.13552288434678508, 0.11084226636035789, 0.0949713837115034, 0.19320136837420926, 0.15604172202367939, 0.15495550127760058, 0.19420805387198928, 0.12556310547816177, 0.1301800339452682, 0.107425767027082, 0.2138176677568305, 0.21292356654040276, 0.19751836575808066, 0.09511065849613759, 0.10581334346845266, 0.15027856514338525, 0.11386494287439894, 0.10153265865219217, 0.12236788298093504, 0.17045160605301782, 0.14199582168892508, 0.09845675434917213, 0.10917017221330635, 0.13524857890461722, 0.1871011787725072, 0.1772612083943621, 0.15221453061507595, 0.13418275141908279, 0.16359527234829244, 0.16479282099152767, 0.13405141330534412, 0.11334441677336732, 0.1141461048034891, 0.09556360032048919, 0.1233050996257413, 0.18688581613523347, 0.16451557377173057, 0.1503215426759374, 0.18627188859447358, 0.08251459487984258, 0.12111444822362355, 0.19346553081225967, 0.14797573548651513, 0.12663035022635616, 0.12788160163308346, 0.10981700323041409, 0.26330766778799797, 0.1145163091320184, 0.14210917205820162, 0.23010581551540285, 0.16933926170872104, 0.09892291119021755, 0.13323965121901807, 0.177223501546729, 0.08735670723141202, 0.20444701816285812, 0.16010034859420794, 0.22681036573504249, 0.20524292222915158, 0.1694783679540119, 0.1634556145196961, 0.13337998320498776, 0.15855102769790158, 0.12129528327814995, 0.15235314656409527, 0.14519626124491616, 0.08619214633419629, 0.08488924527961401, 0.17977026892044853, 0.1424925837425455], [0.026444792071537628, 0.045708157197241826, 0.04792587065528478, 0.06338358676481633, 0.015703299000198324, 0.07684068724272713, 0.0696325736240514, 0.03506469082147364, 0.03991201257092818, 0.013983375111204243, 0.002805048889938682, 0.01799824178188799, 0.01309810784615336, 0.033618749660109325, 0.04567500474231859, 0.025302842259407047, 0.04156943230379013, 0.07303721391625943, 0.06102405511023057, 0.028630134484340108, 0.02330270351751918, 0.03609388015202938, 0.056908366480661984, 0.060391925320389776, 0.004613246457020362, 0.05796650244343666, 0.037754333593071475, 0.051113240751287634, 0.05188906182264609, 0.013244038019629737, 0.059727451298385865, 0.013826361560683339, 0.04829563065281799, 0.041734217816302856, 0.03199942939494166, 0.030248648441967466, 0.007671144820990102, 0.05538946310538919, 0.0142089803440256, 0.032699827194934895, 0.028497798541080088, 0.020340544119056676, 0.01351652783341706, 0.08885958787774847, 0.018554345006123185, 0.016155976524216034, 0.024795268789955208, 0.08825554287121182, 0.03208394038430866, 0.0745197089629308, 0.021624957556806264, 0.00701206693080284, 0.07543891488063721, 0.03471438179633791, 0.02166638184609192, 0.03285285325780992, 0.007879956927706279, 0.05283346054174247, 0.048608830378901575, 0.07743222969433955, 0.15810842806052777, 0.008359634741810302, 0.04348620344253798, 0.03603360052370737, 0.05043762014998544, 0.03989508585824121, 0.014564045817561209, 0.024889769565854824, 0.04896087076274618, 0.03250490378348097, 0.03429303726842327, 0.01958794317268316, 0.03468341652243849, 0.03390324790210974, 0.07057236432428322, 0.03924230999884106, 0.029566506517209837, 0.014097872697147391, 0.011349744858190177, 0.0374487602722741, 0.034309523480553786, 0.013997492196428922, 0.04906047368422151, 0.09416270129863294, 0.0031690064896529, 0.029354646816969882, 0.04497717908253113, 0.010797436642009887, 0.0209413773019708, 0.02988639419087239, 0.034695283224385594, 0.010330094279901636, 0.04224089304766348, 0.058135677639755516, 0.04524696460594574, 0.05820290568555075, 0.026182765103576165, 0.042812815987535065, 0.05701807793229819, 0.028081550413081725, 0.01000935624864313, 0.019136514371982025, 0.04035719775504643, 0.015700571727187886, 0.04170788354390571, 0.022292643402432723, 0.028678170112412305, 0.03915316417753216, 0.00542755195525505, 0.018037063287450902, 0.02558522609873645, 0.0636935459389802, 0.07416133303195238, 0.027930479789633426, 0.025934068065497185, 0.04743665839815813, 0.032024465148307146, 0.011594127863645555, 0.03197122203756965, 0.04206211493921377, 0.04353879537853984, 0.04868470372692232, 0.06884953983488583, 0.055790157733304854, 0.057135676259114865, 0.09674801821670226, 0.02233127530123438, 0.04525759790633475, 0.06911450666525672, 0.041654835785588915, 0.03208585751933917, 0.025444989873757286, 0.035071256194984725, 0.059246937969639424, 0.05155051990802731, 0.03765379987476814, 0.052979722048246095, 0.0326513989468015, 0.05775342274817729, 0.020109463272796526, 0.06310915491814095, 0.0945026911194286, 0.0310948729935673, 0.07578089653003602, 0.01556880556182155, 0.030887052491908113, 0.0674758292734623, 0.07773843503767446, 0.05844892333111456, 0.04861405126810555, 0.018914921524664088, 0.06444921506749046, 0.04059935814791149, 0.009768216667937176, 0.028431394039803458, 0.07158324798388828, 0.060202517741990674, 0.02483070035645318, 0.035887078547309485, 0.03915886387168881, 0.027194571899129983, 0.04742113362637259, 0.011382169529585349, 0.026449377107764446, 0.06957535451698689, 0.011551897266819593, 0.030522243337585565, 0.003523391341948281, 0.030776810524384343, 0.08590853292374842, 0.07639689250819146, 0.0656510231595847, 0.04037625802260253, 0.1053838515954633, 0.021787195826970765, 0.04415077705597205, 0.019784260864159273, 0.04041971052966772, 0.09219240742705523, 0.05230988924121184, 0.049910176274997574, 0.08368651788201063, 0.018649060286641605, 0.044272960419015545, 0.05027493371838524, 0.034670212997063514, 0.009251683800210877, 0.05966415711408181, 0.06072903465059015, 0.02903121407143772, 0.06262204557236645, 0.030278409042605953, 0.04785410736897781, 0.0847692069627585, 0.06032215769312555, 0.01535225070021566, 0.03062457544729114, 0.045074353505286484, 0.02448602207756091, 0.04466824646618578, 0.024015958188101653, 0.01321417495473138, 0.02811556471691978, 0.028764703573899406, 0.05842579130624091, 0.008250682674829037, 0.03480543900701789, 0.023961757467458808, 0.09930991582692632, 0.06415011135921364, 0.02729814507127289, 0.09883881771876928, 0.025242464954874692, 0.04912096398672269, 0.06488806087403529, 0.028281920709677284, 0.06715492270286046, 0.045505821885120486, 0.03658183602496021, 0.013046907317343981, 0.05585000069151002, 0.036145188890758066, 0.01688254388770269, 0.05516250572738148, 0.026111555315794486, 0.024845300077070153, 0.047347493424651124, 0.011058976186529524, 0.03340149861610225, 0.02925513774126528, 0.08022894857511406, 0.06937506082918375, 0.026298603343386805, 0.04343459975995845, 0.04023275826306593, 0.047607599427142454, 0.014799673395651965, 0.04178142415419702, 0.010467504598050108, 0.011759372071302947, 0.021992702743098624, 0.07937928045829458, 0.03224643337870798, 0.04495223142927693, 0.03574585023846838, 0.07062546953919434, 0.030697851757248564, 0.03895896088872706, 0.05511362548737277, 0.015498693194991399, 0.023971911962895144, 0.015176392344367361, 0.04044363162510338, 0.04895655002685324, 0.03253244081391923, 0.04408665549670977, 0.020448058813570008, 0.025335165424152248, 0.02467105720913218, 0.0059005566647336374, 0.04376643457480016, 0.04338413754838609, 0.04917780388026469, 0.035862019811306274, 0.04349508623202001, 0.054047372823040334, 0.014539012937025439, 0.06591872492384526, 0.044371253330140345, 0.030045347859061537, 0.01668364831036137, 0.005315299006930042, 0.06269534103452198, 0.0010963347824966357, 0.012373734366959863, 0.024868870687280453, 0.05859505843311068, 0.016002407496524675, 0.008674820550837585, 0.004882117462975364, 0.013050205325858008, 0.012939775666792788, 0.08805730229904575, 0.037137923927436915, 0.04872311920588536, 0.02546924421744001, 0.02028325223363936, 0.10643130829257351, 0.07367724973347879, 0.04986462468701986, 0.032144716054561644, 0.04547551544683595, 0.029819788591515635, 0.004633143196828784, 0.06821799227186749, 0.007852570242023156, 0.019544199552206744, 0.02800319494018632, 0.027289767899820884, 0.028812965197909265, 0.02753519948812262, 0.028806853731493318, 0.053895357996225364, 0.05863979796788866, 0.039973245978715925, 0.04650409956793151, 0.01685938504975169, 0.09178368419769312, 0.021666944920716268, 0.00896176644375608, 0.012809372180321766, 0.13702510615750668, 0.04314642046548186, 0.02274159582391862, 0.02142917612687715, 0.055485285382958195, 0.10324246730775603, 0.027340896607887362, 0.06363522749574435, 0.07834261794003748, 0.03360456171175165, 0.0729737971578875, 0.04991845002457981, 0.04471513870803099, 0.03702392621386436, 0.019217959094432094, 0.02351007011208323, 0.016165364931728092, 0.06886328345224743, 0.05206277608991631, 0.02394209199044253, 0.0458202243692452, 0.08557723820089333, 0.05752739616699758, 0.036605596241931763, 0.03203479201352644, 0.03613802596866604, 0.10609755442748148, 0.02997685385297143, 0.027510952805319143, 0.07574315903888595, 0.041853493875673706, 0.02623751166186506, 0.02379519846140137, 0.01728572830137226, 0.07536905532282206, 0.048841625346892306, 0.02969814915089838, 0.009519153822874351, 0.039761277110946756, 0.03811762397808414, 0.03943574719972188, 0.0951481355173934, 0.19642241569536348, 0.15181037326974256, 0.20370118560329561, 0.1621195878232679, 0.22268807725800624, 0.2777176590696458, 0.10363825131207706, 0.20331524582880162, 0.1260248956180388, 0.14091525467172747, 0.17333439491208524, 0.17805502870150153, 0.1463468333766345, 0.06712738950286182, 0.11963834235024069, 0.10739356069074524, 0.18724434528379671, 0.1777739663638415, 0.0963334190929609, 0.17108372052110013, 0.14134938137665873, 0.12915113189768407, 0.10453763853518233, 0.05210667292797758, 0.10524771011043942, 0.12469583266084233, 0.1347395900877253, 0.1476791215639922, 0.18751066808979358, 0.14849836066845926, 0.16142964903866092, 0.2738200795025595, 0.15594162497549288, 0.09616561519402651, 0.15937993483197305, 0.0688209341117932, 0.09221579609138351, 0.17059871025623816, 0.14890679278441016, 0.10445828714798536, 0.13107764384438916, 0.13753915115469886, 0.11087490170593224, 0.29583018393285815, 0.16094281548453918, 0.12834528401013345, 0.22662557000594757, 0.0624792889181164, 0.1807029043594676, 0.15025310038078218, 0.09009434541146602, 0.1488069715278764, 0.14627993857908636, 0.14018475919240905, 0.163273117054374, 0.11056230718930883, 0.136425856861376, 0.10005348842711219, 0.16837848019936394, 0.19922501047051724, 0.10813177067546115, 0.1545184021515231, 0.10989628566969788, 0.1459248108609069, 0.12850708944062073, 0.13003037100838077, 0.07559401704178703, 0.11054480974111827, 0.10789230691208955, 0.11593532613328389, 0.15505590476095676, 0.21554490491267175, 0.07393306947403377, 0.1320182925630962, 0.08406610678761237, 0.20239820793992092, 0.23008709232653343, 0.1152120472022122, 0.16627319397464876, 0.08119690832832167, 0.1288156007086077, 0.08822731253120207, 0.17586679047634526, 0.17227690246316696, 0.12691397129768325, 0.1552388925225504, 0.12320699440615794, 0.16239190143683266, 0.14710605715311345, 0.10845887489737042, 0.21222261141144463, 0.13139291966874755, 0.1519519309963911, 0.12190784718240462, 0.14540017852860113, 0.127887393257791, 0.07135171323053299, 0.14313075030522962, 0.15075674190396263, 0.11714848764841596, 0.11140385477413094, 0.171710426408437, 0.13981518305597768, 0.12408258693833506, 0.1332435582674319, 0.16307606391849058, 0.15420951550045323, 0.1417756020542114, 0.1345016891437192, 0.1532117166225949, 0.2384684312968485, 0.16030988896325712, 0.1611513599392868, 0.08175331032684735, 0.14237491263737603, 0.2050361397766298, 0.0977609932963406, 0.09402283662629705, 0.12815019205933617, 0.14656259437962887, 0.14963192564825858, 0.18897657733290427, 0.07683823576136943, 0.16239637539031046, 0.14134104634004255, 0.13652805299047502, 0.20954933227790942, 0.11188321897099096, 0.0921923308182628, 0.1255204650242963, 0.18311070338372262, 0.1168800887441443, 0.16783409812037023, 0.12165658566499911, 0.25166113951033164, 0.14715029106986138, 0.13082776128524734, 0.1411673435640912, 0.10113460702761527, 0.24078293613368468, 0.19518452486203564, 0.14347993318111668, 0.12119644261415928, 0.10647750339440762, 0.19597555660913069, 0.11518466721979842, 0.17120436404741582, 0.13050171426467358, 0.11398238415319113, 0.1097295236503405, 0.14283459603546128, 0.1668093482693357, 0.10549332555984298, 0.16464412332542483, 0.1719449872090932, 0.16778500720618233, 0.16328563493105674, 0.22960784304286205, 0.08946908743030603, 0.08891202659616548, 0.13026580514927066, 0.07588082503887915, 0.12375981111319796, 0.1620393324523203, 0.12700810818181885, 0.07655971683561802, 0.11703861531831565, 0.12880895106542495, 0.23258286888801286, 0.2986833405110144, 0.12931024835955712, 0.11851367931212149, 0.12973944145825603, 0.11730881452920938, 0.09550494862900627], [0.011489920753745303, 0.014702670385069666, 0.10898668649456195, 0.02656574777868246, 0.03611597029732601, 0.01701947252806877, 0.05186250538475091, 0.06790463166731982, 0.01608596183359623, 0.050259749855726, 0.09454328611853624, 0.04648741417294068, 0.05450377736480967, 0.028743293331635576, 0.040953861504432656, 0.015465485198693651, 0.042366336114824786, 0.0171074787935903, 0.04381574765448609, 0.054589824360464854, 0.017851225678778945, 0.0225400687345574, 0.022952819671181422, 0.04125462762350517, 0.06690399826414163, 0.025100807636795987, 0.03875752956035637, 0.03315220594466214, 0.07217866684039755, 0.035956865326771816, 0.02724305568863788, 0.05302071541307434, 0.10291545501639766, 0.07032104151984377, 0.015632186888626987, 0.09541458855833738, 0.03651247442429585, 0.03832151061825214, 0.0763935370430831, 0.013277265168125591, 0.05128991211794558, 0.0733793334614846, 0.0627805721465378, 0.03818261121670085, 0.045690073691789186, 0.02464516726773112, 0.020601259161447807, 0.005454286029787674, 0.04187454597183293, 0.01143083239214555, 0.07706750289446886, 0.12695017661298477, 0.07324264039315524, 0.045475450329362385, 0.03306198376981962, 0.05759034944217532, 0.08856711083001668, 0.03361640543106102, 0.07915797297872844, 0.07824963018778833, 0.007186245638877154, 0.006617732269073567, 0.028841390890339692, 0.04885787024132667, 0.023339707479481737, 0.039697163212563724, 0.051467970103746465, 0.046104998402898355, 0.044324184888072556, 0.033896644224202445, 0.025104040527836453, 0.01760287721070551, 0.025820030132308606, 0.0064766653175015124, 0.03504917754100696, 0.045178487836833925, 0.026768676808945117, 0.0723021831964293, 0.021438108712074258, 0.04893384701121719, 0.04505728123589389, 0.03935171118486793, 0.05796803461928522, 0.028859131571446216, 0.054821328470303174, 0.0851341865716442, 0.11187682979770246, 0.062156313910119, 0.011664660621224152, 0.029644538317957235, 0.03324667607704478, 0.015715707709351857, 0.032577490614306544, 0.03484647833712159, 0.06644780822699109, 0.027749813274450363, 0.048560800496488817, 0.015515929215677805, 0.041722925680298964, 0.03910627959656619, 0.05227669848189239, 0.030031029675756733, 0.019256780599995006, 0.023320871292643493, 0.015231747942556058, 0.022211010988441207, 0.025067793077699123, 0.0855787703767419, 0.05142836718850079, 0.12345279371666333, 0.052782377798951445, 0.07173387619156031, 0.008075404630583382, 0.037230072813408996, 0.029967852319861134, 0.06522842607791386, 0.03274500339982971, 0.03355225322828178, 0.02371962197245129, 0.04696957842116395, 0.06260698811421472, 0.098592106763634, 0.017230299924830758, 0.034327561020730965, 0.015905325004320233, 0.1028429218117268, 0.05850837558447834, 0.03467737974959516, 0.008818056010040305, 0.009840413751531272, 0.010636692243297736, 0.010182301555159352, 0.043646932519491644, 0.04788594215267128, 0.03493622553745105, 0.08059725300559113, 0.0419007768223603, 0.03202259397855209, 0.01485583051333144, 0.025596248188747034, 0.05164851404486164, 0.025399807923203035, 0.07083614371837148, 0.0781608559191227, 0.013546704036754467, 0.031948074690937515, 0.01815082351376693, 0.03088919562287629, 0.05769385558162486, 0.051303238217388435, 0.03300714336576001, 0.05290181090634677, 0.05596556888532735, 0.006025188636305112, 0.01693386411775024, 0.08871926355265802, 0.05146186438298995, 0.02118105173952157, 0.04268224779216032, 0.020047839160167405, 0.03250822477463273, 0.04943913562343486, 0.06142168155600948, 0.04546413521072076, 0.014055045509350397, 0.055399150287191716, 0.016512017802245194, 0.051099558420959985, 0.043986175404561144, 0.04591573255076524, 0.04178047037473129, 0.02551792527458841, 0.04008672275249997, 0.01714983387970396, 0.03455823775561106, 0.03148341363656425, 0.06654987412114298, 0.052165424210890654, 0.025148513847060745, 0.0369852042997316, 0.03736109300065906, 0.022319751423633388, 0.011324465871908733, 0.029249447623207688, 0.020603160974719835, 0.03250809837012522, 0.09886783712934102, 0.103202301317886, 0.08181782259095101, 0.023804450888306867, 0.03791151951337534, 0.0513443426649657, 0.00984787640552367, 0.03796620286941048, 0.030617525523167946, 0.012061450115945792, 0.0613312142330312, 0.01731328065356901, 0.02827762678686169, 0.03678902833452148, 0.017917515266866937, 0.009560850073373126, 0.15012991344255788, 0.06881780081218289, 0.06766365871073739, 0.02720669715575153, 0.047397741131604686, 0.027768475176285834, 0.04602450554469421, 0.008160930686450053, 0.019914415372054906, 0.03438135188433432, 0.06305593479004118, 0.05143682862962446, 0.04826644653334253, 0.034921229366333253, 0.06529525958842809, 0.0830861117931143, 0.07814479105535053, 0.025644347019072984, 0.0503373162580594, 0.046455364884628404, 0.043103599980954206, 0.0069360825000330814, 0.023056366030246984, 0.04276347226433216, 0.040088978881436976, 0.05644816597322783, 0.045697531557732055, 0.0460889526913243, 0.025237694142326236, 0.013541302159278384, 0.039982979125793905, 0.06362179797443171, 0.06031325192100579, 0.008242036414993627, 0.04924399770736214, 0.029540610830149347, 0.024488779994088317, 0.02714389901337845, 0.07629470403997168, 0.037085247721763394, 0.022396890731949, 0.06059443300229408, 0.002937745612730543, 0.03211346349769062, 0.022871939938575513, 0.007705153379168723, 0.017286015584343867, 0.1255408812674784, 0.06061187682432994, 0.061110837550293055, 0.0146141565862983, 0.09285853619897559, 0.05646994202247551, 0.04561258389824822, 0.09030808394234027, 0.07265389416246645, 0.0351964081487348, 0.05053497077296338, 0.1260686698820322, 0.005056285158535767, 0.024653100108187047, 0.013294478206174269, 0.033878867153919516, 0.06425107408675455, 0.05079781553978401, 0.015781460078282943, 0.06468696279391166, 0.032403335846479864, 0.04809090131593328, 0.0615417045511065, 0.04144975021781941, 0.0219911954651076, 0.049289097303464535, 0.028033962946445234, 0.02722668438969601, 0.07624835572055272, 0.016492099516213905, 0.04415219048819235, 0.05730018214953523, 0.0910804461267206, 0.024633331209300988, 0.02146487965458824, 0.04092964546514615, 0.04320778793865635, 0.05486887954776326, 0.05412583554824514, 0.0820934227217109, 0.02541989666379748, 0.09310056635689351, 0.03596252288609263, 0.09363070686137484, 0.05362339678310579, 0.0455059138156714, 0.04064713905174886, 0.044061730826093305, 0.020963409990673105, 0.02732876369038657, 0.027274097571329727, 0.036489070438209086, 0.06533073712020152, 0.002586704016017217, 0.03149426144157206, 0.04482368570602229, 0.04809928997870415, 0.03229575028883354, 0.005486970692272148, 0.02733185102472142, 0.09110905184981324, 0.05937276791120249, 0.033515132437910766, 0.05427400078324061, 0.02156326258104415, 0.06097235183622088, 0.07778926497145046, 0.0782469948453288, 0.03719412030712251, 0.01194949689952116, 0.06537541536794556, 0.031281421148789026, 0.04463640785205268, 0.02535461256611011, 0.08346900253766969, 0.04289232825319614, 0.02624702072822519, 0.02473237871703121, 0.04566038778472332, 0.046441854924083724, 0.016308993010992007, 0.005758425329751786, 0.08447352766750321, 0.02353834067170899, 0.03838710689676866, 0.05966989128219505, 0.07650759221324999, 0.018090771796602397, 0.07939780446430368, 0.016249998495162978, 0.010265629896293245, 0.02957473430151661, 0.04590239496000352, 0.06998943270093973, 0.0476822393736051, 0.046133627108628714, 0.014135885022340283, 0.025243704102092215, 0.028319886111984813, 0.03469817520629975, 0.01486980491468022, 0.055025218940910794, 0.014955039857135666, 0.1624649096160166, 0.1320507440475687, 0.1301796355795476, 0.05995481470299344, 0.18736535653231606, 0.13216939574528125, 0.1978709500643515, 0.11096148496313442, 0.12038078114029863, 0.09365005824234217, 0.183285448039251, 0.22874329749855304, 0.20248661448638286, 0.13490174025777849, 0.07648574338564951, 0.11903787497431041, 0.11441180707826731, 0.17499855238824122, 0.19208854905539946, 0.0959995273320425, 0.12362841937330463, 0.1933231303888944, 0.11750282629603341, 0.1260275769257738, 0.14855040868203487, 0.13715845142160693, 0.22873540679293297, 0.25160075646013985, 0.15081603710930194, 0.17594206627578507, 0.13370981469990748, 0.10651094313230246, 0.23264611710704144, 0.1682805894843994, 0.11271707503305328, 0.14895055172664506, 0.09740041103214027, 0.18920657224953177, 0.13087820051418197, 0.13065369078709235, 0.15650088448197613, 0.14439635819965793, 0.14188617918520205, 0.14937353951315727, 0.1282277814443073, 0.08786639318831506, 0.13888674577878368, 0.09579801556443977, 0.15797037901657243, 0.11381323960038925, 0.16796810222008537, 0.2753969948858984, 0.17991715861905008, 0.13046618310674546, 0.14241559190615533, 0.1508349288375147, 0.12464145573997691, 0.14252753267365117, 0.14824254858878352, 0.18183251632557762, 0.10907510070190315, 0.1051065507495115, 0.10105966830686217, 0.10962725091244906, 0.17991876740369106, 0.13493768510318574, 0.23461105602402843, 0.10062100636141916, 0.13568649008389444, 0.16204431202382813, 0.12341081209841276, 0.12347190761037412, 0.050229746022171555, 0.12023025252405675, 0.12376017117452238, 0.15193428033061568, 0.12325135855785302, 0.14861333514413527, 0.1884214087359367, 0.17337806192376923, 0.16380297410632336, 0.09726091408200803, 0.10625025107254905, 0.1922340444739788, 0.1684278315834461, 0.15691434213471028, 0.261923469482891, 0.16926796956648751, 0.14227682273955117, 0.16121830070211043, 0.14794037286793033, 0.12029387612616825, 0.17745266908839827, 0.09891047758320648, 0.17933286335920134, 0.12698133340886525, 0.14382920798755464, 0.12681174452506727, 0.08118501864373684, 0.12034384804146907, 0.12243170576590685, 0.12099000490120343, 0.10540431380392083, 0.10976218963943182, 0.1026716628562539, 0.17107654993812885, 0.10189647380743297, 0.25893143648582123, 0.11969959107978691, 0.16997022704491693, 0.17249241831802553, 0.16092412293918673, 0.14414809974691561, 0.1501505365294795, 0.20854591031468686, 0.21472445538928434, 0.16127791766437793, 0.16276883201733713, 0.13169603001686836, 0.10170489820020814, 0.13574816016179903, 0.20324697207298972, 0.1272141322072956, 0.1318306623086814, 0.0826874856025942, 0.24039785437766584, 0.16026801459731596, 0.11620944771434992, 0.0929328314058723, 0.15272376458010367, 0.12610201002849689, 0.09284528287788553, 0.15062474495460912, 0.18934693487901844, 0.11334786416902659, 0.1627049862497276, 0.10864714100476235, 0.09153184045346514, 0.16845925651010007, 0.11249762914714315, 0.12898303688533846, 0.14467454004672267, 0.10745652545724185, 0.18429663813402578, 0.13240181149974947, 0.11282097953822344, 0.09560381993651391, 0.17727542698623674, 0.12071963715096637, 0.15805342294756444, 0.11962131987656317, 0.07507214262600868, 0.1255001790160614, 0.09537862073029242, 0.08142277403103729, 0.2932757710016543, 0.08539697771231014, 0.13099472248746505, 0.16027673267789427, 0.12772112153470516, 0.0921374942446428, 0.22010775523320322, 0.1931466237311402, 0.09769920064436813, 0.1266466449165056, 0.16201173796528773, 0.1675862686768655, 0.11154500647417961, 0.09265897029470052, 0.13842834940841123, 0.14975526580406776, 0.09967491841844975, 0.11457811710574936, 0.10041073054796266, 0.11097555799830346, 0.16161032321472324], [0.04380401884836536, 0.04353245983140604, 0.008590659089086038, 0.052503893347156626, 0.020221319770620718, 0.017906475939878055, 0.03454645915377525, 0.0277393140394481, 0.05276250164775599, 0.006824794822492667, 0.06866903419816686, 0.051050930989966284, 0.06955775747736616, 0.03392281761813549, 0.04751386856960674, 0.05869111819793621, 0.007975990837064363, 0.0623390986584127, 0.07123785724322643, 0.002517156878433701, 0.007615540723030967, 0.004652346627065732, 0.016914189064634905, 0.03440761720881828, 0.028110769006513783, 0.0504144000250005, 0.022730131318131765, 0.1433808780125072, 0.02538039717042158, 0.027593466220423583, 0.035701555034686486, 0.025661149242472266, 0.027666642938950853, 0.03610434108263543, 0.024259284949831428, 0.04419972624389395, 0.010924349640375905, 0.0436234251115351, 0.03287305116593357, 0.026441804328632933, 0.03369027545915977, 0.04285602717690411, 0.09646330163964341, 0.018229525641448075, 0.056705491076554024, 0.04763515560977882, 0.024172276513831272, 0.01732779035885488, 0.05618055230907856, 0.020139942080864025, 0.03376638629443703, 0.017902649330696272, 0.01823728802734085, 0.05945116551893373, 0.07694840686576021, 0.0791130955481241, 0.050470355086989944, 0.0500671936559581, 0.014360095017529545, 0.058995492591132084, 0.028875106419887275, 0.018282563823665825, 0.021177569869905714, 0.04701855825260282, 0.03835846286927981, 0.042666439567842794, 0.03464875487430442, 0.07153442520047389, 0.03333368068260532, 0.03854584031467957, 0.02402208114583646, 0.03620574814117244, 0.04932498086183783, 0.016199352422488794, 0.08119634908413695, 0.043689097998844045, 0.16985290834019262, 0.0936053187075642, 0.08169541706240947, 0.06996672585486405, 0.026028300710623304, 0.026816978652571, 0.07668757691018044, 0.06768692480099779, 0.05671468413164539, 0.1269510576140977, 0.04653760825373954, 0.02365374607184241, 0.029830651718281934, 0.06879832685714768, 0.03841875398892068, 0.02733999453935652, 0.035239787877447186, 0.10224788599917967, 0.02421286193683984, 0.027657693116775448, 0.06886338304367758, 0.03580511480029072, 0.03567870646234482, 0.04200602964227719, 0.04265566071074817, 0.042810540706399954, 0.02306212318099795, 0.01692698847862982, 0.03910501172105151, 0.01542356774030674, 0.02273132258485402, 0.06023681166792109, 0.09204993039489755, 0.11169298401763363, 0.01729681933929603, 0.06224635988473893, 0.06331826627795255, 0.012528526262500355, 0.08344983501780419, 0.012595098345510423, 0.024538633165760868, 0.040906781571046005, 0.051682708379361904, 0.09099241496334154, 0.01418596993560993, 0.04758601489987585, 0.006168925883098236, 0.060749952681362636, 0.004541566003970201, 0.005785722478908757, 0.03975024927527674, 0.08369674515579978, 0.05794058568895825, 0.034282618472653056, 0.003667691423963275, 0.03106602786799833, 0.08414421711237201, 0.0537224596125945, 0.01955983540674131, 0.059068749748891404, 0.009194534598669458, 0.036397438661585894, 0.021278946284925746, 0.07458361601757427, 0.054293080202994816, 0.04826611328509547, 0.006489785530814722, 0.01786043980128823, 0.051281010176265435, 0.044317408840382294, 0.0635137680857893, 0.05227662570353958, 0.013744635300921097, 0.019571460790992267, 0.006425807613038248, 0.03966169717210916, 0.022829644224275986, 0.0497227413730035, 0.11741369196604337, 0.03397547850205052, 0.031020671632441304, 0.035164810852297855, 0.05571506196452726, 0.10397024317494324, 0.028382169060228814, 0.04647596115847269, 0.04541873300988828, 0.017781595947341095, 0.010371925553397067, 0.03587608135515644, 0.0401678208201643, 0.057507654081188866, 0.022914013487376997, 0.06809950145261903, 0.027002481097776084, 0.06527566305932499, 0.042795889274848085, 0.01932790994854464, 0.017684143817713185, 0.03065885596668288, 0.07150553602484927, 0.03877617230999374, 0.031201359215042287, 0.023532483929527864, 0.030114527513843872, 0.017180178622384707, 0.00812715770030815, 0.049870918099317825, 0.09268118684450466, 0.04511961781029259, 0.10368901995881911, 0.0408519258452279, 0.09692830168792317, 0.05876538276131596, 0.05830803210096014, 0.03577874605393699, 0.00769176934432659, 0.07988861401475246, 0.05024510225461376, 0.03957479215797879, 0.05533053562225354, 0.02695332315089482, 0.04047681089310397, 0.034354895037869294, 0.024549666747090318, 0.08345681407879438, 0.025528215750631307, 0.032778389511569854, 0.022347989424522367, 0.007503239894210692, 0.047553927307167364, 0.06160657687653458, 0.023452718854851784, 0.033387402598295486, 0.028954865748903928, 0.02237432752735913, 0.018991198984064886, 0.01682393050061599, 0.04954029370339648, 0.029160809335148627, 0.056655013543223186, 0.02584681448136126, 0.08028425246236787, 0.09438549498877219, 0.09177335733247381, 0.08515703897442549, 0.03983846813019726, 0.029995793461679455, 0.023320737227256742, 0.022880060470572883, 0.049783292962538625, 0.023084952601141507, 0.020261112292627656, 0.05813323381927706, 0.05178764710322984, 0.059824771277846835, 0.050704295356427474, 0.10556566724253279, 0.03155523629468535, 0.045693570883163524, 0.014686929193445513, 0.08688400799949324, 0.041738029103726156, 0.054305004361536235, 0.03587574044603013, 0.05459306108194494, 0.11171752181384834, 0.08332765165476069, 0.03640813324900885, 0.03200253971191424, 0.0431791439111675, 0.04801093322795726, 0.009150688513933171, 0.08184259787442223, 0.05859448769760709, 0.04725316884897409, 0.02909092487947595, 0.05486986780118558, 0.05185036289115107, 0.06877978752938009, 0.08190085120018452, 0.00815022365009833, 0.017508077660515424, 0.060650740464728695, 0.0177522815929185, 0.04543668244995418, 0.017213028472577854, 0.03722448420200137, 0.04970586062559197, 0.04989385094133116, 0.028966460489637913, 0.030937997338872765, 0.043299274158573924, 0.0020753051343959787, 0.039996446951502757, 0.03770746050342437, 0.09151927661150695, 0.04885135083309105, 0.05700779320191472, 0.10215004124949056, 0.05406334575626159, 0.05364767410942624, 0.05338106785089739, 0.024347187793483178, 0.05542652643916588, 0.03170331917522896, 0.0949974230400497, 0.08842950611705742, 0.049189099846708204, 0.05366290010692132, 0.018932118283344374, 0.02065930181303092, 0.04108524558344676, 0.041659608513357184, 0.10226558263023054, 0.0033253372643112897, 0.00900484165251856, 0.02040480165892551, 0.032315733692338394, 0.02531766223030225, 0.033465202657445785, 0.06473815278901209, 0.010970326407151598, 0.03765804783230828, 0.03925125790579666, 0.041232016538420034, 0.041850211188918164, 0.0453156826927537, 0.03976729090115236, 0.04091942202179663, 0.07210601106165879, 0.04482082053718548, 0.091217361360548, 0.05344100273965348, 0.029400899375398314, 0.07220892731340663, 0.10644097632217793, 0.06150683605923288, 0.04716551689911754, 0.01222782813373112, 0.07432500005609567, 0.03954009986632774, 0.04488041451681526, 0.044642368016103585, 0.013266947879005345, 0.07692782208323479, 0.02319336744896587, 0.035370271803150256, 0.024478234793810595, 0.07129894509430855, 0.03714025283472673, 0.006590164595118334, 0.022369487766897487, 0.0828591735673047, 0.038064200836684436, 0.03185043678498797, 0.05862895399332047, 0.018747452789196567, 0.046046714433619094, 0.05123045603414217, 0.018993847733063084, 0.048684952705497705, 0.022988609383783998, 0.008548036829808788, 0.022108606100382826, 0.018088373941399397, 0.03645378442841672, 0.04573295163291116, 0.010127897821216574, 0.053614881715827414, 0.040385010577137434, 0.014495377526468328, 0.05652952834122604, 0.051820623357930494, 0.02774115265046637, 0.017949168104678392, 0.1586025547716887, 0.16683610005965158, 0.1803568624440701, 0.17476432866627173, 0.12293283452069569, 0.09745058979118064, 0.11938009411096574, 0.1197541212182372, 0.2572511605197384, 0.14106882465702875, 0.30617568041047744, 0.1825477360116859, 0.1776041553145455, 0.12260452754074529, 0.13770134729002753, 0.10797658424463966, 0.10202377463781065, 0.19205269614054313, 0.0938733498896322, 0.12091267598612655, 0.14491674640486318, 0.12628210197773673, 0.21526997127840597, 0.19102180226435586, 0.12743018432370118, 0.2003464252958375, 0.2402410668230826, 0.21286735100851906, 0.1395155507470331, 0.13323329268924652, 0.12260664960429554, 0.17225335292037458, 0.11699615106467279, 0.16014228424718305, 0.07687923678707692, 0.08478141840427153, 0.09845332227527134, 0.13911635765144903, 0.12412666763749816, 0.17940076939280958, 0.1803498297569252, 0.1404194885324086, 0.16807820437656296, 0.14505625101587466, 0.17263633559548086, 0.2321910149147434, 0.1651630866070909, 0.10889763643424358, 0.12297926710978632, 0.11532314527299135, 0.12984128518690988, 0.1363374043496386, 0.10117959171052902, 0.15954167131454716, 0.2708661670406019, 0.13360672990881628, 0.12065271170990122, 0.21369445017508923, 0.11203221541138426, 0.11340702147853952, 0.09497702211862612, 0.1769824749639919, 0.13108041708267507, 0.14045892673875057, 0.0661090135033573, 0.14102773170077032, 0.12607305190495907, 0.1281081568149309, 0.10397156850705225, 0.08203182925259875, 0.12784793972969055, 0.07960474779528957, 0.07454704298006912, 0.14573387110665922, 0.1654623818373488, 0.09010307115292357, 0.363593970335299, 0.22478436961049036, 0.23010517200154645, 0.20322614980320777, 0.13905191433525857, 0.07879067212343216, 0.15450075148574768, 0.19498089869176188, 0.09779644018459706, 0.16644953209305965, 0.1898212811999744, 0.1321690433448361, 0.1694831636644179, 0.17246179012281282, 0.1278285423834478, 0.1593461503545123, 0.08450653839616046, 0.18099948763847354, 0.128545937759261, 0.0766584885516955, 0.2255055801041665, 0.15215923438870138, 0.20880271830866415, 0.15634078742756, 0.12544111363709937, 0.15267079726101893, 0.16706756586509366, 0.1190301604689129, 0.14275757355555413, 0.12968317996109688, 0.11026115036539494, 0.15127765104895638, 0.1463928446173668, 0.18991123524404344, 0.06365301988778577, 0.13638684766427164, 0.1304899931194321, 0.09963279890437281, 0.22621939018849405, 0.21052096159227435, 0.06806395497293243, 0.13103774598529264, 0.17848762323058423, 0.1843335329284591, 0.12706901217179914, 0.16536712646484375, 0.130038644757963, 0.09582512741608006, 0.11295233297372058, 0.18839753743621612, 0.16320939386083236, 0.216621043941667, 0.15289663998109682, 0.13248278699334592, 0.14622629710262822, 0.15235846321428978, 0.20972442933388297, 0.19242412620975127, 0.19980518417733334, 0.14253289528912114, 0.20835766718993265, 0.22088751016605288, 0.12638095030260663, 0.19755683869363802, 0.22546822565697858, 0.1587872738919912, 0.10298356789374545, 0.13982364066666172, 0.1419743865488037, 0.11335288970580987, 0.13343504960498503, 0.218439583456324, 0.06562247106264676, 0.13020169891176686, 0.12836690301135664, 0.1090696844602785, 0.17301960938399838, 0.17931115242742723, 0.27987612711806453, 0.13890255783354083, 0.1517119309714725, 0.10700810355164352, 0.1661927547425993, 0.18212505466034337, 0.15628607342800788, 0.19815818707068122, 0.15541284044663753, 0.12847815429972065, 0.08661328018793175, 0.1446239476002032, 0.13979318101079236, 0.22783903795624935, 0.08987019574570079, 0.1514546786464991, 0.21591146266268146, 0.07277589366440812, 0.1923697799324028, 0.136246454391268, 0.13572067292707582, 0.17044259685902827], [0.03525280754172033, 0.024071108857770602, 0.0357070517155432, 0.084360882099117, 0.07337998463622025, 0.029583691784571257, 0.02144865008191236, 0.07800395345135082, 0.04752079017400261, 0.03978851919753417, 0.09628897067159416, 0.03934525306366625, 0.04573290566763571, 0.017762133483624747, 0.043157865819070614, 0.02792644633671209, 0.02922135517902432, 0.03508270154857347, 0.025114804063172593, 0.041009000682782744, 0.02580239670351148, 0.014942731697022196, 0.08276465363920697, 0.010985782231023956, 0.03937220786728206, 0.0062099216419512476, 0.03747845767065883, 0.037159657841848756, 0.018849798305440816, 0.06246162676102212, 0.01967960367760351, 0.048019249112375324, 0.035383176554234765, 0.09576731842131385, 0.1084667272985943, 0.010164995628949857, 0.05097776576275787, 0.037218596816303275, 0.02248489316703091, 0.06571477699664331, 0.02736897181509243, 0.035667038943258025, 0.056836449976770155, 0.012913427987856971, 0.023205011985414935, 0.03558225982311753, 0.04152813633423179, 0.05846723666294448, 0.03834290362353768, 0.019668937818477714, 0.020601033165510145, 0.060397732266855825, 0.045716354338031624, 0.023720428279991594, 0.03276114104195468, 0.10101610088660833, 0.02415482311569635, 0.02562980475505033, 0.02167348539636981, 0.03346006220747386, 0.023440137775915287, 0.04262408639694895, 0.06990154709426627, 0.09011665389182107, 0.1947780539311709, 0.027633274064189004, 0.031123735356114568, 0.06753629659332576, 0.055109442647306196, 0.023566235848251852, 0.04140730511637465, 0.02557828725736228, 0.04731806032660027, 0.013993111131111942, 0.05112120423526053, 0.046579042119124246, 0.02242267533626047, 0.026480491768809098, 0.046976641751825816, 0.03782063850291795, 0.028725776731246905, 0.043466798435415954, 0.06909781360938665, 0.03601170956127105, 0.022585783116219026, 0.04256393317313444, 0.02466078013962796, 0.057628347403219635, 0.03274151386933462, 0.026494064931607535, 0.04336194398121969, 0.05069581476310569, 0.028231695985361457, 0.02363754522746369, 0.06404641752822265, 0.016176197414977417, 0.04713708737624749, 0.037604168868593635, 0.013185717661174075, 0.024502017993419885, 0.028648014976492817, 0.06984139387045177, 0.037628856051953576, 0.03298345975758087, 0.01223284313680544, 0.020769501645718853, 0.057260230664284005, 0.04857214242820779, 0.0609061541786838, 0.04558056142301329, 0.05911669153119287, 0.05495963415371315, 0.017781406340579835, 0.021016172381238114, 0.056726681068539626, 0.03734148114979748, 0.0203203423804934, 0.03599007140784975, 0.057405982722317984, 0.057378143087149634, 0.03140190762708024, 0.027609163361992088, 0.0421289139757714, 0.07001954761724319, 0.05107729590588039, 0.01317163504990599, 0.059273559525008165, 0.07574636128640945, 0.02937080744173258, 0.006273563438650942, 0.011953764009259403, 0.05759465102587016, 0.05386358833000545, 0.013973784648002157, 0.03200074706617142, 0.03293364105986492, 0.020573984516123613, 0.027434460841299548, 0.004392026119955606, 0.014446211918707819, 0.03083052286397546, 0.016107329941024224, 0.022509170493351358, 0.018013002380969066, 0.030765698419042656, 0.008357638125157645, 0.03936096552699324, 0.07689798295858406, 0.045654967712659034, 0.009550613223484928, 0.06061229051180905, 0.04815491945332578, 0.07676138948168486, 0.024836806077209693, 0.0651390006345126, 0.0574285363508088, 0.03593578641753524, 0.026550355157063856, 0.037995252923499194, 0.023753622869750666, 0.025424334228098876, 0.04052226288965152, 0.027043857506566474, 0.027164640843928344, 0.012524903624228412, 0.025539140164431547, 0.0229363143068528, 0.0030677629430072326, 0.007481363774727911, 0.020615627140467687, 0.026815906129477006, 0.036749682058730436, 0.04300925625307907, 0.06038018502295018, 0.03923504748531888, 0.10603072091696725, 0.09225744829182664, 0.025795505742632577, 0.022990463316560756, 0.03588766460457156, 0.021401740603088852, 0.02653310477222887, 0.026854312032341, 0.018124238347574588, 0.045726685033690546, 0.04078384361139709, 0.04743067142102988, 0.015544912237073145, 0.05470769081805503, 0.03204302171305303, 0.014181088997922359, 0.05205496965396789, 0.005564476286376557, 0.01982197345745179, 0.016279048549251694, 0.062234715348289865, 0.0780060448713841, 0.013358074037598507, 0.046182878901280706, 0.023484216559858575, 0.018048108360099218, 0.04016179170820021, 0.051753847304010586, 0.0241204334287754, 0.04264486653189506, 0.038698119441828424, 0.023357997828673933, 0.042902406139840046, 0.11431917938734255, 0.040812993256915966, 0.042912729174619725, 0.024558344608052604, 0.030159464316262357, 0.0404083609370695, 0.05573601446925633, 0.03750800951233795, 0.0637394346056446, 0.02002633698735266, 0.01392062484932643, 0.03719010217595966, 0.0316004354822179, 0.01834428561250529, 0.015401914265126953, 0.005537672785125794, 0.047104126443305326, 0.03943648647456881, 0.04536424883671346, 0.04440313407910928, 0.011615410743791972, 0.036041809155816035, 0.028357732770664078, 0.039605133070219914, 0.052364304466473485, 0.02283629386745874, 0.027245520576534253, 0.019192858223593044, 0.015253691573537167, 0.05936652812505922, 0.044312187951178326, 0.034825973993828224, 0.06352693713720768, 0.044852138211530064, 0.04585712299411816, 0.027901109893836325, 0.04673836542473686, 0.03510213719921247, 0.028023050023963856, 0.03886973079774649, 0.02667349804523251, 0.014096888274164691, 0.058393584969904155, 0.0159125674080344, 0.040133281746098114, 0.02871418390573273, 0.01607150766968487, 0.06637154417412897, 0.045423053745781226, 0.05462942727571053, 0.0653189929923223, 0.03387272695920641, 0.040457524629610206, 0.020589882755772244, 0.06681769845947143, 0.03368465237379555, 0.020011999651849754, 0.04680943923191198, 0.018636613273091854, 0.02204721755979042, 0.019636114781361916, 0.07989979123756771, 0.04540427310031749, 0.028521823058385524, 0.070608263204415, 0.039755631042944814, 0.05404386030990751, 0.005831087332954931, 0.03943566676048983, 0.07353431304856654, 0.05687303067515454, 0.037694203351894696, 0.013524744126404966, 0.020301429584862727, 0.03044532619476799, 0.05798396158723101, 0.05778903434533746, 0.02144608943302545, 0.04895612101761564, 0.021907276278662107, 0.03270672581669304, 0.07350281917399938, 0.02794138505123556, 0.041304078599017476, 0.023047303210102746, 0.013644893526009495, 0.04243184046279039, 0.048277179425161694, 0.046295083969110445, 0.012601639778773873, 0.048387706760437264, 0.013908515872073271, 0.035284443142553495, 0.04609182169060073, 0.05761571078290863, 0.04743761217762386, 0.022210647096677173, 0.0464021907218041, 0.049686689275286855, 0.05708547834787638, 0.052427682920449206, 0.018271091656999725, 0.024071015011999878, 0.0581432274362493, 0.018228426305276733, 0.015981831332488407, 0.03319207316024169, 0.04067784385575403, 0.046684842691907, 0.012560178142701908, 0.02374248586655144, 0.017016231976149064, 0.03574549400758359, 0.00896767106643247, 0.0561084327918868, 0.04366253390006962, 0.020896488380047585, 0.06917927173837539, 0.0322742308790405, 0.05269793192705801, 0.034137008140885064, 0.022062552724814704, 0.039588968615017595, 0.01549728838126025, 0.05983939206588173, 0.006861228048951636, 0.01455540530338523, 0.04331993554989177, 0.04613866030629124, 0.0360677182494152, 0.06597341594075964, 0.0510291357885205, 0.02276704909520284, 0.005619574287500714, 0.04030808385822081, 0.028241101629851807, 0.05297324094440668, 0.04986076360388149, 0.030086203328063412, 0.007245618889423749, 0.025464345085164233, 0.026963071619731285, 0.024723806193158514, 0.07599940778867853, 0.12437829687710732, 0.11362675081698165, 0.1607377184254508, 0.15738445965032424, 0.14578899879369045, 0.09039293584083358, 0.07531652467385416, 0.10969196235941303, 0.1220671475053795, 0.15981905643017064, 0.15697264142574804, 0.15165073586808098, 0.08578578265564096, 0.12607875159911572, 0.14932876933486233, 0.26089219256274165, 0.11365532589655732, 0.1000143489950607, 0.1258998087817623, 0.1345007545164516, 0.14976525559060036, 0.11402662573081833, 0.21550335230365877, 0.0576136653281508, 0.15340585862436604, 0.13198758775909103, 0.15008961721774072, 0.14234347238896355, 0.1184967870733911, 0.1754048854232796, 0.10046987253571711, 0.12286800049966383, 0.15853544546952172, 0.15404846849701098, 0.1259154906015723, 0.07838507453280111, 0.13446644909920233, 0.1491823699325323, 0.19029555091213798, 0.1497250819398511, 0.08766024658877043, 0.16404096698088033, 0.1325602997695246, 0.10153062851919283, 0.11914092146100537, 0.12173189976883513, 0.2899949841441647, 0.14988257429532467, 0.12887367017326817, 0.1661027853767718, 0.15733375995149537, 0.12897344546452646, 0.08522444705088293, 0.09905198168370033, 0.11351212108087157, 0.13561884452018047, 0.1441153265055149, 0.09855429266369152, 0.10506345064289148, 0.09438018599945693, 0.15218037841541154, 0.18093207190113683, 0.18459720507023797, 0.1959321041020655, 0.2569190920480798, 0.18270941120722603, 0.15738753932377986, 0.21870613608869816, 0.1888625221627374, 0.15563620104184075, 0.09465898071686107, 0.15194411689956344, 0.1276262338844038, 0.131891765481522, 0.13561495279352512, 0.1599821105839745, 0.1247865298101979, 0.11090677862446155, 0.17518952278600586, 0.18505365557728276, 0.0700976349593651, 0.1738519945572461, 0.21410810701068372, 0.07305097285537951, 0.16460214170717424, 0.14789606234238994, 0.1235210138463205, 0.18514434506575908, 0.122717157787373, 0.19421157787644094, 0.16971502783558062, 0.17681287841931467, 0.11030667130985569, 0.22548763832497984, 0.19163346218485988, 0.08937448323253663, 0.10977996287927513, 0.25379012849542404, 0.10775461792945863, 0.08109033017629579, 0.1464436209249881, 0.15221367259660076, 0.17831290921857282, 0.1582008335859545, 0.1014286622164711, 0.09239545137050653, 0.15681320320694678, 0.23855974897742274, 0.21244433257848988, 0.13638364541674816, 0.16046889817282078, 0.1527417370028073, 0.13975836997551305, 0.10854657664294205, 0.14046568363424272, 0.14144454481861285, 0.14058629651704144, 0.13732581098954524, 0.23595682735885345, 0.11651612037131864, 0.13583241451171138, 0.11028417130751957, 0.13162234768031106, 0.17141087070828484, 0.20820256502878284, 0.16432926118854554, 0.1679945782187485, 0.18887350786357157, 0.09348998417056377, 0.10303599895128321, 0.15259049592479584, 0.1328202180804745, 0.16733356691416235, 0.06409851533751335, 0.08493883415095269, 0.12273517617535208, 0.08955570899190442, 0.0881931679924169, 0.11085889812919403, 0.07247228535913652, 0.12240135336234687, 0.09219970058409438, 0.08693406418446573, 0.09767339880307836, 0.12080932306426188, 0.1273506720580401, 0.2053659712715495, 0.2322713928597589, 0.1750037771078848, 0.1626038473219641, 0.12582873114414755, 0.14800521454984142, 0.14389722127347224, 0.2007891168637622, 0.14538376892526306, 0.11890640662562464, 0.2618059515953064, 0.12606259480479265, 0.16756723905282636, 0.1033891654843765, 0.11716271390116985, 0.15755779470407194, 0.11862867677043523, 0.09630208609685784, 0.08945951899213177, 0.07039499198717457, 0.11790767312049867, 0.11586805595265282, 0.15555994464985787, 0.16312026719172157, 0.07896189277450885, 0.07737121845204985, 0.13808359452072652, 0.15688201322430567, 0.13144190333062603, 0.14705161894521407], [0.04565244728338815, 0.1323027716528985, 0.01576002781099129, 0.0563097606983877, 0.04571289162061388, 0.047091237013979305, 0.07338762253282533, 0.0324827523511504, 0.06346584545568594, 0.06651039761040481, 0.04125899432467357, 0.054429497479671435, 0.04737886089471079, 0.04084877722385911, 0.05693163257092238, 0.025008911559838923, 0.044419463243215315, 0.022831660950736656, 0.07901907357717715, 0.06228742602791998, 0.031387413243552854, 0.04564872409607615, 0.05325008213760392, 0.09643347783675117, 0.04825055403935333, 0.059989614246953885, 0.012121803480230514, 0.03197082941750846, 0.04413003139498253, 0.017403058497415438, 0.11248603057596954, 0.05887274232302463, 0.049068605707537745, 0.027493179565475836, 0.022092589117105932, 0.04342122386480051, 0.05569742662051032, 0.05658832941985419, 0.0381475052375707, 0.03525411372163123, 0.050461817037073836, 0.04201664762090772, 0.029156607342883948, 0.045548067803704934, 0.06721873782695302, 0.019225305877625942, 0.03628138017149703, 0.007032599044783462, 0.044596015866244995, 0.06623647521219908, 0.07854052143351686, 0.03038145744452073, 0.05762137983354831, 0.016042194272872182, 0.05223088642402042, 0.08733911019179129, 0.04131299969289572, 0.006216467863264224, 0.02492081527898629, 0.07260890181867347, 0.03625991438785869, 0.010693860597037261, 0.021088176985241232, 0.021573581785384207, 0.036376241008721055, 0.052351732963636044, 0.035596735054446806, 0.08470265690477626, 0.007469298368725445, 0.033513424061839624, 0.10109031948471263, 0.07185393749105354, 0.03832912170177987, 0.0354198185396531, 0.012337865172735146, 0.03357209490552064, 0.008051249878330818, 0.036582663399918426, 0.041586255594607324, 0.02048695501270554, 0.026106907077313914, 0.04991643138289933, 0.052326685718951695, 0.022485975266223954, 0.04525743319743103, 0.10516258242029337, 0.01206670069105683, 0.0680820652914624, 0.061031367419467825, 0.0645826829056586, 0.10745161483364721, 0.02379546850739468, 0.013511562626057816, 0.03960540120099341, 0.018117812785109686, 0.0367231524339126, 0.03198344497040155, 0.0752653806440292, 0.058967269912001595, 0.07365724717777583, 0.011432180706892284, 0.04420685469202938, 0.009729407611303031, 0.026359786955459465, 0.06480426617687748, 0.08545880866867882, 0.025592063433460654, 0.04100327034510913, 0.005046842167259104, 0.04087042303815965, 0.05766334996048001, 0.0047958506958469035, 0.032862540439612446, 0.06086968839348805, 0.037422127225586486, 0.03950147371318552, 0.004270944487108219, 0.06017457085451292, 0.04100096825089666, 0.013963010578957057, 0.06698875057120478, 0.05176267646733792, 0.02408214435431986, 0.02230569179500303, 0.04944401560351253, 0.05281251186745302, 0.014778200908744288, 0.02810868716257955, 0.04396141161240878, 0.014756037985094854, 0.03032013976706132, 0.024886387287669127, 0.06031780631371564, 0.010531234494861095, 0.05438223751562257, 0.018287675545340585, 0.020934817674119147, 0.03915409880479978, 0.006778873118286532, 0.0031167185947959947, 0.03202512972958146, 0.01530351984735218, 0.020529001748429674, 0.014320504551212636, 0.016492246988139326, 0.02639202202009338, 0.046506662132038225, 0.027266337100656766, 0.06502021104097366, 0.06784306118084539, 0.08112470454145825, 0.03026788874018577, 0.023098709625041774, 0.06043386097336489, 0.09895558484018811, 0.0838429683579072, 0.05254286040942516, 0.031623986940230095, 0.05156569994024692, 0.03369832704324396, 0.04805511734899014, 0.04533241022258036, 0.05881530105046207, 0.03021932259622601, 0.040048410695406704, 0.06593745577359392, 0.026259429437378724, 0.05549489212552867, 0.020570816742556713, 0.022123931689308058, 0.03573685636623733, 0.010999748013883589, 0.0396511098369956, 0.02599684897089197, 0.027319915374861132, 0.05793862450387209, 0.01664286370449249, 0.10858941627966781, 0.021546812758090037, 0.029591446509584788, 0.046529097016900785, 0.03590060766005228, 0.027961098408747106, 0.029605649779700947, 0.07124836796954756, 0.04006739818460999, 0.01853080886986948, 0.0201009041554625, 0.042707486558825745, 0.057034410926843845, 0.011545576083834374, 0.03066451161078388, 0.06740081394391675, 0.05190721810645154, 0.08820601528690708, 0.03666890191755468, 0.10520193635696366, 0.022438236497222416, 0.039359640194884235, 0.05120536282418236, 0.02497276561635156, 0.051895255643513896, 0.011310329634485947, 0.04291531855180379, 0.05298120442837958, 0.045605539719784455, 0.039688464284183524, 0.0849891278231817, 0.020241849011771625, 0.07217416990428202, 0.03038885593864947, 0.065103706963841, 0.03883167921054748, 0.014387881026543198, 0.05563226318167103, 0.03151049484468756, 0.021135651453908895, 0.051592164447591196, 0.0410334580397654, 0.019471049646756822, 0.07966211245905969, 0.01379837062314994, 0.006504328752447281, 0.028039254698782202, 0.01623159514800195, 0.04102609210437344, 0.038565505791695855, 0.042234794987786206, 0.012403338877183777, 0.01631927774137547, 0.012247517550995034, 0.11957844193544119, 0.035023858335109494, 0.02128189955387385, 0.00969146327641342, 0.028961657118352673, 0.03843833519626529, 0.07381942033046678, 0.05360589550447561, 0.06690823473036289, 0.04387247263483944, 0.03377136203550524, 0.029225154975128752, 0.02929132581958848, 0.056988771238754836, 0.018577034615220565, 0.023170141578321497, 0.046902059261957486, 0.008577340650522422, 0.04812823278048346, 0.05974326718358263, 0.026601995228819793, 0.019034414003873547, 0.01650422094239583, 0.05240534762701681, 0.010707809142918598, 0.04217025974104482, 0.05984311525319373, 0.009191459713263378, 0.09050355893709967, 0.03242786981225495, 0.039556517130545074, 0.008624046158436085, 0.03945683760027732, 0.048011890837862614, 0.09000794601536567, 0.005993800577632482, 0.033716349261662656, 0.06652620966516196, 0.03435871398617183, 0.09630976229785912, 0.03423022571951151, 0.06410533352003944, 0.06479652868884225, 0.10563859115204505, 0.05888976862714176, 0.012450405404031759, 0.015374066011469453, 0.05342134875395606, 0.05884635442447278, 0.05001118879825358, 0.12439197920743497, 0.03963714022369635, 0.05975993725681498, 0.06518079839166134, 0.01640580928764276, 0.008988875422566649, 0.038381231002389424, 0.033819043347912456, 0.058163256805029616, 0.04692973418822212, 0.05570676906274692, 0.012979183229617776, 0.04877635082530399, 0.0372462181164132, 0.05920212948694826, 0.01922221279763166, 0.042282518435029254, 0.09621128169519287, 0.012057404214095686, 0.024885623114964655, 0.030579556290420796, 0.00795314657396727, 0.054179649394486225, 0.05340124277638332, 0.07990689287262578, 0.0389671120642414, 0.04790044802751753, 0.04095715185206744, 0.05242711601538524, 0.023323989270495313, 0.03949546758385916, 0.019930508964124228, 0.02316648925414249, 0.034780357288376945, 0.02006821135329383, 0.02525688272960965, 0.029805397629858028, 0.047132272513643395, 0.02463180669433167, 0.07084103135932839, 0.03696334015037264, 0.03200751545298244, 0.03804999756656828, 0.031315360759054466, 0.06587843635990735, 0.09469209869782771, 0.030313158790851315, 0.019479302328921134, 0.019694067417613922, 0.04051215435949065, 0.07804489319002436, 0.017480017775068843, 0.060905200399218075, 0.07208665201981222, 0.08556544044685942, 0.06559392662658807, 0.04932102784814854, 0.017217460291219816, 0.06609874026429269, 0.03231150488699636, 0.03139507986845509, 0.02425667067478982, 0.03533831827582852, 0.029027017824832472, 0.00943933895248319, 0.014578654156667332, 0.031952675048922824, 0.018113652927680843, 0.029329794924706224, 0.032831069547683, 0.03223179343847498, 0.09771767868510178, 0.23466796103504398, 0.08106617542404322, 0.18666426350753154, 0.14217854898062446, 0.10990694961360387, 0.23422441144864406, 0.11326891880842949, 0.23307884953195052, 0.18394615290866745, 0.13886580093493386, 0.11716604638364046, 0.18479986596972714, 0.1707706203864467, 0.1449107555972953, 0.11086673520865942, 0.19782667018232808, 0.1412959697265779, 0.2501591168824704, 0.11786498670135775, 0.27502869045542133, 0.12909847101376903, 0.21740548733261325, 0.2572300471365452, 0.10185591711272156, 0.13832213897858897, 0.12491148641152729, 0.13379212318649217, 0.1136895776876519, 0.07833969148416674, 0.1525140709934696, 0.2065294136803958, 0.17506414483631813, 0.17096316892533533, 0.1007919665426016, 0.19072209334661885, 0.18852334439514146, 0.16384331629641596, 0.1168443660642351, 0.09286939932574188, 0.1844956064897199, 0.24891643033873653, 0.1993470635986136, 0.0654639598102339, 0.08975809409974084, 0.1183230383321643, 0.11492246596683418, 0.11363537696700905, 0.1290748601839427, 0.11965098280099132, 0.20609675786427914, 0.13627311425103297, 0.22861107072282225, 0.10089174183385988, 0.1005444665169043, 0.15355959714901063, 0.20186657356398724, 0.11954959872509204, 0.08197391300552315, 0.14306560218814882, 0.17964738841739394, 0.15690502650555105, 0.15270689532401102, 0.1537723550873418, 0.14744682838359188, 0.11588527760919064, 0.16182467461593691, 0.24042359493192167, 0.13880053024378516, 0.07816378237499345, 0.17719439020560634, 0.1414238451228988, 0.17074313315172351, 0.18837613293961172, 0.10951652056387357, 0.1479281767481758, 0.14478597519618852, 0.16202885236951614, 0.09249101317818127, 0.10912049141141678, 0.14631522458887872, 0.13759083144607084, 0.16841744343119283, 0.13919629126546845, 0.18297619366597745, 0.19929896859872728, 0.06488358692055748, 0.21403686083372564, 0.12065749209854873, 0.13445365543086685, 0.22134599846697625, 0.11664018831065587, 0.07180477762895246, 0.19908187460274468, 0.15606527156647176, 0.10165970667355484, 0.16651904691130887, 0.1790081799751328, 0.1848861427917596, 0.08468391839414836, 0.0673839446878241, 0.10970593580315191, 0.1678500021056783, 0.1615942813335888, 0.2298361525660561, 0.2519342651770961, 0.2006960525027206, 0.1171206097088514, 0.18933224131263074, 0.12057063304969382, 0.19885894301677906, 0.08386364507098353, 0.1268721505578968, 0.23326335414763422, 0.13800574466586113, 0.1299714894905206, 0.07580217079169328, 0.22535124403094092, 0.18666954951420908, 0.13330607104205316, 0.1404273792380287, 0.2474659960716963, 0.20578234005839596, 0.07524269678059124, 0.10726786864500855, 0.16171656428806244, 0.12351026563274285, 0.2054135912969228, 0.12515280410767565, 0.21504988953951867, 0.15483455131611518, 0.13637851262765546, 0.2556820592332271, 0.11913196589317053, 0.13907693476686556, 0.13106178582435654, 0.17949250076086293, 0.10999841285088371, 0.132358665427854, 0.05935900897208241, 0.1287359888515165, 0.12914881831215275, 0.1650178669801643, 0.15379754405829216, 0.1413734671809981, 0.12322367980114876, 0.18924001964830583, 0.1383315925035746, 0.11685268577909279, 0.1703134037914776, 0.24591733401100485, 0.19319787501327454, 0.1779399622952746, 0.12395350878397304, 0.2288490942408962, 0.24822574078796372, 0.141474713361071, 0.15363743168211755, 0.24274813552056593, 0.1812779605989495, 0.10753394630286964, 0.1792972555924808, 0.11765091109179682, 0.18615597949152995, 0.20996651311795558, 0.10888253684125601, 0.10403029680732759, 0.15301319259789684, 0.2694845734344375, 0.05856542232175989, 0.13559532562090507, 0.10363612158764755, 0.24308181277686552, 0.16212306586244415, 0.09265261942580824, 0.13308209757651054], [0.034288096001311656, 0.07474425699441664, 0.05547115106075522, 0.011629190750329966, 0.05413097599821706, 0.08181494210035571, 0.038527657217796774, 0.04819697768036877, 0.012294843590127365, 0.002913911180991319, 0.03749563719236082, 0.04108499660487137, 0.0351845414467877, 0.055466389824305816, 0.009789399956653436, 0.04773328764243953, 0.03580479687380214, 0.05101121316153196, 0.052525926035858934, 0.014992759153697521, 0.04034907339260944, 0.02757691680603931, 0.05426386160956276, 0.07672496966176456, 0.007133094937495527, 0.06792787477494248, 0.02554264501668513, 0.05582212275194545, 0.07945693113029965, 0.010018987889071147, 0.0318513733274754, 0.03569816892606116, 0.02011789023996361, 0.053528804076655265, 0.06253386885228177, 0.059000077627358906, 0.027921219701848687, 0.03046755423589099, 0.042233136407430136, 0.05426666549136562, 0.05958265685025723, 0.01785891145587929, 0.12794150970876217, 0.031223315294952165, 0.04156087127123629, 0.07181213207302556, 0.04409374181000937, 0.04796547357053046, 0.08088547826534317, 0.01071865694792641, 0.01876022539011413, 0.02264047796357303, 0.031277952685711846, 0.07268096004883129, 0.02996989011373972, 0.0539843505999494, 0.008097822278467639, 0.02468684436603179, 0.04677842416229748, 0.0980109831077918, 0.04557634027855051, 0.04438649081895429, 0.002165305143740449, 0.014293917469800481, 0.029315022834306283, 0.046508604164926276, 0.022738983464096824, 0.01213099845054169, 0.08715164081584062, 0.048364222335118445, 0.040299032529395436, 0.04243067600914548, 0.08965960583619534, 0.00552228399394681, 0.026300629645946528, 0.02433190050895416, 0.012690539494337095, 0.02375882652197634, 0.030427708087729353, 0.016338510378714532, 0.04024663594581428, 0.050635086973347974, 0.040118925258397095, 0.02884736063048965, 0.10899253940630345, 0.04386704107145629, 0.042459894602577535, 0.07049034695110976, 0.06812793097548908, 0.04265658767713655, 0.06226862623025814, 0.032345025064123255, 0.0686298641225984, 0.10049425711434695, 0.032274031696180185, 0.026032148387223005, 0.03185563469155422, 0.07985538878147641, 0.07543086329655302, 0.028143601619728634, 0.05433758608095589, 0.03697719868092287, 0.023036058954594117, 0.04640214858696826, 0.013021673338728086, 0.02746893479789217, 0.04534014771061559, 0.08962973606802764, 0.05389675227624755, 0.06787555096971412, 0.029738914604569157, 0.040565968205731724, 0.04249223117386142, 0.04331987426285783, 0.04448751866396877, 0.02479803436736186, 0.009404591119457639, 0.05941048625015444, 0.06603130920519752, 0.026234822693250837, 0.08581798899197772, 0.022441337238095944, 0.035571542253056844, 0.04118228977125499, 0.07173293390341344, 0.19155685339243184, 0.021014531037860343, 0.018467953270902077, 0.03586177083273088, 0.027223156554804697, 0.019605218455375686, 0.012227900912083927, 0.029047357459222118, 0.034218565861303965, 0.006702041202750538, 0.03996263949140426, 0.043034196245454015, 0.06003348810237743, 0.06891767569487134, 0.08023600424489669, 0.03345621644609398, 0.022214780141028668, 0.06832552803379875, 0.024556052089939197, 0.0384348456657702, 0.057209845061504075, 0.018105047845071363, 0.020212354626686826, 0.022221393395035018, 0.030631127414263548, 0.06801361533542795, 0.004730405719695433, 0.04047689516277563, 0.0375673660047112, 0.05149685161849184, 0.058491847237511996, 0.054451476542219046, 0.06490858436952676, 0.05445383609302583, 0.0034542322757789086, 0.03371264522654876, 0.034842077161996596, 0.024203530985922105, 0.04360557909333899, 0.09243254534780018, 0.022005831574900978, 0.038937962418722535, 0.03446978907431326, 0.02266613041771756, 0.0723029186408366, 0.023167952482077866, 0.031263843261366414, 0.06975834993945976, 0.002756871056795541, 0.03274231443121549, 0.03452847907019239, 0.012764438250733, 0.07004572484161585, 0.022429947425881704, 0.031197285542504925, 0.11797718793874788, 0.07286528846429241, 0.05964793903272479, 0.04527044520082493, 0.014705856353224767, 0.03767057720030989, 0.08692749115007539, 0.054597512052785006, 0.055151569822262374, 0.03410874332691874, 0.03824263420556823, 0.057568255466439074, 0.039102498952659874, 0.02841689391061664, 0.04544552693503999, 0.03905785134843281, 0.030329604783365806, 0.04500971483667532, 0.020838715774457783, 0.05038566023652112, 0.02763028823650412, 0.043259265216728376, 0.08751739417352984, 0.02253586865751253, 0.039149785729786085, 0.01731684487763672, 0.028610595411831335, 0.08053925248884386, 0.039262481093887365, 0.03605184107718449, 0.06997217274000568, 0.04074591076782635, 0.0698054107206483, 0.019963008329092015, 0.01586041693019891, 0.04776292375379032, 0.05879275891329012, 0.03953507049910484, 0.01257405965588987, 0.014291974479302525, 0.019361029844731092, 0.07644802121625793, 0.025500184593481884, 0.031978990169121854, 0.033346784616550135, 0.03937830592715933, 0.037325263068440466, 0.03823850882209597, 0.05613603493979862, 0.08370720991684545, 0.03459358122199774, 0.07008892453966603, 0.0573518471191487, 0.04639736819832076, 0.04152769583367533, 0.0848864337369319, 0.02294972850640695, 0.005193258806567399, 0.01430494913591012, 0.019468803093918872, 0.031325720183010546, 0.0681127930781053, 0.03343941996835413, 0.07530974479572428, 0.03483501766177435, 0.015812651348120023, 0.0380018221274499, 0.022415439635815642, 0.08332201324763798, 0.041589856207851446, 0.03778399651749961, 0.028940821442032055, 0.03344324657753591, 0.03685190117046718, 0.02416978289763774, 0.025200929582840013, 0.07231807952085811, 0.019103088040625858, 0.08505798380581603, 0.012360184186799152, 0.06318284108513786, 0.09086045631838423, 0.07778327416388259, 0.013896530426497904, 0.009436304286693134, 0.03147736920284168, 0.0328205626518015, 0.020585052571409655, 0.02478762706291051, 0.03535731342591105, 0.0878519217874254, 0.07191360807947575, 0.018181509165573987, 0.02275579717881497, 0.03264667984518794, 0.02773252075477954, 0.05019042655945786, 0.032365050602463946, 0.00479386892214778, 0.029776341830109878, 0.012868127293674456, 0.046021445023436705, 0.01928820169620937, 0.015890656335790072, 0.0447877676736924, 0.06037287271371292, 0.03667917898705891, 0.05386166927975513, 0.032566271256655455, 0.04434660445117662, 0.029678250017065196, 0.020039724373829462, 0.010202825050650826, 0.023880745584685958, 0.10419521255478745, 0.0240906881498954, 0.02531970576984027, 0.028970103237717867, 0.024771282577045986, 0.015349605781657082, 0.06412522499299338, 0.09431938160090678, 0.05727118572160121, 0.03600083877362552, 0.038638257331425147, 0.01259133781141211, 0.01205303080965795, 0.05276758464113359, 0.06930769871800177, 0.016773418493328557, 0.047518066731431795, 0.013078707627080863, 0.039414921099500316, 0.05172810674975476, 0.07768309284602443, 0.04001515098817406, 0.01463377035237969, 0.048487708047633214, 0.012560915502329028, 0.04917996424821116, 0.01010416154449265, 0.04662436388072468, 0.06310028361997778, 0.023490473582980134, 0.03434549130859875, 0.03555720491755394, 0.031747298367742094, 0.0534855890568466, 0.04403108730912209, 0.021513509000801755, 0.029511926583044475, 0.047681381355129906, 0.03604609924819201, 0.061953526606122335, 0.0640102007216023, 0.00944911614961682, 0.07135691496753885, 0.004149193006132039, 0.02775649356115009, 0.05636992158308145, 0.022821506455300317, 0.07697894313042203, 0.00564625665109845, 0.06820912097370432, 0.012465552877514594, 0.028623559534729972, 0.020086773663699146, 0.02141265544079004, 0.03518588976153443, 0.029118505959969856, 0.04422270122074312, 0.04383628264129643, 0.21258582901810447, 0.14071927405893803, 0.18695396731697744, 0.1294419848390164, 0.17336470135036977, 0.23017344575735832, 0.10729785332636488, 0.11590105902043082, 0.12297089376877393, 0.1637307473368222, 0.17334608541380975, 0.15789191629136765, 0.21332061458979884, 0.12608625159989442, 0.1659298946540202, 0.14954051603713345, 0.11643753507204595, 0.19163977474935595, 0.1701683067386189, 0.16537153913128763, 0.1711074998902698, 0.094405114500513, 0.12862024828791618, 0.12615709941113187, 0.09153906466259111, 0.15031127709775202, 0.14198008624296035, 0.08321147442104355, 0.1461892950558855, 0.14133079608361568, 0.1338850036864319, 0.2022041272251837, 0.31305533383161793, 0.12225696111037848, 0.22867320045348138, 0.13452399762407427, 0.1680578570812941, 0.11346001944114124, 0.18345599453295433, 0.15761027172688516, 0.15697487840248694, 0.10451964312984098, 0.2803938799808102, 0.05708765786802096, 0.11153009840317311, 0.1858618323721232, 0.11966709363003893, 0.10536019480036152, 0.10832787386231846, 0.10030326373394459, 0.22119002296559273, 0.10872086930659511, 0.13314390555024147, 0.13859449855742917, 0.1664318048184918, 0.12837927533133378, 0.10618504932931355, 0.07892644588625239, 0.25190726823864446, 0.14439919272497778, 0.1656187863479699, 0.10681432161119678, 0.06827410821232104, 0.0888257650958915, 0.11491876576215991, 0.13801797142913266, 0.09956939746775936, 0.13376731725950397, 0.15730087945778526, 0.12062257381096003, 0.12322459144577866, 0.12516734445647848, 0.28824931491286526, 0.12754825379459128, 0.17981911468650066, 0.11409289999714783, 0.07465101643315247, 0.11922721360479632, 0.2015504856864291, 0.11306710826653628, 0.17517654525656856, 0.12223875120041833, 0.16544431748409427, 0.11063389810583285, 0.22498077923251739, 0.15328435707957516, 0.19604816642259398, 0.10463304712527222, 0.136338017219978, 0.18840040260505295, 0.14741269150568595, 0.14425553591741672, 0.17850636174121212, 0.12756915267316565, 0.21895434857616503, 0.17605592226309164, 0.16067152842879295, 0.17793970182538035, 0.15163386661198833, 0.2037817014441375, 0.11666931497353701, 0.10654907898917314, 0.12076128935140949, 0.10421817987075738, 0.12189320724217162, 0.14784687949765116, 0.13876457007661944, 0.21923415452962924, 0.1326358053953417, 0.20638621652558928, 0.19775346282028383, 0.16221013941591786, 0.14897236991072857, 0.11242837479878819, 0.20387064425214646, 0.19393256865441802, 0.1469769713378722, 0.15786859657495253, 0.2543103021960105, 0.18514341043849147, 0.22852896141909787, 0.14309517318202605, 0.17137017611774708, 0.22464215304822693, 0.15410440823724195, 0.4247151615638887, 0.18257148473733859, 0.1746257433607694, 0.11267154642771329, 0.16412427138176658, 0.1240800894917019, 0.12026068919728841, 0.1608502720632861, 0.14657417762904398, 0.10516385412624768, 0.15424751346149754, 0.18907851299210904, 0.11200960815673876, 0.14912420853732095, 0.16932165700822108, 0.17925176529153702, 0.17698558528096447, 0.18489910499943843, 0.1339961783660035, 0.11984503287221156, 0.10983328259880505, 0.16040794821756502, 0.1925059597218229, 0.1560186168118831, 0.15980477655126205, 0.1912554744030199, 0.11664185072145156, 0.15878744243133455, 0.14508884039617356, 0.08982642914258665, 0.14946372338360356, 0.17491062081629233, 0.15285430596240107, 0.134630223375655, 0.15394310076390544, 0.17663808779851084, 0.12555250282128974, 0.09045623768601688, 0.12944013090623965, 0.18845415133382046, 0.1187846446109395, 0.11858026001362071, 0.19418465754678174, 0.2193566213452047, 0.21613886820212488, 0.07134176174839658, 0.15168631299128457, 0.1463662307228773, 0.11035237611541826, 0.08929307872970259, 0.1335283591141624], [0.022975392451870347, 0.0512681360686979, 0.04785271308895561, 0.03167520566362768, 0.029602997200263124, 0.038440717729709806, 0.08382733250337263, 0.02424033959546397, 0.03316681524137816, 0.048304685812082984, 0.00810666580594355, 0.017910679847362544, 0.05126753085923772, 0.07965367783101336, 0.05610203978815868, 0.037535205633649905, 0.006485606999992724, 0.0028606972773559396, 0.01746477071015585, 0.005487190942550379, 0.009419173603096317, 0.08724416891533522, 0.033812244317584464, 0.005390320082135018, 0.044789690554382346, 0.026479311993405707, 0.012835524506836891, 0.021671332689302585, 0.009257516602144368, 0.0360269662022831, 0.028649441815251787, 0.03203407955175686, 0.02944543589687636, 0.0451603890096228, 0.08865430695755828, 0.05301865080611841, 0.020923724720975565, 0.019745171227822864, 0.017586469522587234, 0.05099175069781561, 0.0874142787389217, 0.07865151991286586, 0.024470278970716942, 0.018686257685805042, 0.033873014242178014, 0.015150685306458224, 0.015651218427885926, 0.012820441193217713, 0.06375291392267232, 0.035646385212819424, 0.02803049256814824, 0.029508486848264456, 0.049082628946991703, 0.00279941622847541, 0.03726297245931722, 0.023763869295737917, 0.014045579535436007, 0.030693172875251022, 0.011803651953326359, 0.07213370514012153, 0.024877563870001226, 0.05817962810397149, 0.0179453031911004, 0.09141682767339292, 0.026303577169235197, 0.02320598300185896, 0.06902760165112634, 0.058143576006254846, 0.06523348991909335, 0.06859404185125906, 0.06414142775259192, 0.030844528866451115, 0.03191822215974812, 0.019921024795621634, 0.022954018598782922, 0.04100341973225436, 0.06588094912829899, 0.06177979318665401, 0.017536426744153424, 0.00805143278182274, 0.039028345472029144, 0.07061129691259516, 0.011497159327019849, 0.06344643278768466, 0.028225825836641655, 0.03829378972671205, 0.1286854883355479, 0.03304101211289245, 0.03001579793260223, 0.021399944126906417, 0.05562026241433717, 0.015934008293815197, 0.024881302379071716, 0.07201320717051145, 0.05199924058791611, 0.09413286217398222, 0.026760853136018403, 0.045567786906875914, 0.015801955803087162, 0.029823191937119253, 0.014782825206977226, 0.05258094647058076, 0.024028673332424897, 0.09364799746582586, 0.053935102637737035, 0.04217424339825108, 0.01593087116376527, 0.04712975591481213, 0.06277758057319349, 0.02896290775688906, 0.0366487538051461, 0.061793563617092956, 0.07437718596549765, 0.01746692916288251, 0.03676530259150652, 0.028932723892672412, 0.04881133806080588, 0.06450081875007, 0.05137546881732922, 0.02184855755448582, 0.020250536448832963, 0.056451448659983375, 0.018074513495629354, 0.04814759948320928, 0.03584236965604848, 0.02512531478949372, 0.00018519753622615922, 0.027760168867966825, 0.019944840553967703, 0.059905532266824484, 0.03766878455456707, 0.04067305580622727, 0.04777164183436863, 0.03870859569419296, 0.04381485133161468, 0.015247625114786771, 0.00854907009089666, 0.03591182318726375, 0.049182898364961154, 0.06235715918122761, 0.0078080835162601895, 0.02351378372329618, 0.041985418046674425, 0.04071697179648665, 0.022173120279706294, 0.0761987055621801, 0.01285238897488002, 0.017065949167215058, 0.014814995154137573, 0.04655416724422286, 0.02215876570722509, 0.027161584153110464, 0.06259992478355285, 0.02870688883347377, 0.03744692549169545, 0.022961539666979544, 0.03405908167722725, 0.021968050033695275, 0.08635715401220707, 0.01887569973816074, 0.034888391007458976, 0.02443442797108043, 0.028591420231086594, 0.011209906998931641, 0.03248118187090562, 0.0373165526487414, 0.0037364717554150815, 0.02333255604870858, 0.07245599066898709, 0.007613521123740583, 0.04496534302410099, 0.03272510426599653, 0.02696245108851262, 0.07294581962689277, 0.02676932032280151, 0.01574140900160156, 0.03251881210974628, 0.024909253096989086, 0.007599989616973026, 0.07440401436460596, 0.023893047041530092, 0.04677933197648776, 0.04468189815299646, 0.06671226943933195, 0.02761897503308231, 0.023501848073435888, 0.04170766903928692, 0.017169104821439234, 0.0419802775967025, 0.010941081000642191, 0.018814171386522152, 0.045805611242089546, 0.02440793856587862, 0.0479578203521669, 0.025737953387321006, 0.014171139431005765, 0.01553465240454722, 0.037553105278000716, 0.043611033639359864, 0.033904814551914894, 0.013869634994696227, 0.017916992411858613, 0.037902839737193245, 0.09078310442066963, 0.01272999876809697, 0.031243036313342954, 0.027260382682265296, 0.021952318418170177, 0.011282325290413875, 0.020710758023685025, 0.10584301405376005, 0.020228886804092797, 0.0319337718293912, 0.04179139478853153, 0.013445138014973173, 0.025216017684508717, 0.04625903570183343, 0.08671945231335779, 0.03040598757985619, 0.026176182493086786, 0.0519284732159107, 0.013554521006411843, 0.024348915321752432, 0.10152340431006686, 0.029092414920488675, 0.03539640689268708, 0.042308324106758645, 0.022808419758333795, 0.0367743922247281, 0.06693557640838046, 0.006427968459789672, 0.058136083666355386, 0.05671925001567411, 0.07132556664967729, 0.016108243500873927, 0.04416883757878696, 0.035633354057227416, 0.04155160543779212, 0.005885647157312281, 0.029393602387919545, 0.08223095082587774, 0.010365904102312222, 0.022171392751437043, 0.06421451254056827, 0.03592226879611131, 0.0667945855867959, 0.07133965500660482, 0.07916906593187202, 0.005633310722788015, 0.033002841782065175, 0.01753961175469862, 0.015520467329019261, 0.09177045385924079, 0.031251126201823354, 0.0219387031205359, 0.020710145153345603, 0.028964960872526133, 0.0746218131614789, 0.03185679722997931, 0.03427517592846867, 0.031174754896651835, 0.04816015183384861, 0.05714411088716119, 0.015808739511656667, 0.09178236652646335, 0.06390685546061685, 0.06140999105428496, 0.04536820568084236, 0.06255479454393349, 0.05815620113524699, 0.07996143067195531, 0.05250885759690597, 0.029056941219154867, 0.027871098399402636, 0.01289158777874564, 0.010965623584906421, 0.012918906474125483, 0.021508814797045726, 0.0825221868111722, 0.10270320269609652, 0.033718973112803315, 0.037587268968984004, 0.04090779663754567, 0.021783658415980397, 0.042269479618558, 0.014882835112662326, 0.042218990593908295, 0.08588103036726676, 0.065183816778083, 0.024527182066512686, 0.02092384346460383, 0.03550870006062812, 0.05379683142828365, 0.00952643453098473, 0.053783329128618204, 0.04361889370146298, 0.049790735506723006, 0.0334335440739749, 0.0358188737394108, 0.023026685868840546, 0.008361625612803526, 0.024695275163638498, 0.055672394697584456, 0.031710491673420035, 0.05454090581605992, 0.04568554611215669, 0.01761307767141731, 0.07466820744617332, 0.018203105184159452, 0.03888246700948766, 0.13802403884549297, 0.0675529819883166, 0.06765253511407683, 0.028377999626700918, 0.036289182777005824, 0.02567642312046261, 0.04596554358760196, 0.014683179193056159, 0.04775898606185952, 0.002219288726337254, 0.04884152575546215, 0.04935367468504175, 0.08016498789431588, 0.053596870988727584, 0.05077236226849979, 0.021922101995216745, 0.041208003512433464, 0.01599395371628024, 0.013843662698843308, 0.02987560192723909, 0.031463819022680965, 0.04379774075782588, 0.03193840857655291, 0.023312248973055713, 0.07186848550073563, 0.041694063317751696, 0.025097800741693186, 0.02107653436401198, 0.026780254312700806, 0.08258060101539859, 0.002017178213141198, 0.05965736191419344, 0.10375373140578309, 0.04286571435870663, 0.08516429382706843, 0.059208484186280164, 0.01763425425686423, 0.009434260747155115, 0.014511715309063514, 0.07686258969648231, 0.01144230455881165, 0.02845508530886183, 0.0972918716950282, 0.06314050323600251, 0.10374502864696326, 0.17296388414838623, 0.07319030892704764, 0.10672732466651548, 0.22043963984376003, 0.07887315681023944, 0.18280658179954176, 0.24901167038948308, 0.10164944875624873, 0.07058934849356452, 0.1125856756322807, 0.13620294059716886, 0.19315123558044436, 0.18728176101801858, 0.1386275782339996, 0.10626243953142436, 0.13862624524101136, 0.11225962095082768, 0.1210958093044258, 0.36227737162863055, 0.09926817935681152, 0.0679474406605286, 0.08736406933636436, 0.15271622627492876, 0.09076474895400387, 0.17162954284539148, 0.10527486792735516, 0.13510363506934336, 0.09244610510405996, 0.12634161934857407, 0.0898259541680736, 0.11910904454247606, 0.18374255738191067, 0.16062309635021996, 0.13377540714798436, 0.09758951217536965, 0.12281631254741263, 0.10602934195870355, 0.10788716646211763, 0.1535475082815655, 0.1921210465051474, 0.11095411519730285, 0.1260867802005622, 0.07264609538739727, 0.2171712176453683, 0.14809221149452273, 0.12867654042859233, 0.16080928635933708, 0.14730294174965353, 0.09885499749573008, 0.14244799742535239, 0.09340293359972777, 0.11943971107323324, 0.18172386973615617, 0.07455810528969573, 0.11318306333475536, 0.14469635823080618, 0.1252193388438994, 0.14528270660629197, 0.19114321187859584, 0.08688503455731177, 0.24990782472154788, 0.22372722956201724, 0.05836237071742935, 0.14305332945960184, 0.1051223015172347, 0.26416415408734356, 0.1778668928290567, 0.2251793492224909, 0.1907747542305339, 0.11575834450101662, 0.08901475898681149, 0.09810089118658535, 0.08947824984188042, 0.19111713424565333, 0.17408790367264904, 0.11020355587524754, 0.08216922712181846, 0.1314093752373611, 0.15961567540803265, 0.12098165454282878, 0.16463396499954885, 0.1468860213795016, 0.12285890703600262, 0.17996730673457348, 0.16668154948180722, 0.2621092917698045, 0.1673566108389247, 0.14932766616825136, 0.1258779063280071, 0.16645814292132857, 0.20685979675862098, 0.18237677583050343, 0.13874031573293671, 0.10991597412935189, 0.08441832337167957, 0.154170889347311, 0.0957498592775195, 0.12254667258070362, 0.10197636145617693, 0.2060270591849281, 0.32031392498362454, 0.11289897494979444, 0.11845163385113401, 0.12762683143298473, 0.0989512181390197, 0.13290588203216755, 0.13083698498385568, 0.1455449231810147, 0.26397122250449273, 0.1767817446060719, 0.11816967519060259, 0.12051619484179443, 0.18282438568290205, 0.14483259930726022, 0.12720251065348426, 0.19260663899683184, 0.06914236162218355, 0.13321977889826223, 0.14976859573395024, 0.08515983519534912, 0.09251651624518056, 0.1165148946306398, 0.16768515530613162, 0.11620311216721613, 0.10473457675787712, 0.15791151282047072, 0.1615906347550692, 0.13655275166515382, 0.14374887600781458, 0.13823177124704086, 0.09049007578963235, 0.19081534156876226, 0.16242205465753234, 0.2183969123589416, 0.12789457150164152, 0.18101503922333642, 0.21674292853042004, 0.2100739339666982, 0.0893987299153401, 0.12746076655363844, 0.10519137200448783, 0.2765711012386507, 0.1709857838408601, 0.10482711251825096, 0.10441024577425373, 0.12793715066847303, 0.10998907423908673, 0.1541411804576074, 0.18766754757492773, 0.11977446851350608, 0.11497199355113892, 0.18202981460959683, 0.18970221581478275, 0.14119925878701672, 0.11749207042157651, 0.31058316809996483, 0.17367527339487307, 0.13727397748058842, 0.20824286125359998, 0.20999856623670748, 0.16490771885841124, 0.10671780985449592, 0.14903635357416448, 0.1891229307699588, 0.13623894672961007, 0.14634582214057446, 0.1821619647765352, 0.11920234639077418, 0.1284752814700046, 0.06303055429710977, 0.19330405479957982, 0.06337311051245179, 0.166183500400474], [0.04611984901731053, 0.020311827313215024, 0.010216471949411977, 0.05471161701866696, 0.04328672946881383, 0.00958756068646307, 0.050533894419429765, 0.030983560418169347, 0.024000347231424624, 0.016514829344927304, 0.01615277044625292, 0.038715252998254956, 0.03907943970613903, 0.059474481404909206, 0.041466290056104624, 0.01884041372836838, 0.07439377176905833, 0.00780958361217692, 0.03993834301288571, 0.023235984920193593, 0.09713149884895933, 0.021188048037490057, 0.07769017149844477, 0.05327306094489271, 0.020377076936945803, 0.026720072360589143, 0.05755904708958923, 0.019086341358601086, 0.004388169346061806, 0.03676070989440045, 0.019458840120463602, 0.07102507632225752, 0.010224453627973074, 0.1354817760687682, 0.05301337246032012, 0.04429100562007197, 0.05027253969362186, 0.014631930783751511, 0.01315331884524635, 0.04374281225365497, 0.11464813754202859, 0.02861844781305521, 0.049327788574080315, 0.02278890749890237, 0.011793579812341881, 0.061135045928700324, 0.03060048389729233, 0.03452977375878442, 0.06697867651500049, 0.037207170614912626, 0.005045508216660951, 0.014480382312960444, 0.012359750389512028, 0.016672099534902843, 0.022919203733063997, 0.006177722008883834, 0.03659710032685149, 0.05835204002177043, 0.030393590362021522, 0.0715360033415979, 0.06805906733197552, 0.018898148029561967, 0.04206651994477838, 0.03347707702027213, 0.0542835922040526, 0.021286040259104584, 0.01567525539412013, 0.05901306664811508, 0.04577806272033242, 0.03763876539925414, 0.0773726050711928, 0.06722166428282376, 0.03189891482883644, 0.053259769319406444, 0.010712639327281186, 0.05115711460671118, 0.03452299005021492, 0.0106606142963433, 0.04661142465568358, 0.023061129181916197, 0.048286246075745554, 0.026447818118838534, 0.04224892930998918, 0.007644758358853119, 0.02817153127022809, 0.008025966103999846, 0.04379817742794272, 0.06420078041452555, 0.037567534544054544, 0.03892599995578489, 0.013507329990276167, 0.02186691493637139, 0.019823017252248623, 0.08043369323375725, 0.014045280761145537, 0.02136447617123204, 0.02931580615920886, 0.02958509181025288, 0.03487280111819987, 0.0334953980129813, 0.019100184567392837, 0.02458176391589786, 0.06136567286786534, 0.01166447580251242, 0.010245701076552994, 0.05235869670286775, 0.005151135462050837, 0.02386750567013458, 0.059394421386382276, 0.027999860542495886, 0.09528487455099822, 0.06134977654343652, 0.01268504951674972, 0.05456818237660393, 0.04315326163064569, 0.02722408926685251, 0.032627780456095934, 0.0836437012279226, 0.04110403388978974, 0.0338349971289356, 0.06951307922962212, 0.03636936153916102, 0.017768130036852053, 0.02500035435772471, 0.007841981470494742, 0.014663609477030414, 0.06573212888812827, 0.032970535854298266, 0.06258552233057638, 0.08103602220334354, 0.055691696282836704, 0.016592583438802152, 0.09843881256998548, 0.05230872095712731, 0.045515945737039855, 0.035000680344960386, 0.04178941062080764, 0.03789663825544619, 0.05560110255535092, 0.13469031531243555, 0.08064138733090893, 0.04379533907218326, 0.06505288469094424, 0.07640196401025019, 0.027506859980583675, 0.025744742841549942, 0.012100551243601067, 0.02613760039000021, 0.004342098733515389, 0.0645621517492879, 0.03032562687181898, 0.050103601984559536, 0.0404364955160887, 0.015597963825829569, 0.040665609431603265, 0.006815615652744929, 0.05891327603509831, 0.041542408552261136, 0.04593688040791501, 0.030354619469313376, 0.06424480365709433, 0.03986851409858754, 0.00922926806754643, 0.029291283684752645, 0.0256462105279488, 0.06369395579601969, 0.04335625960882153, 0.02606202390105013, 0.04852032424100945, 0.010463478806008016, 0.015359202948128505, 0.07673231644495841, 0.025933715665052016, 0.018393736588017597, 0.05134734572962888, 0.02747472259216011, 0.08268786864655633, 0.024497957727421197, 0.01140249575743632, 0.013344651219555208, 0.01976575601034828, 0.022112731483855078, 0.03288249703003995, 0.025908559252838456, 0.03858759210655286, 0.04680832074354253, 0.02113883263401447, 0.031924599841717756, 0.017434990957319256, 0.10356784017095644, 0.01512602206334592, 0.009815055283627683, 0.04362073231248125, 0.0220774244066448, 0.03918369661175436, 0.028228631633664333, 0.08076248284909995, 0.03873204181511556, 0.01523563392355197, 0.04989704169753579, 0.019984251947232315, 0.019068692608045477, 0.023297195345343604, 0.0407007115802938, 0.019543084894276915, 0.07348644787505751, 0.03935056588342113, 0.082933108712877, 0.03317343807148357, 0.128157286033515, 0.016144594372881037, 0.03401669020193719, 0.055707155937148686, 0.05148635238348957, 0.009721571489447548, 0.01990320367528306, 0.06988571205687139, 0.02098953550411088, 0.046917829181878805, 0.033217840527574864, 0.039770466335598505, 0.0704327448000831, 0.04580646926056474, 0.041767726502110886, 0.09528729538883894, 0.04207135395958059, 0.04597622668370605, 0.038703665918400215, 0.056189519368232264, 0.0384282419878629, 0.02779216644534421, 0.015283831387698172, 0.04935463995582635, 0.03925973083823919, 0.04358300631265006, 0.06428822935108217, 0.07279335280820247, 0.019568365795778173, 0.10403397402936414, 0.048693992543004216, 0.02205710775489288, 0.06858743817335175, 0.042971840518857204, 0.0529182281705641, 0.03755354194811756, 0.09544812022678315, 0.09799484163522722, 0.05559056118551282, 0.018989130546669328, 0.06515580860357131, 0.020701268109523004, 0.013958253172947275, 0.09631773727315088, 0.014328721801810449, 0.007582425614894038, 0.045768819869525974, 0.02954865475335429, 0.04733893239209729, 0.014683680023036659, 0.03562412652817946, 0.04029514080274009, 0.02389103989116848, 0.04086113805251737, 0.03429275381589129, 0.03776905397253652, 0.03469516065031771, 0.05688665171844825, 0.04760980192992476, 0.010237533621670259, 0.08175139510703665, 0.08728365308695263, 0.10285224510176529, 0.03282143599203518, 0.036031240972900586, 0.053939224190769665, 0.02274735872032902, 0.012252674280335347, 0.029424473816048236, 0.11547883732184289, 0.028444490312869032, 0.025039009239164092, 0.049326248737352515, 0.03480774110123035, 0.04111608445283867, 0.03793483156891119, 0.07928507462624582, 0.032561728355264476, 0.081714553938758, 0.033544925597286036, 0.031059646355589072, 0.017869355149507042, 0.06342862124344514, 0.03973188614773174, 0.012504688479126462, 0.034168536489408825, 0.0762829675729717, 0.03344785076596084, 0.010405921662646917, 0.025544169531654448, 0.0058578635423233915, 0.016276763692017526, 0.032619939546190926, 0.07529812324191294, 0.008515956897979543, 0.03572685891882547, 0.006525738994711109, 0.10347535037585806, 0.06466453173948873, 0.03354023330874982, 0.01281612716059411, 0.028901239594204292, 0.004343826740589594, 0.025152325134484038, 0.05360427905895537, 0.03681563073769212, 0.014649184041416213, 0.04132257196150961, 0.08513796338511091, 0.029557298140359983, 0.027678909921838392, 0.05676675895829836, 0.0625945276941263, 0.03893227421588475, 0.05649310852130575, 0.0453810797884099, 0.03564738878800023, 0.014912783404842261, 0.007074475804749396, 0.06142977527492951, 0.047434597621641816, 0.009375019167970506, 0.03103191780316974, 0.02805298682482493, 0.04182522140082814, 0.034250316375325766, 0.02307337701260563, 0.012291038048363501, 0.05214023907037993, 0.022124397087722056, 0.01848664390103471, 0.01584487875187469, 0.026610018084606817, 0.029647240693110134, 0.04010351923023982, 0.05111497210999651, 0.018793366353718505, 0.012430540744155165, 0.0287353509150806, 0.03926795862254597, 0.029244531253953616, 0.10178439514411074, 0.046806033971088554, 0.1829496257367634, 0.07895398674713028, 0.13703996826323772, 0.2515769924127287, 0.16451486897084022, 0.2014377328657335, 0.11735775988669166, 0.08645821633117814, 0.08787204691719624, 0.10003379996745818, 0.14626840129494667, 0.14345788517065589, 0.10501939292636611, 0.2338892020164959, 0.05205511138023389, 0.11112857640029923, 0.17936807276020128, 0.10513902521662175, 0.10505498537132818, 0.13321145918340455, 0.2589416714204896, 0.13700972311198711, 0.13835785399761893, 0.13191937529031308, 0.09623286239201985, 0.15742322369929285, 0.0678062123516875, 0.11805293871270073, 0.0949693765611418, 0.2126068045054713, 0.10236764852438243, 0.20980280012853686, 0.0855225548448582, 0.3034151591841252, 0.1187088325499527, 0.21322422540716587, 0.197952936794008, 0.12334555672902255, 0.11120938335455234, 0.12064827606081964, 0.21641386312342462, 0.09565160084035128, 0.15904861712648025, 0.1717389402009787, 0.16277266245695854, 0.1849290590372778, 0.13832478964280698, 0.16311044594453228, 0.20670159960225706, 0.2388094629972212, 0.09483145009125434, 0.07574040112235854, 0.11084042774933962, 0.12962829742220142, 0.09445623554770025, 0.09027460590004922, 0.1582868652598512, 0.13209732219336495, 0.11504956761435156, 0.23209605065564956, 0.16704363327833915, 0.1439449638729134, 0.27791834346229033, 0.10413787087365504, 0.13234266951199503, 0.16924146292430742, 0.12870586627433378, 0.1129042839391097, 0.17913688274641193, 0.17573042682582335, 0.19139891670596218, 0.16950752526041002, 0.12997746497632998, 0.11544811719607924, 0.12665660405952123, 0.06366816161560916, 0.21629478241647446, 0.08836193716213589, 0.08264550398434363, 0.15502561364443074, 0.06735108717675171, 0.0953743382987957, 0.13671796618690416, 0.14854294698565237, 0.12237702240987171, 0.10312161693770079, 0.12182031397617633, 0.22093405766833216, 0.12238687430057796, 0.13371836424114245, 0.1813511679609937, 0.15113152743827912, 0.13274848160724487, 0.2181668101900047, 0.2827457392648343, 0.20118077165417134, 0.10886682437792902, 0.18551166890369308, 0.14882620033477584, 0.16563205499081843, 0.15021000027416215, 0.1479947344670373, 0.20096602188723706, 0.13737651068837414, 0.13067048343439258, 0.17178459904126583, 0.18451408453045354, 0.14025260393898334, 0.14815918290086333, 0.10019982654240825, 0.12028560237658602, 0.16077908717336195, 0.1164954053538461, 0.11890036219190206, 0.1309400238096714, 0.07959644340219037, 0.09489714213076139, 0.09637964483831199, 0.17006755085481753, 0.17030424137990322, 0.15442501603355333, 0.08766231502616599, 0.18933093896315945, 0.13228525888294945, 0.10955666357110586, 0.1318218522975522, 0.10775466389473408, 0.07958990867219626, 0.17794887955871322, 0.13075888998085453, 0.12216933597359927, 0.1451333194610573, 0.11133822402165783, 0.18193120377198344, 0.12308078142063272, 0.19467640938537736, 0.13964572440712683, 0.2167034750023196, 0.20838588986906315, 0.2074285404336068, 0.22671434427461318, 0.1330825725510236, 0.13931079076663141, 0.19183308937616889, 0.09201912599946223, 0.16817280091345313, 0.16223732021547135, 0.1182642104404588, 0.11017330306311769, 0.1526101384191744, 0.08876214149378, 0.1871275628406194, 0.11181803254951393, 0.13464238885189259, 0.10052824843554728, 0.11253763425854907, 0.12172810763360993, 0.10672920158192997, 0.18911108705064944, 0.10202164491338116, 0.22423782716355017, 0.18427377807036524, 0.19171534166220697, 0.14380139899590325, 0.10287355000693953, 0.09987404765260798, 0.12064017085058075, 0.18182528445557242, 0.13608497837858816, 0.13625275163400558, 0.09323170528777185, 0.1617395009605154, 0.10794751886879245, 0.0758171554714922, 0.13050548341726104, 0.14622510200546635], [0.013297403704435115, 0.05835111688582167, 0.019900920733268705, 0.07047256605038721, 0.03498506364262393, 0.04870152701773951, 0.12555429546703256, 0.007884654483096975, 0.07994853741218967, 0.07222718318864223, 0.02620801919200007, 0.04263790279266335, 0.05551505939013535, 0.11350570126406609, 0.058305749158945784, 0.04705366806217259, 0.03256601461720082, 0.019026157491269614, 0.03029063772109728, 0.07026217532374206, 0.043185762910833286, 0.08420758024458924, 0.015792826907859457, 0.011874747785529303, 0.026368792319009383, 0.03728185652665073, 0.03697696119366634, 0.03969349748184604, 0.008271759668845803, 0.05261040255126934, 0.05453955750131319, 0.051505688442698414, 0.01185684814117849, 0.06549998892531281, 0.029995146117383437, 0.038935786729017575, 0.054386945125917276, 0.025056464552518823, 0.011429247547752194, 0.038242871692824754, 0.015809907795741193, 0.05121766236580668, 0.0789078529323301, 0.024433920437830593, 0.026351553425493262, 0.014665676956816066, 0.04555425013325388, 0.009688529159663426, 0.015436208191057368, 0.06409144051553262, 0.05412615347473372, 0.03961446402113765, 0.04380486920596131, 0.03638723437043448, 0.012808998712458679, 0.023528663066005515, 0.028448586968044122, 0.060280919180161534, 0.049941356053515795, 0.026749796572051225, 0.04647410339525631, 0.015842750942665004, 0.012686580734988375, 0.03509250747400426, 0.0439360732543132, 0.05073407319404426, 0.06772981040299901, 0.03281375979103389, 0.011019188452572113, 0.04427636184939935, 0.035561540975205364, 0.018744442063654145, 0.0648600910039198, 0.09503648586330876, 0.0277477084478784, 0.045734066290840994, 0.06850945042266, 0.06171085676478763, 0.03939804035208879, 0.022552381682720397, 0.05476607437876444, 0.01128336429716118, 0.10186972967799633, 0.023591317566892794, 0.030444811000638915, 0.02302932121130007, 0.010554201810831025, 0.02338585278560077, 0.0029224468368826617, 0.03300818524533703, 0.07178534197831346, 0.009321575916762794, 0.03550256752679425, 0.060925386816022865, 0.05886528062664213, 0.09282763221211011, 0.03181564107146715, 0.03435463456797504, 0.05344097592657613, 0.07938418342100997, 0.022754791688414353, 0.029045538000401952, 0.10975519525668315, 0.03740913437439069, 0.0653362989185318, 0.052717156903517824, 0.0559684417150434, 0.11637766530076343, 0.03927746194324667, 0.025871955571816336, 0.024003472870155692, 0.010483199824398805, 0.06364753086780829, 0.022151487871944424, 0.01817788365447233, 0.03427064451839655, 0.08043268965857645, 0.0696527447190977, 0.06500135761715713, 0.05118597313881882, 0.09604331691779437, 0.025970392124426943, 0.025486552058869315, 0.031634380838142774, 0.027376935299065326, 0.008262643222546866, 0.04358772541426363, 0.03543217553787174, 0.05096172771206306, 0.05190997985341857, 0.014879832047999147, 0.057705967431707736, 0.01878318696042463, 0.07919149698629495, 0.054580022265473684, 0.04560205018928936, 0.031429153544107274, 0.04183291292358791, 0.03444779085956755, 0.026702883262788097, 0.04933747192544322, 0.026670345593424096, 0.0832492808601068, 0.04832163933784731, 0.030586634942841147, 0.06123921856464398, 0.020307058415886377, 0.029923574353057533, 0.02378094539557013, 0.04884386232363121, 0.018847637937494346, 0.03161651375252874, 0.0383076865616585, 0.025122457281536153, 0.020130655180001934, 0.025152823091634822, 0.04015508460842314, 0.03912009982272022, 0.06442683763922223, 0.04674864249424108, 0.06212832105736579, 0.11990390672919252, 0.02855301049778298, 0.025705141841524073, 0.05542854125040674, 0.03589461302204478, 0.116121799594933, 0.024988211864124865, 0.04925425562466826, 0.022290398764814583, 0.044035871528209224, 0.04698639022066228, 0.06218074445402431, 0.020795537143825524, 0.040665965662488056, 0.05645492286871999, 0.04758435631951979, 0.03612233265753716, 0.009835269471119729, 0.0331154567069344, 0.04542462039558638, 0.018371056555019274, 0.03303013366436766, 0.03148767691586287, 0.03334197741482527, 0.06302371313194595, 0.0398546019418826, 0.04178970556465849, 0.046030707026441256, 0.05058746311753508, 0.033221517749611414, 0.027572304956735145, 0.005729894300231771, 0.03994839025601264, 0.03137771073999184, 0.034739160910248756, 0.07029419013809773, 0.058640380194711114, 0.06213369899459424, 0.04121540009134239, 0.04747125109837902, 0.06906123291100226, 0.02868181286049226, 0.051413669791673465, 0.031087311705754652, 0.05098321264789951, 0.01880424863268291, 0.036064209566721996, 0.04832627416978921, 0.0272318018570302, 0.018749783611706188, 0.024063800378972967, 0.04983947019002611, 0.016197471676634687, 0.03906512918371347, 0.03556307315105393, 0.0935272160436838, 0.035625765956337416, 0.05064704560584599, 0.03463231462744936, 0.08099519737785862, 0.061253352886846954, 0.05122746446079785, 0.041070590321455276, 0.050754742246241345, 0.04550144752307285, 0.0419224686019363, 0.046600285737264546, 0.02753096685234097, 0.016665051525999463, 0.008950891825670918, 0.03889659750125101, 0.08136963051172995, 0.09625444308884683, 0.024845798034220937, 0.044571079704309666, 0.026914476747474363, 0.05565762835284395, 0.07013194803749362, 0.01149491181657199, 0.026516363835863532, 0.035284837677834496, 0.07702578940699178, 0.017283112111110843, 0.011389226156977877, 0.07789899174484514, 0.04404455896527056, 0.009247982637926696, 0.03973899161322944, 0.01461078484182156, 0.043347001436256596, 0.04263174344575213, 0.05511111654942075, 0.05847888119939355, 0.03802397739022009, 0.015329517998672543, 0.06146994126479953, 0.034797460201286504, 0.054181484175064874, 0.04304438904528657, 0.01592823486369584, 0.04244605905466503, 0.07909977327912085, 0.007932542160438795, 0.05595194401159402, 0.03222482969924327, 0.0568011831191759, 0.03191909933042142, 0.025108801764285853, 0.09319906228131826, 0.07312151423144726, 0.07265305912662899, 0.004936800819010504, 0.02838699349893197, 0.07798647132491873, 0.056122241526721954, 0.02902640878493267, 0.0577879311787265, 0.04040596691230613, 0.043551642673030015, 0.0321577203970763, 0.035906403115199464, 0.026042289476120667, 0.085810236182184, 0.01848603869157453, 0.09878692292277852, 0.08196010044024837, 0.016432620449772766, 0.020484532259645003, 0.012992838746868076, 0.045980371219376405, 0.05188417035124956, 0.07170610550430513, 0.00789697940138379, 0.045278500615348743, 0.03210067365979476, 0.03674928369300981, 0.04360737556952142, 0.08912870690466897, 0.038142169435178085, 0.03140476896547743, 0.038150638537181, 0.06238551209530523, 0.04312722613253901, 0.02406706199831059, 0.07176848038310005, 0.08961562472846239, 0.06732116378242932, 0.019114575529050444, 0.026919172866450205, 0.09737103156024411, 0.0792625593021512, 0.008323759801926152, 0.055097464862610065, 0.025058707274917155, 0.0313072593792552, 0.013758342529106286, 0.0064607033967941764, 0.0351035199879158, 0.027420259486403198, 0.03350523841236869, 0.030532093313072, 0.04252545640713746, 0.041219506322616534, 0.02070322737938935, 0.04792998071699854, 0.06710854373992452, 0.04707844717608345, 0.025169786193498203, 0.040808408220689145, 0.022539231783500122, 0.04218811725055979, 0.021640982200962403, 0.011731569782920904, 0.006915356470046626, 0.043343914101921746, 0.04788060251983905, 0.10375317216159836, 0.040015196953449524, 0.028074264916921818, 0.04083226419865124, 0.02759323830926611, 0.04752931673259986, 0.06925087031577865, 0.024998073330930164, 0.023503801597642805, 0.02456689989494701, 0.010633119400740873, 0.024505289188856562, 0.03564755732734357, 0.06718778787481208, 0.018417504465868397, 0.1566359151395098, 0.14150577056552135, 0.21330290263698948, 0.18008197477507978, 0.13363383409957733, 0.14023715960642985, 0.23593830335284435, 0.09518408036280064, 0.13780748111105737, 0.17854794499374207, 0.0941369224399809, 0.1677453391734631, 0.1089550547241684, 0.19316815080181246, 0.2033301538998081, 0.18848490210310107, 0.1488891727621517, 0.11965740261779678, 0.28998962152869473, 0.2025107309342392, 0.1704940013587475, 0.20088464802791997, 0.16939889399274705, 0.1546848270921938, 0.09189064539368115, 0.12483865443256595, 0.1390329000329779, 0.23448961576627148, 0.12016567897291915, 0.13618967195432033, 0.09329216494675606, 0.1450014757292886, 0.09799600608887211, 0.14649902440367207, 0.1638955481710934, 0.07287961430847645, 0.20096761535011953, 0.21357374536173962, 0.10784156890886445, 0.10796530743039424, 0.230989896301781, 0.1734380159647234, 0.17082530374248184, 0.14270198621576832, 0.2117682140200369, 0.12509553903533568, 0.21269144189934577, 0.21715647811370514, 0.17756248013146464, 0.1336476083604559, 0.20855560898780826, 0.1540902815759182, 0.13020612689996922, 0.09288805356669812, 0.08115257482014357, 0.15831211551783547, 0.13576596404515928, 0.2658749816398467, 0.12111994107404064, 0.11572655185215897, 0.1882318939052282, 0.13553037668668455, 0.07439452253522412, 0.1297297581068931, 0.09576023210801425, 0.19681929520541624, 0.2323965869483448, 0.11173999883354672, 0.14097030574996627, 0.19126577062472222, 0.15751552197241014, 0.1357224042857847, 0.11104847424693647, 0.10118105493846441, 0.1083640868384992, 0.19300782392101903, 0.1823752130111379, 0.16199355103796528, 0.13088049877795482, 0.10077358043241887, 0.15235919865869707, 0.06807411329880839, 0.15797224827110767, 0.10425712011994855, 0.17130251523227463, 0.12162712192343128, 0.16541739715443504, 0.08807102293376962, 0.12951352212938572, 0.10301020477087268, 0.1800992117533761, 0.17713200000505294, 0.10475074121307944, 0.26810647318920783, 0.14514491803223087, 0.22860402271391886, 0.12712355763200792, 0.16557343394285248, 0.1688291237599427, 0.1662024534157207, 0.13211216897733752, 0.1218819457496847, 0.14774977019236935, 0.23159568798878502, 0.13254484011521264, 0.18040258257139116, 0.13735167411786897, 0.26395234609803847, 0.1929123693656537, 0.2303428737626922, 0.14624373326378484, 0.11043296856505257, 0.12268629210490374, 0.08032624174149768, 0.1878253923308465, 0.06771467250561522, 0.17650910923557897, 0.17526600900436604, 0.1660923819027601, 0.14772845762631587, 0.20518613979220393, 0.1764017803173873, 0.2017041169587643, 0.14213768585074332, 0.07336381252013868, 0.10898443419606456, 0.09678910351208142, 0.1333292375408834, 0.1525495255426053, 0.1449583449791516, 0.24052456532034183, 0.2529012519986399, 0.12014602115678212, 0.10721908416599037, 0.16054752943736894, 0.17651051883735966, 0.11418239438846228, 0.11039855589549388, 0.1511929983333234, 0.1101162831389135, 0.1729441037581813, 0.10772037379924329, 0.1195104516321613, 0.1237112258170401, 0.13930081630185728, 0.16420120193112284, 0.1608974477576633, 0.1541937800544885, 0.09304297952762536, 0.14398038777853214, 0.14167593401526252, 0.11066819586220289, 0.15302423958576497, 0.16018590529359159, 0.20010533742606643, 0.3184880310248944, 0.23903293084473382, 0.1438027013453745, 0.1923467972946744, 0.10932649245425578, 0.2086071820268708, 0.21560089061817816, 0.14878723710294695, 0.13309274619865802, 0.13317574416437458, 0.170176703062269, 0.23446727664239947, 0.1254680569493963, 0.18980857946218985, 0.11113413053775027, 0.08982499655816825, 0.07856803165087778, 0.11627849521896533, 0.0756220558598157, 0.16188966951543288, 0.09219433030774517], [0.01422836141089999, 0.03723068951418804, 0.0713950814679265, 0.02331917057745159, 0.06515685814402758, 0.025816151812191934, 0.012200299721782007, 0.04417117414695602, 0.01968829877554409, 0.01022799295418325, 0.01845234422944486, 0.06737468268481955, 0.05021262778750351, 0.03815406295020254, 0.03576723175243505, 0.11256880637618805, 0.01436650142779634, 0.046081479503622944, 0.01843116764399794, 0.012472166131520945, 0.009772798831334278, 0.04195887693053773, 0.07148305900515088, 0.042520124435184464, 0.021628257480540106, 0.08763956221481485, 0.020213180086425236, 0.03708941140963185, 0.04305096974055614, 0.03178923976637664, 0.07160519640291892, 0.021033076111287363, 0.05457962006931344, 0.07274343451905636, 0.04052108311424813, 0.03140744452755297, 0.032031873218534936, 0.06727087777107954, 0.12111778070609416, 0.041283064807254466, 0.02853073457616472, 0.07972908386540029, 0.08410980444281332, 0.024646542395555207, 0.0016999192983700685, 0.01630212503275083, 0.0466524486640288, 0.03305986553670899, 0.06191434886967463, 0.0235673715735996, 0.07546583521029643, 0.05241630268433402, 0.029648341944501288, 0.01250681054267672, 0.05955337696979123, 0.00645249811632018, 0.0196913612120214, 0.03908334292411324, 0.01811080116538271, 0.0676649150949332, 0.057067992391004685, 0.1956074973267894, 0.06309598203628294, 0.01950540294450137, 0.010845932880446557, 0.0685770117167023, 0.021861784062498522, 0.025237699887985666, 0.020113496725717862, 0.044756993921774055, 0.07916401741245101, 0.03908986233234887, 0.04926046476729455, 0.10200581753686552, 0.041351304089109746, 0.05435823981139449, 0.050256536116883646, 0.044472602932083036, 0.0814391146864622, 0.039982262833584706, 0.021161935930590958, 0.03233025488894313, 0.019026921663974083, 0.01573433226440102, 0.01789240290470902, 0.013297683326527478, 0.02712215743808737, 0.040284787124443444, 0.04150881942722105, 0.060973512459426164, 0.07800274303243046, 0.04862644274028079, 0.10517334595562951, 0.029161184718231523, 0.013845846049427507, 0.03992703938556295, 0.051566630737074924, 0.07378420326858759, 0.07475361092797211, 0.11761508115957822, 0.04149627473746096, 0.07585983422975387, 0.016059957936616437, 0.0238349718312102, 0.041266115111929756, 0.03550509178650475, 0.019460996657970454, 0.014155294817511835, 0.05504726695137159, 0.09214499424542151, 0.07798239573716156, 0.02602419064890954, 0.02778006800180001, 0.09129273675141797, 0.09121965196344162, 0.03964231131718524, 0.01181277797572435, 0.06858278035877213, 0.03808600752944908, 0.061385824810713537, 0.08227363724501864, 0.03504831952253177, 0.03824504355209009, 0.009842773302338056, 0.04913924284459603, 0.03547358642061872, 0.0664041029109109, 0.030383472255761587, 0.01693878431744393, 0.004274953520976969, 0.03685267874971032, 0.06711050492501067, 0.018864187351878614, 0.027100350745322726, 0.05684634783275186, 0.004139423948682604, 0.06344371700599309, 0.02286401092855921, 0.05001329937048497, 0.11154043292927165, 0.03237929983785556, 0.03915395324809417, 0.013149698122194218, 0.03938523136199482, 0.07008360788947152, 0.04314011556186503, 0.02987532422036654, 0.036269325778008475, 0.019189341880020597, 0.087485279767744, 0.011929737576734156, 0.06429707000572836, 0.045039806770341057, 0.035017645362043576, 0.020197628501562342, 0.037861788915770675, 0.014895698686520902, 0.010599140528469317, 0.019092207676881266, 0.04381590087207095, 0.044893901494722215, 0.054532486509772084, 0.02083103765823668, 0.05782451187711089, 0.05943403579294682, 0.011731922183366073, 0.017790555345615553, 0.009912770755979563, 0.023215723809816187, 0.028932247002939546, 0.034247546967479496, 0.01475732597041755, 0.04690493209167354, 0.02177123630028819, 0.019262648833494996, 0.028972091235881372, 0.0038425823544046933, 0.006510005463966199, 0.09171731033993345, 0.07890385395336537, 0.05028082876496258, 0.03672118741838682, 0.035804003972800515, 0.06642477196310798, 0.041940295467934305, 0.06114954414266733, 0.006703224808593551, 0.009445192821834598, 0.024057702319095695, 0.01129560063653175, 0.036721620258064046, 0.03319408797148255, 0.021368613046023156, 0.046788306696520704, 0.01933826745728091, 0.06833501220230134, 0.04686845481515892, 0.01433604560236657, 0.030305427048475515, 0.04104897132023208, 0.05193329956983367, 0.020226644081694466, 0.02487954995294492, 0.036353128136045514, 0.04759681673960821, 0.008139828794575747, 0.04644766570098939, 0.05329032090582675, 0.027091663308261384, 0.04917462844581855, 0.033119620394802866, 0.038068088732900164, 0.013588284416454694, 0.057165572840359904, 0.03255205266478081, 0.02749141564803018, 0.013081097821404618, 0.047059547786991444, 0.019321781245150396, 0.037890724056670745, 0.024740259846552246, 0.03154621752459676, 0.024829399922201713, 0.04688895532801267, 0.03231142444776432, 0.005293979258802269, 0.06178198419811745, 0.01847702375192556, 0.030499199412823207, 0.04437053320749153, 0.051205619463637, 0.10586305491385922, 0.018075995875762838, 0.05999056802641961, 0.061647704306749575, 0.017715214428702192, 0.05231135629958684, 0.062325638493583094, 0.01916960362465151, 0.07293448918649266, 0.013231732732345982, 0.022080760719555042, 0.03184398823988534, 0.09493632752808834, 0.0165510346602288, 0.007563257616223588, 0.04290465460789781, 0.05046753971386821, 0.033456296885326024, 0.08142530212118741, 0.1116718782953197, 0.008544283956589719, 0.05049846668337142, 0.03525800161784695, 0.01427449522570016, 0.05682032765640367, 0.03513035221746372, 0.04634250098118379, 0.0185763968470236, 0.02160663847931691, 0.04058597076143469, 0.04808345111086965, 0.014853265076395006, 0.05348524814772029, 0.023438260860500798, 0.06446454448685532, 0.03218014762105961, 0.06125242209001895, 0.019671841291710734, 0.03395444555808941, 0.030401521287257635, 0.022148260726563396, 0.01158649571269991, 0.057805811670879205, 0.041866559505222306, 0.016721565832173633, 0.031209707658197132, 0.03941293693177643, 0.011675841674479026, 0.008133368758154253, 0.02995219539790865, 0.0622580427255842, 0.04841556554780372, 0.0076840194073625875, 0.04459219691794246, 0.07303906018815695, 0.03271812903544596, 0.05738794901258042, 0.030144609871410558, 0.0033100049721167214, 0.02866114380829517, 0.028420299171440067, 0.02496361661131584, 0.023537176218064084, 0.0412690224156024, 0.033558435557830724, 0.011834172896229693, 0.009196131891991583, 0.031247412590610407, 0.018882795627559387, 0.05708037620230068, 0.039545519938392025, 0.04257789512555446, 0.050998994059139685, 0.008089948809825847, 0.05055226137741439, 0.029223048233336983, 0.006952846419036149, 0.053460553303481116, 0.09494750475090358, 0.1079928636130306, 0.03028028595802044, 0.03186007417107542, 0.016837448122039918, 0.0033942887685336777, 0.040632468467998895, 0.03208097753926151, 0.023673965047383984, 0.03809870160635441, 0.08104546806744992, 0.04739704016115397, 0.01720741879375231, 0.04283942988202457, 0.012597905100143005, 0.017843166433815515, 0.03731435014595909, 0.08463684995208057, 0.0993781359565835, 0.0871886658452211, 0.012127741619253592, 0.023749058900941766, 0.026328995966562824, 0.02883182245216543, 0.02275616873145825, 0.03626246546064654, 0.05045343220474259, 0.07473992093676522, 0.08614834142668594, 0.05987023093527364, 0.04319307905051016, 0.021098567052714286, 0.03115900221370882, 0.035166618819799156, 0.02824164938271767, 0.08383528449602666, 0.02320644648505315, 0.031015358812686418, 0.025734777952874863, 0.05887094584684219, 0.009600060368557612, 0.025753129589101, 0.049019457336755536, 0.10500245472236026, 0.10464043221286229, 0.2172059214283382, 0.14028582151138014, 0.197314617013739, 0.11804756077547228, 0.090727616672314, 0.09273855916915402, 0.12247999228777424, 0.18782903890936606, 0.12891925240476287, 0.1471747752399214, 0.15148150704560742, 0.07392465782862517, 0.14732200201720963, 0.1706251556113843, 0.11175666890677907, 0.14048731795722438, 0.08891804038637108, 0.19856346290438406, 0.14936214012484397, 0.16811509917099632, 0.13961157220746243, 0.1504674824255128, 0.13098790430493895, 0.16690002243605354, 0.09919110325074966, 0.15697303979146868, 0.13160924757680587, 0.12148593957986563, 0.08984880657085488, 0.14176928948971534, 0.1743211008368, 0.2218518922886541, 0.22705608077587622, 0.10162860350382906, 0.061219863353237036, 0.1274182869782371, 0.18606262401707713, 0.1692290063346586, 0.091022529879645, 0.16768311751225304, 0.130526275043526, 0.11149423016655831, 0.11997198896302332, 0.11084309373531612, 0.1616660331285769, 0.12634097583471768, 0.19206754292451567, 0.12909364465984607, 0.1287690991716039, 0.1383044270257796, 0.11485439905476187, 0.14216195551618455, 0.2055820387097136, 0.26131010884719513, 0.07254995135290009, 0.1796461473549566, 0.14982629747640702, 0.15474942362596913, 0.21830371010207364, 0.391114667779015, 0.14708085286040462, 0.11885586014438061, 0.0704010823861726, 0.16428632962126888, 0.14744261490000835, 0.1929373897972607, 0.09705301314111679, 0.08935133205546487, 0.13459930406703105, 0.11753105663604314, 0.10185668320064584, 0.1502233608475616, 0.27327382816903056, 0.10736404332302271, 0.183064523603647, 0.2246752020812804, 0.15343424984283988, 0.14276348775432957, 0.11233637529996135, 0.20766156905841446, 0.13352128046174205, 0.10048898642942791, 0.15128560304161043, 0.07158694818856255, 0.08484867326314412, 0.09487433569325555, 0.14334879425023833, 0.15917857628195517, 0.1202502704015182, 0.1542804399204831, 0.20397936745036035, 0.13455349200915906, 0.10971006501706378, 0.17204961949779143, 0.1465949232900335, 0.12608758459288266, 0.12578704830018744, 0.1474480694460292, 0.1149471493197545, 0.18030902791407802, 0.0861074016880124, 0.09508294909591637, 0.12992967641161335, 0.23196419160212242, 0.06991277794323622, 0.07909485499464697, 0.21934860806551673, 0.26091732024665804, 0.14054857434764986, 0.12663147637560485, 0.14169508621336954, 0.1545434532266471, 0.17438082505137692, 0.17488261264178062, 0.1530841170179267, 0.1188314449222338, 0.10121803400256943, 0.2126556655932819, 0.2037993674316714, 0.09140034912214165, 0.10631102482758223, 0.15437846853127404, 0.1103251953158648, 0.09153233841061593, 0.1312393343616878, 0.1795985732948588, 0.1172600836763459, 0.1254567111872377, 0.19037114846850597, 0.15811284072697163, 0.12850702049270754, 0.22198430292548674, 0.23468011118952306, 0.10049803392781366, 0.16414040519345194, 0.07198683842415772, 0.1448586003314103, 0.2844150142083245, 0.19524208870866608, 0.13753225636338035, 0.1286558100893613, 0.1212204288270685, 0.13322481975680397, 0.13831576512705895, 0.17567165256027253, 0.13598863516123066, 0.13865862011669144, 0.14696764038695445, 0.19096633749863795, 0.1898891259465487, 0.20075257446977401, 0.13094534045986592, 0.11865945052235358, 0.11340127581910742, 0.08992092608804665, 0.09510243837271007, 0.0999888459280614, 0.09507305123993466, 0.2310996613795719, 0.17917078979794057, 0.13026955898009962, 0.21205255521401284, 0.1933965982208329, 0.1863601266015922, 0.14135489720971356, 0.1454035033501925, 0.14057059171459368, 0.0799986702059546, 0.1464982429939893, 0.10957231474739891, 0.20429674235563125, 0.10268260259181262, 0.09786095244870072, 0.1523339637224713], [0.040972094397030534, 0.06102838733744237, 0.017519794975317294, 0.04115453440575831, 0.034874601424821926, 0.04335555480793119, 0.06662202428185171, 0.04449308429273867, 0.025071491367153587, 0.02113271159149947, 0.020875905512741978, 0.024354632252887375, 0.031042533866580457, 0.009545875927283159, 0.04834625757329407, 0.028376919442727685, 0.04344703336696952, 0.0835443013197472, 0.08720933489741818, 0.0355369572137152, 0.09210445287246859, 0.05216694489542035, 0.005910695838411489, 0.022243196257360043, 0.030387499963023493, 0.05540454354617865, 0.03735775668774882, 0.02138599175058546, 0.03755909225512897, 0.02058461015563338, 0.04065112270895512, 0.019659687306792028, 0.03090654559914143, 0.001119018406532104, 0.045948030817652905, 0.015852805846671186, 0.020800018758182565, 0.06502121461615448, 0.07155208352712855, 0.03673132276162505, 0.06427993261886221, 0.005917095066603995, 0.05390656969299721, 0.049873404054632114, 0.0260589040079785, 0.04034208667074, 0.012092743850042744, 0.07152983633380744, 0.01617125614786581, 0.04688543132356098, 0.06993066609626816, 0.016519330111482454, 0.02402581582446733, 0.056026645245090614, 0.0657754818037633, 0.04231589688589016, 0.0361828689253138, 0.02848925666072436, 0.020613566363951372, 0.058317493286825, 0.07098110287540382, 0.09933722686142692, 0.1260670764191497, 0.020941607128348083, 0.018415692667927475, 0.024410324929762754, 0.05352243405556487, 0.053159522884074724, 0.031003852172063726, 0.03875107526959431, 0.012589330661050495, 0.11093213613475524, 0.05413224387373175, 0.027954353004573818, 0.018126854537836006, 0.037947732489556074, 0.10677168881821056, 0.02436511042047172, 0.020303469293961124, 0.04312791561167087, 0.03904922902884503, 0.02916407670014568, 0.006110660587212132, 0.05584873281599534, 0.026291664502012636, 0.019460642342305472, 0.0218485364870679, 0.0342794775121635, 0.03266141554641147, 0.03810484946194676, 0.06829818635578118, 0.06894855669909908, 0.024253635051389857, 0.02313840447083837, 0.05174190782371068, 0.03403107350271556, 0.10736056528384648, 0.0523296581400979, 0.0648580838535582, 0.009669291734274839, 0.05035212473763574, 0.06241760734889296, 0.017449728573762605, 0.0458776579809285, 0.05599236281047906, 0.03040307070008449, 0.058042322165302696, 0.0670178542514482, 0.06479026975050088, 0.036739707593956304, 0.06870242797078625, 0.02298995578331092, 0.052420680876821286, 0.026158506929453824, 0.02199004633322118, 0.02121115324928636, 0.02502296927324947, 0.023701798936892903, 0.04461481949434646, 0.02172417168866002, 0.014217143010858808, 0.043282531306988774, 0.031671641439559965, 0.008016714155899302, 0.022910125591161273, 0.015228655820171681, 0.02100072804868462, 0.03365371391297348, 0.018756550083297397, 0.014426560805840118, 0.030653987477924076, 0.02407517678464853, 0.047726270277053125, 0.09626791857543493, 0.04928925052104939, 0.018140289804808075, 0.051697114662777995, 0.022277660637853608, 0.014729707543137334, 0.03455315476223346, 0.031825242068378196, 0.04052358822176053, 0.005360294702357703, 0.002242866518621844, 0.043097720256135355, 0.049129693558619875, 0.019807099860401887, 0.02681968485816352, 0.0410559197377053, 0.046573679503654285, 0.10518715086002504, 0.05803424376814116, 0.021684469181984183, 0.02120206361606477, 0.04807629968009649, 0.014430198765870546, 0.022545107677879355, 0.009541932489692925, 0.032201241852054675, 0.041250728235970584, 0.04349080380052329, 0.0661884261775882, 0.04628992819738004, 0.04938868873362099, 0.01188737004169173, 0.07533733928275686, 0.040507102009630015, 0.01848194778205887, 0.0370359423029567, 0.05694780468700394, 0.05867505716460367, 0.028828750439589063, 0.024619530135345076, 0.04362697209862452, 0.10028674687829711, 0.04957409350261573, 0.07829578698522623, 0.03142170333904365, 0.016267779395885525, 0.049286067425724, 0.022269210688048796, 0.03249530853222936, 0.08474936528551964, 0.045763173801524025, 0.016086440638548905, 0.05721904194703507, 0.013244483308235725, 0.014385610533457611, 0.009942651057856218, 0.02863325054697212, 0.03679219610808838, 0.07737504889167125, 0.03386417358753181, 0.031032695382412885, 0.05042992479678604, 0.07303798766506296, 0.04167424845359018, 0.058511497392769785, 0.022848901759472587, 0.028548134348144936, 0.044596804936807004, 0.04042159510596145, 0.03959003347723235, 0.03474241295348733, 0.03245498166389523, 0.09110253244157761, 0.048977180774654114, 0.05269249270279562, 0.006000435377861704, 0.02612265209937769, 0.09448681011675827, 0.04090829076425683, 0.057254561613644325, 0.0431873218997592, 0.062204431892643054, 0.03839647615208261, 0.04774004453793169, 0.02410944964316103, 0.0584660760397392, 0.020719332462777535, 0.010773706110945393, 0.013797849683361429, 0.04242750823557858, 0.06325319476966416, 0.05354192716279819, 0.05562865873798729, 0.06876414401396629, 0.018792573452716874, 0.042039940524245464, 0.09206107697419583, 0.05284267274903194, 0.0796651921325153, 0.08901941680139111, 0.05469636420809454, 0.02509366195168226, 0.06715329859646098, 0.03439524105840153, 0.05995248962614325, 0.013377789310329865, 0.013830953300179494, 0.028994568255579764, 0.01776071813618464, 0.03350400884125022, 0.05098395575318606, 0.01559522218867055, 0.04970047502748428, 0.06799083188055985, 0.04698794154870895, 0.0200761882438054, 0.062327446461084395, 0.15811759047210217, 0.03513019899987886, 0.16341286681352124, 0.0751875461109223, 0.04469815453874969, 0.05383604363868794, 0.030679609288551637, 0.036933236725388036, 0.04706253936033576, 0.037072932858380585, 0.08552903594869761, 0.01618874593517713, 0.02358280441483423, 0.06353698821077425, 0.05140149665455665, 0.1127877543049474, 0.028094261726965348, 0.017138817535352804, 0.03376414931769814, 0.07213061014490743, 0.02529040099151673, 0.07068954513318117, 0.007070466770880646, 0.03302925649369436, 0.042565783275471586, 0.014908030786882005, 0.0798338540499249, 0.02981977326975715, 0.02059988211840391, 0.054639152761909275, 0.03161639117846086, 0.04000483178383401, 0.0636982343970768, 0.0083928159250307, 0.00934673137136645, 0.03205797000367555, 0.02365032931970012, 0.03522975212563911, 0.030517715757953066, 0.032699497777127454, 0.025267431760326992, 0.012873748463818864, 0.06762975165920873, 0.023849479621276263, 0.0508223686577572, 0.02274337314790295, 0.027998899102150917, 0.002967190920307692, 0.04382786716544821, 0.037212793700276844, 0.006912683301995839, 0.053211842858863455, 0.063656892462243, 0.006424009221636, 0.02197597712849177, 0.03443081435116549, 0.03099605339699455, 0.027093109299218463, 0.10024936178759222, 0.030579743981962244, 0.024156525746108066, 0.05430115093927711, 0.02292514282969698, 0.050434333632790276, 0.03546914694109752, 0.06783288753321094, 0.018227495508448734, 0.023017010178356882, 0.09104655439695043, 0.13889033107026932, 0.020757897328885815, 0.028292527196988947, 0.020730117065531593, 0.0479546717307981, 0.033544523401125785, 0.06162325844108578, 0.09858368745734615, 0.03524438440499287, 0.046045791297670335, 0.11534575252763687, 0.06737598503429083, 0.038636142928754134, 0.06017069444961606, 0.015818933269099122, 0.08878448827853126, 0.027583526229606043, 0.04275590714607989, 0.050108995243546464, 0.02813141316085333, 0.05076595777345281, 0.048914032147055676, 0.01197835830445852, 0.034888394837898594, 0.06104035363081963, 0.012975240749637447, 0.02819794789707709, 0.04257686090685668, 0.05336609849285695, 0.0375317505771114, 0.04855895039415167, 0.029766888305124257, 0.031002346809292515, 0.15346758998930454, 0.17251828144634926, 0.10535396650553712, 0.15920099201461962, 0.11556721322478787, 0.0977956434531558, 0.22212173909910266, 0.1584610430103156, 0.09134521377423117, 0.09291949381511058, 0.0900828157882056, 0.10660309584871416, 0.12553298290097906, 0.0939123131214611, 0.3234057332719526, 0.09174492014872451, 0.09752716794009171, 0.1442236973032836, 0.19596357499399494, 0.19481550030890973, 0.13800818082546035, 0.14108520361684984, 0.07715375673386358, 0.08290151524687968, 0.19531440740871817, 0.12207912145963601, 0.13667474350621625, 0.09607002274283478, 0.07729608820931566, 0.12229344987821196, 0.10661685478783424, 0.08084543484954104, 0.1785465200702029, 0.081189377684026, 0.2040322121953772, 0.09669470615805158, 0.11513271879765297, 0.1846734154969454, 0.2745830724316259, 0.11221586966947203, 0.16860426163240788, 0.2901077829301357, 0.2326987473474395, 0.12720521494385698, 0.12502554158169416, 0.11642919237455053, 0.2274090328043507, 0.11912562268515749, 0.17460089146850571, 0.2577985763069122, 0.253703392020637, 0.19073612807739168, 0.09553262738571053, 0.18570026442889245, 0.10915029223167128, 0.11525310185407439, 0.1917438401329902, 0.15817268751561642, 0.1121767225765413, 0.14451062787444363, 0.09961212985217573, 0.15070207386968598, 0.19972817701918466, 0.09283843405184247, 0.09286297184805717, 0.16644344935494085, 0.21133830079868918, 0.20021897890875417, 0.09488436378418438, 0.24033384007071298, 0.13560035115768834, 0.27916201059856727, 0.07846576657386557, 0.1511876816831289, 0.18448068309695492, 0.15234568486771277, 0.3149337201349197, 0.11044137254958192, 0.10657526387442505, 0.10753392332023191, 0.14438630712609138, 0.17611409898006147, 0.11853691475886492, 0.1487987590653281, 0.12159555910095093, 0.10230941052037863, 0.11100839252673811, 0.2426638198836196, 0.22650621350734468, 0.1857063778105282, 0.25338564939316244, 0.09929929018741655, 0.0947698413003837, 0.16967505336769168, 0.12439042404894868, 0.15087330984252115, 0.17130548765342082, 0.1649442918959164, 0.12987102472013043, 0.18456441650707878, 0.11810954494942581, 0.07708020463225342, 0.09853695609396505, 0.1698935876089719, 0.1561592552330225, 0.1324218983251241, 0.13794352300465107, 0.12348530648816979, 0.2177770246541308, 0.1708870963944543, 0.08519257779323286, 0.13311021300333162, 0.09441202461359002, 0.13317819564573227, 0.11052708246655042, 0.08586836693387839, 0.08966926620492051, 0.11537762178528695, 0.14388415181348402, 0.08705372711823833, 0.08279682933202676, 0.18335706193841275, 0.24842941292351295, 0.187697087925288, 0.10638358867577008, 0.08668896201397143, 0.13859984585114066, 0.09634416730653855, 0.09674671586723098, 0.07799095293927578, 0.10754704640637483, 0.09612498189052267, 0.30513481206951604, 0.17936888481340102, 0.14466807426464173, 0.10684923989878548, 0.15188704334920453, 0.1569120898362129, 0.11133800185615979, 0.156310435024, 0.12144928227268881, 0.08989583670852647, 0.13487567794659447, 0.2907716134382833, 0.16529689152394572, 0.1044240047133738, 0.11934898328036071, 0.14555356465280056, 0.14111737930966964, 0.15611220211271318, 0.22349132044661432, 0.14080925874652403, 0.1679783065112368, 0.18703563228970577, 0.18306426313375274, 0.08998204458264575, 0.1229401583212518, 0.12633965050260867, 0.16292528249323368, 0.1347187218526679, 0.14810569464199005, 0.12106325056764389, 0.12972588170199625, 0.1951785034109508, 0.10690178586951188, 0.3030855268720658, 0.2156535515020932, 0.12903480910726134, 0.1568580346722757, 0.25521168124771887, 0.2005612669933227, 0.1184466542796262, 0.13988623005007544, 0.16476686593265305, 0.1457908680482257, 0.09528715749301257], [0.022229908462313396, 0.041723749224817565, 0.014813228363862202, 0.08346032276148758, 0.027131515202082457, 0.02504359044495129, 0.052909525411744276, 0.016960518231855768, 0.055817235110988545, 0.03701356870512809, 0.06634147522310097, 0.011184201876242316, 0.020748855576159495, 0.059435410920770905, 0.016795638873572313, 0.07324047236432953, 0.008642186162873142, 0.0734045300933142, 0.07973982441809871, 0.026566942875844338, 0.061363623582667885, 0.056854839917392506, 0.10414514870893571, 0.04005188490414331, 0.013158830847861546, 0.06598442462423156, 0.03134433420435075, 0.003211887543007071, 0.02341061849297295, 0.03336777542567542, 0.02773068980464051, 0.05307546771702267, 0.05136512279991181, 0.0391958735793108, 0.04968808355530904, 0.07395623597286402, 0.1071844952962091, 0.03636994759642309, 0.03154266670706772, 0.062111317735886386, 0.015677647503663697, 0.035970386778635365, 0.05278330859577945, 0.03258556135058884, 0.059401040386048064, 0.05217897247583155, 0.04259232439160828, 0.014514308516687204, 0.09716770416426082, 0.02618542151345361, 0.06807507090871373, 0.051065042329531525, 0.04516540305508722, 0.012822955876829164, 0.011823750270019856, 0.0177655789640642, 0.01591214318684633, 0.04291237677417455, 0.04135013963546484, 0.023697759738312136, 0.05596906224626207, 0.05626642310451116, 0.05863540062320329, 0.029117224677916498, 0.005362534551926318, 0.028356974343619043, 0.029182914802203738, 0.03733607256905206, 0.025247429204624028, 0.1085326951297541, 0.039397982895494475, 0.02710453550060911, 0.04318178691450627, 0.013604431634678716, 0.05030117989067109, 0.01659867383780018, 0.007105008717776547, 0.0628081513118119, 0.013219168890387782, 0.02462243552379791, 0.026693324400712887, 0.03733917139470577, 0.01805587457643161, 0.033093063956907684, 0.08772758571731468, 0.046087332415364446, 0.03452389786440519, 0.022264455197258823, 0.03062381127458667, 0.013429687936760247, 0.013629941404947351, 0.04494940073439672, 0.030676780508891232, 0.05389885901803932, 0.08229691865703753, 0.016228877451090563, 0.033833878640566147, 0.02699820441193879, 0.031876010715120265, 0.06381664477709321, 0.04326857318500838, 0.06333259212213659, 0.01702315549576475, 0.08165978631305118, 0.02944461235235776, 0.01455020260876946, 0.021289759615976966, 0.07101920042787829, 0.015197018304118707, 0.008373027873946535, 0.059973166339219584, 0.04421092644934693, 0.051835676985642606, 0.010328809167408656, 0.008417284773332218, 0.050641307607293136, 0.02374632971271152, 0.07213331443528015, 0.05359304054910618, 0.01911341873628478, 0.06816900094910976, 0.05829241156818406, 0.05592831019912997, 0.03373331044830623, 0.05957094336589498, 0.010581290679833582, 0.1253272040236381, 0.029860366353644963, 0.023766782345069994, 0.010068883195579534, 0.07814627726592364, 0.018446776685455156, 0.03997129628494863, 0.035229085629144986, 0.04538977105591086, 0.06205766093766978, 0.0331250672799445, 0.023132250869586583, 0.053624932789393974, 0.03194113393434354, 0.057883397225410714, 0.021447648421951362, 0.030522902173200445, 0.07485338621923039, 0.09046995832074074, 0.07034387093998733, 0.04074217225875586, 0.058199600016157475, 0.014632398097385323, 0.03650695093036179, 0.007872230452184957, 0.0751652452914465, 0.036357222876000794, 0.06027275651332833, 0.05843558574035283, 0.021264170364086187, 0.04368380433128726, 0.005794159500979849, 0.07556926474095353, 0.01881498152450208, 0.06637030311169163, 0.020609567384986628, 0.038492938113068385, 0.00865409978770561, 0.040089227860012365, 0.011703527134452617, 0.047019454575474226, 0.03199411082952734, 0.028818517420140487, 0.03628371673966608, 0.033452742237357364, 0.07081159060039828, 0.03773554528672849, 0.059468245449205565, 0.06039226239907646, 0.04043842605765789, 0.03918074334280626, 0.030198008114952716, 0.03664126146524664, 0.16599507341461797, 0.030422414420172576, 0.027158301466354923, 0.07647203041180488, 0.022824170526057, 0.13169190846383572, 0.025587537769047965, 0.05000155141216613, 0.04306226570699965, 0.043680192226724285, 0.035674814735689474, 0.012222198345097563, 0.03661772724421274, 0.0145169026819208, 0.0415634146831449, 0.07964259253874903, 0.045056492165331884, 0.0376150090127222, 0.06941693519512493, 0.03520033434934674, 0.03265564690434164, 0.016081139310112885, 0.05928783557347714, 0.014070258100306796, 0.05117462737666023, 0.019367966770885453, 0.015545806644724743, 0.02530739090645746, 0.03821001801219198, 0.011264466823288992, 0.04851191259560086, 0.014011080680985846, 0.05131483678856204, 0.05400299718002639, 0.04780233131661531, 0.021966824293016426, 0.054835390014153336, 0.033062543014004346, 0.03648643892618918, 0.0832865970028985, 0.01947150738429158, 0.04206160932118374, 0.04996839129636365, 0.013310819819209077, 0.00737500204254062, 0.03123595383048298, 0.022334008319904248, 0.025088774310725353, 0.01568788914160142, 0.00706348387945083, 0.029931133725650372, 0.032973320583903024, 0.0070522970805365235, 0.038545062735436425, 0.03487807563355854, 0.04558339977877275, 0.07675950490539113, 0.026213958288633057, 0.043057814736159584, 0.09679606725131312, 0.03807862627229864, 0.04292430859359522, 0.007684957865069831, 0.017632080482379082, 0.02825454264248331, 0.02007675323364956, 0.03903134853669232, 0.026563049233969183, 0.029667928897505327, 0.04175988559220587, 0.020891447521505818, 0.0575075353375606, 0.008628161008199377, 0.03897345144181483, 0.15252033759269024, 0.004615657718762035, 0.018819970672108957, 0.043862551796220006, 0.017647817843563614, 0.03796567426874273, 0.056340457841513626, 0.052630156128396915, 0.06838692232005059, 0.07598190267960872, 0.0456033640300795, 0.05521057774463008, 0.04510235401891893, 0.007618287148239512, 0.05231208025267529, 0.020906108529156735, 0.013858194429157002, 0.06622008093061947, 0.016240788203093316, 0.04528464464050147, 0.05835682041041794, 0.02949831320063001, 0.05444428680704967, 0.0218834892486132, 0.01864514174690891, 0.041968050833430984, 0.07611513303052034, 0.05173459551447342, 0.059581048065616246, 0.02295835657165416, 0.023009190335869793, 0.05013894162050659, 0.004946524868794387, 0.030901414725268563, 0.04311652388423682, 0.06962052306100246, 0.08038070293203478, 0.03844254101896959, 0.0668749099056567, 0.04392126477473686, 0.07107567642965625, 0.027582746735143087, 0.06306580966338515, 0.04622899356388277, 0.06657301763733549, 0.025780000123045137, 0.030860178127524354, 0.08751040745166042, 0.02541052740848353, 0.08923867882619943, 0.02488487234879886, 0.04980794950238159, 0.045991379902848316, 0.020551488344227115, 0.03265436753750809, 0.0197363190818578, 0.11026721778175524, 0.035955436572793036, 0.06215572019197768, 0.021466317984666076, 0.06463921253359126, 0.043990182044405135, 0.02218488355978362, 0.017001201331074682, 0.08260307803509698, 0.02515769924127287, 0.025751070727804498, 0.03943520710773526, 0.04753614640644482, 0.07914447450950261, 0.01743849772479265, 0.0036834364460270495, 0.02365262566825315, 0.019228686240591833, 0.034502083510761304, 0.019130780203868786, 0.088631454554777, 0.0388390030111036, 0.049355969118374976, 0.051052175882843234, 0.04073348865213414, 0.049332990311086185, 0.049962036597031745, 0.02000177620850023, 0.09263024199754001, 0.022158675691893986, 0.03012011995569112, 0.02894225402645046, 0.004366486663779905, 0.016563981546149138, 0.030446117180549813, 0.009975238522935298, 0.034927289121814316, 0.021115700609140822, 0.01988408020547321, 0.09950218091328299, 0.10363792189426961, 0.080905634038631, 0.015819801821283275, 0.19499649624190024, 0.15378154814243317, 0.11921572228593212, 0.3908530640746317, 0.1700827960045107, 0.1529331670533265, 0.251305659391707, 0.11696181500390654, 0.1571976720926262, 0.2493489176155098, 0.11725486661758154, 0.24482054125157096, 0.1386243913082346, 0.11637260912046318, 0.2203956817186648, 0.1120310203142224, 0.06768353869237247, 0.1163351167774489, 0.259713152603757, 0.11861332436843265, 0.17547561066044917, 0.1549868802389791, 0.21052512911058244, 0.12627362904529418, 0.1348487882604522, 0.12787209448194312, 0.15987821373968356, 0.08828672264973003, 0.09103578320073505, 0.12125916989339937, 0.30953362764370057, 0.12325191780203774, 0.11939884794335212, 0.12550934142763578, 0.15287229370686317, 0.19670006128088122, 0.20678735548450103, 0.24647607257769955, 0.12236808216379536, 0.1843551672514408, 0.15483640524889195, 0.1553063235816456, 0.21745221869599438, 0.21287780044780624, 0.13212727623120432, 0.16438837253278302, 0.28182710791307114, 0.1331640076973746, 0.18637203160793553, 0.13826797656234235, 0.19843606248257623, 0.11544764222156619, 0.16293893418004438, 0.09370617418279571, 0.24946556216286075, 0.11873476462618959, 0.17591526852019373, 0.07942716095356211, 0.115581194329406, 0.24830078676102624, 0.08775381656784205, 0.3402103928308333, 0.16182475122472934, 0.15243291163877135, 0.11533000175991368, 0.10341055465922241, 0.10515439294038281, 0.12275743869043167, 0.14741569457034912, 0.23155128553269372, 0.12808597090864374, 0.15477208450676935, 0.1041579960034259, 0.11248200861436707, 0.2538039333998196, 0.11947223150561895, 0.08993678410807926, 0.23986594421007942, 0.08409622170391583, 0.1287622656673193, 0.14049995840797502, 0.12100327354405196, 0.16033596659619964, 0.11227806834804435, 0.2095201749715113, 0.20324067483025215, 0.09042849764227869, 0.1448325073767093, 0.17928205640806308, 0.13467784340102829, 0.13521577501969953, 0.1828746870160103, 0.07784698203566574, 0.09542068661821466, 0.18157691875052068, 0.09127520099883119, 0.12363840915983725, 0.2266752584687164, 0.11050600738775347, 0.14820680292623659, 0.13208146417333236, 0.22778884387545048, 0.08415468187341768, 0.21906227504293765, 0.11939478767735344, 0.2012541781990759, 0.0536329920343574, 0.14112286449920747, 0.1495001125600069, 0.08574114271229313, 0.23777774174607572, 0.11091452377337603, 0.17988967138432688, 0.19702580186628527, 0.08371464096971097, 0.182808987315624, 0.10758053977042438, 0.157832452546685, 0.21268074731192282, 0.21760114618847448, 0.10182540383069746, 0.18892623003452055, 0.13927599505311059, 0.14619350853946902, 0.226742766136604, 0.17558506930307036, 0.2690734600107516, 0.15304523039489024, 0.15895107881196086, 0.12528052628641168, 0.1339212243234919, 0.09118699363522953, 0.1297961013211358, 0.1963364759520177, 0.11381405931446822, 0.07506992863190752, 0.14181536201748157, 0.1465965320746745, 0.13180443145815404, 0.08143493184639562, 0.10937846385903897, 0.09598533938368482, 0.12067056155853695, 0.17041730063576854, 0.13901883465868814, 0.1645432295457971, 0.2308009177326195, 0.08793121954846768, 0.12295000255107881, 0.1578767477504669, 0.15515120609873725, 0.21425976177617428, 0.14691793660242713, 0.14349168496987513, 0.17984111673168598, 0.10258494936410459, 0.24241450422954178, 0.09390902660426595, 0.17007112082454467, 0.1671962686363728, 0.10826021297684602, 0.11736115365619622, 0.1690194812873679, 0.12490097568520617, 0.11442832393391479, 0.07149978270453793, 0.129753292327927, 0.14239533654143735, 0.12860515635580788, 0.11984713195312409, 0.0627880529951184, 0.09929279376181865, 0.13820512670903437, 0.21954800543044845, 0.19598127162504583, 0.18414518255139553], [0.02617523062884087, 0.01509868421576797, 0.011122649584356095, 0.07791888704823871, 0.024801782452531403, 0.07335798259103492, 0.07250862090938515, 0.012969986344086788, 0.02790087623701942, 0.06607352831070462, 0.037330529922919894, 0.027316272626781178, 0.01962121245601485, 0.0318317921201308, 0.014492284446474046, 0.11650257593681736, 0.026246940288993142, 0.042008163197146314, 0.05803119473820252, 0.06600779796680135, 0.007935938802773074, 0.03741162799058422, 0.02115047334002391, 0.02078992554978017, 0.03420205666653572, 0.05540892173866591, 0.05792785713809633, 0.0024648483949638303, 0.029583316401488362, 0.027723134262487296, 0.013429678360661192, 0.010729462618098385, 0.013011121435181029, 0.07920999034878709, 0.05746358104290501, 0.06647685828107981, 0.03297409050226693, 0.05068093733561616, 0.011116223064281288, 0.027842437134935494, 0.02169683192586226, 0.041015799713110736, 0.06424441295225294, 0.04285428815731599, 0.05225839281094171, 0.0610173135364969, 0.016285644566279747, 0.007539721479969881, 0.04006396611070922, 0.055052817258383, 0.019913049820329876, 0.02726845916420702, 0.09872281668527473, 0.04054020083839855, 0.06364165497342907, 0.01775951537814352, 0.061518327378097086, 0.04358675631303941, 0.043074028987076976, 0.05406150331480369, 0.027012072518588077, 0.009778348180735785, 0.07099435619649387, 0.047544772556472215, 0.024537068431175525, 0.01093220395681959, 0.028575148523574876, 0.06141779749023338, 0.013323251511000339, 0.0382418604567647, 0.02905612533551551, 0.03438366930030527, 0.07881259755982507, 0.051027641917068156, 0.007791706950463836, 0.03365274864218889, 0.03557629582862701, 0.0315682023328038, 0.03587840643200663, 0.015793609275152127, 0.021231699727415558, 0.07632056716829538, 0.015100205857907573, 0.012708648855257179, 0.03381309850562004, 0.05916793898288762, 0.05911289556552807, 0.01707888073137691, 0.04109122489969577, 0.021727272429533546, 0.04300494700850498, 0.03899698949328834, 0.04179065168324498, 0.03325456678266487, 0.04128439780024271, 0.04237447962945989, 0.04042793448353487, 0.07789084823021004, 0.030984324590873816, 0.06664230262920742, 0.04935578908771277, 0.010393959199709278, 0.08228829250701013, 0.0462971332543079, 0.041758981608455224, 0.006516552164084128, 0.024355972906754866, 0.049950840222018386, 0.05801272818878774, 0.04156451401931625, 0.022632792186472687, 0.040792144174056674, 0.049742169362763246, 0.06305478182771514, 0.046011995328890706, 0.06272258695154902, 0.03606948025164104, 0.026250443226026914, 0.01873582740494561, 0.06407997600974576, 0.011126993302886766, 0.014512674834188676, 0.0381055542628371, 0.029684620038155588, 0.015125399616907443, 0.05936069436551583, 0.02911124536166749, 0.06629994559672571, 0.02027607207456904, 0.04964835040511624, 0.04359313399500905, 0.11636969798635091, 0.04937890196038831, 0.041574319944747036, 0.005095975695087785, 0.044962619581530174, 0.026302889605323156, 0.057913251671819925, 0.06284302746456477, 0.050915306614291285, 0.041628708356931325, 0.06684982052613651, 0.024824958527460698, 0.050475568315314676, 0.014337662047886801, 0.0559897389593384, 0.06330935284495354, 0.04720885832343371, 0.028199744373259526, 0.0472761859606591, 0.009984460306323825, 0.0236019317150837, 0.06358714398717688, 0.028636929684228478, 0.0981145888386715, 0.020910911900441975, 0.07486272483102738, 0.010327498199448231, 0.024531906913785685, 0.028771259371311437, 0.04557938930848914, 0.04130416286868915, 0.07998178562810344, 0.05118634086102248, 0.04702439584258584, 0.05206227813276553, 0.0616966228511545, 0.07674028375937093, 0.03243271531837602, 0.055608560421293786, 0.04260500697719474, 0.04011738925210891, 0.02257125617395486, 0.06851898055643806, 0.051748484688540625, 0.07726397380352983, 0.016166355100370223, 0.018930298824524208, 0.045850737651269284, 0.134882572737913, 0.02250106145267285, 0.06475413338311257, 0.028488609316428343, 0.04762974319859378, 0.08647261112327538, 0.02653954565645226, 0.03692608146417526, 0.017765615353240602, 0.02349245775070402, 0.03496577737913017, 0.0712397494803994, 0.03800639184191823, 0.04887606482952834, 0.04358905840725188, 0.03473782791726051, 0.03117345637762018, 0.007022562335365482, 0.01886449953270776, 0.027133620028654416, 0.031945971779585365, 0.02060811373315031, 0.04057911044407276, 0.05046626800791391, 0.030269813536095525, 0.03622326474156111, 0.06762191457974334, 0.033957981053859956, 0.008142220904119313, 0.004957195994774661, 0.024473827873026172, 0.07597588122852388, 0.042655561119318015, 0.052099341466542215, 0.03679213482105444, 0.034570567940752354, 0.03508642090544586, 0.05363400327041746, 0.010760840621867008, 0.032976001891638004, 0.04687629189462431, 0.023192038286417242, 0.015871987730685263, 0.04551288521578235, 0.006103943911336002, 0.09149045638379552, 0.03055334842253116, 0.032230406819332036, 0.05924425283146482, 0.13511353292532507, 0.054310095015793085, 0.007944235056188078, 0.015632706870805594, 0.00744793169771231, 0.07680260501201115, 0.012596289612232678, 0.04186362538847231, 0.025075833170464443, 0.027529620452814048, 0.04125048308783481, 0.016169080458160852, 0.027240002828259623, 0.03086117787226554, 0.09862280390675991, 0.03486222144396555, 0.004039162191592398, 0.05696958456669123, 0.08662843340707403, 0.01265569781554082, 0.011357461278807494, 0.05498050621921017, 0.019329313804665883, 0.039176062545588905, 0.0206567220119459, 0.03227279063374285, 0.02158085004456582, 0.025822255617728638, 0.024186251872789957, 0.05554892813726779, 0.08046803695540275, 0.02625597629606003, 0.03587605837251871, 0.030152243937576012, 0.046543530113394224, 0.030809183484844627, 0.00845628152150781, 0.06611530308521564, 0.028435548151572867, 0.0955530436288926, 0.04433902784160549, 0.03244405725009499, 0.02885359275575367, 0.00894729312764661, 0.031702547341645244, 0.01327575405969495, 0.0048208692122340925, 0.12407902462948715, 0.032112362246299465, 0.035208458711783734, 0.015326549407965956, 0.036525202975157774, 0.06336993124756603, 0.04289392937695788, 0.04420246883866288, 0.08458923758758653, 0.03874681199029569, 0.02253225846816936, 0.010517353939283039, 0.03766008562618687, 0.003252314960381257, 0.014428336214604638, 0.03389255331468678, 0.023055372031165228, 0.04879157682279906, 0.04688450818761222, 0.02180646676870604, 0.017473094255453157, 0.05342705610899195, 0.07220245387044645, 0.010287150263696188, 0.03244582308276046, 0.03558264669751929, 0.029274397191681692, 0.04929314990858397, 0.11007912021370665, 0.016241720915141127, 0.04900946371978329, 0.044285888152737776, 0.03449590501165198, 0.027208648764738635, 0.012396785952601463, 0.03436799131093487, 0.09874416755572443, 0.027338705596423922, 0.04930816140146025, 0.059744443128546404, 0.03905440778321317, 0.036513700164974704, 0.016703139502374877, 0.012101836356094048, 0.06257643269735479, 0.039653120817796844, 0.03861188092419217, 0.036649634806259025, 0.0847924194268642, 0.06870005309822098, 0.023559925198975592, 0.021399042058375575, 0.014687500886559008, 0.10312412204521318, 0.014074175682429586, 0.06879621245447667, 0.032116374631802884, 0.01353167434928999, 0.03379380458124703, 0.060794155954593615, 0.08926251948240305, 0.03377293251575001, 0.07147613357031538, 0.031020809528267676, 0.06355088887616031, 0.05773142836387119, 0.02418467756210556, 0.018605023637534152, 0.03979553273248096, 0.09103181486528727, 0.060918622259651466, 0.05107417409758895, 0.02606452709334272, 0.03961933634033607, 0.051878156561043956, 0.07040119729936123, 0.016749865120096553, 0.1426460005102619, 0.0804700134622474, 0.1580644239701571, 0.2990556592422147, 0.15964567541114746, 0.17058191760893793, 0.14187956018553627, 0.15969977654036016, 0.15170295242099993, 0.23737415130580627, 0.19118392179089208, 0.10133212747713251, 0.08733796872078411, 0.08279146671655678, 0.16858808185544708, 0.17265095255307614, 0.15901962835942546, 0.18568791509155305, 0.17356532445598036, 0.1394866998758047, 0.08360881358385087, 0.08782496315336998, 0.11429818091733802, 0.0739364019565044, 0.14119827819447364, 0.1097803152797203, 0.11804458069344682, 0.14618871282906304, 0.1491551431677034, 0.12147465510474098, 0.06652091599760518, 0.10597853500756527, 0.16080668166039452, 0.1866158927159925, 0.20985881647756024, 0.14024408504126534, 0.18389611204545345, 0.18110850195009864, 0.2011475847252915, 0.0812477229403392, 0.12677833543068942, 0.11327147754209657, 0.18843228718446148, 0.11716885792632258, 0.13037457431276, 0.12253679004648041, 0.15465392310532833, 0.09707254838318595, 0.2951487946894861, 0.11359275183490208, 0.08343333348391518, 0.26160787190160445, 0.2027796890826956, 0.13488454924475762, 0.15520170661470584, 0.0974546807006963, 0.13335632640988598, 0.18322151034109055, 0.13215649482463637, 0.13614281801687134, 0.10784999587603154, 0.15796475593120823, 0.12350589893157445, 0.14090236907284107, 0.1699154364365724, 0.050828627596098575, 0.211235752269145, 0.10766985796151624, 0.10905382644024589, 0.07557183113549987, 0.12912781218126898, 0.13426008033415965, 0.124148937813457, 0.16733729010147436, 0.10356726560501323, 0.09661173117497275, 0.17035589102775822, 0.11803972369600689, 0.11952078615825985, 0.1361757597976154, 0.06867131714018122, 0.1260876075755204, 0.23413830316595494, 0.18406721012246224, 0.1417356888733564, 0.17286250007248696, 0.09258749429136516, 0.12354882283797189, 0.09509794909747378, 0.09704468576537986, 0.17795395106077197, 0.1577565025898718, 0.166371958029847, 0.07265983134387963, 0.11781590344804911, 0.21094854590633225, 0.20322110894466602, 0.2129289751211482, 0.186812853921325, 0.15412423459272231, 0.09921688977028094, 0.1899839829533331, 0.13966794095693097, 0.10284204081061388, 0.10649740635868042, 0.14175695547413442, 0.12021602627130286, 0.19204534169647003, 0.13603889052906346, 0.22888104010733867, 0.0951023541030384, 0.1712268563888727, 0.10395294490961299, 0.08434451846105438, 0.14428921314256807, 0.12938733212649822, 0.08107526888770443, 0.09503612580198435, 0.12916064670970365, 0.1209759165442759, 0.0969197521466882, 0.1344024960792834, 0.07138082457165565, 0.13172508007095707, 0.10619210499909618, 0.17242887898558573, 0.1153394016587446, 0.20026761017018752, 0.11139152075855002, 0.1221509422025373, 0.09228114339132464, 0.2699462486611259, 0.10070824845423622, 0.06964429476929289, 0.13950424328927072, 0.13934708801248383, 0.0814464001826221, 0.17793521255014405, 0.21233203941054885, 0.08193867296100625, 0.0875072741520501, 0.1563085044824308, 0.2235153909291952, 0.1482222472587901, 0.15278949492400692, 0.150253820503431, 0.11962129689392545, 0.13674873227794326, 0.13379023861019843, 0.17902887967084685, 0.08956128611199318, 0.12244728799428671, 0.15332172684852155, 0.1555968547660497, 0.24991116486489776, 0.1081386884494174, 0.17685127474607962, 0.07475774780276322, 0.1270628298422502, 0.19083466230621263, 0.1937826605693948, 0.16495604368467487, 0.17661930332260747, 0.1472919713705778, 0.12386777588436682, 0.231852327443419, 0.1344960507365965, 0.1824751874852565, 0.11593840580673949, 0.1902490953404096, 0.16067614027809712, 0.10859742189847654, 0.10643822606652976, 0.12049974693406014, 0.14029587258494672, 0.11147551463856814], [0.04884901043448237, 0.012472676537600497, 0.04103703567037179, 0.03592969601853721, 0.046486460393474954, 0.027046808860294765, 0.02813877909624529, 0.006332291260121331, 0.03673099334381762, 0.03725404370455973, 0.05658694280071124, 0.024748608289707093, 0.04011398782172511, 0.0384068374912585, 0.03104969678867248, 0.04402693128213287, 0.028916785433407755, 0.028806593261599064, 0.028489084290941397, 0.0744790296941515, 0.08355242951262383, 0.04004086089891292, 0.07021758900654894, 0.01609099120081913, 0.027896549755467043, 0.005638328598692052, 0.017823386043610594, 0.02221060304662153, 0.022573115852391048, 0.03838401573199419, 0.020154417312193303, 0.04374966491013766, 0.020494728889917175, 0.013704474099100599, 0.02744271352346386, 0.06618172290825075, 0.02054272429837335, 0.03334735535205372, 0.03551203637353836, 0.016139151318179026, 0.05770575292708893, 0.06719220820213519, 0.06081002929638471, 0.0057735282743740235, 0.04525934841724173, 0.063068107927158, 0.09217219802761271, 0.058782661874448104, 0.03329448762439913, 0.05604943636083796, 0.026550514120308143, 0.05078990568196581, 0.044340376156352224, 0.07548540109588255, 0.024018777391663002, 0.07133698902062832, 0.025245381834646387, 0.032689101963994965, 0.012408518589161819, 0.008039502877621882, 0.059184298790510625, 0.07722985224738237, 0.02460607763139471, 0.011123874367425039, 0.007494325503601783, 0.013453882908628834, 0.09228961632376717, 0.08873358939684207, 0.019546846385985132, 0.016577977972525745, 0.04760162777177269, 0.030562667882130034, 0.04448114481243876, 0.018035919901223916, 0.026514303059347218, 0.04979095001134181, 0.04888730716981715, 0.03670573925539371, 0.032864290950519424, 0.025180360122073083, 0.031578678585168336, 0.0890771874917611, 0.0514988855819308, 0.04774056164728058, 0.058191651853943066, 0.03691549029862208, 0.05624840471653208, 0.028605702025214994, 0.03962705084573358, 0.03465457331208933, 0.02661190840655998, 0.03409269378490506, 0.008380770150031294, 0.04181735750828539, 0.041253072465018886, 0.02978155505843461, 0.010224185497199577, 0.017663572441726443, 0.03522718190065315, 0.050207341780825976, 0.036821759441086364, 0.06670921274851407, 0.021907214991628163, 0.03132001665841428, 0.019282072992815126, 0.02349977772082052, 0.04193834194372739, 0.024218580783194592, 0.07003592657706431, 0.045306240659086935, 0.02056166199186156, 0.030099431751295928, 0.013833321469475426, 0.005001009520774167, 0.03496551690923591, 0.03095021644126504, 0.003309732292696173, 0.010674641366236874, 0.04501560605281303, 0.04108882321405315, 0.051985466327037544, 0.04924287538855307, 0.03145037034917022, 0.015810083038353875, 0.057931802490906376, 0.037272529406172615, 0.0348207262915469, 0.04012050339952111, 0.08819955716570539, 0.03572965897018871, 0.0377761019814399, 0.06287927874514172, 0.016419144963184674, 0.014353403239510955, 0.04470561623513218, 0.07063541336045151, 0.023409329550040346, 0.041405087291833856, 0.04342195930920782, 0.010835151150522214, 0.024557337202432177, 0.02887454717570255, 0.04686117314943864, 0.019139672569449873, 0.03988195894165866, 0.013069723330948864, 0.05355264090241925, 0.07068867945382673, 0.03548538800509226, 0.05656357328858107, 0.04553909691411161, 0.04714521556912411, 0.013029689491245777, 0.06967636320980326, 0.03287727231039636, 0.04701902939667625, 0.07256460661489157, 0.03502218060255532, 0.05137092974637786, 0.05040742862488955, 0.038509458799155495, 0.01831931880705299, 0.05321220675062749, 0.10243304178959901, 0.0365917492027004, 0.011045615613130073, 0.04198510778106509, 0.04579685868755464, 0.07686717090226951, 0.0276838147997736, 0.05278778637969687, 0.054665234225291404, 0.05559861660003663, 0.026915020669900605, 0.03882529769813822, 0.03144289907668868, 0.05947291092466443, 0.02121646032338181, 0.02457438840440685, 0.005270511112851842, 0.01715794675082209, 0.03973950106169909, 0.006603399242815232, 0.02295502791962316, 0.04819131246016872, 0.0447044211379703, 0.06082926576416339, 0.11486924583873442, 0.018364866564591086, 0.009439435671083629, 0.04248741248081769, 0.012790697829557524, 0.01010942169570274, 0.05709742931949516, 0.008363085967909184, 0.03913707250068265, 0.06630215959082689, 0.005584935143199419, 0.06749982314725077, 0.03672838098399582, 0.06126040472618996, 0.06917914916430751, 0.0879253896193639, 0.01587819400048184, 0.0324003174600582, 0.013173693911202494, 0.03807080451459174, 0.020584068148426955, 0.05124061819045775, 0.01988938344912904, 0.018307921333959507, 0.03297924244355771, 0.03162631584751991, 0.02127546441530989, 0.008985115846078242, 0.09781570729589271, 0.1227273237741282, 0.042674494982366605, 0.014887834793978162, 0.01488292321277362, 0.012015608372166755, 0.027836323753299735, 0.027254677242449215, 0.02815818027292769, 0.011258070946731156, 0.025219700652204698, 0.07806661944355696, 0.00541591891012485, 0.04937921222599764, 0.036387977475721034, 0.025802751019176458, 0.05268855884130444, 0.030904643785869403, 0.06622339043045236, 0.029602125775249257, 0.038358888048077786, 0.01970943514137499, 0.07504276315411253, 0.012358823423123649, 0.03825976776199476, 0.026147505906861157, 0.03162594621009644, 0.03933267006950994, 0.01920193636549577, 0.07798509236665503, 0.04201637949013422, 0.08426185757402452, 0.039182241044698224, 0.01832266852650191, 0.02733878603565597, 0.04021300085549874, 0.0694523514398644, 0.05709696583630097, 0.02005427238351155, 0.0870091561228037, 0.024041698742357474, 0.020133526094498175, 0.05621020757262746, 0.007132482067156103, 0.0501655746671942, 0.0929583497946301, 0.001168901982319151, 0.02334993283805107, 0.040639688846685236, 0.04378101322799922, 0.034459669052833514, 0.028326482129012866, 0.06723472608193275, 0.02804037318715165, 0.030806293418150277, 0.04151710466812215, 0.010705974362339946, 0.01699073082436958, 0.09254931246921902, 0.041877468597264066, 0.018898306992806254, 0.04215391142474067, 0.058062891626069625, 0.016025870854425577, 0.046916614932518814, 0.043357596432249394, 0.045331850978395635, 0.03382081301101754, 0.02015757550966115, 0.007400765579434173, 0.027976558063059088, 0.027105703784693635, 0.05332805073609757, 0.05371849127714673, 0.030158675245700345, 0.01370435631308224, 0.028086213973320784, 0.027608044873622638, 0.0572024216695178, 0.04286226696304737, 0.022340952906937852, 0.03597123713623132, 0.028989113709558884, 0.11136569593462253, 0.016157190773576018, 0.024816544966832287, 0.07442512008691989, 0.06210162289320462, 0.049871362430313905, 0.044995071066002694, 0.06043256245433323, 0.02967913676383755, 0.08051620856408151, 0.053919076078361085, 0.031676994478930874, 0.02499248471952254, 0.026276210593360088, 0.04403520120127548, 0.028099894388428623, 0.027587247501698234, 0.027063647472870447, 0.025823556051980105, 0.04290683412804239, 0.06049413294080765, 0.011888509597479096, 0.04035197686584246, 0.041966399913954164, 0.03193656805031483, 0.02438952564261854, 0.058361623781703176, 0.05114227931405749, 0.032269209172696836, 0.06471882439068248, 0.0037914555615580253, 0.019189389760515863, 0.029335672734305266, 0.02548530908121217, 0.01475021858970004, 0.03157896586813994, 0.0380912360795323, 0.05237622096413567, 0.016837946079190702, 0.054256545469885877, 0.04998342577187766, 0.018064738213715535, 0.05967047733945712, 0.042412420133909876, 0.015765111761978798, 0.04482531364286139, 0.04173802144284691, 0.034372151168363715, 0.037079774023544405, 0.06017193168161377, 0.011197363266781455, 0.01559237138398232, 0.03612941514039713, 0.03500131619793754, 0.13267374206935206, 0.10376580495146975, 0.13647670977778975, 0.12157989260289939, 0.15958982760146742, 0.11099720764304362, 0.09543883524114087, 0.08656664075510156, 0.1167205356121544, 0.07853881305744571, 0.21082324456543694, 0.17290748475540071, 0.10729085128273695, 0.17250936418291063, 0.10426966864014826, 0.11570756053251606, 0.10352471708169869, 0.10385959709603941, 0.0659025528077637, 0.18801709817301845, 0.16079528227208123, 0.16136375015541432, 0.12666915257972094, 0.1783345435415545, 0.1598321718554343, 0.1556744747945378, 0.22702229629841544, 0.23415439101236485, 0.1180952957140342, 0.1290350542553971, 0.10512144349875951, 0.07819382834338373, 0.18157215368363167, 0.1297044312401164, 0.07481852155779639, 0.16359793833426892, 0.1602638317572494, 0.1414161689218975, 0.2459013227733874, 0.16464052271218071, 0.11676088546312625, 0.16437367896639532, 0.12309202759136116, 0.1200092284970226, 0.18581831857802408, 0.11432166151221722, 0.1774932870701436, 0.1384496619744647, 0.18042889003071094, 0.18287931418707296, 0.11576578321476137, 0.09874865683096071, 0.09983130760731236, 0.1630581374610624, 0.12257414449366832, 0.17014823523500275, 0.14666664444150465, 0.17536733179323136, 0.13751284369537908, 0.14310894744290462, 0.22435168315085674, 0.16774042088898922, 0.138766638514015, 0.11974317382179922, 0.10977207983453428, 0.12857504910038364, 0.1021065580989084, 0.10484407370489453, 0.13829872733162296, 0.1192889373088556, 0.12433277593264658, 0.11582936851247666, 0.0865975907072425, 0.179610064613723, 0.1453226044653885, 0.20995856112530156, 0.17288675441616969, 0.10556973516941072, 0.13393887498926732, 0.103930575142224, 0.13267677577753223, 0.18755039740954677, 0.13267642337708704, 0.1291747427275104, 0.14187130175771254, 0.11727933546588307, 0.10053348081607012, 0.101846938562249, 0.214444802653405, 0.1264714482691019, 0.11075345378729606, 0.138157598614212, 0.07291649378115132, 0.18292665842079348, 0.09817876402408847, 0.07777239571535781, 0.09660107489194601, 0.10763946725356002, 0.1393584107920047, 0.10271186715052014, 0.11847526766359807, 0.1373642839251026, 0.0787086547502587, 0.17350210688046871, 0.10512035565390702, 0.13139177053686113, 0.10336134883184588, 0.11139868368064204, 0.16072305550258006, 0.11656537216397063, 0.13634570874273777, 0.09573304364758153, 0.12068794409353888, 0.12742303672336763, 0.1507335754051324, 0.09151425873560291, 0.08609430158450719, 0.11154877562676707, 0.12177496923193817, 0.17774755165221232, 0.18729789482970394, 0.1382151011738085, 0.18999640889946492, 0.10488784030800867, 0.11017933217508179, 0.10016589650824186, 0.07154097525222648, 0.14550919284022626, 0.15222934675553154, 0.1408551780567054, 0.08891166653484107, 0.18285997812786411, 0.1642938526046853, 0.11580059425004068, 0.08823771600521381, 0.17843168349035327, 0.09044015750048623, 0.152988524566735, 0.07908616755758563, 0.14807368748851363, 0.13562845126275094, 0.07370731102362757, 0.08952599244132158, 0.09207757084720558, 0.13295056027991156, 0.11080771579497284, 0.21435745330827854, 0.1416779871308996, 0.1672576016355907, 0.23245488623938254, 0.10232045750824675, 0.21687464968812084, 0.06121427857226903, 0.1227325484937718, 0.14142497893302672, 0.11602115096344102, 0.21213638055468761, 0.11153531546193747, 0.1415180586158268, 0.1473454289859341, 0.09573204007240073, 0.2156661459875684, 0.18202613738756027, 0.16203904133890906, 0.13912322179925057, 0.15129000038629578, 0.10918817527952696, 0.11469917431954416, 0.20728581825331335, 0.09070617387131338, 0.14323383509632082, 0.1745558914638335, 0.25042412201723746, 0.1433717309226913, 0.12411338367289114, 0.1005364838807333], [0.025199079480502876, 0.014345269300974907, 0.03422852500431961, 0.04558723021839415, 0.07002870236793834, 0.061471013787893526, 0.01347601231593158, 0.04431652783926937, 0.0647847079521706, 0.024722061427910964, 0.08065785822128096, 0.012062188433182817, 0.035182289148290316, 0.019042712651313316, 0.017123739009783152, 0.05543736658329445, 0.03226191601565769, 0.03196055234800423, 0.012172262818973151, 0.01206065146928473, 0.029725335696111285, 0.03768435912206769, 0.05903903702874819, 0.06641890372960799, 0.020920666114937876, 0.03669109548472109, 0.06813321698216662, 0.021603735006083886, 0.038718577819846334, 0.023504711327052886, 0.06552585971451576, 0.036865005104412, 0.0266539168378879, 0.03569205171398578, 0.029431542892369534, 0.06133356229251912, 0.01406375305621975, 0.0058043906052086145, 0.023983376468682004, 0.04700523598359958, 0.03864167408356744, 0.033708355134172786, 0.04862240928735945, 0.026766045296925212, 0.0908343403810455, 0.05661303958585186, 0.03142378135253826, 0.06705705497053362, 0.06905908786481427, 0.06187560397290415, 0.07135820199525164, 0.10677052436456566, 0.019554503434788317, 0.005004311359727816, 0.057448274606177886, 0.08295694170820136, 0.04689673112044412, 0.011962564444289574, 0.02007839649224714, 0.03705694843384047, 0.02340703703192694, 0.045495081332422076, 0.022753451034546863, 0.07736443091304072, 0.04446210369708077, 0.04670789044710898, 0.0469097392933984, 0.03773027843224906, 0.03646233396965169, 0.049077867710542296, 0.07544882039749816, 0.11762507860699009, 0.014212399968997607, 0.05432155569114032, 0.025648945461838477, 0.012718084185654599, 0.027012675812828447, 0.057929626801201416, 0.05632485263049603, 0.053330218764923276, 0.08616679648478186, 0.04973818570555699, 0.03533611194260659, 0.01395136891533771, 0.04386298846633684, 0.013713500530068434, 0.06255272227609832, 0.03390108753416327, 0.05842897057112667, 0.029148601724075216, 0.040303671191776955, 0.03373761586244068, 0.07074577598682336, 0.05663042978173303, 0.030949580588287888, 0.0235347630411026, 0.06514752719310984, 0.019896218868633433, 0.0527158277409692, 0.07419020688581852, 0.018298653585295525, 0.057778967950012416, 0.01643009235962264, 0.02444974972956604, 0.019775362752918756, 0.03769397352551741, 0.026197929814037298, 0.028746367259431752, 0.014331758382820315, 0.04002020716847431, 0.022699983843091517, 0.023304331454358274, 0.09238238957139755, 0.06846546165404782, 0.060148194447279944, 0.03156308869590923, 0.03828219498597807, 0.03225414405366586, 0.0648222002951849, 0.042769968689930056, 0.0252003722538751, 0.02038772364387349, 0.03964905672135853, 0.07906784273443684, 0.028790151099524194, 0.07109802321440752, 0.11741338553087366, 0.06703715966714006, 0.01661729552001963, 0.027203134846903627, 0.0065337048727087685, 0.051752901185424104, 0.03400057554244995, 0.023537752699227105, 0.016448405691452565, 0.07596243638545275, 0.021823797592773073, 0.059513846832898364, 0.013011527461780897, 0.05914268489446371, 0.048617046671889486, 0.022139580950381297, 0.0069036276639258915, 0.03387817384434804, 0.05041691279339214, 0.019381382885659416, 0.023267285357559883, 0.04573619601527049, 0.02040761320160762, 0.0633172741940906, 0.005583114726769348, 0.05450263206336287, 0.031175488425839334, 0.04692282407514511, 0.04040988928247844, 0.032290391503803195, 0.046448290062647675, 0.07115645274039238, 0.040620732000998916, 0.06763407239510168, 0.10088031946290886, 0.03394583472982049, 0.04012785018271497, 0.015094522443119318, 0.08020412732636736, 0.006425764520592507, 0.055787415138535926, 0.015582414156186487, 0.028441462350348314, 0.05180762667629508, 0.042601191859331825, 0.09041268558752152, 0.04128707144709845, 0.012083436839372642, 0.04134010771409639, 0.016700184318206964, 0.03975918952135309, 0.0034714706904900774, 0.020049411555631988, 0.06939209862461976, 0.049189333503525105, 0.07306473945537884, 0.03076871489024451, 0.022001206319058136, 0.025010231146288496, 0.026981580303981904, 0.02637818264174125, 0.01415742358433143, 0.05235586983842715, 0.04547320186130462, 0.06901032636843382, 0.025947775293682373, 0.01686132708263974, 0.004773590574792076, 0.007539401638261493, 0.008356128931946812, 0.061346034203926404, 0.026647510427621104, 0.028876548580404733, 0.02756363858709172, 0.05234127203302999, 0.055186752410184954, 0.022231210811784672, 0.08237215615208111, 0.012602185616419922, 0.025652274113869476, 0.08220206165025312, 0.015392003002606574, 0.03457775767592173, 0.08895141117635275, 0.049778164003885565, 0.009726268566033293, 0.08785601269694106, 0.039522675196489984, 0.01202298675648748, 0.04234191323179872, 0.05558424862101675, 0.043555591856279684, 0.013017261629894137, 0.018378167766176404, 0.005363167532073755, 0.02842405491748885, 0.06696443494048811, 0.08369502145797016, 0.0474506663158536, 0.039653756670774, 0.02620929855883362, 0.028679648662106167, 0.02768291464646257, 0.04327796159252044, 0.05084719373694351, 0.034699929547646356, 0.010241274045960558, 0.09238354636416321, 0.02357937042571364, 0.013137452206724595, 0.02078744534012531, 0.022384495429334142, 0.06271291126106536, 0.081322998739779, 0.013380565421445476, 0.028167264160489845, 0.12373477535983249, 0.0020638449378536958, 0.06529426367412652, 0.03751646712302201, 0.04863926322169362, 0.07362062051411598, 0.01682623067960864, 0.07997286070378558, 0.050147632888007554, 0.02238692584327392, 0.05946869361064127, 0.05171024157936054, 0.05609035311687378, 0.027879916071411104, 0.03879669580548521, 0.04641837432920452, 0.03970151459197364, 0.02208621335035611, 0.020776308336926085, 0.027221919322806983, 0.05100079819620137, 0.012299555988471595, 0.08384833097337716, 0.023210702103472525, 0.03081790348064275, 0.06783353870794659, 0.009025231082623285, 0.010719993771354278, 0.02785367564478469, 0.0517805876030076, 0.053821645016151096, 0.025549980308560115, 0.03853030405157516, 0.09188889105233455, 0.00999686039698821, 0.034896155308571555, 0.02104574529033515, 0.03389896164017339, 0.014972565076013487, 0.013319939138337731, 0.03499091272392581, 0.014030908951686035, 0.049417516622211666, 0.05717742805098815, 0.1150888602639879, 0.034919651225209236, 0.016712012715757858, 0.05894492312725033, 0.03700409219750474, 0.022033657803530657, 0.0481811962691286, 0.051993609841672644, 0.03071474016553933, 0.03159823680987522, 0.05565042712635571, 0.06428024671491116, 0.038064656658999385, 0.0559465890570033, 0.013157412627591722, 0.0946752371026143, 0.062339221232480584, 0.0027463876223567155, 0.020541090615874818, 0.03427758144455091, 0.04681394765934637, 0.04284848121084994, 0.053859386337740775, 0.046189302548525796, 0.012044396041141403, 0.013065928322893959, 0.04540485532713994, 0.012500470207493394, 0.09152949622441685, 0.030673976627088366, 0.08038002111378216, 0.018976089814978263, 0.01567553980426202, 0.024072744455488942, 0.020296354252364368, 0.010963129968712888, 0.028607561703651186, 0.0436811077017938, 0.0634426444828991, 0.019255390150412437, 0.00421057915269968, 0.028462037556774678, 0.028347610833964525, 0.06201790480483925, 0.018021291452309778, 0.041342976713372816, 0.010802738928055812, 0.06467341835941039, 0.022470341326909202, 0.02686923542510598, 0.03786056317509182, 0.029732000661052527, 0.13267881357141081, 0.04620454003733974, 0.02171083984355773, 0.08764475629094147, 0.06627384498114548, 0.05315004254601175, 0.034784850394052845, 0.052405922192960024, 0.034371059493071614, 0.09255030838352057, 0.030710461564482223, 0.07113049002063852, 0.03512374087867718, 0.013113290751202693, 0.12793832278299716, 0.07856716597152334, 0.26823585011786033, 0.19778553126079423, 0.1169942205231036, 0.15677198767662048, 0.06306445368775918, 0.09612986187060034, 0.1897358930399341, 0.08830624257004069, 0.11751940443871484, 0.10216734717570006, 0.12227522464649332, 0.10303810569307498, 0.12983736281673755, 0.09226797433990626, 0.10937228919036927, 0.14713953519540449, 0.0965704313749748, 0.11563528779773943, 0.1279195000026976, 0.09122394205581758, 0.13850302765927008, 0.1655418251550967, 0.09888970127869999, 0.1546871559994836, 0.10111875666846191, 0.17741373650008635, 0.1164916668447756, 0.1398233801967675, 0.21388800995003796, 0.14325888617144478, 0.12536982915574504, 0.286876117630351, 0.14625746155938796, 0.12479293430524489, 0.15368946437393466, 0.20033844265966647, 0.10835860930984059, 0.14950343738159827, 0.18520713363203312, 0.13177089212882903, 0.13794291013431165, 0.07856489835126747, 0.23029600450348472, 0.18760598474933257, 0.17195261744481904, 0.3088415131693886, 0.12065823520383528, 0.1234370199663024, 0.15397470955166126, 0.24276547975117163, 0.10470715847106711, 0.11769388862434896, 0.11400196536053574, 0.11847130698902954, 0.13476839499367824, 0.12602479602660865, 0.07949029425940207, 0.15756684986333694, 0.09961020697148577, 0.11527424588078454, 0.18453855337875505, 0.17480125410422204, 0.08640979957436362, 0.11135279501397764, 0.17784893572811158, 0.09995782702800729, 0.14787061290154535, 0.17870863959673913, 0.10599764890127605, 0.2851436863983831, 0.03660858015439684, 0.3041908078857007, 0.12695190031081438, 0.1116398404983263, 0.14660912656014966, 0.16574007338814198, 0.14657793145987297, 0.08694678890488802, 0.18198190347081233, 0.1587622687821427, 0.21041516484993122, 0.1276146199914717, 0.12041821985715821, 0.10915466659371892, 0.22229870540961144, 0.13803021351416267, 0.19242343673061943, 0.16467977705742085, 0.1551109251956786, 0.1931349945164496, 0.1612090770035021, 0.09366522678324292, 0.1253368184270878, 0.13177911991313582, 0.09306436870247127, 0.16399025196029296, 0.07197300287624521, 0.23322872697345673, 0.19773853942751887, 0.10393909403994199, 0.10784561385310466, 0.17378868505118356, 0.09139066577077874, 0.07843452550831341, 0.123633352979537, 0.09942181829002597, 0.10075237511867478, 0.16593066074194449, 0.12518887152715077, 0.10412466351784046, 0.23256177082657817, 0.1456211336077221, 0.18468401815381744, 0.09067153903625666, 0.1165097235371509, 0.1938916748810199, 0.12176326340845517, 0.19929224234675208, 0.10382971966699248, 0.14466370756347335, 0.11449464416551976, 0.15795305010772523, 0.12198965005095928, 0.20000533230843084, 0.2107964314880871, 0.13805131157559736, 0.10247169092537896, 0.14544148598947834, 0.19558207852946174, 0.15524597117497077, 0.15124089415034941, 0.14136139363531144, 0.10762769248216383, 0.18959796657004666, 0.08751560918866627, 0.13649181703165655, 0.1319454376014971, 0.1293339204764174, 0.20593289165727555, 0.07957083308288167, 0.07834674715394936, 0.23116595862853914, 0.11580469282043558, 0.09257077059197812, 0.1198959777191762, 0.19363385565098257, 0.07949320539351433, 0.16014865809871306, 0.10543821319457024, 0.12578993645166198, 0.08518835664877007, 0.14934671111404896, 0.13426591792414266, 0.14932225758750595, 0.18381231734829565, 0.11936910841013156, 0.1370667047317951, 0.16798933817734643, 0.21083154895853615, 0.19526576082552635, 0.1819027206229587, 0.11084783581956742, 0.18166066748240303, 0.15885427594184875, 0.1298939460708249, 0.11458449861815861, 0.06567608955646716, 0.1276764892522366, 0.1536055317809505, 0.24782087864174, 0.18797693984402766, 0.11779004798060465, 0.1356914390118853, 0.11469472334870409], [0.03756856876275232, 0.014169367852680867, 0.02758319106613917, 0.02918420182991653, 0.0205038070318199, 0.0368552872790925, 0.05347128619530028, 0.08128084092130584, 0.03755721917015411, 0.03340084361092698, 0.03475121913417693, 0.037106096804622686, 0.010273388451746395, 0.036376378904547424, 0.026038953163210424, 0.009360085241496563, 0.01730755031589539, 0.022118906152524778, 0.019089292712329377, 0.05387799461342154, 0.028497043944474672, 0.030657251012481512, 0.02489281476535384, 0.013045600179823176, 0.020908039070725925, 0.032751063155310775, 0.02139069361522073, 0.09055638069947881, 0.04609154972938761, 0.026644848272084232, 0.05168674949316248, 0.055575224105268724, 0.025398139766747915, 0.0638471772113154, 0.06151087717303346, 0.042924749094151685, 0.014577588336842676, 0.04436781359536033, 0.026854813819931402, 0.050825352570222276, 0.043052256768268925, 0.005349746150445314, 0.018648037559262687, 0.01836503510393443, 0.06484011909173382, 0.02066039540354283, 0.07142300537276654, 0.020209966347582882, 0.04585134286072947, 0.04216987286664305, 0.018912236386489485, 0.010384304576643534, 0.027014102651587418, 0.016721946960915963, 0.03826623737451531, 0.03878372976736676, 0.04050048684040385, 0.019571995137319453, 0.02354752032026168, 0.0447762955070263, 0.021457657360682086, 0.02226485164775964, 0.055960501213708234, 0.03138174993857261, 0.04212668465991174, 0.030704756124666145, 0.04365343277552917, 0.05345152878773309, 0.05883896167600348, 0.08044050375540411, 0.04991804399797994, 0.031942011105016835, 0.10051694097778491, 0.11186811171712414, 0.10493298586938651, 0.009036499278379545, 0.0763533404096961, 0.02381913104815589, 0.01391299174077088, 0.0490802119395906, 0.054790229131017006, 0.024862155926624135, 0.023780788347545653, 0.13508212332042957, 0.05262887293112375, 0.05031169061699221, 0.031073008844208334, 0.038449734584578586, 0.06278261377085602, 0.05594509518555096, 0.038780098510605675, 0.058620136321312, 0.023091004695743326, 0.04873291363999729, 0.06947500465978539, 0.011930769880212123, 0.087803382456543, 0.019645692795635234, 0.04683894127787602, 0.02700695122081426, 0.029115470336569898, 0.1386419500434591, 0.020542772178868615, 0.06774221336649311, 0.03857719629342037, 0.057372745997723074, 0.003971318163225547, 0.04894652576636403, 0.0354310225755457, 0.030410346620145346, 0.030309372401285558, 0.02462978422221157, 0.0751994128128694, 0.009964901124007039, 0.01119192883056859, 0.01864447141997516, 0.04119507194827161, 0.04232109096201678, 0.04039427641058161, 0.019688959526378783, 0.021335205866865093, 0.10778777421482148, 0.034344755864191445, 0.03880966184360366, 0.0388804713504449, 0.08405411751159737, 0.006753698990289723, 0.07432951231396968, 0.051078632729308265, 0.007722680513266355, 0.02568161719658923, 0.0502771630342449, 0.014901969116181137, 0.016262524032724962, 0.023688363669920835, 0.029709161664809913, 0.046183828850306814, 0.06103329413059739, 0.018071943270643393, 0.07293031400730533, 0.055245886737060164, 0.007913248236065791, 0.014056122820493917, 0.01225322777886064, 0.06125380104828266, 0.019404756228229212, 0.031159124787776705, 0.003089744638982079, 0.04591337299995846, 0.04779156012039992, 0.043629978993727316, 0.0810354246547626, 0.033870896009067376, 0.007947790661766645, 0.06941466757486905, 0.011466425794717527, 0.018262844720494845, 0.05471960731571721, 0.037582346854070504, 0.023850197828705275, 0.038391527224091754, 0.032479810573521166, 0.02236212566194515, 0.09463828868202626, 0.06282166893323583, 0.011989438808673333, 0.08443934482432182, 0.07126996398813303, 0.09049543840510231, 0.024793236741736054, 0.10299544991745103, 0.0191608855440732, 0.027043801965191964, 0.038388229215577725, 0.019299580017104745, 0.10054006151133969, 0.044942923460996924, 0.017025595485803582, 0.046089017808797865, 0.021443448344906493, 0.03431986566753157, 0.12081796453604776, 0.034765261525829, 0.027226705457113927, 0.026359405826717138, 0.0963832071471599, 0.06975167731363928, 0.08534133674636965, 0.018692030158314495, 0.012630317322609406, 0.026019128722949855, 0.048859892713446776, 0.013198344705386028, 0.03791515843101567, 0.023099140549499183, 0.01862788178597487, 0.0075844796881410145, 0.020296670263633132, 0.03374067638369818, 0.03250562773656941, 0.002740042977928815, 0.05101525810577216, 0.0281345215626061, 0.023804985234634052, 0.02969410037621856, 0.018930478855186415, 0.0836407671111726, 0.037782751624622656, 0.01632293581121391, 0.0545945396316388, 0.05068207880662334, 0.01336419891055313, 0.054467028127081936, 0.039651278376338944, 0.022817543865511977, 0.09967782955256202, 0.028293312437111334, 0.05670582815524071, 0.07065922337313814, 0.029022306384098147, 0.06028266969106852, 0.01704763200494551, 0.03040887956177035, 0.011914566163003687, 0.049442498749422456, 0.02340322191406402, 0.019556742326747027, 0.07078761970924755, 0.05550868553860534, 0.022170145943340276, 0.026684485661286502, 0.045472274894916245, 0.04582350705600074, 0.00963720222634654, 0.030937292537982428, 0.0505535330833687, 0.0063512294324144965, 0.04199346580031899, 0.0942565853737535, 0.0030513966715173617, 0.012094778771091615, 0.0293207704089582, 0.016396068479685534, 0.023494675575244813, 0.0219312931350883, 0.0410977098339748, 0.008483407737296677, 0.07738493908677371, 0.07269426699607603, 0.09712289568156966, 0.045943147007135615, 0.06656098239604505, 0.04092475016331, 0.06568281580844233, 0.025886273755121137, 0.017406199457904985, 0.025221414773935275, 0.007557960118227188, 0.026477456145409136, 0.06690430469931134, 0.04276749039549501, 0.04585465619100198, 0.06257034612879639, 0.0922154896562138, 0.034319122562245015, 0.06415106896911899, 0.04108318480693045, 0.04684663663107542, 0.02948902629976792, 0.05254215560853482, 0.018768901335856607, 0.011566714364885083, 0.038262085177965706, 0.08388518746341429, 0.03531503303337001, 0.03556402693051965, 0.020050386402515635, 0.12430554916781765, 0.04074931602864977, 0.07585355996965401, 0.01419599419609914, 0.06873426658491935, 0.012540945505362847, 0.02184399741611654, 0.026647790049713467, 0.08078887457809142, 0.07763181858125233, 0.014715126974718466, 0.022276467455911542, 0.029603240433179086, 0.0656657014042139, 0.033746429704009526, 0.047233553167672894, 0.07745337372104968, 0.0981495454306564, 0.06044612604103262, 0.028442946645701607, 0.019905758578510537, 0.026032403111457828, 0.019666647215584115, 0.04341611788878518, 0.10830856844662659, 0.030950227932583903, 0.015126717288137205, 0.04559177695022476, 0.041140197070255395, 0.022133025152969266, 0.011084155581380812, 0.02763896226702679, 0.04575571593558116, 0.03258183816327684, 0.06899999950321452, 0.01679462763751226, 0.09778704028576614, 0.02877577545962507, 0.10033125658669781, 0.05355634493753315, 0.06296678130785305, 0.009559923106984747, 0.038033745011254665, 0.025634757513480804, 0.030078580753216823, 0.044921653029779275, 0.02561395631111678, 0.07832681354615958, 0.05192254369537677, 0.0173182008532627, 0.054140234170781995, 0.03170902078460542, 0.04894325840136698, 0.01931360134133889, 0.00450499631809972, 0.03593682829711226, 0.07732366737458976, 0.043570227966073065, 0.025849693056736744, 0.028123859533919927, 0.0458689590525483, 0.030839585684119698, 0.06494997610007563, 0.025116091090885383, 0.06171063459928959, 0.05136278240130313, 0.039529378465827436, 0.029795949850531838, 0.0652481375202056, 0.08508347155105683, 0.07130583222474783, 0.03203412934747194, 0.06914133506436503, 0.03508679628852875, 0.020681909067676436, 0.11790729773741578, 0.14997121066816393, 0.09653627151443113, 0.20351661970057797, 0.11571168208554869, 0.22388973213251562, 0.19678151174899072, 0.23916995333087063, 0.1436434469876751, 0.14460907017271366, 0.17985371121716115, 0.1516169667123787, 0.10138444362148162, 0.16641407754392396, 0.10991012887848962, 0.15932146700159197, 0.10150641247990633, 0.08212359892504831, 0.11442026468895136, 0.1150202417686101, 0.11279857912731749, 0.0651076982819265, 0.11150340789989119, 0.131902965686975, 0.1581626057985329, 0.15214939781975362, 0.11062653600088052, 0.15204162457056586, 0.10229323074341783, 0.18919938634480202, 0.130601336338347, 0.2261778375794811, 0.10336496476684848, 0.12604578683573392, 0.2189453393821755, 0.15224479108808503, 0.1131725296257965, 0.17620901727387983, 0.12602524035760473, 0.19287794137433653, 0.14796867215585324, 0.1610433875072387, 0.1529664765562742, 0.15390465847186505, 0.1639524072168335, 0.11038279746689143, 0.11896308181026291, 0.1116020263983838, 0.14390685865955968, 0.2311524754810718, 0.07572722441006093, 0.09887491578176137, 0.1760780928476203, 0.08716864796775965, 0.13669188855396164, 0.1381322564256768, 0.15045583788906375, 0.14215760413677464, 0.132027531583463, 0.17674345553161638, 0.15379832546797492, 0.17725443617711145, 0.21384095682972865, 0.12247626910046225, 0.18377643378992237, 0.18152680127851425, 0.13448766973470488, 0.07339588096064907, 0.1262524620359463, 0.14359533666603028, 0.0834747175535848, 0.15018602172213216, 0.17424374127820616, 0.2705467083761769, 0.10376169872019561, 0.21037698302778507, 0.1376317558629859, 0.20279410685743057, 0.07757661428542868, 0.15307691579143848, 0.123117484693085, 0.14613835020892083, 0.11217587221894534, 0.2948534524729175, 0.1513236469679302, 0.1139539776129588, 0.17999252634904078, 0.12188010713866643, 0.1907644273653146, 0.1287950848739955, 0.0662824404876559, 0.11222872462484146, 0.08723900548272556, 0.2043600518616938, 0.10878761088655842, 0.07927971201077585, 0.17531209685389074, 0.20619441875286643, 0.08728508567137104, 0.10124334554758765, 0.123348789620063, 0.25193561349184285, 0.11568885266540513, 0.1752303705941285, 0.08520038422918128, 0.16738451176112698, 0.11850785704389696, 0.0960148644122866, 0.21577637071811387, 0.16252691677260786, 0.15301630291486942, 0.219713541709127, 0.16917944044595765, 0.11683433797330627, 0.1453166443013376, 0.1256595406260702, 0.1319688645702216, 0.20073377467211218, 0.14019209831472368, 0.11905330398510541, 0.1089454786251149, 0.20949618109772283, 0.10809247036494556, 0.1500601381544144, 0.12731053671168704, 0.18601426854729655, 0.07973414004570054, 0.15158089929290358, 0.10981711814360273, 0.0997329878831102, 0.09429495105700147, 0.12163868219020868, 0.11075680159152516, 0.15315625185687698, 0.10783891058376721, 0.1973450919913669, 0.08736693450520117, 0.17676884368542703, 0.18426908961226865, 0.23360700586870795, 0.19565917761816135, 0.16426513962928327, 0.1593394394242956, 0.08582969481546072, 0.12040059983489976, 0.13401462576322018, 0.20021848861248265, 0.07895022525542206, 0.15245247752435748, 0.17555316940190333, 0.15921328006492508, 0.1674466874570616, 0.1325555347026356, 0.12102044157443509, 0.09536258651003723, 0.16119249886082065, 0.12030559727140974, 0.1488731002375003, 0.12129670820168911, 0.16555100288842955, 0.05517924857896663, 0.27868489103932537, 0.12389814360968529, 0.18858138321628495, 0.1781372452575353, 0.15125223225162876, 0.21747477232448517, 0.13741213377685318, 0.17091037014559393, 0.14138118934727487, 0.17877392560964633, 0.09905545206199731, 0.13337599954778148, 0.12357249495483215, 0.17534821023864133, 0.12622243905019376], [0.03469084374486439, 0.01564480339912998, 0.019881142258283593, 0.015226795184125584, 0.01908836957638062, 0.012345939739457062, 0.06855546932427153, 0.05983965253577598, 0.03287977358746914, 0.062275176282010736, 0.015478366009530523, 0.018337007777224627, 0.03270666069921947, 0.05310192073304808, 0.05566512069274342, 0.01089998325633426, 0.016224311567061854, 0.03211346158247081, 0.03532275519964676, 0.040517287148583325, 0.023606049437676708, 0.027244049687719634, 0.04061241994702047, 0.04362785309973744, 0.06146048007893467, 0.025660877281259147, 0.01700059037595507, 0.033591086225163554, 0.058928865924357414, 0.02671400685944865, 0.11715144474780369, 0.02225220545134958, 0.03188095964311111, 0.009591815347272542, 0.06329557475363536, 0.033925173338502645, 0.022136173774338058, 0.030968474231720455, 0.04011784890486349, 0.033798833948469935, 0.05623122136439047, 0.07279847027553667, 0.020180039122820865, 0.011596538167777322, 0.032403002598232804, 0.01802795067159159, 0.04349148178833627, 0.06494423044064353, 0.013709156811537762, 0.027317027223386595, 0.04029000801364741, 0.05553212016820908, 0.0254015373666921, 0.04849348435058229, 0.04474264126451266, 0.106246589172271, 0.03802304659339209, 0.023164212057787566, 0.014233505691311533, 0.038149979701566125, 0.041659999218198566, 0.019969481772052187, 0.06781622512085785, 0.04073878998057016, 0.07263321744939012, 0.04114224635545285, 0.026627837289725582, 0.04420557149475621, 0.0682985310953471, 0.05576470063158101, 0.04588027417118992, 0.0289269590810422, 0.05359761409401413, 0.051441214482990966, 0.011177845261690598, 0.06432888563722372, 0.044625923938808904, 0.013543077568042905, 0.06589528263336228, 0.08762458519589517, 0.02034857846616257, 0.04165338787941202, 0.07442494388669729, 0.016152012019207882, 0.09109771374853388, 0.07299353158281696, 0.06594818866541309, 0.03094797563408652, 0.053792012735239925, 0.12960853235375497, 0.03792178892200032, 0.019296400752218983, 0.031702436258896224, 0.08469023095864443, 0.02892785540391361, 0.06376686055333385, 0.04393039271235467, 0.008117581601254642, 0.045165732472894654, 0.027592981669811473, 0.02578494522059637, 0.03801813980023708, 0.020575604792083466, 0.07621220403140591, 0.0404053885159233, 0.003302066864806318, 0.05827875605093376, 0.027639165280326724, 0.026667717911843813, 0.05900446731116503, 0.021748008514424006, 0.038523386277618914, 0.06974535708826396, 0.03915358169545089, 0.021609036334519906, 0.04630501629904874, 0.028169974196521987, 0.00821217718053489, 0.02106787182480818, 0.032874564189584024, 0.03269736422225833, 0.009012115657359602, 0.022114447520805464, 0.04940721657006972, 0.007277048125322308, 0.05518211757824306, 0.035151511565932346, 0.056266208599892356, 0.017846835994972818, 0.023381796350041707, 0.06081651040022412, 0.05602658395805667, 0.010755093047215093, 0.023864067850574374, 0.057583113741730495, 0.05070018912515333, 0.015057999201329246, 0.04703176177797779, 0.07602634344009623, 0.03853909108006666, 0.1106633848300384, 0.0584292425323398, 0.05396419099622196, 0.04770107364522354, 0.042673709742244215, 0.0616850242799809, 0.03622799150405392, 0.05090840799253314, 0.042004236996534376, 0.07200700951920402, 0.06307568836716876, 0.06180303629427668, 0.028803193746435068, 0.04705916857346893, 0.13018337408861808, 0.017654308523502082, 0.032425598361559456, 0.04173521756104404, 0.054761742151552634, 0.021438721582413684, 0.013766179608571676, 0.05135329823280054, 0.053486868423680146, 0.05309339417445083, 0.03697357891548065, 0.04127698206913568, 0.036224785426090804, 0.051468966018048026, 0.040712260355752324, 0.06712284660147083, 0.04034217860129091, 0.07963285556123142, 0.019668449437425985, 0.0005932421493437893, 0.03399782145636217, 0.01774918851292422, 0.09285795397215313, 0.018495706721178947, 0.02544226451596666, 0.04262472991080534, 0.03559961937548172, 0.05305250423149236, 0.09781023742811334, 0.035352839472433256, 0.05035731881376236, 0.060028351482845126, 0.04049977054819465, 0.016087283335265615, 0.009768627482586572, 0.058514496626993345, 0.006325444349298074, 0.06980807670662481, 0.019709672628631516, 0.05387041800385041, 0.03829927874668952, 0.0508977517095064, 0.020949810014797315, 0.0386074835795068, 0.012509003469359972, 0.02624682154536488, 0.07506338624103416, 0.075805664152628, 0.06632439146238951, 0.03307654710126019, 0.06853205001642627, 0.03686358018087284, 0.028608553787513126, 0.04387955894813903, 0.016382303794906024, 0.02664739168399284, 0.060332844619669264, 0.0463357019508558, 0.05738038006388853, 0.01619127977098669, 0.08843685290025127, 0.03658156406374709, 0.04655205667199147, 0.017584086989142725, 0.027372444108609232, 0.025466038139476895, 0.05464159658238773, 0.11317030030993686, 0.047244933403788075, 0.02387348498638359, 0.06795304842413434, 0.046783265837978934, 0.06152199310881477, 0.0177828504163171, 0.07639136135337815, 0.02149404845230522, 0.048965677964471044, 0.017238269154463085, 0.008623382534771677, 0.022743401876200112, 0.024071237177497918, 0.047826443934032035, 0.030250194024354703, 0.06629040780206842, 0.04944500385693485, 0.043969899866609805, 0.05601999560190786, 0.042314226814215226, 0.0456606712372553, 0.04450424236335582, 0.005540727560723862, 0.049846081528812654, 0.01517535046479034, 0.05803597895728965, 0.030269683301148397, 0.024349930388252103, 0.03800441150463397, 0.05609285056350693, 0.0444437635521735, 0.021775455529531165, 0.03712831335442682, 0.017970386824961153, 0.02791686257677934, 0.06267310916295936, 0.07430121302604675, 0.04312904559135918, 0.013749461654844064, 0.0457824447432593, 0.042091322041326956, 0.0008788987402259674, 0.10228713268354055, 0.014976009598843034, 0.06286429789578242, 0.04659224564449922, 0.022265445365900957, 0.009862917584307011, 0.10435313391949862, 0.023991121617596478, 0.03516207591840818, 0.040453824424935926, 0.0261697243718851, 0.06765487168224589, 0.012686833544003387, 0.008880149351523049, 0.013681726075798996, 0.02266287837447899, 0.04515725954045211, 0.010822459946446603, 0.0481175190408624, 0.06243162292746767, 0.13418596898836477, 0.04757538542992646, 0.04518362445636623, 0.021708283025110443, 0.020892527705479055, 0.021387449232861403, 0.04803974962522907, 0.021472615227403662, 0.03357588321030621, 0.02791328303095314, 0.042578086647535526, 0.011210171299265518, 0.027407274296086644, 0.033467527734295975, 0.02256651792014318, 0.08113590474691122, 0.05443476816459049, 0.030075282744702794, 0.027071944205090407, 0.010321521756028938, 0.11485452162882975, 0.02158758204220043, 0.027876769365262122, 0.022820759519574144, 0.020059688625136213, 0.08834490702757913, 0.05892414682274384, 0.008992866740652151, 0.047050676488828276, 0.01965440130011449, 0.04347737044877103, 0.04176221066905607, 0.02180357095635226, 0.020075651982258406, 0.05142243000708761, 0.039243930274800914, 0.07429519923584116, 0.0025567796640849163, 0.06789270367833876, 0.05644906995697849, 0.03744034479642588, 0.02563556765146073, 0.06424759987801795, 0.013336930010888367, 0.061001731308117035, 0.032433707402237964, 0.020717095486038638, 0.026850506490577134, 0.05501940433356551, 0.03185931191359076, 0.02590371374671738, 0.05490005166540223, 0.006876953918817303, 0.04660228905718654, 0.032580528152926315, 0.0825411934525736, 0.020549925524861585, 0.036245596204553886, 0.07286256885216122, 0.03230496249612301, 0.009344124757204085, 0.0730616904254402, 0.010606776509854582, 0.07400419307692398, 0.04360948997219244, 0.028408488010867473, 0.026975579920314977, 0.019659760085144834, 0.17227633555810298, 0.12424839900866633, 0.12737384621774958, 0.1515436980633005, 0.11261184519577412, 0.14169295648894004, 0.20697273344041842, 0.18309588724326703, 0.15143531194377333, 0.12807446426802105, 0.20811276420229868, 0.12536386133081492, 0.11557488176490992, 0.12166326595169884, 0.1470454289547859, 0.18077390538828988, 0.1257075590171641, 0.1047060093391807, 0.1651845830342462, 0.14297037745916075, 0.15225232939325994, 0.10424641787164635, 0.17732266396764787, 0.1500989941339339, 0.20324269730237224, 0.14218567359832027, 0.13968097977340221, 0.11503791541702325, 0.20678232994771775, 0.16083882670969735, 0.31015526202897875, 0.10161289104050207, 0.10464689033406396, 0.09176080115139486, 0.16782740251191203, 0.15886366817980044, 0.09718888649536718, 0.1549507055671946, 0.18813907469232238, 0.12360107769528705, 0.12112781645790224, 0.32023566144128, 0.1567748528454573, 0.0823312777004415, 0.2612260230366261, 0.2702245224387415, 0.2479070175679461, 0.17067272967148214, 0.13349360936591703, 0.11413288978679527, 0.16816494085135, 0.1000235114066351, 0.19251306901776022, 0.10338764863028642, 0.14131005042262618, 0.2037229271785867, 0.09813824563377327, 0.0660143020532785, 0.09771301320964292, 0.09996092968410063, 0.1851213317845137, 0.12763970171011266, 0.1885879256071583, 0.29929336100336046, 0.14453862072719684, 0.17539319492155508, 0.11985270907321285, 0.1978763892886139, 0.25732090516436484, 0.27108490046474243, 0.11815770889722532, 0.16877129944341798, 0.18815241994396334, 0.09543557936746268, 0.13466278211243693, 0.23392255748471907, 0.14323453989721116, 0.12316266089797982, 0.12021502269612205, 0.14417023968792733, 0.06581740213497993, 0.1867689877267807, 0.11619257845825727, 0.10239872871147049, 0.13093348141879807, 0.11905189438332474, 0.1266654370532882, 0.09368826304712603, 0.2085700420843017, 0.17708015117433765, 0.16996518618637518, 0.0823185683017777, 0.05666378141951658, 0.1150767254312673, 0.213597294904532, 0.15060073575906216, 0.13912152108405867, 0.1310881545707103, 0.11764308167321068, 0.15041557230776356, 0.07785857294596012, 0.12015316875711565, 0.12014152422066658, 0.12787242389975056, 0.17643067715389116, 0.08181203096624344, 0.14448600580855725, 0.127328141412187, 0.29196199149854724, 0.17128866436260362, 0.13984824741078963, 0.09162710348684942, 0.13687830838945605, 0.11030783576350059, 0.12578482664520704, 0.20197587898902356, 0.1526151333124407, 0.22665239840505585, 0.18833568349720972, 0.11011380101403884, 0.21188858175469985, 0.16234444995080272, 0.08612540475423298, 0.11802025740185093, 0.17047642730176452, 0.2227123775669644, 0.06955786472967557, 0.16048254985963145, 0.13506548389071418, 0.175055748512668, 0.14538323266371606, 0.11725744833388638, 0.1466114248239225, 0.24716529123965772, 0.1871611328134614, 0.18658619914804736, 0.1176911230469423, 0.1225346066958962, 0.11199244012635563, 0.1491868438860101, 0.19808949962739023, 0.08308668635905751, 0.1290647631451007, 0.16612788241717125, 0.1496445814207677, 0.10948332597411449, 0.15901685512113958, 0.14179461635649204, 0.1169393303233289, 0.10248938755642983, 0.14531869741697467, 0.2066598324886253, 0.13702971800681085, 0.10144415251430004, 0.14986026581496964, 0.23982577055933016, 0.1691831176679942, 0.13385558591013955, 0.0939857273272449, 0.10499742152469774, 0.07837707657487163, 0.12335685652590568, 0.1625701088097788, 0.18185946729875382, 0.08358715627823146, 0.1404066029335222, 0.12410791380511177, 0.13729578034291345, 0.07136318922763871, 0.21235322940253445, 0.1114651647907111, 0.1498106846045102, 0.1116994038344391, 0.16133434770088043, 0.12599149418454017, 0.11147700851002049], [0.02748248306283307, 0.023452755244028185, 0.061686284494616335, 0.040310163786935235, 0.012924022026239865, 0.03731759835875804, 0.009309959151000987, 0.0656541717809535, 0.041722224709848245, 0.053080914602164304, 0.04362405713407263, 0.09826996679147405, 0.027266327524557713, 0.009163871929500132, 0.028332944080654173, 0.0057893341046667875, 0.05018134458711551, 0.022072255228375717, 0.05605433549311373, 0.042640185734677705, 0.11978008393799106, 0.03447554622506423, 0.036345831148566744, 0.039401407308516004, 0.005023368275649245, 0.02340854239469815, 0.01936250073354571, 0.1581004301025983, 0.03763661652262654, 0.036878185647149245, 0.022139766726702936, 0.030755206844919634, 0.02275528198468589, 0.0005897355015716336, 0.08688945488463487, 0.005102021086420263, 0.07172156515861712, 0.04813497818465676, 0.04918678243073726, 0.037172282970840895, 0.048120774914540594, 0.06983718038686822, 0.032719611415579435, 0.03508996023165603, 0.026087023265239213, 0.07454867474734783, 0.03757347172546772, 0.035351525631643115, 0.04231140761065387, 0.07003240257261262, 0.03990375031266482, 0.01252389526099808, 0.07779471185659209, 0.06164737488894213, 0.022227010734739806, 0.017185460798622623, 0.011047683092915725, 0.023262903334633, 0.09436936883796608, 0.06664250181206773, 0.022000244878713163, 0.008967539873875437, 0.047121987783259926, 0.048573069394596165, 0.06787201930438319, 0.03335375218622146, 0.060717822953818314, 0.02122140159049342, 0.09174534149708287, 0.030110147406136798, 0.014533352504874912, 0.04993367602207488, 0.007313007334878128, 0.04128065929117222, 0.019684370659712343, 0.04814795571409407, 0.029290521427267985, 0.03417876759363759, 0.015496121054785627, 0.009223488891767639, 0.014700576092206664, 0.09413892192946327, 0.04606402802070783, 0.05510963416928726, 0.022201388924112244, 0.017843185586013624, 0.07126078625480015, 0.0319405536227409, 0.046576966020849445, 0.05022809893313435, 0.06101982630488854, 0.04276873528837197, 0.031082316812488343, 0.051405748442536404, 0.006758696277580795, 0.0545677648586852, 0.026343722091687304, 0.10011616208019758, 0.01562545584860228, 0.016629767431426915, 0.05882160212363928, 0.05257458027992999, 0.032848176291032184, 0.039625763818020784, 0.034542751288221735, 0.02246931859953029, 0.08185597376958018, 0.017934361540321863, 0.03837736225837181, 0.008511406335709317, 0.05680934578600911, 0.0626661530846069, 0.07182857231988062, 0.022803662352324016, 0.04780137753714958, 0.022633468259065863, 0.04561790437888234, 0.03691100868426504, 0.07697343495824645, 0.06131486208628743, 0.03329271030041479, 0.06042540719312045, 0.06226744262441512, 0.02998386930313803, 0.04072088650577972, 0.02935930654676932, 0.06377892260770164, 0.04008841963725225, 0.03058240613749912, 0.02584137717231868, 0.028391955833461498, 0.06865767311424979, 0.03434808451622244, 0.03667350993641923, 0.012574603578316109, 0.024662509583117023, 0.020382929848687305, 0.029296238358402928, 0.07224523988101753, 0.04597578618314959, 0.01712826658941565, 0.0678348104139009, 0.060404033340033025, 0.026273029413254514, 0.0765702888489731, 0.04457523190085927, 0.0404974531322237, 0.04162717618108277, 0.03860232014689715, 0.03512907285063017, 0.03717088486037908, 0.0439599292322753, 0.023145906386836883, 0.014738563519542017, 0.02084758898784076, 0.059827157641730966, 0.08232655859882794, 0.049247188463566766, 0.08078718152377876, 0.02850133212163083, 0.05901908809919992, 0.05424442595892376, 0.03252586011864966, 0.07488531676391441, 0.08968883209050664, 0.02077721998155598, 0.041184626339424046, 0.036011521869729606, 0.01907288885465072, 0.06543235102247807, 0.0544619029988685, 0.028366935401854497, 0.09625648854360466, 0.020339276243541992, 0.035650529748489784, 0.06710932514960728, 0.04271407491497455, 0.027884014641806006, 0.0649451727287904, 0.0313515373460588, 0.02332845364787406, 0.06693244310877015, 0.06255001032484636, 0.0513023189118793, 0.04747076846298672, 0.03182223325805559, 0.03647020552307367, 0.050169711541985317, 0.030564125364405975, 0.029516082610033696, 0.035088493173281034, 0.03330963701310177, 0.06348874382374269, 0.06386806842901054, 0.02862055263962717, 0.032278727815156026, 0.043849329118646925, 0.039232956065285596, 0.050880453444176146, 0.06060091793657311, 0.015635190910900074, 0.02595986607634733, 0.0925616924500754, 0.04913673773708363, 0.0569929349266233, 0.03571761989845865, 0.0652515925767441, 0.01209334810189302, 0.03880399279296398, 0.004033632473193951, 0.025450996003083648, 0.029587332617431402, 0.06496071665277404, 0.04177166036360207, 0.013419722090475263, 0.0652336431366782, 0.021801370368789763, 0.007114762932272449, 0.03842842584896473, 0.04391411717440333, 0.03761394415050745, 0.007419905328612415, 0.039506644806674415, 0.03427935493809562, 0.05311372997840086, 0.04242619439478844, 0.02607242545984205, 0.018104168759178252, 0.04404845069192591, 0.07092085006015916, 0.052646627018768946, 0.09647717549195213, 0.03143228109805815, 0.02268243659918587, 0.04651637229647848, 0.016399423944793882, 0.013388750113306508, 0.024747708136396065, 0.025776621675299063, 0.026690524349349643, 0.06840099535521961, 0.016081554912811807, 0.04916941138705419, 0.019104438270592404, 0.015963900087010718, 0.023974576033651832, 0.03330807036329662, 0.03282396025174568, 0.07943159660264369, 0.045578906673096845, 0.03689418539344784, 0.04665147956280459, 0.05199236111835607, 0.08593731484706364, 0.03568160993557784, 0.02026328415189299, 0.05445280187432805, 0.05924801049273341, 0.067541636226158, 0.015543754486697576, 0.012057940475642683, 0.023714879888199994, 0.0814912699523472, 0.05202220407344642, 0.0358820338583281, 0.03773061551093575, 0.02111586148760492, 0.04752874982753589, 0.008237136325107948, 0.017732541422329603, 0.04159646754663798, 0.019169270376404448, 0.037441765889525414, 0.05389782096890192, 0.04826988626812254, 0.0908571774620683, 0.01603145372017377, 0.07482775291728397, 0.024230033797662587, 0.05360085081549422, 0.013548833761183966, 0.04546899603860033, 0.10282155561951861, 0.10258062862821164, 0.03773471025089103, 0.003547120436597916, 0.07648475513222718, 0.043137530015120586, 0.057854316527805025, 0.04183043462915286, 0.08372057815112414, 0.014931279640164108, 0.028552660012557626, 0.0415847655535946, 0.03801453152611371, 0.03347908034019413, 0.010377538105052327, 0.018668622341788104, 0.049795067733934814, 0.014958708460683064, 0.05245123246324159, 0.01431392098311335, 0.041458158032788385, 0.018652639832467805, 0.04088091844272229, 0.043463155687336004, 0.03268084353617123, 0.05004962725985435, 0.0781708610274138, 0.03800913826712678, 0.029750200994913618, 0.03397102370077083, 0.07615339912233815, 0.060689493022378416, 0.048804661604545774, 0.029931114573452263, 0.028546642391912402, 0.046815518139591145, 0.02149768353950593, 0.030746406409889463, 0.03298492298551625, 0.08428224317368962, 0.0503351865336299, 0.026679598020329594, 0.041336062769856186, 0.017204946244976694, 0.02553797762600645, 0.062023830494933554, 0.053431955241267724, 0.082086137225551, 0.05924668516062441, 0.10505883879358731, 0.05739340738904092, 0.052668931668684374, 0.03700152963339802, 0.08822250915991683, 0.03134660182460662, 0.03642417129970366, 0.020682638766424313, 0.08269017457120842, 0.03665036258978709, 0.015692807426075303, 0.06524843629449606, 0.03833906552303703, 0.011582475666317248, 0.03673988762461851, 0.06496244035060368, 0.05998753048779984, 0.0950710517504523, 0.040297569301460064, 0.049510182617532636, 0.030264952708215966, 0.1833944929943931, 0.1563070335936162, 0.14227129158473786, 0.09071133730392303, 0.11055546602414501, 0.12428645825674459, 0.17772781722728284, 0.2080027692981305, 0.1115714211858088, 0.24057077574393443, 0.1907955918220743, 0.14361283411422085, 0.16801645768986595, 0.11246379104352767, 0.09823107250755835, 0.13327784836292267, 0.14403234386155683, 0.10908024115187508, 0.12573061826368495, 0.11802547446061527, 0.1695802423261827, 0.10677152793974647, 0.10796601223128457, 0.1943220477551222, 0.1157129001653483, 0.16601289261973676, 0.2267488335529643, 0.1942512305874017, 0.20337846340431323, 0.1565649141106875, 0.1534664715009351, 0.08452242705971004, 0.19389855435057995, 0.0947504056497447, 0.2019879984999857, 0.11225018274760055, 0.14492581688588665, 0.19397669531885656, 0.26136266247880074, 0.09764436407074814, 0.10385372120166018, 0.12053620505837664, 0.14107009636298304, 0.09838933861183544, 0.17177096267621364, 0.15682244222731362, 0.1343891661494009, 0.11063690883137527, 0.1067019671562218, 0.22123934370615791, 0.16329560939583088, 0.10736492432413564, 0.17807065689515683, 0.14787946887795003, 0.14392625600580247, 0.17580271488235844, 0.11175733540327319, 0.11174165358346318, 0.20972337213254746, 0.09488970341701662, 0.07243609536559352, 0.14236512203370372, 0.12182070468101772, 0.10124620305554521, 0.16058584915534144, 0.11728112045074664, 0.14336558689753856, 0.15328852459788322, 0.18013733228848827, 0.16074119646462703, 0.14241715472552086, 0.11103794053797761, 0.16830685097844372, 0.1543711600524764, 0.14105368675964494, 0.17252574314273175, 0.19951946402509368, 0.18523878838506438, 0.11286345145274555, 0.1057342985164254, 0.15057536292701, 0.20730829527301176, 0.11741615110828031, 0.14385409052333525, 0.10846754701267328, 0.11020039193212025, 0.1987020635316449, 0.11441752209418243, 0.14502136337180294, 0.18175530998456865, 0.1752089660975241, 0.09823596780939449, 0.11560583171705086, 0.17056402179502672, 0.12815114966924154, 0.13563982000754726, 0.12942145368264568, 0.18954334450104546, 0.10385104755480444, 0.14228426911417516, 0.09112018310735304, 0.1563471766008485, 0.06842919505171238, 0.15455924995964573, 0.13050960497029368, 0.10722076189854454, 0.18987882972484638, 0.19052287984278896, 0.17685944124335246, 0.14697274253253015, 0.1400557653077187, 0.18054144366854624, 0.12601279142883517, 0.16128613012692622, 0.16970779596557542, 0.14680570472152005, 0.15130123123526573, 0.11959700424584652, 0.15952719225277825, 0.13334716399831156, 0.14991648134685334, 0.1804470309927579, 0.178059303472119, 0.09699606216482579, 0.15503635419712913, 0.11487830865887866, 0.15236692082497383, 0.0769831795966433, 0.14582209379201935, 0.13619690382432553, 0.11088692928634344, 0.1450417259888303, 0.20465026128916972, 0.10449967887853423, 0.11580760395454785, 0.132891004604678, 0.12069790323655452, 0.1412712557301406, 0.18469318056539183, 0.17469826124368176, 0.11210893145612172, 0.21186399033233044, 0.17201650917770403, 0.13411388011468997, 0.10793637228949417, 0.26924662652515596, 0.10989449302395506, 0.09771662914464552, 0.20803230964849073, 0.10697667862498954, 0.08539821111386822, 0.14667189980466522, 0.16208445503106042, 0.1518619616305636, 0.13296972779977706, 0.15388826419028545, 0.26289839297533035, 0.2712661262241102, 0.1136731680843138, 0.18015081543595562, 0.1497345507865952, 0.16603095697299128, 0.13157284307864406, 0.17783482438854634, 0.2344494574372807, 0.06796571951840194, 0.1387610001068923, 0.11613721328396952, 0.11119226895032391, 0.11448805580937094, 0.27262642258597963, 0.1305001974105835, 0.19158412612253622, 0.07529493631614793, 0.1614089186994299, 0.09625248956463991], [0.0314347057663385, 0.05839312531714959, 0.05733445309282792, 0.015648899096695167, 0.03498475720745421, 0.07775906578547533, 0.01256413019878129, 0.03800107519172373, 0.009196522596832967, 0.009844834078854371, 0.049072072255395116, 0.07043377135790165, 0.0836167655765049, 0.02715708721699494, 0.05636471218519634, 0.007119196666134222, 0.027106000643764293, 0.04220712006152157, 0.04324681628795882, 0.019114571698610822, 0.09234079865798836, 0.050847377598045335, 0.058213956503858494, 0.0803271227426106, 0.07934307514299309, 0.02288223616027784, 0.024583834268513228, 0.022990455655681512, 0.02419848821216053, 0.041423894750374946, 0.027785237180069092, 0.018425115549396125, 0.03320171820720838, 0.03309130195468184, 0.03666270043580763, 0.07632662692377645, 0.04747877025135583, 0.018387943048090227, 0.0375504890877393, 0.1072786551629824, 0.04303724144495303, 0.02199877973555798, 0.06824325785161027, 0.0065705862606034405, 0.08296464089184039, 0.057223240108860124, 0.05772071462425013, 0.06311327264073395, 0.04448764123803666, 0.09108436083601368, 0.05169867748214353, 0.04043675598598296, 0.03205499183686991, 0.01154710921729284, 0.04643970604745611, 0.01522372508676903, 0.029807598217420524, 0.007250747848076807, 0.016371122741651152, 0.011661753317551508, 0.07372858528528484, 0.029735968996500297, 0.032188214526902285, 0.0606617491482006, 0.025191485633953445, 0.03188313150237645, 0.009978991396154368, 0.03172871498991886, 0.05917479930024955, 0.11157027205392239, 0.046710299793630845, 0.042091348854404305, 0.0479438430779884, 0.0043232673347266696, 0.04527789157544894, 0.014773523941966555, 0.031287498141248385, 0.032518440557103005, 0.0659557959185012, 0.025462837807173212, 0.05482033638644123, 0.07785421390567096, 0.026653156495623054, 0.04669951710609659, 0.05532308158675029, 0.03295738978551761, 0.025281372645329085, 0.06946599546579585, 0.05352380152250971, 0.037749093551669395, 0.11876894746937099, 0.09336267567930684, 0.02923380602301369, 0.04813114008415611, 0.025710094599954547, 0.04057909129187465, 0.024026476575302023, 0.08262527926314263, 0.031589026517805555, 0.04394861028319405, 0.043701363066511775, 0.05175876941892409, 0.03058156344078241, 0.08971850267581402, 0.030750945480840824, 0.033205081333195975, 0.018416410875356486, 0.015622530350341432, 0.02993984031490982, 0.05914071604849831, 0.037320762301885316, 0.07049446084326313, 0.027054297369754603, 0.036560174888901176, 0.04398298847879614, 0.09154517804422686, 0.018150022951886058, 0.05681047576569742, 0.015459987560227035, 0.048821304864700765, 0.060458429413096565, 0.022177986853245287, 0.06701498908261139, 0.03788438467909733, 0.05341825758918159, 0.04400268842976901, 0.034013399854302406, 0.05678694537510315, 0.02287980574633806, 0.026258584825442206, 0.02868657601216147, 0.06223293802430553, 0.05831763884353061, 0.04654493588473528, 0.0289164349481824, 0.035432593055790475, 0.019904659242339192, 0.04558579763397575, 0.05178319230195015, 0.05426699873961268, 0.06446064509932073, 0.0729518027735814, 0.033512700108751174, 0.08936699855351642, 0.06565759619397503, 0.05780705656375616, 0.047021411930120764, 0.04112145089874825, 0.039152827098845475, 0.09847799030643317, 0.07782885639537727, 0.09544578365861409, 0.05064256782192857, 0.037752835891179504, 0.0212611481472249, 0.08895264457791083, 0.03356266819361237, 0.045632356627573895, 0.027643097226598093, 0.027547378370898868, 0.03085272792246073, 0.04616861817457023, 0.12073683582486645, 0.016292558509796377, 0.060958677166772474, 0.03485835653038756, 0.05341517408528636, 0.025877871685811592, 0.04547081166698087, 0.0351047380677154, 0.03816268143935069, 0.05753439054974625, 0.07683032973399086, 0.041342287234240965, 0.011127029692063169, 0.025943868245268543, 0.0974021730343661, 0.10616209733510211, 0.055775839550000046, 0.023090460773317084, 0.03547457084360142, 0.08467510072213989, 0.014426215108664287, 0.07386953014159396, 0.028237458881771857, 0.009019524685197301, 0.017520179934499246, 0.040276770014315844, 0.022677470434216723, 0.05850890801558572, 0.03069338546465001, 0.06535948839999976, 0.01465829474205572, 0.010737088065774692, 0.021240672532228694, 0.026321712385622725, 0.046874418809649446, 0.021584958191059773, 0.03339788268109964, 0.1099426799543923, 0.07212206060367246, 0.01704707850642022, 0.06560159516671012, 0.06589668457426372, 0.02319377347556574, 0.016577773044006, 0.017387485845134627, 0.021126339655189265, 0.09759851370847995, 0.0500215194939125, 0.037797418377933004, 0.009834055221759746, 0.07310024763066923, 0.0030818884073185826, 0.04409173082920813, 0.02885533943622103, 0.03915790243134384, 0.029302677327406504, 0.08635993491137221, 0.05384014220908285, 0.02339314019698049, 0.07431114152554544, 0.056159477230281606, 0.028855310707923867, 0.013813445318279969, 0.03901301222222467, 0.009682058589532971, 0.022091943688029726, 0.040559065753533956, 0.017086039823029312, 0.09619139405267854, 0.008163003911895138, 0.04688866038416182, 0.031248663229146795, 0.05050783210824575, 0.014020291930665413, 0.02754621391725396, 0.03514465507901004, 0.01272857767499743, 0.02086791138525211, 0.024817148261072657, 0.036715349828403805, 0.03339936506123312, 0.08696641607750809, 0.07618030413023888, 0.06050230326852011, 0.054757065184774904, 0.03378910080139195, 0.011718186226883724, 0.025146502866259506, 0.06599905690358532, 0.02892395410115921, 0.034130829641775745, 0.051015476440830584, 0.01689293012473612, 0.12238700453552509, 0.042585640274468935, 0.08550540213623355, 0.04335341742262245, 0.04042695389099179, 0.05203459171518203, 0.03810553894107861, 0.07186018876851567, 0.03595935894296535, 0.017677287330790874, 0.06508581881080905, 0.013148045287497584, 0.04071140233727713, 0.01739271056477822, 0.04652586795629994, 0.012337335614457488, 0.021141939120547428, 0.07893792954423735, 0.011790988519938003, 0.012555370940977048, 0.029882381805368972, 0.015220380155369641, 0.05490367143084446, 0.061040211904553644, 0.04808368859812618, 0.06206123090739693, 0.05121194351945193, 0.08736523379000925, 0.04780441890620897, 0.038494389849684896, 0.033800530833222216, 0.01717974578270749, 0.06318338500756411, 0.03933743130595934, 0.01092908789418758, 0.024994955353078344, 0.013049540744583695, 0.02913079784071494, 0.06517743526567375, 0.04497000466912024, 0.019985182744060314, 0.047484086901550336, 0.07088940215086745, 0.02863912835657116, 0.036081247362157995, 0.0642321976803003, 0.03243180367374613, 0.021296550985425714, 0.03700268642616369, 0.0510931002997583, 0.022108602269943205, 0.03584997307869696, 0.1237441216325087, 0.05138648516168037, 0.03909102678599377, 0.02260026409320774, 0.05329189521651115, 0.019018783894998413, 0.01354280464921988, 0.06089164447339793, 0.06266426467787355, 0.03259254041157904, 0.04879191007104613, 0.025973707369919267, 0.018795658871831915, 0.07145731079001581, 0.05031865435622392, 0.0422080738409873, 0.02546277268969965, 0.0424028670174941, 0.02147304806708088, 0.026762126757192518, 0.06855110262310313, 0.05367064525583579, 0.031587597763826775, 0.013990219149197784, 0.030980203037841186, 0.1094991839941471, 0.0596833054817492, 0.03778894927593009, 0.03301904071122408, 0.028208230712240743, 0.0158192157640212, 0.06717101821014959, 0.042490672184935505, 0.04225401230336678, 0.015001054928307573, 0.050434295328394066, 0.016064208766986287, 0.0379742965883305, 0.03615677214017318, 0.028021674896139773, 0.026183289873804298, 0.07254526289480348, 0.019947801483795047, 0.013128135619955439, 0.05329166922057348, 0.21492095694186228, 0.10112772755805524, 0.14026239454265566, 0.1375692584101231, 0.17879819527508753, 0.2287088388637189, 0.09724065105641082, 0.18391442154684376, 0.12939776624402693, 0.14489626121376792, 0.221902055725936, 0.19959847833360397, 0.21117562968884745, 0.08896893160718103, 0.09810466033917281, 0.09912967832098085, 0.2023037646206156, 0.0822623374481355, 0.25232011302103924, 0.13677701624410768, 0.13381515178949605, 0.10016519936823076, 0.202040383592248, 0.30896914341757375, 0.20998073170983025, 0.19152919761836532, 0.10840869613833005, 0.23354948798735298, 0.17503913972646962, 0.11945101087011638, 0.11245752444430707, 0.07882464046199476, 0.16226166648970497, 0.14343067372758544, 0.09516289037081505, 0.18038811883138073, 0.2106912476160834, 0.12438134590704596, 0.10128478324341197, 0.19326354407014387, 0.13939058648482447, 0.09923220386788731, 0.27501695398842135, 0.16119540999493293, 0.19199634271283306, 0.20841760590912836, 0.20272928049727795, 0.12136315100736196, 0.15139414237872248, 0.13501763403896364, 0.15198804438114166, 0.2257534248694297, 0.17847121362724613, 0.15400945929990661, 0.13294250103494815, 0.0816715457626889, 0.168954961362385, 0.13134246511805442, 0.14618485174592466, 0.09247601317662386, 0.08627213357437043, 0.1393307090526627, 0.10965358135440659, 0.1218223670918134, 0.07232285990950561, 0.13886485098590776, 0.09914998731185352, 0.15927133420782705, 0.19791392759690363, 0.1617697307900075, 0.1536564153408812, 0.15923298384633758, 0.11691466995304632, 0.21110636001873404, 0.19707973445615462, 0.19253349292182154, 0.11942593681235468, 0.17138448664017264, 0.2250538027334598, 0.24345963201936216, 0.12559602427626812, 0.17403717333030316, 0.12515074333115933, 0.1229270582177466, 0.18399015699903812, 0.16877183570496498, 0.14819319720470137, 0.14345528047171333, 0.12970343532581485, 0.18773825749033884, 0.19705528092961158, 0.2404045040208486, 0.14365625597776907, 0.14555468314117, 0.16507083429924904, 0.10913822634686386, 0.15464198745546803, 0.09265654945685979, 0.09188902128728167, 0.17017731593260843, 0.14859035250640687, 0.14620766584430972, 0.12081137617989895, 0.14971844761842681, 0.14380184332689933, 0.1306704374691171, 0.14516344203823997, 0.08492839237254474, 0.08768274659110654, 0.13596189869267328, 0.10355039634892058, 0.1363127822837522, 0.20348277393608324, 0.20686523598288337, 0.1653715544530461, 0.10839981717928764, 0.1513507818022082, 0.17815584587233682, 0.11162470260094251, 0.1318011526018381, 0.16806447608095987, 0.12046236950423449, 0.11221470521582712, 0.1169409237862114, 0.1526003324937436, 0.0846114771200284, 0.12282539068931535, 0.18420692923809254, 0.13752163838474982, 0.11297619661256192, 0.11770492795133784, 0.25860931183541974, 0.0870041459077789, 0.1780350338066778, 0.1507020585479275, 0.17631332780564987, 0.12291749744045159, 0.1305724088583262, 0.1678024280455805, 0.19733511752659277, 0.19447883530970544, 0.1361543706227695, 0.1201172392334669, 0.19645439220532296, 0.14928412173063527, 0.13300182688380444, 0.10975514929140769, 0.2615258698501895, 0.15184829462199442, 0.22873543743644992, 0.23863883989472545, 0.29197176678046105, 0.18377301703778007, 0.12712023281041654, 0.08239900753382715, 0.23774987146739038, 0.18980048957370943, 0.19075520366670626, 0.12017002269144982, 0.05791975192785744, 0.10892748321977355, 0.07642981896717703, 0.206198065331386, 0.15093026081881217, 0.1675223769439805, 0.13651132163020874, 0.13704284875383302, 0.16333228968564542, 0.18614405916342813, 0.1408877521152458, 0.11514594913610529, 0.1929181150250858, 0.21341272900181435, 0.16671337277418183, 0.10895688567430743, 0.07952632337448098], [0.02390806236484599, 0.03210268464059599, 0.02750641564958759, 0.06525625805220296, 0.07286643759617883, 0.030243293487376748, 0.08022108851301094, 0.04777019392819174, 0.033640698079139955, 0.036752769393065286, 0.043271963124073325, 0.06297482140061837, 0.07527567686573153, 0.0791909147594725, 0.06405555312671969, 0.03456921962600562, 0.035229675516846685, 0.06752528790985385, 0.04799671846652224, 0.020628865139799255, 0.04498509660122856, 0.05437488307154948, 0.04473983355227017, 0.04397031738452854, 0.014516478460732729, 0.05467278402178519, 0.04047537830868556, 0.025998835053835666, 0.04892745017704945, 0.021107281302852977, 0.008704957492168873, 0.05474322197598316, 0.039630892776673844, 0.059091222938150174, 0.022568159263520952, 0.06234458767839017, 0.059633184179303154, 0.02668650430296698, 0.033962730798990495, 0.057591464100105155, 0.03564889798121106, 0.03012790723944143, 0.0026958770514841405, 0.010492912861668776, 0.045609634459739735, 0.042351075643373114, 0.0391049389426987, 0.012153197763367526, 0.09277188399386022, 0.0465694047330368, 0.041205996362071846, 0.07647674951341844, 0.03632517358768852, 0.056250817893493565, 0.1024655775437432, 0.008419486318504619, 0.015407850488930222, 0.012096825183459349, 0.050245722785832427, 0.04711813053056117, 0.06893154188630081, 0.021251681215700605, 0.03440850204037082, 0.010287511282630507, 0.025567270913011125, 0.1025742317940439, 0.0401797947744208, 0.07094065343300182, 0.03612070472069806, 0.03750852662168684, 0.10045553136977459, 0.05622164526533696, 0.08819945757427523, 0.0653369807367844, 0.04258555217435764, 0.09494020393298519, 0.01385992291503616, 0.016877667738064643, 0.01660530815922445, 0.027721785947740562, 0.029532264302214308, 0.10529271011511165, 0.031798831187188625, 0.026301780693052758, 0.07387156793547255, 0.07949648424983025, 0.01678233767198699, 0.04967843850834235, 0.046790103172703136, 0.042704487324602185, 0.04154551886923371, 0.029119408028500698, 0.08050847107604628, 0.02766587110536714, 0.061496371298187205, 0.02872767088363969, 0.01491567538675642, 0.02328437103349115, 0.0381247217827026, 0.012723291668319895, 0.05595058037508881, 0.03289341761340057, 0.03476534579550067, 0.07231027308490968, 0.03818734947051253, 0.024023532882452975, 0.009457487575409394, 0.024286189957732157, 0.10323754136240292, 0.0424287646197744, 0.037091843738791444, 0.04255384379517167, 0.08699000392469668, 0.03540073528945927, 0.0550752061779701, 0.026336440425967018, 0.0335122213037985, 0.08068088682428484, 0.01982027657269951, 0.04304494445903167, 0.027205977033102707, 0.08710879351823561, 0.045116522815078504, 0.05193624900834215, 0.046864934641146855, 0.023691203940900105, 0.07144208096208111, 0.039165321992890495, 0.03191518653634816, 0.02345959066353258, 0.017440930053952242, 0.03856580456598632, 0.013192137477979546, 0.03675144406095628, 0.0358091750662894, 0.01664701015538266, 0.0017950528150146468, 0.010252023217148118, 0.007696461632862808, 0.03097204037100798, 0.1257448751599558, 0.019543169163948586, 0.03701602401692541, 0.037300491615408854, 0.04516064564907744, 0.11156793548575333, 0.028441494909085097, 0.028154455170395876, 0.06622837000196019, 0.011812049234586378, 0.051996425214794376, 0.039812183653515194, 0.0843621155006751, 0.02115817060844312, 0.016633885154019923, 0.04527193907227728, 0.13205742433426843, 0.022288439494948235, 0.023850799207725835, 0.053061379360095154, 0.02245771236747744, 0.08211681904691844, 0.043557556871805465, 0.016358292684139266, 0.06419525309015187, 0.013187993899919094, 0.06292581092566252, 0.024585105974467534, 0.041167420004644704, 0.015318539001107698, 0.03757265967226798, 0.03140396265793712, 0.028263917643456694, 0.04790744624070583, 0.045290600974112756, 0.025725192277722304, 0.057137905574974515, 0.04266981801558887, 0.013435072577258032, 0.01881055162107993, 0.04779062932357193, 0.07736076135188341, 0.02646033791074109, 0.01824370784414632, 0.028239420066858013, 0.05494361142477682, 0.11409940408362497, 0.13153726595544046, 0.041086930976880175, 0.038525343632265445, 0.05384745834875972, 0.013733810478551014, 0.047003880007973606, 0.032658224790206844, 0.03272885043594626, 0.028757444890816847, 0.01710070274590004, 0.015925764230140034, 0.03458708479639984, 0.02169678021492737, 0.03998672912618326, 0.06676497628852245, 0.06282926469500508, 0.012311787539792639, 0.033874194017581405, 0.06692907232190333, 0.06483274932590223, 0.03666689859763269, 0.0116832641088554, 0.06060237733406886, 0.04039094775855061, 0.007320219095075324, 0.024732744524015055, 0.02989827812979779, 0.10331541419990602, 0.015869410802429963, 0.10747027673548269, 0.04452174747242563, 0.014715610567720668, 0.008885913205543354, 0.06484190407659739, 0.0607130961913255, 0.021848576706683925, 0.018683260366801294, 0.02493375833446701, 0.007031729056184451, 0.04779206956886957, 0.026899802333284772, 0.025122807766761512, 0.07351393510978069, 0.08975339031988576, 0.1225635265150378, 0.029168585127580072, 0.09648970869039336, 0.0440584902741736, 0.05723392320496421, 0.03575526928949741, 0.030765056820406072, 0.0494550702522599, 0.04747734532781667, 0.05761070056788384, 0.07652466831308219, 0.036763655502469315, 0.06619748899773245, 0.00561112960455038, 0.021827670167230313, 0.04008481519356851, 0.07891312361724916, 0.03961067571635208, 0.023213201465325493, 0.08621932713374977, 0.09710164440255012, 0.07829186461505391, 0.024067479516229322, 0.0340280206423373, 0.056856663206652294, 0.03662883551911481, 0.08574649766688386, 0.02771997989545907, 0.06721058665143867, 0.041016270857184164, 0.06224362878128887, 0.020421584730126688, 0.02072709484867031, 0.08066993942784687, 0.006674417987420795, 0.06723731545911682, 0.0037424029517663464, 0.014806976128790169, 0.04643521294178021, 0.02484132982640257, 0.03490511853728564, 0.020971329424590356, 0.031229137563176697, 0.03208523124246107, 0.018004408789678447, 0.029226930383893273, 0.0487060162929758, 0.02502296544280985, 0.025896947275126175, 0.08457743217267337, 0.024269161738395214, 0.019748519032051968, 0.03730360959326068, 0.028034188942382895, 0.02342064658390178, 0.08091214578598738, 0.02626231184319383, 0.03543808590620756, 0.0660018454636297, 0.02171989308760291, 0.022175698165571498, 0.07482089643036166, 0.055183799141236854, 0.04038304556161165, 0.05209803911707094, 0.05030069342483917, 0.06850732835910975, 0.050584107652426734, 0.12157650649427407, 0.09162056875685531, 0.0891771772876382, 0.016554355651380557, 0.022974942375214833, 0.05812886328766904, 0.04293768448875316, 0.009447174116728768, 0.040953888317510005, 0.03660937688583809, 0.02680525942254932, 0.023238618347433307, 0.015805129322313493, 0.024932735607088096, 0.09838783707950385, 0.030826939487709638, 0.06422591192888157, 0.05644486030383457, 0.03189642312786272, 0.03652757784772304, 0.023029516563720764, 0.013679708391728421, 0.07584337866114033, 0.014807439611984358, 0.06136603675962937, 0.025836587207572117, 0.07203432821458386, 0.03839482906304541, 0.030929872976435773, 0.1057463950447498, 0.06048088345015722, 0.013750385748402727, 0.026715527543978348, 0.103675038854201, 0.023364316138829437, 0.035733688592670426, 0.12650416022346866, 0.052201702304544954, 0.052741338468847744, 0.02640836459073809, 0.03938930311931237, 0.027321033863230582, 0.028785318999941793, 0.03852338244717929, 0.022499854864192106, 0.03360183826918083, 0.018953591727861957, 0.03909782964676138, 0.0679893916352622, 0.02442878190307848, 0.03827944089989028, 0.03207155465779286, 0.019490249725359104, 0.118396291659484, 0.1418928288283848, 0.13131404325606363, 0.20578807039606958, 0.18561003459317071, 0.1673891848974651, 0.18638101015840808, 0.1385311124425742, 0.08687260095030071, 0.1172042282057866, 0.27036441009371515, 0.23985482061341887, 0.15021095022318826, 0.15445552165469817, 0.1252033888933159, 0.09143735882976363, 0.11472977953211916, 0.16016497577150024, 0.21650993054912937, 0.11326914097392753, 0.07952090713285631, 0.14601565356696808, 0.12854264358118658, 0.24932470923710257, 0.19531984663298055, 0.15346077180677845, 0.13708856888115406, 0.0997746171009156, 0.11407369417288613, 0.2167270092233535, 0.15249467364722682, 0.1642413755818721, 0.1646971825750605, 0.1469561797116072, 0.15805084889213886, 0.17246012005113787, 0.1533439433983257, 0.08831578036469799, 0.1526364152349772, 0.1453076810726235, 0.17403155024493897, 0.13219418635051097, 0.10010152213996458, 0.10777477370274645, 0.17475821528463595, 0.12240449432283641, 0.13755620427189336, 0.15317897402471112, 0.1804475519325464, 0.09359818642898914, 0.1082778559817422, 0.22438885373694284, 0.1168635182623421, 0.09287227215545793, 0.2533890661453047, 0.3076798480845267, 0.13062847117262502, 0.1411535999467296, 0.12694151215856114, 0.22397734194753632, 0.13605211320663654, 0.12040887358448199, 0.11915193780535653, 0.15174182372227793, 0.11050426070728611, 0.17167003825306895, 0.11156435019426769, 0.17216234167497005, 0.10766551424298557, 0.1800131800794794, 0.19809340667580405, 0.19489457590445397, 0.18357265440206375, 0.12306015067283185, 0.11864320945835884, 0.1746259272218712, 0.1444058730116775, 0.15612691100085938, 0.15596597124972653, 0.11860034683899534, 0.12263130997457813, 0.13177175014730425, 0.14878031166811145, 0.20297957674389888, 0.17759070281059514, 0.17012701459950016, 0.1444741314457309, 0.07745295237269133, 0.14344691479158017, 0.08586592311339994, 0.1553167270556573, 0.08179985016824738, 0.18296499346052447, 0.10331325383195955, 0.09470067888257966, 0.11049640830606224, 0.1124058977790898, 0.13188195955609122, 0.06765918475725959, 0.16543559940351596, 0.10585525613879004, 0.12131425161515513, 0.11486939905631928, 0.15238095555574666, 0.13257156126201153, 0.08060767180136136, 0.18785490203768979, 0.12762552142263422, 0.137011990732243, 0.13257131611387576, 0.18973152633876572, 0.11376348985058647, 0.1440092692932775, 0.10720363983343686, 0.21117840292713336, 0.06985105423917694, 0.2000769155640756, 0.1702646499559764, 0.12143517859400281, 0.13422199044256442, 0.1258997934600038, 0.24017188908352008, 0.10080627706502715, 0.19215213435311473, 0.1511341014937047, 0.13172780734396752, 0.11024522339744915, 0.07112762485180171, 0.10881187289112038, 0.13550537157683604, 0.0711300763331594, 0.1428831353663437, 0.07275571490848258, 0.12822078706155862, 0.0777794667068989, 0.11797613073741237, 0.05058591178948841, 0.1623871670134606, 0.04863926705213324, 0.15794014918708033, 0.21100483804700837, 0.21026553255656075, 0.17748573344321023, 0.08282454639312722, 0.12060133019281973, 0.1330285939958788, 0.0991986109124076, 0.12058279086505214, 0.17021753554863317, 0.11707035434101859, 0.19930817697557712, 0.10570427553067285, 0.16353122739782258, 0.08783704435993588, 0.13475154105934406, 0.1507758328150357, 0.1598465589866523, 0.130076443536147, 0.14741042388543008, 0.2372820215720323, 0.15705320323186536, 0.14939849865773033, 0.17011530877601716, 0.1988168388244606, 0.1258896810994033, 0.1606019829670268, 0.17076377156040362, 0.1019673905665836, 0.13917637297943716, 0.17139959389403944, 0.12083615146337018, 0.13070414533778546, 0.13163898711002645, 0.11072281027032484, 0.17079694316752497, 0.11662867400915393], [0.058531817874961325, 0.01755868351357358, 0.020660573518985224, 0.05383561845988997, 0.00986539779396187, 0.008490672166038667, 0.023206678226650245, 0.058447981042967695, 0.02133868390604133, 0.048582430989030874, 0.039610855747014284, 0.05366714040358221, 0.03207407891750336, 0.02693721423706701, 0.05716186114436677, 0.005505846619921467, 0.0950639654371527, 0.08436956953617834, 0.048445711107624155, 0.013996894647847983, 0.03920062715488096, 0.013339727189421896, 0.02683044647827985, 0.06769476188046318, 0.05461345051204967, 0.024831477935696324, 0.05545888982352711, 0.07674843493488527, 0.01138051956771843, 0.0049280444340359785, 0.02809273529677622, 0.008239131984150699, 0.12958260793839732, 0.026542954747715307, 0.02209878102275393, 0.06065479306984813, 0.011914778752402674, 0.068744761989482, 0.02962609092074056, 0.018595359438369354, 0.040009734746549404, 0.03397612201590692, 0.02749819169572044, 0.030040366372333902, 0.033623867127443516, 0.019428139146898064, 0.05063091945503989, 0.01840391215087185, 0.03165416505878731, 0.11557578574866058, 0.01328128808733797, 0.03738774136910516, 0.02758245370651205, 0.040676560658480854, 0.01954516482299134, 0.04978823422965023, 0.018869760641527754, 0.049981794004598935, 0.03967969257745051, 0.07430250005375955, 0.034268116428246426, 0.08142625973109277, 0.03447232099490301, 0.03862762403103613, 0.0033848204005945235, 0.060815472351086725, 0.039676482669047775, 0.02396181875449275, 0.04783410481327484, 0.05074192176482851, 0.033187844354899666, 0.025581284576366027, 0.04920197395427574, 0.012820737094678467, 0.011729048396040116, 0.011056403088713846, 0.038793148818395795, 0.04274746485715432, 0.020293789773037838, 0.06188387006160714, 0.010780520463031868, 0.034831658366226384, 0.005002534514548438, 0.011061420007007978, 0.049595321798997546, 0.03064683604715092, 0.05754028176588397, 0.06233809125279227, 0.040388071098394936, 0.015133975971219762, 0.027391012164673982, 0.09541108753652343, 0.020004103200570233, 0.007103812184199812, 0.053223525699708736, 0.016491477069775426, 0.04232390250469889, 0.04329407242156806, 0.08550492716172049, 0.012022326963262693, 0.10679821078214916, 0.0348122418677855, 0.0649916895875527, 0.050190981973202965, 0.03173637969960128, 0.04183136925642048, 0.04176932762587263, 0.0825869212407739, 0.004286712013004769, 0.07655332000145028, 0.032841840743898384, 0.04562872154037318, 0.034456960932021184, 0.012805294677344783, 0.005377426822369378, 0.03067585354250285, 0.09105900332571999, 0.05032296360079801, 0.016909402930327964, 0.037320762301885316, 0.04031122481871036, 0.052377638226795586, 0.014381836592820624, 0.020010530678254944, 0.036015877079579144, 0.07688757948457234, 0.030382503154537374, 0.03201418807880292, 0.023304406147930893, 0.042742623181472865, 0.021542470954779177, 0.02139615199168123, 0.035511040459236795, 0.042288532225234855, 0.07259828384004294, 0.02611270827812053, 0.003645016179014478, 0.0424899558927263, 0.0535411610748739, 0.04046910787902532, 0.04011867244938209, 0.047359670392207565, 0.09210299730541245, 0.06286874120574325, 0.03251906108832167, 0.022938752381671822, 0.06533769319855398, 0.07332596777667923, 0.08194045028499058, 0.08004605274407134, 0.08602250382424363, 0.01770562683832982, 0.025463222766355164, 0.0339347226244788, 0.0600986477107771, 0.0782929371381479, 0.033134570600645195, 0.13546542775246406, 0.02030955394729972, 0.01974259142673785, 0.0663335538739639, 0.01386156042797431, 0.03074356805413, 0.01560427447510583, 0.04633863223716617, 0.07523996184670156, 0.03247514126762267, 0.0028846818144478265, 0.03832087476527499, 0.037954604298236876, 0.04107185819696996, 0.07826069249741494, 0.04418663763170762, 0.04832190746862081, 0.025319069916863116, 0.040368758021823825, 0.07436767115347809, 0.020763556803426435, 0.025429978380881013, 0.07700929553398202, 0.02379678809384425, 0.025596156258196123, 0.013721988784269461, 0.044067916986081875, 0.02728254943635435, 0.042689602236233415, 0.051162324004596284, 0.03601779996026908, 0.038117221781923886, 0.0852216125255631, 0.03907272111504309, 0.038501292301882664, 0.02245574352151204, 0.03571029992834215, 0.02842408364578601, 0.06109168918262567, 0.01139744149235588, 0.03090102593564699, 0.027948800782342593, 0.036355342130146684, 0.0446283217940119, 0.08124601456426805, 0.04546280604817214, 0.1039964740254706, 0.03095914902646215, 0.020349120473368995, 0.02652641107899047, 0.08186776386273485, 0.020298667837895697, 0.05967442269226717, 0.026982221902618488, 0.03688139555555198, 0.022220204043532574, 0.13882352820327207, 0.031227471321941386, 0.04278186986583375, 0.011221308302464745, 0.061430238758123694, 0.04725924392621364, 0.052855362995497646, 0.023925266784405517, 0.06693194515161938, 0.014864127245551396, 0.031106601799688036, 0.02201634804688154, 0.025262467510577653, 0.019591777442744183, 0.012762205104433723, 0.042557478882372386, 0.04979588361757417, 0.03424055258473081, 0.10853942904260852, 0.006860749243998961, 0.03416562918573618, 0.019397162381679784, 0.07936996482913533, 0.009471496450714767, 0.0790162007474611, 0.058463532627830585, 0.06597288734009189, 0.05167221297479926, 0.05448062618773791, 0.052443935475762815, 0.025369068645241282, 0.07589684393737586, 0.013896152170585289, 0.04257908639227671, 0.07618228063708352, 0.08435202612271232, 0.02909660542143449, 0.010840024427330543, 0.06373350508511066, 0.08914487135987129, 0.026544944661098625, 0.033671521626773386, 0.04756740279375546, 0.031581844443515424, 0.028735257069309874, 0.03495675669382176, 0.05085427238936386, 0.036405225945336205, 0.0015115871158946728, 0.07034963192117792, 0.07214221637696028, 0.01473988310599159, 0.05368026732016475, 0.05277182493779448, 0.05432163996081199, 0.029958048309650154, 0.015376687947390302, 0.017071520541644385, 0.028273980208342115, 0.07445746431908301, 0.06061047105298889, 0.07233393754089072, 0.03507050542881893, 0.06509485098743631, 0.01654486190677891, 0.05188264966671986, 0.0239889057082755, 0.044558128987949704, 0.03699134449444471, 0.036674187924232216, 0.03106750258725257, 0.03826712603650747, 0.0714629108927423, 0.03753188847293777, 0.03485579396628084, 0.04022076515661132, 0.0412864355941213, 0.07430540352699257, 0.0624058900340911, 0.011693942416909964, 0.05097863144211231, 0.03492076588313907, 0.07564438732280847, 0.04666598926809046, 0.015312496482604935, 0.014709669555867872, 0.07970957160596887, 0.027788154059840788, 0.03987707896158099, 0.04819505479967883, 0.04132576271771424, 0.06870536208753625, 0.04977256390115908, 0.06703305343586592, 0.053118594636720036, 0.08019632089041895, 0.052189391271601764, 0.01443250660574244, 0.02420487930066884, 0.034092797206774834, 0.03992493264377117, 0.06537998125197426, 0.02357999670259174, 0.0211055671811224, 0.06735315561414727, 0.027878138747426773, 0.05658734116643187, 0.03499207717757072, 0.04445447729179456, 0.051251818395910725, 0.037699608102200494, 0.012002495819732789, 0.04049313239633076, 0.043134293293640505, 0.028505105104657914, 0.02810418065036497, 0.025359266550250115, 0.04034061578192538, 0.07362606739925762, 0.018310786502796318, 0.0395641818402275, 0.029307563053143602, 0.023380070736992265, 0.018396571113337434, 0.026397256315836025, 0.17679628495487476, 0.04665660852145764, 0.044216139677671656, 0.06462819618924011, 0.05037799552683869, 0.07623616726167741, 0.0812372888228105, 0.034530497711872866, 0.04053456626171547, 0.059251205079377665, 0.051062406987072005, 0.013506995784419199, 0.06283482649333536, 0.01547226794965325, 0.15980515959522418, 0.13277216904586361, 0.064487504141946, 0.14783557203988876, 0.11890592399023234, 0.16603984359291293, 0.11644800749397087, 0.20180556232169752, 0.08715412294071528, 0.11487748128392043, 0.09632104677298377, 0.24539495397719646, 0.09233797945442701, 0.16185933243363135, 0.14806388156308284, 0.09319458066696122, 0.23159738870397692, 0.21775781116898985, 0.08963710583385923, 0.14564514280326907, 0.0964200406545593, 0.13340359403481408, 0.08489270799703176, 0.07668137925887301, 0.17904623922321106, 0.12205380991461778, 0.13243668382206272, 0.1834234511179309, 0.13101963566676264, 0.06814542842367965, 0.11138161524168907, 0.16747918490680958, 0.1578431930993834, 0.1162330662050555, 0.1580497304037694, 0.13695153107325878, 0.10187569750292648, 0.2684252883397764, 0.10211134614843516, 0.09835866445134725, 0.21307502212303303, 0.19353037249417077, 0.1266549339878463, 0.15621743194999235, 0.1392153974983, 0.102019147466748, 0.16133813217522638, 0.12640502078518753, 0.20386705896066082, 0.23357974846036206, 0.08212265663690145, 0.08150938793175644, 0.09799672621152095, 0.3079330554652599, 0.1103334843872055, 0.19451568413886333, 0.06195708891497024, 0.12589665249951426, 0.13448037657766573, 0.16251827530082197, 0.12606183637774762, 0.1902152495759149, 0.11015303237664123, 0.1478469101411681, 0.16013790222425617, 0.15464727346214557, 0.11017023105054133, 0.1894695395904203, 0.17530069746557744, 0.20281897407145272, 0.21749821461496816, 0.16791994593316512, 0.15752318285165295, 0.062449331049837416, 0.09330803828854715, 0.15903588474517869, 0.12739574867150477, 0.12809823597631148, 0.15711173234928041, 0.14390273710652707, 0.1255363536878459, 0.08941151592279635, 0.18953283377472432, 0.1764384146419264, 0.1365667097871342, 0.14669050041946674, 0.19788225752211389, 0.16715497649725408, 0.15783367828736383, 0.1808439717898446, 0.14729760977770054, 0.24074709854058682, 0.09983388166273795, 0.06544757318953354, 0.10099371579746086, 0.09077112280553387, 0.1400050809306483, 0.17543706111609939, 0.17716803678101112, 0.10333462002416773, 0.1742267954133211, 0.07656956872632427, 0.15487121628417125, 0.13662220519636908, 0.09473133772130936, 0.09542697620007301, 0.14803162926147062, 0.2652396189589655, 0.15643939826517336, 0.13013572341972782, 0.15664221238224738, 0.11690225932867297, 0.10405278148790521, 0.1685217386412044, 0.14341040304110897, 0.06976654708024956, 0.12271843715420655, 0.13657168935864203, 0.11790100049467818, 0.12159582723172442, 0.15178274813919299, 0.1320958972698258, 0.16681877115080435, 0.17984552939812984, 0.11873804348250551, 0.1512430391965374, 0.17198689221855135, 0.1045833969668996, 0.11878688924855764, 0.10971859923654026, 0.172729353991247, 0.14785210421729475, 0.11898513748160294, 0.2399944631202567, 0.1504517316577896, 0.17878071314865546, 0.14408068400957894, 0.11171614285558464, 0.17814838417595436, 0.14334784430121222, 0.07895280697172688, 0.09200974908326903, 0.11972756861078164, 0.10499348383276694, 0.15770365784485496, 0.19241841119383613, 0.16956957838227674, 0.14886577643694418, 0.1756997986306106, 0.17147528338095835, 0.21015106369891476, 0.15692341261573378, 0.1539399598034159, 0.1572507773075373, 0.2542253736887248, 0.17179881763314048, 0.12755341722720093, 0.23657853835292403, 0.11757905204449931, 0.11528941442168529, 0.13978529030517226, 0.14317728248575043, 0.2201839350163937, 0.13214255202441447, 0.1111084895749246, 0.15713742693826077, 0.09643468825567154, 0.11804303319583978, 0.1718539453201717, 0.184990591219356, 0.18667003981048064, 0.37486116251637863, 0.09452571972243248, 0.15549288131296635, 0.13194588193249318, 0.15219982172692978], [0.08445806801319124, 0.04034948708008855, 0.04107117637871735, 0.031555745743155, 0.08076131839545504, 0.028428458007833654, 0.051632418537572514, 0.07465185912986917, 0.023853591598209836, 0.10117019947257735, 0.04573411991699569, 0.03303872917087809, 0.015414133367519227, 0.02998647017164096, 0.03521313950900109, 0.027022445349082835, 0.036379033399205056, 0.08670691145403732, 0.00957200048311103, 0.059411447690499414, 0.0477817312123314, 0.03622184747890119, 0.02580568705114626, 0.03133770562858591, 0.030446176552363945, 0.03082667518737576, 0.09311522927976425, 0.041383583203799305, 0.01900798205526606, 0.05171205720774109, 0.03632595882781091, 0.030710743101794395, 0.03105931502256182, 0.03980596301957004, 0.0254156946715328, 0.019593104690073, 0.03480445458403519, 0.04118698972067045, 0.05532743679659982, 0.060705592360107176, 0.06964529068359444, 0.0902904792418403, 0.024462361452019504, 0.05468810961071042, 0.0601314707478929, 0.05050779380384953, 0.02295966658200468, 0.024180182541209846, 0.041669115664497505, 0.024787106123122, 0.019578801828526685, 0.0066465137135838315, 0.07664468364729997, 0.035067494703276504, 0.014373232467821049, 0.04143522902121467, 0.018069692887365818, 0.01117224898940373, 0.011847933750569582, 0.01780355011203116, 0.09527190468244015, 0.018802685813317378, 0.038934825288672606, 0.035913271093440634, 0.04997538950955195, 0.04423639504238964, 0.029756329698307864, 0.023813879515434948, 0.016329307747524113, 0.09112870966595027, 0.06929384784833079, 0.029794228067922018, 0.04720777047858123, 0.04625160847940753, 0.03062645810836506, 0.054289540876784635, 0.02010522106091582, 0.07580080715518805, 0.03322078613564372, 0.03203542020562435, 0.021492359228432182, 0.03342655735210546, 0.027853727355719577, 0.04644156381067249, 0.04336208570748568, 0.020321857319363666, 0.016495004904666738, 0.03205010036547338, 0.04552416969090701, 0.012013512164083941, 0.025785824306489482, 0.0466160633180651, 0.028217609543653748, 0.0023412417841985104, 0.029237293638288978, 0.03818916892933269, 0.043454100528071006, 0.05316485868646734, 0.01242573066960059, 0.04498214716272009, 0.037217305958150856, 0.03032598310270377, 0.055600884220292496, 0.027457355378916668, 0.11494947056616507, 0.04749881877233425, 0.08879165886150253, 0.045017000332835226, 0.08159122144382808, 0.08832674308289444, 0.03501779857962843, 0.04544412116369894, 0.056987097336640286, 0.025910575979299126, 0.041617094463999235, 0.06075606223255877, 0.026294033628918474, 0.03322457060998967, 0.05014260735122427, 0.07815828952457636, 0.05499376337073984, 0.03257673984814075, 0.053906136853319984, 0.012776366239714046, 0.034783555705460815, 0.0424445498614542, 0.039367067417310136, 0.024385111060954874, 0.054882665299960685, 0.020566967150737202, 0.031136781833465063, 0.08089876222995021, 0.014154219421588126, 0.06463766503598421, 0.0699431839729509, 0.03169285441418329, 0.0954841416809828, 0.06877558936755504, 0.0649354357512728, 0.0371062615135264, 0.04962289713383202, 0.052169450002932743, 0.03525952230237665, 0.01584461540915072, 0.006725409278465856, 0.0041319814044982195, 0.06108703519848566, 0.026509689294823238, 0.09139798191045562, 0.03609018760823435, 0.038787046928078904, 0.020121584698978453, 0.02146709939434884, 0.0062685230589141295, 0.006899124503345981, 0.028818854498827172, 0.023184932820919543, 0.04326313396074599, 0.026688963445203922, 0.03752292141378407, 0.045023029444799315, 0.051929737260985764, 0.02782653506484724, 0.05765698760026886, 0.011151891160425881, 0.022899214583899707, 0.016300604348221136, 0.017419967973124117, 0.036469301539323026, 0.060887277772229534, 0.03816428639355206, 0.0642943580544764, 0.029934376192789887, 0.06833338809590186, 0.05802631475812486, 0.034668968104186564, 0.05032300956607346, 0.02368651931324313, 0.06310977544935961, 0.039743917558582566, 0.07778797028285843, 0.050487860196059754, 0.13563991193809818, 0.08965029786791533, 0.02255541922134017, 0.09330295146472993, 0.06141671347582053, 0.02390009121999385, 0.03670845503708528, 0.009090425164979554, 0.018665510109595714, 0.04792677463903543, 0.06979650111808892, 0.12141846255549502, 0.03677100994654241, 0.03322014645222695, 0.029832928914636857, 0.047983166371141715, 0.0119849945411026, 0.021568274711288755, 0.04451550385584274, 0.049408595528333425, 0.015451853621690987, 0.043853990763666174, 0.0649777467873308, 0.04127373385633673, 0.01864179011224018, 0.024851112769195632, 0.058830438947845856, 0.055888986905976656, 0.027459891129946037, 0.027115994260736534, 0.02551274077456084, 0.03793672763652379, 0.045719426350607995, 0.08315305255593793, 0.040662656162655166, 0.05413156971635838, 0.060592433512811704, 0.041582586033450025, 0.01056930619186812, 0.025548137867102222, 0.0392449836456968, 0.026402969416531346, 0.018973640248840375, 0.012975905330911761, 0.01536577215207921, 0.042322642290063446, 0.04789949807849142, 0.010245284516244166, 0.036552387605150866, 0.046085612547974435, 0.029000832939580567, 0.10927380092682377, 0.019591584005543304, 0.02441913111045236, 0.026767941364537806, 0.06996751492542606, 0.029716351399979288, 0.04151744557724845, 0.03682324948209909, 0.02451310328568422, 0.024151335500421065, 0.00428485808022801, 0.020617017590050257, 0.12991625455117997, 0.05642924743193773, 0.08733144931254849, 0.07853637689784651, 0.035276705654518264, 0.03868485079897988, 0.06957232846968597, 0.02321133029557044, 0.06277668041988246, 0.024519197515121872, 0.02282121342666928, 0.04737514919871765, 0.027049135852364764, 0.03924970657774999, 0.013723242295635565, 0.05098304410855617, 0.026330510905433088, 0.03278028940962207, 0.025811612741240574, 0.0469754581459828, 0.04104799838856824, 0.06836606940675168, 0.03941813866878229, 0.014169134195863962, 0.02642199521013085, 0.04287606037612404, 0.010767411741037524, 0.014732273937683674, 0.017984565197219773, 0.021927715504481908, 0.023673834812436855, 0.05592539523457808, 0.035264394621575074, 0.02941820147116819, 0.02022847886227312, 0.0562948334751831, 0.015518323240441181, 0.007948268030304462, 0.04934653857602708, 0.04446456283931771, 0.05358908753541689, 0.027371000032871965, 0.03805018525810973, 0.029194160972932176, 0.07504048021209818, 0.021231445003180735, 0.04693010191042577, 0.03412552065246048, 0.038359098722256964, 0.015748151532945134, 0.06005373963665578, 0.05298784641068309, 0.019892352039835626, 0.07683174699665078, 0.020406155719331676, 0.03408548489753758, 0.031487906742240154, 0.03544130730592916, 0.019021382848281535, 0.004408722048655393, 0.009919423271992035, 0.030213236027667602, 0.035439851738873034, 0.012234505547601129, 0.018817318092671134, 0.052152209194196816, 0.04567239238249679, 0.06728796919267024, 0.03425761719324416, 0.1049069235582025, 0.049504180318645896, 0.025782725480835766, 0.026774391824860248, 0.09965820237994195, 0.05105462736420093, 0.030299499443161394, 0.035100769732267625, 0.08693186551212304, 0.04911322649868746, 0.036312111788579536, 0.033940330388084534, 0.01869064736961117, 0.0467509369275743, 0.05051289211898562, 0.022135842441310807, 0.019198462156759157, 0.012096206567460492, 0.03259354015632022, 0.04798051953736333, 0.0679564421936389, 0.029113737062641212, 0.03478455928064162, 0.02240486953768038, 0.018689814248993512, 0.007653085734590047, 0.025588822881540945, 0.07719511016001625, 0.03144063911731205, 0.020193401611440127, 0.03994973090988013, 0.06497771614381383, 0.03803293295805493, 0.048543050239283236, 0.029951632323284304, 0.010823384040005265, 0.11578681232828288, 0.02938842554877122, 0.17679030946906538, 0.10927309612593344, 0.15146851419441162, 0.1412627368324226, 0.14577088847516045, 0.12566175462017137, 0.1724947931905908, 0.172388659369561, 0.12371019925922157, 0.25265866259653724, 0.16113331090779076, 0.14719757401654798, 0.12241642231181746, 0.1110740922271244, 0.11823844690356525, 0.18914140881069247, 0.13041689300969725, 0.2923323796881784, 0.10615952327967652, 0.10450627489556229, 0.1401503312010919, 0.17188198413820038, 0.12915390513596997, 0.13361897199384629, 0.12024686131025515, 0.1291645231146005, 0.12785108835105935, 0.1943494124157775, 0.1633794807017811, 0.14707769657815659, 0.12290509447695748, 0.11993525504705407, 0.09497359004472533, 0.187384064399427, 0.15889241179871946, 0.12209543147154393, 0.17365723968513552, 0.0824801822102839, 0.17511276077599297, 0.1359790897056941, 0.16347130400038537, 0.1479426404881862, 0.20005898910664743, 0.11541992516046572, 0.09987268401610275, 0.13455438067115125, 0.15022339149107858, 0.1374010408237096, 0.1451427729860429, 0.10324120326268096, 0.14325425900038213, 0.11332780032628968, 0.14631951468125468, 0.132954360076016, 0.07409368746823843, 0.11931404201013428, 0.09427536218877762, 0.26261362277211686, 0.15534790683417551, 0.11896040816340717, 0.21056925577502097, 0.22873297063333375, 0.2128089751086889, 0.08319975327580206, 0.13916235357042284, 0.10417969161344152, 0.15609591508344298, 0.16389781579134927, 0.1288382922329249, 0.15471491902585954, 0.13442212325190345, 0.12969047311813603, 0.1970925281244901, 0.11510490214512234, 0.06994190460611736, 0.1410901525448407, 0.11281238403171302, 0.1564704401478652, 0.08212572098859856, 0.16541172810379537, 0.16731000204961147, 0.08375986313988125, 0.09411945563530731, 0.15440957170099984, 0.12272541621519674, 0.13009760288461564, 0.17892772542132487, 0.22415001816566915, 0.11315140092084486, 0.08955192451755847, 0.10395427790260124, 0.17844317480921748, 0.13687709797053568, 0.06677806107026917, 0.1127250959736205, 0.10688988086316856, 0.1338277309532127, 0.14471318152162338, 0.08816080843849529, 0.08314131608893795, 0.22110066647010468, 0.12899275088021833, 0.15746581818788283, 0.14191761943361453, 0.14372839081671931, 0.1054769542609011, 0.14253360009001148, 0.12759189782363753, 0.1808156265366462, 0.2154837404527972, 0.28514518793071475, 0.11948188421346488, 0.12591958917196722, 0.13864734330244605, 0.07974176262054714, 0.11417774423476189, 0.11564880158872375, 0.10105636646790851, 0.10729238345858552, 0.23980196054664352, 0.11174329301162113, 0.15520950538977502, 0.1947353828337885, 0.1802030013453576, 0.09723393246531488, 0.17738554446447283, 0.15347846843782934, 0.09170682259625004, 0.146634346174617, 0.1247343055963997, 0.13865483564234551, 0.20354577700697607, 0.09102475153462541, 0.12213205813520378, 0.1935058423588353, 0.08703389310187871, 0.20428738076119654, 0.12503248233828815, 0.25257048587645253, 0.23435256263661772, 0.1478247548783979, 0.1399661483423364, 0.1931524459993647, 0.19275434074863312, 0.08618757278928835, 0.09000316562671816, 0.13802679676202037, 0.12980774585758487, 0.20080270726353894, 0.1367443196114994, 0.09493670291117123, 0.25074555718850705, 0.1471754187537778, 0.1155028771609068, 0.11989005585952152, 0.04793519011488365, 0.09716718322447232, 0.1675306813370797, 0.07157898087415003, 0.11951614366543871, 0.12058306665670489, 0.178059334115636, 0.18419978929863823, 0.13414980963833872, 0.16014495023315953, 0.16904793379287567, 0.2172193432887716, 0.09670413670039947, 0.12661928791672955, 0.21146654391721373, 0.07941098117660131, 0.14631499476250143, 0.12451348075222586, 0.13789067825963422, 0.23953721588177068, 0.09290103875701466], [0.06638796909922554, 0.08449487853795291, 0.05410027502465153, 0.01810517808001849, 0.0006800960510454682, 0.025594011212008137, 0.0477103011742715, 0.03611240415803848, 0.023808762048100753, 0.0031422616420088397, 0.058124707260679816, 0.03995871329079232, 0.035875096932173736, 0.042231290135532625, 0.01627167303776068, 0.023105895529771527, 0.027403472584762403, 0.04340199505790107, 0.04218811725055979, 0.05223767013258992, 0.08849386516357623, 0.0578461155565756, 0.03617375247901486, 0.05443644206670504, 0.024234161096354647, 0.027568286825572292, 0.014788276880168387, 0.029216984647416303, 0.04116798307926905, 0.04798590513547102, 0.0384143183398391, 0.026340000819595113, 0.05770694419381119, 0.029979157862403703, 0.04313246617394109, 0.07579222697043612, 0.04377648564836672, 0.04758608767822866, 0.04069930963939236, 0.011858234760321438, 0.04158080104858645, 0.05388687740290358, 0.11706476189917135, 0.03833865566599754, 0.026042419711067796, 0.0184595990820878, 0.08512106348550127, 0.052828457987596916, 0.04321930990103753, 0.008186049751877304, 0.06491747098944842, 0.05025770057052855, 0.012789587002067317, 0.001278421672571811, 0.08548603543350775, 0.045197640034940936, 0.0372480069317164, 0.03588134054875663, 0.03154033779977791, 0.04014594517948647, 0.010023213821583459, 0.052357206661855026, 0.04475623549472901, 0.05694049237776668, 0.03549432825116861, 0.03788672890814562, 0.025458689441063234, 0.024405958228594354, 0.0695285542056926, 0.016151772616731546, 0.028850832924006448, 0.01294992920461922, 0.015090872991770027, 0.07886068489883216, 0.010500010666287234, 0.03434349181911638, 0.03497125873822839, 0.07610467593035392, 0.06775336760667063, 0.05664292084533842, 0.033681059421430674, 0.02881612531059692, 0.0328407145946497, 0.07526893529199785, 0.038917580649497054, 0.024996401344035423, 0.05441679191144724, 0.04594451447408046, 0.03176037165816994, 0.07885071809493727, 0.0728389963267311, 0.01602177515686039, 0.06065868096606386, 0.042312089428906484, 0.022706842245233637, 0.0681039677452176, 0.02440903598683015, 0.015085159891074704, 0.02830852119762811, 0.022448659123432253, 0.018745355623503848, 0.04202812744845306, 0.05738344058514603, 0.040551623209349574, 0.034337930020786105, 0.021521150727846453, 0.059214340928461284, 0.04638776145575028, 0.06177563715966479, 0.05679829879814098, 0.04101656963147464, 0.02176973093751698, 0.02724630581665664, 0.02986041997979966, 0.05376679695121223, 0.03603696748013458, 0.03617279486910951, 0.03780601771488305, 0.01856205185064145, 0.024665332617117994, 0.06218674292247142, 0.11979239497093425, 0.0690431992012647, 0.04383481558292143, 0.016109825472437566, 0.04934583760557636, 0.019064843016225966, 0.08524573663429869, 0.09716386606376018, 0.029437171723393184, 0.05867752396771985, 0.03375650759065344, 0.027207198943341934, 0.03315522050064418, 0.009596894510210523, 0.02704505451894816, 0.0028987254031122693, 0.026452851316501057, 0.005505019723768196, 0.04104475400620892, 0.056738700988071586, 0.0387101240396019, 0.028316806438529206, 0.08316119607057303, 0.007880274375389901, 0.051275670543433204, 0.03472047985621518, 0.08153494462491044, 0.017909283652120543, 0.016114278358497446, 0.005930390522529882, 0.05498685325766283, 0.020572333596646786, 0.038709105142662605, 0.013833747605883307, 0.03347362196373363, 0.015527029829700629, 0.022225262139052637, 0.052944562442961245, 0.013246897442807114, 0.024705944853203914, 0.08898952405058569, 0.057512541722145774, 0.02128424952858158, 0.054471754889574744, 0.032311527869634094, 0.005848413847777392, 0.029513753702743884, 0.01769439981979949, 0.041687536248636824, 0.11958936634924143, 0.025492372411874034, 0.0443955306564608, 0.03137000006503396, 0.049101080174647996, 0.018483596786315885, 0.05390308782338135, 0.024222635303533847, 0.020396089324006633, 0.059973943918462724, 0.030789491194750995, 0.017295882796808597, 0.026815002145726356, 0.04070148915953694, 0.03343678079545498, 0.002990280810345505, 0.027733631582269748, 0.0432090328315333, 0.00903915090020746, 0.052234755168038036, 0.011380944746516405, 0.0451633959047256, 0.008980015615722346, 0.02991270165019218, 0.02016104014229871, 0.0620403933158565, 0.025277352598946423, 0.016267291014833797, 0.03125005750916898, 0.050558964646751844, 0.042563251354881836, 0.05492679579483886, 0.02309852959437957, 0.03048774256791559, 0.026760075556775256, 0.04138820654442234, 0.04820227517836517, 0.08703521843398772, 0.04210101305356911, 0.009444042732338271, 0.02449294176673697, 0.014038439595981712, 0.05351381556641671, 0.06290832879923045, 0.04360226959350609, 0.019427888253102862, 0.02127807485991188, 0.06543877083928355, 0.04627603519287321, 0.017362678002926613, 0.053791346238745805, 0.037939091017770196, 0.04551093169157544, 0.05821515160102037, 0.06330568328379624, 0.06578855892463077, 0.07936248015011511, 0.013195739048833569, 0.014078051129716539, 0.015547734313464213, 0.09077646243836611, 0.041174751466080066, 0.047240574363498926, 0.04008590303842099, 0.02156681339857319, 0.03085117276397444, 0.00978818187685383, 0.08693990943532798, 0.037052405532449484, 0.0640320380578839, 0.10308900457476416, 0.03780322915483867, 0.06315479077579034, 0.10080888176396971, 0.0317811249800387, 0.027636786577321833, 0.08087564169639543, 0.019482025771491954, 0.03604759695008397, 0.08886764712271192, 0.023121303473148617, 0.023863472217213244, 0.02017292791166373, 0.005709762945996538, 0.02410409851900993, 0.01738479304608078, 0.01870604956732883, 0.02779512354473193, 0.006366037433185885, 0.011611610947687541, 0.04900071882612763, 0.055923840076091795, 0.05262840178705031, 0.050188204904477444, 0.0347115357796992, 0.09033553287266724, 0.094113388218947, 0.028239427727737257, 0.05253399294170161, 0.01682942143581327, 0.053927709889267726, 0.02291506111261345, 0.06216816529030762, 0.07417645560757768, 0.018863557244560892, 0.031174308650435942, 0.018601775424735203, 0.01287190793758078, 0.0625802286630196, 0.059204715033692706, 0.08932658741551061, 0.036280005043672944, 0.05861808320567493, 0.024924511653220943, 0.09479614875970349, 0.04193847217867452, 0.03723680672626342, 0.050766873248522325, 0.08205572353495706, 0.021033683235967354, 0.052183963538658236, 0.03084251213999045, 0.03763378582774632, 0.02914793331236128, 0.013097796622934121, 0.024301458090063066, 0.038715195541660634, 0.17099076341236794, 0.03701397856216758, 0.037076870550311385, 0.02373986393063059, 0.08480529736487136, 0.05688948241332847, 0.030686122951127832, 0.041065292823458874, 0.033993347502884366, 0.06205872196944491, 0.02629853631069343, 0.0029208251245079505, 0.06582327036847992, 0.08491745263698601, 0.040711655146292144, 0.034809074094218594, 0.07178197885232587, 0.023968167708165223, 0.028387217579649824, 0.07767411429555186, 0.011904492106799398, 0.07409245406668033, 0.04161242898854037, 0.02905986767502562, 0.014505752272182896, 0.1233872855382581, 0.03923088379745041, 0.05275140869461241, 0.024909768291118167, 0.04893907556130041, 0.01615587693278588, 0.015910446302094046, 0.02937966533335707, 0.021756939184401306, 0.04467748165611298, 0.025681739770657113, 0.0187890341265067, 0.011305364427126704, 0.031001607534445585, 0.04241377993997547, 0.04377503391175021, 0.07973586374353017, 0.03874872337966677, 0.018839029024445245, 0.046121408006236445, 0.017867539521126498, 0.025888204296690323, 0.047137232932953105, 0.0713111412140631, 0.05337273664472084, 0.060077507514506585, 0.027557781844910596, 0.012544898519052133, 0.06288643017591489, 0.0280952729630254, 0.14947234953363098, 0.21830611561815585, 0.15032115963197526, 0.13987896753655327, 0.19528425418801848, 0.09996399403579774, 0.11516232043504716, 0.1806400545061596, 0.13723020321659504, 0.0672947260881624, 0.13147354276189882, 0.15300255929750783, 0.12079364124445185, 0.19175346219731917, 0.1109557009993061, 0.09689452487134165, 0.07475193319541794, 0.12578065912689895, 0.12905599909924692, 0.22754311351285827, 0.19000518826707719, 0.15051504116385214, 0.10448564414776142, 0.15617761069968825, 0.1317284508578239, 0.16082028738192974, 0.22097369505753442, 0.09083309931860817, 0.23824955997688158, 0.12500759214162827, 0.11430942708806646, 0.29869173683466455, 0.12215189981244265, 0.1633594398416819, 0.12960971212915837, 0.1903903925971639, 0.13127457440620469, 0.1364922153973772, 0.18275873194779121, 0.09024187862392395, 0.15971407174102722, 0.1825181037307747, 0.19675492849801818, 0.12990019734828703, 0.10076713763297566, 0.17718809296286878, 0.29022977477119816, 0.1571587854695897, 0.1431129770653863, 0.14888806959554074, 0.13563749110025747, 0.14276572473106847, 0.08362992696704404, 0.1747180263121282, 0.16769004294708853, 0.0902884720914787, 0.11956919525419513, 0.1118938752540177, 0.1449679363999636, 0.13497828776317258, 0.1315271382730815, 0.2156522031873465, 0.14626702233668298, 0.17231372064880787, 0.10878185756624707, 0.20116820781221315, 0.18114535077925653, 0.27469329716217133, 0.16291066553563843, 0.15290305979790228, 0.18019944669738894, 0.2007012772223642, 0.13067046811263408, 0.24526995907147087, 0.12135622557252647, 0.13629891609232272, 0.20120540904181622, 0.1327916889661743, 0.1084870592721047, 0.1394390798504314, 0.13977264985442162, 0.12180851622214242, 0.08447765688141508, 0.18990740480442203, 0.06725151872923298, 0.10576498799867208, 0.15035269181093863, 0.1294802279481965, 0.1956717721036365, 0.1868100960047976, 0.2205596704997363, 0.10500692101495882, 0.23242652566442568, 0.09170444006280554, 0.12044908553962747, 0.15158724250091662, 0.11359799187630416, 0.24653751282922684, 0.17477635624668292, 0.15197883600429182, 0.09232374554079387, 0.17662083549845606, 0.16843376110398, 0.1040389076355965, 0.10768344070041373, 0.14137386554671874, 0.14801783967883358, 0.11653033896319329, 0.16470721832686858, 0.16914620755180237, 0.15162358571204448, 0.08860239683980904, 0.15483545529986584, 0.10079131536786595, 0.18358252161452848, 0.09708828382915068, 0.12276182071335855, 0.19082718528807166, 0.1859519243120186, 0.08538819068381864, 0.17603716843070524, 0.30477772316625046, 0.1994555722922087, 0.12710950757947662, 0.0927568456879066, 0.17847996235134142, 0.1819449933546205, 0.08518771313491368, 0.11324655670191973, 0.1368546056290788, 0.12962753133427712, 0.1005675181025459, 0.12178247689359611, 0.16713179467666536, 0.2599503947121482, 0.1109292479832807, 0.1258949441234431, 0.1988887131935166, 0.10547202065466874, 0.08798090035035726, 0.19781013800492211, 0.1775421941232297, 0.2210613508378306, 0.17245454293104912, 0.17263327124378375, 0.13898105120226262, 0.155036507414714, 0.18934325765698187, 0.18328690360630714, 0.11942218298152571, 0.1147568837228802, 0.13631123478614515, 0.203650210112814, 0.1283639076075727, 0.1530753070067975, 0.1243620251695956, 0.10021139447006489, 0.12206613626931945, 0.10332770991109072, 0.12556394817487848, 0.2162941848678935, 0.14223623540132277, 0.20048179303205785, 0.12959226064624327, 0.10787461028103867, 0.16886922080189953, 0.08582559624506582, 0.12041216010167716, 0.10193815665139307, 0.12930021260774907, 0.2196679747993908, 0.26268174331034383, 0.1448492080934586, 0.07727160403925566, 0.17269898626592853, 0.08992041280913739], [0.04926505363396099, 0.047375317738060994, 0.09805850354173491, 0.03801438979984772, 0.01743409463444785, 0.0725071270379328, 0.055432904121135516, 0.02713501813911623, 0.06628760392026556, 0.07435776563661714, 0.03414946090009424, 0.03717161264390715, 0.06746806880278934, 0.05213876435112569, 0.013050247460693843, 0.0192179246204755, 0.042777828752033176, 0.042921389798603715, 0.053648451688669385, 0.04485143724107935, 0.022694115609591527, 0.05966092039260173, 0.0698855358566488, 0.068967011757195, 0.07609543690998709, 0.07265654482668446, 0.0527719168683454, 0.04890282045028383, 0.028766498134862033, 0.12594709938932813, 0.07925452303982551, 0.053896809732841874, 0.04200273546420279, 0.027159998351107204, 0.0786561087795323, 0.034824621848641865, 0.03332101724921696, 0.008205251745699395, 0.03564515947214058, 0.09326516034742517, 0.020661565602847168, 0.05404906204691338, 0.030959219889595147, 0.026714073892142025, 0.016386530685028242, 0.07828869301104739, 0.06923636061049278, 0.05576299991638911, 0.06767251468714207, 0.08789393404919295, 0.09931635862636952, 0.05649855157600776, 0.04222393952189915, 0.03149957617654676, 0.024039653287599647, 0.027916872152878393, 0.03497358764551821, 0.04578769244554062, 0.032552309304235444, 0.0998530415217242, 0.06544303028814255, 0.03341159182450464, 0.012665403191931547, 0.03892566670753783, 0.024528668277085792, 0.01800372697142584, 0.03830758697022835, 0.020380635415354086, 0.039440523757929766, 0.03342864877213875, 0.019283409816242995, 0.027243342971609488, 0.0838106471083818, 0.026751033804048936, 0.04508105294418432, 0.022204229195091515, 0.03787391225717241, 0.015706637228328376, 0.0016585461215131107, 0.0779686751024377, 0.045384921719350164, 0.018490210040322235, 0.05394578573384112, 0.0513398150853332, 0.07226908819810038, 0.0297736068962202, 0.05941406005032121, 0.03227071836590767, 0.022395339403902332, 0.04164183527351387, 0.03407333857349811, 0.015059719068719255, 0.03638705817021189, 0.014256643461844614, 0.03633088477316403, 0.04697732740051804, 0.09102600791882123, 0.07060156759595679, 0.015078766887346584, 0.04453351458294257, 0.020534764644840074, 0.04608408803300512, 0.06426882434396014, 0.051756134076464566, 0.01684668331196712, 0.025393857335251187, 0.016898629818892768, 0.024309404337057666, 0.02508994259480988, 0.008399478017142224, 0.02350821043364704, 0.02986817278959338, 0.027714104001079837, 0.06008384689208, 0.06514359716205828, 0.07649551100668407, 0.048962429751672094, 0.0720484012497529, 0.05117779898066675, 0.06599076017136536, 0.025549110798766057, 0.021883694177132942, 0.04895564221266297, 0.049297551083708965, 0.0256724662763337, 0.05716898576206258, 0.03684285367208143, 0.047285723755316394, 0.015150896938247307, 0.03194746756625753, 0.05944330162639099, 0.025802467566644473, 0.014065448983362126, 0.018914373771798228, 0.01138235243307727, 0.03697878065248651, 0.01669757578882479, 0.02807323069822404, 0.1011962847663991, 0.07467228303393049, 0.055020848409302776, 0.017549806469750982, 0.0066096533931070765, 0.10890027943758235, 0.051969351667550304, 0.035812859949205196, 0.038017074938022324, 0.012449364482064643, 0.05360525199061921, 0.050603263680973364, 0.01947002691937791, 0.043699888347257534, 0.0470197188758081, 0.049136879463349624, 0.04466794386145569, 0.026005693455977787, 0.04032136782282784, 0.053863055898898074, 0.006978914475879602, 0.046563666734483936, 0.028538290118317933, 0.024406151665795236, 0.09823040601106421, 0.016934647442652814, 0.017252617981284857, 0.027905070568404855, 0.028259422622560978, 0.09490561506320393, 0.028605408996583957, 0.04162510008280797, 0.008457816570186088, 0.01645395408324417, 0.04253653786896218, 0.06306559132832674, 0.04935685394992752, 0.06456461855240407, 0.06915506335996813, 0.014125454735251204, 0.02109660586762813, 0.004482700286673442, 0.04493785195893819, 0.07198912902705132, 0.05968738106950637, 0.03330370749256784, 0.029053842393501155, 0.06290067175042725, 0.08871081360285321, 0.04666737588723341, 0.05804311506630433, 0.07053963704815797, 0.01964098135490091, 0.05220357538951982, 0.036129863301832835, 0.012571638818049144, 0.02439635723168331, 0.020361628773952686, 0.013109467014850629, 0.04558123558038666, 0.08094285825087179, 0.07231527563905524, 0.060697069631949555, 0.05228260501978859, 0.040168276642479246, 0.0803577815813403, 0.008044272732560434, 0.05853770526065942, 0.026083257943091374, 0.04680185879190122, 0.062318073375330824, 0.024104376225882483, 0.07278557701577103, 0.0072694083134974205, 0.04252302024753825, 0.06267549935728312, 0.02658114231552088, 0.09487252006487501, 0.06263626033380147, 0.054065034980134624, 0.003446164651728806, 0.050404505999458414, 0.033393332118829416, 0.05988340764757126, 0.032651862429995696, 0.054174937953751896, 0.06199385347445646, 0.06554445266843804, 0.14759292135075217, 0.02000489418635205, 0.019378268738247214, 0.017687939783377994, 0.064484033763649, 0.016400431350414312, 0.029160035586345102, 0.03358770777741748, 0.046742421860295924, 0.026716829893449624, 0.061621220647207195, 0.016855139007431366, 0.06143877297760018, 0.013690923918939888, 0.05417030695224962, 0.038001979175474376, 0.028426159744060812, 0.12642137676237092, 0.12643004121679452, 0.013913728142788094, 0.005937616646875658, 0.027815428705164985, 0.05984933205669927, 0.03141753199029594, 0.10026268405659546, 0.09566837050501378, 0.04976712467689669, 0.04560702976079718, 0.023883061085437095, 0.03494109402620985, 0.03454104674259021, 0.0480831370148207, 0.05122974357237259, 0.05330652366542528, 0.025428461526790937, 0.07941809047253863, 0.05062090668586954, 0.018914335467402014, 0.03573404865399484, 0.011674525918469075, 0.011937023072894062, 0.029078665557467652, 0.0120975146625912, 0.039946858080164085, 0.029408135075843143, 0.027383786040328206, 0.011549296398316661, 0.022918416577721798, 0.014497545555294042, 0.043578777507308035, 0.017479289991540775, 0.028461823052155878, 0.026938476366922263, 0.059493269711252184, 0.03997961216936669, 0.07306481606417126, 0.04183909908357648, 0.01771969412783942, 0.08481593832613961, 0.06447037441595908, 0.04321952440565632, 0.03644238120966381, 0.05436666294812195, 0.04303295518301668, 0.07294296211893521, 0.019565864518705397, 0.0177472522256956, 0.10161725774167046, 0.023667380521674792, 0.01795410362613057, 0.04949167776372164, 0.0464518906758918, 0.04137303417308196, 0.03917998491576122, 0.04532081165140675, 0.04470642828833192, 0.07027164417048616, 0.0426149852724085, 0.0650700603822066, 0.013423359092895784, 0.06923592394037593, 0.004182856824744734, 0.026743574022886255, 0.09450868192699649, 0.02670463377369508, 0.029513979698681546, 0.058368192985653884, 0.030490822241371198, 0.027233638552828666, 0.060577525441805204, 0.06278288573206914, 0.050779065537837245, 0.034370664957790606, 0.12067040834095209, 0.06774536964874114, 0.03555925803319101, 0.02588502694702437, 0.03401178340878218, 0.03345037502567134, 0.09836915219503065, 0.04671613738361386, 0.03134435910220829, 0.032804578227261384, 0.06984825801825331, 0.08858913585783974, 0.0409414662018178, 0.010671419966515275, 0.03894778749635143, 0.014285110331500971, 0.06921586775851828, 0.01218754148501302, 0.019285376746988585, 0.06052902058487939, 0.0809362009468098, 0.05567553565807401, 0.04346564547308991, 0.0626317902107633, 0.04992645947382816, 0.04097481017872211, 0.011336268413992179, 0.014204908586708049, 0.04739573015080345, 0.06568410283615513, 0.07632078933379344, 0.07168020407158522, 0.05540513343388035, 0.1577172176011147, 0.10850130084661708, 0.1447518076747656, 0.10563563405265732, 0.16486605899708887, 0.1552086626930583, 0.23427717958486852, 0.08842721551416383, 0.26041614552659376, 0.16262719768189615, 0.16807915432558906, 0.15336985249192486, 0.14338210375318605, 0.16424128365132118, 0.12466809261710414, 0.163855527737929, 0.09725602644105112, 0.10394932897461039, 0.1435596369687588, 0.1568052052490173, 0.18730552506542977, 0.20476446967692147, 0.2549812879653708, 0.16199044072099272, 0.26938749477267265, 0.23653900821603116, 0.20175679316443784, 0.15583976592508056, 0.09661244363674233, 0.20126661946696622, 0.0973604518860098, 0.09739379969335372, 0.13354717423358273, 0.10725910459915478, 0.17758704091031707, 0.07577828417021422, 0.16904146801079475, 0.11273301732275756, 0.18244759299822394, 0.2059060326146503, 0.18329372178883324, 0.14336379425179574, 0.1325278329632936, 0.08807800965563906, 0.10529068764299156, 0.10030938477645959, 0.1495727223734702, 0.24285672082295343, 0.2547753482095657, 0.11676129915060536, 0.31782377150750935, 0.16594763725034653, 0.1142896390369823, 0.1486931461840868, 0.15027101151645184, 0.06676762695274045, 0.1175637302860137, 0.18745500414121538, 0.07998575396355122, 0.21613539016294867, 0.20166693105091973, 0.1334839413363126, 0.1455934778336556, 0.11439215692300951, 0.13670517251856867, 0.09463710124574362, 0.08056428058133011, 0.24845644050548155, 0.19235939178014957, 0.16426907732121407, 0.19086031092991754, 0.10848633148857664, 0.24278185871099275, 0.12062173877512256, 0.26448578844147347, 0.1771140735476248, 0.15640500091737317, 0.19433847268021878, 0.1393357192676875, 0.25897485834936945, 0.17866206145094288, 0.14520879444335738, 0.1904120882071795, 0.21053179407552366, 0.21148667670786384, 0.21935700438916686, 0.14603546460068997, 0.06713639869685135, 0.27335141755400166, 0.12128472658655337, 0.13064167852843964, 0.15807501130527066, 0.07088345730857504, 0.0985131077768822, 0.07920108840710695, 0.15461782504233623, 0.17036327611534827, 0.16333022124824986, 0.1271925821539856, 0.14104256316298439, 0.12652512804995622, 0.1293352841129226, 0.12672863930704134, 0.1689697621810821, 0.11495662582737785, 0.15914537403131687, 0.10028689243500272, 0.08424858127029673, 0.15900842815397248, 0.11305280540498996, 0.2310398299126856, 0.10267240596154045, 0.13076088180945766, 0.1821586705984608, 0.14000434548624102, 0.1262842470239247, 0.07552519936354891, 0.18028805242671123, 0.1052477790583526, 0.13236853264031873, 0.07219398859888315, 0.13768237895302235, 0.16291032845695175, 0.16000587463138566, 0.1195146574548656, 0.1700913149022287, 0.1915074713648327, 0.10718999580750543, 0.12749026093872326, 0.0657339598382673, 0.23364868105178882, 0.11836230033828367, 0.08040046033960196, 0.19920348339984495, 0.13725778238186914, 0.062409276142716415, 0.1711059064273873, 0.12071641192080514, 0.15437120601775187, 0.2954804801171826, 0.08161497016948077, 0.0879390642888123, 0.16313549701965627, 0.23293070344915315, 0.17914979898881528, 0.0964164630239529, 0.23566860975998066, 0.11123060399005491, 0.1664636434326249, 0.16582022150678022, 0.10787046574536832, 0.09807409343099403, 0.1157380278492647, 0.16962798492562386, 0.14055542317369293, 0.10490101702030628, 0.06709496866190626, 0.11521963147266258, 0.144173258074349, 0.17979771018989626, 0.13824834938972227, 0.055392910501048456, 0.1490284322250274, 0.15779606337028165, 0.16603406728996387, 0.12062237462809972, 0.12701966844859625, 0.1241281232045543, 0.0899634592896027, 0.09467057928803468, 0.16590919495830614, 0.23759607165571184, 0.13102270001845975, 0.1813847379338357, 0.13682569347081647, 0.09053345168790511], [0.03701918029917344, 0.028124945463552594, 0.02101726022609059, 0.03643459775635312, 0.029645053512086312, 0.07755749273083865, 0.06745041813701391, 0.03430194304054303, 0.018343741690079053, 0.045566798653453595, 0.024814545477349913, 0.03378617817596082, 0.021177307484791647, 0.06016087320242679, 0.04312808798145383, 0.05102835054839811, 0.03139136434202233, 0.04079131296865883, 0.018705720149521387, 0.026074838636803533, 0.04807468323457626, 0.03952243387879383, 0.0964177883560619, 0.03856871186965897, 0.05986356213989277, 0.07202960145209106, 0.0016928763169186912, 0.02445169559289371, 0.030066390379121708, 0.01912175185768114, 0.04019141632823214, 0.02459460163428899, 0.04970289969576463, 0.012465066411682676, 0.03473612720206861, 0.06163550818699503, 0.03598016206054919, 0.04709056668704556, 0.09033539497684087, 0.023435008817262227, 0.02257626255854003, 0.047010575616431814, 0.025689015690717968, 0.03581761352477535, 0.03823991459343703, 0.02691249449497029, 0.01831770427675257, 0.023460379734094587, 0.05955118978876741, 0.017077243218438763, 0.006746258361325149, 0.1150803030618737, 0.03640445219653268, 0.056762568457352544, 0.041169434815885565, 0.011374691553834465, 0.08374589735702162, 0.01932603877878958, 0.004905698606894622, 0.002008652133348909, 0.06673125309809562, 0.026220701777586536, 0.01464481829785772, 0.02319262817411894, 0.03312593678973856, 0.05265991481381559, 0.025626709759836237, 0.021125525686769717, 0.03015622759478227, 0.04922813585688991, 0.05672165936219597, 0.009722138394511515, 0.05188205211813893, 0.02049845399244899, 0.05168253600957894, 0.03152067998364087, 0.0030103015606366703, 0.0031314552536294347, 0.08657204933584699, 0.09803110823756266, 0.05752593676950182, 0.05675408403359114, 0.022759133491725213, 0.014344621956678889, 0.009793020679705567, 0.028898732571472085, 0.06706581901638739, 0.0043045417518324915, 0.08367470480621823, 0.04177550995542158, 0.07394693566546326, 0.0666502622827407, 0.06026932443942755, 0.07142178729296693, 0.08753709795494234, 0.07703126693565039, 0.023790021622253042, 0.033851571441177404, 0.07179520152989896, 0.05883146550566439, 0.06591621215545362, 0.041761662916190205, 0.043844878147806854, 0.020469919132489352, 0.041209160305199125, 0.061669403747204816, 0.028234224075511582, 0.030804044950092514, 0.08718682723420282, 0.020644619737962083, 0.009445718549672634, 0.015338184368315966, 0.054312163453188636, 0.02934985876744313, 0.04608335258859781, 0.030524880595264897, 0.04705610805221143, 0.019837228183244026, 0.10564095836373107, 0.12623229094090002, 0.07133230056253172, 0.07692992116414732, 0.0795480726106513, 0.007488440511928451, 0.04686574286390697, 0.06724284661393012, 0.0646816538045964, 0.03729747322898719, 0.05539539262592312, 0.07105879951268435, 0.04148284138570871, 0.015693420296414726, 0.04247517422622731, 0.028583872349812623, 0.05694982332868442, 0.0416827175555931, 0.04473358993568728, 0.037272847332661195, 0.018788836858866197, 0.08129799362993048, 0.08909951129387464, 0.030304611164836154, 0.07576287048117769, 0.013085841820875724, 0.017728935063426054, 0.02437707096818955, 0.018396289576025262, 0.03063313647984497, 0.07188209122227085, 0.017542061320836508, 0.030063073218409574, 0.0700468433299853, 0.0021270038597586177, 0.06392378983418308, 0.023257816510815776, 0.047619401011616, 0.02081827846385779, 0.02912892475574007, 0.057918629609048373, 0.0033910939424869517, 0.027029633169032397, 0.07766672920796179, 0.02859917304088031, 0.041182768576207666, 0.019419733247148897, 0.04154966340490407, 0.02887050414668216, 0.05842286868080978, 0.04833427595815832, 0.08017493171557304, 0.0344547277857219, 0.04207066448044874, 0.05440217878429159, 0.022356104210860307, 0.11700206526344824, 0.03194903038562306, 0.021614906483239705, 0.02324626773535725, 0.020254692475822185, 0.07832175736585933, 0.11039963607946712, 0.022768736403856068, 0.016925190087227572, 0.021643360903967294, 0.05768023836877077, 0.06286477287029547, 0.013015104134777382, 0.04066090565174818, 0.010255161304807952, 0.06858662612015201, 0.022688950261762066, 0.13304100462025212, 0.025763682450257966, 0.05737183052265356, 0.07651280161113509, 0.01845220441839868, 0.03909436309890401, 0.050901455744620294, 0.05536258108012619, 0.02102234130424838, 0.047861404356456576, 0.08159789406964857, 0.039723083797481754, 0.009495025883699137, 0.044013976735333284, 0.05683464967014809, 0.08604682711583954, 0.0084649957716465, 0.039263415721154986, 0.06774636556304271, 0.05100554028045266, 0.03104540669629651, 0.04180274821156937, 0.019433068922690807, 0.0772313614405932, 0.05555571567627692, 0.023650846429049008, 0.05530337397489817, 0.04308388853866247, 0.03492427839627189, 0.07051611048800331, 0.03964569742581056, 0.020628750226610613, 0.04563397307309412, 0.04918839121537824, 0.02153701257831868, 0.004138428513185992, 0.06607813249912954, 0.06570497107121252, 0.028317796607171337, 0.04234419234337346, 0.08202456673907657, 0.0367278408920092, 0.035531004710543546, 0.02012821135952348, 0.047036626436296976, 0.028311612362402584, 0.05460567471961822, 0.02516538501837321, 0.03434568283057982, 0.02370053106137822, 0.03765116836274824, 0.008073126476618552, 0.056559666240167235, 0.031221300483711308, 0.06407553653022455, 0.026931508797250932, 0.02577014248667946, 0.029725904516395063, 0.006784143324400629, 0.03701192544653051, 0.10284617768540498, 0.026241786432482546, 0.03904720655672493, 0.045425221774606936, 0.04504411984535475, 0.07405506897597544, 0.003733188111049634, 0.009731530632463195, 0.016086028866289605, 0.07484415485974281, 0.02364342303706273, 0.07580374127193805, 0.01396040875284422, 0.04018204707291819, 0.015482176339343913, 0.049819793221690965, 0.036459932284009074, 0.019590434873656883, 0.010519002943540053, 0.044139967555360454, 0.026351256566422603, 0.08341775891641456, 0.018886072568655498, 0.025968976776986837, 0.05977217551140536, 0.05677715094099122, 0.10889789690413784, 0.04605887607941705, 0.00671870936076307, 0.0661994501828186, 0.046381268860592, 0.04937147473796241, 0.028299523494957436, 0.0020154672036428126, 0.030406887733167222, 0.08459357364523797, 0.02995527315614445, 0.04629426425503147, 0.028315188077789162, 0.021524337653611458, 0.09782018891024975, 0.10839594843527002, 0.017835216356381293, 0.03254054602415812, 0.08385816754232492, 0.01120113912263825, 0.0536699481158247, 0.025270649329608968, 0.03307145644700335, 0.06357045859218606, 0.04865797108880455, 0.05188902351824988, 0.007818060853864037, 0.04173958809265206, 0.09696263008781018, 0.0008681143170237662, 0.07738178280452568, 0.027102501537170143, 0.028364173654887467, 0.03647914959958965, 0.07455727025385826, 0.0759816115661975, 0.011950082956783235, 0.07196316630729745, 0.046036418211916764, 0.0057099391462191226, 0.060241258808321534, 0.06079444323756522, 0.040235075679036884, 0.05030213367013682, 0.026175575368406794, 0.029586909353853236, 0.017745271888411334, 0.012448054471714123, 0.02235375998181201, 0.01698338787161535, 0.017049828762068384, 0.028786431742651813, 0.0402374773646795, 0.03296644877522223, 0.07246100854489111, 0.010411227779132465, 0.020993254860983263, 0.04040354224402578, 0.06616757326428929, 0.04253531212828333, 0.06889476966593536, 0.022597153776235158, 0.012429717199636564, 0.030865261120901957, 0.017195661259334416, 0.008084884968646353, 0.03624759569403626, 0.04702927965310313, 0.05933931668198878, 0.00719734290126531, 0.007157445999778688, 0.018030354272454016, 0.023568511129386967, 0.025699897969682372, 0.02301251707268098, 0.1866431194808214, 0.14393845212555703, 0.11423812728495368, 0.1633464929557616, 0.19954066933883777, 0.09440938161025125, 0.11598367394218523, 0.1770447425904774, 0.15405704868176293, 0.17714321553226442, 0.06908794639692192, 0.20127634878360456, 0.14258880438583513, 0.18222136723418392, 0.10919677078603737, 0.2139435206810313, 0.11567536185705855, 0.2182424077463727, 0.19330296695472735, 0.11042406662337242, 0.16461724896104107, 0.15519720201771106, 0.16487218770048312, 0.20412607328786006, 0.15513214583118118, 0.18482706209103908, 0.14047755799706907, 0.1540944490942263, 0.13874071409865735, 0.08165230163403096, 0.20050359589438285, 0.0693727778871694, 0.09037048180377291, 0.164069511416939, 0.10943901544857411, 0.23123939581696065, 0.09402803070242367, 0.15260961747938587, 0.17322813851698754, 0.16215614553901458, 0.1348747892846023, 0.17502436955128947, 0.14408218554191052, 0.19842017381902666, 0.11667861528093777, 0.1551681059983469, 0.11437200881060093, 0.17835343526976724, 0.13202868071534943, 0.14626971896617644, 0.13440459516019593, 0.13655039211434705, 0.10879466655634104, 0.08366218692953549, 0.12157873581013373, 0.13210795549375395, 0.24571815115069193, 0.12449510230292236, 0.13752971295147173, 0.16821868958011751, 0.16436738172365775, 0.0895962963301328, 0.09665943547001771, 0.11789551530514034, 0.10165541658117887, 0.14454664932864328, 0.061442745143487576, 0.13196580021852447, 0.3056973657540737, 0.22905483481384095, 0.1227315832229872, 0.1917857911077238, 0.13499434496606552, 0.10189525572763336, 0.12777158374627753, 0.1564407465799201, 0.09841398366035954, 0.09952867223370461, 0.2556798375782467, 0.12394888161291039, 0.22020219855250853, 0.17529233178544432, 0.07917207665741444, 0.15089462240857465, 0.12303436415330057, 0.08485414313092347, 0.22368075866853038, 0.1402124149664756, 0.23405240938788463, 0.16376258595095528, 0.1308916989834078, 0.2659084137168623, 0.2819642989385513, 0.19446565859740783, 0.12396657824396126, 0.11385306851157259, 0.16117662551902956, 0.07225913671596397, 0.1339361477162569, 0.20003010759190207, 0.16566294365592543, 0.14182509133411994, 0.12812560829784603, 0.06869911081007413, 0.1310819799020406, 0.12170129455626012, 0.1175864218103309, 0.10726495751089628, 0.1275240224335463, 0.08874184782466582, 0.19580418274046915, 0.0854016048833728, 0.13652981499270087, 0.14236697596648049, 0.14076491757746667, 0.1858933645510866, 0.2068465894028064, 0.07631061568615899, 0.175225559561964, 0.27168529889275955, 0.14701435642857708, 0.22457076897544248, 0.19112053567603712, 0.10761274610676112, 0.17596019191607354, 0.23179324674269847, 0.14610971384231122, 0.11657799729296278, 0.11941682036605575, 0.18211051431154052, 0.08334737841881092, 0.1329611935803006, 0.14899565898362668, 0.12822113180112454, 0.15443422441040316, 0.2889843303109369, 0.1263925795172972, 0.10061499257121356, 0.1637799148598025, 0.16092974602455096, 0.09914486218364009, 0.1504555774191695, 0.1392599072067007, 0.06490510633035053, 0.15699170169330415, 0.0954113863108139, 0.13721053007869952, 0.12829868288169946, 0.1471288712514985, 0.08844423798784133, 0.06694882206859128, 0.167625155299902, 0.17546974242694918, 0.1862643962545741, 0.10641882105940774, 0.16080796868810732, 0.12070431539248075, 0.10709768987350887, 0.1511286929129593, 0.14393235406567975, 0.20897530259624605, 0.12960333827762835, 0.08037124940704915, 0.11299986872942218, 0.1313521637911758, 0.1686640777775357, 0.0814732822078851, 0.13079281235414167, 0.15458001094239374, 0.20134949485861486, 0.18261662263783718, 0.13101070308156554, 0.20268107824508222, 0.19426920301010533, 0.17234341421675298, 0.13981648540544894], [0.007439460201684627, 0.035021360888476336, 0.020579791462589658, 0.0218849390700099, 0.021569119323225274, 0.069130448954961, 0.027194100755056547, 0.034935214301390995, 0.024074878010358063, 0.0741242696981757, 0.03361344067079406, 0.03589741690384765, 0.02646973397913239, 0.041601385831111864, 0.058559940962661663, 0.0557206352541764, 0.05491820028832844, 0.024294274100553126, 0.04733352381135187, 0.0400950156542803, 0.07884078193455935, 0.018281177204522877, 0.01271239502520691, 0.02176962943086701, 0.020266800495465438, 0.01559021293125566, 0.01612693221578675, 0.025632920817682342, 0.02622664278943933, 0.04537090231033583, 0.036666829649719505, 0.041697005095380935, 0.00825587675095566, 0.04261205881653775, 0.025887907437619664, 0.054306735720245115, 0.09737515311327674, 0.04092942713008773, 0.01682116875364896, 0.03263282514507732, 0.02475949439911112, 0.07026586020665784, 0.03432336668934553, 0.016243375665057572, 0.04254662724692495, 0.025264953465891943, 0.12092326332124011, 0.04525718804929526, 0.01043750363732538, 0.0331637968549565, 0.04820111455515989, 0.027442813114894014, 0.06039847537214237, 0.02139088130676218, 0.03471910089795147, 0.046549900134484616, 0.01651017153034768, 0.03389493201769168, 0.042682738088431864, 0.030360937779468876, 0.024962810303775534, 0.023206465637251254, 0.06224694211156138, 0.1063651949047081, 0.032845406883185914, 0.035212396403714534, 0.039267204025940555, 0.006399074496115528, 0.01626918708244639, 0.007320469988870525, 0.0161004351497057, 0.05592122388583037, 0.04108429946486027, 0.06661614072659323, 0.009328262906731858, 0.06326282066443274, 0.036700671583774595, 0.03438151276279842, 0.10730316231568014, 0.010511037544347348, 0.0805205216390952, 0.07362441264934118, 0.08280544016029566, 0.05402074360679235, 0.030506864122505632, 0.05423260139181249, 0.019238128274258588, 0.01588142784913221, 0.07872583044152107, 0.07152619741616711, 0.06766702949760423, 0.02144037824754994, 0.00984637295797227, 0.022599436718249516, 0.05644088430750755, 0.06412149797524176, 0.025805577883617054, 0.03919383195499259, 0.04066267531485327, 0.03767746816118879, 0.019226866781771667, 0.06230435274060696, 0.07303879205738345, 0.05192660779181508, 0.05671669894288625, 0.05369909393090395, 0.03178400547063399, 0.006162394504738791, 0.047796057056515455, 0.0328517577520782, 0.10038785516254364, 0.07606283986880895, 0.024132815324851585, 0.041976117739273656, 0.02172152868532125, 0.0656204179470097, 0.029703724355767333, 0.1386453514738429, 0.036975949957606294, 0.03920680565399028, 0.06581579335033894, 0.03460088203991613, 0.07647586085142628, 0.04294747892286509, 0.02536405843021649, 0.03157887585280884, 0.044832514869349624, 0.04517456546666161, 0.039146786495562524, 0.06762320160745613, 0.008344557173850556, 0.041412185096452316, 0.02130678017443467, 0.044257914452182676, 0.028226503824454643, 0.06061287273863151, 0.10812478395359171, 0.04509719058630928, 0.008602525791033142, 0.019375039677646373, 0.011338133838087803, 0.011440272510592497, 0.09360057662331289, 0.018279729298345985, 0.06332746699392315, 0.047020461981094656, 0.009600120697981648, 0.034983903019418644, 0.03989555700231464, 0.015177680329690057, 0.04419873032959239, 0.03854286406309374, 0.04117786944393189, 0.029484460415739207, 0.0711332785806829, 0.06555544603015147, 0.0370966854144729, 0.007960122283322798, 0.034493794439420584, 0.07902417572275286, 0.04581435613574521, 0.03992603581038214, 0.06256764183842367, 0.1397498970430705, 0.05109229590743781, 0.03002356223371481, 0.08043858853559341, 0.012877441965223802, 0.008837355680072741, 0.07461368496860228, 0.04536723274917853, 0.033510627840916, 0.025432851210597063, 0.003857349656755105, 0.123706805489717, 0.055433559126310775, 0.04836134184452315, 0.06109718586348238, 0.04506267449488083, 0.03420143613531705, 0.048661207810284636, 0.0779246097250331, 0.0677667128583116, 0.07581818969018998, 0.06651750690634213, 0.050901099513735504, 0.013246072940678607, 0.040850171503881295, 0.06734613058788162, 0.017562274550718647, 0.06453985859069132, 0.06255804658717205, 0.02850774236233725, 0.020558042226419337, 0.027008801323151397, 0.03561132136852511, 0.023707083028350628, 0.06123855589858948, 0.02267219017319862, 0.016332697686589053, 0.07959684942879024, 0.032221389964463255, 0.021771927694639853, 0.03200719944171367, 0.032492948981422576, 0.05467181109012135, 0.044087877406949, 0.03111901050884157, 0.028283232635247613, 0.03440582456307546, 0.03245956286968243, 0.03304990256325372, 0.035366851220568346, 0.02619103119227915, 0.012045148722527009, 0.06527314263005411, 0.02464051902925055, 0.04624490137963046, 0.05907715756386038, 0.06438333916688158, 0.08678607898013246, 0.03497515812576298, 0.028266353803055904, 0.008309940533382038, 0.008576114909843573, 0.050500703660110315, 0.01602129156385819, 0.06327679793861124, 0.016207731509160613, 0.04127526986262491, 0.013291749975553924, 0.06501782850752916, 0.02922607428063789, 0.03458006743101343, 0.05466495460319904, 0.040306965369851365, 0.01776401805991848, 0.030304613080055966, 0.021333606658323158, 0.044150129711676034, 0.0370969535452464, 0.07502898123235473, 0.04615746776483232, 0.03887803519084569, 0.053149065783908295, 0.023859821808254047, 0.05655189044773579, 0.04554051034633191, 0.08978268552211024, 0.02737084873050692, 0.05063341690167304, 0.030251534678222194, 0.04568997793079865, 0.041398196330954956, 0.03934613406477917, 0.0506737667526449, 0.05376462126150728, 0.053466892681054534, 0.10396513336848828, 0.016880042610629913, 0.0066724721240931225, 0.07062888629133664, 0.058709699660539634, 0.045296089994090225, 0.015256990539661099, 0.05600732833807988, 0.1443398668761215, 0.045158152032883904, 0.011304152092986531, 0.017286122836653265, 0.09750317406630325, 0.015170183201741069, 0.048116649531068346, 0.06135270299930727, 0.04742691375976128, 0.03334865004064576, 0.06058215261286786, 0.043363525952783324, 0.08161066475534633, 0.06779412348424235, 0.03236705392238594, 0.07180240275638719, 0.02694347126018857, 0.04201384373910485, 0.05872231712865253, 0.06650847472971486, 0.08750860714503834, 0.03573391841904771, 0.05451433788684588, 0.04341969934983119, 0.03212842327963201, 0.05437531208078708, 0.022993159946054224, 0.05450254396325158, 0.0209500570781529, 0.07499321258717007, 0.0814827663763877, 0.035310252644722505, 0.001885907251797166, 0.05361586996924974, 0.0348357952410175, 0.06421224108987278, 0.047812776925462874, 0.044187028336549, 0.09616602888150562, 0.05601872772639317, 0.012286994061733206, 0.06128581203219872, 0.020262973886283658, 0.08037291181784484, 0.054163645817748005, 0.038032810383987044, 0.0034822596024887097, 0.021474346586112535, 0.021082942689498587, 0.02528933612930198, 0.03202487883578626, 0.034862769196831414, 0.03013746227107702, 0.023652821020673842, 0.10969431424934058, 0.033715303551646016, 0.034951018695268905, 0.022743334843506737, 0.05207583022814605, 0.03350761328493396, 0.0185040915535102, 0.006390921884186326, 0.05170550715598849, 0.015247182699010499, 0.01698315038435882, 0.014932333011059992, 0.04862952624417601, 0.018955037718819037, 0.11047658195058185, 0.0508941894006585, 0.058540283146524624, 0.12057605695219771, 0.006665799019467687, 0.055264422234388134, 0.04138189397992627, 0.12451464520587076, 0.0603294508501647, 0.0328559291008259, 0.05292901085809835, 0.04814392609161235, 0.0187605950275376, 0.10063523261417305, 0.01737266012857999, 0.03715935523711866, 0.06367141748928735, 0.05333903643693175, 0.14742856484747704, 0.16167361739902728, 0.09927186423972731, 0.1260616371948873, 0.1240929214644336, 0.17075146818833967, 0.12109458356374696, 0.1756617853478078, 0.2489601279939375, 0.13524228166187965, 0.1802314385291069, 0.13589912544815771, 0.0817159865231764, 0.09431917475716722, 0.1739326176503974, 0.14547979038569236, 0.11867379168829612, 0.1659123359187957, 0.10744773842875036, 0.10928546844591057, 0.14695584263292052, 0.1462106535872144, 0.08445869620528915, 0.14232381457282653, 0.10862917624293797, 0.11953920291195955, 0.09800797238224938, 0.15995788688380874, 0.1774324137236803, 0.10759390800470307, 0.1456377730374375, 0.11523347468145433, 0.13842240456611882, 0.11634727459280722, 0.1779830930454116, 0.09096953957792252, 0.2772327254135763, 0.20110307501689081, 0.09748943044894165, 0.10236129765549015, 0.13509692413912666, 0.11143101259104668, 0.26234065032293724, 0.09693318166800084, 0.11167623733560886, 0.11787065575199744, 0.2491538869517465, 0.12266176196956828, 0.11303490193019952, 0.1786581084372536, 0.22829260797269885, 0.1783743647918586, 0.13260732224631694, 0.23195844594269033, 0.16151842330732655, 0.15630899477870236, 0.15596089974766777, 0.16324178405827092, 0.13191707702654024, 0.14281768081409318, 0.126892697036026, 0.1462725075262208, 0.12150428738565215, 0.15215886666649772, 0.1259063435117564, 0.17932990625981363, 0.09786952497257341, 0.09178242781349728, 0.1537228504856748, 0.09817060518769488, 0.16274424059496773, 0.1744159731653429, 0.2097681576326009, 0.14069549468976839, 0.1316893803736856, 0.12205569449091151, 0.13102571840488142, 0.16617410816252234, 0.11419867375685323, 0.10667701567252798, 0.11755547185818996, 0.12529843742208135, 0.18509707744083098, 0.07849131560614032, 0.20884319839458312, 0.15869577235031515, 0.11826996376077015, 0.1334124040459433, 0.24403937671694065, 0.15302848371286548, 0.22952294517909327, 0.08851463380720347, 0.10428409407576246, 0.13091891042647824, 0.2842635433039358, 0.18756859965862768, 0.09766496417503204, 0.12347559249328992, 0.19768236986091062, 0.12753911436565463, 0.1767242573682339, 0.15733463329172906, 0.20404433170633934, 0.15226970426738262, 0.12094423880860691, 0.1288038948851247, 0.11251145703417641, 0.12763794736876605, 0.15965197265388506, 0.1502770176457782, 0.1840551365767756, 0.18957213408523993, 0.11574695277358256, 0.14566772707527684, 0.1261924313861997, 0.19389545935536587, 0.15028026585857715, 0.18483507537072708, 0.10590578729827559, 0.17089440487325194, 0.1329473427106296, 0.10445878510513615, 0.1450198005524374, 0.1137702237634409, 0.1480883963766598, 0.23426418673367272, 0.18118204639082958, 0.2283858255513253, 0.1397798051156344, 0.2006524161345536, 0.04354116642066548, 0.1969280337253886, 0.13311696989882377, 0.14406157777674738, 0.1404924201028001, 0.1871647334267055, 0.18055737829737126, 0.12732106275976668, 0.08895874263778811, 0.08563406660311645, 0.10454328460318428, 0.18618228695084973, 0.15790395919353734, 0.10398783255368473, 0.12432149911840117, 0.1184012865527503, 0.2667990675376308, 0.18011917600468283, 0.1852926596878998, 0.15727754441961167, 0.1131329382018697, 0.10483213805503423, 0.1389480481344846, 0.08080546038165208, 0.06815938654566003, 0.12655171130092877, 0.19569496924598373, 0.08070354004420581, 0.19192385547343763, 0.19540046972613181, 0.1888807397335768, 0.21004624754911472, 0.1508256744953894, 0.1902962710347868, 0.11649349779491464, 0.18762867627364976, 0.22762844038586463, 0.10539479899190127, 0.1340825164750699, 0.2992733201432613, 0.07509127184147797, 0.13104586651729, 0.08134703857884293, 0.0928193814451656, 0.17471814888619608, 0.2588347255462601], [0.12698416793418507, 0.026748162889552694, 0.042813777427880034, 0.03669989783497107, 0.01154201569020628, 0.011813149528367626, 0.03441844586162798, 0.06354652217499192, 0.062364708977721395, 0.03671951351627227, 0.04764413799069101, 0.01658635131353813, 0.003573137979518863, 0.04734045690706661, 0.05829662888220722, 0.04459644870592221, 0.004579642967831705, 0.0476163404903585, 0.014134035877613051, 0.05039085431264774, 0.0892008570653777, 0.02098951252147315, 0.0326857962946017, 0.0371123634038433, 0.04776783054694534, 0.04741835655764707, 0.0021945390589309917, 0.04730456185737445, 0.04729172605420313, 0.022895740375163096, 0.01646567522848566, 0.02318951211148693, 0.044085211420972506, 0.030180711764842275, 0.06946673091020315, 0.0699584138008856, 0.055794696804256215, 0.06010781778323074, 0.046343726721862634, 0.02724477172558827, 0.04034925342327164, 0.05207276970688855, 0.06985676159421284, 0.024569694200650822, 0.04150908755799455, 0.07776080480506344, 0.04534657135786069, 0.021897219459436113, 0.0329982107805629, 0.008012732892717806, 0.03572664441420667, 0.035872216441578446, 0.037933276410424904, 0.05396680718648338, 0.05750642834051002, 0.0598037536556442, 0.06874630948708904, 0.029152075932811827, 0.020724158816700502, 0.006338766618301311, 0.01087242324325827, 0.06145044049668697, 0.03688357124525694, 0.07059379180352535, 0.014824009136176639, 0.036936664968849196, 0.01959452769839235, 0.013844396228030806, 0.06418896350829352, 0.018536232772373387, 0.016964415704170545, 0.029902296260960644, 0.01905262199861388, 0.03233344181470814, 0.022622888584831552, 0.04130073462522799, 0.022832532375750524, 0.052523106832297585, 0.05863114883522353, 0.07462228813599195, 0.013721590418548835, 0.04473640530880901, 0.05799667481633444, 0.01714603791403915, 0.0036260320414458554, 0.017625555328484026, 0.025169952817621733, 0.06158695736479375, 0.022332286537294428, 0.06133620529585789, 0.008778340096825795, 0.07041813550336708, 0.048968382254843755, 0.055086686005515445, 0.03135109684550234, 0.0597146078343353, 0.015743018743852456, 0.06018631115195252, 0.06600635006062447, 0.06058389929333522, 0.00929718463486361, 0.026069322803748712, 0.04360444528321105, 0.050030409944273775, 0.03878998104482889, 0.07329625122609638, 0.07931681364894876, 0.07369568946981624, 0.03140534544664045, 0.009485343489946138, 0.055848679189840635, 0.034890003622539585, 0.04716468952415932, 0.10697005962532376, 0.05637129288046591, 0.023160280111516197, 0.029860098222871462, 0.014674197769753877, 0.03697508810869148, 0.07060394246852206, 0.03511427203193307, 0.04477102099166763, 0.007263610464325476, 0.02330622943719068, 0.04510665943305339, 0.026365398549504822, 0.06909418235262556, 0.06781013472185982, 0.033387268532908736, 0.019378111690222737, 0.019995936703297402, 0.018306632391026905, 0.0668883164443316, 0.017626541666686535, 0.0458186692107589, 0.02272733509720814, 0.05326435052519364, 0.036787978794065215, 0.06941101333547024, 0.06252682467381801, 0.030669613756359588, 0.014839250455430199, 0.0036355892277037307, 0.14158133747837237, 0.053643050768803206, 0.05624949256138456, 0.03936452783584114, 0.008565087074173555, 0.030946684775934107, 0.030604888902856942, 0.12240598819428876, 0.04082738038813395, 0.06371730615595175, 0.03772036525450888, 0.05914494102340072, 0.020709361828443025, 0.014342369658181505, 0.0541260960181394, 0.06543186838708578, 0.046274047194709705, 0.058070100513437105, 0.005587909479565438, 0.07692888694544954, 0.01797704412902315, 0.012480855483802096, 0.03385232986822244, 0.03934641368687153, 0.024000316587907654, 0.046299734122810826, 0.0850016380389852, 0.019200971094711174, 0.04552287117187535, 0.017491062847717155, 0.026928888776549892, 0.010259981913071488, 0.07648094001436427, 0.039314004337234844, 0.013008427678517277, 0.033246626281329704, 0.03938220914513354, 0.05491384124803928, 0.09051778518985357, 0.03925466316662008, 0.03321105298856574, 0.042518094302185123, 0.06049691383997279, 0.04285478228402715, 0.0037336341178630513, 0.011255723844853141, 0.028358598450018514, 0.03724113129259598, 0.007715423745403608, 0.03620635335063262, 0.04684552963402483, 0.028892693883408944, 0.013636845772364929, 0.03821073430440119, 0.019989009353242094, 0.02145294783516757, 0.04059380018002084, 0.02909846318465087, 0.02636083841113554, 0.019414261464149724, 0.027506252855903683, 0.1427010822320177, 0.010513635540020563, 0.024735971669396086, 0.03366099174825415, 0.06179193568025386, 0.05129278877810125, 0.055644850006266955, 0.04521248298847387, 0.042744837175574035, 0.038103248338185014, 0.034866607297332056, 0.05185890860194641, 0.07443193060856673, 0.04997209150103792, 0.01092282033735706, 0.03680358017464319, 0.03417664936052696, 0.061113147305384766, 0.0401383072828814, 0.03930150561275021, 0.05392727321915088, 0.056719115950287356, 0.018635678645824234, 0.035119515903774774, 0.016880479280746753, 0.02033421623280212, 0.015253983644558298, 0.027802491395343697, 0.006157502075732356, 0.038043891845811764, 0.01758320790324961, 0.005740798125419045, 0.012811379330683381, 0.05419100664796368, 0.050252640559788675, 0.01102352451022354, 0.03261199904485576, 0.04358936101198197, 0.04920297369901692, 0.043031197011230454, 0.010388003823707902, 0.0490522382390355, 0.01990112374656864, 0.029328655368918856, 0.03140341107463164, 0.03439863865834571, 0.0291994986905446, 0.0036795001905111056, 0.02765330726340894, 0.08037642050053805, 0.025337174489733674, 0.057730474584405465, 0.03953202913004545, 0.04884893765612956, 0.03057997380833953, 0.049831908902213465, 0.05047985840769065, 0.02916639411611663, 0.03391204259148048, 0.02796864054436165, 0.06014507646942812, 0.10534189295985046, 0.043544839812262405, 0.018925451403183323, 0.04520309841140144, 0.020947021454752936, 0.042575160191664775, 0.01935117986924466, 0.0404755468480289, 0.04020582644208785, 0.035441809093519565, 0.058614658792653394, 0.02984635269029006, 0.020225629015194795, 0.055081396168398286, 0.03724337976065375, 0.011030341735139731, 0.07868799335894086, 0.029709948820152113, 0.020551817762034557, 0.0070878794705945885, 0.023009259283782977, 0.03545447252690792, 0.09029035666777242, 0.020574838704159184, 0.036505962676939466, 0.036194275974506335, 0.026081394434215564, 0.015476575279007516, 0.059803929855866786, 0.0445675786824957, 0.05224932616035785, 0.03828047511858806, 0.024012991512614875, 0.03945577273806257, 0.018113898075816613, 0.09939864413031649, 0.029043753015538378, 0.06486398273057516, 0.0573147454809758, 0.05738864998303114, 0.02534701871956068, 0.03140241516033008, 0.04220858711989657, 0.08722999628873603, 0.004911556306685652, 0.11641401617277054, 0.026131004372972156, 0.0563549330728429, 0.011766539781444497, 0.020099709058300625, 0.06031971004220748, 0.03679007404453812, 0.06755901876115991, 0.018069890155006322, 0.14452165954055327, 0.021768376877110814, 0.03820174043217013, 0.1498887183204774, 0.025163856672964273, 0.03856024659809567, 0.07790124404334253, 0.06951067371353989, 0.06044309233285247, 0.021234223987126065, 0.05519466609844277, 0.07266999733063483, 0.02110237067925834, 0.04484718545309959, 0.013116282324547009, 0.05829585130296408, 0.06883597241774683, 0.03627399891434658, 0.02782183320021197, 0.0779025617145723, 0.047430012585414995, 0.07374260469429916, 0.034434866956284935, 0.056814750536314906, 0.014486684343747556, 0.042983182450576175, 0.01888167905440975, 0.058083974365745826, 0.02865917496232977, 0.02306931100094751, 0.046638961686121846, 0.014499389911971748, 0.08450715892737912, 0.14438883521624152, 0.12462875400219234, 0.14157507087915175, 0.13393222534608457, 0.12193759437650444, 0.16218046116973125, 0.13611476387708418, 0.21032266739395358, 0.13351740405684517, 0.18664708781626918, 0.15439613451880796, 0.08697436040928287, 0.06824144988410896, 0.10723015413649621, 0.11021824944163523, 0.1096482876868498, 0.15842865281287702, 0.11893418497375904, 0.12469265339595657, 0.10377669872175302, 0.14076580623945883, 0.13587461063458076, 0.11386608434540611, 0.12446124121666917, 0.11047213097974179, 0.2362571185034129, 0.08573538939198179, 0.18508465149469916, 0.24397410602579195, 0.11969375348980389, 0.11768509393497822, 0.14714897339863164, 0.1733467902147001, 0.09154615097589071, 0.13802281310481412, 0.14091248143344157, 0.16446508857752049, 0.2128186737818103, 0.14027817595389583, 0.12432508440988681, 0.12932173967842134, 0.12817710472811616, 0.15046827915695407, 0.12218766845762731, 0.11121519796189763, 0.18928907991897678, 0.12956963040896002, 0.09132974645903996, 0.16705196831495533, 0.12028285212093785, 0.12531765856810156, 0.24008449377311816, 0.06078862479978031, 0.1427690955179353, 0.15898012886604956, 0.20158463788609352, 0.15261712514104384, 0.13635589771213072, 0.13562049927009692, 0.09008520598252935, 0.08904180189053859, 0.13576375771193736, 0.14244582173564743, 0.17627637172418256, 0.19951970917322945, 0.15539324391753445, 0.17076078381749893, 0.12649708923192757, 0.14771802350878716, 0.11348911546050541, 0.14151736913669494, 0.10049120042352908, 0.11334103832562124, 0.12195742073198482, 0.1292798346689632, 0.08761983545076463, 0.1533768392137943, 0.1797977714769302, 0.12242662660296887, 0.13853364053272432, 0.1576937140235978, 0.13271814452544337, 0.1669814116171291, 0.12251268892038254, 0.177398675211495, 0.09615755594906308, 0.11701534922805526, 0.08970524169384472, 0.14958044453974695, 0.19782221155060878, 0.13245485542762664, 0.13268877271442645, 0.1465391367673874, 0.18014065711007965, 0.1669020908734491, 0.13275450305832973, 0.10408419875367995, 0.1672853953054836, 0.12749822059225652, 0.1694352372038749, 0.11173418422620143, 0.07892987796015317, 0.15509604776818908, 0.1230908707985955, 0.0917174252531221, 0.17215966036723507, 0.11950056143705884, 0.22436392523588675, 0.11899609253892016, 0.13848315533851424, 0.14759855975787486, 0.17477189761496362, 0.12038835774986975, 0.22800766923014196, 0.13516757276750382, 0.13129374192607018, 0.16002504215125116, 0.09000400066255562, 0.100188113058046, 0.14427864112921301, 0.1214394916690165, 0.14660169550728414, 0.09963161146809017, 0.12827271250106637, 0.24257783417499837, 0.09315428444214406, 0.1628282804402613, 0.14581394261650502, 0.20963586956983615, 0.09850200716285937, 0.08201117552216015, 0.17188391467976957, 0.22492143806190262, 0.08233846360517126, 0.2729558710369372, 0.14967569991225196, 0.1658371826934238, 0.13670239928028277, 0.137335111296946, 0.17634174966764066, 0.1327609994839276, 0.1200616135892849, 0.26300107940070094, 0.28802126585956545, 0.16846308694972148, 0.16854836785745236, 0.3633475045282995, 0.10154298551741148, 0.1415405049920082, 0.1538496840024187, 0.1946791673019048, 0.21298094652593139, 0.128831795807327, 0.2736640120706251, 0.14635605707524285, 0.09606427708340269, 0.11926222382293594, 0.11434839031989537, 0.2324489567188486, 0.15818514410526524, 0.14831304399957582, 0.17322196384831784, 0.21101597696542743, 0.17669174459672746, 0.14915042406608983, 0.10757061893180495, 0.2157129692815004, 0.10416915024360342, 0.12348965020670045, 0.13614450341030476, 0.1325578482881669, 0.1112944957229399, 0.07247212448067243, 0.155452263331221, 0.08030129791868311, 0.21888690219531137], [0.040805922265374855, 0.016675200275776368, 0.047592415564483216, 0.04730292625965611, 0.048014009070973244, 0.06126636489024086, 0.03350761328493396, 0.0540965480068999, 0.012990045398774167, 0.08966916661349036, 0.020790053869507486, 0.018726990580739036, 0.025955757929853378, 0.09306339577080742, 0.01721364708857671, 0.05110395576564535, 0.021005799550743356, 0.03665233526619212, 0.08965637294515487, 0.04176478089404203, 0.08821366850527064, 0.03218379419957919, 0.027452701394776666, 0.021812105175828742, 0.05373329975672307, 0.03497687416271337, 0.024356984142814914, 0.031453143587456114, 0.053721218550157164, 0.0490691879343602, 0.027296097701295253, 0.0592610186656877, 0.03247398447485701, 0.0376234551320874, 0.07212724701891984, 0.038219226389041835, 0.05559635281022038, 0.12642440280967182, 0.07474760479864574, 0.047358034794489225, 0.017148483649737412, 0.05423679572319793, 0.020914225230714487, 0.042647283539296164, 0.05721488975048546, 0.0539701932951087, 0.028622100137234218, 0.014769273111596705, 0.017738135779396664, 0.04852563706076434, 0.02711440654351346, 0.014228590279667368, 0.04832237478225462, 0.01725631627073932, 0.03239960882872824, 0.04585148458699546, 0.10783539424019475, 0.015930519720930007, 0.04678826839212449, 0.06421269308174811, 0.040683137523310806, 0.03778891097153387, 0.009413658727651403, 0.06385272751832682, 0.07474260990537944, 0.060757471834339445, 0.00256937462836504, 0.06535922793010551, 0.031652933572449034, 0.015084531698976795, 0.0797578657887155, 0.06513124782471888, 0.01461411923951199, 0.04421008375263022, 0.039474833005618666, 0.05568171032674371, 0.04368812506718021, 0.011005138400040809, 0.030573933205056577, 0.053773756860004324, 0.052627854034184456, 0.039064485669857076, 0.06050404994898747, 0.01644475719771318, 0.05303160535291799, 0.03167233666435125, 0.02160948641117542, 0.06771857955402906, 0.02771134991499205, 0.07691670614745348, 0.0309852879464386, 0.037376184932767384, 0.07744784256623638, 0.060122856089184364, 0.01080411309826999, 0.008661917714972892, 0.042207755914498726, 0.04722310755882533, 0.005674312227300459, 0.02333305209063955, 0.033569777489549694, 0.07530735460140052, 0.061005806895874204, 0.056814122344217, 0.05340841718979421, 0.056962348866246404, 0.020445011698851184, 0.038456142910065196, 0.026532731304365783, 0.062373342788628036, 0.06100653084896265, 0.029829312979634252, 0.05159382302794726, 0.04063238802876684, 0.027898106829173146, 0.0712242668434497, 0.09079795886552142, 0.022264755886769103, 0.07588625660226231, 0.031568801796604554, 0.031214091596343828, 0.07441596533622473, 0.061716816928838535, 0.026933759180528503, 0.014562452354678705, 0.035267271281730746, 0.05455704728862452, 0.03106360128449817, 0.029535248214679382, 0.04296037601307035, 0.030915014701144352, 0.021221970410777197, 0.06106384954745732, 0.03502905624167573, 0.0490446501381455, 0.12476966821498449, 0.07478782441467047, 0.006388197962810556, 0.050963160296481465, 0.019180476327516863, 0.022094567539170388, 0.056655036525860916, 0.023164271429601698, 0.043654558924777855, 0.04859257016270872, 0.029277042110240268, 0.037798732218723145, 0.01875090593051526, 0.018810992121636387, 0.061049010424364, 0.020046261019043384, 0.056678337090077906, 0.021452463284555464, 0.03652579669329909, 0.029171350704986724, 0.008595372445040174, 0.024070785185622594, 0.006929739770824991, 0.010757211280325729, 0.061164360283122915, 0.07402517622517002, 0.03568901800580564, 0.0771747705256266, 0.014510575753276148, 0.02622041257939512, 0.06385331357558889, 0.0637116409357517, 0.012965241387005777, 0.015535068964856047, 0.026784192004631606, 0.1034921277013998, 0.06241586449886523, 0.0788116552716782, 0.039388104191710877, 0.038728330119122426, 0.08107303957184477, 0.011751125134798068, 0.018621986739397533, 0.06478817066958835, 0.04474032384854171, 0.03913914859895745, 0.1313241862601811, 0.01775261292594575, 0.034457700206868114, 0.018025997147384672, 0.08593925304951207, 0.02731483621192315, 0.06441452660627904, 0.013621328661458628, 0.062431259035703644, 0.01416965322043266, 0.10199470926196345, 0.041457418757941455, 0.029061361546477968, 0.07056489496702148, 0.09123554828787044, 0.012944294627936137, 0.01332769194813145, 0.01627172666391538, 0.012513130768052032, 0.21526341356577414, 0.06399406690991695, 0.05618649715137097, 0.002334228728056675, 0.0408697871851825, 0.01983721094626573, 0.04292599398702864, 0.044958076680139195, 0.0441239218437864, 0.014076478734251954, 0.017037236191813025, 0.08345909702080874, 0.01103854940963849, 0.07549457882921543, 0.03575220876823991, 0.04031986246005662, 0.026109446658782905, 0.09506599557015205, 0.026171503611089244, 0.025247086380277912, 0.07507317684470646, 0.021684325540498383, 0.04487545409750554, 0.010123466960184518, 0.023923700134600365, 0.003702873533080903, 0.021902417366002357, 0.018094874197436918, 0.010427432453950808, 0.01475011133739064, 0.0028208777028691746, 0.023454858155380336, 0.08160290428467336, 0.07309063322721951, 0.07454577893499406, 0.058034044585280845, 0.024985988293924642, 0.08966056344610068, 0.0027632283895546875, 0.024887203171308485, 0.03861561560282304, 0.01047758631513364, 0.05478253760825723, 0.03214992545244675, 0.01609278384656195, 0.01125703002476404, 0.04470893722628394, 0.07729339924070143, 0.029340673373231006, 0.061390639673317635, 0.013485797173944453, 0.042442213293285146, 0.025131646506187898, 0.015057220664476196, 0.02871857933519829, 0.03295498426943537, 0.01092638168859506, 0.04776293907554881, 0.06266273250202499, 0.01256365618187814, 0.08509251138856334, 0.01188515987803018, 0.014379486618112895, 0.07656103450684779, 0.019701418031247395, 0.04836877289738867, 0.027319459552546183, 0.048828375856241876, 0.04507451438375058, 0.027304901966765046, 0.02710702528636302, 0.01436976208952406, 0.050936205492865656, 0.0016020826883651619, 0.05323349633404324, 0.039516734184637185, 0.01987157382010933, 0.04629301170127527, 0.04842827494646754, 0.01960234179522001, 0.06026594216124185, 0.02292891389750425, 0.04947563205214758, 0.11037999358508857, 0.058646060736669656, 0.03070493998576797, 0.07734002335177315, 0.06717197582005494, 0.0480113698980741, 0.02251109145882149, 0.004384258467208354, 0.034183789299981254, 0.06405626558848927, 0.12753671651045162, 0.021947802329856544, 0.04761038032630759, 0.04933189863579408, 0.038395706233718706, 0.06469937341828501, 0.026975336687399015, 0.01959535315813076, 0.02338409461381455, 0.09826211439025018, 0.04914026557197494, 0.011478137363859964, 0.02176686768389998, 0.05748270259749505, 0.030189087021074472, 0.1229202936613752, 0.04958630111368914, 0.08559495781458194, 0.04310627745824956, 0.014000816060410393, 0.017720038867405346, 0.029644584283232692, 0.06233043420398909, 0.07149624337832775, 0.10148277100656303, 0.04603906887613478, 0.06479665892378939, 0.0658375119429923, 0.010931752922554171, 0.03676659344965893, 0.03550462830331057, 0.042592305239410176, 0.12894153024160093, 0.04745567653087839, 0.13236870117966207, 0.059596454093773524, 0.047814695975713195, 0.029666528871823705, 0.02676413390755413, 0.03117162734270096, 0.04608130713383998, 0.07197009174213295, 0.060431750401133494, 0.052015703817408894, 0.023288249353607817, 0.0344229772717001, 0.022948581289740342, 0.044616340178876154, 0.08427982999672813, 0.06191909478436555, 0.038371988151582985, 0.032335265103967926, 0.04338348254321083, 0.02614183302578186, 0.014748463290743532, 0.005087199200305247, 0.016895619093350345, 0.053550392434361486, 0.05074633443127236, 0.07452801335602999, 0.10310830999045603, 0.1262847679637132, 0.09808869506683081, 0.09727210662658177, 0.22775193375925865, 0.13608436550824873, 0.15655432677557393, 0.07305021442833447, 0.26803596245665706, 0.134561535932364, 0.12410432085274689, 0.06258423530286358, 0.21494294366528913, 0.08091813659355526, 0.21864636590884579, 0.15159070521833437, 0.14596066377576322, 0.20711246787780718, 0.18314658694209593, 0.09096468258048258, 0.11098067546563764, 0.12890235250515322, 0.12165231855526087, 0.23432185783261256, 0.20842402572593383, 0.11469192712778047, 0.14209210361924865, 0.13850169466628184, 0.06869226964491029, 0.19215881463981446, 0.1045450772489271, 0.16669630433522886, 0.11796207302400183, 0.18371854818636374, 0.1803956111712802, 0.09861246171978214, 0.1654156504739677, 0.21140787690397234, 0.10834010828646923, 0.1734141753085198, 0.14395449400669144, 0.09293611792306747, 0.19065227209319993, 0.3167335364607073, 0.11194090539168929, 0.11816903933762543, 0.1239881129755128, 0.1262099671387865, 0.22710655064832783, 0.2084151237842537, 0.12981148436665535, 0.12302382278346247, 0.1600470441964365, 0.1263834477492398, 0.09995602672138523, 0.31068622224753906, 0.17339488521458643, 0.16140692687082678, 0.11900784432767861, 0.12849254909181787, 0.2433546166867018, 0.17743201535795966, 0.11648426643542706, 0.19265972888998448, 0.1420006020775726, 0.17681451784747262, 0.11728532627345094, 0.06296490822287817, 0.16424997108838252, 0.14391920799689908, 0.14837934124854305, 0.1504573700649123, 0.11627733842619967, 0.15744453626534632, 0.10524285311299948, 0.1467535954209105, 0.11259292282404439, 0.27083316397282386, 0.14251806382690707, 0.10001863908743668, 0.15524312132789245, 0.09933089897517236, 0.09822059242475419, 0.13493690369350297, 0.10761894375806856, 0.09373112566648953, 0.13564866066219347, 0.11637046407427519, 0.19032063263077892, 0.1393689368400843, 0.17500875667939264, 0.2945082838977537, 0.1422611485806204, 0.08399181924159489, 0.11349744283624234, 0.18333243987252637, 0.11301793308267671, 0.19014469287808866, 0.17922429337857232, 0.09248745086933337, 0.1041306849689253, 0.18081588700654047, 0.11677998403507857, 0.0710795681563116, 0.24383720611372303, 0.10581211006689457, 0.1868334003994542, 0.16814068650766728, 0.08042486790086954, 0.12869259763148524, 0.10877796583959173, 0.14460841133709879, 0.17996709222995466, 0.1475525331953841, 0.1283365429469174, 0.19236049494676052, 0.13515494763851166, 0.17297194339334968, 0.14512758912338367, 0.20434082305479437, 0.15531016934302547, 0.10777193917742661, 0.07739181089545451, 0.1379043299464449, 0.20099654283014037, 0.15133127720365602, 0.12066564327406308, 0.1528550260850499, 0.19024135785237437, 0.1662376015296867, 0.08181874189646014, 0.2171821727026855, 0.11165385224646139, 0.19887107784949964, 0.1652041948851078, 0.10202290129757698, 0.1338698964325651, 0.18494096404362112, 0.18482772092665398, 0.10652262597314774, 0.15808311651550955, 0.13638229710200142, 0.22470480371867457, 0.1302325569333569, 0.1268935933588974, 0.17981948240870432, 0.11369231262154157, 0.1368454738610214, 0.21233533358862325, 0.1386731451437358, 0.2095116560737933, 0.131280105561018, 0.18814125038202734, 0.16667863834769497, 0.12681338395322525, 0.09922909355091472, 0.17890105023980143, 0.11595529038459064, 0.17727216345167932, 0.19334393733691788, 0.23364373212379796, 0.11087611978573185, 0.13076599927679186, 0.13613449830201366, 0.11067034856927012, 0.1207173695307105, 0.1137426445981668, 0.10131344259265931, 0.19231258380797603, 0.15063145588482582, 0.15666701830923557, 0.15806774879174848, 0.09531893482011172, 0.1768957997762388, 0.17140256631518566], [0.02109139072408359, 0.011856964011977037, 0.042064911160137386, 0.02693951250083985, 0.004531828068842691, 0.045770355875814156, 0.04883933474399871, 0.005669570621854116, 0.023258544294343843, 0.012003581749365456, 0.029274261211075132, 0.028056859399282166, 0.039306056175020435, 0.07832046267726729, 0.04862715137161074, 0.11697014237964347, 0.019174692363688545, 0.04813811148426706, 0.050832749149131204, 0.013522476506149097, 0.042523839961617224, 0.011299592912227157, 0.04312411964600606, 0.07501098582701338, 0.07243280118751912, 0.0665998996625985, 0.022085717308425137, 0.034829306476298845, 0.01576282786235454, 0.05959711292938841, 0.03842178003622159, 0.02171644952238327, 0.037264753613741174, 0.01412235399437768, 0.043521133221445546, 0.05019092451660864, 0.06411274159026724, 0.015079554042688783, 0.032800000851913806, 0.06699321686380333, 0.007786090568368955, 0.04713122680362675, 0.04065546259704617, 0.01784459901823392, 0.02781943342978916, 0.03387357731680236, 0.00918861273901477, 0.020431938408423337, 0.01919025927030992, 0.03989135117961034, 0.025726050296197497, 0.01865082994974669, 0.09133053552960196, 0.02689583016739738, 0.004808166516839617, 0.06087371418553014, 0.03922528752516355, 0.039927299855457205, 0.03243589075282216, 0.010502764752375023, 0.014499815090769723, 0.026755017461255196, 0.04204280952352189, 0.046294543877123825, 0.026875647581032207, 0.06170315758114862, 0.05868069557172637, 0.019103135921121128, 0.03256191987724554, 0.046939616722445336, 0.010778813044570628, 0.019348395139639898, 0.07729798810736788, 0.0784804984446495, 0.027587341347468958, 0.016318076898554162, 0.08415262875778061, 0.06388541649005587, 0.06890114351746536, 0.01618406705317959, 0.026439241764526215, 0.06405798162543966, 0.027591776996550542, 0.008483546590732952, 0.010159409890371946, 0.09795947135576318, 0.026365745204290556, 0.0397673866621429, 0.07646831488537212, 0.028829543340590694, 0.03272284813705952, 0.05670675895206871, 0.03185204173918934, 0.08339361948592049, 0.02397353798451443, 0.06310916640945981, 0.0037918730794767584, 0.025445118193484606, 0.02857679561261208, 0.10503795523677142, 0.03645612099658578, 0.07198689971119165, 0.037450177534934015, 0.03305022432018192, 0.03346597257580969, 0.017277985067677595, 0.03393102241980453, 0.042475185717546174, 0.016741867162167065, 0.04070980121351538, 0.04426590474923292, 0.04158674206043925, 0.025923769928575046, 0.04896282811739272, 0.01769500119882005, 0.09367232075742177, 0.07483102411272065, 0.08941019059068735, 0.0424142855580055, 0.03067309179553582, 0.06387273773490902, 0.02189158296753322, 0.09573299002142684, 0.02900278454856767, 0.045775044333910754, 0.023128288279798244, 0.02681328802399578, 0.021643466241056883, 0.033221533071369894, 0.048415458295494325, 0.019076726955151366, 0.049168434624950734, 0.037514551903211305, 0.0315289001070684, 0.02462472995713113, 0.02228896809561599, 0.04449074772456962, 0.0352246499800634, 0.04854668532648394, 0.031807210273860444, 0.00979819368841427, 0.11878452969775086, 0.02137739815929484, 0.0668283777251359, 0.061178176678837314, 0.03663527448811839, 0.05704741909979813, 0.045351374729145924, 0.043157704940606514, 0.07459464002280466, 0.03470020916973872, 0.06574037965507278, 0.05715134658760602, 0.047177433396779725, 0.022710121101549557, 0.02464065117941749, 0.05963873065587494, 0.04379247773378607, 0.03609696365592461, 0.024638396965700294, 0.08148796045251432, 0.0069084094889882595, 0.060649461097895145, 0.06785763983404444, 0.08614166880086546, 0.03751614536609381, 0.022057090517914584, 0.035353245499033126, 0.03447085776696763, 0.055649599751397494, 0.11146617602677115, 0.051478082464346965, 0.09361251993405242, 0.018904203954603405, 0.07029363855479226, 0.04335404561472036, 0.014559647515265933, 0.02379100221479612, 0.07042953489168037, 0.06133461183297539, 0.030611189976034146, 0.04067249656204255, 0.05765815971479301, 0.03958705722564652, 0.03814066024196725, 0.04365208063034281, 0.07236412140510737, 0.0345676223326835, 0.03242228503128694, 0.059148311810267556, 0.004518445470415417, 0.03202233350865784, 0.03306434332062641, 0.09885338871108909, 0.04424452706570587, 0.05427232305068643, 0.03829019294390756, 0.05684376611644703, 0.0966632659096391, 0.08309953365354769, 0.03516430906470745, 0.07329493355486663, 0.016485423059953798, 0.01504244378602673, 0.040045913248773546, 0.02083785392554297, 0.02981835409187742, 0.039218722151652466, 0.019653947393019355, 0.03530688185785567, 0.012422718028838356, 0.053710255831960714, 0.04457796300430933, 0.06193919693149867, 0.06150659091109711, 0.006886790966570017, 0.0343093472803312, 0.04985334404233483, 0.02631598587838873, 0.036409642442219683, 0.0077985366243087965, 0.010550598324757191, 0.05758708590761789, 0.06374467464704668, 0.047532480675727136, 0.015374483529388186, 0.02598876674329081, 0.021376961489178, 0.04796451213018549, 0.03758536141005255, 0.04863488885964598, 0.05146621576239986, 0.028346065251577287, 0.013667707624394568, 0.007743732609425582, 0.10925296333528335, 0.023265350985551075, 0.02149184594952291, 0.03496602252726594, 0.031065437980296633, 0.06155834398082188, 0.012427732074302773, 0.05465465455105709, 0.006063740574679668, 0.03942466190745754, 0.014361602295520566, 0.07415819207146283, 0.0793633381685903, 0.024682019927328634, 0.02071126364171505, 0.04283133616310455, 0.03417019123932527, 0.07808784007905953, 0.07609843997465027, 0.013994752474489712, 0.08751396976050832, 0.07424279116094112, 0.01646469655116239, 0.027538955234171405, 0.009950220964158015, 0.05967247299849988, 0.02751362645217488, 0.02208608503062879, 0.016832920542407422, 0.08806254234044783, 0.06670458557745142, 0.028336492982963403, 0.05536954864979752, 0.03156515521808498, 0.09030429946799433, 0.04161181994864056, 0.08570918152409215, 0.08195456928543507, 0.030209826936404553, 0.024444385198876265, 0.06904404955886065, 0.06257881140035969, 0.03078529686336556, 0.036487951949839635, 0.00620777994739793, 0.04710321096823581, 0.033075888265645316, 0.025643986957748572, 0.038423595664602135, 0.0340919851535751, 0.041294310977982904, 0.047741867827191475, 0.062167682654915325, 0.036385196576555895, 0.01591674450244154, 0.037089185413694194, 0.058871072251349695, 0.029457135974699934, 0.05618795654886673, 0.03420763378662448, 0.042796808580357226, 0.03630029488234751, 0.054975591765175906, 0.016102281421603217, 0.03302154581873648, 0.03477512873829373, 0.019535399117176572, 0.018261013770355813, 0.03793189362172158, 0.015207632452309614, 0.019155229899972197, 0.03029121611748011, 0.05399427143856884, 0.028055434475743005, 0.003157447659290366, 0.05455321684900311, 0.017901189933200518, 0.04053784894847101, 0.09005213396683817, 0.10664107082712074, 0.013290318348745426, 0.016865100065666824, 0.04523569162213995, 0.04788082085489746, 0.09137249416521481, 0.019989313873191996, 0.039847155567258596, 0.024906129373477835, 0.07449088873521936, 0.050718084939064524, 0.03656916110025298, 0.0392576547399644, 0.10079410392791034, 0.07633128473835607, 0.04625220602798847, 0.11321261134599486, 0.053829466773858, 0.057327079496556715, 0.0722377015758426, 0.014540539367214568, 0.023595801096469648, 0.05112120423526053, 0.03954814761997231, 0.04930820736673571, 0.01724447638186957, 0.043012581074670445, 0.1115085636716216, 0.05369641262316897, 0.06944996124554066, 0.018403868100816206, 0.010431910237868228, 0.06470066810687704, 0.013266736247216263, 0.020514292860283487, 0.02759728708394593, 0.041959853692641186, 0.02678131342925612, 0.1427732477144849, 0.07176099570407983, 0.18865454461305373, 0.16206686565231893, 0.08763704944642321, 0.0776403681224873, 0.20794410228488908, 0.11129233535499343, 0.1425586205216185, 0.31934022723186406, 0.11999433574777459, 0.1478940705137868, 0.15595185991016128, 0.20524851467099883, 0.14016295633008405, 0.21248514974309554, 0.09989064111704789, 0.19881112380854546, 0.1905990749477379, 0.12002388375901407, 0.15323045513322278, 0.13344539179196283, 0.26165374524651036, 0.20790526162712805, 0.13628097431313607, 0.19488277815042004, 0.06635300484636138, 0.10188447687053874, 0.09299454744905235, 0.11840349288597224, 0.15664172208597585, 0.11421501441227813, 0.12122736192278324, 0.23704785913709672, 0.11638767040905454, 0.16080387777859168, 0.1530981057834241, 0.1879420675217144, 0.15070624138799407, 0.12573588128772475, 0.07097639909554875, 0.11693472613490398, 0.14354123553681758, 0.10882855062523197, 0.17851514110882438, 0.12708504639205434, 0.1400028439539094, 0.22051254077063454, 0.11918227488715803, 0.141165949284069, 0.11343420993897224, 0.13938465696429053, 0.21498091098281646, 0.1475984218620485, 0.1636916462091669, 0.22319731122303396, 0.13293687794958392, 0.09959625651038463, 0.09580085775063885, 0.20687090503352307, 0.18961863562224374, 0.0914080176622637, 0.14160487169940628, 0.13510095376160838, 0.15375280452351417, 0.1467330336210228, 0.20216381567860806, 0.1164253925784461, 0.18411870655273238, 0.11876193010398459, 0.1450088301733617, 0.16243587488368635, 0.14999255387773439, 0.18664670477230705, 0.13014726070386748, 0.08296476346590827, 0.20946159988882082, 0.1419260617225401, 0.11464031578432168, 0.12396205066432878, 0.19671705311104176, 0.18645610209674607, 0.11121971788065088, 0.0510870520355961, 0.13777259346698562, 0.19482824801196977, 0.1659310744294236, 0.157016339080949, 0.2449923594512286, 0.19267881980105755, 0.1127013089435716, 0.1931677830796088, 0.08712100495974864, 0.20729395410706922, 0.121053000311217, 0.18080505452329115, 0.15982425050629726, 0.15087062853478617, 0.19386493841246252, 0.21500839821753964, 0.15976823415727387, 0.17806989080723257, 0.13557870151294818, 0.12730947951035154, 0.09476004303583214, 0.10271048053137719, 0.10638044005440128, 0.19728336062642837, 0.19948587873049323, 0.12232090646941816, 0.134701025221617, 0.09508908546018986, 0.12737078186605247, 0.21713887341320517, 0.16018103297439315, 0.20787766714009548, 0.1535715634423879, 0.1220568742663149, 0.1815833079238092, 0.11489222081558359, 0.24247744601340065, 0.2756861777555558, 0.2374236252639563, 0.16005671222604093, 0.10970961302518846, 0.2406369350970753, 0.09223538495960737, 0.15912548638880253, 0.1214827832976176, 0.1423917512499517, 0.1285327304034464, 0.09107552784224672, 0.14175588295104044, 0.10144512544596389, 0.27217792407158886, 0.11127008050079308, 0.07619473722673233, 0.27327107025250313, 0.18778817577948495, 0.06809032371928615, 0.14936783981900062, 0.16352445518057193, 0.09723841407967192, 0.19344852366034063, 0.1325356010948458, 0.2039622990114074, 0.17041109532358187, 0.10468661199293791, 0.18396276169486586, 0.17229902708242018, 0.185940862002392, 0.2969257203080962, 0.15235403522608743, 0.11120480980964438, 0.1699531432842055, 0.15578070054611853, 0.16089370924859278, 0.13215635692881, 0.06170151432255103, 0.15187234978281683, 0.1704076479279226, 0.1964977834253542, 0.1382515056719703, 0.1203395579490931, 0.13189977876120998, 0.20750194697851138, 0.13228948768829146, 0.15641531246083398, 0.09827401173571426, 0.10901330804993069, 0.17155578390004175, 0.2753417139812824, 0.17622219398617747, 0.08007164774162155, 0.2509713845868265, 0.09949129480387896], [0.04608737455020028, 0.0357891112235525, 0.010016839970053445, 0.027431007699980855, 0.030642898355220115, 0.022933508509830124, 0.0551566757982777, 0.058956789829197435, 0.025219363573518012, 0.008655869450810696, 0.010554903738891647, 0.04969229703889259, 0.04856056683967191, 0.004727412709936259, 0.050519388544583516, 0.05270858821008475, 0.03845403616827342, 0.033340583134803085, 0.043217957755851175, 0.0033592598770009058, 0.022675532231768294, 0.04402042719565573, 0.06358080077916384, 0.011776114922888097, 0.05591170141293157, 0.03299618064756355, 0.041367196583098946, 0.06253893269346127, 0.04975545715780989, 0.0284375227431977, 0.033296310913658915, 0.02836120314896107, 0.08721526441795212, 0.06770740999209304, 0.029865564260211204, 0.026594102607979894, 0.026891266198588476, 0.05224748371889996, 0.002836255481534247, 0.029465419300381216, 0.01265936163103869, 0.08062429590931824, 0.007481992924435726, 0.09393800771044147, 0.030802171865117647, 0.07388191012245032, 0.016874754688732566, 0.04102119680253729, 0.028302392494233868, 0.04448668362813131, 0.048587965974283796, 0.0037649096573718014, 0.02903959315810954, 0.01355942971478667, 0.018898280179728905, 0.09302850046585645, 0.056221786991602955, 0.010554732326718589, 0.034733978325441, 0.04989770819402991, 0.07897878501323924, 0.03179689106952039, 0.03774622072195334, 0.034987702815523075, 0.02026986484716256, 0.05511693498720566, 0.01775842561807123, 0.03063406536145316, 0.011461189583755069, 0.05935351612166532, 0.00774668539956873, 0.04143489577296761, 0.01662980573582313, 0.04388206022521181, 0.010514901500315437, 0.043273353573655894, 0.042812927070284085, 0.03567171591003576, 0.015070592729194511, 0.0033319821194445175, 0.056593393261033687, 0.043959810488647034, 0.06472086218456108, 0.035890499129891396, 0.04268630039727977, 0.023678827790483355, 0.04575329509774043, 0.045358556803436055, 0.05505945541024689, 0.02623907065079097, 0.059022343972878116, 0.04902244124922061, 0.05438355901729196, 0.02154914549581947, 0.07921979627421788, 0.037521868042888186, 0.04944795329544333, 0.0644146261977092, 0.03948566165842837, 0.08254469447438756, 0.046851033975760785, 0.023186710144903873, 0.04836746288703815, 0.02419504464694089, 0.03011072197208001, 0.026569637590117996, 0.05560283391405979, 0.0503137628848274, 0.015677678147180667, 0.03041788875575989, 0.03222730033279907, 0.09858527325934942, 0.013862240331007109, 0.011889799498021604, 0.019928040245788235, 0.050479444720211535, 0.03709202376945365, 0.027872655473108736, 0.05391410033729288, 0.04775260071901064, 0.05769307034150247, 0.02433610633165846, 0.030682258037549835, 0.05378989833256891, 0.0574132337445213, 0.006925376421291262, 0.0635339200286375, 0.026010063987585808, 0.07590942310109254, 0.033545090306189754, 0.030532081821753137, 0.0266659616552774, 0.014592067398611578, 0.07909463282914893, 0.00837660454694302, 0.008352673875408308, 0.09213300496940652, 0.04796323659379156, 0.09142794360917422, 0.0665193991435151, 0.02442921282753589, 0.039814692591467214, 0.05734666836478057, 0.04522701184595785, 0.035044278408731186, 0.052412648444935206, 0.059778974541733344, 0.05558695291138946, 0.034372461433973045, 0.07564274789465052, 0.005943788442715642, 0.05558256322758333, 0.0443491057282494, 0.10511844809497557, 0.014210722236443433, 0.02294950825612872, 0.025457733746377692, 0.04690545303146205, 0.024714796999168974, 0.029990654926927342, 0.05200609707483842, 0.06371311182456632, 0.037102323821595604, 0.03455701201493221, 0.03942489173383482, 0.04858656786382199, 0.0805325645412649, 0.0670836995085401, 0.020224378376658407, 0.049870044759084145, 0.03705695992515933, 0.06489946792322783, 0.08628552479128684, 0.05927552071009433, 0.03320705784004062, 0.03578837577914519, 0.056365037772564165, 0.020198093899976344, 0.04512539794368129, 0.033719306361050375, 0.025445700420307058, 0.028266899640701955, 0.02698072420072652, 0.0716329517684156, 0.05292906065381343, 0.029522374107111848, 0.026932805401062774, 0.07032183059040578, 0.035904828804515065, 0.05244999523124388, 0.08781907193723225, 0.04166940677790873, 0.051165277273544384, 0.03896712738599989, 0.05750601465303091, 0.009895152648940924, 0.013222850900473855, 0.0322274841939009, 0.03851453413165385, 0.03255238208258825, 0.05901009039652925, 0.07402975743095722, 0.025329936874069037, 0.017546075621559735, 0.026429250062773788, 0.005022046773979862, 0.05132643152929602, 0.05226610348589959, 0.036444453477498986, 0.09867065375851047, 0.027058978166971958, 0.02561898759355949, 0.01966174808330834, 0.02133352813431092, 0.004796543047808472, 0.04238081134615406, 0.04091738422791805, 0.013094468928513028, 0.025376775489759543, 0.05676030083709667, 0.040595577504005165, 0.042732916847472234, 0.06724230269150389, 0.007253432986251409, 0.0952330946681961, 0.06907317622174179, 0.052605603010423725, 0.03512729552664584, 0.052222528404766516, 0.052121707403491584, 0.01613217800284826, 0.021049095009784066, 0.05512427410952026, 0.05768978765474693, 0.038832008628354925, 0.024034681376971068, 0.0018538189408812493, 0.11490001959065277, 0.03473287132839042, 0.06148091930475447, 0.034405774767360384, 0.09372771657522648, 0.029623894163617687, 0.0367826966178273, 0.05354820908377728, 0.06738620464720073, 0.04499203735782255, 0.06275141100970007, 0.01433689404474271, 0.0899785282390733, 0.04299499935680821, 0.04663437281945541, 0.04592024097819963, 0.09823804390766928, 0.03439859269307025, 0.06293195112037563, 0.05485445411214906, 0.03376416463945662, 0.10443410941309507, 0.04349142816218157, 0.041888258945677555, 0.06044188957481135, 0.03372503286828438, 0.05143061565655855, 0.08064776118243895, 0.07774995700005563, 0.05541334206598902, 0.037817934212545236, 0.049740629526035446, 0.06637555081397295, 0.035915236108966415, 0.062228663253688046, 0.039378669818923365, 0.062099213546682755, 0.04467591883674745, 0.019986136523526044, 0.013537194970394335, 0.03260799240501177, 0.02496571760744818, 0.03922794201982118, 0.039380094742462526, 0.029523473443283193, 0.05502498145365427, 0.06177697015265304, 0.024347367824145386, 0.03166180678583201, 0.03057836502369854, 0.15419609364001982, 0.04485709480040016, 0.02396577176818204, 0.08594101505173792, 0.0336862190236007, 0.030733022853852283, 0.04157111769722354, 0.1038736624703292, 0.03327598277058813, 0.06782829100566526, 0.019955598343644413, 0.04019077281437574, 0.025779195730724645, 0.021976162904813405, 0.01918342576602534, 0.0396854535586411, 0.031110112397601048, 0.02998945025366641, 0.0678934084792291, 0.017063262113820643, 0.03395386716170657, 0.038216016480639096, 0.05791862194816913, 0.053787852877811085, 0.03964161800761377, 0.04988729705913894, 0.03997820256758602, 0.036511302309771704, 0.026050488532130277, 0.022120896065908096, 0.04407580386126234, 0.07745882060619132, 0.03712203909432696, 0.057931779508268645, 0.036497842144942096, 0.09957549552763663, 0.03796243371682302, 0.04448931130971159, 0.05138709420158018, 0.009953271909316462, 0.01763878949737597, 0.043577524953551834, 0.04694093822411472, 0.022977453228386662, 0.011936405414505111, 0.04473116526740693, 0.04139573335827839, 0.08736388547526253, 0.008199129745574489, 0.08050424227070424, 0.008411007640402644, 0.04602803337958552, 0.023062540698916684, 0.08547028466578453, 0.02365521504543722, 0.046168863322706, 0.036781819447154, 0.04761298119481053, 0.02619523318454383, 0.03479773599293924, 0.07715140484393605, 0.02003468926094713, 0.08944467220815921, 0.04523782134656945, 0.05281215563656823, 0.14117040791578833, 0.16490011926620238, 0.12517234701062405, 0.17671455869511252, 0.10403854757427208, 0.08379348673887792, 0.2055674217521183, 0.190463722533276, 0.10412079477382284, 0.08442801438392171, 0.16263717214667028, 0.15862562933996802, 0.2004105928203752, 0.17505625413069803, 0.2170952830103136, 0.13609731239416908, 0.14489845222523137, 0.11729029818407952, 0.1236270021106447, 0.05290536172387581, 0.09024298179053492, 0.16809055371390236, 0.1434853417618621, 0.060254504468532345, 0.16072022097726024, 0.18732058635402113, 0.1552511652510974, 0.2145241387188435, 0.24602293157048766, 0.09492416205185075, 0.1462732736141451, 0.1428687329133672, 0.18273322121991267, 0.20926063970452358, 0.170358786840112, 0.10647702075901533, 0.13864858436488336, 0.16139405659369885, 0.1103907571204247, 0.13956864064018573, 0.14454065852107542, 0.15907391334973997, 0.10834682687756517, 0.20953885219510526, 0.1335396359284078, 0.16692683551340334, 0.13746700099399015, 0.11863082947750246, 0.11227072922572975, 0.149551103372247, 0.12715989318225654, 0.11314505005195258, 0.09162386293492972, 0.11575946298938607, 0.1247393158114245, 0.2342609078773568, 0.17381834797561171, 0.21919989507765542, 0.1690716212314944, 0.13837829322343873, 0.12364092958910812, 0.18952138842113558, 0.15608272304938686, 0.18290850213698803, 0.14068421787552296, 0.19482627150512513, 0.14045523419495554, 0.13092330777116362, 0.14120934050410025, 0.27161518652592936, 0.09092992517135798, 0.16833764771299978, 0.11664582671777857, 0.13634673530055633, 0.1913276552072456, 0.13459665340281304, 0.13288741931319237, 0.11330726150903972, 0.08264233238033711, 0.12663337627365706, 0.12928352721275824, 0.29265576072277566, 0.14735511233729703, 0.16048448040120064, 0.23501266995745324, 0.17369551343783257, 0.18375193429810388, 0.16665150351341695, 0.15451495475586385, 0.24007191460940147, 0.14562470357744925, 0.1428651476218816, 0.15744720225132283, 0.12651877718106394, 0.13708207245555618, 0.09819431560895137, 0.10916270285604462, 0.08555754974123933, 0.18630855356252965, 0.12294235699359449, 0.14412163907001097, 0.0833883411401222, 0.16915509417172403, 0.11420510123453795, 0.13575537671004573, 0.13714841566979885, 0.12252146062711555, 0.112487401873354, 0.09371335242664622, 0.1092899653820261, 0.09652789817341874, 0.3849449940025807, 0.13573971787287345, 0.12051876889722002, 0.23505391613129648, 0.0981978855786785, 0.18593376802821315, 0.16624753002918538, 0.22828988069968842, 0.11382404144012159, 0.1663893175822112, 0.11727767305508738, 0.18393843074239072, 0.11917905731787605, 0.16181129872077898, 0.14425060231118433, 0.13028527910430587, 0.15037809528650778, 0.17173085031249832, 0.1944669456251206, 0.1945971652504898, 0.13400794547652045, 0.1366266485063299, 0.1611336786299944, 0.16981711671237024, 0.10072299564677863, 0.1719912895632367, 0.15371823863637063, 0.16886686125109274, 0.07127537256887845, 0.14532151662053602, 0.15058319234559614, 0.14924224736469408, 0.13371747557915029, 0.14921160384772286, 0.13254969711265258, 0.1961235188308262, 0.1225097471427533, 0.1812649677477537, 0.19906499002489353, 0.12158124091764613, 0.17232884322443318, 0.12181152694768484, 0.16079879095477445, 0.1503275028399883, 0.1316537266416896, 0.0998938280428129, 0.13038293999289313, 0.15767491422593594, 0.06605685057659304, 0.183890734108225, 0.13141699015132843, 0.17403343482123268, 0.09389957307928032, 0.18820831371891886, 0.1402663935216204, 0.22749512576528136, 0.1966841113302977, 0.17377743888045513, 0.10269153517700973, 0.18749281824115785, 0.2399193252166433, 0.1942002550969201, 0.2285870615272753, 0.16369140106103114, 0.21119769302106675], [0.05107327777471754, 0.015263425678225055, 0.027830834733322266, 0.07384841675840079, 0.008169668876836378, 0.04294779684935366, 0.02767949597910047, 0.026602389764100797, 0.06323245293911427, 0.0629449209889337, 0.070796184572241, 0.10297651988484206, 0.016303917678493648, 0.038433045359148134, 0.07607986234248647, 0.021551719551245054, 0.06709097734382076, 0.02537061997328795, 0.032849574401494, 0.006425211500872168, 0.022808718532624266, 0.04143574613056356, 0.098178465249798, 0.05308684795313785, 0.008281887351204793, 0.030816587724632798, 0.04188061338819323, 0.0315617767703389, 0.029086190456103896, 0.01924219811635633, 0.017181371804326773, 0.02613467201890965, 0.04547848403754254, 0.02889508982339213, 0.00906139713591866, 0.05822638628042995, 0.028246521701916095, 0.015387585548113192, 0.019099217381388433, 0.0333165318044203, 0.04339849786652673, 0.03081137832674769, 0.013702196902745675, 0.03641732247366059, 0.10026351909243292, 0.022827485771549326, 0.03498441629832791, 0.032605219166725874, 0.06599528775099786, 0.06715008868805825, 0.048098301725281824, 0.05654019611557165, 0.06090656020528367, 0.0437102994821485, 0.023904092114178405, 0.01461325643298727, 0.004114788955062508, 0.01380093701769628, 0.03274207311351934, 0.014212484238669278, 0.05643861285681206, 0.04387526502532344, 0.041007008854179613, 0.032976024874275735, 0.10290918075629782, 0.026284827167288433, 0.016266469385535005, 0.06452535654628469, 0.03918548925749717, 0.08418426052817414, 0.04289815818229991, 0.05485810452110825, 0.05644798211212601, 0.0553374725484079, 0.04943421733896098, 0.030497753421866128, 0.03690524387263483, 0.031988878449004506, 0.10112491601537313, 0.03671711183062965, 0.038167323932171836, 0.02350611326795432, 0.03644704668512268, 0.07237370516504012, 0.06225854068273499, 0.0368990462213274, 0.03412085900744123, 0.047276806491877765, 0.05212985474856631, 0.039059073258672035, 0.041243086508925886, 0.020635200686933055, 0.05703865888438398, 0.07701898654622417, 0.036638561005313555, 0.03846944602687032, 0.04294915282497964, 0.041882440507892645, 0.04048306983144533, 0.09643245893981188, 0.013041127183955285, 0.03006365736045184, 0.04347985640408532, 0.020993011628067302, 0.05131996191677548, 0.026250533241358016, 0.03463570839695392, 0.06698077559591302, 0.011493344209156932, 0.03046848503271899, 0.004173300356694287, 0.08275143862251313, 0.03614235436543822, 0.028809270738894423, 0.04492338821892777, 0.0779936955340447, 0.033822946565886663, 0.017956227604900638, 0.008667928632348776, 0.04879346905997203, 0.05142357530853441, 0.05107072670192969, 0.004741238202944759, 0.046150048203285665, 0.04467794130886755, 0.04960346531363265, 0.1005548470082783, 0.03999787953592116, 0.06579474891505896, 0.05212135500304642, 0.043128245029478304, 0.06391650050758355, 0.020731074675436945, 0.03377888884936129, 0.07750922919160898, 0.027635231418835542, 0.06200617216827889, 0.010538950915478412, 0.032535022530224056, 0.05543878001551475, 0.07277029356168163, 0.03667891851716465, 0.045358411246730436, 0.002411113072734987, 0.06795268836280993, 0.042196413982779755, 0.04756473297733934, 0.02171478136592815, 0.042049152731534936, 0.055787380664579334, 0.0117347729880543, 0.032720239607677344, 0.032166404003698024, 0.006021327553166738, 0.04223544233208222, 0.01866429394501592, 0.01561705856734226, 0.01629237656391436, 0.03345941869361747, 0.034328840387564515, 0.090898753053719, 0.0561832987342871, 0.0608415806275462, 0.04132210847831542, 0.02544926464437477, 0.0379062679806544, 0.04656935493732172, 0.04886225226425356, 0.02285978212321718, 0.020305926520978252, 0.06596382451994766, 0.02677466570129318, 0.0517716933222067, 0.032648372899500594, 0.00495818185417222, 0.04699933710658262, 0.08246961785780807, 0.030122542708751657, 0.03191491265991523, 0.09099721833462678, 0.007254380062447802, 0.027246696521498026, 0.04292578714328908, 0.019293811375034914, 0.03866590544461243, 0.04949797500645922, 0.049050889924288764, 0.03296079887678066, 0.0168276900771044, 0.058841857488357255, 0.05033136375488774, 0.007970498944257177, 0.05288975651285822, 0.017000506106283397, 0.011021189857274296, 0.01929754796888559, 0.01236196821405282, 0.04013412444281482, 0.038353586719641765, 0.03631615673281974, 0.017120161379176765, 0.04563999452417897, 0.038493765488026604, 0.02731251113507296, 0.04933469868715733, 0.010176282019294318, 0.01037518717273469, 0.12278078138948449, 0.058884444316068006, 0.04383234494936563, 0.011920508132466387, 0.043631108973415635, 0.066625188224979, 0.03148294440771063, 0.042858589741010825, 0.06918887082006663, 0.029675982396809325, 0.008443136410337062, 0.03598080557440558, 0.056273045934616565, 0.01987168681807816, 0.040220546821552905, 0.07077969836011049, 0.0387856871220133, 0.026937311913277355, 0.09234443757562869, 0.03378530100528752, 0.03283104273460565, 0.014279199963165148, 0.02223210521943627, 0.03898516109573745, 0.03965469895892086, 0.0035573278399815243, 0.020497536602159663, 0.011540674078728885, 0.07143557687560398, 0.0398999351948019, 0.04705136596796013, 0.014138532813728578, 0.08089480921626091, 0.03850886125057455, 0.011558050868071375, 0.030853813852093397, 0.033186519022790656, 0.01107857846129205, 0.0772326331465475, 0.03598429510490068, 0.02246990657201217, 0.05559570163548474, 0.06530621464574529, 0.11273927626109893, 0.052682104550542376, 0.0182382284002679, 0.05100663961662401, 0.022112107122196786, 0.0517398547080736, 0.08191543751426282, 0.024540182578587727, 0.08211565459327352, 0.07911272782592044, 0.022455249394800876, 0.04965189739220566, 0.029659206986487396, 0.010935606344813302, 0.023638544972204877, 0.02416162214602434, 0.023294039063095566, 0.03952558250016263, 0.03335303972445188, 0.08780194987212459, 0.02541039142787697, 0.043854948373571526, 0.02891956441735308, 0.005859238670147475, 0.03535162905351289, 0.07638769945310009, 0.0348384803791921, 0.02866304945200682, 0.034897166544631604, 0.024914487392731735, 0.06364790625089119, 0.02314023925141702, 0.07972424218971884, 0.021680320815874204, 0.02859192776433643, 0.04864610821729706, 0.012219304447963595, 0.055200699040846485, 0.026281971574550676, 0.03292612573732773, 0.026942745391880314, 0.014370395069671495, 0.01947332875833156, 0.036135168460708474, 0.027508026349448392, 0.06109295705814035, 0.07458908588535364, 0.03558871028343997, 0.021608277907474868, 0.05786624068634645, 0.06493098478043272, 0.08195349676234108, 0.07602731637176006, 0.020199823343465408, 0.029346758026569605, 0.03195897995253965, 0.02180570259600157, 0.019741917269364483, 0.006317929505565835, 0.028716273410546205, 0.01532717281201434, 0.09967139441399805, 0.014651311850625903, 0.08640783072839822, 0.048235573189994024, 0.03707661391085675, 0.03509935246960771, 0.03304142963081118, 0.006608465478019489, 0.045436303236431656, 0.040774049177285165, 0.0036821963411996206, 0.017962277784282644, 0.005318204395382876, 0.02261663539214961, 0.02946766776843898, 0.012876239207182682, 0.0522148828472822, 0.00503858709107003, 0.016287266757459413, 0.02916238556105283, 0.010995805533903261, 0.034470984171475136, 0.026950017481501547, 0.08627341294120397, 0.050918738688192064, 0.01606319657331633, 0.03882808242774299, 0.054778676525118856, 0.0304675561511108, 0.03396865265864519, 0.08753238651420801, 0.05879505334662334, 0.02176566684107867, 0.031961642108076525, 0.01985718285845172, 0.0193818272166555, 0.05924354803057448, 0.006547800890515529, 0.07581923923064625, 0.024714638035924687, 0.02926666161886627, 0.20685555263152047, 0.1336844418678553, 0.15062206364687414, 0.22768883875781493, 0.09891866706311704, 0.11135409736344892, 0.2792616020287237, 0.12293139427539804, 0.1956991520860503, 0.24144606184094186, 0.15736425025088174, 0.1404523843478772, 0.1116915820767322, 0.15553622656772215, 0.22433089152459176, 0.0937590572322088, 0.24578870784851814, 0.17091018628449212, 0.10160952791451447, 0.20276444393300241, 0.12030539808854943, 0.23651392649739023, 0.21596574765299598, 0.12390069468247315, 0.21073719756978176, 0.14724453520630637, 0.08044424992535384, 0.216319756882806, 0.20211792701194364, 0.16408573715917527, 0.06442635500382993, 0.2352023226839881, 0.20710258534358394, 0.17711623391557127, 0.11018071113334549, 0.1598161912613338, 0.11573867136312109, 0.08839072674633035, 0.13830196022266342, 0.16601614083253569, 0.14856786016495, 0.16220376556438787, 0.09237137322704639, 0.12546966573403728, 0.14454326322001798, 0.170901789960842, 0.1831855808174418, 0.14014558145596137, 0.23538688858670576, 0.19786543423129668, 0.13613748604491835, 0.09509013500064613, 0.11652139871711693, 0.08764406681180963, 0.09498937911684475, 0.11568575000931179, 0.1377309948926972, 0.07255641713498101, 0.0829462624425369, 0.16290265225595044, 0.1232642594784979, 0.1727391752384363, 0.058769163405222286, 0.16560154936967358, 0.14780171095363556, 0.1765541398837682, 0.09189829861204471, 0.1106301289532454, 0.09820740805157731, 0.19467026536022464, 0.13034878779322873, 0.15037069487715923, 0.1302812954470996, 0.2854113575191267, 0.19112859492100057, 0.16656524201314296, 0.09720545697716937, 0.15050684402306236, 0.1115997511172487, 0.10543603750486528, 0.19620469350728298, 0.08641304778716258, 0.21877899105029724, 0.1792926743866936, 0.18456777197218713, 0.1535548627256386, 0.15932531276297185, 0.11710993044318692, 0.12168485430940507, 0.127329497387813, 0.1288406517837317, 0.1746318873859221, 0.1456818230930836, 0.12256850608654561, 0.0786087339022948, 0.15909482755007284, 0.08894176612938605, 0.147258753798181, 0.0746969663868508, 0.17156163681178324, 0.1431892334573692, 0.14656694575903878, 0.12315713740404576, 0.1551793828125923, 0.2601969830932156, 0.10748711534805837, 0.16852111044910648, 0.14682421340577065, 0.09302093151716456, 0.1262859094347204, 0.11850367420383039, 0.1420846878881416, 0.09171370206581009, 0.09209869955215724, 0.1456948159442794, 0.1500207305915894, 0.13213947235095885, 0.0889929254809695, 0.11516484852519729, 0.08711034101584265, 0.15651461277757922, 0.11071190883916233, 0.120486049281974, 0.12067040834095209, 0.22459238797666567, 0.29245863097809977, 0.11826642443455997, 0.16707003266820986, 0.12534519942897943, 0.14628398352332656, 0.16471978216882677, 0.1302735426373059, 0.12612024292109475, 0.1074514692769416, 0.0895270343208986, 0.16325180448832052, 0.14394418246323062, 0.15791243212597986, 0.12763915012680715, 0.1257440860893938, 0.11771659547042464, 0.10453422178304005, 0.12677404533831343, 0.10428605526084862, 0.17177738249301913, 0.17104800550207017, 0.14961298795477038, 0.051966455855196526, 0.13078263870650722, 0.13828700618638148, 0.0657109082526257, 0.15309426002204418, 0.1241343898037749, 0.11816811237123706, 0.12122666478277215, 0.07859955616896191, 0.060237428368700136, 0.11979126116080631, 0.2040615993281526, 0.14157062756919092, 0.14846682848949588, 0.1394117458332931, 0.13421910995196912, 0.09035168966699032, 0.16694442489214484, 0.19994525569340876, 0.11822337795409465, 0.15969148746901946, 0.15815522071094285, 0.14294371759939578, 0.11489264216394195, 0.1469715167918513, 0.13904649043275466, 0.10031331480751116, 0.13463219988249964, 0.14531509680373056], [0.10977800169418897, 0.03546232875857142, 0.033251004473816966, 0.04044826645704527, 0.04569776904498858, 0.10747128797154273, 0.011623564792136032, 0.040927010122686625, 0.026944114774044965, 0.0036549889679712757, 0.022947390023018086, 0.015488807787938465, 0.05508012446244398, 0.036183918465770064, 0.07766373380417786, 0.013518637448038547, 0.04455172449290272, 0.04169159651463551, 0.03582754585471365, 0.02400421214500262, 0.058186557369246605, 0.044449551346441435, 0.07948048067309203, 0.06342317818874313, 0.0089836047376476, 0.05257616225149363, 0.07284211430458293, 0.04263437495777204, 0.08554758293734444, 0.03807956089956626, 0.04542962678017155, 0.03796516482027308, 0.033075976365756606, 0.013370852384175505, 0.054603073851115284, 0.09152561215864075, 0.05948579652355083, 0.03923674820051078, 0.03969498752285877, 0.025255511432225188, 0.12423213496203385, 0.010759768098773015, 0.04157107939282733, 0.0520985332437821, 0.05030229454860092, 0.03757881901917919, 0.01837957162229765, 0.016285058509017673, 0.025991034363546682, 0.023690592985780492, 0.027949622411641385, 0.07627582763351741, 0.045685684007983056, 0.06314951242999205, 0.0357243231677961, 0.02035139000884468, 0.0921359007817603, 0.060715647264113354, 0.03529949677026561, 0.022925238590687517, 0.07541505890267511, 0.026583957688642607, 0.04588812274197417, 0.055574595913170814, 0.06800093658028111, 0.03668044303213397, 0.028415361734768076, 0.02381688449531794, 0.038990355171864076, 0.018142961536444003, 0.023450652332676035, 0.06873524717746243, 0.04071906704695956, 0.05736095973500802, 0.01791656531784083, 0.019701693822900136, 0.0022851627117263214, 0.0180805885728689, 0.03765996305211898, 0.01946222431386911, 0.06934339841527325, 0.10241110103144761, 0.06169466932694759, 0.008321347582574573, 0.03417711667416077, 0.047623798356301365, 0.048372438628106355, 0.07740409894575996, 0.02366130927487487, 0.026334739710775115, 0.01887921991217281, 0.03839834157617823, 0.01175137602859327, 0.049666514349800926, 0.04070322051824581, 0.057290517950370434, 0.014298287043798596, 0.04462416959746231, 0.07591422647237778, 0.09320128393629867, 0.03971682102870076, 0.025482505199409304, 0.07222938952186415, 0.07056970599918597, 0.05314204841852189, 0.013698021723558346, 0.08458778968140965, 0.038738296923017314, 0.044252762510891885, 0.05537826289993621, 0.016732633887459675, 0.06233475877032165, 0.011948614940798331, 0.03909807862533678, 0.0477264273250776, 0.04563632496302167, 0.06757857698586679, 0.042421180349324024, 0.03214056768845166, 0.06778110765040883, 0.015105964923878352, 0.05662115245696999, 0.061952948209739504, 0.017976050129941395, 0.015147939838859585, 0.05834456300362945, 0.05517394725053061, 0.028447368888244517, 0.062054251846406734, 0.010249683776149347, 0.02818281957579236, 0.03871419962735907, 0.052744376007467515, 0.02409213605607229, 0.004205112157750034, 0.047827539439763755, 0.05026829173608173, 0.062165752113346136, 0.029371401159873897, 0.03134831403111739, 0.01681852191987057, 0.07676292931841266, 0.028583916399868268, 0.04376171930362621, 0.023021549249308246, 0.0662359083071351, 0.037215057490093094, 0.051000139360586484, 0.03960446657372579, 0.021672206029536265, 0.048324083158325766, 0.03607791871012699, 0.025776058600674716, 0.023442489665842826, 0.058059042034250115, 0.0807813745773127, 0.03708245916171901, 0.04245524827931677, 0.017740079727504524, 0.0492712474548288, 0.051764266099780805, 0.04476065199161249, 0.0289272636009921, 0.02408609736800915, 0.0351907161154574, 0.05219980240649274, 0.04526812395441436, 0.009789150978078046, 0.030378146029468027, 0.03872259212056956, 0.024263243709180145, 0.045224479925368107, 0.07676227048279778, 0.025978953156980778, 0.03645404106787136, 0.07661742623895407, 0.05429485752697914, 0.07077726220051128, 0.01530521673210446, 0.0706882810881061, 0.10931511604858023, 0.07834131559056622, 0.025129558916594234, 0.05536302158068265, 0.03783302231421394, 0.035763646460949414, 0.07409842189161048, 0.03931925970039541, 0.03963265860933931, 0.03651728928689996, 0.08260703104878626, 0.038703102843775865, 0.022487861757737496, 0.06051446108387844, 0.03316863853063795, 0.01053026156319726, 0.006787380524685667, 0.0385313842355484, 0.056123597502347924, 0.02906618023952169, 0.06992335761747054, 0.04631956047829121, 0.09984770954977121, 0.031956733399701696, 0.12175731856616274, 0.03381072363305477, 0.08796285131886121, 0.05672711773865646, 0.03405518228969267, 0.03723782179276309, 0.06690327048061356, 0.0014731268686685533, 0.005418083587315895, 0.025255884900088274, 0.04212683021661736, 0.04884074434577938, 0.07673350388124105, 0.04925401047653249, 0.025972864673202558, 0.06521567837485383, 0.023088271677073453, 0.01954587728476092, 0.04393202447963338, 0.032923647442892674, 0.027985245500120427, 0.06655971835096998, 0.08342479160355945, 0.03356018989917732, 0.04179735878302206, 0.041476475195057934, 0.036452290556964376, 0.07406697398231876, 0.02965670379419481, 0.009891530968278888, 0.09352973647295468, 0.08348584881112461, 0.048525215712405985, 0.012935277773067357, 0.025210986402066007, 0.07170871786412693, 0.03471898215432321, 0.0715956739300201, 0.00243830225137513, 0.05819300782956904, 0.023608991215305946, 0.03897923923608276, 0.011580318171200494, 0.06015626901400186, 0.00831838473752742, 0.04615049253428175, 0.1270719386276699, 0.01678812546625493, 0.0378823928504942, 0.03363833086745393, 0.1376492226676595, 0.09124985881029599, 0.04231401230959643, 0.08497749860849112, 0.025319818767809102, 0.03417058194416665, 0.04915743743279769, 0.04411897674623517, 0.028847358715269836, 0.031310032617541096, 0.06291389442800034, 0.010932810123889677, 0.06396248493523848, 0.017997923855399414, 0.024855573316134756, 0.041303055871638565, 0.029064849161753253, 0.09165025466392118, 0.045493744508994204, 0.03540842681221905, 0.031726139019273465, 0.058191636532184586, 0.026166296128423947, 0.007836525009254055, 0.06117285236776356, 0.06570121724038355, 0.021360938760241675, 0.08952728712991362, 0.027944378539799686, 0.029091696713059664, 0.01918317870266976, 0.06930411342651614, 0.01935225047711884, 0.039553318713461204, 0.06579736893575999, 0.025526461409284704, 0.018516938848000382, 0.030212720833538525, 0.056086691216595715, 0.07162819436240582, 0.046797924930410045, 0.03552058974521295, 0.034784183897558725, 0.03441602885422688, 0.0559204041717514, 0.054000059232836774, 0.06017722917961017, 0.09043546904238964, 0.055674474626298875, 0.028302375257255572, 0.0277886749996293, 0.0287933916514439, 0.03794138928154304, 0.04153486258620697, 0.022626039121420156, 0.015389122512011279, 0.010580042914126911, 0.020761281522291324, 0.033116805021681135, 0.03848438474139379, 0.04516077588402456, 0.04648615395830524, 0.018874240340664983, 0.014855190829914666, 0.010828788790311064, 0.06499362779000113, 0.03727504217456426, 0.005168195282514658, 0.01412812933971685, 0.07205103659221242, 0.04509524472298161, 0.04785111196519387, 0.04439299490543143, 0.03427420299680483, 0.04195475920794472, 0.036046286939733455, 0.04645354542580824, 0.0768434374983753, 0.04751835784484302, 0.08864043310524956, 0.026259536689688123, 0.01256704037528365, 0.03817168680290061, 0.029177377901731, 0.036211692983464855, 0.04454773317481722, 0.025450959613907243, 0.04326665030431844, 0.05338362658456449, 0.05980790968263342, 0.03927745811280705, 0.0348749729774652, 0.02781431596245497, 0.04813168783702197, 0.04545527923431608, 0.03161942871708063, 0.007008211593323898, 0.020597595345949935, 0.19491588847050745, 0.12482738527919977, 0.127831231352062, 0.09188968012289656, 0.1752592061435984, 0.2746519897012942, 0.1398847131959854, 0.11704166434825429, 0.10720656628930762, 0.16035674290070612, 0.173872878114062, 0.10955153078201318, 0.22904672960360206, 0.17155820473788247, 0.21475879145005058, 0.17780434941091847, 0.10304573592880081, 0.144010326494613, 0.20866290726248296, 0.07599179287471118, 0.11907247150497091, 0.10982320088172152, 0.14070974392516, 0.1003635778362232, 0.1740366217469977, 0.22963479401603823, 0.29508383043350717, 0.0962076734210695, 0.1856391152907764, 0.12095449672591303, 0.22428540122364798, 0.1890813475174289, 0.17622156579407955, 0.11402953686493059, 0.19636356482102027, 0.24559908576550024, 0.15919941387349562, 0.11274713632320205, 0.20756701848679976, 0.1782982462957021, 0.17155091158084332, 0.10638541196502986, 0.1556681928735587, 0.19436710904682838, 0.23023876241378247, 0.07692110349213885, 0.10824266190250074, 0.11992815341199599, 0.11407709560326992, 0.13816093875756189, 0.12986376220660825, 0.09873934120180146, 0.16426877088604436, 0.15975010851698537, 0.09678826847624394, 0.15428647669332643, 0.19127459595760993, 0.09142864841006457, 0.24546820730451616, 0.16898099303005204, 0.3520662163294131, 0.10015779895888222, 0.21665465987978444, 0.1710936183770818, 0.19921198697580447, 0.13376327231526375, 0.08374971247488454, 0.10645933178884369, 0.1312812853364214, 0.13559727148423273, 0.16486121732140743, 0.1261805646842526, 0.06256225240987635, 0.197494019483847, 0.162727463269426, 0.1366326393138978, 0.15537617547858149, 0.1171767179884257, 0.26850330673398515, 0.1361859947322838, 0.16688807146443477, 0.2225667289308002, 0.13678648509085178, 0.1637590466247451, 0.13928463652489648, 0.1360054890955648, 0.1831040230970229, 0.12194625883092805, 0.11383165635408894, 0.08784028491185558, 0.09131961877668097, 0.08981905171587583, 0.07178129703407327, 0.14339178710454895, 0.17224198417557826, 0.24333950943283497, 0.1185943253879105, 0.14622861068815957, 0.15585724805151263, 0.2257647170054336, 0.15420292714430442, 0.09251260919676674, 0.1452043051681211, 0.16281234581143628, 0.20091546008423453, 0.16023675821000533, 0.10983521314037424, 0.11613403401908376, 0.09826393767950997, 0.25179114463108204, 0.11430106906881256, 0.2843067200193482, 0.10833776405742092, 0.1445466186851263, 0.18671039732233172, 0.1007568337503941, 0.08238080528474624, 0.2115071465772006, 0.1818207338933022, 0.18552191916011995, 0.1065746816476026, 0.1138540720867534, 0.11388085452058624, 0.15015710956386982, 0.11549533119485264, 0.10911338977635869, 0.08291450043719623, 0.1872433953347706, 0.11439329073313745, 0.20517426542937758, 0.11332511135767545, 0.12155864132387985, 0.18481638282537463, 0.12753470936009, 0.09520624328645007, 0.11105648752662445, 0.15701048616920749, 0.18585369651836736, 0.07050151651304576, 0.08968534639045116, 0.16158894936163581, 0.09896652457574684, 0.05343433777471224, 0.1024976842886498, 0.19569481602839886, 0.126816026956564, 0.07916700515535571, 0.19167250202548122, 0.08784611484095936, 0.10536684444354427, 0.07446697147022333, 0.12410842708402103, 0.10089478320291928, 0.192835392851022, 0.1395649634181492, 0.23129487590443706, 0.12038309472582995, 0.17748637695706662, 0.11497384748391568, 0.14465437661255562, 0.13936518300925532, 0.10124503094102107, 0.10195112651995114, 0.1382279867726949, 0.1484232687301213, 0.18083217403581067, 0.1264725590965921, 0.12947187758982182, 0.15414900987619354, 0.14069645996055297, 0.1283866527580446, 0.09458576569393759, 0.0846884000085054, 0.2379926140870779, 0.07263713981956244, 0.17973816983642119], [0.011661816519805262, 0.04099236125306737, 0.051549014545256094, 0.05377268816734995, 0.021293034641853264, 0.0792855189572419, 0.061018573751132336, 0.016668981557051023, 0.05146333910224419, 0.03673038047347819, 0.057050759243147994, 0.033727361775574186, 0.02780107413268378, 0.10404059302902992, 0.036653852120282195, 0.009531922593352296, 0.05470607054209518, 0.06515080604942576, 0.019177592006481944, 0.05251580984481881, 0.05103796112140821, 0.018827407470633908, 0.05131510108889592, 0.02885846124451247, 0.10929017222576565, 0.030674930406554096, 0.026145560043533484, 0.061869394830277855, 0.00540326361642069, 0.04734889153511294, 0.015829859598119174, 0.07214754068803403, 0.03409184725774873, 0.03674286387620434, 0.017474699209654526, 0.05750148324295879, 0.04114973486491269, 0.05233835706847811, 0.05049424553890863, 0.05105428262463501, 0.05705435602595249, 0.010139539484835921, 0.01585013124220554, 0.04928294178699294, 0.09489804611451204, 0.02572905527608049, 0.053422654933866956, 0.06014815997332335, 0.0647860332842796, 0.05974109149387768, 0.05429870711879865, 0.009887675630799946, 0.034759113670236645, 0.08910580087573299, 0.02454546858526526, 0.011065953332299908, 0.042792936005899986, 0.03004953836000735, 0.0766454573961035, 0.02354358837399031, 0.07280078386106799, 0.04189072957923336, 0.01795142614883521, 0.05434820022914679, 0.05552514876809813, 0.05370423821131549, 0.01782446814280364, 0.030563648474673112, 0.028353327765099468, 0.06214673781106549, 0.024845146859485297, 0.05134100635205546, 0.031191696931097298, 0.017710361261701873, 0.06693723115829692, 0.013336120830518345, 0.026414627359519084, 0.03478776152816511, 0.1291704832786514, 0.022026527440175418, 0.023663812467167457, 0.029507506255721374, 0.04143288479216638, 0.07590245936186084, 0.047700525892357674, 0.02819286873413911, 0.03205315705629126, 0.06617202423512936, 0.019658480718311284, 0.014016716215278835, 0.043384631675097256, 0.07976669878248246, 0.019929032329650178, 0.021214420614283414, 0.007322884602246867, 0.023375319076641914, 0.0713427500018189, 0.019614557067172664, 0.037693077202646, 0.009621416027056835, 0.003992416942867661, 0.04958878323856381, 0.023315688707835736, 0.09452827079522033, 0.06943368953802893, 0.060871986657260894, 0.06486285658132646, 0.01762488117111066, 0.07124321219781715, 0.040237243707862594, 0.019827288192426486, 0.04911175177943322, 0.031566842526738206, 0.04400043613127163, 0.031646264777068174, 0.0770784273082691, 0.059788531488588745, 0.039118096502798225, 0.10812453880545594, 0.04899717183903821, 0.03648187687260009, 0.015675584811927573, 0.014448498691161795, 0.07600244915773792, 0.02002947220218278, 0.01998792916926886, 0.13531571885030116, 0.01841986210145537, 0.00876182898683774, 0.04520238594963186, 0.05027867988833497, 0.038755112552955266, 0.06983827589259994, 0.03423993205351215, 0.07437674163450157, 0.005551051074308494, 0.023668579449276292, 0.06952110783106859, 0.030524244742287748, 0.0661767203541052, 0.07779391512515084, 0.049782392809227596, 0.01014008149204235, 0.050777008591760556, 0.044599693088281545, 0.07442420844228999, 0.011217570751004163, 0.02216687666312341, 0.04179152885391828, 0.0453917820367121, 0.039733169345004905, 0.042281507198969205, 0.04625118330060955, 0.04629372416304485, 0.019229578733023618, 0.012127075122759469, 0.03660604057292785, 0.042585996505353725, 0.01403715927153826, 0.020852511102754264, 0.03101942673956435, 0.02366857561883667, 0.06659685063265985, 0.042873880855979464, 0.041613980316587036, 0.07425353937451878, 0.03850438346665713, 0.09426298220792124, 0.04742821993967218, 0.06832549739028178, 0.01377359533967871, 0.06052646185121229, 0.04465299365561336, 0.01417418463050478, 0.12509899409187417, 0.018055853509013692, 0.04296842376671491, 0.037377709447736704, 0.03128639688985723, 0.024144668620260015, 0.008467541098774923, 0.083673341169713, 0.05502037343478972, 0.016503159910620704, 0.035985578302173846, 0.03711270814340922, 0.02671490318232006, 0.04620288145698367, 0.03648663810904949, 0.014784530710218655, 0.03730604192242026, 0.014886171425572567, 0.05617953724257889, 0.026579654189727964, 0.03356498944002294, 0.01362375237212907, 0.08209163007596809, 0.038731639618955316, 0.01603012264240533, 0.027562857177408955, 0.09008771109004175, 0.01003806156316592, 0.017964560726297, 0.07797288858602125, 0.08839225126129967, 0.022475121715556712, 0.03264988592315105, 0.11947066102537418, 0.041545832965282664, 0.014652786569880142, 0.031842821871020624, 0.02626583393242571, 0.010431329926265585, 0.035721706977534684, 0.02993675298057497, 0.07794153260728044, 0.004114611318425066, 0.022325464524328712, 0.031033484452974894, 0.03650296344271591, 0.017279927100565647, 0.10794741161648305, 0.04239981032667622, 0.04365055228493387, 0.024102639121514176, 0.05621797953461928, 0.014591221829065153, 0.046428199406833424, 0.036301692992809324, 0.0898123178030214, 0.018797217860757824, 0.028124704145856445, 0.013393242261372508, 0.0406011316414562, 0.019592939981169278, 0.03734390581807783, 0.01838975484603115, 0.05494638466306272, 0.05339465058979489, 0.07271479049156751, 0.016537578325838815, 0.04210290529074208, 0.05582259006557926, 0.031045916144766157, 0.025208552157686605, 0.04279836756928314, 0.03613909083088079, 0.016296266375349897, 0.03597976752526818, 0.024515579664899458, 0.017109158441364285, 0.037535784030032736, 0.04376882476912391, 0.029229121395356716, 0.0817751744762063, 0.04016865585600177, 0.03437695453964895, 0.027341350514982498, 0.03870898639903434, 0.06109399127683813, 0.04216844028222465, 0.06352061308139274, 0.03491005980439725, 0.05630902142354077, 0.1168829539129811, 0.051008734867096915, 0.024992965439695026, 0.04707601484692386, 0.024732386377910455, 0.05875910467077648, 0.015762250423581613, 0.05046306959083004, 0.07049884286619003, 0.01088624729985191, 0.03426434727565896, 0.015041048548394635, 0.05466773550236418, 0.04461809835066238, 0.05725673347290966, 0.03948240195431056, 0.0463455461806828, 0.03407395527427716, 0.04603667102093178, 0.03551528075589769, 0.03917187204464309, 0.005499821817201953, 0.019242410705755317, 0.045543685780778054, 0.03169445553794503, 0.029112132108439843, 0.028774612921199975, 0.055304477141509135, 0.006760892555898717, 0.06829091618137975, 0.032995671199093905, 0.14079231288163893, 0.026520454745379188, 0.047176793713362954, 0.026570616267441262, 0.07001630706532348, 0.04625225582370355, 0.02217680133218246, 0.029381699296796036, 0.044254915217959115, 0.03529195080421144, 0.027790301021248586, 0.026808044152154077, 0.054209124627372915, 0.02874144322929844, 0.06704141911599906, 0.05999739003938533, 0.07010199399965425, 0.0376252630995887, 0.03300781752313337, 0.04339808800948724, 0.07734382314787758, 0.03209219306647297, 0.03632421980822279, 0.04442469179329853, 0.13960781837663344, 0.027524841979386348, 0.01632621658274964, 0.0130939269213066, 0.09358605159626854, 0.11887739487593213, 0.032645883113746686, 0.038299960564942136, 0.05284033618086288, 0.02684717017766689, 0.053657962670249325, 0.04341609490614745, 0.026471139750473445, 0.02729404650087799, 0.08585552730026745, 0.01774678491206179, 0.00707397545357385, 0.016040078912591262, 0.013381756688167733, 0.07170091908905776, 0.0663386023933849, 0.026936961428051995, 0.05185996580328192, 0.060959661589755174, 0.056372396047076875, 0.03211960177718392, 0.03452243463646981, 0.0734470020078363, 0.009917231302918687, 0.007074078875443628, 0.05511916047262569, 0.04990352663181482, 0.005095182315281202, 0.08408681414420567, 0.1608822792167625, 0.13511983016806264, 0.10183081241144289, 0.10388547554612161, 0.1276827711732157, 0.10110567188671521, 0.06921412873893015, 0.06962485145777464, 0.08897103834897281, 0.18165178086248138, 0.16929945578017544, 0.09633732614137473, 0.13198662248830642, 0.11825991268720358, 0.120739187714794, 0.11419814515618548, 0.15692528187026902, 0.1076082491706456, 0.11362537185871795, 0.14531639915320183, 0.1466408119566979, 0.12484705075621606, 0.09640920817130998, 0.2918155461309418, 0.13988103597394883, 0.1026581337435111, 0.15510260548082092, 0.18381679130177345, 0.13846161294608347, 0.15628045034264365, 0.20395541954184734, 0.1867822870131462, 0.15845607876056628, 0.12201703769425232, 0.11464882702116044, 0.22441824086971823, 0.10129942318364497, 0.1041463821104938, 0.1400048970695465, 0.12073473674395394, 0.11374963132003624, 0.18430627552011322, 0.10196347585729054, 0.13847986116043984, 0.13516628573979103, 0.11441237398333128, 0.19608997950150123, 0.12581880264464887, 0.1691696038770099, 0.20362040929255948, 0.13266788915761057, 0.16683429209215028, 0.25278952573576285, 0.10528354770353726, 0.09938756649893138, 0.10030581480673245, 0.15655077212760526, 0.1874401726790013, 0.12037742567519027, 0.1939797596705537, 0.1153590364922439, 0.20582419910257865, 0.12562429292067406, 0.19063033133504853, 0.19827640975915617, 0.1377956220699895, 0.14882043935358524, 0.16745796427130702, 0.18810463137924674, 0.09969979329335113, 0.16250440910939248, 0.10822719458730952, 0.13631808361218822, 0.14792578655385202, 0.06745270107902827, 0.08140314685841722, 0.14303538768041518, 0.23613800715294578, 0.2050746739992211, 0.1522092446083984, 0.1089415256114256, 0.08796606888814319, 0.19880337099875175, 0.1854732266116527, 0.15759876508626247, 0.12095341654193979, 0.12747808780160644, 0.1332079811442283, 0.12224681810626101, 0.13341255726352816, 0.09937065893844252, 0.13481583115794968, 0.16052157437849432, 0.12051961925481597, 0.08536483266300733, 0.21772117684445075, 0.1264437465297599, 0.13803461085884802, 0.05624926273500728, 0.1512144794387202, 0.1069985427743485, 0.10150586089660084, 0.15102029147167362, 0.24948604735395602, 0.15613300906073663, 0.1253335778751681, 0.0865329099037955, 0.09991155531738075, 0.2037228046045188, 0.08217158667262524, 0.1329978279048397, 0.10012247464469365, 0.1153707423157269, 0.08130091242492199, 0.11651213671411238, 0.09585213967629018, 0.1556818139168524, 0.15628798864781857, 0.24342995377317553, 0.12219366692607442, 0.10922680143266918, 0.1343289209950355, 0.289658181249134, 0.10413146637860807, 0.11308317313030844, 0.30829789717831924, 0.09181746101427464, 0.12852606543850514, 0.0906327443437711, 0.14845938211487186, 0.1310536346488422, 0.15511546043619034, 0.17640199482200608, 0.17644811331504778, 0.13983534649014473, 0.11747504028701976, 0.1567013850135188, 0.11365446021720288, 0.19359521417608186, 0.21737887343812376, 0.12557501814538433, 0.15104079198452736, 0.33858702187576606, 0.1392740798332999, 0.1504442852831656, 0.09705522713521797, 0.0819837112700747, 0.1705731229195672, 0.11886437138121937, 0.08259082828918773, 0.08744305300135767, 0.08737229712067113, 0.14472405997014817, 0.22747045773411953, 0.14407458594970166, 0.13928232293936516, 0.15797016451195364, 0.09744248458094175, 0.16947064578773516, 0.12743838912537023, 0.08370052196926649, 0.16453526223138457, 0.12980733217010576, 0.15795363233454768, 0.18693011133901535, 0.20635699793215723, 0.1397605303434595, 0.10705441356666627, 0.20129468892851185, 0.11136319848798937, 0.34363410105147674, 0.10368096071385569, 0.10131493646411166, 0.16488735624138387, 0.15465081278835574]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.047367970954867146, 0.05780444037349475, 0.013207662249765089, 0.10760415826112994, 0.03611086432131068, 0.0663041667411885, 0.037127861362551494, 0.02551344366023137, 0.038080759827167764, 0.02017762403063957, 0.052657896172135114, 0.015286153591718647, 0.06526060177073364, 0.07033312272640967, 0.027748723514378074, 0.09481616663716494, 0.12541564121361704, 0.03537944570604352, 0.011601398038046976, 0.009963983733717714, 0.034798873633506804, 0.08314449535382372, 0.04379444274931185, 0.03764530012924825, 0.023116369866916252, 0.039186998450708006, 0.03279323629554241, 0.02960019714889988, 0.08544916362171212, 0.016254725257655787, 0.05727009021586949, 0.050926966472498836, 0.06584354105495638, 0.024054433038878827, 0.042447024325449625, 0.01677312354947771, 0.002920530659462055, 0.01760212835975953, 0.041362481311925, 0.052021629507503206, 0.054098693053087885, 0.02655727676145973, 0.02045447863037548, 0.030536391066327214, 0.04739004577840528, 0.01281734811322343, 0.012938421606386622, 0.009403833650022505, 0.0334170080661293, 0.019272776515853983, 0.03528871025229174, 0.03314997662880248, 0.07526462987786339, 0.07431488003461592, 0.037866711030684175, 0.012244190814183846, 0.04229336240959745, 0.026022882553778832, 0.018002844055093104, 0.07074374585382401, 0.03724800310127678, 0.03692753703123139, 0.06193635091485997, 0.06397779520240522, 0.028603352050507264, 0.053500734615109624, 0.021759478765870297, 0.06823798716669122, 0.035458513640708504, 0.03886537941833658, 0.04169155437979968, 0.01900546928687442, 0.052065104997206124, 0.033983840351744045, 0.0485302297578704, 0.028287551455920743, 0.026120166144063397, 0.04441182534661024, 0.029120034305378798, 0.027417244930421154, 0.0403095853905524, 0.08522997820569624, 0.04736448525481167, 0.04960178375063885, 0.05774336401373149, 0.06335867358551872, 0.02841043004375552, 0.05330472718924285, 0.02656664793199349, 0.06915933813058561, 0.07908998267544855, 0.025985227417080634, 0.08014087910733877, 0.037690759786675056, 0.023968228995199167, 0.04735662902314817, 0.03320875855523252, 0.0008726884604379115, 0.08418053734086214, 0.09010002978386418, 0.02372230328018627, 0.02298051183442435, 0.00466001708240759, 0.02247831247176134, 0.053472328074877305, 0.012691542111907997, 0.04471090607224934, 0.012362729513927573, 0.02798501375852333, 0.024793108422008735, 0.03456617059606699, 0.03285966760989639, 0.05654688789359024, 0.02398945729158098, 0.02458244190371085, 0.037609202066256155, 0.006083329921708473, 0.05788431653091985, 0.11419567069219005, 0.020237457412745685, 0.019120099022984505, 0.047090348351987145, 0.022419411801703037, 0.04633820322792857, 0.029802105367003433, 0.04267777383868252, 0.02593558108914764, 0.03242531873946709, 0.10706857087150698, 0.035993377077243024, 0.006875110998554456, 0.053100495809508916, 0.05161214402065643, 0.07231826338195994, 0.05726639001119522, 0.061414476499081626, 0.053156002710062655, 0.014530119613834448, 0.04109859849596697, 0.10086557227036647, 0.04103360742691063, 0.04965239917979606, 0.007267000403390417, 0.06952337545132445, 0.04700759170396675, 0.01878431119445351, 0.048309002717536305, 0.04014656954114476, 0.05595342256128789, 0.1402171034245722, 0.04942174159711407, 0.014580826973542573, 0.04854619503021241, 0.03526839360053982, 0.07355909599291702, 0.019460429752906485, 0.01739834131102168, 0.04671413406369187, 0.08061208446780521, 0.0233830297515998, 0.05906363611199683, 0.05382868919461485, 0.13463413042406883, 0.06880056383388658, 0.061625131526060646, 0.0604803778321272, 0.0385660688663202, 0.049252880496844176, 0.034344671594519774, 0.01709748134617844, 0.032453514605520234, 0.061975482686032216, 0.04325615106931618, 0.03920660264069035, 0.030559584378234805, 0.06705373014894224, 0.05465047554143014, 0.07013573251183956, 0.01601308388935943, 0.01708341597188865, 0.04297373275603018, 0.06185727148887612, 0.05012504095512052, 0.027571083046495918, 0.015962145745664114, 0.018028825927045078, 0.029258209753841646, 0.11200082112824726, 0.034381830689287, 0.040892390609388395, 0.05704970970269173, 0.02549978431254145, 0.03761246560081359, 0.04308162474884622, 0.04235083432567697, 0.0499452401192919, 0.05601422695983803, 0.04301540793911104, 0.03422982735379088, 0.026195353843391906, 0.013263800215246457, 0.06963491019222044, 0.05769488980032264, 0.022363544839824882, 0.05357578058817214, 0.014178424927165673, 0.04843705814451941, 0.054241759972947265, 0.011290586591067334, 0.06833944785138292, 0.036531772179108475, 0.03646420322418694, 0.021227888439992265, 0.05914980951215952, 0.047978600487113006, 0.00994662992701295, 0.02456687499708947, 0.024164650108545058, 0.0269201209002565, 0.06791824504973427, 0.01550177669888663, 0.07733084561844027, 0.017859206399730137, 0.024889170102054076, 0.06484066301416005, 0.11741456530627706, 0.0332642194905108, 0.04864730331445894, 0.04337921543347259, 0.06165540349038859, 0.08601293538606937, 0.043856917219536926, 0.031936079669263095, 0.0806471789556165, 0.05890321347021288, 0.046890288321000916, 0.03656758678956859, 0.018964759374578154, 0.11392900314662727, 0.02110263497959222, 0.04653067898846442, 0.04173492644763282, 0.03634565494834416, 0.031562968037061157, 0.04873590138290198, 0.008143490694853808, 0.033764291043964126, 0.08797025172820977, 0.058175889594901, 0.011582096452794729, 0.049206654751493085, 0.02017391424986624, 0.03949824465258468, 0.031222304058892113, 0.032812476593760714, 0.04653019635307212, 0.05974118342442859, 0.02160052126724153, 0.003187058872783617, 0.042296308017666304, 0.030324799496860757, 0.03520010069252984, 0.01595885539802933, 0.06534606653956637, 0.015955631125478015, 0.06959814563273423, 0.05048561172800199, 0.07761644319661203, 0.0692763657218987, 0.017732905314093637, 0.056538434113345803, 0.029412224070138993, 0.03132162927349489, 0.012900787537106344, 0.04534012472797786, 0.01674362533395329, 0.0029018922190692637, 0.05152447291860177, 0.04495681646550375, 0.022005521309291644, 0.03533651413876684, 0.05362290265639463, 0.026829057943917094, 0.025594449797344786, 0.018779707006028584, 0.049075477516218546, 0.031002777733749924, 0.04211128246219408, 0.0639465771194908, 0.0722398849264268, 0.021170060293027954, 0.05066263166466548, 0.016925280102558674, 0.025467641178458452, 0.15422597106906677, 0.02834943795366393, 0.010685024730440591, 0.07069267843279146, 0.02851773980974911, 0.05370113172478253, 0.031135123253108996, 0.03158619390770553, 0.03832688472504097, 0.044283528601930994, 0.05529046156293443, 0.041089413101754846, 0.045687614549552245, 0.022419499901814327, 0.02542817041337971, 0.03732206082091697, 0.03679551326880052, 0.027587586495604728, 0.024457268882542852, 0.002430838879175304, 0.09176665406313636, 0.033327950344931696, 0.03291421690054479, 0.014492960519067224, 0.02437410046226315, 0.013748129619465721, 0.023060439702784343, 0.03856072923348796, 0.032589238572625384, 0.018852690287354975, 0.02838567965814183, 0.11659053815228325, 0.012471739995113064, 0.04150584700607485, 0.03522781392319068, 0.02421575966441343, 0.010056130704469979, 0.06640243283923596, 0.018091560867164406, 0.06391040244770628, 0.08995603589761643, 0.018560646079300393, 0.024766760743072918, 0.06825710872128125, 0.08063831531833257, 0.016048548014594183, 0.030341726209547733, 0.03261180752287469, 0.018685997215910785, 0.03952329189726903, 0.08863739173619017, 0.029761581231028806, 0.06750704735637673, 0.043841051538625074, 0.07367052348150362, 0.03866084926431218, 0.06465247351556055, 0.075010595122172, 0.14545424901429685, 0.16651898562427492, 0.15154503105628878, 0.22614158629890413, 0.20582660461866087, 0.16037690633487317, 0.11636425110120928, 0.10218808517581034, 0.08559849714079211, 0.1199667948868967, 0.12334286009952908, 0.19255028556912177, 0.12775891265200992, 0.11199356627560432, 0.15629397945538645, 0.21697396532662455, 0.18686966700178964, 0.1756398752331734, 0.07198447887335094, 0.10109538332589212, 0.13555294563693387, 0.1811709381159275, 0.09095786439795649, 0.10314407863564069, 0.05770717018974885, 0.171870140418891, 0.17560126440178964, 0.11668058412690317, 0.14988023006627638, 0.1349158669191022, 0.1889659133889983, 0.17143016080221823, 0.1964509141661467, 0.17285931314672195, 0.16439710593511983, 0.10335750307046598, 0.09247749938719696, 0.13948080099878774, 0.11191642888250852, 0.1476051327922652, 0.08422596635477198, 0.14564927967806018, 0.1474961950894325, 0.15296990863017498, 0.11300385238662844, 0.16172497593347104, 0.08548671725176035, 0.19687643004280908, 0.13597159736579464, 0.19528430015329393, 0.1161222669085668, 0.1175295091384361, 0.26365433789549336, 0.15866263138671077, 0.15659105303066392, 0.19966934146659993, 0.15262651737899552, 0.16156694731645047, 0.0990096323432461, 0.14732949435710907, 0.2801605602425914, 0.13304532535614508, 0.1994224619721213, 0.10643824138828825, 0.15555231441413203, 0.19948741090634178, 0.19623063324439913, 0.1615747920567951, 0.15145798814633202, 0.10799025891408806, 0.1678834035391769, 0.1707529390771543, 0.17317555424186493, 0.12463421620909246, 0.17334527336061004, 0.0923840826257102, 0.15642226853918645, 0.12130888133880594, 0.16355094650099355, 0.17674005410123259, 0.14156721081704865, 0.20069266639409528, 0.14418962171241162, 0.12562692060225433, 0.23120308324934977, 0.15470157377421856, 0.0983653677206847, 0.16287125797281343, 0.07052202468677875, 0.17168909852062503, 0.13354299139351616, 0.13807867623625264, 0.2352245698773092, 0.10140690531942154, 0.12992639755529742, 0.09408542600971076, 0.12187382521768733, 0.09501498943615345, 0.2360183135756562, 0.18009954883206278, 0.10476080760840448, 0.14121192988128434, 0.15368181881645035, 0.09820799027839977, 0.18721607663939077, 0.23224801185630986, 0.12847772529048304, 0.145693636168876, 0.09552373310490962, 0.0952285670885636, 0.11101808353898027, 0.11539784650648795, 0.1909682067531732, 0.10591389250851448, 0.09063864322078806, 0.08001645110667714, 0.08555096904596976, 0.07439328913366602, 0.3364857652735326, 0.15015258964511657, 0.10135518672365336, 0.24709251288685108, 0.1570957670769384, 0.16875026266901724, 0.08999408748481544, 0.09259001472063604, 0.17372427237851007, 0.08261306016075035, 0.15537738589750183, 0.14738065370869252, 0.12893276619574717, 0.11901417987481241, 0.15329947965520044, 0.20604299381375316, 0.2338018220278525, 0.1899324712013045, 0.18302975853364314, 0.08572837202659539, 0.19608912148302604, 0.11896147302562192, 0.1710238124454214, 0.11137084404547369, 0.08947693217065066, 0.08822551988545926, 0.18649477421516375, 0.13821975898838815, 0.10421093267899367, 0.12496057732571518, 0.1548271662285251, 0.19686784985805714, 0.10210602183736141, 0.14371460123408225, 0.09344593411491764, 0.14934038322779442, 0.16273175336180196, 0.1410489523362729, 0.10555527909027954, 0.1399015058432856, 0.14958723207875607, 0.13187409949398812, 0.1890457550724668, 0.16647018582349823, 0.1645360742845843, 0.20786291228667383, 0.23707551491116327, 0.11114198293897415, 0.09357320430177836, 0.11443629124832731, 0.16676044121624964, 0.1443438198898108, 0.16757584988109528, 0.14996681332347855, 0.12125050543897575, 0.2194426530191014, 0.19581372819600568, 0.1638993939324733], [0.0011590346501531802, 0.03577294293791056, 0.07135651660181823, 0.011464681987079882, 0.06299460945170253, 0.04032279657680662, 0.06559719016114551, 0.030157577824748816, 0.04722859274836318, 0.050934332407890796, 0.02951716279400693, 0.045575903608433666, 0.07385639939457178, 0.02083133834774696, 0.01609314965354579, 0.10592787361313259, 0.052283482190461895, 0.058441940439684745, 0.03459390680936556, 0.02566714196525995, 0.12466249251437765, 0.02805812919001666, 0.018625265595713453, 0.06268658464954746, 0.1150846008151289, 0.015951421472334092, 0.05980060886471503, 0.07318310003968016, 0.1332204377338771, 0.057528568281521725, 0.0390488115109263, 0.07962155576434829, 0.03490916731196546, 0.034934003882470636, 0.011709092763222514, 0.058452137069956916, 0.06263788827064057, 0.07524677236834842, 0.038711652385010835, 0.02385551639411959, 0.010008383316979294, 0.03096152772946704, 0.053858723671686266, 0.04628025250689638, 0.019665693436118386, 0.02176075238704441, 0.05859519249849743, 0.04173895990055415, 0.028085792624962427, 0.021629872010840524, 0.025274870474071755, 0.02074031369580377, 0.03175528674957252, 0.03854151191790739, 0.02093209040110871, 0.004412708578691368, 0.028344427738639138, 0.023579630895607898, 0.05475902253942144, 0.03904818331882839, 0.06704787723720074, 0.05207117241356642, 0.07640662182482981, 0.05248824217086358, 0.06402679035560259, 0.053526038499248606, 0.0685386383725751, 0.039508391487141775, 0.028442902595645962, 0.02339368411940673, 0.05773131728112217, 0.019897069226229386, 0.01812964884353982, 0.015212615854257058, 0.015117737780054732, 0.07622314376696464, 0.06452459811923966, 0.057958707498807105, 0.06108634188891419, 0.102854413130591, 0.006270960654928199, 0.0438520985264932, 0.10533013351021275, 0.036053407726989645, 0.08841057608444845, 0.04691757637286379, 0.03755795844500104, 0.05771649731022697, 0.055717590054677385, 0.09612850589497436, 0.04211686724316209, 0.07105610288319088, 0.09286760667999906, 0.009780458752967177, 0.013057054151901075, 0.0545181185307522, 0.06578293583926655, 0.0336078099245506, 0.05841396673912964, 0.02055901132764355, 0.04449231820481439, 0.05171431333667809, 0.10564751607636291, 0.021166599490830017, 0.0416579116286049, 0.06305225373756501, 0.025813920581112468, 0.008824245042858586, 0.04973120281412717, 0.05153080080485633, 0.08178287365984532, 0.04686982611254339, 0.04414298594178211, 0.021809171059078748, 0.0037634217709813633, 0.030779786775970173, 0.050774365588421785, 0.04164928930901712, 0.04522659432803912, 0.044385720900590384, 0.03509050032364265, 0.030312973014529676, 0.04478106057391532, 0.07966027384804142, 0.03438303344732812, 0.03156515521808498, 0.06531002976360821, 0.051703584275298545, 0.09059507580053422, 0.034860145345690756, 0.025432822482299902, 0.010068976083740352, 0.03275884277818184, 0.06910267826770583, 0.030216624051512733, 0.016019361022289003, 0.00563829603995527, 0.012564387795845828, 0.07066662378248668, 0.014477552575690132, 0.03232107715561025, 0.015798983381940954, 0.03641221649764526, 0.04436478754805942, 0.07352233909431004, 0.052885378320370956, 0.04877038300037385, 0.06787958059219584, 0.04363942102739408, 0.015968019724823534, 0.021856528699337956, 0.01570982415409338, 0.04292494061613276, 0.01671293202126699, 0.003527806881221853, 0.07261649375000308, 0.010723261136351334, 0.05661411593938547, 0.008053439932184355, 0.037336792691700885, 0.04785658566341285, 0.008502216153447668, 0.07796256938168118, 0.014785024836929816, 0.040422146689266934, 0.03270319032092248, 0.024160668366558613, 0.03720139048152393, 0.08078746497631073, 0.047378159924260074, 0.0490107354257376, 0.04640026784111415, 0.055126189329330964, 0.05723372019166428, 0.024213419265804753, 0.006117793344592135, 0.017291313082340266, 0.030664333495341485, 0.020948980724619284, 0.011722029115433895, 0.03512150390193828, 0.0532730762666512, 0.04696506616328994, 0.036771481090615836, 0.028459000018154903, 0.02780013950541616, 0.01413129041001441, 0.07579334545880556, 0.06401326507329941, 0.017710644714233857, 0.05663049489920659, 0.056982324608872016, 0.0614988227795449, 0.06958035707113243, 0.03680716546612882, 0.08975979481493274, 0.10343883096450761, 0.04747461422436661, 0.04953721019950125, 0.03181289656147842, 0.030030104624588164, 0.0385280019573627, 0.05858823642014496, 0.043315879114332705, 0.12457823050358605, 0.022196037799961144, 0.09466794394557515, 0.03264580650495426, 0.029751486107406598, 0.025689674526332848, 0.037923987594343005, 0.027055256894879767, 0.06433568849799133, 0.009316264054617815, 0.054522117509716944, 0.014697374802293077, 0.024487402951044422, 0.06606198336568571, 0.040369397705240596, 0.04942320482504945, 0.02292240981102711, 0.02324416290878529, 0.048894653953011, 0.043807749696556604, 0.014620528522608502, 0.015540261125762858, 0.09523243583258122, 0.019953121964429176, 0.0518748164176941, 0.044964389244635264, 0.013263074346938202, 0.020628068408358003, 0.06379868001526882, 0.06874077833227574, 0.006267680841002373, 0.04595453490413005, 0.043722782884874654, 0.030214057656966394, 0.04960391730550797, 0.022986113852370652, 0.023276273484131502, 0.06682051000215354, 0.017867466742773692, 0.018392882399982022, 0.029546994257778413, 0.06517927387669202, 0.05511085224908687, 0.029793481132195845, 0.01821634509871083, 0.021661446324639747, 0.01789777509627804, 0.0884354969246253, 0.024691040612637036, 0.015122921322472395, 0.049605621851139495, 0.04893625252729943, 0.1183280332254306, 0.03647069964978484, 0.04276642936371988, 0.0336759457845361, 0.06986800776494127, 0.028261985186667695, 0.034108444552628264, 0.044970847365836945, 0.06989036987145102, 0.04473879167269315, 0.11802627885293578, 0.033445805311203, 0.011155327064766279, 0.04298995083738719, 0.09281587276247241, 0.04923491573501979, 0.10035311307517752, 0.09514744603826154, 0.019652922750420628, 0.02018234696269276, 0.014726144276679525, 0.011102504344777235, 0.051841372849359635, 0.032299435171749324, 0.016263240324934165, 0.0805879220546734, 0.01775490735927897, 0.022414215810356602, 0.009301856813591816, 0.05056068834458148, 0.10216993655288413, 0.02009183750487864, 0.029239555512885415, 0.03486889023934642, 0.04062430580116568, 0.012231274571780477, 0.028543112641801278, 0.07835243918722676, 0.06412144817952668, 0.1149735487096252, 0.028028941240101576, 0.05213261266509372, 0.019280416327678872, 0.024136618951395638, 0.027592276868921135, 0.02985072130667827, 0.04139926502360933, 0.009818976696190095, 0.07374875638033114, 0.021111130894672488, 0.02332666100213124, 0.1288736395297512, 0.013419640693633307, 0.027101333253085617, 0.02360116371193961, 0.01572932300698613, 0.05032088367208358, 0.10559300125967111, 0.04393174485754102, 0.05780056779903751, 0.033269133944545067, 0.023895624927395297, 0.028035870505376693, 0.05885596116704326, 0.04723895025709945, 0.04321927925752055, 0.06495600521203972, 0.02120776905588085, 0.01483111268645453, 0.04342718785929103, 0.051389986183494336, 0.07669013564384754, 0.05073944730083308, 0.014217718534411923, 0.0316839620486022, 0.0745272625898642, 0.04088883213098011, 0.0767358940755648, 0.008720632608709557, 0.04830395802855492, 0.050571926854430675, 0.08358344841267794, 0.05027756906084476, 0.01801443113494785, 0.05313829075725329, 0.04805062424331423, 0.043041650280957265, 0.0694801068053611, 0.0331099447043192, 0.04764128814361269, 0.04609120115938206, 0.021299268682337096, 0.033313103560959144, 0.04779167120314894, 0.042999063453246514, 0.043462922030519095, 0.13103207693465296, 0.14249007097415387, 0.15648743197802575, 0.14158285433246245, 0.20598366796489687, 0.20157705361564315, 0.1827950445154021, 0.20062940285330821, 0.18975195024282704, 0.1210519431098815, 0.15005362640705802, 0.12384134585097914, 0.11667039515751025, 0.16824493575240337, 0.1498621044259879, 0.1875078948515077, 0.11464308902260759, 0.12838522783450543, 0.10957017736209017, 0.12199103667010223, 0.19868796751383813, 0.09166333178478865, 0.12465725247297557, 0.21804604408962114, 0.17538738797508902, 0.10459729380184606, 0.11912386068293165, 0.2223171681285866, 0.2824732571119263, 0.10993121161816582, 0.17380425195780494, 0.1428621445572184, 0.11917392452878338, 0.12117514536986429, 0.11500285923360817, 0.11491976167646148, 0.10294510261906732, 0.14185447846689533, 0.11603621225203238, 0.10206633082200443, 0.10950960278991731, 0.2081036017907243, 0.09871471913591509, 0.11491930202370691, 0.17868666819507079, 0.10609195432475499, 0.18444840015182573, 0.13532465143549827, 0.08178124955344586, 0.06871220325270007, 0.1085072993150642, 0.10930426824357241, 0.10523910694304975, 0.13359821101109828, 0.08303351985711245, 0.10340562871386928, 0.1963858886231338, 0.15173978592839935, 0.15135989824850715, 0.11171044316142799, 0.1920899893006971, 0.07469680550838671, 0.1521787236654951, 0.17319168805355029, 0.1904837633933752, 0.2005882026447404, 0.21996104939570352, 0.1221909243313055, 0.13252392591487977, 0.13085161726320946, 0.2277167396800172, 0.13800519308255565, 0.12188002286899476, 0.13679989162952672, 0.09126730263233186, 0.21496552793729692, 0.11916606446668027, 0.1336951824205537, 0.127541902925699, 0.14508177706551167, 0.19910049053930468, 0.2496906081514974, 0.14596236449095512, 0.11532811718361995, 0.25823068053972337, 0.10492802161963717, 0.12916116764949215, 0.13879780297077474, 0.19585882013122882, 0.2446439733067828, 0.16123305555553208, 0.16812833717032788, 0.16262975641556326, 0.14764097038536303, 0.21036282572294437, 0.09902539843272778, 0.2612169219120856, 0.12285291622843474, 0.16246230491707403, 0.11690889365009724, 0.13846922786005084, 0.1501286264148451, 0.3132989497915391, 0.10596535063438839, 0.13104347632296626, 0.1610051597198171, 0.06834347747386464, 0.1258967674127029, 0.13302493209560073, 0.18739989177594263, 0.10650042474510209, 0.14223680230638674, 0.1678934546127435, 0.10232722972549739, 0.1448079312760984, 0.08594670708501533, 0.1032163513704173, 0.17579992632231406, 0.13214261331144841, 0.21678276510248262, 0.0891611966935377, 0.16574873018168634, 0.07729274040508656, 0.1491807917914083, 0.1293003964688509, 0.12511176477757194, 0.09095445530669344, 0.11514379642903806, 0.1358419752890064, 0.2035806952945648, 0.16834492554828046, 0.17469686696365958, 0.13805989176034927, 0.20554574146386118, 0.08216947993083347, 0.10210120314431768, 0.12171739006354926, 0.1856969242855426, 0.10686866788854522, 0.14989602679927505, 0.20218060832590828, 0.09576084497835367, 0.13279150510507245, 0.2787365560089388, 0.2183317489201023, 0.10569600178109062, 0.20417200791979992, 0.12240856224971434, 0.11755072211305942, 0.1337596257367442, 0.13541347166943934, 0.19568865668148766, 0.1121713906045883, 0.10266747235530808, 0.15417787606918043, 0.18474861468759277, 0.12503230613806557, 0.1465506434080101, 0.06001476108306839, 0.056626327380898504, 0.089389797330143, 0.11604171276332871, 0.12661178791595082, 0.10725344320939434, 0.1200727295250662, 0.14445393736804688, 0.11790342133251891, 0.1601000728025552, 0.28860597480689326, 0.12263207606250241, 0.15078986754580853, 0.13139964592072273, 0.13758488660377843, 0.12267840139928365, 0.14267730286284802, 0.10686029454753285], [0.02155883459284181, 0.019002157871821718, 0.040596856870838714, 0.01884230021988192, 0.048242965938463334, 0.027860989869241754, 0.035770089260392615, 0.04206786059864587, 0.02553854453107042, 0.06125804134494355, 0.0428663348899253, 0.028595511140602253, 0.051172876865753246, 0.09188601822261849, 0.05408731664741232, 0.03608056554390538, 0.03061827245889412, 0.014327779513663583, 0.037871851480656096, 0.08487311146792867, 0.03305525368740482, 0.025655593189801422, 0.0300410999015214, 0.05335079588656945, 0.008502137629435429, 0.05272818473918785, 0.08072306762539572, 0.06499848478744108, 0.01890328656431408, 0.07068383011726603, 0.10445495466551474, 0.011484249787885818, 0.02375228796154261, 0.03860271085173853, 0.017501148395240307, 0.047643678337936445, 0.029058105672799775, 0.01757878374548689, 0.03834085816877984, 0.10237602186539482, 0.011383739052220218, 0.02031441669039909, 0.06192993492849412, 0.05603852343835658, 0.026973005864889394, 0.01966522037682514, 0.05859344581803007, 0.013079121314559974, 0.08310089729005292, 0.04316716229603176, 0.04186635649192237, 0.015110340243535898, 0.05933966142155471, 0.030159617533847213, 0.023098952857957735, 0.049984685986513094, 0.04027641761387068, 0.03855537427889724, 0.04114973486491269, 0.05980085018241118, 0.03554120900169496, 0.01851314479755538, 0.023430837468514522, 0.023363651557555123, 0.02770356454646155, 0.07280464494420637, 0.10846984527644613, 0.040002859107428984, 0.04271693242293212, 0.019597569067451744, 0.04696199032027395, 0.029180423101230018, 0.054569660926297794, 0.04173620198402674, 0.01176415820560989, 0.01764891909495477, 0.07002848786331954, 0.06665598495953506, 0.09988750015655834, 0.022792222744394696, 0.07230795949937836, 0.04970910883839092, 0.021872001760188612, 0.02371014738004775, 0.0329298987203548, 0.03411610926231069, 0.09377501484367157, 0.018759172019218246, 0.03192328217048799, 0.05645393844573729, 0.01983355670686691, 0.03959915758441052, 0.026372322069120505, 0.0612460597298078, 0.040051153290175626, 0.08303123691509809, 0.017855707293135986, 0.0480238073355248, 0.06473940151232867, 0.052962753200723287, 0.02472841229680325, 0.01433822033446162, 0.07063459364637252, 0.03053498337976635, 0.05367709571615823, 0.0771816959604621, 0.0324388325304514, 0.023291982117018873, 0.041330340093061815, 0.06553398024651312, 0.012733136855756805, 0.017382594373738094, 0.05987837828034836, 0.033302485582328616, 0.03304569674054942, 0.0341709649881288, 0.035829162300233884, 0.01361936747637247, 0.02072642260651675, 0.015910109223407364, 0.035263000341552886, 0.018411678367204243, 0.04302065947183198, 0.035193497014622536, 0.05346275963670304, 0.08547891847669117, 0.011792583898040316, 0.002468191889948362, 0.03175768651999533, 0.01476375632093198, 0.01839560392733303, 0.029311148344629237, 0.010011438092577362, 0.03181213621921357, 0.01912609557621181, 0.023115023467389327, 0.08389043516569561, 0.012633289743755615, 0.0032359079904704085, 0.054778297311596336, 0.03421696473754222, 0.022297151829867114, 0.02846950882925622, 0.1136669397894894, 0.05649117031885732, 0.08793015468625293, 0.011828793043781434, 0.07224237471218072, 0.042300425740259315, 0.04513891556510522, 0.09025723868680578, 0.07901937235146761, 0.052989301977739225, 0.05527800880372525, 0.0368923352911107, 0.03484383916422244, 0.08865423034876586, 0.05258365459139309, 0.02790827664636797, 0.03786331343073999, 0.055628022885010134, 0.03467678220101422, 0.031426286460050655, 0.05211232665685877, 0.018518528480443264, 0.06413416523906974, 0.045097048860043294, 0.02294276093673562, 0.006866193256310879, 0.04094143938874045, 0.02438702245032595, 0.06783027517338915, 0.018476793925548275, 0.053316662839103135, 0.04127406710458379, 0.020476706671498476, 0.04573619984571011, 0.031157841590503534, 0.062473527936925816, 0.0663971621543169, 0.01907037417103927, 0.01882027710727867, 0.026144008715486815, 0.05282359715971736, 0.07871220173734812, 0.02379285231713326, 0.03337748559011567, 0.05231680318472847, 0.0847814490477885, 0.02527335936564111, 0.0022431696021568874, 0.028012799767536983, 0.06194169437813182, 0.0229383367789729, 0.003276647588673739, 0.0356427118212225, 0.08331240650506751, 0.012892546346260896, 0.03447749974927114, 0.025576534831235488, 0.05537154813927989, 0.022932012723157966, 0.03139946189138197, 0.05503718140384844, 0.04476015786490133, 0.0005472130132763977, 0.023791452291451638, 0.05252961857965397, 0.05769991533710592, 0.025197156599812934, 0.08530202111409557, 0.03630198793666017, 0.041631780369507695, 0.03808541764174739, 0.01500997793740563, 0.04594386329934482, 0.06323959287856856, 0.031097064005030744, 0.006641708427078783, 0.05258550469373023, 0.053406417700311834, 0.07337604694428944, 0.05701730801393429, 0.004370428664955281, 0.061145376624359246, 0.0508941013005472, 0.01489744536698826, 0.0547506032331336, 0.09109346196055414, 0.07215560759387671, 0.05272986630218164, 0.03314932545406684, 0.02696631217165099, 0.013465583944062312, 0.02873930775920951, 0.07253476749024085, 0.05780172076136355, 0.030535433456421863, 0.06865439425793386, 0.06636966725871449, 0.01125955715730426, 0.04325030581845392, 0.01597322816509874, 0.025485301420332927, 0.046065916427441185, 0.021883889529553634, 0.08761655659444871, 0.038597700636713736, 0.052225688517454176, 0.015515769294823612, 0.040982869423685536, 0.06451810169364176, 0.05499766658871405, 0.009330246116845839, 0.03861312198662951, 0.03915257045939084, 0.0806078939668594, 0.06170120788738132, 0.0764101994554362, 0.04849920319693704, 0.038811121241099415, 0.04418093793755097, 0.052470246765522234, 0.023122006358819145, 0.008480198786503846, 0.095939374108228, 0.050357215391892585, 0.029377275139033317, 0.021702363080675566, 0.09730274248267375, 0.13565466679151983, 0.06431353323522114, 0.012464375017331013, 0.03189006459809119, 0.022971757364669637, 0.005579665415890275, 0.03606411380573146, 0.01923794058271714, 0.03321409435762513, 0.05744953865125295, 0.09562386845749232, 0.01992451432611673, 0.013038364479378348, 0.08294744987881954, 0.019137717130023147, 0.08650958252650115, 0.026927429379054138, 0.024508162018572612, 0.011524470361520447, 0.045719119915438276, 0.04726753299755435, 0.026261040137239525, 0.01658157092489062, 0.020150761157574675, 0.03093205632701997, 0.03453568412712024, 0.023811416542758385, 0.06465772887872112, 0.030220161462503097, 0.046594988239268144, 0.010967288868531827, 0.02383630865463807, 0.013407557571847594, 0.025860921990486885, 0.06077603797518438, 0.010512613770251554, 0.028355892244425994, 0.022905289661139253, 0.029655880249676206, 0.04249638337041101, 0.034357894272092855, 0.059003659088404915, 0.10271323078702535, 0.03371598536989862, 0.04090929816987726, 0.05398556101886977, 0.03353649863011895, 0.027854483867544803, 0.10857723548167175, 0.009083413545252576, 0.07915877737104893, 0.01567899581841043, 0.0721236770491927, 0.06093965137317296, 0.03972715938523893, 0.10708996004635289, 0.04131338656729749, 0.03318666840993589, 0.04323692226241674, 0.024437724064374645, 0.017271892753459753, 0.07292956324113954, 0.044550583021895546, 0.030111087779063853, 0.03629731096988244, 0.05962225210462367, 0.04914337588894752, 0.05914671068650581, 0.015058172528722115, 0.037028771719985434, 0.051499057951713764, 0.0033537804331224895, 0.01632149365069645, 0.02959489007480443, 0.0310973781010797, 0.0682312379320783, 0.024175137852228457, 0.04730126767930004, 0.039527926729210926, 0.011582405760794157, 0.04268045514641751, 0.04669045428595236, 0.08804741976482254, 0.10719134412225216, 0.1379720214754343, 0.17243536008942514, 0.13099343545975226, 0.058680519371503786, 0.1870506016477462, 0.16390953693659077, 0.17704913993516277, 0.1945782275570016, 0.11315410521121756, 0.12485873359706133, 0.1683155843807805, 0.17994196454603828, 0.25889702381626256, 0.16725456792741053, 0.14198646009449037, 0.1504898521929018, 0.12793051634704874, 0.13574682716881076, 0.13882651594617676, 0.1435035286891845, 0.18309818550703988, 0.14770556691913836, 0.20894360187793934, 0.12745127472425663, 0.08056007475862581, 0.18204113738911767, 0.11699982828670934, 0.14556004575663997, 0.16292955726385117, 0.11630229757077272, 0.12845098116104642, 0.14677939726220024, 0.16758533404959788, 0.12667767147743894, 0.15841374474187053, 0.16833533412746846, 0.13137851721577107, 0.21663206028601817, 0.17235343464680258, 0.11425167171945495, 0.10855955417237936, 0.08985610738877328, 0.09713876136248151, 0.2206278829685142, 0.2404900147549568, 0.12506127958336186, 0.22156041115522387, 0.12983258242809004, 0.12717871596255612, 0.15281431617275362, 0.15949570603909033, 0.14142739977086746, 0.08934143419948318, 0.2481907458915826, 0.13804504497637674, 0.0830631674597821, 0.13645219496421276, 0.21479128889979857, 0.11601493032949588, 0.128220924957385, 0.12566334808305388, 0.1609847204939973, 0.09515021927654745, 0.1482923136603448, 0.12734572313004924, 0.06574578057493895, 0.10838710011974459, 0.14203879922147722, 0.17265698932591947, 0.07405792648393301, 0.17780447198498636, 0.2297027460149219, 0.152956594022051, 0.12211943300621164, 0.207751507780725, 0.1543033306276606, 0.17841139748211832, 0.11956318146398953, 0.15694642589697916, 0.11156008308452946, 0.13571756261010326, 0.19768935658278006, 0.17167377676213944, 0.10027295729566006, 0.14879908082225632, 0.15046057231243581, 0.09592860291201262, 0.25936954684795877, 0.07459102408780206, 0.10055812586459423, 0.07433433100701341, 0.17835651494322285, 0.19726088360673, 0.13575366067309536, 0.12995213810955325, 0.10751909951889708, 0.09679214488114081, 0.17023757640873233, 0.09566041085148051, 0.10812485290150489, 0.17584786810461553, 0.16625145239935768, 0.2940295708756293, 0.19099347233291597, 0.12958725043121846, 0.17797681112443248, 0.1402978950570668, 0.222090513355309, 0.1295785783159156, 0.08897882946316274, 0.09541402165327342, 0.23876251712922128, 0.11411335454472613, 0.1641308444161569, 0.11520568867244067, 0.07179177711687743, 0.11555486388744847, 0.08920617371557221, 0.14543986188307886, 0.11794346474832106, 0.09652020665065897, 0.2403346521239127, 0.12771862408807202, 0.14736268128598892, 0.09129371734396105, 0.12322814609374731, 0.17567487012955452, 0.09277957551662, 0.12221130227009136, 0.07030198891316691, 0.1440222621444733, 0.08711315255852477, 0.08518171466646657, 0.13632484050768037, 0.26795837307168596, 0.11587092112148963, 0.1374248968016717, 0.2936510008669669, 0.15928615034828264, 0.1334248606355921, 0.21465222861978317, 0.12102866169786262, 0.1933646676761489, 0.21373937357096903, 0.09515394246385944, 0.15881649248542326, 0.1435936206290799, 0.17731713281283457, 0.141445969742152, 0.1528513795065303, 0.08666486854875281, 0.11876203735629398, 0.09778680279850961, 0.22795073357560944, 0.1267675259300778, 0.18884477956641108, 0.16512971581710925, 0.10191367248133307, 0.08133281998696827, 0.16422626832800527, 0.10014001805815967, 0.1539250517324094, 0.09643949928783602, 0.1333742681890726, 0.13552758812664017, 0.17030206569019826, 0.0904884210397159, 0.11004944196752003, 0.07504749757748458, 0.11179918678657663, 0.12336082486135345, 0.1455543920277588, 0.1396145752721256, 0.20266186475994127], [0.017142171085241343, 0.04479101971693097, 0.06562213398396008, 0.02556419506999514, 0.02517506070885687, 0.01955658910916217, 0.03177317298738466, 0.01762780954220122, 0.019218033788004713, 0.08074982707659084, 0.030189935463450612, 0.04169557634140215, 0.03593154229043472, 0.0237982647283183, 0.05011614667431963, 0.018078935738172264, 0.08618687564927725, 0.026972253183503787, 0.02090412627665266, 0.04047991737963692, 0.010953593131665502, 0.0357861234806478, 0.07008876366120192, 0.017037730318524184, 0.011312920926889826, 0.047051235733013, 0.004401191883164669, 0.07457640713020679, 0.07149690987482187, 0.028461520447425788, 0.011667420452971373, 0.013153214465766666, 0.03575384436595825, 0.038259652848806114, 0.0874667174573387, 0.02015169770006211, 0.05821727749501025, 0.009488092787984398, 0.055314761871892604, 0.022909282894444563, 0.020474950414932063, 0.029502082353217468, 0.029865897508458267, 0.0190002043476148, 0.024456537268575163, 0.040817524666988084, 0.028270484932187586, 0.013546127555591446, 0.020689474185928702, 0.07623264325722572, 0.040276386970353704, 0.060411142635970354, 0.04043933004140854, 0.09548643994475565, 0.054318043178007494, 0.02621801472419212, 0.07192024240090002, 0.06629323466650902, 0.05400288992771699, 0.04460077327225478, 0.05613948233545788, 0.07162463971443715, 0.04329024581238628, 0.02812807684794309, 0.040591896451529, 0.036504916966922825, 0.052444004423676006, 0.07119555386804766, 0.03163208448958974, 0.05939407664681635, 0.04563644370664993, 0.0759693005332543, 0.02464704609836542, 0.07664808507768378, 0.019154921549582676, 0.015426326614444055, 0.017325030527107658, 0.04441250716486285, 0.01799408767011858, 0.012446365247841084, 0.041748106990370064, 0.025078368921493812, 0.06412426355264841, 0.05929378424620917, 0.07372312307838472, 0.028121362087286772, 0.03263904194858286, 0.032056006903369585, 0.010469461952696645, 0.05193804548452458, 0.033923637332214464, 0.0655099940336039, 0.05282132953946149, 0.05748123553912005, 0.04632531762904218, 0.10372311853232885, 0.07610725764665874, 0.03176174678599402, 0.033409366339084604, 0.024476346387077245, 0.008763613971701313, 0.00837203195964497, 0.015540027468945953, 0.007274667985902559, 0.00912733432356148, 0.04070698584039365, 0.05943484018526732, 0.07526649913239865, 0.010836399873838791, 0.04816132777881238, 0.03153417653764688, 0.007745356237020104, 0.06104861205864338, 0.017098630478064862, 0.0323928366114776, 0.05990081699565054, 0.06479086729908182, 0.02970633671558913, 0.04088610102753005, 0.07234365153577059, 0.025777046854097038, 0.07042183570804135, 0.03770236984916753, 0.05653954494083601, 0.01982237948405166, 0.061545098320611065, 0.03031557962869204, 0.05920710139757684, 0.061116211657081886, 0.08157791449658333, 0.014890114863162801, 0.03214737821009851, 0.05565778923130805, 0.010333466024378376, 0.005777329985698265, 0.036676390427014524, 0.02175648527730617, 0.023535699583590034, 0.0348333437596598, 0.030281006080669262, 0.01802823220890376, 0.06942023703407857, 0.051323708086725206, 0.03841631399888185, 0.03986893544694589, 0.03020572262035022, 0.03648627038684584, 0.04953851254897253, 0.023338449180066105, 0.031274608711922364, 0.008783517893584026, 0.06363740701588892, 0.031091678406923052, 0.015303237352430102, 0.03631123461790624, 0.02891878492289013, 0.029670843862057216, 0.03936044458720473, 0.06883214197812543, 0.041533368714754625, 0.05433635650983742, 0.03156750519279271, 0.04402803061830421, 0.05573762325389732, 0.017950401506236485, 0.021385817465582685, 0.03524409712202126, 0.04351673587676018, 0.028455723077058796, 0.045011430873625705, 0.05471983331165487, 0.07596265089007155, 0.012260505614141303, 0.01740656718010864, 0.015630985088195774, 0.06947638361804909, 0.021055677620273446, 0.014428359197242367, 0.0503785164666272, 0.022471082516975945, 0.04235805087392369, 0.04062295748641895, 0.019205236289229606, 0.05952901920423873, 0.008524446109790475, 0.0476476964690993, 0.0647110409373718, 0.09147439152002336, 0.02447616827163485, 0.07337103672926465, 0.025491056655864083, 0.05439811085741367, 0.033611222846253265, 0.03307696461917893, 0.008992029789594874, 0.05329250808685057, 0.012790009308035576, 0.054873131335743015, 0.07014165437149425, 0.06997381216816365, 0.01553396675585499, 0.005128781974030238, 0.058607534174957586, 0.04724868723461705, 0.04131259366629585, 0.04073610101195593, 0.033075064721126715, 0.011666038621877952, 0.046398885052410827, 0.05287115206761707, 0.00895718140752926, 0.0459396191722443, 0.007788426178928105, 0.0713105513263614, 0.05089032065664088, 0.011070258746434365, 0.04336664010019552, 0.04331424734705398, 0.0017021336515749535, 0.011435284320595525, 0.04046241610100673, 0.046281183303724376, 0.03631654743766112, 0.04180461363566499, 0.019937011135381558, 0.059214524789563114, 0.01275266539455662, 0.013432377862984375, 0.03707906539221445, 0.04755509176081227, 0.02812652360467661, 0.025283429591405778, 0.07681932105051895, 0.013140477296415598, 0.03446914556045686, 0.10071235468551036, 0.04188191956810413, 0.046288330904057914, 0.05541733721451414, 0.0645216716633689, 0.02698167798019225, 0.026414813135840723, 0.07075241796912686, 0.02555253329656778, 0.01856505874574425, 0.06889326047272452, 0.012604389076812134, 0.05185456105297612, 0.07641311825042771, 0.0041052502027953105, 0.04278680347206612, 0.0370527119676192, 0.016277340173180548, 0.06035463599067542, 0.06503200879500759, 0.07651345278587073, 0.01781147146116822, 0.023086607351057956, 0.07696179042179739, 0.014038577491808084, 0.03307558566091522, 0.03200877183717826, 0.03500575567745874, 0.031195456507585706, 0.028530621578195886, 0.014971048221923413, 0.02518739472443779, 0.044724174715097875, 0.03296892323921765, 0.02853926304998177, 0.0371689543188099, 0.04624944045058182, 0.08626848699585085, 0.05519712524067971, 0.023984117658748746, 0.05102407577778063, 0.01460118671774023, 0.024395976102940982, 0.04778520542106802, 0.005843139332418721, 0.01873872321729939, 0.039996891282498837, 0.07010030860622084, 0.04959050310595382, 0.03879324457938633, 0.03923497087652645, 0.039154569948873216, 0.0057715546403590955, 0.06051053105282688, 0.010263100848533213, 0.019686395047052253, 0.0470901606604457, 0.03568218067108143, 0.05318655812692258, 0.033216940374263836, 0.016223172011274486, 0.03511784583209984, 0.051735162419537385, 0.019098824761327238, 0.07358201734361149, 0.0531888525602558, 0.05415608452993536, 0.013332122809163505, 0.05761732339798924, 0.029371676951526638, 0.03027351182554999, 0.027005011103146022, 0.010727252454436835, 0.05652667849414772, 0.03873026066069161, 0.02206778127489792, 0.08007069779259544, 0.036247848503051266, 0.010766948257843334, 0.05096529768179021, 0.044140856217352614, 0.08231558821975224, 0.06255893524916423, 0.06683239968673838, 0.023016966128301238, 0.025377704371367733, 0.022642289761513956, 0.056628541374999675, 0.022641284271113338, 0.021273367249617176, 0.06937380444498793, 0.07237535225407732, 0.058274136540750344, 0.0546923843813279, 0.0316305733811591, 0.17474384347517646, 0.045594772354008696, 0.039496337093653223, 0.0956965242362311, 0.011684544433298851, 0.009559099562466145, 0.01874647794231292, 0.03141678122413014, 0.0033095446011547243, 0.04209283889541703, 0.015764558263453507, 0.0825286832367701, 0.03240264253690839, 0.03176249946737963, 0.03602636099282292, 0.039063416977202704, 0.031643522182299245, 0.028709656326100234, 0.030097953201602065, 0.03378276142381853, 0.011645513211166667, 0.06203332232431539, 0.13822525949968448, 0.1331217349657128, 0.20177559296209968, 0.1230170275835741, 0.19990621585278742, 0.1097796870876224, 0.10180967604561199, 0.12238581709924246, 0.1519397655201535, 0.13565676587243236, 0.19557614900892784, 0.2579559920535934, 0.12170217555737305, 0.1593981830463294, 0.0721769048381717, 0.10057702525368623, 0.24024930992914786, 0.18392692410176803, 0.06522287960134207, 0.17399056454098996, 0.12573927505722932, 0.24403096507153205, 0.17885715340174016, 0.2210984907803997, 0.09157147018178817, 0.1997091780386625, 0.1064733665196165, 0.13348308331783743, 0.18487264432253378, 0.11197865820459782, 0.19433104162735326, 0.1576766609064033, 0.14280595966885168, 0.18463802223484363, 0.12686226036279433, 0.2129834746160815, 0.17515760756308035, 0.1953344942340928, 0.15659699787295636, 0.10701061632003515, 0.1158341718837619, 0.1930591977772213, 0.13906449349897523, 0.10512477598123013, 0.10307844022228833, 0.11355231005337932, 0.2685968307477813, 0.13645096922353392, 0.1420568942182487, 0.2252666372805834, 0.12234378185483719, 0.11823079368520169, 0.1324062548097103, 0.1584513443371942, 0.18581672511514158, 0.07095901656054682, 0.17739571811210725, 0.08552982501925961, 0.12396462471975435, 0.20587243199829133, 0.11507929182581364, 0.2041367831970415, 0.19450661365783986, 0.22504012040313215, 0.18500448805430245, 0.2728184042198043, 0.1259943976577732, 0.17324612626144964, 0.13121183180520612, 0.2820762397060471, 0.1449433449775942, 0.16977459883257268, 0.15222809037133572, 0.17992215351231639, 0.07988043985660039, 0.15636029202611218, 0.07368536260459693, 0.1919582834647548, 0.16343050215753818, 0.19695074057146428, 0.19900610850703335, 0.12301935649086392, 0.14059893696779205, 0.13712478951821405, 0.25523965877871363, 0.1887501830295209, 0.07329736971446583, 0.14628105706745578, 0.11150893139382524, 0.12637999269270128, 0.11305686567098865, 0.15285409145778225, 0.1279935577223378, 0.15804809097561145, 0.10195259740876575, 0.20331713040509533, 0.20041313623228382, 0.2121773815803951, 0.16352526723377167, 0.12957874685525894, 0.12020893229712402, 0.11609288743667065, 0.13790535650426342, 0.0386965221485063, 0.14488196601310085, 0.1998066091008725, 0.1918918483199612, 0.19353604154481044, 0.11149987623456026, 0.08431941375977571, 0.22159537540808802, 0.09201041557976315, 0.17139280635503032, 0.06802707550025756, 0.06240288313898829, 0.14478589858739607, 0.13178265923934598, 0.1023477072557134, 0.10119698190641019, 0.12997810849018637, 0.1298534966284229, 0.16553103863712282, 0.06296927492404658, 0.12791557763252528, 0.14354056137944424, 0.16243353065463806, 0.07971049857235725, 0.12618665508325064, 0.12507729848185856, 0.1261472015551502, 0.19679663432461603, 0.18591357395052913, 0.12868921152285992, 0.09486388625396837, 0.13778701124172058, 0.13650638802397635, 0.11723118683984203, 0.10230053156133621, 0.13088497273143263, 0.1314675825978479, 0.1844567351884419, 0.25078165525149915, 0.13134461016424243, 0.08146468670137468, 0.17727640757877983, 0.09020204205186137, 0.18950756819498157, 0.11795881715032364, 0.1392839776892816, 0.1330623325080641, 0.20941574186567338, 0.1172939830669953, 0.1186242334604744, 0.15366403025484857, 0.19677357507809518, 0.10801818281892808, 0.09801586308786947, 0.1948544022537047, 0.1600918756617654, 0.12574185677353414, 0.12852817984117618, 0.12957027392281642, 0.12146790587012807, 0.23096466136555519, 0.15235700764723364, 0.15989102272977754, 0.0799544822544821, 0.1806541045586909, 0.16618949120804188, 0.15071661421848884, 0.2906892743081816, 0.19037341608876185, 0.06453622733393023, 0.11380197810790232, 0.13621763416355656, 0.12381673144597201], [0.035517820337366675, 0.06233156035323778, 0.05262736756835253, 0.038823976196468844, 0.019582111328359575, 0.08406751638939304, 0.037210047275068305, 0.016953362970642986, 0.04097354996408667, 0.04774967426313989, 0.050576013933506705, 0.033350009846711354, 0.046941413198627775, 0.034584219627563036, 0.04867057706559858, 0.0140125400784816, 0.04232652635583955, 0.047645597388186765, 0.0447846535262802, 0.06844050250947475, 0.02242901279861408, 0.016608267173831983, 0.03150204106444313, 0.08936856903376118, 0.05323781706993619, 0.020882344481745557, 0.05494776362132642, 0.04467696837720372, 0.003806471842483828, 0.03113417713452251, 0.02245496594226889, 0.031472096602702816, 0.08812691670872512, 0.048554541558147445, 0.02682742043097894, 0.030658110946176514, 0.05557432012151807, 0.009227621936119132, 0.036087460335223906, 0.040015380814551346, 0.03908345017642264, 0.03901220016902493, 0.0425927036051308, 0.008150454434085517, 0.05973495129916457, 0.08241619088596876, 0.047471848646959955, 0.028326665990114696, 0.014616617643755051, 0.04645237714172371, 0.012173480898772758, 0.044552662950609966, 0.03911882811676591, 0.07883247754146015, 0.051406277043204156, 0.06438667931023144, 0.04076566434495392, 0.06327331989943501, 0.04198452938468226, 0.03356961278064597, 0.0756456283852458, 0.03192896462766634, 0.03593442278103002, 0.05502143063612523, 0.04549102489686301, 0.021811183955099796, 0.05827946851270334, 0.03170848260783861, 0.037069060283923344, 0.07964747251882669, 0.0479697943064234, 0.05185499772309296, 0.03885286920253308, 0.03844917150995424, 0.051776128971288284, 0.03491385960050168, 0.07693170614901089, 0.014909960370841286, 0.03921163583835287, 0.04169966725091781, 0.04488195052310344, 0.04243633739890591, 0.00859974967991753, 0.04026066301570785, 0.020367343789867817, 0.025263260411579284, 0.08105134396182914, 0.02451042580838886, 0.014972048924274504, 0.03728851383071273, 0.054762833826844735, 0.03178671933710575, 0.008861768029389844, 0.01776047298804887, 0.0127870426325488, 0.07022646030471211, 0.012817470687291315, 0.017848739723464655, 0.0368508477995713, 0.022694828071361108, 0.06965161090896976, 0.029047227224274993, 0.030994287564329086, 0.02537906034699371, 0.05621622136283306, 0.05472038872539998, 0.034886943101282084, 0.034062165181122483, 0.028618085836510987, 0.014728386999077856, 0.05737590994085035, 0.05603482323368231, 0.03080266024616938, 0.037289207140284206, 0.04305977592124574, 0.015213566760893072, 0.031015787821924014, 0.01529057487665165, 0.053977202999615864, 0.03612666871518858, 0.05169703039310632, 0.0096172216956714, 0.05066121823244518, 0.060685946035289, 0.018536506648806315, 0.029120855934677586, 0.06257742861165635, 0.06228112495474278, 0.040073377500859, 0.038762432523071766, 0.05232421125495627, 0.03462220609728848, 0.03788915740686559, 0.025864938206429926, 0.01958323747760827, 0.053129618641950434, 0.04027552512143889, 0.09874688716785562, 0.03437040065745673, 0.05979777816983481, 0.05711460884119715, 0.058954713730922634, 0.04989467831628938, 0.028525933120099288, 0.06117866314466923, 0.02957673570621879, 0.02956436338624166, 0.03658168280737535, 0.02261822119415287, 0.03227188281955258, 0.054603345812328404, 0.057956060665028716, 0.04114042306619306, 0.03505846252664924, 0.0285662753101919, 0.025392104909124396, 0.02787263249047101, 0.0743691037378965, 0.0374170825366051, 0.028068117061329466, 0.03744334020020981, 0.05972888388280427, 0.029704716439629276, 0.06931528298845215, 0.012002138631238092, 0.012394060594810834, 0.09834255362229963, 0.04438740246358418, 0.03626317792241612, 0.06513070390229264, 0.03352352493112126, 0.017307504350619934, 0.00910751658657025, 0.11955041077829177, 0.02637045281458526, 0.01611526469669996, 0.010036049624754777, 0.06412672269488535, 0.026085554291644407, 0.023049542102061456, 0.014851689808100704, 0.05145200483140446, 0.028817462134024793, 0.04039038851436588, 0.011030501655993924, 0.036908890451154405, 0.04608210003484161, 0.03636650403120345, 0.05347102189496641, 0.056760132297753334, 0.047718008018789754, 0.009419123807381238, 0.010561364732923047, 0.026661985658950386, 0.02143543506521852, 0.07508860585550148, 0.030375430247776454, 0.06407531436472651, 0.10890310630202295, 0.09067441952685196, 0.049279161143086614, 0.05088756657055309, 0.024664352024574916, 0.1178437507440967, 0.03439932430703794, 0.03656781278550625, 0.040622210550692775, 0.018088854661571886, 0.04517454631446351, 0.039965791943212675, 0.016176377445639625, 0.026001343991787686, 0.015926474776689806, 0.04270916812181954, 0.025982772105283318, 0.0498694280583051, 0.03606121416293806, 0.0179358898857308, 0.07420372067680282, 0.029123906879836035, 0.06920043108684402, 0.015815600786628504, 0.03533461424071462, 0.023133936263020002, 0.06671785422029995, 0.058240941950991276, 0.03681181178938958, 0.03329878920809396, 0.03423556152190413, 0.03764981238712226, 0.0097645700894176, 0.07137194561261324, 0.045043054983140006, 0.06000081062196724, 0.023520496568732688, 0.02500235193198727, 0.06240160377215474, 0.010407951795646261, 0.033333623226010994, 0.0574920527006109, 0.04317415667878043, 0.015973302858671354, 0.056186838060497284, 0.08107021270740418, 0.05167042415949607, 0.06539105122248012, 0.05836924635654977, 0.030744156026611888, 0.04229522017281383, 0.04169289120322755, 0.04081965822185721, 0.025484841767578356, 0.011086910625078506, 0.054388898650124196, 0.0520156501912542, 0.031310061345838254, 0.08188245742912255, 0.07648982663428591, 0.04718447374480386, 0.01564107159332883, 0.041445398838409496, 0.08067698743675025, 0.06775538241791149, 0.0866116943859285, 0.061774989815368775, 0.047574849168379466, 0.018563425063245723, 0.005072345713063354, 0.01771786700814001, 0.014316121570675844, 0.013798068976029755, 0.0446367870655752, 0.011611136930784392, 0.04321097486442135, 0.07602543945634559, 0.12079747168407326, 0.09328114860240491, 0.02626173536203081, 0.06071210793790318, 0.025098689403685353, 0.03307023836720375, 0.018340909079979026, 0.05507015382810947, 0.019425057558222644, 0.051063881706326246, 0.012981520755396736, 0.04610711663600899, 0.048679295146176894, 0.054025240542907874, 0.041096916932973175, 0.054128685395323464, 0.01215693531482811, 0.009423574778221307, 0.04824110051436771, 0.0016474953032053648, 0.008648445101214514, 0.07549254869621608, 0.006790683800054174, 0.019871476143898986, 0.021815138884008895, 0.027227461968939153, 0.022881841624996836, 0.066620392514573, 0.027026086181942976, 0.01856227784657911, 0.05152900432867389, 0.025281010668784864, 0.027484055458297654, 0.06416606514023677, 0.03412623311423006, 0.03824795851664197, 0.04905411132401036, 0.006089873748996686, 0.1798970105066415, 0.009677717743832017, 0.0351790294441725, 0.036080623000499704, 0.04549348786953957, 0.021920280621176767, 0.017072684995289293, 0.027592851434864347, 0.02856362273075408, 0.059096784736480445, 0.06796173586119568, 0.033703781589264833, 0.037141221935950944, 0.012556504751104983, 0.1427144734489341, 0.032778412494207584, 0.04981936804289299, 0.02499480022027368, 0.016947891187643813, 0.09749074812017142, 0.06468595921873085, 0.120450648358993, 0.05973703888875823, 0.059529494178751786, 0.04322013727599575, 0.025799786258909493, 0.030089955243672577, 0.04422768845313019, 0.027718782883077383, 0.025535430383658218, 0.03495710526382731, 0.036496083973155874, 0.031649059082771984, 0.0443212392800037, 0.0295739452309546, 0.041583405747529, 0.052911838997275605, 0.025917250520339417, 0.01665324994152592, 0.2034492958937922, 0.10436652513641505, 0.10592379802537542, 0.09678036244886537, 0.15050033227570597, 0.18357159720072824, 0.10761951832401176, 0.09029506810850675, 0.10452902770691341, 0.14011110749936875, 0.18741740454589167, 0.10479839188196968, 0.15039274288762003, 0.19195443770337492, 0.17951591240782894, 0.09966274528133293, 0.13746284879744053, 0.08927743521428878, 0.16639222871632348, 0.1277941450356476, 0.105723810772742, 0.1492960114152201, 0.13650808873916828, 0.2559965689696612, 0.09255279816927449, 0.11711287222081616, 0.17125976752609978, 0.18484728681224008, 0.08881395202009909, 0.12605006926723067, 0.1278382793609654, 0.07722489565851227, 0.12883220949480612, 0.13594561166340305, 0.1310485325032665, 0.07263916229168255, 0.11867157769419494, 0.14462561767187812, 0.13861890611869676, 0.16089715664425205, 0.11715984873233304, 0.07234960403894225, 0.15334728354167554, 0.0837861093121671, 0.19317932036374846, 0.15334599651396275, 0.11446578563341211, 0.1649222438854556, 0.0889627875820283, 0.14168065311687608, 0.13129243957659892, 0.14887251801067783, 0.14156595443285283, 0.15334919876148626, 0.1930867769424954, 0.0719824870447478, 0.124451580847944, 0.1721765755886032, 0.08947762931066175, 0.13980284904039678, 0.19108345702050195, 0.20300516408056984, 0.1181227676269989, 0.15621734001944143, 0.16952615651872852, 0.14962964270624424, 0.1539836268150999, 0.15993692671820042, 0.10680687523657277, 0.14891434641134355, 0.16398084440058278, 0.1787368929193866, 0.10904718445794237, 0.1288276589325359, 0.10025738272815944, 0.1100809358420872, 0.1940430078895823, 0.18461882407146116, 0.14438699660522325, 0.09727573022246362, 0.15375684946775436, 0.22757012577306843, 0.1464015626979451, 0.1657515647070062, 0.11913060991754455, 0.13684421747682557, 0.16149035384578092, 0.18290081061422828, 0.10771831302272697, 0.12082960141161758, 0.1605136070640818, 0.10678655092394161, 0.11771382223213873, 0.09596355950399753, 0.08215097890746209, 0.1598155783909944, 0.11102107128188496, 0.1386313014213116, 0.17352559513622717, 0.1945226402172158, 0.13077807282247852, 0.15898985818268793, 0.1546940967560776, 0.10641361932240187, 0.1806321025135056, 0.1306215763813065, 0.12100548753815314, 0.15627165565327292, 0.1542930344059583, 0.09614006616175176, 0.1752125054237343, 0.15311238566233268, 0.10139349111986738, 0.1426805051103715, 0.14120990740916423, 0.1328800648691193, 0.08133207688168173, 0.1339351824454723, 0.17859864469257095, 0.07519012016634788, 0.17358629994334715, 0.09727086556414444, 0.15571498552397375, 0.11496765749348749, 0.22878852732960256, 0.09167786447271224, 0.17519238795484268, 0.10545482198076864, 0.10568120096239353, 0.12786102451143727, 0.23770520854140484, 0.13845451897190464, 0.14930966310203075, 0.1567922123978215, 0.10948361708752571, 0.15257367263397864, 0.1037892932072282, 0.30530488358870633, 0.11018031276762487, 0.18727805315246507, 0.08217341762276427, 0.19708293670367813, 0.11628897530176949, 0.19373738477306982, 0.16494698852540987, 0.08438773348086304, 0.1945905615725825, 0.08755021338020602, 0.11645241249953547, 0.07708094007666073, 0.20394664017423508, 0.25835169178824274, 0.144486250956693, 0.10888511855756083, 0.17597324605430328, 0.1192987432342864, 0.1930230997142292, 0.20823596646228146, 0.2661331839138462, 0.16880768861982132, 0.12472560283757987, 0.22899667341862956, 0.13966712890373123, 0.09998702263880162, 0.13297515170228097, 0.16541224904358387, 0.15517823368070588, 0.11648296408595578, 0.172248097557214, 0.12812031463028925, 0.18862944757265432, 0.09865382280681403, 0.14481490267620933, 0.17833278153932866, 0.10408653532184901, 0.14021957022768838], [0.05799837553152635, 0.09519756351026798, 0.026387400594690157, 0.043729424867178165, 0.032451346576694524, 0.03506597784918643, 0.0394742661005547, 0.03507476870811755, 0.035409491674433795, 0.04637477626543372, 0.0136866663853007, 0.07634521987769874, 0.0366002872526165, 0.04371261306767983, 0.07183866935872263, 0.010537463747295401, 0.07553836841496729, 0.00487469311337918, 0.06386853574264435, 0.0046527636661795125, 0.03307143346436563, 0.014978736871853473, 0.10342360113657291, 0.07086988223055679, 0.04206597985279176, 0.05706304346301383, 0.07884116497852149, 0.04861348436304158, 0.044393948684897155, 0.08365409704105509, 0.10748134670598854, 0.04398656227896291, 0.04507377893934327, 0.05980916223638962, 0.03387682552960131, 0.02813116418227794, 0.04964637006783197, 0.04445643464644109, 0.023503993119623874, 0.03127945038760382, 0.0774156132472619, 0.02690525496408584, 0.02821665959462764, 0.019610611714362618, 0.05432308403654926, 0.005742084674326884, 0.016600075778701616, 0.02417833818453214, 0.04369184059361297, 0.03381189191713929, 0.11256598717262668, 0.04002362009017699, 0.00644181166858142, 0.021054210561898448, 0.029800096301422007, 0.024991956118854786, 0.032859552696707754, 0.06849916186183691, 0.02761771481844687, 0.015693826323014595, 0.013023704429337335, 0.03002965071749303, 0.017735661315401236, 0.02825904915469789, 0.021150458018265424, 0.015439296483002124, 0.07779038345981991, 0.02137787887946733, 0.05587851448405174, 0.06754047177251309, 0.09891468340591078, 0.040240085894061674, 0.017652492895121538, 0.07501478562311781, 0.09784371547040441, 0.018198336286830808, 0.021471255421338063, 0.016473615729820826, 0.03993153632167847, 0.04791654353480666, 0.01373806035131096, 0.005339211483876552, 0.06718028021315414, 0.029670478055073373, 0.027626524829576095, 0.05287215947323749, 0.03101352786254739, 0.04419492287260871, 0.066618783729932, 0.055292556813407334, 0.05643916060967792, 0.029542466678145914, 0.04890723694716731, 0.057581834374896945, 0.00884516786168059, 0.032181633831632715, 0.047098625932008996, 0.024757222948415626, 0.027943258136210423, 0.06660776738558086, 0.03543128304543995, 0.06414334680284224, 0.02792097838415254, 0.0597098465978859, 0.032348518425057975, 0.02597062769646366, 0.029671441410638155, 0.0643581808394482, 0.027985632374522187, 0.03687454672950891, 0.025448885430852254, 0.011347069296114629, 0.037945185247207844, 0.03510942269537238, 0.03553452105411599, 0.015354202309202765, 0.021739891812866254, 0.10610152276292925, 0.06387079187158136, 0.057199449248371594, 0.04663197496425241, 0.0641475641168654, 0.01869974849415162, 0.029471333499156663, 0.0156501937852872, 0.024460065103466475, 0.03215212795522905, 0.00707276551345844, 0.047592614747343526, 0.022168278604024844, 0.051472570461731766, 0.026312611261082273, 0.05047910764152485, 0.03209412360804216, 0.04449807535556536, 0.06698235373703704, 0.02344795953362219, 0.03737185270555558, 0.028216590646714456, 0.03128195932555584, 0.04425558171445324, 0.036345781352851665, 0.027485373129527417, 0.07108383526604983, 0.010332118667241548, 0.06824197848477671, 0.05867742437628969, 0.04408231560861872, 0.049173080948211496, 0.056737854460915255, 0.024369814200326804, 0.012139169735864047, 0.013911353270222825, 0.016817202333420996, 0.03694786517430217, 0.016884790440540642, 0.05627121881491715, 0.018862344910420718, 0.013989721192047002, 0.0051953258075480985, 0.03756517882368738, 0.03191774335479544, 0.1356212653580212, 0.03688249489172332, 0.012858314664974328, 0.019157001478297096, 0.017446700611241886, 0.015561649342998864, 0.061512240809538675, 0.02099729214434422, 0.06991328356126625, 0.007799400867248375, 0.030439971240177274, 0.03596416997512983, 0.04170355131669391, 0.018446943309578686, 0.03056945733635897, 0.04572831297052964, 0.03261140149627482, 0.01610693349052341, 0.04406201810906491, 0.07359310263587583, 0.017102342174058, 0.01895254218740569, 0.040486624479414, 0.05818654970836736, 0.05146181458727487, 0.0451475034107364, 0.032915500097817955, 0.027821674236967683, 0.03388306531574457, 0.013305016703182652, 0.010973072832360143, 0.03888348973686657, 0.047242788357600096, 0.04980324572252651, 0.03603383418052428, 0.033445751685048306, 0.05048391867368933, 0.09162966988139576, 0.07237297738151205, 0.06427485345592422, 0.025755081198088108, 0.021787525244778203, 0.022498112014164368, 0.05774141048952457, 0.04738533433767096, 0.011414598989030047, 0.08258014902352326, 0.07708849370359414, 0.018531576873013572, 0.019884557095206073, 0.014693065557719, 0.0590177053104966, 0.0995772268863455, 0.038922525747048284, 0.07746473480496677, 0.041934404251796585, 0.07128042108829945, 0.031174523155054742, 0.022068616310735385, 0.01752412145686967, 0.06238622072663519, 0.005130969633859012, 0.006665396344502487, 0.017373125526993986, 0.10801250610740916, 0.02879521877114331, 0.04506997531279922, 0.029198968174657034, 0.021152285137964834, 0.040589782048857985, 0.07476642757894532, 0.02890874534064243, 0.030241588941745223, 0.030554147069192225, 0.036500511961358215, 0.013578849086057276, 0.05942524110357608, 0.032370646874750816, 0.015215045310586933, 0.020582380839773727, 0.07247161120176315, 0.011329007815689811, 0.06728281342093984, 0.015633800461317505, 0.07067513501932544, 0.024362848545875282, 0.013830348090719313, 0.04776843575640552, 0.03096005109499299, 0.03629977011211938, 0.011302720466178032, 0.05367373259017064, 0.0995166446532934, 0.020091341462947672, 0.05402881434307464, 0.02811289490050366, 0.021558026370081692, 0.017223824566650777, 0.04220566449446544, 0.03314022815996601, 0.05364967742934824, 0.03339796695077131, 0.04903239656179663, 0.041224428437530033, 0.030804726768345125, 0.016541381952382864, 0.03285003788468819, 0.021702686752823573, 0.04193282994111219, 0.03520020794483923, 0.05071498228297119, 0.07256283695178647, 0.061955234982193484, 0.04758119237639251, 0.06517371973924099, 0.07408198930563466, 0.04280335097123058, 0.019285453355781013, 0.01701015689890952, 0.06925182792568399, 0.04756206316092322, 0.013349325313503224, 0.039761376702376915, 0.060757142416532, 0.05790762092557646, 0.05699691092295032, 0.0560858293676809, 0.05093025682013362, 0.029063592777557434, 0.020504789539582787, 0.015276069959415304, 0.06175935013039459, 0.04064970927673482, 0.06166280389973714, 0.036062167942403786, 0.034275903711996736, 0.039668484711118286, 0.02352787974110294, 0.008462599831663312, 0.03928718742944541, 0.03794680935360732, 0.07616632302562076, 0.1761457077678173, 0.05817438806256941, 0.08648208763089874, 0.0692824867644137, 0.07420398114669709, 0.05761186885196836, 0.0830022098436471, 0.027139905780073137, 0.022217141607055263, 0.05194986622119623, 0.017298458767453992, 0.018404442666759415, 0.02493184502987612, 0.03414422085869216, 0.05254125928566341, 0.06063511610151299, 0.09073702423202415, 0.038519034898209, 0.04345831401165455, 0.08078760287213711, 0.027216646722668124, 0.06814892944549361, 0.05364142283196411, 0.02560387842447287, 0.04594197106217185, 0.01697942911226663, 0.06075719604268671, 0.06959298986100382, 0.029747542669816367, 0.023908315173861, 0.00776338180707347, 0.016855200294465307, 0.009605153895644172, 0.013763669713009751, 0.05238769696124139, 0.0826290330939716, 0.017529899675038554, 0.05329673306175298, 0.009343445811781191, 0.10361616499722005, 0.07193471380178967, 0.010279250939586952, 0.048043825212986245, 0.048950126379608154, 0.00537299404611751, 0.034442198417720296, 0.08237171948196427, 0.023622261773374294, 0.1653148179813739, 0.24012348764846403, 0.06807173076536387, 0.07858064911899068, 0.11020815240279322, 0.12459185154687975, 0.10334670889161288, 0.10794003418977223, 0.1734837054485275, 0.18399673003342845, 0.09521571979407342, 0.19289131726949446, 0.1485118438159266, 0.07463336576737704, 0.15876176316411267, 0.10467803946906522, 0.10625749060343351, 0.09307618177826367, 0.13879587242920555, 0.07993826417312508, 0.14025395225373008, 0.1340836196416809, 0.17260324059715196, 0.1935201069159854, 0.1510706540918158, 0.2530312417976318, 0.15638563421464738, 0.10958409717967434, 0.19499337060316918, 0.23113326199593084, 0.20016175214081042, 0.10224185688721557, 0.2143467280773386, 0.19690020941197875, 0.0772337592957962, 0.07036611047242919, 0.1963253217118402, 0.2561607416118345, 0.16495710088601037, 0.13163808312627578, 0.2054496740381564, 0.18815553026093593, 0.3245838539254281, 0.1628459464277952, 0.150034474208951, 0.13441156656030687, 0.18607805302787214, 0.154994449187671, 0.18415891084699862, 0.09358572983934034, 0.1770253758877516, 0.08766570879567055, 0.12801481666223657, 0.09505490261700847, 0.10076876940025438, 0.22423986495742876, 0.13388212319583664, 0.12250730332227484, 0.12446186940876708, 0.13595071380897877, 0.09760727009345448, 0.09411895767815652, 0.17539042168326918, 0.18008313922872468, 0.09392213436865038, 0.08794100249126073, 0.17539904783329657, 0.15210645093071848, 0.2067141174789398, 0.12325769410498681, 0.2551730397728182, 0.16176157961449317, 0.09045463656225512, 0.12556856002418265, 0.17987568261882952, 0.1195235517356665, 0.12833406848292198, 0.14986728318035603, 0.15163663985027423, 0.1179382476895567, 0.14443916719286673, 0.056696765335096475, 0.19401884547645049, 0.14550468824323148, 0.09763691003524488, 0.1129653488075541, 0.1389293249456152, 0.118115198678307, 0.1851264492518479, 0.15554027151196234, 0.10039475761474141, 0.12150754325933034, 0.09952828918974246, 0.10824221757150466, 0.07989680349466302, 0.14979767643155592, 0.2727131437390082, 0.12023474946017228, 0.2515325286696034, 0.13543954930238186, 0.11854020893693933, 0.22523231654157563, 0.12937787860151262, 0.1659930356207394, 0.15858940870290802, 0.1821902947079751, 0.13090357334623415, 0.12822981923818588, 0.1234055414134937, 0.11208389570275623, 0.08824264961144618, 0.1722805796852035, 0.19763093471767443, 0.15916516974328027, 0.16706618690682998, 0.10295035032134864, 0.08531458495605378, 0.22728317988014993, 0.0925857476108978, 0.1638244092464447, 0.09212603356929557, 0.2716723673285977, 0.1072107338076157, 0.17017445076377163, 0.0893057345022117, 0.14411822231786867, 0.09805255103856327, 0.13489720501726674, 0.34066756346052696, 0.11235393403518586, 0.1675570960487089, 0.1948475840711786, 0.16930149357405402, 0.14715168534988357, 0.13194813423099058, 0.12859188771295932, 0.09043316311773755, 0.13768810929069597, 0.10280208932536264, 0.12649740332797652, 0.19686659347386132, 0.12391773247790915, 0.11116732512750935, 0.24442288033183546, 0.2054422123417739, 0.1563671868174307, 0.1502036570661491, 0.18991368672540113, 0.12539860341818104, 0.14811136369262973, 0.09221986401826145, 0.07737643551081419, 0.06903959858802057, 0.10255974507139576, 0.21349218764132072, 0.0917407832739334, 0.13243544275962538, 0.06630622751770482, 0.09993286788343422, 0.13842225134853395, 0.1596266917523838, 0.16840478765868372, 0.20376659419027068, 0.17652308267931785, 0.15114330987055458, 0.12937429331002698, 0.08744447792489683, 0.17355308237095035, 0.21218631416559222, 0.14082942218069108, 0.1514188104098843, 0.08408155112016587, 0.1505384068455427, 0.11853693008062341, 0.2519857769291247, 0.12572229854882727], [0.025283916057237697, 0.023349346780788996, 0.06220614409915382, 0.025418213185583873, 0.05899283809647445, 0.08046741642418408, 0.061613054149934364, 0.05477223755611528, 0.04491463949483249, 0.009261067419673407, 0.06295358161291768, 0.039483976264994954, 0.04197625946553965, 0.03292165561428955, 0.03575536888092756, 0.023702155167777694, 0.05618933167669082, 0.04513392067183891, 0.07999255682431883, 0.047582881600265546, 0.041210401367636464, 0.07262922613130463, 0.08428529220362825, 0.0400007676873957, 0.058516687638456785, 0.04560617940320123, 0.035294111172157916, 0.050981255293252974, 0.018085091254643856, 0.05467598243886906, 0.02037439945965044, 0.03395423488391023, 0.0704531840259029, 0.0641837694321669, 0.017993610780385715, 0.008223412817554369, 0.008802096483357733, 0.012331460677688161, 0.0289405609721378, 0.04579285204771065, 0.06526530555058872, 0.039185684609917865, 0.02777728710263487, 0.023281710793174083, 0.03958915630655904, 0.0050782058068791465, 0.025826559116643284, 0.01968338432150983, 0.020153105386622974, 0.05428996222514299, 0.042465958188498215, 0.0807893725352422, 0.026962127416364612, 0.038251654890876625, 0.005259077250581956, 0.01660574865978091, 0.010947517096816052, 0.054003441511022474, 0.059543061595890796, 0.06662963153493982, 0.024420891197458394, 0.03673783067854182, 0.08501017991934093, 0.027899495363535903, 0.04113618659997179, 0.04197537080354748, 0.009118938957521272, 0.03883617614666301, 0.06639416675053297, 0.027163468729404193, 0.05590681760241428, 0.010755780611127135, 0.04758997174400476, 0.05750145259944182, 0.022948487443969618, 0.06876174615876329, 0.03989964408139068, 0.0225497329337222, 0.039963773301532196, 0.02564416698841078, 0.0037704640342253112, 0.03708171605643246, 0.07157619997498489, 0.06830793099417802, 0.07610970912801643, 0.06179227275894054, 0.013695977226410423, 0.03107195164287283, 0.0056087681385237845, 0.04266619825014665, 0.05498950009144122, 0.022565022133471026, 0.013251191365622706, 0.06311346416271503, 0.05571795777688104, 0.0511520545959713, 0.054039152699612805, 0.050162085136699106, 0.0539716603534837, 0.07314378440740608, 0.004095622871611869, 0.0934233038776344, 0.008760559196103244, 0.015300091603891024, 0.03746445358340298, 0.023741677643791325, 0.03663537407954855, 0.027133535758982745, 0.017557768038504066, 0.009403320371113237, 0.025190066456073718, 0.012601362071901321, 0.0854656957991181, 0.05142621448143356, 0.04490168111759328, 0.015583291326859787, 0.0782923472504462, 0.017749644335239165, 0.004999622422826267, 0.11421736630220568, 0.002956224371671617, 0.051123659547057845, 0.07917969157138179, 0.02141541335731745, 0.03572202490402326, 0.030505397064130635, 0.05993317271913252, 0.054445340177945556, 0.06463329067393657, 0.05875048618162832, 0.029072157640550888, 0.023700410402530146, 0.06902400103788223, 0.06407667034035248, 0.046482832967153484, 0.06449960833114964, 0.02506440122341437, 0.012989916121436944, 0.042685051673963186, 0.026742587684683745, 0.07741059537135786, 0.10322840193346625, 0.01763064981318049, 0.05587941080692315, 0.0077937931036426425, 0.02539481877559616, 0.02486681374120376, 0.04621784698458449, 0.013372601937472582, 0.011614437812128136, 0.02685557224697644, 0.031630837681492975, 0.07172806924509426, 0.03582586046128023, 0.025621960014705698, 0.03395497798919678, 0.046244280848411784, 0.02266966974392774, 0.0382269868597148, 0.012777061464505331, 0.05027828535305397, 0.016549663362844337, 0.07991074629488491, 0.04082231271651484, 0.03309026773598406, 0.02049435542205409, 0.06423345406449611, 0.0841662651228328, 0.06268961069684836, 0.03534452741845481, 0.0379543936240577, 0.08325590752065183, 0.04028770208899533, 0.04552444931299937, 0.04652901657766873, 0.04043829582271077, 0.021700892191860947, 0.05658998033933102, 0.01992527658360139, 0.029947125811069727, 0.06632068359683599, 0.05490953583390482, 0.024740363268422026, 0.047794042245274594, 0.06782240745040678, 0.0464414757105612, 0.020716235552343632, 0.08381364251216573, 0.01771373779422814, 0.018017600823734558, 0.09128277760840232, 0.018751511139975443, 0.050164731970477494, 0.05291578435008565, 0.05800580658439187, 0.055995794884379835, 0.004152176918597111, 0.06434677379025568, 0.03283687649414905, 0.01136108295946953, 0.026981971008823286, 0.03265536728224928, 0.028961222363455646, 0.0037606753457728177, 0.04847206836265903, 0.07101340880317074, 0.032294133843313304, 0.018055658156593, 0.026032240317773916, 0.014993569291677448, 0.10501933163933216, 0.10630958458228458, 0.03513161243209916, 0.04299003893749849, 0.0319002861262209, 0.033209865552283106, 0.06034093067771005, 0.026629323500298688, 0.042261075634028644, 0.021825052061749083, 0.010806373057646618, 0.007822248481980135, 0.05438709834350213, 0.02082870109006763, 0.01004561423248942, 0.08982783108348809, 0.014342127382875451, 0.011256126998623293, 0.02648476462420677, 0.04858875887528543, 0.05015710173475166, 0.07626308759133663, 0.007467676177545781, 0.04686154470208192, 0.02067425776453268, 0.010932698083530751, 0.013202431784462065, 0.04328285306391697, 0.049555515870451934, 0.018203472906363108, 0.053441305344383565, 0.06657768311279436, 0.05658243820371647, 0.0661522898101999, 0.054893861674974044, 0.015294114202861826, 0.011825195303367031, 0.03655154873887378, 0.08546090774959134, 0.05236761013586676, 0.047375647155868436, 0.015621186823644226, 0.048781579375387206, 0.05487339180563727, 0.05949921072310498, 0.024416177841504256, 0.04865581838173732, 0.045953738172688795, 0.04375936358325905, 0.023726687218332966, 0.030255330643887003, 0.01931461066217913, 0.02335916228231884, 0.026319988687793096, 0.018589246056733594, 0.036657962181995955, 0.011867279385877474, 0.07701705600465499, 0.04690468311309815, 0.07877748008937606, 0.03428625355985376, 0.034363666744602304, 0.037018008184649294, 0.12594847068671258, 0.054265638933547085, 0.036912655773302244, 0.025806861080890222, 0.06815683547287218, 0.03793543294793175, 0.031947938710330956, 0.02239756297410256, 0.03452851354414898, 0.03027411895022998, 0.02275858573885935, 0.06474988925601206, 0.03067040665736122, 0.05053094881136091, 0.021802272437320604, 0.07559778619437449, 0.02767827215364143, 0.021597033651966243, 0.017450496576906695, 0.022493184153591434, 0.02840793451234218, 0.020768415716086185, 0.13711991719901562, 0.03493639024635477, 0.028845713541452444, 0.01439897589490659, 0.0612673033479481, 0.01233065149731814, 0.01635322501252015, 0.014546589546596572, 0.012846785041713908, 0.054802950020999684, 0.03021292576205827, 0.06660711621084521, 0.04332499556063164, 0.018161560236025723, 0.05235153378077573, 0.021040085815794526, 0.022499176876379118, 0.01573504855661022, 0.02487741065241637, 0.0276467495507771, 0.0049408663518636705, 0.03424592286108002, 0.04797126902567764, 0.02099852554590231, 0.03232122654275548, 0.041338682790557225, 0.0358479927414127, 0.06984214463661756, 0.007570038451963375, 0.019556851494276238, 0.06968088312855653, 0.009997201306114515, 0.018997501972461903, 0.03932834167273776, 0.07806805968885461, 0.03267994338286019, 0.012519590804473528, 0.0511821924949125, 0.04617485796071349, 0.0863411044701934, 0.03959131284406589, 0.025574129315153248, 0.034744496712641376, 0.10595516166499547, 0.029545573164678873, 0.011362369029572415, 0.07070106709556234, 0.07411758175059673, 0.023796613808841478, 0.030475123184582883, 0.021219308255240325, 0.025521368839808052, 0.0960750712622558, 0.07758619804536143, 0.05853407783433796, 0.03296210505669156, 0.03263971610595623, 0.13583840531927927, 0.10723063677188852, 0.1144386891035303, 0.10474117277490516, 0.17917955384379436, 0.1803446356807986, 0.11666107952835099, 0.2263762849953867, 0.129425912314365, 0.1398543301489084, 0.1079309177434733, 0.1353706320327136, 0.19085304841639536, 0.1156135002571729, 0.24912362647873743, 0.11155154886505297, 0.1721923416780849, 0.13804683762211956, 0.12110616681316208, 0.1111398991798201, 0.05367809546089942, 0.19274556138102086, 0.1280942293364675, 0.25387134913715625, 0.17781685196584274, 0.07986450522777536, 0.14499582200040742, 0.11243654895694026, 0.06600471829334575, 0.14819059250575883, 0.13915392660325573, 0.20646303982263614, 0.20450568517609952, 0.16171190647348282, 0.2079020287360876, 0.13689598969874844, 0.15633439825427148, 0.08407639534843546, 0.16612202950542973, 0.17128851114501878, 0.17739858328094407, 0.16319255524825665, 0.2093971872161473, 0.11812530337802826, 0.1410814191425039, 0.05702080137486901, 0.14109894723421143, 0.1278813258414307, 0.20007686959880017, 0.13971128621168677, 0.15021462744522482, 0.14103409023054186, 0.15388110892907267, 0.20352994963046045, 0.13779361491962788, 0.1910776653957944, 0.03180808744453375, 0.19550975982940969, 0.06014506497810926, 0.1266002736144489, 0.09791912150479133, 0.1238798187865365, 0.15347770234990507, 0.05657348263588163, 0.13045561109339038, 0.1637973663427176, 0.10779449280591742, 0.18268011600500156, 0.1825797584869208, 0.13081899723939358, 0.09270169501823765, 0.09113660037157037, 0.13235406890030832, 0.20922751406267767, 0.13423997818702652, 0.1622519371730666, 0.11617091349175862, 0.1415287991685252, 0.15036983685868402, 0.12891730654143518, 0.14316586777567863, 0.15535815709060238, 0.15814170691995852, 0.1940115676411698, 0.1421867001561388, 0.18500327763538207, 0.1682214781401619, 0.1450340651095875, 0.10128315147613326, 0.2051095922868098, 0.25192770746446425, 0.18571728690256997, 0.14814776819079153, 0.25877858662316877, 0.12029623567697503, 0.2785515917405006, 0.12334111341906172, 0.18893709316128687, 0.16810642705569345, 0.1424513069251853, 0.09956956600710269, 0.2965216242497967, 0.16317888823968751, 0.15644753411892923, 0.1405908011140362, 0.2318009995524922, 0.17622904281222052, 0.20075596057839934, 0.17319677487736748, 0.08676164077534791, 0.13713562200146337, 0.15593430117493676, 0.10003306452305087, 0.1917606787455659, 0.11481319884619406, 0.06543796644696305, 0.12430083772708332, 0.08926838771590302, 0.17427291390636276, 0.2482104343512366, 0.09604714735741578, 0.131212490640821, 0.1391254281324725, 0.12688090694287132, 0.15103952027857304, 0.10048556201640638, 0.09871446632690008, 0.16367543578868912, 0.19203159807910844, 0.15535691602816507, 0.18557123990068514, 0.1455714298231948, 0.15942922492902126, 0.11834151637289794, 0.15709795808840185, 0.18461883939321966, 0.06643545122877245, 0.07629530158855262, 0.2668112023703514, 0.10193611119663525, 0.12145452997497014, 0.2391132321809569, 0.15828285095912797, 0.10979755991889585, 0.12913697459284337, 0.12121467550675716, 0.133050749258649, 0.14021526481355392, 0.07877155822972137, 0.29534276815191396, 0.05798844320158805, 0.09294349534977829, 0.19122280841392858, 0.14706577625005476, 0.12259463734564283, 0.10809435494123928, 0.13590145435544754, 0.055985138601353096, 0.15945859674003818, 0.09829736975652557, 0.14943183880419503, 0.10042900174495675, 0.24311386589561743, 0.12412148888313002, 0.10340513841759774, 0.22712404809651837, 0.15505057278900378, 0.17379740313176187, 0.21038767761520802, 0.09759636100141272, 0.1790386396310022, 0.23139540196186115, 0.14674637887266376, 0.16399985870286343, 0.1972882329456268, 0.15114160915536268], [0.05534104634857467, 0.04042532595415269, 0.009853259130801645, 0.03740864024767953, 0.07933700006575355, 0.0901186457204242, 0.012316653155721726, 0.05101460693103652, 0.04598717791058364, 0.029807144310325388, 0.016200122340852698, 0.035461171965805754, 0.06357346931772848, 0.023402990172466925, 0.019077039135980512, 0.04353586509222946, 0.03565018883936348, 0.07442816145597927, 0.026866575184788917, 0.09506874582580022, 0.053686549241143855, 0.10078208400837838, 0.014287663319508636, 0.038646527250567754, 0.06577333675757532, 0.055044114499563174, 0.06002275904099788, 0.04799299144877061, 0.041067579595912854, 0.051901219638004426, 0.02993998587161543, 0.005547686033101092, 0.025225191587401975, 0.11443762424131555, 0.022636155312460278, 0.01181253474280839, 0.013590343277751198, 0.03006833241200976, 0.01263327825243675, 0.10163214283003923, 0.06794139622680603, 0.07158201458233018, 0.04106305584671997, 0.00844347253141384, 0.012266580691380848, 0.03814742862877827, 0.06132032429318755, 0.028901377490030664, 0.030696702625362143, 0.06913627888406478, 0.03885178518812022, 0.04228326537075543, 0.07234067145374513, 0.08229004684835672, 0.050206422475316835, 0.0065933768975458325, 0.10456782239939898, 0.039606485215406266, 0.0580004784428785, 0.02263391833572138, 0.044390394036928495, 0.014086673449304317, 0.02963767225493587, 0.03916138047052007, 0.029796512925156185, 0.03169418357673191, 0.014280111607795042, 0.0470718166850988, 0.0623596451365419, 0.039799267411111824, 0.06942162365322152, 0.012553461466825778, 0.05679139634594322, 0.03536829912674523, 0.0017467423528996148, 0.03965610473026191, 0.036383292848064054, 0.03370996391881378, 0.03625688451011816, 0.0078047012380744905, 0.03890265342629245, 0.047498730672222954, 0.017102493476423047, 0.02599668809242787, 0.025653808204937848, 0.030408515670006315, 0.056717924683565096, 0.03277224548641713, 0.01695394519746544, 0.035913305567397226, 0.03717782178653344, 0.05007207363603577, 0.022782847743421313, 0.12442465285740553, 0.03843604842381131, 0.05779839593977217, 0.04716476613295175, 0.022873994969432394, 0.045756482023505435, 0.0541539088402304, 0.05366331762484005, 0.012601128415084414, 0.026194853971021313, 0.0651539087055191, 0.06038593068238228, 0.03343167481943965, 0.022226660249514446, 0.02821242504362618, 0.017432983806957642, 0.024984707011871284, 0.04641372800594376, 0.061947593255148786, 0.06008301568668216, 0.07524267379795352, 0.05987510708491168, 0.08189690584737448, 0.023756710204085516, 0.06027011734042918, 0.07151996146046347, 0.03571678103218156, 0.04598969067897528, 0.03413222392179793, 0.030234770759219126, 0.01836566329603234, 0.03892948182540075, 0.023951135658388658, 0.04523845336910698, 0.03659959777348465, 0.02964362092766791, 0.020009996331927758, 0.042609676283093235, 0.019572450959634398, 0.032961806282401085, 0.023413453018292788, 0.014885851583864181, 0.019087544116642208, 0.073517068409391, 0.05200159630828327, 0.062353991407660715, 0.03118990237013467, 0.05637050764034352, 0.03407469454912409, 0.01016001701505194, 0.013556526241553648, 0.01876516857244555, 0.02358745648375442, 0.016005880747651382, 0.017433324716083946, 0.03654729695089402, 0.03602659464963982, 0.0359027220627233, 0.03660118740592753, 0.033254720000249725, 0.09524754308644803, 0.05502804963579101, 0.04468978885861655, 0.03326236938817367, 0.04128998641165034, 0.0232317982496874, 0.023421891476778735, 0.03392328110132967, 0.02757212684129275, 0.03373367050963064, 0.017806917068458373, 0.03539440357276509, 0.01973510674771763, 0.02838305389178136, 0.07766165770590305, 0.031619558952027754, 0.034719537568068316, 0.027235191796095144, 0.0919372771656321, 0.02896820142444584, 0.009604769894072126, 0.012471493889367389, 0.03215321196964191, 0.010745673996186065, 0.04721535091859199, 0.012310635535076503, 0.02361285995932356, 0.023471087728056218, 0.05531286197384039, 0.052419918619336626, 0.06501704709784639, 0.02821090244387667, 0.024440079784741806, 0.036420946069542444, 0.09434385811008754, 0.013616812573144994, 0.012055553154148644, 0.059086783458628965, 0.030883691281140335, 0.016923500863354535, 0.029362552844348456, 0.05620492922682917, 0.10167377204784464, 0.04215806362129027, 0.05323656834661961, 0.04022394059105747, 0.06108615419737274, 0.0368614619477622, 0.03696826609572576, 0.11279634981145782, 0.045438505739213965, 0.05135508321766412, 0.04147255282488562, 0.021718422198788296, 0.06804990492040111, 0.02812242886472133, 0.1302623577536114, 0.04565374580241981, 0.04973176588875152, 0.020298070289314758, 0.06087984671936401, 0.06702345435417469, 0.025333799872427218, 0.05243566172618059, 0.10262082526159864, 0.047204686974686, 0.01766364330485944, 0.012884803112566233, 0.0076882664072928176, 0.06211677611234689, 0.02963458492060102, 0.07505648378883639, 0.033510876819491386, 0.07710254375612544, 0.05024312574776912, 0.013691810665712243, 0.03367979537635561, 0.09373235140716839, 0.07523768656556645, 0.06598057886285168, 0.021946496149945646, 0.04144538351665101, 0.020801405377325513, 0.03727231873199344, 0.04359087786607204, 0.010421676260809745, 0.01021479900490733, 0.03937729086065966, 0.04846084900500794, 0.009462715167882703, 0.060503525178759336, 0.030119261937215928, 0.047202530437179153, 0.026976445599669413, 0.03620966285046551, 0.10351242137051399, 0.05901049642312912, 0.022562155049414407, 0.07773719397523711, 0.06222580574573048, 0.025881242472678426, 0.08035585870065036, 0.04340018709039977, 0.04527851976754685, 0.04714669794925759, 0.010469834462949827, 0.04568484131126635, 0.011805922446411946, 0.019838038321223952, 0.0050295491687833305, 0.03325558567960416, 0.012734606786961518, 0.02840665706072844, 0.030876208517339923, 0.024844782967721264, 0.026970797616447655, 0.07190571737385566, 0.016721136822936036, 0.025115901484124126, 0.04327911838528611, 0.037909558328289183, 0.02931312676669369, 0.02578224476066328, 0.07247105195757843, 0.05291359333862221, 0.06504094138020469, 0.014613527436590484, 0.02794114373353941, 0.011392305830433484, 0.05860215240728952, 0.03485828375203475, 0.01886939483454391, 0.034514632030961015, 0.05408173186644431, 0.048407732298777956, 0.04400577193366424, 0.011667072840575731, 0.06025386861555519, 0.019365969196622892, 0.021059691920996677, 0.04707023854397478, 0.10821951072542899, 0.018152794274952144, 0.035250356060362635, 0.013221628032624723, 0.02560669571281441, 0.027814469180039825, 0.06338634085090411, 0.03892765853614096, 0.10149363413332932, 0.0445743968650218, 0.04939098699739383, 0.08152664789269048, 0.08666784096989902, 0.004382693732623011, 0.044907602977247975, 0.0440983651506324, 0.024042003262307376, 0.023405997067569725, 0.05265550597781136, 0.01774413999350321, 0.029090557157272295, 0.04298872509670835, 0.06451447809775991, 0.04239979117447811, 0.053504044114942514, 0.06084287148569861, 0.03875328926369548, 0.03444998187103099, 0.04207450258094938, 0.05325541410955691, 0.012043485354121414, 0.01993105480177028, 0.04313992020944434, 0.05514893064936323, 0.03322993322545963, 0.06903051278523861, 0.059945610156583215, 0.028102167754343925, 0.01900779627894442, 0.04164004262777106, 0.02788951898354196, 0.057534804237225366, 0.047369166052029024, 0.03798722815249236, 0.038850674360630014, 0.02243048560264851, 0.056163146791438905, 0.010945318424473367, 0.025954991841929096, 0.04261504655944244, 0.011771417846302352, 0.02791696791386893, 0.038738159027190945, 0.03789147865327616, 0.0148847455444235, 0.03444383018499902, 0.06947430751977429, 0.06429594385647966, 0.17332011503317665, 0.10018577648987693, 0.1540746380605044, 0.10469421924602602, 0.17558318472677664, 0.2418253519722531, 0.1251289021644381, 0.13922684285188877, 0.18663743510842326, 0.1780685731360028, 0.07826612406079808, 0.22397285267230005, 0.1593767019409326, 0.083968285020561, 0.12064446860383596, 0.13659255759369943, 0.08607030004983948, 0.2507457257278504, 0.17581613674279184, 0.15919130866325673, 0.1321668829768896, 0.26057221295852817, 0.11618711625135715, 0.2397871750497049, 0.16378100270465498, 0.10528256711099418, 0.16844716764265494, 0.19237198626562474, 0.18841089800961558, 0.13061259783083393, 0.07224434355814612, 0.16799539027194824, 0.11339780544081043, 0.22914780724433162, 0.15282387695004865, 0.14442629691573883, 0.0750416829701393, 0.11795821960174269, 0.12675048813464182, 0.1556714717298746, 0.09425133767147219, 0.2022444694152763, 0.14301298726950923, 0.06562479230905734, 0.21141555310497362, 0.0960027832057207, 0.1636101038105065, 0.1160742485174729, 0.11864435092936601, 0.2001866040330741, 0.2636154819159739, 0.15324779936382849, 0.17347783721502752, 0.188890652911317, 0.32026780649058284, 0.2688371984949035, 0.19490108765181036, 0.13215830279213767, 0.15342531725764275, 0.1362473124097432, 0.17162114652174135, 0.14619985174748207, 0.10988692407526317, 0.1709783527879946, 0.14002973364005167, 0.16883301548659804, 0.12652150445407437, 0.1803746203621549, 0.10869561138773158, 0.15509019485644757, 0.12435680811083126, 0.07199498959967206, 0.2271085731204479, 0.1836532162081811, 0.13269651020246168, 0.18663400303452246, 0.12922364978059647, 0.1486820991962187, 0.11636340840449257, 0.07806124150632851, 0.2069738978940633, 0.15537772297618851, 0.08595134191695722, 0.1859176495382863, 0.10953004201573711, 0.09962021207977688, 0.17217512002154706, 0.0799883280189768, 0.06096709264262069, 0.18003528937697413, 0.3543475342373694, 0.15237249794506258, 0.12499346548030454, 0.18981965709357493, 0.12987338427093723, 0.11078627299397223, 0.13169629048676262, 0.062295389511892875, 0.1656571367094594, 0.13671537680972007, 0.22716264360614363, 0.15481751352067918, 0.16872907267703166, 0.21911151917471042, 0.1286340991575872, 0.18761738413764587, 0.1313098144507216, 0.12652246206397974, 0.08712513417366051, 0.15610936758739336, 0.1602899247119504, 0.150440669348163, 0.12848644337106135, 0.21746895005626066, 0.18955705747489007, 0.11028354311542166, 0.08920248883265643, 0.14227657759141538, 0.24708629225290593, 0.12020651912016254, 0.2125301344260093, 0.11447860228438532, 0.08863661032650741, 0.12637633845330248, 0.17377342457973188, 0.1349263316801479, 0.10933546334384911, 0.14888134334356556, 0.16874782650941805, 0.21457732054254702, 0.13978668458519444, 0.1457790549724333, 0.1085180934939173, 0.18996362033630573, 0.07550757934129046, 0.12736066184457273, 0.15936110439079423, 0.13733828290095254, 0.10378798319687767, 0.23267502926530378, 0.17888460999294636, 0.15281924977898598, 0.13548427351540135, 0.11297697036136543, 0.11964417227934446, 0.11765559188901417, 0.13055629036839933, 0.12523824589387064, 0.10758119860603925, 0.1111532674140988, 0.11437524936252064, 0.16057130880653858, 0.13213147439302939, 0.19548731345322826, 0.150703682654327, 0.1654861305630015, 0.10598262591708092, 0.13763855872375352, 0.16393497105567686, 0.17416615189323503, 0.2555380193817039, 0.15304703836239156, 0.17457179544914156, 0.15617993960697807, 0.08674006773940018, 0.14408843681937264, 0.12660418066286272, 0.18075725063681605, 0.1038183968874716, 0.10128617752343418, 0.11070461568212318, 0.15675341770533593, 0.07582636384834206, 0.10549656611176268, 0.2075453535203011, 0.10481656348753361], [0.06783591358051186, 0.027092670713881814, 0.0371704941555377, 0.03354204510669074, 0.05579930865356038, 0.06545356399710141, 0.037759278690622705, 0.028405567300656152, 0.012315433160702308, 0.01397546046533652, 0.03306828484299683, 0.10718883135386052, 0.03298626746982336, 0.048113133187495896, 0.009710221896849332, 0.02884390174351152, 0.045099496510961366, 0.060118646436040445, 0.02421223374474193, 0.041171170005034056, 0.07606058757031157, 0.04216655570593092, 0.08170336139418426, 0.01553523750419939, 0.011749768201562186, 0.06498770593034645, 0.03682737103513172, 0.019536473555490375, 0.06745244060913402, 0.018006996251642704, 0.025298519608294292, 0.06646466216132527, 0.015087695642104073, 0.02954081192822947, 0.02144048166941972, 0.06760053306577668, 0.06750546921525272, 0.017342150676995516, 0.011682817862639505, 0.10102990579100386, 0.049545158361715656, 0.0057885311487611505, 0.04564845213486303, 0.037294753616856, 0.044652503359341816, 0.04371977215933223, 0.07823494428227987, 0.0073370988848769384, 0.0255744970373569, 0.010466940565815857, 0.04559924630748649, 0.04066154916560458, 0.03736550949754254, 0.004123372491449118, 0.053195134481234904, 0.05627569659883457, 0.0424293200335195, 0.07101058193873014, 0.07351787280171149, 0.021678566474527605, 0.054658320281774773, 0.0389296158907875, 0.0508633888356628, 0.05384894838977245, 0.013445807384297013, 0.025375580392597664, 0.04370760668309466, 0.1259803476052419, 0.03437006740920967, 0.06349587610231773, 0.01321999913817572, 0.0063757260514032705, 0.01326602187022687, 0.025391940200220675, 0.021065673152465495, 0.042163728841490326, 0.03811573940179041, 0.024148876358184124, 0.02764847516382654, 0.03808768143156364, 0.048310722584926316, 0.05193025820077427, 0.07215056673533495, 0.016429086869222023, 0.03924733936606396, 0.02631975503097619, 0.05120025301772741, 0.05145460569990739, 0.018875322439858032, 0.08479837193003587, 0.03888515214766226, 0.053548205253337665, 0.07540141487674368, 0.03917444226962905, 0.04004534251326996, 0.07554370038692029, 0.03386849432342476, 0.04142464551654074, 0.04871832349547937, 0.027483379385704478, 0.037709050135867256, 0.03953084552420243, 0.028717186970395908, 0.09633930264821938, 0.04772359279975776, 0.008336130206683471, 0.03582215642616634, 0.022446931595163002, 0.09577426683878708, 0.01331399716887503, 0.04786886605283907, 0.04645331176899133, 0.017503078936809496, 0.01132037592000298, 0.03663487995283739, 0.04900625764182018, 0.0637538600412588, 0.09033455228012416, 0.028768294611044472, 0.009386113078723992, 0.08072141287547928, 0.0048261777227444035, 0.02796985287850182, 0.03453477248249035, 0.03612281146248983, 0.0695679464467591, 0.03172515076585114, 0.04215938512295966, 0.05541605018680135, 0.08385681922757819, 0.030787357639881874, 0.009263491130343849, 0.038952307415104685, 0.05175742493461698, 0.04153323847980749, 0.03281931775892454, 0.016627955633485993, 0.03262964204975194, 0.03522229042925662, 0.017448077654285778, 0.06740325010351597, 0.04792455681449464, 0.051232873041543274, 0.0735759499272512, 0.040776140597318454, 0.03634575070933469, 0.058474886050868424, 0.03272647556338099, 0.052689206185600454, 0.018377505100121903, 0.010329046654665183, 0.02811498823575676, 0.13150596360285438, 0.0733084243632132, 0.040952865590131095, 0.03464040834636938, 0.05189255135314119, 0.02558875010318814, 0.07956779937470153, 0.042765012101059964, 0.07904730391718688, 0.04094947565106615, 0.020173904673767187, 0.06900052810388227, 0.06001912395379717, 0.04797836299985648, 0.048032383689837116, 0.059097964511883844, 0.03765693317437845, 0.04432519995457223, 0.04238194132584237, 0.06827148053074075, 0.011414546320485252, 0.019015654425827727, 0.03156411908416739, 0.013620038760916121, 0.05279169342811069, 0.023820295501800797, 0.0215227882407846, 0.02629511764333133, 0.03658016212284565, 0.1006253807234668, 0.06024359154605097, 0.029543043159308936, 0.027645638723286892, 0.04681414301176706, 0.04793130987954717, 0.08027907370799973, 0.03922962741325459, 0.06188431822304284, 0.02222197370663766, 0.06450793570688655, 0.07128920045591171, 0.05296352311908718, 0.041438189951042016, 0.03150705127946792, 0.014486453559760366, 0.011761547761007905, 0.047939901555617975, 0.032728490374621846, 0.04430089198473481, 0.04759598170377074, 0.023721489311766722, 0.03549427845545354, 0.033428579824225556, 0.037894757509592085, 0.041334116906528516, 0.062452540958240155, 0.04431817492830657, 0.019550209511972724, 0.029328758790788632, 0.10925170695108753, 0.0030516571414116174, 0.010043048795552985, 0.04536843550721965, 0.05157450612093653, 0.027385147761613614, 0.07266162398962245, 0.050210432945600444, 0.08697675826448588, 0.01924668164593318, 0.06109582222697716, 0.08000695161641606, 0.013484113695730847, 0.023711767656007604, 0.03635590137433141, 0.04099527238717964, 0.01551281602587551, 0.027705437631436416, 0.01733243859733545, 0.08177895128967301, 0.06829172823457949, 0.05949336930268234, 0.07815526347727546, 0.06757814031574996, 0.0219169040886505, 0.033711791038513184, 0.03155533588611551, 0.022071506377429734, 0.04062153639331941, 0.0685848334744092, 0.03346120750892066, 0.023351700585936348, 0.07905898675803216, 0.007980929231346256, 0.024288459493207838, 0.12186611837316906, 0.08819100762447042, 0.027025201350390434, 0.012235215136540994, 0.06280919319138893, 0.023338115931819045, 0.04285716864791128, 0.02416437623211213, 0.018279120258446184, 0.04008350901365761, 0.02900906072388734, 0.1386859234903128, 0.035519563187394416, 0.0782660551128849, 0.03916797648754813, 0.05306366996298875, 0.03355832064464208, 0.027137875647073793, 0.016790050262164687, 0.09647000490898087, 0.03641087584377777, 0.03672128700981698, 0.04882109802096121, 0.030455469198885466, 0.03700198545571297, 0.012998548017123775, 0.051862214271339684, 0.02502607767500224, 0.03287808819403572, 0.047061072301960764, 0.046320104400717446, 0.08634809119206283, 0.019615275274601676, 0.04325597486909359, 0.030273938919567776, 0.05378915522728236, 0.029907501828406128, 0.034629786537299236, 0.022443708280221592, 0.009365391357982112, 0.05428978985536003, 0.06083702240439673, 0.02051274153223682, 0.035008249293652274, 0.029015545658166372, 0.06441369923132081, 0.053373667441548846, 0.02601602798207633, 0.028923632344231013, 0.06647013202910462, 0.047362880300610304, 0.03249244336339255, 0.04677255209835787, 0.02882114510172077, 0.07123167491367749, 0.033961083709953294, 0.045108145643626495, 0.08192143598270994, 0.0403145419794225, 0.025298305103675495, 0.07844717361994329, 0.0047453339005099435, 0.10571878523595872, 0.039523548536723664, 0.009258048075641836, 0.027035480335114465, 0.057020127217495636, 0.0425480866444207, 0.07586161921461744, 0.015916507972794917, 0.04803721004376008, 0.034101614878783305, 0.04636419659119941, 0.05106553645624269, 0.03867162812140681, 0.040595512386531606, 0.009507834873793107, 0.014576141388275692, 0.026098125794481848, 0.03859625273053685, 0.031175792945789236, 0.03568271693262843, 0.023632626942989808, 0.08517065235683996, 0.02926098299212754, 0.05366415649111714, 0.031153222080320123, 0.05597693763012367, 0.013835579513632243, 0.03478360933161551, 0.02705554800829099, 0.016934076707149227, 0.024314320706311735, 0.02848381743646197, 0.03545531905406425, 0.036791449172362205, 0.023001246004095, 0.030822174420820612, 0.050085066487231565, 0.025061582019853017, 0.05143929160230103, 0.029079397171435338, 0.029315030495185527, 0.03615263143494245, 0.05830980176406522, 0.057119071303356084, 0.2254544667178585, 0.11274607146098731, 0.13804087745806864, 0.12579487005789436, 0.080061060406508, 0.18487013155414214, 0.16488740220665932, 0.1725299566263153, 0.13733089781336247, 0.1344410303018747, 0.19732148116154058, 0.22493489056585297, 0.23232892606287237, 0.1821010761083134, 0.09936806956125845, 0.20482163515783128, 0.13768398773766335, 0.12292603165992808, 0.16067093088021203, 0.1265140810620881, 0.2116146746782526, 0.15210154796800307, 0.16882492559811763, 0.1012838562770236, 0.20033159383362342, 0.15175844783023482, 0.11311574718884884, 0.09232677158809478, 0.11649915152379584, 0.118035877934627, 0.13392510072838876, 0.16777454244513668, 0.10609809068902847, 0.13436324173404326, 0.18347142354374935, 0.23809946803075654, 0.2072227385736281, 0.1047421074021728, 0.1226174514440279, 0.1888181043848876, 0.13738263939176837, 0.16449488939777498, 0.18953766012864728, 0.12902425241566476, 0.19098869194426846, 0.1620555122292811, 0.1376712553563618, 0.05793036224560873, 0.17011992062532133, 0.1856258926132033, 0.12339398114671632, 0.23688434533053832, 0.09223008363117134, 0.09560228009978611, 0.2768629807378015, 0.130044512991463, 0.13889670492179934, 0.23035997284516213, 0.1792172913349444, 0.11117711573118165, 0.15453638989598523, 0.10795898720501892, 0.1466646526129015, 0.08565864270372738, 0.10422477588778543, 0.13781341063159128, 0.14391283414536907, 0.2916723183326183, 0.15288410678265557, 0.15852462830803088, 0.21672768338072687, 0.19838292662414814, 0.15101606266633158, 0.042239494937201666, 0.09705785481679825, 0.1316779809853723, 0.11235527468905335, 0.19949096555431045, 0.08403239125806479, 0.20480688030440963, 0.11060432711195563, 0.2850313779086836, 0.10629229397783357, 0.12700936456601467, 0.18596266486471702, 0.2754448600594075, 0.13237705153803672, 0.1195677933132937, 0.12462845522790186, 0.20003764589707698, 0.17381732141779316, 0.20348919375288874, 0.13522124488747891, 0.15057058253836247, 0.1111771080703024, 0.27877764896519724, 0.11742474661479074, 0.157692426995885, 0.16194983806100585, 0.13591870665550232, 0.12662098863192145, 0.20631628801986096, 0.09311375839094962, 0.3041337190135833, 0.15080105242950304, 0.0787331389203187, 0.1284084019942149, 0.1527085194304105, 0.12560127963942866, 0.1171007986751295, 0.14815910629207088, 0.14089772658001992, 0.08905797400662015, 0.08458439591190509, 0.12757113684088955, 0.18413321625801826, 0.22246002820470642, 0.09330418486628803, 0.08492360432301799, 0.11882846484020834, 0.2219830771848079, 0.13028478880803432, 0.16268099237593914, 0.16961496143091112, 0.17553303661125322, 0.1657007577558679, 0.2298342679897624, 0.14076418213305936, 0.14021180209613618, 0.12333290861739267, 0.2485450615565623, 0.1414731198981885, 0.22613827679907123, 0.0975724820408129, 0.15155770215055636, 0.2048761193310061, 0.18202691879724303, 0.11588054318581859, 0.1536884684596331, 0.07629268922873082, 0.13889998377811524, 0.15857555783323704, 0.13211189318568478, 0.11275915624273401, 0.10447010022377777, 0.13000643842162626, 0.11011874228115044, 0.10205149169891112, 0.16263092086920816, 0.09984254611716156, 0.1477537691713341, 0.13834608688710198, 0.1884598510279771, 0.19423669023859888, 0.14962821778270508, 0.09502239750638124, 0.1588070696039546, 0.12551900179636094, 0.10942324935909241, 0.11901340612600889, 0.11819268847184798, 0.08463036884824116, 0.09757369245973327, 0.19741934123298815, 0.2128218607075753, 0.11653167195618154, 0.13179025883155485, 0.12321862362084851, 0.21284427644023973, 0.09837613891690009, 0.18309748070614953, 0.11118975618193228, 0.16435633473578962, 0.10468773048130736, 0.21574561994883323, 0.23188442652744634], [0.027892355424081607, 0.05769244214940456, 0.1100241840486565, 0.06954441988660444, 0.03106822079468158, 0.06172068184241653, 0.047410232195210074, 0.05177204955309149, 0.03962561826131517, 0.060184238884117336, 0.06860793102532625, 0.051368102881937265, 0.017784214052822322, 0.048999925925126, 0.036968629987489794, 0.05902954902980597, 0.023364086312452154, 0.0517071733972238, 0.07649703552165339, 0.029128677692384492, 0.03304277794555791, 0.05156514835694144, 0.02560866264356, 0.04394611666700052, 0.037525472486571926, 0.012725610999510655, 0.06294859438053062, 0.09175916172323689, 0.0131190727998112, 0.02386031593496521, 0.02270829972750958, 0.03741050950221477, 0.02313055015439468, 0.03858133699865111, 0.07014261964227884, 0.03338096745973153, 0.14221558167088416, 0.011572996285864183, 0.030367955144855286, 0.037326446674283476, 0.041829530645402214, 0.06232964130298746, 0.019261264129571857, 0.023673501564189795, 0.03870933113860027, 0.07567570499715305, 0.038463708028317466, 0.04740079782242256, 0.014546150003650017, 0.01713621283641025, 0.03106349020174915, 0.022955849548921953, 0.06751576543695505, 0.022726634126757423, 0.01250858786666105, 0.08014876215207963, 0.0382878563757385, 0.04075583926732502, 0.03235264380853022, 0.037450016656469916, 0.006380062109054697, 0.02848376381030727, 0.08138438536515159, 0.03653778213887446, 0.021256599500174486, 0.03419379440827235, 0.03944891625114026, 0.04074712501718633, 0.023216317527957504, 0.018463090527802706, 0.09715615155836267, 0.039816056227972435, 0.03441558069279117, 0.030852877309605963, 0.03600070087779914, 0.05054188088604039, 0.03877818329079497, 0.045443611715229294, 0.050027544775436965, 0.026259726296449383, 0.020303858083582694, 0.06272865819834894, 0.06398131920685692, 0.0626816357215566, 0.011258573691931464, 0.028528468871128657, 0.055785856149610014, 0.03624257781813222, 0.07464634329681435, 0.03211998482114606, 0.019148503647997014, 0.05995746153677183, 0.022694071559535883, 0.016483971323337288, 0.028822857308231538, 0.06936662620113743, 0.010132127584168508, 0.09914055676950563, 0.011967749901927047, 0.047082381037574624, 0.023750470417942253, 0.09829406025669268, 0.07779840440038713, 0.02568737817777982, 0.022343747212641665, 0.023246126009091254, 0.08897738921786509, 0.008637052416170557, 0.052026540131097844, 0.053615398825176304, 0.04187254648235056, 0.03048541366062578, 0.01586719968115851, 0.042055289095808426, 0.01962101518837435, 0.03727138793516544, 0.06724142169039096, 0.021052720520885724, 0.04810734539322796, 0.04402923337634533, 0.06610414118415887, 0.04725016961475054, 0.03788595898978172, 0.054392162184681625, 0.020945927864241026, 0.0312168073780354, 0.019720541501057245, 0.0862726851576759, 0.038545269579175985, 0.07034339596547427, 0.01223402770025836, 0.026824168387740373, 0.004985852471192278, 0.03399495628752536, 0.02415613121082706, 0.028522378472130627, 0.06778883747756481, 0.018607356375263586, 0.03613069450723068, 0.04606642587591083, 0.013408784270136347, 0.031007571528936108, 0.036703552074369886, 0.039378635344966766, 0.03710194460807308, 0.05856110541630657, 0.06390792798371085, 0.045655829561573845, 0.06830728748032162, 0.05963886472126169, 0.023044604665389466, 0.00907260979030041, 0.041735374609068523, 0.020034968883039492, 0.06784067864740087, 0.0310092703289082, 0.039409903223596277, 0.063787043139699, 0.02586340028492193, 0.03257334990907581, 0.011595094092040053, 0.016074694595449877, 0.029031413254298033, 0.033426239425616885, 0.032648702317308036, 0.007074647216922454, 0.03999259352924363, 0.0031627281597109455, 0.04130140112172212, 0.04575643222779036, 0.05223048422786017, 0.01974868182573588, 0.09021227698652975, 0.07870825638453807, 0.01009931508076167, 0.035488050160629135, 0.018175522188445734, 0.08248814952469642, 0.04452876866825166, 0.05676131973403597, 0.032888572107279496, 0.02276095486576519, 0.025450381217524413, 0.05323395598679782, 0.013364144326788525, 0.06843206022054919, 0.06814896008901059, 0.03869464523309181, 0.01034618308392143, 0.015472311999708896, 0.004069041535859147, 0.019809417276372834, 0.08018774836654625, 0.021404858580940676, 0.05797414034004173, 0.01719253753582316, 0.032292088388555476, 0.03540814335968706, 0.04677133401855827, 0.03699567672165652, 0.04800177847726211, 0.04511538517451094, 0.07354943562419185, 0.062372519244109435, 0.013634487179168051, 0.06362565522713047, 0.02747103770924432, 0.07354133041395296, 0.041888921611732056, 0.03306746512891785, 0.0536937159936755, 0.03371287888336567, 0.052192313897032896, 0.030374509027047508, 0.053082450608452486, 0.04160955998926394, 0.050107072362856525, 0.030431699405814853, 0.018167824920026526, 0.011650428622810832, 0.02510171736620607, 0.07092307171513958, 0.06752136553968154, 0.06445457768296042, 0.0060052081056299715, 0.020685168771794247, 0.03505148346565905, 0.06935384019368118, 0.015163755724056354, 0.038633630160362496, 0.020502728763066476, 0.04037801236394913, 0.02471563586544606, 0.02609125207058124, 0.05526187882247952, 0.05590251601871945, 0.06352242487933367, 0.05913977376035145, 0.016673208447173238, 0.009018741360294723, 0.05250349498143601, 0.017993718032695113, 0.08080510798120692, 0.041379082437244155, 0.019755331468918634, 0.04940591039015882, 0.029135124322267312, 0.08822413326631631, 0.030595008283853534, 0.03679477782439321, 0.010743787504672524, 0.07330424152314663, 0.03414824282029464, 0.007896962164405493, 0.05800685995528775, 0.03081348123809984, 0.01562916084132608, 0.03766787290993718, 0.02607512591977514, 0.015238370772661462, 0.06890541062720361, 0.03262715992487727, 0.06440962364356365, 0.06478683767660011, 0.011929253983731953, 0.08786571137006245, 0.0390625934326841, 0.05601077956417876, 0.002526421036060539, 0.037149583785644466, 0.04262389104452826, 0.034496299546932986, 0.07122582200193597, 0.0236084281406816, 0.02151092728449693, 0.053690659302857616, 0.06342488656481428, 0.0710799435393945, 0.020934294819110827, 0.04963788564407057, 0.005293544025100287, 0.04098525961800929, 0.05553776240577141, 0.023779656452637528, 0.03807882162471933, 0.09372674364356265, 0.02382515824490017, 0.06387941036072951, 0.057391947991545164, 0.008400829204718673, 0.0381064505857085, 0.05884659191172931, 0.041490375860444004, 0.04629451323360686, 0.012977233535850482, 0.09895777585165155, 0.04141500430001367, 0.10248545752537828, 0.037743252131246754, 0.018720247091785557, 0.05007964641516728, 0.037451050875167695, 0.018537782185200243, 0.07610923415350337, 0.02469426392757845, 0.07428541629304809, 0.02282995832032494, 0.024500981859502294, 0.0309300032113829, 0.05762271665697617, 0.014802268518495464, 0.08656341552494035, 0.0791357564289243, 0.024990916154497576, 0.01116954852947064, 0.08402361189045253, 0.06659737157244837, 0.03885001169457551, 0.04110633215356258, 0.05647366137934789, 0.025061214297649362, 0.021945622809711966, 0.041399107975584847, 0.03529664309274766, 0.08718842835796457, 0.04577412885884124, 0.015514352032163692, 0.015459164015708432, 0.03296389004155513, 0.08394232230080713, 0.043017047367268996, 0.03806019419684045, 0.06425493133945331, 0.042075452529975486, 0.08152564431750968, 0.047217917313138326, 0.04267876975298409, 0.03008343200499733, 0.02416333626775492, 0.02988666040642608, 0.022829119454047853, 0.032298251565906315, 0.01871981999776777, 0.017427847187425342, 0.03083815118448148, 0.026629068776063865, 0.026659643345121897, 0.029283228270228834, 0.017721105644839908, 0.0799656518164181, 0.05569001471984291, 0.04244482182266732, 0.08137474031818491, 0.23266456450425813, 0.15729548619879832, 0.21956262238804372, 0.1818002946674824, 0.09101119943924489, 0.14691631249602766, 0.11371855113294818, 0.1121974299331346, 0.1309162137969848, 0.1524378452450037, 0.1666542154646689, 0.06863518077279292, 0.1401286202693178, 0.1087979683952947, 0.1397233750791319, 0.17050524752947593, 0.1377622972452833, 0.15144658875801872, 0.18438708247436633, 0.1472137537935088, 0.15263189531622395, 0.21006564489535748, 0.10050701247828622, 0.20401978624924538, 0.09987348840842325, 0.157078085767646, 0.14983837102209369, 0.17674828188553934, 0.23688448322636468, 0.11203327261271978, 0.33624371213297694, 0.0798877100310018, 0.17731924721550557, 0.17319381777797976, 0.1449240702054193, 0.30326620104812807, 0.25239177288547643, 0.1012715605658389, 0.1269518696672974, 0.16865163650964538, 0.10685181395421106, 0.11565299975054881, 0.13544448290861424, 0.11427464669630413, 0.2221483223500752, 0.14939626168099143, 0.12297473186927459, 0.08292254436040118, 0.1458748466064853, 0.15725751888127099, 0.16262027224706066, 0.1533103887472422, 0.11278792284429075, 0.25505913782023615, 0.11486766003673116, 0.11462004509784522, 0.09437921306779308, 0.1485535802860414, 0.18034383894935732, 0.1428025122731924, 0.16127808620372128, 0.2027176206390704, 0.11290745554311622, 0.16423011408938518, 0.17452420606728525, 0.18134361433406032, 0.11927805119945158, 0.19276344187317357, 0.134760657505643, 0.1857186658608337, 0.22594002856602594, 0.13832324214519995, 0.14106191454395173, 0.12553137411633808, 0.16756719308755091, 0.07241443039909487, 0.17034236191501542, 0.11399143931245613, 0.10484624939459948, 0.18177453879146807, 0.09874337848516242, 0.2071301032218241, 0.11564126328354883, 0.15634051163590726, 0.12862510528535614, 0.15059267651409874, 0.17584186197528917, 0.1340364133037867, 0.18461364531709304, 0.13566264942769082, 0.15986787155270576, 0.12235233905695139, 0.17116659591274877, 0.08592983016804343, 0.36843696368798134, 0.17555525316105736, 0.1651396596383664, 0.13350871661978383, 0.22826718917537123, 0.1547977944175082, 0.2518759045990244, 0.11905646026735345, 0.1397899327979934, 0.17249125386438063, 0.22485969137520562, 0.25696084383995305, 0.10174862649892608, 0.18002638743529398, 0.20034771232355028, 0.11425611502941578, 0.17974650487303737, 0.13863062726393824, 0.09705339618507894, 0.11631794108618652, 0.17186421089835707, 0.10405602970070417, 0.10366915529894252, 0.13865498885993036, 0.17256553374951886, 0.24234967786938916, 0.19435906512362344, 0.12892053943247567, 0.09547812022989798, 0.12453706859941445, 0.0868724400718366, 0.12165666993467078, 0.23246979431038906, 0.21095888809331004, 0.14200043353822925, 0.08084540420602407, 0.1581643984442757, 0.07784758724512593, 0.13896511657343757, 0.07724603202434317, 0.1726796195632027, 0.2749053196560952, 0.23235639797583704, 0.13548202121690398, 0.15178618021309376, 0.13610748604180353, 0.1430614653133577, 0.10524345832245965, 0.17400357271394423, 0.1582374525887351, 0.1771712390285346, 0.24266778821906737, 0.1273460678696152, 0.21452082921901058, 0.2331343296194269, 0.12621958920311543, 0.13377818038627026, 0.18759286932406888, 0.17480359833327033, 0.0974993895919573, 0.08256895647894952, 0.12496243125849194, 0.12981505433638252, 0.1591066865911407, 0.08617690884538236, 0.17170048258717985, 0.18018807795259262, 0.08635023623825082, 0.14718246676268118, 0.06884158018135256, 0.1669982349079463, 0.1221614835723754, 0.11938263752287435, 0.12998940062619027, 0.11708846465954859, 0.1534305113337694, 0.11020911767357781, 0.1320382874579199, 0.13306631616527034, 0.15662742688530878, 0.11129107897079761], [0.0312627132816781, 0.060821279297552766, 0.050069001623459404, 0.05198208787929147, 0.026649061755667773, 0.016259865707627708, 0.027479792178999034, 0.022860950407301708, 0.03378370754240501, 0.04892442412974854, 0.04216276357070573, 0.042909691635999954, 0.0640189341239391, 0.03825679151040893, 0.020196601943743807, 0.023266720367715727, 0.01237603358834261, 0.04176770734991278, 0.05388308909811801, 0.06016847662507527, 0.03642213350582508, 0.023376989148316846, 0.09323603368454403, 0.028014540702344912, 0.017460086082498875, 0.02234395597160103, 0.02834031576170556, 0.051509239260227456, 0.03515551437533671, 0.03716685140745775, 0.018988167191104546, 0.05141564246807849, 0.027651223504254897, 0.02974796593339453, 0.03776857133714422, 0.07809046009976058, 0.03380346494997221, 0.008027604095742949, 0.022319632680005124, 0.0759415758112746, 0.07655501305576294, 0.009880935014676183, 0.02956302656281379, 0.031101984204724435, 0.03634666235396459, 0.04935130364291611, 0.04895982505272954, 0.026410969289680643, 0.022851686489077348, 0.04284472354958135, 0.045560256262580236, 0.06816699379874815, 0.04070200626888583, 0.028228124100414496, 0.05537530580054849, 0.049654789374119816, 0.005952924998822592, 0.05135161283936712, 0.04248608714870868, 0.03823005121141192, 0.027393210837016665, 0.036866169558056903, 0.016063791249067556, 0.03106862299084183, 0.03502227253310623, 0.023766556349132332, 0.03197981754408008, 0.023582716314722935, 0.05646415039776795, 0.03623934492709176, 0.03340555505166131, 0.022536604101919842, 0.04539560481545426, 0.021015747202440135, 0.03331843936335176, 0.02641404704791644, 0.021049225244731195, 0.069327961743599, 0.08352687281946983, 0.03784981496151417, 0.044200603414567254, 0.046434262992754105, 0.04718238232477058, 0.04912071883858693, 0.0485132992147438, 0.02893484978666229, 0.037908868849157326, 0.04385620092732772, 0.020461049749545997, 0.03849495292430924, 0.030365227871844848, 0.03549902820058408, 0.09440286220201562, 0.05524404046516265, 0.030753873851931388, 0.019372310489416122, 0.07500689491749772, 0.04102069501494689, 0.06580293839496952, 0.02479364085311611, 0.029788641371734204, 0.051347705790953296, 0.05248426234409694, 0.019485576589020993, 0.037659871121568066, 0.06302609949583007, 0.024700517120260387, 0.11885733869407447, 0.005238921477294137, 0.06919290810342758, 0.006615541736415077, 0.020228216477159052, 0.017574148913544994, 0.01145672807920604, 0.026612684070583315, 0.07514360330758557, 0.02977224325971498, 0.09864612362317501, 0.04837285231558546, 0.04384958958854118, 0.008166037620075287, 0.0666823000797341, 0.013242306660920864, 0.014415152799037677, 0.03767778608767736, 0.0389147805981338, 0.11856134530277022, 0.04576614239223061, 0.04805873328399274, 0.04782609536402649, 0.015329328391911283, 0.044378672891687, 0.018584147741597508, 0.032542120334842516, 0.11274541262537242, 0.028993373158417886, 0.055098721246805885, 0.012532590358938663, 0.0243064395767907, 0.020135215318371213, 0.019970247859976465, 0.04447973521065809, 0.05122762533926195, 0.0637244729084834, 0.013109340610343122, 0.05186116856132304, 0.036253054070496754, 0.04631351987500826, 0.02223013828869068, 0.013634885544888677, 0.005701247399913208, 0.06670380416776865, 0.023167218952890367, 0.08522384184142275, 0.03182497968326413, 0.045547757538095604, 0.02475651814752529, 0.03070644726375899, 0.026653361424142798, 0.025697641840745366, 0.054797909162457914, 0.022625384116244894, 0.006298812260220369, 0.03806204812961721, 0.08095614221547881, 0.04975938335842183, 0.02557298592892626, 0.03470012490006705, 0.050756910275067055, 0.050893974896039695, 0.08143429599341848, 0.06371826759629673, 0.03938541139265703, 0.041200384768026496, 0.01844460291097001, 0.04594618454575539, 0.04920971527275059, 0.08235551672236574, 0.09186906469685417, 0.02583670212076076, 0.04546368321884544, 0.03560886222628817, 0.021133065907164447, 0.06128355973370134, 0.043630162854829145, 0.02253974314718958, 0.11631211115708275, 0.018945235623827866, 0.12308739275941927, 0.04663434600637806, 0.03792777206868895, 0.03494719974696636, 0.04167852322420767, 0.06867930743723147, 0.02351261543921165, 0.020766069571818077, 0.014216256264086454, 0.13752913072464928, 0.05752179989471071, 0.03167932913188012, 0.017384737504706267, 0.07913993160811164, 0.03919007046328437, 0.05083971288836291, 0.04249388209333824, 0.027968933572992686, 0.04205169997388317, 0.11743723384795651, 0.05655173339971131, 0.053076965418914636, 0.005882076229975229, 0.044366675954792774, 0.054160987492650754, 0.011863681645463071, 0.02243068287028901, 0.07115227756120505, 0.010549376414517963, 0.029810631925600673, 0.02563540294255701, 0.06973117680078553, 0.01744644205656744, 0.04609746775860268, 0.09689684611775222, 0.046699785236870094, 0.04095028004338665, 0.03558620134548795, 0.03151895054015181, 0.022035540464604576, 0.037175638435949246, 0.11005917128415839, 0.026633211396514412, 0.0372793092843025, 0.02389497758309928, 0.03958625283332602, 0.060555760883876396, 0.03973487006019681, 0.05093949201006082, 0.03123127877892506, 0.024125468541657733, 0.04274718140462234, 0.07417437184842364, 0.03261810093517265, 0.024698178636871522, 0.014209888158215871, 0.009995475693065073, 0.024856827785110763, 0.09382847245902785, 0.05574018581800404, 0.07163377148249457, 0.032971991421354395, 0.008153038065610154, 0.013542961697244357, 0.004005689655558297, 0.03677969355316412, 0.0486217198082276, 0.01744352326157593, 0.03501103402325704, 0.03419415830003639, 0.052491000087390986, 0.06216328147979033, 0.0731598569320575, 0.0844293014116345, 0.054346940014511354, 0.04183831001301447, 0.06821125069813383, 0.04794534461031999, 0.06850537483490284, 0.06385520198232224, 0.0071652687150954965, 0.025248239342603954, 0.038672865353404515, 0.017498212363270503, 0.029519581716627847, 0.006573228785137256, 0.10901847148254033, 0.11074271323459764, 0.026811131486488927, 0.0454753086030964, 0.015711582325879606, 0.04546698888823871, 0.034152483116955526, 0.03131192485471407, 0.007061281376668523, 0.04105813373180647, 0.022512351673456932, 0.007037505359133526, 0.012619833409365629, 0.032463132839409575, 0.03753921993437313, 0.04109806989529922, 0.036239459840280396, 0.0898485384400814, 0.007484610072307049, 0.03510895155129894, 0.06893403933293397, 0.0067396230822909745, 0.05065124376767105, 0.022397610854597825, 0.02984044423717405, 0.025644590251988945, 0.021381040907374794, 0.047802836934645335, 0.02691241788617786, 0.016304158996189796, 0.1145104179158807, 0.050315291230236335, 0.0039056931564118717, 0.02870951268461443, 0.038795952700198665, 0.019313976724421787, 0.035874208270181576, 0.06499054811654553, 0.04936281411397842, 0.033885091618304296, 0.06065302723718267, 0.02927881177334536, 0.023365428881539453, 0.02557981751799103, 0.026566307022867185, 0.02480563204435091, 0.0636931169297426, 0.028644956370455124, 0.04111208164343431, 0.02818335966777898, 0.027180481626982653, 0.03893093356201726, 0.07125883273059322, 0.03028216478865474, 0.10670462548131905, 0.0405957077389523, 0.06587001705361951, 0.019105608469896743, 0.03970956617605783, 0.010753713131341483, 0.03353068019233404, 0.03189184192207552, 0.029520809372526505, 0.07035364622190114, 0.06996737702959968, 0.012832138398211571, 0.0609516483100672, 0.06047517992556096, 0.017918063019732797, 0.11012044299634234, 0.04739082335764843, 0.007805107743479312, 0.009162598308326017, 0.04547952591711956, 0.039551606506950436, 0.02665042347695318, 0.07850279926412529, 0.043518674079208605, 0.10778824918933454, 0.15103032722348167, 0.18717746580800704, 0.149171537449283, 0.17293360835361868, 0.13243122927604184, 0.1682954822336474, 0.1269346863151558, 0.12949515134096146, 0.14736620529044062, 0.13878975904756977, 0.08032159924867653, 0.2111333109919102, 0.07776032983055038, 0.1281017676416424, 0.10364870841224348, 0.11027042769015798, 0.16715961899007523, 0.1645815186202526, 0.0974724003143849, 0.12407317171774565, 0.2627839394394429, 0.3043954146485175, 0.12851054449715923, 0.11531473362758277, 0.1418045754995077, 0.11494780815536938, 0.07388589377965658, 0.07988295262499202, 0.09439969059800911, 0.09842873851378119, 0.1706727603149991, 0.16636135537297497, 0.13850388567774527, 0.12129835529072631, 0.13233243457732663, 0.15469818766559326, 0.0802904347919168, 0.139450172803575, 0.16270478706686728, 0.13287447242727204, 0.09300227727620833, 0.196735423899466, 0.1582848121442141, 0.11296459804138831, 0.13474101501126445, 0.15358835608968813, 0.08502004713180565, 0.08298641311064844, 0.11878360273136247, 0.13093902789536985, 0.08196323373985868, 0.1640077494084835, 0.18159547340004675, 0.12765144583799187, 0.1723943130984422, 0.1288379551542382, 0.10917987088642775, 0.1693897775464481, 0.120810778631318, 0.07393044945333274, 0.12184919549092171, 0.12275684880272997, 0.1352428485669436, 0.11429730757710435, 0.13420458492492476, 0.10356911187691074, 0.11239711841147755, 0.09366313536320964, 0.12347289586379645, 0.2146051601777154, 0.1420408216935973, 0.1366783900847358, 0.159218673323912, 0.18030731187712762, 0.21491266787052157, 0.10050946395964393, 0.11946990259832914, 0.16376623252947486, 0.13536916114389896, 0.17952453855785633, 0.08877600002433024, 0.08053448742195483, 0.1308772352433974, 0.22378419586006673, 0.12400267630695336, 0.1003077759918186, 0.14283928449355787, 0.15123203817394473, 0.1991285906443673, 0.12178501264462549, 0.14596872302072664, 0.1169375223558276, 0.2578739287151445, 0.1281760398659014, 0.07491623607253836, 0.13342168903158558, 0.08859608427531297, 0.16254499644762085, 0.13380286373919056, 0.0985349795871204, 0.19311596489241048, 0.13696910513024177, 0.18419859420147636, 0.14359604146692062, 0.1150913653715003, 0.12251854949300328, 0.24683238007128241, 0.10563411719856725, 0.10539284546769435, 0.10931656395475711, 0.26049952653627245, 0.08811244530783546, 0.1357003715970824, 0.10556056509695708, 0.17902313401141476, 0.09583654978703107, 0.25440865256372963, 0.2411407604813576, 0.10486380812982399, 0.12287508681296341, 0.08952877334048671, 0.15261810573358692, 0.1681103187823488, 0.16118912807395383, 0.15568732974990723, 0.2458203626015494, 0.22071710156817592, 0.17809814412988004, 0.09860496171900342, 0.06961452459255535, 0.07428266603739993, 0.08622094357927, 0.07696211983960483, 0.1609204150736332, 0.16529082410758542, 0.11551659779563067, 0.11413429172769671, 0.11076221783314982, 0.10351109603840498, 0.07223687420088439, 0.09463271922281674, 0.185594299147206, 0.1846733235663945, 0.12837599647501785, 0.12620063618786875, 0.12334770943608978, 0.2138641846155928, 0.11663799729919243, 0.13446362989564098, 0.1500403577642095, 0.11667408004042604, 0.20245722735360747, 0.1899853925551138, 0.09103435827719589, 0.26276350021362305, 0.08177775619251114, 0.1164402470232979, 0.15176226294809772, 0.12873557516403739, 0.12211142738740291, 0.14878371309849525, 0.1396270165400159, 0.07066327597825758, 0.23921731288634965, 0.10514582041651012, 0.07931866758172551, 0.19127107195315823, 0.24770052622883554, 0.11684609742294397, 0.11027661001970691, 0.1333372354988129, 0.12582326893724743, 0.17557115714636543, 0.196039647524876, 0.09599689198958297], [0.01538077694168615, 0.040301258014815475, 0.0229881267483917, 0.030331466377021808, 0.05282666917229372, 0.06986026261602679, 0.043127800698482224, 0.03500119362386965, 0.009540371585547203, 0.027387191301151633, 0.027809428321498058, 0.03045853355058259, 0.006516237110425268, 0.06152372446752364, 0.009976275614462793, 0.02105440591431914, 0.018067911732941866, 0.013516916623038631, 0.05961624980573693, 0.018446391726273204, 0.018565955068615657, 0.017918472876772285, 0.05034975369551009, 0.03645132145574016, 0.045505649515337525, 0.010603999441129067, 0.046643087069594094, 0.04425409550388013, 0.02318989324022926, 0.04005358178889559, 0.08627897473953425, 0.012114965187896405, 0.07706937980988333, 0.07073194043891085, 0.053958108258103175, 0.03128139433571168, 0.05921396554537839, 0.054209408079904896, 0.07150371273558948, 0.02114898712945081, 0.019375838324307434, 0.010222046196671023, 0.0320997696760441, 0.043207661534148845, 0.06094794044451368, 0.04050228714702591, 0.05119772109713766, 0.020097770855852196, 0.02768405994790937, 0.06053458238320966, 0.021653113203243386, 0.010924802589861136, 0.01862640706672063, 0.08847724871649858, 0.03425443026747915, 0.03820554022827456, 0.03555737345689728, 0.06592386537381718, 0.010903527370593961, 0.04566914033925822, 0.04500587290573505, 0.03639389167449648, 0.012401909165595089, 0.07768274044557925, 0.05711276639973926, 0.020642625994139144, 0.04220651868250101, 0.023403287031537583, 0.011810193386589809, 0.020578764904771122, 0.038001216917989716, 0.056945468118834885, 0.05432073597706134, 0.03613851626493758, 0.037925466144036864, 0.025232952058074937, 0.024576619635486317, 0.003232456764371525, 0.019925048672443917, 0.008543422107674904, 0.03213927299985963, 0.08539993481169786, 0.03383970856966992, 0.06351864423542734, 0.03540199167365509, 0.04501162239560678, 0.01265862810185119, 0.013710099099684629, 0.09745497181410752, 0.03398362201668563, 0.03766969236875734, 0.039188055652043516, 0.09652432054281236, 0.040831287436547785, 0.0196306353374835, 0.05963036880618142, 0.019717844871563778, 0.05341229359469107, 0.011147995603330916, 0.02202129697487239, 0.03231379165945034, 0.01563247704442831, 0.029651141995864532, 0.030985791649248813, 0.033462651584657936, 0.0815390738388223, 0.006669080748613323, 0.043550374797515334, 0.04786858643074671, 0.04073798941868929, 0.019483035092332193, 0.01188785171947412, 0.024501156144505067, 0.0005082983202995703, 0.02969044805203955, 0.01255215528691488, 0.0384798571617613, 0.02093444229103625, 0.024066474025828705, 0.022882910317651207, 0.021414741115163893, 0.03667608399184481, 0.07682377968223826, 0.048386488680637656, 0.03955712234000525, 0.024935681215156952, 0.057743394657248454, 0.02026385297217677, 0.06855931508565141, 0.036487534431920904, 0.046915320243926785, 0.015799398984639876, 0.006500538532441903, 0.08253919396309123, 0.08056460233825831, 0.022695113439112905, 0.015873693233926692, 0.035895382940408685, 0.014199949125008238, 0.02817698007058953, 0.010349347984658615, 0.09389100055540762, 0.034247252023628647, 0.04188121476721379, 0.04332706782846682, 0.04287931241936261, 0.03593624607028981, 0.026404258359463948, 0.060133175293524424, 0.0237317223312153, 0.006286029125593844, 0.03956044333115701, 0.018535738645662225, 0.026805927834263252, 0.02452394151459298, 0.03248577456801169, 0.06965487444352719, 0.021489229759261496, 0.03718288945815256, 0.00799698068857974, 0.005354632833792318, 0.05336496851316864, 0.01911022414964053, 0.01198387222229353, 0.04514927690428111, 0.06721943496696411, 0.08792038706521835, 0.01731230006102593, 0.042516887713704384, 0.028325470892952818, 0.012739134366594016, 0.07250930272763775, 0.08780765722716048, 0.027559057381304524, 0.016870294141793446, 0.07483986476736684, 0.01895839126870757, 0.06286251674135847, 0.051995651465990854, 0.016064842704743627, 0.05529834460767527, 0.04679610164115026, 0.08670319592760456, 0.04340133622228619, 0.023275536124504382, 0.010563227284188953, 0.0201504796202625, 0.09682410606934179, 0.017169173769352418, 0.03472082459578111, 0.0369886938302267, 0.061069047454023556, 0.05568141921333248, 0.046902220140421585, 0.031205674205275796, 0.057328309067675186, 0.026192795109724807, 0.037431649698485295, 0.05844720729416417, 0.058595663642570864, 0.015232022776598892, 0.05073400807657069, 0.017521928530186415, 0.032492431872073686, 0.06083199303717383, 0.04016539615188395, 0.028142077104759314, 0.021940511088037205, 0.02411553812693925, 0.03243422834202647, 0.02444514171070149, 0.07518614417002087, 0.041815974719582066, 0.060921452954531684, 0.04483236165176477, 0.03087682521811897, 0.010468224720698933, 0.029234503163024787, 0.03814049936350315, 0.026701209360673547, 0.03168847622169602, 0.030754063458692645, 0.02816658808789667, 0.019883226017437635, 0.09065299204760983, 0.02288525646191932, 0.036350469810948256, 0.05006023757760564, 0.02994770803789218, 0.03232703348922153, 0.026438312882918025, 0.07399891473112569, 0.012201274568665654, 0.05649259141195686, 0.06630579084758798, 0.03562265946980446, 0.026260902241413153, 0.04724591782677078, 0.09299553570247467, 0.04011576897614906, 0.03709316141002121, 0.06631810188053117, 0.005454780635303788, 0.028046961543300462, 0.06546450373266013, 0.055071149742411035, 0.041044918715112635, 0.01716434358498983, 0.029280363101392027, 0.007791799359819702, 0.060126284332645524, 0.030384284308961326, 0.048769551794976, 0.0373033108189702, 0.03859357142280187, 0.02908485746311565, 0.03898485466056774, 0.029417128948074196, 0.09681841403606439, 0.01829817669556266, 0.026816806282788038, 0.05845631607958387, 0.034858954078968496, 0.02140276716090739, 0.03228824262717559, 0.07059934594097637, 0.05839916208999292, 0.011694089888835387, 0.03243383380674547, 0.03424603011338942, 0.03328369727598564, 0.04031348477808699, 0.05427924848552193, 0.07367711183765242, 0.03399541977071955, 0.07035570699841746, 0.06950700415238258, 0.04637022953360312, 0.011442001954081559, 0.01323591844524227, 0.06665383991334708, 0.10229057241832057, 0.008740072089788175, 0.05065530786410936, 0.021197547527751135, 0.03426150891989951, 0.08200180626684621, 0.08590673261712636, 0.044218315367376616, 0.01818419813418821, 0.023453814360583504, 0.00873503697690584, 0.04751587188952873, 0.05453235244438533, 0.05477723244938159, 0.08466468192636968, 0.014338401322733733, 0.06386275177881603, 0.023837086233881213, 0.0009144358233653851, 0.04426040806837621, 0.047336726058875365, 0.07647587617318477, 0.04381275991158139, 0.02582722752835722, 0.02427593395564585, 0.0249610138275931, 0.03329018221026467, 0.04058138955564749, 0.07847402500168932, 0.03656777448111004, 0.026188003229758432, 0.016280230239874894, 0.015898574812097416, 0.040735580072167425, 0.013190073828633516, 0.02649672708714441, 0.02507942803804913, 0.05866370757200545, 0.06122867336436626, 0.03381032143689452, 0.06742686859422153, 0.07586780920504563, 0.02882813756924964, 0.02915397200042442, 0.02799893740654713, 0.0490532418142163, 0.02256891002968675, 0.06605281329323208, 0.0641016026718482, 0.02359171976305304, 0.09801050813327875, 0.028185592814078255, 0.05451331132902734, 0.02852960076603678, 0.0698173463705086, 0.02965719983612578, 0.026305390882395932, 0.050471201614146276, 0.011491774686522061, 0.01595139753208646, 0.07362695606124979, 0.049426518155321966, 0.04646035211701547, 0.04403866774913284, 0.0197893304509982, 0.06528919983294702, 0.033282226387171016, 0.08094047571742728, 0.03658399639290668, 0.03881094504087683, 0.05729202714358127, 0.1704183118718286, 0.12133325825655654, 0.18320936018661146, 0.14836398884654045, 0.19126531097196764, 0.11577181232672547, 0.1284315914756829, 0.0954907606806486, 0.13149842529767944, 0.20535481703137198, 0.15948922493525092, 0.15090484202148455, 0.13679315005579304, 0.09234631449104318, 0.10585186236928548, 0.21186114048525212, 0.13597184251393044, 0.1261146504792475, 0.14531881999104254, 0.1426860362651848, 0.08203074140774627, 0.2408426450265031, 0.1840769547608591, 0.11108248855077452, 0.0890216154737338, 0.17970349669696825, 0.11123791246885255, 0.22393300077847897, 0.16867340872845343, 0.18944177656404435, 0.23832995324365555, 0.08815785899998681, 0.11014472798354204, 0.19965634861540413, 0.13213375733504373, 0.23716759867966178, 0.11727298459699077, 0.16979511466718492, 0.1611393323588756, 0.12490613911781581, 0.1434275021235789, 0.12205243861723332, 0.20732908689927673, 0.0991823775092921, 0.14298294130111897, 0.11169545848162905, 0.2767382003366947, 0.11161021587829437, 0.1708153292777077, 0.23866012181726196, 0.16175283089039788, 0.11645764488005832, 0.1423990903722663, 0.1638710486792749, 0.1398307959278745, 0.13552813970994565, 0.1298004833440627, 0.18464847167413082, 0.1437596012387545, 0.1365991919151237, 0.18139949278725734, 0.09757347795511447, 0.11703781092599516, 0.17752892548038116, 0.16799583460294432, 0.13317076459286675, 0.17416454310859406, 0.09590043385903682, 0.11169176593783403, 0.10482372640962563, 0.1302802382457641, 0.19565736965066005, 0.15800635450549666, 0.08859534883090565, 0.12232852138338551, 0.12919812373095943, 0.07068048997391617, 0.08958056088416808, 0.09937359305519251, 0.10495170905825593, 0.22856786336389281, 0.13024184191899915, 0.1841743705013106, 0.14150883491721847, 0.18990938131126667, 0.1661402777197861, 0.09005764979989299, 0.03881012915723747, 0.08630406411905443, 0.255857830446574, 0.14397620493846555, 0.08528971008115238, 0.16542233076066742, 0.19646432070482164, 0.18433264426646695, 0.10979956706925748, 0.1096787856471154, 0.21711979782389057, 0.17588753613733477, 0.09451902411397427, 0.17443350125705043, 0.10652325416524565, 0.08855053268733526, 0.19036039259404908, 0.13372358896078604, 0.2735974849952806, 0.13674514698645762, 0.1394659388930567, 0.08509251138856334, 0.08595852782168696, 0.1571657262261837, 0.1631992202131979, 0.10511627240527062, 0.10720275883232394, 0.14669016334078006, 0.061921393048138394, 0.13682115823030472, 0.24381963205674004, 0.09566143740929904, 0.20152765626628555, 0.13936280813669005, 0.13542143898385187, 0.188038855070068, 0.11323419970370109, 0.11038265191018583, 0.23160846633536203, 0.2442221499739155, 0.1739274848613047, 0.14181546926979097, 0.10515459978412237, 0.13396646947629992, 0.17214553370591135, 0.11484335972777299, 0.13842652611915143, 0.2678981892043545, 0.17030312289153376, 0.09731091664082582, 0.1849551519919788, 0.061370583491459976, 0.07997994701708518, 0.11831978245848611, 0.1698896499170411, 0.206792181838424, 0.23724192453007545, 0.17116952236861954, 0.20431047065123437, 0.18186185749307757, 0.15914284594116673, 0.09033668200455366, 0.06944307411510138, 0.36122476682066923, 0.1632451088798623, 0.19169098006621485, 0.23580532581094774, 0.14049948343346197, 0.17045241810621756, 0.15131005656815347, 0.13974962125141777, 0.12327513792702269, 0.13635188341140747, 0.1323687777884545, 0.09440951950607762, 0.16907071724774378, 0.13500856355794016, 0.11368192446928833, 0.15653485282053872, 0.1678335925023402, 0.15763546069783552, 0.17878255175967372, 0.1352816126159122, 0.15990540986099552, 0.1504160779257936, 0.35044716611023874, 0.11747507859141597, 0.10618940836960271, 0.1638161354968625], [0.05486929706568199, 0.037344380792590885, 0.029896041153058894, 0.002908520316029148, 0.015498493054521181, 0.03296593549631296, 0.0391165528356308, 0.017663227702160517, 0.03078466484082803, 0.0455102268906851, 0.09240534922648823, 0.0430836433905267, 0.09507609260899406, 0.00951741767611595, 0.06059969219589426, 0.037415753374056476, 0.020410876736165057, 0.03414964859163569, 0.05375938888098444, 0.034119192766205925, 0.028019602628304597, 0.026254407731035066, 0.04796650395878861, 0.029783587106653762, 0.027001787788204612, 0.05073387018074432, 0.07457147352397442, 0.07017506346587213, 0.08029555992013024, 0.023704348094460946, 0.027404052896365046, 0.016184166644609744, 0.056901157593294505, 0.023822473106725563, 0.05420507202225347, 0.05444568108707186, 0.0851870542992988, 0.05911761466714163, 0.02508442867697487, 0.10411227587610485, 0.05430997627216482, 0.0320965999872574, 0.11129207488509918, 0.1031615837447105, 0.006840441689541143, 0.07754711223946464, 0.06816542331850337, 0.05125182222635035, 0.0024942616226091502, 0.06328945371112035, 0.025269900478662986, 0.022829579106802424, 0.008663619387774699, 0.07254743858450845, 0.06690091092980678, 0.018331687296590498, 0.07634795481158842, 0.00745028502405471, 0.07470332491662234, 0.04860597287094401, 0.07421835295615659, 0.011999095346958888, 0.06518799195727033, 0.04460962541821984, 0.07319901934674672, 0.03274654706699714, 0.03247747400535211, 0.015029526586013456, 0.04295609741201324, 0.036621527040317174, 0.059668700015472795, 0.018583889186923063, 0.06523780299410706, 0.0328514896213047, 0.049387325097115777, 0.04100920369608268, 0.05730928327407568, 0.06980482083294662, 0.022650578832854668, 0.034735656057995175, 0.017048557056114078, 0.021905972013971018, 0.05043447535905627, 0.03413847902969968, 0.07058290569412132, 0.05166902221859463, 0.024412065864570683, 0.022087268636471803, 0.10412409661277648, 0.05221823065151131, 0.01969255630918328, 0.05589927546679974, 0.03660295706903262, 0.012834995906169136, 0.035906096680029746, 0.04557223404727636, 0.025136223881535476, 0.060720603852983446, 0.03709562821313739, 0.09725001265084553, 0.05663694152908941, 0.037627691598308664, 0.06451725133604581, 0.012153261923231186, 0.011716111086218828, 0.028572114815394727, 0.05916779725662163, 0.17247781668218876, 0.012005272888458304, 0.08270402544087942, 0.014300862056834084, 0.03226297704743282, 0.08468702105024169, 0.047685908934762405, 0.032989408430312915, 0.034579496695509845, 0.010847912260120916, 0.05819959618571786, 0.04858904232781741, 0.08598790729358312, 0.055039249841243996, 0.04101699097983299, 0.05482186473185017, 0.016376123380576892, 0.04923948927992775, 0.03976167930710701, 0.024940846562986414, 0.022924309709079327, 0.06024002157632382, 0.11171434254896258, 0.041525581431004314, 0.04042930195047971, 0.050133215113272594, 0.031897058980839874, 0.0715868332753739, 0.051123042846278804, 0.057079449235912294, 0.04012290125472411, 0.06065108903473424, 0.043745934061946413, 0.02350731794121525, 0.019668786516112667, 0.03469576202933827, 0.051672940758327325, 0.06467622224121325, 0.061316964997639584, 0.005218347707282632, 0.013566725744655537, 0.03334257496340621, 0.02406045640518348, 0.044513764836254625, 0.039673506417461944, 0.017413247466808366, 0.021998097917305368, 0.027240111995788834, 0.06801481809346907, 0.010732971300791589, 0.05468447835394933, 0.05113679029408002, 0.00929812596540057, 0.05738201949204649, 0.058608985911574096, 0.07531506910679803, 0.08907252201630224, 0.032916974817072196, 0.023967878509973808, 0.017803460096700058, 0.041145398807261264, 0.04558165692874501, 0.04815835152722655, 0.014680686534472532, 0.044399970135982, 0.045327373194478215, 0.11917718806334081, 0.016116381269849597, 0.08305423487458499, 0.05143804287898445, 0.07017254303660124, 0.05115851271717299, 0.016692211258135015, 0.031046917804727153, 0.045480540983619235, 0.12293390704378968, 0.04089659260165307, 0.02794843880579837, 0.021164850895142844, 0.06550591844584673, 0.04636152677478329, 0.07583776323665535, 0.03715634834201586, 0.014120671473773978, 0.024252690848023183, 0.029192981197528785, 0.01949365498618253, 0.011542030054354861, 0.07225227256816241, 0.07176854933101325, 0.04326092379708444, 0.038821700915333726, 0.027495192461496884, 0.007841729140284682, 0.04476272042900805, 0.06703476181193706, 0.02046024727244531, 0.06770833695848143, 0.07053272693508095, 0.10386531211195454, 0.00929415092668346, 0.03611956324969088, 0.015906734606100908, 0.05182161544179244, 0.06095114269203717, 0.06972686372577183, 0.02715837999036716, 0.01199795004551209, 0.037652401764306336, 0.034811399171068784, 0.011601799276597317, 0.02900980765961351, 0.050202078756786166, 0.024652152074380748, 0.061269957842605735, 0.07337127421652118, 0.061190947364535064, 0.055488238651906295, 0.06943208841426719, 0.07425866450273222, 0.030672174405246496, 0.020320152773732142, 0.05781443016002736, 0.06450438871979713, 0.07265060764527129, 0.0405944015590414, 0.06771425115725688, 0.03992879755734917, 0.02941503369760129, 0.025985702391593687, 0.02524759391352775, 0.024448077742671295, 0.02558795911740632, 0.020685766320375186, 0.020184915272458907, 0.04619235923934368, 0.035495860427017176, 0.08330569557485082, 0.04130156583062584, 0.1395812504474194, 0.0325967577256022, 0.01672989129269075, 0.058062826508596066, 0.029946170116384185, 0.029604062062477874, 0.0743424362172523, 0.02039545538624929, 0.0375059066009858, 0.03972959171439852, 0.0038808912992657676, 0.06979925137373709, 0.026627864102802934, 0.03827488267674081, 0.04520956419348236, 0.05935775641832621, 0.036721103148715156, 0.06697417191800571, 0.037326718635496595, 0.0855462882487524, 0.04137365087386101, 0.01340261726234589, 0.00934374075563204, 0.06251681573508729, 0.01660500555449436, 0.05453081643809715, 0.028623572941268646, 0.04989546355641177, 0.05656349667978864, 0.0917156019638623, 0.028695001064108747, 0.042247998513161175, 0.004871887795161456, 0.02936048632217271, 0.02546231303694508, 0.03659830691533224, 0.04014818215622537, 0.01980268527873822, 0.03975427123687921, 0.07139574030354139, 0.04348711508716788, 0.03889791134204115, 0.035161512843783826, 0.02815400700896017, 0.07321652445581651, 0.03125008240702652, 0.027654668984694347, 0.053607067618999756, 0.044845886934067936, 0.018230916091030645, 0.005794142264001553, 0.023240681039169434, 0.09938696895035044, 0.025670981980980407, 0.028068358379025615, 0.023075659954619986, 0.03802156038281899, 0.08445041479482766, 0.014236105602204561, 0.0837471307585797, 0.07859186464620214, 0.02844972269339187, 0.043143631905437484, 0.06002500750905564, 0.04395258244908145, 0.04091704714923136, 0.07161374594415389, 0.039794839422909484, 0.05165851532271312, 0.04986801079564518, 0.038839700151114695, 0.022005967555507537, 0.01905834850584788, 0.06076999737190143, 0.030594027691310456, 0.03433371270676294, 0.01830532812633582, 0.037931280751382156, 0.05055094370618463, 0.019215092010375474, 0.02773181020822977, 0.03937529903205653, 0.024121998163360744, 0.0326654298471347, 0.021472431366301833, 0.018483887899727113, 0.025584011849376465, 0.06800767815401478, 0.01599764242963565, 0.040439801185481974, 0.08236758260717315, 0.034411160365468076, 0.06232235963726717, 0.02323747687642613, 0.027175842964601134, 0.07053145522912664, 0.04391860644963961, 0.0609850803870828, 0.028139684995215748, 0.03794440383752508, 0.030686812430259683, 0.04514121382887806, 0.015960424920664202, 0.04539588826798624, 0.03932048544107426, 0.025337201302811026, 0.1349973633524872, 0.17297375136085097, 0.16778600312048392, 0.09338972624391319, 0.17304956342183775, 0.11679982571231744, 0.21528696310856651, 0.11723055864774412, 0.12619630013021732, 0.1663608957202204, 0.1388842789756675, 0.09375501994884784, 0.2152793022293237, 0.10361726816383102, 0.07932100414989457, 0.09441718804619967, 0.14797794181973706, 0.10540452064766039, 0.167619287066402, 0.16208886769750427, 0.13924928922807017, 0.18886247619746194, 0.2082977744360124, 0.12016837560241261, 0.08989482547246641, 0.14127246614906097, 0.14333624573003861, 0.15286618032522742, 0.18958506564940178, 0.19141169505253916, 0.19757401438490038, 0.14001027500677493, 0.10590121375336763, 0.15973608910797105, 0.2016962415749027, 0.14187033648692793, 0.19644775788389868, 0.1501080646149574, 0.12028925661598483, 0.20468919387748166, 0.15692689065491, 0.19774295209396273, 0.24520534721593706, 0.18091435994832747, 0.11961844704684713, 0.1269354907074763, 0.2087359307634254, 0.11834398317601412, 0.13418903334006188, 0.12176019905675804, 0.1262198879774059, 0.1148691539081835, 0.061033531617853916, 0.15140336607733082, 0.2343779967557038, 0.12200124096125366, 0.24192318140018373, 0.13822699085839335, 0.16283661547687747, 0.17276798014438924, 0.11493244809248757, 0.0650954945012927, 0.17089535482227805, 0.08540943430195894, 0.08646002429867945, 0.18938133222681863, 0.21707202458093244, 0.16884982345565674, 0.24794285516104392, 0.15963655896484852, 0.12267299281853823, 0.1331431394623172, 0.145835806765864, 0.1224254698102032, 0.11349586469511833, 0.10179722711684243, 0.17950371628807438, 0.10318280438021307, 0.09934595260288447, 0.11079438586509037, 0.09689041097918827, 0.22413533992103993, 0.107044592319477, 0.14081581645915586, 0.2066423810057102, 0.18357997820261987, 0.16257337234433622, 0.1477018130883094, 0.1679773565622107, 0.16503758608333527, 0.05279468500145501, 0.1785598346783269, 0.15575554221868515, 0.29306531132709596, 0.12256626910980671, 0.11220623994426382, 0.055855125819723454, 0.15357064413687876, 0.19949190018157806, 0.22545504894468094, 0.14881991841379674, 0.13923107165723078, 0.15702147187004167, 0.07512655785127033, 0.07899711749726727, 0.14663842176237415, 0.11214276955973719, 0.19054960098958787, 0.1511585090549723, 0.2531761703111472, 0.132025417180792, 0.11857789280193469, 0.19774082236953322, 0.0789646583519155, 0.1628420087358644, 0.13581530010748294, 0.194592691297012, 0.1509596326298291, 0.08603539708400927, 0.1765134452932304, 0.08394131872562632, 0.1287445843580269, 0.279694625567044, 0.06904891421717983, 0.16201310160179294, 0.1332959433596942, 0.17179437432317965, 0.11056487358385518, 0.12284700969053854, 0.28058230696666625, 0.2885877112707784, 0.12453855480998756, 0.14877416764295873, 0.11635737929252848, 0.08938260376453401, 0.12366992601704214, 0.24550579157808136, 0.10215925728721965, 0.12262190241486796, 0.13305579011719074, 0.14874049041780735, 0.13316690350972837, 0.1297779143938134, 0.1650097770916839, 0.11928806396862192, 0.12198314596448215, 0.16388761150019784, 0.07706474497794144, 0.13572140837148314, 0.0880369243602599, 0.13251117821181976, 0.09558611564458379, 0.1005019946023822, 0.14640790590595815, 0.08847655157648748, 0.13432495265958772, 0.13084921174712721, 0.1939384215661595, 0.0990973647323347, 0.13529138789782602, 0.1885831298967523, 0.2127812733693469, 0.14576184863765396, 0.19973871838902274, 0.16845329634604916, 0.16314378609099697, 0.15597131854343801, 0.20729298883628464, 0.18438542772444988, 0.16652660053824225, 0.12314944588128598, 0.20602572619193987, 0.12128428225555729, 0.25520849432195386, 0.12109007130587295, 0.21217846942524757], [0.07353302602085375, 0.03712886110729268, 0.02868916730456535, 0.02042594185519603, 0.01444233551381096, 0.0622350792400539, 0.04070654150939757, 0.019817949580629508, 0.06742077053434427, 0.05884797853087226, 0.027328409374721592, 0.04677977630748384, 0.0380734475179305, 0.059673928565556006, 0.03349281629667648, 0.05351123001967227, 0.053079796113794854, 0.07681802636192692, 0.023304551704636505, 0.029675811942246173, 0.037922486062011415, 0.017526364179268, 0.0777920994967703, 0.06925900616953451, 0.018781411551660108, 0.052633231971412904, 0.013828637799428356, 0.07647101151486559, 0.037088078416643605, 0.034961265121256156, 0.02881152686783143, 0.05678497269869812, 0.06462205216408738, 0.015816742257635682, 0.029736501427607673, 0.02638345141144049, 0.07095283423099788, 0.0349565843240388, 0.03126000899130539, 0.06449835960783305, 0.06333000657539214, 0.026152899165848092, 0.03137949955529504, 0.07655955595715393, 0.07658645330417542, 0.018641878212351474, 0.028140322763412714, 0.01894773307046102, 0.046130080121539296, 0.022215733920494397, 0.01702028458126851, 0.04377010413595746, 0.04719750490039588, 0.017137842688469157, 0.0036422836391495606, 0.08310494223429311, 0.04027563620418791, 0.048796763238046444, 0.06411809654485795, 0.049273453788050724, 0.035466201333028656, 0.058227018302967476, 0.025143880930338657, 0.04024717603780089, 0.030709618867765513, 0.08793511127512302, 0.07935543980209098, 0.0673772873837621, 0.10839094588112448, 0.05239763695205893, 0.03289645515202034, 0.011570199107330655, 0.0802278990346578, 0.008817218101373123, 0.02603080198769608, 0.04348396263535946, 0.06849188402655625, 0.05095365314534114, 0.03644380996364259, 0.018438635086039865, 0.046408357729594556, 0.03495920434473984, 0.05825950426139659, 0.07107932300817582, 0.03556005859507188, 0.0861851289688099, 0.03607699940461786, 0.06100070858073812, 0.031305288618069985, 0.03169577512439461, 0.03525540457978364, 0.006143154206520488, 0.08504196490731933, 0.02197666660762362, 0.04121797031632835, 0.06218534481200961, 0.021688301536825397, 0.0037936817651854893, 0.078651366695281, 0.006765008363271914, 0.07293378438560233, 0.05287752591914708, 0.048905042105264245, 0.043378430193350206, 0.03684106485677823, 0.0589743945296974, 0.017160022849096887, 0.0405870815889249, 0.026447536581526362, 0.06688118416575656, 0.019511755728613467, 0.06281873864692546, 0.04888184879335666, 0.008298746073588489, 0.035308701316675836, 0.11641915662274246, 0.039489162680242336, 0.058381453967623176, 0.062213222751574176, 0.040830368131038644, 0.04983303505146215, 0.02864516895985411, 0.023110233502642765, 0.021760896028530215, 0.04078200500037882, 0.04867693559537011, 0.011958996389782237, 0.032748937261320894, 0.012018176681932904, 0.036618523975653995, 0.05130830971944717, 0.13804118389323836, 0.08811846675892031, 0.044252996167708794, 0.015235952807650452, 0.02697635558433831, 0.053243604864204125, 0.05796497792846734, 0.05940601229667664, 0.017035843827010646, 0.03854933367561429, 0.07682797018318407, 0.015081040253261886, 0.08113123161057312, 0.014844103622430516, 0.020363490367608688, 0.048584679457088636, 0.020993835172585903, 0.02675890918791054, 0.04452000845283751, 0.053836530104519865, 0.029027331920881427, 0.020393532505559347, 0.04198784654539439, 0.012224776230962768, 0.028504831228224982, 0.018154604157673258, 0.0034317404131269866, 0.06310511380434036, 0.020244578200001872, 0.023496872332367687, 0.037455317984905936, 0.013817442382024902, 0.027169235456254215, 0.07310817664068553, 0.0990164888301684, 0.026977115926603158, 0.02291631175114984, 0.03530912266503419, 0.026122290122833465, 0.02663157771401588, 0.023385352913230177, 0.03960203041412658, 0.025417743956730254, 0.08091540932054482, 0.014394222319336429, 0.029042948623217886, 0.06759700906132499, 0.03383933318658702, 0.02634608738815352, 0.033181872699529893, 0.03393492180733912, 0.01583279371486917, 0.04063428792681906, 0.0630678589485826, 0.062459393614722844, 0.004617444140040466, 0.062221109626754645, 0.021539429585719784, 0.12844019464307255, 0.03810268909400029, 0.07055368710068927, 0.05198387286415504, 0.06275654762923237, 0.018847503872107596, 0.015900584835288747, 0.031352747764979164, 0.03084907368306191, 0.07819906072390657, 0.012395909739538066, 0.049934748545168876, 0.028108838464944597, 0.04437265527104178, 0.08049287352590792, 0.014242641289808579, 0.025430529964186495, 0.04077908237494769, 0.039044927445150195, 0.050529022100231344, 0.06028884819017784, 0.06376068971510376, 0.029969775200551076, 0.09121933020651342, 0.027609174853310953, 0.0680712711126093, 0.06916519870320637, 0.03175845260791962, 0.10127965811519854, 0.04322826163843275, 0.08230742172247942, 0.05832564829277897, 0.04444313536007558, 0.022823279948845025, 0.048305421256490295, 0.0473262804500278, 0.018398122441384102, 0.022658607434301127, 0.05619495093161541, 0.047968756257286, 0.05637325406555207, 0.05156548160518851, 0.03993298805829498, 0.07319478288052544, 0.04398131840712121, 0.049669050100830295, 0.016954466137253953, 0.022866079365954767, 0.09054357170938485, 0.012342997004217919, 0.03165535057985014, 0.0646897973192315, 0.021481796791176164, 0.038278031298109604, 0.023185162647296826, 0.11021516210730038, 0.035788456218377236, 0.04187462258062536, 0.04270966990940994, 0.13108565712407713, 0.049540569495049216, 0.05565530327599376, 0.02843822754408804, 0.038354544329547116, 0.013292614697298456, 0.01573569015524681, 0.006189874078582732, 0.04709397960874823, 0.030519709501776005, 0.02183523528548258, 0.04760489513676974, 0.00939790317187867, 0.07411898369149816, 0.04599813679834047, 0.036591044401810054, 0.060713417948253696, 0.04396462918169076, 0.04466895509751574, 0.0071305170516303236, 0.10777671190519487, 0.025061175993253148, 0.039254019652763684, 0.01837093781139101, 0.05143151197942996, 0.06332813349041728, 0.026758438043837107, 0.06505557365955845, 0.05373542182027333, 0.03200395505935435, 0.016713537230727174, 0.010925514094020811, 0.03795440128493694, 0.028359305166128664, 0.057686436020078204, 0.08393676050247685, 0.00595403774153261, 0.08523008545800563, 0.050402104313815796, 0.012810960855154742, 0.04453038894421151, 0.12165986452131503, 0.049077584258010315, 0.05684062132551786, 0.0272961781405273, 0.007775891065267065, 0.03614165339498751, 0.04678718054727201, 0.05775883515936233, 0.025470083083717093, 0.02773969899863005, 0.02868946607885582, 0.02875236764309868, 0.0871023124143962, 0.053902873318762555, 0.00840363308652154, 0.030337683180527344, 0.025773082349088886, 0.046107522662608855, 0.02811338328155539, 0.047443886437723716, 0.05696182409601827, 0.023055226474459616, 0.017251978297868086, 0.0274992220839786, 0.02158235923777665, 0.04388915419939064, 0.07456570488190459, 0.07047297207698708, 0.031653487070974325, 0.021571358215183984, 0.013710123997542166, 0.057463270777295676, 0.047162521495333606, 0.02316651606721984, 0.028220627930075414, 0.01578913340645452, 0.07822483192167937, 0.06179607255504497, 0.039530902980796756, 0.010750948511544737, 0.017166544172552325, 0.0435599623878877, 0.07677330214890742, 0.013064887400926843, 0.03175480794461985, 0.08732931192723975, 0.054720641534414985, 0.024764933623373512, 0.029401832087446126, 0.01447156176812226, 0.03285004554556743, 0.04907599079512781, 0.015158668900239132, 0.02157525568749876, 0.04708553348938304, 0.010100733301031494, 0.045180540952470996, 0.03583129968554263, 0.008953425661480476, 0.029927573332022277, 0.08479070338991382, 0.04982137519325461, 0.023319048003383705, 0.15646213575476603, 0.17947204621328464, 0.14474198642757632, 0.06205918162219948, 0.14556068927049637, 0.12984263350165662, 0.1285874444029985, 0.10677259280196122, 0.1267782818045347, 0.18637966184366137, 0.09771363374086157, 0.1577513085137452, 0.11957101088257567, 0.1947629619990626, 0.11848714202642442, 0.16348037448140884, 0.18666630130141013, 0.19908211975088044, 0.10438175496434975, 0.23279902825672782, 0.11645034406213992, 0.07501945875945591, 0.12371824318242651, 0.13381129070635767, 0.07018704508100787, 0.17150917511072852, 0.09026095421323854, 0.27001148870875763, 0.17016842931268678, 0.1910969401679693, 0.18885873768839145, 0.14390529584019415, 0.08878627326339485, 0.10603034553388435, 0.161439684790469, 0.0917815697950221, 0.15214297800294815, 0.18137591260094799, 0.13109334864683692, 0.13820846685238425, 0.14289098010668833, 0.14339394747249543, 0.09660027049962552, 0.15757834118220115, 0.10575963304408136, 0.09207181752689424, 0.0984081230877388, 0.14765906538213455, 0.1496494690617246, 0.1249218515811428, 0.12499043177212439, 0.15264905568572784, 0.12181675166732843, 0.10146024802158918, 0.11747094171662485, 0.198795112570928, 0.08538426831364633, 0.11995387864449333, 0.13965171521469472, 0.09915362622949386, 0.14291019359182927, 0.20985484814211247, 0.06631776480184448, 0.11898372787982227, 0.19150858985320215, 0.17635658112985475, 0.1463614196907128, 0.2034576002868914, 0.3039406955001816, 0.10275985489809707, 0.12196258416459446, 0.15183281964592396, 0.25825703396431865, 0.16522475668499548, 0.13416232751502147, 0.16429239703762918, 0.1261749262771299, 0.10622003656481543, 0.17622806221967743, 0.07709492884215809, 0.19402204772397397, 0.12971129538791795, 0.11116861215522213, 0.2316471231320212, 0.13685842074694174, 0.14054826791248015, 0.13272251122661177, 0.08698300188106876, 0.11240103312077061, 0.12103640684677709, 0.13966634749404847, 0.13047822600891515, 0.21505421027541163, 0.1007916984118281, 0.14041507586596474, 0.31286099264698647, 0.18963024951517585, 0.10263335079916062, 0.1259153450448667, 0.10601468669671206, 0.16537193749700824, 0.1148123638103566, 0.14824120027403678, 0.2008182894919188, 0.2145859926578499, 0.19905490830781, 0.12741225020539376, 0.19161663889404268, 0.06831089575444499, 0.20462597630197005, 0.12313099848406932, 0.07831454847849185, 0.15321131825687426, 0.20460230418510977, 0.15751518489372346, 0.27021318433746216, 0.13085474290194052, 0.1654341591582183, 0.1324029453098774, 0.0866908006249897, 0.1356557546363723, 0.10319082532078029, 0.17014789815631606, 0.128582664014351, 0.17067997686324582, 0.16898797975192148, 0.15393363191716133, 0.08741463880024611, 0.1124276240326224, 0.16259699849592102, 0.23434050441268953, 0.22659218389420743, 0.19266198118848188, 0.14425625604006553, 0.11303880131773411, 0.11635991504355786, 0.0858961606037713, 0.12009045679963405, 0.1587019776625018, 0.1763420407810519, 0.15238628752769964, 0.16760270892372056, 0.09523404461722221, 0.1329594775433502, 0.13434909975096104, 0.14417999964808265, 0.13989528520934044, 0.16697189680510954, 0.17789347608002926, 0.16024687057060583, 0.1282584019786408, 0.09959997203681739, 0.12167690997763027, 0.13840118393061623, 0.1723948493599892, 0.1098579199864499, 0.07548475758202615, 0.15286837133669084, 0.13125733742790838, 0.1591679123380492, 0.14244119456458476, 0.1513558992695424, 0.14710696113686408, 0.09111865859238372, 0.21643125331930577, 0.19499061268664178, 0.18107595853507522, 0.10306645860715259, 0.11186512397421945, 0.12665630528523078, 0.23560911537178103, 0.10297676503297784, 0.12969716872659423, 0.1593204864090489, 0.16401694246357487, 0.07228253304117149], [0.01602444114283689, 0.06022834639635779, 0.03988527227193117, 0.04987877433098132, 0.05851191874112814, 0.03157065572938131, 0.09170919746881531, 0.02308050354552125, 0.10260946417768156, 0.10322939018688856, 0.07055744859239749, 0.01765694578118142, 0.050971288489358085, 0.043389913851335164, 0.04666054621338845, 0.028563059656129732, 0.041249556121446436, 0.029256876760853395, 0.03739733662035677, 0.07720244162145161, 0.07963322328343507, 0.017813492018068512, 0.08850941674843912, 0.01064013485090747, 0.061089356444896235, 0.03252738463361898, 0.07393109296718914, 0.017672033882850123, 0.028164808848692525, 0.02120790886692703, 0.02660409622495213, 0.026239356018542766, 0.07980118806083357, 0.03411537764834301, 0.022381149540324847, 0.04561808823998417, 0.06636239708431306, 0.0752320021931683, 0.06280608287441634, 0.04887757402273917, 0.03686144662600371, 0.06268410635511242, 0.09756272208065757, 0.037135131536952914, 0.03189508630443485, 0.03092219102977505, 0.037287686455754504, 0.03154564104343374, 0.06676390376542846, 0.01413438253239879, 0.11628145231835305, 0.05203573318618921, 0.03392693534072849, 0.03223686494053372, 0.0655232013894185, 0.054697574627014904, 0.03899699715416759, 0.04485160194998307, 0.026198820391249274, 0.021279191433061517, 0.03857303260555191, 0.12001330408477977, 0.040550010594268965, 0.03850276319069728, 0.03332568655511545, 0.035520597406092196, 0.07633418821158909, 0.01402624060339745, 0.029623457493500847, 0.005502081297773628, 0.04887896830276136, 0.020115601552289822, 0.040944955732312896, 0.07286758672806525, 0.013293436326597248, 0.030281687898921873, 0.07005770645675159, 0.03246180750730057, 0.03456530874715217, 0.05077695113516623, 0.03357792866506404, 0.04968545204328914, 0.03967370943076188, 0.024568851503934112, 0.054464032723298, 0.04498006723400566, 0.04603650631202806, 0.03374706555698668, 0.018850855506776322, 0.02361260331986893, 0.051032613827696735, 0.03710299414852935, 0.024145170407850417, 0.024043824636347355, 0.02834967161048084, 0.058010226911714965, 0.045815195002022295, 0.06772702184295462, 0.06890078345614095, 0.04524166327750972, 0.01775156721592911, 0.05584292203908967, 0.07768845546149439, 0.02090314185366996, 0.06000712701690294, 0.034558203281654466, 0.04295021002631515, 0.0988589734920571, 0.024930527358646357, 0.05285211095225908, 0.05646045785397292, 0.029733507939043547, 0.048650949892978516, 0.039901555470761754, 0.05433585089180739, 0.02544437125775843, 0.02205002718725272, 0.04525538391223358, 0.020166540653595043, 0.06083510335414641, 0.06667004267294561, 0.07064695830547041, 0.04177352961813731, 0.06683909529519659, 0.08831546626864903, 0.02874256171766789, 0.06011424526091545, 0.09296779565873647, 0.07962077435466551, 0.05096481121595829, 0.011342561826290143, 0.028143224321425925, 0.045214237329820474, 0.019246289025871985, 0.042191139467421084, 0.018930214554852536, 0.017251620151763482, 0.07151773980548305, 0.06474181468929015, 0.04725739765431612, 0.041112403400362506, 0.03198304085902149, 0.0296924609480606, 0.008975154787842787, 0.01951471091278138, 0.02100371579158931, 0.08475221513259797, 0.011740592383449117, 0.013583696507398161, 0.03841846287550946, 0.028764923824177637, 0.01907659288976462, 0.04182113815219172, 0.029890069497689128, 0.057947694984895576, 0.029676386508189385, 0.08299009033268498, 0.025775330817146648, 0.02259485551246232, 0.07268240795500817, 0.040317004952099056, 0.038647657230256066, 0.029298308711018295, 0.07799335079447878, 0.0171427360750855, 0.05335062351678649, 0.12218447387098305, 0.04962617982058756, 0.047742262362472476, 0.012711620318793483, 0.04444390910887911, 0.011530368280927501, 0.012325966869661165, 0.03706601891486395, 0.055676788211830204, 0.05287329328336543, 0.028003681406018235, 0.01097635456150578, 0.06601333678249391, 0.049847311099931124, 0.03965146989832002, 0.05949735679032822, 0.01099104621267367, 0.051898492364993984, 0.032062702511827794, 0.08230433438814456, 0.053193560170550505, 0.004260197231140469, 0.032435637943807154, 0.03506493213916979, 0.048100511888943376, 0.06597094913764347, 0.05535733720828449, 0.1125616587758545, 0.03838623355653498, 0.047883168914385384, 0.03446074540636713, 0.08164998804849964, 0.03201996821219162, 0.005694673407912976, 0.025651103914565137, 0.02732450041108795, 0.01183954125735909, 0.012489084225718775, 0.03884295219435327, 0.027199880888445244, 0.0064056824832674, 0.0485697292512463, 0.08076707937664564, 0.06557114317171997, 0.02174990266681679, 0.06998177948257617, 0.050335389546929836, 0.03361474685070496, 0.03107121811368533, 0.0628054125474826, 0.06448412569419992, 0.05511789259711101, 0.037504523812282475, 0.02085897305439557, 0.04383127625671126, 0.008501026801945222, 0.057200261301571326, 0.026214281960781065, 0.03549502922161933, 0.026853540198757287, 0.05712037365282736, 0.012416550063437993, 0.006855541761333664, 0.04477675515978087, 0.06140863890909861, 0.0379279789124285, 0.01455807224697163, 0.03505954271062248, 0.01786199879021414, 0.017549616862989722, 0.04962755111797203, 0.059928760052688664, 0.01543073928088791, 0.1055312009468194, 0.04748624726949681, 0.06029972663870262, 0.07311579155465288, 0.038269282574014324, 0.0495518233266569, 0.010562794444511735, 0.048183670733124025, 0.03457525639884895, 0.021599450659367348, 0.06387556459934962, 0.013203218939804263, 0.033231752684279796, 0.030542328247740388, 0.019553536248783913, 0.021626397802103913, 0.010071897751561577, 0.04208452301099897, 0.02440921793271217, 0.06071498459805885, 0.03141357323094722, 0.054234168041617646, 0.05534028026065039, 0.021223353199480523, 0.03353927952928409, 0.039029031120721376, 0.02229371784074653, 0.03946168693683801, 0.025154791937600222, 0.031628773074537035, 0.025904085299360658, 0.030488265422923915, 0.0324027344674593, 0.03504800925692243, 0.024781992486227426, 0.03359684337591452, 0.0358412281850413, 0.006741443498721046, 0.05609908268877095, 0.040279730944143194, 0.012853621418828206, 0.009425572352483869, 0.06485192450664698, 0.0519184872598177, 0.11568337513674652, 0.012440941345337178, 0.002581727796144063, 0.020312624044656273, 0.05750897558285825, 0.011072739913699128, 0.036636251250221845, 0.04583335128582774, 0.0415654907814197, 0.020399178573561293, 0.019996760247816003, 0.05578857576174121, 0.05643058808580522, 0.026976508801923166, 0.03769343726397042, 0.021321391386370507, 0.05973636856182449, 0.04518691863444063, 0.05849416082304332, 0.06493111501537985, 0.029326740149108153, 0.09911470130206117, 0.06388344764409047, 0.03618230968112907, 0.01115587864807176, 0.050358751398180766, 0.029247476862022476, 0.06008723300070532, 0.06052271185082294, 0.010394402573095455, 0.03595148355910375, 0.04712626255387741, 0.07532884336767659, 0.03841315771663382, 0.0005231786206188132, 0.012004503927704309, 0.0609163546393956, 0.03337821337364374, 0.05455066194577564, 0.056073464708583015, 0.016105004864174034, 0.01780166170529781, 0.017453398134919907, 0.06264801978343917, 0.02838722907096869, 0.04967023753711293, 0.036935734172021194, 0.017176813581177307, 0.026366804320845875, 0.020443004548489567, 0.03147978046458335, 0.061234124079947515, 0.03538415714677784, 0.02736645713148098, 0.029587007030063582, 0.045784995816047155, 0.08858361236390569, 0.05295920621363386, 0.0951212534921304, 0.0069554415418796485, 0.027236526704303203, 0.049843499812507824, 0.02129304804839194, 0.04869167512703327, 0.037379789376451124, 0.05939770407313782, 0.016444232427485047, 0.07201623321781236, 0.07812072057276964, 0.1145708928966234, 0.19048266022676424, 0.1694186590611935, 0.11165406675108018, 0.07625619280001811, 0.14357482083141804, 0.16705501734489397, 0.11091257024916912, 0.22481922661104511, 0.2123815899774913, 0.12154125878887793, 0.07004170288001338, 0.1332111680699933, 0.169195037996096, 0.13226275121973408, 0.16086089004191662, 0.10035706608886681, 0.14722506125127116, 0.12667004890259237, 0.1114994012600472, 0.1552144236742489, 0.15829236577114753, 0.1558146995281981, 0.1611907521803533, 0.12961024839070537, 0.2703851251111877, 0.17449281178414824, 0.12868207158340564, 0.24934163978022916, 0.15309940813289535, 0.12063853142242278, 0.18560442682956496, 0.14179535180089936, 0.1688325251903265, 0.14436595983082248, 0.09229333951107918, 0.11125266732227419, 0.1796937520585714, 0.14128771129875414, 0.11797004033841434, 0.15105179300712002, 0.2041929067983743, 0.11022891338554122, 0.05906936644967045, 0.20263163493044917, 0.1545365277918116, 0.1299793495526237, 0.15656243198581282, 0.11569880414754154, 0.13734569863205956, 0.15050278375706366, 0.18975195024282704, 0.09323149844403229, 0.12277530386082589, 0.1414818686222838, 0.18170511590376978, 0.16961013507698813, 0.1666984034161414, 0.07254200702112529, 0.11103574952651417, 0.1406476448380178, 0.2512451078021719, 0.08484301953426293, 0.2001658277285676, 0.09416824777520473, 0.2326342427442151, 0.2026401997934426, 0.12987323105335236, 0.1070998425805761, 0.14374581165611744, 0.2322420057269835, 0.17389199966865201, 0.13891256294183194, 0.16426601296951696, 0.08676505752749021, 0.1224228727721399, 0.11355984835855423, 0.1628585102697534, 0.14697361587276384, 0.166872397305504, 0.10881633918371894, 0.11566508095711471, 0.09746198917949393, 0.1277807997840066, 0.23090479925515192, 0.15575428583448933, 0.1429695041189271, 0.0793100031273019, 0.1659128568585842, 0.1350137269905498, 0.13977048948647516, 0.23408228681693155, 0.09630357996831018, 0.10493478617600857, 0.11012752930964194, 0.24320495374981435, 0.15727967414404118, 0.18434880872166928, 0.11637485375808132, 0.14793896326614966, 0.15851707468109746, 0.10544844046835938, 0.16375907726826208, 0.12484053900885968, 0.1490972115988693, 0.09930218599977032, 0.09533726730413976, 0.19542829403954168, 0.10497596340193864, 0.11924925395437788, 0.15454996497400347, 0.13618202639683602, 0.13113418113320105, 0.12896674985606826, 0.1066193369127089, 0.13713277215438505, 0.11259856889204634, 0.17813658642192043, 0.13362142347520398, 0.20939609937129483, 0.17276306185991536, 0.1954888762725938, 0.08849090806418851, 0.2414734877886311, 0.13381245516000256, 0.14261900357181026, 0.1260368848940538, 0.1518952711335113, 0.12936353743557008, 0.17667737278726794, 0.10511019732803108, 0.07823335848027661, 0.2024144030386402, 0.14009809932641445, 0.127852559239874, 0.12630651719988356, 0.08311929106111489, 0.1439355103479278, 0.12091856720226428, 0.20782925038328096, 0.1279385602702537, 0.057289656101455616, 0.14326532131000874, 0.1453437025268232, 0.2247170151601876, 0.1525670076690374, 0.1694277755074924, 0.08147248547644385, 0.13312651535436032, 0.08418764663679947, 0.2203822598582314, 0.14742606740084388, 0.16396818862807366, 0.11172260863766556, 0.15032338128695566, 0.17192448669623944, 0.27928437016183333, 0.10955605070076643, 0.16005913306388164, 0.20790316254621555, 0.09123095942120399, 0.18245951332632573, 0.11049064732487164, 0.2193971014311237, 0.08700610709286506, 0.19564192531810654, 0.1960470785777415, 0.10041295986382232, 0.11753949126408947, 0.08766565516951584, 0.11795476454520419, 0.16594572203053584, 0.16960484907031062, 0.15626758006551575, 0.24612771707677075, 0.15143316689758532], [0.030159200015928478, 0.018410697774661165, 0.02470672434766687, 0.031947718460052725, 0.02723220788363007, 0.02787741287911852, 0.05353535412840786, 0.025076273671020905, 0.045067611931552815, 0.07371492593759492, 0.05388040395994341, 0.035576376267859054, 0.061829067961943734, 0.022287811302850326, 0.01066659935825174, 0.062490948776323954, 0.0421843059631365, 0.06266703408571982, 0.041883758179122405, 0.010197915384666094, 0.045173515926205346, 0.027146235581547506, 0.03907691544642852, 0.03706352912911004, 0.03462939583245785, 0.0870836811560777, 0.03774722046669453, 0.022391654520986543, 0.03206990373831603, 0.020317772155507438, 0.02435027895825765, 0.038046117331231796, 0.05258081623563363, 0.04884760849358094, 0.0707286232781987, 0.06659885778302146, 0.018463554010996898, 0.04814456960546875, 0.032964296068155, 0.028974002625252453, 0.045098600188089956, 0.021411090706204696, 0.07836039117988079, 0.06946080905054847, 0.08980460329762391, 0.018400097033008933, 0.04819659080596701, 0.07748105247775394, 0.05399432889516315, 0.018071596615857655, 0.0761556820643525, 0.020054226418236093, 0.007613021730174942, 0.05810867687086425, 0.031646904460484945, 0.06511165129561579, 0.012261115611651012, 0.048433369431164, 0.02245170815337089, 0.06564392918540586, 0.04238009122350524, 0.07993385150668122, 0.046761800054340594, 0.03281544135402768, 0.025058510007276654, 0.02110622601673728, 0.049276713492168535, 0.035599711306032636, 0.06941536471488015, 0.006127190370593341, 0.056776530409772555, 0.04254340584720335, 0.011217096734101014, 0.04509230677579199, 0.05677613204405193, 0.06709989460725939, 0.019632544811634768, 0.024375096376564716, 0.06999734638919754, 0.058639384280409546, 0.021812911483369047, 0.02815796193786927, 0.0242588865841108, 0.03126138411912947, 0.011282989871688189, 0.026975497565863114, 0.029027873928087856, 0.07159016575784453, 0.017011013002164902, 0.05619119710078644, 0.028263341162293672, 0.050110492945438435, 0.04243729117837164, 0.04723243850974306, 0.008257716319583839, 0.011251633892947388, 0.02959707342538863, 0.035447451331081896, 0.027774559829624432, 0.02658164218789147, 0.04539597253765791, 0.012241630165296937, 0.04360651372060661, 0.04473154831136908, 0.06203084786031997, 0.04638473157800975, 0.029102573246364633, 0.04020238670730784, 0.034810843757323684, 0.05147417924637276, 0.05038681319884716, 0.019556868731254534, 0.03623134696916227, 0.023784285538919994, 0.07384649387771085, 0.0515547065785335, 0.024704719112525066, 0.049927405592414646, 0.05828103133206887, 0.05273693346328313, 0.014830160822208612, 0.04248457412505823, 0.04276741378670258, 0.04682928857003008, 0.012620132183656098, 0.05381044481069811, 0.07406804650541275, 0.014530844524532798, 0.04882935644878496, 0.02689430565242806, 0.040066126478655685, 0.042125780676161094, 0.017883696315449574, 0.06679097731267253, 0.019643706712691535, 0.05386844532744539, 0.029255704646329247, 0.06266763546474038, 0.030370159562857404, 0.038837325278549426, 0.014026709832251074, 0.026142987903327714, 0.07564890724156173, 0.06973443267446372, 0.012302176009172635, 0.0678459799758369, 0.05001853941188705, 0.055201966916361166, 0.07238009433832861, 0.045488190371543176, 0.03823924426650328, 0.0414257486831517, 0.06963599803707293, 0.018471963741185687, 0.035400915320121476, 0.010934185251713762, 0.011055642746448999, 0.03654812432585224, 0.04952120662276303, 0.009550761653020257, 0.00790382152415752, 0.05122685925133767, 0.01341135832556193, 0.014961775685209903, 0.027836645510227933, 0.05959726231653364, 0.031628083595405185, 0.03443478268661326, 0.06237508563865578, 0.0709482377034522, 0.06680014738512617, 0.03487841271224522, 0.09234156474591264, 0.06375287178783648, 0.0265179687900649, 0.020008981265428088, 0.020257967501698483, 0.017990718798471556, 0.055964323992450396, 0.01789277828779192, 0.014401002197466312, 0.04353104256874612, 0.02811688621858916, 0.05848157016800777, 0.06364594506580504, 0.07282192788777814, 0.03350799249845647, 0.007075708727502535, 0.024817818588006402, 0.04845747821814111, 0.04078857420432953, 0.07795320778724649, 0.07154691243363966, 0.03566442275299661, 0.09350490756332876, 0.006009067273548534, 0.04218148675957515, 0.06092858140266711, 0.03260505445782216, 0.06513917683473518, 0.049672750305504575, 0.03562981090057762, 0.03310509919819813, 0.02970702427950117, 0.02435085160898105, 0.0313112143081643, 0.09382903936409182, 0.018444568437013417, 0.023418903733874043, 0.03575711556139492, 0.11286840038073641, 0.022402226534341613, 0.028888930476480917, 0.00589750571957519, 0.046077112802454544, 0.03388193916649588, 0.010363243861995157, 0.09963161146809017, 0.0062322770451916564, 0.0273606980655102, 0.010459526749928633, 0.01772742012455579, 0.016232430183839415, 0.06063215134124603, 0.021518067223951224, 0.028384739285214778, 0.042813949797663, 0.07766983186405513, 0.05983570335252632, 0.029188964981585745, 0.022910215606492375, 0.018855130277393807, 0.062242073622802575, 0.08611385214833484, 0.10380996225942528, 0.08362772063382211, 0.10980492968472744, 0.07818281199903258, 0.032354164493059924, 0.04100205226530952, 0.04222445663124804, 0.03848318964423191, 0.03006958496576596, 0.011901135684081144, 0.04158542055876986, 0.012245903020694613, 0.018364481605409134, 0.017135259056944522, 0.05328902621723471, 0.08229931651224053, 0.05917549260982102, 0.055729621465528206, 0.045447610694194035, 0.04543300522791763, 0.09543200173685629, 0.0881928998616434, 0.044653231142869884, 0.01230915315494302, 0.015738268998721917, 0.029485159470970114, 0.043146769035487406, 0.05712795792327774, 0.018425657556602554, 0.04578684974882392, 0.0059169533403380025, 0.015200617002143015, 0.04509721356894701, 0.03546546971906097, 0.05487680089690032, 0.058654280860097184, 0.010238653067649614, 0.058679902670724746, 0.06064988627669312, 0.033313471283162796, 0.041154442475207394, 0.06016207979090753, 0.047599674247565775, 0.02224684858153905, 0.06873157761630512, 0.04209140631099863, 0.02625551472808565, 0.015322892295737422, 0.022524427134363402, 0.022962665816228238, 0.03509434991546216, 0.022487942196969545, 0.04480000592828278, 0.029627383694112785, 0.02945171590263565, 0.007059098026084324, 0.029805238666613738, 0.05713247018115175, 0.026204556474582325, 0.03598909081530667, 0.06996046691652268, 0.032801870106449055, 0.048105127568687164, 0.08659862492594027, 0.03210103755155879, 0.01852603231166159, 0.040156643597349044, 0.04613748053088785, 0.0411349531984137, 0.030689660362118197, 0.062217037869437095, 0.057295769483091376, 0.021470841733858954, 0.020661462180977388, 0.05386113684864775, 0.04769389157093341, 0.05007964641516728, 0.029274224821898728, 0.030935409876908508, 0.03628927470755674, 0.03796526824214286, 0.052145287589800936, 0.056152923348089384, 0.00644969710734703, 0.02768499457517699, 0.038474697559591264, 0.06628142925159586, 0.01197015924844891, 0.06466186575351224, 0.022809365876920284, 0.052492857850607366, 0.029205629309158654, 0.009594600076877303, 0.016521549851243055, 0.054184471917969566, 0.05083233929209171, 0.01148612957613002, 0.06013944955362428, 0.056673897610556696, 0.017440991340986183, 0.02899396304611958, 0.05126483806018388, 0.026402777894550276, 0.05056079176645126, 0.0059052853424462586, 0.016896647566388694, 0.04114508854165193, 0.026835203884289633, 0.031191467104720014, 0.011337150372715007, 0.021023942428010128, 0.07649217086333422, 0.040661376795821616, 0.011418947495610244, 0.04769513263337074, 0.008777695625359494, 0.07405311545176853, 0.06408672524435867, 0.1713651505809638, 0.07287932319506522, 0.08641187567263843, 0.09890349852221628, 0.10054159368718825, 0.09203250955549941, 0.14755757405392586, 0.18275248067032906, 0.13990657734534434, 0.12703674454842845, 0.12475102929578674, 0.257495389349999, 0.09578070963823027, 0.20679395916240834, 0.09039240724016583, 0.16983603908409997, 0.16047778479274244, 0.13850446790456772, 0.18528417143369877, 0.05725215992800171, 0.08262735536141742, 0.2320147840486419, 0.10771200811911015, 0.2056552767152748, 0.17498346045613292, 0.1013330391217624, 0.1275060576717219, 0.09767765059105812, 0.1401246672556285, 0.08734583644376648, 0.13871227691490806, 0.168154813168991, 0.12841827686755888, 0.14741258425337656, 0.2045657617911216, 0.08818718484572827, 0.1897118532008702, 0.08874753985794322, 0.1863318119919108, 0.1474319049908269, 0.2380049634244173, 0.17444721423089507, 0.14488011208032409, 0.1787526436871098, 0.19311224170509847, 0.14509492313429234, 0.13707677112712016, 0.13313607613165535, 0.10453334844280636, 0.1295577100808582, 0.17050115661996026, 0.1804881239490163, 0.15487489350620778, 0.15795784581813122, 0.13103006978429135, 0.16598145237132428, 0.22066278593434444, 0.12877498272686236, 0.1533567064231442, 0.22168604957480587, 0.23430264434747158, 0.21885875612497332, 0.13362039691738545, 0.1598764670592162, 0.10965027185457368, 0.14103231290655752, 0.22766498277985284, 0.07643822295170638, 0.13492616314080455, 0.09817985952982018, 0.12172632264874636, 0.10383672937149964, 0.18501968723872017, 0.15183740085171116, 0.12179789824351189, 0.11166433999014479, 0.16241732023416028, 0.141252210784343, 0.21212338770349182, 0.2374856017770306, 0.07952361142322903, 0.13722217461514857, 0.11973169016381426, 0.12195906016014277, 0.08530556044030575, 0.12978903799047395, 0.16507487924348924, 0.1744826381365138, 0.15048868773925692, 0.17222174413261876, 0.11863154193927204, 0.12004229285183454, 0.17521622861104627, 0.14782420329509244, 0.19102151115094462, 0.14762822268230302, 0.2164110132763463, 0.13285556537730078, 0.133204564392086, 0.09565428980896551, 0.08561688325097484, 0.12470780661509884, 0.2224540067536216, 0.2466852299027866, 0.1360855606054106, 0.07978478611837472, 0.11712736660434354, 0.15213139475353304, 0.07436775542314976, 0.1974364403154581, 0.14178749173879623, 0.1142298611962507, 0.09439458079155415, 0.09451520899611135, 0.20130648668254578, 0.15643092533273084, 0.18174401784856475, 0.16846426672512488, 0.21100754999826032, 0.14153665923062833, 0.21848158039633306, 0.10935505221207296, 0.1336210863965173, 0.1153335334252446, 0.12203751522446833, 0.220831478495271, 0.11428733311233022, 0.0866203741621106, 0.13871855883588716, 0.18711228704740926, 0.13532702630806354, 0.1572411858867253, 0.09619471887426992, 0.15976656408559892, 0.1056312979950059, 0.16429774433134064, 0.11880349803475604, 0.22374144815389188, 0.15608891303981506, 0.18624170473025692, 0.13565868109224305, 0.13767206740956153, 0.13083183687300454, 0.09012979996060172, 0.14010960596703714, 0.11827072984869443, 0.17251592189554246, 0.19878481634922568, 0.15143684411962188, 0.1486444076703441, 0.19235310985917048, 0.11809296680674439, 0.16909576832286774, 0.12183598047422788, 0.11616926640272142, 0.10805290958453571, 0.16734507355478503, 0.181531872780573, 0.12866088159142003, 0.18209931410608754, 0.13823505010335677, 0.12201957344528168, 0.07237974959876269, 0.10835824158763695, 0.11470138831364532, 0.1371017302716932, 0.13121789922156643, 0.24046192997165267, 0.10711995238858847, 0.1699605590153125, 0.24070055103830754, 0.14082638847251094, 0.16239105874011595, 0.12563787565957155, 0.1129649734244712, 0.1613198992826285], [0.011713223892354198, 0.01566407625608507, 0.07517729585449542, 0.04774613110649009, 0.05950581057057266, 0.056759075096417824, 0.07849663991721408, 0.022334931455853007, 0.03152536269607804, 0.08819161283393061, 0.04501028940261853, 0.035368636205431916, 0.03442317645456042, 0.06493024933602541, 0.05515027130323072, 0.054117695864049666, 0.0204001821487421, 0.01039404921504038, 0.02901865597513895, 0.046167626090708284, 0.05672451303971391, 0.031882949556494435, 0.01699868281702361, 0.02596748099031468, 0.02605420788900266, 0.029078159939437628, 0.1221364631407684, 0.0102562079724345, 0.031002572805230177, 0.03018591541706795, 0.018395636486069813, 0.02821542427784974, 0.03288947992146977, 0.04528120107528183, 0.03907732530346802, 0.02003594372992314, 0.05631316595921113, 0.035919223596612294, 0.023771871084107027, 0.023186361574898326, 0.009268192994979121, 0.028068796964362267, 0.05668460751973814, 0.05779848403988346, 0.035480975338648406, 0.020632931151457375, 0.09034096443605039, 0.001297793642152101, 0.07674350898953215, 0.03773155013820337, 0.03098706527042293, 0.03557307059846578, 0.03829923278141407, 0.035171992926587986, 0.019344279332266703, 0.12047506358113982, 0.08250540948563045, 0.08768470777619271, 0.031005619919949004, 0.05315478846070267, 0.07089320960785113, 0.023139298878489964, 0.04792010584365457, 0.026086448699296005, 0.014078886165554005, 0.07220089871196017, 0.056225337809132, 0.04699221248888681, 0.03578285611565075, 0.04715094973723735, 0.004735347944416947, 0.04147952422499657, 0.0049343569985320496, 0.03266410834546531, 0.03401973157099659, 0.0238947669089201, 0.03477266576561717, 0.05814510818210341, 0.01325400386591472, 0.013712931709784656, 0.024495031271550446, 0.03095797308149838, 0.07967322073396176, 0.019632669300922466, 0.04520456163933681, 0.012258960989363974, 0.08828736616358643, 0.02862232804839169, 0.09374374313460243, 0.011621834391037063, 0.06563821416949073, 0.03622557449665281, 0.09153804576565182, 0.04749911754662472, 0.024730965284810915, 0.02545731239801934, 0.10728645393805158, 0.054299285515181483, 0.05534421795258119, 0.020220434939068173, 0.0364008400919697, 0.021991097788897254, 0.06670669231924319, 0.022867197854324214, 0.027166931446821942, 0.05368743790313602, 0.011169744839501238, 0.03993931211410992, 0.06675694002619674, 0.03283905218385401, 0.033167749868645784, 0.011550047164482456, 0.004512045763417958, 0.049840312886742816, 0.02972652887805335, 0.033738041041238655, 0.021755577463115898, 0.041085613305650415, 0.06452030802686369, 0.04704797985933481, 0.04283155449816296, 0.058002439627964655, 0.05381236386094844, 0.009276267561701038, 0.056508012761872624, 0.041848108277566014, 0.015357186221667837, 0.024147535704316634, 0.008923822108866468, 0.061508747448603955, 0.022153981488137957, 0.028392877054190444, 0.05284110226878717, 0.0698127651647214, 0.021479393190313733, 0.02902788541940672, 0.05133958525895592, 0.00839460761316361, 0.038077094096450076, 0.034834140491101055, 0.03671491698872659, 0.03526737853404015, 0.029405729559760903, 0.007422313238719419, 0.0701946370123375, 0.08505492711499815, 0.044623790383939786, 0.02221390488557518, 0.008923229348335055, 0.030954029643908147, 0.045210889525591366, 0.043092189101322044, 0.051444623574254014, 0.013347525006881165, 0.01913895436202086, 0.02034921814957934, 0.052518801418163126, 0.045691636511154717, 0.008051407883965201, 0.015613974105837125, 0.0499970889500072, 0.02232768043364969, 0.03540001133637082, 0.06382821270474984, 0.030749397983233777, 0.050868621216185635, 0.024434743982349193, 0.03686347675900306, 0.015139150895148277, 0.028309921223309734, 0.002673988961877542, 0.0710382606954344, 0.0505659360468628, 0.029245260952701493, 0.053545658010989435, 0.026785770145755623, 0.038489249399712974, 0.045420364777167, 0.03148592448973608, 0.0789888207650473, 0.03444234014398629, 0.020196220815001477, 0.04607409441603288, 0.04007211728622356, 0.027238943711704305, 0.04428691088011669, 0.04391342769527147, 0.008425524048957854, 0.012206272334761679, 0.062133695164154616, 0.00837294839232439, 0.1086788647057068, 0.03628833624984949, 0.05698136316852705, 0.06850070935944397, 0.04137857298877451, 0.034359173638926405, 0.10218246975132536, 0.022995866151646744, 0.051663046732785246, 0.056499302342173555, 0.04709897067157492, 0.03426419788851373, 0.062266626740775766, 0.02840397575299346, 0.0318047319794254, 0.033568632188102895, 0.037623926276160825, 0.02381754907659225, 0.027787085367186416, 0.018663343995989814, 0.006982675009977914, 0.12114303862495769, 0.021389161439372167, 0.05511426900122916, 0.06122663557048767, 0.048310504249867894, 0.03299348784850971, 0.02839403767739573, 0.028192056680939374, 0.032891081045231516, 0.0548588284741967, 0.011903196460597459, 0.045739367619277015, 0.06899626865502327, 0.04072010892653658, 0.0055239617265009835, 0.01135608806620322, 0.02034927369095385, 0.03354494474948414, 0.059889023072056236, 0.01484079508020753, 0.0751081717410876, 0.010113690720660793, 0.03896745297336771, 0.06088807067323116, 0.06673979497845135, 0.05499594672132404, 0.018792088902104768, 0.04045562856199761, 0.017280829169096488, 0.01692657479115071, 0.00803548474645903, 0.04599430635871907, 0.062459799641322714, 0.07118600841251112, 0.019096934439374075, 0.07592491339892149, 0.045459603800648646, 0.03995829194243397, 0.006305204306338584, 0.030641689851519563, 0.05175077912187384, 0.03539217425690543, 0.034158585007272424, 0.0651609950188187, 0.004434812609331622, 0.020023889336434585, 0.010653228251143329, 0.03410295170221118, 0.03189866968070067, 0.02092414606933392, 0.09370297193527223, 0.0465756330278612, 0.07021446336781786, 0.030924506530526186, 0.028336831976869897, 0.023029261839485938, 0.08214557798759592, 0.030916845651283383, 0.039359391216308846, 0.023069125224625873, 0.03651454286169141, 0.05499072966255969, 0.04918007533096018, 0.03118582486715769, 0.0700228264735591, 0.031945489144193075, 0.02197412511093482, 0.038777750451117754, 0.07507242607854067, 0.09226264236795326, 0.05943194820335316, 0.02765816617606869, 0.11128900287252282, 0.028554257305879748, 0.11294456484216837, 0.044538605237199415, 0.019031326669538697, 0.01797371164655253, 0.04631770271507483, 0.0600791392817853, 0.08510796338199608, 0.025045084316403638, 0.027824328731625315, 0.026551521525928573, 0.02594271719816231, 0.03899285261849723, 0.022205918418964552, 0.05037459409645489, 0.056200949400062525, 0.03096461314858208, 0.05101189881022419, 0.02638033534880848, 0.01229277036468228, 0.018688963891397563, 0.0029036760069204555, 0.02658672135082945, 0.013397580234243745, 0.033019523346616377, 0.020170225536510832, 0.05161577910785714, 0.022441143800895062, 0.08711633182341054, 0.05836429742855891, 0.09613648853114537, 0.07581197671712407, 0.06253358539974978, 0.07729815664671122, 0.023476088366981958, 0.0865296693518758, 0.07184853657118737, 0.030710241314203992, 0.03552841533335947, 0.0229996525412125, 0.010856232932588507, 0.00831987573615005, 0.04023445514781822, 0.04925625128371101, 0.019414407020855336, 0.02188347009641509, 0.0030033126841449453, 0.02029728121875275, 0.028493035389410875, 0.07264385074977914, 0.0704313658418194, 0.04579014392689832, 0.012436611033345183, 0.04147036947430142, 0.018197761720887596, 0.05117507553809593, 0.04227736266329885, 0.05651333324250676, 0.021721967270657904, 0.05865321599788243, 0.0237197675291569, 0.015169300285408334, 0.016278699979246143, 0.003052389473586734, 0.013963063247501852, 0.03425854415963254, 0.06156532304181207, 0.15476955641661921, 0.1100995824221642, 0.148261746752166, 0.16439496088893185, 0.16895899098486672, 0.15046572042328699, 0.18453613254091433, 0.12433770953887895, 0.10965895929163504, 0.19096719551711314, 0.23589892643353633, 0.11589945023578983, 0.10611981694256106, 0.14256747649802318, 0.17767946175750227, 0.18841144959292105, 0.16224282072676768, 0.12391078406043592, 0.0857410277991045, 0.14994350892882194, 0.16297814256000906, 0.21081169195953878, 0.10689442376455954, 0.1249983607821407, 0.12132048757085878, 0.144157798420037, 0.18561443193785607, 0.15158721185739965, 0.17221621297780546, 0.14803074059947846, 0.08246169650867101, 0.15430365238458882, 0.13167143859449895, 0.1366383849733299, 0.13180302185637335, 0.12213838602145835, 0.21114549178990627, 0.11538742004983848, 0.17524022248483476, 0.15816934737226657, 0.13295094332387372, 0.1983119715606013, 0.16597734614005014, 0.15536981694880994, 0.09084317337481246, 0.14653184361034824, 0.16561330115843206, 0.15082614946990244, 0.1332157492757805, 0.1606814875718086, 0.10099196145611425, 0.07898136672954406, 0.17763584071109373, 0.1225652272302297, 0.09421193776952644, 0.2585847970218428, 0.25512646162702196, 0.1514334120457211, 0.16948169277560327, 0.28072859911668685, 0.3519392295950844, 0.199159249483097, 0.1173888553955382, 0.12271872060673854, 0.11763708320476356, 0.20999701873910046, 0.10102614429929566, 0.13217887991378385, 0.12739993151157133, 0.1486789888792461, 0.06998443780767341, 0.17111860816517185, 0.12350533202651048, 0.1083779913343249, 0.20315401496425753, 0.1113434793848184, 0.15382814160998792, 0.15319562877618498, 0.1365596924217478, 0.11427366610376105, 0.08119274847089283, 0.159218673323912, 0.12326815886603248, 0.12224582985283867, 0.14361035198934619, 0.0980110367339465, 0.2556631062179804, 0.16472575765463615, 0.17572757697874503, 0.1471583809583418, 0.13985578571596455, 0.14758550561964512, 0.1870525168675569, 0.10313835595884632, 0.11300659498139737, 0.20187933658880575, 0.2243096708890892, 0.2391008828436175, 0.1040698882312544, 0.15228695656743743, 0.15016541395696903, 0.1761017189992051, 0.1552224216321784, 0.10734545802997966, 0.16020358660288397, 0.24374982612507962, 0.12800397651810802, 0.08293798869295467, 0.34082963702178776, 0.07108464731924957, 0.17284527841594913, 0.1264917955643708, 0.13911165387159394, 0.09872215018878061, 0.08016207676020362, 0.24129050002703745, 0.2257550030105537, 0.13855521356867206, 0.28816109222750513, 0.17929517183332674, 0.12167722407367923, 0.10989984031766654, 0.15025739047315814, 0.13511486591831331, 0.23014012093265213, 0.08989179176428626, 0.11845142700739446, 0.13763659753866736, 0.17154174916926893, 0.24847553141655462, 0.08839838762557314, 0.16673722875214395, 0.11849887083254515, 0.16458936336059726, 0.12474179793629916, 0.14383663904042016, 0.1294074802389068, 0.09685467297752058, 0.10984789189552108, 0.19661609804438007, 0.1026038870575928, 0.17705939019158964, 0.1515070790605199, 0.1771937007264745, 0.20958475618352815, 0.17393494655768718, 0.22294934388370286, 0.14910122589959254, 0.18778511142778784, 0.10715980428240954, 0.08196961525226794, 0.08674418163155356, 0.12061842161441043, 0.13518022854001294, 0.08170110909568687, 0.09165822197833369, 0.12988741900171005, 0.17839740871662096, 0.21657857202714492, 0.2329327718865487, 0.1510514865719503, 0.19381431532242607, 0.13120677562490587, 0.16793606442309197, 0.1392650246740349, 0.17431696396200888, 0.23228525905118835, 0.15354467375624567, 0.14721936155711451, 0.12244744887275082, 0.09600541088730098, 0.15534289661915074, 0.12020582198015145, 0.0895035000998647, 0.1422973079306464, 0.13638119393539044], [0.01854085611299642, 0.0349998414786833, 0.022574657604338664, 0.03416392847054428, 0.0151329628199399, 0.05575238193775858, 0.04832418658019555, 0.036719471381436435, 0.05713847631047811, 0.023184747044597904, 0.05421855516972081, 0.05706318518927982, 0.0707155921226067, 0.03788952129862962, 0.03753386881022203, 0.04273664769566348, 0.05707625464926805, 0.031210228597985643, 0.042169711988178954, 0.03747048269536707, 0.04089378871985021, 0.03372623945676512, 0.05457517675935261, 0.09440724422494251, 0.06808987938829007, 0.021424284655480616, 0.01016695968686573, 0.04428937002235363, 0.021794059974772316, 0.052364526631971525, 0.04302229889998994, 0.06112910874728715, 0.0716506177559495, 0.047879610435977105, 0.052416501867194334, 0.04477605801976977, 0.009351779890787459, 0.039758044219906294, 0.033393113783770995, 0.0066913710343801695, 0.07992947714463358, 0.022295430047257293, 0.06141721526341093, 0.10835139276159388, 0.02721088191103791, 0.06617495069100011, 0.043943262989482576, 0.01707369048568991, 0.035880765982813416, 0.08778356376194185, 0.016313750417001786, 0.009661391452555696, 0.05773182672959182, 0.048677877883516976, 0.024243679738813834, 0.021538667328235124, 0.07543569731135523, 0.07797357806515309, 0.09069155691371811, 0.06581593124616532, 0.019704537924319025, 0.037522385152237075, 0.03853619526771288, 0.07915075643048172, 0.011310038521074721, 0.06424841193121768, 0.09041771878518405, 0.008978504507291702, 0.01821156471006332, 0.07036993325117134, 0.10120999774024372, 0.12620863414579822, 0.024795918049471035, 0.03876888298339421, 0.0540608789531454, 0.028297163944150654, 0.06321924558329968, 0.06758810711964484, 0.01466243448967655, 0.00863113438695549, 0.03921660774898145, 0.046411322489861524, 0.020673719587765878, 0.03900599868727788, 0.05652966623705241, 0.027932086659054604, 0.037746856574930494, 0.03556902565422558, 0.09321673592973141, 0.050716648524206494, 0.04893858143458924, 0.04436708198139264, 0.01586117918768357, 0.05421213152247572, 0.03491266067290018, 0.02481256322484584, 0.0546062263029237, 0.052662278195061994, 0.0400047590054812, 0.09433734636273115, 0.04271119442437926, 0.021048503206862558, 0.033655812993886015, 0.03384354283973094, 0.11988240264115796, 0.044350729834648876, 0.04052407851803207, 0.010901042372889577, 0.04384213172259831, 0.028232209264270725, 0.05247248757270075, 0.050018267450673934, 0.0542769348999906, 0.03436646679596555, 0.021831527419929064, 0.05997955934294771, 0.030846710301815506, 0.061519901688781485, 0.06450327789230693, 0.02131727174855769, 0.04952469998369775, 0.0897524327099804, 0.02616002569876371, 0.03489214100784833, 0.030791076996754256, 0.02699148390562304, 0.012495991465966068, 0.05384069379238833, 0.04402781611368541, 0.02483802224178949, 0.003903365685536917, 0.04690830287854037, 0.07976236272483103, 0.032609804202952695, 0.031101555195486838, 0.03457191242505947, 0.014622848811409166, 0.03981895204032621, 0.047458488073560505, 0.09938809509959914, 0.036300386812898426, 0.021732815075665716, 0.030631558338720954, 0.08831139068089186, 0.017372686941657337, 0.049033112854005835, 0.06250334407893882, 0.07005730809103097, 0.05281703944708552, 0.03615443940244375, 0.0710071038995539, 0.02444364209358971, 0.02503091552024407, 0.04975548780132687, 0.04066809155647794, 0.12052553345359142, 0.015664514841421718, 0.04488995614191217, 0.06308263295420236, 0.07290401420886479, 0.07128420556264539, 0.03357315210685615, 0.020388589323227926, 0.06578999916992842, 0.08003679840194602, 0.03388943150639534, 0.03845852927394933, 0.03629796214461808, 0.06736339054881565, 0.06173732510257152, 0.03111764495711654, 0.07586164985813441, 0.0481474615873829, 0.012913816777478545, 0.07387621808917293, 0.0813095385749494, 0.037864359140756636, 0.08524659465277389, 0.056212203231670206, 0.02431947456282233, 0.010476996427431945, 0.044429587095134684, 0.07403531156840824, 0.04201840579269394, 0.04436808938701307, 0.023081911232082114, 0.016890698893656655, 0.01070989481729245, 0.015473651695966482, 0.030732205054993113, 0.023716862140704068, 0.020157920249227076, 0.08222659944646782, 0.03159434508321987, 0.03134471150265346, 0.046197495858875975, 0.0179623773757128, 0.030437169273594217, 0.039059234137136134, 0.01586550854206566, 0.07404362362238669, 0.030402942380357175, 0.0058245224382488005, 0.046805467066024585, 0.02127116857727449, 0.02476097294880498, 0.034696547269460656, 0.05399819380874115, 0.0812045002596513, 0.05326354996331277, 0.03819750013550924, 0.07596818204488485, 0.0604315358965147, 0.09890544438554395, 0.04384713427674386, 0.00641984649137744, 0.033617826524160566, 0.0517401228388471, 0.09775297235577338, 0.01716328063799489, 0.0174583010976353, 0.017593827797099948, 0.013240692130620442, 0.04382613197629971, 0.04604215238003, 0.007915398070303304, 0.03516715508134615, 0.09555088326094613, 0.05934437286228903, 0.022062615927068457, 0.01178911256213342, 0.012839501460773811, 0.05255343625321985, 0.016850442888455528, 0.005072995930189087, 0.05361865086841488, 0.005044973391528812, 0.0181435514241457, 0.051036907750512325, 0.04783231599797164, 0.038248628843575716, 0.05472105139145448, 0.059468417818988525, 0.0066572571391119596, 0.0377618374242898, 0.04500039920751606, 0.03810674552955935, 0.034725053401123133, 0.023168222528071176, 0.06451799444133235, 0.03933856128564766, 0.04846196749337739, 0.10131135883350527, 0.04201906845874844, 0.028316509579458547, 0.029227407273626136, 0.05820208980191139, 0.016563527639054002, 0.08268986047515947, 0.03146930995787824, 0.02351382011247258, 0.009008505468016431, 0.03449456435778449, 0.03541027308411656, 0.011579128819698048, 0.07152979802941123, 0.025692250496978243, 0.05355982297670938, 0.027690412732021465, 0.028975073233126637, 0.07983796028119904, 0.046483261976391084, 0.06675275718613018, 0.02881759619941154, 0.05534682648196336, 0.023903084708557978, 0.03014406594898432, 0.05533356549999407, 0.049418684906296195, 0.027487585208408778, 0.041833736468106515, 0.04522660198891836, 0.016449491621085232, 0.04385783652504606, 0.03603786763344561, 0.009054580868612374, 0.03982393544227366, 0.03183747649252896, 0.012109001193405881, 0.12510470144691008, 0.06323030406248666, 0.1347239159287945, 0.06956665175816706, 0.07117794916754769, 0.015622371387097145, 0.05753851593321851, 0.06850416441598246, 0.06273705069155944, 0.020714170945387696, 0.06096307068101822, 0.05230050083369978, 0.014495539362542333, 0.019247294516272603, 0.023970759000569105, 0.038051407168348955, 0.02174509354987212, 0.05566730404332761, 0.0843669112110811, 0.026968637248501185, 0.01578412031860001, 0.012718806223523234, 0.03840321772581628, 0.06943513744420583, 0.029687829946558324, 0.01664134301996279, 0.003016321096501704, 0.031193118024196838, 0.034661441290330504, 0.015923049406058366, 0.09242846209916378, 0.036647432303476724, 0.0733906792236432, 0.050104318276768735, 0.013682964265406614, 0.028818157358816075, 0.047095894828558936, 0.0377059091753777, 0.05834364752855994, 0.05083367611551958, 0.08311552190852743, 0.024483697000710715, 0.031992950206322056, 0.050765593881688775, 0.05594505305071512, 0.03309590231266714, 0.06675428936197873, 0.03651738121745087, 0.010804895465562661, 0.01802692219855324, 0.03239828349661923, 0.03488356465353601, 0.0620244280435145, 0.0181084013949599, 0.01633255021466363, 0.02593563854574196, 0.012469338309470446, 0.06570679436047232, 0.0804633561581854, 0.027589545765471075, 0.07626483427180399, 0.027763890140059016, 0.041909985199210145, 0.13069315963695127, 0.10090158606368689, 0.14236282376993087, 0.21131119660792813, 0.09312450660452729, 0.1550169108856109, 0.19534733386770373, 0.1795305293654242, 0.11728673587523161, 0.0876405734508749, 0.15585828993108966, 0.08587238889548086, 0.1987150410610822, 0.22415747986205165, 0.17247646836744202, 0.11938911862671377, 0.20732064461035116, 0.15316032744463415, 0.08811062201857568, 0.15379726826663942, 0.15183232934965243, 0.15370112423214222, 0.18955376329681567, 0.17090258669228325, 0.1732937616085814, 0.15470160441773553, 0.12041662639427571, 0.195207032525251, 0.11013469223173396, 0.12322498981149928, 0.14704524509368405, 0.15358043474055108, 0.23267179637426333, 0.1321084457900255, 0.12668498761711583, 0.20488969440902435, 0.13995747622703353, 0.16447872494257268, 0.17268706593782673, 0.10357547040668227, 0.13278056536951374, 0.14620768116606822, 0.23525038704035744, 0.15792894898162735, 0.13444777187560836, 0.10216754635856037, 0.09605372805268535, 0.10135850388436549, 0.15994452631040929, 0.14088713924490637, 0.08684571126415845, 0.19940660395208867, 0.10610034298752585, 0.10726713320060123, 0.12381399651208233, 0.08997184795237358, 0.13446107116197387, 0.2833065769124416, 0.1740186340025356, 0.14102194007606278, 0.12352060015884139, 0.20878163556898796, 0.12047523212048317, 0.22986851211997772, 0.14915106757994623, 0.101335329724656, 0.17508017139569407, 0.09208104122550258, 0.13956957526745337, 0.22168405774620273, 0.24347265551407493, 0.21870582965352844, 0.11410875801718044, 0.1817975214291965, 0.09593941241262421, 0.09956021207354723, 0.2746948293380199, 0.2066055321765523, 0.1544096942750677, 0.11031676068781845, 0.15599744214165598, 0.07953036831872118, 0.14487813557347945, 0.15397831016490537, 0.13828270077224702, 0.13366833869968692, 0.1359101264707504, 0.12417677744862535, 0.19900898899762862, 0.16110392377501534, 0.1346378689331393, 0.1446907964324759, 0.09221181243417725, 0.1334571129372043, 0.18455484040802528, 0.12311293413081478, 0.18976357945751762, 0.1904188144591547, 0.13454039190565387, 0.16190646216273308, 0.12811528909350597, 0.08200284048554399, 0.137888778361582, 0.10778156890263481, 0.25900838235693596, 0.1326261220439788, 0.12234242587921121, 0.13977743024306913, 0.16569472098302457, 0.14983556714029084, 0.1759366117297642, 0.11081453397749894, 0.1941937586713222, 0.18635508574305043, 0.09896266349260846, 0.3123432091407238, 0.22138293922668506, 0.2412230689679423, 0.1676019121922793, 0.11239598460134961, 0.12135433333535349, 0.14366379428294399, 0.06001988238084221, 0.08121016931029097, 0.19209123036313444, 0.10550562127102768, 0.08271867304199165, 0.1210895427052052, 0.1736921732944827, 0.07020169268212012, 0.07796763322286068, 0.18470698546978737, 0.1613087297206925, 0.1339520976668404, 0.1490388510207976, 0.12053000740706922, 0.16806397046292984, 0.07679959428646872, 0.10984373969897149, 0.2120455838139019, 0.13404669420373055, 0.1390745598943003, 0.1377569499515718, 0.1733587258645604, 0.15918711050143167, 0.11714902390996296, 0.1895661892429475, 0.2361908978632381, 0.19935227299649871, 0.16879186124330567, 0.1964654238714326, 0.18517374752029298, 0.15251880541684168, 0.1310419441471177, 0.11196833133937852, 0.16325186577535447, 0.14216433038874982, 0.11489051243951244, 0.11224197028505226, 0.1740181896715395, 0.1821038340248408, 0.11697541306456251, 0.08154146403314606, 0.12292279110800837, 0.12938371619149563, 0.1282118851198785, 0.10659199523469133, 0.07130461414494822, 0.19080303819669833, 0.11607189662754537, 0.12232708113808786, 0.27967093812842525, 0.12429588879909247, 0.1477825281120116, 0.11838902914596182, 0.13039507482561374], [0.027154731496627775, 0.024178993189707402, 0.015608258132312088, 0.0620248762049502, 0.052786139290659666, 0.058517089834617037, 0.049178953012151104, 0.013400883988417206, 0.07791700247194498, 0.030512017979016228, 0.025596931922219457, 0.04864730331445894, 0.05225390353570542, 0.054752916818664926, 0.028078800157433557, 0.08004149452092187, 0.026329514991131522, 0.06426469513004826, 0.027141422634163213, 0.047112798558608185, 0.04528407390499788, 0.08003450779905243, 0.03466366294531092, 0.019135009009210814, 0.042236579972649776, 0.06546087247589905, 0.04174852067784917, 0.025397157258985024, 0.03323778945712313, 0.02830108631432297, 0.023077194045688358, 0.014920727736617049, 0.035023869826428355, 0.01565996715198121, 0.02146362135517261, 0.059776645634443536, 0.031000987003226916, 0.02141593429710596, 0.06635494304880982, 0.01916149075353338, 0.0604452986660744, 0.03722807332392662, 0.04789952106112915, 0.022711657107837742, 0.01322932147060431, 0.03730516092130735, 0.02332800357121854, 0.05099381147433193, 0.025496472897488746, 0.01272380590483907, 0.07683905547544842, 0.06387072292366816, 0.027799009525727843, 0.032748297577904116, 0.014256229774365503, 0.04207073342836192, 0.024702078024406108, 0.060558664357109424, 0.03356344960329514, 0.09250284923661141, 0.03174399652878844, 0.06613168204503675, 0.022494568857514573, 0.09437229529383684, 0.018340033824525533, 0.028338984683937127, 0.048136717204244873, 0.029895303793431773, 0.032860169397486795, 0.06692127354683415, 0.05936135703157033, 0.026454979125710747, 0.0520827288499042, 0.019701004343768282, 0.059351784762956446, 0.05495177792204965, 0.04422603370321374, 0.07173120254470457, 0.07150280875183883, 0.039942740357571074, 0.012935224146912656, 0.027674541305450183, 0.004303552540800264, 0.04469499825650165, 0.046205133755481055, 0.02885851295544736, 0.09863653986324226, 0.02987772973644878, 0.016422257195377064, 0.0040574625956886, 0.10144583790773347, 0.033958865885412505, 0.03816417148036342, 0.024171085247109016, 0.03892864678956328, 0.06622725151359074, 0.05166894944024183, 0.034543774015600645, 0.05900373186675772, 0.017418621573597193, 0.05713393340908712, 0.06787853105173958, 0.026939751903316187, 0.05773854149024814, 0.07914899442825588, 0.05585735130514349, 0.019102749046719363, 0.10321251326991666, 0.0630123060827534, 0.029189522310550657, 0.07106702729699112, 0.05844402419883878, 0.09330891162878083, 0.02958434678974652, 0.05128331610091752, 0.015149981463177791, 0.05118730613180707, 0.01951525291998781, 0.04842974583528215, 0.04545614874411014, 0.020790927209741166, 0.06389987256918704, 0.003785022098811404, 0.06824495090592293, 0.025985164214826884, 0.03117107575939548, 0.08317679362071138, 0.05011814233336238, 0.10911690611993113, 0.02387589433290545, 0.029670774914144032, 0.02351436211967901, 0.0637824772556703, 0.023118072497327963, 0.026041458270722823, 0.043754188659330534, 0.02874319182498561, 0.03992703938556295, 0.02268248256446133, 0.024418790201326052, 0.020760659075852846, 0.0316852682285131, 0.0600204722685439, 0.043902039798277046, 0.03190948109653208, 0.026367832793884223, 0.032298201770191236, 0.03361090491976469, 0.047934033322117986, 0.10450994445671959, 0.03539155755612639, 0.06149680796830405, 0.04880104566954317, 0.07467546229881626, 0.06514893679489052, 0.030923041387371, 0.013346846061458272, 0.01443465069432052, 0.013261202219573241, 0.0345332249848833, 0.059011113123908165, 0.08067820551654986, 0.014005392478148063, 0.0607512167264377, 0.07341993612147148, 0.04998459022552256, 0.09987734949156162, 0.031398806886206714, 0.02592310726252054, 0.02208447241554818, 0.0431440647451147, 0.008800594951026142, 0.0783386649263482, 0.07078643227296491, 0.013722479080541, 0.03769076361711468, 0.06717261933391133, 0.06753104123016519, 0.0612547739799465, 0.046158620727158366, 0.0482498339167045, 0.014870475241613966, 0.07284455046418213, 0.02852767788534684, 0.07678961982169459, 0.014923094948303076, 0.04616291081953434, 0.06522605886622783, 0.027200681450326118, 0.06496885250652991, 0.040289058064621304, 0.07094596242231709, 0.044237900405160846, 0.05303735867322934, 0.037289299070835114, 0.006923794449727622, 0.05024477283680632, 0.05050532700073335, 0.009819941966974688, 0.02603060472005558, 0.017722404163871563, 0.02446690818385011, 0.023018703232669545, 0.09240104381235377, 0.016256851151645664, 0.0590123005601908, 0.07991283771491821, 0.041182427667081356, 0.059130933105705254, 0.005484647051836815, 0.055004366027611884, 0.040510193174404484, 0.0397352071388835, 0.045769325487556, 0.039872708429972974, 0.0342937956954683, 0.04051837882387542, 0.007705029847490932, 0.09661881748827235, 0.01840169815677068, 0.009122591281700279, 0.021322697566281405, 0.02084282392095174, 0.05294575754012312, 0.021803381349591, 0.046386803845844926, 0.047405566719751206, 0.0897537197376932, 0.02220973545204728, 0.03602055404635687, 0.020938699824675437, 0.04647390804283562, 0.021095041133042787, 0.07011229022135658, 0.03612259695787103, 0.021409123775459105, 0.05624654312287608, 0.0077183454132248325, 0.030857671104792147, 0.04978023244128112, 0.025698926953238346, 0.035643983527176806, 0.05200580596142719, 0.029318759428156965, 0.07624100893735886, 0.07017143986999028, 0.03724313461251798, 0.04762184483209445, 0.04349135538382877, 0.020831024251698006, 0.042301337384889205, 0.046061411830446417, 0.03578169166200584, 0.06786410561612538, 0.030458998948996587, 0.05402340959276884, 0.029581657821132295, 0.030591461296764114, 0.05864015419877345, 0.027601753376544486, 0.0735557098842917, 0.02680370234884322, 0.06111390190199018, 0.019732540353171287, 0.029640437832342523, 0.023478424935151013, 0.037527146388686476, 0.04044514464875383, 0.05199988793221213, 0.06194586955731916, 0.026812209755242355, 0.05062059258982059, 0.021492217502166188, 0.027434422536903334, 0.053163276714903694, 0.04841017994969603, 0.06312060793260894, 0.05455608201783992, 0.04502296049688612, 0.11418570388829517, 0.043643485123832385, 0.03538019264176969, 0.057837056566870985, 0.011010078709542511, 0.0101052982274503, 0.0513473840340251, 0.055415452638220404, 0.04949823164591386, 0.08560743738686846, 0.042764824409518516, 0.05155301735466046, 0.08882295355320939, 0.06850580384414043, 0.06476072173926138, 0.019550420186151902, 0.015382108977064492, 0.04846317025141851, 0.005134866627368836, 0.07230451976459834, 0.030265284041243217, 0.04624810745759357, 0.03957806335341546, 0.06685457027126705, 0.06318902341468681, 0.09158834709876007, 0.0734541802516868, 0.03308331165763159, 0.020243174343880628, 0.03584627670446231, 0.030575503685301354, 0.023663050209682797, 0.02696286477599173, 0.007470219589454393, 0.012198441958565627, 0.027526299461662292, 0.049266375135630376, 0.05799597767632335, 0.04229336240959745, 0.008524372373827764, 0.0116817252297375, 0.059957430893254865, 0.04513034687167214, 0.028319374748295354, 0.04884215394756006, 0.027762059189919985, 0.13039269995304847, 0.012129984341651924, 0.05030369648950235, 0.021763380068624695, 0.06426461852125584, 0.04354239216134433, 0.07951109354654629, 0.13939061712834144, 0.022369623747504046, 0.019718114917557088, 0.019930085700546062, 0.055396028478900274, 0.010866573204346483, 0.02873158176249314, 0.057627581315295356, 0.08981549706790717, 0.05781081039458514, 0.0223631005088288, 0.04641585773037327, 0.08232920926304595, 0.03440491674888519, 0.055335526685080225, 0.025326008758237286, 0.0804292269411587, 0.10178063365240252, 0.05356067333430533, 0.038700712649452115, 0.19605974967200912, 0.13854684788853894, 0.11164222303177081, 0.16341128867239724, 0.14261318130358575, 0.22140445097559885, 0.3518284532812334, 0.13210389522775529, 0.21999487983843974, 0.175087679057352, 0.11226587988916906, 0.16902274482192534, 0.14888823813488408, 0.12355443060157761, 0.169988781694443, 0.1552158945630635, 0.10707200294540775, 0.13046769996083554, 0.12740432885625672, 0.10635673729402405, 0.20095469910771618, 0.08977100268126496, 0.12317883301406138, 0.06150236210575508, 0.08052937761549989, 0.19582721134347303, 0.08318334367246398, 0.21209570128590832, 0.15564649726354307, 0.11514720552030111, 0.1375166741350005, 0.14081405445693002, 0.19113648562662064, 0.0711385952308774, 0.18461572907624707, 0.1129902619868517, 0.10173255397427468, 0.11616149061028996, 0.11010326730507998, 0.12738811843577894, 0.21067033341575056, 0.1267563180637456, 0.234972465663187, 0.11979554359230304, 0.07518842711203522, 0.1144063448713672, 0.13213524354561684, 0.10348223750629734, 0.10449745722355382, 0.08916248372125049, 0.14227075532319086, 0.25795452116477874, 0.07279660102100143, 0.105772526303847, 0.04356034160141022, 0.12711320012327165, 0.09711089874467543, 0.17508145842340686, 0.16930584495346393, 0.24112548468814743, 0.15610510813853434, 0.10407125186775962, 0.09961139440776841, 0.10357598368559154, 0.13469851245322537, 0.17014377660328345, 0.14032711365049885, 0.05842370754708687, 0.25555092030234877, 0.18770836473953342, 0.15773708992187055, 0.17826648429036143, 0.15752067008326132, 0.13785638816414342, 0.1723393539507543, 0.19002928939317504, 0.10708304993327587, 0.16061178889245759, 0.22573759749291405, 0.12583325872378004, 0.15240844279046983, 0.21767643730967276, 0.14744037792326944, 0.12613538081847853, 0.16738878653174447, 0.08460797609821444, 0.1414407756660254, 0.13689238908550433, 0.09219947841859634, 0.12344601383853344, 0.15873885713517666, 0.15869621668131123, 0.19327944805545194, 0.15840755475144233, 0.12203377671539785, 0.15257146630075671, 0.11454414110630752, 0.12515259726393607, 0.20330602213019328, 0.11845568645625346, 0.21054360715131606, 0.14804947911010635, 0.17307109049251004, 0.220370446782439, 0.15182471443568507, 0.10832203627233544, 0.11885454247315085, 0.1755665912623367, 0.13856259865626214, 0.21331014982875318, 0.2349059079443255, 0.164367642193552, 0.22044227518621953, 0.10226909897380299, 0.0965295912277314, 0.17221783708420493, 0.20373789653662713, 0.0940286818771593, 0.08925832132057798, 0.1302266886998569, 0.1503289737288029, 0.13365635708455118, 0.11220349734949489, 0.1818297890525672, 0.07531539852460546, 0.09142585218914094, 0.13998910033654782, 0.1709577909881069, 0.21331900580515786, 0.17539238286835535, 0.08725905400370398, 0.1022861214474805, 0.08651800949366824, 0.16589108463977614, 0.13322653579375437, 0.19104191973324747, 0.12336496173614457, 0.13282674514958936, 0.1501008021014352, 0.1348651059332394, 0.10805498568281051, 0.1910500709087618, 0.08490915590476605, 0.09709771437149856, 0.12270291621286063, 0.09365898316666003, 0.221972857571898, 0.12977664268785907, 0.10154930574278678, 0.26611970076637886, 0.1047074955497538, 0.18403504975140098, 0.13298100461402249, 0.16106558873528437, 0.09670508664942558, 0.1542936472762977, 0.15501006205956783, 0.09147209325625051, 0.12151197890841192, 0.14778787540572305, 0.11657827308461552, 0.17025023218124144, 0.11264065010172707, 0.1461170836081428, 0.203900920046914, 0.18643048411655813, 0.10791767208326249, 0.08507715132568153, 0.21363190675695098, 0.13321008022514083, 0.15224290651179131, 0.08521540721337642, 0.14778001534361995, 0.15340671664284122, 0.10185295235245459, 0.09575486183166505], [0.031395805736763344, 0.020436408531461513, 0.00936960962961518, 0.06517548174146684, 0.06044487731771604, 0.04673304494410273, 0.030842219111359412, 0.021029245671665957, 0.03260337672526798, 0.0590260288557939, 0.04319042455585253, 0.018103735919501034, 0.03079475038835118, 0.04280870975626092, 0.013773789734489495, 0.03940017007651829, 0.020379984240618446, 0.014318928325308428, 0.040637708509400974, 0.05557607829330429, 0.026289144072741754, 0.011472701012427288, 0.027993655230309215, 0.06614868919695578, 0.018351278080034162, 0.03664828266107267, 0.03913043817925838, 0.026479689291708415, 0.042274214041930054, 0.04342546033102178, 0.01633770981683366, 0.028931850552438732, 0.04807983900630667, 0.05488513976395611, 0.04357376729228324, 0.10422718140386766, 0.017396709543742964, 0.0099254303589283, 0.05787073379202236, 0.02552764884556734, 0.027973771418234514, 0.02977183148745568, 0.01572889687057825, 0.09802658065793016, 0.07146398341583629, 0.06885917722097329, 0.04888484036670097, 0.10065421627293672, 0.13600438592895386, 0.011129250389433677, 0.022207103940027378, 0.03891767641048759, 0.03966013052230401, 0.06026397331527645, 0.00878741153545918, 0.06951371508259928, 0.024848695761794527, 0.061191016312448256, 0.05688745994120837, 0.004064876411575824, 0.020783760457209522, 0.03763775416319409, 0.049922648186404864, 0.027051836312297853, 0.007567273353361675, 0.04684104035878855, 0.004299309371309656, 0.03771694084148734, 0.04622822747595849, 0.019715199953005202, 0.0660829205486563, 0.026164597328451854, 0.018278493981568084, 0.027502439653260574, 0.0869174860417843, 0.03613656274073067, 0.013409336811051735, 0.016447342744457628, 0.030661146569576476, 0.014062719795131877, 0.10792913275860971, 0.09207122763919254, 0.007752970672182499, 0.03516423628635464, 0.04515539028591687, 0.023338728802158468, 0.008856545224966062, 0.06700674597654613, 0.02486288179493239, 0.04405502755675585, 0.04242576155511122, 0.034193909321461, 0.03857732269792788, 0.05921896809952394, 0.04167937358180362, 0.03576004967814492, 0.04868527829286553, 0.06256741584248601, 0.10932427079927538, 0.01686375749657952, 0.018803141635632323, 0.0191269880686436, 0.021954367703367627, 0.019900424691337733, 0.04393017054685662, 0.05508034662794202, 0.005234926328769015, 0.03662643000303257, 0.03768612878517278, 0.029837810809934334, 0.028219758420281356, 0.010577530145735271, 0.05333139470988705, 0.034513107515991695, 0.018990226052401048, 0.06034631627581774, 0.02702580272941099, 0.020881057454032764, 0.03394006225731104, 0.024943529785941207, 0.02426251209521246, 0.058514224665780226, 0.059304203041979385, 0.024458027309587887, 0.05580099021655418, 0.020896790984777674, 0.0204780530710254, 0.015463819915068247, 0.08091435978008855, 0.013272803663576563, 0.08423679117714206, 0.05069657319015072, 0.01787166298937894, 0.049980403555016366, 0.018642042921255195, 0.07535507421820395, 0.01566894091440425, 0.030697629591750524, 0.047792847148112716, 0.026444236657792525, 0.04511392577701519, 0.019742263924150218, 0.03699298775304229, 0.01584876760570032, 0.05140114042367186, 0.05029782059512312, 0.02692205718748512, 0.0865219931508745, 0.04715269258726509, 0.03599191767974727, 0.03596784719716638, 0.03849300706098157, 0.040791531303717245, 0.05140013684849105, 0.04422124948412661, 0.0156530216073377, 0.012503568075537201, 0.06597176885172244, 0.055486220010225816, 0.044996741137677626, 0.03156396395136272, 0.03969075871751674, 0.13082650490105152, 0.036109822441733656, 0.08142389251940674, 0.04247446176445773, 0.03137199572407671, 0.027687131960485733, 0.027280295222637155, 0.03977878988089581, 0.05689624313926024, 0.04567418502823961, 0.03290845591935419, 0.05400693870239681, 0.03033748016722741, 0.07323725479504756, 0.027553279163135637, 0.0072567870149449, 0.08125464071429546, 0.04729032028286208, 0.005119050742172066, 0.057125663489944516, 0.027861974292224454, 0.04339321185984919, 0.008326809789474693, 0.006979417221079911, 0.00973225650077145, 0.03209022422050757, 0.04402983475536589, 0.04547289542613491, 0.027664001850831895, 0.01769779167408424, 0.01852018706079933, 0.02606619524979784, 0.030593347788277655, 0.08752369141626744, 0.010817172982159161, 0.04603045804786586, 0.03589548253183884, 0.028006766825133277, 0.027743573488307097, 0.04465816474910225, 0.0379345634381377, 0.01118174369161528, 0.02704327336452421, 0.03675220248800132, 0.05863095348280284, 0.02766704130467148, 0.04070645340928628, 0.03700472422004227, 0.00863668948201643, 0.043199334158411914, 0.06202232513216235, 0.008538014484539388, 0.05741576566511104, 0.013483634890778171, 0.04383228366233168, 0.04866702241762992, 0.06178554267652574, 0.07522794192716961, 0.026880876131115422, 0.041939583006164724, 0.014791884196681843, 0.010216569625622323, 0.04152279287095993, 0.047681013632926254, 0.027059751915775483, 0.04211522015412489, 0.0726509830283542, 0.05985900008630368, 0.016066219747787523, 0.01079520924137004, 0.044561940275373, 0.019877101144483014, 0.044108132771666975, 0.015383872894510148, 0.04983415737027123, 0.043300932738929994, 0.040218011070523536, 0.04275673452103811, 0.02709500536683106, 0.08712580833103388, 0.02496814802138796, 0.015950639105041423, 0.05336570778801557, 0.02403401296525713, 0.05596974023407506, 0.03199955005378973, 0.023091223030801744, 0.039437287036449685, 0.07096198132081379, 0.045144078997714866, 0.05062598967924715, 0.034935555210517305, 0.020873055665663654, 0.022498834052033, 0.04366094809806636, 0.04677663534699429, 0.0249753856370526, 0.006167130364525703, 0.01871217444028345, 0.03094035497445974, 0.0691789346596887, 0.00881186985005174, 0.09234382470528926, 0.030533386086444222, 0.043318453169758284, 0.031169679564153476, 0.03582543911292188, 0.05890193027293971, 0.031210674844201536, 0.023342377295897856, 0.03409185108818835, 0.007556330744973234, 0.05349125427704665, 0.03642389550805092, 0.019014091606462197, 0.02004170854155335, 0.057142567219993765, 0.03913425712756092, 0.0037238569207294217, 0.0338794378894231, 0.03337649733669335, 0.03255752636299979, 0.02463030324678027, 0.03608465262298142, 0.04948381770161852, 0.043522117644428246, 0.022228958513287288, 0.014740666430894167, 0.06042079534381629, 0.02168145271078233, 0.035312956935095216, 0.05159565014764667, 0.08432931161575741, 0.0432760923379852, 0.025793588607602065, 0.05620052039082493, 0.03544570082017491, 0.06516389849205172, 0.021773377516036554, 0.04240327687453359, 0.028261822392983783, 0.04444973137710364, 0.05029441916473931, 0.044536329956064304, 0.0831291199691834, 0.03663288429379463, 0.0186809889161058, 0.012094208035588026, 0.01782094605357176, 0.08228328995286457, 0.07095416722398612, 0.01949398631920978, 0.027639613441762426, 0.03417891698078283, 0.02913945846469893, 0.037922290709590724, 0.042193993144939025, 0.0015733433786907325, 0.05923047474014664, 0.024681435785286372, 0.035814154637797226, 0.08032098637833711, 0.006833574668909874, 0.068477519877976, 0.07274364136279592, 0.04794013521243488, 0.038847315065082044, 0.01897324571355937, 0.10268324610566902, 0.051225798219562545, 0.03579107240863866, 0.07805318226136508, 0.045903827544421925, 0.051339983624676545, 0.025451997663044644, 0.009858797946494195, 0.02933760519109426, 0.04267168343968449, 0.038554608190972964, 0.060052747552793835, 0.02588013547562784, 0.03272074522570737, 0.08065832553491478, 0.02305680078514401, 0.09177849012156648, 0.03826936684368599, 0.017445878981943094, 0.02034265469128807, 0.007253572797297591, 0.005837828906688599, 0.1722240423963916, 0.14364455015428607, 0.1525771200296379, 0.17597601929258916, 0.2855417763273562, 0.1541331058908855, 0.09937602155391248, 0.14845248732355334, 0.11912056650485724, 0.17156693814021928, 0.08845329314710633, 0.17182155512273314, 0.14488133782100293, 0.09438996128137074, 0.1231701379161208, 0.16469477705897825, 0.0659019782418205, 0.10207447433663953, 0.13297038663539196, 0.2976696223260895, 0.09984341945739524, 0.12226693557515261, 0.13075558048102165, 0.16378529279703097, 0.14274464199139228, 0.10971517482351874, 0.150397002336479, 0.12004963963502839, 0.11903455781359827, 0.2665716926417043, 0.1538350823665819, 0.12050261210289695, 0.20603257501798294, 0.1268628272678583, 0.210065629573599, 0.1813182874672836, 0.14815294694515968, 0.1003819409637682, 0.09979894039251151, 0.19317838573648086, 0.09227002745554333, 0.1852206780665344, 0.11128508050235049, 0.13867322175252822, 0.14024449872874445, 0.2227378423295675, 0.18699625537039774, 0.23965130169545454, 0.1832878995206087, 0.11127391094041449, 0.16302127331014604, 0.1484676711862126, 0.16272354089925367, 0.14890043425463861, 0.08792475376638674, 0.1655586484459139, 0.0791248549977618, 0.07599130257843964, 0.1481725128307458, 0.14521631742677382, 0.19394016824662688, 0.12726006683923546, 0.138643650758651, 0.09909905778664736, 0.14399612322449684, 0.1590398224371095, 0.08900023395976714, 0.19931733938715152, 0.2460980694741011, 0.08864142135867188, 0.16904496137172947, 0.07981773555999802, 0.19478004575977403, 0.09963741841455621, 0.17376743377216403, 0.06758331140923886, 0.12176150906710856, 0.1331067349641554, 0.18597835434540627, 0.089789335165293, 0.1887049685202299, 0.37322841464511813, 0.06668213154039075, 0.1070329248003902, 0.09508292611327865, 0.10222293451548585, 0.19982557743787768, 0.1864677619549536, 0.17048384303287153, 0.09031804308535592, 0.20394752883622724, 0.12039145274508385, 0.1334981139629118, 0.14552252277010871, 0.17513626435350987, 0.14835007668983552, 0.23229823658062568, 0.16869393988482415, 0.2051879784032222, 0.12172397075881883, 0.13403028460039249, 0.10558720963496356, 0.13148863469400715, 0.15823561397771682, 0.11865393468929876, 0.1252287540644888, 0.050012732465421005, 0.19669322777659665, 0.07796959440794685, 0.09091344662010671, 0.14485173618360875, 0.09501836022302028, 0.12092864125846856, 0.10783259801927114, 0.18929242006232663, 0.09413182795528444, 0.09176710605501168, 0.10413753379496837, 0.17867724531360213, 0.127737806929696, 0.06005390051511988, 0.13869868651513131, 0.18158004438925177, 0.06481796382896363, 0.14667910103115345, 0.0956907632550405, 0.05084783725079991, 0.12237375887531428, 0.23252751137460434, 0.11998574024126415, 0.21015691661065627, 0.0957811999345018, 0.07592724230621131, 0.13479793534403847, 0.15603119597559975, 0.18978429447499015, 0.1255913894443262, 0.1333843192626392, 0.1316212291919416, 0.12462288576869235, 0.14050538231047893, 0.18628843609363804, 0.10106142264820876, 0.1308875467868582, 0.20403388226705216, 0.14024382457137108, 0.14764009704512937, 0.16458712638385836, 0.18828081628007276, 0.1679110286697265, 0.15077085324352787, 0.11699022154413885, 0.19638850864383484, 0.16593496615607894, 0.22272756142962366, 0.12623203047100576, 0.10036471930723037, 0.19789374884097807, 0.1980736722508746, 0.10862781260643276, 0.15537983737885952, 0.1994363894505847, 0.23168682180825742, 0.10975845113036134, 0.20060700244240223, 0.14864604709850204, 0.11919469317241062, 0.06719212393246352, 0.1251234476184172, 0.06278551341364942, 0.20103797286508546, 0.09909905778664736, 0.19170639375525136, 0.11168250393482948, 0.08116416573043793, 0.16525671787319646], [0.013519212971591662, 0.022191638540055965, 0.06821626857403787, 0.026123458406917995, 0.04235998907637212, 0.05167347701987432, 0.0253936983720069, 0.03091755045217372, 0.027256864423473037, 0.023424120792638392, 0.0544689012120568, 0.03392451833332739, 0.05507450520751938, 0.02692768218806915, 0.04054153000094718, 0.05098514701990832, 0.01901683228601131, 0.026980737607265194, 0.029729240829305306, 0.03300338953493103, 0.0321085030783809, 0.013936546071612788, 0.031545292473428195, 0.06967496892978108, 0.026141045870439663, 0.031267646887910464, 0.044268164708609545, 0.0470885327236066, 0.05800093043475382, 0.047297988822984124, 0.017740050999207363, 0.02323144201880261, 0.06928537491588824, 0.020080183392330524, 0.057424728893825126, 0.0014393188100638651, 0.054578298567644054, 0.04062408363566764, 0.019328149351020976, 0.06105236205903273, 0.09434333717029902, 0.03646504975134327, 0.02564305233048095, 0.026922869240684856, 0.06940527533691737, 0.022561333420115615, 0.061315302586843895, 0.0520085983519112, 0.03259589970712701, 0.07844458424275921, 0.04288756318630711, 0.03281798093549667, 0.016938849434917493, 0.059097213745718045, 0.01696678291585657, 0.06909468797065559, 0.04730721635203208, 0.023173309351888396, 0.07926060577794429, 0.02979649951861751, 0.0699126323865306, 0.04713899876561858, 0.04658041724694833, 0.024546389805994207, 0.001922378184146158, 0.039598012282963724, 0.06341763937305059, 0.04693764021560069, 0.05427731411351312, 0.021700976461532618, 0.0756409552489077, 0.04369842894976178, 0.05743814309337928, 0.057619008791422656, 0.0437847517370697, 0.030049444514236627, 0.0668691489244661, 0.02362610370431456, 0.015198367576475347, 0.04767018498011655, 0.062121307522419004, 0.021472517551193317, 0.08010821311824745, 0.027075868490482533, 0.033728307894160675, 0.0560416222640103, 0.1245501610420404, 0.07034829892818967, 0.09376429727361088, 0.03380821852554237, 0.061921772261660915, 0.027191024912040562, 0.013077436878736462, 0.054575295502980875, 0.03757497325779931, 0.11191844369374937, 0.03430062536931327, 0.06727659278699467, 0.015935699432908047, 0.02455589695713453, 0.04879273744600435, 0.023396683353630286, 0.07381555158644915, 0.01572662350466295, 0.04296064031340423, 0.05561119959419293, 0.031275158380008036, 0.011414537701996104, 0.010784216837266521, 0.004035067451637118, 0.06868254798915117, 0.03484742062526845, 0.03268372785720614, 0.02045240061688087, 0.007860128178201135, 0.008800946393861406, 0.021834972900368517, 0.06358432861405515, 0.032196162689116695, 0.02875733572328764, 0.0972616954916908, 0.023147781387031562, 0.07799809287873008, 0.03092835995278532, 0.040189278942923394, 0.07104410594629665, 0.041907621817963744, 0.04481828478615611, 0.035321150245445396, 0.03560157289968864, 0.01908129475439989, 0.00726739829030609, 0.06163520175182532, 0.023262156398906823, 0.042134904783339276, 0.06683223114739503, 0.03650834521038398, 0.013943095165755481, 0.05758144750049519, 0.032180526834582134, 0.06471261907849582, 0.03838211583394197, 0.042063241088462454, 0.0487398237530743, 0.035154169891029596, 0.023153373828878807, 0.017662781455944625, 0.03002708815338631, 0.05255692961415457, 0.01913349598556036, 0.04299064031651905, 0.04615343814235061, 0.02370932958118858, 0.048117036405470104, 0.00944184118716587, 0.053233258846786716, 0.036954212212754835, 0.06848563274909412, 0.031264188000932336, 0.023409291245644132, 0.0040337904788283335, 0.06936863335149904, 0.010465096209138151, 0.028163305401141127, 0.06618209829133365, 0.017891370601231055, 0.024780841439121196, 0.05896550407933612, 0.11907968805321764, 0.02780610924556611, 0.03736551332798216, 0.0317141171845217, 0.040868549953184785, 0.08253622154194502, 0.04348129664938297, 0.012176143054309632, 0.03649309239981156, 0.028122744875990098, 0.0267117966957871, 0.01120043910979744, 0.025990417662767634, 0.0649423994905045, 0.028065431923154863, 0.043150323683456074, 0.04376025607569083, 0.06641461363723201, 0.01964216304552411, 0.012384023885392855, 0.04438161466931624, 0.016647301268793883, 0.08398928349056552, 0.014289928066934791, 0.017430833015110225, 0.06034526290492185, 0.01608789620560504, 0.020498802562454538, 0.03152799229287813, 0.05701873676791307, 0.0087426001799383, 0.06454763438312278, 0.039152382767849395, 0.02798031380910787, 0.02850777300585422, 0.08066664524977246, 0.017353800959104014, 0.10638632360965976, 0.04242614459907336, 0.029781976406792962, 0.05305869422192055, 0.011435765998377916, 0.002700155652541247, 0.04553337423731724, 0.04456899594515563, 0.03632232757104981, 0.02923711169240696, 0.02186259803091807, 0.04450315451850334, 0.04207446427655317, 0.007345452594886264, 0.006474753928130433, 0.09205259638087404, 0.035299305248284535, 0.06922391168172322, 0.05590225937926481, 0.01302381263925664, 0.07393578908616498, 0.09924908078485921, 0.10528661971611362, 0.0025020448365173633, 0.05371729617998485, 0.01847593590707308, 0.0634705454051014, 0.040062211769362616, 0.03461073010018276, 0.04063247612887814, 0.06610876069434228, 0.011275848974623989, 0.0392219512122533, 0.04173660801062661, 0.03447678345706194, 0.08122481691140322, 0.015484514822732779, 0.011034744825484532, 0.01934403226891112, 0.025488905864016666, 0.06708425109184558, 0.03719127429048381, 0.06558360742224802, 0.008628144728830986, 0.06168050819166726, 0.02390906785524661, 0.05258789488805398, 0.0012120364431945248, 0.035722664587440035, 0.06371287816774941, 0.04190010266498693, 0.054505102696918675, 0.05801783416480307, 0.046083961628497615, 0.03286282006170481, 0.041912896333322416, 0.05783496131639808, 0.04197718260148841, 0.009727275014043817, 0.02211779149459495, 0.04463860652439537, 0.10626912747900333, 0.032207849360401594, 0.012775116558787564, 0.06207202891668966, 0.03062584140758601, 0.027669789645099835, 0.09950464005551993, 0.049614577418974334, 0.03653081839964275, 0.05374125941025634, 0.06039428104075694, 0.09733769907465867, 0.05718546048287423, 0.06821719554042624, 0.03166956917172478, 0.09838825076698296, 0.031001385368947542, 0.052324483216169386, 0.061269708864030346, 0.037290796772727085, 0.035664947523224744, 0.030036106923474904, 0.06877969559882918, 0.027841596353438594, 0.010990401741207368, 0.03586447129266397, 0.024391322118800976, 0.0322215776560047, 0.021749609638185754, 0.036197141143343145, 0.09089045632149904, 0.030286359120040175, 0.024754566538538185, 0.03149832936844999, 0.0685722160062963, 0.022779526752269557, 0.05454969284455142, 0.022203143265458847, 0.012667328945451207, 0.06951582182439105, 0.023902343518491236, 0.016702938404294754, 0.06405241599666976, 0.04481575286556636, 0.05205942445524758, 0.05007912547537877, 0.04406971729270393, 0.021018907315127795, 0.02661425838126771, 0.02813610353416974, 0.025074310570714936, 0.10278263835296517, 0.08554780510284248, 0.008716222815095417, 0.028649248378050905, 0.013588755560528128, 0.018155722646042705, 0.035587227903306484, 0.03534148604939542, 0.03582013012360662, 0.04879427345229253, 0.054793833574700745, 0.028914661454637686, 0.07636880006400809, 0.03473023215549127, 0.07801039625079402, 0.029771486747889753, 0.04378691976589542, 0.03294433181684825, 0.0331726375096027, 0.12626961474457096, 0.08265425270843892, 0.04710549774068979, 0.014303808622512848, 0.04436606691489297, 0.041240707805921, 0.08770811176227947, 0.04968957359632177, 0.04205199874817364, 0.10042646599392738, 0.04875245654294568, 0.05956860679772593, 0.05135902857047416, 0.07588857018779363, 0.022770048329426397, 0.04717471378464853, 0.13064184706778298, 0.14008124539208028, 0.11896707312834841, 0.1861925372072766, 0.08475437550054443, 0.16958540575879236, 0.08322913274769822, 0.07913302915591387, 0.15555999061513334, 0.15871138522221198, 0.09902617984241056, 0.08170172196602629, 0.18509635731818216, 0.10973685511177587, 0.16412067076852246, 0.11692287475471536, 0.14171656731876636, 0.17830635150594099, 0.09957233158450934, 0.153789714639706, 0.16204939884764535, 0.18260615787679152, 0.09790126399527635, 0.17387784236381132, 0.17280135093437088, 0.11840109503076923, 0.14666183340934016, 0.18345659208153525, 0.18662059649584756, 0.14191109236449967, 0.15658847897523837, 0.11210068068917721, 0.21662412361512262, 0.12471192816813147, 0.15590816225496032, 0.09828862103243029, 0.22782219934367368, 0.10643578990693055, 0.07527628973607095, 0.19528342681306024, 0.18122073383100573, 0.17866275093007475, 0.1564072072505951, 0.1235338994452069, 0.19081227721706515, 0.11517997876170183, 0.14255941725305973, 0.19696077632327236, 0.09765306682956797, 0.12622107541368854, 0.173880293845169, 0.2558054913195872, 0.15198888707785838, 0.24702955578123373, 0.12096886853537253, 0.19535114898556666, 0.15431534288631332, 0.14403096490329312, 0.141647205718102, 0.19441897319930215, 0.16407252980336068, 0.0881125755427826, 0.12026391442744963, 0.08033282243676725, 0.17313469111198382, 0.11300022112986735, 0.17553345029873235, 0.21731197864057558, 0.11305339529269165, 0.2071910991423553, 0.29202787506003536, 0.15080548041770536, 0.09825700458379523, 0.25486199275380184, 0.12389452767468269, 0.16431243789772834, 0.12877147404416917, 0.17440196907808705, 0.10174086602825312, 0.13266981969917976, 0.07603746703675679, 0.12252514551003134, 0.18127809849477586, 0.10568292466022315, 0.1296221533970487, 0.16081826490980966, 0.16260784630092884, 0.232306418399657, 0.1964355004771102, 0.14189532627501797, 0.19518014283910876, 0.1726498340647067, 0.12207733647477244, 0.18383425810644705, 0.09961515589947663, 0.2578436222768599, 0.15009519433782947, 0.34249986191430404, 0.054532475018453215, 0.14694900912863595, 0.149462191207755, 0.13663242480927898, 0.16073019544203437, 0.12414928255302292, 0.14157340080747682, 0.14840296740012784, 0.1017194921751657, 0.12855130037473095, 0.10738556273281576, 0.11119705699985066, 0.2251140478878252, 0.09129923317701587, 0.1157511662571661, 0.10126092726544988, 0.14142928434716118, 0.0962357352217359, 0.11354655673306797, 0.09639433074382045, 0.20258099651865422, 0.2215382099271782, 0.29115903942335036, 0.12035664937068379, 0.16968504315422428, 0.257435757065973, 0.21081938348229856, 0.15207568483967937, 0.1817897532976443, 0.23410574442917303, 0.14343116402385697, 0.12900016661132538, 0.07267323788255453, 0.1267544794527273, 0.18701425843661834, 0.14017886031539212, 0.11406085453927518, 0.22473359330286904, 0.12849923703939686, 0.13272850203417963, 0.15320302918553352, 0.12123994874737917, 0.20321510281533967, 0.16122557853739108, 0.21323608444823375, 0.1506310421973467, 0.10325605004665353, 0.10456230656634416, 0.1566213288254315, 0.1337350189926163, 0.08278557550041907, 0.09550026017090968, 0.13298314966021046, 0.1737425359146249, 0.12454912682334263, 0.17323106497285828, 0.12102503044110154, 0.2039401437486372, 0.1278876230841683, 0.1466781051168519, 0.14422662375915435, 0.1424418074349242, 0.16978288790391338, 0.20427588944233235, 0.10172848604739675, 0.08988215437819881, 0.13882031063399008, 0.09155476946503886, 0.10624713309469724, 0.28145586170496484, 0.24538599074848239, 0.15463452575908554, 0.17245979829420968, 0.1262491831796304, 0.12734539371224182, 0.14225912610850028, 0.14452228773265116, 0.23525971799127518], [0.033613804562558094, 0.04394827320450737, 0.04020592603351801, 0.06120530768267571, 0.004988275703057768, 0.025757180279000633, 0.013413827043897925, 0.01211350387518084, 0.03943666650523101, 0.061016899849017786, 0.01682444377952526, 0.0919997209923402, 0.018638524662462935, 0.032928565727366556, 0.08802170985408368, 0.03826020826255122, 0.006148501021427013, 0.08245076443399153, 0.03570612857959444, 0.03502992958190941, 0.04149807887452264, 0.014982291519822133, 0.05865407784679725, 0.030281620866228497, 0.03458817264125232, 0.03270495998402757, 0.005559725583636112, 0.03251626869783767, 0.040271280994338375, 0.02681135556720678, 0.0178770256048489, 0.01861598061007117, 0.04150904542315872, 0.02281712060193381, 0.03585270418214702, 0.017964712028662046, 0.052751106089882316, 0.029422261737166878, 0.057244200274468436, 0.06786166179564691, 0.08129086135135544, 0.0928699738916851, 0.03663140574410077, 0.09957817683537161, 0.012249353289183591, 0.028467340800430507, 0.020265747124569553, 0.00866815462828644, 0.05102042536882143, 0.05458601307304156, 0.06932782384777261, 0.06992490511507758, 0.005244961122967183, 0.04857004717773488, 0.03245206669934335, 0.02411999292821894, 0.06429834171168267, 0.01773908189798315, 0.08066680612823657, 0.02230301623292748, 0.02677972188159343, 0.048430492771008325, 0.03423970222713486, 0.0671274048246203, 0.03306795159474977, 0.10092071527915616, 0.09510137351049532, 0.092039595868799, 0.0597795031424011, 0.05505954351035818, 0.06764205503127269, 0.11590265248331333, 0.0579819735890675, 0.022252326110197652, 0.07833790649930317, 0.016649505686796, 0.028464063859334397, 0.024452907927033883, 0.029139234383981076, 0.023513119142021865, 0.044832353990885525, 0.0033594533142017866, 0.05174703678236373, 0.0265311416719229, 0.04367934953000757, 0.10486196185792647, 0.0733900893359415, 0.016266410013720874, 0.07851030692578324, 0.08235082826426915, 0.006244069053566144, 0.0800357182179728, 0.05083194092637108, 0.01887985768036977, 0.020926835037948146, 0.06480600519646561, 0.015119603204150355, 0.032563524831446915, 0.04619029463238774, 0.09936917272786941, 0.0203111071905662, 0.03826051852816055, 0.018475217699644067, 0.06687029039547329, 0.014717632082230864, 0.018349094729449962, 0.003431617360254149, 0.008829987829460973, 0.03042906406335533, 0.05997310122174602, 0.0555484991280302, 0.028277316521252358, 0.08503915336463722, 0.0566325556757229, 0.023293372566601443, 0.05091939369336732, 0.12219825579274086, 0.060977461642675826, 0.07226077614412194, 0.10037664729621142, 0.05968636217256708, 0.03344045801749153, 0.03892647876073757, 0.029908524555785042, 0.10463137705359729, 0.017907058166700508, 0.017199258042138912, 0.06822769860586814, 0.0068742999029646245, 0.015587346804808947, 0.05891653573921612, 0.048990610295966755, 0.006935901990565922, 0.00700183869940379, 0.036701939459289276, 0.018326788164314725, 0.06021523480153373, 0.008717204365248402, 0.023763068733857046, 0.035447489635478106, 0.002387849615901829, 0.0036023333509107155, 0.03968040120878047, 0.031861692531815464, 0.01901622899177094, 0.015784295561212688, 0.013131575354735458, 0.026964933213387287, 0.054400600643167575, 0.017400932603425557, 0.022430885883588946, 0.030387038395049113, 0.02590122396096347, 0.0035834215128899465, 0.03590820342182152, 0.04385863325648731, 0.07872460470084222, 0.01822287025260589, 0.05960850082638283, 0.01884281349879119, 0.02479033518372284, 0.13801167418639507, 0.024744661021677238, 0.06395090551626298, 0.005801247729499254, 0.10725623176943873, 0.06189302864274191, 0.03576853410190633, 0.03722176458987017, 0.03290720719603762, 0.026229768428170396, 0.03180533335844596, 0.01498381411957164, 0.0436388885962867, 0.03441962180659175, 0.01437789315523039, 0.028839400976956375, 0.07106878163833773, 0.02967048188551299, 0.08329801171297029, 0.03641354566019389, 0.06649647779282063, 0.028615666913890073, 0.07416156285832967, 0.032939034318851854, 0.0293494240125461, 0.015673040442409056, 0.06605243024926993, 0.03639502165418479, 0.011368581045028425, 0.022779867661395864, 0.05022423018911674, 0.02913410925576764, 0.050304504712262464, 0.02264978976229266, 0.023100149870339422, 0.0141144470093892, 0.05233446534182276, 0.07336798003844677, 0.04511474549109417, 0.041683031651642055, 0.021779898839491992, 0.043613492781596805, 0.03917066928660197, 0.055461578792141336, 0.01227824821046764, 0.022449013439097235, 0.049352797514368454, 0.00966943346054083, 0.027983619478501143, 0.030295044641881704, 0.06993281114245616, 0.06722144977820498, 0.043122713874665, 0.03072359805716382, 0.0532277430137319, 0.04651159956871022, 0.042818818286421804, 0.018812886274029172, 0.04233237926758105, 0.06137109293992962, 0.055995067100851774, 0.03975443211534331, 0.025441017707869894, 0.029433153592230334, 0.033773568368727164, 0.040776891363484245, 0.026370552406015418, 0.10039667283455211, 0.06855047443100522, 0.06045287910608515, 0.026833618082286372, 0.03508974189659761, 0.048730308941054734, 0.06904985650532669, 0.09613704011445084, 0.03327816229073271, 0.03587084131375436, 0.08898700362131481, 0.030617328255527446, 0.007562941126149869, 0.005730181583203376, 0.10098221681771741, 0.08112841240701177, 0.07555733675197249, 0.016507271887554277, 0.06873635800495263, 0.05142974614676449, 0.04302198863438061, 0.022043770164131157, 0.011494248192907583, 0.024336968180573276, 0.021399938381246982, 0.02549473770834025, 0.018197778957865892, 0.009657840635026655, 0.02062060096631608, 0.035396169405430555, 0.046669287276604486, 0.01700527500361204, 0.053631509654223926, 0.0724891929196254, 0.030486166342011387, 0.012098156261227786, 0.06785851317427813, 0.010251192011750274, 0.08818958270093126, 0.022884645506799705, 0.016062921739273494, 0.07394031666579746, 0.018460926329416615, 0.06069553745610099, 0.024797256788118713, 0.05401234345270261, 0.018648250148661675, 0.08293644885622686, 0.02311418843155186, 0.032850953359757705, 0.01799676706263375, 0.006815162703259698, 0.03882398002690846, 0.014721518063226776, 0.030649235817573728, 0.0596195018489755, 0.004935528634251246, 0.0945009904042367, 0.02616267636298172, 0.0073595768621852325, 0.01274227628469347, 0.12528560544934966, 0.02338467301019738, 0.016530336879734552, 0.1122674273867761, 0.03729683354557042, 0.04896331841366426, 0.0635819039457748, 0.06340764575607835, 0.030277529956712842, 0.040307547596673814, 0.045681279002418446, 0.03358500348704477, 0.03457886084253269, 0.02669283601966116, 0.029856660403311256, 0.07165980315016163, 0.06640950383077707, 0.05084643147945885, 0.053383672549839944, 0.055599436314115604, 0.03135086701912505, 0.07997156601519355, 0.04394031738141372, 0.05677756845890995, 0.03865375145969372, 0.05215607027733519, 0.03450373826067775, 0.037138402732389594, 0.04256129016979568, 0.015632187846236895, 0.045165939316634214, 0.0037482652002044266, 0.035890192694721684, 0.052010758719857664, 0.03912505258115069, 0.029618646461336367, 0.03440297854643676, 0.06285043936523219, 0.06058436660696903, 0.015758806858361972, 0.03133567932602619, 0.02214040832533952, 0.05980067781262821, 0.03150765840414792, 0.061237912384733084, 0.049864494452072736, 0.10374470689003507, 0.025697423505686948, 0.03136476193885169, 0.034639860593503526, 0.029873684792208578, 0.04083820904094366, 0.06422944742465211, 0.016514220305027503, 0.06232902843264803, 0.02328200190658531, 0.03823452516488972, 0.05546495340944779, 0.005921374625271006, 0.029624983923689976, 0.0459100864827633, 0.0678075913099512, 0.044253329415955854, 0.13727059137196312, 0.178822189148876, 0.11607300745503557, 0.1705446704140594, 0.17092406779768007, 0.1408294987894835, 0.14674224199787264, 0.15003050587350322, 0.09176447071255216, 0.1918029361554692, 0.06486618906379708, 0.14570603147149086, 0.07698623628746118, 0.11093560651305223, 0.12555982662184587, 0.2347280989371, 0.07706487521288857, 0.13030666827915177, 0.21210641119508974, 0.12143469595861052, 0.08106560085810001, 0.12899190818350162, 0.2065783820205158, 0.14390967786312103, 0.11916174373078732, 0.1654368098224363, 0.14142435074092882, 0.2281221993748219, 0.0740465424173782, 0.08406432946362803, 0.09208891660936418, 0.13321953375012646, 0.18304296588945776, 0.07712923425940738, 0.09353880695397816, 0.0977937818594998, 0.19268533154841394, 0.08637062949879516, 0.1082154121550341, 0.15124542939086116, 0.19761106239691859, 0.10346483198865768, 0.1376107803756191, 0.23206537649516137, 0.09213543346812648, 0.11773517310258844, 0.09948448428223211, 0.11494959314023295, 0.19669526557047523, 0.14029867646674957, 0.19621494376370985, 0.12388436934880673, 0.18285671459330669, 0.111713093825646, 0.19976992881105793, 0.07551940773884136, 0.12223864394810893, 0.09884090147792332, 0.13820472834331377, 0.14832835043630294, 0.11971970088779928, 0.12096286240604617, 0.16117961326193425, 0.14038312999952224, 0.09718568424784368, 0.1910357144210608, 0.2180075251887883, 0.2557300929460795, 0.19577694065388174, 0.16971499719206365, 0.1289493290166701, 0.257203632424916, 0.16773013998904537, 0.16185050710074364, 0.12512207632103275, 0.10355576662526977, 0.10532366772813183, 0.11171397482675892, 0.1293346865643417, 0.06609127090703096, 0.057120201283044396, 0.08958185557276012, 0.1725422906418962, 0.11977895012786312, 0.18100209233741607, 0.18048155091462598, 0.13671651061984802, 0.12559132815729226, 0.2096187551656077, 0.17556260760513046, 0.14022154673453302, 0.15884420954652373, 0.1809896204260088, 0.17495994155685748, 0.185670938583151, 0.1647780814598645, 0.10022689242877307, 0.11217233289273516, 0.12739607808931222, 0.1906139676969859, 0.08296862454904665, 0.17554630525410178, 0.08948074728851357, 0.10661424242801244, 0.13967405433856672, 0.10682516941620458, 0.11078604316759495, 0.22206380753026855, 0.17252975744345497, 0.14309160321229888, 0.08759630122973074, 0.10598932918641837, 0.1688561360201528, 0.20593011841898967, 0.11723025987345366, 0.16246046630605576, 0.21244638569412694, 0.18203822625500543, 0.11620206262675986, 0.20235120078488705, 0.16916444044440024, 0.1180192691484286, 0.13464546852534817, 0.14331833459436893, 0.14307603630567753, 0.09142511674473364, 0.12259534980741241, 0.19895242106529976, 0.22667888972547748, 0.15601022048823296, 0.10102638944743142, 0.2471871400672582, 0.15054399928738996, 0.09781554641742861, 0.16020619130182653, 0.11918238213946743, 0.10544269480892729, 0.06421960319482511, 0.10263486765325071, 0.12614404527290216, 0.13416917634106454, 0.12952433929087656, 0.08461385965347291, 0.09927205576170837, 0.07248401416525727, 0.10561060596017108, 0.14698561280965805, 0.14812613386780987, 0.1244353474448285, 0.10196299322189824, 0.24950798811210742, 0.05872776784423379, 0.15357314158351193, 0.12803729368193498, 0.07438439485286513, 0.22710655064832783, 0.17178824561978542, 0.1464554340007805, 0.10664549881532308, 0.19871392257271275, 0.13839847197936428, 0.28744434036554833, 0.0831270591926671, 0.11560866624237069, 0.14189223127980388, 0.11557049974198304, 0.18408718969552748, 0.15465439807984138, 0.28106445206269143, 0.12485122593540339, 0.14636748710707312, 0.1149398101974399, 0.09888051588448787, 0.10746250094305124, 0.1823984407970021, 0.12236900913018374], [0.0704657631896196, 0.04427004928490327, 0.013639136375258527, 0.010649198628661614, 0.08617150792551619, 0.05594881071198372, 0.017597778895569426, 0.03750297248423581, 0.06747218269494272, 0.12152751517151633, 0.061567686423058474, 0.0824234993647664, 0.027982594835902416, 0.0669411305458315, 0.033210049413384936, 0.05682912617621403, 0.01992603884108605, 0.021968942526127064, 0.01347638099574514, 0.04691117953869605, 0.03103601445834483, 0.026518690827933532, 0.02690725062312859, 0.02393281083523987, 0.05692804727943675, 0.05365574101526892, 0.04053614057239987, 0.016479229239085992, 0.03294844953944126, 0.06794211634945485, 0.03108886877946075, 0.0314607470101046, 0.03510135195909008, 0.05777812142285609, 0.03998165762412452, 0.02637055623645504, 0.023236212831351067, 0.029275389275543635, 0.037075909109966415, 0.03550157927337193, 0.011510893368282387, 0.04506482720194806, 0.04373008370279305, 0.0367112321058108, 0.048518841860875975, 0.011534843192015205, 0.023604425331277233, 0.009153446430460581, 0.04352512070909143, 0.007624254973169657, 0.026781788403769175, 0.05130268280364333, 0.031208342106472102, 0.06142142108611523, 0.03558849194838155, 0.018075607086141265, 0.007473776631447817, 0.04605540570112006, 0.08035710742396694, 0.05950876000908114, 0.02060680372279979, 0.02675578929483891, 0.021675243568156036, 0.02809399359619185, 0.04530648963766233, 0.01004519001130135, 0.0465609394614735, 0.011403874715700025, 0.06224464001734892, 0.014800639624046463, 0.009616121401890151, 0.029819401717113874, 0.06761672050361672, 0.03406811385385452, 0.07603250278700745, 0.019974647119881648, 0.06683079090209738, 0.04423618436821046, 0.02560920848120605, 0.030258423723881284, 0.014290567750351564, 0.04657841009658672, 0.04382951425448541, 0.04158738940473526, 0.060113406394638365, 0.08993829330129009, 0.0386233415995394, 0.08090564169951024, 0.013694828094524002, 0.06406956487485478, 0.056547968077563474, 0.010106003985950544, 0.0523747232622437, 0.07262252286196717, 0.04402593919827093, 0.026911019775716048, 0.047683894123521545, 0.09710250242102532, 0.054737886173590544, 0.026044666263905746, 0.056689809256744, 0.02826923812409082, 0.11139751922699714, 0.05218199086225322, 0.04761087445301875, 0.07451543419231331, 0.027704428310596177, 0.07716347072874347, 0.04669745249914066, 0.03438209498962087, 0.042724478388986284, 0.027438172537292686, 0.02313450699852359, 0.06495211348538438, 0.02584605413909641, 0.01776604244725839, 0.01994447666220367, 0.03106288690750878, 0.01493824912505525, 0.09919390713255252, 0.06443395459603879, 0.0709984241233718, 0.05774779200193383, 0.037053654255766066, 0.08864227171626785, 0.05369629770998032, 0.07324469350879231, 0.043918893732611215, 0.011589411634861702, 0.06734514999533854, 0.04129527624876749, 0.0544660551954181, 0.03923202909889721, 0.004270198030186998, 0.08772574710629641, 0.006388407679379828, 0.024841634346352472, 0.018766823322361997, 0.020489356698348157, 0.007728597584871516, 0.02099791076034308, 0.09448755322204483, 0.04180831384033926, 0.01215826160454702, 0.05698574519145393, 0.0785503886459816, 0.0480347432406439, 0.12064900384434771, 0.04556853767304171, 0.03941613917929992, 0.04942784731787059, 0.08328368586878623, 0.012649390039094275, 0.04986006263343077, 0.03705317162037377, 0.021114038198345134, 0.10257165007773908, 0.041445720595337694, 0.09312974664592936, 0.035947381158269225, 0.021695152278088277, 0.015788765684250864, 0.044354027843162905, 0.05567330634221435, 0.025218168476356134, 0.060559215940414905, 0.08140772040332518, 0.025724317022268812, 0.04289880935703555, 0.11510806608824961, 0.03758327765089851, 0.04558683185267352, 0.045982363047979535, 0.030520979292510502, 0.03619137633171293, 0.025734651548367356, 0.008157089713119693, 0.05242120564704942, 0.06729505550596984, 0.05736958588503542, 0.0542506619146274, 0.0570470015818794, 0.020761030628496123, 0.013863457453196809, 0.05790988854583233, 0.034600016360561696, 0.06096683600316606, 0.016896226218030337, 0.017583772893093767, 0.01284403287084593, 0.01753682319465424, 0.05333885640626954, 0.029141551799952026, 0.07389102656874927, 0.09083160544715582, 0.02259721314804929, 0.03958351406899672, 0.03651430154399526, 0.02582444662919208, 0.030912628337260217, 0.031087997354446884, 0.029373371921059106, 0.047306844799388806, 0.07144294664143555, 0.04117242255879026, 0.0917965314921833, 0.061322116938930374, 0.03143850556244293, 0.050261557823227304, 0.04968232640455808, 0.007308538169449857, 0.008895904907295782, 0.07638239812466406, 0.01697492643049167, 0.04125764984036646, 0.020327411456814697, 0.0064388057310885245, 0.08297725069907405, 0.07671387670862098, 0.06223063976053269, 0.012669515168865123, 0.06515594649939768, 0.056899449217223355, 0.10639026896246981, 0.0028535992333350046, 0.0283524391031073, 0.04963430418302456, 0.04599288909605915, 0.0023332007338232813, 0.041017006301591476, 0.03911470656373328, 0.11632194772603051, 0.031854125498343384, 0.036729457337529435, 0.05033059000608422, 0.01861425308180192, 0.04264277511186177, 0.04209460855852212, 0.06575970039252313, 0.03641755996091712, 0.048613063014683225, 0.02468968272179125, 0.03716873598375148, 0.01840789963851773, 0.04206157101678752, 0.04360297056395681, 0.022497614057013587, 0.021671966627059926, 0.03663755743013274, 0.09024919476360084, 0.0812993725881942, 0.011641901106603686, 0.053596526249161655, 0.045882695009030645, 0.023090334368809577, 0.04071527874217399, 0.08565521829070584, 0.03118137772675724, 0.03800600113707685, 0.0696714296035709, 0.03306240511817798, 0.01880056183454731, 0.04586694424130744, 0.04534329633198438, 0.032709878268501455, 0.05582843531644153, 0.03319053332351389, 0.08616861977404164, 0.07660735218274979, 0.018384032169236772, 0.0569974088801011, 0.05780100446915435, 0.015201169543058403, 0.03836212476955787, 0.01824537600060144, 0.0312865884118383, 0.04935637131453522, 0.04000074470475797, 0.022262555299206607, 0.038633166677168304, 0.03061835672856579, 0.04959375514919239, 0.026805002783094684, 0.043953969068224394, 0.0346434535458684, 0.07157219333514091, 0.06434798420917603, 0.04842228413889966, 0.03356730685599389, 0.07860014605666361, 0.04466648829439956, 0.0422472324252369, 0.02127133328617821, 0.05215166144133095, 0.05442503884795213, 0.017914399204234925, 0.06879977476332458, 0.04393958576744603, 0.061481497701137304, 0.032421993917875716, 0.039900705113165805, 0.05706858993958562, 0.08399854549357007, 0.03518648347967575, 0.030021233326424996, 0.02940810060188655, 0.02577423914185455, 0.03717484553494761, 0.06617970043613065, 0.03781504989151032, 0.03057142426710456, 0.023549546622821403, 0.03467254573479295, 0.04479298090201713, 0.03280650493839095, 0.031397339827831716, 0.07412370279311173, 0.06069318173573383, 0.03180246627438934, 0.008728439044657975, 0.0849377999322549, 0.11477261150796568, 0.03841038830878754, 0.05204824723243233, 0.058871846000153216, 0.016050411523469997, 0.026753535081121712, 0.0710419302565917, 0.016768362313028307, 0.012098962568768091, 0.054906555751879374, 0.051976801872613936, 0.04855862480678386, 0.021382525202728087, 0.05981005089838178, 0.04602386586127743, 0.06234105601305924, 0.058281651863287535, 0.054278509210675, 0.02417970373625717, 0.035968996329052795, 0.03749155394372441, 0.020912421093652808, 0.06043944192389327, 0.03394929744723824, 0.07007328868513146, 0.0313267850452253, 0.04108827546118729, 0.056900529401196595, 0.012432095902641455, 0.005821290983623195, 0.0821809559279392, 0.16643715211220328, 0.1826707850540838, 0.15244742134405723, 0.1936487177567136, 0.17838576418017188, 0.31095708029404767, 0.08053259518478187, 0.10320070019412426, 0.1731555899905582, 0.2228617647121991, 0.17095978281671004, 0.22892774082720282, 0.09226145493167062, 0.19706715529243793, 0.0971300432819032, 0.17784015636049932, 0.1723574642692843, 0.2696397215608628, 0.16359416918168146, 0.1335532569717015, 0.16110039977056367, 0.145807032503428, 0.13785053525240193, 0.0778294692657167, 0.14170035689828858, 0.1335918065160513, 0.19972983176910108, 0.23202115790017191, 0.16510206004304273, 0.15622618067408764, 0.14584193546925822, 0.11790568895277478, 0.13959933012243242, 0.15034844768383812, 0.07740014593207067, 0.21426703961145496, 0.1831999373051428, 0.18166653571590302, 0.141150014655244, 0.07440570741891861, 0.14762903473550273, 0.17839221464049432, 0.18050244979320035, 0.14034585216112677, 0.17764612161103757, 0.18356857881430658, 0.15079524548303697, 0.22397400180418647, 0.10036892512993467, 0.09560221881275216, 0.1273067139329449, 0.2000367878786018, 0.1395814649520382, 0.2085472433076751, 0.13492381891175625, 0.12266194583067011, 0.1214515345711862, 0.16021348445886568, 0.20727080292999747, 0.07823304438422765, 0.1962776250776745, 0.13177124452927422, 0.1834701671595535, 0.11914417733468356, 0.10150151717807017, 0.11338357152717729, 0.10049261002530975, 0.060785357434783256, 0.1834513213966162, 0.14824846278755896, 0.09952170083359366, 0.15759375487123767, 0.2223993846846204, 0.16407639088649906, 0.15896321364468144, 0.11930536989483143, 0.11294116341178456, 0.14140227208695105, 0.20095782474644724, 0.10591923214134671, 0.2013730137578903, 0.15715141570375812, 0.1745480926887643, 0.1926037891497535, 0.10313930590787243, 0.2079070389511124, 0.0806136932524462, 0.1667309774746818, 0.09976531679351484, 0.17265193314561922, 0.13891786427026795, 0.14938438731816508, 0.14022364581544555, 0.2698962997284628, 0.1805286193566938, 0.16727145250526168, 0.11174346155096447, 0.17345920595670902, 0.20005119033157828, 0.07879656333956989, 0.1434579617794483, 0.13281822625187137, 0.18736538717583304, 0.13766789989125344, 0.08485831064923156, 0.16683795399242835, 0.09614588076909704, 0.22743823607602429, 0.24269930507627227, 0.19279132747361738, 0.15712967412846704, 0.13188808825948548, 0.1370651112689126, 0.22136352655868377, 0.15567044517205608, 0.2800018268246805, 0.12155410608336811, 0.11567346195900634, 0.11964996390405203, 0.11916260941014176, 0.2620168402791023, 0.12720359849833673, 0.13878841073282305, 0.14064612798392773, 0.12030843179672958, 0.1356248812930238, 0.22826394096257227, 0.1331340689812937, 0.09977145315778833, 0.16202843868203703, 0.16764421556745807, 0.09210607697886806, 0.08938364564411103, 0.11786718537370044, 0.21042585943735417, 0.1294233689024564, 0.07437252049003878, 0.08619593846942149, 0.13923761404810414, 0.12034665958415117, 0.19223689432105712, 0.19355317127079735, 0.1595264874518879, 0.26848338844795383, 0.1023344079693479, 0.23679250671017557, 0.09199570669161697, 0.18555628586440318, 0.2644379232679644, 0.14801929524588972, 0.08893473344224115, 0.26390092627656075, 0.09972309768800774, 0.09816777832325428, 0.14878648633678115, 0.07063316106195412, 0.11296880386409261, 0.19042865102810247, 0.22819018201722255, 0.11452057624175666, 0.11504349253711202, 0.21309293325870268, 0.1295910502273229, 0.15809624726253171, 0.1059065763688376, 0.12655144317015526, 0.1750259476924135, 0.09839712206514613, 0.19168100560144072, 0.2436041621671569, 0.07353000763443208, 0.13290715373812184, 0.19117629155516627, 0.09483452976470995, 0.08714196512535696, 0.1659114779003205], [0.01663955611987941, 0.058143464923505826, 0.07561694605336075, 0.031702459241533955, 0.04460884017809745, 0.11052695223160329, 0.08292259798655588, 0.038402758073061705, 0.05537547817033145, 0.03092230211252407, 0.02267358445322081, 0.029522444970244845, 0.08880497346962653, 0.02431293983282822, 0.057001859850941174, 0.028437626165067478, 0.043237198054069476, 0.04188122625853266, 0.02714781180745171, 0.025070286693892656, 0.0828166327048694, 0.04811042123624394, 0.055440768013678254, 0.037405372882682475, 0.03465587566156061, 0.028513549308803295, 0.03540972916169032, 0.04707293517346825, 0.022083342435859868, 0.08389290962969104, 0.04544754174628085, 0.059336865200631084, 0.02827371782322805, 0.07571221674762427, 0.0817020973491092, 0.04209635523898948, 0.034301740027243094, 0.04701430646462306, 0.02845004828075969, 0.06998728765475173, 0.027343470663312944, 0.02085269113341647, 0.018097762348911455, 0.01784254781781666, 0.0331333716730437, 0.047642912250012166, 0.061526091679209666, 0.022016809614855918, 0.01876278603900104, 0.05093555814856964, 0.030101155449125557, 0.03105515708035279, 0.05547833696548497, 0.04296654685130043, 0.045074437774958155, 0.03674182582706694, 0.061257692774938005, 0.10951374732558766, 0.0016187674848497998, 0.056520791108449625, 0.09447206292421588, 0.021556203080821904, 0.03793811425566673, 0.04140606788437694, 0.0363847867195164, 0.03396531634573494, 0.04527380832681253, 0.02372919041062555, 0.01238559245041782, 0.03202268973954263, 0.03263705778085897, 0.048557716992593584, 0.05566140516631066, 0.02390705112878594, 0.033348975628013575, 0.057942025934255896, 0.06820248665228006, 0.06513061197174173, 0.02155991094637542, 0.008137784297427824, 0.040730439622195504, 0.05478834455472328, 0.061313854680667, 0.09255165669826732, 0.045371499858916774, 0.009347503204950163, 0.06939307921716283, 0.08577698796627023, 0.05867888760422507, 0.023415749366845817, 0.033629969017760414, 0.03265586523940006, 0.04181632712002724, 0.00039790029228653674, 0.019011107693997123, 0.15503710496329492, 0.02927906649758018, 0.01496849906435537, 0.024343669534690922, 0.027348023140802983, 0.06261777463218858, 0.03370913271341593, 0.031210665268102483, 0.03418890293687582, 0.02632764190615666, 0.03198088623673445, 0.021851612330083887, 0.010372690683711442, 0.04057652489732831, 0.05075790618936862, 0.03904161028443806, 0.05224345026597862, 0.0017936102953934744, 0.05073134975147344, 0.05080303259854836, 0.05139286667408963, 0.029323363616581888, 0.06374848593446998, 0.06573735360777186, 0.03385192384162257, 0.03719989277963196, 0.04634556916332053, 0.07503974476769086, 0.011242948371105859, 0.04564119728222009, 0.026364580750645652, 0.0655684465422265, 0.08416015940207629, 0.039535457373506604, 0.0337981291475796, 0.043591981032683004, 0.0788678171774072, 0.05893848032780713, 0.04796463853469299, 0.11429997356308084, 0.03439345224309833, 0.03094901559844373, 0.05742615381736429, 0.03617787403204749, 0.07255471641978911, 0.03583884948203641, 0.04137289244681597, 0.029735850252872034, 0.01438866339383587, 0.04459417725522672, 0.013311596440842316, 0.03775293931304928, 0.03227613077709272, 0.008834388046976059, 0.02232118017761217, 0.06057900782193869, 0.04063598481157134, 0.012624928851671999, 0.08598372445351656, 0.05017425061293668, 0.023499126546084884, 0.030630321106723243, 0.03772881520431369, 0.05045520186784768, 0.043238783856072736, 0.03639874867193642, 0.014950821585502597, 0.05575200272423606, 0.031079443982772292, 0.03904583525934047, 0.04718838845409694, 0.03714197653255636, 0.06698950899824982, 0.01869949951557623, 0.04261057260596464, 0.025129105009499098, 0.02120201765078931, 0.038815254285450906, 0.04800076724120206, 0.019105803822317434, 0.04145525838999499, 0.02155073321304254, 0.04973540863683147, 0.050126446726461577, 0.06726334712678386, 0.04221011929574513, 0.046980138943200155, 0.07090672339883543, 0.039481574579352335, 0.01081576050754877, 0.022190958637023167, 0.013538068310628015, 0.03625849712519877, 0.08473472534528664, 0.03464959757102113, 0.03164581853085228, 0.013332973166759457, 0.015285011163101563, 0.010770169657564933, 0.014397755899887173, 0.06488245311042955, 0.04444566728066533, 0.017643533496847077, 0.00704432497807448, 0.06492582900870232, 0.029752675458909045, 0.034600092969354124, 0.03434649488377956, 0.023153166985139254, 0.057492489370727734, 0.0640098789646741, 0.029231551809296496, 0.017123781144618988, 0.028431608544422254, 0.042586712797562924, 0.043389664872759776, 0.05578731171666615, 0.06566292816592802, 0.1300637877636379, 0.06147706971293496, 0.014033934041377039, 0.03843067431702249, 0.003874390325020819, 0.09222652132232344, 0.03646929387844378, 0.05364555587631561, 0.030983460826739192, 0.043991990011906436, 0.06755194010873956, 0.04239892932556329, 0.012969208764843644, 0.06720589819334208, 0.05433366371078357, 0.07831181354460218, 0.023025381604149457, 0.06744333948459356, 0.024858145456340526, 0.06402992365521289, 0.07424060781035693, 0.01973068642039453, 0.043320824211883935, 0.06835051782188878, 0.040600105083637664, 0.019217549237392603, 0.025847647601978916, 0.011084620979794813, 0.012725367766594695, 0.018025397683583924, 0.06208706722264329, 0.02261225719966235, 0.013937971952761856, 0.060374960303306587, 0.06699962135885032, 0.11024033575649224, 0.06397478064642319, 0.016051095256942417, 0.029130058565868006, 0.03639110694489172, 0.05091746315179814, 0.060434466182825074, 0.03014910297708646, 0.06734976184464271, 0.048344909258547335, 0.08206337675332062, 0.03568835150931151, 0.0629450282412431, 0.03430053726920197, 0.026340742009661855, 0.06823960361221144, 0.029475926196262724, 0.0355665052249547, 0.044911218912250576, 0.0605305259476506, 0.04936563331753977, 0.07643805441236304, 0.01677107809471988, 0.08101622649138013, 0.04230806746730401, 0.029800552123736952, 0.027557781844910596, 0.06584019325072728, 0.030707399128004912, 0.10880169924348594, 0.013995256177299928, 0.026363079218314062, 0.023154264406090783, 0.027441851674549045, 0.015971681625101597, 0.040152100695958065, 0.038213557338402156, 0.042387043471418084, 0.012883986271316967, 0.08401634171605112, 0.02516188591177906, 0.017017260449187412, 0.04555505452557437, 0.09774636101698685, 0.04781958744710973, 0.06754863060890667, 0.04391604388553289, 0.028253416493234616, 0.0863590922146555, 0.010706050971132374, 0.054828748031849825, 0.012334739534004081, 0.026709856578118862, 0.05471173959273485, 0.06795753769937062, 0.11073832355079152, 0.03302916073270383, 0.012765471511820873, 0.03953008326671777, 0.041757024253808686, 0.03270776769627006, 0.08593472546987957, 0.06561379894734391, 0.034016609762705145, 0.03777704043914715, 0.02893012493938929, 0.039279373332617745, 0.026707156118185773, 0.023996928564062523, 0.06810351575334227, 0.08791545345898598, 0.021744580270962852, 0.06053389290407781, 0.04198835216342442, 0.18700005516650217, 0.05274218499600407, 0.049545196666111874, 0.06494758590575188, 0.05330166283754572, 0.026271548948340842, 0.020137381431977117, 0.07170537005989783, 0.02832331627066578, 0.0336782363874297, 0.048558161323589664, 0.08930768802641861, 0.03055102526090078, 0.06094207604145331, 0.04556070825445556, 0.06528139339699861, 0.04185590322219557, 0.019571133288404634, 0.020982797760816834, 0.05861120756655451, 0.028179789698051832, 0.05502110504875741, 0.019703331335838285, 0.08138621631529062, 0.03233529574748489, 0.047509884912400484, 0.028965269222915657, 0.014063209133793511, 0.05169430695053551, 0.04778472278567572, 0.10156730114812813, 0.13646976902119576, 0.23592650559881043, 0.13449641845880017, 0.15152260000186582, 0.16874273968560083, 0.20009781444264998, 0.11364391118648554, 0.19006535681265016, 0.10848866039586645, 0.16666377624196393, 0.11300636515502008, 0.23353565243944047, 0.10992034083052028, 0.10048194608140378, 0.14876915742793392, 0.10221928793696627, 0.12909022790770378, 0.14295833455699106, 0.23525591819517075, 0.15320868291441472, 0.18949382457761996, 0.14334185349364437, 0.12465566667097232, 0.0965496703922268, 0.11928693781937323, 0.12288807200327997, 0.16590885787961945, 0.18716842597050054, 0.19886818203714587, 0.13681153616597577, 0.11575684296868502, 0.16718784166920572, 0.24053772671088097, 0.14316436624334705, 0.1731326533181052, 0.14130157749018363, 0.31113487397951467, 0.1919636920455002, 0.13231217921260865, 0.09275961126531325, 0.17799676005398074, 0.2299359431790729, 0.11526993280577084, 0.11445367378332924, 0.14026964173441933, 0.08188539154587254, 0.16233089019454297, 0.12080783685368877, 0.10634952074577732, 0.13465073921026724, 0.1578112472329409, 0.17109125882627504, 0.19756678251489518, 0.1592529940629198, 0.1123089493522721, 0.22107426708023395, 0.20153042950457145, 0.12568419333547354, 0.14083596457156444, 0.19579327364842739, 0.18333239390725092, 0.12800976814281556, 0.1490239735933081, 0.15690033804745446, 0.13374977384603795, 0.08633546606307069, 0.1306389206119122, 0.09379741525457752, 0.10754467153380956, 0.1509276561198696, 0.16114277975453487, 0.20868849459915392, 0.13772324208290349, 0.07309400401408635, 0.13540251661212216, 0.19049720057556707, 0.26926780119538307, 0.1523083763858003, 0.12007244607253421, 0.1383947334702938, 0.14506601097603, 0.13787886518384182, 0.21551842891400863, 0.14374545925567228, 0.11441288726224054, 0.1715291240402768, 0.13007612177921882, 0.17330327642060098, 0.1392629102713639, 0.18630003466481165, 0.18969959579408172, 0.203425531846381, 0.08264819295295785, 0.15202382068720557, 0.2293439563964644, 0.07766321286438935, 0.0888672334352328, 0.10655153047053084, 0.13411556550812337, 0.11833196325648217, 0.16827017068862918, 0.13138342017848648, 0.2524379220220351, 0.13802714916246553, 0.20372182401197575, 0.13556082102079547, 0.0991936160191413, 0.17032380726548935, 0.18024093801936797, 0.09834679774940015, 0.11128184761131003, 0.10087956869674307, 0.11883995615907254, 0.1663014013320208, 0.1639697514474392, 0.14295831923523258, 0.12305759193916475, 0.15230310570088126, 0.1490762361115025, 0.1285586088535286, 0.10701632367507105, 0.17759395102339406, 0.15251450000270722, 0.10316889988438738, 0.21020280527732066, 0.2721484756517795, 0.2161117946548808, 0.09530595729067441, 0.13636196512849103, 0.1359061734570611, 0.17774126973123322, 0.11267334673433535, 0.14998624131323832, 0.16664241771063498, 0.1504043414587936, 0.0902221825033907, 0.09126562489977769, 0.1470906434640769, 0.1129582624942545, 0.10292529158534543, 0.14594462189462878, 0.1276083380704926, 0.1489018285346608, 0.1723107022623862, 0.08739147230141586, 0.2786678226003724, 0.08796166388257858, 0.19988413719880968, 0.17344094242059416, 0.11564384499985365, 0.06954897810975391, 0.10425669877159019, 0.14423684337206427, 0.1110674502448209, 0.05996031521428978, 0.09042796904161092, 0.16358113036521021, 0.1725343233274837, 0.13858046382665634, 0.0844176492143062, 0.07593147877243257, 0.14727193051047865, 0.0703338964752132, 0.10479024070645533, 0.09252144985141293, 0.17670570271870784, 0.1874023892225758, 0.08883092852850115, 0.14170158263896743, 0.1051512596407725, 0.1589636886191945, 0.12006012737871179, 0.18649028493992745, 0.24055470321928304, 0.14767584270767628], [0.10215301367063677, 0.07903636418162815, 0.033214370149277875, 0.008486590832622062, 0.04879008678178634, 0.04644352116531903, 0.0720082582425206, 0.0089964012788128, 0.0829177333282367, 0.09452087038587179, 0.03775361347042265, 0.08313405357541577, 0.059711918865721074, 0.06504970542605847, 0.02701847701363506, 0.05099430560104309, 0.02604195239743398, 0.1131522129740446, 0.07472181827911446, 0.00691387361110819, 0.015220171396410274, 0.05821050144731999, 0.03409908678863318, 0.02975976751786807, 0.06211233280238606, 0.09041663094033157, 0.005041174553034287, 0.05565270623793045, 0.08761756783050877, 0.015592480551511531, 0.07552811815854042, 0.04773639795941211, 0.031197477064485994, 0.02697280476680927, 0.038028872692056244, 0.045656936558624434, 0.020155459191770326, 0.09390866654294153, 0.005474862193823943, 0.035990806852257064, 0.05145883833568904, 0.04879372569942667, 0.0822626592050637, 0.0450680026363942, 0.033700935572626135, 0.018146443406059858, 0.03449863611510204, 0.015928116120067577, 0.03898432222946037, 0.05616218918153355, 0.05287409001480668, 0.06964999446344954, 0.018548128202617652, 0.02620345139275155, 0.016802265534117337, 0.05433955492692129, 0.03301203866759616, 0.04921690117748034, 0.06927893977732429, 0.03681996679534355, 0.014126546410543304, 0.008343755654359778, 0.004144041064841252, 0.03556431804393088, 0.031104820645264084, 0.08674922249009533, 0.05626741135793348, 0.055130012108073126, 0.03669724717075306, 0.026849359273910526, 0.03924547777240796, 0.02879871404729784, 0.04798995007971122, 0.011558544037172632, 0.03827483288102573, 0.095639128928944, 0.019496834251068292, 0.04625145143138305, 0.06934034938533461, 0.027610088413160656, 0.02123989686820536, 0.02207870377347835, 0.0851847790181637, 0.03782679784982916, 0.005937798592757675, 0.0973846142991416, 0.03504428990005005, 0.03124400732978698, 0.07259987730292544, 0.013830329896131111, 0.020636110416343136, 0.027409030552653056, 0.007689871361494185, 0.016684498667957324, 0.04639301298847122, 0.06543913090060796, 0.04188654290872716, 0.03755503198913029, 0.034998033511182, 0.015527331476820814, 0.04610683701391663, 0.056489618990810654, 0.026260624534540603, 0.13225541209741948, 0.010051659623821898, 0.027361557999205206, 0.02318178036911113, 0.06468659507170801, 0.05221110986425512, 0.10934615793127207, 0.07137004571456103, 0.016838059077159535, 0.04770719851817816, 0.053312158242108366, 0.04677505337543065, 0.03125981938454413, 0.010944256435088333, 0.06277575345349408, 0.04033568983657226, 0.06649467748619857, 0.0561743853012881, 0.09160563004233184, 0.12624699216816695, 0.02829212691604851, 0.022810622261116104, 0.01085266296286136, 0.02161584494094695, 0.03799338749940357, 0.028395751799126307, 0.012923877427144157, 0.03641482502702744, 0.05379233449216812, 0.057117948984547015, 0.0979709473528689, 0.026822806666454962, 0.046609245135539004, 0.03119678183969471, 0.07048316870725925, 0.013362393815881543, 0.03531472276776068, 0.04491269363150482, 0.05385068740936057, 0.03521390559692537, 0.02634891808303374, 0.025613261086325494, 0.0040933169469597845, 0.07525955837580466, 0.05888119993370868, 0.03387100326137678, 0.08423392600830525, 0.019929984193896095, 0.053344341595807386, 0.02700356128174932, 0.0520376292538018, 0.011405479669901393, 0.03698392876333768, 0.0029142037308174037, 0.051850883830939574, 0.042227723996245095, 0.056314813048248334, 0.029870101415942756, 0.013389519074060505, 0.022493182238371625, 0.015375547433993029, 0.03863013296898815, 0.017329923913724, 0.026486578337367506, 0.06152678498878114, 0.005465652380559233, 0.030820400927275903, 0.04426387461623357, 0.024529907424303315, 0.02339305975774844, 0.045379677847508466, 0.08566679387924173, 0.04220427404488287, 0.02393401359328099, 0.05062319728876314, 0.02124524799235646, 0.01703575381167954, 0.055475996566876296, 0.028999574640164935, 0.0501670608777673, 0.05745536858035673, 0.05350736893653389, 0.0730395887888247, 0.0200858160537938, 0.13265022317007666, 0.0496060700125752, 0.09174370206892492, 0.07813103211623046, 0.009434447481086659, 0.05195053271769036, 0.0665033266188637, 0.08231551927183905, 0.07357182071333931, 0.02972808403653964, 0.07362094993192343, 0.02028251295879243, 0.03293182160104475, 0.05508388978459182, 0.0403211111833732, 0.013591676270739447, 0.048808043882731474, 0.02471202567610289, 0.017404253594577312, 0.05441219538390156, 0.05998936143793887, 0.024156878146553235, 0.07095357733628443, 0.01721646054647863, 0.024422618725727645, 0.03603658826661206, 0.019831635741396778, 0.03142556442218202, 0.02978550232646446, 0.04201712259542077, 0.023123031001417868, 0.07603261003931684, 0.01570848350022589, 0.03459597524676112, 0.03547405756469216, 0.03556249475467109, 0.023252103410120455, 0.03640937431144618, 0.07089795169210242, 0.014124591928726483, 0.09517223664349127, 0.026226776854826078, 0.04256970181520428, 0.060021219204270074, 0.03907218102305647, 0.0572892232617784, 0.11000462582394963, 0.03309291073932283, 0.04357690442233317, 0.025019657858196768, 0.03975136393320657, 0.06519065794324683, 0.02885540455369459, 0.01705653586184546, 0.06475437853124834, 0.04913310648032254, 0.025998942306145065, 0.03977676357833609, 0.03779969365906812, 0.009699570401872118, 0.0349378458134109, 0.033983150872612194, 0.06528933006789416, 0.039843895863140785, 0.009554571025223743, 0.03565697254793298, 0.03568900651448677, 0.02089038457451088, 0.053722126364347436, 0.04739002662620718, 0.04916335929245238, 0.02523860770217594, 0.018028440967863126, 0.03568359793374135, 0.02923476171769923, 0.03692314351698564, 0.09342264504201951, 0.10568825663217615, 0.04723855189137882, 0.04973856108863989, 0.025546534828120665, 0.04953180544919545, 0.013288487398606396, 0.07977094290958298, 0.034359495395854596, 0.06426322041079402, 0.029748766495275403, 0.028069974824545846, 0.06578780815846498, 0.016640712912645073, 0.020060244038881316, 0.02235761340407114, 0.00921245914087781, 0.03708214123523043, 0.06149715270786997, 0.05874430002163976, 0.05206894692814639, 0.04347977213441365, 0.13537204163449426, 0.08158546812351673, 0.024920845922503262, 0.055287845372673006, 0.04119599891465999, 0.029181376880695744, 0.026048588634078062, 0.009794656277423906, 0.0741447089239955, 0.013209064190666522, 0.02093091445614494, 0.0016757605959766455, 0.06375913838705709, 0.044615761782493324, 0.038201169696666544, 0.002764860396235881, 0.03196923978506558, 0.08368059602235595, 0.019538007646558747, 0.01168900785306769, 0.05666666191011187, 0.036698484402750774, 0.03324839977487441, 0.03697045710718921, 0.11002966157731511, 0.03502891834584936, 0.0659708112418171, 0.025893729705844196, 0.05812815465633908, 0.02598122652289608, 0.08601848186264116, 0.07850498261470949, 0.0660720037957353, 0.04138965828103885, 0.026765034060865164, 0.01607025320070886, 0.046578134304933974, 0.016543013719661583, 0.00861222063371491, 0.09970070493798103, 0.051791098329328725, 0.03983468365585131, 0.015709164360868597, 0.11017859673067448, 0.0310659148700295, 0.049604993659041585, 0.04425752757778091, 0.017635828567548625, 0.045703235082328326, 0.055360508812291015, 0.05559691971528435, 0.09082740728533076, 0.018431788175216606, 0.005400462607447539, 0.04513729145870574, 0.012028886591114346, 0.034004294899322336, 0.023170834887892972, 0.013083079116298788, 0.046460896039441715, 0.01573311897265094, 0.021158739428726897, 0.016848859001672076, 0.09620539047905514, 0.09059892922279336, 0.05007581214510626, 0.033277062954561364, 0.22912873165501704, 0.15835169162000381, 0.10738235282441301, 0.10323439274103412, 0.09895998984575273, 0.2081433923975114, 0.1574630909148724, 0.1299711370900754, 0.17802332798319478, 0.2290477561614206, 0.18734150055435397, 0.2971155875392499, 0.15614788648822617, 0.32615031986947984, 0.17792896127268193, 0.12284985953761686, 0.10355445661491926, 0.11787951172840212, 0.1575552819356803, 0.1066052332340229, 0.08683084915842741, 0.1969692492557149, 0.14616640434870798, 0.1585585660030765, 0.1188654515651926, 0.2540256852103818, 0.13278787384831137, 0.1122046081769851, 0.19972722707015855, 0.08744191919122973, 0.18521327765718584, 0.08671228939126577, 0.10665694416891183, 0.1291815609100365, 0.11590452173784857, 0.09775596775955732, 0.117520040291692, 0.2605289749560818, 0.09832496424355815, 0.12520128981240336, 0.09825810775040619, 0.15225107300906413, 0.1638374020976405, 0.12318427989920303, 0.29542155263404696, 0.1566948119791285, 0.07088462176221995, 0.10247087887217922, 0.10870658942768652, 0.12361983152767345, 0.1554968956136896, 0.219498991125053, 0.16583503764723578, 0.08354458477227919, 0.11576062744303096, 0.2195009829536561, 0.12462609567709508, 0.22700479885022487, 0.12816894589172256, 0.11558472599473693, 0.14704322262156397, 0.0748261824370392, 0.0903059235743938, 0.0659858112433745, 0.12012936640530826, 0.153961701378707, 0.187074764060878, 0.207500736559591, 0.10316515371443764, 0.2242824134807433, 0.12939893069767183, 0.15077586345855268, 0.12022575558794123, 0.12352513539935313, 0.11487101550183951, 0.16072189104893517, 0.08987841586912833, 0.13280537129650194, 0.1442599179403436, 0.11132812698281581, 0.2397362914897742, 0.12851970690873363, 0.12472457627976134, 0.11286483041100925, 0.16370670749775826, 0.19522793140382538, 0.14248976453898415, 0.14150118935973416, 0.1627655531610212, 0.08275258009352031, 0.15947283065367132, 0.08827478699986974, 0.11175888290088024, 0.11085893643359024, 0.21846107988347932, 0.1859545749762366, 0.19387829898586198, 0.11529710594444506, 0.08843029518761943, 0.1555521611965472, 0.12570179037509427, 0.11784869967208755, 0.05847789294597122, 0.16057106365840282, 0.1005689660087228, 0.13603256264280889, 0.18007177048392836, 0.14709574560965263, 0.1473877170393544, 0.2850319601355061, 0.25418097123263345, 0.09725044932096236, 0.1338073223709099, 0.15348614463883062, 0.126812556578267, 0.07561395831045604, 0.10336451277497316, 0.2004649084542067, 0.08638814226874421, 0.10423059815600996, 0.1600613087535866, 0.28701649558159614, 0.18097881858627643, 0.1363808108914283, 0.06819191463892499, 0.10841155364628761, 0.11209563983063545, 0.10631493187599605, 0.182158992355389, 0.09022465696738613, 0.11501690928613949, 0.13502440625621429, 0.22618647905126696, 0.21513561477824567, 0.1012833736416313, 0.15922918405023315, 0.13213798614038577, 0.19126682782605772, 0.20079043453499196, 0.16919102369537278, 0.11876483357721761, 0.16942081942913995, 0.10071789350120292, 0.19117969298555007, 0.11126885476011424, 0.18669021856640616, 0.1837622305198062, 0.10990258291243546, 0.22820680612517943, 0.17455198441541966, 0.13344827228255812, 0.20679282535228038, 0.16594146258167683, 0.09918476770361585, 0.12332185396864531, 0.11058221781446088, 0.1104807418080107, 0.12115881237531863, 0.11414069622274368, 0.17004882766594812, 0.15227140498257455, 0.16788899598102416, 0.09983215796490831, 0.18792411042076929, 0.17122319448859463, 0.09934871051941188, 0.1435078800685944, 0.13127186245495273, 0.20754273349960006, 0.1462643257071895, 0.1849999681355492, 0.09056240215056366, 0.1307309430933768, 0.29146492300975707, 0.15399683417091448, 0.10220451776178614], [0.018231507893952153, 0.058217266003691384, 0.014237464450660252, 0.03406377013532385, 0.0314679597279117, 0.03484358635520743, 0.03683378319105795, 0.01746823151235379, 0.053664370995735934, 0.013716829182099433, 0.0288084969900909, 0.04954425820840463, 0.014632970748108723, 0.11078316267699966, 0.00794953829984391, 0.05201499518607894, 0.11121229448866461, 0.0614533094959634, 0.037179330979744275, 0.06767171029482158, 0.014476746268149827, 0.06807843403470132, 0.04019774804492632, 0.012875237547221684, 0.033226631386505986, 0.02158705918719211, 0.04073590182909562, 0.06437987644946383, 0.048666118433879274, 0.053344031330198056, 0.03542109407604702, 0.08739520314960711, 0.06872178701263282, 0.007913240096381596, 0.006040174752518896, 0.04558212424237882, 0.000326622843379981, 0.04865408319258883, 0.031124610611568057, 0.04535963315696967, 0.015593175776302816, 0.02772964409462387, 0.054027205558433655, 0.027244534238331744, 0.05385667438648882, 0.07172718824398133, 0.026800873569182815, 0.028856151489420768, 0.0658612989730412, 0.03390356965903794, 0.008266631667802652, 0.021095962353771733, 0.03220398061638398, 0.004026701292699023, 0.03653161896152362, 0.04088045112908848, 0.039869027377496806, 0.031051410910403057, 0.06214582999687522, 0.004989271617359332, 0.06624151607074084, 0.015359319776536958, 0.02203670108780986, 0.031054300977097406, 0.049827124683126334, 0.03355387350424163, 0.01901055802591145, 0.01375357171655783, 0.02503864343218025, 0.04550555375434699, 0.08271105046714507, 0.026472346338954185, 0.06179770815276331, 0.05237863797153677, 0.03076953077388387, 0.010892950569189364, 0.07432436420311851, 0.046132343911355546, 0.03134466745259781, 0.01269099340143223, 0.03166142374186987, 0.00830735307141778, 0.05110804284472139, 0.04967756516810867, 0.045922194502406546, 0.009338281421561637, 0.040015974532692664, 0.011547795823594977, 0.06793860000588241, 0.05042420211999167, 0.03024860630713163, 0.04084886915441002, 0.04189052656593342, 0.028769271373147928, 0.03464588204458837, 0.02428963926861123, 0.0046341731062819885, 0.030151924095867626, 0.09357281359693698, 0.014452483305977959, 0.05868669020973387, 0.04842513398597798, 0.02049684329258819, 0.029734275942187638, 0.041509455280198206, 0.031681227114712524, 0.046410487454024055, 0.074603327459866, 0.018817000166182558, 0.04450005186241, 0.019443930134237297, 0.026458970443796248, 0.04297986912030367, 0.013993960531097988, 0.14151159283374587, 0.060890020366998455, 0.061254138126969344, 0.016466989069275798, 0.043649659792502085, 0.040175489360286344, 0.07411304651008499, 0.04158099640100714, 0.01556212814795154, 0.07033290056091163, 0.046829372839701754, 0.0709698413829169, 0.05584123664565625, 0.011525792820799735, 0.042903555271726464, 0.02646036855425806, 0.012538233554110894, 0.07683596048023432, 0.06497315025978512, 0.053004045339842, 0.05614541185599181, 0.03440924514565737, 0.027923542863479065, 0.03082099656063703, 0.005420321042859747, 0.08111414784986166, 0.01916622134646581, 0.012979273244948878, 0.0400075513959652, 0.1288905853946363, 0.027201098968244852, 0.029488007402828628, 0.06460496840337593, 0.004463407319910344, 0.007399997097485129, 0.03919730233328958, 0.06327800069665236, 0.046245717263269814, 0.05800786736090818, 0.027209190771945065, 0.0813785171316516, 0.060399161020834605, 0.057093372883936094, 0.03901585057798413, 0.04774541864472051, 0.02060905410607736, 0.03211506270623255, 0.10917151286717384, 0.058556171810074206, 0.055988585997012355, 0.016168883190520348, 0.024914711473449588, 0.05955480572377002, 0.022401102300312732, 0.0377037066725954, 0.05426021503104318, 0.0404176306009533, 0.02047546369384133, 0.03561269266590957, 0.06552344653755426, 0.05177430185158888, 0.07677387671485063, 0.0035562510076429577, 0.08283399225723359, 0.041941942556971507, 0.050693420738342314, 0.030440877139147733, 0.026393391402258028, 0.06753575267089952, 0.027897289030313976, 0.029763136389515096, 0.05910424260242332, 0.015263353857482153, 0.019927392901492216, 0.026099887796707695, 0.03554269904270768, 0.08509591281894716, 0.03688499233835647, 0.08427233765682868, 0.045257475332266865, 0.020949940249744444, 0.03896085312590003, 0.050323139801020586, 0.02041869274821253, 0.03733969233449429, 0.08603802476558955, 0.047427882860985496, 0.002362232593323795, 0.01604727726624978, 0.027580590197636236, 0.08567745016226846, 0.062111524579625946, 0.05665652273643402, 0.049921947215954145, 0.033852483085807294, 0.0028819985914930344, 0.0656783724984815, 0.11505567333510808, 0.04827535996634153, 0.06627558400073359, 0.05578514368784043, 0.015006532456966178, 0.0449425442474744, 0.05267974883017521, 0.06140059115545404, 0.017878651626468185, 0.05060332879844693, 0.058779720096818866, 0.050948681234712564, 0.01945555168804863, 0.03251691987257331, 0.02974987923798542, 0.04574048610764646, 0.056202435610635634, 0.07822018176797899, 0.03581553359606093, 0.04440641676586482, 0.016821735658712925, 0.06152228422222599, 0.04737367447946341, 0.01303305453245318, 0.016199520961832137, 0.02577533847802589, 0.031932745271572666, 0.04817005735070956, 0.018409347544694622, 0.036421987949119466, 0.03737330827261171, 0.05012764565406307, 0.026485689675375342, 0.030736937563145356, 0.024557325711113312, 0.024999080736550595, 0.02032826181441065, 0.022897448751234242, 0.009786287724461046, 0.04566175525166816, 0.023697319237755674, 0.02671020706334422, 0.057664859153690844, 0.012121311268739164, 0.02449498913671461, 0.01997192750775045, 0.024923645973866506, 0.01447862605639403, 0.03383224304284781, 0.0411903451857788, 0.03151512584618984, 0.05227456109658365, 0.04666431153553628, 0.01598015455754414, 0.06633433528364667, 0.015974478803635124, 0.09797067156121617, 0.048705361287800536, 0.05348719784148759, 0.05628941340311881, 0.04749169798507806, 0.03171244136718733, 0.0017428112445369123, 0.026534483730492574, 0.01689772966558174, 0.026653413135077686, 0.058123079323840726, 0.06064527442738895, 0.024467295058251872, 0.049666096831882195, 0.037991422483877796, 0.0213871447129115, 0.09868733149262206, 0.012072717354092146, 0.038367916394265435, 0.01245689895679994, 0.026160027613983523, 0.02194697687011813, 0.05846972261825877, 0.06714407489785264, 0.05752664157039216, 0.06449380138468358, 0.038705006572267706, 0.024709143270287785, 0.03702806308865547, 0.10391869311851841, 0.020412077578986366, 0.09048587762780728, 0.0014631902294856827, 0.05531657366983353, 0.022398641242855982, 0.017339362116951137, 0.044018600075956316, 0.06031536632367681, 0.016420763323924715, 0.012408026377670469, 0.057054202808367635, 0.08520062937731705, 0.07939601181856087, 0.02679801989166487, 0.03277051029726863, 0.05532795390594871, 0.004303474016788026, 0.02506271199954133, 0.02433216480928804, 0.02622464521517677, 0.014816874942381777, 0.04920098953129304, 0.011480462440710154, 0.03496161752170132, 0.015663455724866403, 0.03833486736121197, 0.035077013345735694, 0.02938627284170399, 0.05293846438308397, 0.12276593460551194, 0.054105606996604515, 0.04040847585025815, 0.05818674123034843, 0.035503057823065794, 0.026970577366169424, 0.05014793549273765, 0.08899441935242185, 0.040034115494739626, 0.033230067290846384, 0.04954211316221664, 0.04186428039364758, 0.02158006480444343, 0.10205903000408605, 0.03789525929718249, 0.03476981208809922, 0.025629513641639103, 0.11348051229311575, 0.037501536069377776, 0.040990212376439766, 0.03088578844683305, 0.05251217092717848, 0.028077243083727457, 0.06624158501865403, 0.041193696820447524, 0.06000795056142154, 0.09382750718824326, 0.22654315426705346, 0.2717321528302085, 0.16020444462135916, 0.266559282017331, 0.12297263278836205, 0.17369745930116023, 0.08393406387298338, 0.0984038100127251, 0.14777465272815, 0.09720433848879992, 0.23296137760964133, 0.10038690521351754, 0.2646295984666194, 0.12837480903873522, 0.06640103855921377, 0.2018049647731166, 0.17885264880474538, 0.12291965014751881, 0.1182132043064602, 0.1426631608797658, 0.12388514309761026, 0.1348329455621781, 0.10009815135309774, 0.119906319906154, 0.13781037692341114, 0.15781743722336908, 0.16660527776806586, 0.20170374923656065, 0.18864389599090625, 0.10791086922249488, 0.17233150921040968, 0.11954280352520368, 0.07275301827898911, 0.11108774391393508, 0.24253137860327, 0.12950579996310896, 0.15369706396614352, 0.14459161868979856, 0.20264749295048176, 0.149090102302932, 0.20288969930862227, 0.15635399478337458, 0.11204038956953634, 0.10882717932784751, 0.16978158555444212, 0.10078167032089927, 0.15128266126398118, 0.1544387902944319, 0.09768812301298303, 0.17329573811542603, 0.19343859516084197, 0.2206793181117504, 0.12195703002714342, 0.09664316376250598, 0.11795072726184323, 0.14088991248319227, 0.1364190540006084, 0.20716636982415954, 0.09908790354646983, 0.12366912928560089, 0.10702068271536021, 0.13935364572511566, 0.0870427873826796, 0.12170490283038347, 0.12249700710057251, 0.10966583110031583, 0.11149550953339185, 0.1432040342760663, 0.14236892182980815, 0.1389102799998176, 0.06369641493825663, 0.14959311563401453, 0.10229139213239956, 0.15767951075348163, 0.14095604119281616, 0.1573170285912291, 0.16090022099594917, 0.15440180356944763, 0.1558114053501237, 0.07365406025201082, 0.2173085465666748, 0.10364417317173175, 0.07589145833926816, 0.1317373068342286, 0.13582541246808347, 0.1619226112961769, 0.11676023428839062, 0.12888814923503708, 0.17382130507499943, 0.1465831102142411, 0.2149140008635098, 0.1280732538491007, 0.11753297185585385, 0.1770347374821863, 0.16719655974978404, 0.11089242979763977, 0.15893733519459927, 0.19837831477484397, 0.14226194531206163, 0.14907087349603254, 0.18903187355927883, 0.2537155574968746, 0.0982171067246987, 0.15186023027185472, 0.14380225701437843, 0.09161555088095127, 0.3145059366380015, 0.17583390998263515, 0.11071293539698086, 0.19616674151151411, 0.12270729057490827, 0.09617665452101538, 0.20122509750147022, 0.2920135645376098, 0.1199784087798288, 0.16106327514975302, 0.11539793077615962, 0.09678269135615519, 0.14261846731026329, 0.26365657487223226, 0.08287707704209513, 0.19957471428619278, 0.18686323186322568, 0.12696418836111986, 0.13018273057476168, 0.11541014221767265, 0.12397840664151216, 0.11357986623601568, 0.0564946560189128, 0.11493371213756262, 0.17937294507939971, 0.20197431616965802, 0.14987240064769022, 0.10264340187272719, 0.0783691092604591, 0.1483250869017455, 0.09493026777260727, 0.12946057013205944, 0.11426611247682765, 0.12973751091668684, 0.10004024276690138, 0.1519320127103598, 0.2148594094380256, 0.0769155799982048, 0.2855046976718211, 0.19063397791356812, 0.12129409584186732, 0.10797529721692686, 0.1868874862069084, 0.2277480726761203, 0.11300474870949985, 0.1551444492032451, 0.12639405806699108, 0.14385151646790967, 0.16080321894297678, 0.16398035410431125, 0.11756200658818407, 0.15022296248184097, 0.10003213755666249, 0.16187276961582323, 0.16832791839636144, 0.1231714785699883, 0.271989313224631, 0.08623759066986461, 0.12307082227761708, 0.1228746348210881, 0.30840882670975506, 0.12820204855093073, 0.19218487695099848, 0.08908034377400914, 0.1018073701209599, 0.10050382555252123, 0.2092780758656802, 0.1613470341169065, 0.14065778784213528], [0.030435334493015564, 0.044368234943718686, 0.013160964402730667, 0.12803673443775024, 0.03535320719463691, 0.02358064979254719, 0.045154007497213544, 0.042337887439756625, 0.02501890326159135, 0.07342578137233373, 0.058006277728465304, 0.03600178106177238, 0.056235825552815394, 0.024285142332495704, 0.02718642646927507, 0.053048880635610515, 0.013079213245110887, 0.008391423560228319, 0.046265746632050124, 0.02989087197478981, 0.0438106838133066, 0.013225969835935582, 0.10536882861126816, 0.05885299257633667, 0.06556944245652807, 0.05646336898808518, 0.014056627480914036, 0.068171406465192, 0.04702538792644778, 0.0749669434322465, 0.04138465955733292, 0.04018794594993515, 0.06092837072848793, 0.038569286435602174, 0.024863845150497173, 0.026487915160795374, 0.029148766432978937, 0.028319870790226326, 0.03359644117975428, 0.028672512553091493, 0.0345945043579465, 0.05273060557702857, 0.03599908060183929, 0.048106108161230246, 0.017516788080214493, 0.032261406567188046, 0.04220224391188353, 0.036172342877234184, 0.012263136168551302, 0.03504104551769072, 0.053274493529311115, 0.0582922391984011, 0.044179777314345685, 0.09280679462056968, 0.013843716324998007, 0.04054161810105847, 0.030448264141957608, 0.023007288522597764, 0.03673447138299385, 0.017472251558736447, 0.04768700061005451, 0.05104679411517517, 0.04788902565656651, 0.0429784250445664, 0.02988795126457849, 0.0313128977863779, 0.03727914074495916, 0.05016065638272032, 0.042037787817178235, 0.03969334043382157, 0.06997118448658336, 0.061226179748172724, 0.02738511137243721, 0.07194457335337516, 0.03164960492041803, 0.040823255004661704, 0.03084746298320111, 0.050282567784550695, 0.014548054689751759, 0.04306280579898627, 0.06419683889215512, 0.03290145004528665, 0.01385792725599341, 0.06916889124700139, 0.011070768194904011, 0.06300818069928116, 0.0019434295620979563, 0.08620556053375045, 0.03685796092594824, 0.011481816501116321, 0.040934487140827605, 0.02985959452006125, 0.01309863740443102, 0.0964133297243426, 0.01936664526921607, 0.03432067772073131, 0.03381855688208053, 0.030520381743929563, 0.060331894670643156, 0.002897054613229909, 0.022070857117913907, 0.1055914077967886, 0.021864007632698745, 0.07486749755879564, 0.016903013757039464, 0.07050856452194915, 0.03250868825782691, 0.028571597706045837, 0.05457246863854028, 0.01740169677613003, 0.028598295870207013, 0.017485162055480386, 0.04827779612594074, 0.04028259228254038, 0.01796578838219566, 0.050342529486384124, 0.04786056549017949, 0.006698482724342256, 0.055290982502722935, 0.0697561742497548, 0.02307728406101946, 0.057021161436193415, 0.04822097538459686, 0.047782907157295176, 0.022686584965295853, 0.024490517098456625, 0.05420006946810792, 0.05441821300454679, 0.060784315555206234, 0.03801135992210719, 0.009982457944011737, 0.022804552929535992, 0.028940792713734894, 0.025498510691367333, 0.013568423587017724, 0.08331080538130577, 0.044338108536096356, 0.07360609548707163, 0.023777319884468472, 0.05246789870603431, 0.05669874950282036, 0.07213077868425077, 0.017393899916280663, 0.048394153390320084, 0.055631627328693874, 0.056179973912695726, 0.013623008309232612, 0.10574677808871193, 0.03297784816353552, 0.02918343957243187, 0.06074043786934307, 0.029364686399217577, 0.023738977183858236, 0.03487621020946292, 0.043702029563005895, 0.07759312348019692, 0.05612949637936489, 0.04985911268440466, 0.07006139133966739, 0.016029579677588997, 0.047755883405766184, 0.07787204077166897, 0.05543167071957743, 0.042962011610788685, 0.029374105450246605, 0.10782643867235993, 0.021008676210899028, 0.03865093608657199, 0.007024627421126371, 0.032377782983765487, 0.05328621084411299, 0.012254781022127117, 0.028473456097286076, 0.019902370554665406, 0.06434452149175829, 0.030043687363485658, 0.07262915718339144, 0.06165346911837978, 0.032030716425769275, 0.025768947389517582, 0.04379548079844925, 0.030007709959341638, 0.04270363313656661, 0.03870984824794916, 0.05089076881807658, 0.05625077575865773, 0.050037668627356334, 0.040959350524410125, 0.11459607420669449, 0.03493196991903167, 0.07760489059071388, 0.03912843868977601, 0.02240120189174289, 0.03226486928460579, 0.02809002717596389, 0.052516821080878864, 0.04850829666059825, 0.037758627515887065, 0.053284946799037926, 0.04687760956585408, 0.041463616409248887, 0.04331556884872337, 0.07362421346648086, 0.04203124542630488, 0.05510270873445177, 0.0977650382405808, 0.06047974580958967, 0.03137161268011457, 0.07489341431327405, 0.05949950566695583, 0.06855853367596865, 0.06752999935058818, 0.03590167635270665, 0.03841140720572683, 0.0373352566854127, 0.022599792949134306, 0.033663305333785476, 0.0431712149011512, 0.03336414799935395, 0.042240996469533255, 0.03103109042821152, 0.04800358644476341, 0.03222739992422923, 0.04385087278581435, 0.035383463837206364, 0.09854076355094872, 0.08067802165544803, 0.030247189044471712, 0.042512222238245516, 0.03240890147524976, 0.030660757779954907, 0.05050474094347127, 0.06961713695237715, 0.033719536187427665, 0.041446992301292, 0.016344445644907894, 0.042772776402172544, 0.04386198489115604, 0.03838274019560026, 0.03098286136293844, 0.0663157270079659, 0.018901442207636374, 0.03394492691563022, 0.02487096976819298, 0.04386920143940276, 0.0413292637395282, 0.04376084596339253, 0.06086333369415614, 0.06303691665732092, 0.05302807751802668, 0.03484294284135103, 0.020000236371772426, 0.011011188579422813, 0.014218001986943908, 0.05306453181190356, 0.051804087350084904, 0.07197556160991231, 0.012443875462087172, 0.024107708708353104, 0.0228324021408034, 0.06929308942128574, 0.012261300430362745, 0.024003892303294232, 0.043574816832739505, 0.1069040458288885, 0.0922513732145871, 0.03049368741020801, 0.04930793540552259, 0.02681208718117447, 0.07702616479007468, 0.007460418930878082, 0.02728405096868594, 0.06799738193231245, 0.029888922281022516, 0.0032979273565879636, 0.028233664831326857, 0.08024672947583661, 0.03537850724833627, 0.07851753113490921, 0.03244842012082377, 0.025763358778109955, 0.050173415577099215, 0.04270981929655518, 0.019460826203407302, 0.04547887474238392, 0.09547304106695999, 0.06210846022792882, 0.048365857932836785, 0.012155847469975632, 0.016512209324226264, 0.027110158585973328, 0.02734239430977933, 0.01712301505669471, 0.04847519400139009, 0.12261316901253116, 0.10194594010470376, 0.062398129563418135, 0.02884261280057892, 0.07453234941368142, 0.02494630110900729, 0.013906064390715574, 0.00808662781867409, 0.010169900506885063, 0.014154446375135694, 0.02886052776668822, 0.09111631436333542, 0.008932424318646232, 0.04028607415215623, 0.012979000326125853, 0.024081518077441764, 0.038664606925580776, 0.09130460345336507, 0.059135338111269864, 0.044987636182697556, 0.054846437002021464, 0.07473999754555764, 0.03498275388753222, 0.07162728271777592, 0.0559872146996279, 0.04641828239865361, 0.047751918900758035, 0.05779219828846474, 0.0489895990599067, 0.04769442400204078, 0.04861781659025339, 0.09942921103849527, 0.07072175146951791, 0.07730681344025558, 0.04353707168071021, 0.0451361384963797, 0.02490347296360039, 0.03461757892622583, 0.06185675437952723, 0.04636887738841676, 0.03597995904724925, 0.006381659881181775, 0.017301061551176736, 0.08323205154268973, 0.023673476666332256, 0.03508753556337568, 0.03377692000339589, 0.07199582463550953, 0.07582539857755746, 0.014030051890820747, 0.007676117689228587, 0.03599512758815, 0.018719436953805627, 0.058621595718807755, 0.09240394728558679, 0.03783228303936701, 0.04320041817282477, 0.03734620408185067, 0.2052101183442339, 0.1103604200386232, 0.09639992318566769, 0.22798470191417203, 0.13887386017989728, 0.1628722692088735, 0.1350814491630562, 0.13846087750167618, 0.08037325655741077, 0.17099660100235095, 0.12558887667593457, 0.15092014845821167, 0.23430627560423267, 0.09752974965639653, 0.15442824892459378, 0.17795376719967013, 0.14166842635360458, 0.09715939211028238, 0.09603465246337076, 0.22678450260671879, 0.1661707373756555, 0.14034661824905104, 0.2072529530813617, 0.1501342495002093, 0.11961545164306318, 0.08509348432022719, 0.1799540840570004, 0.17119871031853462, 0.20165341725993544, 0.2405588707375911, 0.11318608938205628, 0.14044950385728192, 0.2072277334668944, 0.2018104806061714, 0.17027304627962653, 0.07406990809906876, 0.17814688264362274, 0.16439603341202583, 0.10230600142911558, 0.15597232977949804, 0.1379333953222921, 0.15609637473619756, 0.14155236403307608, 0.11572054572283261, 0.07898123649459693, 0.2523546942299412, 0.08671811932036955, 0.1824170873770791, 0.10590438535737415, 0.14119771128940967, 0.11216512400536768, 0.10245312861497365, 0.12191873329180865, 0.1976960062259628, 0.18258090761880721, 0.09158809428974506, 0.1493714863975202, 0.0848857902230755, 0.20962434760745496, 0.10314886668516744, 0.09144999928051427, 0.17376706604996037, 0.10901438823390393, 0.07874256180178735, 0.15377500575155983, 0.10370356030762197, 0.13921889085923472, 0.1818770566774953, 0.11789271908421671, 0.17714070276387278, 0.20314281475880455, 0.19161371243817193, 0.14826360068494274, 0.1463572981376802, 0.17029728530155075, 0.08357743462247234, 0.12356002304342487, 0.10985362989407395, 0.09432854401248117, 0.1387811022540254, 0.14438031631852352, 0.12788399948828644, 0.11496376576683215, 0.13603345130480107, 0.12639441812831548, 0.16229718232587462, 0.08673220001641782, 0.16276585959619091, 0.13983298693933796, 0.2128554919674512, 0.1367937322826155, 0.14970373873028064, 0.15861576212750328, 0.25279948487877846, 0.10588043744886115, 0.24869469384993279, 0.22403728066673204, 0.07158049772824011, 0.1553836984619979, 0.12718713526884395, 0.17263489535018323, 0.1374645801561494, 0.16612422051689318, 0.11884236933603404, 0.1378630224855677, 0.10459881831681538, 0.13203886968474235, 0.13026695428115706, 0.1847956371643851, 0.19708463741887003, 0.16255972065752552, 0.1477786517071147, 0.09735751010838056, 0.12077644257055176, 0.1584734995999644, 0.1280645740729186, 0.12122301054337334, 0.12768072571845787, 0.15794687543905553, 0.18336714365549628, 0.14274369204236617, 0.10786056788938661, 0.12281652705203142, 0.14577867192847116, 0.08350155361357235, 0.16073849983513355, 0.14803467829140926, 0.14375950930820358, 0.15722955667203473, 0.16985926686996417, 0.09721155503704663, 0.12893910940376022, 0.07262326596725373, 0.22184078401375204, 0.0804167167253552, 0.22496611630964666, 0.09959772739919925, 0.17775145870062614, 0.22611547802244464, 0.24934272762508164, 0.09633714994115215, 0.16433574229238496, 0.16512461367153353, 0.17630483955144885, 0.14879616968814405, 0.1076747915677486, 0.20408991393783402, 0.19055825778313223, 0.13219962557477336, 0.2456699335767377, 0.16678227472209162, 0.20200624671434203, 0.16832931267638362, 0.10391366758173513, 0.1182258754007278, 0.12956033010155926, 0.16980398596534807, 0.12555602682574143, 0.12523017132714873, 0.15533776383005804, 0.11454446286323572, 0.15455466875385854, 0.11714855659632914, 0.11295356637527866, 0.16633564546223611, 0.1675407170888878, 0.24476389671044968, 0.09959781932975016, 0.1039856798466175, 0.08486902821929225, 0.08081343535694384, 0.1518111700011838, 0.1364449477724491, 0.16295992498916967, 0.17910361920873966, 0.08270624709585983], [0.039516117483858144, 0.03409847391829376, 0.021949250236033432, 0.027102074443152355, 0.07875938509260455, 0.035828484312420895, 0.011340652352138873, 0.01949502245312737, 0.08550484289204882, 0.019691889812689156, 0.07629994408137376, 0.013848489052766274, 0.03108875578149192, 0.025613487082263155, 0.06251952002545999, 0.035920169715198784, 0.0774689482885503, 0.022787036329147317, 0.059722349152810154, 0.11303444227744495, 0.04727381874897307, 0.013539227976223395, 0.026663770643813957, 0.06955349802850716, 0.057765484802545085, 0.02709659308405413, 0.05136733296357336, 0.07125446602942483, 0.05242996203202394, 0.050005362699589426, 0.048236396734512625, 0.04202925742814138, 0.021955185502226797, 0.04139564142772748, 0.05573687248773152, 0.08036839189909159, 0.06267672892840159, 0.06386030412789795, 0.03266222759961121, 0.03336667225906446, 0.06554856656059142, 0.07581131788150919, 0.04945459910818646, 0.03096835548809219, 0.055080266188709974, 0.05631986156766934, 0.03595497308959884, 0.030265653678666682, 0.015528346543320486, 0.031380746363391804, 0.05978640942503849, 0.04339938652851889, 0.010676427308710353, 0.023257617327955463, 0.016876853769645095, 0.03365976217713568, 0.023935040151099526, 0.06642520097234557, 0.04004092218594686, 0.0403983022026237, 0.06234579043643129, 0.04517395259632219, 0.06822683292651369, 0.01696599193007475, 0.05849110030178582, 0.04784591405862763, 0.051986508206614566, 0.006278661753787029, 0.058553823750586285, 0.012210323024661312, 0.07725544724493258, 0.035304054993415074, 0.0320349624680896, 0.011433131613528297, 0.06267686299378834, 0.03504300287233726, 0.02080563035222792, 0.06558368403104044, 0.046997215043032364, 0.015423889497234939, 0.04003152994799518, 0.030579652051411332, 0.052053234464819395, 0.02863827991419502, 0.00418633534272592, 0.01328531866742959, 0.029897169217527397, 0.02347608645176215, 0.05090815518351813, 0.031775664688358386, 0.0651409158543233, 0.11569402375889402, 0.10515224789419483, 0.03018768891061266, 0.050781302514576146, 0.04548501493709703, 0.02140943787150806, 0.00814850761314794, 0.03856184389141779, 0.10800054747491114, 0.08575202116081793, 0.05294103460806993, 0.019757411397633054, 0.03738432844740249, 0.043717316847534916, 0.014253251607559863, 0.05629088046149381, 0.015774895662381765, 0.015086156762986174, 0.009087714171337505, 0.051096053568706404, 0.06523005018431334, 0.023785852188725146, 0.06630130923323094, 0.02356256628709455, 0.0800180369086804, 0.02518119898835017, 0.031157759236051675, 0.03292196204945926, 0.03784772354148088, 0.04282558667323282, 0.03971386009887342, 0.03819412168776316, 0.03137858982588495, 0.09332964196801187, 0.019250293750496163, 0.022382505515950824, 0.04564590489251479, 0.0760105696897353, 0.023368043156581062, 0.0283604926024113, 0.0382199541725699, 0.0646337962919666, 0.03974092598523825, 0.052153063382232384, 0.07964951797358452, 0.03869978185262411, 0.024263601855284745, 0.05041198684803901, 0.010712524414092544, 0.04385130179505195, 0.007034138881511266, 0.029661290745641437, 0.08477918142753263, 0.015891417635664824, 0.028789249030993353, 0.026189696284071095, 0.020572381477142056, 0.10041019428641566, 0.022050473433468613, 0.10843440604906891, 0.029506134958336913, 0.02225469523710349, 0.038433420742231036, 0.06443422272681229, 0.09829907813259671, 0.03890131277242496, 0.01934683615071399, 0.050164843053226514, 0.011515958167071785, 0.03641397466943149, 0.025903282822259975, 0.08526596901637894, 0.026289335594722824, 0.050408796091834386, 0.038028198534682874, 0.01115305944451041, 0.03218300512901718, 0.1044575440426988, 0.03839464137150395, 0.10619909172096562, 0.07246950445997138, 0.06412579189805735, 0.05047477158387342, 0.02638726844452322, 0.041253344426232005, 0.02413979055540216, 0.050942119691641106, 0.06897897038969301, 0.009363397614159172, 0.03552775266730497, 0.02448439031028219, 0.04430859116837383, 0.02998966858872483, 0.1193438275086303, 0.10125662951219468, 0.12583614687525457, 0.031207863301519426, 0.003635109225738674, 0.0521092354920843, 0.023136429879213535, 0.042355216348603855, 0.04789374092774046, 0.022462404656013655, 0.05091834798335068, 0.0903193454348272, 0.04740867703672379, 0.007283194544499801, 0.060042696479227275, 0.07079416976100014, 0.046147232830163934, 0.005481811090102119, 0.04647154083114959, 0.027389577665035764, 0.06074465901380586, 0.034740601155546405, 0.05824479920369002, 0.06317031171713626, 0.026688063291892893, 0.02814681344335118, 0.024825854850332105, 0.03643506123954731, 0.048449300229549415, 0.04968063718068504, 0.007346253156767137, 0.06527298175159, 0.024967018041699648, 0.005683231884763847, 0.051224162621844205, 0.04078307369303319, 0.014116257849720218, 0.04813748329216915, 0.047225804188318794, 0.02138488092309525, 0.0881282190581964, 0.03921565396951572, 0.003730450304330237, 0.023480991329697352, 0.0362374373681603, 0.05875736182074874, 0.03223019231471323, 0.042496145883154486, 0.04877995143854811, 0.04499728889054349, 0.03330456168060342, 0.06790498406776498, 0.07920189279942744, 0.014378195759960482, 0.06197478554602112, 0.028905834206530166, 0.045857881421163205, 0.025624055265178605, 0.0395199402626003, 0.014003594086745815, 0.04209293082596795, 0.020199842495663513, 0.04284553177234146, 0.03466266320056973, 0.04358608215566605, 0.07474837088657003, 0.08741977925021803, 0.022544477570561633, 0.020360630944431312, 0.02250713269947277, 0.09147891143877661, 0.04010970539022838, 0.04025255397502934, 0.017665005026144848, 0.03075672752944933, 0.03500091400177729, 0.03941681333667329, 0.02333944126392805, 0.04432646399964729, 0.02604421618725023, 0.04191381946927117, 0.04303019343604965, 0.02366606476566484, 0.04968856236026172, 0.06752315818542434, 0.023445561678419193, 0.07746625931993609, 0.012788753881449661, 0.020874059240844463, 0.05048863011442366, 0.03669031790547794, 0.06033694702050379, 0.03108839763538732, 0.015024174504252452, 0.04652275763932736, 0.034870567971900586, 0.040683252436499444, 0.08795408727300745, 0.05552940821695713, 0.0032234099841932018, 0.0688232783408415, 0.07693445640465907, 0.0529211086611594, 0.011520748131818349, 0.08704268779124945, 0.0625184666545641, 0.03631306939848489, 0.015881060126928553, 0.018007679985115127, 0.02643608165183856, 0.04268057772048539, 0.03547228407114744, 0.0319503806155896, 0.060102727128973896, 0.025865939866390922, 0.015961951350853328, 0.02325255157155616, 0.013729393024057632, 0.009532827534712851, 0.10386319004840429, 0.048089503205471465, 0.06059439469789786, 0.026188466712952625, 0.05219927380582498, 0.025237537094301758, 0.046039532359328963, 0.04274992782983088, 0.1058977893403461, 0.013196774225141253, 0.05400327297167913, 0.04029768804508833, 0.006959885330645428, 0.030186622133178097, 0.020852716031274008, 0.008251733172895208, 0.0820721791035706, 0.03867456606859642, 0.02001095585705292, 0.025793615420679414, 0.07858911439055398, 0.04998274778406467, 0.07024257879463897, 0.0481620287492631, 0.035978932489430716, 0.0012485040239088479, 0.051031717504825325, 0.040907720028753244, 0.046775340658402255, 0.05223720664939573, 0.009199818690127183, 0.06602390879584898, 0.059479587380924535, 0.010726736302697852, 0.03299009024856552, 0.04634347391284762, 0.0449341670760224, 0.03400666211100836, 0.015508002120881312, 0.03485281005381577, 0.018488968977884903, 0.01978193195686946, 0.020035394061837467, 0.09347417977668586, 0.09141985372069383, 0.03110065695739562, 0.021055288830651872, 0.02869888512988485, 0.038177930419483495, 0.3135225248913611, 0.17695474258113295, 0.16622693758578072, 0.13386379837268783, 0.11390268036554899, 0.17486984961696211, 0.08541607628426245, 0.08300734263273978, 0.1563974166469228, 0.22713462010987345, 0.1358356014374764, 0.15769516959065394, 0.07943075390592699, 0.11745059442135597, 0.15280120074748993, 0.124603565031242, 0.1811668778499288, 0.14812829423575632, 0.14935486228956332, 0.16842682034738604, 0.09269480788779837, 0.17791328711375115, 0.11864598269664473, 0.23076069811659478, 0.15949858652968563, 0.09109088790512855, 0.1313690943343024, 0.1687813045517091, 0.254855971302717, 0.08871518030402162, 0.07367256893626145, 0.09435701950062668, 0.1106189287477924, 0.15478052679569493, 0.2065130040770577, 0.17439538072193825, 0.12113733126992181, 0.1470737282427088, 0.1448587075837197, 0.1982383811545949, 0.13286825179332687, 0.15343596587979025, 0.12009970348088012, 0.14760977528508634, 0.10240209183745808, 0.21238663083603307, 0.0894158366586893, 0.1820132364669154, 0.22275650423140297, 0.12933160689088607, 0.1666740264983908, 0.13532806818764057, 0.09512777290036602, 0.18079719446118803, 0.14396002516150475, 0.09871189993235374, 0.18004641297363466, 0.14590077102184296, 0.09568150891291519, 0.09895786778220246, 0.1456888557802285, 0.12157306675949406, 0.1785403760450502, 0.11565578831059319, 0.11234000655672244, 0.1524296634259724, 0.10425240867921423, 0.10505320804734385, 0.14097663363622082, 0.11506704974078363, 0.21501561476578637, 0.13508619890818674, 0.12808926508671817, 0.23869194510963657, 0.19578843197274595, 0.13160532520663354, 0.23688514206197955, 0.09529555381666269, 0.14848633308804807, 0.11861896277555536, 0.13892713393415176, 0.10208161427609383, 0.0857136631384492, 0.19335558187336693, 0.06627762179461218, 0.16857545672645494, 0.11684438904687283, 0.15176200247820348, 0.1204907377400706, 0.1101413571966752, 0.16023173267322202, 0.1434760720979783, 0.2527082438069967, 0.17535211728705516, 0.162008244604353, 0.13565783839552634, 0.11773417718828687, 0.12409741073966989, 0.06744674091497738, 0.23302888527752894, 0.15863260074007898, 0.11654078074160124, 0.11149758563166666, 0.1460115779792109, 0.2532243725633429, 0.19178238967734, 0.15253898417276723, 0.17877656095210584, 0.21192112516972328, 0.1884826344828452, 0.09554609521141938, 0.11565239454108862, 0.13804867623313782, 0.18478242980857051, 0.2121390618624226, 0.11914340358588005, 0.0705438505317415, 0.08761054280424312, 0.08898085959616209, 0.13466465136697217, 0.0672789216942845, 0.1212822980878334, 0.10718893860616993, 0.10139763565553774, 0.1627243529524534, 0.12421299808568532, 0.15170817714064352, 0.20322973509469341, 0.10361984221925659, 0.13512076479533028, 0.18327250115333066, 0.1328917706926023, 0.13187242942231317, 0.14070375311759212, 0.1387830481173531, 0.18941382967656661, 0.16216601275147932, 0.14687365672040373, 0.12515572290266716, 0.09725170570515818, 0.13371145412806543, 0.05929357740246962, 0.1766184146606153, 0.1904233803431834, 0.12778903522919263, 0.1191042718147078, 0.10045589909197823, 0.1133888498729756, 0.1891561789858726, 0.15732036873457894, 0.2148414216935635, 0.10048778367138679, 0.15890258544635388, 0.09353755056978234, 0.11866958586559181, 0.21611280589094087, 0.14436248179164626, 0.09831956332369197, 0.14256787486374378, 0.24775033726567225, 0.07706030932885986, 0.0995014301471172, 0.16963299514064867, 0.21566760155462453, 0.13671392124266396, 0.06550171262314243, 0.12222225732740857, 0.1568913441752234, 0.1984205568629888, 0.1241329035932018, 0.1831120210549524, 0.12554176992947055, 0.1383690542030719, 0.11141914588909958, 0.10124752838765422, 0.1546583051282552], [0.0066273088469320255, 0.01576862714794134, 0.02345118476378341, 0.02649886064201353, 0.043506899307812416, 0.019319322102913455, 0.05199955851440469, 0.01687078060762536, 0.03302531880176356, 0.03532701081806614, 0.06256637013246936, 0.036317757856581485, 0.021501956394903605, 0.05665580644422481, 0.053376153396863135, 0.059192342713715575, 0.04125730127036091, 0.05269749908738079, 0.04206239839174575, 0.049866857833319136, 0.010208180962851452, 0.01229727113123743, 0.06394585316640235, 0.020012909381259835, 0.05344883981911887, 0.04211999288189315, 0.02404427662822268, 0.033509141630342895, 0.012503268343636827, 0.026483757218586344, 0.04376789014185629, 0.04612530739377103, 0.08319752395994241, 0.012776945593706783, 0.11506703441902516, 0.0959413429541934, 0.04655929620287592, 0.03091384067140039, 0.03563960916512916, 0.012584029332614474, 0.028067247551535408, 0.03881083778856743, 0.03155364857746228, 0.0646279816846213, 0.019473817139383287, 0.03885985209396289, 0.0679617052176787, 0.04036130015588096, 0.029301972526516167, 0.047185048310747074, 0.00852125056553632, 0.013434363945928073, 0.03446369867531523, 0.02347740412299191, 0.03753753837137934, 0.028029900765226736, 0.12125188439723947, 0.04585853642633846, 0.06425378603800651, 0.02327303867787123, 0.04016166913413233, 0.08773578285810449, 0.08068517691666081, 0.030880720775213935, 0.06087736076404972, 0.009210373466503958, 0.0816379911116054, 0.042268123642932025, 0.0366309805653028, 0.05350027496235506, 0.012782999603528411, 0.029667411788156437, 0.07511738011793745, 0.05029176083964206, 0.019266086653055205, 0.04361378772544765, 0.07591811819903313, 0.03505996022854121, 0.0648391308383115, 0.0016788008877248956, 0.06777084207222348, 0.06382027986429392, 0.08561981736772484, 0.0077405619630289664, 0.03478750488871048, 0.021985244877155752, 0.013644710622517573, 0.039735272256357056, 0.05005389820003221, 0.02988178042634841, 0.019948776330678694, 0.04369754794864886, 0.02516977278695953, 0.02856444627527268, 0.07387991063296795, 0.024738857905650814, 0.025427279836167733, 0.06691342114561027, 0.0426203900227143, 0.03613208112637362, 0.040747956222584175, 0.021656388229119684, 0.09491683059041539, 0.03940799949510444, 0.09262167713454655, 0.04831462963334015, 0.03373131478926347, 0.028465513680731098, 0.02263861253947741, 0.030234251734650427, 0.02241918006010594, 0.03412869608690662, 0.050941767291195934, 0.07553355738280282, 0.054073584521369594, 0.04468237695794913, 0.01851988828650886, 0.016637656221827193, 0.05709051920641815, 0.07165028833814206, 0.005532822969760145, 0.01741451151188343, 0.0270017858729848, 0.017594898404974132, 0.032554163237012206, 0.03370628669677723, 0.10418431878450418, 0.04284899065931959, 0.04630095603305005, 0.08177943392506531, 0.0084493714084308, 0.09639833738366443, 0.011628009059706764, 0.01630395406767005, 0.036330026754688834, 0.1175985949474477, 0.08167709223926067, 0.03696598698415103, 0.08627420967264522, 0.022536458545214227, 0.031635405480741494, 0.05249453558316154, 0.055927555602524555, 0.03545460276185505, 0.023733647127125054, 0.07315110820796221, 0.06897140910188038, 0.03137243813985298, 0.04627607349726943, 0.07991095313862448, 0.07160493593302465, 0.027668280451889002, 0.025301771651532863, 0.02246839929402115, 0.02608026062408763, 0.006364326663089977, 0.05250078303018405, 0.04537916839903882, 0.05655954749653897, 0.16951779083859536, 0.013372212190241104, 0.03675826224348238, 0.043734381456048264, 0.03322236810720736, 0.08174422452406538, 0.021782559079809055, 0.020850963605147217, 0.026845758660666408, 0.08566068815848521, 0.009280466681136, 0.06686613819892369, 0.05972107744685585, 0.03860308623482143, 0.023218098682381456, 0.08628940119618371, 0.03270212162826811, 0.04883826988178396, 0.029287924389204675, 0.022377185035316695, 0.04288034663806039, 0.07030601853564863, 0.009896103555576937, 0.02628201370938651, 0.026320731793079647, 0.03118211125594474, 0.030453119224177736, 0.041325360521553986, 0.038804762711327885, 0.01803429196438482, 0.020430892698406693, 0.03966063230989441, 0.06682101562018357, 0.04819246925293438, 0.0379029929547781, 0.023036080022012035, 0.049428762792940104, 0.07099155997557026, 0.10791780997908886, 0.05525383489927458, 0.027905426799289645, 0.05484843649150384, 0.04872247952246859, 0.03362261840412694, 0.02999936151618679, 0.09621298241038477, 0.039961053689401, 0.040861992240552945, 0.055398671482239044, 0.07642271733211894, 0.01975772549368201, 0.04540852488829725, 0.040273640545145165, 0.02141286994540884, 0.015719104351686136, 0.0029961653232138848, 0.022546655175486402, 0.06682626332246488, 0.01104170281905681, 0.02567568576083549, 0.02681034624636654, 0.027946866410333785, 0.03428725713503457, 0.007144337756589296, 0.043320456489680276, 0.0690627267824546, 0.015324413937877025, 0.02616433111289817, 0.01433727325826523, 0.0424357628329627, 0.004314948577478889, 0.01288740685389888, 0.03822945366283098, 0.1096369572464497, 0.03057347355230201, 0.008498021822062232, 0.020429260931127978, 0.026777680257275224, 0.029834351922956207, 0.04989373985858214, 0.059508691061167955, 0.024029140646058707, 0.024919794466827187, 0.02898101232975962, 0.0730774411931634, 0.016480148544595126, 0.05676188663909993, 0.025914971408764684, 0.018431361081198822, 0.003261777822063455, 0.06223032183404412, 0.08663786394942193, 0.017783706519572486, 0.04188218769887763, 0.02055095782833955, 0.02589323940957266, 0.0455492782226253, 0.03174144928644021, 0.03392404335881433, 0.07142023213448064, 0.0568765125447704, 0.0048462669421438015, 0.01698882326543812, 0.06894472625947769, 0.04712360805921978, 0.00497328192596474, 0.03364092407507762, 0.024731463241961696, 0.030173608214564385, 0.016809911091601657, 0.02211741419629224, 0.02345022332343844, 0.0387492289976968, 0.024486288293114594, 0.08055975300169761, 0.07072608752716934, 0.018070288520726948, 0.02829117122136297, 0.07920348626230994, 0.04004271100125006, 0.02954346067722767, 0.06549831885363787, 0.055874710857507684, 0.08200693905593888, 0.011788610774543018, 0.027191766102107304, 0.032254419845318606, 0.06923239993592424, 0.056939431345991554, 0.04893303495801745, 0.025009712121719797, 0.05234448960231197, 0.020968843469276063, 0.05871595093800176, 0.10591081283505886, 0.035680533582044226, 0.05391353726266854, 0.040507090518311153, 0.05426933147734212, 0.0026789814611190873, 0.029677878464421922, 0.027309594255301262, 0.019462266448704947, 0.09398064816430693, 0.04652270018273304, 0.010120024352574782, 0.037268518935889006, 0.012931944332986832, 0.04424733860838798, 0.04431769229291428, 0.05862137738374933, 0.012284145172264789, 0.02778263439634635, 0.05786733619207817, 0.03015630803401432, 0.011945634858772881, 0.05318927773905378, 0.026994659340069182, 0.017500612133693312, 0.056505745141616756, 0.047545975314513336, 0.0285027225712134, 0.006664274504498369, 0.028207610181022077, 0.01624621019037741, 0.07244421589759088, 0.023524440006322922, 0.04379825786717477, 0.04260256315671629, 0.03099760855548084, 0.04002401845589761, 0.07831239577142463, 0.027918641815983483, 0.04283034790968222, 0.017645791541003895, 0.036188430723644076, 0.055983284668576334, 0.02787943535123862, 0.08514630608260633, 0.034929690807456934, 0.11110304268978297, 0.026562752374898524, 0.038523286686188755, 0.022549445650750594, 0.05112663196820406, 0.019965919463204283, 0.018959492520098726, 0.026829785727445158, 0.05392077679355299, 0.01782315813245312, 0.015059041080906268, 0.08582237867578384, 0.04666356076937049, 0.0997076610163335, 0.09998924429378203, 0.13175331807184604, 0.19748064358868908, 0.08710095643877022, 0.05991079529086429, 0.14999575612525787, 0.12036202730791223, 0.13653102541162124, 0.13882706752948223, 0.12809386927514307, 0.1675879847138159, 0.07977720950880358, 0.1408692281092367, 0.12805043975071562, 0.15469624180226557, 0.17526570256919632, 0.14628939210407196, 0.05936871530608304, 0.1526758227978022, 0.11383214665036048, 0.2052518548143487, 0.11467246849450374, 0.1521813590079546, 0.13971159264685648, 0.09315289782300111, 0.14800512261929052, 0.0859264976855728, 0.11286501427211108, 0.0916483088005935, 0.1480622268131664, 0.1278915990804953, 0.14201500453054905, 0.06187230596439012, 0.283987537146576, 0.1689189858734608, 0.14382833464732095, 0.07194573780702007, 0.07609661668539047, 0.10326607813758236, 0.16235335189248287, 0.1628728820792129, 0.10542448489896714, 0.1476543003152455, 0.14598565356385323, 0.20045475012833075, 0.1730262896706981, 0.10218372613552118, 0.19650227270059048, 0.10086194867448461, 0.24420892729634242, 0.16360729992870363, 0.14253246627988356, 0.07811732680326508, 0.12630607286888745, 0.10953453895185264, 0.2301862547474523, 0.10928070337902154, 0.17605137170082139, 0.14576403964911738, 0.21566127366836996, 0.2699313252683609, 0.15339778405764412, 0.15311941834947757, 0.14133873275451123, 0.11701361786934639, 0.15740194177675634, 0.10232703820351632, 0.10949638777322347, 0.14118338544522563, 0.19517894774194688, 0.06564999660176617, 0.09424256596473918, 0.22561398154545217, 0.23891492266087766, 0.14567921839414105, 0.15091274804886312, 0.10269937991735437, 0.1157836330633971, 0.13547955441378778, 0.12312507662441462, 0.15627032266028468, 0.22437771481852378, 0.2111114928078267, 0.07369284728361715, 0.11818174873628925, 0.22736023300357405, 0.15228946933582907, 0.11294837229915204, 0.10827872932197587, 0.11990282654521928, 0.17265443059225238, 0.08375658428356533, 0.10135894821536157, 0.23704326260955105, 0.1322828533668672, 0.12211680532463136, 0.1227534550332254, 0.1663062736512192, 0.12158609791508607, 0.09420928710530843, 0.11669166175828827, 0.1764970510116508, 0.1851441305611403, 0.17997965607191288, 0.15285871862884493, 0.12393314616694567, 0.15092518931675344, 0.1302543597956819, 0.14736744635287793, 0.11309203676759236, 0.19675860572005474, 0.16330489438147316, 0.15407492917391563, 0.18102774096112098, 0.1796475416349788, 0.15961034343607966, 0.2001828655240036, 0.13735873744853083, 0.16634540542239146, 0.16552195283434085, 0.1297170104038331, 0.13123254682267868, 0.1265869590063249, 0.10957035356231275, 0.08216436246349927, 0.26272826016910616, 0.15430705381497262, 0.20309001597906315, 0.25238224275169835, 0.13303493720389184, 0.14650832471107283, 0.14466667998461955, 0.05583310845277964, 0.11817522166717438, 0.21433093134433995, 0.2128554766456927, 0.11727230277873817, 0.14909469883047766, 0.1346453306295218, 0.08368722268290098, 0.11082095379430441, 0.10884773346685594, 0.11016604054959551, 0.19162082173410924, 0.15858507264525662, 0.14515823264035488, 0.19391401400489194, 0.18434022853691734, 0.14381924884453898, 0.15203187993216902, 0.2895449534539254, 0.12781839937933032, 0.1055731136171568, 0.16518617649712872, 0.06281260994353122, 0.08794984314590694, 0.1621878615790798, 0.18907062228648894, 0.23203505473511837, 0.23575323183209668, 0.1225436082290065, 0.11852343927227682, 0.16182066031521367, 0.10380348115558587, 0.16224381664106924, 0.10645762341277254, 0.08799043048413531, 0.16940652422847288, 0.09188087777264657, 0.1325702435907818, 0.10292916032936304, 0.11115213360397086, 0.15401935715588833, 0.1382782421405277, 0.19153693510640055], [0.007779808168584902, 0.010927213851602809, 0.04022760249133553, 0.06376347444470852, 0.06164501533813535, 0.03496091655125061, 0.04927374873190157, 0.06043906271037075, 0.021423424721785614, 0.07912829473254182, 0.025894298526127974, 0.02624881337396801, 0.049240680546650005, 0.026494857832609166, 0.04627457962581708, 0.017403596674182245, 0.009205426453732917, 0.03140341298985145, 0.01872578016181867, 0.030492203114854715, 0.07019822230382312, 0.03030577178804144, 0.010744985474664117, 0.03288949141278863, 0.012444169448328116, 0.08525808597163809, 0.006932765818125899, 0.07351677729597977, 0.07851973746813114, 0.0201741574827822, 0.015783767918154838, 0.04715438947201737, 0.054409717089466514, 0.055975692737246716, 0.09471806141758159, 0.04188216088580028, 0.02532888158795334, 0.041799358272504424, 0.046431371010839946, 0.04045346053317189, 0.059676242151087334, 0.053723501492171526, 0.014543064584534977, 0.03772320361026833, 0.07615586592545433, 0.01326405302426147, 0.05667150358579332, 0.04500098909521776, 0.04981964000410611, 0.052510278690005505, 0.040631461062378464, 0.01678703187574302, 0.09274625069191379, 0.028173919549332033, 0.06371321141599648, 0.0306512889332108, 0.016278376307098136, 0.057552002911125465, 0.05064191664719293, 0.03827869779460373, 0.02760935296875335, 0.030244239605963234, 0.09611716013281577, 0.01887376153571231, 0.013303239379198322, 0.05489471969344924, 0.03199860776564287, 0.059721253647078434, 0.07858966597385945, 0.02591513037200897, 0.012676522958152478, 0.0570346713967381, 0.044799695662673444, 0.013399334575590349, 0.016524807640141057, 0.025872646966168, 0.042550580260614236, 0.03250573881931844, 0.018874728721716715, 0.051560145802795894, 0.027489925607017456, 0.02319065741293373, 0.061673686178701545, 0.0051120328979807035, 0.05489655830446751, 0.061497922626233874, 0.018357429766066132, 0.026180585583431587, 0.022598789373953498, 0.030430492817334114, 0.0331012113019824, 0.019086741639541525, 0.03710594741747745, 0.007519902785368745, 0.0649277059241168, 0.08535520293779912, 0.04439799362913736, 0.0510456717963661, 0.014027803422762983, 0.055723117379051064, 0.0676541209160801, 0.03258746124864106, 0.0723085034218046, 0.06286274273729613, 0.07146159322151253, 0.020220473243464387, 0.07130118973192669, 0.03802565129233464, 0.042437957674865766, 0.019351110921331474, 0.025853236213386543, 0.037134296501115445, 0.10588665042192706, 0.08838597700119981, 0.08810746573632763, 0.03606289955637148, 0.01874644921401576, 0.034802378485760385, 0.08541609926690018, 0.03191284422251967, 0.11286624767366918, 0.03722831464162277, 0.05856018994123705, 0.08581985058563371, 0.038434225134551525, 0.06391461976172944, 0.019647523745774262, 0.07734265103335343, 0.010523263350008957, 0.040791604082070054, 0.0719476760094685, 0.005436595144396227, 0.0801861472427845, 0.028408419062954285, 0.06679015759859355, 0.022031991562295346, 0.046022613307521235, 0.032802115254584825, 0.04595671825471424, 0.04995364410382125, 0.0641724236700083, 0.08038009006169536, 0.03861401064862167, 0.09963214006875792, 0.022271037807748206, 0.07812700249374875, 0.015267998265523105, 0.05281313622911131, 0.047516994208337805, 0.09700074296204314, 0.05708400745906177, 0.03297097635485473, 0.010293349830223428, 0.013156956805276775, 0.04991815508072896, 0.009900517179630697, 0.024669925314224055, 0.029517942288469885, 0.03483755724324334, 0.024089956535927715, 0.024343102629626953, 0.12760772520015318, 0.05937025514281085, 0.030264073622322855, 0.028886494316881704, 0.006937606057392494, 0.019947437592031016, 0.06156919561626931, 0.009488228768590958, 0.08388305773898479, 0.0729669789753614, 0.027744255306559707, 0.02493761558716576, 0.04539139516231033, 0.09065551247688071, 0.04768205168206365, 0.06025058592879965, 0.016857163394771276, 0.08886594640752, 0.03517829016932557, 0.010025891298878818, 0.011945313101844683, 0.0379342416812095, 0.018783123758170876, 0.10941407928663878, 0.033716843388373816, 0.0595388021470318, 0.009759027443285431, 0.050170745760683096, 0.062353045289074226, 0.02903984596712455, 0.02477766025901562, 0.06147023620865038, 0.015512038446632365, 0.03251295153712554, 0.018143099432270375, 0.03302505067099006, 0.06445809402653287, 0.028389927615681966, 0.04840436151191112, 0.019578374734508897, 0.0686942231691172, 0.0116412595079671, 0.11573559168966548, 0.06769732061413027, 0.054245720647515795, 0.020726568163222363, 0.03463067136885178, 0.03728747195113571, 0.054861850691057985, 0.03363301421725943, 0.0335066901489852, 0.038841197853006666, 0.07240565103148261, 0.04450727990197559, 0.04917605336935771, 0.010773538529211956, 0.0123538572581545, 0.028571431081922307, 0.05689944538678374, 0.05754988084757521, 0.02686748108375938, 0.06847053315610656, 0.006510373664974806, 0.07220982363627804, 0.0435105114123754, 0.07162147577130987, 0.07700210962925227, 0.060375013929461284, 0.03581477133857627, 0.052909391346357526, 0.040455371922542976, 0.030912245293298078, 0.03297599423075876, 0.10462433670557315, 0.06215339128468787, 0.02534384711555416, 0.0348516532610501, 0.03224933302150138, 0.01085535288908549, 0.05445907996486753, 0.030667263781651858, 0.032163722695963036, 0.03894030281733121, 0.05267171639828913, 0.06351946777994595, 0.04570030096557833, 0.03560612729239849, 0.013493282810574578, 0.009906319338047217, 0.04514682925336304, 0.05386510518409553, 0.054916580012368585, 0.00849099488057677, 0.02219413981712874, 0.018080628792484923, 0.019603489011886622, 0.054402914228698904, 0.05184997218630968, 0.05870914041635491, 0.049865616770881804, 0.03531327486158379, 0.025203287218426986, 0.09603390935808422, 0.039497861608622536, 0.029392324936305805, 0.017935179339181033, 0.15878522077635412, 0.07662887925342207, 0.013371648158006852, 0.04096590823704197, 0.11381254246037815, 0.03780438594760434, 0.034866350657877423, 0.011143374177927693, 0.027962109644807158, 0.020366780715243473, 0.013416564850617322, 0.0457695399921748, 0.01921273054434888, 0.042151685939320636, 0.021125874256775267, 0.006656396247807049, 0.03353821466706934, 0.03126475873643593, 0.06835005816913421, 0.04137667692116192, 0.017600559794734565, 0.08129794766465503, 0.05410616241034962, 0.0808410604874934, 0.0958625431503019, 0.0219082415494467, 0.04433150102774944, 0.09494074785541143, 0.08633502939295384, 0.04037114821614758, 0.013767294266501503, 0.019930451507529905, 0.06656851304034073, 0.031134625295958215, 0.05008760606870056, 0.010596224606307525, 0.03350730301932462, 0.016694182019320228, 0.04867627292931561, 0.11641308154550292, 0.030502625741064552, 0.03926348083862855, 0.027254755766461455, 0.02855218312282476, 0.02007301280935926, 0.06842029311003224, 0.11727226447434196, 0.06115437815746954, 0.040191898963624434, 0.09094987410090624, 0.007917519655048607, 0.0592796154500496, 0.03965693976609938, 0.01793090839900317, 0.017027652431880275, 0.023086011717696826, 0.04113260130848616, 0.027241678645593986, 0.03361037631909694, 0.012629224689707402, 0.0446707554041378, 0.042480755176755695, 0.04120502726084763, 0.03361535206016514, 0.03154982771393994, 0.03598837835353709, 0.06323580840422262, 0.043377537700918414, 0.0586659713618217, 0.12196944831239602, 0.01636688627542988, 0.04228575898694896, 0.023121104290288304, 0.0942377396108162, 0.046133600295551365, 0.05435971453064873, 0.008764087030994556, 0.007044167930050003, 0.033102908186734684, 0.01364314588793223, 0.06694230266035565, 0.04548894496814859, 0.03416155742841863, 0.014098857120130093, 0.008536519655477135, 0.1648672081289753, 0.08045043991578203, 0.17244878194985852, 0.20808360689590055, 0.1731427043916718, 0.14092156723622354, 0.13133180117414844, 0.34271298757483887, 0.20853189090567253, 0.15393897921087282, 0.13642904378714102, 0.11204663318611922, 0.11230199327391964, 0.1338389464804242, 0.09594286746916272, 0.15436866260584325, 0.12969246494673914, 0.06155326864832352, 0.15286155315416475, 0.1424581863947453, 0.16255097193343027, 0.20225144081538726, 0.11628803301362262, 0.11090707739875202, 0.0709041416825306, 0.1575368805037391, 0.1501608633946988, 0.13892172535340633, 0.14192570932209492, 0.10310821805990512, 0.12673616229045775, 0.13423037144445604, 0.152742043437977, 0.11589977199271803, 0.23494290999106823, 0.14511507124670092, 0.17021796455787075, 0.22833072850781105, 0.19208013740999086, 0.10297652754572131, 0.1892220625473607, 0.1117947971027705, 0.09477992301746722, 0.16090451108832515, 0.20195956131623638, 0.18852124531422892, 0.14492891188110077, 0.23123492186348285, 0.22991352744640844, 0.11139338235220603, 0.10879912518806036, 0.2860647385879871, 0.20485413260757926, 0.18825319114952319, 0.1670711664783378, 0.16703960365585743, 0.09581817899860683, 0.1592637039721012, 0.19128135285310208, 0.15597390792062207, 0.09246158008013042, 0.12735447185414453, 0.19593875374524825, 0.12682259999095433, 0.15642856578192404, 0.16605231550432023, 0.14620691507814393, 0.1258210089778708, 0.14688425937727576, 0.12410042146521232, 0.17322406292923037, 0.14172309438788122, 0.1039188003708278, 0.09264431503270903, 0.13449125502619053, 0.12760244685435487, 0.13321311393332097, 0.23532181707841737, 0.0999801125257246, 0.07559346545848154, 0.08083854005822251, 0.10702770008074661, 0.19601559236405358, 0.13576453912162012, 0.1580478305057172, 0.1409328900157444, 0.12134861065855912, 0.1833313367059154, 0.0840626593919531, 0.11311462103960016, 0.11514630153655045, 0.20940662541937446, 0.14850805934158065, 0.0880697129234191, 0.1326389923211067, 0.20516010812453686, 0.09651132003073731, 0.15375248276658599, 0.10142314638341628, 0.19428155234744474, 0.08873034118404312, 0.07152868720192103, 0.19146801783673226, 0.12454227799729956, 0.1495826202294519, 0.09342870479750057, 0.2813139515778711, 0.10894745513195954, 0.11232516743362912, 0.1419528747998899, 0.11458131935327284, 0.09240200908313836, 0.1860279355558657, 0.14166962145076645, 0.16910534442192124, 0.287974871574871, 0.07188063565521471, 0.08734124757710003, 0.18540047890236303, 0.18507004985886236, 0.14779285497723088, 0.09293869197849305, 0.14831927995527946, 0.14721813581643567, 0.21527275983845034, 0.20779978664171314, 0.11168487880739475, 0.15600065971093793, 0.08562659724585472, 0.0992884347215295, 0.17320025291654373, 0.16417454207135787, 0.17053017603053203, 0.20121576655055248, 0.18010831287791654, 0.11805054085749773, 0.1617794447848874, 0.2708786083084922, 0.11495736127178516, 0.11757626348445493, 0.18067155604160604, 0.11804632737391418, 0.16807821969832146, 0.2358202951689882, 0.10607221223894628, 0.18341027440563326, 0.11852694029409079, 0.23449732261078976, 0.10447418347241418, 0.2776355650876799, 0.17096540590207424, 0.17188224460809462, 0.14455636332352317, 0.12896891022401472, 0.17134642739209438, 0.09783423130190182, 0.20356995474186637, 0.16351964414840744, 0.3158677958192364, 0.1468022420041023, 0.17491481897811736, 0.2733432663784873, 0.13405280758536633, 0.1205399742109641, 0.1290450440419297, 0.26805159065031237, 0.17852537604349275, 0.19648210926642343, 0.07451977024996474, 0.1487035036928231, 0.12187742583093145, 0.20939115044330397, 0.1489448673542469, 0.16606429711945597, 0.1398276090021095, 0.12220857499708092], [0.0650663908210493, 0.03632417001250771, 0.06276829558755122, 0.04915692415388842, 0.029757204953761354, 0.013702460245469646, 0.03675979058889132, 0.051891528625762275, 0.023040714853953932, 0.017941767695329843, 0.0419290914320417, 0.03505098167806864, 0.03276519747751375, 0.03506641834974289, 0.025681714872799577, 0.03701264556917933, 0.06029215769001073, 0.056817887666364836, 0.0948298489674926, 0.06011619112424313, 0.07948224267531788, 0.06320221927918254, 0.0028160523065561133, 0.11324012922423501, 0.023915441706776622, 0.012531999513627061, 0.030138400728784265, 0.019657228164555087, 0.04379893585498776, 0.051986151975729776, 0.04552520390960478, 0.05351173180726267, 0.014340982081428652, 0.03410733755557768, 0.04832814725476408, 0.05041652591899038, 0.04862972542703633, 0.04231836368900634, 0.03827762910194936, 0.06877857711045973, 0.031139570393509446, 0.008014729988175415, 0.09374157510577671, 0.053335481788963086, 0.040397248831727815, 0.0300122854194694, 0.016731770123325048, 0.0171315148022146, 0.020984331851885207, 0.025999823307257988, 0.05071305557184162, 0.019152592642292864, 0.08251022817867418, 0.10690292734051905, 0.06895855414651095, 0.07787500553193592, 0.004959975936329894, 0.030402748943156296, 0.005496298291555216, 0.05355092486546886, 0.053862105949871966, 0.0838304581421037, 0.046831153994125706, 0.014752625063392184, 0.048301583155989654, 0.02210263444501306, 0.02505023051203499, 0.017430898132583788, 0.09434431010196287, 0.02712068271883313, 0.019552854430531303, 0.025315517184114265, 0.039899042702370116, 0.04427057022469179, 0.018051841123510274, 0.01709698721946728, 0.039065653953941605, 0.06951249700279967, 0.06157916625060382, 0.04442337029162915, 0.0466098886493954, 0.08000869063600417, 0.044607863415993994, 0.06137868487125924, 0.022404362004430547, 0.020841351116917307, 0.05087809772380898, 0.1471913687043613, 0.012699960460585934, 0.006098492716949794, 0.046024348496669726, 0.0591567502687535, 0.12180341407656671, 0.04039053790151112, 0.06611937867297281, 0.027077331718417908, 0.039512302365995226, 0.017906703851035526, 0.05100899916743079, 0.03771631647982905, 0.008380729930415269, 0.036373598005382285, 0.056219289544969804, 0.04629825174267735, 0.025795747060328725, 0.0268285944607229, 0.025578304494340575, 0.06914410064177168, 0.018966015758773973, 0.03380208982214813, 0.039162901155049765, 0.022005912014133027, 0.0065849173716419655, 0.05310062604445604, 0.010369188704287574, 0.0641082791281083, 0.02769351347289499, 0.035824941155771096, 0.027546068360548348, 0.07672863922292188, 0.08562556302715695, 0.006362466027043881, 0.043908007623207186, 0.05087481503705344, 0.04243018954331356, 0.032653337149249936, 0.031008483173566, 0.044289324057078173, 0.02504902966921368, 0.018829226929454074, 0.006549239220593366, 0.03775365177481886, 0.0985851277026438, 0.025083700893446807, 0.05508996103139174, 0.055504108163257765, 0.029052584094085523, 0.04989563975663436, 0.024466532800767212, 0.07910123650705622, 0.039296828645972476, 0.05840573129394363, 0.041665660607958996, 0.030630784589917432, 0.07340058474050415, 0.048441283119421814, 0.0191758836304108, 0.06974758640412362, 0.0373337704748396, 0.044717494428398154, 0.007387092825205576, 0.06458848985212465, 0.06726132465466376, 0.01988711774409298, 0.03143942869839168, 0.02464690820253905, 0.05060169703116821, 0.02676900814197237, 0.01702927653827975, 0.0071505267894075766, 0.01207568690240864, 0.013258283424581732, 0.06061528974603261, 0.042608396916259686, 0.04348800757959966, 0.015065751053513059, 0.05017462599601957, 0.1102770007245483, 0.03907320375043539, 0.03132033841534248, 0.04243732565232823, 0.04075501572280642, 0.019907905539918332, 0.005457268027032936, 0.03898785772523092, 0.0641731399622175, 0.013621906100231554, 0.08345800917595626, 0.058823551817406575, 0.015622607916743766, 0.026928540206544345, 0.03253638233628965, 0.06870085749054147, 0.06986649091085119, 0.028043805261052428, 0.08836460314811238, 0.07226194059776683, 0.03785796996746813, 0.01428957375126981, 0.031748970354636835, 0.019054533387984962, 0.031214173950795687, 0.024696194469147635, 0.029819244669089397, 0.0626504406212799, 0.006850986411013911, 0.023111830795964888, 0.029606705065816644, 0.04034024805972173, 0.024359833989893238, 0.048588578844623226, 0.07630794203930324, 0.035996108180693084, 0.04308394599525679, 0.009765009632364157, 0.02425050366699936, 0.07644135625131669, 0.1793082259715565, 0.027490555714335174, 0.02736873049739628, 0.03740453018596576, 0.055334615040450334, 0.040470640054873885, 0.013322170369417198, 0.0414977494567152, 0.040046407375484705, 0.05875202218791651, 0.04797268245789794, 0.031949857760581284, 0.0343428329835015, 0.04190554571968894, 0.024351198263766787, 0.0744941369480183, 0.002124619411094295, 0.017587858056949995, 0.06974849038787427, 0.07415216295949875, 0.04033690408593224, 0.08138366524250278, 0.048086132418604634, 0.05409180975308823, 0.10078086592857877, 0.07593543944700111, 0.02776743329670881, 0.014474769761305184, 0.02620325412511105, 0.01876024837275186, 0.03757003965156694, 0.00951961922128835, 0.021948246660852627, 0.045469926835428325, 0.061792265098061294, 0.04372250326278229, 0.007700126405970584, 0.014892182342948453, 0.09223873276383647, 0.09136348497122528, 0.03238794897052069, 0.0077198479031663275, 0.04529634663354486, 0.011414981075382281, 0.02811944878269588, 0.04244934174142057, 0.02978128309722149, 0.05297967991341026, 0.056981060563796954, 0.06624500943167556, 0.025628073396341457, 0.056504431300826614, 0.06931808687025501, 0.032757107589033344, 0.04178072701418593, 0.01007312061941071, 0.01667930650705051, 0.02363582536007368, 0.02995090453975624, 0.027966514650371768, 0.024168769746357878, 0.06984742298241585, 0.023830708551911578, 0.018166398081267555, 0.0243391017354424, 0.0609531345206403, 0.03318010686686443, 0.07443046738063136, 0.02002439495446461, 0.03599388652571267, 0.05156065908170516, 0.025306688020786932, 0.044886627489881176, 0.029105076438657222, 0.05483103097386418, 0.011426911937193045, 0.06224456723899611, 0.05303763063444246, 0.060913037478683464, 0.05350147772039618, 0.06560845165363242, 0.059404449477311105, 0.04870501271779499, 0.02793124970799733, 0.038946217016106656, 0.037642388995135986, 0.05670649082129521, 0.03270518981040486, 0.06710841350497739, 0.09280576806275115, 0.006467147153847281, 0.044688203056613286, 0.06696559939413302, 0.06928697603964998, 0.05572235512156641, 0.025133638334791028, 0.0511778257937441, 0.016450267285108566, 0.024408848295288704, 0.01618720992888895, 0.06855093408375978, 0.06150832226980598, 0.05973716912370536, 0.022164884834520282, 0.03470327352143584, 0.047368825142902714, 0.018622896468807614, 0.029032261696674173, 0.031764016321469704, 0.029270147318921746, 0.048784126617735436, 0.04623295040801168, 0.09364232075430694, 0.03234070049779069, 0.03293587803660381, 0.0240026512408569, 0.08809352293610574, 0.051141754543829354, 0.08798849228168688, 0.04379963682543847, 0.02397501461898848, 0.014079163872426557, 0.026224949735126672, 0.039959456396078875, 0.03286355933655174, 0.07171507639389846, 0.05823499710869886, 0.022482403381276998, 0.013245201515664738, 0.05324570011467703, 0.026391257847388907, 0.02932833744243028, 0.028564511392746243, 0.02539328851496741, 0.030467487203197616, 0.06676931234617388, 0.014408519435223314, 0.05855049892899491, 0.0349847725292127, 0.05189144818653023, 0.04379728493551093, 0.0401534490107048, 0.021187515606382684, 0.028096276538206205, 0.04238676767976534, 0.11180841814606421, 0.2058055065572262, 0.1639708239705332, 0.12941587656255693, 0.10860351995835382, 0.0871026341713244, 0.13757483553021185, 0.1415781965178828, 0.1653128108310123, 0.15637481705315653, 0.19884657835768116, 0.15674001116666103, 0.09875192802639739, 0.11202326750442868, 0.11960827339921268, 0.14077591860005934, 0.12552310802763508, 0.1518313947223848, 0.17537388950586322, 0.1172855714215867, 0.13413165335453328, 0.16718672318083627, 0.12807353730163268, 0.20592748307653014, 0.14964248233985517, 0.16023118108991655, 0.10614816985663869, 0.08999677645342966, 0.09175483332646471, 0.19766936168795635, 0.1493291217353075, 0.291606679919266, 0.08243457699615149, 0.11701757854391491, 0.1694220604915773, 0.10154457898029398, 0.08717700598701354, 0.10437253892662064, 0.1787682259154897, 0.16782461395186765, 0.10556779696696228, 0.1181002369811458, 0.18328606090959043, 0.20151821806305842, 0.13832256798782658, 0.131274773589065, 0.15808009812908788, 0.13862973860194608, 0.15609914797448343, 0.19028257338270066, 0.09325427423802116, 0.1378868324982543, 0.15833646179206912, 0.13996979492085596, 0.21763896028841698, 0.1452844839302763, 0.18947690935625186, 0.10848119103860472, 0.1191090675251138, 0.15301533764408481, 0.19091035179313154, 0.1920907553886214, 0.10068912689964618, 0.1539728556188845, 0.17866293479117656, 0.18266225083460733, 0.11629622249353318, 0.08366899745118234, 0.18157740904679223, 0.11019060132844795, 0.13673956986636887, 0.3344686251253851, 0.21731991531147113, 0.10305863684944569, 0.1176854310136649, 0.0956826197404054, 0.10479733468063417, 0.1640392815874469, 0.07644062846778862, 0.17314668804887803, 0.23534208776489382, 0.12583364176774217, 0.1249085369730188, 0.1855901316288979, 0.09294443763792516, 0.13131390536023727, 0.1580620797411088, 0.27911420671209214, 0.0893359796534623, 0.11200989160927073, 0.22234129989820145, 0.18756668443881697, 0.3257997580353291, 0.18230862464875947, 0.21581896520670385, 0.10665489871415401, 0.13647038189153518, 0.12125591401972118, 0.1927652345189164, 0.1357000345183957, 0.10771802190931574, 0.2180204107876747, 0.11857078350599735, 0.2580476161693373, 0.13121647429802727, 0.19356806402004537, 0.13365105575611516, 0.27458175476039615, 0.11424472330198174, 0.11981514778228537, 0.23315109162321015, 0.15320304450729202, 0.07986108081475382, 0.13401995773517317, 0.14051178680552592, 0.08860674821921895, 0.15783695714367976, 0.15596309075913123, 0.21218553275590946, 0.28499074460517976, 0.17812837395937214, 0.0726942593351968, 0.15262968898300203, 0.13641088750333558, 0.16142313729130453, 0.1420871546912578, 0.11512940929782008, 0.16914239243393944, 0.12049773212281928, 0.09395732844789183, 0.1663933778482099, 0.1557133460958158, 0.2131275297893632, 0.19719614917712827, 0.13174049375999358, 0.17915813402543146, 0.1970720122898779, 0.08781342586923031, 0.11192705452201829, 0.21439615607021317, 0.12634945642803946, 0.15727829518577746, 0.12673107546664056, 0.23158070330898609, 0.1620850066143659, 0.1734173775560433, 0.12499460695131172, 0.13269548364464315, 0.11653938646157903, 0.18288230192997765, 0.10978810639391023, 0.12424644548445941, 0.1409656939006621, 0.10496277136788254, 0.13629218984034755, 0.09754701727820982, 0.16084084918181743, 0.13130157134465634, 0.0665357934250947, 0.05237236754187653, 0.14341757362408025, 0.12149202997886366, 0.14029467748778482, 0.07745656830769393, 0.11140498092337964, 0.11361974877335372, 0.1405528950835428, 0.19882980103213943, 0.1271429396564922, 0.21058232523500922, 0.1606710687760384, 0.13257813429640186, 0.13309303731206926, 0.0452738925964842, 0.10148315405052516, 0.07385852911900129], [0.022844548464842865, 0.010122225897747182, 0.02566760353323433, 0.024480285994227857, 0.040058817999858054, 0.06040489901938747, 0.016402478720391953, 0.02437078713199064, 0.03918556203584998, 0.03578665208131556, 0.0807451845837697, 0.08090859113801872, 0.0580293829402616, 0.027484321673851342, 0.024301021419946226, 0.05013891097698962, 0.03654456967788358, 0.06504836477219098, 0.031125100907839598, 0.027173389568023627, 0.040509354308127396, 0.042796479162549785, 0.03129797822405254, 0.02668516364909949, 0.06659007075452997, 0.10278974764890249, 0.03805666636194914, 0.047966312436807546, 0.027787100688944903, 0.0976542542658506, 0.013772673161339857, 0.04202726176909862, 0.06105839883187606, 0.05718749827675282, 0.015266806041190942, 0.034685565399066094, 0.05079557473260549, 0.031125428410427227, 0.06818378644604838, 0.05828518735905809, 0.0332455346060376, 0.04137233703307087, 0.01417427943388541, 0.08381027172529891, 0.00988084308412527, 0.03864156300081842, 0.027583976306261557, 0.04643600967322146, 0.05980564589281717, 0.05862561001953098, 0.11024735312187865, 0.03649706073525933, 0.14477285977092483, 0.07987857826294438, 0.020742893496888782, 0.04425189683153745, 0.024464186656499104, 0.09466429736705557, 0.06647454469554848, 0.05592289012706569, 0.04525024729270128, 0.08330752652498984, 0.02062221166617688, 0.08860961338805576, 0.15884076215086446, 0.0320602874196465, 0.03396198769370395, 0.0730084473147027, 0.029548128067906347, 0.038974983617663383, 0.007958958308482844, 0.0426257411468654, 0.022541328949192842, 0.004476708521495664, 0.016796567755180503, 0.05483037979912855, 0.06943368953802893, 0.05422968259682098, 0.014721843650594596, 0.04635671957305843, 0.029956475914185567, 0.047073655296117074, 0.055792348744768294, 0.04099289368417475, 0.042097952532311606, 0.042635106571739724, 0.07740288086596035, 0.00704968519951968, 0.029556041756164164, 0.011261155408236289, 0.05410538866154609, 0.04298707417723152, 0.031609789415773366, 0.0823232414381158, 0.03987173166786952, 0.08942536679246733, 0.008745024848218647, 0.06348526195412682, 0.010216749656284529, 0.03730877685630995, 0.026254580100818027, 0.030194143201374722, 0.019956305059754563, 0.02992815938928435, 0.06671095942898143, 0.027175180298546632, 0.018126247413156014, 0.024568725099426605, 0.03526940866703949, 0.029810141629329132, 0.05314914239270072, 0.04652357735340634, 0.07214247684685454, 0.025353888613021663, 0.08704768268451576, 0.048599507088863084, 0.01140458430463989, 0.07021172843392819, 0.04081197819041629, 0.04363325401960362, 0.07625323570063038, 0.05235339537443173, 0.05733866657641146, 0.03711614404774962, 0.01541025217457284, 0.04498620742871877, 0.013123225953970707, 0.02366792444410103, 0.05557954867160129, 0.06333602802647699, 0.13731087227502178, 0.032040277203064293, 0.028952801141947992, 0.010460971783275807, 0.03221422321193161, 0.028591288080919656, 0.06431858941552139, 0.05799084488723067, 0.05218076129113475, 0.04860170576120577, 0.018460658198643117, 0.0221312593203038, 0.05889646040516035, 0.03781565127053088, 0.09948132799998408, 0.017867660179974574, 0.024961324093202432, 0.02115372155282286, 0.017089521692645167, 0.022349048541077686, 0.04854281658246633, 0.014344652600195861, 0.07085135822454769, 0.01569378418817876, 0.034095156757581624, 0.0574239359928235, 0.015071926679792664, 0.022673823855697148, 0.03382824406388306, 0.03986479857215478, 0.041785798516244664, 0.033645064780308355, 0.014327654066765982, 0.04557454380236807, 0.061488093718165354, 0.06474303276908976, 0.006149499808558293, 0.03178403036849153, 0.094286133384993, 0.06540952160233451, 0.01970782827195381, 0.030852536400479656, 0.04646791723526774, 0.014258614223029827, 0.03922390856689984, 0.05344189906252488, 0.0046789490302363715, 0.013341430777443514, 0.06308438346510933, 0.033794773682471246, 0.017971802172401262, 0.08819142897282878, 0.01761972539938025, 0.04155585339533226, 0.02802226861428109, 0.07377104187804846, 0.03922352935337732, 0.059186819219781514, 0.016936091518390085, 0.05681344052596439, 0.012740580357551094, 0.05064170214257414, 0.04400792464073147, 0.01801930153892646, 0.07817623130376301, 0.049116777316216505, 0.022898530850427288, 0.06831623538727723, 0.08324348157452, 0.061646133826504794, 0.07223255346499144, 0.05804321465773448, 0.005420867838115702, 0.016278349494020787, 0.03509877407322488, 0.04259795130741212, 0.029883483056760127, 0.05215731133977252, 0.018140850964212613, 0.0613531741433807, 0.037204067958819295, 0.049110219603584665, 0.045025036595160925, 0.055417923271776214, 0.06014792631650644, 0.07613353446246156, 0.04372356429455742, 0.06426357281123919, 0.008905868838360954, 0.04522534943516216, 0.045965597213756655, 0.0721972521334406, 0.0340179082817368, 0.04670982864955741, 0.09156774699447617, 0.004851258962580394, 0.01532266821501957, 0.023461329683120695, 0.024780075351196914, 0.04022474498337796, 0.07763734973606563, 0.0767796147134035, 0.06563223102280209, 0.03343260944670728, 0.05360446675049682, 0.04137005409105651, 0.04128233319328677, 0.058997633806880445, 0.03247835117602541, 0.09228721846856418, 0.11081065757260208, 0.032420457911587534, 0.05398151224418994, 0.033488104855942155, 0.024501615797259638, 0.04027996843139972, 0.06406990195354147, 0.009260843338955556, 0.054736867276651245, 0.03828620162582205, 0.027552470940375523, 0.037573793482395916, 0.06618480258170636, 0.0040662625519138195, 0.04435027401233393, 0.05154883834503351, 0.03638071496219885, 0.019380992180818034, 0.021678593287604953, 0.08938293318234145, 0.02607938728385395, 0.03255338182732944, 0.09424463440213474, 0.020616598156911713, 0.040801904134212, 0.010737631030591025, 0.0574849127611566, 0.0496894165482973, 0.027766780206753362, 0.021674341499625195, 0.035989833920593226, 0.04965070229504378, 0.045139551418082374, 0.03252717778987942, 0.0059331872222584585, 0.04983420333554668, 0.03297704377121503, 0.029278683453618042, 0.036635523466693784, 0.04911497317915482, 0.1153395472154502, 0.03640141465791291, 0.05317494040355087, 0.09246865873255077, 0.0010850762825406668, 0.08983383721281445, 0.012342285500058245, 0.043090350490303776, 0.10634197477972317, 0.021623637970356692, 0.052598175787997824, 0.03758869006208355, 0.04805791740035338, 0.03751588872663918, 0.014161935842205441, 0.052182017675330566, 0.052447880828572865, 0.020322405072229526, 0.08244042990789299, 0.0328355243489627, 0.033217924797246536, 0.03784440255032913, 0.05449880928462071, 0.04548327591750891, 0.007487954524901486, 0.008908770396374166, 0.027681947460458167, 0.05127694224938751, 0.0513239570653006, 0.008545788361751025, 0.03248333840841248, 0.03153371113923288, 0.025044860235685786, 0.05639738966560653, 0.05008834151310786, 0.033612981018039494, 0.08884995049166103, 0.05951383151113988, 0.023541573562749454, 0.030958476784308592, 0.06238564233025236, 0.005441906527736255, 0.029505298007279638, 0.0247614421776586, 0.08158546812351673, 0.04728378172242834, 0.026405926515919068, 0.05300802133616902, 0.026911253432532953, 0.008953118268700858, 0.08406989892283756, 0.05833044017274534, 0.024392881107726888, 0.020627200813783754, 0.024873651075927962, 0.08223531752704613, 0.018139653951830922, 0.016801853761858037, 0.01727933721286395, 0.022908788767733404, 0.05490691581320378, 0.09501996900766127, 0.014067753950404304, 0.02431299728942254, 0.02127149991030174, 0.05233207131705938, 0.05501443242293693, 0.0400593274483277, 0.027664021003030004, 0.06719829860113322, 0.018830709309587558, 0.024218228382749424, 0.08700689616342706, 0.11318525434621882, 0.16640609490775293, 0.1435460159254651, 0.12837229627034358, 0.12400952513299643, 0.06305496951925658, 0.1277786853813356, 0.12295178753594238, 0.14862775291887023, 0.23537676090434675, 0.138451469941966, 0.1412959697265779, 0.1806004630822328, 0.08584491698251617, 0.1405081708705233, 0.13691108163085677, 0.09470731320400393, 0.1866900959923383, 0.1112176800867723, 0.16442986385476205, 0.14269896782934666, 0.2525568495114004, 0.11708041307546439, 0.14456799253821373, 0.22051850093468545, 0.16713139631094473, 0.13464114778945524, 0.1067741479604475, 0.20260946434592048, 0.08898260627662943, 0.18968752224839505, 0.18324089236557486, 0.15426856555765675, 0.10544892310375169, 0.10959201086793216, 0.12947612171692233, 0.15727192133424744, 0.10153095027612102, 0.17104172358109107, 0.14233290037560847, 0.21202148268780402, 0.08707672507772524, 0.1534540302330448, 0.13611263415265468, 0.18954535165140707, 0.274235820097308, 0.1513054447188493, 0.17209222930813992, 0.20102885641878654, 0.26127750414513773, 0.11111041245561455, 0.4602745421711476, 0.12260176962421787, 0.14878352923739344, 0.2550926465060442, 0.24956706881282792, 0.23378743489663448, 0.09954643781266867, 0.1408306938866454, 0.1911937277163229, 0.1265123267207415, 0.08667419949967055, 0.16036661011317085, 0.3097526675030109, 0.08165405597537756, 0.2019929780714935, 0.22245681063542444, 0.08474483770588714, 0.13113430370726895, 0.18885479999646065, 0.15993783070195108, 0.08790427623617073, 0.0829727154585623, 0.07161483378900636, 0.14990993895597998, 0.15717494992479203, 0.07281948406729968, 0.09713146054456312, 0.12716268940318015, 0.1034382027724097, 0.1038977176311516, 0.19744249241005993, 0.18175708730855297, 0.22960465611709704, 0.13853108179905724, 0.16701939425641493, 0.16339527743477977, 0.15695407145446347, 0.11533874282312971, 0.14229130180132005, 0.12792244178032683, 0.130861132075229, 0.2307225622597241, 0.23778236891713836, 0.23180196482327678, 0.17495509988117605, 0.08116326174668728, 0.22963836398576537, 0.13260468690385743, 0.10022957373650805, 0.1792504016550318, 0.1212166137092056, 0.16363379124912525, 0.28432479969436125, 0.09252815312075038, 0.1519069922787528, 0.18950119434345156, 0.08210462292716389, 0.13881364566904886, 0.08404395152484218, 0.17261782691123026, 0.2272711522997387, 0.06737258360390702, 0.15256270225490295, 0.15826135453197265, 0.15127772765774883, 0.1058530651273266, 0.12222718327276169, 0.141343237351506, 0.21442496097616612, 0.09496792099408566, 0.09362965732091859, 0.10455829226562094, 0.06865100814930855, 0.12373201744330507, 0.1353151672669957, 0.08270308315273255, 0.15338229375981516, 0.17398486484683331, 0.23499356372462166, 0.1363094881056778, 0.1444863582090024, 0.0886028181881674, 0.07790260767984776, 0.10582363969015499, 0.083788346288906, 0.1771217191051091, 0.08111793998508685, 0.1831971793886154, 0.11860482079247314, 0.1100644343081982, 0.10960646694706333, 0.1495139327861609, 0.15337005167478515, 0.0760701866520028, 0.07090887610590266, 0.16904635565175166, 0.1230622880581406, 0.20916972038966997, 0.07088775506183025, 0.15777980698452843, 0.16999831182822106, 0.1751050692532332, 0.12723163731636541, 0.11974274481256163, 0.10945380860639196, 0.06494936322973621, 0.12024984139228061, 0.18105194933952826, 0.1031176639240115, 0.07894663230305718, 0.09688139412431948, 0.11896125852100312, 0.1511027072105677, 0.17671206124847935, 0.08482865538568267, 0.12469339650124313, 0.11563428422255863, 0.1765371020883322, 0.1312578430459384, 0.10192333285005824, 0.12820396377074142, 0.08867458530491398, 0.08740861734916126, 0.10584686747601918], [0.04783565614132151, 0.018403737865869078, 0.058950726243276755, 0.03429812792268011, 0.0714609420467769, 0.04990055804110823, 0.03110207805049516, 0.04750427331835513, 0.03684449693067901, 0.024880534375927625, 0.05188933378385921, 0.02059752256759713, 0.04303539517305551, 0.018088387347938075, 0.04750482873210023, 0.01199020776942733, 0.07382028600982121, 0.06973942756773004, 0.05079800323132546, 0.004033694239032846, 0.012542382877830778, 0.010889654475895148, 0.04984572146748824, 0.015227792056037054, 0.040489619883197936, 0.08026638729197365, 0.05420520608764022, 0.04325841485913243, 0.06014157544761416, 0.058166776979041684, 0.028527143539019653, 0.06481281571811245, 0.013720547581361908, 0.04185357814534538, 0.08422536880619104, 0.00521604752828998, 0.044675830736636155, 0.05370146880346922, 0.06409001942243307, 0.03473215120574159, 0.030154544116568663, 0.03283624830205114, 0.05938417879083465, 0.04221022271761491, 0.039636550335994655, 0.015807877662741852, 0.048150629360949805, 0.011510528518908448, 0.03605199046432972, 0.067655821631272, 0.02285892985040142, 0.09891165735860986, 0.007489014120261757, 0.03660230206385736, 0.019898953802523114, 0.05330444373671086, 0.03669025278800438, 0.02948419420018552, 0.029253096116947073, 0.021479559814437263, 0.05487379783223714, 0.07064891949055657, 0.010157694811031464, 0.043087780265317815, 0.027251850378008622, 0.04806124605238438, 0.028819687619444825, 0.024496802849875345, 0.047397078465550184, 0.07339596523032074, 0.053080926093483166, 0.006519205222326902, 0.04354620727920725, 0.049048174142597184, 0.07119043640071346, 0.0390317928676884, 0.038864188151614326, 0.009492951700644148, 0.04546150752914049, 0.044839919109137795, 0.005687781010619215, 0.059349398399072315, 0.027087490044293866, 0.054993012604574044, 0.06748303816082978, 0.01618554943331307, 0.06345634213498523, 0.013478718521524102, 0.036039484078965844, 0.03118725362113647, 0.03487797604212838, 0.06447266501885268, 0.07906213537940095, 0.034397198413048065, 0.04656955028974241, 0.02455720888270486, 0.022213812955024264, 0.015304103031784538, 0.03393929616938676, 0.03365050783501037, 0.022376227425411347, 0.05896246271027673, 0.09355992033717134, 0.03513680650822578, 0.011028458116455905, 0.044617971946154876, 0.05360712124515445, 0.03368246519277173, 0.03493455546577612, 0.025117738179922588, 0.00779198322092153, 0.053325767794083205, 0.07492387396914345, 0.022375834805350152, 0.11464999913568459, 0.033705723622152885, 0.001983420189654064, 0.04576309336229198, 0.07939569006163268, 0.025086868667013706, 0.012286815946290811, 0.012217164189825136, 0.03080957610490582, 0.018194226225117044, 0.02389738692962114, 0.02031370997428894, 0.030720820988438306, 0.03905183372778758, 0.02742108494614161, 0.029623453663061225, 0.03172742604698626, 0.07426201996784057, 0.08211897175398566, 0.03937784244396514, 0.053861393488102385, 0.1454281100943204, 0.052631251634128635, 0.011842280979298297, 0.05324736252547272, 0.005700785353133876, 0.07088266057713379, 0.018666046371142712, 0.06767716484084245, 0.05622575532705073, 0.01991244078043007, 0.022447757054901412, 0.01920507924120513, 0.018646216185222712, 0.0680016873464469, 0.08362454136893635, 0.006336413291958913, 0.038027727390609445, 0.09318930232116292, 0.03850301983015191, 0.02181037764755949, 0.02335785418718813, 0.0779777685660989, 0.006608224639128293, 0.013271177641957278, 0.06683116628518028, 0.01912215405384139, 0.02061697545521442, 0.0054603788228104674, 0.03049022660801007, 0.046058263209077625, 0.09135390121129253, 0.03787804913196353, 0.006284743055490958, 0.023668047018168915, 0.011715276050381364, 0.03213535062968731, 0.03838625653917271, 0.019531959382396553, 0.06565177392575049, 0.04735673627545757, 0.06892470072113699, 0.06348431583554034, 0.043636142171078154, 0.04108461356090923, 0.01409432858288769, 0.1354475932255868, 0.03318721233236213, 0.034106659567764694, 0.027264404643867767, 0.047767888003539656, 0.05664883121367424, 0.03727966168474767, 0.034763564641076716, 0.02513230725702259, 0.04046567580512455, 0.009575738992181518, 0.03945181972437328, 0.029601028354297725, 0.03798436298365555, 0.0538967254631702, 0.0407525067848544, 0.042375919874757535, 0.002616478741401807, 0.04411464451902336, 0.024679043675742807, 0.028201931554283348, 0.046404443020301486, 0.0672556939084203, 0.00551289702284961, 0.040037034289731134, 0.03658303878300133, 0.045692843099635456, 0.03443920301393636, 0.017986511060547446, 0.038083540726332896, 0.03349091639862426, 0.039387479830052585, 0.00889183123475842, 0.09030124277717645, 0.029002684957137512, 0.03970418057795014, 0.013432470751145195, 0.06309259975809725, 0.03420693281617376, 0.10596548853021477, 0.09920040355815042, 0.02445456650738995, 0.037195579704618266, 0.016154448178807096, 0.05387243664553089, 0.02586894101583429, 0.09046147772741896, 0.06650380159337675, 0.03338935995294202, 0.07612002067147725, 0.018045450035001964, 0.028121295054593397, 0.03993582258361482, 0.022445608178273808, 0.02956714620062661, 0.061063730803829055, 0.03406323770421647, 0.03591113370813189, 0.04636988096359757, 0.038502115846401265, 0.12827716347190643, 0.029608187445950125, 0.035202502378172455, 0.07046772437470575, 0.03381336663639353, 0.04308028792541835, 0.10238906068186607, 0.022881510291969585, 0.012012381226785723, 0.09193443497943302, 0.04491797963818235, 0.05423833172948611, 0.09916234431007218, 0.042985419427315076, 0.08282886712902016, 0.005054960784036666, 0.011106113576510502, 0.041410710377198075, 0.05702666577792937, 0.08818300200566169, 0.06318908470172076, 0.04326534795484716, 0.0583216991095293, 0.033522145972857555, 0.07472476771762294, 0.028927391920719418, 0.0078321214401043, 0.06377618767381196, 0.06832896010769952, 0.03021946240727219, 0.03467389404953968, 0.07755183900195746, 0.031705793639224385, 0.02323946870502926, 0.0634817685931921, 0.053472722610158306, 0.02481828207120059, 0.05054747715832726, 0.1495626253346282, 0.016473041163877617, 0.052445421686335925, 0.027671132214187134, 0.07373992338656418, 0.0402131004469289, 0.07118511208963972, 0.00647054762662118, 0.02978109349046023, 0.04634213325898013, 0.044497194354452436, 0.0371594701503073, 0.032748619334832314, 0.0032579112326681257, 0.02287846317725076, 0.044830967371742574, 0.015967354185939316, 0.022029559233135754, 0.029483927984631834, 0.03948437463071558, 0.08984919727569626, 0.06163822013824698, 0.012735461932606997, 0.06964424880401743, 0.035259200545448455, 0.046600262754626816, 0.04298641917205626, 0.036521487448725014, 0.03699727018453902, 0.07334134316131954, 0.04920641343379694, 0.02239349696244444, 0.03942383453249931, 0.06569793838406764, 0.010500943378335046, 0.03343373942639559, 0.010491018709275993, 0.012994188019224714, 0.070197555807329, 0.034358089624513546, 0.05792136837337768, 0.0907357065607944, 0.046174700912689014, 0.05823305507581081, 0.05883248823304331, 0.0553098933831338, 0.022149785241532712, 0.045906780813370025, 0.05073507676922506, 0.03353829893674101, 0.06309931834919319, 0.06539155684051014, 0.014835241900366402, 0.03584986199594794, 0.054845207430902994, 0.018951075129030694, 0.0339365305919801, 0.06842593151715494, 0.04589597514319805, 0.015599395452638068, 0.051189485651951645, 0.03884637277693518, 0.060955134010122675, 0.045358127794198455, 0.03431349181600156, 0.031204986641363754, 0.02235618656531217, 0.06605056865561394, 0.019017537086901647, 0.03691208120735903, 0.0710264322978835, 0.03956556462893083, 0.05281336222504897, 0.07611280412323053, 0.1480130286466691, 0.21959564077758023, 0.1674094096186661, 0.0860136938131144, 0.21504893959049257, 0.22421501306516511, 0.0733860060873051, 0.3308488596831599, 0.10224711991125539, 0.13149980425594315, 0.18737741475624425, 0.15275528143730857, 0.08950084177476746, 0.2131495931215825, 0.1811259074677383, 0.11883673092891132, 0.1657976525565309, 0.25082210469390115, 0.12797390756708, 0.13219418635051097, 0.09512510691438952, 0.062140865747125885, 0.12858978863204681, 0.12549485470498764, 0.13316610677828714, 0.1445112867100585, 0.2201243793411601, 0.1533737595403387, 0.14856916251442126, 0.20664029724655614, 0.16189192181393025, 0.12371399139444675, 0.10553821831220582, 0.1512863691295347, 0.11827402402676883, 0.07048408035188913, 0.11721756579654834, 0.13644580579092427, 0.11800724922889665, 0.08221540690189408, 0.12371076616428553, 0.21482089053719275, 0.21857415446110312, 0.13344772069925262, 0.18771605626229318, 0.12129094722049853, 0.12697226292784178, 0.0869243578504651, 0.1554255575061806, 0.11195676341172188, 0.11079466931762234, 0.16960291852874143, 0.15801326461857365, 0.19126097491431623, 0.13885783362052134, 0.15747588458320788, 0.218900615169156, 0.1483626711753107, 0.175805855842848, 0.16463241750194182, 0.0952188837372007, 0.15519246759433902, 0.1753833889961243, 0.16177841822706884, 0.2608643376058148, 0.11574206513262565, 0.1415646827268985, 0.13874382441562993, 0.0872020187577413, 0.20443834604755526, 0.14390596999756752, 0.10950015692581093, 0.10938165844568323, 0.1559623553147239, 0.14473365139096014, 0.13806310932963126, 0.16852052822228403, 0.1673985464918998, 0.16015443440166213, 0.09525437659073262, 0.14120356420115118, 0.15988118616082977, 0.18451144918799403, 0.1580865945546858, 0.11846273446515684, 0.13549772601935173, 0.1469848160782168, 0.10718871644067188, 0.14237771651917888, 0.11802550510413225, 0.17476599873794665, 0.22460132056186277, 0.18656605103563878, 0.09653439459901664, 0.15901112478346596, 0.23939958052529445, 0.09247556884562777, 0.0650610052229416, 0.17561764336161076, 0.15662997029721737, 0.13391970746940182, 0.14690469860309555, 0.17066641710698607, 0.13826146481498597, 0.1046067703094694, 0.09608946605435303, 0.21143855106446052, 0.14241574512374017, 0.15913699302942524, 0.08786910513956701, 0.08575749868947653, 0.14971075609566706, 0.17641434415934548, 0.08713197533882434, 0.15200134366750717, 0.14587630217354144, 0.13233401271845066, 0.11830639890244893, 0.16758043108688248, 0.1800685222711294, 0.07084242563935057, 0.10216699477525489, 0.27494754642248154, 0.09317946575221517, 0.08815428903025967, 0.14296939686661767, 0.1608590973961738, 0.1943979670684184, 0.14824784991721954, 0.16725518079774995, 0.19099595445779063, 0.1933263173146594, 0.14556030622653424, 0.1460227781846639, 0.213410415416283, 0.24710902974249857, 0.11289568843259928, 0.12987992666181059, 0.23442701106109928, 0.11463841588626947, 0.1978047141024182, 0.12622128991830733, 0.16535001206061534, 0.20430578219313777, 0.19088464188239268, 0.12359108790875444, 0.1817044417463964, 0.18030410962960414, 0.25203391789428653, 0.17911184699304644, 0.0983095965197971, 0.07636765093212167, 0.24331568409838986, 0.10464416306105354, 0.08867156691849233, 0.11750248921734673, 0.21445453197004335, 0.15998404112554368, 0.09434342910084995, 0.21752822993984147, 0.17215641215443614, 0.1533701129618191, 0.07931497503793047, 0.12916708184826758, 0.19381756353522503, 0.24049048972946985, 0.1067539768654012, 0.15317169618943047, 0.11966466513131896, 0.1544696636377804, 0.1156298409125978, 0.16415883726891012, 0.20384488837613216, 0.1272755724588229, 0.16689052294579246, 0.14155029559568053], [0.06894897804745743, 0.08137118567021624, 0.018210202988777912, 0.004176501167802922, 0.1024755979737928, 0.07473931572730504, 0.06675195279380967, 0.03348147053451788, 0.06922665427649213, 0.032867339980458064, 0.04274331266060472, 0.027050851889315154, 0.03880953926953577, 0.07508009461866272, 0.06426376433322026, 0.010787917041940796, 0.0736974744546798, 0.0426598895160902, 0.03545413161778162, 0.01582359682933818, 0.08302330024420254, 0.05326780558173215, 0.04012451770024435, 0.03323790820075139, 0.031049415251360308, 0.03618735820055008, 0.04164936591780955, 0.014573464868590237, 0.04539557034149767, 0.036893760214649865, 0.04069669344913095, 0.03158147480609196, 0.07208625365409159, 0.028279873339699644, 0.05050863267012662, 0.05885502270933601, 0.041361623293449806, 0.1394377315356847, 0.03810545084096732, 0.05043448685037513, 0.04778190741255399, 0.04889389935640558, 0.012623304745272524, 0.019913699079845703, 0.017269270817538904, 0.0435648117244484, 0.02662206290199632, 0.038223370924712195, 0.019047636681446628, 0.05224369158367476, 0.025460746387139927, 0.059987396422413096, 0.10336404546133934, 0.03219576432339607, 0.0275922347340853, 0.0233710213233867, 0.039574022239614884, 0.09457847253689844, 0.051085324507326856, 0.046005625307800314, 0.01359642122782046, 0.06522228971364037, 0.047761441373656836, 0.01574664904300364, 0.050632156687037605, 0.08965777488605631, 0.05999891838479427, 0.023518497079250314, 0.0039126803570862624, 0.07643372601559086, 0.020932904369528257, 0.013617953086542267, 0.03098939226249293, 0.05608486792733593, 0.040695896717689695, 0.03272151131363165, 0.022284474989940083, 0.16979372038716273, 0.03360802825960902, 0.02995522336042937, 0.017392810156208374, 0.025103839429756327, 0.030733905770185015, 0.02705641751808505, 0.04250060834531342, 0.04453583965979276, 0.028171278461213076, 0.022247164592807813, 0.07288514546328977, 0.0326359163098518, 0.10802367566934518, 0.015673108432712336, 0.008350612141282089, 0.07403050053624377, 0.010670852103841402, 0.07811643048039368, 0.08870317570624814, 0.054825216366518895, 0.06997941993176937, 0.0434643546149375, 0.034557157571637825, 0.018685673543762778, 0.03374278312548995, 0.09155150593048142, 0.08750533594960168, 0.04059966841352083, 0.00346816286647452, 0.018718544461373842, 0.054921391044533065, 0.028499761641386057, 0.026723328234267332, 0.041484802570794864, 0.021277025319455613, 0.046442632503326864, 0.031616716765828674, 0.030960156432082577, 0.048818619726526166, 0.054480710457409584, 0.05421173315675509, 0.0026319676028159, 0.0208486519348357, 0.011139174100882825, 0.015768292942084372, 0.011693400409703535, 0.10635333586364024, 0.018064403050248663, 0.01685645859388094, 0.013495716097344075, 0.04162173695682038, 0.07641319485922014, 0.08974801238265731, 0.12324128450164873, 0.03964763179781937, 0.017617032600326404, 0.012434694855924577, 0.03664844353953677, 0.028132414820814328, 0.010832749464879594, 0.04374093150780086, 0.07853231663184781, 0.014523743847084623, 0.07906772016036896, 0.013093001870138031, 0.09278480023626359, 0.02683645260760621, 0.04572363983419153, 0.03238964585527297, 0.010356757970106219, 0.0240861241810865, 0.04968873473004468, 0.009720368731406429, 0.017041884430293596, 0.041761207093875256, 0.036092194758595965, 0.028964903415931813, 0.16098118116778715, 0.03460974950763968, 0.04180317722080697, 0.018042253533137903, 0.07370391725412301, 0.08831365830114773, 0.03281469824874113, 0.025256407755096594, 0.030601870516435276, 0.03280240636799605, 0.012346851384086956, 0.06568663092630525, 0.03068112039698228, 0.054810438530459527, 0.04187246604311851, 0.019612672490878932, 0.030190266796477863, 0.002437250077491626, 0.035692319844759283, 0.03487893365203373, 0.07002357723972491, 0.057370566477578495, 0.007597709068983434, 0.044600666019945376, 0.01966494075473278, 0.03183732710538372, 0.029804957129301566, 0.023424398499510946, 0.052392772293739745, 0.08799997593967185, 0.013261480884055698, 0.03852193837144202, 0.06467368649018389, 0.022473133717393203, 0.06893862053872117, 0.008005772505120766, 0.02779243840655733, 0.030750725230562593, 0.046155805354036634, 0.0585021932549294, 0.009125703513892669, 0.04818282803640731, 0.039421923143128236, 0.03231524722650647, 0.061207908551178636, 0.02826330860355689, 0.03643623335407146, 0.032543353736400604, 0.03430689196853388, 0.04990091810243265, 0.011370804615228648, 0.0413583827415301, 0.0349096039820823, 0.02884189842358953, 0.08846289222879757, 0.03110266027731761, 0.01772848690199035, 0.05457532997693747, 0.10837483505207686, 0.03436701837927103, 0.06020257519858499, 0.0498887756088328, 0.0242592447302154, 0.06964042602527527, 0.01799603161822644, 0.054520255916060946, 0.03859680048340271, 0.030357402283698324, 0.006679765281132273, 0.022360084037626946, 0.03958550972803947, 0.032392200758500446, 0.0781027251674283, 0.0901741641122968, 0.017406959800169836, 0.07193176436328119, 0.063775337316216, 0.0642949479421781, 0.07508684385327563, 0.025311227091738296, 0.0037542318281221895, 0.0325320232960005, 0.09787535490167719, 0.047202331254318844, 0.051829601908403064, 0.11080651303693173, 0.059444021749039816, 0.044695262556835536, 0.029691386509746797, 0.042137038338208394, 0.03222703986290482, 0.04235864459206501, 0.018245115530707182, 0.036568479282000375, 0.03086314288779132, 0.0450901425774059, 0.037628354264363166, 0.021165142008554072, 0.011065484103446287, 0.041309908528121254, 0.02636376486700629, 0.03208974733077471, 0.01886330443554588, 0.035706661010701815, 0.004568183250094374, 0.01898720192031995, 0.032502843006964655, 0.0046454729031651255, 0.023024604024906314, 0.044821785807970076, 0.02834440858644103, 0.041145866120895075, 0.02604107331154087, 0.013465995716321613, 0.042308657355005705, 0.006909441792466228, 0.048177323694671356, 0.09175225927103912, 0.061276377659411206, 0.030318617167311813, 0.026248231147145553, 0.0664588705366177, 0.030473656126207886, 0.034092820189412565, 0.013088020383410398, 0.040467591024935246, 0.0369096412173202, 0.05613746752421703, 0.04663394764065743, 0.08022930863643847, 0.007236713596108941, 0.06334029513621522, 0.037009960431004726, 0.07859147394136076, 0.01963181511288689, 0.09898786778531729, 0.027345904907692346, 0.012968070166666183, 0.013777208401851598, 0.005318244136193948, 0.059642672178245364, 0.014391168501348266, 0.026176421895563125, 0.03721173266850172, 0.030436020141707796, 0.007385882885090166, 0.03325467786541389, 0.028079368977717338, 0.024825169201639873, 0.036332803823414354, 0.01253777294374642, 0.0364206702778897, 0.026351972858631806, 0.015706833538358972, 0.024577600228029396, 0.007274920794917572, 0.04819574810925031, 0.04225589304922089, 0.021945731977241176, 0.02900480319024815, 0.07547760998169262, 0.03414993204416768, 0.04769702104010409, 0.038825171293630716, 0.08466066762564645, 0.02010535512630257, 0.055759713399193944, 0.032541541938459685, 0.03521891581195016, 0.015113831689250807, 0.06248826746858897, 0.042107980623240435, 0.012728405305214468, 0.023289806427313917, 0.044121600597375826, 0.037593026119734974, 0.09299113069691005, 0.020318825526403326, 0.018762006544538083, 0.047661194938325116, 0.07782629766171018, 0.04379990495621197, 0.03164463684022908, 0.017472161543405345, 0.022228447149597833, 0.03981521353125572, 0.012368204169756463, 0.04100949480949391, 0.04126128492756717, 0.029737840166255355, 0.016443621472365434, 0.025861741704565865, 0.01106290238714146, 0.04930626533384766, 0.023152826076012947, 0.07059415186484976, 0.02258420689031482, 0.20078372360477525, 0.13287986568625898, 0.10730726088607505, 0.1289793596633019, 0.23085742437791443, 0.12998324127927904, 0.18095548354810287, 0.14992346806872278, 0.2163305127572629, 0.14823907054960728, 0.21892546706141966, 0.13447660742507828, 0.06495494801070421, 0.1686767488718033, 0.14938844758416378, 0.0900684822831423, 0.10902156647775443, 0.12813143056607054, 0.10190620312407132, 0.08018586379025253, 0.17632569246474775, 0.1502310370485629, 0.17560302640401548, 0.15721345350386637, 0.09216426135671717, 0.08869226661420639, 0.08477984026314751, 0.1480830797264653, 0.11304135239052196, 0.18185621908595487, 0.14753630745314783, 0.12810716856150858, 0.10726247538602161, 0.15740920429027852, 0.17869198484526527, 0.08909035654317948, 0.11192160763687665, 0.20476679858421126, 0.11692797690029107, 0.18192256230019754, 0.1668188324378383, 0.11231697795371856, 0.1236131665627322, 0.107941351861002, 0.12120503045979047, 0.15741246782483595, 0.16806577843043113, 0.07538150425159162, 0.10974517482663355, 0.1610902567664462, 0.07841161181849819, 0.17782517168070042, 0.2340275115303455, 0.13123649983636795, 0.19086591869352326, 0.1097803152797203, 0.18493060653488483, 0.15076962750284903, 0.32500734732997033, 0.1719186950715319, 0.08038827188072667, 0.2193397061238366, 0.2678056457831014, 0.22785863448535243, 0.17126234158152537, 0.16797184072915586, 0.18159722008051413, 0.13025345581193126, 0.08776943710061812, 0.18649892641171334, 0.15182102189189003, 0.13477058600514166, 0.1072789386155144, 0.07874089939099166, 0.14044386545015922, 0.11093919180453786, 0.135815269463966, 0.3171034956411008, 0.12322684374427605, 0.12408369010494602, 0.09044342103504366, 0.08018893580282889, 0.115238354661532, 0.12335212976341287, 0.24638834018861097, 0.1242865884916917, 0.1349953255586086, 0.11400931980460884, 0.16352614057400536, 0.09967163956213383, 0.14900051598106662, 0.15464122136754377, 0.12695094270090904, 0.1815861884144045, 0.08049557781628064, 0.1299125773291434, 0.2488337081646727, 0.16708443512118634, 0.16411069630374833, 0.11575199363212432, 0.22535631553299967, 0.11192884716776111, 0.06570940672029411, 0.1998875079856765, 0.13486585669940518, 0.16855051290364037, 0.1394767100892721, 0.11349741985360462, 0.09329985646951584, 0.10236996210991375, 0.13567806311672734, 0.15495072088895306, 0.264617187842246, 0.21208574214289266, 0.13778181716559396, 0.1410037837922573, 0.14083086242598875, 0.09400956032256927, 0.11173366328641293, 0.11397833154807169, 0.2150830764683985, 0.12559954828071979, 0.18652679669039865, 0.15332886678797586, 0.2906268841076282, 0.16410436841749376, 0.12370141989160931, 0.1242179163701592, 0.11829703730801422, 0.14701447900264494, 0.17996762849150166, 0.13866669468341336, 0.10963003947249345, 0.054007352389875925, 0.07040570955723524, 0.18532972302167647, 0.09294613069223781, 0.14883675702637242, 0.11952307676115345, 0.19143225685242685, 0.07384100102729375, 0.22634472217290635, 0.09985389187932016, 0.2002696326423076, 0.07106246907384166, 0.1594078970412093, 0.13769580081345575, 0.12595813105543777, 0.07718506674732893, 0.24123950921479734, 0.12145912650251582, 0.23987262449677915, 0.061179038527752125, 0.13911025959157175, 0.07626362385288363, 0.34900060824809537, 0.10705439058402855, 0.16756906234208616, 0.08317720730819049, 0.11445848481549371, 0.17044930778924497, 0.1958620377005108, 0.07973182646016921, 0.16095686553707048, 0.09626571224221299, 0.16921780612920562, 0.23012807803048244, 0.1977589480098217, 0.1604177694647543, 0.09556219071870851, 0.08163642063136063, 0.08774808623016843, 0.11778053316858508, 0.10543175507336856, 0.20187739072547806, 0.12162591916539016], [0.0728522036825457, 0.03527110555179177, 0.047928889041706446, 0.04466895126707612, 0.04409003777489547, 0.053255046387353254, 0.062024102456146674, 0.0322693623902817, 0.05436081003638045, 0.009669926629642086, 0.024936338135552023, 0.06400117237541465, 0.09176411065122775, 0.0533340530349843, 0.054957695951264714, 0.01680885197504634, 0.05809730429562831, 0.02558902014918145, 0.013277093755952535, 0.003601360179844403, 0.021584713042924003, 0.05254364564954754, 0.03520289308301384, 0.03965213256437452, 0.018748314638111382, 0.08659560653951862, 0.07556387914284583, 0.019883226017437635, 0.05606658523902298, 0.0531238499998806, 0.023642317955231956, 0.049972532001594384, 0.024986411557502808, 0.03752957871784607, 0.023951396128282915, 0.01766290403001251, 0.04381058805231606, 0.009877596786546131, 0.020445775871555653, 0.012129778455522273, 0.01605815284194485, 0.047103992377918576, 0.016440650966439038, 0.022525911429716695, 0.07052103643335643, 0.011968425974520224, 0.01091667631220433, 0.020146306356294982, 0.02760326448497513, 0.03716622704579946, 0.03815775549399757, 0.06687258865924613, 0.027177972689030633, 0.06135819968016398, 0.03892661282612432, 0.011843125591234816, 0.017216479698676738, 0.022075440238920913, 0.0364622994956951, 0.010737126370170906, 0.05747530984902575, 0.05167559908342458, 0.014285524976589989, 0.06281454814597964, 0.027985182297866673, 0.02115033927463716, 0.030072515252076333, 0.04216036571550273, 0.008562996611750175, 0.03512819184951725, 0.04738900389882827, 0.053087533601830085, 0.06570598996815182, 0.029957399050134326, 0.0334584572532725, 0.016644072208193042, 0.049274656546091845, 0.031027556847660776, 0.023736537193819403, 0.05687891806085264, 0.026349236009522315, 0.01679830102910919, 0.05636699129677108, 0.024340390678375, 0.013217366668545913, 0.045403499351513964, 0.065486207003555, 0.05517583182682434, 0.0818034507814915, 0.08877778500919381, 0.04235320919824224, 0.04895738889313033, 0.047900976628185286, 0.05346345294627452, 0.03861633189503224, 0.02061945758008909, 0.04220766015350819, 0.08701924550076647, 0.05885088966498452, 0.056958162195740215, 0.012734726488199687, 0.0774153987426431, 0.03337418375116202, 0.028371688977424658, 0.09718211427811654, 0.04253504016707021, 0.03596447641029954, 0.015517545661198036, 0.02127416781149805, 0.021315952162108114, 0.02467996106603213, 0.024012549096838604, 0.036504779071096456, 0.04422925510293534, 0.021021019802578998, 0.020734813184507435, 0.016846114491683342, 0.07828244173358526, 0.011034106099677664, 0.05914147447554335, 0.032442636156995455, 0.027698437503028302, 0.05020943320085926, 0.01735268055551475, 0.050901923058254105, 0.03885712482095246, 0.015843828253808524, 0.06286411020424097, 0.02035041324674122, 0.08965113290375279, 0.06989060735870754, 0.007668461598035309, 0.05142986105995313, 0.016284355623347145, 0.10731248560571864, 0.04665319176931535, 0.027856194158835758, 0.06028671846574834, 0.019308673480765957, 0.06124041749224548, 0.020026900061977007, 0.0754917826082918, 0.03980697425563009, 0.02328066316793763, 0.1154473587690342, 0.09429191734882132, 0.08491814977699712, 0.03178592835132393, 0.04127057374364907, 0.007454670877421216, 0.05064649785298014, 0.027838147042559522, 0.02101042863702582, 0.00714360279098694, 0.049371876934122656, 0.08298903313134948, 0.021260675087931658, 0.03998345410030696, 0.016509240733519677, 0.05179551865665182, 0.05052657061887365, 0.05895032787755613, 0.07228882262302984, 0.011829902913661735, 0.02540145692746005, 0.03001348817751052, 0.05126136768188688, 0.07600807990398138, 0.03874916388022323, 0.031120998507005074, 0.031568102741373644, 0.022655951024423686, 0.029222450684756044, 0.04592745369600673, 0.056873222197135614, 0.0021499323925273793, 0.10068854467282373, 0.024019411329420346, 0.03320346105723612, 0.05374560695922664, 0.0039212021276339775, 0.05295358312826964, 0.04486951691609237, 0.05597140264487075, 0.0903820573923088, 0.032834015155751864, 0.04530182416220346, 0.06614917949322732, 0.08706204683309601, 0.033986816603329875, 0.010868557372070368, 0.07197215251864926, 0.04544941483125572, 0.06005144137288294, 0.07605072035784684, 0.018100899478961385, 0.05016639055083356, 0.0099501108390189, 0.042498398181651874, 0.07530779127151736, 0.032550968650367954, 0.04783317401644684, 0.07277606220375146, 0.027151720771085353, 0.052401727861574585, 0.06494237650786677, 0.0385698456797869, 0.04899724461739102, 0.031211306866739067, 0.024611606870988206, 0.04270841352521412, 0.05241888440063885, 0.04814020290430035, 0.0477458629757166, 0.027296896347956314, 0.0686371113143621, 0.042392517169637066, 0.024878326127485886, 0.03409288913732575, 0.03933309907874754, 0.05532502745007796, 0.027404742375496897, 0.05681540937192979, 0.024695989540627888, 0.02038788835277721, 0.02595773826713764, 0.012899724590111405, 0.017040007514879107, 0.017340616585927147, 0.038838665932416916, 0.013724300454580977, 0.011542649627963622, 0.053364922547893184, 0.05929609400130088, 0.055635994029862273, 0.04105991871667005, 0.010187629696672723, 0.05025608795544794, 0.06808145242112298, 0.03233489355132465, 0.058426626342078375, 0.04705235805182208, 0.037596492667592345, 0.08076449766034081, 0.01150347380673573, 0.007052313359904915, 0.0589136514181812, 0.03695163049645001, 0.08404608124927168, 0.007764966651466826, 0.0339824537326011, 0.041929087601602084, 0.06946338310597405, 0.014728700137516905, 0.02300137432382232, 0.06102745271017475, 0.050986445538939974, 0.03862646340783085, 0.06269004736696521, 0.008445787074555074, 0.03246411343195266, 0.06762180732743395, 0.03143271776817499, 0.003267198372932692, 0.07090010439916965, 0.05138303393558149, 0.041404803839301875, 0.014874606370745648, 0.054111965526376045, 0.04295056625719994, 0.054764829485887484, 0.046841350624397884, 0.017639128491282463, 0.023855016521748998, 0.028593986625632936, 0.030502164173090172, 0.04696991933029025, 0.037396333045175964, 0.0164569130978517, 0.032579888469509544, 0.08181865762678847, 0.029680919833481315, 0.036193092368663325, 0.019429673237966436, 0.02525712787774542, 0.049965836393136176, 0.06400808631893128, 0.03517231085307656, 0.016935386717499747, 0.03156671803745051, 0.022767581526310216, 0.017751335474332015, 0.06340523640955649, 0.038671520869097406, 0.03495798626494023, 0.02965821681784526, 0.03722657562203465, 0.029597946765622305, 0.03771391862462606, 0.06580588783347799, 0.04135850531559798, 0.01570060524353457, 0.04970319080917586, 0.034257674649838483, 0.0376417301595211, 0.004451245674112391, 0.027547173442379124, 0.015292697897811812, 0.046714126402812625, 0.0516978845811419, 0.04910987103357912, 0.028243158575928504, 0.02445617337681113, 0.03276728123666779, 0.01458673255382887, 0.01668801501152977, 0.0173811637045395, 0.09506632498795949, 0.07127171832947962, 0.011028881380034071, 0.09423346484019872, 0.049614033496548096, 0.04872836690816668, 0.09285823742468512, 0.007357966162324433, 0.06012839107443729, 0.030940557987759673, 0.012942298968893387, 0.03626156147689589, 0.044447264573987455, 0.024749064112022042, 0.05130436819707675, 0.030557782156392935, 0.12360136114781904, 0.048562734868497624, 0.02382858457314151, 0.04323779177221079, 0.01973879929151266, 0.04641164424678972, 0.06975683308536969, 0.02185509419969974, 0.036989417783315146, 0.04621341899638215, 0.056374315097327196, 0.048751678963702534, 0.03641163810126243, 0.06323299303110089, 0.024724271591572512, 0.013473278339651805, 0.02550871498251875, 0.01427662495012966, 0.011723990300520053, 0.2022752201845569, 0.25397466375462474, 0.10055426478145585, 0.08779104844096207, 0.1285101844358348, 0.28703883470546815, 0.1493817060104301, 0.12671396872329135, 0.20465553197408878, 0.11249228185343166, 0.12434046745540635, 0.16782315838481152, 0.23256989135857553, 0.16887377136416976, 0.13774605618128855, 0.15540312645175766, 0.13709485080213318, 0.12070390170500164, 0.19113817102005407, 0.1367766944871795, 0.16301724368766432, 0.19821380505398398, 0.15104719647957435, 0.29759194101056746, 0.11588828067385382, 0.17778646891876576, 0.15431241643044258, 0.11008278211398471, 0.19487332462543444, 0.1753004216739247, 0.13456553491132875, 0.13129715867821248, 0.15538282512176424, 0.1110411964116558, 0.1400667663303114, 0.12121725722306198, 0.11056839758830686, 0.11944555632409551, 0.1794326846157351, 0.23025166333442737, 0.20215509759802974, 0.12985692870232368, 0.09439923094525453, 0.11507639601345986, 0.13105536600755108, 0.13287723034379945, 0.10801276657730342, 0.1556775697897519, 0.15025346810298582, 0.14794310014094078, 0.13897876826024827, 0.13649429915653122, 0.106830041735403, 0.21411317851274245, 0.13559126535490637, 0.12375539078587487, 0.2806889464057261, 0.1105717683751737, 0.17412945628166202, 0.10519291950209488, 0.13526776174624122, 0.1365321438999907, 0.14703661894365666, 0.13191218938558333, 0.1441075583739627, 0.11064180413321142, 0.18075492172952623, 0.15974701352177129, 0.095882675940952, 0.10659468420330556, 0.17607695903749238, 0.16512386290536774, 0.1803661167861954, 0.10234148662176826, 0.14016318615646134, 0.09735341153798566, 0.14990174181519017, 0.1082537854991613, 0.15603602232952274, 0.1468156332210187, 0.12222713730748623, 0.11341558634153298, 0.07938390762935724, 0.09058198335790828, 0.16238318335625435, 0.14427974429582396, 0.14779008173894498, 0.1833233693915029, 0.16251508837505696, 0.14657282931429727, 0.14855641481136123, 0.16397811712757235, 0.16884787759232908, 0.15269278398444577, 0.18461130108804474, 0.17885928312616964, 0.14376402922695683, 0.2343825932832495, 0.18357573407551936, 0.1395081043724091, 0.16256414864572788, 0.13617369136021984, 0.12869109609915366, 0.08251982726036541, 0.29767670097850985, 0.13879492248017944, 0.09853884067025878, 0.1066752843138191, 0.10428668345294653, 0.11546985877137031, 0.11950188676916784, 0.09673212189227344, 0.09813358781919365, 0.1566363594705059, 0.08677767499560311, 0.10608249313889012, 0.15595057288244848, 0.20193843261128475, 0.1287747375787266, 0.1315637725976206, 0.13167923736956813, 0.1638017483656445, 0.14071532104524875, 0.1764378783803794, 0.07477190510760393, 0.15095840688915024, 0.09670320973401109, 0.17379841436782192, 0.11019783319845317, 0.22456044211022316, 0.09867969359601698, 0.07911013078785713, 0.10393463540822269, 0.15112461732520213, 0.2501974059569259, 0.10606334094078311, 0.10020566413239126, 0.11930536989483143, 0.15639088957780795, 0.15194210974920183, 0.10809414809749973, 0.21345737660604142, 0.1743883020695179, 0.11188719496731797, 0.2500272578289432, 0.14223638861890764, 0.1798122505386991, 0.1334333795333101, 0.13032151506312434, 0.15099479606555355, 0.17882716872038382, 0.117552759906938, 0.11605918722888155, 0.07502726519540434, 0.09462181013077499, 0.2181053852602359, 0.13417990157200446, 0.16516772909991204, 0.17882842510457964, 0.13205386968629976, 0.2359193043723222, 0.16918840367467175, 0.14396384027936768, 0.21262612524292163, 0.10177384611339339, 0.24998613422916782, 0.09621729548539847, 0.12252732886061554, 0.1665337098341796, 0.09965190513720436, 0.12739718125592317, 0.10846160217038087, 0.10254934925826327, 0.08058412991944822, 0.16756232076835248, 0.13229238350064526], [0.04210796530148195, 0.003999627506052475, 0.029633778613060716, 0.020597049508303888, 0.03953445762876542, 0.08130002376292983, 0.032908858115514444, 0.0697774714940498, 0.05285510635604301, 0.10098023264999352, 0.037778879050165415, 0.09340725433562072, 0.0441746789992096, 0.027032877551391724, 0.020957480470139175, 0.04160661438119508, 0.0308167313661186, 0.012311194779261226, 0.039635811061147726, 0.02128091704611096, 0.03413854031673363, 0.015592286156700745, 0.04668651276358193, 0.03310696845273337, 0.0202896663047854, 0.040175339973141114, 0.02572130629672639, 0.022486346818867232, 0.06302027339716593, 0.01331141832539992, 0.049388960694834116, 0.03443555260497717, 0.07472076107777896, 0.05199555953543994, 0.009279437250487748, 0.03313177054928195, 0.026230695394558773, 0.0032595274387858812, 0.04801075702773468, 0.07554732398280213, 0.053460112802924654, 0.07248573786308689, 0.04170606408508555, 0.06268662678438329, 0.018164697366075653, 0.06175778731102906, 0.05995295693977706, 0.12938429841831808, 0.04887419174455347, 0.08991483568904862, 0.02958274758120458, 0.06450063488896816, 0.025455943015854687, 0.06604453954364985, 0.052306399710716746, 0.06245487369596959, 0.04162012817217939, 0.09199100291176189, 0.03934692313534118, 0.07253507392541056, 0.07476707109280172, 0.10896225595065664, 0.031639414035805294, 0.017707748901880076, 0.05541468271985651, 0.06646567339738531, 0.023813653519497286, 0.021349284647693558, 0.009608148341818203, 0.020471809454442515, 0.06174449185510317, 0.028353636115488988, 0.05027668422929222, 0.048330740462387764, 0.034927178039065296, 0.026335672422822927, 0.06982777282715806, 0.006109701540891923, 0.050171151787282965, 0.029993646500271656, 0.01744685574404655, 0.050785041023646636, 0.024984111378510154, 0.04996834150064857, 0.06004667630599392, 0.03988287441672818, 0.05800925014961151, 0.012152604045226209, 0.01436628309273792, 0.0213843350854492, 0.01339752373525933, 0.046351697866714774, 0.021186310933121753, 0.01634426561424569, 0.004892261903507696, 0.06669993542375104, 0.033952312003220284, 0.0654989700283735, 0.02598392698282917, 0.05560850679513909, 0.018722574083855557, 0.0262559533134223, 0.04701280493229147, 0.036903022217654416, 0.025578308324780197, 0.022394090680585756, 0.01617205862496649, 0.027775009906279947, 0.01854899388197209, 0.048404192972567775, 0.03292092400032186, 0.01808449562128273, 0.03998181850258862, 0.019297048096514998, 0.07805340442686312, 0.018636057859346754, 0.013938001638668922, 0.013095685093092823, 0.08834469252296033, 0.044186553362035946, 0.0052872774258796735, 0.09711223173766367, 0.01910308612540605, 0.030170354256106, 0.012740769006702448, 0.042565319792277394, 0.065732151870766, 0.0150310913205988, 0.04608661229271562, 0.02341581256909957, 0.017119854944007053, 0.0045513187820512445, 0.02269203951131673, 0.01623653833033337, 0.046820746689674356, 0.012252001080571884, 0.0833274218283834, 0.017539458537113764, 0.0344351657305754, 0.02256549710798408, 0.04256289129355743, 0.04161861514852893, 0.07115040064579056, 0.050024729402315234, 0.08329656380679339, 0.03803560660491067, 0.01487646987962146, 0.08085766161281256, 0.03723599084262406, 0.08961543320648133, 0.05514447967852316, 0.0469890064109237, 0.035085290925757545, 0.05893016827382869, 0.047935990676764524, 0.03922700739255355, 0.03690567288187243, 0.0691094734675942, 0.05992749217717398, 0.07406148113190167, 0.05232344133659236, 0.027976851091690125, 0.04008656570447549, 0.10236194883022579, 0.04218609094800007, 0.049616224508011536, 0.053705444799796234, 0.03039440624566088, 0.09054240725573995, 0.0299502169758442, 0.017293504093803706, 0.05159067440657847, 0.007515888484645516, 0.013195284184128528, 0.04734318034963743, 0.02217597204200443, 0.016090313213006142, 0.02472737807810547, 0.012118862660211182, 0.0340998413852386, 0.007232697858970853, 0.07598335824666486, 0.03270935349827332, 0.04756446101612622, 0.031080382440479535, 0.06548878105898058, 0.013373307695972824, 0.07786980379493007, 0.02990485307940793, 0.05115614933592658, 0.058470580636733965, 0.015666270140378226, 0.06096310132453519, 0.07513644038549355, 0.01946344622410834, 0.044921369577247294, 0.045628530018392115, 0.010204011529323556, 0.05478018571832969, 0.04712948395359901, 0.00652972313072232, 0.0356145236160486, 0.05483641657197187, 0.046081157746694745, 0.03450706308226913, 0.011213457816460682, 0.03295521409581265, 0.08194850186907476, 0.03321024476580563, 0.0077411015762106315, 0.0386689966093869, 0.058133785402582544, 0.03848594756075933, 0.029951465699160774, 0.0453088108840729, 0.009611685752808567, 0.03737015199036368, 0.03367402673428578, 0.04214168083102953, 0.05712407002706201, 0.07759263318392538, 0.040396203121711174, 0.034758657847921696, 0.05526500829165021, 0.08450797098057886, 0.010574445684230136, 0.00723701237039941, 0.005158670415591088, 0.012402266354089784, 0.04369376730474253, 0.01725409461575891, 0.03557040078204966, 0.047920760848829826, 0.06858409036912265, 0.06107593075402322, 0.07614278114370762, 0.05054771081514416, 0.031116790769080964, 0.024735636505929214, 0.0010074076553498726, 0.03261084608252972, 0.028645622866949248, 0.027636771255563346, 0.06657291804590533, 0.07053599813051763, 0.030299961011135773, 0.03818968603868158, 0.015343658066534949, 0.013073334477901941, 0.10165900953354375, 0.022519596950000813, 0.06180846785765983, 0.02332600408173617, 0.027474054180446173, 0.07132827860092925, 0.08658701103300818, 0.03812444982148948, 0.016197467846195066, 0.016923288273955547, 0.05694608865005355, 0.03540390306302617, 0.018797595159060532, 0.02369559553992604, 0.09835043666704048, 0.022993843679526643, 0.01686754197092547, 0.02122367495640872, 0.045266273852077224, 0.029035594179144794, 0.029461012379596793, 0.025564518742143147, 0.09279662863381448, 0.030568526539530967, 0.029790150564945037, 0.0948514526469573, 0.11645476438946302, 0.08283640543419508, 0.03944261900840267, 0.04073740719186683, 0.035995273144855615, 0.041229702952888705, 0.007568967844089194, 0.018274797607333432, 0.06021254966335912, 0.03297303330093142, 0.02798440854906315, 0.061963466596939874, 0.017072236833853588, 0.03291433564417305, 0.03195296233189443, 0.06094470755347322, 0.04358511688488145, 0.019047678816282464, 0.03941308248848204, 0.03378371903372388, 0.048548562241898435, 0.04859948410622535, 0.0041744135782092575, 0.014438313552208487, 0.005012944213024551, 0.03221865120013395, 0.024751253208265673, 0.05449578706775943, 0.032189221932522716, 0.04776269009697342, 0.03967016627411208, 0.03742920970844646, 0.02828653255898145, 0.04584748177759109, 0.011663987421460692, 0.07845580743084993, 0.09174330370320428, 0.05120533218066539, 0.024198834866946264, 0.01539828588119558, 0.030657647462982326, 0.0222218013368547, 0.035075707165824796, 0.05111970653336856, 0.05016986859000979, 0.10731479153037073, 0.06913005058924038, 0.05034504225477577, 0.018647127829852606, 0.0885804101163822, 0.0565968138436156, 0.10443379531704611, 0.027311974873525963, 0.021901844715278958, 0.05083794705569745, 0.03477617061787075, 0.019666599335088845, 0.02603129419918743, 0.03436116546752953, 0.0075624642364170045, 0.029620776185765866, 0.021256373504236824, 0.04391137074919478, 0.04649746524650724, 0.04165533757317932, 0.05537911708797178, 0.029805489560408942, 0.002184851637725989, 0.035323651522518165, 0.057955727416781656, 0.039268410614421295, 0.024686357900199872, 0.032029153606403744, 0.060653042558941155, 0.06428113537690332, 0.012019335389918378, 0.035953509861663464, 0.1254086391699891, 0.12660350650548935, 0.07845623644008752, 0.08701071894216923, 0.07557112633460954, 0.14466350838061304, 0.10612573880221575, 0.11505771112898666, 0.1211980207552833, 0.2459433656786719, 0.15866517479861938, 0.2988955468660401, 0.1306436090700088, 0.15354669622836575, 0.14434237964451313, 0.12948977340373302, 0.14173478488960575, 0.15531389253033748, 0.10746815467193242, 0.12604731135070324, 0.15619435738171303, 0.09660553352366533, 0.14590561269752442, 0.1540879373468699, 0.08467241175352566, 0.0934089703725711, 0.12120671585322389, 0.18989409019629802, 0.11930091892399135, 0.03442291981510578, 0.07957105524837971, 0.15906136482954025, 0.1392114751281277, 0.10419175749824894, 0.1633458494419052, 0.15001717594362077, 0.07883070787835507, 0.1764619182194433, 0.10054836590443889, 0.10138088131263372, 0.2562055883989219, 0.1704027602869657, 0.16834676415929872, 0.14758587334184878, 0.2600857471266101, 0.15135246719564163, 0.15270835089106716, 0.4068365080222007, 0.15391478615422405, 0.26758538018311223, 0.17942876224556278, 0.1498362259759057, 0.12602891757964127, 0.11943869217629395, 0.08653376026139145, 0.17325568703874467, 0.11470893427969948, 0.1788772402271148, 0.13619465152582816, 0.19809363650218134, 0.20636813685057626, 0.16307776463368248, 0.12943594806617306, 0.11042386744051211, 0.0982322829264787, 0.27293969125997636, 0.16393305583586618, 0.14973588377958344, 0.09127297934385077, 0.11008586178744033, 0.16064088491182174, 0.07863638967636132, 0.11670781855261135, 0.12301822268073598, 0.16231500153099337, 0.10677598657146578, 0.13127745489679998, 0.12298902706994165, 0.11710762451853483, 0.3318535993176122, 0.06857514246216706, 0.09757665722000022, 0.07484210174410574, 0.21935505852583917, 0.09678037777062386, 0.1382917712532705, 0.12325404752646724, 0.24343983630739877, 0.11361398779216314, 0.11507799713722161, 0.11089563204516327, 0.20993841301289298, 0.0712064782818479, 0.07208748705564968, 0.05240151335695579, 0.16567615101174002, 0.08487301187649851, 0.12657094776870745, 0.2472776456946327, 0.1524659606718248, 0.1559680090436051, 0.16759550769723233, 0.24604573034711424, 0.14776392749721004, 0.1198759828243525, 0.17806509509682658, 0.15629822358248696, 0.1531698422566537, 0.11747240494456022, 0.1794624854359896, 0.16050386242568493, 0.13695275681393762, 0.06678016781206093, 0.08946951643954362, 0.19009043853129112, 0.18142573895954317, 0.10274445653081903, 0.09648092166190186, 0.21826502266189746, 0.11562475408878058, 0.15035086852167884, 0.10671633130480206, 0.12603966579321893, 0.08591008042135546, 0.1324573528742598, 0.17085944062038777, 0.1964592645245214, 0.10503326677867483, 0.12470866463357404, 0.08978340564475906, 0.16893351090050515, 0.0835996741549142, 0.17126860818074596, 0.09118461110178502, 0.1996832842668218, 0.12634968625441675, 0.1374284974149158, 0.13284134678542614, 0.11920851339856464, 0.11798800510023871, 0.23113577476432248, 0.12195724453176222, 0.1583225036700887, 0.14292048981353161, 0.2511943927815845, 0.13289138764864014, 0.12092948395518527, 0.11601442471146585, 0.2806921333314911, 0.2363651062572195, 0.2192492004964621, 0.11711157753222412, 0.11599264483177855, 0.1599641228395124, 0.13803110217615483, 0.19745671100193457, 0.14244418230748948, 0.12750254132814948, 0.21323372489742695, 0.10253094782632205, 0.14405722639733745, 0.09326755054174893, 0.1979133147265642, 0.14892263548268428, 0.08829855104728092, 0.12856656084618262, 0.22751577949571997, 0.22537516129593696, 0.1952321755309259, 0.13361120386229408, 0.11988228772796931, 0.10642209991572366, 0.12944353233662345, 0.11913007365599756, 0.0994762335152876, 0.1499722831912579], [0.02994995267551032, 0.01992712860115834, 0.038427717217634765, 0.02287011090365629, 0.025073567465428385, 0.0630682343316655, 0.04807042761615688, 0.07770888702643496, 0.06063460665304334, 0.02988751076402203, 0.027463541538905234, 0.018242365275059017, 0.036641859013827584, 0.07994727336711462, 0.0450220258696185, 0.04216433022051089, 0.0326999535994424, 0.05961449163395071, 0.035798361735238184, 0.03326097510815148, 0.011069408388838414, 0.04995097428740514, 0.04168814528853663, 0.06321573307016684, 0.03427897189413348, 0.029820349750920173, 0.02860672858303353, 0.029695048410024856, 0.027868175773971507, 0.028442615312674356, 0.04946160115181439, 0.03752008305802461, 0.054867473776422204, 0.0405532741288264, 0.01956696193965693, 0.09889498728537753, 0.04299432136899522, 0.03290533028062313, 0.03995392907170519, 0.037925144387108665, 0.009339989797632781, 0.030000633222141096, 0.04576265286173552, 0.10856837184438783, 0.07506821259495712, 0.058981124612112204, 0.013084721417286465, 0.08221729147818782, 0.020306834335168524, 0.02609857204069774, 0.02327476429092067, 0.03799389694787322, 0.04703589865276891, 0.04705636469166606, 0.004784035704834688, 0.05476969414420667, 0.029156072996556762, 0.05506119826027463, 0.05552434820621725, 0.04448400232039633, 0.020542689824416753, 0.02644210118770359, 0.02940579850767409, 0.012310266855262942, 0.012675064518266629, 0.03836808110316915, 0.04254077050474383, 0.02912435887171136, 0.026334486901760105, 0.032374190031400615, 0.04301233209609505, 0.04220464942796577, 0.014666771504937883, 0.025307266417169766, 0.05392766775443189, 0.026729399481067256, 0.022766147026672, 0.012878206137928271, 0.031558947990678494, 0.02547412036707805, 0.06302152595092213, 0.03540676440142336, 0.036371973898982814, 0.009018354485892962, 0.09916312571975494, 0.02290850914564104, 0.06575858190415368, 0.09176168215250777, 0.06069340773167149, 0.03014671852842214, 0.008087699384158178, 0.0395268848496339, 0.03850912938134805, 0.049077067148661425, 0.08188381340474853, 0.030987080592181415, 0.02191856458422638, 0.013425792379665279, 0.022873885801903183, 0.02809133910153422, 0.021962631876850804, 0.04027625290496696, 0.11524613045396344, 0.025008589802910725, 0.041227450654391325, 0.0112347052650406, 0.0457247085268459, 0.05587220574999529, 0.019071584589959636, 0.03470401279628277, 0.04929707993963554, 0.02935450509070389, 0.042341786827291214, 0.03398595092397544, 0.04852875120817654, 0.028537171629948482, 0.01412565966377095, 0.04056656575431267, 0.07835259240481161, 0.005816228100053606, 0.020235383229690696, 0.016623079483847947, 0.01520804326695901, 0.007454876763550866, 0.04222585474170985, 0.08316183958442942, 0.05744891812003428, 0.009659841082118934, 0.02282217103657463, 0.033587094907078056, 0.08908084939203917, 0.0447447250236667, 0.05842101857847264, 0.027749146777956236, 0.03405158167644855, 0.11066388278718918, 0.04186865858613484, 0.03720531668213587, 0.04768325827054439, 0.06791553309848232, 0.07393855466357163, 0.07322817665314482, 0.04119643175433721, 0.04709077353078512, 0.03928254493662427, 0.05415636415202772, 0.05923130594554448, 0.011092817162974708, 0.02017517254928187, 0.016625329867125522, 0.050715307870339, 0.007345935230278561, 0.01885136304002616, 0.02226523469172178, 0.028169776928881486, 0.0574688593887033, 0.043209718480225534, 0.02053128277522422, 0.06391397241743342, 0.09296507604660527, 0.039885119054346316, 0.014046578322567288, 0.04950549032899642, 0.030121903025334882, 0.04029762292761476, 0.07482012268155813, 0.006923097309716527, 0.08387227888189017, 0.04476344438209649, 0.04676438560108504, 0.07217826847467693, 0.02156422210616931, 0.019375336536717032, 0.03607572769866355, 0.05056284488208833, 0.042005447415454734, 0.04122725913241025, 0.04684361824465375, 0.017622249659090754, 0.07001223913844555, 0.05437518950671919, 0.017360938983338497, 0.03275700416716357, 0.02981884630336877, 0.035394913021234736, 0.015688411996609742, 0.05412208554785579, 0.028210166999469363, 0.03313437907866413, 0.10670673222311082, 0.08679095896021014, 0.01073859821659543, 0.05260735735177033, 0.04582944040697429, 0.04088002211985089, 0.03756210298067139, 0.014475058001886695, 0.04407151376888637, 0.006955080044140379, 0.05891181280716293, 0.01972852030678863, 0.0641931999745148, 0.03343179356306791, 0.025458444292927464, 0.028994051146230874, 0.04657500483576329, 0.04143545501715234, 0.03632668661133897, 0.0223595745891573, 0.028609090049060124, 0.02582337985175752, 0.06462657974371988, 0.01907168992704922, 0.01773417318960832, 0.06930590607225895, 0.06976831674335465, 0.023088652805815783, 0.09237884258430812, 0.04932258683707445, 0.0551260705857027, 0.03592986072744093, 0.10366160167200912, 0.02536512903809067, 0.026130964153356133, 0.01286237397336311, 0.03525669543793605, 0.053818595986212456, 0.028293419689420733, 0.04774548376219408, 0.03486943033133303, 0.04750215125480487, 0.05271054556473129, 0.04827251011926321, 0.04027911041292452, 0.014013022713873897, 0.061916287072123065, 0.04567145392478955, 0.026302240345807328, 0.012225664892954933, 0.027130775927235524, 0.024310940343345848, 0.03071149769839981, 0.03055863825964832, 0.0357276518198271, 0.05386261539834161, 0.020978948168997324, 0.05649309702998689, 0.03419442643080989, 0.05619508882744178, 0.03255519362527036, 0.07143854929675018, 0.01654746277528184, 0.020930175181298007, 0.043301955466308904, 0.01361221029993988, 0.04395836641290977, 0.004373559091735872, 0.05356580229295839, 0.07156185114816313, 0.04684901150364069, 0.03015445984689699, 0.04678563304966496, 0.1391335486644699, 0.030220617284818046, 0.030652750245926362, 0.01869973891805257, 0.06923975437999734, 0.02517335233278573, 0.010910581125156775, 0.035032457672059536, 0.019159313148608612, 0.01914917397493076, 0.022219610325391256, 0.04546723403637448, 0.018689789351135976, 0.06073957602042825, 0.0028770803070191538, 0.05116361869318832, 0.016255859067783724, 0.03653630358918059, 0.011223668810881434, 0.04202404036937703, 0.01850051392290381, 0.042937221005558975, 0.0400015912319143, 0.027811502504553047, 0.026538614859624256, 0.04029212624675805, 0.021832358625326908, 0.04456374441243468, 0.04003410017298114, 0.02928198337735188, 0.030644076215403698, 0.02524965277482425, 0.019746241835697044, 0.02962019395894341, 0.012745224765592046, 0.04096478208779328, 0.03999314894298873, 0.025491284567021558, 0.05649437256638081, 0.03861729333537721, 0.07708351413208632, 0.03572900396501345, 0.04768500112057213, 0.06414661799827892, 0.08529537147091282, 0.0075563058471156954, 0.014561418135980926, 0.04901930411917068, 0.023110474820338914, 0.03432202603547804, 0.023938828455885092, 0.02137274992081427, 0.07214094467100597, 0.05707410960308006, 0.1327973120515385, 0.0763077734999599, 0.051073718275274, 0.03328148328188447, 0.061312104169760025, 0.06104204285469267, 0.07754239313785108, 0.040490738371567386, 0.07378747446402427, 0.03418800278356479, 0.05306034131095775, 0.025691271819654974, 0.019503416861557675, 0.05686676024549431, 0.0684259774824304, 0.03689764428042597, 0.02229809028757436, 0.051296818400582964, 0.045950647007914326, 0.024083672699728803, 0.06518703434736499, 0.0838223682536233, 0.021620039272332386, 0.014719878635068816, 0.0752557892232172, 0.022526621976266467, 0.014551311521039856, 0.04035299193234213, 0.04905959651354821, 0.04866192793293346, 0.016974202477403225, 0.020899050944154302, 0.0364704430103302, 0.04209796402363047, 0.016510929957392718, 0.03934781562777297, 0.181964160874486, 0.0942188938478789, 0.15832041991093468, 0.1656050580523668, 0.10273424457878837, 0.10855897960643615, 0.16365735611367613, 0.1455248823209155, 0.10060711718735196, 0.11944279074668886, 0.18782096434264414, 0.10943693168942006, 0.07775989316043355, 0.23573250149286565, 0.16964537512150504, 0.0996133249493376, 0.1160058981528686, 0.20707951077530462, 0.16146697284233186, 0.15283653272255776, 0.1278221225666423, 0.18246697502270823, 0.17336952770429273, 0.1365452133599789, 0.06905935599558777, 0.13461451857320725, 0.18817797663711733, 0.1021471684197745, 0.054729240871365034, 0.11141690125148143, 0.20564498049357247, 0.11243474098943895, 0.10237723994519442, 0.17017599826137866, 0.1139586124449007, 0.17481706615897918, 0.15002557226727087, 0.14495256867620254, 0.1248197473825947, 0.18178466647382707, 0.15297349392166062, 0.11961669270550052, 0.16762494079528317, 0.17425186181020352, 0.25328415806495375, 0.12479934646117112, 0.091156687196945, 0.21356669735283623, 0.11275057605798207, 0.1581858029408801, 0.19091525475584692, 0.2015645357389604, 0.08559588478097031, 0.1013214941767435, 0.09498779331484149, 0.12216141462446221, 0.13379190868187335, 0.17681462509978205, 0.12049850587162281, 0.1416587123587247, 0.06411683633022251, 0.09704959638897451, 0.17052677460014823, 0.09101618667163196, 0.06582101040910329, 0.13539716931841067, 0.08981814007124594, 0.14096733332882005, 0.11319576507253994, 0.13111938031450396, 0.1244711620552886, 0.1778561369545998, 0.1444305716863563, 0.09155077048607412, 0.11620051512915282, 0.06545950117851458, 0.049869577445450335, 0.1147019935231055, 0.14128279301428026, 0.09465185609916527, 0.12497091951269297, 0.1822156215747518, 0.21951535476311562, 0.13852018802877397, 0.17981551407325655, 0.08413744489512137, 0.15970225866523483, 0.20462966884576506, 0.13035569790630572, 0.08183493699517944, 0.1989913536536117, 0.10007990313874138, 0.11590250692660771, 0.12045394253706741, 0.14468790062012213, 0.19901324844648763, 0.25247901497829345, 0.12303851634985018, 0.14697559237960847, 0.14804105214293928, 0.06532182751764214, 0.14488409573753036, 0.19592058213968433, 0.1334093090507292, 0.09802846523422389, 0.18343149504113584, 0.1134394116759781, 0.17172603928033384, 0.1338368014342362, 0.1558863287491183, 0.1526001333108833, 0.09877327889684709, 0.12834380546043958, 0.11721191206766714, 0.1706273925881232, 0.1734785113724009, 0.07383900153781138, 0.10127489304830951, 0.14028364582167518, 0.2078446334288005, 0.06755520364329701, 0.1429493560065185, 0.13399795568998785, 0.15969338736707167, 0.19385689448925758, 0.1940725788834595, 0.1790626947918246, 0.1638484797290256, 0.16506306616769684, 0.11377223091380251, 0.16912075811095778, 0.1257469512582306, 0.14110896766426104, 0.1519427685848167, 0.15948311155361516, 0.1411890544958653, 0.10533102217220491, 0.15646264137279603, 0.18757894184560547, 0.11133695997658277, 0.2371537324882323, 0.20442071070353832, 0.08568960031674755, 0.10710321336744294, 0.24972676750152345, 0.23561093866104083, 0.18571227668754517, 0.12868671407622675, 0.1367113165437214, 0.11411521613838212, 0.2851888855859157, 0.15127120058863394, 0.08360750357350034, 0.13936896748360128, 0.1826058514416218, 0.1541626922065212, 0.17953504928417746, 0.10437747253285301, 0.21007705960542927, 0.18402741951567514, 0.12512664220506145, 0.15231514860305095, 0.15458923464100208, 0.18681599488181455, 0.12505390981753028, 0.14236496881611888, 0.08402335142055828, 0.12591591961080992, 0.13936132192611694, 0.11301974871105726, 0.202249571560852, 0.12074127147394804, 0.18536608155456283, 0.1511022782013301, 0.12543843232936439, 0.12010014015099696], [0.04636574791924608, 0.00867715328856702, 0.09082194507843064, 0.0672758803252251, 0.02055450481542897, 0.023885525973333467, 0.02684178840999882, 0.07804889982986836, 0.058545251226713585, 0.0677116234756766, 0.026610096608619058, 0.05647805106315402, 0.046995870558725256, 0.03509087187628593, 0.05428376457383556, 0.04920660495577801, 0.03884535004955627, 0.02582242415707198, 0.04031290255126454, 0.006050293337583783, 0.0315529361156927, 0.018225258531709834, 0.024476892224723296, 0.022153203908894813, 0.044255616188409834, 0.04716130724597362, 0.06589211869023501, 0.03416482479341569, 0.027575373138871886, 0.004582721683677407, 0.054182257923868396, 0.08367802962780961, 0.01191139743182688, 0.012691300794211848, 0.006774543763904442, 0.04932247958476505, 0.0598841316006597, 0.06290731756317039, 0.03488059989326904, 0.020519711017127962, 0.0543604614663749, 0.03529598042669316, 0.011806314108863234, 0.0608538763387309, 0.04538268857305089, 0.09930639182247462, 0.04366834084653566, 0.022090543662348104, 0.049131394273811774, 0.020174450511413238, 0.01681879388108369, 0.0073433688357322216, 0.011928544394792089, 0.04181160035753443, 0.03903288837342013, 0.008845064439810812, 0.057984896214498635, 0.0579639513706488, 0.08551634953267152, 0.014076564919143436, 0.05267077411014227, 0.028397239924919222, 0.02273530815728009, 0.07327723692381576, 0.037892087693175966, 0.02923615025206199, 0.010690221679396929, 0.0077262739444361826, 0.0844424934456906, 0.01687839552159271, 0.02335967939166773, 0.023637633327574983, 0.09470749706510576, 0.06029141458472418, 0.028840747376483296, 0.054327060032876275, 0.04335643580904411, 0.10461924988175593, 0.018058854658457062, 0.05787758644850505, 0.03612085027740367, 0.02579685022693969, 0.03538093574705624, 0.0158742677998699, 0.11667903662929613, 0.056127224928669395, 0.015423543800059107, 0.04280096077690682, 0.03727744002976725, 0.02050845527030047, 0.023343451734211658, 0.02137465556452592, 0.02328027629353587, 0.01650053797469985, 0.08188529961532162, 0.02900777944183398, 0.03985615326992927, 0.040189033794787624, 0.03243813156000069, 0.026728845982541962, 0.012106906900542879, 0.0270774198185292, 0.0132064470427952, 0.06124837714577876, 0.04738245767751529, 0.03539096766842469, 0.06743112804308053, 0.012159534268111232, 0.02681276899942708, 0.01570375865295289, 0.050227976359066465, 0.09939957875758411, 0.034398343714494864, 0.021358946931638548, 0.02598297511858325, 0.07559364165870414, 0.05018064744710442, 0.07408580442349758, 0.03887337737626607, 0.017653984851354075, 0.04409518205530701, 0.039250733135568525, 0.06357331610014362, 0.08656781286962571, 0.025682260710445624, 0.031247312999180252, 0.012761370068596256, 0.048941366164194006, 0.03665804262122801, 0.01360696642809818, 0.07483994137615928, 0.01098666323213688, 0.017210816393696496, 0.05509064668008397, 0.010954331448902527, 0.01002380849733468, 0.07499728817492723, 0.00956965625406273, 0.05825840492522525, 0.00957715146679191, 0.024428931290223718, 0.05380527371720922, 0.011834091499387737, 0.027566576534281337, 0.031784373192837646, 0.10861607613943278, 0.054407342216901244, 0.008415916348777471, 0.021752072610862313, 0.06558787453198625, 0.021124091187131502, 0.015733616929801724, 0.04677028064766238, 0.006149440436744162, 0.0668344451414962, 0.05992319059347915, 0.03097380811889326, 0.005781945186637102, 0.03225712413569132, 0.030793448038879904, 0.07916313641133808, 0.06109004209358847, 0.013836778441233741, 0.03230929089289519, 0.06317904894991268, 0.10503523562464023, 0.006523998059903182, 0.044048692009622054, 0.022924629550787713, 0.07526275296244891, 0.052685712824665734, 0.05114139065206532, 0.01083341979181334, 0.03182015715978079, 0.02992053106877833, 0.09300680485584083, 0.021981512113744696, 0.02170087495488265, 0.02628345203946435, 0.019844140211540847, 0.020228762314805103, 0.0405277710618271, 0.06246734560737687, 0.018816046386716828, 0.053146307867380886, 0.0305477176762877, 0.034505182336415016, 0.023130686135001244, 0.05786897562023613, 0.021293961608241645, 0.0592734216291818, 0.01889809823384689, 0.04266471203957354, 0.004666317197974892, 0.029238168893742467, 0.05441969921511989, 0.038277575475794655, 0.0474114004792946, 0.030218263479670694, 0.040199330016489954, 0.09189027767147749, 0.07757619293707033, 0.031755355697485714, 0.01082887593281245, 0.01669320525721677, 0.08571383167779253, 0.059199394553058574, 0.05488461499372798, 0.10043183627027659, 0.03799575088064998, 0.054428673935152834, 0.06572213144071641, 0.04247729628977757, 0.031018304420755278, 0.05383448081932241, 0.022425774161914186, 0.04092021109235864, 0.052594655613985755, 0.02264820587550921, 0.07622901200046463, 0.03001651230959162, 0.07216933588947981, 0.03382394631062785, 0.01054321227955722, 0.06015398224154788, 0.07153001253403003, 0.023910705368184758, 0.010342511607544317, 0.06001293396336898, 0.03145639371547488, 0.0402565376322356, 0.03866128593442902, 0.008963242120620225, 0.014495296129626373, 0.017659286179790096, 0.026894263517592224, 0.03749872835713529, 0.031262847347064845, 0.02952630796860303, 0.06984976721146414, 0.034405786258679245, 0.03945204572031095, 0.02459861401979241, 0.06519484844419264, 0.038966847763907526, 0.0234940109939705, 0.026275252983454737, 0.02205903829646207, 0.08743213624843667, 0.08743873226546472, 0.03307529837794362, 0.04458175130909489, 0.06780237425118685, 0.06308290874585509, 0.024002046031396718, 0.04582887733234994, 0.004467367036868969, 0.053477629403313326, 0.03174866200424731, 0.0429429360214741, 0.0855960763029514, 0.044005155232885194, 0.03143296674675038, 0.02482824312943605, 0.0803674649327032, 0.02624723906328361, 0.05625038122337672, 0.009497031118840942, 0.03643782681695396, 0.04508297199443464, 0.027124704680435603, 0.02787911359431042, 0.034755953557548985, 0.01901990046814805, 0.028326367215824225, 0.026125643672722004, 0.032784253914630225, 0.025150837008691123, 0.055756108955510204, 0.04491586523551134, 0.06430301484802077, 0.02018095651311019, 0.04567315080954183, 0.071542821524124, 0.03094718081786508, 0.04654351479163574, 0.03330346234443207, 0.04843170318992869, 0.006900161594873475, 0.03347380582483546, 0.017802845311140823, 0.040997494042160056, 0.04956872705670615, 0.017538468368471633, 0.0697899280836986, 0.03677780131599115, 0.07231523733465903, 0.041191149578099294, 0.055443522099766045, 0.02459197778314833, 0.0633626074470099, 0.012345011815458778, 0.06453882437199354, 0.0650195522053588, 0.05621283525420774, 0.05298192838146802, 0.010389811791209205, 0.04213219283208732, 0.03293068779091681, 0.08852623237837708, 0.05006858793598029, 0.044211807450459856, 0.07904450003538402, 0.04032668064258272, 0.061817576643079526, 0.04549396667449225, 0.05013281674755197, 0.04393479388747965, 0.01871457804114588, 0.007344105716554389, 0.047542780727869084, 0.07243605706119731, 0.07413209911676184, 0.052872783834895784, 0.04485258254252615, 0.034321348047665054, 0.013166947549419298, 0.04549564440704642, 0.07713784508767628, 0.01084188889381626, 0.05815308315739517, 0.0665790850536958, 0.04777204020008926, 0.008508760459540833, 0.014535600015322768, 0.035130072595371355, 0.04645385186097795, 0.08181544771838574, 0.015439613451880795, 0.053302382960194544, 0.0560265533145397, 0.03770892756179937, 0.022547591717973835, 0.028833400593289447, 0.039156094463842536, 0.02315944316045892, 0.06549158494078344, 0.0737388355417117, 0.031949091672657, 0.06109562304411685, 0.004057632092641847, 0.04895001912729875, 0.1335651772998033, 0.13687407958411402, 0.23455776694801547, 0.1804886602105633, 0.07593291901773022, 0.11328601789089943, 0.17042021176988081, 0.09716052592041031, 0.14778455058413167, 0.19197408019775347, 0.1344015461302573, 0.21756242810478135, 0.0918526933979123, 0.12629576132542666, 0.0769543823515696, 0.15317649189983645, 0.0746271834378281, 0.18273440099531607, 0.11512785413933378, 0.24707270185312918, 0.08513741180180542, 0.13340394643525924, 0.14069958559928403, 0.11920129685031793, 0.19590046467079272, 0.2088386631540714, 0.16494703449068532, 0.11935806908314267, 0.10046406558925107, 0.22791019220265651, 0.12621493904941505, 0.17333712218509567, 0.13546502938674343, 0.17111624861436506, 0.141841500937458, 0.12645116992174618, 0.1888175834450991, 0.09955484179719802, 0.07189873065198622, 0.09938035761156391, 0.2020283253683198, 0.11632966223142802, 0.09965084027498962, 0.18341235816478732, 0.11714069653422603, 0.17917530971669382, 0.13763969253388145, 0.14291275232549638, 0.1440936002519823, 0.19025877869177252, 0.15297082793568412, 0.10268093252013769, 0.12360653224130794, 0.07258665462535235, 0.19818467839110285, 0.1748068465460693, 0.13073298088725538, 0.15814337699163347, 0.19194994842813862, 0.094537410224157, 0.10394725287633558, 0.13612164334664423, 0.10284245449809298, 0.13287522319343784, 0.07374972165111573, 0.11523349766409206, 0.09746019653375111, 0.12645814898273638, 0.18068634153854463, 0.10824172727523312, 0.13358247556513356, 0.11572384756178626, 0.1630984183641211, 0.1370350040134884, 0.10096796758232579, 0.13232080536263605, 0.1978451635448202, 0.2632209159914525, 0.1053974879605155, 0.1857374963020125, 0.12750060312570105, 0.18965726177538597, 0.19760280396909485, 0.13542358403003987, 0.2122118708587462, 0.1659227393928074, 0.14017263968144694, 0.10719260050644798, 0.2132639087616436, 0.1076485913607382, 0.12606606518308963, 0.10066353190209597, 0.16223797905108622, 0.1462330539981204, 0.12612052637362672, 0.15992615552198503, 0.21586250964431994, 0.1381156782829954, 0.12332540861661397, 0.10266518175241449, 0.07768687732037037, 0.15531399978264687, 0.11746926398407068, 0.18230352250318374, 0.16852590615951246, 0.11104379344971911, 0.1134677952335727, 0.14551768109442728, 0.1264300182341568, 0.12459107013719699, 0.11806169509767525, 0.11572680466117398, 0.13478025403474608, 0.16685666185953926, 0.11289008832987278, 0.13935667943329583, 0.12529949462341686, 0.23690752715112703, 0.15125322816593034, 0.0686273743368445, 0.16178650811554926, 0.1810765101183807, 0.1742106922451527, 0.18737366092541527, 0.16592002744155546, 0.13008753648929058, 0.1399358112605349, 0.11029175557796994, 0.18211679623251964, 0.09286248921266488, 0.132653042373638, 0.12359424419100247, 0.09009214673912333, 0.1608009666444794, 0.19362506096161183, 0.13115998297449083, 0.18058720976114276, 0.1575942604892677, 0.18295359407221118, 0.13650035125113305, 0.12510906814807846, 0.13315450820711353, 0.09477736428380014, 0.1791894057345006, 0.09955627438161643, 0.19832193070361692, 0.1737186952584213, 0.11946384284284808, 0.13199068275430512, 0.18840599504690017, 0.10593162744396156, 0.06532725142014605, 0.15516065962372289, 0.09904786779154694, 0.15685170678602112, 0.15914036381629207, 0.0862804686109866, 0.12779164758901443, 0.09385120228774126, 0.10401112928746209, 0.21945503299995778, 0.24120028551307418, 0.07838113684087031, 0.12800255159456886, 0.19371012736472393, 0.18630536663676464, 0.08778588500835242, 0.11020517232076776, 0.15506767187147372, 0.24913433638791888, 0.12415276825307839, 0.20511955142982546, 0.12080197628106802, 0.15995424030528915, 0.09016771365197436, 0.20678629828316553], [0.16074193190903435, 0.05602680229311509, 0.007375715461920106, 0.012095925987758225, 0.026990493736980904, 0.003459348306698244, 0.026205075499151024, 0.03438941879017699, 0.04846484415353306, 0.05867837049487618, 0.03898681201521428, 0.036987521715702555, 0.07063682296223218, 0.0563674432886464, 0.05974780242409437, 0.07990870850100633, 0.006125795132961245, 0.007792163251583735, 0.03881248104716501, 0.012929312820966928, 0.05500083053184133, 0.04935900282655512, 0.026725293249793114, 0.03508212698263026, 0.03634128824717576, 0.040799870170773044, 0.030355228509213177, 0.04276786194813829, 0.01846277068609432, 0.01801075774335092, 0.08475987601184076, 0.03296564821334135, 0.02080518985167146, 0.09400235909608104, 0.04032496077519271, 0.021276582903679342, 0.045004283273292166, 0.03279716249615435, 0.037051271722321553, 0.015336784342634342, 0.035344389522628444, 0.06079116055080968, 0.01816610888307614, 0.03928585443645716, 0.01086615568642775, 0.05122746063035823, 0.00925066586088149, 0.023569150812803738, 0.005358564780063687, 0.07042350577971629, 0.03752416630666103, 0.06364293817070223, 0.03139174930120428, 0.05630190063628459, 0.028177638906204415, 0.01351147548355643, 0.021918715886591424, 0.036356288248733167, 0.08078174996039561, 0.025329672573735158, 0.025263047822180296, 0.06535919728658854, 0.07564211970255261, 0.08637343338059802, 0.02399593456498077, 0.035949951383255185, 0.04050625931291331, 0.04008027995305677, 0.04404648567640013, 0.014684901933275886, 0.013758987958182492, 0.0888421057513164, 0.014147951864757606, 0.003909122596885408, 0.07283717303747132, 0.02735003986726365, 0.017586304813683513, 0.011446288216017909, 0.04530400751278766, 0.07987449501430796, 0.022370104467676535, 0.02343017480246002, 0.10585226073500612, 0.026514410311656616, 0.04118931862796026, 0.04475961777291471, 0.014581675415918713, 0.01895122068573631, 0.07181465250229643, 0.046471908553353244, 0.0051790842647484, 0.058696205021753434, 0.03583842813367805, 0.03106258813321831, 0.01833048453854938, 0.02718311888466199, 0.060351824447993314, 0.06742225674491736, 0.02608778169228425, 0.008133829368518726, 0.07736867504014124, 0.055818326786280646, 0.03560823403419026, 0.01633541921394006, 0.010659659559267664, 0.02808789745153439, 0.06999702463226934, 0.012111378938800866, 0.05464065812468048, 0.036752930271529385, 0.05243255907008725, 0.04001828811822399, 0.03976512670276627, 0.019887780410147483, 0.03810602157647091, 0.020242264614470547, 0.028215908828461846, 0.0556336727834517, 0.027505551885452964, 0.03303819290933109, 0.03577442148760442, 0.07677150184228536, 0.059285219383215716, 0.08181799879117359, 0.030439270269726555, 0.02105330466292799, 0.01949529441434049, 0.04937985573985404, 0.06896671298290454, 0.04410859242442154, 0.02882117191479812, 0.03070895237127139, 0.021399126328047247, 0.11148990943066536, 0.009579401850069483, 0.05633716749387884, 0.020739574420956836, 0.05051554278320363, 0.015545284747326327, 0.015261999797075989, 0.053774997922441656, 0.08106399207345902, 0.028113364129357284, 0.05404404034056971, 0.03647160746397511, 0.01923709788600043, 0.03834342073288657, 0.016927934597216306, 0.02795280359174696, 0.04090904153042263, 0.03157277204727214, 0.029233836666530663, 0.026657839208060218, 0.03915330207335853, 0.05413795122876764, 0.04562618578934381, 0.08928306596053225, 0.04289559944863281, 0.027451693989156235, 0.011143972684118536, 0.05344935309802813, 0.03367046442543788, 0.052131352450458274, 0.027711144986472307, 0.04531733744267014, 0.09481992812887316, 0.007879776418239118, 0.04656524870604758, 0.0052071096762383905, 0.02485932714696373, 0.07512260483758104, 0.06518554813679188, 0.09064327039185072, 0.03329115131148889, 0.006498344648148745, 0.053333715956297614, 0.0485524577989934, 0.021273754124018936, 0.007791394769634692, 0.04228555597364903, 0.024601776047699878, 0.028982257222636577, 0.026674986171025424, 0.024697701747138655, 0.03603656145353471, 0.0672532577488211, 0.0241237620808064, 0.03787324959111791, 0.037105288581862565, 0.093571457621311, 0.0635567379574622, 0.08039997004333042, 0.006877518429856508, 0.07403746427547547, 0.026090053142979745, 0.0037246467094988597, 0.0017474540964617666, 0.019596393122487975, 0.02982662209580022, 0.07048309209846682, 0.03310339082212698, 0.02494550820800566, 0.006739356866737287, 0.023558442818842108, 0.023945016531093467, 0.0878265259727355, 0.046503965502544764, 0.07779792942587407, 0.01136574556209868, 0.04312622255735821, 0.024538502930813742, 0.06170593848031375, 0.01792982438459031, 0.055817235110988545, 0.031715400381794864, 0.08058716362762837, 0.028126898987759507, 0.016660556505103747, 0.030450955025791645, 0.035585393122727835, 0.041295111539863774, 0.007105072877640206, 0.03179121818844109, 0.022835190700847777, 0.033851054331828515, 0.04395230282698909, 0.04339883111477379, 0.014741498593901916, 0.005265739821498433, 0.061243769126914205, 0.01898293864102133, 0.012373688401684407, 0.023903454345981442, 0.04741670563817025, 0.04992539461161341, 0.012678070455759525, 0.017700689401657834, 0.08561713605998986, 0.04598785972883625, 0.04476406108287554, 0.04971989535636479, 0.044564399417609944, 0.0569126297599606, 0.0498456065542996, 0.03922819865927581, 0.04122269707882116, 0.02256919348221873, 0.04813480581487379, 0.04871970628418269, 0.030147624427392602, 0.052776249095557205, 0.05024504479801944, 0.024672049292994123, 0.1193035389446924, 0.01365749950280353, 0.003290536044533515, 0.0052963062508722715, 0.05199018159821149, 0.06498720797319567, 0.05589192485316627, 0.03276111805931695, 0.04411846729776552, 0.017729274057332548, 0.01872296861913656, 0.004917998148518945, 0.09319469558014985, 0.0761597423303512, 0.0037977192879489236, 0.021331729742908673, 0.0288681848154914, 0.05069796747017292, 0.06725240739122515, 0.05813077467704012, 0.05015808615773436, 0.01892060206662263, 0.00804157514545706, 0.04237135399072882, 0.03589288166333591, 0.03740764433337796, 0.04717867445921706, 0.029168954765003537, 0.019743665865051652, 0.029490296090502414, 0.019125494197191253, 0.07779832779159469, 0.016371653257538716, 0.02061626107822503, 0.00468389556420246, 0.026406755806097103, 0.04870932579280869, 0.03623423895107643, 0.039183715763952465, 0.05145117362600662, 0.06613432504837552, 0.05431615860171376, 0.05805969703942538, 0.057418109894159346, 0.06889138355731003, 0.03931774667674496, 0.036868084777867606, 0.04497753148297629, 0.042961839241005724, 0.007059452820554256, 0.055884007334468834, 0.07338329413605314, 0.03459644256039493, 0.08389448777081505, 0.014447149418805157, 0.011152965598739685, 0.09248424096093064, 0.024067483346668944, 0.024390146173837206, 0.015130966203287246, 0.04753200187077446, 0.03076207865360043, 0.06149793028711312, 0.08480995517945097, 0.12363281671799, 0.02318872304092492, 0.05825304230975528, 0.05416490603238345, 0.012571210766421452, 0.020224753759741303, 0.03452627273697046, 0.0048632415353260456, 0.02125699978111492, 0.03299893473365134, 0.026502411459542574, 0.0720922138181425, 0.09160022146158642, 0.0269603175336435, 0.041664886859155474, 0.05541272919564959, 0.024817414476626345, 0.045772497091562524, 0.03306565333097693, 0.02496694717856665, 0.055186258283473795, 0.02522960042340621, 0.045204071343065276, 0.04524003534067062, 0.08286398459946917, 0.03197984818759705, 0.07313449176088457, 0.05058884973667803, 0.044259833502432996, 0.08328810619610934, 0.043602139358558965, 0.0636878194317462, 0.03196531358445364, 0.041217303819834225, 0.08461179121607736, 0.27073798520911124, 0.11145210299160212, 0.15842679888010025, 0.06654933785959598, 0.08646115044792814, 0.18533358410481485, 0.05762291583983649, 0.13092248039620538, 0.15601311630058676, 0.128968603788845, 0.09480449911807814, 0.12413745415547203, 0.1395070471710736, 0.2048705728544343, 0.12090825565880346, 0.20341134389802334, 0.12080778322753408, 0.2284455497659022, 0.14895850371929908, 0.1444129210205809, 0.17637812352228552, 0.14412248176672768, 0.10753052955072735, 0.1643280354478667, 0.20427515399792504, 0.12569634348995265, 0.1129364979363257, 0.11644990739202309, 0.12115082207826838, 0.20472297835494244, 0.24581869252987448, 0.09868124109362403, 0.15112264081835747, 0.17850090719519124, 0.2236496554988046, 0.1046127457952788, 0.11035917897618587, 0.17948191342574937, 0.198268641627604, 0.13740847187657512, 0.20198226816231207, 0.17004112082142986, 0.14255623032729473, 0.14384287499612378, 0.08813008831273164, 0.2653418150880645, 0.08906021098335905, 0.08199516428454269, 0.1285511471571461, 0.24241773712058223, 0.1619242354025764, 0.19997327918967894, 0.1476592339214779, 0.11849351587795443, 0.08794472567857274, 0.061804821279140255, 0.15940588989084767, 0.11928800268158798, 0.16231510878330277, 0.12229389420920804, 0.1438574459884436, 0.14654943298908973, 0.10278004131490186, 0.1299365558811734, 0.20121826399718562, 0.12132024242272302, 0.12674354737804783, 0.1039099214117854, 0.20603730944135498, 0.11200629865690587, 0.1455149844649338, 0.15330658895113777, 0.13864403380261314, 0.1778555240842604, 0.18990342114721576, 0.25206388725388434, 0.1365324503351604, 0.21001606368489806, 0.16797093674540522, 0.12420193577605872, 0.11254711842705166, 0.18193745504944556, 0.1849913266637633, 0.11073597932174323, 0.15516825921593175, 0.1139890721007701, 0.13022524845455924, 0.09822888149609489, 0.15300845817452477, 0.1249275589361787, 0.11213855607615364, 0.21521081396889305, 0.06061430149261029, 0.10887798627898579, 0.09888077635438212, 0.15336357057094574, 0.18435050943686118, 0.182530575642182, 0.08734677873191335, 0.06391077016990993, 0.13846838516333412, 0.12233615927999059, 0.13941795114547978, 0.11407711858590765, 0.10456812117368945, 0.12180673123727884, 0.15969289707080012, 0.10934467938157821, 0.17822102463293463, 0.18193141827660222, 0.12830832792866614, 0.10793678597697329, 0.1714104110555303, 0.11381808893694995, 0.1334835276488335, 0.16849772944565744, 0.17036563566615506, 0.1331060761285405, 0.13307396172275468, 0.116020645345411, 0.09935730602592231, 0.1528888718495446, 0.22897572857477974, 0.11072402835012445, 0.11164198554451428, 0.17198208118638686, 0.23627656181493115, 0.134030805540181, 0.18336484539172343, 0.14525636850345522, 0.12398320235191815, 0.17709764862252822, 0.12413872586142634, 0.20234088924142624, 0.12596304933991165, 0.19600446876739303, 0.07946528148867431, 0.12491317180496071, 0.15769639533133278, 0.08596153088635014, 0.1143257907261291, 0.17882670906762924, 0.12215542381689434, 0.112289100014154, 0.15662816232971608, 0.0831514897365724, 0.0870327286482338, 0.1023993569035684, 0.08169208457993885, 0.1286221635077269, 0.10841408939731699, 0.14554205801217787, 0.15024349363821168, 0.17037233127461326, 0.09815851632024973, 0.25393236037944594, 0.2695925305447271, 0.09945240818084249, 0.15071785528092616, 0.10346735241792857, 0.10595421171596936, 0.14393908031765493, 0.13564334401199896, 0.1484530695503758, 0.16244451635547225, 0.16128058365035444, 0.12721725784602667, 0.12696847845349582, 0.1289406262578503, 0.17930912995530715, 0.2738787618375594, 0.1461680897421414, 0.16822449652658356, 0.1787062340806569, 0.1215950688046794, 0.13770101021134085], [0.04503873041680744, 0.09253275730917532, 0.04848424149977584, 0.04912704289440186, 0.03869363782747138, 0.01999662043676982, 0.037421058532932115, 0.07461407567344366, 0.011670591099367989, 0.060599370438966065, 0.04938284348275873, 0.08238730171034414, 0.009334729646422691, 0.03170135990536261, 0.08371554495346162, 0.06894140909876555, 0.02126625220802042, 0.09817246678135089, 0.01627391192971939, 0.03419536105807751, 0.03902714271398802, 0.012575807293967135, 0.04214604753219793, 0.035130095578009085, 0.023227988877483917, 0.08660293800095398, 0.03325981831538581, 0.004520768632045797, 0.056186887856212356, 0.05078210690689664, 0.005189109004042562, 0.054393035524915305, 0.0567071688091082, 0.06928947348628314, 0.028952458317601876, 0.0112895064070941, 0.015573789921378898, 0.0389219205375881, 0.08365897702113276, 0.026810583733623067, 0.06355687585328856, 0.02249155813197215, 0.02800279465924588, 0.04536438673253983, 0.09812745145492016, 0.05522213035052823, 0.036907254853436065, 0.02401871035896963, 0.05348543200882212, 0.019870779003887888, 0.03136510476319781, 0.04719916348075194, 0.03255730419750175, 0.02330141648980639, 0.05449181873231165, 0.027007125505817034, 0.032592777898835565, 0.03010612735975414, 0.031273354242946354, 0.06065526038348194, 0.04055723863383455, 0.0652368453842017, 0.07814859085145497, 0.03405963326053273, 0.004392465662902161, 0.07243283949191533, 0.022009447509903583, 0.04383007349867014, 0.04952953782893958, 0.07242550036960071, 0.06223000007711592, 0.05466268315250355, 0.051995498248406, 0.03188971794330545, 0.04433405593097691, 0.0634215962171795, 0.05947857614486449, 0.05902484141951127, 0.04893210799162907, 0.037027036530836936, 0.03260641426388775, 0.015838215702153262, 0.00661183387086156, 0.03456234398688521, 0.025201042580808845, 0.05670592391623124, 0.04338415287014458, 0.03134438400006583, 0.02573966367861196, 0.02935094852751542, 0.07141642467749697, 0.07938915533163855, 0.08909216451068079, 0.07636175971598395, 0.0762189839095358, 0.027785882609145298, 0.0770197449732692, 0.0791589842147885, 0.05669630185190228, 0.015295551575329757, 0.01347047637306875, 0.05317256936142522, 0.0347365562113062, 0.016811588824155833, 0.03186283017238302, 0.03177436425410692, 0.03269985783845186, 0.07608614426346556, 0.032730780977515445, 0.03135121750435041, 0.028901622638166435, 0.04364731556345378, 0.030184511560946706, 0.06858253521063636, 0.0227952124025192, 0.09652054372934565, 0.030502093309957175, 0.023776107550328298, 0.050225341016606945, 0.04003008587225791, 0.060852439923872875, 0.039128247167794936, 0.01935896523777516, 0.043843127636899876, 0.02975681424891997, 0.01975544063644784, 0.0043495446293344425, 0.02907864257482992, 0.0572456251980076, 0.03945478448464025, 0.03094571375949008, 0.0021247482096265645, 0.021018143142423323, 0.06495690153491113, 0.03732966041312583, 0.04003225390108363, 0.03114414202319759, 0.03216230926374274, 0.060583451131899516, 0.046759164711881074, 0.024151111419703213, 0.010199256038533585, 0.033766543342461514, 0.03794503202962299, 0.03139702764700257, 0.05495493037385806, 0.055406811166434526, 0.029513769024502368, 0.04756969339664906, 0.052501947483828956, 0.06308546364908257, 0.08729260865478747, 0.030244400484427333, 0.01898002367646944, 0.024197224167085463, 0.03502332207356249, 0.04940795584491665, 0.04390375583522743, 0.03186083834377989, 0.03528673757588671, 0.022826712022745804, 0.04998452127760938, 0.06483260376919663, 0.08920415124345211, 0.004323082516014937, 0.05856144632543287, 0.029284844715749065, 0.015377624489877735, 0.03585155888070022, 0.015796866106440224, 0.019680817926963492, 0.016158493123047294, 0.0390434603867752, 0.0164182907751491, 0.03246546557713901, 0.02027781300937697, 0.03576335534753819, 0.029037402146646095, 0.022560316438396132, 0.02808428917741103, 0.022775797819298123, 0.035986497607682986, 0.027119483791231632, 0.024996104484964764, 0.031207847979760943, 0.006994794042135079, 0.0375454597205164, 0.01784315494249665, 0.021149469764843103, 0.09568690983278137, 0.09328769099327827, 0.0221307939218898, 0.05880564834261614, 0.03598075960913012, 0.013906836224299286, 0.013915464289546495, 0.02000806387513876, 0.03428764783987596, 0.013290922600595702, 0.023598139579858513, 0.045025775870007854, 0.0356495300037486, 0.01991254037186023, 0.02115456424953957, 0.03692289070797063, 0.030683970244060603, 0.02941459511226464, 0.016515020866908373, 0.0628399707737469, 0.03987685679608295, 0.008054164842882705, 0.014853194213262009, 0.011283077014189576, 0.04150976554580754, 0.03606854945481305, 0.018632106760877277, 0.03133994643576443, 0.10246704077167858, 0.031392825654737895, 0.08084737305198947, 0.02592938726827983, 0.025485060102636778, 0.036157024949188196, 0.08658750132927973, 0.04616684851146514, 0.04906505872044833, 0.026187608694477428, 0.07479148631494853, 0.055272021826597, 0.04119650453269001, 0.02517522158732097, 0.008669902266363704, 0.04658230182324206, 0.05844577087930614, 0.0221344098568924, 0.05906218820581994, 0.027685869830630483, 0.08907790761440994, 0.03950449976048643, 0.03894102293998003, 0.02378424914974359, 0.07216480830984731, 0.08476404353014885, 0.049550360098721526, 0.041343976458114, 0.0265861755131834, 0.048897009673378164, 0.040867875795811415, 0.0414709746837616, 0.00837361776164823, 0.05750547456104429, 0.015254878052209896, 0.038458874013515255, 0.033026992703878114, 0.09744057702201028, 0.07106725712336841, 0.035047342760428306, 0.024310214475037593, 0.02982048190108711, 0.023730216968444087, 0.008104605029427238, 0.051927668823590206, 0.016776316220902147, 0.01357688311292159, 0.012910221909893858, 0.057641757772334164, 0.040077430105978445, 0.08923299445380127, 0.10273720933905534, 0.03440321986413291, 0.026766847774025895, 0.021731449523940686, 0.08116303192030999, 0.052940222554870194, 0.02880543838405321, 0.05324833162669694, 0.036380251479004665, 0.035904767517481125, 0.02470029878520197, 0.07501893015878816, 0.04764182440515968, 0.007587038900613064, 0.01759969986103956, 0.17936088685547152, 0.03735622834233988, 0.014977045732760623, 0.029172252773517565, 0.051726969109187206, 0.014614730194631605, 0.07583646088718407, 0.045150353257814725, 0.04232003376068127, 0.01527831363942354, 0.05023425828004557, 0.028004886079279166, 0.038329792028713616, 0.03700899899065976, 0.033665404414698, 0.010064539477048863, 0.02693847445170245, 0.03050797303477603, 0.02204164235492147, 0.07446448934534866, 0.03425614247398992, 0.029153577465143417, 0.036662868975150975, 0.014926117165164362, 0.060733102577468084, 0.02786354094202961, 0.0483719636535933, 0.042400292962068514, 0.01749640631098901, 0.05051631653200715, 0.026074595403887575, 0.035971233305791696, 0.018388006250343977, 0.023981551264202403, 0.01808703711797153, 0.06826804079596074, 0.03401645654512029, 0.027583003374597723, 0.02617717840738835, 0.05659533146348211, 0.10324124156707719, 0.05687413767220513, 0.047595502898818066, 0.03322483107988392, 0.049931753141384934, 0.03083962398851591, 0.02746592790278937, 0.035911880643858064, 0.034792549577691866, 0.024529315621381807, 0.03940960444930581, 0.027501775071986263, 0.017020962569081498, 0.0359881293749617, 0.024888995817051302, 0.06459985859692097, 0.11273294071396513, 0.002848393426487042, 0.03703656666461499, 0.0548305330167134, 0.017063945847293063, 0.023845744942645394, 0.0878924401777406, 0.043896432034671314, 0.01791103416302752, 0.04830573152209963, 0.02244898088036045, 0.01853335036655828, 0.013356245002679288, 0.13245781252701438, 0.2634935513619454, 0.14081155701029685, 0.1251642341395059, 0.12881163237315993, 0.10295643305946743, 0.08535869629873384, 0.11588985881497783, 0.11661735889051231, 0.13206551422274884, 0.2551569978916838, 0.1928070629195821, 0.06529818604429884, 0.18449969739923555, 0.27013580945710985, 0.10076589657053833, 0.10343237284330592, 0.11828250462009061, 0.13342855317938712, 0.16280747349223784, 0.07591665497109776, 0.16444708551129988, 0.10530379540737599, 0.18253865020890392, 0.15983416368403744, 0.12826743415526806, 0.20749063952074898, 0.08151628272307497, 0.08768874505955367, 0.16027864789770496, 0.1305690074279424, 0.1432966543061118, 0.19243241528109198, 0.165288096834575, 0.08328358627735608, 0.08991419217519223, 0.08230333081296376, 0.06881959345792571, 0.12759937484177852, 0.1676603647009019, 0.21508879148431365, 0.1858660152121898, 0.1052681799797762, 0.2501245203518099, 0.13427753181707475, 0.13485255741303967, 0.13279804749594581, 0.12970334339526393, 0.1564519314636146, 0.07437458892743434, 0.12221378439496602, 0.16253876049191723, 0.14994825867395248, 0.13227842537866485, 0.1197156253000421, 0.23313981480896476, 0.15880648737713216, 0.2606914162395462, 0.08376488867666453, 0.15497541956363187, 0.1569196741066633, 0.15908960283042925, 0.10896709762633809, 0.21309146236988807, 0.09973510994666046, 0.1605097766244604, 0.13284562155604362, 0.18329750626317917, 0.08662977406094152, 0.2956161389668142, 0.2055434891653638, 0.15073774292344047, 0.11707426905031167, 0.13943923306801628, 0.14794622577967184, 0.14275765016434655, 0.13060440069004414, 0.14828361090152495, 0.14377360532601036, 0.12188530121479305, 0.25007095548414415, 0.10793968178932706, 0.14561776282085528, 0.08343307301402093, 0.14742320223200708, 0.12928274580307547, 0.19651678240587636, 0.14575309991355867, 0.12782448977832833, 0.08936064002374489, 0.19934756921664362, 0.22581564653063976, 0.22296282703117018, 0.14369128151766716, 0.16575830628073987, 0.10743722770242922, 0.13757538711351736, 0.10628883126041583, 0.15445530715007938, 0.1397214751810797, 0.11383247606816793, 0.12276572776177239, 0.08551263400623876, 0.167738520990937, 0.1549021355927952, 0.09908360579321462, 0.14311280852604297, 0.37500708694419554, 0.07805609339547735, 0.1379264545656981, 0.09420162622606564, 0.1784880675615803, 0.146995801779051, 0.14039623010302746, 0.12403488264329011, 0.24367778321668027, 0.10698367300773821, 0.07837117003697543, 0.17732416549997945, 0.18281520794956915, 0.20175705363433208, 0.12990733728774134, 0.08173731441098837, 0.15379022025773603, 0.18856206247883459, 0.08765449326845907, 0.14500155233808104, 0.20040385124664153, 0.10456193118326126, 0.12885062624850582, 0.09315773183780332, 0.12340436929896956, 0.08505653589963914, 0.13728312457040434, 0.11808761185215366, 0.13482959009706974, 0.16848118194649297, 0.12929458952238485, 0.24187769109923996, 0.10360265120623574, 0.10327123390931277, 0.1671154770038782, 0.13064250590339785, 0.21856707580868276, 0.08047560590409464, 0.17626451268311472, 0.1368811275930174, 0.12913927285661622, 0.12897634127688024, 0.1602745723099478, 0.14415956042226286, 0.2352742736618365, 0.09350414913628372, 0.15413168096734634, 0.133230657346787, 0.15697717666625977, 0.08881394435921985, 0.10306799078300115, 0.19411391698785369, 0.1576276006357324, 0.13523503447011595, 0.16489172294255228, 0.10185639974811386, 0.25416830013836583, 0.10955919166125598, 0.19415352373353897, 0.09333336515532387, 0.11207486352612896, 0.10390710986910329, 0.18308526926463653, 0.09670665712967035, 0.06920722628673238, 0.17932166315374837, 0.18207650000770248, 0.08333045553656356, 0.12191504840889286], [0.05817729153580243, 0.050184650256508784, 0.056586418030483115, 0.051165629673989556, 0.03159713938892369, 0.02864846505314833, 0.026663153943034913, 0.023950421281399268, 0.012600112390974838, 0.06659133479960504, 0.026661104657837463, 0.06138996934638389, 0.053647540044039495, 0.04955621301046303, 0.017825596207272143, 0.044561216322284554, 0.07192945077774987, 0.03777848834532403, 0.02549230729440047, 0.09362727478747407, 0.03208185854037443, 0.04102176370760126, 0.0439210387787992, 0.0462891506181369, 0.08709880373170299, 0.047483807279457974, 0.09750872820375428, 0.02868540198241751, 0.03356597386300564, 0.0319925997210967, 0.027508206380110596, 0.0839699857357529, 0.031426043227134694, 0.05522596079014963, 0.03874534110148107, 0.0722084216953766, 0.057809033070600806, 0.02760362071585992, 0.04457527020525548, 0.05190578935247275, 0.049094193044208714, 0.10460169114653142, 0.041028470807378335, 0.010176612394711664, 0.07442896584829978, 0.0755292596295476, 0.014020914377103892, 0.023676667422536882, 0.05760669775847947, 0.0859409767473417, 0.012526454952275081, 0.12481653747419197, 0.03744918162063245, 0.0392927339060172, 0.03655217310053207, 0.09087322700408199, 0.05429337514684566, 0.01668539307560892, 0.011977496455543706, 0.056315039044186, 0.06318493633561077, 0.04562852618795249, 0.016779729142604817, 0.09185594927159049, 0.04703865656929632, 0.045492066776440035, 0.07924885398918584, 0.022546659005926024, 0.03118541884055782, 0.08215857083879172, 0.05866165445636838, 0.036259577309172, 0.027181318578039928, 0.02595827835912426, 0.06911526509230176, 0.04069757445024387, 0.025328126991347923, 0.029030026635155085, 0.02109619409536883, 0.07516032700697262, 0.03758970512858322, 0.03145554335787892, 0.030173748025610566, 0.04864022083159897, 0.04076631935012918, 0.03984380010215025, 0.06605446804314852, 0.02059187458437537, 0.01883132217992698, 0.09415355420881703, 0.04684660981799807, 0.04088949479703461, 0.05107704309686538, 0.00727049089149542, 0.06616430206885261, 0.03437484013697794, 0.012927300882555786, 0.025840622575713262, 0.03391344453238192, 0.044315474468373486, 0.005996171140953178, 0.06183467189510984, 0.03286958078763658, 0.018203695071861148, 0.040866190402378, 0.014985051351569354, 0.041436960379923546, 0.0022482784510019327, 0.0054745088357688685, 0.03223350564498575, 0.040767319094870365, 0.01913376411633386, 0.03274947352286789, 0.01094437039066707, 0.017557601414380536, 0.07528028871503568, 0.07604583271688993, 0.032517517421154246, 0.003805694023838207, 0.0487418653773925, 0.04865291107806468, 0.05728368444608585, 0.10830842288992099, 0.010416104886380416, 0.02080080016786533, 0.09247799734434775, 0.029567140454967177, 0.004313018035909702, 0.034989269465328224, 0.07621138431732694, 0.02011031937605191, 0.016950762102140055, 0.05721250721704095, 0.05306157088207622, 0.061282062031809366, 0.01186229598393003, 0.024406772197013902, 0.04974751665647473, 0.02620068964578452, 0.06763127617417805, 0.023069653825293628, 0.019507220488101728, 0.021752298606799978, 0.045384182444503235, 0.06572007832507934, 0.021689623038494782, 0.03530398987594151, 0.0482913903561571, 0.026107996837386203, 0.01445854880711845, 0.02832629635269123, 0.06510103331698526, 0.03209205134020698, 0.06028050549268242, 0.021743339208525517, 0.030450273207539034, 0.035697004472416256, 0.03055770937804013, 0.019373869478342035, 0.018573054788453926, 0.05024379224426324, 0.04763024115574457, 0.01959958579391241, 0.1085586118842325, 0.009709700957060823, 0.042254690291179765, 0.15187363681052962, 0.014684075515927568, 0.04389520246355284, 0.045051696454925884, 0.02974108071817506, 0.0353064222051011, 0.04410660059581842, 0.03915919328949625, 0.03653364909452297, 0.047001470661451744, 0.08614695480754299, 0.03281094058747253, 0.030351679606903947, 0.02430614463293985, 0.03391338324534797, 0.040806240191863435, 0.031361408388963154, 0.025243932013249686, 0.03764754859730601, 0.052034756424085754, 0.02980322194015307, 0.04267210478804285, 0.07313785488687216, 0.036206920255696586, 0.030610716916740905, 0.05247527230230551, 0.04840711176755929, 0.022835161972550616, 0.026605276000355522, 0.012337023433628342, 0.018307967299234965, 0.051978858818690625, 0.023443435784429315, 0.041506877394333, 0.008910309275492065, 0.0029138348116013674, 0.06713196304776976, 0.025664045054826046, 0.024131415299169963, 0.04528700802174788, 0.027860470844673055, 0.08364910980866802, 0.009803678877952119, 0.02665743509668016, 0.03921756918932642, 0.04259213286962721, 0.0501065667448265, 0.06094116439682342, 0.08208000852215676, 0.036731809227456974, 0.013563396135014633, 0.018640428390954773, 0.027984768610387564, 0.013996959765321546, 0.0358070261896618, 0.05223010884477727, 0.09579093691201941, 0.05598520754926628, 0.03442233758828333, 0.046581309739380114, 0.04322189927822159, 0.03955906820333293, 0.010985506439371216, 0.0511879190021465, 0.06326283981663085, 0.00919809116185793, 0.08174771022412085, 0.03890478315072195, 0.025316605028966745, 0.07739066176356808, 0.06158495787531138, 0.07586334291244708, 0.06348300582518981, 0.025265384390349352, 0.018389745269932093, 0.01747735944997159, 0.03360991666634237, 0.03572019778432385, 0.010925598363692482, 0.03669386106212774, 0.009126887119735682, 0.05512967885982606, 0.07308928491247278, 0.012368408140666302, 0.051309340107705326, 0.020381700277568835, 0.04276189412320814, 0.06193458125175488, 0.048167816543531035, 0.04368597236011298, 0.016220969508492177, 0.02269906453758238, 0.07599176989207346, 0.07272679508934099, 0.07836324868783837, 0.03982899162257391, 0.035301408159636685, 0.03965070764083536, 0.09606744102652996, 0.07226541863694307, 0.035636456713320754, 0.043341443468365944, 0.046305652152025895, 0.03800511247508469, 0.028960128772943735, 0.006462321278729266, 0.024533157552322073, 0.04859258548446721, 0.061894955353871475, 0.07538967074886446, 0.01187151680970865, 0.06296121950952277, 0.017303825213363575, 0.028009980563975634, 0.061001007355028586, 0.0759604752003666, 0.03622418404707024, 0.003936867668075607, 0.04143948463963405, 0.03197140781389129, 0.039093983885381496, 0.06951741528727355, 0.019789253842205774, 0.05507226440034086, 0.016516288742423058, 0.1326095898665728, 0.03176745797146953, 0.04514717016248934, 0.03811937831943074, 0.05566867534071208, 0.013677262656030156, 0.05887140933003637, 0.07150034960960189, 0.04723273345359391, 0.08826485083949182, 0.05402213405637492, 0.029094213311890924, 0.012969942294031143, 0.04226738819852472, 0.053159890606278376, 0.039529907066495194, 0.05850991925164577, 0.028912135279707374, 0.05987623323416037, 0.023586835952535756, 0.05296158108619913, 0.03144686549691664, 0.03047987676015304, 0.0276864635487718, 0.08224684715030656, 0.035994189130442764, 0.06183354957630077, 0.025660341019712152, 0.004886148521871937, 0.037085259213082256, 0.03994216579162786, 0.010666258449125434, 0.06860983092337847, 0.09910826616349722, 0.03366223281069148, 0.024140905213331985, 0.056919907595241265, 0.05528604123561133, 0.02562005245577424, 0.009910465788937384, 0.024277381861822742, 0.03285864105207786, 0.04637916211880023, 0.02502313015171357, 0.07741781191960459, 0.04623932425954169, 0.06671118925535871, 0.016247054802313927, 0.10321019968438534, 0.03042650149924861, 0.02262591846257208, 0.08022498023966629, 0.01996514762962057, 0.03453487590436013, 0.040052593535473274, 0.033699349770622875, 0.04168385136572104, 0.060488827781932014, 0.04557411479313047, 0.10274612660249395, 0.013837151909096828, 0.1624716205462333, 0.16244453167723072, 0.1091814030622763, 0.138500974543633, 0.15923892868863, 0.10435489592172446, 0.1075791301686437, 0.11441834946914066, 0.15486882608984748, 0.21785064570365414, 0.1311615917591318, 0.18780797149144834, 0.15820598169680566, 0.131474937041921, 0.18180073899847848, 0.1264129268125661, 0.18198210265367262, 0.11966082703081832, 0.08200864743201003, 0.14491668511782924, 0.0875041255306813, 0.1753566372058084, 0.15614800906229406, 0.1477841215748941, 0.19833124633277618, 0.1097192504112759, 0.20143967872906118, 0.15567550135235633, 0.2000584988103759, 0.13176111684691522, 0.11410482798612888, 0.1446450150181209, 0.1883277315045557, 0.09342876608453451, 0.1723977911376184, 0.1414272618750411, 0.09565101095264959, 0.12408253331218036, 0.18065978893108908, 0.27527966085941563, 0.20365482196211818, 0.16372173814283264, 0.16613277005812815, 0.1356363879336465, 0.16042834147810936, 0.13374042757336171, 0.2958917467584533, 0.09694235940133372, 0.09956208132808247, 0.18719620431863493, 0.14026665399151464, 0.21339440417866554, 0.051276961401585615, 0.15671964854963366, 0.11038677346321846, 0.13414466152748755, 0.2178768765541815, 0.15874739135465316, 0.11767911078828959, 0.24908806467729233, 0.1324920566572297, 0.13921383467893447, 0.23033109133041677, 0.14383824782506113, 0.1133214341356389, 0.13571733278372597, 0.12792244178032683, 0.14969307478637467, 0.13413614262976956, 0.14563863105591268, 0.24278942765968464, 0.10150305701479798, 0.12587461981081194, 0.07353161641907308, 0.15814702357015303, 0.14384590870430394, 0.1840088342226321, 0.14725550558538208, 0.08509595878422262, 0.1596873659159868, 0.11193391866981985, 0.14339964716665207, 0.1618023201703064, 0.22514086096517502, 0.1776141757445951, 0.07696765099441813, 0.14757341675219998, 0.12395958386121259, 0.13189824658536142, 0.14081155701029685, 0.1420872772653257, 0.1111074859997438, 0.11113983789278616, 0.07761740846739662, 0.26121584938899167, 0.10325814912756605, 0.0694824357126509, 0.08790980739098403, 0.12317683352457902, 0.14616044418465707, 0.10659020258894852, 0.29126279837181496, 0.11726372259398622, 0.10244577417090055, 0.1226392696281114, 0.12436268400521049, 0.0895384337092119, 0.04917126531983095, 0.11922088571854177, 0.15573321841657162, 0.14916349352607805, 0.154454632992706, 0.1457581714156174, 0.10517548334093825, 0.17159889932842026, 0.205804648538751, 0.11255493252387933, 0.12069935880361066, 0.10295345297744198, 0.09659112340980962, 0.14219760924818056, 0.13053923725120484, 0.1665446495697383, 0.2514583713585331, 0.20141349384380927, 0.20624105818569663, 0.1499335497858063, 0.11916715231153274, 0.14715749229634964, 0.18997465200241537, 0.08351257761880275, 0.18468484552877565, 0.15184783496923987, 0.1293161165930571, 0.06935732589373667, 0.0908628311909495, 0.11925096999132827, 0.09659713720001521, 0.15560301411296093, 0.222832071144254, 0.14794853936520316, 0.13043486543240088, 0.07586871318879627, 0.11431363291077076, 0.18729075489024963, 0.1713412792812432, 0.15542448498308659, 0.24188970335789267, 0.18381774125079955, 0.11689400856172848, 0.13138017196568752, 0.21828369988549143, 0.23203568292721627, 0.14704245653363968, 0.10933465129064937, 0.10608279957405983, 0.08416380598059586, 0.10203201774387591, 0.134074441908348, 0.1532345766862554, 0.1206332913810207, 0.1934796421518249, 0.0933006915053533, 0.23948121485450577, 0.10403646381511804, 0.15694993457967238, 0.2807521946247547, 0.06566999149658988, 0.09483061505541687, 0.11335456743836404, 0.11850409555218874, 0.1287206364495139, 0.1310179809168462, 0.21320412326003277, 0.180537429367823, 0.20617511333717456], [0.029553419820243315, 0.017245935779365323, 0.0094669382275653, 0.05523234613299851, 0.041705887884862965, 0.0248967447964054, 0.01300241101548196, 0.008288928656838834, 0.051195181515668674, 0.09419450160836983, 0.042187879763303265, 0.10003617484002345, 0.04661178088656837, 0.034286854938874324, 0.0233860366467026, 0.05452924595785238, 0.03878073053314321, 0.0351244954752826, 0.06440766245847748, 0.03636485694216625, 0.03167446638878075, 0.02626865313598706, 0.066927831259466, 0.0521389980079426, 0.022156810267798366, 0.0026242590824803037, 0.024147372910632722, 0.024988970291169903, 0.05579851192211913, 0.037587092768761425, 0.04897380615734766, 0.0217268702333733, 0.044616301874479944, 0.020991845259202585, 0.05227783229202033, 0.039510471415856195, 0.12216211176447331, 0.022333016236042304, 0.058888883795589216, 0.013846528825290022, 0.04250715839706602, 0.023024477620398807, 0.047073559535126534, 0.03875174559652805, 0.07080703237724882, 0.0553685603963752, 0.02474755491881121, 0.0679176245185156, 0.050608254743800055, 0.026163480755302216, 0.035128705128426516, 0.01927918484134059, 0.03762181953436906, 0.029898521362713752, 0.033518625798845486, 0.002779693294864809, 0.028867455116743525, 0.1291765660167702, 0.031310576539967334, 0.018858066309363614, 0.014814961637790888, 0.031767572884658174, 0.05123890215350736, 0.02863986188575866, 0.027909414286935524, 0.03338718043279744, 0.025788574562137647, 0.023171321353724888, 0.050367021317323374, 0.07940443112484871, 0.020006598731983575, 0.045836208793785305, 0.047587029966375524, 0.03699166242093329, 0.017643035539696296, 0.07531012017880717, 0.07291851625327142, 0.027605028402420784, 0.049855136688077645, 0.01974502375589744, 0.05649049616148395, 0.0546123473454387, 0.029812188999306773, 0.0495015679588241, 0.044322645051344756, 0.03342432420580618, 0.02499357639481464, 0.04303980017862013, 0.03338682037147303, 0.040675821383633924, 0.032628355022039146, 0.043829966246360735, 0.05300507189766054, 0.031468679850560524, 0.03751112749018977, 0.049943853500148946, 0.048113933749376774, 0.08043795268261626, 0.02380014930461203, 0.06425466320867981, 0.00771219372719286, 0.07066087046217534, 0.017298680932952032, 0.02625753911542556, 0.061622427235687935, 0.02102452273961277, 0.02261551115812073, 0.028751570911657427, 0.04989284736615035, 0.06418794461135423, 0.019257491146544778, 0.03797579812066209, 0.06747617401302823, 0.019662385851505305, 0.07240027309425416, 0.03042391020684473, 0.06131927858317091, 0.046226365882302486, 0.030825058741855527, 0.07380555413903729, 0.02218320965766907, 0.037995229940861464, 0.06702384505901607, 0.014305544769271247, 0.04128001960775545, 0.032046562954483014, 0.05572749174109871, 0.019473537517290924, 0.03600371926422081, 0.02556193128017889, 0.008939749076812258, 0.01747708748875847, 0.0486951531662095, 0.0792840863728235, 0.04856368481752373, 0.027943805889076287, 0.04039241864736523, 0.02528054143993124, 0.06435310167651023, 0.08616437564694113, 0.010927871729607784, 0.035895616597225594, 0.04687259552038966, 0.07916502864851106, 0.008209917221158262, 0.018140278313489213, 0.06158906793702514, 0.029398108900134123, 0.06213355726832825, 0.01612698584194145, 0.03982712619847829, 0.07449221406732837, 0.010162499139926607, 0.06857370987774865, 0.03869138935941362, 0.06320699966783005, 0.03068833311478938, 0.02499083954570515, 0.013240683512131294, 0.0600151211443928, 0.10428872124682512, 0.01728013202908539, 0.015591832249605609, 0.013435754395510643, 0.028669394575239673, 0.01020669858271797, 0.055925893191728866, 0.04527544009409124, 0.025514179104638678, 0.05681613332501823, 0.039729170366040165, 0.0353455999415488, 0.07640932611520253, 0.02912692718147751, 0.0539972898249905, 0.08948703687037192, 0.0485030068234811, 0.01250723476386479, 0.013959948142479747, 0.08097673465888347, 0.049143494632575786, 0.014419331808664627, 0.010111128156554076, 0.026920348811413974, 0.00989395659416914, 0.15890535868463979, 0.01915375709593777, 0.006275333580560983, 0.010318513903316232, 0.03032746356761744, 0.08126431640477912, 0.02215464032375284, 0.04455678067320297, 0.05990889156237245, 0.03081047817343666, 0.03544472788851108, 0.04822736072744574, 0.048630874558922746, 0.011762365559867073, 0.04101850017304382, 0.04547962933898934, 0.02241493784822524, 0.06983097507468156, 0.0656273280600867, 0.02480844550225283, 0.03614488628602797, 0.05074395955870709, 0.05671544638913005, 0.040125938793343884, 0.006958840099433738, 0.05885275891951977, 0.015959786194857332, 0.028740859087256175, 0.008085160760299094, 0.04085106399631308, 0.08259062144544818, 0.055081285085649266, 0.03498079653288569, 0.034883350148917205, 0.02185110479683405, 0.045875784895953634, 0.027252919070662993, 0.05318796006782402, 0.02001745611309044, 0.015075450684244355, 0.003973570222320456, 0.009614371848593076, 0.018840735485296578, 0.06480530039557526, 0.04450594307854772, 0.09977171362768258, 0.04850151678246837, 0.02890466783766545, 0.043669922818099303, 0.039824498516898, 0.037635612947445725, 0.021695537237270225, 0.043231046368037505, 0.0756812438128456, 0.04006982285289034, 0.03483802072643753, 0.010160186512005186, 0.012154621729296784, 0.04153236897001344, 0.022838224409027927, 0.042311009244933244, 0.06092492333282867, 0.07313719605125728, 0.046268906744737784, 0.022659390759203705, 0.02621568773212212, 0.04663410851912153, 0.02990875438216233, 0.05698766807214387, 0.06001231343215031, 0.04550492556224908, 0.040860069359863, 0.05814477493385634, 0.017307316659078482, 0.0464699856726633, 0.023555648513138298, 0.036657678729463974, 0.007662632147736488, 0.05811400501237762, 0.03938207124930717, 0.07087100837980548, 0.04514659176610651, 0.0685875530865404, 0.07028440719530468, 0.050975570920854814, 0.1183089193317198, 0.03725779370494908, 0.041070789504315586, 0.05573304587854974, 0.04018246842127654, 0.08339489119187479, 0.01751383289604658, 0.08401960525060855, 0.02017382806497476, 0.05207831235302072, 0.030118520747149186, 0.017578061707618258, 0.06303644934368711, 0.025755075452428673, 0.009718810700090423, 0.04839368990712589, 0.0360837179957138, 0.017668822059227575, 0.09877584529139342, 0.014312434772540246, 0.05938362720752916, 0.09311685338616373, 0.06457300721517494, 0.06931002762529158, 0.05926219844109109, 0.05609842768359569, 0.0014957563877443694, 0.0023854462544418754, 0.02256890619924713, 0.019948835702492826, 0.021763077463894602, 0.030106336118713505, 0.057003089422059644, 0.018542913059073112, 0.040695329812625726, 0.0740142747940075, 0.020189490732586673, 0.0341278150857937, 0.03511092422770397, 0.027786934064821373, 0.04560279712501553, 0.0036108962986843604, 0.024859892136807886, 0.049676170888086485, 0.04972001026955344, 0.08534656912689248, 0.03852742356097987, 0.03469051815749657, 0.036719938695070245, 0.07156902939201364, 0.030795169821489724, 0.033710841089487076, 0.07826429311065905, 0.04004577152250756, 0.06349447033097667, 0.03255669515760195, 0.024937726669914784, 0.01414315615435161, 0.025361670151112542, 0.04304592888201437, 0.04221284273831595, 0.06322856887333816, 0.04526226721223324, 0.018314793142640305, 0.005248351062032124, 0.04955198037468138, 0.024713130757933664, 0.011364461407215606, 0.018146156123088255, 0.008106792210451057, 0.04411991903438203, 0.04801961300413936, 0.03965237388207067, 0.07957229631081705, 0.07199762494213159, 0.04323943120036875, 0.048175477422773845, 0.03735707869993583, 0.02148840621474289, 0.031786502917267145, 0.0160796741669577, 0.06258789720314165, 0.16558201412760443, 0.15202691568241966, 0.15877360688342204, 0.1038489101694957, 0.25252943888546964, 0.1501323189586401, 0.10635393341222119, 0.13123214845695805, 0.1037683560242576, 0.34322874860898145, 0.128804124711502, 0.17764506440970207, 0.14161149069907206, 0.08613413049569053, 0.13353168393575376, 0.06099907298301978, 0.1528002967637393, 0.11936448889994815, 0.15573639002057815, 0.09632333737587738, 0.13848516248887585, 0.10309317975395149, 0.15857214108109474, 0.23646053016906787, 0.14905948942947775, 0.12981142307962143, 0.14303826817101048, 0.16322693727429838, 0.23784331887239413, 0.09361971349966142, 0.18237251638164445, 0.1235999055807629, 0.18908150073501373, 0.08415116552984522, 0.21684521659006997, 0.13309164303204707, 0.165999838481507, 0.09307652651782959, 0.1574388212494312, 0.11383776207484546, 0.10718124708341015, 0.08948943472557491, 0.09060272901889779, 0.10505242663766108, 0.09103851813462474, 0.0910023587845987, 0.2217743948342339, 0.18238262874224495, 0.12941219934052037, 0.10128525055704579, 0.08157327966464144, 0.14600169544498767, 0.12122981340414095, 0.11251835182549492, 0.13828274673752247, 0.05653835367411376, 0.1271997757195946, 0.2650702522406655, 0.08514954663452604, 0.12628384099732484, 0.1296159634066205, 0.13604241453351515, 0.17823268449114216, 0.1256608966016962, 0.16632360256006642, 0.1692336794709967, 0.1484864863056329, 0.1421751935155161, 0.15789363232831802, 0.12419399144428393, 0.10443668346852066, 0.1248225742470353, 0.16081138544024962, 0.07940413235055824, 0.06851336513195308, 0.1641745114278409, 0.13717090801125573, 0.1981623852325063, 0.12085410090343607, 0.12777820274594331, 0.19810606244831316, 0.14784289584044488, 0.0733409064912027, 0.1588997202775171, 0.10875783304894164, 0.11996360030025245, 0.08689103302575889, 0.13640946257979641, 0.10545403291020664, 0.14740147597847447, 0.14535767597056207, 0.1928402804919789, 0.1466524105278715, 0.13457339497343188, 0.15477098134015838, 0.08226072100261528, 0.16600455758312058, 0.20784576723892845, 0.14113224141540068, 0.16750483353051449, 0.10483956144702052, 0.19201506590170248, 0.13432075449776265, 0.08920324725970145, 0.19302029583242633, 0.07016084487399749, 0.14822270691154465, 0.13415817531847185, 0.11152199319293422, 0.1904597082325528, 0.07334424663455257, 0.10779790189718047, 0.27757179592886283, 0.12432495417493968, 0.21247425597281228, 0.15918288169608963, 0.16106197280028176, 0.1679305945553126, 0.09725681551161314, 0.18708216447022655, 0.10401460732663832, 0.1227598059021177, 0.09824896832146952, 0.13754707250383594, 0.0960182122165157, 0.21453140123236566, 0.14574980573548427, 0.11187563470054059, 0.08731472561316145, 0.17164475735156767, 0.09732774759252226, 0.09049229744461276, 0.13425392098724842, 0.19813218604653113, 0.1909684059360335, 0.1606615846075358, 0.08044705380715671, 0.1269010550552799, 0.18053473273832954, 0.14375145006324017, 0.13272304748815875, 0.09677369748392413, 0.1344096053752207, 0.17943680616876773, 0.18870297669162675, 0.1084324372031035, 0.20762940868735316, 0.16213097188982273, 0.2387829563550411, 0.15186588400073592, 0.26724661610299544, 0.28592558637742077, 0.1325378533933432, 0.14846727282049196, 0.10671359637091238, 0.1709557838377453, 0.1277501179626392, 0.0886228820309043, 0.12379125902248968, 0.1605749400632997, 0.13912100014427017, 0.18244141832955424, 0.07303984925871895, 0.08561458498720201, 0.10924526415164433, 0.1149115492139132, 0.1977072830402082, 0.18156587176265257, 0.1147132320329547, 0.2787660657157821, 0.0970015779978806, 0.22261323046780404, 0.09714121284383921, 0.15134569497839098, 0.09985199964214718, 0.2003086265176535], [0.022681530700215412, 0.029319473805146355, 0.07080549254052101, 0.011138317040017536, 0.06682584197410653, 0.07561754360194169, 0.02188469392187413, 0.0536634516902268, 0.026520797569725304, 0.05299249656438347, 0.015868371795682658, 0.05380344276707019, 0.01457209452881568, 0.008237054928265994, 0.00700039606008138, 0.027576277122622537, 0.037023420595834335, 0.05681874568484003, 0.02567946065908238, 0.027604340838508743, 0.052436439305423736, 0.041644305907069676, 0.011853713883958276, 0.02197382633664435, 0.04559316739980732, 0.052481297583829974, 0.010692964274165852, 0.026134001691975904, 0.03562519522083383, 0.008987665961256192, 0.061832009739572966, 0.04064007955152662, 0.06777530836482203, 0.02939519776602186, 0.021585716618104808, 0.029011205770075325, 0.035216487313230196, 0.028218199431355444, 0.04319677925518444, 0.04120078313374712, 0.055215105324262576, 0.049726127481628815, 0.019224242930631005, 0.046686439985229124, 0.03336942634515224, 0.051107123539212256, 0.015052584874924394, 0.018432188456157045, 0.06889403422152804, 0.02178398974900765, 0.0250866177732185, 0.06454471558813127, 0.06024838725645697, 0.036091248640009475, 0.033526106647426085, 0.0829228890999671, 0.03417562280270842, 0.10900176310491179, 0.07792309287094301, 0.01597759582387704, 0.017735431489023953, 0.01998460243245767, 0.08026277901785028, 0.04612371776132815, 0.026366450005180897, 0.03929998109778089, 0.059787351713185354, 0.07667901970806622, 0.03415611820415624, 0.01519020874008176, 0.057719734031707055, 0.07670222451129267, 0.08467985812814967, 0.03479869743328422, 0.04111382832390167, 0.03289664667400141, 0.029287480058208592, 0.031752281769689535, 0.04423382481740368, 0.09897520435192893, 0.033496780801684625, 0.018844445266069907, 0.015832112854226463, 0.009706178867828943, 0.04802897076813444, 0.008979502336813078, 0.04465939815066034, 0.05640616137233954, 0.025651391197536743, 0.06766316075358661, 0.033944988202664166, 0.002215666566870266, 0.037688327457515464, 0.00462282638651349, 0.02979666614274104, 0.039765988551681085, 0.016347992631997314, 0.021076076626477223, 0.03587334642126676, 0.02600711837951695, 0.037642105542604005, 0.0696707860897145, 0.08184108102033216, 0.029184707447946556, 0.0473496001664429, 0.02714140922762454, 0.059703392307123834, 0.030665689470967462, 0.04572950040681228, 0.04267570923172659, 0.0575328583738977, 0.04565038650687184, 0.015308841285596212, 0.07117298491779836, 0.04069678537968186, 0.07473919315323715, 0.049276131265346086, 0.028784225409429882, 0.05275561451731671, 0.039575129236665466, 0.015382177924977676, 0.01940996371089451, 0.04722549009226984, 0.06719797684420502, 0.03037481929265684, 0.022823825786491076, 0.0295156536007961, 0.04736208356916905, 0.0547295204934574, 0.12087750488952284, 0.014863581407905347, 0.018943510010778424, 0.030110109101740584, 0.04620365137534757, 0.013209961471147837, 0.0441700977934224, 0.03504037519075698, 0.03790199321003691, 0.08390600973319623, 0.009331481433623742, 0.0355012690077626, 0.013525124297537392, 0.0244845531039661, 0.027600192472398765, 0.019313781372001095, 0.06544768810272217, 0.02515472682012666, 0.028447037555217266, 0.01727154992911364, 0.05640501990133236, 0.03527923757510801, 0.07127921833025833, 0.03461088331776761, 0.05465489586875324, 0.058816909835103064, 0.06734810709472626, 0.03940909117039654, 0.05219324852430052, 0.08395127786864197, 0.06473026974427123, 0.07516537552639362, 0.024222981958319584, 0.0782564100659182, 0.023132955670476924, 0.06220262392514175, 0.11067997063359908, 0.01540843558858239, 0.05306371209782459, 0.03917160391386959, 0.06324283726092789, 0.06144981230458906, 0.05116186052140209, 0.018033901259543437, 0.029308737082887563, 0.03654055154672073, 0.018920127092109575, 0.03212995928592019, 0.032993690861809644, 0.019251728250134378, 0.04069201648235321, 0.030759006641024066, 0.03834519039599165, 0.055303147978960514, 0.055943980527621125, 0.04958613640478542, 0.04657073772602505, 0.047275944642962954, 0.008724985903339281, 0.020595390927947817, 0.031185947441225572, 0.0044164753372540645, 0.030866484946360996, 0.037688166579051365, 0.09887798779433775, 0.02252845867206493, 0.054669367269642895, 0.0462033526010571, 0.0689708421968164, 0.040935448581172575, 0.007867515659815963, 0.020472353376868754, 0.08805731762080424, 0.02341272714998453, 0.018298358641444676, 0.012040739886522775, 0.042989357119245876, 0.03583355581447963, 0.03358149097391194, 0.020294544369643255, 0.007734655903937716, 0.07252430272919518, 0.09310094173997642, 0.00734133535109821, 0.012061576520453298, 0.022820608217209097, 0.08579574945953586, 0.10787568280413266, 0.028811948216189782, 0.03302454888339966, 0.08941462623976892, 0.06122126529413847, 0.05248515483652873, 0.038411330596934405, 0.08879000411158608, 0.025381276256314693, 0.09389026511100032, 0.006425789897254999, 0.06996355425085753, 0.05782937653543008, 0.018912814782872316, 0.02307638582292824, 0.03515284838936022, 0.04440042595829695, 0.03028846203139232, 0.07627945122939926, 0.028103876130415067, 0.060827415661826256, 0.012942345891778749, 0.023441231366427197, 0.039038457832629644, 0.02655222058115948, 0.03659074179707997, 0.0675447158996136, 0.02220694306156328, 0.04665049897026151, 0.05672723265184511, 0.035340218173880736, 0.015784576140914955, 0.0026404553782119746, 0.04142182248253976, 0.02260813373140991, 0.059112589130358356, 0.0738134831490536, 0.03865279384978837, 0.10206483695055209, 0.05424488178123871, 0.03535017731689638, 0.01706650841139978, 0.049942700537822904, 0.018133326065576365, 0.04746370130188523, 0.01927855090358325, 0.04553320186753427, 0.04306411580933679, 0.0968010391619417, 0.0019479626479874095, 0.05632990881079628, 0.05285729736750645, 0.1003822473989379, 0.012422616522188389, 0.00424240579670896, 0.0755453857803537, 0.013637632927707127, 0.01351840379122164, 0.02183652039797556, 0.016948322112101222, 0.03538021945484704, 0.07167838078232543, 0.10558278930764045, 0.01461223083277864, 0.09747887375734507, 0.07543314623856738, 0.039453133565163424, 0.04706251254725841, 0.045305857615124796, 0.05687547066519338, 0.007877826724471826, 0.0667893608671523, 0.04221654294299022, 0.04923601890163076, 0.0961596014038209, 0.06375512025589425, 0.0734068743223625, 0.021703765021576997, 0.04170294993767335, 0.01680412904299315, 0.050705793058319445, 0.01005091364570563, 0.011934414543511887, 0.03259449393578595, 0.07066624839940379, 0.07226813058819502, 0.026474144730356433, 0.04941988766433732, 0.014652687936059892, 0.02762219643280391, 0.01145053713116795, 0.007250446200956621, 0.046281194795043244, 0.06442394948774768, 0.02478613127623835, 0.041344010932070595, 0.039331555411580114, 0.053385085982060244, 0.06180814227029201, 0.03467357995349073, 0.03242061495961201, 0.017758414126752366, 0.06187467700651577, 0.007562742422094509, 0.009103931295084617, 0.03570117965160358, 0.007891560286929411, 0.040543763147246455, 0.015372665028177924, 0.03379609518414063, 0.10087365449796762, 0.07846153776852355, 0.02209384550130175, 0.018930566955297705, 0.019128179335365855, 0.03662726120843041, 0.042757887483364156, 0.03163170527606722, 0.0540859530109071, 0.05474976436685651, 0.02946397905508357, 0.04740010068241147, 0.026195620058945594, 0.021663639251323, 0.06648697064168031, 0.11233208520758538, 0.021114490190220457, 0.08892685805837955, 0.019030625699087977, 0.03546856088383544, 0.010377419361424063, 0.04665332200426248, 0.0819717756202144, 0.014567420434867664, 0.05233223985640272, 0.03783984815761928, 0.12289633809198296, 0.1261443593689511, 0.08216773325036611, 0.09463948377918813, 0.1095109970699395, 0.21542312757622814, 0.1561041888330252, 0.09556182299650486, 0.14343756851890396, 0.17452773007173694, 0.13962598998219738, 0.15215610874997032, 0.1368994524161662, 0.11786422827431273, 0.14414099045097828, 0.0907990467103739, 0.0999509935237227, 0.21928750489267612, 0.07037400883892853, 0.13184212298402864, 0.11634344415318583, 0.16631675373402335, 0.15158834566752757, 0.10065754875540735, 0.1726874336600304, 0.21285631934240942, 0.07620511771810633, 0.19671621041432505, 0.1323957287616307, 0.13602821126339898, 0.13929724633213014, 0.20661121654895045, 0.11939800524663542, 0.12355989280847773, 0.19023288491993182, 0.21958015047975127, 0.10867177839240721, 0.17624532984149072, 0.1596003996148225, 0.17237295456711324, 0.21154053268894074, 0.16485545634021684, 0.18977464176714423, 0.2072965128407363, 0.16425873513423628, 0.15616673225116345, 0.10337861645365916, 0.1392887733996876, 0.13081918110049542, 0.13052472754591896, 0.17513255648795636, 0.24356728269448205, 0.08004222996532917, 0.11731491258908665, 0.18748442191750775, 0.11675435839401138, 0.13890752208329019, 0.2124126012166662, 0.18601371696399105, 0.08404347655032912, 0.1178988554484902, 0.08609558861221998, 0.11119007027798122, 0.16137576241406704, 0.17841783262068228, 0.12540270198857592, 0.16414133982071955, 0.1340014184074056, 0.23580616850766445, 0.12830551638598406, 0.1759609733257563, 0.15783490402804268, 0.18360760333316942, 0.11795755310524857, 0.14814021456385815, 0.16077839769423008, 0.1430844632728446, 0.10140634607523681, 0.15990113509037804, 0.16601166687905788, 0.16950994609825074, 0.0888277339418569, 0.15254917314216015, 0.12349711190308295, 0.12405865435158053, 0.06048063064114221, 0.18306694444148772, 0.08900949596277169, 0.16304290763312773, 0.13345640813631396, 0.190019253641367, 0.14111832925869575, 0.2013401945512141, 0.12777032736208171, 0.09881832486679477, 0.11808889887986646, 0.1237075026297281, 0.07329408319727068, 0.1591031779084475, 0.17684339936221802, 0.12967210232971177, 0.12572345534159293, 0.1824178074997279, 0.06896894229876419, 0.15447669632492528, 0.14967775302788905, 0.12198931297227261, 0.13193760818291095, 0.1009068873921229, 0.17020080418836686, 0.1819131547404874, 0.21842904208648592, 0.12088364891467557, 0.2751869642205777, 0.2011278043350866, 0.1346762039728703, 0.1322872200680356, 0.1386318376828586, 0.13014166826202025, 0.15440488324290322, 0.22729133105566426, 0.15592135428901643, 0.1293314689950597, 0.15127515360232324, 0.170218255671282, 0.12684095545762009, 0.16377922538067066, 0.1449797647975145, 0.13459205687526735, 0.17162612609324918, 0.15349760531417786, 0.0859486376265845, 0.18874894196708358, 0.15788083865998254, 0.09539809468532763, 0.10607726841924653, 0.1783648040145636, 0.16970626378972686, 0.27697872130140183, 0.10649678582746176, 0.14168252237141132, 0.0769592699925265, 0.09614536749018777, 0.1336717707735877, 0.13630015715476007, 0.1380765005465477, 0.11011691133101141, 0.18342015693985647, 0.07349612356554117, 0.15750073647547155, 0.1756409171127504, 0.20107217103002534, 0.10848423240766411, 0.18154517206693851, 0.16622586506268672, 0.1208189221459531, 0.27102002813931436, 0.11072719229325173, 0.16736221860253042, 0.13672394167271354, 0.14230385032151976, 0.16340358182787895, 0.13996047929169672, 0.10994002162929505, 0.12326717061261017, 0.19282434586315386, 0.10226758211971292, 0.13256411488738754, 0.1088337293796001, 0.12122731595750778, 0.10365557256004504, 0.1722380924489229, 0.2506960985521155, 0.13086221992008149, 0.1748907178520195, 0.09828988507750536], [0.025875236343352065, 0.030824430549757618, 0.018840542048095696, 0.13951988680468452, 0.03907215804041874, 0.06610350533118171, 0.027070548009848403, 0.04436224030571119, 0.05258359713479877, 0.03272942500188947, 0.024675983154485305, 0.01708499602823248, 0.049674179059483355, 0.030732641725109953, 0.0821917118023961, 0.05355829846174006, 0.06500897253112448, 0.06660091089865854, 0.03724450974034206, 0.04111525324744083, 0.031009348852920438, 0.004722328758948753, 0.0386760829226865, 0.006083626301974179, 0.0084500695060518, 0.05236161549785926, 0.022300457499260386, 0.03348116026890855, 0.01843038048865574, 0.03600365414674725, 0.012150470490357088, 0.05607702701743092, 0.02639276129494031, 0.07030831679942147, 0.03769535248378112, 0.05549129534272417, 0.027665725548661528, 0.023384002683263634, 0.04301130553827651, 0.022304557984875097, 0.022690505420248357, 0.07885821809571597, 0.03538615280582059, 0.046595417248505744, 0.035062055479014115, 0.09477698890071723, 0.04229839177682035, 0.03422290574939501, 0.027495255663750634, 0.026560490500302087, 0.10691751365459735, 0.008168998549902632, 0.05426826278468775, 0.027515491876270504, 0.029524678116544124, 0.041992270703157114, 0.037442194898763013, 0.03965683251378998, 0.04782192401527878, 0.0862472510385898, 0.04425593794533803, 0.01296103077625195, 0.028285310648742224, 0.03789111859195175, 0.014124952947660802, 0.033365285639921506, 0.014237383053818298, 0.0614023914620761, 0.03457162897252748, 0.03263829118241707, 0.05109848589786599, 0.07705516121800869, 0.053675218800743746, 0.10996792255149734, 0.03276782898953365, 0.02299345488990507, 0.03010378504592565, 0.04798302464487572, 0.03805188980374125, 0.06293064877090436, 0.08362178345240893, 0.01686634687376359, 0.022399077912972822, 0.038133462845918634, 0.0399929114557322, 0.11918565333490411, 0.019483701588826317, 0.06796295394099529, 0.02395807066932321, 0.039794391261473785, 0.01758475348563685, 0.009798054834977995, 0.021020188597181154, 0.037981164566571676, 0.05012935786057384, 0.026234579460334875, 0.03491238871168706, 0.04457278424994119, 0.0435753530942865, 0.06233052996497962, 0.03282859508368758, 0.02086604979159611, 0.0708326043921613, 0.037582247262640346, 0.023919151487549948, 0.060497622471302755, 0.04011558128460761, 0.0058428731168650334, 0.008182560221382208, 0.0040708925958061895, 0.02713934079022898, 0.02166009034901377, 0.005749946651649812, 0.008404195203535981, 0.0829319978853868, 0.04019510887202717, 0.05509124422866491, 0.06499781063006771, 0.04246164511348452, 0.05407572956755758, 0.037110501810187296, 0.034947881565218976, 0.11862936624956709, 0.03266543750801394, 0.020658916853848967, 0.09136466474662866, 0.03294980168462761, 0.04948045457563093, 0.04278684943734158, 0.013469411510853999, 0.061743534245197816, 0.03310693014833716, 0.11125164076445565, 0.05194481004089598, 0.04237632207091778, 0.03173660186509932, 0.05892145785412962, 0.051266393218670166, 0.04095951906375347, 0.0852820338801511, 0.019347159822861996, 0.08854575995956698, 0.005298471885673221, 0.05320750680121203, 0.04559756091405307, 0.03863207883231583, 0.05538340718034775, 0.013941391577733862, 0.017223006767791607, 0.03880639447860661, 0.022864524207468477, 0.050183554750777064, 0.07339380486237426, 0.04329037221689378, 0.07867316189672678, 0.07677910143449422, 0.047343084588646896, 0.09616653449953565, 0.004696586289473119, 0.042605987569737824, 0.01720681358429213, 0.08560995015526011, 0.010152352305369513, 0.07613496704687996, 0.053104372214405775, 0.051363368458565206, 0.06637568104892008, 0.0216695457892192, 0.08705473069341914, 0.06074277443751212, 0.020203144334617163, 0.01297325849713337, 0.07095612840907228, 0.03995712365834944, 0.02552956406537804, 0.021496827436250546, 0.023025067508100502, 0.0315850792497757, 0.04607496775626656, 0.038944229017943144, 0.043968961408902565, 0.05600575019695586, 0.028053689710495454, 0.04873403212836674, 0.09753576344660214, 0.02902190227271809, 0.012547466828818283, 0.00963321665392047, 0.025390871507566304, 0.04736605573505644, 0.027350524417875756, 0.07279873074543092, 0.08418167115099008, 0.051382313812932665, 0.0018712912518118, 0.06861147801241568, 0.015214880601683212, 0.056000257346538775, 0.014069649060406994, 0.032312190535688595, 0.022756448353550607, 0.09609007892469246, 0.06956514256495623, 0.08337642847289962, 0.049107932831130685, 0.03913884216378774, 0.02246399811889616, 0.03238124570118324, 0.05704325158149005, 0.09353737436955975, 0.016360910789620493, 0.0319144242788635, 0.039208893243583946, 0.04039004760523958, 0.04824054893106223, 0.053537725170533505, 0.08427972274441874, 0.038994503537974054, 0.030005926889697873, 0.03094087591424825, 0.011475191755791106, 0.05002557975991119, 0.03426372291400068, 0.04827889163167246, 0.008838946270125528, 0.0383721337082886, 0.056728588627471085, 0.04956685014129166, 0.014597382133586273, 0.03181462600496748, 0.10263168838836494, 0.036009786680581114, 0.013593521585027057, 0.03413651018373428, 0.07303137632627642, 0.06515821411965356, 0.021321950630555232, 0.020652977757215984, 0.04851699558897846, 0.029381419674703674, 0.06028332086580415, 0.03354401012221652, 0.04248686472795183, 0.04518106572269913, 0.07057412632650907, 0.029195064956682826, 0.003733364550674695, 0.02804100137924956, 0.07600813353013608, 0.05755291838619498, 0.09155688386770988, 0.024353739760455587, 0.02516776563659791, 0.0026299458489032284, 0.04202276866342272, 0.025942678893766096, 0.054850102732739145, 0.05598807271810309, 0.01691461041299326, 0.05101102930043013, 0.0475575853770058, 0.0864966509623393, 0.020766720746553714, 0.04976631262369695, 0.057255837150038257, 0.025589613867322766, 0.041491444553098375, 0.058176705478540355, 0.0449543917972234, 0.06980516557251254, 0.08046953848773435, 0.020702062925744443, 0.03205833964109902, 0.062458064452174215, 0.027454993912890076, 0.08244639007194389, 0.028474026832789667, 0.021469648551916885, 0.04232029040013591, 0.04608565085237065, 0.044544580723008806, 0.03989697809541418, 0.03420504057900079, 0.025684664311308055, 0.039499868758984154, 0.034404752039981466, 0.042150199728747534, 0.040548643127324126, 0.04519394749114591, 0.0771542240474974, 0.06561052775190723, 0.0379382866254497, 0.05487339563607689, 0.07342254082041402, 0.027987200939547152, 0.02860522513548213, 0.05122795475706939, 0.01653046328424206, 0.03849144424161604, 0.052994473071228114, 0.03428632250776695, 0.039530979589589184, 0.007298831835449223, 0.0530683852341627, 0.11045742975247484, 0.07225583487701032, 0.03453314071521163, 0.07878653524864106, 0.02810081752437738, 0.016357363802531076, 0.02340736836495419, 0.0060779744883128, 0.020029811196089275, 0.03197095007635653, 0.07528347564080069, 0.042079673674438274, 0.03238513359739896, 0.07670506669749176, 0.0430801538600316, 0.04724358891948097, 0.004013951674419185, 0.02331223556651704, 0.0575140126109604, 0.03734404754434382, 0.007711198291696249, 0.03210985713878707, 0.10549206917564716, 0.04836406911753359, 0.0519727147935379, 0.028875479887750362, 0.06957499445566247, 0.05169064888069707, 0.06042862093196281, 0.07718438492907632, 0.03462265808916381, 0.014558494552939892, 0.03287473655936699, 0.08419199035533013, 0.013995361514389517, 0.0037525825844626996, 0.03724464380572881, 0.005556214506918144, 0.07569137915608383, 0.0147074909933332, 0.019482856976889798, 0.07361695861383792, 0.028480504106189457, 0.07501267122044679, 0.08613164070993663, 0.06447901588774498, 0.015208748067849347, 0.08425418903390247, 0.08204948757925341, 0.15801583867399924, 0.131407889026788, 0.17852655581889615, 0.19162900355314055, 0.10444951544125235, 0.1512686878202423, 0.1409432322027222, 0.18710631156159988, 0.10223469396512355, 0.14765509704668678, 0.1854484206846645, 0.16853119216619, 0.17373714265563797, 0.16813463441306548, 0.195951807883478, 0.16760623292817226, 0.247917742798886, 0.12463217841521387, 0.20002866734660443, 0.08203058819016142, 0.11737904947010741, 0.2007587797819607, 0.15840643626307288, 0.08876234067664032, 0.1451574818741891, 0.17118819959221349, 0.17628095292996976, 0.15881525142298591, 0.12552716063275454, 0.09461909817952303, 0.16299444491103773, 0.13554166882268845, 0.217702285116238, 0.1154447464092124, 0.13001720961784163, 0.19495402432737813, 0.08948142910676618, 0.1255128884147252, 0.18951947320132487, 0.12997862942997487, 0.14356345208662172, 0.08667918673205761, 0.08185505446407103, 0.12241248461988666, 0.18305127028255694, 0.12749710976476633, 0.17662814397725368, 0.1167093124240637, 0.11890589334671536, 0.2733193644352498, 0.1285602023164111, 0.09197780321682654, 0.12233099584738094, 0.13012656100815342, 0.1334323070102161, 0.19103428949752163, 0.10470155070746139, 0.11602409274107027, 0.2056883717136037, 0.0815535682223497, 0.1628592610359192, 0.16264126305618595, 0.15457823361840942, 0.13642571896554964, 0.10516336382997614, 0.12719900197079106, 0.15662329001051767, 0.09682428226956437, 0.12418993883916449, 0.14760675689866468, 0.1267582026400393, 0.17627117764805594, 0.16855938420180352, 0.11872584736275098, 0.07208695845498193, 0.18469816013689966, 0.1525879831564042, 0.1677388274261067, 0.1920892385345313, 0.1621476266412966, 0.1701028215428514, 0.13353811907431773, 0.13457832857966423, 0.1975304546255258, 0.1819160199093242, 0.06752777003472851, 0.19918333528743637, 0.10729036864734466, 0.15906757014172693, 0.09240456015592621, 0.1694973362910171, 0.11594948343812458, 0.1467410162571938, 0.16060285630726046, 0.118423962755309, 0.2229595022095788, 0.222457837193243, 0.16995959374452793, 0.16860283670886872, 0.19648380998161533, 0.1329024193147498, 0.1004826125778979, 0.10978666614861259, 0.14143548965934785, 0.149636292349427, 0.13826034632661652, 0.0544052929317038, 0.12670071540220132, 0.08312938043907767, 0.17830033005485613, 0.057009030433912436, 0.11161860454106524, 0.20698833099055677, 0.1640974123391413, 0.15079296254102262, 0.18781247608844312, 0.20051352439388154, 0.08426987851459174, 0.15080931085732677, 0.1844847586847121, 0.08324664551764728, 0.17538014078332534, 0.1182703851091285, 0.13565163308333966, 0.109113336150204, 0.1371306117864386, 0.17755173957876622, 0.12063181283132685, 0.10351269716216673, 0.13739865062938583, 0.1924710720777512, 0.20745248834211982, 0.1926133805705655, 0.11980462173420577, 0.0976379672365804, 0.060509320633906516, 0.20733029731819708, 0.14840616964765135, 0.20668934219546858, 0.07635448954158253, 0.20243392295895085, 0.12397898886833461, 0.09962636376580886, 0.1948677321835872, 0.11783131713708563, 0.1210568996987516, 0.16526899060174344, 0.09006632191519584, 0.186253854884736, 0.18998320154365034, 0.0870787398889661, 0.19883733933731434, 0.11844955009197998, 0.17564077921692403, 0.21670238715746712, 0.14469576068222523, 0.1706440166960801, 0.16467659013165584, 0.13733529515804785, 0.13103278173554328, 0.2562733871802207, 0.09942015587923028, 0.1379874964515048, 0.148679111453314, 0.14860568958665096, 0.1895181708518536, 0.1834220568379087, 0.16576748401407274, 0.10894075952350132, 0.09048407732118523, 0.12902786835066735, 0.12445677492407062, 0.1345016891437192, 0.11892999447281323, 0.2595107828176791], [0.005397056867819159, 0.026014101270946766, 0.04883397978940799, 0.022944279706045505, 0.03490315352175986, 0.0861280937228472, 0.04568155479407118, 0.04595021416823711, 0.02707813036507897, 0.05080976268096317, 0.030037840197403586, 0.04368247516873864, 0.030073526488136382, 0.12162047228024853, 0.034457428245654995, 0.029556196888968832, 0.02018617165665473, 0.020481102100964037, 0.043971309468390486, 0.03785407824081279, 0.04241954092116606, 0.10080172650275693, 0.04448489098238849, 0.012470041195140972, 0.06780445801034089, 0.0583993191380174, 0.05875590242325299, 0.03392854029492986, 0.029391809742176728, 0.03816422893695774, 0.045636068323567036, 0.06721755805154962, 0.0571300263606733, 0.054715746232578834, 0.0655341717684942, 0.0430572095266994, 0.055638135245610634, 0.08313750097107503, 0.028084559223404335, 0.04069032725848017, 0.0750609960467104, 0.0678173436092273, 0.058965833497143565, 0.019453280237353137, 0.09662374343362548, 0.023832399691004428, 0.05549263982703129, 0.050973418213787584, 0.04958501025553673, 0.04234677405967828, 0.043132696000318375, 0.014009332085298675, 0.03961825615636284, 0.04457242418861678, 0.019972205214623003, 0.018478077122821443, 0.004605880042823453, 0.008436728084850456, 0.02029502317459593, 0.02793570833971664, 0.034549653740419496, 0.04152010007190608, 0.034325186148165696, 0.00041956798198835687, 0.021873371142353264, 0.0591049550641929, 0.11081129342557923, 0.02528420142498949, 0.1063421969452212, 0.025893113005065152, 0.015552033981939238, 0.036208716731879025, 0.07876516905643287, 0.21193794846054048, 0.04901024895990568, 0.015415125451381169, 0.036677252275929335, 0.03760346023726367, 0.0465714272051569, 0.06387887409918251, 0.020391804977290092, 0.017550934534219485, 0.012331770943297495, 0.024778294196772962, 0.008742853946563219, 0.03571665462767405, 0.11218633697999102, 0.028724311588091717, 0.07897156846499251, 0.03897504490469733, 0.017358527721596823, 0.05214179805930584, 0.03917136642661306, 0.059807021020641254, 0.07504446386930443, 0.04017022633624654, 0.025498300017188155, 0.025603866933154005, 0.04754551566175876, 0.01960523186191436, 0.04951342316945234, 0.03453101099078213, 0.0407690619448981, 0.043438614060681675, 0.022693236523698417, 0.08098145376049704, 0.02977631501703253, 0.037897883148323146, 0.04217772143742731, 0.06933436623864597, 0.0417832819174134, 0.06610674588310142, 0.07096274740873806, 0.02988551702019909, 0.05164336593401048, 0.02770667486343413, 0.054068122314469474, 0.013622627180490284, 0.042135513823239074, 0.029470875761621905, 0.039431740559877894, 0.04398508755970867, 0.06430843875052468, 0.05534479634896402, 0.03633250504912388, 0.028103789945523587, 0.03514138005313373, 0.0334324715508809, 0.05000902076942786, 0.0889140337465271, 0.010329711235939495, 0.021935280622734178, 0.0756435139825748, 0.05299268425592492, 0.01189858269607348, 0.015930322453289503, 0.031179824483490763, 0.07132842415763486, 0.045991318615814375, 0.014755839759844446, 0.02464854380025739, 0.06940221098522026, 0.08261996261294811, 0.04528873938045675, 0.025876215020675334, 0.016516748395177628, 0.029412936531908573, 0.04593579639350215, 0.0422393761935734, 0.050429327248205105, 0.022035050168333035, 0.04341575782746077, 0.03522595232953468, 0.016600355400793975, 0.05594323742233458, 0.04492788132460368, 0.02334304379239198, 0.03958540247573007, 0.05485628889272771, 0.12313997703454188, 0.016409919349356525, 0.043245870169372334, 0.0286302225844514, 0.07810461740460127, 0.043171739671379335, 0.09120494307529542, 0.028557133966035424, 0.018647154642929955, 0.045243023083575314, 0.05877252653120987, 0.053291052519794435, 0.04959457486327137, 0.017578170875147466, 0.060154813446945725, 0.048385347209630475, 0.07302828899194157, 0.07456412674078057, 0.004347341647747183, 0.01840101633851807, 0.030670293659392386, 0.049468040120817965, 0.011963853387222176, 0.014612402244951698, 0.026550441341955337, 0.07361670580482291, 0.052403949516555, 0.04911336056407421, 0.010187084816636579, 0.03292464335719424, 0.03786942681237575, 0.032190344251331784, 0.06411684016066213, 0.06772994063794613, 0.019101823995550795, 0.01710758987633932, 0.03385003543488922, 0.03080242084369304, 0.015899215453124095, 0.03406894888969199, 0.02010057282243525, 0.05962801308581426, 0.10066281944032639, 0.10378234478975497, 0.046690695603648504, 0.02758057679109756, 0.025582730567323107, 0.05896133273058842, 0.04586977110574803, 0.036982419570126844, 0.01985051406307086, 0.05621034163801421, 0.06762668730751162, 0.045496939095638456, 0.038595892669212435, 0.019829567304001223, 0.01683723553264093, 0.03322255962918843, 0.02579420530838111, 0.08167631849045716, 0.052911187822539965, 0.026410237675712957, 0.03727229957979533, 0.053833481074581226, 0.0433150019436594, 0.11481435563895973, 0.04303850932046772, 0.05273491099116303, 0.044833744440468094, 0.021869923746694, 0.03447079264949407, 0.08169011573397345, 0.05681293873837399, 0.029176977620790565, 0.04721527047935994, 0.02571676531055522, 0.039992585868364385, 0.045545804013888684, 0.07495014312406702, 0.07569921623554922, 0.011448639148335544, 0.13350772070548228, 0.06539202415414395, 0.03165581980870376, 0.041512799253987695, 0.04926168667753378, 0.004645010856385794, 0.07059865646184453, 0.0427922771702851, 0.05725884787558068, 0.027328372985545187, 0.06321431963794655, 0.047476560087694276, 0.09809217310600704, 0.013183614749821925, 0.014765993297670879, 0.007925787658971405, 0.014532320201396944, 0.03686762512511304, 0.010007819284745043, 0.07022858236826236, 0.03419352627749886, 0.04051434154051446, 0.08147210243248171, 0.004802558753233884, 0.030441369350639083, 0.050321960025617195, 0.019158451299693798, 0.05431374159431266, 0.012125569759988257, 0.027718290671586033, 0.0360670555833607, 0.029192990773627837, 0.02265116105967712, 0.03437910724671618, 0.03462670686384363, 0.02054982976387105, 0.04873465649002502, 0.015567220717428193, 0.010320375496972232, 0.03558985941532639, 0.03752055037165842, 0.06465340814282818, 0.034632138427226775, 0.02357685574210219, 0.03676298517553556, 0.05031914848293509, 0.04649757249881664, 0.03676009702406103, 0.05722490635009543, 0.02948640819428669, 0.04953902582788179, 0.039111243846315535, 0.03500482488063074, 0.06971716505265044, 0.06289846924764496, 0.05863318662910212, 0.08031926268050749, 0.004961124110606409, 0.10479859106482999, 0.07303427979950944, 0.0134471652751428, 0.02293895922541138, 0.017380117994522857, 0.11180516993326527, 0.01724552209188621, 0.06857595451536679, 0.05016762395239165, 0.03152700978511524, 0.041870569975505915, 0.03813761121202861, 0.03552608259563004, 0.0318344600213271, 0.05845256607919451, 0.05356063886034874, 0.06734435326389729, 0.026714876369242708, 0.07623249003964086, 0.01999737886381486, 0.04070923813889104, 0.06705092626713938, 0.04533331420633101, 0.04619197619538154, 0.01566563141457136, 0.07661561061057352, 0.02607928386198417, 0.014975940650929848, 0.03777111857949245, 0.06288780913417859, 0.04530703356008857, 0.03871835948478791, 0.07375720633013595, 0.031073303788059184, 0.05807964213853402, 0.06634928931992862, 0.04213123522218197, 0.08068873922550872, 0.026352991755571098, 0.03623173767400365, 0.022789495471384258, 0.04827883034463852, 0.0814342117237468, 0.05833325171542745, 0.009273418672232619, 0.027347550081509738, 0.03234926919122377, 0.06339438094366943, 0.06927576817331776, 0.026289912075885845, 0.010123278311033164, 0.02458610763442853, 0.08546741949694772, 0.003219616891358108, 0.13404931422443161, 0.148943166639055, 0.1785343852374823, 0.10022077904713732, 0.12816550615694255, 0.15435675759949993, 0.09459003280367582, 0.13298432943561386, 0.17719052912246797, 0.16489864837738777, 0.23552815519994308, 0.17477811824890876, 0.11999103390882093, 0.20240923960603055, 0.13826212365060084, 0.15245534269319427, 0.14335743572202422, 0.10812161234958519, 0.12161883285209057, 0.09857529879457529, 0.1661044248049298, 0.1700821678124128, 0.14253991265450755, 0.23057372669779488, 0.09819598568062629, 0.09224951928181034, 0.14435002520199747, 0.203538422562903, 0.10067384344555678, 0.1222740755146069, 0.14046041294932365, 0.17162948155835753, 0.157887258476788, 0.15369632852173623, 0.17550320514748174, 0.12544678268773904, 0.1494527376827694, 0.14683735947455132, 0.13818192956668718, 0.15387982190135988, 0.11083484296837162, 0.1941936514190128, 0.19283461144133923, 0.1875942329605741, 0.15200033243144714, 0.11569711109322887, 0.12718733445170427, 0.17940775611467902, 0.23428384454980974, 0.15580529196848794, 0.11425985353848628, 0.2503776051584752, 0.14979977551246845, 0.17308501797097345, 0.21869564068413552, 0.16548994568086442, 0.12573411162461967, 0.188325249379681, 0.16786710118814824, 0.13741300711708684, 0.1784348244508428, 0.15216707912904603, 0.27516710722158033, 0.11935137347468447, 0.15157663984404457, 0.21214531313988472, 0.1929278136982072, 0.10611429344862701, 0.19766036781572527, 0.13815962108633212, 0.1400932729724915, 0.11117478682389183, 0.19104735895750985, 0.36473636064798604, 0.2182030155053062, 0.10590066217006215, 0.21661624823126102, 0.1112068705861607, 0.13820256797536729, 0.13326294029191618, 0.22872383886527634, 0.14890417276370913, 0.14782418797333396, 0.24417088337002263, 0.1303592372325159, 0.1280437594640159, 0.234255897662332, 0.11949780352053144, 0.2599675550816521, 0.1400680533580242, 0.06615045886006087, 0.1501854394953097, 0.1935933755650636, 0.19324618451777967, 0.14782556693159765, 0.11108741449612765, 0.09848709143097363, 0.1284737569550353, 0.13617350749911802, 0.09511027545217546, 0.08366075434511708, 0.0683375096489345, 0.08218622661285824, 0.18833838012670318, 0.12425814364706317, 0.20796608900831592, 0.14213897287845612, 0.12212765312963918, 0.13753297648602916, 0.12982438528730025, 0.11848911853326906, 0.18092601980653503, 0.24827231893375998, 0.12731946929688417, 0.12395012267534772, 0.11791579365249603, 0.1359559078851054, 0.13887358438824454, 0.11082368872819409, 0.1353065411169683, 0.195828283866567, 0.1530761497035142, 0.3940850970966201, 0.24408050031671602, 0.15850611962378025, 0.08154598395189933, 0.09917427229905322, 0.23967619955299363, 0.07945295513397263, 0.24144935601901626, 0.10147366222114333, 0.09873615427603645, 0.22521913982927802, 0.14089993291324185, 0.0966240881731914, 0.1450276606145405, 0.16814393472046624, 0.23687187341913102, 0.11801209090457809, 0.06750373785654384, 0.08189638490758597, 0.10063717847750073, 0.1809211474873366, 0.14352576056074712, 0.11292811693443407, 0.13798996325462096, 0.11316584167821754, 0.17422458908009916, 0.07277530377670642, 0.11776567872373328, 0.079769586933957, 0.13625000903923667, 0.11329119664526756, 0.20665295301906525, 0.15614088444459825, 0.12947940057323826, 0.10360895610985257, 0.13503435007747144, 0.1455585442243084, 0.1664875913411379, 0.10515260029463999, 0.18691944739510938, 0.07955434687075116, 0.09201259893034736, 0.2231150640234832, 0.16882353131809544, 0.10827421706410185, 0.0685164831098049, 0.07314299533684408, 0.18239516194068617, 0.21857685109059657, 0.1420023027927645, 0.11956821466165206, 0.13328422221445269, 0.20577797335722756, 0.17669175991848593], [0.08609284601745107, 0.08822863020243184, 0.08664534862844214, 0.006607502601259659, 0.0571464934206057, 0.05996867323354368, 0.06054284847191265, 0.005102938476709589, 0.048248133201512604, 0.04364358088482292, 0.0373502720087286, 0.021686388232234507, 0.007752559857533104, 0.015804687864147127, 0.021010848070164363, 0.02463009065738128, 0.021009951747292956, 0.030598865536552285, 0.06932531107938097, 0.05463802278222096, 0.021355170118171844, 0.0589312446273623, 0.033144583369815545, 0.027959616028613625, 0.07578322543732582, 0.052066288603049134, 0.004623036103082761, 0.06883405719793613, 0.03418165957555175, 0.056962310561850193, 0.0069980513522281285, 0.04228025847565263, 0.06478132184354529, 0.04241919618160014, 0.039493077389535405, 0.02396774444458706, 0.10125481388381413, 0.08904523396443936, 0.04734863872609792, 0.034308577361967296, 0.09368506079960255, 0.06115511360187685, 0.025012899047484802, 0.05573340210943453, 0.011823236991110589, 0.07145360292446229, 0.04536812141117069, 0.03906557734514918, 0.011937790118428248, 0.03974590172630645, 0.050247745257952524, 0.042305455107482216, 0.06281952771748747, 0.05823180252205461, 0.013952767983409426, 0.042286046269920566, 0.019694237872177077, 0.036214646252412955, 0.044191705303326737, 0.002510414586492604, 0.015344052601815953, 0.009395572349369045, 0.04372764371275421, 0.044724542437301534, 0.09920758180200093, 0.032844456934159806, 0.03995862902112065, 0.03409683832057542, 0.072404432951683, 0.0869001264894201, 0.04712628553651514, 0.06047594218304562, 0.037089430561829964, 0.02023267127843874, 0.08624785624804997, 0.034509932081545555, 0.008731724604243233, 0.045652075730744875, 0.02019434006914737, 0.0023385339027886553, 0.053551330892068726, 0.1133151675364183, 0.04949101509766714, 0.031203027371497407, 0.06952523704498045, 0.05345771877816128, 0.06302756272376546, 0.03627371163137498, 0.03378908931007309, 0.04565033288071713, 0.01901819975295615, 0.01867085357286757, 0.004456802684393141, 0.04186490475530586, 0.04721191884469121, 0.03997026589669047, 0.041877556697375355, 0.017145204793421492, 0.06421188102854837, 0.016229350510383808, 0.021545343784495227, 0.08090609369138557, 0.022641370456004818, 0.043997785467053616, 0.06574358190259626, 0.07531448687997556, 0.027015979567001906, 0.04283140894145735, 0.021136748874860427, 0.04173127986911324, 0.034423758681382866, 0.020068705480004993, 0.041684605962326454, 0.00409207061766797, 0.07653766882515724, 0.055821797164577636, 0.025472159181991895, 0.027749435976147655, 0.051928174441620234, 0.07072481582121504, 0.020376954362877918, 0.09621485166492001, 0.017938655463137457, 0.04889962586363958, 0.0665483036408982, 0.03545071869607895, 0.049375331990661166, 0.014860675061842608, 0.052050794474780566, 0.024792551093043822, 0.030700379847398693, 0.038282114546746016, 0.014206877432673449, 0.08046692612791255, 0.030495064453251904, 0.0958071320107387, 0.06442560423766414, 0.06983305117295635, 0.029337773730437604, 0.08670023116733759, 0.021140343742445115, 0.06223583000621969, 0.02876689458536285, 0.0328635172017159, 0.05192377326649524, 0.043535451404750354, 0.03508184353009828, 0.0767706131802932, 0.026862398090381778, 0.011039948477710207, 0.03950999261090352, 0.04156641391736846, 0.09197355142884678, 0.08829514961689712, 0.06526902873790072, 0.04185603728758232, 0.03472877658843514, 0.03326161096112863, 0.09930847558162867, 0.02505481554826181, 0.043126260861754424, 0.018076317632691036, 0.01536249138054348, 0.052738806548257994, 0.015318931621168892, 0.017878333699979612, 0.08301430637197149, 0.019026659278860016, 0.05085696518841771, 0.01719113942536135, 0.059096233153174964, 0.06592567334131849, 0.026674968934047128, 0.057844794054906216, 0.01947674934091347, 0.029125169009691285, 0.06693100286347252, 0.03084468208403597, 0.003581825177177727, 0.09103603600975006, 0.06750926901135715, 0.070290191159133, 0.07129207328562776, 0.03279601336426793, 0.008389589737259574, 0.05722102228431933, 0.061985606537951585, 0.009581926109779988, 0.030907030149753538, 0.0024119052555291887, 0.010864482741923103, 0.021057646466238845, 0.04765389412040672, 0.031035888053837325, 0.014541708608909, 0.056391379705840544, 0.036218334965768366, 0.016234052375019077, 0.031694915190699606, 0.046443551808836005, 0.0564891440162976, 0.020672915195445382, 0.06375405156323988, 0.04056868781786292, 0.0713866161963632, 0.032435059547424316, 0.036654541599414045, 0.07905278910672472, 0.014299843159894791, 0.022855930616177862, 0.03991242242796768, 0.0355563928643542, 0.08266222768373067, 0.06404941293200658, 0.04293986783933736, 0.005588884326449085, 0.012040156702090417, 0.03754674291778957, 0.0539342369583826, 0.016463101173060078, 0.022732165281570727, 0.030839037931253834, 0.03929890474424728, 0.0662248459975085, 0.034758301617036906, 0.04512147557350897, 0.07972382084136048, 0.08866221298493686, 0.03584306679605957, 0.04903518895228063, 0.01301145468342809, 0.05811096747375785, 0.06968767832844489, 0.017014598293650537, 0.0585930934175849, 0.052129134625917485, 0.03191553127591408, 0.022659737413989443, 0.09988252058505051, 0.06599126578939539, 0.028786849260570544, 0.039329356739237424, 0.07110468817934876, 0.035328374454571355, 0.015595785263294895, 0.065517348477677, 0.043910834487647786, 0.03637783447160356, 0.03982921378807195, 0.02791535721400813, 0.009476288330681142, 0.07435470894579926, 0.03419587433698677, 0.024080340217258182, 0.0700579592657666, 0.016146082498673952, 0.023706558258122495, 0.03416853265896921, 0.014217554783118109, 0.04908135341059777, 0.06392396986484528, 0.07107458092392453, 0.03538410735106276, 0.032615856297554514, 0.047025077660838445, 0.07266861837237112, 0.13316990657439157, 0.08580447520099341, 0.05727286345415539, 0.040185869851660345, 0.02244479995551369, 0.043158038188853574, 0.037560632091856776, 0.025383524724372455, 0.07068741540875166, 0.0636765962436555, 0.04288000189849446, 0.011531545183501177, 0.054949242171020284, 0.022218658461145336, 0.02330330489653974, 0.09473840871285047, 0.012676218438202576, 0.02134038845167285, 0.017393717970398646, 0.07104782913360866, 0.00647204724373296, 0.024823416775513082, 0.03404121650683303, 0.05968400645219992, 0.06722008614169975, 0.04244224776724174, 0.039849047804431575, 0.02847280683777025, 0.04361901244509124, 0.0627593974763107, 0.02569322534386189, 0.10637105547732885, 0.018397745143081394, 0.04775519009619471, 0.030473079645044865, 0.0795354015163837, 0.03633589881862845, 0.023599621959991997, 0.0699005511799647, 0.03990857283614817, 0.04052014848698051, 0.06338860847115999, 0.06212532565358186, 0.049113000502749804, 0.04813068043140154, 0.04143666926651232, 0.04210616116442027, 0.06107504209203105, 0.0621541114073367, 0.03397228008496665, 0.014524639212346126, 0.06292982522638575, 0.03099293158870311, 0.03712813332376461, 0.012728216656063114, 0.03253588054869925, 0.04172552654880189, 0.03176991711370647, 0.011000207666638158, 0.0468176402031414, 0.03978056720488014, 0.0493375025689602, 0.034201244613335985, 0.02447352143785646, 0.013670740374964813, 0.041448264007246306, 0.03513628939887689, 0.12493197926350179, 0.04823763396651034, 0.033775242270841714, 0.039998415797468156, 0.022527656194964246, 0.026253379257996718, 0.0755469945649947, 0.09967239032829962, 0.12841410168837156, 0.0562925964984442, 0.021060345010952126, 0.046109782621985486, 0.011036527895128295, 0.02106899222839744, 0.03605491692020047, 0.03421507633080886, 0.02298735874524761, 0.0094710904241149, 0.025170908512307272, 0.21197044591028846, 0.18532305805673524, 0.11085031794444208, 0.1298199572990979, 0.1894175681856371, 0.26272531839147695, 0.2836190488549971, 0.14925194603781547, 0.11094412541077023, 0.1996393261417266, 0.12422141739197316, 0.09202856420268936, 0.09301552293641914, 0.17090974195349604, 0.15401410179272776, 0.08122716114045152, 0.12153245643862795, 0.14049289507731316, 0.17231822524580265, 0.11670141405756436, 0.08897126817535009, 0.214145063092151, 0.10090029137509485, 0.1348071896861638, 0.12992861921027785, 0.1316683895645603, 0.22109056943126265, 0.2033266298953564, 0.09218892172699975, 0.1238996834464131, 0.1865034616522251, 0.16244465425129861, 0.15664212045169648, 0.14173280838276112, 0.14082055088252793, 0.12564555186057283, 0.204748458439304, 0.18821373762142277, 0.11327610471315923, 0.15135098098506852, 0.23331550941351922, 0.08984137551798936, 0.16927633524662064, 0.10311839936841881, 0.1971880439668894, 0.14053300744102848, 0.12707412963913334, 0.20116482170358782, 0.12180138394356736, 0.19039852845091976, 0.13384417120006778, 0.17298640713336008, 0.15064959684687276, 0.19392110797907078, 0.09009802263350257, 0.15488422445712552, 0.2222218821125646, 0.15340961245519502, 0.1014439839749567, 0.10834296579442679, 0.1603453741559098, 0.07798712249965438, 0.1813409943133593, 0.1285420766761226, 0.19400026018340744, 0.11606608202020008, 0.18045741914501115, 0.13006150482162354, 0.11828814302721333, 0.17872363959829654, 0.1514077634220162, 0.19332063294226126, 0.1922276399789318, 0.11444132444598984, 0.15081004630173409, 0.21329715697755738, 0.08976907980057502, 0.11760081660242812, 0.13035529954058508, 0.1387901574132904, 0.1523163896654883, 0.21786334744143873, 0.10859135448211625, 0.12438663957460273, 0.12806005415416535, 0.2474777325386963, 0.21459541553931855, 0.12730751066438614, 0.11397878353994702, 0.141506138287725, 0.2463287845133774, 0.11980169527833501, 0.14683270165997167, 0.11830595457145285, 0.14757856486305115, 0.09648452227514598, 0.10675102742689271, 0.10965505990410045, 0.18675786413012013, 0.15938673769274067, 0.1689743127433523, 0.23791834952369814, 0.09892831977096297, 0.0713933271265799, 0.12426395059352922, 0.1769907793570911, 0.13193098918324517, 0.1365523686211917, 0.12651394316626172, 0.15349087906220268, 0.10154701513989318, 0.10961381373025718, 0.14199360003394468, 0.12340140453870259, 0.1798183332768179, 0.14723367207954008, 0.13658020825636003, 0.12160085276850771, 0.19190402911795726, 0.1392403259993561, 0.09822554135274503, 0.1910403109486065, 0.1611196438992216, 0.15731453114459593, 0.23562832885692198, 0.1666602982027877, 0.23293510079383853, 0.14148894727470415, 0.2002929370369642, 0.07606604211633244, 0.11478119935359686, 0.10670730678905403, 0.14963014832427426, 0.1911061791883361, 0.10830300664829631, 0.27139194850479403, 0.11797467517035624, 0.14219834469258785, 0.1268767164419255, 0.13656421234050106, 0.09287417205351015, 0.22152540093708425, 0.11476139598075422, 0.17526421635862321, 0.10116594002371836, 0.10687762345638006, 0.10327445147859474, 0.08866157713195971, 0.08131935982213867, 0.11675474143797353, 0.18404998846592444, 0.18111668376912995, 0.16993749976879166, 0.11454616357842762, 0.18790135760941815, 0.10540405333402658, 0.1613500371815697, 0.20023181854236513, 0.19652764553264265, 0.11009391337152451, 0.09419651641961067, 0.08274349429073834, 0.17589852183816895, 0.18357748075598673, 0.19087304331121907, 0.27384450238558555, 0.161419460069268, 0.05497341990591057, 0.24896919847496096, 0.12108072503319672, 0.17362186174479224, 0.1911213324074784, 0.14162292073090232, 0.14438806912831723, 0.15595371384293805, 0.15237251326682108], [0.03934945122549131, 0.02298154222268251, 0.019507814206243045, 0.06670486136910415, 0.06441597451245593, 0.05064845520762667, 0.028323915734466527, 0.0008493127836939699, 0.04973358917801131, 0.0030044450578580223, 0.03307299245329153, 0.007641677727787606, 0.06082063578369637, 0.04197868796425962, 0.06655607943332965, 0.026165926491000482, 0.01704809931857932, 0.04030762420546624, 0.04117356019935781, 0.002752815339443905, 0.03001845434247967, 0.03397576578502213, 0.042646176542245576, 0.03073834333448641, 0.024537587455744227, 0.07682342728179309, 0.06335036153154028, 0.03508944695274677, 0.1256454369473842, 0.08381936518896012, 0.027260304158253056, 0.023292054895371683, 0.05508496230768581, 0.0481096972831555, 0.005324704172615443, 0.07840317719045185, 0.014848046102410844, 0.02766810999732585, 0.05035740691387365, 0.06009325828222979, 0.03643124995212402, 0.03341915694275691, 0.018201720480236317, 0.016289379244910616, 0.09608505338790918, 0.07122327092914812, 0.040306314195115725, 0.04459994589729656, 0.06898866140193517, 0.05698631592695752, 0.03493421455664981, 0.04609586663484093, 0.02898808906696016, 0.00605011570094634, 0.04436681385061914, 0.07565338119503952, 0.023449200596059525, 0.05864718688591834, 0.04299656217617374, 0.018288221382986636, 0.044646983695847374, 0.057508282273286776, 0.01502272085241613, 0.027916194165065408, 0.05386803163996628, 0.04487561497596964, 0.025888750134336374, 0.012315502108615494, 0.08237597893082327, 0.051115098514504013, 0.014553349314918442, 0.024162397810047673, 0.019774598580214287, 0.03514093955257728, 0.021508987166828687, 0.045748445761179736, 0.016147534235290462, 0.028388609944452203, 0.029053957306689797, 0.024221309971424843, 0.08880397755532496, 0.0601032289165643, 0.05940978911014334, 0.021391386924792203, 0.03571189339122465, 0.06859475431302864, 0.05676129675139824, 0.07456943573009583, 0.04458429855144313, 0.0539995804278841, 0.020123848488794702, 0.09042120448523953, 0.007007773007987248, 0.06754183540901831, 0.06851157248621026, 0.05305878998291108, 0.0648809592389772, 0.021362363683780836, 0.04847008802537476, 0.02777212750046484, 0.046852841943262086, 0.05312669218607968, 0.021218285527861407, 0.020737161243995352, 0.08121851966866563, 0.044088965251801476, 0.015893055148602977, 0.02298061717151394, 0.04982499495869683, 0.015665613219983155, 0.05109706863520607, 0.008573354120486447, 0.02184937535334499, 0.029553674544478138, 0.023482435405434623, 0.020568045419490626, 0.03032827179037756, 0.08197458716289652, 0.06652202682509538, 0.01849902196667127, 0.09576058450845942, 0.004809521534855688, 0.05122542283647964, 0.030670310896370682, 0.01809026043291294, 0.046638754842382286, 0.02617947475594138, 0.041428399347369714, 0.01816280704412249, 0.04031715050880467, 0.030856033591853998, 0.031178629386328885, 0.025143241246921882, 0.06950963183396286, 0.023532937836623, 0.042389418343983354, 0.02109111876287047, 0.046875537298018896, 0.0944729439253288, 0.0424335258562238, 0.09120435318759373, 0.03816293041792609, 0.07973345822744793, 0.03374748307490542, 0.0573857426793585, 0.08081821574559135, 0.04678657533781183, 0.03268665048263727, 0.045161940337669466, 0.06856175124525063, 0.06394249004041476, 0.07594996447404546, 0.029137964593246583, 0.08564492206900351, 0.05077068453594562, 0.06035619497960133, 0.021329305074628324, 0.03418494226230729, 0.029396440743679003, 0.06705918469496312, 0.0835481853855233, 0.00623250495634913, 0.02053804158593618, 0.04451959093491878, 0.013164392646191823, 0.013960360872348952, 0.033924912868608395, 0.039704873887521606, 0.020624188173021522, 0.036582085003535596, 0.019194685343292453, 0.026791184472160477, 0.014712223501485443, 0.03509874726014753, 0.07484061553353265, 0.02631095842638564, 0.034269345999364896, 0.07398835803952909, 0.038869271144991925, 0.06622980258637859, 0.009280486790944011, 0.06030965896864092, 0.0512813434245125, 0.032075348708237854, 0.05174896732393292, 0.05045250523835421, 0.025867027711243402, 0.04332648943208399, 0.006950147395517918, 0.060181902315948284, 0.03841652850350065, 0.026090936059312477, 0.005491050110468942, 0.027590570408069802, 0.039363160368896304, 0.013829345473148411, 0.06387921883874843, 0.06640898289098855, 0.032345408108085394, 0.06930594437665517, 0.06568120702380134, 0.010824384742356356, 0.036288937628870054, 0.043890491022818515, 0.07392637386557556, 0.03518203250883568, 0.021003035888556513, 0.047022798549263715, 0.05437206769842775, 0.03532395029680864, 0.03062001722414167, 0.038409273650857716, 0.023521260741437157, 0.03216078857921305, 0.02902078186912883, 0.13196270522331038, 0.017821689158858314, 0.03019421789494734, 0.04485043366589854, 0.04353538628727679, 0.06705779041494093, 0.056719303641828804, 0.09020652366621841, 0.09695225725731543, 0.0659646901993021, 0.14611529096239997, 0.03139585553247842, 0.05984516070795156, 0.06179583506778844, 0.02514891221278137, 0.06301974096605856, 0.05181288203945564, 0.008816452013448843, 0.01529177763469277, 0.026388195410911596, 0.026827474057133642, 0.006624792248100764, 0.04889965650715655, 0.00853665467847379, 0.044070808967996034, 0.022204746304440404, 0.01807740164710389, 0.0655240594078937, 0.003869410992915472, 0.03694568182371798, 0.042886257006396214, 0.02228432560279485, 0.06412712106060597, 0.018743361879680908, 0.040083987818610285, 0.02173520718520928, 0.04191159015341152, 0.00694458176674802, 0.06105181047572725, 0.038451580856476104, 0.015804753939230597, 0.01630409004827661, 0.028387006905470646, 0.03143092129199255, 0.0434905203479913, 0.032342048812537424, 0.039750168836044694, 0.06924135550375908, 0.07889839174646525, 0.025184931751761227, 0.029591331596396146, 0.06272960814737505, 0.05036445875321666, 0.019512272837962356, 0.03193467006748242, 0.030048260908393614, 0.03511579654690239, 0.07369591163531428, 0.015196500237159913, 0.0628922141397432, 0.027668092760347554, 0.035497967168808944, 0.01722153970941661, 0.03376018481268998, 0.07051029588065802, 0.06779651367856611, 0.030346613850504644, 0.025198610251649253, 0.038354115320309516, 0.0502797409201101, 0.012748016198466142, 0.022094504336916634, 0.005693560186398006, 0.030382284819478952, 0.0408788078704909, 0.005955066214570957, 0.04326266664711218, 0.05713033662628263, 0.0796896763025753, 0.10975505736085678, 0.030653054765876264, 0.012343358980762142, 0.016686419633427457, 0.003765597700088796, 0.026727175910867033, 0.04468577455789332, 0.04317311479920342, 0.02735844768223263, 0.05845237455721344, 0.013138243192506414, 0.010312248261705523, 0.045069688029827616, 0.043528192721667795, 0.017615454459202387, 0.03073435584684053, 0.026810103013450583, 0.018777548553301923, 0.04092514086815138, 0.056982531452611576, 0.09769989778437922, 0.027511153903399265, 0.017709235112453182, 0.0655599276445085, 0.021032133823140495, 0.023498605606296373, 0.0324572837581077, 0.005424355932195942, 0.04231612288182782, 0.00907646129733973, 0.03717438971263267, 0.025553835646039056, 0.1048602304992176, 0.04912012512044561, 0.01612215182713924, 0.059092180548055526, 0.10023951755776521, 0.05600871495722283, 0.03786951108204742, 0.06319003465074687, 0.08461208999036782, 0.04083190796776645, 0.11785678956056796, 0.08824988914233062, 0.018963776866815264, 0.03871265596019165, 0.05923083863191067, 0.043320908481555606, 0.05247748246596706, 0.043917296439289086, 0.022602880283469157, 0.02731793886801649, 0.06535410280189206, 0.054736288880268415, 0.09175300237632568, 0.06157268514676441, 0.03121197144801338, 0.011695669945179215, 0.07219203507467624, 0.283410519722008, 0.14433695574200925, 0.19767072532446156, 0.17860943121054482, 0.11359204703401174, 0.12113916222006084, 0.09250457293444103, 0.1593106958053766, 0.09966726520008619, 0.10009212224113365, 0.14729434624314308, 0.19157821192376076, 0.1857868783296116, 0.18142403824435127, 0.09895396073378863, 0.17265646838613097, 0.1357952286038668, 0.2675926733401514, 0.09165382463364832, 0.1516107767219505, 0.12938635153395514, 0.09594894254640227, 0.11276789730595005, 0.12620885631129627, 0.186938997958937, 0.21775038011612433, 0.16887006349861625, 0.24870866729367166, 0.1296118112100709, 0.12717955099839356, 0.15859725344325268, 0.19441057687565205, 0.1895918531884109, 0.11500776219632357, 0.20157533757869275, 0.062311059840384035, 0.09384504294083004, 0.11339951381688157, 0.16614105912946886, 0.14744264554352532, 0.10397605012140929, 0.17175836819073848, 0.18123554997146132, 0.1831393857156077, 0.17548704069227944, 0.20637245758646922, 0.17600116229826407, 0.19726460679404198, 0.1620133314281702, 0.10361829472164955, 0.15258183913125148, 0.08122582048658403, 0.1416350555636229, 0.15627468936145306, 0.2005147348128019, 0.09304985133630615, 0.13920664877420472, 0.1195688505146292, 0.12395458896794628, 0.21951995129066132, 0.11121217957547597, 0.11816633504725273, 0.08971515487158492, 0.13123392578094237, 0.12541280668829718, 0.1421136613334379, 0.11643746612413276, 0.12839421404585724, 0.0851145517381449, 0.08353037384128378, 0.13327170433776994, 0.0731055029938298, 0.09257661584284037, 0.14876690512943655, 0.17023170817523234, 0.12781804697888513, 0.13482638784954626, 0.1566265382233166, 0.2098697102478435, 0.1219162358451755, 0.1874557242638642, 0.16535880674998607, 0.24121827325753628, 0.12515515599760318, 0.14665012758585716, 0.21904755083303298, 0.1808802537139385, 0.1738773520675398, 0.1335278381743739, 0.11565706767742673, 0.18051677563738439, 0.08544270550051043, 0.17085188699345435, 0.13243847646780554, 0.10503671417433409, 0.2222557278770593, 0.08937445258901966, 0.17772225542895256, 0.10881836931671827, 0.1684781788818298, 0.13146226594765342, 0.2761210399048944, 0.1498196325114658, 0.20012041403641626, 0.12305193054940432, 0.19678240041098288, 0.09048348743348353, 0.07421685142382499, 0.12018274741187213, 0.11898257874793584, 0.11775316850792979, 0.13078302175046938, 0.09743665465183797, 0.2017328758994418, 0.09850230593714984, 0.13765551991039707, 0.20940873982204547, 0.23123685240505204, 0.06976159049137946, 0.20512777921413222, 0.15290566449684484, 0.1466525177801809, 0.10706672459960946, 0.08630289200453028, 0.11351467981453865, 0.15020990834361123, 0.24495005607604983, 0.09734990285529245, 0.14660517354646038, 0.13846481519360698, 0.08829619149647414, 0.16235946527411863, 0.17239651943166412, 0.09684014795047623, 0.2158684238430954, 0.11009644146167463, 0.19075839059247127, 0.22137791368990178, 0.11006502419589989, 0.2176970603965944, 0.12318768899046606, 0.2121705787196275, 0.13098808816604077, 0.08738240182039239, 0.12866846586187042, 0.19082119448050378, 0.14263075536056874, 0.20192858072057848, 0.14492390166607597, 0.14636966279677807, 0.17515046762362604, 0.17513033483297596, 0.1656126116793002, 0.19799183873880297, 0.14867957110606855, 0.15399367788866644, 0.1181425786607208, 0.1479395608147306, 0.22271459922194484, 0.21051740694430568, 0.16354639593872333, 0.14691781402835924, 0.13874520337389362, 0.20797275397325718, 0.15914142101762757, 0.14361675648439315, 0.10394362928045374, 0.08887684017780328, 0.1586744138189862, 0.11966257371128568, 0.22721210224253519, 0.18305655628923448, 0.23925848245140047, 0.20140082274954166, 0.08296064191287564], [0.05987727128329778, 0.03561498709924279, 0.07974620593050796, 0.054463986758022546, 0.051582630483373526, 0.033097932445666486, 0.04961057460956997, 0.03342115643223928, 0.030226987305908438, 0.07654679293233542, 0.0232970517038578, 0.06914278297054191, 0.03524170692769751, 0.07022965489135635, 0.05560119448590183, 0.027386630141747095, 0.09807898107195094, 0.012773581510109287, 0.09247775219621197, 0.026650390918216398, 0.05329413219325004, 0.025005822310284264, 0.017996945178076144, 0.03936322931680949, 0.034554181320051995, 0.04479615633646327, 0.01765029422277885, 0.04418314044033328, 0.054393993134820656, 0.02331291163911022, 0.018459070481420047, 0.030120353612508026, 0.04925920838309873, 0.03817550575120315, 0.03963728194996234, 0.039727105759084225, 0.03862986483821466, 0.03588191894513946, 0.07670457640122022, 0.08450403328864806, 0.023736516126401486, 0.0546805904577336, 0.016549548449655695, 0.007572401354404828, 0.07184209377174416, 0.10418932133864972, 0.05747005448586518, 0.053722137855666305, 0.02176306788779555, 0.03699743489344274, 0.10691334613628926, 0.05295020468052357, 0.02589010802518216, 0.07258578128511868, 0.06376033348421897, 0.047968009321559826, 0.018115357473312367, 0.031801229042391625, 0.05615607963033742, 0.045479104568761204, 0.043473808139923124, 0.08320320067146132, 0.03477164303823825, 0.07902979114723784, 0.0200717315273059, 0.04507289793823035, 0.03216494460620227, 0.04016791658115484, 0.024672817296138214, 0.04607646545815853, 0.013159541394411316, 0.09878490811153766, 0.029132404710136117, 0.037857950815270026, 0.10260536560728666, 0.06608953954832208, 0.021328897132808645, 0.09358143974696437, 0.051714776819872285, 0.024810393280800314, 0.013718156429428249, 0.03844888422698264, 0.035899232532228195, 0.039773530687295625, 0.005545186192443174, 0.04171360239026047, 0.07344589884122533, 0.003236310904838085, 0.000964354292063358, 0.05594894094693084, 0.013065756910720901, 0.010492371812072254, 0.049248494643477664, 0.007710869831498713, 0.02024669643311251, 0.06218814869381248, 0.11174816533081955, 0.01677779860103563, 0.028009011462751417, 0.05264000418866354, 0.005085393626828708, 0.029486258807141456, 0.05241346432857456, 0.040441164821987195, 0.019245030726456357, 0.04587840491665467, 0.021821430381087047, 0.02656738146118099, 0.04458233736635697, 0.11846944539537353, 0.038571906456303214, 0.04883847289508389, 0.08887131668386922, 0.023200239257646665, 0.029321578631718314, 0.05127133448578177, 0.03378478389593863, 0.08961363289985927, 0.03294958334956919, 0.008229374896825082, 0.03700934373022568, 0.08514002416162722, 0.057092426765349605, 0.07899331004028359, 0.04789056549329431, 0.05576547821082416, 0.030256790041382757, 0.018681810545404593, 0.01548699215955792, 0.0726263762842263, 0.03394098922369942, 0.03763649394855865, 0.027662410303169203, 0.016130963753488277, 0.07934482182346045, 0.04642337305291046, 0.028372751924419598, 0.06143507660336553, 0.015700109201603602, 0.04611036484880794, 0.007643904170817546, 0.02122145521664812, 0.007933090870914561, 0.032264137670638106, 0.07270450193074442, 0.045687208522952376, 0.03704923392844297, 0.017494967980911175, 0.04051737907913424, 0.06009840256264133, 0.05907780873859602, 0.08055992154104095, 0.02071338953570493, 0.05683988971155017, 0.0698550915225379, 0.0858892351689358, 0.04556573762167846, 0.08074740623875011, 0.03954607918257675, 0.03780129861326949, 0.02964056615206984, 0.030117453969714623, 0.04125293073875289, 0.028769895734806216, 0.06899857457967536, 0.07480998733831991, 0.034451843464686986, 0.07241204020477111, 0.05242853710848478, 0.06570178414544751, 0.029154175013724356, 0.06003130858223285, 0.03373135692409931, 0.024070453852595344, 0.048245490198173833, 0.06185300054869825, 0.035998827792824276, 0.042623197734956784, 0.004824319001918118, 0.07233866430338352, 0.09251300756248737, 0.029393060380713116, 0.0465643753658139, 0.043210480737710194, 0.03907188607920562, 0.05797483748005283, 0.011383673934746655, 0.013407069190795864, 0.04383736665570929, 0.02443456778212661, 0.056528762253301765, 0.013486050940569372, 0.03795468473746892, 0.023676043060878595, 0.03753404501044462, 0.02470459079279775, 0.029881270977878766, 0.0093226149235101, 0.0051551607752879786, 0.028945140262705185, 0.01821254338738659, 0.020838468711102204, 0.03792983667564489, 0.04455459349217915, 0.031253114199986866, 0.05068805429243273, 0.07126660852302467, 0.023811793841061094, 0.037935486574086456, 0.060421155405140696, 0.05109521087198969, 0.06390852553229179, 0.02328656587539421, 0.012306296604595358, 0.017736946427894217, 0.04284025342654317, 0.03094993681917268, 0.05738096995159023, 0.006157718016766013, 0.027264170987050862, 0.03487261725709804, 0.0398449185905197, 0.033840489979352684, 0.05462766910392431, 0.052527312655001886, 0.030681624099792495, 0.03619625248135098, 0.03870278108684767, 0.025731585281450423, 0.09091903140107471, 0.0407820011699392, 0.05935947628571622, 0.016935379056620504, 0.09260846211785272, 0.06059229178654571, 0.045105502640287724, 0.049401903750314835, 0.011150298655153284, 0.04542391559469604, 0.05632473771730739, 0.027552267927075588, 0.025926728943182577, 0.033064496538211266, 0.018297889412591056, 0.056637102407553507, 0.05973476360762312, 0.02817634613283219, 0.07757515871837255, 0.030532135447907834, 0.02233281130752256, 0.041362178707194906, 0.054316196906109976, 0.033440867874531016, 0.04568434718455519, 0.053743458082599026, 0.023471491839436275, 0.018446592824353326, 0.06335954309531278, 0.020566744985239162, 0.059448932372634454, 0.0164213512964066, 0.036056966205397924, 0.09371482331546084, 0.06015444572474207, 0.01645833227573143, 0.02051359188983277, 0.07614294202217171, 0.05310133084534638, 0.09125409527651726, 0.017195471652573156, 0.047311437496494864, 0.028599174956100124, 0.04553058950771247, 0.0009458431539373593, 0.040241817252770554, 0.09925127945720189, 0.008393438371469178, 0.04401813659276213, 0.06442326000861584, 0.042650114234176376, 0.08791567562448402, 0.04336484745445271, 0.018557834536618283, 0.03099304841711156, 0.06594268815411676, 0.03076620020663306, 0.07406508940602503, 0.04459310473213273, 0.051067980276721145, 0.048326814261775826, 0.056610090147343375, 0.046386520393312945, 0.007835370131708201, 0.03934001685270379, 0.034414274512880275, 0.007941606416997891, 0.057585239635720376, 0.047151244681088195, 0.05277939388648637, 0.029537772474389885, 0.028290811160038558, 0.059152705324513305, 0.006540369358845056, 0.07048344449891199, 0.03465527045210043, 0.0489148058958592, 0.0030425924060475686, 0.010230023087182594, 0.07908773037695116, 0.005241248948169091, 0.08090064680624394, 0.06569609977304935, 0.0527995688119723, 0.08703793038523967, 0.011415912829820189, 0.03249350056472806, 0.02694361490167437, 0.04963212466287998, 0.027056930796994318, 0.03558887116190407, 0.060882815310070594, 0.10739093300916495, 0.03857692816264687, 0.061119164926029985, 0.09914733664763552, 0.040562471014357386, 0.006710629527186675, 0.05330563500343312, 0.019009110119734562, 0.042849028963715806, 0.06362717974209978, 0.07766688242554665, 0.025277706914611404, 0.07557079691680209, 0.011975198191770864, 0.02885974635700545, 0.03270159302760036, 0.08411790965305221, 0.040265374456442175, 0.04294146130221986, 0.06726524702483608, 0.012109130470743103, 0.051200053834867094, 0.027174257162597873, 0.02131796122768954, 0.04307271897672646, 0.16888647310195432, 0.039486519676903566, 0.03826477414657993, 0.0413567356524929, 0.08355125739809968, 0.04665726352663291, 0.09602659321840733, 0.23498270059785537, 0.203028391866434, 0.17980924747403593, 0.17687313889543857, 0.08669206467006477, 0.13760016239698858, 0.10828527937372846, 0.1606852260808791, 0.16014819844595848, 0.12461436687097435, 0.12036298491781759, 0.09351885036355065, 0.2188303342629825, 0.276807117606363, 0.20903018513514152, 0.16273795867398863, 0.16072467960897954, 0.1680397314410056, 0.10192404531182782, 0.12807189787347473, 0.06450900822998056, 0.18670866596362284, 0.14846826873479352, 0.1208104185699936, 0.17422610593418922, 0.10215021744971314, 0.1504020278732623, 0.14547497935352788, 0.1460406433550581, 0.1387818683419497, 0.1873958774752194, 0.1594186529156662, 0.14216865112464275, 0.1360405299572214, 0.13070460499054, 0.15019945890432404, 0.10576363968392534, 0.22657189788597248, 0.1942164195521224, 0.11649185836675668, 0.12239717818315952, 0.13917108697275962, 0.1603110993821775, 0.16272602302412834, 0.1631821977395204, 0.125718314891621, 0.10763667869351565, 0.08979848991598814, 0.1031603656649109, 0.13615224089834, 0.16842698888672938, 0.09898263540479446, 0.25336070557034784, 0.11421990971411429, 0.14509259422700252, 0.11817569664168744, 0.1460846321236703, 0.24330566366834028, 0.09124700896321766, 0.2227701099529382, 0.13649989159837847, 0.11204389825222955, 0.17525736753258014, 0.0836734637437809, 0.20929609425365928, 0.14179633239344244, 0.12443213753642575, 0.08396000361009952, 0.13409941637467954, 0.19354413143329083, 0.16651540033278928, 0.2139096902382951, 0.15865135457246535, 0.35160858604696493, 0.13232887992935796, 0.13990256304462112, 0.1823792885988951, 0.237031081811555, 0.13628619903277966, 0.10904238874753637, 0.17600863931640504, 0.10064244150154053, 0.19401895272875988, 0.13073693390094465, 0.1361206014670672, 0.24915019440795147, 0.14100834967628603, 0.14160871746078615, 0.0790449979925348, 0.15128888189792633, 0.20812247819717855, 0.19800067939344915, 0.13894309920649375, 0.1283486241534833, 0.24929429554650862, 0.2281396661794955, 0.15148510765885154, 0.1024880545634416, 0.11261425071185636, 0.0898452825664032, 0.1242929929867387, 0.1950150815349433, 0.14724013786162102, 0.2603233876007219, 0.25095446936545834, 0.10457644854942638, 0.08651775668465322, 0.1646079486536403, 0.22998527924139656, 0.126289808822255, 0.18691026966177648, 0.17611307242224294, 0.09643869489551553, 0.14430968301190486, 0.20272607824975447, 0.15346910684339463, 0.21738268855598666, 0.08498979431967582, 0.07920410679352861, 0.11618867140984344, 0.17518566170286748, 0.16911534953021234, 0.2796793038085584, 0.12314183096731864, 0.1274770612437879, 0.12341334784944212, 0.15823634942212414, 0.07483572789257573, 0.1559922787090463, 0.08829270579641865, 0.161249649019972, 0.10077497471244105, 0.10080461465423146, 0.23785510130466955, 0.2557302614854228, 0.11047952372821108, 0.1654144706985643, 0.10795193919611555, 0.1512008890389435, 0.10975453642106826, 0.10644826947921708, 0.09720207086854404, 0.1469007149458893, 0.15759039940612932, 0.18359327748898538, 0.13186591767495678, 0.14991208400216796, 0.23228602513911265, 0.1311254170873473, 0.2160441031258914, 0.13209453363332058, 0.11041800686789137, 0.12608411421458568, 0.1329224448530905, 0.25422286092033314, 0.19674060265383414, 0.13569657180097797, 0.16566064539215258, 0.14756728804880573, 0.1229821092959854, 0.17738324620069998, 0.14259392185316933, 0.15122889721345517, 0.2151142715686752, 0.1375505198994952, 0.10845288408980255, 0.13310265937639823, 0.18791562216656824, 0.2881025631100901, 0.26243886279483, 0.16504016013876086, 0.138080959178267, 0.1300749573255739, 0.11518097467600338, 0.25336355541742617], [0.03887335822406796, 0.06792334719530999, 0.07841866748828082, 0.02687889196339154, 0.02395316004572857, 0.10880208994832732, 0.006670548764598226, 0.01923936167581668, 0.028093533943437284, 0.03204498864379862, 0.05510667706989954, 0.028200115925902804, 0.024868736621893706, 0.04085081884817731, 0.0392040898722987, 0.007435191176726573, 0.06773214697116806, 0.04912482890030069, 0.02922631751355385, 0.0475470784811243, 0.05469120843636413, 0.030252796808077447, 0.03058070925274684, 0.05796175652874574, 0.018615609057427897, 0.04438073366820332, 0.05844545678325719, 0.02283899049695221, 0.046246513994711066, 0.029312395152726003, 0.027905700675722574, 0.03359163397802942, 0.036659168770476695, 0.02157706557021987, 0.021362555205761906, 0.06760467760144703, 0.06767327311418711, 0.017411108166279814, 0.02145357028160605, 0.030653301829231844, 0.06068624864001909, 0.023470325470571558, 0.04268472225615575, 0.0376975320039257, 0.07909079472864829, 0.042123072555348764, 0.03550054505467415, 0.03643497313943602, 0.026308652501733556, 0.03926277220729859, 0.06026877285612207, 0.008829356764533348, 0.029051984630284772, 0.06382265856729881, 0.029926500808928284, 0.01773056300026515, 0.019853896341256557, 0.1467123645688257, 0.03609522463633649, 0.07407131770084943, 0.11272590802682024, 0.015202178863898642, 0.034766701771126646, 0.021921730442573468, 0.03356086022611107, 0.03141839575443057, 0.0477561553669793, 0.0683029514226702, 0.06366899665144664, 0.005545350901346895, 0.04504236550400815, 0.03587700066066558, 0.04290822457762496, 0.049646806737948815, 0.10465841995732439, 0.018996180470792517, 0.007624678715552775, 0.10036973718313441, 0.12576759732778997, 0.10918739386984419, 0.06229716683587721, 0.19884385108467073, 0.15023897371945844, 0.20907337717231245, 0.10349518439221768, 0.1606824528425932, 0.0877190898022344, 0.04033192834486404, 0.06715122249818618, 0.025919870541040457, 0.05333390364783907, 0.06752043857329315, 0.0059104310592726595, 0.004969218787136338, 0.06956881212611353, 0.07679762544050332, 0.036046175856984435, 0.01969523378647864, 0.056465494882075064, 0.02754205980548455, 0.08594090779942852, 0.03394344453549674, 0.017483384731496056, 0.011606697451263186, 0.07273446362946304, 0.019711748726906318, 0.01975266931338176, 0.029848951643573183, 0.06609432759784883, 0.026943109283644347, 0.028195320215496807, 0.061268705288849534, 0.08023520751345543, 0.016070410248733336, 0.11136921993907421, 0.03693316394703523, 0.06061199939839783, 0.04514013364490482, 0.023464966685541218, 0.03681071628365786, 0.036807881758338025, 0.0650151165562772, 0.010597538447097666, 0.11625131441941185, 0.02070983488773627, 0.11081608147510599, 0.059068405009325475, 0.034699243898954124, 0.04222564789797029, 0.04329717890810102, 0.033820816841457164, 0.07576905281072663, 0.055102042237957644, 0.028764929569837068, 0.043632376848930315, 0.007184352922899228, 0.06282841816784875, 0.05806048994042701, 0.036728243088169445, 0.01933329171621271, 0.039756542687574704, 0.028961069145870787, 0.031017745176570553, 0.06656643694206592, 0.019426449923025026, 0.050372835924668666, 0.020478001360090512, 0.02949968641323428, 0.057814901304100795, 0.01350526538332023, 0.07571626935274371, 0.06210293673399476, 0.035681207739417596, 0.021355495705539664, 0.05290126315348091, 0.010863023344427349, 0.05149142388554831, 0.020232736395912308, 0.10725059336231602, 0.054188666249355005, 0.02205387869429204, 0.019801834921142267, 0.03968293312937021, 0.01895545332151796, 0.07195525261903964, 0.011854068199623258, 0.05702475821899791, 0.010302510326578012, 0.018018114102643826, 0.05799456041366343, 0.04736212570400489, 0.07056555380263636, 0.05413516266872326, 0.02118608876762371, 0.003304945679584278, 0.10580136951419616, 0.012491611358258995, 0.06636843385715639, 0.0519922232225297, 0.028528978319598303, 0.02941190039799098, 0.03724700718697521, 0.0452866900952593, 0.011520526923930213, 0.01690734598425127, 0.019641033065835797, 0.020313114340927814, 0.038306828543183305, 0.010259611318038117, 0.05593520116000887, 0.01788265060543293, 0.008388162898500601, 0.05195931208530261, 0.10591885675826382, 0.008381365783392422, 0.02904181289787014, 0.08440344594419004, 0.020256940943879947, 0.029030066854771108, 0.006777368713125226, 0.008953100074112656, 0.034020348271775636, 0.09063678928801129, 0.02412274701430673, 0.034824717609632405, 0.11203991459502328, 0.03051398299454201, 0.042091915759468274, 0.03927023007324146, 0.04973529755408245, 0.10138599111908868, 0.04229737287988106, 0.04187356154885023, 0.025554431279400186, 0.04033932875421259, 0.042428722484938564, 0.04032026848665649, 0.0851606395876696, 0.006914969116839911, 0.05792274733164138, 0.04460579880903806, 0.028321198037555142, 0.011824608288495051, 0.016711112562446825, 0.03628884952875876, 0.04630821854657224, 0.020526205527506048, 0.003915397814595171, 0.04626291593716991, 0.04250508229879122, 0.020885217311461608, 0.0047735953628416025, 0.03659080308411391, 0.04032126823139768, 0.019797226902277722, 0.09676540075170417, 0.04784071615206138, 0.07576903748896814, 0.0496067863047844, 0.05048833517057281, 0.05414181614234563, 0.03821641867679935, 0.05714815966184101, 0.06722807643874999, 0.04610884416427824, 0.027399326133872234, 0.019873852931684064, 0.04057716458074508, 0.06904279317466483, 0.03069264044414365, 0.061430296214718016, 0.029022572599651835, 0.040434185760997, 0.12036494610290374, 0.08894029524057143, 0.11606006056911523, 0.11851636061985647, 0.24863359067709218, 0.1367501878449994, 0.29709625148004104, 0.15395972487186232, 0.18116064189422518, 0.03278193649865928, 0.09552098284926146, 0.050805353844958934, 0.02311819315617604, 0.055137040964778394, 0.0256361345565247, 0.012995936614911885, 0.04354895370441579, 0.028628652104206627, 0.013484422046120369, 0.0652657498815848, 0.10321174718199239, 0.03413784700716215, 0.04653970733465207, 0.032923754695202076, 0.04769537778150651, 0.03627455049765207, 0.04076035152519903, 0.0883544218395987, 0.023951968779006315, 0.04957487108185888, 0.03178788953641009, 0.06352208013976775, 0.05225606773409152, 0.21332798435563044, 0.014587876897665763, 0.007810745671797063, 0.04678338841204682, 0.0019514290761435407, 0.02064804989664305, 0.04018309661337445, 0.04146660415215358, 0.06704707284488025, 0.0249424725846057, 0.026822023341552387, 0.013331606657424522, 0.03986920357771939, 0.010051182734089033, 0.008763983609124778, 0.04675181026780798, 0.06544817839899371, 0.014096322326710629, 0.02691571589469189, 0.06873152399015042, 0.0364813061370965, 0.08045448486002223, 0.05075456604601876, 0.018715811442703973, 0.01906435846561386, 0.04032342859934415, 0.07384080950531267, 0.08686601259415189, 0.005713753785277087, 0.026694465871720065, 0.019869844376620267, 0.024554652064257575, 0.005545479699879164, 0.07560818200750698, 0.04366022414497791, 0.029907515234944802, 0.03831087731786313, 0.03927157838798819, 0.05941975974447786, 0.022622440423395847, 0.08925979987027184, 0.02748059657131953, 0.029475309495483677, 0.08278710767626762, 0.013673171746514499, 0.04744852126966562, 0.035351111944164, 0.001255415693101954, 0.07398125640447102, 0.023249456576342066, 0.056945311070810405, 0.029648966306159576, 0.049820494192141684, 0.007768534227169209, 0.04013325876346038, 0.023282858009840694, 0.05508753253267177, 0.06525769829750061, 0.03365797719227211, 0.03482097527012229, 0.024816575610349258, 0.01988244460775487, 0.00966995440032934, 0.07158815860748291, 0.03894729720007989, 0.04385161972154052, 0.09968642505907244, 0.16126651827606464, 0.2358577568684855, 0.11038760083817667, 0.2639579538616442, 0.18229232229773076, 0.12917627490335895, 0.07046259158561308, 0.14222831405218572, 0.10880515430002444, 0.1396648153181999, 0.1789336549418588, 0.08248944421328845, 0.1163041208600325, 0.13231374203197419, 0.06673951918679862, 0.17377648893142902, 0.17320855730964294, 0.1129221261268662, 0.1621667941611621, 0.3952849746471451, 0.17898698998314722, 0.12363104705488491, 0.16919235668836102, 0.08898373242587813, 0.16983435369066655, 0.16348143168274434, 0.08449051949766376, 0.18620114803554552, 0.19717705826605522, 0.1928320833511891, 0.1523138156100627, 0.20068891256326632, 0.14274084219528785, 0.23430897223372615, 0.15056590940202438, 0.19342911099233936, 0.06278946642733871, 0.13227223538823668, 0.07141689199113077, 0.11189955196553662, 0.15439804973861865, 0.12450627952573762, 0.2494896173236832, 0.12492263299082557, 0.126892697036026, 0.10716364238291018, 0.09238679457696215, 0.11705562247023468, 0.19123362557541942, 0.1183729183169142, 0.1240681155374454, 0.11040813965542663, 0.1443690395042781, 0.09016441181302072, 0.09345799999972505, 0.11648796664010133, 0.1533997145992133, 0.10467281474942162, 0.212555461292786, 0.10989225604721617, 0.18454380874191562, 0.1304878480732441, 0.07498127693730978, 0.17368262783894617, 0.13364457465227575, 0.0911724379646682, 0.26613873039041797, 0.13895431473370523, 0.06752718014702683, 0.18133186254530184, 0.12026585262989807, 0.14992489299226194, 0.15102781445509003, 0.2193495120492674, 0.11934436377017729, 0.1189050046847232, 0.20927842826612536, 0.24705688979837204, 0.2086792555787871, 0.31150458801177244, 0.37059797514830867, 0.26211915898226923, 0.4068852618577019, 0.22338771471573463, 0.3981586010946382, 0.14849079171976737, 0.12918218910213441, 0.1490496068952545, 0.15414977596411783, 0.12429821770638229, 0.24004300245113913, 0.13256656636874523, 0.09546168764392216, 0.2606733672080502, 0.19855051601846374, 0.1865879611502732, 0.17608964545351846, 0.13930766512790035, 0.23156441627971588, 0.1540212110886651, 0.1051993316580211, 0.10363116499877746, 0.13882245568017806, 0.27772348133787034, 0.08559423769193311, 0.14066226179561309, 0.105814048269343, 0.16611697332512948, 0.1742005645627937, 0.3910849129240359, 0.11046177347100551, 0.13263949793913674, 0.09823546985224371, 0.22736538111442522, 0.09018002468491755, 0.11856482334194646, 0.1602359155132886, 0.1628893836131019, 0.09896620281881864, 0.11950164162103208, 0.19270920284813453, 0.11129877815443663, 0.1686219276199418, 0.26834910855658595, 0.18313762371338185, 0.15302716604163571, 0.14795883558690548, 0.07192849316784451, 0.13101779705574437, 0.16419415392221945, 0.14959723718704718, 0.12429176724605984, 0.06088275402303665, 0.17796081520857351, 0.10641988592162248, 0.19883361615000233, 0.20704005724720417, 0.07258203511516895, 0.14998431077166913, 0.10490398178057325, 0.22295914980913364, 0.20616901527729728, 0.14696626142869074, 0.10166812597984269, 0.17913197978369652, 0.08712582365279237, 0.16082198809712164, 0.12408377437461769, 0.10163018930583231, 0.2033382437882885, 0.20082768172987048, 0.21944251512327503, 0.11294286412697647, 0.17315361348371353, 0.12427011760131967, 0.19475116424502867, 0.08750843094481577, 0.3274850288946783, 0.1434978136732694, 0.13431845623398983, 0.2187889195497959, 0.14539083225592492, 0.16557983843789947, 0.16287184019963588, 0.1422639064971478, 0.12618915252988377, 0.2042663593085543, 0.11330821145806583, 0.11454745060614041, 0.11835041831457808, 0.10636883382234844, 0.24168541835200405, 0.170532857338267, 0.16791914920172385, 0.35495580804924814], [0.03993617881449961, 0.024555033192999905, 0.05740076949399325, 0.009368148316899616, 0.08698573681495844, 0.011741667779372826, 0.05273758463801877, 0.07024900627232368, 0.03689738381053171, 0.04621913401229728, 0.06680487414761897, 0.046394372794536815, 0.08724546360392725, 0.034854392025379405, 0.0558741937481588, 0.003770279215513579, 0.045131936504115025, 0.0176743206553041, 0.023275888524949554, 0.011785551210895423, 0.05660072855290867, 0.056478426446236914, 0.010876214420873552, 0.10246714802398797, 0.06534820392487511, 0.008209623234917321, 0.02554064935764238, 0.04704390810201726, 0.036226578071833625, 0.016671701169182217, 0.026701948635520476, 0.0504274120283944, 0.05728970206673107, 0.004859073538213007, 0.09503430251272456, 0.022551077418029312, 0.034953297806843635, 0.01813459394109105, 0.10787510057731022, 0.032781610911291455, 0.011859562965260159, 0.012034230054386202, 0.03424266315696221, 0.0661243888879976, 0.041912743115737554, 0.030186555100484725, 0.023594548542713447, 0.0872078869912413, 0.04289577947929502, 0.022779379280344136, 0.054721488061571316, 0.03110872386323829, 0.0259383485817741, 0.019663780131527496, 0.0213466971857293, 0.05482730778655218, 0.07154544154482503, 0.028204187683220354, 0.07093400378981907, 0.04001083408272074, 0.04178864836332299, 0.03299983105652275, 0.03386072619187255, 0.08009491383188194, 0.010516126283384379, 0.0035032288653911244, 0.054237676724310846, 0.029018801531844565, 0.052312467127077045, 0.03027471649881092, 0.05939940861876934, 0.037514969421130036, 0.03451679239890749, 0.08272631093859673, 0.013194613857194783, 0.1078898630916111, 0.04671309984499409, 0.492886261593911, 0.8918449955601847, 1.3578323779567596, 3.144472726891118, 3.0013192084527787, 3.11311460310413, 6.2203564374677605, 4.982332366128122, 3.2183015394595365, 2.8408442581853564, 0.8564532656342754, 0.2809294980139502, 0.15121820262603222, 0.03962323189743104, 0.09872410371298752, 0.05408690295993321, 0.06762442734813498, 0.15314114460301015, 0.010520035247018021, 0.19677337589523486, 0.11091532816569652, 0.9421466963906443, 0.502180164499629, 0.7653614277801206, 0.6579853798593245, 0.02625709095398986, 0.02116447551205995, 0.03768568828461632, 0.030830231750564232, 0.032035931569313815, 0.02138487517743582, 0.026035074843093756, 0.025578708605720632, 0.059574333304959926, 0.03742279372208061, 0.0473662089526413, 0.037894895405418454, 0.025748795446669383, 0.07950940815311286, 0.09141347986916382, 0.07040095215122547, 0.025719339365980802, 0.013986698975185714, 0.010421210862395745, 0.013170023392435285, 0.028028391572015903, 0.07515761505572066, 0.07633549822193962, 0.036402134780561736, 0.015383886301048822, 0.04251422172772788, 0.03540322124477356, 0.022468403124460773, 0.055667120182225784, 0.006355688064133809, 0.019847606759398215, 0.04693992698805467, 0.028659864441461624, 0.022566929692402486, 0.017589409384996663, 0.015915673894567356, 0.03890264193497358, 0.028961584339999867, 0.040871587491804556, 0.05954210015554583, 0.011251943200946817, 0.04983262902486229, 0.08255704381172696, 0.009861512770575863, 0.027126817167886806, 0.08934405422018421, 0.06550569628034869, 0.046129995851867625, 0.023094867694101507, 0.009358878653015821, 0.02500146901565454, 0.029747125151897633, 0.03685513789194726, 0.04287195797528952, 0.02745817509299565, 0.04471467905527642, 0.006010282001713472, 0.01248136972032127, 0.019436037513397394, 0.05509844545515315, 0.013075959286652507, 0.045630115820395376, 0.03186706663860429, 0.016352309537450635, 0.034877225275962584, 0.02406776488398112, 0.10107213255739021, 0.03664853547008769, 0.11670236400659047, 0.050879411564599124, 0.04894074563297534, 0.02134168697070451, 0.010477435012768594, 0.06717292576908104, 0.019801626162182902, 0.034266446356571494, 0.01904769605326076, 0.03351902416456611, 0.04129414626907918, 0.034827977313750216, 0.009306192871243244, 0.0894100756774987, 0.03757039205201211, 0.06024167249580065, 0.029371749729879444, 0.06187503706784018, 0.06458061446826305, 0.05917525129212488, 0.038053510079701106, 0.030399395393267758, 0.025395102228128144, 0.006751504627191612, 0.033942433299436685, 0.035345350962973414, 0.06794524964906516, 0.02534342193675618, 0.042899188570558064, 0.015524768912714097, 0.038569098744060726, 0.02146802827595703, 0.0334704848336837, 0.09031625043961311, 0.06540415132598532, 0.0849910430429924, 0.03894396471760927, 0.013821019055021387, 0.013162235151075069, 0.011778072277534635, 0.05963656262704923, 0.07096972646972827, 0.044328195358356165, 0.029134808310998545, 0.05285478842955443, 0.08268004688884943, 0.03852924685023966, 0.013177250474390965, 0.031715189707615686, 0.04410494967634159, 0.022724726567825964, 0.04946147091686726, 0.020857691772342212, 0.04144851681626132, 0.01902792523915489, 0.06477762163887102, 0.04944940503205984, 0.0351591992582525, 0.009308505499164664, 0.07667590173021441, 0.004384836384786233, 0.04849277954969195, 0.029895746209208044, 0.038930757361794674, 0.05576551268478075, 0.042583460754324357, 0.036038204712132295, 0.04586346237169159, 0.05367691185505641, 0.06228593215646763, 0.06384087996857782, 0.02513470128178597, 0.04293901365130179, 0.04823176956344997, 0.05224900057299003, 0.018352002033122608, 0.08474469981006078, 0.01684468956814418, 0.06305356374791553, 0.025522935489613204, 0.11293498108223562, 0.09676598297852664, 0.20108415264516108, 1.1529538684314298, 2.3105442235546727, 2.6571425026462925, 4.891640793892646, 5.697144616034723, 6.789760051235077, 9.595113723508774, 8.194508879415451, 5.577404460599346, 4.813482665246533, 1.3333516399706564, 0.35562058850642175, 0.18685629110663168, 0.11744565315424435, 0.1258777224669053, 0.040327929365899295, 0.19923826379160728, 0.13020912996463238, 0.050535024399118084, 0.31636967534019106, 0.33164776681411656, 1.327158707764841, 0.8687284456626062, 1.5769577939664166, 1.154526371148325, 0.013631839387779756, 0.05728683689789427, 0.10264512557055681, 0.06722383231164948, 0.02535333702971618, 0.042903306293151075, 0.02126870560459793, 0.06791444525362984, 0.016362201647772905, 0.04534432288980292, 0.03850414214896099, 0.060907563780464476, 0.05745677435169778, 0.09879670586557159, 0.041671279862883596, 0.039706130271717426, 0.07779447436933556, 0.0670041106340866, 0.013914110229140329, 0.03111945675505746, 0.01598365366413829, 0.020111788349646716, 0.0995803218815596, 0.07204868470228488, 0.019186710368000695, 0.023666807870951392, 0.02022651576196715, 0.014525611186400058, 0.10715948252548134, 0.042400155066242146, 0.022130154238473025, 0.05277880399878468, 0.08679898756165659, 0.03484545560974268, 0.031153769833185983, 0.016696283015452566, 0.03016123206414763, 0.027572550104870915, 0.02608840988438216, 0.06615592872784024, 0.03812297127179561, 0.048353347717033285, 0.02491532434378901, 0.02396403083337411, 0.029956188631213965, 0.043320713129134915, 0.043739820680310654, 0.02569753841887559, 0.06294401700518305, 0.049152810261735035, 0.03866514318712777, 0.009515038973111059, 0.05034334537002349, 0.059948896673778375, 0.031754028450156895, 0.04183110112564699, 0.05674626227588423, 0.02154062659810147, 0.022765880811118314, 0.04894971652256866, 0.08439788414585976, 0.058585145255370494, 0.020756313442102364, 0.02915672800173202, 0.050758591838060856, 0.09811006891991823, 0.03615672617489773, 0.09234253001669723, 0.04701888383997064, 0.0817620360683049, 0.05275810813351024, 0.020949980469360467, 0.04587391564141839, 0.049724848114795266, 0.2271778887558368, 0.07849529160246735, 0.21789800525913317, 0.13529989147378554, 0.1613050984639314, 0.07982579480496146, 0.1967326659829386, 0.2593414773864131, 0.17288212724510701, 0.17253571760750588, 0.17881534032283292, 0.12946826165481923, 0.13938061202005034, 0.128600238071334, 0.10470915029967025, 0.12011107222567644, 0.14129192478233768, 0.06537978206911395, 0.14778409093137712, 0.20352987302166803, 0.1250520175803573, 0.07908659656682322, 0.1994100973130234, 0.188594130919345, 0.16523817854542888, 0.0790101869572555, 0.15484605795673786, 0.18555813979717994, 0.15861352515076438, 0.15106136910617352, 0.12653814388378976, 0.10852143363726717, 0.18694227681525294, 0.11824446069377086, 0.20048432112220796, 0.1619920495056337, 0.11438295620703891, 0.160456441583172, 0.17301508946524513, 0.2334502183141247, 0.16402670242373021, 0.13170508517613336, 0.22735643320746962, 0.11039084905097563, 0.16496457790415134, 0.1743937259720218, 0.11038886488325174, 0.10542473004710291, 0.1300347070660322, 0.15111286553644365, 0.1520002711444132, 0.1299876539457229, 0.09653956569250553, 0.11934936632432284, 0.13237620884132, 0.16138691665424457, 0.19101786457242506, 0.11247172005354397, 0.19145804337195813, 0.11461722589428387, 0.19636816134856594, 0.17970348137520975, 0.2503754294687702, 0.24112497907011743, 0.16728044637749273, 0.1300298041033168, 0.19173821704762598, 0.07776865720628731, 0.16883565082905755, 0.12948591232059464, 0.15971365805354812, 0.08268108110754721, 0.19777977027960364, 0.12811910421136888, 0.14449480049792798, 0.22984104020701301, 0.39935590458973763, 1.6383575960513086, 2.818484296721797, 3.334888354424508, 5.1304214519839135, 6.614624752152351, 7.398774210483798, 10.47182523435162, 8.955108427232313, 6.894090685152239, 5.80670916265057, 1.8195462154765285, 0.7270374197152354, 0.3445716394532112, 0.2511515837883757, 0.2765783024651389, 0.18065647943125618, 0.30110522023131775, 0.2334122203530804, 0.19459168006095195, 0.5669942366019373, 0.8104227194862982, 1.7678961998993352, 1.2702719602854022, 2.1073034261503527, 1.532007309217607, 0.41633541605645613, 0.24566438710016592, 0.21684472629379845, 0.25405075160726426, 0.13606124497469396, 0.10607176024707095, 0.1120262629082126, 0.11423946027794193, 0.13021936489930078, 0.15246435188718382, 0.13959022899789197, 0.1724926787879198, 0.13692548408383323, 0.2787600289429388, 0.1248223597424165, 0.18289408436225307, 0.19533368218089306, 0.09791468585570974, 0.10543978367481502, 0.08376791472396544, 0.16232652349337456, 0.11648606674204912, 0.1564731214556002, 0.13196509541763415, 0.13420717430210885, 0.07878340960990998, 0.10476610127596125, 0.07881747753990274, 0.18192179621227328, 0.08424824419161005, 0.10657881852239372, 0.12429731372263163, 0.13691554026257607, 0.10658888491771876, 0.10216720927987369, 0.13274667363974357, 0.20723744746177428, 0.1341205604013897, 0.13169497281553286, 0.23965170006117514, 0.14742010723679297, 0.18885536690152463, 0.24330877398531287, 0.10524197211188656, 0.08119372906343592, 0.21558573739903591, 0.15626030223023507, 0.17674022264057593, 0.1564030550540455, 0.20623627779704912, 0.0969250841186412, 0.10628731440632574, 0.15120295747633905, 0.12427344242291105, 0.10549338684687692, 0.11094934246953457, 0.09575348287340134, 0.13583808356235105, 0.12513343740494984, 0.19598127162504583, 0.08048300631344318, 0.18223684221025438, 0.17556228584820227, 0.13709360973969584, 0.1977830184924026, 0.18510021840132054, 0.21078752954640698, 0.16516743798650083, 0.2346991561353207, 0.16312775953162104, 0.21273648786929347, 0.10507728619080399, 0.19115998920413757, 0.18385025402230604], [0.07304752545972025, 0.04293314924824142, 0.0474456369486307, 0.016697730921629458, 0.04858970882431154, 0.06640737410634756, 0.04112392153230406, 0.009190160236621817, 0.01952105603601423, 0.053204105370828224, 0.0544970894172307, 0.06714883996474166, 0.053418211623906135, 0.053586046166357496, 0.041938744139887636, 0.021767997663588296, 0.09497887605140287, 0.04536472764166613, 0.07641596809750603, 0.052112280691583315, 0.0865934385106929, 0.023967028152377858, 0.009724788101119621, 0.026719346492280884, 0.04860992971507292, 0.07720526082501297, 0.037331257706447955, 0.06194695357173201, 0.05036029506534819, 0.03254970460529289, 0.08287156886991956, 0.07314338604168547, 0.01916315316432907, 0.04923683478527012, 0.01073103501356297, 0.06278749375093369, 0.14045751713696988, 0.052510730681880835, 0.03293323503326505, 0.044616991353611794, 0.1035430648874852, 0.08840090805484403, 0.01926650800141356, 0.013414551954596274, 0.008876468299046881, 0.03884684009056899, 0.0012848878137564528, 0.04421994713465533, 0.0042376301961109765, 0.07959131827397693, 0.00996606270482223, 0.04798949808783589, 0.018611182984445366, 0.01817648745923033, 0.024847083146713918, 0.05684403807766015, 0.037485409918571674, 0.04020747736156468, 0.04633317386070567, 0.03287578609982326, 0.04802892480285899, 0.051260046180217504, 0.03053280385962177, 0.013747256279232041, 0.03716467188731317, 0.03284313926293004, 0.048444098492543546, 0.03792594111854992, 0.08144285319553268, 0.05317848356020066, 0.07817307502151498, 0.02609590988516087, 0.053408827046833696, 0.8894657103284713, 1.7909381634766057, 5.705168804814739, 9.08312870610145, 23.94817033121663, 23.847337961196903, 28.381207604562086, 33.54659649633592, 38.79411981951806, 44.50495350745417, 49.805283700266195, 42.17866636091664, 29.851351168847856, 27.57042427216807, 20.747482930460286, 8.70403947368745, 6.56053428688357, 3.21269745307584, 2.1652115833374763, 2.6622276104265645, 1.511919258102294, 0.9659901105107801, 3.356104699834701, 6.4633997313437925, 6.50174972511107, 13.93012116032262, 13.985823719732224, 13.657892980883199, 14.698725285068637, 8.44592692390565, 4.159320064129369, 1.5362055936167318, 0.5175643438293088, 0.04514049370622924, 0.048070385481321046, 0.003389692240987995, 0.015955738377787413, 0.046107507340850375, 0.053075781813071626, 0.08903384223700532, 0.016543454220218044, 0.05146371831576671, 0.047281295767114054, 0.05306436327256022, 0.029937206887670105, 0.034915901224819884, 0.0688265725189159, 0.006393726244794146, 0.051317690466079986, 0.031346647789882075, 0.03442613738438776, 0.033751018570675966, 0.03714214890233932, 0.023513756910218828, 0.026810553090106097, 0.01473324686934751, 0.01631241742401354, 0.04266893701447595, 0.04473826307202539, 0.033329034359344555, 0.02300180907871935, 0.030221446574996078, 0.06365599230893197, 0.04177743666655114, 0.006947869720358041, 0.047388996237949024, 0.01936899715914361, 0.020096623639185584, 0.04475794004036054, 0.074690378030702, 0.011222130889373442, 0.019345980047458605, 0.04455944665917947, 0.08481551697778125, 0.03173261820789307, 0.02665492232828852, 0.03728808099103551, 0.08641949824748502, 0.030378714849751805, 0.05229081365189726, 0.06228132413760309, 0.009373777147923267, 0.021262779914503618, 0.0494842084064599, 0.06148545071482659, 0.03240010678587902, 0.06082450069727437, 0.03546872559273916, 0.025894984174820206, 0.0244394343556656, 0.1119083696375451, 0.0875479534208294, 0.0766263818067889, 0.04920348314748657, 0.10215832265995203, 0.012058201903146843, 0.09954126671917977, 0.10631274852541187, 0.02399738247115766, 0.06754003510239624, 0.047110488803516475, 0.09902080956606135, 0.048083569854497916, 0.06309833775665011, 0.041507030611917864, 0.07377353166380236, 0.012250943879236378, 0.026280830103543498, 0.03576596004648074, 0.050080845342768784, 0.03053616315516974, 0.025722411378557165, 0.07257275779040591, 0.11081805032107139, 0.10878493723970269, 0.048336149043133186, 0.0055427031099586, 0.018676373236362013, 0.006689500343430067, 0.06062205047196439, 0.03011334773844048, 0.04074190029754274, 0.05718333458888435, 0.03757307335974709, 0.014904702134851008, 0.016244316037984628, 0.07916228605374213, 0.05207877583621491, 0.05031014694982479, 0.03143777394847524, 0.03991989178522941, 0.038618258606161804, 0.03116182141727017, 0.055538133958414684, 0.07507049553697148, 0.03222992801437936, 0.09304995092773631, 0.08159302941132938, 0.07972171409956871, 0.02033018086466097, 0.07566820499637435, 0.027728468149660096, 0.08882709042800051, 0.05313603462831629, 0.005401570083303077, 0.03873035259124252, 0.03959535778830609, 0.06326752827472745, 0.0021020495032350863, 0.0915203261519632, 0.026206657470714663, 0.027382558384429545, 0.04658826581773259, 0.05108602164733795, 0.020397962408981497, 0.004240532232929141, 0.028710068098359534, 0.020364130051025463, 0.041251490493455244, 0.03942713254101334, 0.06272205835088127, 0.03742624111773987, 0.03146981174546865, 0.08566773616738858, 0.03047167387370381, 0.03413605053097971, 0.03823042659449481, 0.04775933463186507, 0.06103207605079778, 0.028517804927222674, 0.03395984264751596, 0.09244151623739351, 0.04673363483180443, 0.11431212371755993, 0.06210727662208581, 0.26790339860223955, 1.400601657167558, 3.049800439227012, 10.20478537005763, 14.936423859288617, 33.545698273566465, 36.909264056913315, 39.75994856126847, 46.45916854181598, 53.864372007308475, 57.359902012732725, 60.56658083392728, 54.06489141525761, 40.49582835166685, 35.029679959820164, 26.805628768859375, 11.92670391451928, 8.002062689873481, 4.624862747807657, 2.927889006753122, 3.1454729312850587, 2.4212776364818698, 1.9252776258414792, 4.96252243557284, 8.662362329421505, 9.422487270447517, 17.94215867596288, 19.343533285202522, 20.784353210080056, 20.31699888167843, 14.44566180629115, 6.564732203560491, 2.1776952618552796, 0.6848859750936109, 0.09196672558544144, 0.07100226222387246, 0.04423191725847222, 0.029390467173089425, 0.050027456675325675, 0.04489164153534559, 0.04069942455258101, 0.059582507463112, 0.04180885010188626, 0.03218072984788207, 0.03936370812176217, 0.03433128420804297, 0.035072083569942944, 0.04416856561757384, 0.035485319057179075, 0.007234388040453797, 0.06568680712652784, 0.06832375837069365, 0.014491141060247056, 0.06038626393062934, 0.03324654201165803, 0.04293743551017777, 0.020922575589089144, 0.006238328182183567, 0.011969189189614789, 0.055319779747796644, 0.015834458040884666, 0.06738731547469093, 0.08536668659578409, 0.05129049817520765, 0.04709919666751258, 0.04110446289902733, 0.04440542085156326, 0.018111253157258034, 0.05674672575907842, 0.004055756134837265, 0.052371379288454215, 0.06359162560153393, 0.010725758582984489, 0.061212091391245206, 0.05184110854902575, 0.04312202439553315, 0.10042627447194631, 0.031239709576531768, 0.04627897697050245, 0.013293514850609487, 0.022913272297310255, 0.015072154590950139, 0.06767353358408136, 0.054232693322363405, 0.009435980614545125, 0.020222371226296793, 0.014910439175793962, 0.020437645763459227, 0.0392783620965577, 0.1311748144367049, 0.011087736084816918, 0.0064597319015451985, 0.04863961562213879, 0.04853475350706328, 0.010197007570475822, 0.0916317000143951, 0.09349018335342409, 0.005081163385071822, 0.10705414543589277, 0.06176235319505777, 0.05139190523374466, 0.04903089119902542, 0.025474419141368523, 0.0440747236772891, 0.21145315270029733, 0.1569868293741057, 0.21830251500491174, 0.2859063728922798, 0.2182692514672395, 0.14939316668577735, 0.16200442948649008, 0.1704528930807306, 0.16207657964719882, 0.18074672458873642, 0.1869725526100205, 0.22813316975389758, 0.20369036844180477, 0.3242185525596142, 0.11870098014872883, 0.09537169529545693, 0.22715669876385122, 0.17173259699296567, 0.20185558786315305, 0.10470850678581385, 0.1158930917060183, 0.08155375974433077, 0.10846812923949574, 0.17321701492032698, 0.1694958041151685, 0.16416709569673385, 0.10365512822904896, 0.10542917335706373, 0.28255669940863887, 0.1299145078707126, 0.21804610537665509, 0.13870565791524228, 0.09883612875015506, 0.2390552086815719, 0.17911524842343024, 0.16692245349047646, 0.24912080727517608, 0.12865190304094745, 0.10801411489205015, 0.19003557131415416, 0.16031413309035764, 0.15883279483645193, 0.10835428091306841, 0.09110662335109326, 0.15914961815841738, 0.13143110149089368, 0.18421768511254943, 0.20313172180566097, 0.09322790549166741, 0.17272930802597156, 0.1842357035005285, 0.1271231056401326, 0.1421511383546937, 0.12725203057690976, 0.16397839291922509, 0.1479509295595269, 0.13126694417047885, 0.24730113395039113, 0.10910041990780062, 0.07942415788889894, 0.12423742862959063, 0.1063339998044314, 0.13759953420489066, 0.1495283199173789, 0.12402541379654601, 0.12907205630213986, 0.18785747609311537, 0.14476464730837654, 0.2722524184613459, 0.23701822685618557, 0.21314444501073132, 0.16927794403126165, 0.3248051001179603, 1.7194300457354517, 2.9673409413906837, 10.37785210917073, 16.11329278638286, 35.88731012036724, 44.207210310043834, 45.53855688341203, 52.73519615973196, 61.898998214352524, 65.80045823127993, 70.22288353212419, 62.89551165796096, 48.40611542424848, 41.28377760610273, 31.350561457295573, 14.870566283502887, 9.935821583194118, 6.1483049488836725, 4.60515970183957, 4.449438664220995, 3.434789896972718, 3.1789648244457864, 7.332631282268032, 11.138173168705357, 12.902911247745639, 22.03254553579515, 23.664861456040416, 26.207996837554443, 24.422833996434367, 16.518889396421372, 7.479556895071461, 2.5526231046645873, 0.9633279856174224, 0.151960005563113, 0.19365821724697468, 0.12072427198290826, 0.14064857946528544, 0.11554591598049288, 0.15312940813601017, 0.189119559983092, 0.15880376010412173, 0.1496296733497612, 0.11616391910900993, 0.1397694016416227, 0.1405781453415271, 0.12050566879371483, 0.1985618234762261, 0.10165288849102874, 0.09685930014858324, 0.13891617887683455, 0.10345185445922037, 0.11095124236758679, 0.11231096416351297, 0.13797982025050348, 0.2215117339285151, 0.13217296571500842, 0.19024598502343704, 0.19402423873543742, 0.13402502923723192, 0.08889328808553758, 0.10790548362438718, 0.1961225842035586, 0.16094571129689295, 0.10476895112303958, 0.10327704085577881, 0.18097668886184695, 0.15245810060972168, 0.13174576444491265, 0.12145960913790811, 0.17999482461281363, 0.12767943102986584, 0.06713190176073583, 0.2025107768995147, 0.15353920388846629, 0.11845826817255829, 0.19082444269330273, 0.1474239223546559, 0.18479592827779634, 0.11384100262676516, 0.17471246451379793, 0.11439588777120076, 0.16024621173499093, 0.11007642358421318, 0.1773242421087719, 0.1919937380138905, 0.16442943484552447, 0.07828339168261136, 0.2512143723546498, 0.18092886965361335, 0.11645401362329723, 0.25232584335871283, 0.2746464738682393, 0.23569978953849888, 0.2297251311040694, 0.27970492178874634, 0.238865555955037, 0.15135096566331002, 0.19838366206855546, 0.2587184027558373, 0.32571944137734754, 0.32588084078123497, 0.19440761977626433, 0.18328647459706954], [0.1250727632413468, 0.04513992680116527, 0.07541554919894665, 0.08608677094021151, 0.07844437739901966, 0.043006371932044145, 0.091996212309647, 0.061589443320108045, 0.05243523271694299, 0.03948289991146134, 0.04169516265392304, 0.019087672436369524, 0.029953970806673173, 0.0691408830724897, 0.05852431787418262, 0.07077976730802367, 0.03701996170885621, 0.019238340863657576, 0.03376541719321282, 0.04410240626443298, 0.019488840123578426, 0.006528630976625268, 0.021998806548635327, 0.006655622499003526, 0.037885962820221344, 0.031887955941079606, 0.009843944459252301, 0.0185177470707605, 0.021555042457616618, 0.04133920756078536, 0.08259560867783525, 0.004616619637911959, 0.03588848431865054, 0.0508703870488511, 0.03303355041650995, 0.010008925324185722, 0.052295862171318264, 0.05432098112519711, 0.025903855472983375, 0.04488836267902967, 0.025368976714690367, 0.07874596323217116, 0.058013697290011955, 0.036116625302501267, 0.04167466980194853, 0.049486502839793126, 0.05739583971820051, 0.026963690235730142, 0.03400985286721299, 0.0593887523357426, 0.06077728286806134, 0.03935464147117831, 0.039261596262334816, 0.0303293175003942, 0.05248595922884922, 0.01760275655185744, 0.036112936589145855, 0.056301153700558416, 0.03680600867336316, 0.05190480492949005, 0.03420012995540615, 0.012397811552810093, 0.02047269811643468, 0.034350244884168914, 0.02307479236004574, 0.05098337735680323, 0.03956705083950393, 0.06414182611831254, 0.09193479504075744, 0.25873890326869103, 1.7996997578490166, 4.961633038136267, 10.838948295962426, 14.532293235102008, 29.719488928394934, 49.925480811826645, 58.607019609020604, 68.31159883929838, 82.86733411973523, 72.88731036647674, 68.99848430387436, 71.54569502799743, 83.57118775767665, 76.27700697991156, 79.30678690633466, 72.85360151721586, 64.82117183746831, 58.27221785822223, 43.7376319977545, 33.93294211356871, 25.244699985750263, 22.463457122925792, 22.303644072624948, 25.079891797034975, 28.99670985437209, 35.94394914565548, 46.20824667715257, 45.34786301274454, 54.12408390352803, 57.79784640958233, 52.79228625759002, 57.82760150970952, 52.1035925803646, 31.19689476105475, 13.36750618873104, 4.355861698427509, 0.9663106416982989, 0.19081662859647505, 0.10790127780168288, 0.10820524616827888, 0.03585774887112841, 0.05148859319066809, 0.057017656583939834, 0.04521647813699899, 0.051196250208323045, 0.018430110442662434, 0.04064182623199398, 0.06333067690232588, 0.02862849697140196, 0.10248089930222881, 0.03329224298678098, 0.04277263084546693, 0.015788927520324868, 0.07692903250215516, 0.03459029470480258, 0.043725268840188944, 0.06357975123870759, 0.03761225492663441, 0.012856657999838072, 0.016963718564159447, 0.07654817189059912, 0.03885399535178177, 0.027852061114484267, 0.052216043470487486, 0.03708839251269256, 0.018093828487420277, 0.034070415948066986, 0.04509832439643722, 0.08179973525505874, 0.03481928604624925, 0.04653219201211487, 0.01752096134418201, 0.06280354329294736, 0.05163656690368249, 0.05258136015805987, 0.022278545469406153, 0.014526035407588128, 0.03831939621558113, 0.04272974141302609, 0.05507484994708531, 0.01767836368432449, 0.029796999390988104, 0.04184708938062672, 0.0387694537188978, 0.0309068979995866, 0.03643472799130025, 0.04626242564089837, 0.06885693258335514, 0.043597845435743375, 0.04246259506251063, 0.02731967214194517, 0.03843290363288215, 0.10337961236796073, 0.08119809576460431, 0.07907981668869335, 0.02429684815597871, 0.018941489453878135, 0.04570120494932898, 0.04238068877208618, 0.033701307125269406, 0.05847580918681718, 0.011731851320233078, 0.03631676194227992, 0.03491530367623895, 0.07672480878330047, 0.031746781258393204, 0.0753245302926629, 0.0950889475643635, 0.09965825600609665, 0.0795208688284601, 0.07270486199206884, 0.1535743366806738, 0.08860416650291413, 0.04381209724552689, 0.0883285970156712, 0.02366120585300509, 0.08596061924172026, 0.0788667599760717, 0.04877640445145869, 0.028488255000763366, 0.04345088295878903, 0.05859291338692269, 0.035975059914973476, 0.01431072831168891, 0.061121501494199044, 0.019957599748346596, 0.0007160639987916747, 0.032868040950908776, 0.05609568508882677, 0.04170532481023862, 0.010824004571223933, 0.019338566231571378, 0.055652231263417395, 0.056890072301030166, 0.0723010570471806, 0.015100769890141825, 0.02484646644593487, 0.012537786350285095, 0.09957831473119798, 0.050219905622784174, 0.05094137275591493, 0.0588622852228582, 0.06061001140023432, 0.019052907366365678, 0.033618504511973554, 0.04013428532127892, 0.02613227416370665, 0.012476128721309286, 0.06844875327641926, 0.022114349844595118, 0.007111183865251201, 0.07873005158598385, 0.04575612962306027, 0.026035658985136018, 0.045168157141175, 0.03216535063280213, 0.043487279796071594, 0.029914404280603896, 0.051908528116802057, 0.08255289161517736, 0.0473698248876439, 0.030304176409939126, 0.026646656239585533, 0.02370629204256881, 0.029912956374427004, 0.06178876407624734, 0.01383689431203229, 0.07622570250063174, 0.049421036796223734, 0.060503969509755416, 0.02732051100822226, 0.04396015139777334, 0.02851588013131292, 0.13447913551522842, 0.1281138488482083, 1.0858546173380268, 3.848585486412049, 9.506062192301597, 17.584791529563166, 21.852212605937837, 41.977225195977, 61.866654349911606, 73.85241739211544, 79.2333758261896, 95.85824766466695, 84.4250955889302, 86.08142622055547, 85.3726617751583, 93.7704720035676, 85.76525965044576, 90.1782791076168, 84.07344725824173, 77.87089347839355, 69.75015163421631, 53.22511588373492, 40.49094107843215, 31.142809198748683, 29.473577891626668, 28.62197445284936, 31.027283630063458, 36.55261862662531, 42.946329116821296, 54.62462540595762, 54.819657418035696, 63.25724047999229, 70.01488024188627, 63.33287554402506, 68.81906724745228, 62.01859912564678, 41.5430345073823, 21.021617381803452, 7.270462695629367, 1.5485669432147857, 0.32012577378942125, 0.03104813779974657, 0.05624454746383333, 0.09804242335620428, 0.05049412679528037, 0.04885111334583452, 0.016132516996754755, 0.006763200395770612, 0.0023390816556545157, 0.012820519717229951, 0.05155727680351946, 0.00775276143441818, 0.029202628159715287, 0.021415972601502173, 0.05387915906706645, 0.011698118553707197, 0.04342127749095521, 0.06051058467898158, 0.026066402093537396, 0.030505510062099467, 0.04856745780055081, 0.06270261886980265, 0.0129820330766961, 0.15472074129408406, 0.01581551460173702, 0.10003956094864877, 0.027246803773807424, 0.10285810567438604, 0.07072672338014649, 0.036862404235909065, 0.0660387862233385, 0.01452933628893187, 0.03884528110164308, 0.07760644574920017, 0.03947805440534027, 0.04318550244093903, 0.028361683869133555, 0.0638234284856627, 0.052105205869602586, 0.02411086499060114, 0.027067895430410584, 0.04985067805635834, 0.01973044127225876, 0.05182592851680614, 0.04377084341080439, 0.02860558519680654, 0.039133268874138594, 0.05918023469407232, 0.03331097000609002, 0.012552719319149131, 0.042993302472055926, 0.07206483383572872, 0.048105755760785074, 0.09841917007560692, 0.030503818923006618, 0.15948547110442193, 0.07547721927685123, 0.05986275008669304, 0.06914943261372467, 0.0333308499877251, 0.03704473316188782, 0.026069441547376976, 0.035969264459826296, 0.06432024416543784, 0.015810206570031664, 0.04063460202286801, 0.06572829078762762, 0.004386107611935586, 0.03618296468630433, 0.2346168323269775, 0.1531717881199814, 0.20539820825140323, 0.18540515203870114, 0.2807628585686607, 0.2291113108156189, 0.34290953509269223, 0.19300189440048512, 0.20341854512451157, 0.21005737114577525, 0.2550203278059921, 0.13843152101241774, 0.13668120928829716, 0.16632305097676095, 0.12077731591078544, 0.22400182611759634, 0.08531218710085077, 0.19128006582538928, 0.2041157157791238, 0.1230635061379402, 0.08184183944737719, 0.14471911104215732, 0.11457217226345694, 0.18523072914010097, 0.1098737397020863, 0.06848213172728015, 0.10776001118844557, 0.21362965445845358, 0.17167578391250105, 0.1315771791362955, 0.08303946469940486, 0.1895112300952596, 0.2153416004993262, 0.15706170680782489, 0.15417070548620918, 0.1876829152986888, 0.11702393707368644, 0.11062942415235505, 0.11509760132720394, 0.1888772004073666, 0.08796973844930049, 0.2036514971405268, 0.1564410836586068, 0.1181184009258305, 0.12388578661146665, 0.19257460119983844, 0.13532160240555965, 0.1058527433703984, 0.07824131047293063, 0.15354861144817647, 0.2577854915251655, 0.10668993957581059, 0.15988163049182585, 0.1028095433608659, 0.2267071890134004, 0.10731820828251301, 0.13942533623306982, 0.10553411208093168, 0.13876362012759333, 0.18265261344851988, 0.14225241517828358, 0.1388903617137863, 0.08553297364062841, 0.14867183361803332, 0.1723134755006721, 0.2158410591824401, 0.14422473918286063, 0.2411466133930991, 0.40392724316447015, 1.3685034311586812, 4.421499621483588, 9.896835184866383, 19.843533500548332, 26.36031423845599, 48.72255656027025, 73.40936999167167, 84.00187969207764, 91.24733678756222, 105.04076726974981, 96.13325288218837, 98.50591813364338, 99.3909852735458, 109.2725810697002, 98.41654300689699, 99.77844484390752, 95.04189260544317, 89.45313484438005, 81.77932354711717, 61.40196331085698, 48.632173384389574, 37.655655799373505, 37.90105496683429, 35.511484299936605, 37.3734647996964, 45.926608731669766, 51.58017581509006, 63.33909642311835, 67.34507976039764, 73.37506494214459, 81.07829401569983, 75.5066534780687, 79.10902884698685, 73.22814080022997, 48.264200149043916, 25.097032554687996, 9.617342775867833, 2.4355089760595754, 0.4873867002466033, 0.1218458476866926, 0.1376644524955942, 0.1746790630802993, 0.08614544561433216, 0.21333294860537977, 0.1171975325973284, 0.16674628391140894, 0.07096367437512645, 0.14129891150420712, 0.13876824729865597, 0.07707519441722863, 0.16930969071484384, 0.14887169063571962, 0.11340578807698143, 0.14523648086094088, 0.17522595792768464, 0.11894803584343004, 0.1574160377945631, 0.13039099923785658, 0.2328870057939522, 0.1669129233566984, 0.12329882536564143, 0.16756319410858617, 0.16052650798472667, 0.2091314619587314, 0.15876248328676149, 0.13401925293428285, 0.17336727540579536, 0.12278703266694663, 0.12891545260865844, 0.14625395287669476, 0.11479208546300089, 0.1294742371406286, 0.12334498216307933, 0.16327670234585964, 0.1423228952673174, 0.1416116592384154, 0.07250745645574025, 0.10450377744892914, 0.16346160532726398, 0.11890332695216903, 0.10082983426869878, 0.21021291763792116, 0.10099247473502353, 0.1453249486944368, 0.11385106902209022, 0.16180708523719542, 0.09017678413299784, 0.13684159745612454, 0.1606648941073687, 0.250390536722637, 0.10014042408475954, 0.18434369125433508, 0.1394415466535476, 0.3162846395805959, 0.1672601450474993, 0.18104821083045777, 0.2110573150698216, 0.14643383032131582, 0.15633073635399342, 0.11807749183067393, 0.1620020699356833, 0.13348220997760374, 0.09026904410171895, 0.1446820630301391, 0.14686213475802254, 0.156330123483654, 0.11277725890038476], [0.002534653608416838, 0.010573372203526239, 0.036818706580708106, 0.021948759939761895, 0.04194850410004297, 0.13110929859742043, 0.011509007834378752, 0.037241169596992196, 0.015312191005045129, 0.04448111416892179, 0.01590874271407243, 0.04219465198055391, 0.014899038829870764, 0.03101804203564121, 0.05634751734173587, 0.015934665214210268, 0.0839552921693652, 0.025126778017429095, 0.08687293802898738, 0.041871148371888746, 0.10800198772020879, 0.02755606963839983, 0.021697747400931774, 0.022944417601871877, 0.019172995478936264, 0.04591793505354755, 0.05209682869815058, 0.004808755446931407, 0.009826753446231446, 0.015221423950166473, 0.0924780433096232, 0.015802448972188417, 0.07365513277510483, 0.052320204615112276, 0.015430529564318639, 0.015220688505759163, 0.054568530946609475, 0.03500130087617905, 0.05212145076403695, 0.04526403687533833, 0.0075763476648247775, 0.019286158156671354, 0.027830087797596093, 0.05942417241092171, 0.03754999879146776, 0.04908625254287355, 0.055714858951227325, 0.03076428690204217, 0.010128573893809752, 0.03250058687802765, 0.06759733081825318, 0.034785478586150755, 0.03435044406702922, 0.042839698012798064, 0.05534515641028843, 0.07984978867874992, 0.01850428307549127, 0.014018118156180268, 0.020303859998802506, 0.09656815609383969, 0.060171602263806336, 0.04043443857001201, 0.03146619964090567, 0.15858714108265218, 0.04228364458427795, 0.22537306221502446, 0.44095879961406037, 3.4931356435821903, 8.735111509599994, 16.100210701265645, 26.36770006149046, 51.18354182089529, 59.47199636890043, 68.05177319434382, 71.42829064399966, 76.2633571317119, 78.43501660131639, 75.03429028295702, 78.89944876393965, 78.22358515954788, 81.26262187957764, 78.28284432811122, 71.75216859386813, 69.93443242965206, 72.71948783628403, 68.47424384086364, 70.66680954348656, 72.82561148366621, 75.67977905273438, 63.663590185103885, 69.60135259935933, 69.39258836930799, 70.4469685400686, 71.93259762179467, 65.56983463225826, 75.20215203685146, 72.15973423373315, 64.94269863251718, 72.8250466623614, 73.80284647787772, 68.4321254299533, 74.67325964281636, 71.81438522954141, 67.0703177298269, 59.45503996264551, 40.83873764161141, 14.595185499037466, 6.441169698392192, 1.9225137031847432, 0.5699151766396339, 0.10270133344156128, 0.034216439967314084, 0.10302374920537395, 0.04745727382420052, 0.04005928914393148, 0.062211414784072876, 0.030367349935395103, 0.023712832518222354, 0.03245971991770691, 0.05981761984707368, 0.012118188502837815, 0.029304391449137084, 0.0172457174443069, 0.026175958412368933, 0.002499245263959071, 0.04704770406768207, 0.011185229391670756, 0.060921847489812685, 0.03475049518108849, 0.016127435918596965, 0.04260753889778449, 0.03115062121181719, 0.07763266893884829, 0.04910636235088591, 0.04497255957234771, 0.056847868517281554, 0.0103068032917837, 0.02532115750645678, 0.026483353107206287, 0.03358428719483557, 0.021401286695993716, 0.04507508128881455, 0.033016868851958744, 0.07452406800321995, 0.05817526906368233, 0.010607759017617473, 0.07460641479420085, 0.03404401655819628, 0.03131752304222075, 0.03745366323498949, 0.04875824433721362, 0.03950574082292376, 0.025461943399521614, 0.06471439640248014, 0.0338230614790753, 0.10742847897833395, 0.06755575522660248, 0.07129493079358531, 0.04086924326275626, 0.012697999275499776, 0.0691655817471685, 0.03434174896908864, 0.0024718875459755862, 0.056965413217943524, 0.03180036144781738, 0.03858583393476663, 0.04805458108744314, 0.028847893061597022, 0.033897027268164584, 0.03225503271565803, 0.028455535385517344, 0.013468873334087193, 0.03735741960906214, 0.056125612313588785, 0.027861677433153795, 0.061292074800979715, 0.019929951635159312, 0.027663480911043384, 0.015363876084466616, 0.04972092191418333, 0.021961409966611577, 0.02855595419063203, 0.06460026462352084, 0.06936215990853888, 0.056433460915521275, 0.07788075119136803, 0.04835128694051697, 0.061983947957595514, 0.07144496911355565, 0.01273788947371706, 0.07439601640667647, 0.00858429002560555, 0.016093048146895824, 0.024780772491208008, 0.06324567561668736, 0.02276513579061195, 0.05906231844076707, 0.06067471901675867, 0.020432528296125033, 0.05490929068576905, 0.016266327659269015, 0.04011852689267647, 0.03567494114019698, 0.005844923359672389, 0.009989847819651327, 0.09069218510581602, 0.008304490775410688, 0.008788299239841441, 0.06734064539834377, 0.04737832080272417, 0.05971058587273283, 0.046894409874033545, 0.031158335717214696, 0.055064186003179326, 0.024905717601218534, 0.012558931334605141, 0.026594765274034395, 0.01353309735760934, 0.021149691930341146, 0.016806004043187828, 0.038996307675035737, 0.040055002881995136, 0.013602737622756152, 0.032928753418908004, 0.05245822684599027, 0.08487030758612579, 0.02296781009663978, 0.029252967797219757, 0.03816167020329064, 0.05108090418000376, 0.04527792987984516, 0.030643771695453795, 0.021583575402356444, 0.04416041827249912, 0.028081119488624316, 0.028667908364666567, 0.03306302564939664, 0.04250772530212999, 0.053693807924226414, 0.14907534744951034, 0.12278046729343554, 0.31964558987848224, 0.9760386713089483, 4.879837401451604, 13.055311999013348, 23.874578822043635, 36.76283413364042, 66.04372362936697, 72.20772051042127, 80.33082362144225, 80.78994489485218, 84.36447928028723, 87.52637247885428, 83.66687790040048, 87.35524731297647, 87.6997333957303, 87.83697712805964, 87.72797446097098, 81.84403481022005, 80.27116437112132, 79.96133635121008, 78.65173539807721, 80.28305699748378, 84.7783285571683, 87.98670968701764, 77.84198561022359, 80.44146583926293, 81.12191077201598, 80.91495083224389, 82.31398967004593, 77.48945866861652, 84.84718184317313, 80.88845914410007, 74.99379573329803, 81.29315360899895, 85.20600026653659, 80.15923561588411, 84.55672248717278, 81.47172343346381, 81.41640232455346, 72.58699801660353, 54.40140331945112, 23.650552649651807, 11.383364450547004, 2.7043261643378966, 0.7892248214733216, 0.12571561826212754, 0.10003687198003454, 0.04390764373144315, 0.054955968422995466, 0.04525491276816015, 0.06691866118701235, 0.057041826657950885, 0.023733951647074956, 0.08415927074008411, 0.04767005474516942, 0.05557566077538556, 0.0397560217477862, 0.02643876679001316, 0.012484970333565389, 0.06916310728317307, 0.04081549836442836, 0.02084203868082935, 0.06782274452909347, 0.0820114359920544, 0.016328359713717815, 0.0605139707876069, 0.0326892321989421, 0.007494511279923421, 0.06053730582578048, 0.10575917339132679, 0.04183646374111695, 0.028159091917557583, 0.061164126626306006, 0.047061072301960764, 0.04084732165680297, 0.08394088971638873, 0.024980217736635, 0.05273156701737354, 0.06854493561531268, 0.03811179021854074, 0.039001969064796166, 0.09443720592366112, 0.04535719699737045, 0.027444889213168816, 0.04742058970394635, 0.030040159528594346, 0.02861582013147493, 0.046018196810637756, 0.10112097832344233, 0.03486797859471652, 0.04837189470568011, 0.07739072305060203, 0.07321395806127018, 0.0700147365850787, 0.128262446922881, 0.06124263148634665, 0.06758809179788636, 0.039228478281368176, 0.14864756395259213, 0.04178900076376815, 0.029005869967682712, 0.015032068082702257, 0.017895260412666588, 0.01703012306543608, 0.08429005727051728, 0.028229451347743312, 0.031367780325273355, 0.042250112915832194, 0.03479110933239422, 0.04339816461827967, 0.0269391275416579, 0.13506384446255623, 0.09840231614127275, 0.08208332568286889, 0.15690959238957974, 0.1648773358113343, 0.19298176160983502, 0.26646235657315104, 0.20164549591079836, 0.15224007198647146, 0.17210174412015947, 0.1959976812283839, 0.1776136394830481, 0.14102316581674162, 0.16583433284634547, 0.2472959705177815, 0.1881739623363941, 0.1666393227154209, 0.13487768509695608, 0.24567592438430558, 0.18163858882842526, 0.30669704920822577, 0.1558288568330388, 0.09676563057808146, 0.1370558722485458, 0.09895393775115091, 0.22194150925403644, 0.0910396213012357, 0.10685654071670388, 0.10982723050420323, 0.2273437008261681, 0.15508826431487838, 0.20303179329681784, 0.14187646519032218, 0.1871529203509131, 0.12448254612184341, 0.08013748533783421, 0.2292292883559581, 0.21674153425039785, 0.1162677010401122, 0.16029907180176628, 0.07089845731013245, 0.09266477724116656, 0.13335081057683115, 0.11995488988055338, 0.1347260609749825, 0.11883714461639044, 0.0907980967613478, 0.10845025640822227, 0.1487336262700058, 0.1446110466795583, 0.1478530848098378, 0.17412585566841787, 0.1161925861191365, 0.1258016805795412, 0.24347653191897178, 0.11565404163012583, 0.11331016498227274, 0.13104741401489706, 0.15905140568652462, 0.137156245088385, 0.12995423719046578, 0.16778502252794084, 0.15999848954379559, 0.22815261306541584, 0.18635142384277237, 0.6053276828700497, 1.4283005773059785, 6.35712948537642, 15.724538833864274, 26.579625721900697, 43.406744772388095, 74.89449701001568, 84.66029659394296, 90.6914584867416, 94.02014655451622, 97.01249922475508, 100.50650735055247, 96.7214201342675, 101.13047799756451, 99.75887221674766, 99.4579872008293, 99.77337714164489, 93.1553109999626, 93.50025992239676, 93.74934611781951, 89.33698561883743, 91.95008431711506, 96.1861264321112, 100.6670734959264, 90.16294264024305, 90.73523213786464, 92.06077360337781, 93.91556832098192, 93.78938567253851, 87.95369901964742, 99.9810823317497, 94.30654233501804, 86.98104535379719, 94.99396124193746, 98.55497129501836, 93.183363791435, 96.08751804597917, 92.0057741288216, 91.25572281499063, 83.64422229028519, 62.76478690485801, 29.196301621775476, 13.50439396596724, 3.7544907677558164, 1.0599929599031326, 0.23092177576355397, 0.20166147650489885, 0.21409735113622683, 0.13182710766071273, 0.11845260678279786, 0.1433325531862436, 0.15313411191586526, 0.058244638325225924, 0.213116038470499, 0.13512598951497387, 0.10527278416820111, 0.1880444015466398, 0.09319752244459045, 0.07027851597916696, 0.10036970653961744, 0.13853348731513948, 0.0939771701251307, 0.1470094381441032, 0.1470811746173328, 0.11089637515044982, 0.13395896181464195, 0.1403184568569545, 0.1173161919559202, 0.10914130602031948, 0.13619020821586733, 0.15108032212142022, 0.15114556216905195, 0.10003882550424147, 0.17309180550998257, 0.15220863173805899, 0.12396553636438425, 0.09536464728655354, 0.10979667125690369, 0.09353116905737309, 0.09015120445720612, 0.07838685951766469, 0.166258056077265, 0.20789557827576516, 0.15188126704625546, 0.1213115779682994, 0.36923348062461425, 0.1705484855319223, 0.12713445140229118, 0.3228148343341966, 0.17639050350314187, 0.2433421447752945, 0.1555992143168565, 0.19038060199349158, 0.15940889295551086, 0.20866482248229368, 0.1542478658619427, 0.21513742274574696, 0.146129678093618, 0.2637884645692764, 0.11543246601978618, 0.08322140292054223, 0.11193748863954699, 0.07706664487599366, 0.1526497298431012, 0.16517653911104127, 0.1092625470952161, 0.18510288438729702, 0.1274574264102886, 0.09286877879452321, 0.1381350296639627, 0.12634574856248595], [0.02129449786978864, 0.04182103473032194, 0.030012430976175015, 0.03480082332727409, 0.06451761139737022, 0.05537336376766044, 0.02296452166422481, 0.09724922358028351, 0.03402761461573743, 0.05431444256476337, 0.03646242973064223, 0.09055012176113744, 0.02851763830309914, 0.0154464689811932, 0.006918677461198381, 0.05149308246590438, 0.017904951424908735, 0.009313445808666368, 0.051367846242482626, 0.07218897838385836, 0.05589801142172468, 0.041840803629208, 0.03333071592233835, 0.034478572272365136, 0.014727877550608209, 0.08744072409406786, 0.03821565258887507, 0.02366231476527549, 0.03450907023263074, 0.028771939274344235, 0.06953515022272064, 0.08550729437340653, 0.0780736597915811, 0.030418555252254013, 0.03546843447932794, 0.03294771792547357, 0.007195474125535018, 0.04829943810980167, 0.04141409648582339, 0.07727540383536009, 0.03881113273241828, 0.030155451930758935, 0.028952889242059285, 0.01780505164436275, 0.03731044692798488, 0.05604337277491728, 0.06037034079312317, 0.04292833821607694, 0.018677744533746474, 0.014717975864186885, 0.060145524630863825, 0.04199068107071423, 0.017150328006415118, 0.03868011254516821, 0.027159475496098883, 0.007950995782119854, 0.07658953297763102, 0.09198843651721555, 0.06374201632194942, 0.2817621436570921, 0.5087503490428771, 0.2424090496835209, 0.5428299235720788, 1.548748720557459, 3.5000147454200254, 5.280421712706167, 14.53211182548154, 23.15265678590344, 45.37515878677369, 66.43175586577385, 77.52938839697069, 77.98227310180664, 75.63704090733683, 68.68104688582882, 70.73359966278076, 61.51799094292426, 67.14126556150376, 55.66204917046332, 56.829942734010764, 51.491985244135705, 51.831572286544315, 50.21708549991731, 54.566625318219586, 46.204300772759225, 42.62171376136042, 43.16254192782987, 55.43017433535669, 52.97590025009648, 60.975484002021055, 74.90751927898776, 70.20134971987817, 74.31331942158361, 65.06841451891007, 69.39487903348862, 71.2952595372354, 73.24495992352887, 62.28758742732387, 57.65209505634924, 59.53305590537287, 60.106275004725305, 57.497549749189815, 57.4409774041945, 58.604466146038426, 69.28203244363108, 80.0441611197687, 73.4068988984631, 66.56794840289702, 47.94757466162405, 19.920031486019013, 8.742828772914025, 2.894253701932969, 0.9225710661661242, 0.19191067876114, 0.11787833195299872, 0.013107134277121195, 0.03902435032350402, 0.09273357193676696, 0.03241378528576705, 0.046088856930333766, 0.033051373452068336, 0.07745496718393219, 0.03330855682912854, 0.02207512422765215, 0.031550241401419044, 0.034907141009405736, 0.019744770946882425, 0.05260187216223248, 0.04553366152028884, 0.03373343685281373, 0.03617245779042283, 0.05484004782873297, 0.039208648095448176, 0.04849030891613615, 0.02775944491487838, 0.028787891140147567, 0.052359336386284525, 0.018281294032931328, 0.015044757371558058, 0.05660047957433328, 0.028814436086723884, 0.013114503085342868, 0.06150382916413008, 0.03061900790330143, 0.016505245584994555, 0.044908319269457174, 0.029065398829838926, 0.050309806040698485, 0.056282035976408, 0.08827261897104402, 0.06337800198384831, 0.05026598198099002, 0.027189745545207013, 0.05661795787032574, 0.034321014799417994, 0.04924228550085137, 0.04880970629352716, 0.08800250402982197, 0.02815830859265501, 0.06131392745901981, 0.053688380191282886, 0.018556524526267763, 0.022287008825749643, 0.08767489418988267, 0.10551910441849502, 0.037528831782119895, 0.12710564649633824, 0.0019048527258658603, 0.007582326023463881, 0.02363842239813699, 0.041187633234526844, 0.01015663282164643, 0.05894603012430091, 0.022027241817164808, 0.07561888425580918, 0.0033886194784915257, 0.03875822286992785, 0.023499565131421533, 0.06760335226933803, 0.04443371630904656, 0.09926333768113006, 0.06654391395709207, 0.04036010505871908, 0.043518919227344376, 0.018125259159733693, 0.03203972753497862, 0.015689649228607456, 0.0712155334411129, 0.13289019255147827, 0.03399338197684096, 0.06264796232684486, 0.005803574721569256, 0.035898531561777476, 0.037784080787171284, 0.006275525102542053, 0.09408615379323883, 0.09762986202634151, 0.08804041006031536, 0.021592147926229145, 0.09131691448630826, 0.015554738272311948, 0.04762922991968451, 0.034704303909694, 0.015970611017227413, 0.03943613407412364, 0.034267821484395576, 0.005122447863311297, 0.03633769529481088, 0.07903935192453285, 0.05550456015513309, 0.0014900857809885977, 0.02386307193627281, 0.03248505061492324, 0.033846641665384654, 0.04523592910939648, 0.015534069220114861, 0.02735847641052979, 0.06026357494955582, 0.07920405316737392, 0.060783032357933066, 0.017514828810348146, 0.022696373653748346, 0.030635976750824242, 0.028507474231563752, 0.03807530528114688, 0.015562416388533049, 0.09204785429662274, 0.02076556203856824, 0.03638442282775237, 0.04013693598549693, 0.09764710666551706, 0.07621597318399338, 0.05593117536796678, 0.037777611174650734, 0.12163914950384248, 0.12939753641764964, 0.2024820945676296, 0.654047504067421, 0.29972092999565986, 0.8299574712591787, 2.701366736042884, 5.334045415924442, 8.609449555796962, 22.225447700869655, 32.931396269029186, 58.531992512364546, 79.83666773765319, 88.94855330067297, 84.48254262247394, 86.25267690227878, 75.48114238246795, 80.03380606251379, 69.68511873675932, 77.53536608911331, 64.04840215559929, 64.80362315331736, 62.32921946433283, 60.19877233812886, 62.53089204911263, 63.98350261872815, 58.41585113156227, 53.10323215300038, 51.11606528682094, 65.7171235545989, 65.97993020088443, 71.34964712204473, 85.76411431835544, 80.2033858145437, 84.0075122156451, 75.57107448577881, 77.1905662167457, 79.37172566690754, 82.88056819669663, 72.30000603583552, 68.17514742574384, 68.69514388422813, 70.55098979703843, 65.81565349332749, 66.69500966225901, 67.43754571483981, 76.47178403792843, 86.39196811183807, 82.10535095584008, 79.85286712646484, 60.68129447198684, 28.783876165266964, 14.03282646209963, 3.991043764737345, 1.075707690850381, 0.4168435468548729, 0.09590720607628746, 0.07398794435204999, 0.056339255083472504, 0.0747714531157286, 0.060549501945535024, 0.040300250609195044, 0.10540868050508923, 0.032152587607983625, 0.06435219003188034, 0.03750497197371818, 0.06509779276506555, 0.07770162451291278, 0.10904800417202135, 0.04769697507482864, 0.0700273004270369, 0.02321180910052311, 0.1135472615339583, 0.053565844427794225, 0.10085267134972158, 0.04535571844767659, 0.04969133559854762, 0.03266108229816441, 0.012941833570479386, 0.07045927442490094, 0.01721495709892723, 0.05364072952239264, 0.054159551077792724, 0.06458952407082243, 0.0726059370584065, 0.01645087440978856, 0.09355897038814523, 0.05732474292838766, 0.07647780671475396, 0.037200034505897955, 0.058407952948924036, 0.07273573533541734, 0.10187139208879202, 0.018032424625069383, 0.05794898584304799, 0.041271810975646785, 0.1094447074818515, 0.023171313692845648, 0.04726698524468849, 0.04889743102173652, 0.08834388813063984, 0.035465132640374285, 0.025012797540834835, 0.021459405956369255, 0.04570286352968505, 0.0615385712514962, 0.02986994245269847, 0.08054590213202661, 0.06111319327066022, 0.006981037497039765, 0.06334595652597566, 0.028098530751923402, 0.03350031246701556, 0.004768455391674633, 0.039388353170286265, 0.05251957899740627, 0.05855668125854385, 0.003396761556711769, 0.054004510203676845, 0.12463247718950435, 0.1675092768404753, 0.21705596737803953, 0.21539640642942923, 0.17161308727677793, 0.2165170245233082, 0.12839998268792707, 0.17942729135674818, 0.15165695650202615, 0.13729024918810015, 0.17089852642628456, 0.25264248281957646, 0.10504521008941436, 0.13769613789214244, 0.1018502327403234, 0.17696847087673603, 0.11435602821650044, 0.08103412996617057, 0.17572328688636904, 0.20336658904148688, 0.3276452332014038, 0.14258164912462234, 0.2218123774735197, 0.21500617656255924, 0.2988305213230272, 0.22869530975097613, 0.14545149109776945, 0.07943214052506993, 0.15333580754456982, 0.08343091264607445, 0.1505951586389734, 0.22298715798364532, 0.21313610997411514, 0.13018285314882957, 0.16142056323587894, 0.12028139655388172, 0.10038846037200383, 0.10716714340472415, 0.21793445572257045, 0.18197015168205385, 0.1781577917356645, 0.18915018817830473, 0.15094251822560065, 0.10380125183972622, 0.21403778013923477, 0.11235119144041693, 0.08363476098184625, 0.16693239731173362, 0.1371526597968994, 0.1570263441892401, 0.11493568098352802, 0.1164474405889069, 0.1876293657527816, 0.18268794542358768, 0.13246326707303524, 0.21902944051450302, 0.16912609008291077, 0.36398807660706584, 0.48097773124614074, 0.4060662219360952, 1.1510305587322482, 1.0430844801087533, 1.3713382016266547, 4.150040716894211, 7.5577081595697715, 11.71524795793718, 28.021669426271995, 40.81776865067021, 66.11001953001946, 88.6477388874177, 99.50504779815675, 97.9916718698317, 100.65048187009751, 91.34159134280299, 90.39547643353863, 83.5230367414413, 86.96584224700929, 77.8548352949081, 77.01973915100098, 74.08402550605037, 74.77475489339521, 73.49050029631584, 75.0728864054526, 67.28862116413733, 60.64262382445797, 62.404674099337676, 74.44905696376678, 76.03706775173065, 82.0783572043142, 96.7494180125575, 92.23395409122591, 95.83763168704127, 85.12180266841766, 91.20998797878143, 91.57048517657866, 93.27844988915228, 81.48902893066406, 80.27520441239881, 80.44476063020768, 81.25754633257466, 78.80545308513027, 77.2812984835717, 79.19670166507845, 88.88796052625104, 97.82520647971862, 94.34729576110841, 89.1579294204712, 69.5331661162838, 34.27301945224885, 15.347972666063617, 5.160945336664877, 1.4090846406836666, 0.4918867313573438, 0.20525303458975208, 0.12290877935987328, 0.08983858695794499, 0.2870502953808154, 0.08547265187747057, 0.20159396883701125, 0.23018651521734654, 0.07670944872041864, 0.13745898771430218, 0.13451615288372964, 0.2352999682508169, 0.14456396291573204, 0.10474315694262905, 0.15597252896235836, 0.13339354296124753, 0.12777370580982778, 0.15731356587381135, 0.12117754322506728, 0.17744471709574425, 0.16659387837975256, 0.16437674331809246, 0.10727100194461885, 0.1473483094765294, 0.17461768411580594, 0.11384422785692638, 0.195597798653668, 0.1022073905915022, 0.11121975618504709, 0.14412936123628772, 0.12184598558251897, 0.10187624908623197, 0.16470352578307354, 0.22335858805285347, 0.22144572779295907, 0.22785316461757307, 0.1918690648650931, 0.3204736389940785, 0.18934278268246882, 0.1921379004394816, 0.08945934279190917, 0.17756160679123095, 0.12403785506443632, 0.15343195157906703, 0.15736136976028645, 0.17106737220479598, 0.14901891741300785, 0.1902257756239945, 0.10356325130428999, 0.15138652746475514, 0.1666218559107473, 0.26349014993156156, 0.2519953989934537, 0.32553729631247064, 0.17076150394014775, 0.12351042651120694, 0.12508631533672734, 0.1326565663780897, 0.08051245473325253, 0.11881222377621359, 0.09668981851709467, 0.14240860518428589, 0.13977280307200649, 0.23236798122525218], [0.05785741918389836, 0.03566931039395352, 0.038321836205619964, 0.03611487096115466, 0.048778737189188126, 0.10722560357422599, 0.028821644974091364, 0.04992542142469076, 0.04409541571212392, 0.03178368371370579, 0.05515618550200617, 0.008679021585492358, 0.03904037305244035, 0.030765801840912432, 0.13334094336436642, 0.0035613244249215054, 0.0062194105985033665, 0.013353790648491874, 0.03617284849526421, 0.022801157244811618, 0.0535696174108213, 0.019036457543411565, 0.016073920846646352, 0.05002366454010049, 0.06402081103935357, 0.07636130006322939, 0.0324266440715761, 0.05619915675431971, 0.03275107081619001, 0.06259871053419287, 0.013937737338335044, 0.015440727152200717, 0.01688144838197097, 0.0945654183986687, 0.06615678674631542, 0.012331944270690363, 0.03228014890825556, 0.00894137988648107, 0.08218487063723226, 0.06198832231964316, 0.003722612985462371, 0.030891200858018095, 0.03761416248556587, 0.03245405086706723, 0.008992523916306035, 0.04203702555969358, 0.07416176970206922, 0.049771629273891456, 0.0803806876102763, 0.009126474389866477, 0.07209575314435267, 0.03885349739463099, 0.05603958447013171, 0.2596235509601332, 0.18194470224120926, 0.5804947895869133, 0.880363911630646, 0.4375379718840123, 1.3339352151078563, 5.002174656237326, 8.34953075455081, 11.767431170709672, 15.05281823296701, 21.60330487835792, 26.774585170130578, 41.42115077664776, 58.27226100429412, 68.57316601660945, 72.56817063977643, 70.92852577086418, 67.2420940091533, 59.26020014670588, 58.18809870750674, 50.06334820101338, 53.67881251919655, 45.79731172130954, 39.39466214949085, 36.69511833498555, 28.187522926638206, 20.936660805056174, 37.350883714614376, 38.39558347578972, 25.81965473390395, 21.37583290376971, 24.824139533504365, 32.97957866422592, 25.54291778995145, 34.70333876148347, 48.39339517777967, 44.36958074569703, 49.6904053226594, 50.475922707588445, 53.32572075628465, 46.21108255078716, 55.4294918429467, 53.21853806895595, 39.771774507338, 36.560741855252175, 39.13306751558858, 49.87521563806842, 34.35811919550742, 45.6064413439843, 41.66194900389641, 48.90815919445407, 55.07458010027486, 69.11032676696777, 70.94849847978162, 69.79505492794898, 63.84723163420155, 45.08290690760459, 21.220705124639696, 12.317958378022718, 3.964002209324991, 0.36751453254011374, 0.2584713240784984, 0.06171390579472627, 0.05339744298027889, 0.0825164411517401, 0.017324387013251265, 0.02243526407607621, 0.036876611336464846, 0.07781507447361946, 0.05771389644172403, 0.03496230700083318, 0.06112685644878976, 0.062210679339665564, 0.04080262042642121, 0.01786001270727044, 0.059493966851263284, 0.035479006492683006, 0.00499457773384488, 0.024243467149414846, 0.06477392143419673, 0.017290801718650807, 0.055259611202223655, 0.0193722702698001, 0.05992144774345141, 0.02275249533986132, 0.009835006128395758, 0.013084571072531324, 0.08758650296517918, 0.06464151845824334, 0.02955651864589703, 0.013434714431153431, 0.01683215445448314, 0.031048800465801073, 0.03718066780317215, 0.09865485702551181, 0.12243928237547799, 0.12484864421909857, 0.04994863388879646, 0.04528606190316139, 0.03394129565886913, 0.06058140567714169, 0.04951273369032049, 0.02726971363318303, 0.039950466354287444, 0.05955146941085977, 0.027788349412261482, 0.10660879554287081, 0.0075435437799070875, 0.029350358639813723, 0.0487882903056039, 0.12344586062094859, 0.03924817057146181, 0.10581080005654406, 0.017948788891155875, 0.018079600319446578, 0.06299133442582623, 0.027574122500335498, 0.04984661779035965, 0.03858793684611878, 0.025731075832980777, 0.043287154647611806, 0.050074030990682306, 0.003314872503265619, 0.04211160421912228, 0.06660163102130737, 0.05521919623377824, 0.040932001185513316, 0.03910406560246502, 0.05700074902345097, 0.014839282056557076, 0.040495932447694005, 0.034285514285006834, 0.015257703959040586, 0.052079511280622215, 0.05719378402817154, 0.00976608598589777, 0.01958595325929984, 0.03926612767240694, 0.01365110841429522, 0.06715290023074036, 0.00815102038153958, 0.011093450143122146, 0.023916801512842218, 0.01806065879551874, 0.04711015938570903, 0.04480308560173839, 0.010324490346735524, 0.03858208393437728, 0.07866717108915891, 0.07799792433938674, 0.049527779657153354, 0.0296328095118365, 0.04433294893392632, 0.009202897405972885, 0.06478444748227635, 0.06180797756138829, 0.07030273201845347, 0.050781291023257284, 0.03352128795438236, 0.040716538956809434, 0.06879440448697537, 0.03871878466358589, 0.037102201247527715, 0.028118495003230153, 0.03500433075391958, 0.02935918205748162, 0.022165627939806833, 0.039603202528650724, 0.03359387095476832, 0.017287417525245298, 0.0792936088457223, 0.0845608999952674, 0.01723579277524785, 0.11533635262880595, 0.008754993567333348, 0.01533981230515506, 0.24582408578886142, 0.22494943091465583, 0.7642439812902482, 0.7803931760211146, 0.3924855055107225, 1.4035292162049202, 5.573329117990309, 9.141582808186932, 13.221222373747057, 19.16007814868804, 28.295221405644572, 34.000814807030466, 52.187601904715265, 72.10480536184004, 79.92281867611794, 83.36452591803767, 78.88207266407629, 74.52381733925112, 66.5771738175423, 67.46625746450117, 57.955345261481504, 62.345685574316214, 54.76396760632915, 49.45489052803286, 47.81570457643079, 40.58320306962536, 34.51694380852484, 45.3450624404415, 48.974204063415534, 38.86165911151517, 35.20929313475086, 37.49297157410653, 46.23598960138137, 36.08526822059385, 44.248877648384344, 61.996590706609915, 56.94762168392059, 60.59661049996654, 61.007553300549915, 64.89730896488314, 58.726412634695734, 65.9520499936996, 64.34177975500783, 50.26904905996015, 47.59178823040378, 51.807218290144405, 60.87938201042914, 47.634918612818566, 54.91142126821703, 52.10451825972527, 60.3515447339704, 65.49736884332472, 76.5504510941044, 77.87008547013806, 77.85809870689147, 76.8911873909735, 58.33186926380281, 31.87760445379442, 20.528328341822473, 6.201134862438326, 0.6471620896650899, 0.36177291805225037, 0.05794395264538546, 0.024549245398731965, 0.04486782769221933, 0.028708317587452552, 0.025420570821170847, 0.024906248117106098, 0.01650804180591818, 0.05323148152280239, 0.053270199606495525, 0.07544031682153864, 0.04772717043036415, 0.04074543196287367, 0.11596262950690524, 0.030006037972446893, 0.03685717185538623, 0.017971857713775772, 0.041836911902552655, 0.02156274547169526, 0.010714815974596047, 0.034599215798680825, 0.030502964734971046, 0.050751877077404535, 0.023153643874872117, 0.02468880363589814, 0.006185500195340044, 0.06081456070645683, 0.029914616870002884, 0.004445107394619095, 0.00963156477683374, 0.02924833296527786, 0.017945556000115413, 0.006780611659069696, 0.1451233909615586, 0.04293673453972705, 0.08431753684436122, 0.027118106748187737, 0.05355380918650378, 0.049140211945820245, 0.09784182323323143, 0.1107585789155095, 0.03101063588063323, 0.06286386505610521, 0.07108799512347869, 0.045423904103377176, 0.02368772207128425, 0.045944644709027586, 0.05557629662836271, 0.09474169523004564, 0.07234410352764592, 0.021131062587242455, 0.061975049846355, 0.0902605175431217, 0.02071847252908253, 0.039635251816963, 0.024593147982452667, 0.08951558896730985, 0.047146383853208636, 0.016843911988901037, 0.03003396953816616, 0.03442198901827778, 0.025997548026122877, 0.1485474056173717, 0.09706127156894054, 0.18966441703659875, 0.11233773127558733, 0.13093076946754612, 0.15198966848754114, 0.14074737416400065, 0.10196405808411299, 0.24162612314666473, 0.16657846469071605, 0.14811954551166104, 0.18128333853617792, 0.15035172654015405, 0.07790151983499527, 0.2299085938401761, 0.14984203292237175, 0.1132504331068166, 0.09488555122046702, 0.14377797202717874, 0.15469118562196532, 0.11184438597410919, 0.1885914342898515, 0.13012410952679573, 0.19371694554725002, 0.23831630155684488, 0.11799108477369433, 0.14267685853185194, 0.21414480262225677, 0.07073662889700744, 0.20028978075471618, 0.10934418908530667, 0.1100145543234483, 0.15185436203835473, 0.1611019625899292, 0.4411839068897309, 0.14485674639863355, 0.14809642497810627, 0.1840427872394362, 0.13250382376774666, 0.24175438158694776, 0.12275742336867318, 0.1859022971362837, 0.12479577649144397, 0.10797912765654827, 0.13694880380024835, 0.15811483255557476, 0.21625647802026043, 0.18026470206677916, 0.19150477473533925, 0.10238608059984061, 0.24409174648744447, 0.0763991754502058, 0.14146803307437128, 0.40790140088046756, 0.35638814731951685, 0.8435986167000187, 1.3245423642858383, 1.2384876464643788, 2.7995946522681945, 7.53366255952466, 12.16279725874624, 16.220154819949983, 24.797891032311227, 35.97030355084327, 40.82914352416992, 62.37191446365849, 81.76139831542969, 92.32650633781188, 96.4420924648162, 90.90199562811083, 84.49269371647989, 82.15372946954544, 77.94752090207993, 69.28386811287173, 72.01976837650423, 64.60057381660708, 57.71051483769571, 54.135878470636186, 45.18056215778474, 38.361721654092115, 56.24191276488766, 54.08324026292371, 40.40293093650572, 38.17621315679243, 43.031656357549856, 50.006222801823775, 42.86260612549321, 53.194945012369466, 67.15791210051506, 66.52688903193321, 69.27393667159542, 70.67980043349728, 74.18982751907842, 66.28945227592223, 77.24596577305948, 73.58019705741637, 60.93065131095148, 55.82281927908621, 58.46128394526821, 69.15408472861014, 56.81355114906066, 64.71738200033865, 60.62502414949479, 68.6916059063327, 74.57887172698975, 88.43500521875198, 87.90055874855288, 90.56231837118827, 87.85752250302224, 66.90006333012735, 37.502365650669226, 22.660369911501487, 7.83578900560256, 1.545991171752253, 0.58939078642476, 0.23783703695141503, 0.14137244062317958, 0.2784210197146862, 0.13165224043111648, 0.09270780073899416, 0.10378711751752323, 0.19407438685096082, 0.15528370866612082, 0.1589094955594309, 0.14803224213181004, 0.14023352834966876, 0.12355297503452148, 0.3211431385528657, 0.19736908586515536, 0.10870034581110363, 0.07737052897291799, 0.1070136500282153, 0.19040490230244977, 0.10222782981732201, 0.16752986928387997, 0.09318849792884243, 0.14110343650944773, 0.10849901790460272, 0.11884724165523246, 0.12481325861787605, 0.21237055831138166, 0.1339896666186471, 0.19661200713486443, 0.1599356550122461, 0.1739708301160605, 0.13392269521230651, 0.11099442674387848, 0.12815534783106658, 0.27794068258616234, 0.20540444420710688, 0.1956784830338532, 0.24492563319302377, 0.15568195181267877, 0.2530825543668001, 0.1513288410440568, 0.19562746157809613, 0.12215299531817438, 0.13650384461206777, 0.10969026930510037, 0.26737657525847036, 0.20910149259913355, 0.21523879149988775, 0.17424711206507298, 0.2749001409017271, 0.17707132584144994, 0.3081366203484997, 0.1284344566445197, 0.18992614331504992, 0.17947385418078593, 0.13388626007062776, 0.18121580022477335, 0.12080282663866398, 0.13633565766917122, 0.11177394418947159, 0.16395024684888704, 0.05113039345991227], [0.02189190855490104, 0.06012823785685244, 0.07760352695420866, 0.028023465626662778, 0.0549831607138678, 0.05634896907835238, 0.013861594901930903, 0.03030538491363968, 0.03674207097520271, 0.03860553388573951, 0.04791951212551325, 0.014094549790775825, 0.042692716383645614, 0.00849287083838135, 0.017608404535079197, 0.05678435216747946, 0.02490412796877565, 0.013308087758149111, 0.011526861513454107, 0.024182151387175246, 0.060164638524574626, 0.02579828089613828, 0.04768747941500718, 0.036551970087232134, 0.028420477286882462, 0.056293481329996745, 0.01082022584253742, 0.04796234410135977, 0.027905095466262395, 0.0390593528807644, 0.07096706048375176, 0.032733573367999445, 0.00835078259584524, 0.03170594302636962, 0.05191472193766987, 0.02969994754230063, 0.04365131454241853, 0.016630642686880404, 0.05172785011030013, 0.03966028373988886, 0.08814341058173487, 0.030000660035218445, 0.0935061869301623, 0.04499297198509017, 0.06529339799477209, 0.06037141714665679, 0.046138189162217805, 0.006286778455344781, 0.055209999348247246, 0.07337009444111779, 0.01595444177397557, 0.1003870967354986, 0.1998530033855669, 1.207174139638101, 2.7307761772986385, 3.5068475142602002, 5.054362771972533, 10.204484328146904, 17.359912241658858, 21.30085091437063, 23.886893103199622, 28.56602184234127, 40.92117801789315, 56.73374268316454, 57.81916841383904, 63.3352917240512, 68.46328473860218, 61.4043128105902, 53.54695812348397, 43.07605758790047, 39.353124249366026, 33.7711835676624, 39.363859776527654, 34.26554733707059, 27.57925548861104, 24.667887995319983, 20.59520083089029, 23.275199474826938, 15.433722542178248, 22.502127770454656, 17.879483122979444, 24.048728135324296, 26.87793177943076, 14.491144630216784, 15.988932078884496, 16.88232837184783, 18.397920439320227, 25.410092607621227, 13.719191781936155, 18.78349531081415, 24.982993564298077, 27.75691140082575, 19.140409423458962, 30.90601375026088, 33.92821957988124, 34.83054514854185, 36.41398637525497, 45.19924440691548, 30.576952388209683, 28.49178118090476, 23.698364380867254, 25.781913688105924, 26.640642112301244, 37.42730325268161, 54.452115643408995, 46.387322487369666, 54.90633787647371, 63.78384613221692, 72.93076238324566, 70.20420520536362, 60.58949532047395, 49.36605668837025, 28.916779795000632, 15.05684748772652, 6.483106699682052, 4.177072221232999, 1.6606849528128103, 0.7775865975887545, 0.06482276720024886, 0.013954785667480001, 0.009985877568983744, 0.060195370141657135, 0.05030178893057089, 0.059705874431998505, 0.02060162496843165, 0.02353702874613866, 0.047928915854783795, 0.07885994945442484, 0.016814785326019894, 0.01913586894290582, 0.05149911157786847, 0.057866577765033136, 0.013565651306341733, 0.07398465017397558, 0.020253842118226235, 0.06016708234505308, 0.09991222947475412, 0.05251862138750092, 0.039774220166427475, 0.06559296135580348, 0.06961824777986735, 0.01870701866855304, 0.045987285162893035, 0.10274529156665649, 0.04188792186699087, 0.06465427382218261, 0.04427632737544276, 0.05958461037446415, 0.03892783090592392, 0.05869027167077988, 0.02271204206701969, 0.05824245114420211, 0.05874432300427749, 0.007465255818510008, 0.02705751110859696, 0.052315355278551585, 0.08177350440453138, 0.03064981229873675, 0.02220773979300453, 0.0721956050444034, 0.03023032553403849, 0.01903816783470252, 0.031145995955974348, 0.023272567533797795, 0.042349757972143354, 0.02956962257984185, 0.04359297311654495, 0.050987736397092386, 0.04335307268305652, 0.02714600383995041, 0.03620797745703209, 0.04922959908482529, 0.04382953723712314, 0.04145597085176457, 0.031896938321991794, 0.035194558046397664, 0.020538215870938955, 0.04126972338605312, 0.07345077116042376, 0.046946741340141145, 0.04763092680443679, 0.029301443925848412, 0.03800742223017639, 0.02007984056798441, 0.04300542581345766, 0.022498265231749224, 0.04528641430360656, 0.032755150234386805, 0.006498744929089181, 0.05248060044381888, 0.011330272818374778, 0.041153741504756675, 0.030764669946004308, 0.007345114079784723, 0.007174671486756134, 0.04640997417511479, 0.057185341739245964, 0.053557114855897044, 0.00560935611100567, 0.014807859045122902, 0.04540862064928778, 0.025657269007135785, 0.09832782941239496, 0.05191065401079194, 0.01747028654321067, 0.09893153734024494, 0.07593528622941625, 0.03889332630581433, 0.04089697181517559, 0.04000807999663296, 0.01823051581009021, 0.04910848058399655, 0.03781331470236182, 0.031836438443391554, 0.04815372818660352, 0.020866252804896044, 0.05505384764664116, 0.04386654694474513, 0.021533886939587615, 0.1218110366514133, 0.005641471474401413, 0.019762580575902137, 0.006485368555126291, 0.030863997075826894, 0.040553086437284946, 0.025263543864111268, 0.026940209640850945, 0.08944772889897709, 0.38001380860805517, 1.6908000529773775, 3.2246959834329547, 5.015280765871848, 7.850734706847899, 13.890766059198688, 20.842229743157667, 25.803437694426506, 30.743202047963297, 38.29493937953826, 50.98602694849814, 68.30078878710347, 71.50472194917741, 75.77471610038512, 76.88527245675364, 72.93355511080834, 59.80063215378792, 55.092713217581476, 51.02033199802522, 41.16094858415666, 46.33573155249319, 44.575540481075166, 42.904701002182506, 40.212103705252375, 33.67881567247453, 36.38632974316997, 23.97855889412665, 30.687310234192882, 34.8198841464135, 39.511478177962765, 39.50080933109407, 29.01666295143866, 27.06244203352159, 28.171056816654822, 32.07491928531278, 37.49148499581122, 28.37162329304603, 33.77100706100464, 36.71765627399568, 39.340913911019605, 34.956888614162324, 41.60709465703657, 45.95868979730914, 47.54934034039898, 49.00174302439536, 52.74346059368503, 40.20469434799687, 40.13103615853095, 35.103471509871945, 38.808118758663056, 35.50484764960505, 48.578774236863666, 64.08621772643059, 55.883341450845045, 61.02535301639188, 71.57748976061421, 78.91502841826409, 81.08875105457922, 71.64789630520728, 60.04140684681555, 38.30147012587517, 23.22950190113437, 11.303534411614942, 6.17718388957362, 3.018148627973372, 1.0622457486967887, 0.0876186326927235, 0.09064038990125542, 0.05277934792121092, 0.11775247902879793, 0.04208621223487201, 0.04089764980298858, 0.04891557964466272, 0.026419924857515483, 0.03659566008155385, 0.10214037321988614, 0.015180035092447315, 0.05786005452635789, 0.02294205230540566, 0.03609670701646998, 0.0122773997680915, 0.024784141362855033, 0.030388434590291113, 0.031325461628336104, 0.057453981961213776, 0.04462795790224787, 0.013979067781849975, 0.02135210576647472, 0.028607996458548213, 0.051596312813701174, 0.026985351371789174, 0.1169475964120319, 0.04842565109532687, 0.027753208959174734, 0.07540294705259223, 0.09144480520438764, 0.031938293663364266, 0.0653599786962713, 0.06662894205580797, 0.021117705844282623, 0.03366755712176523, 0.04001364945584247, 0.043752886309859254, 0.07426930546400047, 0.025052312355969223, 0.04815822895315867, 0.020327214189174197, 0.08841065269324089, 0.016382470419029557, 0.01840437371884623, 0.028315050181962793, 0.04765122813443023, 0.0199675339935047, 0.031701834879875664, 0.034518960427733204, 0.013543963357205353, 0.03770242730576185, 0.032100788572983395, 0.11307072420153888, 0.015829733193611667, 0.043514897265741904, 0.08199635938170456, 0.019552289440687147, 0.02480540413319344, 0.16045233535189785, 0.32456071807011483, 0.2195193230985634, 0.07826847595072563, 0.24168656748389047, 0.20259469417074036, 0.09774441515365917, 0.15047160397854545, 0.12013815343379976, 0.10149632310194355, 0.2150831990424664, 0.12707596058927237, 0.1793706927809023, 0.12692494167675897, 0.11062930157828717, 0.13237043253837094, 0.11948614366232388, 0.04965213870990181, 0.14599429503563913, 0.1386018223579853, 0.12842319515203277, 0.1215934600200384, 0.09445854147235233, 0.15089138951753417, 0.19108091360859333, 0.14429145011930697, 0.13511745529549737, 0.1730380414594566, 0.21942290327241346, 0.13880547917177602, 0.17242855722865752, 0.13282533554780868, 0.09928350111529713, 0.08768562708170184, 0.2214471986817737, 0.14578432565735233, 0.09593900638602434, 0.0988049413107576, 0.14841179273301555, 0.08408158942456208, 0.19946680314117865, 0.19590850859399767, 0.135788103986171, 0.14822698168216214, 0.22317472695102616, 0.10011390212082094, 0.10509330508930069, 0.19559752286201526, 0.10498035308574477, 0.16863793885755926, 0.09954990819096567, 0.19899121575778533, 0.5164806052081047, 2.6887038542378336, 5.037382831496577, 7.863990847141513, 12.302433636880691, 18.040015928206905, 25.338505429606286, 32.605674805179724, 38.3036901873927, 47.22049274752217, 61.58458494370984, 78.92186903184461, 82.83303691494851, 89.07155098453646, 90.96342778974964, 84.53962095322149, 74.64504995653706, 64.18932899352043, 59.204882960165705, 52.598952631796564, 57.22447433779317, 50.88755192295198, 44.69239181087863, 40.31002175423407, 34.17924734853929, 38.96573135929723, 26.320308023883452, 35.71636930588753, 35.42234451540055, 38.70195196520898, 40.15616678422497, 24.571803654393843, 27.201482211389852, 26.693619605033632, 30.362930220942346, 39.89607834046887, 24.92531511091417, 33.405253887176514, 42.294340979668405, 45.0282447568832, 33.78436665381155, 48.16340700272591, 54.07073966918453, 50.192704046926195, 52.692850251351636, 60.838169667028616, 45.81915540079917, 44.45346455420218, 37.8332999444777, 42.22781365917575, 42.442543814259196, 56.17198474945561, 71.3249283452188, 67.889434137652, 71.07062539746686, 83.38202753374654, 89.5354732390373, 91.57498805753647, 82.28923951425861, 70.04643178755238, 45.173423444071126, 26.47432969462487, 13.521322915630957, 7.301799491528542, 3.6845669198420743, 1.1797834932804108, 0.14948557221120404, 0.1677419224213208, 0.14499536234765284, 0.1616253845033146, 0.09219698863284242, 0.18397472798824313, 0.1860510560894205, 0.1039239714643167, 0.10736539929864869, 0.19750022479603369, 0.18681642389105213, 0.1495754956117561, 0.12342045714537944, 0.14249538762434838, 0.08727183235028098, 0.1599540870877043, 0.1363680478666098, 0.1274515198723924, 0.2601127747085787, 0.16050970001566797, 0.13951584186044433, 0.1499826406999942, 0.18892604617341874, 0.14704979565595427, 0.10793661743762994, 0.2983110217798141, 0.2069374933959015, 0.12403360327645657, 0.15373208950604164, 0.16624550755706527, 0.21120130895606934, 0.19474436138426104, 0.12789424208383407, 0.11118329806073059, 0.15240258987872832, 0.1399750809275335, 0.2059157925748056, 0.17231745915787836, 0.15541155341892474, 0.18427420707960285, 0.09315799996857682, 0.22282637145009734, 0.09536332961532379, 0.09982359310191485, 0.14522791599794743, 0.16912846495547604, 0.10971855327126481, 0.1729906512604606, 0.27717539139332315, 0.1394036712665712, 0.14236852346408752, 0.15181015876512374, 0.20940498599121649, 0.20269738059611092, 0.23888676126878108, 0.12118698142829443, 0.12235179513452515, 0.2309803968115199], [0.09359274720472675, 0.04885676707471571, 0.053252043322690075, 0.024810592463660627, 0.03307647815334701, 0.07449500262737274, 0.02483319014220709, 0.035958060423933694, 0.04539948122035112, 0.0252769369962475, 0.03004505099999088, 0.02818516763528028, 0.04869859673142914, 0.03228243951114916, 0.06033154227019799, 0.07286665976167687, 0.044872213545585835, 0.04782914822440475, 0.05211672783198376, 0.0820540841067991, 0.0762522014819326, 0.10100045737119452, 0.02309659522237076, 0.10328786567814889, 0.08690042526371057, 0.04558875090292385, 0.054267006400491924, 0.07161482612812711, 0.0093470981359602, 0.037062613654040524, 0.04452304216101766, 0.04403269609376308, 0.06756266533967949, 0.029693165748950937, 0.06842210107753355, 0.07839575379846558, 0.021244326771627513, 0.029713308115700082, 0.04503133000745889, 0.05132057861755452, 0.04869002420755644, 0.03167928316660466, 0.054479182112000646, 0.05527019853733721, 0.020545620110727126, 0.014241010480139767, 0.07284483391671412, 0.06747834204185395, 0.012662431728395243, 0.13488295578187512, 1.2158928330867522, 3.584936756280161, 6.312460553261542, 7.675318958297853, 17.061074702970444, 28.36652421182202, 32.12683969928373, 32.87668704986572, 34.10660113057783, 40.266605038796705, 47.059655958606356, 59.12492544420304, 63.521592540125695, 60.750332109389774, 59.27458347812776, 50.07624495413996, 54.387557352742846, 43.73959318284066, 37.100703177913545, 19.107410523199267, 19.287992523562526, 33.60472209991948, 24.389476199303907, 19.704954201175322, 11.561865633533849, 14.931158077332283, 19.18008419775194, 23.58643170325987, 25.34858984331931, 25.874642441349646, 15.688242200882206, 22.248991727828983, 33.504944847476104, 30.27525151929548, 30.166148831767423, 26.928959854187507, 19.478484392166138, 19.93413240678849, 23.85237232331307, 20.36401241056381, 15.332515585807064, 18.799373065271688, 19.38202742607363, 20.59001937989266, 13.592437448040133, 19.891963005065918, 12.71205852108617, 28.785651037769934, 25.264713879554506, 17.0227413792764, 26.4297519576165, 19.20187688642933, 25.143606778114076, 32.8898250287579, 37.79941066618889, 32.032538075600904, 38.123610250411495, 42.439068594286525, 43.949934205701275, 58.13685294120543, 59.997970519527314, 57.50884225291591, 61.74266822876469, 57.68122257724885, 47.207027250720614, 30.22169351577759, 19.4202156220713, 6.618210779082391, 3.07548166763398, 1.1741485182316074, 0.040562585927546024, 0.0062978273584327156, 0.01660427394052667, 0.036444771403987566, 0.019494047606243722, 0.06532411045965648, 0.013202563934629003, 0.054357335827643835, 0.050547151570959445, 0.031573377256732316, 0.031280178171131885, 0.028933080123557203, 0.05819751625700344, 0.06680140376932199, 0.03663684879880279, 0.1012719359489218, 0.047241156590321375, 0.09531160335867636, 0.04074861888863868, 0.04419449769381074, 0.04566178589518513, 0.10274308523343456, 0.07739689771927173, 0.06129920707955476, 0.047232296783477075, 0.050523042783982335, 0.013089460628708045, 0.02291578123526227, 0.03877396597677181, 0.02846882126534418, 0.06655399567417561, 0.018584057726266406, 0.04427052808985595, 0.0891676931191356, 0.04051686963066459, 0.08402024110358569, 0.03980863666642578, 0.0346890740817593, 0.015211448527782436, 0.018797652615654855, 0.05258970285555529, 0.02075867682334877, 0.03799203535421722, 0.04336980021288318, 0.08921354348140378, 0.02544055039423608, 0.028070926688791766, 0.012601725963665353, 0.026037646983299526, 0.05131918433753233, 0.020511462165403272, 0.0467895056241222, 0.13734025940779718, 0.025173373400203647, 0.041605453757989797, 0.06815412352162023, 0.024357966650577805, 0.07904823088357527, 0.04517690586527029, 0.024246054611379103, 0.052757908950649926, 0.0847369010349916, 0.04363022797230271, 0.02863769768737257, 0.030055762824392127, 0.005678222148544005, 0.01605008114805265, 0.021797827212139968, 0.09662689971587352, 0.016434821037335262, 0.02744831745662997, 0.06899064556965906, 0.06278895314842944, 0.08009465336198769, 0.018219524363596595, 0.03814879609572311, 0.06802001983047494, 0.03172760607764846, 0.025303746243157697, 0.08438240916978929, 0.03279735401813542, 0.038432451641006816, 0.025578679877423474, 0.05993710275018408, 0.02900677586665317, 0.089633627794683, 0.14557668518635536, 0.07495431064237511, 0.009279890199972978, 0.04819235433974574, 0.06955338311531852, 0.04337211379841451, 0.07182467293234603, 0.026397781086064158, 0.034490691783327254, 0.02639620677537976, 0.02777561511574013, 0.012492887852262827, 0.0164635531649354, 0.050947685320411, 0.047429407375954816, 0.046573361577165705, 0.05550412348501625, 0.06744561476572868, 0.0883125781171745, 0.4259145181746252, 1.6506047066180938, 4.756835795217945, 8.653272236547163, 10.634530052062004, 20.763297926995065, 32.411695949492916, 37.98555458745649, 40.54823906190934, 44.822065368775405, 52.80903477822581, 58.84575074718845, 74.14304933240338, 75.83733281781598, 71.40376798568234, 70.85858991069179, 61.110405691208385, 65.8320725348688, 52.61612084604079, 44.92847927155034, 27.376992587120306, 27.708403448904715, 46.88358468394126, 39.446453125246116, 36.080024011673466, 22.7706120475646, 24.754393908285326, 27.098894580718014, 36.55473670651836, 34.53694005166331, 42.84577915745397, 26.01793250729961, 28.6248593561111, 37.528257216176684, 31.926887073824485, 28.380181904762026, 22.355937111762263, 25.447178617600475, 29.83037041079614, 24.973317077082974, 28.518918098941928, 26.511166634098178, 26.095671922929828, 23.363295908897157, 33.61902306156774, 26.754606577657885, 28.354453117616718, 23.487684072986728, 45.627653521876184, 36.69932311581027, 27.305115153712613, 38.14540293908889, 34.047420409417924, 34.94226209578976, 43.08586351333126, 50.728954807404556, 42.79159161352342, 46.77955165986092, 52.799428893673806, 55.56608446182744, 64.13472567835163, 66.82787602947604, 66.63899821619835, 73.90500853138586, 67.98044881513043, 60.86764627887357, 39.61775479778167, 25.82880170114579, 9.433443430931339, 5.264518462842511, 2.2358049308100054, 0.17507614177321235, 0.02178297659772779, 0.041387570691445184, 0.04606478644775287, 0.026477126727601694, 0.11590364839761488, 0.010047895259283965, 0.0477547227825609, 0.07813841720382053, 0.12052183324891715, 0.01303309954011873, 0.050799240463323174, 0.05367084826913573, 0.0568610490600188, 0.04050746590139405, 0.052840665598670324, 0.024807853699331323, 0.0427631390160851, 0.0371775804688373, 0.09014481528391761, 0.060785050999613545, 0.06984681777295566, 0.027689700270251884, 0.027109392498049046, 0.09090210851882735, 0.022313304793750568, 0.04755422225101821, 0.035042554710901556, 0.03676874615672616, 0.028016589987542362, 0.07194239000279097, 0.028469300070296855, 0.0561158791665108, 0.023461032824050036, 0.051412869229792595, 0.024109267697279013, 0.03048352525389243, 0.0470750917109751, 0.019500199292275696, 0.07025482854054821, 0.08311820321626241, 0.025168681111667427, 0.017932147546220693, 0.027614706008124257, 0.0486213980512994, 0.028739920629548932, 0.01977741395333602, 0.04420042338390504, 0.03725054268274577, 0.03590895418798731, 0.012580787823084864, 0.021619707939305136, 0.052849215139905294, 0.08442302715153464, 0.06285093732238298, 0.022529563753895705, 0.20491883639366398, 0.1441196778849248, 0.23401268006813145, 0.12382010223283885, 0.13764618895947933, 0.1352233746119084, 0.1126461889174196, 0.14283412106094823, 0.14400246643250988, 0.23124232227283142, 0.12258253315643919, 0.19056199629220272, 0.22629641266840123, 0.10967258799580798, 0.2678282913421431, 0.21453820409313326, 0.20093589931005434, 0.17908161716355434, 0.145428002842011, 0.21144437333268506, 0.19471040836745696, 0.13784898775479487, 0.11716060715937808, 0.1978921400563371, 0.27429882316820087, 0.16501049721433272, 0.1829108923313118, 0.12029599052883926, 0.16093503203122847, 0.15352351440777703, 0.24722498481071767, 0.1887968377841096, 0.1625697564093336, 0.2646071367686795, 0.19466597526784868, 0.12993551400159636, 0.18716937591952665, 0.1304933792280574, 0.22110394532642058, 0.18742115837672066, 0.09749357498461202, 0.16386600782073316, 0.1332574857458953, 0.14678872821311797, 0.16043312186675687, 0.1301331800078192, 0.2952369867313293, 0.08212917604513707, 0.1306687520756837, 0.8139051100419414, 2.76342059335401, 7.132272691495958, 13.515572720958343, 16.95910680678583, 27.802067687434537, 39.81682685113723, 46.82297622003863, 48.93249357900312, 55.61356867513349, 61.9744332375065, 71.81487160344278, 86.89298814342868, 87.58004619229226, 83.44877058459868, 82.71353014053838, 71.64104000214608, 77.29920018103816, 65.54444120776269, 58.321604421061856, 32.89323749080781, 33.13339048816312, 52.69407010847523, 41.058923813604544, 34.42813350308326, 20.762085914611816, 23.476976002416304, 31.100388765335087, 35.408953543632265, 38.520424673634196, 41.48803503282609, 26.128941466731412, 31.863232889483054, 47.4660841111214, 41.18702842343239, 41.26704477494763, 37.35553172326858, 29.052283956158547, 32.02453447926429, 37.148712988822695, 33.181647408393125, 29.86880571611466, 31.506354078169796, 31.250658689006684, 35.18745337763141, 25.842871242953887, 33.01739031268705, 21.054280919413415, 41.56676484692482, 36.35039691002139, 29.95680605211566, 40.249334842928, 32.72424021074849, 39.02126035382671, 48.23213869525541, 53.63495257592971, 50.28884133984966, 55.920905989985314, 62.661295167861454, 62.627205848693855, 75.88087897146903, 76.52370052952921, 75.67688434354721, 84.06033869712584, 76.79534035344278, 68.89246263811665, 44.26017407448062, 31.10065156413663, 13.080043523542344, 6.972638599334225, 3.254003197916093, 0.3646743688131533, 0.0947910312923693, 0.11551550995077818, 0.1295681595201454, 0.11994522185094895, 0.35443686008934056, 0.1492220073217346, 0.21771040564823538, 0.12853456901446467, 0.23800649560026585, 0.1331887063720534, 0.1541535144731883, 0.18959012182970203, 0.22247334281283043, 0.09155191195708129, 0.23930470819675156, 0.15340818753165586, 0.143718600213047, 0.11835497653772754, 0.22017590641494722, 0.08813049433933151, 0.14400389135604905, 0.26824176431663577, 0.12361816145599851, 0.21872311259710023, 0.17976368056429973, 0.1173978033024938, 0.12022384802900976, 0.129745340335273, 0.08925762418056689, 0.11048638787601264, 0.14540313562798887, 0.22159611085249534, 0.20030982161481536, 0.09014624020745678, 0.14635958107969455, 0.12187442276626827, 0.10940088725258267, 0.08501417889830568, 0.15849355578182206, 0.13069417087301133, 0.16471040525263356, 0.17027623320539154, 0.1561985402217796, 0.15906104307261207, 0.1687437049563854, 0.08930654655541144, 0.12914316458327155, 0.09575061770456453, 0.10239367253117024, 0.11875114358601072, 0.26174065026064075, 0.2622846646174308, 0.17028538029520743, 0.11835313026583004, 0.12256633805771991], [0.06993035966109845, 0.02362825641138179, 0.07275140949434812, 0.028758218639620373, 0.02952721003713387, 0.050671901328549276, 0.020199520738735315, 0.005449655985895304, 0.04212785294399627, 0.06184758047663397, 0.027976259288768617, 0.021514594930434422, 0.07004232341123205, 0.048455268054479556, 0.036368537994642416, 0.030471361692874666, 0.023861669995371374, 0.028707834952060255, 0.035236026385738965, 0.027556987028689157, 0.03523273603810418, 0.0527549863252188, 0.0979441879016738, 0.09977241842857293, 0.060511362258224725, 0.06725472863763571, 0.04451822729841356, 0.127786269651786, 0.06851186359962148, 0.044935331529667305, 0.020962638157089392, 0.033583567072186744, 0.013778082699695183, 0.06867255054173932, 0.054332005130427505, 0.06758304327846536, 0.05739276770562415, 0.020296674094072754, 0.021836830663584897, 0.027876443777894302, 0.02727645712213651, 0.03494724954268144, 0.025600454011451335, 0.06858228240162134, 0.04311551647861639, 0.01429469217621391, 0.06650410036766721, 0.08894363538392129, 2.634610937487695, 7.478191419955223, 14.008170443196452, 21.293992650124338, 30.522296121043546, 32.483004639225626, 40.11505250007876, 46.633886598771625, 60.275819455423665, 61.31754606000839, 61.35218058862994, 60.87849947714037, 54.71138038942891, 52.35797397551998, 44.860237875292384, 45.082573506139944, 43.64754692200692, 33.8017584431556, 31.490701859997166, 46.00042773831276, 21.39280107713515, 29.41389314589962, 60.04718449807937, 10.797072091410238, 14.639030733416158, 16.80530871114423, 25.834579352409612, 36.830424416449766, 53.74844635686567, 29.789140416729836, 42.99510771228422, 38.528179199464866, 40.207361559714045, 52.615297148304606, 54.3808618668587, 56.862941634270456, 49.34804908690914, 53.108158649936804, 58.91908730230024, 45.35267576094597, 55.08327207257671, 46.84516506810343, 37.66694438072943, 43.533731506716826, 43.754988485767, 23.22625613981678, 33.68170253692135, 25.45376623830488, 27.58686684793042, 23.97403051776271, 20.90351873828519, 20.384038071478567, 24.41372625289425, 19.279192686080933, 18.90129585419932, 35.89335449280278, 39.418537616729736, 21.179628103010117, 17.33560335251593, 28.77712968857058, 28.387261782923055, 43.47054604561099, 40.998178066745886, 54.0541676552065, 57.526328179144095, 61.94443102805846, 64.55641577320715, 59.96538739050589, 56.08385693642401, 35.9014267306174, 27.444645627852413, 14.11409503029239, 8.958413024102489, 4.219783890631891, 1.1894234534232848, 0.16120233542976842, 0.011253572095395818, 0.017406381403787002, 0.04724784070746072, 0.03163893906129224, 0.040104902018943143, 0.04734883790895824, 0.07749989057981199, 0.021997990664995967, 0.045100331546798836, 0.02092236683012978, 0.011386635822183903, 0.030046474008310228, 0.034152628673661145, 0.017819756702069315, 0.09174572454104502, 0.06970236423395335, 0.052950036141180226, 0.01926468471215377, 0.04396903418725537, 0.02998813449765646, 0.05467284530881913, 0.01586993461504819, 0.047246147653148066, 0.06341340290682931, 0.06925973395306258, 0.02385939088379664, 0.03538129963882027, 0.020803763012912486, 0.04270215458687275, 0.08091902525554742, 0.06680723369842576, 0.03869706990137216, 0.0642859081046716, 0.03844564750550255, 0.00777746681236632, 0.006933607557232702, 0.04368643584330717, 0.06736932773022883, 0.06356873489435642, 0.11313252451439058, 0.0511505683853982, 0.03341848661582316, 0.06967280090095536, 0.09114085215955012, 0.04315753640126317, 0.06475581877654599, 0.04274811220145033, 0.02553346536813244, 0.029575847044226625, 0.05400396628125061, 0.023971446564481146, 0.06869776249532739, 0.06308350629443604, 0.0025426834068756794, 0.005263921320288172, 0.02510163884219383, 0.025199255680725462, 0.052318480917282646, 0.07433409351975688, 0.08521706196329287, 0.010959439340137668, 0.0262615553313686, 0.023725398275400364, 0.031137231910120577, 0.06190455443556271, 0.003241903107282856, 0.058783347523140336, 0.033043498068206736, 0.0021445700164598926, 0.03604282422231571, 0.09760093454632068, 0.010208961414924313, 0.08260172972035024, 0.04126033497854106, 0.022300836712782903, 0.02934928994715935, 0.07798686969063937, 0.039190112598120205, 0.07986904046828709, 0.06419073700183822, 0.0808001667140953, 0.026015514703167063, 0.06987880960467362, 0.08600761107499562, 0.06088587200088848, 0.04223532358845396, 0.029443882653609883, 0.029154573379444982, 0.019090221593937567, 0.03230304344587269, 0.013749157134894163, 0.052890411518033476, 0.08323772825420865, 0.06427325999304172, 0.04194598367077209, 0.05598635285071308, 0.0516726496449161, 0.05557252364533563, 0.047081752845476714, 0.19158768077050486, 3.661061381140063, 10.93019929624373, 16.728667559162265, 26.318799872552198, 35.10158092744889, 38.53070912822601, 47.78595339867377, 55.99865913391114, 69.41885255998181, 72.88321541201684, 75.78252946176838, 74.75907325744629, 67.98796407638058, 64.06776297476985, 57.18687057495118, 54.176455390068796, 54.44461214926935, 41.01784875316005, 41.6034782317377, 55.311091176925174, 32.70006468219142, 40.64469014444659, 61.70413486419186, 26.71297650183401, 24.1351830574774, 27.504867738293065, 27.983630280340872, 41.54237554919335, 50.54332079425935, 30.650020260964673, 39.032341049563506, 32.40366881893527, 37.2634619282138, 36.9506529069716, 42.26482122175155, 37.88341606816938, 42.21288119592975, 42.093970621785815, 41.0077957184084, 37.53090873841317, 46.42498508576424, 37.794233137561434, 30.679339978002734, 34.83142375946045, 39.889731945530066, 25.99560049272353, 29.824428019985078, 29.224876088480798, 26.28030573168109, 27.997866522881296, 24.820970258405133, 26.75855640442141, 27.331863757102724, 23.766933295034594, 23.78133623830734, 43.37576981513731, 46.02865311407274, 30.055812558820172, 31.281639529812722, 43.48848304440899, 36.61965193287019, 50.55750016243228, 50.700682363202496, 58.6601520353748, 67.67743787457867, 70.20397770789363, 75.83974899784212, 69.16906033792804, 67.58056317606281, 47.38551470541185, 35.95138595950219, 19.889813546211492, 13.366713869956232, 6.306950113465709, 2.051651612404854, 0.22881376226582836, 0.07270015055133451, 0.04468716883791551, 0.10608124441557354, 0.03610582346276891, 0.057973274660687295, 0.07453056442881785, 0.03386685872570642, 0.03601108903005239, 0.129733067606726, 0.02031651768653143, 0.046846445109094345, 0.052780186787488005, 0.08365533810349242, 0.07123451709987656, 0.12780779672245826, 0.06205058994612867, 0.040777343355359576, 0.026953528079414563, 0.06293076368409299, 0.0242018475077085, 0.047811570336982134, 0.009201342247486597, 0.008729135227059166, 0.03473600462800072, 0.01737689659480126, 0.008954576708586707, 0.07336308473661061, 0.10053561054049961, 0.05732999063066899, 0.022489679301337853, 0.03305889643548477, 0.04079604356159126, 0.053727665180039984, 0.011037041174037563, 0.04137081634854117, 0.037410467367378936, 0.032036561676631534, 0.10233849121798431, 0.03579993221548296, 0.03318785584621853, 0.05754371767022437, 0.031459316340906006, 0.01692330168049422, 0.05810305761593965, 0.04865832731968934, 0.04006404271950165, 0.006671608359958496, 0.04720827609661126, 0.0850503918744864, 0.016968539172422983, 0.08620343847020019, 0.04929447141025336, 0.13946213909695226, 0.08104876990640357, 0.2510067472054113, 0.14908683876837456, 0.08176109378015803, 0.22378790372562027, 0.19544493346925707, 0.12784722726792097, 0.11525549204839815, 0.14003218512140936, 0.18643474356541712, 0.08178726334365145, 0.14461418764004785, 0.15245805464444623, 0.16834582953203112, 0.15702383142084847, 0.07242304122736377, 0.130723787832164, 0.2991080596562355, 0.09500229535924812, 0.17867508494565565, 0.14452539804962375, 0.23374171476931344, 0.20711088973668315, 0.16385660026102297, 0.1910047338254029, 0.20770926569258014, 0.21406136032554413, 0.14059184299361321, 0.12409429276181806, 0.19617968839743447, 0.22628887436322628, 0.17644514089390156, 0.17464578422086854, 0.14535825819738452, 0.20259117016628866, 0.15316055727101144, 0.12641857288056804, 0.10538647161616434, 0.17251586060850851, 0.15354093524717516, 0.1954671500190612, 0.11179387779726137, 0.08760909489806622, 0.23894547424729795, 0.08522116819456702, 0.26067474616631386, 0.641125071673624, 4.708883348972567, 14.240783664488024, 23.38202326528488, 34.18565650140086, 42.944265950110655, 49.307629062283425, 57.192052025948804, 65.39321030339887, 80.30051938949093, 85.14465439704158, 89.71937748693651, 88.07595929791852, 82.41357864872103, 74.03971841258388, 70.63343017332016, 68.9933930673907, 64.91991358418619, 52.57353175070978, 49.522100340935495, 65.12520259426486, 37.51025353708575, 47.24647060517342, 74.22999258964293, 22.415794441776892, 25.700036171943914, 25.269924748328425, 36.696981460817405, 52.970118676462484, 68.9728476924281, 41.91398874405892, 56.916215265950854, 51.01378556220762, 55.348098739500976, 66.04708117823448, 70.90008074237456, 75.15291844644855, 66.9184200225338, 72.8327109736781, 79.08422377801712, 60.11375104227374, 73.94761331619756, 63.45534763028545, 54.71417703936177, 60.66927240740869, 59.73219071665118, 34.09357886160574, 48.64995348838068, 40.414129303347686, 40.115636933234434, 34.27646721563032, 30.175115369981338, 33.831274278702274, 34.675454631928474, 28.75797675501916, 30.072361038577174, 50.758804044415875, 52.85021574266496, 36.3906757293209, 32.58960485458374, 44.90398014745405, 43.255933561632716, 60.25573692014141, 60.49709604632471, 72.83355820563533, 78.26969654329362, 80.80546963599421, 82.35846150305964, 80.76579878407141, 76.58623879955661, 55.624904324931485, 42.82507688768449, 26.060256842643987, 16.083805388019933, 7.959821704895266, 2.9254002628787874, 0.5429714966204859, 0.1428827063571061, 0.13506703138832124, 0.20873248336776612, 0.10388596584239315, 0.21641458324607343, 0.18183858374193793, 0.17688798567941114, 0.08407968186563061, 0.17152754589915278, 0.17920756201830604, 0.16968836797581566, 0.181206070908135, 0.1361474298661755, 0.20672182432345806, 0.2216189402726389, 0.2070748376389665, 0.13746749129026167, 0.10826202860522656, 0.20603991414029754, 0.07989361656889801, 0.09682017603829023, 0.20717968443228355, 0.1702238787566462, 0.10012026831147172, 0.14612169545744697, 0.156981757872047, 0.17345212730428866, 0.22302708648625882, 0.24230717531135007, 0.16909805126488212, 0.10068189502964098, 0.14783791626893705, 0.12524304160427663, 0.12257978290079102, 0.1667362021943254, 0.09219118168637638, 0.16572904172203234, 0.1710878880394082, 0.13063910447301405, 0.1902495243496472, 0.19379888631163106, 0.07417493875348762, 0.17456552884992094, 0.1771120357537462, 0.08521464878633138, 0.12343489790275214, 0.12900922177059035, 0.13312662260666971, 0.19368244094714043, 0.0849563392600225, 0.13325151026008591, 0.24616281922546127], [0.0640726100743538, 0.06342955204027315, 0.010318640307823737, 0.0005371867178661389, 0.008789732781869751, 0.020779600599780682, 0.015091749204833423, 0.014320885679954964, 0.011479961610729656, 0.021903934220092434, 0.026817832840606574, 0.02773035655639345, 0.02603776572692779, 0.043561406463624976, 0.07225326848246398, 0.07388404750775907, 0.053991567148196126, 0.03903136768889043, 0.11768595195345341, 0.05461844157487635, 0.04348741003101872, 0.07068821980107216, 0.027008356992155317, 0.0379312003121501, 0.012264890509897904, 0.01599497357082944, 0.047018496965568875, 0.0790476486567528, 0.007827353979190512, 0.04889268127660598, 0.06466075492602202, 0.009284397669797464, 0.054905544515819325, 0.0313144184709076, 0.03132663565808006, 0.02246315925261907, 0.013274967861962656, 0.057885071127525264, 0.04307021003877444, 0.05563890133353491, 0.07269900908032734, 0.1373518273354538, 0.01777159083904999, 0.06683410806280952, 0.04759280243888498, 0.0933225250111953, 2.9492124818986465, 12.528079748153688, 27.703871150170606, 38.63925680037468, 47.17713094526722, 50.19968586583292, 54.90308230923068, 62.17536057195356, 68.14339191682878, 69.75891420918127, 68.67493583310035, 65.84465549838158, 54.06831172204787, 56.4709674158404, 50.41485532637566, 38.98286819458008, 38.25602554505871, 32.389167816408225, 24.27678454306818, 18.613295824297015, 19.167007015597438, 14.195067459537139, 14.161854790103051, 16.421950959390212, 39.53091744453677, 22.13009095961048, 34.28097401895831, 39.03417671880415, 49.78291834554365, 44.18646881657262, 62.3796925237102, 59.19043687082107, 44.16690403415311, 60.21315959192092, 38.12552828942576, 41.291418383198405, 34.31069774012412, 30.888786700464067, 21.79484401979754, 16.745186621142974, 24.883155515117032, 27.726756218940984, 22.451368378054713, 26.68409412907016, 23.975491600651896, 22.073430361286288, 31.576144810645815, 44.097266274113814, 44.09739963469967, 39.33156690289898, 51.51427607382498, 53.74345710200649, 58.42578649520875, 48.66343467466293, 65.06555118868428, 46.01638001780356, 50.707672026849565, 41.82899882716518, 37.48471106252363, 20.08170177859645, 22.0792943046939, 15.907157524939507, 22.117531530318722, 21.583061525898596, 25.697231677270707, 34.04833824403825, 33.40179435668453, 44.58088274924986, 48.87669786330193, 58.4264454533977, 59.954734233117875, 59.10768662729571, 55.47947460605253, 53.106428884690814, 46.10495105866463, 33.17944695872645, 16.323300407778834, 8.773514455364598, 2.147119405769533, 0.21070356630990583, 0.11406694493827321, 0.06880121500862223, 0.026299505411917647, 0.010111923930385422, 0.04958985959209743, 0.011204534807362625, 0.026910307313946467, 0.07359690243198026, 0.064682082813834, 0.06723954477497647, 0.028457559772857258, 0.07376766343030237, 0.07913058533543542, 0.059470126195059675, 0.01499630997122656, 0.017503327915384885, 0.08665203657602111, 0.02536250901738963, 0.05881504441100744, 0.0020666332584956004, 0.021799765414588397, 0.07302704026862498, 0.03772346024972297, 0.0080158187906378, 0.032672359112409816, 0.03713506641947935, 0.03001414318268578, 0.06054380225137838, 0.023135859143709945, 0.03584412399739508, 0.07072817894720262, 0.044423128973933, 0.036957311038408554, 0.034016536984352336, 0.03844794576927539, 0.0237965640131264, 0.013644049871682882, 0.008648147284533949, 0.020156750049922737, 0.05107094886742773, 0.015376171795651318, 0.05049576239299871, 0.03877369401555869, 0.038136990680809946, 0.020306949248357166, 0.05119418560136711, 0.1152507576250261, 0.0325827804514237, 0.035389833858296756, 0.044570072298689235, 0.07659961469471455, 0.07208633792376326, 0.06120227014405593, 0.04713078247263067, 0.0200890202165371, 0.003393929425416695, 0.05460548702807677, 0.03896862508789186, 0.0307970984478391, 0.12211345752040226, 0.08035819526881942, 0.09096142670680439, 0.03088031474861407, 0.08376483505050983, 0.02693274028358921, 0.14563473932925733, 0.049272576617377425, 0.027771941724143205, 0.0457103903435411, 0.0375782291314775, 0.029653576240243933, 0.03597731987435011, 0.08224999577167534, 0.08145584604672848, 0.05532827566287691, 0.03863218991506485, 0.03381612072248132, 0.061576810530236656, 0.04752029987773107, 0.05273453943851975, 0.029365996409568097, 0.052479167859400475, 0.03880621827838402, 0.03731363768418951, 0.05557273048907519, 0.06323799941568606, 0.052373348134419614, 0.0578449511029307, 0.11054323926087349, 0.012449264890634486, 0.023968418601960428, 0.06313976396115557, 0.06072530380239891, 0.042741033549029986, 0.004036812216884667, 0.2015098983482007, 3.9780739574663104, 16.210591100877334, 35.1014946353051, 45.03806637179467, 55.58779870310138, 58.28540094437138, 64.17785606076642, 71.6308653739191, 77.649946366587, 78.30340539255451, 79.04879693062075, 74.61782086280085, 62.434087953259876, 65.63356922518823, 60.87138037527762, 47.429484475043516, 47.888256657508116, 42.22558967528805, 34.6907675650812, 32.14674376672314, 30.78717770115022, 32.812099341423284, 27.158632278442386, 29.636136601048133, 45.48114515119984, 19.26195779154378, 37.07891048923616, 35.15712561145906, 42.58239592275312, 40.45985237244637, 55.123025294273134, 45.39711229262814, 37.65529101894748, 35.14427984914472, 25.68143237021662, 28.576635776027558, 23.57242491937453, 18.53560936066412, 17.74026055489817, 14.307049166771675, 18.34270719558962, 19.456676014008064, 18.195078988229078, 18.858328250146684, 20.25464692423421, 21.618013766504106, 23.98385605504436, 28.478680464529223, 38.2038737112476, 32.93673069246354, 39.87341488561323, 39.463287938025694, 37.52020459021292, 40.03818581181188, 54.65901282525832, 29.709045617811142, 47.7441095536755, 50.58911838839131, 42.721965620594645, 28.685436441052346, 28.148263923583496, 26.337911621216808, 32.86452574114646, 33.80373924009262, 39.1396806316991, 46.7309142697242, 42.27307781096428, 52.89200075211064, 57.46347219713273, 67.81392066709458, 67.71389238296017, 66.58698758771344, 64.93818006207867, 62.663805484771736, 56.558683380003906, 41.48243388822002, 22.001686288464455, 12.688639029379814, 3.1227084753974794, 0.4820798253340106, 0.2044953889543972, 0.1236924873064122, 0.07126148339481124, 0.06083635590790261, 0.01728916229049285, 0.02513036905457416, 0.01694886603452746, 0.0666530738254228, 0.017114894524697336, 0.025077357685433763, 0.02339816190332415, 0.10421594289401848, 0.05376184419278176, 0.04062913981596789, 0.006799082038924099, 0.014395743003866125, 0.015943759635481385, 0.026472041819004283, 0.006374267132712469, 0.018001532129522775, 0.06729491761014347, 0.04412372649136571, 0.03336124835656055, 0.03117501345132628, 0.016364601418195714, 0.07205188694980837, 0.052174073343555775, 0.02281664945786038, 0.08250997536965916, 0.04087995700237732, 0.09233719804474423, 0.017413835439290253, 0.026689185610701962, 0.03638392870104121, 0.01728099962365964, 0.04784625879819355, 0.021302516895136046, 0.010747224366622827, 0.05376916033245864, 0.05265198963423891, 0.011281741148371612, 0.05967255343773192, 0.08220429096611277, 0.014445463067761835, 0.02224171770766618, 0.005238428308192882, 0.10529178314872327, 0.0471487395735758, 0.060127245772990494, 0.09250029050294431, 0.29966402498464434, 0.13173287884602625, 0.23053042740831453, 0.12435883058295136, 0.12371387648125812, 0.1285173780014438, 0.15495626736552487, 0.14722847800341346, 0.09610664940649465, 0.19933688995097915, 0.393477252293979, 0.19128446317007466, 0.11835383506672037, 0.13183528947974407, 0.171713077072655, 0.2328785941485436, 0.17148879717194265, 0.2694043793505238, 0.22686854245201235, 0.08449396689332302, 0.23146217418534143, 0.18567257801130896, 0.15505569025633797, 0.20051396872487762, 0.14726140446239902, 0.19703255876177744, 0.19084551011122045, 0.21319221825368945, 0.15155983187498587, 0.11044554772876924, 0.17426332248555076, 0.171302653128101, 0.17508187211088597, 0.13045481436194914, 0.11477213653345263, 0.08302534569896038, 0.1132656476129928, 0.11917397049405884, 0.25214354507625103, 0.18222993209717736, 0.21497398554798097, 0.23490117352095344, 0.09580214477835164, 0.17950906358178587, 0.17020785219727025, 0.604774689962787, 6.132762066779598, 20.122400291504402, 43.191610613176906, 54.4482050403472, 66.82358495650753, 70.16929611083, 75.8961134572183, 82.61441184628396, 88.3605900118428, 87.9269798340336, 88.46985155536284, 83.48627628818636, 71.74422971663937, 74.32192510174167, 70.16233782614432, 59.21273554525068, 57.612934112548835, 50.444151509192686, 38.51526283448742, 33.447266394092196, 32.821930762260195, 27.99112004618491, 27.756030828722064, 27.639332471355317, 51.90637188573038, 30.02177226927973, 46.45779178988549, 54.12936341377997, 66.75886584866431, 58.912627158626435, 72.10886109259822, 73.59187787578952, 58.02238249009656, 75.26147396333756, 47.55228996276856, 52.201761661037324, 43.75305867964222, 39.00075028019567, 27.2589567015248, 22.068144967479093, 33.32280174378426, 37.440113713664395, 28.940616038537797, 33.68127892094274, 32.88074081943881, 31.384584096170244, 39.96348034950995, 57.94048732326877, 58.818811908844985, 54.3090001229317, 69.06248169560587, 71.72272728335473, 75.78518098400485, 66.7682481581165, 84.1592530281313, 61.06434529827487, 66.9381966129426, 56.45869039720105, 51.622486422138834, 33.83377675087222, 34.24542557808661, 27.752539919268703, 33.81364714714789, 35.52586370898832, 40.51417327696278, 50.74995125493696, 47.46642143495622, 61.09839539374075, 67.20145825416812, 75.80973502128356, 77.18526317227271, 77.33385824388074, 74.32644367218018, 74.17608353399461, 67.62047721493629, 49.33996115961383, 27.91011525738624, 15.585707522207692, 4.877030945593312, 0.811111769608913, 0.3715969844450874, 0.2593278410213609, 0.15990018514135193, 0.19772291123386354, 0.12445124376925731, 0.22590177013508736, 0.1652071519844955, 0.2560887753122276, 0.14456307425373985, 0.1451900559327295, 0.1474453115295018, 0.20943248854769816, 0.10394566707433232, 0.2495264355093241, 0.11045216672843504, 0.10799221243829497, 0.1217655080460733, 0.07834551375239127, 0.11175725879448076, 0.14276992289289353, 0.2775391912268054, 0.24467562805981408, 0.2712703243859353, 0.18637912558211436, 0.254220807804696, 0.14244692490225838, 0.11513021369014056, 0.1916353620829121, 0.1519774723677866, 0.12262996932071064, 0.21272366355744102, 0.1412268532740493, 0.16490983326108227, 0.13244016186123894, 0.14756077630144937, 0.1741607739560066, 0.09860395048294338, 0.15026079190354194, 0.15251321297499443, 0.1441895451036192, 0.10985246544042904, 0.24485696107149127, 0.1927628902898681, 0.16141247334739856, 0.17621130021589418, 0.10945423761562956, 0.30287221735042913, 0.1932748055626308, 0.16698922571395675, 0.1886650093740994], [0.03034539577070504, 0.023195399497185024, 0.0402291193454256, 0.09136739968051834, 0.056879308765694025, 0.033121662019121076, 0.05102384978184297, 0.042602739356938875, 0.0213009157713743, 0.05293325115475924, 0.017362003845553246, 0.006335274693781451, 0.06967233358732156, 0.010291425034313673, 0.005933282025639089, 0.03358096620368381, 0.11336208276090123, 0.036069794347690004, 0.010164710261198062, 0.052476164794737296, 0.016370117251250534, 0.04050722841413752, 0.044703655050046025, 0.031203224639137907, 0.011968176995944834, 0.04070649554412212, 0.04639239245725255, 0.010866614381572413, 0.02021095268578539, 0.026175109969992793, 0.035036736273116646, 0.07205402433511711, 0.05687083583325148, 0.021468878633552985, 0.14877127183060493, 0.03252102610384745, 0.08596556050883186, 0.01609936454183152, 0.07706775570348387, 0.030826826489740805, 0.06894976711801945, 0.07365085034360809, 0.03315640793692681, 0.17348819472376378, 1.4518872600409294, 9.208498443326643, 28.293160200119022, 42.26746097687752, 52.17449334359939, 69.19121388466128, 62.18233062374977, 62.053696493948664, 62.71034440686626, 60.08940096824401, 57.45028518861341, 54.78206542230422, 52.191881210573264, 44.24385701456378, 40.78516983216809, 32.813156420184725, 23.385898567015126, 23.47098654316318, 22.257728807387814, 10.91589637341038, 12.911462014721288, 10.089271568482923, 16.404989650172574, 15.684726776615268, 16.711381673812866, 22.659373629477717, 17.82347559928894, 47.26044993246756, 41.24482847029164, 56.826036053319136, 39.029650303625296, 39.099970556074574, 26.920260037145308, 22.974943999321233, 13.742389659727774, 12.860668301582338, 13.671670306113459, 7.416754845649966, 6.3675056253710105, 4.704991867465358, 4.964548339766841, 2.242960314596853, 3.165471135608612, 1.668725934240126, 3.392054448204656, 2.953613381231985, 2.0570443810955172, 2.501911025854849, 6.091719856185298, 9.600498157162821, 11.372962324850022, 23.394474829396895, 27.424480722796535, 30.060992048632716, 48.010273748828524, 52.210834103245894, 53.855174049254394, 65.66449319162678, 47.885048158707164, 40.483143406529585, 36.56150279506561, 46.033936546694854, 58.4221661475397, 51.98971440715175, 23.707593717882713, 22.860400984364173, 31.748603582382206, 24.289948017366473, 26.424466563809304, 27.733145759951686, 28.59191929140399, 44.08673471020114, 45.41088765667331, 51.72620565660539, 54.13356034986435, 57.24991483073081, 58.18796926929105, 59.78351885272611, 50.28500918419131, 31.81843157737486, 14.755534933459375, 1.9879917896563009, 0.6589670142819805, 0.02425385913210771, 0.055160793520870714, 0.028292720634189826, 0.03848467585480502, 0.10136350643851104, 0.014465850582646747, 0.02282145282914562, 0.050577894679360816, 0.04175675229259557, 0.07726591966685749, 0.05695598267559564, 0.04334650730954544, 0.04766764539864756, 0.009493870048543379, 0.04241847988939093, 0.002440304134882266, 0.09646376129239799, 0.03978656184288763, 0.031519324008014896, 0.07472109815646565, 0.02896896751237012, 0.0711282836874166, 0.021857154976216056, 0.028755276861991134, 0.033331137270696705, 0.027645043089925766, 0.054798311358618165, 0.03154552421502529, 0.07627444101437446, 0.13590652585750626, 0.05096994400505097, 0.009125101177262203, 0.00344521853314232, 0.049006728785893613, 0.06241040612240473, 0.05707337415867275, 0.01564559246969199, 0.09414918750764863, 0.046721063328966986, 0.07517932598749477, 0.05547489723070495, 0.043881229019813964, 0.0541528171649383, 0.05695494462645823, 0.07467028354444812, 0.020501121893645297, 0.07976996997791914, 0.040599044051862536, 0.13620985071024588, 0.06370445886146157, 0.034517102664516824, 0.06383550969222862, 0.03936183886722692, 0.00911186222032073, 0.08776025936728524, 0.019710752812604752, 0.05826539930797393, 0.05307861250795184, 0.04484702457463549, 0.0514623929836577, 0.02115578999021842, 0.03720112235075043, 0.03519569568696522, 0.014052724262939827, 0.03046437688622504, 0.06512857417786314, 0.062317127256744334, 0.01569702569770837, 0.06666664890344105, 0.024009660945364067, 0.08808955460065797, 0.00698710204057035, 0.042132755906711665, 0.09816331203065573, 0.0595534420872648, 0.007525543586516212, 0.03591746925526569, 0.051127719813056534, 0.02154155164927004, 0.05030796359924059, 0.03042838032988291, 0.0569654630136586, 0.07957525341020477, 0.056289581942462155, 0.04376259264385989, 0.06940147554081294, 0.024146767701172543, 0.06666438128318518, 0.03125671481323098, 0.03964708404495351, 0.014767488126733131, 0.007768600302252679, 0.22942266426980498, 2.5768420244416883, 11.450347746572188, 32.76111049036826, 50.06748630154518, 61.74267999587521, 80.92077947431996, 71.40695295026227, 71.22518247173679, 73.83136210903045, 68.30647622385334, 69.05317783355713, 64.52848065283992, 59.92168826441611, 52.39451085367511, 50.458950611852835, 40.03662863085347, 34.87322053601665, 34.151390675575506, 34.18782557210615, 25.81205906406526, 22.15775151406565, 20.812872763602964, 28.22760366624402, 23.162643140362157, 24.4251109323194, 25.865373880632465, 30.363704889051377, 39.58258682681669, 35.92323118640531, 41.331457937917406, 30.305912686932473, 26.91566694167353, 20.777151738443685, 15.442043850498816, 9.92357005996089, 10.6660766947654, 7.671195076357934, 4.64852003320571, 3.8291749021699353, 2.3722622279197942, 1.8228347551438118, 1.8490185372291075, 1.1024510235555711, 0.7854760161811306, 1.5784812670561577, 1.6709728394785237, 1.7545560963692206, 2.441056923520181, 4.011808056985179, 7.259576157216103, 8.798210678562041, 15.169944128682538, 20.108299370734922, 22.0437458638222, 33.307979106903076, 46.860340718300115, 43.616211106700284, 50.09778661112632, 41.919503596521196, 30.971609507837606, 34.080740944031746, 39.606497595387125, 50.52602706416961, 46.688493836310606, 24.55018355000404, 26.187139634163152, 31.642719199580533, 29.079611109149074, 33.82101728070167, 39.156162431163175, 37.01939244424143, 53.82458740665067, 53.103612622907086, 61.59948995036464, 62.85265584145824, 63.7036846530053, 66.84027071922057, 69.65487726273076, 61.882849816353094, 40.08232816573113, 19.100340450963667, 4.027646342592855, 0.7916218799448783, 0.04941285880763204, 0.057031503623171206, 0.020506019110701258, 0.030847453407102057, 0.03847413831540654, 0.05520055731458049, 0.0194771840958105, 0.05383356151381328, 0.04384033907685549, 0.09354524209254211, 0.028581365327080412, 0.04521010428546898, 0.03095191524123713, 0.025401334353392164, 0.07508867480341466, 0.034274957593410246, 0.012765740600204276, 0.01693310760592501, 0.03066636937400026, 0.036245178686635154, 0.05433930977878552, 0.036150294866773396, 0.02368629714774509, 0.029816082641181928, 0.05015165868004964, 0.03631052215613666, 0.05641439681752555, 0.07137711670610213, 0.0329301476989302, 0.0727080412569546, 0.08713472559447251, 0.019889046370442358, 0.01879764112433599, 0.06388758451888157, 0.03412252524867654, 0.02442867656598889, 0.03129450401531593, 0.05750264003572445, 0.060434159747655355, 0.038854140908487385, 0.04569006220047032, 0.03716787030439704, 0.02880510513580615, 0.052105722978951476, 0.015711012547985924, 0.013854014461920148, 0.03382635182671009, 0.09288671291283063, 0.02328620772928961, 0.13199010052748267, 0.12445042405517832, 0.12166263775960093, 0.22910905851712152, 0.22429856261418712, 0.1308268419797382, 0.13681939622807887, 0.2998290709670513, 0.148083416805152, 0.15990321884953207, 0.14560021940738926, 0.12493335056088625, 0.12631981648624907, 0.13323900770516167, 0.14068970306506082, 0.13141792477859607, 0.15228159395196747, 0.2915769557078039, 0.156154980462405, 0.13526134192943573, 0.240235842103439, 0.17869936993285535, 0.1736999567477934, 0.11709182012465694, 0.1947312153154804, 0.18327334385004737, 0.17278293418067117, 0.109433806050689, 0.12067219332581568, 0.10912598426183386, 0.11560370199262135, 0.2355822103638803, 0.19358157781102966, 0.15491741138600534, 0.25283624177738545, 0.2088310942053795, 0.19236613335388322, 0.22337121318184563, 0.1966898569897298, 0.14336388618234666, 0.232622092589736, 0.15378891790826477, 0.1306714946704526, 0.5471156645686396, 4.046334230130719, 16.381182824411702, 41.162929381093676, 65.96770025068714, 77.37395271178215, 92.03333270165228, 82.88998188511019, 80.68826921524541, 82.07447405784362, 76.94904235101517, 78.23459133025139, 71.6783574319655, 69.76853970558413, 60.92515999271024, 58.81420312389251, 49.63004004570746, 39.8621694503292, 37.37966214456866, 35.6936195588881, 24.038696673608598, 22.78679966926575, 18.32117142215852, 25.80648929842057, 23.434204516872285, 26.250476106520622, 34.97644162947132, 29.570480046733735, 59.2858132239311, 55.665430253551854, 71.28194701287055, 51.5406971593057, 48.80469099167855, 33.7587143528846, 28.320304962896532, 17.699895443454867, 16.612226117041804, 17.57449923023101, 8.730679231305277, 8.371596047955176, 6.269959711259411, 6.95612395001996, 3.9992515694710518, 4.633979316680662, 2.2777134949161164, 4.427035066389269, 3.8259879764049285, 3.3397741567703987, 3.678033231727539, 8.30231914597173, 12.970130866573705, 14.776959899933109, 28.722583247769265, 35.11357161306566, 39.48996397756761, 59.14448238188221, 65.79804205125379, 67.76300045751756, 84.5156317372476, 63.5116179527775, 57.160010184011156, 52.36195910361506, 61.47956740471625, 73.885663401696, 62.47330773261286, 37.232326153785955, 36.72701112685665, 45.21492212049423, 37.269212122886415, 40.28800549045686, 43.72287996353642, 44.3292470132151, 62.12975125158987, 60.77123442003804, 69.4243517229634, 72.81755493533227, 75.11926451037007, 75.39292043255222, 80.05578702495944, 72.43321757162772, 49.050780496289654, 23.909882114779567, 5.623592820859725, 1.1010720652918662, 0.15766532280512396, 0.19428771169435596, 0.11884796943876053, 0.19579715005332426, 0.18798058642254722, 0.21847603391976128, 0.09813878189532027, 0.2175811206501338, 0.13292952350551082, 0.19189687385674448, 0.24905417294752216, 0.11515619939253216, 0.1335447380739835, 0.15857462320596943, 0.14277375333251494, 0.09306191722111357, 0.20355898436279068, 0.14137119956074223, 0.0789555648882543, 0.1402323179307484, 0.15344931113143123, 0.17604101419208512, 0.17436611616323072, 0.0996335496705386, 0.13302719971585658, 0.11214758825278091, 0.1780455751765159, 0.15643348406639793, 0.15788531261346034, 0.23559629105992858, 0.2875593148412243, 0.11919503791197655, 0.06572126576136197, 0.17859458442657225, 0.20297490360756076, 0.10995298383697388, 0.13662534615685865, 0.2228128116938376, 0.19922773774352767, 0.07816302394794841, 0.1349248301478163, 0.2417217615631319, 0.12197933850749848, 0.1621101342982823, 0.129506841842686, 0.06985293881547067, 0.15199903008197585, 0.22403994665270854, 0.2996723293777435], [0.03340802951565674, 0.044319339381951484, 0.039477686683136615, 0.04850589114451601, 0.02060164412062976, 0.11636619696453696, 0.05120537431550123, 0.057207431884542595, 0.09689077870139191, 0.028397140333489067, 0.01973543999596469, 0.03652279745907553, 0.02657200288658421, 0.052698824419489795, 0.1361802337510932, 0.035995112266391516, 0.021882470351673906, 0.04126512685850744, 0.015045832767481766, 0.014608910799236789, 0.025232812247028755, 0.0018842381377321398, 0.03331078231454857, 0.018739770842535843, 0.058199159515601014, 0.06429093364145487, 0.02348661441506157, 0.030781834145947814, 0.030575264282825015, 0.017840868170042674, 0.06078804640339748, 0.008856878473213124, 0.0370062870394078, 0.039376949951533353, 0.022859657633929484, 0.025881868749556523, 0.041503770907800046, 0.03770386372061987, 0.01011978590770835, 0.03104005748736522, 0.03739400413788615, 0.05587614344192609, 0.4961999595886277, 2.301744140924946, 12.140839830521616, 30.65344252894002, 58.141414657715835, 64.34335654781711, 67.62607835954236, 64.2671880414409, 63.42848331697526, 63.88381165842857, 61.90531715270012, 56.08784206451909, 51.91755064072148, 36.564322979219504, 41.19222164154053, 38.42598184462517, 20.2506951362856, 17.289625329356042, 16.199633959800966, 13.675615229914266, 15.801242743769, 14.296713721367622, 17.39233063113305, 31.048974337116366, 26.592353813109863, 38.09805600873886, 33.78948534688642, 40.32727626062209, 30.116505353681504, 26.47226260554406, 29.96456842268667, 19.133598227654737, 15.018117024052529, 13.601316713517713, 7.24551740192598, 4.183880965555868, 3.5415175893614372, 0.48677646524963847, 0.44856176260978947, 0.24354204775825625, 0.1514794079646949, 0.10795999078019973, 0.032587476570399544, 0.07936657105963077, 0.07397843720090967, 0.024178872530859326, 0.1497759501780233, 0.0474050457799627, 0.2661883116008774, 0.26446059947052314, 0.11164993753716831, 0.4119432194819374, 1.3324403017759325, 2.5602175487625987, 4.526482839738169, 8.452373339283852, 8.241954849612329, 12.094967711356379, 20.191947837029737, 17.18263287698069, 28.026029140718524, 43.730701169660016, 51.46708996065202, 54.07727041552144, 49.840102580285844, 81.13095575763334, 83.73786495577905, 58.275375366210945, 75.72945979333694, 59.05111820467057, 40.608976964027654, 25.337964142522505, 29.851774784826464, 25.375565944179414, 23.50977093942704, 29.424911083713656, 45.372154251221694, 39.505731905660326, 54.280625697105165, 61.16070616629816, 64.55750226974487, 60.492302909974136, 47.372770924722, 29.096245881049867, 10.151922606652784, 1.2864088363224462, 0.3088447613821876, 0.00845436630169711, 0.050687169460880185, 0.047832335150169755, 0.03841438345731266, 0.027256046624613867, 0.06062041870468567, 0.034457305671587106, 0.040614825463102716, 0.15469225814505932, 0.08283837428016048, 0.04068055197656636, 0.03267567244268233, 0.05202084809782044, 0.007177938851753191, 0.02000683238880048, 0.028694876574821053, 0.013541644026014595, 0.0419329563456197, 0.08673888030311755, 0.08668032054218554, 0.03340315719645831, 0.05032688597097032, 0.04216783124232485, 0.009546100008001011, 0.09314102346017476, 0.03709294690540241, 0.06581957782468488, 0.02787706622433278, 0.029097796688156746, 0.07557480355664607, 0.12466735717269684, 0.09860236468094011, 0.04204150717405062, 0.08365608886965821, 0.038868125843545126, 0.017636039241727804, 0.06249522737738106, 0.03844496185681032, 0.06092228415992953, 0.03346697615099049, 0.14319940710500365, 0.012323051905109277, 0.052379706664191145, 0.03589588089755947, 0.06503643678320993, 0.04287747763878396, 0.021273342351759636, 0.022248286911616885, 0.01427390438038856, 0.03586011991325406, 0.035910808120764075, 0.05652379800355243, 0.0765820482986108, 0.027045201990873586, 0.0300752118815698, 0.036069893939120155, 0.035030182390924425, 0.09360718796209944, 0.06599000940519957, 0.0230402437098805, 0.06288505887853042, 0.09313353878115455, 0.0242390027720361, 0.0020303908358102725, 0.004102088174887843, 0.027947582702542988, 0.021450036701055306, 0.037900085651105454, 0.032262256924783995, 0.04173096577306429, 0.03990532079290959, 0.09657314332622675, 0.06423310549449056, 0.057005697951441815, 0.011000189472049957, 0.03976789228017292, 0.0791170715444511, 0.04501971994496642, 0.06681180724333372, 0.026992320856680314, 0.033524137801460685, 0.05284993909299374, 0.029368888391482256, 0.09246413881379752, 0.06906482586336714, 0.020545007240387703, 0.03240535831859997, 0.015049293569679704, 0.0722678394747838, 0.5864252294263532, 3.1516217368264354, 14.766146905960577, 36.988417486990656, 65.25619799090971, 74.69672326118716, 79.20300099157518, 74.75589613760673, 72.87562954810359, 72.60158923364455, 69.92029620755103, 63.37383685573455, 60.49965735404723, 43.019461708684126, 50.56951830464025, 45.1348469334264, 27.002702374612134, 27.414359046566872, 27.690023222277244, 23.041077121611565, 25.63352061856178, 19.006446753778768, 23.133150839036514, 31.88056192090435, 26.958601205579697, 34.58293768667406, 30.221762157255608, 29.257684753787135, 27.08676661214521, 22.11652740355461, 18.523657898749075, 12.027705927048961, 9.200887084007263, 8.000450595732659, 4.462658032294243, 2.7063493719024043, 1.1152004426525486, 0.2995409912640049, 0.25537897952862326, 0.11864020639369566, 0.09668041861826375, 0.04125074738816869, 0.06063775910485176, 0.1003050180752912, 0.18817393169287713, 0.1413308726924081, 0.10581102988292133, 0.016786166196388584, 0.11407197813593573, 0.17267555929720405, 0.044642168833243276, 0.22092616696271206, 0.804203862865125, 1.3614430422744443, 2.5677227589391896, 5.28875723961861, 7.3712421136517685, 9.411402652340552, 15.869722424014924, 19.298216181416667, 23.849157940956857, 36.12948509954637, 44.382391206679806, 55.335409871993534, 51.51174614506384, 66.37639553316178, 68.33200300893476, 63.75634639493881, 84.95372910653391, 68.74869992656093, 48.998789479655606, 33.546784770104196, 35.514178968244984, 33.90100225325554, 32.04835503332077, 39.935698201579434, 49.965610581059615, 49.31037472140405, 62.90513715436382, 68.99962963596468, 72.45719894286125, 73.2343146108812, 58.00992504242928, 39.14784308402769, 15.128964185714723, 2.8286263202467277, 0.7362818946280788, 0.0862259384725363, 0.07168739763719421, 0.031403100809022304, 0.02722742941020237, 0.024830503088812676, 0.04535852232947946, 0.03485357997217967, 0.019437946987548665, 0.11442351290175032, 0.028936018070746816, 0.02473052286903464, 0.028067925539348396, 0.07013020901790551, 0.00913917133960152, 0.029037317876974424, 0.04103605890826833, 0.025542267718382423, 0.06549560690238591, 0.04366573231715349, 0.0743608376491935, 0.019974424954383604, 0.05768765026943819, 0.010833631423602422, 0.09300675122968613, 0.09408596993213701, 0.023851425484603932, 0.05873881483210191, 0.059252028623896266, 0.032510457920932004, 0.034445852657119115, 0.012249808153888632, 0.1281937058534353, 0.042029395323967746, 0.0376043948645313, 0.08065231174470917, 0.05481730267826108, 0.09132366372092117, 0.07188115659500323, 0.028512237383232965, 0.026607212287584142, 0.05676087923347951, 0.02393008356222943, 0.011178973326159101, 0.027979258522992174, 0.07974393831025209, 0.06715527510330563, 0.012623786423054915, 0.15704569557020742, 0.15529941346856857, 0.19970899417756066, 0.12499774791180127, 0.1401015773655907, 0.21963244364146264, 0.13166822102521697, 0.1131151113358717, 0.17544795488638265, 0.12327583506703378, 0.22235962472135024, 0.10681947738292719, 0.1539531671592305, 0.11072878575613422, 0.3142214115829237, 0.17570877718108316, 0.12185657291763252, 0.10516432143988148, 0.12862591733855586, 0.084437552178579, 0.06476072173926138, 0.19615736459532093, 0.1119661096843981, 0.11964227238129224, 0.253880649444557, 0.18124495753117148, 0.17662984469244558, 0.12878445157360646, 0.1498989532551458, 0.18224932944342015, 0.1778795792450828, 0.1497888817421852, 0.1323833641025328, 0.125135904208066, 0.1156476831003543, 0.18406783831456017, 0.23001379303393826, 0.16847718296752823, 0.149697502774577, 0.11435844139346193, 0.256046854981011, 0.2671819889257031, 1.219964743621888, 5.465321752332873, 21.522590344952, 48.56283372448337, 77.38605714613392, 83.90361647452079, 89.89130281632947, 86.9458067801691, 81.77971578413441, 81.0595529310165, 77.57376609310028, 74.26664321653305, 68.8837863552955, 54.50455381024269, 57.90741782034598, 52.09118220113939, 31.93328642076062, 29.693599324072565, 26.840694758199877, 23.986533072686967, 26.726887187650128, 23.367685041119977, 26.62027128281132, 42.59725386096586, 38.00744925775836, 52.93681775369952, 47.81873656857399, 52.7527879899548, 42.51547636524324, 35.4988189666502, 37.51016332257179, 24.462402866732692, 18.560810589021255, 17.188077126779866, 8.821047698297809, 5.820120726862262, 5.0947582817846735, 1.2588193748266467, 0.8544299967827336, 0.890662829962469, 0.7527732548694458, 0.26377256058396836, 0.3004429831860527, 0.18488952890038493, 0.373145462644677, 0.5025741788408449, 0.4252510553886814, 0.2413386716357162, 0.551597646647884, 0.47441300124891345, 0.41251085999031223, 0.8530969425074516, 1.9083837323611783, 3.1033390760421757, 5.843936377956021, 10.785467759255441, 10.243039265755685, 15.710494787462297, 25.62188686863069, 22.023361306036673, 37.60017779565627, 55.34493730914209, 63.35467215507262, 67.65027153876521, 67.1186883987919, 94.06771705996607, 97.5395324153285, 74.0234641105898, 85.80126700862762, 70.82244134718373, 52.32645380881525, 37.12128777657786, 46.94959425157117, 39.35701131820679, 39.950387477874756, 45.470923454530784, 63.7982020070476, 58.44957174793367, 72.16217394798034, 78.27943971080165, 82.43963887614589, 82.24654059256278, 66.47443125324865, 45.60696694158739, 18.34186976955783, 3.352207825068505, 1.0690184562436997, 0.17758247502628835, 0.11714843402226126, 0.15246795250042794, 0.19800265590029378, 0.22579948207543743, 0.1492138101809448, 0.1515034784472758, 0.11751051015791394, 0.24698945873927688, 0.18321951851248744, 0.1499621861524159, 0.15904647208029227, 0.11447345417353416, 0.07839034521772016, 0.17677158628019596, 0.10883033561009554, 0.16442848489649836, 0.11901310735171843, 0.114634930186214, 0.23184098934213962, 0.13377024371537471, 0.15796849444027872, 0.19265102613116467, 0.16208352040379279, 0.24431012751113987, 0.3212559066953198, 0.0974026556697584, 0.18447725102305415, 0.18597734310934622, 0.1722440679347323, 0.20514955143294028, 0.2574480144727615, 0.1913531812568826, 0.231728267164961, 0.13613192424658807, 0.18300196486375025, 0.2238883684960104, 0.11924478766177932, 0.24444132772905214, 0.1428427778544926, 0.2634527341973397, 0.12223217816602801, 0.05250429171287725, 0.1359714441482098, 0.23738985610825403, 0.1943391928028676, 0.08926906953415564], [0.059719369070784706, 0.010121921377797282, 0.024498064979730595, 0.03272687392910162, 0.03880101271093853, 0.009634939394140197, 0.06204241195753698, 0.05256320770469405, 0.01786483906119341, 0.04047865716500148, 0.05178538331341359, 0.03450753805678218, 0.048539805856923905, 0.03833404381669337, 0.013652068897030287, 0.04383835873957123, 0.1430525327281606, 0.03543709765278524, 0.09217751467780722, 0.0703958040403743, 0.049692825639560345, 0.060722936590712887, 0.030522434859566634, 0.06392817568754958, 0.015973812307141, 0.04520648068958714, 0.07446216809893809, 0.02539757669212357, 0.05098458011484435, 0.06327825350566738, 0.032465553677250306, 0.05113360719875463, 0.054090204798886855, 0.027307273008890694, 0.038054249354548035, 0.0709901350520311, 0.025033259749292366, 0.029805031822874185, 0.027898026389941096, 0.06169668413818844, 0.10555889502528215, 0.8820909189601099, 7.223390331191402, 21.488000923587432, 42.451675092020345, 64.12969327742054, 69.08363896031534, 68.02594046438894, 64.38594956551829, 60.750383100202015, 52.06534554881435, 47.91490131808866, 60.778212316574596, 40.62800438173356, 33.17520295420001, 32.5429835627156, 23.063324805228945, 22.440305332983694, 26.580214077426543, 14.942949702662808, 17.441183751629247, 25.354702857232866, 29.997155474078273, 47.39678759728709, 40.91230953893354, 47.5544511887335, 42.34376676620976, 38.084155128848174, 30.00103077580852, 23.518635496016472, 14.93624931381595, 8.502642435412254, 5.142210625833081, 3.804424010938214, 1.1807562410831451, 0.2969828091802136, 0.3038257823115395, 0.1798612342005776, 0.04593914036729163, 0.12813180594915344, 0.06861333194519244, 0.03624382271100918, 0.046977813866349964, 0.10386425491061904, 0.15698132886280938, 0.07458583767255468, 0.14602763518210382, 0.042837679371117585, 0.08639085421999616, 0.04247483714754063, 0.0640313370874332, 0.048473117903115294, 0.06827203977492548, 0.051887529646797534, 0.0685835081423002, 0.09533316107286562, 0.18180835391244582, 0.19517439717967666, 0.3420160007813285, 3.471503281785596, 2.316626839099392, 3.767185763966653, 5.2802260844938225, 4.243795169937996, 8.623566166047128, 16.385982824910073, 23.624023698991348, 36.69298456561181, 45.317150854295306, 38.328581548506214, 33.65076680337229, 36.33998693958406, 60.27160290748843, 75.35340647543632, 46.20073141590242, 30.92026568228199, 24.600236915772964, 25.145438524984545, 33.445167926050004, 26.677888939457556, 34.42350118390976, 43.63337932094451, 47.29614350103563, 55.671827639302904, 62.35240851679156, 58.19978737062024, 39.67096174916914, 14.003479288470361, 3.3568445569084537, 0.5074648841494515, 0.09699240026454772, 0.08222187268397502, 0.0767893516909211, 0.14637189977351697, 0.012627094007667997, 0.012968540353129708, 0.01428080587497642, 0.10538241901104489, 0.08016163242920753, 0.03585753819694923, 0.05142015855639212, 0.08260238855596512, 0.06862116902465783, 0.08346020784829894, 0.01728354495078806, 0.0496744548511361, 0.014051297424180854, 0.0540874392214802, 0.04975426972152726, 0.014199816017231394, 0.04601728516600786, 0.10841411237995471, 0.020302274196799246, 0.07116158552948507, 0.04012666274643233, 0.05798450934009687, 0.042920577745403976, 0.06254889949735615, 0.08725063469741615, 0.04927795838504549, 0.06428098215931846, 0.02337172995471666, 0.03912005768788438, 0.015588704695654734, 0.04792970109490618, 0.1282934658229351, 0.028598608051036156, 0.1063464563940802, 0.061616336836689906, 0.042144465560634295, 0.018085495366023916, 0.023539752188709476, 0.01494338765980736, 0.04275284662482239, 0.03980373370371038, 0.01660929756209014, 0.01042990979077595, 0.010325937295302508, 0.009981181450007905, 0.03391353263249321, 0.045094562904729, 0.01984343924109013, 0.059791741396991484, 0.05101577138468143, 0.01182867813059279, 0.008097827066517165, 0.0630305772797475, 0.04798056167219916, 0.11564386032161214, 0.08678745027751693, 0.059533749797171166, 0.10198173939340538, 0.06424232153221965, 0.040146220971139214, 0.04963728809548963, 0.015456748923527138, 0.06776394728090494, 0.042146518676271366, 0.009115020417788578, 0.15379725294488092, 0.02851536302196403, 0.06179666244274667, 0.03161742156671901, 0.03709951227891349, 0.042177633337316014, 0.021019255885133342, 0.02222959245104463, 0.04371329488593244, 0.02300221893575884, 0.027287339401100914, 0.02880287581994649, 0.03428665192557439, 0.03879586843052699, 0.03899797391627104, 0.06512511146044539, 0.008186876169225622, 0.08661385475387497, 0.9273000962791905, 8.137862499683134, 24.754854786780573, 48.382487066330455, 71.99202937464561, 79.90257924602878, 77.67224111864644, 73.83610817693895, 72.10991228780439, 60.654273263869754, 57.06599489335091, 70.96150505927302, 50.890642750647764, 40.82362082696731, 41.09708063064083, 35.143616968585604, 30.185121336290916, 34.791105716459214, 19.92128468328907, 22.36975758306442, 29.339052361826745, 31.883144801662816, 40.67405300755655, 31.372803257357692, 35.12329124635266, 28.080042139176403, 23.183006125111735, 18.18950333902913, 13.131819790409459, 8.80050918748302, 5.668366186080441, 3.214204868962688, 1.458772000285887, 0.5643181995518747, 0.3418781662419919, 0.17992325667892733, 0.13139834357125144, 0.23590333909998018, 0.16202641620991692, 0.08221313162075897, 0.023664145715414517, 0.014936136637604045, 0.21937264790458066, 0.2332882673269318, 0.19221431004904932, 0.15648251369355187, 0.261175032224386, 0.06954779833435051, 0.08391681157292859, 0.09145415913794311, 0.09626806413214054, 0.056809633068980715, 0.11361642395176234, 0.029780101406598286, 0.1609867582878759, 0.1865906424580082, 0.18187606076319374, 0.3726299467586702, 1.82354360097839, 1.981982350830109, 3.219961927783105, 5.167107380205586, 4.7230416344058135, 8.984043751993488, 15.251084239252153, 23.837928195153516, 35.08881753490817, 52.4635406463377, 42.904987335205085, 34.88848247835713, 39.49314109740719, 51.9082820800043, 76.81769001868464, 55.40095267757293, 40.374054447297134, 31.321981107034993, 35.30395953885971, 45.77104753063571, 35.52405941870905, 42.58967584179294, 49.951846984124955, 54.96202376581008, 62.839464910568736, 71.82559536349389, 67.85411711662047, 47.8506842736275, 18.010288284670924, 5.043752270360147, 0.703716354985391, 0.08062893074126014, 0.0760036978810545, 0.026812669407996922, 0.04760698655680303, 0.030893874504873832, 0.04868382272580939, 0.03824229712688154, 0.023795305713710767, 0.0451266888018337, 0.047987326228570555, 0.02647053071057364, 0.03692071884870529, 0.015923873908186875, 0.02724012540232751, 0.01371299874247803, 0.011063208822311174, 0.014512569497099087, 0.04001122861800175, 0.08368749847455371, 0.0565194083197463, 0.027841900873388496, 0.06043331705093865, 0.04229028273614184, 0.02422075647289955, 0.01684441186127163, 0.08748760867503383, 0.041185997636808504, 0.030553932564573425, 0.09217751467780722, 0.05155104467825544, 0.056831569996692484, 0.045760565272141854, 0.028676387042768543, 0.022767474274000814, 0.01908279820195129, 0.05502022404764449, 0.027762080257337902, 0.06381306714648682, 0.03172122839567883, 0.11292993256281461, 0.008719991967682878, 0.0580701886135484, 0.060187609670984174, 0.044050327607340393, 0.0599962753814555, 0.024892448958369996, 0.1379730939985283, 0.09319179210691683, 0.13079633635859336, 0.10166521484573042, 0.20730507770372977, 0.19607641974524145, 0.13950571417808533, 0.13906889084366061, 0.0745000051815183, 0.09572805641519447, 0.13499886488481877, 0.13078732716460384, 0.22343027856080766, 0.23405627047102298, 0.16750287234542832, 0.19241954500396408, 0.22583545756436166, 0.14310070433683936, 0.19204567877515671, 0.2145633011335327, 0.0933397236850954, 0.21341239192312766, 0.2483960268117728, 0.21444046659575355, 0.10356589430762876, 0.16253031820299166, 0.13697370165778747, 0.11216314749852305, 0.17027387365458474, 0.12356471916240071, 0.19290953484033385, 0.12112701972646099, 0.24659872325437687, 0.10164087623237603, 0.07905376203838857, 0.17670222467953162, 0.14407377389650192, 0.2278442167106175, 0.1783130471143992, 0.1484447498355181, 0.18866435053848452, 2.459249366675654, 12.666645319231096, 36.42077992039342, 60.189480243190644, 84.37850567602342, 91.48489121467837, 88.69410130285448, 82.43862690464144, 80.00486681538244, 69.74208724114203, 66.48907738347208, 77.08485834060177, 54.94511050562705, 48.87652920138452, 47.66436384570214, 37.75221670827558, 35.43409985880698, 40.90520220418131, 24.250341884551514, 28.00535236635516, 35.878900558717795, 41.87220373461324, 62.29552238218246, 54.706128335768184, 60.79427442243023, 53.317872093569854, 48.231146335601814, 40.25514779552337, 30.80119036859082, 19.715968216619185, 11.676292938570823, 7.72711826908973, 5.085424021367104, 1.7867282345410318, 0.8567352472774444, 0.6923240759680349, 0.39513803898326816, 0.41874411906446185, 0.44635031192052754, 0.34818656321975494, 0.2878370370355345, 0.17264808738423934, 0.4805665565354209, 0.4273233232238601, 0.23108227118369074, 0.419255007779406, 0.44871225292163514, 0.09990449964759812, 0.20542704380087315, 0.23017146925051368, 0.21883975714445117, 0.1774537109679753, 0.2923575686591287, 0.18163422212725688, 0.3512362979592816, 0.4435818846667967, 0.46099297942653783, 0.8652371684870414, 4.4951269222844035, 2.995708012773145, 5.407772737164652, 7.130209034489048, 6.305422350283592, 11.11098231807832, 20.876083720114924, 29.37718760582709, 43.800229103334495, 54.248838809228715, 48.5672503132974, 44.5409647880062, 48.27424533905522, 73.65976625873198, 87.46673676275438, 60.15707754319715, 47.58686565583753, 37.15540062996649, 39.05885627192836, 50.22805244691911, 41.96181420356997, 50.07407980580484, 58.98716788138113, 64.1887092590332, 72.65825963789418, 82.54529968384774, 77.20394934377363, 56.42626808535669, 22.83914762158548, 6.302686006792131, 1.143685307714247, 0.1879581553681243, 0.21052857650624168, 0.1667562277326661, 0.3251788284509413, 0.14171394729806533, 0.14963322799772988, 0.09594425408830566, 0.15520988843373715, 0.19324302823553163, 0.17519657079490925, 0.12299714760193903, 0.16620735637843612, 0.18902242003429323, 0.2613398024151402, 0.1184251425307124, 0.16478974131807206, 0.09379423598969176, 0.11863481313470872, 0.1995685242957646, 0.25975038447687704, 0.17956799106492152, 0.1652352674113166, 0.12200302594611723, 0.18535958512896494, 0.12042450177813731, 0.2079217171957416, 0.09312737943424333, 0.2167673360916876, 0.20259584330262678, 0.24183904962433925, 0.15288583814136444, 0.234165376713199, 0.2141128261122973, 0.1311339206633068, 0.1059890304121279, 0.3607726523712758, 0.09075395477515075, 0.2162406353219863, 0.11587010906828989, 0.2157341745952445, 0.08125909168513552, 0.1805319748218021, 0.07114660084968613, 0.11991166719986547, 0.1408867868444612, 0.18886831378744495], [0.0585122519893752, 0.04994248220276448, 0.051738456597611795, 0.0367023186728118, 0.05298770085397748, 0.06172767622516521, 0.05882414553554789, 0.024201437650669008, 0.0693443943295748, 0.010205637550942842, 0.048900870756516536, 0.011154745795553731, 0.03472393874319331, 0.03941639581875455, 0.003424908584659739, 0.029731920221820477, 0.011606546148898141, 0.03191535699091131, 0.022274753334180965, 0.030505799260290883, 0.07822255664054426, 0.04658804365223454, 0.12025482096378842, 0.015372376787596414, 0.048149890086102876, 0.08334423745832137, 0.013394622177246117, 0.01573223797153802, 0.014656728092250566, 0.04168801122314988, 0.0199916772544384, 0.011464139022263549, 0.014773975933841882, 0.03627669171340043, 0.06232808997494079, 0.03785047379712905, 0.07868704340991475, 0.03555830042328566, 0.04368161331982382, 0.18114553464035835, 1.9919323007906637, 12.949746308788178, 27.19174296625199, 43.27607493246756, 63.961321615403705, 72.14345639751804, 69.18569118745866, 67.72698525459536, 62.68519809169155, 49.54665830058437, 42.94721557248024, 35.48125067064839, 26.369637712355583, 27.19937982097749, 25.50819696918611, 16.988989383943622, 19.437050434850878, 26.02431812594014, 14.71084442830855, 32.753620724524225, 46.24848235038019, 47.83662649892992, 40.54073949013987, 38.563857078552246, 29.958222027747865, 25.860947485893007, 16.2125934708503, 13.900922056167358, 5.787886198489897, 3.010614000020489, 1.7790548527433028, 0.37306483955152575, 0.12928087654854023, 0.05227222069797497, 0.038186146712471405, 0.0881529713590299, 0.013233683383723181, 0.07901423190149569, 0.2006389636306032, 0.270079180237747, 0.06086581581903081, 0.07095663402710231, 0.00463617068054455, 0.029766740833198833, 0.0281062261051228, 0.04525520388157137, 0.12127656008928053, 0.13610668931036227, 0.027948814188881267, 0.035623651553666404, 0.10265055713393997, 0.010391391847553033, 0.021170447167429714, 0.07430971660200628, 0.0965966852081399, 0.0649877518956219, 0.03620544936688196, 0.08758767507970334, 0.05949025515527014, 0.003151125279292765, 0.04214613563230923, 0.17353284232799085, 0.22115991571016852, 0.6192190019834427, 0.7886001840233804, 1.4402022741494642, 4.248209797566937, 5.231741666793823, 9.196365571791127, 25.429916266472112, 42.58479249092841, 59.01990398283928, 73.34745930087182, 58.26671477287047, 26.5712514615828, 23.40461023392216, 23.661074407639045, 17.41697488292571, 14.787752301462236, 25.84858221392478, 50.76743718116514, 32.1887170499371, 41.33710615096554, 48.992352870202836, 58.56785082047986, 66.55895048572172, 56.3845693680548, 42.3297913612858, 23.142921463135753, 9.9306244427158, 2.411497941901607, 0.6707828479909128, 0.0832595004730167, 0.06400387666578736, 0.029638574323466713, 0.039812589680115064, 0.009773424150602473, 0.07903786571395975, 0.05681277785990989, 0.036477739997808976, 0.02131039036377784, 0.08970501186746745, 0.08055898691377333, 0.032177623361349106, 0.04835515185409496, 0.0355316405635207, 0.04816375627753235, 0.08415990659306127, 0.02961016586801458, 0.06132747572396071, 0.06547549709437356, 0.027661567606452494, 0.020099324099118673, 0.061603799807809057, 0.07278080428800277, 0.04238862544298173, 0.03458522703318346, 0.056863860602700905, 0.15166895343892037, 0.010700435546647397, 0.09596716011724166, 0.014282050767853377, 0.03084842250832627, 0.013322076523646474, 0.014435505839965999, 0.04829135588220051, 0.014856398376005312, 0.044574561573925524, 0.02272795945886643, 0.07023713957037657, 0.021012843729207115, 0.015323821177345612, 0.053500167710045655, 0.01820773810088154, 0.022840214322411248, 0.026059053395123735, 0.01646510640820188, 0.028389435404190616, 0.049474126689376376, 0.0771219717458852, 0.041872144286190315, 0.048013220000411236, 0.009383004676971224, 0.045263243974336696, 0.029773405798140074, 0.03636407170204386, 0.047920967692569386, 0.013181256156625047, 0.04138800736156203, 0.030914317561133258, 0.040926538978613196, 0.05378087381682089, 0.08949937854683207, 0.04969099851986093, 0.0425655189751377, 0.012676964416318845, 0.033109213090351516, 0.03278331162648336, 0.04272473885888054, 0.04788043015005608, 0.019209244844293403, 0.05775652540427062, 0.016132923023354624, 0.011453929943062607, 0.036661689199747584, 0.07014242812029778, 0.04112288348316666, 0.030517953245209593, 0.1489969153678225, 0.016429046649606, 0.015485840154841784, 0.06156818821064888, 0.11286531304640156, 0.07515753844692823, 0.04685443157570497, 0.2000178501851136, 2.4512818071150013, 14.378509848348557, 30.964096207772535, 51.558802820021114, 73.71377729600476, 82.12615520723405, 77.32717452510711, 77.65428450799759, 72.4360102991904, 57.557824811627796, 54.29630733305409, 42.32383720336422, 34.93568035864061, 36.16841854587678, 33.51508025200137, 26.136719526783114, 28.988931794320386, 33.745444974591656, 20.745292286719046, 36.215604659049745, 43.08391801772579, 43.08137239948396, 37.39459460781467, 33.82272351172663, 24.512369940357825, 16.131405311246073, 10.456829032590313, 7.342727953387845, 3.4022945309838946, 2.046101213462891, 1.0994081223203291, 0.09829835034906866, 0.020823223561409022, 0.03481278195977211, 0.05947369999522644, 0.06378264962545326, 0.09703740026921996, 0.1381882880964587, 0.41544758143924904, 0.2392673997148391, 0.07532381783089331, 0.06336248870338164, 0.04513387087612383, 0.026190751570186792, 0.040143945690004096, 0.033224042009321914, 0.6111064373004822, 0.3490045306182677, 0.210214679640147, 0.19757194594750482, 0.34002404960413135, 0.2015779575993938, 0.02529777267256812, 0.07430298268915185, 0.19125654692611388, 0.08303961025611048, 0.1563715381968406, 0.0674228006673436, 0.05687131080776454, 0.046064571943134076, 0.11698304330028834, 0.19141822212165405, 0.05031233413084861, 0.3981222885270273, 0.2415650506173411, 1.3486812431966106, 2.7472981810569768, 5.183368546347465, 9.251895546913147, 18.870499364791378, 31.336313447644635, 47.95419170010475, 75.52808530869024, 67.05834665606099, 33.490989054403, 33.927435105846776, 32.43157844389639, 24.61206482302758, 23.51754899947874, 33.22469149866412, 57.958157600895056, 41.04337161587131, 48.16380316211332, 56.49046159559681, 66.57081957786315, 75.02738691145375, 68.44498295937815, 58.40084414328299, 35.48077214148737, 17.83549374149692, 3.4352676906893334, 0.8419545307274788, 0.09106985113072781, 0.016897913526683565, 0.04923122702166439, 0.022883888994974476, 0.09661213720157262, 0.056436682315242875, 0.030230239349147005, 0.05178329189338031, 0.06160535496629535, 0.057724583368267746, 0.029125869980142004, 0.04694999338337972, 0.011973684210510505, 0.017985111034865824, 0.01825539643065103, 0.01113804029075489, 0.08655469744436203, 0.07768682369421567, 0.02228475652725226, 0.07805151985056939, 0.015667240199212347, 0.08668200593561896, 0.023767462248102795, 0.04362635156740585, 0.02900731978907941, 0.043898473658989516, 0.03592572385264981, 0.03521226999920703, 0.033020469465202866, 0.0262783422330094, 0.05638699002203442, 0.047977079802583304, 0.050451149262728236, 0.018590582880161462, 0.07457355728312846, 0.007545171716746184, 0.044262392236100095, 0.035280846359749, 0.053450628634422064, 0.02989969922289733, 0.03826690387100943, 0.039238851111862934, 0.03205856563703668, 0.04674091649752471, 0.16996671836222374, 0.12147676184653275, 0.2490761443491905, 0.1374014391894302, 0.15601181395111546, 0.16704384778295794, 0.12439320494811382, 0.12294045709554227, 0.11355850770468674, 0.15657432167039764, 0.11669713162606764, 0.06738189157218703, 0.1455272418717223, 0.1559048987204029, 0.16066687061421334, 0.1968256230916708, 0.2057504554789874, 0.1864973635923478, 0.116667453379881, 0.19226890147453357, 0.24891089918392323, 0.17287460426169057, 0.24850042927409374, 0.17558862395103902, 0.161035634697445, 0.11984379180977422, 0.07874381818598317, 0.17365878718274255, 0.06876462664935859, 0.3091771209672574, 0.10988991181816786, 0.14341624063109198, 0.11199660764466371, 0.09381886571645738, 0.12319069971600849, 0.1403715773936241, 0.27268320502292726, 0.13168239365181617, 0.10082339146925558, 0.7999135253410187, 5.031450736907221, 20.23221096684856, 44.093896958135794, 63.13080287748768, 85.62515258789064, 92.06930083613243, 88.28828504008632, 85.62823557084607, 81.92582407305318, 65.70458373715802, 58.79856855638566, 50.21046453906644, 39.62416002827306, 42.269096605239376, 38.697676581721154, 28.902474910982196, 30.415890063008955, 39.28593797068442, 26.996069646650746, 46.279088604834776, 58.2146413864628, 60.023207049216, 53.466129841343054, 49.315312985450994, 38.204654262911895, 31.276365903116044, 19.793313434047086, 16.985147422359837, 7.964229958672678, 4.576380781589016, 2.8133626618692955, 0.7871374463842762, 0.22802574890515498, 0.11572158760240964, 0.14824238004944018, 0.2808805296738302, 0.19016805855977922, 0.24579541877873484, 0.684813533819491, 0.8676706927437937, 0.18919840575225894, 0.3912544941469547, 0.2762605291941474, 0.2525942039585883, 0.1183642921668868, 0.11567366880274589, 0.5067555786621186, 0.45724622724998387, 0.193675990486818, 0.13578997324070624, 0.18137317000617906, 0.2171888683111437, 0.0819312036037445, 0.1978887233041948, 0.1846295493024011, 0.3030570896883165, 0.26030325481007177, 0.31879550807418366, 0.26355183533122467, 0.19865093482357843, 0.35748481750488287, 0.43642319138011626, 0.6896991523042802, 1.0698713266080426, 1.4013433528523291, 2.4372764941184752, 5.4994885383113745, 7.06971824169159, 13.334380792033288, 33.0700324427697, 52.40509733077019, 70.68194204761137, 84.22965957272439, 67.58652517872473, 38.30517676568801, 34.88035140498992, 36.187814666378884, 26.844356290755737, 25.646844910037135, 38.66302636361892, 65.6293801338442, 47.35326497785507, 58.385115438892, 65.21478952900057, 76.93718894835442, 85.40376617062478, 76.43964413673648, 66.96698681000741, 42.75185015893752, 20.108473916207593, 4.213889548855444, 1.2177653971218294, 0.18831726674351001, 0.19867563349825723, 0.2346361990297033, 0.1379240030843404, 0.14642264543762132, 0.14174416180579893, 0.17310292910664313, 0.11238448562160616, 0.1378618427101643, 0.258446165751065, 0.21358894454615734, 0.16527600796712985, 0.15863060891147585, 0.1647863092441713, 0.10785446216863011, 0.14908852416180796, 0.15225085850444534, 0.20294596080578145, 0.13073120356327103, 0.18634612251433635, 0.20112723743002262, 0.18977914636413898, 0.21061525169399478, 0.16140755506292467, 0.15220552142108643, 0.19988340175440236, 0.2452461797023012, 0.1309704987872993, 0.1232845914520083, 0.08261405607505191, 0.1365232726018275, 0.130052495627634, 0.10911209508776666, 0.11418004249853474, 0.13525147471697102, 0.07140734653559423, 0.14054955494019294, 0.10454732954742448, 0.26892192781932894, 0.13095883892909174, 0.15122797790794604, 0.1406071953956158, 0.12385828405498497, 0.12735175990289258], [0.04105874277170628, 0.037124256918867754, 0.05182593617768538, 0.06253960685083462, 0.1098252003712039, 0.04111077546352341, 0.04588807677669872, 0.03447554239462461, 0.07558885360917739, 0.06668524951824258, 0.014643107048956858, 0.061665492868351365, 0.0356704518649607, 0.08883123496367086, 0.03630200708885828, 0.04542514516581451, 0.03391513758669457, 0.012567158161302008, 0.17733461493926664, 0.045202194427650784, 0.11089046095167437, 0.018207234398071325, 0.025331298595354445, 0.03753387647110128, 0.06528697817796661, 0.015281526420655993, 0.030336185478635376, 0.04719557435882669, 0.043064962336493116, 0.017427444991265095, 0.014462330408634679, 0.020357480407842708, 0.09246748661802662, 0.05211430316370341, 0.02491440120784025, 0.06230627945173652, 0.062134066716797894, 0.03668826478984087, 0.22710055984075994, 1.1486836330544565, 11.796670479159202, 22.09349524590277, 47.851982578154534, 63.36543121645528, 69.92771733191707, 66.74314498901367, 75.64814121492448, 61.31497690754553, 46.72847063310685, 39.94577477055211, 34.7318700821169, 33.70554270282869, 27.507199587360507, 22.782508596297234, 18.76308329643742, 19.537614122513805, 32.70045495802356, 40.5001429588564, 29.768759781314483, 38.11380824735088, 43.41089071766023, 36.96528334771433, 20.425811313813735, 16.09904673791701, 7.640658934270182, 5.071675623616865, 1.3545068209209752, 0.4277633028405328, 0.07492319981177008, 0.05177556589666394, 0.0637244729084834, 0.11802873799517272, 0.026660426670024474, 0.036835070218770735, 0.045371499858916774, 0.08194753659829017, 0.04743283561941597, 0.040580382150027065, 0.07923711752218586, 0.07155021427259331, 0.07703321279897805, 0.04955532051803124, 0.07028944805384645, 0.08704115561540089, 0.2581422739932614, 0.420193005833895, 0.2659427038123531, 0.8531432142180781, 0.15682271801896636, 0.029642243884624015, 0.08354552706042606, 0.046704753317059054, 0.08973598480224611, 0.13870916659793547, 0.14631530119767114, 0.09912853684997368, 0.03572274502667208, 0.08790993762593116, 0.017625633852496263, 0.1633607421911532, 0.06532151342159317, 0.1427697390317917, 0.0691729898173963, 0.0532310180396082, 0.025590561901129065, 0.04245146380497083, 0.07000475445942533, 0.30214348387333656, 1.4382265027492278, 3.0694645066415114, 5.546448134606885, 14.265905464849165, 20.02139925956726, 29.848685918315766, 35.21566698628087, 42.34595544876591, 36.441148788698264, 35.33763308678904, 31.468375728976344, 24.786741695096417, 26.36488183852165, 20.846420795686786, 31.402948633317028, 31.832716849542436, 42.83283141351516, 52.38594439721877, 66.3755875249063, 60.72157329128635, 57.82345556443738, 43.43809235480524, 18.218197438024706, 1.9653256381711655, 0.5254392373946406, 0.03488131235503862, 0.0692312278214001, 0.03406803341462247, 0.029813234709323417, 0.023945820923413963, 0.02996349902523141, 0.09645875873825244, 0.08612414070915791, 0.008420303159753883, 0.07941255931772533, 0.0467119928479435, 0.08179205905405745, 0.015873967110359623, 0.07786483954518073, 0.03477030238437076, 0.02126871326547717, 0.05494223629695274, 0.05700349927909913, 0.01807589436911287, 0.0977737026950044, 0.03168263480127339, 0.05852810617896819, 0.04973909735018688, 0.015488397930898975, 0.0013558005030649986, 0.04672939836558315, 0.04052815793622886, 0.09910191529460492, 0.03563418526262526, 0.09402010169240738, 0.055616091065589464, 0.02350021247571755, 0.06870405973806497, 0.03914004875226848, 0.05257516250675244, 0.06596859724771592, 0.013142191418146175, 0.06810261943047086, 0.04425376225563307, 0.057866999113391486, 0.01971592965175308, 0.07386312564654697, 0.021891173110493732, 0.04334382217137083, 0.0357102731152648, 0.055947473888555845, 0.04668792236536261, 0.05474687238494235, 0.018047911092458714, 0.013514391405718222, 0.033943934831768274, 0.05183555824201434, 0.05872418638318778, 0.04027127333345913, 0.05098762148390374, 0.04921589377185991, 0.11351275693384871, 0.013070241397907658, 0.026706317251908685, 0.05300092353155056, 0.03496573907473395, 0.043598891145760016, 0.08065860898744676, 0.050761116097771355, 0.025523954386552496, 0.031025859962908492, 0.05488399829294893, 0.030455082324483705, 0.04425049106019639, 0.0637470227065346, 0.05368751834236807, 0.07170383788404927, 0.008044021838765231, 0.023149945585417653, 0.056545800048737764, 0.03763266350893724, 0.03193152719177306, 0.010509745728585028, 0.04004844133892367, 0.05231936957927481, 0.04171159140945923, 0.2896508880920949, 1.3492228980025938, 13.06766354268597, 27.715489210621005, 56.96068709896457, 72.41487656870197, 77.72857419906124, 79.2399497185984, 84.8366306674096, 69.74921811011531, 57.68398784822034, 50.90074285384148, 42.945654469151656, 44.76721494428573, 36.03885481434484, 29.148946846685103, 23.841287705206103, 27.425884931318222, 36.2879410097676, 43.691046007217906, 30.703046783324215, 34.954280237997736, 34.78134293710032, 28.514617220047985, 15.828463992764874, 12.81981485505258, 4.68103991400811, 2.8881769699435083, 0.681431899147649, 0.24123880441390702, 0.016182004361443462, 0.16314574727608314, 0.013470066516029259, 0.3730620816349984, 0.04148853724942573, 0.3281508818749459, 0.34334660357525276, 0.2154214728263117, 0.12317247448428986, 0.28525311439748735, 0.1349321692701309, 0.19182882992730987, 0.08725199833392136, 0.06752904940156207, 0.03283341760717092, 0.16739188152695858, 0.15191341209555828, 0.15418904563111646, 1.1545435315178287, 0.9818948312632501, 0.8460030296156484, 0.9775440034366424, 0.41305125841209966, 0.6213148959702062, 0.8318634367277546, 0.6226175518766527, 0.57211464571376, 1.0008651907405546, 0.34705186442982766, 0.1617667430471028, 0.1412213374409945, 0.44870137447311037, 0.11749946317004582, 0.4516746536377938, 0.2803563723160375, 0.07141018106091408, 0.02764267779345955, 0.07429131517006506, 0.07306084006784425, 0.21877257123349175, 1.1993883574201216, 3.244233064113125, 6.700823739651711, 15.803502028988255, 23.075693999567342, 28.024711224340624, 34.57656775751422, 37.037035265276515, 37.618660003908225, 32.40760099503302, 36.04548361993606, 34.036916302096465, 35.41487632259246, 28.90276908874512, 41.15015422144244, 43.133155530498875, 50.30750397712954, 62.290968510412405, 74.08357835585072, 70.49493912727603, 68.40906189334008, 56.07106608729209, 29.172126093218406, 5.120415485674336, 0.5464064510118577, 0.03110161456730097, 0.09535147057425591, 0.046274219564492666, 0.030792578529085846, 0.016933971370059638, 0.029070060474858172, 0.04086966461111461, 0.06341252956659564, 0.10354053679733508, 0.01130005160737182, 0.09061470297315428, 0.024041725555434827, 0.02444726951991118, 0.05743957184735806, 0.029452466668801445, 0.006796453399733911, 0.10212414747764988, 0.035812530531397754, 0.050592469502120256, 0.08270662247894273, 0.023641459936756763, 0.05879969583944448, 0.10552918613557855, 0.020150326402677644, 0.06830197849100636, 0.024116338688820124, 0.040633134964493015, 0.1033188998999615, 0.038806877113998904, 0.05309460076293158, 0.03639469606681697, 0.026058423287806012, 0.04613143992760489, 0.040807937076615716, 0.04699218567580946, 0.04635370501707639, 0.046617227771710006, 0.05721795410218258, 0.06384075739450994, 0.0859320288403861, 0.02187336348147402, 0.023402107256134192, 0.04120260642300691, 0.1753758047256739, 0.12145543395872078, 0.10446304455399515, 0.14798883559002032, 0.25151662468429536, 0.16050970001566797, 0.1248124618864348, 0.07406544946734944, 0.12334626919079213, 0.16491666676536684, 0.11752947849491913, 0.18294597915824384, 0.09818637127717657, 0.3228999926678596, 0.12561727555528765, 0.11247882168860206, 0.18093188804003502, 0.11009651040958782, 0.23950986654287387, 0.12806223750474954, 0.2228002325301209, 0.11144272607540893, 0.13215621903298364, 0.22683610628929832, 0.16456618154000852, 0.1525990454660308, 0.11314940909224172, 0.1123294038998504, 0.22490919597687262, 0.13865865076020842, 0.08580564731551756, 0.10185025572296112, 0.21212571661078164, 0.15274605773870023, 0.16940145272641413, 0.14786741065402187, 0.15753438305710593, 0.13127514131126866, 0.6298716690751814, 2.6204992302002448, 21.46464909276655, 39.46695535413681, 71.38780393908101, 83.81203697573754, 88.87008236300561, 87.34516682163363, 94.24935417790567, 80.31524396711781, 65.2314752917136, 55.31272288291685, 49.81799610199467, 48.66150486853815, 41.01961774210776, 36.372617137047556, 31.054887310151134, 33.46645070660499, 44.838680528825336, 54.145668706586285, 44.66682580209548, 50.65539467719294, 55.550971569553504, 45.113803417451926, 26.533720262588997, 20.534472734697406, 9.562347223681789, 6.877046515864711, 2.00924662332381, 0.5780805707458527, 0.2006746480061162, 0.38098618868858586, 0.17359952262092024, 0.6104891542946139, 0.15968298389305993, 0.45542646199464804, 0.19590323790907863, 0.5162803191811808, 0.22433361879760222, 0.3418851223203444, 0.1383000603246112, 0.2348508721878452, 0.2946295709379258, 0.36457149852668086, 0.19610013782737717, 0.45381675804814986, 0.4360137633498638, 1.9817126878807623, 1.628541496972884, 1.9060788495886711, 0.5754548503506569, 0.8469029071350253, 0.4380197799013507, 0.29007232838100006, 0.43562808404526404, 0.4873935337508879, 0.5083851089640972, 0.6773397026042784, 0.20426268208651774, 0.18392701603231892, 0.3185880821078055, 0.6178087873324272, 0.2716578116580364, 0.4672531741521051, 0.37084462481641, 0.13455539190721127, 0.1958862154354011, 0.1322547379400461, 0.16362858185124013, 0.5272440179701775, 1.99311183104592, 3.8631767034530644, 7.5350373502700565, 17.75603828891631, 26.246638067307014, 42.46530140599897, 47.635471667012865, 56.85135887515161, 50.45207861931094, 47.47905146691107, 40.58680772781372, 35.10080429815477, 37.3198656112917, 34.742358499957675, 47.94984179158365, 49.41059912404707, 62.632355920730106, 72.76368510338568, 84.2540410257155, 82.4573915235458, 79.80275492514335, 64.56033422100928, 34.0853811079456, 6.486167619305273, 0.9289167869475581, 0.13088244464128249, 0.21233681979919636, 0.1394244169275607, 0.12412096028246226, 0.21539395494807154, 0.20335828464838768, 0.3433237128680752, 0.2183537816088046, 0.20619823387072933, 0.12806551636106547, 0.20356448487408701, 0.15164097590792566, 0.18123231708042084, 0.2148780100528271, 0.17414315393374813, 0.1313409022986889, 0.20352451040619807, 0.11741911586854728, 0.09496324785774755, 0.22115715779364112, 0.11783159292873838, 0.20668157406391638, 0.12396775035848542, 0.17149734671317762, 0.18393752675864006, 0.16634030327681573, 0.13333941118851786, 0.266639169666075, 0.19235108738705037, 0.14373784434170495, 0.1575198273865446, 0.13312584119698695, 0.14602112343474744, 0.12249176705917045, 0.12878340969402946, 0.19201900359363328, 0.16437182503361858, 0.17186526809969258, 0.14050118414865387, 0.2044119006924091, 0.1584448632333548, 0.12697882830135285, 0.1480442390687043], [0.049010861830245105, 0.08110820300756924, 0.06389398518348895, 0.03162057593374724, 0.03142390392660614, 0.10619909172096562, 0.017582144956254674, 0.08830351529703026, 0.042432644855110876, 0.04420082941050491, 0.02855688115702041, 0.1243070966654247, 0.032661312124541694, 0.03413651018373428, 0.03192918296272476, 0.056408007644237056, 0.02199674194167939, 0.036943038820379206, 0.06342083012925522, 0.03576980197742101, 0.03581562169617222, 0.045653799428574504, 0.10460184436411628, 0.08127812130917465, 0.04276244570651362, 0.06912571453158894, 0.08366067773632466, 0.0536246148629054, 0.02247836992835566, 0.06957904706078191, 0.08154016934455403, 0.07767146363133386, 0.05272128228699008, 0.08837037945106145, 0.026434765895828608, 0.09274392178462398, 0.10623682155123643, 0.3257321890804076, 1.5304435092595317, 7.031296174372397, 23.79126375721347, 44.59583482434673, 66.62672904229933, 66.65991229395713, 66.90808065475957, 69.78876344619259, 58.42721423795147, 42.56483939386184, 32.37890297366727, 29.472305082505752, 26.668130082468835, 19.697091810164913, 23.365194336060558, 25.79695793890184, 36.70967032832485, 28.524095627569384, 46.10018930127544, 51.39789542844219, 35.397578670132546, 32.27707824399395, 21.88071450879497, 10.59069658479383, 7.111159553450923, 2.1751219418741043, 0.6931929422482368, 0.18779700111237266, 0.062228674745006915, 0.04800803741560348, 0.17407180050448065, 0.11544620197626854, 0.07864950510162501, 0.02473769919766534, 0.032035010348584865, 0.06115250507249467, 0.1921912508025285, 0.16614694268472735, 0.09847255874305003, 0.38919469822318326, 0.3484811087048823, 0.021093284876476374, 0.06916161341172072, 0.20809011864325694, 0.08591131382291356, 0.09714025523393385, 0.19726908074751978, 0.35608606352921457, 1.1657063518801045, 0.1227456332755185, 1.0870411343151525, 1.6569550239270734, 1.1229248152625178, 0.8554917333587524, 0.7008793168971617, 0.5814058826335016, 0.5979206545218345, 0.9016606656293716, 0.7151851202211073, 0.13338053478829323, 0.08894354345337038, 0.11404282849041686, 0.20640015932581118, 0.09346028294173941, 0.13207409440750076, 0.044598386908370646, 0.1455923746670446, 0.014235820234452766, 0.07249080170426639, 0.058731425914072224, 0.06337355867388748, 0.12163783183261273, 0.35568457216985766, 1.43162282484193, 6.700433463819566, 16.279858196935347, 23.182894337561823, 52.65558381234446, 56.93658021188552, 48.77534381804928, 46.25431491482643, 23.73888638711745, 15.12396316374502, 23.398869845174975, 17.990272429681596, 27.440619314870528, 36.30679192081575, 42.43693874728295, 45.59940068952499, 48.47024225419568, 57.4631937088505, 60.12907574253698, 52.434593554466005, 37.07401929363128, 13.739575359129137, 3.438850530693608, 0.20763218192563904, 0.1573439642426468, 0.06495173810230148, 0.03370426422465713, 0.05643700790261069, 0.09715988240655392, 0.0758633122689301, 0.027577667572205106, 0.023597335187538017, 0.05219068979063342, 0.0315254278135516, 0.05452373395523718, 0.02966492391762234, 0.06178420968353749, 0.04208442341956881, 0.01803505422186948, 0.047739274619567784, 0.03334093170480863, 0.08327574919789069, 0.043099122197036786, 0.05560781731600723, 0.050345111202688954, 0.04143263581359098, 0.060000400764927755, 0.036244343650797685, 0.046111127106292595, 0.05120581864649731, 0.0531470433117882, 0.02442405514058567, 0.033177414067810586, 0.02920544927849645, 0.024147265658323324, 0.02779542040380259, 0.052520348915770176, 0.018288432057165814, 0.03984046761967963, 0.07422913947413046, 0.04103900068589757, 0.023519831987458373, 0.05215274928618343, 0.041572439198892926, 0.03149346854057043, 0.010405046407193428, 0.031344322713031884, 0.058902026033930244, 0.07365954544154868, 0.03563011350530771, 0.06454453938790868, 0.061367055656568664, 0.055075581561052994, 0.036187829344623515, 0.04355035947575685, 0.018444397982450265, 0.09945230858941233, 0.017690900713205338, 0.01583603330917897, 0.017130377161647045, 0.0879392941151896, 0.018657594506118088, 0.12051250995887865, 0.06823595703369187, 0.052705133153546246, 0.0844463392070705, 0.05881669150004464, 0.021117533474499663, 0.03355021160396357, 0.029851165637674353, 0.0280345298515092, 0.06615468000452365, 0.029043377632455483, 0.041772809495488485, 0.0844856778219823, 0.03931531051714574, 0.07258850089724987, 0.04952643134240662, 0.0645932242754967, 0.017004016704196413, 0.05639394226994726, 0.05305279534490359, 0.44877568500176557, 2.0883137612573566, 7.605207081763976, 27.293169575352824, 51.12550250945553, 75.9705835773099, 79.170241355896, 76.96950143383395, 78.08055985358455, 68.31447001426451, 51.96649005336147, 42.69437566880257, 39.25783026602961, 37.071536433312204, 28.86456716445185, 30.27884637155841, 32.930184256645944, 35.49972503416, 29.704883983058316, 45.451790132830226, 46.39342961772796, 33.600395725619414, 28.02477005989321, 16.892771682431622, 7.274159039220503, 3.6600991747071667, 1.2000976935509713, 0.7724327257563992, 0.09675039308926753, 0.1995031463523065, 0.17002720866472493, 0.4207209936313091, 0.41117817343723395, 0.5161948237688311, 0.25744758546352386, 0.488206843334821, 0.6776026239798916, 0.7544250017212284, 0.8396492189457341, 0.7001621360259672, 1.278560909052049, 1.1889498272249777, 0.15785396429559878, 0.07216726745208425, 0.17313469111198382, 0.10431361910436424, 0.1413067256010348, 0.4409206177919142, 0.963558363578012, 1.3184554586487434, 1.9405643281436737, 1.7666099076309514, 2.7609779373292, 3.9112539300995492, 2.3848628420983595, 2.642282603248473, 2.6708710433975345, 2.6168965331969725, 2.2960017909926753, 2.050991551049294, 1.297040175526373, 0.801518694047005, 0.5179568259946762, 0.8631576381383405, 0.6504554097210208, 0.7783482728465911, 0.7720058002779562, 0.4334754382650699, 0.31506781616518575, 0.18425542260369948, 0.09949028356781892, 0.13210505968140018, 0.1348369905064183, 0.30667713092219445, 1.236003315256488, 4.665960361880641, 12.386379222716055, 19.74617438931619, 43.69603133970692, 51.90476371395973, 50.44448098828716, 43.953695758696526, 30.43939486626656, 23.32031849891909, 31.376733472270352, 28.81415882418233, 35.26834049532491, 46.863357020962624, 51.2825777453761, 55.628681567407426, 58.570235621544626, 68.74073751511114, 71.46523937102288, 64.90949184663835, 50.167455750127, 21.983309984207157, 6.178063481084763, 0.60720122749767, 0.04557074783670326, 0.04159137306194152, 0.10400376718250975, 0.1520672272289953, 0.08148574645841315, 0.08579523618062658, 0.06242254095512533, 0.04332794882957974, 0.030684200070437886, 0.03875884723158614, 0.02234540387777792, 0.011115710742981925, 0.11101134196524659, 0.06147974719023032, 0.028757621091039434, 0.08874433761041972, 0.02724170928911096, 0.04215136418239244, 0.023779344271808386, 0.03138990494452658, 0.0391167137140949, 0.04629080536805334, 0.031301484991525935, 0.012854025530208264, 0.045963628367791255, 0.05668725435351653, 0.020053261147451498, 0.04285510021051572, 0.021717068138382128, 0.06508056344764848, 0.014118410556787446, 0.01983655977153009, 0.05458551128545115, 0.007558575382591376, 0.04164108067690846, 0.06483937598644726, 0.01419380893029513, 0.04128609085455537, 0.047666549892915834, 0.04640483755558249, 0.029454351245095173, 0.09322107964826208, 0.15363381574711493, 0.232183430644293, 0.1712197930582108, 0.1438657350597843, 0.2001934222156002, 0.13712051474759657, 0.10641666069146126, 0.22718957925756134, 0.17083048249684996, 0.105152064033093, 0.2018207155408398, 0.1378316128806722, 0.09031789752865031, 0.08295268992022162, 0.2232721273697192, 0.1046548959528727, 0.16916401143516266, 0.12360152202628313, 0.11300997342914344, 0.1967222318654099, 0.162574690015566, 0.2715090067396241, 0.16664226449305014, 0.13875396741974738, 0.1472169407192738, 0.15617027157737365, 0.119759384242277, 0.1673254004168895, 0.22598539629290182, 0.2095260278832528, 0.22493558004498485, 0.11260662047613053, 0.19199306385651713, 0.11917323504965152, 0.21478044109479075, 0.16175332118666944, 0.9409136012677224, 4.345015364308511, 14.807253345366448, 37.817339820246545, 66.19286783279912, 85.61475046219365, 88.22194207099177, 85.01712245325889, 86.94834847604075, 73.87080546348326, 55.91456743978686, 47.116871572309925, 43.250018627412864, 40.474926041018584, 31.17163665833012, 34.92029682282479, 41.661297890447806, 54.949821272204005, 42.519081023431596, 59.38597094628119, 64.99876499176025, 47.75200528483237, 40.403974286971554, 27.707516993245772, 13.4397493831573, 8.588702178770497, 2.7462337478514645, 1.1329968489946858, 0.27220740313491515, 0.21291737654997459, 0.19793082749651325, 0.5243856519941361, 0.3441955515694234, 0.32138479332770076, 0.29312050030116116, 0.443225898930142, 0.3926419100213436, 0.33013915583010645, 0.5290192581953541, 0.6515341840924755, 1.5762431871506477, 1.7543827766372313, 0.28260977398003306, 0.2862421645512504, 0.4302888495787498, 0.4327486353295465, 0.8999343937443149, 1.41524987115014, 3.1017397296044136, 5.707670296392133, 3.73689133794077, 1.8183853164795907, 4.4812255520974436, 2.610657022845361, 1.7734909706538724, 1.5565321738681488, 2.0300557776804893, 2.975449215981268, 2.4951518014554055, 2.060743421316147, 0.590426659872455, 0.5245155192190601, 0.32056768394766316, 1.0328139989606797, 0.5871670476851926, 0.7208611575826522, 0.7092452421784402, 0.49876466874153386, 0.38759912093800886, 0.30597275904109406, 0.1606462475272917, 0.21986444570845176, 0.4433660623767684, 0.6787843605683697, 2.3847049666989237, 9.202043202615554, 19.384878989188902, 29.485354808069047, 62.263762950897224, 67.90213477226996, 63.67330589602071, 57.480048133480935, 33.913742111575225, 25.131896541964625, 37.35925797493228, 29.713823064681026, 42.36947398031912, 50.982740002293745, 59.048262719185125, 66.20118325756442, 68.51622104644775, 79.38926650631812, 82.38172115818148, 78.16742466342065, 58.52564219505557, 23.59277809819868, 7.744056044086334, 0.7663165249170796, 0.23533877826506094, 0.19078685841973753, 0.1925786921093541, 0.25554741161965555, 0.22026144779257237, 0.16058007285239237, 0.21056096670368027, 0.09872984171154038, 0.14264998416746819, 0.17749301127849088, 0.13195781758235348, 0.12320193056497844, 0.21059202390813062, 0.09991920087486507, 0.11415165894094015, 0.30696836690748897, 0.16932130460777592, 0.24783606250439924, 0.176213629123184, 0.12683298048232833, 0.08329448770851859, 0.14636384052855356, 0.27093955826374794, 0.13769235341779648, 0.10056501299503351, 0.17877076932739827, 0.10597418362815535, 0.12574638435316662, 0.18538978431494008, 0.23648521352198817, 0.09455939694758385, 0.06537341587846318, 0.16529747375076817, 0.09786177982365894, 0.126858874254169, 0.16060285630726046, 0.19946167035208595, 0.09024276728591613, 0.12265362611581242, 0.1684106558921837, 0.11251846673868357], [0.0404169870870969, 0.06154757661504611, 0.01956180808314633, 0.08075479132634017, 0.024525728414676363, 0.059599648680417776, 0.03668527704693618, 0.055371559630598755, 0.019265569543706316, 0.05557821950905266, 0.022892128270600113, 0.04295468397979294, 0.01764105520241203, 0.01635817777095062, 0.006138358974919445, 0.07443361600200016, 0.010777788401971902, 0.06624382199539293, 0.01870261557820824, 0.015627312654208754, 0.03563294803062755, 0.04601624711687046, 0.015063000797864892, 0.1219230540277016, 0.04977411139876612, 0.028144858003924453, 0.014216156672656298, 0.09136294870967827, 0.028490279388103276, 0.0392771631689562, 0.018045857976821643, 0.04774035480354102, 0.05197979727639787, 0.025227915029972795, 0.01595533330879745, 0.08989274937419162, 0.02094192505483666, 1.3820461496230096, 13.071365279536094, 32.769892677184075, 48.58404198000508, 67.2705311929026, 66.44055766444053, 65.2793360525562, 58.15850834692679, 59.4592761224316, 48.06839150767173, 33.80715954688288, 22.07444037160566, 20.562804014452045, 21.8428950155935, 21.69805757461056, 32.257927271627615, 32.19489870532867, 39.128494031967655, 56.33406492971606, 41.975679782129106, 30.84274199701125, 19.17647953956358, 8.658792972564697, 2.887782036296783, 1.8945905950761612, 0.18751253734432882, 0.12457162682567874, 0.08272903821160717, 0.05669563918584778, 0.04551913266280486, 0.03147369006558532, 0.16451975661179713, 0.5199297781913511, 0.11350551740296426, 0.24872055697825649, 0.3381810872064483, 0.7066711867528578, 1.8418904874593982, 0.021243397890019323, 0.312742249018723, 1.0192623938764296, 0.8876419920594463, 0.21640057915881758, 0.09904661140735112, 0.28118819058422123, 0.07422566909583346, 0.0986028626380909, 0.20505984253700704, 0.12069833990667136, 1.3372922736790873, 1.2221016999213927, 2.1106259188344403, 1.6592985175309645, 1.1572035113649985, 3.0375891202880494, 3.6883699028722705, 2.9984110161181423, 1.3767766904446388, 3.2124594142360077, 2.7155323759202035, 1.353864777953394, 0.5373335185070192, 1.4592583741872542, 0.47312027384196564, 0.8950965178589668, 0.6568855227481935, 0.1766170510241101, 0.08944866352624471, 0.10549242923697157, 0.03736334912959607, 0.11345609707096893, 0.11962524224673549, 0.04563200805756835, 0.02451877808198333, 0.08160131082179085, 0.15496852477231335, 0.7549445319079584, 4.8420301656569205, 9.677576653419003, 25.38302629224716, 32.7837033425608, 42.38983108151344, 37.04305610349102, 33.26723744792323, 20.941173491939423, 19.28748457662521, 25.21042827636965, 18.857296666791363, 32.76411306473517, 39.30289829930952, 46.599432499178, 45.30828629770587, 54.98488726154451, 67.6155585627402, 61.51634746982206, 54.452237236884336, 34.82756414721089, 11.418192155899542, 2.5401203045921945, 0.08682638286582886, 0.1745866422331141, 0.07494309511516364, 0.013878135697826022, 0.05290868271502757, 0.008259959041982168, 0.04814149376245276, 0.02997125183502513, 0.04324142302897188, 0.08217948503912458, 0.025609595355607813, 0.11326215425205809, 0.04019383716607287, 0.028344914204471057, 0.013714680305471825, 0.03334180887548193, 0.05684120738277993, 0.09105570914764559, 0.08618702120598286, 0.045801876563458674, 0.05162470786261463, 0.02850903322048966, 0.08157838947109639, 0.13059995738008331, 0.06669408251200953, 0.035119109877174905, 0.01807431431276904, 0.026792837306857113, 0.0452712266105077, 0.04850989778436, 0.05554863702385657, 0.06607486896457211, 0.038103876530282924, 0.03842733034323301, 0.03973614942703036, 0.03239808431375892, 0.04888876273687329, 0.037814597899635, 0.04103845676347133, 0.03836138166427132, 0.07853482940023945, 0.01362049171040135, 0.04208382587098787, 0.03158827575163976, 0.01891707806217094, 0.02614641423156906, 0.01806027766677641, 0.11444436581504923, 0.037982911247039036, 0.055959060968410586, 0.04025352307625356, 0.05244640993975824, 0.044374662421403394, 0.06663681743966957, 0.04212298062479785, 0.01947765715510374, 0.02688610659641845, 0.05547430734300325, 0.023884250436939543, 0.012267446370735284, 0.06049894397297214, 0.039963233209545576, 0.03313278944622124, 0.01918278799782838, 0.028719561842961178, 0.09044474636715266, 0.08181282003680546, 0.0920157398908369, 0.11567271885371978, 0.026210024427141876, 0.04840765568998553, 0.06371929032367564, 0.01989260484885064, 0.009977889187153309, 0.016900859134752425, 0.06896583964267085, 0.07691010246954619, 1.8697384576643667, 13.98415377063136, 36.79709995946577, 54.86667879166142, 77.00837996698196, 78.84282542813209, 72.60699425974201, 67.21797927733391, 68.41529846191406, 56.28997356660905, 40.75424586572955, 29.55701258874709, 29.41884513824217, 32.34200915982647, 31.04503823864845, 35.330529674406975, 37.11268601878997, 50.786044905262614, 48.28203516621744, 34.198710149334325, 30.024519889585434, 16.282445980656533, 7.448870232028346, 2.843336924429863, 1.1379277585975587, 0.11092131131238515, 0.06765713164162251, 0.16928860797516762, 0.639314101107659, 0.3588159718821126, 0.44027351864403297, 0.7041449352137504, 1.5183146826682554, 1.5117387065002996, 3.0625307367693995, 2.6986779512897616, 2.267693800310935, 4.866550862789154, 3.4913629774124395, 1.924285511336019, 1.5635640029945683, 1.003369991817782, 1.1278578086245445, 0.14635795697329507, 0.4231072349413749, 0.16020582357962287, 0.07495165231727785, 0.02586142760851691, 0.22905144870521563, 1.5312765226248772, 2.1269317019370297, 2.5681721154720556, 5.507352890506868, 5.240763608486422, 3.93470676195237, 6.181601949276463, 5.86213372407421, 4.8728575437299675, 8.056478221570293, 5.579287198282057, 5.456724897507699, 3.2822172968618335, 2.9373186297955054, 1.8645085899099227, 1.9394356661265897, 1.6664513272623864, 1.8339583518043643, 1.5172974404788788, 0.9160666119667792, 0.45072531748202543, 0.44110833997687987, 0.5008280499567909, 0.15837829019273483, 0.04169547291953237, 0.11775901375879204, 0.09301802804393154, 0.34142531634819123, 3.368971299740576, 10.357787224554247, 22.589741752993678, 29.013913369947865, 40.97637361095798, 34.28748123107418, 37.4326180642651, 32.626065246520504, 23.664126011633105, 31.73112746207945, 35.65037935010849, 43.167652776164395, 52.12720524880194, 56.61636575575798, 53.44645523255872, 63.448393267969934, 76.01463179434501, 71.72383339174333, 66.96210738151305, 44.65169722034086, 18.02584440477433, 4.015500723354278, 0.5665162590242202, 0.06393487129600779, 0.019817093477374124, 0.04424071194784296, 0.06263516865850938, 0.07882246477228981, 0.030800298780142784, 0.0675195882156972, 0.06439229473471642, 0.053909136087543545, 0.04958028732348354, 0.06187461954992145, 0.09887741322839454, 0.02456043028242646, 0.025134096072325786, 0.12382767118153074, 0.016628622129980116, 0.03993135246057664, 0.037847509036862084, 0.054648525847662846, 0.02878549711538419, 0.03134879092085025, 0.028369327511398063, 0.030227420145585656, 0.08687129093995018, 0.050056732725352056, 0.01561285082941815, 0.05006131010069963, 0.02435795898969856, 0.05188310931947443, 0.033049259049397324, 0.08037548587327042, 0.06667339813805397, 0.05820131988354749, 0.07631837615683194, 0.04456726458644675, 0.106288647399314, 0.03264157386917261, 0.018432243997531555, 0.026807793258358876, 0.1768467241838094, 0.10341920379188754, 0.16628195802050252, 0.24143400361701367, 0.08333735032788209, 0.13100462034344673, 0.17829202566175692, 0.20761693677594587, 0.195086726077622, 0.31394405711081724, 0.15175205865694633, 0.13899162321561767, 0.24559355461068694, 0.1700487510571557, 0.11747072721200606, 0.13020189809462718, 0.16021256515335652, 0.14820717064844025, 0.11511386537383642, 0.09435896536395436, 0.10440497508933468, 0.15110840690472435, 0.06599795373697435, 0.21488550239272658, 0.16376925091589653, 0.13764824207511642, 0.18849058647549924, 0.31184807119350283, 0.20014062343585878, 0.13723179667947755, 0.20162796781909084, 0.19410196601623492, 0.15511325410296842, 0.16056639052206473, 0.09992617227497602, 0.09811571498792018, 0.13039570301771164, 3.233321765738149, 20.596842342807403, 47.28665920995897, 69.43676210218861, 87.49927674570392, 86.44558691209363, 85.23730078051167, 76.0866778896701, 75.40591916730328, 63.63299962012999, 48.55281599106328, 34.412169456481934, 31.683831522541663, 32.7086115267969, 33.46670566066619, 46.65446727506576, 48.08220609541863, 56.451520304526056, 71.12058070398146, 52.154402963576786, 37.76640392118885, 24.631853180546916, 10.691970221457943, 4.381527237353787, 2.2114543664839963, 0.37212003863626913, 0.3049888569981821, 0.2425573489839031, 0.42948697002664693, 0.24575431050071794, 0.47525830266456454, 0.401371022265765, 1.1052009727685683, 1.2093689508976475, 2.574456487932513, 1.9620231250601432, 2.101986898529914, 4.522038794332936, 3.13368498317657, 2.8985822825662555, 5.492202245420025, 4.499291989111132, 3.2240500180952014, 0.32036200466175235, 1.2391263799321268, 0.44120557185622955, 0.5904908273969928, 0.43702070931753806, 0.8158823523309924, 3.5380784061647232, 6.735048380590255, 5.303148906077109, 7.7335975343181245, 8.019699137057028, 5.875959098339082, 8.968498418408057, 7.948213450370297, 7.108568827952109, 10.035195812102288, 10.394082876943774, 5.3396092980138725, 2.688146387377093, 4.182870955236496, 2.0648435238868963, 3.5072164622045334, 1.9228257767615782, 1.1229071645967423, 1.3627335020611364, 0.6186712797610991, 0.3731704983980425, 0.3019762928447416, 0.399423657405761, 0.35404842286821336, 0.15782984784774243, 0.37368291928883524, 0.3115126166132189, 1.3360936218692412, 5.8804820814440335, 12.679974513669169, 32.50015324161899, 43.71452139269921, 59.51032184785413, 48.79696392243909, 45.769843362992816, 33.01540559337985, 31.45396886333343, 39.448061297016764, 32.67674226914683, 47.53455692721952, 55.70394008390365, 63.30967472445581, 64.48589940224925, 74.92435409176734, 85.4000634531821, 84.61143170633625, 79.33047017743512, 53.25589472247709, 22.351210655704623, 5.800376005711095, 0.8245123021544949, 0.4119747210173838, 0.27235902725688876, 0.19148934572454424, 0.22091276042403715, 0.16571713671568902, 0.12119371534114885, 0.16077769289333976, 0.1162376320890842, 0.12348687696841457, 0.21603297952923084, 0.183988165170435, 0.1483957968171566, 0.17944314937678077, 0.2637801295326602, 0.24442925418336547, 0.17914927804902678, 0.12908733209535, 0.1446237177738259, 0.11135993495343194, 0.20339470446830799, 0.10689695185470967, 0.2084535507545356, 0.19824074070540168, 0.21184584937028347, 0.15038811571655736, 0.12474603440252044, 0.20419857584901396, 0.1661400632151673, 0.28890818117126343, 0.1284280674712312, 0.19207224670437076, 0.1722236287089125, 0.09830997190287999, 0.12426373608891042, 0.1240335190067849, 0.1772084096146207, 0.1641630047872182, 0.15298028146066975, 0.14877478051329815], [0.053563890903587305, 0.01286954359872447, 0.09090302782433649, 0.052435677047939076, 0.05801439443002305, 0.027766822341589198, 0.11534713148590058, 0.09739317150125582, 0.010003550259786989, 0.002405479693064286, 0.008259639200273781, 0.03517406519442316, 0.040952681729029265, 0.03262976462381982, 0.07122137869197516, 0.014276917978760698, 0.05549297690571797, 0.07422764560267811, 0.024676944594830278, 0.023730996462907043, 0.03633811281272962, 0.05650352731707597, 0.010601074900478126, 0.04408975049192387, 0.08198571842043631, 0.06624716979962203, 0.0090147462117696, 0.028780052145462365, 0.022039956961488052, 0.07057872285405475, 0.03387783293522174, 0.05586472107097507, 0.011048214566413195, 0.035028301645070314, 0.04809734411537648, 0.07303364394653229, 1.9250316196872344, 13.440050425068026, 31.00970356695114, 47.03542747805196, 70.63232406493157, 66.50446091928791, 69.28795522259128, 63.12948103873961, 55.50428359739242, 47.64628564157794, 34.18365609261298, 26.12531719669219, 32.950808079011985, 25.8322573092676, 27.410958351627475, 27.33811405397231, 33.02727076315111, 51.77601583542363, 34.35454983865061, 30.245270882883382, 20.218390495546405, 8.153089140692066, 4.487171865278675, 0.9970621464233246, 0.3425859089099592, 0.10478561353539267, 0.0615738112960131, 0.20179716599804742, 0.06997961145375045, 0.32592493680215656, 0.6648433376704493, 0.7123057940794576, 0.798298979718839, 1.868893799762572, 1.2893439949520173, 1.1880715840285825, 2.6139194542361848, 3.1800912801296484, 3.9107999157521034, 3.9606814326778537, 1.1217158672309693, 0.5962125235988248, 0.49559665002649833, 0.803586395998155, 0.22697570283086071, 0.07955876719807425, 0.02517688399811666, 0.16390054306435972, 0.04644678086943684, 0.6115977754515987, 0.8086531789552781, 1.5419794450844488, 2.00319648990708, 3.269537009539143, 9.310925256821418, 4.855257868766785, 8.220116563381689, 5.415986670601753, 3.304183550419346, 3.5812531603920847, 3.4242958407248225, 6.166538576925955, 2.8992110875345047, 2.4346965551376343, 1.784566518279814, 1.7815603892649374, 1.537202978807111, 3.0548853018591484, 1.3616901515953004, 0.50784440410714, 0.5636461259376618, 0.5151778267275903, 0.24920064895864458, 0.13065359885654143, 0.12920290411960694, 0.021448592625318036, 0.05122077268277926, 0.16354567581607451, 0.11744458829202961, 1.3239810976289934, 7.988347141973435, 19.335643437600908, 30.36900204996909, 54.256361915219216, 42.213402871162664, 28.067225794638357, 29.642053496453073, 23.458578125123058, 17.710581940989343, 24.45560539922407, 23.252200657321563, 25.37881955023735, 37.08404094942155, 47.97697674843573, 45.25171787508073, 55.71092974755072, 65.93896496680476, 70.03452347170922, 52.29734982213667, 31.227218604856926, 8.903104662895203, 2.566207988608268, 0.3608324378728867, 0.10456310329778541, 0.016559553557946798, 0.07940192601733631, 0.05221244668768299, 0.04407519865180216, 0.04964851511401996, 0.022678516144233368, 0.08199516428454269, 0.030667597029898918, 0.03238552813267997, 0.011972053400841693, 0.00864303077480966, 0.1017912975963085, 0.04420355668351535, 0.061093451184851516, 0.07013807674088786, 0.03203468859165667, 0.017880451933090246, 0.01307654342869477, 0.07817552650287267, 0.042521610645757574, 0.04865239396871579, 0.03685724463373904, 0.0885099683317446, 0.021556850425117922, 0.04267182899639011, 0.022326402982035955, 0.03782149652139314, 0.0743265628754612, 0.03750740047243815, 0.04447568643597826, 0.016383004765356743, 0.0923823282843636, 0.09111875818381387, 0.06125201606341909, 0.03625819069002906, 0.02532285247598925, 0.015876231857785778, 0.0035759823203402306, 0.028582347834843303, 0.035147573874001546, 0.03692059244419779, 0.06821902649056527, 0.04366511561637444, 0.05956511343679121, 0.009162648104041094, 0.02724323571930009, 0.03321889006803113, 0.04129438758677533, 0.06254209280614892, 0.030708938964732715, 0.0429441885752303, 0.01266048011940814, 0.07039799505183775, 0.028153307953729268, 0.02972097474060232, 0.07143540833626064, 0.07383384576608097, 0.04847443940478468, 0.04013179936596463, 0.022227824703159354, 0.042135904528080456, 0.010009947093954731, 0.004074311263168291, 0.028323117087805466, 0.03760201233108679, 0.07100412381752845, 0.08324460006288945, 0.024141184835424347, 0.005980452931966754, 0.08222927309332356, 0.027463861380613623, 0.04916811669846216, 2.2077217409687657, 16.110753051696285, 37.021596816278276, 55.25246350995956, 80.58685241207, 75.84493437120992, 77.78925326562698, 71.82321840716948, 63.467589347593254, 55.74323831066009, 42.775772694618475, 36.121918847483975, 40.72751099063505, 27.51826459361661, 28.976307645920787, 25.950671703584735, 33.40422622619137, 46.86016028927219, 34.307297045184725, 30.787656230311242, 17.360243681938417, 8.23026716709137, 3.8105039298534398, 0.9651254730359201, 0.1533670332883635, 0.10491997003555299, 0.1278455495353668, 0.48593606679670276, 1.21203861409618, 1.2891130654081222, 1.7775220640244025, 2.887827633850036, 2.8686170904867114, 5.679024246431166, 6.212218499952748, 3.7967413135113257, 4.243443627511302, 5.016544749659877, 9.019206819995757, 6.7889883249036735, 4.440983014722025, 4.302359098388303, 2.2115166341104815, 1.8801973351547796, 0.16900795932498672, 0.032679679082526315, 0.05765981063426984, 0.1924997084443608, 0.2589545723411345, 0.033276530523453994, 0.5832204078474353, 2.7311858198335095, 3.5803431705121076, 5.954515347557684, 7.458162817262835, 5.50033429937978, 6.78907657823255, 7.416867123496148, 8.713309995589718, 7.135121312833602, 7.385036599251532, 10.723605117490216, 7.188001236607952, 6.622599421008942, 3.1867669090147945, 4.139177712701982, 2.728292581535155, 4.747650094570653, 3.561687887676301, 4.302233582542789, 2.878361483735423, 2.8228491592791776, 1.3892737295358413, 0.9470872280578461, 0.45352539948878756, 0.1889491054199396, 0.08924994031868635, 0.13563007536915042, 0.17770457411966017, 1.0155423934901915, 6.1254997984055555, 16.998008874154863, 28.593727504053426, 43.98433339211249, 31.093491277387066, 26.290423485540575, 34.21242275545674, 31.85232673921893, 24.558832376233994, 34.73418428051856, 37.649811467816754, 38.10923476372996, 48.859235471294774, 59.47271024027179, 56.919082518546816, 62.35528361412787, 71.43702968474358, 79.83661282447078, 60.73684700073735, 39.88254224100421, 13.425942640150748, 3.9016512324733124, 0.5136137203343454, 0.05178706104596777, 0.08032186737945003, 0.029597831852433663, 0.07451566401869059, 0.10117678782872616, 0.03372949533044331, 0.04618775505091875, 0.018488664457935, 0.04930140833640772, 0.08038559057299169, 0.04750793904907281, 0.06443235347227705, 0.08256915566180983, 0.014604644647108452, 0.023051150886702444, 0.07435696890517589, 0.020266049729299643, 0.053409677404429645, 0.010855206374769971, 0.03206781040306293, 0.03774634329602122, 0.08760400807424899, 0.021313983316142714, 0.023443625391190572, 0.022131389555250926, 0.024039097873854543, 0.02446074117605965, 0.023560773641351732, 0.0753527912761896, 0.06098590776204102, 0.028519476914117416, 0.046211963429326014, 0.09075296652172843, 0.07854568486612651, 0.014564167434019188, 0.03422606203164305, 0.05324795624361404, 0.13238699535929388, 0.09217725420791296, 0.16729222880976816, 0.18953413612419562, 0.18847223100883348, 0.17781522785944326, 0.15549153299821963, 0.17417638682790343, 0.13309283812920894, 0.14091355395653557, 0.1333426900448338, 0.10126560806266724, 0.14286350819372362, 0.2084325905889273, 0.18956156207188485, 0.25743358137626804, 0.1546242601809002, 0.22736726569071894, 0.15077990840279287, 0.15843277436590966, 0.20017066940424905, 0.16802460886538031, 0.08785794323851025, 0.1093602309664411, 0.1546672377134523, 0.18186839988395093, 0.14670531655992233, 0.14722765062845525, 0.1495227734408071, 0.18423525916953243, 0.10301660160504042, 0.1823805603048494, 0.11632587009620284, 0.3048986424842189, 0.10100724491020364, 0.1382349275292889, 3.789870301561971, 24.454244336774273, 45.41292336679275, 68.40980714367282, 90.81935913332048, 86.62090901405581, 89.82444209437217, 80.69315648848011, 70.70101261138916, 63.37797103389617, 47.519271450658, 38.678562871871456, 45.76242223862679, 37.201249214910696, 37.86426705698813, 39.06930938843758, 47.25310725550498, 66.16057103680026, 44.4919704621838, 37.9166660001201, 24.752495481121926, 10.178290740136179, 5.546038737220149, 1.2561261774070802, 0.5721837162010132, 0.33360882932620667, 0.18525545845829672, 0.39198295183239446, 0.6804592739189825, 0.701012003325647, 1.638206094503403, 2.734275421788616, 3.6491363952236795, 4.9463985523869916, 7.356115983378503, 6.028556458411678, 7.715409994125367, 11.633335140443618, 11.888108772616233, 13.222975673214084, 9.227922020419951, 7.542638903664005, 3.171459859417331, 3.0523659144678428, 0.8004993680984744, 0.19800742096718282, 0.4421233145460006, 0.6186837823160234, 0.5523276365091724, 1.7923407785354124, 2.239660865837528, 4.77015910610076, 10.338344035610076, 13.6652817456953, 22.23776590439581, 15.62243659650126, 18.031118031471006, 12.947656666078876, 14.44043524803654, 12.06718752461095, 12.919016499673168, 16.588627176900065, 10.460356223967768, 5.755449668053658, 6.4450190144200485, 6.785477313303179, 6.8514608952306935, 7.636023673319048, 4.39613365357922, 4.864995152719559, 2.8865082465833236, 2.459169693531529, 0.9950012473329422, 0.954279384065059, 0.6560141436995999, 0.2926264042335172, 0.19674492338972707, 0.3952663740323436, 0.34972419361433676, 1.8755590098519481, 9.60760941428523, 23.46199058717297, 38.25358190844136, 68.14105418420607, 56.41206518296273, 40.800290569182366, 42.983505341314505, 34.95965780750398, 28.496240915790683, 36.155772824441236, 36.98749965237033, 40.3902538361088, 53.80463823195427, 68.13043240577944, 68.36589228722357, 75.64700372757451, 81.72291201929893, 89.77813459211781, 72.71070957183838, 48.43246982943628, 20.77256844889733, 5.77842200956037, 0.8708133079832601, 0.2023941629956807, 0.1114410943081302, 0.19361770651753873, 0.16353040002286434, 0.15641240132672174, 0.1650168097788288, 0.11026679643339689, 0.1609003129265001, 0.14268830388544068, 0.13817621455077203, 0.11380512672927111, 0.19842213500411282, 0.17120424147334792, 0.10249586099939001, 0.11710252237295914, 0.19855259977761777, 0.11677367913146174, 0.13027657634548603, 0.1116290156759562, 0.16873682548682536, 0.12230353925617472, 0.17344708644574688, 0.11836813792826668, 0.1752030978640241, 0.12810437234058497, 0.15752816242316078, 0.0789108943013895, 0.22109130487566997, 0.12927197460686007, 0.1522486521712234, 0.10457038113306608, 0.1809385070397008, 0.32386222974427287, 0.2042718751416091, 0.10327826659645765, 0.17044327101640164, 0.07861307762082546], [0.027510845553009745, 0.057875598450341535, 0.0722282710334947, 0.07707440534666662, 0.06055654229355916, 0.046766768134529554, 0.008750139442723124, 0.07855734472433407, 0.052343577957682075, 0.05618601451597868, 0.06336813477138359, 0.035953249391769214, 0.08808313478385249, 0.028532690015591444, 0.0444973667242354, 0.027619017167918147, 0.03389242691017928, 0.030644468835464893, 0.05338996596213791, 0.04310406346414839, 0.06300434259878052, 0.04163989707106545, 0.0612586580457226, 0.044648481397739345, 0.07688818469403252, 0.0314052650074084, 0.09163903147583047, 0.050885766263931036, 0.0658628924359237, 0.016276106771622455, 0.024019683290633465, 0.04135608830819688, 0.05081960308035055, 0.06367106891928181, 0.05599175760101888, 0.7751091305286654, 6.807187141910677, 33.36793253498693, 50.54469754618984, 67.98743063403715, 77.78261661529541, 65.33091914269232, 60.644788972793094, 50.15080528874552, 46.39515938297395, 35.116356495888006, 39.715323755818034, 26.261597987144228, 24.579464043340376, 38.266215862766394, 41.48616406225389, 59.89152523779101, 51.793760638083185, 35.5858406712932, 26.081951472067065, 10.176847307912766, 3.655938275398747, 1.2065366319110318, 0.10957623711757122, 0.0499834870589116, 0.022283576751848864, 0.1509968798247076, 0.2047486882656813, 0.3484525489470651, 0.5118730459963122, 2.9191002009376406, 1.5479158297661813, 1.6252378806952508, 3.232491203854161, 4.312433215879626, 4.921806271999113, 5.798527098471119, 6.1668254002448055, 3.0445640750469702, 8.22531762623018, 4.390185379212903, 2.49008140256328, 1.47444995901277, 0.25938419444907096, 0.5797775474286849, 0.1001667085614416, 0.2585841535079864, 0.04323665030120362, 0.30665669169637466, 0.13706613782673113, 0.10044266109264667, 0.9948469878685091, 1.6521480367068322, 1.5201405459834685, 3.8615229341291615, 3.6556117380819018, 2.8416157393686237, 4.33762610920014, 6.333198124362577, 5.349069074276955, 10.388734725213821, 3.685359483765018, 7.149436493073741, 6.649418627062152, 5.540875427184567, 2.5640930956409824, 1.6446290982346383, 1.6237837845279326, 4.679361139574359, 3.9630721172978802, 3.4208436646769127, 1.7912343024246156, 1.7616575475661986, 2.05744814007513, 0.4636089245398199, 0.2448777986630317, 0.09165331135473906, 0.07822411179903054, 0.0454370271895201, 0.07967193370624896, 0.08380780492218272, 0.3181400126026523, 1.883054536677176, 11.691309732775535, 29.460208492894328, 55.45068048661756, 41.52945526184575, 32.358083032792614, 27.023461518749116, 23.948407634612053, 21.48133485547958, 67.44111507169663, 47.80518870199881, 25.957822184408865, 31.36056938479024, 33.25225399386498, 52.53203307428668, 54.40503543423068, 64.7783120985954, 64.58438227253576, 62.07858393269201, 50.11280536651612, 30.045773252364132, 5.626981748688606, 0.7890053526047738, 0.05220026972012655, 0.11324697038939885, 0.08681938848308018, 0.03745677738240169, 0.017822589312169342, 0.0175060149687793, 0.025752698664643595, 0.1092975726351142, 0.036126481023647135, 0.057840760601984884, 0.04040166915905091, 0.08958560940358909, 0.0542728363295957, 0.062136954868272434, 0.029293790707484852, 0.0160624391038812, 0.06090133165520045, 0.030860392632143154, 0.023232545185413574, 0.011704756705571088, 0.07120430259214294, 0.05911323647465437, 0.0320177101680348, 0.01497906245922129, 0.049330615438520915, 0.07007819164784686, 0.01672186269124429, 0.0811422019896488, 0.013697083265851102, 0.03664530640948684, 0.013232914422969184, 0.04590030737040986, 0.03644465649079892, 0.053051389573562535, 0.02803911680295583, 0.05994609662241513, 0.047099208158831445, 0.09561205538169992, 0.019104378898778272, 0.054284434900769306, 0.025634924137604334, 0.025756090518928347, 0.041690719343962214, 0.0397862515772783, 0.02370735690478356, 0.03693618616389652, 0.02206093244885485, 0.006438612772692596, 0.03842174173182538, 0.0769791346524031, 0.013646562640074522, 0.01576295139403233, 0.02480633876046106, 0.03643221139246899, 0.06031681039941408, 0.0479918806212804, 0.039940365485005805, 0.018665286028877865, 0.08157195433253243, 0.042453555225004116, 0.043153671487685175, 0.015465058104675865, 0.06916340605746354, 0.0427469247651677, 0.07253113623347975, 0.026802601097452066, 0.05860036742242594, 0.017889892051537192, 0.04759165713743818, 0.07851773031776951, 0.03611842943956295, 1.174969764486436, 8.98186291417768, 39.4705835465462, 55.97480327852311, 76.63628824295537, 87.03303244806106, 74.72138712483068, 68.97389888763428, 58.82719009153305, 52.92487413652482, 43.56636954892067, 49.660442336913086, 30.020793637921734, 33.83807566858108, 45.36007727346113, 39.12275560440556, 47.14809363888156, 44.9234821719508, 34.93613143121043, 22.704612285860126, 8.41559817714076, 3.4481171302257048, 1.1996843737940635, 0.15143560305718454, 0.20190720686749106, 0.49019689461396593, 0.3258863872578067, 0.7358253062252076, 1.7826357315624914, 2.390664517879486, 4.634132779413655, 3.9727824349557204, 4.684894132998682, 7.841004287042926, 8.202933149953044, 7.891036079775903, 7.490715547915428, 8.377101094492021, 8.56925997041887, 10.326861296930621, 9.521013286805923, 5.301699590298438, 4.056487775618031, 2.060000132168493, 1.0726569448747942, 0.22898781744222488, 0.42336270994236397, 0.7246833234544724, 0.3664120400865232, 0.14305547450578984, 0.25105349389055087, 0.1588078203701204, 1.4919445879997746, 1.9640381201621027, 3.496509127078518, 4.325721225430889, 6.961793245807772, 6.789898314783651, 7.64208177405019, 9.04658398320598, 12.115572902464098, 7.503689767852907, 12.676789549089248, 8.2334295780428, 6.236619564794726, 4.077259912606209, 3.5765362651117387, 5.0297518603263365, 5.689771540703313, 7.2605430214635795, 5.672491048612903, 6.921706622646702, 4.7202243920295475, 2.42660102825011, 2.294962853193283, 2.0738814002083195, 0.3989363641988847, 0.520196192927899, 0.11610368161552376, 0.2256518569324286, 0.0862602821941818, 0.2454382685884353, 1.4145717914066007, 9.81438990562193, 26.35681744544737, 46.35609649842786, 37.59433738646969, 33.474671994486165, 29.75424308930674, 22.146492350486017, 29.509940224309123, 67.31636016599595, 43.23586671583114, 40.48497123102988, 45.50203177236742, 43.99704579384097, 65.06887735859041, 64.47732902342274, 73.79194228879868, 73.89189212552964, 70.50512944498371, 58.504096615699034, 36.966209027075, 6.86587707650277, 0.9204287166076323, 0.015474852538787791, 0.10753652801917446, 0.04882834904316453, 0.041283129924728025, 0.04176341342709718, 0.03168568766165165, 0.06094446623577707, 0.07943546534666131, 0.04812158313730071, 0.04912832609167503, 0.026621335118468252, 0.04892072009463464, 0.05855748565086435, 0.05017935275851239, 0.046010026482925306, 0.019924581358810107, 0.05823486687375173, 0.028339283458227595, 0.037736181139705643, 0.038859515015276215, 0.03431280616730933, 0.01732713152324, 0.03780263926713698, 0.02620273701576216, 0.013683751420748812, 0.05651336771646335, 0.00509684281085708, 0.07381369765367239, 0.014726188326735171, 0.05227295614238228, 0.01881271773468583, 0.03780730091215622, 0.012614247670787717, 0.0803652279559643, 0.061810838899785475, 0.07245852642001645, 0.14936069987954634, 0.15092434662003673, 0.19992843240259156, 0.15028366728896095, 0.1040661650439424, 0.11032439092354429, 0.15153154790882142, 0.21196005775803523, 0.15246444381773472, 0.13790030032396317, 0.15801936267845093, 0.11889283154760638, 0.1663812430154893, 0.14802907052780354, 0.17392561560676945, 0.12170630477128491, 0.1085453662240217, 0.1602846999923068, 0.18878255790520101, 0.13472786894248379, 0.2031662876928045, 0.12281561540740153, 0.1896034517595845, 0.18733247603860595, 0.22397646860730266, 0.13540069332286236, 0.23827913097075878, 0.1311539462016475, 0.19326645520425614, 0.09331202194575342, 0.13887350777945212, 0.14879715028068713, 0.19786354965500294, 0.18764422785851265, 0.14472111819251893, 1.7561913570088727, 14.404749524208809, 51.140627168839984, 71.19818087547057, 92.10741058472665, 96.15017398711174, 82.67236094320975, 77.93047428131104, 66.93241503930861, 61.92607433565202, 49.6396263184086, 54.259872436523445, 40.76537362990841, 36.368141712680945, 51.40162560247606, 58.30253777965423, 76.18943614344444, 66.70668263589182, 45.19338046350787, 32.37783020542514, 12.89987337204718, 5.178609240439631, 1.9301503127621067, 0.3861359542896671, 0.3257884199340498, 0.43228499891777195, 0.40204720211125194, 0.5634058194775735, 1.8208902401308862, 2.0279951850252766, 6.507142984098004, 6.705309950536297, 7.559399681706583, 12.70550718230586, 16.17423563234268, 12.742208800008221, 15.27883500822129, 14.895633170681617, 9.651602718137926, 17.97978597302591, 16.331867844827716, 9.540870285803273, 4.248289715859198, 1.5485512537340966, 2.3898648446606052, 0.649995205383147, 1.0399744082843105, 1.2879956802052837, 0.808771585504855, 0.2546060581000582, 0.7721307645401647, 2.2762862424696646, 4.694494624291697, 7.286606680962348, 13.976839530852533, 15.205091507204118, 12.582714442283878, 14.805071526958098, 16.239663708594538, 15.484362302287934, 28.961975305311142, 15.46486125838372, 20.143173163936986, 15.968136652823418, 15.705324122982642, 9.310745808386034, 6.781224973740117, 6.161188954307187, 10.493204112975828, 9.72097081522788, 10.050240062898206, 6.857478791667569, 6.966978128879302, 6.967861152464344, 1.372120591901964, 1.574533891773993, 0.5134590012171577, 0.5570898229076017, 0.15241803421128183, 0.2850372614639421, 0.299467354892723, 0.7078924534782287, 3.045110510241601, 14.94503346181685, 36.380708986713046, 68.19023286142658, 56.79462179060906, 45.29094157680389, 39.560233239204656, 36.30952973519602, 33.22246751477642, 78.07268373427853, 58.07745648968605, 40.29241423453055, 47.32860895895189, 49.312265303827104, 75.15914717028218, 74.13889946476107, 84.52696738704559, 83.9423930260443, 83.99383098848405, 69.75173627176594, 44.51472413155341, 9.385537562831756, 1.3378094136714938, 0.1646005942095672, 0.22232893523910355, 0.18597510613260732, 0.17414059520008104, 0.27220645318588904, 0.1359583287229461, 0.16480846450694148, 0.19571153206690667, 0.260059179197396, 0.1521262159991649, 0.08966138316017967, 0.17159396572218788, 0.21431467495858672, 0.1228875740461292, 0.11026309622872262, 0.16507587515779082, 0.15866633925226428, 0.11970113857739395, 0.083629704801546, 0.12372205830028943, 0.16654817357419, 0.1537043418014242, 0.1384316742300026, 0.07717614182301107, 0.10576753141058069, 0.15297504141926765, 0.06822910820764881, 0.15602511323748097, 0.12950592253717685, 0.12260330946094568, 0.1032421915161033, 0.08843475381933874, 0.15102211476093338, 0.22706965585389446, 0.17920627499059325, 0.19383296190250307], [0.11000719987937521, 0.03061313966980144, 0.07908203068279451, 0.05164651072493965, 0.0029500683763950706, 0.02630265594850625, 0.05325282473237284, 0.03903702524821124, 0.048039523629291404, 0.045301858636160056, 0.050390268255385666, 0.05354387302612586, 0.04961065504880202, 0.031113421897433942, 0.040710754992981116, 0.09319708577447361, 0.031150931477426525, 0.035947484580139, 0.08006709717935132, 0.008510140375414444, 0.057388784048417886, 0.03003443876701978, 0.05460659785556698, 0.06335723334022107, 0.07565707373883455, 0.015451872773889094, 0.03066852974194673, 0.06437315785836789, 0.06174565247830845, 0.018636965673537027, 0.01886898880794404, 0.03230605034097549, 0.07791024557645283, 0.008336967157740748, 0.5072947206997103, 5.88069437972961, 30.995861522613037, 57.86932768360261, 80.08330637408842, 74.29283680454378, 67.79322624206543, 63.128425921163256, 62.14189098727319, 37.135914294950425, 31.318886356969035, 33.199855050733014, 16.859610003809777, 27.53879035672834, 31.610426325951856, 32.868699143009806, 43.676090009750865, 42.983540642646055, 22.552169369113063, 11.68777959962045, 4.13137415724416, 1.9416518052739484, 0.5110879284479927, 0.18729529013076138, 0.036260542579956596, 0.15004728319904498, 0.21058791767685645, 0.1859034769116871, 0.6526502822676014, 2.3913560807704926, 3.8107988430607707, 3.4900605053670946, 2.479290471922967, 4.842954374128773, 3.4407089987108788, 7.325116021017875, 8.342029221596258, 1.685421502878589, 3.107044980410607, 3.65332622201212, 8.499034835446267, 5.636147837485037, 1.8080486453348592, 2.7808802887316677, 1.0406359405286851, 0.9912164052647929, 0.10607934451752132, 0.16046489919385604, 0.7268583390020555, 0.25827735061607054, 0.037151295992155234, 0.15336551643427343, 0.531676909135234, 1.545682530249319, 1.333649127233413, 3.734841899525735, 4.368497613937625, 3.8612733733269478, 4.29837397029323, 5.101614584845882, 7.20954534507567, 4.464895254181278, 4.14234257513477, 11.58242081442187, 6.331787541989358, 8.518327013138803, 3.0570411345651074, 3.703206268049056, 2.3169585245270885, 4.710257159125421, 5.445077419281007, 3.853531840347475, 4.241571676346564, 4.636533269959112, 2.5959022919977865, 2.568811216662007, 1.69038440431318, 0.9152515557023787, 0.2600993834916623, 0.06603701656023342, 0.12091847527171336, 0.022857058680646365, 0.0349951530205867, 0.4086465592826567, 1.7353031423784073, 7.375034555312126, 16.100073418309613, 32.94948231789374, 46.964440422673384, 28.29195603247612, 40.89997368474161, 42.23496021762971, 69.25551722126623, 67.49036435158023, 24.853057207599765, 25.6926562324647, 30.149286562396636, 33.412129802088586, 35.825136630765854, 50.541885206776286, 56.43858825006793, 59.871760414492705, 56.445268046471384, 54.29247517739573, 20.27260353488307, 2.640008609141073, 0.26702662629465906, 0.024563232249009515, 0.052309464062413866, 0.09816337331768968, 0.052729441123383666, 0.07534111609622356, 0.042838648472341805, 0.05532417326204239, 0.0742797242597707, 0.047475219433826786, 0.09616953756419883, 0.07403654496996634, 0.03522121024528339, 0.04661632761839898, 0.060703160030947584, 0.02247697947877309, 0.05720820180290649, 0.02857034515228964, 0.04219387440131076, 0.025147531339297854, 0.012358954615680682, 0.011793780910422005, 0.09217873275760682, 0.0953849715991847, 0.03055828777442296, 0.07135158299558586, 0.0659880099157172, 0.044126599321081754, 0.04518102741830292, 0.060495408477201584, 0.009932389310110482, 0.04575132242133541, 0.059489818485153306, 0.03005571302867705, 0.03886691542462476, 0.05813022309373464, 0.12221617458928978, 0.07042909822156353, 0.07283264545783882, 0.08563513912621044, 0.0269734004001704, 0.005402168589493921, 0.020394683552665577, 0.005528059339285979, 0.0761880033138779, 0.08127611415881304, 0.049920813405826214, 0.021793313039046143, 0.020601910336183447, 0.12279345248375209, 0.028306324440505237, 0.06940113846212626, 0.0696967181659514, 0.02030572733811794, 0.021858646932448593, 0.016171378721933694, 0.04077706756370683, 0.04961073548803407, 0.022442386778552207, 0.040850688613230185, 0.10029349611291002, 0.07403639175238148, 0.034661954569239775, 0.07769442328642454, 0.020721297478303313, 0.050157833348719344, 0.038542871723972985, 0.05511507722398928, 0.051426846503971085, 0.043179220519959934, 0.7630139505190234, 6.976433982772212, 33.85639313728579, 67.75431632995605, 89.96851075080134, 85.28580481006254, 76.1600419013731, 73.2982570894303, 69.00497190413937, 45.84739646603985, 41.77186558323522, 38.71597443857501, 25.431491098096295, 38.49586279161515, 30.950003131743404, 34.04992288158786, 41.488650844943145, 46.8784503013857, 25.483342870589226, 11.572120670349369, 3.994226032687772, 1.6335948580695738, 0.33973817623430685, 0.17791986014814148, 0.14172928437830942, 0.7749604481843211, 1.394370849574766, 1.4586700186614068, 2.679063403798688, 5.645065346071798, 6.441552619780264, 7.31191038124023, 7.426421036643367, 8.556583850614487, 7.7801447914492705, 9.320863562245524, 8.145852858020413, 7.7372463191709215, 10.24453761116151, 9.188109963170945, 12.024509195358524, 11.346983486606229, 9.17642326124253, 5.997279968953902, 5.307865065913047, 1.0773425837678294, 0.46151934311755244, 0.5329769296992211, 1.4767531257483268, 0.3358387886997192, 0.11660306368984523, 0.11751437890193156, 0.5608507017454794, 1.8326317326676462, 1.760414523943778, 0.6970889589959576, 3.3819033541987022, 5.917482289575762, 5.402730040011868, 5.076386880490088, 9.985229719069697, 8.907674224145952, 9.86927955381332, 8.351587057113647, 9.559314250946045, 8.004106735029529, 5.974436085070334, 4.631745036571257, 6.3967704292266605, 6.030409778318098, 8.461885086951717, 7.809406653527291, 6.1312122402652625, 9.263798959793585, 6.374455084723811, 3.5804770213942376, 4.105910865529891, 4.309003103163935, 2.3249099043107804, 1.5438194044174687, 0.6217770002061321, 0.24436179248075335, 0.19819426981191482, 0.24415643495177072, 1.8225492801397079, 6.733770178210351, 18.775595657287106, 28.247548918570246, 44.12727240593203, 27.802720762068226, 33.250822328752086, 37.69590323971164, 68.22011347739928, 70.90291269363897, 36.7457914352417, 37.328506592781316, 45.69627931041103, 48.48623375738821, 44.2833984282709, 60.43125906298238, 64.63529071500226, 69.57424117672828, 67.18947149092152, 60.934106919073294, 25.473717374186364, 3.9193847583186243, 0.33933000458825024, 0.08935038976731802, 0.044896387450036504, 0.03113449889145071, 0.05185037438246993, 0.017001733762182055, 0.0271027083809097, 0.05420640884568134, 0.0703882350916824, 0.05674478372619037, 0.054337662689748316, 0.03721601893043807, 0.02726236301954956, 0.031727835904025746, 0.018826325371440862, 0.04386585363517365, 0.016119633313088168, 0.029848488160378994, 0.029955671521865075, 0.09899192039043674, 0.05195579957216979, 0.0395745087054468, 0.06375383322818146, 0.06079773741563963, 0.037018180554432255, 0.10387735501412423, 0.03603586814396324, 0.04289160046966807, 0.048159427880760164, 0.06559556605474604, 0.0250665366935033, 0.03304078228651516, 0.026401383614528085, 0.0819295565147073, 0.04587704511058908, 0.08536377546167181, 0.2361763268709183, 0.10392119056515156, 0.14943467332951485, 0.22249759715651313, 0.07037630710270136, 0.11833495099938686, 0.15357524066442443, 0.15848174270602966, 0.15390945418227106, 0.1405804742488169, 0.1886870420628017, 0.18024777152365257, 0.14349435095585164, 0.1726784704313163, 0.14139202183052418, 0.2642766157946279, 0.12959216871569235, 0.11631670768462843, 0.13929998892689907, 0.07374143257977502, 0.12094966271111082, 0.1437683346410913, 0.1205674078195326, 0.17361597818953378, 0.16961707583358213, 0.2329437575873829, 0.10049743637923272, 0.3894673642371932, 0.13760538711663217, 0.10546728623129668, 0.12933873150858188, 0.2080817376413653, 0.1981398009604985, 0.18751930956157947, 1.1790931561300833, 12.196004044625068, 48.493486219836825, 78.33918525326636, 97.54061498949605, 91.51499148338073, 86.00758367969145, 81.87240139130624, 79.3147885414862, 52.59310830023981, 45.929978047647786, 46.16351596770748, 26.119149269596225, 37.91538730744393, 45.61446259098668, 45.62315456328854, 57.08207661105741, 56.8667894794095, 28.941327948724073, 14.360850357240247, 5.571211528393531, 2.6608947400123846, 0.8588125712929234, 0.29892928537822544, 0.29019640398121654, 0.6312584720792309, 0.7302037530368375, 1.3847791836146386, 3.79932223308471, 6.884715730144132, 11.531249573153834, 11.936247041148524, 11.919714250872213, 16.8656426091348, 15.409030241350974, 19.808949962739025, 22.268774201793057, 11.023436977017312, 14.958499939210954, 15.1834164896319, 22.315028752050093, 19.459113767070157, 11.8680085866682, 10.089832467417564, 5.0845439395596905, 2.2581702855325516, 0.4820777415748566, 0.7061028108000756, 2.3947219646746114, 0.9579498645278716, 0.2744475974430961, 0.4113515544562571, 0.3674100075037249, 3.7685308917876217, 5.050971882958566, 10.406446187726914, 12.32727792955214, 13.429001108292612, 13.698212004476979, 17.47178804489874, 19.811372026320427, 13.173796995993584, 14.866482115560963, 23.810312747955326, 16.555477265388735, 19.21326744940973, 11.595780407228778, 13.143914418835795, 9.250725700009255, 13.135857870501857, 16.593375205993652, 16.974317758314072, 13.103211002965129, 15.191455387300062, 8.855820490467934, 7.186313146545041, 5.276322835876096, 5.992240703875019, 1.8695677119878031, 0.6387441929790282, 0.6259866227065364, 0.34377588860450253, 0.27202139698689987, 0.7939574062343567, 2.792543701587185, 9.520582806679512, 22.256916876762144, 41.40443755734352, 62.40172055459792, 44.156042991145966, 56.65527959023753, 55.27642526934224, 77.59136969043364, 74.9692181617983, 37.294562401310095, 37.73534267179428, 45.67129773478354, 49.12190091225409, 50.0237165727923, 68.44897593221357, 74.34096428655809, 80.76512413640177, 76.03987616877403, 74.37512028601863, 32.866610480893044, 6.209536089051155, 0.5343052035858554, 0.30004284014144256, 0.07443646584907848, 0.13173980428086174, 0.16840452718878948, 0.22391133581198033, 0.11837884017656888, 0.20608299892515908, 0.17233676457357022, 0.1069987572789673, 0.30628608900212473, 0.1868832114362909, 0.1267730034587364, 0.10915226873851593, 0.1220347726296994, 0.12271643000384494, 0.13697927877787622, 0.09987056961343174, 0.1561994901708057, 0.2721349005737613, 0.10492120343711107, 0.15568677816660176, 0.138011229855399, 0.1597913087255532, 0.11173637523766487, 0.1406614957076888, 0.160860461032679, 0.17698829723221643, 0.18199964606713864, 0.15101119034713315, 0.13059572857474128, 0.0715519686139399, 0.1016562286343786, 0.23625149541804868, 0.14714540342890448, 0.2171447876119806], [0.027369720666038416, 0.1034936675381276, 0.04985164715758255, 0.07566876424055907, 0.028963719810088797, 0.09623562030854727, 0.032720224285918864, 0.047078071793000546, 0.102512645985811, 0.054379146350848104, 0.07648943592944453, 0.07627168309784706, 0.009684753303806628, 0.02925284522315187, 0.0296865371731861, 0.07188917753557045, 0.03425101351533686, 0.0282768587837176, 0.06519460329605688, 0.027190756781267065, 0.12298168794762705, 0.10850295559653353, 0.05961980445370559, 0.25027464294145185, 0.04529721614333891, 0.1521153528723986, 0.011454943094342467, 0.018024551156427593, 0.019820199963907083, 0.001611784473718745, 0.044250732377892545, 0.029122319162612962, 0.05276242120852394, 0.19058222101340372, 6.639279790462987, 24.45505430621486, 63.72911337883242, 76.39496049573346, 71.55142168844901, 68.3985028728362, 53.15090464007471, 44.33678188631612, 46.12300965093797, 46.67045877825829, 21.51250397005389, 25.368327210026404, 40.744914547089614, 28.71386185769112, 45.306670281194876, 54.72826619302073, 38.90996702255742, 16.6174546364815, 7.961276413932924, 3.7823712200887747, 1.0812519610889497, 0.0676239293909842, 0.03708438204240896, 0.0959021652177457, 0.09704642478496799, 0.7788858827083343, 2.5297373004498023, 1.5926901755794403, 1.440125787931104, 3.11174520561772, 4.139413545208593, 4.897005125399559, 4.6440333320248515, 3.860276601006908, 5.54777144424377, 3.8774622207687752, 3.944790440220987, 8.065637936515193, 7.3996753750308875, 11.412119346280253, 8.22398990392685, 6.50029452577714, 5.306251500883411, 3.3867987173218883, 2.6753322491722726, 1.0145641298544024, 0.2525877228547489, 0.43885457059068067, 1.289804505725061, 0.7030640157961077, 0.2874300604866397, 1.921289433394709, 12.113985323136854, 13.852335656842879, 13.324084570330958, 7.615530760057512, 0.46925735209257374, 2.6963814035538705, 3.609878617909647, 2.87925063602386, 6.113393402868702, 8.113738452234577, 5.372188994961401, 8.012935990287412, 6.461834215348767, 3.6946893315161433, 1.5864532392832542, 2.014604090682922, 5.964298719359983, 3.204436451196671, 5.313486802962519, 4.921971992138894, 9.256638673044021, 4.7082694980405995, 1.3194146007299423, 3.2632874481139647, 3.356925455793258, 1.8008990225292023, 1.0589713050473122, 2.236047627464418, 0.3566583618521691, 0.12585069488493666, 0.13248827218288375, 0.14132475931077235, 0.05070830199627146, 0.699410695702799, 5.518353177655128, 15.382408134398924, 22.527874208265736, 32.69863301707853, 42.64855846281975, 60.70633096079673, 50.437432489087506, 25.324714376080422, 21.713295982730006, 17.279668392673617, 10.789912785253218, 23.211125596877068, 35.1837428154484, 35.31720538293162, 46.07585883909657, 50.728244858403365, 60.30360160335418, 58.4705642730959, 33.44620735414567, 10.59322161059226, 1.1041429134145861, 0.21612705512633248, 0.025577701200100205, 0.09310387585672641, 0.04625196471029232, 0.11237783597842341, 0.04547042862301873, 0.02604519103413388, 0.07619852170107827, 0.12915692352239164, 0.05487358332761834, 0.07071995116289585, 0.04459561750052437, 0.12753117003387984, 0.015466193830023612, 0.0382110407395709, 0.05658331537438978, 0.061750520967067256, 0.07427492088848546, 0.036137160289311604, 0.09127075002799112, 0.031697709496403416, 0.09543490521008931, 0.035531092810654835, 0.011604648166065736, 0.06645629648119211, 0.024214124066695094, 0.08935204451723446, 0.059007236719011306, 0.016442803673506264, 0.07173095739656879, 0.1449759343578931, 0.07073325811014061, 0.01905138093617655, 0.03782458002528837, 0.14610540842817676, 0.026899049651899168, 0.016287644055762118, 0.040189964591615626, 0.06217431314589997, 0.02476777389435278, 0.054624305977936716, 0.06571059415657675, 0.03433109651650152, 0.026182050726586775, 0.05679935216903687, 0.049314320748371464, 0.07360770427171262, 0.04762930269803732, 0.039738321286295696, 0.03203167978133405, 0.04722927839705541, 0.003324298496966461, 0.020992492603498603, 0.032003863128803434, 0.049625674202557535, 0.06268306830597502, 0.08367925536848846, 0.041984962224359476, 0.023036279204872348, 0.07834147646903031, 0.020051577669237892, 0.0274836341099393, 0.01739836429365941, 0.02790732286690224, 0.0633622665378836, 0.05082704945497456, 0.003956055537151594, 0.023637888051809806, 0.30053911189879146, 8.329719843402986, 30.42975171919792, 75.70201889161142, 84.38045901636924, 81.48052523213049, 75.27327245281589, 63.86988724431684, 52.30193899523828, 58.21125638100409, 49.516357991003225, 29.66595445909808, 35.49530844534598, 33.872667051130726, 24.33596722541317, 44.00985625482375, 44.48798533408873, 36.25368302868259, 18.279186371834047, 7.283150092247994, 2.5376531337538077, 0.537686164100324, 0.07395933096807811, 0.1498170737777987, 0.4972711037243567, 0.4007798781798732, 2.5953082980648166, 5.01994691548809, 4.36491354819267, 5.923603148229661, 7.148996207021899, 7.87964306531414, 6.899571216875508, 6.26016604323541, 9.537614718560251, 8.7951777058263, 6.845572437009504, 7.772815352486027, 8.13785759672042, 11.709583074815813, 12.039048440994756, 7.904402046434342, 9.958981217876559, 11.300339641109591, 8.35768340095397, 8.411259055137634, 3.3050486781904778, 1.6329062369561966, 1.1646246357310204, 1.2827259758787772, 0.7395936007941923, 0.13850955472838494, 2.1778237194784227, 12.269043480196308, 14.393761004171065, 12.657067871862843, 6.605040440636297, 1.6219261745291373, 3.314782775217487, 4.778243601322174, 5.991372389178123, 8.678785293332993, 6.255505777174427, 6.919146295516723, 11.025406987436357, 9.146441644237889, 6.651980425080946, 6.20682769244717, 6.906927622133686, 8.643367271269522, 7.2123611165631205, 7.845895482647804, 7.59500107457561, 10.370487859172206, 9.145892512413765, 7.141109301197914, 7.931103091086111, 5.6577610777270415, 7.140459168341852, 5.475304184421416, 3.3748729959610975, 1.7801808181308933, 0.7705639002303925, 0.6436790249520733, 0.08387377275334251, 0.027039061796160477, 0.6604462381332152, 3.7177268824269696, 14.084617437854892, 22.02737585190804, 32.44627164256188, 41.94165322088426, 51.2078958172952, 49.490611553192146, 37.728372619998076, 28.976997983071115, 29.105630151687134, 21.64926132848186, 31.92717144566198, 48.43894566259077, 47.82494175818659, 55.090289192814986, 59.43562423029254, 68.3890813396823, 69.6980704030683, 44.81487566424955, 14.344709803981168, 1.1901950571806201, 0.15809420946865313, 0.03050314476563325, 0.06807794373842978, 0.09437060990040341, 0.03580830172605572, 0.03442628294109337, 0.04722453631280411, 0.06441593620805972, 0.02780618010869911, 0.08992948329016086, 0.017370254612497745, 0.05395548057652289, 0.02257365977481729, 0.058721608497322574, 0.022026052465662364, 0.02983977199502049, 0.046148868427882274, 0.04671741675044741, 0.06641757073661973, 0.08942937343231133, 0.017089705553746993, 0.03409067131278496, 0.026748618711867643, 0.05400125049955903, 0.039745457395310366, 0.019195233096158313, 0.057119956134908625, 0.023997064544669083, 0.020849919810350385, 0.044322756134093776, 0.06540256552398205, 0.059304965299464045, 0.013443071492797425, 0.011165386756821986, 0.11183055042619668, 0.12281417516210388, 0.1945910978341295, 0.26262863809543274, 0.16894029843951427, 0.16640362810463677, 0.17321436425610898, 0.153609270290021, 0.17521337876396795, 0.20145035799472563, 0.16188393917775926, 0.25731293784995235, 0.18387132144022375, 0.15399792201576695, 0.18884024432589933, 0.08637353297202818, 0.2907063121036176, 0.10116282970674577, 0.14973323311536543, 0.15653405608909746, 0.09324656739350289, 0.160980798123825, 0.25560206433217375, 0.0961843154002582, 0.267604777529355, 0.19411308961289545, 0.3084432700228307, 0.1464433144898184, 0.1439654030987332, 0.19908648645204885, 0.12071271937701011, 0.14730081202522402, 0.11590329599716973, 0.1565712879622175, 0.5164072446284756, 11.325889960412058, 40.00593216188493, 86.70996250644808, 95.4044137462493, 91.32490558008995, 87.17401027679445, 70.55811282127135, 60.15777180271765, 61.94674914883029, 61.647335021726555, 32.74275183677673, 35.56144745119157, 54.05275952431464, 39.74338831440095, 58.42493141851118, 68.57164413698258, 50.61426470356603, 22.806158527251213, 10.89152668752978, 4.620897231563445, 1.5028712081332363, 0.19307992811645233, 0.2852560255315996, 0.5320886967162932, 0.30094452562832064, 2.177528806271092, 6.494356547632526, 5.763460618834342, 7.518646255616219, 10.569902139325297, 14.478709736177999, 15.776632812715347, 14.046398843488387, 15.831088058410154, 16.54183526192942, 14.554834115889765, 15.479010228187809, 16.650153475423014, 17.88901448249817, 21.819494155145463, 18.208630777174427, 19.706987950109667, 18.519233465194702, 16.476125755617698, 14.741003532563488, 3.2925505359326643, 1.5253185649071972, 1.697684057777928, 3.056512595184388, 1.1882450263346396, 1.1173649781173276, 2.177707764410204, 9.624749191345709, 7.985222974131185, 7.174128303604742, 6.607393862739687, 7.094520368883687, 11.897736230204183, 14.324926349424548, 13.901531984729152, 19.054040793449648, 19.623800362310103, 16.180331976183002, 21.603328412578954, 16.56385152570663, 12.49489845768098, 8.748286751008804, 9.237152338027954, 16.838248775851344, 13.658054778652808, 20.20968479494895, 14.593485151567767, 20.664715036269158, 14.443991857190287, 12.030549645423891, 12.283601357090859, 8.47849142166876, 5.767947810311472, 4.961663926801374, 5.928996897512867, 1.3622075367358424, 0.7717000392656174, 0.5471852866391982, 0.1422994529768344, 0.2132444348066084, 1.0902351693760965, 6.394543503561328, 18.782322522132628, 29.852274887023437, 45.58328367048695, 57.676798143694484, 78.50687442287322, 63.86654146255986, 37.846522254328576, 30.274723960507302, 29.137260144756688, 21.103944009350194, 36.399701103087395, 52.89324806582544, 52.161094527090754, 65.81017001982659, 69.84187233832576, 82.73282035704582, 81.08946492595058, 58.62380735335812, 19.423524141311646, 2.1692087236912023, 0.4491277177247309, 0.07533786022254536, 0.18614298664033416, 0.14489975457470264, 0.12572117239957856, 0.11530631432129491, 0.09294118176424697, 0.1458612562067086, 0.2535658179511947, 0.18563871692505576, 0.2194043179793704, 0.1360605708173206, 0.23984043348220088, 0.21124070119713584, 0.14136245083664695, 0.21105117104466886, 0.148760546599665, 0.2210133171249782, 0.1961279161755116, 0.1821719698848263, 0.16541612544848075, 0.17140903209726657, 0.1001978500355636, 0.17096719854781706, 0.17399739804527453, 0.09749421083758916, 0.193448661556167, 0.12468901447831623, 0.10529623411956335, 0.20755603278596557, 0.22199919567473475, 0.15185411689021897, 0.07709589411294268, 0.1998366244257458, 0.40798070630238903], [0.022362219507715875, 0.04255640635927839, 0.01969523378647864, 0.026896971638404557, 0.05477951922183556, 0.020888210800025734, 0.08626635727142135, 0.02048638044676233, 0.06770145748892138, 0.06256653101093347, 0.0637820673986308, 0.018638840673731703, 0.08250694932235826, 0.1472437691183821, 0.037186267905898636, 0.08221952079404747, 0.12246254846573838, 0.09862822014838458, 0.09759234670068949, 0.059259398389727845, 0.12368175441459303, 0.13090078478618977, 0.2866222973792784, 0.17089385328994644, 0.08119978115803773, 0.21296704969098493, 0.08677129348319385, 0.09694291864551845, 0.10108167801292674, 0.0433773921442128, 0.08797828032965622, 0.0483640537957751, 0.18472299670740483, 2.052353471517563, 19.22303807350897, 47.55232526410011, 74.09167412788638, 73.56244441001647, 69.75195592449558, 63.939717200494584, 48.88067514665666, 39.94957554724909, 31.04654835116479, 29.099605391102454, 28.740653607153124, 21.91343099840226, 34.181506633758545, 50.75927472883656, 43.20743345445202, 37.56610416596936, 16.79305522672592, 6.986816006322061, 1.7268363386392596, 0.07179380724987677, 0.12712323587507973, 0.025351297320617784, 0.2582255630723892, 0.3454602401583426, 0.2706728983790644, 2.2678693263761462, 3.4689216267678047, 3.300404101610184, 4.506130641506565, 9.012747656914497, 6.9982144140428115, 5.129762984091236, 6.892510460269067, 5.087621529256144, 4.115136035027043, 5.4615322524501435, 3.9267247386517066, 4.228612165297232, 8.545875780044064, 8.525192141532898, 7.9275396177845625, 9.991346655353423, 9.510940640203415, 4.94332145298681, 6.467105390564089, 0.7250203408541218, 0.5054688267409801, 0.8483433975808082, 1.2536037256640773, 0.37736813928331103, 1.9386776680907898, 18.827914191830544, 47.9210868958504, 57.02862647271926, 60.185110722818685, 42.58918946789157, 14.36535127701298, 2.5768390826640593, 3.0586495514838927, 3.950101329434303, 6.716072934289133, 3.4555309001476537, 7.862880326086476, 3.1833309127438456, 6.747805889575713, 3.209665951228911, 4.9917239912094615, 3.788434959227039, 5.241147510467037, 4.582407503358779, 5.782773388970283, 3.8652810550505117, 5.222334352231795, 10.099768811656583, 6.0694417741990865, 4.180852895782841, 3.866115784452808, 6.051396419925075, 5.32240136977165, 6.511758633198277, 1.4533863408911614, 0.14911896849591888, 0.5662599566482729, 0.16086652844903931, 0.10757441872790938, 0.060557580342696565, 0.29183301293561537, 2.031431671592497, 10.486443907983842, 25.606309175491337, 32.28381687594999, 43.57550867142216, 46.52764528028427, 35.355648532990486, 38.569116976953325, 39.00775563332343, 35.01059370656168, 22.950511555517874, 16.890467289955385, 24.398523146106353, 33.68439720522973, 44.850612378889515, 52.40711342903876, 55.44216894334363, 51.36819524149741, 25.760034707284746, 4.038773371327308, 0.16666320933689996, 0.04926637130519075, 0.026628386957811254, 0.09139055851846935, 0.0073429235471262335, 0.12112405496619402, 0.03395926808157275, 0.05143763685238458, 0.08804758064328663, 0.12416101135914365, 0.2520617268859379, 0.24832634345418025, 0.13369928865182784, 0.1453335901662227, 0.05725947989811821, 0.13787538714466557, 0.04493746508453642, 0.15721708476062746, 0.119861074753346, 0.17186019659763382, 0.02461420582427133, 0.035973374521540064, 0.038079491951653076, 0.04671956945751463, 0.14660711940978804, 0.04458031106379725, 0.05137534241282171, 0.01822915025836518, 0.08502567021716988, 0.16309261141765505, 0.17931015651312568, 0.26473801522966356, 0.06572629129814525, 0.030956094250864083, 0.04185791803343643, 0.0728315499521071, 0.07277038549223254, 0.013823929231523747, 0.012834917382156898, 0.09622749977654989, 0.006632254423288208, 0.05382950124781459, 0.05674755313403665, 0.11969191487878562, 0.02948435507864962, 0.0457272481083149, 0.00720293055506303, 0.05025666635183077, 0.021139018410336108, 0.006643665781725319, 0.017323946512694803, 0.020115605382729444, 0.05551273814372479, 0.03987540122902682, 0.0924656403461291, 0.09787273488097614, 0.0686567078434652, 0.07928588667944556, 0.12395625137874197, 0.019965053783849846, 0.151163074939001, 0.036342127113452846, 0.07625212487314018, 0.060190804257628426, 0.004991392244494731, 0.09331851837135131, 0.04136031711353891, 0.24941075623275774, 3.189003395457422, 24.426391586180657, 58.76185124920261, 83.0208243093183, 85.03467113740983, 79.4976572836599, 70.36961940027052, 56.81905031204224, 47.165595254590436, 40.17029123921549, 42.009180745770855, 29.681649823342603, 30.119949194692797, 49.39467037877729, 58.65266423071585, 43.46088524787657, 38.794841535629764, 16.703801693454867, 6.632915254562132, 1.486029653779922, 0.2370801574039844, 0.11016293789350218, 0.274114441126585, 0.6641204571050983, 1.7464909678505314, 2.2011966330389825, 5.284249455698076, 5.122191338769851, 6.533945029781711, 7.69259209594419, 10.51923982558712, 7.437146757879566, 8.352812797792497, 8.135019761900748, 10.011785145728819, 7.424760893467934, 7.6969027807635655, 5.034923995694807, 6.077184042622966, 8.895811015559781, 8.724373040660735, 7.199048101902009, 6.47817628037545, 9.497344724593624, 5.038174169678842, 5.706194014318529, 4.158742985417766, 2.1455024086659957, 1.8541742476724812, 1.4877733924696523, 0.5234102688489423, 2.253522276878357, 20.55086039727734, 47.63636988978232, 59.72163954088765, 60.203032032136, 41.3376356709388, 12.490520111976132, 2.5146266145090905, 2.0107459493221778, 5.179734470382814, 5.366967339669505, 6.556434429460957, 8.142385973084359, 6.01795478213218, 3.706601324581331, 6.2877559950274815, 3.9873702199228354, 5.7327136493498285, 5.3291439240978615, 6.430452802488881, 8.403299585465463, 11.113190612485333, 11.669051262640185, 12.266407647440511, 8.583478562293514, 6.208051962237205, 7.46326631115329, 8.390690145954009, 5.365863192465998, 8.64742692439787, 5.687258282015401, 1.6688574562149665, 1.034920556891349, 0.6941437492928197, 0.5145982352475966, 0.06764042326399396, 0.3227887567012541, 1.4623340026986216, 7.458556034872609, 25.379749151968188, 39.90548026177191, 47.206882123024236, 48.485378680690644, 33.662741799508375, 28.03197153152958, 30.565901110249182, 26.236749772102606, 27.822097270719468, 28.320132378608953, 34.420684922126036, 44.956865464487386, 54.72570096292804, 61.32351982978083, 65.34613793896091, 62.47051108268, 31.34903369411346, 5.395478558155799, 0.1875030991411017, 0.02228033428470935, 0.021288694753762216, 0.018275469849486987, 0.032777489358258825, 0.06431520330689608, 0.04935544051770722, 0.11421204199113193, 0.02275986893613252, 0.01845540092026274, 0.15265356028272262, 0.11471085716038944, 0.14013312486631258, 0.01985479649456759, 0.03232704115010077, 0.020609506097952687, 0.12256630741420294, 0.03951360088502688, 0.012635610990166184, 0.05313401215619618, 0.03769827127877263, 0.05865054618146631, 0.027983906761472745, 0.022253228178728494, 0.058356617397118005, 0.07320470371914488, 0.07903837133198977, 0.0632043949688875, 0.08484719471345026, 0.04056393424229276, 0.1193010185154215, 0.1205567055712304, 0.04421496373270789, 0.05622554082243193, 0.012765131560304474, 0.19383924382348217, 0.21881934856214832, 0.0723640907615904, 0.18784596945249266, 0.21286522128408958, 0.1390893300694804, 0.2074305782274854, 0.13525293028402713, 0.23243815487911626, 0.12922504406061866, 0.17185199945684404, 0.07125021424144506, 0.18585093860183993, 0.20920324439723648, 0.12556036288339284, 0.23038825681132657, 0.23165260832155907, 0.2593119063925359, 0.23954159790469756, 0.16988278576923957, 0.2263035526078555, 0.1301374547784367, 0.3808638291253198, 0.254986374789188, 0.29437066386303595, 0.33524743010920866, 0.20017163467503366, 0.1875945547175023, 0.2631346238476615, 0.10930682697723951, 0.31841454787119744, 0.10555083578031872, 0.3625960029180973, 5.1672966345664, 32.235001017970426, 69.2388863717356, 94.14758436141476, 92.22017088244039, 89.28903856585103, 80.55213943604501, 66.4622248372724, 55.37084456413023, 45.94597347321049, 40.69487687080137, 40.799058944948264, 31.189102972707442, 48.32312591614262, 67.1975201945151, 58.49522421436926, 49.08031202131703, 22.580347676430982, 8.699098267862874, 2.5047831814135275, 0.33878228236590663, 0.3806092427863229, 0.320248439787857, 0.5625561360389956, 0.8255631909255059, 1.297763117378758, 7.168661500177077, 10.846720472458871, 13.220354549346432, 14.252488017082216, 22.074607072337983, 16.402690160659052, 15.698197176379544, 16.82677584309732, 20.28360970558659, 16.39730376581992, 16.309985922228908, 13.434580679862732, 11.969023346900942, 20.896736960257254, 19.524040760532504, 24.67647602481227, 22.61725521856739, 23.137575272590887, 13.783622595571703, 17.624268224162442, 7.08545430052665, 4.294521222191473, 2.5239907829992236, 3.0403269346683257, 0.9388365224003793, 3.211544031097043, 18.880946597745343, 39.21013424473424, 46.67127855362431, 50.15734387982277, 32.38812838831256, 17.402071837455996, 13.607438552764155, 11.634521657420743, 14.543308231138415, 17.211164197614117, 15.300693396599064, 18.162072243229037, 12.759133827301765, 14.59750165862422, 11.660607380251731, 11.44655873698573, 9.962141667642902, 13.966372686047709, 14.127134949930253, 12.993425823027088, 16.479987329052342, 14.302050105987059, 21.56155909261396, 16.611104319172522, 10.215472848184648, 14.999283763670153, 16.676968759106053, 12.346517155247351, 16.081692211089596, 6.762407402838431, 1.875009755453756, 1.1035681636102739, 0.6306809643583914, 0.4896270477723691, 0.4204429956453462, 0.6554243172849379, 3.2149251141855797, 13.905285692984059, 30.172359904935284, 40.89730255065426, 53.063212210132235, 58.99575394968833, 49.92693993353075, 55.224732352841286, 51.908791988126694, 49.57757442228256, 35.70860301294635, 28.52885150140332, 38.77829697824294, 50.48370469001032, 64.8480086941873, 71.71232515765776, 77.17693205802672, 73.29200483137562, 43.29691840756325, 7.807705815761321, 0.40305053214392356, 0.21082886765080117, 0.06760522152387327, 0.16228170734980416, 0.18826357930177645, 0.21288815795654253, 0.1352969496961563, 0.27870088695518436, 0.18057090741011406, 0.3000097451431136, 0.3960574977099896, 0.38950940714247767, 0.2128811559129146, 0.2564165077262348, 0.15967227398387848, 0.16000803499933214, 0.16322730499650204, 0.2801388339890588, 0.22590515624371268, 0.2379040236795141, 0.12127103659534648, 0.2106561454673929, 0.16273241219741685, 0.13954293072944687, 0.19313465743776292, 0.19760059763587293, 0.21842164167713737, 0.21171471043940515, 0.25279085872875107, 0.23094460518369753, 0.3031808894968802, 0.31905876652848336, 0.2634519068223815, 0.17391176473709846, 0.0892007498130683], [0.026515281736670483, 0.009430405409676174, 0.08498771822140103, 0.07730296767887569, 0.06166504470691566, 0.073240234877073, 0.042775748823318756, 0.06936661087937894, 0.100875370534918, 0.08703482006826709, 0.1243380083131694, 0.0184849948967777, 0.04773835531405864, 0.17184142744348896, 0.03902045476640906, 0.047276756696162686, 0.14443141438307303, 0.12516529900172066, 0.1417417716114752, 0.05043900293868877, 0.13540397217917827, 0.22582647901388908, 0.18466759322872087, 0.16329101286828518, 0.15891784591780556, 0.2507009249060385, 0.11963127135869958, 0.0719636949079652, 0.12845880291875333, 0.06371916774960776, 0.17386314879742362, 0.024199947609656283, 1.0806732889144652, 19.163406279779252, 52.34697957192698, 74.01362680619764, 74.62784644096129, 66.45387803354572, 60.55453131275793, 48.177194133881606, 38.25963020324707, 34.629970827410304, 31.929322865701494, 22.67382364119253, 31.530680617978497, 33.081101371395974, 28.688633172742783, 27.340765576208792, 30.616160400452156, 15.988091711075077, 4.544969460656566, 0.8213071741404072, 0.023805096317383072, 0.1173505739819619, 0.09902662417340664, 0.11905087548638545, 0.6120334649758955, 1.4733986412325215, 1.4215841312562267, 4.550795160954999, 3.9471803893966064, 2.839150529715323, 5.776929057413533, 5.643068859654089, 6.161182580455658, 4.694176912307739, 4.250827489360686, 8.590557459862001, 4.399924134054492, 2.5272431633164807, 2.960130154125152, 4.490951068939702, 7.033075949838085, 6.872364186471509, 4.186153488774454, 5.342024007151204, 9.912118700242813, 4.663890331022201, 5.5733752058398345, 8.014290678885676, 5.393136412866655, 3.3627288476113355, 0.6374698516822631, 1.0470952261840145, 8.4587707250349, 39.00644948405605, 75.26534926506781, 78.57979128437658, 79.07924236789827, 80.3766918182373, 40.5070424079895, 8.539987321822874, 2.5245911507837238, 6.805744690279807, 5.5608800053596505, 3.3218398546018912, 2.998671853734601, 6.457563244527386, 5.042098991332516, 4.340795384299371, 2.4139474620742183, 5.076188310500115, 4.609568445913253, 4.5970737357293405, 7.30048353633573, 9.630798466743963, 11.78515047796311, 10.192653479114657, 5.016772247129872, 8.045823593293468, 3.8379972932800173, 7.837899240755267, 5.773527381881591, 1.5823743420262493, 3.251310000496526, 1.982773566438306, 0.9904992856806325, 0.21360297927693014, 0.17772185706323196, 0.16405555329495863, 0.0871183313128929, 0.11926762474280213, 0.6834912660621828, 3.699618034785794, 12.305365608584497, 32.43759535974072, 51.79797718601843, 54.7993120839519, 81.50837406035393, 112.55981752949377, 82.94891157457906, 40.273449574747396, 30.242733109381895, 16.64768042102937, 31.55483065112945, 40.851383363046956, 50.39131718297159, 51.6185954309279, 57.2823057636138, 53.60646440136818, 9.716252203910582, 0.5769760558201421, 0.0535442024439333, 0.02049769173496433, 0.10427371358438846, 0.05582756197620785, 0.029070282640356212, 0.15214234981085026, 0.06605685823747227, 0.0389466192122669, 0.09489394754411713, 0.16412952674492715, 0.22256751034048297, 0.320151575630711, 0.08423941885872234, 0.10827152043460839, 0.20593489880763716, 0.028166032674151565, 0.161567973874269, 0.03019905574018917, 0.0380503423061342, 0.04914518768688844, 0.04233830495767536, 0.03853758571729545, 0.022219497327422424, 0.10227178794241722, 0.022438985348168402, 0.054771666820611686, 0.06477179937064648, 0.1299627407664253, 0.059462132067569805, 0.19783597048972884, 0.18282217934968012, 0.03667249486991956, 0.03298810991128126, 0.004391515713876053, 0.023919710731734673, 0.03192260035223538, 0.08009232445469788, 0.03248891935894086, 0.07267349069156954, 0.06813480278416988, 0.016092854709694945, 0.015612146986137717, 0.048999404985337495, 0.04983053377438938, 0.011994060234076554, 0.039100851863622665, 0.049248490813038046, 0.09401057155862932, 0.028641127846053535, 0.037391522013011484, 0.04730831951864305, 0.00913249584095132, 0.03310504940248305, 0.06531262680167152, 0.1087961987321896, 0.23120311389286674, 0.08818182989113754, 0.19219190963814337, 0.07134079647761199, 0.15781379064484952, 0.08087144353457036, 0.10875961037292596, 0.09301387584738194, 0.07750454839439162, 0.14935288578271866, 0.04171071423878593, 1.6092270107999926, 24.19016488136784, 64.52785307361235, 84.46874372420773, 86.09105171695833, 77.7086014901438, 67.03300814474782, 58.951831248498735, 44.650202797305205, 46.092623049213046, 40.96356707234537, 28.81029921193277, 35.54497741883801, 35.683943071673, 30.09398114296698, 29.011922767085416, 30.29096845657595, 16.19962513446808, 4.1899728967297465, 0.6540703028440475, 0.04868103033532539, 0.3318242121848368, 0.43248727677329896, 0.615056693073242, 2.420901824389735, 4.527254075773301, 4.554970524003429, 8.208735806326713, 8.7498527573001, 8.629711539514604, 9.191718543729475, 9.51119657485716, 7.6212191773999125, 8.74452421742101, 8.755020480002127, 7.881456180926293, 9.290727011619076, 7.046116359772221, 6.029339461557328, 4.81480009132816, 7.138484745256363, 6.455283857161, 4.440018601955907, 5.992981541541315, 6.825105999746631, 5.616727202169357, 6.611951166583646, 5.626484588269265, 5.484036851313807, 3.808903602823135, 1.6274187185110587, 1.4927054052391362, 10.41375062158031, 41.02344989776611, 80.05501039566533, 83.16993713378906, 85.12149672354423, 82.63139570913008, 41.97304787174348, 8.216093682473707, 3.0984883298796997, 3.0326707132401007, 4.328291848782571, 4.43537010300544, 2.4328268103061186, 2.0436655441599507, 3.580319391142938, 3.526447843159399, 4.584974694636561, 5.459141077533846, 8.636737485085765, 8.48808357792516, 7.112414221609793, 8.097656734528082, 9.610837524937047, 11.470871548498831, 10.308998823165894, 13.92158216045749, 11.643075366174022, 8.056552256307295, 8.723098270354733, 7.398566815160937, 6.729659534269764, 3.572981371994942, 2.4999231196218923, 1.2127402280607533, 1.1666814285901286, 0.4460518134217109, 0.16508561979618766, 0.2167676731703743, 0.7781245751727013, 4.273130576456747, 16.47226418218305, 37.62890523479831, 53.634372065144206, 52.412251733964496, 64.96400494729319, 89.26311169901203, 78.68711517703149, 47.217958896390854, 39.91610988493889, 25.21858092277281, 42.09758704708469, 52.853106529481956, 58.929473738516535, 62.277369653024984, 67.41354865412559, 63.54360095916256, 14.124266716741747, 0.838619658062535, 0.1402039879993085, 0.053363505285233266, 0.031474766419118935, 0.08102626990406744, 0.008656509134227471, 0.04878842054055103, 0.06013940741878845, 0.022978571716756113, 0.03209114927167614, 0.027978448385012247, 0.09713032673443518, 0.14298678706249884, 0.0572215891893833, 0.06388876812472459, 0.06912504803509482, 0.045142477873953125, 0.06583276219786176, 0.051032008618236556, 0.03580293144970652, 0.09524185105317062, 0.011851622463924991, 0.06855590599438838, 0.02344435317471864, 0.037604797060691544, 0.019069529559102752, 0.07115845222987476, 0.054828870605917714, 0.10874422732740642, 0.0931911945583359, 0.09675602383551099, 0.041180853356396964, 0.016922391951084137, 0.04416360902870375, 0.040440686017034516, 0.12001445321666619, 0.0870578563321502, 0.17907631583511832, 0.16904463961480126, 0.2208363661362279, 0.27582413486896024, 0.11199403358923812, 0.16517183533118618, 0.27563095813797367, 0.15131750294277746, 0.12691926496524003, 0.11485104358965352, 0.20241477076084385, 0.255674735432671, 0.12858444133833533, 0.23839554569173246, 0.2901230740451044, 0.2162197977304459, 0.22630922165849518, 0.25680589489638805, 0.271503797341739, 0.36231521637209, 0.25581948008508454, 0.5123065291873871, 0.3196353855873308, 0.42774136208238145, 0.1636976370167348, 0.30138885662440335, 0.31281873523708315, 0.1750352173562973, 0.4393124766647816, 0.23577318076164494, 2.3949413722561252, 32.582401421762285, 77.39183087502757, 94.72472975330969, 93.125273489183, 84.59082357345089, 77.89829515641736, 66.9660375964257, 52.24031463746102, 48.43639612197877, 43.065035727716264, 31.955700805110318, 43.471142245877175, 46.11268989501461, 39.25812444379253, 37.84518080372965, 39.19530376311272, 21.053755321810325, 6.45399094589295, 1.0475383314394182, 0.14481366161377202, 0.270090916704747, 0.3130365187121976, 0.33589820647912644, 1.9850556504341865, 5.443827654084852, 6.391223707506734, 12.288540601730348, 14.935916892943846, 12.87381902817757, 17.075301139585434, 17.184192019124186, 14.726509394184237, 14.684647898520193, 16.04647913286763, 16.457408205155406, 17.14123029862681, 10.908799825176116, 11.871381825016392, 10.700607280577383, 20.65748022448632, 16.829972574787757, 15.277941688414543, 15.683130371955135, 18.06949254005186, 14.903295520813236, 16.466867000825946, 16.562043313057192, 13.077401807231288, 7.895319798300344, 2.095467919303525, 3.154309540987015, 12.796312993572606, 43.053217626387074, 71.70536687297206, 77.53189086914062, 77.8488419132848, 76.2733042624689, 38.92721368420509, 16.386063233498607, 7.632694561635295, 13.108646427431415, 13.017221862269988, 9.776454702500375, 8.731745135399605, 13.770414994608972, 12.16162839243489, 10.24670374008917, 7.452993623671993, 11.427126334559533, 11.97033243794595, 15.162459265801216, 21.22421172357375, 20.565384934025428, 22.93542611983515, 18.247876051933535, 13.259591979365196, 17.859161323116673, 10.597416585491551, 14.488034190670138, 15.012054020358672, 10.753124875407066, 11.46778856554339, 6.606491717600054, 3.2217130209169085, 1.4663588447916893, 1.2750072416759308, 0.33776206775538387, 0.23449266479621012, 0.3921330437785195, 0.9426790355674682, 5.3534935078313275, 18.5001491731213, 43.02655335395567, 60.30436646553778, 63.28508930821573, 88.64324385120024, 116.89900229054113, 87.77255612034952, 53.11003354287917, 44.76267283962619, 26.79602876786263, 47.80944447363577, 58.016314583439986, 69.57742614130821, 73.17464751581993, 79.90093185055642, 79.0938178954586, 21.714251079866965, 1.949022306549934, 0.2799573630815552, 0.185905713888426, 0.18086022817559783, 0.17235663689432607, 0.1551282847480428, 0.22420002838536618, 0.1970087334273323, 0.1787019593100394, 0.30177456657252005, 0.36111809673809236, 0.34875426501516377, 0.49910747776589093, 0.19664298773052233, 0.3677803344063221, 0.3474679114597459, 0.21569366386580854, 0.2827604787964975, 0.15776517470517468, 0.18053162242135695, 0.15576301923682614, 0.10093998239045182, 0.16098701875777016, 0.15436048078681194, 0.15438151756121268, 0.2013517931223877, 0.2844433901050399, 0.13130020770815112, 0.4244532207808187, 0.201240771660401, 0.3893303570728148, 0.325767950064713, 0.2352078385170429, 0.15448510797033388, 0.09570338838403264], [0.0436340928858807, 0.0379991561414734, 0.04058859844301497, 0.16396650323464027, 0.046630799019288634, 0.09117141140684967, 0.13443425808462406, 0.1310998603941933, 0.08031468913559953, 0.07764985995186914, 0.08253193911044829, 0.024366633020221226, 0.05265257569150098, 0.057657332339834784, 0.10266475274317688, 0.06855618178604111, 0.0379826354553863, 0.0348969328878147, 0.2079074526385915, 0.0758688587455019, 0.232462914840829, 0.40127400489103415, 0.2033262162078773, 0.2493584171057709, 0.057277551912251985, 0.2665313044863363, 0.06233230728896395, 0.058078941168083306, 0.11223673024365019, 0.0204550551115385, 0.04812045698805202, 0.2988113691249202, 12.373458935368447, 53.56474214984525, 68.95708760907574, 69.68782517217821, 71.23730259556925, 50.88041713160854, 45.321218352163996, 39.89157938188122, 36.029499961483864, 22.17031486572758, 23.512334208334646, 27.94890553720536, 25.792892402218236, 55.43944289607387, 60.874753613625806, 57.70210919841644, 17.116658610682336, 4.575898820354093, 0.1849837883585884, 0.13090896660522108, 0.019952288843811523, 0.14594457592935334, 0.28820929447970084, 1.4471746548529596, 2.629499108560624, 6.4595616921301815, 5.592407526508455, 3.8325371088520175, 3.5374790189727663, 4.89657219379179, 7.380420459854988, 8.184503893698416, 5.210329938319422, 6.779849692698448, 7.762382338123937, 5.411669121634576, 4.743663005290493, 4.919492563893718, 2.6086012105787955, 1.803637817502022, 5.831503935398595, 7.866165801402062, 7.969792860169565, 10.940109164484086, 10.856042965765923, 11.172804755549278, 11.724971513594351, 12.458327258786849, 11.389231335732246, 9.501429873128092, 7.323806439676593, 4.862067103385925, 21.155827160804503, 46.25105934758341, 76.36598986964073, 66.32606367911062, 72.6147605526832, 63.895770965083955, 56.384098683634114, 24.554105920176355, 9.88135947335151, 11.303440274730807, 14.580183413720901, 13.782960695605125, 7.809087960950791, 7.687873484626894, 6.282368129299534, 8.250312439856991, 4.147778489897329, 5.587817372814302, 4.483626532939173, 4.841323158433361, 4.624160153250541, 9.895550608634949, 11.484663582617237, 13.663703972293487, 7.212458195224886, 6.897184944921925, 8.681431912606763, 3.9461424321897574, 3.9135078220598163, 5.671324143486639, 5.514999060861526, 2.6097426202989396, 1.5450152370237535, 2.158518303786555, 1.1994534442501685, 0.3640412431090109, 0.2223265297230213, 0.13536137769058829, 0.055799454210266, 0.4523831011066514, 4.4368708998926225, 11.182067432711202, 34.56428289413452, 55.40880918502808, 72.77511489006781, 76.01723624813941, 53.926451360025716, 37.48429921365554, 25.06331389950168, 20.186664404407626, 25.870518069113455, 28.13367270654248, 34.30509659551805, 44.77088628276702, 56.844278996990575, 55.29557428052349, 28.160768439692838, 4.156169910584727, 0.26717515542141856, 0.0679812481206271, 0.05433091728557503, 0.04639977371440299, 0.0773715861742535, 0.060677400324493654, 0.07224588339487392, 0.042119885629583756, 0.10582206154903097, 0.2634557372620029, 0.19896357530547729, 0.2673409674917498, 0.14844841173579618, 0.2120123509197466, 0.1612032087700021, 0.06256158591338223, 0.143441261062699, 0.018665400942066507, 0.10666531750992422, 0.04438671298445233, 0.08439000110111891, 0.11349763435822342, 0.04994961831177916, 0.042740359391656615, 0.041584531896777695, 0.050111098154898615, 0.01822191455792035, 0.08474200318056731, 0.06588312481800396, 0.11911948632088401, 0.0736256154073823, 0.01315027460335724, 0.08189745743067996, 0.04523929989626331, 0.03352191997691989, 0.05121416900487197, 0.031829091660197706, 0.050887283118021105, 0.05444307255768969, 0.05407298697278865, 0.08562275914535408, 0.049027210146549254, 0.04893164067799526, 0.12987450275930668, 0.06764446820823417, 0.004912002552901545, 0.04495173347212615, 0.04616133650884994, 0.019634599842491652, 0.021029379737052708, 0.11181307596064384, 0.03710793924608058, 0.13263123951131298, 0.07231519136938357, 0.09950022738907607, 0.08121737819765845, 0.10408321050025764, 0.15490121628728606, 0.08378230185518343, 0.13980917692665132, 0.023764734975092357, 0.08245376749865471, 0.07527609821408987, 0.06866055360484509, 0.058360122249371586, 0.26211710586663217, 14.830615962705306, 63.22564186588411, 80.30032327098232, 80.98186646738361, 80.60749976865708, 61.07686550386491, 58.52734450371035, 50.625855307425226, 48.54965456070439, 31.684108049638812, 33.42273589103453, 35.96670281502509, 33.500343907263975, 44.45413527950164, 47.5940671274739, 41.15832844088155, 14.444270345472521, 4.41337296078282, 0.32454665269582506, 0.286015831534901, 0.03893675583024179, 0.6832725326380422, 1.3476695168402888, 2.6467670980961095, 4.711808946824843, 5.661491742057185, 8.37390338220904, 5.9878118576542025, 8.698779575286373, 8.020972436474215, 9.286653630195126, 8.940513287821124, 9.090339003070708, 11.536845814797188, 9.90199310164298, 10.279361394143875, 8.321302437013196, 9.287700903031135, 4.565328523035973, 4.98279030284574, 3.378697797175377, 5.5658163082215095, 7.748315247797198, 10.491502784913587, 9.652831400594405, 11.748333150340665, 11.879706075114589, 13.465755677992298, 12.373631519656028, 11.683919987370892, 9.60322420443258, 7.59769868466162, 23.50640162344902, 54.95447320322837, 83.28531757477792, 73.86930711807744, 81.0600628391389, 74.0027069276379, 64.45465380145659, 28.347410501972323, 11.339001463305566, 12.312470001559104, 14.000629686540174, 14.19566365980333, 8.704225786270635, 8.565450368389007, 7.3018622494512995, 5.961199556627582, 3.1563908486597003, 5.923036856036033, 5.014830673894575, 7.103509951022364, 13.226735265024248, 13.10108115596156, 11.759856093314387, 15.527826086167368, 10.642351258185602, 14.29475743924418, 13.600460656227606, 12.769293746640606, 8.407857379605694, 7.803137725399387, 7.424685387842118, 7.088784392802947, 5.446544876021724, 4.106363899284794, 3.6570090824557893, 2.6405469544472235, 0.40437540460017424, 0.22750821054702808, 0.04673128294187688, 0.28182465643171345, 3.4666922496211146, 12.595794566216009, 41.36129540781821, 65.94044762272989, 79.32204492630498, 84.75464528606784, 67.04921537829985, 46.71764096906109, 30.426268654484904, 24.150470495224003, 36.88557294107253, 39.24591018307594, 45.53162213294737, 53.737440186162154, 65.39142954734065, 64.23601304331135, 34.1284958008797, 5.469312273686932, 0.17822991125285628, 0.12543696144054975, 0.05954293136094367, 0.04608560105665557, 0.0688585720115131, 0.011432308069009696, 0.016196075481392683, 0.0634840591960857, 0.029843334303868395, 0.12805587131409876, 0.11732259645096718, 0.149542048212982, 0.08671801972893939, 0.0610761605804005, 0.09477247664284322, 0.07653396862048296, 0.11766564296258074, 0.010532814551204925, 0.055556171498591864, 0.015229833680355262, 0.026012726143122684, 0.04653563557733451, 0.045361548376780365, 0.03081266343924067, 0.0586765663578145, 0.06394978702789353, 0.032521439791326566, 0.09220115615115052, 0.12080832714996032, 0.06069534976455954, 0.030495792236779968, 0.009585578433958995, 0.08133211518607794, 0.02023263488926234, 0.12293282685981644, 0.1036690250639954, 0.19328147052757202, 0.36302780071573876, 0.18572062704591982, 0.20347937250569945, 0.1952047189397197, 0.2420504439261652, 0.26812734142426525, 0.24328729287991602, 0.2202627961073191, 0.11899122021972172, 0.1655884492661684, 0.1406637326844277, 0.18222977887959252, 0.24530668532656086, 0.29861993907440093, 0.23260062680609767, 0.434696521129339, 0.20425569536464833, 0.40205293244892554, 0.4481229780902786, 0.5039986120837351, 0.4485192294082334, 0.21870690217662245, 0.5338115978144831, 0.16206770834903564, 0.17736148930365042, 0.2706641343332106, 0.17601116740655515, 0.30481495503937045, 0.6355596574083452, 19.73190284544422, 74.63313379595357, 91.01543841823455, 90.29479703595563, 89.2606641400245, 69.43897431896579, 61.98598854003414, 55.65720112093034, 51.21876078267252, 32.829077320714156, 34.24326827449183, 42.239502322289255, 36.91265690711237, 71.0082204880253, 76.63580971379434, 69.10651422316029, 21.508642396619244, 6.393793350265873, 0.3646594147768713, 0.341927073295078, 0.12892801645061663, 0.40583893897071965, 0.8098196550723046, 3.0200208242862456, 7.593189429852271, 13.054539292089402, 14.184982065231571, 13.088826690950702, 15.185883660470287, 17.673050741995535, 17.613889632686494, 16.477667247095418, 17.50151764961981, 21.844877773715606, 20.928776841009817, 18.103238651829383, 13.658372490636765, 12.66814366463692, 8.940613308260518, 8.049281652896635, 12.618153056790753, 15.512258198953445, 17.286809067572317, 17.62236391344378, 17.62157943940932, 16.65265790877804, 15.544485372881736, 17.08245554277974, 14.93490884380956, 13.966644310182142, 12.671367852918564, 8.929277658462524, 29.308936403643703, 58.001005572657434, 80.71756147569226, 73.37347245985463, 82.0325517654419, 72.16284859564998, 63.75914696724185, 35.90751424912484, 16.041008407069793, 17.549005785296043, 18.369183194252756, 20.10825622466303, 12.296786404425099, 11.266906338353312, 10.610000529596883, 15.095292598970476, 10.675869872493129, 13.31899235325475, 12.80079234030939, 12.038440473618047, 13.978710501424729, 21.26142324939851, 21.260219081755608, 25.96542766017299, 19.636167595463416, 18.366859189925655, 23.412254933388006, 15.824514166001352, 12.295128222434753, 15.050688385963442, 16.484131313139393, 9.231401162762797, 8.891736653543289, 5.582626606187513, 4.317512194956503, 2.0512544724249073, 0.6737168421668391, 0.2374125629543297, 0.25172490866914876, 0.715657152956532, 5.666804102159316, 15.226096780069414, 43.39507179875528, 65.29698279596144, 78.75727853467389, 79.2587927849062, 61.79955044100362, 49.85130094712781, 32.715412916675696, 32.07671769203679, 39.50729693135908, 41.70160416633853, 51.11023664474488, 64.0030909353687, 75.1391823061051, 75.56067236008184, 45.32669790329472, 8.97931141238059, 0.5322475527082721, 0.22772464570739578, 0.17958761823754157, 0.12835151230495784, 0.24573485186744123, 0.09237133492265018, 0.2524781263163013, 0.24336734906800334, 0.21748796435854129, 0.3998717881979481, 0.357065123896445, 0.5356579922860669, 0.27540677016781223, 0.4545512218629161, 0.34720860601913545, 0.2992772118699166, 0.33618009619174466, 0.19661784472484745, 0.1815215612371122, 0.20621868841830762, 0.1931405103495044, 0.24605169051116516, 0.1508620789935512, 0.18172521805090291, 0.20929048649005352, 0.26443703460597223, 0.17017812798580817, 0.260122029050704, 0.3898223080942708, 0.2800616736133253, 0.32088318959839884, 0.1147345292772497, 0.17194069711671722, 0.17469732661641416], [0.03947543821507885, 0.050753390101054986, 0.06519082648259017, 0.0639647985207698, 0.1809566173582308, 0.1105438674529714, 0.08255591000159902, 0.05336293454972967, 0.06449552508251322, 0.07300649379049579, 0.06711727714226132, 0.024629140708355174, 0.13444873714639297, 0.049408170349535444, 0.03829967328197053, 0.04464898318532975, 0.0620985585415075, 0.09805425175375516, 0.08570730460867768, 0.1184385490693873, 0.08665852534073977, 0.2898494274385514, 0.13166641305771568, 0.1564769672169801, 0.09929832491663196, 0.1439213530430871, 0.04062933899882821, 0.12697402493006762, 0.07755249783757233, 0.0774582077358519, 0.21187577276460587, 4.394247974118879, 35.86042227283601, 59.86253499984742, 62.946702511079856, 66.17606439898091, 56.30363125954905, 37.31933609131844, 27.49589139415372, 21.243698058589814, 19.81324495807771, 31.38137951973946, 27.172027172580844, 36.184386514848285, 50.94402620869299, 55.33866151686638, 36.866529833885934, 13.805667296532663, 4.57821645082966, 0.2679466978917199, 0.0977200458967878, 0.1231202579313709, 0.09847211441205395, 1.3368653482006443, 2.633301110998277, 4.41836957008608, 2.735100100117345, 3.7456333204623196, 5.066429943807664, 6.396080092076333, 7.928356451372947, 5.485379772801553, 7.564566423816066, 9.054553258803583, 6.029252679117265, 8.502207052323127, 5.705973380996335, 5.444981321211785, 7.413825325427517, 6.210604934923111, 6.094985719650023, 8.589485672212417, 13.975870705419972, 21.818282142762218, 21.27155080918343, 28.56594143375274, 26.009781822081536, 27.49072563263678, 28.30359958833264, 29.719669357422863, 29.085986921864173, 18.99984540477876, 22.9639397898028, 23.98683705637532, 39.778681801211455, 38.91983570591096, 67.77490877336072, 52.04565525054932, 62.960881879252774, 48.164560179556574, 54.10975548528857, 37.97107711915047, 28.605457352053737, 27.885610249734697, 32.609130413301536, 29.31117999938227, 26.626878515366588, 26.69851080063851, 28.77865941293778, 19.81255069855721, 23.74993178152269, 15.280714804126372, 11.833841800689699, 9.877365519923549, 7.354627443898109, 5.86040739090212, 6.427279605019478, 9.07473091156252, 9.96645921661008, 20.87473246359056, 13.121250963980152, 9.591683610793083, 7.7046175925962395, 3.737218120405751, 5.579942234100835, 3.8384983760695306, 3.3405532375458753, 1.7970016574667347, 3.241895331490425, 2.1789487042734703, 0.34616415238668846, 0.13923111762250626, 0.08685558613750242, 0.08540755738654444, 0.3812423378469483, 2.3045660411157916, 7.027180137172823, 18.033059604706303, 33.381892250430205, 39.480350248275265, 39.0210485458374, 34.741789756282685, 36.09547422778222, 28.093850843368042, 23.720617948039887, 21.485333711870258, 35.917892840600786, 46.64862294350901, 49.90719079971314, 58.47762453940607, 46.23939421869094, 14.404001332098439, 0.33641191439763196, 0.13477895168527482, 0.040460995007907195, 0.091653372641773, 0.04260991377034976, 0.07399283965388614, 0.12455582243180084, 0.04360832934898715, 0.05191282970049689, 0.0978938252815316, 0.06035709513291236, 0.06891573749242291, 0.14277939173963763, 0.05151649794331001, 0.1494316396213347, 0.09426563287213927, 0.14988464273272023, 0.09323836259183385, 0.030873778103400144, 0.0475617911997101, 0.15172942841966308, 0.008588935391256406, 0.12333160626792139, 0.05268858182394216, 0.019239382743234598, 0.07070000989422684, 0.026391121866782347, 0.04595348153323416, 0.059490622877473795, 0.04887509572830412, 0.09446565076828965, 0.08241075932258561, 0.054067961436005375, 0.05041224348749365, 0.032244690528680245, 0.01533154525884217, 0.08857814249612632, 0.016198915752371954, 0.07069031888198468, 0.03617307449120187, 0.07414906796428465, 0.03384663400450542, 0.02117122283145305, 0.027325396733959357, 0.031490783402395826, 0.02897920436225832, 0.13849814001831318, 0.067175637720333, 0.05285064389388408, 0.05013280142579348, 0.026809777426082763, 0.03472627148092274, 0.036019787958432595, 0.02190365076756045, 0.05607279821208889, 0.10112097832344233, 0.05722516681998969, 0.19226755315978683, 0.055858262949773384, 0.06890223136231785, 0.09988176981888472, 0.0703584878975826, 0.05596558803752546, 0.006901968125959919, 0.2330888852837586, 6.751064398596364, 45.263422227674916, 71.96022679728847, 74.77595513866794, 76.06456356663858, 66.78532615784677, 47.07942470427483, 32.90130776743735, 32.51393056684925, 30.234070554856334, 32.819532232899824, 29.546045641745295, 29.52087186997937, 46.97993378485403, 54.25542446874804, 35.863728830891276, 16.74777146308653, 4.33513246236309, 0.25011989318074723, 0.10130364432810776, 0.11034161258008211, 0.46883627952587226, 2.229456574686112, 6.022401279018772, 5.1940378835124354, 8.461915485320553, 7.963627874851228, 9.850781656080677, 7.650927699381306, 11.096273429932134, 9.404419852841286, 8.719030772486041, 6.485292440460575, 10.537588673253214, 11.538372597386761, 10.896197249812465, 12.61924151451357, 7.467076403479423, 7.575847160431647, 5.669967983999561, 7.5933772133242705, 11.60113444251399, 19.097794832721835, 21.325330426616055, 27.48165319042821, 26.803657777847786, 28.723557956757087, 29.652306572083507, 32.69830549916914, 31.692219511155162, 23.107561296032323, 26.807464438100016, 27.50492265147548, 43.13220631691718, 49.75299066112888, 77.25297112618723, 62.601875182121034, 68.50075906322849, 59.857479064695305, 61.436378186748875, 43.906788133805804, 30.594571675023726, 31.53414995439591, 33.28351136176817, 31.465694788963567, 28.375249524270338, 29.35618527473942, 29.147160207071614, 20.777463566872385, 19.933638188146777, 12.948534296404931, 9.00805454100332, 4.021855453329702, 7.108622760541978, 10.70221741353312, 11.132736763646527, 17.79022566733822, 13.884211778640749, 10.727654964693132, 13.352905165764595, 16.222065994816443, 12.937886041979636, 10.830881941703058, 8.04094563568792, 7.215767695057777, 8.419951027439486, 6.33710676623929, 6.1074088465782905, 4.929479898944979, 2.1073742739615904, 1.2225960411371724, 0.5977891325469941, 0.24095326812276918, 0.45134073123335844, 1.9501213056425897, 9.857237877384309, 22.47636760434797, 44.68570809210501, 49.13261682756486, 43.16576611611151, 36.66582215216852, 37.876759805986964, 34.53263721158428, 26.725102509221724, 24.81493373070994, 41.541493015904585, 53.38441510354319, 58.63968903018583, 66.76978572722405, 54.362105092694684, 17.98637947728557, 0.5098296443541204, 0.04196657994461637, 0.017647348614709995, 0.01840576033798918, 0.03286284687478216, 0.05052703410206784, 0.05596442741432017, 0.06359692309953033, 0.0655371441896404, 0.013864348988018691, 0.016891482218559233, 0.05410766777312083, 0.03405015292246977, 0.022032154355979255, 0.015023553973033786, 0.056258444298779776, 0.10682075674976073, 0.05747884917523592, 0.04186536057762081, 0.10222434411726652, 0.11699046669227463, 0.07455509456415331, 0.0868760560068392, 0.01872629344072794, 0.04598058189355558, 0.07437569975492454, 0.037887230695736025, 0.058284651097511096, 0.13646667402598167, 0.0747674081714884, 0.05891033425746907, 0.035297091254183365, 0.06654986646026373, 0.05303097333038046, 0.24621633812785151, 0.22133576353230786, 0.15070682361481652, 0.2198068052530289, 0.3832029713498008, 0.17910712789143288, 0.21510851058748462, 0.19439661875367167, 0.17552995693779763, 0.2383353158591255, 0.16543420512349377, 0.11866460629408399, 0.3009311956984382, 0.36843886358603356, 0.1476231205367273, 0.1458829671384827, 0.14125510659669677, 0.1935125379672935, 0.2714028575968358, 0.37351137688083036, 0.3463161442308657, 0.5778015308803128, 0.27915042734915213, 0.40875231005972434, 0.28438933494110263, 0.3480696275589928, 0.25646179884431825, 0.2530544542617375, 0.17186647851861295, 0.25533894377370037, 0.3828933798978406, 10.255886989255107, 60.10470213428621, 89.76472793086883, 87.05611951889531, 86.17666921307965, 73.83672791142618, 53.87750802501556, 40.982829832261615, 34.411847822127804, 31.478324820918424, 43.25003039452338, 37.629877982601045, 50.959601940647254, 68.58647069623395, 70.54931102260467, 45.717377739567915, 17.57241645166951, 5.28735940494845, 0.4317719958001568, 0.20120881047220002, 0.2701823876029061, 0.7470062675495303, 2.3737872944724177, 8.701021209839853, 11.431616467814292, 13.368868231773378, 14.377942085266115, 14.646138068168396, 17.312990888472527, 20.860929642954183, 17.957577513110255, 20.32443961789531, 21.767344282519435, 17.404803768281017, 20.682214690792946, 18.436159626130138, 13.433157840082723, 14.866799827544922, 12.662973000157265, 14.4987295135375, 17.211230877907045, 20.848340795886134, 27.30415221183531, 26.142544246489003, 33.58818538727299, 32.02373039337897, 32.12038543916518, 34.62148674072758, 35.32435194138558, 36.103342502347886, 24.94823940338627, 30.715790564014068, 30.497579305402695, 51.77500386391917, 53.946702557225386, 80.29538108456521, 64.89353172240719, 74.5848023506903, 64.180350688196, 64.23343604610812, 48.50055825325751, 35.61519961203299, 33.78424898270638, 35.26436321197018, 35.24632030917753, 29.477804245487338, 30.882304983754313, 33.47957887957173, 25.617019207246845, 31.157555349411506, 26.236281048867014, 19.971600847859538, 17.630038030685917, 16.107299404759562, 16.22500777244568, 16.63725672229644, 19.352805768289876, 23.425302697766213, 28.960280841396703, 26.320470802245605, 17.713784556235037, 20.68632729591862, 15.786959432786512, 16.942672075763827, 11.869842294723759, 13.150990374626653, 9.802102100464607, 7.730109076346121, 6.233081096603025, 1.4978857530701546, 0.9119681641459466, 0.4056077949222057, 0.5893709907127965, 0.7444120486897807, 3.039826342175084, 10.038538652081645, 24.611596099791992, 44.778083832033225, 51.779141964450965, 50.89644001376245, 47.25611179105697, 48.80901736597861, 44.58108671249882, 35.176741384690814, 34.38776839163996, 50.37313699722291, 63.034187055403194, 69.98842777744417, 79.39730736517137, 63.20233514232021, 25.089895802159464, 1.1351642036630263, 0.3273282873053705, 0.12821924722483083, 0.18034103506755444, 0.15434696699582762, 0.2199564835116748, 0.3043947711346611, 0.1736186288537518, 0.21039736096657094, 0.34457344742071244, 0.25383333585435347, 0.4208145176451053, 0.2756893646813208, 0.32986532536245167, 0.24042477470732507, 0.33219692928175776, 0.18164543765446833, 0.2155017281972593, 0.10196109332384602, 0.17220625383478982, 0.2828508465280456, 0.13934532601025798, 0.18759751181689002, 0.15777485805653757, 0.18986076537159183, 0.1977504291121037, 0.11799110775633205, 0.23323965138725697, 0.4221601970493794, 0.2809875061915767, 0.19409833475947383, 0.28027813941720997, 0.16818590101695832, 0.11252630381814896], [0.067916406438716, 0.04484979398248177, 0.052320227597750006, 0.04740524496282301, 0.042573930620546305, 0.060701719785649935, 0.03775837470687205, 0.0703043484639737, 0.025751011355990366, 0.10497570293204439, 0.049464336085704066, 0.09017259363205203, 0.06079238629148853, 0.02497820484061395, 0.029613325980702238, 0.06697104627927465, 0.0962131662714866, 0.04996768649547331, 0.09473197357428652, 0.05168919714408056, 0.16167989932000637, 0.16530154933852537, 0.11763010414377337, 0.19962201255463785, 0.03752334276214242, 0.07320088860128196, 0.05286493526411153, 0.163774061948061, 0.06230924804244311, 0.08924025696732345, 0.13225679105568316, 23.93279660132624, 54.551308462696696, 59.211194053772964, 62.08245923442226, 52.7839159196423, 48.23182882801179, 26.754430071000133, 29.609827303117324, 25.972723268693496, 28.473204835768673, 27.996187748447543, 47.28793790263515, 56.27351137899584, 56.6704866193956, 33.78767321186681, 23.434724230920118, 6.4832145648617905, 0.38771814035792507, 0.11152061423467052, 0.015885963089643948, 0.15846798376690957, 0.3507889945420527, 1.5923940366314304, 4.7437262535095215, 2.3399384656260094, 5.8695146441459665, 2.802040004922498, 9.460279307057782, 2.3891909324353744, 4.457642301436394, 3.73744708876456, 6.62810888021223, 6.200605342465063, 10.191031579048405, 10.67731624649417, 8.100732363039448, 10.206331764498065, 7.1497929384631504, 15.060196211261136, 14.8755516159919, 24.51774750986407, 31.764298946626727, 36.81415834734517, 40.689875848831676, 46.591101384931996, 39.766451851014175, 45.170611104657574, 45.66725377113589, 46.63150179770685, 47.070477777911776, 38.41897256912724, 43.42928663376839, 43.50769481351299, 49.292653452965524, 29.72670020595674, 53.87291885191395, 48.86797058966852, 57.80684432675762, 45.83455462609568, 44.243511845988614, 48.18507025318761, 42.24443274159586, 48.83800368155203, 52.16538952242944, 51.11835595100157, 52.85962943107852, 56.459596464710856, 52.83576965332032, 52.020497168264086, 42.27226195796844, 38.99509030003702, 27.97297908413795, 17.703309866689867, 25.937376829885668, 15.691564448418157, 10.28451636914284, 21.267183249996556, 9.708559455410127, 10.741356784297574, 10.193257524121194, 14.48962373118247, 7.849101529967401, 10.074263599611099, 4.362277225140603, 6.555027279161639, 5.0041966380611544, 4.710614585107373, 5.141855651332486, 4.67521813607985, 1.6542471176193607, 0.8415067063704614, 0.23444657694668541, 0.01865072078221748, 0.12731406837701797, 0.26529146778968077, 3.3305031445718583, 14.90676191545302, 26.745971479723533, 33.111229096689534, 39.38803726626981, 29.526243555930357, 23.928111330155406, 21.872018614122947, 22.447322453221968, 28.47940806419619, 40.16286619247929, 45.963322116482644, 51.05769257391653, 60.59655558678412, 57.410586880099395, 33.10542006646433, 3.6764331498453697, 0.09355969817167328, 0.019179602987283183, 0.04110787582073001, 0.015928842945985736, 0.051549060510531555, 0.05294755401630556, 0.01985747588708276, 0.09019260384863423, 0.12136432312188611, 0.0710571064583717, 0.1098454250924049, 0.021316722080472018, 0.11301803267410687, 0.10360404548625793, 0.06785667456325985, 0.25093818233618814, 0.09390492803387104, 0.1061669466716628, 0.04034918447535846, 0.015112106076201365, 0.038619560955633084, 0.0005500544214174302, 0.04555466765117261, 0.06562771876492808, 0.06196265837417976, 0.04666294406859144, 0.02369864265464487, 0.059910810612622774, 0.1338588341229385, 0.12057768105859719, 0.08916357156610297, 0.1012829599541522, 0.03127838744060888, 0.016805318394495596, 0.022551853082052643, 0.009590053345046697, 0.005744812426142274, 0.06922722118155611, 0.08995184539667062, 0.06145068947526236, 0.013712685604038979, 0.062178990112677704, 0.008480610558763146, 0.06266208132728934, 0.07202786243250293, 0.03810193449739487, 0.020516259791029078, 0.04139526221420496, 0.059270361107924295, 0.06010869495390404, 0.0290865486022085, 0.1209453649578556, 0.05623176528681671, 0.022427402098753282, 0.18313158694053852, 0.11246527725410078, 0.11267667921680598, 0.024633942164420605, 0.05125031303313952, 0.013958245512068033, 0.07679394055758754, 0.02463967441731403, 0.08602838737950211, 0.6960615431589465, 28.748768991039647, 66.00926952977335, 71.18609997533983, 75.09832689839025, 63.42079939380769, 57.051333073646795, 36.11598822378343, 43.16557391997307, 31.737558187976962, 32.395267102026175, 33.841346925304784, 34.52199582130679, 46.386306593495036, 51.97109099357359, 35.41016947838568, 23.91479096105022, 4.2379420130483565, 0.4983172733937541, 0.13061284297896972, 0.3988449239442426, 1.3328235908862085, 3.5708245586964393, 6.151076593706685, 7.738243091490961, 9.271706458060972, 9.175614272394489, 10.157986590939185, 10.785000016612392, 10.86146270075152, 13.219115080371981, 9.271628010657526, 11.52803421020508, 10.865560596989049, 11.058275468887823, 14.15528089769425, 10.812529171666792, 8.026350986573005, 6.301915261053271, 11.024923555312618, 13.254914552934709, 22.048368377070275, 32.376429919273626, 36.00784847813268, 41.25030409905219, 45.254130132736705, 42.09215064202586, 46.31416243891562, 48.62023761195522, 49.52512448833835, 49.609973199905895, 43.567860049586145, 47.85677963687528, 49.078856821983095, 52.56406707148398, 39.84109455539335, 61.7339252656506, 55.46001964999784, 63.12606465431952, 55.28804332979264, 54.88379993746358, 54.81846109513314, 47.60488502440914, 52.30476310176235, 53.98061536973523, 53.91810455629903, 55.577926097377656, 57.356442482240745, 56.33668507299116, 52.69731783097791, 42.03117347532704, 36.7942483963505, 24.559858076034057, 14.981120247994701, 10.902924114657987, 5.719736487634721, 9.504731528220638, 13.488761359645476, 12.312867141539051, 15.722381530269502, 13.5094577458597, 20.015590229342063, 16.859100095687374, 9.239394953173976, 9.269959042149207, 12.19510974422578, 9.642712666142373, 7.3902538418769845, 7.720421802613044, 6.174844195765834, 5.937626602188234, 1.9288187906626735, 1.2079464788398435, 0.22514311326367242, 0.1089427590129837, 0.211388019904975, 2.992057021587126, 11.698465116562383, 23.66186868759894, 33.308120312229285, 41.425790940561605, 34.87831569487049, 29.01132852800431, 28.039108284058113, 26.487512780774026, 33.501395102470156, 46.684022334314164, 50.54070849572459, 60.393215994681086, 69.64220016233384, 65.76980490838328, 40.826888161320845, 5.436794844365889, 0.1492695813818324, 0.06899904955418841, 0.08430124215421178, 0.02317930207467608, 0.037057063347029115, 0.05277074475382125, 0.04688392979122939, 0.0390434067606205, 0.05127946267865839, 0.05544864722797948, 0.05553853232413531, 0.038414088513461814, 0.043250903367034854, 0.04004003735439431, 0.0958794200672738, 0.13971756813266586, 0.04073611633371442, 0.061734862129894964, 0.040211372918659644, 0.030680538170159827, 0.07534316155098139, 0.020212086495913325, 0.06728355652622639, 0.01888613960134887, 0.039752754382789135, 0.0405034669224293, 0.03140467703492651, 0.08057399457620998, 0.026007761893373345, 0.08331647443194544, 0.09558479797335402, 0.023780476166716507, 0.01975628333316455, 0.21285248890278802, 0.11553075510047137, 0.15839016455556118, 0.30023920379819413, 0.23180371150374415, 0.2664661870127724, 0.21122698822329122, 0.15507792212790059, 0.21741094187863413, 0.18458919179055, 0.1312017347663641, 0.1357222970334753, 0.13126104529346191, 0.07322228543700711, 0.10552173976095454, 0.15204510260974208, 0.20024868779845778, 0.21376261667859173, 0.29032670021537815, 0.22531986506956242, 0.3944935138908125, 0.33858521390826474, 0.23356828778501482, 0.3195677859888923, 0.2805837778554809, 0.21608936360045788, 0.1846470007853162, 0.23795472337834297, 0.14958117998415424, 0.22927700031188228, 1.6926096139415618, 38.656350489585634, 81.12770019039031, 84.12855655916276, 83.93246942950834, 71.53531643652147, 65.0501911870895, 43.28077393193399, 45.34435641381049, 39.59398915690761, 43.38719567944927, 42.101172093422186, 66.14477172974618, 75.38185150392594, 67.95356488996937, 42.49687648588612, 29.104259283311908, 8.384222157539861, 0.8573498949408532, 0.2964759654095096, 0.2840361377644924, 1.6258795559406283, 2.2895840579463593, 6.871123246608242, 12.812881085180468, 13.742565185792985, 17.5282407576038, 12.88992722188273, 18.726295386591268, 10.348592208277795, 14.307835601991224, 15.097134151766378, 21.08064709171172, 15.80675563504619, 22.21293926239014, 21.608060752191854, 16.70219352168422, 20.458321878986975, 16.33915658920042, 23.17871701332831, 22.04549131854888, 29.18832548203007, 39.55809162509057, 39.042256801359116, 46.27596247580744, 50.494926591073316, 44.42557650227701, 47.76198771692092, 49.370900815533055, 48.04033871619932, 50.41789908562937, 45.02698567605788, 53.47874026144705, 55.331860126987586, 62.50459647947743, 44.15069287823093, 68.91242750229375, 61.84659142648021, 70.32980734302153, 58.87030870683732, 58.31246137619019, 62.921250251031694, 53.68674747405514, 57.295900698631044, 55.79055778441891, 53.54698558007517, 57.97858530475248, 59.63810090095767, 59.26186715402911, 59.33637257545226, 46.82099150073144, 46.663727991042606, 33.72914360415551, 22.94388274992666, 36.67958574910318, 25.884091431094756, 25.854516759995494, 34.56892305804838, 18.878771643484793, 22.701992142585016, 20.512613365727088, 24.53668079068584, 19.021691045453473, 18.009464586934737, 10.102423275670699, 19.383965076938754, 11.071796859464339, 15.387824927606891, 13.995753199823442, 12.931477869710616, 7.192560011340726, 1.6128279917663144, 1.120004978391432, 0.17268410883843902, 0.30478167617993973, 0.28051976354852803, 4.717426761504143, 17.829659215865597, 36.53156726591049, 46.33131888604934, 52.86401464093117, 44.15905929380848, 34.459606601345925, 32.6360123772775, 34.221726617505475, 40.91760866103634, 55.77992031651159, 61.450761518170765, 69.83349415563768, 79.09941904006466, 77.29149664601972, 49.57470324731643, 8.600963507929157, 0.32942335391717575, 0.1977865271750958, 0.22975479402849752, 0.13069640784975023, 0.17349993119076376, 0.12499653749288091, 0.18951407994233793, 0.29022352349373604, 0.31190289244536434, 0.1519507512209877, 0.22816782757159204, 0.18377873205369522, 0.21993670312146987, 0.21589906736006662, 0.32566428304679934, 0.4656124896099491, 0.38645676126883877, 0.2986936673762337, 0.0959338965795694, 0.17008103400228486, 0.1552261294977319, 0.12727148154930723, 0.15846248325561324, 0.18265941630928748, 0.12178063062169861, 0.1821606624270639, 0.08784509594402007, 0.23372080056898056, 0.2001450514240611, 0.32476011543504657, 0.27397504376788295, 0.2234942315807266, 0.10611351969982348], [0.057921372203817295, 0.004857923448716681, 0.04222503119719125, 0.0493585508346798, 0.10319670887603875, 0.02269767217278, 0.14132005553091728, 0.03610548638408223, 0.03291265408117925, 0.11571052529278303, 0.015345539769998964, 0.05947478017919968, 0.13086045791785564, 0.018027527408013423, 0.009035652751223215, 0.0405645854170284, 0.08026071058045472, 0.03710825717256915, 0.05175978065498414, 0.02647468099190343, 0.0948550149558052, 0.11693001469416965, 0.07530317176133394, 0.12760513582296912, 0.0971292388895827, 0.09638626383797777, 0.06972445054881035, 0.01971421936046212, 0.03757104705718737, 0.07430130495659767, 10.782616196140166, 40.96638725649926, 62.1962393483808, 71.79573828174223, 53.11321458508892, 41.29107713699341, 26.4289302210654, 25.76612222579218, 20.70717469338448, 29.02460182866743, 27.811357821187666, 35.418257405681, 43.41052985960438, 28.78556082325597, 39.53278841510896, 31.313630380938132, 5.105831132781121, 0.49153506635658206, 0.09425569671176134, 0.28216026422958224, 0.22174448676166997, 1.3441254102414655, 2.0641448516999525, 5.296812807360004, 6.345364336044558, 5.5073058220648, 5.962578269743151, 7.695677530380988, 8.234810252343456, 9.281907562286625, 14.520219199119078, 8.402126796783941, 4.2887788722592015, 3.881963875985915, 7.370238967480199, 9.494335286078915, 7.144845358787045, 13.62668562319971, 15.085136602001807, 23.48592292877936, 37.433410383039906, 45.88268603048017, 45.773220523711174, 56.16974899845739, 56.10177824574133, 58.83668222735005, 58.69293520527502, 60.38644990613384, 64.3056861046822, 63.083142157523866, 67.48393166449763, 57.824141979217536, 60.28774346074751, 55.142142926493, 49.72015650041642, 22.88402149754186, 46.6923063801181, 51.20504425417993, 52.52831074499315, 50.22287491829165, 39.756414505743216, 43.457523776638894, 48.61745665150304, 59.160454273223884, 61.76479431890673, 60.95739795315651, 65.19173775949787, 68.45114892528903, 67.11215373008483, 65.26736497879028, 67.53529117953393, 60.69711731326196, 50.90438281336139, 34.55872097323018, 27.099953620664536, 20.614402794068862, 12.05979875979885, 16.568852547676332, 12.339017583477883, 9.72681808856226, 13.098375701135206, 19.45705060035952, 15.905383633029079, 7.268916791485203, 6.188174861092722, 5.738010810267541, 9.731418048181842, 2.6938419140154317, 4.901529579393325, 2.956737549074235, 4.800254471840398, 2.7283685774572435, 1.8716915528620444, 0.5077540363755919, 0.18355164827117998, 0.08840824717715864, 0.12337905009307208, 1.4733237484770438, 13.83850439902275, 29.401518068005963, 39.09441647991058, 39.590702210703206, 38.03961269317135, 31.66238400243944, 26.154150539828887, 15.590389851600895, 20.82408485874053, 29.44707247518724, 44.001317254958614, 57.485876775557, 64.65602044136294, 51.9579706653472, 22.25617947116975, 1.1292839579043852, 0.08174477610737085, 0.07465656290972426, 0.06988705271073888, 0.08207166582466134, 0.034625664984266606, 0.11281189373544148, 0.026940259436566024, 0.1639760486901768, 0.10306445145679098, 0.04337165031522032, 0.03129527584889964, 0.1293437110800897, 0.05564062503136455, 0.12212957601032912, 0.051382558961068435, 0.03448272446891473, 0.034624646087327314, 0.07097444557134183, 0.03811173659238604, 0.04466562644548474, 0.006458392205287613, 0.008737036466388213, 0.10251425477045198, 0.043132205704046835, 0.052308996748780055, 0.02931007390631543, 0.04290997891897156, 0.09653947376195463, 0.13184341001174144, 0.20542834615034444, 0.03875701245100748, 0.021416466728213335, 0.0202266325903756, 0.016356074859598474, 0.009351958006229854, 0.025219614467313214, 0.05138762280224793, 0.08397672730948656, 0.039645394821080475, 0.028313939354472586, 0.015335061602414617, 0.023397715657108256, 0.01023490498248007, 0.030399713319756334, 0.05685527658750934, 0.04215410294672174, 0.020843856224429705, 0.04592294143813272, 0.02684252002396651, 0.02532623283895514, 0.14911331476703768, 0.043392173810711795, 0.03442101225617432, 0.016493627861622843, 0.043121932464982235, 0.06620849002032511, 0.04102018556647724, 0.040858586979729515, 0.0054726122893513215, 0.011107400604223293, 0.06431223854662911, 0.1322593191458333, 12.39790608805995, 50.29061817353772, 71.41431131670552, 82.3525857925415, 64.68518326359411, 54.34507023903632, 40.47079186285696, 33.443830397821245, 28.9245911951988, 40.05186703897292, 27.671272331668487, 26.627733592064153, 32.83257607490786, 30.764549547626128, 39.002570259955625, 25.39959046148485, 5.358702905716435, 0.6183266627692408, 0.07597634088127844, 0.39181312546134, 1.218978390097618, 2.589394589585643, 5.136778143144423, 9.403211762828212, 9.038802000784106, 8.61264922926503, 14.730275850142203, 15.11087421448, 11.574272090388883, 14.21597271196304, 14.775422330825561, 15.506984572256766, 10.047181594756342, 8.58957882850401, 9.066245844287257, 7.569052144404381, 8.22314953611743, 7.7418153901253985, 12.153824836977067, 20.975617785607618, 33.53796728195683, 44.45961090826219, 49.82335013727988, 59.5288864258797, 59.270504213148556, 59.68915447112053, 61.35434573696506, 60.667876043627345, 66.86807247900194, 64.05216763096472, 70.2443467417071, 64.50372265231225, 65.61776207339379, 60.13630467076456, 52.88199478580106, 31.14018709428849, 53.74710490626674, 55.967256638311575, 60.09424117303664, 56.75802999927152, 48.13687609088037, 50.32995954636605, 52.56683626482564, 63.13007331663563, 63.67658499748477, 62.86321093959194, 68.20967997274091, 71.23438435216104, 70.32309224528652, 67.80468740770894, 67.59551525115967, 60.32907739762337, 51.1418431035934, 35.23012484273603, 26.177194464591246, 18.052500832465388, 13.254518393547306, 15.456634086947288, 16.938759511516942, 10.871449055210238, 13.838326911772452, 22.65848521263369, 16.355421677712474, 9.72735349209078, 10.525057681145208, 8.683540186574383, 10.136651838979414, 11.662796062807884, 7.085190521132562, 8.080998918702527, 7.5997088993749315, 7.742331181803058, 4.541600144678547, 1.5453471675995858, 0.6912095712557916, 0.18976313512652151, 0.18969005033854516, 1.7057787266469773, 13.930316298238694, 29.134863576581402, 41.31471333965179, 39.349025372535955, 25.620474815368656, 26.14977905827184, 27.813930896020707, 23.527911901474003, 31.654380406102828, 41.16495724647276, 54.192658701250636, 64.03740775200629, 72.7967820628997, 59.15605729626071, 28.549389031625566, 1.7825665997882045, 0.030497910469890605, 0.047116847333288005, 0.028479946777224544, 0.07785900195519771, 0.03137817805362565, 0.03168649396919195, 0.02340786632210497, 0.08260860152903103, 0.03570589492277753, 0.06331563859637226, 0.07106747928886645, 0.030586188696625254, 0.035788306831232006, 0.07563914728140639, 0.03787493498455133, 0.09345293615854557, 0.014987846614883072, 0.07757546515354226, 0.02049417347617207, 0.04750446484033619, 0.02243766576171883, 0.03954146350283296, 0.0073896558681172475, 0.004397565414453106, 0.010446260022299906, 0.06672672551846312, 0.03886156047003404, 0.0701503264867971, 0.016203860849923184, 0.04925781793351616, 0.038504613293034416, 0.05389319762827889, 0.16216821908470125, 0.05284044726361191, 0.1060395539107342, 0.1810624600658494, 0.39029997923681814, 0.15333176260032963, 0.19949885625993052, 0.1151476345295387, 0.22598049333018644, 0.1724739402772919, 0.055301500889923305, 0.1146568556226069, 0.2185517080849217, 0.14265370735478017, 0.1065578047306307, 0.1683430869372622, 0.21612005308270457, 0.19294693525279724, 0.22660684681707816, 0.11326991472273104, 0.17166265316547888, 0.21039725371426155, 0.1974332380679346, 0.3430781357230679, 0.22786084081857438, 0.252684464437827, 0.27902414541571374, 0.09176908256185633, 0.12840539126867248, 0.33992773703029083, 16.278747185584038, 63.409436287418494, 87.664808611716, 95.1203243194088, 73.82636500943092, 59.06503085167178, 43.03784585768177, 41.79137153010215, 33.344919989185954, 43.64251452107584, 40.95233340417185, 49.775528600139005, 60.68710742458221, 42.81136820393224, 51.18968033021497, 38.86228669074274, 6.614489920677678, 0.7597912331261943, 0.2444397495879281, 0.33674329339015874, 1.0877067115037673, 2.3367280056399684, 7.253675931884397, 12.571612173511136, 16.160072934242987, 13.955196872834238, 18.94526758501607, 20.3345436434592, 22.375521506032637, 23.468523294694965, 24.09784601580712, 15.390142067786186, 11.73523243396513, 13.673443217431346, 14.428077820808658, 19.23183398862039, 15.692257727346114, 25.479271450350364, 23.277443070565504, 29.01912816109196, 44.74357874162736, 50.21883095464399, 51.51982230524863, 62.174462349184104, 59.97417742206205, 60.70491106279435, 61.69118712025305, 60.82328034985451, 67.42821831857005, 63.696110556202555, 70.89516209017846, 63.907287043909875, 71.46156803254159, 67.34205169062461, 60.65752883111278, 35.286277494122906, 58.408979139020374, 62.195337203241166, 62.55338684205086, 61.380484411793375, 51.74621366685437, 57.18321884832075, 57.009791251151796, 64.61623976307531, 62.98111738697175, 63.372922943484404, 67.67553944741526, 73.90711092179822, 72.803481471154, 71.89254237759498, 74.5121757445797, 69.09870870651739, 56.571238886925485, 39.55328672162948, 32.72262027186732, 26.011848911162346, 20.60739547975602, 25.248239924830777, 21.763366999164706, 18.285675933284146, 22.53191621072831, 29.681267392250803, 24.529867633696526, 17.899528395745065, 15.511311927149373, 13.705684119655242, 17.24119778602354, 14.527434399051053, 14.416097921709861, 15.144215341537231, 16.471022752023515, 9.060945741591915, 6.046290474553262, 1.3191791359455356, 0.5917982024050529, 0.24055363069618904, 0.3977753732713961, 1.867977313456997, 17.545136367121053, 37.978768887058386, 51.73423867071829, 54.71240020567372, 52.73803987810689, 44.43326434781475, 37.65869955862723, 27.18629675526773, 34.37906465222759, 44.89315832814863, 61.02683567231702, 74.42796245698007, 82.71929602469169, 71.29707951699534, 35.8736720392781, 2.369645271570452, 0.2336306013767758, 0.15341647660299657, 0.11677229251231878, 0.22574530433743234, 0.1281672298547722, 0.13263908425165763, 0.13571003962668682, 0.2519479015421483, 0.23816919735362455, 0.3426624564153533, 0.2514607155875814, 0.24981906577464075, 0.16732533912985556, 0.38566741491517714, 0.1801432618090222, 0.3346862860264317, 0.1525925490404329, 0.21789091128495433, 0.14448560744283662, 0.13987291544195146, 0.1147428872965036, 0.1256774364399814, 0.17047373067227103, 0.11021516976817963, 0.15865734538003323, 0.1614602312685982, 0.11779493562156156, 0.22469918063331037, 0.18957328321712633, 0.34869227318033097, 0.11888271918700588, 0.079926366827661], [0.010431659344073025, 0.014230628073545954, 0.03710580952165108, 0.031907968072881626, 0.12983161715730546, 0.18304990664605172, 0.09083299972717801, 0.03313162116213672, 0.05618589960279004, 0.07070511970068179, 0.05606236792499981, 0.03049393830400321, 0.005052967040213727, 0.06091608267818248, 0.08085262075427078, 0.05592880049540151, 0.013558850360793934, 0.0964024665975763, 0.006163144313294682, 0.04595550400535426, 0.07223393242325514, 0.03892620679952445, 0.11000004461816243, 0.09537829897336422, 0.07633614939667525, 0.0236563392794661, 0.07701993649525028, 0.1276371199938078, 0.05311643426877357, 2.860561767893453, 25.36276528912206, 56.802576357318515, 70.05646521045317, 64.40942495099961, 57.034894420254616, 40.35021035901962, 22.15572168750148, 24.979934115563672, 37.933614561634684, 34.47119720520512, 48.0604330185921, 40.85964779700003, 33.398028881319114, 48.161226164910104, 29.028836027268444, 6.728971158304523, 1.0819945147921963, 0.09412763745433862, 0.13912663855139287, 0.7273307394596839, 1.3930436175677086, 2.4830451607704163, 7.1293255206077335, 9.277591974504533, 5.4673618751187485, 9.446613769377432, 8.817296931820533, 9.772195989085782, 5.573159965776629, 10.053182821119986, 13.628834101461596, 11.41891191082616, 7.28504704852258, 8.712863825982618, 8.98173543714708, 9.844515669730402, 19.46112202059838, 21.03840708732605, 32.11424889103059, 48.514796456983014, 52.05588086958855, 65.73566852077361, 69.52776893492668, 62.654733042563166, 63.717805185625636, 66.31305709961923, 68.40390789893367, 67.94531222312682, 69.51373469445014, 66.61231825428625, 67.83147719598585, 73.29220094988423, 70.13346133693572, 57.54743053067116, 44.129943540019376, 22.816901899153187, 46.09884000593617, 54.794860193806315, 54.03811339409121, 50.13136209980134, 36.81702952231131, 41.69107652479603, 49.957730539383434, 62.28230007233159, 61.139807778020064, 67.68168187910511, 67.38220107170844, 66.24800066794118, 65.09996214220601, 66.62229676400462, 66.37902352117723, 68.42617911677208, 65.48393864785471, 60.730524140019575, 47.191890824225645, 34.19789821870866, 29.230824362847116, 25.613696959710893, 17.462082139907345, 11.641834916607028, 9.60238972017842, 23.037223392917266, 14.760112339450469, 5.860489760675739, 11.91310799890949, 11.866721068659137, 9.336836434179737, 5.583774880055459, 4.05178044111498, 4.719955219376472, 5.002435003557514, 4.428433881651971, 2.515493703465308, 1.7415036741764316, 0.11047329543338669, 0.0994516574146767, 0.14445493328234843, 0.2066485556743799, 2.311588799761188, 10.871124479078478, 27.813948546686483, 38.21842962695707, 40.6209715720146, 35.728097192702755, 32.47359095081207, 29.35339450836182, 19.31907730717813, 21.106020904356434, 34.906929385277536, 50.627836104362245, 59.3807698834327, 60.5472239371269, 44.3183938149483, 7.5341332439453375, 0.05287030554046074, 0.06432228962019568, 0.038481657468383355, 0.023219912395542188, 0.05431592494489686, 0.017956105030832753, 0.05083942177495168, 0.05867295808369114, 0.060748320914083914, 0.13606435529166652, 0.06303531553355918, 0.0561983676837577, 0.011114621940519542, 0.02882532219612791, 0.06940888361104074, 0.06455649035952746, 0.08717042529174397, 0.05572297182234545, 0.04164274691814377, 0.053532247641874905, 0.02738679676587063, 0.05389172290902465, 0.039752333034430785, 0.03930897497001194, 0.1429379412964467, 0.07388580950998491, 0.03518409328535199, 0.04309651366765461, 0.16239850511473997, 0.08300771035494343, 0.04041158999767035, 0.03191080642864108, 0.03100192737615397, 0.029317981848913818, 0.0407644615869128, 0.04991300696987779, 0.060590797915093364, 0.0824070361352736, 0.04127121342706584, 0.01737018566458456, 0.02702137282598884, 0.09014227953288825, 0.036664075563631715, 0.04301898556971743, 0.02791846753098071, 0.09265042075346555, 0.05127430690692798, 0.03236828349350441, 0.046456127142113064, 0.034276937930694515, 0.01905286331631003, 0.008852628600453178, 0.06801548458996319, 0.02439958437706434, 0.08683101769777075, 0.07644108045966395, 0.046610562806768764, 0.048414945016585054, 0.05711378529667855, 0.11363329320785501, 0.05712307411276045, 3.4265592934623843, 31.1584202320345, 66.23282894011467, 81.49262966648226, 72.88311343039237, 64.99313639056298, 46.73467974508963, 29.796732164198357, 37.0207574290614, 46.98491911734305, 34.320903747312485, 31.524516613252704, 28.461271024519398, 33.25646269705988, 50.18096831537063, 31.015432188587805, 8.90391561292833, 1.057141274213791, 0.09885970893646441, 0.252005220240643, 2.106400790714449, 4.276241016003394, 6.299892298636898, 10.826283943268562, 9.470735365344632, 13.703481708803485, 11.648479411678931, 13.358246453346746, 13.371513870454605, 14.860122972919097, 19.069008558027207, 18.432755008820568, 17.44933443684732, 12.142142057418825, 6.414447080704474, 7.164766586595967, 6.945736533211124, 9.323383685081236, 17.626968776026082, 29.60589904938975, 43.070154420791134, 52.50643176417197, 64.66094301592919, 70.15432834625244, 64.91828972293486, 66.30180774196502, 65.31935991779451, 68.85963239977437, 68.64874224508964, 70.37707190359794, 68.18846779484903, 71.29638133510467, 73.9745129308393, 74.31040902291575, 61.07542599401167, 48.53002702036212, 31.18326060233578, 50.99997097446073, 58.858035610568145, 61.22534682673793, 57.83119832315753, 46.032242082780414, 48.389319835170625, 55.4954033513223, 62.28431617060016, 61.90687041128836, 70.79335304998583, 71.49970916009718, 70.18605247620614, 69.49147132135207, 69.34537872191399, 68.50809389545073, 69.70928053702079, 66.7270475818265, 61.196423269087276, 48.219198796056936, 33.4834659484125, 26.269209346463605, 21.837064412332353, 17.12477203338377, 8.880056815762675, 10.842455875489021, 19.812603650554536, 19.865512501808908, 9.801349005391522, 16.260245365481225, 18.467922979785552, 12.001307395196731, 11.76606128292699, 8.210861730960108, 9.771259523207142, 11.536612433771934, 5.814405833521198, 6.886128763998709, 4.7127493350736565, 1.148346799515909, 0.41443459869873145, 0.15543571583205656, 0.09241055862437333, 2.156231071679823, 11.582746371146172, 27.590848053655318, 40.155052831096036, 37.90514599892401, 35.27790715617519, 33.837369641950055, 29.313764841325824, 23.066805908756873, 28.746503822265137, 42.045670555483916, 58.91672211308634, 67.35267346905124, 71.84753710223784, 51.499167103921216, 10.36730387518483, 0.1198257121347612, 0.01807611653461091, 0.03865414982541435, 0.03553938954287479, 0.016141696645307447, 0.054977790437518596, 0.049686344535720926, 0.031803822250015316, 0.008908933190058076, 0.05937427710441332, 0.04771695464789387, 0.0324670207356253, 0.03407999587756011, 0.04533311119303108, 0.11671766278243835, 0.057474662504729726, 0.03746966681172771, 0.04326250193820846, 0.05307344907534219, 0.06338960821590116, 0.031860786632845, 0.028621228712220347, 0.037410417571663857, 0.06761118168792418, 0.02289955549302601, 0.02463693373776492, 0.016058308932359423, 0.0176070983551683, 0.059665762068283175, 0.00877258198846492, 0.01413792473143868, 0.014408461978628993, 0.09591461414651525, 0.10186595286452964, 0.11294180692564096, 0.1285115557332193, 0.32401167817654153, 0.20101889727577088, 0.16241853065308065, 0.13328106593220465, 0.21489389871637668, 0.1645672847066195, 0.12794965322339727, 0.1631424684197672, 0.13932243530308047, 0.16780452712649302, 0.23759092354486067, 0.1105820033098421, 0.11639861014461327, 0.19326322231321566, 0.13985063760511338, 0.15906671212325174, 0.23104575943321953, 0.17619495189959006, 0.5156075101225607, 0.32167146342896646, 0.23950975929056448, 0.2645445014199903, 0.2463635955486567, 0.211871390741679, 0.18522279246920542, 5.26324418283278, 42.27270518579791, 82.28175563196983, 90.73450257701259, 83.89335555415, 75.32170587970366, 53.855389779613866, 36.9863425531695, 38.6758799706736, 52.08934653189875, 48.39039456459784, 66.8019962310791, 60.96253625808224, 49.25892499185378, 61.28692411607312, 34.409741509345274, 8.610969474238734, 1.667834820766603, 0.26286064016242183, 0.5497167475761906, 2.120276910643424, 4.479127574351526, 8.369509347023504, 18.370703112694528, 20.46032621014503, 17.71929156395697, 18.333756346856397, 18.192919723449215, 22.235624290281727, 20.17433443377095, 22.74137862267033, 24.828320780108054, 23.33617271915559, 18.261902447669737, 18.55314039414929, 15.870823629440801, 19.004136477747274, 29.843657439754857, 25.33551069997972, 37.952759650445756, 55.56789267447687, 58.65715534456315, 70.72620207263579, 73.61475313863447, 67.20970307627033, 70.01215027224633, 67.84125958719562, 70.67519557091498, 68.57633529170867, 69.06751017416678, 66.92020077859202, 70.89904523664906, 73.4476052561114, 77.0176524500693, 69.03982608549057, 53.165044784545906, 38.79243712271414, 57.28244696894, 65.2010690781378, 64.7204649832941, 61.981132645760816, 48.658661150163226, 55.47819199100618, 58.8084803858111, 63.14680222542056, 61.44923571617373, 71.72690852995842, 72.8374570415866, 73.63963665500765, 71.2925374123358, 73.46723279645367, 73.35879495066982, 73.76611740358415, 70.10544776916504, 65.75131093302082, 52.73256817171651, 38.05267810821533, 33.022316809623476, 32.64277454345457, 24.841123396350493, 21.683132956104895, 14.384696406702842, 32.19250605952355, 24.08837937539624, 14.548267087628766, 23.784764389837942, 17.884172316520445, 17.824571901752105, 13.1731076394358, 13.805899696965373, 13.304617847165755, 16.284745470170055, 12.566142428305842, 7.8988827813056215, 5.542314937037807, 0.6361074409177226, 0.3239858763352517, 0.5134093587196643, 0.5564035307015143, 2.8511461182948086, 14.399506295880965, 35.51051547450405, 52.399433428241366, 54.866870987799864, 47.97218361208516, 47.34072908278435, 41.66362385595999, 28.827096762195712, 33.23730584113829, 48.555518504112, 67.88250723192769, 77.71177076524305, 81.15879674111643, 63.09468961531117, 14.305087001092973, 0.3475725284266857, 0.20550722256302836, 0.13168116791113732, 0.13796049951305314, 0.20022647124865364, 0.28265724078782145, 0.11300083400020677, 0.2222386134728309, 0.20691308583463394, 0.2709672600030899, 0.3880107859450002, 0.2132197361319296, 0.09215976442060164, 0.13697281299579528, 0.27027529874636286, 0.2948388661588392, 0.3072780196464831, 0.08662517753339584, 0.16463793333499663, 0.23514489673318403, 0.17262498217244304, 0.1438835389431446, 0.14824478556552242, 0.2131380711592013, 0.19411333476103124, 0.14325318647728813, 0.13857494799360154, 0.18742031568000395, 0.2620912733818254, 0.21545184055163016, 0.0771987337558981, 0.13789201125262246], [0.0476558591359325, 0.06048124351148164, 0.03700203142098842, 0.028997737944366473, 0.08709003202496998, 0.13516011107112133, 0.048414979490541646, 0.010765928403294135, 0.029180672079805407, 0.07259927209346526, 0.0345468805021336, 0.012254592372975763, 0.033507260884488785, 0.026887814972489595, 0.015414565249586539, 0.15433743686204957, 0.022210591555302663, 0.010834647447711999, 0.10576164785532222, 0.09683231853189007, 0.04744536498741758, 0.08090380308849197, 0.052399513867473414, 0.013924755020848206, 0.08127013101212441, 0.03814748225493297, 0.02300140113689967, 0.05669049873587586, 0.15655558315976975, 9.577411086328569, 43.27987178679436, 64.62972094935756, 66.39231251132104, 65.12824243114841, 48.841012139474195, 38.20999260871641, 30.508483494481734, 20.070407313685266, 34.758322546559, 55.52182835917319, 51.91983738253194, 39.10184937138712, 51.0267529179973, 28.368048052633966, 5.688900774525059, 1.126792517400557, 0.041628325312969186, 0.15868425038793396, 0.18912636284385959, 3.1307238388446073, 3.890679627656937, 7.139052508338806, 6.376526586471066, 7.254654072946118, 9.724507812530765, 7.704138573138946, 17.038287693454375, 14.149045309712811, 10.30341434863306, 16.417459845542908, 13.43617610393032, 24.15033321226797, 15.196007297885034, 6.27425225511674, 15.067938969981286, 15.458217743904362, 24.64405763533808, 38.6692629321929, 55.5414088310734, 59.48150419419812, 70.36113139121764, 69.11012280371882, 73.36240353122835, 67.9351140606788, 61.52873431482623, 64.49005711463191, 66.41937686551002, 66.94823788058373, 65.9546152237923, 66.33004096246535, 69.94918838624032, 70.36729735712852, 73.57688657699093, 60.856679331871774, 44.460783696943714, 26.606970525556996, 42.36612035382179, 59.05608000293855, 52.736655281436065, 45.24615203180621, 33.908325318367254, 45.53728211310602, 57.50993659419399, 60.603000040977236, 61.33076836985927, 69.28251881753245, 68.6099107803837, 64.05054769208355, 62.39424059467932, 61.370592194218794, 65.17191802301716, 65.79545328694006, 68.22103915675994, 63.55986310589699, 61.87628376868464, 50.5156288608428, 47.31049153112596, 51.727405901878114, 48.74314115893457, 17.533908582502796, 18.468503490571056, 26.08157688571561, 19.97804334086757, 8.268202370212924, 8.841939222428108, 15.145628375391807, 8.276362861356429, 14.402611832464896, 2.903452395431457, 5.534378511290397, 8.93392566711672, 7.640834460335394, 6.397749550880925, 3.161129071827858, 1.3694734823319221, 0.925598277920677, 0.04902203905306036, 0.050462134963562416, 0.15505167595561475, 3.0443623181312316, 9.269694282162575, 23.131399500754572, 32.7561604592108, 34.416248721461145, 37.259665073887, 31.789464873652307, 27.231149058188162, 22.62941260491648, 34.73920099196896, 40.859690943071925, 49.55504040564261, 54.90322351455689, 47.51183071444112, 23.546935396809733, 2.0545333287408276, 0.006246694341121663, 0.04066635636732944, 0.014864567746107858, 0.05595670524804343, 0.03834697538085523, 0.11469185817986728, 0.16687745348580424, 0.173935161062306, 0.07108497673705702, 0.11907252513112561, 0.06024074552941227, 0.01809872953491586, 0.05755468804930007, 0.04989611473114741, 0.07953786065862065, 0.08007341740472664, 0.041208237169250365, 0.10374964049626743, 0.03507498704317597, 0.04499266554992046, 0.06387976276117467, 0.06605038479451211, 0.05040379736812846, 0.06979796434602431, 0.039861006436929594, 0.08219135940195092, 0.04160460340039384, 0.04829284209277361, 0.05967249215069798, 0.05521898939003868, 0.07067956300752778, 0.08107709217696421, 0.06894400613682886, 0.0073288366266135736, 0.041227956272421346, 0.07438328402537493, 0.06923475948673102, 0.022941728633257653, 0.08072792462283566, 0.02340611581119799, 0.082016660711698, 0.04713388895916362, 0.023808649050131924, 0.025301225813886812, 0.04151347341136106, 0.023780414879682566, 0.045398301444947727, 0.08363678345396634, 0.0370825472618303, 0.056690540870711695, 0.11479019322582792, 0.04473517956813017, 0.11100577250603708, 0.03139374496024703, 0.06300883953489604, 0.08539762122616654, 0.04361647669406187, 0.023379657049513152, 0.04845067152693387, 0.15252726302752573, 11.155684590339662, 51.41827214148737, 74.8382031533026, 77.77397955617597, 75.20121851275044, 61.16475797468617, 49.90473931835544, 41.13238196219168, 28.341677957965484, 32.62042291702763, 35.5226355983365, 48.48180540146367, 43.16263606471401, 60.3219190720589, 37.985158428069084, 8.858897589868116, 1.1097083889668988, 0.17027646303176883, 0.27954266436638375, 0.9095723314150688, 5.370240067282031, 7.9726243211377055, 9.818735891772855, 10.844346457912076, 11.341070513571463, 14.723395032267417, 15.639990183614916, 14.070370408796496, 14.383306907069299, 14.211698309067758, 9.55986338277017, 11.232419879205766, 16.03702916252998, 12.170995992998924, 10.707221377280451, 11.684369098755623, 15.24058895726358, 22.47073704196561, 37.28514479052636, 52.031930877316384, 60.74988103681996, 69.1545004998484, 70.63627781406527, 73.11870667242235, 70.06816171830701, 64.23908033678609, 67.74225111930602, 66.8758701509045, 68.53398938332835, 65.7417481945407, 66.75424529660133, 68.42925425498717, 71.37311858515586, 73.63148596978957, 64.32501554489136, 48.60173186948223, 35.36705086308141, 48.56881926136632, 62.1007727807568, 58.54774082860639, 54.41745758056641, 41.85991494886337, 53.64222465022918, 61.33133711353425, 63.34041826186642, 61.22904562181043, 70.46019477228965, 69.22325180422875, 66.65380124122866, 64.62289602525773, 64.53976923419584, 67.56026883279124, 68.7599806631765, 69.91329869916363, 67.1301652539161, 63.15175225657802, 53.18487628813713, 46.96060434464486, 39.283808123680856, 30.229706918039632, 16.71881848765958, 13.149627350991773, 15.666945692031616, 13.847508199753301, 8.607525633227441, 16.496290660673573, 19.418731004961078, 14.440911816012475, 11.928118909558943, 11.116329489215728, 11.771803632859262, 11.269951078199572, 14.212344519553648, 13.72260130220844, 7.493567601326974, 4.532677733129071, 2.6811329443608565, 0.20812926573618767, 0.0071196793015265184, 0.289860459104661, 3.337896812346674, 10.395456687096628, 23.368100812358243, 34.70113438944663, 35.718860010946955, 36.19301965159755, 34.46510184195734, 31.572520540606593, 27.46203741719646, 39.72654173451085, 50.577829807035386, 57.745984831163966, 62.794522393134336, 57.288785519138465, 29.447437255613266, 3.0467132887532635, 0.060271653346717365, 0.04318810713988158, 0.07763191051180325, 0.05082937070138512, 0.024883081618275855, 0.033933745862375346, 0.07836743918878418, 0.04264075647018129, 0.019877671879986604, 0.07995066713661918, 0.04792962065567413, 0.023195669543178334, 0.061445564347048925, 0.09164633229374887, 0.049488850899281046, 0.009443836846208621, 0.08084940318498882, 0.03532611449519473, 0.058293411312925245, 0.07396308479890709, 0.013767581549473109, 0.02835595927711937, 0.06375868639518177, 0.09593481588507853, 0.014015907034908813, 0.02083567440539839, 0.03623706964595664, 0.11277846931930512, 0.048588755044845805, 0.03536670949430235, 0.035332618581671874, 0.12142804631542777, 0.2384030533533904, 0.14041311468087858, 0.12192700704139088, 0.2365896313060676, 0.3012499189184558, 0.1438488504819332, 0.3122802980003819, 0.07659059783984577, 0.26998020167793, 0.1681013861971517, 0.1575759356661189, 0.15340688518218457, 0.14809895306825638, 0.1154223919635819, 0.21449565556981873, 0.13668222052435722, 0.18355036124346719, 0.16873078871398203, 0.19918495939383585, 0.1299757182958626, 0.20257232440335138, 0.13778768539909395, 0.20892644150843545, 0.2019825286322063, 0.18161350710978433, 0.16389838269641324, 0.20746479171418375, 0.47031777099736277, 15.625257761247697, 63.48317684665803, 86.78040043000253, 89.62615843742125, 84.13123161562028, 67.5113098083004, 55.12733597909251, 45.66181736607706, 30.868500201932846, 47.779579547143754, 73.1190832199589, 63.83557435004943, 49.99564024709886, 65.92408349437099, 36.64646525536814, 8.252097118285395, 1.8171029465813793, 0.2419506686349069, 0.3447015066781352, 0.515088654093204, 7.147096799265954, 12.374276749549374, 17.183391855609035, 17.620432146133915, 18.638973620630082, 26.829470895951797, 19.956213389673543, 28.745262392105598, 26.196827888488773, 19.609850452792262, 26.81916879069421, 24.06998149810299, 37.767349212400376, 26.49740892071878, 13.984636222162555, 23.627481268298244, 23.59637491164669, 28.56247405852041, 45.79094571451987, 60.50769821290047, 63.0593490600586, 72.6618839079334, 71.71759682316934, 75.33247670819684, 70.37935472303822, 64.41430045712379, 69.498594345585, 66.40131827323668, 67.02379841958323, 66.19513496275871, 65.37069197623961, 70.79606733014508, 70.6540539956862, 76.41881635112148, 72.10610758873725, 55.378873655872965, 40.96679910536736, 52.31296870016283, 68.43611055804838, 63.1499558110391, 56.4423615701737, 47.01173636221117, 58.64601581327377, 62.73313729993759, 61.72398990200412, 61.189900367490715, 73.33375453948975, 72.89523355422482, 70.40839595179405, 67.24517699210875, 68.08141062336584, 71.28741479689076, 71.11998450371527, 72.89229177659558, 68.3440995985462, 67.96211565694502, 54.616666916877996, 53.68620226460119, 56.511065806111986, 54.378253490694114, 25.282019376754764, 27.850169674042736, 33.34458266535113, 30.335836448977073, 19.477848968198224, 16.882383285030244, 29.15249266932088, 17.86714138523225, 27.30658212015706, 13.713376868155695, 19.27148718987742, 19.444904981120942, 24.545166838553644, 18.763906994173606, 8.744325157134764, 5.634474456310273, 2.292761422934071, 0.20649199794617393, 0.14504698135199087, 0.2610969525431433, 3.81356313343971, 11.419464965020458, 29.757200556416667, 43.92031638853012, 49.59008678313225, 51.245903584264944, 46.23467560737364, 40.10673707531345, 32.81298579708223, 49.04431643024568, 56.70207346639326, 67.56668583039315, 72.61669820354831, 66.43500358827653, 36.926055723621005, 5.1264490715919, 0.2654834187799885, 0.18913635263039222, 0.1317638134764087, 0.15156390746274304, 0.16933233627388555, 0.22187639178047258, 0.2556867170478067, 0.23113868589843475, 0.1869913983729578, 0.28998128649207855, 0.17087336809885117, 0.1538666145455453, 0.2537154349228067, 0.17325006395338044, 0.19114457551510106, 0.17009353655720913, 0.08166902533341801, 0.2560028662123988, 0.239097144334547, 0.18218269511576624, 0.10352585089182663, 0.08032950527605512, 0.2660176578548647, 0.1730121476876159, 0.23399625514303488, 0.17073084510141806, 0.23535802239371886, 0.2298908972091252, 0.18685567823629226, 0.29152204252539143, 0.1935810109059657], [0.07093543637423746, 0.034030142705887556, 0.018873780687910416, 0.062446144124072414, 0.09331274972928148, 0.04295402897461768, 0.02082054991455328, 0.019202892060181307, 0.07956351694320479, 0.06898818642742212, 0.040300399996340275, 0.05228401079112965, 0.0438724649739602, 0.0676456020183621, 0.009204116443382397, 0.04538441993175976, 0.0892663958872999, 0.01565748119666692, 0.0037903942903804205, 0.05584976320425349, 0.055212040972565456, 0.030085661320856986, 0.07531527595053758, 0.10018291898191937, 0.08903248626137934, 0.045410899760862516, 0.024873036290368727, 0.05095672132747789, 1.442591610454744, 26.898198666111117, 56.83382195811118, 58.88628452054916, 54.17637302029518, 41.70824473904025, 38.572360777085834, 34.35526763239215, 44.782880890753965, 47.45255977876725, 86.71401039246591, 75.78656950304585, 57.41264220206969, 66.89236763984927, 32.783548408939, 10.63584404606973, 2.6867843443347565, 0.08925429935897551, 0.24817410646186722, 0.4809533390066316, 0.5227527815488078, 2.7451729918679884, 5.679741549876429, 6.287374054231952, 7.917990117303788, 5.462880567196877, 9.820682367970868, 10.093753856997337, 10.348301952885045, 12.493168692434988, 14.494466877752735, 15.939422941976979, 19.330463947788363, 24.149203569658344, 27.358269153102754, 25.215792117580293, 33.86872506910755, 36.01749750875658, 41.430301666259766, 57.758254005062966, 64.5175450847995, 69.18531463992211, 67.52159426289221, 69.69372441691738, 71.893020906756, 69.87220794923844, 65.14716786722984, 63.436963481287805, 66.94182088298183, 65.06664945233253, 64.82781241017004, 63.370640124044115, 66.82436158580165, 68.02487357970207, 73.44067050564674, 61.39749573123071, 48.361525920129594, 35.907800582147416, 35.246324231547696, 56.243764123609, 52.157811503256525, 41.62164272800569, 36.67251371568249, 50.68521645761306, 58.00923078290878, 59.21721489198747, 62.50419639771985, 68.77712142082953, 67.99744836745724, 60.05728460127308, 57.17749611023934, 59.88504940463651, 63.20061714418473, 68.55512311381679, 70.18225562187934, 66.46733960797711, 65.82676949039583, 63.75113748734998, 60.44805072969007, 53.20613553447109, 49.1120949868233, 34.31697745477, 33.14833079614947, 32.38962673371838, 29.729128153093402, 10.988702427956367, 26.521341262325166, 25.153683347086755, 11.533370594824515, 12.273871917878429, 9.711020742693256, 10.975991987412977, 9.370338378414031, 6.139141801864871, 11.261986705564684, 7.798892740280398, 4.958145560756807, 1.7340624476632767, 0.3077871923244769, 0.24218420287774456, 0.12499189500005976, 0.2533032030107514, 1.7081705144336148, 9.136236617642066, 22.55753124913862, 52.40210456232871, 43.64411877047631, 29.446468430180705, 17.35776866635969, 20.105018308085782, 24.044997961290424, 30.211889551531886, 47.19911975245322, 60.812285946261504, 55.70222993050852, 42.141070442814986, 10.30636691278027, 0.6555376982977313, 0.02512982321692811, 0.034567721924113656, 0.03588971772020863, 0.0029501756287044698, 0.11624766018001303, 0.09165868163108827, 0.061299433075492425, 0.03751960042263231, 0.021053927109366464, 0.059205588373926386, 0.09051460592496781, 0.07621817185633606, 0.014317032257695834, 0.023007886071178704, 0.0212710804771632, 0.0168854454457159, 0.10567861924608869, 0.07114987204512281, 0.0428316502591535, 0.13475501909852028, 0.016621991638995467, 0.07681260245942301, 0.06294266102955708, 0.058021040242766185, 0.05458585602501708, 0.019991502969435627, 0.020280166814524322, 0.10258789880261307, 0.023639688358431863, 0.026567626609316757, 0.05457013973125047, 0.08754082880313359, 0.045023546554148204, 0.13594542780230123, 0.058353836497952866, 0.029686035385595697, 0.0425792089663446, 0.052912639559156475, 0.054045465264108875, 0.0468393856088721, 0.051458091399962866, 0.026129776717073498, 0.01768408061545943, 0.01168731096831541, 0.0510957854379329, 0.04967224851791417, 0.05787585125935655, 0.014990589209651996, 0.04187874413365799, 0.09915917270606565, 0.03856796110349317, 0.02569254927126871, 0.06033455299574041, 0.03323337296023965, 0.06383713762906772, 0.021168832637129292, 0.04649327857600105, 0.0688852012277611, 1.8788208283724326, 29.834696785096202, 66.53805209744361, 71.48651430683752, 63.5531166292006, 58.07239270979359, 48.137515437218454, 46.033665903152965, 44.896912036403535, 35.509432900336485, 60.885430305234856, 70.31345105940296, 62.6895401554723, 72.56628005735337, 43.850078505854455, 13.200727009004163, 2.4492338395887807, 0.1723069943968327, 0.17365956859242532, 1.0305332632795459, 3.5804900142454334, 5.752287257102228, 10.51150098923714, 11.470445971335135, 18.168434327648534, 16.24477945989178, 16.658227674422726, 13.696516559969995, 15.553797079670815, 15.407170057296755, 14.564495894216723, 14.038687463729614, 12.742498074808429, 17.015612471488215, 17.922252647338375, 21.12794891480477, 28.436665996428463, 32.64863260330693, 42.28432324624831, 57.10816037270331, 66.82153747927758, 72.02425556798136, 70.09324919792914, 69.65697965314313, 71.6261036165299, 70.37178454860565, 66.15083571403258, 64.39721461265319, 66.00373898783039, 63.86214840796686, 65.22240284950503, 62.95691244063839, 65.8485072658908, 67.70488662104454, 72.95144896353446, 66.23148748951574, 53.93995215815883, 42.6471346424472, 43.536355572362105, 58.1449055671692, 57.87914145377375, 50.30660575436008, 44.50150182170253, 57.35671312578263, 61.59890943957914, 61.00494492438532, 64.21595796462029, 71.32524213483258, 69.49274216928791, 63.95743062419277, 59.82420167615337, 63.095889860583895, 64.75756276038386, 70.24298175688713, 69.4796806766141, 67.17543725044497, 66.4318343131773, 65.6421592158656, 61.56124684118456, 54.464329904125584, 46.940227631599676, 33.550087405789284, 25.33253754338911, 19.919131302064468, 19.973558110575524, 13.947558056923652, 16.256060196507363, 14.503226510940062, 15.02753169305863, 12.30230223747992, 11.262588789386134, 12.436388461820542, 14.191939369324716, 13.496197192899643, 14.659644749856765, 9.52064948697244, 7.55263114167798, 4.429837599877389, 2.7550078447787993, 0.723955478639372, 0.12807534526913397, 0.25476302951574326, 1.7955263559856725, 9.099781128668017, 24.604808438208796, 47.83182551783901, 41.854219667373165, 31.186243564851825, 24.571154502130327, 26.18542555839785, 32.871027069707075, 37.299987039258404, 54.85189930085213, 65.61508701693627, 65.52944206422376, 49.53754663467408, 13.433181374303757, 0.7672312338986705, 0.050769221308010246, 0.02929222597289951, 0.07165387362962769, 0.12049836031491719, 0.06195013283661777, 0.1306984303218703, 0.04608374329343919, 0.023441390329671484, 0.08043015390754708, 0.030337114360243566, 0.08186905855132688, 0.11004374227336339, 0.06160410624297877, 0.0667767970251941, 0.04395995604535265, 0.04235074622556568, 0.0044729815037440395, 0.05590317102389471, 0.03458371400953301, 0.06960517831987913, 0.021682335627115062, 0.040735595393925905, 0.03352049888382035, 0.03688174795599715, 0.016651200656328472, 0.03533720744833831, 0.056471795955252264, 0.015028696338225518, 0.07158452735072182, 0.04419467772447294, 0.2158762839051985, 0.1826497023144076, 0.2141624226445152, 0.15643590490423864, 0.15080563363529023, 0.14126854377888864, 0.1342215920768438, 0.13717121444642544, 0.1690765548377268, 0.1785163974930202, 0.16423687098487733, 0.10525019223531408, 0.1843285533569513, 0.16592088546003067, 0.15614909690714654, 0.15519985268192907, 0.2530152918470483, 0.15512171171365247, 0.1930851681578544, 0.15988739147301645, 0.18352941639961737, 0.1567452512080631, 0.22744722994825534, 0.2342795544574338, 0.1813420361929363, 0.18588535127139863, 0.19255817627474187, 0.2545920999780778, 2.9776364276486063, 40.491937360455914, 79.19272438172372, 82.73915106250395, 74.12469263999694, 62.609272772266024, 53.99948589263424, 49.2578737966476, 60.52964387401458, 63.5626950571614, 98.65016721910047, 82.04800590392082, 68.43760105871385, 79.42551705145067, 41.702824023462114, 14.574974506132065, 3.5587953848223535, 0.4664255540457464, 0.33925578599014594, 0.9392364815838876, 3.623604707179531, 11.714013391925443, 15.827361806746453, 17.362899126545077, 23.436742290373772, 17.47317264156957, 26.39504486514676, 19.71278521322435, 22.58938873967817, 22.28100807436051, 23.576645389679943, 26.002297939792758, 30.112022084574548, 36.77361280687394, 39.774704517856726, 37.228313569099676, 38.4876532708445, 40.88784963853898, 45.11728648216494, 62.51167635763846, 70.79190177302208, 74.7777045157648, 74.39332792835852, 73.63008960600823, 75.57389074756254, 73.23156110702023, 67.76336131557342, 66.48106005883986, 64.400670220775, 65.110023021698, 63.50880561336395, 63.361744188493304, 66.98365688323975, 70.2587418402395, 75.26774191087293, 69.22580134484076, 57.80929188574515, 49.107650941418065, 50.0504671373675, 64.4370972725653, 62.28792475115869, 55.13558472356489, 52.27115623412594, 60.4551580644423, 63.40981675732521, 60.81869902149324, 63.576968562218454, 73.46678564625402, 72.76836841337143, 65.97399173244354, 61.70450356698806, 66.45677274273288, 69.96232048157724, 73.66283355220672, 72.92709104476437, 69.951275087172, 69.27783550754671, 68.78640174865723, 65.52557068486368, 59.67694413277411, 56.37180597551408, 39.836481848070704, 37.626936204971805, 37.537831721767304, 37.7947901141259, 17.12061235981603, 35.72715974623157, 37.00620543572211, 27.236410917774325, 21.72687718945165, 18.259719648668845, 24.056215939983247, 20.745104012950776, 14.645291816803718, 22.348372820884954, 17.579625768046228, 10.437134811955115, 5.28121599266606, 1.892471044294296, 0.6979419519343685, 0.35444789175545016, 0.5131747519537326, 2.2361586795699213, 11.544323813530708, 29.299036341328776, 65.54653967580488, 59.39964432870189, 42.960096636126124, 28.376704723604266, 32.49719773569415, 37.51147339420934, 43.98672211554743, 64.90971934410834, 76.20024619563934, 73.63642031146635, 61.08022697510258, 18.04771554085516, 1.5047014841148931, 0.10730737579926368, 0.1462556995571621, 0.1590662371487387, 0.23141718950242768, 0.22293711712043132, 0.3213005236560299, 0.2413886205683793, 0.16624751470742688, 0.22747151493545503, 0.12118132769941323, 0.1607081014662981, 0.23316656659928062, 0.12466268403635872, 0.2333978638653794, 0.14428634797373127, 0.14848561296539922, 0.22793357320610555, 0.15370757469246465, 0.11512154157483771, 0.3722276280243551, 0.12326887132780207, 0.20575687529579287, 0.24880294207363363, 0.2253906669155244, 0.15234251326370626, 0.13437841027494402, 0.21200711087834453, 0.18819141381930923, 0.1923345398878859, 0.1027499800247531], [0.06258818831655287, 0.022462123118701483, 0.016939180767944744, 0.04746740533699913, 0.027388597072492686, 0.025898395181303064, 0.05520726441435757, 0.013562895305034135, 0.02642944349997467, 0.0452069211901436, 0.030957687713746584, 0.05828460130179602, 0.024230393858987, 0.02566771270076354, 0.034748016886653445, 0.051065387069097454, 0.05166881537485508, 0.06970674625688023, 0.05265518422088316, 0.038748221592076366, 0.04728861190679093, 0.03649239142936084, 0.05923817009334603, 0.02524112621622701, 0.04669400893392102, 0.038003059359447616, 0.008851444037000259, 0.15284431617586844, 5.369525705614398, 41.02693296247914, 63.705861568450935, 59.20512614711639, 44.30524210776053, 31.092489111808042, 29.07757539902964, 33.37370626388058, 58.78937059833158, 82.70630513468097, 81.73796607602029, 76.42161692342451, 72.42689471090995, 29.782958761338268, 14.541001877477093, 5.38357416468282, 0.6063862938073374, 0.010891522772820487, 0.21258915383969584, 0.6414861135905789, 4.251434966441124, 4.753513547681994, 7.358932245162226, 9.245932563658684, 10.707183134171272, 14.375786742856427, 15.648929265237625, 15.819755350389789, 12.371089823784368, 12.809788296299597, 18.151485766133955, 12.704200052445936, 16.496988842564246, 30.044310208289858, 29.09110953730922, 43.09375139974779, 47.91491700756935, 50.28075341255435, 60.44102576471145, 66.96437451147264, 67.0918829210343, 64.4006270747031, 66.45809065911078, 66.93371726620582, 68.99755862451369, 66.3779801707114, 61.83222378453901, 63.41186815692533, 65.96140876893075, 65.38183542989916, 63.50587560284523, 63.241492163750436, 66.1877844410558, 64.75410715226205, 70.20816679923766, 64.34107372837683, 60.25296772679975, 42.6035806440538, 33.48231277158184, 52.06319216758975, 49.640493162216686, 39.39088098464474, 42.44879214994369, 58.34771956166914, 59.14125819360057, 60.112762604990316, 63.14883009079964, 65.60652056047994, 65.2132676493737, 56.835841978749926, 52.988122355553415, 60.55586884098669, 64.62614767013058, 66.26171327406361, 67.62384260854414, 63.203735428471724, 62.261927281656575, 64.85515133027108, 66.74760080152943, 67.72297659227925, 63.10151846178117, 56.222198932401604, 43.74056593064339, 40.663023302632, 31.543291038082494, 23.777066738374774, 33.006329228801114, 17.530980533169163, 18.942253243538644, 8.214694867211005, 12.795668744271802, 9.721268915360975, 11.944335949036384, 17.43464319936691, 12.645082089208788, 8.091453996396835, 6.532761454582215, 5.696285616966986, 1.675503912471956, 0.21790162119413578, 0.08419611956924201, 0.036630835008597186, 0.09887363641492783, 1.0185054990072404, 8.606351863953376, 26.000236734267204, 42.32626122813071, 39.15730776325349, 28.85103302617227, 15.144857629652947, 21.78361035162403, 39.714755012143044, 33.78393127072242, 42.96372875090569, 53.81776640492102, 55.91308870623189, 30.449865633441558, 4.332189704141309, 0.184234646299193, 0.052982253968835845, 0.010783820386765706, 0.02862610103141877, 0.005132649281632997, 0.056984193863407265, 0.02522973257357315, 0.09713331447733987, 0.02336077106695983, 0.03618133674946524, 0.033189568052729296, 0.02951371922878729, 0.037860436770584316, 0.03451444433941957, 0.07753977311715003, 0.07386482636173887, 0.05604420781075474, 0.04165810315058597, 0.07189197375649406, 0.037890969204806516, 0.05349853594276694, 0.020608774483984998, 0.031697550533159126, 0.07554370038692029, 0.04555758644616412, 0.07878854239900267, 0.03897227932729068, 0.027406042809748364, 0.08939550468517889, 0.027587799085003716, 0.04398959981758268, 0.026714043248625054, 0.029508494509143696, 0.07568802369097549, 0.06662917188218524, 0.17952505949764483, 0.06331951500126912, 0.0530183635231468, 0.03824072664663677, 0.050460771327057195, 0.052499610915659904, 0.07393115425422307, 0.05032757545010217, 0.06119572775318258, 0.03139348640557259, 0.0977899897242746, 0.08055046801605532, 0.0683158370215566, 0.06456890864478004, 0.0950484138522898, 0.03224821836357156, 0.011995980241936783, 0.0763338128285062, 0.04068162066922073, 0.06091863758140995, 0.02286220296105791, 0.007442676334551746, 0.16520678426229185, 7.532829546159314, 50.706691434306485, 74.36232551451653, 70.28996390681114, 56.794766918305434, 41.59370760763846, 39.312194316617905, 38.15652678089757, 60.8287363667642, 73.29021623057704, 79.77711831369709, 84.87121028284874, 87.15712055083245, 47.0452255587424, 16.963333160646503, 4.743990523199882, 0.47423661716522714, 0.02883334888235456, 0.8392885447509828, 4.0454597867304285, 7.253176319983698, 11.126959112382705, 9.313507156987345, 11.443232567079606, 13.99591205581542, 15.298359586346535, 15.605122273968114, 20.394622587388564, 12.922005345744472, 15.974090810744995, 18.294487537876254, 12.382605902610287, 15.286792516708376, 27.910684001061227, 34.0289342787958, 35.80639554608253, 48.34594626580515, 51.27451727467199, 62.153332541065836, 67.19569237001481, 68.8429937055034, 65.78536887322703, 67.66364682105281, 67.61048301573723, 71.25127407812303, 66.95130517405849, 64.64555555774321, 64.6868698827682, 66.38073367457237, 64.15813046116983, 63.696004652207904, 64.3688597986775, 65.69216159082228, 64.60327240728563, 68.53609961848106, 66.21953210523053, 66.08388085519114, 47.93594091169296, 41.40279800661149, 55.17472213314426, 56.54650442061886, 47.9008121644297, 47.803431480161606, 63.04463624954224, 62.59733307746149, 61.64160836127497, 63.84268952954201, 68.27334788537794, 66.26977766713789, 58.59532310116676, 56.02182465214884, 63.007856184436434, 66.72071687636837, 67.69934038962087, 69.163255230073, 64.2069169013731, 63.341457689962084, 67.81378730650871, 68.94865451320526, 66.69215417677357, 62.01766952391594, 52.94969097260506, 42.971381295111875, 35.820445476039765, 24.559822774702504, 22.956773619497977, 21.950911206583825, 12.557681875844157, 11.038942106308477, 6.710927274919326, 11.69333367578445, 14.281200747336111, 10.898552633100941, 15.747036568580137, 13.13496062832494, 9.91008299012338, 11.265808074705063, 8.456038794209881, 4.921536118753495, 1.4594879554164026, 0.1312317807347544, 0.2142557168319341, 0.14078503504635828, 1.2010323208185936, 9.359088040167286, 29.57286680898359, 44.377594147959066, 40.08565825800742, 24.769955911943992, 17.359665132338, 22.370420463623542, 42.2371724344069, 45.567249021222516, 51.86764240264893, 62.8504357799407, 65.52359381029683, 35.919799112504535, 6.204076640067562, 0.16109575727774253, 0.034125428721909566, 0.02171892973203813, 0.10007378975710562, 0.04253327433440474, 0.008925830216837988, 0.046682475480220975, 0.0705008959818271, 0.03756610962051538, 0.0536811176777607, 0.024821511131801435, 0.042881901796546676, 0.04111428031577699, 0.020143130921848842, 0.0107938417744252, 0.05196673930772851, 0.020785899757738077, 0.019641967693103418, 0.039644276332711025, 0.06835025735199451, 0.00791476221732615, 0.04598457321164109, 0.05606624049945705, 0.02842287322686565, 0.09282911076180397, 0.025927772737979412, 0.0629056360001766, 0.03058003126493385, 0.08453946485514603, 0.001950114876249685, 0.13277779213122784, 0.09812865421296128, 0.08586106611596, 0.20977543546788155, 0.11855650362708878, 0.2105739442331176, 0.15393493426663263, 0.10738985282519173, 0.0865482852884358, 0.14786339635329862, 0.22315218864429384, 0.3098413191976086, 0.16429680970407304, 0.14703091924950001, 0.10407305983526093, 0.2614050731062889, 0.16545274445126135, 0.15823558333419985, 0.11520488428012018, 0.22583939525629246, 0.13350963592529297, 0.1294241962774146, 0.29373162396011815, 0.21509657493762432, 0.14148810457798744, 0.12381282439755818, 0.09834033196731921, 0.23263706194777645, 12.152867778655022, 63.171340573218565, 85.52185304703252, 81.22794812725436, 67.6583908450219, 49.17064420638546, 44.500913466176684, 46.58684561329503, 71.69578060027092, 95.97526765638783, 89.16345211767381, 86.82277771734422, 82.66223338342483, 39.53186665811847, 18.507385946089222, 6.9568113453926586, 0.8097374691597877, 0.2796449217825167, 0.7879396323715487, 3.303963162245289, 14.009569748755425, 12.729651331901552, 21.013290189927627, 23.79234633138103, 21.676319799115582, 25.086002849763442, 21.63855129672635, 24.24415042323451, 26.754204534715225, 26.815407237698956, 32.418801323060066, 25.40109076807576, 24.97652557588393, 47.30145831261912, 40.921236853445734, 46.82123076531195, 52.00000278411373, 53.32847033777545, 65.9143481716033, 70.6663937722483, 71.0301386925482, 67.29062941766554, 71.57415574596774, 70.27653371134113, 74.33713605326992, 68.55084773032897, 63.64975206313595, 63.97716406852969, 67.2746261473625, 63.867404383997766, 63.13760426736648, 64.92254157220164, 68.72132178275817, 65.69558189761254, 71.31530284881592, 68.95795053051364, 68.81417997421758, 52.695560609140706, 47.7282984795109, 63.2009623127599, 60.975374175656235, 54.30920016381049, 54.067880261328916, 64.99398754489037, 65.68845887337962, 60.02871013456776, 64.05159496491956, 70.02481168316257, 69.55079324783819, 61.010267580709154, 57.772586345672615, 68.23266506195068, 69.68856257777061, 69.88969387546663, 70.285704212804, 65.56259785929035, 65.1831046227486, 67.01262750933248, 69.72078877110636, 70.0865105659731, 68.76831177742251, 60.5536997702814, 49.0670818667258, 46.644496610087735, 36.13372910407282, 30.711564210153398, 43.45534293882309, 24.796582921858757, 32.05216953831334, 18.15283113910306, 23.38100737141025, 21.39640965769368, 18.287095831286525, 29.561527236815426, 24.058610546973444, 21.29166472342707, 17.090368924602387, 12.600421001834254, 4.756932383583439, 1.0025505228869378, 0.3366259900071929, 0.2589576366928316, 0.29849402486316623, 1.7188826299482778, 10.605169150137133, 34.7917176062061, 57.23422927241172, 54.68983088770221, 41.88371589106899, 25.117968205482732, 31.383317170604585, 51.615139822806086, 50.88067208566974, 59.58600005795879, 71.28210390767744, 76.44826550637522, 44.74557915041524, 8.266358856231935, 0.37321867000672126, 0.15447904055397357, 0.11998949407209313, 0.2148539702137632, 0.096551853742811, 0.11253575734313458, 0.17074693294782795, 0.26155697301991526, 0.07137040577588544, 0.2179858295787727, 0.13145480425127093, 0.17155929258273495, 0.16807541581651858, 0.08538504206244985, 0.19970809019381003, 0.21035341816323422, 0.2759674545978346, 0.15832915331327146, 0.134455080354406, 0.15127095544049818, 0.11238821646979741, 0.1028728988322039, 0.22502564134136324, 0.29893277873916013, 0.19267279834997272, 0.1028723089445022, 0.14165777773145707, 0.09970207623536549, 0.1877505302188858, 0.08512685511020884], [0.05828351345694354, 0.07387307712868338, 0.036770006371361595, 0.02122426675933023, 0.043743030588713386, 0.03221908787025079, 0.05497292577919941, 0.05612149459099578, 0.03849246313855533, 0.007317201187458611, 0.03442394637292431, 0.058692861047963944, 0.01295392914119387, 0.02186516825590403, 0.039158063309807936, 0.02695976978077764, 0.0469471626884995, 0.010134751435309168, 0.05916796962640459, 0.02958763522216149, 0.09286842639407805, 0.01718600089060924, 0.026737652163231568, 0.06331060922914936, 0.031610582316775, 0.143867144661565, 0.04047180450851879, 0.43618199625803583, 16.834771594693585, 46.916395310432684, 53.54601283227244, 53.94507477360388, 42.36252354037377, 32.14453743350121, 19.23492285513109, 44.26477501469274, 56.51393305870795, 66.60783890754946, 77.75147299612723, 56.88361252507856, 25.082482522533788, 21.92214454374006, 8.366538151617974, 0.29172018350612733, 0.126047050880809, 0.06178001152171243, 0.27215472692924164, 3.45862050210276, 3.533148967450665, 6.538277287637034, 6.554056982840262, 7.984284547067459, 17.672740874751923, 18.386547527005597, 17.04302199425236, 18.27060618708211, 12.491498743334125, 23.636692954647927, 25.776326271795458, 30.185117413920743, 34.500395328767844, 43.31659301634758, 53.81435786524127, 49.693609899090184, 62.05655590180428, 60.7981889478622, 66.36860570599957, 64.83366458646714, 64.74577211564588, 61.648566645960656, 63.20289211888468, 64.43387700665382, 69.08961665245795, 66.31086057232272, 65.33328433190623, 65.11766379879367, 67.01578893969136, 63.91611237679759, 62.56475779318041, 60.090903236020004, 62.776142166506865, 65.09839319413709, 69.3584402145878, 65.85946636815225, 62.5608903361905, 51.98566652113392, 32.88545158601577, 48.022433096362704, 45.037325043832105, 40.339270868609034, 47.98639435921946, 62.132387084345666, 58.96590471267701, 59.41605944787303, 63.59483495835335, 66.0613742951424, 62.98948380254931, 51.64954293158747, 53.21709463673254, 60.250500555961366, 64.84683590550577, 68.05905311338364, 63.373742718850416, 60.76449186571183, 62.90059504970428, 63.64639843663862, 63.56254600709485, 62.82714474585749, 65.38868388822003, 65.16565007548179, 60.27401124277423, 51.69139069895591, 49.27577941648422, 49.72494179202665, 37.60446102388444, 27.32831793446695, 19.29076760045944, 10.366271311236966, 9.157255618802964, 9.879581659070908, 12.867625605675483, 11.500773737507483, 10.851413588370047, 5.77601759664474, 4.713771602799816, 5.159581332437454, 6.818041320770019, 1.9716921352571057, 0.2762831747531891, 0.131249247539428, 0.020725562672821746, 0.24648051588766037, 2.0183202912730556, 10.590655399907021, 33.74420158324703, 55.57421553519465, 43.517171259849306, 55.25413443965297, 87.30003603043096, 70.1408746165614, 41.13464124741093, 41.16173305819112, 46.29986932200771, 57.48098165758195, 50.98061407766035, 15.83271093906895, 1.2204069908588164, 0.06650522651691591, 0.023519470010914152, 0.03322749706586042, 0.013293365463464251, 0.0326534214189216, 0.06255452258272037, 0.012608371776408486, 0.08115778421802868, 0.08868945507152427, 0.059556583047754345, 0.04393838683984453, 0.1016967470246938, 0.006373794552224178, 0.03255029449299459, 0.03053191136718998, 0.02974447065724, 0.015979150024753426, 0.030405855429689252, 0.04304993552185836, 0.04810616561782457, 0.03327074272918605, 0.0084259616766846, 0.07266984411304997, 0.022784686354439587, 0.023021053207377275, 0.08863739173619017, 0.05485088031198229, 0.03510208740349739, 0.030066160552744425, 0.05965745384474436, 0.05196127710082839, 0.034410719864911614, 0.012349508751574303, 0.035926715936511755, 0.05535820671807855, 0.037100933372013034, 0.013212206108765978, 0.09843195608306317, 0.023105133272286867, 0.06471743011066029, 0.06981624320389763, 0.0314105452684265, 0.05488039384926519, 0.019223319794682246, 0.019479118467819308, 0.049002603402421366, 0.06973758129583252, 0.06634100024858791, 0.09811824307807031, 0.04858424661741142, 0.010780328941050797, 0.043753093153598814, 0.09569407275487339, 0.03431458732173328, 0.07392599082161343, 0.020301322332553325, 0.3688412129638657, 19.375810469350508, 55.28908668025848, 65.24197939903506, 66.36112966845113, 51.951486987452355, 39.01837741175006, 23.609867865039458, 39.86391490505588, 58.54289277907341, 77.84491954311248, 86.55651154056673, 73.62204874715498, 39.28865225084367, 20.432340098965554, 7.280619673190579, 0.48390783369541174, 0.20503779452654625, 0.21997706063332098, 1.4247710570212335, 7.42342826820189, 9.775952639118318, 13.990853178885676, 9.267860574107017, 12.230653282134766, 21.633909171627415, 16.044074719952, 17.809094229052146, 19.876530439622943, 14.68818195404545, 11.66234597083061, 21.235641510255878, 23.49130638184086, 29.05503353764934, 38.624830322880904, 46.472453609589614, 52.08921709368306, 60.465348382149976, 61.136842466169796, 68.17823040869929, 67.69991305566603, 66.2843139709965, 63.568570767679525, 64.56113438452444, 64.18822288513184, 68.71586184347831, 66.00042850740495, 66.54327669451314, 65.7636389424724, 63.95611270781487, 64.22813300163516, 63.842979784934755, 62.23512180389897, 63.196082884265536, 64.78108129193707, 69.23906680076354, 66.36713089481478, 67.79716430171844, 57.8988003730774, 39.11295360134494, 54.21414936742475, 50.93626776049214, 47.14364959347633, 54.12377795865459, 65.02467616911858, 61.72919488722279, 59.82591575191867, 65.38148241658365, 69.08182682529574, 65.04173063462781, 55.37860301233108, 56.86350645557527, 64.35502952144992, 67.56165735183224, 68.41343925845239, 62.72138195653116, 63.40582770685997, 65.10525341956847, 64.92789952985703, 65.2016927349952, 65.06292320066883, 69.04691773076212, 66.9873752901631, 59.27433636880691, 48.09154133642874, 44.40694524395851, 36.952567023615686, 27.527548843814483, 22.28532072036497, 14.588493935523497, 9.206783386968798, 8.44182804707558, 13.279994187816499, 13.914088472243279, 16.04494744731534, 15.899937422044816, 13.591402922907184, 9.340752920796795, 8.236161508867818, 10.229489437995419, 3.1208397111585064, 0.6539700372565178, 0.21881633017572666, 0.05193408864039568, 0.32372531451044545, 2.1384943589087455, 11.507252512439607, 32.94839189898583, 48.56844271382978, 40.836392064248365, 32.22963717675979, 71.79453019172915, 71.20673948718657, 49.62257185289937, 49.15502925072947, 53.590998495778734, 67.7520570447368, 59.93693843964608, 20.043501815488263, 1.3983606354844187, 0.014448097452611454, 0.03288956802158106, 0.02310243855801321, 0.03636163554244465, 0.046755598572593544, 0.022955276898198554, 0.05036358158254335, 0.009949788124480797, 0.012280296538055185, 0.015802412583012015, 0.04400474154540608, 0.03626280253933322, 0.018701935675175443, 0.014302218990069965, 0.016625389238939654, 0.02930946486641563, 0.02866168006984217, 0.061117295671494744, 0.01062946420373215, 0.07265026290570537, 0.05144940013246191, 0.028127406521009344, 0.049651284521866235, 0.018950109858246102, 0.055623139074492844, 0.0938178851239143, 0.017630178669107058, 0.0634807113918566, 0.07110256611579849, 0.16583627870967313, 0.18933168972932524, 0.1181121190048514, 0.17280447657310194, 0.17421361870102345, 0.1371159028982924, 0.09872148369228649, 0.14468981583993282, 0.20897069074694188, 0.18568276698070188, 0.10730248049742754, 0.1354226800462892, 0.2152221520701724, 0.17312045719835067, 0.15067719133390536, 0.11090906922735515, 0.15832660990136285, 0.09967260483291843, 0.19741672121228712, 0.21060061941464103, 0.16583721333694074, 0.08809682477505938, 0.14672005609158548, 0.16469830106342995, 0.1404465467578942, 0.23790388578368774, 0.20958713105609342, 0.7445200364435873, 27.866210206862423, 68.87401965356642, 79.56062701440628, 75.27918738703575, 61.381947455867646, 47.526876926422126, 33.04583141880651, 58.48233530598303, 68.54377961927845, 78.01642910126718, 87.15217836441533, 67.13131843074676, 36.38762020295666, 29.145061739029426, 10.93161625246848, 0.513433138088834, 0.34104107728888916, 0.11773984623892654, 2.4374147576670495, 11.634208848399501, 14.808748748994644, 22.2359400410806, 16.03783815137802, 19.41575784837046, 31.236528350460915, 27.581579492938136, 25.362267148110178, 32.11470388597058, 27.89183505119816, 41.050310288706136, 37.27396211316509, 38.61599714525285, 38.253413246523955, 50.82324466397686, 60.782656361979825, 53.93397838838639, 63.97393988024805, 61.84670125284503, 70.66665264867967, 70.86327322067754, 69.07376243222144, 67.46683013054633, 69.96774119715538, 67.26725993617889, 73.14668886123165, 66.93528621427475, 66.19821010097381, 65.36507514215285, 66.16517589938256, 65.36405140353789, 63.33287162165489, 61.029483272183334, 65.52331924438477, 65.82716172741306, 71.11777228693809, 69.83082694392051, 68.71493616411763, 62.51317470304428, 47.019314381384085, 59.4672542233621, 53.75944468282885, 53.220777742324344, 60.476809547793486, 68.38108754927113, 63.64696718031361, 58.76134134108021, 66.32432214675411, 71.77475360132033, 68.27338710907968, 57.19590771582819, 60.551848411560066, 65.90641713911488, 70.32998777204945, 70.62946073470577, 64.1018013031252, 64.02658985507104, 66.8038397450601, 68.04183390832716, 68.502273098115, 66.9694108347739, 70.96186591732886, 69.15556738453527, 64.50434630916965, 54.30770181840467, 54.01345345281786, 55.883819980006066, 46.08626880953389, 35.83835501824656, 26.9916844367981, 18.782818701959428, 22.915196495671427, 21.204850904403195, 24.433785253955474, 22.00595774958211, 20.955556823361306, 18.645341588604836, 16.66684904406148, 14.448230958754017, 15.746791420444367, 5.0096364751938856, 0.5997008589967605, 0.6150381231019574, 0.2645706096964498, 0.5400111490199643, 2.8215756147138538, 13.561487986195473, 42.34326862519787, 70.07297054413827, 58.864276101512296, 66.1391156719577, 94.64786698741298, 76.4401226658975, 52.48225819679999, 55.458191825497536, 63.11129300825058, 74.1546360138924, 71.54692665223153, 25.461630590500373, 2.2290653182614237, 0.19272867680316974, 0.12964751090734236, 0.11093283327476633, 0.1173831633622608, 0.07518798278103914, 0.21550528284522796, 0.14786692035775031, 0.1775526129189999, 0.1515435908109911, 0.18850727187049007, 0.15315893316461196, 0.27825729140350897, 0.07597130002273668, 0.10379375949982675, 0.1778267957870999, 0.14436432040266453, 0.21740878151068765, 0.1994082893455221, 0.2448373338988712, 0.1627091384462772, 0.1278828273737623, 0.12673977056458113, 0.2652027241645321, 0.07607914988071689, 0.15540113462315452, 0.20389552678792708, 0.12052089096077027, 0.08376447498918542, 0.17740221453770516], [0.0347968511613867, 0.013951392855585344, 0.015248462065844046, 0.03472178603612608, 0.033400161792674375, 0.05274878867391137, 0.030045525974503932, 0.03780884074888403, 0.03445029979751956, 0.08171143596090617, 0.011766383691029924, 0.021947003683195482, 0.08472160992002295, 0.08637243746629647, 0.07919249290059652, 0.0032616789488407274, 0.09783080688888028, 0.061512620023061196, 0.07083192257390869, 0.0588603163768928, 0.012482649087154818, 0.14309777788096859, 0.00568518684538562, 0.06309618121914326, 0.008952401976491655, 0.07057748179161741, 0.06912560727927955, 3.332487373582779, 34.17946307889877, 51.37163516013853, 58.05882523136755, 52.136222777828095, 41.950631526208696, 35.27853473540276, 39.48892062710178, 49.395945149083296, 40.02578719969719, 38.72243065987864, 25.89252256578015, 26.243029486748483, 33.72049085555538, 15.257563994776818, 1.1700898456958033, 0.10761405611711164, 0.046097410302008354, 0.3064899296770173, 1.4136521181752606, 5.7616494644072755, 6.3100973252327215, 10.726035025811965, 8.449751234823658, 9.491711220433636, 14.109997134054861, 11.602880877833213, 20.70522527540884, 23.57757106904061, 14.562663166753708, 22.87212690999431, 45.11449767697243, 36.206190970636186, 46.06355436386601, 54.375562744755904, 61.01617074781849, 61.0465181258417, 64.61721251087805, 66.33454384342318, 64.5524698688138, 63.605794060614805, 60.76098526677778, 58.28611089337257, 61.316467408211004, 64.75303242283483, 67.20993841848066, 65.33935616093298, 62.04853073243172, 64.68464197651033, 65.60494769004085, 63.1072098209012, 63.198365703705825, 63.83029876216766, 62.58824886814241, 67.04943503102949, 68.3554038693828, 64.99436017005675, 65.45949051457067, 55.363415595023866, 35.305085259099165, 43.32146852247177, 45.101593079105506, 43.16863729107765, 52.93120484198294, 63.07061410719349, 62.34622293902982, 62.00267822511735, 64.98498178297474, 66.88230283798711, 61.757981161917414, 50.35280735261979, 53.74490445660007, 59.22290232873733, 62.445607954455966, 62.6329089749244, 62.26949745608915, 58.413886024105935, 59.988945145760816, 62.543984920747825, 65.44706836823495, 63.04464017191241, 64.07706683681857, 62.071574657194084, 66.871124082996, 65.06242505965695, 53.38449747331681, 49.94201360210296, 41.831077683356504, 31.269691990267848, 23.672053121751357, 15.678535315298266, 15.218764889624813, 20.041534746846846, 8.848255218998078, 12.971780223231162, 11.35724146519938, 5.899599713663902, 9.321192060747455, 7.386615843542161, 6.755620721847781, 3.7132923977990306, 0.6913984578944022, 0.43703881963606805, 0.04731694183823082, 0.055624675080781026, 0.3174316264208286, 3.0182452163388653, 16.22973422850332, 41.018382195503484, 53.04542426140078, 76.4352903058452, 80.65376020246937, 51.75630592530774, 38.22453283494519, 37.29938299425187, 45.327494144439704, 53.13173993941277, 58.28260037206835, 31.353063929465513, 3.1509882740436064, 0.3058101032530108, 0.03894689117348002, 0.06233996050732751, 0.013740062713623049, 0.04737745129293011, 0.034448189225288174, 0.04596790313840874, 0.033667943996166995, 0.050831297412514694, 0.046621866434091525, 0.04473937006907598, 0.021447728861183412, 0.03140825849597252, 0.029123475955378626, 0.008486802464411145, 0.03424220733464726, 0.07935832029268627, 0.04916756511515668, 0.07740505655566532, 0.014942810221034435, 0.018626079564133, 0.04554756984655415, 0.03072138214784284, 0.03246476077624867, 0.07252439465974608, 0.029780319741656704, 0.029854021230412107, 0.05630320681619549, 0.019455482740135446, 0.003939052933879618, 0.09608594204990134, 0.04113076652790751, 0.1158995345054615, 0.04070362654484568, 0.02202028190837272, 0.01632897449927705, 0.041877173653413216, 0.015088432044121287, 0.04995753966091622, 0.013147016814459237, 0.023574896472235842, 0.09816001785258133, 0.07559316668419108, 0.04430774847165712, 0.049075676699078856, 0.06186186418598218, 0.03860528107672449, 0.0382022000849247, 0.030393266689873515, 0.03781680806329654, 0.03614136994245552, 0.05462656593731335, 0.039632505391754454, 0.041693841152253656, 0.07984053433662461, 0.05053575218264615, 3.8590194813666807, 40.80502879235053, 60.31660033810524, 68.2808082334457, 60.120175884615996, 52.581392180535104, 40.976824683527795, 43.02298399709886, 55.26532496175459, 50.18612230977705, 53.64562926753875, 41.10178747484761, 32.020037481861735, 28.299408535803522, 13.86952740530814, 1.4849700009630573, 0.09395355929530437, 0.35292463317032785, 1.693035436253394, 6.169958883716214, 9.3280856263253, 14.49629568284558, 19.121460453156505, 17.18815165181314, 10.829246313341203, 13.897267387759301, 16.17284809389422, 18.596557109586655, 15.1291093134111, 14.048137434067266, 25.10346131940042, 28.447819256013442, 34.618933277745406, 43.19312464806342, 53.20449598373906, 59.40269985506612, 61.559744573408565, 65.74813773555141, 70.14886840697258, 67.42500197502875, 65.85591270077613, 63.854491941390506, 62.57050014311268, 62.291431350092736, 66.13527174918883, 68.66982106239566, 65.53364292267831, 63.715718484693966, 64.33057354342553, 64.88629887180944, 63.47596360791115, 62.822124112036924, 66.74766355945219, 63.73803677097444, 67.22468653032857, 67.51078421069731, 65.3173085181944, 67.19858707920199, 61.325630064933534, 40.03789163404896, 49.433227277571156, 52.59883496069139, 49.32879809410342, 58.17166005411456, 65.6902906202501, 63.68173506952102, 63.13053615631596, 67.06302212130639, 68.61633562272596, 63.60754736008183, 52.12964888541929, 57.26365881581461, 64.26130840855261, 64.88638516395324, 64.47111598906979, 62.20959109644737, 61.51813214825046, 61.517124099116174, 63.89488450942501, 67.15590384698683, 63.75456563888058, 63.112438340340894, 65.08428050625709, 68.36303680173813, 62.80257109672793, 53.86013976989254, 48.7262043645305, 40.040919703821984, 28.618750264567716, 23.454192915270408, 14.234601028503912, 11.296176045171677, 8.855390990934065, 15.364003392957873, 15.533742000979764, 13.672634228583306, 13.159095952587744, 11.66938074173466, 11.029183249319754, 9.359582258808999, 4.9643551630358544, 3.1819499932950546, 0.8889896939358405, 0.08444264666327546, 0.16143156425847163, 0.2851457088705032, 3.1411450860961794, 16.586869955062866, 43.67970643504974, 46.46860576445057, 75.46950863253686, 94.4094104151572, 63.83295812914449, 45.50689551138109, 43.68011828391783, 52.75383918516098, 60.07014213069793, 66.00587275720412, 39.628623685529156, 5.609714494597528, 0.39180739512366636, 0.034716944360444625, 0.028765762690454725, 0.042921883925314874, 0.042754528187816186, 0.014336013043629787, 0.024618494001427488, 0.043599224394007076, 0.04516434968419133, 0.03976632563036777, 0.028264771831492265, 0.030721305539050413, 0.0013890766093672645, 0.06788072972408227, 0.017659077420830727, 0.046455027805941726, 0.01763971646376435, 0.049884791951626546, 0.047664171189910946, 0.043529966215212504, 0.054362958913008054, 0.03640684239085644, 0.050834530303555156, 0.01033170402215253, 0.005865465528557018, 0.05815068913263179, 0.03703364020874424, 0.04251563515994818, 0.02807943984085033, 0.05749939565336513, 0.1606536172931233, 0.16374976163910282, 0.207025884620605, 0.1248598367636723, 0.14980703802599063, 0.12826660678030985, 0.10863050923592622, 0.17958925766569955, 0.20294979124540286, 0.1759273267441219, 0.18753538208623088, 0.21379194252433317, 0.127882880999917, 0.08608981997015015, 0.1267337184699793, 0.1772252022619209, 0.16067247837781906, 0.12217195599430031, 0.15472725304144044, 0.15343627231495996, 0.19219414661488227, 0.17114856220301122, 0.23992787475787827, 0.08649384708053644, 0.18353540720718522, 0.2211088329673775, 6.567394512314951, 49.85223447122882, 74.85669320629489, 79.97376241991597, 71.8963784556235, 60.49143998853622, 52.73630226812055, 54.28466573838265, 63.974994997824396, 54.41837149281656, 49.42911663363057, 39.14219879334973, 38.04511577852311, 45.29660547933271, 18.42604579464082, 1.7963251711860782, 0.30868186044596857, 0.2230524746400695, 1.1205186863099377, 5.23461970590776, 18.578737781893825, 21.488852077914824, 25.506888858733642, 26.642917087001187, 18.74073559238065, 24.397619039781635, 21.262427376162623, 32.75077504496421, 41.162917613983154, 23.46027651140767, 31.009927142050962, 51.43973927344046, 39.22534127389231, 49.85550180558236, 57.40111435613325, 61.53754003586308, 61.516849533204116, 65.63877813277706, 70.02168163176506, 69.51309142574188, 70.11958399126607, 65.70809818083241, 64.41633224487305, 65.17668762514668, 69.07546474087623, 71.79653060051703, 66.34150212810886, 61.559050313888065, 62.619345418868534, 65.71525650639688, 65.20417951768445, 64.6232255043522, 68.20356892001244, 65.86986849384924, 70.68775500020674, 71.12947663953229, 68.15429610590782, 68.46517532102524, 64.0419969251079, 45.53740762895154, 53.378021640162316, 56.0212206071423, 55.97246946827058, 63.361120531635905, 67.0830968118483, 65.70638802743727, 62.51382581649288, 67.1189002067812, 73.03846282343711, 67.38092237903227, 55.695522677513864, 59.26151021834343, 65.9029576086229, 65.46693517315772, 63.716828515452725, 62.44235238721294, 60.99151472891531, 62.90611382453673, 65.35320997238159, 69.08780451743834, 67.36764907836914, 67.34314995427286, 68.05441687183996, 72.95410048577094, 69.7683749660369, 55.24861174245035, 53.43628060433173, 42.43886070866739, 33.14156470760223, 30.77678538137867, 22.894221621174967, 22.279927461378037, 27.830504871183827, 16.668788656111687, 22.74404387320242, 23.0018828376647, 14.534505451879195, 16.78636170202686, 20.161727936037128, 16.304582857316543, 6.416406304605546, 2.9683019220829014, 1.3984883576631548, 0.3041342399533718, 0.190555316005503, 0.6742691609167284, 3.9161625312220667, 20.406829003364813, 51.92582684178507, 65.8862953801309, 83.39533221337103, 82.61143868969333, 57.321270588905584, 48.19236586170812, 51.27883580423171, 60.95340105795092, 70.90458362333237, 76.2645181532829, 48.44338578562583, 7.792133025584683, 0.5843752394280126, 0.07484977794510704, 0.13574627558550528, 0.12105686905523463, 0.14932892255244717, 0.1327528176648963, 0.16606849528128104, 0.12020673362478135, 0.16589171283187407, 0.12679133594276445, 0.12458589904370809, 0.11075026686153105, 0.18811282852003652, 0.17742556489763722, 0.133451581782391, 0.13769737895457976, 0.18701018284886115, 0.15736199795238434, 0.20922746809740222, 0.1522839994680497, 0.1666339754217094, 0.1185854311071096, 0.13265636719522939, 0.12486519937914227, 0.14140006575372913, 0.14327278300639124, 0.21920986954242955, 0.19518480065368837, 0.1835700497031212], [0.0651965414985053, 0.045189496520305836, 0.04377601833473291, 0.05728752637702612, 0.026301294227220842, 0.005552659858949483, 0.06560026217372188, 0.0034666347604680567, 0.04912623467164175, 0.009968477797003524, 0.025107202555743918, 0.09972573303046728, 0.0651702876653402, 0.032204110851331104, 0.08360335137695075, 0.0165278221961231, 0.019268978634969364, 0.024819678266442595, 0.0694524740139323, 0.012666743845799038, 0.07722800597548485, 0.08005847869020316, 0.021381772521342483, 0.08566108652420583, 0.023937213925584674, 0.05655825280794694, 0.10877457973096641, 14.305209575160859, 49.052290608806, 52.00154035322128, 54.61027737586729, 48.924644916288315, 33.101509463402536, 29.495372541489143, 31.45110945547781, 34.12362813949585, 44.39292277059248, 31.01396914451353, 38.42808423503753, 41.86986600199054, 22.542739991218816, 2.6551163533041557, 0.24995020470551907, 0.08283311891699992, 0.6964074471785177, 2.998597083553191, 3.6266602335437654, 5.700078548923616, 10.324645157783262, 13.768195913683984, 6.510987397163145, 9.01363411257344, 20.21693921858265, 16.76291573432184, 21.644246578216556, 28.73265785555686, 33.5698365396069, 34.816401081700484, 39.334065452698745, 56.517627931410274, 59.49658962988085, 61.37846439115463, 59.607882961150146, 64.79710809646114, 65.68530921013125, 65.89597578971618, 59.53775882720948, 60.73810215919249, 54.67912673950196, 59.829453729814105, 58.989431088970555, 64.05115565946026, 64.69786036399104, 63.334417035502774, 61.38360269608037, 64.78483107782179, 64.91756800682315, 62.97290394383093, 63.311702589834894, 61.91207539650702, 59.949223303025775, 66.38907263355871, 67.6764259030742, 63.01749737031999, 61.37382422724078, 57.17728430225004, 44.050648904615834, 33.13821500347507, 40.03672669010778, 45.91244113060736, 55.15027792223039, 63.39921066837927, 62.777852319901996, 60.08462352137412, 65.43179073641377, 64.20605790230536, 59.496546483808956, 47.50544117343041, 52.40240658483198, 60.74942996425014, 63.74056277736541, 62.02352170021304, 60.72471903216455, 58.1355114906065, 62.66374664921915, 61.80103701929893, 64.48299684832173, 59.209283859499045, 58.75185705000355, 57.718088934498454, 63.2293406609566, 62.64953197971467, 68.60362714336765, 58.23506909032022, 53.42669825400076, 48.86960229566021, 38.78179181006647, 26.63968309279411, 19.977688366366973, 15.160302942798985, 24.535902200206635, 21.144613104481852, 15.856813903777832, 19.946419231353268, 8.845518385210346, 5.987852552244741, 8.573455925910704, 2.5732123611434816, 2.217123907419943, 0.4455287898740461, 0.1194253852290492, 0.18414162790342686, 0.04314260151717932, 0.4325151317302258, 4.465218359424222, 22.94977022755531, 40.820773186222205, 29.682308781531553, 24.005415362696496, 17.41379972427122, 24.30983247295503, 34.174960197940955, 44.05751305241739, 52.57130776682208, 48.08041749462005, 42.36461024130545, 11.832315018100124, 0.7776071900321592, 0.04938725997964221, 0.03186013737332917, 0.027718076166967233, 0.0662888832870991, 0.04333860894304611, 0.103128848807706, 0.020509949141752817, 0.04403518970995661, 0.04097187606197211, 0.06008702232652615, 0.04530063672592083, 0.07821501833536933, 0.020186188893633026, 0.08921573449286724, 0.07831505409652188, 0.08401122424871692, 0.014970436309193893, 0.09462475190840422, 0.03491351103049613, 0.03311043883103036, 0.08115585367645949, 0.054773808036360054, 0.008837002322017666, 0.029055788256828825, 0.0688663554648238, 0.05145669328950105, 0.026835079395001935, 0.021895526405123454, 0.01581711572549877, 0.05146024027659048, 0.021263498121932633, 0.018169625226648587, 0.04769645796547975, 0.040749469246234626, 0.04594422336066923, 0.02318702807139245, 0.05207874136225832, 0.04084924070705329, 0.0815862495331995, 0.050315670443758856, 0.016429278391203093, 0.010540006201594107, 0.042942794295208114, 0.06025674910615049, 0.0641268567602721, 0.024588854059637077, 0.06031906269791146, 0.03187107136322847, 0.020900337971867095, 0.03641237737610936, 0.013108314052524586, 0.09758880737447932, 0.02792040573342914, 0.04122529028644485, 0.12931861403969028, 17.395503828602454, 58.56400297534082, 64.69900569608136, 68.16530227661133, 58.16137167715258, 43.50142686597763, 39.519122877428615, 41.39760086613317, 41.577378780611106, 37.42612654162992, 34.187955010321836, 31.950944931276386, 32.16099962111443, 21.88559001491916, 3.3541391020820988, 0.07467124115435347, 0.21411075767490173, 1.385404924231191, 5.371948749788347, 9.123052550900368, 13.153825267668694, 13.791610502427625, 14.996144886939758, 17.356862598849883, 11.263544867115638, 11.839751831946835, 14.910395010825127, 17.322214341932728, 20.8394193649292, 23.794682102818644, 33.63188451336276, 41.15630842024281, 50.38202508803337, 59.16522387535342, 61.608527091241655, 61.70035762171592, 64.65257660035165, 66.64499159782164, 66.81460272881293, 62.42312100625808, 63.52416561495874, 58.10060239607289, 61.53235074012511, 61.182538078677275, 64.12157004879367, 66.29842665887648, 64.68430465267551, 62.820480638934725, 63.31343627745106, 64.82500399312666, 62.17709425956973, 64.3172610190607, 63.96855446600146, 63.07203792756604, 66.20785913159771, 68.0940955685031, 62.89135002320813, 64.03912575014176, 61.05204082304432, 46.05036735534669, 41.392631223124845, 50.21516746090305, 51.447038804331136, 61.31841682618665, 64.9514219837804, 65.82523192128828, 61.490361767430464, 67.6666670460855, 67.57584848711568, 62.06366323655652, 50.727268188230454, 56.54149163153864, 63.98293387505316, 64.70887830180507, 62.397562842215265, 61.19853742661015, 59.21688541289299, 63.02116870880128, 63.61829857672415, 65.47738436729678, 62.25745577966014, 62.33858216193415, 61.56175282693679, 64.07496444640621, 64.99169295833957, 67.17149134605162, 59.66227054595948, 51.530185207243896, 45.80444259028281, 36.492065075905096, 27.288933415566724, 19.11542000309114, 13.530494397686375, 14.576667989453963, 14.22523735031005, 16.30860426733571, 16.077563916483236, 12.950634725632208, 11.887217413994575, 15.246345035491453, 10.071387521682247, 5.09466169341918, 1.9664232889490745, 0.3221776636858141, 0.1695238276114387, 0.15386730402467713, 0.5394089426244459, 5.2639144178359745, 23.946193456649784, 47.21008277708485, 44.36059851800242, 35.49065651432161, 22.85068919581752, 28.236023033818892, 43.6845858635441, 50.95804083731867, 60.38037023236675, 57.34008619862219, 52.11296704507644, 15.670589573921697, 0.9339448977862636, 0.10083708146046247, 0.021869027423822594, 0.012559935867395854, 0.05195870687584243, 0.02054478890532928, 0.03049121103099277, 0.03527625749308256, 0.042665382366507285, 0.019346795931097963, 0.04747005983165676, 0.0758874746820619, 0.05698228247403618, 0.044925119577636646, 0.05255980627431024, 0.04840755992899499, 0.02858883851478177, 0.03194571705535054, 0.058520154186314156, 0.0810036396667842, 0.02187472520275943, 0.06022617070665283, 0.04121872491293377, 0.060738269840517355, 0.04460219436535432, 0.06106384954745732, 0.05157923671386896, 0.01715161503412791, 0.01631536877774183, 0.25734094602446406, 0.14756365679204464, 0.1054985196359696, 0.09482417991685291, 0.15304861650351556, 0.121290962542257, 0.10624069795613328, 0.1672097977491156, 0.12030456305271196, 0.07556702776421463, 0.13519221015514868, 0.20296108338140673, 0.14304254294162796, 0.17001096760073017, 0.1689618867972205, 0.08755141613824714, 0.1154426166847829, 0.14149443246424198, 0.15261363178010912, 0.1331034254643225, 0.2281882055103779, 0.18455284857942214, 0.09996073050124031, 0.16092472048776765, 0.10388779679253217, 0.16859824018132302, 0.24335244099699685, 22.36561752134754, 69.043364063386, 76.37553691864014, 78.3356394306306, 66.4495163579141, 49.54290851469963, 45.18535921650548, 44.99501051441316, 47.227152932074766, 55.146736021964784, 44.83776269420501, 52.0896799333634, 52.76529642843431, 26.244208158985263, 3.4299099781820854, 0.495926006546905, 0.37407632075971176, 1.6098391456950096, 6.303190521655544, 11.892278252109406, 17.35461311955606, 23.72864507859753, 24.32810483440276, 17.561182783495997, 23.029378652572635, 33.15265717044954, 29.44481907352325, 36.378928230654815, 37.59274490417973, 39.12500704488447, 39.10817223210489, 46.58586894312213, 56.60724624510735, 63.41340572603288, 62.050107525240996, 62.63145377559047, 64.82049326742849, 67.99938601832237, 68.53085933193084, 66.01432938729563, 66.45451345751363, 59.47192576623733, 64.4384701021256, 65.02276597484466, 67.42352716384396, 68.18016021482407, 66.53630272034677, 63.14925762914843, 64.56004788798671, 65.68897662624236, 65.22778826375162, 65.79633189785865, 65.44484046197707, 65.16268868600169, 70.011687432566, 69.91864096733832, 67.10966694739558, 64.24636810056626, 62.726990945877574, 52.96623552999189, 45.69676176194222, 51.85527909186579, 58.11113788235573, 65.66235942225303, 67.45602007835143, 66.23611588631907, 62.17510561789236, 70.83750324864542, 69.80895580783968, 64.77273448821038, 52.727347497017156, 57.60082183345672, 66.27051507273029, 68.9212606799218, 62.31283180175289, 59.90769324764129, 59.111820805457334, 64.54615877520654, 64.743430460653, 68.44412788268059, 64.97437961639898, 64.49778026150119, 62.84466205104705, 68.41086618361935, 68.27987470934468, 72.29493048883253, 61.6426242551496, 57.31518307039815, 54.371279516527736, 41.83606301584552, 31.180558089287054, 26.556338610187655, 21.693646869351788, 32.92062936290618, 35.484827872245546, 25.95571783281142, 29.71419372866231, 22.43903644623295, 16.664593681212395, 21.38410714364821, 13.609164395639974, 6.716821126399502, 1.4394616816313037, 0.3114402059826159, 0.5446313946477829, 0.20434276891812203, 0.9261788499932136, 5.7648844392068925, 29.182438004401426, 51.45544836598059, 40.9766403321297, 33.686079902033654, 27.408330363612023, 36.16717907690233, 49.43742421365554, 59.63108770308956, 68.95121974329795, 68.49063150344357, 64.79422907675466, 22.928465873964374, 1.4294245815084827, 0.2546483767969955, 0.09164531339680956, 0.17824737805752985, 0.1169242766956168, 0.1352783031160793, 0.16441020603862502, 0.13252634675272051, 0.13106187775490746, 0.1025530418020583, 0.14087457540294818, 0.1705437204650333, 0.1793606110638188, 0.12740515623121493, 0.24794242615180634, 0.22517721949806138, 0.12761851171812705, 0.04913995913680523, 0.24825092975891408, 0.24346591394034126, 0.0870923073061051, 0.18781563237069115, 0.21533406219415127, 0.29718162431832285, 0.16054250390058564, 0.12633506929682148, 0.14004275713476444, 0.13674298661851114, 0.1622763447343342], [0.023345566136882673, 0.03219495227019633, 0.015356370338028478, 0.021828717792466767, 0.04500237954480033, 0.09284706020186986, 0.04287948095870595, 0.0429966272936473, 0.0400957664204461, 0.0787621506700112, 0.035726962340695244, 0.0022034220878155, 0.04848801065236331, 0.049557657086200295, 0.02486462464496013, 0.050168359396798964, 0.02352913612529876, 0.024983950500046054, 0.01805199434109513, 0.048076081345038074, 0.07679679806554511, 0.06159100230903395, 0.053613675127346674, 0.06948576819512152, 0.04509431009571399, 0.18879838528171664, 1.9518355039819597, 31.890960124231157, 44.581580931140536, 44.96847568019744, 46.09885961778703, 36.30264989791378, 36.449793692558046, 35.43975199422529, 35.94177615258002, 48.31643043025848, 55.51976127009238, 38.39710535541658, 44.521953059780984, 31.756107076521847, 8.049794993092938, 0.6410499950570445, 0.01349428542814548, 0.13048173469160834, 1.262207076914849, 3.6975168701141112, 11.117943544541637, 7.983979092490289, 14.193327888365715, 22.873299698675833, 20.581474496472268, 10.381139055375131, 11.972477974430209, 26.181265884830108, 30.90974000192458, 33.821782142885276, 33.257066742066414, 62.23290958712178, 52.61711712806456, 59.72793102264405, 62.01297444681968, 65.16962735883652, 61.74229560359832, 64.23965692520142, 63.49670117901218, 62.74952104014736, 57.47883612109769, 56.58866597760109, 57.291460575595984, 60.99455456579886, 60.8222605336097, 64.99131641080304, 65.71107525979319, 64.60794395016086, 59.10940854780136, 65.20236346029466, 63.270768734716604, 65.76751424420264, 63.87222105456937, 58.7649263874177, 57.39992980034121, 63.48405545757663, 66.85992963852422, 63.878261504634736, 63.29269086160968, 60.64058811433854, 51.92822340996035, 25.164173726112615, 34.02318016175301, 49.245773284666, 54.12756304587088, 60.9164091848558, 63.54495025450184, 60.88376329791162, 64.04158115386963, 65.78669463434528, 56.222665694452104, 46.20939200924289, 48.518518786276545, 60.19261029458816, 62.16287959006525, 62.56049809917327, 60.391898078303186, 57.88244801182901, 57.08554006391957, 60.19871350257628, 62.96612216580299, 59.26788014750327, 56.897015263957364, 53.915896261892016, 58.398875113456484, 59.13843800944667, 60.319067508943625, 64.47906663340908, 62.751788170106956, 51.59597904451432, 47.83227266803865, 36.84906744187878, 29.790432837701616, 19.02745496842169, 24.7244171942434, 16.61072777163598, 13.476092103988895, 13.447563725133097, 10.13682246208191, 12.029338613633188, 6.245244856803648, 6.924721454420398, 5.579899088028939, 2.51257227313134, 0.25851735064098913, 0.03326253792751701, 0.08579976376025908, 0.09795830690211828, 0.9629059631016947, 9.347405260609044, 28.36654382367288, 36.34488990229946, 37.01544261747791, 42.16277291697841, 24.656722968624486, 13.639591201659172, 29.123990766463745, 47.04733579389511, 45.58879460057905, 49.32949627599409, 22.447967683115316, 2.3104910264092107, 0.05042316790129389, 0.030583017092618733, 0.03700994127880662, 0.052002205348183075, 0.03591800168637307, 0.05336752724683574, 0.03969967981139499, 0.09319487178037245, 0.02280553352207907, 0.05625711513623115, 0.03922981127435642, 0.06323960436988743, 0.06604559674498535, 0.05241527612651548, 0.04796057443825468, 0.0015433267371038036, 0.051330583725845626, 0.024886303017997456, 0.023254007138612292, 0.03455716906295669, 0.026617926027205203, 0.03200418680095144, 0.01692089807963179, 0.034076701699485706, 0.01390811654874274, 0.021652084730205037, 0.008069126540043903, 0.026377567856182015, 0.10862022067510313, 0.060492087486049825, 0.04452172832022752, 0.060495151837746945, 0.06780949120800342, 0.026885604808828043, 0.02916697442771927, 0.010243800220890872, 0.047750922986456466, 0.06675333175207339, 0.06267849476106706, 0.005289784448611881, 0.010419056240108707, 0.02787998884976391, 0.014274061428413037, 0.07644843490373704, 0.050798696540896936, 0.034246673627245816, 0.05446623522608031, 0.05246539742896154, 0.04446181258366955, 0.11811275485782854, 0.05749902793116147, 0.08786964906199325, 0.03483609018486834, 0.10912528712182276, 2.218218738994291, 38.64091596295757, 57.629141346100845, 59.46925070977981, 54.32552899083784, 47.22736474006407, 42.06498822858257, 37.27238139798565, 35.817695894548976, 48.87762746503277, 62.822959576883626, 36.25101973933559, 46.42133728150399, 28.695999383926395, 7.21185758229225, 0.9779033906036808, 0.0700682478265897, 0.9412145818914137, 3.4016821509407413, 8.49045955365704, 14.040023030773288, 14.0049119341758, 15.20920999588505, 24.056631711221513, 10.892391570152776, 14.622627381355533, 16.13076988727816, 18.519819859535463, 24.66761931296318, 32.32189524558283, 36.65438059837588, 50.207899308973744, 52.065871146417436, 60.15002512162732, 62.1781611442566, 64.02278907837407, 62.429581149931884, 64.44325931610601, 68.10692956370693, 66.65495441805932, 61.04434121039606, 57.85569352488364, 58.935639704427416, 61.64957469509494, 63.78788225112423, 65.36393373243271, 66.55311399890532, 64.8509543941867, 60.61634002193328, 64.89921523678687, 62.11123766437654, 65.90609550476074, 64.92396931494436, 62.02352170021304, 60.707115434831195, 64.36074833716116, 68.39275267816359, 66.01157588343467, 61.93174608292119, 63.89595139411188, 51.23433651462678, 34.51903835419686, 44.681707274529245, 52.196709648255386, 60.29507829296974, 62.42708260013212, 65.75314660226145, 61.55322559418217, 65.74364269933393, 66.87465421615109, 58.00599874988679, 47.70567817072715, 51.52008902642035, 63.617235614407456, 64.63319616933023, 62.878531717485004, 59.7642796270309, 59.82666884699176, 60.21756049125426, 62.507169554310465, 64.99964752504903, 60.655038126053356, 58.35538387298585, 56.5977031184781, 62.63218725881269, 63.06966881598196, 64.27258130042785, 66.05242344640916, 62.60705271074849, 54.28178671867617, 46.983032457290165, 35.74085274050313, 30.424517316202966, 22.560959400669223, 21.05391613898739, 15.510767698287966, 14.800539228223986, 15.901693663289471, 15.789218718005767, 13.758442940250522, 11.754118646344832, 8.271244168281555, 10.296965972069772, 6.4089366409086415, 1.617712323223391, 0.511660288057981, 0.10537027651744504, 0.06857486667051431, 1.2558068719602402, 11.121776680792532, 28.955650483408284, 40.04723864216959, 37.96760582154797, 34.58418500038886, 26.482241115262433, 23.242885028162313, 38.745721693961855, 55.01534838830271, 55.458121222834436, 57.587638747307565, 30.20691010259813, 3.891549658390784, 0.00903427379295951, 0.007062066137985958, 0.05070361353817487, 0.03973864687366351, 0.06798003770170674, 0.03683252680686213, 0.12922657623646722, 0.029113173988016865, 0.01667940609848067, 0.06857245349355283, 0.01070080997212039, 0.03255682539254908, 0.044261151173662756, 0.016899060743350177, 0.03309017963587277, 0.02185183641080174, 0.029445592944900838, 0.030639366689889185, 0.019628978672347242, 0.020079752467873118, 0.04467718671226213, 0.027078553628657135, 0.02127002710626731, 0.037993701595452525, 0.044287355211112774, 0.03733992599131119, 0.030834037292328094, 0.03980230111929198, 0.1837314797505256, 0.27673522791554855, 0.23715293575679106, 0.13855153634663553, 0.25605350462419374, 0.15356393320666206, 0.07202603914324315, 0.08509516205278136, 0.1510126305924308, 0.17605532471451069, 0.14825782438199367, 0.08400861954977436, 0.15338987803026555, 0.16215600764318822, 0.09375332689453518, 0.17440645835332333, 0.12157075317396272, 0.11324647243224806, 0.1262810217937635, 0.12933595827029598, 0.20380704363267269, 0.15692065469920635, 0.18336685254208504, 0.2843490693598025, 0.13783306844772833, 0.17595037066888425, 3.0629810738948087, 47.692326422660585, 68.28161624170119, 71.74701459946172, 65.52120900923207, 53.92488633432696, 51.34013068291449, 49.433050770913404, 48.665831242838216, 60.7478492490707, 67.61880628524288, 54.63616501900458, 56.55352546322731, 37.34283893339096, 9.476600289344788, 1.3461411407878323, 0.08502666613147145, 1.3745816340369563, 3.3469283148165676, 10.477340086813896, 23.601436730354067, 20.516304316059237, 21.39707842180806, 36.5643661252914, 29.195919190683675, 16.02990908007468, 20.49372911453247, 32.06036925315857, 38.35165685222995, 38.64296736255769, 41.58751810750654, 67.95334523723972, 56.69406006413122, 61.03561393676266, 62.83102396995791, 64.64437492432134, 60.67488531912527, 65.1098818163718, 68.31203030001733, 68.08847873441636, 63.777029052857436, 61.68323647591376, 63.5881551619499, 64.79478997568931, 64.09528624626898, 67.96980350248276, 67.43425092389508, 66.3241260282455, 60.566933847242794, 64.92331820149576, 63.06378918309366, 65.97708256013932, 68.90626153638287, 63.47204123773883, 62.40281097350582, 66.84159648033881, 70.8965741434405, 67.82305194485572, 63.7592097251646, 65.16518331343129, 56.38267878563174, 38.930277055309666, 46.39273143583729, 57.644136567269605, 64.21856634078488, 63.25942916254844, 67.13102033061367, 61.30255083883963, 68.60115605015909, 70.28980701200425, 61.31046618184736, 50.47933909200853, 51.87575386416528, 64.99208127298664, 67.15091459212765, 65.18582282527801, 60.374890681236025, 60.1313114935352, 60.882743481666814, 63.72637164208197, 67.25441025149438, 64.04607226771694, 62.029389565990826, 58.84697452668221, 64.1319094165679, 64.6909373806369, 66.39000615765973, 68.10899273041757, 65.00576642251784, 56.93409342919627, 52.07532798090289, 39.266624219955936, 34.01722992620161, 23.237248582224694, 34.81004684202133, 26.9074672268283, 25.96785560730965, 22.673115653376428, 19.131648809679096, 22.986444388666463, 21.300941128884595, 17.82330889855662, 15.197353651446683, 7.28233031688198, 1.0385883407246683, 0.6351238453099806, 0.35267360147929966, 0.31217748900094344, 1.443587034460037, 12.157330455318576, 36.02052557852961, 49.46091921098771, 52.57152741955173, 57.07419264701105, 33.460661288230654, 24.274193817569365, 41.62848726395638, 62.14532698354414, 64.41260599320935, 66.25815960668749, 41.15472378269319, 6.103462451888669, 0.1679202676900933, 0.13131483998750487, 0.16316995565449038, 0.24872807996167293, 0.15726586923964564, 0.1179441542274529, 0.1649704921029268, 0.1720589198051922, 0.17330539082327198, 0.13402473812382068, 0.13875666404924086, 0.2250780877206595, 0.14518668514586267, 0.11433443985879423, 0.1690667335905375, 0.18237953374703086, 0.10412090202613224, 0.18292207721500628, 0.11205354329919624, 0.13187330276254686, 0.059109524778661236, 0.1435281354333124, 0.09615292111712118, 0.15154420368133054, 0.11974201702903356, 0.10977724326714393, 0.21159270327658425, 0.12483303900808097], [0.03280383512197483, 0.08106454365676449, 0.05519529429054069, 0.05104508573910402, 0.013645007481588232, 0.005158854755497868, 0.007277583908064352, 0.028762926249915076, 0.017750847093280286, 0.024782946265693155, 0.08614469484816636, 0.023445329936822096, 0.02776349751999782, 0.05493124676567893, 0.04524348273632988, 0.018515065763025515, 0.024771594757875128, 0.07450513030973173, 0.014041678232681609, 0.014095970883875365, 0.03010403019406142, 0.031256312617070736, 0.0635929087988071, 0.07040363345896045, 0.09376795151300969, 0.17932192362364263, 7.6722457812678435, 27.917130416439427, 35.394538833249, 45.23176870038433, 41.45327498835903, 27.704298688519387, 24.672324195984874, 36.11248162484939, 47.06161322132234, 38.90223210857761, 12.943099852531189, 48.97329015116538, 28.317057240393858, 10.021312582877375, 1.6718831970807047, 0.2392119043056042, 0.07631390986423339, 0.7829456584107491, 3.5805669907600652, 9.744991410163141, 8.206727552798487, 12.83263021899808, 15.28366344590341, 11.558794417688924, 17.551816163524506, 17.83070648870161, 20.012819074815322, 31.809125754141043, 36.90372567023001, 47.66721540881742, 45.82121856750981, 50.64427868012459, 59.021131684703214, 66.47590606443345, 68.65064851699337, 60.4965586816111, 63.35861413709579, 63.19864811435823, 60.996162737569506, 62.118674478223255, 54.79497786491148, 56.79501794999646, 59.59353100868964, 62.99686962558378, 62.74395911924301, 64.43379071451002, 63.007444335568344, 64.00592288663312, 66.75609665532266, 60.51558217694683, 63.664998315995746, 64.4827889627026, 60.21649360656739, 54.427957765517704, 53.46028943215647, 59.64822061600224, 65.36455346691993, 62.81899406063942, 61.32622234282955, 56.883106539326334, 59.5247208687567, 25.2131700131201, 26.237569547468617, 48.83313602016818, 53.26638706268803, 61.59350441348169, 60.39622053023308, 65.33234688543504, 65.95874155721357, 63.64583753770398, 52.680518319529874, 48.01361953058551, 46.01087301008163, 54.51157485285113, 58.284808666475364, 63.27804473138625, 58.40741803569179, 55.20105300411102, 57.06943873436221, 59.35664338450278, 63.395311832427986, 60.74411515266665, 56.867526885001894, 54.325960451556796, 53.80009612729473, 58.26538508938205, 59.745946468845496, 62.604511014876834, 58.54348897933961, 58.89913420523367, 56.70737258849606, 50.90378661309519, 43.03857934090399, 34.56980559133714, 26.030364459560765, 25.29795596676488, 21.664762535402854, 13.855854022887446, 12.554593009333457, 11.398606781036625, 15.448095087082157, 9.64349223721412, 5.869951498123908, 4.638158602099265, 1.2002862124673783, 0.34221126127146906, 0.2105838114455823, 0.016369548430966756, 0.2412547850080075, 2.020805112777218, 20.15967457525192, 40.78087091445923, 52.89226355091218, 33.34719104151572, 24.813804088100312, 29.014715494648105, 36.30217136875276, 40.81048873163039, 48.845381659846154, 47.68366975169028, 38.865522646134906, 11.52998656995835, 0.14352477996820404, 0.024171650236953172, 0.013891505847324528, 0.07808816949686698, 0.063322571692087, 0.08490322638423213, 0.08263081041795593, 0.017310752563418883, 0.03350100577658704, 0.017454332762187528, 0.05734874829349499, 0.021086955075002006, 0.013046583645195972, 0.03719151560817996, 0.09065389603136048, 0.02467283453311651, 0.03988356389586003, 0.03768748476079876, 0.07354048771723624, 0.014895933300947711, 0.04814854560179576, 0.013767363214414689, 0.017273942038657206, 0.04894024384538493, 0.05518212906956192, 0.0007287496367597111, 0.005522663207469328, 0.02805370503225394, 0.09555354924692262, 0.023488757546029748, 0.040617238640064196, 0.02929878751597097, 0.021682186239969828, 0.04612390162242998, 0.05715960118499014, 0.04010503991476951, 0.06353053392001218, 0.0742636900395155, 0.03446863994242684, 0.03140023755540531, 0.02561350431924145, 0.01996029446262025, 0.03279509405875879, 0.10134647630395428, 0.016858379559351072, 0.10936011605325247, 0.030687252930816145, 0.01548894472615493, 0.09468921820723242, 0.05245129758071515, 0.05693788767882413, 0.051152395505097606, 0.06535643937006112, 0.17261349085357883, 10.397581631137479, 38.584680941797075, 50.13671221271638, 58.01915437944474, 50.85231727169406, 37.70065715236049, 33.1030156535487, 41.40093488077964, 42.779142010596495, 41.90175094912129, 25.514462955536384, 45.05733697645126, 26.036599066949663, 11.981750457517563, 2.5500887632369995, 0.24080003521615462, 0.1573856853910031, 2.6227862171588407, 4.974266992461297, 10.116658537618576, 13.427780270576479, 16.559483966519757, 17.74112347633608, 12.695025628612889, 16.444319255890385, 13.062083971115852, 18.460301814540742, 26.9728688270815, 32.96530123679869, 42.20820573068435, 45.9347790287387, 54.134431116042606, 61.226092077070675, 66.5619550212737, 69.52998899644422, 61.84817998639999, 63.007142313065074, 64.49372453074302, 61.718133803336855, 63.568637447972456, 56.867236629609145, 58.390763651940134, 60.89995091961276, 63.71554197803621, 64.7707615360137, 64.39137812583678, 63.63428615754651, 63.03987449215305, 66.59558542313115, 60.47419724925872, 63.73307105033629, 65.64739165767547, 62.26621835462509, 57.86507191196565, 55.95865095815351, 61.94094404097527, 66.10415950898202, 63.94722853937457, 62.64186766839797, 60.24273034065001, 59.816549131947184, 31.655984655503307, 35.62960255530573, 53.364579677581794, 59.2043024493802, 63.264755741242446, 63.024773366989635, 64.43281404433712, 67.91591013631513, 65.47122232375607, 54.42758514035133, 51.81805579893051, 49.40842220860143, 57.284792546303045, 61.87964916229249, 63.739841061253706, 60.9566762370448, 56.1995864683582, 59.4656107502599, 61.441959719504084, 64.35969321958481, 63.28494810288953, 59.38205249847905, 57.71191120147706, 56.82893860724665, 59.11096965112994, 60.715709347878736, 65.62640697725358, 59.690684195487734, 57.370653229375044, 56.628823203425256, 51.24958668985675, 41.49732320539413, 30.673801591319425, 25.73975605349387, 20.29864807282725, 16.294061099329305, 10.729627916889807, 11.497279886276493, 18.726313037257043, 15.635714800127092, 9.224090845354143, 10.895200967788698, 8.33993467592424, 3.9319076605381507, 1.2202011889988378, 0.32396111637353897, 0.05003478047588179, 0.14882515845519884, 1.7286684532319347, 20.28484329100578, 35.40009683178317, 50.777823617381436, 40.06868223990164, 26.604287624359134, 25.097546385180568, 37.62915234411917, 46.27556631642003, 55.346710220459975, 57.95730252419749, 45.990504141776796, 14.10089429347746, 0.13292822115603956, 0.027735742154501142, 0.051845015597439585, 0.0325008818218785, 0.06266030017286539, 0.01784096584625302, 0.006592945973088424, 0.017392528618896202, 0.0830167961577254, 0.01856916114657877, 0.015912129780307652, 0.04902641724554762, 0.036319837785295905, 0.038721990741549, 0.0637121771972987, 0.11040892872598865, 0.08781085947468396, 0.04132200505644564, 0.08234576442308965, 0.02769723282976737, 0.041350702710089185, 0.033666863812193755, 0.0574143254198134, 0.03989205215006106, 0.026629434583047708, 0.005899976831935948, 0.04893639425356542, 0.05809600960703627, 0.14138371743742498, 0.15398491384281268, 0.15533546556628522, 0.09732296720387475, 0.14165779305321557, 0.14666454536059212, 0.13908951393058225, 0.11991745116369379, 0.14606551056908024, 0.1728062079318108, 0.13767983554111374, 0.09982484182523144, 0.15939979183097042, 0.18091388497381442, 0.1487471247392316, 0.16716694279063135, 0.0781853937153374, 0.26503102853894234, 0.15541555239788948, 0.1615766306678134, 0.1322950035213463, 0.12547335061695308, 0.1281968161704079, 0.20734169670651037, 0.15461863709553597, 0.406417795006306, 14.45193563738177, 52.1250714794282, 64.32166191839403, 71.7301562524611, 59.61954024530227, 43.84769370478969, 36.71523224922919, 52.91211858872445, 60.65388494922269, 48.86955522721814, 24.188815586028564, 62.23959722826558, 37.26476415511101, 12.736934192719, 3.0781800131643973, 0.541536154285554, 0.40080145121582095, 2.369319224549878, 7.725841537598641, 15.820366259544128, 22.124417251156224, 29.428480440570464, 32.43582440960792, 18.586180479295795, 27.541033952466904, 31.863593747538907, 26.27644611943153, 35.87473107922462, 42.370893878321496, 54.908142166752974, 51.26871216681696, 54.37653549255864, 62.27917786567443, 67.33158680700487, 69.4162324167067, 59.814250623026204, 65.39310047703405, 67.03346313968783, 65.64153163663804, 67.35936503256521, 59.34976746959072, 61.74349584887105, 63.04086292943647, 67.5621437257336, 66.95007354982438, 67.80628773473924, 65.14747773447345, 62.877904138257435, 67.85440737201323, 61.9886439846408, 65.38020372390747, 70.40295954673522, 64.62385308357977, 60.56863615589758, 58.36269517098704, 63.44896201164492, 67.59061228844428, 66.84449903426632, 63.17191323926372, 59.21950947853827, 63.895731741382235, 36.15557670593262, 38.33312757553593, 60.20243975423998, 61.93688831021709, 64.68100593936059, 64.48837049545781, 67.13720198600524, 71.19341127334103, 67.08010012103666, 56.39232781625564, 53.217730060700454, 51.638105300164995, 58.840439857975134, 63.966114751754276, 67.15842985337781, 62.767532563978634, 56.61424375349476, 60.448658697066776, 62.49788922648277, 67.97707557678223, 65.58288043545139, 61.4898322474572, 60.23154766328874, 57.70585113956083, 61.98990698783629, 63.957932687574825, 68.40262136151715, 60.983952399223085, 60.42872128948089, 58.99195317299136, 54.577909977205344, 45.98420481528006, 37.465413001275834, 28.50331294921137, 30.666109823411514, 27.862140747808642, 26.403936878327404, 25.684185874077585, 23.420515444970903, 23.104950958682647, 20.272234832086873, 15.393167195781587, 12.089364605565226, 4.479275643825531, 0.9377619155472325, 0.8250838037460082, 0.12562871324799715, 0.47792851744640263, 2.252486035708458, 25.270773941470733, 49.37591752698345, 65.24159500675817, 45.99764677786058, 38.29862640750024, 40.7211410614752, 48.050246623254594, 54.17483152881746, 65.05167776538481, 66.87337552347492, 56.67602108370874, 18.162821415931948, 0.5026577437116254, 0.09721124860187692, 0.20531629813053917, 0.2291830779323655, 0.24080490753535302, 0.1642590568911645, 0.1791279654829733, 0.10922163800005952, 0.14232474920009414, 0.12795630286658002, 0.13920491741549584, 0.1062445667001509, 0.09837210163353913, 0.09692868473188532, 0.23329370655119422, 0.27894704632701417, 0.1500799338663778, 0.16146393913415172, 0.1320954529388297, 0.09791721394585987, 0.11775560466752899, 0.13297435497083973, 0.1270964611021261, 0.10573088176428311, 0.15847080297047095, 0.1340600700988885, 0.15727443410263908, 0.13567412542479654], [0.02013827009396928, 0.043288050970483216, 0.003714298537459165, 0.04989622964433605, 0.02492955251176271, 0.05321959566865718, 0.07290944577224794, 0.13292192391330196, 0.035546422230019685, 0.033974651127092304, 0.016150098714616992, 0.017084415716629837, 0.02283432310627353, 0.027540361005512458, 0.02372320726393692, 0.012216025591647674, 0.037724494468420744, 0.11328204955545165, 0.07747069496901766, 0.022737476186105804, 0.031006192570672404, 0.028516613660500418, 0.09151684811278697, 0.02785272186531896, 0.049382268916815526, 0.47885119374240603, 17.39769054997352, 35.332114311956595, 39.81827028336064, 44.67331732473066, 36.24988617435579, 25.86160252171178, 27.832846526176702, 25.161602612464662, 47.909155045786214, 35.37624489876532, 41.57657077235561, 41.93786421129781, 18.648293172159505, 4.067644957573184, 0.2772652688285997, 0.15969816775571916, 0.5525532340811146, 3.7880544893203245, 4.68207492943733, 9.850010910341817, 11.266422906229574, 12.34523061783083, 10.706949753146018, 26.37980449584223, 15.536791643788739, 26.80777038297346, 39.03985631081366, 43.491718999801144, 44.16892797716203, 52.515037444330034, 55.08551959068545, 62.23679665596255, 63.99106494842037, 65.09211740186139, 61.07331968122914, 63.52202792321483, 62.555948149773386, 60.49528783367526, 57.911399026070875, 56.18947459805397, 55.64793256021316, 60.45027471357777, 62.74795993681877, 64.67308667398268, 63.84605100077968, 62.018948216592115, 61.86918820104292, 59.81536065378497, 64.09357609287386, 62.01952480500745, 64.1149647774235, 63.13346616683468, 59.92025659930322, 50.60672590809484, 50.742789007002315, 59.079069014518495, 62.37849620080764, 61.951000998097086, 62.23291743186213, 59.64893840974378, 64.13509438114782, 31.048944919340073, 22.88800270326676, 49.827727502392186, 50.7698808177825, 63.00298067831225, 56.95722756847259, 62.76010359487226, 59.980402223525516, 62.72545337677003, 55.93599927040839, 48.583504615291474, 43.690696916272564, 49.52356338500977, 56.74569414507959, 59.81237965245401, 59.08229320280014, 59.93953112632998, 58.79267323401667, 58.49585179359683, 61.944807575595, 63.73048620839273, 56.830691906713675, 53.95970913671679, 49.88739067508329, 53.13760388282038, 54.53621518227362, 57.329754675588305, 61.77283517775997, 57.41630177344046, 57.383899073446955, 56.095306334957, 52.3524748125384, 51.21936875004923, 45.612889720547585, 33.677093751968876, 24.970747924620106, 16.852220258405133, 14.70489811512732, 14.80339373311689, 13.153041774226775, 4.295647923023471, 11.396431826776075, 9.240900162727602, 5.5419687878701, 0.7525083110217126, 0.36764682060287845, 0.1661099406379846, 0.02556447086164788, 0.4533878100975868, 4.72735575129909, 29.674605246513124, 53.748403210793775, 43.69285814223751, 33.646036424944484, 30.247065367237216, 28.223179232689645, 30.96830491096743, 50.49845280185823, 54.213984627877515, 44.074481225782826, 17.753655449036632, 0.40393193162256674, 0.022156379343340957, 0.02223073392205181, 0.06417296376199493, 0.016477440423782796, 0.03780447787815525, 0.020128144326830105, 0.046954785263346094, 0.0637225385364746, 0.03158903034824518, 0.024795506277211735, 0.07049022437704187, 0.007553026990799775, 0.027044598696633216, 0.021179674696477673, 0.01447356987609378, 0.05556476317466267, 0.02570382608551412, 0.058099269311154084, 0.07577303646793289, 0.06599670501365777, 0.012275674155042058, 0.04761971893810457, 0.08961305067303682, 0.027432783108745373, 0.04805840003574568, 0.04052616227718611, 0.019124620856957573, 0.029870608949192592, 0.017771636804325447, 0.05138879108633246, 0.1317712598510327, 0.04200359348267798, 0.05550152261651332, 0.03507607105758882, 0.0648273560669153, 0.056161434584928144, 0.0445920437003576, 0.035377346625130986, 0.02799723669135523, 0.07255189721622775, 0.014881011823402538, 0.043262467464251865, 0.05606326807831084, 0.05637316596544078, 0.03831227542832494, 0.019897180308978406, 0.07116066622397593, 0.00409939058778447, 0.056532427984019445, 0.03806804659806433, 0.04306917582007666, 0.06558889342892556, 0.6363911385978422, 21.637441265967585, 44.56795069479173, 52.86152001350157, 55.3851729823697, 45.56135369885353, 31.353540497441447, 28.618336454514537, 32.39903061620651, 51.70810784063032, 42.2111318188329, 29.353692608494914, 39.35634843764767, 20.394012658826767, 4.544457101052807, 0.34427387639880186, 0.1309051208438412, 0.7853133603930474, 2.9537310523371545, 7.233200669288636, 11.548210882371473, 10.982816911512806, 16.38188590926509, 23.447546459013417, 19.093876384919692, 11.840681433677675, 18.767535186582997, 26.557889907590805, 36.52197707083918, 41.838192862849084, 50.95200823199365, 56.185383565964244, 59.57398583812099, 64.0429461386896, 65.2866748071486, 61.4885574771512, 62.16197744492562, 65.29200138584261, 62.984212137037716, 60.687487894488925, 58.36789623383553, 58.07871164814119, 61.61848991147934, 65.30537274576002, 66.22666297420379, 64.18373177128454, 61.78754406590616, 62.83325579858596, 59.968211497029955, 67.11268717242827, 63.45865418834072, 65.03451739588093, 64.44812305511968, 62.413444519042976, 51.207374142062285, 52.338660224791504, 59.82933605870893, 65.84276491595854, 64.52478185776742, 65.32475709915161, 59.72089429055492, 66.07384743229036, 35.79176510533979, 30.187800315118608, 54.11151270712576, 55.18100577016031, 63.13298371530349, 59.67675978137601, 64.09783578688099, 63.59349743012459, 64.32183450268161, 57.33165310275171, 50.18202735531715, 46.83291158368511, 51.10574553089758, 60.665416717529304, 61.952569946166015, 61.54846383679298, 60.482551897725756, 59.212068742321385, 60.13384142229634, 64.81289171403455, 65.2572178071545, 59.44836408861222, 56.71030652138495, 53.32756034789547, 55.316943353222264, 58.86840635730375, 59.754450167379076, 64.95292032918623, 58.458381391340694, 60.466062253521336, 55.061569598413286, 53.69241922132431, 44.915115756373254, 40.38058519363403, 28.349422677870724, 19.763840744572303, 11.78362173418845, 13.857104278379872, 13.228867073212902, 16.39932574764375, 13.373749621452825, 10.596583081829934, 11.404451112593375, 6.3640578619895445, 2.8982300046951543, 1.1903721767087136, 0.16444126324307534, 0.04470415683763643, 0.48993844719183066, 5.324068377094885, 30.517816774306763, 53.32330457625851, 41.3900032351094, 35.98869946695144, 35.80727415700113, 35.925561074287664, 37.27236570850496, 54.58943782314178, 62.95956788524505, 52.56949563180247, 22.25515965492495, 0.5634380564574273, 0.016302910272873217, 0.025239689801368984, 0.027602100031330224, 0.038591326785183726, 0.03770235452740904, 0.04582679740363552, 0.047367614723982356, 0.05499318114391739, 0.04720071480879861, 0.03924930438158974, 0.03814729839383114, 0.03432282659735891, 0.04307323991651497, 0.037981708488997915, 0.01437096676278499, 0.08637723317670246, 0.030531752403945695, 0.03715856233611703, 0.04271982057440666, 0.03719765580289307, 0.027935344447952606, 0.017271318187516545, 0.012794835661958544, 0.07363712970888422, 0.009397143787223726, 0.05202993007016279, 0.06482200111232458, 0.06531423558631251, 0.1604599196223482, 0.11040054006321777, 0.2294701157558349, 0.15488773313981874, 0.12866206136682343, 0.15261095047237414, 0.16949994098995963, 0.21270135507708599, 0.11222970521738453, 0.08761664852499963, 0.07594659368717864, 0.2084483413566505, 0.10882225338249438, 0.14766402963188388, 0.08441185758959863, 0.1109215717822794, 0.23144332842240412, 0.14284679215521584, 0.12249897594653791, 0.1110297587189463, 0.15597378534655418, 0.11528366876225318, 0.1189336027469366, 0.2114039698555585, 0.8330706074353188, 28.729129683586862, 58.60174009876867, 68.55917884457496, 66.68495270513719, 54.13493317942466, 38.955846986462994, 40.4808880436805, 36.96835456355926, 61.308332412473625, 48.96875589124618, 58.03251397225165, 52.135544207788286, 23.86330200779823, 5.445240197643157, 0.5689016116722938, 0.3039834738498734, 0.7572836741324395, 8.920670017119377, 11.905055372945725, 22.531749509995986, 24.419660798964966, 20.633798914570963, 23.811673810405118, 42.66283981261715, 27.07764514030949, 36.88103083641299, 45.96323190196868, 47.546171065299745, 50.87827159512428, 58.124105238145404, 61.3038020749246, 62.82672505224905, 65.0134817246468, 65.41802713947912, 61.36601086585753, 63.7300233687124, 66.35808590919741, 65.58773632972472, 62.247916575401064, 59.55458971761889, 60.11795582309846, 64.50910414418867, 68.48770541529503, 68.4722512768161, 65.28614528717534, 62.463172328087595, 63.3275568100714, 59.538766876343765, 66.1194645973944, 64.83284088873094, 67.10201832555956, 67.66996183703023, 65.66925887138613, 54.69918181819301, 54.763928382627434, 64.02709976319345, 68.8190358684909, 66.5537101991715, 65.67657801412767, 62.184837018289876, 67.71091138162922, 40.6558257533658, 35.8085959957492, 59.69006446100051, 57.94290350329492, 64.4620906153033, 60.68455396160003, 64.96529148470971, 66.23297014544087, 66.51471399491834, 61.26079720835532, 53.82160248294954, 48.855666114437966, 53.158878818635024, 62.769117201528246, 64.66797974801833, 62.76344153188891, 60.788610519901404, 59.12653753834387, 61.12642072862195, 64.82208574971845, 67.85653329664662, 61.6839111235834, 59.87703600237447, 56.04835164162421, 58.64498422991846, 61.73974998535649, 63.292871290637606, 67.16357600304389, 57.39527394694667, 59.27354797240227, 57.014553008540986, 54.349263252750525, 52.81463984520205, 48.81171595665717, 39.73371574955602, 30.988818906968643, 26.14239911879263, 26.002246948980517, 28.935793484410933, 24.138436663535334, 13.549949353741063, 27.071059480790172, 17.312212297993323, 9.341204973959155, 3.302584694277856, 1.3466563195951524, 0.47650785335609996, 0.2258809631870639, 0.6084683369244299, 6.480428701446903, 36.23613826690182, 64.75943765332623, 57.146827097862, 47.48602936344762, 42.03669225015948, 39.13894322610671, 44.798750800471154, 65.04642963409424, 69.77033615112305, 62.44287014007569, 29.100223164404596, 1.4745271806755376, 0.1357162449388735, 0.1198305078451672, 0.19740421865736285, 0.18053005960199142, 0.1814160249646633, 0.13803982025673314, 0.11162789718758677, 0.15450502625636517, 0.16703244839464465, 0.11761478238528776, 0.21139817823085094, 0.1434239015103348, 0.1253027428362158, 0.21586379667203273, 0.10985759056864247, 0.23749309411693006, 0.053935991299729195, 0.09872900667570292, 0.1459997342599015, 0.1783183484428352, 0.1571341021166694, 0.09805615931268662, 0.09490373814778943, 0.2268647732994249, 0.19905751300675256, 0.12154371793111488, 0.3033380600954256], [0.06479688875016666, 0.04835084643996051, 0.05578889751866941, 0.036285195289359945, 0.031546338183444836, 0.02928717553825869, 0.05862167615803981, 0.09488436378418438, 0.05056456857991796, 0.03349401522427797, 0.013733925391739656, 0.0386000563570809, 0.01365281391753665, 0.07484950981433354, 0.03194455451692545, 0.0827665918416554, 0.06679715198134223, 0.04214617010626582, 0.029987542694734953, 0.040928419724467306, 0.040383076205128626, 0.0407174812449563, 0.1258954803849901, 0.03296499703860572, 0.029732906560022986, 1.605878042117242, 27.586025499528457, 48.82496180072908, 50.34442524756155, 49.380079161736276, 44.097368255738296, 36.41117011347125, 44.52829945471979, 41.55642155678042, 28.497925573779693, 16.73926188099769, 46.85001704000658, 32.3370022543015, 8.4150823854631, 1.0923966404891785, 0.14571088846893082, 0.006437079160429177, 0.2183329133737472, 2.1188572577891813, 4.654369267725176, 7.2379217320872895, 10.23368049052454, 15.140159610779056, 27.210764500402636, 8.071266047416195, 19.51357391572768, 19.64209625797887, 31.150734347681848, 44.06803284921954, 54.636918114077666, 56.23810022108017, 64.10675917902302, 63.17653379132671, 68.17437079644972, 65.84046640703755, 65.33615550687237, 60.22447170749788, 61.33316493803456, 58.42988144966864, 55.01453253530688, 55.09234451478528, 59.93433006348149, 61.88610930596629, 64.44753469959383, 61.907129287719734, 60.437766275098255, 58.35110848949802, 60.56694953672348, 58.51396529905258, 64.93015489270611, 66.22363490443077, 65.52577464811264, 59.70657371705579, 55.03445817578224, 46.27064766422395, 50.183702207380726, 57.25030314537787, 62.73545149833926, 59.623517528657, 63.45408070471979, 57.12779183541575, 64.33365652638098, 38.666866364017615, 23.821730767526937, 50.59932439557968, 51.92479918079992, 62.463172328087595, 55.87289617907617, 58.684941414863836, 62.66234244069746, 62.80132378301313, 59.74979039161437, 55.57762799724456, 48.97689088698357, 44.221213171559, 48.74425118969333, 54.21649102241763, 59.01727207245366, 59.30767259290142, 57.063598325175626, 58.072777102070475, 58.15748853068198, 60.76819066078433, 58.76733080033333, 56.72958104841171, 51.517617933211795, 48.645450607422866, 54.23498107540993, 57.79712077110045, 62.15309327648532, 60.662149383175766, 58.70563583989298, 59.14520017562374, 58.62270908970987, 52.66915129077051, 54.819245569167606, 38.52613956697526, 33.278777060970185, 14.555484248745827, 10.740275190722558, 18.290780898063414, 11.232361043653182, 12.285480172403398, 9.448029745009638, 7.591540563491083, 3.887283345383983, 3.6128029900212444, 0.4930828091117644, 0.32527679577469826, 0.11277529005441936, 0.057954256527967034, 1.3951759160526338, 9.498622436677257, 32.38451196301368, 47.97541564510715, 46.942510451039965, 26.818478453543882, 17.983390631214267, 36.66413161062425, 44.5209018645748, 50.545611458439986, 48.560523448451875, 26.42594921973444, 1.5810958944982099, 0.02036502062823744, 0.06855926912037597, 0.05772225446097794, 0.043200502442496444, 0.038514649044842496, 0.04213881566219273, 0.023418400031063828, 0.08640187822522656, 0.07158972908772769, 0.04909155004086995, 0.025698438572186618, 0.049241048268853664, 0.02679471613749141, 0.01744964238887112, 0.005858381130477233, 0.04183296271930299, 0.0262789512729092, 0.0336589424630567, 0.018684093487418948, 0.033976409298878525, 0.14877827387423287, 0.020482073117408062, 0.04255010528610118, 0.02352673635487595, 0.02126264201867725, 0.00405775083627011, 0.0402827033652894, 0.028477769172299775, 0.09637559223319254, 0.04053783745715215, 0.04418073875469066, 0.0349625789620463, 0.034371932833305294, 0.09321303572505714, 0.035905372726941304, 0.03570491049979483, 0.03346422206490271, 0.0455816186243488, 0.05013629861716783, 0.061205610287405794, 0.0903449557541359, 0.03163999434740793, 0.058197236634911075, 0.00884161321371193, 0.04855275657328387, 0.04336177161143672, 0.04891727269897538, 0.05851598666800607, 0.034193066624744285, 0.047727453882896134, 0.025146163872353015, 0.02633855099819841, 2.2148462360905063, 32.6618549131578, 59.116574718106186, 59.68211381666122, 55.75637825073735, 48.939922548109486, 39.94988149212253, 50.02882349875666, 41.534009133615804, 30.423211166935584, 24.863398536559075, 43.33997034257458, 31.744596881251184, 9.437892379299287, 1.5850302769291786, 0.13145999832739755, 0.24652026052917206, 1.7695483757603554, 5.366431936140984, 8.169611144450403, 14.2094252955529, 12.062004112428236, 18.10542929557062, 18.466230477056197, 12.459231365111567, 20.516145460067257, 21.336722950781546, 34.36646207686394, 44.188473147730676, 55.27629583112655, 57.42126749407861, 64.82430581123599, 65.20219087600708, 70.2548743832496, 63.742414136086744, 65.28264261061146, 61.73843206897859, 63.41979918941375, 61.02509413996051, 57.67122445567962, 56.476160633948545, 61.5897624723373, 63.08374228016023, 65.53327029751193, 62.992633465797674, 61.967404350157715, 60.45941775844943, 60.70539351432555, 59.848689033139145, 65.45782350724744, 66.24170134144445, 66.33745424209103, 61.334133763467115, 58.00081729888917, 48.56606967987553, 53.09652882237589, 59.06366978922198, 64.48665641969251, 61.5732845952434, 64.7678158360143, 58.078503762522054, 63.9635181427002, 42.139113180098995, 29.92867481323981, 54.90786367847074, 54.158216368767526, 61.81097630531558, 57.685337143559615, 60.69074346173195, 64.82216811949208, 64.81763385957288, 62.2916353133417, 55.76857289960308, 50.51221247642271, 47.47771786105248, 52.49635911756947, 59.38613568582843, 61.49429198234313, 60.9233949261327, 56.605720443110314, 58.117166565310576, 59.05597017657373, 62.9288165030941, 60.93878238431869, 57.6706321777836, 53.63133615063083, 50.699917501018895, 56.353680702947806, 61.349070149083296, 63.51808986356182, 61.443665950529045, 57.64505047951975, 60.19089621882285, 58.42007944660803, 53.7915571274296, 44.73776578903199, 33.55060123628186, 26.557289784954442, 15.173398756211805, 9.740827814225229, 12.129374742507936, 17.153213139503233, 14.84058564709079, 10.465673977328885, 11.302095882354244, 8.534416575585643, 5.9072473549073745, 1.6863843221818249, 0.5912905006158737, 0.20115118533853563, 0.06380058374376067, 1.57190945840651, 11.079264071679885, 32.45736018303902, 46.54188348400978, 44.75698540287633, 26.819039352478523, 23.315419458573867, 41.059406265135735, 50.79673336398218, 57.34815843643681, 56.291193423732636, 32.52325207956376, 3.449611798409493, 0.03651259699836373, 0.06513342351442383, 0.04902523747014423, 0.053031203156757745, 0.02464000191990166, 0.026081559143119284, 0.03577449043551761, 0.08297163527458906, 0.057993200607597835, 0.026392663618729963, 0.03773108282456956, 0.05864083984746568, 0.030028626074894305, 0.056784811820234024, 0.038247766994660905, 0.041421765025945446, 0.007967509764937625, 0.04530703356008857, 0.02754424507128856, 0.02547228367127959, 0.06207272605670076, 0.02857671708859984, 0.0631815578878647, 0.024640057461276173, 0.06625687613362266, 0.0654755047552528, 0.014991610979421005, 0.15412988832160351, 0.2260811419616784, 0.14051561724514733, 0.20358691592850994, 0.14335104654873573, 0.11427164363164095, 0.14028761415712296, 0.22342825608868755, 0.17003592674530324, 0.12420952770738833, 0.10437461502489545, 0.12217960921266388, 0.10863715887910898, 0.1693450686551871, 0.13294852248603298, 0.24720489798534304, 0.2023917268360815, 0.17203550815822619, 0.2773795997904193, 0.13997691953855176, 0.13458421213492272, 0.2026107207301163, 0.22635397651503164, 0.2755328069531149, 0.17973317494315488, 3.146149540139783, 42.258823917758086, 72.03251607956426, 74.26983602585332, 65.32431387132215, 59.001515911471465, 51.88772886030136, 58.372861954473684, 53.19452531876103, 40.179049891810266, 29.63714857255259, 59.67047614435996, 40.40582956806306, 10.81403143944279, 1.692497703817583, 0.3572373098183063, 0.4155973975937213, 2.7063035292010156, 9.476202168772298, 12.208655649615872, 19.466083818866363, 18.58002039694017, 28.4064676684718, 38.32723225316694, 16.283463835716248, 30.10162192006265, 24.50182660933464, 34.80501836346042, 47.16927836018224, 57.69156194502308, 60.408332809325195, 68.13858309099751, 65.29465290807909, 70.08858942216443, 64.87326483572683, 66.62678395548176, 64.91923109177621, 67.32487170926987, 65.40516961005427, 60.430458899467226, 61.24221301847889, 64.87799913652482, 66.11554222722208, 67.50653236143052, 63.794754243666134, 62.20990488606115, 60.48024946643461, 61.80160968534408, 62.206712076740885, 67.29022149116763, 69.70507575619605, 69.04698833342522, 64.96857058617377, 59.097559067510794, 50.41707538789319, 55.1752555754877, 61.03118558083812, 67.91301542712797, 63.24258258265834, 66.15264000431185, 59.46197079073999, 66.42057711078276, 45.86741624339935, 35.46429426439347, 58.973721996430434, 57.57609128952027, 62.00046993071034, 58.33370493304346, 61.32406111686461, 66.86018067021524, 65.82046231915875, 65.92987291274532, 59.221458896513916, 53.16637839040449, 48.294810325868674, 53.504620059843994, 60.4456933852165, 64.15362365784185, 62.88870242334182, 58.936514392975845, 58.588043182126945, 60.5538409756076, 63.09609774620303, 63.586343026930294, 61.33439263989849, 57.64141444237002, 53.512786434542754, 57.917176677334695, 64.37252721478863, 68.16537287927443, 61.95469979316958, 57.59523637833134, 59.77674099706835, 61.377597547346554, 55.03242638803298, 54.980149038376354, 39.61462082401399, 37.33510009704098, 19.094272544307096, 17.42467841794414, 31.45915423670123, 20.886825130831813, 24.7706207536882, 15.465459419835, 17.231817437756447, 15.073539133994812, 10.501310671529463, 1.9459465554644986, 0.8217138136106154, 0.4196650486799979, 0.18963288485763535, 2.2238076261935698, 12.376192827378551, 40.97391428485994, 62.3636814086668, 60.22711930736419, 37.28168133766421, 29.627738806509203, 50.81238754333989, 60.52946344498665, 67.13783740997314, 64.44191786550707, 41.265730780939904, 5.853044611792411, 0.1531256543051812, 0.23144245508217046, 0.18867196545245188, 0.1756273880000076, 0.10812630080768179, 0.10573034550273612, 0.09001668707858171, 0.19064386044779133, 0.2841347179585888, 0.22523430837017877, 0.11016447006935075, 0.0993221196075601, 0.17059667246235957, 0.1113759461910494, 0.1304300544002364, 0.11792437383724798, 0.06504640358710481, 0.10072173160170356, 0.1112476417854909, 0.11557528013063055, 0.18387332859058536, 0.09997238269856862, 0.11110793033073987, 0.13041517697274685, 0.19623584264228422, 0.19331939187982392, 0.1098361018023664], [0.025368444283582994, 0.018201142083853483, 0.03933473467646588, 0.03362445318470559, 0.047639801933039586, 0.03753367345780134, 0.009320723643947032, 0.04219880034666389, 0.02977164379591423, 0.05365066185233094, 0.05396180463233783, 0.04764322634606112, 0.054367030670325604, 0.021562042586024732, 0.07209079655548258, 0.04893362101527953, 0.028593710833980192, 0.11152205447996817, 0.032899691873500427, 0.042649964847031145, 0.01874549926498965, 0.04243477840998, 0.03319442505016923, 0.017756571685294473, 0.050372445219827276, 2.712416052818299, 30.215560890013176, 58.68614166013656, 53.55430472281672, 39.684960688314135, 26.28006450591549, 28.570291342273837, 26.90723776817322, 68.11307984013712, 75.66875719255017, 62.341418035568736, 43.80330816391976, 15.559097182366157, 4.5143445749436655, 0.1666587813486976, 0.03828217966421958, 0.2515307819891361, 1.7392393634203942, 1.485100297197219, 5.726514343292483, 9.447926782792615, 8.319545215175998, 14.558910439091346, 23.729915926533362, 27.24845651657351, 21.62864338967108, 38.23768846450314, 44.40486638776718, 53.60835106142106, 60.32415482305712, 61.45427988421533, 64.35049133916056, 61.113504363644516, 60.87961735263948, 62.577074035521484, 62.625636900624926, 57.91947910862585, 57.776328286817005, 53.51177838540847, 54.69259615867369, 58.05338882630872, 64.60147988411688, 61.54230179325227, 60.84675965770599, 60.574849190250525, 60.09530021298317, 57.40302455040717, 59.30289906840171, 59.1411679790866, 61.746994603064756, 63.159855873354026, 61.341919668259166, 56.03561962804487, 49.42651217983615, 46.82847146065005, 51.196928870293405, 54.727238532035585, 59.148043893998675, 56.64379489037299, 61.710002729969645, 57.30494176187823, 63.69959362091557, 43.66756669936642, 28.67541086289191, 52.010926585043634, 51.87077637641661, 63.693364897081935, 54.41627302477437, 59.790179037278705, 60.569416707561864, 64.82296043826689, 62.73222731005762, 61.10206673222204, 55.90566758186587, 46.662057061349195, 46.129744360523844, 51.36208026639877, 55.97140258358371, 60.467525297595614, 58.91101898685579, 55.96634272606143, 59.02935689495456, 59.896255616218816, 59.7358149866904, 54.658597054020056, 55.25657807627032, 45.90349420424431, 46.6398407566932, 53.33932745841242, 59.48526966956354, 59.42818741644583, 62.136293765037294, 57.681614814266084, 61.324590636837875, 59.55000446688745, 54.37544115128056, 43.360198005553215, 37.703167469270774, 27.082348062146096, 20.05419223539291, 8.71138018946494, 21.20223468349826, 21.247306639148345, 7.857864595228627, 13.038362456906228, 5.819046487731319, 4.266055110962161, 2.992816000215469, 0.2132591283729961, 0.08765362758910464, 0.05345993277226245, 0.15990144152554775, 4.881307309673679, 22.96091172002977, 43.839507718240064, 48.49032478947794, 36.635443395183934, 29.44648608084648, 28.466562301881854, 34.382390822133715, 50.66178814057381, 52.04027768104307, 35.502105912854596, 3.606460027156338, 0.1300720921567371, 0.035593069323729125, 0.04275415280473329, 0.026581000589254885, 0.015705220923278362, 0.06085239395859742, 0.00789887642660629, 0.04385896267429475, 0.03977687849152473, 0.01806355652309233, 0.05682866269301984, 0.048165732784377, 0.041320380950046164, 0.06288431960368349, 0.046443934852798144, 0.04736988234423822, 0.04498446074825141, 0.034730170868457325, 0.06013330552847155, 0.08162958712707605, 0.0471059650543236, 0.030624638649544893, 0.009539469517016364, 0.028397318448931463, 0.03521052714917929, 0.0372388789940986, 0.016282488284031713, 0.028974146266738256, 0.06815111279607781, 0.062126413498434334, 0.04032291148999526, 0.057220102978810194, 0.00296956196243334, 0.036791177211149086, 0.053715312012260964, 0.05199612261006429, 0.08257751368106374, 0.06551701139899031, 0.07953786065862065, 0.045161434719639446, 0.05488273424787387, 0.019397202601295807, 0.03505321865480754, 0.052312294757294084, 0.04468426153424286, 0.0467852998014179, 0.017263760730143518, 0.050058249579442125, 0.04125396878789029, 0.03588812042688651, 0.01595019477404534, 0.04165131178113722, 3.7561413501539542, 37.83504932157455, 66.59222787426364, 62.775855833484286, 50.77024167583835, 32.81904782018354, 35.67667099737352, 36.182715585154874, 65.18967459278723, 58.305224603222264, 41.00674060083205, 43.545875164770315, 17.975720436342304, 4.8813759511516945, 0.12252202753217951, 0.04096700374277369, 0.3911854849467355, 4.701030763887591, 6.7290628437073, 11.056429013129204, 14.170512441665897, 14.480384588241579, 11.299881704391973, 16.63334023567938, 12.196650255110956, 20.987016193328365, 35.2842810077052, 44.62218530716435, 53.337554547094534, 61.336785285703606, 63.770631667106386, 67.3154031076739, 62.515316317158366, 61.25264260076708, 61.852757392391084, 65.0151095082683, 60.308873268865774, 60.480131795329434, 55.6016093684781, 57.29118208731375, 60.81384312721991, 67.19045208346459, 62.69337231113065, 60.64471444775982, 61.52749092348161, 59.84142872595019, 58.454513934350786, 61.06759694314773, 62.103134047600534, 64.72204177610337, 62.65377598424112, 62.816648483276374, 57.98091519263483, 52.83284356517177, 48.64339528545257, 52.39258104755033, 55.67148247072774, 61.74475885206654, 58.400600956332305, 64.25156524104457, 58.233178507897165, 63.18443736722393, 45.65940903079125, 35.079042988438765, 57.553086588459635, 54.426404506929465, 64.66184123869866, 57.00885772705079, 59.56047719524753, 62.10224366957142, 65.67149070001417, 63.248426914215095, 62.096783730291556, 58.85521934878442, 47.35513202605709, 48.11642485280191, 54.974214492305634, 59.62228198205272, 62.63991040568199, 58.89291724851055, 56.79340585585564, 58.52148056030274, 59.21070375750142, 61.756655400799175, 57.96676720342329, 55.77980656777659, 48.662316799163825, 49.46577118289087, 56.55179177561114, 61.73812612410515, 61.84779167175294, 60.310512819597804, 58.22149768952401, 59.951239401294345, 60.306249203220496, 56.5696503270057, 46.46338901212139, 34.6230988348684, 25.721391516347087, 15.716772540923088, 9.886559555607459, 10.594234562689259, 14.141887964740878, 13.156115931849326, 11.704807589131018, 9.879789544690041, 7.477487844805564, 2.956416895312648, 1.054254900063238, 0.3026891223365261, 0.050154091009209235, 0.2485463639060336, 4.706781448856478, 24.78406075508364, 39.005174713750044, 49.74633832131663, 39.48028356798234, 29.92134782575792, 35.75338471320368, 41.02164168511668, 58.86260124944872, 57.987163528319336, 42.5791403555101, 6.5847206019586135, 0.17227034475053513, 0.044150907290919174, 0.03798422125738956, 0.06419048802326284, 0.06944230802717709, 0.06411246579861449, 0.013394823275326241, 0.006440069776163587, 0.04459168363903319, 0.06060316640463087, 0.03831029126060106, 0.01600922855188049, 0.13200077979314712, 0.06709958051121043, 0.01921914653071473, 0.04286617784190082, 0.07342420323120971, 0.044499645835810134, 0.03414768740654953, 0.0515380441661804, 0.06706732054871899, 0.04823695980913697, 0.04469088053390865, 0.05299046260094451, 0.02723239365995171, 0.04167694508308365, 0.041341819920607155, 0.15942767743141423, 0.13740298668703727, 0.22414542163812348, 0.20782309103636973, 0.10522254412212681, 0.12362138668615973, 0.05142599231593552, 0.11060323926710314, 0.12584816679478655, 0.1273403451928208, 0.1579555322325999, 0.204573851679602, 0.10223455606929718, 0.09168719542362998, 0.19760323297833243, 0.14882701238797558, 0.16864699401682423, 0.2517012365522885, 0.06796148305218067, 0.14957546496823912, 0.15749658427892194, 0.09670924650685442, 0.11457872997608878, 0.2123359158154457, 0.21459186089134988, 6.094885699210629, 48.43645887990152, 77.39504721856888, 72.3340835878926, 58.17841437555129, 42.14623620433193, 43.754694308004076, 39.13610735247212, 76.34895893835252, 84.09410245956914, 77.71715225711947, 53.818323381485484, 19.988341523754983, 5.4091166392449415, 0.43419767531656456, 0.14445908547889802, 0.7328599943749367, 4.9020939104018675, 7.2552693947669, 16.877543080237604, 24.61511250465147, 20.485650993162587, 28.267300013572942, 35.78271227498209, 34.908878803253174, 24.515878500476962, 39.873014803855654, 47.01241100988081, 55.79856726431078, 61.41285181045533, 63.184959042456846, 68.19834432294293, 63.4896566021827, 61.54603981202649, 63.41102876970845, 66.27024835155856, 61.9487887813199, 62.305143956215154, 58.38281692997102, 59.576453008959376, 62.90515676621468, 68.52469336601996, 63.94078800755163, 61.75577678988057, 62.332169086702415, 60.53304064658381, 58.418467352467204, 62.38394829534716, 62.92688277459914, 66.25946967832505, 67.065289251266, 64.46878217881726, 60.70185161405995, 54.415798417983524, 50.97292230975244, 55.76504668881817, 58.25487705969042, 63.7319217958758, 60.335168838500984, 66.21022039844145, 59.84214259732155, 62.98687934875489, 48.07137250900269, 41.480272662255075, 60.80502171670238, 56.23049866768622, 65.66197502997615, 60.00998473936512, 58.19409601150021, 63.7582330549917, 67.82484839039465, 67.63169519362911, 64.39152325353315, 60.36856389814808, 49.255379169218, 51.6993687998864, 56.69237344495712, 61.964125248693655, 64.20195902547529, 60.99503701733005, 56.501993363903416, 60.14619688833914, 60.22504829591321, 63.14998719000048, 59.0319731158595, 60.138665937608295, 49.68301165488459, 51.558540021219564, 57.66660390361663, 65.30110912938272, 61.493068202849365, 62.688928265725416, 58.255088867679724, 61.95613145828248, 61.49427629286244, 61.17365783260715, 49.49152938781246, 41.32749634404337, 30.21351537396831, 26.494622076711348, 13.534386369489855, 35.22998755978, 33.901319965239495, 17.552735959329915, 25.88644877556832, 14.416929464186392, 11.367666144524852, 7.695482392464915, 1.2445705071572335, 0.32655478364998297, 0.26495788246393204, 0.31895467050133214, 6.465464859239518, 28.465307143426713, 55.86924837481592, 62.41079691917666, 52.81445157143378, 39.66500366887739, 40.639747958029474, 48.75998773882466, 66.2572809957689, 67.74668339760073, 52.453440543143984, 11.33121555851352, 0.2718936135211299, 0.08852421756713622, 0.19850574584016878, 0.22181220893417636, 0.07504308491104072, 0.11038666621090905, 0.11904436373902906, 0.1437326502655783, 0.14844303379856771, 0.12205174913810146, 0.11042187561190898, 0.1645119118714525, 0.16284398524270904, 0.12150906777429966, 0.1398692535416734, 0.12892991634866885, 0.12757222468574203, 0.10813285852031362, 0.0960669277476207, 0.2688735417060314, 0.11621482565157837, 0.14857801849082594, 0.08371235802769662, 0.14108457542475195, 0.31385770367999233, 0.07370170326002183, 0.10675288902054872], [0.062493764149445685, 0.05448655953871147, 0.01835100420360123, 0.0413059976492678, 0.03514076335235469, 0.0735382967057728, 0.04045720287268201, 0.04706507511136513, 0.057185828205077886, 0.02443861655680643, 0.030967554926211317, 0.08328417616505777, 0.07099449409232025, 0.02497254728129314, 0.02216021169818217, 0.03954409884529249, 0.06072623076878729, 0.05126040624154191, 0.048627944272612376, 0.04646764527405462, 0.05309720546187413, 0.04789852897726721, 0.06174564481742921, 0.041930638929648746, 0.14195049992732464, 9.16019445465457, 39.54848966290874, 54.71343178902903, 48.02479828557661, 33.2379412651062, 31.170328547877652, 31.548294021237282, 55.95396764816777, 63.01118627671273, 62.626315470664736, 58.590110271207756, 27.152962492358302, 8.62062733019552, 0.6101318508867295, 0.14269746629701507, 0.05626392182743838, 1.123469656994266, 3.4444004393392995, 9.22404573809716, 9.002247471963207, 13.400642371946766, 8.425702202704645, 14.322515072361117, 14.601570137085455, 18.80169314722861, 37.5426640818196, 37.60937183134018, 52.05486889808409, 56.40254559055452, 62.91395072014102, 62.33382432691513, 64.56751215842463, 59.88679878173336, 60.587738098636756, 61.26238576827511, 60.259933856225786, 56.85116667901316, 53.82155933687764, 55.00014920388499, 59.27916480648903, 60.57758308226063, 62.39195777523903, 58.60630966001942, 59.725589367651175, 59.88863837334418, 58.83933767195671, 58.557629123810806, 60.677058312200735, 57.69968125127978, 58.726695045348144, 56.93590556421588, 54.15674547995291, 48.27473171295659, 45.992077012215894, 45.74022946819183, 53.45047958435551, 57.139100028622536, 58.70008960846932, 59.1989052680231, 59.376012048413685, 58.31209659576417, 63.30075133231379, 47.04884590641145, 29.237541421767208, 54.64334687879009, 55.7449798430166, 57.235037280667214, 52.805771366242446, 59.86936776868759, 55.31880647905412, 60.938080280057854, 61.092864851797785, 62.09120219753635, 59.53430714145784, 52.11218257104197, 42.67514821021788, 48.55689917841266, 54.84174428447601, 59.842095528879476, 58.9890427743235, 56.91126523479339, 57.15791956070931, 57.66761979749126, 57.61100038405388, 60.24253814451156, 55.04304816645961, 47.00248741334485, 43.4500555838308, 53.83289890904581, 57.35610908077609, 60.53234246469314, 60.19713670976701, 61.94205014936386, 57.73463741425545, 61.50815363853209, 56.416191516384, 51.870529267095755, 42.105219979440015, 40.70296872046686, 20.81451427552008, 12.87743055051373, 13.705103608869738, 8.696349666964624, 10.51433195990901, 7.657849702142901, 6.1268780212248535, 5.232981626064547, 1.5748126252043633, 0.7251383183944611, 0.3949319613316367, 0.03166005435970522, 0.16872910332054863, 0.4739210502274575, 9.129969650699246, 31.293324270556052, 47.61431832467356, 26.711405592579997, 17.127096037710867, 20.32931120164933, 36.47129220347251, 47.546779032676454, 55.52692351802703, 38.5477832055861, 14.899101526506486, 0.5968991835271159, 0.050040288648057374, 0.060552217727226604, 0.06916283915239958, 0.06711086498633509, 0.03974162695568897, 0.03897973336279392, 0.013322828247422173, 0.10903047608031381, 0.09754338602144873, 0.010466016472257193, 0.07314614395821288, 0.03691432201453755, 0.03776551464632635, 0.0728340550596195, 0.040552960032777446, 0.03918086974731377, 0.001093030908621938, 0.050453007025944616, 0.07755538598904688, 0.0334677652215525, 0.05736835631391695, 0.014809243749046038, 0.025403165303531195, 0.025127643696783532, 0.07242401415902762, 0.05280135379683587, 0.024692839004039287, 0.03090590783094447, 0.07567526832703622, 0.03314923735395555, 0.026261266133177186, 0.0998506436665212, 0.04829261992727557, 0.017935504926548853, 0.041662895030552344, 0.031173908369495507, 0.015992895557334828, 0.05149991980062858, 0.026359672042270823, 0.060898409029769326, 0.05465126461199215, 0.09946834280966751, 0.04609105943311607, 0.035860100761055946, 0.03088083760362239, 0.10571504672688824, 0.061383365668476596, 0.03173411782500485, 0.08995372997296434, 0.023085622928075256, 0.17780565176038973, 10.73192838699587, 47.66181038271996, 65.58598695262786, 55.81793985059185, 39.97758911501977, 35.453311627910985, 33.00012403918851, 40.10611734082622, 62.0566382715779, 77.2590821789157, 65.44243212669127, 28.47404814535572, 9.870710238333672, 0.7498945415981355, 0.16205437841915316, 0.2676226120562323, 1.4660468937889224, 4.172882149296423, 14.133542141606732, 10.658745784913341, 11.94198448811808, 15.772433915445882, 12.869021969456828, 16.685395971421276, 19.254987739747573, 29.04527860303079, 35.368094213547245, 51.63547731214955, 57.42570761711367, 63.61227773850965, 62.11827439646568, 64.1619037812756, 62.09424987916024, 63.489676214033565, 62.32933321306783, 62.40156365979103, 59.52476793719877, 56.27562553651872, 57.53229410417619, 61.44401504147438, 61.600784332521506, 64.30019478644094, 59.51962963227303, 59.90840319664248, 60.8089990000571, 60.633684742835264, 59.4536945896764, 62.508703201047844, 61.11885055418938, 61.58221975449593, 57.95844001154746, 55.42099206678329, 49.77902343196254, 48.70709849942116, 47.18602295844786, 54.785768139746885, 57.54071935530632, 61.25676893418836, 61.63971777885192, 62.00684378224035, 59.53342460816907, 61.520010963563, 49.72769137351744, 35.08349487858434, 58.14019480059224, 55.07754541212513, 60.14780113773962, 53.525443923088815, 59.225240061360026, 55.16229214206819, 60.08053641165457, 62.10021188182216, 62.862485301110056, 60.95288722745834, 53.60127118326003, 44.20785750112226, 51.36941117625083, 56.696052628178755, 62.17711387142059, 59.37207791113085, 56.46932786510837, 56.551983971749586, 58.88539022014987, 58.4027974836288, 62.5607491308643, 57.04208412478047, 49.79042183968329, 47.13666777456961, 56.6062185841222, 60.76322494014617, 61.22191867520733, 61.72564121984667, 64.01009628849646, 60.38675192863711, 63.51597178366877, 57.16692140025478, 52.110746983558904, 43.55106838287846, 33.81634181545627, 23.723534230263006, 16.862141893756007, 13.085279887722386, 13.002682616633754, 10.740526222413587, 10.546952351447075, 9.706555124252073, 9.089994815088088, 5.984140028876643, 2.192032015131366, 0.6758971283993414, 0.021301065158519535, 0.13737640343606472, 0.9236192583076416, 10.243661942020541, 36.054277573862386, 46.251259388462195, 29.752323089107392, 22.72966250296562, 23.96503652295759, 42.2474725784794, 54.61832215709072, 62.82248497009278, 46.66261403791366, 17.586886075235185, 0.9785255152852306, 0.024244020647940137, 0.06129330054165856, 0.06003942911423022, 0.0074378585991179275, 0.028750086616304134, 0.03188972177374507, 0.022616049334887537, 0.03328011581493962, 0.07251935380120432, 0.040057182402139714, 0.11199961070932689, 0.024354419663488388, 0.08886459809277328, 0.028387931956639214, 0.029195413526688373, 0.05611361154625493, 0.1072028047975994, 0.047647773077891725, 0.04215907485735032, 0.12745459188496874, 0.04024886526167393, 0.11454944243474353, 0.03483943798909745, 0.02293587763673596, 0.1054041835689737, 0.03447522446813603, 0.07381987998322134, 0.13678217967671735, 0.16367086990466043, 0.1106390079122878, 0.16643683035527507, 0.27771775100019674, 0.1426982017414224, 0.11743708063037166, 0.20493864742738588, 0.11872393980381951, 0.1170626398356211, 0.12902789899418432, 0.1335363264285749, 0.1551164563504919, 0.11899747149718386, 0.13761890090761647, 0.16862335254348096, 0.12746624408229706, 0.15106360608291242, 0.1528019821571727, 0.17764201537976343, 0.1158118557425276, 0.1399522974726654, 0.2231785420688891, 0.36150291802421697, 14.972712647530342, 58.407625921310924, 74.192322146508, 66.09011742376512, 50.47411841730918, 47.25572347640992, 46.667132608352176, 65.99043430820589, 68.54483081448463, 71.84785089185162, 70.07696351697369, 32.8510602443449, 10.645196937745618, 1.062320028581927, 0.3255532309412956, 0.41014609978564326, 3.530360897702556, 8.045303879245635, 20.58552630486027, 21.2198971163842, 25.290497579882224, 20.506729810468613, 24.254136777693226, 21.886339187622074, 21.65393287135709, 39.65518205396591, 40.02153142806023, 56.06268005986368, 59.419550357326386, 66.31792868337324, 65.24409355655794, 67.18400370690131, 64.4457970896075, 65.9936349622665, 64.32519989628946, 64.88179599085163, 62.387415670579486, 60.26092229350921, 60.968384512009166, 64.00800174282443, 62.073484851468, 63.963404393965206, 61.27419994723413, 60.15787378434212, 61.29876575162334, 61.1882019812061, 61.02804768470026, 64.61172511500698, 62.54927227574011, 62.99126455860754, 61.228194467483036, 57.240403083062944, 53.20285251063686, 51.738580734499045, 49.69873251453523, 56.58861890915902, 61.63176713451263, 64.08414279260944, 64.85536313826039, 62.523733723548155, 60.82919528407436, 62.19371334198983, 51.60541234477874, 40.389422293632265, 62.02385510167768, 57.95813406667402, 60.288657372997655, 56.266647231194284, 59.844394037800456, 55.56399383852559, 60.60005041860766, 63.41243297823014, 64.80479986436906, 62.928416421336514, 56.97119905102638, 46.97220671561457, 54.62992452806043, 59.55776683745846, 65.12117039772772, 61.554080670879735, 56.98043231041201, 56.930190670874815, 58.932933269008515, 61.054300108263575, 64.29907298857167, 58.953290370202836, 52.16139262722385, 49.08108865061114, 58.50488501210367, 63.67973466073314, 64.43990961197885, 63.00911134289157, 66.28301958883962, 61.85840560543922, 64.72028455426617, 58.52907426895634, 55.74230478655908, 46.527664892135135, 43.98505903059437, 25.35566972148034, 17.6259744551874, 23.54603913522536, 17.568537227569088, 22.384625327202585, 18.491561143629013, 15.560079736094321, 14.062199131135019, 4.383750240648947, 3.2277507743527813, 0.9371255109867743, 0.11103311418405465, 0.3532728660971888, 1.0171297276693008, 11.964812682520959, 40.62128536162838, 60.30037741507254, 38.46764526059551, 26.107970514605125, 30.951103356576738, 50.26617788499402, 63.49086861456595, 70.00767092550956, 57.25025215456563, 23.479804031310543, 1.685466364987435, 0.11655814029396543, 0.14029256308511381, 0.1646741846155736, 0.22198249495798544, 0.09484861812163746, 0.10352002096272285, 0.14050271632450242, 0.17557751567613694, 0.16282345408633833, 0.104917824989365, 0.23169400771298718, 0.10497009516843867, 0.1750145483041002, 0.1256082816830566, 0.07747872357046412, 0.10252656580339517, 0.1726312028063882, 0.14982294201129867, 0.11063379851440269, 0.21314421518435403, 0.1636357830777284, 0.21081953669988343, 0.09031422030661376, 0.14560645536309288, 0.251265746210852, 0.1158445523751359], [0.016569022404690905, 0.03892840930230675, 0.05627756968380944, 0.035322456425356294, 0.028912229125478098, 0.06274727796534858, 0.04288787728235607, 0.03595942789087853, 0.023984280452432654, 0.0035456098069722255, 0.014102621484668025, 0.03136287736255796, 0.009635073459526945, 0.023907198600711364, 0.04913133298677783, 0.0993614582224719, 0.008866315718830354, 0.06413984578102827, 0.07837038862729266, 0.07511456857525534, 0.05785896285106579, 0.12548730873893346, 0.025449325931408716, 0.018889985362728758, 1.2958431171794094, 16.78913874010886, 42.722946213137725, 53.4526918011327, 45.039337219730506, 32.519004152667144, 23.82425677391791, 24.500438090293642, 48.55196875910605, 43.04191727792063, 23.31564891722895, 28.47797836026838, 18.221705998143843, 2.9632825140030157, 0.5656634499469112, 0.054947307799011476, 0.349853846334642, 0.2864222258569733, 5.940630157147685, 9.917015779402949, 7.541018474486567, 9.863415610405708, 18.79007116440804, 9.709609670023765, 22.934114087012507, 22.362826754969937, 27.309959280875425, 48.34337711334229, 50.499617745799405, 60.08469020166705, 62.42294449960033, 65.81329222648375, 60.242032158759336, 62.58686427147158, 61.331741117662006, 58.14867888727496, 55.04899447964084, 55.37353531006844, 57.34771913097751, 58.32181230668099, 60.57081307134321, 60.40114702716951, 59.7437067954771, 59.43787174840128, 58.007469638701416, 60.228327397377264, 57.58284953332717, 57.80966451091152, 60.31956172758534, 56.92595843345889, 53.62947694716915, 49.26213349065473, 46.32560791507844, 43.54636546104185, 46.03661160315237, 52.194379760373025, 58.15272677329279, 58.30621304050569, 55.93004119011664, 57.93581578039355, 60.605922206755615, 58.42408810892413, 60.96698814822782, 48.492168303458925, 30.23757323142021, 62.52523991369433, 55.99026526174238, 58.879161496316236, 58.654527356547696, 61.85379682048675, 58.73450056199105, 59.871372099845644, 56.05000295946675, 58.81396778168217, 61.14812712515555, 54.55112803366877, 43.44162248796032, 42.3056766294664, 51.5655336072368, 56.279512605359486, 59.70997833436536, 55.871358609968624, 55.76901612743255, 59.66678127165764, 56.123021802594586, 58.463927622764345, 58.097468422305205, 53.243543178804465, 44.19260340352213, 47.91170458639822, 55.844725716498594, 56.4806439030555, 60.154033783943426, 59.60286232732958, 59.01024318510487, 59.64220762252808, 61.36753666785456, 56.86769946928948, 48.1969315005887, 40.33867074597267, 33.407709290904386, 25.752568475661743, 7.994661667654592, 11.021298304680856, 9.053955097352306, 8.042404757392022, 9.252564311027527, 8.040447984972309, 4.498868373132521, 2.7488210412763783, 0.49626679309914196, 0.05183357790473008, 0.07860990601681894, 0.24976997486045285, 4.190372978487323, 16.802000191903886, 44.002293925131525, 43.60449106462541, 20.7719212578189, 18.935767604458718, 24.756211926860196, 40.15253074707524, 51.070134332103116, 58.26103125849078, 24.958476789536018, 2.681225855504313, 0.015691169913137154, 0.010894083421707395, 0.022580949101416815, 0.020373941722115683, 0.06285291382922761, 0.05599484110491411, 0.05227363413019527, 0.04209850411561709, 0.038458333921528635, 0.03815141994686377, 0.04320243681450525, 0.06039617327792991, 0.028356227407892867, 0.02898603595132309, 0.06814589573731346, 0.027892757620241855, 0.09574667235175449, 0.012711266003128503, 0.07103515803934106, 0.03824813471686456, 0.05086268020433284, 0.07871438508793231, 0.0017876267896011293, 0.01847703332802461, 0.02756486815821019, 0.06314954690394864, 0.03662730334326625, 0.04951232000284138, 0.12465464777403301, 0.04791169036780635, 0.04005920104382019, 0.07441365941157264, 0.026897052077636607, 0.05596183803713611, 0.06091189600767628, 0.053359632710776025, 0.019280211399159124, 0.014963900621589876, 0.06917600054293871, 0.030451529591734854, 0.042105716833424185, 0.054706369316385645, 0.042857237595824466, 0.013856020654671857, 0.00950619448802524, 0.11647226949853283, 0.03600944960189443, 0.02217234078524334, 0.0371258580426295, 0.07293046722489019, 1.2814295099627588, 20.340625278411373, 51.21533263114191, 63.07967870466171, 52.55411994072699, 39.64286973399501, 31.10802169769041, 32.605060954247755, 53.535355752514256, 48.88782170511062, 38.541001427558164, 33.720800722799, 18.239790085823305, 4.089483243803825, 0.4014288159387727, 0.06656254521541058, 0.9950044955457411, 2.9064883099448298, 7.289685251251345, 16.87278720640367, 15.575779022709018, 12.280793920640024, 13.07228115297133, 10.778301588950619, 16.432115781691767, 18.048776541986776, 30.0366105956416, 43.83607172196911, 51.82337453288417, 60.39845235886113, 64.23240446275281, 67.12674494712584, 64.66189615188107, 63.023349546617084, 63.88746730742916, 60.73266575413366, 58.011431232575454, 57.69886147591376, 59.38226822883853, 59.97686424563008, 62.78729738727693, 62.39771189228181, 60.51151860144831, 59.299651345899036, 59.45173732696041, 61.06786366431945, 58.30837818884081, 59.1541471019868, 62.494241422222515, 58.98686585887786, 56.684767969193004, 51.037774778181515, 48.2880481596916, 45.72812503384006, 47.705270244229226, 53.00105048764137, 60.41085097097582, 60.783315320168775, 58.53166695564025, 59.01307905873945, 60.224989460360625, 58.42626110199959, 59.00288089629143, 49.298780195174686, 34.30224111003261, 64.89811697313863, 56.84549885411417, 58.91936971295265, 59.82161683420981, 62.35986102011896, 59.487046503251605, 58.40040876019386, 56.6293134996968, 59.76929241611112, 63.82857291929184, 57.54908969325405, 44.71569853444254, 45.10563704275316, 53.366309442827784, 57.66362682465584, 60.50796493407219, 57.6427911943005, 56.898690116020944, 58.38574301811957, 56.07905987770327, 60.559002814754365, 60.754270169042776, 55.40698136052778, 46.83852057303152, 50.14138375559161, 59.86337830943447, 59.235744168681485, 61.38129242004887, 61.79472984806184, 62.5762777943765, 62.8889181537013, 64.42116068255517, 58.23536326808315, 47.69922194942352, 37.095266772854714, 27.159897242822957, 23.769914296365556, 13.728769229304406, 14.03802360257795, 10.728474740059147, 8.294422434222314, 15.89082673672707, 9.80362888305418, 10.631343126296999, 4.532388458328863, 0.8750932879986302, 0.2509284530195498, 0.04577091511999888, 0.22575817461456024, 4.753101208517629, 18.714608684662853, 44.84002982416461, 41.87845599266791, 24.286447301987682, 24.655844357705888, 31.51253377237628, 45.92708333846062, 58.09917073095999, 64.12788898714128, 30.433997684909453, 3.3782447634204744, 0.015902575706281973, 0.009042605956745966, 0.04315492021100175, 0.036063631170339165, 0.07684895333143012, 0.03549365409379525, 0.03626487863760802, 0.026331114199673458, 0.012016741224684784, 0.0716597112196107, 0.04114860488522438, 0.035183706410950234, 0.013362240598296687, 0.04667103778751147, 0.03953727300188715, 0.04722289688464615, 0.06236431827288001, 0.030466366799608357, 0.052329416822401754, 0.03831861480589836, 0.05316625679692915, 0.05049762015621509, 0.03415427576269835, 0.04104592229029344, 0.014856898248375905, 0.030689796342724757, 0.07597000533414465, 0.1018424109826165, 0.2478617570933796, 0.11134399266372766, 0.14000832914344727, 0.1780192983607131, 0.12911483465183166, 0.1087125112873412, 0.14247341622268, 0.12588303911709978, 0.13325388513265118, 0.09080657735466958, 0.12970928823755634, 0.1366693808907463, 0.11299914860677336, 0.2307817655345125, 0.10699866534841639, 0.09848651686503042, 0.15661714598536491, 0.1677815598105231, 0.08595077501189324, 0.17744854753536565, 0.09384759401361789, 0.1436557963250145, 2.011446214972004, 26.2749909200976, 61.94740810701924, 74.19982956301781, 62.08233371857674, 47.22373654765468, 36.541843875761955, 36.88904423867503, 60.553472272811405, 54.22787766302786, 37.00907268831807, 39.594785398052586, 22.85838096372543, 4.3521893793536774, 0.8616225205121503, 0.14507779340830543, 1.227834856798572, 2.8316882204624916, 12.94266741121969, 23.237436855992964, 19.99384657029183, 20.228476870444513, 30.10701910141976, 18.918458184888287, 30.94523156842878, 25.524672885094922, 30.388215780258182, 49.641477677129934, 54.11041444347751, 59.77716069067679, 65.00767269442159, 68.91118803331929, 66.52321769345191, 65.45048083028486, 65.06188377257317, 63.82441520690919, 59.670068217862045, 59.26700545895485, 63.08730771464687, 62.8937348242729, 63.0227376568702, 62.904329146108324, 60.52000268813103, 61.11544593687981, 59.72416554727862, 61.9348329882468, 59.1828941529797, 61.196340899313654, 64.41873665778868, 60.42157473102693, 58.480456490670484, 52.68284428504206, 51.52138733094739, 48.58974510623563, 50.892992250380985, 56.985582382448264, 63.59498008604973, 63.297260422860425, 59.64160357752154, 61.825351791997115, 62.950644493103034, 59.28975520595428, 59.97112974043816, 51.13999566724224, 40.27109223027384, 65.94148312845539, 56.45861194979761, 60.271842172068936, 61.442740271168375, 65.6049123887093, 63.3247366259175, 61.78286075592042, 57.45001454507151, 60.550138258164935, 65.72666275885798, 60.253869871939386, 47.473148299801736, 47.26145798160184, 55.36276448157526, 61.215595814489554, 62.923580138914055, 59.20125476775631, 57.086187254997995, 59.00987448230867, 56.78120728461974, 62.46030115312146, 62.96992294249996, 58.67822631712883, 50.452886627566436, 53.49794026344053, 60.890960847177816, 62.29212560961324, 63.703668963524606, 66.14418337422033, 64.48621319186303, 65.70682341052641, 66.86202418419623, 61.563741468614154, 49.6968811558139, 43.248539893857895, 37.23855879998977, 31.359679006761123, 11.667732365669744, 18.310229970562844, 24.673940212495868, 23.424653545502697, 24.215317080097815, 19.914824539615264, 17.506308824785297, 4.447713801937719, 1.8747708585954483, 0.3581297409630591, 0.214577351186064, 0.4815552083234634, 5.495578425545847, 21.547438559993623, 55.294330889178866, 55.99625079862533, 32.63752052860875, 28.514550539755053, 35.99453203139767, 54.14439001391011, 65.54096598779002, 72.73204726557579, 37.43091967798049, 5.106174340171199, 0.11989139651338901, 0.11647609993815423, 0.10276195397900958, 0.10562438022104964, 0.2994701434527674, 0.16547008868186705, 0.09568120247774548, 0.1007981412112713, 0.09510868198929295, 0.19000952432472862, 0.15109498504429095, 0.10487849403533245, 0.11996329386508274, 0.13735219505765747, 0.12904076927131222, 0.1155006018797717, 0.1996434936600347, 0.16161180942529635, 0.18017321584686158, 0.12121376386212727, 0.2140575605294397, 0.23048950299139948, 0.11557987665817623, 0.0996322626428258, 0.1211981816337474, 0.18698364556316407], [0.007410849690542467, 0.026039414731184804, 0.03642619377182376, 0.015003342658371456, 0.034744634608467745, 0.016692490880227378, 0.022931623933536392, 0.04790738495367189, 0.04963457231379805, 0.027402708412057934, 0.05003764947515823, 0.021804105302679445, 0.034846777111412056, 0.04985275798507276, 0.08405275387509216, 0.04117256428505625, 0.025347369204786037, 0.07732228075544681, 0.02001516167975722, 0.009175155447014879, 0.05823905737469754, 0.0620925102773453, 0.04630929106966623, 0.07287405251014618, 3.0682561714803023, 23.323168100849276, 39.300654703570956, 56.25898291987758, 49.55726831190048, 31.203817744408887, 21.543975107131466, 18.96284764812839, 12.498529591868001, 29.793747240497222, 36.98864498446065, 34.31503195916453, 7.546207770224541, 1.5579852894429238, 0.21153327017541856, 0.15869142097090522, 0.9943086425623587, 3.3956696477628525, 3.0614783158225403, 14.18562533393983, 9.67994184263291, 8.775942402501261, 10.424446925040215, 12.059915450311477, 22.064948235788655, 26.539427311189716, 44.22412749259703, 48.51259208494618, 59.337863076117735, 61.28770074536724, 64.31802195887413, 59.70427520813481, 63.28429306707075, 58.88196206861927, 57.19525660237959, 56.43670943475539, 55.27349918119369, 56.27460572027392, 60.32956377152474, 60.267688382056456, 59.43408273881482, 57.71896362304688, 58.21954434917819, 56.7622269353559, 56.52341342741444, 55.98170665002639, 56.97224240149222, 58.68639661419777, 57.858266599716686, 55.84423934259723, 50.17728128740865, 45.479427153064364, 45.62637482920001, 43.3606686899739, 47.55713408993137, 57.43004575852425, 61.979367579183275, 59.93206685589206, 59.678952386302335, 63.88894604098413, 59.89296082527407, 57.18528201503139, 62.534430027008064, 51.01805702332528, 28.51085174468256, 69.58447071813768, 53.02042699629261, 64.11121891390893, 58.008026615265884, 61.75032469534106, 56.98116971600441, 59.907540275204575, 60.90935676328598, 57.84691918280817, 60.533829042988444, 57.474996120699, 46.220519773421756, 42.77699255174206, 49.31176716281522, 54.82881223001788, 58.3443384785806, 58.37313259801557, 55.60738309737175, 55.258056809825284, 55.83749286590084, 59.14237999146985, 59.98372839343164, 55.3739667707874, 48.056718534038914, 47.635063740514944, 49.23564964725126, 53.375793733904445, 54.19853441176876, 56.40664446738459, 54.612273862285, 56.15480084573069, 56.974478152490434, 59.342871942827784, 56.26712183798514, 47.87510887269051, 37.743230558210804, 39.37039052286456, 28.692528086323893, 21.199920485096595, 5.506943002823861, 5.85064608243204, 10.908138905802081, 5.38644681053777, 10.297950486983023, 3.833181848449092, 0.8336481764431923, 0.26235765747485623, 0.09372904956821473, 0.150023840908562, 1.2159906471929243, 10.738795476575053, 30.407580521798906, 46.68932537878714, 32.36768107260428, 16.530225046219364, 21.86232447624207, 40.419977557274606, 51.15393184846448, 53.4078198863614, 34.76889725654356, 3.390160433707699, 0.3131185207636126, 0.039437497710628856, 0.12476900171849037, 0.011235452200766775, 0.0350126926036131, 0.05888800662491591, 0.04997888287048667, 0.008821955397574893, 0.07932771508011126, 0.04888592055067421, 0.05007954682373712, 0.045246217670219566, 0.0693395066886179, 0.05691175641972692, 0.038745973124018604, 0.05179452274235026, 0.10069776071055282, 0.06043733901254112, 0.017836273557716803, 0.03519689844500634, 0.010836827925466483, 0.057947821389403076, 0.019753600110209758, 0.026868432948005297, 0.04320223380120532, 0.03441582967136656, 0.024058221343664393, 0.06924449646424863, 0.07958548834487315, 0.043683279561059135, 0.0408554881540758, 0.0538336189704076, 0.039647290888693065, 0.02438188008513422, 0.019011875697141214, 0.05322912963287485, 0.05997946741239679, 0.0268782407886559, 0.014935388744267968, 0.02791862840944481, 0.0770525488581869, 0.03779372200369835, 0.008461517732470267, 0.04888407427877669, 0.053126443207504294, 0.011189399782808558, 0.049269638670187806, 0.01587601448033726, 0.07260763011271916, 0.1346625676078181, 3.911180385658818, 27.87488845086867, 49.63089120003485, 64.61083081460768, 55.23352238439745, 37.15791879161712, 25.9817192246837, 26.002488174746116, 20.232342366249334, 33.47120069688366, 39.635629038656916, 31.29045701796009, 8.097685662008102, 1.4947067946195605, 0.0531786865735006, 0.2775614077766096, 1.5308847759039172, 5.886803961569264, 11.545713313164251, 16.65203425192064, 15.385819615856295, 17.216657477040446, 14.801510014841634, 13.229144580902593, 19.458950988708004, 29.19380307197571, 43.615532536660474, 48.76287852564166, 57.83883125551286, 61.440084826561716, 63.68109572318293, 62.05170392990113, 64.73575830459595, 62.30294742891866, 59.358486898483775, 56.83431225438272, 57.65235001041044, 58.78140034214143, 61.57819148032897, 61.29474139982655, 60.238556938786665, 58.41521178522418, 58.44966980718798, 57.756292819976814, 56.95719618951121, 57.322655185576416, 58.93356477060626, 61.04302329401816, 59.31094384962513, 57.94914399423907, 52.148668458384854, 47.37854073124547, 47.311252470939394, 44.73829923137542, 49.65757900668729, 61.16800177481867, 63.4324017647774, 62.715474867051654, 61.390525679434504, 63.770937611979825, 60.95390704370315, 57.77547713248961, 62.18206390257805, 53.36143785907377, 32.7962000139298, 71.28377483737084, 53.36890212951168, 62.88504677434122, 59.940170472668065, 63.11561546018047, 59.10760817989227, 64.31609999748969, 60.285766586180664, 58.18732207821262, 63.32420710594424, 59.08384253901821, 48.111588570379446, 45.75270652770997, 52.07334718396587, 57.251381797175256, 60.426575752996634, 58.90698286794848, 55.09259946884648, 55.83726144606068, 55.75939455339986, 60.15655194559405, 60.081262050136445, 57.626270171134706, 51.15422210385723, 49.18589045924526, 50.8395891804849, 56.31332343624484, 57.49197606117495, 58.51389469638948, 57.1244695878798, 59.77879631903864, 59.04053564994567, 62.39933575353315, 56.08830098182925, 48.422475630237216, 37.210972770567864, 30.984761215025383, 22.232760960055938, 13.93972606428208, 6.9493362884367675, 8.565142462330481, 10.649520370268053, 11.153550820965922, 13.26344668865204, 6.858972724406951, 2.412158370979371, 0.47615076445283433, 0.18699069357206746, 0.1624630863267568, 1.4534063204642267, 11.684409303049888, 33.80587300946636, 49.69434730468258, 30.4225855488931, 17.509713442094867, 25.36316537087964, 44.96157623106434, 57.409480771710804, 60.12729890884892, 42.95631547128001, 5.646468574000943, 0.40584019535491545, 0.026491025477767955, 0.027993572875857357, 0.022959308435900078, 0.05249360095589392, 0.027326722066068364, 0.06898558172847956, 0.023662611624346148, 0.0699631022589822, 0.039878266397863626, 0.019971523396370393, 0.013217139714998345, 0.07745506677536235, 0.06932043876018255, 0.051889498492762934, 0.05727453352583032, 0.05400423058158448, 0.05708008508888945, 0.043761631203514915, 0.018712975002164324, 0.0342887663282454, 0.03351319806590196, 0.03018747632121367, 0.04968175183861487, 0.041877372836273526, 0.031546903173288995, 0.1357132571959688, 0.15838955168522176, 0.13862891122698784, 0.1911708370091454, 0.11468533877163165, 0.1206370298900912, 0.21825586025032306, 0.10960799912291189, 0.1303009992285121, 0.14919098076080123, 0.15950768765422607, 0.12661809281956765, 0.1475522267602144, 0.12955269986583343, 0.16054089511594466, 0.1411763067928053, 0.10505002112157884, 0.127497194034438, 0.16617777006280038, 0.06495877845032562, 0.15374666049836144, 0.16285601282312026, 0.1666882910555409, 0.21264547662388897, 5.336805783933209, 35.478752120848625, 58.74307094081756, 72.76449311164119, 64.89603027220696, 46.56055004365983, 32.962720317225305, 30.824479441488947, 21.691922987661055, 42.30296234930716, 48.72073265814012, 43.550315287805375, 8.914154960263161, 2.398434242894573, 0.3893027472640238, 0.7584143586216435, 1.4026153039547706, 12.279116126798815, 16.853271453611313, 24.90375972563221, 21.856854731036773, 14.8120847248262, 19.408670125469087, 15.264238888217559, 27.751053340973396, 30.790925525849868, 50.35163456393827, 49.46798339966805, 59.70988027511105, 62.14623305105395, 66.87630161162346, 63.866921932466575, 68.86167987700432, 62.176172502579234, 63.31518173217774, 59.977393765603345, 61.02118745926888, 61.432275387548636, 65.93379528291764, 62.83016889326034, 61.529761975811375, 59.28325191620858, 58.86741792002032, 57.662285374056914, 57.76813837789721, 57.006261117996715, 61.696576456869806, 61.73277208881994, 60.747053007925714, 61.481320704183275, 53.57895681934973, 50.31542324250745, 49.318647000097464, 46.715385606212, 52.19017890191848, 63.613528974594615, 66.98491988643524, 65.60084489084059, 63.15959307455248, 67.15158923979729, 63.88836553019863, 57.62967478844428, 62.64577042671942, 54.66414328544371, 38.47014381039528, 68.04374018023091, 54.899030500842684, 63.924596463480306, 62.799088032014915, 65.68621527764105, 62.68253480234454, 65.02347592384585, 64.37510421199184, 58.511243174152995, 64.51862373659688, 61.23742380449849, 51.63662656661003, 47.57410618566698, 53.56315358992546, 58.60219509370866, 63.7510629623167, 61.06294501212336, 57.04729695473948, 55.107865333557136, 56.36952315607379, 60.370199526509936, 63.14239740371705, 59.93390644750288, 53.904631214757124, 51.33759683178317, 54.29748012173561, 58.05889975640082, 60.141799911375976, 61.408458755862334, 60.68990407451507, 62.007338000882065, 61.66179287818171, 62.6136109136766, 57.398372619382805, 49.9163063879936, 40.19614358102122, 39.203513283883375, 34.178737440416896, 27.740068743305823, 13.82681965827942, 17.381818679071245, 20.621270864240586, 15.462831431819549, 22.251150992608842, 10.655998164607633, 3.207123274764707, 0.585169090378669, 0.4821632982742402, 0.26007520575677195, 1.7271234071062458, 13.432719515215966, 39.75588106339978, 59.4081990180477, 45.64762623079362, 25.94734553367861, 33.772062178580995, 52.32643811933456, 66.40600158322242, 69.25517205269107, 51.69108475408247, 8.054740121287685, 0.6735436450089178, 0.1495779164495968, 0.2154263451455101, 0.0915453465835702, 0.2526614971218571, 0.1469187026903514, 0.20792608389691, 0.12053471884780353, 0.21268952667953508, 0.21075604333271905, 0.11481383469917121, 0.1190911717112026, 0.19728797247573254, 0.18447980975672124, 0.09929456342492374, 0.1789544006028483, 0.1522714356260915, 0.1180860796763051, 0.17270160628662956, 0.13655005503566037, 0.1243213612225748, 0.11697516025554751, 0.11435968245589927, 0.18504257794589768, 0.10351516396528292, 0.10220097077469673], [0.034303708873208494, 0.055681989948836066, 0.06173369001537081, 0.0032694193097056764, 0.10208240334665585, 0.03907678138104178, 0.022484517783948013, 0.015607045798171914, 0.07214536499832908, 0.08918109199693126, 0.01240383874955437, 0.05026108284871425, 0.06553807881690803, 0.02276844146000522, 0.06202159734863428, 0.053488270364581585, 0.07617825867548104, 0.016761996122377536, 0.022627508095014962, 0.01699554185653406, 0.05985762112803998, 0.046299588566105214, 0.03877816030815725, 0.04315732955752362, 7.517766173808806, 28.741002698098463, 43.27168580024473, 61.87291837507679, 39.66807096235214, 33.005329024407175, 22.693300170283166, 26.880814721507413, 35.183978157658736, 49.473839498335316, 47.0640843145309, 13.100705589017561, 3.9450510326893102, 0.06464453684466501, 0.13876990204857242, 0.11227762401704827, 1.6298139383715968, 0.7015871821391968, 7.755301969666635, 16.84339100314725, 14.958853933119006, 17.569943397275864, 16.12352134719972, 15.265919623836396, 20.70565477494271, 30.20762005159932, 43.90133996163645, 58.31838807752056, 57.185258480810354, 61.0503149801685, 55.508480533476806, 62.6770434841033, 60.88642266488845, 57.8741325870637, 55.730196429837136, 55.14522198707827, 56.31560625568513, 59.62905983771048, 59.403523552802305, 57.06449654794509, 57.917725809158824, 57.798242568969734, 56.34047800494779, 55.64010350934921, 57.74285870213663, 56.70272457984186, 58.31650926220802, 60.674920620456824, 54.78554848701724, 53.71753415753765, 46.193051415105025, 46.49121822849397, 45.655086578861365, 43.21211676443777, 54.78147706677837, 59.59555495169855, 63.14442526909613, 59.226738406765854, 60.44867438654746, 47.53511390378399, 51.50176371297529, 61.86995306322652, 56.62914091540922, 55.29564096081642, 27.628522419160415, 59.65424929895709, 55.44877029234364, 62.08236509753812, 57.40171447876961, 57.47292510924801, 53.02275296180479, 56.75167968196254, 57.44910455519154, 58.44340970439296, 59.176390863234005, 59.88164478732694, 46.24124949978244, 42.27301113067135, 46.72835296200168, 53.8468703915996, 56.58052313712336, 60.755642998603086, 56.253181734392726, 56.26949094956922, 55.8951360179532, 56.147536616171564, 58.233802164754565, 58.88804174238636, 51.99788862659086, 48.76709115120673, 44.965886915883715, 45.72906248031124, 47.311072041911466, 51.6423414599511, 55.00047476060929, 59.28127111927156, 56.65332232752154, 60.654237962538204, 59.45059983961044, 53.14376592636109, 38.71076553098617, 38.51088154700495, 35.770686288033765, 22.723669121342322, 8.804970883554029, 2.8739456303658026, 15.538080142390346, 7.172380887692975, 10.70064748487165, 5.480578791710639, 1.3311084119542953, 0.4947089379833591, 0.06222101769620373, 0.13620295591892737, 0.2501785908375056, 3.7161344001370096, 20.321831241730724, 41.74647215873965, 41.40905026466616, 32.05056921128304, 30.341792568083736, 35.65896934078586, 50.51163588800738, 55.69270641573014, 45.384850963469475, 11.221219551178718, 0.8508113038636024, 0.004857190877139088, 0.05769868193554783, 0.027264609572387515, 0.08688636755030002, 0.018479197526410706, 0.055779895985559116, 0.028151819827936353, 0.03388568916688523, 0.013552643133387452, 0.04537326952202186, 0.03223596861766231, 0.033336055555170586, 0.06045975474520557, 0.041145103863410415, 0.050516768523882476, 0.03959911928001431, 0.03447897063808576, 0.020576006988243713, 0.004131173181738104, 0.08244255963232248, 0.03789538953212961, 0.03760775416007927, 0.06945928453557915, 0.022722466608449336, 0.03061049475124286, 0.06620115855888975, 0.007873384850925856, 0.04057014338491906, 0.07220746408547125, 0.07443037545008045, 0.0621346949088958, 0.04179932762898746, 0.027362730113729358, 0.023905995842670242, 0.03880308497877371, 0.0879474759342209, 0.041787656279461044, 0.036383867414007266, 0.07967474524893108, 0.01428860369243569, 0.023482437320654432, 0.02821354353199563, 0.017234944332871708, 0.0474283310224212, 0.028153252412354755, 0.09015816053555858, 0.11396938364111608, 0.010669271089887668, 0.0898794654095846, 8.365785056544889, 33.764613597623764, 51.19812911556613, 67.68722026578843, 48.71408031832788, 39.025535737314534, 28.226740744806108, 25.835991405671646, 25.48601596586166, 42.24133406915973, 40.33006114344443, 17.27013114959963, 3.727075116288278, 0.24424628174353033, 0.05935632766434743, 0.43650914644522054, 2.135513602725921, 9.470999144738721, 11.797149008320226, 12.867687383005697, 15.727097199809169, 20.24693162210526, 8.812543999764229, 16.443737764512342, 19.665571643460183, 32.76672732445502, 46.25012582348239, 56.32238803371307, 60.10985220632246, 61.486023626019886, 58.306146360212765, 63.47990166756415, 64.14164081696542, 61.1702649824081, 58.46901885924801, 57.39148101499004, 58.632099243902395, 61.00163052158972, 62.40001824594314, 57.95337230928483, 59.435949787016845, 59.14060315778179, 56.49250122808642, 57.78652252689485, 58.4457278251648, 58.77614436611053, 60.09704174533967, 63.42720462429909, 58.3957842857607, 55.78813375965242, 50.147012356788885, 48.694158600222686, 47.79495523821923, 45.360547957881806, 56.526504255110225, 62.16439754732194, 63.79870407042965, 61.939504531122026, 60.06413305959394, 51.953095159223004, 54.807486303391, 60.520049756573094, 59.22368680277179, 55.03148109682145, 32.526884194343324, 60.530479338861284, 55.88105078666441, 62.77880937822404, 59.68650294888405, 60.061222660926084, 55.58137386075912, 58.06642286239132, 59.61592382000339, 60.74470743056267, 61.17696439066241, 61.54445909684705, 48.56279450078165, 43.83507936231552, 49.50468501737041, 55.95134750489266, 59.25030008439095, 61.49012250284995, 56.106030095008116, 56.33452384702621, 56.08079356531943, 56.50100884899017, 60.05839855440202, 61.02600020747031, 53.64128328138783, 48.739814989028446, 47.606128415753766, 48.44635501984627, 50.8822214218878, 52.56149791902112, 57.50870104758971, 60.167228637203095, 60.69949426958638, 62.10028640685543, 60.45644460185882, 51.55748882601338, 42.27052042561193, 35.62924561962005, 28.055162545173403, 12.601294709790139, 7.819942630106404, 7.641144817875278, 16.561113711326353, 10.449655017545147, 9.30050253868103, 8.281931646408575, 4.163618491541955, 1.3875936067873433, 0.21936656516646186, 0.11683709588983368, 0.10837824414333991, 4.314958241678053, 21.851951768321378, 41.73103763211159, 37.69793110509073, 27.91398467556123, 30.804922503809777, 41.19277077336466, 56.81785006676951, 63.61628640082575, 53.06379664328791, 14.833203746426491, 0.7838091927189982, 0.023839549206557776, 0.023445025416872194, 0.021636081153466817, 0.0132369976716056, 0.052870186796832475, 0.01506762509609783, 0.022811997388940186, 0.0364136912168995, 0.018225093822806113, 0.013447020676047092, 0.023125009423482324, 0.06422568210250428, 0.024337153956894914, 0.06787210357405486, 0.0015073477768436858, 0.05682762081344282, 0.05756891430205396, 0.055191827742683316, 0.021512198990451235, 0.02211883528939178, 0.07936322325540167, 0.08743665616718993, 0.0195844785400456, 0.004643460007144078, 0.05643451811685678, 0.21051319346072214, 0.13956179181414266, 0.183352526697901, 0.11628421023488046, 0.2910181098887998, 0.10144239817295345, 0.13955583165009178, 0.17565530424396839, 0.13785952912463298, 0.16133336710833734, 0.24761477034659157, 0.1961176812408432, 0.1310036091073867, 0.1523183814940914, 0.1231603473124485, 0.19120377878988945, 0.14336580140215738, 0.13638173019693745, 0.16877952722772477, 0.09986297002122288, 0.2629548996206253, 0.17517536548116516, 0.039482363649914344, 0.20695728910786493, 10.508455268798336, 42.958868934262185, 61.48910268660515, 76.55340856121433, 57.21758665577058, 48.96565721881006, 32.59922642861643, 38.01889865629135, 49.13329931997484, 63.08441692782987, 58.12568595332485, 18.70026457694269, 4.829946814044829, 0.2687659523179454, 0.3911054134368897, 0.4728322860694701, 3.3565964669950548, 7.802617030759012, 19.65710912981341, 28.82075232844199, 25.92807689020711, 34.546749899464274, 26.909353886881185, 19.48233812086044, 24.728388594042872, 32.49502082024851, 47.36189026986399, 59.457271791273556, 60.162823815499586, 61.32617919675766, 57.43833764906853, 63.80279902488955, 65.0712033241026, 62.18692764159172, 59.67285702305456, 60.414341880429184, 61.207876589990434, 63.47760315864318, 63.010550852744814, 57.7853262039923, 58.95116052319927, 58.249095486056426, 56.46986130745181, 57.2250509262085, 59.10832205126363, 59.68041543037661, 61.460983214839814, 65.76865565392279, 58.619261326328406, 58.774155724433164, 50.63376672806279, 50.53917092661704, 49.919899279071444, 49.21425704033145, 59.737070145145545, 66.4942313778785, 66.69107944734635, 62.958293114939046, 60.3619586267779, 55.510073015766764, 56.50340933953562, 62.24933255103327, 58.66837724562615, 56.57258425989459, 37.54786906703826, 61.32452787891511, 56.01160687784995, 63.573611013350956, 61.45450345931515, 62.93579047726047, 57.80432224273682, 62.05539880260345, 61.356059812730365, 62.326893498820645, 64.12659068261424, 63.73541662769934, 50.452443399736964, 46.251918346651145, 50.97272619124382, 57.929245810354914, 62.32135511213734, 64.44836231970018, 57.60365770709131, 56.72094791166244, 55.79188746790732, 58.20246242707776, 60.3040801325152, 65.12614004073605, 56.69566823590187, 53.06989200653569, 49.0209077250573, 51.22535820930235, 52.7161059841033, 56.67016498504147, 60.63149606027911, 64.21383988472724, 61.60011752959221, 63.66792832651446, 61.00481940853981, 53.67743968963624, 41.13564145180487, 41.856176930089156, 39.396768462273386, 28.11542780168595, 13.068999109729646, 11.853474243994683, 32.269166823356386, 16.793949527125207, 17.9437001674406, 17.07140230363415, 5.07871529748363, 1.5647413269166024, 0.5111292359088698, 0.2960962922342362, 0.3578542251019709, 4.802315187069678, 27.12341723903533, 52.108017013918975, 55.11826745925411, 46.609638506366366, 42.69578772206461, 46.912186607237786, 64.87221364052066, 69.751555842738, 62.610233752958244, 19.662516117095947, 1.6094030271614752, 0.08242361427795503, 0.20146557250090186, 0.12572182357431422, 0.19275337547784854, 0.17217473697758492, 0.10750429870019998, 0.17495762797132616, 0.11265420985798683, 0.1428734366932223, 0.16667149840824066, 0.13300720482103287, 0.17281704041506016, 0.09964948429936364, 0.2064539233763372, 0.09116587259115712, 0.1732630874480932, 0.11054497061958236, 0.1678175352994473, 0.15859300931615217, 0.14450961663838358, 0.16064237112239485, 0.14276914148321077, 0.1549765686955183, 0.09314433296000765, 0.16727528294488309], [0.019183933299275178, 0.03410872034428101, 0.018419467566174366, 0.07550565646060052, 0.03506421584696059, 0.0796084403390846, 0.08591267745941879, 0.038958692757953564, 0.03737500898780362, 0.03396705153488344, 0.04301035175881079, 0.06967499957329805, 0.08822805563648863, 0.05651411465218952, 0.06931530597108988, 0.028923664902967793, 0.02188758973422791, 0.059720207937061794, 0.010535550442704511, 0.015077015418829698, 0.0432760042378739, 0.034253637366477525, 0.046790976512936816, 0.3544889847117086, 8.269529111923712, 30.97001506436256, 50.15113476783999, 54.14764950352331, 31.858867291481268, 27.020874715620472, 17.30532853834091, 36.820904824041556, 44.45039726072743, 43.40873733643563, 31.66744189877664, 9.121856227997812, 1.0124204319811638, 0.05184295482092327, 0.04450914149563159, 0.20655552195685528, 2.881959032627844, 8.612815929997353, 10.760385182596023, 10.015350580215454, 13.76407644441051, 20.594728185284524, 15.662346713004576, 27.068915905491, 24.43595628584585, 38.286965200977946, 50.382452626382154, 56.48604108441261, 62.98283538510723, 56.321234856882405, 60.87198442028415, 60.07675524680846, 61.077296964583866, 61.12189823581327, 59.28991210076117, 58.65246418983706, 58.54352035830098, 57.77122528322282, 57.52080940431165, 58.22514549378426, 57.208004305439616, 54.690101531244096, 54.995818907214755, 56.167183768364694, 56.1371462575851, 57.13915101943478, 57.9210441343246, 58.813983471162864, 53.69643180601059, 49.03099213877032, 46.018549088508856, 45.61601584957492, 45.89559847308744, 44.53639130438528, 53.40877302231328, 59.181846880143695, 57.59963335529451, 58.78950788128761, 57.18293251529817, 55.09869875446443, 53.96835404057657, 54.99787815155522, 59.4022919285682, 52.675752639770515, 24.951240016568093, 56.124018084618356, 57.3487977827749, 58.945284812681145, 56.809044345732666, 53.889867413428526, 46.79446843362624, 51.84422193035003, 58.02078608543643, 57.51905218247445, 58.9312074261327, 58.19588853466896, 46.51279518681188, 41.09091466472995, 44.203715478220296, 50.92659127327704, 56.936909690979995, 56.40143555979575, 56.53229367348456, 54.801206588745124, 54.216608693522794, 53.62843359670332, 56.949786832255704, 56.96595091973582, 55.60162113558862, 51.50366998487904, 49.23685773726433, 48.19870441190658, 51.90138263087119, 52.95366433358962, 55.7202414543398, 57.64995344223515, 59.20837386961907, 61.85401255084623, 62.33376549136255, 59.14399208561067, 55.850801467895515, 48.62991802154049, 37.60365301562894, 15.635689304720973, 9.36680922585149, 9.743578376308564, 4.783300026770561, 11.10337390053657, 9.308277656955104, 5.893606332040602, 4.178523988493027, 1.263208874771672, 0.31115322944618046, 0.11745820933532332, 0.008875506858701908, 1.2990039346679565, 12.881909897250514, 41.69192375675325, 56.85357109192879, 37.057466891504106, 24.42774872626028, 36.74894894323042, 46.17047425239317, 50.2935677959073, 47.22980053194108, 15.69287746183334, 0.9294806889468624, 0.08881186826094505, 0.054798966363793424, 0.003210692206442717, 0.02149060488708558, 0.0269931597229574, 0.0631127631922643, 0.0443109315669825, 0.04031984330785852, 0.07798146110989394, 0.08134964327778547, 0.023886226943784186, 0.031944922239129106, 0.045329338210004, 0.012742899688741854, 0.03430744355183936, 0.004567949114472516, 0.059411727312591776, 0.05824874838693969, 0.03167332108733395, 0.07942816452874292, 0.03875831480047876, 0.030252580388238838, 0.0009943489086224639, 0.009640231146477163, 0.05546918987566906, 0.0786433457547138, 0.014259298914112152, 0.032329205348486864, 0.0594406547926126, 0.02371093836582957, 0.06479076004677242, 0.024524581198009755, 0.08603134447888983, 0.04238553044776763, 0.017300220769679835, 0.06695306619569179, 0.0537171621145981, 0.06101235311718718, 0.06513478715092906, 0.028320010601272507, 0.03071207034912321, 0.038374512411293485, 0.06219757157528113, 0.04700528577931466, 0.027999929490409074, 0.020736010196889122, 0.02846527427825476, 0.050867770858589685, 0.22332176986721256, 11.174333499323938, 37.49778039993779, 58.50244922022666, 62.07241796678113, 39.02029545076432, 33.2645780809464, 21.161326323786092, 40.78957073150143, 53.153548317570845, 47.454466050670995, 33.29310155683948, 9.185127000654898, 1.1795372419780301, 0.066826929818959, 0.17303903737375814, 1.0721182318464404, 5.159398942224441, 10.362228328181851, 15.70828257068511, 18.970721806249312, 16.767993242509906, 15.98589518377858, 13.209220901612314, 16.480271700889833, 24.77666904849391, 42.19037071351082, 49.55136514479115, 58.31505406287409, 61.6021885410432, 59.10185014047931, 59.6463143440985, 61.048914694016986, 63.17974621249784, 62.06796607663555, 61.20156549638318, 59.12553733394992, 59.83356829612487, 60.24650758312595, 58.28470668485088, 57.801062753123624, 55.788188672834835, 55.5083393281506, 56.431324020508804, 57.53647927315005, 57.90067526601977, 58.576491801969475, 59.969192089573035, 61.10569100226126, 55.46287121311311, 51.036762806677054, 47.84132549839635, 47.040244148623565, 47.10212346046202, 48.2367161012465, 56.215887838794345, 60.249982803098625, 59.980029598359145, 60.10710654720184, 58.83743924479331, 56.98082454742924, 55.494865986608694, 56.88566392467868, 58.42420185765913, 54.54433448853032, 28.490671150145996, 57.5220057272142, 58.06735246412216, 60.02012798863073, 57.607909556358095, 55.317543475858635, 48.57523233659806, 54.81189504746468, 59.602732889113895, 58.48335512222783, 60.19663856875513, 60.73038685706354, 49.11684497710198, 43.99957964497228, 47.454375836157034, 52.86387343560496, 57.97941684722901, 59.087125562852435, 58.076879901270715, 54.28182594237789, 54.585346791052054, 53.41420158263176, 58.37680785886703, 58.49951528733777, 56.67980617092502, 54.66821470568257, 48.894336761966834, 49.35131642126268, 51.9720676637465, 55.10581001158684, 58.48000541810067, 59.356086407938314, 61.59147262573243, 61.44063003601567, 62.87991631415583, 59.83610999199652, 55.36533363403813, 45.25899387175038, 35.46096417211717, 15.434075555493756, 8.609262262621234, 11.878084175048336, 10.956377194773767, 12.011835036739228, 10.90890278739314, 11.740275621414186, 9.106262845377769, 2.767268438493052, 0.6910241779781158, 0.15754207457986572, 0.10665135938794383, 1.591902514619212, 13.417660555531903, 38.76215642498386, 50.47625218668292, 39.99633412207327, 30.506530154135923, 40.81630168422576, 52.07544172963789, 55.7386883612602, 55.689548907741425, 21.104683376127674, 1.0020258445893566, 0.11278847442759622, 0.11865814817288231, 0.009990266295179967, 0.06809825272930246, 0.11206810663063681, 0.1006633940062696, 0.009138672424840831, 0.04968921736543698, 0.04123803798950488, 0.07250201723147785, 0.041454170545142506, 0.02424351119947049, 0.038888231821117863, 0.01724205171358922, 0.058136194749104406, 0.07703458409636252, 0.04854772337562135, 0.0730259141193763, 0.07309820983679065, 0.08947296383520288, 0.07231465510783658, 0.05613313529700522, 0.01998784489959719, 0.030714341799818703, 0.14251800253987312, 0.12406604710004984, 0.18312706702178527, 0.06978369212799496, 0.1837206013020008, 0.12183411121969262, 0.20087922412541606, 0.17326814362839346, 0.2795237266728955, 0.13069956413199826, 0.13066599415915628, 0.17315391991888324, 0.17685899691235635, 0.21212904143237302, 0.1565592450600478, 0.16816307159681476, 0.08111876736004507, 0.08377676303949087, 0.09689463978453029, 0.2433652653088493, 0.12040787767018042, 0.3011229321841271, 0.11013640826868434, 0.12638882568646825, 0.6708964741518421, 12.871163583570912, 45.07779998164023, 66.91565082919213, 68.54395220356604, 45.73651106126847, 40.384111404418945, 27.30610751336621, 49.052290608806, 57.97919327212919, 55.61043470136581, 38.989359717215265, 11.82648245365389, 1.3139920465407835, 0.15566600186209525, 0.22470279656831296, 1.2609350032383397, 9.34760824326546, 22.244267232956428, 21.027761774678385, 19.04270906602183, 24.73076358918221, 32.71644057766084, 25.18323644515007, 33.43121605534708, 28.309579241660337, 43.10381620160995, 51.75864365793044, 58.520350917693115, 62.24367257087462, 60.16541650218349, 61.386599386892016, 59.930560665745894, 65.67578961772304, 64.29499372359246, 64.35438625274166, 59.52237921376383, 61.49396250324865, 59.36056183230493, 59.04881185100925, 58.58570152713407, 58.39064205846479, 55.21962150450676, 57.904550567750015, 59.1291537592488, 60.86697555357411, 61.061446666717536, 63.22440631927983, 63.9185756252658, 58.69155060860419, 52.98914609416839, 50.08431719195459, 49.29565798851752, 49.03812300774359, 50.01055309849401, 59.26598172033987, 62.6124930381775, 62.121851598062825, 61.23922025003741, 59.91628323831866, 57.502029095926595, 56.353574798953154, 57.46122075665382, 59.004171356078125, 53.87742173287177, 33.93651931516586, 58.32267130574873, 57.681218654878684, 60.47962188720704, 60.967674563007975, 58.40220128336261, 51.92415198972149, 57.42840228542205, 61.93242857533117, 62.21936564291678, 62.499073782274806, 63.75017258428759, 51.862700216231815, 46.860285805117705, 47.61260032653809, 55.2308237937189, 60.254356245840754, 60.8838221334642, 59.07662145553097, 54.93966625582788, 54.72222574295537, 52.91449946741904, 58.90696325609761, 59.950309799563506, 60.05329555080783, 56.885903189259196, 53.3022806721349, 53.95279007573282, 56.337669587904415, 58.923590183258064, 63.01549696153211, 62.117125142005186, 64.97329704223141, 61.76039734194356, 63.832832613298976, 60.047333548145915, 58.551447468419234, 50.05124768903179, 41.9695177385884, 22.267779880954375, 14.52475247844573, 17.773857616609146, 10.671279718798976, 20.53941099874435, 23.8824470966093, 16.987567524756155, 12.378072623283634, 4.3384051899756155, 1.0222267864211914, 0.43207662300236765, 0.23206191377774363, 1.946191213303997, 16.25781349597439, 47.38341231499949, 65.84480454844814, 47.04624145261703, 37.36593777133573, 50.38664564009636, 59.95000385469007, 64.7775629258925, 65.87736022087836, 29.54429626464844, 1.7608944014195473, 0.248404331204872, 0.1925045960853177, 0.10018533215888085, 0.25688181420968426, 0.22131927732017734, 0.25245675246321386, 0.28942339062210054, 0.17605273533732663, 0.2967573035388224, 0.17272673397054597, 0.08846383451694444, 0.1132186481188382, 0.07776259745080626, 0.07816023538790404, 0.20538163010872182, 0.2172930103035704, 0.13863199090044345, 0.17891050376478704, 0.10144111114524065, 0.1844095748158232, 0.20912180925088547, 0.09119345941731045, 0.08098038123740305, 0.2647590060387888, 0.13270957966244992], [0.05723498040629972, 0.0165499429849367, 0.1062243802833461, 0.04616570321001834, 0.06471459558534046, 0.003510204095941698, 0.017578684154056737, 0.02630771021358669, 0.03333467659690688, 0.052227906341994965, 0.017065753814794363, 0.018378489523104603, 0.04890662024638826, 0.055183416097274715, 0.028503992361947898, 0.03723437822754345, 0.05002670590915988, 0.026192915768572883, 0.01869176777320043, 0.009434788390212964, 0.05104466822118529, 0.02207253485046808, 0.05637610774307002, 0.2208989861631586, 7.620732803498545, 39.10943915767055, 54.17148966943064, 54.51732504752375, 43.353388770934075, 25.551443061520978, 18.899919102268836, 15.868109349281559, 23.232327968843524, 37.89797982861919, 22.880365848541263, 4.756899533733245, 0.27957370624907557, 0.14508807430824927, 0.06810559951249631, 1.5341843472373102, 1.8090118323602986, 8.425813009662013, 14.193410258139334, 14.091017765383567, 16.296722427491222, 15.420531611288748, 8.246788190257165, 18.9903611137021, 32.228105491207494, 48.583159446716316, 53.013507935308645, 59.07695877936579, 60.39072528962166, 57.19663335431007, 59.20543993673017, 58.06055499661354, 58.18720832947762, 57.737736086691584, 57.429916320308564, 57.564104526273674, 56.56288816082863, 56.610639095306404, 57.26153289118121, 56.953230673267, 54.373260313464755, 55.22666608133624, 56.01478007531936, 58.510568526483354, 57.65833946966357, 55.960478782653816, 56.69871983989593, 54.926855794845096, 50.596998430067494, 46.07215219928373, 44.445753174443404, 45.5805693903277, 44.28058216648717, 44.30290045276765, 49.181136546596406, 57.591349309490575, 56.972442442371005, 59.227860204635135, 58.66650235268378, 60.4278269890816, 57.84473050025202, 51.45218887636739, 56.3982976636579, 52.54235675258022, 20.928039435417425, 55.368000845755304, 54.988884156750096, 59.71492836552282, 58.33076707778439, 57.094318328365205, 48.846358330019065, 42.5469926095778, 49.16376044673305, 56.78869508927869, 57.83977654672439, 53.49071133521296, 45.48891536651119, 39.38834321114325, 45.172744874031316, 49.67286840561898, 54.751949464121175, 58.69774795347645, 55.91602263912078, 54.979599906552224, 56.649345044166814, 55.951924093307994, 55.442216011785696, 56.56149571941745, 56.40744070852957, 52.84796430218605, 53.593693164087114, 51.07189547631049, 55.03425421253328, 54.69606353390602, 60.71099858130179, 60.05324848236577, 61.929341670005556, 59.66963283477291, 60.63244135149064, 57.3334534706608, 60.142019564105624, 45.449173911925286, 33.72081248990951, 18.413853106960175, 11.955956951264413, 10.238860960929625, 12.379532725580278, 10.32205149050682, 6.008514617719959, 5.550649973653979, 6.994422462678726, 2.1619239016886684, 0.4154112995151551, 0.12799422421883191, 0.05312024555619686, 0.2788426438646932, 4.909220366708694, 24.795349336439564, 46.07316809315836, 36.570241835809526, 25.00879687647666, 31.495961758398245, 37.79015387258222, 52.60129820915961, 50.814215367840184, 26.62604501170497, 3.106802774052466, 0.13441628566192043, 0.04142488683423689, 0.030041253119106257, 0.08957961859602122, 0.042549940577197465, 0.03997683510064118, 0.027167737754362247, 0.04698097397903762, 0.07285933596112075, 0.05440119819174852, 0.05812857217425781, 0.026377726819426305, 0.03213820430720526, 0.06966436627290903, 0.020772834128189473, 0.023446283716287826, 0.021401154545826778, 0.015812991299636422, 0.049901783781787085, 0.018333458874915397, 0.038004671974528226, 0.006296573847066612, 0.06356893024677712, 0.013685626420943488, 0.06546768299754589, 0.010723787821799276, 0.0880878232419491, 0.09802529363021736, 0.030241512332952795, 0.03641692410793997, 0.026569719944569855, 0.017818822074801694, 0.06132390575423356, 0.07769964800606813, 0.03609849200133355, 0.11513945271050739, 0.028870165152775667, 0.007991728677053847, 0.0491955426461514, 0.03638345755696778, 0.09454193014291026, 0.03220567367069664, 0.017678505410590482, 0.036413549490633516, 0.056907286296688744, 0.028482712354631196, 0.03415630589569769, 0.02004864546770771, 0.418789685974198, 10.07198372194844, 46.58294285497358, 60.54228175070978, 60.07662973096294, 48.43436433422951, 32.211978666244015, 23.792936648091963, 21.62658218414553, 30.1803203552, 40.011890242176676, 22.42368625056359, 4.587658576426968, 0.44758484728874703, 0.1347725778337448, 0.6619383935486117, 2.5788235568231155, 5.7350008814565605, 13.8383553489562, 16.962754611046083, 14.406350831831656, 11.020946271957891, 16.040960358035182, 12.128838358386872, 18.008542829944243, 30.341525846912017, 46.30487818871775, 53.25870706189064, 61.335396766662605, 61.132159156184045, 60.098394963049124, 60.60270194084414, 58.09967279434205, 59.37495693083733, 58.63931640501946, 59.7251892858936, 57.94576683352071, 56.472967824628284, 56.415560014786266, 57.51902864825342, 57.1473801520563, 54.79165561737553, 55.700296202013575, 57.4589850056556, 60.43596198481899, 59.07435432557137, 59.40214287850165, 58.207824307103316, 56.406063956599084, 52.78461410153297, 48.19172259299986, 45.3531386006263, 47.020616608281294, 46.42935852850638, 46.88797773853425, 52.16789199459938, 59.524579663430494, 57.565210634662265, 61.37394582071612, 61.40714868422478, 63.097458808652824, 57.338560396625155, 53.348835283710116, 57.63198898684595, 53.561631710298606, 24.366516605500255, 56.062228987293864, 55.27505243978193, 62.31791127112604, 59.759494335420676, 58.60045748372232, 52.03375477944651, 44.826595706324426, 51.89019995350992, 58.84438576236848, 60.47143197828724, 56.496270625822014, 47.227494178279755, 42.754717411533484, 47.5159413583817, 51.83263132649084, 57.72433727018295, 60.321848469395796, 57.09941740958922, 54.75178472457394, 55.98897872432586, 55.22226125963273, 56.85874077581591, 57.73757526951452, 57.195240912898896, 54.66896780075566, 56.78306648808142, 54.63528640808598, 58.44719871397942, 56.44719785259616, 59.54476025796706, 59.86304883033999, 64.17314529418945, 59.60420377792851, 60.70609169621622, 58.51417318467171, 59.846782761235396, 48.103622236559474, 35.851679309721916, 21.94058752829029, 14.507081220226905, 13.387335731137185, 14.193552444058081, 12.36146923034422, 9.290295550900122, 11.646710422731216, 9.546529285369381, 5.4236436274743856, 0.7337459597376086, 0.26075726915751735, 0.06637380413350559, 0.276915779517543, 6.31840588585023, 28.472583140096358, 52.7186555247153, 45.42604369501914, 34.84270057370586, 39.46996381205898, 44.3508828070856, 59.70112554488644, 57.68803965660834, 33.043124983387614, 5.043406611488712, 0.1830255603718181, 0.038830840344270395, 0.04504657132671245, 0.03913464017152306, 0.050517752946865176, 0.010411482503367289, 0.04908148747598452, 0.05570643581449986, 0.019860352547238433, 0.09520347004816418, 0.05930454012066607, 0.023210433972699028, 0.04883160874728234, 0.06751874551898049, 0.03304613341066626, 0.05702628656440685, 0.04742541222742969, 0.04622725837473427, 0.020503111807028615, 0.0628701814510409, 0.01571364501761573, 0.01730405503974086, 0.055435083641280095, 0.04841652315770907, 0.023365166496425387, 0.08564561154813537, 0.15432350938358616, 0.16070857644081116, 0.1601121769917588, 0.12189170570984004, 0.10878912007976925, 0.12089712440126366, 0.20604553722566177, 0.16294575236257047, 0.21074441411802847, 0.16518870458727883, 0.156848642434324, 0.12497457375209178, 0.12814440043462863, 0.1311888644892362, 0.24673522480072516, 0.25546033806618185, 0.14629204276828997, 0.09685474958631302, 0.1016663563167376, 0.17715040143699418, 0.10989255482150663, 0.185470775130295, 0.6746141456307904, 13.441374225001182, 54.5664252773408, 69.19552849185082, 69.19537159704393, 56.57059169584706, 38.65332634218278, 30.18666478895372, 25.739010803161133, 35.618647375414454, 48.69527647572179, 29.483497565792455, 6.108161451355104, 0.5818169347701535, 0.3724419794255688, 0.6550407217394921, 3.075704016993123, 8.088087622196444, 22.461541045096613, 23.74656442672976, 22.65219569206238, 24.627893547857962, 24.704609224873206, 14.660094841834038, 24.809267866996027, 35.68547671841037, 52.08283147504253, 54.24738360989479, 60.72030244335052, 61.41035326065556, 60.24318925796017, 61.37458908942438, 58.260576263550796, 59.99654669915477, 59.74936677563576, 58.88968521548856, 58.27866231241534, 56.6254460427069, 56.19018846942533, 57.87563877720987, 57.75022883569041, 55.909739002104736, 58.03743654681791, 59.343013148153986, 62.60476989130821, 62.22295853399462, 60.948756971666896, 59.92612838745118, 59.83732200437977, 54.39739073476484, 51.88768963659964, 48.156852722167976, 48.15422473415252, 48.36274185488301, 47.812080306391564, 54.62602176973897, 61.25886347986037, 60.556378749109086, 64.46377723447739, 64.5979654404425, 64.99916115114766, 59.69733653529998, 54.60214630250008, 58.77186506025253, 54.78543866065241, 29.292578158840058, 57.51925614572341, 54.49952533168178, 63.75917442383305, 62.39861011505128, 61.171986902913744, 55.087880857529186, 47.372527737771314, 53.106519099204775, 61.20378163553054, 63.8762689405872, 58.77199842083839, 51.4853838951357, 45.17052481251378, 51.07224456725582, 53.83042781583725, 60.10470605665638, 62.1647152593059, 57.614652110684304, 55.30352492486277, 58.08335965679538, 56.61280424364152, 56.81021713441419, 58.62841613831059, 61.16804884326074, 58.395909801606216, 58.89895769857592, 56.25670402280746, 62.24887363372311, 59.922641400367986, 63.00787971865747, 64.89889360243275, 68.41448260891822, 61.81093708161385, 62.544949823810214, 58.309947136909734, 62.463203707048976, 50.41788731851886, 44.356468262210974, 26.08943731554093, 18.653056890733783, 17.88644729122039, 20.414014785520493, 21.614144348329116, 15.069712861891716, 16.255086468112086, 14.301318583949922, 8.034373704464205, 0.9238925371919909, 0.43453582652634193, 0.239924427362219, 0.6662830926718251, 6.728934386084157, 31.16939502377664, 57.08402210666288, 47.83994090172553, 38.14861536026001, 42.644412517547615, 51.78430380359773, 66.994247282705, 66.82497347554853, 41.861209331020234, 7.83933973120105, 0.4945398777002289, 0.17837431882658314, 0.11571355134008393, 0.18365488627985602, 0.15659511329666262, 0.19814525550651937, 0.1448180436366989, 0.16877787247780832, 0.16067241709078514, 0.2113035663722023, 0.26442918986562763, 0.1591375752562477, 0.14574078121973624, 0.216877116491237, 0.0902786278616517, 0.08291108368505394, 0.12930375193395924, 0.19399148081579518, 0.12676240080186438, 0.15686702854450674, 0.16281833661900413, 0.13110615763693087, 0.12919884385360828, 0.15091166020401064, 0.1706910698163894], [0.030254124055406263, 0.019740341043460275, 0.03088132789989393, 0.041797251530712655, 0.013206618454968257, 0.14636351877162534, 0.046355447867104126, 0.03446225843001758, 0.0740837130034643, 0.013696145765753764, 0.07607328930809613, 0.04771837191055379, 0.022215128711034215, 0.045188634671391024, 0.016209196652315797, 0.041041904159130595, 0.02626045791041707, 0.03587651802527328, 0.0717723721097554, 0.07560396852392344, 0.059066191015224305, 0.06745590332655177, 0.05534684563416147, 0.5588582602720107, 12.611009440114422, 46.11708294960761, 55.300685128858014, 51.32968148877544, 44.091880859867224, 17.17526078224182, 19.317910402051865, 29.988330141190563, 43.09148426978819, 31.798082320920884, 15.269596845872941, 1.5807926462542627, 0.0682406148482715, 0.03795195746445849, 0.23207944186945118, 1.3119704324391581, 5.092322980203937, 8.214748309504602, 16.324437895128806, 21.638829785008586, 9.113853612253743, 17.21333130713432, 18.251623876633182, 21.0915885433074, 35.80874896818592, 50.84823800671486, 57.887378431135616, 60.877342377939534, 59.235065598641675, 55.71024333277057, 55.618377500964755, 57.32375344922466, 56.84101166263704, 55.830460056181884, 55.02665265913933, 54.99848611893193, 54.19742830338017, 54.19258417621736, 55.537098146254024, 55.307741472798014, 55.50497001217258, 60.805155077288234, 55.9547285879812, 54.846313845726755, 55.87788935630552, 56.06491188849173, 52.55617134032711, 50.397141902677475, 45.43661056026336, 43.448698443751184, 43.363508485978656, 44.708395081181685, 44.62507217161117, 42.845834070636386, 43.37010983497866, 44.651791357224994, 50.08108908130277, 53.33416169689548, 58.75048422044324, 56.396575743152255, 60.342048675783225, 53.63095960309429, 56.08824214627666, 51.07878708070325, 18.290653421032815, 52.31989560588714, 54.43118979853969, 57.722289792953006, 58.17752399752217, 58.494839822092366, 54.302265413345836, 47.987116075331166, 41.40091134655861, 44.802261321775376, 48.67032627905569, 45.58875537687733, 43.22769249639204, 41.17021322250366, 43.10429865314115, 48.473964583489206, 55.58036973399501, 58.186592517360566, 56.411194416784475, 54.01645014362951, 53.224578519021314, 54.170909158645145, 52.7923882392145, 55.34335267159247, 57.39390503975653, 55.88602435204291, 56.9127086670168, 56.42307919840659, 55.65081550228981, 58.625752848963586, 60.040237980504195, 60.522042320620635, 59.36521768569947, 59.305683951224054, 61.89557790756226, 63.60153828897784, 64.64190383111277, 56.34778930294899, 42.36076631853658, 25.682583585862194, 18.62273108574652, 15.6012773706067, 17.4072003364563, 9.839974545663404, 6.2715889657697375, 12.147652987510929, 7.632804878296391, 3.3417228393016325, 0.9810940548777581, 0.3011317575170148, 0.21789826572902743, 0.10657523323090808, 1.5064426487491978, 12.049785929341471, 33.43000404296383, 40.176696469706876, 18.11755922532851, 18.915081024169922, 29.30310383919747, 43.97805367746661, 53.8248384383417, 38.29647694864581, 10.447245701666802, 0.17572832774491082, 0.03532098170610205, 0.03876780279942098, 0.05754806138875504, 0.04315610381684477, 0.05738910963578571, 0.06488606138455291, 0.02242849185882557, 0.07819977318567616, 0.034468230085387346, 0.042949057063989104, 0.07842285032834738, 0.032701217644517465, 0.025597617570911686, 0.04056468117801894, 0.02770979092606614, 0.04073676750845006, 0.022242175445200938, 0.0651744015574936, 0.05159226020858173, 0.043229081352511724, 0.010038845845678402, 0.06361963760648524, 0.027424980503236576, 0.04725406134140588, 0.039907557769648494, 0.037729891557847305, 0.03613498459960665, 0.03641257272853005, 0.06688671532056986, 0.024692890714974176, 0.0426929998361776, 0.06165832611581972, 0.02393414957388755, 0.1188480537084322, 0.06629813762922442, 0.0734546782088376, 0.03693023366072486, 0.03494706185113999, 0.009963270314338227, 0.03557395926045795, 0.039408428504342036, 0.0929975122093193, 0.028475528365121256, 0.021451413744099198, 0.013126006853135844, 0.010960149886687438, 0.012150031905020437, 0.6112182861374271, 16.89740400160513, 51.907791783732755, 61.68287954022808, 60.56551394924041, 48.50892859120523, 21.826760345889678, 21.439328232119163, 23.504260009334935, 39.77195493636593, 35.93291159599058, 15.266730573869522, 2.0626455257015843, 0.03087251405832508, 0.025377757997522433, 0.7694058204370161, 3.787368319688305, 6.857327290119664, 9.69239144555984, 14.802374897464631, 17.462348861079064, 8.669282370998014, 17.0079069752847, 15.044016434300332, 20.64907458520705, 36.94095680790563, 50.376384719725586, 58.366852883369695, 61.343990679710146, 59.61992855994933, 58.36362085034771, 57.08759930826003, 58.61089098838068, 58.638892789040845, 56.30554145382297, 55.43453993335847, 56.2279648165549, 54.463863142075084, 55.52033393613754, 55.62455915635633, 56.92921400070191, 56.76746722190612, 61.431812547868304, 58.16414087049423, 56.90906086275655, 57.988163732713275, 58.371293006404755, 55.900242943917554, 52.55816782674482, 48.43280715327109, 46.046613647091775, 45.40102681806011, 46.7975906402834, 46.05806304562477, 45.45907789661039, 45.036964185776256, 47.222446087867986, 53.5457774900621, 55.94239665615944, 59.54646648899202, 60.13482201483942, 62.695007939492505, 55.21625611089892, 57.59314183265933, 51.49488387569305, 20.827161958140714, 53.755851791751006, 53.65419180162492, 57.782231453926336, 60.696364218188876, 60.42642670293009, 55.32918114815989, 49.12939656165339, 44.11603089301817, 47.87767410278321, 50.748197955469934, 48.508854066171956, 43.736725930244695, 43.826116746471776, 44.275032012693345, 50.29847468099287, 57.72705939508254, 60.64582055614841, 57.09211003395819, 54.26701115023706, 53.66402910601709, 55.490586680750695, 53.352204599688136, 56.66832147106048, 57.1749230354063, 57.806408943668494, 57.55542824345251, 57.274311973202614, 58.61049875136345, 61.089793635952866, 61.928933743507635, 61.33138025960615, 59.64249787792083, 58.64694149263444, 62.34838024262459, 61.98298400448215, 64.13638484093451, 58.368817990826024, 43.72616298737065, 30.149382660465857, 15.253024831894907, 13.163942040935641, 14.788133751961494, 10.295225420305806, 10.341493698858446, 12.516652903249188, 10.306103133386182, 6.1894790491750165, 2.301511005047829, 0.4235563463261051, 0.05409526480962673, 0.27591600413283995, 1.8147909545129346, 13.571424330434493, 35.642875855968846, 39.18396026857438, 22.940015292936756, 25.09611668125276, 35.4327937095396, 51.23216352155132, 60.27736094690139, 47.31510423844861, 14.110641383355665, 0.18870768047148184, 0.010684295031692713, 0.05428201406292858, 0.061926939524710185, 0.015851730450747475, 0.05879918639097483, 0.023793225784996347, 0.025803746933478023, 0.04371632093323335, 0.022971391557685794, 0.0839296818500565, 0.06432346173471983, 0.029604858793919126, 0.030649205174056754, 0.054285825350351875, 0.10946640309186713, 0.051317299761238604, 0.05077652978680788, 0.039892534785453355, 0.02115475960196026, 0.027761080512596716, 0.01548197907170341, 0.0958509599008868, 0.007733944399778041, 0.039555911921084895, 0.08775947029672324, 0.09510218556369505, 0.2241442112192031, 0.15273858072055926, 0.12616774803327938, 0.27869607592301987, 0.09650214995828368, 0.14213149586031515, 0.20424395889764835, 0.31797845998118, 0.20431014889430618, 0.1000453832168733, 0.06489405934248241, 0.1190552881528293, 0.11950874325609016, 0.11154878328764632, 0.14880127183371974, 0.19995541401928474, 0.14438177188557966, 0.1345998862938535, 0.1341377820579275, 0.15624490386295706, 0.17352679023338904, 1.0911014003138388, 20.867738877573323, 60.27787085502379, 70.43093389080417, 64.76040255638861, 58.3513948225206, 27.708103387586533, 29.955078248054754, 42.904026354512865, 56.21344027980682, 42.17210815798852, 18.488252624388664, 2.680919175186465, 0.24671585809799934, 0.1408613680471336, 0.8261349989521889, 4.281555827586882, 14.414507400604988, 15.332876443862917, 23.204298711592152, 36.00020377866684, 18.754877698036935, 24.83860327351478, 23.611295607782182, 26.735630150764223, 36.914578868496804, 52.813600417106386, 58.53322021422848, 60.86253935290922, 58.393540690022135, 61.933746491709066, 58.96317866540725, 58.15891627342471, 59.497978148921845, 56.20690953346991, 56.76931858062745, 57.901200863622854, 55.45436751457953, 56.947123542908706, 56.813041240938254, 57.3938815055355, 58.63314651673841, 63.98641301739601, 60.36507298869472, 59.26815863578551, 60.823484313103464, 62.0736692028661, 58.95565948178692, 54.98516182745657, 50.072224524713334, 49.92358238466325, 46.71284391034035, 48.33662671427573, 48.40785303423482, 48.121112085157826, 46.31722973239037, 49.53293392735143, 54.8397477980583, 57.61009431654408, 61.76799497296734, 62.55025286828319, 63.79574268094955, 58.25538696781282, 59.24696606974448, 53.11315574953633, 25.41413853245397, 53.30595593298636, 54.876402347318596, 59.793689558582926, 62.49687725497831, 62.46341551503828, 59.04741940959808, 51.551103207372854, 45.500835449464866, 50.70324367092502, 53.224915842856134, 49.58249699684882, 45.81626853635235, 46.34618466900241, 47.34838554936071, 53.89656289931267, 60.19859583147111, 63.89370779837332, 58.86021644838395, 55.526119432141705, 53.36442670514507, 55.690560879245886, 53.534159429611705, 58.95153707073581, 59.948599646168375, 61.42185757237097, 60.46705853554511, 61.43576237463183, 61.719255601206136, 63.46016037848688, 63.67570246419599, 64.22978039710753, 61.83984887215399, 60.283534757552616, 65.07759678748347, 66.71689648782053, 69.81012467415103, 64.14548473973429, 50.52289309040193, 31.69691654943651, 21.876486193749216, 22.814958364732806, 26.93941100951164, 18.530737776910108, 14.395989891021484, 24.418701779457834, 16.565157674974014, 10.526884525052964, 3.8186957999583218, 0.755542203062965, 0.34224493849662047, 0.4267735785293964, 2.1136329058677923, 15.692287145122407, 44.53876041596936, 51.82914041703748, 28.20267700379895, 31.306703475213823, 43.0824863526129, 59.14582775485132, 69.31405467371788, 56.89058649924494, 20.72125404111801, 0.5390015677098305, 0.21690667216335574, 0.17669632580251465, 0.1914375428591044, 0.10900272837569637, 0.14883905529014527, 0.10638526640832426, 0.12447597308745309, 0.12935002364458578, 0.16211090038620657, 0.215500456491305, 0.1783883075920805, 0.12071267341173465, 0.163734685028753, 0.1214962587842057, 0.3339876444830049, 0.10279210719970927, 0.08984359717296977, 0.11342255774164393, 0.1458446320987517, 0.10945570850444418, 0.08816145961323092, 0.1835311017930508, 0.12993267947627654, 0.11897792859423546], [0.021378725406623656, 0.04713622552733268, 0.09364655722052821, 0.028324323676286206, 0.021505708310512767, 0.008203732018779603, 0.09519282908689591, 0.062757340530234, 0.034326086301476724, 0.10521989345790879, 0.055443476134490584, 0.00778314017225057, 0.054158160628210154, 0.14292513230635276, 0.058554367673012524, 0.046993461212203394, 0.03306274219686466, 0.05585872260252795, 0.022176447016517484, 0.022826279183068586, 0.02400144848281578, 0.07532465286673078, 0.06310675706293795, 0.9181213210667334, 14.396503721514057, 53.70910106166717, 52.06491016572522, 46.64095863219231, 54.40380773236675, 22.1710346206542, 20.29869318008423, 34.66303640796293, 45.62168367447392, 22.460638899956983, 5.681031029070578, 0.3060364056258433, 0.03669112995867768, 0.16024276433933168, 0.7651049415430715, 5.695783063288658, 4.729476772969769, 12.062701313726365, 17.732786478534823, 10.612038200901402, 7.088333810529402, 22.235530153397594, 16.761046724934733, 26.37478582320675, 40.16096776531589, 51.17312008334745, 58.48641064859206, 61.17523462541642, 61.54793823918989, 56.43885889360982, 57.074275016784675, 56.7889618104504, 55.37999153137208, 55.28879250249555, 54.27531088552168, 53.18331126243838, 53.91362128719207, 55.041247798550515, 55.50857859273111, 57.708745848747995, 59.13405672196419, 56.051175748148275, 55.92251808412614, 53.38011226346416, 51.436342500871234, 49.18171705738191, 48.744953293954175, 44.88347791856335, 43.0710801001518, 40.305436503502634, 41.76023967804448, 42.9702163511707, 46.77188734854422, 50.96493244171143, 51.34269983537736, 48.10115114335091, 46.21094526783113, 48.44696690959316, 53.66377807432606, 55.66862698524229, 58.43070122503466, 51.72363258177235, 52.55157432248516, 43.92260313034058, 18.99117108314268, 55.2844072926429, 53.216549427278586, 56.35609688297395, 55.4517081476027, 58.15155398461127, 56.011524508076334, 56.6177660419095, 47.73379372012231, 42.062913294761415, 41.87972291823357, 42.37026237672375, 44.36073972332863, 42.90348898979926, 41.64247443599086, 43.876072052986395, 50.53943764778876, 56.62235913738128, 58.75543032923053, 55.38330593416768, 54.694576955610714, 52.863944038268066, 54.54533469292426, 54.89361763000489, 54.9383875631517, 55.900435140056, 56.14408493041993, 54.814060195799804, 56.81295102642429, 54.660895562941036, 55.892821819551536, 55.34010887145997, 59.07936319228142, 59.575335133460264, 58.186792558239354, 52.18367953454295, 43.187209713843565, 35.90021864060433, 36.39410780322167, 31.805117091824933, 24.896471961852043, 18.936316736282844, 20.973009409443026, 8.5036063578821, 9.198985715066234, 9.225295993589587, 8.2881054570598, 4.011280498197002, 1.3454460232488572, 0.18066533540766086, 0.1024879473111322, 0.15732994483363244, 0.5538694344220624, 7.519434652020855, 31.837178545613444, 49.87147369692403, 36.99951779457831, 25.12614634729201, 27.931603962375274, 48.54882694059803, 41.03452667113274, 50.60503928892074, 23.64165475291591, 0.7015572740666328, 0.22803794502490954, 0.10112321530018123, 0.01473979883631992, 0.01925553762233786, 0.04319530836636982, 0.05843970729338546, 0.026939600600951144, 0.07232849065574908, 0.017993871250279972, 0.014845167527035361, 0.0822136755431852, 0.008463871537617618, 0.12059213713772836, 0.03309522049441453, 0.01450720783923903, 0.04034299448493027, 0.061519855723506024, 0.038402558890201395, 0.0445961422707525, 0.05938027940330006, 0.019658329415946238, 0.008226334485375594, 0.05523477080127886, 0.02056737126211726, 0.04000835961872532, 0.038746191459077026, 0.05143888174526153, 0.06005472022919886, 0.024095424488487265, 0.023861242901353587, 0.051886522241177103, 0.03955447933666649, 0.04978718468919397, 0.04514074268480463, 0.023679649419782144, 0.0619197114851446, 0.06271195748159963, 0.08970370951799617, 0.09349557661241101, 0.04290044495475389, 0.0824384993663238, 0.02930814911040568, 0.06711744568160466, 0.034641189756052154, 0.026986902699835842, 0.04642202856860334, 0.08799720270138595, 1.2105916272247992, 17.366848953308597, 62.652665953482355, 57.07808756059217, 51.415236226974, 59.75358724594117, 26.24407675958449, 19.837279281308575, 35.83655465033747, 42.734164191830544, 23.29418766883112, 6.444962140052549, 0.6309361022806937, 0.052128774564593076, 0.11550061720153017, 1.3851393062260844, 5.073510802561238, 9.065000491757548, 10.7794096585243, 20.126232447162753, 16.034428631105733, 8.897314263928322, 14.120320812348398, 18.95887036477366, 29.281230741931548, 42.77189739288823, 51.53980678127658, 61.34064097558299, 60.79488631217711, 61.467376678220695, 56.926840966747655, 58.389402589490345, 57.172812800253595, 57.173526671624955, 55.128567603326616, 55.114537285220244, 54.82462313867385, 55.500067049457186, 55.80725531424246, 56.413551761258034, 58.390904857266335, 61.17055523780085, 59.425881062784505, 59.06723914607879, 54.49468120451897, 53.840429859776656, 51.71613301000288, 50.93302788272981, 48.12126505759455, 45.1912231599131, 42.40837604768815, 44.41808869761806, 44.826136789014264, 48.96974432852961, 53.211771980408706, 53.84931795058712, 48.37276743304346, 48.54423384512625, 50.567682635399606, 55.243951966685636, 57.25966584297919, 61.15665828028033, 54.07725080367058, 55.828145857780214, 45.89508464259487, 20.796365468732773, 54.6785266168656, 55.0762039615262, 58.535310837530325, 56.802615581020234, 59.008305534239746, 57.599582364482266, 57.00994422358852, 48.5903020828001, 43.22232277162614, 43.21615680571526, 43.550315287805375, 47.50749257303054, 44.79158855253651, 44.15954959008002, 46.80764367503505, 53.863787574152795, 58.51815046802644, 60.58305871102118, 56.81801480631675, 54.468926921967544, 53.245504363890625, 55.116906396804325, 57.062174504803075, 55.93747800396335, 58.13304824213828, 57.74268611784905, 57.90978300955988, 58.92486495356406, 56.155965789671875, 58.796222979022616, 57.78409457975819, 60.26073794211111, 62.301327490037494, 60.534946918487556, 55.50510729512861, 46.876120413503344, 40.16326627423687, 39.56134719233359, 32.71763886174848, 21.340859090128255, 13.03144927947752, 9.75426781562067, 8.738997597848217, 9.591107022377754, 13.553151968986759, 11.408941245848133, 7.471566046437911, 2.5768493788857616, 1.1306338661140012, 0.15404928055021072, 0.17337994650006297, 0.7716455550924425, 8.15213208237002, 31.375017435319965, 48.426146968718506, 29.425458254352694, 30.81317517065233, 36.409820818131976, 52.76573965626379, 48.2328054981847, 54.26292796288767, 30.30553221702576, 1.4811445868784383, 0.32174899152690367, 0.09443157517741765, 0.028870163237555858, 0.029001208322663462, 0.06817850810025008, 0.05616560210323623, 0.011579543464787064, 0.05986992833054355, 0.0281608309371457, 0.021448694131968003, 0.06683521889029972, 0.05339206504305044, 0.04743288541513105, 0.08153574901723093, 0.04865206838134797, 0.02294619875629583, 0.058583237696439035, 0.04837618479805608, 0.03243766041592725, 0.05020113263819968, 0.028513214145336422, 0.017386612504900947, 0.054934173221549684, 0.022836171293390856, 0.15046542930987575, 0.13154451314720417, 0.2580371973735671, 0.09254103105875755, 0.1011498751599462, 0.09505103387299085, 0.15923191132324357, 0.1815818983220285, 0.12571109834337427, 0.21523270876176898, 0.22115398618963458, 0.2391922158459502, 0.1871446159578139, 0.2702297931236606, 0.25346409679660875, 0.18040336398107393, 0.1281800158622284, 0.2168049510087698, 0.1812372660084117, 0.18314963597203457, 0.18917770605654488, 0.22746641278987934, 0.199112931807195, 1.9665796934596955, 25.21037728555741, 71.29495359236195, 66.53456118799025, 60.81925992042788, 64.51019456309658, 33.00345020909464, 29.79607516719449, 47.5051038495956, 58.06387724414949, 29.356518676204068, 7.8396054717802235, 0.8356240091304626, 0.39111509678825257, 0.3147220347196825, 1.426652814111402, 7.470831582623144, 14.530298709869387, 23.89876807889631, 33.748727998425885, 22.33998679345654, 13.931433193145262, 24.936284019101052, 21.211334582298033, 29.603920213637817, 42.43062373130552, 54.334071913073146, 58.51943308307279, 61.540834826807824, 62.79218466051164, 60.627977694234545, 59.339231983307876, 60.483587403451246, 57.1044498105203, 58.498781804115545, 56.99885176074121, 55.938164418743504, 56.163559498325476, 56.28552952120381, 57.49472564266574, 59.519959111367505, 62.79039998208324, 60.210107987926854, 60.440213834085775, 57.63405607592676, 57.34837808916646, 54.43339024820636, 51.77849477337253, 50.91189415224137, 46.69821739196778, 44.79389098382766, 45.95138634404829, 46.27619389564761, 51.24949647534279, 56.64741131567187, 56.64735248011928, 51.855090818097516, 51.32688091647241, 54.481992337011526, 56.330005276587706, 59.37560019954559, 61.62370274143835, 56.03134424455705, 57.42307570672805, 47.23117728387156, 24.435615039640858, 55.202304240195986, 55.35775953723539, 60.81054833627517, 58.990105736640196, 61.33634990261447, 60.15716383534094, 60.00704688410605, 50.5605282322053, 46.69534621700164, 44.89264842002623, 46.19015670591786, 49.2202425772144, 46.896497126548525, 46.25806470071116, 49.436043539354884, 55.567304318951024, 61.156419015699825, 63.69388264994468, 57.1899417907961, 56.24060269325011, 54.60478213525588, 55.692506374851355, 56.94836693425333, 56.08254294241629, 60.15832485691194, 58.76140017663279, 58.97146663358135, 59.038762738627774, 58.221552602706424, 58.96934070894795, 59.85493736882364, 61.25584325482769, 64.82237600511121, 63.56395806035688, 56.93601539058071, 48.26413739112116, 39.99883659424321, 40.616531448979536, 36.85697494014617, 28.598885420830022, 28.213826341013757, 31.179004830698815, 20.493119185970677, 18.136845519465787, 19.899764599338656, 17.060927614088982, 14.84136619875508, 5.31423548536916, 1.249250507643146, 0.37800589215851604, 0.3905557606729769, 1.0055776733544566, 9.603836094179462, 39.20505869773127, 61.26115806641118, 49.66808311400875, 36.51082969480945, 39.543496485679384, 60.78269558568155, 55.21927241356143, 65.37907015892768, 36.75571110940749, 2.621100578577288, 0.6305583290034725, 0.29280223673389805, 0.15259201277888593, 0.11941884283817585, 0.11542954722479468, 0.1947636821217114, 0.1674145424077588, 0.23156300667793522, 0.17551558512833812, 0.16430434800924795, 0.17367433876760546, 0.24162089842702114, 0.2360596210365334, 0.21590629923007182, 0.11820364352916518, 0.19167706790950992, 0.153110439799005, 0.14767893770289037, 0.13083278682203064, 0.13341373703893156, 0.10899148220496793, 0.2925506534595644, 0.22741185200791206, 0.07857608323496196], [0.01922049676068127, 0.062229291445785956, 0.05908800919930782, 0.03660704031766903, 0.029645605095391794, 0.046139196567838235, 0.0872087833141127, 0.0463974486375528, 0.03561445849857504, 0.023389192928950635, 0.164849940507162, 0.03237567624197372, 0.06517056345699296, 0.02084053906371757, 0.042697473789655396, 0.06736333692266096, 0.02201459370553494, 0.04049051237562972, 0.051675867214198076, 0.09050969530137316, 0.036935255367068515, 0.13874966200561295, 0.018975377353208683, 1.6790507157002728, 28.01593884345024, 53.18313083341045, 55.19873488333918, 47.630835425469186, 33.15069598536338, 14.044414124181195, 21.217575073242188, 35.369337604891875, 34.96973437647666, 19.621707777823172, 2.496994579991987, 0.1503237796526763, 0.023105956816805467, 0.3049334535194982, 1.404141718822141, 6.866135952934143, 5.073779484918041, 5.690394216968167, 9.625137505992766, 18.08456816980916, 8.190395783993507, 16.367986990559487, 22.373666224941132, 28.437477927054132, 47.796567332360056, 54.16353510272119, 63.09597615272769, 60.77217971124957, 62.04525555333784, 56.84057235717774, 56.133325869037265, 53.644519236779985, 55.91715228173041, 54.131708991143014, 57.79892113900954, 56.13156472482989, 55.43401041338521, 54.996587691768525, 59.27239479557161, 58.63025965229158, 56.32499248750749, 53.34118273950393, 49.36666073337678, 44.72896399036531, 44.002274313280665, 44.82091611431491, 45.64730459643949, 42.23362661177113, 43.082274544623594, 41.4637202601279, 41.86152312063402, 47.447029236824285, 57.79491247669343, 57.96601018598003, 57.3204037450975, 55.488233258647305, 56.05711813895933, 50.408920780304946, 54.37505675900368, 53.45889306837513, 59.21788953965711, 52.609503807560095, 54.66639472592262, 34.36869390549199, 21.303165112772298, 57.72783210200649, 53.11119848682035, 57.01595329469251, 54.80579183947656, 55.11192498668548, 55.413621933229514, 58.282757266875244, 51.84565359546293, 46.251027968622026, 42.147444294345, 42.78505302244618, 41.84655927842663, 45.297919473340436, 43.244029168159734, 43.442042181568766, 48.157162589411584, 53.90616093912433, 55.754385686689815, 56.198578419223914, 55.22165721462619, 52.7504502573321, 55.50091820378458, 55.87732453500071, 55.309718347364864, 54.49556766017791, 56.521318881742424, 54.66850103870515, 51.04275618830035, 52.76234288369456, 51.15647354433614, 51.370540818860455, 53.47878340751895, 57.138295942737216, 56.445742653262236, 52.137077854525664, 45.44597325786468, 30.871108578097438, 21.713519557829827, 20.558622767848355, 15.590411424636843, 11.451320494374922, 7.772861440335551, 6.313780921120798, 8.842012766868837, 10.522819968961901, 9.762652862456537, 6.267100303403794, 1.3592134199796186, 0.8309047849428269, 0.01958174169093611, 0.05758995873733394, 0.08898708023010724, 2.664890899773567, 15.979569381283177, 31.774924647423532, 40.89149352042906, 14.830539476486946, 25.404824864479806, 31.12397005481105, 45.430040590224735, 56.22700383586269, 30.407449122398134, 4.261927306652069, 0.060143222536651365, 0.062436977882058396, 0.058153121461791385, 0.06955524470897452, 0.07495744394198542, 0.02957975983829989, 0.09861638408995445, 0.044055740018525434, 0.038638552275275996, 0.021278831371737104, 0.030616447254414522, 0.05985120131123451, 0.03303579122368847, 0.05172846298063955, 0.07590282708406448, 0.08995348482482857, 0.004466737887161154, 0.08122309321357359, 0.11595279293795747, 0.030197531225219853, 0.03748857386169895, 0.06483110989774428, 0.03025426386645244, 0.06343003467566545, 0.031727236440224994, 0.030593345873057846, 0.029953695015020432, 0.03524443037026832, 0.05747237956271537, 0.01127988146993542, 0.02843415387155068, 0.021786517839157776, 0.07057070191348754, 0.04485083586205879, 0.07757933389755987, 0.054536596571485844, 0.049441219382588907, 0.11599495075643064, 0.10280916031690375, 0.1518188308804266, 0.03804219496105948, 0.04193752222964841, 0.02213128996382077, 0.03499421456287946, 0.08719216686703506, 0.003659682932324828, 0.052375313149945396, 2.470512942921731, 33.56803224932763, 60.906736620010875, 61.39443236012613, 52.30411591068391, 39.4020793514867, 18.767541070138257, 21.24463942743117, 35.82346570107245, 40.078468553481564, 19.892586661923318, 3.0390264238080675, 0.17449848083478792, 0.01346516259570396, 0.5215573166647266, 1.6549309583440905, 9.264171584959954, 9.010320690370376, 12.030263312401312, 16.911534340150897, 16.911120530097715, 9.051818386200937, 21.12407753544469, 25.190177079169985, 31.40318201434228, 48.59590714977634, 58.91147398179578, 61.440300556921194, 61.054872774308734, 60.754254479562086, 59.66619683850197, 57.82021568667505, 55.66861521813178, 55.78321118508616, 57.156872287873306, 58.68022672591671, 56.56759500503541, 56.324298227986986, 57.43475652510121, 58.179340054911954, 60.760334153329175, 58.647306273060465, 56.166469896993334, 52.94024198285995, 48.43512919641311, 46.815237383688654, 47.82276484274095, 46.762893353739095, 43.108177877241566, 44.23416091549782, 43.464078057196836, 43.19164199213828, 49.63630799324282, 59.5999833076231, 59.49299673880301, 59.77350111930602, 57.758858050069506, 57.862671421420195, 54.49594420771445, 57.085810707461455, 55.43641874867102, 61.43446407010479, 53.95621038252308, 55.79251896950507, 36.829730156929266, 23.667709096785515, 57.77187639667142, 54.38156397111955, 58.09929232443533, 57.21856724831366, 57.73330773076704, 56.790468000596576, 60.19228081549368, 53.810211919969134, 48.959675604297274, 44.642911111154866, 45.467001084358465, 44.34551700468987, 45.82709820039811, 44.291588337190696, 46.11986391005978, 49.876451184672696, 57.10746219081264, 57.39363831858481, 58.08982764520953, 57.010932660871944, 53.27270600103563, 54.806023259316724, 53.97899935322424, 55.22986281302668, 55.42820922790035, 57.98397464136924, 54.58356603499382, 51.4809633839515, 54.21552219698506, 54.51867042049285, 53.701017056742025, 56.274778304561494, 59.39545131498768, 61.952785676525494, 54.24353576475575, 47.08224096605855, 29.55089761364845, 22.83258157391702, 21.19313870706866, 15.662824261573055, 9.98135147556182, 11.86547669672197, 9.874417858739054, 10.82361771214393, 9.32564591207812, 12.403477814889724, 6.753863500010583, 5.531667663205055, 2.6792291239384682, 0.024057466747058977, 0.04094915389413795, 0.31880102390723847, 2.9642609002128726, 18.46028220268988, 35.69089351161834, 42.39035275674636, 20.86412637464462, 26.954684718962643, 37.13014841079712, 50.57699826455886, 62.40527422197404, 35.5795648790175, 5.887709048486525, 0.042590991398620034, 0.044616669596683596, 0.018907750941692822, 0.10612743951740766, 0.049621797797660676, 0.05267083539717621, 0.09321436871804538, 0.00487563971077062, 0.04751745769153199, 0.09680699166511336, 0.059748415294433796, 0.034204998444164955, 0.09460089593044213, 0.08185541452539545, 0.1018475284499507, 0.07227591404150571, 0.02047078289662398, 0.021145097318015272, 0.02716528052734512, 0.07053525502523107, 0.04907472675005275, 0.009335515844154983, 0.02347472856091636, 0.027599539382443316, 0.12056591394808024, 0.31380116639118044, 0.22221429784211422, 0.11251100504230108, 0.09936295209392425, 0.16433260133189542, 0.21223192704060387, 0.12498530664391096, 0.17303782695483777, 0.14103906980204967, 0.18813666917624014, 0.15616592019796371, 0.2077453943990892, 0.1532134786248207, 0.2080292759403106, 0.15077675212054484, 0.13871342604679449, 0.19801796233702093, 0.1786067805463268, 0.13377294034486817, 0.30767509833939616, 0.22703663746435798, 0.07923234479441758, 3.7299712963642615, 40.78143965813422, 67.0843441255631, 69.58600828724524, 60.537268961629565, 43.62533061735092, 23.771067473196215, 32.84291740386717, 48.41670974608391, 47.53658871496878, 23.70307122507403, 3.2668273871944797, 0.4163839247438216, 0.20998462343648558, 0.7087447722592662, 2.9095551131233095, 15.728606331732967, 16.15771460917688, 16.40086723912147, 18.842236726514756, 31.821873457201068, 15.16961366899552, 21.524351489159372, 26.889930309787875, 31.109398449620894, 50.63729686121787, 57.93185026414933, 63.35429952990625, 60.435793322901574, 63.02339661505915, 61.77258806843912, 59.14429018574377, 57.4763140370769, 55.58313500496649, 57.384467817121944, 59.6082712757972, 57.3346576383037, 57.81140604326802, 59.92405345363002, 61.85675428759668, 62.96711844782676, 61.05422166086013, 59.341161789432654, 54.820979256783765, 48.662983602093114, 48.69041273670812, 50.398765763928814, 49.21100931782877, 45.675396611613614, 47.099169915722264, 46.00309102765976, 46.10443330580189, 51.778479083891845, 63.31527586906188, 61.78408845778435, 60.881582460095814, 60.95558189576673, 59.37255644029187, 55.8661614694903, 60.62645581460769, 57.78935447815926, 62.914880321871856, 54.74461070952877, 58.563657806765654, 38.62914885244062, 28.01219297993568, 58.97295713424683, 57.39555243522891, 60.71363049168741, 60.14567913547639, 59.93831126920639, 59.85838513220511, 63.24087242926321, 55.72387749148954, 49.976059775198664, 47.96042826867873, 47.14915267882809, 45.55760783533896, 48.813198612582305, 46.660378286915446, 48.447920045545025, 51.86080571143858, 58.2178851865953, 59.7849230612478, 59.4938478931304, 57.8658446188896, 53.36259103590443, 56.29262901121571, 54.91701064571258, 55.59172891801404, 55.50769605944234, 57.315559617934696, 55.51238721416843, 52.03514329848751, 53.965012181189756, 54.428118582694765, 54.19380011097078, 55.463557627893266, 58.76667968688473, 63.01783469415481, 57.60129644024757, 51.5192182602421, 34.83389485266901, 25.55010945566239, 24.54099932024556, 20.686790135598955, 17.161748216998195, 13.8456666469574, 14.571134505733369, 20.038151702573224, 20.77633196307767, 18.099775198967226, 11.954300730459153, 7.18329978566016, 2.242429323734776, 0.223558199922404, 0.41941999247477907, 0.36612089603177966, 3.9851893821070274, 20.550138681165635, 43.44394060873216, 54.367804296555065, 24.399868519075458, 37.53599605252666, 42.98993410602693, 59.71962344261908, 70.03853213402533, 45.45704218649095, 8.584731759563569, 0.29067891679944535, 0.14812901435840517, 0.2130690926024991, 0.23722493269991493, 0.15991858657329314, 0.10435025342890333, 0.33330754226734566, 0.11891439692267489, 0.13241592283931472, 0.22124547240955217, 0.1306449880282725, 0.18347182190946995, 0.16416764728003935, 0.19690975486751527, 0.17991774084587253, 0.23682719517138698, 0.2673229797472877, 0.10732379306348101, 0.16402520089139863, 0.15541386700445609, 0.10922777436433301, 0.11873046687293438, 0.17748115223742303, 0.11974919527288407], [0.05387221831047247, 0.03734917650299688, 0.012513021600522823, 0.06480394441994929, 0.046355003536108046, 0.112663617417697, 0.022426561317256382, 0.06982499192799292, 0.03381703236711121, 0.05749389131162917, 0.061587068447542775, 0.0641222908762434, 0.059657507470899054, 0.02535324892960489, 0.07883589429360244, 0.06179524901052637, 0.06103040980956247, 0.04655216009386125, 0.06283957240802628, 0.04565899350470112, 0.004358302929528779, 0.030291583839683767, 0.01797534915949068, 2.827340518274615, 31.188265546675655, 55.78114017363518, 56.43214771824499, 46.9347127791374, 31.521872935756562, 20.979577418296568, 21.40425047566814, 35.28018997561547, 29.443391330780525, 9.338214166702764, 0.8507185152942135, 0.03703059500924522, 0.07850215575026889, 0.10775945960514008, 1.601710646383224, 5.671360425410732, 5.360385112224087, 9.535739825617883, 21.638974912704963, 13.123411209352556, 10.15557433328321, 20.42611529750209, 28.10152888298035, 41.044607162475586, 47.17411072023454, 59.13873610957977, 64.51699987534555, 65.75619820625552, 57.629180569802564, 55.74234008789063, 59.31330511646887, 55.830479668032744, 55.32447038158294, 54.828678869432025, 56.61863288571758, 55.85071125338155, 57.43822390033353, 56.38676589535129, 56.183438070358775, 54.535462087200536, 51.73117137724354, 46.56834379319222, 42.0110595610834, 42.17721900632305, 42.61575960343884, 43.026702404022224, 46.170999849996264, 43.02430975821711, 41.91225897881293, 40.17216220978768, 45.90457677841187, 55.87917981609222, 56.88665628433228, 55.219919604639855, 59.47838590991113, 56.12510850352626, 58.351163402680434, 56.87546576223066, 57.195084018092004, 55.78124215525966, 57.82553049825854, 53.06439676592427, 50.21794449898505, 28.08661799277029, 28.731328172068444, 53.18507632901592, 56.41774869734242, 59.22199233885735, 58.469418941005586, 56.318826521596606, 52.70361323510447, 53.655607777257124, 50.80384854347476, 44.832141937748084, 42.06817711553266, 41.82117369867141, 42.09210357358379, 41.127169132232666, 40.668216520740145, 43.32191175030124, 46.096796451076386, 51.90218671675652, 55.8689385075723, 56.02163637838056, 55.04421311040079, 51.23726260277533, 51.76000079801006, 52.18080443720664, 51.46488951098535, 53.02012497378934, 53.10030606485183, 50.96299479084631, 54.15318396783645, 50.85579641403691, 55.74860411305582, 57.10614427443474, 55.25505227427329, 53.52849552708288, 54.72296707091793, 52.244154637859715, 51.5378063724887, 46.90232184625442, 44.64122841435094, 38.45832963143626, 28.129207088101296, 13.41908633708954, 11.618454648602395, 6.3376382473976385, 7.653698853908047, 9.957390696771684, 13.209950462464365, 4.633404199154147, 4.468669554879589, 2.57951928723243, 0.302437998714947, 0.12787852962050708, 0.06198861343305438, 1.3790281309235481, 10.492779516404676, 35.21294878375146, 31.63946951589277, 22.16722207684671, 24.38691096921121, 45.24039791476342, 47.93861204578031, 51.519382999789336, 37.56614338967108, 10.482486236479975, 0.27286541137483816, 0.024131459349225608, 0.0010736768942273733, 0.03839054663154868, 0.03865917536219762, 0.04935020813718439, 0.0747616471902978, 0.0192699515666332, 0.011848534171980236, 0.07832919607960409, 0.017925222111385197, 0.02920348234775086, 0.024760036406317548, 0.0225358629118531, 0.04608499201675577, 0.06778659283994667, 0.05583555227325809, 0.06254341047737869, 0.009748660358450106, 0.03915478828393164, 0.043625596970800436, 0.03576504840185085, 0.0680281403624723, 0.04437956155367917, 0.08656202124491816, 0.0176358419740873, 0.033050193676664945, 0.059265956102359685, 0.05067893784613379, 0.05426062871852229, 0.06262388801382435, 0.04334808928110907, 0.012161530884763887, 0.09642983891911085, 0.05595895754654081, 0.05187016626399371, 0.047048374394615816, 0.013010165740495488, 0.03877028492429564, 0.022050387248577132, 0.02904995449728543, 0.05065756399304636, 0.045103476337728, 0.025501584619163506, 0.030445960132525336, 0.01402830042230386, 0.02917904414296631, 3.734782328528743, 38.22184601137715, 63.2714355376459, 62.246504522139034, 54.40109345220751, 35.41520580168694, 22.0162873114309, 25.646917473885324, 40.81445032550443, 32.83967360373467, 10.519887016665551, 1.0752596826322618, 0.020885937434110432, 0.2927664451060757, 0.7957521357363271, 5.47365531806023, 9.239977425144566, 9.310355532553888, 10.838417795396621, 14.617924459518926, 13.460447730556613, 9.32436231643923, 18.630518951723655, 26.912246634883267, 41.27918451063095, 51.76920660080449, 59.042755711463194, 63.859351758034, 63.692721628373675, 58.900412897909845, 58.28330247632919, 60.92934908405427, 56.02176973896643, 56.296182678591826, 53.99458685228902, 57.79531255845101, 56.66235162365822, 58.00480242698424, 58.71903465640161, 57.96793606973464, 58.22258418606174, 55.6036921470396, 49.63829663492019, 44.4406109471475, 43.73719661466537, 45.81733542103922, 45.541486893930745, 48.37126516526746, 43.71891052492204, 45.224947698654674, 42.23849819552514, 48.24224272081929, 57.54110374758321, 60.35555339628651, 58.16150111536826, 61.20834335204094, 58.73492417796966, 60.191633624415246, 59.447862025230165, 60.097426137616566, 58.016942162667554, 59.04040621172998, 54.010990204349646, 53.14436212662728, 29.627468162967315, 31.415937562142652, 53.96213708385345, 58.50299835205079, 58.70646738236951, 60.744107307926306, 57.812845553121264, 53.65910653145083, 54.15151303814304, 53.30581080528998, 47.146246202530406, 43.905254487068426, 43.74668875048238, 44.97167241188788, 43.64472673785302, 43.11822698962304, 46.12865001924577, 47.72325038909913, 53.86109682821459, 56.85261011123658, 56.926127095376295, 56.65603268531061, 52.578309197579664, 54.362528708673295, 53.26472790010514, 51.474601299532004, 52.31526720908381, 54.42780479308098, 52.6514417894425, 55.784446731690444, 54.47428095725275, 55.75990446152226, 54.40327821239349, 55.89577536429129, 55.429236888885505, 57.24976185829409, 58.00080160940848, 58.248742472740915, 54.18602205091908, 47.32559265628938, 39.32553037520378, 27.99594456149686, 13.835034082012793, 9.942231716648227, 8.673442044565755, 9.120853081826242, 12.319066447596397, 15.329798363870191, 10.693030241997013, 6.036613497041888, 7.421318033049184, 0.5313886149275688, 0.19739133305847648, 0.13165035585482276, 1.2186707291872272, 12.809137182850993, 34.77876201752694, 37.90146681570238, 21.341931858370383, 31.271968926152876, 46.70772521726547, 53.6847274534164, 57.379298133234826, 44.25621248060658, 11.657254734346944, 0.4468861444582863, 0.05354112277047769, 0.011910429288212572, 0.01854137896800474, 0.12061124337055992, 0.06714605906557652, 0.03911116723752311, 0.050557842327942776, 0.037834366798521056, 0.01671781583178428, 0.05642582684935582, 0.08689044313805719, 0.024598732763420672, 0.14398676163006213, 0.04263147148453901, 0.01339590058646976, 0.04976085807767607, 0.06232496433620972, 0.036174671784524, 0.07287427467564422, 0.01067314079151519, 0.03544610301633516, 0.0872185356133888, 0.04895751529763784, 0.1654308649801439, 0.13114066223704046, 0.08375661492708229, 0.26904649371581696, 0.16613543604410466, 0.23720063239095673, 0.1810652945911692, 0.18669164348994532, 0.09565621268965545, 0.2136315696782643, 0.15250113942930776, 0.16355263189442698, 0.12603659378064255, 0.1424914039671421, 0.20003502587637595, 0.17267770434339202, 0.14124298708573466, 0.16136252441473548, 0.14135987678122136, 0.1494661288996858, 0.09954630757772154, 0.16280620178628355, 0.09042440673276302, 6.0287854267704875, 47.50835157209828, 69.88883879876906, 70.80213915917182, 59.68505167192029, 42.04049694922663, 29.32306674218947, 31.695714342978697, 48.461969975502264, 40.42699859988305, 12.425946131829294, 1.458495228040603, 0.21627797444741573, 0.4462817930165799, 0.7408429369811089, 4.490749066875828, 9.92180303219826, 18.299649377023023, 21.467988990968276, 31.86674733315745, 22.915090591676776, 17.031309796917824, 23.22005291138926, 29.977949588529526, 42.043893721795854, 53.32734069516582, 62.47124064353205, 63.892346735923525, 65.93487001234486, 61.20664496575633, 59.377490781968646, 59.43229021564607, 57.08193932810138, 56.19382450657507, 55.57486664864325, 57.16053970398442, 58.44744582330027, 60.149205346261304, 60.98319930415, 58.281509953160445, 60.93489531547793, 57.39159476372504, 51.896307083868216, 46.1625353751644, 46.32014405342841, 48.34738969802857, 47.49081073268768, 48.90270709991456, 46.17519678608064, 47.0284652709961, 45.01110399923017, 50.77350508782172, 61.10722072662846, 61.8687371284731, 59.72857821372248, 61.47227571856592, 60.03707655014531, 63.65312137911397, 63.51022158899615, 60.76948504294119, 61.060324868848255, 61.173128312633885, 55.62582608192198, 54.255597053035615, 34.077673650556996, 35.72992893957323, 54.98717792572514, 60.3781815498106, 61.62524815528624, 63.03127273436516, 60.96173217219692, 56.124982987680745, 56.92634674810595, 55.35101698290918, 50.03047089422903, 45.341402869070734, 46.27483283319781, 47.076118146219564, 47.35068013591152, 45.437673522580056, 47.962389453764885, 49.85785522768575, 55.87910136868877, 58.58823145589521, 58.05605603802589, 58.881444315756525, 52.96652186301447, 55.29416614963163, 52.641722156155495, 51.869278031010786, 55.08488024434736, 54.482565003056685, 52.51956778187906, 56.44117309201149, 56.63766422579366, 56.48711973621, 54.4010659956163, 56.72348176279376, 54.63501576454409, 57.436007761186175, 58.06241420007522, 58.79841166157877, 56.26611378885085, 53.95573185336206, 44.753141480107466, 32.694345866480184, 15.64270152199653, 15.889799075741923, 16.410486851969075, 17.795367894634126, 17.38976736222544, 24.960212438337265, 16.766298778595463, 8.998186838242317, 6.723992199667039, 0.4232992165751996, 0.22669088666237172, 0.22342226528111966, 1.684529408812523, 13.546489823249079, 45.13664730133549, 44.48079562956288, 33.91111804592994, 39.09539707245366, 55.79914777509628, 60.19096289911578, 66.43573314912858, 53.49510831217612, 17.400726464486894, 0.6332882986434045, 0.18094232215756373, 0.14525718055665493, 0.12961637709409962, 0.20796981219562793, 0.2542885299772024, 0.14999223212080617, 0.09415227484198348, 0.12216617969135124, 0.14571320205446214, 0.09938224218785764, 0.1715116265920862, 0.1332768830921381, 0.3564574935984227, 0.10847208225318503, 0.20099482679319, 0.2539666964402122, 0.13072193389938724, 0.1517171556911161, 0.17986592265867418, 0.18865434543019344, 0.12933557522633385, 0.25848327505011714, 0.11567446553418714], [0.0455185121315862, 0.07340310516977504, 0.007438278989866377, 0.025628774366792173, 0.06321982397968251, 0.08568050685308634, 0.016658173971659234, 0.0179159696844797, 0.04758270540004296, 0.014989345274384946, 0.06003673631517638, 0.006262485807265846, 0.02640311688845677, 0.054719212780436205, 0.060001017465706796, 0.03395156506749411, 0.04212824364883765, 0.027748719683938453, 0.05469755930525642, 0.05073623739243035, 0.04319672945946936, 0.05426819000633494, 0.039538222950913256, 8.070836057586055, 38.83299835266606, 52.644448203425256, 48.9142898590334, 35.070680495231386, 26.191391483429943, 23.73513267886254, 37.90479690797868, 38.483526937423214, 26.808397962201028, 5.802386710720678, 0.3652099868462932, 0.08862159500319151, 0.09956079430036968, 1.8806354148734001, 6.161746911464199, 14.742322429533928, 7.354083215036701, 8.39340050374308, 15.070852310426774, 15.189761903978164, 9.542354902913495, 30.06658534849844, 34.23398402429397, 43.613818460895175, 61.53754788060343, 65.25928097386515, 64.25794693731493, 57.233625227405184, 54.64653968811036, 54.645331598097286, 54.28781540163102, 54.35419367205713, 52.389007768323346, 57.36445196213261, 57.60090812560051, 55.08178157191123, 58.39413689028833, 56.79112303641535, 54.68197438024706, 50.88419437408448, 47.54433931842927, 43.20520162582398, 41.62234090989636, 41.29866692327684, 42.98746693518854, 44.818731354128936, 45.442184248278224, 42.18820164280553, 39.770307540893555, 43.32322574430897, 54.157165173561346, 55.670968640235166, 58.34034942811536, 58.76451061617944, 54.42955809254801, 55.82429801264117, 56.74319951764999, 56.92367169164843, 56.21779803306826, 53.87000453087592, 54.92373358818793, 52.315518240774836, 45.00419278298655, 34.1477075699837, 34.99932473705661, 55.06418581931822, 57.101288380161414, 56.02797492857903, 52.746531809529955, 52.19103790098622, 55.16341393993747, 50.22703655304448, 48.41890235101023, 44.91095019925026, 42.42104530334473, 42.60923277947211, 42.704028621796645, 42.04818479476437, 41.88403360305294, 42.37708730082358, 42.12470239208591, 48.79880743642008, 52.73571783496488, 54.78046509527392, 55.00176522039599, 51.52099509393015, 49.892587815561605, 48.70320358584004, 51.52547444066694, 51.1271224483367, 51.50684318234844, 54.91640267833587, 51.00178310948034, 47.85491651104343, 55.35005992458713, 53.17956932129399, 56.72740805533625, 55.1932631769488, 58.70090938383534, 55.46406753601567, 54.93335516222062, 50.84859494240054, 48.69091087772001, 44.78023329088765, 35.26254323221023, 22.249687948534568, 15.409881395678367, 9.72571296076621, 6.330850585814446, 6.989587651145074, 10.42194543346282, 7.495573893670113, 7.795303771572729, 9.265769950805172, 1.0996723920106888, 0.14243567873152996, 0.23463095898830125, 0.23009590233766267, 6.229880442542415, 23.3525074297382, 40.6197242582998, 23.556303977966312, 15.359831952279615, 29.698459140716064, 39.9445156897268, 55.36517673923124, 44.74172346053585, 13.996689665702082, 0.5752480066111011, 0.03769231494516134, 0.01101669483637858, 0.013810692189802087, 0.06274178128449187, 0.0829095898136016, 0.03723337465236264, 0.0035950176900387894, 0.02074742299174109, 0.10676762089133264, 0.0013212585561690974, 0.03728119386059623, 0.01011980027185693, 0.04065404150394663, 0.010205659575970664, 0.07181252277786694, 0.05464888973942688, 0.039272750502512346, 0.09560807938537291, 0.006541341332898986, 0.04243702687803776, 0.07362516341550697, 0.04898962204254443, 0.06569433010994427, 0.05187770839960826, 0.10089190271232398, 0.03192157954007628, 0.05985600851295937, 0.09388569156609236, 0.028797070788700255, 0.00799260824175191, 0.0441425186281483, 0.04426564427933866, 0.02831261402236358, 0.05987367450049328, 0.02651092269638133, 0.026552404442261306, 0.03715700717763074, 0.06202158585731542, 0.01908448551060452, 0.055854581897297216, 0.030097378635658856, 0.07463981622769948, 0.031160254767465017, 0.0820536014714068, 0.04312554456954522, 0.08433072887841733, 9.461314812783273, 45.851769908781975, 59.3130736966287, 56.69965728636711, 41.91997428094187, 30.805465752078643, 25.236080577296597, 36.658083315818544, 39.20661980105985, 28.044911430728053, 7.008188020798468, 0.3558785456322855, 0.06144519279440565, 0.43590599010067604, 3.002346379141654, 6.117244680081645, 9.954111595307628, 8.556672103943365, 12.861102704078922, 15.959491748963634, 10.140972329724221, 11.186413418862129, 23.55098524401265, 34.35030975649434, 42.90639154372677, 60.40875250293363, 65.39708952749929, 63.35747664974582, 59.411258466782115, 57.42141654414516, 56.315119881783765, 55.65994678005096, 55.91333189318257, 52.788175613649436, 55.7808538406126, 56.238990599109286, 54.385505953142726, 58.992066921726355, 58.39205018935665, 57.28675765375937, 53.100808128233886, 50.1711113991276, 45.440862409530155, 44.563185015032374, 42.63584606109127, 44.77384767224712, 48.20361521936233, 46.493238249132716, 43.60685233146914, 42.456130904536096, 45.871609257113555, 55.24638383619247, 57.67640198430708, 59.38376657424435, 58.906849507362615, 55.73052590893161, 57.3345438895687, 57.802874888143236, 58.46819123914165, 57.04142516659152, 56.656134666935095, 56.70312073922927, 54.168253714038485, 47.438792259462424, 35.90447048987112, 38.06948546440371, 56.21837854385377, 58.76134526345038, 57.38627602977138, 55.43947819740542, 53.56370664411976, 55.7153541811051, 53.89576665816769, 50.060347587831565, 47.70840421799691, 44.362920561144435, 44.568444913433446, 44.60237733779415, 43.59323778460103, 44.18696695758451, 43.11474392491002, 44.96928368845294, 49.791747600801536, 54.63684358904439, 56.97345441387546, 57.1201628254306, 52.44704707976311, 50.75247726132793, 50.785385947073664, 53.22648086855489, 54.03562661140196, 52.347630685375584, 53.33305951087706, 51.379166110869384, 49.936318320612756, 53.88954185670423, 54.763092917780725, 54.42116814274942, 54.05945108782861, 56.79974048368393, 53.66043229256907, 53.45758691910775, 53.099976585757354, 54.02465181965982, 50.28893155436362, 38.058447914738814, 23.755244631921094, 15.922307679730078, 8.312630076562206, 14.155179896662313, 13.947995401197865, 11.279294163950029, 11.544798420321557, 10.766354049405745, 4.207637290800772, 2.518849045999589, 0.09365146784412284, 0.2690319380452556, 0.240000024918587, 6.896478918290908, 26.453582317598407, 45.56210287155644, 24.36719713672515, 20.853806618721258, 39.045449610679384, 46.32350160229591, 62.02275683802944, 52.12407127503426, 18.0432754178201, 1.0179249882217378, 0.08229078229276404, 0.0273385408875202, 0.01523856708269206, 0.014077196941680968, 0.05836248946105761, 0.016046894222287642, 0.038520026982070944, 0.017118010587329348, 0.05751940586994733, 0.020904114785333796, 0.05501549345471206, 0.010159790061504371, 0.03049786833505477, 0.006465983179007327, 0.04181870965347175, 0.05190554803477661, 0.05428997754690148, 0.06216245410483211, 0.08925177892970462, 0.05698394105439225, 0.01529518864117563, 0.03549061655517548, 0.0455852881855061, 0.25368895892414356, 0.16752651381877162, 0.15377924987866035, 0.3518648884229122, 0.2658965240322775, 0.16759124824837332, 0.06793952697227079, 0.13007854261705953, 0.15522118056974105, 0.11371646737379414, 0.1492437182535087, 0.12432824835301408, 0.06244198043620395, 0.13104061115412943, 0.15482146653436846, 0.08254327721172765, 0.11983302827443808, 0.1280332027724193, 0.25031550607133296, 0.11841036469465303, 0.1251381182021672, 0.12945637197023438, 0.14692766591906548, 13.02183751137026, 53.46201527503229, 66.7853340025871, 62.08269065426242, 46.169160258385446, 36.59206982581846, 32.024593314816876, 49.343142201823575, 50.18037603747461, 34.469745928241366, 7.467425494424759, 0.8145093389095799, 0.23040894118528213, 0.8948457313160744, 3.6755121282992826, 11.20843948856477, 24.067055409954442, 18.57817884414427, 16.031737885167523, 20.7779715138097, 23.575476523368593, 14.32140111923218, 35.338727428067116, 37.405581166667325, 46.201680629484116, 61.83668351942494, 67.17975970237487, 64.63965631300404, 60.80703781497095, 59.29331279570057, 57.04605748576503, 57.48680637728784, 57.73400199028754, 54.44249799174648, 57.47347031870196, 56.62670904590238, 55.67244345141996, 59.84672392568281, 61.33889944322648, 58.96546148484754, 55.219864691457445, 52.48134428454984, 47.47921228408814, 46.082856347483975, 45.660895609086566, 47.16779962662728, 50.134566676232126, 48.73717523390248, 46.50274999680058, 44.32218282453476, 48.48115821038523, 58.928740255294315, 59.80123619879446, 62.06918201138897, 57.39768620460265, 53.88175202954201, 56.94335414517311, 58.14240309499926, 58.296124704422496, 56.99124628497709, 55.77455451411586, 57.43034385865735, 54.4840358918713, 49.909469696783255, 40.79470119168682, 41.04852168790756, 58.93750675262944, 60.52137551769134, 60.19811730231009, 59.447736509384654, 55.025275907208844, 59.701325585765225, 54.53131221955823, 52.088173743217226, 50.31043006527809, 47.492328689944365, 47.468476756926506, 47.06989726712627, 45.91365706536078, 47.00867691347676, 46.62977203246086, 46.59333713593022, 52.59628934244956, 57.28144676454606, 58.852418776481386, 60.76847699380691, 54.62906552899269, 52.9003083321356, 50.839832367435584, 56.21038867581276, 54.03157088064379, 53.36105738916705, 54.88132099951468, 53.188014184274984, 50.27586221694947, 55.128940228492986, 54.1164235145815, 55.82310953447896, 54.001046995962824, 57.10338292583343, 55.66693252132785, 56.766725893943544, 56.07847936691777, 55.47106112203291, 50.44305324554444, 38.919639587402344, 25.488581195954357, 21.2132663496079, 16.567926868315666, 17.722241186326553, 15.838700398322075, 24.88025296118952, 17.869139832835046, 19.157652162736465, 15.186192547121356, 3.3962545712147993, 0.44214859544750185, 0.5632044915710727, 0.4327539673014995, 8.296347337384379, 29.205005361187844, 54.857453377016135, 34.659066969348544, 25.928761343802176, 42.06236416293729, 51.87503607042375, 69.39891123002576, 60.62374153444844, 22.627037609777144, 1.6067593496653343, 0.18381965647061027, 0.08925655931835214, 0.13685186303430988, 0.10165739308802352, 0.23727163341977905, 0.14255406995934827, 0.10157143036204, 0.12240184365861839, 0.19251941222577326, 0.11733392689136729, 0.20294251341012218, 0.09678130473701224, 0.11907731318065237, 0.11214519805845716, 0.10645692627276145, 0.1723016624248797, 0.14521049515854928, 0.20510905602526283, 0.12000412635144689, 0.18749091834310563, 0.11441942199223465, 0.13042568769906798, 0.16565027256165782], [0.03650402830493066, 0.012570668759215023, 0.033074719981560786, 0.0318285707204092, 0.07139944816909491, 0.0437169031600558, 0.03496690352837886, 0.018722597066493287, 0.02574148505265194, 0.006005198050725965, 0.04191296911167522, 0.048538304324592316, 0.04424155081412004, 0.04983460170126731, 0.01797355076808843, 0.05932919666050904, 0.09676962955704621, 0.104362579783605, 0.036901670072468064, 0.037820075428293604, 0.02813182110267301, 0.064741967906875, 0.24365480057895186, 8.12434797325442, 42.95876695263771, 52.381480739962676, 47.58096641109836, 36.73276524389944, 21.996122406375026, 27.233710365910685, 28.675406940521736, 36.68536732273717, 18.027970329407726, 2.2841559879241453, 0.19746149139058208, 0.1343549833062195, 0.3606933775928713, 1.5972819227364756, 6.5412249488215295, 5.156182598683142, 6.021104935676822, 12.116215190579815, 16.405863358128457, 8.978729921002543, 11.18103781054097, 23.242755589946626, 36.975889436660275, 57.31290025095786, 63.21198025057393, 56.3265771250571, 58.52632468746555, 51.31348602233395, 53.621232125066946, 54.166598473825765, 57.42569977237333, 57.04133495207756, 56.07018747637349, 53.8828149918587, 54.45535159880116, 54.17388231523576, 54.964726278858805, 55.41118221898233, 52.553970890660445, 50.604568604500066, 45.64859113385601, 41.870834827423096, 41.18560068068966, 43.02942452892181, 46.960110126003144, 47.04318984862297, 46.022949987842196, 41.74773123956496, 40.4393893672574, 44.40925159761983, 53.789764604260846, 58.77018628581878, 54.8417168278848, 49.68760867272654, 53.859308227416015, 55.946181743375725, 53.98237259157243, 52.120890232824514, 52.21913383853052, 52.85379686663228, 51.155853809848914, 53.15172049307054, 47.476372488083385, 32.94952154159546, 39.950332564692346, 59.10997336910617, 55.63283927979008, 53.39723340926632, 48.65205587879304, 45.270780594118186, 45.47877996198593, 43.966741561889656, 44.92487461336198, 43.702283597761586, 43.60197682534495, 47.21536620970696, 46.95699184171615, 47.57203909658617, 45.931833328739295, 43.987106507824315, 42.056190352286066, 43.457967004468365, 49.59836690656601, 52.279204937719534, 53.49578688221594, 53.43903410819269, 51.52623930285054, 52.115273398737756, 52.28618283425608, 51.04991451386483, 51.546059039331254, 51.173449562441924, 54.65933445961245, 54.65933838198262, 54.59159120436638, 56.337759802418375, 57.17493088014665, 57.957784975728686, 60.38692059055452, 59.15270366976338, 57.2013048971853, 55.87688130717124, 54.460991967108946, 50.309476929326216, 40.09194973976382, 29.237553188877722, 17.949799453058553, 9.82061274590031, 8.096652607763968, 14.166213523957039, 9.968588083021103, 8.85686089915614, 5.373792263769335, 8.013862650240622, 3.789859760192133, 0.37549845573882906, 0.052432126230410034, 0.026086914097710003, 3.1420482118283553, 18.1278044562186, 40.347170522136075, 46.655067397702126, 34.87292243588355, 20.41877850409477, 38.89969825744629, 46.0190393847804, 45.9311233797381, 22.74232783625203, 2.211664458436351, 0.06928718288338954, 0.025711557827889923, 0.04680718310297497, 0.026980582474460526, 0.017125160102882696, 0.017766230138799837, 0.029952308395877484, 0.03661250252456915, 0.03184572917469327, 0.03199924361862002, 0.015622718999492786, 0.053581235134193016, 0.008546338029836696, 0.015759429304800447, 0.06889582686727086, 0.0036732079752255235, 0.08067057528082403, 0.03909936948348919, 0.02315563953391487, 0.051098466745667884, 0.0449817909318353, 0.06746685838386898, 0.06314888806833376, 0.0806439920298515, 0.04328005301255373, 0.03845727288975351, 0.005201115038230895, 0.01221176518517877, 0.019561601239406777, 0.06514731268849104, 0.03266781238057921, 0.02358105581914706, 0.0640127977596656, 0.09032132960255108, 0.02014263104947825, 0.018516189997054396, 0.07036044142178952, 0.04477159172717122, 0.03678789835483317, 0.06513285660935987, 0.03405638887817341, 0.047326996742237004, 0.04722940097112329, 0.042280744941484545, 0.059271969892565286, 0.3122765288477944, 12.726451658433485, 48.70342716093987, 59.63307634476693, 52.44457598655455, 40.439236394820675, 28.83410799887873, 32.113123170791134, 35.87534689134167, 44.229210884340354, 20.295612158313876, 3.269178112668376, 0.14751447394730585, 0.14767726763121544, 0.41186425113870256, 2.79905655211018, 6.058957278728486, 10.990807760146357, 11.310266179423179, 14.942025003894685, 13.930756584290537, 6.517805947411445, 10.446680880361988, 21.669243843324725, 38.032811303292554, 53.77736991451633, 64.73020030606177, 57.95533349437099, 63.65556501573133, 54.9165125047007, 57.78548309879919, 56.982660216669885, 57.93231702619984, 57.78835427376532, 58.006814602882635, 54.22253539485317, 56.811990045732074, 54.28522271494712, 55.10601789720597, 56.85796414652179, 55.694946089098536, 51.748190541421216, 47.15957049400576, 42.72005150395055, 44.03497511340726, 44.23066216130411, 48.59068255270682, 48.85711739140172, 47.72221488337363, 42.79191324787755, 41.819773412519886, 46.97277153691938, 56.896262168884284, 60.14997805318525, 56.83457897555444, 50.70621682751564, 53.6825034695287, 55.11501189201109, 51.94715276841195, 51.36895225894067, 53.56990791136219, 51.52814949712446, 51.217862559903054, 54.192768527615456, 48.60294388186548, 36.200381940410985, 42.388615146760024, 60.75458788102674, 57.29889738944269, 55.00713102279171, 51.09620240426833, 47.87474016989432, 48.764761263324374, 46.03044563724149, 46.876634243995916, 45.33937892606182, 46.592364388127486, 49.000699673929525, 49.32467568305231, 49.965394850700136, 48.65648031234742, 44.79832718449254, 43.4111927401635, 45.53645057062949, 51.08483537550896, 53.63045361734206, 55.75721371558405, 55.70416758137365, 54.443643323836795, 51.507812007781006, 52.80757957889188, 50.18558494506344, 51.76362506804928, 52.76344114734281, 54.925165253300825, 53.828274434612645, 54.991437619732274, 55.311322596765336, 59.84780649985037, 58.68605536799277, 59.165945591465125, 59.19870914951448, 59.67028002585135, 55.37456297105359, 53.16231481490597, 50.53209104845601, 39.22503532901887, 29.413365587111446, 18.135759022928056, 7.821567962246557, 10.832339102222074, 13.999177428983874, 10.540524567327193, 14.193651483904931, 8.233196197017547, 10.438224250270475, 3.9532134850179, 0.5464129474374556, 0.09398613335384477, 0.22112870528813333, 3.4427121041282533, 18.9776232165675, 41.0053873831226, 42.209515802321896, 33.02878087566745, 24.118938561408754, 42.23524655065229, 51.18220037029636, 51.258502237258426, 26.89645713375461, 2.763123228665321, 0.03509927203037566, 0.06854437637112795, 0.028575435806546482, 0.029509588099655606, 0.003902205541136585, 0.070354335701033, 0.019719934376377254, 0.034401898362463525, 0.08824939118517984, 0.04305571565524705, 0.05257674064787646, 0.002489012244510495, 0.06248662420999139, 0.035448029727464726, 0.026257606148118937, 0.015270726496143448, 0.025930890715831233, 0.017821398045447086, 0.020833096519533186, 0.029277237462660963, 0.06539377083461131, 0.042254606021508094, 0.16752288256201053, 0.17883404818994386, 0.14653659335547878, 0.21018201365105568, 0.07352716544823301, 0.13250958474893726, 0.14958672646072604, 0.16809280601239976, 0.18674793563062148, 0.1797262495083194, 0.15321165533556094, 0.17335684128826664, 0.10552599920981354, 0.09077485365372512, 0.20395378011368936, 0.12752249025769774, 0.1430598718504752, 0.24307410593234727, 0.18530992730971307, 0.1344943500214046, 0.16226486873722848, 0.18277874216437343, 0.21824407781804764, 0.6363444378779781, 18.7078857421875, 56.427025102799945, 65.71209115366783, 61.57157444184827, 49.63024008658625, 31.437998933176843, 38.25701398234214, 39.86315788761262, 49.690558295096125, 22.797958812405987, 3.568792280650908, 0.4284963876970353, 0.36263899577240793, 0.6424469717087284, 3.065092044491922, 10.370474130876604, 13.985020614439442, 15.621520723066023, 24.80647513943334, 30.10491082745214, 13.31111623394874, 16.704931336064494, 24.06941471561309, 39.221140415437766, 58.428771418909875, 66.18967502347886, 62.087974086884536, 64.45288481250887, 58.070674711658114, 57.36445980687296, 56.681077018860854, 58.777132803393954, 58.96775999376851, 57.876611525012606, 56.294382310682735, 58.16621972668556, 57.54237459551904, 58.24700094038441, 58.49347875964258, 57.84720159346058, 54.76857246891145, 49.883425158839074, 44.90047747089017, 45.74963923423521, 46.60311168239963, 51.016240965935495, 52.410882826774355, 50.47382816191643, 45.26485389278781, 43.065851580712106, 49.14019484673777, 57.73478254195183, 64.06311104374548, 57.7127270544729, 50.24026278526553, 55.525389871289654, 57.15964148121496, 52.75818909368208, 50.2022667854063, 52.82414767049974, 52.16804104466593, 50.20549881842829, 55.67002727139381, 48.88830023427164, 39.60396374425581, 45.829608517308394, 61.91013382327173, 62.00071704003119, 57.98828532618862, 53.26339037187638, 48.55584013846613, 51.1586033913397, 48.048838492362734, 50.47872327989148, 48.399514075248476, 49.36887687252414, 52.71953413563391, 51.67401852146272, 52.88155155797159, 52.09690101685063, 48.660716472133515, 46.530736107980054, 47.62048821295462, 53.891118649513494, 56.81486514306838, 58.845232994325706, 56.45366584101031, 55.59476091015724, 53.68939899629163, 52.863696928947206, 50.22666392787811, 51.552546639596265, 51.95402083858367, 55.294550541908514, 54.508025107845185, 55.916140310225956, 57.47277605918146, 60.76624124280868, 60.704122666389715, 63.18756741862144, 61.46188143760928, 59.86133867694486, 58.27628143372075, 55.96297341008341, 54.11868672217093, 42.8953226151005, 30.00175249192023, 19.90985489660694, 13.727315010563022, 16.60277516611161, 24.715029001235965, 16.379186337993993, 19.70693499811234, 11.686129262370448, 19.401937377068307, 8.090891136277108, 0.35635560390449345, 0.1880275629340641, 0.28773284907783236, 4.515208476974118, 23.261647685881584, 51.69366959602603, 58.581006450037805, 46.76882789980981, 31.563010754123813, 51.998088667469645, 59.63810090095767, 59.96711323338171, 33.888160413311375, 4.738855160051777, 0.11808846220974961, 0.18214128040257963, 0.12399706854334763, 0.14281389633974723, 0.11480140109216014, 0.2587186479039731, 0.07371497956374962, 0.07386100358299671, 0.1607748736897784, 0.08331307300156163, 0.1381273841064784, 0.17360057982225574, 0.11136248602621979, 0.08510526675250261, 0.18114577978849414, 0.107195251170666, 0.11463112272923032, 0.14276667468009457, 0.13176415055509538, 0.1587213596869861, 0.14361133258188927, 0.1691772647562527, 0.3168987969477331], [0.0441853812475118, 0.06776548711763275, 0.02947427910722552, 0.01445678776250251, 0.04212888333225443, 0.01876223828613518, 0.06766555094791037, 0.01624541728937578, 0.03934492364585881, 0.03987159760248277, 0.06304601778186138, 0.041542458347976215, 0.015314149317301571, 0.02037400683958925, 0.03793591175288443, 0.04016893930853375, 0.06454960322908818, 0.11263684264474338, 0.008464092745505756, 0.041857347297932834, 0.05296466075965474, 0.03798903611999366, 0.3559315589166457, 12.523235620990878, 52.13273579074491, 51.704958177381954, 52.30903456288, 33.32116611542241, 17.4452139869813, 18.249295949935913, 31.697506866147442, 36.04958249676612, 11.13622865369243, 1.6288263591066485, 0.08888551229310614, 0.18461254215048206, 0.5032231165997444, 3.65936765267003, 3.275669880451695, 10.199085185604712, 9.146437721867716, 11.0720076868611, 11.582906207730694, 7.128747461303589, 16.78324734011004, 28.412182561812866, 47.20907080558039, 42.16534991418162, 40.74827994069746, 47.36196087252709, 48.5779897628292, 52.30477486887286, 59.87190946455925, 58.98841519509593, 61.20901015497024, 55.06052624794745, 55.36425105987057, 56.76295257383778, 55.05879256033129, 51.19503828787035, 54.42048957270961, 53.35431483484084, 49.57648008100448, 46.570222608504764, 44.77161976598924, 42.318389031194876, 41.71321045967841, 46.36623974769346, 47.83038208561559, 47.11372190906156, 47.01776896753619, 42.01440142047021, 39.445829468388716, 47.9056719810732, 56.02697864655526, 53.96737737040366, 50.00306137146489, 50.44134309214931, 56.924428709091686, 54.14606094360352, 58.27035865476055, 56.00225986972932, 57.421714644278254, 53.49426892495925, 54.53589354791949, 53.92376845882785, 50.95977060256466, 21.69668278386516, 37.6060535061744, 61.31565939995551, 55.75522899627686, 51.53810055025163, 44.81074933082827, 42.929698267290675, 41.26129850264519, 41.58373302029025, 41.92051556802566, 43.02054428285168, 43.68922210508778, 46.36558078950452, 47.836842229289395, 51.19283783820368, 49.69397075714604, 46.69759765748055, 41.79436429854363, 43.15900394993444, 42.854608412711855, 48.34036473304995, 52.41775481931625, 55.37024836386404, 55.70449706046812, 54.140051872499534, 53.116019079762125, 53.57871755476921, 53.08382818775793, 53.69538845554475, 57.10034701132006, 57.141916290406265, 57.2203754609631, 57.82330259200066, 56.2989910956352, 57.11491469414004, 56.8081892690351, 57.44709237929314, 56.626003019271366, 56.694730789430686, 56.79318620312599, 53.92064625217069, 47.30998946774391, 36.43574376260081, 25.39468357639928, 10.075280474078271, 13.331077175755656, 14.875654578208925, 7.789224097805639, 12.996411727320764, 7.067586433502936, 2.7123515788585912, 1.870983932768145, 0.5602600173123422, 0.32353078946471214, 0.2298592730996109, 0.9626994257973087, 10.439677488419319, 35.16032626551967, 33.47323248463292, 32.409220933914185, 36.47090388882545, 35.70316660788752, 42.1410822099255, 49.033498533310436, 32.48960010467037, 8.003803731933717, 0.07425326358286605, 0.051928986494819966, 0.04411866265018621, 0.02368963729109495, 0.036954262008469914, 0.04795223557119889, 0.04028511271181126, 0.044713472466795676, 0.05394857046344588, 0.0163021192870914, 0.03028031277109779, 0.01440997021422992, 0.06811121493698129, 0.017228880746951027, 0.010000806707408159, 0.06351634980209413, 0.049487548549809766, 0.05960056415548729, 0.03116532435430394, 0.016181826246001067, 0.025461075804947365, 0.08333338965331355, 0.046054118673407266, 0.02224346438813354, 0.012014623949184053, 0.035528093576431274, 0.0539617280235454, 0.041668514285476944, 0.04088828437811425, 0.057950947028134144, 0.011419890741367015, 0.062352294522908434, 0.041290855921444394, 0.01312742698862548, 0.009003707842390624, 0.022010657928823944, 0.07728573836145863, 0.03516371917700575, 0.05354031071727795, 0.018054685224929166, 0.033570884486600276, 0.009881989343181975, 0.049560660150863474, 0.05764188034640205, 0.01467542255282282, 0.5423201993107796, 15.580174038487097, 58.61826896667481, 57.654193524391424, 58.272045273934644, 37.94844896562638, 21.20962835127308, 22.729799785921653, 26.528152458129394, 35.842034201468195, 13.861228650616063, 1.520654131327906, 0.0892081578832961, 0.12155478024074148, 0.6013002667215563, 3.6192209682156964, 8.261702022244855, 8.987652332552019, 7.3130694416261495, 14.285669307554922, 9.370978705344662, 10.014524921294182, 15.122697218771904, 25.257153511047367, 42.52432130998181, 46.47032768495622, 44.260193686331476, 52.70139709595711, 55.020494537968794, 55.99022996041083, 60.59806962167064, 60.725727081298835, 59.79937307296261, 57.50111126130628, 56.875795241325136, 58.56525028905561, 56.59265502806633, 55.14724200771701, 55.76475643342542, 55.77760611810992, 52.03930101087017, 49.85667459426388, 46.296970690450365, 46.42545577018492, 44.32462253878194, 49.154413438612416, 49.77995695606355, 49.66097185688634, 50.10858097384053, 43.950899108763664, 41.59949310364262, 48.71058548650434, 59.08949075206634, 56.861784535069624, 50.588365293318226, 50.70638156706288, 57.25825771208733, 55.74898066059236, 57.731389691752774, 57.05808347271335, 57.70728672704389, 54.09100263349472, 55.479745249594416, 53.91704159398233, 52.08113701112809, 24.000328048583, 40.28500879964521, 61.35405940394248, 57.56224532281199, 53.31928806920206, 46.74334426080027, 45.1582242596534, 43.13881158828736, 44.63583123299384, 42.84027214973204, 44.83331080405943, 45.099314182035386, 48.24855773679672, 50.81220319194179, 51.95443660982194, 51.011483130916474, 48.04754803257604, 44.82935705492574, 45.15749077643118, 45.32094770862211, 50.06235191898961, 54.98451463637814, 56.75201700579736, 58.77900769633632, 54.70428089941702, 52.1716143238929, 54.41883825486707, 53.866105694924634, 54.81870428208382, 57.83721916137203, 58.255747825868674, 60.705828897414676, 59.87430603273454, 57.145336597196525, 58.30431853571246, 57.89909062847015, 59.262024048836004, 58.434223513449396, 57.72670638176703, 58.84023589472617, 56.79739490632088, 47.403420325248476, 35.17943997536936, 20.63387736197441, 11.143141831121138, 11.189468945226363, 13.649946258914087, 9.061772381105731, 9.108305419645003, 12.500542748358942, 8.338860927089568, 4.396652387034509, 1.0381197400631443, 0.2169772135394235, 0.12839303427045384, 1.1696565463658304, 13.387985863993245, 37.3079925967801, 43.8177111071925, 36.16749286651611, 39.865401483351185, 41.63311958312988, 48.24868325264224, 54.5234243331417, 38.80375708303144, 9.326755942836884, 0.07197597529739141, 0.0094456764148368, 0.02714201826752434, 0.05528108081630161, 0.024261893479213602, 0.02707042543578052, 0.019348958214264245, 0.0352965435013175, 0.054427440533594745, 0.004056872229181952, 0.07739509741264967, 0.07649878220212075, 0.0026864400452693868, 0.059566794999785004, 0.08616066012050837, 0.0401973152052491, 0.05633906739193106, 0.022424931465197476, 0.04103889726402779, 0.03321798225384086, 0.05492139487497269, 0.03264751105058578, 0.03232523318259947, 0.1505467112386419, 0.08420957973407162, 0.1237911364484218, 0.1529914969878812, 0.26391597224339364, 0.14796951485256996, 0.27284913966732643, 0.09023250170773076, 0.1494070328772068, 0.15683445448596633, 0.20796374477926763, 0.10710101469510025, 0.10798416085421078, 0.18815068858525447, 0.12658666789291367, 0.07553300579949733, 0.1591590563616445, 0.23388979956507686, 0.12881777639831268, 0.15128117505340807, 0.15388106296379722, 0.1236978575827614, 0.8329496881173504, 21.071759000901256, 65.58869338804676, 67.05866829041513, 63.023365236097774, 45.50804476584158, 26.878879031827374, 29.583521927556685, 42.92514047315044, 47.45086923722298, 15.340388763335445, 2.3583118281056805, 0.15097544468458624, 0.3969479063826223, 0.7732220414665438, 7.526093855980904, 11.635718960915844, 20.86440094055668, 18.85791640127859, 20.19275780647032, 17.975822417966782, 13.433988401966712, 21.880436020512736, 31.1118773875698, 51.44364595413209, 45.85436259546588, 48.117546650671194, 56.099875896207756, 58.80236933308264, 55.83097388667446, 61.05891281558622, 59.568984816151286, 62.57771730422974, 57.6389943399737, 57.896423416752974, 58.711307587162146, 57.31378670661681, 54.91882278073219, 58.48377481583626, 55.59711433226063, 55.8150137624433, 51.565400246650945, 50.53191061942808, 47.97740036441434, 46.17316107596121, 50.77692539461198, 52.69094005707772, 51.09041690826417, 53.35602891060614, 44.41051852318549, 42.87110982402679, 51.40939581778742, 62.402591320776175, 56.763603687286384, 51.1822513611086, 52.86392050404703, 56.86207479046237, 56.239280854502034, 60.269900598833644, 59.126400255387836, 60.30952438231438, 56.48671180971208, 57.82934304206603, 54.37591183570124, 52.12298477849653, 27.09165192419483, 42.797290817383804, 63.48167065651187, 61.39844886718258, 55.93133949464368, 49.490258539876635, 46.906746279808786, 45.16805371930523, 46.525370305584325, 46.082213078775716, 47.40789967198526, 48.30393375888948, 50.17325693561185, 52.348587743697635, 54.52107091103831, 54.594831082128714, 51.39144312950873, 46.91311620896863, 47.36866812552176, 47.688992408014116, 52.9479572849889, 58.284185009617964, 61.04719277351134, 60.986003798823205, 55.6879093570094, 54.26539121135589, 54.525260002382346, 55.02704097378639, 56.75132666864703, 59.362836807004875, 61.42418746025332, 62.504121872686575, 62.43775536937099, 59.78177339799943, 60.64781704256612, 61.643667605615434, 62.143389332679014, 60.0124675996842, 60.49961028560516, 61.771595708785526, 58.01174109981906, 51.170115547795454, 38.24458399126607, 27.241780642540228, 15.156181512340424, 21.964023690069876, 25.927394397797126, 16.1270514803548, 24.27860844519831, 18.48461070368367, 5.9188286431374095, 6.183237577638319, 2.265451430313049, 0.456477350765659, 0.3305983182884032, 1.6405967791234295, 15.290547205555825, 43.99339014484037, 45.80170085353237, 46.308475002165764, 49.163144634615996, 49.19597879532845, 56.107602965447214, 61.76597102995842, 45.42230175387475, 11.483006381219434, 0.2753247987599142, 0.15445498539315117, 0.1824164285414642, 0.10821402553589114, 0.1717678063939656, 0.14447736433677136, 0.30532808073105355, 0.19088458059535873, 0.17181933346775272, 0.1039797733087213, 0.1859788446416778, 0.09771042383245884, 0.08838026198528467, 0.14229582172007332, 0.15849674270758707, 0.12303527579793047, 0.15082843241191682, 0.15100801874312664, 0.08700302741940945, 0.14834286014158882, 0.14677015824183343, 0.19940848852838242, 0.18260133152286853], [0.032901844580567656, 0.0186385361537818, 0.06964200416639929, 0.010453853868849335, 0.007581336333626702, 0.07016243067600074, 0.03969108813532418, 0.0418164458636555, 0.051723119517367695, 0.02291738044380421, 0.04726904985164443, 0.048865305124631817, 0.02821975267462192, 0.04195501201695973, 0.03471661494263718, 0.06502715945844689, 0.0411978451865575, 0.04159058016093989, 0.10771492691410166, 0.03245768595426794, 0.028002601222045002, 0.03349179356929756, 0.280442082233006, 16.551696100542625, 42.76966556426018, 49.30189063472133, 43.95766127494074, 33.84725009241412, 28.544491952465428, 30.711489685120124, 55.42075672457295, 36.90633796876477, 7.605961647725875, 0.7404040605310471, 0.06948792090218875, 0.2745494564935085, 0.7097871421325592, 2.3863459883197664, 7.370525300502778, 7.332247870583688, 7.34735684048745, 10.264934916650096, 7.994172842271867, 7.0084562128590004, 11.814917345200817, 18.421376212950676, 25.048742294311527, 27.064911165545066, 40.38813183384557, 43.846371866041615, 55.49597993973763, 51.97014570236207, 59.10507040639078, 57.46890860219156, 55.56547257208056, 49.40822216772264, 52.340566496695246, 54.657479178520944, 59.59995585103189, 54.04939805307696, 51.71915323503556, 51.39280026958835, 53.13026905059815, 48.02641822445778, 44.12261263016732, 39.57969603999969, 44.620749719681285, 47.449598389287154, 50.618034101301625, 50.04868638130927, 48.29602626062209, 40.12029670899914, 39.69461756367838, 48.148443160518525, 58.465904497331195, 57.70458421399517, 54.53588962554932, 54.457230414113695, 57.7840357442056, 55.024915049152995, 57.84693487228886, 54.98956664916008, 58.44708496524442, 53.09214361252324, 57.78758941158172, 52.23840836555728, 54.32273234090498, 23.57960285678987, 40.899342183143865, 62.93086005795387, 50.09211094148698, 51.16558128787626, 42.479519997873616, 44.209728471694454, 40.80947283775576, 40.604411325147076, 40.13600580153927, 40.545387498794064, 41.471572845212876, 45.859504822761785, 49.667808548096694, 55.14897569533318, 51.91286340836556, 51.03889265368062, 45.391922996890166, 41.47879785107028, 39.85710567043674, 41.70844477991904, 43.474476260523645, 49.9017269380631, 54.939426991247366, 56.03446252884404, 55.854386514233006, 54.94373375369657, 55.023506918261134, 56.41306538735667, 55.77144015219904, 54.55339908599854, 53.822441870166415, 53.517740388070386, 54.035434415263516, 54.144327255987356, 54.78321467676471, 55.39824231978386, 56.91913350935906, 55.52075755211615, 59.15725361916327, 56.972050205353774, 54.19880897768083, 40.0167186798588, 26.84029663762739, 9.715209834037289, 7.390053310701925, 10.429027272808938, 8.530260824388074, 10.539739112700186, 8.752915147812136, 13.57099679208571, 3.673406796109292, 1.5384716204097195, 0.3081068348500037, 0.022863557021464073, 0.4630927344964397, 5.6066849539356856, 28.009761110428844, 33.15221002024989, 31.07954921260957, 22.844968418921194, 31.338107931998472, 45.65453744703724, 52.049130470521995, 41.829579337950676, 11.584060365153897, 0.2399144375756864, 0.03422469073425859, 0.03246840735476825, 0.11496788731986478, 0.11982359007121095, 0.0727641495365289, 0.08371785853899295, 0.02001038320632952, 0.048632559952356165, 0.00874888593135702, 0.039301850352316134, 0.05122587482835497, 0.046967306970468456, 0.05396696040406824, 0.05214453299319552, 0.032168633319557674, 0.050457193696450804, 0.03793292784041936, 0.06829969554899201, 0.023981767684041012, 0.04481595970930592, 0.023390288434682355, 0.10140145843427989, 0.039106409831513325, 0.014611461872024643, 0.042985473053469773, 0.06824446827053063, 0.012733947951346638, 0.0018382331214642394, 0.015605485851636097, 0.027957890415564183, 0.039233044165396885, 0.0038954666008301562, 0.029265884039623123, 0.028882736655613108, 0.0025194211470549025, 0.048618253260370226, 0.04688278065934297, 0.10264048307773568, 0.08127388484295338, 0.08331383142860667, 0.07089229796322123, 0.03177702449442398, 0.022175215530179204, 0.05354394197403904, 0.4539099756267763, 21.42732774057696, 53.27213725736065, 55.002326119330625, 49.817458737281065, 35.560592374494, 27.154864841891875, 23.71391069504523, 50.716473825516246, 37.87748544446884, 8.81651932193387, 0.8279929766731878, 0.1059967449175254, 0.2350777721092586, 1.3882121155338905, 4.830727856005392, 11.811532339742108, 9.603059464885343, 9.96026873588562, 8.150397414161313, 8.908008606203142, 11.229683045418033, 15.152307191202718, 24.4619341434971, 27.616331692664858, 32.96327729378977, 44.179965526826926, 51.85978589519378, 56.31138578537972, 55.27203613711942, 58.521280519423954, 60.81478841843144, 56.36550664901734, 52.82210803801014, 54.43384916551652, 57.80745229413433, 58.09320088355773, 56.20903545810331, 54.15074425358927, 53.68619441986085, 55.678048518396196, 49.707903015998106, 46.380493640899665, 43.711693363804976, 46.70902744416268, 48.73380199555428, 52.539387518359774, 52.43483281904652, 50.26495018313008, 42.76985383802845, 41.18057220212875, 51.83669882435953, 60.27889851600894, 59.97230252911968, 55.935308933258064, 54.61545882686492, 59.67806985301357, 58.33534056140531, 58.69220564442297, 56.58151941914713, 60.06687087397422, 56.09354519074964, 60.610719265476355, 54.22499472095121, 54.45627335579165, 25.59968233108521, 41.66230986195226, 64.78796897395965, 53.93346848026399, 53.2187145756137, 44.30855651055613, 45.65237229870212, 42.46281070093955, 43.00845553798061, 41.77272850467313, 43.99918348558488, 42.55551591996224, 48.629514017412745, 51.411953203139774, 56.572219479468565, 53.56928817687496, 51.27328172806771, 47.92362074698172, 44.3254070128164, 42.24891993307298, 43.12831924807641, 46.533179744597405, 52.93685305503107, 58.27957622466549, 57.3413452794475, 56.155663767168605, 54.18665747488699, 57.16155952022922, 56.17938626197077, 56.252452173540675, 55.277762797571, 58.10448946491365, 57.02570822931106, 57.367907570254424, 56.598566039916015, 56.3620118171938, 57.32728750474992, 58.88174241588962, 58.55671521156066, 59.68518895487632, 59.34002822445285, 55.23738591901718, 39.34901752779561, 20.118713263542425, 9.541077190829862, 9.964744160252234, 15.110812437149788, 11.76580927064342, 13.55125746419353, 9.69414866739704, 9.123088832824461, 7.708443374403062, 1.842394389452473, 0.1388883085981492, 0.09248097742637319, 0.5733201616714078, 6.528029114969316, 29.90167517815867, 32.766140930114254, 36.923741525219334, 31.75530691300669, 35.39450745428763, 50.54569775058378, 58.74527923522457, 48.79370443282589, 14.382555773181302, 0.22950043751587793, 0.0434164971023077, 0.013074221224674295, 0.03093134769569001, 0.042385308282269586, 0.04025149294325421, 0.04609718047563107, 0.0371940475287697, 0.04702234272694877, 0.016732059321516467, 0.030087936601992098, 0.021357692462662538, 0.016803627255402746, 0.01957748607251673, 0.024014883749787847, 0.005417327554295621, 0.07313528083144658, 0.028419443068184683, 0.03844524147890268, 0.014435698319556973, 0.039274612096168345, 0.06340281940215538, 0.09777551066250571, 0.1502871453281372, 0.10013348332816556, 0.11976686126041798, 0.11730319144384516, 0.09089234089779277, 0.09024098230105254, 0.08956291021839266, 0.19441825307665334, 0.13564613257204333, 0.0930374943380875, 0.11942591382971696, 0.09007503233489492, 0.09814431305013357, 0.11990333982412854, 0.1689502729042884, 0.16108003715353628, 0.21384233578799233, 0.1567207517162446, 0.17978346095450465, 0.19249463694230204, 0.15604342273887128, 0.17098938445410422, 0.7633044510599106, 27.44764624103423, 59.68831508390365, 63.229956473073656, 56.360509549417806, 45.32827077373382, 38.725003734711684, 41.747158573519805, 67.38646076571557, 44.23052487834808, 9.378564569257922, 1.4384426008309088, 0.28402795594546104, 0.5716115404521266, 2.149327700176547, 8.054369457306402, 17.040558745784146, 17.48206465475021, 16.31925546353863, 22.99493043653427, 15.813499169964945, 13.505335334808597, 18.95067849466878, 26.874225139617923, 34.06828349636447, 37.524993804193315, 51.184024272426484, 55.268000018212106, 58.58593294697424, 55.25875891408613, 60.4554130185035, 61.249908708756976, 59.05447575353808, 54.315424965273955, 58.49971532821656, 59.31709804842549, 61.78455521983486, 59.284609056288204, 57.75079365699523, 55.29833170675463, 57.72210936392508, 53.349356958943034, 49.42372729701381, 43.23743958627024, 49.4377262361588, 52.02282313377627, 55.646187105486476, 54.54661338560043, 53.23658489411878, 45.11426625713226, 42.70538183950609, 54.62361735682334, 63.15960091929283, 61.159772642197154, 56.56028762940438, 55.070716565655125, 60.025454567324736, 60.69435988703082, 61.291878069600756, 58.13622143960769, 63.46886411789925, 58.65792020674675, 62.94983256247736, 57.12431269307291, 53.295122346570416, 28.967074386535156, 45.92784820064422, 67.5287643555672, 55.71462854262322, 55.694573463932166, 45.97819182180589, 46.95148483399422, 45.9571796847928, 43.82522244607249, 45.00733852386475, 46.26057109525127, 45.7293801922952, 50.97451086967222, 53.59867065183578, 60.196622879274436, 57.010681629180915, 54.87566886409637, 50.56032819132651, 45.87280950238628, 43.74390386766003, 45.546213349988385, 49.4238567352295, 54.35184024995374, 59.86450010730375, 60.92657989071262, 58.283808462081424, 55.894516283465975, 58.10059455133254, 58.81857656663465, 59.38741045613443, 59.40942671991164, 60.236917388054636, 58.72167833389775, 59.92597149264429, 59.68293751439741, 59.61297812000398, 60.816455425754675, 60.5405362959831, 60.62917009476693, 63.79140846190914, 63.06658975539669, 58.155354761308246, 44.19606293401411, 29.271552293531357, 14.998793467398613, 13.171899549422726, 16.308804308214498, 17.313830275689405, 22.824642696688255, 19.88751111492034, 24.326078930208762, 9.726204237630292, 3.2655266311860855, 0.8367134474458233, 0.37192566680812067, 1.2252940189453865, 7.1253256836245145, 35.961411537662634, 44.26697938672958, 45.637953665948686, 36.280535574882265, 42.99025181801089, 58.43434510692474, 67.81032777601673, 55.58153860030636, 19.51552333370332, 0.760050293418669, 0.18021125977318134, 0.11123421226417828, 0.31824101363458945, 0.18091344064281834, 0.2879389267294638, 0.1582285966123304, 0.15854863750357784, 0.14030950894999888, 0.10180847328757087, 0.163629807591919, 0.14198488195336637, 0.10437887447375445, 0.13979541798753126, 0.07971424474230698, 0.10993863501015211, 0.14507554110980805, 0.17721536569297316, 0.18308401288044068, 0.10005755635399012, 0.11505919733955977, 0.0909158061709135, 0.17406317435445326], [0.061061654705554254, 0.05956790582727521, 0.009511079256152435, 0.042452486532349745, 0.05873974179849029, 0.07128301046548352, 0.08516889035461411, 0.04601279206033196, 0.0780898931946966, 0.056847240325183644, 0.048180204185266653, 0.03756394925256891, 0.04461282383530371, 0.02952595556815786, 0.03182022036203454, 0.07836846574660271, 0.06031374604771696, 0.00762866524558875, 0.0058657815398257835, 0.06837740750803102, 0.07946690559507379, 0.06748758106222076, 0.8982094088869711, 19.6764366088375, 43.87158486150926, 54.907016446513516, 44.463168498008486, 25.55333560512912, 15.720024185795939, 33.47313442537862, 37.11005410840435, 21.64312674153236, 5.467746267395635, 0.24530247184297732, 0.15275639992567802, 0.0394261404571514, 1.2910850370122542, 3.4589426267531613, 8.84177448288087, 2.821692060078344, 4.622989325754104, 8.896762190326568, 8.489729992804989, 14.583168337422034, 11.475280292572515, 17.769925440511397, 24.134231882710612, 42.22635061510148, 41.50128479926817, 58.488583641667525, 56.186524975684385, 54.86739266303278, 57.86223603833107, 55.08304849747689, 50.332175685513405, 50.033302845493445, 48.479585339946134, 50.93383981335548, 53.72525730440694, 56.710565397816325, 55.455712887548636, 53.015237700554636, 50.96337526075302, 46.79613544094948, 42.5795090583063, 41.974004930065526, 45.15754961198376, 50.49290657043458, 53.80221812955795, 50.04135154908704, 46.43449291106194, 39.52056238728185, 39.82374591212119, 47.96478602194017, 59.8401225766828, 47.704470080714074, 47.74636099415441, 57.52259016036988, 55.70965105487455, 54.99701523011731, 53.627221584320075, 53.02670671093849, 49.76784859934161, 47.65624453944545, 50.158226413111535, 53.34251634536251, 58.27321021787582, 25.916429411980417, 38.159692133626635, 60.572727187987304, 52.76502578489242, 54.14977150578653, 49.249291650710575, 51.52267386836391, 47.203744226886386, 47.406099304076164, 40.07971978956654, 40.7735792283089, 39.006971159288966, 43.575383155576645, 50.62786356095345, 53.63313259616975, 53.526063657576046, 50.22188255863805, 46.96341668405841, 45.25503620024651, 41.34298970622402, 40.573832527283706, 39.24196427868259, 43.02161116753855, 48.75432383629584, 53.56888417274722, 55.4844795503924, 54.992610408413796, 55.21700528360183, 56.529234224750155, 53.42382707903462, 53.72345301412768, 51.25629002048124, 50.08214419887912, 49.267687566818736, 49.14244236484651, 49.64264262107111, 52.5818040294032, 52.19801971989294, 53.530503780611106, 52.26927349644323, 54.731337408865656, 53.79635418615034, 45.92546339957945, 21.068472054696855, 13.333621813404946, 8.983383813211995, 17.081971130063458, 6.915755896799027, 5.354171097278596, 8.888549727778281, 10.207929149750742, 4.567118104427092, 0.6335944886649809, 0.19555129711666416, 0.12796208683040836, 0.3994682743664711, 3.3911471549541723, 18.632586040804465, 44.4853259671119, 27.693672987722582, 19.10613967526344, 36.02200431208457, 47.63404000189997, 54.84816128207792, 45.00429084224086, 19.895891258793494, 1.208154609607112, 0.08272371390053342, 0.03651419429168586, 0.02462724464074258, 0.02370216665909656, 0.0226120695081209, 0.043833126359048395, 0.021063353821274736, 0.051031139108442494, 0.02923386539482782, 0.021483464947631283, 0.06850803316000008, 0.02329557506938375, 0.07915665530749867, 0.026480135537924308, 0.02534896075244873, 0.046252309449858246, 0.03458333862645011, 0.03392687788413417, 0.040779534366823016, 0.03937777732649157, 0.03596549147679921, 0.020184501584979798, 0.1082999959227539, 0.05322485869269698, 0.0540331925355619, 0.02693005514541461, 0.02345249285891412, 0.03226829369762733, 0.020400586260122158, 0.05105515979530831, 0.05215450745796965, 0.032581707928329706, 0.04152653138003042, 0.07392552350797961, 0.02750177315676645, 0.032379456885880044, 0.024700049806626576, 0.05556844805757846, 0.07552738271413312, 0.00798663227713757, 0.06325696392225162, 0.13283075945031259, 0.03474708992026506, 0.053992578384256175, 1.225430811605146, 25.368821428668117, 50.35605899749264, 62.029362109399614, 50.726962243357015, 32.9467248916626, 21.145501521325883, 34.02567871155278, 43.708649604551255, 25.66841990716996, 5.987996699348574, 0.37479791429735004, 0.08143732204071938, 0.18902568356885066, 1.588020839037434, 5.670376400793753, 10.452790952497914, 10.00741562535686, 11.397782102707895, 9.414275788491773, 7.824412170917758, 12.309776313843267, 15.307947820232762, 20.812902181379258, 28.49918857697518, 45.64961095010081, 47.34980936973326, 58.27731301707607, 55.40767562004828, 54.13255230073006, 57.07509086978052, 55.457340671170144, 52.48717684899607, 52.53702232914587, 52.1279897228364, 53.51887003068001, 57.38369903256817, 58.361055620255016, 57.05009752704252, 56.19531892961072, 53.161608788274954, 49.039511526784594, 45.3649135558836, 43.63796457167595, 47.24582341409499, 52.818377863976266, 56.34311776007376, 51.740220285231075, 48.4804835627156, 42.05151096467049, 41.52039066437752, 51.444669692747055, 60.46934919972574, 51.22294595164638, 51.916487678404785, 57.2734921978366, 58.02582240873768, 56.983279951157115, 57.371112146685206, 55.505778020428075, 52.85450681563347, 49.60976531428676, 52.42691355366861, 54.30171235915154, 59.444418184218875, 27.594346807849025, 42.554468647126235, 62.96643595541678, 57.066057651273674, 56.25897115276706, 52.344563391900834, 51.69073566313713, 48.33493617273147, 48.41308939841486, 41.94017056495913, 40.68902861687445, 39.843773534221036, 45.799602385490175, 52.08679699128675, 54.113203248670025, 55.4697157490638, 52.400147299612726, 50.059974962665194, 46.52488000931279, 44.15741189833611, 42.2813069435858, 43.69461928644488, 44.55782705737699, 51.894204693455855, 55.743563867384395, 57.38574258742794, 56.339007116133175, 57.172581380413426, 57.67562535501296, 55.844066758309644, 55.35948538011121, 53.92639252447314, 52.749367683164536, 51.89703664472027, 51.17122950092439, 53.61969063358923, 54.020384280912346, 54.297758610017844, 54.41890885753017, 56.194640359570904, 57.132184890008745, 57.57129423079952, 44.1433580460087, 26.369218018747148, 15.544030377941748, 11.375397136134486, 10.170254784245646, 11.43665082993046, 9.382544794390279, 11.732533843286577, 10.000028821729845, 4.35634316936616, 2.9105165841117984, 0.1077303789075344, 0.07340174153326981, 0.3896578136951693, 3.961684088553152, 22.517262235764537, 47.537043709908765, 38.98329181055869, 27.724365534320956, 39.77862688802904, 55.42885641897879, 57.54099392121839, 52.55129191183275, 25.328424938263435, 1.734695542723902, 0.06798716998028179, 0.07152473418823174, 0.023469086323354035, 0.051144818895526474, 0.004228756503923046, 0.12189447128724669, 0.034974625694655606, 0.04357501984603944, 0.0475934153092244, 0.001413251950232793, 0.08523151038154479, 0.06934767318589073, 0.0123217849872045, 0.013879021486988472, 0.047764589995025634, 0.06358080844004309, 0.04911473952233792, 0.09182717500915451, 0.03295009662847846, 0.034187198391244296, 0.10208902234632163, 0.0902116947597073, 0.18488502430339016, 0.1898616693553425, 0.12551440526881527, 0.2583892300965325, 0.14830740559245312, 0.14657774759877115, 0.10242289112460229, 0.12606289357908312, 0.2342128741645044, 0.08107985775437086, 0.14608487727180605, 0.22788023816481714, 0.22650376202598696, 0.1275810806621467, 0.11435156958478113, 0.14553513257734238, 0.10681793754619938, 0.23990852337691093, 0.171626846215898, 0.34273140432853855, 0.1668836741197494, 0.21767371003666233, 1.9280386067205861, 31.432837094030074, 59.159167735807365, 68.70110588689005, 56.846271561038115, 36.495759948607414, 25.74381962899239, 45.26989021608907, 48.689134044031945, 28.4061421117475, 7.3842952712889645, 0.6378332837935418, 0.32609237297888727, 0.29504957098153334, 2.744349539279938, 8.138836718374684, 18.366798393187985, 13.578539509927074, 11.784531724068428, 20.56308250273428, 15.449549305823544, 19.980422258377075, 17.870128270118467, 25.027940004102646, 34.358397683789654, 52.340515505883005, 50.65461020315848, 60.453636184815444, 56.41241035153789, 55.58031874318277, 57.56580683492846, 58.808774563574026, 56.56346867161413, 55.75364828109742, 54.63265842007053, 55.72248112770819, 59.50126509512625, 61.722534702670195, 59.80562140864711, 58.77528536704279, 54.731906152540645, 51.824868955919825, 47.695911468998084, 46.41295517644575, 49.089251102939734, 55.44958614533948, 58.24814235010455, 54.40119151146182, 50.46759551571262, 44.179808632020034, 42.25871801376343, 53.053037581905244, 62.700946407933394, 53.683970435973144, 54.112595281293316, 59.53850407754222, 61.73989511305287, 61.019716570454264, 59.98292822991649, 58.49422008760514, 54.7844776799602, 51.44235941671556, 53.61150072466943, 57.27253906188473, 58.11518576837356, 31.29810367861102, 44.24260577847881, 63.7519415732353, 58.79290073148666, 58.02519090713994, 53.80339484060965, 54.45859539893366, 50.884578766361365, 51.59372368166524, 44.20160132069742, 43.2043347820159, 42.83457686824184, 48.05219211886006, 55.5221107698256, 57.6046226101537, 56.66777626160653, 53.646390207352184, 52.262036723475305, 49.552941937600416, 46.85735187222881, 44.63188925097066, 44.40290520268102, 46.88145483693769, 52.06327845973354, 58.029101510201734, 59.67904652318647, 58.54024125683693, 58.94627324996456, 58.95855811334426, 57.58880369124874, 58.217253684997566, 55.34985988370834, 55.081216750606416, 54.21476125717164, 53.39411120260916, 54.38345063117243, 57.29012696973739, 56.229153294717115, 58.1772651210908, 58.73557921378844, 60.50110470864081, 58.64918116600283, 48.34344379363522, 26.586083904389415, 19.822970474919966, 16.073675867049925, 30.742692139840898, 14.572924087124488, 12.172643388471297, 22.53143179801203, 20.701536286261774, 10.419103676272977, 3.0162394142919973, 0.5526546028352554, 0.508367182506669, 0.8055630254168665, 4.80362182663333, 24.577863716310073, 58.356686099883056, 39.40637434682539, 32.48726629441784, 49.71747752158873, 60.94142998418501, 66.08870537050309, 62.078242686487016, 31.9945244250759, 2.5090154188294567, 0.1891851371094104, 0.13967953952810458, 0.11087261110303864, 0.13234924254638533, 0.15810750875501864, 0.25740888270158924, 0.16394546646023953, 0.12153541353801567, 0.09392091628885078, 0.10754797337276321, 0.15144315668411795, 0.1225833222270012, 0.12920085100396989, 0.12300071757166617, 0.16692590088613574, 0.18356362988631572, 0.18629488655396048, 0.2574033055815005, 0.2042203633895805, 0.14998190525558688, 0.18966835472852955, 0.21518151876666855], [0.10035203289120428, 0.04620337941413445, 0.08783917408436538, 0.020046199732009443, 0.07199711166322231, 0.016287144183391528, 0.05289225012905175, 0.018489495663332845, 0.07164655748995082, 0.026189937601767244, 0.04656741673487329, 0.0300266208397525, 0.047138730634845076, 0.032487774057494055, 0.1019058583845054, 0.03993572299218467, 0.026132697427284815, 0.028412138419826666, 0.04845402699204222, 0.10054608296242454, 0.047661049381619504, 0.11323961594532575, 1.3518722139058577, 22.938326712577577, 45.26855661023048, 46.59905595164145, 32.89222551930335, 22.887443765517204, 19.711649687059467, 34.69819261181739, 42.606349837395456, 20.601023589411092, 2.655017803753576, 0.13452188322140327, 0.047302367015471386, 0.33171677601433575, 2.0099243353451453, 3.464147366823689, 9.63717329886652, 8.461582083855907, 15.695123999349534, 2.8944157448507126, 6.57099622872568, 8.294977449601697, 11.86113267175613, 27.517227126706032, 36.33139302653652, 51.16112155299033, 56.77957165625788, 54.603279867479884, 54.942011833190925, 53.76744631798037, 52.98677698258431, 56.07624753828972, 52.709641918059326, 49.03236496833063, 42.746460822320756, 42.24352275171588, 46.24572492414906, 48.514808224093535, 47.81838355525848, 45.8911975737541, 44.862144147196126, 43.448835726707216, 39.18859651011806, 42.706013341103834, 48.279744502036806, 51.082399583631954, 55.28815707852764, 51.90005686975295, 48.64627430515905, 39.49504344694076, 39.363589132985766, 47.43525820393717, 57.67802976792859, 53.514818222292014, 57.18442301596365, 53.84780391570061, 54.095623185557706, 52.14095707862608, 48.37229674862277, 43.48922437237155, 45.203429575889345, 43.12226703090053, 52.04423927491712, 50.08897304534913, 60.423167213316894, 26.410744151761456, 35.18341725872409, 56.48353076750233, 52.048777457206484, 55.739825848610174, 52.441536149671, 57.07901323995283, 55.95769782220164, 53.86818062874579, 50.78534280100177, 42.61839151382447, 37.2644111417955, 41.08379948523737, 47.3516175823827, 54.97348885382376, 55.37834805826987, 54.02325937824865, 51.95761372966152, 49.85269338853898, 46.81346055000059, 41.60764378886069, 41.43011731486167, 41.187573632886334, 41.96225743139944, 51.44681915160149, 54.5660291179534, 52.8446695112413, 56.09305881684827, 55.488817691802986, 50.64232141740861, 48.51578097189627, 45.661664393640336, 42.80773216678251, 44.26910138899281, 45.936559784796934, 48.61256937826834, 47.39517158077609, 49.078821520651545, 50.08699224841211, 51.08556493636101, 55.52075362974598, 55.879540674148075, 48.936945469148704, 23.87046817810305, 14.810838391703946, 9.551527365561455, 10.51575872205919, 11.451255775267079, 13.488556415803972, 5.818128162814725, 5.153071668840224, 6.450134765717292, 3.228474206501438, 0.12788910163386216, 0.056041541824778246, 0.17025352635931584, 1.651096473778448, 11.957874990278675, 31.624162466295306, 32.22394777882484, 19.99027721343502, 24.959018076619795, 39.254963013433645, 49.25543800477059, 51.58272143333189, 29.432410655483125, 3.7685875210069844, 0.17338964517318434, 0.06986393983806334, 0.04008415635795363, 0.018904336104770342, 0.04692340630196756, 0.06713258357898844, 0.05038791636545813, 0.06812156478483831, 0.03131022796996179, 0.011810629099096743, 0.06608944761777116, 0.024990862528342875, 0.029390610814575228, 0.08950709305222958, 0.00714240194816563, 0.03839001037000168, 0.07032129432885878, 0.07063232602611666, 0.031132524299825874, 0.051454486956279126, 0.014251251160467585, 0.04410846985035366, 0.02561521078009279, 0.02237361698080936, 0.0982391011090048, 0.016890093684196472, 0.030933596163747773, 0.04001664102918679, 0.05376912202806242, 0.03750623984923286, 0.026014206608036355, 0.04431743948389927, 0.04509729017773944, 0.06060878948999509, 0.08575623464440146, 0.043105105343725414, 0.11291511642235903, 0.039009721874589884, 0.038646144206605615, 0.020550854406469775, 0.028030523211665215, 0.09146957282697962, 0.057801268769488226, 0.05031469368165539, 1.7124976241780867, 28.220290407057735, 52.89310293812906, 52.10160786105741, 37.960423961762466, 26.853054146612845, 18.369881376143425, 35.77144330547702, 44.412769963664395, 21.674499819355628, 3.1689512585439994, 0.15665522055520167, 0.03271995998558498, 0.5021776210877203, 2.4093553471949796, 7.397951003043883, 11.167863549724704, 10.3597846915645, 18.370116718353763, 7.958486137851593, 10.52493412648478, 9.97081304750135, 14.402656939721878, 27.75034143078712, 41.602732981404955, 52.79283931178432, 56.620907860417525, 54.50036471889865, 55.242936072811005, 52.833349550924, 52.98918139549994, 56.61262773698377, 55.29482510782058, 51.07933621252737, 43.954590059095814, 45.56012599698959, 49.09227917271276, 52.29331762559953, 51.746692196015395, 49.85021837296025, 48.15296565332721, 44.846368374363074, 42.298832093515706, 44.85482108208441, 50.62022278385778, 53.960611281856416, 55.76612534061555, 53.643162096700365, 49.86198156110702, 41.9321414732164, 41.88234306150868, 49.289676374004735, 60.99920257445305, 53.28802285655853, 58.57541707254226, 56.5205853985202, 56.446707556324625, 55.09244649640976, 51.027113776053156, 44.77087451565651, 47.157005263913064, 44.45409213342975, 54.522945803980676, 51.934903206363806, 62.34045313250635, 27.620461948456306, 36.547260668969926, 59.0579156721792, 53.89873197001796, 58.09708403002832, 55.509198327218336, 59.23607364777596, 57.806157911977465, 55.79239345365956, 50.88204491523005, 43.73071293677054, 40.607313879074596, 43.398754904347086, 49.42337820606847, 56.670380715400945, 56.56311958066879, 56.676119142963046, 54.858951722421956, 53.033225690164876, 49.024747725455995, 43.34526554230721, 41.83856941038563, 43.273870560430716, 44.9748573764678, 53.89937523872622, 55.89945846988309, 54.12864954240861, 56.47120668042091, 56.454395401862364, 53.780852979229344, 51.69605831946097, 48.05446709356001, 45.08315793929562, 46.210698158510276, 48.403793381106475, 50.119979381561286, 51.0769945575345, 50.00694059556531, 51.749331951141365, 52.78277058755198, 57.98721451913157, 56.88708774505123, 51.50021045438705, 30.269677831280617, 21.5229021733807, 10.817275239575295, 11.762773356130047, 16.55300028862492, 9.449957589949332, 11.063876613493889, 7.402742178209367, 6.831122915590964, 3.089195989793347, 0.8073266211055941, 0.23809254259592105, 0.18800146997936312, 2.0292803741270498, 15.187235897587193, 36.453021803209865, 33.0589242904417, 24.31704375051683, 33.63395944718392, 42.789340173044515, 56.454356178160644, 59.312261766003026, 34.46550192371492, 4.359654630384138, 0.19630488248602038, 0.05560309055351442, 0.12282104697078468, 0.09266291564751057, 0.023327118739666, 0.034907014604898236, 0.03761442295546013, 0.0720035161582693, 0.07691756416592868, 0.04344679204927337, 0.04152345936745406, 0.06922464712613052, 0.059751514120087515, 0.03378872924874868, 0.025128775591691657, 0.08379030747399216, 0.06643181997201135, 0.028655654788317702, 0.03811524910551887, 0.0839017809278542, 0.03410527294862174, 0.04781466533219622, 0.18429734293491612, 0.3119631682432467, 0.19844982142169632, 0.07750983440106915, 0.1812710198423555, 0.08371493974400145, 0.09943011502224593, 0.15609605297926935, 0.15538397425365064, 0.19085828845779743, 0.2280313719905192, 0.17703210213972678, 0.21717245870780563, 0.13181601470756915, 0.2610241435468197, 0.1298822249255834, 0.11548884243013398, 0.1457962766289711, 0.16479669739642452, 0.12663122356658982, 0.16535111522722631, 0.18902969786957388, 2.617521170646914, 34.35451453731906, 60.12230573161956, 58.25145675290016, 45.009782160482104, 35.157737501205936, 29.133122044224894, 47.079593366192235, 53.436159010856386, 27.019184174076205, 3.620759027619516, 0.32325729607574405, 0.19855410130994938, 0.8404980443658367, 4.4043039506481545, 13.50691604998804, 19.209774578771285, 16.25726240296518, 24.29243480005572, 10.307583828126232, 13.666744789769574, 12.46344595186172, 16.949869625030026, 33.086624068598596, 43.32068404843731, 54.68941511646394, 58.857682597252634, 56.111450810586255, 55.337214162272794, 54.185814165299945, 53.719303146485366, 58.239842614819935, 58.33617994862219, 53.97803445016184, 46.53899269719278, 46.93141014345231, 51.136951907988525, 54.84465860551404, 52.70705315374559, 50.525521078417384, 48.530125079616425, 48.26762437820435, 44.066922818460775, 46.18907020938012, 51.97398178039059, 55.75086732064524, 58.745326303666644, 56.47726281996697, 53.21420384991554, 43.42356781805716, 44.114983620182166, 51.6709904516897, 64.02511112151608, 57.61501296874016, 59.22087838572841, 57.379458950411895, 59.52352846822431, 58.073777306464414, 51.791387604128936, 45.96762887893185, 49.76145513596074, 46.566943507040705, 56.569881746845866, 55.33003230248728, 61.73536477550384, 31.561067219703432, 39.597158432006836, 60.76360933242306, 56.49201485418505, 59.88275481808571, 57.58350849151612, 61.968404554551654, 59.52167318713281, 58.3828483089324, 54.910275936126716, 46.667132608352176, 42.21767433228032, 46.33037359483781, 51.90712498080347, 59.71828199202015, 59.6215759554217, 58.865115488729174, 57.49312531563544, 53.66502538804085, 53.29185501221688, 44.75775810980028, 43.895381881344704, 45.078972770321755, 46.05814149302822, 54.880771867690555, 58.20942463413362, 56.079805128036014, 58.32836658723893, 60.420954996539706, 56.21775488699637, 52.84122959260018, 49.566077955307506, 46.95490514078448, 49.1009868344953, 50.66313351354292, 53.923062432196836, 53.81176517855737, 53.71499638403616, 53.9410190428457, 56.09030923535747, 61.426835060119636, 61.74571983275875, 54.43377464048324, 28.81621610733771, 19.292687600658788, 17.44322926767411, 20.105669421534387, 19.622533436744444, 24.11982697825278, 15.22465923140126, 13.345676237537017, 12.209496017425293, 6.528618451087706, 0.8911824214362329, 0.9402183611546794, 0.4058469982156831, 2.2884019536356774, 16.744574731396092, 43.59045290177868, 44.16324446278234, 31.46069180580878, 38.269322379942864, 50.754681633364775, 61.765555258720156, 64.91220612679759, 42.04711006533715, 6.913597122315438, 0.41092144205204906, 0.16889641692321147, 0.3518028965880794, 0.17767797554692916, 0.11090814226096678, 0.20738931673188366, 0.19437175153964953, 0.13413166867629175, 0.21918037515734473, 0.13737560670462348, 0.14371524474793865, 0.13828935041542978, 0.10591880313210911, 0.14729109803034415, 0.06901351329419883, 0.1513795407428857, 0.1481437845335853, 0.17349908849404705, 0.1490445353931958, 0.3128144145011902, 0.11624606671713053, 0.19124539268593635], [0.10843535599809502, 0.035030921665771354, 0.0098310942919324, 0.06535037195370083, 0.020218935321956392, 0.04384999178470143, 0.05515173070072647, 0.02939621666296115, 0.016786351972710223, 0.06180691652961316, 0.018658998362239332, 0.016312304426044706, 0.025985959031048323, 0.054325780666042725, 0.05233215175629143, 0.0960266238619243, 0.05846220346528196, 0.09278394987866764, 0.04178898161157005, 0.025324206536395416, 0.03812749119054887, 0.11481519833567644, 2.5991041717990755, 22.262563128625196, 45.69852290614959, 44.23358824945266, 37.60058179978402, 18.04271451888546, 22.320516147921165, 36.758327330312426, 34.216376504590436, 12.877023604608352, 1.3018519431352615, 0.1055824752115915, 0.1292713004494867, 0.549938790500164, 1.182520694790348, 7.541880905628205, 8.377921850450578, 11.620253055326401, 15.461581176327122, 9.174933741169593, 4.790261253233879, 9.480401066041763, 22.41906177613043, 33.69295581694573, 46.78563525599819, 55.64284524609966, 53.36801175148257, 55.07095190786547, 55.043314887631325, 52.54601240158082, 52.28615930003505, 55.05009666565926, 53.26993680769398, 50.22742486769154, 47.00691576926939, 40.5709574299474, 39.11908426592427, 39.036377168470814, 40.23505741550077, 38.704128880654615, 39.701238524529245, 39.42029483856694, 40.08236346706268, 43.55266086516842, 47.63693078871697, 51.063325097483975, 53.65727086221018, 53.308564309150945, 49.556919220955145, 41.40274701579925, 39.19079695978473, 44.88841226024013, 56.719712365058164, 57.92357798545592, 55.58952062360702, 54.075222938291496, 52.81536156131376, 46.22266530990601, 43.19060256404262, 40.12289724042339, 40.46808934980824, 42.33500026887463, 50.673531716869725, 52.23210903906053, 61.33469074003158, 31.67634960143797, 29.287612438201908, 48.80001160406297, 54.3162408182698, 54.60232280915784, 50.621685827932055, 54.34680784902265, 53.66536663424585, 55.810903118502715, 54.939768237452355, 52.399080414925855, 40.15041266718219, 40.660156050036036, 44.92281929139168, 55.96125933431811, 55.350616901151604, 55.30954576307728, 55.99650575268654, 54.36214039402624, 52.8792687385313, 48.11195335080547, 40.98544605316655, 39.17728047217093, 38.81599487796907, 41.27841964844735, 48.307146180060606, 52.79299620659121, 52.282699769543065, 53.2138547589702, 50.247778046515684, 46.715864135373025, 42.1129862723812, 43.30075448559177, 43.56122732162476, 43.943376002773164, 45.11973796352264, 47.10654004927605, 47.63148653891779, 48.74336865640456, 52.35954684595908, 52.624981480260054, 57.721524930769405, 52.57311597947152, 38.11603615360875, 35.55773296663838, 19.107622331188573, 5.0998514794534255, 13.9161330076956, 5.964881191330572, 11.378990027212328, 7.7565703661211085, 5.198944278301732, 2.888909472573188, 0.4868314090755678, 0.18516293035880213, 0.030113987421857256, 0.9346772165548418, 8.640633379259418, 30.638123712232037, 38.402137756347656, 30.952431078880068, 20.963740848725845, 35.145436948345555, 47.2507812899928, 55.48620931563839, 37.02266370096515, 5.1190858021859205, 0.22811662225473314, 0.03347497793935961, 0.07956679579952071, 0.03623911127027485, 0.039950883872206175, 0.0614157788485529, 0.029447695856252988, 0.033376347949548114, 0.04435825281806531, 0.027038010340484402, 0.02262086802793126, 0.008356154787414258, 0.038063047874358394, 0.017449498747385318, 0.04743823270884253, 0.03766275161216336, 0.025671184994280342, 0.029830990712188428, 0.020368023692900618, 0.024749617610547333, 0.027905369342695323, 0.01698535863280056, 0.08723178893447885, 0.020876803750833197, 0.024560418791107597, 0.017005763384663773, 0.05069007676455283, 0.023872454598125432, 0.049905250329644456, 0.0038427619062619467, 0.037311990595152306, 0.02390803938220826, 0.021029722561398824, 0.037712275366028475, 0.10203945645762068, 0.023295021570858457, 0.035650974079485864, 0.07780834822164429, 0.032159099355340004, 0.029481985951743783, 0.0484019598262685, 0.01632586609752428, 0.07703368777349111, 0.14920320752407276, 3.375857265726213, 28.573864621500817, 52.25022646688646, 49.951066432460664, 41.72195734516267, 23.124278437706735, 27.449346588503932, 46.021279058148785, 37.11563171878938, 15.645219683647158, 1.7185346421695527, 0.10811946730339721, 0.03861207244617324, 1.0052519327690526, 2.8407993960765103, 8.7930380528973, 11.045051197851858, 11.916855823609138, 19.402692433326475, 7.998456070500036, 7.623831966230947, 9.7097606812754, 23.43235904170621, 36.17279983335926, 47.61536559750957, 55.915410749373905, 55.26382269397859, 55.13371767536287, 54.135721575829294, 54.06382453057074, 53.148178592804946, 56.383631921583614, 54.71031350474204, 52.534770888666955, 48.81811726477839, 42.41667970534294, 41.61620240057669, 41.423935659470104, 41.50512872203704, 40.59594685031522, 41.77081046565887, 39.7567988980201, 41.603537067290276, 44.09736041099795, 50.120395152799546, 52.72243668956142, 55.101432646474535, 55.46092179513747, 52.2192632767462, 43.057222366333015, 42.02468195269185, 47.89899610703992, 59.846390524218165, 59.93958211714222, 56.20507386422927, 54.76072380619665, 54.82609794985864, 48.38447178563764, 44.31110605116814, 41.212633655917266, 41.72980993024765, 45.38198763324369, 53.613387384722316, 53.65380348697786, 62.086891512716974, 33.16382808070029, 33.48808257810531, 52.154371584615404, 55.14684977069978, 55.58991678299443, 52.33404751746885, 55.25970420529766, 54.174047054782996, 58.166357009641594, 57.71162486845448, 52.90121439964541, 41.55146760325278, 42.713783556415194, 47.02365252279466, 57.18242652954594, 56.44391482876193, 58.09606813615369, 57.051368374978345, 56.92152615516417, 55.24940013885499, 49.5785314806046, 41.99931206241731, 41.57839075211556, 41.0881023253164, 43.28601814085438, 51.97054186174947, 55.321752179053526, 54.896084800843276, 55.95551306201566, 52.865838543061294, 48.93235629604709, 46.503777657785726, 44.37861396420387, 45.552191042131, 46.56577856309953, 47.28541974098452, 48.445115550871826, 49.25905835243964, 50.961704331059615, 55.47310075452251, 55.86152522794662, 59.2229337076987, 55.64999180455362, 38.30477276156026, 26.11312843138172, 12.423528971210605, 9.942869101801227, 16.034788508569044, 11.19172921103816, 12.993439551322693, 9.305886972335077, 6.8759899273995435, 3.932847558490692, 1.4042303398732217, 0.20898924539646796, 0.13663499886470457, 0.9404905981594517, 10.240373034631054, 34.20195002709666, 37.154502407197036, 29.85241020879438, 27.177561636893984, 41.447767980637096, 53.28705010875579, 61.876495576673946, 44.04187848491054, 6.955246809990176, 0.31337356675536404, 0.07545226779315742, 0.007851508252638122, 0.010499119131465354, 0.01759724837968186, 0.01646701588235315, 0.03854152340922625, 0.04013696279857428, 0.044012965499273235, 0.06759132468892683, 0.02695789095014334, 0.05111978697260061, 0.05229418060832447, 0.026626285961678913, 0.07875295761491984, 0.07226963978140585, 0.031242703065095894, 0.023315389933545264, 0.052695112723496654, 0.017548228328626965, 0.035117880306056434, 0.04960082231029388, 0.32376545751767777, 0.21474976693430256, 0.12171942785742784, 0.11528240471717813, 0.18328469727308522, 0.15250385138055972, 0.14086766528987116, 0.09735082982168083, 0.09014727442615456, 0.19232013743490944, 0.19907781433674598, 0.17914423719048503, 0.20989142117961762, 0.1360473481397475, 0.14891033211062032, 0.24025191462809042, 0.2100357061792766, 0.11092616830982509, 0.1498015221929358, 0.0804113311272475, 0.17303894544320722, 0.25711927082269426, 4.698388066983992, 36.86618466531077, 60.923069369408395, 58.56266936948223, 50.228985971020116, 29.132166947087935, 33.47604874641665, 50.820059699396936, 45.73891155181393, 17.662727063702, 2.1729977332776595, 0.29250202219813104, 0.25382095587349707, 1.111550309485005, 5.777332080948738, 13.624056654591715, 20.079821002098825, 21.79304365188845, 25.168639344553796, 18.036544630604407, 9.877691076647851, 14.884892740557271, 28.657132617888916, 40.699701386113325, 49.397569010334635, 59.09168335699267, 54.5770235215464, 56.17844097075924, 54.89932860097578, 53.930338428866484, 52.60134527760168, 59.69932125460718, 58.225620100575114, 55.23126309917819, 50.60767904404671, 45.155345239946925, 42.44360285420572, 43.86840774166969, 44.11416776718632, 43.150319822372936, 43.76158983476701, 42.79051688409621, 43.926133263495664, 46.63700096068844, 51.59863841149115, 54.20021318620252, 56.50741015711139, 57.89440339611423, 54.136894364510816, 45.88794985125142, 43.604620502841094, 50.21339454958516, 62.31953121000721, 62.00210555907219, 58.639143820731874, 58.76720528448782, 57.523280497520204, 50.58572161582209, 46.047574627783995, 42.48238725046958, 44.69128570249004, 47.03802800947621, 55.773287588550204, 57.85164171649564, 64.33937141972204, 35.16577051531884, 38.48844166724913, 55.893751421282374, 56.951708793640144, 57.93277986588017, 52.14523638448408, 56.40292606046123, 54.08591139701105, 61.01428408776561, 60.09020505412933, 57.534435718290275, 43.43005541832217, 44.5687351688262, 48.30216869231194, 62.24717132506832, 57.47596886850173, 58.321694635575824, 59.78224408242011, 58.99275333650651, 57.99437284469605, 52.94705513984927, 44.36036317579208, 43.2240564592423, 43.85072569693289, 45.76157892903974, 52.83573827435894, 57.81249253980575, 57.317289383180686, 59.347790595023866, 54.757083846676736, 51.10641233382687, 47.872092570028, 46.778829943749216, 48.2432625370641, 48.540107511704974, 50.08796891858501, 52.481948329556374, 52.52685162328905, 52.78663019980154, 57.865934833403564, 57.96956385335615, 61.43279706278155, 56.70748633723105, 40.5918558182255, 37.61143892042099, 24.34907186415888, 8.620376298504492, 24.836181209933375, 14.167836404615834, 21.728958006828062, 19.874792829636608, 14.267803892012566, 7.290315772256545, 2.0577935537984295, 0.4750138899732021, 0.4278340280777024, 1.4777391115503928, 11.548729615826762, 40.9677561636894, 53.60765680190056, 44.0440240213948, 34.140392349612334, 49.2827808472418, 60.59536318625174, 69.35159175626694, 51.97354247493129, 10.424573421478271, 0.6702085271958382, 0.16334781062699136, 0.19448566881399001, 0.1479344433473964, 0.12062513254462712, 0.18508432973777095, 0.1411427521417218, 0.1413621750449942, 0.22573828697204593, 0.15157401982334354, 0.11644190177321435, 0.11788102092161296, 0.3212980415311552, 0.08991161811976664, 0.1371155811413642, 0.1899800452614023, 0.11588081131659209, 0.14750737997312702, 0.09221639363996445, 0.09593663917433831, 0.09054630664327452, 0.11588091856890148], [0.07982557263946341, 0.024641160627887137, 0.0237862907740618, 0.0355968231545581, 0.06510452667791998, 0.08128608862358717, 0.07954081775800836, 0.024844505260848714, 0.05847035081035668, 0.042255820270868084, 0.07193982360824462, 0.03170318894028183, 0.07713076643525593, 0.04915418538955912, 0.0566765635965332, 0.041617806925768816, 0.015117687026729748, 0.05907018999418905, 0.043652885022663304, 0.03594044806255448, 0.09997088882711627, 0.013982103405249937, 1.777541553301196, 29.726247172201838, 50.134833397403845, 41.67073903545257, 34.65834133086666, 22.21256075366851, 18.223829961592152, 27.069663117008826, 33.90049626750331, 10.21430496246584, 0.7000565384664844, 0.04201165655808103, 0.03002037147751018, 0.7791271084739316, 1.8951592161770792, 5.59915449350111, 8.183273740353124, 6.570896698582557, 24.124704445562056, 6.031542362705355, 9.25664455659928, 14.124652089611178, 28.02888462620397, 40.517428844205796, 52.843943872759425, 53.29625983392039, 59.60907143931235, 52.88679968926215, 55.162229384145434, 52.80817577915808, 52.5681306469825, 52.47760626577562, 55.90764837880289, 51.76898694807484, 52.665632924725934, 49.331641812478345, 48.17224410272414, 42.83160371165122, 42.00473277799545, 37.71142798085367, 39.702470148763354, 37.422568951883626, 39.15345599574428, 40.629761603570756, 47.35757566267445, 49.56290083546793, 55.94307522619925, 50.467399397204005, 50.835192203521736, 44.16964969327373, 39.59685640950357, 39.27011120703913, 46.47686235366329, 49.31860385402557, 51.726390008003484, 49.02897604050175, 44.275996915755734, 38.478584751006096, 39.617323337062714, 38.896246571694654, 42.80678687557098, 47.11472603582567, 54.886227884600245, 50.90489272148379, 53.78568533928164, 33.89927248800955, 32.69351824637383, 54.9516490967043, 45.490994222702525, 49.00503781534011, 48.864648342132575, 52.762448787689216, 50.14555715745496, 53.169237798260106, 55.51815309832173, 54.585146750173266, 46.617075320213075, 39.63840607673892, 46.12794399261475, 55.71875879841467, 54.3436699528848, 54.26961560403147, 53.379484684236594, 52.87828030124788, 54.38200719894902, 52.29420408125847, 43.9012772037137, 38.95272085743566, 37.783819244753936, 37.10031878563666, 36.57217948667465, 40.07162793990105, 41.01522860988494, 42.52658843994141, 42.241906735204886, 41.90313162342195, 40.47853069920694, 44.11524641898371, 42.22374616130706, 43.56163132575251, 47.219967149919086, 49.3352464706667, 51.639815453560125, 52.588589729801306, 53.40480750606906, 55.054368126776914, 57.667862984441946, 52.83259253348074, 40.42144452371905, 31.620273436269454, 10.07348991209461, 14.187629665097884, 23.22697001118814, 9.837509336010102, 10.715981010467777, 5.132304189666625, 6.874419998738074, 3.1668491132797736, 1.1421359714961823, 0.18247508023294712, 0.03653765573436695, 0.36419249950878085, 5.300339018144916, 22.77937658371464, 39.18440741877402, 21.707981171146518, 18.382674186460434, 31.94126452169111, 46.38845997471964, 52.50382731037756, 37.23616615418465, 6.71768012546724, 0.29501365677964303, 0.05715947861092226, 0.1345129812797231, 0.040157229654611125, 0.043005904618410334, 0.03958616090277511, 0.08005150729009221, 0.05444098879853564, 0.018499029627550515, 0.05435235625613601, 0.027155062829655026, 0.004068624496745367, 0.029212843942185564, 0.026102277991031448, 0.023955065689440218, 0.07877529673879186, 0.07199422351174778, 0.05741207695175564, 0.015390661391129178, 0.1127167379543666, 0.0617955937500923, 0.03239048089111044, 0.1098754940434329, 0.13642764950711883, 0.024409461165628126, 0.06869459089132086, 0.022211145053827958, 0.04626049892976881, 0.07205409328303031, 0.02942902054787884, 0.0963804185871155, 0.004753252376817288, 0.0012785375433703584, 0.0494465168805853, 0.044255317414119366, 0.015634477491520585, 0.04822765567129658, 0.03019544938128562, 0.02392095562461163, 0.0443585017966407, 0.049086850091454484, 0.041498814318929954, 0.04028727691019735, 0.05161459933245375, 2.8326624391540407, 35.06544413105134, 55.59187404571041, 47.98893997746129, 39.4664885920863, 24.42093949164114, 23.726193597239835, 34.45740222930908, 36.612477917825025, 12.163863162840567, 0.850950118995482, 0.004719743212204306, 0.18059032007811532, 2.4512366998580197, 5.92530349569936, 8.152887628924463, 12.100050122507158, 11.42918263712237, 17.04383392487803, 7.276173176303987, 7.689620410242389, 16.39350495030803, 30.43757880887678, 40.50763468588553, 52.66785690861364, 53.33977068624189, 57.64669787499213, 53.83198499679566, 55.48278900884814, 52.86832924812071, 53.088240854201786, 53.50019170391945, 57.02318614529025, 54.882434952643614, 54.28816841494653, 50.84757512615573, 48.51216454659739, 44.79522066731607, 41.93585203539941, 40.54410880611789, 42.54777316124209, 41.28891198865829, 41.50561901830858, 42.990581297105365, 48.12459907224102, 52.10362788169615, 57.456349172899806, 54.00503996879824, 52.44682742703346, 45.86545113594302, 41.634559092983125, 41.715960041169204, 49.31986685722105, 52.61081387919765, 55.92303583698889, 51.38969375241188, 46.39679893370598, 39.79614811558878, 41.64591043226181, 40.852940544005364, 45.17041890851913, 49.43660051591935, 56.43936095699188, 53.809317619569846, 55.905644047644834, 35.65727095450125, 36.308419704437256, 57.86077299425679, 47.06606903383809, 51.11941891331827, 49.44405694161692, 53.30699143871185, 51.02174012891708, 53.88255219305716, 56.5874735770687, 57.01989135434551, 48.44814362064485, 40.83559582310338, 48.83922353867562, 57.659057263405096, 55.39432387198172, 55.38828342191635, 53.75664803289599, 55.46369098847913, 56.33420613504226, 54.64682602113294, 44.3874785207933, 40.429250040361964, 41.14710261744838, 39.561394260775664, 39.28214896109797, 42.790375678770005, 45.30676834044918, 46.46559338415823, 46.56912826722669, 44.201024732282086, 43.28217814045568, 45.85557460784913, 45.09902000427247, 45.484271280227176, 48.758787493551935, 52.38796834022769, 54.77578963002851, 53.70322142877887, 55.400270185162945, 57.77546928774927, 59.56865533705681, 54.93545755263298, 39.53429460525513, 29.20670766984263, 13.76085029494378, 11.836132464870332, 14.556205964857533, 11.668638433179549, 13.125515560950003, 9.632398793774268, 7.262764553869925, 5.083726615675035, 2.4337211107054064, 0.33363539725542074, 0.13288414045687647, 0.486690724689153, 6.374169732293775, 26.985094854908606, 42.65397525602772, 27.856447427503525, 23.848948094152636, 35.9350061416626, 52.70289936373311, 59.624788376592825, 43.6861587339832, 8.154831653641116, 0.28898396258873327, 0.0333044161238978, 0.05215990837783583, 0.03005828516888282, 0.05902281894739117, 0.07155622040191967, 0.047581234511228344, 0.018853870062758366, 0.008244744535805959, 0.08901452149955497, 0.026649033027370612, 0.055462318066988266, 0.05051842327379892, 0.03773326617515376, 0.01595588968015246, 0.014564872234909525, 0.025149530828780225, 0.06498135506145417, 0.020797800933641773, 0.009949129288865915, 0.03886220781433006, 0.013990738173766483, 0.2739211418215306, 0.2283767703920603, 0.138348201289773, 0.13749743000634257, 0.12401582237573401, 0.16480978217817124, 0.18826353333650098, 0.18845294091490009, 0.20382680870111913, 0.1446781559817253, 0.13748642898374988, 0.10694843296322132, 0.12086768364233356, 0.17087902182773237, 0.2058073145247275, 0.10122775565832855, 0.08523914061727063, 0.11377933254886059, 0.12075753552058052, 0.19325274223041153, 0.17771661702182986, 0.14580415201283273, 4.005742111513692, 43.00878893944525, 61.419080534288966, 55.414637827104144, 46.55203457801573, 33.52994995732462, 28.014524829003122, 38.72053615508541, 43.740095246222715, 14.140416095333716, 0.9925824932513699, 0.255118417703817, 0.2816641763333352, 2.9088907616753734, 6.386363890863235, 15.108135419507182, 18.64438060791262, 19.229423692149503, 34.83648753935291, 15.096839974003455, 18.32722560051949, 16.657678542598603, 30.525043741349254, 40.630314657765055, 54.97281420615412, 54.2892352996334, 59.61621015302597, 54.11310518941572, 57.17938277029223, 53.53158243240849, 53.4126522464137, 53.855852619294204, 59.02545021426294, 56.731597146680286, 57.331751162006015, 52.86994918700188, 52.28653976994177, 47.46990057729906, 45.670972178059245, 43.1985963544538, 44.444490171247914, 43.17346965112994, 43.84912929227276, 43.74182893383888, 50.89319621362994, 54.812546160913286, 60.55865372380903, 56.05821248023741, 55.24055519411641, 48.48837537150229, 42.891690500320934, 43.61440289405085, 49.460785850401855, 54.627151412348596, 57.339325258808756, 52.77452576544977, 47.74911842038555, 41.85244283368511, 44.20828503947104, 42.70697039942588, 47.77670444980745, 52.15382245279128, 59.60857329830047, 55.63653807486258, 58.66842431406821, 39.32849960942423, 39.600366930807795, 56.34067804582658, 49.34877080302085, 51.71472095674085, 50.416769443019746, 54.59264239957256, 52.8844541118991, 53.11098275646087, 58.39403098629367, 60.09558654600575, 51.53570790444651, 43.387489857212195, 51.87381621330015, 60.70275375919958, 56.50613538680538, 56.03219932125461, 54.165935593266646, 56.666689765068796, 58.97099987153084, 56.867668090328095, 48.281297760625044, 43.38131604656097, 43.04822444915772, 41.68817397086851, 40.89904800538094, 44.211364100056315, 44.58132989944951, 45.70749728910385, 47.020079243567686, 45.87520607056157, 43.86407352262928, 48.91871429258778, 48.31140195169757, 47.41316349275651, 52.49500589986002, 54.83890056610108, 58.59673907679897, 56.41432839055216, 58.32163580002324, 59.35348979888424, 62.601922250563106, 57.28153697906002, 43.69148923504738, 35.887019864974484, 16.96070125026088, 21.072337550501672, 32.46474208370332, 18.842185735702515, 18.9399782688387, 10.87901040430992, 13.535482671953018, 7.033429453449865, 3.1562937699979354, 0.502870072640719, 0.20853417384768688, 0.8796434212596187, 7.661307761746069, 31.668506822278424, 49.94399047666981, 34.8792217623803, 28.75922799110413, 42.88754455504879, 59.70037637218353, 67.3165641292449, 52.43837864168229, 12.057971915891095, 0.77211887485558, 0.13171084615732395, 0.19801886632077156, 0.12038428982299183, 0.1862287425225781, 0.10928647968197062, 0.09213114337575051, 0.18583814493350445, 0.162327105720197, 0.16964065601989148, 0.09703859536638183, 0.2554099141590057, 0.1928132375882518, 0.11978990518518033, 0.07387526047926757, 0.13843798679449867, 0.13766589274089183, 0.21954895537947455, 0.13246908934125978, 0.20719243213534358, 0.1362651929018959, 0.13457005483008203], [0.035918311951982404, 0.05921832075522793, 0.02572709409099433, 0.04126106276206913, 0.032569220695163936, 0.06383095529951877, 0.05077849097189404, 0.043093686803214015, 0.0377898647509996, 0.06346136767176852, 0.04277084969104298, 0.026144424318185738, 0.02631644936158292, 0.012054549578967835, 0.029801074978745276, 0.014469084431297116, 0.02656781813129783, 0.0374305771753913, 0.016582557263093132, 0.04099745956820346, 0.03806238520830389, 0.03311110532752449, 1.8346891383970938, 26.8166055217866, 47.82982118668095, 48.7088204199268, 34.68366415269914, 17.96420043514621, 22.11626852712324, 40.07856661273588, 28.974740659036947, 6.4243392982790555, 0.33357680685097174, 0.10810592286889592, 0.06801533137237833, 1.2049931792482254, 5.6833162999922235, 5.15236662280175, 9.562960094021214, 11.446501862618232, 13.44348151837626, 2.3749235560817104, 8.99573927925479, 18.79236182858867, 30.96520035497604, 46.95548565156999, 48.52353549772694, 57.070336957131666, 54.65932661487211, 55.41163721392232, 53.52283554692423, 53.24784994125367, 53.69809489096365, 51.33275270462037, 51.21134750304684, 55.7437756753737, 52.73039517864105, 52.94794159550821, 52.93657456674884, 51.024015103617025, 49.131208696673, 44.847188149729085, 40.65758689757317, 37.712651760347434, 36.29730762973909, 40.36875532519433, 41.49040414441017, 46.546637396658625, 49.41492157597696, 52.168649012042636, 49.52210818567584, 46.59225456176266, 41.334435016878196, 39.9643942617601, 39.37177119716522, 40.94093107408093, 41.080120302015736, 40.96690500936201, 40.37979287485923, 37.85758333821451, 39.061119479517785, 39.46491179927703, 47.71815130787511, 51.90661507268106, 56.00796691833004, 51.180419614238126, 57.06681074634675, 39.065794944763184, 41.34777499783424, 52.977688850895056, 49.50998806184339, 53.716149560866825, 50.702537644294004, 53.50429058074952, 52.24053821256084, 54.746442456399244, 55.9972196240579, 56.30177597845755, 49.30811543618479, 40.61599016189575, 42.04221102499193, 55.06161274448518, 54.699283799817486, 55.56725725050896, 50.97027078751595, 55.16473577868555, 54.930656571542066, 52.43238918242916, 46.11683976265692, 38.53516886311193, 37.62357473373413, 38.51861646098476, 41.497260447471376, 43.639258953832815, 42.42103353623421, 42.43829588736258, 38.515078483089326, 38.82824444001721, 40.39492145661385, 41.44314350620393, 43.69690602825534, 49.15648837243357, 51.20410288533857, 54.309455117871686, 53.939093159091094, 54.75896658435945, 56.48815524193549, 55.57611788472822, 51.479163016042406, 56.08013068476031, 44.72035438783708, 31.63096581735919, 22.295310997193862, 18.41493175875756, 7.292403944077031, 11.70525081696049, 14.930865860754444, 9.336167670065358, 5.106178262541372, 4.331798447716621, 1.5877451699587608, 0.518860932319395, 0.034076345468600916, 0.13768279264050146, 3.3514991018079945, 22.185453253407633, 39.06781104303176, 23.938933149460826, 14.74483568822184, 32.621717299184496, 49.37096749582599, 50.08198338170206, 39.0342120201357, 10.281139208424477, 1.0659722455086247, 0.022245167018545252, 0.024900023652721318, 0.01998741397513978, 0.01828831331353755, 0.06874532889454596, 0.036311426139887304, 0.03198493501141427, 0.03123124430496847, 0.1273190096441296, 0.06256831599579704, 0.05705151383975341, 0.03496362467206294, 0.036708152432355194, 0.06937561241248924, 0.028177558466972365, 0.047574898964094545, 0.056015920014150684, 0.013611467194653327, 0.07203712443550749, 0.09569267081397195, 0.05643371755497591, 0.05870622545180302, 0.05605719683151092, 0.027188498737110246, 0.01661223933971938, 0.051868182096269824, 0.02316275457551162, 0.022022698915773825, 0.018074959741845247, 0.004725990180421862, 0.04612233880306444, 0.04266877613601185, 0.060944998666884444, 0.04962194718480591, 0.03008598307778518, 0.02999734287450631, 0.0562645155455797, 0.03449788151849662, 0.02583088942863528, 0.025076294738438823, 0.032962185495923606, 0.025271756326659553, 0.057625934226258155, 2.4390121429197253, 34.909251428419545, 55.39550058303341, 53.530417488467315, 42.21793320871169, 24.36840718792331, 25.685313555502123, 37.49534853043095, 31.922876450323294, 7.643642877378772, 0.39804770220671937, 0.050753439896770065, 0.08819617871795932, 1.9124234059164602, 7.148820680956687, 9.577209084264695, 16.43918095096465, 11.921516579966392, 16.316119528585865, 7.648204103592904, 10.561631821816968, 18.766454573600523, 32.66283550570088, 47.80898947869578, 49.375427230711914, 55.42672657197522, 55.87336294112667, 54.07505035400391, 54.03357128943167, 53.64436626434327, 53.76770127204157, 51.586310402039565, 52.88388929059429, 55.82735746137558, 56.166807220828154, 55.504083556513635, 55.48863726277506, 53.00285085555046, 49.90240158573274, 45.02665619696341, 42.4517378499431, 39.71638279576456, 38.24947126450078, 41.84265259773501, 44.50842872742684, 48.326279501761164, 51.79955790119787, 55.15096433701054, 52.308104961149155, 47.73043224888463, 43.46514101951353, 40.99454595196632, 43.83832316244803, 42.71323442459107, 44.099384354006865, 41.519814075962195, 42.75862801459528, 40.24333361656436, 40.68196050582394, 40.63153059251847, 49.83256770718483, 54.84719637901553, 58.01132140621063, 51.81808717789189, 58.23621834478071, 41.85463543861143, 43.61353997261294, 52.82349263468097, 51.9064817120952, 55.09894194141511, 53.41329551512196, 55.848844205179525, 54.22159010364164, 55.88081544445407, 57.510779903781035, 58.14161862096479, 53.08504412251135, 41.486956381028705, 44.54207874113514, 58.28180413092337, 55.39180571033109, 55.22956079052341, 51.4770527808897, 54.53449326176798, 56.98339369989211, 54.12544496597783, 48.71023639555901, 41.77988290786743, 39.283082485198975, 39.801435470581055, 42.82117020699286, 43.261052254707586, 43.50176026744228, 43.60913515090943, 40.33745088884908, 40.33140259404337, 43.1957055676368, 42.6770152584199, 45.217369679481756, 50.41915424408452, 51.91476575789913, 55.404153331633545, 56.301144476859804, 56.025091986502375, 59.25638368052822, 58.934145281391764, 52.965176490045366, 55.478654830686516, 45.80383070053593, 30.022676375604448, 19.53169526592378, 13.371863941992483, 14.638334512710573, 13.42112793076423, 14.887186346515534, 6.787156578033202, 10.605108353399462, 7.003158561645016, 2.761374096716604, 1.1391862265525328, 0.14706110311371667, 0.22593843510314343, 4.156876917808287, 25.415360350762647, 44.264331786863266, 29.497382756202455, 18.611360134616977, 37.7269801785869, 54.55595647135089, 58.690024806607155, 46.16148025758805, 13.702019645321755, 1.3829788157055456, 0.02296264474881032, 0.026559255183524182, 0.047257489584867036, 0.0836859203334297, 0.0388632535243467, 0.007914490734917984, 0.022320630509526502, 0.026010803262432738, 0.08985995315015317, 0.08135242417695061, 0.07399441013413091, 0.010119101216626025, 0.057859123729529886, 0.03867751167666528, 0.02865307881767231, 0.022352147366731398, 0.026480348127323295, 0.016698495094333927, 0.037484241634487145, 0.021904673494939363, 0.07236353917828492, 0.1720691394181021, 0.12945442610690672, 0.19218138359006376, 0.14971447928297907, 0.10661855550302614, 0.1084254734638718, 0.20484924496662235, 0.13283334882749667, 0.11038159470885031, 0.12144932057708503, 0.23033407907332146, 0.2292643292176147, 0.1275680724891924, 0.09975607011226878, 0.0889631093389565, 0.12808817724186566, 0.16547670768153283, 0.0666823000797341, 0.1517608993115925, 0.11828994333383538, 0.11986094451839886, 0.1324908768818263, 4.676710107634145, 43.778052022380216, 62.052606075040764, 61.91179690822479, 47.39292406266736, 28.236174045070527, 34.29418456169867, 51.54453323733423, 38.67355008279124, 8.91054637970463, 0.6606943280466142, 0.27559311339451426, 0.18270610170739313, 4.020753267311281, 11.576498035461674, 14.908715255798834, 19.432112170803933, 19.16442805720914, 23.382962672941147, 9.945295087752804, 15.446125076663112, 21.125740620397753, 35.07907436740014, 51.526910028150006, 53.37876296812489, 56.56495917227961, 56.99683958484281, 53.398202234698886, 55.171121397326075, 54.00825238996937, 55.11559632516677, 51.902331844452895, 52.66811186267484, 57.718849874311886, 58.359702402545565, 58.377623711862874, 58.7760345397457, 56.291640573932284, 52.90683907847251, 49.130918441280244, 45.61209347940261, 42.81555729527628, 40.66997374257734, 43.497935956524266, 45.6541883560919, 49.37478788437382, 53.20440184685492, 57.980821055750695, 54.78807449340821, 51.73870232797439, 46.65647160622382, 43.84605415405766, 44.74593216373075, 44.463756853534335, 44.9789797875189, 45.419956176511704, 44.926596533867624, 42.24694698087631, 42.73274429382817, 44.050644982245664, 51.44057081591699, 58.87731798233525, 58.646451196362904, 53.68418224396245, 57.49068560138826, 44.50466325206142, 46.26214396569037, 51.02778057898245, 55.19069402448593, 56.53947553327007, 55.404977029369725, 57.80198058774395, 57.7477655872222, 58.1585201140373, 58.96211962546072, 60.09796742470034, 54.68265295028687, 45.161107201730054, 46.19919384679487, 58.601206656425234, 58.167447428549494, 57.63662522838962, 51.23924339971235, 55.44607170166508, 58.583002936455514, 56.96546454583445, 51.08645531439012, 43.2435388718882, 41.92182956203338, 43.51206433388495, 45.97147280170072, 46.880360495659616, 47.20244984472952, 47.5071434820852, 42.923261657837905, 42.930165029341175, 46.101165971448346, 45.48816619380828, 48.13265954294513, 53.700318874851355, 55.130799431954664, 59.58630208046206, 59.05645262810492, 57.64364234862789, 60.038971054938536, 59.165282710906006, 53.27756581767913, 58.50297089545958, 49.68309794702838, 36.51969032902872, 26.662432839793546, 25.351259016221572, 17.12387381061431, 21.508881661199755, 28.665212700443885, 18.658122631811327, 16.735178693648308, 9.060493688429556, 6.037448471592319, 2.3728677438151453, 0.3605048893199813, 0.46437409315859124, 4.878363570859356, 29.218461052063976, 49.495926364775634, 35.52260029700495, 25.295112248389955, 46.32887524943198, 60.83499254718904, 65.57178012786373, 55.74528578789004, 18.44250209869877, 2.1128224461309375, 0.08876047908298432, 0.10772672466813557, 0.13170657138670647, 0.13444892100749478, 0.10532123156853261, 0.10431906598950587, 0.09894321252021099, 0.07340413172759357, 0.24236504559315022, 0.11307918947310218, 0.16503934808556112, 0.10447011554553624, 0.1742324184986853, 0.22851494201008352, 0.10670040433685626, 0.1797776540080386, 0.16614876597398714, 0.08529353285989455, 0.15218373388051987, 0.17620566180877148, 0.2018910883775642], [0.025672575443862908, 0.02546411525878695, 0.007210864831933813, 0.08494339237410216, 0.06124197648117139, 0.020517343805441936, 0.04954687439866605, 0.030702273999791474, 0.03465446222934031, 0.031300339690079136, 0.12486637149366642, 0.009169678875966179, 0.023793905688029145, 0.009735272014363399, 0.013936015555725224, 0.0608924986614335, 0.08677536907095103, 0.10161567960054645, 0.02767318532982421, 0.033547572431064425, 0.05084838117322615, 0.10325937486824491, 3.9218994878953506, 36.93968988233997, 49.404915609667384, 41.091122550349084, 16.360383475980452, 20.924405359452773, 31.993084915222664, 36.271404297121116, 27.115901977785175, 4.476308370790174, 0.15491728881193748, 0.05792850065195273, 0.7923489280285374, 2.560616404779496, 7.9630635438426856, 6.348194816420156, 13.407438858862847, 8.454744412053017, 13.809508277523904, 4.681365470732413, 8.897068135200008, 26.489470043490012, 40.150702922574936, 44.259644554507354, 58.57042781768307, 57.36895484309043, 58.82196549446353, 56.22320698153589, 57.101751219841745, 56.16839578074794, 55.10828894953574, 54.61225032806397, 52.90899245969711, 53.89479391036495, 51.894208615826024, 55.44256902510121, 55.11522762237057, 54.39726521891933, 51.93904522926577, 49.94265687081122, 48.917655252641254, 46.38498475474697, 39.43134807771252, 36.99033552600492, 37.33775554164764, 38.207560739209576, 43.138446807861335, 45.83213452369937, 46.192517972761586, 44.11263804281912, 40.22730681204027, 37.63373759485061, 40.559629624889745, 38.62849381662185, 40.13857495400214, 38.396822944764175, 38.82934662603563, 36.53169278175601, 39.76471424102783, 39.65710793772052, 51.07360170733545, 52.62199263418875, 53.165119309579175, 49.94834430756108, 55.91584613246303, 38.87344583388298, 38.716272538708104, 54.29153773092455, 51.37870719355922, 51.68404017725299, 49.453870711788056, 49.4884071811553, 49.16866733181862, 52.562403986530924, 55.35884211140295, 56.37322979588663, 51.463171512849875, 40.8548350487986, 38.25749251150316, 50.52416001596759, 52.788105010986335, 56.670451318064046, 52.91888075490152, 52.08858559208532, 56.972516967404275, 53.87724130384384, 48.55728357068954, 43.72443322212466, 43.0622116211922, 49.19078949959048, 49.69548871440273, 54.13091274999804, 53.482137034016276, 53.67712197765228, 47.46311487690095, 41.10952238882742, 39.13444034514889, 42.56982472635085, 46.45796437417307, 52.19585457155782, 52.95240525276431, 55.06109891399261, 57.25629652700117, 54.47520663661342, 51.42985097823605, 53.71413346259825, 52.99502964942686, 53.1512733428709, 47.910206240992395, 38.04281334723196, 21.48176239382836, 15.03142660663974, 14.585631585890248, 12.332914375489759, 7.725014898084826, 5.331072749630098, 3.961980962945569, 7.763441378070463, 2.4515436253240033, 0.7957090509514656, 0.3224506054914767, 0.05997856342864614, 2.011217491761331, 16.01215447148969, 39.66218348472349, 30.56543827056885, 25.093698540041526, 27.908122693338704, 41.476813131763095, 55.34593751353603, 44.50061536604359, 12.69819196193449, 1.003629787554664, 0.019839710308118694, 0.05851322109059942, 0.053911338590325854, 0.03167110709323278, 0.05773223658663131, 0.020864722544267293, 0.04709009554297213, 0.019510608511946855, 0.09039177904806792, 0.013513454863230788, 0.027173763035886714, 0.06825671801643987, 0.1183218049306062, 0.08048812378077738, 0.05506839948676287, 0.03753465788078405, 0.06330460693026263, 0.031099094138030085, 0.014737383744138625, 0.05472215072762582, 0.06536037706199192, 0.055322495529488216, 0.051322022693291794, 0.04340488703981523, 0.14661672615235852, 0.03423436642474225, 0.005601813017781223, 0.05901739121444764, 0.06293549810746504, 0.03431442644326918, 0.028941003387914072, 0.11958925909693204, 0.03758874751867787, 0.08109033017629579, 0.02764899227317543, 0.037432477073443514, 0.04590889904648066, 0.06001962191094795, 0.052566371647821325, 0.0335377243707978, 0.04241777891894022, 0.05340328440070153, 0.08118358605931844, 6.132797858407421, 45.23978602501654, 56.03424287611439, 48.45885953595562, 22.70162736215899, 21.201079545482514, 32.12419798297267, 38.38142764183783, 30.423185671529463, 5.317994586883053, 0.3058990920262952, 0.12175061529682529, 0.9473184027498769, 5.401241990827746, 13.192093872254896, 10.973158074963479, 14.680816723454384, 12.21608461872224, 11.48042840342368, 7.661552909881839, 11.273771466747409, 22.0218982619624, 39.09578538710071, 46.947283975539676, 59.588365247172696, 57.12820368428385, 58.52463022355111, 57.28263916507844, 56.91378731881419, 56.25368772014495, 55.19791118560299, 55.836057278417776, 54.19909138833323, 54.655125756417554, 53.2871756246013, 56.56108387054936, 55.53897696156656, 55.20775633473551, 53.5684331001774, 52.88681537874284, 49.87613739505891, 47.15426744953279, 42.07988146812686, 39.314724245379054, 39.0017230279984, 40.888736094197924, 45.5197451960656, 47.987021938447036, 49.168835993736025, 46.165669348932084, 41.41241958064418, 39.730887720661784, 40.742702330312426, 40.568811893463135, 41.46708957610592, 39.44921055147725, 41.71279076606997, 39.315045879733184, 40.65384887879895, 41.74305577431956, 52.49260540931456, 53.850914355247255, 54.687034237769346, 50.85918141949562, 55.76242654554306, 40.6126404577686, 40.69218612486317, 55.390338743886645, 53.37957882112073, 54.76434807623587, 51.22854709625245, 51.64571862066946, 51.938794197574744, 54.59289343126359, 56.86800933653309, 57.31374748291508, 54.818841565039854, 43.753360702145486, 40.70373750502064, 52.67893760435043, 56.46537019360451, 57.125779659517356, 52.76399812390728, 52.67097127053046, 57.31236288624426, 55.66562637206047, 51.60277651202295, 46.67518915668611, 44.31879389670588, 50.77351685493223, 52.08679306891657, 56.61913887146981, 54.90341178832516, 54.12758265772174, 48.37870590148434, 42.123047151873195, 40.844095599266794, 44.16218150046564, 49.37561550448018, 53.465859197801166, 54.876084635334635, 56.310679758748705, 57.78456134180869, 56.78249774440643, 53.68330363304385, 54.02598542551841, 54.108033564782914, 55.29402102193525, 49.33807057719077, 36.976524860628196, 21.17787480354309, 14.03557800477551, 14.828201743864245, 11.19957002901262, 11.687264788535334, 12.260121068646832, 8.557377149981837, 5.072580220237856, 2.324727268949632, 1.288822687441303, 0.36902780133870344, 0.1001095277587733, 2.443052919641618, 18.87725172504302, 40.61829259318691, 30.20624722203901, 26.831906687828806, 33.57113484413394, 48.496216189476755, 61.947102162145804, 50.995828951558764, 15.544888396416942, 1.361075197496722, 0.09358337028853356, 0.04033831751815254, 0.022492998377269795, 0.044763145607806025, 0.02962909781584336, 0.033989559198098804, 0.014856889629886757, 0.033834571950137615, 0.07311287275966137, 0.06982976465576118, 0.025651747428421533, 0.028251326988421144, 0.00653377860867148, 0.08563945220122415, 0.040469211300895105, 0.0038437681148699937, 0.05622298591920445, 0.08788974354824713, 0.014628590640401649, 0.02260267152450979, 0.022005551952808615, 0.15614788648822617, 0.13180856833294516, 0.15135128742023823, 0.27120189741253853, 0.11980659058017117, 0.1138746721910373, 0.18011487059054837, 0.13530372191340695, 0.07932015379229862, 0.11476469015882862, 0.21518366381285653, 0.1221095274893507, 0.13322068288201286, 0.18195098416218836, 0.20015416787036006, 0.2550347455807271, 0.15432467383723106, 0.18146791976065407, 0.12663577412886004, 0.13327490658529345, 0.19619936153533, 0.34049007621022964, 8.055015177496019, 52.61315553419052, 61.959614522995494, 55.0406829772457, 27.561385170105968, 31.639067472950106, 43.201098826623735, 49.27641876282231, 34.10383585960635, 6.6550374223339945, 0.4973108483658683, 0.2617653182918026, 1.4019692160429493, 4.6261095712261815, 14.269549346739247, 12.670905013238231, 22.26501068761272, 19.732334306163175, 21.649947743262015, 11.049785498649845, 14.212238615558995, 28.949441371425507, 42.62671478333012, 49.26688740330358, 62.894927224805286, 57.721211141155614, 60.505140827548125, 58.63813184922742, 59.36410373257053, 56.45154383874709, 54.98792317605788, 54.81599392429475, 55.54557046582622, 54.8971869868617, 53.82829796883368, 58.585034724204775, 58.031290192757886, 58.95027406754033, 56.50132263860395, 54.86096389832036, 53.37133007664835, 51.83633012156333, 45.03776827166158, 41.696579610147786, 39.4763925767714, 42.21096315691548, 47.731334394024266, 49.27324164298273, 50.15093864933137, 48.82461663215391, 42.88027248074932, 41.95960983153313, 43.31281185150147, 43.126377674841116, 43.62515411069317, 41.800483196012436, 42.97051837367397, 40.93034067461568, 43.80164900133687, 44.50043493701566, 54.197510673153786, 55.53880829964915, 56.14742678980674, 52.86843515211537, 56.62077057746149, 43.78728135939568, 42.733179676917295, 56.5503954118298, 56.56259006069553, 57.489187255982436, 54.299806087247795, 53.30784651540941, 53.77076856551632, 57.34513036666378, 60.95740187552668, 59.67075855501237, 57.75496705885857, 45.86487846989786, 42.26683732002012, 54.86782020138156, 58.63011060222503, 59.359538093689956, 54.64862638904203, 52.93607642573696, 59.44681475239416, 58.485802681215354, 53.594814961956395, 48.31674421987226, 47.9287512071671, 52.82947817156392, 55.009135353949766, 59.516217170223115, 58.22871485064107, 58.48232353887251, 52.42184192903581, 45.015002835181456, 44.29724831734934, 46.83296257449735, 52.24314266635526, 56.95511733331988, 57.60452847326956, 60.13285690738309, 61.10929566044962, 56.459525862047755, 54.2116351281443, 56.02793962724748, 54.53238694898544, 56.604025979195875, 51.340283655351215, 41.66836992386849, 25.035929872143655, 18.783540418071134, 20.380196109894786, 21.345463952710553, 18.315125088537894, 18.28991601544042, 13.908592251039321, 13.898793189756333, 5.967526339715527, 1.6706791520118716, 0.6646422549120842, 0.1961650867615977, 2.9886237219456704, 21.876511689155333, 51.303523202096265, 41.75501115860478, 37.07653745528191, 41.27403051622453, 54.5998203369879, 70.27323892039638, 62.52012514298963, 21.010273887265114, 1.926397952821947, 0.19375091388581261, 0.11100702122935366, 0.13776715424272323, 0.14501966265661104, 0.09704283949348236, 0.22028139672212063, 0.14425401906332663, 0.13657090794895926, 0.2327597585897292, 0.22061473689973357, 0.21218096687188073, 0.1295516426644979, 0.21750677947796163, 0.23017267966943405, 0.15310808024819822, 0.07586876681495099, 0.19273696587451045, 0.17355510484307043, 0.11276338504807604, 0.21928077864070095, 0.13212799635385314], [0.04563770009084575, 0.012230173320389323, 0.03078403473351031, 0.010060555819842604, 0.07440792907389902, 0.14955176220786187, 0.10092106767960134, 0.062114588931323066, 0.04716199672510547, 0.013130235658477873, 0.00979760092788286, 0.02829724055294308, 0.011100224275592596, 0.009259873280121435, 0.13534810904773975, 0.08049203082919121, 0.0354072010715402, 0.04264261423339767, 0.05578704358589265, 0.06427823956454955, 0.01621012170348437, 0.03863310155969474, 5.783214655614668, 34.07779524403234, 48.32716203504994, 42.94457973972444, 35.78248085514192, 23.682912203573412, 30.1487531200532, 39.77127244395595, 18.508721513132897, 3.124864062955303, 0.026983125886369138, 0.09436837292366451, 0.3482571045958227, 2.5302707427932374, 7.162823052175584, 11.846959187138467, 17.900612931097708, 12.883157210965312, 11.36177964748875, 7.7864372537982085, 14.770650767510938, 25.759054114741666, 42.21371273840628, 50.2442479133606, 52.93522134903939, 56.93790205063359, 52.54611438320529, 54.74494803336359, 55.31819851167741, 57.20519981076641, 54.754193059859745, 54.944722190979995, 55.57581193985478, 52.9787871145433, 51.513946594730506, 52.681196889569684, 54.00581267572219, 54.2338514328003, 54.95883880123016, 52.07955629594865, 52.74627293309858, 50.1942612278846, 48.31742278991207, 47.70666660801057, 40.47024273103283, 37.55267397049935, 37.627646153973, 39.082013945425714, 39.52044079380651, 40.64298783579181, 38.369260449563306, 39.396788074124245, 38.809954427903705, 38.289287244119954, 39.303333682398645, 38.54451979360273, 37.341238606360655, 37.53812197716006, 36.880062010980424, 38.90248706263881, 51.176210911043235, 49.689220766867365, 53.97199400009648, 48.545206592928984, 54.050468860134, 39.82648764887164, 39.74771076633085, 57.03152902664677, 49.855329221294774, 51.07499414874662, 44.53605790292063, 41.39831081513436, 41.45140009541666, 45.05489333983391, 48.185007495264855, 49.61300126967892, 45.54515431004186, 39.805373530234064, 36.981612174741684, 41.05463274063603, 50.05237340927125, 53.69144647352157, 55.90533418040122, 50.67186863191667, 53.999438824192175, 54.51458723314347, 50.43609888322892, 50.41005042291457, 52.33444367685626, 53.223543013295824, 53.004019721861816, 54.40509426978327, 52.65698802086615, 55.95652111114995, 54.5291627607038, 53.4171865063329, 46.7160798657325, 48.85136719672911, 51.082666304803666, 51.68222019749304, 54.87345272494901, 55.01485024729083, 51.552134790728175, 50.707970126982666, 52.234395780871, 54.46787572676136, 53.43555888822002, 52.59265330529983, 46.46528743928479, 38.799564069317235, 29.707037364282918, 18.082799180861443, 18.905292749404907, 9.627940039480887, 11.364132088999595, 3.7605677448934127, 8.823739424828561, 4.168224334716797, 1.9121356020050666, 0.8483837244491425, 0.7229460811903401, 0.0953946702723061, 1.1944117276899278, 12.940710148503705, 35.206496484818, 38.806977348942915, 23.25210455925234, 26.51917023043479, 35.12673900973412, 52.20185579792146, 51.401986460531916, 20.407307532525834, 2.354821654096727, 0.0566947658456141, 0.1480036670522344, 0.06925389636307955, 0.011658503189532748, 0.011360337938963166, 0.07415755621848569, 0.05948033431665071, 0.03762913567404594, 0.07620592977130607, 0.03557867070119228, 0.01426103984892008, 0.012697684221840914, 0.08546757271453258, 0.040281171189440836, 0.05782815845563047, 0.01781381377499671, 0.0007412129296778491, 0.02037037941326778, 0.07104442770322485, 0.038636771120852044, 0.09681232363706636, 0.028550666268734683, 0.03212302235976583, 0.034850921647082415, 0.02179797276884558, 0.02057054286612378, 0.038039168913758574, 0.03152260669477044, 0.07087810235398431, 0.01893505623053399, 0.042111424188460075, 0.050584031043634306, 0.015796450503741302, 0.04085072308718678, 0.040391897707576715, 0.04626802191318524, 0.04510642960667611, 0.019245032641676166, 0.10382049596838414, 0.12202194831784695, 0.05776427438362472, 0.043667892685099956, 0.12768647137788997, 8.123047217246025, 40.427685014663204, 55.55587845463907, 49.09314601652084, 37.460078577841486, 31.31256349625126, 35.557446633615804, 42.32447654970231, 22.76858025981534, 3.9108619382304535, 0.12189074043905544, 0.016160019553236423, 0.6487922634809249, 4.335068723847789, 11.582418853236783, 13.475629264308562, 12.314338030353671, 8.180257927986885, 8.447089906661741, 8.503258247529308, 14.980975120298325, 25.934674316836944, 43.2148192774865, 52.18637420285133, 56.623367186515566, 59.33305425028647, 57.15309112302719, 57.15638199160176, 57.61054146674372, 58.46493567189863, 55.79928113568214, 54.16499814679546, 54.062926307801284, 53.00863635155463, 51.82999157136487, 54.009652676120886, 55.32464688824069, 55.958341090909904, 56.95099492226878, 54.26610116035708, 53.13774508814658, 54.1619465428014, 51.00175173051896, 48.17243237649241, 42.66947646294871, 38.966398162226525, 39.141971295879735, 40.91216833360734, 42.059238033909956, 41.90885828387353, 40.236496925354004, 41.61596705836635, 41.111765984565984, 40.33740774277718, 41.05538191333894, 39.12248888323384, 40.19434321311213, 39.41690591073806, 38.63125516522316, 40.89470201923002, 52.68983002631895, 51.9264308867916, 54.05627004561886, 49.63724936208418, 54.33961422212663, 41.09310726965628, 41.98628587107505, 58.30799379656392, 53.03870916366578, 52.68906516413535, 47.76382338616156, 43.78856397444203, 44.492586274300855, 47.372904285307854, 49.166855196799006, 52.64178491407826, 48.987755852360884, 41.650833006828066, 39.602896859568936, 43.14101203795403, 52.10998604374548, 55.82510602089667, 56.75064025386688, 50.287515578731416, 55.52842186343286, 55.59981292293918, 52.59927818852087, 52.96820063744822, 53.817146670433786, 55.609265835054465, 57.14051992662492, 56.16880762961603, 54.67097997665406, 57.107830893608835, 56.7864122698384, 54.60869666068785, 49.762318057398645, 50.231731630140736, 53.281696073470584, 54.18614756676459, 57.72688288842478, 55.53842782974244, 55.07117156059512, 49.59936318858978, 52.72303288982761, 54.23470258712769, 54.39982260427168, 53.67312900481686, 49.51616187249461, 38.592117755643784, 25.547340262320738, 12.619721024267136, 16.206579496783597, 7.390645588597945, 11.608498692512514, 11.948162221139478, 8.645978589211742, 7.227304366327102, 3.3727889916589184, 1.9902048644519623, 0.3522986167621228, 0.07265827618539333, 1.2942392355011356, 14.991270361408112, 37.936113111434445, 39.16511720226657, 26.3543620417195, 31.05219460302784, 39.879306285612046, 59.1396382547194, 56.62541466374552, 24.121056641301802, 2.64878319636468, 0.062469812410493056, 0.11256393405698961, 0.013835234774066316, 0.04772410990910665, 0.050432908709251115, 0.006597591817544233, 0.031109721692759666, 0.09984623866095658, 0.062008121862046184, 0.07560697924946586, 0.02710379814098199, 0.06710470563942386, 0.017288662418122255, 0.03783171613430304, 0.06403557738409409, 0.07699136907655386, 0.03128921417819877, 0.0805646176600168, 0.048186045605689294, 0.03585150525454552, 0.03888643917537505, 0.16962323518049333, 0.08147939558952086, 0.17189064093174475, 0.17188659598750455, 0.14405696592744321, 0.1873942686905784, 0.16409758087848464, 0.1759736444200239, 0.13256722520436012, 0.13788479470437573, 0.16568695285147236, 0.11394443215742228, 0.1446707862158937, 0.14110191965535765, 0.19248933561386602, 0.10352637949249438, 0.09030521111262423, 0.1154108853229592, 0.16966765295834313, 0.22386834295766972, 0.14800847808439888, 0.16337486885247693, 11.627032872169249, 49.81224198495188, 63.36984388289913, 55.03057895168182, 47.18912163088399, 35.46392556159727, 41.30975546375398, 51.06351337125225, 25.736322018408007, 4.8466443438683795, 0.30646302466911657, 0.22436671379593112, 0.6924043006954655, 4.662756766042402, 13.422879269046168, 22.578390413714995, 30.04353357899574, 21.95425698834081, 20.29160153481268, 14.8098175948666, 18.720749155167614, 28.473438216793923, 43.93874368359966, 56.728302355735536, 58.472431321297925, 60.29299551440824, 57.65203622079665, 58.99482042558732, 60.673300681575654, 60.68134938516925, 57.65454261533676, 54.465694888945556, 55.24454424458166, 54.928518879798155, 53.73840508922454, 53.01922282864971, 54.56545645190824, 57.94290350329492, 59.55097329232001, 55.926291404231904, 57.205278258169855, 56.33190762612128, 52.309850415875836, 52.93139703812138, 45.9545869981089, 42.27543123306767, 41.14993849108296, 43.86889803794123, 43.095571379507746, 44.83892763814619, 41.678093479525664, 44.31623651135353, 42.605851696383574, 41.53516231044647, 44.038928862540956, 41.548251259711485, 42.290312705501435, 41.61682213506391, 41.226475700255364, 42.68109844576928, 55.30214817293229, 53.89739051941903, 56.60252371141988, 51.19971767548592, 54.099953482227946, 42.98743947859734, 45.052889008675855, 59.451301943871286, 55.92682092420517, 54.057666409400206, 50.00303783724385, 45.70697953624111, 45.5695749867347, 48.75348052670879, 51.61161753439134, 55.26155164164882, 51.15173924353815, 42.613676824877345, 41.56558421350295, 45.996940751229566, 54.98316926340903, 59.69402605487455, 59.188671804243526, 49.91262720477197, 54.79424830405943, 58.64019893830823, 53.732160675910215, 56.04715139635148, 56.27202087833036, 58.50203737135857, 57.73081310333745, 57.40635464268347, 56.29219362812658, 58.96013490615353, 59.13421753914126, 57.94610415735553, 52.44458775366507, 54.303622553425456, 56.744352694480654, 57.052882409864864, 61.408635262520086, 58.16634916490125, 53.69852635168261, 52.45751196338285, 52.628809713548236, 53.82704673274871, 53.45005989074708, 54.956363785651426, 51.01400913730745, 42.63828969770863, 32.564413432152044, 21.84014347291762, 24.72650585636016, 15.861422688730302, 23.843533262129753, 13.616512956157809, 16.19653822914247, 13.209061065027791, 6.558495144690237, 1.6513765555235649, 1.1703587732007428, 0.33608598995112604, 1.7941151607421137, 16.804016290172456, 47.14371235139909, 50.437338352203376, 33.0244662684779, 35.93927760278025, 47.695342725323094, 65.36793847237864, 66.67529582977295, 30.49564361572266, 4.388906196240456, 0.2508998932617326, 0.29545305416949336, 0.17070826082941026, 0.1143252544645821, 0.1667510030130225, 0.1723446859227073, 0.12406543422971042, 0.29471380996607965, 0.22617374666996543, 0.12437431321990107, 0.21210187595457802, 0.1642950477018472, 0.08901521863956606, 0.12179121795681216, 0.1577952513170819, 0.17736518184744543, 0.11667342886569039, 0.1439168637678508, 0.14574979041372577, 0.16571633998424778, 0.16883310741714894], [0.058217484338749806, 0.04775792503008439, 0.02680662497427435, 0.07507572791749433, 0.024976584564654097, 0.016635177927392147, 0.030201899841608062, 0.009414160515241807, 0.014623992197636156, 0.013014317937045088, 0.09466472637629318, 0.008446935248831588, 0.0523240733591299, 0.027560763842155857, 0.059164185152058645, 0.02990196301271358, 0.015115044981000886, 0.04781118346258037, 0.06557805328479697, 0.06699705496430397, 0.047952522854170496, 0.057144670131345915, 11.956194254659838, 39.11646020027899, 52.966690524931884, 38.9966514033656, 18.872646862460723, 10.590933888189255, 29.45687447824786, 42.86233155958114, 20.262723084419004, 2.2812840775136025, 0.1670852165308691, 0.10849884936525937, 1.7952121986496834, 10.541799337633195, 16.000794306878124, 12.837570444230112, 7.298246314448695, 6.0144825039371375, 4.816814718707915, 8.051468864563974, 18.12019898045448, 27.533336301003736, 46.33544914184078, 52.06285484375493, 53.75172545832973, 53.59656826142342, 50.980923944903964, 50.82321720738565, 50.20667945185016, 51.971969604492195, 52.98712999589982, 54.29594647499823, 57.98186440621653, 55.12613573381978, 53.728328520251864, 53.64894759270453, 53.31871932552707, 51.62684417540028, 54.183178332544145, 54.96121183518441, 53.054477091758486, 53.054100544221946, 51.84377870252056, 50.39139563037504, 48.27178993532735, 41.905473278414824, 37.95356765870125, 35.24658703034924, 37.73387962772001, 38.05833024363364, 38.044703929655014, 38.738018158943426, 37.24542687016149, 37.777406169522195, 41.00171604464131, 38.32254109844085, 41.050259297893895, 39.43325434961627, 39.1113297400936, 40.04008423897528, 49.11641351638302, 50.43209414328299, 52.87374604132868, 48.67413490049301, 53.25145459944203, 41.8905565046495, 40.109502346284934, 55.75545257137668, 49.677045729852495, 50.90377092361451, 44.80116305812713, 42.60418468906034, 36.31464450590072, 38.565320122626524, 38.189074608587454, 41.32167554670765, 39.38629965628348, 38.241665747857866, 38.76963638490246, 38.64813312407463, 44.21704369206583, 51.36484945974043, 52.489451823696015, 51.39162355853666, 49.764691091352894, 55.283528681724306, 53.405619436694735, 54.460917442075676, 53.69019915980678, 55.63103891188099, 51.77775736778013, 52.430867302802305, 51.83331381890082, 54.59866716015724, 55.03981221106745, 54.255149902835974, 54.04523249595396, 54.39687690427227, 53.40826311419087, 55.567245483398445, 53.944243231127345, 53.29760912925967, 51.84162139892579, 55.37699091819025, 54.903254893518266, 53.70284095887215, 58.05322408676148, 58.75344560992334, 55.1387147749624, 43.39920205454673, 27.468170042960878, 20.028463448247603, 21.988628718160815, 6.023290186159073, 4.718728007808809, 15.578675693081273, 6.996896007368642, 4.401440620422363, 0.7337236512572535, 2.0389837050630204, 0.3927107660039779, 0.032790972505726164, 0.4809482828263314, 8.702681353015285, 36.217244209781775, 37.51342673455515, 29.932273587872906, 32.612880199186264, 41.01814293092297, 50.28397367846582, 53.33790363803987, 26.207988992814098, 2.9471096011900135, 0.04994085043548577, 0.0319998124389038, 0.04936281794441804, 0.010098560484156254, 0.10361245713166653, 0.03435317900091891, 0.014727639105741777, 0.07583881277711162, 0.023897735499626687, 0.04551181652312798, 0.033627571162557414, 0.004946697717382303, 0.01657105445291006, 0.0879952415162998, 0.05033530144681854, 0.01770919680805697, 0.03546485684872155, 0.04236783381671675, 0.009716489453679852, 0.05390265498370413, 0.02656464652729131, 0.013234384354173899, 0.04269380422849809, 0.02554016289181046, 0.07091710389020943, 0.038387489940730796, 0.03382501883372184, 0.020499806137635343, 0.017766982820185444, 0.01206370816010261, 0.02914522710676876, 0.036844427982765826, 0.011790399589846212, 0.06939959862539846, 0.082597462610612, 0.02435489272278163, 0.014223072531392739, 0.02358736838364313, 0.04274598630746046, 0.016850465871093255, 0.017114915592115254, 0.057042788098295855, 0.09009470547279043, 14.26195759927073, 44.53942721889865, 59.38807725906373, 45.833723083619155, 26.72420232526718, 14.565514729868982, 30.20021461671399, 43.66448371641098, 21.549325220046505, 3.0886225883037817, 0.030658672105581052, 0.07641659628960394, 0.9131253246338138, 9.607788862720612, 14.852941113133586, 17.521500164462676, 16.95173078967679, 10.35317353663906, 11.100852797108313, 9.024772663270275, 15.30206818734446, 30.433623098557998, 46.34213678298458, 53.275082957360056, 56.20073964518886, 55.75136546165713, 51.07256227923978, 53.876535277212824, 54.81025157436248, 54.75068646092569, 55.12901867589643, 55.48412261470672, 56.80473758328346, 55.295366394904356, 54.828341545597205, 53.11556408482214, 53.009212939969956, 53.05697171918808, 54.50039609786003, 55.26297546202137, 54.89591613892586, 55.17232948733915, 54.07547396998252, 53.32827814163701, 51.289759605161606, 42.08441965041622, 39.48889709288074, 37.58695940817557, 39.418290507408884, 40.320353277267955, 39.311868759893606, 40.607349180406146, 39.392438165603146, 39.014709995638945, 42.09428048902943, 41.33471350516043, 42.88313581097511, 42.1719551855518, 40.911395626683394, 41.625714148244555, 50.84726133654195, 53.79988039693525, 54.167543765037294, 50.18226661989766, 52.9045170353305, 43.56963688327421, 42.17935277569679, 57.71610421519126, 51.61493585955713, 52.90820798566265, 47.37392802392283, 43.10154907165035, 39.004958983390566, 39.50825398968112, 40.33694490309685, 43.40837647837978, 41.846033680823545, 40.52954504566808, 40.957730585528964, 40.58643510264736, 46.83339795758648, 54.4335824443448, 54.80044172656152, 51.473459889811856, 51.39611467238396, 55.46929605545537, 54.14858694999449, 55.465918894737, 57.399137481566406, 57.89216372274584, 52.20465244785432, 52.31039562532979, 53.39756681073097, 55.58617484185004, 57.350064708340554, 56.82408271297332, 54.75956278462564, 55.52214999352732, 57.41491717676963, 57.84489916216943, 55.282410806225194, 53.75060366046045, 52.16750367995232, 54.050802261598655, 54.12205211577877, 54.64604154709847, 59.554883895381806, 58.89147381628714, 58.15842989952334, 43.39268307532034, 26.430899250891905, 16.870641669919415, 16.233085893815566, 9.811953133152379, 15.379235917522063, 14.285177050098298, 13.01661781726345, 8.209360934072926, 5.484249639895655, 3.0189009876020494, 0.169970671375913, 0.1809055192936813, 0.5817225527378821, 9.687291383743286, 40.03899774243755, 37.45593655493952, 27.592301291804162, 35.47946991459016, 43.773203972847234, 57.380227734965665, 59.463496592737016, 30.06209227346605, 4.785360741999842, 0.09129847474997083, 0.04401306509070339, 0.06634282353784769, 0.025758247056435195, 0.03826698047980186, 0.04941033837836116, 0.0381712731154215, 0.02118728194956578, 0.04183670888925272, 0.03195769484004667, 0.011457048878524334, 0.03100208633939826, 0.020898710035028, 0.022050793275177, 0.06441543825090894, 0.055111832841629946, 0.05394167950256698, 0.043159217964256966, 0.08301705662761966, 0.04288487038725326, 0.018668982403112516, 0.14587915202061977, 0.1623391486223667, 0.12795886926112637, 0.26920063060618216, 0.2170291849442067, 0.2637965851012738, 0.05392195273851676, 0.1253204241455082, 0.07682312850750263, 0.11369472579850305, 0.1844863368258361, 0.05677970967465832, 0.2990552915200111, 0.16740764761644025, 0.149808217801394, 0.07691798551428704, 0.1221926786726521, 0.17212933860719207, 0.14284388102110357, 0.1718534090586247, 0.10689109128208892, 0.17713180082219263, 17.73880143319407, 51.96028878611904, 67.75080973102202, 53.974621988111934, 29.79690867085611, 18.57869267463684, 40.68643200782038, 54.81456618155203, 26.33077879105845, 3.492649514828959, 0.49954071580882997, 0.22014415973136503, 3.0020806385624796, 17.06840757400759, 28.276607797991847, 23.099489058217696, 14.576824884260855, 14.925322571108419, 11.33117437362671, 14.271715475666909, 22.86340748110125, 29.914048294867243, 49.60584686648462, 56.67569944935461, 58.87615696076424, 57.88496617347964, 53.5990785783337, 55.25910016029112, 56.11399642882809, 58.22512195956323, 56.977949450092936, 58.13458581124583, 59.969141098760794, 55.15198023088517, 54.71967620234336, 54.59478009131647, 53.80364979467085, 52.58488701235864, 54.836045080615634, 57.41184596092471, 56.818207002455196, 58.91565915076964, 55.83765760544808, 55.051069413461995, 52.897535216423776, 43.9990815039604, 41.6440982972422, 39.27479843939505, 41.4658736413525, 42.3190087656821, 40.66262714324459, 42.95617818832398, 40.04217093990695, 40.8998050228242, 44.6821818813201, 42.74527234415854, 44.404921300949596, 45.26619142101657, 44.06593438117735, 44.16207559647099, 53.86010839093117, 55.732032099077784, 55.65085080362136, 52.38092768576838, 53.582887034262384, 45.652054586718165, 46.375143527984626, 57.95073647652903, 54.46421615539059, 54.15483528567899, 50.137292723501886, 47.47495651245118, 39.795249892819314, 40.87655321244271, 42.11615946985061, 45.128461314785866, 44.291823679401034, 41.73052380161901, 43.26398618759648, 44.080400082372854, 48.865436738537205, 56.46436214447022, 56.855414605909786, 51.78750838002851, 51.759906661125925, 57.08634414980489, 57.47200727462769, 57.74574948895363, 59.47404384613038, 58.16573727515436, 54.02871931752851, 53.38623508330315, 53.88425057934177, 57.388268593818914, 60.532311085731756, 60.166463775019494, 57.50185651163901, 59.13331539400163, 58.799929618835456, 60.87338470643567, 55.46765650472334, 54.532194752847, 52.32267264396914, 53.90081867094963, 53.50665576996342, 55.23412250703382, 61.706382382300596, 62.229979576603064, 59.203561121417636, 49.201230848989184, 33.53432732243692, 23.351407204904866, 26.455272859142674, 15.797073264275829, 19.786957233182846, 22.541814311858147, 20.40777429457634, 11.342255069363503, 5.214856353498274, 5.149582230275677, 0.6373444584108169, 0.3229806157610109, 0.7131773569891531, 12.028358021090108, 45.00426730801983, 50.647781356688476, 42.73871021886026, 45.774252107066495, 53.59733312360702, 64.59957361221313, 68.36865363582488, 38.30851862507482, 6.523978287173856, 0.17067109024332416, 0.1526560117640803, 0.15823803481555757, 0.11198802745991177, 0.1363042940295512, 0.12112351870464703, 0.11809089836934883, 0.2667314985827092, 0.10760237327626637, 0.1830453560837815, 0.1628426369279623, 0.1359106320887804, 0.06489340816774676, 0.13995323209993302, 0.1389120726455604, 0.08657260091915246, 0.1546572326051612, 0.17566013059789137, 0.19279969315375053, 0.1284558611411241, 0.09961812832062283], [0.04123576270836977, 0.026030508959065043, 0.037296921645681706, 0.01508156693870983, 0.008853384154668499, 0.02953562359776228, 0.03650123208400704, 0.04455842393180055, 0.01768022144754087, 0.030031874287693255, 0.028178427976766424, 0.020745770157044454, 0.05188276074946888, 0.021502697584970344, 0.04302886427350102, 0.05299785917985344, 0.03976154141128063, 0.10291903264700406, 0.07607235468082851, 0.024790890597467943, 0.06596917181365913, 0.09818986463811129, 9.37280554925242, 42.900351093661406, 47.765349188158595, 41.82026370879143, 22.566217337885213, 31.46226271506279, 49.697795068064046, 47.40585611712548, 17.102261550964847, 0.8037027187885777, 0.15391219677703996, 0.03002424213674761, 0.1833649986093083, 6.779957067581916, 11.473101415941793, 14.57256813203135, 18.32799634625835, 6.5672763509135095, 7.736650609201002, 6.788193064351236, 17.17574715614319, 32.645280937994684, 48.73887754255726, 53.21939706802369, 48.74946401965234, 52.773898186222205, 47.52150327928605, 48.12698387330579, 45.70116266127556, 48.104457701406176, 48.835289401392785, 52.672814784511445, 52.61495590209962, 56.432818443544456, 52.75588666239093, 55.300998918471805, 54.873770436932965, 55.001243545163064, 55.56543334837883, 54.273494828131895, 51.15317090865105, 50.4790174576544, 55.44796620645831, 52.41613488043509, 50.65919153151974, 49.478028589679354, 41.69563824130643, 35.529405609253914, 35.95788532687772, 36.2939343913909, 37.317704385326756, 39.71485307139736, 43.06153697352256, 42.608601277874364, 43.33383575562508, 45.37984209675943, 44.51368862582792, 41.43849941991991, 38.97590598752422, 37.32525102553829, 44.209724549324285, 49.7168577871015, 55.11646709134502, 49.7462010383606, 53.520313462903424, 42.38207655568277, 36.3647606295924, 55.83991689066733, 52.26557862374091, 54.51828995058614, 48.401761593357215, 48.88387580071726, 45.8990187798777, 42.385940090302505, 38.479086814388154, 40.25836413906467, 39.87939650012601, 39.65295022533786, 37.474344238158196, 37.3931315637404, 41.714461695763376, 49.90282520171135, 50.747158527374275, 54.173960762639204, 52.57634016775316, 51.75735712051392, 54.64256240475563, 54.437657786953835, 52.511503388804776, 51.628671999900575, 52.35480862279093, 54.93368071894492, 53.3175818381771, 50.577735670151256, 52.759777653601866, 55.254307023940555, 56.842615912037516, 53.95355493791642, 57.90101258985458, 54.62180129943356, 53.576823049975985, 51.997178677589666, 52.64848432233257, 49.50459872522662, 55.22609733766126, 52.84350456730012, 56.684430645358184, 54.98984121507215, 59.4183305002028, 49.724824120921475, 39.37785871567265, 17.036520665691747, 22.59689615618798, 3.452958315610886, 15.487136398592304, 14.374804189128263, 7.265358711442641, 5.4946179351499005, 3.3986356950575307, 3.3341796311639973, 0.05835015927591632, 0.09295537737348387, 0.3000183866148995, 6.738596164411114, 36.75001190554711, 58.009917197688935, 55.1411231102482, 48.003927353889715, 39.17028688615368, 48.660987115675404, 47.84883291490617, 26.158990744621526, 3.4477141066904995, 0.2835672000242818, 0.16955045682768669, 0.08102705131375021, 0.09557708346795651, 0.04394577958831384, 0.09868539329017363, 0.0959881968916424, 0.01269159286523298, 0.08745773124598688, 0.08087253904030209, 0.049000144260184425, 0.04330876981839538, 0.07454760988513309, 0.004389221280542833, 0.04333095189424292, 0.038130827503459114, 0.02487743938071353, 0.045913177647537766, 0.04326853871105179, 0.029462737992646235, 0.07453657821902344, 0.07051882243925525, 0.013606987495516098, 0.058665178460820075, 0.060695472338627425, 0.0742696655253249, 0.1255541575712062, 0.04852290595731428, 0.09928591429225861, 0.053631218540812695, 0.08483024118768592, 0.007171935595256547, 0.018512903479859233, 0.012024704708657678, 0.038469882696987166, 0.05010013926714178, 0.02303953316333073, 0.03165525290363979, 0.04699466013980489, 0.04855326602175351, 0.02501665862397321, 0.03960813996532271, 0.12209541614978545, 12.272758945342034, 49.82256174087525, 56.215938829606586, 46.848663822297134, 25.20407207550541, 27.73114731234889, 42.2136813594449, 51.11385307004375, 19.634622181615523, 1.9068835483443354, 0.12382921867913778, 0.007799793487309569, 0.5762887830215117, 4.121203451387344, 7.076492665275452, 12.08808885466668, 9.928905463987782, 8.710134836935229, 12.29670403465148, 9.729380376877325, 20.392416254166637, 33.56268213641259, 50.3728820431617, 54.47763458375008, 54.58859451355473, 53.99010358318206, 51.52037535944293, 50.51438939186835, 48.86480915930964, 51.0129540197311, 52.688786675853116, 53.21208577002249, 54.874445084602606, 57.31108419356808, 54.731000085030836, 55.67238461586737, 55.35426470541186, 55.58886166541807, 55.83936383647304, 53.550186234135786, 51.87624808280699, 50.971341594573, 55.16749320491668, 54.03746228064261, 53.42463116491995, 51.22087886256557, 42.393412205480764, 37.523942608987134, 36.8284789208443, 38.1047946406949, 38.88882152495846, 40.2027488523914, 43.35801716773741, 43.45986543163177, 46.345698295101045, 47.19913151956374, 46.73252244149485, 42.199352941205426, 41.77440727910688, 39.02705369457122, 45.45209215533349, 50.96494028645178, 56.11601252709666, 51.31853019037555, 52.93782972520398, 43.38320662898403, 38.900063037872314, 56.411123814121375, 54.639381362545876, 57.52619481855824, 51.430745278635335, 50.31390920762093, 45.44931903962166, 43.8921380812122, 39.598068421886815, 41.4783428561303, 41.480358954398866, 41.639477745179214, 39.201552098797215, 39.40287559263168, 42.96865917021229, 51.67789382319297, 53.70203687298683, 54.91920717300908, 52.07131931858679, 52.5375557714893, 56.31622991254253, 56.38227478150399, 53.22524924432078, 52.57919565323861, 51.45128673122775, 55.38139573989376, 53.277793315149125, 51.177622964305264, 53.97035052699428, 57.43888678089265, 57.30280014776415, 57.96011094124087, 58.0665954466789, 55.330491219797445, 53.607205729330744, 54.23747178046934, 53.318868375593624, 51.50871023055046, 55.471971111912886, 56.752534758660104, 59.18349427561606, 60.018645332705596, 60.52729829665154, 53.69471773024529, 37.471476985562234, 19.539028136960923, 12.673174104382916, 9.121958209622292, 8.006570473794016, 13.013240656545086, 10.217504635933908, 8.418472293884523, 8.037645451484188, 2.6436772509928677, 0.3235526076487957, 0.02022247464816657, 0.49943251355040463, 7.31566212831005, 41.074840791763805, 55.24879217147828, 55.97652912139893, 53.03348848896643, 49.98717184989683, 54.66113874989172, 55.895602780003706, 31.276040346391742, 5.624263546159191, 0.23202903328403351, 0.17443203036823582, 0.13544436033454635, 0.022470352818228068, 0.019661207991321723, 0.03379504947412399, 0.024527727904158737, 0.007977489017761283, 0.03828229457740823, 0.06060847922438576, 0.03479368721825942, 0.021652818259392536, 0.13154963061453837, 0.04726780878920709, 0.01832114784197221, 0.05456948855651483, 0.03159371497590215, 0.025666418012171507, 0.04221676893892788, 0.03523603404661821, 0.0517686672749058, 0.12496944096299911, 0.12328438460826875, 0.14116430985591105, 0.11852828094795828, 0.1401617305894052, 0.2658346547715126, 0.1871490745895332, 0.1390452800138343, 0.13533268003694474, 0.18795031062777967, 0.12162436400690388, 0.04302740487600527, 0.1236570863834312, 0.07508331984882394, 0.12645295490660977, 0.1434247442070515, 0.16350465946860854, 0.15156124147676653, 0.13807856898394325, 0.23014212808301374, 0.22586879771082635, 0.3551034178704985, 16.45046757113549, 57.897101986792784, 63.06432262543709, 53.590084583528586, 33.172896600538685, 43.29742831568564, 61.28466483085387, 58.79337926064768, 21.436539426926647, 2.1336789140778203, 0.33746792063597714, 0.17516931338656336, 0.8061678671548445, 11.064239432734828, 17.9149668447433, 26.764132053621356, 29.539365845341838, 12.477345851159866, 14.013479371224681, 14.693124140462569, 20.876426927505, 35.38528596201251, 49.53988436729678, 57.586513027068115, 57.00812424382856, 57.12997659560173, 52.71456841499575, 53.50692641350531, 50.42356691052837, 53.25887180143788, 55.625422077794234, 57.14180646404144, 59.058688379103145, 60.039720227641446, 55.86901303260557, 58.126533185282064, 55.97772936667166, 56.24048109977477, 57.27053473072668, 54.29482075475878, 51.793886153928696, 50.6094519553646, 56.58240587480607, 56.116106663980794, 54.54149077015539, 52.875056112966234, 45.333769936715406, 40.23049569899037, 38.75239756799514, 39.728087148358746, 41.341946355758175, 43.104592830904075, 48.426954976974, 46.12293120353453, 48.49344307376493, 50.17727736503848, 49.84709616630308, 46.38959353969943, 43.13541481571813, 41.490541427366196, 47.69523682132844, 54.6513367468311, 59.22758956109325, 53.17705115964336, 53.228324382535874, 45.21941715671171, 42.71894539556196, 57.57117263732418, 57.79143333435059, 59.0429675194525, 54.300288538778986, 54.21987995024651, 50.86474334039996, 46.083119146285526, 43.06654584023261, 43.25457249918292, 45.08819818496705, 43.281985944317235, 40.72777378943659, 41.50210457463419, 46.35335476167741, 55.87745005084623, 56.00224418024863, 56.505880432744185, 53.07830941292548, 53.4247370689146, 57.51243122162358, 57.75257049068328, 54.65481196680377, 51.939508068946104, 53.574061701374674, 55.28223429956744, 53.39555463483257, 52.220459599648755, 54.702174586634484, 59.72757408695837, 62.5436201403218, 59.8571103618991, 61.53331172081732, 55.6740673126713, 53.95905410089801, 52.2864495554278, 53.24522979797856, 50.623733305162006, 57.737626260326756, 57.34263181686402, 60.96414050748272, 59.613911644104995, 64.710333501139, 53.82800771344093, 44.17303862110261, 22.251211789346513, 27.888148023236184, 12.695218805343876, 24.027033505901215, 24.69281073539488, 16.345750093460083, 14.03520537960914, 10.828504985378636, 8.552435944157263, 0.2831674247018753, 0.2741557792309792, 0.6790762094240035, 9.060687845753087, 45.762359480704035, 67.51236100350657, 66.27550432758947, 59.547945222546986, 54.06594653283396, 60.999535975917695, 62.70044042218117, 39.04153508524741, 9.140452184984762, 0.39192240024285935, 0.22589015624215528, 0.20160869304691592, 0.1652393276773153, 0.23544990697935705, 0.23057577981343194, 0.2005349595340029, 0.08342242439187343, 0.16556961882498958, 0.2710341548006381, 0.12058714224446206, 0.17505706618389777, 0.2216798442626192, 0.1433633039555242, 0.15273527122072636, 0.23406791500747207, 0.11362298166439419, 0.17078353662885007, 0.13341482488378403, 0.15021257432958773, 0.14620351364776013], [0.05411620199259731, 0.08399086929256878, 0.037215720156147596, 0.0015704540302038134, 0.03305211272691527, 0.041328620225671804, 0.009691875048672721, 0.07949900467910113, 0.044937350171347784, 0.0812639716652132, 0.010778255715605714, 0.04965087466482675, 0.006350963695665762, 0.06822569911638576, 0.05334604614143891, 0.06397534372104753, 0.009929481048827932, 0.09949261247510872, 0.038812032885729306, 0.060914064036502, 0.029369482109623573, 0.0789327278072315, 8.253348354370363, 41.11325648523147, 49.65113847486435, 43.769191388160955, 22.797843102485906, 41.23690920491373, 54.24927811468802, 42.67335176467896, 13.209309154941192, 0.9540257783186052, 0.11267807349682817, 5.287142693996429, 12.785587272336407, 22.378310311225153, 13.858042705443598, 12.847439127583659, 14.696880790495104, 9.641940939810969, 17.268760281224406, 10.652815161212798, 15.736138263056356, 39.814704848874, 46.56937537654754, 48.22530592641523, 55.04114973929621, 49.13443288495464, 51.8441552500571, 44.688838143502515, 41.560908748257546, 42.06967938330866, 44.152261826299856, 46.00387157932405, 50.791496999802135, 49.163077954323064, 54.6180828925102, 54.1755767791502, 55.93352817719983, 54.12411920485958, 55.10541385219943, 52.88549746236494, 53.95502190436087, 50.2984001559596, 49.95327864923785, 53.93395093179519, 54.67459247958276, 52.236678600311286, 43.698737775125814, 35.78914103969451, 37.61073681616014, 36.96312604411956, 46.45994517111009, 47.38280434762278, 51.454001011387, 50.690715620594645, 55.109453893476925, 51.328520467204434, 48.33826234263759, 42.26389946476106, 41.93301223939465, 37.308722157632154, 43.177317496268984, 46.81954806850803, 53.98187445056055, 49.17912829306818, 53.97759122233237, 41.62584750883041, 36.008530970542665, 53.86241866696266, 46.341540582718395, 52.81336899726622, 51.550444249183904, 53.202326913033765, 50.339839996830115, 50.021143497959265, 43.43399347797517, 41.238007468561975, 40.065375681846376, 39.41535657451999, 40.2544496136327, 39.2259531636392, 37.46658186758719, 49.0738401105327, 52.891028004307906, 54.611909081858975, 47.178268432617195, 50.630954388649236, 50.54083008919993, 50.69936836919477, 50.18185869339974, 54.15815753321494, 55.25130248838856, 52.105361569312315, 55.03563488683393, 56.24176763719129, 50.20943295571112, 49.69744205474854, 49.185435464305264, 52.644303075728885, 49.75858003862443, 51.61166068046324, 50.528658974555235, 52.03887347252139, 51.19844682755009, 53.06820930973176, 56.168999825754476, 52.942497345709036, 54.859128229079715, 54.70966631366361, 56.22890618539626, 54.2357773165549, 40.26035670311221, 30.103606639369843, 17.04499298526395, 10.934161870710312, 10.387617830307255, 11.120755883955187, 11.251017797377802, 8.25896813023475, 7.944491121076769, 1.6952449564010867, 0.3329218323192289, 0.05951366680223615, 0.44654226291083526, 3.953238735275884, 27.168848091556182, 46.60978363406274, 61.77864813035535, 36.11829065507458, 28.035825260223884, 55.98630759023852, 49.33933750275643, 25.47906356473123, 6.332918165191528, 0.19864051602780822, 0.10902706698905076, 0.014997078931980557, 0.05237747734833149, 0.033639575760330886, 0.05520428433233211, 0.05982253813154756, 0.05209024034200176, 0.03208368182963422, 0.03084177861080295, 0.03326467914326537, 0.019607269655792944, 0.00790189768585767, 0.014661297806718898, 0.020407546168914246, 0.04462954370425113, 0.04018133844158823, 0.059038301584340876, 0.045386335151570464, 0.04312064926770907, 0.04328642686408374, 0.007752380784480803, 0.01428634852110859, 0.0720950253608246, 0.03873222184577777, 0.08856966190280453, 0.01689665905770756, 0.02804799767721805, 0.04600492050690998, 0.054729949502695, 0.02423642871661052, 0.03332176035450351, 0.05644013354134175, 0.023842192209896543, 0.06364526707799205, 0.06398880771631676, 0.09981802364270534, 0.03689232379979184, 0.086500964037353, 0.04390178698926203, 0.022163831463624394, 0.05244549829512835, 0.20436317750042488, 11.385468802144452, 48.363608698691095, 54.70068408596901, 49.98982337213332, 27.006112875476962, 39.081441279380556, 54.63325462033672, 44.9234821719508, 15.36758549751774, 1.1543168920663096, 0.13067443644808185, 4.370577450721495, 9.31660484883093, 7.851379936741245, 8.826839077857233, 11.019889193196452, 11.2051054739183, 14.288247285350678, 13.538083203377264, 8.57081126782202, 21.739952410421065, 39.41958488956575, 45.53327737316009, 52.8301763534546, 57.185756621822236, 53.852942220626346, 52.60987251035629, 49.23516327334989, 43.941736452041134, 46.171796091141246, 47.51053633228425, 49.960990028996626, 52.06747147344774, 52.58668345789756, 56.63305936321136, 56.830029026154556, 55.76395234754009, 55.59252515915902, 56.310911178588874, 54.61480379104615, 53.614050265281435, 50.336113745166415, 49.52595995318506, 55.312287499827725, 55.73207524514968, 55.92312997387302, 44.538650589604536, 38.05068946653797, 38.782960676377826, 38.81310409115207, 46.33584922359836, 49.08554838549707, 53.90077552487774, 52.49928128334784, 55.81522164806243, 52.904564103772564, 50.19635185118645, 45.595843099778705, 44.548425136073945, 38.7162450821169, 44.07151591393256, 49.20940114605812, 55.1375106073195, 51.57571608020414, 54.812083321232954, 43.75807931346279, 38.03063831021709, 54.82772181110998, 49.48004861031809, 54.647347696365856, 55.24741934191797, 54.758315470910844, 53.57427743173415, 50.81574509220739, 44.53889769892539, 42.98205014198057, 40.58457982155585, 40.87330548994003, 41.604176413628366, 40.55331853128249, 39.42910448197396, 51.47851582496397, 54.279166575401064, 56.71277369222334, 48.08464580966581, 51.0748686329011, 50.38540617112191, 52.526267190133375, 51.39759340593892, 55.313519124061834, 56.278853647170536, 54.04569141326412, 55.12104841970629, 55.860375973486136, 50.6431451151448, 50.229146788197184, 50.85519236903037, 52.89209488899478, 51.59214688885597, 51.1273067997348, 50.91969182414394, 51.6280875667449, 50.674406405418154, 53.54307889938355, 57.20951834032613, 55.517615733608125, 56.97301903078633, 57.15349904952511, 59.17050730797553, 56.19533854146158, 45.860395200790904, 27.68060561149351, 16.154151135875335, 9.446796159590445, 10.513307240701492, 11.853133978382235, 11.701643216994501, 9.547260807406518, 12.276897045873827, 2.4571960058904465, 0.9639483942620216, 0.06930712415205856, 0.4857267102887554, 4.982584378411693, 31.75056672865345, 54.21558495490782, 65.93257934816423, 45.16802626271402, 32.82047556292626, 61.75012857683244, 54.955630302429206, 31.795970124583093, 8.299324416345167, 0.25668284585399015, 0.12094177200549072, 0.05268845541943466, 0.0811018061734015, 0.049103255864352956, 0.04532437779069428, 0.11299639835112518, 0.021493634764826106, 0.03593698151469712, 0.014041578641251452, 0.02292880089953542, 0.08424924010591162, 0.017959165552090255, 0.05390580743551255, 0.022758064799070842, 0.01917465022885271, 0.04735463336410542, 0.01679074357173616, 0.055038859136402614, 0.061359061529078794, 0.023408452379367044, 0.1452564910775231, 0.16688699894134076, 0.1192030818351815, 0.10245225527473997, 0.2644519886422542, 0.1262970406922602, 0.13388212319583664, 0.16206229976829023, 0.14945385617113885, 0.15493095582050664, 0.10041768662631513, 0.18576872204580616, 0.09959112372129195, 0.18035896152498263, 0.13499269021614907, 0.23652799187168, 0.15254977069074108, 0.18231786366912628, 0.14138243040971218, 0.24877565402177074, 0.1749539813928066, 0.5375864500960996, 15.849438867261334, 57.98362162805373, 61.484960663703184, 56.440004225700136, 32.55022621923877, 52.30249989417292, 62.02913068955945, 50.28538573172785, 18.118577080388224, 1.7408628569495295, 0.33908905461430555, 6.598667569698827, 17.49644602498701, 26.975779225749356, 22.300959210241995, 25.450842111341416, 26.50662256825355, 19.002104689998013, 28.87317872816517, 16.99675371569972, 18.910540880695468, 40.83069286038799, 50.68004677372594, 54.45981917842742, 60.14998197555543, 54.80249704853181, 56.31056601001371, 51.397546337496856, 46.236091583005845, 48.65809240648824, 50.221160842526345, 51.58135252614176, 53.99694811913275, 53.62062023532007, 59.415035709258056, 59.566474499241004, 58.821486965302505, 57.22867127387755, 57.95523543511668, 56.641017852290986, 55.465809068372174, 51.0189748579456, 49.250805685597086, 55.36454523763349, 57.66644308643957, 59.20777766935287, 46.05147346373528, 39.928222164031, 41.14038751971337, 40.64430182979953, 50.230625521752145, 51.73320708736297, 56.106991075700336, 54.80656062403033, 58.79707413335001, 54.888906863427934, 54.67945229622626, 47.11585960080547, 46.36816955381825, 41.82953226950861, 47.67487187539378, 51.48661159699964, 57.71701028270107, 53.90679636309224, 55.79351132915866, 46.18168438634565, 42.26397006742416, 53.93691232127529, 50.412988278173636, 54.11285415772469, 56.68750578357328, 57.75706944927093, 54.50037648600917, 54.14959892149895, 46.87261381456929, 44.87400931696738, 43.65313629950247, 43.832533744073686, 44.63398771901285, 43.706390319332, 40.556919267100675, 53.241083852706424, 58.06766625373595, 59.06943567337529, 50.49768793967463, 51.260859581731985, 51.21536008773312, 52.90991813905778, 51.37192149316111, 57.096385417446015, 59.56778849324873, 56.06244864002351, 58.39084209934358, 57.41485834121705, 49.82043189387168, 50.08902403616136, 50.03593083350889, 53.139031625563106, 49.303114414215095, 51.89708371316233, 50.635696534187566, 52.28521400882352, 51.70807253929877, 55.06270708576326, 58.68776159901773, 57.26940116574688, 58.709934757601836, 62.42478801358131, 61.18851969319006, 62.554857730865486, 49.86549992715159, 36.912009716033936, 22.353746468021026, 18.992608631810835, 19.900751075436993, 19.91459115859001, 15.076983955598648, 20.347607097318097, 18.41623398565477, 4.988902336166752, 1.933818096595426, 0.11575607688076074, 0.728534723241483, 6.006899581801507, 34.392177135713645, 55.921255080930656, 69.15875234911519, 47.0390909717929, 39.27486511968797, 67.84954363299956, 64.28747846234229, 37.085476536904615, 10.92706238069842, 0.39182486192834, 0.24647829423267997, 0.1728857738236266, 0.16696051273855472, 0.11880321458222405, 0.16765034427085232, 0.23785778261240453, 0.10188426236591994, 0.09851312309864069, 0.09683659330250756, 0.1253068950327654, 0.1808159789370914, 0.11955259412887598, 0.09084737919751676, 0.1036865991209784, 0.1477544126851905, 0.1274962823898081, 0.09135570151791458, 0.13983252728658338, 0.14816152712991162, 0.19372335004229702], [0.06897789020571979, 0.09824245657411315, 0.037369022010675365, 0.09894626921102886, 0.06739898299377772, 0.03298846614216605, 0.02697242746850656, 0.04188062870995172, 0.0408166321745563, 0.043640842120493614, 0.06660758352447903, 0.04754457720405152, 0.06337204948067665, 0.024316513632994988, 0.07748554941386947, 0.025181817604349028, 0.02327064656832766, 0.055508608929812915, 0.06158501150146608, 0.056075406741471066, 0.07505777847742842, 0.04058812729894154, 15.28831341574269, 46.50962983408282, 54.66656338784003, 32.74135939536556, 21.625213276955392, 45.90199585883848, 51.98522721567462, 42.138379696876775, 10.897678925145058, 1.1550165448457965, 0.09951829174233061, 3.8647208915602778, 35.53838783694852, 42.94960821828535, 7.436210292000925, 7.224273354776445, 2.2830989091627063, 8.718505174882951, 10.779860731094114, 10.09614061924719, 34.50611022210891, 36.89413155278852, 41.72324780494937, 54.97916060109293, 55.7065406153279, 54.308007763278106, 50.24632284718175, 47.97187766721172, 42.53507252662413, 39.43170893576838, 38.73675123337777, 38.036019802093506, 40.86708068847656, 43.077885412400775, 47.871641497458185, 47.76437644035586, 49.5388331720906, 51.131876360985544, 51.60822076182212, 49.99539313777801, 52.43442881491877, 55.21749950224354, 56.50129125964258, 53.16812384513117, 54.20112317608249, 52.855852188602576, 42.00503087812855, 36.94621278393653, 39.22767508414484, 44.19499212695707, 52.6357287745322, 54.25294553079913, 55.96302832326582, 53.17759244672714, 49.26796605510097, 49.13857098548643, 49.56758414545367, 41.904441695059504, 38.85524211391326, 36.907408775821814, 38.62904687081614, 45.27529131981635, 53.04681278044178, 50.81750231404459, 53.945314038184385, 42.01875132899131, 33.570071881817235, 54.774605074236476, 48.605038427537494, 52.058206835100734, 50.0492198236527, 52.19579573600523, 51.43622482976606, 52.529083451917096, 44.67261914283999, 39.81465385806176, 38.11452211872224, 38.88117290312244, 38.643885197178015, 43.56325126463368, 37.46065908862699, 45.52707218354749, 54.29538165369342, 50.35364281746649, 49.58964355530278, 55.05296391825522, 53.67178363184775, 53.7479325263731, 51.43325559554562, 52.72676698623165, 52.22540178606587, 49.96934467746366, 50.248523296848425, 52.21577628966301, 51.88297887002268, 52.10864851551672, 50.37125818191036, 50.90174305823542, 51.193543864834695, 51.81040325472432, 51.22684478759766, 53.44971864454208, 54.26548142586985, 55.7370174315668, 52.236945321483, 51.14267464606993, 49.7526337254432, 51.42984705586588, 52.23560779325424, 52.15168476104737, 41.500241448802335, 24.199386373642955, 12.560509904738396, 11.15532079050618, 6.443140689403781, 10.171372659744756, 11.427789215118656, 6.365578270727589, 7.370479702949525, 0.5354347236214146, 0.5741088032241791, 0.016690297953544125, 0.05061290106706081, 3.65632462886072, 19.69146320896764, 46.78179525559949, 43.89310298427459, 21.341467057504964, 38.016317736717966, 46.76701968716037, 57.13646811823691, 29.500455933232463, 8.144339803726442, 0.3566531830978009, 0.017216510342193708, 0.03793315383635702, 0.05291303026399786, 0.07075329897023978, 0.04972810781891308, 0.062151161968828215, 0.07915829473565664, 0.03005568046994027, 0.031521451817224586, 0.04906706970124956, 0.02831988228154519, 0.07272608262757141, 0.08184355548432759, 0.020938690248576385, 0.05597543992823171, 0.0318707189627833, 0.019939372601408153, 0.06183256898375769, 0.058855735171105594, 0.06791293606041901, 0.03739012773298929, 0.05962328632332145, 0.027547715449585553, 0.12529041648151415, 0.03158659801908559, 0.03435900509958306, 0.02369013333302592, 0.0498633606419448, 0.00927611434411618, 0.009107887181603621, 0.04025066556829599, 0.058676834488588, 0.06275931703707864, 0.04483908024286071, 0.041028275454957644, 0.0062659782105906605, 0.034898740855316, 0.03685180157903702, 0.01978420149234514, 0.029080509914145358, 0.018482884324546305, 0.06722419237297389, 17.9892937983236, 52.70027529808783, 58.68812637944376, 40.25065275930589, 24.146987430510986, 47.81850122636365, 52.72202484069332, 47.48267181458012, 12.203063330342694, 1.5081802587355337, 0.08588663813087248, 5.972516575167257, 37.63420435690111, 48.62333628439134, 16.84062965454594, 13.242854245247381, 7.54168184534196, 11.021762124953732, 12.597122288519337, 12.090228507595679, 31.079649233048965, 35.79640134688347, 44.47857164567517, 55.9074483379241, 57.18692548813359, 56.36955453503517, 53.34042964443084, 50.660874228323664, 44.344238312013694, 41.870795603721376, 40.837176538282826, 39.983813916483236, 44.6068331503099, 47.77819102810275, 50.46271608721826, 51.06242687471452, 52.166295589939246, 53.554771484867224, 54.66427664602957, 52.54436500610844, 54.33702153544272, 55.05613711572463, 55.59061104251493, 53.51199803813812, 54.687230356277965, 54.20600260457685, 44.646245125801336, 39.438059253077355, 40.4850261442123, 46.61198408372941, 55.22004904285554, 54.10101644454464, 55.40499664122059, 53.05742671412807, 53.91233867214572, 51.41855847450995, 52.49762212076495, 45.931884319551536, 42.24678224132907, 38.0604757801179, 39.382953874526486, 46.67267099503548, 55.288306128594186, 52.90741958925801, 54.32474451680338, 42.308512503100985, 36.48692284860919, 55.246195562424205, 49.38575483137562, 52.4480825854886, 51.55562177781136, 54.33457005408503, 52.52849117402108, 55.127265376429406, 46.60795973193261, 41.69736016181208, 39.47864401725031, 41.08425448017736, 40.9454417997791, 46.00245168132167, 37.874782931420114, 48.042433261871345, 56.233966042918546, 52.85721325105237, 52.34850929629419, 54.68187239862258, 55.52997904439127, 54.477807168037664, 54.78743514707012, 56.40224749042142, 54.283669456358886, 53.24619470104095, 52.28354700150029, 54.517007335539795, 52.78430423428936, 53.3333654557505, 51.001386950092936, 50.73943145813481, 52.18813926942887, 51.25533688452936, 50.934679200572354, 52.404155961928836, 55.319653711011334, 56.47982805005966, 55.90963309811008, 52.41039253050282, 52.77552596984371, 52.60154924085064, 55.71338122890842, 54.39685729242141, 47.961208820343025, 27.466185323653686, 17.148323905083444, 9.080802740589265, 10.536308999984495, 9.925766587257385, 14.791436387646584, 12.369009987000497, 6.551320149052528, 3.4165062587107387, 1.3676842686630066, 0.05283952795810277, 0.0581447136468224, 4.3118512342053075, 22.192389965057377, 50.699666469327866, 51.71345010880501, 30.132406642360074, 40.03680513751122, 54.12061260592554, 61.97240929449759, 36.89763030698223, 9.58840548992157, 0.48143992741261765, 0.062315009023633704, 0.05778203613214916, 0.012567255837512354, 0.029157338956851634, 0.007321878633041296, 0.010898904987580834, 0.0676129053857538, 0.03366238985871596, 0.027194525933854526, 0.048641565315906084, 0.025872725490180236, 0.07129896041606704, 0.04541394879080115, 0.06308838244407408, 0.032303357541921644, 0.007077272504477972, 0.07097124332381834, 0.021799849684260065, 0.04390290164719186, 0.015599400240687594, 0.17696526862921255, 0.19588241563929668, 0.1929268331056641, 0.23172904857464377, 0.16741864863903294, 0.10198871079351633, 0.07437376921335537, 0.14744774768910102, 0.07302075068676665, 0.18779074983491054, 0.16084841813050932, 0.13593796610591874, 0.14776083250199595, 0.22314579947100532, 0.15744982227202386, 0.14713873846396325, 0.08585818562536471, 0.10153843495514124, 0.23445658205497652, 0.12196263779074916, 0.17822293985274532, 0.3415842949142379, 23.536260666385775, 60.96210871973346, 65.70558394155195, 47.02565293158255, 32.68583236202117, 57.65411115461781, 56.39155903170186, 50.475903095737586, 15.414215614718778, 2.152583267419569, 0.315948112477218, 5.700328109725829, 41.12652194115424, 49.08947467803956, 11.424183576337754, 14.185997959106201, 8.936664462089539, 16.94651992090287, 18.360100946118756, 16.419559294177642, 35.76370839149722, 40.10535640101279, 46.4544616976092, 58.814767945197325, 58.41072459374705, 59.5338599912582, 54.96305927153557, 54.413872534228915, 45.66634770362608, 44.08791142125284, 41.72571105341758, 42.16724049660468, 43.89684492541898, 48.74868739035822, 52.87436969818608, 52.938535751835, 53.398472878240774, 57.710667810132435, 56.16097857875209, 55.22827425310689, 56.37208054142614, 59.65433951347106, 57.87284212727701, 55.16112719812701, 56.00802183151246, 55.40990352630616, 45.48225125958843, 41.5013514795611, 44.14697447130757, 48.576138404107866, 58.10922768808181, 57.135158046599365, 57.39887860513503, 56.238672887125325, 55.02900215887255, 54.5191607167644, 53.50988780298541, 47.23128711023639, 42.2840133790047, 40.08417560208229, 42.28606477860482, 50.23242981203141, 56.83699515558059, 56.08284888728973, 54.8271373779543, 45.65076804930165, 40.369861433582926, 54.169697146261896, 51.18265928760652, 54.502867191068596, 52.659282607416955, 56.37085676193238, 56.23478974065473, 57.84465205284857, 48.5787546250128, 43.18879042902301, 40.65009909291422, 42.830897685020204, 43.00428213611726, 48.65707651261361, 40.430979805607954, 50.63025620675857, 58.14104987728981, 56.09241947051018, 54.143632996466856, 57.345781480112386, 56.24384257101244, 58.22078381815265, 55.86024653527045, 59.11222088721491, 56.7740999498675, 55.2892396526952, 55.43669723695325, 55.619059993374734, 52.96368598937989, 54.46998203954389, 51.06328195141208, 51.53162471709713, 52.110923490216656, 52.143922390476355, 51.42279855666622, 55.17507514645977, 56.537683010101325, 60.46510519519929, 56.96483696660688, 57.20308173087336, 53.83173396510463, 55.98473864216959, 58.13092231750489, 60.12345498608005, 49.62815338565458, 27.926912807649185, 15.376991341190955, 18.314220982213175, 13.426856552400897, 19.36974452387902, 24.368673909095026, 14.780945028028182, 15.081276989752247, 5.496822797483014, 2.4992374402861444, 0.2850489366439081, 0.36004312216274204, 5.074171721935272, 27.213821987951956, 57.14445406390775, 52.983768524662146, 33.078869542767926, 51.802178044472974, 58.657575038171586, 69.41235711497646, 42.68393431940387, 11.950326388882054, 0.7325508012886971, 0.17663212763445993, 0.13754071397406442, 0.11410043830232275, 0.15619564440942582, 0.16666959851018845, 0.1482701583975746, 0.15428093021675465, 0.16182586971309879, 0.1204155691929402, 0.14794087848596035, 0.13294559603016223, 0.14202762965954122, 0.24148265020020548, 0.2794281188999453, 0.2873949123726737, 0.125292431292755, 0.25017368787479016, 0.1537473499774933, 0.10396872632085316, 0.15332174217028005], [0.06937152150297357, 0.057548559345905824, 0.06345322415713342, 0.039471339644683946, 0.052228986525968205, 0.0531478860085049, 0.027240362889584036, 0.06570743021344946, 0.03661197009346178, 0.10698264644991969, 0.041563767083590074, 0.03387090366994662, 0.0342767387478342, 0.018716261519359487, 0.02459784410142851, 0.05885678471156186, 0.02824653702367458, 0.017353312578052282, 0.06186944845643255, 0.01382593063622593, 0.03662260339385079, 0.4211494206420837, 10.593875665818492, 44.82143778954783, 48.334477255421305, 31.71953489703517, 30.019899337522446, 39.06726583357781, 42.76888501259589, 29.766004316268432, 11.230962718686751, 0.5257258155653554, 0.08520208494437319, 0.13910088267537857, 0.0663928644010617, 0.6986841992024453, 8.819819996433875, 13.203250073617506, 11.534479644990737, 12.585093359793387, 13.079592450972527, 10.646587417971704, 26.85532323775753, 36.46609506299419, 45.98778201687721, 53.49630071270851, 48.751656624578665, 53.76038997404037, 50.92184520536854, 49.12421511065576, 41.440409614193825, 38.422012406010786, 37.759151458740234, 36.10881813110844, 35.91676712036133, 35.103381295357984, 37.88127837642547, 40.20374513441517, 40.82977894813784, 42.75230123150734, 45.297935162821126, 44.66513918292138, 48.2842513053648, 50.6774030962298, 52.8420493679662, 52.93594306515109, 53.21960887601299, 47.200002285741995, 36.599534096256384, 35.71693804956252, 43.42035539688603, 49.160453888677786, 54.00631473910425, 49.370865514201505, 48.33779950295725, 49.71549280228154, 53.07083729774722, 51.572844905238, 45.76748601851925, 39.952274137927645, 38.21992797236289, 36.96343591136318, 38.968947702838534, 43.72070697046096, 51.2889672863868, 49.25202946509085, 55.083197547543435, 42.89137671070714, 33.14500462624335, 54.67531027332429, 48.46277406138759, 53.91503334045411, 50.66723239037299, 53.571849484597486, 51.02682352066041, 48.93212095383675, 40.691091783585094, 39.818329118913226, 38.305973006832986, 39.605591527877316, 38.25903400298088, 37.44527555281116, 36.49932930546422, 37.848808996139034, 46.58268790091238, 51.59632029071931, 52.891545757170654, 53.46975411138227, 49.11837077909901, 50.39760081998764, 47.847875856584125, 45.292447766950055, 41.605427649713334, 44.27869158406412, 51.68581701094105, 51.87246691796088, 52.68806495974141, 52.01579816879765, 55.49298717129616, 52.819413369701756, 55.55076760630454, 51.9318869037013, 51.36557117585213, 49.82533485658708, 52.735694300743845, 52.80927404280632, 54.430813251003144, 48.3863623680607, 47.29324879184846, 49.70121537485431, 53.15562717376217, 51.903061405304946, 50.60126596881498, 28.604319864703765, 16.771391976264216, 4.851343343334814, 10.082581966154038, 6.467305921739148, 5.788835412071598, 8.497113854654375, 6.38177324687281, 2.248033900414744, 1.3100634250910053, 0.15971234038231835, 0.02805034765192578, 2.9544946887800774, 18.096962859553678, 45.286403394514515, 39.21384480691726, 20.12307886154421, 37.64582241735151, 49.656735697100245, 54.67794610608009, 27.559108234220936, 4.890397402548022, 0.207470920417578, 0.061696925455884594, 0.06759954481235436, 0.03277598016504799, 0.044591204834080515, 0.04730334760801447, 0.03925247215515664, 0.020318524836893045, 0.08541249099277681, 0.04023969518922029, 0.08882984834452791, 0.011469511213832566, 0.03592521823461979, 0.0686976399212595, 0.004514040943655756, 0.05544935202886982, 0.02081560290178224, 0.08618853039919369, 0.05239909634955468, 0.011125492728165081, 0.023125229673760555, 0.008086598132767023, 0.054818413505751284, 0.07329063580161141, 0.015313538362181958, 0.05114365444188157, 0.038232479710131884, 0.05733237699455312, 0.07178525004776255, 0.015205444313675888, 0.06983902665876573, 0.049021452995798284, 0.05676917979613908, 0.05281808132666254, 0.033175043025684935, 0.028952588552549004, 0.026655370489724224, 0.049079775269473755, 0.04832583366923275, 0.06075426958681596, 0.05943540709033128, 0.017403914600670818, 0.4178827604459178, 13.614971464680089, 51.30640222180275, 55.998008020462535, 39.446739458268695, 35.07808593011672, 47.389786166529504, 53.51919950977449, 38.34978980402793, 11.622258367076999, 0.9138976638355564, 0.010986643122328867, 0.29693705840937556, 1.5476581790754873, 4.102359894783267, 10.667425990104677, 14.687091535137547, 8.89202690893604, 9.751502544649187, 12.86046531892592, 14.358070377380619, 27.53235374727557, 35.15245406858383, 48.194079937473425, 53.60113782267417, 51.85113706896382, 54.22955643746161, 53.16827681756789, 51.42925477796986, 44.651324595174486, 39.756092871389086, 41.479272457861136, 38.144430191286155, 37.77115391146752, 37.497843157860544, 41.02054342146843, 41.71245736460532, 44.25924447274978, 44.79997065759475, 46.812723144408196, 48.71024816266952, 51.03908877218924, 52.05973263709776, 55.581154208029474, 55.591775986456106, 55.70778008430235, 50.32246781933693, 40.82385224680747, 36.60266414765389, 45.19647129120366, 52.79035252909507, 54.51498731490105, 50.72580906652635, 49.519460585809526, 52.740044209264944, 52.52789889612506, 53.823461686411214, 48.32287488445159, 42.24229112748177, 38.86138454560311, 39.01549054730324, 40.6253920831988, 45.25761319744972, 53.168041475357555, 52.24967341269217, 56.834775094063055, 44.36299900854788, 37.46909610686764, 55.78138336058586, 51.257027426073634, 56.74546664760959, 51.695046347956506, 54.59370143951909, 53.07434389668127, 49.86371524872319, 44.917751589129054, 38.901400566101074, 40.5762565520502, 41.54566249539776, 40.11603309262184, 40.25115482268795, 38.326992988586426, 40.54353221770256, 49.39130106279927, 53.0790860422196, 55.569775412159586, 56.28311334117767, 52.646021073864354, 54.16970106863207, 50.336043142503314, 47.13385543515606, 45.63023836381974, 46.810597219774806, 53.03321784542453, 54.79608397330008, 52.7970637044599, 52.818950530021425, 54.951747155958614, 54.55414041396111, 57.45387807969124, 53.12226741544662, 50.646788997034875, 51.36324913271012, 53.06276505993259, 56.10603401737829, 55.911900228069676, 52.01034215188796, 49.17027158121909, 51.747496281900716, 55.60963453785066, 53.587256554634344, 52.04741639475669, 31.13761990301071, 18.288105841605894, 8.813364755722786, 13.34003096626651, 16.346139388699687, 15.277074844606462, 12.545899075846519, 9.533948283041678, 4.6535838130981695, 0.6278837015551906, 0.1292993086239984, 0.07846745962817823, 3.380395202867447, 20.028579158167688, 52.33184706780219, 41.48363413349275, 22.95430840984468, 45.27048641635526, 53.29160005815568, 63.39005585639708, 32.677862105831025, 7.544185788400712, 0.27345505392839836, 0.017802253508219318, 0.04601917740318083, 0.03228863716245659, 0.044068874595987226, 0.007903955110739316, 0.02754659313077648, 0.002285950106470996, 0.04132429565933924, 0.050883445017520464, 0.03917446142182716, 0.028538669331840454, 0.033648864576412786, 0.028281294432799184, 0.03499599954774303, 0.015392346784562595, 0.08603427093476058, 0.05389937229694859, 0.06812359491783766, 0.0875519447389149, 0.0725924768935769, 0.18228023343028563, 0.14447456045496848, 0.21113491977655122, 0.18042522813043288, 0.09740999479207302, 0.14593178226101786, 0.14036872754654578, 0.18875248129329375, 0.09877029881482163, 0.2020120383390496, 0.18790586220641292, 0.20831764675676825, 0.16193080843696672, 0.087335157178102, 0.14351638364455394, 0.1504630237937935, 0.1275026179369419, 0.1509138205719571, 0.1264690887182951, 0.11506676628825166, 0.13990254772286262, 0.9620914584205997, 18.3179864575786, 60.44590911557598, 61.44100658355221, 45.18411582516086, 41.784758413991625, 49.39875356612667, 53.56066288486604, 38.77771254508726, 15.058857702439832, 0.8219327921828916, 0.17812439030216587, 0.3976102353584382, 0.8002859053592529, 2.2149597396773677, 14.420759658659659, 24.609817304918845, 21.333692919823434, 21.119235369466967, 22.95846219985716, 15.51963519665503, 31.90789103507996, 43.11385354688091, 48.40641744675175, 55.14627318228445, 49.91728305816651, 57.65169889696183, 54.59915353405861, 54.87550020217896, 45.59221882973948, 42.72925730674498, 43.11496750000985, 39.50458657357001, 39.03182721907093, 39.014353059953265, 42.35713028138684, 42.85698929140645, 44.97662636541551, 47.85043324193647, 48.21671593573786, 48.755041630037375, 52.61944701594692, 55.110971850733605, 57.08888976804672, 55.6132705750004, 57.115334387748476, 52.591676635126916, 40.4343451992158, 39.775363476045676, 48.402475464728575, 55.524974100051395, 56.192890982474054, 50.8698816453257, 51.7261468210528, 55.24177112886983, 56.03974203909598, 56.487998347128595, 50.233975225879306, 44.442866309996575, 40.28840949458461, 40.51069413461993, 42.34836770642189, 47.52460979646253, 55.25574653379379, 55.11670243355536, 58.39725517457532, 46.467476121840946, 41.224816537672474, 55.48424813055224, 52.13963131750784, 59.20711871116393, 54.377057167791556, 57.45622365705429, 56.26585883478965, 52.06292152404786, 46.40770704515519, 43.21008497668851, 44.168437680890484, 42.93300874771611, 42.647232701701505, 41.722471175655244, 40.111694951211255, 41.88879143807196, 49.99873891953499, 55.37358630088068, 57.49842051536807, 59.840542270291245, 54.31451889776415, 55.695130440496634, 52.36116678484025, 49.34476998544509, 46.22981971310031, 48.875470161437995, 55.99455633471089, 56.96280125648745, 53.60040826182212, 53.43132272843392, 58.317631060077304, 56.990124487107806, 60.67817618769985, 53.93875583525627, 52.11199037490353, 50.421456675375666, 53.86443476523123, 56.33277446992936, 59.04764690706807, 53.45627292510002, 51.364351318728545, 55.077847434628396, 59.03525613969373, 55.148465787210775, 55.93260249783916, 32.6696055166183, 21.46136018537706, 8.972392351396623, 17.08777819910357, 17.227924485360425, 16.56857994294936, 17.50169611746265, 12.49062797715587, 9.394155990692878, 2.6518411742102717, 0.515410349734368, 0.2608809463920132, 4.001880047782775, 23.296707791666833, 54.498289785077496, 46.687442641104425, 33.02229327540244, 50.041665338700824, 63.16700243180799, 69.45803703800325, 41.61953249285298, 9.936910040916937, 0.40434212574074346, 0.23440312443962022, 0.14533521427262217, 0.13832080598560073, 0.13051625461347643, 0.24595799795802564, 0.15024729343431611, 0.12124989256863633, 0.16570604376254544, 0.10886403581788463, 0.21372166161815967, 0.09193616633814189, 0.1719119841413152, 0.16291222835500396, 0.1631351139756941, 0.15660010818992892, 0.13008980410954646, 0.16305341835944884, 0.17905796036845256, 0.11228471033034787, 0.2612206910646731], [0.025532067257670626, 0.05698066602851595, 0.0036204980138028345, 0.02080350445823804, 0.02874810627901987, 0.07873889990150928, 0.04966969361468669, 0.04230162466786081, 0.025541685491559968, 0.05493651362015836, 0.03216426661838928, 0.04043766763061285, 0.0590472724739342, 0.05459195791533398, 0.021744913519209912, 0.02008607077802862, 0.052252915282283104, 0.0391107190760874, 0.045826268802967765, 0.08843499896747452, 0.047582513878061894, 1.1029284495499827, 12.285606668841455, 46.08459003510014, 44.30468513119606, 33.863394568043375, 24.229916141879176, 15.361706845221983, 25.8619398455466, 32.77665876573132, 8.713053080343432, 0.3895182937623993, 0.3420629160058114, 4.1176924397868495, 2.1610580384731293, 3.7975922226905827, 12.868926851980149, 13.566473318684487, 6.5593276677593115, 5.33334086018224, 8.454407088218197, 13.917426409259921, 30.687945658160796, 32.01133962600462, 47.7693147044028, 51.57459428233486, 54.08684492111207, 52.11013117144185, 51.48695284320463, 47.847679738075506, 41.76146737990841, 36.06966895441855, 37.9441814268789, 37.043919024928925, 40.66177206654703, 37.5164940280299, 37.0434404957679, 35.947577338064875, 37.25658601330173, 35.09882742358793, 37.91781133221042, 36.487393533029866, 40.11786876186248, 43.049110904816665, 47.556404529079316, 47.790311151935214, 47.48126368368826, 39.863722708917436, 34.742076089305264, 37.99714519131569, 49.25181765710154, 52.79474950605824, 51.48632918634723, 44.917806502311464, 55.11538451717746, 52.19417187475389, 51.56651419977988, 45.287897817550174, 42.75320729901714, 37.069896882580174, 38.262262113632694, 35.70508856927195, 39.06611657911731, 40.51851141837336, 49.72012904382522, 48.468724296938994, 56.37481835580642, 44.48745973648564, 33.87647175019787, 56.56755578133368, 48.211656078215576, 49.272629753235854, 47.46349926917784, 49.657680988311775, 44.42775734009282, 41.41123502485214, 38.254413450917895, 38.03256811634187, 39.63771966195876, 40.95584784784625, 41.43993892977315, 43.102921901210664, 38.14854083522674, 34.9692754591665, 36.686610714081795, 39.22567467535696, 41.95165526482367, 42.32177011428341, 42.11537107344597, 40.26681684678601, 40.80147120260423, 38.2212576558513, 39.54899564866097, 44.11552490726594, 51.828810937943004, 54.24861131175872, 51.76524108456027, 52.03002852778281, 49.13616657257081, 50.77820408728815, 52.25621592613959, 53.93332727493779, 52.52076410478162, 49.99762888877623, 51.239733695983894, 52.98005796247914, 53.05306111612628, 45.22576355165051, 50.80976347769461, 52.978869484316924, 55.50062794839182, 57.346742460804606, 51.305625592508626, 30.131276999750447, 22.259797857653712, 6.217325425917103, 10.392946370186346, 11.140437356887325, 17.288766330288304, 12.91212587587295, 8.225552968440518, 3.873239789278277, 0.58242968253551, 0.09720720365763673, 0.09308846216768989, 1.904082730893166, 15.653316436275361, 35.750364488170995, 46.08352315041327, 30.476565207204512, 33.224275727425855, 47.898313614629934, 48.426578429437455, 33.831521388023134, 4.629201869810782, 0.23101559089076137, 0.02965692021403342, 0.04507503532353909, 0.018066119087199052, 0.08671885476477685, 0.009560222838885121, 0.03553052207515125, 0.04881005869397233, 0.02362038485795981, 0.14017369688278244, 0.058557600564052986, 0.06199603299460104, 0.028123528200892672, 0.02784111563326611, 0.09644833228160297, 0.05006853814026521, 0.04689560497119542, 0.048472501202336246, 0.030699439474471638, 0.021360998132055806, 0.03657051324543934, 0.03358111559082905, 0.03621167766170637, 0.016024698739901425, 0.027422513700120395, 0.04132466721198252, 0.072821797652831, 0.0294483068113726, 0.031771102634769295, 0.04265517807535587, 0.13055336391252856, 0.00957544787877029, 0.012543322293147927, 0.07654849364752732, 0.06564611253599006, 0.03011757654378251, 0.04545831677293585, 0.03038287279196084, 0.07906043466420905, 0.044439944603870955, 0.0059549479497476455, 0.035466369872372, 1.2587300183311587, 15.358665047153352, 52.89059262121878, 49.17209156097905, 38.78773027850736, 31.484859489625503, 23.672272774481005, 33.29133256789177, 33.07522173850767, 10.876247094523523, 0.3647798437985682, 0.34613283471234385, 2.8966389932940086, 2.0284755527973175, 4.764421659131204, 4.643294455543642, 7.789808530961314, 10.69242129402776, 9.618319446040738, 17.102483164879583, 14.480385568834121, 25.66142239878255, 35.36080252739691, 49.7284483909607, 53.227728182269686, 53.4693540296247, 55.59790272866526, 55.405545773044715, 50.24320848526494, 44.21012463108186, 38.184654097403254, 39.41525459289551, 38.42829996539701, 41.784829016654726, 38.98025981841549, 37.51807474320935, 37.46829594335249, 39.143987394148304, 37.05159118098598, 41.04999649909235, 38.31801076089182, 42.7472335292447, 46.643335588516734, 50.4612648102545, 49.798596059122396, 49.25987028306531, 42.39181187845046, 35.96011715550577, 40.642921155498875, 50.38899906219975, 53.728720757269095, 53.121439795340265, 47.278692876139, 54.37819073277136, 54.44618109733828, 53.69522763836769, 48.44546464181716, 44.271674463825846, 39.729405064736646, 40.54392445471979, 37.03683130202755, 40.66534926814418, 43.04467862652194, 51.0644978861655, 51.00827855448569, 57.055592767653934, 45.183068552324855, 37.20470874540268, 57.24330955936063, 52.504019506516, 50.20979773613715, 49.50734046197707, 51.528906514567716, 47.29248000729469, 45.14661796631352, 38.81071144534696, 40.402205298023844, 41.72985307631954, 41.13225252397599, 44.3029789001711, 44.19447437409432, 41.01929218538346, 36.832063967181796, 38.810687911125925, 43.48359577117428, 45.37111482312603, 45.1846492675043, 45.346211694901996, 42.837102874632805, 43.163016534620716, 40.69277448038901, 40.81126536092451, 46.73594667065529, 52.967765254359094, 56.6382957273914, 52.45671572223787, 52.25840068632557, 51.846940132879446, 52.7632293393535, 53.87267174259309, 55.616165284187566, 51.821217229289395, 50.58133640596944, 51.263126711691584, 55.67003119376398, 54.732549421248905, 49.02603818524269, 53.043690573784616, 56.70909843137188, 56.89693289418375, 60.34501398763349, 53.055151739428126, 33.02922018112675, 23.014854115824548, 14.940068721771242, 13.705295805008182, 15.7934784120129, 11.696221520823817, 10.968409065277347, 6.800798581492517, 2.776807397603989, 1.3583486599306906, 0.21472414895411462, 0.12588059529662132, 2.3766802876226367, 19.049406513091057, 41.30589192913425, 50.73390483856202, 32.19976636671251, 39.96116615110829, 55.5906149648851, 56.09507099274666, 37.92817031183551, 6.357593795945568, 0.2335690538729391, 0.06246460684304757, 0.03473091014330426, 0.05933545942929003, 0.09653657794960084, 0.0812464512343849, 0.009011684732902195, 0.022241727283765233, 0.028062972780917923, 0.05959903197963873, 0.026643086269858385, 0.035925336978248054, 0.01735750499421791, 0.026723466130093704, 0.04333002875829416, 0.012464733163435614, 0.04252526105471677, 0.07690053403137193, 0.03398852880984064, 0.10524205638155823, 0.03493995255520267, 0.17342186683127958, 0.10402519466175188, 0.06913232587037549, 0.09328343920529851, 0.06308698433361228, 0.24215463188386735, 0.1587687498859821, 0.0789325133026127, 0.1002151023356184, 0.2977818082417211, 0.09382788257132615, 0.15855657417447339, 0.14710512252584582, 0.12813487030085058, 0.16128812195552936, 0.11660536961449731, 0.10276940035363359, 0.14843042399133408, 0.21296832139693925, 0.205960639361893, 0.19398035721913462, 1.9111399328516376, 21.170953781374042, 60.966623367801795, 55.66959188830469, 46.19160013814127, 35.325677702503825, 26.075981624664802, 37.68827815209666, 42.44138279268819, 12.50636354569466, 0.8490823966360862, 0.3225497372688786, 6.472475115329989, 4.976593448269752, 9.926460846777886, 21.805563857478482, 25.872030142814886, 15.935291705592988, 13.891203403472902, 17.224447304202666, 18.845674683970792, 32.901474468169674, 33.118665910536244, 50.82877128354965, 54.33791975821219, 56.401372801872995, 57.90371902527348, 57.855434648452274, 52.10583617610317, 47.473826869841545, 41.131016977371715, 41.335435221272135, 41.47429497011247, 43.7282810672637, 42.45034148616176, 40.156994404331336, 38.25690023360714, 41.16215667416973, 38.006727541646654, 42.48340314434421, 41.07644111879411, 44.78008816319127, 47.70692156207177, 51.83178017216345, 50.28053768219487, 52.72074222564698, 44.01529265988258, 36.93397891136908, 42.152821863851244, 53.47884224307153, 56.535368811699655, 54.70790516945624, 47.04032259602701, 58.28241209830008, 57.121433673366425, 56.193816661834724, 50.060206382505356, 46.923934105903875, 41.45589120926396, 42.70096132832189, 39.205274428090746, 42.66436169224401, 45.3730877753227, 53.804187159384455, 53.54135305650773, 57.10814468322262, 47.38488320381411, 41.37974623710879, 60.82056999206544, 53.28172745243196, 52.78013083242601, 52.87196528527045, 53.11579158229213, 49.65764176461005, 47.39820749528947, 41.62558078765869, 42.47133008895382, 45.0682411655303, 43.95971267454086, 46.44744457737092, 47.196617280283284, 43.88269693620744, 39.443393676511704, 40.81120652537192, 44.733513939765196, 48.14443449820242, 45.38790648983371, 47.24081454738494, 43.84008822902557, 43.684562329323064, 41.21582646523753, 45.148410489482266, 48.7282165404289, 56.28983236128285, 58.19210344745267, 53.089135154601074, 53.44623950219924, 55.29877885695427, 55.06776302091537, 57.372057437896736, 57.64108104090537, 55.25273023113128, 50.43394942437449, 51.01373064902521, 55.62378644943238, 56.41740745113742, 49.27948605629706, 56.17731917288996, 60.218250828404585, 59.4384640262973, 61.780707374695815, 57.95401165562292, 35.388808250427246, 26.063696761285108, 10.172005141935042, 18.15038161893045, 19.80771637731983, 23.374506042849635, 21.070431278597926, 16.424830959689235, 8.600775234160885, 1.4649174963274312, 0.35850684008290695, 0.2677055640566734, 2.7691842711740926, 22.272437695534002, 46.1847516798204, 55.485397385012725, 41.82869288229173, 46.87523788021457, 62.20673953333209, 62.13511313161543, 47.08400211026592, 8.536735676950025, 0.36391480795798764, 0.16136276956287124, 0.14225941722191152, 0.14185349787435225, 0.30969358680229037, 0.2857250858458781, 0.10486178565770389, 0.1058560528702313, 0.10172760504628382, 0.23132266957432995, 0.14838854962539288, 0.2554363135488764, 0.2677543791792085, 0.15947670705856817, 0.21188026203984217, 0.11466610230385296, 0.11785633756869263, 0.1248618592357924, 0.09970204559184852, 0.2788571076047036, 0.10039705587851425], [0.02410219096007847, 0.03418842030148353, 0.013559799352210137, 0.03308721104516618, 0.015577176030004218, 0.02497416181159356, 0.06686368671756598, 0.002526372676760319, 0.008780601013812327, 0.055607602811388435, 0.015258681678753949, 0.07522893018059193, 0.04587796441609821, 0.027428006550537485, 0.09116858454240907, 0.013521517938633841, 0.041182462141037955, 0.010319196679178747, 0.056568621808002074, 0.05761566481763317, 0.03551371410609253, 0.9280256734740351, 13.114183833522182, 40.22540838487687, 45.8972184119686, 32.98342258699479, 19.5542057483427, 19.67063150098247, 41.79965557590608, 35.68461771934263, 7.998490391239044, 0.6073586126008342, 0.3911935748352159, 13.82605185431819, 21.886001863787254, 17.198143889827115, 7.496555957102007, 5.223323770107762, 5.052078481643431, 8.033163653266046, 16.59828797463448, 17.633413230219197, 28.461871147155765, 37.37262149010935, 50.35348984502977, 48.93655323213147, 55.26577995669458, 50.47111780412736, 50.874094270890765, 44.58382060450893, 38.187576263181626, 36.2177933416059, 40.25057038953228, 47.81556729347476, 50.47070203288909, 50.56987131795576, 44.47484539401147, 38.704254396500126, 35.55794869699786, 36.00837799810594, 36.22192359739734, 35.86958492955854, 36.95783084438693, 37.93187695164835, 39.55514200272099, 41.71688964290004, 37.70348125888456, 34.946400196321555, 36.41860300494779, 45.408024326447524, 53.698518506942264, 53.78497539028045, 51.35810298304404, 53.47222128222066, 51.72925726059945, 46.193745674625525, 45.689689728521536, 41.17478278375442, 38.084312023655066, 36.13834181139546, 37.890554781883, 37.88874656923356, 43.635195378334295, 44.94747138792469, 50.459680172704886, 49.221285927680235, 55.43981944361041, 44.44857728096747, 32.17368260506661, 55.147787217170965, 49.096734985228515, 48.96806163172568, 43.29131726295718, 43.60234552814115, 38.02798678798061, 36.93537135278025, 36.406133790169996, 37.4571289554719, 39.247228099453835, 41.43765611033286, 47.73126771373134, 48.394148272852746, 46.18888585798202, 43.27924420756679, 37.802328909597094, 35.59173599366219, 34.138556680371686, 34.537316599199855, 35.05342991121354, 35.71988374956193, 36.88130147995488, 37.41102933883667, 41.96565420396867, 48.81938026797388, 54.160730608047984, 53.57178280430456, 52.55277849012806, 49.2746066278027, 45.800492763519294, 46.33371153185445, 46.991822488846324, 50.392631176979314, 53.5799374118928, 51.25288932554184, 50.91327090417185, 56.847361979946015, 51.26969275936004, 47.90641723140594, 50.33558422519315, 56.05776533003777, 55.89056253433228, 53.68148757565407, 48.76657339834398, 35.16586072983281, 20.457939447895175, 23.640287806910855, 17.791906402957057, 23.54168922670426, 14.437064951465977, 9.122863296539553, 5.581484215874826, 2.1470039409975854, 0.8224539771195382, 0.043974239754700856, 0.06415603321886833, 1.4801665683907848, 14.566470807598485, 43.45910056944817, 40.64366248346145, 30.13811565214588, 37.61289019738474, 42.56359208014704, 53.97792070142685, 30.278463940466608, 5.314125659004335, 0.09735135842234859, 0.047212566188987226, 0.020096849635123246, 0.021121718229786045, 0.02172310874166508, 0.052661404854828314, 0.02495659541548981, 0.025160583562307784, 0.09687852895548267, 0.06079157806872841, 0.054390296760586, 0.010615860397416738, 0.02376491117531494, 0.019306120492758292, 0.03342165821982968, 0.02831078690266417, 0.03009996035196368, 0.03984386138918419, 0.04173518691752707, 0.05711741655343964, 0.08565648999666015, 0.005565577058962757, 0.018201825817325906, 0.0637245801607928, 0.06843834214152829, 0.06153936798293745, 0.041387566861005566, 0.0490425395659141, 0.09928407568124034, 0.037031797767286344, 0.028501182734485597, 0.011752565380095715, 0.05336123000409815, 0.004883815784142503, 0.024244696720533317, 0.033594897512586853, 0.014893964454982311, 0.04898150151054706, 0.04507179860205901, 0.05619871625376325, 0.037226384100053585, 0.05889021295813784, 1.1627423883445802, 17.512325740629628, 46.725218988234, 51.806237697601325, 39.288840524611935, 24.57264304161072, 21.524396596416352, 41.345527479725504, 38.526841671236106, 10.499851549825362, 0.5523720083217467, 0.240982762507854, 15.034650794921385, 14.684913639099369, 9.517959721626776, 5.405212900330944, 9.52487878261074, 10.967500055989913, 10.686004296425851, 13.238800475674292, 17.425023586519305, 30.665374379004206, 36.96759362374583, 50.44382595246839, 51.02395626806444, 56.825679117633456, 53.307513113944765, 54.58275018199798, 48.27906200962682, 39.961813342186716, 37.3642982206037, 41.9363776330025, 49.9689132167447, 52.16894711217573, 51.850132942199714, 45.5493434013859, 39.4990756434779, 36.90807165638093, 37.9662839827999, 38.04720640182495, 37.56944994772635, 38.84533812922817, 40.58576045497772, 43.01934403757895, 44.65654919224401, 40.86811227183188, 36.650826930999756, 38.159852950803696, 46.89360633973153, 56.675405271591686, 54.025879521523755, 50.57393881582445, 54.94257273212556, 55.15741271357383, 48.98790882479761, 48.156589923366425, 42.76706503283593, 40.10628600274363, 38.48274638575893, 37.876524463776626, 39.56007242202759, 44.07836044988325, 46.84836964453421, 51.853682687205655, 51.86657551796206, 57.037118404142326, 45.063710827981275, 36.58217368587371, 56.60945453951436, 50.81069307942545, 50.341193214539565, 46.93590125729961, 45.42759303123721, 40.170812914448405, 40.58069667508526, 36.50851941877796, 39.465406017918745, 40.849582995137865, 44.02406700195805, 47.94891611222298, 50.63991700449298, 48.49531012196695, 43.47294653615644, 39.47913039115168, 37.87061737429711, 36.84639630779144, 36.55561531743696, 36.78575646492743, 38.16800755839194, 38.29548066662204, 39.50988961804298, 44.30694833878548, 51.67616013557681, 56.80728712389546, 54.748238901938166, 51.92879607600551, 51.42226903669296, 48.25801849365235, 49.4154393288397, 49.300780603962565, 51.78635128082768, 56.20871774611935, 51.06725139002646, 50.846319967700595, 57.709797043954175, 54.176812325754476, 49.74964095700172, 51.68582093331122, 57.73126809827743, 58.75519106465002, 55.168305135542354, 50.574103555371686, 35.64863781775198, 23.62170361703442, 17.114346373465754, 15.222374450775886, 14.515804571490134, 16.281267308419753, 12.226101371549792, 13.262971101268647, 3.4062634793020066, 2.2023218629821657, 0.21539593145491617, 0.12629398400144232, 1.821341557848838, 15.470926223262666, 44.881669705913914, 43.986286732458304, 32.81555298836001, 41.35056380302676, 49.89874985910232, 60.33382738790205, 37.879023013576386, 6.8255212806886245, 0.021209404653599186, 0.0501287066858382, 0.08991059156194811, 0.03385459365803869, 0.027173902846932895, 0.005362824228922687, 0.042086315656741785, 0.04920032686523853, 0.05757550648864239, 0.050051630579776345, 0.08633760344837943, 0.07801761279904074, 0.056746810028750094, 0.009158461433534902, 0.03308967018740312, 0.04625299509855048, 0.03800016354709383, 0.09833977272313449, 0.010705935100333826, 0.037631587155403635, 0.01456454185949218, 0.08369666854700736, 0.13452592816564346, 0.11463469269895747, 0.18045844570282968, 0.10920308335053344, 0.13919091332824002, 0.12408589643816795, 0.14405301291375391, 0.18352880352927795, 0.13805333404771744, 0.16779956287674366, 0.16533501205905793, 0.09534354156423962, 0.13255181151532358, 0.13346518750392622, 0.08317366798198031, 0.09760701728443946, 0.12712659900106732, 0.19926875409099365, 0.113323992869306, 0.2105650729349544, 1.598826478565893, 21.436568844702936, 54.75928821871358, 59.15401374140094, 45.69140772665701, 30.1932700603239, 31.10906504815625, 53.52644804985293, 43.255553091726, 11.742064222212761, 1.0439753484341407, 0.4152088071550093, 16.689357565295314, 27.451631369129306, 26.231531058588338, 18.340949973752423, 15.338688415865745, 13.245072345579825, 18.885478896479455, 23.107759375726026, 22.444802330386256, 31.73007038331801, 40.27219833866243, 51.47070246358072, 51.44577580113565, 56.96379753851122, 55.189682052981475, 56.34705581972676, 49.511584466503514, 42.05976363151304, 41.15178200506395, 44.588429389461396, 53.43144432190926, 55.38990728316769, 55.302658081054695, 49.774795116916785, 42.66761725948703, 39.58955687861289, 38.91578781989313, 39.573996836139315, 40.085681792228456, 40.50677568681779, 42.23926305770874, 43.71485871653403, 46.98545255968648, 42.55977953633955, 38.21098889074018, 40.385660740637014, 49.631687441179835, 58.75213161591561, 55.42321997304117, 50.74569940567017, 57.19062820557625, 57.07309438336281, 51.24169880344022, 51.10646332463911, 45.3733427293839, 41.96943536881478, 40.348825762348795, 40.36628423198577, 41.39405112112723, 47.2359468860011, 49.954773072273504, 54.17942070191907, 55.732655755935184, 58.35261467964419, 47.73275821439682, 39.97142707147906, 57.518357922953946, 52.83604421923238, 52.82978411643736, 49.28437725190194, 48.00657495375603, 42.231300646258944, 42.896205148389264, 39.72795771014306, 42.35002686900478, 42.79875778382824, 45.1254528568637, 51.93974341115644, 53.978634572798214, 50.007968256550456, 47.018243574327045, 42.392376699755275, 40.32008263372606, 37.65220411362187, 38.53867153967581, 38.16406949873894, 39.77362586605934, 41.1589873990705, 42.06971860701039, 45.654411931191724, 54.76633279554306, 58.529427282271854, 56.31770080135715, 53.932813444445216, 53.2236881409922, 50.20372982948057, 53.08849188589281, 50.39415305660617, 55.29836700808618, 58.59438957706575, 52.35345148271131, 52.14147483148883, 59.669373958341545, 56.443930518242624, 52.98627491920225, 54.97825061121295, 62.15135958886916, 60.118128407386045, 56.865687293391076, 52.648299970934474, 40.06612485454929, 25.50401376139733, 30.424988000623642, 25.92681977056688, 32.975915170484974, 30.99725788639438, 18.355498044721543, 18.99365394346176, 9.794123999534115, 3.163126048541838, 0.3146758549396069, 0.32337790895854274, 1.9867070908507996, 18.511131809603786, 53.066299115457845, 52.49833206976614, 44.279327008032034, 49.05101191612982, 56.277249397770056, 69.96211651832827, 44.409400647686375, 10.58622214101976, 0.17586864440912203, 0.1037770358004397, 0.20778431166564265, 0.12340050821583118, 0.11407695770744355, 0.1291252381258434, 0.17484346554884989, 0.1584118601655768, 0.16939241288890763, 0.1491885599229605, 0.18088161735044372, 0.1740229853819455, 0.15379541433386265, 0.08214603764035049, 0.1627285204707615, 0.1069749549271599, 0.12357168290163241, 0.23889316576382807, 0.15788989381924753, 0.23169264407648196, 0.1546221304564707], [0.050917643182460344, 0.04435582431934534, 0.005040726870403535, 0.031175888706779772, 0.022381306588349324, 0.026666501747264017, 0.02769162698138145, 0.04054991483327843, 0.038351656178072575, 0.010728563422397261, 0.009597069752823201, 0.05002726898378423, 0.05867028060639578, 0.06471841836408262, 0.0065841680418910285, 0.01776096711476003, 0.050308599452217745, 0.0524203974242893, 0.03483503681397246, 0.039127584501740434, 0.15729813686301633, 0.2726422039972198, 8.28310247390501, 39.50457088408932, 46.71530715880856, 36.63885193486368, 24.200074749608195, 25.438923989572835, 44.03363366280833, 31.78593081812705, 7.499574220949604, 0.3856716130770022, 0.08545979692210114, 3.702654439595438, 31.492315915323076, 32.68665605975736, 2.707481711141525, 4.91646743589832, 10.530717661303859, 6.312910645238816, 21.602071292938728, 19.04812389804471, 26.11126530554987, 41.784083766321984, 52.03945398330689, 55.0683121527395, 55.00555030761227, 50.27666630283479, 48.85969046623477, 40.570129809841035, 38.5555612656378, 36.537333150063795, 45.24463407454952, 51.98685499929613, 52.46697664260865, 52.17358335371941, 49.204706068961855, 46.514046422896854, 44.158286586884536, 41.43442799968105, 39.653177722807854, 38.38847221866731, 37.80898517177951, 36.47611671878446, 36.991006251304384, 35.750023241966005, 34.487204397878344, 34.917237374090384, 37.94207511409637, 46.97330890163299, 53.71909133849606, 51.3537883758545, 53.13146929587088, 49.01364741786834, 48.8890847083061, 45.46053701831449, 40.9554438437185, 38.14493617703838, 37.78167370826968, 36.52331459906794, 39.460110818186116, 45.62799476808118, 48.653158064811464, 47.28276821874803, 51.1838948342108, 50.56046939665272, 54.02285929649107, 45.7953348467427, 35.063749667136904, 54.592493349506015, 49.66056393038843, 48.13568369034798, 43.30577904178251, 39.29910536735289, 36.73302019796064, 37.98227156362226, 37.02136147406794, 36.991378876470755, 39.604128483803045, 45.5836445285428, 49.97879758957894, 53.78121775965537, 53.24265672314552, 51.224291324615486, 47.98462929264192, 43.68237756913708, 39.124265716921904, 39.625144543186316, 37.57133660777923, 36.71353778531475, 36.448711118390484, 40.41359586100425, 44.86159893774217, 51.87992726602862, 51.20822921875985, 52.968851750896825, 51.84981915258592, 48.1343500844894, 45.302218391049294, 41.277352763760476, 45.731537495889974, 49.62212078032955, 52.72534708822928, 52.86901958527104, 52.499916707315755, 55.08499399308236, 52.276957419610795, 49.36768447199176, 46.96338138272686, 54.76313606385262, 56.23468775903025, 58.07759377264208, 51.94349711941135, 37.43406149648851, 29.945868522890155, 24.409701901097453, 13.380823616058597, 11.136102157254374, 6.828832251410331, 8.67719183045049, 4.906753686166579, 0.4167036285563823, 1.8830026878464607, 0.24435393241865022, 0.1311022046232416, 1.1822255364348813, 13.101712657559304, 39.23870086669922, 40.9712000047007, 31.26154914979012, 32.91034490831437, 43.40916487478441, 50.08483102244716, 34.37271825728878, 4.757684988360252, 0.08343274359621349, 0.026696208721747803, 0.018559634843240344, 0.06410209296811974, 0.03437888891165776, 0.021087173410060427, 0.061714135621103554, 0.028350376411371177, 0.03570727388104124, 0.028501370426027045, 0.021807520139601924, 0.05362252727331174, 0.07181466782405492, 0.011250754807054276, 0.019721937696299246, 0.024019817356020216, 0.022834365241109364, 0.04673527809040201, 0.007409883462147968, 0.017677951912065188, 0.010823939453750368, 0.07265684360097494, 0.020499693139666514, 0.07421600106622904, 0.06644451404891669, 0.04068547409147986, 0.046394958851798895, 0.04095040261745453, 0.036639767593794295, 0.037894918388056184, 0.02542866070965125, 0.06565679180165453, 0.09689532926366215, 0.00857251525420936, 0.03519233639141725, 0.03141143009997904, 0.10352261033990692, 0.048746657257358876, 0.03205665233244579, 0.03007543404706784, 0.03434551046079686, 0.06168643771220119, 0.5082630864795178, 11.00807991720015, 44.52586366284279, 51.940543574671594, 41.57317399978638, 30.42915551893173, 32.88216856218154, 46.943612637058386, 35.509377987154075, 8.966102830825314, 0.4457634272834947, 0.04810835279884839, 4.807122051715851, 40.945641840657885, 38.76990702844436, 7.84286545168969, 5.758137472214238, 12.544941036931931, 14.285334925497732, 16.170346602316826, 22.336625322218865, 29.596683440669892, 42.80570822377359, 52.0083103641387, 55.72906286485734, 55.75348746392035, 51.97589589703468, 53.08238083316434, 42.67262612619708, 39.91604320464596, 38.26044997861309, 47.93361886855095, 53.67729456193986, 54.865262816029215, 53.422681746944306, 51.994633059347834, 48.446394243548, 43.14453432636876, 41.83740446644445, 40.15650018568962, 40.08712914682204, 40.30101991468861, 38.52861458255399, 39.320215563620295, 37.655349854500066, 36.61371738679948, 35.5449931083187, 39.19893980026245, 49.695979010674264, 56.03243074109478, 50.82822215172553, 52.887391967158166, 52.30700277513074, 49.507160032949145, 47.32783625202794, 43.183569754323656, 39.37446978784377, 39.157786292414514, 38.277194576878706, 40.79532092617404, 47.07554940254458, 50.07511138916016, 49.60448580403482, 53.800170652328006, 52.55385321955527, 53.19045782089234, 46.896155880343535, 36.6143096646955, 55.50647620231875, 51.50539975012503, 50.16947184839557, 44.270972359565, 42.28329166289299, 39.195754835682536, 39.56102948034964, 38.16365372750067, 39.90037333580756, 40.5829010471221, 47.09380411332654, 52.596187360825084, 54.25980967860068, 54.56530740184169, 54.61179533312398, 48.422514853938935, 42.99759841734364, 40.50859958894792, 39.97874621422061, 39.287110759365945, 38.552929355252175, 37.80310161652104, 41.69295534010857, 46.64580275935512, 53.88019484858359, 53.689214644893525, 55.44627174254387, 55.09734553675498, 50.71577564362557, 47.380760792763006, 43.175368078293346, 47.55108579512566, 51.98904368185228, 55.53055171043643, 52.51701039652671, 52.142710378093106, 57.62148880189466, 55.10836739693919, 51.917844818484404, 51.80672799387286, 56.852425759838475, 59.24155712127686, 58.299392038776034, 53.90451746602213, 39.961829031667406, 25.079656454824633, 18.702963167621245, 17.648692823225453, 14.818905726555856, 11.190015135272857, 15.609138781024566, 8.829736728822033, 3.952097815852012, 1.4102737317162177, 0.3659287918238871, 0.08844920223759067, 1.4641642786802784, 14.301408798463884, 44.087530951346125, 45.87253101410405, 37.69404403624996, 39.40495837119318, 50.32385633837793, 56.09933460912397, 39.69491566381147, 6.806025139747128, 0.09507148842056913, 0.012981388605229799, 0.061903937734783664, 0.03191655591851281, 0.014162196312099697, 0.09404719056140992, 0.03831262399833049, 0.05660778039225167, 0.005465935354286264, 0.0648147539205609, 0.034978268442735556, 0.012150100852933624, 0.04920378192177704, 0.027102206593319297, 0.05316948968796961, 0.03496223039204075, 0.008948978521080028, 0.07719243651316052, 0.061642307217323014, 0.05356291414148385, 0.004938309533416384, 0.25725373457516393, 0.13303786365976258, 0.15950814730698065, 0.12383727026322197, 0.1347390538261783, 0.23002061121646436, 0.13879800215363503, 0.1514193313496728, 0.1202767234175436, 0.07241246155312947, 0.15495173212501312, 0.1324257287647455, 0.16087789719383563, 0.1865593401054221, 0.11197186300470946, 0.18463947780189977, 0.2744652787523885, 0.24757211457096764, 0.18877498895650913, 0.22547847591340545, 0.19352795165633002, 1.0968173968215142, 15.810108280950978, 54.5685080559023, 59.27479920848724, 49.92272338559551, 34.80017423629761, 36.4800077099954, 54.99533645568356, 41.92769350544099, 10.57674765586853, 0.7942133408881004, 0.23961451415333057, 5.949855571792972, 39.25238601623043, 37.82663583755493, 5.864974010375239, 10.589934664387858, 15.430440498936562, 17.477775542966782, 30.674566453503026, 22.856851239358228, 26.51912904554798, 43.91017313926451, 54.1214245365512, 57.395183732432706, 60.40781113409228, 54.46428675805369, 53.550833425214215, 45.5450915521191, 42.61200981755411, 41.209158435944595, 51.36722641606485, 56.68015526187036, 55.77896718055972, 55.942581007557536, 55.27778240942187, 51.03468395048573, 47.61665213492609, 46.42198839495259, 42.71496811220723, 42.17435959846743, 43.3875879164665, 39.84241247177124, 41.17971320306101, 40.18428233362014, 38.607693487598056, 37.54584904639952, 42.95358942401025, 51.07218180933307, 58.07126698955413, 51.41471062937091, 54.93038200563001, 54.55059066895516, 53.359947358408284, 49.28678166481757, 43.82153934048068, 41.49097288808515, 41.26920992328275, 39.62840403279951, 43.915185928344734, 49.94707345962525, 51.96233626334898, 52.981775960614605, 56.076239693549375, 54.256165796710604, 53.73969554901124, 46.595376768419825, 43.23268175125123, 56.17374589366298, 55.271639977732015, 51.573013567155414, 48.11024319741034, 43.95475087627288, 42.376851958613244, 43.33711485708914, 42.09670451379592, 42.79683974481399, 43.73783596100346, 51.242620560430716, 56.19051010377946, 56.99447047325873, 56.96144411640783, 56.96648043970908, 53.061482444886245, 47.61020375836281, 45.034967699358546, 43.59877617128434, 42.76181690154537, 40.946391013360795, 40.28888410137546, 43.96864391142323, 49.88336632328649, 55.926287481861735, 54.93211569324617, 58.1269960249624, 56.129972242539935, 52.03271535135085, 49.72337284395772, 45.6678617385126, 50.149295176229174, 55.05982806605678, 57.53635375730453, 54.61858103352209, 52.05314697757844, 59.47203951497232, 57.58450869591006, 54.57622728040142, 53.26198616335469, 59.920233065082186, 61.10510656910559, 62.104930493139456, 57.035698506139944, 41.366924009015484, 33.551672043338904, 30.273508025753884, 19.53552938276722, 16.840453147888184, 13.637283867405309, 17.861595153808594, 12.7270233438861, 7.5905099607283075, 4.672259198081109, 0.49563513828381417, 0.31699271932724987, 1.9629760158638803, 17.524679245487338, 50.29552898099346, 54.80991032815749, 43.39412650754375, 45.920442765758885, 56.65575419702838, 64.84165837687831, 47.58331591083158, 9.12467150918899, 0.30230096090705166, 0.13277086669639235, 0.09572949666049212, 0.13756758833844818, 0.1073888109456147, 0.15075628225120807, 0.09513791590448349, 0.18971030570326314, 0.07754156576289285, 0.13047133121759663, 0.12349122068694524, 0.14821454041427182, 0.1436633499519479, 0.1753743338368593, 0.1406223179712411, 0.1137026624693986, 0.08187175518082035, 0.15161183392328603, 0.1215262204829243, 0.20638522061128772, 0.08153122143759843], [0.033277108919836824, 0.04135395858376738, 0.11157674549688255, 0.08729672254694086, 0.058095503989006245, 0.025517231965016936, 0.025890040992488785, 0.051564696365066116, 0.013768403178771899, 0.03505800287389467, 0.04997315253281305, 0.020537074399931778, 0.06414683250289771, 0.037045621823879986, 0.026739858496453495, 0.03024955817137755, 0.0552331313731209, 0.037533336379114664, 0.07388715782473165, 0.06184780647257163, 0.02657336460786962, 0.5509551746710655, 12.538360280375327, 35.958057911165305, 48.38561711772796, 37.07809071387015, 24.823492342425933, 24.332168409901282, 35.16059690906156, 25.06541825109913, 7.646080630440866, 0.35922582892160265, 0.07831918331043375, 0.11321553014098637, 1.1983074992895126, 2.037030977587546, 4.6115276698143255, 8.665805189840256, 15.436550571072488, 14.358279243592294, 10.302721069705102, 22.9163339830214, 36.9338337836727, 41.967070179600874, 46.764336785962506, 51.829948425292976, 52.0568653845018, 47.65658970802061, 45.06802151280065, 36.558015807982414, 37.026393874999016, 36.9113782144362, 45.028856646630075, 52.77451792070943, 52.47972826803885, 50.923892682598485, 53.41023998875772, 50.25209265370523, 49.19980310624646, 50.55482510597476, 47.862569055249615, 49.58853352454401, 44.891703128814704, 43.01386056407806, 42.40290434129777, 39.74645953024588, 37.034434733852265, 36.84534511258526, 41.909678059239546, 48.529477888538, 52.80182546184909, 50.23647769804924, 52.84504605877785, 50.00164931820285, 48.33536371108025, 40.50169621744464, 37.61046617261825, 37.074639028118504, 36.44136844142791, 37.89282975658294, 45.148335964449, 49.91072485523839, 50.26138867101362, 50.90127629618491, 53.47367648155459, 49.254857493985085, 50.29057110509565, 46.28021432507423, 31.00850920523367, 54.79754309500418, 49.713594375118134, 50.05518182631462, 45.86538445565009, 43.90656455870598, 38.5316740312884, 38.7753983466856, 35.79314577964045, 36.54384428454984, 39.4610482646573, 45.67028576327909, 51.40634421379336, 50.13062077183878, 49.64889880149595, 51.02590568604008, 51.911161099710775, 51.23651343007242, 49.74935070160897, 50.404790524513494, 50.82183261071482, 48.22654147301951, 37.07689831333776, 40.05376154376615, 48.01126610848212, 52.01950480861049, 52.09166857504076, 50.74161229595062, 49.857717944729714, 43.598399623747795, 41.49601313375658, 38.82691867889897, 41.43074881645941, 47.86841730917654, 54.50867622129379, 53.69874600441226, 50.07612728303479, 53.105820917314105, 56.76921267663279, 51.50709421403947, 48.288495309891246, 47.78197219294887, 52.05990129901517, 52.68847680860951, 54.71510664109261, 45.267842738859116, 27.577413935815137, 13.956227475597014, 21.453327171264156, 12.626256673566758, 16.787630588777606, 13.641548464375159, 13.28756142047144, 2.3267676368836434, 1.368018037849857, 0.5575659618743005, 0.08271739367515811, 1.2142846613161027, 11.605173503198932, 32.614339320890366, 30.45549619582392, 23.003192909302253, 29.946705948921945, 43.56634209232946, 50.310959585251354, 34.68101655283282, 4.497472009351177, 0.03515618470227046, 0.02210047216184678, 0.10176151209781248, 0.03186417848712975, 0.03232218798310046, 0.016758910703262495, 0.024450109790890448, 0.055446092324752005, 0.04220270739507772, 0.04461631719623843, 0.053309798691301584, 0.08536963603429257, 0.07311559237179256, 0.03996720537543297, 0.04729485935381344, 0.09360843668541602, 0.048724145763703895, 0.06128519533141967, 0.03414674894884229, 0.04041422917056949, 0.023417155138186874, 0.021622471601491975, 0.03457277044353466, 0.06552568351429316, 0.05152965933384915, 0.0217712918416627, 0.041016159774435144, 0.10821564964229062, 0.029453778594371774, 0.01997481182878537, 0.03958021606048269, 0.043316028501477935, 0.0137322687266034, 0.05307148022937679, 0.011852062964481453, 0.011106893070973458, 0.039582384089308406, 0.01551950588867429, 0.01952632480571347, 0.025413545794905196, 0.05157465167764214, 0.02998491309793486, 0.9851949541799485, 14.891526449111202, 41.42214705867153, 53.96452580728839, 43.47264843602335, 28.830642584831487, 25.20016735599887, 43.14578948482391, 30.69251325822646, 8.557837047884542, 0.46129160049942236, 0.07866694126278162, 0.13493105078176146, 2.143261019260653, 3.827023727278556, 7.008417969749821, 7.84456923123329, 11.926789226070529, 14.096563016214679, 12.052985602809537, 23.067276593177553, 33.08334104476437, 40.75936063643425, 48.93673758352957, 54.437814681760734, 54.98792709842805, 50.47606391291465, 45.904737595588934, 38.19033368941277, 38.415866051950765, 39.6872317406439, 46.7773590549346, 55.334127256947184, 53.81137686391031, 52.13915671071699, 54.793883523633404, 52.37726811439761, 52.19784713560536, 52.10210600206929, 49.911517174013206, 51.38839544788484, 45.949574209028675, 43.65022982320478, 44.68560218811036, 41.95316929971018, 38.94972024425384, 37.836233877366595, 43.68820621121315, 49.07977857897359, 54.25726013798868, 49.95522414484332, 53.51974079685827, 51.37281187119023, 50.66075655721849, 41.72933924582697, 39.57694253613872, 38.20912576490833, 38.312982282330914, 38.07926393324329, 45.714063336772305, 51.681514170862016, 53.26794424364644, 52.74910096199282, 55.38878156292824, 51.06363104235742, 50.74563272537724, 47.81943867283483, 34.78939556306408, 57.28239205575759, 50.8509522868741, 53.45328800139889, 47.13326707963021, 45.24517928400348, 42.68836267532841, 39.84424814101189, 38.844938047470585, 38.575926211572465, 41.13087969441568, 48.04830897238947, 53.49742251057779, 52.449102401733406, 51.295325448436124, 52.78425324347712, 53.95934043392059, 53.85481711356871, 52.756745661458666, 52.27799684770646, 52.674093477187625, 49.352195032181285, 38.25887710817399, 42.80760272856682, 51.78171111691383, 53.924097937922326, 54.979254737977065, 53.54680907341742, 51.761848234361224, 46.05574492485293, 43.57251590298068, 40.61183637188327, 43.918002190128455, 50.51654669546312, 57.440341980226584, 54.400591388825454, 51.069616579240375, 53.09103750413465, 59.13110317722444, 53.37544464295911, 50.26662895756383, 52.687378544961255, 54.803006956654215, 56.61627946361419, 57.268298979728456, 44.25635368593278, 28.56401162762796, 16.234844096245304, 9.474020350363947, 12.858715941829066, 14.249817863587412, 15.654310757114043, 9.976859381121974, 4.150336855842221, 2.261069407386165, 0.33437883962065945, 0.05681031488723332, 1.179487354332401, 12.680835473921992, 40.314756055032056, 41.231853269761615, 28.72323436121787, 34.32287277713899, 50.802499248135476, 55.96279298105548, 40.311084716550766, 5.8146779479519015, 0.019273657516966906, 0.061117073505996704, 0.077647079052704, 0.0517240694663938, 0.07148653704432711, 0.042017352421798056, 0.0356470248962362, 0.06259111094198401, 0.07751689773173102, 0.05651790295697509, 0.045763204445041, 0.08521752161604744, 0.016188320756379156, 0.05769139643938792, 0.016041145690025824, 0.04008404144476499, 0.051392881995848114, 0.019854352163571506, 0.08054947210175377, 0.08409790709734925, 0.017315400801899455, 0.11198913828740198, 0.1449395145379728, 0.2387532474653375, 0.23352999871055927, 0.25811356101785937, 0.1419013477261028, 0.1709749360358523, 0.14541626637501104, 0.10500888986092423, 0.1437868739688589, 0.14471541849836228, 0.0765649032508654, 0.1635013959340511, 0.10394693878028663, 0.09094305591838014, 0.15188486765949957, 0.1873239111756125, 0.16277981771817132, 0.1532331057974408, 0.1164893915636405, 0.1410911178156253, 1.6626884259523886, 19.40639711195423, 49.47158805785641, 60.35005031093475, 49.107525425572554, 35.35337748066072, 34.14785269768008, 48.08739146878643, 35.01822271654683, 10.84545256630067, 0.8020303794933904, 0.20644598670544165, 0.2464700664483732, 2.2408008046688574, 2.7224612428296, 9.314772121367916, 18.951555144402292, 29.520495322442827, 22.22742065306633, 17.147649257413804, 24.469906360872333, 38.435403377779075, 43.33094889117826, 48.13265954294513, 56.067147639489946, 57.66761587512109, 53.60038080523091, 49.2108485006517, 39.22860468587568, 40.91658884479154, 41.600791408169655, 50.05421300088206, 58.397592498410134, 53.499646494465495, 51.09961094394807, 55.8986779182188, 55.43949388688611, 55.5498811506456, 54.9547948375825, 53.725061185898326, 55.244414806365974, 49.40899487464659, 48.83474026956866, 47.076969300546956, 44.702703722061656, 39.327632765616144, 40.78076501046458, 47.45663119900612, 52.52870298201039, 55.29722559836603, 50.088569041221376, 56.43195159973637, 54.29917458565005, 54.44310203675301, 43.91264423247307, 41.26543268080681, 39.53318065212619, 41.9753973714767, 41.19591259187268, 49.71179792957921, 55.03109670454457, 55.092983861123365, 54.851036379414225, 55.80472930785149, 52.765312117915, 50.758980551073634, 48.648074673068145, 38.08921106400029, 57.52484944558913, 54.19303917115735, 56.108705151465635, 51.01083201746787, 48.177817790739, 43.876801613838445, 42.3625902206667, 40.804926810726045, 40.4703760916187, 43.86666620931318, 50.39712621319679, 56.08261354507939, 53.60528376794631, 52.65743909343597, 53.91167971395678, 55.34583553191155, 56.49458792901809, 56.497447336873705, 56.18965502708189, 54.6385851214009, 52.671653762940444, 41.78981827151391, 43.90983189305952, 54.48580488081902, 55.63052900375859, 56.8819219835343, 54.51551683487431, 56.07833423922139, 46.08163649036039, 45.476873690082186, 43.322190238583474, 46.02622908930625, 52.56084680557252, 60.822229154648326, 56.8437377099068, 51.66560111507293, 54.36436045554377, 61.78726557762393, 56.717355020584606, 53.23529443433208, 53.29614608518539, 57.47832229060512, 58.87470960617066, 60.87614605503698, 49.99185123751241, 31.560257250262847, 18.224685038289717, 28.7138932366525, 25.70287989031884, 29.70634702713259, 27.35347797793727, 21.12489534962562, 8.257111868550702, 5.702649662571569, 0.9025421570385657, 0.2272687161401395, 1.6491727963570626, 14.947049560085421, 41.152362515849454, 44.66867716081681, 35.20988149027671, 42.93847653173631, 58.40846923089797, 63.04314574887676, 47.22359926469865, 9.272774323340386, 0.26178005782346575, 0.12788833554593787, 0.25117692597691094, 0.18473278731107715, 0.21225150824794847, 0.08190786090469168, 0.12666414236469617, 0.1886057294905186, 0.15385336122445523, 0.13192424760951152, 0.13851563746650375, 0.1593547765045397, 0.16475485367400033, 0.17952800127527407, 0.12335628195996247, 0.1482962360305171, 0.12246958115288328, 0.17811196435603405, 0.11932356448303308, 0.1594245211491662, 0.08267699019803156], [0.0535456886545064, 0.014609690293699745, 0.056175779581310294, 0.007655756987421023, 0.034164303853627176, 0.03424634037899875, 0.057280983986152764, 0.029500243742199197, 0.08268613728784746, 0.0407399965690509, 0.022318761254991257, 0.052348569020508766, 0.056220940464446624, 0.05562721466225001, 0.028083927200866804, 0.04239573090847942, 0.03821353052532481, 0.052152653525192896, 0.020958355725592664, 0.015084529783756984, 0.08295347899078362, 0.3638498743455256, 5.62312949088312, 31.308350870686194, 45.70617545035578, 43.18375802809193, 35.413428967998875, 32.76384634356345, 41.43369451645882, 31.107086212404315, 8.348134390769467, 0.4942524721545558, 0.10910887751848468, 0.15396946951025917, 1.3888878663701396, 3.892288289723858, 6.443377992799205, 3.102275133132935, 9.612114256428136, 14.91403595093758, 14.399844600308327, 30.892436465909405, 34.74453933777348, 41.29957691315682, 50.09208740726594, 53.529844822422156, 49.27286509544619, 49.017279532647905, 41.79347392051451, 37.575659059709125, 42.262071640260764, 36.13629433416551, 43.41712728623421, 48.72639656066895, 55.276880264282234, 49.13108318082748, 51.27114795869397, 52.3595311564784, 52.5324410007846, 50.01107477372693, 51.259114127005304, 48.548752415564756, 47.45494850220219, 50.12919695146623, 49.27280233752344, 47.367550250022646, 43.28670063326436, 45.30520331475043, 45.339869222333355, 50.27781947966545, 50.23575205956736, 51.348038181181884, 53.183644663903024, 48.1850584860771, 46.46409896112258, 38.27218963253883, 36.51212015459615, 35.09448535980717, 36.97047656582248, 38.976137407364384, 46.26699201522335, 51.621882377132295, 53.30625795548963, 52.5761793505761, 51.77947144354544, 51.10734585792788, 48.11306730393441, 45.52909220418623, 32.130458085767685, 53.62899449563796, 49.96068408412319, 50.68415349529636, 47.924805302773755, 47.100252489889826, 42.837420586616766, 41.579767504046046, 37.7710872311746, 36.836025561055834, 38.02866535802042, 44.9782855279984, 51.362586252151004, 54.35585675701019, 51.96372478238998, 50.5571706833378, 51.45248305413031, 52.27598859417824, 52.981650444769095, 53.71396480068084, 53.6873475966915, 54.07980034428259, 41.387155594364295, 39.87363061597271, 46.74057506745862, 48.89334832468341, 48.62346572260703, 45.8200575459388, 43.322347133390366, 38.92390320377965, 37.37854426906955, 37.38946022525911, 38.66078276788035, 46.356888817202666, 50.4040805755123, 53.75666764474685, 53.328474260145626, 51.39946045414094, 53.28935254004694, 54.4606585656443, 51.90950585949806, 51.43478139754265, 53.18976356137184, 55.707085824781856, 56.84102342974756, 50.482198499864154, 31.395419643771266, 22.422354605890092, 16.07604007567129, 16.199457453143214, 8.267672850239663, 17.358698268090528, 7.052881958023195, 3.5773087268875496, 1.0762931045985993, 0.5302280836528348, 0.010174662700944371, 0.6690437671157622, 9.763955089353747, 33.75101866260652, 25.232748523835216, 29.213403155726773, 33.73342683238368, 38.65313022367416, 49.206706477749734, 32.051545881455944, 7.699838184541272, 0.047540379042226466, 0.034862324865835334, 0.016166795600926685, 0.06485570898099292, 0.031133234846375646, 0.05668533147282659, 0.09730485688534476, 0.040991124021069664, 0.04520339335525229, 0.014537908812804569, 0.029876300982469996, 0.037719568523067626, 0.039618957126813556, 0.028558698700620767, 0.059636394087705887, 0.04171524181841843, 0.028772347216163913, 0.027634666428991386, 0.10733608877466572, 0.011125436229180666, 0.05159226786946097, 0.039879557256016045, 0.016743525742523132, 0.007395894217845654, 0.031552034047161864, 0.02788181022380389, 0.03395199407673171, 0.03291631598145731, 0.027156468600996082, 0.016221837103066426, 0.051020708821353414, 0.011875836587991687, 0.09349787487618386, 0.03076213802541456, 0.015521884591679181, 0.049880145628365784, 0.05549128768184493, 0.06427077786816705, 0.014374237000611762, 0.03419387101706478, 0.02115948253401345, 0.046763209656121275, 0.5081261099586564, 7.466844003046713, 36.64984633845668, 52.46205406804239, 48.06305316186721, 37.173529824902936, 35.29178450184484, 41.94312018732871, 32.99649192440894, 9.318576820435064, 0.5605217129472764, 0.03711014174886289, 0.32957951327966106, 2.402185989964393, 8.725518372751052, 10.528243626317671, 8.52082360175348, 9.381181770755399, 14.075961747477132, 13.733625123577735, 24.909853127694902, 30.338205560561153, 41.990549487452355, 50.40859130121047, 54.35210697112545, 51.13363358282274, 51.84668125644807, 45.613442774741884, 39.721238690037886, 43.49919111497941, 37.46789978396508, 46.48114950426164, 51.93266745536558, 54.0266522284477, 50.33303468458114, 50.66883663977347, 52.11089995599563, 53.825815108514604, 52.434644545278246, 52.702820916329664, 51.4409944318956, 50.501202383349025, 51.36895225894067, 50.42817177311067, 49.154072192407426, 45.399626531908595, 45.86281530318722, 46.09028531659035, 51.45271447397048, 50.3237465120131, 50.771959673973825, 54.231580380470525, 49.337239034714244, 47.22656849891909, 40.50050381691226, 37.40674218823833, 35.81507182890369, 38.34475740309685, 40.81321870127032, 48.38759399229481, 54.705755710601814, 54.502816200256355, 54.867298526148645, 53.142887315442486, 51.02482311187252, 46.46989230186709, 46.51531727083268, 35.26564190464635, 54.74402235400293, 52.22293853759766, 51.9765587775938, 50.15391572829216, 49.4420486880887, 44.39575472185689, 42.08037176439839, 38.97482341335666, 38.11130185281077, 39.65792771308653, 46.96373439604237, 53.56374194545131, 56.23288346875099, 53.59707032480548, 51.6569209098816, 50.64598098877938, 53.49914443108344, 54.06962179368543, 54.8118362119121, 57.14916875285488, 55.82035995298817, 43.38057864096857, 41.74709581559704, 47.63051379111506, 50.35079517672139, 50.20496537608486, 49.89434503739881, 45.73713864049604, 41.34139330156388, 39.37162214709867, 39.09707584688741, 40.7201212452304, 48.82472645851874, 53.03628513889929, 55.15502791250906, 54.43774407909763, 50.64888354270689, 56.36208634222708, 56.17783300338253, 52.84750146250571, 52.5406583662956, 55.306902085581136, 56.75339768009802, 59.31510548437796, 49.417808440423784, 31.330894693251583, 19.596010369639245, 8.931410447243723, 7.666793196432053, 15.162487702984965, 12.754003367116376, 11.085566339954253, 4.0915297404412305, 1.7821842912704715, 0.48475396248602104, 0.05609964193295568, 1.0239330787331828, 11.116560909055895, 37.17556945739254, 30.641504795320575, 33.630044921751946, 35.6940863209386, 45.37396246387113, 57.915482213420255, 39.44824957078503, 9.729298007103706, 0.06215570870065882, 0.06629007838426099, 0.015546627316413628, 0.021034091177787033, 0.057457218682693864, 0.02468028473818014, 0.08712099729886941, 0.050912686593590245, 0.022073429258119677, 0.03547797227398523, 0.07496633822278631, 0.05695530085734302, 0.03180507097333189, 0.06808833955156227, 0.06832991005672563, 0.03371837556422238, 0.0364780311112202, 0.03461464097903621, 0.059537292953820965, 0.06648428167306608, 0.06051076854008341, 0.16925238733810766, 0.05395645733862635, 0.2870908980408023, 0.15096249779866588, 0.14109283385257568, 0.1616491945160012, 0.1868104024399673, 0.09641286241070879, 0.1626074632569667, 0.09310533142378254, 0.11984091898005818, 0.13804706744849682, 0.12296932328852916, 0.12428265846064016, 0.20813046083334955, 0.17512385372913655, 0.1828721282823432, 0.19617279360611595, 0.1112602592536038, 0.13506805794613977, 0.18158111691234574, 0.6733892016833829, 10.953930616378786, 44.87245998074932, 61.343261118858095, 55.2915067826548, 45.951547161225356, 44.95587310483379, 52.8639950290803, 41.09091858710013, 10.995376340804562, 0.9679554018282122, 0.23067477369500747, 0.6581783727292092, 5.437012535910453, 14.002903680647574, 15.295473702492254, 8.328861824927792, 17.9351847017965, 23.900238967710926, 21.113616574195124, 35.77322013916508, 36.13973425280663, 42.744307441096154, 50.753042082632746, 57.441106842410186, 54.46421615539059, 54.84552152695195, 47.38070195721042, 41.799110366452126, 46.946468122543834, 39.88546832915276, 48.445170464054236, 53.456982874101215, 57.506390771558216, 48.580041162429325, 52.11394763761952, 53.56920972947152, 55.848397054979884, 53.19723175417993, 56.237955093383796, 53.31065885482296, 51.302456317409394, 53.791007995605476, 52.67421507066297, 51.698325449420565, 47.950171270678126, 50.175771174892304, 48.72642401726016, 53.43683365852603, 51.04177951812745, 51.782813302932254, 56.09981706065517, 50.21304153626966, 49.88775937787948, 41.881495829551454, 38.79773624481694, 37.95779989611718, 40.35543887845932, 43.2940629220778, 50.3678378751201, 56.21948857461253, 56.5233192905303, 56.32127408058413, 55.045683999215406, 50.499347102257516, 48.22796137102189, 47.448009829367365, 37.9475821218183, 55.481690745199884, 53.35801362991334, 54.7300979398912, 52.80019767822758, 51.62259624850366, 46.93225345303936, 46.01411681021414, 41.2391802572435, 40.74666784655663, 42.10765577131703, 49.31991784803329, 56.47379936710481, 57.76005045060189, 55.09828298322616, 53.452562362917014, 52.077281321248705, 53.31941358504757, 55.56384871082922, 55.42801310939174, 57.88110656123008, 59.20360426748953, 45.45965056265555, 44.35465612719136, 51.364155200219926, 52.66519754163681, 51.50264232389389, 51.84228035711473, 47.24400735670521, 44.66872030688871, 41.02492863132108, 40.767628992757494, 42.407262094559215, 50.703553538168634, 54.57076341875138, 57.62862751560827, 56.35380621879332, 51.76041656924833, 56.40905280267039, 58.45603189160747, 55.02120056459981, 56.247784553035615, 58.353693331441576, 59.52150060284523, 62.44599626910303, 53.29479678984612, 36.67053291874547, 29.229886916375932, 24.19728986678585, 29.142406294422766, 15.398579086026839, 25.1422712110704, 13.20108590587493, 7.094349745781192, 3.251066323249571, 1.1468115593156507, 0.2251522909970053, 1.0527836435264157, 12.710883771219562, 44.46000314527943, 36.74872536813059, 41.6304249148215, 45.37282105415098, 53.11413634207941, 63.31898250887471, 46.92977451509046, 12.348294969527954, 0.31542122784641485, 0.1524282691459502, 0.13291101482126022, 0.11611087518113276, 0.1677979234485857, 0.11992770908099991, 0.2266005036090651, 0.21161994536317166, 0.16032392369402995, 0.12196590898618584, 0.12687430326496402, 0.07974691839227754, 0.10689630834085327, 0.10781470986623919, 0.20976778991039724, 0.08315630842961612, 0.1526007461812227, 0.10680502896467525, 0.14884504609771315, 0.08038502366792771, 0.11651372251611565], [0.0924565315607094, 0.02509611151782015, 0.023633486876684814, 0.028230385975010937, 0.02793682682808609, 0.036636373824289734, 0.05114603697532608, 0.036961064869237524, 0.0579464998877337, 0.02786389334247478, 0.06472964921305258, 0.009613509042068355, 0.031864804764007854, 0.07331431557935092, 0.05208618007600308, 0.05987778456220704, 0.04770258283843437, 0.030042936597319863, 0.04563865387031148, 0.058949358776331916, 0.06258675190169485, 0.25079254902178244, 5.030410818515286, 27.87149560066962, 47.93668223965553, 49.644148811217285, 30.49386089847934, 29.146109011865434, 39.20548623608005, 27.569539777694214, 9.257127988723017, 0.32986811392249604, 0.031114661044651465, 0.15631657904915272, 0.9437195055427091, 5.148314814413748, 8.01127290533435, 8.665469827190522, 8.61674516431747, 12.778622123502917, 11.674499434809531, 23.678323030471805, 30.046004672204297, 41.70067456460769, 49.69611237126012, 51.825406320633434, 48.09874280806511, 46.38428265048612, 39.97990723579161, 36.87256243921096, 37.74306581866357, 36.80536831578901, 39.26572599718648, 47.571968493923066, 51.31528246787287, 51.69364606180499, 49.662529037844756, 50.59395074844361, 51.80844991437851, 51.895291189993586, 52.43585263529132, 52.688308146692094, 51.23699588160361, 48.491807445403076, 47.99712596401092, 49.87877322781471, 50.3560080066804, 49.85374458374516, 50.00846247519217, 51.598097124407374, 52.469502648999615, 53.029091512003255, 49.936910598508774, 49.808598103061804, 43.95944595336915, 36.6194950380633, 35.85646852370232, 35.81783709987518, 35.63304639631702, 38.55570639333418, 43.44020258995795, 49.760552990821104, 50.104133006065126, 50.35778091799829, 52.989742294434585, 52.16381665199034, 50.159207005654615, 46.3431409097487, 29.877880119508315, 50.111534518580285, 49.83356791157877, 51.013087380316954, 49.6751041566172, 51.89067848267094, 46.03041033590994, 44.23703209046395, 38.028245664411976, 37.051991262743556, 37.474057905135616, 39.683289758620724, 45.09338748070502, 50.00750933924029, 50.776972463054044, 53.192877923288655, 50.862346772224676, 53.10363223475795, 49.92199774711363, 50.72388710514192, 52.08428275200629, 49.74358089508549, 39.389013936442716, 40.28923319232079, 45.678887521066976, 44.14320115120181, 43.95816726069297, 40.86229931923651, 39.56377906184043, 36.753906819128225, 36.438595325716086, 36.168202815517304, 37.59074841776202, 41.85663584739932, 49.35266571660196, 53.2857596489691, 51.8738946607036, 53.765285092015425, 53.824744301457564, 54.51735250411495, 54.47260610518917, 57.718461559664824, 53.20508041689473, 55.19303960184897, 57.416133111523045, 52.70741008943128, 38.42525228377312, 21.54047243056759, 5.497459692339744, 2.749307905474017, 14.7641033511008, 11.680415349621928, 11.067264560730228, 3.2727285931187295, 1.0479936941016106, 0.09188049472868444, 0.1343165410141791, 0.6563312428132181, 8.731749057769775, 41.94402233246834, 43.94195610477079, 29.30611621948981, 30.300911664962772, 42.72279716307118, 51.008749238906375, 33.55891666104717, 8.36928184955351, 0.15207562355264542, 0.13148013111804763, 0.02960300869158199, 0.010826841011763582, 0.11784021907876577, 0.061048148575449185, 0.17482826636443216, 0.0426858407445252, 0.03922242618676636, 0.015918384888209403, 0.014110095629979287, 0.014543878552954526, 0.020327815568194758, 0.024331218690701553, 0.07075719835777437, 0.050202461800748305, 0.10086148902173005, 0.007075552637087963, 0.058834338335380446, 0.011200726392769046, 0.026566577068860495, 0.04692719843719275, 0.06522440411631139, 0.08193391555499646, 0.02546998732272656, 0.033907101324368874, 0.08588731228824585, 0.015853979876415146, 0.037212372351918495, 0.044020285469389735, 0.03560803485132995, 0.04338699505634366, 0.024869583149050033, 0.0245663617181802, 0.054922681902685476, 0.05213398013203856, 0.03826359820161616, 0.06371039221243513, 0.02267803159362126, 0.11249831862627499, 0.02015503784341197, 0.07817463784088051, 0.3132815749174164, 7.268607904834132, 33.94296769172915, 53.985549711412006, 56.2395554204141, 37.36988367572908, 29.81937796838822, 47.82044279959894, 34.73691817252867, 10.037156016595903, 0.5666042672049615, 0.06878439171780502, 0.3422515881398032, 2.6353740836343458, 7.722785030641864, 10.106577065683181, 13.157835891169887, 11.615132401066443, 10.538521216761682, 16.224684176906464, 28.349763924075713, 32.0064405856594, 42.07982263257427, 49.91529441648915, 54.94722466314993, 50.63415896508002, 48.99305889683385, 40.74033714109852, 38.85590891684256, 39.1877688900117, 39.09239645927183, 41.742490953014745, 49.66900879336942, 54.195980948786584, 51.98394460062827, 49.909179441390506, 49.98002921381305, 51.24981418732674, 51.753128805468165, 52.19113203787035, 52.89629574744932, 51.74924565899757, 50.55963393180601, 49.862385565234774, 51.53020089672458, 52.843555558112364, 53.2701172367219, 53.12820196151734, 54.27166308126142, 52.65586622299687, 53.158451280286236, 52.63930205375918, 51.753811297878144, 46.68657187492617, 38.86678957170056, 37.79893213702787, 37.89054693714265, 38.54700657629198, 39.13365194874425, 44.49510443595148, 53.40132836372622, 52.12142759753812, 53.07530879974366, 53.526385291930175, 52.900869231070246, 51.38768549888365, 46.93922350483556, 32.92111965917772, 51.19783493780321, 51.90230438786169, 53.16855530585013, 49.66211718897666, 52.70707668796663, 47.72675698803317, 45.8541900111783, 39.287181362029045, 39.024606135583696, 39.27539071729107, 41.60892640390704, 47.308965729128936, 52.92535266568584, 53.01094662758612, 55.101146313451956, 52.781370301400464, 52.898445206303755, 50.791818634156265, 52.0443687131328, 53.643268000695016, 52.21719226529522, 42.459037380833784, 42.46190463342975, 47.20448947721913, 47.299195105029696, 46.29193436714911, 44.323359535586455, 41.391736922725556, 37.16200590133667, 37.67281224650722, 38.62108053699617, 39.043574717737016, 43.32637932992751, 51.507886532814275, 54.758040904998786, 53.85807268081173, 55.09272106232182, 54.42251351571853, 55.366306381840865, 54.64204465189288, 56.39136683556342, 56.608677910220244, 57.62692128458331, 56.59622438492314, 54.308702022798606, 36.99676036834717, 21.564630308458884, 9.27916092257346, 10.359250268628521, 14.421146992714176, 10.051638387864637, 14.192276693159535, 4.684067003188595, 1.775205659289514, 0.46809139691533586, 0.06309043555971115, 0.7037452211783779, 10.236296711429473, 43.05348826992897, 42.31711818325905, 34.511338741548606, 36.756562263734885, 48.918937867687596, 59.09800621771044, 40.2288757601092, 9.904632856768947, 0.09428236423240555, 0.008345986885439244, 0.04171675101162926, 0.07793175732536663, 0.01658159582274816, 0.018267134812870817, 0.031676021547267036, 0.03928601148448164, 0.10256537581763922, 0.043947522438341574, 0.035732286651768995, 0.011607218391051697, 0.01620920239797523, 0.06654127095375331, 0.01729309806720384, 0.04931733530435351, 0.015066441490254818, 0.030497052451415412, 0.055774805331302274, 0.03739737109431336, 0.015095316301730853, 0.18604745547617638, 0.13805992240386625, 0.23309533574408103, 0.11760429464160435, 0.10255199992248129, 0.23554730739805008, 0.1954819508377583, 0.19872391235924539, 0.12630906061179217, 0.15574041964305987, 0.18929546909226527, 0.12376513542427171, 0.07545508699671877, 0.13494355333668573, 0.17015333738057845, 0.15729255974292755, 0.22398327146807026, 0.07199978531007806, 0.14987204824724507, 0.1158898511540986, 0.1865090540940723, 0.6041905019552477, 9.563133658901338, 41.13748496578586, 60.70580928556381, 62.48475320877568, 43.02338407885644, 40.925386721088046, 50.85985998953543, 36.70749733524938, 12.1412742330182, 0.8505981475595505, 0.17976545788828405, 1.1634763618630748, 2.3705709509311186, 7.95429410472993, 18.842446573318977, 20.168517558805405, 18.454088780187792, 21.840549438230454, 17.882324880169286, 25.411098695570423, 33.063340879255726, 43.62047472307759, 51.75404271771831, 55.920333323940156, 53.54978615237821, 50.46682280878867, 44.27578903013661, 41.06283441666634, 41.168585438882154, 40.96499089271792, 44.764300623247706, 50.85692213427637, 54.61767104364211, 52.219710426945845, 49.76044708682645, 50.43009765686528, 52.75520416998094, 54.17124648247996, 53.94078370063536, 53.95357062739711, 53.97648903631396, 51.24166350210867, 50.93250228512672, 52.55321779558736, 54.85713958740235, 55.50887277049404, 54.7446067871586, 55.14868543994043, 53.98750697412799, 53.29384365389424, 54.90602408685992, 54.98001175542032, 47.54385686689808, 39.822733940616736, 39.23324484978953, 40.72358077572238, 41.044536559812485, 41.60662789498606, 47.5003420922064, 54.6181966412452, 53.70621027485017, 53.79069420599169, 57.58520295543056, 56.022326715530895, 52.50172884233537, 49.061974940761445, 37.2137027402078, 51.93110242966683, 54.092912827768636, 53.63942407792615, 53.57770950563493, 55.811279666039255, 51.25719216562087, 47.14510087044009, 43.71565888004918, 40.992137616680516, 42.44268109721523, 42.58648303247268, 49.12925143395701, 53.63250893931235, 55.867526454310266, 58.04864668077039, 53.86329335551108, 54.864674460503366, 51.67824683650848, 52.0343941257846, 55.32001064669702, 54.51020986803117, 43.81776994274509, 43.9124128126329, 48.507092921964585, 47.99475685242684, 46.80058340872488, 45.7945974411503, 45.27118459824593, 40.71098996746925, 40.65391163672171, 40.46286083036854, 41.97419712620397, 45.86213281077724, 54.03586587598247, 57.39386581605481, 56.093745231628425, 57.403020628037, 57.74347843662385, 56.13041154799923, 56.176934780613074, 59.10151281664449, 58.830292686339355, 60.427175875633, 60.182204246521, 58.216563347847234, 46.69208280501827, 27.63338811935917, 9.269498163653958, 12.876727465660343, 23.24748989074461, 23.910643054592995, 20.831515789031982, 9.59027744108631, 3.943158979377439, 0.7550813858547519, 0.2998330546242576, 0.9029537607585231, 11.755684652636129, 51.45253796731272, 55.83094643008325, 41.63160554824337, 42.510918571103005, 57.01740064928609, 66.42972407802459, 48.36749184516169, 12.543942793723076, 0.2768045741944544, 0.27697899709305457, 0.15846556292906885, 0.15039154779045813, 0.2447726913998204, 0.12589742624831776, 0.21354251961794593, 0.17440184650401916, 0.20094268684906347, 0.09303999178472067, 0.16421952675427162, 0.11340146734108848, 0.08602798901378148, 0.15831893370036157, 0.14958010746106026, 0.15705812151633924, 0.14611567400636213, 0.14842288568615913, 0.1522777328688291, 0.1442391569575956, 0.10132183891630943], [0.03544540587632406, 0.01230616445442842, 0.02911122046380995, 0.032220371067523956, 0.02060610083712926, 0.020190136161662882, 0.05105599483114578, 0.029858926108347315, 0.026846072756715363, 0.08522319066668711, 0.023739984589478662, 0.008160943135378823, 0.0769658200442791, 0.021538263216855067, 0.11624273423465992, 0.09576764017824205, 0.05420286951947117, 0.02263918710542062, 0.06730787215694305, 0.14306141934808225, 0.04178980898652827, 0.08184536345182888, 2.916394991259421, 22.358019890323764, 49.23843060770343, 45.44302755786527, 30.757606952421128, 29.27705537888312, 24.771287556617494, 22.845576386297903, 11.095229098873755, 0.45335695207599674, 0.1713858962419533, 0.5308115975030008, 3.4129574942973355, 11.14700242396324, 8.554613840195442, 9.941766915782805, 6.42592050375477, 10.906573880103327, 18.582009038617535, 28.299502672687655, 30.944825603115945, 48.93747498912197, 48.111463054533935, 54.28137094743791, 46.6364400617538, 48.2565240706167, 37.91650518294304, 38.63057659518334, 37.29471145137664, 37.815519840486594, 39.24996591383411, 44.7341650532138, 49.94882675909227, 55.33472345721338, 49.92763027068108, 52.91074183679397, 51.154877139676, 53.476951660648474, 50.8921254065729, 51.62023105928975, 51.66759760149064, 52.943195527599705, 51.61666562480312, 50.7453267805038, 47.51624338088497, 50.28045139005108, 50.17175074546568, 51.45720558781778, 51.03977518696939, 53.99604597399312, 51.92890590237033, 48.860643602186634, 41.21617163381269, 36.55985932196341, 33.63693652614471, 33.870156734220444, 36.43132325141661, 36.93706973906487, 36.86470985412598, 40.37253256767027, 43.53247242589151, 45.88857350810882, 45.067205659804806, 50.402703823581824, 52.10826412323983, 49.103865854201786, 31.25500075278744, 49.226439922086655, 49.540104020026426, 49.212103659106845, 50.74750761831961, 52.47269938069006, 50.934800794047696, 47.75994416206114, 42.27029685051211, 36.84691013828401, 37.5482887606467, 37.55645513534546, 39.377795957749896, 45.08848451798962, 44.60269504977811, 49.24527514365412, 49.865829406246064, 52.27152885929231, 51.95771963365617, 50.623062579862534, 51.732897220119355, 49.036887461139315, 39.87754514140468, 40.889606860376176, 43.01179739736742, 43.649688536121005, 40.831077252664876, 39.42439371539701, 40.36731189297092, 43.234293845392045, 43.08551442238593, 42.998692758621715, 36.90471018514326, 36.762108495158536, 39.74496118484005, 47.47687847383561, 50.10012434374902, 51.60746374437886, 51.793262497071304, 52.31667926234584, 53.154564211445475, 55.974658150826734, 53.567982027607584, 54.774036330561486, 54.91255091082666, 56.058604717254646, 38.224709341602946, 23.21755828395967, 11.05688008569902, 7.0348934781166825, 21.75731674317391, 6.799988121755662, 12.091467976570131, 3.397572977888969, 1.7606651879126027, 0.5242860605639796, 0.02754492305910155, 0.7292536814366618, 9.537494105677451, 30.294894749118438, 38.08375112472042, 40.38994396886518, 29.591527485078384, 37.06967330748035, 51.194489156046224, 37.96280484045706, 7.999592577257465, 0.22449593750699876, 0.023615027988149274, 0.02062609573195298, 0.05661902273254049, 0.020297591484362082, 0.06980937905609608, 0.09217045134714535, 0.037518979891413645, 0.059749828726654096, 0.04467443262617435, 0.015163192649432009, 0.02860049645776951, 0.031478236797415925, 0.027802163892756068, 0.029930771749106147, 0.021916013511438525, 0.04837131247885766, 0.048198938865454934, 0.12246001271470902, 0.04123804565038412, 0.013929144704654334, 0.04941230339388694, 0.04808647332773094, 0.038750021898698424, 0.05589862812250372, 0.04947999109243674, 0.020629738480032935, 0.029529674925030242, 0.004118414466164165, 0.028223937429908304, 0.03175672316443055, 0.012723222720406711, 0.04431141803281442, 0.05483678812461515, 0.09124075768575554, 0.05109601909474981, 0.04100338525829777, 0.08453545821530205, 0.03466682305799858, 0.030078316452882947, 0.08126272294189661, 0.06272567428588387, 0.13364071356913737, 4.047385915633171, 28.773730954816266, 54.23155292387932, 51.42151594161988, 36.35222865689185, 38.773033157471694, 31.702676550034557, 28.331391542188584, 13.165836545728869, 0.7451375645975913, 0.11733589573733269, 0.753508699276755, 4.294269700204173, 6.783517599105836, 11.076534102039954, 13.274858824668392, 13.15085897522588, 10.001919404152902, 19.456377913874967, 29.09819529902551, 33.7119165543587, 45.802242140616144, 50.347061080317346, 54.242386510295255, 51.08949515127367, 49.88446850930491, 41.79570967151273, 40.11187145786901, 38.56621834539598, 39.14718412583874, 41.989729712086344, 46.74788636545981, 52.84960777528825, 54.40194852890507, 49.501723627890314, 52.85736230111892, 52.82002525944864, 53.25219592740459, 52.99904223411314, 52.773258839884114, 53.04658920534196, 52.70311509409259, 51.715297545156176, 50.20256880790957, 48.030991708078695, 51.21874509319183, 50.54546633074361, 51.247562746847834, 52.08410232297836, 53.89816322634297, 52.54934641622728, 51.18092952236053, 44.06539309409357, 37.38339624097271, 36.86807132536365, 36.74120618451026, 38.33258236608198, 40.16259162656723, 39.46462154388428, 44.3709300410363, 46.50137716724027, 49.593056017352694, 48.403224637431485, 51.84338646550333, 53.9036427774737, 50.0649759846349, 33.0961868070787, 48.74814218090427, 51.18850361916327, 51.150095770435954, 51.71595258097495, 54.93526535649454, 53.50229017196163, 51.3405542988931, 43.63610929058444, 39.79525381518949, 37.85337855738979, 38.9400633688896, 42.536237470565304, 47.2701068078318, 48.52155470078992, 52.556822453775716, 52.19548979113179, 55.02316174968597, 52.59131577707107, 51.7917327727041, 53.27316099597562, 51.08399991066226, 41.196842193603516, 42.05488028064851, 45.49492835998536, 45.06666437272103, 42.29214053000174, 42.09577883443525, 41.22359668054889, 43.97262511714813, 45.20885813620783, 44.33798997632919, 39.0991743149296, 39.43479976346416, 43.06622420587848, 50.91065468326692, 50.878852105909786, 53.73081138057094, 53.08768780000749, 54.651199463875066, 55.95122198904715, 58.05522841791953, 56.42680152770012, 57.99692630767823, 57.45856923441733, 58.98783076194025, 41.58315250950475, 25.02609452893657, 15.350824229178892, 6.224895110053401, 11.492372020598381, 10.128785525598834, 11.281003336752615, 6.932322027221804, 0.4819782114317341, 0.617741861891362, 0.12350375388538647, 0.8145897474981124, 10.765452884858655, 36.26483824945266, 44.90467832934472, 45.15752607776273, 35.78071578856438, 45.11226977071455, 58.28544016807311, 46.30323471561555, 10.369079728280346, 0.2363749887914427, 0.023266383289029042, 0.04341463167821208, 0.016028800183126045, 0.015706863224266038, 0.025900419568642977, 0.017122737349822156, 0.016073779120380362, 0.03163505691073595, 0.05280729480868867, 0.07573148385891992, 0.025413195309679837, 0.02321668716538097, 0.011908455654197644, 0.01768478541634977, 0.0323184724566677, 0.06432457256221003, 0.09605684603053717, 0.05260809279617764, 0.024716200855290218, 0.01622979292616008, 0.1159829538195364, 0.1330807339400053, 0.10614054728179209, 0.13571855852440481, 0.09418743061682872, 0.08971790512723309, 0.2519459097135452, 0.11035331074268588, 0.10188601670726653, 0.2228274899384668, 0.10327072063040349, 0.074092002074805, 0.2494638154823934, 0.09576338839026229, 0.20798340259540468, 0.2261237364502684, 0.16084215153128872, 0.18933417185419993, 0.14658424402436904, 0.14540325820205674, 0.14294111290045325, 0.298159887954112, 5.909729234633907, 36.494241991350734, 63.89934032194076, 56.42947658415764, 43.10244729441982, 39.56006065491707, 36.572257934078095, 32.838037975372806, 15.757876038551332, 1.0290482784471204, 0.37108364424878554, 0.8232551212272337, 5.691754298825418, 18.439664263879102, 17.143064006682366, 17.09929427792949, 12.301238294570679, 16.951638613977742, 20.189288470052905, 31.21257639700367, 32.673518080865186, 49.425311934563425, 49.842044153521144, 57.85585826443088, 53.60123980429865, 52.798569894606075, 42.87661683174872, 43.10721297417918, 40.06784285268476, 40.97679330456642, 44.565911062302135, 48.60233199211859, 55.549634041324744, 56.42826064940422, 48.367625205747544, 53.61532895795761, 54.30278316620858, 57.09577352769914, 54.584421111691384, 54.17591802535519, 55.63176847273304, 54.66695170248709, 53.54884478353686, 51.79150135286393, 48.887256883805804, 52.240624504704634, 51.14201176551081, 50.806421618307795, 51.477452862647276, 56.553372490790586, 54.666963469597604, 54.66067591021138, 45.942741440188506, 41.53628410831575, 38.51651799294257, 37.05927510415354, 40.16814570273123, 41.41773439222767, 41.203937761245236, 46.36372943078318, 49.24480838160361, 51.97318553924561, 48.429932055934785, 53.2460456509744, 55.41859157623784, 51.18809569266535, 37.23722519413118, 49.471074227363836, 50.7021414849066, 52.609080191581484, 54.87319384851764, 57.412924612722094, 55.28422686361498, 53.82687414846113, 45.75444021532613, 41.277921507435465, 40.54428139040547, 40.81696064241471, 43.32846995322935, 49.620155672873224, 49.83222253860966, 54.74595216012771, 54.713651441758685, 56.3736730237161, 54.70879946985553, 51.498774866903986, 56.36001925314627, 54.5423536915933, 44.10465209714828, 44.92084241682484, 47.41922355467274, 48.83972167968751, 44.51918386643933, 45.19619280292142, 44.22554346822923, 46.89819943520331, 47.928527632067286, 47.45896893162882, 41.96226527613979, 41.81806718149493, 44.34770176487584, 53.04095275940434, 54.703186558138945, 56.868931093523585, 54.89850098086942, 55.515278000985425, 57.450485229492195, 60.77791813881167, 57.98710077039657, 60.696654473581624, 60.18668751562796, 61.58304345223212, 44.25970339005993, 27.608263377220403, 16.014482398186964, 12.779030050000838, 32.64629094831405, 16.431442114614672, 25.967237834007513, 10.06889485543774, 4.737816712548656, 1.5842179785813055, 0.21033008312506063, 1.3135826491540479, 12.09852235932504, 41.211515780418154, 51.23774113193635, 51.667448551424094, 43.394479520859264, 51.42278678955571, 64.83217408580165, 53.43627275959138, 13.271655228830154, 0.3082854559104289, 0.13767788967778608, 0.1317146153099114, 0.15545060858130455, 0.10551469175205117, 0.15360122636681603, 0.19027426898960145, 0.09990938728855503, 0.07729683897548145, 0.14964038325894266, 0.20046147638030593, 0.12255935133585047, 0.09054530306809372, 0.09147405444133667, 0.11191220773804574, 0.21824128925800326, 0.16583079352013527, 0.2825711937921663, 0.18597659234318042, 0.13748636769671596, 0.1410022056511333], [0.049603541922425075, 0.07135954264911913, 0.06329276704139288, 0.07074398334108054, 0.01654215953162601, 0.08581988122915069, 0.09571518613806657, 0.020687382765895417, 0.04016086091137221, 0.04220856030681922, 0.012547982022947362, 0.06592308396413442, 0.13847690406105212, 0.043279455463972785, 0.03378445830857081, 0.03346198125772419, 0.04213464431344502, 0.05341787837565907, 0.02224860100766584, 0.017850040157716122, 0.027873655217849923, 0.127308736405065, 2.3800714217847396, 23.042859838854884, 48.28884832320675, 50.50415985045895, 27.54736073555485, 20.471091155082952, 25.605526662641957, 27.969843149185184, 12.630337899731053, 0.8322742437162708, 0.047019883584711826, 0.7109447929166979, 5.099802449826272, 8.399963609633907, 8.555800357172567, 13.876023830906039, 18.914037673704087, 5.19099461455499, 20.32953085437898, 28.725630929393155, 39.808154490686235, 44.98810322053971, 51.1992391463249, 50.466756128495746, 48.30348268631966, 44.53268466457244, 39.40539375428231, 37.10257807085591, 35.75636571453464, 36.74686224229875, 38.79247634641586, 44.84546622922344, 49.24751481702251, 52.54035242142216, 49.68543567965108, 52.69255215121854, 47.59240404252083, 48.176182162377145, 46.944185303103545, 47.84672660212363, 45.70271199749362, 48.234947112298784, 50.254140130935184, 51.32702212179861, 50.735465941890595, 52.51802236803117, 51.13384146844187, 53.46002663335493, 51.32808508411531, 52.676113497826364, 48.914336927475475, 46.86656159739341, 37.656903113088305, 35.150053578038374, 34.33274930523288, 36.81842196372248, 39.04441802732406, 37.64462609444895, 36.21074092003607, 37.512779543476725, 38.366805045835434, 41.099335993489916, 43.63281842200987, 46.2508475395941, 48.102606342684844, 51.24713913086922, 31.003872963689993, 49.5013000119117, 48.09747588249945, 48.17466420512046, 50.14569836278116, 50.43589099760979, 51.331654440972116, 51.31522755469046, 42.355549566207394, 38.18532482270272, 36.9087423816804, 36.07874924136747, 35.294800804507354, 37.80542365966305, 40.25069590537779, 44.640330191581484, 48.14587793042583, 49.14062238508656, 53.63383077806043, 51.65325349377048, 52.60343590090352, 49.227059656573886, 44.63370138599027, 41.74085532465289, 42.23519163746988, 42.22140842868436, 42.90650921483194, 44.03456718690934, 49.99844474177207, 52.954284068076845, 52.46566264860092, 53.32927442366078, 47.370476338171194, 38.60284936043524, 34.26422549832252, 40.11956714814709, 42.01165968371976, 49.31921966614262, 50.8976794827369, 54.08555838369555, 51.87278462994484, 54.6900583851722, 52.3263910508925, 50.86731249286283, 51.306108044039824, 57.06653225806452, 45.13128934368011, 29.33516529298598, 18.44994087373057, 13.201307519789665, 6.023950615236837, 6.275863858961291, 9.665765416237617, 4.568781679676426, 0.32362667302931514, 0.27008451220970003, 0.11007090775115837, 0.5410842849842964, 10.178547655382465, 34.18846884081441, 40.15006357623685, 21.44095797692576, 27.841303156268214, 43.564541724420366, 54.436622281228345, 31.88034030698961, 5.907254709351448, 0.24886900949622356, 0.012343879920550653, 0.03938391369076506, 0.045688959033859354, 0.009864344423065984, 0.049695752095431096, 0.08051721213926231, 0.026132134352660468, 0.05798021541728128, 0.02890628428318568, 0.07927075644294101, 0.06449161037322014, 0.025861852787314885, 0.014249808999950127, 0.04102007448372822, 0.042083722449118094, 0.029881351417110815, 0.0471771959095232, 0.01806786193722679, 0.028088263258518233, 0.04078780811640524, 0.04216639482746682, 0.029503206587246353, 0.02863098675715587, 0.03388286613288426, 0.04903432327292619, 0.08184596866128907, 0.04948375258414496, 0.019014970692355308, 0.07184638386412014, 0.05535192096665983, 0.06199451997095059, 0.01908640456085484, 0.06532936582281705, 0.030134279175751635, 0.04308712526014255, 0.06370249001549617, 0.05402977195297999, 0.047120206628835974, 0.048157899535351226, 0.01313414749494123, 0.013806900054576897, 0.27671092760659033, 3.1321255958849386, 28.695477708693478, 54.009727201154156, 57.79934083261798, 34.42061039709276, 26.199020493415098, 30.984986751310288, 31.235730148130852, 14.465512921733243, 1.1504141337448552, 0.05671181513236896, 0.3580037961083074, 2.2386211925937287, 5.965925032092679, 8.664948151957605, 9.38856759378987, 9.473674201196241, 11.118770184055453, 17.07248095543154, 27.708209291581188, 40.792461518318426, 46.18004483561362, 51.91872735177317, 53.89035770970007, 50.66410626134565, 47.17740943354946, 41.62022675237348, 38.919345409639426, 37.86588307349913, 38.6724361296623, 41.15955222037531, 46.98120463278986, 50.772548029499674, 53.37680178303873, 49.61428388472527, 52.82376720059303, 51.037896371656856, 51.67038248431299, 49.418679206602036, 50.39057193263885, 48.484747179092906, 51.34656336999709, 51.261141992384395, 52.390945419188476, 53.14514267829157, 51.88601870690623, 51.450714065182595, 53.49601437968593, 53.02610266593195, 54.490013584013916, 50.8726155373358, 50.77783538449196, 40.60538799531999, 37.32154830809563, 36.349333947704686, 39.73629666912941, 40.12611358396469, 39.18650980918638, 37.57994621030746, 38.123645551743046, 40.292006308032626, 43.51930110685287, 46.45301434301561, 47.136734454862534, 50.96062175689205, 52.35523223876954, 33.85740903116042, 50.266209263955396, 48.70677294269685, 49.872242481477805, 51.57985025836576, 53.49568097822128, 52.677768738039084, 52.41413839401738, 43.26421368506647, 38.847589569707075, 39.114499015192834, 37.897207121695246, 37.931351354045255, 40.146443228567804, 43.75907559548655, 47.19753511490361, 50.09136569115424, 51.47689588608281, 53.60880605636105, 52.11968214281144, 53.3795827434909, 51.43362037597164, 45.62611987513881, 43.93229530703637, 44.46439619987242, 43.09936431146438, 43.087620735168464, 46.01520330675187, 52.12298085612636, 52.84146885718069, 55.61667519230997, 55.084123226904104, 49.182152440471036, 40.322479201901345, 38.49387022756761, 43.77953860067552, 46.458741003467196, 52.089244550274266, 55.010453270327666, 53.67196013850551, 53.99043306227654, 56.596879420741914, 55.2206648549726, 54.51053934712564, 55.387000806870006, 57.56914084957492, 48.23693575397615, 29.94720408993383, 17.855893988763135, 4.256321749379558, 11.981977954987558, 6.2276084096201005, 8.7538908373925, 3.5664251302519157, 2.0175795761808275, 0.4146897366210338, 0.11165097941674533, 0.7743304174753928, 10.034175015264942, 36.41239781533518, 44.131743907928474, 29.470302712532785, 33.34427279810752, 48.56544994538831, 60.199925514959524, 39.49625545932401, 7.967702236867721, 0.2460697395426612, 0.01615512616662008, 0.015239627156857283, 0.03524935248518183, 0.042478556504413005, 0.05442053808139698, 0.03454551686562839, 0.007941181717004867, 0.011356575489645044, 0.07577774790866722, 0.03520640942658629, 0.023987432904241067, 0.012785709639560553, 0.012716975273384203, 0.0712070145433949, 0.027096522220921133, 0.030560078504945964, 0.02737781630017825, 0.04684672856162633, 0.01161055853440156, 0.04583089597403042, 0.1394946978337342, 0.10661376745349939, 0.18078490641088257, 0.1441742080233751, 0.0871491127256905, 0.1363168272279924, 0.3337774299565823, 0.08970606906880295, 0.11729857193366175, 0.15248145096965376, 0.1271939074860946, 0.11169447022820674, 0.17149894017606013, 0.1195511845270953, 0.12205043912775095, 0.21074134976633135, 0.10669403048532625, 0.1408006479182551, 0.11873256595384692, 0.09178181494315786, 0.1094239464991035, 0.3946842391404414, 4.946349522759838, 36.77695074389058, 61.718365223177024, 64.13614949872418, 39.08556761280183, 31.58945929619574, 37.14002101652084, 39.00852049550703, 17.33892167768171, 1.6523364330491714, 0.24739585306134917, 1.2417141636533122, 7.401772372184261, 17.649259605715354, 16.979022641335767, 22.64177787688471, 27.91771092722493, 11.932027551435656, 26.68572779624693, 32.78832781699396, 41.53533489473405, 48.14509737876154, 54.13627463002359, 55.51397969645839, 53.19319171290244, 49.60288939937469, 44.363081378321496, 40.614417291456654, 39.66131271854524, 39.796650178970836, 43.8460776882787, 48.43507036086052, 52.659121790239894, 54.495544125956876, 49.126525386687256, 55.982781379453606, 51.58682423253214, 52.879135377945445, 52.54034849905199, 52.80252364373977, 51.54223080604307, 53.373032385303134, 53.53873291323262, 56.184579480078916, 53.54855845051428, 52.68553503098027, 52.85755449725736, 54.42233700906077, 54.91921501774942, 57.698226051945845, 52.22700603546635, 51.61637929178054, 41.17085649121193, 38.6498236656189, 38.45933375820037, 41.75253614302605, 43.03799490774832, 41.476511109259825, 39.66254042040917, 40.493502386154674, 42.3912117558141, 46.080448012198175, 48.635883946572584, 50.44219816884687, 52.3091757682062, 55.45390075252902, 38.789777755737305, 49.91405886988486, 51.54643950923797, 53.083608535028276, 53.344132361873505, 55.07221883343112, 54.60966548612041, 55.466852418838016, 45.938536659363784, 41.60231721016669, 40.23837966303672, 39.41068110927459, 39.27030340317757, 42.58357263380482, 44.34794495182653, 49.801110298402854, 53.293569087982185, 54.081949803137014, 55.96608384963005, 53.440524608858176, 56.804266898862785, 53.59866280709544, 48.130561074902936, 46.70512076347105, 47.1731379724318, 47.317363523667865, 47.00220108032227, 48.72416865441107, 54.242135478604226, 56.960569427859404, 57.808887881617395, 59.69639124408845, 53.39467994628414, 44.352553736779, 39.17310707030758, 45.329314124199655, 46.51199502329673, 54.91071524158601, 55.75705289840699, 57.51986411310012, 56.990093108146425, 59.74431868522399, 56.96727668085406, 56.6863133830409, 57.220826533532914, 61.48614521949523, 49.84300513421336, 33.04389769031156, 20.277990910314745, 22.753106509485555, 14.06490360536883, 12.459565747168757, 18.282698854323357, 10.555064793555967, 4.749678940542283, 0.5713035118195319, 0.2651469529636445, 1.0293099740820548, 12.482574370599563, 43.5694250752849, 51.432651550539084, 33.424912806480165, 38.66951396388393, 58.678022353879875, 67.7209291150493, 46.22003339952039, 10.918271368549718, 0.44278233402198364, 0.09563485415832651, 0.23397422245433255, 0.13401552974697084, 0.09825848313348909, 0.21339369937777522, 0.1961975535678287, 0.14534192520283884, 0.15362522024060452, 0.2036731008199915, 0.2038592295420747, 0.11192772867939166, 0.17686307250011354, 0.0817419569038095, 0.14118340076698413, 0.22289228565510244, 0.06802430226197166, 0.08395425795066742, 0.1374626802580972, 0.13525711312409372, 0.1475187793614403], [0.04914769662484046, 0.02145837748333091, 0.03503965889854777, 0.03787043421799618, 0.08636863000931279, 0.04158379645237038, 0.040550811156149835, 0.05728147045198468, 0.043046189351908626, 0.022454326258852117, 0.012584307039487026, 0.015741141828437968, 0.03636989780070801, 0.021911972397637945, 0.025531025378093607, 0.038166071378415635, 0.03476769385498858, 0.03914934522922962, 0.02961768310577158, 0.09389986419269154, 0.057137633613761396, 0.06712968776663465, 2.649815024868135, 20.786157500359323, 45.25678557734336, 43.86921182755501, 31.944345543461463, 33.0459883136134, 22.916255535617953, 28.925230541536887, 12.46829007902453, 1.8356373713862513, 0.058114886013490547, 0.6333487889459056, 3.057354433882621, 2.2100212304822864, 6.915010156170015, 7.913147461029792, 8.799284427396714, 14.427169792113768, 18.21463200353807, 27.54640563841789, 42.53368008521296, 48.800682329362445, 52.57173138280069, 48.78702071405227, 47.403400713397616, 45.57909850151309, 41.07194608257663, 36.917269614435014, 37.883353310246626, 38.50851243542087, 43.81589112743255, 46.017925431651456, 51.08550610080842, 52.6681746205976, 52.16040418994043, 49.94466904670962, 43.97732411661456, 43.729916695625555, 42.39941735421458, 43.34133924976472, 44.508134549663914, 45.85188365751698, 47.62803093079598, 48.10324176665276, 47.859160515569876, 50.38435105354556, 51.13877581011865, 51.8166829693702, 51.429458741218816, 50.613342946575536, 47.91845498546478, 39.52123703495149, 35.27413383606942, 35.94572990171371, 36.434445458073775, 36.15709858555948, 35.948950167625185, 37.57381554572813, 35.571386737208215, 35.64704533546202, 34.274851199119325, 36.38998931454074, 42.86314349020682, 48.29965445303148, 49.05402429642216, 51.58580049391716, 31.289284229278568, 48.60596018452799, 48.91026158486643, 51.88994107707855, 52.696145042296386, 49.68026599576397, 50.70511464149722, 47.103304093883885, 41.613201787394864, 37.5713405301494, 38.79219393576346, 36.16126022031231, 38.19416976744129, 37.89004879613077, 37.6327177786058, 39.92838298120807, 46.053116936837476, 49.34880218198223, 50.62864019024757, 51.11139766631588, 52.55193125817084, 52.5088793231595, 52.157791891405665, 48.61288709025229, 45.96802896068942, 48.34880567366078, 49.50249633481426, 49.57398937594507, 52.31811092745874, 51.546129641994355, 52.23171287967313, 51.46262630339592, 54.20678707861132, 48.58345754684941, 38.83888190792453, 35.99573619904057, 39.5479287639741, 39.54515564826227, 44.92365867860856, 46.67449489716561, 49.59254218686012, 49.38894764069588, 51.06140313609954, 48.42231873543032, 51.64603241028325, 53.961250628194506, 49.04288476513278, 34.86739189394059, 27.434798517534812, 1.3117828941152943, 9.319921212811625, 6.8051264266813964, 4.362254181215841, 4.138883044642787, 1.1264328850853829, 0.4793449220878463, 0.004106462058130532, 0.972571234789587, 10.848131545128362, 31.85903399221359, 38.65699768066406, 37.54059699273879, 29.58650096770256, 45.375327448691095, 49.8289159805544, 38.969998898044715, 4.773735327105369, 0.26130447044007243, 0.0585678584813591, 0.048236358430116415, 0.06001270030655208, 0.03194057085971919, 0.043148688085737734, 0.03758270691539492, 0.04580900118115448, 0.06004266200527068, 0.08238846616398904, 0.03602346901090876, 0.048692383758363225, 0.08506788932267698, 0.037080708650812026, 0.04951273369032049, 0.07957421919150699, 0.05532537985052313, 0.038120320607577605, 0.01066283020566428, 0.04468173727453236, 0.03703292008609541, 0.021980068038007426, 0.04021640994676179, 0.02604546108012719, 0.014875349476032201, 0.07570559774795849, 0.0841398504112036, 0.0656533520668745, 0.03258032513962638, 0.024285858624704906, 0.05232079833325359, 0.04306641024267001, 0.006557063372325033, 0.07362935391645278, 0.06210599725525226, 0.04715330545760451, 0.021717443521465027, 0.06121156662101708, 0.05003618241678323, 0.019637369250337926, 0.031734307431766105, 0.0650681451623959, 0.05838266438654354, 3.5202294155474636, 26.155692031306607, 52.01121684043638, 49.76214155074089, 35.90143457535775, 36.93881911616172, 26.011023252241074, 33.08103861347322, 15.384552690290636, 1.8911440574353742, 0.11534509369202199, 0.2699383732772643, 3.1947283398720527, 5.954440332228138, 9.95122963382352, 13.771427946705973, 15.693268718258029, 13.88744479225528, 14.450286280724312, 27.819230018123505, 40.71039768957323, 49.20710655950731, 55.38032885520689, 50.74151815906648, 49.82326384513609, 46.868365887672674, 42.81891876651395, 39.3612317885122, 39.6388336150877, 40.37407013677782, 44.99585774637038, 48.885315310570505, 52.76138974774269, 53.24749300556799, 53.709210888032, 52.074610187161355, 47.01773758857481, 46.28720791109147, 45.55141441283688, 45.2616689282079, 46.095604050544004, 48.22618453733383, 48.68932624017039, 50.65095847652805, 49.728158135567945, 52.67467398797312, 52.525196383076334, 52.96440378312142, 53.61854530149891, 51.877393414897305, 50.665616373861994, 41.710629540105025, 36.88261939633277, 37.62359826795517, 37.01055142187303, 36.84444688981579, 39.28623607081752, 38.35828958019134, 37.00350684504355, 37.71560530508719, 36.733282996762185, 37.820246296544234, 44.423183856471894, 49.66771048884238, 50.92156671708631, 54.016097130314, 33.34122119411346, 49.493576865042414, 49.32115339463758, 53.81294581197924, 53.362512588500984, 51.75906335153888, 53.94711048372331, 50.77867477170883, 42.87114120298817, 39.1743936077241, 38.59060372075727, 38.11525167957429, 38.77682608942832, 39.316756033128314, 37.94516201942198, 42.51345242223432, 47.6901416624746, 50.37012069456039, 52.86171613201019, 50.709719504079516, 53.5012036754239, 54.39819482065017, 53.183625052052165, 49.41499217864006, 46.3423329014932, 50.5951274594953, 51.73597628070463, 51.034644726784, 54.89992480124197, 53.29067045642484, 53.87570373473629, 53.91191505616712, 56.60480260849, 49.68051310508482, 40.13447607717207, 38.44868060081236, 41.43667159541961, 42.450266961128484, 46.63215291115546, 50.12007744081559, 52.94021844863892, 52.617277945241625, 53.09934508415961, 50.852882092998875, 54.92128995157058, 57.957463341374556, 50.86979143081173, 32.62427664572193, 24.155783345622403, 6.224040033355837, 6.763392408047953, 6.491377997782923, 7.775016292448967, 7.7135488294786025, 1.1038500839664092, 0.603945353819478, 0.12795068744209506, 0.9640015914074838, 12.146777318369958, 35.51938787583382, 47.11968391172348, 36.88759296171127, 36.17379219301286, 54.17624358207949, 59.12397230825117, 43.43237746146418, 7.304563291611211, 0.21903731589836462, 0.028509542668959307, 0.08332557555648588, 0.02208485354429051, 0.017152394528590867, 0.04111465186842027, 0.037269265871615186, 0.05249802894409626, 0.04216767036386075, 0.06914863588228341, 0.019912230106250896, 0.01924168292222725, 0.08778972310885307, 0.025731663805462664, 0.05344879385384341, 0.022260034869935726, 0.10822468181891788, 0.021453418979241003, 0.022144723315573028, 0.020899874488672903, 0.05956435500974617, 0.13083949775224732, 0.15649316231569937, 0.13468418660904133, 0.07917245204049735, 0.1873853514271398, 0.17240571248675549, 0.2079378969727024, 0.15368977080910437, 0.08845472573152474, 0.17542192321871558, 0.1553945615887642, 0.12818140248137136, 0.20682460267937955, 0.12692928539528964, 0.19532324806336435, 0.09527146035144407, 0.1452046422468078, 0.15499100179201172, 0.09511419782234777, 0.14322473397178037, 0.18968484094066007, 0.20840321877791038, 4.877447207127848, 32.81724156871919, 60.48934152049404, 56.45056324620401, 42.85474177329771, 44.0376187909034, 33.567004588342485, 39.36054929610222, 17.076928923206946, 2.628793081929607, 0.23125162258023219, 1.5460759930072294, 6.615350390634229, 7.351472877687024, 17.629153536212062, 18.541157553272864, 17.642011065636915, 23.03231062427644, 23.701708201439153, 31.54580919973312, 44.20351543734151, 51.23570934418709, 57.75851680386452, 53.506369436940844, 51.3257630409733, 49.29848993978193, 45.341775494237105, 41.30968878346105, 42.1937321847485, 42.04923598997055, 47.99833405402399, 50.91329051602272, 54.49100986603768, 54.442415621972856, 55.54619020031345, 54.862929005776685, 48.036785048823205, 49.0132002676687, 48.25206433573077, 47.55067786862774, 49.070992469787605, 51.43325167317545, 51.466254495805316, 53.89961450330673, 51.75623924501481, 56.87148847887593, 55.57188956968246, 57.86219681462934, 57.201214682671335, 55.471045432552216, 52.466968797868304, 43.9151623941237, 38.636491529403195, 38.90309895238569, 40.27696794079196, 39.49472181258663, 41.089228045555856, 41.3501754883797, 38.20507003415016, 39.965559205701275, 38.767843861733716, 39.191997205057454, 47.761285612660075, 52.38519914688603, 52.11630890446325, 55.82358806363998, 37.17917019321073, 50.49245942023493, 52.52678102062595, 54.95841910762172, 55.25937864857336, 53.18031457162673, 56.59267463991719, 52.230265525079545, 45.87883818534113, 41.89111740358415, 40.89949515558059, 38.382690645033314, 41.12813795766523, 42.0607050003544, 40.05912734616188, 43.454507473976385, 50.14935401178176, 53.95612409037929, 55.03013180148218, 51.80179365219609, 53.162891403321304, 57.82052947628883, 55.9949524940983, 52.94693354637393, 50.35466263371129, 53.71336467804448, 54.046577868923066, 53.59335976262247, 55.539506481539824, 54.58217751595282, 54.379712612398215, 54.546907563363355, 60.04783561152797, 54.52866461969192, 42.605267263227894, 42.03400934896162, 43.871616240470644, 44.89070292442076, 48.32058029790079, 51.99124805388912, 55.376947772118356, 54.29109842546525, 56.83539090618011, 53.24816765323762, 58.19355080204626, 61.768265616509225, 55.36318025281353, 37.747380425853116, 33.10936989322786, 5.122451686090039, 15.164879368197534, 15.146639366303722, 12.754375992282746, 13.549318832735862, 3.1395114189194095, 1.3237667155842627, 0.22125184626108219, 1.6723803575000458, 14.390378940489985, 40.40956366446711, 52.09174702244421, 50.40505332331504, 44.01326087213332, 60.51456236070203, 65.0320972934846, 53.13177916311449, 8.827956953356344, 0.38913650618445494, 0.10291123387193489, 0.12331461443776086, 0.11281018535937033, 0.17605034514300286, 0.08480439338112071, 0.16719659039330098, 0.08064401501248922, 0.1745480007582134, 0.2276640481525852, 0.16847727489807915, 0.14144111274471208, 0.20470089970096467, 0.11876979782696694, 0.18168870630043168, 0.12405844750784098, 0.24453518882153497, 0.13700353312155894, 0.10897053736111811, 0.17835273046887692, 0.21780104917143622], [0.02093837423730762, 0.05835603517029555, 0.12580265351120504, 0.06318416258680724, 0.03166423528455198, 0.027360322682427305, 0.011440038853775591, 0.025174827052039966, 0.03670916749885486, 0.026919444827663324, 0.047907488375541665, 0.08980001443095746, 0.03513520538446403, 0.029106296433676637, 0.06950741017898245, 0.06091322900066453, 0.019971406567961942, 0.01579178024023291, 0.05717407641631942, 0.012380426144978453, 0.03065991891367782, 0.02413171024302081, 1.7145134772985213, 16.34798192208813, 40.59731183513519, 48.06521438783216, 36.82241885892807, 26.067228855625277, 27.223392571172408, 26.875188081495224, 16.80881727126337, 1.9526275776086317, 0.12035507122955977, 0.040424261091937946, 1.301882341504097, 5.2590403826006, 7.905088461214497, 8.192478072258735, 10.950952556825454, 11.87758211166628, 10.693295982576187, 29.26225627622297, 40.767985928443174, 49.435098248143355, 49.879067405577636, 48.62474441528321, 44.973661053565245, 39.27468861303022, 37.78836134941348, 38.3581248406441, 40.505108679494555, 47.15262397643059, 45.878775427418375, 51.05345641413043, 49.91577294565017, 51.25464654737904, 51.34859908011652, 44.29477722414079, 42.16873491964033, 39.98662625589679, 39.39920425415039, 40.052961380251, 38.113729799947436, 39.6211515703509, 41.02851367765858, 41.31294827307425, 44.475202329697154, 45.742406383637466, 46.03012792525753, 47.2285649853368, 45.436179099544404, 45.45828950020575, 40.683549065743726, 35.4640353879621, 36.45945449029246, 36.11085384122787, 35.59772545291532, 37.30361915403797, 38.46914752837151, 37.792915221183534, 38.62266125217561, 38.73515875108781, 39.096044263532086, 41.42084090940414, 44.43152673782841, 44.827344879027336, 48.98969350322601, 50.514785551255756, 30.412246181118874, 49.1727779757592, 53.692211335705174, 48.53214902262534, 48.10901157317623, 49.54203774852138, 46.03759219569545, 42.175944236017045, 38.85289261418004, 37.352648781191924, 39.820384440883515, 38.868950797665505, 40.22521618873843, 36.59200314552554, 38.78288222897438, 38.03351732992357, 44.78723864401541, 49.29964703898276, 51.84805800837856, 54.26422626741471, 49.347260690504505, 49.972470806490996, 53.58955114118515, 51.93821368678924, 52.683707206479966, 49.74081170174384, 53.69398424702307, 52.68031043391074, 52.62964517839494, 51.738172808001124, 52.3894392290423, 51.964874036850475, 54.40661614941013, 51.6809924956291, 48.280297556231105, 36.78907871246338, 36.7494470842423, 37.462757556669175, 38.80752255839687, 39.22653759679487, 42.109554198480424, 41.72028641546927, 47.707729570327274, 48.815606947868105, 53.0391170901637, 54.05104544854934, 52.184464008577415, 33.175226488421046, 20.05251738332933, 4.566240474101036, 10.750546897611311, 2.981838021547564, 7.171756250243034, 3.103417768593758, 1.0777474459140532, 0.5624613862845206, 0.0824464820024948, 0.6657105492007348, 9.303153080324973, 39.01778905622421, 42.61605770357194, 27.143344840695782, 28.37103101515001, 42.69480320715135, 50.578735874545195, 37.57153664865802, 1.990169930842615, 0.1050665686207433, 0.019024797685204015, 0.06881591623588916, 0.035804375525443785, 0.07549984951413448, 0.06475812470119807, 0.055781301756900166, 0.03184619457310727, 0.023142351738868222, 0.08486735048673807, 0.034987997759373925, 0.013023193065647878, 0.052821904105404695, 0.014221236793204181, 0.08998505530818816, 0.044384510481670025, 0.044597996203529264, 0.04389245220790467, 0.05209348855480071, 0.03631578518017646, 0.029844759227407557, 0.044107370514182315, 0.04640817386849273, 0.016220356638152755, 0.021279398276801073, 0.03506394771618709, 0.024418608255444035, 0.083680281926307, 0.0077312142539378865, 0.045919195268182986, 0.030192586127668623, 0.03531502154205115, 0.024296221879100608, 0.023556956608269005, 0.005687296460007108, 0.08224009025481441, 0.10081602936430324, 0.04087162962664039, 0.023842939145622716, 0.02721956168722001, 0.0872184130393209, 0.04218348624905752, 0.014459357029878566, 2.524320262093698, 21.282033343468946, 48.148745183021795, 53.46092485612439, 43.16523659613825, 30.410602708016675, 32.1202971858363, 32.8799210440728, 18.51238892924401, 3.2199484446356377, 0.03913285518665949, 0.19666955565973637, 1.286544280667459, 2.809003192570902, 8.38316802055605, 9.344144790403305, 8.719872120888002, 10.319129324728443, 16.145835711110024, 26.632120763101888, 39.38253418091805, 51.597151833195845, 52.8553815041819, 51.10497282397363, 48.378854951550885, 43.33019971847535, 39.833308650601296, 40.0663641191298, 43.19338744686496, 48.868449118829545, 48.20460365664575, 52.24766123679377, 50.47638554726878, 51.95787652846306, 52.88032385610765, 46.86046231177546, 44.97053100216774, 43.09918388243645, 41.643717827335486, 42.00345016294911, 40.93205475038098, 42.909360777947214, 44.24327258140811, 45.55022985704484, 46.856896877288825, 47.85629718534408, 48.919828245716715, 48.78516151059059, 48.15409921830701, 47.67372654330346, 43.002834781523674, 37.817802659926876, 37.380552522597775, 37.027978512548636, 38.42013359069824, 38.70841210888278, 38.01420357919509, 38.69776679623512, 39.78974288509738, 39.71333903651084, 41.12919699761176, 42.88166492216049, 46.60255470583516, 46.979612150499904, 51.32180929183961, 52.54503965377808, 32.09936937978191, 49.45193698329311, 56.039977381306315, 50.70039210780975, 51.3359219797196, 51.24752744551628, 49.68188593464513, 45.26381054232198, 40.57341283367526, 39.326993419278054, 40.852654210982784, 40.38385252798758, 41.28852759638141, 38.11999382511262, 41.37395289636428, 39.68310148485246, 47.19500126377229, 51.37234510913972, 54.81695490498697, 53.633587591109745, 50.048906034038914, 50.82886934280396, 55.54508016955469, 55.160001477887555, 55.510837877950365, 51.795404111185384, 56.44000030332997, 53.1414831069208, 55.72571316073018, 51.65799171693864, 52.16259679486675, 53.081466920914195, 56.53267022102111, 55.461094379425056, 51.193579166166245, 38.59417307761408, 39.540856730553415, 38.751499345225675, 42.54506672582319, 42.279788986329116, 45.318453081192516, 47.15913118854646, 49.84345620678317, 52.024513675320534, 53.858347246723795, 57.02044833090998, 51.700145429180516, 34.012632908359656, 25.756777178856638, 10.345484710508778, 11.33022221826738, 6.522692730349879, 8.356002665335133, 4.890852887784281, 1.8000364688134964, 0.8687314487272694, 0.058342988692945054, 0.8995509207729371, 10.403663266089655, 40.63474693605977, 43.4157976027458, 32.17765596605117, 34.21023407290059, 48.598154667885076, 58.67254672511932, 43.42470530540713, 3.3215103755074167, 0.19316294140392737, 0.053025913319640586, 0.04238459199006039, 0.04098202672696883, 0.12136989258109562, 0.03784850878160327, 0.04871040980722155, 0.10271383599648554, 0.026755038528673114, 0.059544995967899604, 0.03510056288852807, 0.050540275931839025, 0.012559569102802105, 0.047641146417346694, 0.04557705657075971, 0.04959655137011602, 0.010733690465830508, 0.030995086210990147, 0.05165152860084369, 0.04911556306685652, 0.019139666823790442, 0.19015097479906776, 0.12688014085494703, 0.24420521943078888, 0.22086815878508553, 0.09780161893896519, 0.1471628395900611, 0.15598285582757768, 0.12012824025605956, 0.1299134506693771, 0.1829035225654802, 0.1604590769256315, 0.21062436814029373, 0.15065779398766257, 0.12315081717867045, 0.18069656115145455, 0.086023430790632, 0.08531678362839645, 0.09400435092468416, 0.17349292914713585, 0.18973065299853203, 0.10569843027981059, 0.10228618273451444, 3.6005056240866264, 26.38381708052851, 56.191694659571496, 59.9724986476283, 49.482488324565274, 37.275880152179354, 39.240344339801425, 38.694664201428814, 23.276370302323375, 4.047974026010883, 0.3215846197018701, 0.2654341133611818, 3.582783865351831, 9.581693333964195, 14.696658195987826, 16.52238815061508, 20.369262503039455, 19.40346514025042, 12.541158891493275, 32.239074399394376, 45.64016980509604, 52.279224549570394, 54.922847132528986, 52.71296808796545, 50.09337394468246, 43.93887312181535, 42.28881828246578, 43.044906123991936, 44.906180597120716, 51.343033236842004, 51.24676258333268, 54.127339470771055, 50.36398218524072, 53.773769178698146, 55.53566255877095, 50.02023743044946, 47.587673664093025, 43.70927718377883, 44.292874874607215, 45.2895373682822, 42.48694504460981, 43.66790794557141, 45.12561759641094, 46.784195746144945, 48.59552275749945, 50.64972292992377, 51.71608986393098, 50.77723133948542, 50.75534843629407, 50.54093207082441, 44.18955179952806, 38.30161133120137, 40.269597807238185, 39.26693016482938, 39.095299013199345, 40.00392783072687, 40.471344917051255, 42.02065367852488, 41.642580339985514, 43.70669234183527, 42.38338662732033, 46.351405343701764, 50.59246809251847, 50.80118917649793, 54.137835733352176, 55.318649584247225, 36.31714305570049, 50.758694218051055, 57.942224933255105, 51.37655773470479, 52.73735738569691, 54.05074734841624, 51.382304007007235, 46.52075759826168, 41.613221399245724, 42.058743815268244, 41.12325852917087, 42.643949677867276, 43.454899710993615, 39.627788220682454, 42.32406862320439, 41.74335387445266, 49.83623512329594, 54.048111515660445, 56.402420074709006, 56.26331713891799, 49.84467606390677, 51.814404072300086, 57.584249819478686, 56.186238642661806, 57.52155857701456, 54.08459740300333, 58.506555941797075, 55.52694705224807, 56.707855040027255, 51.811426993339296, 51.943873666947894, 52.11290820952385, 56.57666744724397, 57.25352341128934, 54.6787384248549, 41.008580192442864, 42.709112013539965, 41.69733662759104, 43.58660505663964, 43.12334176032774, 47.06920692997594, 48.19111854799333, 52.715313665328495, 54.565895757367535, 58.008520833907596, 60.94820783984277, 55.55010472574542, 37.19421248282156, 25.912167756788193, 7.817018993439214, 19.650021406912035, 10.639372218039728, 17.699867986863662, 7.59372728486215, 3.4381143508418917, 1.5327304962181276, 0.17435764323078817, 1.0879733101014168, 11.918844465286503, 48.01702414789508, 53.37467585840533, 39.96360586535546, 41.1714134677764, 58.99241601267169, 66.88483668911842, 49.3596593026192, 5.586633307318534, 0.3593982599915997, 0.10400857821467424, 0.15640259540129095, 0.15824643113920767, 0.30699423003581267, 0.14093603097623394, 0.1657429232352203, 0.20235207412512074, 0.0884268171484432, 0.2816825318000009, 0.1493764812907865, 0.1326334611662934, 0.1833588239406386, 0.1413818022176143, 0.2669591492702884, 0.11335171759128572, 0.103370534226058, 0.14411502007034518, 0.1616314365979164, 0.17652383344548364, 0.09896739025510128], [0.10139009735036282, 0.01896467127446686, 0.0855392172572113, 0.04301812372080261, 0.006757205278958164, 0.05960295051937142, 0.07423054141503188, 0.05323963269831673, 0.03555598683775433, 0.1038647681895283, 0.03679426837592356, 0.013958346061108094, 0.06678280315452045, 0.10486493427907267, 0.051680812311749307, 0.034459335804586454, 0.06482184789473973, 0.016432725786862355, 0.05836161612082393, 0.03942037181508157, 0.004514962643189657, 0.02516057015576911, 0.7943471304831967, 14.357340816528568, 39.035086708684126, 48.68365057053105, 39.888649371362504, 31.541371037883145, 20.917466686617946, 34.804975217388524, 18.918101249202607, 3.9189834508203694, 0.1177965367453233, 0.24590447905563542, 2.5569266801880253, 3.7478901542002157, 7.397397948849586, 13.723777032667591, 13.928584571807617, 7.731164684218745, 21.613538342137492, 22.054146028334095, 34.16637805200393, 53.04611459855111, 50.44241782157652, 46.56007543686898, 45.04959814010128, 40.918491194325114, 39.18275610093148, 41.439232903142134, 46.01233997652608, 47.590458546915364, 48.05964854455764, 52.14644839686733, 49.16188555379068, 52.892714623482, 49.711829308540594, 44.359676761011926, 42.47195374581122, 39.62912967128139, 35.98916622900194, 35.415103820062455, 35.310847220882295, 35.61285795704011, 35.22644173714423, 35.783222183104485, 36.83688456012357, 37.43721900447723, 36.04016880835257, 37.66245326688213, 35.81348326898391, 35.979415216753566, 36.353954499767674, 36.85790454187701, 35.32979226881458, 37.575000101520175, 36.23340437489171, 36.30561128739388, 39.53528696490873, 43.49324480179818, 42.7926428087296, 43.49213084866924, 43.53787352961879, 49.248617003040934, 48.889253370223514, 52.12908014174431, 51.31785946507608, 51.71881198883057, 30.389427792641428, 50.07940246212868, 54.4776894969325, 46.98047507193781, 45.874013670029186, 42.47610361345353, 42.42289273969589, 38.723062161476385, 38.229722130683164, 36.90090548607611, 38.51678079174411, 36.69243151141752, 36.40056402452531, 37.24419132355721, 36.91213130950928, 36.65492580782983, 41.39663204070061, 49.500382177291385, 50.381291604811146, 51.84797956097511, 53.35597399742373, 51.059634147151826, 51.18563636656731, 50.888053986334036, 50.83332123294954, 50.59488427254462, 52.3028842864498, 52.8607512289478, 51.760349888955396, 53.42885555759553, 49.66269377739199, 48.72509825614191, 51.19390864526072, 53.26401402873378, 52.06474150380781, 47.59367489045667, 38.186525067975445, 35.286081375614295, 37.57246625038886, 38.53954622822423, 40.71774821127615, 45.11922021065989, 47.675424929588075, 51.73968292051747, 53.621232125066946, 56.463291337413175, 51.6400037273284, 35.91409206390381, 28.171672628771876, 15.845784198853279, 2.812269546331898, 4.894612969890718, 7.028378911556737, 7.999299870383355, 0.8014697869939189, 0.6580918967243164, 0.39241821234745367, 0.6748087932505916, 11.338273863638602, 33.45444433150753, 55.20343388280561, 41.42589292218609, 34.53452387163716, 44.24193505317935, 46.782203182097405, 37.447279883969216, 5.483934379393055, 0.1491982432743234, 0.061094450929592696, 0.029260770402728554, 0.023055362455066175, 0.03610953898920167, 0.09304784418594453, 0.0370439594130843, 0.0792391476551852, 0.042060460189297315, 0.05454651357966566, 0.03770024778561727, 0.09299349790859608, 0.012687372678380101, 0.020955871685498187, 0.08380280236803717, 0.03875578671032864, 0.038584562228812326, 0.07091950174541244, 0.044140212703496225, 0.041962695878840266, 0.023791536561123306, 0.012313868426116965, 0.027553916931332603, 0.10864785346653193, 0.03407158040171189, 0.019322250474004016, 0.03734204805486145, 0.0419000796823492, 0.08913763948986608, 0.03974019054083094, 0.03939290756299611, 0.01317228813986144, 0.06926186367749207, 0.09087930208132153, 0.07263315616235619, 0.0612214491552403, 0.0677227394114579, 0.046054551513084484, 0.07191997427012652, 0.06345084545412852, 0.031437923335620475, 0.03555031395667503, 0.027695708314798055, 1.4028600843683368, 17.351410504310362, 46.49295191611014, 53.93835183112852, 43.81942126058763, 37.850146524367794, 27.23998615818639, 39.87494853235061, 22.456651810676824, 3.8554766005085366, 0.18318864516913894, 0.15137790131472773, 1.1900148733008293, 4.636663198471069, 6.708942555612134, 11.208349274050805, 11.26363802340723, 8.325655287311923, 15.98282789030383, 24.455509301154848, 39.33059023272607, 53.92159154338222, 51.97978688824562, 48.524880870696045, 47.5852535616967, 43.64715076261952, 41.199854573895855, 43.145510996541674, 47.43419916399064, 49.616856959558305, 50.72446761592742, 53.7433982664539, 49.793053750068914, 52.40053953662996, 51.844802441135535, 46.8389206547891, 43.50370576304775, 41.006524870472575, 37.90820544765842, 37.67862912147276, 38.17171027583461, 37.814896183629195, 38.085669163734686, 38.56494749746015, 37.87541051064768, 39.952705598646595, 39.04793247099846, 39.88951229280041, 40.13148330873059, 38.30384315982942, 37.69784481294694, 37.34729082353654, 36.33345227087698, 38.01655700129848, 37.117745876312256, 37.518933742277085, 41.279329638327326, 44.40857694995019, 44.499717143274125, 45.7244066269167, 45.29491493778844, 49.07164750560638, 51.93502087746897, 54.6927648205911, 53.01084072359147, 53.924921635658514, 32.29458770444317, 50.795454671306, 56.887542739991225, 49.03132554023497, 48.336120728523504, 45.25265532155191, 44.60567605110907, 40.14120294201759, 39.559805700855875, 37.97632132807086, 40.16866737796415, 38.125783243486964, 37.57522759899017, 37.66092354251493, 39.2565280391324, 37.936434745788574, 43.226680524887584, 50.985183638911096, 53.72919536405995, 55.10624931704614, 53.99011142792241, 51.13301777070569, 52.84787016530191, 51.95456212566745, 50.629405052431174, 52.536465352581395, 52.43770399401265, 53.82230850958056, 52.81658534080752, 53.53106860191592, 50.349877342101074, 48.47285063036027, 52.560721289727, 55.84906778027935, 55.24108863645985, 48.70331341220487, 40.157296426834606, 37.06338182572396, 39.62416002827306, 41.46191989221881, 42.825512270773615, 46.38260779842254, 50.55486432967648, 53.95133095402872, 56.06134253163492, 57.15469537242767, 53.511237098324685, 35.66476268153037, 22.426120081255515, 6.299913871672846, 5.865948719363059, 9.61145627883173, 9.64103683348625, 8.253038487126751, 1.1394725595751116, 0.8502438472163293, 0.2004171045677316, 0.9252369295685523, 11.705577354277334, 40.352199000696984, 58.800286554521136, 43.65742345010081, 38.33056626781341, 52.261252249440844, 55.285846802496145, 43.66845315502536, 7.158533450095885, 0.15516845839879206, 0.03338944422261369, 0.06852692488821284, 0.07264835534677391, 0.0028370107963470925, 0.061358322254231865, 0.027528275968506936, 0.040588219229492455, 0.02237735165944023, 0.06247423656825578, 0.023617722702422933, 0.03893992360380869, 0.040387982998283646, 0.014985486106466384, 0.11316476149424431, 0.057954834924349864, 0.05529970058330125, 0.0984501276886271, 0.04293263213889253, 0.05918288152785071, 0.03669007658778179, 0.22774672436137355, 0.08072095322272471, 0.25906706469193586, 0.1703796703969279, 0.07175048497775871, 0.23456075469092016, 0.12329977531466754, 0.21789088064143736, 0.14776386621017612, 0.13526840526009762, 0.08124134908880919, 0.21736016557101281, 0.1982170839102999, 0.20874233525847236, 0.2650591899310389, 0.17537557489929662, 0.1787904424652938, 0.13042816982394265, 0.23998595954429722, 0.0774513359271711, 0.09832432072970176, 0.14849529631676214, 1.7614619193538543, 21.47578077931558, 51.93575828306137, 61.87220058133526, 50.130381507258264, 43.86955307376, 32.69842709264448, 48.27709297980032, 26.24327071251408, 5.283202673158338, 0.40024291183198657, 0.3793662191639024, 5.392537270822833, 10.306181580789628, 13.598504374104163, 24.07830672879373, 27.15740457657845, 13.163809660942325, 25.117574007280414, 25.788605251619895, 38.31013464158581, 57.22335646229406, 54.37806521692584, 51.790677655127745, 49.9502113557631, 45.64834402453515, 44.38241866327102, 45.630681591649214, 50.60951863565753, 51.897879954307314, 52.856840625886, 54.85977934252832, 50.232280761964866, 53.80348113275344, 55.2612574638859, 50.442335451802904, 46.700174654683764, 44.37611933677427, 39.78646378363333, 39.21855557349421, 39.635954595381214, 39.179567213981386, 39.17856700958745, 39.771641146752145, 39.240842480813306, 41.11780643463135, 39.88104781796856, 41.967493795579486, 41.320902839783706, 38.99298398725448, 39.85268515925254, 40.46104477297875, 39.20535679786436, 40.709526923394975, 40.05096881620346, 38.383361370332786, 43.69081066500756, 47.65650341587682, 48.07977422591179, 48.098025014323575, 48.223533015097345, 53.387490241758286, 55.38298037744338, 58.15000072602303, 57.09608731731292, 53.53300625278104, 36.11591762112033, 52.94948308698593, 57.76747941970826, 51.77777305726082, 49.64280343824818, 48.076648096884455, 47.22046529093097, 42.23903948260892, 41.27152804405459, 40.699701386113325, 43.22182855298443, 39.894850638604936, 39.20050874833138, 41.102991642490515, 41.16511806364983, 39.74574958124469, 45.91676358253726, 54.06698203855946, 55.55274448087139, 55.18550472874796, 56.254754604831824, 53.05628138203775, 52.329407353555005, 52.02951469729024, 51.0863886340972, 52.1684842724954, 53.12631922383463, 56.52706515404486, 53.91758288106611, 55.07051652477634, 52.72234647504745, 49.638249566478116, 54.07154375506986, 57.86880993073987, 57.33153150927637, 52.545161247253425, 43.048095010942035, 39.52976034533593, 42.15217467277281, 43.88959246297037, 44.83693115172848, 51.07297412810787, 53.90254843619562, 57.428986718577725, 58.12303835345853, 61.357879792490316, 55.0314889415618, 38.72870645215435, 31.945304562968595, 20.62107670691706, 7.085368988975403, 10.252353914322393, 15.344869090664773, 17.565264009660293, 2.7336069028223715, 1.3920052926386557, 0.561604838698141, 1.22416780840966, 15.871564957403368, 43.84500295885148, 66.62213986919772, 53.73334130933208, 46.94502076795025, 59.80527624007195, 64.7633521787582, 50.25072374651509, 9.710731467893048, 0.18411945731889817, 0.16246909245608315, 0.17003859273127972, 0.17773524828014836, 0.16164810667114873, 0.1676504821666787, 0.13720605612522171, 0.15275702811777592, 0.11755819147032116, 0.14235500967310322, 0.13366927332695455, 0.16514356668678024, 0.11390097198947785, 0.13194957447628822, 0.28016295043691514, 0.09654652943173725, 0.10776666083162832, 0.21190637031630163, 0.09241392175036092, 0.19375695065865595, 0.1222902552915677], [0.06729059687425053, 0.016219644176383174, 0.08715993754806058, 0.00749431592750273, 0.06509556344920589, 0.02578341495996762, 0.014034078640472746, 0.029159198635287827, 0.02430159598588944, 0.03730739406760662, 0.05934884298532721, 0.09714550293621518, 0.06804695548189264, 0.07301678235131888, 0.07039583468389127, 0.08191526131404024, 0.009014900386964363, 0.051020065307497024, 0.0034288297578196733, 0.07759967353194952, 0.01261016921020083, 0.04082963651707096, 0.4204484501913671, 10.05921934881518, 35.709838559550626, 53.36822748184205, 40.609365278674716, 22.830773361267585, 26.961801859640307, 31.100618223990168, 26.21183683795314, 5.86381200821169, 0.2577117632233328, 0.1072167629195798, 0.18377168404479183, 2.5441137677238834, 5.873976340216975, 7.207900401084655, 3.6353531864381607, 6.1601034383619995, 13.748472275272494, 18.998113678347682, 38.17712314667241, 47.5037153305546, 50.08487416851906, 45.9483661190156, 43.199353371897054, 38.2962376840653, 41.97392256029191, 44.81959427556684, 46.41832097884148, 51.79347822743078, 49.156351089477546, 49.17199742409491, 50.2853504303963, 50.62177996481619, 49.644117432255904, 44.92819293852776, 43.443968065323375, 38.758971460403934, 35.32513249304987, 36.416900696293006, 37.261991039399184, 37.000576834524836, 35.633336651709776, 35.4464945485515, 33.53029512589978, 33.990706859096406, 34.3410921865894, 35.64012235210788, 33.484423006734545, 35.141675395350305, 37.51302665279758, 52.36022149362872, 39.638162889788234, 36.971872929603826, 36.66777941488451, 39.6229362487793, 46.94628377114573, 49.75065292850618, 47.91673306495913, 46.82119154161023, 49.1344524968055, 52.4932094543211, 49.458420661187944, 48.531870534343106, 45.8894834979888, 48.63486020795761, 27.7487293366463, 48.616107356163766, 48.910614598181944, 45.04120426793253, 42.86904665731615, 40.12976531059512, 37.103837151681226, 37.70789392532841, 37.13615748190111, 38.4531952488807, 34.92248550538094, 38.27428025584067, 37.26128893513834, 36.7366954588121, 37.25797453234273, 36.086390018463135, 36.97373997780585, 43.66850806820778, 50.84852826210761, 51.41767986359135, 49.55187897528372, 51.26773941901423, 53.176137247393214, 53.23032479132376, 52.76021303669099, 53.91068735430318, 51.236525197182935, 49.51873886969782, 50.34486455302085, 50.18314130844609, 52.43127130693006, 52.82535576051282, 50.95210629124796, 51.412647462660274, 56.597573680262414, 50.86502967342254, 48.03880899183212, 39.780199758468136, 38.12877993429861, 40.322655708559104, 44.12013369221842, 45.342473676127774, 49.12325412996354, 49.62078717447097, 56.18019819259644, 54.19869522894583, 55.69345951080323, 33.78136604062973, 26.082655537513, 10.400272377075689, 11.547391107005458, 7.360359497608678, 7.917709177540195, 3.1108741942913305, 1.8239771454564988, 1.0025516260535488, 0.058725944554974, 1.0112611877341424, 11.516754454182042, 31.92681843234647, 34.397264449827134, 34.919324075022054, 31.141583458069835, 38.794998430436664, 48.837034856119466, 34.34128830509801, 3.7714621280470206, 0.23287978924570546, 0.021562312632018042, 0.011711629471861789, 0.02118843682711163, 0.05691057281388391, 0.02334108643774544, 0.07127591649130469, 0.004718354677841549, 0.07125402169842875, 0.01771942025140649, 0.0330319301405501, 0.030842726644609245, 0.033825306116693446, 0.04362952700185199, 0.029431058341757427, 0.06929332690854227, 0.059095528352284626, 0.03080155324911879, 0.05104988911038926, 0.03667693434944076, 0.03198563981230461, 0.04447167213525503, 0.017989155979106025, 0.02004330008921604, 0.046155521901504654, 0.028261274640117923, 0.043408449348663135, 0.015421648690056418, 0.01821142681423695, 0.03287921434328441, 0.04961750004440547, 0.03239795024837217, 0.023150050922507243, 0.09156284403176078, 0.02461230209577949, 0.001774971855000683, 0.019594211687123584, 0.057989584672595226, 0.02338723174386448, 0.03453685241120477, 0.018314931038466674, 0.03623148103454902, 0.07164158557932224, 0.807031830472331, 12.699044096854426, 43.271144513160955, 57.135875840340894, 47.18046888228386, 27.275891534743774, 32.357728058292025, 40.024069201561716, 29.390847259952178, 6.342468646264846, 0.36221035425701453, 0.03605017100550956, 0.31534841885009124, 2.583503679883096, 6.532085336023762, 10.725095618155695, 6.263212253970485, 7.964277027114746, 13.560290682700373, 27.08815120881604, 42.409654740364324, 50.9467444112224, 50.22156092428392, 49.169138016239295, 44.185727488610056, 41.82764168708555, 42.15638337596771, 47.275449076006495, 47.820866415577555, 54.61179141075381, 52.32677544316938, 50.78600175919072, 49.22993475391019, 52.2236837879304, 51.635057618541104, 48.330394068071925, 44.75739725174443, 40.11690778117026, 36.55050054673226, 37.53423490831929, 38.75133068330827, 38.04726523737754, 36.238887848392615, 37.47312438103461, 35.3157776401889, 35.969005246316236, 35.395472357350016, 35.92328217721755, 34.99734001774942, 37.64831312241093, 39.64320313545966, 51.81293710585564, 40.31754878259475, 37.9226593817434, 39.27433167734454, 41.15367650985718, 48.931273721879535, 51.507886532814275, 50.44566162170903, 48.6961119405685, 51.827190999061834, 54.99734470921179, 52.4480119828255, 52.33989969376595, 48.34334181201074, 49.916157337927054, 29.594528098260206, 51.02780411320349, 51.19950978986679, 47.73672373064103, 44.5032629659099, 42.27354065064461, 38.825216370244185, 39.04232348165205, 38.039926482785134, 39.716194521996286, 36.724740074526885, 39.61513465450656, 39.58336737848098, 38.919031620025635, 38.82771884241412, 36.6415269913212, 39.068215047159505, 46.16544185146209, 51.95705283072687, 54.358712242495635, 52.87069835970479, 53.78382221344979, 54.88112095863589, 54.171015062639796, 52.99703790295509, 54.31054553677959, 53.67247004662791, 51.380613465462964, 53.03926614023025, 53.26250783858761, 52.888035235866425, 54.97665812892299, 51.219286380275605, 53.46779292629611, 58.77419887050506, 54.23261980856619, 49.56869809858261, 41.74191044222924, 38.54399419599964, 41.834286182157456, 45.44132132684031, 48.533800340467884, 51.01234997472456, 53.531554975817286, 57.50359019925518, 58.34687232971192, 57.125159925030125, 33.01260502107682, 19.62089780838259, 7.641467923118223, 10.298753592275805, 15.641866057149826, 12.07783381785116, 7.572135127359822, 2.793863088853898, 0.42127055446467093, 0.05176663331146683, 1.065166075864146, 13.143886962244588, 35.89654337975287, 41.95465587800549, 44.03658328517791, 41.66441225236462, 47.49017138634959, 56.66345380967664, 39.65587631348641, 5.064034846521193, 0.2681121728833645, 0.10592321579855297, 0.061582927742312034, 0.0686445040628314, 0.07357627168417939, 0.017631563373030196, 0.07179481082505758, 0.008326670936038418, 0.07252254838784856, 0.017678486258392374, 0.05571216232173386, 0.050036722508769844, 0.010530173463085967, 0.014811044055668098, 0.04369605407719651, 0.008058621559382207, 0.05119737635757174, 0.035056233210789586, 0.047593943909892154, 0.02696146666552992, 0.028752160799359123, 0.18919201657897045, 0.07430905776639139, 0.18017419643940466, 0.13372452358805365, 0.11821216242688319, 0.13638946768497268, 0.10291033754906348, 0.12928319013407155, 0.15899149761084588, 0.13873178151346025, 0.0816707413703684, 0.15457582810232717, 0.23593592848027908, 0.11508555076415501, 0.12304178754528686, 0.16561682516288373, 0.14241631202880414, 0.1809460453448757, 0.18598917150689712, 0.1800848246221581, 0.19198174107699625, 0.1486969766237082, 1.14370773876867, 17.166790423854707, 47.99293295029671, 65.59842086607411, 53.24517488479615, 34.17146144374725, 39.17859446617865, 42.48629000879104, 33.77052460947345, 8.187400564070671, 0.5412878805110531, 0.2443675994272194, 0.30679801959664593, 6.18716779255098, 11.19643311346731, 12.499550388705346, 7.611276459309363, 12.955289598434204, 18.82316812392204, 22.31092595284985, 43.2845550967801, 52.0836434056682, 55.10138950040264, 50.476958213313935, 48.62334412913169, 43.2912427379239, 46.447781901205744, 49.81465032023769, 51.94110447360624, 57.21255033246933, 55.75902192823349, 50.17481019420009, 50.54031233633719, 50.44687363409227, 54.15979708394697, 49.620900923205966, 47.62925863265992, 42.563278290533255, 39.808758535692775, 39.6803322915108, 41.24283198387393, 39.46695535413681, 38.139464470648, 38.89484236317296, 37.73516224276635, 36.962019935730964, 37.98673914324853, 39.17054968495523, 37.59225460790819, 39.323745696775376, 41.36730840129238, 52.610150998638524, 43.98916575216478, 39.827695738884714, 41.91001146070419, 43.66531133651734, 50.297909859688055, 54.79062795639039, 52.60363201941214, 51.39431038210469, 54.735365683032626, 56.09332946039016, 54.253933968082556, 52.46488994167697, 48.46812417430263, 52.81357688288535, 35.08325561400383, 53.10554635140204, 54.02082750874182, 50.69227672392323, 47.838069931153335, 45.05152402385589, 41.82388405646048, 40.592412794789965, 39.70545507246448, 41.40559465654435, 37.72296759390062, 40.84380142150387, 40.9447043941867, 41.38709283644154, 40.98200613452543, 39.840243401065955, 40.24033300338253, 47.42915891831922, 54.945185030660326, 56.3420351859062, 54.91192725396926, 55.486574096064416, 56.97896142159739, 56.715613488228094, 54.470958709716804, 57.07507125792965, 56.36802873303814, 53.25556916575278, 55.75955144820675, 55.32588635721515, 57.71990891425841, 56.27496657832977, 52.3511568961605, 54.16050703294816, 62.07564215506277, 56.47194016364313, 53.65570583651143, 44.19156789779664, 41.732594813069994, 43.94762392966978, 48.96677901667934, 49.824267971900206, 54.216357661831765, 55.251886921544234, 61.343437625515854, 58.91812632160803, 60.94459141454389, 37.3245410765371, 29.150755059334543, 17.469279689173547, 20.3564618479821, 16.01800076423153, 15.859325201280656, 8.924467852038722, 3.6128054415026023, 1.7064990944439367, 0.30201851961112797, 1.6210756330720841, 16.45794164749884, 44.2344747051116, 48.671679496765144, 49.459487545874815, 45.89014245617775, 54.52930004365983, 65.6542871844384, 46.41952514648438, 7.069404942374076, 0.36173559424857943, 0.22633588151826015, 0.0783539330586791, 0.11338003986184636, 0.16756800514075065, 0.28340178631967117, 0.13472805280358563, 0.16135074198246002, 0.1720086644373594, 0.19380807936672242, 0.12452612886385572, 0.13523132660456244, 0.16943575814366343, 0.07895862157907217, 0.1565907619172527, 0.17451374130623956, 0.10003533214330675, 0.2498290249176564, 0.17198269405672628, 0.1092372049066809, 0.14140305349663382], [0.056111933813700755, 0.009084797291565807, 0.04064781320912223, 0.006728253379884747, 0.042660789669401226, 0.037605241391687624, 0.01863296286413266, 0.030061052661509286, 0.04362530968782883, 0.0799694822560395, 0.03320000983113724, 0.007861782449312628, 0.06947564051276253, 0.022664219028346484, 0.03871251423392565, 0.014722201796699197, 0.014551298114501182, 0.06656941702409137, 0.006500287638646701, 0.035975799189820405, 0.024717621948389758, 0.06752048453856861, 0.5217700439595407, 8.422446635461624, 35.28082539958339, 48.130419869576734, 42.93636629658361, 35.622769786465554, 24.74320730855388, 38.978612422943115, 26.280358683678415, 7.215633844175647, 0.7364118844270707, 0.09278296928612456, 0.3836055658757687, 2.2037263166519905, 5.283457627219539, 13.289003872102308, 8.75955964288404, 7.383229857490909, 6.559367381757306, 30.520172157595237, 37.04447992386357, 49.77574825286866, 49.14971836151616, 47.35149598890736, 40.8827034888729, 43.875534688272786, 44.51237855419036, 46.1892427936677, 52.04020707837997, 49.545383530278365, 46.03583105148808, 50.940417628134455, 51.013762027986594, 51.77909489600889, 48.67917122379426, 45.45707356545233, 43.315479063218646, 41.71406553637597, 37.75320122318883, 37.21126302596062, 35.85715886085264, 36.28501884398922, 35.99152749584567, 36.288039069021906, 35.422948560407086, 37.09689455647623, 34.2503010842108, 36.06345592006561, 35.678318392845895, 35.59657227608466, 35.487950078902706, 41.23183365791075, 37.30716105430357, 36.29182807860836, 37.410342924056515, 44.79798986065773, 50.59534318985478, 53.8336794607101, 51.532562163568315, 52.8651011374689, 51.37520451699534, 49.99332997106737, 42.597540193988436, 46.235715035469305, 41.33596866361557, 46.72402266533145, 28.697276115417484, 45.51202204919631, 51.44519921272032, 42.791297435760505, 41.342138551896625, 34.6993536333884, 39.16424251371814, 35.955739790393466, 38.94834349232335, 37.01019840855753, 35.546052148265225, 34.29827167141822, 36.506224832227154, 36.51173968468943, 36.248780065967196, 36.25839771762971, 37.7579943595394, 36.154349004068685, 41.51091029567104, 43.687021655421105, 47.997169110082815, 45.33488781221452, 49.63130304890294, 50.410870198280584, 49.88895962315221, 50.2195095246838, 49.315077643240656, 47.29486088598929, 46.76224616266067, 47.91139471915461, 47.31200948838265, 49.22872666389712, 53.520270316831535, 50.4268499343626, 52.88188888180641, 52.06643204535208, 49.68504736500402, 44.2274183611716, 38.03847520582138, 40.40585702465427, 46.471845642212905, 47.96414275323191, 51.099053967383604, 51.43327128502631, 55.60921092187205, 55.373562766659646, 52.495476584280695, 30.172114756799516, 16.3396841479886, 0.9502230404365448, 4.053245691522475, 17.008340397188743, 9.784480852465476, 10.175110678518973, 1.619922823963627, 0.28697463653741345, 0.05134991595461484, 1.1492912327089617, 11.969694072200406, 32.24576400172326, 40.778250771184126, 34.75731057505454, 29.140503944889193, 43.78149586339151, 49.99082357652726, 35.779315502412864, 4.086457380364019, 0.32116026827885263, 0.04227059044604821, 0.0562337494545406, 0.021870324027634436, 0.04662341776213819, 0.03265201564758055, 0.002136912010046804, 0.04652814323743505, 0.04523586399192291, 0.06680932511845905, 0.05089600502903904, 0.04707400386612262, 0.04128848870975837, 0.04583897820163158, 0.00108602718917668, 0.052066001320077535, 0.01627959438689774, 0.02117152926662276, 0.015251500562073724, 0.02494913754954694, 0.007026941485462651, 0.041488774736682256, 0.030449212175763907, 0.05625198234713847, 0.01637557179727141, 0.04169995453388941, 0.03527428864711716, 0.03244203094753527, 0.016854719574292822, 0.048020417396459854, 0.01656329972789653, 0.055139412006904046, 0.013674581348295174, 0.03440104034398833, 0.012494256276817573, 0.027145335428236474, 0.04004237392256337, 0.170273597862932, 0.10153648143093433, 0.07112512740516855, 0.024495167252157005, 0.045474622954404166, 0.015117994419509366, 0.37715988594197464, 10.84997800088698, 40.430140418391076, 56.65320465641638, 45.35117741554014, 39.376430972929924, 28.28344056683202, 39.755065210403934, 32.54554879280829, 8.371121441164325, 0.8760632778848372, 0.0028284334844248674, 0.4325838957823092, 2.072965036476812, 5.477224184620765, 8.906785807301922, 6.729132465777859, 11.372227861035256, 10.28743657373613, 25.86817249175041, 39.321035338986306, 51.20649553114369, 52.1398352807568, 49.1341269400812, 43.317750115548414, 43.72607277285668, 47.06879115873768, 49.926029943650775, 53.788372162849676, 51.66237692679129, 48.513047079886164, 49.34896299915929, 51.48997699060748, 53.22474325856855, 50.08221480154222, 48.309464300832445, 45.115501803736535, 44.27541248260006, 38.86590703841179, 37.42002725601196, 37.09037949962001, 38.48577445553195, 38.247157066099106, 38.26811036755962, 38.16837233881797, 38.08591627305554, 36.1622251233747, 38.82556153881935, 37.05708249922722, 37.80860862424297, 38.014607583322835, 43.90292459918607, 38.49514107550345, 39.02457867899249, 39.86674293395012, 47.02466057192895, 52.85735445637857, 54.390228486830196, 53.645178194968935, 55.07917711811682, 52.999371713207616, 50.68550279063564, 45.05113178683866, 45.8979126714891, 43.64957478738601, 48.76914255080685, 31.069719752957745, 47.28949900596373, 53.690748291630904, 46.358281258613836, 43.516461310848115, 36.86570221377958, 39.72559644329933, 36.82498408902076, 41.131660246079974, 37.32449400809504, 37.62707348792784, 37.16910146897839, 37.73895125235281, 37.724293355018865, 38.703469922465665, 38.20958075984832, 38.58302962395453, 39.24953445311516, 43.84094330572313, 46.914057577809984, 49.308358623135476, 48.30480060269756, 51.29926350808913, 53.06265523356777, 52.83449096064414, 53.06368681692308, 50.65203320595526, 49.70270587551979, 49.06101396006923, 49.55162794359269, 49.20796555857505, 51.59894827873477, 54.82636859340053, 51.98114795069541, 56.17883713014665, 53.619059131991484, 51.53064412455405, 46.09672192604312, 39.87360708175167, 42.50085769161102, 48.114640174373505, 50.210676347055745, 53.439438112320445, 54.283728291911466, 57.36640530247843, 57.30159990249142, 54.39571588270126, 32.86823434214438, 16.877619566455966, 7.558531857305958, 9.55208336153338, 18.054050168683453, 9.629715892576403, 6.273797260176751, 0.9628046556345878, 0.11563675102567482, 0.09637169284565796, 1.2566933276191836, 13.068020478371652, 37.083209406945016, 43.43972013842675, 37.0210555291945, 35.70353138831354, 52.04671821286602, 59.691805993357015, 42.23022591683173, 5.329604802593108, 0.16089082875799748, 0.040244069551267934, 0.07954706137459125, 0.041531055129223296, 0.05511144596722819, 0.07846437229384338, 0.049363020957717975, 0.024829380770003604, 0.03342381475733654, 0.101326274565391, 0.03864443200009485, 0.03298052181039126, 0.08136961518997148, 0.02451276620699754, 0.02407596393999073, 0.03162908717058599, 0.04079276470527534, 0.038826362560352976, 0.039494758952529206, 0.07001507366376539, 0.032283121329401775, 0.15481831025212042, 0.08525714368349122, 0.16378451138734818, 0.11029554771319514, 0.17340447663539843, 0.20175705363433208, 0.1349778434321765, 0.0687354386994435, 0.19067171540471817, 0.17270686164979013, 0.1332286195529084, 0.108880958700132, 0.1312456009609084, 0.14430747667868293, 0.147793238021193, 0.16048875517181813, 0.22129061031005076, 0.19344619475305083, 0.11605623779037308, 0.08775011636316778, 0.17437371575543958, 0.142037941203002, 0.8564392309035025, 13.506087449289138, 46.514497495466664, 61.2808915107481, 53.95694778811548, 46.286027277669604, 35.28463402102071, 49.001750869135705, 36.71009002193328, 10.289391875267029, 1.3809431055861137, 0.16513356157848913, 1.6016874798843939, 4.0414712265614545, 11.843486908943424, 25.392104618010986, 18.561534266318045, 14.775261513648497, 10.51894074486148, 35.06782500974594, 40.11795505400627, 53.163052220498365, 54.30349703757994, 52.49585705418741, 44.29454580430062, 47.85413203700897, 51.04168538124331, 52.92086547420871, 57.9481908582872, 52.72206014202487, 50.19179013467605, 50.461056924635365, 51.87531063633581, 54.50308292142807, 52.83203947928644, 52.37776625540949, 48.24940496875394, 47.28717696282172, 42.240286796323716, 40.11268338849468, 39.77328854222452, 41.43540466985395, 40.73498702818348, 40.8564079192377, 39.22137968001827, 42.16643248834918, 38.662194821142386, 40.46481024834418, 38.913002937070786, 40.008042397037634, 39.865950615175315, 43.97502953006376, 39.972207623143355, 40.573554039001465, 41.0596808310478, 49.576331030937936, 54.74458717530774, 57.09293765406455, 55.995336886375185, 57.265835731260246, 54.11994580299624, 52.60152962899978, 46.03801581167406, 47.867919168164654, 42.5790972094382, 50.47666011318084, 34.27539640857328, 49.40217779528711, 56.062209375443004, 49.06139835234612, 45.543754023890344, 39.75595951080322, 42.36918764729654, 38.321140812289336, 43.43312663416709, 39.85132409680275, 38.98819477327409, 37.54505280525454, 40.2748380937884, 39.86250285179385, 40.56306169879052, 39.97787544804235, 41.66305118991483, 40.46499852211245, 45.020745185113725, 48.911822688195016, 50.96369689510715, 49.29051576122161, 54.866580732407115, 57.24468631129111, 54.95852501161637, 54.820014353721376, 53.47844216131396, 53.3238301738616, 49.98916833631454, 52.06997786798785, 51.34233113258116, 54.94185101601386, 56.49208937921832, 50.69373584562733, 54.97635218404955, 57.023178300549915, 54.53308120850594, 48.40596245181177, 42.64025088279478, 44.78083733589419, 51.15284927429692, 52.58462813592727, 56.761054146674375, 57.69056566299931, 61.3936008176496, 59.03378917324928, 56.431147513851045, 34.0538844754619, 21.336595473750947, 4.861439033862084, 11.926240094246404, 29.51857532224348, 22.10534864856351, 18.431668512282833, 4.444293495147459, 1.0483817636005341, 0.20933200845554953, 1.8993907181486007, 16.030942624615086, 43.06762056965982, 54.03606983923144, 47.68940817925238, 42.410666711868785, 62.050574287291504, 67.67536686312768, 51.702106614266675, 7.273894769530143, 0.4388087585328087, 0.15229170631256797, 0.2254036597667202, 0.15623022561832783, 0.1562399396132077, 0.22348177499107777, 0.10968774121495024, 0.12628883589059114, 0.09503967278907377, 0.20789635968544792, 0.12978130050243872, 0.14616229811743384, 0.1317257848718474, 0.13167367557123785, 0.16013926586076138, 0.1668444810615432, 0.14689357500643502, 0.1875069449024816, 0.1274816271278166, 0.10338607815004165, 0.18647294070932174], [0.06917748675351182, 0.021960731978798588, 0.07116019891034212, 0.04986962341072579, 0.05134810798711354, 0.07436877432008905, 0.0404157690072973, 0.042526237816820224, 0.015257189722521412, 0.060237210033641714, 0.04936906539144055, 0.00794283215767674, 0.014759365679515947, 0.09687808462448659, 0.027150761245960192, 0.06646775715653935, 0.06202818570478309, 0.055396174035605886, 0.13454071366258208, 0.04539679608217651, 0.008632082420761788, 0.05695545024448826, 0.2521759505954481, 7.234518095370262, 32.644139528274536, 48.094726301008656, 41.4495801156567, 28.407844420402284, 36.130724568520826, 31.969991960833152, 34.461140248083304, 12.369235523285406, 1.0325543870848994, 0.05987709508307519, 0.35123994453780116, 0.5938435345888138, 1.2036193690953718, 6.495952952292658, 4.168818083501631, 6.369902683842567, 8.000975703039478, 21.389070903101278, 37.96710375816592, 52.36524604981946, 47.96925752393661, 45.233200365497225, 43.40321071686284, 45.8979126714891, 47.61157266555294, 50.96741922440068, 52.495743305452415, 49.921413313957956, 50.433902355932425, 52.585879372012236, 49.968250336185584, 51.0171470334453, 49.66371751600697, 49.3987927898284, 45.82852202077066, 43.78932099188528, 38.45949849774761, 37.032316653959214, 35.01369630136798, 36.83038127037787, 35.35054160702613, 38.0125444166122, 39.34220829317647, 44.68010694749894, 43.045384653152965, 41.70234941667126, 37.74924355168497, 36.32068887833626, 34.89371099779683, 34.44818465940414, 34.59286520558019, 37.184010398003366, 35.623711155306914, 43.8082189713755, 51.41265922977079, 52.31065842413133, 53.04141952145485, 54.24244926821802, 49.82673122036842, 52.95159724450881, 50.4613785589895, 54.122558101531006, 47.60765029538063, 52.27418822626914, 32.9741971723495, 43.75234873064103, 52.82488899846231, 45.152403462317686, 44.2628961993802, 36.05865493897469, 40.4778560515373, 38.3406271473054, 39.5812806775493, 39.975718144447576, 38.23552723853819, 36.07535639116841, 37.72914532692202, 37.29840632407896, 36.195192644673014, 36.77345591206705, 34.340798008826475, 35.68759479830342, 35.96100753353488, 36.85883806597802, 39.01124262040661, 40.608996575878514, 43.42877672564599, 45.63922843625469, 44.536336391202866, 43.05868148803712, 44.11257136252619, 44.311011914284, 42.73045755201771, 45.16297424993208, 46.229670663033765, 47.16389294593565, 51.99968899449995, 54.068421548412694, 52.46428589667044, 50.557806107305716, 52.4014259922889, 49.288946813152684, 39.70037952546151, 43.6912735046879, 46.933881236660866, 49.42159745001024, 50.23142176289713, 54.07698408249886, 53.77857408215923, 57.37659169781593, 50.083364056002715, 30.068050353757798, 11.054767889361228, 9.346227568964805, 15.898755808030407, 21.612949986611646, 12.77866134720464, 4.976518432940207, 0.9621458813067406, 0.05543414518357285, 0.04333442227253991, 1.1230846518470397, 13.749350886191092, 36.82947520286807, 42.60758930636991, 41.623501931467366, 35.01280592333886, 38.76208974469093, 50.440142846876576, 28.49784124282099, 3.6530798481356714, 0.13020767439757625, 0.07316073793317042, 0.11035774639176746, 0.04003489307398277, 0.034812234206906253, 0.048013465148547006, 0.08575399766766256, 0.019624006761718663, 0.04915107507258654, 0.025436591634887363, 0.022770835484768596, 0.05571881579535623, 0.04327640260359453, 0.02439070350280212, 0.05327414112886595, 0.026702691740807027, 0.025217819906350587, 0.038310593865331144, 0.01211888947328853, 0.08106907123639699, 0.05662375332547292, 0.05395345044352355, 0.047136076140187444, 0.06922252506258027, 0.022128005361845417, 0.043526557123949455, 0.09326182786495456, 0.025406474803364085, 0.017873727596334873, 0.024036066080894203, 0.044184450450683796, 0.08685678123466431, 0.008846591827609848, 0.02423772340520255, 0.10723046057166592, 0.03155501987484675, 0.03104407178808845, 0.08286416079969176, 0.014664178297314194, 0.051158937895970966, 0.015454103047358654, 0.1465754340132398, 0.09268968275958493, 0.40866457767063574, 9.465258755991536, 39.061350899357954, 54.211254658237586, 49.2626198645561, 33.2281510291561, 35.31937837600708, 40.55437757122902, 35.47422962803995, 13.40042369980966, 1.0438312013303082, 0.05050435023862989, 0.291397936281658, 1.146487841202367, 4.890664123719739, 8.037028658774592, 7.503198000692553, 9.913570957799113, 12.896722728206267, 25.32197852288523, 39.15125162370744, 53.21356058120728, 50.69940367052632, 49.08033947790823, 45.861662126356556, 49.44888145692887, 50.01852727705433, 52.71320343017579, 53.10285168309366, 50.617018207427, 51.517300221227835, 53.74700684701243, 50.87124270777549, 50.997664620799405, 51.12024261105446, 51.348112706215154, 48.490422848732244, 46.39149981160318, 40.50028024181243, 38.664873799970074, 37.51369345572687, 38.83120975186748, 37.27617432994228, 41.13765755007344, 41.65044861455118, 46.736421277446134, 43.866693665904386, 42.24940238460418, 38.69775895149478, 38.14865066159157, 36.703402380789484, 35.68743398112636, 36.71157267785842, 37.79812412877237, 37.726878196962424, 46.27321681668682, 53.43496268795383, 54.83087147435835, 53.05004873583394, 56.00453876679944, 49.344868044699396, 52.29969147712954, 49.53860175225043, 52.85094922588718, 47.37174326373685, 52.214627035202525, 35.087636901486306, 45.78350890067316, 53.983843480387044, 46.7187156984883, 45.466126395810036, 38.000361534856985, 43.43565264055806, 40.604944767490515, 42.192881030421105, 41.61008350310787, 39.300533110095614, 38.201838001128166, 39.40435040381647, 38.73142857705393, 37.570595279816665, 39.045202501358524, 36.570296748991936, 36.467930732234834, 38.28982853120373, 38.960910766355454, 41.75303820640811, 44.11536409008888, 47.22393658853347, 47.576263489261756, 48.291107608426, 46.92817418806015, 46.15400422003962, 46.38243129176479, 46.34984424037319, 47.64154741840978, 47.413794994354255, 51.14741679160826, 55.57035592294509, 54.75069430566604, 53.173191547393806, 54.47321799493606, 54.7380328947498, 50.15484925239317, 42.115704474910615, 46.10625328556184, 49.57712334971274, 52.75931089155136, 53.46936971910539, 56.086292728301025, 58.58763133325885, 59.962080832450624, 52.99027573677802, 34.21885936490951, 15.621793327793, 10.645429338178328, 4.016901499802067, 8.182136253003153, 9.440162451036516, 7.2031347213252905, 2.171640838346174, 0.08524413551053694, 0.12091922603787915, 1.3314554191404775, 15.303393948462704, 39.34605613831551, 48.821325763579345, 45.936987323145715, 38.8019214137908, 46.85735579459898, 57.295288808884166, 35.87156964886573, 4.951019594746252, 0.30517890809043763, 0.03466565094347443, 0.09425195820269086, 0.045738616853111216, 0.039757523280117786, 0.03500400516655176, 0.06329815263950056, 0.05008626924527269, 0.04972567548975349, 0.13666705198345647, 0.06005630603120212, 0.012792314275077755, 0.060943830382799914, 0.031510985140959104, 0.05023389821872116, 0.02953092173312701, 0.05114731634215963, 0.04092989061328192, 0.013466013910909815, 0.0542335513408386, 0.08193437520775103, 0.16441846446644875, 0.08926929169965368, 0.133085866729098, 0.0876022920372986, 0.14247314043102727, 0.19828667533734154, 0.21762664159459455, 0.18222060114625963, 0.08412681159473236, 0.09970547000487005, 0.19452921325160613, 0.07004547203260084, 0.16283379627331612, 0.261229301892942, 0.08075252370608431, 0.07930542958239395, 0.2838265667519262, 0.12504853188030182, 0.2863391819259813, 0.1289373167580174, 0.24205378406951505, 0.2161944555419107, 0.5849535438802935, 12.016502657244283, 44.30662278206118, 61.94812197839061, 54.64015799184, 39.78079988110451, 46.92499706822057, 43.19859243208363, 42.79963247237667, 15.851397110569863, 1.6354160635702073, 0.18617462607160692, 1.3681049428639875, 3.6874628547699224, 9.435442859126676, 14.558240694384422, 9.332818946530743, 12.2996977836855, 13.416849605498777, 26.025090832864088, 42.483658098405414, 57.60071985183224, 51.921637750441036, 50.52052397881785, 48.319587938247196, 50.83245438914145, 52.30681450136247, 55.69843307618172, 54.682170498755674, 52.973966521601525, 52.54979356642693, 53.81257318681287, 52.40025320360738, 52.338907334112356, 53.36312055587769, 54.7748992519994, 51.93008261342203, 48.280372081264375, 42.01820611953735, 40.44723410760203, 39.13520520733249, 41.74063174955307, 39.97055630530081, 43.1279387781697, 43.647692049703295, 50.17895221710206, 47.15271419094455, 45.34189316534227, 42.66829190715667, 38.91270483693769, 38.416528932509884, 38.65805279824042, 37.757806085771136, 39.747271460871545, 39.74510631253643, 47.75102469228929, 55.664304533312404, 56.05055601366105, 53.95628882992653, 57.44580584187662, 51.1275186077241, 52.30507689137613, 49.43662012777021, 53.46654953495149, 49.496946181020434, 49.4413818851594, 36.03676026867282, 48.461326706794004, 55.525687971422755, 49.94721074258128, 48.47597283701743, 39.98053481501918, 44.582298724882065, 43.52588676637219, 44.74437890514251, 44.19455674386794, 43.13143360999323, 39.721348516402706, 42.58876585191296, 41.75485034142771, 39.67980277153754, 41.13473930666524, 38.037608362013295, 40.082669411936116, 39.65054581242223, 41.08442314209477, 43.74570031319895, 44.4610268838944, 49.05808002718034, 50.00371248491349, 49.27854468745571, 47.32355694616995, 49.66485892572711, 49.04251998470676, 47.129905608392534, 51.096057276571955, 50.886916498984064, 53.34221432285925, 58.20220355064639, 56.4681472316865, 54.76909414414437, 55.990649654019265, 56.24926720896075, 53.84621535578082, 43.242958361102694, 49.26968405323644, 51.7728034142525, 55.24806261062623, 55.87132723100724, 59.82927330078618, 59.24546380196849, 61.05571608389578, 55.78667071557815, 34.80986249062323, 14.822332897493917, 17.35280098453645, 25.617185907979167, 31.371230386918594, 20.8188896794473, 9.948842871573664, 3.9541171010463474, 0.4414847036523204, 0.26693310228086287, 1.8768806034518828, 18.184155187299176, 46.666759983185806, 56.62985478678058, 55.11399599813647, 46.829142185949514, 53.900814748579464, 67.66509025327622, 44.45611215406849, 6.98623892761046, 0.49011038796555617, 0.15589801925084285, 0.2218323876901019, 0.16434983831019173, 0.1865021593027538, 0.12156998708603844, 0.20389794762576782, 0.17675680078325734, 0.2715715195142454, 0.19104182780269655, 0.1791500134934341, 0.08353391316749396, 0.1891133853144223, 0.13777188866609527, 0.15530612439878527, 0.12421736478685372, 0.2071192400950578, 0.16884685103451053, 0.06162627299706783, 0.1850318986802332, 0.14758594995064123], [0.03857526958229081, 0.045406176828809326, 0.021537552670305295, 0.0764540120238258, 0.019206027275011427, 0.03241743569472625, 0.052744820338463595, 0.028145218065248865, 0.030651859668714386, 0.009620848164382962, 0.015816088210070328, 0.10238670879193854, 0.02049345526874306, 0.11760358217983477, 0.020143443102677985, 0.0161010978157602, 0.07581936180471413, 0.044830963541302955, 0.02818215882495767, 0.04657339222068268, 0.022102266722809405, 0.04709669156000019, 0.059058120278942014, 5.019040357682013, 30.63109286369816, 52.45120086977559, 42.51821810199369, 37.9477233271445, 30.216878806391072, 40.71057027386081, 34.3710434052252, 14.573439878802146, 1.8081688904954543, 0.03136333701531253, 0.29979665012609574, 1.458086566098275, 6.232694743141052, 6.366261253433843, 6.7329631505473975, 13.108881769641755, 10.87990568530175, 19.607593128758094, 35.5071069348243, 49.37816504509219, 49.7323589940225, 45.24663448333741, 46.30221097700058, 49.83284619546706, 53.05388481386247, 50.841185585145034, 49.207702759773504, 51.210959188399784, 51.17275138055125, 51.471620298201046, 52.573347399311686, 51.051628589630134, 52.28723795183244, 51.24757451395835, 47.38043131366853, 44.96165860083796, 39.26471010331185, 35.538313311915246, 34.690285113550004, 36.00758960170131, 40.668875478929095, 43.3974487550797, 46.25322449591852, 50.36261720042075, 50.57430359625047, 50.11221701099027, 46.628485495044345, 39.1811087054591, 35.62386412774363, 36.75567973044611, 35.048362208950905, 35.46097986159786, 33.78480203690068, 40.84005163561913, 48.31271202333512, 51.12589474647276, 51.07017747817501, 53.21711032621322, 53.67823593078121, 53.651575580719985, 50.64925616787326, 53.476308391940215, 51.35735381034113, 54.69062712884719, 32.4432651458248, 42.06435280461466, 52.68200097545501, 42.820809348937004, 43.56622442122429, 42.1719551855518, 43.26482949718353, 44.780029327638694, 45.80177145619547, 42.396138252750525, 41.15905015699325, 36.67103105975736, 35.60473472841325, 35.094501049287864, 37.14377080240558, 37.427919064798665, 36.42067793876895, 35.04334549750052, 35.731752841703354, 35.49582619820872, 35.06960576580417, 33.39103529530187, 36.80183426026375, 37.21661706124583, 36.471743276042325, 41.86489243661204, 38.91825106836135, 38.344749558356504, 39.36334594603508, 41.676524531456735, 42.66499711621193, 45.943439622079175, 49.26511056961552, 55.93823894377678, 50.35092461493708, 53.22109153193813, 53.54925271003477, 50.120610883159024, 39.749962206809755, 41.20332587149836, 45.86137579333398, 50.57624909185594, 52.20835516529699, 51.956158530327585, 53.80875279826503, 57.81907035458473, 46.2889612105585, 29.80582617944287, 16.25700156534872, 8.949348426634266, 2.965948254831376, 6.8400919052862355, 3.7481475597427742, 7.201081360540083, 0.6513668704898127, 0.1984200206014418, 0.20439492418400704, 1.4268247855286447, 14.20931056622536, 40.28327903439922, 41.10445860893496, 28.99384064059104, 37.77049887564875, 46.452233791351325, 48.312104055958415, 24.192367292219593, 4.141279122521801, 0.22990015155125051, 0.0038263599638031017, 0.022639415016578093, 0.050328245777035915, 0.0354025662395983, 0.03742809122007701, 0.08214586910100714, 0.030305124443745425, 0.02730060038307021, 0.024817234445964138, 0.03927354340351397, 0.03315618194098915, 0.04469075795984076, 0.025464105682687897, 0.03924411030546312, 0.016186541517175013, 0.04532973657572462, 0.020577981579868544, 0.016673424867011847, 0.09740277058294705, 0.05204879881573781, 0.015078452791297629, 0.04537932927750292, 0.040370788154823166, 0.05121951629858344, 0.05754984254317899, 0.09852144281349837, 0.0520982114868539, 0.0500347460019252, 0.05276265103490122, 0.011582934361461912, 0.024078848261025645, 0.01682584188998707, 0.035963545613471544, 0.04223940683709037, 0.050799386020028786, 0.018040449396076224, 0.010069362958142114, 0.059838821330378135, 0.08973046130831204, 0.13064912490306363, 0.07092281124524533, 0.06495114821459978, 0.057360454116977995, 6.940662947393234, 35.0989294052124, 58.42300553475657, 46.44420862197877, 42.65710138505505, 37.19826821357974, 37.721818339440134, 39.77842684715025, 17.423807651765888, 1.8180310774234034, 0.09659034200012685, 0.20553743707076197, 1.257972755739766, 5.205880499655201, 6.880119692894721, 12.153592436544358, 10.814896322065785, 13.234571180035992, 21.17914761266401, 39.03087408311906, 51.609311180730025, 52.172143843866166, 46.26701554944439, 48.88921806889196, 51.10843235446561, 55.47824298181842, 51.250108365089666, 50.46153937616656, 51.46745081870787, 53.384921089295425, 52.21012807661488, 53.07653650160759, 52.16689571257561, 53.04622050254576, 52.84766620205295, 47.76417639947707, 46.67755434590001, 41.24534622315438, 37.940070782938314, 36.21401217675979, 37.330024550038004, 41.72326349443005, 44.53809361304007, 49.10222238109958, 52.57285318066997, 51.81919328628048, 51.78995986138621, 46.797496503399266, 41.162874467911266, 37.76307775128273, 37.49380311658306, 36.58335431929558, 36.498682114385794, 35.480336758398245, 43.2782793045044, 50.96131601641255, 52.43277749707622, 53.10262810799384, 54.79153010153002, 54.45457889187721, 55.831224918365486, 53.00943259269961, 54.89531209391933, 51.73823556592388, 54.69631848796722, 33.5425760669093, 45.43359817997102, 54.829373128952525, 43.607079828939135, 46.04532318730509, 43.391859377584154, 44.17418395319293, 45.77285182091498, 46.03770594443045, 44.19714550818167, 42.44767035207441, 39.23892051942887, 38.700634048831084, 36.34144606128816, 38.53614161091466, 39.15360112344065, 38.8449223579899, 37.32995002500473, 37.63553011801935, 38.22260302882041, 36.9599606913905, 36.32175184065296, 39.42391126386581, 39.34744857972668, 39.10693668550061, 43.90037505857406, 41.1730843974698, 39.86255776497626, 41.230962891732496, 44.016787082918235, 45.66303330083048, 49.102300828503026, 52.23054401336178, 57.622845941974276, 52.078226612460234, 55.32201497785507, 55.8166140894736, 54.782288997404045, 42.09714774162539, 42.74830433630174, 47.97697674843573, 52.96078735782255, 54.3281844354445, 54.50753088920347, 56.98983030934488, 58.97398087286181, 51.233618720885254, 31.76894695528092, 15.800727932683884, 9.721893552810917, 8.705124989632639, 10.80628966131518, 10.710033716694003, 5.502314115724256, 1.4550657281952522, 0.2489150820239898, 0.19178382992263765, 2.024398616725399, 17.019599560768373, 45.30003755323349, 47.634314567812034, 36.83916737956386, 43.60953131029683, 51.99595882046608, 56.33479841293828, 30.921644395397557, 4.819672165378448, 0.2840491919027221, 0.02826303664234377, 0.1302249726629065, 0.03790313851148371, 0.011907974934025158, 0.05339188118194861, 0.027784283400603363, 0.08139287361935263, 0.03333890540224891, 0.06024726493764789, 0.05635143588146856, 0.005036544030336964, 0.06254809893547528, 0.016927074663521304, 0.07637027861370195, 0.03686208630942049, 0.01316371561598874, 0.015001898582634187, 0.05135455461699636, 0.07977399960040085, 0.0515929879921098, 0.14723354950547218, 0.08053763604332363, 0.08982701136940911, 0.1614725806059376, 0.2174833984745126, 0.17672361385437751, 0.11916827846078143, 0.1568665229264767, 0.1270272527190466, 0.18388809876576548, 0.11477369169193892, 0.13803680187031148, 0.08710713110743992, 0.34063814568423456, 0.2724340425864343, 0.12599034505265375, 0.23938540789869525, 0.2617838576195702, 0.12966672439248333, 0.25743238627910614, 0.1289386037857302, 0.13400845109455048, 0.2886988246633161, 8.457962716779402, 41.199211305187596, 65.62256697685488, 54.1507677878103, 50.82460964879682, 41.045568143167806, 51.61424160003663, 44.11317148516255, 20.35174519784989, 2.9713937303712292, 0.28236444198316146, 0.5756877410796382, 3.9164397937636224, 9.628568599301001, 12.311949306918729, 18.31021231989707, 24.79647113430885, 18.541483109997166, 24.358516931533817, 38.580719347923036, 55.42913490726102, 55.22039813380088, 50.4725573139806, 52.143388948132916, 53.697577138100904, 57.76906405725787, 51.7008279215905, 50.81315632789366, 53.53409667168894, 55.670203778051565, 55.134215816374756, 54.017144403150006, 54.01281802884994, 55.406024302205736, 57.03980915008053, 51.870584180278165, 48.057695204211825, 43.260318771485366, 40.26090583493633, 38.32176446914673, 38.85468121497862, 44.652324799568426, 46.864941658512244, 52.21612145823818, 54.96545191734068, 55.452720119107155, 54.58141265376922, 49.59255003160047, 43.00732589537098, 39.27151541556082, 39.79122946339269, 39.214244888674834, 38.236903990468676, 37.1329568278405, 44.064232072522564, 52.37505589762042, 55.84009731969526, 54.120157610985544, 56.854971378080315, 58.72862485147292, 55.33992844243204, 54.72063718303558, 57.40392277317663, 55.18671281876103, 54.5889671387211, 36.44341984102803, 47.02376234915949, 56.39511662144815, 46.65671871554467, 48.421714690423784, 47.008653379255726, 47.071175959802446, 48.33071178005588, 48.917098276076786, 45.94904076668524, 44.63357979251493, 41.10883205167709, 40.3715794317184, 37.75061638124528, 39.99952693139353, 40.97227473412791, 40.117413766922496, 39.251683911969586, 39.684588063147764, 40.43660448443505, 38.771444597551906, 37.211000227159076, 41.16510237416914, 40.31641129524478, 40.45660857231387, 45.61868698366227, 42.06395664522725, 42.63455952367475, 42.395569509075536, 45.86549035964474, 47.7195555163968, 50.95947250243157, 54.37493124315816, 59.57453496994511, 51.29903601061914, 57.104049728762725, 56.516576736204094, 54.865533459571104, 44.164758497668856, 45.34923976467502, 50.298251105893044, 54.70575178823164, 58.140116353188795, 56.135361579156694, 57.310268340572236, 63.814436697190814, 52.05874419981434, 34.836581676237046, 19.32931665451296, 12.883653390792109, 9.877243926448207, 17.170153856277466, 11.452180474035202, 16.82658560814396, 2.6954062042697786, 0.7180938028520154, 0.6409040093421936, 2.260800725029361, 19.013710983337898, 51.790053998270345, 52.906180120283565, 41.88455135591569, 48.97048957886235, 61.21764721408967, 64.29693137445759, 39.08935662238829, 6.270547576488988, 0.3460276048750647, 0.1397277724238173, 0.22627506945883075, 0.1562402613701359, 0.14947233421187248, 0.12669998761867324, 0.17451844508609465, 0.16720213686987279, 0.14217686358719103, 0.1794197836950902, 0.1463274819956672, 0.14296953476244403, 0.09010062733244512, 0.19950645585213939, 0.14274841114397974, 0.1250013332032869, 0.1631605634165387, 0.14854034228670984, 0.0929927854468265, 0.18415045323631457, 0.17281670333637347], [0.027191881015295946, 0.03132486599497497, 0.02946917313121019, 0.04069547153889172, 0.05599148180936614, 0.024599887640966524, 0.015783486380842666, 0.01608503295198804, 0.018821497102298083, 0.012345179397192214, 0.011366238731199936, 0.031386112809301384, 0.033969790299212745, 0.03422243460532158, 0.03820684257774584, 0.0613321450298592, 0.025893022989734046, 0.0732843155762361, 0.10132039101013254, 0.02514336190576996, 0.023169827482272542, 0.07576694606893486, 0.08419540710747243, 3.8024591486300197, 32.43715801546651, 49.131522486286784, 50.66977800861482, 29.002173716022124, 30.77322583044729, 53.914382227005504, 35.75394168976815, 20.823643592096147, 2.3119758886675683, 0.2903420526173807, 0.20660579264644655, 0.6004767528464717, 3.9791420678938594, 6.9246675218305285, 6.814884303077576, 4.441978806449521, 11.225648887695806, 19.871380367586692, 34.64299701875256, 49.26580090676585, 48.64196362033967, 45.4137509868991, 48.377839057676255, 52.86459515171667, 56.18291247275568, 51.993417124594416, 50.22979790164579, 48.88603310431204, 46.000847431921194, 47.75042456965293, 48.9566396897839, 52.223813226146085, 49.32200847133514, 50.683655354284475, 49.21260964485907, 47.43531311711958, 40.752010114731334, 35.66303683865455, 33.84199411638322, 37.3710564644106, 38.841745238150324, 43.87958649666079, 47.800846638218054, 52.26493143266248, 52.48585893261818, 53.310913808884166, 50.76129082710513, 49.68334113397906, 39.603183192591516, 36.65174084324991, 36.661966462289136, 35.34009241288708, 35.857351056991085, 38.87157878568096, 40.48497515340006, 47.37389272259128, 46.4096760749817, 50.891458603643606, 47.48563712643039, 51.76145207497382, 50.17798339166949, 52.88130052628056, 47.12340624101701, 57.28673019716817, 35.884913552191954, 40.654013618346184, 55.162707913306456, 45.23139215284779, 46.75695488529821, 44.37257743650868, 49.0711493645945, 46.97660369257773, 49.569396280473285, 46.134521807393725, 44.053374951885594, 39.02417075249457, 35.15134796019524, 36.42086621253721, 34.852804599269746, 37.050159515873084, 35.48754999714513, 40.80891193882112, 37.27821004006171, 36.14840661325763, 35.959148330073205, 35.96743629824731, 36.93482222095613, 35.45848915653844, 35.89378595352173, 36.81534682550738, 36.494010571510564, 36.90094863214801, 38.10199406839187, 39.3771291548206, 44.043192478918264, 45.4766030465403, 46.759096499412294, 53.08222393835745, 53.45364493708457, 49.082579151276626, 54.54722135297714, 51.40764644069057, 42.99040086807744, 40.8159133695787, 42.546729810776256, 45.6883482779226, 47.77168773835706, 51.134049354061005, 53.418527956931825, 56.46393852849161, 46.80827517663279, 28.873296399270338, 11.538091167326897, 8.915640557965926, 4.464742772040829, 2.313024877540527, 8.899895183501705, 4.702744839652892, 2.2864204212542507, 0.2982494895977359, 0.19123390136707216, 1.9969720561658184, 15.644853922628588, 35.81997479161909, 37.669078150103175, 31.440173887437393, 37.87905831490794, 53.16218929906046, 47.71504871306881, 28.943010645527995, 4.375271056928943, 0.07304766335554662, 0.013226812532652291, 0.03784112752445283, 0.0174875809781013, 0.051498207594117815, 0.016421144452667045, 0.04202466473103531, 0.0665637479734517, 0.003372248897757081, 0.03129159288120366, 0.04783336170798829, 0.021947637620952823, 0.026386310834617867, 0.08737477158466656, 0.016200662432839314, 0.06078972030551203, 0.07450100875669911, 0.06856523694530611, 0.04636056916487794, 0.02185492374513659, 0.014318545281346289, 0.07090808703534066, 0.03733910627723221, 0.05656717773226481, 0.0621514645735583, 0.024179527536034588, 0.013747118383405671, 0.05721284046528801, 0.027920444037825353, 0.07157043899379431, 0.019467853144892765, 0.027070247320338126, 0.033360574199187185, 0.05989401413488293, 0.03509087187628593, 0.0465312305717699, 0.054185065636110884, 0.04607636586672837, 0.08461051951012305, 0.14114537216242284, 0.026949192021763133, 0.05116187584316058, 0.0262536263213523, 0.06118650788501386, 4.901217750964626, 37.32470581608434, 53.59491302121071, 54.86934992574877, 35.71116432066887, 31.4522724382339, 55.78369755898753, 38.89986299699353, 22.394976462087325, 3.1186250428999625, 0.13713462608716182, 0.12221814343525518, 0.8212792272529295, 5.228947958638591, 6.80678068630157, 10.9639669810572, 7.147315471403061, 13.015956897889415, 26.348429456833873, 35.802865412927446, 53.956900719673406, 49.77594437137727, 49.73367298803022, 49.996738510747115, 56.22889049591557, 55.316708011011926, 52.38188082172025, 52.18804121017457, 52.13838792616322, 48.9036367016454, 49.82292652130128, 51.74855924421742, 54.636776908751465, 51.30294661368094, 53.94693005469538, 50.87911490471133, 49.17571975338844, 42.99084017353673, 37.73975926060831, 35.82126917377595, 39.09413406925817, 40.160453934823316, 47.220339775085456, 48.74138393709737, 54.18351957874914, 55.32701599982477, 55.413441504201586, 51.2058130387337, 50.55082821076917, 40.50763076351535, 38.89198687768752, 37.980055424474905, 36.82223450752997, 37.26651353220786, 39.1103099238488, 44.321688605893044, 50.43366309135191, 49.480774248799975, 53.45913233295564, 50.333728944101644, 53.69946772052396, 50.31044967712895, 53.56472253799439, 50.45209430879163, 59.61781832479662, 37.502961850935414, 42.27584700430594, 55.27051033512239, 47.337438214209776, 49.93990728932042, 45.93872885550223, 50.40185266925443, 49.127223568577925, 51.012546093233176, 48.01265462752312, 45.9832634464387, 40.540645353255734, 38.2073450088501, 38.432461600149836, 37.300893106768214, 38.96082447421166, 37.908974232212195, 42.123835548277825, 39.02460221321353, 39.498098973305, 37.99140676375359, 36.69260801807527, 39.661289184324204, 35.9561594840019, 37.85144090652466, 39.781909911863266, 38.05607095841439, 38.738057382645145, 40.676865346970104, 41.35323885948428, 45.26084915284188, 47.27594721701838, 49.767272010926284, 55.67040774130053, 54.05985509195636, 50.41742447883853, 55.82749082196144, 53.79063144806893, 45.831750131422474, 41.50520716944049, 45.77265570240636, 49.13899852383522, 50.85631024452948, 53.14622525245913, 55.20484593606765, 58.36279715261152, 48.79796020446285, 29.233473923898515, 15.635954064707603, 9.926607935659348, 7.735790629540721, 11.145609982552068, 10.908066341953894, 8.372984566996175, 3.1084489437841603, 0.30709581329457225, 0.26989501270075, 2.284796314854776, 17.496904942297167, 42.87298471696916, 41.690786269403276, 34.608421325683594, 42.85498888261857, 57.75774801931074, 55.0292218116022, 35.39003202992101, 5.1158336670167985, 0.08628350998004598, 0.027092733916135568, 0.03605749097562606, 0.015046595024966426, 0.03749971278011799, 0.0427174303800829, 0.023389547244615616, 0.046309723909343445, 0.06588114065028007, 0.011420471052969656, 0.059026982635259635, 0.023664733687896403, 0.0070237698814561295, 0.07439533458842386, 0.04282074499755137, 0.025116646504630486, 0.14163519345944928, 0.04438547958289424, 0.044988957684366934, 0.05248696663446965, 0.09154107181295272, 0.1446062662909108, 0.08872887029522851, 0.16162066540170103, 0.18828230249064584, 0.10066753088106072, 0.09843020940259581, 0.13908035151900786, 0.0798774904180919, 0.1085350240370439, 0.1604376877507856, 0.1520528400977773, 0.1141329663955877, 0.09186315815895797, 0.10250578183800944, 0.1216720989454658, 0.15984314223451002, 0.13081034044584922, 0.24701596538145698, 0.12262140445771719, 0.12214661380576512, 0.14854492349249704, 0.10807242184396713, 0.22830705639095078, 6.646779362232455, 42.07455881180302, 61.716580544748616, 63.1163489434027, 41.67623035369381, 41.90195883474043, 62.91826140496039, 47.017870949160674, 28.287635541731312, 3.7743916482694693, 0.5750204478540729, 0.26374133484017465, 2.3061698002199975, 6.920134732800146, 13.013746642297315, 18.35956750377532, 10.205930702147946, 14.238655778669543, 22.13576074569456, 39.47556495666504, 54.251207920812796, 53.562169075012214, 49.93809123193064, 53.149590646066976, 58.32254186753304, 56.621919831921986, 51.91853515563473, 53.78792109027986, 54.26512841255435, 50.1879148329458, 51.83482393141716, 54.2316274489126, 55.45988236704181, 52.38946276326334, 54.07686248902352, 52.902795114824855, 51.895295112363755, 44.982125528397106, 39.846629019706484, 38.32512986275458, 40.16594525306456, 41.77443865806826, 48.55207466310071, 50.990494528124415, 56.120613467308786, 57.58529316994452, 57.19639016735939, 54.75134934148481, 54.621036437249955, 44.713937390235166, 41.71498337099629, 39.95256831569057, 38.85441449380691, 38.47049682371078, 40.78389898423226, 44.81009037263932, 51.3518468026192, 50.09059690660047, 55.85974447188839, 52.590213591052645, 56.334072774456395, 53.727187110531716, 55.97589761980119, 53.19607465497909, 59.800467414240686, 41.66597727806338, 46.29031050589777, 58.07906073908652, 51.439817720843905, 52.65559557945498, 49.009132769800004, 53.303500529258486, 51.72290694329047, 53.06767586738833, 51.536966985271825, 48.502331164575395, 44.1110534052695, 39.543763206851104, 39.75936412811279, 38.82809538995066, 41.09631969082741, 39.867986325294744, 43.5148060706354, 41.53442882722424, 40.731562799023045, 38.85268080619074, 39.31336318292926, 41.416734187833725, 37.25182425591254, 38.804894570381414, 40.337898039048724, 39.71329981280912, 40.82360513748662, 42.18546775079543, 43.319460268943544, 48.62565440516318, 49.498016988077474, 51.59969352906751, 57.832237751253196, 55.228603732201364, 52.00784752445837, 59.16232916616625, 57.08160200426656, 48.96431576821112, 44.592814599314046, 47.7312167229191, 52.06730281153033, 54.177310466766365, 55.78837302423293, 58.56514046269079, 62.77328275865125, 52.02590611673171, 34.84390474134876, 17.032898356837613, 15.142446352589516, 9.063938510033394, 11.85146991283663, 22.079598288382254, 7.4426969116733925, 5.590597352673931, 0.672946157715013, 0.504434056459896, 2.7343705392652944, 21.06796214657445, 48.54268058653801, 52.731058059200166, 44.344701151694025, 50.748480366122344, 66.01930295267414, 64.64749320860832, 44.02536922885526, 6.608422014021105, 0.1467558323976494, 0.1312304937070416, 0.2328632570682995, 0.1154958444737619, 0.18603671492347795, 0.10478375960261592, 0.16346030297779268, 0.2717954316927541, 0.09965247204226833, 0.06538268554234697, 0.11544738941255117, 0.1102276570013454, 0.09351090603177586, 0.13572001409146095, 0.150445465058569, 0.07858779671932421, 0.2524207156872557, 0.11455537961615671, 0.15894384694195565, 0.13471386485522793, 0.20632958730622647], [0.01446941959476399, 0.018617800068891337, 0.01981161594871552, 0.01568663754545513, 0.01832997317485992, 0.03771112240370243, 0.03708686799772325, 0.032127959796437816, 0.04639121268184916, 0.03086317161608848, 0.09212771896272899, 0.10657846612194855, 0.06388624386501408, 0.059781923980241826, 0.03900536666474035, 0.03993643545395425, 0.05743417092749188, 0.007118804046073028, 0.012871488504442237, 0.04405868179615467, 0.016501032101411014, 0.018294055142530033, 0.03341604662578433, 4.825398825830029, 28.143160919989313, 50.73869797491258, 52.2962397913779, 45.42764402204945, 41.01968050003052, 35.519505546938994, 41.853074335282855, 22.25139614074461, 5.260853498212753, 0.12390075596950709, 0.08321987074469367, 0.7419730698870075, 5.940668400256865, 6.8772284157814525, 12.194232113899725, 7.949110202250942, 8.086356386061638, 17.31717997981656, 30.013092064088394, 45.22788163154356, 48.920950043586, 48.85034738048431, 52.36678754129718, 56.779363770638746, 49.296128672938195, 50.279278601369555, 48.533459094262895, 46.832919428425456, 43.66004359337592, 45.54541710884341, 47.890253143925825, 51.76718658016574, 52.041019009005645, 51.79345077083957, 49.28720920316635, 46.02868057066395, 39.64118703719109, 36.049001985980624, 35.26965841170281, 34.64143199305381, 36.78052402311756, 41.806472655265566, 47.123825934625444, 49.96101356321766, 52.457715926631806, 52.30479448072372, 52.001834530984205, 49.73941926033267, 45.278754772678504, 41.905296771757065, 37.06708454316662, 35.06920960641677, 35.83075738722278, 37.92436953513853, 35.930032576284106, 39.77490848110568, 40.44970912318076, 44.68106008345082, 44.87688049193352, 47.771840710793775, 45.04908038723854, 49.35983973164713, 45.77038465007659, 56.41947454021823, 40.465975192285356, 39.74786766113774, 56.83583021163941, 46.02383644350114, 51.743930847414084, 46.88658137475291, 50.59683369052026, 50.281435904964326, 51.98441920741912, 49.79535618136006, 49.04991757485175, 46.13918550552861, 38.713538646698, 34.57143729732883, 35.62635091043288, 35.7152122066867, 36.17452175386491, 37.3272906580279, 38.99641606115526, 39.54587344200381, 39.45623943882604, 36.09821988690284, 37.48395796745054, 36.35289545982115, 36.07115553271386, 34.432593237969186, 37.91029214859009, 38.779626661731356, 38.22737655332012, 36.46445551226216, 40.486226389485026, 43.065745676717455, 49.313598909685695, 51.619540722139426, 51.037511979379964, 53.13897671238069, 53.15784331290953, 54.36647853543682, 45.30372065882529, 39.834214718111106, 41.74554255700881, 42.56482762675132, 47.20484641290481, 50.42461418336438, 53.305728435516365, 55.055772335298606, 43.967420131929465, 22.7989060648026, 9.81668645335782, 6.622160115549642, 11.933611208392728, 12.36837358244004, 9.9518483877182, 9.10400159897343, 1.5973823108980734, 0.04003044593358233, 0.14732544941286888, 2.3991182061933705, 18.821277541498986, 40.60637643260341, 46.50539367429672, 38.08801081872756, 35.325407058961936, 52.56207450743645, 50.15062878208776, 28.089948085046586, 2.8288266062736516, 0.050269050163126765, 0.03915405283952433, 0.06817692995912607, 0.027859139766904618, 0.1233653447801067, 0.023527979332533096, 0.08302415826267774, 0.0341869111082727, 0.04446021912078704, 0.05650724284350873, 0.014929369208402933, 0.008257485535596649, 0.04686896426362857, 0.07045595726418881, 0.05021165485583967, 0.0465411629017082, 0.003928242715060591, 0.014120908961030505, 0.05612672314107899, 0.02524530522585396, 0.03268984506928152, 0.030934586332389907, 0.024514886355327985, 0.009313180550722586, 0.02442274704545496, 0.04143578443495978, 0.02566615754227725, 0.0025493790153338905, 0.018101154203196208, 0.06839721854175292, 0.012991370730883172, 0.0776454855898215, 0.059764269484026786, 0.009308742986421191, 0.03161607899763171, 0.009216511745997255, 0.036778567403915434, 0.014787051139489539, 0.0433066975505602, 0.01722872944458598, 0.1143703923650807, 0.03942262028313933, 0.036490499192187865, 0.017539190406340267, 5.712623759623497, 32.16776570966167, 56.349530835305494, 58.14145780378773, 46.02588784310126, 42.98439571934362, 43.80580671371953, 47.45566237357355, 25.88311868329202, 5.674279649411479, 0.20251646127191283, 0.05743728507490409, 0.32806777665691994, 4.485132723085342, 6.905742085749104, 6.70992216756267, 6.890588498884632, 9.809791907187432, 24.12156851060929, 33.269524189733694, 49.001715567804155, 51.26397394364881, 51.6405842381139, 52.39284384635187, 56.83722657542075, 51.68453831826487, 52.51394310305196, 51.31638857626146, 48.42962218869118, 44.44453331731981, 47.99456073391823, 49.85688640225319, 53.1103277206421, 52.46426628481958, 54.015430327384706, 52.6813930080783, 47.16395570385841, 41.086019546754905, 38.683501135918405, 36.52882160678987, 35.490660436691776, 38.59163530411259, 44.0163242432379, 48.19120484013712, 52.561031156970614, 53.799496004658366, 54.44996226218439, 54.833691658512244, 51.38555172950991, 48.516867468434, 43.27908339038972, 38.221630281017674, 38.4657625229128, 37.152278423309326, 38.89008845052412, 37.47845095972861, 41.247687878147254, 43.95056570729902, 45.932139273612734, 48.09783674055531, 50.85285463640767, 47.150953046737186, 52.079689656534505, 47.18557188587804, 58.94333147233533, 42.959527892451135, 42.19406166384297, 57.66129301440332, 47.708282624521566, 52.19457980125181, 49.458110793944336, 52.660953537110366, 52.296537891511, 54.12857893974551, 51.431741560659106, 50.897255866758286, 47.36760908557523, 39.461703300476074, 35.90766722156156, 38.122841465857725, 37.49363837703582, 38.28349782574562, 38.943703328409505, 41.44142943043863, 39.615966196983095, 40.56412858347739, 37.9833149140881, 39.34777413645099, 38.08027590474775, 38.62674443952499, 36.004910622873616, 39.45238374894665, 40.00048006734541, 40.25741884785314, 39.81494019108434, 43.16036893475441, 46.61183111129269, 52.74955595693281, 52.146330725762155, 52.454864363516535, 52.38342231319797, 55.9539637257976, 56.457388170303844, 47.97680024177798, 44.024992681318714, 44.34756840428999, 45.0668251898981, 51.13159787270331, 53.61393259417627, 56.02504884043048, 57.654687743033136, 48.47584732117192, 26.8483708366271, 14.0708303066992, 11.313446241040385, 11.083597310127752, 14.925690293312075, 7.1297481559938, 6.323556938479024, 0.6504448070641488, 0.20224161956819797, 0.21264907723713308, 2.5248264929940625, 19.99160493573835, 45.539651224690104, 51.78403316005584, 42.68287527945734, 41.17721465326125, 58.47455724593132, 58.09571904520835, 32.71065704284176, 3.782437410085432, 0.03914335442166175, 0.05982862853054559, 0.06293032701397616, 0.03895838632278385, 0.12434255121456039, 0.03095890196310657, 0.04968994131852543, 0.05172268667769048, 0.02465975166658961, 0.05873297724211889, 0.049462271478748134, 0.02087661988973137, 0.028629831879610018, 0.05150939630825193, 0.02957279035340875, 0.038926524726013025, 0.07096641696989536, 0.07735909894108772, 0.019173627501473795, 0.03974968237021277, 0.06922144487860703, 0.18488727660188753, 0.1590355629882505, 0.0668976397343701, 0.11672106421282215, 0.09388701689820136, 0.12801961237264256, 0.12153746665365274, 0.15490561363197144, 0.4802884666189071, 0.13104367550582657, 0.1636417125982623, 0.19151576043617344, 0.17082364899256539, 0.16603164645212312, 0.1332935991306459, 0.18039299115057916, 0.14496490269178344, 0.2354384769475268, 0.0783446250903991, 0.28508543307262085, 0.09525904972707072, 0.15272954088305274, 0.18281689334300258, 6.459932846407737, 38.12278263030514, 62.889514353967485, 64.30549390854375, 56.24864747447353, 52.38557569442257, 47.70843559695829, 55.43392412124142, 30.485661183634114, 6.828746449562812, 0.3593119372042918, 0.2090897101668581, 1.2762322469103722, 12.453304663781198, 15.461761605355049, 20.304694406447872, 16.357776080408406, 13.90323821575411, 25.247098515110633, 32.990188675542036, 49.81629379333989, 52.64291847905805, 55.10054619081559, 56.228721833998165, 56.40485194421584, 51.78846151598039, 55.86667922235305, 51.09023647923624, 50.50588569333477, 45.927000968687, 51.06673363716372, 52.38517953503517, 55.714079410799094, 53.96782059823313, 55.5921878353242, 53.441132576234885, 50.37214855993948, 44.453617526638894, 41.57253073107812, 39.965237571347146, 37.576015995394805, 40.54803117629021, 45.13774164261357, 50.89500442627938, 54.31935910255679, 56.49980860371744, 55.042440199082904, 56.4306297609883, 54.339461249689904, 51.70957872944494, 47.271099167485396, 39.98473567347373, 39.40031036253899, 37.9661427774737, 42.15921532723212, 39.36588764190674, 42.81876187170706, 45.577694292991396, 48.23315458913004, 49.95630671901088, 51.65460278910976, 49.712041116529896, 54.241382383531146, 49.95503194870488, 60.25051624544206, 46.480686664581306, 44.40343864502446, 59.80478594380041, 50.76667231898154, 54.1822212742221, 53.27889942353772, 53.753894529035016, 54.565860456035985, 55.598036089251124, 54.86669448114211, 52.92132439151887, 50.729743203809186, 42.3600406800547, 38.464252410396455, 38.98972842001146, 40.049709735378144, 40.49939770852366, 41.43027420966856, 44.11341467211324, 43.219604569096724, 43.301558571477095, 40.44204481186406, 41.192029445402085, 40.49782483808456, 40.45493372025029, 38.68090452686433, 40.81950233828637, 41.960719862291896, 42.238576642928585, 40.58689009758734, 45.087762801877915, 50.47208662955992, 56.716711751876346, 55.027197868593284, 53.37567998516945, 53.73657726472425, 56.708015857204316, 59.59587658605268, 51.2382314282079, 45.45330024534657, 45.920317249913374, 46.504260109316924, 53.80506969267323, 57.87944347627702, 58.67833222112348, 60.35310975966915, 49.338451047097486, 28.805568833504957, 15.046800336530133, 11.918844465286503, 22.306309323157034, 22.221795974239228, 18.13402533531189, 18.841083549684097, 3.628519927301715, 0.6865311642327617, 0.4360076959335035, 3.0293423370007546, 23.710496271810225, 53.140679021035474, 58.96095075914937, 50.83821635092459, 49.98267681367936, 66.39310483009585, 64.82695733347248, 38.28392928646457, 5.185407198244526, 0.1189988044901721, 0.17982735779256592, 0.10903318037068653, 0.06729305601648747, 0.2784421024543624, 0.13064891039844484, 0.11786556126730097, 0.14005095427555425, 0.09890801844096954, 0.159447074777657, 0.12847404040756727, 0.10170541913999666, 0.15366220696558877, 0.19333396287214374, 0.14069316578247856, 0.19919026072227186, 0.10589636441680694, 0.13806782843124482, 0.11216968222851716, 0.07302102647841939, 0.12747547544178464], [0.02292538989305256, 0.022903443389241735, 0.0833873758693376, 0.028416478307917718, 0.02658488848547061, 0.09668454017129638, 0.04474331159144641, 0.055340322395486224, 0.03892640215194514, 0.048780686882955414, 0.019049239720428185, 0.037357067208616965, 0.06667878373616165, 0.06981487190651317, 0.05971241299243224, 0.036667113102251486, 0.07185033687780942, 0.030923194604955857, 0.02524628390317723, 0.05173062717902565, 0.04333768580709735, 0.04599715237535777, 0.06352664219335684, 1.9696798367846398, 20.852469090492498, 43.51976394653321, 49.090306220516084, 42.34395111760786, 33.73534487139794, 30.720452300963867, 39.712472192702755, 30.675900059361613, 8.196324446508962, 0.7159618720892937, 0.13807096939173438, 0.15466179848918993, 3.303817544252642, 4.382259249687195, 3.9977176775855408, 3.8417355572023704, 8.440617995877421, 23.020302287993893, 23.53881020699778, 41.88582220385152, 49.85042625857938, 52.719451765860285, 54.535724886002086, 47.61636972427369, 44.37841784569525, 53.78123344913606, 48.303725873270345, 44.579474618358, 40.37169710282357, 42.3978993969579, 44.280484107232866, 47.58493192734257, 49.64309369364093, 53.34422257638747, 48.81541475172966, 46.01907468611195, 38.462628549145116, 35.68073457287204, 34.26663775597849, 35.383230640042214, 36.11749049155943, 38.49490181092293, 42.33712619350803, 47.170921833284446, 48.354732374991144, 51.51534295851185, 48.94273488752304, 51.871490247787975, 50.45537341025568, 48.53085071809831, 37.946985921552105, 37.226979963241085, 35.448581249483176, 36.500121624239036, 35.87537434793288, 38.10093502844534, 38.79914829807897, 38.693683608885735, 38.34199997686571, 39.73148784329815, 40.35865522200062, 45.21383170158633, 47.30163481927688, 53.88257180490802, 42.33987577499882, 34.533735475232525, 50.42106051598826, 48.58073149957965, 51.498437543069166, 49.743616196417044, 52.300589699899, 52.03637492272162, 51.440888527900945, 50.53941411356772, 50.64061518638365, 50.029364785840436, 46.316672755825905, 34.53641445406022, 37.22699957509195, 35.806521061928045, 36.99461875423309, 39.08902322092364, 45.47408488488967, 47.27848891289004, 49.468916923769065, 45.566817560503566, 39.48695551964545, 36.51525412836383, 37.42605986133699, 35.16422117910078, 36.60416249305972, 37.26392084552396, 39.151114340751406, 38.888864671030355, 42.670143265878, 44.94173296036259, 49.21339019652336, 53.0095188848434, 52.98713391826999, 50.88988573320451, 53.467432068240264, 51.755466538090865, 48.757446042953006, 43.79620867390787, 44.24364912894465, 42.26750412294942, 46.59975413353213, 49.273465218082556, 54.91409240230438, 50.76868449487994, 39.65947312693442, 24.4304375110134, 14.230412917752421, 12.980305494800692, 7.540839516347455, 15.412078903567407, 5.173594980470596, 4.929307314657397, 2.1009947840244543, 0.08783954946744828, 0.09606232355919578, 2.789203803385458, 21.47944623424161, 38.057981152688306, 34.31906415570167, 26.941313359045214, 42.69881186946746, 55.04218132265153, 48.61476982793501, 24.762556360613917, 1.905710514514677, 0.057954252697527416, 0.05930903322634198, 0.01624238358119563, 0.0715983935421513, 0.04783492452735382, 0.029207155739347783, 0.025137242778474768, 0.006303563441765765, 0.026868398474048705, 0.025083645352072297, 0.04274013339571896, 0.08726849220693113, 0.011472858060451766, 0.03547062166035175, 0.035202686239274285, 0.021905198265167496, 0.019981932616041555, 0.012349808483474679, 0.0058427170264504615, 0.054549918840489084, 0.026413968523904204, 0.03594294550918764, 0.02707869535492313, 0.027701534413462205, 0.030277424619623253, 0.016911456045965036, 0.03332076444020195, 0.06040342430013323, 0.05451750566041278, 0.03401331175419112, 0.008473837383902602, 0.08396281515278163, 0.04832224071686787, 0.03254702329755791, 0.04827972666750993, 0.04946684885409571, 0.01514456905199275, 0.02330786503490902, 0.05063609820940802, 0.009966971476622408, 0.014547454268341104, 0.029037122524553732, 0.0888153309783628, 0.04254796790079244, 3.028405135677707, 25.729706941112397, 52.01387620741322, 57.365393330973966, 47.80606339054723, 39.5687565495891, 41.09722575833721, 48.00100911048151, 33.87014104473975, 8.912102580070496, 0.6281515258935191, 0.14188503005331563, 0.3379063987203183, 1.947896831458615, 5.007023686362851, 9.750365057299215, 8.461141797804064, 9.318053184017058, 19.040473315023608, 28.08727106740398, 43.93994392887239, 51.94863934670725, 54.57980448199857, 57.28829130049675, 47.8788939599068, 48.5199700632403, 54.76996098795245, 50.36297021373626, 45.92244709691694, 43.23255231303554, 45.48492631604595, 46.969880750102384, 51.785931587219245, 51.61110762626895, 54.31108682386337, 53.21494517787811, 48.723615600216775, 42.01918671208043, 37.936858361767186, 36.97692494238577, 37.65554205063851, 37.83717132383777, 39.87814134167087, 44.5703786419284, 49.26771502340994, 50.670852738042036, 53.12926100146387, 52.325539896565104, 52.872486960503366, 51.964521023534964, 49.69599077778478, 39.29350030037665, 38.06713204230032, 36.86926372589604, 38.2812189286755, 38.005017388251524, 40.66901276188512, 39.592573181275405, 41.477511313653764, 40.03942528078633, 42.58994648533483, 42.276086268886445, 47.46607626638105, 47.673448055021225, 55.97015526986892, 46.18721100591844, 37.538451456254535, 52.09219025027368, 49.85410544180101, 54.06304397890645, 51.0144131414352, 53.24008364831248, 53.889388884267504, 54.96908795449042, 54.06297337624335, 53.92266235043926, 51.83799712888656, 47.48225212097169, 37.2330988607099, 38.94217752641247, 37.66104513599027, 38.170231542279645, 41.541159614439934, 47.71514284995295, 49.0384485644679, 49.77571687390728, 47.07370196619342, 40.29982359178605, 39.12472463423206, 37.60850890990227, 36.79829235999815, 38.827891426701704, 38.99036776634955, 40.213672653321304, 39.25643390224826, 43.51950114773166, 48.43706684727823, 52.32133903811055, 54.561843948979536, 52.59784652340797, 54.285387454494355, 54.87751630044753, 56.06494718982328, 50.372968335305494, 46.951300482596125, 47.29626901688115, 45.02838988457957, 47.76931078203263, 51.05425657764558, 56.91036308965376, 55.90085875603461, 43.88219879519555, 25.936610006516982, 19.60437286284662, 13.848906524719732, 9.650245578058305, 14.769741758223503, 8.390463629076558, 5.4443557031693, 1.4138110967413073, 0.3428155514261415, 0.1388685435297028, 3.2044504246404095, 23.792436545894994, 46.23336945810626, 43.065996708408484, 33.7826447333059, 45.080184782705004, 60.672618189165675, 55.256680057894805, 30.047322588582194, 3.377838552959504, 0.0639846631806464, 0.05774994087856143, 0.05939538665716687, 0.038485913086802735, 0.015471505692168592, 0.014849940254803629, 0.0405120202941039, 0.035034621870445634, 0.03247120357569187, 0.031161583930013642, 0.049847751600487586, 0.04053473097061919, 0.014993095274774298, 0.024394696736107432, 0.002992769877891988, 0.07000481574645928, 0.010665432031777118, 0.013610841875385134, 0.03204080963417167, 0.06851334214931534, 0.015418878324600238, 0.10735510307694636, 0.13086301665152275, 0.09869046479223237, 0.1435033295063242, 0.12304629214228162, 0.11568778780319038, 0.20721827994190878, 0.16541152892093505, 0.2017915429126832, 0.1583989439231734, 0.2866593147477796, 0.33679817592905414, 0.19432529596792114, 0.1753321683575069, 0.17869065185227703, 0.09455752769304861, 0.16955030361010184, 0.09576517337512586, 0.09663059225966854, 0.146210040716875, 0.1461798874961753, 0.1947304798710731, 0.21590530331577026, 3.2470358427493804, 29.781107402616936, 57.774602443941184, 64.76504664267263, 54.28778010029947, 44.67642776427731, 42.37702454290083, 51.996504029920025, 40.674547226198264, 11.924830002169456, 0.9640697425892277, 0.3915563940761551, 0.7019850575635511, 6.888573871504876, 11.325847794932704, 14.280633964846212, 11.301002521668712, 14.521775399484943, 29.002652245183146, 27.09360722572573, 46.50959453275127, 53.48653008860927, 58.14290123601114, 57.861404495854536, 49.62569405955654, 49.22515730704031, 57.201838339528734, 51.64473018338604, 48.39224984568935, 45.298790239518695, 48.42972809268583, 49.470309365180235, 52.61942740409605, 52.696007759340354, 56.91266944331508, 53.87133813673451, 50.60621599997244, 43.42183020807082, 39.370759225660755, 39.574000758509484, 39.74130945820963, 39.03450619789862, 41.530961451991914, 46.34119149177305, 49.990180307819, 52.619717659488806, 55.12481781744189, 53.03209212518508, 56.40791531532042, 56.42429513316001, 52.34166083797332, 41.66811889217746, 40.40065988417595, 37.71271451827019, 39.05073304330149, 39.760085844224506, 43.06251756606564, 41.49347536025509, 43.74479424568915, 42.472322448607414, 43.13868215007167, 43.671442001096665, 48.38808428856635, 51.8653085923964, 57.150992654985004, 48.50473165512086, 40.78343614455193, 52.60304366388629, 52.83081177742251, 55.56743375716671, 54.265916808958984, 55.46376159114223, 55.94776245855517, 55.591670082461455, 56.830244756514034, 54.72163346505935, 54.97904685235793, 50.335545001491425, 40.174201842277284, 41.08230898457189, 39.22582764779368, 40.637680868948664, 42.755533264529326, 49.6708248507592, 51.863665119294204, 54.56721759611561, 50.1598894980646, 43.509773669704316, 40.797846932565015, 40.1117733986147, 38.540362081220074, 41.29747452274446, 41.56878094519339, 42.29484304305046, 42.47951215313327, 46.758539522847826, 50.781977407393924, 55.40205486359135, 57.32480464443084, 53.83653886856572, 54.459548534885535, 56.707890341358805, 56.98384085009175, 53.072304264191665, 50.72114536839147, 49.67254284889468, 48.050603558940274, 52.28076996341829, 54.58859451355473, 59.42176649647375, 57.73510025393579, 46.88020752322289, 28.203124153998594, 17.96962115072435, 21.512623602344146, 13.492821012773822, 24.23320701045375, 17.451023017206502, 10.451752504994793, 4.0561761923374675, 0.3729242470956618, 0.36957463489905484, 3.8614768462796367, 27.10155002532467, 48.60768994977398, 46.28551344717703, 38.12094303869432, 55.110312892544655, 69.64815432025541, 65.14214723340928, 34.40048471573861, 5.207053778632995, 0.20056057751419085, 0.1488136977798516, 0.20805817277681446, 0.2678604670349629, 0.1083988059432276, 0.11315290245317644, 0.2590559410952753, 0.12666257188445137, 0.15515146656863152, 0.11242394681058585, 0.09608519128373555, 0.13859687342999444, 0.20070582778463442, 0.11450494038722209, 0.17240508429465756, 0.1606430606015267, 0.08878955211971076, 0.10785597136184093, 0.08861605618749896, 0.13926068861638347, 0.17106611582060016], [0.026239553286183267, 0.04482063667608365, 0.004718391545822904, 0.008696163760408038, 0.011978130393301048, 0.05850341133472901, 0.00948368682480988, 0.10197280680820828, 0.08224991150200367, 0.03778416122640333, 0.051498046715653716, 0.023586822545997078, 0.022762169115125172, 0.020048398404352127, 0.06276465283947126, 0.023208863492454254, 0.02560038123309853, 0.1248679266521527, 0.025363183174762997, 0.028058027683366692, 0.031923596266536944, 0.02459684435668732, 0.022583806609374382, 1.0300467668041107, 13.93087915835842, 38.99531387513684, 48.48142100918678, 49.164054624495975, 27.69972912726864, 29.74189546800429, 39.1830502786944, 30.302251154376616, 11.469292794504474, 1.1589109681306349, 0.059994888762312557, 0.04462058813641629, 2.499374968390311, 4.161742127710774, 5.839824753422891, 6.789639928648549, 3.730514054336856, 6.615545038254031, 18.57802587170755, 31.144797840426047, 46.46486382330618, 50.252037740522816, 55.49636825438469, 49.080088446217204, 55.37868930447487, 51.64948801840506, 45.64231141921013, 45.41467666625977, 40.36164014570175, 39.792516000809215, 43.35228658491566, 46.41415149934831, 52.19178315131895, 51.90845466429188, 49.24143906562559, 44.957202788322206, 36.26648172255486, 34.93120885664417, 35.21422355405746, 35.1724071656504, 34.41870020281884, 36.285030611099735, 39.08626971706268, 45.42775384841427, 48.991568396168375, 53.84258716337143, 52.822606179022024, 49.77825856977894, 51.64542444290654, 48.26937767767137, 47.04842229043284, 40.817082235890055, 36.468264133699485, 36.229438858647505, 35.761915868328465, 37.60291561003655, 39.35932551660846, 37.79175419961253, 35.56172986184397, 37.22352435511928, 37.718876561810895, 43.08477701679353, 46.21055695318407, 55.17380429852394, 44.71774601167248, 35.79517364501953, 53.61991813105922, 44.943192082066695, 51.22287927135345, 46.44992351531983, 51.41633449062225, 50.25481477860482, 53.43905764241373, 51.60486713532479, 55.198915312367106, 52.178223517633256, 49.298533085853826, 37.78968318816155, 37.5355802812884, 37.501016355329945, 38.69109092220184, 42.62684814391598, 49.695351431446696, 51.23935714844735, 54.0890924392208, 50.51769202755344, 49.35592912858533, 40.456008449677505, 38.62469303992487, 36.73732303803967, 39.276645875746205, 38.209757266506074, 38.82973886305286, 40.04018229822959, 44.76634025573731, 43.889388499721406, 51.91249078319919, 50.27939627247472, 54.61177179890295, 49.4569536947435, 51.20484813567131, 55.533713140795314, 54.0885550745072, 50.12676900432956, 47.462220576501664, 47.790366065117624, 48.78832686331965, 48.83314386490853, 54.785626934420684, 48.26864811681932, 43.506580860384055, 24.788102757546213, 16.876905695084606, 13.8401763093087, 7.53704805527964, 12.594950276036418, 4.3056651661472936, 1.8787263237660932, 0.18966643950871884, 0.32125541639904825, 0.17982207178588838, 3.8716813825791885, 23.10800256267671, 45.17633776510916, 35.75226683770457, 33.95776679438929, 44.42216011785692, 55.687795608274406, 47.61531068432716, 19.747766871606153, 1.0831187641428364, 0.06892486926048033, 0.03542019009229637, 0.04820591792644513, 0.011041188582537637, 0.026706378538942626, 0.047241489838568435, 0.015377621617048018, 0.0778373446495783, 0.04118659135494982, 0.041523624076357776, 0.023594694099419063, 0.022267682342639854, 0.027835569156694318, 0.07742852948966526, 0.11468029025221065, 0.05848978646099568, 0.03404891952091167, 0.03831208773678349, 0.07997299093873271, 0.02915997046887154, 0.03997839408956709, 0.021447409019475023, 0.022971046818119865, 0.06823219554198366, 0.04772325189063146, 0.05966768494897312, 0.0267206373504333, 0.05857181532548801, 0.0666503005871369, 0.06532427899899983, 0.056528551579122586, 0.07622550331777142, 0.00265294237197527, 0.06842423846284229, 0.10636517958294962, 0.018097017328405095, 0.030879514186733195, 0.01828577564728837, 0.03729873727406225, 0.06906940706915433, 0.008911728453371794, 0.02753405418667582, 0.02879850337311866, 0.013374473107227636, 1.3167348864578432, 16.098688821638785, 45.048131173656834, 54.161483703121064, 51.86996836816111, 31.578258968168694, 31.415215846030947, 45.44746768090033, 36.33653525383242, 12.90522740733239, 1.2729707961120915, 0.09799996676344065, 0.1088562447036947, 0.5161043641067321, 3.9957714465356644, 8.010211413906466, 6.634243957458004, 6.10134143021799, 9.16517194240324, 20.691430299512803, 35.51334350339828, 50.474816599199855, 53.534892912833925, 56.89575226076188, 49.69298624223279, 54.2918711323892, 52.848030982478974, 48.44961843182964, 47.488747565977036, 41.955624703438055, 41.37947951593707, 45.56442099232828, 47.430143433232466, 54.284332336918006, 52.96033236288255, 50.703588839500185, 47.356638216203265, 38.90703308966852, 36.140138256934385, 36.533536295736994, 36.9404508221534, 36.37767307219967, 37.28583905004686, 42.04147361939953, 46.72237526985907, 51.609989750769834, 54.984067486178496, 52.22241293999457, 52.86395580537858, 52.75581605972783, 50.53869239745602, 47.13928007310437, 40.95930345596806, 38.724081977721184, 38.605363599715695, 38.11829151645784, 38.596644170822636, 40.878647758114724, 39.73115836420367, 39.09093341519756, 39.30200007654006, 39.49575731831212, 46.38180371253721, 48.86829222402265, 55.4838990396069, 46.27665281295777, 37.428511342694684, 54.128873117508434, 45.411785879442775, 51.47284015532463, 48.568062243923066, 52.8604962748866, 52.34446141027635, 55.143386317837624, 53.32702690555204, 56.26226986608198, 55.48553074559858, 51.00387765515236, 38.96115395330614, 37.225924845664736, 39.9768477870572, 40.79603871991558, 44.51898382556054, 52.41575441052837, 52.1091466565286, 55.10775550719231, 54.0904103555987, 50.24258875077771, 40.73398290141937, 37.99941232127529, 39.46930093149985, 41.03705267752371, 40.07345968677152, 41.37149357026623, 40.75939986013597, 47.02562155262117, 46.276574365554325, 54.16668084359939, 53.16653136284121, 55.194443810370664, 52.341864801222286, 53.77595001651395, 56.392935783632346, 56.80003466144685, 53.86428963753485, 49.46163700472925, 47.92677433260026, 51.84705780398462, 52.25568248379616, 57.85708988866499, 50.714073334970784, 44.51739526564076, 27.654561073549335, 18.62543163761016, 11.783023572737171, 11.843824232778243, 21.203101527306345, 7.2000610539990095, 3.9689034560034355, 1.0535057273603257, 0.37878907916526644, 0.12448785511115867, 4.614650857064032, 26.028970056964507, 47.88999034512428, 35.98466334804412, 35.79924114288823, 48.229608766494266, 64.42448293009113, 55.55741994611679, 24.03790435483379, 1.8512055037483093, 0.05059816153539766, 0.03136473321055453, 0.053776204510922396, 0.034451548520836144, 0.021294815796277216, 0.04705788154575614, 0.0038890757517243226, 0.04669921067092688, 0.030137969804326856, 0.011682548774256101, 0.03932941036539213, 0.017027085526816307, 0.0770078399669259, 0.047651281760584925, 0.03820681959510811, 0.011991157718453438, 0.059320942063124917, 0.007534124250073107, 0.021276533107964263, 0.025024648921023455, 0.02301907287009301, 0.1752220662010293, 0.1428512967522106, 0.20742063440622824, 0.14021976941054867, 0.14323037237890307, 0.13433319576565297, 0.09917473195180779, 0.2613238677863152, 0.19143714449338375, 0.2092461146774792, 0.16590777003476698, 0.06769747383171512, 0.11589966474040864, 0.20165468896588973, 0.13406511095743026, 0.14410761966099664, 0.1237931435987834, 0.19589459643729273, 0.20888461310776973, 0.09029746596370974, 0.09493635051072606, 0.1197154107954233, 0.09612443030721719, 1.8678267925016343, 18.86271542118442, 51.22389516522808, 60.89490675157117, 59.188691416094386, 38.398929257546705, 40.042896578388834, 50.53410714672458, 41.53323642669186, 16.571298145478774, 1.8955057330669898, 0.28377220515281926, 0.6132755080057729, 5.445019074024693, 8.870455834173388, 11.220949888229372, 14.25122501388673, 8.759506690886713, 8.82199397010188, 21.10613661427652, 34.048165659750666, 50.93878592214277, 53.71640451492802, 56.629662590642134, 50.535095584008005, 57.208631884667184, 55.58390771189044, 50.918754377672755, 50.19139397528864, 44.54059216283983, 42.84675582762688, 48.91167363812847, 50.23790151842179, 56.09269011405207, 55.5882772322624, 53.268258033260224, 49.28107461621685, 40.37918098511235, 38.49255623355989, 39.85707036910519, 38.20960821643953, 37.91955286456693, 38.82174899501186, 43.36677974270236, 48.84177307928763, 53.29215311234998, 56.741979660526404, 53.57495600177396, 54.359422191496826, 54.38771424754974, 52.91831985596688, 50.87982485371252, 43.617650616553526, 40.174543088482274, 40.517377853393555, 39.338183941379675, 40.759674426048036, 42.07619836253505, 41.84012659134404, 39.15242441238896, 41.17126834008002, 41.70474990721672, 46.99389742266747, 52.27105033013129, 57.43845924254387, 50.466901256192116, 40.96772086235785, 56.59127043139551, 46.826929969172326, 52.82227669992755, 50.02286541846491, 53.58349892400927, 53.09057074208414, 55.65884851640271, 54.727485641356445, 57.88304028972503, 57.99145852365802, 52.512056442999075, 41.82409194207961, 40.87443905491983, 41.54968292482438, 43.18049853847873, 46.496285930756606, 53.80262997842605, 53.86942794246059, 58.6573749972928, 55.881988233135594, 52.98089342732584, 44.77521657943726, 40.73315920368318, 41.579383111769154, 43.8177111071925, 41.04861190242153, 42.14756588782034, 42.143796490084746, 49.125387899337284, 48.6283726076926, 56.72676478662799, 56.67292241127261, 53.42827504681003, 55.54554300923502, 56.16761915145382, 58.952847142373365, 57.81905858747421, 55.74377959774387, 52.18304803294521, 52.02296433910247, 52.81167061098161, 54.70131950993692, 59.64503565142232, 56.84110579952117, 48.30175684344385, 27.42924051900064, 21.454082227522328, 20.38093939904244, 17.91992275945602, 27.347166884330015, 11.261041414353157, 6.811005569273426, 0.4105225860351517, 0.8715176185773266, 0.5090136994277278, 5.269125776906168, 29.592780682348437, 56.12005256837415, 47.13687958255891, 46.300449832793205, 57.72428235700054, 69.5426425626201, 62.9950104221221, 29.112904187171694, 2.8438093248874914, 0.13628357901207863, 0.12689934667920874, 0.16075688594531629, 0.12983417589097254, 0.12617792168091382, 0.23458580576604415, 0.14557512236698983, 0.17637012556435602, 0.13121370105974137, 0.10651326437871303, 0.13551485574533864, 0.10929009561697323, 0.21451352074021296, 0.1443779874112337, 0.12788949233870353, 0.13521185264952723, 0.1225964759566611, 0.16913696853143556, 0.1573421256316285, 0.11771328597059173, 0.14022438125985284], [0.053068844886917266, 0.08726942683419875, 0.016800277535953832, 0.03706190502271056, 0.015911444131615424, 0.02277357616431771, 0.04238279168343833, 0.0974156485209542, 0.02657279004192641, 0.07483165230481856, 0.013611297697700081, 0.048331537193829016, 0.08043905584922723, 0.07396801074426021, 0.0912248230569305, 0.02621770254336298, 0.059098136881666805, 0.05980637750678486, 0.060179389547556646, 0.022997944165141355, 0.021407288994880456, 0.07132388891712313, 0.018953536186487447, 0.3783655857607242, 9.008023162041942, 32.72232805528949, 49.662815370867335, 49.70555743863506, 36.483847710394095, 33.87462039147654, 33.13649700533959, 33.12218819895099, 16.423289468211514, 2.6348068108481746, 0.0757262361566386, 0.05013657823926018, 0.10823156894935716, 2.7203588524172386, 10.361477194293853, 7.30048647811336, 6.273260385759416, 6.773147342666504, 11.245633363723757, 25.67215988712926, 37.12000123916134, 50.65467296108123, 47.42660545533704, 47.27812021009384, 56.907919453036406, 50.30078887939454, 46.49767052742743, 43.66113008991365, 38.79967781805223, 37.30392902128158, 39.99881306002217, 44.224221629481164, 48.01389801886774, 51.783648767778956, 49.09863733476209, 43.95839083579279, 39.71079734063918, 36.0672959204643, 36.20910921404439, 36.674537658691406, 36.89100150139102, 41.74398929842057, 46.30729829111407, 49.103140215719904, 48.96894024264429, 50.915687084198005, 51.17133148254887, 51.22635449132612, 48.855987748792096, 49.2299622105014, 49.06720738257132, 49.204957100652884, 39.44494301272977, 36.22303362815611, 37.278700336333245, 36.63013250597062, 36.46729138589675, 37.70237515049596, 36.13212093230217, 38.05710646413988, 43.35032932219967, 49.56805482987435, 47.776194541685044, 55.523605192861254, 46.55024205484698, 32.0157346417827, 41.41084671020508, 53.58748405210434, 54.04307126998902, 44.242170395389685, 49.5443009561108, 48.475357024900376, 53.13040241118401, 51.56990312760877, 55.20854865351031, 54.56230678865987, 49.36809239848968, 37.67322801774548, 36.38467842532743, 35.120388692425145, 38.34025452213903, 44.61072806389102, 51.16584800904798, 53.81857441317651, 55.178220887337964, 52.836852227487874, 51.896181568022705, 48.11373802923387, 39.17430339321014, 36.3779947065538, 38.65404413592431, 37.74653711626607, 37.17209815979004, 42.020155537513, 45.82008500253001, 50.065360376911784, 52.6875275950278, 47.99858900808519, 49.53861744173112, 48.94542171109108, 52.11239830140145, 48.02579848997055, 53.28250408172608, 54.75482848382766, 53.19157177402128, 51.06927141066521, 48.52692050318564, 52.27560812427152, 51.57189176928613, 46.00698986361104, 39.01672217153734, 24.636622782676454, 24.78238590302006, 12.018381472556824, 9.353952677019182, 18.07485442007742, 6.578234472582418, 5.316243248601114, 2.766989459914546, 0.430431280645632, 0.1298620155261409, 5.828422423331968, 25.98125050144811, 53.19340744326192, 41.17866985259518, 37.63553404038952, 51.6277188639487, 53.81967659919493, 40.432407548350675, 16.18691763570232, 1.3842534634374803, 0.10444479633963878, 0.11272526451296384, 0.07202724190128428, 0.013825668251111865, 0.027044629340150186, 0.0006999449103586226, 0.029903470290704604, 0.06915628143976774, 0.036744269647545395, 0.06715895998622141, 0.07182222911186757, 0.03332033160052473, 0.006320253624806121, 0.02844121337177292, 0.06479369416352242, 0.05240630523692216, 0.07640343489906481, 0.0320775761088777, 0.019311766560760238, 0.16633143197865258, 0.051770390972735426, 0.04465141934492896, 0.10770415571788627, 0.008966702922818162, 0.056850388946552435, 0.04860623717127789, 0.03371585130451187, 0.013200556784267388, 0.09933293676905094, 0.0418292242102325, 0.023539150809688915, 0.03222834987325534, 0.04336068759702387, 0.024258806144878752, 0.06196477277685077, 0.015237452424762231, 0.015411495152229985, 0.06363989680164284, 0.029261894636757435, 0.06414217851875771, 0.04300206651790969, 0.06193258942315175, 0.0410297540046515, 0.005386669194370869, 0.356424214738992, 11.57008594082248, 39.851014229559134, 57.372057437896736, 57.49850288514168, 37.592595854113185, 38.32029750270229, 39.33705822114022, 36.02587569144465, 19.163980907009496, 2.7466468224602365, 0.1311643496756592, 0.060432979972251964, 0.7295261023025359, 4.557102332192083, 7.883542881857965, 10.40116765806752, 8.75592556691939, 6.51757501786755, 13.28971480169604, 28.322324983535278, 39.00131510150048, 52.06739694841447, 50.576994342188684, 49.11723721411921, 55.61246648911507, 52.154120552924375, 49.17475485032605, 46.07442717398367, 41.16958564327609, 39.051705791104226, 42.44955701212729, 47.45730192430558, 49.824107154723144, 53.22257026549309, 51.934208946843306, 47.501922807385846, 40.95287469125564, 38.49337208655573, 38.50544906431629, 37.22232018747638, 37.70724673424998, 42.554437268164854, 47.786282877768244, 50.1207560108554, 51.81422364327216, 53.23089353499874, 50.193402228816865, 51.851525383610884, 49.91943251702094, 51.53238173454039, 50.46488515792355, 49.895207958836714, 40.04692877492597, 39.712648699360514, 38.93666659632037, 38.2082667658406, 35.6992442377152, 38.135498954403786, 38.17246337090769, 41.07864549083095, 44.44035207071612, 51.78020492676766, 49.687471389770515, 57.34574225641067, 48.23243287301833, 35.31480097001599, 43.211599011575025, 52.377095530110026, 53.77026257976409, 46.53183044925813, 51.844178784278135, 49.95998982460269, 53.57399894345192, 51.20098067868141, 57.40761764587895, 55.318669196098085, 51.349093298758234, 41.619724688991425, 39.153754095877375, 38.73138935335221, 39.45130901951944, 48.42060858203519, 52.4049404359633, 56.29087178937851, 56.972195333050145, 54.70984282032136, 53.12032584221133, 49.103261809195246, 40.34673513904695, 37.923275193860455, 41.39436883311118, 39.05835028617613, 39.35227309503863, 43.950914798244355, 47.90222029532156, 52.81854652589368, 54.24048416076168, 50.26598568885557, 50.88486117701377, 51.4461798052634, 53.34258694802561, 50.523167656313994, 54.37589222385038, 56.77434705918836, 56.7011752436238, 53.18140891290481, 51.940841674804695, 52.47892418215352, 55.82981286510345, 50.128416399801935, 44.272855097247714, 26.306936663966027, 19.187487671452185, 12.386900897948975, 11.41135056172648, 16.133714606685025, 6.686334013938905, 5.796192307626048, 1.7559571179651445, 0.37991957979336866, 0.22465206622596712, 6.047431884273407, 27.954269378416, 53.787928935020204, 41.44695997238159, 44.428651640492106, 55.93424204857119, 59.75900403914913, 48.12947850073538, 19.984283831811723, 1.8899672238096115, 0.13498248592499765, 0.042629556264728315, 0.04591397437897902, 0.050334163806250984, 0.028502567438408736, 0.0357322521778124, 0.03039850290083597, 0.019306405860510086, 0.012040172023848902, 0.08741809385678462, 0.06704245333469684, 0.06914970074449817, 0.06136160111054779, 0.003991462684596979, 0.04924019791125771, 0.09556572238403944, 0.03221344946312808, 0.046797457616776235, 0.02325247113232411, 0.009078730832815412, 0.03804270440952913, 0.12711991105348835, 0.2999526869145132, 0.15511319281593447, 0.0601212702871811, 0.14163514749417383, 0.13533473315258182, 0.1935540905763065, 0.27612330752515024, 0.14976550073873612, 0.18499838999442517, 0.09499491027165806, 0.14653702236471638, 0.12104798243531298, 0.12297413432069364, 0.1627502160807771, 0.15636711020863828, 0.1344810507350391, 0.15748117058988542, 0.2020473856358759, 0.13160961529900952, 0.1452413531801393, 0.20306032241111804, 0.2077380552767746, 0.4875873233522139, 12.51605768357554, 45.015006757551625, 63.78377945192399, 61.80237454752769, 47.84779740918068, 45.54294209326468, 43.85358902715868, 44.822336012317294, 23.364613825275054, 3.6901258989687893, 0.5396788507219284, 0.244236521783375, 1.2734224815522472, 9.085595876939836, 19.94468358255202, 15.774475509120574, 13.47226877366343, 11.648246030653677, 14.744517976237884, 28.114298159076323, 39.341266924335116, 50.945300978998986, 51.06520391279652, 49.456726197273504, 58.32838619908979, 54.58793555536578, 51.372513771057136, 48.6658194757277, 43.76227624954716, 41.36619837053361, 45.569567141994355, 48.962809578064956, 50.919523162226525, 56.033701589030606, 53.4927745019236, 49.10590940906156, 42.44986295700073, 42.050753947227236, 40.25119796875985, 39.675817643442464, 39.49039543828657, 45.311059413417695, 50.91291396848617, 54.30956886660669, 53.15129687709194, 56.019757563068026, 52.8549421987226, 53.12300482103902, 51.17879575298679, 55.031406571788175, 52.096198912589784, 53.96150950462588, 42.79003835493519, 41.927293423683416, 40.14569013349472, 41.740745498288064, 38.54027971144646, 39.38233021766909, 40.86624130125969, 42.82555541684551, 47.334586651094504, 53.97630860728603, 53.17448592955067, 60.16667950537897, 50.60206220995996, 40.42685739455685, 49.27523812940044, 52.89207135477374, 53.02737351386778, 47.46857873855099, 51.959508234454745, 50.63071120169855, 56.758716414051676, 53.6071978845904, 59.398424471578295, 58.898969465686434, 53.2529176435163, 42.81389028795304, 40.94581442494547, 40.31633284784133, 41.949937266688195, 50.23899585969987, 55.74790200879497, 57.67773559016567, 57.88447195483793, 58.4666262134429, 55.48399317649103, 52.84218665092222, 41.851807409717196, 40.348115813347604, 42.989067262218846, 41.778682662594704, 41.74454627498504, 46.20310444985667, 49.748695665790194, 54.255514683262, 58.258116937452755, 52.24950867314493, 54.249768410959554, 53.30661881354548, 54.66541413337954, 51.08742021745252, 54.240315498844275, 58.400961814388154, 57.86431881689257, 55.747772570579286, 53.7866541647142, 56.95687063278691, 59.551640095249304, 54.168555736541755, 42.36014266167918, 28.792175900551584, 30.083339752689486, 17.81458946966356, 18.389279457830614, 28.161401902475667, 18.321669563170403, 12.114897274201917, 3.778831281008259, 1.0548089348500775, 0.41289053316558566, 8.378828898552927, 33.478629665990034, 67.47993084692186, 52.21205788273966, 53.48265870924919, 63.39405667397284, 69.52251295889579, 56.84163924186461, 24.002475546252345, 2.536418812890207, 0.22637407866216477, 0.23827349256363609, 0.10918457466628283, 0.1709863047806486, 0.16028885218885638, 0.10598916830795427, 0.17232288306038226, 0.12307209398357138, 0.19424044406942784, 0.13644038188842036, 0.2259253503213967, 0.17212310265148842, 0.19688447396601402, 0.10365664508313903, 0.17812011553154838, 0.19012589308042682, 0.1678475506243206, 0.15452486793360404, 0.15612545543380324, 0.30448510822269226, 0.18898532605699955], [0.0490033082033117, 0.046391503795260386, 0.026424958055178006, 0.02876271940617552, 0.026847254447338563, 0.09078293588132628, 0.03879828160748847, 0.015520956667680896, 0.034228517343440366, 0.04832108392410221, 0.025002830736939947, 0.017412531174599163, 0.03368704256811931, 0.019105543352423177, 0.036030344650029175, 0.035575280762127334, 0.019537616941717365, 0.036500688161580794, 0.05507234483957291, 0.02115814571058558, 0.04052339286933984, 0.025209691713473974, 0.01960408847568737, 0.09408785450843074, 4.588966686879435, 27.007464132001324, 47.311107343243016, 47.187968454053326, 34.22821029540032, 17.2787780146445, 30.816250308867428, 30.535541965115456, 21.544890980566702, 5.0431957840919495, 0.28725180714841814, 0.03653749102546323, 0.5870681304124095, 3.4499062213205525, 5.683017709562856, 5.783915288986699, 3.5711832104190706, 2.7350976486359877, 4.907882838479934, 15.035781418123554, 30.1488668687882, 42.08230549289335, 45.26740735576999, 52.51809297069427, 55.40197249381773, 48.58777607640913, 46.35524534410047, 43.40124168703633, 37.32612571408672, 37.64930155969436, 37.54639425585347, 39.71876759682932, 44.18249937795824, 46.30379169218002, 45.233894625017726, 41.64957392600275, 38.916227125352435, 35.27508697202129, 38.12300620540496, 36.917995252916896, 41.15850102516913, 47.37889766693116, 48.39891395261211, 49.0557187603366, 52.503356625956876, 52.52213693434193, 52.156689705387244, 53.76176280360068, 50.29987496714438, 51.63930162306755, 51.773497673773, 52.251783647844874, 48.234605866093794, 39.80449099694529, 36.64922660396945, 37.39316294270177, 36.362493499632805, 36.903682524158114, 34.19365421418221, 43.432200954806426, 46.98636647193663, 48.63845309903545, 50.28766855116814, 54.58668431928081, 45.78446203662504, 28.47526211892405, 42.34923847260014, 40.7475660693261, 46.595074745916556, 49.00175871387605, 53.4063607646573, 51.98285418172037, 51.87798569279333, 52.99518654423376, 53.538066110303326, 50.84245251071069, 45.01143347832465, 39.9840178797322, 37.159962346476895, 36.66104078292847, 37.33862238545572, 42.333227357556744, 49.180477588407456, 50.662047017005186, 55.22600712314729, 53.13998868388515, 52.775663252799745, 49.59340510829803, 43.67072028498496, 36.67809132606753, 36.58082831290461, 36.51118270812496, 38.63087077294627, 41.086788331308675, 49.32081214843258, 50.16065828261837, 53.368482435903246, 48.830170708317915, 54.914327744514715, 52.44769427084154, 55.45229650312855, 52.745198203671364, 51.12954647310319, 53.14248331131474, 56.675001267463934, 55.21933517148418, 57.317328606882405, 50.078727814459036, 50.228911445986846, 44.385654618663175, 36.68278248079362, 23.582750558853153, 14.637217617804005, 8.907704622514787, 12.797664250096968, 18.497764372056533, 4.447278418848592, 3.5486957719249115, 2.616033121462791, 0.23363361976319746, 0.16816849549931867, 7.004573066388407, 29.498155463126402, 47.629984271141794, 44.141942070376494, 42.51303665099606, 48.005904228456565, 55.856685023153986, 35.84104576418477, 13.552032132302562, 0.1688680563482546, 0.0358938277819224, 0.02714815846223745, 0.03320484001549982, 0.05608961384202685, 0.007799022611335762, 0.07050676421532709, 0.02417763146842199, 0.036753252028457584, 0.0460837088194826, 0.09884543671843507, 0.016653248026306113, 0.02049250148927733, 0.01885622769834534, 0.0265545150144927, 0.035982847198723786, 0.01727865347939153, 0.01636914623480651, 0.03668193307314669, 0.07609332250731607, 0.022760895493951057, 0.029885779405313156, 0.011267130894045676, 0.009317994455716783, 0.07010385559331025, 0.07760770213339599, 0.03782461832968458, 0.09081002475032884, 0.021201042803905664, 0.08644287159005482, 0.058790583223585165, 0.03790314234192333, 0.09389732844166218, 0.047135248765229225, 0.044498362638536966, 0.08933150569998449, 0.022700387954471574, 0.08960477692345459, 0.009925446638296689, 0.011553316444699323, 0.03046853291321426, 0.06499990205010099, 0.020739990023655758, 0.018004948881665067, 0.025836684883782463, 0.1251197780572599, 6.198556884642571, 31.775081542230424, 54.748846869314875, 51.31950293817828, 42.31483144144858, 22.409679466678252, 34.273874528946415, 37.75668036553168, 24.97451928354079, 6.276038404433958, 0.40803319864696075, 0.14740647087174077, 0.5153779288934124, 3.5701295637315322, 6.595835128138143, 7.7641233801841745, 8.93034944611211, 4.667438114843061, 7.384013841229101, 18.30014555684982, 31.509152689287742, 45.75416957178424, 45.85015781464116, 50.51037680718207, 57.41411309088431, 51.400648932303156, 48.77649307250977, 45.344709427126, 40.76001174988286, 38.84571075439453, 39.64362282906809, 41.92375152341781, 47.514188058914684, 50.16928749699747, 48.28232149924002, 45.44265885506907, 41.497672296339466, 36.96832318459788, 38.99284278192828, 39.417447197821836, 42.11931305546915, 48.7667695168526, 51.549408743458415, 51.44248493256108, 53.09723092663673, 53.63823952213411, 52.458822035020404, 55.84125441889609, 51.86656375085154, 52.79502799434047, 54.012045321925996, 55.03226164848574, 49.39341129795198, 41.04674093184933, 40.441785935432684, 38.948782797782656, 37.9417299455212, 37.734381691102065, 36.31602125783121, 45.14959504527431, 48.187859058380134, 50.52425023048155, 53.40645490154144, 56.38940565047726, 46.09525888196884, 33.48512903336556, 46.689443049892304, 43.04345092465801, 48.926872822546194, 47.874026298522956, 53.67729848431003, 52.60377714710852, 53.596811448374105, 54.594595739918375, 54.076619302072835, 52.59113534804314, 47.0567024138666, 40.304502979401626, 37.94849211169828, 38.04284472619334, 38.86143553641535, 45.10954764581496, 51.06078340161232, 53.669924428386075, 56.79467670379147, 54.936218492446415, 55.943188974934245, 49.96108024351059, 45.03145325568415, 39.55865644639538, 38.1906553237669, 39.41656858690324, 39.8876020985265, 43.517081045335345, 50.32191476514263, 52.30552796394595, 54.876029722152225, 51.562458469021706, 55.777068753396314, 53.62259710988691, 56.064347067186915, 54.66077004709552, 54.94281984144642, 54.58054188759097, 57.8768390224826, 58.654974506747344, 57.71383316286149, 55.89100968453192, 52.68997515401533, 49.0380798616717, 38.37674825422226, 24.95551343887083, 13.57148708835725, 13.478674984747364, 14.831790712571914, 14.000664987871724, 7.212936724385909, 1.9900364476826884, 0.7419655928688665, 0.18367242969332204, 0.27310151967310137, 7.465041673952534, 32.37985807080423, 53.3723420481528, 48.22898118726669, 45.35130293138566, 57.02082095607635, 62.634744644165046, 46.4328259037387, 17.079921691648423, 0.26110010882539136, 0.06012130859157732, 0.025344684066611434, 0.06800426906275173, 0.1267551612709799, 0.059927699020913536, 0.027658041686780994, 0.0036229621834917777, 0.05016232645439525, 0.035923958019984346, 0.016183017512723323, 0.04239602585233027, 0.03743043927956493, 0.04450498929908199, 0.036360126349233815, 0.07882043463929046, 0.12597271736951607, 0.03983932614867245, 0.0477304722693178, 0.0285912421156442, 0.016139672257967533, 0.07197017601180462, 0.09190266531321312, 0.110330029330667, 0.1656409262889816, 0.1349202642637876, 0.1148603285752958, 0.20660683452602358, 0.13049949260969318, 0.19398530614712547, 0.18236514661581288, 0.1291473780668551, 0.12907329736457718, 0.14224331405374313, 0.10865992701221859, 0.25235766665108744, 0.16937033423492986, 0.09512863091884122, 0.10086256154482404, 0.17472725001073655, 0.13730204694213408, 0.1412135693094423, 0.07350938454751046, 0.13435228667672605, 0.1265013716634243, 0.26268119172703835, 6.7384579008625405, 37.67695034703901, 63.030817739425174, 59.20266289864818, 47.340430982651256, 28.469596255210142, 41.19535169293804, 41.19151561490951, 30.49229979515076, 7.643783102112432, 0.6897583555790686, 0.342498820034727, 1.880175639544764, 8.618265082759242, 12.30851919420304, 12.765096810556228, 10.577418381167996, 6.73649916725774, 6.650455113380186, 17.53052357704409, 31.742367013808224, 46.01058667705905, 47.448456979567005, 53.65516454942765, 60.30341332958591, 55.048410046485166, 52.67194794070337, 47.539342218829745, 42.2890575470463, 41.01692307379938, 41.85930698148666, 44.482117468310946, 49.26012131475633, 50.98218694809945, 50.24594237727504, 46.027550928054325, 42.38796011094124, 38.479851676571755, 41.37551007732269, 40.28869582760719, 45.521890732549856, 51.62432993611982, 54.174941355182284, 53.029734780711514, 54.52200443513932, 55.58172687407463, 56.09136435293383, 57.067555996679495, 54.18922662734986, 52.91187540177376, 55.531536225349676, 57.47653761217671, 53.6364979897776, 43.88196737535539, 41.54202253587785, 41.061771454349646, 39.50718318262408, 39.66464673319171, 37.178860325967115, 47.90484436096684, 51.11455909667477, 51.66569132958689, 55.20945079864995, 59.17500626656317, 47.545135559574256, 38.94275019245763, 45.14408803755238, 43.39047478091332, 49.41026964495259, 48.5215429336794, 56.798563772632235, 53.7671168388859, 55.1456573701674, 55.51362276077271, 57.2298675967801, 55.818641954852694, 49.241144887862674, 41.41210579103039, 40.37188537659184, 39.27976023766303, 40.242949224287464, 45.871593567632864, 54.56189886216195, 54.629646039778194, 57.58078244424636, 57.324694818066014, 59.06697242490707, 53.30770138771304, 48.69625706826487, 40.90083660617952, 40.45318434315343, 39.26445907162082, 42.71193219769386, 44.84908657689249, 52.54688709012924, 54.94826801361577, 58.01769525774064, 53.06112158683039, 60.1787329489185, 57.25253497400592, 59.37283492857411, 55.99107326999788, 57.259281450702304, 57.03080731053507, 60.068384908860736, 59.63160545595231, 62.46763598534369, 57.22616880170761, 58.92904227779758, 50.38639460840533, 41.68855444077523, 26.36993581248868, 18.310016201388454, 15.59443969880381, 21.2426802035301, 27.56402296404685, 12.159557380983907, 7.991551718404216, 3.772681985170611, 0.5088976217854408, 0.538787063091032, 9.758431411558583, 37.83264098628875, 62.07283766038957, 57.05500048975791, 55.23792720610096, 63.850965730605594, 72.14635110670521, 53.954370790912265, 21.702168218551144, 0.612818674454766, 0.14420860537117527, 0.10448899195199052, 0.16325957261987273, 0.15859820339227879, 0.27085629982813714, 0.12064538024846586, 0.08979221565588828, 0.12477478568231869, 0.15836016455244634, 0.14495978522444927, 0.2120559872879136, 0.18473559119288, 0.1439843714357384, 0.11185334154194403, 0.14940306454175903, 0.14532922346505428, 0.15964187561504303, 0.10614745739486911, 0.2313953253530687, 0.11285521600755954, 0.125212574287528], [0.09336637588398111, 0.08030986278167657, 0.03742038054511913, 0.03662406662178617, 0.01988580390330284, 0.025198397662250266, 0.08504884437687936, 0.016662577062004035, 0.014910944793823988, 0.05080367228196514, 0.07580085312046352, 0.038899259656787886, 0.08373367825462934, 0.04290226441357405, 0.0644471083256987, 0.03633420193387616, 0.025868971659351262, 0.059062414201757604, 0.0836316736475114, 0.022810714191667015, 0.06182726765532167, 0.024416744746568225, 0.011788733348610901, 0.032869860409728946, 2.0165723850650172, 22.611952174094416, 47.00834743438229, 48.47647490039949, 34.77352957571707, 29.823841625644317, 33.25113611836588, 33.59942297781668, 28.282989494262207, 9.01633172265945, 0.6146267645301358, 0.04047255527468459, 0.4366827726123795, 1.9557646157280093, 3.3535789385918653, 9.618011539982213, 11.372711293158993, 2.894634907284091, 2.8323506107253413, 9.028436157011217, 17.667198565698442, 29.300742572353734, 44.972876579530784, 55.144382599861395, 51.86084493514031, 47.96379366228658, 46.46506386418497, 41.3456843745324, 38.36889566913728, 35.899944074692264, 37.83193495965774, 38.378658448496175, 39.79152756352579, 40.42749281852476, 41.158508869909475, 40.187000536149554, 35.89581774127099, 36.76758020154892, 34.62011391116727, 39.1304434499433, 47.33721856148013, 48.44530774701027, 49.52743476436984, 53.33302028717534, 51.43780946731568, 53.531217651982466, 51.850576170029186, 50.31991435635475, 51.71038281533026, 51.67751727565643, 52.066353597948634, 55.28469362566548, 50.58680418998965, 44.7248415793142, 37.092983953414425, 37.77021646499634, 35.69544346101823, 36.136698338293264, 42.015880154025176, 50.200391892463934, 49.68958162492322, 53.42430953056582, 49.09568379002233, 53.73452194275395, 43.766822276576875, 33.55137786557598, 53.881006779209265, 48.89604299299179, 56.76616499500891, 51.896597339260964, 53.85192240438154, 50.33222275395548, 50.42681855540122, 47.651004252895234, 49.43564345759731, 48.375858260739236, 41.99003565695978, 36.868867566508634, 37.08389582172517, 35.53366138089088, 39.12280267284763, 45.307615572406405, 49.85176378680814, 49.97159611794257, 52.921838222011445, 50.29670176967498, 51.92317139717841, 49.98107256427888, 46.36956591759959, 37.248568688669515, 36.5268761111844, 36.22389262722385, 37.81991289507958, 38.95831807967156, 44.99404561135077, 50.50454816510601, 52.340848907347656, 54.342026479782604, 52.470373415177875, 52.01647281646729, 53.08319276379001, 54.017356211139315, 52.673258012340916, 52.12596185745732, 52.53394719093077, 52.12883303242346, 54.01205708903652, 53.49042500219038, 54.288631254626864, 44.52088617509411, 37.232275162973714, 21.47666527378944, 14.231619046580407, 16.575100883360832, 12.798494811980957, 8.644950928226594, 5.912874485215833, 2.5672427588893525, 0.9548700684981962, 0.06800210869480526, 0.579532583154017, 8.089007418001852, 28.934126477087702, 43.34456736041654, 34.08675785987608, 42.45588771758541, 46.41714426778978, 50.05362072298604, 30.791247160203998, 7.400104384268484, 0.09975361097003184, 0.04147908755487973, 0.07521156296734849, 0.03142193891108036, 0.03521695079642438, 0.025950598327683348, 0.09522070702646049, 0.020634382888073885, 0.020865902319670688, 0.06980230040367573, 0.05154639835499468, 0.045845581879538876, 0.07231048758952849, 0.04654649104322157, 0.07746837372260709, 0.012796717365422558, 0.025052431099597487, 0.048643457553079056, 0.009704011796613135, 0.03331018093552801, 0.03372398332782811, 0.030675432194144498, 0.09836424157143601, 0.0697415343095218, 0.02496618492108199, 0.015976060775198763, 0.02614859758215326, 0.042937998584802115, 0.1859557394298815, 0.011762976514986687, 0.060385122459622166, 0.044205291872663845, 0.03132401755259883, 0.05133015854704765, 0.026805682686127486, 0.036172538229654876, 0.023529040364308224, 0.02052935031843522, 0.021228618138740142, 0.037189715301557895, 0.06475466964465958, 0.043918081679411476, 0.045940645730062846, 0.021372631177186005, 0.03015488885613459, 0.0535270918701445, 2.8295321426083966, 26.19019123815721, 52.989122559947354, 56.911206399240804, 39.170922310121604, 29.584565278022524, 34.24146790658274, 36.50311047031034, 31.5239929768347, 10.781885654695573, 0.6269227208629732, 0.060164282293689836, 0.330121566451365, 2.0603609902243463, 4.897136524800332, 7.495557223596881, 7.1577082814708834, 6.846455460594547, 6.855989761890904, 11.07057406056312, 21.521570528707198, 34.215270396201845, 48.16451311111451, 55.5664021738114, 53.056402975513095, 51.05187177658082, 49.306589634187766, 42.033907367337136, 39.9578478259425, 38.10143316945722, 40.02233159157538, 39.49006988156227, 42.98314448325865, 43.68070663944368, 44.41138536699357, 41.55169902309295, 37.37135848691387, 37.26870613713419, 37.35506496121807, 40.56898055538055, 49.35675674869169, 50.913714132001324, 51.83916207282774, 53.996622562408454, 53.4920802424031, 55.12152694886731, 51.934601183860536, 52.02766726093908, 53.27410628718715, 52.34237863171486, 54.03006076812745, 54.69128608703614, 53.536516774085264, 47.1095367400877, 38.54987382888794, 38.88966875691568, 37.83521406112179, 37.02074566195088, 42.182129813778786, 52.8499686333441, 51.90694847414571, 54.80824332083426, 50.39736155540713, 56.01099498810307, 44.95491604651175, 35.93320969612368, 52.60731904737411, 47.89147300104941, 54.568570813825055, 52.47329165858608, 55.432935683958, 52.369560657009, 52.68680195654593, 50.88653210670718, 51.566294547050234, 49.65732405262609, 44.402877746089814, 38.945703737197384, 39.00614746155278, 38.04096983325097, 41.0977513559403, 47.241983413696296, 52.07976810393795, 53.25366681621921, 54.67236849569506, 49.64292503172352, 54.52097677415418, 53.605577945709236, 48.1255365187122, 37.16454759720833, 38.234232856381325, 37.50364042097522, 40.497067820641306, 40.661356295308764, 48.532121566034135, 50.6344021520307, 53.31591875322404, 55.73768423449609, 55.46835076424384, 55.63534175196002, 57.368350798083895, 54.79901006144863, 54.856598300318566, 55.6423157261264, 53.96331771727532, 53.76477518389302, 55.144111956319506, 56.20401874665291, 56.94328746488018, 46.95933349670903, 35.774106594824026, 19.652967106911447, 9.725263849381479, 8.993050494501668, 11.032441758340406, 8.125189321656382, 5.261257992636773, 2.8781898800403845, 0.6868588660032519, 0.15217994940617394, 0.8781697132414388, 8.518467237872462, 35.17994596112159, 53.15230884859639, 42.42194352611419, 48.61067879584528, 53.007377270729314, 58.31976090708087, 37.25278131423458, 10.258973894580718, 0.19690803883056487, 0.04397209087807325, 0.05543244829882057, 0.08711655398890858, 0.03170067234145057, 0.025217049987986687, 0.05523250318102299, 0.028098450312691352, 0.059902395136774554, 0.04693949031793783, 0.03730965402698325, 0.07008629685808575, 0.044433831222235196, 0.04521826312186257, 0.035958305572069464, 0.0239522886207147, 0.022156132279985377, 0.04501400492905129, 0.015592012280267815, 0.02547457810461281, 0.07707941556169141, 0.03247737058348233, 0.23062628032940052, 0.1865419805530579, 0.17787997761080343, 0.1442246778958267, 0.12703852953329203, 0.1496942085965026, 0.19329135306179526, 0.13239393611588787, 0.21595787226913438, 0.12632726286087306, 0.2533104195589981, 0.13980476426020746, 0.22251921615773634, 0.17743238308016332, 0.1122613063442611, 0.10983223305834879, 0.11140172504970144, 0.20541377515802461, 0.17598924197016225, 0.08166363973531031, 0.1288543647575763, 0.05006997838556286, 0.1458442184112726, 0.17312814872111046, 3.3593234948573576, 29.241093127958237, 58.43222310466152, 63.425729813114295, 47.12455941784767, 41.7787964113297, 43.95709645363593, 44.289023107098, 36.86422348022461, 12.727037072181703, 1.2407405578321027, 0.33248914585959527, 1.5402479638015072, 4.527864004335096, 11.477747463410902, 20.310222987205755, 21.709805073276645, 7.995378971099854, 5.386755206892568, 12.302925894337317, 20.82197070121765, 33.39972726760372, 47.5141566799533, 57.73591610693163, 57.582571045044936, 53.198992898387296, 51.40817203829366, 45.648818631326, 43.129641086824485, 42.076053234838675, 42.67339098838068, 41.26906871795654, 45.28850578492688, 44.60316965656896, 46.170372270768695, 43.12342805247153, 39.08453210707634, 39.23997563700522, 37.850519149534165, 42.418848776048236, 52.51888921183925, 53.36253612272201, 53.69514526859407, 57.40009846225862, 55.4764465362795, 57.87345009465372, 55.961816310882575, 54.1356352836855, 55.06790422624158, 54.18374315384896, 54.262457278467, 58.064987274908255, 56.75269557583717, 49.550145287667554, 40.81714891618298, 41.0539424034857, 40.668538155094275, 40.0096623359188, 46.42719730254143, 55.793970246468824, 53.89723754698231, 56.4832091331482, 53.50215681137578, 56.54434711702409, 45.93448485097578, 38.26738472907774, 52.79744809673679, 51.26333067494055, 57.56305333106749, 54.17899316357028, 57.6947037635311, 54.47033897522957, 55.01635251506683, 52.71225813896426, 54.94834646101921, 52.361178551950765, 45.265936466955374, 42.10389421832177, 41.64759312906573, 39.12416373529742, 43.8079640173143, 49.56719190843644, 54.84737680804346, 55.04079280361053, 56.32443158857284, 51.446615188352524, 57.23730048825664, 55.208666324615486, 52.82003310418899, 38.9282178109692, 40.95536147394488, 39.16053979627548, 42.95878264211839, 41.829096886419485, 49.85533706603512, 54.728932995950025, 55.42650691924557, 59.69672856792327, 57.06441417817147, 56.614847798501295, 58.580574989318855, 57.6557271711288, 57.60289284490771, 57.75479839694116, 57.381239706470126, 54.77556605492869, 56.07089350300451, 60.10647896797427, 59.45835436544111, 48.211373667563166, 41.17437093488632, 23.771102774527765, 17.514535996221728, 22.91120940639127, 20.25269554507348, 19.697582106436453, 11.599010479065681, 5.6870425516559235, 2.0638082633095403, 0.5975124828757779, 1.2771368435313626, 11.16786256913216, 37.37828147026801, 56.546276923148866, 46.779112354401626, 53.309101673864554, 62.31318873743858, 67.47596140830748, 44.5267540408719, 13.399422514823176, 0.3565698020881222, 0.1571149345968039, 0.14402868196127877, 0.20257094544508766, 0.20465004678455093, 0.10376779678007288, 0.2685240217514577, 0.12770383093025417, 0.1038854908678801, 0.19378590878219376, 0.10094211977576056, 0.16298033357147249, 0.20289262576449305, 0.1262620151523621, 0.14900764059876243, 0.09438498937074216, 0.16727745863458804, 0.19883416773330784, 0.15289691577274955, 0.15879422997034368, 0.18941382967656661, 0.15474309573971456], [0.10403739844238567, 0.0868496566169685, 0.02350925614366368, 0.040718465667939, 0.047639974302822546, 0.07062196085650115, 0.034794935941576, 0.09228596974524761, 0.06740614591586976, 0.03510379194912892, 0.042133269185620936, 0.02373598561051392, 0.04324955505228812, 0.04111996085773553, 0.03230128144364684, 0.06344918687377246, 0.04396521140851321, 0.03611992714145491, 0.07608910902373253, 0.03982094386892934, 0.07742559537291527, 0.03434919917415227, 0.01723568552293845, 0.0045471383360094365, 0.4716093952376997, 11.956928718474604, 38.53713789293843, 50.13513149753694, 48.326083383252545, 30.878837608521987, 33.51987338835193, 42.902245598454634, 34.676482292913626, 13.25285726977933, 1.7408426322283286, 0.016286682615417148, 0.32774378275198324, 1.821069198269998, 3.3319914389041165, 4.225874350916955, 4.416517230772204, 4.670744672898324, 5.334292034949026, 3.0469839322951535, 10.3829639380978, 23.975772050119218, 39.090215621456025, 52.9251604695474, 49.90306054392169, 46.789330128700506, 43.71853397738549, 41.17048778841573, 39.098095663132206, 38.261885566096154, 38.79112312870641, 36.82144611112533, 34.670261413820334, 36.44351005554199, 36.936147982074374, 37.497662728832616, 35.30277498306767, 36.70453202339911, 35.64843385450302, 43.59269649751725, 47.07941685953448, 51.90375174245527, 49.31967466108261, 50.703981076517415, 51.11386875952444, 49.47966029567104, 49.51959786876556, 47.69773537112821, 48.31069200269638, 52.227590468622026, 50.03067485747799, 50.980104169537945, 52.00507048637637, 48.06018198690107, 40.55777826616841, 36.76543466506466, 34.63188102168422, 36.105625321788175, 45.123628954733576, 51.341001449092744, 50.227130689928615, 50.50579155645063, 51.71467781066895, 51.409336982234834, 44.47979934753911, 34.038002798634196, 56.03695715627363, 53.11322635219943, 52.5443140152962, 49.2423176765442, 50.715195132840066, 49.644886216809674, 50.6043371846599, 45.91237445031443, 46.93997267753848, 45.22621070185016, 38.957804249178984, 37.157220609726444, 37.16052716778171, 36.733902731249415, 38.785015998348115, 45.72411244915378, 49.36635086613317, 49.07068652491416, 53.09516383755592, 51.212688953645774, 53.77342401012298, 51.46541510858844, 48.20774939752395, 40.0577349047507, 37.50259707050939, 36.25617765611218, 36.80263834614908, 37.53575286557598, 38.131278484098374, 46.27471908446282, 49.52927827835084, 52.370678532508116, 51.77741612157514, 49.825962435814645, 47.84016447682535, 48.4746745324904, 49.058817432772734, 53.92594537427349, 55.72845489748063, 56.32325487752115, 53.39432301059846, 56.75690820140224, 48.62019054351315, 38.15489507490589, 24.971181346524148, 17.72646165663196, 4.412991019987292, 7.686338857296975, 12.341754417265616, 7.282428376136288, 5.407410408219984, 0.9428559099474262, 0.23412030009973436, 0.055103811901062734, 0.7804958930900021, 9.384363793557691, 37.09536483210903, 39.36709180954964, 25.85583663755848, 34.338817211889456, 48.82153364919847, 53.96852270249398, 36.407024168199115, 5.9203176729140745, 0.2509932793797024, 0.06146068692267422, 0.03568794548271164, 0.09448812778798804, 0.031088244417802464, 0.033321557341203574, 0.08464093320071699, 0.0726176428818895, 0.03638280638223214, 0.037858690090116956, 0.04364039012861829, 0.01873118108168485, 0.01751554510255735, 0.04388829618091545, 0.0426994962617755, 0.07900170636393371, 0.01916637839449029, 0.02315018307267418, 0.028591454705043186, 0.03958509987099998, 0.08069289908293756, 0.05075724352331412, 0.025907505881942572, 0.04526166200277306, 0.12150895286111102, 0.02956151928482277, 0.06663428934951944, 0.06640784141998138, 0.019238042089367108, 0.08697846664055701, 0.07536537043990628, 0.04726608126093784, 0.05271943218465294, 0.0256211192332088, 0.07560729334551482, 0.04796593705372465, 0.04944190120084151, 0.02334471003362729, 0.01258415190668236, 0.04213896887977758, 0.020027484204019272, 0.03335529202294927, 0.04718946863807017, 0.00796563141310828, 0.06993874066299008, 0.024334284957618486, 0.778141919403307, 15.750866763053404, 45.67460429283881, 56.02682567411854, 53.18222868827082, 36.64476294671336, 37.019761147037634, 45.09096345593853, 37.25351479745681, 13.786119184186383, 2.2118010059479745, 0.18169071345079332, 0.10817235801368953, 1.4240140395779766, 4.269973558764304, 5.529440247243451, 8.17007839679718, 10.506507812007781, 8.261125433829523, 6.602314393366537, 12.876694125513877, 27.78068292525507, 43.02940491707095, 55.77986932569935, 52.21539974212647, 49.624238860222604, 46.01670557452787, 43.55165673840431, 40.98995677886471, 39.567975997924805, 40.78409510274088, 38.6912517393789, 36.95037834105953, 39.01668294783562, 38.71766890248945, 39.80152568509502, 36.9318647538462, 38.33181750389838, 36.39216622998638, 43.860970927822976, 49.38528414695494, 52.64848432233257, 51.86677163647067, 52.06058379142515, 52.987996839707904, 51.64977827379781, 50.99820983025336, 49.05580113011022, 50.93510673892114, 53.631591104692035, 52.23170111256262, 52.088762098743075, 53.58721340856245, 51.294038911019605, 41.948725254304954, 39.504025674635365, 36.62713581515897, 38.18954137063796, 45.745799233836514, 53.05897997271631, 53.288901467477125, 53.19165806616507, 53.519313258509484, 51.029204399355, 45.89304893247543, 37.105119766727576, 55.87574774219144, 54.52711528347385, 54.92166649910712, 52.50261922036448, 52.22220113200527, 52.211332244257775, 50.872670450518214, 48.51513770318801, 47.909170735266905, 47.26950276282526, 41.87328238641062, 39.114424490159564, 38.53430986404419, 37.87196274726622, 40.64476859185004, 47.54059737728488, 51.29536859450802, 51.838401133014315, 53.52174512801632, 52.6882924572114, 55.26494449184787, 52.50108165125693, 49.38563716027045, 41.037405690839215, 38.26347412601594, 37.62554768593081, 38.110988063196984, 39.63727643412929, 43.752164379242934, 49.43351753296391, 51.33497668850807, 53.5379288273473, 53.20253087628273, 52.18531124053463, 49.82142425352528, 50.964147967676965, 52.289093232923946, 56.12043303828086, 56.06564537171395, 58.2907824362478, 54.23055664185555, 58.85889460963588, 53.421128488356075, 41.977178127534934, 25.926757012644124, 17.684200079210346, 6.457619138302342, 7.514163967101806, 7.707001903364736, 9.340497966735594, 5.736821841809058, 1.4205889523990693, 0.5127558244332191, 0.059870250087471745, 0.9894668443068382, 10.735005486396052, 39.10512847285117, 48.42944568203342, 31.756705237973122, 39.671730533722915, 55.03246168936453, 60.04076750047746, 41.4746872071297, 7.337281252107314, 0.24180986167442417, 0.04271927665198042, 0.061672950734294234, 0.038133347932729995, 0.04857512634067286, 0.038948679988783215, 0.05240410656457948, 0.04788141457303878, 0.05798053717420948, 0.01713268883195856, 0.07133183324889791, 0.03912697546184063, 0.09904305675938245, 0.0275977467367005, 0.05103519937444118, 0.04698329139500857, 0.009825741252561492, 0.046611987730307926, 0.054733902516384283, 0.03681237486401393, 0.11654415152846806, 0.007756009647217129, 0.2044677944673646, 0.2017973805026662, 0.20744450570594883, 0.13330600975501922, 0.15829117067398565, 0.19355166973846574, 0.10420219927665689, 0.287131684561891, 0.15166139981198698, 0.2294638491566143, 0.26333647269395094, 0.11946222639732784, 0.14661554637695515, 0.15786092037395125, 0.10692145134652815, 0.1194072902322777, 0.07987380553517612, 0.09489998431696046, 0.12915392045772847, 0.08445759303867818, 0.1460059089285712, 0.11248847439644799, 0.16273677889858523, 0.15342606802380857, 0.9113419332331227, 17.50056255248285, 50.89215286316411, 65.00657050840317, 61.72528428416099, 42.13748147410732, 45.11822000626595, 54.51901166669784, 43.48322314600791, 18.035713088127878, 3.0914513526424288, 0.4019607873933931, 0.6743289157748223, 4.90386535083094, 8.867715078015483, 10.347834210241995, 15.167304373556568, 10.883944745986692, 8.815890762113757, 4.687728535744452, 12.309226201426599, 27.822513041957734, 43.600396110165505, 56.7716210119186, 55.41046050287063, 52.64658589516917, 50.01526778744113, 45.40287425441127, 43.09342584302349, 42.44850581692111, 43.451404879170084, 40.62041067307995, 38.250102766098514, 40.36249130002914, 40.9471833321356, 41.218360316368845, 38.703811168670654, 40.259458480342744, 39.22149342875327, 46.2838464398538, 52.03405680194978, 55.716232792023696, 52.293819688981586, 52.637568366143014, 54.87771241895614, 54.076654603404386, 53.14191456763975, 50.428944480034616, 52.16033358727732, 55.16913667801888, 52.67485441700105, 52.72600604641823, 56.46980247189922, 54.85693954652356, 44.12358145559988, 41.352728951361875, 38.69617039157499, 40.838510144141416, 49.71203719415973, 54.979003706286036, 55.18202558640511, 56.269439958756976, 55.26601137653474, 51.99722182366156, 47.36642060741302, 40.95317279138873, 57.53766775131226, 56.66741932592085, 57.43733744467459, 54.0044790698636, 54.903560838391705, 56.64166504336942, 52.85770354732391, 50.25245743413126, 51.96612527293544, 50.129522508190526, 42.74690012778006, 42.57341761742869, 40.066697520594445, 40.8921681680987, 42.23159090165169, 50.55746093873055, 54.48435360385526, 52.11409276531589, 54.73862125027565, 55.00910789735856, 56.97023807033416, 55.4530692100525, 51.91476575789913, 43.008930144771455, 40.949509297647786, 39.36567191154727, 40.6699227517651, 40.99253769843809, 43.77347461638912, 51.534805759306884, 52.8463561304154, 57.30080758371661, 56.42427552130915, 55.355292366397, 52.963784048634196, 54.61345449570687, 53.743892485095614, 58.436969172570016, 59.10354852676392, 61.99563364828787, 54.6104891838566, 59.292932325793856, 53.321770929521136, 43.33096458065895, 28.205063766048802, 20.800499646894394, 5.6433071436420565, 12.734513109730138, 22.541424036026005, 16.160581861772847, 13.167807536740458, 5.126418182926794, 1.1975612683642296, 0.24320081687502323, 1.786022207910015, 12.485987813242021, 46.43790145074168, 51.55644155317738, 37.51931028981363, 47.49831814919749, 62.46990311530329, 69.79836540837442, 48.84187506091211, 9.018929312306067, 0.41886313848437806, 0.18348959514931326, 0.16881982345254193, 0.175566821088714, 0.1965067160105513, 0.20812330557213676, 0.16066449574164807, 0.10100476278532898, 0.16719030847232189, 0.0853943423698506, 0.12758253622920285, 0.09735999989413446, 0.19305702208751635, 0.07371514810309296, 0.07482839643114036, 0.15387891791760921, 0.09250898560088489, 0.19868836587955876, 0.16618825014560454, 0.15747070582883974, 0.24343332456004238, 0.17861462528667144], [0.05220254117082204, 0.07729692324515312, 0.02640596482031528, 0.06461360221428257, 0.07757107546973614, 0.058958475222630854, 0.03469899108993911, 0.023720026083831346, 0.012065631040792552, 0.06123265702157252, 0.0560919504101959, 0.03980408227371593, 0.054723813138421507, 0.015611426863488893, 0.09739654994900189, 0.010842510382644834, 0.08270780991522536, 0.07797584568540897, 0.0467119200695907, 0.017638230253191247, 0.04652266953921607, 0.015403591997681126, 0.06402680184692144, 0.04590089725811155, 0.09463091891619468, 8.148492122850111, 31.585552615504113, 52.54736954166044, 48.40050643490207, 38.531638729956846, 34.19153613428916, 35.83277348549136, 38.823451303666644, 18.614945180954475, 3.8118882813761314, 0.20753861194656742, 0.048554913110790715, 0.8500119370798912, 2.852567242037866, 3.141316934939354, 3.962509502326289, 12.66149720837993, 9.029964900785878, 3.213081355056455, 5.225603647770421, 14.829375513138311, 34.45180500707319, 45.92357673952657, 49.73605778909499, 46.11486681046025, 43.40646628410586, 41.622431124410326, 38.21634684839557, 37.43550492871193, 37.58171519925518, 36.58766892648513, 36.39300953957343, 37.532065837614, 36.854688198335715, 37.30017923539685, 36.747485899156146, 35.80217899814729, 36.85441363242365, 44.00337257692891, 49.54801544066399, 48.259371711361794, 49.86417808840352, 53.80157486084969, 49.23408069918233, 49.07333412478047, 46.561828736336004, 44.63126167174309, 47.50295831311134, 50.73053944495417, 53.07418700187437, 50.84823800671486, 52.78736368302376, 48.9765457184084, 41.96803900503343, 35.987691417817146, 34.64147906149588, 38.143861447611165, 45.96649531395205, 51.20617781915973, 50.35499211280577, 51.26584099185083, 50.00040592685823, 49.402417059867616, 46.633302165615945, 37.459031305005475, 55.26490526814615, 45.838127905322665, 49.74759347977177, 46.99972606474354, 50.46760336045296, 47.20553282768496, 46.44063926512196, 45.7493019104004, 43.72992846273607, 39.80131387710571, 38.52977952649517, 36.63083068786129, 38.997129932526626, 38.42516599162933, 40.03778965242448, 47.61044694531349, 49.89774180996803, 51.64328675116263, 50.59258184125347, 50.875875026949, 54.83686877835182, 49.496730450660955, 46.804195911653586, 39.48493942137688, 37.05261491960095, 36.12040873496763, 36.577941448457786, 36.528703935684696, 36.72061766347578, 37.85166055925431, 42.75368582817816, 43.297102758961344, 45.21474953620665, 43.89077309639224, 44.30672476368566, 45.86853411889846, 49.420620779837336, 48.17718628914126, 53.27106252793343, 56.24450937394173, 56.69030243350614, 45.039250927586714, 39.17615475193147, 29.158482128574004, 17.226520276838734, 7.686288356781007, 3.27487854226943, 3.3684810034690367, 4.094501180994896, 5.138638817494916, 2.3331292310068688, 1.4120846409951489, 0.3827106832496582, 0.18786706751392734, 1.2008809418447557, 11.144408756686795, 37.98794331089143, 42.66262800462785, 35.092684991898075, 41.303040366018976, 55.679707680979085, 54.64607292605985, 27.714993030794208, 3.117275747560686, 0.03698993872310366, 0.04375109749455606, 0.08366332840054266, 0.02243423177259824, 0.052405550640316746, 0.03302368320404522, 0.09262811993398974, 0.01631897705186519, 0.018231841142199213, 0.06944813029540163, 0.005258000897048342, 0.0244432284061106, 0.14444586280132496, 0.13580969234387721, 0.01783766209207956, 0.05299884743327576, 0.020186052913026466, 0.035241829501765395, 0.0223526127651454, 0.0419743710588063, 0.036111178417359634, 0.06321210181340575, 0.08731609691054591, 0.07296618224392015, 0.06437387032013747, 0.061760683123382835, 0.031409951550285184, 0.04291165665152573, 0.032362308007695025, 0.01837754723495774, 0.058746039041227875, 0.07501852413218829, 0.06782672052542049, 0.054913603760782755, 0.04006290507893409, 0.06912199134427695, 0.07296317917925697, 0.03727553630127542, 0.05523335736905856, 0.08063112941360281, 0.0395790362850793, 0.02180966518578991, 0.03409743586915635, 0.04593361687335757, 0.11247352036016603, 0.1106843066912505, 0.202133524562082, 10.110057188618569, 39.580507970625355, 59.51699379951724, 53.34607001273863, 39.84806460718955, 37.14931311145906, 43.12243961518811, 43.91179307814568, 21.884366235425396, 3.7059411406517033, 0.31233554826148097, 0.30890325985608563, 0.9843167722705872, 1.8591407037550405, 5.692769212107505, 8.328490180353965, 9.90366501192893, 7.889252381940042, 6.2193689807768795, 8.721742110867655, 19.304358613106515, 36.28853721003379, 50.257387853437855, 51.83336088734289, 48.886099784604966, 46.10763003749233, 43.84199057855914, 40.39390164036905, 39.354108764279275, 38.930763429211034, 38.03461951594199, 38.84731892616519, 38.44620166286346, 38.12590091459213, 39.266337886933364, 37.210325579489435, 38.53749090625394, 39.20416439733198, 45.49732100579047, 51.42142964947609, 51.71838052811162, 52.23721596502489, 54.141424702059844, 52.356220676052956, 51.45924129793721, 49.08207316552439, 45.71943306153821, 49.43439222151234, 51.28550383352464, 54.48241987536031, 51.4884433438701, 54.379500804408906, 52.01665716786539, 43.25276036416331, 36.575266392000266, 35.75089400814426, 40.358298286314934, 48.5972446780051, 52.618646852431766, 52.82503412615869, 52.21139892455071, 52.3028136837867, 49.86318180637975, 47.387409210205085, 39.12092385753509, 57.20789055670462, 48.55934673740018, 52.04270955054991, 49.35204990448491, 52.60229449118338, 49.94657531861336, 48.10819964255057, 47.39301819955149, 46.00311456188079, 42.7672964526761, 39.88236965671663, 37.58039336050711, 39.96203691728654, 40.04595210475307, 41.89332962036133, 48.80864081844207, 51.085910104936175, 52.90360704545052, 51.77029309734222, 52.37289467165547, 55.22404986043131, 51.87201976776124, 51.01219700228784, 41.01986877379879, 39.52900725026285, 38.24377990538074, 37.26911014126193, 37.63266286542339, 38.926605716828384, 40.77728586812174, 45.78937284408077, 46.67336525455598, 48.02391575228784, 47.49759643308578, 47.722077600417606, 49.506999215772076, 51.55992069552022, 52.334043595098684, 56.22560747208134, 59.27477959663638, 57.5973819148156, 49.243894469353464, 43.77351384009085, 34.22911636291012, 23.001894604775217, 11.564530884065936, 6.484985514994591, 5.5347383887537065, 4.8796324576101, 8.263749499474804, 4.64452657007402, 1.7182657146646132, 0.440646143810403, 0.03748555164483767, 1.4674979256045435, 13.196641860469697, 44.32103749244444, 44.986106734122004, 34.743076293699204, 43.44561938316592, 61.81573021796442, 62.97935232039421, 33.93729986683015, 4.410335575380634, 0.042934600984857935, 0.04527685352631154, 0.01997481948966461, 0.04570808441888902, 0.03359091768582021, 0.03538946996653273, 0.0534246659146682, 0.06833656736078762, 0.04077408748168138, 0.017763326665566816, 0.02962480772346739, 0.04663203625128635, 0.0707526937607796, 0.09774236969890134, 0.028585992498143066, 0.0581601043532212, 0.01802563900128007, 0.06813488705384155, 0.014258817236329761, 0.03314845211383316, 0.04317982572942011, 0.014188750834775068, 0.20362215597302685, 0.19511130217823291, 0.12739647645503283, 0.16536334199049782, 0.15772593568169302, 0.22056500247168928, 0.2186232606970495, 0.11586115350045505, 0.1442689577778501, 0.18297472277716284, 0.16131910255118725, 0.12594290122750307, 0.14600200188015738, 0.15820633409725082, 0.17495773522363556, 0.2184126478049063, 0.210596390609299, 0.16423665648025854, 0.19937104215064358, 0.13946129640023555, 0.12355714255282957, 0.08286675783775507, 0.14119820158568122, 0.25362753399437477, 0.22336405792063285, 12.094274432428422, 44.04890737225933, 66.70347413709088, 60.27119890336068, 49.235830076279186, 45.26862329052341, 46.26609771482406, 48.714166610471665, 24.5946632277581, 5.113215975223049, 0.4119253236680262, 0.6844127166175074, 2.1959737520064078, 7.443761344878905, 8.814007043838501, 14.667508121459717, 21.03848945709967, 16.845599297554262, 6.602323708995697, 7.721152834353909, 18.845727635968117, 36.849345930161014, 51.82194286777128, 54.87248782188662, 50.896502771685206, 48.032042903284875, 46.488770669506444, 43.27708298160184, 42.53331530478693, 43.06313337818269, 40.81322262364049, 40.94584188153667, 40.767130851745605, 40.528321266174316, 41.761957676179954, 40.2067300581163, 41.09038122238652, 41.532651993536184, 47.131698131561286, 53.925686497842115, 52.3787860716543, 52.584761496513124, 56.94975153092415, 53.32174347292993, 54.75866063948601, 52.13290837503249, 47.55020718420706, 51.57193099298785, 53.448926325767275, 56.20150842974263, 52.786112446938795, 56.06744181725287, 52.40332049708213, 45.55576824372815, 38.065276761208814, 38.66865496481619, 42.06283092498779, 50.94284557527112, 53.96012490795505, 54.2862307640814, 53.38962008876186, 55.29147148132325, 49.04267295714348, 48.34092170961442, 42.07622581912626, 58.381699054471916, 49.80372651930779, 54.69358067358694, 52.065357315924864, 54.919748460092855, 53.34854110594719, 49.07229861905498, 50.23585796356202, 47.43860398569415, 44.11250075986309, 41.99237338958248, 40.039472349228404, 41.86755180358887, 42.01744517972393, 45.26606982754123, 50.90901513253489, 52.65337551793745, 55.16082517562374, 52.66166348611155, 53.84303823594124, 59.413113747873616, 53.64801406860352, 52.27902058632144, 43.78285300347113, 41.49864896651238, 40.691201609949914, 40.83167345293107, 40.829673044143185, 40.87819276317474, 42.45020420320573, 47.021758018001435, 48.04158210754395, 49.11381298495878, 48.64772558212281, 49.67359012173068, 50.71816436706051, 54.91964647846838, 54.10606061258624, 58.870285172616285, 61.157725164967204, 59.62597293238486, 48.545296807442945, 44.90661990258002, 31.996662116819817, 19.467931255217522, 9.302944214113298, 6.628647225518381, 9.168284343134973, 11.683061968895698, 12.694963851282674, 10.121747812917157, 5.8799515808782274, 1.4405104253561267, 0.4784630935999655, 1.962722655265562, 15.382898430670462, 47.78167409281577, 55.94417741221767, 46.286415592316665, 52.52781260398127, 70.46112829639067, 69.38497112643334, 39.107866287231445, 6.2850775064960605, 0.20415507737667332, 0.14332207310343945, 0.17216586567942174, 0.12049364887418286, 0.15848738111315236, 0.16244140603849966, 0.23227356854946385, 0.1634186584382288, 0.14055845688187307, 0.17371590669837692, 0.134012158960104, 0.1696797877910637, 0.2770692422505348, 0.2955911951439996, 0.191246296669687, 0.18889984596640835, 0.14570889664032768, 0.18462769536962434, 0.09825602399125215, 0.15516623674381166, 0.12145841404074624, 0.16171999636196321], [0.05612459341664949, 0.04298310967222337, 0.0071838678934821685, 0.0725175611554615, 0.03548953637120224, 0.03459482994531432, 0.01885827698354279, 0.011100010728583702, 0.017926026503705693, 0.07271681296368761, 0.04760321357377595, 0.045454474841995586, 0.008025125801307901, 0.03307674628412051, 0.14513253805137452, 0.012969093851655001, 0.012828481285983037, 0.03096196056914426, 0.04246569771860396, 0.028860380294762795, 0.08464631879882467, 0.05798805632718629, 0.05403257583478286, 0.037028338880308216, 0.08254268732402595, 3.6073388832230724, 24.656089505841656, 48.30852685436126, 54.024557682775686, 41.147385028100786, 29.648060606371974, 40.138708314587994, 37.1885250460717, 24.834688748082808, 6.535359044228831, 0.5048938011450153, 0.0620389262574815, 0.7602468409365224, 2.1050948865952033, 4.3910492812433555, 4.726027048403218, 8.580664261694878, 4.424301174379164, 4.939370645630745, 2.966601574613202, 9.889966134102115, 24.137491372323808, 43.76635943689654, 49.10477584408176, 47.72525864262735, 45.437869641088675, 44.860147660778416, 46.44980976658483, 46.18115094400222, 45.10316987191477, 41.815921645010675, 39.10241419269193, 39.25607304419241, 38.63946076362364, 36.90645171749976, 36.07716460381785, 36.4937360055985, 40.45576918509699, 44.44859689281833, 48.78409070353354, 52.732101409666, 49.505430267703154, 51.99757875934724, 51.533150519094164, 48.470814920240834, 43.357079721266224, 40.97263166981359, 45.57002998167469, 48.470877678163596, 49.63200515316379, 51.26305610902848, 50.46009594394315, 50.684228020329634, 43.65925127460111, 39.44201300221105, 36.25310644026726, 38.63835857760522, 45.506648402060236, 49.43228983109998, 52.225593982204316, 53.39992023283436, 48.65450736015074, 52.817307056919226, 46.82107779287523, 38.346585227597146, 53.864693641662605, 49.010772320532034, 46.27230290443667, 44.59132802101874, 44.38241474090084, 41.23631692701771, 41.58499602348574, 40.530105944602724, 39.27845016602547, 38.142096381033625, 37.75764919096424, 37.467174145483206, 37.45177492018669, 37.88996250398698, 41.82055004181401, 48.29129980456445, 50.57881432194864, 51.761601125040364, 50.39746745940178, 53.08249065952917, 53.103039956861934, 48.978812848368, 46.49978076258014, 39.13766845580071, 38.46267561758719, 37.95514445151053, 37.63364345796647, 37.91081382382301, 37.113215538763235, 38.34500059004753, 35.746650003617816, 37.71724093344904, 39.47074436372326, 40.08840783949822, 40.00929755549277, 43.522717491272964, 43.969561746043546, 49.899628470020915, 50.04221054815477, 55.084852787756155, 54.26632081308673, 48.81406937876056, 32.29295599845148, 21.87053595819781, 12.96901201048205, 8.043184818760041, 5.083424593171766, 4.66450467225044, 2.7739938324497593, 9.620312010088275, 2.9659666409415584, 0.6170238230016925, 0.20551338190993956, 0.09906406289026623, 2.0711582947161893, 12.5713836954486, 42.9121966515818, 51.159348641672445, 42.69480320715135, 44.944188364090465, 56.41697991278864, 50.679823198626124, 19.862910009199574, 2.4747135562281457, 0.00487655422823023, 0.08697396204356225, 0.009939190255658282, 0.04854858522453616, 0.011857689880285294, 0.02731114558334793, 0.058720758139726624, 0.022224685657889615, 0.014049785358140306, 0.03060002807497738, 0.009194024192589906, 0.1126848457140788, 0.03186573173039623, 0.06071497310673999, 0.03357024097274389, 0.01691852320706652, 0.006834730504065633, 0.018217139914932273, 0.03439393487849063, 0.03916973465933435, 0.012310692991670823, 0.020913669816969384, 0.058414644726942626, 0.0367248876230611, 0.021383902245771982, 0.0778422322905352, 0.046146822973124446, 0.08971585201159601, 0.03907257555833748, 0.06449483560338136, 0.010959318681289593, 0.07537208903100222, 0.02535996369026121, 0.05347934927070334, 0.041914045465208834, 0.05131592846385414, 0.03320256473436471, 0.019375886204802704, 0.055443338238664215, 0.031220203062759775, 0.01696266136282394, 0.02743138882872318, 0.04642538020327207, 0.046081230525047555, 0.03731301715297084, 0.03662860569273753, 0.11005608394982354, 5.071848698200719, 30.236045468238096, 54.63781633684712, 58.07102380260345, 46.46373025832638, 33.77938524369271, 40.907202612969186, 41.15875597923033, 26.889747919574862, 6.945292815085381, 0.6186986750652713, 0.09291339575523332, 0.6531249503454855, 3.0602599295877644, 5.047355947955962, 9.174749389771494, 8.925988751073039, 7.619464897340344, 6.146022129443384, 5.804147854928048, 13.409516734461631, 27.656714454773937, 45.05042183783747, 51.59796376382151, 50.17057011204381, 47.66124163904498, 46.16237848035751, 46.2243676185608, 45.93497906961749, 45.848380980953095, 41.64120358805503, 40.870140137210974, 40.50662663675124, 39.97726748066564, 38.639515676806056, 38.64482656601937, 39.39614088304582, 39.886935295597205, 47.423726435630556, 51.314878463745124, 52.490161772697206, 49.20803223886798, 54.80346587396438, 53.40515267464423, 51.08132485420474, 46.13748711924399, 42.56781647282262, 46.830460102327415, 50.50711731756888, 53.749344579635135, 53.94272527387066, 53.342579103285274, 53.01640264449581, 45.67593397632722, 40.12373662764027, 36.98948044930735, 40.54173969453381, 47.1953542770878, 51.35346674150037, 54.64272322193269, 54.99397147086359, 50.950882511754195, 52.234419315092026, 47.7445920052067, 41.300655564954205, 56.38591866339407, 49.68911094050254, 49.13862589866885, 46.38305102625201, 46.571971985601614, 44.821477013249556, 44.17983608861124, 41.73634459895473, 41.98349314351236, 38.26720037767964, 40.10534463390228, 38.152612255465606, 39.70007750295824, 40.65341349570982, 44.604636623013405, 49.406410032703036, 50.6827728209957, 54.342293200954316, 51.51173830032349, 53.39816301099716, 53.111512276434134, 51.57954431349232, 47.81715193102437, 40.033235780654415, 40.65015400609663, 40.45430614102272, 39.99781285562823, 40.50221397030739, 39.159818080163774, 39.20277195592081, 37.98206367800313, 40.11580167278167, 42.65901157932897, 41.88925427775229, 42.86772089619791, 45.318115757357695, 47.30187800622756, 51.06839672211678, 52.813247403790875, 56.81188021936725, 58.29215918817828, 49.8649743295485, 36.08367181593372, 24.322058500782138, 15.137977792370705, 9.07758443586288, 7.822053845851653, 5.8068626253835625, 5.447659319446934, 7.6738245352622005, 4.7810574116245395, 1.523649351250741, 0.06833472874976936, 0.14368703739056665, 2.2540012963356513, 14.828297841933468, 46.17169018714659, 47.9894067395118, 42.73538012658396, 48.39017491186819, 62.870545771814164, 59.90513193991877, 23.73090632500187, 3.3111259004762097, 0.011670663877720795, 0.01612910982071152, 0.03821287552014955, 0.03719899645676056, 0.0766244665869782, 0.01404592714783165, 0.029751164350478403, 0.01981562833421894, 0.035221348141109755, 0.03520237980410457, 0.045594086705316464, 0.046558821228362864, 0.038812756838817755, 0.009258876408209965, 0.02220422153421227, 0.029880592990065777, 0.012218408125092187, 0.025226198993022406, 0.08585152832130272, 0.03608256120294814, 0.02239805518559391, 0.05434626585713798, 0.12259941773429034, 0.27525067209236087, 0.1371320826752532, 0.13818326255967542, 0.2382389879635265, 0.2285399930852075, 0.13807400309991452, 0.12430611607288161, 0.12870182133009359, 0.20944728936639526, 0.3323012704570448, 0.08690746561173471, 0.17544869033078994, 0.11752762456214237, 0.17181801579652295, 0.10485295266393693, 0.13808760882144974, 0.08478831319559006, 0.14715478034509769, 0.09835455822007311, 0.12004993840931885, 0.20428172703231537, 0.11927548480490524, 0.12001699662857479, 0.15791053222792764, 6.32206496692473, 35.367447022468816, 60.58286259251257, 66.61806060421851, 54.001760867334184, 40.59108311130155, 51.714481692160334, 50.970510052096465, 33.579465958379934, 9.063813974780421, 0.8516867891434701, 0.35016417323100957, 2.197070544765842, 7.800548470789387, 11.431978306462689, 13.796892954457192, 17.7513079104885, 10.552819236632317, 10.877860169256888, 5.617038540301785, 13.058137086129959, 27.036126852035526, 48.22105015477827, 54.36392899482481, 53.572049525476274, 51.09098565193915, 50.817349341607866, 50.89421602987474, 50.739011764526374, 49.73923883130474, 44.890495038801625, 43.051840874456595, 42.65985881128619, 43.255262836333245, 40.805887791418264, 40.172272036152506, 41.483551763719134, 42.935444539593114, 49.14931827975858, 52.27836947287283, 54.586809835126324, 48.82784082043556, 57.283188296902566, 55.18117050970755, 52.57173922754104, 47.32911494470412, 45.18263316923573, 49.468528609122004, 53.601494758359856, 54.0222317172635, 54.2308194406571, 54.12511156451318, 55.02646046300089, 48.28900129564347, 43.508526355989524, 37.89367698854016, 42.054103651354396, 49.83354437735773, 52.200883050118726, 56.01805525441324, 55.754048362854995, 53.51375133760514, 53.581247483530355, 49.18864788547639, 45.06454237045781, 58.54216714059153, 52.8338594590464, 51.472993127761356, 48.77122532936835, 48.733633333636874, 45.51956476703767, 45.83309158202141, 43.51885395665323, 43.77479253276702, 40.531635668969926, 42.91047473107615, 41.027811573397734, 41.7473429249179, 42.165816676232126, 47.13370638508951, 53.09115517523981, 53.95936789051179, 56.798312740941206, 51.20514231343424, 55.50486410817793, 55.14660266137893, 52.45609206538047, 49.65007943491782, 42.58833831356418, 41.694437996033706, 41.27471300863451, 41.27894916842061, 42.82454344534105, 40.93290590470837, 42.1345789201798, 38.81007602137905, 41.17140562303605, 44.595011126610544, 44.56875085830689, 44.091967152011016, 48.65308353977819, 49.46530834321053, 53.46041887037216, 54.51063740637995, 58.96754034103886, 58.335171899487904, 51.405214571183734, 34.69068127293741, 25.109170329186227, 15.225755533864422, 11.099556453766363, 9.64282347309974, 11.750064876771743, 8.698508931744485, 17.994708630346484, 10.30559910881904, 3.173800288669525, 0.7568879437542732, 0.32755489611337263, 3.017826258174835, 17.077895787454423, 52.45813169787007, 63.80196356004285, 56.37683445407499, 57.09960176098732, 70.160964996584, 68.41544751198062, 28.864453415716852, 3.590445480039043, 0.0638405352290119, 0.1260109145134207, 0.09222004787936326, 0.12364039332756113, 0.10385692344918367, 0.12218875630247979, 0.1452646882183129, 0.11030308601837005, 0.17968393081138212, 0.09606633019903976, 0.10423857313130172, 0.18383343073148883, 0.17570061068381035, 0.19468109784347398, 0.08473590512069003, 0.16441509367958193, 0.11761961640008997, 0.09159747120593825, 0.12230042893920215, 0.14123604632914066, 0.09964819727165085, 0.11351806592316398], [0.026078345404276927, 0.10362326663227812, 0.04725507257746593, 0.04741636472904394, 0.022839013479589935, 0.06199263539465685, 0.050083576446218844, 0.028338841042451324, 0.0373745761481264, 0.042534205131232745, 0.04463655723919792, 0.052080813630093495, 0.02352331960273366, 0.02430386935180474, 0.06690942216664553, 0.04236157104793576, 0.03295932415752642, 0.08625131896546773, 0.06679839304377956, 0.03670819839763065, 0.03677419304186779, 0.040488118350866346, 0.01194638083688915, 0.053117299948128006, 0.06703168213848146, 1.8699595812828311, 17.322357508444018, 47.14524207576629, 50.54516038587017, 39.46154640566918, 32.00536585623218, 42.407391532774895, 40.689934684384255, 33.446305413399976, 8.780339379464428, 1.232977329242614, 0.03132665097983855, 0.17287440507883028, 1.103071983783476, 3.4283775571853887, 8.0945193286865, 4.925108417387932, 4.604947893850265, 5.757729055420046, 3.7993151237887726, 4.870757114502692, 17.21345486179475, 34.80050763776226, 49.385625393159934, 47.51437241031278, 48.464801926766675, 47.315794575598936, 49.9896703996966, 48.9738118263983, 48.23104435397733, 46.372386101753484, 47.14830936924104, 46.40364739202684, 45.019266451558764, 42.20228295172415, 42.173002458387806, 41.35131689809984, 43.45133035413681, 48.429284864856356, 49.021358797627116, 49.17046377735753, 51.934832603700706, 51.85625968440887, 48.93590604105304, 46.7530599717171, 41.6001049933895, 40.89481184559484, 44.810910148005334, 48.191385269165046, 51.401327502342966, 51.29286612233808, 49.56544645370976, 50.702000279580396, 45.54127508594144, 38.187470359186975, 35.60709207288681, 38.80811483629289, 45.13936942623508, 48.24190931935465, 51.36466118597215, 52.60513036481796, 49.958977853098226, 51.67015498684299, 48.599115648577296, 39.30965654311642, 52.93539785569715, 47.06058163796702, 47.260457777207904, 39.377709665606105, 40.72154114323278, 39.760799715595866, 39.19784938135455, 37.60948558007517, 37.544068290341286, 37.65366715769614, 36.342952251434326, 36.289682542124105, 37.0172155287958, 37.854833756723714, 43.618297807631954, 48.90388381096625, 51.58310974797895, 52.31727546261203, 51.65966656900222, 51.15989777349657, 52.30546128365302, 46.741606650813935, 47.66301847273304, 41.21641089839321, 39.01177998512022, 39.66352493532243, 40.80886879274922, 40.09923750354398, 39.157856895077614, 37.492583259459465, 38.41157890135242, 36.6930708577556, 37.47889418755808, 38.627987830869614, 40.47616158762286, 40.870155826691665, 44.05459480900919, 45.31644875003446, 51.92221826122653, 52.331011602955485, 53.29237276507963, 39.464837274243756, 26.83785692338021, 16.65598015631399, 9.214057422453358, 4.531112217134045, 6.682924493666619, 3.306362181901932, 2.7148221817708786, 4.843218153522861, 3.481944876332437, 0.9357190348448293, 0.22273344498488212, 0.27049669815647986, 2.120510046520541, 18.32697064645829, 43.9269216599003, 52.23008117368145, 32.70879195582482, 40.27121382374918, 57.68112059562438, 46.17873476397607, 17.060851127870624, 1.5158613626995396, 0.04039918703417625, 0.0682329386472702, 0.027390211602793108, 0.033215622703034076, 0.058081503732190023, 0.02744078106667486, 0.055401325976896676, 0.054424487264646645, 0.05556426904795151, 0.0516741358554892, 0.06405224745732642, 0.014578867703676225, 0.05036001161281621, 0.05483810196540529, 0.021635985392476284, 0.09731906015546092, 0.08368451073164902, 0.028457172898455497, 0.023318992462009195, 0.028221238885195028, 0.018285247046620618, 0.08425610425371317, 0.09656192013813604, 0.06996626620210948, 0.04800677720096804, 0.041020783115058176, 0.03208003525111464, 0.023202832465270357, 0.017807303942860137, 0.018186515550159158, 0.012757003367427858, 0.0024001338357676665, 0.019859879487945188, 0.03818276060384609, 0.03979709172140687, 0.04972812697111119, 0.035246613720852527, 0.027182027209369887, 0.04297764746532325, 0.07287549275544382, 0.052639490909754276, 0.07221023732375714, 0.034034425137384285, 0.008049835488500615, 0.0174123051786615, 0.04632270526922038, 0.02480191460269834, 2.405640127197389, 21.164411267926617, 53.602196862620694, 57.557687528671764, 46.45923522210891, 35.991845207829634, 45.21827182462139, 47.46812766598117, 37.0009651491719, 9.705430384605162, 0.9423827740453905, 0.04111875809969441, 0.37821154080090985, 1.545343980673821, 4.918541389126932, 5.65752818699806, 5.610002788805193, 8.999559667802627, 7.437703244147762, 5.407522195769895, 7.957305504429725, 21.766051861547655, 41.35008527386574, 50.02058259902462, 51.16087836603965, 50.12111294654108, 49.39235618037563, 52.17822744000343, 50.97019626248268, 50.36679844702444, 49.22076425244732, 48.43539199521465, 46.76814148502965, 46.857202822162265, 44.525800904920025, 43.972483911821925, 42.72832770501414, 45.5612164158975, 50.10054795972763, 51.15719133807767, 50.68323566067604, 52.76517483495897, 52.9701735896449, 51.95411889783798, 49.33654869756391, 43.23667080171647, 43.61588162760581, 46.42233748589793, 50.04446983337403, 55.21765247468026, 51.77968325153474, 53.03032705860754, 53.01380211307157, 46.44108249295143, 39.79894084315146, 36.53106912489861, 39.6345111631578, 45.82690992662984, 50.58599618173415, 53.06926442730812, 53.29806804656983, 51.013118759278335, 52.41716254142023, 48.74059161832256, 42.42428518110707, 55.85209585005238, 49.200336548589895, 49.930823080001346, 42.14278844095046, 41.98119071222121, 40.30973542121149, 41.00615616767637, 39.26642417907715, 38.93144984399119, 39.23571986536826, 38.634083194117395, 36.732251413406864, 37.92611891223539, 39.479420646544426, 45.577709982472086, 50.74636620859946, 54.95552047606438, 55.36506691286641, 50.699509574520974, 53.65440360961422, 54.07584659514889, 51.22788421569332, 49.133232639681914, 42.47997499281361, 41.74294594795474, 39.868912004655414, 41.80641381971298, 41.16602413115963, 40.88783394905829, 41.06030056553502, 40.75189636599633, 38.97667869444817, 40.2168183941995, 40.188051731355735, 42.87821715877902, 44.19581190232308, 45.80727454154722, 49.32597398757935, 54.81828066610522, 55.625225959285615, 56.692130258006436, 42.93979444811421, 29.418019479320897, 20.518702845419607, 10.769142854598261, 6.628002976217578, 6.607861605382736, 7.254401080070004, 6.090979018519002, 7.220886878428921, 4.136032462120056, 2.22663099727323, 0.36539246898985683, 0.1627337451904051, 2.8192528361274354, 18.669552418493456, 48.1758919069844, 55.429986061588416, 41.63597506861533, 48.20432516836351, 66.42187933767995, 53.2470654672192, 20.88400886904809, 1.8053224754910318, 0.0371701723986095, 0.07225953508168459, 0.05340099762824755, 0.04450372908444655, 0.04860121929537385, 0.0652314751078525, 0.07555564369765982, 0.062404062914391684, 0.031194117768938025, 0.02156618520647528, 0.05842193788398178, 0.017864199377776637, 0.03813784486884552, 0.05348297286658518, 0.05179108683800986, 0.04357996877403029, 0.10507323358568454, 0.017846315055184307, 0.05465515250820787, 0.05731749190618435, 0.0428424789119632, 0.020774644010910587, 0.16490440935857836, 0.40114778424462966, 0.19747623092224523, 0.21080171749476465, 0.1909377624190623, 0.0848034434320946, 0.15323805472543164, 0.08603636235479387, 0.15481215090520922, 0.14958254362065948, 0.09948058489469752, 0.092101878817043, 0.106411351702146, 0.1548303531542901, 0.1353836248839094, 0.141014248553303, 0.1303501973950094, 0.21369371473068194, 0.1658232092496849, 0.1820321741604036, 0.10557574895961631, 0.1730446298156054, 0.1084290357727197, 0.14250476454054156, 0.19931079699627816, 2.994344253693858, 24.251681373965358, 60.9950017159985, 63.49359466183571, 54.168826380083644, 43.698859368601155, 53.446161054795795, 52.94939287247197, 42.93951595983198, 12.48900999945979, 1.581811236758386, 0.20423923979603475, 0.8879682842281558, 2.9059043670854265, 11.787680406724254, 17.18353109975015, 11.524156947289745, 11.89382758832747, 11.123151471537929, 7.805209717442913, 7.556116657872354, 21.6638348948571, 41.2308059969256, 55.35756341872677, 52.79816589047832, 53.54436543680007, 50.72427934215915, 55.59576111455118, 55.16008384766118, 52.48547061797112, 51.90503827987179, 52.24122854971117, 48.855862232946585, 49.28850750769339, 45.5460133091096, 47.54040125877627, 46.02476996760215, 49.15522144686792, 53.40601951845231, 54.00513802805255, 50.906583263028054, 53.63393668205508, 54.793146118041015, 52.797961927229366, 50.4653597647144, 45.62752800603067, 46.2478155474509, 48.5560009556432, 52.66724109649659, 57.53337275597357, 55.25726056868031, 54.57877289864325, 56.15677379792737, 50.493859706386445, 42.960116247976984, 39.67025180016795, 43.19956517988636, 49.56183395078106, 51.18101189213415, 56.18535610937304, 55.8321858990577, 52.62160039717152, 51.4968607502599, 49.49375729407034, 47.13921731518161, 57.44636674081126, 51.36488868344215, 51.26717852007959, 44.32183765595959, 44.38716080880935, 43.469145759459465, 41.416271348153394, 40.475941934893214, 39.910202795459384, 41.644682730397875, 39.94906563912669, 39.5846539158975, 41.48483045639531, 41.74950415088285, 47.136726610122196, 52.56219217854162, 57.633612848097286, 58.43025407483501, 52.912404921747026, 54.15452541843538, 55.99782366906443, 51.77209346525131, 51.99873978091825, 46.168269880356334, 43.61231619311918, 44.82548175319549, 45.10304435606926, 43.45786502284389, 43.227716030613074, 43.1417808225078, 43.013970390442886, 40.652048510889855, 42.029784956286036, 42.35901694143973, 45.35321704802975, 45.06659377005793, 48.68729053005096, 50.91082334518433, 57.318952468133745, 56.95888280868531, 58.8493279487856, 44.42649433689733, 30.137505723584084, 20.201379176109068, 13.773771562883931, 8.172276885278764, 11.751019973908702, 7.276094238604269, 10.873910342493366, 13.257272878000814, 11.920925282662916, 4.647867448868291, 0.9534669018560841, 0.564358281272073, 3.5570160996529365, 22.28069624593181, 54.62505686667658, 65.48586453160932, 45.993375316742934, 52.351764863537205, 72.53913725576093, 62.397492239552165, 26.482129327712524, 2.626510507637455, 0.14087627611814008, 0.113779692610185, 0.07391043923675053, 0.23667356389905178, 0.13193039163466425, 0.20653944943220387, 0.18626297133103495, 0.1562759457456489, 0.11171836451056505, 0.13832547912193885, 0.21448764229013076, 0.08985291280212904, 0.05570904434388203, 0.29355628175600884, 0.12223491309991769, 0.1504270329831108, 0.1890053056300648, 0.14224896778262433, 0.10913467935977444, 0.16474046654278235, 0.08445951591936812, 0.1447079568019798], [0.03523595360738616, 0.023484718347448977, 0.027141639054001823, 0.06083740927879849, 0.06425344129844059, 0.03994916783525579, 0.02976298508715005, 0.02828464606746791, 0.060948576297490835, 0.0478655795356439, 0.025571947879788857, 0.10629563412118344, 0.05282284256311194, 0.017064694698239048, 0.05214819106303396, 0.05229530292713354, 0.1038460296789004, 0.02333395224395058, 0.04012537954915916, 0.0377112602995288, 0.13012014119134796, 0.04102851294221417, 0.021891835776548234, 0.04923072140363436, 0.04284175112843514, 0.5431744179898693, 11.436600819710764, 39.0282892411755, 53.34494429249918, 48.28891892586985, 36.8308872561301, 33.28418600943781, 29.92875522182834, 31.74231210062581, 14.470989531086339, 2.0288817632582883, 0.09256956017305774, 0.3740093340316127, 1.1716006936565524, 2.9065218952394303, 5.461262589500797, 5.392603460819491, 10.14775901071487, 6.204952799504803, 3.8177061369342193, 5.213578151118371, 13.085817252435993, 30.288087475684385, 47.1641988908091, 51.73020647418115, 50.75007677078248, 50.89507502894248, 53.58722909804314, 52.05548863257132, 51.14843268548289, 50.30520154583839, 47.43446980753253, 47.090042560331284, 49.47393363521945, 48.00610034696518, 46.13775776278588, 46.49270872915945, 44.7866738227106, 44.91169937195317, 50.51841766603532, 49.93260383605958, 51.38389648929719, 51.034460375385905, 50.21280227168914, 45.566531227480986, 38.90124367129418, 38.39643855248728, 38.17139256385065, 42.96602725982667, 47.29218582953177, 50.01005103511196, 50.29818442560012, 50.049992530576645, 44.90788682814568, 39.72006197898619, 37.22243785858154, 37.326851352568596, 43.66291084597188, 48.03907571300384, 51.53748866050474, 52.948153403497514, 50.24648758672899, 49.94527701408633, 48.292849140782515, 36.92308648940056, 53.39334241805538, 48.91144614065848, 47.855402884944795, 40.33332063305763, 37.49440716158959, 37.59081902042512, 37.79295836725543, 38.62007641023205, 35.697306586850075, 35.765587206809755, 36.30183404491794, 37.39120567998579, 38.13915068103422, 37.271157618491884, 44.09694856212985, 48.9129719426555, 49.53642091443462, 53.45183672443513, 49.037919044494636, 52.178992302187034, 52.883842222152225, 49.66715743464809, 46.495630894937825, 45.87009914459721, 44.80998839101484, 44.927000537995376, 47.19452273461127, 48.01054831474058, 48.494164789876635, 44.04837000754572, 39.877807940206225, 40.023535759218284, 38.990359921609205, 39.72674569775982, 38.903322527485514, 40.33405803865002, 44.77212575174148, 45.59744342680901, 48.723199828978515, 51.28152655016992, 48.84582096530546, 38.020777471603886, 20.89383440632974, 11.415123881832248, 3.1197240419926184, 3.1825964489290794, 4.400339414996486, 7.195585139336125, 6.282307332561863, 4.74124780585689, 1.1897312369077437, 1.7716519919133957, 0.055133153068562674, 0.20580251881432152, 3.875754518855003, 21.05044876375506, 41.70914296180972, 40.23093108207949, 32.86142314634016, 36.37323687153478, 52.66256955362136, 46.218762551584554, 17.088992172671905, 0.8876107356721356, 0.0675186765710673, 0.009055079783373063, 0.03862261381601134, 0.06152648238405105, 0.03169746817870727, 0.006832441816391845, 0.03658840522891091, 0.02112361621261845, 0.05239291785044536, 0.02372440427631861, 0.07787939521574205, 0.0339699435167976, 0.06609690165327442, 0.014616086170257581, 0.03002473626345877, 0.02809907275912983, 0.04150490088748836, 0.02558214259484122, 0.018753434020665385, 0.031188764729567116, 0.058666040309734886, 0.06795883238796266, 0.014776031922308669, 0.02060478891155893, 0.03764042781004983, 0.021474896254198208, 0.1793189818460134, 0.04420364478362664, 0.0356777718350772, 0.022032650397910226, 0.041392021662285255, 0.07291470879628774, 0.062062567730824796, 0.04103130533269817, 0.01157634983575272, 0.033456293054886406, 0.02275423818988906, 0.006330135201419434, 0.052289767941880616, 0.03585730454013233, 0.0063991477532732875, 0.014782348317244362, 0.06254752819997168, 0.10906102000585488, 0.048255108432063175, 0.03380025121112985, 0.024071467003875205, 0.9817471907984827, 14.480394394167009, 45.95453600729666, 58.28070586727512, 52.94562347473637, 40.37575283358174, 41.42239809036255, 40.47773445806196, 37.590207130678245, 16.21248560567056, 2.328290742251181, 0.0400178591089864, 0.19556376902807146, 0.7461425493801794, 2.859752779045413, 5.32120063420265, 7.519292466102108, 8.27522929637663, 6.716967234688421, 6.413865589326428, 6.825073149896438, 16.805899027855165, 36.11187757984285, 50.2337202718181, 52.77763620499642, 52.93643336142264, 52.96714551987187, 53.95390795123193, 53.58072188592727, 54.67662426733202, 50.97541693718203, 50.400366090959125, 49.26653831235824, 50.69828971739739, 48.62182224950483, 48.39734892691336, 48.064720169190444, 48.12847829634144, 48.012446741903986, 52.3546987964261, 51.41778968995618, 52.40078664595082, 53.57446570550242, 51.28242085056921, 47.62030778392669, 41.01872736407865, 38.91588195677727, 39.76794235167965, 45.95674822407384, 49.12782369121429, 53.79545988575105, 53.14832764287149, 51.49207545864967, 48.137119277831054, 42.43601306792229, 38.465601705735736, 39.84603281944029, 45.34132442166729, 50.09678248436221, 52.82039003987467, 54.10032610739432, 50.64538478851319, 51.396067603941894, 48.05923277331937, 39.38509548864057, 54.995834596695445, 50.67509282019831, 50.21997628673431, 42.09225654602051, 39.40537806480162, 39.23224464539559, 39.7813529352988, 38.337371580062374, 38.37405750828405, 37.36442765881939, 37.76967125554239, 39.69631594996299, 40.80088284707839, 40.312351642116425, 45.84145407522879, 51.50860432655581, 52.588452446845274, 54.95067634890157, 51.00048872732347, 51.775148991615545, 55.02328334316131, 52.451444056726274, 49.161807106387236, 46.71737817025954, 46.10408029248638, 46.86756964652769, 48.950936563553356, 49.749319322647594, 49.08202609708233, 45.936646076940725, 41.68279640136227, 42.19089631111392, 40.23157827315792, 40.41674552425262, 40.25228446529758, 43.41611923709993, 45.06948063450475, 49.167408250993304, 50.25008832254718, 53.922277958162375, 52.111123531095444, 38.48455067603819, 24.40537944916756, 15.293517420368811, 6.416411207568261, 5.653952456289723, 6.381335902598597, 8.387153148651123, 8.332590037776578, 6.918250524228619, 4.635516885788211, 1.5768172015105526, 0.4174224641774932, 0.1680700838445656, 3.7602412075765677, 22.629165495595625, 48.93729848246421, 50.96323013305665, 37.33573159863872, 39.98588492793422, 61.550640752238614, 52.969436184052505, 20.414103038849372, 1.1483152979804625, 0.008408792688691569, 0.019439701328895265, 0.03827083773250061, 0.02804468817738516, 0.04507598144212558, 0.045766038970360835, 0.0678696214491802, 0.0399383774868423, 0.05693881847565213, 0.05463127737804767, 0.04172897011402153, 0.012189010458607829, 0.014446272248131855, 0.06148477655745322, 0.044602757439978664, 0.056443278332270926, 0.018950220940995122, 0.040001935971480225, 0.08711764183376106, 0.026131908356722806, 0.03777194212401106, 0.04495570563801354, 0.0940714908703681, 0.1824592528564315, 0.10627144106453466, 0.18862900324165824, 0.2687592107442118, 0.1291184199433173, 0.12187979304261747, 0.13306099951507586, 0.17507301613448129, 0.10438085864147834, 0.20271956650239809, 0.2041031212936486, 0.11161845898435963, 0.10545917336017856, 0.14582947887960943, 0.1644217280010062, 0.14166409029595314, 0.12995956916241877, 0.1693725405681518, 0.12848144847779505, 0.1957586617960084, 0.19335421823686172, 0.1373639928116914, 0.17091842939055737, 0.12897772023514395, 1.148660711703762, 16.317169743199504, 49.29290448465655, 65.45285386423912, 59.19612038520075, 47.800776035554954, 43.18944154247161, 42.458037176439845, 42.39755422838273, 19.653345615633075, 3.1291171379627722, 0.4190431997901009, 0.9182576234302214, 3.7707105038627504, 8.860015465367226, 12.445348135886654, 17.420985506426906, 22.240170317311442, 13.199056079310756, 7.899329931505266, 9.294341475732866, 17.31070218547698, 35.93426089132986, 52.190527992863814, 57.598495867944536, 56.54598274538594, 56.21751954478603, 57.48143273015177, 56.54380975231048, 56.27522545476114, 55.19891138999693, 52.02849488104544, 52.055676906339585, 53.943568583457704, 52.43500932570427, 50.751367230569166, 49.34620165055799, 49.973702430725105, 50.07000446319581, 55.38496509675057, 52.04359992857903, 53.93702999238045, 57.46235432163362, 55.236785796380815, 49.30366746840939, 42.828920810453354, 41.98456787293957, 41.47850367330736, 46.97175956541493, 51.2442522664224, 54.490460734213556, 54.921207581796956, 53.108747005462654, 49.9272027323323, 44.560847282409675, 40.38932815674813, 40.74527540514546, 48.614095180265366, 52.674011107414, 56.19699770404447, 55.13810680758569, 52.37651109695435, 52.50457648308047, 50.34120105927991, 43.36175518651163, 55.95952956907211, 53.894452664159964, 52.74576302497618, 43.49518637503348, 41.23052358627319, 39.96903834804412, 41.36077765495547, 42.57761847588324, 38.94494279738396, 39.38564854283487, 39.804322335027884, 42.80293510806176, 43.598862463428134, 41.608726363028254, 49.84711185578377, 53.966687033253336, 53.54038815344534, 58.62479186827137, 52.73041871286208, 51.615979210022964, 56.28537262639692, 54.840842139336374, 51.80846952622937, 49.96841507573282, 49.18478435085666, 49.70884438483946, 49.90876367015224, 52.45573120732462, 53.213097741526944, 49.926390801706624, 45.03939605528309, 45.28434415017405, 43.25262308120728, 44.03905437838647, 42.27294052800825, 44.672313197966545, 50.22584023014192, 50.756034851074226, 53.91599039877615, 56.00340520181964, 54.61113245256486, 40.57491117908109, 25.32481831888999, 14.74466996808206, 6.259272233132394, 6.703414955446798, 10.700319966962262, 14.996401802186044, 15.498707390600636, 14.967321349728493, 8.360280990600586, 2.642229406103011, 0.347803182178928, 0.4348501370799157, 5.16414697131803, 26.827741130705807, 52.67563496866534, 54.64762226227791, 44.520258595866544, 50.36843015301613, 68.3920858752343, 60.82238212708504, 23.26881777855658, 1.5849056191021398, 0.2539543471028728, 0.17509699468651127, 0.13719136255883402, 0.25488263116248194, 0.14957600122978612, 0.10355082535815817, 0.11833252250066689, 0.13847653633884846, 0.1585735660046339, 0.19417823772997628, 0.11654962139624743, 0.19200838561500275, 0.17987050386446138, 0.12105683841171766, 0.09607464991389744, 0.14523333990045134, 0.09835691777087989, 0.12782706383375392, 0.19625283447244476, 0.13599726131125806, 0.18980954473297443, 0.14790851893203874], [0.05080047769532089, 0.04442460752362686, 0.01995670342547519, 0.037083807476465745, 0.031818711168823705, 0.026727647054940466, 0.049990933433535605, 0.06373925074454277, 0.06993254301168265, 0.03769475493520018, 0.04112800861138009, 0.00332817226843608, 0.009622065286572662, 0.013144139196693659, 0.03555035609151087, 0.06055125628688163, 0.07286276803502152, 0.04296569649370448, 0.043756636310248606, 0.027373907336544608, 0.060331565252835714, 0.04675716905283832, 0.04399413505809442, 0.05039134460891928, 0.048811832187517036, 0.20198491882653008, 6.576297802309837, 31.967656189395537, 50.609797123939764, 48.96400982333768, 32.17310405546619, 24.676024952242454, 40.0396567006265, 41.03322052186535, 17.696486903775124, 4.247120849547848, 0.29707590418477214, 0.058021312203979304, 0.054735400218276255, 2.575121329676721, 3.447355454967868, 3.4963818951960537, 4.888962795657497, 4.786120701220728, 4.607919579552067, 3.268675804138184, 10.47120059690168, 25.3652108869245, 45.55823541456654, 53.66052250708304, 53.38630176359608, 54.19261947754891, 55.50052988913752, 49.522508267433416, 50.43383567563949, 50.82359375492219, 48.32520084996378, 52.00961259103591, 53.79296133595129, 50.5708283762778, 48.39418749655447, 49.336332967204434, 51.99422121047974, 50.387206539031006, 51.8896508216858, 50.3782517679276, 52.035994452814904, 49.00703037938764, 47.148960482689645, 44.991288185119636, 36.25028625611336, 37.5532191799533, 37.856528220638154, 40.739599735506125, 44.01156640821888, 48.688722195163855, 48.934646960227724, 46.51517606550648, 44.89829271070419, 41.04917672372634, 36.5418517205023, 37.87699907056747, 41.244138133141306, 45.3204103439085, 49.664866770467455, 52.143318345469815, 53.03698724316013, 50.73820375627088, 47.46704509181362, 37.15504369428081, 55.58108360536637, 49.866488364435014, 49.02148039110246, 43.126130565520256, 39.018781415877804, 37.32550990196967, 38.66572887666764, 37.43147273217478, 39.336261979995236, 37.74528980255127, 38.21580163894161, 36.96108641162996, 37.810581576439645, 37.75532322545206, 42.99808086887483, 50.93544798512613, 49.5747346262778, 51.6371129405114, 51.890282323283536, 51.94628984697404, 53.63993006367838, 52.108762264251716, 49.11720191278766, 48.774069047743275, 48.031987990102465, 50.46987441278274, 49.47985641417965, 50.50394412009947, 48.93487445769772, 51.96142235109883, 51.17821524220129, 47.506292327757805, 44.311521822406405, 44.993916173135084, 45.3718836076798, 49.17619436017929, 48.17936320458689, 47.7313579282453, 51.44489326784688, 52.95609620309646, 47.26577258879139, 31.203800093743112, 16.002931998622035, 9.999479689905721, 3.974937532217272, 4.071365570829761, 4.4763500459732555, 9.175381871961779, 5.708429275020476, 4.862583385359857, 4.32273434054467, 0.49316156295038044, 1.1371193826198578, 0.14077150593361548, 4.419077067605911, 21.38895323199611, 42.45330287564186, 30.329307663825254, 30.078334808349613, 44.3209865016322, 51.28434673432381, 41.98414033459079, 11.073200087393484, 0.27802256206350945, 0.0421574967162263, 0.05583824124187232, 0.039571195375174284, 0.02124932358011363, 0.07237176696259169, 0.05115143023431302, 0.07477584279953473, 0.03929088380368006, 0.04565536990881928, 0.011941166650954516, 0.08651886751214344, 0.02790622927639033, 0.007784262969864593, 0.03938657967674156, 0.08642510601109074, 0.046433749713844834, 0.10525871879391133, 0.09002079330985585, 0.07865165780869224, 0.028733994939454624, 0.06303018274446649, 0.014222749816854636, 0.014582987341489044, 0.007273149216592673, 0.0520722947323755, 0.037365727832600955, 0.022900972755685933, 0.009841451800668673, 0.049637065929991585, 0.03258164281085615, 0.0326622620735678, 0.01243841995845639, 0.07401435906367917, 0.055063228393273975, 0.016689227345669945, 0.05315426752091416, 0.04897472163241717, 0.06802322973887767, 0.03582216025660596, 0.04192654802013309, 0.07024108492318662, 0.007546286853480965, 0.03884942946775306, 0.018589744013884378, 0.020570035332873948, 0.0674431479626125, 0.015263513778336348, 0.282675841402623, 9.149100030622176, 36.7711534807759, 56.41753688935311, 53.8492081242223, 39.85353239120976, 30.864985758258452, 38.18146521045316, 44.53071171237577, 21.611000568636005, 3.9003818554262963, 0.36140351045516234, 0.2180613964916237, 0.9943972023264055, 2.85283764043162, 3.225289732217789, 6.714494180294776, 7.762764769215738, 7.941749874622592, 9.482262230688526, 5.626707673072816, 13.202674465794718, 30.82252217877296, 47.37893296826271, 56.00666469143283, 55.37295087691277, 56.88381256595735, 54.71070574175928, 52.4117967390245, 51.620113388184585, 52.30513964929889, 50.264412818416474, 54.45078988229075, 55.09201111332063, 54.43569267949751, 51.258380643783084, 52.08789133256482, 54.00017622978457, 51.95059268705307, 52.40846272437803, 49.84973592142905, 54.12055377037295, 50.021108196627715, 50.61940693086194, 46.72755279848653, 38.04093453191942, 39.574232178349654, 39.032380273265225, 42.259165163963075, 44.97680287207327, 49.55685254066221, 52.1602943635756, 49.24771093553113, 46.96779797154088, 43.07308835368003, 39.26222724299277, 38.495360728233095, 43.403379378780244, 48.80176098115983, 51.46548178888137, 52.99773216247559, 54.86760839339226, 52.395981742489724, 49.54593266210249, 39.28559672447943, 57.65573109349897, 53.1322733817562, 50.670735066936864, 44.61565063845727, 39.18035561038602, 39.242717373755674, 37.69980207566292, 39.20574903488159, 39.95549440383911, 39.67377408858269, 38.4945801765688, 39.33770148984848, 39.72369017139558, 40.09156142511676, 44.01973278291764, 52.43975539361277, 50.74906087690785, 53.952084049101806, 53.98535359290339, 51.93493850769536, 53.976438045501716, 53.27429063858525, 51.89709548027285, 50.83682390951341, 48.91115588526572, 51.46540726384809, 50.91144307967156, 52.97204063784692, 50.75722332923643, 53.57323408126832, 52.732732911263746, 49.61560572347334, 45.93658724138814, 47.72310526140275, 47.66843918831118, 50.60259957467356, 50.08724720247331, 51.95063583312496, 53.86379934126332, 56.33584568577429, 51.17036657948648, 34.50181522677022, 17.91586898988293, 11.858627257808564, 6.123081166898051, 5.204069345228134, 6.743303008617894, 8.68108086047634, 8.776432698772801, 6.0096570080326455, 5.402286321886125, 1.9536230016139247, 0.28154475854769834, 0.19440677707954762, 4.596840354704089, 24.411851359951882, 48.20088524972239, 37.560593235877256, 35.585342530281316, 50.690754844296364, 58.098947155860166, 49.202101615167436, 14.751591970843656, 0.4874292947351933, 0.04746541733883562, 0.015679102113109925, 0.04123363681437989, 0.03698161134736673, 0.07212826591585914, 0.03050251657353534, 0.0943217641343513, 0.010605857204345447, 0.021034185023557757, 0.012407269865845241, 0.06445951128919279, 0.004948430512506034, 0.00962932588487503, 0.07481207109747395, 0.027041157046633384, 0.047061551106913437, 0.026682957315877564, 0.037979651542921225, 0.07955878251983274, 0.07038166205729209, 0.017359929662498257, 0.09463327080612222, 0.13923241997197752, 0.10191520465718162, 0.16974666726685342, 0.1272524289426304, 0.08594979441935018, 0.20916028218644284, 0.12470612122166543, 0.22384994152572849, 0.1968740551702438, 0.11042115548926015, 0.10024275044880568, 0.12548736236508817, 0.08840420223291844, 0.21426834196092623, 0.1599704813692839, 0.14386035712255588, 0.0947599970705567, 0.09903288311174802, 0.15456061359615098, 0.11281890343994865, 0.19955796760416802, 0.2907551578696697, 0.10928303228631135, 0.1458633859311381, 0.08795856888736449, 0.3823046260062726, 10.22011007032087, 41.541920554253366, 62.76198241018481, 60.07316235573062, 44.4335546032075, 36.69113320689048, 50.767111624440844, 52.034421582375806, 24.224203209723196, 5.852437134711973, 0.6766771284803268, 0.5862832886557425, 1.6223390039897736, 6.807743628178874, 11.799666189378309, 10.104604113486506, 13.12179127047139, 14.101398318044602, 11.67680774965594, 6.579596515624754, 14.109092047137601, 30.456447370590706, 48.49086999893189, 57.00241327285767, 56.96400542413035, 57.15302052036409, 57.53402386942218, 54.02974305614349, 54.19239590244909, 53.60908846701346, 52.49648071104481, 57.40778238542619, 57.76088199307842, 56.44258514527352, 54.11500753894929, 54.58784534085182, 56.987700462341316, 55.1287401876142, 54.15560014786259, 48.42667256632159, 55.15082705405451, 51.51748849499611, 51.80017371331492, 50.142270211250555, 39.63779026462186, 41.933679042323945, 41.89489856843026, 44.59519940037882, 47.90938254325621, 51.21619163020965, 54.679138506612475, 50.372913422123084, 49.11501715260167, 45.26955681462442, 40.61901823166878, 40.40719455288303, 45.4118525597357, 50.537213663901056, 54.098259018313506, 55.90109017587478, 57.95822035881781, 52.330709580452215, 49.96415145935551, 43.42116340514153, 58.069870625772786, 56.52118552115656, 52.26551978818832, 47.82904063501666, 41.16314903382332, 40.99664442000851, 40.630353881466775, 41.64154875663019, 42.06057163976854, 41.967407503435695, 40.945967397382184, 41.19320223408361, 41.482641773839156, 41.48352430712792, 46.03053192938528, 55.90033315843152, 54.415566998143355, 55.74776472583894, 55.808353577890706, 53.04425147271926, 55.18660691476638, 55.11774970639137, 54.15127377356253, 53.017838231978885, 52.66236951274257, 55.38972293176959, 52.23238752734277, 55.877940347117764, 53.625636946770456, 56.6548442071484, 56.6183190961038, 52.36950574382659, 48.88803351309992, 50.491435681619954, 50.30364436487998, 54.314424760880016, 52.84474403627458, 53.28506931181877, 57.95318403551656, 58.39514101705244, 52.83668748794064, 35.79948825220908, 19.559863767316266, 13.719024100611287, 8.833688516770641, 9.845037344963322, 10.7186766593687, 18.908946437220422, 12.54589613406889, 13.858980151914782, 10.592973520678859, 3.122770497875829, 2.599776613135492, 0.4170726377877497, 5.862929474922919, 27.417726401359808, 53.10777425765992, 42.09358230713875, 45.352059948828916, 58.27051162719727, 66.195095739057, 54.90846772347727, 17.729576018548784, 0.8226838647838562, 0.1278096659769935, 0.13237181149663466, 0.12074409833838864, 0.158320082832248, 0.2435051529638229, 0.12451352671750131, 0.26087874005879125, 0.07979011809032771, 0.23731887040119018, 0.1509238410020067, 0.20901397471466374, 0.1326740331827633, 0.14779982637734185, 0.23507432471359932, 0.15168508725060573, 0.19675181818104562, 0.25266209467043804, 0.09114711109789149, 0.16792915431001496, 0.20063229866566198, 0.22776324121702105, 0.32094576366005406], [0.061576565382100885, 0.03511149113276794, 0.0365986401635793, 0.035608115290561994, 0.07638336339544866, 0.040168303455556595, 0.07230240536192734, 0.03929921884029623, 0.0699756661009404, 0.04374127624736678, 0.01751759630297461, 0.02349244817460497, 0.06708569133714323, 0.04422265142502804, 0.08622800690993186, 0.09889697911398065, 0.03618987862982097, 0.02562089323727114, 0.04968802609871473, 0.0464927155013767, 0.007145983888016593, 0.11533508858373089, 0.0653812223144116, 0.05842436638270175, 0.03379214983133059, 0.03160932018691975, 2.7527622878551488, 22.077631219740837, 49.32673492739278, 46.48178885059972, 34.29669880097912, 31.51258868555869, 34.122941724715695, 28.670137236195227, 28.748865089108868, 7.246411212028996, 0.6720268522058764, 0.13053441089728188, 0.903182790404366, 1.089664832238228, 1.8739476511555335, 5.5044974050214215, 4.7506212899761815, 4.994517209068422, 9.638577507388208, 4.835280747182908, 9.039448211269995, 23.731439767345307, 36.710160624596384, 54.59617253272764, 54.942513896572976, 55.59891077779955, 49.03098429402998, 48.26167414265294, 50.58224639584942, 50.55588022355111, 49.01079585475307, 51.09904612264326, 51.43991970246839, 53.87274234525619, 51.97415436467817, 52.574308380003906, 51.701016195358775, 51.82006405245874, 46.725666138433645, 49.828366848730276, 51.55479808007517, 49.95788351182015, 48.222803454245295, 45.32133602326917, 39.99214503072923, 37.43841140500961, 35.81644465846401, 39.15642522996472, 41.89816982515397, 46.52003195977981, 46.89937614625501, 46.60881088626, 42.97823367580291, 38.07253706839777, 37.08080107165922, 37.416081351618615, 38.96083231895201, 44.46883240053731, 48.16072410152805, 49.102512636492335, 49.838784663907944, 53.24551220863096, 50.95485979510892, 32.029129535921165, 51.25967894831012, 55.061695114258804, 48.4927095905427, 46.65493403711627, 40.91789107168875, 40.68683601194813, 38.99944020855812, 39.880337868967366, 40.388833938106416, 38.86991962309807, 38.453799293887236, 40.34638997047178, 38.46172248163531, 39.01855391840781, 39.36676625282534, 46.76587827744023, 49.63226795196534, 49.147957217308786, 49.71137823597078, 54.30848629243913, 49.203101819561375, 54.60726499557496, 52.71625895654002, 51.524023163703184, 52.12250232696534, 52.55288047175254, 52.03222505507931, 50.64355696401289, 55.19650305471113, 53.2008913255507, 50.298141279528224, 50.90925831948557, 50.928062162091656, 50.38060911240117, 51.2866295537641, 51.845943850855676, 51.24719012168146, 51.94386582220755, 52.613230059223795, 54.52118465977331, 44.62472308066584, 28.588822580152943, 12.95389715702303, 5.786763910324344, 2.61473800386152, 3.377898369104632, 4.568890035152435, 5.420807753839801, 6.149440965344829, 3.757546539268186, 4.175023273114236, 1.4478898745390678, 0.14211476450004887, 0.32156267894371865, 5.2057589061798595, 24.364871171212968, 42.6730065961038, 44.80037466172249, 40.269688021752145, 45.181644731952304, 52.885575909768384, 37.50317365892472, 8.302943783421671, 0.331011638045311, 0.03766555166352661, 0.03215273316468924, 0.028530133197144158, 0.04392009649065234, 0.017371352033449278, 0.046628581194747845, 0.044426852161245006, 0.07558864676543782, 0.05551559565168235, 0.036263250700768926, 0.03733939356020382, 0.0477981063417129, 0.1273434938141896, 0.03414166595546469, 0.06781428691840942, 0.052320794502813975, 0.07823241619212974, 0.0286675023380667, 0.07660394309148674, 0.09116877606439014, 0.0696494505410233, 0.020094520727833434, 0.024470763521329052, 0.05361347977492598, 0.07562760999726673, 0.020982531545263146, 0.06530880402292936, 0.07139621527805444, 0.10943696233293704, 0.036129078061710444, 0.04080476164216957, 0.05060905913612054, 0.08166778427098068, 0.036885616700014764, 0.03172221856432096, 0.028613596561274705, 0.029160334360635573, 0.015955879146443502, 0.05638564170728769, 0.02647271597637765, 0.020053220927835475, 0.024631381515533696, 0.021495542323757565, 0.0804298168288604, 0.022761165539944367, 0.02955237219500686, 0.03826756270662431, 0.04252016273958068, 3.770256244367169, 27.27687212728685, 55.814252822629875, 52.98778895408877, 37.28262270650556, 31.404099848962602, 43.84890571717293, 39.838890183356504, 30.62472881809358, 8.449309968179273, 0.738140607793485, 0.039714162703603506, 0.12703591717347024, 2.266347937045559, 4.288623938637396, 7.495956815058186, 9.14883723182063, 8.13241824988396, 6.961889343876993, 5.862650006048142, 11.152943834181755, 25.865099314720403, 39.74533773237659, 54.87110714758597, 56.17620129739085, 55.22166113699637, 51.25828650689895, 49.582198896715724, 51.9863490135439, 51.21843130357804, 50.70204342565229, 53.19112070145146, 52.97504909576909, 54.43714787883144, 53.77394176298573, 54.192948956643384, 53.7449005342299, 53.982909956286036, 46.63523981648107, 49.62403489697365, 52.45401713155931, 52.222044237198375, 51.09388428349649, 47.400623675315614, 41.3264294593565, 38.15149830233666, 38.39614045235419, 40.54897254513156, 44.5079384311553, 47.76853415273851, 48.17485247888873, 48.27657914930775, 44.26450437115085, 41.14987965553038, 39.34566390129828, 39.08596377218924, 40.592381415828584, 46.12534738356068, 50.50727813474594, 52.0453179267145, 52.57359450863254, 54.07456005773237, 52.22908096928751, 35.88124613608084, 53.74866600959532, 54.84954195637857, 49.63770435702417, 48.90653533320273, 42.140070238421046, 41.77332078256915, 40.0484977229949, 39.940793360433275, 41.396588894628714, 40.17329969713765, 40.21981900738132, 41.592272020155384, 39.661979521474535, 39.65824934744066, 41.581450200849964, 49.24839342794111, 51.83092117309571, 52.212332448651715, 52.14594633348527, 54.0334104722546, 50.408175529972205, 57.04581822118452, 54.05681525507281, 53.138376589744325, 52.48550591930267, 55.27513480955555, 54.41713202384211, 54.248458339322, 57.3151046229947, 54.12278167663082, 52.271607306695756, 53.937896836188536, 53.18837504233084, 51.660784444501324, 53.424482114853404, 53.24793623339746, 54.031496355610514, 53.726045700811575, 55.57567465689875, 54.79253422829413, 49.56764690337643, 30.488524513859904, 16.015801295157402, 7.84220943527837, 3.8297000094767544, 5.3774204561787275, 8.041998301782916, 8.448777506428382, 9.470456877062398, 7.354310222210423, 2.8109317729550027, 1.3152973377896895, 0.23807302267561037, 0.47235964046370604, 6.12245652944811, 28.44276135967624, 45.282869338989265, 40.9945067282646, 43.80751294474448, 51.49149102549399, 60.08333306158743, 44.32871749324184, 10.528306384240429, 0.3723582306936864, 0.05602111409027731, 0.04860747823371522, 0.01746086366174202, 0.07271981602835079, 0.04541528561422902, 0.05684473521767124, 0.04392587662404103, 0.1019008098650844, 0.05241711090709414, 0.04343197590881779, 0.027057225740845167, 0.028837263591647632, 0.06505725905299187, 0.06127813966163705, 0.042478625452326196, 0.030958013301114404, 0.01938417910658304, 0.06817311484126315, 0.02917941952604921, 0.05298626060867983, 0.04486974291203003, 0.03368041590757428, 0.12460536533786405, 0.31034307614449536, 0.20356981684604, 0.13179928334730287, 0.15383063905662106, 0.2051808384637679, 0.25147543979748604, 0.0902063244833581, 0.1823196563148691, 0.16904430253611458, 0.16990302581219904, 0.07981273300585248, 0.20943434248047493, 0.12663077923559374, 0.15376287091883922, 0.23197718445331822, 0.1439793305771966, 0.18059203611506572, 0.16250001176470713, 0.18246766450184007, 0.08973328051187339, 0.2099773762447219, 0.21328964931589944, 0.247076608901543, 0.13682900297064937, 0.14792315121139252, 4.406928996885977, 31.182036822842015, 63.3275568100714, 58.56707419118574, 44.991609819473766, 42.72715099396245, 45.219260261904815, 40.294324428804465, 37.325403997975016, 10.187319055680307, 1.3035021578111958, 0.3215079189788911, 1.8087328537817926, 2.726513541513874, 7.661470049811949, 16.906105779832412, 13.170418854682678, 14.199894916626716, 17.749813487452847, 11.50291927399174, 14.122483018905887, 27.81534294928274, 39.87375220944805, 55.261834052301225, 56.147536616171564, 56.73025177371118, 52.217553123351074, 52.12917427862845, 52.243013228139574, 51.61914456275202, 51.952432278663885, 53.32775254403391, 52.93903389284688, 56.53008145670737, 53.911424759895574, 54.72739542684248, 53.8687179934594, 55.32314854283487, 47.262881801974395, 50.974683453959805, 55.73781759508195, 53.79287896617767, 53.85718622515279, 49.69058182931716, 44.191520829354566, 41.79943592317643, 40.59812768813103, 43.481607129496915, 46.85675567196262, 49.357545145096324, 50.76430712976764, 49.42880676638696, 46.76946332377773, 41.96980799398115, 40.57694296683035, 39.807103295480054, 43.34573622672789, 50.629193244441865, 52.51359793447679, 54.233490574744444, 53.98192544137278, 57.72915001838439, 53.76910548056326, 39.17415434314359, 53.59190456328854, 58.472466622629476, 52.99290764716364, 51.4872548657079, 45.11643532783755, 42.89524809006722, 42.3763342057505, 42.90131207435362, 45.01886636980119, 43.61145327168126, 41.107306249680065, 44.130798616716945, 41.72251039935697, 42.17083338768252, 42.3299757126839, 50.35191697459067, 54.94657354970133, 55.20843490477532, 55.005624832645545, 57.48491971723495, 51.40210413163709, 59.466242251857636, 57.34553437079153, 56.72602738103559, 54.86337223360616, 57.03731452265094, 56.9211535299978, 56.09479250446443, 59.418761960921756, 56.80165852269819, 56.311323027456964, 58.506555941797075, 55.36802830234651, 55.16181753527734, 57.38748804215462, 57.120131446469216, 54.83299739899174, 57.501683927351436, 58.432478058722715, 58.798207698329804, 50.75217523882466, 32.07005358511402, 16.155409236108106, 9.018515502252887, 7.296959777032176, 9.325919497397638, 12.404208356334317, 11.493815452821794, 17.108537343240556, 10.495451631084567, 10.772694560789294, 3.9038752163610155, 0.6184945892422431, 0.8661974137348514, 7.075400285182461, 31.56060830239327, 53.38171651286464, 56.26514496341829, 53.67568639016921, 57.98896389622843, 68.64171335774084, 49.786989765782515, 12.806411135581232, 0.7607477398649339, 0.16629354126991766, 0.21576144732534888, 0.12499895833072164, 0.19786489796974968, 0.09827130744534154, 0.13328897195958322, 0.15490760546057455, 0.2779725212002954, 0.12008624331605051, 0.11536972341878761, 0.12791170888850767, 0.20705928605410362, 0.21443504269324967, 0.11571686850079607, 0.11712459336605766, 0.07291530634486869, 0.113323992869306, 0.10478989596688941, 0.14832367729996482, 0.2843730632335909, 0.2217393539725773, 0.09288719554822292], [0.06804077315234369, 0.03282309840283087, 0.058890967554743254, 0.057581504957089504, 0.012222812173046894, 0.09733402951350136, 0.023800359978791208, 0.062297860145448684, 0.020575374965706182, 0.016880812528993816, 0.05449023676074801, 0.06497690409061409, 0.011794651377825968, 0.03468597908654521, 0.04736913540851205, 0.11765337023403376, 0.05308229739086763, 0.01680773348667689, 0.06782456015747401, 0.06550823203137805, 0.08176691604838257, 0.09074224895166774, 0.04896260595189468, 0.029042067622104963, 0.02027888361725115, 0.02666002830430385, 1.5015525563109307, 13.965113605222395, 42.16150991378292, 46.52600572955224, 37.864694595336914, 28.14205873397089, 26.318729269889097, 45.30515232393819, 30.460542325050604, 10.41962339032081, 1.920035255532111, 0.05603852343835658, 0.36433560473303644, 2.769635588892045, 2.0409564121115595, 4.288058136740039, 6.031590902036236, 6.765432040537558, 5.610377865452921, 3.8013407828346377, 7.765108875689968, 20.12630108864077, 36.728489860411614, 51.98478791021532, 54.63960101527553, 50.47866052196872, 53.3485685625384, 53.70531597445088, 52.16019238195112, 53.85344820637857, 51.55094631256596, 53.59560335836103, 53.24571617187993, 53.02412186899493, 50.658960111679576, 50.2261265631645, 49.97485168518559, 47.85042147482596, 49.84476235605056, 49.96413184750465, 51.66301627312937, 52.62820174617153, 48.17375029287031, 48.838996041205625, 46.68096288557976, 41.50721934533889, 37.34353319291146, 36.24276707249303, 38.1544126233747, 45.655086578861365, 43.676486169138265, 41.963061517284764, 40.804616943482436, 36.969162571814756, 36.34780814570766, 35.06817802306145, 37.32960093405939, 40.33340300283125, 45.25496559758341, 46.97549758418914, 48.97570633119153, 50.23430470497378, 52.02125418570734, 34.90812178580992, 47.35778354829358, 53.09737997670328, 49.35071629862632, 48.115012799539876, 42.72930045281687, 40.899255891000074, 42.87584412482477, 45.77730763343073, 44.256506658369496, 42.92011983932988, 38.616891445652136, 40.29317909671415, 41.79227759761196, 37.66279451308712, 37.74639198856969, 42.808861809392134, 49.72689513237246, 49.30828017573203, 48.933274130667414, 51.24580552501064, 50.8636607662324, 51.92543460476784, 52.59769355097125, 51.895612824347715, 53.97592813737931, 51.161933483616004, 48.830813977026175, 52.13248475905388, 53.760578247808645, 55.42762871711485, 55.72853726725425, 55.595698356628425, 50.7366269634616, 53.480109168637185, 54.11718445439493, 53.40687851752005, 55.44753866810953, 53.286814766545454, 57.98116622432586, 53.542561146520804, 42.658623264681914, 22.069394242378976, 11.261691547209217, 5.992161766175301, 3.417777106646569, 3.274068327680711, 6.9641579447254065, 7.494122616706356, 8.515500945429649, 5.5007878234309535, 3.230131653047377, 1.2429820698115135, 0.15050898906925034, 0.5683984451236264, 6.647079423550637, 29.689880917149207, 44.37557412732033, 43.233297563368275, 35.51885835586056, 52.348913300421934, 53.07062548975791, 35.52715024640484, 6.91958167860585, 0.08794382935570133, 0.010877086803497327, 0.04103232806007709, 0.0688834851908107, 0.06675311724745459, 0.011070804584080414, 0.033272137009208246, 0.05170406691069084, 0.014487399678346852, 0.021398327681386185, 0.0739744152393072, 0.03462604419778913, 0.06501227437007813, 0.02906565929973318, 0.025218712398782376, 0.01728438381706515, 0.06519091075226184, 0.01622026853804146, 0.008002474017801785, 0.05073270955753904, 0.11649607951121947, 0.05621524077028998, 0.09932114667589627, 0.020341168480714964, 0.02207182047347869, 0.05715799623078877, 0.030026004138973453, 0.04680378933347041, 0.020466247656112237, 0.04089944244873139, 0.07055338832639879, 0.011278576247634427, 0.06716880421604841, 0.041568505337401744, 0.016101737499176975, 0.013778767390777508, 0.033077991176997466, 0.03132790736403437, 0.038316975377740405, 0.02614234821991094, 0.02606407127102777, 0.04653236438189784, 0.007852080903361522, 0.02471092633993155, 0.0753319766672869, 0.012365542971829494, 0.08920132437901152, 0.06494691174837851, 0.025663627536907315, 2.083494148908123, 18.68028598447, 48.43537238336379, 52.64525621168075, 43.24687288653466, 36.25358496942828, 26.8500143097293, 40.38305236447243, 37.760159507874526, 11.780223000434138, 2.0404878114500353, 0.060111464361750314, 0.2543952460250547, 1.724203937957364, 3.2065746332368548, 7.061263572785163, 10.99718749523163, 8.069401450695532, 9.4878976960336, 7.434127513439425, 9.798134623035308, 25.03708697134449, 39.0991311688577, 53.63033202386672, 55.175741949389064, 51.21428143593573, 54.37908503317065, 54.45768148668351, 53.243260768152055, 54.478979956719186, 54.48400451290993, 53.82872942955264, 53.56755056688863, 52.97915189496933, 52.14293003082276, 49.36328357265842, 50.27684673186272, 47.874602886938284, 49.545167799918886, 49.622575775269546, 52.11439086544899, 54.818943546664336, 52.342225659278135, 50.96054330948861, 48.30801302386869, 43.48560794707268, 39.45248965294131, 37.47886280859671, 39.96537093193301, 47.066645622253425, 45.73059612704862, 44.39358957352177, 41.804727200538885, 38.316688922143754, 37.11654563103953, 36.583420999588505, 38.57944065524686, 41.68773074303904, 47.01715315541914, 49.20059150265109, 50.03101218131281, 51.751489254736136, 53.710599407073, 38.44974748549923, 50.348669252087994, 53.185978474155554, 52.03013050940729, 49.24425924977949, 43.97977167560209, 41.70344768031951, 43.690638080719985, 46.39557515421222, 44.23445901563091, 44.32124930043375, 39.10149635807161, 43.213293475489465, 42.9924601124179, 39.958016487859915, 39.737022307611284, 44.131457574905895, 50.89193321043446, 51.95981810169836, 51.28229533472369, 54.54305187348397, 51.57772433373236, 53.16263252688993, 53.78735234660488, 53.59731743412634, 55.29103609823412, 52.83401635385329, 50.44523800573042, 52.322276484581735, 53.93764188212734, 56.146877657982614, 55.89764241249331, 56.89924709258541, 54.31955129869523, 56.14073914866294, 56.35616356326688, 57.12574043581563, 58.45443548694734, 55.49936102282617, 60.69921578130415, 55.77902209374213, 44.03976040501749, 26.013202128871797, 12.423386785291857, 5.670301875760479, 5.9010328496656115, 6.603403831681898, 7.01605482447532, 10.65741414023984, 7.876208539932006, 6.697406864935353, 1.9800152821886925, 0.7887981411430144, 0.03252937646222211, 0.8210666225321832, 7.180704647494901, 31.13288756339781, 50.01167097399312, 54.07855303056779, 44.908357512566354, 58.71386889488467, 59.32560959169942, 42.82445715319726, 9.670861555683999, 0.14469464219385578, 0.0773363997558913, 0.03934015091809054, 0.037338968381405845, 0.06715421790197011, 0.049068866177432, 0.01679470233108488, 0.053752007623833996, 0.06469328301928698, 0.07090662380740528, 0.060764152121039174, 0.018326654098927975, 0.041403547455106056, 0.02588323047084193, 0.04305817862792362, 0.01702610493427323, 0.023742474375232577, 0.049254876155886924, 0.02481546095241943, 0.05014876669813549, 0.0972522649493429, 0.03740942931824154, 0.06055699811587411, 0.2724245737396902, 0.17641661177960136, 0.15378936223926085, 0.2296099114802576, 0.09245277772988043, 0.15995859168469906, 0.12784888201783742, 0.11087325461689504, 0.10685611936834552, 0.15988376021625536, 0.17348660126088128, 0.12344694080492183, 0.06347654770398814, 0.09400648064911367, 0.1169990162335096, 0.24805709419231264, 0.14681453005440775, 0.11352888308465482, 0.1512073548210244, 0.21479867398738864, 0.1790162851853717, 0.19090422308973728, 0.18861745063576008, 0.25484621134256163, 0.17980670406212731, 0.1508459911471413, 2.5115796683296083, 21.386833190917972, 54.42409423089797, 59.91727952034243, 51.19987457029281, 39.34798202207012, 36.708195517140055, 56.36918583223897, 39.65890830562961, 14.38169873529865, 2.8614185606279685, 0.17153840902591908, 1.22227918717169, 5.963978065598396, 7.44229143665683, 13.181256363468787, 16.275684795072003, 15.728705371579817, 15.01983698337309, 8.300253037483461, 10.298762417608692, 26.219257962319162, 38.98899493678924, 56.842906167430264, 56.929139475668634, 52.13221411551199, 56.45268524846723, 56.73320139608076, 55.968951102226015, 57.01354888177688, 53.63236381161598, 54.63539623445081, 54.05900785999914, 53.79612276631018, 52.01339375588202, 50.85694174612723, 50.35339570814564, 48.23191904252576, 50.23658752441407, 50.50716046364077, 52.65390111554054, 56.241222427737334, 54.00645986680062, 53.23156818266838, 50.26417355383597, 45.67230186154766, 41.60849886555826, 41.18437297882573, 42.79582385093936, 49.43771054667812, 47.32437279916579, 45.76314787710867, 44.95095837500788, 39.51190179394138, 38.7273806910361, 38.09612620261408, 40.67706538784889, 43.79747167710335, 48.92612757221345, 51.07957939947806, 52.68906516413535, 53.69852635168261, 55.54438591003419, 42.45253409108808, 51.14109785326066, 54.178718597658225, 54.33005148364652, 51.72307560520788, 46.70927847585371, 43.88385403540827, 46.55513325045186, 49.92587304884388, 47.82729125791981, 47.35033496733635, 41.404876862802816, 44.62064381568663, 45.00611474437099, 41.73830578404088, 41.582395492061494, 45.56191459778817, 54.472715931554, 54.45299425432759, 53.98734615695093, 56.38682865327405, 52.32597527965423, 52.985286481918834, 53.239495292786636, 55.02381678550474, 56.80375699074038, 56.41673280346779, 52.72438610753706, 54.55750188519878, 55.47749773148568, 58.114456207521506, 60.09799880366172, 59.42231562829787, 56.187219235204886, 57.80322790145875, 58.35250485327936, 58.303534061678, 60.49713134765626, 57.92548425735966, 63.49212769539126, 56.81459449952649, 46.84121916371007, 25.582547456987445, 13.959179059151682, 9.675052608213118, 9.630471929427117, 12.701738765162807, 14.560602941820699, 17.584903317113078, 18.69500271735653, 16.471103160612046, 9.586598257864676, 2.683518235721896, 0.6711400901117633, 1.2119779399325772, 9.353492779116477, 36.89734397395965, 56.49403487482379, 52.90193219338694, 49.66039919084119, 66.92390349603468, 68.15940303187217, 48.614295221144154, 10.293053407822887, 0.1937277320652239, 0.130015769372544, 0.1703035212572544, 0.16781938923222406, 0.14440795677083154, 0.14470170552451767, 0.1734889148464126, 0.13709921750330156, 0.15676205917712183, 0.12824525590986013, 0.22985029454913833, 0.08339525891407844, 0.12312192034216658, 0.15972522598120475, 0.12071328628207408, 0.17089426697742555, 0.1768775822053994, 0.10905227894263883, 0.09659299266434486, 0.1057648117984495, 0.27375211218191736, 0.10404886677861215, 0.24642393263357304], [0.04108497745267326, 0.059843927306393464, 0.036753286502414176, 0.03139948678923951, 0.03094145239541127, 0.02695896155801752, 0.03830999631675021, 0.020832043148637302, 0.06852109495910906, 0.04856518634985532, 0.009746097794343388, 0.031173029283602393, 0.010900765623626931, 0.027193047384160663, 0.09943443575813886, 0.004793651544699265, 0.045096642833443425, 0.017795672812949748, 0.028168627796995065, 0.02900400837402671, 0.027322223214733026, 0.010357615988581412, 0.044611858564519116, 0.009275845255732778, 0.04076713906420816, 0.07057721366084392, 0.09751952238260739, 8.29246517150633, 36.31968867394232, 49.17235435978059, 44.32263389710457, 25.26885590245647, 34.179737644810835, 41.861958503723145, 31.35630772959802, 18.004440030744, 2.781745416502799, 0.32300454834776543, 0.06976974166689381, 0.7355553981277251, 4.28677159932352, 6.04572908532235, 9.355861890700556, 5.389853879328697, 4.0624041807266975, 5.925306437476989, 8.65983534243799, 17.676916237800352, 26.03067824917455, 37.39625769276773, 45.61321527727189, 55.10709654900336, 54.522926192129816, 54.907196875541445, 51.500630147995494, 50.371948519060695, 50.518405898924804, 51.653704566340295, 51.84377478015039, 54.11798461791008, 53.500858506848736, 54.14825747090002, 51.72568005900229, 50.817831793139064, 48.71930099302723, 49.511953169299716, 48.96375486927648, 53.528738714033565, 52.13860757889287, 52.0246038898345, 48.90994387288248, 46.62942294151553, 41.15805387496948, 37.972371501307336, 36.13870659182149, 37.55470968061878, 39.62485821016374, 38.883800891137895, 37.50034563003048, 37.10876757098783, 36.473347525442804, 37.84352556351693, 38.57503583354335, 38.05686719955937, 41.200850855919626, 43.85069431797151, 49.02209620321951, 50.34402516580398, 54.79253422829413, 38.2315734894045, 47.23133810104863, 53.68875964995354, 50.859585423623365, 48.53366305751186, 41.873313765372004, 40.73539887705157, 46.13419232829925, 49.37828663856753, 51.22944139665174, 49.316736805823545, 41.85124258841238, 40.81083390020555, 39.65333853998492, 42.05352314056889, 39.90715903620566, 39.43112058024253, 40.83736088968093, 45.91586535976779, 47.89785861968995, 47.76457648123465, 51.732893297749186, 51.23146926203082, 47.31832450436008, 49.9976759572183, 49.34462093537854, 50.73388522671115, 52.4729347229004, 53.31734257359659, 54.2869681696738, 54.18475904772359, 53.9008657393917, 54.040961034836315, 55.045487880706794, 54.56628799438477, 52.29838532786216, 52.8326827479947, 56.55997776216077, 55.26516022220735, 57.589882343046135, 51.44106111218853, 35.11267731266637, 22.359437827141058, 9.12658856761071, 2.8471690800882157, 2.704623038730314, 3.265018439100635, 5.06314839086225, 7.5379266661982385, 5.754200883450047, 3.4003318750089218, 0.2956314913688168, 0.28286963100394896, 0.10177633589914731, 0.9275904129589758, 7.634040424900671, 29.68238526774991, 36.37592369510282, 29.397601581388905, 33.36187639544087, 44.25211360377651, 52.60470282646918, 25.04807549138223, 3.3685758757975797, 0.026657913901632833, 0.009751172169231841, 0.0061614273187343875, 0.03618324813883632, 0.0008489458395483634, 0.016619992149513096, 0.06635576276288879, 0.04101238679140806, 0.032376480634294214, 0.0190483299910181, 0.032989335651960106, 0.04026620949227964, 0.06980209355993618, 0.08774111483005748, 0.0495224361938815, 0.05201477685102052, 0.02698972190339719, 0.028042349693996292, 0.01221250829046532, 0.026138414358419758, 0.04258196688287201, 0.031269498905467416, 0.0396958876761698, 0.08154022297070873, 0.04838343198981978, 0.060844085735058596, 0.011857075094726059, 0.047550974038219264, 0.007783537101556337, 0.015422669502215521, 0.023651564636478023, 0.020011576388271588, 0.012426671042527645, 0.0390563651378597, 0.0710137612036159, 0.016908313170255675, 0.04282026236215907, 0.011281908730105048, 0.06595864576557953, 0.008214291583205904, 0.022431263181891654, 0.021849346625047828, 0.030017134756030097, 0.03598845879276914, 0.015350707033048234, 0.04048815665526256, 0.030769526943444248, 0.058348596456550786, 0.03882327905645774, 0.3849048816388653, 10.633673014179355, 42.49989278854863, 54.22023688593219, 49.170459854987364, 29.271079647925596, 37.386130132982814, 51.465795578495154, 34.66783738905384, 19.913057511852635, 3.0665940671197833, 0.38011146949664243, 0.07687113157683804, 0.9629147271475486, 2.7836965505153906, 6.883514013982589, 8.326464276159964, 7.529704888020793, 8.47561240196228, 6.763194328354252, 8.544722603213403, 17.556134693084225, 30.4740450843688, 43.79601255539925, 50.92302191642023, 57.14613676071168, 57.387393905270486, 56.90430302773753, 53.77205510293284, 54.05208095427483, 52.93766106328657, 54.32892968577724, 52.673720852021255, 55.2361503724129, 55.24927462300947, 52.10553807597007, 53.8755036938575, 51.86256293327578, 48.3737244913655, 49.680517027455, 50.43471428655809, 53.79670719946585, 54.825576274625725, 53.990970426990145, 51.363602146025634, 48.94873611388668, 43.083164922652706, 39.06644213584162, 37.683077089248165, 40.38080484636369, 41.53337763201806, 41.119324391888036, 38.97734941974763, 38.32069366208969, 39.11053349894863, 39.348064391843735, 39.59552280364498, 40.81862764973795, 43.04010122053085, 45.962121871209916, 51.00923953517791, 52.21829052894346, 55.204281114762836, 42.78460194987636, 47.91383835577196, 55.3918606235135, 52.95063626381659, 50.238113326411096, 42.90615227914626, 41.878910987607895, 46.87265303827102, 50.67224125708304, 53.789031121038626, 50.336792315206225, 42.345688727594194, 42.30404492347471, 42.770991325378425, 43.603000563959924, 41.14489432304136, 40.44910507817423, 43.71039898164811, 50.1738884372096, 50.78781389421033, 50.83478035465364, 54.32501516034527, 52.519120631679414, 49.80357746924124, 51.54724751749347, 50.71349674655546, 53.68595907765051, 54.59811410596294, 54.62429200449298, 56.06562183749292, 54.41422162517425, 56.13989976144607, 56.92445616568289, 55.468837138145204, 55.276739058956025, 54.93916027007565, 53.62808842812815, 58.0458539532077, 55.33130707279329, 61.01322112544891, 52.33196866127753, 39.44186787451468, 24.59733828421562, 10.93836174857232, 5.114262757762786, 5.4856759117495635, 6.2546364818849876, 8.135167341078482, 9.293824703462663, 10.765784325138217, 9.721549364828295, 3.1441248616864605, 0.30754106359616407, 0.2051712776864729, 1.028475857550098, 8.970609634153305, 33.485815448145715, 40.05530303524387, 32.261749621360536, 37.991461676936, 52.199388627083074, 59.39223104907621, 31.795652412599136, 4.493368719854663, 0.056994283241370035, 0.031495975563302636, 0.04495867422872013, 0.07786008980005019, 0.07820014856875905, 0.04307197970187953, 0.05162113023200824, 0.024248527160154718, 0.044073578375842304, 0.031965466802038496, 0.028871873528846813, 0.05032638418337992, 0.015326488120932014, 0.03336722384236994, 0.011767738709045995, 0.07295745650246259, 0.08225151262576542, 0.029689837096919938, 0.0055293248207759, 0.06022799399591262, 0.08394777684682801, 0.027366924445114793, 0.058450172054431135, 0.18024201054246197, 0.3172354466251789, 0.10339819000012453, 0.16321993523067044, 0.13291270021469365, 0.12230291106407681, 0.08589042260521844, 0.1371228283331279, 0.1458332173886799, 0.1634632753989389, 0.1201262943927319, 0.18335831832260857, 0.10469575908275382, 0.1436136308456621, 0.12502755639293503, 0.11199553512156972, 0.12737817461452178, 0.12220528081900651, 0.12243408829935136, 0.12917812883613572, 0.12422239798451624, 0.09316532376913295, 0.14031127095222473, 0.1478340551857987, 0.12620751565742877, 0.16600630426358792, 0.4232804320992962, 12.866701887499902, 47.56705376409715, 63.70963096618653, 55.92578934084985, 36.3724837764617, 46.50298141664075, 52.93589599670903, 42.23403846063922, 24.040042046577703, 4.446740563838713, 0.8919177432694744, 0.4374081659461222, 2.6670521257385134, 9.22988026372848, 13.109703506192854, 20.95081860019315, 11.556743018088802, 14.947496710285066, 14.707468248182728, 13.972063064575197, 20.919149383421868, 34.01650428771973, 45.77688401745212, 52.85165133014802, 57.981778114072746, 56.8289307625063, 58.939295353428015, 53.913813483330514, 56.04682976199735, 54.235145814957164, 54.96023124264133, 55.12381369067777, 58.07795070832776, 57.00861061772993, 55.90783665257116, 55.367985156274614, 52.52156819066694, 49.79461093102732, 50.80696290539157, 49.7793686005377, 55.61920119870094, 54.98770352332823, 55.99683130941084, 53.53531652881254, 50.187675568365286, 45.74741132797734, 42.40484983690324, 39.56253959286598, 41.57257779952019, 44.186017744002804, 43.44068111911897, 40.843899480758175, 41.15155450759396, 40.84748452709567, 40.39734155901017, 42.46717629894134, 42.84239022962509, 45.87120917535598, 48.05482795161586, 54.79254991777482, 54.951460822936035, 58.40294261132517, 46.575141260700846, 49.04688558270855, 56.87113154319025, 55.345713938436205, 50.34167958844093, 45.183817725027765, 44.462509539819536, 49.384358467594275, 52.59475569571219, 54.841140239469475, 52.94714535436323, 44.2942084804658, 43.843732110915646, 42.80000901991322, 45.89894425484442, 44.19627081963324, 43.75345483902962, 44.72120554216447, 50.260670877272084, 52.47864961624146, 52.27019133106355, 56.758912532560295, 53.06859370200865, 50.71357127158873, 53.194486095059304, 52.13016663828204, 54.874786330807595, 54.503600674290816, 54.638275254157286, 59.71891349361789, 54.66010324416622, 57.028296993624785, 58.08520709314654, 57.54029573932771, 57.45295240033058, 56.03100299835206, 55.35296247851465, 58.78997464333811, 56.57213318732477, 60.15620677701889, 54.05933341672344, 38.59196478320707, 26.826485972250662, 11.812496262211955, 7.0122050181511915, 9.151586813311424, 10.795848311916476, 13.845301866531374, 16.1921275238837, 16.387655715788565, 13.095919316814793, 3.9782936101959603, 1.6890519016212033, 0.48470431998852764, 1.4693464651223154, 10.502758026123047, 37.49507004214872, 48.59590322740617, 41.01194166368054, 46.75040060474027, 60.49361690398186, 69.24835497333159, 37.57536880431637, 6.324561555539408, 0.18306300674955692, 0.07485484178628653, 0.1723861925664448, 0.12922859870858733, 0.18419882402785365, 0.1740583480005303, 0.1548335707235721, 0.09602750486303722, 0.09788293917212756, 0.10884758024927109, 0.15857655374753862, 0.09144471327383673, 0.1765700745125932, 0.13276607098598636, 0.17094962449083406, 0.22898772551167398, 0.1331468779713877, 0.14495161872717643, 0.07790217100973092, 0.18402862993459548, 0.1666756046395148, 0.20924481232800793, 0.10251941820306164], [0.06824058420475453, 0.0620476060336636, 0.03450939581999856, 0.05179813101647362, 0.014981591506981322, 0.02508179716495497, 0.03759765712123725, 0.10591740885208692, 0.07900219666020525, 0.0343658845691431, 0.0744394229484662, 0.04177752476666243, 0.028487557860752268, 0.028861098502191807, 0.06108168790477419, 0.06592270092017229, 0.07607058501772343, 0.11470989955048408, 0.023940253379424254, 0.02879495064036981, 0.014126154748092016, 0.07709491352039961, 0.05968054756522179, 0.016869386327603174, 0.028779741879853032, 0.0028308981329187633, 0.06227496943827118, 4.474265796522941, 25.301654761837376, 43.41123196386522, 47.947731556430945, 38.544053031552224, 20.09421806181631, 28.568418410516557, 44.27209023506411, 20.118405357483898, 6.78439473913562, 0.21849227498375604, 0.14820873346780578, 0.5564800169198745, 1.3952231070687695, 4.186198105735164, 6.9143923828678755, 7.546762295307652, 9.345551940702624, 4.274746592967741, 5.155957062398234, 14.951764249032545, 31.349035655298543, 45.78766269068564, 57.329429118864006, 54.97635610641972, 53.964855286382864, 51.14758545352567, 48.12204953162901, 48.4402165105266, 48.071588239362164, 49.01200786713631, 48.79129217516992, 51.03813955860754, 50.39693793942852, 50.05969647438296, 51.56889507847448, 52.291913417077836, 50.780981125370154, 49.96683436055338, 47.624367437055035, 51.80359402010518, 48.82156502815985, 50.02220253790579, 49.43940893296273, 50.78726084001603, 44.37844530228646, 37.005679838119015, 36.04257714363837, 36.69543604696951, 38.26310542321975, 36.296425096450314, 37.24168100664693, 36.59274839585827, 37.515540892078036, 37.157907024506606, 37.2592963710908, 38.11559292577928, 40.30995507394114, 40.89340763707315, 48.066822559602805, 49.03470662332351, 53.7938517139804, 39.59673481602823, 47.48478204973283, 54.57421118213285, 49.98560682419808, 49.24104682860836, 40.065642403018096, 39.89345035245342, 41.12352132797241, 48.31930160522462, 47.597624717220185, 46.66224141274729, 43.00906350535732, 44.08932739688505, 43.4332952960845, 42.18587175492318, 39.26672620158042, 37.93920786150041, 39.39798831939697, 40.79407361245925, 46.318273082856216, 48.518644302122055, 50.62777334643949, 51.39286302751111, 48.51383939866097, 53.405156597014404, 54.62805355748823, 51.3444649019549, 51.77298384328043, 52.086212558131066, 50.01220833870673, 52.10576557344007, 52.66280097346152, 53.49428461443994, 53.18772000651206, 53.584969812823886, 55.33090306866554, 56.73110685040874, 57.96742616161224, 56.5988092268667, 56.41978048509168, 48.98264892639653, 32.50431291518673, 21.095587399698076, 9.98083862566179, 3.9823307096958165, 3.8570276527635516, 5.259227675776328, 4.604881703853607, 8.684747295994914, 6.370034573539612, 7.00452599794634, 1.7042604016680873, 0.17255804140961942, 0.05529577438268931, 1.1093069588945759, 9.198246348288752, 27.234561520238078, 35.13563886765511, 44.57057868280719, 37.784176180439616, 48.65860231461064, 53.91276621049451, 22.156121769259055, 1.8845571721753769, 0.10085110853035605, 0.06693175362963831, 0.04826768376534024, 0.09341204238514747, 0.009302132605244557, 0.03990083151767331, 0.02046193649631835, 0.037005386886096774, 0.031479246118256164, 0.011071638662307974, 0.02176360797978217, 0.027466881682255098, 0.023383887770074992, 0.08789050963617141, 0.01898289076052606, 0.035867370935457374, 0.053429262442213875, 0.028001660849117947, 0.015472034292836345, 0.00799813843895531, 0.01833338609656259, 0.030384671183363087, 0.015260964620768305, 0.06654485624523894, 0.03500341910928969, 0.016685896778419133, 0.035718137007807536, 0.05632414399916607, 0.014189353171405534, 0.01435328066544307, 0.05425633862614632, 0.04177079468424763, 0.014171670904503235, 0.06186637261341657, 0.016993592162766767, 0.0138427127498172, 0.051002380167765, 0.016175979079919, 0.022841143204019438, 0.01818572647959715, 0.07610401709473903, 0.09126907229543695, 0.04653214604683942, 0.02016074902888748, 0.016169777598171946, 0.0192487251854712, 0.03302995363370546, 0.017384446391295043, 0.02341769139973387, 0.017475595532525933, 5.282846227768929, 31.190483647008097, 51.51751595158731, 54.121616732689645, 41.19490454273839, 30.5085874372913, 34.604051805311634, 45.633337036255874, 23.94832330365335, 7.272920550838594, 0.7209001361362396, 0.18085328741900383, 0.42880116811683106, 2.3975446003098644, 6.254834071282418, 7.9219776968802185, 8.326629996299744, 7.921307952173295, 6.700820797874082, 5.545692097756171, 18.137631954685336, 31.880436405058834, 47.45045738835489, 57.800093927691066, 58.08066891085718, 55.53723542921005, 54.77335776052168, 51.26248736535349, 50.48158661011727, 50.658254085048554, 52.31994659669938, 51.52327399100027, 52.082611822312884, 53.344112750022646, 52.52139168400919, 54.571508669084125, 53.32030004070651, 51.38888966652655, 50.259380417485396, 48.59685636335804, 51.017860904816665, 50.51775870784637, 51.74270706792032, 51.24716266509026, 53.21953827334989, 47.47597240632581, 38.28032462827621, 38.718763243767526, 37.1200208510122, 39.069748693896884, 37.45443820953369, 38.80998188449491, 38.13024690074306, 38.39403413957165, 39.588690034804806, 38.908174499388664, 39.148015668315274, 41.749213895490094, 44.42471750320927, 50.72051386679373, 50.29608203518776, 54.24577936049431, 43.55196268327775, 49.142450209586855, 54.67152126373784, 51.587396898577296, 50.593032913823286, 43.09349644568659, 41.952341679603826, 43.00839278005785, 50.78332278036302, 49.26070574791201, 48.822706437879994, 44.50543203661519, 46.60606130476921, 43.97468828385876, 43.89690768334174, 41.15985816524875, 40.67391180223034, 41.86031110825078, 43.69840437366117, 49.4813508372153, 50.85968740524785, 53.745367296280406, 52.843626160775464, 49.22275681649485, 52.45968103408814, 56.36403183783255, 54.94263156767815, 53.822139847663145, 53.272674622074256, 55.02712726593018, 54.48326710731753, 54.015987303949174, 55.21513431302963, 54.052728145353264, 54.6019031155494, 53.90621977467691, 57.75423749800652, 57.375520890758885, 59.52344217608052, 57.41637629847373, 52.07563000340616, 35.446569073584776, 23.874090486957183, 9.58897227241147, 4.8762822631866705, 7.524666603534453, 7.929162498443358, 7.811394804908384, 10.952883343542776, 9.938455454764828, 7.252726228006425, 2.7078891473431743, 0.4102938628244785, 0.2912002243101597, 1.2025284598911963, 10.987844409481173, 31.48122541366085, 41.35366247546288, 45.3355703046245, 43.32339440622638, 53.99541839476555, 62.680757968656486, 26.30210234272865, 3.1150819168936823, 0.08438966402243223, 0.012163677846171684, 0.020807392354453766, 0.04565845341271451, 0.04941556692844437, 0.057019008729126186, 0.035009995974119634, 0.05303725142091994, 0.07340841415909029, 0.008390837502966245, 0.029175998943467295, 0.031530074136812365, 0.023638250028354027, 0.09457208336360994, 0.05430498520933813, 0.029932378618527326, 0.02622302876965654, 0.055948109741533, 0.045788515990059224, 0.07601105232512759, 0.03131597362939389, 0.05231061702473991, 0.060569489179479505, 0.18411875251800786, 0.15241702297522178, 0.1346232060102686, 0.20717180904842195, 0.09626093185356549, 0.11501865596660685, 0.16328307619738966, 0.17387100885952675, 0.13032385929217263, 0.11443799962439846, 0.13010975303909472, 0.19888439245762365, 0.09233752746255168, 0.2579193424072958, 0.14294077582176656, 0.13380139285037596, 0.12710118786461894, 0.15074066937931124, 0.23099219456555384, 0.06534782088091297, 0.11308291266041418, 0.19414339605118, 0.16356203945413714, 0.12117133791288062, 0.12169380221636066, 0.09381927940393649, 0.20063775321168287, 6.442830331863896, 33.20898632849417, 56.950783114279474, 61.654873817197746, 51.09360971758443, 31.816382138959824, 40.190032528292754, 54.720711708068855, 28.296949209705478, 9.631499590412263, 1.0026510949096372, 0.5254207899974239, 1.9861526883417562, 5.295938609107848, 10.880544051047295, 14.943868517875673, 19.209764772845855, 17.737709053101078, 11.749527512058137, 9.536611572388681, 21.530872429570845, 34.56679713341498, 47.841243128622736, 59.562583508030066, 58.30059620641894, 58.50399855644473, 55.23934318173317, 53.906537486660866, 53.08475386711859, 53.95535530582551, 55.23242804311938, 54.26535591002434, 54.85624920937323, 54.613105404761534, 54.10324827317269, 56.960059519737, 54.57817277600689, 51.80323316204933, 50.72644449049427, 49.289656762153875, 52.62274572926184, 50.79714521285027, 53.06363582611085, 51.402202190891394, 54.915661350373306, 48.048281515798266, 40.22983281843124, 40.87345846237675, 39.04306873198479, 40.63984601728378, 39.345726659221036, 41.34029503791563, 39.46469999128772, 41.29096731062859, 40.43870687484741, 41.02183388125512, 42.0310793384429, 44.063267169460175, 45.633086004564845, 52.05379809102705, 54.036077683971776, 57.29818351807133, 46.000863121401885, 51.38611262844455, 56.55117204112392, 54.46772275432464, 54.31689585408857, 43.86688193967266, 43.47499793575656, 43.644981691914225, 51.53206402255643, 51.92656032500729, 49.71408859375985, 46.67898601101291, 48.43532139255155, 46.43817993902391, 46.45674059467931, 43.06621636113813, 41.462641608330514, 44.414413436766594, 44.521662804388235, 49.863381847258545, 53.14828057442942, 55.44499697223787, 53.43119329021823, 50.467724953928304, 52.84264949060256, 57.1639286318133, 54.372973980442175, 55.74374821878249, 55.06601756618869, 56.03306224269252, 56.42212998482489, 57.275041534054665, 58.404060486824285, 57.013360608008604, 56.84098420604583, 57.53177242894327, 57.83260645404939, 57.96419805096042, 58.2745595132151, 60.29175996780396, 51.96568596747614, 36.10218932551723, 26.21503749201375, 13.559646433399571, 8.526445338802954, 9.542334310470089, 11.505535494896675, 13.025501005111202, 21.82419707698207, 15.117919771902024, 14.649971204419291, 5.126794240167064, 0.7893286417088201, 0.6889607661193418, 1.8208936722047868, 11.932057949804491, 36.6467555107609, 48.52808152475665, 57.80052931078019, 51.20200049492621, 62.15991820058515, 67.88622563885104, 33.05708862120105, 4.0821604238402465, 0.22158440502901233, 0.20598115519650523, 0.17977599925812215, 0.2534319057820305, 0.07894225794100955, 0.16155703413871028, 0.10075818972602006, 0.1919765010355942, 0.14149181244354095, 0.0539539598919932, 0.11029199306522647, 0.10401658383348297, 0.15762850461948305, 0.1906341924181869, 0.1320960964526861, 0.07903729880889578, 0.10174425213687843, 0.1626640924763295, 0.07714817961377483, 0.15733866291421075, 0.08962533106246302, 0.22914679600827156, 0.14284860012271713], [0.09028216718786186, 0.04848408828219099, 0.06566889599085816, 0.04761472404483826, 0.029027490884125717, 0.009942594558871802, 0.05932051305388732, 0.04357554078582795, 0.019023321050729965, 0.025018669604774446, 0.06571191948868575, 0.030151384003881006, 0.0058720874010525165, 0.04136774816640443, 0.03939036032064788, 0.04348461764053472, 0.06831825019851809, 0.02260994169891121, 0.10444321053763551, 0.0134074512771481, 0.030439524993961378, 0.09916989027612633, 0.054323673924250956, 0.0372038189802439, 0.034291501262135086, 0.025616448012090502, 0.08953489438300172, 1.8498353708174922, 15.526137505808185, 37.40269037985033, 53.640083036115094, 39.78320429402013, 34.14771149235387, 36.10307970354634, 32.70310255788988, 26.224453141612393, 10.996932541170429, 1.0469812323008816, 0.21416108965152697, 0.34059748173721377, 1.663934759074642, 7.5202210872404045, 5.091682162977034, 5.762534449177404, 4.0481206245960735, 5.126906518013247, 6.068645533054106, 16.5187579970206, 30.03233325096869, 44.26130371709024, 51.63927024410617, 55.90982529424853, 51.71409729988345, 49.483162972234915, 48.757716686494895, 45.27451469052223, 43.252517177212624, 44.347411509483095, 45.58968497860817, 48.11578550646382, 48.91936932840655, 49.76430669907601, 51.68330669403077, 52.29303129257695, 50.809092752395145, 47.65972368178829, 47.980855972536155, 49.48915635385821, 51.87279639705535, 52.16867646863384, 51.11662226338541, 51.89875464285574, 49.38727671100248, 38.59927608120827, 40.54692114553144, 41.17588104740266, 35.72790891893449, 37.37927775229178, 38.31319409032022, 38.12953302937169, 38.65120826228973, 38.02615111873996, 39.11518542997299, 42.82782646917528, 43.40909034975114, 46.75081245360836, 48.19384067289291, 47.56841482654695, 53.562400494852376, 39.5249475971345, 48.77757172430716, 52.96312116807508, 48.58618359411917, 45.977991780927105, 39.63569571894985, 40.296803366753366, 39.29236673539685, 42.72406408863683, 43.91154596882482, 44.1150777570663, 42.25488585810508, 43.357146401559156, 45.78512883955433, 39.847982237415934, 38.25197373667071, 38.365177262213926, 39.388566786243075, 40.52256322676136, 45.26410079771473, 50.83093643188477, 51.665169654353974, 53.01230769003592, 51.797361373901374, 51.55140130750595, 51.248202093185924, 48.359902058878255, 46.92752307461154, 45.52999434932586, 45.76334791798746, 46.274436673810406, 47.54976787874776, 50.252002439191266, 50.829398862777225, 53.41488799741192, 55.958858843772646, 56.10313930819112, 57.66079879576161, 54.454041527163604, 52.58358478546143, 45.875637531280525, 30.61431100291591, 18.726122802303685, 7.628534397771282, 3.740501879684387, 4.502167576743711, 7.181597477005375, 4.9438269484427675, 5.968695206026878, 10.632292339878699, 8.998834029320749, 2.276476477423022, 0.24556825838742719, 0.16606625830454214, 1.5313597504169711, 10.925518928035613, 28.02583302220991, 32.36288009151336, 29.30986600537454, 39.17084386271816, 49.10780391385479, 42.773223154006466, 19.812676214402725, 1.4172488090492066, 0.03293493191801733, 0.077089972253288, 0.05938145151782421, 0.028487986869989868, 0.03874654002908257, 0.03774191913825851, 0.01993890145733472, 0.11480107933523194, 0.022540945905230703, 0.045996459065786297, 0.018417584905100447, 0.01672475084271883, 0.03894293049891149, 0.03586706066984804, 0.054552194121624195, 0.11645785172379787, 0.04742166222704034, 0.04191866114495262, 0.03737673268563325, 0.025003211865682277, 0.058713415186972394, 0.021662011314483903, 0.044671831757671414, 0.05272259995821984, 0.013607245092580636, 0.04575912119640459, 0.049031209125513994, 0.007934750408880533, 0.034444105976651755, 0.024072637203179544, 0.05343344145184083, 0.024713094368757262, 0.0469951810795934, 0.026408778278217204, 0.03243623549238809, 0.06375135493374641, 0.030586933717131618, 0.019215720202473384, 0.03016452815744185, 0.022859870223328475, 0.02040307413065626, 0.07316109033361559, 0.025311274972233563, 0.02363296019123687, 0.08884322423968585, 0.02511520625933284, 0.024815717591874065, 0.027964969067984534, 0.05201720918018011, 0.02346164377916965, 2.406643273368959, 20.84685225640574, 44.96301966328775, 58.806389762509255, 46.40885629961568, 31.9293503222927, 40.487889474438084, 42.81520820433094, 32.04261856694376, 11.07315399954396, 1.1938032700169472, 0.14531859016466528, 0.3192108809467285, 1.7068210965202701, 6.295645842629095, 6.875008844560193, 8.134193612683205, 8.799476623535156, 3.937295035969827, 6.202456701186396, 18.98137104126715, 32.56017334999577, 46.89625001722767, 53.88422312275056, 57.15106718001827, 53.851522322623964, 50.709366490764005, 51.41535389807917, 48.42193434315343, 46.18754832975326, 46.847200778222856, 47.79610057030955, 50.509796296396566, 51.089263731433505, 51.35865995960852, 52.65352849037417, 53.54294161642752, 53.22435102155132, 48.4541017009366, 49.49613425039476, 49.544669658907004, 52.519850192531464, 52.366348235837876, 53.866513621422556, 52.83800540431854, 50.86013455544749, 39.662320767679525, 42.39599312505415, 41.54398372096401, 38.185454260918405, 38.249098639334406, 40.741639367995724, 39.16041035805979, 40.534400939941406, 39.83435200106713, 41.1324917885565, 42.996394249700735, 45.26728576229465, 49.587027334397845, 50.6338922439083, 50.12557268142701, 56.30346652000182, 42.62400442554105, 48.77632048822219, 55.81748877802203, 51.46028464840305, 48.76052902590845, 41.93536173912787, 41.31752960143551, 41.765483886964866, 45.20953670624764, 46.95486199471259, 45.07552500694029, 43.93889273366621, 45.287791913555516, 48.7528411803707, 42.52966750052668, 40.475157460858746, 40.15817896012337, 40.94829336289437, 42.93599759378741, 48.26259982201361, 52.06995041139665, 53.043937683105476, 53.277420689982755, 50.926136278337054, 52.979583355688284, 53.66282101600401, 50.712712272520996, 50.73270851565946, 48.55080773753505, 48.1020454437502, 49.43990707397462, 50.492620237412, 52.261926897110484, 52.982364316140455, 54.157039657715835, 57.05392183796052, 56.5219033148981, 59.38659068076842, 55.36147794415874, 56.768169326166955, 46.77146373256561, 34.32067232747232, 18.8010008488932, 10.779261589050295, 4.620116189602883, 8.75839764072049, 7.939015002019945, 9.698976124486617, 7.125681638717652, 7.458427086953194, 4.955160146759403, 1.4638256065307127, 0.21010485327532216, 0.4028333002521146, 1.583346476958644, 12.607642085321489, 32.51184974947284, 34.78376696186681, 38.96176192068285, 45.56835512961111, 57.94408413671679, 50.10248561059275, 24.60758939866097, 1.8328072587328574, 0.012974750453365907, 0.062168460234158465, 0.01363194759769906, 0.028820691194625634, 0.025994688602945498, 0.024615148112418193, 0.028666786045857498, 0.03597306425593073, 0.02789055511745955, 0.05199331106738218, 0.014817557718244292, 0.026928850472153678, 0.04279032364607819, 0.09255399326643637, 0.07990236529299329, 0.05901940219524888, 0.04714517343428828, 0.030989765730356018, 0.04475798217519637, 0.0732480030086252, 0.0388305185873422, 0.03406505333259702, 0.027678195544849002, 0.13181209233739685, 0.193204831091627, 0.1171975862234831, 0.21838647824141288, 0.08042088424366328, 0.12082513511901903, 0.2037489128809783, 0.1391861329395925, 0.11861452712647377, 0.22952481443362854, 0.1411117562243054, 0.10263522771457512, 0.23473764439263653, 0.12388271459889029, 0.1600798327595957, 0.1418510157494776, 0.1621833723038435, 0.08608251915223177, 0.21520748914730167, 0.07869028396183446, 0.17571527360668107, 0.23045101473408364, 0.2275552483455789, 0.20822380098604387, 0.1563282082638433, 0.17911268968976315, 0.15979273364909236, 2.5850081539923147, 24.31410393407268, 51.50197159859442, 66.71065207450621, 50.68004285135577, 45.463898489552165, 46.481702558455936, 44.45089147936913, 35.90970293168099, 15.400940352870574, 2.119346083171906, 0.29509906026144184, 1.1856638616131199, 5.998304197865148, 16.20566362334836, 13.376969887364297, 14.306185264741222, 11.376954317092897, 10.591330047576658, 9.498907789107292, 21.31701304066566, 31.841899118115826, 49.52908215984222, 55.435265571840354, 59.432470644674, 56.02606473430511, 52.510020732879646, 54.17752227475567, 50.19863074825656, 47.78282334727626, 48.57583245923443, 48.41740792797458, 51.834729794533025, 53.244865017552534, 53.69712214316092, 54.85498620617775, 54.60654720183342, 53.29222763738325, 49.348864939904985, 49.51106671364077, 50.64660072326661, 53.40019087637625, 53.22842244179019, 53.12896682370094, 54.90327058299896, 52.694097565066436, 41.445041933367335, 44.29710711202314, 43.77078779282109, 39.641049754235056, 40.270954947317804, 42.09621029515421, 40.4854497601909, 43.12434196472169, 41.35140319024363, 44.00450614190871, 46.55912622328728, 48.51350207482615, 53.084090986559474, 51.86053114552652, 51.07936366911858, 58.137335392736624, 44.771098090756325, 51.93596224631033, 57.739481541418264, 53.26646158772131, 49.97022721075243, 44.23016402029222, 43.13292018828854, 42.75934580833682, 46.89568911829303, 48.65549971980434, 46.75402095240932, 45.76686628403203, 47.162473047933275, 50.48439502716065, 43.72442929975448, 42.22101619166713, 43.01398607992357, 43.29970329038559, 45.26723869385258, 50.66906021487329, 53.60649578032955, 55.1375812099826, 54.21356885663925, 51.5380613265499, 52.915954666752974, 56.24858471655077, 52.254258663423606, 52.03337823190997, 49.34082015868157, 49.73618722731068, 51.986231342438735, 53.22165635324294, 55.437811190082186, 55.24419123126615, 57.742835167915594, 60.31658072625438, 59.295285747897246, 59.129291042204834, 57.26825191128639, 56.38246305527226, 50.27473649671001, 37.41508899196502, 21.55416346365406, 8.961618581125814, 9.005037257748267, 10.079430341720581, 15.496598136040474, 14.924030150136641, 15.412832979233036, 21.219357790485507, 18.607094557054584, 5.7709930404540035, 2.1113476349461466, 0.6212157335492873, 2.369925475889637, 14.203140677944308, 37.8370261961414, 45.073657958738266, 42.76076178396902, 55.06148722863967, 64.8090870149674, 57.117291650464466, 28.35623779604512, 3.000187114361794, 0.19774302870275515, 0.16244042544595658, 0.1993931667698968, 0.1088342120149924, 0.19451917749979805, 0.08698123987884292, 0.0986211721394812, 0.18846535153927343, 0.10314858323263545, 0.15576729400744363, 0.061966714809738824, 0.1537379730613001, 0.1953871704397663, 0.17942091750521816, 0.18634439115562748, 0.10979392100125553, 0.10759503415395176, 0.156489301232561, 0.11131920971937719, 0.16582124806459875, 0.24660791630946824, 0.12617291146588902, 0.2057811449612341], [0.018222688306723873, 0.02225510700936279, 0.030013311977287935, 0.03069204289556271, 0.033157438325184974, 0.05242472199062186, 0.027381549063589306, 0.0764903245914367, 0.015884709578277846, 0.08446291734975192, 0.043326374518895344, 0.0220558762685546, 0.0691164908329806, 0.12731800606894877, 0.011224391806359974, 0.018980684427304134, 0.04082881297255236, 0.03844616461485144, 0.03250589969778254, 0.1224416112827678, 0.007629620461469337, 0.03096428181555483, 0.07015974170738651, 0.007185459919949814, 0.023813875684995326, 0.05206383329125182, 0.034227632511887825, 0.38966765026411704, 8.555745443990155, 30.90533321903598, 51.00680374330091, 42.18351048807944, 34.81924480007541, 29.731944414877123, 35.800672808001124, 31.34413661495332, 16.15360788760647, 2.3903311164148393, 0.22629183146261403, 0.06429544589932888, 0.9431683512464647, 4.0688976645469666, 5.501345290291694, 3.4393337176692103, 7.621910004846512, 3.631684789734502, 4.987605992824801, 13.913702118781305, 24.63237289459475, 41.42794432178621, 53.96343146601031, 53.30639523844565, 52.016111958411436, 51.75454478110037, 50.25136701522335, 47.76617288589478, 46.69227107878655, 43.28704187946935, 41.742738062335604, 42.153571036554155, 43.54788341829854, 47.73482138110746, 49.00664990948093, 51.54991865158082, 54.271392437719534, 52.2905876559596, 49.228448175614886, 51.12218810665993, 51.46570928635136, 48.11242011285598, 54.327588235178304, 50.168350050526286, 46.192086512042636, 38.001365661621094, 35.71646344277167, 35.7287992969636, 37.29064003113778, 39.029740518139256, 38.78448647837485, 40.02082147905904, 41.80390742517287, 43.721860147291615, 45.93860333965671, 46.142672492611794, 48.61267528226299, 47.63068245303246, 50.650264217007546, 49.67798317632368, 56.80593782855619, 40.90523358314268, 48.257371302573915, 52.596881620345584, 48.923162260363185, 47.08219781998665, 38.46806103183378, 38.12297482644358, 38.18229283055952, 38.695252556954664, 39.577052362503544, 41.31084196029171, 40.451034884299006, 41.672566859952866, 41.785562499876946, 37.83481790173439, 38.80244308902372, 39.20156386590774, 39.31767779011881, 44.04889168277864, 46.719355044826386, 50.51381672582319, 50.731633786232244, 53.63823167739376, 51.34053860941241, 53.48311370418918, 51.41975479741251, 45.915073040992986, 42.40219439229658, 38.44444444102626, 40.30287127340994, 43.97017363579043, 45.58057331269788, 49.624580106427594, 50.51057684806086, 49.38689624109576, 51.80072676750922, 55.39961514934417, 57.949673514212336, 52.49340165045954, 55.94575812739711, 47.00505656580771, 31.358339517347275, 18.039931597248202, 9.811830559084493, 3.558207274444642, 12.049393692324239, 6.378335289416775, 7.777103973973182, 6.7604486692336305, 4.633277702716089, 2.920711804782191, 1.6999258149054743, 0.2716502733528614, 0.18665148516095456, 2.3709786322809037, 15.556385843984543, 38.066324034044825, 37.29659026668918, 35.39733156081169, 38.93356792388424, 48.53299233221239, 43.85400872076712, 12.851082028881198, 0.5330835078512469, 0.08074799612645181, 0.07653940784474535, 0.05563043989241124, 0.08638782817269526, 0.049406469634343544, 0.051812242356038866, 0.021629262970940723, 0.014169722168345847, 0.11532417949168913, 0.010617823497722707, 0.0316298226149933, 0.03497192523472252, 0.03549818933430699, 0.08681646968808868, 0.07945758996591454, 0.09423932541281947, 0.03728643390199831, 0.01821818179450929, 0.061619669319160526, 0.016749095201732653, 0.02063805819489062, 0.04217701280609735, 0.06355361997961037, 0.03074454098579384, 0.02150055445400217, 0.10713611684379079, 0.0429853696316, 0.025782250506322713, 0.044012452220363964, 0.021992191379409165, 0.0027003871547358655, 0.026641498552635316, 0.018493373983449513, 0.017774601564592412, 0.06895977222631056, 0.02797742182719371, 0.04190611262475291, 0.029974657095848557, 0.023667995307234027, 0.05184960063366641, 0.017357799938068758, 0.04788567402189778, 0.023772855507089727, 0.03415120375012198, 0.014260298658853338, 0.029455364396375035, 0.03844875782247513, 0.02217611185305061, 0.03781793804298486, 0.12557173928906842, 0.6903253219300701, 9.978075315875392, 37.40772670315158, 56.92750384730678, 47.84673052449381, 39.65460938792075, 32.894696612511915, 36.90425519020327, 33.800660179507354, 18.389703073809226, 2.896421301749445, 0.12086152429542235, 0.11766738198216885, 0.8444443777684243, 4.718264677832204, 6.170861028855847, 7.4199697183024504, 9.038734339898634, 5.7040960365726106, 8.168739397679607, 16.529846537497736, 25.263337127624023, 42.442543814259196, 55.04399345767114, 56.189627570490686, 54.91631246382191, 55.071552030501834, 52.10670694228142, 50.03526795294977, 47.550238563168435, 44.687802637777025, 44.106840779704434, 44.909338105109434, 46.48005516298356, 49.854258414237734, 50.696524650819846, 52.98226233451597, 53.294408475199056, 52.70752776053644, 49.411869971982895, 50.669413228188795, 54.11694911218459, 51.064199786032404, 55.231027756967855, 52.447859010388775, 48.36473441893055, 40.44372750866798, 38.50058924767279, 37.59276059366042, 39.37905896094538, 40.38248754316761, 40.57094566283688, 42.32526102373677, 42.564647197723396, 45.12369171265633, 46.82057572949318, 47.35304532512542, 49.85254041610226, 50.16373734320364, 52.26560215796194, 51.52666291882915, 57.5264262383984, 43.40597598783432, 49.07644456432712, 55.205618642991595, 51.64749545435752, 49.68125443304739, 39.99728725802514, 39.303012048044515, 39.82651902783302, 41.11414294089041, 41.970282600772, 42.98883192000851, 42.77296819994527, 44.1756469972672, 44.85315015239101, 40.64633361754879, 40.398216247558594, 40.064912842166045, 41.16846776777699, 45.717503255413426, 49.122214701867875, 51.54340751709477, 54.08040046691895, 55.28194796654486, 51.83944056110998, 54.79510730312717, 53.15785115764987, 48.93204642880348, 44.47782639534243, 41.321816752033854, 41.58725138633482, 45.9540770899865, 48.29733633225965, 51.648315229723536, 52.44918477150702, 50.31943582719373, 55.89774831648796, 57.64153603584536, 58.05254551672167, 55.84612600265011, 57.75796374967022, 48.695978579982636, 33.4978610469449, 18.76852950742168, 11.155032496298514, 4.4749497598217385, 9.381738747319869, 9.594885245446237, 8.444131458959273, 8.721807810568041, 6.1274075411981155, 3.6237228685809724, 1.2020227192871034, 0.2396003262049729, 0.07914937747221801, 3.0880244268525034, 16.21074897627677, 35.777679874051, 44.60295392620949, 39.731315259010564, 44.84665862975582, 55.23700544911047, 50.2549167602293, 16.872265531170754, 0.7820471292061191, 0.12628168062937836, 0.09381341883131573, 0.0356229352614572, 0.0543788590678765, 0.06406186186077614, 0.04405428062102968, 0.012985754348788292, 0.014093771253922775, 0.011548828127072945, 0.03774284227420727, 0.03368429997335038, 0.05184061442231459, 0.0385048431194117, 0.025296529694910974, 0.06123940625618543, 0.021569079103609248, 0.05303886403600055, 0.030201585745559107, 0.020755823145830826, 0.03902012151816199, 0.050111232220285365, 0.03989317446887013, 0.04093972335179006, 0.13641496309109274, 0.05575574506374617, 0.16570898554017469, 0.13818050464314802, 0.12543676225768943, 0.20311387195702524, 0.17934018715975747, 0.12810127734537088, 0.07870235750752111, 0.1305726080411865, 0.11880788771856217, 0.1007773802285233, 0.12532366469742792, 0.19656572010247939, 0.1544152407516395, 0.17465568207685025, 0.1841064491459439, 0.07597661667293118, 0.1268495279814928, 0.26253643175286634, 0.22217616198524354, 0.13274990653078403, 0.10411064410882612, 0.1450606636823185, 0.30251543488233323, 0.21152553268738333, 0.222157561370442, 0.7523193630960681, 11.945215540547526, 44.21689856436945, 64.43197465712025, 54.623907612216094, 46.09127767624394, 39.18854944167599, 47.3019289970398, 42.79198777291083, 21.776561852424376, 3.629743951943613, 0.41982954307909937, 0.47525667855816506, 3.40945874010363, 8.745009610729834, 13.533080220222475, 14.113230147669393, 16.963013487477458, 9.753848122012231, 8.630262632523815, 16.814485096162368, 26.78872923697195, 44.15013197929629, 56.600350718344416, 58.21560236715502, 57.67298952225716, 57.2303500483113, 55.680707885373025, 52.220459599648755, 49.91606320104292, 48.62829023791898, 46.866455693398755, 46.356731922395774, 47.80047009068151, 53.17710999519595, 52.70289936373311, 56.148262254653446, 55.023879543427505, 52.371196285370864, 49.50891725478634, 50.14985607516382, 52.81273749566848, 51.424665604868245, 57.007669248888575, 56.1372168602482, 51.22302047667965, 42.50600776364727, 38.99612580576251, 39.46318595640121, 41.50453252177085, 43.215642975222686, 42.88799170524844, 43.983356721939586, 44.79748779727567, 48.36046688018307, 49.6185435787324, 49.7403214054723, 54.24813670496787, 53.36531708317419, 55.03094765447802, 55.494932666901626, 59.21039389025781, 46.42463207244874, 50.159218772765136, 57.30627536773682, 54.60283663965041, 52.05623388290406, 40.87519607236309, 40.595162376280754, 41.288692335928644, 43.98656522074054, 43.991421115013864, 45.27443232074861, 44.347678230654815, 46.002522283984774, 47.089701314126295, 41.71714459696124, 43.26413523766303, 41.661835255161414, 43.225201791332616, 48.0735533468185, 50.76231848809027, 54.50380855990995, 55.50558974665981, 55.19835441343246, 51.9684551608178, 57.64931409589706, 55.80802802116641, 49.69883841852988, 47.49377996690812, 42.33600047326858, 43.98576113485521, 50.138508658255304, 50.02320274229973, 54.49405754766157, 55.428566163586034, 53.37131830953783, 57.10466554087978, 57.24773007054483, 60.55404493885656, 56.59581645842522, 59.31390523910523, 50.3110380326548, 36.463651426376835, 21.696419985063617, 13.069077557133092, 9.387234968523826, 19.904665600868967, 17.698603022483088, 15.42149063079588, 14.946938753128054, 12.084270427303931, 6.303496466528985, 3.2710831588314426, 0.5845860055377406, 0.5520791788735698, 4.0456017275010385, 20.085669256025746, 46.47843130173222, 48.42670786765314, 48.39419534129482, 53.57016286542339, 63.407506481293716, 57.9264844617536, 20.044094093384285, 1.4382272381936352, 0.2702517951688459, 0.18823937092336918, 0.18827641893538738, 0.1544626309506355, 0.12691417048054357, 0.11401451388073545, 0.116788579541589, 0.11575715706473398, 0.19031493293662227, 0.12757479108028835, 0.10737728898323352, 0.12056626634852541, 0.1360144676460374, 0.09623289303553682, 0.15917063961105962, 0.2035628914112045, 0.12175477515425413, 0.11972881733409821, 0.11852504805691781, 0.14154246617709437, 0.11982715238005885, 0.1376228079560303, 0.13800105620776454], [0.05372648540463659, 0.041478773458830775, 0.07940466861210524, 0.023947084968489026, 0.03468484144597765, 0.07760489059071388, 0.05799012093414223, 0.07496727285005393, 0.01804079413564215, 0.012544354596625895, 0.02989578834404388, 0.012132221318390823, 0.05695805111299119, 0.03098815503049522, 0.029950406582605456, 0.02711754941922282, 0.009627501638005338, 0.028062183710355914, 0.031320037725832195, 0.04168512690211496, 0.06302690005771096, 0.10268519962987593, 0.03446243846067979, 0.014739293218289894, 0.04752259814150391, 0.06457685297655483, 0.015325775659162433, 0.18111236303323702, 4.796467423439026, 21.487642026716664, 50.27986303452523, 48.23082862361785, 39.880855621830115, 44.27799340217344, 44.95887371801561, 36.030213832855225, 16.33756410691046, 5.114619203152196, 0.2814484153303408, 0.3305266124586905, 0.45704014959835243, 4.623697803866479, 3.4263952893595544, 5.215699172789051, 5.465344305961363, 2.536212153011753, 8.05806040763855, 12.279734880693498, 23.60203096943517, 38.432500823851555, 50.2222591061746, 54.70480257464994, 56.27837904037968, 52.91203621895083, 55.578208508030066, 51.34164864017118, 51.551389540395434, 45.60047541895221, 42.110675996349705, 40.581100679213, 42.10436098037228, 47.157679911582704, 49.611047929333104, 52.26644938991916, 50.42586541944935, 48.583249661230276, 51.03881420627717, 50.90783057674285, 48.51826383221535, 53.8108120426055, 51.84325702728764, 49.33069259889665, 44.005894660949714, 37.80454112637428, 37.013434363949685, 39.612922437729374, 38.76551789622153, 38.349793726398104, 40.50915264314221, 41.54867095331992, 47.30147400209981, 45.41517872964182, 48.316630471137266, 47.88601698413972, 50.28953559937016, 48.840459085279896, 52.962356305891475, 50.271881011224565, 53.57612094571514, 37.65596958898729, 47.389797933640025, 52.8335613589133, 48.94033047460741, 49.625023334257065, 43.97471574044997, 39.94663769199003, 37.94240067082067, 38.16143366598314, 37.719213885645715, 38.32453758485856, 37.712173231186405, 38.52923823941139, 37.49458366824735, 37.5842490503865, 37.618483497250466, 37.37090741434405, 43.895719205179525, 47.187823326356956, 48.91518415943269, 49.196935853650494, 51.16760915325534, 52.49880275418682, 51.53972441150297, 52.03553553550474, 49.85514486989668, 49.33250473391626, 40.701109517005186, 37.345302181859175, 42.76469592125186, 50.683353331781205, 51.955872197305005, 53.97921900595389, 52.60756615669497, 55.30596071673978, 53.8706595666947, 55.52248339499197, 55.823741036076704, 54.84945566423478, 54.80897680405648, 45.04800565781132, 32.731237719135905, 18.656996911571873, 13.972362145300835, 3.823413430683075, 7.545989098087435, 6.022746937890207, 7.415086857734188, 5.208599682777159, 4.2953836533331105, 2.5575748518590005, 0.8606605592273897, 0.10330358580235513, 0.36396365372403977, 4.048629552125931, 16.909318201003536, 43.08258441186721, 23.434786988842873, 27.070129879059333, 46.3674399929662, 51.368842432575846, 37.75202451213714, 11.4827916314525, 0.21234898527543392, 0.1381452492768726, 0.03155370028839717, 0.055139634172402086, 0.043028871934380264, 0.05175003218614767, 0.04146727830952695, 0.058429690693775495, 0.022402776202427286, 0.07162156004098154, 0.057231667076027205, 0.054057937175516164, 0.0017977560280762134, 0.027417172152068348, 0.055075171704013506, 0.0420390518622533, 0.019988030675918828, 0.021624333195147977, 0.007426146072365585, 0.03568009691192739, 0.03336527797904226, 0.08654958763790709, 0.041113502736533844, 0.026714560357973944, 0.06481203430842969, 0.03384631224757722, 0.038121098186820745, 0.017263751154044465, 0.03166898694490233, 0.028880005552163048, 0.02791882567708531, 0.08801896725931475, 0.029839237648693305, 0.005298674898973156, 0.02472289646374843, 0.03342965617775917, 0.04574165056129137, 0.013489207222817406, 0.02474261748213922, 0.023436450977779688, 0.04256617014987334, 0.006216017307803756, 0.05099738910493832, 0.009746024058380676, 0.05818674889122767, 0.09310755307876295, 0.00541827941854154, 0.09766105712661821, 0.04439176533431296, 0.02847002593860511, 0.05047761760051212, 0.23806399815986234, 6.001534759998322, 27.409059924464074, 55.934630363218254, 52.09706967876804, 41.826425752332135, 41.41447882498465, 45.644566782059215, 43.0311111480959, 19.05267776981477, 4.477579218726005, 0.3625469120039094, 0.15368811605918795, 0.4613512940704823, 2.109234703163947, 5.526233709627583, 6.002232451592723, 7.143451446487058, 5.16434112864156, 7.51892033123201, 13.053283153041718, 26.681556355568674, 40.388712344631074, 52.49080896377564, 54.882470253975164, 58.991372662205855, 53.83658593700778, 55.518164865432254, 52.719094830174605, 54.23309441535704, 48.056290995690134, 42.93906488726216, 43.15091602263912, 43.75437267364995, 49.45016407197522, 51.45808812110655, 53.560992363960516, 53.66386828884002, 49.839012161377944, 51.56633769312213, 53.483368658250384, 49.76886449321624, 52.166138695132354, 53.55224155610608, 52.22730021322928, 46.152172473169145, 38.34216863878312, 37.63173326369255, 39.747542104413434, 41.24578552861368, 40.013408199433364, 42.70456598651025, 44.16479379900041, 48.24379597940753, 46.94773897047966, 51.14453777190178, 49.534008656778646, 52.01276617665445, 49.841542090139086, 55.027335151549316, 53.15300310811689, 54.505687375222486, 42.089495197419204, 49.569541408169655, 54.00925651673348, 50.18835806077527, 50.12115217024281, 44.80315954454484, 42.077406452548125, 39.49101125040362, 39.76632241279849, 39.87407776617235, 39.94228386109875, 40.102618586632516, 41.32585287094116, 40.1431562823634, 39.93006567801199, 38.85013911031908, 39.395434856414795, 45.38453717385569, 49.69178599696006, 50.677544301556004, 50.73010013949487, 54.85802212069112, 54.260841261956, 51.459821808722715, 53.575152120282574, 52.42528184767693, 51.52395256104008, 42.399899805745775, 39.937463268156975, 43.62636220070624, 51.253728712758715, 54.212325465294626, 55.34926760581232, 55.03117515194801, 55.66659911986321, 55.60351956275202, 57.00183668444234, 56.77489619101248, 56.271812992711226, 55.732106624111054, 47.032650439969956, 36.05175941221176, 20.407980219010387, 10.375860525715737, 3.6080449098540894, 9.059510154108848, 10.904797046415268, 7.2686314390551665, 5.272827023460019, 5.073979035500558, 3.211519516283466, 1.046064868569374, 0.1499107816526967, 0.35652573671071763, 3.253574924122903, 20.375995251440234, 47.567865694722826, 28.501910701874767, 35.688442030260646, 51.10083864581201, 56.785266937748084, 44.29639716302195, 13.31954344626396, 0.43924024989528043, 0.047628042483401876, 0.03312314822969418, 0.05468409530998719, 0.04862470755113229, 0.010607208391921896, 0.004766225118205072, 0.019022828839238615, 0.019445245890247247, 0.0065261914653913875, 0.02983365095250549, 0.03161451234782656, 0.037324466336999214, 0.026311140372267654, 0.03254272937474232, 0.03281191734957599, 0.05903891828511992, 0.017392946136814934, 0.03726158584017427, 0.026951984412247137, 0.022961097251203273, 0.07031631475735096, 0.04634630460772784, 0.09556154720485212, 0.15840095107353505, 0.07620868768783347, 0.18392552982174581, 0.12397753330127848, 0.07892598623349782, 0.168966130924321, 0.23885555084674592, 0.2264367599761294, 0.06811784925840556, 0.12570645585055315, 0.1592519368615843, 0.22502580988070658, 0.13892681217722355, 0.08966381165889964, 0.07167457332534176, 0.09180266785645678, 0.16022595637027295, 0.14665165976170572, 0.08556274381736595, 0.21241287700831893, 0.138561143089206, 0.2853559540404428, 0.18369395676399433, 0.13666587220805307, 0.17419541645194256, 0.19610142485508997, 0.23046981453174548, 0.3721144615161804, 7.411244405854133, 31.776609305412542, 63.61432521573959, 60.10647112323392, 50.78593115652762, 55.58175433066584, 58.104030547603486, 48.52557513021654, 22.892727198139315, 6.5649278317728355, 0.5698365453750857, 1.161977035864707, 1.3537292110343135, 9.053614831739857, 13.089789632828007, 12.901908101574069, 14.456287507087955, 6.282291152784902, 10.625435056224948, 14.759228825569155, 28.895865717241843, 43.10923299481792, 54.83193443667505, 56.84695797581827, 62.2711056278598, 55.78662756950625, 57.65797468923754, 55.90039591635428, 56.024840954811346, 51.74725309495003, 45.43757154095558, 44.840767229757006, 44.90718080151466, 52.80109197862687, 54.061271067588564, 56.25234234717585, 54.23849944145449, 49.244996655371885, 51.62664805689166, 54.38802411479335, 51.59206059671218, 55.760571264451556, 54.88642792547903, 54.080341631366366, 47.13781310665993, 40.77330466239683, 41.084046594558224, 42.888411398856874, 42.99555878485403, 41.235905078149614, 45.53896873228012, 45.47799548795147, 51.09664955446797, 49.39725914309102, 52.78331579700593, 51.13756772010557, 55.20470080837127, 52.099944776104344, 55.44789952616538, 53.707810601880475, 57.18939658134215, 46.64727364816974, 49.71043294475925, 55.82523153674219, 52.3103367897772, 53.616062441179835, 47.721367651416415, 44.26914845743487, 42.09499828277096, 41.63534356701759, 41.92401432221936, 41.35991081114739, 41.40466897718368, 42.014652452161236, 41.763134387231645, 40.852383567440896, 41.015389427062004, 40.94115464918075, 49.20630639599216, 52.06921300580425, 54.181409343596435, 54.56384828013759, 55.4643185677067, 53.33417738637617, 50.900962506571126, 54.97568538112026, 53.68224851546749, 53.94683591781124, 46.00230263125512, 42.121768459197014, 46.910825544788, 55.86938958014212, 57.23092663672663, 58.91793020309941, 57.60163376408239, 58.491737227286066, 57.344714595425515, 58.90061686115881, 59.150487530616026, 58.23686161348897, 57.09554210785897, 50.071545954673525, 38.12064493856123, 24.077079026929795, 17.501311725185765, 8.032529209890674, 16.612200621635683, 17.478636503219604, 15.078232249905987, 12.828083211375823, 12.89746895913155, 8.782608470609112, 2.573430052688045, 0.7161160702666929, 0.6955602152212974, 4.819555965162093, 21.016971334334343, 51.38321007451704, 34.95981862468105, 39.16040251331945, 59.61197399323987, 66.04516706159039, 48.851845725890136, 17.00421602495255, 0.7756981602118862, 0.2603228053738994, 0.1555137189045068, 0.11413161808084096, 0.13014496244009466, 0.11592407996255545, 0.19302689951033364, 0.1217598849607091, 0.12724569502977595, 0.23989254278281044, 0.13723602548481958, 0.12653016124761876, 0.06791469806264486, 0.09186033895539661, 0.11581837515076322, 0.19428783426842383, 0.1785615353935188, 0.34669437716084145, 0.0998406921843848, 0.238491322004026, 0.17662613682689207, 0.1760561674112274, 0.1651766923286261, 0.16240262666777258], [0.04184474515157842, 0.08997066051609094, 0.03690993233073143, 0.03608248459415571, 0.04455338690369841, 0.011710903603553532, 0.044593958920168306, 0.05263481011253692, 0.03397914423276821, 0.042051638686849226, 0.03362025885332016, 0.011916318589130477, 0.0603358400234532, 0.053132407201994816, 0.01415191828498557, 0.06256568448377714, 0.01941043102452832, 0.06821462148500067, 0.04395775737300996, 0.006026241528396045, 0.008077573617019, 0.035208014380787654, 0.03306057033759933, 0.043581891654720234, 0.04880846906152945, 0.0381374120291683, 0.03582958747903186, 0.021427316448440956, 1.3445504971088902, 16.88694304035556, 46.2725539361277, 53.054014252078154, 46.13841672097483, 39.497859708724484, 28.741565558218188, 30.01838726382102, 27.581263742139264, 6.42626763351502, 0.6432807205184814, 0.10486933162375804, 0.13805299696903076, 1.3550629394669689, 3.5988660733545985, 2.7645578355558458, 5.518538019349498, 7.559579130141967, 5.078294623282648, 11.699728119757868, 23.021945761096095, 38.740410804748535, 53.93488053352603, 55.26287740276706, 55.48021593401509, 55.489892421230195, 50.25388517687398, 53.74677150480209, 49.90872836882069, 49.087164402008064, 40.53415775299072, 40.02555185748685, 43.57807782388503, 47.16228869653518, 49.35327368397867, 49.986685475995465, 52.647460583717596, 48.564335992259366, 49.69245279988935, 50.18299618074971, 52.21444268380442, 52.08390228209957, 51.05971259455527, 47.33006415828582, 40.261505957572695, 36.893076435212166, 36.85455876012003, 39.593377267160726, 39.51414146730977, 40.07920203670379, 40.135586107930834, 41.75061025927144, 44.69078756147816, 47.64037462972826, 47.894854084137954, 46.8400816763601, 48.08913300114293, 47.26736507108135, 50.44573222437213, 48.33254744929653, 52.5095029800169, 37.66158250070388, 45.50438127210064, 53.38241077238514, 51.278827959491366, 51.00660762479229, 49.74063127271591, 48.447115959659705, 43.407886182108236, 41.06610175101988, 35.32736039930774, 39.03991122399607, 36.6923765982351, 36.46067434741605, 35.58004733054869, 37.0095786740703, 39.079927244494044, 41.947222986528956, 47.78216438908731, 49.60239125836281, 51.559999142923665, 54.12783761178294, 51.793442926099225, 50.86073075571368, 51.77190911385321, 54.58355034551313, 51.09653972810315, 48.77867783269575, 39.57467148380895, 40.13407991778466, 48.804871420706476, 51.48941609167284, 53.25993476375457, 55.66922710787866, 55.048217850346724, 52.78693222230481, 53.91192682327763, 54.79337361551101, 58.33268119442848, 58.550180542853575, 54.77398926211942, 42.08996588183988, 36.530947531423266, 18.115866722599154, 5.948006174256725, 2.495405774924063, 7.182001481133123, 6.778379294180102, 5.400238354359904, 5.811013963914687, 3.0949684929463173, 2.0892274283593704, 0.9850236569200793, 0.15868051187886348, 0.264795073458264, 5.416980501144163, 15.698280526745705, 41.147294813586825, 68.3323246432889, 40.30056884211879, 49.77410477976645, 53.875229127945445, 38.81616746225665, 5.9026449438064335, 0.061030961392867955, 0.0664510487789108, 0.033213435522010254, 0.04572390030408579, 0.012517611424799168, 0.023355674667043552, 0.04056871080050065, 0.026190029532318155, 0.03741867982992723, 0.04994412163092245, 0.06686651358200658, 0.04454331667793374, 0.05960200823122456, 0.05562719551005191, 0.015891228986513472, 0.038238187065167774, 0.05256206240324725, 0.034340860307096474, 0.09123397780762565, 0.047265977839068066, 0.03828947665169835, 0.04677282022913137, 0.039215450956215786, 0.050807973865659974, 0.0936352804062828, 0.040747282065210805, 0.026872414689991745, 0.02273702993988991, 0.06213066145597447, 0.014080216285712538, 0.03457906385583263, 0.0246783446205119, 0.031741529725672256, 0.0798892498677296, 0.0140895338300916, 0.01596994835117291, 0.0868796719418418, 0.05384825124976136, 0.04029918957741992, 0.012525881343941777, 0.04000564766747337, 0.046899048536415064, 0.016728069918650775, 0.036012395209963285, 0.03671726504821451, 0.018183033680543303, 0.05381389220635738, 0.021755793882954507, 0.018400100863448555, 0.02118871453398418, 0.04278191966154883, 0.05132077396997521, 2.300054825121357, 21.367062484064412, 53.37416202791276, 58.44934817283385, 50.4218763689841, 44.22011490791075, 36.16983452150899, 35.86026537802912, 28.875212477099513, 8.624847800500932, 0.7711526847654774, 0.07774179816366204, 0.14320271660483655, 2.2771594601292766, 5.9157603690701155, 7.386846773086056, 7.077592399812515, 6.142509646954076, 6.716896141729047, 13.17476091846343, 25.751493746234527, 40.24591845850791, 54.84610596010762, 55.746595859527595, 55.40989175919564, 56.02185603111021, 51.637120785251746, 55.57635322693856, 52.99413534902757, 50.48329284114223, 44.790619727103945, 41.80262873249669, 45.25902525071175, 48.70759271806287, 51.026901968063854, 53.01438654622724, 52.27027370083717, 50.6753203176683, 51.22720956802369, 51.008125582048976, 52.52631425857545, 54.779527648802734, 52.874463835070216, 50.34782986487112, 44.42578831026631, 39.34472253245693, 41.31000649544501, 41.4825790159164, 40.84362491484612, 42.11366092005084, 42.83915427423293, 43.64333429644185, 47.797100774703495, 49.584626843852384, 48.86893549273091, 49.05342809615597, 49.94516326535133, 51.78786531571419, 52.414161928238414, 50.55153031503001, 55.32335250608383, 41.980155206495716, 48.51013275884813, 55.20351233020906, 52.45957905246366, 52.21390924146099, 50.74049834282168, 50.16100345119354, 43.91580174046178, 41.875145512242476, 37.539647779157086, 40.220003358779415, 38.53677703488258, 38.391170809345866, 38.03836537945656, 39.43210117278561, 41.148667643147135, 44.029785817669286, 48.960801324536725, 51.49240101537397, 53.44810262803109, 54.021156987836285, 53.01908554569368, 51.16699726350846, 52.40112004741546, 54.534712914497625, 52.849011575022054, 51.68907257818407, 41.03727625262353, 42.022693311014486, 50.32580575635357, 54.62928518172234, 55.86266663766677, 55.00930793823735, 57.07774631438717, 54.65630246746925, 56.02123629662299, 56.615134131523874, 60.064411547876176, 59.269778574666674, 56.29810071760609, 46.842015404855054, 38.84949191924065, 18.548158984030447, 7.828976338909519, 3.0521916141433105, 4.0812266545911, 9.6070965643852, 6.4225820764418575, 6.637042078279681, 5.368128851536782, 3.2679114322508536, 0.4980046788771307, 0.25817552220917517, 0.43401687856643434, 6.7945350466236, 17.93654380306121, 47.0722742234507, 53.59892560589699, 37.564550907381125, 57.68561563184185, 60.27275608431909, 44.15425439034739, 8.33632609536571, 0.10972840516197105, 0.10632197222402019, 0.0976033017580067, 0.05029793167787214, 0.0201187654954171, 0.030908991334839698, 0.0024272792037546395, 0.03900865701237514, 0.026986477521037864, 0.050861033115295634, 0.02970011225120435, 0.03939581869710838, 0.17100214747892273, 0.02563357007719817, 0.015814278327349215, 0.007319236108507481, 0.03272111677835065, 0.06205573805697984, 0.049177631510481726, 0.053877630721657514, 0.03892852038505577, 0.0553142064581475, 0.08028082804934633, 0.03442657788494422, 0.16575375571846962, 0.15896823918146474, 0.14169730786834994, 0.10606592265708793, 0.20916345379044934, 0.16056138030703992, 0.08447276924045817, 0.08628011621054142, 0.13163184717057214, 0.14855724218631947, 0.12902693372339974, 0.08239172969854648, 0.1550439691110965, 0.1303180523457066, 0.08556842052888486, 0.17628024812907944, 0.12229626142089406, 0.18848163856854364, 0.12415816151206532, 0.08014336889309269, 0.1530064050588877, 0.14828664460970511, 0.21819319425811692, 0.0957246243412937, 0.1572341838430974, 0.15070210451320296, 0.16322673809143806, 0.25351395379872094, 2.328689353119943, 23.43291013471542, 59.406622225238436, 66.65673517411756, 57.81546961876654, 52.3403743005568, 40.28215723652994, 42.08706725028254, 36.250090137604744, 9.196241036538156, 1.5035903501895167, 0.36655915961150204, 1.7400135412331552, 6.782186444728606, 11.92095862280938, 11.439872076434474, 12.230195345417147, 13.049320578575136, 7.9036131597334345, 15.385782353339659, 29.09776383830655, 42.13726966611801, 57.20454085257746, 57.779132781490205, 56.20286949219243, 57.621496646635, 54.17072872961722, 58.55333020610195, 56.16763091856434, 52.79426705452704, 46.89459085464478, 43.26046389918174, 49.26360437946935, 50.387516406274614, 52.656234925793065, 53.32011961167859, 53.74338649934339, 49.492984587146395, 51.45574646611368, 51.87674622381888, 53.73792656006352, 55.63311776807232, 55.51354039099909, 51.406250076909224, 44.319241046905525, 42.142086336689616, 43.7667908976155, 43.55861502309, 42.19195927343061, 44.05896432938115, 43.8671447384742, 45.63461572893205, 49.53923717621834, 53.394177882902085, 51.58146627487675, 51.31353701314619, 51.514621242400146, 52.57774045390468, 54.91255091082666, 51.149550560982, 57.572286590453125, 43.92316402927522, 47.325443606222834, 55.720602312395656, 55.30668243285149, 54.379088955540816, 53.81259279866373, 52.74243685507005, 47.18207313168434, 44.83973956877186, 40.52478328827889, 43.50982073814639, 40.39517641067505, 39.42180887345345, 39.55384369819395, 41.920645006241344, 43.016272821734034, 46.66654033045615, 51.72797856792327, 54.60743757986254, 57.783192434618556, 58.035840142157774, 52.45970456830917, 50.740816054805634, 53.07325347777336, 56.696656673185295, 55.74897673822219, 53.69761636180263, 43.28409617946994, 43.80056250479914, 53.38345412285098, 55.34289375428231, 55.15695771863384, 57.49226239419753, 58.860691055174804, 54.76961974174746, 58.01058400061823, 58.4534352825534, 61.15892933261011, 61.3674739099318, 58.15443300431775, 47.891127832474254, 40.85154025785385, 21.757577580790368, 9.01461862748669, 7.116888665383862, 14.177146150219826, 15.977839616037185, 12.940031578463893, 16.723056608630767, 11.212537384802296, 6.293204657493099, 2.580550870587749, 0.39406389178287604, 0.7310803414833161, 7.4622548299451035, 21.009895378543487, 48.69893212472239, 74.33665752410889, 54.0235927797133, 63.74521863075995, 68.35716109122, 48.225317693525746, 10.296976758587746, 0.3691646246419799, 0.17989356311098223, 0.13994573976003355, 0.18043376234990938, 0.15713442387359758, 0.12458480353797637, 0.13578690888900913, 0.10603544001858081, 0.1966685903889518, 0.11813363075376519, 0.16416824482862027, 0.1200019813052589, 0.26099212107158476, 0.11878769364087813, 0.09094264989178028, 0.11848721863521684, 0.221229690998312, 0.13919790005010946, 0.21280980248364711, 0.10069999768729172, 0.07719346307097905, 0.09192698860480901, 0.2076559612948087, 0.25444304991152983], [0.04216453706425044, 0.048579427924367695, 0.04616278441502683, 0.06361339782034198, 0.1102489389238819, 0.08287181401805532, 0.030127616126030207, 0.09136543083455294, 0.08711263161873625, 0.07135186644811785, 0.036262342886578654, 0.04481783662472041, 0.08382940094076818, 0.004348668416271046, 0.049888695169600754, 0.022525499657457395, 0.023622342212606343, 0.023434882412754723, 0.07076510438515295, 0.016490220685579603, 0.049344175194780675, 0.03003530827681384, 0.02254094015957127, 0.039515378209011215, 0.015110578688402331, 0.05813641308416283, 0.029002506841695117, 0.048298936322211265, 0.37019875140920766, 11.754495193881374, 38.17080813069498, 48.83718390618601, 44.8870276635693, 37.88748748840825, 33.52083436904415, 32.12445293703387, 20.380141196712373, 10.94158201448379, 1.4742767618548487, 0.2165509009313199, 0.012470056516899457, 1.314318338709493, 2.847095535647485, 5.954378064601652, 3.5132647570102447, 3.1635295623733155, 5.189506075074596, 11.512585955281413, 23.44674433431318, 35.006412459957986, 47.263827093185924, 58.35739604888424, 56.770114821772424, 45.89878343766736, 48.2422270313386, 53.63038693704913, 51.12296081358387, 47.51696509699668, 40.50465760692474, 41.31977711954425, 43.84998044660015, 49.66086595289169, 52.40488160041071, 55.43659917769894, 51.71231654382522, 48.62696055443057, 52.96186600961993, 52.24485281975039, 52.93042821268882, 50.20963299658991, 47.70267363517515, 42.96066930217128, 37.74034369376398, 38.540342469369214, 38.85257882456626, 40.47022704155215, 40.17846938102476, 38.689600421536355, 39.137460570181574, 40.101904715261156, 40.8284100409477, 41.033267590307425, 43.03931674649639, 44.642448271474535, 47.160421648333156, 47.73439384275868, 51.35751070514802, 49.184717670563735, 54.489570356184444, 39.874152291205625, 44.66312308465281, 50.69731696959465, 51.62281982360348, 52.114206514050885, 52.64938254510203, 51.29167764417587, 50.89083494678621, 48.312406078461684, 41.608530244519635, 38.12727374415244, 36.24965083214545, 37.648524930400235, 36.78399532072006, 39.81950582996492, 38.80292554055491, 44.12475032191123, 49.7201878793778, 51.43014907836915, 52.02225439010128, 50.15437856797249, 50.0950684085969, 50.42283734967632, 53.23501986842002, 53.00909526886479, 51.28671976827806, 46.045915465201105, 40.2172145535869, 38.43377167178739, 50.17190764027257, 53.09089629880844, 51.99734733950708, 50.45402803728658, 54.92198813346125, 51.75716884674565, 55.053085511730565, 48.88324037674935, 54.85626489885392, 51.15644608774493, 55.905302801439845, 43.301523270145545, 29.00428591235992, 15.481658808646666, 9.179288552653405, 1.4566892217243872, 2.189563128256029, 8.343592286109924, 5.547275754713244, 1.9296075547895126, 3.3082262883263254, 1.6004573265391013, 0.30843582364820665, 0.3115341283621327, 0.8833142694446349, 6.674189865589143, 25.684638907832486, 33.61049190644295, 42.625498848576704, 39.16849436298494, 45.34918485149261, 51.24422088746102, 22.02253760830049, 4.352579164889551, 0.07329989014373672, 0.02245443925682095, 0.13213243966381397, 0.06226898629158255, 0.06521238419677942, 0.019734030394184015, 0.05991346127684078, 0.019153523439120863, 0.0667569859914722, 0.008465251453491229, 0.03758377943848891, 0.05084205711741121, 0.022404459680640892, 0.04490199138320262, 0.03164618433783612, 0.030575093828261863, 0.010982461239872201, 0.048793526516566356, 0.0639841422408579, 0.07854196167881451, 0.03273800135620179, 0.04740185885419769, 0.008185058625625267, 0.09979805173051935, 0.03733218850327596, 0.09220166943005978, 0.03902047774904678, 0.021685120356719823, 0.017112701598014084, 0.014767330121098748, 0.025669419161614873, 0.012891890383475732, 0.045020604776518966, 0.06662432254562456, 0.059833849419749556, 0.03314020517732828, 0.040289782017709753, 0.018697268284496762, 0.041522015291716785, 0.0036167346068748064, 0.026011446776289134, 0.03969696019926379, 0.013545227402280416, 0.02559981815847418, 0.017524131032968723, 0.03928528370095357, 0.03918346295493745, 0.04352935334487308, 0.00659218275799386, 0.0359294623617203, 0.05425499031139959, 0.06569059926175302, 0.6822519196617989, 14.226707258532125, 44.35542491174514, 55.24557975030715, 50.918899505369126, 42.921143577944854, 36.772985227646366, 38.59331407854634, 28.998412163026874, 10.784724470107786, 1.539436891194313, 0.25628133917287477, 0.312833811847433, 0.8890283660542582, 3.0769052428583947, 5.872056340017627, 6.407523116757793, 5.341050769052198, 5.721192177264921, 12.056149974946054, 25.5658636554595, 38.22702354000461, 48.44004392623902, 56.29901070748606, 57.777665815045765, 50.240678556503795, 50.24197293866066, 56.53243880118094, 55.24059441781814, 49.52405760365148, 43.324198492111705, 43.16744881291544, 46.189788003121656, 49.3307553568194, 53.25864430396788, 55.355821886370265, 52.330658589639974, 48.77610868023288, 51.563654791924264, 52.1461267625132, 54.742461250674346, 53.23610636495775, 50.49682894060689, 45.68912882958689, 39.70153662466234, 39.529038629224225, 39.93115609691989, 41.09450363343762, 43.0422624464958, 41.01830767047021, 40.82882188981579, 40.711095871463904, 43.15754875060051, 45.07910613090762, 45.018230945833274, 46.74840411832256, 47.46588407024261, 49.374913400219334, 51.11904236578172, 51.42432043629309, 55.46706030445715, 41.529086559049546, 45.632430968746064, 51.388065968790364, 51.963536508621715, 53.41285228729249, 54.540451342059725, 53.32051969343617, 51.83455721024544, 49.592557876340805, 44.10831559088923, 38.918207922289454, 37.48311073549333, 39.13877064181913, 39.281015396118164, 39.99477694111486, 40.91437270564418, 46.00412261101508, 51.806061190943566, 53.02210969309653, 53.37949645134711, 51.29500773645217, 50.881535007107644, 51.69468548990066, 53.40072431871968, 55.79044011331374, 52.67709801273962, 48.889076863565755, 41.01447159244169, 41.74340486526489, 51.760938244481245, 56.15840158154888, 55.665410641700994, 52.78045638915032, 55.38227435081236, 52.286994764881754, 54.944635898836204, 52.812388404723144, 56.96631570016184, 54.79325986677601, 57.16419927535519, 45.77375004368444, 33.15941933662661, 18.435028022335423, 7.417535397314257, 2.500395274931385, 3.929809682792233, 6.826772516773594, 6.868799732577417, 6.805261748452341, 4.612547486059127, 2.1705602253637006, 0.8256517506895528, 0.09531286740375143, 1.233359637760347, 6.593497885811714, 24.914665875896333, 39.18898874713529, 57.46535885718561, 44.83611922110281, 51.293379952830655, 58.714304277973795, 29.054353006424446, 5.6777264322004015, 0.10189229096736639, 0.02699154519265698, 0.04095687989085432, 0.08756201113423995, 0.058442974658382524, 0.025947572280382438, 0.061463854696241126, 0.10630441348879568, 0.012333585614068134, 0.02073649857794085, 0.05189216064829981, 0.008728846986477655, 0.05864301936761026, 0.06730045642583601, 0.022537324224568667, 0.06044820213930742, 0.029059547833317233, 0.09522935615912562, 0.02709435419209542, 0.05563856042440861, 0.040949529277220856, 0.0472121141971119, 0.028219425172034292, 0.06974357210340039, 0.1742498699816004, 0.14849718089305586, 0.17162624866731707, 0.10664361423902935, 0.24727076622507266, 0.14888563343594152, 0.1383210511337365, 0.08939853073247979, 0.14540069946838965, 0.20244385145844954, 0.1593189695549588, 0.10682426543245394, 0.15803794797149398, 0.12070435369687697, 0.09926421868224299, 0.08924093112469682, 0.11444310176997416, 0.13479019785600324, 0.1983057968919316, 0.09909715788859515, 0.18611145446137076, 0.10728222513270956, 0.15223409650066208, 0.10259965059137154, 0.07943090712351185, 0.128139206358502, 0.17349384845264498, 0.26590390911986755, 1.0129341398996692, 15.583711035789984, 49.258564133797925, 61.47025962029735, 57.70891058829523, 50.077715842954575, 44.87610778500957, 45.099137675377634, 31.05553842359974, 14.528566002845766, 2.6148257668941253, 0.512777152321031, 1.1707741767168045, 4.942007458979084, 9.00321727798831, 16.339793974353423, 12.94817049657145, 6.669445758865726, 9.638858937448072, 15.780002128693367, 28.853592372709706, 39.3848366122092, 50.337200241704146, 58.341981134107044, 57.98389619396579, 51.89127076056696, 54.27824481841057, 58.135782134148386, 56.6777547713249, 53.39770801605717, 44.651865882258264, 44.777942626707016, 47.91410507694368, 51.8652811358052, 57.266624127664876, 57.96100524164016, 53.67612961799868, 50.45946051997524, 53.69403916020548, 54.99672497472456, 57.55751494438418, 55.88231771223007, 51.74147936605638, 47.14199827563378, 41.132354505600475, 42.53471951330862, 41.79647453369633, 44.592959727010424, 44.093630236964074, 41.56602351896225, 41.75665070933681, 42.64668749224755, 45.29115338479319, 46.39416702332036, 47.31288417693108, 49.506520686611054, 50.64007782167005, 51.59308041295698, 55.76825518761912, 54.87683773040772, 56.6494744823825, 45.15250544394217, 45.40161125121578, 50.66757755894815, 55.799300747533, 54.53115924712151, 58.70831874109084, 56.33285291733281, 54.170575757180494, 53.578513591520256, 46.863404089404696, 41.4705491065979, 39.22227398041756, 41.02379114397111, 41.95893126149332, 42.8821591408022, 42.91530316875827, 49.34270289636428, 55.25633488931964, 54.815327121365456, 55.37286850713915, 52.47611184273997, 51.59423751215781, 50.79822778701783, 55.233055622346946, 56.97568232013334, 54.19698899792087, 48.83775657223117, 42.93633099525206, 43.15695647270449, 54.871915155841464, 59.02606602637999, 56.307651688975675, 53.83549551809988, 58.60356792326897, 52.93727274863951, 55.00599353544174, 52.313753174197295, 58.273665212815814, 54.69560069422568, 59.310783032448064, 46.499694470436346, 34.45834752052061, 18.496303289167344, 11.17519740135439, 4.455108450305078, 9.652771584449276, 16.263516622204936, 15.227919701606998, 10.337098683080367, 10.957736296038474, 5.700750745111897, 1.3987895221479478, 0.7564000989640913, 1.6522972093474482, 8.920511161127399, 32.38665946068303, 44.60872765510313, 51.12496122237175, 50.44323759694254, 60.772744532554384, 65.85912904431744, 34.77342367172241, 7.334723376458691, 0.21859278571942162, 0.09343335495120095, 0.20297913241290277, 0.16924267334322776, 0.14463445832652433, 0.16515732562590033, 0.18742809913331465, 0.1982736365208703, 0.14478805895534255, 0.2298855652371722, 0.11784042592250532, 0.09951598581767852, 0.13910966204299083, 0.16154872974561107, 0.17251435907617693, 0.2124613397304089, 0.17789070284174335, 0.19299404966014047, 0.13723058626055717, 0.15840090510825958, 0.10548148950141285, 0.2585513343013102, 0.15054058253524766, 0.13924835460080257], [0.05928325819812956, 0.07109473669721235, 0.006679577589590824, 0.025309478496051124, 0.03835523380867897, 0.0917494630501155, 0.02636159875340039, 0.047787951846276565, 0.00876688133669837, 0.06469059405067275, 0.01867117916023539, 0.019003301258048704, 0.005709420600455375, 0.020321918606397607, 0.05191987004852103, 0.05118936690832338, 0.07431122579521711, 0.03357194934881503, 0.04041606012070852, 0.07672170612720713, 0.024325183833078034, 0.015700785274196778, 0.057884159482895374, 0.014338373552046478, 0.04963251919816098, 0.05269146231453746, 0.057310608606184685, 0.04602840493222879, 0.031324136296227094, 4.57047418240578, 27.30998673746663, 49.57268714904786, 48.31313171694356, 44.974265098571784, 37.83579457190729, 29.523409643480857, 39.315489107562655, 18.554362212457967, 3.3829663165154, 0.1552044951747502, 0.12265043152916817, 0.5359875326675754, 2.5903327715012336, 3.613045196379385, 4.6905859824149845, 5.202187097841694, 4.318690376897012, 10.754581055333539, 21.00741251822441, 36.32426215756324, 59.5717461647526, 56.19764097275273, 48.33909388511412, 56.20687815450854, 55.02741752132293, 52.618042807425226, 49.595107416952814, 44.99555180149694, 40.90590430844215, 39.98002882926695, 44.1378745725078, 48.01541597612443, 50.86196630231796, 52.48466653208579, 47.079252119987245, 49.21186047215616, 51.238290263760476, 53.211113022219756, 49.69276658950314, 48.301352839316095, 43.672206863280266, 38.10956816519461, 38.673318662951075, 38.389746988973315, 38.8044003517397, 41.33970668238979, 42.069953949220725, 37.92266330411358, 38.65045516721664, 37.75642541147048, 37.927997727547925, 38.25702182708248, 40.64342321888093, 39.42860634096208, 44.72868942445324, 47.540695436539195, 50.49779384366928, 49.29206901980985, 56.380082176577666, 39.22348991517098, 43.27006193899339, 48.23297023773194, 50.95334576022241, 50.50000606044647, 45.587841464627175, 53.991617618068574, 50.6916844460272, 52.083965040022335, 50.00799963551183, 43.45878285746421, 36.0814360649355, 40.28105897288169, 36.15311345746441, 40.09286365201397, 37.941459301979314, 47.113623849807254, 49.68755375954413, 53.203609528080115, 49.54253196716309, 50.49893133101925, 50.30658222013905, 51.21938836190009, 52.25748677407542, 53.218137987198375, 48.9395381558326, 43.3965701441611, 36.66528870982509, 39.02882660588911, 44.39907304702267, 51.34617505535003, 50.61775953538957, 53.9343745477738, 53.730466211995775, 53.85308342595255, 55.75678617723527, 57.97377255655105, 49.619084865816184, 55.29623323871244, 48.38435411453248, 43.14952358122795, 28.223746015179543, 12.3858134208187, 4.358641678287137, 1.6024799212332697, 1.697858480676528, 5.400160887549001, 5.160092711448669, 4.385037268361738, 3.9481470084959462, 1.7730955467108758, 0.4901396218807467, 0.2367436762658819, 1.2626272608195583, 8.99422916673845, 22.926553718505367, 33.98405451928416, 28.686944592383604, 40.30043548153293, 53.45831255758963, 42.62204716282506, 17.35490925850407, 2.5615604702503454, 0.09596660853393617, 0.04444008249969733, 0.05969414945631739, 0.008177539472648454, 0.09616075053570733, 0.04283160429387804, 0.04898809369713549, 0.03801509460073806, 0.028533277988073327, 0.025454533414074013, 0.015215238747787813, 0.07769836097835534, 0.028218936790982564, 0.04399094813232941, 0.041612306414472486, 0.03585871031147338, 0.05141013046546329, 0.04685412897097488, 0.05347699355033617, 0.022226928380287947, 0.016871406884503462, 0.009656260578682827, 0.02971898291199919, 0.06436163589598672, 0.025370993441151037, 0.04427908146153054, 0.0653261712361728, 0.07446337851785845, 0.03421540191817669, 0.0444560247894016, 0.0296112077475916, 0.014949903237603366, 0.07928907360521056, 0.037308424455864776, 0.023348312562091217, 0.04802655759117296, 0.049771644595649936, 0.03920372598053467, 0.03522558460733102, 0.0663602367163666, 0.012133367577447526, 0.022274967838799762, 0.03699706334079947, 0.060930910309956926, 0.023184339102778225, 0.04047836988202987, 0.04756550672614286, 0.023797014089781913, 0.0707766569910511, 0.03071570543632392, 0.0524370598366424, 0.018005232334197048, 0.10383408636816087, 7.440351334310348, 33.72935541214482, 55.37522585161271, 53.55633651056598, 48.87969455411358, 42.336761413082, 32.34186403213009, 34.10239634975311, 19.703502924211566, 2.960947232861673, 0.16108570620417595, 0.14444417740789153, 0.6841023590776228, 3.4343785384008965, 5.8347938233806245, 5.967972019026357, 4.610867731032833, 5.534960983260985, 10.04227667085586, 22.2161752177823, 37.10963833716608, 58.17143255664457, 57.97728700022544, 51.84030348254789, 55.29865726347893, 57.06222941798549, 54.586488200772195, 52.82290427915512, 48.62230077866585, 42.07113850501276, 42.9027751184279, 46.43545389175416, 50.56200304339009, 53.010071939037694, 53.829788469499164, 48.554420240463756, 50.539547474153586, 52.73347423922632, 55.789565424765314, 52.21587042654715, 52.332635464206824, 47.28410182460662, 39.33257495203326, 39.70302712532782, 39.82321246977776, 39.65931623212753, 43.687358979255926, 43.832372926896625, 38.62984311196112, 39.72579648417812, 40.1449135042006, 40.778913651743245, 40.58836098640196, 42.96104977207799, 42.210782727887555, 46.71560133657148, 50.484061625696, 52.866497501250244, 51.20834688986502, 54.54188692954279, 41.4440691855646, 45.083106948483376, 48.55352594006447, 51.07401355620354, 50.90165284372146, 48.776453848808046, 54.34706280308386, 53.40581163283318, 54.4600349087869, 50.39298026792465, 44.3434303037582, 37.23877453034924, 41.959904009296054, 36.93991345743979, 42.45007868736021, 39.66268162573538, 49.218665784405125, 51.5157038165677, 53.76739532716813, 51.4430340643852, 50.70576575494582, 50.01187101487191, 51.74464079641527, 54.425604343414314, 53.796467934885335, 51.51784150831161, 45.595933314292665, 39.810539291751006, 39.845271879626864, 47.370582242165845, 52.42846681225685, 53.28723446015389, 55.15416106870098, 56.31218987126505, 54.781398619374926, 56.6314668809214, 55.932618187319854, 53.67583544023576, 57.56131179871098, 53.289854603429, 45.65318422932779, 29.770305195162376, 13.272180826433244, 6.589540704604119, 2.918086513396233, 3.8214640127074335, 6.661065124696301, 5.982475963331038, 6.1775471991108315, 4.589614368254139, 1.0828109806583774, 0.4419260622272569, 0.24873243134108283, 1.3467460438128442, 10.642423822033791, 26.25506331843715, 37.010708316679924, 30.30399072554804, 45.43996810913087, 57.40442875892886, 49.422585887293664, 21.708181212025305, 3.405480476156358, 0.08853947037770864, 0.056725968606770046, 0.0965530181964559, 0.017487042801334493, 0.023329736845147227, 0.0242654902620181, 0.05553839059786932, 0.01716041163871846, 0.007927660265141318, 0.009425303264100467, 0.04409295656988698, 0.04022773655672227, 0.09284716745417926, 0.005998862503592166, 0.04005099624215115, 0.03676314605399966, 0.02261821161805382, 0.07252889159586161, 0.0612473659097187, 0.02074483361455702, 0.02178162253732162, 0.00988884678771419, 0.0264096190597141, 0.024437277818158753, 0.12898046282991288, 0.11956931016738377, 0.131227919651616, 0.14529188433962484, 0.12816968899700912, 0.2607881271791074, 0.12490625403100446, 0.141750474370295, 0.15911004205624904, 0.1542131314354558, 0.12162545185175636, 0.15659005711636237, 0.093915875430309, 0.1635943377210248, 0.10632280725985767, 0.16562126847284456, 0.15307257973378705, 0.17914327191970042, 0.17265052354383856, 0.1144271594802699, 0.08293698511777386, 0.08242169139726509, 0.11627025211290007, 0.09025814267055643, 0.1744413000321196, 0.1918307451471206, 0.15642544014319298, 0.08605258043615088, 0.19313591382195874, 8.336559476390962, 37.27719806855725, 64.04459745653214, 61.963340774659194, 56.422584979764885, 50.60005395643173, 41.41899347305298, 48.57329860810311, 23.550465529964818, 4.264092454987188, 0.4981532080038902, 0.5792125422627695, 2.739589988223968, 7.871825781560714, 12.45251234500639, 12.091807261590036, 11.847762292431248, 8.828207004454828, 13.00819746909603, 25.118221198358846, 39.38679779729536, 60.872027566356046, 60.10547484121015, 53.95058178132581, 58.18567468274025, 57.910951875871234, 55.91659530516594, 55.0460252454204, 48.328185773664906, 44.95423355410176, 45.28644261821624, 48.770017239355276, 52.614853920475134, 56.004428940434615, 54.02163943936748, 49.47856987676313, 51.61406509337887, 54.71799350553944, 58.80374608501312, 53.995783175191576, 53.43921845959079, 48.082135492755526, 41.2917164833315, 42.80877551724834, 42.293591806965495, 42.29365456488825, 46.05730210581134, 45.6163727852606, 40.3834955923019, 42.03871227079823, 41.10159527870917, 41.65902683811803, 42.986949182325795, 44.67640815242645, 44.92260748340238, 48.700932533510276, 53.69812626992503, 53.45585323149159, 53.4648197697055, 55.69893121719361, 45.123005297876176, 45.06549942877985, 46.981483121072095, 50.71086483616983, 51.5400028997852, 49.50737184093845, 54.97123741334485, 56.19796260710686, 57.41777658462525, 53.83046703953897, 47.5585186866022, 39.3503511336542, 42.89541282961446, 39.30620093499461, 43.96161894644461, 41.733999021591686, 51.137434359519716, 54.3944489571356, 56.05106984415362, 52.324684819867535, 50.856106281280525, 49.91412947254796, 53.02984460707634, 55.295421308086766, 57.28709889996437, 53.92975791808098, 46.51869050918087, 41.203098374028365, 42.00521130715647, 47.1976214070474, 53.66522542891964, 55.107241676699736, 58.074502944946296, 58.49995851516724, 57.509120741198146, 57.87730578453311, 56.70810999408845, 56.03790636985533, 59.70500476898686, 57.12044131371283, 50.082077518586196, 32.21843488754765, 15.312750762508763, 7.821558646617397, 4.585086482186472, 6.891422492842521, 14.174904515666348, 10.968927798732635, 12.423346580997592, 9.43743150080404, 5.345324191354937, 1.6436395577846037, 0.5070191129080711, 2.2814417077649027, 12.742113682531542, 30.032931412419966, 44.38447790761148, 39.5489917262908, 52.13865464733493, 67.48853652707993, 57.25714768132856, 26.006414467288604, 3.8653859784526214, 0.20625132376388197, 0.10803252398487061, 0.13359093317581763, 0.13684319091900704, 0.1638421058774956, 0.24456512753761586, 0.2742392215276918, 0.10834749337405929, 0.10208189772862582, 0.0888797436510363, 0.09136122501184864, 0.20213488819858721, 0.1608646438727456, 0.20292464823972797, 0.14052695534642667, 0.08942345923353588, 0.12201490796982281, 0.16304506800107418, 0.13707283343518936, 0.09425024216574046, 0.07781857549543343, 0.1577662012629932, 0.139476802019823, 0.2412671343453469], [0.14402687399377748, 0.04129688503340848, 0.03335846362695579, 0.023897620586438045, 0.034828567201451915, 0.04794144905322502, 0.10258670370545118, 0.06155510725934179, 0.007160234559823069, 0.02121716895471177, 0.03991863540103359, 0.09432578609595377, 0.06468610477543647, 0.06977137343417253, 0.03607069450100103, 0.027171441789476142, 0.04506394237039551, 0.059715875709849986, 0.06339015213832741, 0.03982314637171165, 0.062426685490795684, 0.04733044413789626, 0.024053885286012967, 0.07325675173272049, 0.024549214755214994, 0.030316274853483326, 0.10903709507997959, 0.0320471681639432, 0.028041867058603998, 2.2145505874387683, 25.09337886687248, 52.29857360163043, 51.7302417755127, 48.885370223752915, 44.217428084342714, 61.82713647042552, 53.973786523265225, 25.327695377411384, 5.075301854841171, 0.5067917380121447, 0.1225746960769738, 0.40666634457245954, 1.6398940619922455, 3.375806274913973, 2.8539251175618943, 2.778387622487161, 2.444960662434178, 9.745049265123184, 14.314967451557038, 33.420225574124245, 45.89843434672202, 39.79979591984903, 57.04372759788268, 55.93940388771796, 54.831710861575225, 50.554295586001494, 51.77692190293343, 41.4716552149865, 41.40805790501256, 40.92165654705417, 47.8579249689656, 50.53499360238352, 52.6379527584199, 49.56891382894209, 50.98567001281246, 52.998230303487475, 54.59351708812099, 51.04588623969786, 49.41096390447309, 42.16658153841573, 38.2221362667699, 39.31300624724358, 39.695978626128166, 40.059547039770315, 40.3541091949709, 38.045025564009144, 39.336509089316095, 38.72706690142232, 37.89424573221515, 36.294816924679665, 40.44031112424789, 38.291315109499045, 40.88860665598224, 40.70315699423514, 45.3391828075532, 47.506484523896255, 52.865336479679236, 50.16405897755777, 57.112357308787686, 37.02797066780829, 43.40909034975114, 50.12717300845731, 49.80240468055972, 50.44501835300077, 49.86875549439461, 52.99562192732289, 53.313000509815836, 51.25213623046876, 52.25013233000233, 47.142841585220836, 35.26701081183649, 36.23549107582339, 37.45661120260916, 35.89615506510581, 38.79027197437902, 47.272079760028475, 50.1414700477354, 53.446623894476126, 51.58075240350539, 49.69228021560177, 49.20465900051979, 52.64447566001646, 52.31047015036307, 48.95893819870488, 47.723830899884625, 42.681388701162035, 39.68763182240148, 39.316850170012444, 39.16146547563615, 46.97477194570726, 50.774524904066524, 49.50701490525277, 50.90747756342734, 54.56955925110848, 54.610446037784705, 54.76596801511703, 56.130333100595784, 50.00526574350173, 48.994227763145204, 31.893507703658077, 24.747161057687578, 10.826705598062086, 3.643893166895836, 2.430295655804296, 1.5412601804541004, 3.5258575264484655, 3.686891414465443, 4.5271197345948995, 2.675431043870988, 0.7886989174350616, 0.30768662030177735, 0.2164758243147404, 2.088816805231956, 9.295013181624874, 22.847180635698383, 35.228340164307625, 44.11718014747866, 44.48245479214577, 49.94087219238282, 40.469183691086315, 13.649616779819613, 0.824500535043978, 0.05008534227888431, 0.02771232859231532, 0.05326955609263913, 0.07442528862626323, 0.03295762727277414, 0.06678054319514383, 0.09667319440913778, 0.03319785712407001, 0.06345266874338831, 0.06399985470418489, 0.06656744817812597, 0.022026370392150937, 0.01697024754849413, 0.11297158476325775, 0.009221855209269112, 0.02947312614489948, 0.057137461243978435, 0.020854569964050766, 0.038937855166413134, 0.12718839165303977, 0.014133767746839554, 0.016507243159257116, 0.045199926807394916, 0.05712398575739034, 0.08450187292070159, 0.07754306729522444, 0.012781435826552973, 0.06200890327172895, 0.03813643143662522, 0.09208940690563572, 0.05796026648773302, 0.07732859331994288, 0.030683351628061746, 0.020847621546577544, 0.029820962621259595, 0.01898531925924603, 0.03528699804578097, 0.0446183511596774, 0.01806384955172337, 0.049347174429004236, 0.03896284495450316, 0.02733810038696374, 0.056193246385983886, 0.05776225191150462, 0.06883362818869852, 0.0735410699440587, 0.02431304900035743, 0.0969208246697822, 0.023818784393370155, 0.011030685517095752, 0.05255466965477794, 0.01617079457989143, 0.09068837764883235, 3.1464939732705397, 28.464612883906213, 58.43059532104, 56.59043104417863, 54.466251865510024, 43.97657494391165, 53.30944292006954, 54.90629080803164, 26.071298314679055, 5.929322944533441, 0.41665876644753647, 0.2083263954808635, 0.5800144218148724, 2.527312049942632, 4.5259312564326875, 5.575971324597636, 4.788382928217612, 3.309491252706897, 11.498975330783475, 19.579122604862338, 37.52470354880057, 51.40920362164898, 44.40950655168103, 57.19671180171352, 57.41454847397343, 55.94772715722361, 52.91098894611482, 53.682115154881636, 44.71689093497492, 43.66581732226957, 43.864587353121856, 49.430716960660874, 53.10966876245315, 54.87425288846416, 50.39176433317123, 51.95808833645236, 53.441826835755386, 56.63174144683346, 53.40521935493716, 50.769712155865086, 45.08651156579295, 41.727511421326675, 39.976381025006695, 41.77896115087694, 40.28841341695478, 41.714038079784764, 41.410670203547326, 41.57528815730926, 39.928567332606164, 39.278230513295824, 39.958569542054214, 41.67041740109844, 40.98995677886471, 42.53679836949995, 42.67264181567777, 47.47468586890928, 48.694182134443714, 53.6629504542197, 51.64577353385187, 56.433461712252715, 40.83201469913606, 44.536622724225445, 49.17012253115254, 50.62235655323152, 50.36395472864951, 49.628745663550596, 53.849525836206254, 53.21738096975511, 52.93038506661692, 53.92957748905305, 48.52554767362533, 37.64285710550124, 38.94451918140535, 39.6416812558328, 38.723525001156716, 40.1583593891513, 49.94825801541729, 51.88079410983671, 55.367271284903254, 52.3287562401064, 50.86961100178381, 50.16303131657262, 54.495473523293775, 53.34547773484261, 50.71814867757982, 50.32072236461025, 43.82325733861616, 40.94388461882069, 40.67518265016618, 40.85609805199408, 50.38063656899237, 52.361676692962654, 51.87715807268697, 53.458696949866514, 57.390347450010246, 56.330307299090975, 56.50500966656593, 55.576121807098396, 53.496669415504705, 51.695297379647535, 36.90307063441123, 26.318633171819872, 10.81903540319012, 4.420418518204843, 4.390653612152223, 5.215210837702598, 5.740182822750461, 6.903108704474665, 6.796835026433391, 4.123344575205158, 2.1680871709700558, 0.5082269884165257, 0.2492598369116745, 2.2638493872457937, 10.334158866636216, 25.904705447535363, 42.91494623307259, 47.97032440862348, 51.18926063660653, 55.72477179188883, 47.005833195101836, 16.98825393953631, 1.0933240358867953, 0.04769189208145103, 0.07319244631235639, 0.011997559340670707, 0.12993140777032222, 0.01766337134364632, 0.09898619771364237, 0.050329364265405366, 0.07669885372442585, 0.03804965665744197, 0.07064761714108529, 0.043712425376138384, 0.06295530914118694, 0.04684383274927255, 0.04240454091960865, 0.0161220905401053, 0.017504716449747645, 0.08008167583255038, 0.06184478425571035, 0.05024859561554847, 0.07592663709675113, 0.04793687167787745, 0.018052996001056126, 0.029493086565766605, 0.11880401897454455, 0.22647302657846483, 0.14616686400146256, 0.11651064284266004, 0.12596650439645016, 0.16538577304492075, 0.1738424184581926, 0.1954655412344202, 0.16458234599521085, 0.13754305820311272, 0.13228570321394553, 0.30153704867247616, 0.21145309141326338, 0.15929989396564423, 0.21925050284593336, 0.136267751635563, 0.13793537182913673, 0.1600954762750095, 0.19947904522620863, 0.1420382782816887, 0.13561311418250685, 0.09005638575481792, 0.2495176101764364, 0.10469817992059455, 0.27850188795597325, 0.19253643469945078, 0.17734071299914392, 0.24075590855171605, 0.11327482534632569, 0.14236380436247395, 4.1796639273243565, 32.03353827999484, 65.5242213895244, 63.619039904686716, 59.4726514047192, 52.499932396796446, 71.95466487638413, 60.951184918803555, 31.029721383125555, 6.504288969501373, 0.8617183121462023, 0.4609856556259817, 2.322960731483275, 6.534560351602494, 8.767933903201934, 9.04184183766765, 8.64847811960405, 5.198286791001597, 12.478156801192993, 23.68349075317383, 43.54964456250591, 54.71981348529939, 48.96537088578748, 57.12890971091486, 60.38173913955689, 59.471341333081654, 55.139675755654615, 56.139566359981416, 46.822423165844334, 44.4983756926752, 45.81591944540701, 52.54904047135384, 56.3288011089448, 56.18927847954535, 51.4168797000762, 51.360997692231216, 53.63585079869917, 58.56246932860344, 55.9694492432379, 52.54461603779947, 46.854614057848536, 41.799592817983324, 43.396797641631096, 44.19655715265582, 43.03870877911968, 44.13701165106989, 42.86235901617235, 42.87292588141657, 42.24726861523044, 41.717081839038485, 41.92370837734592, 43.477163084091686, 43.06006608470794, 44.994088757422666, 45.98485200635849, 49.458114716314505, 51.35099957066198, 57.24723192953295, 55.0557448787074, 56.893893057300204, 43.58380056196644, 45.79723719627627, 48.876897904180716, 50.80158141351516, 51.61637929178054, 50.32122050562213, 56.71029083190426, 54.59005363525883, 53.936398490782715, 56.409358747543834, 51.34462571913197, 39.375379777723744, 40.47297270067277, 41.92694433273808, 39.927155279344134, 42.204950163441325, 51.99784940288913, 53.96003077107092, 57.66536051227201, 51.65956458737774, 49.61647648965159, 49.33860794190438, 56.27125601614676, 55.37519447265133, 52.470424405990116, 51.58492972773891, 46.475540514915224, 43.99540232073876, 43.90182241316765, 43.25414888320431, 52.2983931726025, 54.08069464468188, 53.43401347437213, 55.58135032653809, 60.270983173001206, 58.821486965302505, 57.85842349452358, 57.66432892891669, 56.63594622765818, 58.01034081366755, 42.37905633065009, 30.57109432835733, 12.893622094585051, 5.072395378543485, 5.561849321088483, 6.696448335724493, 8.261061695314224, 11.319660255985877, 13.052429056936695, 8.50406527519226, 3.570045477920963, 1.0683002947799622, 0.6063897871682721, 2.8364489972591405, 12.4929617874084, 31.386496251629247, 48.92295437474405, 56.6514866582809, 57.41686659474527, 61.36140208090506, 54.52227115631104, 19.925744418174993, 1.8799760889622474, 0.168349139031864, 0.2655320806849388, 0.22440763821284618, 0.22914354779547264, 0.20560423993775923, 0.12727380279571782, 0.15888101241040617, 0.1768232665715679, 0.14859539336494862, 0.12424932597505471, 0.10764974049262463, 0.17501883839647617, 0.06910176662307593, 0.2237353654157731, 0.11727738194167615, 0.07127968564389214, 0.12873165279386506, 0.21220286166475666, 0.15597959229302022, 0.2387292689133075, 0.14027610751650027, 0.08366750357972999, 0.18962419742057401, 0.1490227784961462], [0.026784356713535327, 0.07457713491373485, 0.016412646622366963, 0.03690183478137178, 0.048934233885618954, 0.049832242150460525, 0.034695700742304325, 0.04255310835076436, 0.05924556667225496, 0.08355163278118258, 0.026672023325978268, 0.050504392373465726, 0.07837067207982464, 0.06834147798438227, 0.09575152934919443, 0.02258858699802189, 0.033106259821403416, 0.06523845416884269, 0.04755588849225352, 0.027546966598639568, 0.01100908662568057, 0.02120566805974851, 0.0827933129884543, 0.059891911223530776, 0.030326879425575177, 0.024296917103891893, 0.05324596441501091, 0.05708380444576183, 0.014460252395140068, 1.7167292487236763, 18.912690339549897, 45.534658047460745, 54.60838679344424, 37.68477547553278, 56.563398068951024, 70.70895148861793, 72.4071494994625, 32.732253613010535, 6.039576847707072, 1.0654059533149967, 0.060769893950031656, 0.2634491489058541, 2.6346013767103997, 2.900105387933793, 5.166942640658348, 2.368369765820042, 3.223539619676529, 8.262320776139537, 17.39043220396965, 29.469271129177464, 31.86480183755198, 55.50697826570081, 58.38513505074286, 55.249333458562056, 50.72256134402368, 52.15434805039437, 46.21022747408959, 41.491757362119614, 40.722027517134144, 43.81622845126737, 49.48888178794615, 53.004627689238525, 51.62004670789165, 51.02579978204543, 52.662969635378936, 54.90666735556818, 52.022528956013346, 50.0538678323069, 43.501501391010905, 38.267996618824625, 39.71903431800104, 39.79393589881159, 38.87084922482891, 39.69921458152033, 40.68755380568966, 40.921648702313824, 39.41255600221696, 37.15887977230934, 38.07006205281904, 40.514004615045366, 41.34402128957933, 42.64506363099621, 43.900904578547326, 48.135177704595755, 49.008846436777425, 48.132506570508404, 49.55309491003714, 52.677431414204264, 55.65386710628387, 37.998078715416696, 43.234278155911355, 52.606918965616536, 49.22835403873075, 57.08861912450483, 53.89946545324018, 51.31818109943021, 51.83161935498638, 51.34744590328586, 51.18064318933795, 46.8068435115199, 34.67265798199561, 37.731730168865575, 36.70654812166768, 38.80312165906353, 39.500118993943744, 47.42655838689497, 49.44988558369298, 55.1361220882785, 51.189013527285674, 51.4867724141767, 49.49984481257778, 49.63226402959516, 54.637851638178674, 50.01114145401986, 48.326989450762355, 42.70654678344727, 39.41262660488006, 39.052023503088186, 38.642441764954604, 40.635252921812, 44.44643566685338, 45.82344647376768, 49.07278107058618, 49.47216464627174, 53.1089666581923, 51.95095746747909, 57.72212113103559, 46.9928030813894, 45.13658454341274, 32.02895106807832, 21.146821398888868, 8.345281847061651, 3.1176255739504293, 2.9340294772578828, 3.7707347735281918, 5.468735194975331, 4.404791305142065, 4.708845596159659, 2.4242711403677544, 0.9664985477443665, 0.1037275311987727, 0.4992549037260394, 2.801403110065768, 14.469219561546081, 25.96024620917536, 24.134669226984826, 23.586684696135983, 43.532037042802386, 49.22582410996961, 30.320909869286325, 8.421739628238063, 0.6534837859292185, 0.04852107500717525, 0.007252196711863602, 0.00322070449680811, 0.011245203542432958, 0.029559230597148982, 0.053174986368826324, 0.02213629251796632, 0.07158497168171792, 0.07832278392367786, 0.0398755046508966, 0.045620436299472086, 0.02768195129089779, 0.031055647376624328, 0.09411333459279231, 0.0616163713106465, 0.025628128937715967, 0.051631767362836874, 0.040029193379826127, 0.09813208628686206, 0.09109335470824473, 0.04824758544864674, 0.05949065735143039, 0.048948234142435175, 0.05074121313349855, 0.013014168549899854, 0.06621399819250069, 0.039890811087623726, 0.0638480543819887, 0.03632387123821724, 0.027973606709330797, 0.040195920925226905, 0.023016630964834365, 0.03068301263415525, 0.02109944805382721, 0.03497358764551821, 0.021822487582422553, 0.04750040840477713, 0.058879866940720435, 0.014608336233293578, 0.05369336742366995, 0.028263195605588057, 0.017505342726625742, 0.04469017956345793, 0.026870892090242238, 0.06799910563014208, 0.045164698254196875, 0.03452179878349266, 0.009566041276670031, 0.07918185193932827, 0.05031627182277942, 0.0498653294879102, 0.03322747025278307, 0.0695454694270607, 2.276948142436243, 23.85538274242032, 50.90609296675652, 60.91361645729312, 45.02562853597826, 57.91829847520398, 72.49867408506333, 71.76615576590262, 40.37201481480753, 9.293830587017922, 1.061934655712497, 0.045303716399376436, 0.2919294787270408, 1.313504937195009, 3.5819233953952794, 4.690151579918401, 3.1814069901743247, 3.5455164457521136, 8.429199976305808, 16.843753822388187, 34.00671405176963, 39.97826376268941, 54.25647566395422, 60.8351259077749, 57.03782443077334, 53.60773524930401, 54.40217994874524, 49.39128537331858, 43.423434457471295, 43.498594914713216, 45.43999948809224, 51.92677997773694, 55.84212518507435, 54.27016865822577, 50.27308125649729, 52.32385719976118, 56.431982978697754, 53.107942919577326, 51.75820435247114, 46.482294836351954, 40.50340244846959, 40.844574128427816, 40.93372175770421, 40.61600585137644, 40.55265957309354, 42.934656143188484, 42.67934514630226, 40.578633508374615, 38.77544541512766, 40.244388734140706, 42.776074717121745, 44.78202189168623, 44.4294321921564, 45.98775063791583, 48.66427798424998, 51.65666987819057, 50.61010699118338, 53.14656257629395, 55.71052574342298, 56.41450489720991, 42.022552105688284, 44.380002483244866, 52.77611824773973, 50.37037172625142, 55.587265260757945, 55.122687970438314, 53.408812246014996, 53.22184070464104, 52.648374495967744, 52.912248026940134, 49.849006360577, 36.30171637381277, 39.32965278625488, 38.17502075626005, 39.616699680205315, 40.9909922845902, 49.154840976961204, 52.30144869896674, 55.424820300071474, 51.65408111387684, 50.96408520975421, 49.7383092295739, 51.408046522448146, 55.730623968185924, 50.73485012977354, 49.9248218536377, 44.57079441316667, 41.23413216683173, 40.37974580641716, 40.89591010924309, 42.05748473444293, 47.61914676235568, 47.410531582370886, 51.383021800748764, 52.281150433325, 55.61225468112577, 55.408573842817745, 56.78714183069045, 50.86582983693769, 48.41886704967868, 35.195407944340865, 23.998184473283832, 9.007253396895624, 3.704753152785763, 4.202809833711194, 3.815628996779842, 6.649329883437003, 6.4999439639429895, 7.115106438436817, 4.646514231158841, 1.164974216972628, 0.224028792412531, 0.45938928160936604, 3.2530735961852537, 14.432268873337778, 30.132600799683605, 30.25499051617038, 31.76051582059553, 48.08763857810728, 55.26956504391086, 36.18936008022678, 10.052086518656823, 0.8927609915694884, 0.031050665889896696, 0.006791534157650125, 0.07164402939980069, 0.07446332489170375, 0.037458060579674865, 0.1019827429685862, 0.03263474802576727, 0.06193787542982929, 0.012245793853165403, 0.037037566409356175, 0.014785664520346591, 0.02686221614449976, 0.06834179208043122, 0.06357246574254767, 0.09884138411331563, 0.021381649947274598, 0.09615718822685942, 0.024766551984113552, 0.08400141066240688, 0.03242969310151474, 0.04367374942728108, 0.012304578652425159, 0.07966819519717848, 0.05088826371056419, 0.10685218933729396, 0.176805631227551, 0.15361400471339304, 0.15517198240324376, 0.15804321865641302, 0.21990769903265664, 0.09620338332869353, 0.10820063431897473, 0.11786614349412343, 0.2525852407298742, 0.0831108104677931, 0.11080571630549048, 0.1440501783884341, 0.17863690312350952, 0.15143823839964407, 0.08944925341394641, 0.11755774713932507, 0.19447223163179814, 0.13915797154749596, 0.08510223304432246, 0.18504908969325407, 0.21196787185486288, 0.23897067854000678, 0.13750783348035428, 0.09209215716128388, 0.0948343075992119, 0.1310120054310368, 0.22999644880333256, 0.15168464291960965, 2.768373811437238, 26.685306141453406, 56.016035233774495, 67.11675074792677, 49.1520639388792, 67.89635319863596, 77.59832797511932, 78.31787109375, 38.84590687290315, 9.812857239477097, 1.9869723411337024, 0.18727379370360606, 1.1592900897226026, 6.719382924418296, 8.310728707621175, 10.68441475591352, 6.273403552270705, 7.041054050768576, 13.662470386874292, 29.191635962455507, 38.49076763276131, 43.54002298847322, 57.64291671014602, 62.7526746257659, 59.94844275136148, 53.59735273545789, 57.37281445533999, 51.302205285718365, 45.644892338783514, 45.63571791495047, 47.64883910456012, 54.81199702908916, 59.05587603968959, 54.94139602107387, 50.20187454838907, 53.08532653316375, 58.783585102327415, 55.36467075347901, 54.26037842227567, 46.299751650902536, 41.324974260022564, 41.95182000437091, 44.197404384613044, 42.26441329525363, 42.82173895066784, 44.30299851202196, 45.207124448591664, 42.85165879034227, 41.18884055845199, 42.667252479061005, 44.72174290687808, 47.3480756821171, 46.971265346773215, 47.06786940174718, 51.68258497791906, 55.0361212607353, 51.64612262479721, 54.38507449242377, 57.94060891674411, 56.88475785716888, 44.50277659200853, 47.31349214430779, 51.85845621170537, 51.01168709416544, 56.71176172071888, 56.96109502546249, 55.691047253147254, 55.36176427718132, 54.805611410448634, 55.2522320901194, 51.426717004468365, 38.42914327498406, 41.161882108257664, 40.67109161807645, 43.6735914599511, 43.630115908961145, 50.927332601239605, 54.30478357499646, 58.456169174563506, 52.954280145706676, 50.66667149143834, 49.693052922525716, 51.18824082036173, 58.61537033511747, 54.11357195146623, 51.875039992793916, 47.31079747599941, 43.101278428108465, 42.3343530777962, 42.79619255373555, 44.33040019004576, 48.51187036883447, 49.06396358243881, 53.2721019560291, 53.73775005340577, 58.26116069670647, 57.335799048023844, 59.73661515020556, 51.48875321111372, 51.355118059342914, 40.91974635278025, 29.34687552913543, 11.91887584424788, 5.0159122674695915, 8.017718340120009, 9.895019127476601, 12.640813569868765, 12.003439203385385, 13.5984778981055, 9.446799101368073, 3.7680320153313303, 0.5412389734579671, 0.9677006316281135, 4.25096232083536, 19.512508992225893, 34.684291731926706, 35.53361823481899, 35.304430223280384, 58.1431051992601, 62.306140238238925, 41.18652636005033, 12.294412389878305, 1.2771357403647516, 0.1639778413359196, 0.12886721971294574, 0.12915468654565274, 0.10946782801540629, 0.11078971272875225, 0.15473177296019372, 0.196097134762714, 0.19574640438921992, 0.2135315952041457, 0.10819224565620385, 0.1385405046805259, 0.0903709797609237, 0.19072624554316844, 0.18466855849950545, 0.2616876982633145, 0.16851760176641328, 0.15960734037141647, 0.11883470079591198, 0.1825711323368934, 0.17899664269099314, 0.1956303727122084, 0.16967197369423606, 0.13890124016231106, 0.16571566582687441], [0.08669296865381541, 0.07953600672584388, 0.03656819965990801, 0.06685241756419982, 0.036562220343659003, 0.08289168633881115, 0.033018822376165664, 0.059388790640138814, 0.08638516218671877, 0.024668557847279216, 0.058119455727958874, 0.01524897630236322, 0.06646624030244928, 0.04126814141448948, 0.07499820748043638, 0.03769423782585129, 0.018329097919406432, 0.014874908017865835, 0.0693958830989657, 0.056065623798678, 0.03717524773110786, 0.0497974272847416, 0.06666448853549457, 0.051707506645470865, 0.046373830146847234, 0.03213565706485703, 0.03234377634080668, 0.11909373810574894, 0.03635067282424819, 0.5122669684069773, 11.40618872257971, 39.76540457817816, 52.74126406638853, 55.78434867243613, 68.93903686154273, 73.170301529669, 43.452083449209894, 21.294043640936575, 12.43344178122859, 2.1111667156219482, 0.25631611956463707, 0.24292622031944416, 0.5497380141769687, 1.4055388180478927, 3.213694715692151, 2.994540862498745, 1.2448610076981208, 10.036268580344416, 15.130360549496068, 25.481944545622795, 43.7887797048015, 51.802123131290564, 56.21218904372185, 57.04963076499201, 52.35955076832926, 50.87226252402029, 48.32626773465065, 44.24848541136711, 44.03072326414047, 47.13520865286551, 49.933733478669204, 52.71487435986919, 54.04783694974838, 50.3829703792449, 53.88347787241782, 54.461007656589636, 52.42869430972684, 47.47766687024025, 40.626839437792384, 38.28786734611758, 35.8065132171877, 36.25579718620547, 38.24226587049423, 41.99241261328421, 41.46478714481477, 40.19294684933078, 43.81458890053534, 38.3077851418526, 39.207561169901204, 42.15275910592849, 45.4621216558641, 48.13944916571341, 47.579707330273045, 48.127297662919574, 49.732849290294034, 52.542862738332445, 55.75386008908672, 51.00385804330149, 37.61606731722432, 29.988271305637976, 46.805804083424235, 51.92056302101382, 52.2973027536946, 51.8048805575217, 49.89913032900903, 50.338396564606704, 49.600273178469756, 51.4263875253739, 49.65619441001646, 40.536679837011526, 35.65443900323684, 38.77934817344912, 40.78890392857213, 40.35581934836603, 36.61091681449644, 44.4376064115955, 48.724698174384336, 52.37854680707378, 50.95240439138105, 51.192076898390255, 46.77278949368385, 48.06397099648753, 52.822304156518754, 50.71791725773966, 49.4938475085843, 46.564586162567146, 39.86053774433751, 39.38803726626981, 38.977274894714355, 39.136225023577296, 39.48994828808693, 42.26623327501359, 43.810376274970274, 46.21016079379667, 49.86476252155919, 54.05506195560579, 53.84844718440887, 55.05316003676384, 43.812443364051084, 35.34356371048958, 18.19832867191684, 7.3677168834594, 3.2010284018131996, 3.5993600468481746, 4.293394521359475, 3.9131119078205483, 5.035471166333845, 4.05590481335117, 2.8958736408141355, 0.897350287245166, 0.353182130643437, 0.7906871913902221, 4.65203937984282, 13.372408170853893, 23.222353381495324, 38.164398977833415, 35.68587287779778, 44.05657560594621, 43.67261086740802, 19.257313705259754, 4.044719684508539, 0.18617798153671528, 0.018215201712483843, 0.016144395190020724, 0.0565961167036045, 0.05972654348419559, 0.023580312713860505, 0.021624704747791254, 0.025784983524992585, 0.03757429526998632, 0.04821885715148622, 0.02199816303477893, 0.05213650056130944, 0.04213505417048451, 0.05155422011270158, 0.03439964606396614, 0.042741711536842975, 0.02695938865203531, 0.042563140272132816, 0.07203410604908582, 0.11926724935971922, 0.0951465956806656, 0.07034875858094423, 0.04274695540868467, 0.023949618804298585, 0.024998506170607386, 0.00852747694514091, 0.05714957309406131, 0.07879840195058815, 0.011353729473006342, 0.023675535527628758, 0.07244831446798579, 0.07991091483422826, 0.06362479720865527, 0.03234545790380047, 0.030289862057073947, 0.03173009586340237, 0.00825239583894971, 0.03356228131921061, 0.011932076060123021, 0.041474705531952843, 0.039698059535435135, 0.05213537824250037, 0.015711036488233555, 0.04724860296494538, 0.054784081275424654, 0.04863409212820473, 0.030403867431525743, 0.036758036247544715, 0.0465662905856246, 0.052985295337895234, 0.049655923184247754, 0.09353021910834698, 0.08258837680783003, 0.05055167532015232, 0.588502798589968, 15.791708442472643, 46.500624072167184, 58.95057216767342, 54.12494290259577, 70.57190387479721, 77.98035898516255, 60.51968497614707, 28.270681096661477, 10.419942082897311, 2.0396849513053894, 0.19401123056248312, 0.15510939301983004, 2.024712528913252, 2.56530094050592, 6.874714666797269, 3.971672404196955, 0.627785274578679, 10.388078708802501, 18.318784659908665, 30.113930317663378, 44.838201999664314, 56.20230074851744, 58.2547946899168, 60.8405387786127, 54.98755447326168, 53.166150892934496, 48.58547756748815, 45.64719477007466, 43.61135129005679, 49.438161619247936, 51.34724978477725, 52.950612729595555, 54.35057724675825, 51.02447794329736, 55.82667889133577, 56.06273889541627, 53.473707860515965, 49.348774725391024, 42.64629525523032, 39.97167025842975, 37.72323823744251, 37.44798198823006, 41.179815184685495, 43.80621464021745, 42.15147649088214, 43.00233664051179, 44.27458094012353, 39.84144756870885, 40.564014834742395, 43.95413506415583, 46.56383698986423, 50.26278111242479, 49.538378177150605, 50.32273454050864, 52.07977202630813, 55.58444115423388, 56.0506344610645, 54.69600077598326, 41.739811974187056, 35.54448712256647, 47.20985527961485, 53.42949098156345, 53.8818383216858, 53.33698972578972, 52.86693680670954, 52.18463267049482, 51.46157903055991, 54.87400577914331, 52.35286312718546, 41.867390986411806, 38.03287013884514, 40.66646714364329, 43.061788005213586, 41.587816207639634, 38.732887698758034, 47.40034518703338, 49.721741137966035, 54.62383700955299, 53.66055388604441, 51.56590623240317, 49.02306502865207, 48.86571522681944, 53.10538945659515, 51.657662237844164, 52.34769344329835, 49.29361051128757, 42.89198860045403, 41.81467825366605, 40.12059873150241, 41.91887601729363, 40.825605546274495, 43.278208701841294, 46.15043094081264, 49.02712860415059, 52.994504051823775, 55.38597706825503, 57.0064337022843, 56.57805596628497, 46.6182049628227, 37.96698608706075, 22.420385576063588, 10.045486150249358, 3.732620857415661, 2.9078758483932865, 5.178074327207381, 7.762733390254359, 10.633309214345871, 4.17652456029769, 3.664576069962594, 0.6897766191151835, 0.20128298310502885, 0.9330018129079574, 4.977323009121803, 15.324455115102953, 30.968479456440097, 37.57243879379765, 35.40979685321931, 51.441390591283, 50.45743657696632, 25.53614777903403, 5.595025708598476, 0.3228053042004186, 0.0370376430181486, 0.019962627200349685, 0.11305815269870144, 0.05160480489834182, 0.033636722082812945, 0.03169789910316467, 0.03065667070087887, 0.037218524037950465, 0.03856456350354898, 0.01644385704440215, 0.035589844093567906, 0.0449641096225429, 0.05485857183474207, 0.023450679145753387, 0.06023188572256796, 0.03316898327020388, 0.017354243374880285, 0.011069789517580742, 0.04232114075773186, 0.019782786144905036, 0.04945009451119169, 0.01479751590053521, 0.05999223809809454, 0.033853785435278574, 0.15190844784580892, 0.1790875160405713, 0.1380491205641339, 0.1251559833725614, 0.08036426268517971, 0.20194584834239176, 0.1652362480038597, 0.1518786623473129, 0.21003693191995546, 0.1369514084991909, 0.1635757064627063, 0.12114915200659346, 0.17364027849849195, 0.08925085196331625, 0.13701226652389573, 0.1407961739647773, 0.21801319423942797, 0.12310238510009744, 0.20863537406248434, 0.12209654229903415, 0.18477674543617234, 0.06916362056208235, 0.132164875826528, 0.11749705765396358, 0.2487148113188244, 0.2390464752792351, 0.1715483834906932, 0.34492995409715566, 0.18783493778638302, 0.8450052154160316, 18.241613987953432, 52.03850084735502, 66.55745214031589, 65.98081665654337, 77.24571474136846, 79.2497399545485, 52.140658978492986, 31.37367794590612, 15.7205468416214, 2.736582510894345, 0.5629900482393081, 0.496035649050628, 3.173775283559676, 6.722864027946227, 10.630263493907067, 10.076552302606645, 2.419678290044108, 12.070372489190872, 18.905504557394213, 32.01904316102305, 45.72566178537185, 55.460937484618164, 61.162231968295195, 61.3105171726596, 59.00943909921954, 56.01614113776915, 53.62933181947278, 48.741532987163914, 48.84333418261621, 51.6387132675417, 54.23527917554302, 54.89138972374701, 55.25173787147769, 50.109479196609996, 56.981071656750096, 58.2127429592994, 56.4836758951987, 51.86626565071845, 44.59950616282802, 41.26063954445624, 39.00666521441552, 40.32290674025013, 42.295639284195445, 45.63381164304672, 44.4497343801683, 45.440525085695334, 47.85827405991093, 42.936833058634114, 42.77082266346101, 44.71709882059405, 48.201857997525124, 52.45718640665854, 51.19930582661783, 51.41540096652124, 54.04986481512747, 58.284628237447436, 55.07155987524218, 55.325066581849136, 41.57660999605733, 38.43521902638097, 49.383750500217566, 54.70339836612825, 56.67174177785074, 55.17835424792383, 55.44189437743157, 55.77972812037314, 54.34351305807791, 56.64418712739022, 54.80127326903805, 43.57247275690879, 39.20999303940804, 41.42244515880462, 44.769027079305346, 45.2603784684212, 40.57626439679054, 49.36468385880994, 52.83795049113613, 56.71080466239684, 54.5152069676307, 52.05954828569966, 50.20771495757565, 49.88223275830669, 54.560796676143525, 53.71945219655191, 54.60283663965041, 51.69587396806287, 45.12615888349472, 43.596418826810776, 42.24775891150198, 43.10978997138239, 42.57988560584284, 45.30821177267259, 49.27524205177061, 50.65075451327909, 55.708517489894746, 58.335015004681004, 58.4364043512652, 58.87715716515818, 47.93156746895083, 39.7284911524865, 23.375935746777444, 10.423144698143005, 5.060662098469273, 7.382441951382545, 9.429387700173164, 11.026715097888824, 13.55714298063709, 12.546742385433568, 8.039278138068415, 2.180124189584486, 0.922609431849372, 1.7509499672920474, 6.602841461858442, 18.04328718493062, 32.99938663359612, 49.72894653197258, 47.65655832905924, 59.44694419060985, 56.875116671285326, 29.476127432238673, 6.420370349960943, 0.4844797642961626, 0.08287548357921262, 0.16858415948527475, 0.2697077808120559, 0.11857975439559068, 0.12462698433908725, 0.07742565665994922, 0.10131625413534143, 0.09884101639111197, 0.13173511582276515, 0.12414931319653989, 0.1558615687874056, 0.11453661046201184, 0.24527660871465362, 0.05739123936021521, 0.16742860778204857, 0.21884219330405036, 0.14291221606394938, 0.1838631549429509, 0.19894708909334677, 0.19046862549599142, 0.1706531484641375, 0.16301633970391366, 0.13229331812791287, 0.10606775360722696], [0.009060180971338865, 0.055148294796386076, 0.06410880389833643, 0.060682678670291944, 0.030408002391097047, 0.0041346828220412135, 0.0542119131874173, 0.04130910796624038, 0.0394215592513642, 0.08211324141631204, 0.02752676102963667, 0.086409401208643, 0.045015820557431835, 0.035636495017716964, 0.035819555557663404, 0.013206000796579307, 0.03177964451512502, 0.03109260537331143, 0.01666482361484199, 0.035716505240528815, 0.047086115716205496, 0.026638960886386134, 0.03638731864010615, 0.05228581492819133, 0.04689500742261449, 0.03678471142906816, 0.023106270912854422, 0.015386509194579578, 0.10753880330030957, 0.267047954182471, 6.996042891856163, 31.896896631486957, 50.61556300809307, 53.71258804875036, 46.55645508919993, 31.527466235622285, 24.53544132171139, 40.94277458806192, 17.771702274199455, 3.3006443467832383, 0.03369685615442934, 0.24452072508152456, 1.597621207756381, 2.416363642100365, 3.852884404120907, 2.7717485206742443, 0.993404352376538, 1.1604422859607206, 8.638457444406326, 22.89142889361228, 34.5544965805546, 48.211087334540586, 56.50168741902998, 55.976415372663936, 54.59816117440501, 52.212277535469305, 46.28158323226437, 46.50153406204716, 44.03756780009116, 47.41954911139704, 50.3691989375699, 52.65730573285011, 53.119176587750836, 50.164251173696215, 55.416434272643066, 53.72415119601835, 49.94106438852126, 45.83443303262034, 40.13177748649351, 38.086653678647934, 37.76576065248059, 39.69663366194695, 39.49344311991046, 45.19137220997965, 42.110479877841094, 40.256528469824026, 41.63390797953452, 41.895757567497995, 42.538975284945586, 45.38483527398879, 48.1634658382785, 51.571083761030636, 52.32897197046588, 51.34645746600244, 55.2804692329899, 54.31696645675167, 50.631530977064564, 43.953283909828436, 35.50252952883321, 30.602110470494917, 45.91065645217896, 54.34524674569407, 50.274822788853804, 52.24617465849846, 46.70054335747996, 45.50834678834485, 43.85944120345577, 42.959861293915786, 38.967327763957364, 36.515485548204, 37.63723634904431, 38.78632606998567, 42.85469078248547, 38.6033514238173, 37.10754379149407, 39.990713365616344, 45.88342343607257, 50.18128994972476, 51.898091762296616, 49.39276410687355, 50.04976503310665, 49.72589492797852, 51.42412431778447, 51.28597451794533, 50.48410084939773, 48.229416570355816, 43.1206274801685, 39.1244226117288, 41.21209236883348, 41.477476012322214, 40.11227938436693, 43.0302756832492, 44.20402926783408, 44.838378506322066, 50.45683645432996, 49.975769519805915, 56.93241465476252, 53.02262744595928, 44.84193609606835, 28.500286840623428, 15.468153107550838, 4.35682071793464, 1.5731643717135153, 1.986142269545986, 2.7082997704705885, 6.520144660626689, 7.069931030273438, 2.7751394096882116, 3.425212939900737, 0.18587310918636862, 0.2419227830344631, 0.7959242297276374, 7.320561168655273, 14.476390634813617, 19.346041640927716, 37.438634980109434, 40.8025106306999, 50.4080774707179, 40.009109281724506, 10.603551172441053, 2.280748428836946, 0.10374263845263951, 0.10702710253216567, 0.03286146408607883, 0.08655118876166883, 0.012731239830534305, 0.04087205480543837, 0.10741819041751086, 0.025090233708221107, 0.006102040661649118, 0.037921440351994774, 0.018182164170749245, 0.011403009993955495, 0.015982375254914645, 0.07875995199766853, 0.03868981887916884, 0.03061715588574448, 0.03138585425462694, 0.023064136077018998, 0.04933879342711261, 0.022064854819027167, 0.04607562659188144, 0.021472132592011365, 0.016910856582164284, 0.04817132905666386, 0.07980689541586945, 0.022950289665811488, 0.012929570418031467, 0.007886066478902415, 0.009447251683131102, 0.046026550999452034, 0.035167381077283816, 0.035107645371388045, 0.045922577546368686, 0.008367606844272344, 0.016702555360332612, 0.031459145886342854, 0.14402402414669915, 0.04849974328892366, 0.047541723526533575, 0.05164487129678169, 0.09197787216473972, 0.008673038438803727, 0.02089161031518973, 0.04695623316952298, 0.03183854518518333, 0.009809724269284597, 0.026460010408153458, 0.04445756462612941, 0.022210783077283733, 0.06712240227047475, 0.006274041764798665, 0.025446761452082186, 0.02013173727919498, 0.07032356194911465, 0.2548853277919754, 9.051853687532487, 37.655138046510764, 57.80359660425494, 61.09651265605804, 58.44403728362053, 43.96170916095857, 30.869119936420073, 40.058907693432225, 19.59820297456557, 3.4300602539893124, 0.21661267826153388, 0.09591138891635403, 1.3282471654876586, 2.990956796753791, 4.480346941178845, 3.380197123173745, 0.6896914914250375, 3.6695214433054772, 9.736268058899912, 25.310017255044755, 38.188521554393155, 51.11186835073656, 59.39343913908928, 58.2690054370511, 56.11772268049179, 54.51873317841561, 47.22618802901238, 49.12751774634085, 45.83002428854666, 50.30412681641118, 51.586027991387155, 53.94310966614754, 53.12954341211627, 49.776434667648815, 56.09843246398434, 54.335021126654844, 52.30315100762152, 49.01313750974594, 41.90826600597751, 40.572498921425115, 38.92836293866558, 40.64180720236994, 41.9329337919912, 46.14630068502119, 44.46642798762168, 43.207425609711684, 43.62019231242519, 43.93811610437209, 44.00823631594258, 47.32902080781999, 50.28971210602791, 54.572206850974794, 54.67488273497551, 53.873844531274614, 57.25781448425786, 55.68832905061784, 54.28554042693108, 46.33185232839277, 37.16543013049711, 33.480732056402395, 47.22732943873252, 53.79620121371362, 52.88785872920867, 53.55539906409479, 50.197104946259536, 48.397839223184896, 45.78395997324298, 46.27672733799104, 41.18105465365995, 38.08302156386837, 38.29844205610214, 40.37033604037377, 44.037489352687714, 41.14391765286846, 38.74840459515972, 42.55795171183925, 48.17702547196419, 51.92607002873575, 54.218330614028446, 52.35444776473507, 51.362766681178925, 50.03254582805019, 52.991899598029356, 54.74803101631903, 52.15631708022087, 49.82610756351102, 45.81002804540819, 41.099963572717485, 42.19765063255064, 43.01287604916481, 41.614731511762066, 43.83837023089009, 44.818252824967914, 46.49118292716242, 51.46646238142445, 52.31588302120086, 56.981197172595614, 54.233239543053415, 47.661394611481704, 32.04237341880798, 17.386466687725438, 5.210017619594451, 2.1082952955076775, 3.4290409280407816, 7.007069655003087, 8.492546254588712, 9.204081854512616, 4.4093853812063895, 2.695802853953454, 0.34287628687677846, 0.259304306800327, 0.8415651129138085, 8.224074725181826, 16.643889450257827, 22.925161277094197, 42.37143516540527, 48.02364118637578, 53.12407170572589, 46.71831169436055, 14.231299373411364, 2.7774808195329483, 0.0691999790949687, 0.09731744370994069, 0.03665726121154524, 0.041091347473763654, 0.05989736959999127, 0.03039615675656786, 0.10424852461343813, 0.029231163019674922, 0.06984306394212669, 0.06090051194112148, 0.04605257117580022, 0.03941398647223269, 0.06808213423937559, 0.03942136006850389, 0.0764823802596619, 0.09301839576613519, 0.03833276444985982, 0.008174832309446028, 0.009299274139677086, 0.04104380788762243, 0.043330285397748795, 0.027998906763030157, 0.018761983561900356, 0.038536758342337225, 0.06547800220188595, 0.13798029522501654, 0.12541444611645516, 0.13780899796514742, 0.19041464694084662, 0.22443633586648973, 0.20003343241349344, 0.09951888929091154, 0.10763632629307048, 0.17090183592611746, 0.2442975177039062, 0.10878669924192852, 0.2411221292230391, 0.17895243941776215, 0.1785431186398191, 0.18403040725857983, 0.12742620066649493, 0.1957239580130385, 0.0869024170923137, 0.22311019170428478, 0.10847274874967915, 0.1504397193991369, 0.2195728726444706, 0.12044607481408505, 0.16838270900470598, 0.255098698600646, 0.1844647178246129, 0.10777250608249057, 0.14150744063719628, 0.16055284608756343, 0.4891346370981586, 10.211404369723413, 43.637191864752005, 64.5490691738744, 67.77328491210938, 59.25256721435055, 42.973754329066125, 36.24834468287807, 51.21002566429877, 22.054718694379254, 4.802509344393208, 0.6041477236055559, 0.7147948443889619, 3.0263093642650114, 5.227926671504974, 9.476627745935994, 7.1081270710114515, 3.4605010334522497, 2.531127045231481, 10.479585643737547, 24.6949190093625, 39.078291616132184, 51.333239078521736, 61.25276811661259, 61.21654502807125, 59.1211207451359, 58.062327907931426, 50.79737663269044, 51.11100542929865, 47.2356919319399, 51.70336177272182, 54.89991695650163, 56.92225963838639, 52.95034993079401, 49.35327760634884, 58.094507032825106, 57.57926448698967, 53.52598913254277, 49.72660095460954, 44.13143011831468, 42.83381200605824, 40.83724321857576, 42.7365372257848, 44.03263345841439, 50.19508100325062, 46.0772002896955, 44.56670338107694, 45.221578382676654, 45.405408105542584, 46.4862407407453, 50.946873849438084, 51.813764725961995, 57.44330729207685, 57.43006144800494, 55.86045834325976, 59.65160954383112, 57.58497153559039, 55.63809917819116, 48.981421224532596, 38.60501058640019, 38.26982444332492, 48.050615326050796, 55.96136916068293, 56.69483669342534, 55.541577492990804, 52.00985970035676, 49.62812592906337, 47.19441683061662, 47.3170889577558, 43.339750689844934, 40.250111472222116, 41.069423998555834, 42.11013470926593, 46.84508662069998, 42.922657612831365, 41.693037709882184, 43.7923922077302, 49.814728767641135, 54.875515891659646, 55.925608911821925, 54.54623683806389, 52.30339811694238, 48.75623403056976, 53.05031937937583, 54.82906718407908, 54.43966604048207, 51.24910816069573, 48.11615028688985, 42.332121249168154, 44.62612336681735, 45.15872240066529, 43.30208024671001, 47.0471671319777, 47.76662003609442, 48.279356187389745, 54.468464082287205, 55.07960073409542, 60.20986872334635, 56.0634135430859, 49.39094804948377, 31.31065134079226, 17.465967247563025, 6.644548023900678, 3.7234841863955226, 6.185248282647902, 10.51475557588762, 15.402164132364335, 15.164427315035175, 11.907165608098431, 7.63686502172101, 1.7167066950951855, 0.8918567013836677, 1.4829706953417872, 9.895405480938575, 21.030474093652543, 28.809371571387018, 52.45635486418202, 55.70820762265114, 63.60559401973602, 52.0374692639997, 17.796128834447554, 2.9045293311918936, 0.16703402653576868, 0.24907787570789938, 0.12368361600824904, 0.16404660538800303, 0.13703835947859672, 0.10047859061629542, 0.3132429640860327, 0.10989464624153991, 0.1884650757476207, 0.18660475379757344, 0.13906332904533034, 0.13050301661414485, 0.19369512736316652, 0.1498980799149121, 0.16342998121774968, 0.24881588895955395, 0.19692332994553352, 0.056183605169456814, 0.1512377072245844, 0.1767078784084128, 0.09928832746922009, 0.07387697651621795, 0.08748586199456647, 0.16668836766433331, 0.12115652943330428], [0.040302464603296215, 0.005665007131850167, 0.02665959737984644, 0.04585276778426863, 0.014380722892500702, 0.02316411246635741, 0.028950014497123422, 0.02736101790721859, 0.021144792798065373, 0.11441027490241874, 0.0339589731377219, 0.011180125330875238, 0.030075627484268723, 0.04148137432733371, 0.025247879281279542, 0.012532267644400559, 0.06436748880772822, 0.08308564447948048, 0.06392524923167883, 0.07386746936507764, 0.023439373603210818, 0.07896801381702385, 0.023813839295818925, 0.05283401212504795, 0.020916037028655413, 0.06943374316418363, 0.04237292830141322, 0.06655034143477678, 0.06803570165028495, 0.034027266045731884, 3.165685885375546, 24.998233933602613, 45.145900172571984, 47.25264441582465, 35.50724421778033, 33.57603780684933, 39.04899151094499, 24.942200914505992, 18.490323635839648, 7.1861307563320285, 0.7438797095129568, 0.03865499635257068, 1.5905241692258467, 1.886181646297055, 2.5792305027284934, 4.115257628502385, 2.328665328602637, 4.329655362713722, 6.908074425112817, 15.637574984181313, 29.189300191017892, 42.67375576880671, 52.678929759610085, 56.0597578940853, 55.4732301927382, 54.71957422071888, 48.851084786076704, 47.34080360781762, 46.09052850354103, 48.82593062616164, 50.76611926478725, 53.16657843128328, 54.49344565791469, 52.09813264108474, 53.385474143489716, 52.751328868250695, 52.438712043146936, 47.8336964884112, 44.184268366905954, 40.2147630722292, 40.013482724466634, 38.08940326013873, 40.08433641925935, 40.52326140865203, 39.825197189084946, 41.25477167867845, 39.2125072786885, 39.07401623264436, 41.07854350920647, 47.14184138082689, 52.03156609689036, 50.90546930989912, 51.39789935081236, 51.295301914215095, 54.015375414202296, 51.26778256508612, 47.14067643688571, 46.27633117860364, 56.83911323547364, 41.48747805626162, 44.74069579955071, 55.83377445897749, 48.356101282181285, 50.42226076126099, 41.792944400541245, 39.97482776641846, 37.36875795548962, 37.62832080164264, 37.447154368123705, 37.69023933718282, 39.504916052664484, 47.30165443112774, 43.75982476818947, 45.17954626391011, 40.236775413636245, 39.19153044300695, 41.0305650772587, 47.168556644070534, 50.406073139559844, 51.89152571462816, 51.0116635599444, 52.7954202313577, 50.044532591296786, 54.36093230401316, 50.22338090404388, 49.152256135017645, 43.74195444968439, 40.313685247975016, 40.125031009797134, 40.52633654686713, 43.25993830157865, 46.378642282178326, 46.92941757940477, 49.473055024300855, 49.70220381213773, 51.514483959444114, 54.652627206617794, 53.291501998901374, 38.06991692512266, 24.466654715999482, 9.985839647631492, 3.663746733819285, 1.5305583611611397, 2.8434215005367034, 4.989607872501497, 7.820528534150894, 11.167329126788724, 2.5578999182870312, 1.395611176567693, 0.4470396378347951, 0.4678367186457881, 2.0798171720197125, 8.267621859427422, 20.514956981905048, 36.006530561754786, 37.17446334900395, 40.89696130444927, 47.897638966960294, 32.73185941480821, 6.325240125579219, 0.5732832055899405, 0.02138824021864322, 0.041045006815223925, 0.03265326437089713, 0.008275083532827276, 0.04513993829248413, 0.0482112460679585, 0.09907240558776165, 0.0164154983846651, 0.028539490961139242, 0.007077802541560584, 0.06248335301455471, 0.023596059651144093, 0.023151067904226726, 0.014785683672544698, 0.044302876152458696, 0.057111724520162235, 0.01587148785831467, 0.04394856048747898, 0.03119577251885447, 0.045839813237469045, 0.014939929730439139, 0.10266464549086748, 0.009493143222625218, 0.0851822739106513, 0.03916669329027495, 0.024819193715830485, 0.08196517960318635, 0.014338317053062061, 0.09059575761878684, 0.07727839157826479, 0.030668696366070263, 0.02651311179262496, 0.05518248530044671, 0.0953851324776488, 0.010031356378608655, 0.0202809501394269, 0.04843656784824787, 0.05387925865849661, 0.05034926339923855, 0.009283343341291673, 0.012668209946564129, 0.08877675079049603, 0.04472138998549312, 0.042940335152971174, 0.1007887259906819, 0.01526487262679204, 0.0715476708606847, 0.03742151818568668, 0.06006534203826901, 0.026137726794507717, 0.05518906982615591, 0.08329550660545788, 0.06565486126008534, 0.06263524143686218, 0.02573838431177841, 4.348792606784452, 29.40508742486277, 52.6157364537639, 52.661334007017075, 40.16153650899088, 35.08509520561465, 40.251700032141905, 36.22971342455956, 22.702880559429047, 7.430283590670555, 0.5873412867226909, 0.06647570148831414, 0.8316499739885331, 3.6565570292934297, 3.9974570851172175, 5.352075571014035, 3.772702822762151, 3.8656872655114825, 7.465963430943028, 17.393832898909046, 30.826183711328817, 44.1400985563955, 54.10497803841868, 58.428590989881954, 57.71904991519067, 55.45752502256825, 51.15358275751914, 48.80782104307606, 46.95388140216951, 51.13486520705685, 53.4620427316235, 54.07992193775793, 53.62313447460052, 51.60385124145016, 54.68733233790244, 56.019988982908195, 54.98546777233001, 49.010078061011534, 44.894574303780836, 41.08951045620827, 41.241070839666556, 40.34926114543792, 42.9859568226722, 43.399794332442745, 42.594013983203524, 43.40739196346652, 40.86342503947597, 41.35070893072313, 43.576967793126265, 50.26411471828338, 53.956845806490996, 52.736474852408136, 52.41632707657353, 52.29269004637196, 54.80096340179444, 52.6073778829267, 50.13987364307527, 47.060636551149436, 54.3251092972294, 43.51102882815946, 46.3236310405116, 58.80937468621039, 51.06606291186426, 52.725013686764626, 44.53495179453204, 41.33280723325668, 40.11926512564383, 38.51582373342207, 38.28911465983237, 39.172330441013465, 41.306484207030266, 47.85617951423892, 45.35187167506064, 48.48493937523135, 41.50067683189146, 40.476977440618704, 44.108872567453695, 49.761604186027284, 52.452456028230735, 52.95786519204417, 53.051072474448915, 53.301378526995265, 52.69806308131064, 56.01914567332114, 52.215948873950595, 51.74950061305877, 45.48544799127887, 41.07331498976677, 41.95078449864542, 40.84917899101011, 46.197883775157315, 47.505845177558164, 48.063433631773925, 51.64426734370571, 53.06270230200983, 53.84243811330488, 57.446955096337106, 54.12886135039791, 41.6670794640818, 24.403614382590018, 11.733092781036131, 4.491578157871, 3.490983242950132, 5.258760913725823, 5.71576165576135, 7.866914974104974, 8.080185517188042, 5.933224231966081, 1.5620830631063831, 0.5450766449493747, 0.3164310849482014, 2.2287681987208705, 8.926150548842646, 21.41253452147207, 32.941704257842034, 40.63538628239786, 45.59305821695636, 53.75145481478784, 38.7280474939654, 8.210494989348996, 1.014299308580737, 0.051321409822952364, 0.07888322320556448, 0.050734885247243997, 0.023992663369544094, 0.10653146662779393, 0.03273821586082059, 0.062433166594635096, 0.02645260999880491, 0.01927860644495776, 0.05484101692995718, 0.05604741771915748, 0.03711503705069904, 0.04649449665580065, 0.023652070254508047, 0.034004766043395765, 0.029780149287093553, 0.028037469713918628, 0.06531536173556121, 0.03558715512495368, 0.04039231905593507, 0.021702987442333854, 0.058662918501443444, 0.04444073750487259, 0.11070659218896782, 0.07950162469980218, 0.11181223326392713, 0.11658092374883353, 0.08762373483829922, 0.20369756966829303, 0.16439624791664464, 0.057173995977087375, 0.09179240227827141, 0.10955461811634803, 0.1503551739358133, 0.2667475864291191, 0.05767684842970583, 0.14457085770705055, 0.12449114928923308, 0.14010278778451105, 0.09956041891728679, 0.15800448525096142, 0.270777668563589, 0.23602963635517707, 0.1477450357689973, 0.21604001221637573, 0.10549568511064976, 0.14742802858593004, 0.12176215258096496, 0.18992231287542852, 0.1498435650982203, 0.12550922651444713, 0.11835645508742142, 0.15258004648550866, 0.18691115832376867, 0.10151785017261583, 4.661868839494644, 32.22799762602776, 59.66229015781034, 59.49696617741739, 47.72517235048356, 46.26126535477177, 49.43720848329606, 33.674010769013435, 24.5503306388855, 9.204170107841492, 1.573014708776628, 0.22251491074360188, 3.526248537725018, 6.098549192951572, 9.818194604689076, 8.769578356896679, 3.490166654509883, 6.185889590171076, 9.217521855908057, 19.15226870967496, 31.73332791174612, 46.58875972993913, 56.27057352373677, 60.69589745613837, 60.690194329907825, 59.689327055408114, 53.51104882455642, 52.356326580047615, 49.72390628630116, 52.7443431269738, 55.62777157752745, 56.32504347831973, 54.51754862262357, 51.642168875663515, 54.62901061581027, 58.14244231870098, 57.709424418787805, 50.81326223188832, 48.97817350202992, 44.33863324503745, 43.1948975593813, 42.2256955792827, 45.24454778240573, 44.467432114385794, 43.91352676576184, 46.06656674415835, 42.68920990728563, 44.174548733618956, 44.754659437364154, 50.555703716893355, 55.607681197504846, 53.6850098640688, 52.82977627169702, 54.89620639431862, 56.17608362628568, 53.46128179181007, 52.237172818953, 49.7128491247854, 54.756989709792606, 45.42838142764184, 48.49836172596101, 58.34373835594424, 53.20290742381927, 54.45302563328897, 46.08147175081315, 42.83282356877481, 41.160595570841146, 39.888696439804576, 39.71300171267602, 41.007882010552194, 43.96246225603166, 50.47135706870787, 47.07393338603359, 50.552781551114975, 44.13418362217565, 42.93437765490624, 45.57298352641445, 50.80690799220916, 54.47862694340368, 55.21228667228453, 55.92834280383203, 54.35037328350929, 52.21612930297852, 56.5348667483176, 55.60881084011447, 53.653999605486476, 47.38807601313437, 44.129531691151286, 44.38732162598641, 44.39054189189788, 48.55983703367172, 49.19745752888341, 50.609330361889256, 55.032634273652114, 55.15689103834091, 55.19828773313954, 57.888327644717315, 58.83619193107852, 42.26916328553231, 27.892650904194003, 13.012450298955365, 6.474929538465316, 4.473678421589637, 7.207860196790389, 12.230182597714087, 16.539034689626387, 20.01920077108568, 8.373485649785689, 4.3509288276395495, 1.186165189550769, 1.0716546567216998, 3.1872809846555037, 11.577134440022132, 26.914107799530033, 47.34605958384853, 49.64735338764806, 53.58462072187855, 59.263498860020796, 42.29566674078665, 9.655615302824206, 0.9863149747252465, 0.18132535079794546, 0.12820695917452538, 0.12793650715461663, 0.12219712964349216, 0.17448426224291327, 0.0870251750213004, 0.1723969637626602, 0.08483754200560432, 0.10362086877707513, 0.15606645134187516, 0.14502965244314364, 0.1542919465611058, 0.1866042635013019, 0.11325288458817429, 0.1583362626092088, 0.2144766412675381, 0.12397458386277, 0.21397649310529235, 0.10761712046880877, 0.14475902422301232, 0.1381811634787629, 0.16059349471282575, 0.11099998088132952, 0.2398322210196526, 0.24195209355844607], [0.039631555442728346, 0.03429786745278585, 0.013518039899457608, 0.04930669817352488, 0.04497898705003243, 0.07972371358905109, 0.05355521495784483, 0.04580759540981343, 0.10509417076865513, 0.030701670705551104, 0.044958854259382335, 0.021984957594184146, 0.0762806922918366, 0.03297848018607305, 0.06698986905957423, 0.057273395885262764, 0.06510173045699635, 0.035424081818951715, 0.04389563530323006, 0.040408223041243134, 0.05728052433339819, 0.05122316287710302, 0.011439577285801212, 0.07111381228652693, 0.046459643485685514, 0.03554813443653045, 0.033891833192037965, 0.007159500073025665, 0.06714774445900995, 0.06004702870643908, 1.113316479229158, 11.436279185356634, 38.35661080575759, 53.787909323169345, 44.93603767887239, 33.977751270417244, 30.840986736359138, 29.807177435967233, 24.126700931979766, 10.388733744621277, 0.8593971270226664, 0.16952419533364235, 0.5571956656152203, 3.306267309573389, 1.8978500846893558, 2.7213651855145735, 1.6408661969246405, 1.8627398461103442, 2.2087964703959804, 11.333786672161473, 20.155297210139615, 36.03918821580949, 47.25432711262857, 56.54188386855587, 56.82646751403809, 55.8466516002532, 49.248632692521625, 48.05349434575727, 47.93029269864483, 49.467081254528416, 51.04427806792721, 52.814204462112926, 51.672943792035504, 50.138885205791844, 54.17691822974913, 54.06780181392547, 52.219353491260165, 49.15511554287326, 48.80290631325015, 47.09320399069017, 46.54338575178578, 41.94543438573038, 40.33641146075341, 38.587301085072184, 37.705320850495376, 39.79343383542953, 39.46475490447014, 36.28672899738435, 39.91524304113081, 46.88422403027935, 50.8625703473245, 51.02590568604008, 51.80632006737494, 52.22830041762322, 52.361782596957305, 51.9915343869117, 56.08577105306811, 49.98077054177561, 54.23161960417225, 38.53785960905014, 44.07626590421123, 55.42503210806078, 45.862497591203265, 49.31254379210934, 42.960135859827844, 39.578099635339555, 37.93253983220747, 39.020522948234316, 37.603201943059126, 37.93011580744098, 42.26991245823522, 45.59739243599677, 45.051190622391246, 46.13477676145492, 41.852132966441495, 39.03070934357182, 37.87263347256569, 41.305056464287546, 46.73316571020311, 50.87248609912012, 51.72327564608667, 52.84505782588836, 53.67290935208721, 54.00189422792005, 51.86588910318191, 50.83004997622583, 44.608900239390714, 40.21899923201531, 41.10444684182444, 44.04982912924982, 47.23780608946278, 49.057519128245694, 49.65075408258746, 49.10277543529388, 52.15106110418997, 52.81370239873087, 55.06846120280605, 46.73812358610092, 34.460908828243134, 17.668918525019002, 6.502308662860624, 1.1892329733217917, 1.8907377244003358, 4.297832192913178, 5.08649924109059, 5.632056805395312, 5.129258469227822, 4.750981657735763, 1.11089980890674, 0.4231338948011399, 0.7548256350621101, 3.7528372435800494, 13.123340606689455, 27.73383413591693, 35.941089737799864, 40.35988684623472, 48.31400248312181, 42.17226113042524, 17.710821205569854, 3.140956812327908, 0.06293861225487725, 0.028627391889571186, 0.06929221608105206, 0.03077731805763418, 0.044434333009825605, 0.016729672957632332, 0.04880293407627652, 0.031171138961649233, 0.03123264050021047, 0.021592312635132865, 0.0034361952144066777, 0.025841961314360944, 0.008785878402000714, 0.011705482573879343, 0.030293822731642477, 0.028103205803481322, 0.06431966959949463, 0.02918474575234277, 0.006454613476601099, 0.010740711661656539, 0.06118150533086831, 0.03283768854734879, 0.051307543631522894, 0.01723170569617181, 0.029715411027052233, 0.06827125070436348, 0.025566332455303882, 0.13228346623720663, 0.018827482164206526, 0.04885962075223366, 0.056481303106392586, 0.08704692425747072, 0.06320369016799716, 0.042086353961137996, 0.04401116136221155, 0.06444964407672805, 0.0805980344152739, 0.0925411306501877, 0.08932799701729129, 0.027440045622267553, 0.023034739368144545, 0.028096324418701475, 0.015087217794761304, 0.026630553071417158, 0.03193379672724874, 0.005345139567995625, 0.07128150893315192, 0.004768520509148198, 0.021969766070645665, 0.03662731100414549, 0.007843929727847178, 0.028897943500910076, 0.007306175267008404, 0.010944789823805614, 0.08376082841066584, 0.06900242800193448, 1.4218774510006753, 14.715753274579203, 44.84900420711887, 58.98024097565682, 50.05890807797832, 43.17625061158211, 33.76307995088639, 28.573890116906938, 28.839569899343676, 11.603003451901099, 0.9091374999092472, 0.15355636425797017, 0.3766604885458947, 2.266709775693955, 2.09323535523107, 4.379984274987252, 5.318186783021496, 4.474295214299233, 4.17938151667195, 12.750589924473918, 23.78769636154175, 38.01711397786295, 50.72824093603319, 57.20572148599933, 58.30783297938686, 56.19982181056854, 51.854698581080285, 49.23765790077948, 50.12113648076212, 51.369862248820645, 53.821371063109375, 55.78716101184968, 52.621682766945135, 50.231963049980905, 55.35620235627698, 56.45917677110242, 53.95286460076609, 50.528305961239724, 50.59868112687142, 47.7929626741717, 46.30109310150147, 43.733054591763405, 41.16231749134679, 40.567344927018695, 40.39345841253958, 40.60641565630513, 40.727836547359345, 38.61056466256419, 42.33986793025848, 49.21833238294048, 53.68007160002186, 51.40948995467156, 54.18837547302247, 54.267328862221014, 54.92180378206315, 53.83546021676833, 57.067195138623646, 52.28388432533511, 53.76463790093699, 41.23441849985431, 47.20006504366475, 57.73817146978071, 48.79275914161436, 50.527286144994925, 44.17983608861124, 39.32481650383242, 40.39496068031558, 40.84264039993286, 39.72938153051561, 40.076177889300936, 43.59264942907518, 47.24133622261786, 48.07104695227839, 46.87533986183905, 44.07300641459804, 40.631259948976584, 40.87878896344093, 44.01383746054865, 48.5959699076991, 51.58502386462305, 52.90909051895142, 55.570100968883885, 52.24964595610096, 55.214106652044485, 55.205226405974365, 53.13318337163618, 46.31498613665181, 41.462963242684644, 44.21716920791134, 44.78950185160483, 49.12001425220121, 50.93650310270248, 51.599544479000954, 52.23631774225543, 53.22954816202964, 55.25244782047888, 55.983499173195135, 49.88298977574995, 37.072924952353205, 20.953281848661362, 8.010844876689296, 2.1960622504834206, 3.104378013841568, 6.807567611817391, 7.10898018652393, 8.1576606631279, 5.976585543924763, 4.8927665141321, 1.757004513375221, 0.4923433810472489, 0.8870252606368835, 3.7255444113285314, 12.613568786651859, 30.352553590651485, 40.1216342372279, 44.66038919264271, 53.605864278731815, 48.401777282837905, 22.83002418856467, 4.972397002481646, 0.11457546644153134, 0.04593458597458178, 0.025522152164710626, 0.019293125726342685, 0.0542081555261487, 0.08372404852942114, 0.03345728896918797, 0.03770931443620113, 0.11162693191680217, 0.08231266942476073, 0.05178791523400334, 0.009098959384456037, 0.04238293340970432, 0.031022990963632063, 0.03889514959507412, 0.00859959933516239, 0.019312609257476947, 0.01822204670808729, 0.017950566215140205, 0.02652870551232369, 0.052679116807637684, 0.05889171449046943, 0.05394722597913877, 0.051294355427906405, 0.0454665752007596, 0.048594473891200564, 0.13703843608738916, 0.1898726244126597, 0.2017738462816323, 0.12704108060607988, 0.14859992860546037, 0.12620782975347775, 0.13203464087940034, 0.1242632151491219, 0.21715433306751714, 0.12909893066652361, 0.21938472145026733, 0.2924822571296846, 0.3273956417556732, 0.09324146524792717, 0.20360180867775796, 0.1508499288390721, 0.12078771938479717, 0.13455574430765646, 0.16883373560924686, 0.13519136745843197, 0.17956057533381448, 0.12479638936178339, 0.05293291024563294, 0.1510250871820796, 0.10077067695918585, 0.08513368095361418, 0.08211463569633423, 0.0965966852081399, 0.165847065227647, 0.20953649264429847, 1.900891637609851, 17.381985379803567, 50.97951973638227, 67.54648562400573, 59.61552373824581, 48.16000630778652, 44.01926209849697, 39.14989448362781, 33.1496016440853, 13.102760910987856, 1.6378517328731477, 0.42758881865489873, 1.0884919209826378, 5.264840097196641, 8.739451612195662, 9.47466459966475, 5.698236505831442, 3.5570339954668477, 3.1082560122013096, 13.716500055405403, 24.12343163644114, 41.159477695342034, 52.984753039575395, 59.70937036698865, 60.30840650681527, 60.432094527829086, 53.54928408899615, 52.8810259603685, 52.31242741307905, 54.172995859576815, 57.80212179307015, 57.514133530278365, 52.74693189128753, 50.91180393772741, 57.36443235028175, 58.59343644111388, 55.53098709352555, 52.326944105086795, 52.990028627457164, 51.65467339177286, 49.865076311172984, 45.63812625023627, 43.084929989230254, 44.24776369525541, 40.44824215673631, 42.36222544024068, 43.40166138064477, 41.78097332677534, 44.2317682696927, 50.74208298037129, 53.448373271572976, 53.92689066548502, 55.845294460173584, 55.01185747884936, 56.298183087379705, 56.07205844694569, 57.745702420511556, 53.84876489639283, 56.249086779932824, 44.0064908612159, 49.799078510653594, 58.55039627321305, 50.609255836855986, 52.404728627973995, 45.88304688853603, 42.331532893642304, 43.160412080826305, 42.5850905910615, 42.194269549462106, 41.5412929750258, 46.139244341081195, 48.815340226696385, 49.85167749466435, 49.8642094673649, 47.367373743364894, 42.362323499494984, 42.85376118075463, 44.459767803069084, 50.84631604533042, 54.40716135886408, 54.983408527989546, 57.12072372436524, 52.69836510381391, 55.769737843544256, 56.31535914636428, 54.89355487208213, 48.2812193132216, 44.83364812789425, 46.25898645770165, 47.40865276705834, 50.654131673997455, 54.442627429962165, 53.95188793059319, 53.81640534247122, 57.323247463472434, 57.44330336970668, 59.77818442929176, 50.881260441195586, 39.54665791603827, 22.39945580882411, 8.248868027041036, 2.5197649194348246, 4.564971097054021, 10.059648848349049, 12.394509315490724, 15.515211743693198, 13.229985929304554, 12.997509990969013, 3.2546040559968645, 1.3300190962130025, 1.6310814768075945, 5.271691497295134, 17.885417669050156, 37.34777327506773, 46.83904617063461, 53.41273853855749, 59.07422880972586, 54.26952146714734, 24.99606486289732, 5.87375472630224, 0.21118430180415032, 0.0990064837218773, 0.1721457941758056, 0.14886289594634888, 0.1391357856412088, 0.1635503489524126, 0.13804492240230884, 0.18198167364443504, 0.2869817458333508, 0.10692470722020635, 0.14039590834609925, 0.13510011106489167, 0.23243826213142565, 0.10345136416294884, 0.19078728742897513, 0.05986950315174557, 0.1365010407302649, 0.18314081063914686, 0.07988087652671723, 0.09721397587488737, 0.18132715876544678, 0.12736729616599698, 0.1304103659405824, 0.16512334196557923, 0.1128340719808494, 0.2398512812872087], [0.009590089734223102, 0.0694742538936196, 0.04014483818243589, 0.05411192722197983, 0.05817646799128383, 0.008687302038343924, 0.06754827054758226, 0.08383310114544246, 0.06953607718910902, 0.037861593563349984, 0.038548494809337204, 0.013464166681402394, 0.03702221017691397, 0.0685757783151442, 0.0346843128453099, 0.04897218971182743, 0.04087656323287276, 0.07687614179186283, 0.017337048531419808, 0.05969500747479259, 0.0511582101124429, 0.02560669762803422, 0.0711005283219199, 0.04040355373534464, 0.04374197338737788, 0.014652573022871249, 0.041678687933111386, 0.0016617918205860582, 0.05364616874665503, 0.055688030552119024, 0.14625013775883183, 4.738082943424102, 17.75984887153872, 45.3480238299216, 47.73166779548892, 34.07037804203649, 24.347463692388228, 25.451230425988477, 22.56795298668646, 16.17788245601039, 2.749935729849723, 0.09525104410826199, 0.15288453579189318, 2.486014885287131, 1.9032152742147448, 3.7063024890038276, 6.773517026055244, 3.1559486014227716, 1.5903191028102752, 5.297969416264565, 17.46573386653777, 28.927303514172955, 42.44036689881356, 53.465164938280665, 57.00953237472042, 54.205033779144294, 53.04245502718034, 48.99747156327771, 51.23534456376107, 50.79407399700534, 52.6835189327117, 53.75458094381518, 52.464544773101814, 50.30073004384195, 52.189508176619015, 53.09121793316257, 52.93043997979934, 50.80862599034464, 51.72101243849724, 49.41085800047844, 50.43304335686469, 47.08309212038594, 46.05164604802286, 40.91753413600307, 38.366110786314934, 39.029905257686494, 38.38294952146469, 36.25004306916268, 39.29185682727445, 42.6436633448447, 52.11624614654049, 51.54185033613636, 52.612182786387784, 50.53007102781727, 52.78830112949495, 48.899843769688765, 49.818121617840184, 48.36165535834528, 56.12513596011747, 41.66163129191245, 42.65768581821073, 55.43334753282609, 48.85517189579625, 48.81576776504517, 40.9661126905872, 41.29333642221267, 38.52666124220818, 41.87516120172317, 40.47457695007324, 43.764594370319, 44.74632440074798, 48.80522051165181, 47.23473487361785, 46.00891966973582, 43.97040897800077, 40.01805228571738, 37.35387256068569, 39.26706352541524, 40.28647184371948, 47.458262904997795, 48.41164596619145, 52.194611180213194, 50.33024195701846, 51.986035223930116, 54.43982293528896, 50.34298181533814, 48.31707369896674, 39.34102373738443, 39.20772590944844, 45.62578255130399, 50.05433067198723, 52.61391647400395, 54.180056125886985, 53.87837879119381, 52.78367665506179, 54.98838993810839, 53.05825433423443, 45.542392961440555, 29.559189504192723, 13.825444867534022, 3.6214429909183137, 1.4776969460710403, 3.304806962128609, 5.823376294105284, 4.003801518870938, 4.37147077052824, 3.943058958938045, 3.563107785678679, 1.2097322604348584, 0.2909308677959827, 1.4673103872806796, 5.507702471748476, 15.077626243714365, 21.71116025217118, 29.04545903205872, 42.715925170529275, 45.182248776958836, 37.49905517024379, 9.101435388288191, 1.4478274843385144, 0.10710536607451017, 0.00658873201069993, 0.04860900274868454, 0.031619495749774004, 0.05450252098061385, 0.03991059147782865, 0.0689447645638739, 0.06880345964624036, 0.04756169926915919, 0.05888097393777102, 0.01405932698323722, 0.034383431813048745, 0.05601995729751164, 0.019219975820892764, 0.025896089256650982, 0.0148186685457345, 0.026586280850272988, 0.019187775230215445, 0.035340628030920224, 0.02036559902462027, 0.03592436787702384, 0.06375046244131462, 0.01951427615788435, 0.018391756250733332, 0.0025073193518760344, 0.03542000623119455, 0.009480897307155595, 0.03577840131437106, 0.08269949020036767, 0.010166672403894125, 0.06445812467004984, 0.08552885208759578, 0.04016534252572925, 0.07376833758767574, 0.021991919418196046, 0.060695116107742635, 0.010494412478780555, 0.05008791633430989, 0.01762964623799968, 0.06906962923465237, 0.03767705064327006, 0.019721797885253065, 0.0185655509572356, 0.056514332987247944, 0.06908285191222545, 0.0416832001909854, 0.0448798667639494, 0.046683839116726196, 0.03764415482780145, 0.0522460243214042, 0.02167177702029867, 0.03572573276957677, 0.017906075658937617, 0.07149422856708688, 0.06355044837560385, 0.07180155239879124, 0.22756752107412587, 5.749079248597545, 25.02370776668672, 52.18951994372953, 52.8707964189591, 39.155715280963534, 31.693154996441258, 29.3817336328568, 25.727388820340558, 17.309313666435983, 2.5396432463199865, 0.15082743649761524, 0.08344637230038644, 0.9351129060791386, 2.68271537557725, 4.9326251495269045, 6.332208216190339, 4.024071837625196, 3.647041359255391, 7.216899789148762, 19.86185489162322, 31.39912824476919, 44.269677977408136, 54.96148640109647, 58.762302321772424, 56.98473907286122, 55.973297088376945, 51.24901402381159, 52.76160547810217, 51.722326432504964, 53.40986736359135, 55.0357251013479, 54.169999168765166, 50.188730685941636, 53.37462878996327, 55.271032010355306, 55.74590944474744, 53.80009612729473, 52.46319547776253, 52.82823085784913, 51.125506431825706, 49.50568129939418, 47.195299363905384, 41.97652309171615, 40.11467987491239, 41.178316839279674, 40.31110432840163, 37.97517991835071, 40.462786305335264, 46.337276966341086, 53.414068222045906, 53.28514775922222, 54.906514383131466, 54.376417821453465, 53.81014916204638, 51.22243996589415, 52.73503926492507, 50.13707699314241, 58.80715462469286, 43.91590372208626, 45.11623528695876, 56.93829428765082, 50.53220087482084, 51.762883740086714, 44.11756846212572, 42.36053489869641, 39.10553639934909, 43.50855381258073, 42.4115845464891, 45.02251417406144, 46.55957337348692, 49.687851859677224, 49.79128083875103, 49.46809322603288, 45.233506310370664, 41.003049650499904, 39.58066094306208, 40.45479251492409, 43.140321700803696, 50.27450899924002, 50.85809100058771, 53.1739995556493, 51.5269257176307, 53.747261801073634, 54.92254903239589, 52.849078255314986, 50.853097823358354, 40.82315014254662, 41.61470013280069, 46.90602848606725, 52.20328354066419, 54.06968847397835, 56.13171377489644, 55.6617118466285, 55.18832099053168, 56.87733673280286, 55.52432690897296, 47.1470973568578, 33.47898267930554, 16.07545172014544, 8.34272740348693, 4.158340452178832, 4.927040184697797, 8.034955686138522, 8.193983772108632, 8.441078874372668, 5.802547527897743, 3.8151311009160938, 1.1245847132898148, 0.25108211493540195, 1.48288881586444, 6.088100489108793, 18.483520284775768, 27.632746811836, 34.25904404732489, 49.02263356793312, 52.70430749462497, 42.72983781753048, 12.40642253429659, 2.1104692691756837, 0.05757258003277164, 0.045786753987833384, 0.011437586414807988, 0.03374267204274093, 0.08517424530920484, 0.04056101161686163, 0.0613085035565159, 0.034613583777700706, 0.06899760164801153, 0.026252768302877105, 0.038618856154742746, 0.05696678834576761, 0.05472714179045251, 0.0673051065795364, 0.02315264029969131, 0.04695358250530497, 0.052826121419427864, 0.032336988801797556, 0.08773502443105945, 0.02541727664309644, 0.0989478703347906, 0.017461417160267313, 0.02312502474524081, 0.04242941579451004, 0.04456694282951855, 0.040404484532172644, 0.06101254080872863, 0.268897382362235, 0.1833771027985119, 0.10762931658856331, 0.1716565704273601, 0.2145249660938017, 0.22211415482865227, 0.21927109528933802, 0.18078044777916324, 0.14247804339374268, 0.14245844686463957, 0.24273454512078918, 0.15797143621790796, 0.18214690348794385, 0.19512573527472635, 0.19441960139140008, 0.11266128851040719, 0.15881816255709819, 0.1579835250853531, 0.2398436357297244, 0.10285294990265563, 0.08943036934661289, 0.17722995200705144, 0.12581202276651898, 0.1395144935456976, 0.2084306600473581, 0.09635583482562535, 0.12294166751446263, 0.31817987981823187, 0.13164577464903557, 0.3212270098588159, 6.819534763213127, 27.907763796467936, 57.69635900374382, 59.57762187527072, 48.41914946033109, 38.411822088303104, 37.142684305867846, 31.71776394690237, 21.17518013523471, 3.7894278091769067, 0.4134153033937178, 0.6823276704357517, 4.75577381349379, 4.20097416447055, 11.60551671058901, 13.29899807130137, 8.704764131576784, 3.263450961920523, 7.053490905992447, 20.292815508381015, 31.917453773560066, 45.45863074641074, 56.788636253726104, 60.726994006864494, 58.38513505074286, 59.38127586918493, 52.01171890381844, 57.46163652789209, 53.74081342451034, 54.969448812546275, 56.99040297539004, 53.574504929204146, 49.219560084804414, 52.56758543752855, 55.89227268772741, 57.78887202662807, 55.860199466828384, 55.36458446133522, 54.93546147500315, 54.692278446689734, 51.36463372938095, 49.869606648722005, 44.284371176073634, 41.8251274478051, 43.54436897462414, 41.92676782608032, 39.75664200321321, 41.91758163513676, 45.31341675789126, 54.929428869678134, 55.33807316134053, 56.945433001364435, 57.110717758055664, 55.61335686714419, 53.818448897330995, 55.76765898735293, 52.87882158833166, 58.954431779922984, 46.91128838446833, 47.01703940668414, 58.067929052537494, 53.59217128446026, 54.51155916337044, 45.88934229266259, 45.596647185664025, 41.244051840997514, 45.9355164343311, 44.02013286467522, 48.65950445975027, 48.638947317677165, 52.61777608625351, 51.42041375560146, 50.44017422583796, 46.49742734047675, 43.33255314057873, 40.77727802338139, 43.37931956014326, 44.16528801764212, 51.7540309506078, 53.22217410610568, 55.38456893736317, 51.51862598234608, 53.58211432733844, 57.779399502661924, 54.354966378981075, 52.39713099695022, 43.15266539973598, 43.24864972022272, 50.785064312719534, 53.39901024295438, 57.17041230970814, 58.08113175053751, 58.21813621828633, 56.57809126761652, 60.42833297483383, 56.343788485373224, 50.61858715549592, 34.64482876562303, 15.955733137746012, 5.252199769020081, 4.153926805142434, 7.83856898546219, 13.079271797210941, 12.099197006994679, 13.493408387707127, 13.537646839695594, 9.659082678056533, 4.1593082970188515, 0.8309375735059862, 2.1962723424357753, 7.548937739864473, 20.212416725773966, 31.376037251564767, 41.51892762030325, 54.43459833821943, 59.33093224802325, 47.459580821375695, 14.611194652895774, 2.6295400482992974, 0.26100333659879627, 0.1241951482370496, 0.1333458616488403, 0.0883200781179532, 0.17906272543534157, 0.11823191217357114, 0.16256591064795373, 0.2281358510616326, 0.11398888057878903, 0.1351428894145835, 0.11370633969143515, 0.13545157688279308, 0.14582718061583658, 0.21457770358650916, 0.07591753597221068, 0.09847641216530915, 0.14383611810063163, 0.10365485243739621, 0.2648239090077339, 0.15731618589451238, 0.11409827793437628, 0.1648288884110028, 0.10383180342614652, 0.20985562955179524, 0.1431254489767936, 0.1289291042954691], [0.055272749610125065, 0.012398806509501752, 0.04751725850867168, 0.014116025150513217, 0.027320394179813808, 0.0171080514443137, 0.06353974995774127, 0.03815172255159386, 0.06258071512885152, 0.04811095366735132, 0.023917096456693068, 0.06363227805723587, 0.06183573292688497, 0.021143984575305256, 0.07447372070483624, 0.033988341118299195, 0.07480378202613323, 0.05910272957877286, 0.008077186742617239, 0.010248467611569551, 0.05368397518571827, 0.07073292869233316, 0.08803460311384932, 0.029158622154124805, 0.1115696668444622, 0.010005073817146402, 0.06738716225710607, 0.00790700701350767, 0.059379302641196605, 0.03143646393812472, 0.15431852981207833, 0.45821980242767646, 8.291396325634372, 37.64527720789756, 42.086573031640825, 40.12769429914413, 26.93348626936636, 21.258377528959706, 30.722709624998032, 21.51373755547308, 3.7060666564972173, 0.5157446705045239, 0.07054497668099019, 0.5261757236815269, 1.265099702342864, 3.2527600517196045, 5.417668877109405, 5.8822559733544635, 3.1221907225347336, 2.990167174608477, 10.58460122154605, 21.775428287444576, 36.50913915326519, 49.165894216106786, 55.94598170249693, 55.883663085199174, 53.56486374332059, 52.75178778556086, 53.679051783777055, 52.1420318080533, 53.650830330387244, 52.09744230393441, 51.453079254396506, 50.05748817997594, 52.74266827491022, 52.41488364435012, 53.29997431847357, 52.39920985314154, 55.60025222839848, 53.11205356351791, 54.02868009382679, 53.22399408586564, 50.33917319390082, 45.94491443326397, 41.89767168414208, 38.79633988103559, 41.051451698426284, 38.21375808408184, 36.98378909018732, 38.89372841004403, 44.298381882329146, 47.1793863081163, 46.896191181675086, 48.25049538766184, 46.27415818552817, 44.45789291012672, 48.306432308689246, 49.09339704821187, 54.75339681871476, 43.64708015995641, 44.01832857439595, 57.040491642490515, 46.79943023189422, 51.953840409555745, 42.50489381051833, 40.09824514389038, 40.93603203373571, 43.122212117718114, 43.660977117476925, 44.99158236288255, 47.84081166790378, 49.44835585932578, 46.918780111497455, 46.09779273310016, 43.31418860343195, 43.92343467281711, 39.43927518783077, 40.19507277396418, 37.772875831973174, 44.46977769174884, 47.920757416755926, 51.69803519402781, 52.62551884497366, 51.70595838177589, 54.43630849161456, 49.86431537135955, 48.15078873788157, 40.86488808355024, 40.254834005909586, 48.2509974510439, 52.974252854624105, 53.28358273352347, 54.07072005733367, 54.12482130912043, 56.877634832935954, 55.31071462938863, 51.96221466987364, 35.11713312518212, 25.751213296767204, 11.776714440315, 8.158264217838164, 1.541546023180408, 2.66334401503686, 6.08180606557477, 7.526057574056811, 6.158816900945479, 2.937201203838472, 2.2356833373346636, 0.6828244631328891, 0.027496889346249165, 2.7670009818769272, 6.4911509906092, 9.926860928535461, 25.809640922854026, 33.34642225696195, 41.44301799035842, 34.303339373680856, 21.610055277424475, 6.59206033714356, 0.7709007337689401, 0.04956128068208214, 0.06722302791932899, 0.043215939114170696, 0.03498867957762653, 0.060041589482176694, 0.028951085104997602, 0.06297034744714057, 0.05398330105949314, 0.046169472362605796, 0.08404828758249361, 0.04548375855290121, 0.019121137072121906, 0.04082231271651484, 0.013057441983912742, 0.023893091091585737, 0.016944091391539382, 0.02748631541767428, 0.039502599862434214, 0.04175328957517782, 0.05064129228553465, 0.02430566774320699, 0.04211990095134224, 0.04801247306468506, 0.018130709875314947, 0.05779997025045657, 0.009466181715740072, 0.012629816492628908, 0.025777514167730848, 0.05154165244030376, 0.016526770740447026, 0.017967213305734822, 0.03204043808152839, 0.0563690903776836, 0.011422863162513222, 0.048274287443247535, 0.026178120695535215, 0.019196025997159943, 0.06285964391164242, 0.06389990321270402, 0.0660367637512184, 0.07704400697783118, 0.04098463142591138, 0.019198548341650638, 0.05981796075619998, 0.04666082200504119, 0.012104650771605873, 0.014469408103445125, 0.03643887635741023, 0.07022094447165728, 0.03457442136301148, 0.08025668861885225, 0.07549192816499742, 0.05948706056862589, 0.01649851358735994, 0.037945319312594594, 0.02258535985264086, 0.0878922256731218, 1.316080340935338, 12.049346623882172, 43.96393314484627, 49.855631243798044, 47.33078195202736, 31.141140230240364, 22.997479977146273, 34.28101716503021, 25.384897262819354, 4.392601068942778, 0.34092910587787634, 0.17328922636806968, 1.1958204714521286, 2.4074255410702, 5.7532418639429155, 6.128658777283085, 5.920720696449281, 6.09172034648157, 5.080138627559909, 12.569280324443696, 23.996892052312052, 38.621190363360995, 51.856981400520574, 57.98011895148986, 58.03705607691119, 56.38923698855985, 54.10784136864447, 55.945452182523674, 54.697840367594075, 55.44254549088017, 53.53702275983749, 52.12628741418162, 51.42469698382963, 52.432616679899155, 53.02481612851543, 55.40032902071553, 55.41122536505423, 55.70797620281097, 54.8643292919282, 55.92990390716061, 54.98136497312977, 51.61300997580252, 46.76186569275395, 43.78824626245807, 39.6012023956545, 42.568181253248646, 38.50304072903049, 38.74303487039382, 41.89323940584737, 46.756064507269095, 49.55407942495039, 52.11262579887144, 50.017240739637806, 49.79405395446285, 45.98091002433531, 50.60406654111801, 51.60893071082331, 55.334252772792695, 46.75571933869393, 46.60776753579417, 57.038530457404356, 50.366527803482555, 53.779386012784904, 44.94683596395677, 42.51522141118204, 43.041022977521344, 45.23497719918528, 45.222453071225075, 46.94441280057354, 49.78104345260128, 50.631476063882154, 49.721988247286895, 48.809915588748076, 45.50908811630742, 44.176780562247004, 40.05265151300738, 42.02018691647438, 40.56728216909593, 46.47777234354327, 50.627694899036044, 54.30031207300002, 54.09903564760762, 52.80371996664232, 56.11907589820124, 52.13704647556428, 52.24910074664701, 42.80120534281577, 42.199909917769894, 50.95707593425628, 55.34456076160554, 56.15652276623634, 56.520161782541585, 55.93141009730678, 58.33406971346948, 56.543594021951, 52.41538963010235, 38.33795993558822, 27.384264661419778, 13.506046264402329, 8.083673975160046, 4.555325988800296, 6.050227063317453, 11.044923720821258, 5.660927411048643, 5.844682118585033, 5.120060020877469, 2.4051493406295776, 0.4799378434977224, 0.10542791697286791, 2.6940483287457497, 8.763445731132261, 13.745604042083988, 27.604515552520756, 39.189890892274924, 48.313194474866314, 42.81831472150741, 27.709884143644764, 8.32725561434223, 0.8211852129428618, 0.04575022308516406, 0.06451527482920116, 0.011878444159763956, 0.053607829876484415, 0.08257819549931635, 0.02723882496807604, 0.0204501157596467, 0.011013712839133317, 0.018525714385173014, 0.02464848825888288, 0.020295591994879708, 0.0506662859040643, 0.02208924705853626, 0.021694880316875154, 0.058483473896499605, 0.04921767875672348, 0.04234888846234929, 0.035989393420036764, 0.02686033348342584, 0.037381225791309154, 0.02081889707985665, 0.05413626966577384, 0.028250197008732828, 0.028583259479473197, 0.02965928168006001, 0.015025794780212305, 0.07307302852671954, 0.10488247003165946, 0.12199721133877194, 0.10589307789961178, 0.16691946574757177, 0.0989837538931639, 0.15798219209236486, 0.1001262054928849, 0.1277090250063808, 0.10034793432080939, 0.14344003532202015, 0.18515445742635958, 0.14997019943210388, 0.16939768357382667, 0.149608590610085, 0.2647207629296088, 0.23124388509219695, 0.13809697041588445, 0.16482626839030176, 0.12287276556655286, 0.16820278559480945, 0.11247112250496304, 0.1314736959794837, 0.1184532962619297, 0.16262606387176823, 0.17034564077133135, 0.15875667634029544, 0.10166840943237467, 0.18652947799813363, 0.1273972042385609, 0.24935189003665603, 1.1822330134530221, 14.250361111856277, 50.70308285374796, 56.8194386266893, 52.253211390587595, 39.38139669356808, 33.639741020817915, 39.428916208205685, 27.06186152273609, 5.97293822996078, 0.8518376778210364, 0.49897175762922535, 2.9728859470736597, 7.143752488397784, 9.307964847933862, 13.654161826256784, 13.614832220538972, 5.049511780661922, 3.9142209579867706, 11.841114855581715, 24.4719087308453, 39.24647108201058, 53.434323341615745, 59.661905765533454, 60.17369270324708, 60.13553588621078, 56.629945001294544, 58.23912089870822, 57.9389811331226, 57.73425694434874, 53.02856983677034, 52.78779514374272, 53.359480596357784, 52.36058235168458, 54.73608739914433, 55.38673016332812, 57.984527695563536, 58.039350663461995, 56.82479658434468, 58.397125736359634, 56.910523906830825, 54.59479578079716, 49.7984823103874, 46.14227241085422, 42.06948326480004, 44.326834755559126, 40.37684717485982, 39.38542496773505, 44.583224404242735, 47.90556607707855, 50.928881937457675, 52.01952049809118, 52.57708149571573, 50.22531463253883, 49.1033677131899, 52.14782907116798, 54.66559848477764, 57.275696569873446, 49.945782999838556, 49.54894112002466, 59.55845717460879, 50.80926141431255, 56.327934265136726, 46.05394847931401, 43.91686862514865, 44.145703623371745, 47.09157620706866, 46.74234013403616, 48.35739566433815, 51.199909871624364, 53.11295963102772, 51.45958254414221, 50.518637318764966, 46.441180552205736, 48.14923547929334, 41.16146241464923, 43.818405366713, 41.88182138627575, 47.88618172368696, 52.51414706630092, 55.470331561180856, 55.48602496424029, 52.48496855458906, 58.85860435424313, 54.32605458844093, 52.96727495808756, 44.23649080338017, 44.50416903341971, 52.8927852261451, 57.480259941470244, 56.78042673295545, 57.86467575257825, 55.655745921596406, 60.065592181298044, 57.31634016959899, 55.35187598197691, 38.078251961738836, 30.502503841154038, 15.360821370155582, 10.684789342264976, 5.144821943775301, 6.7659767596952385, 14.811273774793072, 16.36454903310345, 15.695931027012488, 11.868902887067488, 6.4543179735060665, 1.2797196017157648, 0.5342242434140175, 3.781658574458092, 10.752447285959798, 16.853751943957423, 35.98323952767157, 46.61893452367475, 54.74539518356324, 46.418430805206306, 29.85626589867377, 10.057002229075279, 1.1663368728853043, 0.20401578727028064, 0.17809904811363067, 0.15556536855236178, 0.0924695780380599, 0.21793085510932633, 0.09519622285640049, 0.12460440772795871, 0.14477403954632823, 0.2123339086650841, 0.14927783980965614, 0.12959196953283203, 0.14534863613305554, 0.12125017602116832, 0.15140344268612324, 0.2121255327496798, 0.2480433965402265, 0.09922537802448196, 0.09021596186944554, 0.12284342439905291, 0.15178333036601543, 0.1885680226428855, 0.15784412772665102, 0.13450443173848814, 0.23672745052364566, 0.13369715892739836, 0.1425397441151642], [0.03960501432659165, 0.04885820348957374, 0.024375086800465663, 0.02719552759381552, 0.01238207419162556, 0.06043303359840667, 0.08875880135043014, 0.050435134194671154, 0.04214703195518063, 0.021442630546047323, 0.029759916905013305, 0.07088413912682764, 0.008825157645098385, 0.03157637074529644, 0.10195320261822594, 0.08218356062688174, 0.05155222828409845, 0.020658664044833953, 0.02547922442787357, 0.02963477644258209, 0.016757983736874118, 0.018177414425618706, 0.03930983298848714, 0.03216644996897348, 0.009637920433775553, 0.05105652343181353, 0.04862807833799913, 0.04060577796471696, 0.04799366560614398, 0.07418246173690404, 0.03187447087839246, 0.2995544744114722, 6.25985715658434, 25.350403939524007, 39.32767983405821, 37.58414314639184, 31.426427941168512, 20.66201840677569, 28.714136423603183, 23.64267456916071, 8.522885787871576, 0.714998072193515, 0.049615266898106185, 0.5890603880247762, 2.006459901890447, 4.531263718681951, 4.452696192649103, 0.7854617975892559, 4.745858551994448, 3.495983039179156, 8.94262646475146, 19.949045258183634, 31.872287681025846, 45.134078148872625, 54.52703291370023, 55.18284536177113, 54.599000561621885, 53.11046500359812, 55.47337532043458, 54.37772789309102, 53.98364736187843, 47.52004807995212, 47.88879009985155, 51.951769398104766, 53.92164645656463, 53.43164044041788, 52.92768647593837, 49.42869301765196, 50.76767252337549, 54.39633953955866, 54.38644339961391, 51.6454440547574, 51.29251703139275, 48.47509814846901, 46.47310472303822, 39.99011716535015, 39.817744685757546, 39.69816730868432, 42.1012976092677, 38.81516725786271, 38.60452813486899, 37.64708542054699, 39.048995433315156, 38.330613336255475, 41.07952017937937, 39.527595197000814, 47.66996106793804, 48.29269616834579, 56.928621722805886, 42.616853944716915, 43.574559457840465, 55.864317955509314, 47.177644775759795, 51.589095284861905, 42.40853294249504, 41.19730111091368, 38.89042969672911, 38.93174794412429, 41.161309442212506, 44.97657537460328, 46.50198905698715, 44.95838734411424, 46.718092041630904, 44.11375199594806, 42.39372599509455, 40.526822920768495, 39.5257830619812, 38.727145348825765, 39.53635777196577, 42.530157796798214, 49.06723483916252, 49.13163623502178, 53.029695557009795, 51.70253807498563, 52.97839487752607, 51.830772123029156, 51.12465919986848, 42.671888720604684, 38.267678906840665, 47.38012536879509, 52.94286604850523, 52.68746091473488, 54.31586819310343, 54.20989359578779, 56.55064252115066, 50.98508557965679, 45.04984917179231, 34.262825212171, 20.179859092158658, 8.50535475438641, 6.334182148979557, 7.064034727311904, 9.743901971847782, 9.633684350598244, 4.038627263038389, 6.588573840356643, 3.8459101848063932, 2.140570028174308, 0.2158775709329113, 0.444861312787379, 2.970505068379064, 10.008537423226143, 23.827412320721535, 25.153502918058827, 31.923068646461736, 40.47660481545233, 30.432985713404996, 11.335386018599234, 3.5297164032536172, 0.12598823064998274, 0.05097411152335906, 0.053022948559373624, 0.04191673443382306, 0.02063415497691641, 0.043810875335287665, 0.03770584405790414, 0.016206268281225237, 0.04448474542568288, 0.07436646839543697, 0.0631376380671657, 0.029315132001835494, 0.020390221090506644, 0.0319243221348452, 0.03937690781669752, 0.012031749844731343, 0.0737945684382031, 0.04092477697638735, 0.036265119955304174, 0.0779969897121191, 0.016555937622944196, 0.06655496860583944, 0.031728155745734135, 0.023461362241857478, 0.053182168443116455, 0.04884561666497781, 0.01608401213982894, 0.0443675569559057, 0.011955493452748465, 0.01457400591818676, 0.017607965949742545, 0.03588590260234571, 0.052729310888436534, 0.06737733334903756, 0.0028604413561087345, 0.03687921220496778, 0.02846434731186638, 0.05852707579071003, 0.1062294058201294, 0.013001902524622218, 0.03263943265342424, 0.03328667735801109, 0.07248946871127813, 0.020697504702594974, 0.01089076817621507, 0.0663826447881518, 0.05492998272060387, 0.031299332284458706, 0.007373842855750193, 0.06522314773211557, 0.05029287166713227, 0.032849562910175135, 0.02499873791220448, 0.05974641963539105, 0.014106385849205958, 0.06609036692328031, 0.01296856908142687, 0.046247613330882405, 0.3897229924557671, 6.924407174510341, 30.575248118369814, 45.36112846866731, 43.37081193923951, 37.2573273412643, 25.297771615366784, 33.57038567143102, 28.87094689953712, 9.17632127961805, 1.2715474660358121, 0.0717939221630654, 0.3954765272717322, 1.920645306667974, 7.436784428934898, 7.345911447078952, 4.398000211484971, 8.637939691543579, 5.127613525236807, 8.780373700203436, 20.82609115108367, 32.695075427332235, 47.87011961783133, 56.300269788311375, 56.72562337690785, 56.043452601278986, 54.64184461101409, 57.34548337997929, 56.00262465015535, 55.493850092734064, 49.586246782733554, 49.9049158250132, 53.801531714777795, 52.44647833608812, 55.08667276751611, 52.938331788586034, 50.62811459264448, 53.47379807502993, 55.65982518657562, 55.60043265742641, 54.00108621966455, 52.56339634618452, 50.533185389734086, 48.75195080234159, 41.122426986694336, 41.92775626336375, 41.57400161989274, 42.80174270752938, 39.59364006596227, 40.606980477609945, 40.40716317392165, 41.87822457282774, 41.444673230571134, 42.43046683649863, 42.26215008766421, 49.75925468629407, 50.26871565849551, 58.111055512582105, 45.75329488323581, 46.23809199179373, 56.464283697066776, 50.40906590800132, 54.44889537749752, 43.391961359208636, 43.164550181358095, 42.32015802014259, 40.391458003751694, 42.918119430542, 47.25381720450617, 48.18478392016504, 47.383757483574655, 49.05461657431818, 46.03235975388558, 44.62850424551195, 42.55140135365148, 41.41348646533105, 40.997805441579516, 41.45753075999599, 43.591551165426935, 50.00745442605788, 51.933816709826075, 54.74698374348303, 52.530613176284305, 52.534308048986624, 53.57499130310551, 51.9699142825219, 43.818468124635764, 41.51772737503052, 48.829350932951904, 55.038180505075765, 55.19502432115617, 55.95963547306677, 55.733546133964296, 56.24512126368862, 54.13729836863857, 48.40356980600665, 36.50070997976488, 23.277027299327237, 12.243440208896516, 8.417724101774155, 6.466466044226001, 9.134395064846162, 7.526412548557405, 7.499121677490973, 3.8012240923220113, 2.088774149456332, 0.6225994722016397, 0.21654158530216064, 0.19065270110243754, 3.061001502698468, 10.798775380657567, 23.416828417008926, 28.750341861478745, 37.753801345825195, 44.96199592467278, 35.17514498003068, 15.311608372196076, 5.156591996069878, 0.19714445356399785, 0.03753315634845245, 0.04374622134491802, 0.019790906676902406, 0.0033002225081286128, 0.029518332993311268, 0.01440661091868195, 0.06289389953317662, 0.06449465174227953, 0.1317466531069048, 0.07782465057267297, 0.041305714196735815, 0.035753836705079006, 0.09958904762301715, 0.03032273488990482, 0.06470043828049976, 0.013636420593566954, 0.02917357427518695, 0.022335048284261458, 0.05388779670841271, 0.03502435629226027, 0.058724178722308534, 0.013432907421262035, 0.024859909373786182, 0.09964568450325921, 0.021098747083376494, 0.025905933486477985, 0.11794434574943398, 0.1536465174848995, 0.07783189776443666, 0.14359846230476134, 0.12001557936591488, 0.10206133592873813, 0.1662840111361396, 0.12240034212628681, 0.18477237873500396, 0.09222121999388741, 0.1876815669839421, 0.19858030151695977, 0.12755592999559257, 0.11297584421211675, 0.14826979067537094, 0.24438661372950002, 0.21865077857528964, 0.05558800628228534, 0.1892516948282719, 0.12398998223004803, 0.1729423877212309, 0.1345670670871773, 0.14921626166230248, 0.13581372196635894, 0.1462458170229389, 0.13668101010543687, 0.24986359080479992, 0.1330675572277077, 0.15724777424287412, 0.11112741960753357, 0.10188957901611444, 0.5776377719256186, 8.609007308560034, 33.799448167124105, 51.985646909283055, 50.883915885802246, 42.84220980059716, 31.946298883807277, 37.467833103672156, 31.320251341789003, 11.154283323595601, 1.5403723764804103, 0.35367797339154833, 1.8640328799524617, 5.113508191800887, 13.101089981294448, 11.975526636646642, 3.2130396798733747, 9.25030698699336, 6.145742170272335, 10.92489625177076, 20.97835167761772, 33.74754344263385, 49.05743675847208, 57.98786955495035, 58.07116893029983, 60.62209806134624, 57.319289791968565, 61.111033270435954, 57.350005872787975, 56.55033657627722, 48.386680080044655, 51.18105503820604, 53.93723395562942, 52.997959659945586, 54.5815852380568, 52.99822245874713, 50.492914415174916, 54.1257469884811, 57.2084593003796, 55.847098750452844, 55.43947819740542, 56.48673534393311, 52.34603035834528, 50.36845368723716, 44.105020799944484, 43.926258779341175, 44.339888403492594, 46.27793542800411, 41.47537362190985, 42.78043639275336, 41.85926775778494, 42.365739883915076, 43.748261620921475, 44.49654002343455, 42.99191490296395, 50.65584967213292, 54.15793395811512, 58.49381608347739, 48.06299824868479, 50.878820726948405, 56.60799149544009, 52.3990882596662, 56.10158212723271, 45.693137491903, 44.464737446077415, 42.573445074019894, 42.20595821257561, 45.51549726916898, 49.68571416793331, 51.620438944908884, 48.071745134169056, 51.05443308430334, 47.61948800856068, 46.78903595093758, 44.96409831508514, 42.69926294203728, 43.10817003250123, 42.55000106749996, 44.69410196427376, 52.24329171642181, 53.30629325682118, 56.04456263203775, 52.23840836555728, 54.33047509962513, 56.62125695136286, 55.52367971789453, 46.98677439843455, 44.007322403692434, 51.67494812319356, 56.993105488438765, 57.01229372332173, 54.846741384075536, 56.06933239967593, 56.88377334225563, 54.48061166271087, 49.52044510072278, 38.65728009131647, 23.189821243286136, 12.080055840553777, 9.797070680126067, 12.250666195346463, 18.761018168541696, 16.02493747588127, 12.422924926204066, 12.420299879966244, 8.839606392768122, 5.840348389840895, 0.49140051067356144, 1.0319030284881592, 4.637970328330994, 15.501868820959523, 32.71009418272203, 35.18944594167894, 46.77538218036775, 52.766833997541866, 42.017562850829094, 18.00673657847989, 5.185100272778542, 0.3104179076129391, 0.1368161939805554, 0.10952060381250997, 0.24439003048164232, 0.14037090323625073, 0.13939536687347198, 0.14569300797677812, 0.21509136553973923, 0.1525191118520114, 0.17974932407659872, 0.19983147631489462, 0.15816927076347415, 0.08217819801141178, 0.27384293956622, 0.16117719242409353, 0.13547121937717163, 0.18319802208533212, 0.12194755351952008, 0.14516923366294754, 0.1474191266442499, 0.19633252293832842, 0.16508626331004406, 0.10239485230657364, 0.11861854142719701, 0.21233954707220679, 0.13334743978996433, 0.1720900995837104], [0.066061676930516, 0.04658908936225119, 0.04476383125649826, 0.040137671429904244, 0.04850643506694225, 0.026762862201599825, 0.03256579245170278, 0.009560418191305813, 0.027188519804528164, 0.053052351013907505, 0.061954556994380496, 0.014261370224337426, 0.029891542301723556, 0.040183410709423405, 0.016903588322982672, 0.08577320349192427, 0.07874194893144792, 0.009234177733531163, 0.03337286224949264, 0.051209154959407546, 0.033908836513517365, 0.03322149093653406, 0.12605584557017974, 0.024849676354337605, 0.021659527274389422, 0.044127713979011586, 0.038207984048753016, 0.026225451522717075, 0.05363263963391224, 0.026257782348341523, 0.054479392786179824, 0.055891453709092834, 1.566722123853622, 15.316914358446676, 36.687963931791245, 46.830958243339296, 27.290247409574448, 30.2175691435414, 37.11142301559448, 24.7075431577621, 14.577056304101022, 2.575598142800793, 0.22413671887930364, 0.2526378250049968, 1.1710187119822348, 3.9306824101555735, 5.557567563749129, 5.909104106887694, 11.140964915675502, 5.267989760445011, 4.258570248080838, 15.272111085153396, 24.92295188288535, 34.527157660453554, 45.12520574754284, 52.82297488181822, 54.780351346538914, 55.711420043822265, 55.341434632578206, 53.582208464222575, 51.68053750068911, 49.045712794027025, 51.73240300147764, 54.59052039730934, 52.25505098219841, 52.61642679091423, 52.12844079540622, 50.80027526424777, 52.16747622336111, 51.430423644281205, 51.69952569469329, 54.67192919023576, 52.9014144405242, 49.855356677885986, 48.428555304004306, 41.75812944289177, 42.04609417146252, 40.011803950032885, 40.74579708037838, 41.06372871706563, 40.21775976304085, 38.90382459086757, 42.00082609730382, 37.96031805776781, 39.7093774426368, 42.5512719154358, 50.66202348278415, 46.93968242214572, 52.711963961201334, 42.911447478878884, 42.19630918195171, 57.660641900954715, 47.7851414680481, 52.224256453975556, 44.809517706594164, 42.613378724744244, 40.29352426528931, 41.29092416455669, 39.08954881852673, 42.68359307319888, 44.810321792479485, 41.592020988464355, 41.897361816898474, 41.676987371137066, 40.57992789053148, 41.61915986768661, 40.82912783468924, 40.54641123740904, 42.11636735546974, 46.22709366583055, 49.109627815984915, 50.21583034146217, 52.51275854725992, 49.436094530167125, 52.84292013414445, 50.626145562817975, 49.44074646119149, 44.711905602485906, 41.474604837356075, 43.56971925304782, 50.15815973281861, 52.38117087271906, 53.93553164697463, 52.605781478266564, 52.46654518188969, 42.22339314799155, 31.143481885233236, 20.712818984062444, 12.602275302333217, 6.095022001574117, 4.564343027530178, 3.7005964209956512, 3.1847194317848455, 6.1700167386762566, 5.160399146618382, 2.0826684899868506, 1.95474173513151, 1.0931629735615946, 0.4035180296388365, 0.7009462423382268, 6.004205894085669, 16.259351065081937, 29.060646449365926, 36.72998820581744, 41.571589362236764, 32.52079667583589, 25.78126257465732, 11.020096098223041, 0.6849840343479188, 0.04233163233185488, 0.06256127947821252, 0.01546929361328723, 0.030528661239171223, 0.06791626088201039, 0.0654872642048905, 0.06801982830849386, 0.03691881512021346, 0.11350355621787811, 0.024178077714637886, 0.019094017559602376, 0.025529659826368577, 0.07784077672347908, 0.054590674718060804, 0.027979610923437342, 0.061650094501073324, 0.03895739806936153, 0.04941224976773224, 0.04009003225233286, 0.025955846029964667, 0.012417321897021705, 0.02715073826332246, 0.06336637659959736, 0.038996974171529857, 0.04572340617737463, 0.033954748162819494, 0.029242018485561978, 0.017772971712533506, 0.049127494886277184, 0.00798191987879334, 0.027367594772048538, 0.041755331199496024, 0.07890746988836797, 0.043948441743850715, 0.025138522145308317, 0.033395645704360745, 0.06720876336217889, 0.235520770112353, 0.011017958881453642, 0.04372348768576499, 0.045417901804490436, 0.05472590838889441, 0.09579150381708339, 0.04180881945836929, 0.023618875664748976, 0.07622271475772704, 0.05403605387395909, 0.0593970567288418, 0.029896516127571948, 0.021712249445338404, 0.06275717582133028, 0.04232223626346358, 0.028208945089230136, 0.03992475644354859, 0.012648559791306335, 0.04027367118866213, 0.015537721544293868, 0.009686902180434236, 0.13245726094370888, 2.532876422328334, 19.48980239129836, 44.97929749950286, 52.836918907780806, 31.108445313669023, 30.307187457238477, 33.71967500255954, 27.367969174538892, 14.686800299152253, 2.66743480197845, 0.07746551621464953, 0.5393685544690778, 0.6378497087186383, 3.8992625090383717, 5.065225285868491, 9.599669556463919, 10.62715599613805, 6.160187769320704, 8.329911058948886, 16.92710614973499, 29.6151578041815, 39.494447246674575, 49.76882919188469, 54.77909618808378, 58.90379398099838, 56.195526815229854, 56.644814706617794, 54.82149308727634, 52.96928321161578, 50.19251577315792, 52.531703595192205, 54.285975810020204, 52.12958612749654, 52.8071520405431, 52.013672244164255, 51.87853874698762, 53.307975953625096, 53.06220808336812, 53.11168093835154, 54.57343063046856, 54.55210470384168, 52.85074526263822, 50.569553605971805, 43.62862933066584, 43.437802099412494, 41.32057336068923, 44.16787285958567, 41.70373401334209, 41.515322962114894, 39.719834481516195, 43.0903075587365, 39.86367564047537, 41.53327172802341, 44.39013788777013, 51.80716337696199, 48.43505859375001, 54.332400983379735, 47.14333580386254, 44.293180819480654, 57.51474934239542, 50.451502030895604, 54.31700175808322, 46.33814773251934, 43.15429318335749, 40.776826950811575, 42.47740976272091, 41.477476012322214, 44.44290161132813, 47.07533759455527, 44.533892754585516, 43.96934601568407, 42.782887874111054, 41.691123593238096, 43.37109434989191, 43.301131033128314, 43.12082359867711, 43.51393530445714, 47.641445436785304, 50.04408544109714, 52.9239563019045, 53.47875595092774, 50.14256046664331, 55.15232539946034, 52.980207012545684, 50.52485427548809, 45.98531092366865, 43.1562190671121, 47.62037446421962, 52.27433727633569, 52.77419236398513, 54.95516746274887, 55.136255448864354, 55.16181361290717, 47.17780167056669, 37.22423822649064, 26.60314033108373, 15.19175740980333, 5.888737690064215, 4.253882035132378, 4.5959460543048, 5.037040604699043, 4.494794991708571, 4.015549507833296, 2.46060797764409, 2.1548825117849537, 0.40423370897769934, 0.2820013163070525, 0.876889733537551, 5.865225532362539, 16.45828289370383, 31.49484584408422, 40.67696340622441, 44.96920916341966, 40.61829651555708, 31.12983595940375, 12.38498285893471, 1.2571564124476526, 0.06008852768929736, 0.0721767975858623, 0.044194267867433454, 0.028613592730835084, 0.06570117893598734, 0.02105665055193728, 0.01429455619560735, 0.05356919989290257, 0.018545086833558256, 0.01814410109223137, 0.0034346508290318233, 0.02355912846753434, 0.0364021462718806, 0.053782233622886484, 0.016892110410657142, 0.05765553203321273, 0.027468457908159303, 0.024692205066281944, 0.01796895232532294, 0.016436002727958466, 0.048484164890983415, 0.039132663664678415, 0.03495619361919742, 0.018635561817415783, 0.014664966410266296, 0.014053935639470095, 0.03245270638276012, 0.08050310079969707, 0.18963003501055703, 0.11194383184756003, 0.08578169174612531, 0.19352965237152195, 0.22678615735663524, 0.13674062706770437, 0.0990285700367343, 0.08608588227821935, 0.21195288717506394, 0.2880138501284584, 0.14055147016000363, 0.11681975932010721, 0.13044816471876639, 0.08452867067629292, 0.16225296373088516, 0.14980712995654152, 0.08664316527785794, 0.15981570096506229, 0.15409126216846128, 0.14518201200952455, 0.19170559702381013, 0.24483883543120277, 0.25925414336304514, 0.08171698243747796, 0.18862885002407337, 0.2071117783986753, 0.14473506099274083, 0.09872730596051102, 0.07256185635924339, 0.10070748236631194, 0.23157331822139604, 2.560572768411329, 22.12196576979853, 50.31420730775403, 60.18553826116747, 37.129497297348514, 41.04944344489805, 47.20990627042709, 34.277989095257176, 18.373764522614017, 3.9291718073429602, 0.37640464582270194, 0.7168060396948169, 2.475129817762683, 11.258653671510759, 12.929578461954671, 13.44818247902778, 17.67019525651009, 8.752987711660325, 6.458884102682914, 18.891001593682077, 31.44229392851553, 43.405658275850364, 51.29358783844979, 58.381753967654326, 60.301475678720784, 56.88427932800786, 56.98678655009116, 54.3988694683198, 53.80023733262093, 51.092331024908255, 52.98322331520819, 56.1322864409416, 51.76182470014019, 52.390058963529526, 52.318903246233546, 52.22839847687752, 52.6994437556113, 52.943493627732806, 55.507343046126834, 57.94479408571797, 55.69476958244078, 53.97822664630029, 52.62968440209666, 45.1003614548714, 45.334719150297104, 42.75227377491613, 46.36378042159542, 45.3939155609377, 42.79897351418772, 41.964093100640085, 45.484188910453554, 41.22332995937717, 44.075759918459006, 48.01404314656412, 53.175854836740804, 51.295054804894235, 55.364058863732126, 49.321016111681544, 46.725003257874526, 59.9391467340531, 52.64763709037535, 55.80152080905054, 48.86483269353067, 45.781775213056996, 43.364724420732074, 44.407047225582986, 42.307265189386186, 46.33853996953657, 49.4219857646573, 47.23957115604032, 45.26745834658223, 45.463576855198035, 44.112649809929636, 45.8591204304849, 44.614069923277825, 45.64527280869023, 46.17307086144724, 51.04845146979056, 51.4637912473371, 53.78240231544741, 53.719216854341575, 50.636339802895826, 56.97060285076019, 55.10948135006813, 53.29192561487998, 48.68185020262196, 44.86548992895311, 48.301513656493164, 54.98116100988081, 57.253201776935214, 56.15613837395945, 54.95719532812796, 56.73945757650561, 50.99869228178456, 40.25449275970459, 27.50317523556371, 16.068334579467773, 7.906682904689544, 8.214469330926097, 9.443758283891986, 14.700616848084236, 21.14270094902285, 14.859099234304121, 9.38645245567445, 6.931355162974327, 1.920334458831818, 1.601022883288322, 1.5928453543493826, 8.91491001652133, 22.697106830535397, 38.84898985585859, 48.87985144892047, 53.23957374019008, 47.09883651425762, 34.62297724139306, 13.89951490586804, 1.5423982806744114, 0.1912220423260043, 0.13735234827524231, 0.11769481559073734, 0.11654445030275853, 0.12536988278189976, 0.14784220636131304, 0.1701460442235393, 0.18999150593674954, 0.19844329435258143, 0.10396320282691911, 0.08515876267225513, 0.11526160543003391, 0.10940900012370079, 0.18125900758370278, 0.13711231760680676, 0.18900300736629194, 0.1606447766384771, 0.20555303462090033, 0.21638456792120012, 0.10965907420482367, 0.22692730139580466, 0.12339598063619868, 0.13616509585370942, 0.2186019634527545, 0.3150298794911754, 0.1343865001634244, 0.1713949514012183], [0.01644421136006713, 0.02045631532617394, 0.042971350222585664, 0.02713212807242188, 0.05847323130095198, 0.047059804426446084, 0.051737755627161076, 0.032929538659030394, 0.055115759042241884, 0.0012811153095343242, 0.020235731799696243, 0.053457711117282036, 0.06715744313213133, 0.033217028474375125, 0.02505402456247999, 0.019145276502615983, 0.06912826560437679, 0.025203727718983448, 0.021905148469452417, 0.03395713069626401, 0.024581371295836665, 0.0016515336638774664, 0.03766496943670415, 0.048969611825962225, 0.015909977073240426, 0.09919409099365435, 0.11175730475975622, 0.029079422069292878, 0.0198327848732832, 0.050153535595464135, 0.06591891644582634, 0.04328068886553088, 0.24199484126462092, 8.310188401129938, 24.192920346413892, 39.36950798957579, 45.63436861961119, 37.69638961361301, 35.091625951951556, 30.369362908024943, 18.911048827632783, 6.080389599646292, 0.7258093501290968, 0.4428314862232055, 0.8338384113965497, 1.5351563595956372, 2.394390524395051, 8.24779918116908, 8.316315143339096, 1.2157767554444652, 2.982333956226226, 6.168697841705815, 14.250770999539284, 24.428486131852676, 35.87891232582831, 46.28096742014731, 55.49819215651482, 55.39487300380584, 53.48102308088734, 50.44861516644878, 53.59494047780191, 51.94998079730619, 54.90647908179991, 53.690014808408684, 52.24724154318533, 51.83532991716939, 53.01408452372397, 51.22913545177829, 54.122114873701534, 51.998998657349624, 50.97000014397406, 54.70062917278659, 54.10543303335867, 51.20804094499158, 50.23457534851567, 46.0076331323193, 41.98451688212734, 39.32090590077062, 42.24537411043721, 39.55076463760869, 42.23554857315556, 39.15303630213584, 40.31590138712237, 40.48154700186945, 46.013771641638975, 47.33897970568749, 51.00830993344707, 50.375211931044056, 58.16203848008187, 42.770387280371885, 38.921985164765395, 59.07160866645075, 48.25040909551805, 51.4145851135254, 44.60979061741983, 42.48803546351772, 38.7091181355138, 41.51953558767996, 37.39956032845282, 42.980492961022165, 39.25540624126312, 37.4000310128735, 39.79384568429763, 39.56845060471566, 41.406269304213986, 44.06702087771508, 44.193964465971916, 48.19788855891074, 49.031396142898075, 48.60198290117326, 49.77754862077775, 54.72257091153053, 53.04767177950952, 51.45626029660625, 53.75571843116514, 52.73949899981099, 49.76205133622693, 47.16479901344546, 41.90195491237026, 43.63540326395343, 46.777135479834776, 49.06912542158558, 52.18399724652691, 52.028290917796475, 43.5582463202938, 34.5544534344827, 23.005805207837014, 14.173584638103364, 6.784289325437238, 2.5316428369091404, 3.224960743419586, 4.665511250495911, 4.264820544950424, 1.9571092532527063, 3.361875241802585, 1.8093907088041308, 0.6702286906300053, 0.20787005222612814, 0.41463368962849345, 1.908024100046004, 9.137925198001247, 21.951350512043124, 31.468834646286506, 33.331901642584036, 40.50520281637869, 28.250639746266028, 13.812228441238405, 4.501004593987619, 0.23891011162871317, 0.05614451553312041, 0.04883927345696477, 0.049224366704302455, 0.09339254544747454, 0.005815057421944315, 0.025554226350880442, 0.06737737931431302, 0.04393051911686217, 0.016921645015357964, 0.10275446163911013, 0.030830076617759564, 0.050671817058877605, 0.027361852943056056, 0.06607149051682604, 0.019217805876847238, 0.010947368667280723, 0.03681939605983996, 0.029158141433952317, 0.04156305462182049, 0.05188273776683116, 0.03318353511032558, 0.03437165704165255, 0.0538645995660655, 0.05018703662039292, 0.046379989493758454, 0.023888036826505296, 0.02269903772450503, 0.04288364464657442, 0.007801367319189013, 0.040804198567545226, 0.03478155621597844, 0.033354165873700575, 0.027493160413277727, 0.06886290806916452, 0.03545620771605642, 0.05562389750153788, 0.028481680051153226, 0.037745232468531016, 0.028879802538863117, 0.10319540652656749, 0.05939392342923149, 0.020706330035482685, 0.007986078299807325, 0.01458428969096032, 0.020005179554103844, 0.04263780703167281, 0.008375601929372117, 0.06388294585650006, 0.02775897760124457, 0.09081307378026748, 0.0607304748958878, 0.0447359379951752, 0.036569425400586865, 0.05511824499755617, 0.05810134923986851, 0.03657448924176636, 0.043044247319020575, 0.09602213458668801, 0.04705407025833284, 0.3599503948803871, 11.014578303983136, 30.397990326727594, 47.006158751826135, 46.49237925006498, 41.09214236659389, 36.71354955242526, 31.262655258178714, 22.899979660587928, 5.446947899556929, 0.7044879587427263, 0.16995732612427206, 0.6365219864153093, 2.7426496821065105, 6.700767355580484, 6.171135594767909, 8.045903021289456, 3.4995239588522145, 5.490429334102139, 9.918504318883343, 18.279531540409213, 29.048869532923547, 40.84489968515212, 50.05665271512924, 56.955274228126775, 56.748094635625044, 54.12851225945258, 51.920982714622255, 55.2736835325918, 53.79359283754903, 54.62402528332126, 55.27774710809031, 54.1955965565097, 52.65194777519473, 51.92571309305007, 51.73763152091734, 54.311165271266816, 53.41477424867692, 52.851062974622174, 56.061338609264745, 55.68695622105753, 52.84034705931141, 50.528800179881436, 47.70185385980914, 42.87981748580933, 41.28307942421206, 43.86243789426742, 41.6583521904484, 43.35936254070651, 41.788535656467566, 41.405892756677446, 41.67699913824759, 46.76728640833209, 50.26416570909562, 53.19949888413953, 52.18536223134687, 57.52815208127422, 43.888266701852125, 42.13393172910137, 59.56936920842817, 51.012408810277144, 53.572457451974195, 47.16773686870452, 44.216176848257746, 40.209232530286236, 41.365280535913286, 38.34226277566726, 44.27341207381218, 42.273732846783055, 39.904868372025035, 41.87733027242845, 40.205310160113925, 43.20831991011097, 45.466322514318655, 45.88765175111833, 49.980605802228375, 51.14564388029037, 51.68832732785133, 52.676897971860825, 54.22417102321502, 54.314856221598966, 50.509243242202274, 54.0111235649355, 54.60024395296651, 51.763966314254276, 49.21977581516389, 44.673344781321866, 44.39093805128529, 50.640634798234515, 51.64123142919233, 54.59325036694927, 52.43677439228181, 49.17298193900816, 37.752675625585745, 28.68474022034676, 16.742905762887773, 5.90714096061645, 1.3728500301799467, 3.1768126689618637, 1.0662534304203526, 4.3418411862465645, 4.113875483312915, 3.2262698344645964, 0.5727335834695447, 0.19970323319637007, 0.1328204172633348, 0.2352143655861578, 1.800525416770289, 10.416867925274758, 26.75814259436823, 34.901332163041644, 38.76869893843128, 46.995211416675204, 33.42104142712009, 19.542042478438347, 6.619151167331204, 0.43916345724175054, 0.10005017126640005, 0.028780442850303747, 0.11776034675178029, 0.06808656222757793, 0.029043253143167788, 0.03638528850710681, 0.03371854793400534, 0.08136186238017776, 0.023509514698338126, 0.08938307873904706, 0.010073310226171969, 0.007744537480551029, 0.014776107573491192, 0.05085217713889095, 0.08796951628380245, 0.07409268389305762, 0.030401295291319973, 0.021612600558587623, 0.03590924913183816, 0.0743002171117452, 0.05136104721215464, 0.03597391461352668, 0.02215404469039171, 0.11079239403648723, 0.07771640234897215, 0.05028681574209083, 0.05947541220173721, 0.09857479317654526, 0.12696015873863814, 0.09029267025330374, 0.17414940521121028, 0.1609535253937206, 0.1475942543437404, 0.12793535036185097, 0.18622333394183269, 0.13957596444074186, 0.11737787735558326, 0.12889590204483078, 0.12566379241404996, 0.19525935633047936, 0.13850233818013824, 0.09331566852427299, 0.14279575537770026, 0.2161382246882685, 0.07103248439248531, 0.1940380742833499, 0.22300321518653826, 0.10858774620799289, 0.07344854950544334, 0.19418269636169558, 0.13337561650381935, 0.15351049091306426, 0.18970964686764827, 0.19832712477974354, 0.10064347572023831, 0.15250421910276338, 0.17604579458073263, 0.20866050174640072, 0.15999671221981127, 0.49494814127683645, 12.227991953972849, 34.96319578539941, 52.327038241970925, 58.13948485159106, 49.55910398114113, 45.044008762605735, 40.132911051473315, 26.041268648639804, 7.6072231800325465, 1.1767513785631427, 0.8858745965746142, 2.150666699294121, 4.497700487413715, 8.917096737892397, 16.66887887062565, 16.762723538183398, 4.973741394858207, 5.619895496676046, 9.19290800248423, 17.883309395082538, 29.362967052767356, 42.34557105648903, 49.99685225948211, 57.325655798758234, 55.86343149985037, 54.92674596848027, 51.41882519568167, 54.295067864079634, 53.593155799373505, 55.058416012794744, 55.206693372418805, 53.7586719759049, 53.095018709859545, 52.734443064658876, 51.94372069451117, 53.66896344769386, 53.873091436201534, 53.31312602566135, 56.60918781834265, 57.04402569801577, 55.0991419822939, 53.84565053447601, 49.20503554805633, 43.92070862554735, 43.212579604118105, 46.11634554401521, 42.935491608035186, 44.916590567558046, 43.935688157235425, 43.180435780555975, 43.819558543543664, 49.890877662166474, 52.7053233884996, 53.94391767440304, 56.20586226063391, 60.189158608836514, 47.540930778749534, 46.58886171156361, 60.5473376858619, 52.82655208341537, 54.995105035843395, 49.96604988651891, 45.53776848700739, 41.71293589376634, 42.60839731462541, 39.8706849159733, 45.28816453872189, 42.30802612919962, 39.79082938163511, 44.08323987837761, 43.19863165578535, 45.233576913033765, 48.66410932233257, 47.75985002517701, 51.6882606475584, 53.57323408126832, 52.55260982821065, 55.37491990673927, 56.95324636274769, 55.835563059776064, 51.36093885667863, 53.80155524899883, 55.721833936629764, 54.58175389997421, 51.47225964453913, 47.05288987005911, 47.83284141171364, 52.065137663195216, 54.22258246329523, 56.67313814163209, 52.96484701095089, 51.76137362757037, 42.916989787932366, 30.990003462760683, 18.538186357867335, 9.530324013002458, 4.893826044374897, 8.626113745474047, 12.6470923039221, 15.888061465755587, 9.663058980818718, 8.806203488380678, 7.753471693684978, 2.1377755845746687, 0.9082025049194213, 1.2395802717055044, 3.0476154338928962, 13.179036301951255, 31.258666207713468, 43.268116443387925, 46.044574014602176, 54.40479224728, 42.55991681929558, 22.053938142714962, 6.501018203073933, 0.5966432488733723, 0.2203521372810487, 0.08745714901916443, 0.18764438107609752, 0.15603617554710758, 0.12710588398359476, 0.17732038102563352, 0.10426488825150075, 0.30248761056892337, 0.11516847978195838, 0.260378668505338, 0.07974508744213851, 0.1659336178413322, 0.10715912246415693, 0.1363391816736229, 0.22592173438639412, 0.2611897411125322, 0.1470198416181149, 0.11787142950080096, 0.19203259399341, 0.15844578253886393, 0.15058017395917447, 0.16254902607010258, 0.1370811991153225, 0.1504318440152753, 0.2617975552716563, 0.16940463965217914, 0.1491990093622477], [0.05128479465061138, 0.02212159129069938, 0.026999772976963755, 0.02951262180783576, 0.05582545523441607, 0.014600913798917207, 0.01511285875758697, 0.029770396987817464, 0.09435996893913516, 0.043419166918723814, 0.08559153340156041, 0.017154528083459988, 0.050098990135255365, 0.07099123821864206, 0.09202150853290673, 0.059895297332156094, 0.076040156005371, 0.05213100388045273, 0.031601042606897896, 0.01868456080105276, 0.05625847877273637, 0.04670355055901793, 0.05210034504172303, 0.010379484925989904, 0.03352915950780434, 0.04251124547614206, 0.018968854114533435, 0.02558859305516366, 0.031046747350164, 0.01585655967750016, 0.021001237497154265, 0.049529721690041405, 0.09265999685251906, 2.601691955520261, 18.17507097798009, 38.8318020297635, 47.15347905312815, 35.74311594809256, 23.400701592045447, 30.533594508324903, 20.92127726924035, 9.655751605187694, 1.6748156590807823, 0.39079603648954825, 0.056679589643834107, 3.2099669931396364, 4.508490437461484, 5.91927138067061, 5.305973012601176, 3.723181183299711, 3.6099271572405294, 2.9151118859168026, 8.771248305997542, 17.684847270288778, 30.723005763946045, 43.81392601997622, 53.47052681830622, 50.48051580306023, 52.50276434806086, 53.89503317494547, 55.335625602353005, 54.55939638999201, 55.596820154497706, 54.477195278290786, 56.49803177002938, 53.95805389650407, 53.23098374951271, 53.659938073927364, 53.302719977594194, 50.065089733369895, 53.42478413735667, 52.35751505820982, 53.60737046887798, 52.48083437642744, 52.641773146967736, 47.42885689581595, 45.29580923818773, 39.51129382656467, 38.77680647757746, 42.686401490242254, 44.20987752176101, 41.72813900055424, 42.76408795387515, 42.3693916105455, 49.95401605483025, 48.41571346406014, 54.95607353025868, 51.08190928736041, 60.64209038211454, 50.803319023501494, 35.268771956043864, 59.40061315413445, 49.08479136805381, 54.55940815710253, 47.72599997058992, 43.97941473991641, 37.42641679702267, 39.5344828790234, 38.79024059541764, 39.093835969125074, 36.15591010739727, 39.84648781438028, 38.690953639245805, 42.00798050049813, 46.328031939844934, 48.654526972001605, 48.69183655708067, 50.31337968764767, 49.3462134176685, 49.25008396948538, 50.539068944992565, 54.16236623640984, 49.21731256669568, 52.85935094279628, 52.71835742458221, 52.29024248738443, 50.30162826661141, 47.28563939371417, 42.39589898817001, 45.50769175252607, 47.056239574186264, 49.89474904152655, 51.2793182557629, 51.84674401437083, 43.09283356512747, 32.88706564134167, 19.663737935404626, 8.672637958680431, 1.6955032199621203, 0.8184109940644234, 0.922791576914249, 0.8535191488842812, 0.7172154983685863, 2.668941237272755, 1.5923966106868561, 0.7346889833288809, 0.14253727731204804, 0.273862122407844, 0.649766298311372, 4.173547971633173, 10.215787618390976, 17.257148104329264, 31.380091021137854, 32.77340712085847, 38.082903892763206, 25.31437893067637, 8.150101765509575, 1.4799270586621378, 0.03024690367671992, 0.03619174788435621, 0.04217769079391034, 0.021566194782574332, 0.06358263172930287, 0.05656999310538654, 0.014719020616593621, 0.13315674518385243, 0.07328626143956378, 0.008819297072477639, 0.019298057417355238, 0.02535815955319953, 0.03833559514474004, 0.0661107142185492, 0.042431587653775374, 0.04019644569545504, 0.07564389702653693, 0.06842334980085012, 0.05916537258834128, 0.09227378894725154, 0.03664810263041047, 0.019585972411497947, 0.006418703583955404, 0.011779518268491712, 0.052257760788404176, 0.04585495113485283, 0.09334825790457188, 0.04788567402189778, 0.04796954532784801, 0.040585599208791415, 0.03199976072796891, 0.027979130203264858, 0.02413043087618726, 0.04803039952211323, 0.0223494986177332, 0.04414839069208792, 0.04614953875481602, 0.08308980433690934, 0.06744052028103222, 0.05090170472319569, 0.05213208406442597, 0.03501715123533242, 0.06397747727591666, 0.050128381098470384, 0.06798868683437187, 0.030812793674187797, 0.03313431779163019, 0.06006587829981601, 0.015198170308834844, 0.031264950258416996, 0.06341421112958943, 0.07917190811807111, 0.050423964632735144, 0.036082967229548006, 0.07639306206857005, 0.04833618351708978, 0.02267630598057182, 0.02009139508910237, 0.016304840814442407, 0.024114703091101784, 0.11445257061671828, 3.85514491508084, 21.785481322196222, 45.37582166733281, 54.73556964628158, 40.296748453570956, 29.004091755036388, 36.980698262491536, 23.77790024203639, 11.758814704033638, 2.1009393805457703, 0.28055868081508145, 0.22910302174427818, 3.038969304292433, 4.369671873507961, 9.355889347291763, 6.148426542359014, 4.8078962295286125, 3.0279425411455096, 4.137857835138998, 10.805912133186094, 21.682674038794733, 32.33145994524802, 45.254757711964274, 54.62628849091069, 53.12571125645792, 54.183068506179325, 55.60410007353752, 57.118382069372366, 56.12568509194159, 54.833134681947776, 55.89825430224019, 56.151988506317146, 54.991061072195734, 54.44052111717963, 53.40805915094192, 55.974693452158284, 52.23236007075156, 54.15521575558571, 53.65053615262432, 56.04185227424868, 53.6953531542132, 54.61553727426837, 49.65105610509073, 45.927479497848026, 41.71741524050313, 40.45116824488486, 43.30100943965297, 44.215145264902425, 42.90482259565785, 44.5757483666943, 44.91227988273867, 51.038170937568914, 51.62271391960883, 55.19459286043721, 53.65741598990656, 57.16770587428924, 49.31987077959123, 38.25552740404683, 58.571145611424605, 51.61394349990353, 55.409275947078584, 49.325883773065385, 45.892327216363725, 39.5683172441298, 41.63410017567296, 40.936283065426736, 41.66665584810319, 39.43190113190682, 41.220462706781205, 40.14964780499859, 43.09296300334316, 48.29975643465596, 50.274540378201394, 51.29026559091384, 51.4615241173775, 51.885720606773134, 52.22763361469392, 53.10442847590293, 55.77355823209209, 52.17752533574259, 54.12816316850724, 54.473116013311575, 53.74290404781219, 51.26846897986628, 48.99958964317076, 44.92931473639704, 46.7034419890373, 50.365692338635846, 51.591409483263575, 55.29926130848547, 54.56063978133663, 45.68262161747102, 35.47405704375237, 20.57222358642086, 12.23425990150821, 4.637789899303067, 2.8997357045450523, 1.2599373728998247, 1.0472555530648078, 0.5312814851922374, 0.8346004543765899, 1.0614745126616572, 0.3308630476315176, 0.12509475762565292, 0.23457002435480398, 0.5639615703013636, 4.511406719684601, 13.380434320818994, 22.55806665266714, 36.403019428253174, 37.693573351829286, 44.56920977561705, 31.56845892629316, 10.683199801752645, 1.821517574210321, 0.07566723972558975, 0.06959983868704689, 0.021120785517738234, 0.05608079233957876, 0.025317863328382376, 0.024568715523327553, 0.0428405100659978, 0.06744163110852242, 0.026733974941195022, 0.012770930845891277, 0.06014907544839287, 0.04286133616621937, 0.053553705764633995, 0.040513893379078764, 0.01743907420595567, 0.02148675912570569, 0.04805255861532304, 0.020455970586608016, 0.04200650844722987, 0.04510101719549106, 0.048060054785662124, 0.05764473785435962, 0.04230009632245187, 0.019010098373156883, 0.05697535703920069, 0.051949023524479526, 0.08855645454698995, 0.06304893657685288, 0.12618879246855938, 0.20619688555598262, 0.10220989569901459, 0.17141396570349896, 0.09561572494285722, 0.09483012475914533, 0.12918819523146077, 0.13682482013058278, 0.16834800522173607, 0.13879113800583348, 0.18573936555654774, 0.1913759800335092, 0.20596399482700134, 0.1883522003528572, 0.1508629216902679, 0.20543046055301545, 0.1684083269848939, 0.07870535291130505, 0.1478919714328743, 0.16662395499165983, 0.153653442919735, 0.21873250483505188, 0.17958510546914994, 0.15361956651172332, 0.11524398540777546, 0.14129881957365623, 0.15307863182838888, 0.14839743624531454, 0.11852713947695111, 0.06896714965302138, 0.10585144102092713, 0.065123931685042, 0.23438841555147405, 4.419002542572637, 25.089976210748, 51.97730795029671, 60.658678085573264, 50.16888349286972, 35.558529207783366, 41.21760722129576, 30.0269478367221, 13.936382243710181, 3.0643048738279655, 0.6442229473783124, 1.04009207938948, 8.542099518160667, 9.5767972353966, 16.933338795938802, 9.917501172711773, 7.92323628740926, 7.024370739536901, 4.04313700814401, 9.868705907175618, 18.866045513460715, 32.85903050053504, 45.20388064845916, 55.279700448436124, 53.9208149140881, 56.07560819195163, 56.28943227952527, 57.96786546707154, 55.86761666882423, 58.57823333432598, 56.47942012356174, 57.85404612941127, 56.670039469195956, 54.730576469052224, 53.920909050972234, 54.31638594596617, 52.72017740434217, 54.00904863111435, 53.84086524286578, 57.974631555618785, 55.27275000849078, 56.624665491042606, 52.358130870326875, 49.00706960308937, 44.385760522657826, 42.06488232458792, 46.512567689341886, 46.328761500696984, 45.66770484370571, 47.0271905006901, 47.40662882404943, 53.01937187871626, 54.12108329034621, 56.17611500524706, 56.10877967649891, 58.25230398485738, 51.26960646721625, 42.75652562418292, 58.421048272040586, 55.80884779653242, 57.08251591651671, 51.28060479317942, 47.19007868920603, 41.227577886273785, 42.475954563386985, 42.44733302823959, 41.1653063374181, 40.5884825798773, 42.890349049722, 42.04358385455224, 46.00764489942982, 50.2924773769994, 52.25225825463572, 52.35766803064654, 54.0389370918274, 52.602674961090095, 54.22991337314729, 54.60323279903781, 55.76641951837848, 51.266652922476496, 52.96504705182968, 55.26781958918418, 54.9923829109438, 52.17723900272001, 52.15479127822384, 46.79895562510337, 50.62385097626717, 51.55374296249882, 54.12185599727016, 57.31372787106422, 56.251812827202585, 45.885890606910955, 38.55030136723673, 24.448035224791496, 11.746769105234454, 2.8839283076024826, 3.5225632257999915, 5.129329562187195, 4.445119154068732, 3.6986433257979736, 5.87947452260602, 5.458250699504729, 1.982121840119362, 0.5234186038855584, 0.6651169842770023, 1.5631119498322088, 5.290948863952391, 16.16922676563263, 27.50595815720097, 43.649778750634965, 45.51585420485466, 51.25475637374386, 35.22247622090001, 12.188656464699777, 2.4033580432015085, 0.12127166478744439, 0.10440753382300177, 0.16668521138208528, 0.1645100119734003, 0.16174058880536787, 0.13271451326868228, 0.17246747449521097, 0.2175640675329393, 0.113303768148105, 0.11204066536118908, 0.08866886262811961, 0.14912206349113297, 0.17772610119033247, 0.1733654367947771, 0.1188193483939094, 0.2932608476088893, 0.12200195342302324, 0.1543258995779099, 0.11929414670674071, 0.22244306701806285, 0.08235723275931613, 0.08823534879352778, 0.12495572798915448, 0.08556406914947495, 0.15718291723920455, 0.10954916357032715, 0.19075759386103, 0.1806114334613085], [0.03823887654429963, 0.04453405850536881, 0.022891310471740943, 0.05476092243747366, 0.050749774166052385, 0.11848397808329714, 0.026539122392874093, 0.014332747593852542, 0.06143030770603688, 0.031636989367524945, 0.06678573727127045, 0.03576055912661456, 0.09950775803337175, 0.06320425324262151, 0.07364335800370864, 0.037800417612156564, 0.03073208439614504, 0.039243574043916124, 0.019501076462948998, 0.011761871433155912, 0.034771217859440276, 0.02404061664316443, 0.052797124991493846, 0.01658600274353258, 0.02722155543104295, 0.015724743716418743, 0.012726079270754372, 0.004302167358072174, 0.0557042601247949, 0.011930299693748597, 0.10354812106778545, 0.07714398145194977, 0.057420890793324485, 0.21951797478381666, 5.110460019880726, 24.350042650776526, 37.67747202227193, 38.68723523232245, 16.81312599489766, 23.738698113349177, 29.49843787377881, 13.71268653100537, 4.679671987410515, 0.3849576497750898, 0.3022112979763939, 1.7418519071032925, 4.945888153968319, 3.966412750944015, 5.4224884894586385, 3.178231586371699, 2.1749089081441206, 1.1540168307481276, 4.168327787230092, 12.264762213153224, 22.513041765459125, 33.38497131101547, 40.793034184363584, 53.02638899895453, 56.12458290592317, 56.66546206320486, 56.41809778828775, 54.66686148797312, 56.4932543231595, 54.19956207275391, 55.935826686120805, 52.95309166754446, 54.65363525575208, 53.63246187087029, 50.599669564154844, 51.959547458156464, 55.13672613328504, 51.10512579641035, 54.305368008152136, 53.94161916548207, 51.75532925513483, 48.68297200049124, 49.33656046467443, 47.597142265688994, 42.739243661203695, 43.08021530028313, 48.0234960586794, 42.763452529907234, 44.25518481962143, 41.63326471082626, 52.08923670553392, 49.59977503745787, 57.357207344424346, 46.591313192921305, 66.61767621194163, 48.28863259284727, 34.454134894955544, 61.05342149734498, 51.366669439500384, 54.55481506163075, 46.78491746225665, 49.14187362117153, 38.450343685765425, 45.02919004809472, 40.12413278702767, 38.16314381937827, 39.342996689581106, 39.10112765527541, 42.79484325839628, 47.79397856804633, 50.6527509996968, 49.64148944424045, 50.98920406833772, 52.76276649967317, 54.626386550164995, 49.77651311505226, 52.20894744319301, 49.22931501942296, 53.201915064165675, 51.872043301982266, 49.43734968862226, 53.949412915014456, 49.88321335084977, 47.11385134727725, 44.9155354499817, 45.07952974688622, 47.89992570877076, 48.69667283950314, 52.49199351956768, 48.895729203378, 36.91117817355741, 20.549158088622555, 9.500658146796688, 3.25183192087758, 1.0167097276256931, 1.2323347959787616, 5.121695649239325, 2.5280082706482183, 1.2424724068372481, 0.8130615553067577, 0.4732805087922081, 0.12697541154921055, 0.015546129359262846, 0.1520642394860906, 0.7814482323104336, 7.005832637509992, 15.270689225965931, 27.928309171430527, 28.293889760971073, 33.73425445249004, 32.84741047889956, 13.259018332727495, 4.169096081487594, 0.12977339447506014, 0.026881471764476552, 0.037351949741282774, 0.038806777522568746, 0.012619739563594903, 0.08869130900430103, 0.01946437702093634, 0.054694299601138606, 0.0321975952735351, 0.09224367403094808, 0.02838554176231546, 0.044706229105471604, 0.07469845259742391, 0.05756127257500926, 0.0626912616163252, 0.04571347001699671, 0.07475947150059285, 0.034989403530714974, 0.019614445984423644, 0.10091768923185526, 0.07419643518064292, 0.05375662330357779, 0.03728792011257141, 0.008501569766761556, 0.040152862953442725, 0.03735554269364765, 0.04222321173837108, 0.03379427572532046, 0.005156294106610961, 0.026437793858349327, 0.03527066122079569, 0.04421155847188446, 0.050489250645642324, 0.05997373324428355, 0.0445395322035878, 0.0712928853388275, 0.026256447440133463, 0.0905835998034285, 0.032574759510856484, 0.051938397884969754, 0.07110969839437355, 0.08006545775119336, 0.09841822012658082, 0.04669608503219582, 0.03913363276590263, 0.007950820539507174, 0.020663647446781397, 0.01896097490023221, 0.019803472434080416, 0.022842238709751158, 0.03286869595608404, 0.04115364191332652, 0.02013383636010751, 0.07628992365132417, 0.020082410792970372, 0.07305237479628095, 0.036310843913064855, 0.0489555579429913, 0.02338728728523899, 0.036117774434387684, 0.059086829423904426, 0.1224591853397508, 0.6426793721414382, 8.743443604438536, 31.395005833718088, 46.17619699047458, 44.20559821590301, 20.924117065245106, 25.06267063079342, 32.53843165213062, 15.635884442637044, 5.2917681490221335, 0.3096578564615019, 0.24804814628535704, 0.8369744076363502, 3.792737554157934, 4.652777766027759, 5.8754893945109465, 5.4492042429985545, 1.8085071949228164, 1.7861631680880825, 5.0643000968040965, 16.29320602263174, 26.7240434692752, 37.25645657508604, 44.13890615586312, 53.750415386692175, 56.28390958232265, 58.67426080088462, 57.337454288236565, 58.03258457491475, 58.490509525422134, 56.830354582878854, 56.74937332830122, 55.740892733297045, 55.21487543659826, 55.04613507178522, 52.2544861608936, 54.055258074114406, 54.69826790594286, 53.75391806325605, 55.1413780643094, 54.63838508052211, 54.76539927144205, 53.20490783260715, 51.179329195330226, 49.185968906648704, 43.38631706853067, 43.96438029504592, 49.522673006980654, 44.9978385433074, 46.27888071921564, 44.96828740642917, 54.13512145319293, 51.92713691342262, 59.979676585043634, 48.61817836761475, 64.57076380329748, 50.81396825851933, 37.59958159539008, 60.09255455386255, 53.34642302605414, 56.77499817263696, 49.05244750361289, 49.441978085425596, 40.32600541268626, 44.90778092415103, 41.875129822761785, 38.3494681696738, 41.29033580903084, 42.061771885041274, 44.26775209365353, 47.68510141680318, 52.583349443251095, 51.58216445676742, 53.07969400959631, 54.324587621996486, 55.24537186468802, 52.55164100277809, 52.93489579231509, 50.937048312156435, 53.6728544389048, 53.620200541711625, 52.681600893697436, 55.85653205071726, 51.79016774700534, 49.66032858817808, 49.10268129840974, 45.69782472425892, 50.206553936004646, 51.42549322497461, 54.6062530240705, 50.39631036020095, 39.00261340602752, 25.19464465879625, 12.138514845601975, 4.129021715733313, 2.8471394171637874, 3.04189833421861, 4.368092629217333, 3.3909461334828412, 0.10945439083321441, 0.4568306398728202, 0.26769704515895537, 0.0678010565799571, 0.036071089036282034, 0.13798052505139383, 0.813081473592789, 7.385887753578925, 14.1210925386798, 26.957491174820934, 33.94442681343325, 39.3875430476281, 39.254590388267275, 18.44726581727305, 5.526668112124167, 0.30263402529301187, 0.0885987579221687, 0.05860201834190277, 0.031856354814203035, 0.08604133426542245, 0.04847822387913062, 0.017732403526503234, 0.01995171044742869, 0.028741213402921156, 0.03330456934148266, 0.00846488468889748, 0.007427044310456803, 0.061846327922877774, 0.024637328273045923, 0.013894191943109037, 0.05263857926512438, 0.018732039100160042, 0.011053509191579877, 0.006637403012944326, 0.046279792854141806, 0.030313426921624812, 0.022874657635486895, 0.029505822777507767, 0.06656211620617299, 0.04588463321147908, 0.027312011262702367, 0.026599656745430925, 0.005890910660157041, 0.03636787149814829, 0.12966900733449768, 0.09970295723647842, 0.17778754144185976, 0.11945478002270384, 0.13051945686099992, 0.20992931188835254, 0.12214808469457973, 0.09854556692223396, 0.16702443511495668, 0.15375061351205074, 0.21267494036545678, 0.1869481756922699, 0.18783703686729555, 0.16460778011429697, 0.1513695356345946, 0.13482055025956324, 0.08515490158911675, 0.18714429420088569, 0.12957799608909315, 0.10933656651046007, 0.09058088019129731, 0.18032998807968634, 0.1405013680097557, 0.15942517998478106, 0.2187521779729474, 0.09956300063359161, 0.14932159875189105, 0.15400257983034657, 0.16183230485166275, 0.09638345995617491, 0.15979287154491872, 0.14866319214624746, 0.23675794082303203, 0.7700967091706492, 10.069913691090001, 35.455057082637666, 54.12307977676392, 50.53527601303593, 24.559083407925023, 33.35585555722637, 38.42964141599594, 17.323787212371826, 6.195143932296384, 0.7262225473119367, 0.8085111156105996, 3.1890590440842415, 11.29486499294158, 10.029055341597527, 15.539931501111678, 10.647990645900851, 6.031078052136206, 5.728538286301398, 6.995910021566576, 16.4007495680163, 27.227389466378, 39.970140534062544, 45.37839866453602, 55.87941908067273, 56.6407040626772, 60.09034625945553, 58.74242374973913, 58.06492843935567, 58.85682752055507, 57.47549033934071, 58.430108947138635, 55.74230478655908, 54.890601327342374, 55.84426679918843, 52.86161807275588, 56.289926498166984, 54.18844607568557, 54.026609082375806, 56.83499082442253, 58.876400147714925, 55.35678286706248, 54.87227601389731, 52.36157863370834, 51.03204419535976, 46.86972695012247, 46.63168614910495, 50.20629505957327, 47.13001935712753, 48.00026386014877, 48.2046389579773, 55.09785152250721, 52.9523777961731, 61.52474134199081, 49.918957910230084, 64.9999770041435, 54.069931660929036, 40.536130705187404, 58.7438161911503, 56.51309759386125, 58.4132545225082, 50.20631467142413, 52.3595311564784, 42.154261373704486, 47.99770647479642, 43.17242630066411, 40.56246549852433, 42.576237801582586, 43.197141155119866, 47.13995079840384, 49.55896277581492, 55.0402162151952, 54.31359714077365, 55.322728849226436, 54.79636246158231, 54.732212097414084, 52.83883694679507, 52.84137472029656, 49.74964880174207, 52.19965927062496, 53.63224614051081, 53.59833332800097, 57.798811312644716, 53.73011712105044, 51.4521731868867, 51.70616234502485, 46.882647237470074, 52.50079924060453, 53.45911272110478, 56.544174532736506, 51.21683489891791, 39.31712081355434, 24.09170162293219, 12.88554887617788, 5.12847742726726, 2.366269336592767, 3.4581728616068443, 11.079892631499998, 6.535472792963828, 2.021299944289269, 2.390932955088154, 3.634849407019154, 0.3856464547495688, 0.21480662598004266, 0.3470432536015588, 1.442530936291141, 9.497119188308716, 21.013658892723825, 38.28515698832851, 39.9219463717553, 45.77750375193935, 44.69925988105036, 21.041293951772875, 6.4669690882006, 0.3418522111831173, 0.19713763538147175, 0.17010226995954592, 0.1823039055471459, 0.1286431543168522, 0.22769864468324572, 0.10272332782586736, 0.13030427808482803, 0.1361613879881559, 0.24008365107640145, 0.13368122429857332, 0.1432409750357751, 0.10797383398899149, 0.2566565843599458, 0.15486623671266342, 0.2308276235576599, 0.17815371614790734, 0.11405877078012114, 0.09811567668352397, 0.14726235441142513, 0.19672122062934985, 0.115023267815911, 0.20943032817975168, 0.13555910498384507, 0.12358607769372965, 0.11985510692841585, 0.1426698718099825, 0.0968746678723443, 0.12428066663203702], [0.01895583445026029, 0.03804949194853825, 0.02654675837425936, 0.016371999912324454, 0.0848042325026566, 0.06771111019676732, 0.015954139169245478, 0.057479592280522476, 0.04157383347891512, 0.037331081506225376, 0.04227766526802894, 0.038346734063159076, 0.0067400726801415374, 0.0067213470972473585, 0.04224454345662267, 0.07250000242023699, 0.019878581609396685, 0.0703067999453314, 0.06375279134860443, 0.019992012417905276, 0.006332050421230135, 0.11069169177884057, 0.006418544141906164, 0.025082501965845307, 0.0798563157478648, 0.03225482204147885, 0.00902158641932352, 0.024924057746125806, 0.05691805749290413, 0.023759441307535576, 0.022053735052806236, 0.02996612096115226, 0.0875914978584455, 0.030775592444584738, 1.5814223092409874, 13.849483113135062, 37.480333697411325, 36.09891414642334, 30.40138709929682, 27.880244447338967, 22.711350917816166, 20.597738604391775, 8.101710994397441, 1.7506679243618444, 0.3552015077683234, 0.7332039372094217, 1.8285742858725211, 8.273308315584737, 2.7366192831147105, 3.6675543746640606, 0.8695694876293983, 0.4160430769045507, 1.6256948368203257, 8.869254608308117, 13.621178615477778, 22.986824858573176, 37.02274214836859, 49.067125012797696, 52.9098436140245, 54.60059304391184, 55.93202198705366, 55.98782162512503, 55.16403759679487, 57.299340617272165, 56.28166598658408, 56.362686464863444, 55.45512060965262, 53.06065090240971, 49.13689221105268, 54.035253986235595, 54.43400213795324, 53.6831545829773, 52.870117848919286, 55.111258183756185, 53.80574826271304, 51.52215611550116, 51.82279794446884, 52.22904959032613, 50.698207347623764, 42.26804148766303, 42.4369465920233, 40.784048034298806, 42.47495435899304, 42.49664898841612, 50.31003782826085, 53.1395140770943, 54.74657581698511, 54.24109605050857, 46.20273574706047, 34.59222193687193, 38.98457050323486, 54.647473212211366, 51.05464489229264, 52.63883529170867, 49.51981359912504, 50.55120083593553, 43.175321009851274, 39.258387242594075, 38.807067563456876, 38.89844702136132, 38.890272801922215, 43.90451708147603, 50.937354257029874, 51.35003466759959, 49.04727781972578, 51.2857234862543, 52.119180079429384, 52.85316928740471, 51.266939255499075, 52.28854017872965, 53.030676149552875, 51.68126706154116, 53.134615036749075, 53.14083983821254, 53.696149395358184, 51.93912367666922, 50.18168218674199, 46.905891203111224, 47.06445693969727, 48.98078972293485, 47.984331192508826, 52.404320701476074, 52.74358610953055, 42.8367498613173, 32.41080361027872, 14.527318689130968, 4.301627576351166, 1.1402337445366768, 6.257633172696637, 2.0820551293511547, 1.103878030853887, 1.1809624106653276, 0.2051606137425669, 0.19524693038434754, 0.07068811254876275, 0.024550938453044624, 0.0841459178275639, 0.5048564466978274, 1.937936340128222, 8.740051734832026, 19.293652503721177, 28.584545235480036, 28.73687832586227, 34.27375293547107, 29.281668086205762, 7.107551953484935, 1.6613149835217385, 0.09927539590505824, 0.09562926937735851, 0.03119104575636166, 0.0594942924386311, 0.01765463219565009, 0.06646606410222669, 0.06856123030546211, 0.08617215910025182, 0.01854965654802659, 0.013590474470308232, 0.00963807748180003, 0.047945061157788, 0.027341166653880672, 0.023374665986686465, 0.011591762567179338, 0.040878489944002325, 0.003735564659432238, 0.07453608026187267, 0.034731595791996486, 0.03479348803539911, 0.07153353653848171, 0.04960944079944203, 0.02484755620600716, 0.040560011872120445, 0.05397052654335576, 0.01700458169404057, 0.059894351213569605, 0.05073689622804523, 0.05970047351213233, 0.020161392542743878, 0.05348917051789261, 0.049663610876567905, 0.02594789978297007, 0.041536050022489605, 0.05849321087401721, 0.03563028204465105, 0.07828685440002911, 0.06509288214147091, 0.08275498560960255, 0.03563728408827897, 0.08830299435724175, 0.05541510789865448, 0.007008819196808844, 0.030813138413753723, 0.02231167111125204, 0.014309500655790251, 0.08355257506932944, 0.01565755493262963, 0.0370829226449132, 0.02961557061832038, 0.07529498994230263, 0.03568672357247241, 0.04478662620268522, 0.03136634965607476, 0.03939336721575068, 0.03067322777614238, 0.012021688237455825, 0.08341531509593611, 0.012587929677758968, 0.03424337178829216, 0.019455837055800423, 0.014892450473721952, 0.06412826253161316, 2.2410699773219327, 18.43872485622283, 43.95982642327586, 42.85575374480217, 27.29181831882846, 29.934654466567505, 27.258178111045595, 25.571566781690045, 9.352947569662525, 1.0737756783923795, 0.2732194052828897, 0.7476801184877273, 1.5112989107447288, 0.5903069662951654, 2.6385558612885016, 7.781602932560829, 1.2562610088817536, 0.7617173620289373, 2.647091183931597, 12.904761625874428, 16.716686679470925, 26.300113701051284, 40.12113609621602, 51.73729027471235, 55.43447717543572, 58.37126162744338, 58.653260430982044, 58.26344743851693, 58.27907808365361, 57.01869503144295, 57.37704669275592, 58.36812373130553, 57.98813627612207, 56.51339177162417, 53.05012326086722, 53.62357378005982, 54.03391253563666, 53.667802426122854, 53.533861329478604, 56.94755108125749, 55.81993241463938, 53.9794151244625, 54.515367784807765, 53.09877241811445, 50.891835151180146, 44.439834317853375, 44.78592465000768, 41.329657570008315, 43.8539538075847, 44.13634877051077, 52.53215074539185, 54.71207857131959, 55.38807945866739, 55.28074379890196, 48.34849972878733, 39.14662714927427, 40.431783891493275, 54.27806438938264, 53.699785432507916, 54.52100815311555, 51.32084831114739, 51.22169863793158, 43.639490373672984, 40.92818337102091, 40.291013948379025, 41.0389236480959, 40.37088909456807, 44.80250058635589, 53.65909084197014, 53.376115368258574, 51.72721762810984, 52.374777409338186, 53.77330241664764, 54.601048038851836, 51.940131725803504, 52.92364251229071, 52.280989616147934, 52.47423302742743, 53.63895731587564, 53.62135371854229, 55.938929280927105, 54.65668293737597, 52.1969332233552, 48.99702833544824, 48.53828360957485, 50.76525242097917, 50.756325106466974, 54.63163075908538, 56.08869321884648, 46.016729108748905, 35.22140933621314, 17.227800930699996, 7.017519339438408, 2.5263370958066758, 3.3906142029070088, 2.733398772055103, 2.1994185736102443, 2.2102104848431003, 0.19856744656159034, 0.10280165265524581, 0.0176183023910609, 0.11229224097464355, 0.1647719221129533, 0.5486763388879838, 2.3849437409831635, 11.104467261222101, 23.579089026297293, 33.65012353466403, 33.433432194494436, 38.362396301761756, 33.3458339014361, 9.449852666547223, 2.2879597063987487, 0.040171007745929306, 0.013277267083345402, 0.048011143902136434, 0.03149211639538407, 0.09243250704340397, 0.039760147131258444, 0.06682165147316071, 0.03384511715041534, 0.021891406767310637, 0.0385501955245291, 0.05099041387438775, 0.022891339200038104, 0.07117052577556142, 0.014151314033135293, 0.0261106455863844, 0.049004660348498055, 0.021816238220180237, 0.06992117426688634, 0.056473144269999, 0.027722211126538537, 0.034165387868040034, 0.07248415206108363, 0.028394987626421838, 0.024861403245238528, 0.05452674851121922, 0.0828199805090985, 0.006994361681262813, 0.09517077341555588, 0.014077934301308086, 0.09588649871969417, 0.11030956712220946, 0.11174411272570012, 0.09994465031570966, 0.14451818150137702, 0.13129024856513546, 0.055272186535500714, 0.16211090038620657, 0.18761674062378947, 0.21828192256150708, 0.11840601331524311, 0.14795183354327757, 0.10011053899483335, 0.06839032375043438, 0.08822036411372886, 0.12474795728321038, 0.1649641948601892, 0.13522565755392277, 0.15565599675380415, 0.18640269044666521, 0.14010185315724344, 0.28484999893173096, 0.08330944940567979, 0.12563497984721778, 0.2000650105577323, 0.1661870244049257, 0.18703126558853736, 0.16521945535655946, 0.16691234112987596, 0.07798148409253167, 0.10839174261256572, 0.08958535659457408, 0.1997914712034887, 0.19198269102602236, 3.4687073672971422, 20.78923656094459, 50.73133568609915, 47.36658534696026, 42.03675500808224, 41.9387859682883, 31.90128576370978, 26.710105326867875, 10.689180435672885, 2.560678427257846, 0.5392918843896158, 2.3817026374801515, 4.967553365615107, 17.095670007890273, 11.047400697585076, 13.380636322882868, 2.956566925971739, 1.9157981151534667, 5.2922030418149895, 14.453380050197726, 17.712794157766528, 28.38519077147207, 40.22525541244015, 52.741095404471125, 56.62789360169442, 58.000472130314, 58.48923475511613, 60.9503572986972, 57.57197280083933, 60.679694144956535, 59.35289359861805, 60.32157390348373, 58.30029418391567, 57.68008508989888, 53.39627635094428, 54.6193733522969, 55.73148296725366, 54.10941423908357, 52.78041324307842, 58.537346547649754, 58.48182147549045, 55.507437183010964, 56.34304715741066, 56.173953779282115, 54.606488366280836, 47.0915291386266, 47.364773211940644, 43.84617966990317, 45.47482229048207, 46.48465218082551, 55.27147131581461, 57.64842371786795, 57.847837017428496, 54.509272421559984, 49.7303468181241, 44.01603398784515, 44.09736433336812, 53.91027942780526, 54.441062404263405, 56.38525578283495, 53.039552473252826, 53.53064498593731, 45.88132496803038, 42.947066522413685, 41.959668667085715, 42.52372510971562, 42.25808651216569, 47.30305863964943, 56.14791708607828, 55.85963464552357, 54.19150552441997, 54.107264780229144, 54.724081024046875, 55.81883415099114, 51.94864326907743, 51.55387240071451, 52.383802783104684, 51.431400314454116, 54.949197615346606, 56.044699914993785, 55.68440275807535, 55.57268973319761, 53.019713124921246, 52.61899986574727, 50.58958907281199, 53.67119919869208, 52.72047942684543, 57.022574255543375, 56.808263794068374, 47.54775570284936, 36.4897273432824, 19.11198792919036, 5.223591962168294, 2.929086555396357, 10.358081402317172, 4.2002480356923995, 2.747553380266313, 2.6285229286839886, 0.8056365698575975, 0.458861232524918, 0.39975212526417553, 0.24562220629905504, 0.39701280935156735, 1.2509683832045526, 4.745524660233529, 12.296302972301362, 31.043728167010894, 39.694088043705115, 40.679383508620724, 45.99290855469243, 40.87270928967384, 11.451767644574566, 2.3660928299350124, 0.1844491815615085, 0.23592056075651802, 0.17838602465006614, 0.12031195580118126, 0.15074897377241045, 0.1767888079367338, 0.19344083213758087, 0.13868662829120315, 0.2024901997778685, 0.12453165235778979, 0.15250922931778818, 0.11170816021941363, 0.18087818527654295, 0.15334032746332307, 0.18565344113496043, 0.18740713896770633, 0.11876705523219802, 0.21827410846467943, 0.1388048509796781, 0.16810264258134752, 0.1561220999686949, 0.13767635750193752, 0.1123935867461466, 0.13624959535175754, 0.13254134675427792, 0.08996992507168362, 0.1523602405382741, 0.08504489136319007, 0.16473213150616617], [0.04469231694876667, 0.04582814188794263, 0.06165830313318199, 0.056877159889066414, 0.10853965120810656, 0.018504365429943128, 0.03502548627194858, 0.06130160493475776, 0.011858041323120556, 0.018835575883126548, 0.01963724284583042, 0.03126367472202307, 0.033065074934594096, 0.05875052448602454, 0.09651179500525037, 0.033532465177197615, 0.021721771918237213, 0.019834709669192954, 0.04370414013523729, 0.016277537440821048, 0.049805229890250394, 0.04774950572379655, 0.03666621294894046, 0.10241371339126941, 0.03808285507764067, 0.09181794364966693, 0.04310551903120453, 0.06925446326814352, 0.03666483399067675, 0.027586939151308713, 0.033066358131867264, 0.013402884435509483, 0.025797903597835573, 0.08172771532929714, 0.15894939341852743, 8.024898238720434, 28.69557184557761, 42.024564281586684, 41.06018289442986, 28.428485893434097, 29.111684330048103, 18.313828745195945, 9.626401489780797, 3.5573188576006123, 0.1279425669100977, 0.48196684268693774, 0.8392151228843198, 0.6383211898707575, 3.062337560038413, 5.552982313017692, 0.5923242903044147, 0.3016284276400843, 1.146121344739391, 9.017470190601966, 10.226823206870787, 19.886038264920636, 29.86510495985708, 34.63798422967234, 49.52363791004304, 55.25782931235529, 55.52018488607099, 56.38039596619145, 58.04632463762837, 54.52354200424687, 53.124805188948116, 59.22774253352996, 54.85360553187709, 54.350977328515825, 53.36659185348019, 54.07559164108769, 53.15401507962135, 51.91878618732576, 52.92600377913445, 51.73747462611045, 55.61569852213706, 55.32426249596381, 52.19324619539323, 52.85659351656514, 52.856052229481364, 43.992825323535556, 41.83741231118479, 41.325684209023755, 43.14920979161417, 40.75533628463745, 46.262438143453295, 50.49255355711907, 53.00759692345896, 54.3794027451546, 50.179246394864975, 43.05847752478815, 36.79507993882702, 57.08298267856721, 53.02816583264259, 54.31891195235714, 52.292450781791445, 51.878707408905036, 44.70310380381923, 39.718995094299316, 38.046112060546875, 42.906415077947806, 42.07363313244235, 48.970944573802335, 50.874506119758856, 50.61177007613644, 51.33423143817533, 50.2202469302762, 50.48133165605607, 51.882315989463564, 52.24855945956323, 51.97224809277443, 51.68325570321853, 50.3340191994944, 53.9941357797192, 53.59233994637766, 51.80549636963875, 49.63592752333611, 48.713821441896506, 47.09985633050242, 49.63351526568013, 48.620441575204175, 51.261522462291104, 53.2281086521764, 49.44962278489144, 36.78223417651269, 22.76843905448914, 8.514334040303385, 3.201607441709888, 1.7421531941621535, 1.9133238350191426, 4.4576452432140234, 0.9430656954646112, 0.17145230074322995, 0.14683498460198605, 0.10905752664492016, 0.17669802651770655, 0.09005459310907511, 0.04770549780298625, 0.2349987578007483, 4.244963055656803, 9.43815419750829, 14.611421169773227, 24.979863512900568, 35.891863992137296, 36.57440347056235, 21.026492887927642, 4.33212302384838, 0.23774147514374028, 0.030080359992420966, 0.026854597400092793, 0.04209338281784327, 0.10694384409655487, 0.06514211861236442, 0.06478772633859227, 0.02326369623563463, 0.0264298073917387, 0.09911271713433728, 0.04888642999914385, 0.02986595879549221, 0.05283690793740173, 0.07387507661816574, 0.0456778890633535, 0.06041828257542464, 0.04890323030732332, 0.02043118189659811, 0.06838513733518702, 0.03714112617496041, 0.03283033027283607, 0.06276638036774052, 0.021942093059600844, 0.034685082763673804, 0.02531164652487684, 0.0376687539110501, 0.04378406225793785, 0.055756737147608114, 0.05194530033716752, 0.02262548179245524, 0.02763098537651522, 0.06517806345777166, 0.06226515585196115, 0.1231668437380464, 0.0360434141100174, 0.036636251250221845, 0.03318973276163301, 0.028617697046889413, 0.03745393136576299, 0.03686560648343256, 0.005900215755607332, 0.03980799315256938, 0.05167401328142132, 0.05274961221842997, 0.02706310355044421, 0.019460695968460173, 0.0539254499298911, 0.07773679560951649, 0.06845655971236768, 0.06720260401526768, 0.014857066787719248, 0.016773470204263445, 0.02919294097791276, 0.011522616428743688, 0.01875459081343105, 0.030202591235959725, 0.01064544862827226, 0.042095711725133086, 0.04197909782129911, 0.05233160400342557, 0.10249490338948467, 0.071465898635647, 0.03746622707694769, 0.045178499328152794, 0.3538889233623782, 10.509935963538386, 35.577854725622366, 47.63662484384353, 45.550006281945016, 31.022635621409265, 28.181684478636715, 20.303252935409546, 11.475628402925308, 3.3419741161407965, 0.25115405059149193, 0.13850891121452855, 0.9023833623336208, 1.2820568440421936, 2.7420718679505014, 5.928487479686738, 0.936170720284985, 0.26810147829594155, 1.3806387541755554, 9.357615190167582, 13.856111918726276, 21.946808407383582, 32.84646714887312, 40.73647752884896, 51.165408703588675, 58.046285413926654, 59.518637272619436, 59.00787799589096, 60.68464025374382, 57.848413605843824, 56.613561261084776, 59.31741576040945, 57.23744953832319, 56.85558719019736, 54.96671099816599, 56.5003381236907, 53.11390492223924, 53.32689354496618, 52.935346864884906, 53.30177860875284, 56.22395223186862, 57.13946088667839, 56.25948498325964, 54.454167043009114, 56.095871156261815, 45.19806769586379, 42.27447025237545, 43.72933226246988, 43.26424898639802, 43.19315994939497, 49.37256390048612, 53.496955748527284, 54.19627120417934, 56.67324796799691, 50.08254820300687, 43.931302947382775, 39.3186426931812, 55.780900909054665, 54.07172026172761, 55.91275138239707, 53.55358300670501, 55.11814978814895, 47.724383954078924, 42.25042612321916, 40.84388771364766, 44.82660355106477, 44.447071090821304, 50.9058262455848, 53.6157133502345, 52.724801878775324, 53.86335219106367, 53.007946014404304, 51.502359913241484, 51.93753511674943, 52.00596478677566, 53.70276643383888, 51.24172626003143, 52.03549631180302, 55.21543241316273, 55.40002307584209, 52.78748919886928, 51.781224743012466, 50.89270199498823, 48.75116632830713, 51.69647409069923, 51.87686389492404, 52.83104319726267, 56.11973093402002, 52.70639027318647, 38.828872019244784, 24.53482354840925, 10.962463732688658, 4.132917119610695, 1.7717077631142832, 0.970845146765632, 2.2069161841946263, 0.45849075240473597, 0.257049756004445, 0.09921436934101005, 0.1279508023552837, 0.09793518636856349, 0.19365279334447077, 0.2870563627971757, 0.5020976415084255, 4.64474279072977, 12.326361075524362, 20.490706928314705, 29.381362968875518, 39.9736471329966, 42.40856432145642, 27.063477539247085, 5.918724700327843, 0.6156650894591885, 0.06452190915062543, 0.043990454005618254, 0.06741160046189063, 0.021576908522195393, 0.052989696513020226, 0.08394116550804147, 0.05936182817564376, 0.037981103279537735, 0.07946042449123437, 0.05960916732287696, 0.054040481862161434, 0.05417640884256652, 0.051182767060855706, 0.053685737187944116, 0.09815985697411722, 0.07528157574274848, 0.06176168286812402, 0.029178695572960763, 0.0699927575225311, 0.036494287496973435, 0.03992920358394904, 0.04182699106393322, 0.04032971435076287, 0.022713225672862703, 0.004499522619880736, 0.029877260507595156, 0.021383312358070287, 0.03268517193294341, 0.01079002091090285, 0.23927476948067067, 0.1584216354474906, 0.1089813085573335, 0.1773547017646413, 0.18514797632252017, 0.15735939325344178, 0.10875151282356632, 0.14962892258359542, 0.09779642486283857, 0.21203335705063037, 0.08886817572337967, 0.1163155202483458, 0.12684597333352413, 0.19068852337377687, 0.16809881214172612, 0.11146765457646501, 0.17790921152599398, 0.15433417332749214, 0.12343316654404327, 0.1659856964984248, 0.11992246137871859, 0.10892930650903333, 0.14116602589286145, 0.1905469962906453, 0.13460013144198926, 0.1806510402069938, 0.18199710265523006, 0.10300663480114552, 0.06898933555930853, 0.13765426352620125, 0.1921244785790482, 0.1744074389458664, 0.16659124303729306, 0.21465711626074008, 0.5074874377779423, 12.561812131635605, 41.50435209274292, 55.73264006645449, 53.117105576299856, 40.201175981952304, 41.83256818402199, 27.135682490564164, 14.911558974173763, 4.299301120542712, 0.692263279230364, 0.7961193063566763, 2.765403351476116, 3.945351339155628, 11.795759508686682, 15.750532380996214, 1.021172097854076, 0.7968991225765598, 2.7322053909301762, 13.92643609354573, 13.433857002565938, 24.661210160101614, 33.4444462099383, 41.996825279728064, 52.10999388848582, 60.77494890459123, 57.801360853256725, 59.35838491685929, 61.994845251883234, 57.31199418344806, 56.70091244482226, 61.21961624391618, 59.52255179805141, 58.58349715509723, 56.297771238511615, 58.14679614959225, 52.975676674996656, 52.43304029587777, 53.75283156671832, 52.56297665257608, 58.36978289388842, 59.15908536603374, 56.52538637961111, 57.802757217038064, 57.689114386035556, 48.549968350318174, 44.90416842122232, 45.53837253201393, 45.55532893826885, 46.59308218186902, 50.59379385363672, 54.918018694846864, 55.20316323926372, 59.42692441325034, 51.661710123861994, 46.432982798545595, 44.73250589063091, 55.41301004348263, 55.021581034506525, 58.60964367466589, 55.53616069978284, 56.499694854982444, 48.39931795673986, 44.75743255307598, 42.84765012802617, 47.315061092376716, 46.502938270568855, 52.978277206420906, 54.51279078760455, 53.354169707144464, 53.84163794978973, 53.95956400902041, 51.66075306553995, 51.444916802067915, 52.815687118038056, 52.53292737468597, 53.16417794073782, 52.045870980908795, 57.69209930973669, 58.261525477132494, 55.36337244895197, 54.231137152641054, 52.58417706335745, 51.578520574877345, 54.95031549084572, 53.66342898338072, 54.93366502946424, 57.53266280697238, 52.623714554694395, 40.58580360104961, 25.653797311167565, 10.217120243657021, 4.7846841331451175, 4.275180014871782, 4.381488994244607, 9.397032068621728, 2.972262780512533, 0.3809384767326617, 0.3701325920560668, 0.6153075409031684, 0.6722751872674112, 0.4925590807632093, 0.9838875791718884, 1.8617599890116725, 10.762061015252145, 19.794452882582142, 25.285349469031058, 36.652748892384196, 48.037000779182684, 49.6353195559594, 30.53808366098712, 7.275129335541879, 0.7801422056171202, 0.19391667999086842, 0.1943518485753767, 0.1808153201014765, 0.2152603645358355, 0.15628942889311623, 0.3002171404659748, 0.07924028912619238, 0.20724774368347662, 0.27330192827409316, 0.26591717776271606, 0.21972575315064002, 0.18934523416382654, 0.10091853192857198, 0.2654472900734794, 0.19327806909718823, 0.12285670836365993, 0.12218151677159533, 0.1426891312603989, 0.10904914564302853, 0.14424084235102902, 0.08584681688056839, 0.11564432763524594, 0.08156904319842016, 0.143270913751856, 0.13431552977811906, 0.10334798825844642, 0.12255690751537202, 0.08173423473753276, 0.06715251718677821], [0.020647881357299707, 0.04347442867114179, 0.05342371596564209, 0.07540916002565816, 0.05207296888974886, 0.028959558037440145, 0.011858958713409883, 0.040675882670667865, 0.015793879321145437, 0.05673381334711468, 0.08484325702151946, 0.04065152873555499, 0.04396485900806804, 0.06790179714199997, 0.04020374268293381, 0.037752981447885116, 0.06285443451375732, 0.057164055986269835, 0.02283189652277337, 0.03819375779599913, 0.0080389512943164, 0.1059262112023369, 0.03222701688026709, 0.027744521522113395, 0.041481332192497875, 0.028884638468885136, 0.008874690017452645, 0.05747056393433483, 0.04812743221860259, 0.041271466236080856, 0.03255023320596064, 0.021640658528814395, 0.040907252715119434, 0.02321799717573149, 0.039914617269870736, 3.6199171889212827, 24.65904893413667, 46.723222501816295, 41.4384445067375, 31.907290912443596, 25.400104291977424, 33.25587434153403, 24.812250829512074, 6.912598388810312, 0.7946485401161256, 0.4112467842717325, 0.8959590715746727, 0.16727189683625776, 0.15178608828254286, 3.523973563025075, 0.763841815773518, 0.37776576955952956, 0.5127135057362818, 1.5944948335809093, 6.016139215038669, 10.44182792786629, 18.96947841490469, 28.948390176219327, 38.87405772362986, 44.896802210038715, 49.97779346281483, 54.58772374737648, 55.001631859810125, 59.31397584176833, 53.37376586852535, 54.05853325320829, 52.69763554296186, 54.768133163452156, 53.48999354147143, 52.36633646872736, 54.2913455347861, 54.089327781431145, 54.25644428499284, 53.115018875368186, 55.23952361076109, 53.93945401714694, 56.11331001404793, 54.58954372713643, 51.88531660264539, 43.909694610103486, 41.91880149226035, 42.29705918219782, 40.795046360261985, 41.52068091977028, 44.65982829370807, 48.6933623590777, 52.43029071438698, 54.05778800287555, 57.95496086920462, 46.71094156080677, 38.12418683882683, 55.21940969651746, 50.543595360171416, 56.39699935913087, 52.55023287188623, 51.97281683644941, 47.70681173570695, 41.40930129635719, 37.59375295331402, 42.82105253588769, 42.66267507306991, 52.11606571751257, 51.555539408037745, 53.40864358409759, 49.76917043808968, 52.34007227805353, 52.89623298952657, 53.439528326834406, 49.56297143813103, 52.02299179569368, 52.622396638316495, 54.89488455557055, 50.72507166093396, 52.11572447130757, 50.78456617170765, 48.98396684277443, 47.61562055157077, 50.753559835495494, 50.594746989588586, 53.807984013711255, 53.474774745202836, 50.04557986413279, 38.01034004457536, 23.858899147279804, 10.452993935154332, 2.767596446698712, 1.6504953705495404, 2.0871561717602516, 1.65743563684725, 1.4150281346613363, 0.6684908967825675, 0.1711731689471391, 0.04651978904862077, 0.062043143571504665, 0.07150906002930096, 0.04743629833683372, 0.20256789641514902, 2.39008131046449, 8.185994884660168, 16.773245296170636, 22.99904304165994, 33.67068459910731, 39.31018606308968, 30.191381439085934, 10.053437775181187, 1.0244697080023828, 0.07905843517472667, 0.05170332380540429, 0.03715192035381352, 0.02129236814535914, 0.049110234925343145, 0.027069588484723243, 0.03080357572123889, 0.031937027703069394, 0.01089289790064457, 0.028693020726824482, 0.08107446449538393, 0.039928188517449364, 0.09597396297800927, 0.0563819223504153, 0.018826470928146474, 0.060762332662219004, 0.0805568342067061, 0.034424191521060084, 0.029877528638368653, 0.024402125873753143, 0.05428505543198797, 0.10445405068176408, 0.0590781802912393, 0.02535227216750143, 0.019307916968940728, 0.018472341039488395, 0.02637634977638241, 0.03665255743169016, 0.1055770896134838, 0.016080398120046142, 0.015543440390648621, 0.03144220193667758, 0.06305590031608459, 0.034596216564457265, 0.021053197410618587, 0.04082467226732162, 0.07843150712189176, 0.03188850752438509, 0.025658366428087317, 0.01913384455556591, 0.04307166177539095, 0.03483007639466274, 0.046146037733002056, 0.011128696890908384, 0.04707815989311184, 0.02630227481976392, 0.028082942777884104, 0.053260010637102596, 0.02358991371077155, 0.02464980401489283, 0.025246808673405362, 0.02282741299319652, 0.04488251742816741, 0.040287690597676465, 0.025242514750589768, 0.02799787254433238, 0.06734970821848801, 0.06534824989015056, 0.08110279442682382, 0.008729373671925597, 0.01175894114684554, 0.02080871577134296, 0.04615754054318513, 0.03011179066473438, 0.024365391957783894, 5.211765035506218, 28.488658974247596, 51.51201286623555, 43.949185032998365, 32.76193026573428, 27.69200598039935, 25.793663147957098, 22.84762974708311, 7.800077296072438, 0.6837074867179317, 0.20972067550305398, 0.7878364250063897, 0.954020691494788, 1.1767961180979207, 1.5720174461603167, 1.4096267857859213, 0.15002828421852282, 0.6854327167234113, 2.343495074779757, 6.88584243097613, 14.649524054219647, 24.30807525111783, 29.970752039263328, 42.49201274687245, 49.52905862562118, 54.12302094121134, 57.23244459398332, 60.6155437807883, 59.49235739246492, 55.981486997296734, 55.27234208199286, 56.36620483090801, 57.25677505616219, 55.43052734867219, 53.14982991064749, 56.02463699156239, 54.685590805545935, 54.379390978044086, 52.88409717621342, 55.51361099366219, 55.35533159009872, 57.440447884221236, 57.75414728349256, 54.757778106197236, 46.51942007003292, 43.53319021963304, 44.532786646196925, 41.82939106418241, 44.23150547089116, 44.07566578157487, 51.394820290227095, 54.758386073573945, 55.52169107621717, 56.87814474105836, 48.57033329625284, 39.26235668120846, 54.04385966639365, 50.580465639791186, 57.73225261319069, 54.3607714868361, 53.448016335887296, 49.49385535332465, 44.74513592258577, 40.08567786985829, 43.37804871220743, 45.12387606405443, 54.734122291688, 53.24430411861789, 55.07306214301817, 52.579305479603434, 53.83258119706185, 54.336480248358946, 51.898236889992994, 50.675418376922615, 52.60320055869318, 53.318013298896055, 55.69764467977709, 53.69815372651624, 53.27826792193998, 52.51821456416961, 51.01468770734726, 49.73617546020016, 51.941339815816576, 53.123797139813824, 54.83298563188123, 56.4406043483365, 51.8660028519169, 41.01859792586296, 26.963447293927594, 12.879592757071219, 4.9634809647837, 2.2136374106330257, 1.1592469436507071, 1.2786209703453126, 1.0492232345765637, 0.24494162910888273, 0.23012199529236366, 0.10010560538860099, 0.04393343791185368, 0.22269872588015374, 0.07410051331164376, 0.018011715353256273, 1.6886015644957943, 8.570239582369405, 16.227738722678154, 23.19524980360462, 37.87996438241775, 43.41705276120094, 35.45819105640535, 13.130865673865042, 1.5546059223913378, 0.11204818068372627, 0.05811252263224414, 0.08355937026921781, 0.0336009917420245, 0.110467909835279, 0.034383546726237384, 0.046544380470990174, 0.0036712496629690817, 0.027674983721226457, 0.048395336996163094, 0.03514319185107466, 0.02932945784601954, 0.034812808772849466, 0.03618391463533044, 0.032907505970328085, 0.035644971780599125, 0.040313140038521066, 0.04383951936277651, 0.021416175614802108, 0.0006334043087741931, 0.02182488352240574, 0.03754662800460093, 0.054311385873945496, 0.021594641542422677, 0.060144026928971854, 0.05422107176855207, 0.08112558554257117, 0.06218218086888233, 0.07812672670209601, 0.08143403552352421, 0.07846062612389365, 0.16246391370171503, 0.10818549642159093, 0.11809845199628223, 0.09866464762918412, 0.10124931337251779, 0.18580333389822515, 0.10519878007471563, 0.1263362873766211, 0.12260620527329946, 0.19371159825353854, 0.13019639758333085, 0.12511083781118357, 0.08950492502340386, 0.11867827330265315, 0.11775890650648264, 0.14326452457856748, 0.2202232200051508, 0.19207414660242297, 0.11434120441516561, 0.10666793753062526, 0.1614012424984286, 0.18192050918456049, 0.13622210811703436, 0.17363920597539795, 0.12807225793479912, 0.1505779216606771, 0.2077178305555736, 0.13787923290604545, 0.07604829952000611, 0.13680647998567552, 0.11875653684499765, 0.13239540700470248, 0.13274966138264827, 0.16688612560110708, 5.889456954694563, 32.00400479378239, 59.93297684577204, 53.51357875331756, 42.03919079995925, 35.605868293393044, 43.3917260169983, 28.791061947422644, 9.36061482275686, 1.3284133759237107, 0.8174003708747126, 2.643601990515186, 1.6260123036561476, 2.999646562722422, 12.99067133857358, 5.2440495740982795, 0.7893223291443241, 1.5110066941668912, 4.748237469503957, 8.493673936013254, 14.17592139013352, 24.01610774378623, 31.2225607902773, 41.26963353926136, 49.26786015110631, 54.43363343515704, 56.27451158338978, 58.61244424696892, 59.64041509935933, 55.2388999539037, 55.47885879393547, 55.72821955527029, 57.54676765011203, 56.22961613439745, 53.68346445022091, 54.780939702064764, 55.87847771183137, 54.75875085399997, 53.741966601341005, 54.516132646991366, 55.23160042301301, 60.688892103010616, 59.40559848662346, 57.39519157717305, 49.35701954749323, 45.20507697136172, 46.817998732289965, 42.79501584268386, 45.056968273655066, 47.32511804949853, 53.89698651529128, 56.475678182417354, 58.275873507222826, 59.77038283501903, 48.6713304058198, 42.5187829232985, 56.36506342118787, 50.18037603747461, 58.237226393914995, 58.18321927901238, 54.23597343506352, 52.459269185220045, 45.777617500674346, 41.36165234350389, 45.61507840310374, 45.79443662397323, 57.81241801477248, 56.42885292730024, 57.58605410975795, 53.56761724718156, 52.181220208444905, 53.05544591719105, 52.95529211721113, 48.79407705799226, 52.17183005425238, 53.74525746991558, 56.37373185926869, 53.94389414018201, 54.66960322472357, 55.022577316530295, 53.37273428517004, 50.313438523200254, 56.1558206619755, 53.91236220636676, 56.945523215878396, 57.654593606149, 52.411930099610366, 42.284907679403986, 26.792106397690315, 12.708127325580968, 5.67721946585563, 3.994294183869516, 6.328521188228361, 4.435569653587957, 4.623168283893216, 2.067178805028239, 0.35839722822270087, 0.23509922257113844, 0.17130620777606967, 0.5001024727619464, 0.22534983442916026, 0.4701178220491256, 2.8771465295745484, 12.949525675465985, 24.379574175803896, 31.41998544816048, 45.7080150419666, 50.30442491654427, 40.25431233067667, 16.25048258612233, 2.0797872639471486, 0.31248300486514646, 0.15229066443299094, 0.15061852432066394, 0.06989220848246928, 0.21995824551390064, 0.1485460419808665, 0.18892495832856626, 0.13895213904400028, 0.07533118759672489, 0.096905862972621, 0.1513724008034314, 0.09064784393675866, 0.1762450387280795, 0.18665617361905115, 0.14046191448165526, 0.07485064362446148, 0.15556683944117639, 0.10917353533929396, 0.21813196851120842, 0.12515511003232774, 0.155763141810894, 0.2045278404388697, 0.16546127867073784, 0.15861435252572262, 0.1170072133742994, 0.19309649093737527, 0.134132465407733, 0.1656327291481918, 0.34942823852742877, 0.1367167251244668], [0.04545413776330891, 0.047389586125650716, 0.00776677318255327, 0.07669127711485471, 0.04966836828257769, 0.023061391567030264, 0.08727250650765435, 0.11013896700235144, 0.10383734224183906, 0.015461882670229722, 0.024709637396998947, 0.0664812786084029, 0.05871069940528082, 0.05648694534395492, 0.06502152871220343, 0.05400544100050485, 0.05126817437309412, 0.05773223658663131, 0.034233290071208636, 0.0688552778334387, 0.07214200953322072, 0.04640851094717941, 0.08948350520504099, 0.10838487846476418, 0.01417176475027396, 0.006044672167439375, 0.029328806671283902, 0.04057742122019972, 0.03792027589834986, 0.054864198750545906, 0.06072503950206503, 0.05832910334931747, 0.07689386140555143, 0.044628517146432595, 0.031248151865457336, 0.4341872565207943, 9.333361214207066, 37.772985658337994, 51.253301174409934, 34.17491312949888, 37.77621376898981, 50.87056413773568, 34.26830476330173, 13.79928069729959, 2.2740889797287602, 0.1575360071635054, 0.46015426636703555, 0.36556922079574683, 0.377286167875413, 0.24147183303871464, 0.5439948062262228, 0.18414461564633156, 0.18558193448810809, 0.2840941152986019, 1.4718646267729423, 4.993633695187108, 10.715747629442523, 19.766025504758282, 29.667388085396063, 33.386618706487845, 39.73284890574794, 46.287466787522845, 50.28623296368507, 50.39476102398288, 48.49580041823849, 52.96655324197585, 57.455156772367424, 51.283201402233495, 54.545424907438225, 52.85416949179865, 54.88338808859549, 54.18675161177113, 55.413959257064334, 55.28809039823471, 57.0504544627282, 57.108862476964156, 52.753003720314275, 53.08616199801045, 49.13527619454169, 41.708864473527484, 44.486577203196866, 41.31066153126378, 42.28659429857808, 39.46526873496271, 44.35576615795013, 47.123822012255275, 55.76552129560902, 53.78293968016102, 55.59663580309961, 48.24258396702428, 36.88593379912838, 55.165453572427076, 45.384545018596036, 52.52256839506088, 51.93370688346125, 51.98504678664669, 46.852158654120664, 40.60294435870263, 39.21098932143181, 39.38905316014444, 44.66859479104319, 50.19575957329043, 52.19490535797612, 53.39173816865491, 56.461965576294936, 53.180730342865, 50.42777561372327, 54.12470756038543, 51.046957046754905, 51.36407283044631, 52.6578313304532, 53.83659378174813, 51.373835609805205, 50.30316191334879, 49.79967863328996, 48.29366499377836, 47.134361420908284, 51.0118479113425, 51.65892131866948, 50.08665100220711, 48.0906548807698, 39.65697849950483, 24.432157470333962, 11.427678408161288, 3.4343400501435806, 1.6281218033644462, 0.6135546704453807, 0.6498574321308445, 0.5976908894315843, 0.5070115133158623, 0.17710946169832062, 0.04991419057572081, 0.09673767602972447, 0.07835235491755509, 0.05794398711934205, 0.1097374143559606, 0.21689974672852025, 3.861420952504681, 13.889162790390754, 27.905881058785226, 28.136206557673795, 32.74626039689587, 37.74719999682519, 22.452843189239506, 5.938298308080243, 0.30261953090948446, 0.04991312954394568, 0.04866380101790832, 0.05129905154688224, 0.06281788445888989, 0.035818387273578875, 0.06112763402803291, 0.03108354255316719, 0.004026139175684582, 0.05184043822209201, 0.00910165888677922, 0.044088559225201614, 0.05896159320048267, 0.06150220888817023, 0.06613249409823649, 0.030647650015570467, 0.12228870779396066, 0.06574574993142197, 0.04349977852055623, 0.017767348627169288, 0.0357017197435902, 0.049506899930777094, 0.05927534450987174, 0.03659102524961195, 0.008854070760970636, 0.11906714719389716, 0.08912445511668922, 0.012020115841991239, 0.1187454515527333, 0.05268832135404791, 0.013322438500190695, 0.08402401025617316, 0.0346846346022381, 0.046644201727523926, 0.03924624002989262, 0.06818637582323245, 0.021546418222809033, 0.04245307642005144, 0.04334774454154315, 0.03650906916347243, 0.03703913688960095, 0.018797951389945323, 0.07052296697492562, 0.06928722884866499, 0.04765407798150855, 0.0045563361791503285, 0.05276356650997074, 0.02017800898982152, 0.021150666777224793, 0.029747343486956054, 0.05015044060025004, 0.0846755680357737, 0.02228405938724116, 0.032808784049965685, 0.0720428164687849, 0.028825751205365506, 0.03741503708184727, 0.049961101969764124, 0.14642652184251817, 0.018774576132155715, 0.05880986948707893, 0.00913211088176937, 0.02859302135484834, 0.06476267526346831, 0.06801514751127652, 0.08195611678304211, 0.6378063787856411, 12.578378262058383, 44.63875339877221, 55.94754672819569, 38.069144218198716, 35.14622534475019, 47.58422197834138, 31.986579664291877, 14.901238237657855, 2.4866831591052394, 0.20033758464119128, 0.4079213498100158, 2.3017559080354633, 0.8510622742675966, 0.387757578564267, 0.3291092885117377, 0.14002188889970704, 0.06067574557457721, 0.49933843795330296, 1.0322556740814641, 5.48178639142744, 13.934494603064753, 22.327013554111605, 29.7144781004998, 36.61534124805082, 44.0197523947685, 47.45560746039114, 53.1233617567247, 53.86812963793355, 54.22826205530475, 54.19728317568379, 58.857768889396425, 53.81180440225909, 57.039691478975364, 54.52169456789571, 54.82698048314741, 54.21674205410866, 55.99072025668237, 55.73838633875693, 58.16322695824408, 58.442319285485056, 55.27102416561496, 55.953100804359686, 51.891211925014375, 43.336004826330374, 45.3001356124878, 42.529455692537375, 44.066832603946814, 40.80176538036716, 46.10037365267354, 51.002634263807735, 58.60507803578531, 56.52096586842691, 56.95565862040366, 49.02453199509652, 41.973506789053644, 55.20919584458875, 46.849452218701764, 54.72087644761609, 53.33586400555026, 53.60777447300573, 48.758003019517474, 42.131605763589185, 40.006724480659734, 41.79673341012771, 47.03269750841203, 52.39151808523363, 53.784559619042184, 54.795966302194905, 56.10306086078767, 52.44064969401206, 50.189370032279726, 54.09814919194868, 51.4301843797007, 51.891796358170055, 54.551186869221354, 53.67287012838549, 53.87900244805121, 52.24968910217286, 52.316357627991714, 50.58975381235923, 49.23060155683949, 52.06718121805499, 54.43051907324023, 53.46232121990573, 50.60006572354225, 43.90032014539165, 28.693918566549982, 14.23664164158606, 4.688568413257599, 2.5249841232453627, 2.114195275691248, 1.4123202283536236, 0.6946670179886203, 0.7179461623872481, 0.05800723150793103, 0.0904029639317624, 0.15482719687204208, 0.09527247158750411, 0.10171206878317941, 0.05922693924437608, 0.35337236559679436, 4.7059655958606355, 16.046674270783704, 31.32915512208016, 30.2126387242348, 35.93888144339285, 43.326928461751635, 27.635918048120317, 7.729699188663115, 0.33158396701178244, 0.02588788828542156, 0.03058043920675353, 0.005698677174927246, 0.04602179742388187, 0.01586125388125619, 0.07409390197285722, 0.013038620161223076, 0.05678930492590993, 0.048241552506243034, 0.01980459283766968, 0.0246145409877382, 0.10280225020382674, 0.035490965125181025, 0.09274617408312137, 0.05413758350656398, 0.12636133845174505, 0.09324639885415954, 0.04314605274327821, 0.03435491035962778, 0.03503664051212611, 0.009395948690061849, 0.002597237246171121, 0.04473278554336679, 0.057827472806938236, 0.09597299770722467, 0.016875097513078682, 0.025076469023441596, 0.04837035869939193, 0.06297773636517025, 0.11406090816542988, 0.18695119407869157, 0.061244864632645925, 0.0908839139306257, 0.16753003782322332, 0.3418438148594672, 0.06871913634841481, 0.16632377109940977, 0.20642459753059572, 0.17177784214577368, 0.13495000379700817, 0.08403927838850407, 0.1536601232064347, 0.19045802283911936, 0.14697880994889045, 0.13205486560060134, 0.14690192536480967, 0.10720898712714834, 0.19617257910149713, 0.15810291222747297, 0.12587125668482435, 0.182938348922518, 0.24257826318423598, 0.16359980758880416, 0.26447184564125154, 0.1496995099249386, 0.07650344001670038, 0.19218096990258465, 0.21813117177976718, 0.1495141626125382, 0.19198569409068555, 0.13312980953243472, 0.1767744208055158, 0.18578203665393014, 0.15398034795878396, 0.14309108227251038, 1.0586879138023624, 14.928716401900015, 51.090922894016394, 63.129888965237534, 44.75772280846873, 46.233381225216775, 61.16591115151683, 39.18042229067895, 17.946789033951298, 2.8986683295619105, 0.6180566320976904, 0.8940852205118827, 2.6634773756227186, 2.5688514209562734, 5.19111865951169, 3.6992289846943276, 0.8148160805144619, 0.6419386570492099, 1.7694213890260266, 4.344433382634194, 8.607211843613657, 13.776922206724844, 21.619739609379923, 32.110514794626546, 37.9726460672194, 43.981383769742905, 49.13504085233135, 54.35122836020685, 54.266611068479484, 55.038145203744214, 56.889311728938935, 63.23338462460426, 55.868150111167665, 58.85812974745228, 55.892072646848625, 55.96677026441021, 55.32667867598995, 55.40844048223188, 56.764725485155665, 59.14393325005809, 61.881237722212276, 57.24393321621803, 59.472129729486284, 52.64734291261243, 45.24881532115322, 46.806914114183, 44.250607413630334, 45.54598193014822, 43.88639573127993, 48.91878489525088, 52.56018784738357, 59.799773154720185, 58.94721461880592, 57.104406664448405, 51.700698483374815, 45.43361779182188, 53.928847928201, 48.19246392096243, 55.27969260369578, 56.00294236213931, 54.723759389692745, 49.596103698976584, 43.82407711398217, 42.6775957692054, 43.71927922771823, 48.81895272962509, 53.06390254728256, 55.99590955242034, 56.49893783753919, 57.16389333048175, 53.90055979451826, 50.45142358349216, 53.55338688819639, 51.50019084253619, 51.48329719420403, 55.12659072875977, 56.66703885601413, 55.609960094574966, 54.67254500235281, 53.6892891699268, 52.74368416878485, 51.545913911634884, 53.9950143906378, 55.23254179185437, 54.561094776276626, 52.81802485066076, 44.13685083389283, 28.699464797973636, 14.009300085806078, 4.814241643874876, 2.8053963280493215, 1.6623529407285875, 1.9404044915591518, 1.682721441311221, 2.149736116970739, 0.4927806027473942, 0.23584701631578708, 0.18549412549022706, 0.2172080511527677, 0.27221062070419716, 0.2416982426638565, 0.5375748055596505, 5.794079130695713, 18.972420192533924, 36.60182868280719, 40.229201316833496, 42.55537471463604, 49.61641765409901, 31.97806419864778, 9.113217207693285, 0.5631450431481485, 0.1535643315723827, 0.1990253219921743, 0.21419982305697857, 0.13166705657157207, 0.09198325010196817, 0.33689804315086336, 0.07085495117691255, 0.13794704700910276, 0.12300837845090898, 0.17249100871624487, 0.08248186760371731, 0.1721846501553251, 0.18856221569641946, 0.2569788775496906, 0.14455124585618898, 0.34314395799752206, 0.1245751967954059, 0.119623112522306, 0.07953841990280537, 0.1137125066992256, 0.10448722228888543, 0.21188377072253536, 0.15246216087572037, 0.1428001680441441, 0.13708591821693605, 0.15502590475784195, 0.1198519123417716, 0.18863580610242583, 0.13834964153507065, 0.1657222695047817], [0.04934268898420757, 0.008173018596285294, 0.02879665135556171, 0.028481105485210018, 0.09897905011330882, 0.021917302454371127, 0.05422349643683242, 0.06290428002455062, 0.011095364405322942, 0.026732147821495612, 0.017246983404601776, 0.0592705756125431, 0.015861549782716942, 0.04872825199497804, 0.04636146165730973, 0.02295770539691852, 0.013571518582231818, 0.05691230034215316, 0.016828412114973032, 0.03572167633401771, 0.027154040102276112, 0.04088746849447489, 0.04729322758653472, 0.05594800631966322, 0.06152387002422925, 0.05183824721062857, 0.02644682411975678, 0.033436934013039835, 0.02089267709262429, 0.025439663647463726, 0.07318821750701436, 0.023915321047928546, 0.007358222801779067, 0.12771529926648065, 0.06293351010930154, 0.05106450223754491, 4.064068736568574, 22.62484892722099, 42.67963540169501, 41.58703173360517, 34.140800276110255, 31.075330703489243, 28.643141523484264, 16.708314380338116, 5.309344289764281, 0.5043129532808258, 0.5225312902081398, 2.8561062005258377, 0.28756789502597624, 0.2382751013482771, 0.42426749042445616, 0.12235758675923272, 0.04552658286786849, 0.11404883461974322, 0.35033828969444003, 1.0554222954857735, 4.039457824922377, 8.372179500518307, 15.91466494144932, 24.1273618513538, 28.210311897339363, 31.150434286363666, 38.46067913116948, 43.13270053555889, 52.82048025438863, 47.69842963064871, 54.66246451100996, 55.62437088258805, 54.23506736755372, 57.83776437082599, 57.114232201730054, 57.61222808591781, 57.83270843567387, 55.766266545941754, 54.38764364488664, 52.275925836255475, 53.43014601738223, 47.43633293336438, 42.6720142364502, 42.946301660230084, 45.48071761285105, 42.49720596498059, 40.842165793142016, 42.108126455737704, 45.318135369208555, 49.72828365141346, 52.84238276943084, 54.15926756397371, 57.54063698553271, 47.9397181541689, 36.98671517833587, 56.552678231270086, 56.69461311832551, 56.46839826337753, 51.65511661960233, 51.47469935878631, 43.198172738475186, 38.76476872351862, 37.91525786922824, 38.652353594380045, 41.830595231825306, 49.2921043211414, 50.86675943866853, 52.58127843180011, 54.789353186084384, 51.29310146454842, 50.3180512305229, 53.059823282303356, 52.42560348203106, 52.06372168756301, 52.622055392111506, 51.366791032975726, 51.5353980372029, 49.1903188151698, 49.42348018769295, 50.66321588331654, 51.3719371826418, 50.89718918646536, 53.11921188908239, 46.072230646687174, 39.299948676939934, 26.60462494819395, 14.798676102392136, 4.625829121758861, 1.712895377028373, 1.9667299692669225, 2.6387519797971173, 0.8069171624318247, 0.5015139437971577, 0.29413973431914087, 0.16095983795821667, 0.2840609283697221, 0.03079436159872961, 0.07901067725352703, 0.03189360583952117, 0.23597947291789517, 1.1985743430352982, 7.511638451007105, 10.513066995528437, 19.663830111103675, 36.96674639178861, 36.165861160524436, 30.96196439958388, 14.10994222087245, 1.8570226238619898, 0.04893845886052136, 0.004190658472643625, 0.056415327614353555, 0.05464596711399575, 0.06586363554121026, 0.01964896973673134, 0.05293552643589435, 0.04334212145617893, 0.06591916925484134, 0.03245182921208682, 0.05752563416477173, 0.03255683688386794, 0.02371407358065969, 0.018836115975113168, 0.024974255657364285, 0.08507230965000007, 0.021181513307495944, 0.037112765600003546, 0.03325392326880847, 0.005232991477955254, 0.06014081702056912, 0.07801424967305315, 0.06060859030713478, 0.03971831490015311, 0.041508543635568315, 0.033984893722639936, 0.05279830093645761, 0.046354907775117506, 0.08203143088687813, 0.012572483429985662, 0.019593085537874894, 0.015022190336528567, 0.07150966523876114, 0.045198413783744465, 0.07019328103671152, 0.07943176514198703, 0.020274413494212974, 0.11306725382324188, 0.11663696308049465, 0.05038206345371662, 0.03469570840318357, 0.04822516205510305, 0.03541701082741061, 0.042864913796825756, 0.03372616284797269, 0.07180365147970377, 0.04034743396445148, 0.06764911836193455, 0.014659758927601, 0.05226066809207682, 0.04040062727947389, 0.041708297231384826, 0.04135955102561463, 0.060864555604395375, 0.05445187490793967, 0.0394594116557029, 0.021129539987492948, 0.017965909041043733, 0.03260053070862928, 0.026316062487181158, 0.04193075001239777, 0.09240374044184724, 0.13105919644717248, 0.04211085728339611, 0.03261697478592396, 0.09586473416176536, 0.10624231440165352, 4.874688800304167, 28.338036037260487, 49.27267682167792, 44.19983625411988, 36.97270447208036, 35.21353321690714, 33.96583510983375, 19.718978635726437, 5.972943132923496, 0.596359306045117, 0.12154244622516057, 1.4719693050269158, 1.2473624992755152, 0.3447092594879289, 0.20894006255172917, 0.13956050478642987, 0.01804161576494094, 0.2942546475077829, 0.6209813719314914, 1.345584654519635, 5.021488897262081, 9.74521694644805, 17.12507405588704, 25.389566844509496, 27.557747171771144, 33.28197379266062, 40.91061899738927, 45.19822066830051, 54.08165170300392, 50.85635339060138, 56.21582508087159, 56.2924172032264, 56.11037608115904, 57.50219383547383, 57.69600206805814, 57.054329764458444, 58.45725567110124, 55.60330775476272, 56.61800530649001, 55.52694312987789, 54.67882863936886, 51.105737686157234, 45.29118476375457, 44.441367964590754, 46.633282553765085, 44.69937755215553, 44.64950461541453, 44.53440658507809, 46.59484724844656, 51.66713476181031, 55.76227749547651, 55.91387318026636, 57.90500556269, 48.65103998491841, 40.54347730452015, 56.04380169222432, 56.112125458255896, 56.87541477141842, 53.68928524755663, 52.18757837049423, 45.781790902537686, 41.42100172658121, 40.00089976095384, 40.88141302908621, 44.889710564767164, 52.049542319390085, 52.12528720978768, 55.184743788934526, 56.52756329505675, 52.12986853814895, 49.979162370004964, 53.43972052297285, 53.03448477099019, 54.00215702672159, 53.96896593032345, 53.842124323691095, 54.07032389794627, 52.2662454266702, 51.581572178871404, 51.837675494532434, 52.96256026914043, 53.868098258972175, 54.36243064941899, 50.37760457684917, 43.643361753033055, 29.250022403655517, 14.912068882296163, 5.509956854005014, 4.1595593287098795, 2.2810575606361514, 4.71014242979788, 0.9273830176361146, 0.38697019339569155, 0.23677269567645368, 0.2212765296140025, 0.38184206211759203, 0.10763252649696604, 0.3993029525924114, 0.05347303287576764, 0.3344363881455314, 1.6195267871502907, 9.819386024628917, 13.799920043637677, 24.964766310107326, 41.265440525547156, 41.12555311572167, 36.460835164593114, 17.18986180520827, 2.5087974821367576, 0.11917578612243938, 0.08927915125123917, 0.09628734656519468, 0.06255641098945372, 0.09410315328427861, 0.07486324577081589, 0.030890963370761568, 0.029595734686740947, 0.04193486773499078, 0.08769944730785587, 0.013992574869564945, 0.011497075057348177, 0.06890786210856131, 0.10298869302195889, 0.033675593384090936, 0.025427132364242308, 0.0671996392550007, 0.08278513116942299, 0.05428509373638419, 0.027246311562316074, 0.04234854755322299, 0.01476486236037266, 0.02911286563762734, 0.02994643250149825, 0.03614307831852667, 0.010556872584857048, 0.02191850904285187, 0.03887095270798572, 0.023035467151672612, 0.039759518939160535, 0.00629738973070597, 0.07611304927136629, 0.12044587563122473, 0.11810188407018302, 0.17094761734047245, 0.21176936315192332, 0.17229914965648807, 0.2062704606402305, 0.24263463193370452, 0.1350755962513147, 0.24084701172767148, 0.11509552522892914, 0.15695845347739038, 0.12754538096487522, 0.2102810075326312, 0.13142480424815609, 0.11140183230201084, 0.10248236253016418, 0.09252229254812964, 0.10076696143275309, 0.1102811529210979, 0.09890947400802567, 0.164578469590314, 0.33039472276164644, 0.23699011142936446, 0.14082736906505403, 0.16965306664426483, 0.19344714470207694, 0.17713121859537018, 0.14935429538449935, 0.06480733818945385, 0.20415576685580517, 0.2831582316467839, 0.18379636739771213, 0.13123152026486012, 0.22360071780220156, 0.2167300735750506, 6.427434048345012, 33.05342120508994, 55.27955924310992, 53.48262733028781, 44.92181908699774, 42.53984605112384, 38.19858635625532, 22.525773779038463, 7.266329007764017, 1.3140133744285953, 1.0456113445182, 4.476706001066393, 1.3519414682542126, 1.0698953511253482, 1.2984524739365424, 0.5476415073198657, 0.18108847641175796, 0.7144421987956571, 0.9100447318726971, 2.103776970217305, 5.468975930444656, 9.903693449112678, 18.282722388544393, 27.304058074951175, 30.908716263309604, 34.81838580100767, 41.606208201377626, 46.68677191580496, 53.312286638444476, 52.167597816836455, 59.667055837569706, 57.834983410373816, 57.11459698215608, 58.78925292722641, 57.572431718149495, 57.60594052653159, 60.271732345704116, 58.22475325676703, 60.48243814899076, 57.13336160106044, 57.036373153809585, 51.094633456199404, 46.959039318946104, 47.161155131555375, 49.80705268921391, 46.80439987490254, 45.50004313069005, 47.029441941169004, 49.4328389629241, 54.29549932479859, 57.50721054692423, 59.05470717337824, 59.10059498202417, 50.999013916138686, 43.50315663122362, 55.99865913391114, 58.56249678519465, 59.39868727037984, 56.73745716771772, 55.109795139681914, 46.309773306692804, 42.23968275131718, 41.32610782500237, 42.01568795788673, 45.588072884467344, 53.747136285228116, 54.26019799324774, 55.9563720610834, 56.58752456788094, 52.72949695587159, 50.623878432858376, 53.0871190563325, 52.938680879531375, 53.804081255389804, 55.741979229834776, 54.29803709830008, 55.20775241236533, 54.79114570925313, 53.93077773432578, 55.19780135923817, 55.360885666262725, 56.20355198460241, 56.05269762777514, 50.38801846965667, 45.00432222120224, 29.20088295013674, 16.608652837814823, 6.624798890083067, 3.89550389782075, 4.573970975414399, 5.906777160782968, 1.7634728695115738, 1.8624817051233786, 1.2058874796475134, 0.5130273259935841, 0.8075826170463717, 0.26151545105441926, 0.4208270508435465, 0.32975393617826126, 0.7010802770814588, 2.0918632611151664, 9.140992491475998, 17.24037212710227, 30.864591560056134, 47.7550765006773, 47.80327850772489, 41.96362633858958, 20.006339319290657, 3.1587555475773352, 0.21470654425361466, 0.11695874299133018, 0.22321586587256004, 0.17476659628652758, 0.17552490075749738, 0.2884804283178622, 0.10863345101355545, 0.11381530037690556, 0.14527853908798388, 0.269581989174889, 0.09403350823108228, 0.22585983448211225, 0.18460747064842334, 0.16696153929637325, 0.09766783700474808, 0.21007099218906897, 0.22473440535606878, 0.20971145180444564, 0.09861816141393878, 0.09184971331588684, 0.12569520201894546, 0.14155705249117267, 0.09916174676149123, 0.14351264513548345, 0.1351164900247128, 0.13910135764989162, 0.08198803200596765, 0.19134320679210848, 0.10992090773558426, 0.10512478364210938, 0.19198546426430826], [0.08261986302151796, 0.06137046857827133, 0.020512410199209567, 0.03693523238443079, 0.0554276219448976, 0.04662317644444205, 0.04192911824511905, 0.016473891521473567, 0.013443352072499694, 0.03470628041653864, 0.027582627991514824, 0.015548807794168113, 0.03667219992606871, 0.06775181244818435, 0.07630776583908067, 0.05686269997949562, 0.03439036490876348, 0.03136496878259125, 0.09362940451190357, 0.04152298056250138, 0.03830498993216503, 0.01797524956806052, 0.03735109172280758, 0.016055401628686777, 0.06657075001707961, 0.026478034541791966, 0.07451482898285312, 0.011576017545115565, 0.0907732218864464, 0.10535844045901492, 0.014709351629379296, 0.021818172592189045, 0.06211301462063867, 0.015727991929217693, 0.07944128761488585, 0.02539829298433277, 0.4139352013026515, 11.124350736218116, 42.52010868441674, 44.89266018713675, 39.103657584036554, 27.536940959192094, 19.51789636765757, 24.191704411660474, 11.212450112065962, 2.1335992409336955, 0.5903805107358964, 1.5949314424107153, 1.0624473830384593, 0.20932943440012394, 0.04619173104724577, 0.06324567561668736, 0.07782714801930612, 0.5134234547374711, 0.1105183260815759, 0.15008762538913759, 0.7439229168718862, 3.2911691261876017, 4.713207271791274, 10.572137890323516, 15.04549026489258, 19.775907916407434, 26.62555471543343, 31.67299793612573, 40.987658269943736, 48.48290366511191, 48.79049201165476, 57.09615791997602, 57.83543056057346, 54.76007269274805, 54.85053823840234, 55.05666271332772, 54.87243683107438, 55.234824611294655, 53.95628098518618, 53.5687586569017, 47.759449943419426, 44.07352808983096, 48.318630879925145, 48.54657157774895, 49.672315351424686, 47.57310205890287, 46.77038508076822, 42.74989289622153, 44.44766729108749, 50.1454512534603, 52.40848625859907, 54.528331218227265, 54.94492223185878, 52.21311300031601, 37.55438020152431, 53.843073537272794, 55.02065927751603, 55.0699556258417, 52.16046302549301, 47.29958734204693, 41.17501420359458, 40.68730669636881, 38.26670615903793, 37.14652430626654, 40.05294569077031, 49.20685945018646, 50.4989666323508, 53.32359875402143, 55.271314421007716, 51.59722635822912, 53.227873309966064, 52.44456029707386, 53.27146260969101, 53.917853524608, 53.7834809672448, 54.745818799541844, 52.388223294288885, 51.2111121608365, 50.34945764849263, 52.410510201607984, 52.46956540692238, 51.87079991063764, 48.975274870472575, 38.93248534971668, 27.46250810161714, 18.069924000770815, 6.511611054020544, 1.5872241075961822, 1.5126005247715981, 2.298377276428284, 5.316715894206878, 1.0018321775620984, 0.4022958436079564, 0.10646733740765242, 0.1787488132474884, 0.3042353942028938, 0.04191912079770719, 0.14420351854735805, 0.05175018923417215, 0.29138374833330033, 1.95078945688663, 6.901611339661383, 19.31028727562197, 31.023163180197443, 32.363164463350856, 36.66215473605741, 24.87148254148422, 6.710160451550638, 0.8909468953647922, 0.07493231625806901, 0.05575913883325073, 0.025719000372074308, 0.012276947776216173, 0.07394122831042736, 0.024432363364124493, 0.05644158527795827, 0.05442272909286042, 0.0339071243070066, 0.012345910053549996, 0.016354056217917995, 0.051819439752087484, 0.04995752050871811, 0.041241952698797955, 0.06642310189143305, 0.05481697709089326, 0.05674734629029709, 0.04172734217718244, 0.042484865238469456, 0.041449631474191145, 0.07950699497615138, 0.07501951238561062, 0.020845654615831953, 0.044619534765520406, 0.058838620766877174, 0.0301894145236621, 0.026217637425889413, 0.042543310086212816, 0.05444876842140671, 0.02671846357594815, 0.01948860646676152, 0.05641452322203306, 0.029386891457702846, 0.04741631493332887, 0.056582629725697546, 0.036704781645488356, 0.0230214515730979, 0.06404430695599125, 0.02241344397677289, 0.028444084286269163, 0.02890816119860017, 0.06567433521512055, 0.06791763217939485, 0.04132418840702984, 0.06887403932670433, 0.010141380011074005, 0.007399668637287593, 0.04929630619083201, 0.04280856802999493, 0.050194107611934026, 0.049557457903339985, 0.04002606008021582, 0.007567511319423155, 0.04080151342937062, 0.07933362161800747, 0.037417837133210514, 0.07476471920287417, 0.03715847423600574, 0.03531836551584063, 0.08617082610726358, 0.05103288961934948, 0.04335373534911102, 0.03684518640981086, 0.04650595350070827, 0.07006949654990627, 0.005643939235127501, 0.07141727503509292, 0.8069607987999917, 13.867714289695988, 49.99111775429019, 49.9584012646829, 40.221960621495406, 26.460315065999186, 23.330238173084876, 28.224071571903846, 14.599376551566587, 2.6452898354299608, 0.32117402721797267, 0.13760117363304863, 0.413552402488647, 0.09838556179836874, 0.05607282502516624, 0.15973659472600107, 0.08136566217628219, 0.10290580996943098, 0.6042493987948664, 0.3189533221865854, 1.3260872878374592, 1.7949632507178093, 4.113963736641792, 12.493698212408251, 17.83523290388046, 20.79654197539053, 27.43218033544479, 34.87455414187524, 42.73317183217695, 50.52310489839124, 50.77640371937906, 58.25431223838561, 57.15880993873843, 55.94107481741137, 54.56019263113699, 56.94666070322837, 56.829405369297156, 57.828848823424316, 55.44878598182432, 55.065186023712165, 49.26216094724594, 47.1461049972042, 48.417713872848026, 49.65296237699447, 51.03025951693135, 51.02307373477567, 47.408468415660245, 46.04888469942155, 47.692557842500754, 52.72787701699042, 53.88395640157885, 56.062887945482814, 55.8571360957238, 50.7849701758354, 40.80644476798273, 54.23485163719424, 56.82467499086934, 56.030810802213615, 53.722052727976155, 50.978590134651434, 44.430969761263945, 41.67572829031175, 40.61800233779415, 39.44258959062638, 42.807936130031464, 52.05890893936158, 53.35759785867507, 54.74687783948837, 54.71104698796427, 52.650520032452, 53.679961773657034, 51.640509713080625, 54.48113333794379, 54.32234010388775, 53.77040770746047, 56.42826457177439, 54.40593365700015, 52.786234040414136, 51.2644132491081, 53.59044936395461, 53.74979957457512, 54.306603554756414, 51.599791588321814, 41.17897971983879, 30.254947370098485, 19.30010676383972, 7.2240537020467945, 2.261412859924378, 3.1092174831897985, 3.38169718461652, 2.3865950588257085, 0.3684156358001694, 0.14289269614363873, 0.059346234455945036, 0.27250093738398246, 0.3523380243249478, 0.06927107971522116, 0.25255923970572414, 0.17897307782644228, 0.3004070689841625, 2.4410623167791674, 8.181847958795487, 20.423671660884736, 33.51208748355989, 36.35600982173797, 42.17255138581799, 29.355826377868656, 8.439349109126676, 1.2346987594519894, 0.06004698657160325, 0.09338183553829309, 0.04859618992815095, 0.026297856407660632, 0.03339598661348705, 0.04622663018263636, 0.04948368363623177, 0.03548173376569345, 0.05025858540208109, 0.033876247133218476, 0.05846061000239946, 0.015457311040541578, 0.013360720871376896, 0.03407682044311397, 0.022812537480926803, 0.038207367347973975, 0.06497819111832688, 0.05278967861686984, 0.049593245700722745, 0.03852258954617766, 0.03672328649929935, 0.03258754551831273, 0.029145284563363082, 0.11384814256621946, 0.039563392769665494, 0.017092741177146955, 0.027244457629539316, 0.09153701154695404, 0.030602067784075777, 0.02674522494236308, 0.03079390003075523, 0.1164876908484486, 0.24479181295441044, 0.17031819950188362, 0.17352734181669452, 0.2907372007687246, 0.16487396502446744, 0.18689202144742015, 0.05051777209906329, 0.10494122897545177, 0.11881712673892898, 0.12056750741096274, 0.1575292349462548, 0.10388273295135268, 0.18064223019586456, 0.13107742933977035, 0.08598802220677176, 0.13287617314246394, 0.07818242895507044, 0.2784795794756182, 0.15829873962267754, 0.1599454609376769, 0.083777682345, 0.08922328811980064, 0.1047755931053431, 0.12513661666983558, 0.08205435989845185, 0.1655592459944948, 0.1725728422283165, 0.3001550567005911, 0.17793789385787903, 0.2434360671548113, 0.1382571594008515, 0.15972478165020867, 0.1991884374330121, 0.11379718239749632, 0.19148139373189021, 1.0614135933499182, 17.53402037005271, 55.9360110375189, 56.84444765890799, 51.345778895962624, 36.558423734480336, 28.849020850273874, 34.56258843022008, 15.473653251124968, 3.1841700548125855, 0.6977100417979303, 3.5275247789198354, 3.444074392318726, 0.5497116607523734, 0.8202356929259916, 0.34926205873489385, 0.3505562263871393, 0.8688858920528043, 1.106494987203229, 0.7199089409362885, 1.936637300156778, 4.829865915160026, 6.415771861230174, 12.36860009931749, 18.211843198345555, 20.65982384066428, 28.8941575250318, 32.750567159345074, 45.247713135134795, 51.26835523113128, 55.97255576041437, 60.19920772121799, 58.96684608151836, 55.76486233742007, 57.04468465620472, 57.90520560356879, 59.16251743993452, 60.482285176554036, 58.19961478633266, 58.33211245075349, 51.118002937686065, 48.08346909861411, 50.51596226230745, 52.75463934867613, 54.283924410420084, 52.89356185543922, 50.21744635797317, 48.758834561994, 49.82996717576058, 54.98349874250351, 56.798544160781375, 58.22935419697916, 57.05699305380545, 51.863080686138524, 45.14478229707287, 53.60933165396414, 58.915870958758944, 57.92181684124855, 55.345054980247255, 52.304751334651826, 47.05071687698365, 44.5060400039919, 41.84500994220857, 40.49001932144165, 44.499701453793435, 53.56126692987258, 53.53483407728134, 56.94384444144465, 56.95918483118857, 52.472389513446444, 53.316354136313166, 51.57836368007045, 54.66968167212702, 53.01567308364376, 54.85305640005297, 57.466480655054895, 56.04324863803003, 55.023200973387695, 53.67433709482993, 56.518055469759055, 57.80235321291032, 56.254166249305975, 52.358091646625155, 41.812265996010076, 31.059823613012995, 23.249943333287394, 8.50494388611086, 3.589132711771996, 3.897673949118584, 5.298344002616021, 10.328368467669334, 2.7632475187701564, 1.0884697350763506, 0.4794443909439349, 0.6974869569943798, 0.6982824626949526, 0.16510895483436125, 0.3210388280210957, 0.4282019954294928, 0.5091528209947771, 3.2714261210733846, 12.232349707234292, 30.415282095632246, 41.69060584037535, 45.173996110116285, 48.97259589164488, 33.51356621711485, 9.465257775398994, 1.2175886453159395, 0.19514320207939995, 0.2290208205100029, 0.11941870494234948, 0.09982070495044032, 0.09087622240786591, 0.10078773007638032, 0.0892797487998201, 0.15534092011230607, 0.10030326373394459, 0.12657672407165652, 0.12573502326924957, 0.09666406264108035, 0.23552536663989868, 0.11342427377859432, 0.1560701285639117, 0.1437758729462662, 0.12735472466315956, 0.0851565563390332, 0.13170240386839838, 0.16601064032123936, 0.2087258030810664, 0.14822125134448852, 0.15988939862337806, 0.26356577813144655, 0.11922513750652153, 0.1297184046838553, 0.09039135769970956, 0.2994562006525455, 0.1375256986507485, 0.10200496717926957, 0.09694592937106088], [0.08654836955810748, 0.03949844766588461, 0.03824914212248499, 0.021310821288235245, 0.00801126774956262, 0.05294139466939434, 0.06586356659329708, 0.08856958529401211, 0.016688986027973796, 0.035831154128837014, 0.005725282929732555, 0.04425414913003484, 0.09456953995170132, 0.04679516701388263, 0.042205986251393636, 0.04080399938468491, 0.026577363586834362, 0.0354974577203393, 0.004583704670245249, 0.06268796743825078, 0.028070861571318204, 0.05539505554723644, 0.04435567110176048, 0.024968238036719062, 0.06019198020259219, 0.04739485681056977, 0.007234109854776293, 0.10190654786363726, 0.07724720413886732, 0.06107026936426278, 0.05457570536002036, 0.037352463020192045, 0.038700065305156094, 0.04343639240570126, 0.009540188682055282, 0.027672057265355706, 0.08134765911006159, 4.10230694278594, 23.339959767556962, 45.92496525856757, 46.23595037767964, 32.12027169043018, 29.351439206830918, 28.479604182704804, 17.61020652709469, 8.450984820242851, 0.4891695094204718, 0.18656828801237768, 0.19312918756998357, 0.14574887110821663, 0.1047142984105214, 0.03205134142791072, 0.09611100078590455, 0.06770336504785285, 0.4433226711567371, 0.13340386982646682, 0.7665497833682645, 0.24707452514238898, 1.098178459271308, 4.53448643607478, 5.8655707009377025, 11.355547981877482, 15.248724933593506, 23.106488527790194, 28.24724885725206, 37.77069107178719, 40.45485527284684, 49.081853512794744, 57.10532057669855, 55.08635897790232, 59.062026316119784, 56.457733338879, 55.77158135752524, 53.74206466059531, 52.543506007040705, 50.41616147564304, 50.914639811361994, 52.08568696052798, 52.99308023145122, 54.86449403147544, 56.589175885723485, 52.28035419218002, 49.521296255050174, 45.89245273220924, 44.43997160080941, 47.64231228059339, 53.20441753633561, 54.27671117167319, 56.174899070493645, 50.09765325054046, 38.46581743609521, 53.273635602766475, 57.15775482116207, 52.326324370599565, 51.13020935366231, 45.2950914444462, 42.35476901454311, 40.81006511565178, 38.75874396293394, 42.544682333546305, 40.159673383159024, 49.93317257973456, 52.318926780454575, 54.06273803403301, 55.157542151789514, 50.521457502918864, 52.442634413319254, 55.31666486494003, 54.88807139858123, 54.16973244759345, 56.513278022889175, 53.70366465660834, 55.02100052372102, 53.04781690720589, 51.63314350189702, 53.14965732635991, 52.67192440648233, 47.08283324395457, 38.59962909452377, 28.80923821080116, 16.484978545096613, 6.755013244767343, 0.6572632347383808, 0.8349931204030592, 4.7383378974853025, 3.338193931887227, 2.9381724807523915, 0.18419575967615653, 0.17544908869651057, 0.1477128600761775, 0.15457838683599426, 0.08190526386662837, 0.19415934600176352, 0.42692854279471987, 0.14784664967127387, 2.1554649837555426, 10.798080140544522, 26.482070492159938, 33.006184101104736, 30.84961202836806, 38.108901362265314, 31.23352381490892, 18.015265772419593, 2.028859699926069, 0.17014952226271554, 0.055153802968561656, 0.036350887328866995, 0.04689495379645978, 0.07334872058803037, 0.0478217133410996, 0.04147941314224755, 0.02651898002612495, 0.031146593504555287, 0.04151657223701478, 0.10291301119591921, 0.10848234783137038, 0.06874378905781815, 0.05880218945563801, 0.023000351596443404, 0.08137803449625931, 0.08576204925174676, 0.04407473516860797, 0.03429098032234657, 0.03279127128001663, 0.06178890963295295, 0.017722584194533767, 0.04753556417962236, 0.02265167242336658, 0.020014466454965935, 0.037715312904648246, 0.029376514796768467, 0.010477426394279446, 0.006605228756539404, 0.0311748200141254, 0.06815335743369595, 0.025869189994409684, 0.02260092292882262, 0.08932916913181545, 0.0530539789507466, 0.01105392862471842, 0.01596269254092007, 0.09595792875775407, 0.04908817925400311, 0.0649809873392505, 0.07348457095964302, 0.13290206691430462, 0.04692490017341991, 0.019108098255650654, 0.02675410390140549, 0.03648257018217156, 0.05227447682691198, 0.011467715695260033, 0.06829932782678835, 0.0235731708591864, 0.014667849773691307, 0.06179832485354236, 0.006302261571099441, 0.02813010315050281, 0.057183529941305045, 0.0858157673369973, 0.08131653295769807, 0.0429429360214741, 0.06845775480952955, 0.0641092099249363, 0.07913323599965343, 0.05185844511875222, 0.09537252267041514, 0.026262758089409723, 0.013690557154346139, 0.05844908420957866, 0.0673560054612256, 0.05181412310189298, 0.07980173198325981, 5.579690712113535, 27.84805943889003, 52.49697492968652, 52.58635790117326, 34.20076939367479, 28.017166545314176, 34.36153950229768, 22.08380110802189, 9.955180441179584, 0.7062334134694069, 0.3607353898546388, 0.3177797980606556, 0.09848356742652194, 0.012989677676570513, 0.033654066313418655, 0.050762552512629386, 0.05327929307015673, 0.712298010626147, 0.565580589877021, 0.9071009930583739, 0.9213410353948994, 3.048156720976676, 5.534679553201122, 9.139668691542841, 12.591019080531213, 15.903042958628749, 24.11403559869336, 30.168327708398145, 41.50734093881423, 44.717757778783, 52.00649822911909, 57.34639729222944, 56.47192839653262, 59.510686628280155, 58.73003298236478, 56.61645597027194, 56.15414580991192, 54.58053404285062, 51.8115681986655, 50.909309310297814, 53.5320060483871, 53.9482440487031, 56.716645071583415, 57.19908483566777, 54.472704164443485, 50.82082456158054, 49.194547130215554, 46.31065583998158, 50.00833695934665, 54.7953583348182, 56.94367970189741, 57.11723673728205, 51.644216352893466, 41.43538505800309, 53.228944117023104, 58.55103561955114, 53.75634208802254, 54.61897719290949, 47.302478128863925, 43.1623811106528, 41.67384555262905, 40.430391450082105, 42.66642485895465, 41.632201748509566, 51.679023465802594, 53.48703999673167, 55.1850026653659, 57.646274259013516, 53.345469890102265, 53.61771768139255, 53.63099098205567, 54.38238374648556, 53.86427787042434, 55.61560046288275, 54.854390005911554, 56.350366300152196, 54.76331257051038, 53.03598311639602, 56.072101593017585, 54.811816600061235, 50.39756944102626, 41.110479447149466, 30.314024148448823, 20.11341610262471, 8.709543539631753, 2.036286830421417, 2.561734280278606, 6.545245868544425, 2.948728804626773, 1.4817181109420716, 0.13728053519322028, 0.1138245777016686, 0.1699974231662289, 0.8045247617748477, 0.8105946909035406, 0.3356396364829233, 0.17540093240959032, 0.02639031172880242, 2.2211676259194655, 9.46393201428075, 27.501806328373572, 41.704389049160866, 36.760394419393236, 42.945301455836145, 36.92664407914685, 20.862320123180268, 2.7789502374587522, 0.3037011244845006, 0.04570045418316319, 0.010677800521314626, 0.09117946299093385, 0.027475728082560727, 0.09749627927498472, 0.08595382404183188, 0.056624370026251966, 0.06824691209100908, 0.08043255176275008, 0.040966555581337986, 0.04806398098627406, 0.05427428423577259, 0.026620253019275206, 0.009726674592633162, 0.04439725052385081, 0.01631925092829812, 0.03127741259372523, 0.02908358192672172, 0.035039877233606194, 0.03834932727078277, 0.046099513213360505, 0.02939667823093553, 0.010635884978147525, 0.03315104915189647, 0.028997295528590202, 0.05440409017366268, 0.03638061154032907, 0.04795621922840515, 0.033700173315141475, 0.03409471242658554, 0.024534528849706538, 0.16697925124918261, 0.20513873427144944, 0.10614344309414588, 0.05931868593418791, 0.11456382956596152, 0.1316717143861517, 0.12137805907836846, 0.140999325160538, 0.1752175922475515, 0.24111750205197643, 0.17894220448309378, 0.1303791555185472, 0.1668687507269844, 0.19298015282519404, 0.16123720775208167, 0.059014338354069384, 0.15878287654730583, 0.12158687932476883, 0.10335058529650974, 0.19901714017314298, 0.13348887494254497, 0.15732429110475127, 0.18237283813857263, 0.1449669864509375, 0.1969618948116418, 0.18124895651013623, 0.20199984221929507, 0.2578463189063534, 0.22549229613955946, 0.11120822656178668, 0.1581217120251348, 0.12284045963878594, 0.10384622886176072, 0.17733043209920007, 0.11243350758788087, 0.12421577898485046, 0.20965618622158805, 6.817649083752786, 33.23554077456075, 60.84007201656219, 60.10792240019768, 43.33234133258943, 42.07218970021894, 39.90409566510109, 26.504824161529545, 19.635881262440837, 0.8540875248370633, 1.2994822186808432, 1.948083021467732, 0.4122913911217644, 0.411191963019871, 0.13654646974417473, 0.2337937014958551, 0.4804267608109982, 1.432643008808936, 0.8377857253916803, 1.4936592766354162, 0.9054915955470455, 2.6113895254750408, 6.012092309613382, 8.838555197561941, 12.824707031250002, 17.024259336533085, 26.071694474066458, 31.25599507362612, 42.81571419008317, 47.76846355007541, 54.292498711616766, 59.99070628996819, 58.077429033094845, 60.34450015714092, 60.93787631680889, 58.6414501743932, 58.70464740260955, 57.74478850826141, 56.463824779756614, 53.61771768139255, 56.483487621430434, 57.976682955218905, 58.78240054653537, 60.192527924814534, 57.27684582433393, 53.598058762088904, 51.04946736366519, 48.790590070909076, 51.64999008178712, 56.93679201987482, 58.83235585304999, 58.407625921310924, 53.3982140018094, 47.25224825643724, 53.872663897852746, 62.024902374513694, 56.563374534729995, 56.24219517554007, 49.38593133803337, 46.292354060757546, 43.502768316576564, 43.474864575170706, 44.737185278246486, 44.12579759474724, 54.30441487220026, 57.15096912076397, 58.64887129875922, 58.252072565017215, 55.39216656838694, 53.93132294377973, 54.15906752309492, 55.48260073507986, 55.34232108823715, 56.62043325362667, 55.71482073876166, 58.00473574669131, 57.50711248766992, 55.43040967756703, 57.77694802130423, 57.013839137169626, 51.133727719706876, 39.95503156415878, 31.864474319642593, 19.96435623015127, 8.950937967146597, 1.1622492728694793, 1.7304544799750852, 10.766016725570926, 5.405300663363549, 6.375088057210369, 0.6192170407983565, 0.3658337969212763, 0.365978924617652, 0.9803930537835245, 1.2951198076048207, 0.5870805103932658, 1.1057713099064366, 0.42446517175243753, 3.1457774052696847, 13.559474829704532, 34.09763459236392, 42.64704442793324, 41.416945995823035, 50.38999534422352, 43.181518354723536, 24.03809262860206, 3.643075352714908, 0.45449802471745404, 0.14964655792761236, 0.1381805199649065, 0.3485955622407698, 0.13859793063132994, 0.20242866759579028, 0.136020734245258, 0.18347526930512922, 0.11357756797224285, 0.14915221671183265, 0.2468393055061179, 0.1977796017402603, 0.1899816387242848, 0.16566461372760036, 0.10975476624744554, 0.09218663112410615, 0.2027164561854255, 0.12844246226332842, 0.21028034869701634, 0.11078428882624834, 0.1468242746928046, 0.11016362737263403, 0.1479872574488963, 0.12181108261668876, 0.16970565091938744, 0.06836085234798732, 0.15785188053644475, 0.10169532976203388, 0.18927988686388542, 0.18460785369238547, 0.1423180842351529, 0.11381864052025542], [0.035358562149227626, 0.032134975246604414, 0.015020958850190285, 0.00425938134750111, 0.019181899335836212, 0.060767729751645565, 0.047184730384258494, 0.12480422644124878, 0.008683955191724725, 0.06323722949732216, 0.050555850499339645, 0.03811511504013212, 0.013099118124603504, 0.0414853464932211, 0.13252489118566438, 0.0617473800065777, 0.06714870972979455, 0.036362056890803005, 0.015501937577350727, 0.01645461291885905, 0.028759134114689888, 0.056412818676401535, 0.02004386699428001, 0.049282688977977926, 0.05021170465155475, 0.06741094928715499, 0.02232349759358312, 0.07719106521577605, 0.0577683154974253, 0.07094292105325768, 0.014520205478484352, 0.07055463704971537, 0.013661874822461078, 0.03528022965896995, 0.03631210795813992, 0.038731283388070525, 0.06995039286031839, 0.41043868408568446, 12.230105130903183, 32.75836483124764, 45.75131408629879, 38.135051804204146, 17.880477443818126, 25.7695484161377, 27.404651180390392, 9.839379325989755, 5.132772422605946, 0.16761159554364222, 0.21377701913156819, 0.021192255775414167, 0.07935207667610339, 0.021446288615885763, 0.03545965511171568, 0.060459547901466015, 0.8162030060925792, 0.574836157743008, 0.09018392407245214, 0.9054617487615155, 1.9831040261253237, 0.9179022812074231, 2.596495060190078, 3.544776098382089, 8.403169166657234, 14.648571898860318, 20.18349316812331, 24.308190961037916, 32.09849665241857, 39.121876993486964, 51.08168963463076, 53.03026430068478, 57.33225322538807, 55.4767446364126, 53.75026633662563, 52.325998813875266, 54.144880310181655, 53.04140775434433, 54.54327544858379, 56.17645625145205, 57.61283213092435, 56.638448699828125, 57.38484828702865, 55.61259200496059, 51.45835484227827, 49.172189620233354, 46.20939200924289, 47.57371394864975, 53.4738726000632, 53.901383492254446, 56.82205484759424, 53.48133294813095, 38.235923397925596, 54.09527409461237, 55.54188736023442, 55.099863698405606, 51.479398358252745, 46.25624864332138, 40.4111796809781, 41.67841903624996, 39.877501995332786, 40.31166522733627, 40.15673552789996, 43.8972959979888, 50.6799251802506, 51.56061495504072, 52.08088990180723, 53.89333871103103, 56.37706587391516, 55.75714311292095, 55.11188968535393, 54.69319235893988, 54.98875079616424, 55.61991899244247, 54.72974884894587, 54.124699715645086, 54.79916303388534, 49.9562753400495, 47.626293320809644, 38.650412021144746, 27.3850687473051, 16.195812590660587, 7.727877738014345, 0.6061163244228209, 0.28359591299968384, 2.872638745654014, 4.846192781002292, 2.911161323708873, 0.5339314139658405, 0.1195945144600926, 0.05535270620678222, 0.20773941891327982, 0.4182642415886925, 0.3508707514453319, 0.1868505454471996, 0.31328552793110576, 0.8925571508945958, 5.7014405919659525, 15.566457509994509, 14.698718420920835, 16.074731965218824, 27.173097979637888, 30.31285332095239, 22.109178843036776, 8.327564500993299, 0.7556733573156019, 0.06829473896012192, 0.029985506816076177, 0.07060151396980209, 0.07656641244407623, 0.01529905451236353, 0.0106256251456216, 0.062412746521013404, 0.04006294721376993, 0.03117957550491537, 0.09224259384697484, 0.03335496260514183, 0.0720071320932719, 0.015117110545566727, 0.14752067925949253, 0.010261877980684082, 0.02644596610128159, 0.010546329299799137, 0.07645773521113781, 0.08493688828762501, 0.01722804571111356, 0.08096075406478298, 0.017331739542104544, 0.01815108781410081, 0.07465579682179997, 0.07353836565368599, 0.10679870873929993, 0.0237495836711699, 0.01589459115489116, 0.057111628759171695, 0.03586953896428308, 0.05926116422239331, 0.04581088575744822, 0.007183166444226499, 0.07595859062407287, 0.026792714732789227, 0.08235005451546562, 0.02152360603964377, 0.04217741883269722, 0.06544650832731878, 0.02882232104668454, 0.03636894019080266, 0.036125780053196416, 0.0282493504815765, 0.03181998478999782, 0.013330503490813559, 0.06051048508755142, 0.0825338007041043, 0.014985395133525375, 0.04156106662365698, 0.016894220982888536, 0.02104044779233875, 0.05152747215282533, 0.014997099041788569, 0.07631168820925298, 0.039780440800372636, 0.06968852868604083, 0.006519618431001061, 0.02984976369677292, 0.025226258364836537, 0.0759438127880135, 0.026102783609061472, 0.09378645253638107, 0.0526149224700226, 0.03290071077043972, 0.013930001765519623, 0.03360674123189623, 0.05162527859811822, 0.09229153920445712, 0.07995966100885023, 0.6634527961573293, 15.449240419172472, 39.29719517307897, 51.3422683746584, 43.652116483257664, 23.256346602593702, 28.141274259936427, 31.02752681701414, 12.494772941835466, 4.7101041866887, 0.21349362788661835, 0.017661279923613035, 0.024020054843276743, 0.11951258901747004, 0.07007131983916606, 0.053272068861030766, 0.0029837805543079855, 1.017420902367561, 1.5081298807936332, 2.120259995422056, 2.5835634960282237, 3.7326693967465436, 4.454844180614718, 4.912686271052207, 5.699378405847858, 9.316214572998787, 16.180277063000588, 22.13515473950294, 29.979634246518536, 35.77424387778006, 44.07816433137463, 53.65716103584536, 54.78113974294355, 58.67143277199038, 57.79352395765243, 56.37351612890921, 55.20905071689237, 53.919143984394694, 54.57547026295816, 55.842584102384514, 56.49011250465148, 58.39408589947609, 58.38463690973098, 58.189534294989805, 56.91980031228835, 53.076089351407944, 50.29116338299167, 48.17937497169741, 50.157190907386045, 55.73674678802491, 56.65274181673604, 57.718885175643436, 54.64439807399627, 42.07536682005852, 55.51244997209119, 57.318575920597205, 56.633761467472205, 53.80970201184673, 47.32789116521036, 42.17292401098436, 41.828061380693995, 42.09141323643346, 43.40901582471786, 41.67938786168253, 45.982592721139234, 51.90435970983198, 53.84849817522111, 54.11730604787027, 55.35950106959189, 57.23122473685973, 56.17148660844373, 54.96195316314698, 55.09939301398493, 54.11734527157199, 55.581295413355676, 54.92621252613684, 55.70455197365054, 54.269748964617335, 51.652720051427046, 49.57336964145784, 40.97804846302156, 32.04046126334898, 20.04947166289053, 9.03932563720211, 2.711692620669642, 3.189379452697693, 5.626654230779217, 6.124990870875697, 5.008834350493647, 0.8273945700737738, 0.3343277262343515, 0.12312310011756998, 0.31222590575775794, 1.1025946803631321, 0.340661128321963, 0.35244052688921657, 0.24136983609247595, 1.0337856435968031, 6.785240990500297, 20.731271774538104, 25.291572309309437, 22.527650633165916, 29.837371841553722, 39.31754835190312, 26.61536047535558, 11.350126285706798, 1.0745394374093702, 0.016738486799201178, 0.028544428397811232, 0.034299794163915424, 0.02894917371562652, 0.015547480546839297, 0.038321920475291635, 0.04766732747215898, 0.03604811405943286, 0.03363697872226758, 0.08441948016444523, 0.061436252548329295, 0.07770658876266211, 0.06348853698000312, 0.0447718024013504, 0.023477365818595695, 0.01946968026459217, 0.022253819981650002, 0.03730469360767353, 0.03427864630676566, 0.0862486836230082, 0.06387672905299453, 0.023279473816435185, 0.0874835407481559, 0.04453803450169583, 0.0633696248123963, 0.029426616947016412, 0.042967385717577515, 0.014312028745940376, 0.04357735258376887, 0.060160654867368366, 0.022563526346798868, 0.03788776695728302, 0.11620226180962018, 0.1596487244410861, 0.1518980750153142, 0.1982120890170336, 0.07781333545403135, 0.17580242376894722, 0.1558225902338182, 0.16966567645149846, 0.132525289551385, 0.19381305893823025, 0.12226565620831906, 0.1796602127292464, 0.08502403078901191, 0.1315476541076937, 0.18306774117292898, 0.1470101429449935, 0.09072704210637078, 0.1251183990989962, 0.1220736439309774, 0.12516354466037405, 0.09965051851806142, 0.13496057581036322, 0.13117616275145164, 0.15768533302170618, 0.0892298841368287, 0.1298848909115599, 0.20378458193473278, 0.17681343000262015, 0.16940535977482798, 0.12786517670798686, 0.14766497958091, 0.1429572313903801, 0.16103751927373872, 0.10677109893050887, 0.18010530981325334, 0.23916822197216175, 0.1776476844304031, 1.3432779331361095, 18.600514781090524, 46.945969981531945, 57.1683059969256, 51.50866708447857, 27.80356211047019, 37.413778920327466, 39.01575334610478, 19.90284954347918, 8.510195939771592, 0.31597697867020486, 0.24516449940781443, 0.12453093223514096, 0.2486282433833807, 0.195134621894648, 0.3688762997907977, 0.14590919798901006, 1.5369898225030594, 1.2683481602899491, 3.090913742780686, 3.276665672179192, 2.7250286792555167, 2.255680561065674, 4.311680120806541, 4.076940729733437, 9.417058710129032, 16.830237334774388, 20.773084240574992, 30.87502898708467, 37.02765295582433, 47.38340839262932, 54.995979724391816, 55.202519970555464, 59.18068978094286, 59.761388840213904, 57.569701748509566, 57.42436224414457, 56.95027712852725, 56.78356070672312, 59.23859180942659, 59.240074465351725, 60.380644798278816, 60.954358116272964, 59.77471705405944, 60.83658895184917, 55.63264708365164, 52.442724627833215, 48.832167194735625, 52.03818313537106, 58.44261346324798, 58.29374774809807, 60.41234931638164, 54.880791479541415, 45.39103654123122, 56.537349608636674, 58.555934659896366, 59.70410262384723, 56.320179739306056, 50.120571659457305, 44.192113107250584, 44.449353910261586, 43.68362096048171, 44.78510879701184, 42.909854996588926, 47.664658023465066, 53.800527588013686, 55.85733221423242, 55.881019407703036, 57.34749947824786, 58.27909769550447, 57.684442843160326, 55.28129293072609, 56.445817178295506, 55.77253841584729, 55.14838341743716, 55.89317483286704, 57.44701000951952, 57.02126418390582, 52.28885004597326, 51.612998208692, 41.41887187957764, 32.103629073789044, 18.86506884328781, 8.815513233984671, 1.5761024721207157, 2.2895995022789126, 6.575143154590361, 8.110908462155251, 5.10849000946168, 1.6387345113100547, 0.40490743734182855, 0.22632561594007478, 0.42451876726362014, 1.9869115443960315, 1.3423635305896884, 0.6971765381674613, 0.6500598632039563, 1.6150571237648688, 7.2427021207347995, 20.93325814893169, 23.72195743745373, 25.946164900256743, 38.2113693606469, 48.625203332593365, 34.830964842150294, 13.726928657101048, 1.5740053523932735, 0.1467154595640398, 0.092989046937756, 0.2030030496778988, 0.1487168029791886, 0.16638605404765378, 0.12501359827095462, 0.1795157438684856, 0.10379741373922556, 0.1763217088075415, 0.18903156712410912, 0.20122578698060206, 0.24000429968920448, 0.1160960283971602, 0.21483317858749823, 0.11540321678283716, 0.10213341714153368, 0.09749816385127845, 0.1895474507323196, 0.19880036793408856, 0.09342633758581455, 0.22337093739019287, 0.18016198499789163, 0.1348902336171558, 0.16245554802158188, 0.12621353710851363, 0.20397832557078333, 0.08998397512421494, 0.13994264476481946, 0.09401575031299746, 0.16574491506382344, 0.12359976768493654, 0.1982701125164186], [0.010884122363471938, 0.05828829001515143, 0.04446218796675244, 0.028052023469260143, 0.06498458029161538, 0.011670354569721366, 0.030805602023798614, 0.055795769327350205, 0.008436624662980678, 0.026561662614826235, 0.0256024879748903, 0.0357106676505458, 0.09313320170246786, 0.03781878840058081, 0.03881854080264607, 0.005943826268306904, 0.03991345664666545, 0.04427450791662259, 0.014950423219781971, 0.08659709275009171, 0.06358818203631429, 0.051082398051456104, 0.06160462718276728, 0.041424794903685974, 0.03937659755108818, 0.03949465553065942, 0.00921053338735815, 0.006280012941363478, 0.05032929148705256, 0.10215249273084825, 0.013034393271100859, 0.03233935601348358, 0.020150244048225786, 0.07582967334817495, 0.05696523318728132, 0.01169770007817856, 0.046483457328811775, 0.01969670276007345, 3.4497081416268505, 21.509732815527148, 40.023645585583104, 36.84137567397087, 24.917750820036858, 29.420145403954294, 21.93721821231227, 16.302981549693694, 5.6197268347586355, 1.683577621175397, 0.12102877661105126, 0.158436666092565, 0.09139796658869713, 0.012796276864866096, 0.08887200616300107, 0.07654172909115592, 0.5031339439653582, 1.1795113788497065, 1.4593552077008833, 2.8367909789085393, 4.69022806613676, 3.8397432383029693, 1.0878785603469419, 1.4749032379158082, 1.926933601498604, 7.350870303569302, 12.40170882594201, 14.16357376883107, 21.729754247973045, 33.14383968230217, 38.96838680390389, 47.83788557975523, 53.61042599524222, 56.44081615632581, 52.58492231369019, 56.516345316363925, 52.77791861564883, 55.835363018897276, 55.671847251153764, 58.9588640582177, 55.8213052441997, 57.9693442006265, 57.81110402076476, 54.97746221480831, 51.24724503486387, 50.40618688829484, 46.61696549384825, 47.1127805402202, 51.687060402285674, 54.55887079238892, 55.15745193727555, 57.865597509568744, 39.75466120627619, 50.19823458886916, 56.8046042226976, 54.01979200301632, 51.86814838840116, 48.579221387063306, 43.235953007974935, 43.32296294550742, 42.725993894761615, 43.43093402924077, 40.74359270834154, 43.31554574351157, 45.61433707514117, 50.360518732378566, 51.01787267192718, 52.75374897064702, 53.84050438480993, 55.91129618306314, 55.58224854930755, 55.3623055642651, 54.49420267535795, 52.974264621734626, 54.05943932071809, 53.58738991522021, 48.79721103175994, 43.33684421354725, 33.36128019517468, 24.235468256858088, 16.21263465573711, 6.3532301591288665, 1.8635009084978413, 2.204280596586966, 2.750334095570349, 6.318165150380904, 6.24192702193414, 4.90256900748899, 0.6353563683167581, 0.1017468415140625, 0.17037205548296053, 0.17055040075173303, 0.8066596956022325, 0.1374115515500307, 0.08529183214470264, 0.3643010694894099, 1.9040588289499285, 5.800364238600578, 15.176512137536081, 18.267105471703317, 24.342799994253344, 33.735211510812086, 28.387781496970888, 14.36139850847183, 2.994864703186097, 0.4910881613050738, 0.040683336706171115, 0.05677764123726276, 0.0197629502133256, 0.038540952673722664, 0.029386420313629414, 0.1364688650374451, 0.018366534721046206, 0.028540073187961697, 0.08295682679501273, 0.048430577040679997, 0.02772948513137958, 0.03225821964142304, 0.09223333184397028, 0.05226570512017897, 0.039115353908029296, 0.07967767936568107, 0.05557433161283693, 0.03960431335614093, 0.023585972188401128, 0.03876946137977704, 0.059213268405367295, 0.048320022892327084, 0.09276432270604758, 0.023654079320089474, 0.042684297077357776, 0.04393148438764676, 0.06785515770916978, 0.04137791415315963, 0.025718423890911286, 0.0031435515425513472, 0.06192665224173858, 0.05034688086579404, 0.03592183212599447, 0.03513312545574961, 0.05610476323072949, 0.04761474702747599, 0.03168002627189121, 0.07163612337242212, 0.006631514190831372, 0.01958343666046858, 0.036641376378435286, 0.06674470560204598, 0.019953474364874345, 0.02781784571256609, 0.025266849533504537, 0.03248678197363212, 0.02723338382859384, 0.04280502487334513, 0.032660523053979686, 0.019725243365692518, 0.051668424670013695, 0.02777076003352, 0.03701369894007522, 0.04389340215693078, 0.02602880632865333, 0.05825284695733459, 0.052615876249488325, 0.012593458917352461, 0.037788485792735894, 0.07609707633814505, 0.04592814317513858, 0.03508636727929115, 0.027994197237515644, 0.02382839113594063, 0.02658670028341153, 0.08799299687868165, 0.037008474220431624, 0.026446753256623785, 0.05830790569645263, 0.04696860548950011, 4.5061835935038905, 25.856128854136315, 46.450915874973425, 41.207542419433594, 24.653098698585268, 27.5516184683769, 27.11410749343134, 25.95457446190619, 8.207440933873578, 1.6634722871165124, 0.24262675654984292, 0.10362752608113712, 0.13068307791986775, 0.07913716603070498, 0.12215425936324943, 0.13017939043141183, 1.5012152324761114, 2.3506470264927035, 6.6740820004094035, 5.595162991554507, 4.768505336776857, 6.64401654274233, 3.0317499368421497, 3.863223771895132, 4.4300092035724274, 8.710107380344022, 16.570027297542943, 19.5608933894865, 26.278925057380434, 36.38297219430247, 44.65907519863498, 50.66003876347696, 55.88894651782129, 57.919224154564645, 54.54406384498843, 57.00244857418922, 54.10511139900454, 56.26167366581579, 57.4855080727608, 60.466132856184444, 57.30993886147776, 60.40506547497165, 58.53151006083335, 56.69644094282582, 52.3639516676626, 51.122474439682506, 48.30445935649257, 49.10978471079181, 55.418348389287154, 55.676922798156745, 56.38553034874701, 58.3651662641956, 42.66594632979363, 52.67540747119535, 58.251750930663086, 56.254554563953036, 54.97844280735139, 49.81248909427274, 44.79488726585142, 44.89165606037263, 43.99513167719687, 43.82383392703149, 42.552366256713874, 44.08913127837643, 48.154307103926136, 51.01487205874536, 53.35296553950156, 54.675141611406886, 54.770576800069506, 57.339364482510476, 57.95411755961757, 57.323357289837254, 54.88982469804826, 54.749882375040364, 53.545593138664, 54.6830177307129, 50.226820822685, 44.474292339817175, 37.04497414250528, 28.12808332904693, 19.61500836956886, 12.553113295185952, 5.680321080069389, 2.2633201124206668, 6.7160494000680995, 9.942523933226063, 5.895179202479701, 7.562995514562053, 1.4326383509943563, 0.44651882062035225, 0.5030240256699824, 0.50150076708486, 1.4201974508262452, 0.4331861328213446, 0.16905637608180124, 0.2320864439130791, 2.3884625973240023, 8.90672795234188, 17.739130912288545, 17.075269760624057, 25.359880385860322, 39.864989634483095, 35.36136342633155, 18.61493733621413, 3.7543615746882657, 0.476115984061072, 0.036201975158145355, 0.04138447186579147, 0.023832074103636608, 0.014389446718738446, 0.026804728906661756, 0.08421459760997566, 0.017686091596260667, 0.1363670979175837, 0.035276165562531644, 0.010300952295262006, 0.05615051400156752, 0.03421899104010194, 0.02535562380217016, 0.023198295309538805, 0.020823449557346684, 0.020359964447937185, 0.04149258219366593, 0.024778878338815227, 0.020450638614655025, 0.05567599531082858, 0.033678535161720174, 0.042852794285863645, 0.03675909727931984, 0.03890444607203526, 0.07906956643226647, 0.02851140043217569, 0.05724910706762345, 0.02683071269383354, 0.070796720833788, 0.05201389584990759, 0.0019982296268403112, 0.02709790309440465, 0.06303539980323085, 0.1922187073937347, 0.13776454954378067, 0.14118314029708987, 0.18613374761996732, 0.17384244910170957, 0.220447653123448, 0.14836360580257832, 0.10495926268518933, 0.15811861702992072, 0.1010209272405313, 0.186801684359389, 0.14743653216188954, 0.15235103216142426, 0.1150235359466845, 0.13752111744496132, 0.17286427739647128, 0.14933040876302028, 0.11614587007751388, 0.18765510630703744, 0.17124496670740266, 0.2093981831304489, 0.18328488113418703, 0.1487753474183621, 0.1385609285845872, 0.1982237948405166, 0.18130045294040636, 0.22979962549382643, 0.0945939475129689, 0.22571410923715562, 0.08784444476928442, 0.12231722158650238, 0.1298633944844046, 0.2638718149354381, 0.15424748281798056, 0.09274402137605414, 0.13584621941610692, 0.23061716388310158, 5.450694743664035, 30.922477899059174, 53.8641837335402, 47.99327027413153, 33.999512580133256, 40.82467202217349, 33.10686742105792, 21.415850885452766, 11.244403700674734, 3.1315382209516343, 0.3513132744739133, 0.5273461221687256, 0.2815446666171474, 0.24402570970837148, 0.2895744325172517, 0.2767466579473788, 1.5716644328448082, 2.068490102406471, 5.983117270854212, 8.985444038145005, 8.173368284779212, 8.402000300345883, 3.2444453623987015, 3.404527585352621, 2.679572576476682, 9.22078428729888, 14.554423247614215, 18.709401738259103, 26.31820563347109, 37.545245001392985, 47.098632551008656, 52.889227636398815, 56.716821578241166, 60.95137319257183, 55.370852408870576, 60.19900375796903, 57.50459040364912, 58.57301265962663, 59.57972426568309, 61.53790089391894, 58.01367090594385, 62.26775200136247, 60.14149396650253, 58.392081568318034, 54.68014263337659, 52.89895903679633, 51.190849196526315, 52.08964070966167, 56.41245741997996, 58.07797424254879, 57.92991261328421, 59.048101902008064, 47.45931802257415, 54.78958460592455, 59.63250367872177, 58.347174352215184, 57.974333455485684, 52.62472260382868, 47.275806011692175, 46.92947641495736, 45.728179947022475, 46.77145196545509, 44.83418549260786, 47.0672300554091, 50.16243511630643, 53.986122377457164, 54.86511376596267, 57.03654573809717, 58.199912886465754, 60.263373774866906, 59.51880985690702, 59.43007015412854, 56.78580430246169, 55.92444004551057, 55.12906966670867, 54.603013146308164, 51.41246311126217, 46.33529616940407, 36.14640228209957, 27.650660276412967, 18.87252526898538, 8.802378196870128, 4.0753379512217744, 3.740307967508993, 7.401462504940649, 12.205116691127902, 12.219277428042504, 12.555352968554343, 2.6428989056617986, 0.4072178972344245, 0.8830684471514918, 0.5353945193271483, 2.2285164315854353, 0.982801940652632, 0.3657387407316316, 1.0452653179245612, 2.6657182747317902, 9.497808544866501, 22.877951629700203, 27.54962198195919, 36.212968826293945, 50.60015986042638, 43.68095374876454, 22.59809051790545, 4.9566070110567155, 0.6738636246131313, 0.1565011143083534, 0.16653767816962736, 0.141845791029834, 0.11092427607265212, 0.11239970778866161, 0.2801429402203329, 0.14176386558721144, 0.31533763233211737, 0.15731100714014423, 0.16194015470964296, 0.22936438030052572, 0.2056841275865032, 0.11160334406961357, 0.13758669457127973, 0.1367592276825059, 0.1663157424979633, 0.12321457101572907, 0.11978311764617121, 0.10525757732290415, 0.15676789676710484, 0.3098401241004467, 0.16233300459721398, 0.18739615326687215, 0.09375434579147447, 0.18398085669163736, 0.1103646794874822, 0.2238255492862194, 0.11719750195381143, 0.21957460400317946, 0.11598501459605272, 0.11068955439353183, 0.15799999597572512], [0.037036559003735744, 0.019719633686866973, 0.058470358471235925, 0.03129372643607278, 0.06235084278629192, 0.07924552916759446, 0.04376826552493919, 0.020066983697395173, 0.04494921304285527, 0.03342660331738091, 0.07087424127084595, 0.036086081376960205, 0.0702412074972545, 0.06232399906542513, 0.009976444153806135, 0.04021853584075167, 0.01798712201566706, 0.050288608387833646, 0.03607576600305977, 0.024219128536060456, 0.019082807778050343, 0.03296156879514456, 0.032265053145707615, 0.04872647850143333, 0.0180121137189769, 0.04522510428702639, 0.0639601253844317, 0.03363165058075421, 0.08452504708041107, 0.03505082846048378, 0.07362556944210684, 0.062082003381463795, 0.004345174097726423, 0.025772203263195775, 0.022193383305303516, 0.04351449506958166, 0.09082245835733992, 0.010188937791803432, 0.6155112590039931, 12.105792472439429, 32.85727523988293, 47.18282230438725, 41.06755695035381, 25.511715335230676, 23.572346471971084, 22.640257958442938, 16.53339236013351, 4.875020730879999, 0.993829132808793, 0.07921377482313303, 0.03941714275448073, 0.029002832429062937, 0.05066545469866646, 0.1090539183707968, 0.9162600338459016, 2.8373643803981046, 5.684171376689788, 2.9931033138305914, 6.887027967360712, 9.960396212916221, 0.9573609574187187, 3.2191252371957226, 1.7090828332208818, 2.6751351500711134, 7.445898056030274, 9.17422281157586, 14.208938921651534, 21.73226652606841, 25.32561848240514, 37.29707271822038, 43.39664859156455, 53.35996697025915, 56.68174382179015, 58.05722098196707, 54.96243953704835, 59.675524234771736, 56.788848061715406, 55.596161196308756, 58.06714065613286, 57.7650083264997, 57.16809811130647, 54.25325539804275, 53.11157503435689, 49.49164313654746, 47.806608600001184, 48.664011263078265, 49.1994579376713, 53.73363548709501, 52.69097535840927, 57.38788420154203, 39.61951986435921, 54.187151693528705, 57.35831737518311, 54.35410345754316, 52.644428591574396, 47.341858725393976, 43.9976498388475, 43.093967130107266, 42.29651789511404, 45.34563902885684, 45.6041036113616, 46.13504348262664, 46.37964248657227, 47.63874684610675, 49.71874052478422, 51.99648834043934, 51.51313858647501, 53.91339378972208, 53.034563218393636, 55.45716416451239, 55.435602895675174, 56.00616655042095, 51.77544709174864, 47.64572082027313, 39.37741548784318, 28.724211031390777, 19.846053623384048, 11.554302323249079, 5.8320942521095285, 5.955174305746633, 2.0871147417253066, 2.2453218265887234, 9.256968152138496, 9.191585183143616, 5.870246166183103, 8.022840465268782, 0.4484808330814685, 0.9490809565590275, 0.5393039579353025, 0.3409426503123776, 1.1914885813190093, 0.164541712691707, 0.18916356407346266, 1.036141884903754, 5.186865339356085, 10.567924284165906, 21.552506262256255, 30.31759350530563, 31.31623091236238, 27.323477729674313, 21.582784998801447, 7.78141858116273, 1.0839169664729027, 0.0856074067433515, 0.028038662895860694, 0.04197406079319697, 0.02156558191223491, 0.11265894428135888, 0.023435102663032954, 0.012882729887121148, 0.030327800646304127, 0.019321095596458164, 0.0635178130300295, 0.023046341769757773, 0.07262518884794367, 0.018864744680843527, 0.015049521480837177, 0.042772983245912104, 0.0188615002984842, 0.024755164087119124, 0.021275391636957085, 0.06243202895406754, 0.040740697539501616, 0.02045456864570658, 0.02720172332990314, 0.06984506343160907, 0.05939768875137933, 0.06352168177404711, 0.0692886078069287, 0.03757482004021445, 0.07988297560762975, 0.026663368447653713, 0.04729627661647336, 0.0449930485938826, 0.010824376123867208, 0.0761662770603453, 0.028569674825355895, 0.010078076250670899, 0.018010564306150043, 0.0193400198834077, 0.05434953322213504, 0.03304454377822338, 0.036774189211428165, 0.032260598344427925, 0.04629064448958924, 0.03429934600247972, 0.04012361371649369, 0.10448558286072747, 0.12237792639362237, 0.019309797714794838, 0.03734511623699819, 0.05910998060097618, 0.02537078276697186, 0.0195933555838682, 0.10355284783027827, 0.014885212858057311, 0.04132571292199916, 0.07085918764313383, 0.1004720712080598, 0.06540944499354209, 0.017000726356561628, 0.02031905918322023, 0.013745985530887642, 0.021388816699806242, 0.12585253349595493, 0.03732823548958667, 0.01744513204621692, 0.06691607180982828, 0.041534008398171396, 0.017606870444010825, 0.03603641206638948, 0.05837498818554225, 0.0408828528147311, 0.08080143842004961, 0.7757914390775466, 14.648485606716527, 37.19667965365995, 50.43023493982131, 42.84004857463222, 29.103672888971147, 24.2216811257024, 22.191701589092133, 18.69555381036574, 5.395959048501907, 0.7155438332307724, 0.06406239812232314, 0.03282028302970914, 0.09230427158575866, 0.08572677856371289, 0.30798472043487335, 2.817767483572806, 3.923427986521875, 4.254907244636167, 5.4288201755092995, 7.408295764077095, 10.007852969631072, 3.6038668501761655, 3.702652723558488, 4.37752494888921, 5.167044622282829, 11.813878897697697, 12.620816346137756, 18.366011957968436, 23.86770682950174, 30.957228137600808, 41.31254034657633, 46.21733088647166, 57.167764709841826, 58.16367018607355, 58.85521542641425, 57.58392034038421, 60.77613738275344, 58.037691500879106, 58.09818621604674, 56.623245593040224, 58.917875289917, 58.809684553454005, 57.14113573874197, 54.268893887919766, 50.82868499140586, 49.55569936383156, 50.93380058965376, 53.366842885171216, 56.45609378814698, 54.428149961656146, 56.781932923101614, 42.35156443811233, 54.78118288901545, 59.5786730704769, 56.95296787446546, 55.089504718780525, 49.30447939903506, 46.88991931176955, 43.924513324614495, 45.047503594429266, 46.03759611806562, 45.962910267614554, 47.08815197790823, 47.719320174186464, 50.275356231197236, 51.37283148304109, 52.67670185335221, 54.01050775281845, 55.325321535910334, 55.54298954625284, 56.61507529597129, 57.571200093915394, 55.63309031148111, 52.05984246346259, 48.892481480875325, 41.494569701533166, 31.906371116638187, 23.96182017941629, 15.33567701616595, 9.537314657242069, 2.8345108560977446, 3.0368556370658264, 4.634409796807074, 7.937878985558787, 10.859508379813164, 8.797680177996236, 7.111444905880959, 2.0391186591117614, 1.429990873702111, 0.8272525067290952, 0.8540199252386248, 0.5158745990164819, 0.11511968764206094, 0.14148721591599528, 1.197030645224356, 7.388342176714252, 12.526822628513461, 28.033538518413422, 33.91022374553065, 34.36444597859537, 36.56655480784755, 27.27265557935161, 10.299048750631272, 1.286873269465662, 0.05638298338219043, 0.07277227772940552, 0.003433039410963595, 0.03190031485451806, 0.05192669972236599, 0.05417000817795915, 0.05162053651386692, 0.04470831286462565, 0.08791621188603102, 0.041552520912861636, 0.03558473428711295, 0.060126927846501914, 0.06748623274747403, 0.009356887782022599, 0.024546979693695906, 0.023223949678903146, 0.036485714973100734, 0.009016858699220804, 0.056504492587860555, 0.012122130982818143, 0.01694268562019833, 0.057106890505360025, 0.03599474837462749, 0.008028452059314137, 0.096747221485261, 0.04478759530390944, 0.01703037204401147, 0.046315431264379335, 0.051552373840804064, 0.005590007124063109, 0.03992520077454467, 0.04784974832868865, 0.052246150725911704, 0.133273788096924, 0.0882470392952523, 0.0923408446232638, 0.09691938442448456, 0.16128159488641447, 0.19357742561448008, 0.17725412974194174, 0.13045447728326245, 0.1469696168937991, 0.15890263141162936, 0.14329175134339642, 0.1755602174108067, 0.1838102642326586, 0.23888437107445734, 0.06127235186736911, 0.07120338328663381, 0.1497547908295547, 0.14587841657621248, 0.15640866281765123, 0.2180774996597921, 0.0985654392429898, 0.16360314773215404, 0.1803878583614865, 0.23040540185907196, 0.19368820192833103, 0.1052363413656431, 0.15323411703350084, 0.08026641027461137, 0.216869133855066, 0.15245961746381176, 0.2352788548676237, 0.18556413060474783, 0.15028902990443094, 0.17349982393845437, 0.10377584836415707, 0.1322110862501206, 0.17525171380369894, 0.19216480544738232, 1.297148776150519, 17.353401107172814, 44.03264914789508, 60.71239102271296, 51.36914053270894, 37.042883519203436, 32.605684611105154, 30.961309363765103, 22.96189231257285, 7.63192234500762, 1.9087905556924882, 0.19386728264151082, 0.3875070678130273, 0.1643880814193718, 0.22866875714352056, 0.3942110725948888, 4.461558788053451, 4.521741184496111, 13.347155951684522, 10.810896485082566, 14.268379499835355, 14.11905094500511, 6.094539550042922, 8.917725297712511, 4.215776208908328, 4.417966546550874, 10.012244063038981, 11.743994028337541, 18.329571177882535, 24.91362056424541, 32.653916035929036, 42.61887004298549, 46.195577421496, 57.84968445377966, 60.596135893175685, 59.72406356565414, 58.57789601049116, 61.25875757586572, 58.74041157384073, 58.861812853044086, 57.814304674825365, 60.08578454294513, 61.0160138530116, 59.797525636611454, 57.13347927216561, 53.281095950834214, 50.83419199912779, 52.0739237723812, 55.22980005510392, 58.02432798570203, 56.69527599888464, 57.86070631396387, 45.27811934871059, 56.73181287703976, 61.493750695259344, 59.60914204197546, 56.60790912566647, 52.07932487610848, 46.72471692485195, 45.735636372720045, 45.8867770625699, 47.99749858917729, 49.01546347525812, 48.97823625995267, 48.83347726637318, 51.54294467741444, 52.72528433030652, 55.30506249397032, 54.14827708275088, 57.74577694554483, 56.16479896729993, 58.87452917714273, 59.313524769198516, 59.898452143515314, 53.52415346330213, 50.280345486056426, 41.13399797870267, 31.865490213517223, 23.47918429682332, 14.12244281461162, 8.151807506238262, 7.680957855716829, 3.951815650347741, 4.768436695298841, 13.7656718684781, 17.241231126170007, 15.671702546458091, 17.166953202216856, 3.295473682303583, 2.0897243436305755, 1.2204619040412288, 1.1747786715146036, 3.922430723905564, 0.8160893799316499, 0.8243643552545579, 1.6638985997246158, 8.159225198530383, 18.532151791357226, 33.37262761208319, 43.37353798650926, 45.52819398141677, 43.739601027581, 33.18297709188154, 11.781632111918542, 1.5359640001289308, 0.14531820712070312, 0.1420471189363349, 0.15749276916105903, 0.08552097670373418, 0.18777532082411552, 0.11142797122198729, 0.1436347135853383, 0.12372381264163602, 0.2669022136157559, 0.3797729812081783, 0.11585112540952622, 0.28321890581038695, 0.20332220190715408, 0.1622801598521971, 0.15680970984601206, 0.1185212176172964, 0.17577374143706215, 0.10959815489308489, 0.12863154042392008, 0.07418116704831201, 0.10472483978035951, 0.10852180902035007, 0.1990552147429797, 0.08639477659016849, 0.1992946938281098, 0.11878683562240294, 0.11276997340422486, 0.17939002884011115, 0.1488597856293763, 0.11691438650051433, 0.08794700095970785, 0.13715676602817353, 0.13984063249682227], [0.06210668290394449, 0.026706062527673862, 0.06425460958252512, 0.015899858009370587, 0.004093259490365464, 0.0342123260751607, 0.020407563405892542, 0.05221264204010368, 0.04740188566727504, 0.01469798384219288, 0.06639389861975947, 0.032051126923291914, 0.07419173140078783, 0.029671542917288123, 0.036485737955738465, 0.037541859107272285, 0.05654290423638398, 0.05466184428622646, 0.043476673308759935, 0.11956457574401172, 0.0477720478609685, 0.03370374328486862, 0.015017988344263888, 0.03930514069995092, 0.08200977358125872, 0.05995568038234788, 0.03280748553093403, 0.05179815016867173, 0.03005988629264457, 0.023441392244891297, 0.06592116108344448, 0.027819500462482535, 0.03464144256506716, 0.04794227259774362, 0.05740055115893484, 0.06042827236195726, 0.08066226322684558, 0.03183537358117681, 0.06310403745080675, 2.3555843099471065, 21.08325350669123, 44.6934312389743, 42.25530947408369, 22.276844478422596, 23.861360434562933, 34.17190467157672, 18.989349142197643, 13.083051000871967, 3.4703388281406897, 0.4098677953645107, 0.05023530015962259, 0.07476268906987484, 0.12542815909029978, 0.5922393464753705, 3.074022055633607, 6.0208210541356, 4.549880758408578, 2.825906401680362, 4.076298686765855, 7.115700187221651, 3.222543092504625, 1.1144676948747327, 1.8564927361665235, 2.4727783568443793, 6.953165012021219, 6.946947074705555, 7.499167275044226, 14.137668475028008, 13.314047225060003, 22.864395918384677, 33.8415861898853, 43.61040599884526, 49.548721467295, 54.733388808465776, 56.73151869927683, 55.80810254619968, 56.23178520510274, 58.7583956410808, 58.787150536814046, 56.965899928923584, 55.21553831715738, 54.262065041449766, 50.77334427064466, 48.82454210712064, 48.43254435446955, 50.69330830727854, 51.755788172444994, 53.88212465470838, 54.38109328669887, 57.75127610852642, 38.89071210738152, 53.551241351712136, 58.005939914334206, 56.43501497084095, 54.75692695186984, 49.05646008829917, 46.060157591296786, 46.86917389592817, 45.5236126530555, 51.18474598853819, 51.64210219537058, 51.61321001668131, 51.15474770146032, 50.58703560982981, 49.644097820405044, 49.407021922449914, 50.08457606838596, 52.378119268725, 54.65496101687032, 53.62623314703665, 56.02028316067111, 53.05534001319639, 45.26008429065828, 35.96285104751587, 24.09151727153409, 15.185151157840608, 7.9427466469426315, 3.6761301467495584, 3.00474637939084, 1.636943091307917, 6.788220030646171, 3.9150613257961893, 6.938542416018825, 12.412864046712077, 4.6833614668538495, 4.963477532709799, 0.9718145850685336, 1.1207709437416447, 0.4939916345380968, 1.0826988253862628, 0.18848182242964545, 0.10841489378963748, 0.5964921150476702, 3.78559761470364, 10.88242482754492, 19.1458164107415, 18.421597826865412, 22.71380828272912, 34.800319363993985, 28.285984223888768, 12.82213983997222, 2.961132564852315, 0.3051794596737431, 0.08113421169259856, 0.0883516486013128, 0.04881247570137343, 0.011717005493870426, 0.02925836488664631, 0.049657252346796375, 0.056637201998983665, 0.03234084988493593, 0.03523664691695764, 0.02404998781369819, 0.10420128763202699, 0.006686330654643357, 0.021594794760007533, 0.034677222701570684, 0.10209882061087316, 0.02129077659769645, 0.03924611362538511, 0.03199311683044559, 0.019618435387289333, 0.017225753193000154, 0.0367307405348026, 0.045553943698084166, 0.05280178663651309, 0.05392457658965742, 0.010596412297848974, 0.019289138238696803, 0.05350878619919381, 0.04448385293325109, 0.0714881458289681, 0.05372816313719077, 0.036840149381708716, 0.05812599428839261, 0.0473610187069543, 0.041629298244633024, 0.02977828386299793, 0.04616076960378597, 0.05266038978832865, 0.001605402482504536, 0.09616823521472755, 0.011372742817677077, 0.0271832280521912, 0.06486754503942306, 0.021945287646245093, 0.014605776542016577, 0.04568164289418248, 0.028669342864304784, 0.01737922741731088, 0.019630120143354423, 0.0415175068642824, 0.013913656322045193, 0.03844680429826822, 0.023126872932358135, 0.027810701942672173, 0.10496064164345303, 0.03374284058208427, 0.02787914423782739, 0.06816153925272726, 0.06672540018635412, 0.0827947608946312, 0.046734132788955204, 0.025832982763888377, 0.10379166041891422, 0.05562169116831595, 0.0265466223936528, 0.06400884474597632, 0.023461440765869715, 0.055885815301970135, 0.08562456711285538, 0.07094343433216696, 0.046113965462052056, 0.07670230112008511, 0.02669379937522594, 3.133045146542211, 25.277851858446677, 51.681082710143066, 46.84444335199172, 27.145982634636667, 20.465499816402314, 27.14199358417142, 24.911526018573394, 15.325964247026752, 4.623252124555649, 0.5983701336287683, 0.12392478048681252, 0.09685159330406497, 0.14338452459102677, 0.7775330327210889, 1.7365654101294858, 3.677675315449315, 5.471376420990114, 7.3439129994761565, 9.132510365978364, 7.264393318083979, 5.561640945173079, 3.6252315102084993, 5.4434692475103565, 4.4287432585993125, 5.841599135629593, 6.933355571762209, 11.381995543356865, 16.674409412568618, 18.58297198049484, 25.688926058430827, 36.54762152702578, 46.376555581246656, 51.560532585267104, 58.05094518969136, 60.71553676359115, 58.52601482022194, 56.6369503544223, 58.530215678676484, 59.95869974936209, 57.849460878679835, 57.43013989540839, 55.826572987341116, 53.748293384428955, 52.80810517649497, 51.384963373984064, 51.840311327288234, 54.58826503446026, 55.68761910161665, 57.19590379345802, 57.36700934748496, 42.19097083614719, 54.39477451385991, 58.9548828524928, 57.234072377604825, 55.14895608348232, 51.17725426150907, 47.63272208552207, 47.26297593885853, 47.213730581345104, 52.426054554600874, 53.05544591719105, 53.06166679628434, 53.78004104860368, 52.109742856794796, 50.10280724494688, 51.38547328210647, 51.55674749805082, 54.37886538044099, 56.3222703626079, 54.77106317397087, 56.33741071147304, 53.96937385682137, 47.99489805775304, 38.52466867816064, 28.467374232507524, 18.885902512458063, 11.728708551776025, 7.425499769949145, 5.009538415939578, 2.5631858023904988, 3.6243357389203967, 7.599700074042044, 10.49846891433962, 8.368974924087524, 7.195725854366057, 8.41302216053009, 4.165102618355905, 2.2626795403419004, 1.2019537100868842, 0.8349429263222603, 0.1369819600856112, 0.10357642801658762, 0.3250469693974141, 4.281738217799894, 11.563060975843861, 21.015618116624896, 22.4268163019611, 27.381575876666655, 42.224310982611875, 35.71457678271879, 16.644764138806252, 4.01636928319931, 0.2068376568176093, 0.09141612287250259, 0.06767538751685812, 0.08737464901059867, 0.09245612553410953, 0.04325397921005084, 0.07819164499279954, 0.03337107343418944, 0.06267444215594761, 0.013059789085790757, 0.05922565221666329, 0.04039709178370334, 0.0213575066863409, 0.010101190080956347, 0.02404384953420489, 0.07430977022816097, 0.03354987835571651, 0.05707797451665806, 0.014443668506799207, 0.028429852287855842, 0.015735807941265164, 0.025195959587431243, 0.04482159811642863, 0.028533590168902473, 0.06556007320121413, 0.08421858892806115, 0.016823941991934856, 0.02901636537224535, 0.03719358404557552, 0.05306416025926029, 0.15281008736741158, 0.03177144928955503, 0.0789216501758464, 0.05755230551585556, 0.25160415789052365, 0.12513057989699225, 0.12244750249890551, 0.13503195988314767, 0.06715204221226516, 0.11153530014017898, 0.19058876340427708, 0.09966863649747065, 0.10478788115564855, 0.1766420561339586, 0.14679459644661796, 0.14789816142330248, 0.1451665063899371, 0.16957581433798039, 0.1548027893107745, 0.08919741733059769, 0.16770599289767205, 0.24683185913149389, 0.13848263439872574, 0.20355909161510008, 0.18511310400020692, 0.14845395821236795, 0.1595072280014715, 0.16894334746945291, 0.276781591556726, 0.28158367581425175, 0.17019940990834467, 0.24666656800095113, 0.14218668483438032, 0.17701233707128033, 0.1368328946973047, 0.13549853807255147, 0.1938232325858647, 0.08486294548117346, 0.202872967948356, 0.13308465631017763, 0.17502205596575815, 0.15375335610681964, 0.19031356930011706, 3.68720741041245, 30.22119341358062, 58.30649152878792, 55.96550333884455, 33.512307136289536, 34.341919806695756, 46.69066682938607, 27.57378182103557, 16.68392900497683, 5.17847833133513, 0.7447270640442449, 0.21616986411954128, 0.28517325739226035, 0.37382970173512736, 1.148872642267135, 7.871320776401028, 14.363451869257036, 14.462646649729821, 15.537160346584937, 13.172772276786066, 17.64660219992361, 4.62179349314782, 3.56665262772191, 4.593625972347875, 6.100008804951945, 9.602148494412823, 10.530562727682053, 11.947979830926466, 15.775193302862107, 19.67290255331224, 27.85969318882112, 36.86748689220798, 46.11317234654581, 53.357629237636445, 58.64515681420603, 60.90621494477796, 59.505893491929584, 58.415596177501065, 59.563262078069876, 61.155493336339156, 60.558234030200595, 59.287750874796224, 57.68226592771469, 55.12292723501883, 53.85500538733698, 54.0911752177823, 54.9861777213312, 56.50182470198601, 57.494325560908166, 58.3786827518094, 59.03135338137227, 46.52234615818147, 55.534603518824426, 60.324896151019686, 59.543191309898134, 58.67024429382817, 52.83025480085804, 49.08066111226236, 49.5660073526444, 51.08276436405798, 54.689744595558416, 55.91769356881419, 55.98837467931933, 56.68774112578362, 55.888722942721465, 53.1646054790866, 53.53577936849287, 54.09838845652919, 56.67894324948711, 57.75861486311882, 58.00115854509416, 60.401700081363806, 55.97744303364908, 48.67966936480615, 39.860992739277506, 27.308645286867698, 18.053738340254753, 10.705700478246136, 6.437556214870946, 5.079571845070009, 4.194208075923305, 12.802108295502203, 10.026711725419569, 14.216881721250473, 20.837856300415535, 14.386547765424176, 15.943429643108, 7.542103009839212, 3.0137484640844407, 1.2793461185309196, 3.3801591252127006, 0.883005444080599, 0.47239613689241877, 0.9755291921957847, 5.848120076041068, 16.6766785037133, 30.084749844766435, 30.50363152257858, 35.64113824598251, 51.24154190863333, 45.63401952866585, 20.831970783971972, 4.492635726928711, 0.5242514946768361, 0.16148466947338275, 0.22491748504821332, 0.13908150065089428, 0.168458275917557, 0.07626863406790842, 0.11862804091745809, 0.10849628297071304, 0.18594126036811262, 0.03632295576314773, 0.12595514331253307, 0.09221022663217399, 0.07335588351012239, 0.14096299727116862, 0.13989954465819945, 0.18605649531368287, 0.12837065684218563, 0.12803072830842388, 0.11560801506763506, 0.13292518744785942, 0.2145420038892377, 0.17228755108531446, 0.190460029989481, 0.17689584574151426, 0.17870621875889842, 0.11517348999698317, 0.12036261719561393, 0.20735058332643203, 0.09306682018382896, 0.1479876864581339, 0.19829105736026842, 0.16405635002639987, 0.14754177732092721, 0.0907722719374203], [0.03719558736549751, 0.04510456035214086, 0.04338331017342787, 0.03912333271376068, 0.019090945547026013, 0.01967474476494376, 0.04960320101329877, 0.02602760548583202, 0.037550213296086564, 0.019253390660930066, 0.008431354935671534, 0.040984482038766146, 0.03983718493292409, 0.011593917189466377, 0.04127703569529038, 0.029438376396654115, 0.03225734247074973, 0.01988784552762105, 0.046059741758771484, 0.02906664372271588, 0.04193011798986024, 0.05663356308134333, 0.019459315094976656, 0.0045084020577281, 0.02921627218564672, 0.058227868660563425, 0.05983546586526979, 0.0937377599879138, 0.030248816981310808, 0.031338684305909185, 0.0207405167091037, 0.059960483753633116, 0.02585867160720931, 0.036184251714017124, 0.0417008470263212, 0.020981608409314387, 0.0321349369422082, 0.019087727977744034, 0.017442393281887618, 0.06070536636416951, 6.47449758745009, 30.24401572442824, 45.500286317640736, 34.18071431498374, 31.502506233030754, 19.484795485773397, 23.49000611612874, 19.57678879460981, 7.066348435417299, 2.22232055760199, 0.10039660388663893, 0.12991628519469692, 0.10653550391115489, 0.6803156171114214, 0.7441757871739326, 1.6580303662246274, 1.2807636876260082, 2.617213509736523, 7.102148888572571, 7.52834088379337, 6.994067488178131, 4.163562107470728, 7.852480161574579, 3.247750939861421, 4.8753958075277275, 1.7275131926421197, 3.907048413830419, 6.47633864994972, 9.79103611361596, 12.029156223420175, 20.079218918277373, 26.937330192135228, 36.624335242855935, 44.34890201014858, 50.478366344205796, 53.385403540826616, 55.541899127344934, 59.22033317627446, 59.62585133890952, 57.126975982419914, 55.784999785884736, 55.6783466185293, 54.53154756176857, 52.922159856365575, 51.149115177892874, 53.81658969386932, 53.03453183943226, 54.72267681552518, 55.40730299488191, 58.58013960622973, 40.702180324062226, 53.878669046586566, 60.13385711177703, 54.27537756581461, 54.51466568054692, 51.46218307556645, 49.710613373787176, 47.92374626282723, 54.105334974104366, 52.04665937731343, 53.68000491972893, 53.17026545924526, 55.37244881353071, 52.35177663064773, 53.5811847256076, 50.537143061237956, 51.8430648311492, 51.10208988189698, 55.07913397204492, 53.89670410463887, 53.063482853674124, 46.549971411305094, 36.52673882822837, 23.03753718253105, 13.909503221511843, 6.0717231227505595, 2.9955060107092706, 2.6188395773210837, 2.666667243165355, 1.9581088447763075, 2.26879574118122, 7.508877592702066, 7.377486036669824, 5.9716507119517175, 5.3013740335741355, 3.483749411759838, 2.890768921183002, 1.5622964645585709, 1.341585552980823, 0.32434661181703694, 0.06592048692607111, 0.4001499394014959, 2.905077727571611, 6.932004315237846, 15.101843937750786, 20.00035966596296, 27.847347528703754, 31.973049448382472, 26.30551676596365, 17.551157205335556, 8.116178656778029, 0.6685445842243011, 0.13251189833446858, 0.15048948447069815, 0.056218205530556946, 0.10196546768589367, 0.09243642175269705, 0.009582746781468874, 0.04641381610605506, 0.05698294514009068, 0.02579766802579886, 0.0443356110894632, 0.02251333226600001, 0.024868414864965507, 0.056875769439483845, 0.028915303053274274, 0.09052151603804481, 0.05925067264827029, 0.001969401259444684, 0.009376347372909228, 0.06289052874630978, 0.042557605286879886, 0.04995749369564076, 0.06420626943450301, 0.04437115756914981, 0.024222438035893346, 0.05784080656726034, 0.07641826636127888, 0.06207006390116388, 0.0724231714623109, 0.027708666692037257, 0.12986858856053124, 0.011391318534621069, 0.019177427297578226, 0.041755032425205556, 0.03546893626691834, 0.05079657447734668, 0.03683843717519795, 0.07714547532340212, 0.02297513006675628, 0.01208989208774461, 0.046167599277630936, 0.06732816582605725, 0.03753122580688327, 0.07699705344895202, 0.10281467614995857, 0.03779068446507858, 0.04789178740353354, 0.021057012528481505, 0.09265428949748317, 0.030519098546656392, 0.04370879028893767, 0.05016406547398337, 0.03408527039291878, 0.015024218554308098, 0.024262581043125644, 0.0356659779114829, 0.017292990814894438, 0.13225228645868842, 0.031010398393376704, 0.039617654777342276, 0.0135361684125758, 0.015026141434998043, 0.031124553154973738, 0.03590561021419783, 0.02061962228899281, 0.06895665424845873, 0.0535968020408144, 0.022080601756310752, 0.016387231655478958, 0.069317581252225, 0.014276012079790236, 0.0649888627231121, 0.05919977759702071, 0.03615110691997313, 0.13396781779104663, 7.740138576876733, 35.36426598025907, 52.36054705035303, 35.169665428899954, 30.074432050028157, 26.61596255917703, 26.668787079472697, 21.711073960027388, 8.85402012255884, 1.9447388331736288, 0.2958404801545605, 0.08490085151166686, 0.1297128275637665, 0.3731700693888049, 0.8773459542182185, 1.8423809063050056, 1.984932708644098, 3.516967719601047, 6.02445169802635, 8.141424011799598, 9.933106322442333, 4.702918894829289, 5.892043267526935, 6.445250434260215, 5.5205673556174, 3.6737860402753277, 6.07541750515661, 10.535416660770293, 11.741994600142203, 16.272119360585368, 22.91128589260963, 32.302516775746504, 40.17214259793682, 47.67116131321077, 51.992773855886156, 54.62559030902002, 57.48116208660988, 59.50079441070557, 59.747319298405806, 58.2438708889869, 58.15844558900403, 56.69966120873728, 55.4911240454643, 56.147842561045, 54.06536209967829, 56.0787578552, 55.59108957167595, 56.551219109565984, 56.06182106079594, 58.87379961629068, 41.3591577160743, 54.969005584716804, 59.355207797019716, 57.50033855438233, 55.470904227226015, 53.67538829003611, 50.23835651336178, 50.257140744117, 53.74621452823762, 55.10642974607406, 56.6503099472292, 55.44720526664488, 56.70841201659172, 54.783108772770056, 54.5233537304786, 53.10051787284113, 53.350070830314394, 52.031605320592085, 56.72837688076881, 55.72578376339328, 54.500552992666925, 46.40430635021579, 40.21564560551798, 27.64118383007665, 16.845277663200132, 8.628526003130021, 5.108813114704625, 4.099898607500138, 2.507310413545178, 3.733372236451795, 4.9017428582714455, 7.606796622276307, 12.461631855657025, 5.6816424285211875, 9.527748976984332, 5.5747308750306415, 3.8961054913459288, 0.9945529939666872, 0.728976664043242, 0.6570504461565326, 0.1885187172240788, 0.20263528150896873, 3.1558522582054143, 9.959466611185382, 21.481740820792414, 28.734397426728282, 29.977827995054184, 36.32318742813603, 36.44077616353189, 23.773777830985285, 10.422558303802244, 1.0290749995939195, 0.0990208019051821, 0.10732082830321406, 0.05803333595395089, 0.050984955497927247, 0.04985415992597419, 0.012054971884936096, 0.022242003075417974, 0.042985308344566056, 0.01343417912721634, 0.012332248790640266, 0.04101746978478567, 0.02053256980293701, 0.010798157722268616, 0.007743735482255298, 0.07193806160601877, 0.05123525557498779, 0.053066358931602976, 0.08173494719930234, 0.06478942705378418, 0.07213817909359932, 0.03541062165412211, 0.03081378192761012, 0.023666413335670388, 0.06405708530256826, 0.06012671334188312, 0.03674348823786263, 0.02874542880172451, 0.06864758373628702, 0.011075727656603822, 0.027813923342393774, 0.08151024595023164, 0.04843135845036276, 0.01684767156538944, 0.10372399953344177, 0.251757130327244, 0.24670275799449415, 0.15127066432708694, 0.08096979390228949, 0.08064387711666285, 0.1908314907022061, 0.14227336002213342, 0.07241876645674629, 0.15730256485121866, 0.14668237988746938, 0.1336537830291256, 0.1917836613832943, 0.12001797722111787, 0.22353678010404113, 0.15978904110529732, 0.10784085644709487, 0.14772678755464094, 0.07456364410538828, 0.13351665329067938, 0.10764490647782242, 0.11702599018932351, 0.12841237032966268, 0.27483961995570894, 0.09514012989858467, 0.25694414312320374, 0.1665995780739092, 0.13571236853397664, 0.24794116976761052, 0.13858780294897097, 0.159132978728702, 0.14244920784427276, 0.28068891576220917, 0.23714689898394772, 0.16934041084060747, 0.19074645494261097, 0.09487246643872031, 0.21489955244525788, 0.15677157398914138, 0.13739987637006468, 0.3191891853367129, 10.026535218761815, 40.201568218969534, 60.84606147581532, 45.70685009802542, 43.186640970168575, 31.308068460033788, 33.62030959898426, 27.619895165966405, 10.391249945086818, 3.46595190225109, 1.1699393247404408, 0.5666844919323921, 0.679070387155779, 1.8520402331506054, 2.025908238945469, 6.0223203801339675, 7.258637730152377, 8.573666753307466, 18.73057077007909, 18.598084872768773, 20.985470779480476, 13.191358427847586, 12.01309705934217, 8.645444166275764, 8.918090078138537, 4.804781867611793, 7.72650686963912, 10.114874839782715, 12.016340859474676, 15.89179163978946, 24.330687715161233, 32.723734224996264, 41.86040916750508, 48.1698553792892, 53.626958785518525, 55.53309732867826, 57.39962777783794, 61.69382295300884, 60.95958663571266, 59.754289350202015, 59.984112785708525, 58.296877799495576, 59.06900421265633, 57.911697126203975, 55.71000406819006, 59.504391224153586, 58.69078574642059, 57.44561364573818, 59.45986840032763, 59.469489974360314, 46.336159090841974, 56.3703860775117, 60.601333033654, 59.33239529209753, 58.35233226899178, 56.367091286566954, 52.91662539205244, 53.31463613817769, 56.21333045344199, 57.45973417835852, 59.806190152322095, 58.610388924998624, 59.128184933816236, 55.79055778441891, 57.45154426943872, 55.19541263580323, 55.69071777405278, 53.6999580167955, 58.549219562161355, 58.36121643743208, 57.285043577994074, 49.14059885086552, 40.84802581417946, 27.673753230802475, 17.21945804934348, 8.6476848202367, 4.811072859071917, 5.319973422634987, 6.21200276959327, 4.550045497955815, 8.78870971741215, 15.530609007804626, 17.551296449476673, 15.390685316055054, 16.271388819140775, 14.26556323805163, 9.67777277192762, 3.8391656692950957, 4.350342433298788, 1.9652356688053378, 0.5802742175517545, 1.1196638547605084, 4.3166492735185935, 11.112418886153929, 24.811933117528117, 33.83923276778191, 37.94030612514865, 46.2630186542388, 44.069699856542776, 29.699373052966212, 12.501298785209658, 1.3892669879621076, 0.2559551542564746, 0.3858073638571847, 0.1438892999243352, 0.22237969622496637, 0.1823618217942215, 0.11524727192497063, 0.11743071443972089, 0.16460139094100845, 0.1470763942286853, 0.17224199949733673, 0.11209324963631169, 0.14348367169018716, 0.13845677127040204, 0.2707665756104454, 0.1568049907443985, 0.18713603577306195, 0.10272581761162128, 0.13376088212094, 0.12600858560613087, 0.15626030223023507, 0.16820892961996217, 0.13289143361391562, 0.11172850751468252, 0.14139312499713513, 0.16356043066949616, 0.17048712188918747, 0.24597520429280498, 0.15658447999627362, 0.07632695634158389, 0.23084357350824342, 0.17230993617446194, 0.1502972576887377, 0.15191770218793424, 0.2962041880574919], [0.06731069902138365, 0.07631864428760544, 0.043968091899108504, 0.01258066716423679, 0.043736028545085466, 0.022490989311688372, 0.057130524317824075, 0.032898845346344095, 0.07255951979107435, 0.016360677132803588, 0.010146504181677536, 0.05816617943046074, 0.07956478098827986, 0.03653489781783954, 0.013498293983209278, 0.006960334449691037, 0.03138816592493846, 0.05576665415578792, 0.0572644709609449, 0.05815918121727244, 0.05127951630481309, 0.06147086057030867, 0.04825848687980925, 0.01573567770631804, 0.05374600532494726, 0.047513550643118165, 0.04109857168288962, 0.10781196727147026, 0.05455325898383895, 0.04580675271309672, 0.033577231525052945, 0.04867932578969387, 0.024261684720254233, 0.12311336314005238, 0.0704821038450445, 0.057560146425760565, 0.008578402639907456, 0.06994332952965653, 0.05453401485518102, 0.03372080789338197, 1.4158327108429325, 17.205870959066576, 37.19987246298021, 47.26558039265294, 34.60414594219577, 18.09896719071173, 17.47385121160938, 22.850610748414073, 15.888372313591743, 5.816646487482133, 1.9467701306266172, 0.2939527782220995, 0.1000885139670103, 0.28435525935023065, 0.37957238874608473, 1.4910143733985963, 1.9740399189533728, 3.770116755077916, 4.520173707315999, 5.105199140887107, 8.175451063340711, 5.251942853773794, 6.954639332909738, 4.030006383695911, 1.2592893238029172, 1.780855098078328, 1.9576966281860106, 2.4736552517260275, 3.639876659839384, 4.997545769137721, 10.58132996482234, 19.2770863732984, 26.17601186998429, 33.68996304850425, 40.518997792274725, 49.53063149606028, 53.48737339819632, 56.17487161390243, 58.57974736921249, 59.8138976097107, 58.14960456663563, 55.01628975714407, 57.070215363656324, 54.90636533306491, 51.565435547982496, 51.91837433845767, 53.32848994962631, 57.52178215211438, 58.154040767300515, 58.26650688725134, 40.29141010776643, 54.78527784347535, 58.83864341243621, 56.776853453728464, 53.62997901055121, 52.331650949293575, 50.54269321503178, 52.71612951832434, 54.29540911028462, 53.76400639933925, 54.823936723893695, 55.05192841252973, 54.99684264582973, 55.548347503908225, 54.94216480562764, 55.22447739878009, 53.30622265415808, 56.24143815809681, 55.574376352371715, 52.73800457677534, 47.36292577558949, 35.85545655219786, 23.646965642129224, 10.631768703460695, 4.727411645074045, 1.8727562312156925, 2.1033599732383608, 2.3548574457245492, 1.8147516082371435, 4.401521519307168, 1.7990236392905636, 6.3059695209226305, 12.472721376726705, 3.0589074473227225, 7.22720189440635, 4.897195850649188, 3.219806013568755, 0.6102070500773769, 0.2965578448868567, 0.21860231585319967, 0.3445386976724671, 1.8037806162911079, 5.0635798515812045, 10.428802717116572, 13.930709515848468, 15.46566926663922, 24.954915277419556, 31.452217525051488, 24.607010849060554, 8.801719238681178, 1.8831149656926434, 0.06815124303102493, 0.06150383682500932, 0.0481393180727478, 0.09247701675180467, 0.06713253761371298, 0.062425540189348885, 0.046279015274898666, 0.047416479642232584, 0.049808834333934134, 0.02133718428892955, 0.02792592348170377, 0.056357361571562875, 0.017193094864788077, 0.0882383595190702, 0.07709902741255299, 0.009442001108020064, 0.017170041363926667, 0.06062795700986059, 0.08816153622202336, 0.03907790369985085, 0.01641411368074196, 0.04995111984411075, 0.039699595541723316, 0.008250776520599763, 0.05060330198536958, 0.009934274844014117, 0.016424697185415896, 0.014789953655112657, 0.029266449029467283, 0.04076039749047449, 0.045517554521680846, 0.04618004437596087, 0.05265494673362663, 0.056490714496542374, 0.03185135034483767, 0.04396821064273677, 0.010971297423595624, 0.022228516097511017, 0.06592254004170818, 0.014632039951280722, 0.03518457209030467, 0.013440046403106424, 0.019103819654593547, 0.06618252730057125, 0.03763965023080668, 0.025314538506791, 0.015843419354378937, 0.1038309224250336, 0.017527354347910133, 0.057094146632739616, 0.03693191139327903, 0.010797726797811207, 0.1066274421229478, 0.04067204457016722, 0.07473054402057203, 0.0526133481593382, 0.02750944744254793, 0.020449746122223236, 0.033183393384059595, 0.016231777093883966, 0.024012600807773492, 0.030322114358686154, 0.07733069240085541, 0.015307674916731495, 0.09202652640881077, 0.043131784355688485, 0.039026548995846705, 0.02944882009028187, 0.07163867444520997, 0.06788267558740993, 0.06361983295890593, 0.02836327924723587, 0.05844946342310118, 0.046793397350777546, 0.014016012371998402, 2.109515888075675, 20.955688222762078, 43.352674899562714, 51.44608174600909, 41.23346928627261, 19.60962099413718, 21.08724451834156, 27.059792472470193, 18.165625910605154, 8.358437476619597, 2.1670117060984335, 0.24398069438194078, 0.09998450220953073, 0.3677274130525128, 0.8853110010104795, 1.0288792488075074, 1.709778073333925, 3.439317292744114, 4.779683601471686, 5.388668342944115, 7.589372473378336, 6.266595788540379, 7.943398250687507, 4.695565431348739, 4.833275925728583, 3.976208870449374, 3.8449612163728286, 4.41299052969102, 6.510787846580629, 8.381243117393987, 14.784673240876968, 21.79179241580348, 28.70069642220774, 37.11640050334316, 44.162373696604085, 50.39103477231918, 54.75744862710276, 58.07399695919406, 59.93158048199069, 62.77971152336367, 58.916953532926506, 57.17151449572656, 58.6940295465531, 56.863102451447524, 54.11902404600575, 52.5516253132974, 56.31234284370177, 59.18791478680026, 59.208236586663034, 58.43498053089265, 43.95138940503521, 55.99045353551065, 59.259560800367794, 58.01941325587612, 55.225854150710575, 54.91552798978744, 51.12301964913645, 54.13761215825235, 55.89198243233466, 55.46884890525572, 56.447044880159446, 57.051588027708, 56.673428397024836, 56.67985323936709, 56.66850582245858, 55.12331162729571, 54.40414505620157, 57.5713687558328, 55.72014339508549, 55.05330908683039, 48.4680143479378, 38.84125494187878, 26.34262238779376, 14.892378584031137, 7.959461337135685, 4.232112390379752, 3.268604220882539, 5.314275689663426, 3.971220841330867, 5.8191965183904095, 7.480421287398185, 7.5131863163363555, 5.8803202836744255, 6.824864773981034, 5.17722660495389, 4.451629798258505, 2.4850673877423812, 1.1323329878430213, 0.3926713277976359, 0.1337562089846019, 0.3861001626618447, 1.363760427601876, 7.503288705502787, 14.084262463354296, 20.023042732669463, 22.934269020634314, 28.584490322297622, 37.40282766280636, 31.92490823807255, 11.474440905355639, 3.302170639076541, 0.11826009654830541, 0.009915389819070697, 0.026427060966530157, 0.020129349000091036, 0.06083930917685071, 0.010650574714095603, 0.07494814363458464, 0.03523917883754738, 0.038260698558822755, 0.021917672091794592, 0.04534049628062114, 0.01039653133991505, 0.06313110716761121, 0.1027817343692145, 0.012894760340362067, 0.016002108722234207, 0.07756814135298615, 0.05247058767464854, 0.028026807685232455, 0.05468814408466701, 0.032278547784493815, 0.023470294827054587, 0.0077381985817825604, 0.014867429084505045, 0.03890613146546868, 0.020822986074152495, 0.03215020124409949, 0.047963274898187774, 0.028145415332889365, 0.020812283825850295, 0.018294510964844978, 0.03565715257859519, 0.07291920573240326, 0.07845141008616456, 0.045264462054136305, 0.22521282726478195, 0.2183254669991232, 0.09421608996607604, 0.15241349897077008, 0.08519926574081184, 0.11934665437307089, 0.09929984943160128, 0.13645892121618794, 0.11583706769611567, 0.10625782002124096, 0.3310348351876582, 0.10901791989923486, 0.14417831425464925, 0.07237087063972028, 0.21990068166727023, 0.08298268992333643, 0.11981749201133368, 0.20106473997715982, 0.14111229248585241, 0.16932576323949522, 0.20265627231809402, 0.11639359226870923, 0.16472791802258263, 0.10621699519575604, 0.15155089928978874, 0.20634994992325384, 0.1735079751139687, 0.2226569128012465, 0.19666673645617502, 0.2168944760436012, 0.22190047758481196, 0.13146350701009074, 0.14142491764599277, 0.2324167350607534, 0.20419909678880246, 0.14436243582637082, 0.09973373098839676, 0.14678855967377463, 0.12026424384525708, 0.16936207580710613, 2.6031912815186287, 24.487835514929987, 48.947535868613954, 60.393110090686434, 47.67243608351677, 27.71032737147424, 27.20935440832569, 32.85484533156119, 21.086275692908995, 9.17312748970524, 3.1015985242782103, 0.5335234261808858, 0.46354147815896624, 0.8346315269027987, 3.033909691918281, 3.0321595793770206, 5.9255667847971765, 9.194045489834203, 12.063308300510531, 15.069460849608145, 18.51185352571549, 13.977721083548762, 13.709966367290868, 9.953665425700526, 2.983034589598256, 4.582189811814216, 4.056235518186323, 3.810292612160406, 5.8775643283321015, 7.17266574982674, 14.875456498515222, 22.03204151122801, 29.037496620608916, 35.90756916230725, 44.274722145449736, 50.9533183036312, 56.131023437746116, 58.76992740938741, 61.53996798299975, 64.32854960041662, 60.436201249399495, 58.15966544612762, 60.80982662016346, 58.227432235594726, 56.785298316709465, 55.41890536585162, 58.89625518552719, 60.32077373996858, 61.828756409306685, 58.67986586786086, 48.1483058775625, 58.161689389136534, 60.09147982443533, 60.38345713769237, 56.53612190677274, 57.27262143165835, 53.64896720455539, 55.44288673708516, 59.76407566378194, 58.30264368364888, 57.86722137082008, 58.695602416992195, 56.82512606343916, 57.46575893894319, 58.61818659690119, 57.45645507689446, 56.42049827883321, 58.99088236593432, 58.64914586467128, 57.91350533885341, 50.60757706242223, 39.84930799853417, 28.579236307451804, 13.755304063520125, 7.741359904889138, 3.974761025559518, 3.789353284143633, 5.955507216915008, 5.528299327819578, 9.89871988373418, 7.599808429518054, 15.258202360522363, 22.337009714495753, 12.773052357858228, 14.369770807604636, 9.425912480200491, 8.515683335642661, 3.8133040118602017, 1.6041970613502687, 0.4545644905057646, 0.9252900041399464, 2.5131765632860126, 8.697477348389166, 16.98388441916435, 23.55494683788669, 28.55754952276907, 38.19910018674789, 48.02661434296639, 39.197464989077666, 13.395207928073022, 3.805724276650337, 0.28440796619942116, 0.16613194268316994, 0.15248753370777254, 0.0904818709879633, 0.17659552395343783, 0.20544683951283657, 0.16173576245144491, 0.1601901340989336, 0.11057813456582447, 0.1311793956424921, 0.12514799307551117, 0.168685604848208, 0.2053842960946983, 0.265825737508074, 0.16841604915117064, 0.1377832727326501, 0.16454509880033233, 0.12966123920294548, 0.15949987355739842, 0.12797979878321772, 0.16306680957636527, 0.17730092239235679, 0.1260151050143665, 0.11160935019893993, 0.21678700922958313, 0.07228182057940191, 0.15552585373722738, 0.1492312769856184, 0.08044798077354509, 0.1441334215022864, 0.12085259937110449, 0.12371687188504205, 0.1986381871205184, 0.30033422934432186, 0.09060993024538602], [0.037518194651291255, 0.09546759418181835, 0.06738581394235935, 0.06357122851054996, 0.053761641179481824, 0.016398832141872377, 0.06644274438581159, 0.056042748413258986, 0.04560961530754163, 0.04907988252178316, 0.027939048483066505, 0.020887864145239996, 0.022535225143656138, 0.012967220766680136, 0.05937800795260457, 0.03399007247700807, 0.07467915484261128, 0.022580315163659475, 0.048597844678067395, 0.013861624587837969, 0.009734853538834761, 0.0984687053207909, 0.03637873079447496, 0.1435029924276375, 0.037498031217124195, 0.036304033391418, 0.01135440363037971, 0.06902558683988548, 0.027809003142700083, 0.06987898580489621, 0.041344305875921444, 0.0450011921085177, 0.013918038344972078, 0.06157838101048143, 0.10440929582522762, 0.05145398516868872, 0.024326558960902116, 0.026279803545724963, 0.037490083054909785, 0.019118298716362447, 0.04077644320204854, 4.546361411771467, 24.575153358521003, 41.812481726369555, 36.02127475123252, 31.969919396984963, 19.067694564019483, 19.750942030260642, 19.615312353257213, 10.766114784825234, 4.4980446753963355, 1.5916214522815522, 0.31497208581816766, 0.14852702767858583, 0.26033313223911875, 0.542929882724439, 0.4735908050450587, 2.350626434049299, 1.212007848005141, 3.908301611100474, 4.941161207614407, 3.1235782609831904, 3.371326928177188, 6.247997380072071, 9.438456220011558, 2.411582518008448, 3.1686730154099005, 2.742389579934459, 1.950843879772771, 3.192905418334469, 3.091379033942377, 7.756968486693598, 14.650384033879927, 21.47219769416317, 29.82687165660243, 40.37476439629832, 44.583577417558246, 53.38038682937623, 56.31765373291508, 55.96177708718085, 57.78536542769402, 60.325559031578806, 58.455106212246804, 58.72943678209859, 55.019580625718646, 55.675236178982644, 56.31862255834765, 57.740069896944114, 56.494650686940844, 58.07355765373477, 43.573920111502375, 54.91723029844223, 59.2451500123547, 56.879074342789195, 54.91648897047966, 54.734616510329715, 53.94864020809051, 54.4135626669853, 55.23975503060126, 56.257912112820534, 53.91333495416949, 50.21277481509794, 55.59714963359218, 54.99954123650828, 54.6601777691995, 56.50089510025517, 58.20425887261668, 55.850268025552076, 51.83454544313493, 43.9399556959829, 36.632874242721066, 23.46076092412395, 12.17286402179349, 5.754844642454579, 1.3998028419671522, 1.243315838998364, 1.7416564014650162, 3.2076682390705233, 3.6245436245395295, 3.781398717434176, 5.856314887923579, 3.635722624678766, 5.926632198595232, 5.334262617172734, 5.2693199342296975, 3.2052334277860584, 1.0765155765318102, 0.6688572093844415, 0.26980265314059876, 0.13433459004567516, 1.3742440650540015, 4.2539178267602, 11.095127117249275, 16.499191253416, 23.1656123745826, 26.292702382610692, 33.05161691481067, 28.99495263253489, 16.7699916901127, 4.715712685738841, 0.9280769094344109, 0.025186484995027705, 0.02656906876983422, 0.037926596123725176, 0.06774776750394414, 0.04175660290545033, 0.050416127553269754, 0.034404652448551315, 0.009047031072118591, 0.04077721695085207, 0.12483178262388515, 0.03062840588691254, 0.06553997871496024, 0.014953142831913166, 0.03724740555269584, 0.02319159012498154, 0.013295930900400686, 0.048897032656015894, 0.048898507375270135, 0.051834903236839085, 0.05627616774290801, 0.10699738598158283, 0.041503747925162315, 0.09912872837195474, 0.025932953407567357, 0.05716838438304202, 0.0448221841736907, 0.030408402672037486, 0.07207267857607334, 0.10979133928495069, 0.02639708203083325, 0.026457271643824158, 0.04036286297524649, 0.04865421725797558, 0.051802084030162905, 0.018221985421053345, 0.0457845208415341, 0.03818353818308923, 0.038172901052260594, 0.04934398750323923, 0.06770955503828104, 0.04668611056742169, 0.08946878865601555, 0.053864867696839, 0.0806332361553946, 0.05167121323005808, 0.014572550351130626, 0.03870909365134374, 0.03896709674248292, 0.025585375485881686, 0.02056534495955754, 0.02134859899900133, 0.022690231543815425, 0.03029058601016239, 0.024403615914765867, 0.03256097375865906, 0.010388988246690604, 0.09600472140816912, 0.009035822248176463, 0.06772457036159693, 0.05674313663715317, 0.022139218973837072, 0.028206399762101715, 0.024860309654726617, 0.046728276046774084, 0.035462110423513, 0.10314179569362633, 0.017490444231718298, 0.025368126357094418, 0.024675937189209848, 0.026929312040128058, 0.054237037040894075, 0.10387694132664513, 0.010839650959467456, 0.03930425586839838, 0.06960383000513239, 0.048090682980874856, 5.797350387419424, 29.86462643069606, 47.287286789186545, 41.003865503495746, 30.093781102088194, 22.212486228635235, 28.353698061358546, 27.04594062220666, 13.66745081640059, 4.903699630691159, 1.8990522911471708, 0.33401782834722155, 0.047444120094540625, 0.21891791343448624, 0.3720976075818462, 1.0625232563864802, 2.2572058727664333, 2.668895639719502, 4.387246053065024, 5.84019051444146, 4.934466702322807, 6.53582678687188, 6.527374079150539, 10.922406527303881, 8.78157590666125, 4.852452883797308, 3.8307774355334625, 3.2699836694425155, 4.797952530845519, 6.8667355852742356, 12.635891975895053, 18.47298283730784, 24.852329607932802, 33.1052827835083, 43.04612598111553, 46.85776764346708, 53.65018313930881, 57.92479784257951, 58.67293896213655, 59.39623971139232, 61.32324918623894, 60.86898380710233, 59.09069491970924, 57.24135229664465, 57.33026066134053, 57.46955579326999, 60.061877696744865, 57.930293083190925, 56.55130932407995, 47.26518423326554, 54.392213206137384, 58.85465844984978, 59.858816592924065, 56.6586842075471, 56.3530727355711, 56.99621985035559, 55.20572062461607, 58.36460928763113, 58.67931673603674, 55.614027592443655, 51.026474429715066, 57.646486067002826, 58.71092319488526, 57.10001360985541, 59.0057324594067, 59.310120151888945, 57.136279844468646, 53.46999337596279, 47.21923366669686, 38.9770983880566, 26.64416636190107, 16.33127360574661, 8.10492733793874, 3.4415596627419998, 2.4114484219781818, 3.645852145648772, 5.747825070734947, 4.765156122945971, 8.285618674370552, 8.420508004003956, 7.7280919974850075, 4.394520578845855, 6.307627212616706, 3.7367216954308176, 2.113997195997546, 1.7106332726055578, 0.08521815746902459, 0.16935631482591554, 0.2798915101635841, 0.9947276007263892, 5.38595651426623, 14.207309176844937, 18.780563339110344, 22.9955776276127, 26.94359225611533, 39.165074056194676, 37.42992731832689, 21.229438281828358, 6.702106354698059, 1.1497171775948618, 0.05193717597473053, 0.048600169754917585, 0.043476738426233494, 0.01599789428104076, 0.07391801584632167, 0.12541893539169144, 0.07828848616730782, 0.0027117350715167464, 0.07282130735655946, 0.039292672618983254, 0.0155255033995115, 0.04848472413516814, 0.024666613899171356, 0.06462671763954625, 0.019770578533831625, 0.047727204904320746, 0.045724459548270514, 0.03590822257401963, 0.02061318140476942, 0.05675826687365771, 0.08615912028378056, 0.042198110867532036, 0.04454672576919679, 0.020339755048494668, 0.03880005510103318, 0.06883092389832582, 0.034540158080598043, 0.03377819937022944, 0.01317667495083785, 0.019024665535037077, 0.025800724716616735, 0.04072963522987501, 0.03769722173831636, 0.03427442133186325, 0.13109413005651968, 0.18350959004413697, 0.19915076122889597, 0.11735061994723736, 0.11146882669098916, 0.22244268397410072, 0.13271537128715746, 0.172036764542422, 0.16829119214127142, 0.1204762586783017, 0.13754302755959574, 0.11333363025539345, 0.14220413631729542, 0.09333133502232452, 0.10734112197232824, 0.16397473101894702, 0.09844248213114278, 0.2302962496516205, 0.20991110963927162, 0.1301001922617997, 0.11630281084968198, 0.08269336149697343, 0.19774511246190918, 0.12413391482926185, 0.24089849283618314, 0.16823195822296605, 0.16240731512586917, 0.09770424916378914, 0.1738051406197971, 0.15513793745588872, 0.22220884329609333, 0.18524413567877587, 0.12464883316668773, 0.1795387418279725, 0.20116230893519618, 0.21032571642389222, 0.12040668257301855, 0.16850634027392636, 0.12831633354747488, 0.17137990543438544, 0.16646765773334812, 0.14965158346439564, 7.29786241246808, 33.98629419265255, 53.82883925591746, 47.812735342210345, 43.29440024591262, 30.337862353171076, 33.385944058818204, 29.76866956680052, 16.05112223855911, 6.074110865592957, 2.4918261218455533, 0.6194121787144292, 0.5389890038678723, 0.839103028899239, 2.8148737549781804, 2.525145430718699, 8.301960249100963, 8.608396399405695, 12.192941654113032, 13.369075136799967, 9.614987392579357, 11.152405488875605, 15.483684712840667, 19.961555657848237, 7.496516243104012, 8.339378679952315, 6.689539570962229, 3.6464488362112357, 4.797793184557269, 5.751659187578387, 10.355435763635944, 17.965381068568078, 24.922269390475368, 33.84595178788708, 42.83137229181106, 46.61016802633963, 55.144166869501916, 57.96532377119988, 57.648929703620176, 60.1594505771514, 62.66506848796722, 63.3820620659859, 62.77925260605351, 60.253622762618534, 59.28102008758053, 61.12857803221672, 61.83900164019678, 60.24093389511109, 58.604054297170336, 50.905273191390506, 56.27529605742424, 58.252484413885306, 61.967423962008574, 58.13184407449538, 58.693696145088445, 58.68516891233383, 59.14265455738191, 60.19510099964758, 61.07429635140204, 57.510458269426906, 54.78969835465955, 56.20519545770461, 58.02992128556775, 57.969622688908736, 61.07195861877934, 62.02411397810906, 57.88585262913858, 54.015967692098315, 47.24448588586623, 39.74299607738372, 26.68198193273237, 16.913077792813702, 9.441913789318455, 3.1891740185599176, 3.7197714178792896, 4.645856253562435, 8.763846793482381, 6.960590549053685, 11.249952873876019, 12.717291943488583, 11.29826961025115, 17.246581239085046, 11.186313398422735, 12.700826814097743, 8.292170013150862, 3.8942328047367836, 1.9250481671863988, 1.0741502647438357, 0.528777787281621, 2.221346829206713, 6.534453467015298, 16.029967915627264, 24.22349718309218, 30.883803329160138, 38.00398972726638, 49.098837375640876, 45.54051022375784, 26.362222471544822, 8.007104406433722, 1.6295044388501876, 0.14648921847824128, 0.17810641787946227, 0.09005348994246415, 0.17874122897703804, 0.16611329610309294, 0.1568222430444533, 0.09814367719715643, 0.08585929645285492, 0.14586545436853363, 0.14827775798978346, 0.0976654238277866, 0.1429318892018449, 0.11429016763765006, 0.15127939772942375, 0.2234538434253585, 0.1460565013750907, 0.15185436203835473, 0.11445920493814254, 0.16002841293811798, 0.3448304239540331, 0.16171527726034965, 0.11257472057496348, 0.17037758663777383, 0.15663406120673304, 0.25184821818144093, 0.14147790028683602, 0.11668081395328046, 0.1640569782184978, 0.15409861661253438, 0.15748061900657995, 0.1263260524419527, 0.1442274358123541, 0.16482200894144275, 0.13536309372753869, 0.3106843836365208], [0.02096812143140743, 0.043639834714873184, 0.050010997276272506, 0.07144329904188072, 0.02938895223421916, 0.0157950188769328, 0.02670269940168627, 0.03182430169545114, 0.04017375034069823, 0.02442915920138119, 0.015773577033542097, 0.02231409577953239, 0.053308140110945514, 0.08131684705374703, 0.040433143881419976, 0.06000541864083179, 0.02332783694709501, 0.05552871490738565, 0.05808164162801639, 0.04857827879248127, 0.03204884589649737, 0.06632475918459316, 0.038325452140622565, 0.032056047122985605, 0.021524224655642625, 0.03765568062062225, 0.03153016798258309, 0.054164791119194804, 0.04436002631161002, 0.03622778849075398, 0.03486436265971392, 0.06074696876889756, 0.007404303948034443, 0.03202095838083375, 0.012626783742058664, 0.08316095092243726, 0.04134193866423542, 0.07832174970498008, 0.0043282976595594765, 0.012147913671909802, 0.05237180446725219, 0.46258055875378273, 12.283481724800604, 32.83466277583953, 46.547778806378766, 41.34443313844743, 23.331434495987434, 15.986158963172668, 18.03938638779425, 18.51156719269291, 11.046532873184452, 4.408492551695916, 1.7510189764922666, 0.4228743442123936, 0.3868081198344308, 0.1092158540362312, 0.9902653530720742, 1.295178888305541, 1.2391600878007951, 1.1079847524243018, 2.883508613994045, 3.3478557102141844, 6.345836491354051, 1.1441883516888465, 8.39194530440915, 8.432421222809824, 3.9663139562453, 3.0870565820124845, 2.2657970891844843, 1.5772854344498728, 3.5973571865789356, 3.836764933601503, 4.747440247766433, 11.273477288984484, 15.917100733326329, 25.72764377440176, 34.41787650508266, 42.374227892967966, 48.764992683164536, 57.03965225527364, 58.63988122632427, 61.082505872172696, 58.52970184818391, 61.01956359801754, 55.22721521316036, 56.705234896752145, 56.87628553759668, 60.53627660197597, 56.102982413384225, 56.19441678447109, 44.36386192998579, 54.419238336624645, 58.9351886318576, 59.05385209668068, 55.530022190463164, 55.06191084461828, 55.111591585220836, 57.573984976737734, 53.63930248445081, 59.668805214666556, 54.686002654414025, 55.1318427824205, 54.9031372224131, 54.47419074273879, 56.83523401137322, 55.03896497911023, 54.7722634192436, 49.97161180742326, 45.00070187353319, 34.39438150775048, 24.013536630138276, 12.621068358421327, 4.123336730464812, 1.4483768613107744, 2.2700227076007478, 2.9086108025043242, 2.998207788313589, 7.248273847564575, 4.160610033619789, 5.16820123118739, 8.81863053767912, 4.791273224738337, 1.1879914205881859, 5.381640926484139, 1.3041335368348708, 1.0646785987961678, 1.4783300411316658, 0.19545504582985757, 0.512184169624121, 0.7986817172458096, 5.743378573848355, 9.049584596387803, 15.273859481657706, 19.451192540507165, 22.419518732255508, 30.86473276538234, 31.20850301557972, 21.58038058588582, 9.43009666858181, 1.3767953217029574, 0.14602633283263253, 0.02346783760003746, 0.06529005785142222, 0.014079002993962458, 0.015803690034625752, 0.011670980846599467, 0.06091381888836623, 0.07557762276020742, 0.013637725815867946, 0.03315008388111188, 0.013092283662709018, 0.0633030977370518, 0.04172458043021541, 0.0730387307703495, 0.03788893141092793, 0.0068827038874939815, 0.04405030845514229, 0.015129100779191622, 0.04199493285869399, 0.01727209959719931, 0.029179168632254008, 0.0628084730687401, 0.09709661886576684, 0.09309386308755606, 0.0204728091991837, 0.022232442298122955, 0.06349158217950214, 0.024744266486396233, 0.07050115645172135, 0.09947725241222691, 0.06190152072738256, 0.08461624218691742, 0.056097837795893994, 0.02724955785989521, 0.05125877064382357, 0.08316774612232562, 0.023436719108553185, 0.051941178784134893, 0.0704304158927933, 0.05599008752934395, 0.029963807375620932, 0.015501439620199946, 0.015213395348720014, 0.08631118873675024, 0.025475983875953866, 0.03277086652815342, 0.03531846510727079, 0.020475480930819627, 0.07745142785772201, 0.024284454768583662, 0.04653750483186976, 0.030298792727051244, 0.009118188191355478, 0.035054540156476924, 0.03165421293928258, 0.015575870807703226, 0.01924848961343448, 0.08681273117901818, 0.018499577380416375, 0.04575098534264872, 0.02743080660190073, 0.005847720059400966, 0.026825242826054176, 0.0672311178078094, 0.0008115037112034888, 0.07311255866361242, 0.0634644243625864, 0.02648590226477433, 0.03626233139525979, 0.06791891920710764, 0.01784959965715966, 0.012571266307795962, 0.031323149958024585, 0.01816285683983757, 0.05415292058680808, 0.041171625827349005, 0.03548363366374566, 0.6890981716494406, 14.29700299616783, 37.44968037451468, 53.30000177506478, 46.389977931976325, 26.747826760815038, 19.811501464536114, 24.919676703791467, 23.99331092834473, 14.996821495794482, 4.918149642405972, 1.8420754517278366, 0.5712153810647227, 0.14787635856097744, 0.2915220118818745, 0.6106364270371776, 0.8688252178892013, 1.4157667659944104, 2.1766322995385816, 4.17819352880601, 6.473756749783793, 4.3778612921314854, 7.783593045127008, 9.808917218639005, 13.228997492021131, 7.864479672524237, 4.344175486795364, 5.597706648611254, 4.665163630439389, 5.053302751433465, 6.879699999286283, 9.173649164938158, 13.514987307210124, 21.696098350709487, 31.952727648519705, 37.32363108665713, 43.726186521591686, 50.90950542880643, 58.14518405545143, 59.05399330200688, 61.19381097055251, 60.89139623026694, 62.19396829605103, 57.97778121886715, 58.74621275932559, 58.45673399586832, 60.69965900913362, 58.56417948199857, 56.94642143864786, 48.72054046200168, 55.80466654992873, 58.45470613048923, 58.71841099954421, 57.09775040226599, 56.38730718243507, 56.07965607796946, 58.79353615545458, 56.00503690781132, 60.26898276421332, 54.87890481948853, 55.91465765430082, 57.63638596380911, 54.337033302553245, 57.62448157033613, 56.86028226729363, 56.75688858955138, 52.91161652534239, 47.52659059339955, 36.0273975710715, 26.038358249971946, 18.072926575137725, 8.466620368342246, 3.3381762812214517, 3.984657410652407, 3.5160364018332575, 5.85336575585027, 6.025644588855005, 7.0550206303596505, 7.985643648332166, 7.4583667805117955, 5.693651255100004, 4.648812740079818, 5.121602492947733, 2.6650323502479063, 1.4528381896595803, 0.9835839019187036, 0.0992002043752901, 0.32903831812643236, 0.7911740555878609, 4.36386872683802, 13.844717433375697, 20.746131673935924, 20.43673119237346, 23.657869831208263, 34.46565881852181, 40.65134640662901, 24.827989339828495, 13.1026412786976, 2.4566804593609226, 0.18274520283504841, 0.027650078202808098, 0.049074569702028274, 0.03546116047448689, 0.02181580921094264, 0.04151011411581309, 0.05528113444245631, 0.03772132669485385, 0.03548158437854821, 0.07969310071559683, 0.05048020314725657, 0.027083312949886727, 0.034984014102167664, 0.10680379556311716, 0.06898643208607551, 0.03691318820440962, 0.014967052115788384, 0.04398787611975305, 0.012038986502786078, 0.035359175019567056, 0.049625992129046115, 0.010465883364480351, 0.015878545443317103, 0.027645180985752135, 0.017022188309760346, 0.03886986103269362, 0.048106797640362096, 0.008505279547534883, 0.04580537758527264, 0.09644467804220416, 0.043994610032607476, 0.0937037916493512, 0.08473490920638846, 0.023061148334114302, 0.025899383434725386, 0.021008097814516197, 0.11401633716999524, 0.13045352733423635, 0.13384803228320616, 0.2187876478438416, 0.06894116395062978, 0.11760986410081388, 0.08122090220211015, 0.1790641043936053, 0.16748621759395446, 0.19350248689372695, 0.13195317508953233, 0.09773530636823947, 0.1365878078485689, 0.2051755218135734, 0.12337531924488084, 0.159402365886396, 0.16311184022455447, 0.09847298009140838, 0.17971138740258832, 0.19197910573453675, 0.14240115880966187, 0.23843882965945432, 0.1236775792354057, 0.07063069425883793, 0.12074956054528876, 0.12599661165187437, 0.10869846889568914, 0.16618742277064633, 0.1312730881956316, 0.27705909924641736, 0.16934385823626674, 0.16492973622535506, 0.11702094933078175, 0.17121749479443799, 0.16892404205376105, 0.1434382579980358, 0.1576251491543747, 0.16706987945062501, 0.08206077971525731, 0.12351726001549153, 0.1240304776377255, 1.080913043791248, 16.740993607428766, 42.458484326639486, 60.73488189328102, 54.62970487533077, 34.93596276929302, 26.428365399760587, 28.322030805772354, 27.324862326345137, 16.76423365069974, 6.264084000741282, 2.514238545010167, 0.786967252291018, 0.782799917844034, 1.0476475449339038, 2.3057228951684894, 3.9706368984714633, 9.30807859666886, 7.5320588004204545, 11.564293580670512, 11.080022069715685, 15.13564202093309, 9.364970614833217, 16.04037102191679, 14.793162230522404, 9.899747544719327, 9.434963349373112, 7.126651935039028, 4.645541483356107, 6.396939581440342, 9.395638646618012, 7.808484896536797, 12.799683290143168, 20.29710069779427, 29.020975597443122, 37.45110027251705, 43.78461022530833, 51.02729028271091, 59.54956123905798, 59.7960312135758, 62.291607856750495, 61.31432971646709, 63.3106396275182, 61.16443241796186, 60.83416492708268, 61.04490995407105, 63.509719525614095, 59.94102162699546, 57.64150857925416, 53.21907543366956, 58.90560611601799, 58.32831167405652, 60.61734807106757, 58.66528641793036, 58.460844639808904, 57.701634591625584, 59.95762894230505, 58.051455097813765, 61.40900004294611, 54.4645691687061, 55.52910435584284, 59.20975846628989, 55.71006290374264, 58.26678929790374, 58.16881241336946, 58.0312313572053, 53.56255738965927, 47.959271169477894, 36.38529815981465, 25.529715091951434, 16.129829499029345, 5.319913606489859, 4.379801394477967, 5.173981333932569, 6.07874220417392, 8.70508380474583, 12.551693397183573, 13.860432409471082, 13.357889517661064, 14.405196674408453, 15.140703839640464, 7.31279879808426, 12.667672980216242, 6.528102659410046, 5.756200311645385, 3.7821934876903414, 0.6223437826960319, 0.8493558593815373, 1.1539899870272607, 7.277069928184633, 13.18196140950726, 22.151869919992265, 28.1708195132594, 33.17973721411921, 44.720056287703976, 47.76655727817167, 31.503775119781498, 14.588511586189272, 2.538667066443351, 0.3389423334550473, 0.12093386597811215, 0.1576790051354516, 0.13267170427547348, 0.12603647120657469, 0.14981636897690837, 0.23184894133479367, 0.23672786421112477, 0.14167185842750535, 0.23389212847236665, 0.13017764375094446, 0.19052479506259967, 0.13578041246341122, 0.2612307114947227, 0.15366208439152088, 0.1426616746691927, 0.15584488339241476, 0.1331251363960966, 0.12590765352210692, 0.19064162347105243, 0.1081390638325003, 0.1476933861211423, 0.1402256989310826, 0.28583901844197707, 0.2062870541046704, 0.10774306532356048, 0.2513082028036156, 0.14276826814297708, 0.16521571684748898, 0.3589714264437076, 0.20600157910056655, 0.2164197160351661, 0.18956153142836787, 0.14632487729672464, 0.12321568950409852, 0.19533475470398703], [0.05110335055618517, 0.025343266803951516, 0.07041307932306683, 0.033301884203308055, 0.014830650160870245, 0.04122358191037371, 0.01989907829181081, 0.028205321493348288, 0.04410226836860661, 0.09567451453016651, 0.022835110261615728, 0.05912693029630089, 0.047520035577397195, 0.027550534653146903, 0.03346394244281035, 0.019377720985381354, 0.032139476013159564, 0.14615279862717276, 0.10884047861421302, 0.07608834293580825, 0.04258807260362853, 0.08268484259925543, 0.03044266595445093, 0.030890109182725993, 0.0181475599792095, 0.0268386340429706, 0.015078026654889748, 0.027405263315285408, 0.013670945303484559, 0.00950307459495361, 0.06384255387069238, 0.023557663324379155, 0.02099920736415492, 0.030109749040416176, 0.10708845085314206, 0.015316382463600849, 0.028097237978551178, 0.031385863830725995, 0.021866819175380855, 0.03292903687143999, 0.02210337180464018, 0.06422775053989983, 2.4052081761821626, 15.122101999098255, 37.45882341938634, 34.64052984791417, 23.282516656383393, 14.78178833761523, 15.444119764912514, 16.314816321096114, 15.15689048074907, 14.086543321609499, 5.678736932816045, 2.012959146691907, 0.6423768593418984, 0.055540692692081776, 0.3086743834278276, 0.5143906560636337, 0.8239874399958119, 1.6127854585647585, 3.4496345971861198, 4.3460140978136375, 2.932353399453625, 6.231870555108594, 7.286525782077544, 17.041868817421697, 5.912577365675281, 1.6775774979783644, 3.873996561573398, 4.007679762378816, 1.9053366636076283, 2.587459635350012, 3.727041776141813, 4.123999120727662, 12.332296602187618, 14.736735993816009, 21.589784468373946, 29.826624547281575, 40.02374364483742, 47.12231974447928, 57.016423979113185, 61.475276331747736, 60.0632034578631, 59.93849562060449, 58.77523045386038, 57.14160250079248, 58.525132286933164, 59.22542441275812, 52.719769477844245, 55.223304610098566, 49.50443790804956, 51.09994826778289, 59.71973326898391, 57.925288138851045, 59.390720936559866, 58.50756006856119, 57.1420810299535, 56.638860548696215, 60.39559687337568, 55.479690336412006, 60.634543741903, 55.394049306069654, 49.611416632129306, 57.457706312979425, 54.50809571050829, 51.70622902531778, 49.56958455424155, 40.373218982450425, 34.72913619010679, 23.129673657878755, 13.423088135257846, 7.196648591949094, 4.054857785663297, 1.303232494861849, 3.8247467913935265, 1.4845590101134394, 4.3990151247670575, 4.017467301699424, 3.922981081470367, 6.549963499269178, 4.775087073926003, 6.541098452383473, 2.532464083163969, 3.5634674179938535, 0.9107049770893589, 0.9510678209124074, 0.2282247325826076, 0.3407919148523962, 0.45442181429074663, 6.093594258831394, 8.249422061827875, 15.4770206059179, 21.403466001633678, 18.36729653419987, 30.393401153625984, 29.1870742459451, 24.92980818594656, 16.18385034222757, 3.5758937318478865, 0.7377457354337938, 0.05922061518856114, 0.07099996396009961, 0.09665400390663455, 0.023475103943999258, 0.06974593931508642, 0.034001192243229, 0.033213558096078136, 0.042816420431218805, 0.02473728359496642, 0.06812129665406481, 0.03237874825455008, 0.03256349801836956, 0.07015633261612347, 0.04229732308416598, 0.07179325566657128, 0.1134164673426459, 0.04400492540650791, 0.05438778399219436, 0.03837519805998572, 0.010578528932866552, 0.05162076250980458, 0.03921739298910384, 0.012349969361938778, 0.09456223147290369, 0.04139278008933029, 0.06630728471904032, 0.11336985855333268, 0.021760342530004924, 0.04657077219998164, 0.048722460370270476, 0.01679054630409566, 0.03467300538754752, 0.05218167293576464, 0.04196424337644731, 0.047038955343586784, 0.13349871151149273, 0.05076858162459347, 0.05617451936667485, 0.05466356798405609, 0.031253190808779294, 0.030942850505873084, 0.054685730907705524, 0.061660023000572, 0.12558321528617414, 0.11378798168152572, 0.027041490294880448, 0.04597573638743451, 0.0259344108898433, 0.040742199071833206, 0.00904619890911084, 0.0571457235022418, 0.04492220078264514, 0.039114185623944774, 0.008830061565423685, 0.05284937601836939, 0.05632293741068533, 0.07060051039462129, 0.03985691552741393, 0.05182399414479733, 0.03086516344469161, 0.030392255453813462, 0.025641052840998577, 0.02574219751442152, 0.02938430208051878, 0.031942769532061877, 0.05893916597649936, 0.041507337047087575, 0.03231194155711321, 0.013651078728388154, 0.038433064511346246, 0.08277504179146021, 0.12119422095917887, 0.03238085116590223, 0.01623878488317132, 0.04906853675962456, 0.03378230560150358, 0.0470990396194881, 0.028012265421209798, 3.9857581257820134, 19.618071740673436, 43.50192500698952, 40.58966321329917, 25.541246860258042, 18.12976368011967, 16.82683663983499, 22.53117488276574, 19.170564605343728, 15.551955526874913, 6.848961364838385, 1.7753978554279575, 0.49553646615916686, 0.06617000942388851, 0.056333586032832825, 0.21187197296850144, 0.4857733497215856, 2.488318052022688, 3.1943527729280534, 4.477888105377074, 7.354482806498005, 4.853755600990788, 10.001831150824025, 15.0730517795009, 7.899743251262173, 6.774767771843941, 4.841297172730969, 5.13086909247983, 3.787098901887094, 4.337179939593039, 4.9099822871146666, 6.911807050628047, 14.827600640635337, 19.220468921046105, 27.38979716454783, 34.61186516669489, 42.55954811649938, 49.57344024412094, 56.541377882803644, 62.360959283767215, 60.348752006407715, 62.55399873179775, 59.535362259034194, 59.81641577136133, 58.567438971611764, 61.339017114331654, 57.25854796748008, 58.13955545425416, 53.357950871990575, 52.014295901021654, 56.667603677318944, 59.537037111097774, 60.055409708330714, 58.98118234449818, 58.989372253417976, 58.1991833256137, 60.93831954463836, 55.54986546116491, 58.327523277651885, 57.83208870118665, 52.53003658786897, 56.59173719344601, 55.19432221689532, 53.22142493340277, 51.962571605559326, 42.58159968160814, 38.07446295215238, 27.14555705747297, 16.067565794914, 7.536314572057417, 6.228910146221039, 1.4445498537632728, 5.393086892943229, 8.4123053473811, 5.570918821519421, 6.821768553026262, 6.29414406514937, 7.857971479815822, 5.72488901115233, 5.482565472202917, 3.9403444336306666, 4.160498246069878, 1.3790266600347336, 0.1734314276085746, 0.25187510786758316, 0.0661900349622292, 0.54851864734965, 3.9673435784155324, 11.385004981871575, 18.218699501406764, 19.972652043065718, 20.66495430084967, 32.64597715870027, 37.65401232627131, 30.58899602582378, 19.91669354900237, 5.866338504898933, 0.9930978559197919, 0.07661230111074063, 0.055498339521187934, 0.1523694795586409, 0.033829983083471175, 0.030312917473155166, 0.05812333213285573, 0.03327890922645888, 0.05195813230989922, 0.006169216038899557, 0.049864609365261374, 0.023774399174257152, 0.0801365890149628, 0.07460364155591497, 0.1207561182579206, 0.08941142399224544, 0.03390436256003957, 0.04923955056696169, 0.028961549866043275, 0.0713238123083307, 0.025163653659664338, 0.04026611756172873, 0.04930898111553923, 0.009354254354782885, 0.1267089125429911, 0.014523206627927722, 0.0601444827512868, 0.01896873345568536, 0.036644283682107925, 0.051001663875555804, 0.038078729694168416, 0.005146399602263926, 0.03328590743964718, 0.04396119710778998, 0.024921916530377446, 0.05182403627963317, 0.053176683253578605, 0.14677716028546134, 0.12242692537725934, 0.24371830926787472, 0.14478543893464152, 0.11364690659026946, 0.1395646263394625, 0.13470888528372013, 0.23147168899736098, 0.25987599225294206, 0.2230669383800799, 0.19445723163024073, 0.09297587788633763, 0.13575811930481466, 0.0945958091066249, 0.11728545650839807, 0.07549411917646086, 0.24461418780828678, 0.25689627794969466, 0.16847522178244206, 0.23559768533995076, 0.17977399210776054, 0.2850632471663337, 0.17438430309055314, 0.08924179680405125, 0.16721451685072916, 0.11400650826192672, 0.14141492785946017, 0.12429552107688882, 0.09358571451758185, 0.17543635631520904, 0.13397569317490826, 0.11372487901920274, 0.13058445176049588, 0.10722603258346358, 0.22647578449499225, 0.24993704331497996, 0.15735674258922377, 0.0899123995294494, 0.11282487126487879, 0.15094435683661891, 0.1564943114475858, 0.1809511781339684, 5.044997622889857, 23.952522200922814, 51.89915080224314, 48.092996535762666, 33.5833098811488, 23.82544525208012, 25.332068820153516, 25.38664467873112, 24.866130467384096, 20.619786247130364, 7.32034985096224, 3.105403223345357, 1.0604049313452937, 0.28861795642202903, 1.3765149948097046, 1.8181585544540038, 3.0720897980274695, 6.571699803875339, 10.292001232024163, 14.369457998583394, 8.577070390024494, 15.747816139651885, 15.409417575405492, 26.106840871995498, 14.510588799753497, 7.054866677330387, 9.77690871684782, 10.636023494505114, 6.018631390986904, 5.886022919608701, 7.3181405759626825, 5.865086778517693, 15.767858470639876, 17.600457476031398, 26.233305931091312, 33.1250476068066, 42.06798884176439, 48.690863809277936, 58.24988780483123, 63.020494061131636, 62.30683057538925, 63.14721015191848, 62.23927559391145, 61.563917975271906, 63.19843238399875, 62.8920913511707, 56.30536886953539, 58.599704388649236, 58.06884688715781, 55.03150463104249, 57.22441550224059, 59.07818255885955, 62.476449551120886, 60.443689054058446, 59.759125632624475, 60.315823708811116, 60.22211828539449, 56.43403437829787, 57.57061958312989, 55.97852168544647, 52.49466073128485, 57.736590754601266, 55.01859611080539, 53.12111423861597, 51.63650889550486, 41.030325812678186, 37.555513766504106, 25.67724916242784, 15.651683749691134, 10.311657209550182, 6.290999795159986, 3.559967192911333, 11.424758203567999, 9.601224776237242, 10.404859588992212, 11.03877148320598, 9.068690461497154, 13.130226327526955, 13.860325524883887, 17.149716346494614, 8.110314223074145, 12.901051063691417, 7.420900790922104, 1.9485088437795641, 0.5309637119212459, 0.5571011610088811, 0.7726273120891664, 7.338934531134944, 11.878308730740702, 22.59943981324473, 29.36204137340669, 29.522797753733975, 43.08199605634136, 47.21917483114427, 36.17801658568844, 21.047985515286847, 6.36030464403091, 1.4264493411587131, 0.1769952533105689, 0.14307303324101434, 0.2381059950998714, 0.1702727551662153, 0.191917083256187, 0.07632242110107215, 0.145007451215098, 0.17984859374982698, 0.13543633173309988, 0.1168280254088102, 0.13939735870207512, 0.20602480688643074, 0.15900338729543073, 0.16441504771430648, 0.1729629495211186, 0.22668059044066938, 0.13261273082706238, 0.122194379387844, 0.22440203044924045, 0.18963715962825284, 0.1800986754918291, 0.18158045807673087, 0.10080769432768708, 0.249827308880706, 0.08238690334462351, 0.20617509801541606, 0.20689088460658828, 0.13948556606567677, 0.1175471214998153, 0.1597896999409122, 0.18232149492588737, 0.13967858957907847, 0.141790418194667, 0.21967054885481635, 0.14909595521467348, 0.2131739393958161], [0.015536355992568838, 0.049221267878648736, 0.08720859179213163, 0.023434788566984, 0.014905829241709604, 0.02089308886488359, 0.019003657488933495, 0.003694863365625122, 0.031017285523815986, 0.03902438862790023, 0.009534462174821285, 0.03968898139353241, 0.049026616428407936, 0.07238470618763278, 0.06837246624091942, 0.03372464599388261, 0.03350628412238533, 0.06074616054613745, 0.05672834730977493, 0.05739626872743811, 0.022659203067662257, 0.0861810687028112, 0.03922327271392269, 0.10109920610463428, 0.019044876849699407, 0.015307298576038693, 0.07702237265484949, 0.025216454354625557, 0.0607564069721247, 0.031901121162058364, 0.0890995572591501, 0.12435261760988545, 0.11584230773751775, 0.024889482282883218, 0.014685033125832919, 0.030490722649941043, 0.034930070020979455, 0.04846221264151316, 0.05727981187162861, 0.01480322517079091, 0.043138219494252436, 0.12995514117421644, 0.15206561844435432, 5.409715290992491, 24.057498555029593, 38.399658818398755, 38.82471430686213, 28.080087246433383, 25.805742086902743, 31.64866355157668, 23.891645054663382, 15.675780830844758, 10.995911744333084, 7.349766156365795, 2.929825431877567, 1.1775509292079558, 0.19035702180718223, 0.21222555318907385, 0.1071388211341635, 0.9918539129918622, 1.8731237082712113, 3.4982133969183895, 5.278246268149346, 4.566049748851407, 9.91407007940354, 12.179023123556568, 7.716956878862074, 6.760934552838726, 4.041347671901026, 4.379001721259087, 4.658117092424824, 2.354904023870345, 3.076745161125737, 2.3776226370565356, 4.089645286721568, 9.253172278404236, 13.125610678426682, 22.02477335929871, 29.056271045438706, 38.02325248718262, 46.88108221177132, 54.5725324076991, 56.99940873730568, 60.197215157170454, 59.1143899579202, 59.36764171046596, 61.10372589480493, 58.99886831160515, 53.48370205971503, 54.803614924030924, 46.18670894253639, 49.58290100097657, 64.84379214625206, 59.10681586111746, 57.00703774729083, 58.070388378635535, 58.218932459431315, 59.28191046560965, 56.26412122480331, 61.99294290234966, 61.2788087321866, 45.403376317793324, 56.82196855545045, 54.69563207318706, 49.51931153574298, 44.70350780794698, 37.2607554927949, 30.34416756322307, 22.09845900535584, 14.374387437297454, 6.683521674525354, 1.5283378093473374, 5.02514454626268, 0.9124868363142015, 4.324723472518306, 6.135465070124596, 4.815533574550383, 5.406225852427944, 5.495726985316123, 7.947117638203406, 4.870282507711842, 2.948554994598512, 3.590194203199879, 2.9880591457889927, 0.7360132122712751, 0.28876541302569453, 0.34401533704611564, 0.5613126834073375, 3.8195084660283984, 11.831999267301253, 12.81787818478, 16.47918128198193, 21.26842664134118, 30.485457220385154, 32.48625432291339, 30.35334198705612, 12.126829124266102, 6.541372527999263, 1.0568349616181467, 0.16156153873570506, 0.07105822494674115, 0.026698754048876228, 0.030344627767560944, 0.08281597386925452, 0.05918998316290879, 0.04075094013504925, 0.03906358168610642, 0.032032610578162056, 0.020343606555533987, 0.11907358233246113, 0.05427239582903924, 0.04984445359197356, 0.03199481371519787, 0.0850369853358115, 0.020292004788174264, 0.07120284702508681, 0.08948738160993784, 0.04461612567425736, 0.018366894782370618, 0.030970768665053675, 0.04138245705455061, 0.030233144737599842, 0.05193722194000598, 0.04174775075948527, 0.027260848080679297, 0.018376829027528727, 0.016822446205262697, 0.05399791418664879, 0.0324045232827625, 0.06441129371523857, 0.020900977655283867, 0.033063960276664264, 0.003993803083205656, 0.06037829278577721, 0.05389499410446133, 0.029547298777728315, 0.0738808835646318, 0.06944822988683177, 0.02799803533801629, 0.030653882140834487, 0.018315534332707044, 0.026461142303061583, 0.05645932021340536, 0.01849874617501853, 0.03865473588267642, 0.044528783990010146, 0.022934397171822288, 0.03942235981324508, 0.03261207182320856, 0.12198177466709768, 0.07239395286887884, 0.02121877390891314, 0.008543178874758944, 0.0025950699355528364, 0.049953831795362696, 0.04630151144679516, 0.006590504546634734, 0.07593530921205398, 0.03208134334624535, 0.08936840049441784, 0.026582339327902566, 0.049334541639132846, 0.06196564994752408, 0.011794995159781989, 0.022640487539672086, 0.05485853736078548, 0.0584006980962811, 0.1082709841730614, 0.09174304323331003, 0.01910093724877844, 0.03168693063930879, 0.09009275960946277, 0.031372664135790644, 0.02562964004614661, 0.04700132510474613, 0.018964646376609322, 0.07784603208663964, 0.12778584830342762, 0.14210469810472381, 7.069280407121105, 27.42850115222316, 43.55984664732411, 42.172469016044374, 28.138479571188654, 24.269810568901804, 27.033330202102665, 28.042071634723296, 25.222601352199433, 13.60205804148028, 8.504511444799363, 2.9346737265586857, 0.5117094402592028, 0.08263634157276924, 0.36324028286241716, 0.15052590429061843, 0.3980430137486227, 1.0716283032971046, 2.695685673144556, 5.655297338962556, 3.9394038002337184, 10.142466752759873, 11.157593804021037, 8.044568434838327, 6.220944302697336, 7.975945097784843, 5.928417367319907, 4.884736441796826, 5.564815123235026, 5.004737925144934, 4.771492711959347, 6.32871485525562, 11.49216119320162, 16.89828065133864, 25.192301042618293, 33.6632203286694, 40.55604850092242, 51.36277844828945, 56.31302533611175, 60.092703603929095, 61.204220940989835, 59.92887796894197, 60.61763440409015, 62.29732275009156, 60.59238218492078, 56.000024118731105, 57.53218820018154, 49.365711519795084, 53.24581423113423, 59.05139277058264, 56.92864133465675, 59.461037266638975, 59.28922176361085, 58.489544622359745, 62.84162221416351, 57.039369844621234, 59.187624531407515, 63.685092618388516, 50.075252594486365, 56.029783141228464, 55.476336709914676, 50.06070060114707, 47.07890695141208, 41.15179377217447, 31.80958663263629, 25.49939517051943, 17.818005854083648, 7.856913910758111, 3.514214460888217, 1.7928527704169674, 2.304917093246214, 5.354415755118094, 7.302867356807956, 7.008414047379648, 6.296974055228695, 6.075577341741131, 6.872856934224406, 4.541364802468208, 3.6879237332651695, 2.3903392063033198, 1.7404440213595669, 0.48645737430741715, 0.2331972560815273, 0.1496119001099179, 0.7905197552134915, 2.863318458680184, 12.244061904568827, 18.681176362499116, 20.946825627357732, 19.448160548363965, 29.46487219102921, 38.87827819393527, 36.898034311109974, 16.63021214546696, 9.025782673589646, 1.8224073393690972, 0.08871584680051574, 0.05782638113164614, 0.009379834030574609, 0.06885710878357773, 0.10028780407963261, 0.019780330833107717, 0.08025186226492928, 0.024829650815996914, 0.027529007582474622, 0.0407389048937588, 0.042692689570568265, 0.03427290064733356, 0.03594699045342784, 0.030540593058591893, 0.03355196594531017, 0.04702084885549642, 0.04455289277698725, 0.04373431250813507, 0.05636428700639837, 0.02223654661417729, 0.029968643305642955, 0.03415253674311023, 0.037818451321894125, 0.055930003253442634, 0.04768641455279243, 0.03252648064986833, 0.0514364417552227, 0.06926036980603972, 0.03486807818614668, 0.07172793901014714, 0.04809750116340095, 0.05586713807837618, 0.07964161960708518, 0.033546565025443995, 0.044723328187941544, 0.025915036526238246, 0.08846718232117354, 0.141325663294523, 0.12397721154435028, 0.23855830873212508, 0.1788784966113106, 0.1282816144427465, 0.171864808446938, 0.16691149843315925, 0.23685750160967153, 0.1980610164783655, 0.14251725177370733, 0.12403574066176531, 0.10886691630847993, 0.09860480850141856, 0.233028793346978, 0.2105401903991738, 0.18032102485097226, 0.15140620060265064, 0.2266615301731133, 0.1267242266405975, 0.1620858493110826, 0.16387590567671484, 0.17624370573509127, 0.15422652265237224, 0.24155702201589463, 0.124171813198876, 0.11213251930331031, 0.18296666353219943, 0.10118423420335017, 0.18432755744264973, 0.1964356077294196, 0.1556373195302102, 0.22522205096339026, 0.24761585819144405, 0.1164390136217398, 0.10520162992179395, 0.191536981071676, 0.1594842453637431, 0.09778555407519303, 0.2204313660941778, 0.14854953534180118, 0.15105510250695292, 0.24035855406715026, 0.28253619889578513, 8.896003211698225, 32.60426863547295, 50.978339102960405, 52.09793652257612, 38.18892163615073, 37.32325846149076, 42.65667384670627, 36.1064725537454, 24.558047902199533, 15.950052565143956, 10.66023628557882, 4.278326736342523, 1.5738385290868822, 0.9570096601401606, 0.928979667444383, 1.0500410487574916, 3.4355569654895417, 6.917358675310689, 8.372885527149323, 14.017971465664527, 11.46553712506448, 21.909190916245986, 23.617689071163056, 17.485006432379446, 14.046494941557608, 9.526156494694373, 11.051734916625485, 9.860297326118717, 8.311603396169602, 7.26579507512431, 5.0722433866993075, 6.680248946912828, 13.233049300409133, 16.993456963569887, 25.682762053705034, 33.42510500261861, 41.46690130233765, 50.98542682586178, 57.367229000214614, 60.18362414452338, 64.27127122879028, 62.02603593949349, 62.69227404748241, 62.789011463042236, 62.614618962810894, 56.52182486749465, 62.20392719391854, 53.298279854559134, 55.08646488189698, 60.373694358333466, 58.309335247162856, 59.83505487442017, 61.02401548816312, 60.63177062619118, 62.41662556125272, 56.796849696866936, 58.483559085476784, 60.01812365747268, 54.80590166584138, 58.198430230540616, 55.7608340632531, 50.14773407290059, 48.030976018598004, 40.34626445462627, 32.06876900888259, 25.376224902368364, 17.920516998537128, 8.638622183953563, 3.472488286995119, 9.628080264214548, 5.8008658116863625, 9.791750965579864, 13.172596750720857, 11.851623865865893, 13.116498031923848, 15.09167323189397, 17.578704011055734, 14.507093967929965, 8.30613463155685, 8.883407500482376, 6.432190412475217, 1.7001310038951136, 0.5411110061310953, 0.614834221140031, 1.0072109115219887, 4.621389489020071, 15.245809631962931, 17.713045189457556, 24.634043824288156, 30.64731578673086, 40.37616468244984, 46.912080703243134, 44.29489881761613, 19.564811837288644, 9.781286081960126, 1.9649471294495369, 0.28045001890390153, 0.1867664136713551, 0.12640149678073584, 0.09399393978979319, 0.25871515454303834, 0.182687608344901, 0.2684165855809566, 0.2018092395437341, 0.140251899138093, 0.1839959179802287, 0.21303172283355268, 0.14514943795098414, 0.1711501863094107, 0.11467781578821522, 0.3060499500603445, 0.14494640932929131, 0.12569411417409299, 0.13266254186389909, 0.15481585877076273, 0.1264591755405549, 0.12811847601927098, 0.12790623135984908, 0.16438369939644493, 0.20872937305079353, 0.15198369300173176, 0.06637316828052844, 0.13552334399953966, 0.2245777710190704, 0.1434977677079939, 0.2460373646669811, 0.15737885188671852, 0.17086138648371543, 0.1913884519449165, 0.07986832800651751, 0.11340640094732085, 0.06965881979633724, 0.14771514301819189], [0.04337570675077938, 0.10447849654742788, 0.08729680681661253, 0.029054152659110488, 0.040423230703679786, 0.010308806611705693, 0.026085696017910397, 0.03358085512093479, 0.013286067518375575, 0.034489818443093574, 0.06888199131935835, 0.009122202492078707, 0.07123779595619248, 0.03596138907596469, 0.04475805495354918, 0.061398365670034004, 0.023905721966237314, 0.04543874705691011, 0.0432233854887947, 0.02933200317314796, 0.02684126172455088, 0.16584455245925536, 0.08382298112396272, 0.03994819490359195, 0.008358025957169312, 0.03719086443344432, 0.041114372246327906, 0.0475869725097812, 0.04402911080227744, 0.025969417277543295, 0.02912201081222344, 0.03676692669790599, 0.02021260935092165, 0.0038262766517413362, 0.0492383707915583, 0.07235636859531365, 0.01525469802154769, 0.06240200213787537, 0.07863984473289982, 0.04744048500733991, 0.03398255332403126, 0.05002231239491413, 0.04829928872265643, 1.1674431038479651, 9.268214568015068, 21.663007274750743, 42.14751881937827, 37.84490623781758, 27.547521552731915, 24.294076311972834, 13.632016124263888, 20.899814059657437, 20.0788894391829, 12.763768107660356, 8.309870689145981, 2.6417643600894563, 0.613551177084446, 0.3439603932201863, 0.22437294975163477, 0.8844338609806953, 1.0841706947934244, 0.577076321407672, 4.797705421524664, 2.195269686560477, 6.984898947900342, 10.488322723296381, 4.6948422443482185, 6.751434081985105, 4.952419390601497, 5.424401135213914, 2.0163464810579055, 4.473094478730233, 1.176130418335238, 3.212104194587277, 2.1167406487849454, 3.213068852501531, 5.715151236903283, 12.148370781252462, 19.458711724127493, 25.941524736342895, 37.39348065468573, 46.94329100270426, 51.36117812125914, 55.90329454791162, 56.815037727355964, 61.39563260539886, 59.00044118204425, 59.045124823047274, 53.67987940388342, 50.81346619513727, 45.515991487810695, 35.83006312770229, 75.79266486629363, 60.03224419009302, 54.953622048900975, 60.76855936358052, 56.611474560153106, 55.985872207149384, 66.83674843080583, 61.54533770776565, 47.30992670982115, 48.78290222537134, 58.207522284600046, 48.490775862047755, 42.370823275658395, 31.047015113215295, 27.369620492381436, 17.580659312586633, 12.407740450674488, 4.7920748591423035, 1.016013568207141, 1.8511733893425235, 0.9895011037588121, 0.6756877718913941, 3.1509152198991472, 7.060126085435191, 4.513959202074236, 4.6014976789874416, 4.163724885832879, 4.3069816116363775, 3.793848320361107, 2.1101437124513813, 2.319907166304127, 1.0151234353261611, 0.31982562054068814, 0.08187262086017479, 0.517376866792479, 2.5622927277318897, 10.956018297903, 12.810062862211659, 11.923921973474565, 15.927645044942057, 31.449085512468894, 36.92711476356753, 33.68808423319171, 23.736438828129923, 8.814119811980955, 2.493205815553665, 0.1796003659406016, 0.0438630152794142, 0.07870316189984161, 0.03768853813169464, 0.002870803413492057, 0.10408969160409705, 0.04375900735237426, 0.03987283483448048, 0.024358569944818175, 0.01928442488274267, 0.06624350789934397, 0.0293641712050885, 0.0286981784137747, 0.042795981205399, 0.05654649718874886, 0.08173395894588002, 0.011310752898064113, 0.02362724709054155, 0.0168214445453017, 0.024725365182084423, 0.03595117329349441, 0.05129027600970961, 0.011217492226991924, 0.08261774861884695, 0.04701044155104507, 0.04729364893489307, 0.05910523851672488, 0.02345072511102884, 0.05245560682528923, 0.03307441737683069, 0.042157653764250784, 0.029877658873315782, 0.09045710336537131, 0.015738363802102546, 0.011838398828742006, 0.04965522987467628, 0.03336441996056707, 0.024336521934357383, 0.045338259303882245, 0.04112556479090164, 0.0519138332756777, 0.05053858287752636, 0.041787633296823314, 0.04400828087161626, 0.03849246696899495, 0.047098851927946654, 0.011875309902543743, 0.01698737344404142, 0.061210628163309834, 0.025762703772934697, 0.016556835861035412, 0.012809556041423593, 0.04293780323238142, 0.034550956089890776, 0.0728529008225568, 0.017583895467161652, 0.07420401179021405, 0.010940008477548198, 0.0782131873852303, 0.08917426615352593, 0.03103620023466647, 0.017395380381194335, 0.08706992987783686, 0.00969128420336112, 0.035800709794726104, 0.020890924666497498, 0.022041425935082862, 0.03562069445427868, 0.04199682892630658, 0.029201626499754288, 0.04195872754339249, 0.03649739015306677, 0.05250554809707308, 0.030336154835118406, 0.026877603020458937, 0.04363932909684316, 0.015902119883967024, 0.05209101026036567, 0.0363020109192979, 0.061273700182115844, 0.05458522017203993, 1.5025396452796076, 11.811840245800635, 27.093440524993408, 49.07944125513877, 42.204703054120465, 30.281384145059896, 27.843499683564712, 20.281732851459136, 23.702361276072843, 24.612011871030255, 18.209642748678885, 8.833808149060896, 3.0612086528731934, 0.38795440187377317, 0.26261251960550586, 0.0447861205846552, 0.6305958366682453, 0.5775254940794361, 1.8849682855990626, 4.045346528291702, 3.459292207994769, 4.473009657475257, 6.418605773679673, 9.373568450250934, 9.68268750175353, 10.381610720388352, 6.197365954999001, 7.566258436249149, 5.473529802214715, 4.142395036835825, 3.74376087900131, 3.8220452589373437, 4.474289821040246, 8.312373161315918, 16.015924849817832, 21.234551091347974, 31.27078437036084, 39.886366551922215, 47.73439384275868, 53.485078811645515, 59.1064275464704, 59.26465595922163, 62.64423677998205, 60.209143084864465, 59.9311686331226, 56.787012392474765, 55.34376452046057, 48.1909381189654, 42.069012580379365, 63.93660676094794, 59.27672116987167, 58.612361877195305, 59.38875975147371, 60.1399407079143, 57.51834615584343, 61.467666933613444, 65.4501905748921, 53.203413409571496, 50.465438212117846, 59.27610928012479, 48.441624641418464, 44.48574958309051, 35.68724570735809, 29.893659814711544, 21.030064205969534, 15.739818426870531, 8.580893720349959, 2.8300462182491057, 2.820535206025647, 6.10431605769742, 5.362523294264271, 7.768942502237136, 8.303244825332396, 6.117894322641435, 7.768449754484239, 6.317464517008874, 5.497416546267848, 3.4555674272198833, 3.934290500417833, 2.2415860141477277, 0.3588067481835043, 0.2722393336795992, 0.09585714223043573, 0.7235358463179681, 2.2386881180347937, 8.757161113523669, 18.19567322731018, 18.285268006786225, 9.549010184503372, 28.938821554183964, 42.45640939281833, 41.174323866444254, 28.370548563618815, 10.766122629565578, 3.352830256185224, 0.18745990710393076, 0.14574907029107695, 0.08090216366033401, 0.04928776431047628, 0.08407619616557514, 0.05256986117831642, 0.02729532969815116, 0.060105508028139035, 0.03890626936129505, 0.013754929607403616, 0.037370535034325816, 0.08179961268099085, 0.005372795820867102, 0.05845944171831493, 0.07306646315320846, 0.012430201750248672, 0.030402582319032763, 0.02652337928603013, 0.07341459648863924, 0.0295544731911392, 0.035368402548615015, 0.009990203092926213, 0.034663199462116726, 0.013515756957443252, 0.02928862535965539, 0.027771054977370847, 0.04044253611937165, 0.08507430913948244, 0.061053855930485075, 0.004325082963107214, 0.013181647819076336, 0.057110690301464456, 0.029298237847885298, 0.019608246417896404, 0.043841921048419136, 0.015360094482950387, 0.07092478009121073, 0.07063035718015126, 0.11008292767069033, 0.14008343640354373, 0.19172059702536753, 0.13001549358089126, 0.10994356095550523, 0.07858746730151676, 0.1988571044057608, 0.07438309250339385, 0.10782743458666148, 0.15412035818782546, 0.11123941400118413, 0.13057950283250502, 0.14835896330975717, 0.0943088785354649, 0.1684881993118794, 0.16014067546254204, 0.203535235637138, 0.17139504333176922, 0.14589085784410277, 0.18972213410081404, 0.10494192611546287, 0.22981672457629637, 0.1821350291251175, 0.09674699931976297, 0.1830693039922945, 0.11295327526186744, 0.18968312490370967, 0.1271075923596659, 0.21246806598238407, 0.1268577940701958, 0.0989488356055752, 0.15912962326359364, 0.14792312056787554, 0.17418830715600522, 0.20201959196598301, 0.22906459477399627, 0.2529848781564544, 0.1037100643940991, 0.14781245150633399, 0.14620424909216745, 0.11167130372937649, 0.15282119564231367, 0.1415222261341349, 1.7575435941257787, 14.57585802001338, 32.54163426737632, 56.11479266997307, 50.60557665363435, 38.266768916960686, 34.1887669409475, 23.52979071678654, 32.919719373026204, 29.504356730368833, 20.33641657521648, 11.012180755215308, 3.9490285611921743, 0.9828333809010446, 0.7119399104868213, 0.7287824454326784, 2.3589082735200084, 4.069431597186673, 6.407043116707956, 13.682872595325595, 10.367135213267419, 14.756248804830737, 18.669777954778365, 13.13903695152652, 14.524601467194097, 12.964981775129996, 12.571741611726823, 7.9037528941708235, 9.457197304694883, 4.599479129237514, 7.544049976333496, 5.359883539138302, 6.012369327006802, 8.73284928260311, 16.013008567594714, 22.37071660257155, 30.19335243009752, 40.0709689817121, 48.71774381206882, 53.449922607791045, 59.498919517763206, 59.57540965849354, 62.73240773908554, 61.51615135131344, 62.074661562519694, 61.06693798495878, 57.66590964409613, 49.839192590405865, 41.87808336750154, 66.8729519074963, 59.89762452340896, 60.61851693737892, 60.00379131686304, 59.95424001447616, 57.102049319974846, 64.18450840057866, 60.30723764050392, 56.24310124304987, 52.647123259882775, 58.970780218801195, 47.798759937286384, 43.29923260596491, 33.76770050294938, 29.212504932957312, 18.897036160192183, 16.785196758085682, 5.747438226976703, 2.491233108505126, 4.429789060546506, 6.413039440108884, 8.03416827032643, 11.640516019636586, 15.034720416991943, 12.3400354385376, 12.818204722096844, 12.40313264631456, 9.939800827733933, 8.174784750707689, 6.732157593773258, 6.5295103000056365, 3.032689344498419, 1.1843930136772896, 0.46942812841265436, 0.9452404045770246, 3.6887903319251154, 13.156248311842642, 18.331481372156453, 18.774773920736006, 22.47305908510762, 39.1832346300925, 49.88595900997039, 46.40858565607379, 33.84728931611584, 13.44594672802956, 3.717343715890762, 0.3302476645237015, 0.2744095994820518, 0.28806937618121026, 0.133674651264183, 0.23059603517814992, 0.13948239446167024, 0.15785281516371236, 0.139007251409273, 0.11055896704595898, 0.1208732224580261, 0.19296291584689773, 0.20232970435773173, 0.12193790847255338, 0.15194103722610783, 0.13312538154423237, 0.1397496978602102, 0.1359796566107581, 0.19058079608986456, 0.12858186728290974, 0.06897987437344368, 0.10082387410464788, 0.14961422901720772, 0.12731174713060742, 0.09546554872706052, 0.15212359597846387, 0.10504307270410562, 0.18767989691226714, 0.15697883141617622, 0.09943614413421001, 0.141575331349046, 0.2349709641308554, 0.16280011904816474, 0.19580894780735816, 0.1000200410283381, 0.1105502566262599, 0.17991676025332945, 0.24954702795272876, 0.18192954902206698], [0.01980216433894971, 0.04625354668185596, 0.06768585227790379, 0.03207992799880524, 0.06177787796684331, 0.013813759414328924, 0.006911971797836164, 0.07264659334454807, 0.03236082562756154, 0.03499857360316861, 0.014965039219767337, 0.030479750355645537, 0.03733418799275833, 0.06439975643109891, 0.062447078751340035, 0.08852750408433138, 0.051733515330500184, 0.010158661039425962, 0.04170672292070043, 0.032968743208555445, 0.057478588705341664, 0.06581597721144077, 0.05535008235564155, 0.029100636959136016, 0.04378528416817708, 0.01572957007034171, 0.06905505824233256, 0.02875556606018255, 0.008998285855106529, 0.0833518140678925, 0.043631246869242, 0.027223692816351692, 0.016890375221508647, 0.03350355684937489, 0.0463143510804061, 0.07355675176386872, 0.08355423748012512, 0.10957587705624681, 0.05606376603546162, 0.046800671355618585, 0.017315190127720276, 0.0231663839170529, 0.05544962015964332, 0.11895503022617872, 0.9210499219836727, 10.144158274896684, 28.681941609228815, 39.906723653116536, 38.36465950935118, 23.413035485052294, 22.256922760317405, 23.552775805996312, 20.927556983886227, 20.40084150529677, 16.810523502288326, 7.984082545003584, 3.64115878458946, 1.5820419211541454, 0.20363570040752813, 0.07787914240672704, 0.21559592636842884, 1.4844915943761028, 1.7561457594556196, 2.3875192672975603, 4.770044376773219, 4.3668884615744314, 8.307234856390185, 4.533693136707429, 11.46873385675492, 3.2340890794031085, 6.833388084365476, 3.4093126318147107, 3.1858181857293655, 3.297149269811569, 3.078737234877002, 3.127364573940154, 2.1580128083305974, 5.188003317002328, 9.195683079381144, 16.60241626924084, 23.57932632969272, 34.44217558830015, 43.46285427770307, 50.42353553156699, 52.07066428276801, 55.71182404795001, 58.742992493414114, 59.07919060799384, 57.08125291332122, 52.454095578962765, 41.5234265788909, 28.426381541836648, 67.5600334905809, 62.99284919615715, 55.083409355532744, 58.35855314808508, 59.04030030773532, 68.63149950581213, 57.180692841929776, 54.51511283074656, 51.71297550201417, 52.649472759615996, 47.040993321326475, 41.31414067360663, 27.60649831064286, 24.084092224797896, 16.247688877967096, 9.802209965644344, 3.095647062986128, 4.131112339035157, 0.9765182423495478, 2.697836848035936, 3.3295277001396304, 4.1048091698077425, 4.500752581704048, 6.162639250678401, 5.035894782312456, 4.3812315887020485, 3.590889443312922, 4.657827327328344, 2.166181634510717, 3.51404972134098, 0.4403834982264427, 0.47534499317407614, 0.15878892864190763, 0.5891404288911051, 1.589413280448606, 8.743611285763404, 19.21643476332388, 6.596214617452314, 20.318450158642186, 40.32200851748067, 38.86254556717412, 29.81861898975988, 28.920335423561838, 16.050901605236916, 3.8459945157650983, 0.32625772539646397, 0.004233123205091444, 0.03715741320423061, 0.04613493328853961, 0.04237747886368344, 0.0524321913478836, 0.05797966766441542, 0.11523846957472064, 0.030648282038108, 0.012459326497910005, 0.06594563759262524, 0.02323834447100038, 0.04550031371294491, 0.04001544976246454, 0.0323427957482636, 0.032935391570771896, 0.056539330436217214, 0.03516579910572018, 0.05625397034530198, 0.07284550807408749, 0.05266328943112204, 0.07986665027396334, 0.03528910478757274, 0.06160315246351304, 0.023650425080690655, 0.02961343897867107, 0.036523245620511235, 0.061200082963032115, 0.04107052137354209, 0.038147535881087664, 0.07355233143654562, 0.03900591441760621, 0.014133478548648137, 0.03507826972993151, 0.050654878854871764, 0.01688454146196525, 0.057393740637287985, 0.030042641653469013, 0.036171933020194696, 0.06875075279704987, 0.030228078981200536, 0.03621787914345342, 0.059414856781762455, 0.0939638555170067, 0.05431932637528066, 0.018317443806858315, 0.06555476421189886, 0.08241738598313063, 0.02503410436122889, 0.011119361151941122, 0.03083940565345749, 0.06595875301788892, 0.047109998507244934, 0.03590651036750886, 0.013560825910028673, 0.040574452629493135, 0.008674931633586605, 0.1133257625324111, 0.06127820860955024, 0.09880052864431374, 0.06779623022603412, 0.017308659228165785, 0.039314268637568726, 0.003224556722054859, 0.028448435665679075, 0.0137725735699097, 0.09464426416783564, 0.06352200736141493, 0.06993149347122639, 0.013888042172296874, 0.031588101466636986, 0.06656040783010184, 0.022859106050624002, 0.012886421473306275, 0.007337351215086998, 0.06471046637142859, 0.052215959200815815, 0.03885435158266656, 0.06756491763817687, 0.04717973166055257, 0.0049276738390026074, 0.046238385801834446, 0.08379301176436486, 1.5353687804552818, 12.75912009900616, 35.60594674079649, 44.212403528151974, 40.21316666756907, 23.67049986316312, 20.623508576423895, 27.263051655984697, 29.833612249743556, 28.39938779031077, 19.677103411766794, 8.654492093670754, 4.446930308495799, 1.5781291117591243, 0.27291885366843593, 0.2378677264336617, 0.03170670145341466, 0.7339004643501774, 1.4378601288603199, 3.234884585103681, 6.009524137743059, 4.775387625540457, 8.575731881203192, 9.779706347373224, 10.137743238479862, 7.213689819458993, 7.01003888922353, 6.80143645694179, 5.505185290690392, 5.8647278816469255, 6.70708139096537, 3.852484077215195, 4.741064925347605, 8.806450597701534, 13.065922990922006, 18.277252643339096, 29.330185844052224, 36.89666932629001, 48.14825488675026, 52.44652932690036, 55.534838861034764, 58.0949463382844, 58.791017993803955, 58.0738792880889, 59.93592646814162, 58.18547464186146, 45.59774937168245, 31.315303271816624, 59.592895584721724, 61.866050304905066, 59.3626916793085, 57.92090685136857, 58.293508483517556, 66.95459996500324, 64.28514857445994, 57.194013211034964, 52.98331352972215, 53.77498119108139, 48.68368194949243, 42.53238570305609, 30.96804407335097, 26.907200505656583, 21.55223757989945, 11.468789750529874, 6.598224341869355, 5.772295267351213, 2.0486054016697794, 6.580479539209797, 8.852813013138311, 8.432876217749811, 7.619914989317618, 6.8470041021223995, 7.52877087362351, 6.23960497879213, 5.4776816310421115, 3.7630942415806556, 2.319450210179052, 1.2214644373424592, 1.0488009669127003, 0.37024977286496474, 0.260424419276176, 0.5071434336564233, 2.1635963022708893, 6.982119458336984, 20.905946685421853, 15.714742714358916, 12.499999500090077, 30.291921592527824, 40.83894552723054, 34.48243871811898, 34.25252114572833, 19.92246335552585, 5.137081636536506, 0.5389203011028229, 0.04342183673513993, 0.0561848538927734, 0.05514328075092166, 0.0828566148336376, 0.02874398281076743, 0.0057865043673964766, 0.09323149844403229, 0.040594972294544986, 0.057844855341940164, 0.030819020053792386, 0.025378669642152327, 0.012696530301904967, 0.06686770867916846, 0.021736884917763453, 0.07471659355947087, 0.06188256388169624, 0.016656398562894716, 0.04298517810961893, 0.07492120798316694, 0.019316893604193485, 0.030511546834942796, 0.06475499906246701, 0.059345721177035765, 0.030488027935667388, 0.02196636464026186, 0.029990631944289612, 0.06098045321602014, 0.03694236849344546, 0.024637581082060937, 0.13355123449958142, 0.07695584557950497, 0.09382976714761988, 0.09175338542028781, 0.08741542787080811, 0.01757733966974962, 0.034758868522100875, 0.05624753903717764, 0.017381910640265674, 0.15066274291565343, 0.19338674633012665, 0.18867722081561245, 0.1155789573526671, 0.20987875008535004, 0.1258481974383035, 0.13938047412422397, 0.11513201399676262, 0.12372418036383968, 0.15868158440195745, 0.16202339782349526, 0.2381880737600788, 0.2428840088748163, 0.21304934285581115, 0.19850493378696904, 0.11724416436927936, 0.19190340092585934, 0.09137425616744066, 0.14427251242581876, 0.1344334613531828, 0.15456000072581155, 0.19511053609030862, 0.13248278699334592, 0.18356487094875307, 0.143230969927484, 0.18907103597396807, 0.1544646534227556, 0.23310789958603922, 0.17888502368042547, 0.16843042096063016, 0.12191589110560956, 0.18445613763986096, 0.1538893673568964, 0.11841486163076856, 0.11622918980015863, 0.1783922452840113, 0.25121546019950225, 0.18020355292866308, 0.11819340093361756, 0.17633857806363415, 0.05317399428496438, 0.11443121208538932, 0.19007163873362928, 0.1987643618016474, 2.3518747283566386, 15.755114689950021, 41.341514895039225, 51.69108475408247, 50.35231313397808, 33.89161209906302, 33.711198760617165, 35.1720816089261, 30.74396298777673, 30.047063712150823, 23.04335209631151, 11.746787736492774, 5.697381919430149, 2.3699112572977623, 0.4480034070870569, 0.41166405704232956, 0.5909460674851172, 3.239410264838127, 6.979052655158505, 5.636375825251303, 11.816840287177794, 14.716952539259388, 16.70447437993942, 11.559754417788598, 21.425625431922175, 10.655136223762266, 14.376679082070629, 8.163100009964358, 9.543036414730935, 7.916191220283509, 7.549147096372421, 5.321656609735181, 5.802564688267247, 8.207819932891477, 12.84028668557444, 21.318668280878377, 26.922062366239487, 38.48950070719565, 47.20217527881746, 54.894005944651944, 56.17109437142649, 61.52404708247031, 61.74525699307842, 63.029801845550544, 62.46277224633002, 58.907441785258634, 49.96948980516004, 37.27375814991613, 61.56536140749532, 65.25900640795308, 60.895738294047696, 59.759031495740345, 59.1840002613683, 64.8443530451867, 61.66278916020548, 59.47004302855461, 57.89231669518256, 56.91328133306196, 49.53504808487431, 44.32096688978134, 29.491230518587177, 27.51276739182011, 18.91582431331758, 11.513471430347813, 5.327644598099494, 7.226337011783355, 5.115666966284476, 7.770832594363921, 8.966611758355173, 10.229559060065977, 12.607099817645166, 13.78087889763617, 12.0516235597672, 12.772461060554752, 13.56782457520885, 12.518135559174324, 8.098718716252236, 6.572789732486972, 3.285168144972094, 1.4689664855118723, 0.5979921764904453, 1.165089314022372, 2.3087220374614965, 10.850506540267698, 22.424229498832457, 13.219193527775428, 27.689105387656923, 47.07765963769729, 48.525131902387066, 42.75777686026789, 41.762424438230454, 22.668006766226984, 5.350254120365267, 0.7299841615942217, 0.14040631182011098, 0.14700847287331859, 0.21730810223567873, 0.23605519304833106, 0.106024055952026, 0.14411518860968853, 0.20687387745466926, 0.1437056226836097, 0.1801058001095249, 0.1080783207209841, 0.16230913329749339, 0.10207995952617738, 0.12903850165105638, 0.10648362443692262, 0.1261670891976645, 0.16976065603235077, 0.11541873006330383, 0.15473727347149005, 0.22503192326234234, 0.1371448457000717, 0.26761010950130804, 0.22963614233078497, 0.18773710835845242, 0.14204845192932314, 0.1966400153093761, 0.12632883334111783, 0.22127269917438108, 0.1691121319609304, 0.1589397407106815, 0.208022978697573, 0.11744748410438338, 0.16566085989677137, 0.18226995253034178, 0.19466580672850534, 0.15728359651421348, 0.12468067944170007, 0.17193659088544308, 0.1263263358944847], [0.08398515427665365, 0.0733093360078431, 0.061725094508860386, 0.010734521671228353, 0.04285299729916357, 0.013970448335091916, 0.10242450757012253, 0.12241400913485598, 0.05747378150361681, 0.12499872084346511, 0.049967682665033694, 0.03562396564971536, 0.028328613768662178, 0.10547854006290437, 0.01840046283999278, 0.03888473079930391, 0.027924473660307068, 0.08205541709978735, 0.0484500318435171, 0.05523703076065548, 0.0681192358775485, 0.05379590063145565, 0.040722261633603804, 0.09482959615847758, 0.005255821376903764, 0.02038848781657796, 0.013256650699693109, 0.04015619160547372, 0.046679560515669086, 0.13437104050911244, 0.016029131516153296, 0.03712266345598525, 0.05700230801237687, 0.03526395412101861, 0.008124683236312723, 0.05908935751405455, 0.036979443318541014, 0.12288505361685831, 0.029857175597440333, 0.07488324832651885, 0.1385396160185337, 0.10149782463427513, 0.08094910186745467, 0.07816371342708027, 0.0780082282219683, 2.7750893994685146, 14.72100434764739, 36.55343840199132, 43.86402645418721, 41.02614064370432, 29.666146655236524, 24.79361761000849, 21.39654694064971, 22.26649530472294, 18.974110734078195, 15.701942059301562, 8.502594386377643, 5.664798790408719, 2.262186792589003, 0.8703197022118877, 0.24376395278640334, 0.16147166130042848, 1.1461733161441743, 2.262012737412607, 2.750177691059728, 3.1449100711653313, 5.957740026135599, 11.849807808476111, 7.694019838686913, 6.300547824751947, 5.953969157511189, 7.250661100110701, 6.326968910232668, 3.262451738119126, 4.988540007222084, 1.5072801973550551, 1.5132104533333934, 4.112639936708635, 4.067762628678353, 6.212734781926678, 13.640910098629615, 20.60217872742684, 30.19917714980341, 36.73590706240746, 49.66405876221196, 56.564017803438254, 59.392431089955, 59.77909441917174, 61.79043093035298, 52.81926431963521, 55.156859659379535, 48.1421281445411, 48.55914277415122, 52.41247530906431, 56.66278308437717, 64.5227304581673, 61.81223538614089, 50.798431750266786, 51.006631159013324, 59.01809184781967, 49.44703402057771, 44.44566688229961, 39.17319336245137, 28.09100320262294, 18.654749393463135, 13.585316384992293, 10.664629340171816, 3.17144196360342, 1.660436250029072, 4.410062970653657, 1.7878906044267842, 4.448893945063315, 11.588907434094338, 6.619511044794514, 7.325737226393915, 6.472589844657529, 5.139475753230434, 4.200007300223074, 3.044051470295076, 2.051657373386045, 0.9305975225663955, 2.099955601076926, 0.8018300934664665, 0.1646438475337721, 0.41021596700433766, 1.9676084576114534, 4.832684628425106, 20.885909257396577, 14.871493924048641, 24.39711109284432, 44.96642428059732, 24.808061738168043, 35.99395544298234, 34.93247185983966, 20.16024724129708, 6.174036677806608, 0.6880542696002991, 0.03060834970505488, 0.023615644688928322, 0.03803027080251806, 0.043692813525276805, 0.03512896176788115, 0.055972429202689286, 0.08546286127379826, 0.04910682200364048, 0.04411497776727042, 0.02329071232628438, 0.01162794011179358, 0.0429481262671611, 0.014134273364869578, 0.08643067547030027, 0.026813215245642973, 0.07744003613028796, 0.038051912786378976, 0.03980152354004883, 0.023292246417352752, 0.014035527504259541, 0.09803496165982178, 0.018188748696458437, 0.016483055848267772, 0.04589840747235764, 0.04345981554398614, 0.03232992930157531, 0.020827764547580195, 0.09840774004377666, 0.006661905377592531, 0.05140036284442871, 0.07148210905612477, 0.08537333623896684, 0.04678218948444532, 0.03477306030089817, 0.07244882008601582, 0.07466557976459304, 0.09371695303989035, 0.025858932077103568, 0.055494168172440225, 0.07583551093815796, 0.044693653772194544, 0.05627282376911852, 0.06239817169825397, 0.03996305700932299, 0.02167369415532918, 0.04466091117431079, 0.03042374166750139, 0.07300591156367334, 0.027836626358029824, 0.027043102909961057, 0.10501007729720686, 0.06097588350155181, 0.024814509088173512, 0.07460560274100111, 0.03485028579410526, 0.02010112249052092, 0.05718967013601815, 0.06004526287377362, 0.02526193507947028, 0.022978184842354348, 0.043042994765264374, 0.06184313716667314, 0.05553111276258865, 0.05056434641441992, 0.037148982406623905, 0.038961420030964, 0.044030531895376986, 0.017106339237802935, 0.12353451997642556, 0.029123203994165507, 0.06309529255715109, 0.09406088055261681, 0.032839868067493366, 0.0802068162949816, 0.02328524820416445, 0.03149935018060909, 0.04171849003121738, 0.037103365701172626, 0.038081667641358036, 0.04691473418666471, 0.0361141968037813, 0.024236528308040673, 0.14707843202256388, 0.08535177086389835, 3.6509281829480207, 18.49195141946116, 42.81594953229351, 48.95782424557594, 42.965101580466, 33.06208179843041, 25.355106861360614, 22.74183753998049, 27.359100695579286, 28.97402874885067, 21.532651224443992, 9.721386586466144, 4.890462121655864, 2.2451747377072615, 0.525801872774478, 0.2460439683448884, 0.07262161121733728, 0.6219299113558185, 1.414279697402831, 0.6243705449085082, 3.5098226320359016, 8.815463223764974, 9.223021018889643, 8.225602488363943, 5.039759787821001, 8.776630778466503, 7.544206380844117, 7.905266929057337, 6.5612682604020645, 7.398312841692279, 6.120991524188749, 4.1388237187939305, 3.637047895500737, 5.731610482738865, 8.908191977008697, 15.379538920617874, 22.999776524882165, 34.00141492966683, 40.115727147748395, 53.21030501396426, 56.51818490797474, 60.10501200152982, 61.704138786562034, 64.29521337632211, 59.022912440761445, 58.29656008751162, 47.683571692435976, 48.66999679996122, 59.3511010754493, 58.07451078968664, 63.23907990609447, 64.6325058321799, 57.95487065469065, 51.97636658145536, 58.96856015728366, 53.64046350602181, 47.8575131200975, 41.03695069589923, 32.529694572571785, 19.766662889911284, 15.586331179065091, 15.898901916319325, 5.296082756211681, 4.163863639677725, 7.959845239116301, 5.678042673295544, 5.623794332627328, 10.826312380452311, 8.643527107854045, 9.110531364717792, 7.773875373025095, 6.058862161251807, 4.8397767639929254, 4.551773792312992, 2.5844396554654647, 1.6308554502264148, 0.617280799535013, 0.35967941425981065, 0.243892609592407, 0.27448810817253205, 2.476744853681134, 7.50730570285551, 19.978374781147128, 20.3668757407896, 16.050229899344906, 34.90565461497153, 33.97420544778147, 37.01078676408337, 39.58134735784223, 24.872929896077803, 8.719905461034468, 0.9474223455594433, 0.10175671638740648, 0.06978132491630894, 0.01698576082896081, 0.05880081049737431, 0.01779471711826421, 0.1062621254353754, 0.03227571325917398, 0.04857092434840818, 0.04444915681116043, 0.06492818089862985, 0.0026947238497556218, 0.020588371647341598, 0.03399813555241112, 0.038253183236285564, 0.05313308902024742, 0.041547897572238604, 0.019790251671727148, 0.01801749931708459, 0.0770780519251862, 0.005498331297384275, 0.06521708031575527, 0.014572937225532389, 0.008410498191932998, 0.027093490427960793, 0.015495736095603677, 0.06222771330466194, 0.04140406073401532, 0.11202070877076158, 0.04146477320201455, 0.013454396187538102, 0.07559581734840909, 0.10383183406966348, 0.04289830373900552, 0.07184105955304639, 0.07776786047484606, 0.04469442369055845, 0.038324923539954814, 0.05086484823315855, 0.023405181183930368, 0.16269701893531507, 0.2095970442338336, 0.15555922452720905, 0.19282786986760556, 0.11349941168220774, 0.14707248718027147, 0.17249237235275008, 0.19123334978376666, 0.1817401414436679, 0.15869866816266892, 0.17175561027421107, 0.15360675752162933, 0.11843645764935402, 0.10965844601272576, 0.18561381906751664, 0.14266852349523576, 0.12532348083632608, 0.21494377104024734, 0.19677294688599725, 0.11488625299065344, 0.1663694299396969, 0.1314045642051966, 0.08523147973802783, 0.16134761634372896, 0.1712473722234849, 0.16760178961821143, 0.14928988271182583, 0.21564851064355145, 0.142966914741743, 0.3259964281272504, 0.10149770206020725, 0.12025189450791768, 0.2661630919864101, 0.1313925366247854, 0.24269490773158692, 0.1435379107152262, 0.20105737021132825, 0.2849598559400728, 0.21070244782153638, 0.1699566366451402, 0.2474478704314078, 0.22893391549587253, 0.19296950420304654, 0.24469297229041978, 0.17999099417319223, 4.465420361488096, 20.974241033677135, 47.17311443821077, 55.91841136255572, 52.55423368946199, 39.724506024391424, 33.59697934119932, 31.48353372850726, 31.76542662805127, 28.07250334370521, 22.684386584066576, 12.18821127568522, 7.889378388081828, 3.3679801658276594, 1.2640614999878792, 0.9876161597428784, 1.1404888211719453, 2.3774375502140295, 6.567993654358772, 8.735415493288349, 7.016434313789492, 12.04138421243237, 25.274515882615123, 16.784735879590436, 12.31337606906891, 16.608117434286303, 16.478481138906172, 15.516004062468006, 10.174449759144938, 10.568818584565195, 7.746068710281004, 4.70880146949522, 6.616777643080681, 6.0596123145472625, 8.160372001509513, 15.837860030512656, 24.124849573258434, 34.03731638385404, 41.78499375620196, 55.376524156139745, 58.864291790992986, 66.37554830120456, 66.01798503629624, 66.61828810168852, 57.998291292498195, 62.62796678850728, 52.44880822397048, 51.70771168124292, 60.332509471524155, 59.787841304656006, 63.07406187057496, 63.25030572952763, 58.01765995640909, 55.01042581373646, 61.9443251240638, 52.65712138145201, 48.107450469847656, 41.92708553806428, 30.54108427416894, 20.963038744465, 16.17411501945988, 13.595835201201902, 5.437440074259236, 3.7009099654613005, 8.248162981002562, 7.281300694711748, 10.326135658448743, 19.515788093689952, 15.521279650349772, 13.616975795838142, 15.791545664110492, 13.510416765366832, 9.340665648060462, 9.001508105185724, 7.301681820423373, 4.111982204260365, 3.6490331878585205, 1.6599117555925924, 0.7948864563818901, 0.7408564201285763, 3.5399726658098163, 7.322172282203552, 25.873693227767948, 21.650979326617335, 31.462480406607355, 50.82324858634703, 35.547373987013295, 45.95924677387361, 46.95284197407384, 28.559887255391768, 9.076100799345202, 1.1257176653992746, 0.17745522782206538, 0.20918113509974173, 0.155569919114632, 0.1220643206409389, 0.20395143588464107, 0.2886660973871908, 0.1783687417064944, 0.13934826778788723, 0.16392596186168734, 0.34056598020176737, 0.08221277922031381, 0.21199897502458867, 0.10473035561341433, 0.1300725211659747, 0.13054676023462128, 0.15746028703306952, 0.10483509515442195, 0.2185439399533695, 0.21335234595162256, 0.13325121914667468, 0.24287723665756566, 0.12877102971317309, 0.10042864168363233, 0.12198801062280133, 0.11058463099142236, 0.1570878916930768, 0.10538985772478966, 0.26291463403932513, 0.09396509657944403, 0.1184502165884741, 0.1595580196308513, 0.21945025261131026, 0.22708327689718819, 0.09242141409026039, 0.13713074968226496, 0.22168388920685939, 0.20386192617156815, 0.1770555903954852, 0.1330199372023344], [0.04586518606952122, 0.08137626483315423, 0.044044811774285576, 0.053732116150880055, 0.005384243568480616, 0.02434282300753459, 0.04097095292602335, 0.05076305046978016, 0.038809313273598114, 0.0916848894989779, 0.0542829486901962, 0.03461287514637074, 0.03827600499554988, 0.07695512545685615, 0.04203219154489137, 0.034913032225543456, 0.07005675650772548, 0.04801899630336031, 0.02953477707060595, 0.060617231778920665, 0.03226803322773307, 0.0277946524006585, 0.04704672347513899, 0.022440387289069837, 0.01786967116077581, 0.05510487676327748, 0.02957047102221799, 0.044137224960591526, 0.05566423969163049, 0.012417514376612681, 0.040750641360758774, 0.01776156466334097, 0.05387638582878056, 0.09558208602210207, 0.035963311956654635, 0.04342436482529006, 0.014726444966189805, 0.03405196855085031, 0.0833734866952704, 0.0532874136021541, 0.03940488534769224, 0.027173332111429305, 0.09168876590387476, 0.020753940484756907, 0.05834070958137032, 0.1068055192609468, 2.8350369439971064, 13.618575142275903, 35.92184658973448, 37.24579949532786, 36.97803889551471, 37.91080597908267, 21.675915794987834, 24.298930245061076, 14.809428299626997, 20.428366737980998, 22.21322363422763, 12.54790242641203, 5.330737386980365, 2.764734587361736, 0.672275432415547, 0.24076493306746408, 0.16420923053256928, 0.583114136130579, 0.6892706946499887, 3.044598395785978, 7.4958263962499565, 5.803882604645145, 5.9712104258998755, 5.288725860657231, 5.303832869375906, 6.694777406031086, 4.56812370208002, 5.9105803889613, 7.729385399049329, 7.571002542972566, 2.402353426141124, 2.0617563734131474, 1.9918871935336822, 1.4142698914774003, 4.997989977559736, 10.626183248335316, 18.217305098810506, 28.343341042918546, 36.48114519734537, 57.20579208866243, 58.456867356454175, 58.52771320650655, 60.89023520869594, 63.31551121127222, 57.48112286290815, 62.139663081015314, 31.499054547279115, 38.09089768317438, 64.52949654671454, 55.67149816020843, 50.25617584105461, 57.15930415738014, 55.27571139797088, 49.08027671998548, 45.850805005719586, 34.496402355932425, 26.235078842409198, 19.603676642141036, 9.355896211439564, 5.460920362703262, 8.06558253303651, 1.098982300008497, 4.213344829697763, 8.891032588097358, 3.5313044728771334, 5.735682883570272, 11.275755205462056, 7.509359063640718, 8.117669157443508, 5.5413323833096415, 6.251171558134018, 4.540621513320554, 3.181175080037886, 1.4301830698405544, 0.8901060985461359, 0.4358927521013445, 0.14721179260842263, 0.9022453439331825, 1.246029751435403, 8.405614764459672, 10.721993023349393, 24.103900194168094, 46.517988404920025, 42.474762162854596, 17.429522545106952, 26.11442477472367, 35.980737055501635, 27.054877742644283, 11.665404438972475, 0.8084104210138322, 0.08975508337419841, 0.052351932146496354, 0.016858186122150193, 0.06251597686881019, 0.06686493544088257, 0.009040166924317038, 0.0387821248131654, 0.02687797457310221, 0.05824977494475823, 0.04790900522963174, 0.047209873389933384, 0.03812212091419966, 0.08622806053608657, 0.08170336139418426, 0.044353219620402784, 0.05431772908195854, 0.05603821700318687, 0.030715965906218178, 0.0351290422071132, 0.04278162471769799, 0.062435074153566555, 0.09341320683879238, 0.015670062275603414, 0.040993916411553664, 0.03552151671160133, 0.0410851268398185, 0.08468164311301324, 0.07113576070555756, 0.054917970461951154, 0.03711636621324766, 0.061527704294290275, 0.08252630070332559, 0.06379947674671008, 0.04157650712577086, 0.010048646983059665, 0.05611837278270433, 0.04032962242021196, 0.034190569178111134, 0.056022994836131414, 0.07498018143157806, 0.046811791121839516, 0.06254256395022235, 0.055188027946578885, 0.014708468713046563, 0.004890825009844717, 0.05864240649727084, 0.02551041761293046, 0.03668015957960198, 0.08751619141548873, 0.11064094611473622, 0.1264559503103937, 0.045914974123720205, 0.0641197512947744, 0.10167277613354307, 0.016247916651228746, 0.033769446815694534, 0.01163862320789767, 0.07151652172568344, 0.10929028713895429, 0.07807211995485329, 0.06038792251098541, 0.037740716380217386, 0.06014592299658445, 0.007954032841934673, 0.021409562360795758, 0.01400359312913591, 0.006618372910100246, 0.02676844698256783, 0.027779129544092764, 0.036678876382328814, 0.03409527167077026, 0.04843274506950571, 0.05841926040668642, 0.012363287800502394, 0.01998402403607484, 0.03594476879844743, 0.046921422134243676, 0.07033412630159049, 0.036334132985962976, 0.023714663468361385, 0.07836425226301917, 0.04942859042315714, 0.06294605862950126, 0.06372944098867236, 0.06078971264463279, 0.3490220893534922, 4.347345742487139, 18.64251159852551, 42.23847466130411, 42.39333768044749, 37.20604235126127, 42.038025856018066, 22.195100322846447, 24.549542242480864, 19.049873275141564, 26.9757164678266, 23.855902456468154, 17.490658567797755, 7.396114353210696, 2.3766175296998795, 0.5711617549100231, 0.07979607825437862, 0.07330823284123214, 0.3337354789818487, 0.8557759213351435, 2.5551902959423685, 5.4181371100487254, 4.071215049874398, 4.334881430672062, 5.106314074608588, 4.753800371000844, 6.920883415206787, 7.40520836845521, 6.076613337762895, 7.1572626021600545, 5.66784353025498, 7.819843590259553, 4.7641887684022235, 4.589832059798702, 3.7709571228873346, 6.7214044159458535, 13.213522761098801, 21.989189617095455, 33.17972544700869, 39.96025616122831, 58.74369852004513, 60.943606899630645, 62.35763311386109, 64.32167368550455, 66.5941890593498, 62.415084069775006, 61.29741253391389, 34.8601080525306, 47.26198357920493, 66.34376925806846, 60.29871825248965, 55.0042284688642, 58.390104693751184, 57.5132784535808, 52.22365240896902, 48.0091715628101, 36.78408553523403, 27.98016486629363, 21.12018458304867, 14.44885265442633, 8.725875308436732, 4.076418073907975, 2.805131077766419, 5.45573155726156, 7.219243895622992, 5.955494469211948, 10.171611924325267, 9.777269574903674, 7.791538296207306, 7.769254330665835, 4.89375053874908, 5.653604345936929, 2.549316546609325, 1.919378381102316, 1.2619178021146407, 0.15908327494417468, 0.3726908047833751, 0.03714110319232268, 0.7374404647177266, 2.200218491977261, 10.471021148466296, 12.615755508022925, 28.31918904858251, 42.6558619160806, 37.23155736923218, 27.371552259691303, 28.022522541784472, 40.20999739246984, 31.55707032449784, 13.89583964501658, 1.3173003206329963, 0.02940934932520313, 0.030274366013585564, 0.0527829600257739, 0.049703949236220894, 0.019856119911456784, 0.05841827981414334, 0.015365903344636243, 0.015335601694401235, 0.06320997591941588, 0.025348652402059208, 0.05215716195262728, 0.04836481222282014, 0.041661945081526236, 0.14730908577480625, 0.014094910809710143, 0.07364750253937899, 0.06366394813202562, 0.026172200751100338, 0.008417478210533099, 0.035797695238744064, 0.07126867696042023, 0.07129291598234447, 0.016133396082647865, 0.03051827117169817, 0.05327478081228272, 0.03349624070969801, 0.009299870730648118, 0.06268906677442213, 0.06781912093321163, 0.029928743531326615, 0.04153136922527225, 0.02031438796210193, 0.023831440165879268, 0.02011427622018082, 0.026036009470361377, 0.042168750547833984, 0.0964580386156036, 0.0664818684961046, 0.10302121345434459, 0.044087586293537775, 0.1732259168620071, 0.2157955075944624, 0.26191602310826706, 0.14551599570099386, 0.10263784007439691, 0.13366594850536317, 0.14107814028618798, 0.18612806324756917, 0.18228205671954542, 0.22589410925584458, 0.16555322454340998, 0.09614448648907485, 0.18457973826556437, 0.11749523436470379, 0.12335075080514916, 0.15009488790265976, 0.13601157183368362, 0.12260599076868066, 0.11386991478502752, 0.19820949963984952, 0.15173183393574532, 0.174725181573341, 0.19905939758304628, 0.11628617908084586, 0.09741060000153319, 0.1035695868514238, 0.07171833226757665, 0.13693047897709956, 0.173416075206572, 0.16272017011238685, 0.19865874892040608, 0.19889047519574243, 0.20748745259498397, 0.16213991979677833, 0.1204800354917684, 0.11415919724611506, 0.10544582810853759, 0.12879641786698373, 0.1646095421165228, 0.18350462579438764, 0.24639866705383026, 0.10334654035226953, 0.1874877773826161, 0.17005271939260347, 0.23349820606170163, 0.5118313708132314, 5.0270743523874595, 21.34442452461489, 48.02249977665563, 49.57467971309539, 46.328526158486646, 49.8514578419347, 30.904384005454283, 36.02617771394792, 23.41012900875461, 30.29670100058279, 29.127012952681515, 18.08181662713328, 7.267694973176526, 3.8966301083564763, 1.181481756990956, 0.7172439968393696, 0.9714149323201949, 2.5809171219025893, 5.122554158010791, 6.812524507122656, 13.579693667350279, 13.937756053863035, 15.643379111443798, 14.378145067922532, 11.42665074717614, 13.867533860668061, 11.857626072822079, 13.595200757826529, 14.928485962652392, 14.377698898315431, 10.216499528577252, 5.664284469619875, 4.844301708282964, 3.319214318067797, 7.712776612850928, 13.73579909724574, 22.229650520509292, 32.15569461545637, 42.462889148342995, 62.27893075635357, 65.12748933607533, 66.30581640428113, 67.68130533156857, 65.29923031407019, 62.29600483371366, 63.408275265847486, 39.62090053865987, 49.56733703613282, 68.19093104331725, 63.49624618407219, 57.897811935793975, 61.09945835605745, 57.894803477871804, 53.209634288664795, 49.509689961710286, 38.03245828997704, 28.18179234381645, 24.05563150682757, 11.682984502084794, 7.6615406524750505, 11.214346578044276, 4.203121171843621, 10.27098713382598, 15.167432831179712, 7.526602293214491, 12.455390384120326, 20.914224847670525, 16.897353010792887, 16.706565003241263, 11.486481601192105, 15.28365363997798, 10.992844450858332, 7.781219520876485, 4.787316043530741, 2.791096837289872, 0.9444979734478459, 0.5099927597949582, 1.3166707802203395, 2.2853459369751716, 10.475272017140544, 15.244966322375884, 30.01367061368881, 51.35141141953007, 49.47827962137038, 27.398989239046653, 34.03593178718321, 48.25353130217522, 37.95710171422651, 15.912611580664112, 1.9693286620801496, 0.1531622886297203, 0.2699464325222277, 0.06717762954893612, 0.14183445292855465, 0.22775403284017118, 0.1099826620831605, 0.13895612270120652, 0.11286145962414243, 0.12227307193942609, 0.1832637217857184, 0.24893904525426128, 0.1269907409685754, 0.15753755466111247, 0.2524304450038941, 0.16495081896503128, 0.1652759466800959, 0.18456144408593256, 0.23064196981008978, 0.1471541368312413, 0.17900879284547222, 0.126564497308385, 0.20121622620330704, 0.15772366806143717, 0.1169869886530984, 0.1731260802837149, 0.11561034397492487, 0.3010188974440098, 0.1777435373514891, 0.19641809495947055, 0.12784820786046405, 0.13857004503088613, 0.2966886927043238, 0.1508325846084664, 0.10755684467092638, 0.07888038868024465, 0.17911457426605687, 0.14905746695735764, 0.15543327967245735, 0.2059662777690157, 0.21004745796803506], [0.03100072078767323, 0.04997694849847786, 0.03452027043808372, 0.0475794188828478, 0.07051178209123111, 0.022201274010923602, 0.026877061013252507, 0.021054469116572893, 0.056172937395111214, 0.02174484840173635, 0.09532058957002817, 0.02091834869896693, 0.0643744831904769, 0.027583189150919358, 0.048294619416757945, 0.03595223432526954, 0.1167159007802125, 0.05458293723002557, 0.02611129101546061, 0.024614336059218454, 0.07175541092311183, 0.012431584538951998, 0.0280877384882901, 0.08833061182691206, 0.04124470295444612, 0.06651291803967568, 0.021669507484822985, 0.006890003268997516, 0.07365334779024124, 0.05125711972434675, 0.025229579355988293, 0.018784590816545873, 0.03521809609787118, 0.04429245352624886, 0.009548851221259083, 0.07517973967497388, 0.03316170160448359, 0.07384135342773891, 0.03635874356053049, 0.09977322282089342, 0.047055521994949355, 0.054367976788912094, 0.058864196612229275, 0.06369359190425565, 0.06525900064697189, 0.05578081529106825, 0.2278696508297036, 4.773971159611979, 20.281028786013206, 36.28146909898327, 44.308834998838364, 33.692551812817975, 27.627298639666652, 22.59508598235346, 26.804587379578624, 18.449901650028846, 15.682720484272128, 19.639505532480058, 15.508592744027416, 9.809243755955851, 4.1153262699804, 1.7046699216288907, 0.3460761135624301, 0.34985706390392396, 0.09721304124761974, 2.8783970302151096, 7.140896022319795, 2.8999310876092608, 2.2171121403094265, 2.15208831333345, 3.4887631814326014, 3.8134746349626973, 6.068267024332478, 3.712117647932422, 5.530021738621497, 3.4350727979213964, 6.095349519483506, 2.824850303511466, 3.0381939007389933, 2.083409327653147, 1.2499082400914163, 3.5330077621244618, 6.204214413319865, 14.726923204237416, 25.542027411922334, 43.45537039541429, 54.9679151658089, 56.265701939982755, 56.22239897328039, 61.320119134841434, 56.61476542872768, 59.9148045047637, 23.95527570478378, 32.04169288758309, 58.3474842194588, 49.796850604395715, 57.60075515316379, 47.646313098169145, 40.27930959578484, 39.610494490592714, 29.497049354737808, 20.880184558130082, 15.947020573000755, 7.981738928825625, 5.868760078184067, 2.779188031150449, 3.4809373174944236, 2.9437515620262396, 4.7181269045799015, 6.7655247065328785, 6.271775768649194, 5.74270147469736, 6.130739594659498, 4.8266064255468315, 6.720240452597219, 4.834079521317636, 3.1841104838155934, 1.7509464126440788, 3.191946153679202, 0.839691874721358, 0.5301424656664172, 0.33280198552435447, 0.7660610805596075, 1.711451699656825, 5.572492672551063, 6.612945487422328, 18.251961200468003, 40.279011495651744, 22.571175213783018, 11.125732391111313, 22.44474349483367, 36.44270989202684, 32.21603047463202, 15.297189739442642, 2.4618266090270016, 0.18686997343695935, 0.06181423649972966, 0.10849455927288341, 0.015819641900429084, 0.03762008434522056, 0.05838318149589243, 0.03191620734850726, 0.05780014645067915, 0.04038945771753788, 0.07744113929689893, 0.07796817714528692, 0.002266849619298873, 0.04831552595621155, 0.03504727381251512, 0.0779335423102302, 0.01663118086364721, 0.029898348992930788, 0.038869876354452104, 0.08077572850931077, 0.07176644258922146, 0.03974176102107571, 0.06756629659644059, 0.1044820435345173, 0.025277660949335947, 0.016653920268459667, 0.016468015627094334, 0.03174256011393042, 0.07992881064813945, 0.11554063763469459, 0.022874169254435167, 0.04927097166317606, 0.05672494204895151, 0.025738085537487944, 0.021270090308521065, 0.05100165238423694, 0.014947672006523898, 0.046803291376319625, 0.023048377648416548, 0.04357670523947285, 0.1362446617455252, 0.08485317786013888, 0.024533331837324847, 0.035063936224868225, 0.11715529050918357, 0.008519974071532488, 0.036996714770793915, 0.04354801524670855, 0.027832771020550883, 0.050854360489475156, 0.09070301758906535, 0.06908516549775678, 0.11429083413414418, 0.034173171321350726, 0.04024074089923694, 0.04000601538967702, 0.060733435825715144, 0.03354913908086958, 0.03887447671243741, 0.03964978067444698, 0.07061208598315716, 0.06913697602407587, 0.050566357395221154, 0.02550041825029879, 0.020484838694814714, 0.04273510019805643, 0.024003311991691593, 0.037833903315326864, 0.025543947366156408, 0.0473010991399567, 0.06002793779536601, 0.03429715499101627, 0.05040358669394928, 0.05087098076699242, 0.04243189025850546, 0.06617141902566918, 0.026541445554504474, 0.01131888492138035, 0.041113426127741416, 0.04574630071499175, 0.12781962512000916, 0.020004461346674832, 0.039570345017578334, 0.1284112058760178, 0.054347740576392224, 0.10550486284398264, 0.0703806431603528, 0.09548145271236859, 0.15689759545268553, 5.970592162301464, 24.092011490175803, 40.03973907040012, 48.87037892495432, 38.7178454091472, 30.747740230252667, 21.874397531632457, 21.51715393989317, 20.30375303760652, 23.784015217135032, 24.66845673899497, 16.967690913907944, 11.172121282546751, 4.247594966042427, 1.1248889421263049, 0.160405297553347, 0.17181724970859868, 0.1442842948580942, 0.8602806409039806, 2.730635952564978, 1.0713917353460867, 2.3890136903332126, 3.062923464082903, 4.555153894808985, 4.208179068180823, 5.816898990061976, 7.269966515802569, 6.863278506263611, 7.95967314512499, 7.6622265769589335, 9.234664574746164, 5.035085793464415, 3.115319710585379, 2.4430766990107875, 4.849103179670149, 9.133057536617402, 19.127938247496083, 30.08714052938646, 46.483844172570016, 57.80597748294954, 58.60847088598437, 59.44981536557598, 64.47947848227717, 55.637381384449625, 64.46941760278517, 28.78035387685222, 37.30163443473078, 64.98108294702345, 55.1870854439274, 61.04233295686784, 54.08713125413465, 44.624801528069284, 42.17263767796178, 32.76432879509465, 23.78814547292648, 17.37060658393368, 11.662137104618935, 7.1735688755589155, 5.479280977479873, 2.9239457989892657, 4.548542739883546, 6.459306738068981, 5.2031706321624025, 8.488668991673379, 8.61329936212109, 11.655158227489842, 6.616959052701151, 7.388730001065039, 4.5667042943739125, 4.7084607135865, 1.7556146460194744, 1.4086080727077301, 0.708674659892436, 0.38144213357760065, 0.05890198006865479, 0.5244332720195094, 2.5755069476942865, 5.453535520261334, 11.543112781740005, 14.746911602635539, 32.5775396439337, 34.39711539976059, 19.138624745030558, 24.28154826164246, 37.170674339417495, 37.091536598820845, 18.21847592630694, 3.822349978070106, 0.12284652705514625, 0.053455880167143005, 0.0339018804351649, 0.03331039927058643, 0.03903976784298017, 0.060886956015301336, 0.0493807788758028, 0.065314250908071, 0.035450837439707214, 0.007488134076758739, 0.027224765339445685, 0.02676731700287952, 0.031593195951333454, 0.046205011181413166, 0.06810542331227372, 0.0798104807073551, 0.040383926562724576, 0.04731401921279969, 0.013239326578895412, 0.006644902534918079, 0.06032459385272476, 0.04179075127467514, 0.03052854249554296, 0.06974297455481945, 0.04096779664377532, 0.024706906293548887, 0.02107696528846939, 0.04924402068999987, 0.05910170685139395, 0.05270283872021302, 0.06759397535314483, 0.06967293879678173, 0.014426917036724909, 0.02961939914272197, 0.1096116150579145, 0.09895422886456214, 0.05639807531429876, 0.054394364687463934, 0.0382297256240441, 0.10151001309315044, 0.01330790485465719, 0.11305720274967533, 0.1417277981677363, 0.2896692435587606, 0.19993362647871818, 0.11155837470845831, 0.14290607203879666, 0.1078810760631196, 0.09840154239246923, 0.16246559909514843, 0.2741054319325955, 0.22595067718817344, 0.12379904247580037, 0.12927755172694885, 0.0831647507185417, 0.15726537894337408, 0.17347826622426513, 0.14023055592852254, 0.18366398740439646, 0.0971020887335462, 0.16436292309193842, 0.2148346801198298, 0.28440689367632715, 0.25451213572054143, 0.10998747311532499, 0.16322421000128792, 0.16186611997264047, 0.11908008641893826, 0.11711339316060466, 0.09028913858797281, 0.11941334998775875, 0.10680900496100226, 0.19377763503261153, 0.09881340658232089, 0.19277419774763047, 0.22275975244420193, 0.10328689274648506, 0.17455146347563114, 0.150063754089417, 0.2034509966089841, 0.16759518594030412, 0.12956057524969503, 0.18181029977577348, 0.12282914452014432, 0.11447674835160856, 0.20049682367713223, 0.17976928832790545, 0.37131828165823416, 7.093059285994499, 27.565744884552497, 46.15695776477937, 58.28918210921749, 47.090340660464385, 39.52956030445714, 32.80009296632583, 36.903862953186035, 27.963163352781727, 26.11623690974328, 28.769592854284472, 20.64240655591411, 12.421300084360185, 5.443657030982356, 2.2397804981277836, 0.4836450655373835, 0.8544869937243, 0.29794250284471824, 5.003731837195735, 10.906618987360309, 7.053159956009158, 8.785176642479437, 7.469693604976901, 8.986973762512207, 11.32424452612477, 14.129214786714124, 10.678356655182379, 13.342055889867968, 10.191092375786075, 17.13393076773613, 10.446310216380704, 6.571896412680227, 4.454600993664035, 3.3366078234487966, 5.524209766618667, 9.750107161460384, 19.35869324591852, 30.19966352370478, 46.842372340540734, 62.72181341725012, 64.93405765102756, 62.04438086478942, 63.52054526728969, 59.89361978346302, 63.202182169883486, 36.36964790282711, 43.88185754899056, 68.19364532347649, 60.14796979965703, 63.177773260301166, 54.96998225488971, 45.157949693741344, 43.394601114334606, 33.38564595868511, 23.448034794099872, 18.447124611946847, 10.08324778849079, 8.234551375912082, 5.7163907058777355, 8.064180285699907, 6.949187238370219, 11.943321035754296, 12.556390435464921, 13.302640972598908, 14.247831183095133, 15.368538633469614, 10.100664092648415, 14.294713312579741, 13.131637400196446, 8.988653517538502, 6.8231506982157315, 6.28862185824302, 2.213103968289591, 1.8361985154690283, 0.545082712365735, 1.366185800683114, 2.8394128382205968, 7.11485589704206, 11.023062390665855, 25.07490254217579, 46.34753004197152, 31.24307086390834, 20.613047615174327, 30.958375430876213, 49.157692540076475, 42.71250486373902, 23.398308946240334, 4.177634591056455, 0.31392061482033423, 0.19040969801285576, 0.18284825698262264, 0.14448684850527396, 0.18768455472684678, 0.11626591605524864, 0.11671092120870469, 0.12958136687596, 0.1935525890439749, 0.1235450690071429, 0.251560153800153, 0.1324337114009165, 0.10985061916853152, 0.13515664835370358, 0.2716969434292086, 0.18689458018108723, 0.07766544218024901, 0.13188533034295807, 0.18659006023118574, 0.14411578615826948, 0.1481949592069272, 0.09664253557040807, 0.1809157082630742, 0.1633698892809691, 0.11676990997887428, 0.1747619997589819, 0.1408102393390671, 0.18676462102561228, 0.23892788486855648, 0.1139768146939816, 0.11845516551646496, 0.152575955575993, 0.09442675648437393, 0.18302010582579722, 0.1898223384013099, 0.16005922499443256, 0.2142990467649314, 0.11880051029185135, 0.19853344757951077, 0.1799767296160421, 0.21021769802656867], [0.04028311322232889, 0.04089103463376242, 0.10177201516325436, 0.0051772020824794335, 0.05203579064278353, 0.06876130948864645, 0.01745199236357885, 0.1417432425002898, 0.04820250117430284, 0.2012891118084231, 0.03832726393856349, 0.0372493322638254, 0.1100326493202198, 0.08379270532919515, 0.07850937229851562, 0.0710034879645513, 0.07101762994763351, 0.030367438035506397, 0.026410214693075227, 0.03403320322714506, 0.02328771117684101, 0.13131421179540698, 0.03171865050981362, 0.05902234014243849, 0.05782146667761188, 0.026304144074299166, 0.13584765966140455, 0.04961173140233563, 0.016631431757442413, 0.009563056406595055, 0.024281817510904326, 0.11737341106298471, 0.05214265990822066, 0.08235768475119146, 0.03956235472052809, 0.025646122427837505, 0.07152712438255548, 0.021283717097474203, 0.052322920396803856, 0.06655394204802091, 0.01852496170378741, 0.038623199873273416, 0.07365901684088093, 0.04952205698035898, 0.10808729927145666, 0.05058921745888168, 0.06069483648565027, 0.45107603253376105, 5.237196703110972, 19.609266019636586, 33.61646959858556, 43.192650041272564, 35.70488460602299, 31.35128709577745, 20.905352446340746, 23.30256781270427, 14.119482405724066, 21.348229223682036, 24.45563873937053, 14.352893829345705, 9.00776134383294, 4.397359884554341, 1.7832385508283493, 0.5994321766399568, 0.386008324041482, 0.43117147479807183, 2.636203664925791, 0.5490857975617532, 1.594606130834549, 2.1253090664263694, 3.245982441209978, 3.734703881125297, 4.5307739127066835, 7.097067948310607, 5.2191361496525435, 5.373497595710139, 7.623239688334927, 7.2062363355390495, 4.006950936971172, 2.5854663358580683, 1.2921380708294532, 1.444460129545581, 1.9550721948185277, 5.922551462727209, 14.162273503118946, 32.265197384742, 48.079680089027654, 54.20757547501595, 55.10161699787263, 48.191640223226244, 58.85188925650812, 39.954400062561035, 13.26268574883861, 31.05071390828779, 46.50462881211312, 52.64416187040268, 47.15221604993267, 42.52462333248508, 34.019999119543264, 30.096905269930442, 21.80239458237925, 14.855517129744253, 5.863584020445424, 3.360846845373031, 4.163293425113925, 5.75710637915519, 2.9659345265357726, 4.977225440163767, 4.105222979860922, 3.005904459184216, 4.34739084974412, 12.32616005405303, 9.08539681665359, 7.837158893385242, 4.644884976648516, 2.5187853074842885, 3.8958056751758825, 1.2268172468869918, 0.3907660058429165, 0.3145701041625392, 0.02549826171279194, 0.7064427086903203, 2.77947657050625, 5.294720222873073, 11.728664425111587, 14.512087145159322, 40.13382496372346, 22.883542968380837, 7.0584281894468495, 24.397979897837487, 33.84843464820616, 36.23260813374674, 19.882665026572443, 4.216704830046623, 0.29912546517387517, 0.04015606903140584, 0.03142673845192598, 0.024709570364305572, 0.03893592845528357, 0.08181731697292098, 0.010328519011607334, 0.01046072184709051, 0.0067928135244836735, 0.03625048384551079, 0.12786598110030736, 0.060730555335119854, 0.015347784407617105, 0.08986385253768775, 0.060495335698848775, 0.030544812287834865, 0.03698515450401652, 0.07238171844472809, 0.09916432847779605, 0.08526038423541092, 0.017705178676894116, 0.016578860888858477, 0.00912952820785464, 0.05824566105260484, 0.016844756600837556, 0.020826180660796743, 0.07529541895154022, 0.03359678208888058, 0.07838375686157135, 0.014518783427774908, 0.07667582512142197, 0.024555209393222487, 0.09654001002350161, 0.03947336211680405, 0.03721519538591947, 0.08919564766749259, 0.05687471223814834, 0.03319705656218914, 0.026376455113472, 0.08261358110053886, 0.061650630762620326, 0.15678586918980847, 0.044597701259678414, 0.0219646179597945, 0.011920256281061279, 0.04541705144689449, 0.046091476951034806, 0.011666650534607472, 0.04687082968772419, 0.019192637973314813, 0.024937701772057244, 0.1724975664288767, 0.03540578380888028, 0.09264599276526321, 0.14609927972478254, 0.055354655900549506, 0.09039279028412797, 0.023772489700105884, 0.024416604935522043, 0.07430399392521189, 0.03274644364512736, 0.03704116319216067, 0.05518488698608934, 0.03972727429842757, 0.033525371203018774, 0.06679640121517644, 0.019269639385804053, 0.031145300731183063, 0.1198680921187324, 0.13811552506541053, 0.037360422673725316, 0.044451064370091886, 0.032215548544040615, 0.018202936644816113, 0.04218678808801117, 0.051201624315111875, 0.027840588947818167, 0.07479491838884932, 0.03874673155106364, 0.033090662271265066, 0.037775998559570124, 0.051481575825281685, 0.015265472090592789, 0.040388940608189, 0.007984601186528321, 0.049231970126950936, 0.10814333860311778, 0.03554375241360357, 0.06554588525285644, 0.6335767154251376, 6.971046117044265, 23.883564972108413, 41.95670335523544, 48.39376388057586, 39.70507460255777, 33.98100683766027, 23.24691330232928, 21.40518988332441, 18.779429774130545, 26.705510270211008, 24.93814910611799, 17.65621985158613, 11.176223101154452, 4.9345946696496785, 1.5943011665536513, 0.43494169990862575, 0.46875945622882537, 0.22682990097711164, 0.6183688282485932, 0.5985629426375513, 2.353011480262203, 1.8736455060781974, 2.285000278103736, 4.119936035525415, 4.117233032180417, 2.4515553924345204, 3.4430668334807124, 5.667803816256985, 6.193990755465723, 10.25669401691806, 7.240782120535451, 6.994759296217273, 3.136004084540952, 3.408276635792948, 4.285159505182698, 7.016780462957199, 16.972195756050848, 33.89781336630545, 50.124780362652196, 56.62166487786078, 56.26579215449672, 52.57911720583516, 58.62514880395705, 50.06143016199912, 18.87206635167522, 36.009597855229536, 51.297941669341064, 56.39379870507025, 54.56898266269315, 45.09712549947923, 38.153271213654556, 31.582636333281, 26.306326735404234, 15.318295032747331, 7.989503750877996, 3.4659045886608864, 5.197094390469213, 4.576453345437204, 4.334871624746631, 6.049373457508703, 4.309328659888237, 4.98126155907108, 5.7024947289497625, 9.537996169059507, 7.198606835257623, 7.017534538622826, 7.801556519923672, 4.357880248177437, 1.443089751466628, 0.8444997812471083, 0.3917037587492697, 0.2157666414014755, 0.2399570014207594, 0.9103286134139185, 2.6062387179943824, 4.313418711385419, 14.20088335391014, 11.609033115448492, 31.76140815980973, 32.984752270483206, 9.69711692102494, 23.85519446865205, 35.495971325905096, 41.21799553594282, 23.179097483235022, 6.08853881397555, 0.42090981898288576, 0.04962711444785518, 0.031910210795279954, 0.017446095401781703, 0.05021021461054202, 0.008252987641871216, 0.03999797912735132, 0.014169825590215625, 0.043572909273808046, 0.04309213547516735, 0.04738692397011384, 0.07495641738416688, 0.02680842719611622, 0.05398133987440698, 0.029916480378878695, 0.056242969322709314, 0.04069055708485746, 0.15309168596661862, 0.05135152856969545, 0.011395002459926952, 0.05772541457366559, 0.03229791448721963, 0.03543470745846149, 0.06401002835181933, 0.03861622464272284, 0.025025302010978905, 0.03801443576512318, 0.08480987857065855, 0.09743056425283994, 0.04097022897293491, 0.13003901248016667, 0.022811696699429906, 0.07719140995534197, 0.06800292840888424, 0.01571317578876211, 0.05187303526327015, 0.06750811987947072, 0.018996452432005637, 0.0996884398703133, 0.033783975673178514, 0.09705959383638636, 0.07374947650297996, 0.14248616392574004, 0.09979133313942341, 0.2235705492597434, 0.058679056143568414, 0.10557371882661697, 0.19696667520028932, 0.1839549322762797, 0.2816879250589879, 0.13672679151979186, 0.3253024137548862, 0.14748862614074063, 0.15784113998374633, 0.2455945505249885, 0.2552583666458245, 0.26747625861917773, 0.2339080631011917, 0.23590496320637966, 0.142730561295344, 0.13793759348411716, 0.08509583621015472, 0.16474172292697817, 0.2352440591541029, 0.15795873448012338, 0.1781378887713917, 0.11163217961908349, 0.11523322953331856, 0.41791361846750785, 0.2615464010065602, 0.11183250395040359, 0.1598576212962789, 0.1148457805656137, 0.23198905881614457, 0.15804160987177204, 0.1749669742440024, 0.13983833423304942, 0.16520850029924225, 0.1883769143492945, 0.1734417544737939, 0.17866517176791546, 0.20194040911812938, 0.14439478005853393, 0.17401229079452255, 0.22444234199581609, 0.1651380508537254, 0.3125334134505641, 0.10977609413525752, 0.15715967413158188, 0.9100743947971253, 8.448837322573509, 27.828843747415853, 47.447523455466, 57.347475944026826, 47.3124134925104, 42.8937065985895, 31.121959840097738, 33.176301217848255, 25.564069171105665, 32.234353826892, 30.304824229209657, 20.004833129144487, 12.140830024596184, 6.07858628995957, 2.6479320420372874, 1.1376822427395852, 1.164183123938499, 1.3926277237553752, 5.963207319859536, 2.9816617600379454, 4.429187467021327, 6.438956501022463, 7.928779577055286, 7.1740763321999586, 12.187198323588218, 15.531349355174651, 15.38656976915175, 14.71041100640451, 14.610989709054271, 13.69292857185487, 10.293699618308775, 6.287576056295826, 2.5987026191526845, 2.9518338509144324, 3.169937244346065, 7.955031020026054, 17.094903184521584, 37.26828252115558, 51.9601240465718, 59.270919984386815, 59.59829276607883, 54.76366558382588, 58.18287411043721, 49.92661045443628, 25.294255210507302, 43.04714187499016, 56.31959138378021, 60.28274636114798, 58.552835987460234, 50.36195039749146, 40.355956631322066, 33.54849492349933, 25.76347854829604, 17.080466901102376, 8.167643095216444, 4.630564893445661, 6.544327543627832, 8.770964914752591, 5.706658324887676, 10.884512509069136, 10.780114704562772, 10.486837125593617, 11.509193105082359, 21.410898893110215, 18.30042208394697, 17.940789768772742, 12.280564461984943, 5.927305865672327, 7.611191147758116, 2.4515156784365257, 1.4887496949203554, 0.830208441663173, 0.3977203068713988, 1.2516962280196529, 3.767401984622402, 7.596750451672462, 16.96563559193765, 20.445158404688684, 47.86766029173329, 31.927591139270415, 13.89964532467627, 33.39163541793823, 44.88260323001493, 46.58157002541327, 28.69310075236905, 7.6174654691450066, 0.5527849603564509, 0.12328908838812383, 0.11811579622688795, 0.14514557686784577, 0.1287751512662057, 0.14876886631452269, 0.1119144217321469, 0.153457002654191, 0.11501964422002917, 0.12200497947032414, 0.39034729282702174, 0.19519627665079411, 0.17817156599654307, 0.17470040628986974, 0.14526678729922543, 0.1492210573727085, 0.15906787657689664, 0.21977041607662556, 0.28592187851186723, 0.14106191454395173, 0.16099106370201036, 0.1268385422806586, 0.1874987477616918, 0.2611032957511564, 0.11516453442914833, 0.12700164239973794, 0.17721905823676817, 0.15126862653320836, 0.17180935900297858, 0.1186758831083294, 0.24596864658017314, 0.1529813999490392, 0.20450334094705122, 0.19538246665991124, 0.17345822536416594, 0.2585722331798846, 0.14304333967306923, 0.1060176667787375, 0.18924723619655257, 0.15604354531293915, 0.2712479852620633, 0.2327294368296862], [0.11345024415922743, 0.11636607439046907, 0.09267431503582386, 0.06310342841090695, 0.03245628784380613, 0.05169746706322317, 0.06662895737756645, 0.030918471672902667, 0.10560561872778401, 0.12341877175194603, 0.03664562433597542, 0.013339070269026825, 0.029586474598956206, 0.06604014985984372, 0.01411685252547144, 0.013729286729358138, 0.07672153758786379, 0.07958735759940841, 0.021169322933400833, 0.05853528059237908, 0.023721456753029942, 0.08701396715496817, 0.04793057443513986, 0.06901904444901213, 0.054749917584441365, 0.027481678670512575, 0.05244807235055393, 0.09233847741157779, 0.022852000585126302, 0.035588936279377634, 0.002942029001837176, 0.08766431451564835, 0.010176057938576467, 0.07441561293577956, 0.10815678344618891, 0.03398750991290135, 0.10448727591504013, 0.028733839806649956, 0.04792579021605273, 0.05410597088836855, 0.06969536219032542, 0.0397218389046048, 0.0415105278032922, 0.0682673896212251, 0.04831603157424158, 0.02764880075119436, 0.03308292861366945, 0.1133320444533902, 0.4593643071430345, 6.064583428444402, 17.93541023808141, 31.09358737545629, 44.35814703664472, 36.93832881989018, 30.11919217724954, 23.8791601504049, 14.56810643596034, 17.59262058042711, 39.54787777316186, 35.085518821593254, 22.559100197207545, 12.261555675537357, 7.31060129019522, 2.384343863494935, 0.42790573390741504, 0.4965065173324078, 0.26860277559007373, 0.07516414212483553, 2.440313389224391, 0.6796548815984881, 1.6865922078009576, 3.182056632734114, 2.654168365463134, 1.6777210322118576, 2.4577755360834064, 6.098104494233286, 2.592469237504467, 14.034047299815764, 6.848165613989677, 5.584935411330193, 1.6736743719347063, 3.1053559097551533, 1.4386980451883808, 1.4883409104039593, 4.65680064693574, 18.691335301245413, 35.104714901216575, 43.62995901415425, 45.62895574877339, 46.04037315614762, 48.777740386224565, 21.067950379463937, 17.847627593624978, 26.309868635669833, 32.679083924139704, 35.25492598933559, 34.33221586288945, 35.47309606306015, 27.00443998459847, 20.290401289539954, 18.900909500737345, 10.016061509809187, 3.444939765237993, 1.3249395042657852, 3.870585325264162, 4.8326865896101925, 3.1164177290854918, 4.586929015574917, 3.9187248195371325, 4.065432740795997, 5.671147146532613, 4.29551407214134, 7.309068133754115, 3.832450326411955, 8.423816523244305, 4.353974057782081, 1.2278556943901124, 1.0750589063090663, 0.5935034528374672, 0.7397211391118266, 0.9562332759941778, 3.4777601976548476, 7.701793486072172, 18.25687004673866, 11.228200389492898, 31.312453669886438, 32.133335144289084, 6.153776655274053, 26.82321471552695, 25.942085635277536, 39.34078447280392, 24.8384306892272, 6.927237654885938, 0.5850031250907529, 0.1143203515018667, 0.03446372548839258, 0.07911013078785713, 0.027805258887970162, 0.03253058305070285, 0.09435683563952485, 0.08611967441655936, 0.036556486175545765, 0.024029301524522807, 0.010615530021999393, 0.05502148426227993, 0.07980048325994323, 0.04936514302126823, 0.02917762304986677, 0.07000891431685417, 0.02576151059099263, 0.013982622429818637, 0.04541952974132953, 0.03028897914074121, 0.009068572506939453, 0.05767870619292221, 0.04433714709575138, 0.05157625663184351, 0.04640643101846499, 0.028138507135032166, 0.03261074266065994, 0.048428684803507024, 0.05838721494881376, 0.020641275764172597, 0.06534045877596063, 0.03981464662619176, 0.027261026196121693, 0.03594487988119645, 0.029804918824905352, 0.03283241020155049, 0.05122586716747573, 0.041163865356676044, 0.018927259370684624, 0.04702260702728264, 0.056055492285879395, 0.05947456567458088, 0.05870722136610459, 0.11542340319964195, 0.04492005956689677, 0.10541293995394822, 0.04298911963198935, 0.009981618120124745, 0.0501636594473835, 0.029355895540286458, 0.03196061555025799, 0.14511137870290589, 0.07339674664000351, 0.04767690740165211, 0.040681344877567985, 0.04025309023657634, 0.031193548948654247, 0.004549077017262819, 0.010136061445659688, 0.05260814642233234, 0.061907469400114594, 0.04406521269570916, 0.03078384704196886, 0.02182760696497656, 0.04867850990605451, 0.0010554548944421715, 0.08033969424544804, 0.03437361439629909, 0.015161797411799913, 0.011024907298926866, 0.02361971836146568, 0.008677910758002151, 0.042432162219718586, 0.05634282505319965, 0.12296957609754418, 0.04271165790757345, 0.057816487106104056, 0.021542493937416904, 0.08080450277174674, 0.04055482928731269, 0.01821041940861652, 0.12152979045265144, 0.015555965928210607, 0.07056757627475647, 0.07246825573665482, 0.04558825294577307, 0.04876651042591661, 0.02814233374421395, 0.06092340264829898, 0.052147045761587164, 0.0876249299354611, 0.708407448424447, 8.147729712147868, 23.57555497077204, 38.655707220877375, 48.87257545225082, 40.769782373982096, 31.349992713620587, 24.67733306269492, 16.184671098186126, 19.28695309546686, 34.27254092308783, 32.879785722301854, 20.96962440398432, 12.79662972496402, 7.149846871053019, 2.199144252846318, 0.30337801924155605, 0.2543578609343498, 0.18590094882153696, 0.0857984614107878, 0.5018530755994782, 1.1088164174749007, 0.9174167653245311, 2.9550153834204522, 2.135589108351738, 3.70773783133876, 2.2309652163136393, 5.64110767456793, 5.902641511732533, 9.311892121068894, 6.488613707403983, 8.94536231794665, 6.1561143878967535, 3.690692436310553, 2.5455248403933743, 2.5034248155932275, 6.774490754450522, 22.143962421724876, 39.714056830252375, 48.897686466093994, 51.36285689569289, 46.81134247010755, 51.04438004955169, 27.87450013622161, 20.263397732088645, 33.23649783288279, 39.46968140140657, 40.878090781550256, 42.689194217804946, 40.04409682366156, 30.946994673821237, 23.108818415672552, 19.787602463076194, 10.85611847139174, 4.713761796874385, 2.2471547991998735, 5.717883658024573, 5.971592856991676, 6.727577246004536, 6.0929161790878545, 5.145010707839843, 6.225130942560011, 4.2244368022488015, 4.709847271442413, 6.227303445339204, 3.2859737017462334, 2.7975258471504336, 1.878558274719023, 0.4791852387209093, 0.3042370183092933, 0.19033603099805696, 0.44558854473214, 0.7798323996605412, 3.7615105846235832, 9.43670880409979, 16.3948061966127, 15.290813926727543, 25.205131115451938, 37.453696881571126, 11.818029745932549, 22.187488963527066, 31.41431958444657, 42.32180933798514, 29.991162092454974, 9.004797012575212, 0.8451493625198642, 0.031108758337194883, 0.06125232632902842, 0.02028393405189197, 0.07569956863599439, 0.03684704034258762, 0.07482660378539756, 0.011297333910460434, 0.08398900003803354, 0.07352407811389816, 0.038570305332541466, 0.06039184488115772, 0.062474696221010345, 0.059375407084101633, 0.038132424796781236, 0.05916560241471856, 0.05119709290503975, 0.031245556742613836, 0.03367858112699563, 0.06046926955722513, 0.04556406371956391, 0.05649133119732142, 0.02149102623544393, 0.08751950857620086, 0.10606351714100569, 0.062189186742949876, 0.059170815643043294, 0.0362165346591463, 0.03220552811399102, 0.04642736820143558, 0.01712075126687846, 0.02966596962763898, 0.021181645457662886, 0.036425925641050266, 0.03555987090353043, 0.05597411842656232, 0.027617462009431857, 0.022186662798987764, 0.01716928676732125, 0.07833031456797354, 0.0271431386711136, 0.08311711537140994, 0.06664244818591303, 0.22698098883753826, 0.21850131482126253, 0.2810743805621901, 0.2408228339927812, 0.0960563863777826, 0.22465258716575562, 0.12688436199940983, 0.12851115736749866, 0.22982466124719192, 0.2826692224029572, 0.17440359318448653, 0.12377249752922405, 0.23898238436348979, 0.25706058848769436, 0.11681189925800409, 0.11472682243273144, 0.14938429538761416, 0.14545104676677337, 0.12781917312813382, 0.1938937126748985, 0.1545410017452894, 0.14794397348117444, 0.14763432074218028, 0.24588561797093964, 0.1846705196845916, 0.1358747638521656, 0.18012528938631858, 0.1612270647479642, 0.1942204798181211, 0.16494934807621664, 0.20113721189479675, 0.24215437141397309, 0.09923313849515493, 0.18392313962742207, 0.2320454275656131, 0.1650819732176681, 0.12052707329031923, 0.2547245565801859, 0.2849360152838692, 0.1583295670007506, 0.15029456105924424, 0.12268578648687371, 0.12996290930576865, 0.16823499193114622, 0.1640334439974639, 0.17247228552737545, 0.11938388624619092, 0.2650193533589763, 1.1590668823449843, 8.94988481075533, 25.08396713964401, 42.735548788501376, 56.55235267454579, 50.20788361949306, 41.804280050339244, 35.01986226727886, 23.61057585285556, 28.072387633785127, 50.836121805252574, 42.19638762935516, 30.094138037773874, 16.485100138571955, 10.143151206354942, 3.3337226750389224, 0.9228572766146353, 0.9891951588853714, 0.7959260070516218, 1.0956767225457777, 5.879969231544003, 4.431652676674628, 6.719153465763216, 11.174262896660837, 7.584765159314679, 9.223971213063887, 9.354278233743484, 13.601145109822674, 11.058721638494923, 25.684403565622148, 14.984764129884782, 11.94088230209966, 7.103129971411921, 5.851858585111557, 3.692972068825076, 1.9475314381622502, 6.855253827187323, 21.746659663415727, 41.22636979626071, 48.59595029584823, 50.62858135469499, 50.17623793694281, 53.9425919132848, 30.5817533693006, 28.91195135731851, 37.190482308787686, 43.4787751782325, 42.547745704650886, 47.54566900191769, 42.69208892699211, 32.50544648016653, 25.157180140095374, 23.1098598049533, 11.687364808974728, 4.879965859074747, 2.7499185694802195, 5.74183855325945, 11.11267384021513, 8.388329859702818, 11.936087204564004, 11.106046995809002, 12.189799835605006, 13.228327747314209, 11.354559544594059, 15.09730379427633, 10.710853492060016, 12.354558994693141, 8.437858608461196, 2.654413023302632, 1.9550680273002194, 1.2607885272272172, 1.0895290201710117, 1.5883352415215586, 4.483464244873294, 11.661555613240889, 23.421299919005364, 17.689977730474165, 40.60285806655884, 41.47521672710296, 12.72659678612986, 35.48221557371078, 38.064974738705544, 50.39496106486167, 34.096567707677046, 11.216492114528533, 1.1763156277518119, 0.16038361726508987, 0.14939889702345097, 0.1522551639185798, 0.2655869938673512, 0.0849958923795531, 0.15354776875145976, 0.1313837266136562, 0.22740428305922017, 0.2320089311369004, 0.20360571572617178, 0.13581957487810042, 0.2731362387778298, 0.24167015788055238, 0.10754366029774952, 0.19351846748782744, 0.1587225394623895, 0.13111950288857185, 0.14268341624448377, 0.16117035891980896, 0.13481305791966378, 0.2336267556153959, 0.2151908650393448, 0.16973819433441087, 0.19302709869319395, 0.18770718496413002, 0.14259430489713146, 0.17182567667576576, 0.19593037274335662, 0.1055693751080863, 0.1402143455080448, 0.11089360191216392, 0.13495892106044677, 0.09650193545366488, 0.12833773804407927, 0.2138285308835968, 0.13506667898787608, 0.10871913794788624, 0.12155478790162072, 0.17899121878848923, 0.15911315237322163, 0.2342327005199848, 0.2073508437963263], [0.0940624357111031, 0.07709679043581409, 0.028583632947336284, 0.014716443688338323, 0.018302914949374336, 0.05662176532730941, 0.03216974031660826, 0.018978096965339877, 0.08320777421636928, 0.07408009706846169, 0.06064040976906977, 0.02094939058165877, 0.026275375557522622, 0.04805106474387069, 0.05318399556281586, 0.07403199440769612, 0.04809990284904357, 0.062388438551175984, 0.0935399943902608, 0.09058512431839782, 0.020210447067755367, 0.06877808681418819, 0.06389986490830779, 0.013886784830491149, 0.059705985514747525, 0.09422149088594223, 0.07955357312194763, 0.06817992536291, 0.0479174628403158, 0.018905197953685157, 0.037690269490403515, 0.04277415919087587, 0.01352554468828584, 0.05573367024020803, 0.04774439974778122, 0.061126595978895505, 0.0031878462675282914, 0.12342013538845124, 0.03374166463712051, 0.019057885022653688, 0.05910064965005844, 0.06487237139334602, 0.03362296697413249, 0.01664781263248334, 0.13319411495279881, 0.05065460306321902, 0.03148039525014258, 0.06868159037924583, 0.07267873073297162, 0.6331753466398485, 6.052718748969417, 22.302971386140396, 31.814728859932195, 42.68917460595408, 40.84680987942604, 38.124786961463194, 31.728966236114506, 45.59771799272107, 35.745857684843, 23.898622951199933, 25.343074990857033, 17.92641624327629, 11.984027393402593, 9.046070152713407, 5.3877181487698715, 1.2200298304519346, 0.7233769903259893, 0.3290947328411764, 0.4035715945065022, 0.46923541133442237, 0.2708295786813382, 0.8394412107525334, 1.2058940986471793, 1.6519869743816316, 0.17995774595727845, 3.089812537354808, 5.803447221556018, 4.796146769677439, 4.853358951307112, 10.535317620923443, 5.479907576114901, 3.744934648275376, 2.6680805221680672, 1.3490876988057168, 1.7034063055630655, 10.8100345442372, 20.89668400825993, 30.138654978044574, 39.14314408456126, 37.32825163872012, 20.860560940157985, 10.710145504243913, 14.593985253764739, 18.434361219406128, 15.02016842365265, 20.23596859747364, 17.95179593947626, 23.879909323107814, 16.780788014012, 8.813903101028936, 9.96816642822758, 2.922530313653331, 1.5308752151266223, 0.30443053211896653, 5.240287040510486, 2.959170889469885, 6.85893448129777, 3.7382560776126, 3.426446035023659, 4.248957009084763, 1.9586230429910847, 5.071372620521053, 2.790557266243043, 2.026021007087923, 2.4246518554226046, 2.6627603173255925, 0.4328078079608179, 0.3184656919010224, 0.4569129483594049, 1.2844335552184813, 2.4895999316246282, 6.891917692076776, 12.832415469231146, 28.96839426409814, 22.457324497161373, 39.45010092950637, 21.321527688733994, 26.408582925796512, 30.13568574382413, 38.30032871615502, 26.526475644880726, 11.23059597707564, 1.3141262651451173, 0.016121619396031867, 0.0499628524806711, 0.07731247483001602, 0.11084226636035789, 0.057796584141831246, 0.03252494081314052, 0.07104121013394288, 0.07470104197460799, 0.07860954595549453, 0.003200174537449775, 0.005941472941964504, 0.013886941878515628, 0.08828798669480509, 0.09941764311083864, 0.04161240600590264, 0.03467527683824301, 0.006714496834789433, 0.02737623432861461, 0.018228372679122033, 0.015159651408002022, 0.050218281516384695, 0.06164646707475186, 0.019327697359145652, 0.045673702392847314, 0.03792523631765958, 0.05712560986378982, 0.040214950549266035, 0.059289808249882156, 0.03893652983430413, 0.0028086978624830205, 0.015039530736694654, 0.06788642941823891, 0.07212461167646032, 0.02608496631916252, 0.056638113643613555, 0.06766341356260162, 0.022002416737978498, 0.10850231208267713, 0.09249101317818127, 0.019881261001911857, 0.13238780741249362, 0.01511270649761202, 0.03221477096479747, 0.03595800296733937, 0.028740719276209994, 0.04694249338260101, 0.02352905760128652, 0.021518802668358532, 0.050837154154695814, 0.06251978815623349, 0.05721992677858761, 0.04365929717858953, 0.049547222968671596, 0.09546354157669891, 0.0961642362357628, 0.01350051372296988, 0.047265908891154874, 0.04807886224420321, 0.05564756578795853, 0.15649346875086909, 0.04553845340025522, 0.03181993690950256, 0.056357683328491066, 0.034475917777707504, 0.029399215897184708, 0.024698730220177004, 0.035585147974592064, 0.015470683105259895, 0.060691718507798455, 0.013074413704265271, 0.03520972658729842, 0.016936258142513615, 0.08053215851466503, 0.017706352706638076, 0.03706804138698405, 0.039104333733238524, 0.04669940602334757, 0.07137592160894025, 0.05020092579446012, 0.014535322308450218, 0.0481213303282857, 0.00658043671489483, 0.017753890377559492, 0.0641593388882616, 0.0134127487751445, 0.053151528756584854, 0.0915991795820094, 0.028026727246000405, 0.03811393526472873, 0.029397015309622212, 0.05823033163323999, 0.026566973519361308, 0.9567455130238688, 8.299066520506337, 25.469226260339063, 39.126815257533906, 47.04695924635857, 43.615332495781686, 38.50301327243928, 28.210239333491174, 41.92959977734474, 41.819879316514545, 33.20701337629749, 33.70456995502595, 22.026673747647195, 14.189279021755343, 8.036058362453215, 4.6513696351358975, 1.3395607519534327, 0.5679658812380607, 0.2803705909079121, 0.1655976882865352, 0.05784068016275283, 0.5043282443957945, 1.2481496699394719, 1.7981869487031814, 2.342323756987049, 2.446997598294289, 2.4927608716872434, 3.623654962547364, 5.784886565900618, 7.597459420081108, 7.308946049982502, 7.628644224136107, 5.758331139241496, 4.950373874556634, 3.863649349058828, 1.815977716638196, 11.692010856443837, 23.710668856097808, 34.218945657053304, 39.82224364434519, 41.83341933834938, 28.523672011590776, 16.37165342607806, 20.277608479222945, 24.31514728453852, 20.681392954241847, 27.610104930016306, 24.870880457662768, 26.557889907590805, 19.24293233502296, 11.793308027328985, 10.86946237471796, 5.495277873931393, 3.2669470194847356, 0.696955414548997, 7.967007977347221, 6.76800266388924, 6.05692696186804, 4.970283335255039, 4.498537423149232, 5.144697898818601, 3.2039299751481707, 1.310004221816217, 3.1054779935267667, 0.819565580496865, 1.3740244123243517, 0.6619697112229563, 0.3547606701331754, 0.23761160791881625, 0.1167097261115428, 0.9707967912958515, 2.780738102812921, 9.648936487013295, 16.568181822376868, 30.983872798181352, 20.228041487355387, 41.53757849047261, 27.941027456714263, 23.79041652525625, 31.853389701535626, 39.27572804112589, 32.06557816074741, 13.660118925955988, 1.8137423333621796, 0.16105316278915252, 0.09817131764946446, 0.016351164236003836, 0.04125914754225843, 0.07317890953873435, 0.015114992312456091, 0.06077384696372094, 0.059013683348894126, 0.05214621838662894, 0.0317344319210538, 0.03879267384388274, 0.05899378804550056, 0.028102887876992746, 0.010690915946578308, 0.02885348741866408, 0.09522112837481884, 0.01976515463132772, 0.059275290883717045, 0.02261406325194384, 0.024804934904339816, 0.015687508970468996, 0.030407379944658572, 0.041731808469780994, 0.025292438785395315, 0.0475920018770041, 0.055306675813851826, 0.028407511248764013, 0.011960351407798308, 0.08657109938682088, 0.03447397191437983, 0.06120209394383335, 0.13447449302240727, 0.05523522662359381, 0.03826694217540565, 0.05683483736168954, 0.020967841809315067, 0.017698349003049157, 0.01665841145891576, 0.03590250755810449, 0.050822046900829004, 0.047032236752490846, 0.02127285780114753, 0.08221253407217803, 0.216336227773178, 0.17739501331121693, 0.145917241912215, 0.16836473658200235, 0.17941875713727168, 0.2021687646065989, 0.19146257861246987, 0.12211678234199363, 0.10690552437858236, 0.2436176912798997, 0.22073197899566543, 0.12398412931830653, 0.14852885096784563, 0.21559286201673172, 0.14238488710215016, 0.27793118309590126, 0.25333259014352677, 0.14136822713959601, 0.25459983746611303, 0.14666762503404773, 0.11652169749140741, 0.15210384623177592, 0.1081256955982216, 0.08827595145351465, 0.16686053826443611, 0.19270995361430032, 0.13531544305864843, 0.1800757694628931, 0.1425396368628548, 0.13452197515195416, 0.11832766550322694, 0.13900967224711372, 0.12159769648625968, 0.17717896119481136, 0.1458180028825037, 0.30725552730502625, 0.11390215942576049, 0.23348346653003849, 0.10827890552219846, 0.20611019504647102, 0.17931061616588026, 0.1786204015896205, 0.26322030312111305, 0.24849736492239663, 0.17033667754261725, 0.15309481160534968, 0.09529730049713005, 0.2184412994932744, 0.11721599531630356, 1.2427698941000047, 8.478479654558244, 28.31124036542831, 44.049346677718624, 57.20726689984722, 52.27854990190076, 49.74190996539209, 43.20053008294875, 56.07964823322912, 44.37256959176833, 32.55997527030207, 33.9826032423204, 23.737899911019113, 17.332292872090495, 11.830181248726385, 6.867145963253514, 2.352606740690047, 1.4544006413029087, 0.931577502239135, 1.0368624978488492, 1.9536145440032406, 3.0410971901109143, 3.5256413057927167, 6.775813083494864, 5.453445305747371, 5.327865721717958, 10.464147194739311, 12.2545571865574, 11.571851987992565, 12.484917006184979, 19.378197231600364, 14.087560196076671, 9.484722537379112, 6.273466310193462, 3.495995296585945, 2.6226278514631334, 13.075301378004013, 23.236813199135568, 32.71575612406577, 40.983367196975216, 41.8991857190286, 29.324788662695116, 17.756950239981375, 20.653187190332723, 24.824108154542987, 21.931844565176196, 27.981714202511696, 31.49628535393746, 31.87280739507368, 21.28644012635754, 13.397011237759745, 12.243101904469153, 5.700239856396952, 4.028798538830973, 2.8577205009998816, 13.931401814183882, 9.763058827769372, 14.974507131884176, 10.39860438915991, 10.251755752871114, 9.848005598591222, 7.5879883670037795, 11.187654849021666, 8.903380209399808, 5.577174511647994, 5.065447390079498, 4.913302083169261, 1.4384153893878384, 0.6509475446035785, 0.9846553831331193, 1.8355266870029512, 3.5787087678909306, 9.557059868689507, 16.70330551362807, 37.15196855606572, 30.459969659005445, 48.24939320164342, 30.52127826598383, 37.22989428427912, 39.946586701177786, 48.7124054662643, 37.073085769530266, 16.600715921771144, 2.430913919402707, 0.27915447229339235, 0.210621947302453, 0.14782536774873734, 0.22142334270381162, 0.21794306655083934, 0.1439213377213286, 0.1261662465009478, 0.16283482283113465, 0.1853819855398709, 0.1291483433376397, 0.11053698798341137, 0.18707202146610907, 0.29877689516832756, 0.13660827771790568, 0.16602726442919624, 0.2081681063939487, 0.11340019563513418, 0.18117259286584395, 0.17796533512732676, 0.12164113367156637, 0.12584701000202086, 0.14190150094368767, 0.25785425557724895, 0.17945744457744783, 0.21243019059540766, 0.13969170500434216, 0.14444039293354557, 0.11522330869469913, 0.11016688324631223, 0.10710722766816617, 0.18040852741368357, 0.2786510912401061, 0.18164641824701142, 0.06788047691506725, 0.19226415172940303, 0.18484016219454427, 0.10760077215250462, 0.2383946570297403, 0.16136368886838037, 0.19320599554527193, 0.24822322801957208, 0.19959536801663139, 0.1819148554556793], [0.031675531250995495, 0.011147508179889092, 0.04015292041003704, 0.0652659643862036, 0.0913065952819682, 0.015281816576457313, 0.004858092466864976, 0.07448603939865867, 0.03812371437708217, 0.030387515284781976, 0.048353657982642614, 0.0484405821489711, 0.032370673687828165, 0.028231797492011424, 0.02689354147972359, 0.02932864196238018, 0.03882138298884515, 0.009094536184303222, 0.017415938350642403, 0.018107625730936567, 0.036859450966960965, 0.024432424651158434, 0.05915665450776297, 0.030551147834968664, 0.052780742201233105, 0.047063347583095876, 0.00436066200153061, 0.031926078391411615, 0.01990672193407532, 0.006991281529002253, 0.057094058532628326, 0.015914502737653113, 0.04621973156087822, 0.07232260710049061, 0.07541724225325931, 0.06943211905778417, 0.009215481357739098, 0.03149586256533381, 0.07332660362965639, 0.030478325432106376, 0.0641529880193693, 0.07090855434897446, 0.047268659146803046, 0.008918815724281295, 0.04406762970311027, 0.06447650311935334, 0.038664254525135604, 0.06843009903546303, 0.007519647582328969, 0.046722063073708166, 0.4606207526258884, 4.227557047720879, 17.19209755620649, 30.660667534797426, 42.50761985778809, 46.44032547550817, 42.14972319141511, 20.805712476853405, 13.898052842386308, 22.08438357999248, 23.13650250434876, 16.213086708899468, 16.509897362801336, 14.123972538978824, 8.735499824247054, 5.717117815248429, 2.469752003108302, 0.9289698615189522, 0.4395544685183033, 0.16138852543888554, 0.34703602173155357, 0.3956565885774551, 0.6057263550258453, 2.4901794618175876, 1.1650951975776305, 2.2316587403897317, 2.6031679924457305, 4.268355090771952, 4.316700754627105, 4.530074750223468, 8.429256850673307, 2.6451466689186716, 2.953107640627892, 2.4140950412519517, 0.5353676143192476, 1.1039867540521007, 6.148176981556801, 15.448217661150041, 20.42509940362746, 14.5575709496775, 9.997687166736974, 8.592103854302438, 6.986144300430053, 8.640922654059626, 8.415077482500385, 7.4363706188817185, 6.312471830075787, 5.865555501753285, 4.979563172786467, 3.5796069906603907, 3.8604241801846415, 0.9880969565241569, 0.8430827637353252, 4.129160469578159, 13.253256370944362, 4.775911261958461, 4.699420630931854, 3.3500649852137414, 2.5047216492314495, 4.455689451386852, 1.699654803641381, 0.8212233947650079, 3.367409460967587, 0.6371708935306919, 0.5531616304670611, 0.154056420489665, 0.5494361142477682, 1.1349723752467864, 2.538667066443351, 4.582339842473307, 8.347048874824278, 8.04875115233083, 19.29974982815404, 35.377806002093905, 35.180287207326586, 29.199874901002456, 20.37902528239835, 37.49747445506435, 35.61548202268539, 25.70844965596353, 10.48226756434287, 2.005612792507295, 0.07423046480623946, 0.04113133343297147, 0.007125295683621399, 0.0061744010177320775, 0.0797210859074708, 0.03115611597745409, 0.059409444370577415, 0.0372394880339984, 0.03621604053243514, 0.03584753308865813, 0.035732052994952086, 0.05149860979027806, 0.007423945963608042, 0.03679967695666898, 0.05118766619313148, 0.027593364713773615, 0.028320349595179, 0.024742171235923326, 0.017087675420747652, 0.04082526981590256, 0.04717176817657967, 0.03643338733743276, 0.03836164979504482, 0.03713162285425971, 0.04449220329162575, 0.057060304698684526, 0.033833487935724764, 0.061558704042146285, 0.02474892621619567, 0.04174228472214553, 0.017389696008796175, 0.047733739634314855, 0.10882452866362949, 0.04569472767592919, 0.04126149943218597, 0.02116772755529852, 0.034316441254510034, 0.024193453099278193, 0.025391580138896263, 0.05960559735314981, 0.06168353806940779, 0.09740106986775514, 0.04912859422244853, 0.05159098084174818, 0.019997443981288422, 0.05920499848622469, 0.011194288381375374, 0.08378443924049217, 0.006620756879959617, 0.05036217198076268, 0.051629476759943276, 0.04430152400727234, 0.018916986131620024, 0.064317945901665, 0.026844582715702635, 0.04542498045691079, 0.03802478944341983, 0.017568171512515798, 0.018913600022994706, 0.03063987230791921, 0.030998637028519186, 0.05136128469941117, 0.04591665185627438, 0.03453226737497795, 0.1242239301603648, 0.007403155294952975, 0.06949475440647333, 0.0395783927712229, 0.021446093263465072, 0.023832288608255408, 0.07265859794232153, 0.0664304486746269, 0.06376242107381264, 0.05355046521271429, 0.07338375378880771, 0.04622014141791771, 0.09257491512764847, 0.07721368013130081, 0.036185504267773325, 0.04453501611527416, 0.0476619074000947, 0.014245362817159584, 0.02246965567821697, 0.01063696324690095, 0.036966140201735886, 0.026373844668870012, 0.05141690268271393, 0.01166130802894552, 0.06216308612736964, 0.13691014700358914, 0.088054375843175, 0.010313434740378252, 0.022142790858784032, 0.03494017472070071, 0.8146415963288277, 6.48839601585942, 21.503388381773426, 36.40707515901135, 46.97432479550762, 51.362700000886, 46.30215214144799, 28.392882539379983, 16.018053716228856, 18.94407714566877, 28.564974569505264, 23.908791695871663, 22.55997684694106, 18.875304268252467, 9.666534200791391, 5.212146976301748, 2.6306258093926216, 0.7891379777462252, 0.4272021281142389, 0.14588356468706362, 0.1467400663081677, 0.12973191847483959, 0.32147154512424625, 1.2848329015316502, 1.6471199258681268, 2.4607874260794733, 3.957603107536993, 2.7234202623367314, 6.566237413114117, 2.9230012432221444, 5.466584755528358, 3.611367892834448, 4.950901433344811, 3.6864271038962952, 1.5192607093241908, 2.9146752770869964, 8.666054260346199, 16.869298258135398, 25.082054984185007, 19.805696356681086, 12.496086935843191, 11.02014316666511, 10.221483880473722, 14.133422509316476, 11.469379086648265, 10.810516015175851, 9.164716947463251, 11.191616442895706, 6.342470607449932, 5.128619122889734, 5.269823468500569, 2.590445539643688, 0.8761773330550041, 5.1984569238078215, 6.824900075312584, 6.208160808009486, 5.65082730785493, 5.291072908909091, 3.9083349512469385, 3.4028257669941073, 1.9290915179637171, 1.543314521831851, 1.3395282698254432, 0.5468464919155644, 0.36180487924045135, 0.1558958435611379, 0.32207552884374896, 0.7371201786783435, 2.622222621594706, 4.649092208954596, 11.836603149291008, 11.297685177095476, 21.943876435679776, 38.440879006539625, 34.33260809990668, 34.47265240453905, 26.02937209990717, 40.912427210038715, 39.404240577451645, 31.70375127946177, 12.688933207142739, 2.7704450680363566, 0.07217944825008031, 0.001415913746665953, 0.07503005375544872, 0.0481824143489282, 0.056486259695262685, 0.023780024174841183, 0.06500269827102462, 0.006239264245866048, 0.04065733568202104, 0.027580881311047464, 0.027817401381570007, 0.027051344100806504, 0.008443827804688726, 0.07817284519513769, 0.06375494788611127, 0.03127534224110986, 0.04550345467343446, 0.06923381719858417, 0.006168719996968585, 0.060086168138490575, 0.050424516216040625, 0.015978287218228703, 0.03523647454717467, 0.031552227484362746, 0.1314737572665176, 0.0047904138656092755, 0.0034436528409470717, 0.052344512584949696, 0.05173862130651551, 0.06099690112375444, 0.043251642641881784, 0.08306387226067244, 0.02571904059169033, 0.028856369824479186, 0.03133525989288765, 0.02740267010766172, 0.038470771358979326, 0.07369671602763476, 0.06748568116416855, 0.029106805882146283, 0.01752363307581794, 0.018711705211429827, 0.08827386003348135, 0.058612123041624026, 0.10081664989552191, 0.15122404021601524, 0.12400968601146053, 0.1975686824129474, 0.1611875499328298, 0.11173170210132677, 0.12299613636587897, 0.272375758617155, 0.21475839308432995, 0.17194947648432948, 0.16203159496428507, 0.1469197752134454, 0.09505031375034202, 0.11342492495332995, 0.20462965352400658, 0.13393780246617334, 0.16924097262803586, 0.2267912901457279, 0.12523650687428253, 0.07874885904452494, 0.24648040863535098, 0.0765711315456898, 0.18966176637238075, 0.16885866411030295, 0.18691920224697361, 0.18216627019066967, 0.1337541865124818, 0.14177626088982628, 0.14041878373151825, 0.14490263506529794, 0.1019300897455504, 0.22829832298861397, 0.25593633913705427, 0.18400825199580964, 0.15905678362375306, 0.19438042365495237, 0.19264345718247278, 0.11340512924136655, 0.16345279531613474, 0.1261764814356162, 0.19325061250598202, 0.11165542272670616, 0.2622169424449244, 0.0937964806273099, 0.11964982600822566, 0.2962493259579905, 0.16764890402555468, 0.1955943819015257, 0.08970325752612084, 0.1561245208065356, 0.7885368132302839, 6.692759836873701, 22.807678445692986, 43.87385199146886, 54.94434564344345, 59.663710055812714, 54.52742515071746, 30.781692266464237, 22.322089018360263, 33.323111611027876, 34.766857624053955, 27.01687389804471, 26.309821567227765, 19.651282448922437, 12.642966951093367, 7.925128340721131, 3.8403683660491823, 1.452914185581669, 0.8981363547425117, 0.5409721909992157, 0.6868614400586774, 1.4339789435748131, 2.1569780380495134, 5.826903485482739, 4.11028798549406, 6.4134052011274525, 8.932102745579137, 10.018770887005715, 12.79705334094263, 13.0421563694554, 16.565300841485303, 9.475559880656581, 7.284094402866979, 4.976896941661835, 3.016963827033197, 1.9137604438489484, 9.153047896200611, 17.91076990865892, 23.392625431860647, 18.460652866671165, 14.845263073521277, 13.136921813411098, 10.430048069646283, 11.984231356651554, 11.949475234554662, 10.009738649091414, 9.37231231120325, 11.190816279380552, 7.842773766286912, 5.175266890756546, 6.233648859685467, 3.6077370037955627, 0.9354733964127879, 9.386644651812892, 23.538476805533133, 10.624277957024114, 11.311762563643917, 12.65791412322752, 9.265175711724067, 13.346495032310488, 6.548475450085056, 4.159774078476814, 6.855570068282466, 2.6606145356932, 1.701214436081148, 0.7909927072544253, 0.9645139510112425, 1.7635275375458503, 3.768423271756019, 6.317404210567475, 12.98442888644434, 13.617436674333389, 26.632450242196363, 44.51737957616007, 42.69746649649836, 41.6397483887211, 30.37651535003416, 48.688702583312995, 46.262387152641054, 36.20629687463084, 14.610009116511192, 3.480481341961892, 0.1568112879871361, 0.13151132621832434, 0.14935420345394843, 0.1163558777601969, 0.16437228468637313, 0.15709294787337705, 0.2014434632034071, 0.12492764320585037, 0.10567268972555477, 0.06509708796417521, 0.19597699685442835, 0.11298139068868854, 0.09353558172381694, 0.187947828502905, 0.21233594645896267, 0.1060667576929254, 0.11438441943497428, 0.14724890190747478, 0.1618636378477658, 0.15006424438568855, 0.19625638912041343, 0.11224339520859142, 0.11542426121811714, 0.14212274713621986, 0.2993583252593395, 0.15266065425690145, 0.1289663668121061, 0.1016668925782846, 0.11839260677656821, 0.163878403123348, 0.17153991055825066, 0.2523963387695051, 0.1859611786541439, 0.13321982486353767, 0.11652876848294852, 0.15515230926534823, 0.12346092190953994, 0.11195104839580675, 0.1314068011819355, 0.07356997444144181, 0.17537988031343107, 0.15770450054157167, 0.22460964027672048, 0.18114777161709725], [0.0053439846904497715, 0.046209527269726804, 0.027235668685828007, 0.02704313738391765, 0.019668311541599613, 0.04776794162969436, 0.057647576210119074, 0.053730836784046505, 0.02950167824183741, 0.012528244725188181, 0.030102101567712043, 0.021095860847121766, 0.054785962021278764, 0.0352354058545203, 0.08654050183512511, 0.04679435113024327, 0.051746826108184554, 0.05742294007852193, 0.05404906204691338, 0.03440080668717142, 0.06287285509789664, 0.03416481713253645, 0.0549748026946139, 0.025438401517608476, 0.03467113613301227, 0.042510341492391406, 0.04214554957504715, 0.05032186426462666, 0.006936412396645475, 0.06008745133576374, 0.04249627611810162, 0.05786902541595121, 0.04073516638468831, 0.08053742919958408, 0.0636597001744855, 0.05084405660689358, 0.050510555550816565, 0.03321400242707422, 0.02700979149179353, 0.057509033039452574, 0.07361767873648675, 0.02962876648281611, 0.02767600453338556, 0.02982659911316249, 0.04729395920050241, 0.018316024628978585, 0.07019165693031204, 0.06993907774167676, 0.057633422735718, 0.04188866880271704, 0.046382843171276396, 0.5799017149594523, 4.147884884188253, 18.77327753651527, 33.615387024418006, 43.53519062842093, 39.8698063050547, 37.17976247110675, 37.138303018385365, 31.157659292221073, 29.626314986136656, 20.00132456902535, 17.200544380372573, 19.526872711796916, 16.983615736807547, 8.699455203548554, 7.835768413159156, 4.462010841215811, 1.5396044499451116, 0.7379622012376786, 0.45147547077748085, 0.3126114624882898, 0.08727420722284625, 0.4731767192002266, 1.4288680952402855, 0.9531695984544294, 2.3921346712496976, 2.8958599125185325, 7.086618754171557, 2.705524693573675, 4.57836599119248, 3.7169870253532165, 6.838870086977559, 4.763066480236669, 1.2141711577292413, 0.5040812882925234, 0.6599469939547201, 0.7405923342993184, 2.5834499924413623, 1.883304955497865, 3.3880357348149825, 3.359425721629974, 3.6166282815317956, 4.575572773333519, 2.468721890641797, 2.407679024242586, 2.1559366487687637, 2.0368380460046955, 1.0468781475097904, 1.1891844339909092, 2.104337133707539, 1.1211347435751269, 2.8458891616713617, 4.7457403905930065, 7.23831691088215, 5.0479884301462485, 3.552059449495808, 2.097910575328335, 1.783713893063607, 1.9851784696502073, 1.657738027072722, 0.8182452126376091, 0.5253401975477896, 0.3465434578397582, 0.21599518075104684, 0.5071418708370579, 1.7209684728614747, 1.9764212879442402, 5.039287632511509, 9.468751626629984, 7.8526365660852, 12.975700632218393, 22.729501685788556, 57.9767967039539, 30.680418629800123, 23.01679176668967, 32.477954587628766, 36.85524909727035, 22.646869113368375, 10.305114696102759, 1.908920606778514, 0.20358403543791465, 0.12052437666082576, 0.017008262746516737, 0.04806608772806583, 0.05587007985600541, 0.01855397345347991, 0.022898753015925328, 0.017525837493820057, 0.01942913506119963, 0.045400864009054444, 0.018890684417959665, 0.0540798319683921, 0.030302378018536878, 0.05671438535735492, 0.02680402410577142, 0.06924014508483872, 0.050084128029524326, 0.07076134289344473, 0.04376166950791113, 0.0415853745934944, 0.04045082902115199, 0.022950172837403034, 0.016612398302963665, 0.025452664159538767, 0.05049575090167984, 0.04762946740694104, 0.01595573933539732, 0.07104110288163347, 0.037971952359282204, 0.05613882733028262, 0.006057802914461542, 0.027138289334552906, 0.02910534456943072, 0.02600654764401336, 0.06605302779785087, 0.05863471880495068, 0.05565325016035669, 0.03114988768262969, 0.10068691290554502, 0.07940266912262287, 0.10910988875454473, 0.069256340183558, 0.044522268412214135, 0.022489623759963343, 0.022744273301213983, 0.0470302410934481, 0.03273498296978013, 0.032166576373480985, 0.016665411587323875, 0.0808969006362942, 0.06765821948647499, 0.017917216492576465, 0.04906965141755439, 0.046200456788703326, 0.04666090627471286, 0.007642019594523816, 0.04258811473846436, 0.08517844347102989, 0.07292935639739999, 0.06556322948346216, 0.04631409827139109, 0.01804027128063383, 0.039503752824760256, 0.0413427583783144, 0.008765638359041225, 0.027607824623344407, 0.03790185531421054, 0.03900173923841888, 0.05816197360775644, 0.051630131765118534, 0.020787677081722408, 0.05093763041640482, 0.021307289622904315, 0.01818499295040965, 0.023965978611921592, 0.036693366935416576, 0.11270372212053308, 0.07478621563002949, 0.030336574268256946, 0.023850146117770386, 0.025335858733723723, 0.05824730814164204, 0.018264399878981135, 0.042093252582896146, 0.033498761138968894, 0.018487364023683533, 0.06090358395369784, 0.052803345625439, 0.049534957901003866, 0.025898205574541807, 0.06050137247169211, 0.005972151411697269, 0.04632837815029968, 0.06131185136074501, 0.03878995806219117, 0.05545956015046086, 0.5643927245851487, 6.293966087602801, 21.775159605087776, 41.17513187469975, 47.961659892912834, 45.40841264109458, 34.64213409731465, 33.8294150752406, 29.624032166696367, 28.11129950707959, 22.3463684897269, 22.638200675287557, 22.069451116746475, 22.98646596170241, 12.99628326969762, 8.436423020978129, 6.4071578460354965, 2.152872297071642, 0.7054125962238158, 0.1911239677499379, 0.29106496382624875, 0.0394191958701178, 0.1118583670787273, 0.9039599099947561, 1.0515673410507942, 1.6253488102266866, 1.955323226509556, 2.188004231260669, 2.718144674454966, 3.942666476772678, 4.408486668140658, 4.381918984074747, 3.9285807551876193, 1.9001979909596907, 1.3184484719268739, 1.8451559832019193, 4.148283985353285, 5.756231690606763, 3.5871776553892323, 3.927416546690849, 3.5765262140381724, 4.856121280500966, 5.5572979007997825, 5.199370836057971, 3.704650926013147, 5.290203613619651, 2.4397186598470135, 2.0359008446816476, 1.2196200653429956, 4.42065337011891, 1.346280997799289, 3.381470177442797, 10.189617564601283, 6.602140828486412, 3.724765820849327, 2.040647893182693, 2.293965835725108, 1.2865173143725241, 2.1234020590782166, 1.2009484801561603, 0.5966487647064271, 0.3613000579418675, 0.28228501398717204, 0.13301592290161118, 0.37794049889329945, 1.6853745570105894, 2.149299017844662, 6.185096781099997, 11.71593927568005, 14.373216609801016, 14.74170465623179, 23.745613251962972, 58.683035142960094, 32.968533269820675, 29.209973043011082, 33.56273704959501, 42.12790304614652, 27.365607907695157, 12.984019979353874, 2.654264953828627, 0.18864162837065038, 0.055705474374154886, 0.03942100000717948, 0.012313640514959492, 0.03778223068483415, 0.008180675645088478, 0.04673474948973425, 0.06956189435215727, 0.05660045276125593, 0.06252767886185358, 0.02479808416307694, 0.024366864761818322, 0.024076379542689652, 0.024448357364763657, 0.044572431849496025, 0.005884747961611157, 0.037241391762490236, 0.020706630724992965, 0.011506461549640424, 0.05278407851414335, 0.03759048270782636, 0.033625414625050566, 0.0785383610655704, 0.030677234415986368, 0.0464332249436167, 0.01476915053752882, 0.032902089728703426, 0.07240722917260663, 0.06590279795589947, 0.050522759331450354, 0.030873033082893783, 0.02287485681834721, 0.014238805104527744, 0.06550277748535718, 0.034910251326378317, 0.005782796023038006, 0.0331115190150036, 0.01227188585025649, 0.0833119391914337, 0.037971680398069085, 0.0922164549269984, 0.07190932564797901, 0.033372743505864375, 0.02916201783884918, 0.028376042272054383, 0.11235756529194695, 0.12568913460258516, 0.10938838469765841, 0.07497586835656436, 0.1674179285163841, 0.1576713595779673, 0.1622331067318878, 0.2484494537836121, 0.1969880950186522, 0.1360767352725229, 0.1291021482358056, 0.10489589189209285, 0.16030630367177148, 0.16629812247570486, 0.15912899507149575, 0.2562290153676464, 0.0780608278188494, 0.23246596387076765, 0.14465489755234412, 0.11640893700983256, 0.11901938161181828, 0.11767646778495082, 0.2269936139665304, 0.13504067796372599, 0.1778800235760789, 0.10628405087176832, 0.1246277810705285, 0.177068046985134, 0.07628977809461855, 0.07867225791297613, 0.15382169114966548, 0.184104212169205, 0.21669521657449586, 0.2395300452987994, 0.19715474978570016, 0.10854106080988724, 0.13855214921697495, 0.14897972435480164, 0.13736054541603213, 0.1530499648182623, 0.1474011388997878, 0.11641945539703293, 0.22691325134327336, 0.12185864135502808, 0.21728239232493987, 0.11188622203565414, 0.18999596456846884, 0.13378585658727155, 0.12618685426611093, 0.18861855380237105, 0.2293492730466589, 0.867090059384223, 6.305134056075928, 24.149811537035053, 46.0207534605457, 55.1684541856089, 52.73593748769453, 47.66039048471759, 47.309997312484256, 45.77784892051451, 40.28472246662263, 30.545977430958903, 29.87436175346375, 28.91219258308411, 27.389171546505345, 14.101449308856843, 11.386377811431887, 6.064513316077571, 2.7432713777788225, 1.2822133711268826, 0.9412278198907453, 0.9328485953231013, 0.9687217349006284, 1.6128536097465025, 3.205303049856617, 4.765138472280195, 7.350276554784468, 6.243835255022972, 13.86508139871782, 10.068059390591038, 12.752386370012838, 10.266791178334145, 14.674462483775232, 11.138599726461596, 2.863926180908757, 1.270985709082696, 1.5352317426473865, 2.96024733493405, 5.217428447738771, 4.140046027398879, 4.299801713035953, 5.969560088649874, 5.647642833571281, 6.572904952110783, 4.44398460849639, 3.475706101425233, 3.716116014026827, 2.5744655584135367, 2.0817629127733173, 2.176199613078948, 4.799405278698091, 3.8558830561176425, 12.436151158425117, 10.036949111569314, 14.635427055820344, 14.072869939188804, 9.615147229163878, 9.191891128017057, 6.167616248130799, 5.979605278661174, 5.243410227760192, 3.1910192485778563, 1.5013434449511192, 1.3189349684023088, 0.6057083366378662, 0.9256380532057056, 2.6712488166747557, 2.8718206863249502, 7.955661050734982, 12.56350463436496, 13.353875952382243, 22.575701628961873, 30.446221751551477, 63.880183466019176, 39.14500721039311, 32.702267093043176, 42.57560629998484, 47.85923111823298, 31.024965509291622, 14.877322566124702, 3.2993453068117944, 0.32693350687623024, 0.20325480149157588, 0.07628235470263228, 0.11052903599075733, 0.16393740721527608, 0.07480705322156991, 0.11417374525579715, 0.18790958539372493, 0.14945685923580201, 0.10524929591244268, 0.12220144271850587, 0.07522138421453776, 0.14051197066662774, 0.11475407984107734, 0.11793458578927864, 0.2811006420562344, 0.10391158382258109, 0.1751775718143871, 0.10303534011566833, 0.2067781317858927, 0.22651413485648172, 0.0697805128631092, 0.18048683692130352, 0.1346586299158873, 0.25819976123109944, 0.15756452095604714, 0.1304810452124765, 0.22281857267502816, 0.20316051138985544, 0.1112855095115881, 0.12160132008214151, 0.11805589581208846, 0.126471861956581, 0.13795277734677638, 0.10811303216483324, 0.14464035720354126, 0.1224724463217201, 0.07137895531712041, 0.14406854917685832, 0.16945890932073518, 0.3022155267817359, 0.23672052508881017, 0.14760478039182004, 0.10609888742046972, 0.17601895085986585], [0.09736930786241448, 0.05686107587309615, 0.10933236834863502, 0.028826850541536848, 0.039265851880754196, 0.013981397646749693, 0.09054396241422623, 0.02090964402492729, 0.11805377374853819, 0.06504702411832348, 0.009173188516269288, 0.016724547829418894, 0.0053296473549468626, 0.027521183909547907, 0.04841503694713597, 0.043442731783274686, 0.019345359516239936, 0.025767470755043532, 0.0021072684772192474, 0.06280780657224598, 0.04695396937970673, 0.06760381958297185, 0.01586714605500381, 0.028668904278968132, 0.004137819952091142, 0.04973821251863434, 0.0709402397455227, 0.08265563932758185, 0.044248223439940525, 0.04830372820217763, 0.052199955624077594, 0.08021009515129751, 0.07375572011956284, 0.06780044370961767, 0.030061807258114703, 0.00879333722555349, 0.016869010944520275, 0.08499699554616406, 0.022164781412650502, 0.05887587179219531, 0.06335660131768354, 0.05200981260127118, 0.03753922376481276, 0.005622244103916831, 0.03160966109604605, 0.05066365439204439, 0.09839772727460631, 0.022550866743850134, 0.07710447429769463, 0.0018196564469103432, 0.028782074617582466, 0.08211586143701308, 0.2146262275956331, 2.4720326162153676, 14.471961298296529, 30.956835900583577, 42.795847385160386, 44.53168053780833, 32.1705388253735, 32.549675126229566, 34.07244120874713, 23.7896869644042, 18.29583683321553, 25.704690064153365, 21.268161881354548, 16.08746397879816, 8.716675389197565, 9.36253874532638, 8.817316543671394, 3.7819061740752193, 1.3903615743883195, 0.47417897670980425, 0.10653358103046495, 0.2659018253607135, 0.7092952523981372, 0.6188356515861327, 1.4478664628921019, 0.5190554573651284, 1.8973219130308399, 0.7888311748543094, 1.9920878472828099, 1.5590613671848852, 2.334796238330103, 1.9330478411528373, 1.7229134781706719, 2.0669657712982548, 2.780539042526676, 0.9909379169825585, 1.2670666484102127, 1.7548453711694287, 0.29831874394609087, 1.6240258683120052, 0.755918137729168, 2.1555564240101845, 1.6380087502541083, 1.3928177135605968, 1.1533041851174448, 0.2190705641142784, 0.7705797122851495, 0.26496983343555086, 0.8474697509119589, 0.24629932077180958, 7.924640986227221, 5.277569168998349, 1.644324869398148, 4.147622085386708, 3.2277083637252932, 1.7951778779106757, 1.8091013114298544, 1.3856897863649553, 0.4162479288155033, 0.4543123862916424, 0.23984550498425963, 0.1479406333378246, 0.7564980356443314, 1.788390093753415, 3.687965898744522, 7.0599682100357555, 10.724472941890841, 13.414916857596367, 15.851034291328924, 15.08515033029741, 23.593346841873664, 44.34401865928404, 25.123073170262, 29.36159618439213, 38.122096215524984, 22.767125060481412, 9.692386542597125, 1.2802249745976542, 0.08974154660057637, 0.045635382674874804, 0.04204047295535284, 0.05689848394643876, 0.04752003940783682, 0.05901835265479261, 0.03027318432296236, 0.10259552137745966, 0.049366181070405635, 0.06143461312017134, 0.07438478555770651, 0.06831209851248611, 0.04553495620888087, 0.04548305375201087, 0.017581468883661494, 0.0322052370005798, 0.010589596030542688, 0.05536965590210692, 0.05004938211171858, 0.026173911042391296, 0.031017260625958446, 0.022091392104724245, 0.015343241506226122, 0.028638597840683597, 0.023847554825366508, 0.03363124072371471, 0.06230469748017289, 0.04511421689042642, 0.029264351863774563, 0.043440900833135655, 0.010468962080326053, 0.03745548269380966, 0.05461563769307348, 0.03391837813861428, 0.01589612524595953, 0.01873123087739993, 0.04885496293765403, 0.04501879297857804, 0.046938486742757024, 0.06803844424505388, 0.017015278196683335, 0.10399720180899867, 0.04334261175245047, 0.04344297310097083, 0.018058824014940092, 0.03582926955254328, 0.07411262516172663, 0.05190852045592281, 0.08174660705750988, 0.043220098971599535, 0.022014315998662385, 0.10421370591727958, 0.02949260776081393, 0.048685002501212785, 0.0697138095875421, 0.025428815842455915, 0.05936820968805302, 0.005247706590565823, 0.04340834975723298, 0.07521468094520031, 0.04413591878068063, 0.05683246248912427, 0.0035499367673295524, 0.0733799233491863, 0.04752295820282833, 0.062579405118501, 0.033139837455124624, 0.0405643709124096, 0.04038091583718215, 0.030518539302471667, 0.03989316680799088, 0.033777590330329635, 0.03314776263470131, 0.02769061191488178, 0.029129623810970978, 0.044585214026512644, 0.014977060096909203, 0.046807006902752385, 0.06684476434583626, 0.03372933445197921, 0.01255090943642802, 0.031171830356000896, 0.03815800447257296, 0.03467442265020744, 0.03386228135035884, 0.010800403317496663, 0.03607284337762864, 0.036001447813525315, 0.03042002422584882, 0.049016373832860304, 0.048016935526843996, 0.11490479231842103, 0.04081734463632588, 0.02567519354934414, 0.012918385534336971, 0.009518483495940606, 0.018728195253999966, 0.024707996053621176, 0.368615186382686, 4.742966784584907, 18.490223615400254, 36.97965883439587, 47.401957281174205, 51.71553680973669, 36.30958857074861, 36.97830561668643, 32.3863515546245, 21.0501173234755, 19.204043995949533, 32.548367015777096, 28.902959323698475, 19.10956390442387, 13.65432950758165, 10.454417755526881, 9.66494171850143, 4.219063155112728, 1.6578990893979229, 0.3411868791426382, 0.1610417940443562, 0.02074458272076182, 0.26167642144906905, 0.19928131793295184, 0.39967288112928795, 0.34444931053346206, 0.8619537156435751, 1.178578099896831, 1.5737733196827675, 1.1847796122873984, 2.264111940899203, 1.8987690224762888, 1.9561541561157474, 2.79435264968103, 3.035902991410225, 2.064623626009111, 1.3470617946117156, 2.3768506655769968, 0.9022556401548848, 1.9276652461098087, 1.9327908033324828, 2.9600671510542593, 2.6812010955426, 2.837400172025927, 2.2150102401933363, 1.7164670627924705, 2.1875514426539024, 1.218768911015603, 1.1731208572464606, 0.3728859426994478, 9.729336250212885, 5.981585585301922, 1.9524562190617285, 3.0186379436523687, 2.19273240335526, 1.217039758639951, 1.4181536508183328, 0.8044614522687851, 0.7073747619025169, 0.2644240723982934, 0.17409554923013335, 0.0885093248178882, 0.6128354671020663, 1.4269958989274119, 3.6596204003980084, 8.988744712645008, 14.376725169920153, 14.668401441266461, 13.308681422664275, 16.381517206468892, 20.92576446071748, 50.862633105247255, 30.454743100750832, 31.843595543215354, 42.25154399871826, 27.340781265689483, 12.417135507829729, 2.2088104438397194, 0.08514661251777604, 0.03935282201235814, 0.03633394912486115, 0.05274952411831868, 0.0561434047056302, 0.05808526905433786, 0.012176438955770386, 0.032039807974210674, 0.03721134579409996, 0.06800711124895081, 0.06104485056693516, 0.010350910804024147, 0.0159682457207612, 0.07016027796893351, 0.0029817116381074754, 0.020977394925730846, 0.029698924814921715, 0.06094898998496994, 0.045474182453847704, 0.024535147465705395, 0.0612189095737713, 0.06316266615965194, 0.05281440027418637, 0.031232282354105866, 0.047372042712184696, 0.03935001813055527, 0.05922112463703079, 0.06953475185700002, 0.03323611172456895, 0.020849324176989256, 0.09170377356631142, 0.04288812243049184, 0.036594522440986293, 0.03053676644941011, 0.011637956711403545, 0.08865710317848191, 0.01032614701187178, 0.020850682067835045, 0.06397144050307332, 0.024172477611911394, 0.03598333366455571, 0.004502168017244268, 0.00964385474235901, 0.017091321999267224, 0.021276761019121737, 0.023726250548216126, 0.180298425257206, 0.13051196452110045, 0.15959466927714888, 0.11111544565327706, 0.16152755507538397, 0.17704285801418368, 0.1576777334294973, 0.12068543132514724, 0.19473124595899738, 0.17642251065661832, 0.15056664484643167, 0.08048017178812335, 0.12610764077474035, 0.15194698206840024, 0.09853672626758776, 0.12049797727095506, 0.18086392071939286, 0.08936997097466262, 0.17637542689279204, 0.18731598982647543, 0.0917335360821697, 0.16722182532952679, 0.13492501400891813, 0.15539609376461277, 0.12966220447373006, 0.16738285701121056, 0.18097124963758454, 0.14695679258194663, 0.14126362549441476, 0.17179782171883892, 0.18001523319511645, 0.1731348290078102, 0.1612531270591482, 0.23690764972519493, 0.13485788938499269, 0.14224893713910736, 0.13284484014636086, 0.2530896943062544, 0.14078141911135567, 0.1454673031525266, 0.08842657966118667, 0.0675327955715118, 0.1241999286256971, 0.2906251987141948, 0.24878044973217675, 0.20346025095110942, 0.22236569213771054, 0.06487225648015738, 0.19370396801781273, 0.14569826333993866, 0.15197742640251113, 0.12752721702019054, 0.6314480941622489, 4.690731600407632, 20.09616355742178, 39.985935918746456, 53.03161751839423, 58.05436549648162, 45.49498327316777, 45.867173056448664, 44.1870963958002, 32.36987759990077, 27.563179654459802, 36.66753622793382, 30.73584564270512, 24.83870525513926, 17.133350256950624, 13.969005577025877, 12.034977020755893, 5.320188172401921, 2.0502119799775462, 0.8149635984051613, 0.5434779113819522, 0.5805875168692681, 1.6673594785313455, 1.3187036711362101, 3.574784436533528, 3.1567007159033134, 6.222322035220362, 4.493647208136897, 6.360888586890313, 6.129120146074603, 7.644108168540463, 7.650972806638287, 5.790013594012107, 6.544837942046504, 6.346610669166812, 3.4526543319225316, 5.247171290459172, 4.524662369681943, 1.7297789742869718, 3.220634614267657, 2.758341123980861, 4.776865378502877, 4.253150513095241, 3.205025051870654, 3.3191966674020215, 2.460548406647098, 1.6808507158871622, 1.3985730563440633, 0.9580637971239706, 1.6039428427334756, 17.24992702084203, 12.425421514818746, 8.808603978926136, 9.361109041398572, 8.509963539338882, 5.31553477048874, 4.140808438101123, 4.36634668419438, 3.3660998796263053, 1.462426178397671, 0.9437639999293512, 0.5823201013188208, 1.2288045402496093, 2.4490904279293555, 5.624361605413499, 10.40266110051063, 15.07690844997283, 20.543796208597, 22.711223440785563, 23.900417435553766, 31.726467686314738, 55.84193691130608, 34.18961025053455, 40.69848152898973, 48.64282261940741, 31.394762646767404, 14.251716290750812, 2.5767238630402476, 0.2402196623264782, 0.11616785680094074, 0.14222091364283718, 0.18152088707973882, 0.17275198422853025, 0.21356170245956993, 0.11546870197860465, 0.23718040766975573, 0.1388012350446755, 0.14184124046756377, 0.1636366104526866, 0.20006540892345293, 0.23634895712377565, 0.2488043669971728, 0.06308927493650587, 0.13508416111430815, 0.17154564089592428, 0.1411914140466721, 0.1344000292761672, 0.19302011197132452, 0.18422044302907684, 0.17963557534160154, 0.18242487083038977, 0.11632044619369893, 0.16002737105854098, 0.13817915632840128, 0.19362791080869016, 0.22405581999449964, 0.1516911699887245, 0.09255984617817788, 0.23471130628979978, 0.2290974752677064, 0.0976406715269531, 0.1699878317454169, 0.09251000449782418, 0.15750021553568302, 0.1670594453330963, 0.19752227280649448, 0.14135768576975793, 0.1482294791287953, 0.1356886657735994, 0.17884887965215793, 0.18573058618893548, 0.22094055409393004, 0.15286207409395328, 0.14439827341946865], [0.038923816605200695, 0.02466944267883176, 0.016341900317779472, 0.02965488433537464, 0.030478926811126933, 0.07674554678341074, 0.07410239788793749, 0.035091174481016014, 0.015254825383665101, 0.04183099770377721, 0.08980964415616567, 0.05247862010653462, 0.05252776847731683, 0.060072757769376046, 0.04126363681749471, 0.1089990281710221, 0.042617708714979316, 0.0136316861701949, 0.03498426308074305, 0.012998582491080367, 0.0628237028966748, 0.033905760670501384, 0.031388238703291264, 0.0475691992699379, 0.03043722864540835, 0.029846494416556055, 0.022107811284161383, 0.05385736003518105, 0.03705955313278302, 0.03031407043548121, 0.01713473237149658, 0.03164263926596651, 0.031334296537322864, 0.018007239484558665, 0.035202345330147974, 0.03276228634340148, 0.07080005331625862, 0.05899348927121009, 0.028901921412456903, 0.02455608656389579, 0.05723828990613261, 0.01645801051880323, 0.02992351306602359, 0.05021591430469867, 0.020079679689520312, 0.061564327127510504, 0.07800950758880185, 0.029202624329275666, 0.027157382160845785, 0.09099517287986894, 0.0023864984283253794, 0.035853175326220454, 0.03937860087101017, 0.1924389729937238, 1.8115716691940063, 10.772810270709376, 25.107793577255745, 38.37943115542012, 48.34878213943974, 39.84862550612419, 40.10341875014767, 36.179099159856, 26.241452693939213, 14.441662949900474, 23.336635558835923, 22.14432327978073, 17.878669231168686, 28.37836192500207, 17.85032226193336, 10.783292804994892, 6.703471339518025, 4.436722830418618, 1.5282506591850713, 0.687869244044827, 0.4830126139906145, 0.21361807120903847, 0.3900500507124009, 0.4423820684033056, 0.20240612928905796, 0.32038756135490637, 0.8689663006413368, 1.438129546661531, 1.691034904891445, 0.4775003049402468, 1.3620225724674042, 2.1957420870181057, 3.3728931796166206, 3.589406787387787, 1.7191912714512119, 1.2194124248719986, 1.0212769599691516, 0.5780172612397902, 0.7839551171468151, 2.218461435648703, 1.2690202339041619, 1.1698643094108951, 1.8097975321354407, 1.3298467570735564, 2.157929457964436, 0.6479454605329422, 6.550042927265168, 2.7708870701251493, 5.207782358892503, 2.689088491662856, 1.6223935494499824, 0.8037338526018205, 0.7248576237790046, 0.8586165140713415, 0.696693412478893, 0.5606782400319653, 0.319109205757418, 0.23628996835360605, 0.8101163456036199, 1.7783267627800665, 3.3883159391341673, 6.700841880613758, 9.436989253567113, 10.466938941709458, 8.118169749936751, 22.05535804071734, 25.859245177238222, 16.07760706255513, 26.7639555469636, 32.35710244024954, 32.404066939507764, 37.34153278412358, 25.479806853878884, 10.534041870024897, 1.4603823783897585, 0.21496730526128124, 0.016221969253233364, 0.05892794661884827, 0.026830781641746723, 0.04054122356577747, 0.0610564721207465, 0.08960836987581947, 0.04680797217353698, 0.056011537991223805, 0.019324433824588216, 0.03481072884413504, 0.040500544296998175, 0.04366562123440447, 0.04775106854316208, 0.06568071672752981, 0.018417234419875087, 0.041329554852939425, 0.024746976522428375, 0.023704187215996847, 0.0339905972472362, 0.034158339859136654, 0.01595694592387806, 0.021802961916452455, 0.05987895667673119, 0.03133112876375597, 0.03926667925571242, 0.0305557711755917, 0.03123294310494056, 0.05158828421225471, 0.01951905463131205, 0.023887203705887643, 0.0409562133943602, 0.06314515338970289, 0.06527740207891311, 0.05363453570152483, 0.0197167570267113, 0.07990974271970411, 0.05754076440127627, 0.14291189430702117, 0.028056685114279393, 0.06817051014232059, 0.04022904273663317, 0.023941122889218312, 0.031038322298216726, 0.036802936660786795, 0.006554602793673234, 0.03667816775099885, 0.03773068445884893, 0.027817989354051893, 0.06044966919768242, 0.06383001301137191, 0.05117976016575291, 0.1025046097234853, 0.0707130870150943, 0.0135353094364907, 0.05926628552016713, 0.039168202483485785, 0.019561955555071755, 0.026643160963431004, 0.05138935799139643, 0.023389116320158207, 0.04860902190088265, 0.06422061443088517, 0.028907425754192858, 0.05210101153821715, 0.027028782811436444, 0.07495477029512967, 0.049386727548534834, 0.016977289811738076, 0.0370610699868731, 0.053913023983759266, 0.023358570479397333, 0.06680112797766924, 0.01428723622549085, 0.049083735944042285, 0.060655061200621634, 0.03338861684765547, 0.02181280231583984, 0.05343380534360486, 0.004705156419321054, 0.06035682700213887, 0.007505847465982962, 0.019126357961325877, 0.04923211568365655, 0.02003796811726305, 0.02906858767082374, 0.02470395877026022, 0.05564817099741871, 0.06934008891544036, 0.02356423635876948, 0.03657416748483816, 0.03488007895348053, 0.03653523489652622, 0.04808162016073062, 0.020288277770422643, 0.009173198092368343, 0.058435692992662235, 0.03140185591614535, 0.03187869968373449, 0.02278523602252526, 0.2232686799740599, 2.6566200919689673, 14.675914741331532, 30.839676664721583, 41.97752721848027, 52.22441334878245, 44.26973289059055, 42.24986522428451, 35.155235029036, 24.33889331356172, 18.616990696999338, 24.314400073020693, 28.330454095717403, 21.166558765595962, 26.777572055016797, 22.477879678049398, 11.335836110576508, 7.367333471775056, 4.689212662558402, 1.8484550642390407, 0.5855864550798171, 0.17850449248667688, 0.08893011393205774, 0.15164946416212668, 0.17401186178528494, 0.2051206852399534, 0.6312855609482335, 0.6692658100397356, 0.8382130798793609, 0.6741563927742743, 2.1550945649223943, 0.7896329931193783, 2.5814765499484156, 1.7905496036814106, 1.312596540777914, 1.5567979144473232, 2.597464866215183, 0.8431934481186252, 2.2828091440662264, 0.9936205730322869, 2.2330443176531025, 2.756818263761459, 4.285993499140586, 1.5628129916806377, 0.8914391528214178, 2.881562382944169, 0.7393531717600361, 7.468896873535649, 5.884181857109071, 6.281938629765665, 1.8252913846123604, 1.0986716973204766, 0.9278222005213461, 1.2715193965742666, 0.4645575865382149, 0.3546312932045229, 0.24559994378397543, 0.2060683666458053, 0.1992391984188749, 0.44522244663488486, 1.5267309858914346, 2.8878080219991746, 8.529736207377526, 9.859095119660902, 13.50082362851789, 16.18283837072311, 25.296183055446996, 21.705674817485196, 16.539024883700957, 29.67968471588627, 40.6108832359314, 36.876033736813454, 39.41828266266854, 30.01834607893421, 13.044523519854392, 2.455101950514701, 0.13046638228960578, 0.018900053673273614, 0.07584949970365533, 0.035470188820674535, 0.03326484002172947, 0.04498356059494038, 0.025561950432377, 0.05033784102828753, 0.05796721490520624, 0.04100144705584934, 0.029752907200506138, 0.05792268604460744, 0.0730664861358462, 0.04759785861918523, 0.030822069083731023, 0.060122361962473204, 0.022230963748429092, 0.05540070927611763, 0.02275039242850917, 0.03924328293050489, 0.014817631454207005, 0.07262566382245672, 0.01655887940057343, 0.10313692337442791, 0.08642951101665536, 0.03458257253852583, 0.027728096597016822, 0.06730101567002074, 0.015109772380862026, 0.04271996230067265, 0.04050260507351449, 0.05626119838486757, 0.06929618441649983, 0.01651011790419298, 0.034793583796389645, 0.054394176995922486, 0.04202875181011135, 0.004841888749656538, 0.012920719229676312, 0.04219094028456077, 0.0857873837794027, 0.026618525491005955, 0.02528378965273019, 0.03794995414453649, 0.032125108034139684, 0.023420849597201716, 0.03739188207433589, 0.19509316121618595, 0.10955641842297009, 0.09431041071131345, 0.12472197924169803, 0.14757439734474306, 0.1459484370124917, 0.1984117162083426, 0.11827005569132105, 0.15146958671750563, 0.10054321013270848, 0.14071820153584405, 0.17297859303653243, 0.1724215398632711, 0.205952120464175, 0.11348479472461248, 0.1389361124846243, 0.08413034326006329, 0.10280231915173993, 0.09169022913181013, 0.27005913937764786, 0.1949117822392333, 0.1653191540390253, 0.139571551774298, 0.13225532016686856, 0.1668893278486306, 0.17299316402885223, 0.10920920439304845, 0.15782310627400875, 0.1832634306723072, 0.17976824644832842, 0.11918540052588909, 0.13174067762109543, 0.18769727178638984, 0.19108860513135312, 0.09469115640968086, 0.12812812106623767, 0.14703456582801958, 0.22825087150258405, 0.12123044159623886, 0.06974266045877049, 0.15649094066071897, 0.12337614661983906, 0.142317961661085, 0.21216103326409094, 0.10644584098049711, 0.1762177813197336, 0.19122112302049515, 0.07264080938071975, 0.15039162439925058, 0.18519080063748747, 0.15936357119391042, 0.07335567666638283, 0.1467943512984822, 0.29981148158830984, 2.9287252070442324, 15.30081008711169, 33.24915139905868, 50.26377347207839, 61.15502657428865, 51.738223798813365, 51.92965507507325, 48.40414639442198, 36.06114956640428, 23.10132472745834, 36.85639442936067, 32.80753566372779, 27.849914719981534, 38.06804595455047, 23.843686234566476, 14.486447591935436, 9.508949056748422, 5.4262652416383075, 2.2433167599862625, 1.2546659525363677, 0.6842175174144007, 0.5254303507747189, 0.8208664590793272, 1.5099351516654416, 1.3412755631631421, 2.058165443520392, 2.0906453651766626, 5.776856003269073, 5.515108887226352, 4.715587169893326, 5.613723156913634, 7.980079275946464, 9.494142109347928, 10.421890520280408, 8.571016211663524, 4.80875228681872, 3.485884652022393, 3.2575443627372866, 4.683370292186737, 5.893454340196425, 4.598962847263583, 5.65022522403348, 6.774481929117634, 4.330791379174879, 4.930466865339588, 1.1331044690262888, 11.938593599104113, 8.105684845678269, 10.535789285936664, 8.920664133564118, 6.438624080150358, 6.117658980431096, 4.872634458926417, 3.6971844492420076, 1.6346152871847155, 1.607318655137093, 0.7541380558283098, 1.0212244982680967, 1.4759082226983964, 2.6445107546544846, 4.346896631102409, 9.686318635940552, 13.807203885047668, 16.17181552994636, 14.953857814112018, 31.883203637215402, 35.0312332184084, 26.87344066558346, 38.13054107850598, 43.56993106103713, 44.36450912106422, 47.84383581530663, 33.35584379011585, 14.1982465405618, 2.7045828344360476, 0.29343098041511356, 0.17452734702777478, 0.18215186773769318, 0.19247286472349398, 0.22648673955230947, 0.1080155015111931, 0.11729202954278839, 0.124116723816241, 0.11864806645579877, 0.09749931298316487, 0.11803828345070924, 0.15873355580674064, 0.19512610299693, 0.141968748141681, 0.18018006467290465, 0.148369274853218, 0.13774910521122719, 0.10753056019424431, 0.15503814684287195, 0.08074025097753733, 0.11346070125939385, 0.195960326781196, 0.10344161952455198, 0.2167008243381016, 0.13326275643081437, 0.2040553174071735, 0.12413979072364108, 0.16093847942688774, 0.1423590699391019, 0.29033975435360787, 0.2056835913249562, 0.272178782090064, 0.21435169232708795, 0.20827017994897984, 0.16385948075161827, 0.16368945519770348, 0.20516484254790893, 0.21676859247588345, 0.29435371799815085, 0.15795986829025133, 0.1763453349591263, 0.12307072268618692, 0.14945629233073804, 0.14876221667133993, 0.13634626032604327, 0.12605513310841016, 0.10825186261847135], [0.032709399463548776, 0.019825853692788272, 0.06060910741648367, 0.036222900849797075, 0.07699902995579666, 0.023462643523910837, 0.046286411853807594, 0.05425531972920703, 0.07361631509998152, 0.032946561132707906, 0.029438456835886164, 0.04061168450261316, 0.0765824773078484, 0.07867407354135668, 0.02527453339538507, 0.08424950823668512, 0.05177106513010879, 0.041029332656293147, 0.06152516088238167, 0.025789769659299525, 0.009521306529941579, 0.09793904745170186, 0.047071280423551805, 0.038852995607040586, 0.015431452700267396, 0.012194767609358797, 0.045525257535759485, 0.029465384826424624, 0.034205182305266785, 0.029587342193530455, 0.005350390621911614, 0.05452529677460271, 0.06344660515746763, 0.05084761891574149, 0.04347399583146457, 0.05386073848292713, 0.07433133560322946, 0.04645599690716594, 0.03499485424629623, 0.016370917813131408, 0.04085785153532221, 0.01575236022847915, 0.06125103164043638, 0.02228634424447533, 0.09573572495531651, 0.049854259517404347, 0.012503048093358596, 0.018790960837636265, 0.07848637433902872, 0.04987672504578387, 0.011939124069026402, 0.048032582872697425, 0.020231989460186135, 0.07619806970920294, 0.034715492623828115, 1.8855264879042104, 7.610430207944686, 20.61118252815739, 31.946361641730036, 40.32700953945037, 40.62379960090884, 40.32294204158168, 34.65594868506155, 27.284181464102964, 26.58514253554806, 23.92140211597566, 24.990912829675985, 24.62520476310484, 28.53275622090986, 22.883111507661884, 12.793328069871473, 8.822258730088512, 5.95881377497027, 5.0336624633881355, 2.3796527087688446, 1.4548153093745633, 0.5015232287828, 0.30038237030948367, 0.13896208286525744, 0.39378874364399147, 0.20057668068235923, 0.3340879713575686, 0.08304579258565942, 0.5519253484183743, 0.6743308156728746, 0.996889194413539, 0.6270329149500017, 0.33162083116269886, 0.6295563472855477, 2.7568028194289056, 0.4527691481334548, 1.3100814434789843, 0.21381506305788794, 0.8013744243691046, 2.1239717833457457, 3.8184683024883275, 1.0546526529135243, 0.575124697098809, 2.2253500982638332, 1.1102963767705427, 4.40069095742318, 3.948432851222254, 1.1702597333538918, 1.8427288940837308, 0.6275868271627735, 0.30723867337069205, 0.5766919291307849, 0.3101522589643156, 0.6502564720088436, 0.3787791200222508, 0.6809653209582452, 1.299821135978545, 2.7798597370424583, 4.329954933735633, 9.567873843254583, 10.510961663338447, 11.161281812575556, 16.203611243155695, 19.354933654108358, 14.789613466109, 15.739255566750805, 17.632381646863877, 29.146885641159553, 31.139430076845233, 27.444441664603453, 27.302444019625266, 12.945109086651957, 2.464421992340396, 0.11554606153719849, 0.04407732071535241, 0.0404383915837013, 0.06429236622587328, 0.020676006360219854, 0.0020223011867323473, 0.023230877028958454, 0.04811625116534772, 0.08077227345277226, 0.025022291285436482, 0.033774008869283625, 0.029797506924237938, 0.010239517789394146, 0.05408570020189209, 0.031932525021294435, 0.05505460990412582, 0.09138007077478594, 0.017525879628655892, 0.028396021845119617, 0.05896636975869056, 0.024987463013178883, 0.01759992011131779, 0.04568411352773828, 0.03815805426828804, 0.029174056910579244, 0.04918050434019777, 0.05010413824610653, 0.017780036958415183, 0.04852393251513282, 0.06298662681553154, 0.07308772209310725, 0.1036892497851964, 0.02766754309226188, 0.04756394007633771, 0.03428317771683778, 0.10476350423789794, 0.04064536938864378, 0.04458920534459814, 0.010266091464267624, 0.05004261755534718, 0.046398513499767556, 0.039680125417127725, 0.0909535360011843, 0.05242415891599752, 0.031457324512302876, 0.07092238223600773, 0.0017784873606644632, 0.05523982315113949, 0.03005000567364116, 0.04627207068786506, 0.05480309174726567, 0.037542709464868235, 0.032853366536719185, 0.02610853118371339, 0.07622233937464415, 0.04520174626621508, 0.02268505661988691, 0.03481665836466897, 0.07227402180433273, 0.04722205801836906, 0.03594687170979958, 0.04610510182476813, 0.0133602382359846, 0.05542172689832026, 0.040034104003420765, 0.03342626240825461, 0.03841657829921573, 0.04666699667371089, 0.03595474326322156, 0.06892179724790397, 0.03988538718511982, 0.06404073698626411, 0.016620614595951575, 0.01092074232386245, 0.01455078962364144, 0.01421709321514373, 0.09187629656685938, 0.06232634712491305, 0.025575688304079157, 0.04069341842325465, 0.015022279394249764, 0.006782080632664504, 0.03938764836939593, 0.019269080141619332, 0.04509139896160172, 0.05765162881523852, 0.05569138218678775, 0.05182779011046214, 0.030237798721739845, 0.06144506638989814, 0.0066612834099590065, 0.021135655284348517, 0.05441166295279419, 0.012082207268254172, 0.009840555477797264, 0.05935275386418066, 0.060202123206709666, 0.060349717706201546, 0.06738477206278233, 0.06766473123383138, 0.017849802670459596, 0.0642061775039521, 0.12020363096868801, 2.6726745982323927, 9.766579154999027, 27.572305048665694, 39.89853766656692, 45.59141866622433, 45.08144778590049, 45.806093908125355, 37.74206561426963, 22.016248087729178, 27.10210111833388, 20.614330230220673, 27.521461325307047, 27.901003591475952, 29.076222181320194, 29.62829774425876, 17.4552591769926, 11.025049071158133, 7.334065889158557, 4.946899144880233, 2.1503703151979754, 1.2465604971493445, 0.4330833544654231, 0.12804128500002046, 0.1301688643833322, 0.142853549050708, 0.2628720395507351, 0.4502021713602928, 0.4881343714171841, 0.4703921428130519, 0.799294587585234, 1.2110034760928925, 1.5577608563246266, 0.5511638570216395, 0.8698880576318311, 0.7679829806570084, 1.306307510502877, 0.4042373249127019, 1.7311205474599716, 2.690142628646666, 1.6373694039160207, 2.408685357339921, 0.5173942110230846, 0.3464072474068211, 0.8330216390951988, 0.649322273750459, 5.105991949958186, 3.4860925376415257, 1.391492810460829, 0.8101870708407894, 0.7969898886738286, 0.7159890222453302, 0.33533503992422936, 0.3014394490709228, 0.26661324525071733, 0.1511773241743926, 0.5008219825404306, 1.1179644878833526, 2.700920811583919, 5.313403942892629, 10.961121301497183, 13.849407607509246, 16.11257597323387, 16.657170595661288, 15.249152471942288, 18.20747760034377, 18.887981368649392, 21.48504541766259, 32.33862023199759, 36.1636842450788, 33.6281817959201, 32.32617062907065, 15.951159654125092, 3.533700550756147, 0.1139956068307642, 0.09106479495042756, 0.0330721804000918, 0.041801055157256704, 0.09331316341676059, 0.025106313893751755, 0.04427732328974432, 0.0726856331851694, 0.028604104731892867, 0.0206077191978693, 0.04234617268065772, 0.05045032188777001, 0.05637333450478412, 0.10556231943830367, 0.01730713471319647, 0.06753516278319782, 0.034425198926680514, 0.07236396818752251, 0.016585818882430756, 0.03639710924377845, 0.04881972672357675, 0.0353313890105534, 0.07352943306848889, 0.021589045270135807, 0.04599907142560809, 0.05007350622045417, 0.07002713188769356, 0.03437457200620444, 0.11286386514022467, 0.04430160827694401, 0.05370380154119865, 0.06109504847817364, 0.025219062884007732, 0.11651716991177491, 0.054821156100520206, 0.0375253614038229, 0.06057710026300723, 0.024740280913970163, 0.03152275991235529, 0.029273014402978366, 0.028048371145081137, 0.04015678532361504, 0.04354601192678656, 0.020106128875106093, 0.012764021690424173, 0.0274816652639739, 0.04072792685380386, 0.09151677916487379, 0.24751727799734763, 0.11082375001522804, 0.16325189641887144, 0.18295428355134305, 0.17758592242194762, 0.19090365618467334, 0.19023922812794486, 0.2544672429681786, 0.19101265517453994, 0.1068504962829813, 0.1392810818769278, 0.1420598819611534, 0.2160179948494319, 0.18416028980526233, 0.14158199631398724, 0.21293266766494323, 0.13531476890127506, 0.14134156727983108, 0.103144814080048, 0.14721940752239, 0.08546466924129956, 0.2992056899013058, 0.09457634281246893, 0.21017013928822934, 0.2335385788953112, 0.11170619137344823, 0.14750669049399515, 0.10533530460370165, 0.17359982905608995, 0.22150070226240545, 0.23770122488419856, 0.16854700422094715, 0.1414846265388112, 0.09783840648108914, 0.11182278229464447, 0.23465550444539518, 0.12746628238669327, 0.16240961338964202, 0.09061019837615952, 0.20438724798300575, 0.12544106001094465, 0.1603906039869593, 0.16505347474688487, 0.1364794217290417, 0.15462718663677094, 0.16630213677642808, 0.10648118061644417, 0.13732196522816537, 0.20273260531886933, 0.14510482099027405, 0.0907726319987447, 0.16102405144802986, 0.15328202817228534, 0.21034036402500447, 0.3030029425938284, 3.0654193172531747, 11.013488865667775, 27.86558262763485, 44.79928816518476, 55.418399380099395, 53.29405546188355, 53.42448995959375, 45.760755231303555, 38.99076000336678, 36.81365628396311, 34.09257081247146, 36.7428300457616, 36.65785581834855, 39.492078135090495, 32.22372420372502, 18.779929876327515, 12.693924423187012, 8.205370412718866, 6.724850708438504, 3.2796628532871126, 1.9772644749572201, 0.8345372061575613, 0.586141225311064, 0.62008204599542, 0.74447468403847, 1.3220322925236918, 1.1647407133733074, 1.6638721237259528, 2.800512241740381, 2.0640168843730806, 3.659149470829195, 2.3259208952226946, 2.5542989373207092, 2.3403843900849743, 6.930782006632898, 3.6419143311439024, 4.703360651769946, 3.9008277798852617, 5.740534855473427, 6.122958102533895, 9.806582427793934, 5.145534344257848, 1.6342061349461157, 5.870926697408, 2.8460970472904945, 8.58493572281253, 11.129655741876173, 4.290500792764849, 3.987800454901111, 2.951811787582213, 2.783772546437479, 2.2994804430392484, 1.1801937486856215, 1.2021223720042937, 0.8226519955262062, 1.236289770853135, 2.0475298142240894, 3.8536931478208114, 6.86870853747091, 13.794555221834491, 15.82941516753166, 18.34027924845296, 23.864302212192168, 27.67919355823148, 24.62258658101482, 24.61126465951243, 29.468204244490597, 41.089392785103094, 42.04646287425872, 39.992215633392334, 36.5426165826859, 17.133958224327333, 3.676144365341433, 0.15232366750076895, 0.14719921344470593, 0.20015522507169556, 0.11700806373189535, 0.2278415354028825, 0.15329140508847852, 0.1668160745213109, 0.19496047478770057, 0.27913155094269787, 0.20637287127394832, 0.11962548739487126, 0.1503069563618591, 0.17286622325979895, 0.12562275308394624, 0.1633786226833059, 0.16339697814997167, 0.34897404031888135, 0.1454447342022773, 0.2146825350580677, 0.1986153883438918, 0.16060605855478396, 0.09728919804817247, 0.19544379965912914, 0.11288916136348441, 0.16653397030407385, 0.10663390024414948, 0.22265358797965512, 0.10075275050175768, 0.3130937301583829, 0.17914785312548762, 0.1084815127955329, 0.262181120173585, 0.121126736273929, 0.2464027732851044, 0.08691123476432216, 0.1616555070804973, 0.16417202930296623, 0.19056279302364398, 0.13737188351731147, 0.11831429726894825, 0.20140082274954166, 0.12660848607699718, 0.12536179289341937, 0.1225718155863785, 0.0814021203005987, 0.17608802134711898, 0.13361793011426926, 0.23696614819909298], [0.04565712425016588, 0.04526676797878839, 0.006585010738607737, 0.058374206775859486, 0.03274479655609016, 0.011622784340063171, 0.014614892030705609, 0.04364227470491202, 0.04225863181355019, 0.009574050725918383, 0.03744556951606947, 0.029111699268762625, 0.018721340682297465, 0.018842759872636488, 0.03783628584877138, 0.0369430196681811, 0.028563685933007833, 0.034062900625529795, 0.04109806989529922, 0.03409097008707543, 0.03441477630047068, 0.08895924059493888, 0.07134118718245337, 0.07946458434866321, 0.03022986971172354, 0.02049394939545422, 0.00719875154543608, 0.08150931132296402, 0.0480209268449295, 0.02643389638603455, 0.03210891102020058, 0.031948576478527925, 0.027733300249242497, 0.05649359881757729, 0.07204273219911322, 0.024101702579026742, 0.0828298936868387, 0.06096326986387853, 0.07181649111331471, 0.028281941777095202, 0.08248704635808546, 0.02260914879790958, 0.043045561159810716, 0.06457035655095693, 0.016111842198898236, 0.010843446925132266, 0.02857392469811584, 0.05224962493464832, 0.043022865805053906, 0.03256979909154677, 0.03770365687688032, 0.07009158286476327, 0.02301883346761667, 0.05050172255704961, 0.02778613733338012, 0.00532332904479136, 0.6988347814448419, 3.4766781137835596, 14.838032184108613, 29.545116040014452, 37.15378069108532, 40.53402831477504, 37.26834135670816, 32.67379656914742, 23.570748106125865, 35.29498515590545, 18.62778898208372, 23.77667057898737, 33.74488407565702, 31.974891001178374, 27.57421132056944, 27.920874318768902, 16.189552487865573, 13.326765510343737, 9.995826982682752, 6.676208415339071, 3.6621128214943797, 1.738053704461744, 0.7850333399349644, 0.4677538279323809, 0.2448241112212981, 0.2614910588149102, 0.23876286952966647, 0.8739592327225594, 0.15240067465891763, 0.8365857865541213, 1.2614044619183387, 0.754222019064811, 0.8395808226158543, 0.7467521715068048, 0.9168042627073104, 0.7300040185932191, 1.4491455232904804, 1.6058027816395608, 1.2859359455685462, 1.7156736408510518, 1.024656817317009, 4.98555802529858, 0.9051260796766128, 0.6160567136060807, 0.5693616321490658, 0.2304907746973538, 1.69922775558887, 0.19886269684760802, 0.3476674313987455, 0.11378480241663995, 0.12519158347840273, 0.2995124927932217, 1.1491666974559909, 1.3518299258524373, 2.6406173119621896, 4.683701242170026, 7.512052751356556, 10.879164357339183, 11.799280816508878, 18.83585306905931, 19.279078937345936, 11.738279134996477, 16.900861570912024, 26.11294407998362, 22.418989212282245, 27.227418884154293, 36.24275138301235, 30.53293162776578, 21.33931955983562, 10.152022627092178, 2.1811601856062492, 0.1459167209724265, 0.07715667552885509, 0.021955172095688123, 0.051808224224876014, 0.041666851874681256, 0.0871458568520123, 0.07027436378261737, 0.05127775813302687, 0.04090065669809138, 0.06726925366468008, 0.03627500248952739, 0.07979761809110641, 0.013300177900330916, 0.04624613095074893, 0.01621652236809173, 0.008393899939443556, 0.02532759839068017, 0.06432777480973352, 0.024303185618332317, 0.014440258457926253, 0.03294443140827841, 0.08114441598374998, 0.06016217555189806, 0.038006568042140816, 0.02728806143896955, 0.06890332686804956, 0.02176181150359973, 0.023686390993515813, 0.009450931777997364, 0.04866228416381825, 0.0019021301212037104, 0.05825984900096252, 0.05034297381738021, 0.028575359197754054, 0.029492423899712104, 0.09488254815580384, 0.03288247787784184, 0.037782629050554774, 0.07089507120150713, 0.029566393519241004, 0.033430682735577706, 0.03129834403103638, 0.009977505185581263, 0.006976993989214422, 0.022049609669333985, 0.029130972125717712, 0.0638707459063059, 0.04799878307347817, 0.039515665491982814, 0.03645118739035341, 0.06046568043529988, 0.01675397709703013, 0.02990652506630267, 0.034080804100320224, 0.013249867948733512, 0.0440385873099008, 0.023953064284738035, 0.05978329910806591, 0.029700661919290022, 0.010611199710007397, 0.04300244956187183, 0.04126467103619249, 0.06125273235562829, 0.018888179310447267, 0.04469943390558324, 0.08023228871846393, 0.008171920217723857, 0.0321103110458822, 0.03407690854322526, 0.017476346298691728, 0.04423586644172188, 0.052748451595224684, 0.039702399423526186, 0.03145159225940945, 0.018739412696431243, 0.05538177924350866, 0.051088009645501455, 0.022203826998931267, 0.05409290525881995, 0.03141406544243857, 0.009903201360195395, 0.020760852513053728, 0.12219329154299152, 0.01697567911187728, 0.05257991991276222, 0.039405785501003265, 0.06311588500055575, 0.07730544980375037, 0.057531716902890516, 0.05436900717717025, 0.021456674852919196, 0.029701560157381242, 0.04071203052937504, 0.024092398441186356, 0.02990247820684266, 0.047441182147351005, 0.0708036845730197, 0.027484630024240866, 0.07530771466272493, 0.02602582816184769, 0.07697820768601472, 0.04287709842526144, 0.04812960790830755, 0.022541556860350316, 0.02670273004520324, 1.207993915004115, 5.2266778869013635, 18.210811614990234, 35.1771963796308, 44.53910166217435, 45.49718764520461, 41.07719421386719, 35.56112581683744, 26.16566465746972, 32.836253296944406, 22.538078254269017, 30.191548139818256, 35.6902620100206, 36.98375771122594, 29.34742662214464, 28.892608188813735, 17.927659634620912, 15.461550777958287, 9.963466448168601, 6.274543491102034, 3.256202666990219, 1.7902939141758027, 0.5054471617744816, 0.5363062252440761, 0.1052200926407691, 0.19154936105253237, 0.09217198352299391, 0.14490868715989977, 0.19712231362298613, 0.4160299001922531, 0.37411438000779, 0.41611916475719024, 0.3516659200672181, 1.0406784737302412, 0.666332183586013, 0.7463091888254689, 0.5143969073410958, 0.6640179851843465, 1.145828515291214, 0.9764012454017517, 1.6550477714307847, 4.385559924187199, 1.0602259732061818, 0.8640716729625579, 0.2242667393218125, 0.24761712989739834, 0.7160340682152779, 0.286997527244591, 0.20371967896578774, 0.06497165638833277, 0.22405850130223462, 0.20690957715194072, 0.4921762513056879, 1.3872524831564197, 3.237006587366904, 5.5013962811039345, 9.517860681779924, 10.951351657990488, 16.743872627135246, 20.21732164967445, 20.52027375467362, 17.20143868077186, 17.257536418976322, 28.162490360198486, 24.522142525642153, 29.77966004802335, 40.382558145830714, 36.464914429572325, 25.58859967416333, 13.292854659018978, 3.4767560708907346, 0.14646122562548808, 0.06161639046284461, 0.07699306213086651, 0.025208063776634877, 0.06208140966332248, 0.02261059095842704, 0.06390298288615961, 0.016146002059441902, 0.04593539802778152, 0.021766664670600046, 0.04461946581760722, 0.03390849943483069, 0.031839251901293476, 0.02149953555706288, 0.017095914696373286, 0.03916141877491628, 0.043531525204138416, 0.0644570444860766, 0.02986954025653822, 0.06747166175515422, 0.04764075954294494, 0.012092465185560288, 0.05905452349613752, 0.03650087585312225, 0.028036242058019967, 0.018045214462965246, 0.02902886984238942, 0.013310685753822328, 0.05944379192266253, 0.08069623922628742, 0.02490161136994439, 0.029125021537765864, 0.033076026161471685, 0.047782979935647986, 0.003655664322357024, 0.05622757095543127, 0.0449410580369013, 0.039166812033903216, 0.13994417694066802, 0.07764217608998861, 0.05370655562728644, 0.006966660899530736, 0.036361283141999476, 0.013734586142574348, 0.07225918268123943, 0.023872879776923407, 0.01996258315029404, 0.039596978064265945, 0.031660339727457014, 0.14994467338246686, 0.1274722808551404, 0.12182051315903665, 0.15124971948323712, 0.09858681309607722, 0.09480062271318129, 0.12013721114565289, 0.14129155706013405, 0.19682205312194365, 0.16811067118279396, 0.15473355028417804, 0.1642544756853773, 0.07681293187723046, 0.12594868519133137, 0.07722303406485627, 0.13643514184701827, 0.1718654519607944, 0.13591591809545794, 0.11654025214093348, 0.29007018333481205, 0.25067895350437014, 0.2137123613107589, 0.21171322422883204, 0.21047465923813083, 0.14172891665610576, 0.14352500979458133, 0.1357941560807728, 0.17242556948575283, 0.11305208528234113, 0.12291160622431387, 0.17818331778530153, 0.11048160748736513, 0.10701505962999598, 0.20744919416404542, 0.16188464397864957, 0.20903525663720024, 0.12415827642525397, 0.19101404945456213, 0.2501936980913724, 0.16013001151863607, 0.2567546436142537, 0.11701659795137183, 0.1261528782666691, 0.16617663625267245, 0.09451461910840966, 0.17632823587665636, 0.0986686006428734, 0.15679087940483324, 0.1999256131990302, 0.27310633070526585, 0.12097371021105398, 0.16603970569708656, 0.1411692434621434, 0.11514803289525932, 0.12898751083881627, 0.12906163750636962, 1.029616409251767, 6.346994571147427, 20.13676008870525, 39.96989734711186, 50.90341006555865, 53.12983366750902, 50.355172541833696, 45.84180708854429, 34.29369426542713, 48.082798373314645, 28.994374082934474, 35.54624434440367, 45.9578033416502, 43.99642213698357, 37.89099800971247, 38.255268527615456, 23.132450695960756, 18.387802685460738, 12.598294096608317, 8.909378493985823, 4.370214631480556, 2.3109224871281655, 1.02785422316482, 0.5920857611683108, 0.5219808100692688, 0.9556650839024975, 0.9567194047474092, 1.6603421131449363, 1.0054479899906343, 1.9722117267308699, 4.028637231357636, 2.457539213280524, 2.8816307792740488, 2.7196158084177204, 1.761790417855786, 2.7568560165743676, 4.0358948419170995, 4.810556086801714, 4.7597143246281535, 4.318349130692021, 4.1672074602496245, 8.717139209470442, 2.7686395520164124, 3.007560189693205, 1.6176916082059185, 0.9254787069174552, 3.980641393892227, 1.5370623863512471, 1.6223006383065255, 0.6493305475000413, 0.5789941765608326, 0.8201346306070205, 1.6243921196268452, 2.0383936335002226, 4.309269334039381, 6.89859748848023, 10.932737069745219, 16.287918667639456, 19.06492733186291, 27.803279699817782, 29.517249561125237, 20.64457170424923, 25.272815535145423, 39.1013276961542, 32.53215782104, 39.70089335595408, 48.859266850256155, 42.922653690461196, 29.016002032064623, 14.667047242964468, 4.267511781184904, 0.4418358477132936, 0.19411672086965656, 0.13157186248610098, 0.12424502056092025, 0.10315737026112695, 0.1649448434792219, 0.22868145888130512, 0.17337443066700814, 0.14214936103070938, 0.08812191415457957, 0.13894311452825225, 0.1945255207078111, 0.12966571315642328, 0.17550043190919584, 0.14911864673899067, 0.15027655799302364, 0.14794478553437418, 0.1863683390641405, 0.15682294784534365, 0.16133238651579426, 0.10889995001977491, 0.13849038720851944, 0.16929144250048747, 0.19005938132684078, 0.06508242504130449, 0.12347595255461433, 0.07288228795533219, 0.16354097203621942, 0.2883276397422437, 0.17187063071516254, 0.17794063645264796, 0.1369444983861139, 0.15256058785223192, 0.21541065566482084, 0.13418831321741306, 0.15847671716924638, 0.15787392854690552, 0.1191142232968442, 0.27592222476678513, 0.2041120845223627, 0.12441211199808506, 0.14498886592205495, 0.13175955402754969, 0.17793288364285426, 0.1529823498980653, 0.11858071966637528, 0.15679798870077058, 0.23242263393777035, 0.12560938484966755], [0.09323503777024247, 0.036143308144903956, 0.013333447183662606, 0.006904608735273923, 0.027358541528003353, 0.024523439727002577, 0.06258793933797749, 0.06909131718378875, 0.11114003707564647, 0.025201946564559496, 0.030995725894406922, 0.05855296190167147, 0.04410975304762683, 0.05929045176373855, 0.012376408971425508, 0.012160082978586997, 0.06519780554358037, 0.04806845877019148, 0.06563901090093198, 0.021197562849509622, 0.053407218262192704, 0.0697899280836986, 0.03210996822153609, 0.09014827800133536, 0.0674364906585505, 0.06718913618955882, 0.025831590399086, 0.04235201027064074, 0.02394393443190042, 0.11395964666359848, 0.04579942125166136, 0.08535285870875083, 0.04129652114164445, 0.024720151953759695, 0.008789173537685026, 0.03073255745543828, 0.03675506765683813, 0.021961055650946595, 0.07887462003817482, 0.0198318540764552, 0.04137126067953725, 0.03453498315666953, 0.04423063789163867, 0.028802335727959875, 0.024017247131034255, 0.015068387353582489, 0.03597486839299241, 0.023614869024904988, 0.016116392761168462, 0.015223954913146315, 0.017439729211130933, 0.03658543663820432, 0.06355783729363354, 0.042615510042636626, 0.10619836393743755, 0.010004886125604953, 0.03360253157875231, 0.5413888202559564, 3.3543514003676758, 9.875805397187511, 23.1322035866399, 35.384819199962, 43.94225028253371, 45.48663646944108, 34.025062899435724, 30.689855852434714, 20.025166696117772, 30.9495500979885, 46.294370159026116, 33.46835697850874, 31.921158452187818, 25.426968605287616, 27.714281120607932, 22.70403765862988, 22.675827972350582, 16.836650410006126, 11.371869944757032, 8.037809210438883, 5.621360501935405, 3.217276575103883, 2.0476217447750034, 1.0318198006960655, 0.8816995399613535, 0.45426703388652495, 0.5805402032790646, 0.6108771625065035, 0.2808746461185717, 0.056201401391937855, 0.3389219861597784, 0.31143061456180393, 0.2022722477634107, 0.18063775624238676, 0.6173538536794725, 0.8039041079821125, 0.6118139348203137, 0.31392548713953267, 1.0001117279452663, 3.6429086519825846, 0.49601720165341134, 0.25665227894581133, 0.4904183859546339, 0.4667223671511297, 0.3777234815061093, 0.2597540923424306, 0.2545720744397371, 1.0078805336548438, 1.4608091812941337, 2.2813159467712527, 3.8109353905723946, 6.341920004736993, 8.646586556588451, 10.80602195955092, 14.38864427228128, 13.892374230969338, 12.214534301911632, 16.158999185408316, 20.045084491852794, 17.11015139856646, 18.948836941872877, 32.20503018748376, 33.13599886432771, 38.201622270768695, 31.257391437407467, 19.37975441255877, 10.215143369090173, 2.799512282494576, 0.2217823621486464, 0.04243601181153809, 0.03973474748612892, 0.07389432074682367, 0.031233858580010074, 0.03430137613547906, 0.0313378818288085, 0.04542189695301556, 0.012033082837719592, 0.04125822440630967, 0.017758494565984415, 0.02775775186056572, 0.02134740007139983, 0.0677765570881386, 0.11856416450633157, 0.10400899190215335, 0.015941788874296172, 0.06644885776744736, 0.037674940071038665, 0.045144917863991954, 0.04716368594897851, 0.053538625323844534, 0.04746856979064403, 0.045171979919917164, 0.006780557554110044, 0.02534702638043992, 0.0316400058387268, 0.07684199725307765, 0.059130404505037495, 0.04038797916784402, 0.019135690827463425, 0.07627536031988359, 0.026022401833606344, 0.028469321137714772, 0.03256099674129679, 0.031247136798957666, 0.017670649178926984, 0.08141819282525009, 0.059054082995581056, 0.012320636812927983, 0.06969933052577319, 0.03869699329257973, 0.01036100018198692, 0.12517517387506463, 0.05908470736035417, 0.03264033280673527, 0.05016292017253657, 0.04085199479314108, 0.04831448024619491, 0.019783500521894426, 0.058335703196785146, 0.01579915096367439, 0.04610380330573648, 0.05946921071999016, 0.05089219757205537, 0.03568146437887223, 0.05011359943197139, 0.050436930670853586, 0.035190888485240365, 0.07503276570670067, 0.04654927577282633, 0.027259459546316537, 0.03117763155680751, 0.10550126989161777, 0.05485089563374078, 0.04786210149646767, 0.05839551168103373, 0.04500935860579053, 0.07477798784572272, 0.024374090886164098, 0.10281442334094357, 0.04073102567945758, 0.02692777028818044, 0.02705397561282641, 0.06845453724024758, 0.010007368250479622, 0.027320382688494942, 0.02468271898255954, 0.0604984536767006, 0.043117343598315795, 0.029066329626666925, 0.02941355514790743, 0.09928110326009412, 0.06096382144718401, 0.0307020633256123, 0.024150441092769467, 0.06387360341426346, 0.02627091309536369, 0.07637999260858183, 0.038050694706579374, 0.014266322025157993, 0.052383506460295576, 0.034172140933092565, 0.1010024568606769, 0.06761557903260955, 0.05801592660587161, 0.01851365616124484, 0.04896678496152163, 0.03400591517528219, 0.024518621033958854, 0.030512144383523735, 0.06034856091343588, 0.06173547116979476, 0.0413045650648494, 0.047204690805125626, 0.018954311850510778, 0.04627347262876649, 0.7180382155122296, 5.044553414467843, 13.458320825330674, 27.80250503170875, 42.57833626962478, 48.37313613583965, 47.37686980155207, 37.951939875079745, 35.544875437213534, 23.02830392314542, 35.563224284879624, 49.314065671736195, 34.16272240300333, 37.18388095978768, 34.71892233817808, 34.43740598617062, 27.605264725223666, 27.032926197974916, 21.866831279570057, 14.983284415737277, 8.407477890291522, 5.332696120585165, 2.136785186106159, 2.0866550889707383, 1.1755092129591973, 0.5681355237480133, 0.10382989586721506, 0.31616629431805304, 0.18385046852692483, 0.059469769964174884, 0.13253471243285364, 0.272113848477602, 0.22247233157677038, 0.13695382933703162, 0.19488342166427644, 0.3761182821566059, 0.1389645649901321, 0.18449205184175124, 0.25204141023418597, 0.9169731084858218, 5.18980368491142, 0.7679283739097658, 0.157818065415467, 0.3260742933038743, 0.2919993459457352, 0.19356443276328428, 0.3149039652799407, 0.2510534019599999, 0.7222985836767382, 0.7843577729598169, 2.6859072043049723, 4.900345513897558, 6.543995122755728, 9.372482934305745, 13.071070121180627, 18.153813692831225, 19.68380674239128, 16.964250995266823, 19.48940819309604, 23.882048976036813, 17.990076311172977, 20.623169291403986, 38.61027048480126, 38.313068574474705, 42.726797980646936, 36.656318249241004, 25.23503330446059, 13.792896059251602, 4.2102451766690905, 0.3319200651059228, 0.017893741643356702, 0.04396343025408926, 0.03993696788506162, 0.023692682490593964, 0.013277892402613596, 0.0350092911732293, 0.04154563761286197, 0.06357162687627059, 0.05307181730806347, 0.024162644873403256, 0.03867447030760589, 0.05073391614601978, 0.039968772025238124, 0.05418753626966669, 0.02781645334776371, 0.07324361332481907, 0.07777416537846289, 0.03506821099548571, 0.03784222303018455, 0.13067330263795393, 0.05915831308811904, 0.011248320562674875, 0.04629746267211534, 0.026430697968950676, 0.07601436948583973, 0.011097658838656162, 0.07914752353944125, 0.04985468852664194, 0.013808260818252401, 0.04200056743537707, 0.09057754004794745, 0.07178108252945446, 0.015834524115968137, 0.05555462783142444, 0.008291886713836462, 0.04352460743018216, 0.01304386116023506, 0.031290478223273833, 0.063524596738599, 0.03737472170483201, 0.07344054388663462, 0.057144758231457204, 0.04451189175127976, 0.019988429041639454, 0.03527455677789065, 0.01623138255860296, 0.06994661604685169, 0.048161097952435096, 0.07698494159886915, 0.15215961743266354, 0.15896627799637858, 0.14962132299138656, 0.10509623920605068, 0.12584078936807572, 0.16218907199800014, 0.17808024831596883, 0.19817468860457021, 0.14076438131591967, 0.11646616377777631, 0.18434211311321105, 0.18606496824612542, 0.1185100097509642, 0.16115640079782856, 0.1647709568421687, 0.2012792139524414, 0.17119602901079964, 0.11094762643258418, 0.23125853269330918, 0.0837643294324798, 0.17560503355437712, 0.1443259087541411, 0.13194036609943838, 0.1563334329834869, 0.15185359595043046, 0.13435227135496755, 0.07867950510473982, 0.11063417389748559, 0.2968470277565141, 0.11930121003740257, 0.17341340922059553, 0.23082195450702023, 0.1911635591738647, 0.14183210869950635, 0.15397398942901244, 0.09085022904459508, 0.18954817085496842, 0.16925408805329956, 0.20039044470796663, 0.2363300807173214, 0.12444283212384871, 0.17724063127271592, 0.12868225544450745, 0.20173407099660368, 0.19907462741098098, 0.1617082292514463, 0.18761153122590435, 0.25841625767850107, 0.09515020395478896, 0.0954130870260058, 0.11640621739770136, 0.12506118765281093, 0.24834868257805226, 0.11877001233158574, 0.3498972375546733, 0.12504414985737494, 0.12969712276131878, 0.9097939453298046, 5.013338212044009, 14.263185301134664, 31.18641418795432, 47.33535935801845, 56.116032138947524, 58.71210382830713, 46.27210678592805, 43.08698923357072, 31.767627077717936, 39.431693246287686, 58.41100308202929, 46.33399786487703, 43.70482529363325, 37.33539819717407, 38.578907212903424, 31.272296444062267, 30.99320019445112, 22.159681320190433, 15.95944271933648, 11.120502891079074, 6.810484874633051, 4.429641481368773, 2.9555775080957725, 2.0240636217978696, 1.3861979784504062, 0.7805338297640124, 1.0533702830153129, 1.2527849308906065, 0.8210213927011337, 0.4343576344751543, 1.2761676503765969, 1.961903002473616, 1.5173893710297923, 1.1036772545306914, 2.1163270838799018, 1.7664759341747531, 1.5386559718078183, 1.2189107292121457, 2.355104309897269, 4.807378966962138, 1.1046993996827834, 1.0731963933475557, 1.1209405862515973, 0.9269510053338544, 1.5382567480687173, 0.6827745142002261, 0.5258066531631255, 1.7015092267144112, 2.1131136821162317, 3.4647227294983405, 5.8512393409206025, 9.397260546684265, 11.906466445615216, 16.1666880115386, 20.309185520295177, 22.978076011903827, 20.63603662675427, 25.96874402415368, 29.6402217495826, 26.271517661310014, 29.55817557150318, 45.52652305172336, 45.75564438296903, 51.0204771257216, 40.85605098355202, 27.544228722972257, 14.326742406814331, 4.502148945485392, 0.489121399098827, 0.19208386059730284, 0.18179842541294713, 0.18466472805988404, 0.20665765679892034, 0.14909845266130664, 0.15015461211723669, 0.17469603958870136, 0.14633699680768675, 0.20003853455906917, 0.09346878651769892, 0.10168425979152804, 0.08401402046964054, 0.18856831375629673, 0.2554715535933933, 0.20295907623104512, 0.1568565178181856, 0.1940092234121215, 0.1631909311418572, 0.1766305648150944, 0.1879751931635603, 0.17810405832865547, 0.1442235900509742, 0.14611109280057494, 0.11692023941225584, 0.23823809930153433, 0.11302203165307162, 0.2957947600272394, 0.20680099184955322, 0.12078136851590489, 0.08494815744099118, 0.17421544199028324, 0.08773967458475983, 0.16888247412298957, 0.16272410780431765, 0.1455450151115656, 0.16880105429839704, 0.14810987748205662, 0.2510446992011801, 0.18063182672185285, 0.16665628390206447, 0.2350297383964062, 0.1290285578297992, 0.23676828301000982, 0.19384308958486204, 0.11346242495722349, 0.13393594853339658, 0.18730157205174047, 0.11789652654120039, 0.14320247145670076], [0.027050882532832124, 0.03507794031212407, 0.06821793098483356, 0.008390515746038047, 0.02527906097501757, 0.0678939447407761, 0.026751142971578146, 0.031474055872569164, 0.04418052425007186, 0.02825831945595001, 0.026983855585117015, 0.01502433155227693, 0.016443811079126694, 0.0220604038481871, 0.026257364830422788, 0.031321119825025244, 0.03688772344180653, 0.041775291620363156, 0.024137599543938716, 0.05578883623163547, 0.01904403798342232, 0.1084360684598646, 0.04650969584021838, 0.054782058803304556, 0.0833557517598233, 0.04802684487414457, 0.03909746192455773, 0.07541723459238008, 0.024189802690318996, 0.03219854522256121, 0.019305695313960314, 0.1073133742677108, 0.07206182311018629, 0.07211665202292704, 0.0449026502188175, 0.06830938656123416, 0.03894916645461514, 0.024417261855917114, 0.06207370664924384, 0.04096368275162193, 0.05345743915606892, 0.060806922809851754, 0.06891140909565073, 0.09044058650972382, 0.053700082184326266, 0.04383215342738456, 0.015457296676393, 0.06489871715706202, 0.0745578141762845, 0.012555248366909163, 0.0696153213239966, 0.05952808457697111, 0.024592835801623525, 0.08966350522372993, 0.018661302371671604, 0.007480876830091039, 0.03195451174472128, 0.05108285770421067, 0.06745973376617317, 1.39506081900289, 8.221478116127754, 19.3824569256075, 29.10663820082142, 38.53015607403171, 45.151246363116854, 43.003493739712624, 34.45016153397099, 34.82650902963454, 45.670740758219075, 30.468632213531006, 21.920081377029422, 20.631474910243867, 25.399876794507428, 31.891207233552013, 32.05582910968412, 21.960850492600475, 18.88351575020821, 18.96090215252292, 12.734477808398585, 11.18792353137847, 7.302557979860614, 5.184961028637425, 4.224272552997836, 3.003553488562184, 1.5641959948885826, 1.4797424621159032, 0.817166805988358, 0.9294110055892699, 0.5418696783242688, 0.6198643544508565, 0.38209539207239307, 0.6908068541557558, 0.5611529693968835, 0.3853839317396764, 0.4379466644698574, 0.4645708551810634, 0.3685383017986052, 0.23223178611407358, 0.4016661499777148, 0.7113144150184048, 0.5981973041930507, 0.7002693270483326, 0.9716805503253014, 1.451310671625599, 3.321187515412608, 4.08716953569843, 7.549862928928868, 8.747133574178143, 11.283973551565602, 14.930678567578717, 15.898200792651023, 18.675469313898397, 20.570795843678138, 17.74334353785361, 20.72161489917386, 16.675035030611102, 24.769345983382195, 35.190665798802534, 31.334977880600963, 28.82314301306202, 25.222958287885113, 23.43689722399558, 15.04624237937312, 7.678742697162013, 2.1446850847813392, 0.17670397135999896, 0.01354607297182684, 0.058992489526468905, 0.07339614909142256, 0.012463457627041687, 0.10170892782268987, 0.030104803942864942, 0.04873233141317483, 0.03342194550280129, 0.031775626383962176, 0.07014983619052557, 0.03283547072280799, 0.042018497723244855, 0.035959332129888, 0.08146189048045105, 0.037070067689543774, 0.059516562614589937, 0.08106642823305824, 0.025272690953927177, 0.049766121101715875, 0.08434169925749303, 0.02667801030310652, 0.05213291526982381, 0.0117044368638627, 0.03851849480622238, 0.0044316046161486985, 0.03774274651321673, 0.031188079080874884, 0.05987431801434967, 0.057486398971729705, 0.015200448462799674, 0.05501880295454495, 0.06919349799112928, 0.032231509985943, 0.0817044952043122, 0.09231457546834024, 0.10165108052352745, 0.032677821319309935, 0.06205424418552749, 0.07979358846862471, 0.054378468363035115, 0.04835866053678817, 0.024654810399478002, 0.08014641792303132, 0.020078247105101907, 0.019133990112271522, 0.05032884332561686, 0.08128559066643638, 0.032634851447637045, 0.026448206908460108, 0.03501763004028509, 0.024494108135601687, 0.023122720735808535, 0.022327180561279098, 0.06256119520854085, 0.060813273678744034, 0.09607614378534979, 0.04362624048465683, 0.039831075381727955, 0.05196182868413387, 0.03865712607700018, 0.060586542296673984, 0.00746282923500985, 0.011770693893213908, 0.02188759164944772, 0.025492290057422175, 0.07868312103974243, 0.0310634633886718, 0.01913944657351221, 0.038342424818585, 0.022953830907241474, 0.017877466105405363, 0.06941933305032792, 0.004911751659106343, 0.10525606812969332, 0.02316881050055306, 0.060475072673251556, 0.03700509960312517, 0.029455914064460707, 0.014839702447305524, 0.0051303452722007235, 0.05969612596316203, 0.06064712836016571, 0.041824229316966194, 0.03842603565464097, 0.03373432168436628, 0.034329173635811575, 0.09621306668005644, 0.018502228044634386, 0.035338030992856914, 0.01346636535374508, 0.05053367991481097, 0.06952695308193084, 0.02838605887166435, 0.06397906307791991, 0.06685132971934735, 0.05966322631725381, 0.03188279825412939, 0.03645646956659133, 0.04478794004347536, 0.07852421142160892, 0.010795553980935967, 0.08682206212993591, 0.025312362817086043, 0.008528491054030677, 0.028542700869541977, 0.015333883742231037, 0.03825507930389816, 0.0802789970992073, 0.13655627566960551, 2.7198933161074117, 11.131497294672075, 24.60926425072455, 34.964780422949026, 47.162186714910696, 48.94256622560563, 47.670988728923184, 35.020905617744695, 39.96831270956224, 51.48065351670789, 31.784556027381655, 26.845072123312182, 23.639638654647335, 30.87523098914854, 32.92831328607375, 37.84601626857635, 29.913195179354762, 21.219240119380338, 23.765648718803163, 15.802213530386648, 13.933859179096839, 7.185480133179696, 5.289875115117719, 4.920862941972671, 2.830746851621136, 1.8936354979392023, 0.9403477993703658, 0.8692585785062084, 0.6975128814097374, 0.5401526607813374, 0.15337368293154627, 0.8335903827701846, 0.27406148912925876, 0.4392823540875989, 0.07880464556717104, 0.3734950745298017, 0.13835198576411895, 0.44999961771311303, 0.27494935438998286, 0.28591694490563485, 0.5532555834900948, 0.43648552029363574, 0.8350397598358893, 1.0707434411010435, 1.1549461873308307, 2.2587208882454903, 4.197601906714901, 7.65569337914067, 9.417688250541687, 13.591177386622276, 17.656555214235862, 21.508687503876228, 24.642174897655366, 20.0620997336603, 19.8962305438134, 20.20806093369761, 17.41050297214139, 27.198469831097512, 35.20585321610974, 34.381214111082016, 34.59792506310248, 31.84281695273615, 32.324848790322584, 19.963259927688107, 10.652185620800143, 3.1044520485785703, 0.34095282396001203, 0.026380055726716117, 0.02541781673508306, 0.0850722253803284, 0.01634912452690544, 0.06263847432790265, 0.04515560096009605, 0.03987275056480881, 0.04122741618043473, 0.046018652632952704, 0.05152196398064975, 0.03720246683505755, 0.09721556167689063, 0.016574733590166417, 0.018623938348384637, 0.03754611855613128, 0.049790095823306235, 0.07483195107910903, 0.05561100041133262, 0.040018483470644683, 0.10381458943048794, 0.02106882943471353, 0.03350591256974205, 0.03438710903508529, 0.0030231055232786365, 0.048931269125351985, 0.03823776954724904, 0.01401305718783049, 0.030124230017404885, 0.10538996497709906, 0.020534335635602474, 0.021339133982696844, 0.0431806645956972, 0.055499680175055424, 0.02027794707476372, 0.05731772173256163, 0.06889294637667556, 0.10095027095127491, 0.040379877788044756, 0.021250865332061247, 0.04152426375977455, 0.05873200048001544, 0.027918760559611747, 0.020657357864923055, 0.022717167195233128, 0.040047058550220345, 0.010816845479571532, 0.02903671266751424, 0.04198367519664668, 0.01901713872118102, 0.033748521124042814, 0.13469871163608568, 0.16488704980621416, 0.18954251712608725, 0.24414308970012974, 0.08971818091888582, 0.24275714471455545, 0.19723908074440497, 0.11726700911118139, 0.17038343954951535, 0.1498179164745154, 0.09680390433077851, 0.10173914999130274, 0.18372265441763788, 0.14138197075695763, 0.18206341522595576, 0.15166362146696738, 0.22223660632246928, 0.10126674953367441, 0.13142537115322006, 0.15888478156299363, 0.10350250053189455, 0.22073086050729598, 0.1373873891368989, 0.1719064376647434, 0.14814680292000695, 0.18760154143937174, 0.15790202865196815, 0.19575176700468988, 0.14718539321855192, 0.12463270701588162, 0.29054763997274063, 0.20092733444706087, 0.21184333660189184, 0.2841986709785077, 0.24303129693913847, 0.12384768139811293, 0.13180705147885508, 0.1125755632716802, 0.09204473631877093, 0.17187148873363772, 0.13973028519220893, 0.12925757215388362, 0.07418322016394908, 0.1604136325899632, 0.24315212432655597, 0.15059158866924627, 0.04465489738410519, 0.18615928899136283, 0.16772644744525034, 0.15359143576314374, 0.1623015643488015, 0.21422340324328792, 0.09592658810077176, 0.11756733856013707, 0.13417073916043007, 0.1711266520883768, 0.1313765713524434, 0.20915229955027181, 0.24438498962310054, 2.270225445109029, 11.127808305525011, 26.03300029231656, 39.43951445241129, 52.07900324175435, 59.44058995093069, 55.194675230210834, 46.49969054806618, 46.721567261603575, 58.08641126078945, 42.5578026617727, 34.930804852516424, 31.22238036124937, 37.11197606978878, 44.25427482974145, 43.107142371516076, 33.44197903909991, 28.525790091483827, 26.400783292708862, 18.286278017105595, 15.275568654460294, 9.894481762762993, 7.186765690003672, 5.757635408832181, 3.984374509703729, 2.7004569913110426, 2.095770432103065, 1.738643653450474, 1.6844765793892646, 0.8145446402411308, 1.1999003493016767, 1.834885869776049, 1.055749813395162, 1.243874654173851, 0.8607581894724601, 1.245014102708909, 1.470661807444788, 0.83612717567913, 0.7759002848498283, 0.9518141131247244, 1.1485654716530154, 1.1269381353932044, 2.2570190698869768, 1.7604186914620863, 2.0480588439010807, 4.19686597201132, 5.334526396566822, 10.33713790678209, 11.735508961062278, 15.673369553781326, 20.719051630266254, 22.696138005102835, 27.614796084742395, 29.485478362729474, 27.142823165462865, 29.975301988663215, 25.506720196816232, 34.67119886029151, 46.70104149849185, 43.2408324364693, 41.94403017720869, 37.278786628477036, 34.573578911442915, 22.133519111141084, 11.542364589629635, 3.7821623538770988, 0.5789123583705195, 0.20180796783777977, 0.27279916009114635, 0.2721948699364739, 0.07306291616611904, 0.16368683517700242, 0.09878848574214405, 0.17057169799602803, 0.08271441359313265, 0.08324903571197102, 0.1456678649711032, 0.1956472879335765, 0.17869987555088537, 0.10930128050066772, 0.14907844244472443, 0.1328107339119719, 0.1973757661518551, 0.1898462097010305, 0.1557379375181852, 0.14968021983100524, 0.23751538727552662, 0.09690882773288796, 0.12234372056780324, 0.1971975128136335, 0.10241535281942737, 0.13518009064418657, 0.18334967685082268, 0.08048454615017099, 0.17894274074464075, 0.18914612791230603, 0.11184449322641858, 0.13321296071573613, 0.19249866656478376, 0.23278571364860381, 0.15935226373614805, 0.224408388979012, 0.21426031335947976, 0.12527412179136468, 0.20290241636816533, 0.15879881117613087, 0.16521773931960906, 0.32775554986250016, 0.1407499635411847, 0.1739504828207916, 0.14821642499056556, 0.1711609268621091, 0.14295550003167123, 0.1522545204047234, 0.07882628755103196, 0.13856961602164855, 0.1270617573191562], [0.11961914418685822, 0.025095770608693845, 0.01934233346893903, 0.024764853184141462, 0.019208428960654046, 0.08878486366161416, 0.02964722154091203, 0.024615820354571747, 0.04088718504194291, 0.046236160316414414, 0.06516922280312547, 0.08928069108796698, 0.010524533140743452, 0.02295255920128717, 0.03522902051167142, 0.05473936855372402, 0.06152036134153605, 0.04472950668705087, 0.05739480166906311, 0.01406538865393809, 0.008611666177579714, 0.04041190792415892, 0.048942867696525595, 0.009853564608361452, 0.027405307365341053, 0.0411109708159441, 0.041188345696296425, 0.008865458657965064, 0.019968196659559206, 0.008562547492704565, 0.049582700500445026, 0.04612369860913004, 0.029995092491228736, 0.017429279771843748, 0.10904525391637318, 0.0701852600961443, 0.04437526763086358, 0.03515947504990524, 0.03327360789802286, 0.012560288267841023, 0.056605524263314666, 0.022534842099693995, 0.02687908923103204, 0.056325794918642896, 0.013100646470012444, 0.013335632449466617, 0.029311757384529038, 0.013033896271559983, 0.045774860472808925, 0.055685533105485865, 0.050416878319435546, 0.012870393956320421, 0.03691517237213351, 0.10199066431772325, 0.0036506780475798637, 0.06894730031490326, 0.08432652305571303, 0.016778681517368364, 0.027070852529798305, 0.07508421617169535, 0.7414323956735673, 2.7414599782036198, 10.467051709851912, 21.455431522861605, 36.909440563571074, 43.06234890414823, 47.53715353627359, 30.945090363102576, 43.1472642960087, 39.25040914166359, 26.371581246775968, 31.410218746431415, 26.182232749077585, 33.28620210770638, 18.67155282728134, 25.397770481724894, 33.64091773186961, 28.656638399247203, 22.234023963251424, 15.75430864287961, 19.697882167754635, 13.814292588541585, 11.965142161615434, 8.483724844071174, 7.595356539372475, 6.4655771370857, 5.741036918855483, 4.470314989166876, 4.279225449408255, 3.5859489729327545, 3.2629545369455895, 3.0030207816631567, 3.332051745345516, 2.099489574470828, 2.3225996282792862, 2.3279860231184193, 2.4554731047922567, 1.9419866776274097, 2.1253443677579207, 3.001380495486721, 3.5688099313166837, 4.705981285341324, 5.087392070601064, 7.66246437065063, 10.796073848201383, 17.204029406270674, 17.55920002537389, 17.953360965175015, 23.6880289354632, 15.24892399387975, 21.129247219331805, 19.091116997503466, 31.91578284386666, 25.713791924138224, 26.18235630373801, 27.775479901221495, 33.60090563374181, 39.462785874643636, 32.93046274492818, 24.732230555626657, 16.738614689919256, 11.345921504882075, 4.0215360253087935, 1.6522562696087746, 0.12354796481949669, 0.05442864329163587, 0.07354995656398035, 0.10851403322791862, 0.06011540588412074, 0.010762123819140178, 0.06327258828546732, 0.016969671067331108, 0.05519077437178743, 0.05395877092415768, 0.045081895640901024, 0.05555035689124658, 0.01208005743401666, 0.009213884064416972, 0.07919116756848751, 0.02884400325016149, 0.02270831504926807, 0.05947196863651757, 0.0702767156725449, 0.014253244904290526, 0.05197663333327059, 0.0889684949370642, 0.06089179769098278, 0.009708174526871694, 0.07399901432255584, 0.013302683965453218, 0.006983224678063586, 0.05124344888533797, 0.022866148313867952, 0.02658782068700079, 0.02536575723018858, 0.021800339980531606, 0.0577199753494032, 0.055346596655586076, 0.045775339277761604, 0.026744315212952997, 0.019285909178095962, 0.06696275720793395, 0.041901761245343, 0.07466063083660218, 0.0067247102232349506, 0.047892316004201296, 0.022966459866673238, 0.13879093882297316, 0.04198715706626254, 0.024022916181673928, 0.05327258213994004, 0.009609498571784747, 0.020127491236874656, 0.05709856696006271, 0.06081854436366309, 0.049546648402728384, 0.09277777520999794, 0.03302801543125703, 0.018279016836576404, 0.05133976912005775, 0.05090844629692936, 0.014460825045863468, 0.04671347139763736, 0.057270676273131566, 0.02749655035234267, 0.012285785558032654, 0.03651415215685003, 0.015385788114320849, 0.09080216468822572, 0.029352432822868712, 0.028100375108601108, 0.020655791215117902, 0.06514722075794013, 0.05113952139753008, 0.01933837854002993, 0.021031289211203976, 0.024370425155446417, 0.013632079747865998, 0.031240891267154968, 0.01204898586541775, 0.04750230447238973, 0.024301394887809313, 0.028551957126887097, 0.03939067058625721, 0.04873084903304135, 0.018710958275703654, 0.04552690462479669, 0.057911210047501716, 0.027683506449384075, 0.06801204485518318, 0.06035866178271752, 0.03693000383434757, 0.05308271490878636, 0.07813057246347589, 0.04411275228185039, 0.06572774686520139, 0.06455982284199807, 0.04524824014233966, 0.039492966306786385, 0.11286156687645182, 0.05558645878467829, 0.031075102179461432, 0.03564203766384914, 0.033044176056019725, 0.0417267982547562, 0.06204825337795962, 0.025380933431968577, 0.06699808918300175, 0.03112052736293164, 0.09376131719158542, 0.0540590709856441, 0.04405329619804698, 0.14283977478982943, 0.0956645094218754, 0.05932895917325251, 0.06860412356834258, 1.2133065202543813, 4.576214571152964, 15.444413942675437, 26.464278621058313, 45.22528110011932, 48.410516323581824, 53.592351713488185, 35.92450595671131, 47.97089707466864, 40.635347058696134, 28.288337645992158, 31.28859389212824, 26.192230870646817, 38.22263833015196, 28.976899923816806, 31.411603343102243, 40.038707487044796, 33.87678161744149, 29.95180699133104, 23.619322738339825, 21.345958171352265, 20.295672955051547, 13.41634754211672, 10.909570570914976, 8.002770677689584, 7.578358948230744, 5.779922806447552, 5.654172599315644, 4.127957282527801, 3.7669271326834157, 2.9046903935170945, 3.4395987228039777, 2.9449822056678037, 2.6002879921467077, 2.106459381118898, 2.783682331923516, 2.001199390619032, 1.921315051374897, 2.8567232383835703, 2.7905533438728702, 3.2859082471939827, 4.163098287197852, 5.422912105437248, 9.47195718365331, 13.3468617739216, 16.738559776736846, 19.200694291822373, 22.41344298085859, 24.814853322121408, 23.248048828494166, 21.55544019514515, 22.851401106003795, 31.34871990449967, 28.547296447138635, 26.791476857277658, 29.937339328950454, 37.20545791810559, 43.10760128882624, 37.98243238079933, 29.845079298942323, 21.907408199002667, 13.617506296403947, 6.17025355177541, 2.1944898703405937, 0.2953183452688879, 0.08009417072659539, 0.025281531608573375, 0.06229053634489256, 0.016615368808890064, 0.02353552146814764, 0.031344284408635674, 0.06995036987768066, 0.03481158686261024, 0.014734257147797655, 0.035441525640987584, 0.007765134233200262, 0.026255819248035554, 0.03734768263154453, 0.0799792345553156, 0.022895818899175333, 0.030809453530837933, 0.08088357836729096, 0.09880045969640056, 0.010085936312774017, 0.06349502574472178, 0.031021173420031706, 0.06067530124358112, 0.03229989099406427, 0.006280927458823088, 0.02770004054200986, 0.05823483623023476, 0.005589192676838608, 0.010041625787233634, 0.02224832904645272, 0.04332774581627981, 0.0673999252819246, 0.014536318222751782, 0.08193092781209177, 0.07732830986741089, 0.07840683142985068, 0.06850981814486366, 0.08623618106808394, 0.019502920819626703, 0.04154403648910023, 0.01920789652954667, 0.05407582532854811, 0.10907842552349453, 0.06406871834769845, 0.0704096012838906, 0.019126298589511745, 0.07376333503353019, 0.01855443119101467, 0.07381872319045567, 0.032451074615481405, 0.03189491393465189, 0.0641452543617737, 0.17493787822463822, 0.13622025418425762, 0.14378613852445157, 0.14541333991914027, 0.11957838830928649, 0.17973524338055044, 0.17284173908973896, 0.12410764567433827, 0.12494648896878767, 0.1609238318257755, 0.10993020038210577, 0.24991353973746303, 0.15841466404737967, 0.18881788988026882, 0.1477874157529685, 0.2219072344803041, 0.13574745536090868, 0.1333998402039851, 0.13593125517570204, 0.07153460140069647, 0.08793036919087173, 0.12341212210876328, 0.20112388196491426, 0.0948042769525801, 0.11170306573471717, 0.10758421699246092, 0.16176789217898924, 0.06770339569136982, 0.10046050328040317, 0.08705618626047527, 0.13279568794513905, 0.15854135966829716, 0.10019090927896962, 0.09591231588274242, 0.1445997851870714, 0.19076701674249866, 0.1634444143142431, 0.12656552386620354, 0.1285587007840795, 0.19467219590179383, 0.1548425033087692, 0.12415002565830947, 0.06391437844403329, 0.288285780698061, 0.16374599248651536, 0.11906676414993503, 0.08948858436797896, 0.11743350299976527, 0.1552570028410804, 0.18787773145783335, 0.13264938047335995, 0.12062959883722568, 0.13450099966458737, 0.27424470671722967, 0.12201473943047947, 0.1793738030978749, 0.3306834766220662, 0.17028161114261997, 0.1934786002722479, 0.18199625995851335, 1.0618736138266902, 4.417799355522279, 16.12361352289877, 31.43771456133935, 50.543634583873136, 55.203516252579234, 62.299401606282885, 42.788877333364184, 56.14699140671761, 52.66804518238191, 40.95586745969711, 42.510506722234915, 39.40229900421635, 48.156123161315925, 30.751992079519457, 37.38538488265007, 44.98449463998118, 41.26966491822274, 34.586789454183275, 25.532721588688513, 29.843586837091756, 21.36725271901777, 15.656215067832703, 13.29850777502983, 10.370686919458452, 9.596233560192971, 7.22638015785525, 6.04686608237605, 5.746732690641958, 5.5198495618758665, 4.612590632131023, 4.897922960019881, 4.384212590033009, 3.7641836798960164, 3.059238152157876, 3.180535488551663, 3.7301617764657546, 3.1177084340203196, 3.4114054614497773, 4.386346359406748, 5.19182272495762, 6.859925860358823, 7.164632735713837, 10.101827075404506, 15.102676460819861, 22.129865423325572, 22.185374806004187, 26.60107324200292, 31.43076216020892, 26.070196128660633, 29.657440954639068, 30.46256430687443, 43.059987637304495, 37.68440677273659, 36.680884053630216, 38.32185076129052, 44.59066906282979, 51.80716337696199, 43.3179501564272, 35.399504553887155, 25.140121752215972, 17.842652067061394, 6.246890781387207, 2.3629456181680006, 0.41482793888257397, 0.15095164999365807, 0.14603529606134663, 0.16021592061846487, 0.1679447365383948, 0.12870609610071107, 0.19699377939105037, 0.197117640486648, 0.20632635441518601, 0.16538159020485418, 0.08841810672874413, 0.13055187770195548, 0.07704736244293951, 0.16716406230003605, 0.2327008004630766, 0.13748007045397836, 0.1212013302551162, 0.17202849079283977, 0.19632673131362086, 0.11004946495015776, 0.09783117461108393, 0.16319119161175144, 0.2138814522374061, 0.05157922139211048, 0.1389032473126727, 0.21515842887663075, 0.12981372134339425, 0.10635987059363436, 0.09679462700601547, 0.11341609962044225, 0.1187625582960825, 0.17765272528894488, 0.1169357143883263, 0.2353089161577725, 0.11743466745341018, 0.14408906501147056, 0.15605825420108535, 0.15089117501291538, 0.10365799339788576, 0.1452484011890427, 0.09040437353354308, 0.18175414553092373, 0.15216832019148335, 0.2248864125220045, 0.12508672902420645, 0.11983377137972463, 0.17358962476493853, 0.12148347277674945, 0.15226955104979778, 0.19450163408633203, 0.23865840578031158, 0.21656390910427417], [0.05408579596288262, 0.007961516084540035, 0.09790658064547086, 0.059684730405288364, 0.05694097501315898, 0.012062703627311896, 0.013970673373419673, 0.06032101622211838, 0.0388468056166124, 0.08508413804755097, 0.06658522907884852, 0.0675644196810261, 0.023779432371919675, 0.04738885834212265, 0.025650109915483384, 0.0571289002114246, 0.06827204743580473, 0.03344303590335673, 0.05946911112856, 0.1150849761982118, 0.08543441642916973, 0.055759242255120516, 0.010590263484646718, 0.02458690053543016, 0.02451214376055906, 0.07983900216077605, 0.014062353988148034, 0.006894812385942186, 0.1577991124002203, 0.03566048889150543, 0.042308507967860474, 0.029072119336154674, 0.037346510517020384, 0.0388555581711473, 0.026904188186651277, 0.021361540139262235, 0.05020192936964093, 0.050971782616069244, 0.050537276697615464, 0.04481922324386336, 0.055655061958297614, 0.09909223194324202, 0.015944641594204213, 0.03743007155736128, 0.016579810837884585, 0.034578129228565006, 0.015955814028969936, 0.02958030567594594, 0.041426012983485576, 0.05151290499094514, 0.05683362694276918, 0.06245163314404988, 0.01887355277675294, 0.01722553102750211, 0.03571208491320572, 0.1321309074879654, 0.07567542154462108, 0.024780481377796783, 0.013781637347663843, 0.034899537586757255, 0.028089789688707362, 0.11988983369402348, 1.8177745298993204, 5.45434647029446, 15.263836845274895, 32.984003097780295, 39.38438946200956, 46.58863029172344, 35.306583604504986, 44.08303199275848, 34.88932971031436, 37.555639282349624, 21.628527679751, 16.163153956013343, 11.906842993151757, 16.88303439847885, 21.77827004463442, 25.362820202304473, 18.59424879474025, 31.594477968831217, 22.277509320166804, 21.19080097444596, 21.666937489663404, 17.90431760972546, 14.40089677610705, 15.96668831763729, 12.681743502616884, 11.928361115917085, 12.266979332893127, 10.431351277136034, 10.945631861686708, 10.950315171672452, 9.99274301913477, 8.33997586081105, 9.285258247006325, 7.418420382084386, 10.911497435262127, 9.67751487608879, 8.648722287147276, 10.227848906670848, 11.083853244781496, 11.591329497675742, 12.458941109718817, 12.779181061252473, 24.998484965293642, 28.23348722150249, 23.309849692929177, 12.555904061563554, 21.38718620423348, 21.659941942461078, 36.07810989502938, 23.52473674281951, 24.218645211189028, 30.323579042188584, 35.206159160983184, 39.84914718135711, 36.66746170290055, 33.717549077926144, 22.310590590200118, 13.303870635647929, 6.266241794632328, 1.0924468958570113, 0.2958813892497171, 0.05761154709504016, 0.0935884417905923, 0.023378456206691843, 0.022151131641059633, 0.029117075290771264, 0.040981084438821966, 0.036720183843206015, 0.024390713078901175, 0.05960612595381756, 0.04550409052641161, 0.07402014302750749, 0.01749489903299799, 0.06190154371002029, 0.047866372436645536, 0.0595434025050171, 0.031833213213230335, 0.10319715320703485, 0.08471013392291724, 0.026808655107273694, 0.011561052017514745, 0.03606834261107349, 0.05697898446552216, 0.13182781246160308, 0.04803396949184038, 0.14789869768484948, 0.027534529161188873, 0.07893952300711986, 0.010896650773863639, 0.011490353593422521, 0.05374707018716201, 0.021398775842821887, 0.09264370982324885, 0.04054895722337308, 0.06156318948694295, 0.04395397672910364, 0.08669378836789439, 0.08084136692266311, 0.058096362007481445, 0.03491868978486427, 0.09319890140285415, 0.09044489958473752, 0.029206586919064005, 0.01207601823543589, 0.036549744601812095, 0.044823532488437436, 0.028369666505304557, 0.026707280607473467, 0.01808750443160534, 0.08908705470422584, 0.06594503238316506, 0.06043079662166777, 0.07181064586245245, 0.008688919441474062, 0.0798150082869876, 0.015306123588684828, 0.10144890992030983, 0.05741460121146614, 0.04787247432696243, 0.02333507073232003, 0.022295454945114833, 0.026945915080667026, 0.025122943747368072, 0.10517216618022612, 0.04143914373050775, 0.08174181900798314, 0.07533981374675229, 0.03745694592174503, 0.03518280242719958, 0.0646387375590782, 0.021480320156702114, 0.05557334718985423, 0.03820498481452946, 0.023019226087677865, 0.036964592704128836, 0.014448008394890256, 0.0021237494224952834, 0.037177595790595784, 0.03289691480477491, 0.07803048307616865, 0.03134779883698831, 0.040075128011765986, 0.10839141319475828, 0.025770079284425707, 0.02121618644694888, 0.0522002429070492, 0.05146906943991781, 0.04121377598494291, 0.039520254358649254, 0.05298875422487336, 0.09645731849295479, 0.04571671439935604, 0.05101983931155936, 0.08252907394161148, 0.021455860884499647, 0.09362130696254392, 0.043189122206381256, 0.023174450822895574, 0.04596756989016168, 0.032377989827505047, 0.04751546586292887, 0.015552867102556893, 0.02399557641887617, 0.053421069131863695, 0.024785637149527192, 0.010388156083682853, 0.06641077553673137, 0.02704021667370633, 0.07135483120838482, 0.0122253010011909, 0.033005216654630444, 0.008584966098198728, 0.04272580755153491, 0.051498146307083874, 0.028518362256187587, 0.3485526919605271, 2.8041389632609586, 8.200276724753842, 20.91147722736482, 39.12957268376505, 47.68521908790835, 49.03642854382915, 41.7568076041437, 49.504112351325254, 40.35036725382651, 42.03042038025395, 27.81193833197317, 21.66230909286007, 14.812853509379973, 17.52955279042644, 24.39257291055495, 29.849101689554033, 26.662648570153024, 29.75444313018553, 36.02928030875422, 27.47090589615607, 25.24356249840029, 23.566859076100013, 17.52657178909548, 18.864268679772657, 16.85084350647465, 17.65643362076052, 16.04037102191679, 13.53822833107364, 11.95485378465345, 11.945125326033562, 12.73995049538151, 9.374161708739496, 10.552152433703023, 10.153294455620552, 11.463003273933165, 10.464371750431678, 10.5978911922824, 13.071984033430777, 13.342630517098213, 13.164789272892861, 13.459531857121377, 18.393158681931034, 28.103025267201087, 31.743651590039654, 25.631577084141394, 16.439091717043233, 25.796846151351932, 20.60304949360509, 34.50322335766208, 23.077035450166274, 30.882071602729063, 32.39628495708589, 38.32562408139629, 43.693991707217315, 40.75064512991136, 39.93930285976779, 27.95286124752414, 17.136935303288123, 9.186886183677181, 2.7054251634305526, 0.3822004686920874, 0.06109191134812371, 0.03633872568306904, 0.00529034800204118, 0.0256337367013217, 0.12027609522544569, 0.07069745116055974, 0.011258389830829637, 0.023965695159389608, 0.010449640385265793, 0.005345763929653914, 0.13730863529828288, 0.049520949983308395, 0.04124345806156916, 0.01225533452065241, 0.028094342166197397, 0.01295459468007809, 0.03606912402075625, 0.02478355530559296, 0.005293716394883251, 0.06215406161162162, 0.012145431547035134, 0.04631523974239827, 0.09063092105451132, 0.023436529501791925, 0.004486514925731406, 0.06771776750082932, 0.020075422155881123, 0.0562840776007262, 0.02323810889896366, 0.08575931431785708, 0.031279638079145265, 0.07458183869358993, 0.05500995463901951, 0.0307972057001485, 0.09624365657087296, 0.02079716316544481, 0.02567979199210963, 0.07356073542107498, 0.005252709144711374, 0.013641470070597867, 0.036614796957902374, 0.052649492187605756, 0.007965068817288886, 0.08063689805567265, 0.03272019364240189, 0.03462906258421079, 0.004639231680607003, 0.03224317750502979, 0.09364772167417312, 0.07044465746730566, 0.052172732689688285, 0.04026850392561286, 0.03671807327097462, 0.14096629144924303, 0.20112282476357876, 0.2572407723674851, 0.25159450518267773, 0.14988304926983773, 0.1255987055840031, 0.17737803680281486, 0.13186918120951424, 0.12742449229042377, 0.24092645504541937, 0.198535347477563, 0.2673841748506792, 0.17645732169189762, 0.16819311756520502, 0.14314231823288626, 0.14200694528558563, 0.304361921284468, 0.08068866261671628, 0.1174570985078331, 0.22598689782523343, 0.12844421660467503, 0.16370148277811467, 0.14316690965525566, 0.17714327681929837, 0.10560002628593676, 0.22045039571821692, 0.19665450969290352, 0.10779830792378034, 0.295686619055848, 0.1630184541065847, 0.15969816775571916, 0.1028345637924729, 0.1605189083925178, 0.21252028253530303, 0.14246978496591892, 0.16145656936832015, 0.17289407821672578, 0.23787206249131312, 0.23114403319214624, 0.23381835420525846, 0.18252159709170943, 0.21895615654366635, 0.17222529878058743, 0.09976628972517868, 0.11077108913131299, 0.12900329225005644, 0.1281223830676848, 0.10667140790892225, 0.14806340658856978, 0.16582615102731413, 0.19122346724954345, 0.1591758030436693, 0.17184243867954901, 0.09712447382269368, 0.14657869754779726, 0.3430676862837807, 0.1422754897465629, 0.11857293621306458, 0.16084261118404328, 0.12379263031987414, 0.13659709283421118, 0.39990604764992194, 2.976672750326895, 9.261106252670288, 24.073913674200735, 44.418477012265114, 53.734514098013605, 59.63917170801471, 46.97548189470845, 59.46215514213809, 50.37289773264239, 52.65705470115908, 34.87709191537673, 29.541219165248258, 22.263967337146884, 28.757115794766335, 35.648296571546986, 38.33689697327153, 30.67958708732359, 44.77592260606828, 36.803650317653535, 34.81990768063453, 33.14839355407223, 28.136722349351455, 22.11842583071801, 24.268722111178985, 20.24134812816497, 17.52335740673927, 17.381691202040642, 15.732508109461879, 15.45122023551695, 14.621045685583546, 14.505635826818406, 12.744910332464404, 12.507021523291066, 10.798386085417963, 15.094530678564503, 13.135752947099748, 12.464670711948026, 14.898236643883491, 15.300914029921255, 16.623824565641343, 17.19001477764499, 20.184397274448028, 33.66158862267771, 38.67466403592018, 33.77834973796722, 23.010066863029238, 32.82658465446965, 31.299101921819876, 47.57682831056657, 31.740148913475778, 36.62009123832949, 40.53075313568115, 47.195671989071755, 51.5239643281506, 48.39192821133522, 43.66700580043178, 30.894695751128662, 17.994067322823312, 9.90386603340026, 3.529064064064334, 0.5063160280546835, 0.11877699905345518, 0.2432560058490884, 0.16945950686931613, 0.26713924121952826, 0.2660714372271492, 0.15244846322363423, 0.11564017543869635, 0.14583055140270343, 0.16626110510720363, 0.15218618536187759, 0.1913089013748592, 0.09677886857741302, 0.11565394969957492, 0.13980038223728058, 0.12571829956986252, 0.10252169348419675, 0.1851389058414967, 0.18460756257897426, 0.09181683282217673, 0.20958063463049553, 0.11299727169135887, 0.19506241044690534, 0.2673661258191832, 0.20414761568029083, 0.1898144783392068, 0.12477425708165094, 0.18837660791412478, 0.12627342986243387, 0.10350911953156033, 0.14002009625396422, 0.0902740466558645, 0.18941511670427938, 0.13859498885370072, 0.15121420364706747, 0.17703087639904794, 0.19447779343012842, 0.24706810532558351, 0.12546644050387606, 0.12421635355079368, 0.16943197366931748, 0.2033848832211187, 0.09830173645769397, 0.12025640676579169, 0.2526150875154042, 0.15526006719277752, 0.08838121959519002, 0.2220471681005532, 0.26836102888468777, 0.3079163241049936, 0.19491746661163148, 0.2437243920059935, 0.1528915531572796, 0.08816348974623027], [0.037269020723479415, 0.11940300013990172, 0.07675375924595902, 0.057651180653802814, 0.05273643550613234, 0.09811799792993454, 0.07909094794623314, 0.05858249459115248, 0.056544482377508, 0.02521836957443626, 0.12200980582424711, 0.05262518038732871, 0.012970662416679966, 0.007395146803314528, 0.022412392521096815, 0.01638600016914068, 0.02242958544933748, 0.02986376778402877, 0.06869161080929541, 0.048931502782168894, 0.06098996802803971, 0.031761371402911125, 0.09735749478662208, 0.04630910337812478, 0.11758187890893991, 0.02232366421770665, 0.0316048194203646, 0.03579348941603976, 0.05223413463681937, 0.03213075027170201, 0.055309816774341374, 0.05743783665820957, 0.032551922429833687, 0.05641523568380264, 0.05362997747837536, 0.045691257297632196, 0.06765575268335881, 0.08094259012009829, 0.0695843254065802, 0.05790706168139174, 0.0503194549181048, 0.025353047831524766, 0.004106645919232359, 0.04239698729267524, 0.04193112539548067, 0.08056433420748481, 0.06820649329212404, 0.013811495624512676, 0.05910522702540602, 0.04696000232211044, 0.02056944161473263, 0.03514909455853124, 0.015294475221796142, 0.04199012565696913, 0.025026834186827464, 0.01722414057791954, 0.022475294085339676, 0.031855159717041164, 0.0029014634492341433, 0.04187709704462079, 0.048333172791547356, 0.08548630356428125, 0.060362610965967185, 0.31328761169025976, 3.1517877021143517, 11.727871125744237, 24.03500964564662, 35.75664812518705, 40.10279509329027, 42.234564058242306, 41.515840714977635, 43.0409445301179, 29.04428820456228, 28.375698635655066, 24.11151351467256, 32.534009179761334, 36.155023651738325, 23.376881037988973, 28.493057912395848, 27.569855528493083, 14.128078279956696, 23.2112628798331, 21.762684506754724, 20.17710166592752, 23.312295290731615, 20.023509494719967, 18.216740277505693, 10.315144196633371, 16.940967805923954, 22.452172463940038, 19.03117337534505, 21.400628166814005, 21.56607177949721, 19.359024686198083, 17.201152347749282, 18.839532252280943, 18.8782891919536, 29.33850715237279, 21.152561787636053, 17.483088393365186, 21.621555666769705, 28.257170492602935, 28.67974900430249, 25.5972465392082, 28.587643907916163, 35.80192404408609, 31.88926369913163, 30.57889984500024, 20.29003650911393, 30.202742584290046, 24.006799959367324, 29.297194788532874, 33.69255965755832, 41.543599328687115, 36.78966314561906, 31.54585626817519, 20.948902522363973, 13.74688861831542, 5.968985951715901, 2.1107394224213016, 0.4244377151612313, 0.12683999784771474, 0.06213260731930214, 0.01648226486248595, 0.0022609014253717878, 0.03982446404294141, 0.014131523109221411, 0.010222521171184077, 0.061395669040540536, 0.03518883153916367, 0.04551616407209828, 0.005911630944484064, 0.04428121884683928, 0.02014479716308415, 0.02652712354076005, 0.05504222609282983, 0.04399109751947465, 0.06876254289020454, 0.037524281219849666, 0.027326771861783443, 0.03609029486054375, 0.04701286621932541, 0.042784275381915995, 0.06869066852114855, 0.02578339580776951, 0.026687337423584638, 0.015041162503973372, 0.033806242018697724, 0.07197022197708007, 0.015713055129914034, 0.09504267585373695, 0.0166153573175712, 0.04379850684575016, 0.019195416957260143, 0.08453739641775047, 0.016297407846357075, 0.04936020941503587, 0.10273644325113106, 0.02341837896364591, 0.0706283959950651, 0.05566057396091281, 0.035305261581895814, 0.02938425420002351, 0.057118431619939306, 0.018586187450695905, 0.03262333714613511, 0.03508141452086068, 0.08210060096556142, 0.019258471739087856, 0.039018455276926683, 0.03846658085803351, 0.027930853257496512, 0.024861929930686474, 0.04778213723893127, 0.13058478883918256, 0.049137775786221034, 0.013380404542981377, 0.05201339406231719, 0.02052397429642658, 0.10573930107057096, 0.018365529230645588, 0.03685091674748448, 0.04578012732728835, 0.017517739944460414, 0.03024893572493907, 0.028255950329044176, 0.09005814009616453, 0.031199643178091898, 0.039874884119677934, 0.008507411187184195, 0.02763325874243052, 0.014090278850597961, 0.020303001980327313, 0.008262986046892982, 0.03090102402042718, 0.038620373008832816, 0.0650185869345742, 0.045057376996884425, 0.014720756763352022, 0.04495479399338365, 0.05149841060741775, 0.048533309431326006, 0.004476024788023243, 0.065436702401888, 0.08674546865926636, 0.03983531184794922, 0.018683170351470192, 0.03194168551764902, 0.09429253788004, 0.09672784712165595, 0.06052192661070055, 0.07619206357987658, 0.053972292376021226, 0.030985046628742453, 0.0982488917126771, 0.05785394114472213, 0.0205626713127018, 0.03714843848419767, 0.030487123951916734, 0.06345483294177441, 0.0690480485378254, 0.015325904936499655, 0.0310644650486328, 0.0323704821658471, 0.054744420903584654, 0.047512826690029715, 0.07582389704522587, 0.016969931537225362, 0.10230912706784664, 0.028230464499023174, 0.027973078108663042, 0.06455667422062929, 0.0074687745561072185, 0.06449403887194011, 0.01354848710639823, 0.05350541158188736, 0.029085541196588068, 0.11712941205910138, 0.04595279971498155, 0.6685420714559094, 4.7707714861439126, 16.032099723815918, 30.017153678401826, 43.992593903695386, 44.37251860095609, 49.36081640182003, 47.5551179916628, 51.65881149230465, 32.700515754761234, 30.65729037407906, 23.909193738814324, 25.000422616158765, 35.63038702934019, 24.741975684319776, 24.06904797400198, 33.533860560386415, 22.498009281773722, 27.674380810030048, 29.704230908424627, 26.463003850752308, 31.383711368806903, 30.167305930968258, 24.773313460811494, 20.63264769892539, 23.548490616583056, 28.303474072487127, 23.492810610801946, 30.865654522372832, 27.431489998294463, 26.57639761124888, 22.80071035508187, 20.155650223455122, 24.681222092720773, 31.514634201603553, 20.87596408782467, 26.443291979451335, 25.324647695787494, 30.040421178264005, 29.94171473287767, 26.728118811884237, 39.45778877504411, 40.76455777691257, 35.4309227389674, 26.646145197653002, 24.245362435617757, 29.570397676960116, 29.072040934716505, 30.76147048704086, 36.68928969290949, 45.448334524708415, 41.06069672492243, 37.97336386096093, 27.457573759940367, 18.429407265878496, 8.485595814643368, 3.572012056266108, 0.693702666509536, 0.24688228303867005, 0.03454028448510555, 0.041480769117873524, 0.033277062954561364, 0.040331154596060514, 0.02518680292151628, 0.020494527791837053, 0.0667296749569716, 0.02292818036831675, 0.033188227398861805, 0.08195528174720465, 0.04354069144615243, 0.06819071188088387, 0.01678490406653333, 0.08247698762363966, 0.038220865817199794, 0.03674510468338286, 0.030254696706129663, 0.022765719932654215, 0.017096169420608112, 0.01938084853933223, 0.015317909851399882, 0.03765348960915881, 0.021122382811060356, 0.11584287464258172, 0.03818748353589927, 0.08901267522765745, 0.05034526825071343, 0.028129097660102194, 0.05662884397972977, 0.07009034946320519, 0.05697670918438704, 0.011377891886138148, 0.036516197611607855, 0.08379547856748105, 0.023340881509225697, 0.12034675151470209, 0.027881164794727683, 0.014480404337988266, 0.06942442753502438, 0.07558055687695742, 0.09946833514878828, 0.05697012082823823, 0.03316257494471727, 0.03490537134630065, 0.02421602396474731, 0.06889378907339228, 0.028041156512054227, 0.02815012485840388, 0.054471938750676574, 0.022691373014822606, 0.03315723531188504, 0.02563322342241243, 0.0682075428325803, 0.037254135635110645, 0.13863548426137817, 0.17945318512858885, 0.16229206485854042, 0.24379833481244503, 0.12417984946120171, 0.221902055725936, 0.21103578799914932, 0.17003162133116878, 0.20485413260757926, 0.13841693469833943, 0.20190139992102502, 0.17820144342559, 0.2856585281270166, 0.12364418546278631, 0.1976364965160047, 0.1747418669683318, 0.10985366819847016, 0.17618473228668013, 0.1330050597748449, 0.19132961639233176, 0.17965966114594092, 0.17326397611008537, 0.10005178005104104, 0.13730221548147742, 0.18826212373472032, 0.13888593372558394, 0.18744381925752088, 0.20201260524411357, 0.1421922313109521, 0.12950506451870167, 0.2636634390200338, 0.1872416946195787, 0.1857613369582161, 0.1674041848990225, 0.1910975683600672, 0.11869239996397689, 0.18287769008067348, 0.21460330624493862, 0.252929367425461, 0.13045020251264497, 0.1659392562484549, 0.07466289845685806, 0.10487286328908899, 0.2787605805262443, 0.17501315402407802, 0.1389880838894075, 0.10577818769360743, 0.16095654378014226, 0.11770037738906762, 0.2549483308628682, 0.21829903696573552, 0.1288192319653688, 0.25377987823899717, 0.15040342215328448, 0.12175813061936248, 0.1259492061311199, 0.0695660159051899, 0.15435246750712395, 0.18878644963185634, 0.18703215425052952, 0.13892480502686194, 0.23914779806810044, 0.133218415261757, 0.8384114047211986, 5.666859505638, 17.768589873467725, 34.45563324036137, 47.898721541127856, 53.279664285721324, 57.32906826080815, 57.72565126419068, 60.195842327610144, 42.9014140559781, 43.40711347518429, 36.211203759716405, 46.36125441520445, 49.45528668742026, 34.105695063068026, 41.78693925180743, 43.027243691106, 23.91190213541831, 37.787121880439024, 34.26583759246334, 32.90419855425435, 36.72236311820246, 35.39627252086517, 30.64953780943348, 18.82064800108633, 26.901544447868105, 34.719738191173924, 30.355224724738832, 33.19731727723153, 31.362669814017515, 29.26132079093687, 25.945052908312892, 27.508917585495983, 27.742263309417236, 41.034322707883774, 29.70874555649296, 26.238204971436534, 29.809805423982684, 37.776637384968424, 41.00893712812855, 36.61878116669194, 42.23416397648473, 50.97578171760806, 44.27886809072187, 41.7660879319714, 30.71727518112429, 41.575080271690126, 35.216816240741366, 39.53043499300557, 45.96689147333945, 53.03733241173529, 48.53317668361049, 44.79904497823408, 30.442709269062167, 20.267457385216993, 9.355829531146634, 3.2491325947546192, 1.045348668290723, 0.23703837496859415, 0.14011283885807763, 0.1322191914603595, 0.11155681188909278, 0.19974625669419768, 0.09308211895967684, 0.09684351107646381, 0.1810859636433663, 0.16982526788788457, 0.1455707863093384, 0.11286272366921749, 0.1527605674439861, 0.1800719237015132, 0.19712701740284122, 0.1852618782751022, 0.11102797373408273, 0.32628778668661274, 0.11456633467347392, 0.16447374537106485, 0.12246401169367375, 0.13192130583188227, 0.0921388348985103, 0.12024517591682174, 0.09899444081970761, 0.1464763022358379, 0.13810339023268994, 0.13981847723405208, 0.20016717604331433, 0.09704806421312595, 0.30531076714396477, 0.1248271554528225, 0.10360835090039239, 0.10190679301177302, 0.14544694053549923, 0.20639350968262843, 0.14099903404712677, 0.22851311872082375, 0.15768312668848425, 0.13653418169386927, 0.11797374054308861, 0.24142448880499412, 0.19643905512507887, 0.15576703353754937, 0.11003486331432097, 0.13762650049982533, 0.13096544260699905, 0.2115465541400256, 0.171389956507952, 0.1464093308294973, 0.12573111622083571, 0.08013285816677156, 0.18799451390101066, 0.1592028306256379, 0.25092892799406286, 0.11758478238217293], [0.07392309500925964, 0.0039743389436719765, 0.07476492604661374, 0.0922412608539866, 0.09067093382679647, 0.03022286575287581, 0.07458504094111343, 0.059343392269745956, 0.02489786711521447, 0.05586142689290066, 0.08974717734681983, 0.02371659017949095, 0.03162144735876111, 0.046637866180390126, 0.06550548177572989, 0.036129055079072714, 0.03280319543855806, 0.05633933169226493, 0.039486546489980914, 0.0051192958903078355, 0.03869196392535683, 0.07831803417854732, 0.08622359424348801, 0.04770908692491151, 0.04110676882367942, 0.08458595107039137, 0.0554777164342663, 0.04908558987681905, 0.005060104106838305, 0.027775938787888137, 0.004712743562601146, 0.050802140106116576, 0.08765306834491991, 0.03919043818548803, 0.04884238377393735, 0.04640332070149241, 0.019951070764011914, 0.022924890020681966, 0.062149354001326915, 0.010017656811302709, 0.05882224180705606, 0.05489595309500733, 0.05572446952423742, 0.0644552518403338, 0.025331160699528073, 0.004477336713593573, 0.08466770797367058, 0.05397676632949903, 0.04407371627166868, 0.027988554999953317, 0.04409838430283051, 0.0430521801594765, 0.015507057917514637, 0.03672306816424093, 0.015920822963028426, 0.07107088071925026, 0.09466292606967111, 0.021180588256327376, 0.04344510282540033, 0.028322236086692543, 0.00696507222469776, 0.025140822324300968, 0.026157468880316424, 0.020437295278233868, 0.147299770145647, 1.8084107291313911, 7.684570848941804, 14.95667015352557, 28.50773346039557, 34.57535574513097, 44.29121178965415, 44.52891526683685, 43.15321845393027, 41.48421856664842, 38.704878053357525, 44.47643787630143, 31.66617693439607, 37.58551205358198, 34.19397192616617, 28.775545051020963, 28.1019466154037, 21.301333365901826, 26.58212034933029, 23.65167444752109, 14.342302449287908, 24.49441529089405, 30.10970984735797, 29.349946744980354, 25.272191878288027, 19.483022574455507, 23.346680748847223, 22.23964471970835, 27.999137370817124, 20.329628913633286, 16.868480443954468, 33.47075746905419, 24.94352863680932, 51.17706991011097, 51.71306179415796, 23.81587859122984, 31.210770145539318, 27.826994349879605, 26.473684464731527, 29.532413444211407, 22.510509875512895, 36.16463738103067, 38.18660743774907, 31.27688365597879, 21.388849289186542, 33.12555359255883, 35.923941135406494, 37.79480972597676, 38.728247534844186, 32.53512901644553, 24.68428742501044, 14.12194859596991, 6.0294826280686165, 3.1770051102484427, 0.6426804753080492, 0.10028222695954385, 0.03475494615192856, 0.06650196298235847, 0.0035760766449159072, 0.12654208157572056, 0.052340685975767916, 0.024255299377405358, 0.12309630236197865, 0.03145047760147962, 0.020376330001219627, 0.05511887702009371, 0.07072834748654597, 0.0416837019785758, 0.09437416454837208, 0.03535972277243291, 0.02373420637130978, 0.0708224920315608, 0.04503937776110346, 0.01821967183552202, 0.010747265543848758, 0.015019255262168666, 0.018806780553272655, 0.06316681452576192, 0.048992016067307805, 0.07858325381793323, 0.016146356375106884, 0.04437556640515405, 0.04196074235463335, 0.07036275500732084, 0.07384844740191776, 0.07280793912228077, 0.05663902911868307, 0.03124171864211319, 0.029491608016072746, 0.024316825813824133, 0.012093192969088354, 0.07955181878060102, 0.07306878439961903, 0.04083329841734902, 0.01146045222412795, 0.030560658816548607, 0.054735522792344136, 0.038721121231754946, 0.04048962754407718, 0.01439182446413343, 0.06612323209523194, 0.00908681306041657, 0.030750566267318306, 0.008897332703664659, 0.06112616696965791, 0.0497014441287085, 0.008248090424815254, 0.04543809588217447, 0.0413933355030754, 0.025425163518276908, 0.06451855368551708, 0.031308312750151085, 0.02775830152865139, 0.031032764330326073, 0.04088481783025688, 0.07065893992060615, 0.03939638943261197, 0.04852367204523856, 0.07114820197344789, 0.039350301583087256, 0.020235660936563246, 0.02872431541853134, 0.09741921082980211, 0.014648026291040644, 0.08545385207980873, 0.03745624495129432, 0.0602959651469944, 0.019217147041232358, 0.036238586500046716, 0.05086295599598558, 0.00985213585438267, 0.0588821345609763, 0.07600680819802708, 0.013383627857922787, 0.043061702632375305, 0.010531320679752577, 0.011442827413819972, 0.021188207000734347, 0.03769041121666951, 0.05272700113334483, 0.0671655789858872, 0.05592362174103337, 0.039415997453033924, 0.05835202470001194, 0.038925425389841686, 0.07333474714429149, 0.06766037985442147, 0.1261899645830835, 0.02769812723741897, 0.07351087841896281, 0.04112589037826946, 0.04765071485552096, 0.05984776540689411, 0.06353801093815316, 0.025273232961133606, 0.04711523088776777, 0.03503412391329485, 0.020156841980473652, 0.05347921137487697, 0.011766321446386077, 0.05239971688077335, 0.016089131522382942, 0.05018586067542915, 0.0309422452964129, 0.05310672793477293, 0.008824586909594796, 0.01725581639836873, 0.06695899571622572, 0.05984895284317675, 0.06369457632723836, 0.020248816581442952, 0.036202419489141435, 0.04012885758833539, 0.028813620203084526, 0.07923223754210819, 0.12329504855217473, 0.2988507766877451, 2.732933726041548, 9.587346449975046, 19.873572972513017, 34.98865196781774, 42.88761515771189, 49.13908873834918, 51.215556206241736, 46.83302141004994, 47.30140732180688, 40.87701212975287, 48.146725162383056, 36.83970082190729, 36.39016974356867, 33.287049339663604, 31.509994037689705, 21.17182062518212, 20.588366100865027, 21.73238615835867, 23.76095952526216, 21.95036795831496, 28.786349219660607, 35.148057091620664, 24.31532575238136, 27.92373961017978, 28.972579433072, 29.569324908717988, 24.170656973315825, 32.2620379155682, 27.26233582342825, 25.354294930734945, 37.933383141794515, 32.28891791835908, 62.51090757308468, 49.23195869691911, 23.49533465600783, 29.37314364217943, 35.99862698585757, 35.88502730092695, 28.581577962444676, 27.943753503984023, 46.150905547603486, 43.458982898342995, 32.63775390963401, 22.40925192832947, 37.89306509879328, 38.032438678126184, 40.909042204580004, 43.32750112779679, 38.481581441817745, 30.38406787380096, 17.660499157444125, 7.516981209478072, 4.343680777857381, 0.8945704299596049, 0.1437030792717011, 0.010122212491208508, 0.032850857598767165, 0.04339300501610964, 0.07896500309148143, 0.05422949107483991, 0.018125377903361956, 0.06240918804260512, 0.032866087426701864, 0.06554680455836558, 0.02398257399158132, 0.045308343570439086, 0.025127040402543162, 0.057174880808639916, 0.06753977463250199, 0.024149644361328215, 0.006520062283192191, 0.09476404201479689, 0.021304801752370213, 0.022155415987776175, 0.005398489931042517, 0.038275334668616136, 0.0826899217621934, 0.028283964249215303, 0.0343691787472175, 0.04287715971229538, 0.0038514572436050064, 0.05740001489738784, 0.05521977079972144, 0.04061858695481093, 0.0489168283679793, 0.053954702997279745, 0.025841116702424425, 0.057738384442223664, 0.08238907137344922, 0.05342018813075078, 0.05294710585486986, 0.07689064383626946, 0.09340064299683418, 0.007254399693450861, 0.08388871146786599, 0.06306030915208882, 0.043619560197957104, 0.04208372627955772, 0.04363698486779486, 0.04497921304597009, 0.029010003012034203, 0.07110557684134092, 0.014110907683179024, 0.024299878033719236, 0.06445816297444605, 0.09006867380512339, 0.04979424035897659, 0.019360675529066115, 0.0394998227937087, 0.04774203636653481, 0.028194743734333786, 0.14193453465498265, 0.08434385196456025, 0.15032980110376112, 0.2077834230036505, 0.21267595160151684, 0.19336108238466326, 0.17749089687581987, 0.120906884361419, 0.10953059359904259, 0.1187885286767156, 0.2144928057227404, 0.1250016549602151, 0.15422515901586703, 0.10884179628544277, 0.1387673892801808, 0.08475931676765604, 0.19245213438426295, 0.1565227333095766, 0.09439142450930611, 0.12923837399050114, 0.11740053823638348, 0.10812425535292396, 0.19528521945880306, 0.12051275510701442, 0.12892138212919235, 0.14418254305999126, 0.2582932852448956, 0.1252049670344399, 0.18592463626015573, 0.1611897869095687, 0.1174765341584721, 0.11787191213619326, 0.18102361940808837, 0.15679028185625232, 0.19901058246051112, 0.23339414067806738, 0.2268415608353192, 0.13111663771973503, 0.13557454931639856, 0.15568973526598948, 0.1939815523162965, 0.21697909811571722, 0.14573981594895163, 0.1539844695118166, 0.13543412539987795, 0.09358317110567324, 0.23419782819767154, 0.17236995150245008, 0.09077103087498296, 0.13761842593310342, 0.18694311951196965, 0.14168380939912412, 0.11799023441609838, 0.21351152370052956, 0.16364125294550774, 0.235484043857263, 0.12044481842988923, 0.09527598793107657, 0.15900176318903125, 0.1808836704660808, 0.133928042506018, 0.1476428243181398, 0.12862178046376477, 0.1885797284663685, 0.36298106935235763, 2.8157038265658967, 11.260755081330577, 22.273700698729485, 38.43738809708626, 47.204748353650494, 57.01559243663665, 61.44663126237931, 58.621755953758, 57.00122871706563, 51.30297407027214, 57.8113393629751, 44.4434585878926, 50.30148706128521, 45.83487233807964, 42.78945784414969, 38.57428273847027, 33.64996271748697, 35.91602971476894, 37.664587036255874, 24.895350163982762, 37.880254637810495, 42.79694564880864, 40.70217247932188, 36.43865808363884, 32.138569547284035, 36.403748989105225, 31.797240972518924, 40.47427884994015, 33.654218489123934, 29.306110335934548, 46.348671451691665, 34.448804393891365, 64.49853335657428, 62.60378537639495, 32.81875952597588, 42.302487742516306, 39.09038428337344, 40.70323544163858, 40.20327444999449, 31.954765319824222, 50.8331133473304, 50.0920795625256, 42.42044910307854, 29.372737676866596, 45.36980475148847, 47.18134749320246, 50.323617073797415, 49.73749729894823, 44.38762757085985, 33.8276578534034, 20.702793405902003, 8.364571082976557, 4.41946538225297, 1.0679447074090282, 0.2610459310873862, 0.18632059646469934, 0.17021211164612926, 0.09733998967755227, 0.261429495989315, 0.14346588312858535, 0.09987053130903553, 0.1447983398552864, 0.14824625645433703, 0.11613100797178284, 0.1566405882758479, 0.19104084721015346, 0.12437379994099179, 0.1892126090223751, 0.1706593231328072, 0.07179407538065026, 0.16619581909429643, 0.17013332716399626, 0.17068720873325102, 0.16009307075892726, 0.0718428521987892, 0.09646728529684967, 0.3268056621234263, 0.16857925652255937, 0.11573902376356626, 0.17244458378803346, 0.08855449336190378, 0.12224695600208738, 0.16566249932492935, 0.0890735332523623, 0.19323005070609434, 0.19054207800617143, 0.16503176381511075, 0.14258045402746047, 0.15199861639449674, 0.19036273682309737, 0.2416307196742104, 0.13220187787327076, 0.1636797258810651, 0.20165945403277877, 0.1586869929827029, 0.13335220485685334, 0.1375254994678882, 0.11955812528368928, 0.16124713625158035, 0.2943186618147358, 0.1302370155650762, 0.15781823395481034, 0.1074375264767197, 0.18273600977995705, 0.11468386022193779, 0.17601872103348856, 0.12696814903568837, 0.149161440410441, 0.1446623439269681, 0.1564882440312255, 0.22090880741034785], [0.013798338064413159, 0.0969413175217567, 0.020242843010853377, 0.02024691859861055, 0.008695313402812087, 0.025357368567417708, 0.06604607938037765, 0.0381570813366242, 0.07124333477188503, 0.028173396694323713, 0.0436006071827104, 0.026753542742000955, 0.014410279522229348, 0.013943860296069855, 0.08206536858192376, 0.0383454853398425, 0.024921853328123692, 0.029722250276996248, 0.03837163575113781, 0.03791325470252383, 0.12511666774028732, 0.007155685912772653, 0.029915178029407418, 0.10427686220575726, 0.0997733453949613, 0.0174825516108784, 0.06452200108117635, 0.026824744868903395, 0.03942803269432437, 0.03643426067766644, 0.04909686669106445, 0.009597690284041869, 0.026013905918526075, 0.02374587772083619, 0.0775918670960011, 0.029496826990056905, 0.0254761332630991, 0.07711955090804447, 0.02230344715738489, 0.03912491468532432, 0.036195467241228595, 0.051541112348317146, 0.05612922441815177, 0.03557098300887212, 0.037461324114232294, 0.013960457590949393, 0.04175659141413147, 0.04855828006721793, 0.027821902148125154, 0.04835943045515207, 0.029002185084766922, 0.037203811319364656, 0.017324306574019215, 0.05300187348057667, 0.06430109962821007, 0.04945587464458039, 0.02898861383718829, 0.022058230073701952, 0.05545044753460154, 0.09401021149730492, 0.02777843048886186, 0.01805480971421686, 0.02890685501868927, 0.05918699925044372, 0.045079876999220544, 0.01911122964004115, 0.4750377306294057, 2.6662090612996012, 9.080639962227114, 15.98987638950348, 26.995224375878614, 36.78356778237128, 40.81556427863337, 40.66571797094038, 49.25071547108312, 50.977927254092315, 46.30793371508199, 47.90364803806428, 45.11026936192667, 38.70023788944368, 42.363339393369614, 44.30699148485738, 43.39631126772973, 35.417421940834295, 29.709983064282326, 29.944179942530972, 18.000298007842034, 42.17235918967955, 28.01396000769831, 17.619224056120842, 25.744817872201246, 31.19521990899117, 33.63477137780959, 20.0767497862539, 18.308106007114535, 21.14624677165862, 26.852485402937862, 40.37207365036011, 75.94584911100327, 49.526022711107814, 48.61786850037114, 18.56437013995263, 20.389354844247144, 24.85748556352431, 29.394569589245705, 35.50097627024497, 45.255593176810976, 36.84412917783184, 36.25173753307712, 40.0652580107412, 40.212797964772875, 36.32568990030597, 26.054743951366795, 16.5178225117345, 8.639017362748424, 2.6155742041526304, 0.594602574504191, 0.041263790035079566, 0.15290882077909287, 0.06127628189842067, 0.049820260535324776, 0.09588250740160865, 0.05238492755339511, 0.007752109780877589, 0.040559165344964114, 0.030616290206390045, 0.012084729612744864, 0.05396365090423534, 0.054053719861493, 0.02921938633305892, 0.047134413729391755, 0.11165461833438567, 0.028682209310993075, 0.023257345366742344, 0.01615102951144499, 0.049130406020389455, 0.03991898014059952, 0.0662848000384627, 0.041321422829623186, 0.05816593428232497, 0.10394946687043675, 0.023478212345752026, 0.026314788866007043, 0.012280613506933855, 0.028535898008774367, 0.020373428443206415, 0.03882717078311309, 0.02587131397317975, 0.03782225494843818, 0.01531999456816383, 0.008985388764901268, 0.03551149245111212, 0.026968068428217407, 0.04592943786373062, 0.12419492607155155, 0.01408005732246825, 0.019898465421471386, 0.07622194100892352, 0.02838565476028429, 0.05096548154289204, 0.022872248288965034, 0.0739993130968463, 0.021439646633582252, 0.013109766746751003, 0.0007604369485277623, 0.0308309959232687, 0.0523616767848932, 0.06246899269641407, 0.02037543942400765, 0.07765340693895856, 0.05455778656347145, 0.06414404011241372, 0.012103154984933716, 0.018649525685055603, 0.059268882558230436, 0.04800798378944878, 0.03756911268517856, 0.05914693285200385, 0.0314833868234869, 0.038421293570389675, 0.08230006727840632, 0.05083310921045561, 0.0482537524564372, 0.029554861980760773, 0.06511949603596041, 0.024361103780627735, 0.06110069454617559, 0.07798978082475164, 0.09314762713808207, 0.006280750779795551, 0.05099239038123239, 0.03902785900619723, 0.006082063482608647, 0.04969771328051725, 0.0776233456488098, 0.0517793350492514, 0.07486236476970297, 0.08268784566391861, 0.061082174370606104, 0.03700657049193978, 0.026262026475442034, 0.020393392694513165, 0.030042919360341567, 0.05978864640177739, 0.08080409674514687, 0.03168856623702713, 0.08032361405991739, 0.07625093743685754, 0.04406935723137952, 0.03774315637025622, 0.045431430917233236, 0.0070153510539732395, 0.02072712549218728, 0.04569283926919584, 0.043795262463390834, 0.040962261658522396, 0.026932801570623156, 0.04133446547653406, 0.03190203663712788, 0.03594678744012791, 0.04461138742044569, 0.03354920419834314, 0.018222533173919208, 0.032686627499999545, 0.04787952233586581, 0.04390656354746992, 0.04839128439104365, 0.05716506339189026, 0.06819192229980423, 0.04076419728657892, 0.11827075283133215, 0.03615950324362324, 0.012839191195164478, 0.029628483030284126, 0.04109215952696339, 0.027489921776577834, 0.0475987128072208, 0.041235509899354754, 0.008966919342656771, 0.03260578607178984, 0.04239355521877447, 0.036853383550600666, 1.1003735156789904, 4.555017102149225, 12.302692513312063, 19.836851742959794, 33.817432234364176, 43.288383330068285, 48.267173305634536, 47.247713996518044, 56.60983108705091, 57.389853231368534, 48.70738091007356, 51.2041421090403, 47.5565771133669, 42.9153698490512, 38.77552386253111, 41.44254338356757, 42.92926288420155, 34.35998624370944, 21.601879096800282, 32.928309363703576, 24.328130329808882, 30.66294643186754, 27.916328291739188, 19.323266398522165, 28.53608435200107, 30.505559367518273, 33.598469841864805, 25.2695599679024, 17.88901840486834, 23.915310675098052, 25.89801976757665, 49.51518127995153, 78.90621093011673, 38.61571473460044, 48.01322729356828, 24.0809464839197, 21.32622668820043, 24.38060379797413, 25.386834913684478, 42.341385887515166, 49.90166810251052, 40.757909359470496, 34.68557042460288, 42.93433843120452, 46.4483977133228, 42.48830610705961, 32.02654273279252, 20.833359303012973, 11.290436637017036, 4.247852861881256, 1.0740357805644314, 0.18267809353288145, 0.11165167655675642, 0.020347724278126995, 0.06227442168540532, 0.02484561800355873, 0.05323733443454389, 0.028556387030309247, 0.013730997978259, 0.07168232613513548, 0.05217384734761812, 0.05958616553295044, 0.03821486734875268, 0.08835472061388916, 0.06980093676717052, 0.03488444182420931, 0.027269405282793507, 0.032552037343022325, 0.07653294972354367, 0.02271007130583448, 0.0390763562022438, 0.07476553891695316, 0.03709360191057767, 0.04966991194974511, 0.04542279327588697, 0.04355833828148823, 0.04764052971656765, 0.03788614285088355, 0.02469243872309885, 0.05579962274960934, 0.07062891693485361, 0.018754899163820574, 0.012679651469713258, 0.035099747004888715, 0.043149978943890145, 0.019694013791459224, 0.0844774270550378, 0.023218474065464352, 0.09468013240445046, 0.09037887812742303, 0.07514821515688974, 0.101580485521305, 0.020420705644233574, 0.026427078203508453, 0.06814375069112548, 0.029355656137810122, 0.031128184411734827, 0.04645040829575831, 0.041037292309826424, 0.030247648697226282, 0.039457377692263935, 0.022919830009942094, 0.016820749320510416, 0.017161491822691697, 0.07636370557931162, 0.07274012501922346, 0.013381895541604008, 0.061266158046501304, 0.007890812393593332, 0.04591405864865069, 0.1448215676411506, 0.1557205626440625, 0.07913222476359337, 0.13319872680210298, 0.08551127803061279, 0.17194549282712324, 0.1484365526947283, 0.19799813598154054, 0.13905044344644393, 0.24087976964731372, 0.1580581573709365, 0.22167831208677063, 0.10480919372170203, 0.07813706888907379, 0.10534756967136938, 0.1649246034362624, 0.10819073646299301, 0.13593232769879604, 0.17556179555193072, 0.24114889633511347, 0.22483186706179575, 0.1566540254580398, 0.14796530136898642, 0.21462987417415266, 0.20616193662487692, 0.1354863419527969, 0.15198254386984533, 0.1453612459402892, 0.12895677539129413, 0.2134072438122765, 0.1606786377247303, 0.12931628513240045, 0.09108988432994775, 0.07929322580176015, 0.14016176123292218, 0.14396111300635722, 0.12477784237313656, 0.3100469984835194, 0.1002612591330563, 0.08198391045293502, 0.14833256391988647, 0.24544735439121726, 0.2035748117393063, 0.08526377034403625, 0.14938887659340136, 0.10791731202193808, 0.09983179024270467, 0.2717556564077255, 0.059889946208004995, 0.3350157038338723, 0.16221715678130427, 0.14428614879087096, 0.16363705478368268, 0.12829872884697494, 0.1822669494656786, 0.13319901791551422, 0.11833894231747236, 0.20744199293755716, 0.13469292001137811, 0.16412246341426528, 0.16315572174085727, 0.19272948885636945, 0.182729130310397, 0.18779669467720295, 0.2429183142920656, 0.059705824636283426, 1.04419965897837, 4.625724198356751, 13.624129218439903, 22.63910674279736, 36.39617881467266, 48.954376482194476, 55.9760231356467, 55.266505595176454, 64.2005273603624, 66.3129315837737, 60.7384826290992, 61.73578839148245, 59.71639533196727, 55.13607501983643, 55.181731408642186, 58.63685315655124, 57.27410408758349, 48.201214728816865, 40.33102212413665, 43.34439085375878, 33.34153890609741, 56.76496867210635, 39.382475345365464, 32.07827291181011, 39.96046796921761, 45.11611369348342, 44.304445866615545, 33.35389437214021, 27.418752101159868, 33.98587057667394, 39.2043605158406, 50.326292130254934, 86.33490547057121, 61.31711852165961, 58.90568064105127, 29.061852578193914, 30.701234648304602, 37.289286813428326, 40.20423150831654, 48.335406857152144, 57.395289636427364, 50.624113775068714, 46.827855648532996, 52.747567315255445, 52.68752367265763, 49.81864721544328, 35.542557316441695, 22.15615118703535, 11.47545385745264, 4.34452751951833, 0.8258503819665601, 0.24102414657752363, 0.2932981407690433, 0.1339177003190402, 0.13597912034921109, 0.17486445635797518, 0.24918413210299709, 0.09310232835911936, 0.14229536206731874, 0.18005963565120775, 0.17931228623755519, 0.15661529205258817, 0.14543287516120942, 0.12778005667872008, 0.367425911489033, 0.20491476080590681, 0.11310702144739129, 0.19521196613148337, 0.16832663136864864, 0.1337536349291763, 0.12063664684612906, 0.1850402950038833, 0.140859330253255, 0.1307446560672214, 0.23348239400694448, 0.0976776812345751, 0.10906658180418516, 0.13108997785997006, 0.1478535138190754, 0.12448898126040736, 0.12387510734580218, 0.14001335468023055, 0.11542668205595787, 0.07831670118555908, 0.06647060700361768, 0.17045309226359093, 0.19604317152932768, 0.15877581321664397, 0.29190631222821056, 0.12482528619828726, 0.17473120302442582, 0.19874320245317875, 0.1551527689181028, 0.2464172523468733, 0.27187884334594975, 0.14793205315307265, 0.11679583439423193, 0.1926436410435746, 0.11351549952861764, 0.09666996917897656, 0.11330232024192811, 0.1478939632614774, 0.19636434623070304, 0.17685541162087073, 0.10061622597277166, 0.13907534130398305, 0.06714802791154192, 0.110854922132867, 0.16065364793664025, 0.19429682814065488], [0.0687194198009468, 0.08183317499295359, 0.02065376299733837, 0.12373412418509684, 0.11471606655827454, 0.061350140435200554, 0.025695703638296936, 0.011390495947712373, 0.02381553043491177, 0.04387641032677024, 0.10895527688966644, 0.014135373658650826, 0.05030347815444393, 0.06026495773825915, 0.054711843014604626, 0.023063304871621153, 0.04502242040489951, 0.0445114704029214, 0.061151689188855315, 0.03820497715365022, 0.06767053051941818, 0.04833625246500296, 0.08426112979049645, 0.10754276397487811, 0.08587850227711663, 0.031151825885078123, 0.03784340280558794, 0.11504948334467989, 0.03159359623227389, 0.03172111348249018, 0.00994343342514889, 0.04828445343000274, 0.015395549032086087, 0.00808053550445625, 0.008528402953919385, 0.033947251992480415, 0.07363391980048149, 0.008775941284012892, 0.03080697906684251, 0.016809300136482044, 0.04327962783375575, 0.022295343862365813, 0.005427889512746685, 0.02584206473623072, 0.02055425583685358, 0.019995919466319106, 0.04081955863042705, 0.02523061548990588, 0.05114339780242694, 0.09265108724995967, 0.00637896899734774, 0.04761630218596228, 0.01053467518725102, 0.009172315176035608, 0.013983479490683926, 0.007817222466391903, 0.012295319522250325, 0.06720566070608555, 0.04317088931378338, 0.014756336759385324, 0.03411891697455318, 0.00407944213704116, 0.030704514806969996, 0.049491386650310415, 0.06201675950339245, 0.02244394959791774, 0.08313265929539358, 0.05988599319431571, 0.4845978950540866, 3.5122846547634374, 6.619123710739998, 16.3229013066138, 23.462449504483132, 30.942917370027114, 35.851518492544855, 44.8310632859507, 49.76172185713246, 56.39270044142201, 52.95369179018083, 50.083509183699086, 54.83959874799175, 49.735536113862075, 43.623302751971835, 44.93453541109639, 43.282162450974994, 31.527015163052468, 25.943935032813783, 30.310694056172526, 35.23081125751619, 34.44267765168221, 30.650243836064494, 24.035503864288334, 26.983941678077947, 26.044412428332915, 43.42545840048021, 30.703054628064557, 37.434269382107644, 30.4580633871017, 75.45643145038237, 66.6236460593439, 37.54082056783861, 26.529974399074433, 36.92785216915992, 33.57373145318801, 41.06893370228429, 40.200297371033706, 45.72636781200286, 46.595365001309304, 39.55685215611612, 31.7615258309149, 22.57952201750971, 14.459558763811666, 6.680567149193057, 1.3254773592756641, 0.6973230141785838, 0.03439800663580818, 0.04703047091982538, 0.0122159585589543, 0.040006930864746534, 0.015410358469272334, 0.04122246342200426, 0.05816817508950349, 0.050402832097343864, 0.02918666288737328, 0.03753895946447888, 0.017754177660531095, 0.020525985277227817, 0.013433724262511298, 0.032825231957699985, 0.010481451228711634, 0.07660406566555462, 0.08424119618270667, 0.006069490543356346, 0.05555481935340551, 0.07271631500653683, 0.048667026248069546, 0.022316736867651347, 0.07302884057524704, 0.07881076660968604, 0.02992725157509408, 0.032124960562214255, 0.04720675541208156, 0.051453169285049366, 0.07900301637428422, 0.021247638186680216, 0.010359116563303097, 0.026124661164959113, 0.016001530325851374, 0.06090650657912897, 0.0034409052187261446, 0.030105870720299504, 0.03868483164678178, 0.0726176428818895, 0.0465090906307582, 0.057408897686869874, 0.07250637627176701, 0.03859160640727609, 0.03428660212985931, 0.055332060137222853, 0.04188111517578364, 0.02735093810535487, 0.03536402818656737, 0.04534600828323634, 0.06068307703601257, 0.044871252105240865, 0.0378112156214493, 0.040873717216234055, 0.05023621946513172, 0.013401355132490638, 0.0560446483113112, 0.03613419935948426, 0.12126781136518526, 0.020551764135879856, 0.0197489901761254, 0.07905778399999104, 0.043240913580502235, 0.03480713589177017, 0.028711665391681657, 0.03418429108757166, 0.06914903424800405, 0.12077422857645059, 0.031450276503399495, 0.0069528215211786095, 0.0512137821304702, 0.016224589273934404, 0.03103368746627483, 0.051953367243010196, 0.039276841412028, 0.0422248779796064, 0.031179196291392854, 0.07339839372904071, 0.037526322844167875, 0.11064621679965528, 0.04953731745181065, 0.0857729200393923, 0.02583078217632588, 0.020802351495912, 0.05785000728323095, 0.05826579001281531, 0.10537992156441174, 0.02938195593625067, 0.061815661423268824, 0.08792289217273075, 0.07961070029846123, 0.033005216654630444, 0.04547805885874456, 0.013543310267249904, 0.009270173332263387, 0.08538629078576643, 0.0395267048189717, 0.039142415963954506, 0.01726896055192957, 0.023809258090031725, 0.026506479386420503, 0.02451675177942361, 0.02732785779141611, 0.029760271220678286, 0.04192772779553648, 0.014155655836446152, 0.04696443797119203, 0.03700707227953019, 0.028021385697948358, 0.0194611843495119, 0.014046045891459913, 0.02333081511390065, 0.09090156459640111, 0.008960568473764486, 0.029016323237409516, 0.021691817880397844, 0.03156027715322712, 0.01874519857547937, 0.06895043361451357, 0.03593095623317265, 0.03896621191093037, 0.051691346020708163, 0.02236110484978605, 0.022155172754860213, 0.05848605178236481, 0.029723506661192067, 0.026251490851263368, 0.0372756588753433, 0.06804604383726275, 0.012298188521526756, 0.14138555604844324, 1.1530687203330379, 4.859457256332521, 10.071027644218939, 21.69624543959095, 30.919085048860122, 37.300445956568566, 44.244849374217374, 52.592567013156035, 55.8459298841415, 62.18924968473373, 61.15575221277053, 54.564719046315844, 60.15634013760475, 54.77199277570171, 49.111035946876775, 44.38650577299057, 43.020732556619954, 34.06687144310244, 29.27891654352988, 33.79418042398269, 40.55992380265267, 35.10511498297415, 34.44425836686165, 29.1232317878354, 31.637726022351174, 28.372007685322917, 34.88133984227335, 28.84451012457571, 36.75129059822329, 30.4177257322496, 82.59128555174797, 65.24535263738325, 45.33269520728819, 26.32224371356349, 34.774914172387895, 32.699582230660226, 39.56903896024151, 43.64026308059693, 51.26507612966722, 52.440120174038796, 45.30845103725311, 38.15440085626418, 27.77735479416386, 18.322812934075635, 10.270339942747547, 2.7317364225464487, 1.4687062607657526, 0.11395053021729955, 0.024337148211235483, 0.03868482781634216, 0.05181901840372913, 0.054908501615207043, 0.11262673028414288, 0.09048782349113496, 0.009472429162762579, 0.04645788914433891, 0.03010602393788436, 0.028458325860781536, 0.024502460409196156, 0.057311321067954266, 0.05122521216230047, 0.0032135621633290526, 0.052657846376420035, 0.05903881103281052, 0.03197093475459805, 0.09233706014891786, 0.1160418353373966, 0.05383955998226039, 0.004086598834668797, 0.028478541005883488, 0.028201946876041835, 0.04763636602869919, 0.07019634538840863, 0.008680397670926347, 0.03223753526746746, 0.10220035024347807, 0.041380212416932474, 0.05916234271060075, 0.015401097423877689, 0.037067459160161596, 0.05302219013232858, 0.02789315215552286, 0.03391093176399027, 0.063096993272343, 0.04296635915975898, 0.04455356693436061, 0.014170351318053663, 0.03438973671666557, 0.04299942351457092, 0.03652396957359968, 0.0353780284433836, 0.03450712436930307, 0.03081894727543958, 0.017354159105208614, 0.04108466335662431, 0.04172165397434466, 0.03432945708834356, 0.029134323760386438, 0.053980512499448755, 0.036121302269278996, 0.014759268960915508, 0.05328663985335058, 0.04008274292573333, 0.04279434560768066, 0.018097346746212533, 0.0398449185905197, 0.01863744830892932, 0.0408423688983725, 0.0958451452935415, 0.18675458527380423, 0.1747946810698317, 0.2681621831030615, 0.2148778108699668, 0.21453463412340612, 0.21794560996274795, 0.1694615293414362, 0.10482181118981493, 0.10020508956644805, 0.13304802198563853, 0.14803103171288967, 0.13285525894213107, 0.12561267902774195, 0.28742601554239955, 0.11490277750718017, 0.23219944188191047, 0.16514983328600086, 0.21174120175982677, 0.17177422621077107, 0.18817390104936016, 0.1465374360521955, 0.1687777805472574, 0.24962029660180693, 0.16871067124509043, 0.10280225786470598, 0.20628530742420306, 0.2016147911067932, 0.12992889500193058, 0.13179028947507182, 0.1177895730060916, 0.1571215382747112, 0.15215203316221315, 0.18572408976333757, 0.1193851885956622, 0.10208994931271, 0.12406686681412882, 0.13773367620043217, 0.1289391247255187, 0.2006789227767337, 0.1574807875459233, 0.14670200706008943, 0.11833046172415057, 0.16829382748373095, 0.14438855942458878, 0.22677440556787679, 0.10160370564628994, 0.10164423169748438, 0.15417073612972615, 0.21211497605808322, 0.09217284154146911, 0.1395676140823672, 0.14725406534008442, 0.16157358163787475, 0.12949124429254763, 0.1062979017414393, 0.09524085513886907, 0.1796656213099918, 0.14653993349882866, 0.1296868571831334, 0.1610488420532596, 0.14503509166740602, 0.14961288070246098, 0.11310011133431427, 0.137047108202692, 0.09057711103870984, 0.1668141286579832, 0.20045182367245998, 1.003531912161458, 5.319412033404074, 10.487265644534942, 22.009380017557454, 31.262163000722087, 42.267311926810976, 48.63328733751851, 58.57896289517803, 64.88802079231509, 71.25041115668513, 71.54584407806396, 66.14059832788283, 70.05015803921607, 64.95763894050353, 56.95741584224086, 56.740657821778335, 57.184972147787775, 43.32424556055377, 41.785809609197806, 43.98850287160566, 49.793230256726666, 47.51209743561284, 44.834962121901974, 36.59760036776143, 40.77282613323581, 39.45181892764184, 56.82838163068218, 42.05395852365802, 50.49004716257895, 40.13592735413582, 84.94699831931823, 76.62026928317162, 48.3749992616715, 36.660526952435895, 48.24948341615739, 43.161569180027136, 51.164498713708696, 52.93797485290035, 60.70673104255431, 60.50330123593731, 53.10422451265397, 42.80301747783538, 31.743180905618978, 19.780159765674224, 11.66820893364568, 2.7734814728460004, 1.3558785473146748, 0.17684994175309138, 0.11509738682258515, 0.11965153438429679, 0.2045074931436008, 0.12683540132016907, 0.27602950771970136, 0.12712542688654316, 0.10234102696901369, 0.1904385029188087, 0.15911207985012762, 0.13712308880302215, 0.17676296013016857, 0.10163719901033949, 0.16755605416913188, 0.1685616518220594, 0.14043569895288638, 0.3149681634479954, 0.11792821959862787, 0.19226096480363802, 0.26132797401758934, 0.16826802564244117, 0.09395861547560462, 0.18650934520748355, 0.13424348686971974, 0.05408813253105168, 0.14814577636218842, 0.14194421800634555, 0.0869567174043867, 0.17058672864110241, 0.13064390018342004, 0.13738130639878013, 0.11467503488905008, 0.09440810990429695, 0.15687530229408897, 0.12485818201375586, 0.10709890029242924, 0.2643471265271787, 0.14801592445902287, 0.2769946865737438, 0.153785991452394, 0.2396618890305681, 0.14118597482240972, 0.21205865327389012, 0.16971456818282607, 0.14116253253192673, 0.15500086900447646, 0.12192272460989415, 0.17154159595168408, 0.1336811476897809, 0.1318085223676697, 0.19893988786685854, 0.1334434152851182, 0.09945972432051936, 0.13160480426684504, 0.12252077880886295, 0.13514963098831717, 0.20746025647367203, 0.13779778243793597, 0.14047239456445942, 0.1420767052519706, 0.15952870910686834], [0.09034578312909411, 0.07970142809133376, 0.03703643642966786, 0.03323364109101315, 0.040982785154013865, 0.041018975147556876, 0.05840222261125042, 0.06885334729186951, 0.06671731795875296, 0.07465271714834437, 0.07224826592831843, 0.0164112216988278, 0.0183302738643702, 0.06643759627496043, 0.04416565065302196, 0.04321535305690862, 0.059711658395826823, 0.027404196537850846, 0.05624372774975435, 0.01737619179391092, 0.08348984779008935, 0.021945450439929, 0.034564661402856155, 0.04810870902973318, 0.004352680322969513, 0.04248754654620444, 0.017292368368455963, 0.006188591838919468, 0.10100157585956397, 0.07232846001223212, 0.05302761020439287, 0.011870157961252958, 0.030410478770312284, 0.061497823034803716, 0.05107723461884645, 0.0267622665682387, 0.12863661192597883, 0.07322520423199862, 0.019602975732977354, 0.055044489882646076, 0.04406980539281522, 0.07440775287367644, 0.03863718097789153, 0.02788042935032037, 0.062041396891037305, 0.06821158011594126, 0.022333916389353337, 0.05465881823892555, 0.08202530218348389, 0.028098645665112044, 0.03157136244549146, 0.12493649918225505, 0.024704550573181723, 0.021685725566180005, 0.0674338782987287, 0.06298239034931026, 0.05854995500656867, 0.019232470714937777, 0.03163988709509854, 0.014956661090705425, 0.029070861036739046, 0.01180856832258043, 0.04241715838772155, 0.055546989934819366, 0.06023623327153826, 0.02845019958312473, 0.09029490723004265, 0.07131397573938293, 0.008087936871414705, 0.17223029367385373, 0.883633574891475, 2.1888225357378683, 4.944612403069773, 9.84518345325224, 16.892591253403697, 25.64863351083571, 30.9271357136388, 35.42290541433519, 42.095539569854736, 45.169967835949315, 44.75498891645863, 49.73377889202487, 51.56781642667709, 53.350125743496804, 50.35123055981052, 50.160917159049745, 48.47251722889562, 43.51144459939773, 45.329741662548436, 52.1619378366778, 41.061096806680005, 42.48476028442383, 45.969342954697154, 46.97899241601267, 55.07662757750481, 39.63465629085418, 39.41447011886105, 35.27453391782699, 48.68582356360651, 68.58583527226602, 33.007749126803496, 45.29802145496492, 39.13642114208591, 44.26290012175038, 43.619827531999164, 43.0654554213247, 33.44214770101732, 29.9920367810034, 20.321721415365896, 13.425939698373119, 6.1748196809522575, 1.8071349782328454, 0.33460848213684175, 0.31219183016688595, 0.03483681030751717, 0.031249693617404952, 0.06169979828560065, 0.10766317001393727, 0.003480180152579241, 0.04156270222137532, 0.03385663145191727, 0.027881701056274678, 0.07167068925956566, 0.05273439771225376, 0.004016196790842279, 0.032268213258395274, 0.0749923775513326, 0.0348621754786901, 0.0736111746500096, 0.06615834956568095, 0.027063099720004587, 0.04891831074811278, 0.04749455932347525, 0.009744790656822584, 0.045052788130217986, 0.13240073897665547, 0.022860722496144237, 0.05592804206835647, 0.07489334536536087, 0.019578993350507754, 0.03844399658602573, 0.022968578099783872, 0.034519895055000825, 0.02119253156706691, 0.03789222941944196, 0.06104798003610584, 0.02020619719499542, 0.04803564339395493, 0.04006049573241223, 0.002086020071029423, 0.03925992619065989, 0.03508515302993117, 0.09180287470019634, 0.029421585664573698, 0.03599568683233473, 0.05043691151865548, 0.02758722834950013, 0.020957566655030655, 0.05607044632216135, 0.010342280823557128, 0.023848742261649142, 0.09514043633375438, 0.027303923289441777, 0.047792134686343135, 0.04554514134783418, 0.05754560990739734, 0.03272349931179516, 0.032321847073974154, 0.04393517310100217, 0.01695017412965817, 0.0038876915266061384, 0.02899611192274719, 0.039095083221552834, 0.04681862079568448, 0.014856045017950239, 0.03496522196538506, 0.029687475630893346, 0.07911809810226964, 0.02180059278954662, 0.025695966023411003, 0.035086018709285606, 0.019102122769841266, 0.017782750824886947, 0.023638652224514275, 0.023781973868608478, 0.038594023414677193, 0.045356783309891346, 0.03493532921457964, 0.07132450944834179, 0.03050800942395243, 0.033312785634470564, 0.02250467355723583, 0.04978880879559344, 0.03149599088506112, 0.06966443522082222, 0.037790155864410827, 0.03171457492205645, 0.05355379386474529, 0.05319953182592027, 0.06933196838344298, 0.07565477547506172, 0.0330326809067159, 0.04795338853352493, 0.05217131159658875, 0.09982928513519226, 0.057213832549149954, 0.010501287160291067, 0.031170223486579718, 0.08121031486699659, 0.07688907335602468, 0.04870410873404434, 0.010709508900500594, 0.11200207751244308, 0.04458062899028582, 0.045605340536924145, 0.030798345255935868, 0.03802473964770475, 0.07251157800877288, 0.010616186942394462, 0.031118841969498226, 0.0150499370835361, 0.08424564715354674, 0.02122061826559084, 0.04648574027082613, 0.07468793421022354, 0.07779595291902942, 0.04552109767833064, 0.06329666642892746, 0.05857607094390739, 0.012222768122991248, 0.06950414664442502, 0.026589339456310677, 0.034588134336856105, 0.006835820264137921, 0.019374154846093828, 0.06863400865826877, 0.07476314106175015, 0.038313826756371606, 0.025905577255593195, 0.05617355792632988, 0.11395790764401037, 0.011801963687063226, 0.07149492570709798, 0.04484830011102942, 0.03975252838685148, 0.16502322959563426, 1.3514571781119993, 3.615002213947235, 7.50368437459392, 14.146006453421808, 21.118676431717414, 30.969465932538434, 38.30739682720554, 44.961552696843306, 50.4512902229063, 57.440283144674, 54.74903122071297, 56.339011038503344, 56.63913511460828, 58.214421733733154, 55.192678743793124, 53.86022998440651, 51.14184702596357, 47.41084929435484, 49.90752027880762, 56.84546747515279, 47.74837317005281, 46.86584380365188, 48.54173921769666, 48.54525366137105, 61.488329979681204, 40.98579514411188, 42.67175143764865, 37.003593137187345, 56.03341525600803, 72.02718950087025, 37.65356517607166, 45.56396599738829, 42.51917516031573, 46.08306031073294, 49.00022506713868, 47.4106570982164, 40.82967696651336, 36.69722857013826, 25.098783892969934, 16.57958023009762, 8.102826908711465, 3.506958321217568, 0.5404281459989086, 0.2144157219557993, 0.04442364608328189, 0.009908341810167318, 0.03438779851421714, 0.04696711927892701, 0.026266395091830243, 0.04805373456028681, 0.021253125291437875, 0.03594978284391184, 0.03501276538196591, 0.023223348299882585, 0.0743071272248222, 0.035398295299420436, 0.05013385096624975, 0.05790082189524847, 0.02221380529414502, 0.02770627075205407, 0.07377733912078605, 0.012043521743297819, 0.10464568757602286, 0.0299074252196137, 0.04968005495386259, 0.028502128853072083, 0.05647409038858549, 0.030140907751516472, 0.058727549509175365, 0.018626801602001634, 0.06426307485408841, 0.03700979955254063, 0.018738359325535355, 0.048845367686402415, 0.07565218609787765, 0.027959164036738298, 0.014992421117400932, 0.018600913575820385, 0.0015926551385482234, 0.02699388942170528, 0.08226904837835221, 0.03471086928320508, 0.07172525770241214, 0.07442462979064834, 0.00972235577196003, 0.037615560596027685, 0.02174741862672231, 0.03906140599640147, 0.022647185063350107, 0.09447315076906836, 0.03423259676163716, 0.01708097598184982, 0.048923026019286726, 0.03052076670311151, 0.05934764022728609, 0.026533721473007917, 0.05086543812086025, 0.07330296981719232, 0.05347156198695303, 0.03438135954521356, 0.057226748791553324, 0.04205114839057769, 0.12847455368647653, 0.0653970803344442, 0.021961298883862553, 0.05366136410063314, 0.15606658923770153, 0.10807828241658789, 0.19395878418318688, 0.11228638806290205, 0.09550736180596775, 0.12616047019799873, 0.14002366622369136, 0.16437879643372952, 0.11601645484446518, 0.21985612599359405, 0.1749232919105599, 0.19475462696244641, 0.1545120282999931, 0.14858756394636247, 0.16314245309800873, 0.14589972914226595, 0.14723278341754792, 0.1161376576149656, 0.1831224398507226, 0.18040791454334415, 0.28657844650649256, 0.17391070753576296, 0.10542808551221125, 0.2059758691898277, 0.16174702394393184, 0.160590031995408, 0.11866056901072303, 0.1750669333963625, 0.2392873026791119, 0.2691490882106366, 0.14240002499953394, 0.10150829705620006, 0.13655550958168122, 0.22909005953659936, 0.1719523263314078, 0.118212346287985, 0.19156054593622687, 0.20375159418871328, 0.07781833034729765, 0.23176350720947791, 0.12068410599303823, 0.18970393185173312, 0.18984441705528768, 0.11533924078028049, 0.14983075610812635, 0.17458063610378774, 0.08239025880973186, 0.08407510832072267, 0.2868071084301318, 0.11252708522783172, 0.12474763552628218, 0.20251486780903033, 0.09102094407764175, 0.18796842094630967, 0.17323394546345358, 0.1970417364951103, 0.14776902964278577, 0.16248640604317188, 0.12724002597913628, 0.15282249799178493, 0.12123349828705673, 0.1147355864785852, 0.12174575829938536, 0.18863698587782923, 0.2248973062922878, 0.13301734782515034, 0.1444074511528015, 0.16881750986701058, 0.10805140805220413, 0.22084070219387933, 1.401525620491274, 3.5850355509788763, 7.503595630968771, 14.891141076241771, 22.02883105124197, 33.481481229105306, 42.595225995586766, 49.91636130117601, 57.65542122625536, 64.94864102332824, 62.07173939674132, 65.42212601630919, 66.12227301443777, 68.39073657989502, 64.56192670329925, 64.80276023187946, 62.644303460274976, 58.491611711440555, 60.29326223557996, 66.72369787769934, 54.865604062234205, 56.478474832350216, 59.331838315533055, 59.81285033687469, 70.59837987346035, 51.00024161800262, 52.8765623031124, 49.069870671918316, 62.761527415244814, 77.60093242891374, 45.610089148244555, 59.023465494955744, 51.88557155670659, 57.44424866091821, 59.127741705986764, 55.974740520600356, 47.15990389547041, 40.63741807014712, 27.496740587296028, 18.647551844196936, 9.035366004513158, 3.6723906570865266, 0.7489732749039127, 0.32085603944236235, 0.11984159313743153, 0.16150615057877957, 0.2419273795620088, 0.21183573700968297, 0.1398687172801264, 0.2505127430683182, 0.08251354533938632, 0.2088272637657581, 0.15779578757862892, 0.13718474355916824, 0.3457316497881567, 0.11942284947801983, 0.20990824447043482, 0.13573165862791, 0.12256111333807632, 0.2935622265983013, 0.20215511291978822, 0.09890264050374109, 0.20134119046551568, 0.14789627684700876, 0.0893353361396059, 0.2631747055678599, 0.1132099147165014, 0.1456596984738304, 0.20714994489906297, 0.15014912692769883, 0.22276932854325543, 0.11752803824962148, 0.10212655299373212, 0.13560497832875099, 0.19110571953558153, 0.14558364126470782, 0.128104877958615, 0.0989146144579976, 0.21773769370009824, 0.131219400753898, 0.11985761969680749, 0.16176950096363024, 0.2203650228799351, 0.22720701541871796, 0.08586398491095151, 0.14130295644844734, 0.16466100790327595, 0.11978482602224236, 0.24100796680056283, 0.2537145002955391, 0.15345052155035158, 0.1373636404112462, 0.1962578140439526, 0.2604362170302099, 0.1667043635801923, 0.07239121793498916, 0.21793528309752866, 0.10887804756601972, 0.11657444264499411, 0.09679005346110753, 0.29073073498664365, 0.1375402083560344, 0.12173629711352049, 0.11616378121318356, 0.12873808793242902, 0.1780266374830277], [0.02460063649191251, 0.06281819472449922, 0.05813403438115793, 0.008650600681111457, 0.04484190327686168, 0.05045214134659018, 0.028732638963828647, 0.029178990516811613, 0.0773471020041935, 0.035977925083810286, 0.055777057629799655, 0.05856488989065251, 0.024642803886484717, 0.09827513022408371, 0.05967463336644634, 0.01925241389882661, 0.015130293003523783, 0.03320977362173219, 0.046122748660103935, 0.07626609831687904, 0.043764879416313865, 0.029851470157624255, 0.04336935205144748, 0.016126361480283163, 0.027402164489631693, 0.036886696883988, 0.06049870265527599, 0.08154085882368588, 0.03886043815122497, 0.08536992714770379, 0.017566671895404017, 0.028981939296148, 0.014062814598512507, 0.0374425319774497, 0.04679130976118388, 0.010344428742574829, 0.04160782480011544, 0.03301105807505308, 0.060996625332101706, 0.04501179859582936, 0.013376031138543642, 0.03255689051002264, 0.028872038237750534, 0.07613924947837669, 0.019526481853737947, 0.0208597659553972, 0.016652853491025108, 0.036629766315942815, 0.01610551431264368, 0.05874340369876835, 0.04098297284555532, 0.028306374236220316, 0.02149366732356289, 0.00068967633964231, 0.03053939221577058, 0.03492442012253789, 0.01324886724638242, 0.010816375293108004, 0.009706122368844527, 0.04725179755158963, 0.053378294612611496, 0.029001158526948387, 0.0713882632854004, 0.015430640647067659, 0.06813168480631805, 0.026032336078764453, 0.04276486654435435, 0.0419013322361054, 0.04749529093744294, 0.08620648750013883, 0.03162550379432017, 0.04710414942594306, 0.18173188301584414, 0.7576896394452741, 2.9534650666098443, 6.642598115628766, 7.46492890581008, 13.984874506150524, 18.829894988767563, 17.181669935103386, 27.78177530534806, 31.931438984409457, 35.81371468882407, 47.33161741687406, 49.492898295002604, 49.35293636014385, 46.65218445562547, 49.19935203367665, 49.82682143488238, 53.42012828396213, 51.39344353829661, 48.82929994213966, 51.27374064537787, 47.370582242165845, 47.42314200247488, 47.104229773244555, 48.04335894123201, 51.20793504099692, 48.84726439752887, 51.729523981771166, 42.60122329958024, 49.67070325728386, 48.388425534771336, 39.64551733386132, 34.127715249215406, 25.874773840750418, 17.17922825967112, 8.743739743386547, 3.2393857500245495, 1.3784435751938051, 0.3874219707663982, 0.0817888108412585, 0.016264188358740463, 0.024366543004890124, 0.03190383311331032, 0.08510479177798956, 0.012937933225334894, 0.10391395869514636, 0.04570099044471018, 0.006280526699077699, 0.027168388929097887, 0.06250673401800376, 0.03908377959423008, 0.028060731973739404, 0.10791719710874943, 0.022590147902167613, 0.05341452674099034, 0.07816159902440925, 0.04177870454206582, 0.09899775031954051, 0.04144260261748587, 0.11878676667448976, 0.02560093281640401, 0.07040715746341214, 0.0646169730011494, 0.0012779891919983072, 0.08693425570644679, 0.008980725204662211, 0.04083570010299164, 0.06428711086271272, 0.052441449520448526, 0.016211841570874377, 0.05634214323494704, 0.08495199554149183, 0.08517920189807493, 0.04097245445835494, 0.012903483208989906, 0.029214912379581123, 0.037989480450989745, 0.035223872400820255, 0.025363690708012834, 0.03202689939268655, 0.024521614522522977, 0.04809189723023484, 0.009660915520432736, 0.04761386219592345, 0.015466882351545558, 0.03280257107689977, 0.014093577816721894, 0.01825922495505262, 0.020511448758864598, 0.06452591579046942, 0.054534156581447016, 0.06802496875846578, 0.06632744049232814, 0.0305966668642096, 0.016789697861719518, 0.0836160684364938, 0.02719014199570783, 0.038597279288355386, 0.006697291457619999, 0.027042327245937723, 0.015686742882544718, 0.0575523131767348, 0.06289909743974287, 0.116279904820746, 0.05537430222536768, 0.01524949532693192, 0.06252252309012317, 0.00027934600145653675, 0.06682099263754583, 0.05702734376574236, 0.09023752724451405, 0.04457354267698623, 0.06941750210018889, 0.03229690325115958, 0.05537405707723191, 0.06403134857875205, 0.036327563782012275, 0.052949346662048376, 0.04601857219372065, 0.03986219387321223, 0.04253538490663614, 0.04104074736636493, 0.014085900658110698, 0.05051587603145069, 0.022705968904999957, 0.06338617231156077, 0.01592356555779735, 0.031765686393144636, 0.030347276516559146, 0.012731810566037895, 0.10285639729831489, 0.03498148984245716, 0.03651396446530858, 0.021367440931499008, 0.05491020999127819, 0.03597039060907499, 0.02271348614275696, 0.0036705968124161087, 0.07737123377380833, 0.025243299990712155, 0.030209388351067904, 0.03315631217593628, 0.08713727666726036, 0.09409003785901493, 0.022481284892907547, 0.07409428501681936, 0.029570890455356533, 0.026325144459523504, 0.0212413179613049, 0.05965636599989188, 0.00850778273982747, 0.03898629107542577, 0.00941874650907853, 0.05955814203668026, 0.0443297773299198, 0.024776514957568822, 0.04103520472023276, 0.015766600845381618, 0.06826117664815919, 0.07915058023025913, 0.08206518472082193, 0.029200873818368684, 0.051537423634961735, 0.06090347287094882, 0.03292262088507414, 0.015195601999068694, 0.0774994079444197, 0.022276009718376785, 0.05674926151010779, 0.04715753043250692, 0.04471719182366806, 0.025373718798941663, 0.060776811723987904, 0.02956290973440534, 0.03707125512582641, 0.10251388704824833, 0.6285967149080769, 1.6309813337941326, 4.976715041745094, 10.152766896832375, 11.253674222577004, 18.262745757256788, 25.17482884468571, 23.04489947134449, 35.46551412151706, 40.940950685931796, 43.17627806817332, 54.1272061101852, 57.664070052485314, 56.81178608248311, 53.563863538926654, 54.94048995356406, 57.07238051199145, 60.45491095512145, 56.00480941034133, 55.77394262436898, 59.218042512093824, 53.47890107862411, 53.93396662127588, 52.000493080385276, 53.07268865646855, 53.89799456442557, 52.585455756033625, 58.90548060017248, 45.47293955279935, 53.473903979024584, 52.96329767473283, 46.19428303933913, 38.01255226135254, 30.122790951882642, 21.297873835409842, 12.140861403557563, 5.028022095080345, 2.379059450280282, 0.5994378763341135, 0.11838597245514394, 0.03415767719308215, 0.051329465237476175, 0.04019749906635092, 0.06334835438117867, 0.023699180831411676, 0.04931640450752551, 0.05312376189976931, 0.023023018222903053, 0.02064021664761728, 0.043986884035891106, 0.035280815716232025, 0.09922144033255116, 0.01794719159783375, 0.08257593553993972, 0.07246918270304319, 0.0013756164445376565, 0.06203653223271813, 0.07246752795312675, 0.009730234986261256, 0.0633836020865748, 0.03374868200250691, 0.016061921036922406, 0.03381872159098426, 0.009540396483404743, 0.032967364250291745, 0.10084794458722877, 0.07904951025040881, 0.045053818518476146, 0.04456248419779924, 0.031663833088391734, 0.0498386811194641, 0.06034655376307427, 0.07966820285805772, 0.05190623368346884, 0.01118021151576672, 0.04153342617134895, 0.03924412179678198, 0.03459820073218115, 0.018177355053804575, 0.050511850239408594, 0.05479644593452254, 0.009956140908592892, 0.05603772670691533, 0.04584752774286655, 0.03532861194182788, 0.027466684414614594, 0.018687561950496128, 0.040808029007166624, 0.07007125089125288, 0.05732287750429204, 0.04276568242799371, 0.02192839540751471, 0.13136256726518755, 0.09869349850041252, 0.0115229764900681, 0.040389289178194544, 0.023585550840042775, 0.014630692594143895, 0.025151413489854144, 0.013564977148968368, 0.05139627193491306, 0.12453375909958156, 0.044880380042858666, 0.054647564407317877, 0.18338860943913463, 0.17978313919757644, 0.1499486570396731, 0.15616523071883187, 0.14891117480733704, 0.15178515365527523, 0.1931093305709862, 0.07864025842037894, 0.24638080188343603, 0.10575829239021386, 0.12706709695198845, 0.16366241229397638, 0.10666579248443728, 0.27843392063533107, 0.16358974119347913, 0.14876521973600312, 0.13586903351449198, 0.16880096236784614, 0.16526532870146537, 0.15156988294855242, 0.1421811690013255, 0.15697941364299867, 0.09503397309491712, 0.11814361287941856, 0.17261356746237125, 0.09991687196757525, 0.20779275395456823, 0.10788093816729323, 0.14549466781318188, 0.23628365578910998, 0.18750951895790716, 0.22275947665254917, 0.11476813755448788, 0.10024476526004654, 0.2845673124876715, 0.2053598119246383, 0.27170583004913024, 0.1363490029208122, 0.2217584142401334, 0.2444851326365625, 0.14130071947170844, 0.12144273222093621, 0.1600093526705619, 0.21183186060478612, 0.10005160385081846, 0.1501489277448385, 0.08930523654506092, 0.057083727836969404, 0.16237389837061206, 0.20489511831152826, 0.25453136452744085, 0.11892638619868987, 0.11059489656960773, 0.10085512283107928, 0.15722974053313657, 0.22435765863666612, 0.09791460924691732, 0.07558582756187647, 0.18294297609358065, 0.2625807422784067, 0.17859662222045083, 0.1495120482098672, 0.19717266092136984, 0.19539406523108485, 0.1591341585041054, 0.17608688753699103, 0.18943336491863574, 0.08470622687450341, 0.1713089197273216, 0.1262565069801865, 0.09201399321036954, 0.2156839039056532, 0.5394811387504301, 1.584530542454412, 4.306876197937997, 8.751102032199983, 12.03718335397782, 18.528860922782652, 25.88733523122726, 26.291274639867968, 40.61167947707638, 45.795232865118216, 49.08722715993082, 59.42520641511487, 63.89824205829252, 64.06677061511625, 62.59334402699625, 64.30373276433637, 64.01644660580543, 68.361099150873, 64.83308015331146, 65.75525683741417, 67.64874181439801, 62.34093558403754, 62.40004178016417, 61.304327672527684, 62.20491955357214, 63.44290587209887, 60.922049553163596, 64.50219292794505, 55.323627071995894, 62.60667616321195, 61.12503613195112, 56.12805420352567, 45.15318793635215, 35.176176563385994, 24.52239944088844, 13.675796639534736, 5.7403617808895735, 2.5300479031378225, 0.8441878302443413, 0.2900182732170628, 0.0779122986920899, 0.14287732841987766, 0.07636454061514909, 0.15483317235785146, 0.12249172109389499, 0.1892551728674481, 0.1721721935656763, 0.09814438965892601, 0.1733820149374585, 0.16003965910884643, 0.14780013281251156, 0.2184424639469193, 0.12969050376165298, 0.2480905415910867, 0.16862493068460496, 0.16505940426741877, 0.1835822917881512, 0.18009113718665418, 0.11165685531112457, 0.21377142668972093, 0.048727861290136655, 0.20760841787822787, 0.17001516576255524, 0.09255643708691483, 0.10821579519899623, 0.15323911192676715, 0.22768828717450942, 0.2475964455234428, 0.18074776646831345, 0.09117969281731114, 0.1236353218255024, 0.14262278804615622, 0.1486967774408479, 0.07965272022110802, 0.09233114595014243, 0.13730679668726462, 0.08329711539009887, 0.1506129625223337, 0.08936779528495767, 0.16220014962938525, 0.12843020485653994, 0.1634107677326087, 0.16415800989395188, 0.12486788068687725, 0.11633273424400438, 0.1461082276317381, 0.09340305617379566, 0.11508174330717134, 0.10315431357030908, 0.11661624806302211, 0.1638516819765491, 0.12944074377657908, 0.2268431389764432, 0.18447126021548627, 0.19537659842641125, 0.2136319833657434, 0.12749520986671412, 0.21062501165415012, 0.14022271118817792, 0.10150955344039587, 0.1804450085206378, 0.22560774558974853, 0.2132062223409453, 0.2279270461369907], [0.09830660111601315, 0.13645688342230936, 0.08262688038690437, 0.08837208016625336, 0.03788628457714954, 0.039832753114282124, 0.06206617600494816, 0.04987223194010797, 0.02712240258622314, 0.05806230556880755, 0.038048293020936756, 0.020462840480069, 0.020432888357449445, 0.04717366424419227, 0.05649427297495066, 0.04151053163373182, 0.06726987419589874, 0.009867921096062469, 0.059742608347967754, 0.0040668361602471245, 0.054603257712217114, 0.08279613219201565, 0.03711345124869578, 0.06230501540666146, 0.03398865904478777, 0.03239931388487739, 0.030285864993329012, 0.03179481497124559, 0.020750573528329694, 0.00488575877464046, 0.08434984277212813, 0.024529168149456385, 0.028884496742619142, 0.024417828760981083, 0.044585581748716296, 0.04118160029212314, 0.05137737637626068, 0.08740109436574482, 0.01275031541984889, 0.05795077082791156, 0.05470895486313009, 0.0317635509230557, 0.012908444585909527, 0.05176466829594105, 0.017574304046349663, 0.04951633047312499, 0.04374624815799537, 0.016436799459399718, 0.023318335541614124, 0.03361954256111095, 0.03745622196865659, 0.016530365608031714, 0.09700795184941062, 0.0594570835481488, 0.02447835545265867, 0.032908341006165555, 0.01352450280870882, 0.06068367841503313, 0.05163968105109469, 0.11100777965639869, 0.09096385520552436, 0.05820198638004161, 0.06911482842218492, 0.07096876885982291, 0.05958775899583294, 0.08530372182928747, 0.03679706076640756, 0.031881547615593, 0.07521985203868921, 0.01221727239974444, 0.06437158737812312, 0.06273843731070239, 0.02500431311707343, 0.09509113091494768, 0.06644771629644018, 0.2015943518809734, 0.5533673710400059, 1.1409257977239549, 1.5864138930074632, 3.883843181594726, 6.700305986788965, 8.24640085620265, 14.936891601931665, 17.284704715974872, 18.369630344452396, 25.710944283393125, 27.53808236891224, 31.145539168388616, 29.74900280275653, 29.450686939301033, 38.74774563697077, 28.857022485425396, 33.913706810243674, 38.211894958249985, 35.10307142811437, 31.7750991928962, 39.67487627460111, 34.07005248531219, 36.94448694106072, 38.570521185475016, 34.35077259617467, 29.68098694278348, 26.547830989283902, 17.309325433546498, 11.845174508710063, 5.687051376988811, 2.0934753552559884, 0.52333390520465, 0.26606665683850167, 0.050202120891622, 0.026190571539524584, 0.1261616652951606, 0.05493030064709245, 0.039659735987023007, 0.04195830236459452, 0.05719802815527205, 0.01890733342377409, 0.059932766692532655, 0.036456818136596875, 0.03348558825711089, 0.01124845558567153, 0.03899495552984938, 0.017077934612790426, 0.042923898736555735, 0.06178931948999244, 0.05553341868724074, 0.04139677523785541, 0.03640802599669945, 0.05691529957637672, 0.027733041694568052, 0.013944478912068712, 0.06712528276107005, 0.022964575290379506, 0.018146464473477775, 0.024532989012978734, 0.02832307686818944, 0.01838782047402234, 0.06408616983061356, 0.06087926066210193, 0.06105062303944461, 0.012525748236164933, 0.04211368414783671, 0.07490615435545483, 0.0036570483080727322, 0.024272867688728918, 0.05588487684426289, 0.02354225538100206, 0.07153289302462532, 0.10388521507622735, 0.04008024547910018, 0.030570845870721727, 0.051647008682090434, 0.04573098278694576, 0.013837432488799097, 0.04599322234430621, 0.031696591008033966, 0.02815132570122519, 0.05456905188639799, 0.08109491904296222, 0.050607465673238046, 0.059344602688666315, 0.027551224132278757, 0.06798075782435556, 0.04493665686177631, 0.007923145134437589, 0.012290244189751966, 0.03147750901388786, 0.02857802518373055, 0.083251464210691, 0.07251557698773761, 0.03776202128539163, 0.025603244486715526, 0.020897547496602904, 0.037416703323082584, 0.06043811276134464, 0.04291421155475321, 0.057821436034094904, 0.06717988184743351, 0.045405265184179436, 0.011182420721818364, 0.05600624432366702, 0.028386916890139544, 0.10621392318317968, 0.0772901893322987, 0.058674015285026644, 0.04343453081204526, 0.08614651813742616, 0.038077883167012085, 0.03606171978096809, 0.032400148920714855, 0.0431075185206869, 0.05268155679767651, 0.07172701204375875, 0.081593964038597, 0.023103212306816733, 0.047604240131594484, 0.026933590641185164, 0.020588377393001032, 0.029290027300556822, 0.06547830863705566, 0.007106185620350223, 0.03321014900481509, 0.01937467578588234, 0.1113421004265547, 0.07506513292150152, 0.04940214506801098, 0.0808673526250547, 0.13776182227077025, 0.023622133453646978, 0.055409879348571264, 0.04685339735700719, 0.026964810639319402, 0.011045244060486797, 0.07162946606836013, 0.047973276176039255, 0.09269016539497722, 0.03060149704857219, 0.020570569679201133, 0.07553605482943597, 0.050712350770951285, 0.018960580364951206, 0.050157496270032666, 0.02914612726007979, 0.02619766742892323, 0.013444701344856333, 0.05378541288777225, 0.06918253527293283, 0.03285952205319078, 0.06127552347137563, 0.055280820346407356, 0.059614177537901755, 0.036699997426401225, 0.07163603910275045, 0.09136158507317306, 0.05055595392120942, 0.037038206092772946, 0.06879372266872276, 0.016924132885892066, 0.05399614069310408, 0.04882128188206304, 0.039999093785281145, 0.02729059910521873, 0.08942744289074214, 0.04097142790053641, 0.05266114055449444, 0.03630134059236415, 0.02666088632277904, 0.09718261223526732, 0.02166523654464512, 0.025850125896413962, 0.10460514620306993, 0.3937296935867879, 1.1895592654905012, 2.083820195928697, 3.0950010976483746, 5.693886597310343, 9.911723521447952, 11.98212504386902, 19.380452594449444, 23.33442138087365, 25.311501872154977, 32.3583830941108, 33.91367150891212, 37.79956756099578, 36.63453732767413, 37.32094034071892, 45.69044282359462, 37.004071666348366, 41.78089880174206, 44.45859501438756, 42.34871287499705, 39.47263102377615, 46.613043123675936, 42.54233675618326, 44.3176995554278, 42.52447428241853, 41.54372092216246, 35.06201990189091, 31.0618769737982, 21.759315190776704, 14.694508737133397, 7.516870402520703, 2.874621748924256, 1.0106339762287757, 0.3645229285522815, 0.06622771882722456, 0.07263320212763164, 0.05099949201629047, 0.015022302376887491, 0.02482734489134483, 0.05531454353683418, 0.059794840222645196, 0.05803091511611016, 0.040372339482869835, 0.014419305953197183, 0.03984390352402003, 0.026317631052206122, 0.04352310972829019, 0.036003133206958735, 0.048854373049952333, 0.04338424097025587, 0.009440328163515416, 0.04172512435264165, 0.040965820136930675, 0.04144742897140884, 0.030319331544301206, 0.028363235197180224, 0.09744217048489279, 0.04804836045349798, 0.0327193547761248, 0.06939048217909952, 0.08853960827353502, 0.0866403843786928, 0.05842330535092662, 0.033501381159669934, 0.04185831256871743, 0.07778713524702095, 0.0061000062194052004, 0.03372014522732746, 0.0766933149087333, 0.052622418640361684, 0.055436290229760835, 0.05311134361451673, 0.01113939147833134, 0.02921430525490113, 0.03354031757842149, 0.03241350949411431, 0.06445863028807987, 0.05014903865934861, 0.05805267201315972, 0.06542036940734233, 0.03055115741106772, 0.046069865610690854, 0.035292318526415095, 0.022509976800891663, 0.03279633129075651, 0.0570018828335789, 0.019932077529149193, 0.0416850081584867, 0.025142348754490097, 0.03027832094249466, 0.050745112521033135, 0.02701768985829286, 0.04107916284532797, 0.057033721447711995, 0.015787296710656058, 0.09480803844428833, 0.01733254968008447, 0.04788913673931553, 0.021489739207731142, 0.04069656704462344, 0.027925672587908568, 0.17073873580703813, 0.27622072326560176, 0.1495104241034677, 0.14880923914813227, 0.25949451111016736, 0.21125822928884339, 0.12887265893720812, 0.13349249087754758, 0.14319908534807546, 0.1651791744535008, 0.36144938380006825, 0.11802060214141685, 0.13048032508982768, 0.1524443723141186, 0.15207951527930078, 0.20637380590121593, 0.13251436513758477, 0.19380498437150834, 0.1498519767436289, 0.12824871096639864, 0.15378283517014596, 0.13558673011439462, 0.10434499806574277, 0.2614434081460199, 0.1677583167029004, 0.14260529059796564, 0.12901254659218173, 0.174120937383944, 0.20870251400816828, 0.11771069659340767, 0.2535134635024494, 0.21756340869732443, 0.08121188534724136, 0.20430178321417303, 0.14795068441139114, 0.07821028391199727, 0.16838600318278038, 0.23643990708214624, 0.12890742400721197, 0.23950861015867805, 0.13162984002021053, 0.09455377386221964, 0.14385867172912245, 0.1348623326949535, 0.18201208733502897, 0.12160492069538563, 0.16116947025781678, 0.17111689212822145, 0.18003971736517646, 0.24190257363502057, 0.13294694434490897, 0.11599379396366498, 0.1346643908970779, 0.13211008521818346, 0.24418546968410093, 0.09835579928251044, 0.18150329770099732, 0.21150141623952698, 0.18578500907507636, 0.21591054335717233, 0.3402646318558724, 0.1077017425409248, 0.15942255996408003, 0.23996366638570066, 0.1505701535291249, 0.20137466850780672, 0.21187083915837351, 0.15088449472621565, 0.12441854713664902, 0.10774842793903044, 0.13796616856369281, 0.12449078156702942, 0.17840370595935853, 0.17351519166221543, 0.2213945990848926, 0.36724738235915866, 1.0371148778546242, 1.993004333588385, 2.6653836475264643, 5.720218448869645, 10.735339868453242, 13.377429785267001, 20.877038817251883, 24.683659845782866, 26.779766621128207, 33.99864965869535, 36.36057938298872, 40.82756280899048, 41.42592822351764, 40.806350631098596, 49.23555158799695, 41.746585907474646, 45.96616583485758, 48.973937342243815, 46.86386692908503, 45.41133872924313, 52.988777391372196, 50.43978198882073, 52.39382443889495, 50.75983170540103, 47.44014547717187, 40.5689021079771, 36.745473723257746, 26.636813879013065, 16.701679691191643, 8.992698461778703, 3.4398024409048022, 1.1285607709038643, 0.3946065884684363, 0.13327357359230518, 0.07256270671683936, 0.23644830340579634, 0.14062979498938208, 0.05538860891735362, 0.11128649010413116, 0.2922330027626407, 0.2720708556232914, 0.28630388059443046, 0.09004919985008818, 0.0943336308362984, 0.16238384219186922, 0.1375627773062837, 0.16762748420719178, 0.09948228560988942, 0.11709343657017716, 0.11822572218314295, 0.15315088924140702, 0.13572203656358106, 0.09709684103126488, 0.13669067813504127, 0.18996329857937752, 0.22613199487809213, 0.10443976314197626, 0.13428977390210475, 0.12728940034585615, 0.12722262046149663, 0.2583236529702141, 0.21331002725468529, 0.07976431624903794, 0.18921829339477325, 0.18319042249312326, 0.07737586860575023, 0.1558646331391027, 0.22423071786761287, 0.11766407248233596, 0.19052032110912187, 0.14386729787914984, 0.1395946569860943, 0.2467011185663362, 0.13713120933501952, 0.16350157979515292, 0.12695742380474845, 0.11682485380480367, 0.18131058062276534, 0.1513263129539067, 0.1026315045272631, 0.15047502073068775, 0.13922149555817728, 0.17093370518376752, 0.10547103240124642, 0.12264900660562901, 0.16416007833134744, 0.19674919816034456, 0.09436052052244064, 0.14888664467200158, 0.17891709212093584, 0.13225063170877197, 0.145863477861689, 0.23285729690424858, 0.1904386101711181, 0.16693835747578453, 0.1712640116532003, 0.16105083388186273, 0.1159621392106337, 0.14026541292907732, 0.2220846298000505], [0.0650988040011256, 0.05610623411954411, 0.06029264798628227, 0.04391223259810959, 0.08162217905684825, 0.09509333724816961, 0.04226694769796826, 0.0688973207387232, 0.028858926642926473, 0.08581057326087067, 0.08629595890881554, 0.07396143770986989, 0.053473779811493816, 0.02904397518103642, 0.027564847090792273, 0.05130344123068837, 0.06421144435843153, 0.07215668777784995, 0.041425162625889626, 0.05450860754917226, 0.029925571927320094, 0.019773154504477017, 0.006799217061920753, 0.03966027224857, 0.024133562260577758, 0.0756194434999939, 0.025985470649996595, 0.04803547868505121, 0.028737463402531804, 0.05200934911807699, 0.0636226713146654, 0.04295271513382754, 0.05263283360569228, 0.017103675167046247, 0.03328439824643635, 0.06486737650007972, 0.06598280817871133, 0.027571115605232697, 0.024355534321418213, 0.029714106762361144, 0.037290574607229045, 0.04635783040054864, 0.008823418625510268, 0.04438355670220429, 0.02694133962053926, 0.049523286551477454, 0.04726276026978608, 0.023788694374924226, 0.02534290482740729, 0.01850635725854626, 0.03658614143909466, 0.050935025717462265, 0.06427695253683675, 0.06879753012570643, 0.04549037755256699, 0.029942946801442775, 0.006103331998606483, 0.05375663479489665, 0.08670872708241786, 0.013095750210566387, 0.058445694270513715, 0.014624783183417976, 0.025398530471589298, 0.021828570320541342, 0.08176054985773179, 0.08540660743751834, 0.04973247068964186, 0.011702399069984114, 0.09988003079929661, 0.08157954626386205, 0.07306508419494476, 0.023293489395009897, 0.03574460534559142, 0.013360483384120369, 0.035093327188083244, 0.024608837463141933, 0.03848563346471037, 0.016611904176252506, 0.04324859744238277, 0.181101193471301, 0.3294089208206823, 0.7747896412207235, 1.1392574420859738, 1.637040169969682, 3.35990228960591, 4.108888925083222, 5.629741626401102, 6.650106512731122, 5.679942081051489, 8.613693560323409, 9.313460088545277, 8.757235638556942, 8.787574191247264, 8.321435797599054, 10.248707090654682, 10.97101548025685, 11.498094758679791, 9.872287031142942, 9.983564672931548, 10.565588512728292, 7.908174876243838, 7.983262279341298, 4.339736344352845, 2.699031209753406, 1.1511066772284047, 0.11362793059238505, 0.015062226091451464, 0.04859322899832361, 0.03787338748694428, 0.08281529971188115, 0.04138469786172913, 0.04604202214508288, 0.04743814843917086, 0.00835187427113734, 0.07215953762492827, 0.019504207847339493, 0.01337683074281461, 0.03956681718268702, 0.04133342359695704, 0.017205990039773526, 0.04117973869846713, 0.006651115507983993, 0.047117720673521685, 0.0920241515362455, 0.040973952160246914, 0.05118372850120068, 0.017565055449883786, 0.026780307938855503, 0.10400880804105152, 0.028353124751799533, 0.0181101729732848, 0.023094316110796025, 0.03739450209503693, 0.1280865531354662, 0.04302110380282806, 0.06894474924211541, 0.004511505192626388, 0.01594559154323032, 0.018536853303592053, 0.01959581089566552, 0.0754429598248774, 0.021692474800792914, 0.0689246317732238, 0.05861656635158485, 0.06489691685043997, 0.03294006087667039, 0.018049224933248856, 0.012672137104785972, 0.006129322967852556, 0.05844711536361326, 0.040329024871631015, 0.06025709384571641, 0.053479092631248705, 0.0648234183749845, 0.03963871836482037, 0.03185769738329034, 0.06933769106023735, 0.05927398470380615, 0.04682376890653565, 0.043439621466302106, 0.059256322546711857, 0.043187463626025185, 0.044504318972148245, 0.06711294108460988, 0.07413252812599944, 0.042543287103575085, 0.045064647171285846, 0.010962066064108043, 0.05125399025517607, 0.020861221522453333, 0.023332050430678555, 0.05874808832642533, 0.020786386223569996, 0.0588589220968706, 0.06651426635442242, 0.050545872204125895, 0.058046738662186174, 0.027759603878122666, 0.029167196593217315, 0.10374383354980139, 0.0407552455491837, 0.02586276443194478, 0.028658826392324224, 0.09367067366838457, 0.06521118909961755, 0.06557055328401827, 0.0162039891696505, 0.10062116723988326, 0.06356437202362765, 0.025692882519515774, 0.04009487775845393, 0.05629295655976861, 0.04678025128199689, 0.04434635547260123, 0.027406611630032142, 0.11496536689059389, 0.019143190828242132, 0.040873112006773876, 0.09523817383113409, 0.05199640223215665, 0.037083891746137417, 0.0810576718480837, 0.12649097585029181, 0.03618546213293749, 0.027810947090807944, 0.06724457031175976, 0.049442276583924416, 0.07895346580734176, 0.027457680966284488, 0.032863206936106566, 0.004023150953974936, 0.0672673078013524, 0.03629385208290431, 0.013761447100419433, 0.06689319642440927, 0.040054746242540504, 0.047321768192153786, 0.019310395263375777, 0.052826933472627596, 0.07772742635420254, 0.03389930637973932, 0.03489743850584473, 0.026729336278813503, 0.02215713010950675, 0.05258410275282879, 0.018883806863619436, 0.038689826540048086, 0.08504248584710783, 0.04565175014337705, 0.029940397643874732, 0.030381534053313158, 0.06058440491136524, 0.025489884541339936, 0.027711150732131738, 0.026269231532369892, 0.046647921084396304, 0.050963022400655096, 0.03831357777779622, 0.043987182810181574, 0.03536132006575504, 0.04462185601193098, 0.026153015994256543, 0.06443423038769154, 0.00679199668323441, 0.03647991568751393, 0.009773419362552946, 0.018714240962459196, 0.026936195340127717, 0.004783835564364469, 0.03789804785722687, 0.08002794242554134, 0.03369579129221459, 0.06917826816319458, 0.06622873772416385, 0.06612523924559355, 0.26761847518144116, 0.539469555501015, 1.1469191793472537, 1.6950689400396042, 2.692203098727811, 4.968253018394594, 6.422815947763382, 7.912943497780831, 10.05207279036122, 9.40143689032524, 12.563847841755038, 14.148487352555799, 12.605363188251374, 13.28743100166321, 12.071964971480831, 14.02109367232169, 14.931671907824857, 15.163858571360189, 13.287679091576608, 13.657376208612996, 13.473073840141298, 10.487412733416404, 10.037835567228257, 5.452800075854025, 3.5308546260479963, 1.4148288292269555, 0.17514803146402683, 0.00857224329299624, 0.012424632291039153, 0.03602722284173773, 0.026669039413513198, 0.05449920765034134, 0.03695827630919315, 0.023374336568879026, 0.06389058375310513, 0.06317763551769238, 0.046062223883646156, 0.020034325369183096, 0.06952560476718411, 0.02838256359550982, 0.020623887483511242, 0.021981889412047404, 0.0252961409052894, 0.01577026274565968, 0.03886182477036792, 0.06693210603008348, 0.027950413397423206, 0.04562836147904877, 0.025863974850865144, 0.07625280669139278, 0.01336839419954847, 0.012877571242561024, 0.09841437436520092, 0.03214329113102248, 0.09627241551155045, 0.04398846600745474, 0.07092261206238501, 0.0490509320591246, 0.022717707287219745, 0.028274095121530757, 0.0367479047347461, 0.01688319889287795, 0.07920405316737392, 0.1060752765906434, 0.04347167075461438, 0.042491840469020034, 0.02568833770290498, 0.05842016055999745, 0.004661461636949812, 0.01215941743970278, 0.04931629342477649, 0.04050435175398185, 0.02992417190163847, 0.04130077676006383, 0.009703595236304307, 0.05934516959373028, 0.0589968026014826, 0.026823973035319682, 0.033328750906812574, 0.055704673812274015, 0.03068988827327567, 0.0033160139742727966, 0.05643815320405749, 0.023490879609580004, 0.04897502040670765, 0.10445427284726214, 0.029870595542653918, 0.0021471613088637712, 0.010914328252716411, 0.076455942565395, 0.07139526532902833, 0.035630822136637666, 0.043496492003361066, 0.09524074022568042, 0.06309628847145266, 0.016002205440834645, 0.026966645419898055, 0.16085641608843881, 0.16005346401324197, 0.17651614192272388, 0.18321098429301094, 0.17816678560789556, 0.22859921168175437, 0.17153365928078854, 0.20711703376183588, 0.14344869211556452, 0.2537356749657662, 0.2418471854780951, 0.30093539386026325, 0.169436187152901, 0.16364840820672052, 0.09514543888789993, 0.11566009372472764, 0.22475732670676327, 0.1884895445959222, 0.18777334431727088, 0.42841953375647146, 0.08222071589120934, 0.1545897402590321, 0.14810365684811147, 0.10132202277741126, 0.0696549816958366, 0.16515231541087552, 0.19875699203581582, 0.13111024854644654, 0.18059211272385814, 0.17111405760290163, 0.18078075421433296, 0.11332763178694634, 0.20996616071751042, 0.06590274432974477, 0.136987506562183, 0.1657419886079527, 0.1277608048891829, 0.06522757572031791, 0.12322283710443205, 0.0994390246248053, 0.14828106748961634, 0.1262862158698901, 0.19256413643879278, 0.15224802397912549, 0.1937226299196482, 0.1270503196264467, 0.15591228380799294, 0.09463952208358435, 0.10303331764354821, 0.12451469883202546, 0.09885796225599705, 0.08726673786558452, 0.22200198423477913, 0.12754926503065134, 0.13424865030232938, 0.1278928324820534, 0.10474517941474916, 0.10481804203722747, 0.2012895101741437, 0.0868393297517492, 0.16043424035512632, 0.21726541581653783, 0.07733141252350423, 0.19126587787703161, 0.1714534192315994, 0.19791651697408771, 0.19176348262736875, 0.055241317022591836, 0.210413770569909, 0.09817670324757215, 0.09914156034468644, 0.21251760122756805, 0.11248555560145648, 0.10972151037065253, 0.15491376480748578, 0.11531333934756056, 0.12862219415124387, 0.19733928504490084, 0.22909929855696617, 0.3038771714895003, 0.6450107309126085, 1.1154880014158066, 1.6385581272263683, 2.982752669242121, 4.799359681144838, 6.060590455608984, 7.790478275668237, 9.564933046217888, 8.986261852325933, 12.082761295380132, 14.895568451573773, 12.002671399424154, 12.84071324333068, 12.682333819327816, 13.931951926600549, 16.30782175448633, 16.75476504910377, 17.43575126894059, 18.20754624182178, 16.145520940903697, 13.46476233774616, 11.479982233816578, 6.662920896084079, 4.406968710883971, 2.0974869593497245, 0.4455337541237955, 0.1216412639065135, 0.07198303096717404, 0.14717172620998276, 0.12926091229723347, 0.1470635239515574, 0.14694989779062811, 0.18180309854928525, 0.07990944394541365, 0.23977242019628328, 0.13705098460758888, 0.09427179987992972, 0.13131373682089392, 0.1384009081389635, 0.15839466915255593, 0.1569372328418878, 0.10137651461146532, 0.13938859465622133, 0.14712752293675177, 0.19315524988116758, 0.1512025897541354, 0.1729382661681983, 0.18110405864013782, 0.25187415791855705, 0.13916753232479095, 0.14641323787791116, 0.25979837222445396, 0.12491725505359712, 0.1959548875569336, 0.10936187039459906, 0.15826284074254576, 0.1621809361442443, 0.064772856571982, 0.10460651750045438, 0.14037929955990086, 0.19566728282840024, 0.2309342936402367, 0.2636668404504176, 0.10542507478666883, 0.12064645277155985, 0.08522454664231309, 0.20189389225936707, 0.08072040163941922, 0.11929194803439802, 0.12379738006500468, 0.11090947525395502, 0.23771221058503275, 0.10525209979424555, 0.1717389708444957, 0.10151565916115239, 0.14415916205654222, 0.16685028800800925, 0.1110469037666917, 0.20379216620518317, 0.20516053713377447, 0.09288919503770529, 0.11078210547566415, 0.13526975357484433, 0.13016242924476826, 0.2497023139749804, 0.06545296644852047, 0.2379492994758391, 0.10158979348958501, 0.16210984318487107, 0.11899639131321062, 0.14216714959231116, 0.09814324052703959, 0.2084239337953829, 0.2380788296220764, 0.12298239274851738, 0.12778165780248182], [0.06147015959985795, 0.13942565798999804, 0.028358703787108103, 0.05932765299334161, 0.025609323394394694, 0.03309577973859926, 0.016209872724908977, 0.041021840316393686, 0.03997674700052988, 0.010910811909143964, 0.009659195653042726, 0.05821725834281214, 0.08806156174790475, 0.05641223261913946, 0.014606084892406099, 0.01679811142234793, 0.04224276230219872, 0.02673123617686572, 0.011900536220280394, 0.03972501816949056, 0.0343916212929593, 0.03557928740197132, 0.06419365579682974, 0.013970424394844281, 0.03219063153430339, 0.023827837637415337, 0.03696209142705606, 0.03458879700291061, 0.023234016074228193, 0.07369516086914847, 0.014205251411054165, 0.023453921612892902, 0.06104545194595572, 0.030346939437872464, 0.025011866744006836, 0.012057192582306604, 0.044545997985668724, 0.019215944283191237, 0.08267004178055833, 0.04444247269402108, 0.07258194318461804, 0.0628343706710204, 0.052843864015754194, 0.044539823316999023, 0.07027420290415326, 0.025106869307496858, 0.04489118571303064, 0.06866587791591883, 0.04084953948134377, 0.03343401904848795, 0.022123299666770527, 0.013934496786415338, 0.04851761995063675, 0.03875605484110214, 0.030795914841996088, 0.005746723815513354, 0.030428975963244037, 0.029123772814449285, 0.009693528840979262, 0.054747726572977926, 0.018026613848163717, 0.03746750644378124, 0.02213979162456047, 0.010594274912540232, 0.04384398948581469, 0.0321903289295733, 0.0445106468584028, 0.05924506105422493, 0.022145504725255796, 0.02186281636597649, 0.019342161099156065, 0.03093893771179982, 0.06553759618151574, 0.0316880778559754, 0.03631300428101132, 0.05131164603235741, 0.11579304828398651, 0.11869433816642531, 0.07203692525264717, 0.04011972582027797, 0.008409638258237994, 0.0558108919029755, 0.012096568544004715, 0.024767222311047297, 0.027750590853693507, 0.0229722342544025, 0.11984890161622917, 0.3520148577949693, 0.3018274266392954, 0.3115595624812188, 0.3257350389274859, 0.13572841041511105, 0.18148218431780416, 0.3555919674615706, 0.4130107783261807, 0.7904736060769327, 0.3975776919434148, 1.3616961577246267, 0.688530347279964, 1.0767867103699715, 0.7213953966575285, 0.3276783281997327, 0.10488608596666206, 0.07721521996802862, 0.035862686307800394, 0.0335046332029085, 0.03101997449243021, 0.02057728443985745, 0.044916976063001546, 0.024803238019587535, 0.007747989185454865, 0.06810887836881223, 0.01117806742718864, 0.027733074253304835, 0.06556907473432441, 0.017994106822316686, 0.04702663281932474, 0.02665126234323027, 0.02444060838540956, 0.04121226679173209, 0.039116679240138306, 0.06476524931889388, 0.07042952723080112, 0.054759991640645655, 0.0388705198683085, 0.015277420189381849, 0.027337217470631007, 0.023627953806651697, 0.0379359960225561, 0.09160137059347284, 0.03322852362367896, 0.034068558184850606, 0.026994157552478776, 0.02084851595422914, 0.05930321478855707, 0.005064969243962439, 0.05879296192659005, 0.015059042038516173, 0.08560834903149836, 0.08618051711950572, 0.03716968210233796, 0.05041232775716532, 0.09893649392911504, 0.069655878018708, 0.11033146957596464, 0.054422399675052975, 0.017137607116432443, 0.038405155928264705, 0.021750272304240256, 0.06406300716222295, 0.04922790220007301, 0.03058738187856732, 0.045777235345374194, 0.06773398558218634, 0.09267577826375924, 0.022685037467688806, 0.01658594911737788, 0.017145700835352464, 0.02901234149542307, 0.06282128971971332, 0.011496611574153987, 0.04605046826444807, 0.05537066330772735, 0.02047329758023543, 0.036802480838471846, 0.09203995593012342, 0.015172847272497753, 0.1153388500754391, 0.04884346395791058, 0.02499078783477026, 0.047396082551248615, 0.013653956346153734, 0.04965434121268411, 0.0072439018948634555, 0.02806105181544779, 0.03926285647697026, 0.03031137380598774, 0.03721349850116718, 0.043330530545884566, 0.03852637019008398, 0.05196485473143478, 0.03395704259615272, 0.02037068967887711, 0.023310178620440346, 0.031606688674899845, 0.03484404983840162, 0.07717762803358418, 0.01980408147398022, 0.0341195298448926, 0.03994854730403712, 0.0009348755279901408, 0.09616884808506697, 0.04099200502218258, 0.06371132300926313, 0.002134665217806375, 0.035224523575555895, 0.037101488785758134, 0.020147235237903172, 0.04823421721436805, 0.02638366974649891, 0.026999045193435687, 0.015346775086776865, 0.06195803886399635, 0.025012720932042407, 0.027463648791214632, 0.09419231825778562, 0.01965332686180069, 0.03370854665615386, 0.08887181464102, 0.057157230142864494, 0.07064884288176414, 0.02007675323364956, 0.032398091974638166, 0.011190354519884193, 0.040579508809793385, 0.10421571306764119, 0.02018016361210856, 0.012252499037722667, 0.06316828541457653, 0.04147187866751225, 0.026853431031228076, 0.04015861627375407, 0.04410837408936313, 0.0503868208597264, 0.02460716356102738, 0.0554161842521881, 0.017165850862980853, 0.011409460454277936, 0.03231081923830413, 0.08776117101191513, 0.031317854375248, 0.03281952843310372, 0.014024142480094828, 0.045548692165363225, 0.010578874630042383, 0.09530583471660653, 0.06490912063107376, 0.03849356247472667, 0.03909582632683939, 0.02975957216544738, 0.04771596639447155, 0.12170098046021116, 0.05126091569001156, 0.028507966443055102, 0.06067938449221754, 0.008606911644399648, 0.03191996884021548, 0.011799564874250323, 0.04098651217176549, 0.02316695465255649, 0.03366314062488175, 0.04079137425569277, 0.08416222783947185, 0.07623049055015849, 0.0374214683899716, 0.019838474991340792, 0.033033523603432605, 0.029197730942659324, 0.03221221989200961, 0.08539179129706276, 0.03438487971922563, 0.09571641953962465, 0.1953804748313081, 0.32462225025219305, 0.5826172208593738, 0.615345232429043, 0.6179352837704843, 0.6200526282191277, 0.5515009969953568, 0.6043030862366, 0.8963661400541183, 1.4152894625740668, 0.860678393754267, 1.941991580590125, 1.159628271575897, 1.2275699742378727, 0.7888835139812962, 0.48691433043249194, 0.06905318898779732, 0.060284140579883135, 0.027565843005093838, 0.015469743689942746, 0.022117984931795828, 0.04666798492713321, 0.03423533935640608, 0.04987164971328551, 0.04674911746875413, 0.06225307847583487, 0.06700390379034704, 0.05134436564760343, 0.03348088064681619, 0.016742690706685666, 0.07320636612994057, 0.03866798154288723, 0.046831782186223615, 0.028287189479376522, 0.014299310728787415, 0.059274532456672004, 0.04752598425012924, 0.12081064073549164, 0.050532795083258426, 0.0654978055747286, 0.09216613827213165, 0.03253882232632849, 0.08714826236809455, 0.11010277700880844, 0.017684383220189524, 0.030766384067734888, 0.035311976342552134, 0.0332528545761541, 0.04493229782148715, 0.06394838891743172, 0.024754752314859824, 0.03416317004349924, 0.03923263047791777, 0.06131827117755048, 0.08127726329069945, 0.08962710072556812, 0.04472117548087432, 0.06823398818772647, 0.04469372272010773, 0.04288476313494387, 0.05809575679802126, 0.018499466297667355, 0.012737051565049878, 0.14352851847727455, 0.045657170215441335, 0.0615537129793196, 0.07191237467791765, 0.06101604183054259, 0.01866713230077538, 0.0678434748683245, 0.05284615844908742, 0.03543415204471639, 0.015377243361135405, 0.055415069594258265, 0.028457115441861174, 0.014516664237054366, 0.03951026840255626, 0.02455726059363975, 0.019278047200773033, 0.07061492050847701, 0.062077276618970986, 0.0067956561894877065, 0.05252909380942584, 0.01794129272081679, 0.07509665743958566, 0.03602273739694107, 0.07516875397413969, 0.01707278841715907, 0.08680890840027602, 0.03027720628456483, 0.13046849669227678, 0.18931770096382788, 0.11745648563749368, 0.17121734157685312, 0.12871178047310922, 0.18429377296518895, 0.12273139170100614, 0.24720883567727384, 0.178484650809438, 0.1441928392816936, 0.15851698275054657, 0.12777246474739046, 0.19563872307058305, 0.13372620898148707, 0.11482441437340553, 0.174495738240019, 0.1573881215506023, 0.13889627591256173, 0.08538614522906081, 0.10250827162376336, 0.10453126468365231, 0.18307976875334017, 0.1658009467346053, 0.09484808186009046, 0.11733070932208531, 0.0948015190360527, 0.07918926000955605, 0.18762366605862496, 0.08901753222509738, 0.3827051980601203, 0.0787448064394055, 0.15079126182583072, 0.1712113814128022, 0.10294934674616783, 0.20134938760630547, 0.11236045344342148, 0.09267177928479449, 0.0785469718938393, 0.17968477350809883, 0.1954889682031447, 0.07211880472999427, 0.13689896211989466, 0.17334003331920794, 0.08379783045740859, 0.1402126141493359, 0.2045065585163332, 0.12839267420912945, 0.2333418321945975, 0.1491823699325323, 0.16976739760608445, 0.062335160966481895, 0.1492274312242385, 0.12444615694544009, 0.10232475526150196, 0.1321604171948087, 0.13794281820376075, 0.10533947212200974, 0.12422812066131061, 0.08599022087911445, 0.2157565137191165, 0.09642097528182692, 0.13602165355076715, 0.15526166065566002, 0.06578137301990102, 0.10643036600442664, 0.20128996982689829, 0.1346186248044814, 0.24257170547160412, 0.195425842558184, 0.09385537746692858, 0.17944976837644655, 0.078105712910333, 0.15439573615308733, 0.16611375575584753, 0.13814468237180866, 0.10115255646768118, 0.3071138316825513, 0.2302077664963661, 0.18594731246271443, 0.19802799808882898, 0.1270643850007365, 0.25009001575170026, 0.1144730328251758, 0.11219795853380235, 0.20580235027497817, 0.18363876778992916, 0.25185355015339395, 0.32421018687948105, 0.56652496178304, 0.7628693744059533, 0.6514940410852432, 0.5968481927148758, 0.45800152865629046, 0.6753746564349821, 0.8183247019206324, 1.4328800670562254, 1.1759635950288465, 1.8902299000370888, 1.6428977395257645, 1.7304943165471478, 1.0168882567555675, 0.6076009415330426, 0.3941993054843718, 0.20916772856106683, 0.11511737405652962, 0.10773573386212511, 0.17587023787200454, 0.1421881863667119, 0.17173149382635472, 0.09206379658632702, 0.12638838135547217, 0.15784801945330637, 0.21617211641803866, 0.12000419529936007, 0.11622080113738777, 0.10681794520707862, 0.21314789240639057, 0.17578926237840808, 0.11963399863171002, 0.11397686065925706, 0.11067771833510169, 0.1805899370341532, 0.17398811305963224, 0.2493971811547395, 0.12148524243985453, 0.1353892632910321, 0.1495172269642353, 0.09574874078915005, 0.1444727524874672, 0.16965305132250633, 0.10321741623263206, 0.13582858407208998, 0.12754597851345617, 0.10267851168229696, 0.1790163771159226, 0.11535565804449782, 0.10910229682321511, 0.13976557120200128, 0.18817167939437976, 0.22659129523221525, 0.17668737789555905, 0.20801789187375577, 0.1899880278975733, 0.24940694111489484, 0.17822836375524923, 0.1333068984170114, 0.19024115866951405, 0.08167263360754137, 0.15946371420737238, 0.306200593589775, 0.16679542079087228, 0.16525126332717557, 0.16934131482435813, 0.16717595198462087, 0.1806427358138946, 0.12280820733717374, 0.2422013019602145, 0.16211031815938412, 0.10472534539838953, 0.14774171094740593, 0.048558663111180074, 0.11490574226744714, 0.19816621567212767, 0.10770846113202073, 0.15031795738445175, 0.18312328254743931, 0.11780477219050932, 0.18907678163340016, 0.19724099596421565, 0.1350191662148122, 0.17943021781261892, 0.154206543079307, 0.24329017337051131, 0.12308609040994799, 0.1924745501169274, 0.20852320346861117], [0.10580605031141352, 0.09224973378642913, 0.05492632082032581, 0.0484520543156372, 0.018370727137211832, 0.056868533739039016, 0.06745112293790426, 0.08385452096380534, 0.0690552804078306, 0.06414670609839021, 0.0950214245747174, 0.04456579752807175, 0.012866129719411895, 0.061024085753747535, 0.03572814977697788, 0.0409886802005912, 0.04887313454321796, 0.021526572715130546, 0.03318946463085952, 0.02441266532837143, 0.031230066444784887, 0.023484488521071694, 0.06446351792903678, 0.09607944562430344, 0.03901039986240287, 0.056298192770731066, 0.040204493449099606, 0.05967607744218362, 0.08107448747802166, 0.06048952492194311, 0.012428398570796896, 0.06599267539117606, 0.09852329674627512, 0.020397089068747817, 0.006784643675576175, 0.028663304176241643, 0.04077825883042909, 0.05880366800533188, 0.047784876003260576, 0.04533210378741065, 0.018257951333878503, 0.015640362004388966, 0.022282686174636888, 0.042202665260241884, 0.03425109012412929, 0.028560315146140998, 0.09586914682820921, 0.06836744836501538, 0.01380111226030896, 0.06327840672325223, 0.03592478922538219, 0.042898901287586465, 0.07363205820682549, 0.03021221713072831, 0.03936583401575204, 0.0360318883171966, 0.026370142548975926, 0.035123932400658246, 0.06325626295180091, 0.05759554351830195, 0.06342449969041251, 0.00430868293586818, 0.049874005433652675, 0.041702911633277134, 0.09510717279608212, 0.029662175577193983, 0.02663785388933555, 0.056288869480692574, 0.011646042769444327, 0.04392307274223816, 0.016312438491431457, 0.096405707149496, 0.023934704987632654, 0.03325681908116226, 0.038756414902426546, 0.08604990678929514, 0.04413674232519923, 0.026237714675164996, 0.024564758679198644, 0.08476100216108946, 0.0367807277718619, 0.02693101467053977, 0.028626300214279084, 0.09738970878383807, 0.08761136251832209, 0.05828586151643146, 0.03059745593477161, 0.04832266206522623, 0.040312412254993, 0.02536037929296013, 0.04484093417563746, 0.015128432367477688, 0.024571668792275653, 0.010807998121655997, 0.06625419482588768, 0.06491364821070625, 0.017085873198905782, 0.03454741293324098, 0.07354594992413636, 0.00808270832133149, 0.028454550962534644, 0.06647401609488073, 0.03018867333359536, 0.038106508042302825, 0.09511979792507426, 0.03332796566669018, 0.0678583293131763, 0.01209363251203491, 0.034506354450939164, 0.09111021630345814, 0.032622743427993796, 0.05348539753486553, 0.0661585564094205, 0.0300705942866062, 0.023195320973172787, 0.05099966438607343, 0.04413224921952333, 0.048739509657025344, 0.06218852790733499, 0.04454161979318146, 0.021518944394624522, 0.014852777652953182, 0.03356313167680656, 0.052637820838079344, 0.017917306507907568, 0.04201742136971124, 0.029249012868310657, 0.05214722962268899, 0.057589832332826434, 0.026414989336063305, 0.052011655042729074, 0.005317722717600485, 0.03089583377474018, 0.04997248603631893, 0.04749211933343642, 0.06422078297022851, 0.06571623256369945, 0.038870343668085915, 0.0751726916660705, 0.03582135969472509, 0.042408187498128226, 0.023151048752028617, 0.02288515304004954, 0.03548144648272184, 0.04542981830215262, 0.07208158817863272, 0.04648434216036432, 0.036604891441041426, 0.04354615365305255, 0.06950892703307253, 0.020787554507654522, 0.033426595656501676, 0.0076111338022465435, 0.04022910019322749, 0.022940267320542086, 0.02480928436852992, 0.06951373040435777, 0.03232367419367356, 0.13111950288857185, 0.008238688610764522, 0.07070446852594614, 0.0031566873170255174, 0.02547782823263157, 0.017791532107719013, 0.01419580458933788, 0.037215720156147596, 0.06991877641168333, 0.011385451258730986, 0.02727569103421223, 0.034115293378671335, 0.044178704791251695, 0.043260031304652655, 0.06173799542950527, 0.027036436029800007, 0.10226686965794334, 0.020502462547512788, 0.0646288933292512, 0.02698809971221753, 0.0688901961210274, 0.041491823766620896, 0.03812509716578549, 0.02287275582221487, 0.027996901527888356, 0.05309059795352721, 0.0061822505461262365, 0.03453955670157748, 0.0912075707568757, 0.062031112160653844, 0.0498127835171838, 0.028848848756282564, 0.035311509028918324, 0.039585582506392276, 0.006500367120268845, 0.027462062989211375, 0.027501265623516617, 0.055490525424360275, 0.0479777769425944, 0.06861939936155273, 0.06530127337863369, 0.01965836197468302, 0.07796086866648928, 0.04647375865569038, 0.012556665629569082, 0.043248478698754506, 0.02676822481706979, 0.04284912855514596, 0.03218280977659649, 0.007564889383502305, 0.06981299499109869, 0.02934527373121631, 0.040598553755590995, 0.03686479826067244, 0.08383756743804102, 0.02488131578561039, 0.04077444371256617, 0.010360618095634686, 0.005200864623240646, 0.048546742783078266, 0.006238109847125147, 0.02678311182065837, 0.03894016109106522, 0.04844713986160294, 0.05044617735209966, 0.03394667359609758, 0.009340162167415745, 0.02202442835926289, 0.015520156105800022, 0.08746692430107825, 0.01623080607743994, 0.039824249538322615, 0.10740831554416688, 0.01954048977143342, 0.03663152831816866, 0.07335540853560933, 0.04799681805795239, 0.06555548433454768, 0.0254414122431509, 0.01463877099130543, 0.011134662800618719, 0.036822916233852025, 0.06710838286146041, 0.022190876282571305, 0.05743656878269488, 0.028688385894882585, 0.03747528223621269, 0.10292557503787741, 0.016842312780359102, 0.031181835464292, 0.0442464461159562, 0.04895425559352002, 0.016409702929517916, 0.03639519019352813, 0.055198439081469854, 0.05858106966761332, 0.02552653035719789, 0.018778283997709234, 0.0767075794658834, 0.04982779501006008, 0.09543753289166959, 0.06930101843130204, 0.01707226556215075, 0.07813346827582968, 0.07633842467781037, 0.06891962155819902, 0.014135681051430444, 0.039747303667207884, 0.11610442472081031, 0.0929613222157763, 0.07490112115779231, 0.031766377787496296, 0.01599699029729011, 0.018955642928279216, 0.0848530016599163, 0.07615120811087471, 0.04912329672445213, 0.029345886601555734, 0.0096507792195846, 0.03206861288016362, 0.022895089200427456, 0.027418288725217985, 0.009407263808703471, 0.03101596210692679, 0.022291059515649275, 0.048010588488391334, 0.04445392570848908, 0.05203008711818726, 0.019712373088564605, 0.017402891873291904, 0.018400380485540917, 0.016947785850554224, 0.05202142266376365, 0.02440829862720303, 0.039579986234105406, 0.018665318587614645, 0.028289989530739766, 0.020526711145536076, 0.028146769393295534, 0.0552249533845292, 0.011394084112027721, 0.019713413052921815, 0.013019432531549566, 0.060302741194684664, 0.03878678645818465, 0.04404638225453035, 0.05663185470527219, 0.023691770845964074, 0.08789086203661658, 0.03224033531883071, 0.032082555680385524, 0.02105145839103047, 0.03577080938304144, 0.03807412167530387, 0.08344270273922913, 0.03543566506836684, 0.095075364825466, 0.046114019088206754, 0.03603653464045736, 0.06961139129294504, 0.04630341900572662, 0.05353040136997739, 0.0391627096330687, 0.06205918928307872, 0.04250095308487935, 0.020728613617980195, 0.02650795219045493, 0.02922743791714311, 0.03963074338952861, 0.033785990484419375, 0.02809903828517324, 0.04086865337505456, 0.04819659463640663, 0.01196345310628174, 0.049344688473689946, 0.051922149160095764, 0.08311637992700262, 0.013468711498013188, 0.02688897751091469, 0.11791994584904564, 0.02299863938993264, 0.029229021803926558, 0.014884898762008356, 0.06452862008084213, 0.048775849037713585, 0.029602723323830196, 0.07336876910900877, 0.01931537866532322, 0.024900347324869326, 0.049740851691533486, 0.06414635369794504, 0.018651574970253052, 0.08228914286460608, 0.029639154635069352, 0.20917637003285272, 0.15137286045618598, 0.11190784869775658, 0.0721927245538081, 0.11896482082985102, 0.14909757932107295, 0.1262288895105162, 0.24068358985166396, 0.11740189421200946, 0.08788777470228173, 0.2516273856763878, 0.18441853804453728, 0.10498487300449803, 0.14441829895780933, 0.09256150092809431, 0.08255854534405856, 0.14015550995546003, 0.08711873733949277, 0.07571390214105768, 0.16503416933119297, 0.3469001483773032, 0.1202122571187154, 0.1964413533888517, 0.12215438193731731, 0.08999983314424755, 0.2319384510478666, 0.08461793524123008, 0.12142604682594539, 0.09072502729512992, 0.12427007163604423, 0.09903272223328391, 0.10598196708146604, 0.1784595384472801, 0.04370486791876536, 0.10042147876154031, 0.09127717750567584, 0.09928352409793485, 0.15211814143244298, 0.15824093062791134, 0.1780120664907079, 0.13270941112310658, 0.14393926417875674, 0.0710787637639911, 0.13632715409321172, 0.13960268558754077, 0.2161958191784159, 0.17571081497496174, 0.12300642492670207, 0.07506769931604786, 0.12051728268664692, 0.20618983754707923, 0.16318824983412222, 0.21730526771035888, 0.20010863160414083, 0.16222838763027422, 0.1321745898214079, 0.09612499721228115, 0.10842501381111723, 0.12394901184785752, 0.1331755143379973, 0.2089345926839498, 0.0882734540068815, 0.1460459446834941, 0.09231895749126712, 0.12161770670284187, 0.1070079043687832, 0.15486925509908508, 0.14157370724264653, 0.1517177992049725, 0.2504752047600285, 0.12867192857928816, 0.1893108521377848, 0.17906914525214704, 0.1572236577950178, 0.13640639822809927, 0.1916997594338271, 0.1566123809184759, 0.13149566738115204, 0.19869550581901305, 0.153758856618116, 0.21241111500609308, 0.14300583200829645, 0.13981354362781973, 0.1565693880641653, 0.11639216734517006, 0.13265639783874636, 0.22653756182520624, 0.16230067568680934, 0.25052971957672027, 0.14570108254350003, 0.21852333218820635, 0.141434800180216, 0.12809527121604453, 0.14890624120110466, 0.10971351241272305, 0.17218097293328855, 0.14898429023883036, 0.16777990506060664, 0.11240240441815508, 0.14927912683736894, 0.12389124881836677, 0.19886563862523726, 0.11844453221607594, 0.0954059470865515, 0.15749598673034101, 0.12805407866835594, 0.15127846310215612, 0.23126567263276349, 0.1441619506165866, 0.1696782096499397, 0.10003864164313964, 0.14470818662835708, 0.17247455314763133, 0.07792212760015842, 0.15586984253698782, 0.20574175272016756, 0.1258855825290084, 0.1776369285559462, 0.13359028966196124, 0.12307828397399957, 0.17022936394618404, 0.24982237527447365, 0.20573508775522634, 0.1062489334013193, 0.1387095649636561, 0.16114279507629334, 0.204011160099218, 0.18766373245706483, 0.15832794289435112, 0.1236657508378548, 0.23108637741496488, 0.11146338746672678, 0.14566069438813195, 0.1362402797225983, 0.0994426022554117, 0.167585747737077, 0.14833588874147785, 0.11176071385101927, 0.17268417012547294, 0.13815770586652143, 0.09676528583851554, 0.1414321341942395, 0.17410305689179129, 0.09841498723554035, 0.17255713742586876, 0.1539737136373597, 0.1566646434366703, 0.15584488339241476, 0.08027692866181174, 0.11365249137123747, 0.11421549704767044, 0.13930763448438338, 0.15990390832866394, 0.09379023701072702, 0.11096215912050779, 0.058886535736101295, 0.13067538639710796, 0.17551851158420886, 0.3114476523572399, 0.17934038634261779, 0.1626025756160098, 0.29058490248937763, 0.07563611357322625, 0.07091819939594116, 0.12824257460212515, 0.19019589819494756, 0.11348360728832985, 0.1560173144624118, 0.1137505736081831, 0.10775334622350433, 0.11528985875268137, 0.12462058750491951, 0.18793402359850947, 0.08791693200867984, 0.16187640087258431, 0.14025985113074704], [0.02703431588146956, 0.03301548606325542, 0.09308603366896992, 0.027601232436755975, 0.059778147166775125, 0.04241317090007567, 0.06844878391993624, 0.009079577359971742, 0.018078456933219588, 0.048890796700312246, 0.01194348693975518, 0.053552633241540006, 0.007645693943730646, 0.03180625840961453, 0.015202125237743943, 0.030107575265931028, 0.08127167084885221, 0.08553600734880856, 0.030039651995344512, 0.036712446355170784, 0.09148281848719043, 0.018903765369266756, 0.05233531186897909, 0.0473732607919843, 0.04969099851986093, 0.07191356977507954, 0.053930356723046115, 0.07102943536254668, 0.0672257322097017, 0.04093026599636482, 0.028622285913555857, 0.05608331276884964, 0.03374203618976378, 0.02071350636411338, 0.029844316811631286, 0.05325713397694692, 0.07650835064029501, 0.012486630829141266, 0.03354411737452592, 0.024191208461660053, 0.08278454128172129, 0.07172404728349178, 0.020224267293909387, 0.06412253985481878, 0.061906262811633854, 0.03255676793595476, 0.00973960136874549, 0.051631790345474604, 0.025756519528165944, 0.06145234805561843, 0.02197991865086219, 0.09163645742040488, 0.04346808163268913, 0.05043157571626287, 0.083946987776266, 0.050280809612764474, 0.045202696215241187, 0.036481765789851066, 0.0355982902129331, 0.05955194821581245, 0.019530563187154553, 0.02152917932929291, 0.031807700570131985, 0.0434724253512198, 0.01336866616076159, 0.042625882873131384, 0.047255141525379116, 0.0105053378501907, 0.04800350217509174, 0.016592788367321896, 0.02984446619877652, 0.094157308039646, 0.06053508800123969, 0.023059547210352558, 0.03263284429727543, 0.05244213516914076, 0.05333989445540694, 0.05878163914706919, 0.060752683784812696, 0.024058929974994352, 0.018335263011977077, 0.018513066273543145, 0.030313811880806764, 0.051803386379634185, 0.07626340934826482, 0.041658413416195306, 0.022308334798341798, 0.08750828538811015, 0.07345025022063525, 0.029841342475265268, 0.013932058711596315, 0.07449910119776765, 0.05409738304273737, 0.0650814444487614, 0.06925976459657954, 0.022806385794894832, 0.0302501576351783, 0.0029079591566246125, 0.016008845507918347, 0.03373295421742144, 0.026873667243747946, 0.03316606447521237, 0.04177588533850447, 0.05553779304928838, 0.018764890865573, 0.07448842193210319, 0.07658058507067543, 0.036136555079851425, 0.009514476856096618, 0.022178128579511278, 0.013073340223561372, 0.06577761152819281, 0.0662596034066331, 0.01730749094408126, 0.040288479668238474, 0.09408199393580999, 0.06557744041445755, 0.020844541873121937, 0.024442523605220264, 0.03291203738040021, 0.02541202319515569, 0.02674268536089409, 0.052723576720323295, 0.03889904515216908, 0.044964779949476646, 0.01946508373704649, 0.058567946581470395, 0.03892300072156134, 0.06744018320234553, 0.059963666848958506, 0.024144423472124244, 0.05582601830904042, 0.029065812517318036, 0.07667954064785473, 0.047628337427252726, 0.09275064803659917, 0.05288122612382135, 0.01095676760850174, 0.036740148094512766, 0.007403499076908996, 0.02682561820913707, 0.018334443297898097, 0.0329568688457291, 0.06279647996228549, 0.018390107246476318, 0.07013014773087156, 0.029494015447374795, 0.02574170147249055, 0.00895586565151931, 0.032734753143402844, 0.03629015187823004, 0.03465704394564514, 0.040792550200656544, 0.014812498665114325, 0.04577271159618132, 0.09830760469119396, 0.04076088395630641, 0.004951482415274387, 0.061136964978950645, 0.01862481551905794, 0.03677022470642002, 0.014186803056227585, 0.05319107038479659, 0.017922153929248452, 0.058606254808124036, 0.0547853414900601, 0.010327089300018646, 0.045521270048113606, 0.0408821365225219, 0.03073675561726334, 0.11153313211135327, 0.007852279607416883, 0.038302940646967584, 0.020991699702496973, 0.03767770564844532, 0.03411078878167657, 0.027800809832349904, 0.05268604990335242, 0.05695736546429896, 0.0766275615821923, 0.02392234990463382, 0.028893126723086162, 0.02248391448970764, 0.009847803627170864, 0.03328149860364295, 0.03040219161419138, 0.030472371013714906, 0.01302057496016665, 0.019805188471030806, 0.036246052026868834, 0.056290934087648514, 0.0590751389221799, 0.028198528208679734, 0.102187633183935, 0.033040766964756677, 0.03590012502465998, 0.06013058591634036, 0.07168590376574187, 0.048454532610072244, 0.009309431507943139, 0.024118801661496683, 0.06487502971844328, 0.028920941460396976, 0.08281755201037853, 0.016071773885238557, 0.021229363159246502, 0.05153075867002049, 0.042067002580170675, 0.02475932777498759, 0.019595931554513595, 0.057764293535822825, 0.08153266934377533, 0.03802701109840024, 0.016233004749782624, 0.01793200198951508, 0.0034071291203520474, 0.0560341414154297, 0.07197260451052459, 0.02102154648802694, 0.03760921738801464, 0.012727644962949619, 0.005342006268385317, 0.034777503610859, 0.15760864762048568, 0.08372802452574815, 0.03758557208423172, 0.027121035119278297, 0.05487704987547571, 0.03135723320977583, 0.03778996817286938, 0.08083417335705412, 0.06203107768669725, 0.008917178211343146, 0.013098434391131085, 0.0609240155186384, 0.018843073968685443, 0.08170937518438987, 0.033839662604394465, 0.06588108702412536, 0.02749388053592655, 0.028269088736945586, 0.04054381677340116, 0.033835924095323974, 0.048162047901461204, 0.025042757324333635, 0.030505780108092777, 0.027122063592316645, 0.06026120390743018, 0.05506535045682423, 0.04155159394647326, 0.014769298009454243, 0.03453093821242933, 0.05413594407840602, 0.08189497530580529, 0.03123529691008791, 0.02368600603433386, 0.033290959789507815, 0.02674145770499543, 0.08813319096882498, 0.0738771450555613, 0.10362996990161558, 0.014082147784891629, 0.039639859835827546, 0.031731687411065065, 0.04206506054728262, 0.10358896121502885, 0.03426026402702255, 0.096332254639316, 0.009027165454632093, 0.060955513223645195, 0.028017151146946896, 0.07751411683256589, 0.057390224293715535, 0.04529090357884284, 0.012336308099029046, 0.08048483726358222, 0.06523418705910444, 0.012529994278485257, 0.03777878711961451, 0.05219558126202995, 0.06199615939910855, 0.0652985001403478, 0.007881735209300514, 0.06139467695667859, 0.06396094126807106, 0.028843252483995694, 0.019921252706779108, 0.07586423923531849, 0.034335865413830165, 0.0741853881927748, 0.023612065143102122, 0.06317668173822664, 0.02432427218844814, 0.051089545651789636, 0.06785144218273702, 0.05725694797752846, 0.011915920223409851, 0.011141752944357935, 0.04672512359496567, 0.04620817512454045, 0.030758412922882748, 0.05232673934510639, 0.02504187249278109, 0.01940180487450092, 0.038924712928072105, 0.06111962457878455, 0.02116374198287245, 0.05957329525582253, 0.021589748155806335, 0.02598231819818818, 0.08325104286233265, 0.049379675709191835, 0.06208386880555942, 0.015290867905282687, 0.029195220089487495, 0.04052373760890576, 0.027504699612637202, 0.06232695999525248, 0.03325876877492955, 0.02234283173757215, 0.029820548933780486, 0.07083966006194392, 0.03947197166722148, 0.04069129635970439, 0.010799049257090496, 0.02092570505825983, 0.06823183548065924, 0.041813281920528224, 0.022043862094682072, 0.002889153852705814, 0.040519922491042845, 0.06122208883865707, 0.06077496545209039, 0.10921138008275341, 0.02189426236004839, 0.026345775207324375, 0.004550346807997313, 0.03980709299925835, 0.010405097160518411, 0.012039254633559576, 0.03166370668388423, 0.03921745044569816, 0.06714138592923842, 0.12654132314867553, 0.014431300017261698, 0.050784979736612695, 0.019169808553171255, 0.062496533557291956, 0.042306110112657475, 0.050893285416907845, 0.02803138697579984, 0.00926759161595856, 0.27692947716962907, 0.22674481925224105, 0.1272229039140286, 0.11056498083616458, 0.1766770969956152, 0.06682208048239832, 0.11830216243622765, 0.10589115501892184, 0.13142904837525662, 0.12506083525236578, 0.14858411655070322, 0.13934904919757, 0.16001854572565327, 0.10762796061293733, 0.16864409820447046, 0.3245633227690574, 0.13050301661414485, 0.28021731203602207, 0.11947189442693226, 0.11577446299094347, 0.15419310589711513, 0.17654108574553845, 0.13026039656852523, 0.18449044305711024, 0.22173645816022353, 0.18079106575779377, 0.12158818167424011, 0.43712995345554045, 0.16317882695265357, 0.12878471204350073, 0.15698773335785637, 0.17332150931319884, 0.12369501539656233, 0.14149481550820414, 0.18555044827442016, 0.18119718428821335, 0.10314712000470008, 0.08920418188696908, 0.12001489754766227, 0.17449978318425918, 0.18725906949370139, 0.16078618114754079, 0.06637223365326082, 0.19430183835567968, 0.14468148080331666, 0.12945696951881533, 0.12603098601703683, 0.30476770273620085, 0.118741781991576, 0.20068180326732898, 0.10036578416944512, 0.11898442501983336, 0.10127094769549948, 0.15646149224090963, 0.23371405899524691, 0.2108569371123468, 0.11379483816844803, 0.08353140039910233, 0.09252188652152978, 0.09908417269827859, 0.10240940797713496, 0.10629606313042103, 0.1959817006342834, 0.14164967252121818, 0.11764298208178052, 0.1273500438659422, 0.25823831077544923, 0.1190721650698012, 0.23647185294858872, 0.12239827368889125, 0.09083183527353311, 0.196319667982959, 0.16157359695963322, 0.15678300402097164, 0.10351894843962886, 0.12907908898928475, 0.15227270733204581, 0.261269751335344, 0.17893989089756243, 0.09494267839698062, 0.0975110417892856, 0.16665610004096262, 0.16952416469012538, 0.19900641494220306, 0.2669045731665627, 0.10446269981442921, 0.16968703498282742, 0.22190007921909133, 0.15209290649621718, 0.2047909609973431, 0.13728959035248528, 0.2276579807362249, 0.0844438877257128, 0.1746929139499703, 0.1330667911397834, 0.22114341417627953, 0.08156437006208204, 0.1365676597361603, 0.17598881296092467, 0.14153930989484634, 0.14013378370192744, 0.09719097025452123, 0.11288224358952816, 0.11307669968734826, 0.1746814226311061, 0.1513916755756063, 0.13385454403056254, 0.1421054641926481, 0.20814448024236387, 0.13050165297763963, 0.06691088539458091, 0.1635140670283187, 0.18396478416698595, 0.13615613262499535, 0.1746031590887616, 0.20122973999429136, 0.1632921773219301, 0.14270881972005292, 0.12700094525972683, 0.13258061642127653, 0.1645491743880895, 0.10805802705186991, 0.1103170364794712, 0.16916644759476188, 0.1062401463728278, 0.10006173153317745, 0.13857723093561589, 0.07438467830539712, 0.24587621041122945, 0.11712064035236837, 0.11024628059878466, 0.08944208283097514, 0.1401556478512864, 0.13693579562729405, 0.21637094687790642, 0.19985559276275097, 0.1058156417322255, 0.06862031100618263, 0.14017328319530334, 0.1907364191908029, 0.14127186860048002, 0.08977335457119251, 0.08050732960503909, 0.15035989303742686, 0.07140750741405834, 0.14726160364525934, 0.14572904475273626, 0.16120349988341331, 0.20564187017659988, 0.1520423140496977, 0.13183285332014485, 0.128821668124968, 0.14968602677747128, 0.26157422531997004, 0.1415062455400344, 0.2604835612639304, 0.11800522675677655, 0.2580453791925984, 0.1658207730900857, 0.20215430086658848, 0.11934512985810158, 0.14478761462434647, 0.16536248397202263, 0.10722885944790418, 0.25533563427386746, 0.15033974492501828, 0.14497676173285132, 0.32897966643494947, 0.13359822633285678, 0.13790489685150886, 0.24358854929526008, 0.16629580889017354, 0.08096203343161652, 0.1109899910947969, 0.14318733355931698, 0.208444633491097], [0.07579818713448702, 0.039702426236603534, 0.039902045767033295, 0.051440019385829094, 0.0869435253703306, 0.02000912107647427, 0.048981938180663896, 0.01680794607607588, 0.05392888966467112, 0.07389245149228843, 0.07420213487479957, 0.04375489346022087, 0.05467241246914191, 0.035392392591963855, 0.01293560048760546, 0.05042324834052594, 0.028631164872598265, 0.050925985879955754, 0.019136838044130036, 0.04631335516610453, 0.021525266535219648, 0.0274077320336214, 0.019890245298043858, 0.08601685009536245, 0.05989215254122692, 0.047375585868834495, 0.011516070207430711, 0.08704140076353666, 0.041489808955380035, 0.054808917845929825, 0.021622935084686167, 0.02832320710313657, 0.07075418763223194, 0.10445626467586526, 0.017013782410011176, 0.03146650416085557, 0.02986585728884224, 0.02409855012721833, 0.014077266847204058, 0.027468358316729148, 0.018632302113297968, 0.043512595171529445, 0.14411048482983344, 0.033335051979989774, 0.042602643595948335, 0.03371858240796193, 0.037443757718128544, 0.05326662963676838, 0.044692818736357075, 0.051569446110196655, 0.009937826619153062, 0.04168444125342273, 0.0069453425878178215, 0.020644897444834633, 0.027557168974571174, 0.04758352511412194, 0.05467063514515758, 0.018793195899155353, 0.00929546285225379, 0.03681826991059127, 0.061787994157883434, 0.024143925514973463, 0.021995430016109062, 0.04126544478499601, 0.11428704965979823, 0.05172946272538074, 0.07070702725961324, 0.05443662592780687, 0.02189119417791165, 0.04221676893892788, 0.05386286054647738, 0.03303766047822372, 0.06865096218403309, 0.06343403365463018, 0.032045599598918235, 0.057764255231426614, 0.026906417502510934, 0.11122004729845833, 0.003773355058529565, 0.02343922230084577, 0.032360155300627795, 0.0739548187102041, 0.10429426006251767, 0.03641871675368279, 0.05296413215898699, 0.0942557963031915, 0.053443791299697854, 0.020488220973000414, 0.00700394161075594, 0.014054537018490656, 0.05446377608384337, 0.012404492797119724, 0.006221886020108697, 0.08541658190229247, 0.05772767453304222, 0.020132355895193837, 0.08125818004050563, 0.003547939193066991, 0.03383082578018789, 0.004665500356725628, 0.01222849558783515, 0.030525246402248744, 0.021282154278108673, 0.06553814010394197, 0.07163680519067472, 0.02947889670218912, 0.03565724067870648, 0.03530863236876265, 0.04451115630687245, 0.025598986953076337, 0.036797056935967944, 0.04056076646872586, 0.041237700910818194, 0.026427805987036517, 0.07830290394204278, 0.04675316624343396, 0.03622076729492795, 0.0375285100251917, 0.06438494795152257, 0.052796661508299654, 0.08389213588088752, 0.04707023854397478, 0.048380471059992436, 0.01843436606108181, 0.026872068035206007, 0.015177851741863115, 0.031317574753155636, 0.021909231718088833, 0.06497950878955665, 0.060633652873577616, 0.020066073967985088, 0.0549126461508774, 0.07140522447204398, 0.029360064973814354, 0.033344030530462344, 0.049677894585916114, 0.028654974885284904, 0.06291636506155615, 0.013246068152629081, 0.036328460104883685, 0.038236758311188994, 0.012970173078018331, 0.02678619723977341, 0.025852699951839545, 0.011885364806549925, 0.02535308422070117, 0.04904646576652604, 0.07046101344448906, 0.058730625352191354, 0.02191146103394849, 0.033618565799007495, 0.020231539383530617, 0.03416084879708867, 0.04320839314811653, 0.02473988446346935, 0.13411293016566386, 0.02037117231426941, 0.06562054818195683, 0.059815137722199006, 0.043009260083518686, 0.07231958871406895, 0.058260910032737645, 0.04947275156155229, 0.02862115210342792, 0.05418832150978908, 0.0571255715593936, 0.03334362067342286, 0.05012993625695667, 0.0557506314268516, 0.11392248373839164, 0.018283096254773198, 0.07796245446849255, 0.04084870061506668, 0.03363165824163345, 0.019989501564733444, 0.02685106573476186, 0.07710333282668745, 0.015237010966595865, 0.025348284679855553, 0.03826899146060309, 0.05007383946870124, 0.025223061862972476, 0.058425186096780726, 0.026506655586643085, 0.05175100894825113, 0.0481212230759763, 0.0562150837222655, 0.04177179059854919, 0.018544307339095303, 0.0368415781356875, 0.04021758972216518, 0.08197403557959103, 0.03715201611480406, 0.05969895665804225, 0.03571984155343906, 0.012911927413135287, 0.045403744499649734, 0.042778617822595184, 0.029723558372126955, 0.0197652044270428, 0.09727189212196297, 0.02091188866254543, 0.049026214232247685, 0.05771685737155138, 0.0582757031905555, 0.03802970006701447, 0.03178420082305468, 0.02390913297272017, 0.03495143238274801, 0.09737186659608157, 0.009305650864036815, 0.054519225527802785, 0.027332787567208854, 0.02715911734999428, 0.05763939056064814, 0.017036525645263253, 0.04917535622934661, 0.03717876024424069, 0.12263035236467278, 0.059979429108000575, 0.028959418226393963, 0.02266456568313222, 0.028076164814974033, 0.015003283286557324, 0.0589957454001471, 0.05660120352742173, 0.07810989575039956, 0.020206066960048293, 0.04914819075155163, 0.029586281161755327, 0.050646440396385814, 0.0669408241106618, 0.021471234353920145, 0.031453080385202364, 0.032926451324695544, 0.026576273826762076, 0.046246874056035475, 0.022968972635064876, 0.02559063276426206, 0.027396575878224066, 0.0983264581150105, 0.039870310574769974, 0.03636153212057487, 0.06674598496887954, 0.015532931579547304, 0.07230772201212184, 0.03672207608037899, 0.019868865699296998, 0.009294334787785286, 0.01423483485386016, 0.061852786044079455, 0.06552832651763194, 0.017447054926906864, 0.07630483938320991, 0.04485841630206955, 0.022677855393398675, 0.047487518975451115, 0.062445531253732985, 0.060873867403115, 0.021901710649892207, 0.047808678355067975, 0.04979086957210976, 0.02801087688684704, 0.01159575388526484, 0.019724904371786024, 0.011089095890882516, 0.03890165368155126, 0.06034034845088759, 0.03090561288709362, 0.029103854528417992, 0.0036638794183325506, 0.050350362735409895, 0.04850344732403756, 0.05405423697084189, 0.012595057168284492, 0.03549808208199759, 0.009029538411977551, 0.010757758075581684, 0.07684873882681131, 0.07122366929486876, 0.07760266127485423, 0.029016568385545286, 0.027196209412068132, 0.060638375805630806, 0.04707220355950056, 0.04915998850558554, 0.014650005670715005, 0.03728130877378487, 0.012268010402969536, 0.052813293277135784, 0.030631757521581267, 0.06296214264547152, 0.03461080287853557, 0.040229096362787875, 0.04590677315249078, 0.05282909384057407, 0.03300393345735727, 0.037784337426625916, 0.10968985561762126, 0.009548573514386531, 0.03946336466939219, 0.027541829979107268, 0.032931457709280715, 0.051772976519479874, 0.011206305428077618, 0.018833553411006447, 0.035627512636804776, 0.06360885874939061, 0.01001846599167273, 0.014474312023770426, 0.09988669576423784, 0.0714408628822815, 0.010724473470491509, 0.005907203913891629, 0.11676862295116149, 0.030891813728357517, 0.019334555761287772, 0.046565463210666375, 0.05064862374697001, 0.06990208335581326, 0.02597267123600168, 0.018020333842404427, 0.04364330509317018, 0.05659083069692697, 0.059329077916880774, 0.00908518608118738, 0.03526014283359532, 0.016043231364399675, 0.09831477527416523, 0.06041723303496838, 0.040522883420870195, 0.1063501259552375, 0.06747323989627824, 0.006045373616695044, 0.03671321244309506, 0.047279070281694015, 0.015636978768593362, 0.10916660224357921, 0.011709640516088375, 0.02621721607753106, 0.09055476425395859, 0.07281427466941458, 0.002397963412917189, 0.02982389673800959, 0.02484747959721473, 0.014603459126045628, 0.02881697375297306, 0.0114688016248927, 0.05807974172996418, 0.020083132830839005, 0.032603395877466086, 0.022954786601927013, 0.3042397762258207, 0.12267643255331825, 0.12498827140417793, 0.10378501077573146, 0.20395397929654968, 0.1347337065324668, 0.1905599125330487, 0.13040249055672076, 0.20147194635243187, 0.28794364583107734, 0.18876650070230808, 0.2351057649620118, 0.25646311651554804, 0.17317561552889887, 0.10021608292816148, 0.17544357286345574, 0.08731926851455243, 0.13911220545489944, 0.22688928811300188, 0.128661984758031, 0.1686993178220526, 0.09485398073710742, 0.14357312011622614, 0.13896277234438928, 0.1718209422523937, 0.20454035831555245, 0.11436398787003373, 0.15893967942364756, 0.15601446461533347, 0.1479534116844016, 0.10235932880952474, 0.10476227083633985, 0.1493863944685267, 0.21518343398647927, 0.10038870552013959, 0.09166123270387612, 0.12366553633323601, 0.12368163184052515, 0.12220027060398173, 0.14221997901556954, 0.1373834514449681, 0.19333734898076904, 0.1895125324447309, 0.19862384595457586, 0.12131496407692471, 0.1204633730794153, 0.17216096271670636, 0.20283106293889785, 0.1411044477455078, 0.12047665704402233, 0.1889575017435897, 0.12442254611561376, 0.10444917070168643, 0.1021427097880552, 0.26045598209865634, 0.1395633546335082, 0.1782176232025508, 0.13994711871829726, 0.13828662314241932, 0.19683587334809766, 0.2012944437803761, 0.0934483626136376, 0.10617335882758903, 0.14113884509330796, 0.1847836095839739, 0.11875421559858708, 0.1572956087728662, 0.2146362173821657, 0.16366011403020353, 0.14432474430049622, 0.10918326465593231, 0.10690982213183757, 0.195663268527677, 0.15588876490871753, 0.19726941782620647, 0.08180004169022845, 0.08843965678205414, 0.16058782566218607, 0.08958164872902055, 0.07565631531178951, 0.15597231445773957, 0.14918482141389003, 0.17610915005207065, 0.15786760066065098, 0.14748490295342861, 0.23810052523209205, 0.10732232983554564, 0.19763315637265483, 0.07880158121547393, 0.10299995451444581, 0.18537319085050016, 0.15071958663963503, 0.11395416913493989, 0.16025171224628726, 0.14291235395977575, 0.14133514746302558, 0.1333713876984773, 0.12248573028632712, 0.1057269057679561, 0.10985721518555958, 0.13626119392293115, 0.12952495216121598, 0.14803328401138707, 0.18179094839480617, 0.23345219482096935, 0.1529335960625641, 0.10282769964467134, 0.11909779071086839, 0.10647922709223726, 0.14549204779248084, 0.12491055944513892, 0.11009835668148533, 0.15344351950672366, 0.13448269016319706, 0.1620973559517053, 0.1389645496683736, 0.127067840057275, 0.08405675285405691, 0.1780525925419023, 0.17446085059594724, 0.1255043695170072, 0.11305112001155654, 0.19691818183468235, 0.18221341524152987, 0.10283335337355252, 0.08893663334029336, 0.10364213537785316, 0.12233996673697427, 0.15321108843049697, 0.13550831335446528, 0.12207845496314189, 0.2210969126392757, 0.20500106827145625, 0.09142249672403259, 0.2110730351940278, 0.12098449672902785, 0.09084980003535749, 0.1075693242432129, 0.13591126028087833, 0.13406383925147597, 0.20317089954210868, 0.1513334375716025, 0.16808634023031882, 0.13260805769072426, 0.1728666063037611, 0.14546843696265452, 0.09625923879925283, 0.10522157885134222, 0.24006929458870044, 0.09997643530368806, 0.1419424560041197, 0.14965901451726116, 0.2083159920068518, 0.12338468083931554, 0.17357742864518397, 0.3281569799348232, 0.141044064695316, 0.18457105082850303, 0.1581977385907404, 0.1519716347778036, 0.11458364826056266, 0.21846438938331222, 0.10884875236379524, 0.1440801783915489, 0.19340689444253523, 0.14499314069267244, 0.1400553669419981, 0.14447004053621523, 0.13152670926384388, 0.11396805064812784, 0.15511408147792663, 0.1920354744840053, 0.1388834209571923, 0.1460462817621808, 0.13299681666877963, 0.10840674261412314], [0.05732149088514909, 0.02384223625995219, 0.03431719202067583, 0.004638162030342726, 0.04319356551634208, 0.03464511978710371, 0.04686071732712369, 0.07647363153556663, 0.010592542596221452, 0.022853101836517457, 0.04676396425272669, 0.05314855250499902, 0.04870567155340987, 0.021418203832581643, 0.06749447585353929, 0.027860260170493877, 0.04302903664328399, 0.007054399991888674, 0.02715616982670561, 0.0594154734825415, 0.04781591022507318, 0.013491502613760533, 0.046993043694284656, 0.07430485960456633, 0.02328202871966266, 0.048552699116689545, 0.024538694452794812, 0.009573458922996877, 0.12302115679748597, 0.04470714458054112, 0.042656633642412005, 0.0597980616223668, 0.023691770845964074, 0.044636020977650924, 0.04838398357312526, 0.04055395594707901, 0.08780322157807889, 0.0282517310998012, 0.07256952489936545, 0.049810898940890073, 0.03093822333481043, 0.04991931953437386, 0.046976323825337236, 0.03549202998739577, 0.02555328980839301, 0.017574091456950675, 0.018613251421840924, 0.0589850431518449, 0.10637273320988302, 0.03347687783741182, 0.05427830236693544, 0.08249560356019967, 0.024913186958480268, 0.026196564262312268, 0.03388870372286728, 0.03827654891797612, 0.02322357429582025, 0.02759916974501985, 0.03300388366164219, 0.03925785775326433, 0.016250764583087256, 0.022928546175300595, 0.031170501193452268, 0.008876033544149852, 0.024956426876146468, 0.0579429031049292, 0.07168391959801798, 0.01095715256768369, 0.05204730877472509, 0.10255247489699434, 0.028763454850582827, 0.02864686009894696, 0.01743928679535466, 0.02902815355018022, 0.044471289091292894, 0.029273523851448012, 0.04565823890809571, 0.03923449207157378, 0.016644493556551395, 0.10428159662912931, 0.020851342818669735, 0.017937293741852045, 0.03917096806089244, 0.03156124242401171, 0.03367220727546561, 0.036220081646235726, 0.050476614025331316, 0.046815395565523256, 0.04399670145264076, 0.06122742464104968, 0.05556735638228636, 0.042042606510221965, 0.07673000285942709, 0.024389052583325296, 0.06466902867560426, 0.02684238404335995, 0.035938659247251294, 0.017769229373023394, 0.0423321915760396, 0.031638082958036856, 0.030473659956647508, 0.03117853171011854, 0.009608122486350758, 0.055917676898740956, 0.02170240330029159, 0.07846899946490604, 0.037933559862956885, 0.015740427451448578, 0.017272151308134198, 0.03669578011237806, 0.04410865371145549, 0.015335247378736256, 0.019297230042397015, 0.06551907983638587, 0.02609572602405904, 0.06205804781207155, 0.028044588585955002, 0.09180213159490978, 0.04044276977618856, 0.053513072461130164, 0.03909012663268274, 0.039887899953511455, 0.010466743298175355, 0.03182999564394836, 0.04057828689955416, 0.020288099654980248, 0.026102906183129358, 0.06712024956340752, 0.011308373237449315, 0.051042063522242734, 0.025501011968440106, 0.019855307858257044, 0.04377734366684191, 0.056065309702629046, 0.011865085501584315, 0.011791037358043176, 0.01672002599544583, 0.03342183442005227, 0.01474160488860141, 0.07433745664574447, 0.05929977888421667, 0.031995731105487195, 0.03787987625166293, 0.011578037144405948, 0.07746843500964104, 0.04212124160520973, 0.05899557303036413, 0.012932619447970103, 0.03992711216391575, 0.03143124496414056, 0.02982780761686304, 0.047750566755571676, 0.024797630255981803, 0.08315352753045098, 0.060485782582433, 0.02772588451813546, 0.004552730777856684, 0.034033731827812816, 0.057086209961844075, 0.043454567841704816, 0.032170943074649384, 0.01472197675837144, 0.016090531548064564, 0.029230762738734487, 0.04730876001919951, 0.08144004165285057, 0.006903826846786205, 0.05156805183017447, 0.08355998313955723, 0.003436759964848358, 0.02685780730849553, 0.010740249136072254, 0.11186625012346815, 0.04719477379694582, 0.031190892538776806, 0.04696425027965058, 0.04562030223408534, 0.03051105653867126, 0.012464557920822935, 0.021702330521938783, 0.004417085813568725, 0.0829967859411432, 0.031822880602351604, 0.039881947450339794, 0.026056465933159478, 0.025339359755537687, 0.02119837298748955, 0.040519390059935476, 0.08718172508862712, 0.048962314838483456, 0.07503449706540954, 0.04428534039987191, 0.11998783932217669, 0.025257012964556777, 0.02388228159097414, 0.08552822389549787, 0.03182685851389843, 0.017996506592739495, 0.10244286303678829, 0.0489823863420996, 0.021003572150103508, 0.06233688466431153, 0.05820502008822176, 0.024613395686291402, 0.06034176954398714, 0.040960763956630425, 0.02967279547104432, 0.08781895702404362, 0.05183362770044515, 0.02709321080586843, 0.05874359522074942, 0.04832273867401866, 0.043047472549181794, 0.06696540787215195, 0.07557543174874398, 0.03436903319051189, 0.04468175259629085, 0.06561004511651493, 0.05970974700645574, 0.01884388219144556, 0.04911145683558238, 0.030975618001614368, 0.05253115075550253, 0.07307789318503873, 0.05071228948391734, 0.020726169797501737, 0.05797377261783808, 0.03207170787537771, 0.058267084701407346, 0.021111263044839425, 0.04853549278191021, 0.052698609914871, 0.056655017373662804, 0.06123629593921285, 0.038564471572998076, 0.06941407002628812, 0.01642890683855982, 0.09279249175902336, 0.05506333181514375, 0.058445043095778075, 0.03633068175986409, 0.011869405279867353, 0.0692307988121625, 0.03210008760253268, 0.04376389116289155, 0.04006042295405942, 0.04126971189473425, 0.005037845422198335, 0.030436294018140728, 0.019149671932081544, 0.01999678323045373, 0.010552284675800513, 0.025103613433818665, 0.05384512178059067, 0.04541609000654952, 0.022893474670127038, 0.041914474474446434, 0.01475754047503635, 0.051721629476354974, 0.03383157271591406, 0.06659945533160241, 0.05495658895421413, 0.08116684703817291, 0.025015130278564272, 0.033431444993062366, 0.0541672426005525, 0.09400566859591393, 0.06437937849231305, 0.0618786376810843, 0.0905233929534593, 0.10552462025154984, 0.024930397123699228, 0.018762588771360538, 0.04007400569295691, 0.024464709511507424, 0.08356726863571713, 0.09586213712370205, 0.12617815150729111, 0.03595721389677736, 0.05987059099659805, 0.04668494611377678, 0.10348745456506168, 0.024918047786359827, 0.09913845002771386, 0.04276830627913437, 0.07266786760620533, 0.022642569383606318, 0.007456584660817059, 0.007975588640904115, 0.016995235421364347, 0.050609549432392084, 0.014109494250958726, 0.0577357069649283, 0.04158929696366672, 0.04947362490178597, 0.04366162608587935, 0.04059157086416118, 0.011705080377719095, 0.023677521610572457, 0.06775970315380443, 0.018880704207526102, 0.03553968065628602, 0.020450228757615534, 0.022327174815619667, 0.05447140248912958, 0.056774538581169424, 0.043423345928350766, 0.031120862526398514, 0.04768018242752841, 0.03582057062416308, 0.030196412736850402, 0.029980858577595606, 0.02803138506058003, 0.047263602966502796, 0.03958917545875715, 0.10998024890619902, 0.05441235626236566, 0.009453628407490831, 0.053475848248889374, 0.02284885579419713, 0.08212114744369062, 0.013120841505306383, 0.035374109903650905, 0.01037853401935389, 0.011867966949789515, 0.044886321054711464, 0.009522786037245346, 0.02295172033501008, 0.02025902853347361, 0.0132672619750543, 0.03308652922691357, 0.040797640854913386, 0.031695744480877634, 0.0012411219288497384, 0.006727550015409267, 0.05391785033768224, 0.057161313391500906, 0.025820817287650802, 0.062379961788293824, 0.03861098843176038, 0.047171404284815636, 0.04146168203724008, 0.08053929845411932, 0.01861564353138449, 0.013559439290885725, 0.031400363959912816, 0.03546942273275026, 0.0283221211735039, 0.04548097382329645, 0.03052193115675642, 0.008257121643832615, 0.008309753799450495, 0.15965329032511483, 0.14026142927187105, 0.12384276311363905, 0.09970081219029042, 0.13540168923716392, 0.15037015861561223, 0.12364218597330394, 0.20904216675027726, 0.0815214614774431, 0.1581328969088293, 0.09929828661223573, 0.20234032233636226, 0.2126823867400808, 0.12401812063950686, 0.13380030500552348, 0.14126426900827116, 0.20272019469449598, 0.13184832829621532, 0.13126257746931047, 0.176704476978029, 0.1395043965068556, 0.11183264950710921, 0.20645010825847426, 0.13363415585650554, 0.07048139904415415, 0.19051331906549393, 0.09944658591261796, 0.13228141312156955, 0.11638848246225428, 0.17715902758702157, 0.12032514017435814, 0.16523039509211818, 0.11463007318877405, 0.10078267389608007, 0.13511474334424542, 0.14619678739578496, 0.2373357856225583, 0.16733344434009445, 0.1252493158643765, 0.10863829268923691, 0.12143631240413075, 0.16583796410310656, 0.1629886226428132, 0.09058606660654468, 0.2036914256431403, 0.14933417791560774, 0.13072349671875277, 0.20050583287112175, 0.21683758635434414, 0.09197345949829587, 0.17996263359823536, 0.18798121461464515, 0.09693270669348779, 0.12096357486781575, 0.11054724590071749, 0.12445890464850011, 0.1185848029150117, 0.19176666955313376, 0.16667522159555268, 0.19109845702205935, 0.13033662231699114, 0.22428822042720936, 0.11933497153222562, 0.11357315530579899, 0.14010617389313637, 0.17353135611741774, 0.147367385065844, 0.16465034395936998, 0.08472696487461367, 0.19106549991955682, 0.1438478545676316, 0.09547028315043259, 0.09502093427844586, 0.11392264461685574, 0.08101713813601003, 0.09802593714407376, 0.11184301467672472, 0.13122307797593455, 0.10945424527650881, 0.16893223919455083, 0.09138351050956596, 0.11650737164722336, 0.08099085365932795, 0.11473125808181302, 0.16426610490006788, 0.13870671511657778, 0.19392181277996112, 0.14240584726775848, 0.1150231222592054, 0.23682880395602798, 0.1413058522608011, 0.18603456987728997, 0.15934562941472377, 0.1740051968203437, 0.20266518958153265, 0.13021873670720285, 0.1843082060616824, 0.11958503029159001, 0.11331998622946202, 0.1412620933185662, 0.18081905861054698, 0.33072049399056747, 0.0887140311721352, 0.15961693179222847, 0.16030311674600647, 0.19654514298083323, 0.1267401229650263, 0.1416422874336281, 0.14023585725695858, 0.19994291146436047, 0.1341384255717839, 0.057930844881001024, 0.07336772722943176, 0.1816179044544697, 0.09397530853147469, 0.12894053432729938, 0.17428389960719695, 0.18427385467915766, 0.13855760376299583, 0.15245802400092925, 0.12016259929946355, 0.13100028428579533, 0.12885093268367553, 0.181085228198959, 0.16329783105081128, 0.12602350899889586, 0.1288120920259145, 0.11683420773835913, 0.18764934532584684, 0.09137393441051246, 0.20516340230261126, 0.15970314732722699, 0.22036292379902256, 0.21219446534110656, 0.15761765681447523, 0.08883590043912973, 0.1018590580732111, 0.12397014821368842, 0.14749149130957742, 0.1689996549318875, 0.1599662372421834, 0.09518932806508196, 0.21038294319183598, 0.10664577460697583, 0.19333739494604452, 0.10415233461366546, 0.12999631073926726, 0.1423040341826216, 0.12593353963306836, 0.22298383316205395, 0.11442434793758778, 0.1681557631180171, 0.07363496934093776, 0.11113310397993173, 0.11731747898363298, 0.1247924363480941, 0.12805358837208441, 0.13323876255702588, 0.08459795566816485, 0.1108916637097155, 0.16122242225514305, 0.14630975472109933, 0.13516749615871138, 0.16242303525007543, 0.19474888130301432, 0.10838906130483074, 0.20484924496662235, 0.08834710569992181, 0.12573515350419667, 0.06705612800414525, 0.1399791411935322, 0.07538779383344997, 0.17712878243577096, 0.08762198049695262, 0.1295336702417943, 0.09479488471462842], [0.00360864112735726, 0.03270582949382163, 0.06254994903781241, 0.03284513875241241, 0.049975914279780084, 0.02833681665511141, 0.02702467849538211, 0.025174790662863565, 0.03428580922885768, 0.09775957603368068, 0.030552319949492816, 0.038572285669825734, 0.031271161316263105, 0.026867992447448835, 0.014432284440244398, 0.061906458164054545, 0.019184065449442116, 0.040858303527197534, 0.06929416960525898, 0.09859011493503086, 0.03998430062746329, 0.0183792230522921, 0.058058486620505015, 0.043059354572887384, 0.05322248765057134, 0.03875808114366185, 0.09659397325688794, 0.07354496167071405, 0.04502148960807151, 0.05351432118444674, 0.04625286103316373, 0.04769697890526826, 0.022733664898682508, 0.039473369777683294, 0.02384668914601207, 0.036623580155954245, 0.08224935225781896, 0.03524717679547687, 0.016893596621230245, 0.031075483308203762, 0.04825838345793947, 0.022775250066432263, 0.02152827534554226, 0.05206192956275998, 0.013994943996470784, 0.07437102661858644, 0.016512067597960273, 0.05706945561894006, 0.06142013405840244, 0.027943258136210423, 0.03411618970154274, 0.07783289367873823, 0.013204201447567152, 0.06634626327262771, 0.05478894593374384, 0.027854709863482464, 0.003515663430012102, 0.07376204034493816, 0.08880250666651035, 0.012860450135063262, 0.021331034518117388, 0.026457907496801308, 0.043819938155431906, 0.02743881413592927, 0.0788800745841957, 0.015385349528984198, 0.09306575532161421, 0.06803207805440312, 0.013103565265003954, 0.07467965279976208, 0.11130217192394119, 0.021235782976051974, 0.020117581889574087, 0.0787796711008395, 0.04896052985361988, 0.04413073236543325, 0.07058025502990331, 0.12377362367847275, 0.04861811919498348, 0.02340939083707429, 0.01842152259703125, 0.03256215353406245, 0.046507715502934116, 0.05550953589620129, 0.027656136043069345, 0.05432864200443991, 0.027931728512950005, 0.04559594063809322, 0.022036522972367464, 0.03183601134937377, 0.06215715660683571, 0.017698534779370795, 0.02737095789803613, 0.06211179271039944, 0.01836380553281596, 0.04396431891608142, 0.06244466940481817, 0.03553753561009804, 0.05069078922632241, 0.032275866476758834, 0.035333748561360186, 0.04749466657578465, 0.02647096738069048, 0.01758683532957108, 0.05482925748031947, 0.042144281699532465, 0.05995510964684429, 0.012064923367072499, 0.02233977696197408, 0.056142378147811665, 0.090696728007207, 0.016891579894769578, 0.020391375968052496, 0.019862510999965093, 0.03134037544500203, 0.08642305289545367, 0.01812694646838692, 0.040327052195226, 0.04111971570959976, 0.05410635776277031, 0.025474945826816465, 0.07279009693452428, 0.005590808164748934, 0.02212525319097744, 0.02824429621649606, 0.03375086535309111, 0.027614661958068613, 0.10464970953762533, 0.022484312855428266, 0.028335125516018564, 0.06638494305192463, 0.05187642903277471, 0.03736116577901187, 0.09793052089310463, 0.03604146824668973, 0.0328323221014392, 0.038002412015151595, 0.032578475037289244, 0.057402573631054936, 0.01935191722887178, 0.022188934249683254, 0.014571786178426157, 0.017917727856265924, 0.017163792001684348, 0.023578098719759334, 0.022625483707675052, 0.02626370995365564, 0.007963416461397203, 0.05466448728956523, 0.04423958962903388, 0.03614294425313992, 0.0022559563278205575, 0.04407294252286515, 0.03988210832880389, 0.026636961396903764, 0.06436758839915838, 0.018336427465621984, 0.025817685903260307, 0.062398229154848286, 0.0750118132019716, 0.048109249121719794, 0.03374328491308036, 0.061620213241586765, 0.046159900093991915, 0.01342016354864163, 0.04605281249349637, 0.023115871909765467, 0.04193959066704397, 0.03458624593012276, 0.026009749891536853, 0.038954881470530264, 0.08322106584185555, 0.04101191947777425, 0.06777641153143299, 0.045881415642197096, 0.09591881230834032, 0.09400664918845701, 0.03542125878495074, 0.03235244845610953, 0.05516325649354727, 0.067535515183643, 0.050382140062509045, 0.01344296328287812, 0.08321502906901222, 0.008225597125748474, 0.07027768094332949, 0.020794399503257968, 0.05092716182491953, 0.058282463916487275, 0.029485737867352944, 0.026409762701199904, 0.06791129663226105, 0.01568545489722202, 0.059277420608146544, 0.039579706612013044, 0.03907253725394126, 0.06813197591972929, 0.036659547983999216, 0.03858341309692591, 0.07416491066255877, 0.02435703010809037, 0.043530050484884175, 0.03266381723205409, 0.1047321405982779, 0.08380073393064161, 0.04435451430899482, 0.04104642407788385, 0.024586048262614398, 0.004784774022071713, 0.019849104461290186, 0.022179710551074917, 0.024797040368280104, 0.051197429983726436, 0.05792010815874223, 0.03692343463039687, 0.05299412450122257, 0.05750033411107237, 0.04099246850537677, 0.03879031812351558, 0.06494675086991442, 0.04495362953973874, 0.030440112966443264, 0.07961079222901214, 0.006100463478135006, 0.0016774109169472792, 0.02922954657415469, 0.03111011431282086, 0.04261319262666568, 0.034397826605145974, 0.006776075460948051, 0.01046775166140569, 0.05718436880758213, 0.047341609869392655, 0.031827222405662464, 0.016668736408915252, 0.06363237381822641, 0.02697160392398796, 0.016475107686053363, 0.0073804556309515915, 0.12300822523332412, 0.0431057833315384, 0.0464117476686595, 0.016734144995890318, 0.049326474733290174, 0.03783143268177106, 0.022393920226022605, 0.08138770252586373, 0.06571290008122883, 0.04299796028663555, 0.07956628252061144, 0.07021319932274281, 0.028527620428752516, 0.014704985885820804, 0.025918822915804003, 0.0048283677765979405, 0.017677172417602232, 0.03813058618576296, 0.0423179270188895, 0.015264915719237781, 0.0673120856405266, 0.025064937484961365, 0.03798597942917578, 0.02546433550906518, 0.062237224286241885, 0.04512031878074331, 0.062100603996265324, 0.038397330340118184, 0.003568435875481115, 0.09591800025514058, 0.029382758413351355, 0.0688494785478519, 0.0935435566991087, 0.08036031733236967, 0.022164193440168616, 0.008208574652070961, 0.01620750742844276, 0.011973212108827166, 0.032584611401562734, 0.018423397597225926, 0.019355046698042465, 0.012151119749872916, 0.0435854118287323, 0.058794187667268905, 0.035864333396837596, 0.09503657779385967, 0.025464597894179247, 0.07442240813566793, 0.019819684769778002, 0.07694730369914925, 0.012058997676978189, 0.014462351476052597, 0.0831505780919425, 0.07522547512405342, 0.01250566524122992, 0.03351152033334778, 0.0007526511610429284, 0.04902424155584267, 0.014284497461161547, 0.045755754239977374, 0.03608965517712697, 0.039679213772497834, 0.049144050046320886, 0.03444859525188804, 0.11589237158336949, 0.009432339781684982, 0.015271676445169555, 0.043658986912980195, 0.08897233303756484, 0.08142822091617892, 0.04237274444031139, 0.04484066604486397, 0.04168181740228207, 0.019851188220444228, 0.04802220621176305, 0.014138419815759747, 0.03738073166459799, 0.03161537802718099, 0.04787640435801399, 0.01478314983673514, 0.01989429598794349, 0.07040883519596632, 0.0684521240632861, 0.0658306401343115, 0.02470598698803975, 0.009944496372143828, 0.03207589646110372, 0.022796690952213063, 0.03805953536122557, 0.013581757347339825, 0.05029405527297528, 0.016329483947746696, 0.07892315936905724, 0.07860589937697496, 0.08361994484139067, 0.030824677613113197, 0.08386041217994306, 0.016539828709116387, 0.09106244306050001, 0.038840106177714565, 0.01080202263584661, 0.025999597311320326, 0.02233223482635954, 0.03559672739356756, 0.02185448707501975, 0.04883843459068768, 0.027641846588061705, 0.03600959515860004, 0.01589673715868905, 0.017716373136687665, 0.0539696915075183, 0.06859869200495944, 0.016886998688982382, 0.21176966958709303, 0.13000144352835993, 0.13886699603209574, 0.15682544529197678, 0.15125949476515094, 0.13989110236927388, 0.08128788893020923, 0.152452431559082, 0.09010772130662396, 0.15026384093348058, 0.1176475249831715, 0.15790019004094988, 0.19379041337918854, 0.15193663988142245, 0.14599052588305167, 0.14995067951179322, 0.11164386245992877, 0.14574873321239026, 0.13471706710275144, 0.2490330442425705, 0.13176726087206794, 0.13895848225201332, 0.1496030594552717, 0.12725656581742148, 0.22088997696916904, 0.09521195064148597, 0.21455780062223637, 0.24135192495680627, 0.2179042718583538, 0.1233452962591283, 0.17905327191035594, 0.08931230753660203, 0.15590563416481018, 0.13204941105458046, 0.25063154798361564, 0.20527417861646224, 0.12840777380211701, 0.17640266897937945, 0.1512117215221928, 0.1261547015559289, 0.18631745550420978, 0.10392326666342636, 0.07090440215242487, 0.25378050643109507, 0.13892811452669485, 0.1383765158994544, 0.11288728444806992, 0.14695424917003802, 0.11781454747242313, 0.08772062963896221, 0.07971323350624693, 0.13879968754706845, 0.1198233832274714, 0.1695576886976919, 0.1091625189949428, 0.12172981600968108, 0.15632296822244124, 0.21122300456608498, 0.24156601588812568, 0.16404539496908266, 0.08538848179722987, 0.147593610829884, 0.16432074229082755, 0.16637894475171644, 0.11903546945822817, 0.073219473894325, 0.13676258314761425, 0.16825270388395558, 0.13067851203583902, 0.11398849753482689, 0.23414129090885963, 0.1110291688312446, 0.15476600176865055, 0.20122666032083575, 0.12395220643450176, 0.11939907010885016, 0.1335690230611832, 0.2410488605739609, 0.10081822037576668, 0.11925190461859589, 0.09193766787047349, 0.1656087505961618, 0.21702806645583725, 0.1896811637186235, 0.08634234553263073, 0.15308093009216173, 0.09674692271097053, 0.15931929131188702, 0.10331158376028461, 0.13775491215769323, 0.11941905734279465, 0.11443570136062561, 0.1918619096038803, 0.1522287645287091, 0.12174585789081552, 0.12352409351977611, 0.2277962902500745, 0.1372248252793666, 0.1098580961866725, 0.17141067152542455, 0.13078311368102027, 0.12110093443263924, 0.0804811830241834, 0.11205479968339206, 0.24230072485102763, 0.16991816370958285, 0.16275979217983064, 0.08626492468700295, 0.1394335486956181, 0.1483500000810431, 0.251234857545745, 0.06772522919721181, 0.13617491710089868, 0.07588834802229559, 0.11443924834771503, 0.16440361768247622, 0.1761446505664818, 0.0855750318676714, 0.18503120920110136, 0.19965696148574355, 0.09226745340011774, 0.11824488970300845, 0.10328895352300137, 0.12703649173941345, 0.10093737769150928, 0.10792049894770307, 0.13995479491929855, 0.19811297256139018, 0.07413696377508103, 0.17348160636761498, 0.12836340965042192, 0.14463217538450995, 0.18995851819073, 0.269735298690296, 0.07704773782602242, 0.1909867307591823, 0.12842317216939506, 0.1859858773288227, 0.1747118363217, 0.13200428847584034, 0.15726861183441457, 0.08346481203672387, 0.16134208518891566, 0.07436967830383971, 0.12163183336416561, 0.10120137925109557, 0.12870638721412228, 0.1396087070386256, 0.15742936772444557, 0.1064882209644683, 0.12597558253835286, 0.1504891167484945, 0.13616849728409322, 0.11747995857149364, 0.08010602976766326, 0.09793691772727237, 0.18204270020848323, 0.158796007294328, 0.1781119183907586, 0.28242698540129973, 0.09702517350594844, 0.11579264991826589, 0.1729005746423237, 0.24339958604785705, 0.11737649839731956, 0.1475257047962758, 0.13732282324664055, 0.14335719057388846, 0.23155508532879815, 0.18660398770964917, 0.205702421766135, 0.17845307266519916, 0.13873421767305943, 0.13750498363327596, 0.16195760619255806, 0.18722387541445995], [0.041479930251596436, 0.01509660428705355, 0.05096901320822297, 0.030132645493253108, 0.015028828488392456, 0.02475192736563904, 0.024503902569713614, 0.029881763189370115, 0.03235268977380568, 0.06843527012895192, 0.056021638860505436, 0.0812655651280957, 0.07145137360860264, 0.03897363530291666, 0.05850222389844637, 0.014460579897727699, 0.03154794505286602, 0.05612476961687208, 0.0441054169899754, 0.01626243976305329, 0.05736395896923158, 0.03493435245247618, 0.008604198735537789, 0.026526127626458486, 0.028233034724009134, 0.014967361423787812, 0.02496910180085369, 0.02899259557917474, 0.023110654851001118, 0.011224227097456255, 0.051173960880166104, 0.031017205084583936, 0.08020024326059126, 0.03029099586720188, 0.03417908552012617, 0.0608393436508073, 0.03641506251428397, 0.05360229872167111, 0.027304402094394453, 0.028267091162683024, 0.009077013838255118, 0.02032839779501721, 0.03784963876129158, 0.03419045043448287, 0.03962155033443724, 0.004388547123169466, 0.03790604581515636, 0.05206122476186964, 0.044993726581695585, 0.02677338633445963, 0.04325259259090789, 0.0451645412061724, 0.05059135867463005, 0.007160238869067643, 0.0016012088693265294, 0.03767844492329225, 0.06063956324191344, 0.014180772029043687, 0.06219816146298282, 0.1283502329381243, 0.027404144826915958, 0.0663428082160892, 0.033894759647908716, 0.02122700360843972, 0.014492341903068367, 0.12049262231636433, 0.032909509290250084, 0.03605284848280492, 0.03344797334002872, 0.029179348662916212, 0.04732986957195306, 0.015950558665809373, 0.035909099744692925, 0.07176409069929393, 0.028626242757684765, 0.04139853340964164, 0.004144247429775856, 0.006036421400494874, 0.07976273810791393, 0.06070042126661828, 0.014035556232556702, 0.03547716788166473, 0.0541692114465179, 0.02215032916395895, 0.0657569041715995, 0.05635508629042776, 0.015869317914269144, 0.06749180986756279, 0.00624417391185078, 0.07914288870749936, 0.030236325917705417, 0.03991179040543014, 0.03404335006170216, 0.011791381139999196, 0.020140708168788303, 0.015240230451097653, 0.03655599970971385, 0.025250556758574905, 0.03641421215668802, 0.057267749817260814, 0.02462702439046435, 0.011609571238589144, 0.04446381590359154, 0.14589856468862103, 0.01712222407091289, 0.027920698762060176, 0.023049894502506624, 0.022501115078827547, 0.09329026504870384, 0.059165993119559945, 0.05040493883913563, 0.021638806511257446, 0.011199812832919341, 0.07132590372836398, 0.021236374778973482, 0.03893204438950747, 0.028995774844060504, 0.02657254489379064, 0.016318002204981544, 0.02165604348955376, 0.011372494796711591, 0.03134722044060548, 0.02480522410253123, 0.046120484870287685, 0.027464213781058792, 0.04100058903737415, 0.055434049422582315, 0.0828141812235117, 0.022597504261460517, 0.012020650188318424, 0.02442801389993439, 0.010575547893231195, 0.07769188753539517, 0.02474450205843295, 0.026830978909387227, 0.05079786916593871, 0.039502707114743615, 0.026855104933342627, 0.06935103631187832, 0.0511958135382062, 0.06769321438285612, 0.021584276372807163, 0.022802517050877217, 0.050037902284173236, 0.032541185707574895, 0.003966839900503176, 0.005920085203533452, 0.06405168438270208, 0.06425645585442263, 0.046177650351197495, 0.06310897871791836, 0.031620520392372724, 0.025940936043738358, 0.0953421779277344, 0.018385192792442058, 0.10555608348260004, 0.07074403696723523, 0.01842543156066489, 0.019153420017251087, 0.001411766577568356, 0.06343781046809689, 0.07493185660531444, 0.04067548430494724, 0.10976012120203626, 0.05616285567802768, 0.014417700041385909, 0.03338902670469496, 0.027822698879566406, 0.026739504180788517, 0.028911767557503718, 0.03458390553151408, 0.02609297385319106, 0.020552020775334492, 0.054107487742458625, 0.04054012422960612, 0.04891964757154065, 0.009849265897496334, 0.045787466449602965, 0.12463317432951544, 0.007454503295687779, 0.0377785534627976, 0.014177327506214142, 0.039130595227282856, 0.0984917032802778, 0.05844314319772586, 0.026081863663069187, 0.06739961118587563, 0.07881627478186162, 0.03151495922206631, 0.029662736736598517, 0.03317592785723748, 0.07476626670048123, 0.0038062149636267175, 0.00580857057244547, 0.051757367478022655, 0.045326499854244535, 0.050943157740778504, 0.01370832943657954, 0.07192167498531842, 0.03901505001610325, 0.02179156252813916, 0.04788339491032305, 0.012956068441722424, 0.009722309806684573, 0.029312977379548456, 0.019828146210901683, 0.05434849900343726, 0.03836589009170571, 0.03968571402853535, 0.0202171828958296, 0.017682749537690994, 0.011169277525867426, 0.02765492370892917, 0.06158293540319128, 0.00267116712488895, 0.04246430726902139, 0.060683034901176734, 0.014281115182975848, 0.02403554131066607, 0.02655719440700787, 0.028221597031299627, 0.014053588027074454, 0.028173193681023778, 0.09198554070486177, 0.03692498978888316, 0.07493453025217019, 0.010282544160051452, 0.049273315892224355, 0.0380594510915539, 0.08393190350503692, 0.03387759927840483, 0.03268362060489674, 0.019093077186675324, 0.05483303429378618, 0.020122385260859327, 0.13163524860095593, 0.04537491278061944, 0.061921481148249684, 0.03516683715485758, 0.056009986663177136, 0.034369642230411696, 0.018910020477168502, 0.055356532815964, 0.05986682184401059, 0.0643621338531375, 0.029221332196386594, 0.05017395183864621, 0.04638136079114291, 0.05188440017762685, 0.0514272601914502, 0.044039491293651443, 0.015615876876719057, 0.0508800512480159, 0.004930907208848024, 0.040835558376725645, 0.04898432837498765, 0.02307100214004036, 0.021221985732535684, 0.022107623592619936, 0.03855542790505194, 0.015480041826864886, 0.03050647150244444, 0.0240633771153948, 0.03113740236468373, 0.08725664848762174, 0.03840381910483684, 0.011415577666353316, 0.03211206538722881, 0.04433506333659734, 0.027328815401321458, 0.03777777588355445, 0.039058877906251344, 0.011395660337931927, 0.016736900997197917, 0.023613878856262854, 0.014911359438913004, 0.02953849642747833, 0.029288657918392174, 0.0013494873400627366, 0.05201721301061973, 0.0031036929454609395, 0.014773747065074503, 0.015376518450437054, 0.06123771320187277, 0.046584086808105635, 0.14617175164241947, 0.027481297541770245, 0.04616241669282318, 0.011360653950231931, 0.06727882976373357, 0.021376294992683877, 0.03559761605555973, 0.0391903615766956, 0.028325373216742472, 0.03232254038354562, 0.027099251409151384, 0.03756558868072687, 0.05121173284527275, 0.03508394261101081, 0.08427782284636652, 0.016947540702418457, 0.051285338573037624, 0.03294968294099935, 0.023347808859281005, 0.042190844523570234, 0.0667786049926954, 0.047691861437934066, 0.03273166197862837, 0.03642153212680452, 0.07939122376903411, 0.01776596392324615, 0.02863676880576438, 0.045755164352275675, 0.1045969260796424, 0.053519837017501556, 0.05374406329205921, 0.046206524205063625, 0.030220040803655025, 0.0741605133178734, 0.029644708772520387, 0.06121474971634246, 0.051480319441085866, 0.04287855016187795, 0.02647407386722344, 0.02338125242761547, 0.024273926805284236, 0.021149316547258247, 0.019788169827792915, 0.02510815441998984, 0.05240061320364476, 0.01584552609617071, 0.05641264247617895, 0.05114798283865375, 0.022651927147601402, 0.012952377813147202, 0.06707904169396048, 0.006345126105682745, 0.03728271071468631, 0.036507464209271055, 0.06956296687525126, 0.04565833466908625, 0.02768933637848785, 0.07101510185748339, 0.045046529191876614, 0.01084800610589164, 0.009523124073541934, 0.04865625888229378, 0.06923599288828912, 0.047341303434222944, 0.013224181978242293, 0.0366281881748188, 0.06620005539227879, 0.1570483921997009, 0.17901355791236126, 0.23317551450623622, 0.10647604782735148, 0.1379298713178404, 0.15480344814638938, 0.155464505416251, 0.15710485287972037, 0.11968010180299321, 0.266614593565464, 0.12086056668551699, 0.19784979071588288, 0.13681518274449533, 0.15993537922059337, 0.12668829711694873, 0.19142790547301694, 0.16098180935988504, 0.2082941738227683, 0.2172627651523198, 0.11996278058617346, 0.09718196106053169, 0.17800180091252252, 0.1787169899551138, 0.11799283145416169, 0.18162714347483652, 0.10185396358851465, 0.10640052687977591, 0.24007471849120435, 0.13838523398003272, 0.1786477815720343, 0.21236717220275633, 0.1321668982986481, 0.17844633109146552, 0.11433693730542738, 0.13271422215527104, 0.13581444208900775, 0.09568048235509666, 0.21931025770402726, 0.16625862298232896, 0.20259601184197013, 0.17996733737809045, 0.12929652006395403, 0.1283822324307215, 0.10771891057130792, 0.1884400399942552, 0.1561141020107654, 0.12480775044570047, 0.2059781980971175, 0.15874739135465316, 0.1301649420131599, 0.23642244027747264, 0.14663485179264701, 0.13870351286905427, 0.1377454739544661, 0.09377473139113958, 0.19964948446760256, 0.18773177638649943, 0.19934623622365538, 0.11416434535696623, 0.21458249929691517, 0.10998737352389483, 0.10062531177555362, 0.11379378862799176, 0.12914932393018277, 0.15179089931470735, 0.16826817886002604, 0.18973318108868217, 0.12114091656140744, 0.19635150659709208, 0.09527162889078741, 0.09230967250562484, 0.10197200241588777, 0.12307369510733313, 0.12450244142523698, 0.09502361558618085, 0.08815102549570222, 0.19040021384435316, 0.09390823753370393, 0.18728392138596506, 0.11341612260307997, 0.08679468980840138, 0.132287832938375, 0.1371271797125378, 0.15298913743707443, 0.15781880085987432, 0.13873375802030488, 0.07503704047731816, 0.1736407381512465, 0.1919631711057117, 0.18035775110606225, 0.1259843389233274, 0.15829543012284464, 0.17562481394458204, 0.15076429553089604, 0.1467930642707694, 0.13527943692620725, 0.10352983454903288, 0.06105083371362379, 0.15755491421347664, 0.13489424791787902, 0.08248294778769055, 0.062396888500980796, 0.1271885908359001, 0.22654703067195034, 0.15449748795119025, 0.058936886864924626, 0.1543583817058994, 0.22493910404943654, 0.14546384043510885, 0.19404536744038905, 0.09692182058408376, 0.19676053626162393, 0.10074440780426226, 0.15553820307456678, 0.06481012674949824, 0.13942479997152282, 0.20001434150242037, 0.16394538985144708, 0.12297909857044298, 0.16884001753022596, 0.21413631436805572, 0.28553911034137974, 0.10471451291514021, 0.16155311176853795, 0.12012870756969338, 0.11724223382771017, 0.1801575416879308, 0.23836477960069336, 0.10231981399439036, 0.18405521318556803, 0.10964216664433481, 0.1585304658980139, 0.15322817219120843, 0.1796210349927987, 0.1104507111613789, 0.1911919044270631, 0.19755912163565237, 0.16723350050949282, 0.14097733843711116, 0.19745542397422178, 0.237484636506246, 0.11020049918442966, 0.14363155730309027, 0.125860454845092, 0.11856108483287597, 0.20044856013790255, 0.10079030413180591, 0.1656827700114058, 0.14986545989109626, 0.15099427512576505, 0.22153436416579833, 0.12975850172581213, 0.15305780955860693, 0.1589961554254255, 0.12119894006079245, 0.1618251036251745, 0.17212710163045317, 0.19642192539909195, 0.13949296647502532, 0.14123897278501144, 0.17841486019953606, 0.1247807841507658, 0.11715414903817639, 0.20578109899595862, 0.20028547534058172, 0.17071920056496898, 0.18090482981454942, 0.161489189392136, 0.06661320660984324, 0.13631399270267258, 0.12215173893397856, 0.1474087997790306, 0.08387895150771064, 0.14246690447532362, 0.12041579901931748, 0.17994846097163616], [0.09832986720627356, 0.009845747638704076, 0.05451534146202668, 0.019157599026878035, 0.07114436387294723, 0.04850158956082118, 0.031017394691345193, 0.03879083906330409, 0.04474826434987687, 0.0039525995230031835, 0.03648441645406908, 0.05586140774070256, 0.058119183766745755, 0.06638748646383325, 0.03042638850127978, 0.05586877367609451, 0.046533364126639026, 0.030240964580086932, 0.040580408963104414, 0.0159092923821581, 0.013937016258076316, 0.03285327077572865, 0.050491571892052896, 0.03450924643285332, 0.04514374191902819, 0.02070618064833745, 0.045984488941969416, 0.031748047218688076, 0.04394676784173616, 0.04583954510669555, 0.006728782459357453, 0.03880806838072116, 0.025577459882404056, 0.042294239580270745, 0.030869028358269605, 0.021025825089084047, 0.028944831912315665, 0.11190793296742825, 0.028461219757915508, 0.06790075526242295, 0.11865082437232619, 0.03249464586617486, 0.0214721211006925, 0.030895052365057414, 0.11377002458058058, 0.02296119684263343, 0.058590124826878316, 0.07581972952691779, 0.05908949540988092, 0.013788598214065837, 0.04834844475431789, 0.02838095481086883, 0.053096818587472366, 0.05399071296016055, 0.06566026217995152, 0.0758405824402167, 0.030336486168145656, 0.04589799761531815, 0.002517144668907408, 0.048824376877277136, 0.044365373605321494, 0.025207006575299368, 0.05735470079666665, 0.03565325702150022, 0.0300067006385014, 0.02913050289686409, 0.07517606245293733, 0.03866603950999918, 0.04620219197785182, 0.023154187797298355, 0.021933147067865057, 0.014510549897808703, 0.02803346307407464, 0.018669036029267217, 0.02099313994779462, 0.06594697824649273, 0.024313908934052435, 0.07111152168363333, 0.023910115480483062, 0.07266552337715704, 0.015214651732915833, 0.04696399364019594, 0.042344318747880964, 0.031095983821057507, 0.055036951577471155, 0.029250230948110263, 0.03304288902830693, 0.0502268004141027, 0.0051726788120915095, 0.035692319844759283, 0.014358560926461173, 0.048845930761026765, 0.07751279150045688, 0.03125086764714891, 0.020848111842849085, 0.04677886466285394, 0.04741061523917222, 0.03334932802845875, 0.038083751400512074, 0.015527092074344476, 0.05854678723300177, 0.02775278378037676, 0.03995581364799892, 0.029865640869003632, 0.04170002731224222, 0.010995310449582196, 0.07214725723550205, 0.008111940321302222, 0.06523990207501958, 0.03962885498279526, 0.08399351995678679, 0.08428136983345594, 0.04607306785821434, 0.05567972998945944, 0.022278093477530826, 0.04333609617465446, 0.02182780040217744, 0.01409105164179158, 0.04418191469965443, 0.029872146870700583, 0.03943640603533676, 0.015728267720870433, 0.01818586246020371, 0.01713356408741205, 0.03889065648939821, 0.013926768874479158, 0.05626934956038191, 0.014742471525565752, 0.05699109631560503, 0.043968501756148, 0.02894686779097444, 0.052279241893801, 0.025182164259134762, 0.10087433631622023, 0.04305091994484106, 0.011372314766049387, 0.020138392668037165, 0.03939425587774285, 0.03065632404609313, 0.04928510215493941, 0.044529550077934424, 0.00713433025427343, 0.08868347192483564, 0.014972115956967878, 0.0496353498930412, 0.046224002501056086, 0.059251205079377665, 0.026594606310790105, 0.04444634526847832, 0.007952112834074446, 0.028889575905557123, 0.0839659254697542, 0.05213470408512701, 0.02823575242092052, 0.03847635997038695, 0.03413408551545393, 0.03733427609286962, 0.016605788879396937, 0.03045851056794486, 0.03343237578989037, 0.12199649887700235, 0.047952044049217823, 0.028618417169538238, 0.0556483855020375, 0.03844651701529661, 0.020756338339959903, 0.011804033082068689, 0.02765192064426599, 0.02562363008638063, 0.00955886782086905, 0.07037576318027512, 0.026671171053162506, 0.053912556670125455, 0.015575344122255282, 0.037425069003215725, 0.04868793661796278, 0.07930002100164853, 0.09545126118727269, 0.05213744284945631, 0.036217415660259225, 0.06454293060326768, 0.014080400146814364, 0.05661181001473339, 0.08441323654786234, 0.020557877517515616, 0.060243583885171724, 0.0425419656019057, 0.0572940381243825, 0.028697977315694578, 0.07315742843333753, 0.01921830766443764, 0.0672181785827683, 0.05675483479975693, 0.06289426342494066, 0.009232914646066005, 0.033050967425468473, 0.03199262461895424, 0.10200207902779503, 0.00704353207707285, 0.022358218613531322, 0.024799955332831993, 0.01325452097526361, 0.059554694641021, 0.07765825627551926, 0.04417558298296025, 0.02870388385359078, 0.10114583787658524, 0.048133603056832674, 0.07677501052497857, 0.028880940179430672, 0.03734022093516204, 0.041772916747797886, 0.04446666192023024, 0.017683329849293637, 0.004521310160447273, 0.027802558428037073, 0.03744652712597482, 0.04118363042512248, 0.08144479139798111, 0.021959584762131976, 0.036201929192869894, 0.0449012367865972, 0.023907587390332937, 0.0685780689180378, 0.03217723648694735, 0.011617454283329989, 0.02619831860365887, 0.07847093766735447, 0.04758387751456711, 0.04123139217676174, 0.011765590790028294, 0.045469631891577475, 0.037702117040152514, 0.018185274487721826, 0.03358066359895372, 0.019227573497881813, 0.03672246678522037, 0.014406177121394826, 0.05573203847292931, 0.025643634557303403, 0.13406861964012348, 0.0018001326961600555, 0.0027779904250506194, 0.04824037656127926, 0.09858871299412944, 0.050949133226587895, 0.038706841352846355, 0.05743664539148731, 0.053459890637426614, 0.01108156524658684, 0.05533865232381129, 0.025357058301808375, 0.04668078625634794, 0.06264731881298846, 0.010716319422147447, 0.016480602451690262, 0.008106327769646962, 0.04803348685644808, 0.04732967038909274, 0.03607470880172426, 0.056306615907458536, 0.05424008990127233, 0.044997641290988655, 0.05383297162611158, 0.01952503969322049, 0.028520047649621006, 0.08910815276566053, 0.04559896668539413, 0.04125740086179107, 0.024152890658907356, 0.09136808149877096, 0.06393243513640857, 0.0326603468537571, 0.027621095181412758, 0.005036397037216493, 0.025192347482868263, 0.00947025826110715, 0.04238109479868605, 0.02363730390976754, 0.007196134397564757, 0.06848112815209935, 0.02463661772649615, 0.03908544966590501, 0.0550849431554877, 0.12445855224805495, 0.021952757003506827, 0.07846742132378202, 0.048014598958674944, 0.03612560002253421, 0.01092874411223156, 0.06816760666908757, 0.012165784587963455, 0.0038824079139533666, 0.038755430479443846, 0.06435300208508007, 0.11016848437007397, 0.03266973526126916, 0.021737735275359407, 0.027890461271688826, 0.09676981341814804, 0.02229000997519301, 0.03570789824269953, 0.09791856992148584, 0.031066207898660537, 0.08136921682425084, 0.07060532142678577, 0.027987727624995094, 0.06302138805509576, 0.022361294456547307, 0.02047468419937838, 0.015071609710913994, 0.009393296110624028, 0.022668733201440305, 0.0515848636296728, 0.034605528363176895, 0.045935761919545556, 0.09859247448583765, 0.04537906114672942, 0.050308465386830994, 0.04614938553723116, 0.120658005377458, 0.05165794841764916, 0.04503243700450948, 0.04143330614052473, 0.033375524405029514, 0.024775214523317355, 0.04502150876026961, 0.12107357743286318, 0.029291526917668603, 0.03238839330151677, 0.007002389325099367, 0.028806215963296355, 0.02092824463972882, 0.026764434597064412, 0.02286524624533711, 0.007087827759659699, 0.03587802721848411, 0.03080259129825619, 0.037599802167425235, 0.09386475438312178, 0.020528921309197624, 0.023831074358895424, 0.024859338638282595, 0.022270417276529536, 0.06267644164542999, 0.011163641991574439, 0.020752573017812064, 0.028427287808529315, 0.06405291778426017, 0.07265456065896057, 0.058902895543724305, 0.057303399718817205, 0.24345112844340264, 0.20413701302341877, 0.1500587745179092, 0.18985711879307227, 0.21556747386292105, 0.09358990501852767, 0.24261788525167974, 0.18508953913565607, 0.14788247194261323, 0.11173491967060875, 0.1353038904527503, 0.19832427493266522, 0.1645441794948232, 0.1271680673404086, 0.1085583973796137, 0.13806162311905815, 0.12535568717266285, 0.14996255387461957, 0.19601318684797134, 0.13972941185197524, 0.2014077175408602, 0.15709749843564727, 0.1208079670886359, 0.13167537628642975, 0.1314130831029146, 0.1780434454520864, 0.12357847810152078, 0.17887469681520618, 0.16534883228521194, 0.1437153060349726, 0.2136572029802107, 0.1768592727040091, 0.1605326520098794, 0.15080892781336463, 0.14758198161519345, 0.1567296076926493, 0.15367614976581068, 0.16597432775362847, 0.07329874867272955, 0.1100495262371917, 0.1777937467540464, 0.15704791722518785, 0.16204218229939862, 0.1730980721092032, 0.1705614170960842, 0.18056577462102139, 0.24298851858944664, 0.204257074322912, 0.12927966612961986, 0.1442957861769584, 0.2144313807929716, 0.1350518628474205, 0.21241923553809045, 0.13708881402928985, 0.09613259680449002, 0.13159432418404088, 0.12407891737717776, 0.11704303564563875, 0.16335826006627854, 0.144320699356256, 0.11420432748573442, 0.12840800362849428, 0.16892402673200255, 0.16009281028903302, 0.2260023728013039, 0.11358817062911489, 0.14767394280962406, 0.1078176286612307, 0.2015252354284448, 0.20790388266886436, 0.14381255323608078, 0.17810344545831605, 0.19734313080628074, 0.15550653299977704, 0.12601662952933582, 0.2181454056934003, 0.18688750152866687, 0.21195687083227022, 0.16573576797400752, 0.19909132812773028, 0.08440634175654381, 0.15505861671220872, 0.10174661934856447, 0.10806741162894234, 0.30803751921461475, 0.17290101897331978, 0.26057285647238454, 0.17025259173204824, 0.11956187145363902, 0.08814023131684912, 0.20419007227305444, 0.16741849542144807, 0.13572068824883432, 0.07736119802200025, 0.16054400543291725, 0.21672287234856238, 0.14502481076746218, 0.11510189141957991, 0.1292733535651238, 0.06458428402942035, 0.15711793766146706, 0.12405982646610468, 0.16353646743922465, 0.10864350208712202, 0.21926447628967224, 0.1083836144196891, 0.2193354466749776, 0.15253950511255573, 0.21729350059984193, 0.15838890817136536, 0.10938823914095279, 0.24832801352585518, 0.20710543519066227, 0.21757071717612206, 0.2828051876877585, 0.1453602959912631, 0.14216005561813233, 0.07907315938463134, 0.09056633984249446, 0.2360284412580152, 0.18640627573815086, 0.1378076343286422, 0.09471424629971867, 0.17381667790393676, 0.10043192053994826, 0.09027749405152376, 0.22398359322499847, 0.0661101779570022, 0.19810050064998289, 0.18778521868009723, 0.12634102179999315, 0.18665689374169997, 0.0648493504512214, 0.2170093585887263, 0.22954051923607627, 0.07471899907555311, 0.11854552558713383, 0.10107710446801879, 0.09102367901153142, 0.19671259447932246, 0.11725416947757045, 0.11111153094398399, 0.16992167239227604, 0.13649105094373226, 0.1979576405738631, 0.09953090921044351, 0.14435229282225334, 0.1774828835961319, 0.09464551289115222, 0.10741316488072758, 0.11630131697822964, 0.27126122326139485, 0.15686980178279264, 0.08902545357423444, 0.10807278190529156, 0.1105015027907587, 0.159456099293405, 0.10754009798890161, 0.1494249133693595, 0.07230017604606767, 0.1432965623755609, 0.15363717121222328, 0.1570943727969162, 0.1620236889369065, 0.08749926853324137, 0.17264776562731113, 0.056466923636053844, 0.1468117108508464, 0.20336430609947254, 0.09886715531108842, 0.22182776051903927, 0.07446095001913848, 0.16782469056066007, 0.08060201807248016, 0.1340465716296627, 0.15377974017493187], [0.034520852664906176, 0.03790180168805584, 0.017713019586799127, 0.013033873288922254, 0.10044189500472239, 0.043037773876060406, 0.05867463198580569, 0.05656870224723413, 0.027125206468026006, 0.023033406375156298, 0.032589273046581976, 0.017391856376742645, 0.03330874452066999, 0.03987242497744099, 0.04718758406177644, 0.026667103126284578, 0.03199479839343938, 0.008991289557138038, 0.07038665695055839, 0.11302736362502461, 0.014925830839802662, 0.05235796508890006, 0.08615415603403123, 0.07171031132700943, 0.07826580996474913, 0.03921678394920403, 0.07142198647582723, 0.003996091770879444, 0.03296129300349182, 0.10494136687127814, 0.07011918501267511, 0.09849243106380587, 0.023815281456336383, 0.03243337032355128, 0.01722404864736863, 0.01190135880718909, 0.05867277805302894, 0.02234100078743312, 0.023652221556873094, 0.028582928146445946, 0.05847383651041216, 0.012170354302431787, 0.0475204109604801, 0.033064573147003694, 0.02442266660622291, 0.019788179403891968, 0.06691771889886548, 0.030442823002475406, 0.04022499013151373, 0.07659714023071913, 0.012378995475779858, 0.07509122587620251, 0.04165651734858271, 0.02194303534774771, 0.07468219621167069, 0.03863624252018429, 0.013689001995859849, 0.02285316695399102, 0.03882284238634091, 0.02112253028298578, 0.007074475804749396, 0.005052474828722377, 0.05339252469580501, 0.041868428759757555, 0.053157347194369764, 0.05717932794904036, 0.017716160547288678, 0.03322656626903242, 0.019673743104982763, 0.016427052905783057, 0.018484600361496694, 0.005790968744775221, 0.04302094292436396, 0.030526943287001024, 0.08308405867747723, 0.009066094212504405, 0.017205714248120785, 0.10087541650019347, 0.04896529109006928, 0.023665668315164024, 0.05945983763423659, 0.1172305356651064, 0.024084775866339767, 0.06264499756657789, 0.030870914849783146, 0.02720311377948571, 0.017621814904193726, 0.03013549150989181, 0.033602500935235334, 0.04440513356859165, 0.030056653401604103, 0.04211742265690719, 0.01996653807920314, 0.040235738345091386, 0.04478542727508372, 0.006501188749567636, 0.05356340443775539, 0.02444453841646112, 0.13054155083673616, 0.019515793011974425, 0.09558868203913012, 0.03484605698876324, 0.07061616157091434, 0.024166113336480433, 0.09352864096722296, 0.0352267797044929, 0.008948618459755616, 0.0550253453454183, 0.049450695890212254, 0.029338648985891096, 0.10962350474249934, 0.08759229458988675, 0.02457903855810723, 0.08022192354884841, 0.03526373195552057, 0.013348159902248413, 0.04215917061834086, 0.02763727112793394, 0.03817518016383533, 0.03799333770368849, 0.04917699565750457, 0.03608307065141778, 0.0412659618943449, 0.023231758030071374, 0.05072094244702209, 0.07565525044957477, 0.030541399366132198, 0.057970888296803164, 0.038207451617645646, 0.048145351015151515, 0.009316308104673461, 0.034090062272885156, 0.05036335175616607, 0.05483695666395849, 0.06877972624234616, 0.03491014790450854, 0.03955870048112927, 0.04824348304781222, 0.058979956328027675, 0.06848024715098643, 0.12815279675827873, 0.02136538398542231, 0.016961663533302567, 0.046816613645322865, 0.026519550761628537, 0.04442959092557431, 0.03092830824185043, 0.04881423770359928, 0.05234422147153847, 0.0635474338196218, 0.007326144785169633, 0.05422823086020447, 0.06673381949264197, 0.04906656791365916, 0.05313993401585087, 0.014447252840674935, 0.019562744625633764, 0.047179291159996105, 0.018304665460281314, 0.006736732536791674, 0.05627936615999188, 0.024444040459310337, 0.03529475085557469, 0.08628767749835407, 0.03845429280772805, 0.014759117658550461, 0.04209019972251789, 0.10459786836778927, 0.05597878390202119, 0.019353129563011953, 0.07960587394453826, 0.03265133382932794, 0.04299249807973543, 0.10906346382633333, 0.036662045430632374, 0.07688833791161738, 0.015662231899407363, 0.04404969175436324, 0.055217009052754416, 0.020052851290412007, 0.009249312758085229, 0.006479272410468829, 0.03668292515700863, 0.08385867316035495, 0.06528998124262979, 0.02324777884378789, 0.05231131799519063, 0.04555145391233025, 0.039461361349470196, 0.011748326998654635, 0.04089814009926012, 0.015897271505016235, 0.034857368276965235, 0.022344350506882035, 0.009476497089640509, 0.05095816157277554, 0.04027225392600221, 0.07944172428500268, 0.024762614292182752, 0.05618595705938436, 0.02062427052747338, 0.06102356481395903, 0.08126554980633721, 0.04408096346343237, 0.08520046849885295, 0.015411765198223295, 0.054639623905982704, 0.05816684592695487, 0.031800629578590874, 0.05669227222942057, 0.05056202899844897, 0.061149563294865435, 0.023438722428475178, 0.03927784881764843, 0.1205207530649439, 0.03734101766660329, 0.06759012959176494, 0.001824724477633173, 0.08050052674427148, 0.014834699893159973, 0.022742126339806185, 0.06935537236952974, 0.03594384949293829, 0.04118900070147168, 0.036937626409194166, 0.02691916712079077, 0.02175310299912047, 0.02054964781798903, 0.0659523255402042, 0.04213646760270481, 0.056944215565078685, 0.03172594749729239, 0.046043328324993776, 0.03016804833145392, 0.023613319612078132, 0.05364855128009954, 0.039081699665515654, 0.019077052542519186, 0.01538241636984411, 0.005313878392635455, 0.045520841038876006, 0.03981931210165063, 0.027630131188479644, 0.04443349414354852, 0.014063003247663861, 0.00864129271283145, 0.08049087403642555, 0.02554933870992353, 0.021630770248931744, 0.04676764913564248, 0.057379261575519085, 0.01085912012645314, 0.03798977922528021, 0.08492819318968443, 0.028308766345763882, 0.03113114342634236, 0.019365097771609024, 0.034470543670918674, 0.04510435350840131, 0.0667897362502352, 0.0471494903397416, 0.05005867475824011, 0.05267039106618013, 0.025759281275132974, 0.05218914995390562, 0.027594500439121362, 0.03677101760742165, 0.037700259276936134, 0.023786865340005008, 0.020133110491799253, 0.026242818735960512, 0.031930805153904424, 0.040585231486587756, 0.07547774021663974, 0.08593913047544419, 0.025742676319374193, 0.09511727749580338, 0.014144884640230768, 0.07952921918683475, 0.0443854182958603, 0.02021436369226825, 0.036459254296196085, 0.04476827073601946, 0.051024002999427824, 0.06160561160574998, 0.06551858954011433, 0.04171458681324317, 0.042066347574995416, 0.007549494367858936, 0.06644812998391929, 0.004148261730499085, 0.06824203977181066, 0.004395338013813261, 0.08395914559162433, 0.05181100512404115, 0.06523606397451893, 0.02058862062591699, 0.02625946582655513, 0.031675481455280416, 0.03961922525758705, 0.015963373401562776, 0.03388781506087511, 0.029783792035173506, 0.03496347911535733, 0.04158332913873657, 0.0132270289524909, 0.024532814727975957, 0.013629781484093158, 0.10316339937309105, 0.024295499841231975, 0.023304522976339347, 0.036137589298549204, 0.05139357913585921, 0.07638186186311707, 0.025057504516876033, 0.05872613990739469, 0.030662288040583654, 0.03911839144664907, 0.07122285724166902, 0.0401634004928412, 0.04292667197484163, 0.09359573494763145, 0.03861383444839909, 0.037729374448498415, 0.006518540162247636, 0.04286990485965245, 0.023556552496888948, 0.03216892060252928, 0.03705671094658394, 0.01760972795196839, 0.03695482891353388, 0.011216952135005306, 0.013192707255873229, 0.038432930445959496, 0.08022483468296067, 0.014004200253815902, 0.014016944126436308, 0.042437379278482935, 0.0046366130963208215, 0.04432586645106635, 0.033467485599460146, 0.0066182220865401535, 0.05743833461536035, 0.0756795967238084, 0.023419807717624693, 0.010500552673493663, 0.01823172622901057, 0.09407819413970556, 0.011998747734563246, 0.09326100048999633, 0.02152892460505809, 0.06702877100436919, 0.07774078692760199, 0.21161341829405678, 0.1902371750123078, 0.14314895255431054, 0.27904320568326985, 0.0907512428238988, 0.151416496824353, 0.18615456988974927, 0.1450065012660719, 0.09871429012667748, 0.12950648944224083, 0.14240672060799214, 0.19852373358463088, 0.08647566781409326, 0.11208414851177124, 0.17230190757301547, 0.18430414579568372, 0.12193585535691631, 0.11145960299238084, 0.2560610276076102, 0.12530351658501934, 0.28278318564257315, 0.1277807997840066, 0.235637889634217, 0.20210346327193324, 0.12535459932781037, 0.24040091872936298, 0.17090597280090855, 0.17753119310063703, 0.16258844895468605, 0.1941094277126174, 0.17490770968218006, 0.13801118389012354, 0.1548191835923541, 0.0994171528145671, 0.20617842283700744, 0.1350794420126946, 0.1569846230408838, 0.1521865990493567, 0.09166533127427103, 0.14089267039971967, 0.08303823129784677, 0.10338541931442677, 0.18637138809407913, 0.17770354756184165, 0.13908264978278068, 0.16659708062727607, 0.07302210666239262, 0.11048261106254594, 0.14357411603052772, 0.21333927649163434, 0.1771577252375503, 0.1477676047192466, 0.14075745588108418, 0.26483821953015946, 0.11581875819472537, 0.1440130997328989, 0.07914266654200132, 0.10319323083686252, 0.17001942521141422, 0.1356098812914664, 0.08714099985457237, 0.13529146450661844, 0.11612215199537816, 0.17283237749530425, 0.13645319087851432, 0.15180430585338225, 0.18181480437276826, 0.18741061700688255, 0.13244103520147263, 0.19361332449461185, 0.14496353905527823, 0.12372808741225351, 0.20332338168255745, 0.27789447216256974, 0.05232299317515666, 0.09338316853128134, 0.27157017119949867, 0.14877703281179552, 0.15716653827938343, 0.11694182776996206, 0.14330005573649562, 0.12976391030655754, 0.17924963556710752, 0.16199637024152666, 0.1038651435726112, 0.11663483335606514, 0.10080033988361398, 0.1628627543968539, 0.10952517735741793, 0.11172348197789923, 0.22245267376063332, 0.1152304792776704, 0.18214946222161094, 0.19454003041309698, 0.09451511706556044, 0.1430673488686162, 0.1772274545604183, 0.2545291428724604, 0.1458476198416564, 0.21574238705779278, 0.18223633659222435, 0.17711464045268877, 0.12504391237011842, 0.19767745157643674, 0.08777925834780739, 0.14892945366521038, 0.12120418776307376, 0.1168396239799838, 0.10829401277606526, 0.18657144429462572, 0.2438738557600206, 0.14733404491937932, 0.13472442154682454, 0.10757326959602295, 0.12009911359317842, 0.12701227570012694, 0.2264117395445224, 0.13115357847944384, 0.16203861232967148, 0.18791522380084763, 0.2300697634176862, 0.13900355886547797, 0.07761018425827065, 0.07199469848626083, 0.16814453226904716, 0.13654645442241622, 0.17746544743497528, 0.12175133541947412, 0.1311336142281371, 0.11671806114815897, 0.08220707186527791, 0.2356767456137365, 0.14737139936656724, 0.13429507523054077, 0.1612317225625438, 0.10019745933072222, 0.1657449457073404, 0.11706390388069615, 0.11975036738740823, 0.23848862537453253, 0.09552927958148141, 0.18450705184330865, 0.1313027664418182, 0.14239472367109793, 0.17425218356713174, 0.0988410240519912, 0.15216139475664786, 0.07015552822380297, 0.16419076781359412, 0.09871081208750125, 0.11047201606655314, 0.10387137952831485, 0.10728911226314884, 0.1361317863507617, 0.11640181239213675, 0.227098384151055, 0.12527860340572175, 0.18781146485238306, 0.14457094963760148, 0.21350043074738598, 0.1539203785960713, 0.1772352226919705, 0.11268166644919304, 0.07306198153885142, 0.058675490004280885, 0.14582871279168516, 0.18635995806224886, 0.19953921377178163, 0.08218879300740459, 0.23574652090187997, 0.17258324570232825, 0.11588075002955815, 0.26579003781080246, 0.04412725432625702, 0.19212683812985498], [0.017162518380510233, 0.062425796828803524, 0.02620257805251787, 0.06654937616399219, 0.060714996089377714, 0.04342580890102733, 0.02140724686004462, 0.012993911269962067, 0.052391209474374215, 0.03929491342616178, 0.026985447132779707, 0.030483509932133942, 0.0823470974160779, 0.04011160145784098, 0.08037509516842904, 0.047063615713869376, 0.04268050494213258, 0.04183003243299262, 0.019961792164512222, 0.0040938862460485155, 0.02143659185798418, 0.026051448057255438, 0.08119834857361932, 0.03957278883805679, 0.03905480997937341, 0.02756645396021345, 0.12174625625653614, 0.016612074630815658, 0.0766395508582073, 0.08585025661534841, 0.02970584258887797, 0.054222852922976024, 0.025306891034086867, 0.022342515726303382, 0.055798105895519264, 0.03032961435946486, 0.011038156789577296, 0.06773989978096179, 0.12037148083289785, 0.06412113791391735, 0.025029021367851286, 0.031174153517631274, 0.034571219115487994, 0.06547136788046168, 0.040797395706777616, 0.018080686249079245, 0.03012822708114982, 0.07392615936095677, 0.03165599983936596, 0.025670890050429492, 0.02986454727849172, 0.06755262192699217, 0.048632965978956035, 0.04192336492480771, 0.0971833783231916, 0.03103803501524512, 0.009699594342119752, 0.014804183738306166, 0.04491786855543333, 0.020854646572843197, 0.023334136105052406, 0.044099839869886644, 0.14994692568096424, 0.01961295977385054, 0.021948836548554323, 0.08603662282468812, 0.06800781604984114, 0.10634501614878256, 0.06167238765966989, 0.046481553600319934, 0.01311424548827833, 0.02178451451923578, 0.030787166117900805, 0.04819251521820984, 0.041745241821533254, 0.10544809572879346, 0.046830931828627666, 0.04331277645823937, 0.123894190595996, 0.04962631388597431, 0.07109674384757396, 0.017733198342724674, 0.03314174501405608, 0.011158906610592479, 0.042251296521675204, 0.04861950198368681, 0.10277497747372236, 0.05239511652278805, 0.030701839244894447, 0.027878140662646586, 0.04158971448158545, 0.07838538096797082, 0.056729071262863376, 0.055015669654934644, 0.022252090538160938, 0.06637497624802975, 0.14397795161893293, 0.0203330671009157, 0.012049323901714338, 0.01979317621237809, 0.04106623128116612, 0.016850391177520636, 0.05208507690939212, 0.05095229716971517, 0.05611674101542562, 0.014667940746632316, 0.027513547928162643, 0.02018232589527484, 0.06063344986027768, 0.06252643396897663, 0.03864122592213173, 0.0072483126460875, 0.027818713307140336, 0.012848945409660379, 0.017998504167002057, 0.0374209129762265, 0.034174473670822, 0.07589735721628513, 0.04695490017653473, 0.0770454089187326, 0.051295205785502354, 0.04690273341933086, 0.01884836189058279, 0.014641482942557384, 0.035756345643031026, 0.036566855175600904, 0.045517129342882864, 0.02401144593022764, 0.05433451789881914, 0.03307172457777685, 0.07177565862695057, 0.0071146341337401785, 0.015043470343845266, 0.0339713569490179, 0.0810555574454127, 0.09024745574401272, 0.057342592777023395, 0.02865775578445004, 0.15735977629740394, 0.01727222983214644, 0.011273458780300234, 0.05296768680695565, 0.013111756660134323, 0.07683095792608877, 0.041546323261554205, 0.01687380857014608, 0.035710487619883595, 0.05173801226661571, 0.02664329119837813, 0.01836680668225933, 0.024573348440049637, 0.053766632242308515, 0.037418032485631206, 0.05933736315778187, 0.02161885375126956, 0.028331831337944157, 0.05297766127172978, 0.07580141236464824, 0.020484970844981652, 0.01753294870497719, 0.014543668836385254, 0.1127568273354442, 0.029566694208751285, 0.06270010610141101, 0.01956310660217799, 0.058267578828118505, 0.03564533184192354, 0.06741124806144545, 0.047725963841883406, 0.058302627350654335, 0.041820379725146684, 0.01552010918291466, 0.014223780205112793, 0.07792051881551743, 0.02396001844787069, 0.017905445551619898, 0.07446526309415218, 0.05016521843630941, 0.040567749360155676, 0.06303232396021485, 0.027585067981553656, 0.04788602259190333, 0.02495277072152784, 0.05646369074501338, 0.013866189514256775, 0.04107602571527805, 0.01992881974025119, 0.010136284568767634, 0.011098971721836397, 0.021456188387087276, 0.01933291441791, 0.03393858370761718, 0.03227589712027581, 0.05164766368726569, 0.023489738138572826, 0.023152220866552765, 0.042586302940523436, 0.005660254513889912, 0.08283482729307107, 0.016020513984615046, 0.02830460457311523, 0.017188032938828392, 0.06199774520111181, 0.04912406664281603, 0.10619114738919082, 0.0698578111346691, 0.05128638045261464, 0.08619458249379551, 0.035300779967538776, 0.05397181740150817, 0.14104668471601703, 0.05075754612804421, 0.01958468921422478, 0.016460507965436386, 0.0982714070367717, 0.04482682283607222, 0.047479107330042514, 0.06974759406500286, 0.016133660382981745, 0.03181029186253587, 0.02825631422080821, 0.024393396301855965, 0.10711995238858847, 0.06757589567813181, 0.06369253087248053, 0.02864674901619794, 0.026031382299298723, 0.008128980989567935, 0.036340211893642144, 0.08650657946183797, 0.05419884372742907, 0.026616524086303772, 0.016960757634332104, 0.021807257754487858, 0.02988679638703264, 0.07609245682796163, 0.021551290542007457, 0.0525457677130978, 0.05242047020264211, 0.02371098624632484, 0.038867440194852894, 0.004701619965940594, 0.04545917479141105, 0.12014591390447271, 0.10167026336515143, 0.03516607489737292, 0.012315086505916572, 0.023229298887834437, 0.03337395392478474, 0.02309287778071819, 0.019795652591593323, 0.06017338341823029, 0.06906787489330576, 0.004387495667493392, 0.04325668350042355, 0.01581940154034284, 0.04759412394055436, 0.04070561837344881, 0.05678146784644454, 0.015185184160908385, 0.031176585846790866, 0.023723216840035977, 0.04069012041474062, 0.042354124673311754, 0.064183788584365, 0.023452320489131158, 0.018749366093787457, 0.043261525176105, 0.04118589038449911, 0.05146339655883851, 0.04291392810222122, 0.025804961182838006, 0.052665193159613884, 0.02809060557234672, 0.019368742434908787, 0.026549759523702726, 0.037455149445562594, 0.02402158893434511, 0.021565821314711246, 0.07011916203003737, 0.0510626214916908, 0.017166737609753208, 0.04991860324216466, 0.03726803247005709, 0.015488639248595124, 0.05061207369210259, 0.04046814643868035, 0.03943086338920459, 0.029221973795023178, 0.03490870765921089, 0.03146775288417215, 0.021777893604350188, 0.022357712995501298, 0.04133853723385161, 0.055103957457768346, 0.008267985728208818, 0.018267385706666018, 0.012929877810811084, 0.022903734502652963, 0.04071045238825102, 0.06907053321840302, 0.02289577867955931, 0.025766490162500454, 0.02353550806160896, 0.007814594306006667, 0.034096830659696174, 0.02804859331057918, 0.03430087051744904, 0.03247808304525191, 0.014801974532254522, 0.029226803979385766, 0.06532948839688493, 0.05838428083206377, 0.05941196096940868, 0.032407273538410664, 0.08806396726398699, 0.017845872639408036, 0.019698409220924782, 0.023240175421139406, 0.02865521045732162, 0.07338840394250809, 0.027568729241348566, 0.009421854910831298, 0.10918277435966077, 0.04526825418936149, 0.019237729908537962, 0.036333225171772704, 0.08480220236965726, 0.020656197241717772, 0.02237907918770948, 0.02861241104021188, 0.024367502530015284, 0.0672208292469863, 0.06110065624177937, 0.04226864458272054, 0.06285890463679548, 0.03551173376880827, 0.04847310258135681, 0.05986671842214081, 0.012522806458535695, 0.03414310237032271, 0.01608558453529352, 0.04661623951828769, 0.03523082847917273, 0.03462892851882404, 0.04946529369560942, 0.04082992763048218, 0.08899803528742445, 0.013228113924513661, 0.02650538196546897, 0.022062960666634386, 0.042123911421625845, 0.12647181599130555, 0.15740014913101352, 0.1011729803717425, 0.1927963070451252, 0.23041318531238267, 0.10220953563769018, 0.1218412664809054, 0.11286158985908955, 0.1544573909092334, 0.12453440261343796, 0.13790276712707936, 0.08997153385632461, 0.21741762216533386, 0.18171430895886115, 0.1957753778345162, 0.17928268460016097, 0.14087262953962051, 0.16266458277260104, 0.12600847069294224, 0.08915139842898616, 0.18675005003329248, 0.1108390104866797, 0.1578065894183613, 0.10265700759426241, 0.2614170853649416, 0.1277692548389877, 0.1458617771464971, 0.13631753202888275, 0.1551281774957334, 0.1614736378072731, 0.17722782228262196, 0.21621268843450855, 0.1245686467436533, 0.1429029464000656, 0.37492569776312, 0.18700934015214446, 0.12753464807305606, 0.10884630088243755, 0.18253944694034516, 0.19552169547926998, 0.090225062993986, 0.1112610100197696, 0.14353490765056304, 0.13833241987853281, 0.15950738121905636, 0.11724648561568991, 0.2613833468527563, 0.2222632968257512, 0.17464887921608266, 0.08707203661962863, 0.1767504575752443, 0.10016471673283847, 0.14705555663714487, 0.14374997917442553, 0.11479148791441995, 0.0903593275635954, 0.12789333043920417, 0.16011576228324445, 0.13256912510241234, 0.1383570419444192, 0.09062032605851851, 0.17040568674283643, 0.21905436901555908, 0.06577975657438079, 0.13426363498212832, 0.17600755147155256, 0.21829499202149533, 0.20302400984350713, 0.15242808528484839, 0.27600863948464394, 0.07887066702448553, 0.13782815016325445, 0.1751066627161157, 0.12829701281002454, 0.0811343802319419, 0.25098151226918547, 0.20613319300595792, 0.0976125714218905, 0.21785744856442177, 0.1770784044938703, 0.24415436651437517, 0.1169581760862662, 0.13101900747466472, 0.08402662261599496, 0.13469935514994208, 0.19627690495502567, 0.2220641752524722, 0.1233671144432118, 0.12192655504951555, 0.1492015374523978, 0.1424025071244086, 0.18387639294228247, 0.10951989135074039, 0.3638397006978912, 0.15298313130774807, 0.21042513931470536, 0.22107258168680055, 0.13274596883885323, 0.15048203809607416, 0.11611338028864515, 0.1566734074825241, 0.1894637632874712, 0.15603516431104753, 0.22672139228351657, 0.16499073214588628, 0.14051472858315514, 0.09116162846405661, 0.09946720899953958, 0.23506087220964894, 0.14853202257185213, 0.15055624137241996, 0.09435154963284732, 0.19665607251226905, 0.10273441311813171, 0.10814836413990106, 0.06808604128778943, 0.21077418429476602, 0.15198530178637276, 0.11183519291901782, 0.12090877659859196, 0.11713770113044208, 0.10139783483839805, 0.09726580938384419, 0.11294694737561288, 0.12369640967658452, 0.17712974770655557, 0.20278420900144886, 0.11795713941776946, 0.09443675393178579, 0.06274554277620008, 0.15166532218215928, 0.15813867321177838, 0.10175369034010558, 0.07351892234216775, 0.28967509647050216, 0.17724784782096265, 0.14498333476724165, 0.25692034843227557, 0.1808293701540078, 0.19959247220427762, 0.07705884610092448, 0.09249883493588817, 0.16264005263726558, 0.06786725423749417, 0.2185023107355641, 0.06890293616320818, 0.15467400993070296, 0.2466621400127488, 0.1359089313735885, 0.09903520435815859, 0.10222235994954264, 0.1982474209921014, 0.08672458510245047, 0.18016056007435247, 0.12298313585380394, 0.1504165069350312, 0.1361013266948923, 0.16362311198346077, 0.09745520164048481, 0.15202732936989877, 0.09445483360679881, 0.1977786517912342, 0.17199931816468317, 0.15226841723966986, 0.17083573786001052, 0.15678429104868444, 0.22928352738099717, 0.0911837301006721, 0.1469509856354806, 0.09836389683187009, 0.15937513912156706, 0.144951542118384, 0.07200949930495794, 0.1361581857406324, 0.09659780369650933, 0.1251623189196952], [0.065357381658208, 0.007543403011251002, 0.021516192223756544, 0.03622990672386462, 0.04379913120740845, 0.05163875408470631, 0.03236755570997635, 0.01765574493836011, 0.05688942878717377, 0.011727435780959505, 0.04141063759884527, 0.034244486446221994, 0.06299077901208112, 0.06549729995669858, 0.045934792818321336, 0.017415754489540573, 0.012706941436795939, 0.020326377238116918, 0.04157256943384006, 0.04749842423705324, 0.062466602502090324, 0.06612529287174826, 0.0024817933022390094, 0.033542922277364044, 0.018537561934922012, 0.039785707654852065, 0.08639264686573898, 0.024536380867263483, 0.04070030938413355, 0.020602433191191767, 0.0381354968093576, 0.06111702754072124, 0.021870369992909894, 0.08480738878490464, 0.056824813101200335, 0.010475331143806539, 0.06802583443782023, 0.07367816137810869, 0.04664962179958821, 0.056024335489998904, 0.03732368875775607, 0.013295453053057916, 0.0630635611953274, 0.022392728959300348, 0.011867984186767811, 0.08220728636989671, 0.017745879013091326, 0.05328129255963911, 0.013447964879413767, 0.059737885415914564, 0.08751107394815454, 0.016487874541311495, 0.0273019946630924, 0.04235121353919949, 0.04293230655152471, 0.03987951895161983, 0.027001684366334832, 0.03304221870137319, 0.05962815098164063, 0.04023017654676111, 0.05963496533372711, 0.14201521903516787, 0.006179722934781064, 0.0507151278396768, 0.02493769028073838, 0.06428527225169443, 0.056745124635316675, 0.07300602647686198, 0.03966961086036698, 0.06234212853615323, 0.0362920785893596, 0.01559085548750215, 0.026573866395460024, 0.005682656840015684, 0.08168204882813078, 0.040330871143528534, 0.05123562329719144, 0.09091404416868765, 0.0349507314122973, 0.0564665750660483, 0.03206038509585685, 0.06810010666207922, 0.016758814942271962, 0.09053950378250691, 0.11072681691016882, 0.014043599198151742, 0.11277603315970591, 0.0488762371993113, 0.023523244909161044, 0.046291196072894725, 0.01204354185310583, 0.05462837390481465, 0.027112841808928118, 0.03661966161622155, 0.022228979580705206, 0.07730875164270401, 0.022032895546045997, 0.03618045574835232, 0.03696830056968235, 0.05122932222401423, 0.035072573866214485, 0.04945122066044039, 0.06912548470521165, 0.033753462391154426, 0.020785099195857203, 0.023187102764965068, 0.02818776850378321, 0.0339335581708339, 0.04084331501695899, 0.03625306939225524, 0.032690021269504106, 0.01934818829590034, 0.025320379927213636, 0.018133875733662038, 0.01631697947760263, 0.033769308919868166, 0.03668763659774296, 0.05636196192954818, 0.08232667351201658, 0.05094578159191916, 0.038661339560583714, 0.03920063098532058, 0.041469132242303704, 0.035527660736754056, 0.0559148385429815, 0.006410725735833929, 0.035946461852760084, 0.045475385211888826, 0.00869399477397242, 0.0298692146691704, 0.05454419233325509, 0.005268288021456571, 0.035639444456225446, 0.034395095501695915, 0.06034034845088759, 0.013108754553081048, 0.05925426560063517, 0.013816241539203593, 0.0551691668618831, 0.056387097274343816, 0.06731579350608011, 0.03447549642934915, 0.06604243280185808, 0.05165121833523435, 0.04542189695301556, 0.04560661607331807, 0.08349101990461351, 0.07461133307867474, 0.04330413498645348, 0.06594712380319834, 0.015706547212997274, 0.027920905605799733, 0.06360672902496112, 0.04281165153389016, 0.036436581924077005, 0.033406914857726906, 0.05251903890541965, 0.027848232590082674, 0.04602653567769355, 0.1059427663623806, 0.0587897481877477, 0.05574619577777001, 0.04377001603584617, 0.07661897373656112, 0.11218626037119858, 0.08262756986603623, 0.018569459920869242, 0.025371615887589516, 0.04055952540628853, 0.03735018007817768, 0.03385586919443261, 0.027836304601101626, 0.09808573796744309, 0.017749979498706037, 0.038961940970752514, 0.10322945147392251, 0.02891232297124882, 0.04868870653632668, 0.051058863830422206, 0.006674135971303669, 0.016651430482705756, 0.06806107448233713, 0.09607174644066442, 0.06075420063890277, 0.022639403525259227, 0.029000668230676846, 0.05198755008619159, 0.028480358549483845, 0.038243829302730105, 0.011634147339200061, 0.06598581890425374, 0.01721645671603901, 0.02325564082111082, 0.05164550331931922, 0.04230244821237941, 0.03669375380981834, 0.09049260387978247, 0.057940980224239255, 0.045825897250324495, 0.01602841139350447, 0.0698053570944936, 0.054545441056571664, 0.0247381933243765, 0.023962355016039747, 0.06421723215269946, 0.003597475635263348, 0.08891205723968246, 0.044819621609583984, 0.06969124063729279, 0.03236386699662094, 0.02543038440748088, 0.02358762310787795, 0.07924955112919693, 0.048457715705397635, 0.04548737831834344, 0.05654159039559384, 0.009662693802026973, 0.02307321230370191, 0.0600082301835139, 0.08547776168392551, 0.02491237107484091, 0.015471024971996105, 0.04964405648230065, 0.026129202151130286, 0.01663049138451536, 0.028340578146819628, 0.029304720866944522, 0.01679339806639379, 0.045418775144724116, 0.046507470354798346, 0.03128179653187192, 0.055353004981072686, 0.019318772434827783, 0.054862429087440816, 0.054234221667772343, 0.05289298557345906, 0.03191383247594199, 0.04884191646030353, 0.04774755603002925, 0.027880672583236333, 0.08071487814548516, 0.039957759511326595, 0.005500664513918662, 0.06606015241554668, 0.09696662906677493, 0.04255350671648499, 0.012210142993999105, 0.033136451346499306, 0.16324849498848762, 0.007512142314695784, 0.05721048091448123, 0.02534874433261012, 0.030168915926028165, 0.03973215810894486, 0.029707039601259658, 0.036309997385908524, 0.03058767873763798, 0.04474462926267617, 0.012381480473484243, 0.014806400605237052, 0.038861732839817004, 0.008957878547540356, 0.010836312731337405, 0.046677603161022554, 0.039921531213387366, 0.0064245282462046995, 0.026033358806143367, 0.05491439666178438, 0.08423990915499388, 0.14074011165047848, 0.021410874286366087, 0.03115788564055918, 0.015954838224476384, 0.04118088016947431, 0.004376938975896806, 0.05383251197335701, 0.08324921957307285, 0.02728539162255343, 0.02818057302295441, 0.05743602486026864, 0.07369785749864194, 0.03202965156355452, 0.07370306689652704, 0.029705685540853493, 0.017732593133264495, 0.0258841727589888, 0.028806319385166132, 0.06705725415339393, 0.01167129302742861, 0.04841501779493786, 0.000784762813700288, 0.11732959849459511, 0.009293348449582775, 0.09509103132351752, 0.05567442100014418, 0.024831196398384152, 0.05984562802158537, 0.032162615698912454, 0.05088935538585629, 0.04492526130390264, 0.033840846210237474, 0.014577295308211639, 0.03938397880823862, 0.016226075484507507, 0.043278176097139236, 0.043872564565390355, 0.038237765716809424, 0.07878818233767826, 0.03964593874350671, 0.07948130038717101, 0.0817744926579537, 0.10892298628365803, 0.01935804401704621, 0.07512708645193808, 0.04793350089101061, 0.05451921786692354, 0.027263764960450992, 0.04855327368263276, 0.043694158009583914, 0.087010427828758, 0.014809854704165652, 0.020601940979700417, 0.0674629973007306, 0.024014483468847412, 0.02814807365798662, 0.014416996198105476, 0.012795208172211725, 0.04147711870891433, 0.03784329172283892, 0.023460816404211427, 0.007058594802079062, 0.015600559906282974, 0.07085468304613907, 0.03131929270532583, 0.05743722378787014, 0.12710455099060652, 0.0572820105439713, 0.03308863213826572, 0.044730337892448714, 0.06058143249021904, 0.05384428291431358, 0.06315182218508375, 0.014668534464773633, 0.053166007818353754, 0.0035360959525625674, 0.06728701924364414, 0.012832067535078574, 0.07321012762164877, 0.019489816885681886, 0.04698321478621614, 0.058609797964773835, 0.0646366231564072, 0.13664966178757532, 0.10429841225906726, 0.10479393325025037, 0.12068379189698927, 0.13916492762584842, 0.16369844906993453, 0.18163802192336131, 0.11136610962210164, 0.14686605712819487, 0.10112493133713162, 0.2249228323419248, 0.1329192272838085, 0.1231426123770014, 0.14477197110893267, 0.17833694905763675, 0.10074414733436801, 0.1615741638646972, 0.23037250604360338, 0.11877856187282071, 0.21825895524553715, 0.19671195096546606, 0.12315124618790804, 0.14222564806620921, 0.16605711121472622, 0.16403091590731375, 0.17565600904485873, 0.22193096788419833, 0.07023405223604172, 0.25516979156001923, 0.07084785720273372, 0.1545690865285935, 0.11770371753241747, 0.21569593148606442, 0.21588126347670633, 0.11111362236401728, 0.1535014817190747, 0.1396506733351177, 0.2510140250406919, 0.06896010930499724, 0.14539830927406588, 0.15640808059082878, 0.11877465482440688, 0.1636788985061069, 0.14685425937416094, 0.12188869498429761, 0.1359775115645701, 0.22767961505920659, 0.07710661934388262, 0.08553192410017214, 0.093277869746089, 0.1443882070241436, 0.07374816649262944, 0.12575070508905958, 0.1705049717378232, 0.05774686503554544, 0.17760967114760032, 0.09312025481654752, 0.26180463392407666, 0.1411348614361017, 0.13455583623820735, 0.14431481580099753, 0.2915379771542165, 0.06480035912846366, 0.17544133588671687, 0.12494188478036274, 0.19429120505529066, 0.14319001486705196, 0.15283149186401598, 0.20905070096975376, 0.139565714184315, 0.17774914511509482, 0.15643029714063292, 0.204678192854889, 0.08128342263761067, 0.16100494521519831, 0.10873197758149718, 0.17053446612290799, 0.2650045525402792, 0.10544628010041292, 0.14371932033569584, 0.08071971982116662, 0.19168799232331016, 0.09224207290718633, 0.13862455984757793, 0.17048571228740678, 0.1258557127608407, 0.18900159776451128, 0.1390335435468343, 0.12172448403772809, 0.08502102772434873, 0.08165299111316282, 0.11470577799745145, 0.2261468263403062, 0.23512776700719712, 0.16501618158673087, 0.23469567809614444, 0.09278523690638044, 0.20372053698426296, 0.06944672835450019, 0.1396031912055708, 0.24958539363597673, 0.1971260521320566, 0.16101819853628838, 0.15939983779624586, 0.12380665738976772, 0.06767206269526674, 0.1554695156312758, 0.13518807328035756, 0.07146330925846292, 0.11439994803719944, 0.07627809525377328, 0.13251320068393985, 0.1424805714838928, 0.15307622631230663, 0.09072927908310968, 0.21993143243655083, 0.1578267681742868, 0.2120867840224697, 0.2166999663196264, 0.17218265832672197, 0.08596333885385145, 0.10377599392086269, 0.17642289370058045, 0.10910908436222423, 0.17344075855949234, 0.1849343603657138, 0.15771844334179358, 0.12791491879691042, 0.17448243895365348, 0.14542559732592877, 0.18331520289423006, 0.13607880370991846, 0.12197884821122694, 0.1705170146399929, 0.180366009533886, 0.16314389334330637, 0.1331532518229177, 0.1613304559742251, 0.1941114501847375, 0.10607231183037644, 0.24743306961271072, 0.2008465121710493, 0.12411103944384283, 0.1976816497382618, 0.1435936053073214, 0.1510990912755651, 0.18132715876544678, 0.16948478777081738, 0.20774901033409182, 0.16045881645573726, 0.060770411059380545, 0.15356290664884353, 0.21571761177432155, 0.10166064896170171, 0.17233225997657547, 0.0892149224396675, 0.2667103239124821, 0.10966243733081127, 0.19088805863453498, 0.4086268248577272, 0.09323481560474442, 0.11450932241014897, 0.11291564502302678, 0.1474001583072447, 0.1803157694878117, 0.16511408762345392, 0.09306030077559334, 0.1389574250506778, 0.13664014697555574, 0.12384939743506333, 0.13590579041309897, 0.15531580775014817, 0.13842471815165014, 0.15067739051676568, 0.1668608906648813, 0.15905903592225046], [0.03862131146654006, 0.03335230044960495, 0.01942834790585743, 0.09287775734499579, 0.04729631492086957, 0.05305620443616664, 0.06188388921380524, 0.031032839023898688, 0.015046280928917471, 0.018217270149879398, 0.061924920883029706, 0.044367005372600216, 0.055294502676735004, 0.06509888060991803, 0.050841693225647175, 0.041116394718448, 0.07918677022380215, 0.0701289373119512, 0.051933154013128056, 0.03932053906722896, 0.048609041053080754, 0.02719174886512901, 0.06684012951389437, 0.03843938856716118, 0.0578752345585775, 0.012482649087154818, 0.019620974968758323, 0.010747390033136453, 0.05077674429142668, 0.014007019457377255, 0.016498111391199693, 0.03433446347292873, 0.01914332680884869, 0.06227105089853849, 0.047848511096690936, 0.035311263880782554, 0.02935247878814417, 0.01133399217524716, 0.018672397240034996, 0.04640032146726886, 0.02044328417058193, 0.03511561268580056, 0.04939452249316439, 0.036893603166625384, 0.06272182086362474, 0.02629684325638077, 0.11646207286826066, 0.012076643554704085, 0.15394831016179056, 0.0480107263842177, 0.07969260275844606, 0.06431990708675116, 0.02608930237681395, 0.02178223923810067, 0.029165867430668686, 0.06396063100246173, 0.021727707184430574, 0.07913459963615864, 0.02601607203213198, 0.029355506750664888, 0.04170716342125689, 0.008633870278455077, 0.04765433462096318, 0.00681569274034231, 0.04673711670142028, 0.019605986458519777, 0.042488002368519386, 0.010382366374195104, 0.027189469753554272, 0.02081582123684066, 0.02520025734068646, 0.020023332007469672, 0.024682098451340874, 0.05786897178979651, 0.020992641990643837, 0.0411889317535585, 0.04503037622799316, 0.012744861831437918, 0.03971708532903464, 0.018034611806093205, 0.10737659950410167, 0.0420371902685973, 0.05319630659575905, 0.033075214108271946, 0.03631567409742744, 0.0618045071830913, 0.07254571488667881, 0.06823536714599018, 0.0438322147144185, 0.05426985624757025, 0.027261120041892416, 0.024560933985236674, 0.045378904098704945, 0.03354221364603408, 0.031140221568245082, 0.027774824129958308, 0.020808755990958983, 0.039372422371900855, 0.03884226271522142, 0.0425280764278385, 0.07498280145227909, 0.05250994927219806, 0.08783422515637453, 0.035458797093240485, 0.0306244432971242, 0.049126422363183195, 0.04492805752482626, 0.03533980831684124, 0.014330793112035722, 0.02750422846856377, 0.07447823296271025, 0.03770172250487151, 0.02282203122552845, 0.0173333061919097, 0.03555331319089859, 0.026768017973330234, 0.012051306154218414, 0.07122743078657696, 0.04748008792258559, 0.04405147290878719, 0.035181603499598084, 0.0394146146643306, 0.007451563433278353, 0.07391028601916567, 0.01063760388792763, 0.07609096295650929, 0.017116034080484704, 0.0630608952093509, 0.020862562176320824, 0.049070658823174816, 0.06018430783203053, 0.01702100278869752, 0.0071350910753432304, 0.03659919174688478, 0.02534188018480857, 0.04357161075477639, 0.06620822955043086, 0.059840679093594515, 0.036458698882450985, 0.03150307911358053, 0.05238875799301652, 0.05867386206744179, 0.04221084324883358, 0.032676174230272734, 0.05438586494194404, 0.048492603349469365, 0.043564313767297615, 0.06550219525853473, 0.042541613201460535, 0.016981275384164145, 0.013279205285793832, 0.027415892785234798, 0.009223912155345805, 0.09929758947222464, 0.04937425563712755, 0.02754134925893478, 0.03207625077676869, 0.04441957815640396, 0.031557065329604575, 0.03986684402691261, 0.06997796436471325, 0.041871355215628306, 0.011619784148229707, 0.09420687392834695, 0.050958487160143354, 0.028949882346956484, 0.040142321583604625, 0.02704639134237603, 0.024631624748449654, 0.005445447290361289, 0.052626930898235696, 0.018487390836760886, 0.02984049786332875, 0.023883518822971853, 0.042103663717787114, 0.03971515095702583, 0.06393813866100485, 0.0650681987885506, 0.02577314746656245, 0.03693042901314555, 0.03346556654920982, 0.014717191581674402, 0.04994970641189045, 0.03500874342036343, 0.04677535214972112, 0.03330442761521667, 0.0149124147250287, 0.056166908283147125, 0.035478711548832156, 0.03484671965481774, 0.03873629360309532, 0.06904372780193245, 0.05800921184521529, 0.08102775611464055, 0.038965361553334424, 0.07207717551218887, 0.02625920152622125, 0.03354866410635653, 0.017366613779637604, 0.01475329347510612, 0.017610317839670087, 0.06150974719334514, 0.04003297402373245, 0.023564623233171243, 0.043502827550494866, 0.05200888946532242, 0.08091449767591492, 0.03464024746790528, 0.0358094968232176, 0.03678368870168924, 0.1075063594767163, 0.013632894673895453, 0.018661827141899737, 0.033728173828773925, 0.07353756892224474, 0.00965293575709145, 0.05979282158096472, 0.03088859424385573, 0.03491050796583295, 0.0997904904427067, 0.06659272141874799, 0.030639178998347734, 0.060053314457857804, 0.029311851230299765, 0.07547738015531533, 0.08766668938821362, 0.02673386002800638, 0.05540317607923381, 0.04385740368536884, 0.04214742649046164, 0.009415685030211125, 0.03684146322249886, 0.008215227168083431, 0.024056961129028952, 0.00458678673772562, 0.04556603256552931, 0.04734879960456202, 0.06355266620014464, 0.03980950617621984, 0.002755781296723252, 0.07022058441033287, 0.04634772570082738, 0.06274445876178723, 0.024579017490689314, 0.036582870243657986, 0.06232249370265392, 0.04336089444076342, 0.0465651452841778, 0.04940546988960236, 0.0410312210630265, 0.02784811001601479, 0.014834392500380355, 0.0406944488115128, 0.036526271667812145, 0.016461105514017325, 0.08708869137110249, 0.08300141311220585, 0.0669483241114405, 0.0132541791085274, 0.04440036084082338, 0.07443688719743684, 0.03635864013866071, 0.0571944390333468, 0.05382573209522713, 0.044357804656629606, 0.06628830106027665, 0.08772781554369197, 0.05653699769848778, 0.05249726285617198, 0.05678214200381791, 0.008483001710696807, 0.06881077578591724, 0.000722695148133132, 0.06323895702559142, 0.02919401350100675, 0.06500213136596066, 0.027435617634065212, 0.03767712342162286, 0.0208891530881726, 0.05709944030029639, 0.050499631137016325, 0.06778175116426523, 0.053914732359830415, 0.03433617184899988, 0.029776523775991895, 0.02433623656660559, 0.07763840693740115, 0.07663338385041683, 0.05215850260649478, 0.04340320547682144, 0.050513776950538165, 0.029379810890062686, 0.04856888272408997, 0.038228699066225565, 0.06629269840496202, 0.045909354868795604, 0.05588548971460231, 0.05514668984218471, 0.02071361170120297, 0.027187370672641743, 0.05205708022619929, 0.014788460741270215, 0.03747775286976849, 0.03536327742040157, 0.02674850188345919, 0.03659981993898269, 0.026902326592995275, 0.06696992013002596, 0.052414487055953474, 0.0402635894715786, 0.031222962894506996, 0.028254146191982493, 0.020669262871266376, 0.007353616219329378, 0.043660132214427, 0.01119465993401865, 0.05134327014187171, 0.02850921325115187, 0.028905096846903046, 0.0343830487690866, 0.007421593594875548, 0.03705763025209308, 0.04098232933169892, 0.024148110270259843, 0.03296354913242883, 0.010134095472524004, 0.01772343263690991, 0.01770429193012176, 0.023469000138462554, 0.04632416849715575, 0.027555954725211187, 0.06038515310313913, 0.029907526726263668, 0.048521603607843, 0.0572967232625571, 0.047033159888439605, 0.013228896291806333, 0.036657950690677094, 0.028093055138484608, 0.020610507757913683, 0.040367911494667494, 0.030169888857692003, 0.031938316646001996, 0.005865765739262345, 0.04139343126406593, 0.021009756394872264, 0.057794109677835825, 0.021048598967853095, 0.04936934501353291, 0.014704012954156968, 0.03529605320504597, 0.02213953690032565, 0.17528994159112055, 0.09937828917416835, 0.11645836500270713, 0.20651476607928354, 0.1766786138497053, 0.1470949182346944, 0.14530639404491072, 0.17358125908480537, 0.12710406835521423, 0.1438505205536081, 0.11884865891789237, 0.14326607207617453, 0.15292610372266463, 0.1792874649888085, 0.10899733511670943, 0.17259124366025771, 0.2447239222425607, 0.1696599154703079, 0.14086119950779025, 0.17904250071414057, 0.1074283640651453, 0.08971227438098962, 0.14957699714408768, 0.08162212543069355, 0.17485167801139817, 0.16520434810269266, 0.16593151876041967, 0.07695835834789662, 0.07453858536938507, 0.13044105542282905, 0.1683940777495023, 0.21176642137429408, 0.1043868647708047, 0.20724991937318157, 0.2137725145345734, 0.13574311930325725, 0.09972407828055083, 0.13377412012027157, 0.11636692474806502, 0.1377802696679869, 0.1014658711069534, 0.11826757356644639, 0.16421221827547397, 0.21482662087486637, 0.19061287985213343, 0.2043200314285294, 0.20462159427904314, 0.09081110493430207, 0.23796934033593825, 0.13668534616308828, 0.08764643402349565, 0.18901005537519533, 0.15443348896599587, 0.24704624117622453, 0.07376907303208306, 0.13313423752063705, 0.11629377867305472, 0.13807663844237406, 0.0825348579054398, 0.15502550639212132, 0.13049527912610961, 0.1431001221100169, 0.14004870197705685, 0.11495079589827407, 0.12660052642346392, 0.11528991237883607, 0.1219192618924764, 0.11724160563561226, 0.1537833561099345, 0.13228873692212567, 0.16240063483916944, 0.14326435603922413, 0.14954273769211385, 0.10327349386868939, 0.07891779675358727, 0.08811269811685048, 0.10879991425862236, 0.15489537869730305, 0.106008879750246, 0.15812302969636458, 0.16999604420796519, 0.10794274614102418, 0.15609962294899649, 0.08283035333959327, 0.1568328916666008, 0.1582427692389296, 0.17868093785739717, 0.207517774355027, 0.12367352663028626, 0.18344690873017236, 0.17328187192399658, 0.10772639525032814, 0.14268234372138977, 0.13685998356630727, 0.1228032277656659, 0.17295184124621654, 0.20693493466223442, 0.16377167175373725, 0.1520432639987238, 0.15552357079521303, 0.18205521808516595, 0.12541034754606026, 0.21685270892996944, 0.20471830521860432, 0.166014761874272, 0.11076390322658325, 0.21647888866643752, 0.0966619405775301, 0.12004336537492853, 0.12620324854769055, 0.21983220872859802, 0.22181599340852232, 0.19518400392224713, 0.1510912925004959, 0.1490969970942505, 0.09811370017667932, 0.29656121567372357, 0.09106887819906397, 0.205529960052621, 0.15557070052431476, 0.10911454656912435, 0.15573317245129617, 0.2756909887877203, 0.15016806462118704, 0.13754013174724194, 0.12308887130911313, 0.10836266191496004, 0.14914807983704154, 0.1640266104931793, 0.16539340328064658, 0.13555316014155266, 0.12300923646938418, 0.13484258294826554, 0.16493542059775324, 0.16234293309671266, 0.10033108804735447, 0.14270004035244066, 0.15751985803006158, 0.152593498989459, 0.14065172042577498, 0.10494325910845112, 0.1512104804597555, 0.14098286959192446, 0.17014463462175863, 0.16905847516271377, 0.13020277143486086, 0.13287692390862973, 0.16007796350506046, 0.21208609454333785, 0.10391374419052755, 0.12843061854401905, 0.06993288009036934, 0.1263971760448429, 0.15464333577021477, 0.11696251980479687, 0.08764628846679004, 0.1396809184863683, 0.12048056409243615, 0.23673906441657777, 0.14763108785113982, 0.11541588787710476, 0.156001104041934, 0.0764190401100824, 0.165634659689761, 0.07506401443313207, 0.2608970648819401, 0.14929101652195378, 0.08872712361476115, 0.13091606057939992, 0.08132048597138736, 0.15322827944351783, 0.16101882672838627, 0.14347495360960885, 0.1119086760727148, 0.08611822651038248, 0.15293068492845183], [0.04496942627273741, 0.01748121670267034, 0.06639965960095007, 0.05738176285259186, 0.10670531496045091, 0.11209242992223271, 0.05649684319993662, 0.05640989988141003, 0.026004959926790288, 0.08948591838200247, 0.07683678785519255, 0.06926785448505994, 0.047408347618916345, 0.012313086058824294, 0.03851742994400763, 0.036236495080013434, 0.06690287211489293, 0.034328568426351395, 0.015260620838812283, 0.017319367222127416, 0.04093979613014287, 0.06670484604734568, 0.037095888683031646, 0.10725680633538193, 0.017051466275006533, 0.032894034314179615, 0.02619154638640823, 0.03631434493487881, 0.05906777298678795, 0.009275806951336563, 0.06026910610436913, 0.019726170332080895, 0.04024241480135149, 0.06767000957962967, 0.02617293619550765, 0.047331401747801614, 0.014099565751460052, 0.03136598767953054, 0.05356163094421068, 0.027247705842338266, 0.047806770796136516, 0.030138090463174932, 0.014878593858391529, 0.06640117645504014, 0.025710291867595048, 0.023396030263674837, 0.03697990297129558, 0.06902462922998014, 0.035261835887907975, 0.03616236075158081, 0.10310671652757353, 0.07544171110156082, 0.03853916768885909, 0.02333100089022229, 0.0421927176085451, 0.02227987463195478, 0.08571390828658497, 0.02454213035713521, 0.051524656779703595, 0.029404130351218968, 0.05913820711054629, 0.025234710229861162, 0.015668877712150496, 0.026171116736687483, 0.049508328684755874, 0.014007416865487975, 0.026060951377956137, 0.051146749437095664, 0.06778547435157722, 0.0436093942112019, 0.031446139628608386, 0.013003624307232039, 0.014488124589045203, 0.025927106241485285, 0.0420021302547426, 0.02771888630494716, 0.036558504817226244, 0.10752245498400544, 0.03561434741582602, 0.06327207500655806, 0.1023296275807004, 0.02995978349879865, 0.037221615202724934, 0.023643570508988156, 0.017544869033078996, 0.039264365670181094, 0.04935219996578751, 0.029491033450129534, 0.05491009124764993, 0.02914828571280645, 0.033131667127412175, 0.05332222463743341, 0.03967803016665482, 0.023742717608148535, 0.031211044481625, 0.05459457793603501, 0.03985613028729155, 0.10234183902221342, 0.04034466838704483, 0.03526104298690635, 0.017504417675457174, 0.02849681411809739, 0.0932484136654004, 0.006349024535607427, 0.09599856206125791, 0.04076953691941115, 0.09022646493488744, 0.03651424791784056, 0.01993810281067366, 0.027045014299332138, 0.022976156624574817, 0.022520497103311846, 0.07402655518343372, 0.017089784077759233, 0.019713526050890648, 0.0563864499300478, 0.034915602450529416, 0.033457315782265316, 0.02791754247981214, 0.038549379640889746, 0.025000308392449253, 0.042069634092190576, 0.04716775770629606, 0.032966035087743116, 0.013940906069511849, 0.01937721728257114, 0.019696861723317735, 0.03925393921353164, 0.0185309199526185, 0.030749863381647778, 0.02950610239960013, 0.022979605935453888, 0.011222027467503663, 0.06895553576008928, 0.016793164409576886, 0.047530737825699394, 0.03564746922723228, 0.046359385559034925, 0.05573641666541657, 0.05008097940815553, 0.06527419217051038, 0.007945641306334086, 0.02980773228280727, 0.03117215211292909, 0.03446435751093011, 0.044543339660571474, 0.05067907191152054, 0.016226096551925424, 0.03549295312334453, 0.013410952298962062, 0.034536342962735125, 0.012738024496713714, 0.06514525191197473, 0.06962105166167021, 0.07354950457210503, 0.025181394340770862, 0.03270740763494565, 0.01887070101445481, 0.0657333163244109, 0.043041477911174304, 0.10199257187665471, 0.03354417866155986, 0.03605162657256569, 0.05220386267249143, 0.044556072041873014, 0.03683094100485887, 0.04992280140398972, 0.01073304312153449, 0.02405061409057629, 0.017492713767193982, 0.03347585894047253, 0.02188576836018793, 0.02099486364562425, 0.019020536321125204, 0.06205702125425301, 0.0683797134326831, 0.036810639674865434, 0.030915190901366935, 0.014487392975077515, 0.023611266496441057, 0.015608886324409998, 0.047593794522746924, 0.027830693007056272, 0.0493791317867656, 0.06555580609147588, 0.04517507491513126, 0.059491791161558324, 0.07558506147395219, 0.03606418275364465, 0.004232397815588141, 0.07154852121828065, 0.03914389068320875, 0.09479759666588038, 0.046228729263548894, 0.025320778292934262, 0.08538250631142048, 0.03605678617473572, 0.06630208298203445, 0.043640976185880365, 0.01636316117289807, 0.017407455842100808, 0.013980186270219425, 0.029239385058322263, 0.02369867138294203, 0.11996435872729748, 0.06257785762089395, 0.048128340032792864, 0.024109051277440403, 0.04775320592847082, 0.04868867589280971, 0.1751402939759916, 0.03196548403901679, 0.07276057956680175, 0.04957306311435757, 0.04715514789906241, 0.0263398016367348, 0.01582831976139137, 0.009670410222644287, 0.018544387778327353, 0.05042896335644107, 0.0669492893822251, 0.059648107572068135, 0.029544019921412392, 0.01788718010028524, 0.04013715049011573, 0.03335035075583766, 0.03820107776611563, 0.06526673813500712, 0.016696581789743037, 0.04248459710769596, 0.08719513928818126, 0.029491925942561323, 0.067424516704294, 0.030416029077323697, 0.024171428071455132, 0.008175801410670243, 0.03852361227355657, 0.029806542931304827, 0.05712820307141351, 0.0673847490801446, 0.059094471150949124, 0.034960035550137686, 0.04329391154310396, 0.029156331551231207, 0.04936994256211385, 0.03863973205067939, 0.022620653523312464, 0.018619835947550113, 0.025839144026019403, 0.03172554721635196, 0.0523892559501673, 0.027540678932001034, 0.10724107855029645, 0.023019858110215397, 0.014197312824938808, 0.03153208320239379, 0.017804134254073425, 0.0225384044085419, 0.033861867662879734, 0.009487075806264917, 0.08478098173415469, 0.026848926434233308, 0.028871965459397728, 0.01882440249075092, 0.03507246661390509, 0.039098683834796956, 0.045869901340695164, 0.014766391663391505, 0.017911428698308526, 0.03943114301129695, 0.021165919587797215, 0.0628699324724655, 0.09609963204110823, 0.018329867837770332, 0.04033626823295509, 0.02931146052545838, 0.06282252312127141, 0.08002653282376067, 0.05224002585295708, 0.027975895397004583, 0.04743267474095187, 0.08148901765384982, 0.088884592987597, 0.03778051847832338, 0.019077644345440695, 0.03428007123030482, 0.016081886245839058, 0.013796576062187314, 0.05668916574288761, 0.015910753694873665, 0.0617255809746923, 0.050252058332966226, 0.03894580332862754, 0.058215358444759925, 0.015245988559458527, 0.05804445572017182, 0.06412183122348881, 0.034000874316740426, 0.021996941124539704, 0.0414678069101947, 0.023079775761993184, 0.01979105031838821, 0.036994496946253126, 0.02894561332199843, 0.04755608384467421, 0.00948978967273668, 0.003022976006538938, 0.03145386945576437, 0.004631761365735363, 0.020034955476500818, 0.03184718282652959, 0.013763167925419347, 0.03657484547265115, 0.11213252696418956, 0.04455748930453293, 0.013476700837453528, 0.02502225106582046, 0.009879136623273934, 0.01807398872540122, 0.002541533317379353, 0.025631695077003493, 0.0448936486857072, 0.024157674877994487, 0.05604726833201224, 0.011478077992045832, 0.03814828664725346, 0.05345624788934666, 0.01812724524267739, 0.055149892089708205, 0.045320386472608776, 0.015409533009533922, 0.032984417367486224, 0.046978836593728875, 0.0442058740994863, 0.036428633761862596, 0.0072662381459057575, 0.05086033597528454, 0.024404640557364594, 0.017911152906655785, 0.04608771928976621, 0.04193048571206389, 0.01966073301680867, 0.01878458124044682, 0.024817031432664203, 0.013981270284632282, 0.031234933018323877, 0.06346888682474533, 0.02988150463469567, 0.05308849504217506, 0.015384810394607486, 0.029928006171699495, 0.06111054643688183, 0.13252510569028317, 0.14639889671196862, 0.10602535064061804, 0.11912605935527433, 0.17760115224988232, 0.1459404543763207, 0.15520820304030372, 0.14741759446840133, 0.1398442177883079, 0.1349273888814834, 0.1378041409677075, 0.2122757625916312, 0.15918128823320712, 0.10305604747226162, 0.2050677638861441, 0.11941154202025746, 0.13217632118011677, 0.11767726451639207, 0.0980047011868127, 0.11175427871245532, 0.17521932360626039, 0.1985463025348802, 0.09648742574837901, 0.19540256880704435, 0.12775965575729648, 0.13356767474643647, 0.1906570984471229, 0.09812534471312839, 0.17656017665661153, 0.15388110892907267, 0.10974540465301084, 0.12601767140891285, 0.1278387313528407, 0.12713524813373245, 0.16639936865577776, 0.12410429020922993, 0.162416017884689, 0.15764347397752349, 0.06846349280808242, 0.08592291239408717, 0.1829567963197347, 0.14791221147583378, 0.09547281124058271, 0.1744606973783624, 0.17363954305408463, 0.21001810147877664, 0.08810225633844253, 0.1970529520223218, 0.16726150868400452, 0.10800859905899533, 0.20852940878079784, 0.12222511483536613, 0.12531090933348865, 0.1287244822108938, 0.17360730607423092, 0.13816415632684387, 0.3182991443862838, 0.2344923736827989, 0.12463257678093449, 0.11392763951012205, 0.1416071699631791, 0.12928562629367077, 0.10818502144707788, 0.18832785407862357, 0.10612495739253298, 0.11262142895570687, 0.15640968937546978, 0.17506189253782073, 0.18153743457890328, 0.12499515087373796, 0.11522278775491061, 0.23247871157382768, 0.19450091396368321, 0.13382886476334066, 0.12413237499253404, 0.11116570102110987, 0.22378076378616596, 0.24585782430104672, 0.09849022473058394, 0.17281140200793746, 0.2363615975745263, 0.10617774085051591, 0.16000080312932694, 0.14541265044000842, 0.19704435651581134, 0.13820368646373674, 0.24626228808154985, 0.09549671318382026, 0.19666459140998704, 0.12622926489359912, 0.1956333604551131, 0.11787051019529182, 0.2262211675124784, 0.12413345517650728, 0.21111575225668572, 0.16211797903862693, 0.1713937716258149, 0.17393433368734776, 0.10360872628347528, 0.08746047384075581, 0.14679007652786472, 0.1566670029874771, 0.26481912861908635, 0.05976222402926895, 0.18633838502630112, 0.23396314482294747, 0.1804278481511339, 0.09900069975804898, 0.17758851179913168, 0.10588182406800409, 0.10043680818090517, 0.12232822260909504, 0.1490495302864621, 0.07153159833603329, 0.13403321105626323, 0.17428049817681315, 0.17235476763979082, 0.14170463166890607, 0.1025087619200349, 0.12341533201716601, 0.14067171532059872, 0.12474981887686638, 0.15605719699974985, 0.10991988117776572, 0.13923219014560023, 0.09604417493626957, 0.09075458296724866, 0.0890684540894243, 0.1566229069665555, 0.058822000489359906, 0.21495700903957893, 0.0853515640201588, 0.10911196485281953, 0.10698084614329761, 0.14306331924613447, 0.10980812427137168, 0.15971819329405987, 0.2573704863748243, 0.13841411549477808, 0.15712677831611327, 0.15315965328726078, 0.06767625319621257, 0.15307490864107687, 0.13403765436622406, 0.0972548773091647, 0.1301266069734289, 0.16717878650994072, 0.2145020753866242, 0.13399273097034425, 0.1676103391594464, 0.10865330035167356, 0.09910970640879485, 0.1985077529905304, 0.20194716601362153, 0.13142592273652554, 0.11652799473414499, 0.19655553113308646, 0.18535964641599886, 0.10848019512430315, 0.11066815755780667, 0.18987351307465186, 0.10373175234323549, 0.06376866852083514, 0.14057978476968505, 0.17610349632318945, 0.1047291681771317, 0.12979475300638907, 0.1275395203922545, 0.12301016343577255, 0.14128026492413015, 0.1723959065613247, 0.07924407360053833, 0.09972167276446858, 0.08319036869872963, 0.12582156822205554, 0.2547273144967133], [0.03679435264559523, 0.011437140168592094, 0.0054379544716568725, 0.027540276735840787, 0.025476665694206476, 0.04878985695540906, 0.03152078149029084, 0.012578731834618075, 0.025380393339981957, 0.026603092649771322, 0.04415353497249946, 0.0005600560583726264, 0.02977483838255848, 0.02455901876542597, 0.04512023451107164, 0.02420933410194853, 0.057210496236239715, 0.045126424501499826, 0.040338880592776884, 0.0520952582179058, 0.07646758710184405, 0.1092492861132468, 0.02396784978167665, 0.05307238421312744, 0.019789294061821797, 0.023926279935685378, 0.038901833712213466, 0.018468866830751784, 0.08092372137452326, 0.06580716720031154, 0.007319684748748138, 0.07947205370592494, 0.14572280879703262, 0.06108943688412828, 0.04733242447518053, 0.03280682669531915, 0.05519489592482006, 0.016533048830986503, 0.0034165436227340256, 0.03141803952354578, 0.018535928252423485, 0.042460384898849075, 0.05183846554568699, 0.07289336558671729, 0.057234716105965845, 0.02478003321636108, 0.025608917367794824, 0.03962251177478222, 0.049079491816941774, 0.024415063183574427, 0.06530856653567284, 0.018877224253130057, 0.0047200644903275515, 0.09128077811891995, 0.03888045985912604, 0.020200825003426404, 0.0259035739356712, 0.018420367719485395, 0.013540729508554984, 0.010787032210388252, 0.0325561665569342, 0.06723551515249476, 0.05300328308235734, 0.04784925803241711, 0.01581143901397985, 0.016809035836148168, 0.10376660934379024, 0.06206076359376312, 0.06605626834977059, 0.01672133600579635, 0.054515165261804104, 0.07591348336709124, 0.026033245808174534, 0.04284767298808983, 0.01675651859371893, 0.027720901116188017, 0.030519213459845033, 0.03304405731239146, 0.07346898873126315, 0.049706358582742756, 0.014296524083962845, 0.039020910588724, 0.05428437744417498, 0.0364355247227415, 0.03077448353231434, 0.07861105514870537, 0.08745342583185242, 0.03340719064937965, 0.06336448819286401, 0.03298892579492062, 0.06226724344155481, 0.02494720317753813, 0.024356677707645203, 0.013312581821434922, 0.026856246404349807, 0.06389154902388973, 0.054097348568780776, 0.022925786343553377, 0.02067545669213418, 0.01396910863883433, 0.02186082070693374, 0.03895144939662949, 0.03903933500330295, 0.005447207856172275, 0.03814505758665262, 0.03620505483160096, 0.05027353560792343, 0.02052107656885299, 0.04217584452201282, 0.05137964782695617, 0.04278382339004067, 0.04895935773909573, 0.06011411502596833, 0.020029636911086498, 0.07148426942407124, 0.031099743397545912, 0.07347723949820766, 0.01842259128968562, 0.026844327991467812, 0.050952576791807536, 0.029190769118647424, 0.06494960837787198, 0.03190983349697725, 0.0417678912110146, 0.04412130565352498, 0.027420355247393734, 0.08799797645018947, 0.0656566079405527, 0.015077877267744514, 0.0878558594793562, 0.014116284662797568, 0.025918995285586967, 0.08344250355636881, 0.09781520933874192, 0.012626496459087058, 0.03069299667502844, 0.052923759325377406, 0.06039809615861985, 0.008592552283868916, 0.015013932866314727, 0.08844776199229303, 0.0402100590778695, 0.027199495929263295, 0.043382812216277086, 0.045292880085687486, 0.059777790935890335, 0.036535227235646985, 0.038627999414119034, 0.06651006819259736, 0.051314235409541484, 0.0750156972677477, 0.029809490454593496, 0.06056441767742077, 0.0054167654372811805, 0.047687127014562014, 0.04269584202237668, 0.04220154294143281, 0.04508142832726721, 0.05138333654031158, 0.047297153787146655, 0.05643989222364561, 0.07822344530253642, 0.03663610569351623, 0.01585941814306763, 0.08427619873996704, 0.019612074942297993, 0.04766244749208132, 0.05705914024503962, 0.026119449851854194, 0.008394775194897047, 0.03361237580857931, 0.041836333506169825, 0.04242581518126592, 0.007605092241353686, 0.010474938523745345, 0.0319841516865117, 0.029278604929605802, 0.07058358751237392, 0.06884628396120764, 0.05958086037407479, 0.026561005694431164, 0.06207900797767986, 0.01742478666616784, 0.03335136965277695, 0.062326389259748885, 0.043189907446503646, 0.07515189237892628, 0.030207023054601687, 0.03312875982373953, 0.03502376640455858, 0.0296123702860167, 0.044314011240438114, 0.01728916995137209, 0.043700600809027115, 0.03584717685777334, 0.09922023757451004, 0.013399092300284295, 0.051167797702815265, 0.022251711324638417, 0.0364660226830071, 0.023348724334350517, 0.04225192471377311, 0.00778725310679405, 0.019026268574018634, 0.007625816356120332, 0.040710107648685094, 0.01760306107180734, 0.03253101589038007, 0.05068283723366838, 0.013010792017373587, 0.05410403651635974, 0.049068812551277305, 0.032582948990767045, 0.022988691738235856, 0.007807039242658405, 0.054516544220067804, 0.030894119653009602, 0.018489476511134736, 0.06867183041909049, 0.03725807715748106, 0.06948854143340742, 0.026559101965939327, 0.03819787934903176, 0.03912568460368822, 0.07332209137178237, 0.06253903228489142, 0.040262003669575344, 0.054286748486300634, 0.021397762691542026, 0.02208990589415114, 0.05295125805141945, 0.025066301121466586, 0.053357751964921915, 0.042563818259945804, 0.059825583331046574, 0.0391630313899969, 0.0439343189129666, 0.03808745543562597, 0.11282002958919733, 0.056874256415833394, 0.0040975998572614645, 0.03885786409579939, 0.03516155880905929, 0.02805534062997228, 0.07910489074645505, 0.10167205601089424, 0.05345643175044849, 0.044015501250302604, 0.009308400162075077, 0.044522563356064984, 0.03972141755624645, 0.0039273238883564075, 0.04626931660177727, 0.04665802961455719, 0.05183895967239815, 0.06381933757614705, 0.003747480438886992, 0.026042643791785645, 0.05683390273442192, 0.0038233413379789604, 0.04821051062355119, 0.014885775932681658, 0.03614961687896041, 0.044110296970053066, 0.04841408699810986, 0.03693850741030709, 0.044293257918569355, 0.08419497043735559, 0.04458700284181584, 0.037367635391532414, 0.046732271195299206, 0.0187814460256167, 0.06846047442166076, 0.031094673810706987, 0.03142815954502552, 0.041942754610171246, 0.043426866102362835, 0.03924646219539066, 0.0605854352996234, 0.04500289665414922, 0.028028535213501706, 0.07072015034575617, 0.04858622695469568, 0.02068727551358602, 0.08477175803554636, 0.026153983180260947, 0.037547765645168485, 0.08665983535109029, 0.03705743873011201, 0.04239456645483452, 0.053313353339270245, 0.0039041303370463396, 0.05989045565647464, 0.09170031850977291, 0.04818693809812108, 0.03565194318071008, 0.012438513804227115, 0.07304855967841803, 0.04353239471393247, 0.053787485155607426, 0.04778864898628766, 0.04791704149195745, 0.008957320260965537, 0.08511629841861226, 0.029499441265098514, 0.03791867477458812, 0.008887645521862133, 0.039796448207550475, 0.007478985550527972, 0.06681112542508111, 0.022180162542950244, 0.026482858980495124, 0.03821684768603694, 0.049560028128325946, 0.04848403848647591, 0.04154590957407509, 0.06368673924777297, 0.07119235162052416, 0.14363411603675735, 0.03504194567100175, 0.05117910899101727, 0.01685321038108199, 0.0765150232661155, 0.05026564490230334, 0.02340732431489854, 0.07740985992695056, 0.012588346238067795, 0.03270292985102823, 0.03584058084074528, 0.05179421630718055, 0.00994766797615035, 0.03781297379323552, 0.00577720022955609, 0.017719085087939616, 0.029656142634790272, 0.03486865658252951, 0.07162894512857161, 0.038898413129631555, 0.04325606296920488, 0.02277407029102887, 0.028358016223196062, 0.03822114160885254, 0.02820092606388273, 0.05587931504593261, 0.02746822233612259, 0.04161994048063794, 0.07946743419574154, 0.04814992456005947, 0.01485774190270252, 0.08620336186140777, 0.09082040524170285, 0.04357366387041346, 0.17596094268223933, 0.27314196911550337, 0.1512850821018219, 0.1353790436781222, 0.24269636329864305, 0.2780253506235538, 0.1452362357128051, 0.14785806438134563, 0.1437119046045888, 0.1181116363694591, 0.1314731443961782, 0.18418121932735368, 0.10271383599648554, 0.1032253529035276, 0.09186839820036004, 0.13687354332256702, 0.16157093097365674, 0.1707286540899546, 0.09964373863993153, 0.16041073677760942, 0.1910848819440411, 0.15227287587138916, 0.13414058593973038, 0.16382174326046822, 0.09878567419946195, 0.11884147301316263, 0.15349222737694942, 0.08356940602102587, 0.1482589888356386, 0.11158105091101701, 0.06590774688389033, 0.21791148840660052, 0.18742203171695435, 0.13182477875342294, 0.14545662388686212, 0.20906623723285817, 0.2219673264170847, 0.18008114740012154, 0.16135087987828642, 0.1192592437409105, 0.08387495252874591, 0.13351116810114155, 0.14313087287929752, 0.13078452328280096, 0.16733162105083468, 0.14070481031892762, 0.1407689318781899, 0.1367552746688166, 0.2039829374200875, 0.11180090282352702, 0.1826937830135707, 0.1800111269638423, 0.1193186461985592, 0.2084154302194234, 0.13322163283103897, 0.12200861838796448, 0.1761085371817312, 0.21719550263256798, 0.13349924777303973, 0.11884906494449224, 0.17455268921630998, 0.12546006665234605, 0.29314636342948486, 0.17900087149633517, 0.0792380215059365, 0.09979226776669103, 0.14451366158262377, 0.15627343297725724, 0.17377589138284807, 0.11759060465039746, 0.18823664365035875, 0.14690937173943366, 0.08449175289922184, 0.1335611323555631, 0.12724907347752204, 0.11331792545294571, 0.3078755682274219, 0.10447827438192983, 0.14425722131085011, 0.2083343168300006, 0.1257955595370262, 0.1300094721298064, 0.13872482543510778, 0.09836308477867035, 0.15626201826718547, 0.22000713724522825, 0.13754460570071975, 0.08732256269262684, 0.2368422871034953, 0.13177810867707576, 0.1873965209890758, 0.17103312807458063, 0.1308760401462355, 0.14016687870025635, 0.06281455197641928, 0.13961396240178617, 0.20639969967305663, 0.10138056721658477, 0.17623910920754557, 0.1661833931481646, 0.15531969947680352, 0.14545216525514282, 0.1997306897875763, 0.14763396834173512, 0.16410047669083844, 0.1128877824052207, 0.16222222828336302, 0.08637766218594006, 0.1189833218532224, 0.14088024445358785, 0.09830460928741003, 0.2000020994173904, 0.20268092502749738, 0.10341741880702396, 0.11968791589982088, 0.16813210632291534, 0.2108467021776784, 0.24630980085461374, 0.1484520889578327, 0.10680151262110281, 0.1336132110126557, 0.14424758392476267, 0.10834038407812197, 0.13187610664434973, 0.10290725021472863, 0.26232382703212004, 0.15544697732454346, 0.18711642392220038, 0.11006943686234374, 0.21028566534721085, 0.09067440420509347, 0.07751269956990596, 0.2603259003691135, 0.1546834481339301, 0.14476518356992354, 0.11192820365390471, 0.22794082039786925, 0.15290508227002236, 0.1267720305270726, 0.13978619428892292, 0.20781080298606427, 0.13537185777339245, 0.24343842670561808, 0.19416812536937578, 0.18396735822241153, 0.11382096176666599, 0.13509548389382903, 0.12555829444599728, 0.11709671542649308, 0.18864087760448459, 0.13519746551830925, 0.1066728481542199, 0.12091512746748426, 0.1911986153572798, 0.14016649565629422, 0.10426863442145048, 0.08721240690999454, 0.1561031316316897, 0.21644004800867653, 0.13498152065421307, 0.22031755607214668, 0.14481838071538558, 0.13389209766061078, 0.07512363905627882, 0.21969641198314008, 0.13139987574710002, 0.10663947736423825, 0.11354919973640673, 0.10555699512722994, 0.07833829720414455, 0.16569479759181702, 0.2229790221298895, 0.11602596199560551, 0.19260355932337625, 0.1533672477929823, 0.1608598634840981], [0.07077834238448451, 0.015848309868165565, 0.015444310528466539, 0.041845821505112034, 0.07034376368767793, 0.08402984018527693, 0.025006107678036057, 0.02289687035485141, 0.023877110497485247, 0.05035132034531525, 0.1041818902857842, 0.043384765740484006, 0.05495648170190473, 0.02812818984591192, 0.05227577534594363, 0.030489996781632788, 0.012816929637694792, 0.08048743430164554, 0.043109000900820385, 0.054278639445622126, 0.08852633963068647, 0.0028592548774360052, 0.06535947307824128, 0.07511161913674685, 0.04659868844394242, 0.1035560041125263, 0.04732874725314398, 0.04592845344074792, 0.06122018894060485, 0.011719312376132416, 0.061699629746257305, 0.033529772378143766, 0.01784998078590199, 0.06058709004953985, 0.03723918925970793, 0.008814976336584698, 0.019899555181543675, 0.08875966702978458, 0.01112906652833185, 0.017664836486801505, 0.05193473981513132, 0.033331715667079535, 0.08105897419755498, 0.07666396608035411, 0.04184326277144494, 0.024460011477311774, 0.0731923237382885, 0.11584046912649948, 0.0064915595031643835, 0.02684852998373249, 0.044412131781779954, 0.020447283149546674, 0.027717313909482573, 0.023036514776909066, 0.029480871293813955, 0.04225251460147481, 0.05870658168268781, 0.0479393691245106, 0.037834159954781496, 0.028560956744777582, 0.009557048362048884, 0.06917999186102422, 0.053371231281949635, 0.04585576318805257, 0.043897650114470915, 0.020870046855341044, 0.05796621899090468, 0.04825251905487911, 0.020849929386449438, 0.057450549887313004, 0.05638183808074363, 0.05234763056280152, 0.02376726115002267, 0.03468997423507033, 0.016113636759860862, 0.03985790378083626, 0.048630211892868244, 0.041259902138863845, 0.047730725078332814, 0.05427809552319589, 0.013863754312267468, 0.06432844896710689, 0.0487974718693764, 0.021592996368605285, 0.028165538547440406, 0.08871351023234668, 0.02765275759532327, 0.03726337082503784, 0.04610215238625965, 0.03138511689499982, 0.03746781287895095, 0.0284695586249713, 0.047120329202903856, 0.025219124171041676, 0.06507698581704209, 0.013235736499360252, 0.01196004401501869, 0.05361265239996776, 0.170934256767073, 0.039778743915620356, 0.09882305929016683, 0.024979189263596654, 0.05068042405670689, 0.04265382209972989, 0.05409971961090642, 0.04717197502031923, 0.04869282425891969, 0.02664413772553446, 0.027742744198129065, 0.11063331587901039, 0.007658064827292918, 0.041509110540632284, 0.08094315702516226, 0.05845990903194874, 0.04842188577317903, 0.0031471509587830838, 0.020616542615537203, 0.0507604074664414, 0.01879084400922781, 0.040997716207658096, 0.05058383952165323, 0.05711485781977254, 0.03629841030605378, 0.05423179316905238, 0.09401109249841783, 0.043830138616143696, 0.035137327448014295, 0.07840437994849297, 0.04044547789700089, 0.08581962842013567, 0.008617070927885512, 0.02502159989108482, 0.03020209136358913, 0.007297264706839117, 0.05901622293036311, 0.017042177458924633, 0.0372654392624334, 0.03662574052390072, 0.01050233287030771, 0.07880673698720433, 0.013439184554191607, 0.03678129084648625, 0.011147988900061578, 0.08550512634458081, 0.05188935676649694, 0.042251085847496025, 0.09219174859144035, 0.07323284212860369, 0.04695907535572206, 0.0575646088879195, 0.03523140304511593, 0.015782961610614533, 0.031292887569795695, 0.0530982205283738, 0.1285122375514719, 0.03138092830927382, 0.04685630849111946, 0.08730379353848197, 0.06375812332055743, 0.019956998369326035, 0.03289661986092406, 0.07973033258871687, 0.040179044008255005, 0.03167899396841324, 0.04420493947221868, 0.05167801226038606, 0.019965277864567695, 0.010700988087562785, 0.03784920975205399, 0.015038989687098131, 0.057480358368446755, 0.07911524825519131, 0.025887639306846167, 0.04973376154779427, 0.049488743646971645, 0.059285985471139994, 0.030916962479691834, 0.042159400444718144, 0.012467434580978608, 0.014661705748538577, 0.010142049380397845, 0.002535739777451982, 0.013161412564166372, 0.020916423903057174, 0.020391169124312943, 0.02673860977313692, 0.07587334035985893, 0.04292439669370652, 0.05595935208182182, 0.03665343077192384, 0.0402545687862702, 0.06009811144923011, 0.0023383914583152343, 0.02652300007250761, 0.01964816725963066, 0.018622314241985162, 0.01497154905190391, 0.01700999793566523, 0.041445716764898076, 0.0887703003301736, 0.05546585356275882, 0.05000286908339589, 0.0639920712508742, 0.03215595456441084, 0.0310452439026126, 0.05105234442218658, 0.03844392380767292, 0.06694565046458475, 0.02756391437874446, 0.04136444632745078, 0.027830424876282775, 0.0952156278635225, 0.07812703313726573, 0.026652396153358203, 0.024095311490518433, 0.023704478329408075, 0.03219947984982883, 0.010489983532968308, 0.049932894612392115, 0.09667368470540932, 0.055062220987653544, 0.03839827262826505, 0.069444008742369, 0.07804896877778154, 0.04098747361211046, 0.02718555312904139, 0.06343776450282143, 0.09789698156377963, 0.01869660178800264, 0.029889763062519413, 0.02413594670924208, 0.04000469771844726, 0.04512247148781054, 0.03459021809601015, 0.048212533095671285, 0.02096270327456296, 0.030111359740276972, 0.07340252294295257, 0.027618752867584268, 0.01712247496470809, 0.03763356366224828, 0.013707029959937979, 0.038924065583776084, 0.04042585838526007, 0.02633188411803736, 0.07558695371112517, 0.05728166580440537, 0.043446964419056336, 0.04521261705386062, 0.04204547933993801, 0.030703333116346793, 0.054321375660478115, 0.046263161085305676, 0.013522249552601529, 0.025162855013003273, 0.024459986579454234, 0.046833157314047705, 0.0641900705053441, 0.015531063282621965, 0.04578748943224069, 0.021409016523149707, 0.07659457383617278, 0.03291330525591489, 0.019762676336892673, 0.005060308077748144, 0.04124102573240957, 0.027540864708322673, 0.061721919074414246, 0.09288948615111652, 0.05884722010382722, 0.0031738158460000473, 0.01092198434390969, 0.036407780848563685, 0.07871325893868363, 0.05941628170530162, 0.056721601905601646, 0.06257723708967529, 0.037503432136990374, 0.034962119309291724, 0.028971713937578664, 0.04153087509856109, 0.07618195121927608, 0.06653341089165019, 0.03255675261419627, 0.045437264676776626, 0.015420461253773783, 0.036939131771965374, 0.08577603035636487, 0.05144362765995245, 0.04155817847218245, 0.04281604504813591, 0.09352053575698407, 0.019040065817534924, 0.14964441288142435, 0.05905300664204744, 0.06417033991085426, 0.02918966595203646, 0.07954693880052337, 0.02865472016105008, 0.012029650763818815, 0.07500720135266743, 0.02662870105386021, 0.025360505697467638, 0.02398429194375152, 0.04398014246215744, 0.02527463298681523, 0.016336146997468128, 0.019676121807987654, 0.03819981372104057, 0.020131022902205586, 0.014034666612954631, 0.030331056519982316, 0.04123413477153067, 0.0550585973917717, 0.06040332853914269, 0.06284048022221654, 0.013141480871596405, 0.05346085973865083, 0.05357311077175602, 0.05483645870680771, 0.05435724389709292, 0.04511318267172864, 0.048953386083725965, 0.048361801497277715, 0.033629390621377576, 0.02857354931503294, 0.031370894472685554, 0.07221381495436353, 0.02360201598475537, 0.03700416114541792, 0.016120301724802104, 0.02649705267451223, 0.031131283237388542, 0.01649541667692604, 0.018049414540010116, 0.06529365846466634, 0.043767560724048846, 0.05444330238406697, 0.02467160304677823, 0.09238047435158685, 0.032572924730277834, 0.033602757574689966, 0.007655411769050144, 0.04169327424718969, 0.005485038235483151, 0.029713532196417935, 0.041394641682986295, 0.05086380635358153, 0.012644352053382225, 0.01546852752536295, 0.050382703137133396, 0.0670077955170024, 0.2331447484151971, 0.06943254806702176, 0.07483194341822978, 0.15172521493607952, 0.12044235162677304, 0.20328797309869723, 0.09258512707967913, 0.14011545887877866, 0.14793407562519276, 0.19089381961572557, 0.18107338447964963, 0.10457210483089571, 0.0881899274404972, 0.20837928619115584, 0.1319957082910884, 0.16334566558080335, 0.06469117627749521, 0.15107848351040196, 0.15805543009792605, 0.09299862303680952, 0.16091656931225332, 0.1240442748812418, 0.14041850793986552, 0.1759399059078386, 0.16036723830526875, 0.15939954668283463, 0.14887965795013214, 0.18368913041007134, 0.1728607533920196, 0.10165222199453462, 0.12315839378824159, 0.16473162588813614, 0.13321573395402203, 0.15017100639881628, 0.07249031906887408, 0.16626583953057567, 0.11297001428301297, 0.2152338425718969, 0.12356456594481585, 0.15697967411289293, 0.10414733972039916, 0.09160768315796891, 0.1559303175177305, 0.21471316325328044, 0.15197883600429182, 0.21437587006197822, 0.1934539015975691, 0.22829620858594296, 0.1107725217157314, 0.10930594597612658, 0.16539675874575493, 0.19241229781220037, 0.1286749776092268, 0.14032133734754978, 0.13098192881912957, 0.14093777765670132, 0.10204739312851623, 0.14012293589691963, 0.19019453455844235, 0.1094266278068385, 0.16070529758449525, 0.21198438871051037, 0.15690600709809413, 0.08714234050843986, 0.16980668259484155, 0.0854103229639511, 0.11449256040636571, 0.15092679810139442, 0.07962788365060285, 0.20397973517256401, 0.10078668053592406, 0.12523492107227926, 0.14041775717369973, 0.1702720044000495, 0.1159700299162538, 0.11207691664176603, 0.15509194153691494, 0.12487100632560831, 0.11682432520413592, 0.13110756723871156, 0.1343677616527965, 0.1813123273032327, 0.12582171377876114, 0.17749978349574153, 0.13469555535383765, 0.17177785746753219, 0.10471164008542415, 0.06588258089557772, 0.09194924345900936, 0.10697912244546799, 0.1148492509439107, 0.2077997100329207, 0.2877700503074354, 0.10462696438715344, 0.09246560970261213, 0.15269491370887528, 0.10531307273213902, 0.1625865030913584, 0.2876164037133417, 0.11063990423515921, 0.1424033651428838, 0.103176491815717, 0.14665751267344723, 0.11952409565809274, 0.15343834075235552, 0.2203375356452119, 0.20917865297486707, 0.04485020000908164, 0.37456729118862464, 0.18480346658297125, 0.15426239088898705, 0.17317947661203725, 0.1521446174311061, 0.13571851255912937, 0.13255207198521785, 0.15870890309733732, 0.09940628202692156, 0.2564082033331356, 0.13356991172317537, 0.08551846393534253, 0.14658773738530376, 0.20138697187987067, 0.09490519371484557, 0.17768755164598266, 0.1820734050124884, 0.17314966047002425, 0.10778909188605125, 0.17106035483940957, 0.18419821115751422, 0.19200830900621033, 0.12448459923748048, 0.17746480392111888, 0.11494434543795164, 0.1155360947333036, 0.17563477308759767, 0.086250759721283, 0.10066421372034859, 0.1681852881466189, 0.20123563887130833, 0.18350761353729234, 0.15700328494271926, 0.15728312153970042, 0.13186561123978707, 0.1338746002124202, 0.29616462727708204, 0.10094938995016199, 0.2791715407323453, 0.2678972086118114, 0.0894683673076572, 0.22129687690927138, 0.12260438198403967, 0.1538909608197789, 0.15876612986528105, 0.12924220443012255, 0.1615263446564636, 0.11945622792888073, 0.12972752113015423, 0.15408164010413233, 0.12917471208399342, 0.10438113443313107, 0.10586722243216731, 0.2039070181067913, 0.17709391011345774, 0.18627478440682735, 0.1332899678738848, 0.09478620493844633, 0.11984156249391457, 0.17268288309776014, 0.09178787469863893, 0.08883542546461667, 0.17016320459304318, 0.1589842504190822, 0.14657100602503748, 0.1252710804223053, 0.13762092337973658, 0.14854798784419415], [0.017689337893839807, 0.08697245285035142, 0.03423866034755784, 0.06751495338375531, 0.011450556283366057, 0.07221484151218208, 0.04405994967166935, 0.0582004810172704, 0.022714815305305586, 0.06131301964482954, 0.06250324831794828, 0.12724089931936997, 0.02443653088243258, 0.0710898950215309, 0.02819696921975382, 0.018096904330436262, 0.07225239514223031, 0.046643615670261845, 0.026696572613511837, 0.011778588429273618, 0.0366624974225077, 0.04525299371790983, 0.07218598298007442, 0.057985118379996675, 0.06346148258495717, 0.035863360465173764, 0.056921727054061434, 0.022889301406159517, 0.06973106954847613, 0.033658747110636, 0.08179082565249936, 0.042226245446551236, 0.053300655431925296, 0.04814931552015966, 0.045232883909897464, 0.01281173173112855, 0.012688969971702225, 0.03874298921155353, 0.003567115570824113, 0.020639172852820447, 0.03170438403744371, 0.055716850779830455, 0.015825330103266866, 0.008500438829463337, 0.019799446642038324, 0.0574148808335585, 0.014518746080988599, 0.0844608182688394, 0.01941771843590804, 0.016291327023458098, 0.019874979080932758, 0.013765037179954592, 0.009349073685194937, 0.05595035437915114, 0.02146245115586827, 0.013604733281798903, 0.010037849931376836, 0.04462684707475766, 0.027696357574313882, 0.05034603050819809, 0.022561002087088364, 0.0022920828797073378, 0.08914743775441762, 0.04354547183479994, 0.051801195368170745, 0.05796717660081002, 0.055948860507698796, 0.07256609282546467, 0.048156903621049664, 0.03411050149870496, 0.05007871561833928, 0.030879759334868966, 0.07738346819795909, 0.053548438910154574, 0.05311984336003662, 0.0745740092750038, 0.040429700316200336, 0.03374494349343642, 0.010973376394700139, 0.052700670691387314, 0.07254518628601106, 0.054419568980172764, 0.0555191119952548, 0.07065157781565382, 0.006301250335039392, 0.02855650577393751, 0.026176012038523634, 0.039927782490849495, 0.02721365706454362, 0.05993337956287208, 0.04680534832239632, 0.03485230060534612, 0.05152720785249145, 0.015593583718122495, 0.025618859273832173, 0.05029390205539042, 0.03809555681542524, 0.01957624884051902, 0.025063759624777783, 0.054207600112403595, 0.01717780758025906, 0.0742036976941651, 0.029504304008197882, 0.04088651854544878, 0.03590851368743085, 0.05958190608409144, 0.007200345487123536, 0.03512712315686288, 0.019522569059664686, 0.04448598265768059, 0.034412232888562065, 0.07506767633341013, 0.07430034734669232, 0.03996787570236672, 0.06197188973366734, 0.005128482242129864, 0.03334580785444668, 0.036325928184293935, 0.024909689767105926, 0.024810060032553254, 0.027016870144213882, 0.08300755713735858, 0.053879909833232244, 0.014018645799238116, 0.017244424670934677, 0.043684681501960566, 0.033200553753563476, 0.08099227858286712, 0.04987712724194412, 0.045285138767212636, 0.012983942550847368, 0.03972519820015277, 0.049627911179296436, 0.04218056362362639, 0.01974237117645962, 0.044192578643560416, 0.06617921780073835, 0.050996607695255554, 0.06491134228605418, 0.06918153935863126, 0.051128972366812735, 0.03214944281705445, 0.03822074707357153, 0.08290477878143711, 0.040777102037663424, 0.03346052186022843, 0.062047337902890104, 0.018119680124425122, 0.05846406505893796, 0.04986841682224505, 0.029863378994407195, 0.06296356373857107, 0.023596322036258156, 0.03531956827388175, 0.06575232296581231, 0.022058023229962396, 0.014323810220605904, 0.04839742458575676, 0.11036296345053181, 0.02166411231061624, 0.07573097058001065, 0.08432417116578549, 0.023596164988233678, 0.05575874812840935, 0.02735427441826511, 0.02905798309873189, 0.0536151651683594, 0.014231808806559252, 0.016799521024128603, 0.019968606516598694, 0.027165830195430788, 0.022293037937713728, 0.025154903020349242, 0.044428529893799175, 0.07935640507287557, 0.06210107897077838, 0.013236724752782574, 0.028811544104809725, 0.007497844720003947, 0.07185782921770889, 0.06616907479662089, 0.029848296638397925, 0.061073709099042806, 0.05740650366210649, 0.018250183202326298, 0.037797575425957484, 0.038899546939759486, 0.06188865428069427, 0.036317317356025024, 0.04102414624104577, 0.0519592929331045, 0.07902603731640885, 0.04576802313808472, 0.10398773296225457, 0.05213003860966814, 0.01094390307703326, 0.025234884514863935, 0.021169799823133696, 0.04615718814273996, 0.03196241202644043, 0.041341390911369555, 0.06197611470856975, 0.0475053611632076, 0.046317227740561774, 0.008135078091835304, 0.032384758214316064, 0.06368799946240841, 0.02989231413530727, 0.06239235709090868, 0.0615602630310722, 0.03309704378367432, 0.05234812468951268, 0.04224768441711222, 0.008674721917017333, 0.03304083591266986, 0.04282672431380038, 0.014967291518264722, 0.05390317209305302, 0.05065675577028625, 0.02228569690017931, 0.005296562890326905, 0.05243510631243548, 0.08200101719628419, 0.01631441882871572, 0.039303125888710065, 0.04917824821126077, 0.014636105962938841, 0.04563026137710099, 0.03463780364742683, 0.040786988402326266, 0.052166067724747044, 0.027591125821814905, 0.03586357880023218, 0.015434350427840988, 0.03827750652788147, 0.03096920584568814, 0.04590842407196761, 0.01872020304172991, 0.037996555272970474, 0.06559288474701105, 0.008352719840683765, 0.04380853110623937, 0.037168506157374194, 0.07618416521337724, 0.048519037213296666, 0.0450954209232042, 0.06169198801921261, 0.09019194501301936, 0.07850882071521013, 0.016653975809834177, 0.05085927877394904, 0.07422429013756976, 0.08664603044669475, 0.0586986871466281, 0.06202075848235719, 0.0601252424530685, 0.053489971079773484, 0.010103993962759213, 0.008261676036542463, 0.015341562816062042, 0.06191848957490537, 0.035162596858196685, 0.02822619930450474, 0.03024882655740986, 0.06158289709879507, 0.017915243816171444, 0.02702161414368499, 0.03678315244014225, 0.08701117093404455, 0.040706710048740914, 0.029438700068802125, 0.04590608750379855, 0.06022656141149421, 0.05094621443159638, 0.003935872711383948, 0.03959962872848396, 0.03184347879141569, 0.044466416772094466, 0.04684113228933946, 0.028219522848244638, 0.016894554231135596, 0.050882249920358585, 0.040691196768274235, 0.08513587962595687, 0.024442720872860764, 0.04095613295512815, 0.09418285707192076, 0.08267053973770912, 0.057028282223449606, 0.037967359662176146, 0.02527900734886287, 0.03446411619323396, 0.012203412911584301, 0.11663467247760105, 0.03800257672405532, 0.05321370062207984, 0.038606874539607, 0.07745726544770502, 0.1273457844170832, 0.00959451197676601, 0.022559148154311606, 0.03393828493332671, 0.01565810077027568, 0.05166028498581821, 0.03547582339735762, 0.030887703666643753, 0.031617900371671684, 0.03014652700644107, 0.04842555533433634, 0.04849119757812831, 0.024990224760145913, 0.054625118031136455, 0.00969471148921237, 0.11386851284412608, 0.0555794797236881, 0.09018957780133333, 0.04658361183359258, 0.030956814373512904, 0.022514017914692243, 0.04383959214112932, 0.013207495625641559, 0.030109360250794602, 0.055333128829877225, 0.07807500810632784, 0.03775157567654406, 0.0479655348575644, 0.06636309422432415, 0.0419466846412228, 0.0667065697451753, 0.034097654204214775, 0.04420488201562436, 0.008619348124240436, 0.010330043526576653, 0.05928764788193568, 0.0718292311554955, 0.02090185865639679, 0.037369110110786655, 0.0486354825777873, 0.06046383416340236, 0.03973733303287337, 0.0723045657298738, 0.0962865268511157, 0.07077452726662159, 0.08642869130257638, 0.019513061908524365, 0.031527297068086844, 0.04749469721930162, 0.01681803736925846, 0.03369544655264866, 0.011957653820694936, 0.04092291538273135, 0.023589270196915157, 0.21826961918944315, 0.15756625231475602, 0.11708261174780708, 0.18706215425364434, 0.134659503256121, 0.13822015735410875, 0.09167836242986303, 0.11785258373786366, 0.12909398173853276, 0.13019203088216244, 0.11615222860728541, 0.16293593111538118, 0.14550467292147298, 0.17812935455191523, 0.14128248657911055, 0.26952710663599355, 0.16625266281827805, 0.16066081851961153, 0.1149389521789647, 0.10527845321884079, 0.1299200543472844, 0.14450385565719298, 0.2647959008332222, 0.10853041984861898, 0.15754118591787356, 0.11093820355111554, 0.1536724112567402, 0.1696389246611826, 0.152793693085832, 0.15951502677654067, 0.1442314807565943, 0.15996841293188835, 0.15169109337993208, 0.11921298735204244, 0.12084244104522852, 0.1059196764723428, 0.20606070576656252, 0.17259501281284517, 0.1347192427924564, 0.14618817656751604, 0.16588002233014953, 0.1950489119776795, 0.15725591009662998, 0.0756390247073385, 0.11742968022102311, 0.14860064872810919, 0.18928667440289454, 0.1735330261890927, 0.08028480404567334, 0.09005228718442303, 0.10939316508630592, 0.13390383412761075, 0.1419767460996105, 0.13234646930809946, 0.12289521194273427, 0.15530255442905813, 0.129277904127394, 0.21974329656410604, 0.17161442026976617, 0.15639213064024526, 0.08505439085345115, 0.10963921720582633, 0.21447083432107203, 0.1276980929317013, 0.14478075047654493, 0.1794614129128956, 0.2004936673948842, 0.23120319050165916, 0.1593553740531206, 0.12408592708168492, 0.12285850867028199, 0.11548720300197603, 0.22514188752299358, 0.16527639101109198, 0.18965113307199172, 0.14494202730636443, 0.17523286804076166, 0.1991157050454809, 0.12997302166636915, 0.17390568199897968, 0.1433182886290935, 0.1755397935067454, 0.11570612028721841, 0.16663953722003969, 0.14794060269430762, 0.1711788226760203, 0.1044981160591687, 0.12369824062672355, 0.21351964423252692, 0.12272117974897548, 0.11786933041988842, 0.1880914699887076, 0.11907115383374116, 0.23082160210657507, 0.11817026507830429, 0.13561771071005252, 0.078500991296624, 0.10766264141326952, 0.15074235477274464, 0.12356756134859978, 0.23426254730551477, 0.12834380546043958, 0.08940258333759923, 0.17539589155104854, 0.1339784204479187, 0.20471654321637847, 0.11540080360587567, 0.17034691247728564, 0.09007500935225718, 0.16128585433527348, 0.16401283623230073, 0.16457977193978526, 0.1829882059246302, 0.09516348025851673, 0.15480006203776406, 0.13429852262620004, 0.13315499850338505, 0.35131863708938327, 0.09799175430089237, 0.11567334704581769, 0.12478120549912415, 0.16899372541135357, 0.3004553631669091, 0.10156008459988142, 0.14121648044355456, 0.1669557476716657, 0.12922017174142023, 0.24166136319118164, 0.20248580243318312, 0.1493820430891168, 0.20597678849533682, 0.18918685314636077, 0.12749127217478332, 0.2236502070821101, 0.11741151627633842, 0.21595797952144377, 0.23781328822576234, 0.20374598642510755, 0.10727209745035057, 0.16078081853207082, 0.12868856800900352, 0.11370540506416753, 0.11321268029390805, 0.23146600462496283, 0.0878394805195351, 0.07967168089723395, 0.12310597039158307, 0.08063959468516611, 0.23032744475189718, 0.17137969092976663, 0.16134648253360104, 0.18317097918160502, 0.1746418005636623, 0.26316324489251264, 0.16279843365473134, 0.07778025577746092, 0.0941402166180553, 0.16891262734368925, 0.14933174175600852, 0.14709848820442153, 0.18912473873746014, 0.24685977537545467, 0.1595590921539453, 0.16696051273855472, 0.14106572966181463, 0.20522776901000933, 0.13766599999320123, 0.15505345327959907, 0.13143531497447722, 0.08466541737077699, 0.17141592688858512, 0.25385291706169805, 0.14596061781048775, 0.13985198591986012, 0.11630756059481252, 0.17231825588931962], [0.022964766812360576, 0.012843654614933317, 0.031902446494167375, 0.008854200038307858, 0.013767421628618914, 0.02397596456801459, 0.061733716828448165, 0.0472840958184773, 0.015832343638213654, 0.13037324131977174, 0.030064477074530818, 0.022230370030287775, 0.045249259039278955, 0.008334892974685757, 0.0500935738936307, 0.011186965538429157, 0.02467340335340029, 0.05253518420842387, 0.10830215629070036, 0.04005968367921249, 0.03996563872562782, 0.05587899711944404, 0.0177850337669013, 0.026023652472142732, 0.030217641033232216, 0.010207293258469191, 0.0327454132568692, 0.025402351335111647, 0.03427203496797912, 0.05129575353836821, 0.04926185904731674, 0.016320076388036533, 0.06563345676348095, 0.024580109165981415, 0.045397738370323376, 0.04430934193453962, 0.007980165058641785, 0.062172443891364726, 0.009239193694215388, 0.014852719238748955, 0.025156274317733707, 0.03895405026513242, 0.027816926407056953, 0.02695739873865199, 0.06147566394159391, 0.07635275818287365, 0.02193017656193866, 0.022818007348706166, 0.029950946674592076, 0.03821592455008819, 0.06700477713058073, 0.05338152750365196, 0.032151507424010385, 0.04077854228296107, 0.023390282689022924, 0.024720720774043473, 0.0364913648715423, 0.040389178095445524, 0.10860126765985643, 0.058675294651860194, 0.022396247218092604, 0.030818246304988865, 0.016028419054383715, 0.022589979362824274, 0.08854602809034048, 0.02680769366692872, 0.019574193809662136, 0.024218040691207976, 0.020884656152057073, 0.09020048689337508, 0.0230590894728178, 0.009871038116304385, 0.04636317769426011, 0.08720957238467471, 0.006460283006045727, 0.032696988839175434, 0.049586504126989076, 0.00600562849637842, 0.01806190943405513, 0.0368129072951213, 0.049961446709330046, 0.004100756618314453, 0.026139576896844853, 0.026163706751239878, 0.053351267030642885, 0.04598084619388946, 0.02356453321784014, 0.03536119749168715, 0.04253789001414853, 0.041498852623326164, 0.1017729344687635, 0.009766616501785334, 0.0394844857134646, 0.09236535177596154, 0.01942248350279706, 0.06975580652755115, 0.03936170097140055, 0.055604266498478196, 0.07836647391799959, 0.09504744092062598, 0.04363637199745544, 0.04812438318866396, 0.012343793735659171, 0.06885816598491323, 0.035176769484795874, 0.01826987549241993, 0.05149870938170822, 0.06842851323345978, 0.03867330202352136, 0.06389283988204214, 0.0027992136939804283, 0.03937664734680326, 0.041855895561316324, 0.011792423977186123, 0.02828797663471872, 0.056888635886172136, 0.06857301273773755, 0.040370642598117554, 0.05288613291697637, 0.05421360624172995, 0.04835273101625424, 0.09649205291944166, 0.017862422053792307, 0.03689584397380391, 0.002782098092739621, 0.04238589433953167, 0.012174191445322528, 0.03093730019886167, 0.02065734062794476, 0.0524559055995797, 0.035646607378317464, 0.05362497109379019, 0.0667502214351008, 0.015616297267467506, 0.009351884270267142, 0.10417219161266282, 0.029010508630064227, 0.02056567246214517, 0.06115278086414742, 0.009760140185995449, 0.048619042330932234, 0.05773327463576871, 0.008517736137183684, 0.07581113402040736, 0.012810090387750779, 0.03247409172716641, 0.09295506327743493, 0.022534204331497033, 0.006993746416898625, 0.02663880958402109, 0.04040131292816612, 0.02595880695979201, 0.015248381626611997, 0.03977621965590985, 0.09154982053704801, 0.04566509539501802, 0.06530730249059778, 0.04282984995253144, 0.044121627410453175, 0.017098946489333626, 0.03781429912534453, 0.010916043332056894, 0.06948101078911174, 0.04674738611004526, 0.0035463967229119476, 0.012839568493467186, 0.004112529474490833, 0.05701094565372314, 0.04516118191062443, 0.038288990185866435, 0.045035600947636756, 0.032647522541904644, 0.032343646105859554, 0.042739597134171955, 0.021696167344587947, 0.044142058975393736, 0.035184863203715895, 0.07351683092213447, 0.0396280046251993, 0.06931552813658792, 0.004188667122845448, 0.030663490798624776, 0.07087804872782962, 0.03831960305932068, 0.08190508000552654, 0.015030993644388453, 0.05346524559201733, 0.029179852365726427, 0.0261747173499316, 0.023941693624721903, 0.02412922620292633, 0.03129521647708551, 0.010243043709065645, 0.06794780072185301, 0.012558901648698075, 0.04836386993467327, 0.02558332237024461, 0.048576440181463, 0.013960322567952738, 0.02819122164510191, 0.00605223297644707, 0.009324614412992472, 0.041624142472902616, 0.042291519968139554, 0.020426355542675145, 0.025243384260383826, 0.1035195996143645, 0.002576446338113578, 0.04371865750140241, 0.06432480238858732, 0.021613833960145715, 0.07914609095502285, 0.03943091318491967, 0.03956639200388905, 0.036681067393792254, 0.04089654280593799, 0.043377177639594006, 0.034719591194223014, 0.063836831193898, 0.014552109210091013, 0.027720435717774015, 0.0682423155634634, 0.05768270517188696, 0.028942535563762632, 0.021937151792489236, 0.04253554195466061, 0.05080081094356795, 0.024794090929771626, 0.06108441900822425, 0.07710897123381015, 0.030659068556081866, 0.09081199359629424, 0.08341831049972004, 0.019958852302102793, 0.047415372645181995, 0.0423161190513882, 0.027912055375054482, 0.028111814716530424, 0.06375490575127545, 0.09999648382466647, 0.05554676010844208, 0.07190134301180802, 0.03567606345900605, 0.01335386151162487, 0.04959567419944271, 0.0751262667378591, 0.03746716170421532, 0.04585585128816386, 0.03993783356441606, 0.060804478989373294, 0.02240967099374581, 0.011038152959137675, 0.035258388492248716, 0.004742496023555437, 0.020393754671057387, 0.039789155050511324, 0.02119395074494664, 0.06763024961635952, 0.07720513825094508, 0.03714939609410302, 0.05127765471115709, 0.027573892673958215, 0.03982549826163919, 0.004067965182325533, 0.0754979036508068, 0.03391494223427388, 0.020505059585576097, 0.04151049715977523, 0.014373591571535557, 0.05669357457889184, 0.012923157304495335, 0.0415292663139201, 0.07664754881613678, 0.059172907063076575, 0.03393878289047749, 0.06220741197466851, 0.017803921664674437, 0.07310819196244402, 0.03220166320041303, 0.05091370932096916, 0.010394671661478859, 0.03757816018356431, 0.02629235781158411, 0.04122101168538775, 0.022831061486935905, 0.05283342606778588, 0.019701421861687017, 0.006177112490179078, 0.034331077364303415, 0.03321044394866594, 0.043289123493577206, 0.05694954753703168, 0.022330292793471488, 0.06811724404894537, 0.0058262518817378635, 0.06247574576146661, 0.034463802097185005, 0.05383448081932241, 0.006502614151911751, 0.045697937584331924, 0.02484239277339751, 0.03836752185898443, 0.07115614630522267, 0.0546879104278501, 0.01887613257783796, 0.011956039290394516, 0.08009128257512085, 0.045734863022282246, 0.07254720875813116, 0.041857121301995176, 0.035315370112056696, 0.06150828396540977, 0.06427688358892357, 0.041291062765183954, 0.022030495775623188, 0.026255177649398966, 0.04868663043805188, 0.04955088103851003, 0.057967119144215706, 0.09171040022685643, 0.031210431611285578, 0.007273554285582636, 0.06840676399728945, 0.036181482306170853, 0.030548820842898665, 0.04151858321781601, 0.04690590119289775, 0.0739132967447081, 0.03035474587382088, 0.08774856120468148, 0.05695365376830582, 0.0398755774292494, 0.04425019994678517, 0.14173427927157572, 0.02025725120948928, 0.012827678808882352, 0.08207645387418809, 0.01336834919188292, 0.04839960793634096, 0.04941544435437649, 0.06453524674138715, 0.05973207080856927, 0.031861320979172186, 0.03515583613226491, 0.030493760188560814, 0.03912282709573065, 0.03723782945364233, 0.03458172218092988, 0.04277014489015264, 0.028187563575263468, 0.05118754744950322, 0.031946228419040004, 0.08679994517156193, 0.08229148709365437, 0.18370152571268622, 0.2279793239769436, 0.08780518276316505, 0.19047709842843397, 0.14801353426469913, 0.10208378230491955, 0.1921462048325808, 0.21870245886666162, 0.16187158984041985, 0.05148087868527059, 0.24343507124050973, 0.15616045033018436, 0.09879654498710748, 0.12954753643322375, 0.08389109400131049, 0.24828727297004194, 0.1902719707258286, 0.1106569956567499, 0.0835419187863027, 0.09100232814108172, 0.14642823787946857, 0.07014179992819987, 0.07512774528755296, 0.17474228065581093, 0.13336648473576193, 0.12124325824721206, 0.14629889159433304, 0.0676322874102381, 0.17694548823900763, 0.14324987697745525, 0.23327567284145664, 0.128158358556609, 0.117939802848043, 0.2321127513723989, 0.13262958476139655, 0.1330474091152991, 0.12716156325393146, 0.12962167842253564, 0.10739549123231443, 0.12246657042734085, 0.1198467029438865, 0.0839743907413175, 0.2092060789225563, 0.1923377421354094, 0.07926616757627457, 0.08951259356352592, 0.19803760483139948, 0.17531952790675626, 0.12767549333793501, 0.1434945961039874, 0.13492207223128888, 0.1437965419984633, 0.1319287368847478, 0.14934416770214035, 0.11455830607202747, 0.1950528496696103, 0.18893608192522682, 0.14889583772709294, 0.11176676594562109, 0.1623600168574241, 0.198947380206758, 0.14494916724581874, 0.1371422103576122, 0.19350101600491232, 0.14014899820810364, 0.0834114846563147, 0.10042325608552465, 0.33891662354430846, 0.1174755305832913, 0.08525968709539983, 0.14198100554846949, 0.23193592295771648, 0.09494294652775412, 0.12706145854486575, 0.15604642580353445, 0.12720932117513112, 0.13425522333671971, 0.07581068202853203, 0.1697927857598951, 0.095078551751231, 0.15073688490496528, 0.14313902405481185, 0.11911113596250934, 0.19575939724041572, 0.10466986531091314, 0.09344270122387717, 0.14562577610054325, 0.175893695484246, 0.277789885839147, 0.1047557820716212, 0.10348251329795008, 0.16950591647576901, 0.15037155289563442, 0.14201118941268615, 0.18169207708729854, 0.1433293662604786, 0.1542441426746307, 0.19569311531320696, 0.14370015281583035, 0.24515942790575568, 0.08313322620045754, 0.18403370143665423, 0.17843517685128799, 0.13427287400249513, 0.10190403509524562, 0.136120846615203, 0.09386113844811918, 0.11810955261030506, 0.20275299857941367, 0.11392772377979372, 0.14872636375648363, 0.1353855554254786, 0.1237136772983978, 0.21348373003063664, 0.1339757391401837, 0.10439034280998093, 0.1324719391883381, 0.1615947103428264, 0.1276742905798939, 0.18833332394640293, 0.07102360543344291, 0.17430623873106896, 0.09229668731530828, 0.10494416309220177, 0.10037806455887134, 0.1329851414888136, 0.0770963614265765, 0.08696080831390235, 0.11414910786815229, 0.1173738400722223, 0.20334297821166056, 0.10532891543041314, 0.09833002808473765, 0.24614359041856182, 0.2312398707914737, 0.10642441350125498, 0.2272131441221122, 0.13078524340544978, 0.19359994859945392, 0.16376482292769418, 0.19629728289381151, 0.14407697614402543, 0.11997154463202724, 0.06931662364231964, 0.34667497981459866, 0.16752263741387477, 0.07281662655934211, 0.14366065332245442, 0.14981407071313552, 0.15233348874795824, 0.10377131312364533, 0.15376411198127657, 0.25144242140794953, 0.16485044612519203, 0.2469599490324336, 0.2930477219483545, 0.06732038237274655, 0.09276898818150645, 0.23771571926772597, 0.09399918749207452, 0.16372861761239269, 0.13420130606860886, 0.16124379610823047, 0.14043058148555218, 0.10478424223800821, 0.21373615600168708, 0.14409004560401364, 0.16179393916841478, 0.10737587938145285, 0.10512649967905977, 0.11454942711298505, 0.08554070346778439, 0.13870792553549813, 0.1171021240072385], [0.06587177139496611, 0.02213467415722628, 0.048371653387983965, 0.044024518105171384, 0.05099342459993017, 0.028713567204953685, 0.02673959994177905, 0.12338800566090692, 0.0366489491575668, 0.10373079473333013, 0.04745282285336045, 0.014182376983245055, 0.030402494218921473, 0.024152630189013098, 0.01670303799572491, 0.03712037668353127, 0.03957693337372715, 0.011312167287894316, 0.010852480059369438, 0.09152582666325955, 0.018206958606418584, 0.021135599742974007, 0.022496235098749883, 0.012744191504504173, 0.06121956840938619, 0.0476728433052138, 0.013389390754333187, 0.02693864107582598, 0.07120136847539295, 0.060884485381745526, 0.0018056182448016181, 0.05091623741111929, 0.006698238533816391, 0.039531703542677626, 0.05986914692086078, 0.0764543874069087, 0.017122873330428716, 0.02529384264151656, 0.05280307366422588, 0.010345802912789007, 0.048260520843248216, 0.04535789796782117, 0.05581052418077185, 0.017941444023181836, 0.024237905351084568, 0.056165234381032575, 0.10024348589321298, 0.028771719024066004, 0.041881567167658965, 0.03499697247940687, 0.029555708507917104, 0.023908864841946674, 0.0683364371258405, 0.04665793768400627, 0.1311848042232375, 0.10611502889303431, 0.03756121814911885, 0.03664599971905832, 0.016097353561030283, 0.015854180016885364, 0.022026717046936675, 0.01782564408776741, 0.015056656632241944, 0.04508977868564187, 0.05777187780627321, 0.011276033793335721, 0.014257880693842328, 0.0618668973836447, 0.01700818805294412, 0.07562949457356045, 0.0472736617009486, 0.023712102819474477, 0.02766221112030889, 0.04501143853450495, 0.05365603212868014, 0.033177513659240744, 0.09491768094801134, 0.03786702129629351, 0.0721784446748995, 0.04882775915546283, 0.014167241001081084, 0.011979785143217493, 0.05444849646019359, 0.01790761358044561, 0.018509760604149873, 0.020537436376476002, 0.032111624886672345, 0.04424384524745326, 0.03254896533044596, 0.023161427328182806, 0.03785355730102428, 0.10887214102812352, 0.020471920537191535, 0.10800457709739286, 0.04564230427927068, 0.03221315451927724, 0.09250330888936598, 0.03591119499516583, 0.009724067978470797, 0.04418842644701081, 0.01112764735045212, 0.032882458725643736, 0.012668002145214668, 0.029833162571453763, 0.06898141421017147, 0.03858220650844517, 0.029374245261292786, 0.007257800645029714, 0.0490252144875065, 0.009799993037426425, 0.0339933704855221, 0.03570932316623869, 0.030292424621180664, 0.02345214045846895, 0.04805050166924635, 0.058032926096911394, 0.020691764788822304, 0.03385920167690323, 0.026225516640190637, 0.029353300417442958, 0.06095779616565955, 0.07212182311641593, 0.023784390876009583, 0.038340643664161046, 0.009907633178837357, 0.042193943349223946, 0.03771348578494884, 0.03753850747260355, 0.013907360994527418, 0.04093733698790593, 0.05142982658599654, 0.017250691270155293, 0.07689144056771072, 0.020441114226536407, 0.09148849519870936, 0.06850837789956601, 0.08022394602096851, 0.024473634435825294, 0.014408951317290626, 0.07899584579131297, 0.04062949604685268, 0.05481716478243471, 0.025893802484197002, 0.010123728387688678, 0.0257387041534868, 0.03282397174306455, 0.02956170889158403, 0.060015446731760624, 0.05997225852502931, 0.06784019601200858, 0.05445667444878528, 0.05664751354244448, 0.0702906048466121, 0.01333035506127823, 0.07220489003004567, 0.025309501478688854, 0.0724821066063258, 0.05455047808467381, 0.03281095973967064, 0.006303780340409328, 0.038042857627113985, 0.05385852065838633, 0.002611189622492079, 0.06991323759599079, 0.041592591141741124, 0.05742260683027487, 0.03640444070521382, 0.025895204425098437, 0.03779665995088797, 0.047625717406551686, 0.03588052849555689, 0.06970544390740895, 0.05224856390287319, 0.02563791188050903, 0.04633569428997655, 0.04898893256341258, 0.04820840771219904, 0.06285302874241626, 0.04714653707079349, 0.04971689612214124, 0.04894490549040418, 0.028170765182303808, 0.040763618890196085, 0.0563057157541475, 0.02451937180012465, 0.08469684995831021, 0.07175551051454199, 0.023416555674386122, 0.05267578049472744, 0.027103708125650886, 0.046252064301722476, 0.016236247216922142, 0.02693918691347203, 0.07018006602001768, 0.040881983304937045, 0.03963370048891633, 0.0189665750029587, 0.08712086706392227, 0.09517157014699713, 0.04764210785769167, 0.0537587913324035, 0.012831356988528804, 0.019755714512880773, 0.06650252988742245, 0.023055925529690522, 0.07650637413345038, 0.020156219534035173, 0.02640991974922438, 0.051569285231732556, 0.0334630576112578, 0.018596192558987007, 0.03392592027422882, 0.03192407124105, 0.02814943346405222, 0.00898137829461766, 0.06303646083500597, 0.045664846416442625, 0.07078212685883045, 0.07175251511075804, 0.007146920430504027, 0.04114119681499658, 0.012315346018200921, 0.0683673257909475, 0.016666834595643224, 0.06482316556596948, 0.031005139199776516, 0.02751840109516296, 0.03311639133420202, 0.03417617055557428, 0.04868611332870299, 0.053403698088180636, 0.12175917249893951, 0.04243758995266211, 0.05287465691987065, 0.048950631997638175, 0.016068267117765163, 0.03373815978486692, 0.03604242202615546, 0.03842197921908191, 0.01692881368310942, 0.05041950983145545, 0.01295969395282408, 0.010973833174624992, 0.03695549541002801, 0.08384034067632691, 0.03140389945568337, 0.07863752348648925, 0.03471942265487967, 0.02420450391758594, 0.01823362995750241, 0.06695458304978187, 0.06811876856391469, 0.11845339585335986, 0.030203625454657504, 0.043813962669622515, 0.024907494925202864, 0.03790223452773306, 0.01489513273906684, 0.017208895428226362, 0.04656236055457304, 0.030041484860703353, 0.021930917752005404, 0.04690047729039385, 0.0421737109671437, 0.03934466317596455, 0.02086840168152365, 0.04110008087610045, 0.08956726925868182, 0.04080537834294862, 0.0176130585192192, 0.04454634655567427, 0.02670190075502521, 0.07903150718418822, 0.017216738253351183, 0.02970641523960137, 0.08271211532935982, 0.00931265865332417, 0.03784639437893226, 0.023839516647820993, 0.03135279947591405, 0.046396927697764295, 0.02952365730438502, 0.023895458303271763, 0.04202304062463584, 0.03783089258978444, 0.052625050152381586, 0.020418167977984396, 0.03487192394752656, 0.08379152555379175, 0.047842991433196494, 0.08429429373673855, 0.00858898422936158, 0.04968263667016741, 0.026547763864659978, 0.03839800066705193, 0.06685954218189563, 0.015029157906199896, 0.029049305237769604, 0.01780384888632163, 0.03480280366455836, 0.05247826387564983, 0.009899299099831092, 0.03446325817475877, 0.027964421315118674, 0.042229313628687974, 0.08095611923284109, 0.03002145932236266, 0.06270974731793807, 0.008842626364991791, 0.08259498048573732, 0.017206566520936547, 0.027288208910894972, 0.02373651038074205, 0.013131227742339815, 0.04060613802604137, 0.05196046121718903, 0.027612878888424848, 0.018385889932453152, 0.07832976298466807, 0.01988695111996945, 0.026528831916831197, 0.0367068654046424, 0.019797895313991655, 0.04438712284149182, 0.042673794011915886, 0.040948008592691154, 0.04167506816766916, 0.019343547718299013, 0.04070561071256957, 0.023433616452459848, 0.03567208746267903, 0.019885621957420822, 0.10268282475731066, 0.016755947858215343, 0.03848460307645221, 0.01305933900913524, 0.060419163576537566, 0.027801847881487304, 0.028872980525897398, 0.03856500783454507, 0.011354949468025758, 0.02806954581530825, 0.02273001065928369, 0.03992517779190694, 0.02996748268243767, 0.04871260847956423, 0.0737301021393749, 0.057245223001847347, 0.050672789990541436, 0.02253425795765173, 0.05332520471945886, 0.045281044027257356, 0.10729511073159595, 0.15567914793087592, 0.14087460604646515, 0.11842439176454661, 0.2110916051653124, 0.17423531431103909, 0.1921906072886721, 0.24884040377313094, 0.14636244624853134, 0.22808331275178542, 0.14533133786772529, 0.0980757175373935, 0.16976281640029725, 0.05758392962536985, 0.1031938513680812, 0.1395358827205435, 0.09035244809403535, 0.18742770076759402, 0.08410679371727091, 0.15242292185223874, 0.0741380133155373, 0.14927998485584415, 0.18627705202708322, 0.12140642731420456, 0.1230268335090049, 0.10101417800591839, 0.09381107460226744, 0.1338729914277792, 0.1474747139840357, 0.1921823795043653, 0.24618901943247168, 0.10837279725819828, 0.12272948414207467, 0.13636769546616462, 0.13231115265479013, 0.142335535718068, 0.1575555117620576, 0.15361461758373246, 0.07437477278853617, 0.16892595727357174, 0.13684723586324724, 0.17743308788105366, 0.17133956324429284, 0.11557407737258943, 0.1601352209165212, 0.13880596946804755, 0.16869086021136853, 0.13665888548618363, 0.15650932677090168, 0.13470798129996947, 0.1325153916954033, 0.08490999860148277, 0.16440689653879212, 0.22256754098399995, 0.2209866112999378, 0.1942164195521224, 0.10098443081181857, 0.18983591347932818, 0.16951022188990347, 0.10647617040141936, 0.0996069357760491, 0.15446267691591095, 0.07716915510114163, 0.1180739984697392, 0.16287796890303013, 0.15667932168129953, 0.08831668434844864, 0.1893456938165811, 0.1740471477950773, 0.2295650800149287, 0.16612109487816212, 0.09051531838673739, 0.1195485185411188, 0.07411480851231084, 0.09888280648738147, 0.19451222142144559, 0.30231937766075134, 0.1275502762667114, 0.12999376732735865, 0.06580866107176389, 0.15235454084411745, 0.1128552083466803, 0.1098323403106582, 0.1934354542003524, 0.05537640513671983, 0.0579327562703721, 0.13583527968054818, 0.12911794496880424, 0.19667671092094915, 0.08365415832808903, 0.24162046941778353, 0.21567365364922633, 0.10278523539102848, 0.19346003030096331, 0.17157942537338505, 0.08696137521896632, 0.1791547785603231, 0.12554150179869708, 0.15946161512645984, 0.1257307868030283, 0.15289189023596628, 0.08693854579882276, 0.11490879129738578, 0.19764581214516394, 0.20833839241775776, 0.14535602122064561, 0.0821417092435783, 0.08524189853379804, 0.13785739940020347, 0.10849019257171501, 0.1593513750741559, 0.09088644202077582, 0.1310653557940837, 0.09275872260332109, 0.11485046136283106, 0.12276286259293558, 0.17580371079666002, 0.08079097365900394, 0.19164061744607266, 0.11802080132427717, 0.10666003150324668, 0.19293619470009882, 0.13802684272729582, 0.1105008056507476, 0.084268530199845, 0.17330539082327198, 0.12359116451754687, 0.11913026517797863, 0.18551523887342025, 0.13513407940345426, 0.21845721880034094, 0.15452848386860665, 0.09832074309909537, 0.12696167559272822, 0.23595377832891481, 0.19217504038205072, 0.16200711079422506, 0.08028354000059829, 0.12113259684654976, 0.2372136558856695, 0.09916801336071185, 0.13686359950130986, 0.1465755565873077, 0.10043306967183467, 0.14438236943416058, 0.11652752742051117, 0.10150594516627251, 0.1045911650984518, 0.18772929426162474, 0.1424333957895156, 0.12132630217820407, 0.13917632701416172, 0.19019422812327264, 0.13113028940654572, 0.13450841539569441, 0.11570424337180392, 0.1828380833349882, 0.15748889275616215, 0.1316728788397966, 0.05633533654373981, 0.13574661266419197, 0.13585403351293457, 0.1544729578158548, 0.1429224050333423, 0.14014398799307887, 0.15528114993245373, 0.1151811738588637, 0.1269001970368047, 0.10415372123280842, 0.1206254159971591, 0.16824038519013315, 0.1392337376432073, 0.13503231228359286, 0.12335383047860478, 0.1155133649045902, 0.17442329696589903], [0.0731221117800282, 0.0837075929608076, 0.019997066682985714, 0.06407293949216124, 0.04085769065685811, 0.044742082020327936, 0.01188998335912343, 0.07283885843090473, 0.006916557791672888, 0.04955561163144247, 0.07518393017591969, 0.023412167905799808, 0.024185838185310848, 0.037108199715974836, 0.03904155282784374, 0.04748111831084375, 0.07352110569275196, 0.014111622060168416, 0.011644527830574061, 0.02845063625324157, 0.012484848717107408, 0.032245724747378024, 0.03951191549159346, 0.1493144281689198, 0.027694790924508727, 0.02611984630235501, 0.050836353592814944, 0.04926068693279259, 0.008761825156398118, 0.04829119883417603, 0.06184642368386831, 0.017134374225391977, 0.016613350167209585, 0.017024953887167, 0.04096891130170515, 0.023242515819748084, 0.10756854283353014, 0.06918382230064563, 0.04932897217992333, 0.0486775599570284, 0.04727105317156642, 0.00447826128595719, 0.04880127166548083, 0.03880935923887357, 0.07438897605865233, 0.06792451164895488, 0.01084811335820104, 0.025307046166891535, 0.011204321260353731, 0.015864386223256588, 0.0135636767147169, 0.08895988410879528, 0.05921793388082616, 0.014137753319265622, 0.031136157471806775, 0.03590561404463745, 0.11241890595204408, 0.050347474583935355, 0.015649777224978373, 0.07910109861122985, 0.06397364300585563, 0.05811140797431431, 0.051113240751287634, 0.06418704828848282, 0.04420163763326503, 0.01283325688658102, 0.05129880256830685, 0.07167395279412309, 0.07151549516786491, 0.049871745474276044, 0.06505805578443312, 0.012922372064372946, 0.11451011148071098, 0.0495109640272154, 0.04500385809449419, 0.026021065010178476, 0.05002333129185343, 0.039409746175571796, 0.05260460709612216, 0.05177886773561759, 0.023296553746707017, 0.03443116292117104, 0.027149560403138883, 0.05173924949861342, 0.023746597843485016, 0.030068673321136066, 0.0889191895182575, 0.06183918798342348, 0.018684656562043295, 0.040249493453771844, 0.023483649654794606, 0.057172655323219884, 0.02961519140479786, 0.04282031598831377, 0.029346432439201785, 0.08166420664037428, 0.01959039656926067, 0.026161479350600033, 0.04334212145617893, 0.057835309886403626, 0.01647671072503492, 0.022161104190613956, 0.023309711306806535, 0.057321724541966, 0.025225155198225574, 0.018560563724848534, 0.01978940705979063, 0.05229516503130717, 0.028313502684355746, 0.04620711792320494, 0.03510049011017527, 0.034042246895091194, 0.03197716879508188, 0.043958282143238096, 0.08311437277664101, 0.057180775855217254, 0.03921619789194196, 0.03476153067763775, 0.02051287368240376, 0.03630218328908086, 0.05118796496742195, 0.028076902174601154, 0.04088257319263874, 0.04774032799046367, 0.028710039370062373, 0.025110542699093782, 0.029490545069077806, 0.04226324366285436, 0.01709960915538813, 0.02068517068701406, 0.028756588787561464, 0.0787916986812507, 0.0853613546238311, 0.02169333473448792, 0.06350319990287386, 0.037513234231981545, 0.0416604358883154, 0.048712018591862534, 0.0385397422548023, 0.02689670350763106, 0.03989585194616549, 0.036100954974010106, 0.05698928451766411, 0.060610513187824726, 0.038902860270032, 0.031127717098101016, 0.014218603365964467, 0.04274719672638082, 0.023880379777702115, 0.05304036556833214, 0.004251271828017648, 0.01219119955485146, 0.07295079153752135, 0.031161183649073207, 0.07972398171982459, 0.019639362994160865, 0.03098337655706752, 0.04505752255359004, 0.1038749878024382, 0.020084584567455516, 0.05767495236209324, 0.07682243902837077, 0.08307799126111692, 0.050244964358787385, 0.05947127915738572, 0.013771571909948705, 0.044644470927455736, 0.042297916802307295, 0.01735797422307153, 0.014955741785196288, 0.021169577657635656, 0.0544098396635344, 0.05462907487526537, 0.019098384260770776, 0.017295758307520902, 0.007001506887571587, 0.009729863433617978, 0.0424950925122586, 0.05724593929405655, 0.12666764338651013, 0.09573030871369186, 0.03134138093540265, 0.04811862603791299, 0.04626739755152695, 0.022115972035774784, 0.018390599457967668, 0.06326417664005872, 0.026745575427588437, 0.04299103102136043, 0.03960356642041476, 0.019801551468610283, 0.05669673852201912, 0.057700164315681306, 0.03928715295548882, 0.06702550746981176, 0.05509210990801935, 0.04372994580696668, 0.11134304271470155, 0.01531620913620798, 0.08541677342427355, 0.048380275707571745, 0.047602248302991354, 0.05796161863291937, 0.02531279757198307, 0.06478447812579333, 0.02924836169357502, 0.0326341811207033, 0.009674960784914513, 0.05484732566401363, 0.01854132725706985, 0.03420713199903408, 0.03778825213591899, 0.03996086599785955, 0.06211265455931426, 0.0720356229031759, 0.009168233842619005, 0.07282463983903009, 0.04045235353612131, 0.015008269561334484, 0.0456439015725928, 0.06238686041005197, 0.1056285094349615, 0.026761850965539777, 0.057433194165388425, 0.027403175725691745, 0.02071353126197092, 0.03716772474769143, 0.04264578583740419, 0.17514312850131145, 0.03157741645531308, 0.03331473532823786, 0.059314192828512004, 0.07519437961520688, 0.03688072905905786, 0.010432891788021212, 0.05077238908157714, 0.06428075999382042, 0.05304101674306778, 0.043482124024341186, 0.12156815613589941, 0.05472436855216661, 0.030982893921675223, 0.02112220086517834, 0.06610947315611186, 0.1019553629861724, 0.02869596825011315, 0.08244215360572262, 0.05366624791115042, 0.020057162450205897, 0.04525251108251753, 0.030436866668864127, 0.039041606453998436, 0.028136364004063993, 0.017721998137271693, 0.052311076677494475, 0.1013692444370639, 0.0491724374343551, 0.03528193037416186, 0.0476072853310935, 0.010850685498406811, 0.032389335589663636, 0.02534633690130807, 0.07900958940867456, 0.0251027247718265, 0.03246794004113444, 0.012124627471841391, 0.06980727231430431, 0.03839590924701864, 0.06832470065884053, 0.07925793213108856, 0.04123107425027317, 0.0654174276297131, 0.0167240479570483, 0.01011791761078301, 0.015258227771658812, 0.03409319174205584, 0.05457791935412153, 0.03381761076349405, 0.019890327652495716, 0.0036379514119377543, 0.04876061537933927, 0.01451221901187373, 0.03775020054871998, 0.023113891572481202, 0.0510455836962548, 0.022944618699952, 0.050112706939539606, 0.04110498000837622, 0.0235863609780227, 0.04320047179897947, 0.04519833717495204, 0.009686702039964017, 0.07023860279831194, 0.04106331248617461, 0.0811657515324412, 0.09194159790152505, 0.013641352284579508, 0.01835850995003937, 0.041219540796573126, 0.02317605194665732, 0.009516783738358608, 0.03526208869692299, 0.04479134530429879, 0.03521358000955755, 0.02896220104077891, 0.043648051007861094, 0.03071381511437076, 0.036955464766511036, 0.04598065850234801, 0.0634061327324279, 0.03392932553505225, 0.04084844014517242, 0.026641912240114425, 0.052348952064470905, 0.10130894565654379, 0.02981318682882815, 0.042420329991728074, 0.03641904617149023, 0.015490081409112582, 0.07007011708112494, 0.04181803549609838, 0.026038704184635032, 0.03369600962727301, 0.06348898514143883, 0.020647414043665897, 0.052788491180587205, 0.014819771712345463, 0.07173857231053614, 0.010838096758591072, 0.05631475176121439, 0.032942232735935724, 0.06980260683884544, 0.022130500893258763, 0.016065652842723554, 0.07825142283353113, 0.05884432046103382, 0.028452417407665524, 0.035986585707794276, 0.03643444836920789, 0.04237927150942626, 0.08151573880064873, 0.0366700855233977, 0.016482827937110298, 0.023326864015431176, 0.043113566784849094, 0.09521726729168047, 0.07412596275248835, 0.04431634397816755, 0.024241168885642005, 0.02994009312392483, 0.01370416479110117, 0.0022908355928056186, 0.14261878906719147, 0.16772028809833914, 0.15419621621408772, 0.21587904182172593, 0.2691276683922737, 0.12536631281217261, 0.14584757387638092, 0.17279005879836698, 0.08663701359182598, 0.15026618516252888, 0.19809775805521398, 0.2270026538040369, 0.16800502765803568, 0.17869776114821437, 0.13089519234434252, 0.18086848660342156, 0.23941842628823173, 0.17080780629429126, 0.07603629492223263, 0.13289852758809445, 0.12610624649471816, 0.13425084131379283, 0.1079788288822578, 0.2393249022744356, 0.09557331431536906, 0.15499624183341382, 0.16981782151326058, 0.12711339930613197, 0.1424774764886787, 0.12725562352927464, 0.1259159349325684, 0.06923561750520622, 0.12879595821422915, 0.1721648237998447, 0.22331239295101937, 0.2258252685949687, 0.2059476618324557, 0.1003072550520301, 0.23313734800584857, 0.12979766414050134, 0.19239977993551763, 0.14637706320612662, 0.10641938030359246, 0.16410439906101074, 0.20875362739447625, 0.16767403170947107, 0.22888827197734388, 0.14366885046324424, 0.08932445769108112, 0.18463457483918438, 0.12617792168091382, 0.2576790972342414, 0.3084388267128699, 0.205544883445386, 0.10166346816526306, 0.13091647426687902, 0.18042484508647075, 0.15633611429122188, 0.07473134075201328, 0.13063486034591354, 0.27038356229182214, 0.18037115764473716, 0.10585994459688665, 0.19853873358618832, 0.14594558716541337, 0.22752316458331, 0.1555786371952103, 0.18217567775037982, 0.1475999080726216, 0.21896496655479555, 0.1465048619936551, 0.15460277907550335, 0.24012990746526952, 0.10333780694993273, 0.11114028988466149, 0.2568684076710094, 0.11753042078306598, 0.10042651195920284, 0.10210579967186337, 0.14921702775022677, 0.12386999753934723, 0.2099600166923577, 0.1389930787826738, 0.174675676971674, 0.10158140482681413, 0.07381334525322722, 0.25663726362249545, 0.19863342205362938, 0.06772716739966024, 0.1262037082004451, 0.11945628155503543, 0.11090274900197984, 0.14709229821399336, 0.29725290113879793, 0.09396059198244926, 0.23422503964074198, 0.09596087053538331, 0.17219919050412794, 0.08318940342794504, 0.151566619413995, 0.16454990983249682, 0.17576179046544338, 0.1625418861306483, 0.15899620139070098, 0.1886630022237378, 0.09004035919544198, 0.1753233430246192, 0.13527081077617986, 0.1261701995146371, 0.18543273120397524, 0.10440103739740388, 0.2136724481299039, 0.08438979425737936, 0.1542684123400719, 0.2286623373267151, 0.13008764374159998, 0.10238290133495485, 0.11431042300236803, 0.2452944125980139, 0.20354251347241864, 0.14149417199434774, 0.08888053272159831, 0.1274846531751175, 0.1374420265276586, 0.0655091513368872, 0.1558308946269174, 0.09399579372256996, 0.11866334224900893, 0.07612429544209473, 0.15157112401098977, 0.07537984184079594, 0.1677062380458078, 0.19515106214150307, 0.0945217667087432, 0.18217765425722446, 0.11125826742500068, 0.13080113206899938, 0.12395487242047826, 0.1777195587994591, 0.11112190377447875, 0.0814808894609732, 0.1539988106777591, 0.15204111895253583, 0.13636328279972076, 0.1635337708097312, 0.13655526443354546, 0.1424846011063745, 0.19472281899183028, 0.12649194878195563, 0.17954189811022053, 0.08076094301237215, 0.08663238642076332, 0.1288785424924666, 0.16953181024760972, 0.20555524095412225, 0.09896226512688784, 0.13600639307931547, 0.19043560710645493, 0.17586755656426953, 0.18295520285685218, 0.23622793055349783, 0.14200607194535195, 0.1790054067368469, 0.3311175113964466, 0.19446447882200443, 0.12762795758223341, 0.14107590330944908, 0.19781894801605135, 0.12704493402833902, 0.09460874067078676, 0.14947876935043644, 0.13869153125391853, 0.10369859605787263, 0.1285346456232571, 0.12041963711981812, 0.1647110028012145], [0.03436205795996132, 0.1166717664548947, 0.030820107898644866, 0.05573392304922304, 0.030198473513366717, 0.05115306200159173, 0.06888520888864033, 0.024274012990175717, 0.022755672689527277, 0.02296305460584981, 0.023439607260027723, 0.06111329286209038, 0.08342301427957513, 0.07416664202126765, 0.04758847021167317, 0.03157067871201904, 0.10550998797219609, 0.03978144054511382, 0.05103660897622186, 0.06590814524961096, 0.028961360259282014, 0.017310271843246395, 0.010733371581732026, 0.04784992069847161, 0.02805500929694503, 0.01544221144755401, 0.04890722545584844, 0.12020390676034075, 0.09663717295493811, 0.04165922546939504, 0.030393274350752755, 0.005708590352667436, 0.06968538772555129, 0.02245968504388246, 0.16130537425558414, 0.02716929674328816, 0.0388780007168891, 0.002870687303291033, 0.0359331127706795, 0.02432455372576031, 0.06133987485701519, 0.02427485760211224, 0.02866438627543469, 0.0571637457206605, 0.019576492073434978, 0.018122528056283633, 0.031812965509391604, 0.004257434047758579, 0.03737948677172104, 0.04700640043724449, 0.019908100892339024, 0.06769742786643967, 0.10589736799198775, 0.04834801191464067, 0.06583768814321488, 0.01712089299314445, 0.05150710953579796, 0.03916146857063136, 0.01574715561864357, 0.09416319925578372, 0.040604594358873945, 0.09437972634670236, 0.023252325575618495, 0.06112249357806099, 0.03355838193167602, 0.021915605569618846, 0.024281518736613855, 0.02785799829589744, 0.043411153639035846, 0.048120614036076495, 0.06146961950787133, 0.04596301932789145, 0.023110787001168056, 0.07990558286227527, 0.021603591364598083, 0.010188486757538012, 0.014989242810125073, 0.02951383222675612, 0.04536199270777645, 0.016972697114632014, 0.004574170706027578, 0.018688636388809934, 0.011582915209263805, 0.03554489771505037, 0.02047989168204367, 0.02487123981418629, 0.013126416710175335, 0.046387703999155955, 0.07192288540423879, 0.07220605448369058, 0.04521989105870167, 0.02282506876414822, 0.00918075554974137, 0.01476600766181946, 0.0749342467996382, 0.006674501778287513, 0.05404838788954001, 0.012909250893449832, 0.015863052272658437, 0.02863246147641011, 0.013175226087051054, 0.08049379283141705, 0.029040259654603662, 0.050310326980487, 0.07601192566536127, 0.030294481567257357, 0.026795587562505278, 0.017913146650478724, 0.02238621146628453, 0.0481725701191012, 0.014760310840492528, 0.032061064998889645, 0.11677418474949176, 0.03838768912359111, 0.11041213863439138, 0.06202211445798317, 0.09649803606613029, 0.1246320405193875, 0.053029222819473476, 0.040597213101723505, 0.05297269319154082, 0.029666965541940545, 0.010550543740992586, 0.05503656087262977, 0.02606737502520123, 0.061997170635168596, 0.031114879379709883, 0.030733245019350323, 0.016569478227005854, 0.02765104730403231, 0.05952611573100571, 0.009807778405956924, 0.022404664609160636, 0.021063459158364325, 0.02333643245360544, 0.12002092665962635, 0.04080730888451781, 0.004334120885393913, 0.028167105197245558, 0.02205251697300663, 0.017683136412092758, 0.01895270115064998, 0.023600391878355897, 0.03174215983298998, 0.04977402329865483, 0.03886049560781929, 0.07554700222587393, 0.018911389859333154, 0.03600199173595156, 0.06781427159665093, 0.06568303797394037, 0.018372054384540648, 0.069748513370512, 0.029702272619150823, 0.040052739092178886, 0.03293099805652615, 0.0680165571130572, 0.052133328957302924, 0.0404744360205387, 0.03158294761012639, 0.04915092185500169, 0.04982812825830714, 0.05205904524172506, 0.04890039578200348, 0.051360821216216976, 0.005802023393522588, 0.020582177826473792, 0.0674723205907691, 0.019171143461379315, 0.05679318899168603, 0.04962953145525629, 0.017877385666173314, 0.028161056933083364, 0.017433638812132904, 0.056782616978330966, 0.03210165425233784, 0.02023574712145473, 0.10361052659009734, 0.036697155240202145, 0.06156301711715999, 0.06471507055985351, 0.03217722116518886, 0.04548719445724161, 0.036544872282613675, 0.00724758246853467, 0.0754511033395125, 0.02069587868097569, 0.043036693692087166, 0.028536577911807165, 0.035997782082807635, 0.08571753954334606, 0.011259548538815112, 0.09239300755002806, 0.013997670311871317, 0.05204457001039579, 0.04504442628052446, 0.021687771020937833, 0.03521963593459899, 0.08742138037397977, 0.05699640530492029, 0.009923101451638485, 0.05866510185202765, 0.029725448694080118, 0.04400061233149421, 0.0666338526794026, 0.05478012826173537, 0.04607839216928809, 0.0864986198083047, 0.03225120610647625, 0.021346971062162233, 0.07288354433952801, 0.03135269030838484, 0.03659269149084726, 0.04483263361297789, 0.01836951671829147, 0.04169760264396187, 0.03959179547945819, 0.03991341834226924, 0.023647469896522742, 0.05806055505790057, 0.04875439857583373, 0.0559650939108143, 0.04829352391102622, 0.01598963872604673, 0.04026977563156717, 0.0545151116356494, 0.013383451657700203, 0.03841259464200947, 0.038121082865062265, 0.046663357756070556, 0.02756767395523287, 0.012369448105023514, 0.04046499781731156, 0.04237218902656629, 0.03719811928608725, 0.05822012351164895, 0.00852423926605092, 0.09402849801605749, 0.02198262102601509, 0.0068442338247663315, 0.009540431914971241, 0.04672419662857729, 0.039250748457327005, 0.03911181458181912, 0.02261862339031312, 0.03232714457197055, 0.022046516589339704, 0.009240601380776254, 0.0341224831138407, 0.030002019841284044, 0.07106832198558316, 0.0468872431215019, 0.049078319702417626, 0.07639456360090165, 0.09701825573199219, 0.006464881448811221, 0.040251584873805125, 0.013263879696868602, 0.06358506022802284, 0.05177895200528926, 0.02469474273253112, 0.0373780120524668, 0.04563398839485261, 0.026192634231260708, 0.07129301557377463, 0.0523174888334207, 0.03875668303320005, 0.014191119961680905, 0.01643787964337295, 0.033209474847441724, 0.03041546600269935, 0.05778019369069127, 0.06111864015580185, 0.019914087869467276, 0.030134959078784433, 0.042713381605403083, 0.018249074290055903, 0.016467868155168913, 0.008303635629765209, 0.06698269847660296, 0.03899482529490225, 0.09845050307171, 0.00492625130948821, 0.01127115477086796, 0.01515973855050341, 0.06264835303168624, 0.03371264139610914, 0.013867095413227237, 0.013814995688716731, 0.04029514846361933, 0.05667550256475807, 0.01277212690066306, 0.06528789748347576, 0.0465614948752186, 0.024501795827921842, 0.022890873801624103, 0.007353481675137676, 0.07084066363712473, 0.05191124389849363, 0.033247645178268996, 0.030911086585312605, 0.07331521190222233, 0.04035990587585876, 0.03451211926256938, 0.03893806967103193, 0.03543638902145528, 0.03681440882745289, 0.02005167343022843, 0.03733076741017642, 0.020712912645972064, 0.020581528566957965, 0.10518744963431552, 0.042744480944689245, 0.003056085608418911, 0.033133574686343634, 0.05750610658358182, 0.02860121274997871, 0.07425946123417347, 0.032649410948638, 0.02008016424013242, 0.08768664597864113, 0.016383606144377304, 0.03844950858864092, 0.03132758560710617, 0.06005389668468026, 0.07051267075322329, 0.03985400439330167, 0.028911893962011225, 0.024988041409561713, 0.02012398063896164, 0.03917593231064178, 0.05780314568490271, 0.04550817377504803, 0.05967557182415359, 0.012743864959526448, 0.04115415902267541, 0.01915075786171421, 0.03356343811197627, 0.02550758117239081, 0.03144955638075068, 0.07776988294696616, 0.06929209350698418, 0.046872315898297295, 0.05376614577647659, 0.04240647146117784, 0.09345062257301423, 0.0052348123731902774, 0.05172114301052305, 0.025942609945852912, 0.013249619927768026, 0.043401623505257794, 0.03485541475275832, 0.15829141582212142, 0.13439796083877165, 0.11288095656181536, 0.11127578019494973, 0.10691451058993418, 0.15611597126530063, 0.1799248807853268, 0.14533987208720178, 0.20315802926498078, 0.16794904195252927, 0.07567391235141024, 0.12041955285014645, 0.16333153891947963, 0.15130231908011824, 0.13010245988205557, 0.1391547080129385, 0.21694200413842357, 0.0802396584842955, 0.0943454975382455, 0.12014430511983172, 0.14528511212237422, 0.06161098188209919, 0.0932524049834859, 0.19515008154896, 0.06919892189363319, 0.08025177033437837, 0.12177285482926715, 0.2149949457135893, 0.16835077846002194, 0.13233942129919607, 0.09203925879011232, 0.17563630526344623, 0.12995534035707676, 0.09888073038910666, 0.23887773675303306, 0.09512112325718326, 0.1378075117545743, 0.09845237998712449, 0.08681054016755474, 0.08821526196815314, 0.16486011415479646, 0.15060568468705302, 0.0940389168118277, 0.1319221025633235, 0.13474484545088586, 0.09749041870236398, 0.11883931264521615, 0.1579928713580293, 0.1683171931654215, 0.19610004589682628, 0.08273850705835127, 0.12043404723367385, 0.20925276432066195, 0.12333288563475495, 0.10251721953071895, 0.14627148096840228, 0.14738051581286615, 0.13254972775616955, 0.13303849185186048, 0.17087854685321932, 0.1872691665325434, 0.3009885910057253, 0.062055592500274225, 0.0929942180312449, 0.08525493735026929, 0.06841214959539714, 0.12384066403272653, 0.07101762994763351, 0.14485331432473275, 0.19833846288102291, 0.18435152067292124, 0.08717889822418652, 0.11962679740522178, 0.1013376739537043, 0.13981795629426358, 0.1615529585509531, 0.10907231980273802, 0.08866858683646688, 0.21012625777192656, 0.10652425007954722, 0.1285623167190821, 0.11227062197342036, 0.12415410890694588, 0.10565267950897256, 0.07781940287039166, 0.1404748613675756, 0.11700674606066559, 0.14318673601073606, 0.22348182095635324, 0.10360322577217895, 0.08492852260749187, 0.13308946734234212, 0.12798781972378492, 0.11395577791958086, 0.0914515620998798, 0.12129886856963559, 0.15519292724709358, 0.0935510183954912, 0.11297160008501624, 0.26512305102040695, 0.0830022098436471, 0.19617392741624387, 0.11811470838203547, 0.15733175280113376, 0.1814881138383381, 0.1951703215919195, 0.12175847535892842, 0.08375048622368805, 0.10542187253914534, 0.18141596367762935, 0.10187164489780703, 0.12679684411494002, 0.16599525727571982, 0.23081404847964165, 0.15012740067416622, 0.15653761073706612, 0.26211735101476796, 0.18708311441925266, 0.10336598366378777, 0.1442747953678331, 0.12288794942921209, 0.14900051598106662, 0.1944598363291833, 0.09168832923375791, 0.13362105575300035, 0.09539475454197777, 0.07859472981503896, 0.12029255079405925, 0.17555536041336675, 0.16022935780065675, 0.12738633345091535, 0.17892820039583793, 0.13088963054601224, 0.128942541477661, 0.11712089316138338, 0.2648531735664414, 0.07988863699739018, 0.0911675886281075, 0.1899610003156047, 0.09245514494156645, 0.2130885665575343, 0.20444016933681505, 0.0972850152081059, 0.08436054502043032, 0.10784494735661054, 0.18868249150053149, 0.18654590292323023, 0.13535383938541337, 0.129951341378112, 0.12906745977459416, 0.16705238200243444, 0.12094154217911345, 0.18615832372057825, 0.124755012952993, 0.1449138659142679, 0.1171452011312208, 0.18171740395407524, 0.09313572979261799, 0.09744547998472568, 0.13231121394182407, 0.08459575699582216, 0.10999332602706649, 0.16681726961847276, 0.1862910254708221, 0.08491845621216683, 0.1695044609087129, 0.1412981913815583, 0.19510285988930734, 0.09472864109181589, 0.18861483061505904, 0.11052903599075733, 0.1474371297104705, 0.0992603192947084, 0.1276589688214083, 0.20316947461856952, 0.10393543213966394], [0.04960898880756671, 0.011615534275469762, 0.01130927051793063, 0.10324515627637025, 0.05081714393811361, 0.060203536638929966, 0.037312890748463334, 0.05455320535768425, 0.029281646298665195, 0.13632703151914383, 0.04768390944528003, 0.05510186220729544, 0.03636183089486534, 0.048555426389699986, 0.06759492530217094, 0.02235324478768293, 0.04933761365170922, 0.0998951533749219, 0.032218229851775596, 0.03123431248710521, 0.1533623601520254, 0.09939874372174663, 0.036443235397699385, 0.07221696357573233, 0.023705215689035195, 0.03377191361881072, 0.04994943445067733, 0.019846589777678735, 0.030916338118033546, 0.02671613658387815, 0.03557320466385253, 0.059245080206423044, 0.0464639910346558, 0.0979778191615497, 0.06071653975654514, 0.0637649912987986, 0.03691169816339689, 0.05721355292705759, 0.025166367526136102, 0.02959396885407548, 0.008133656998735764, 0.016058444912965982, 0.011728996685105226, 0.012622877651254737, 0.0356969585071408, 0.02920755410506841, 0.022913584478139397, 0.040324275126500476, 0.08044590467527028, 0.03393042870166321, 0.0543437454278671, 0.027136590534580812, 0.10518433931734293, 0.026607365505168998, 0.052232579478333076, 0.054346484192196405, 0.16679580383483442, 0.04771360301322514, 0.04905666239679821, 0.056737816156519044, 0.027828456030317375, 0.04470795663374086, 0.05116785132896997, 0.09099203958025864, 0.03882116465378673, 0.021294298686928326, 0.01264584400961476, 0.0257770755823942, 0.02805667745340015, 0.04760155116298026, 0.044109408308060906, 0.007663181815822159, 0.06274034870007346, 0.008032294469059356, 0.03124200784030461, 0.02102078997620171, 0.051278991534584956, 0.06250565383403052, 0.028105632386981484, 0.07421972425354105, 0.029326661625095916, 0.036134781586306716, 0.038435477688307726, 0.09223159282438217, 0.028471245933624528, 0.07485770695512334, 0.060039436775109464, 0.009259068887800941, 0.07762322307474191, 0.0696216951755266, 0.035394962816949815, 0.06372289476735939, 0.08576090778073958, 0.0402857102603922, 0.05177471936950761, 0.03963774160271691, 0.023852417568465876, 0.05348618660542754, 0.016593567861784852, 0.03846789852926328, 0.04435162615752028, 0.012740143687434256, 0.04821017737530413, 0.04344975680954034, 0.023148137617916353, 0.04070017148830718, 0.03490110806700203, 0.04068875294779578, 0.02595456857835093, 0.06337568456787737, 0.04214128629574853, 0.01584239949982974, 0.06402017901681605, 0.04059294599198526, 0.05065552236872816, 0.08051931888105408, 0.03305282518868485, 0.02405771764085418, 0.017271603555268338, 0.036886773492780425, 0.022129503063737385, 0.05936734017825896, 0.019789995032272512, 0.06025632009691289, 0.0392857893189836, 0.04116383088271945, 0.020346533011404738, 0.06904093924188806, 0.009435132172168985, 0.022391575996974306, 0.03970654012875692, 0.01370357777622919, 0.02993263334276215, 0.02650300134724427, 0.08436301948442575, 0.03871510361110972, 0.024656890328192425, 0.1178453442069792, 0.010098109449890834, 0.04102112402418449, 0.02651142256875192, 0.032463427783260425, 0.08159682154655457, 0.03835459029482257, 0.03865367102046167, 0.030930970397387302, 0.04746321866649294, 0.013936148663502068, 0.036145893691648404, 0.045500359678220366, 0.03049896767122611, 0.058460996876801216, 0.01943326235989169, 0.015486201173776101, 0.03955991856092888, 0.036248687369328354, 0.009025368978449655, 0.03297992809224994, 0.07292264546718329, 0.031558563031496546, 0.03870600631700889, 0.05389339298069958, 0.06838443253429667, 0.02903255664052502, 0.026844419922018727, 0.036017256037842844, 0.07521009973941312, 0.019443788407971303, 0.013462269656179894, 0.029076244719626925, 0.037957534584547245, 0.032946032532040155, 0.08199751617447024, 0.03077565564683849, 0.010700601213161024, 0.03821475626600366, 0.033229140324458, 0.018048594825931134, 0.07782033749765928, 0.03909766110741804, 0.08847360979885825, 0.0359811847879281, 0.026100456616991473, 0.08986035917675303, 0.03010637442310972, 0.12371823552154726, 0.011598432320170106, 0.03084244319207726, 0.0364056358023757, 0.009305140457957262, 0.017608373891562223, 0.055214749093377785, 0.04859799406521263, 0.02814375866775311, 0.03435505974677301, 0.018715058761318366, 0.02485267175812154, 0.09222992275270725, 0.05058038829555435, 0.03821918808464562, 0.013086340735636413, 0.01011844716906067, 0.01802211691204819, 0.04667879442774481, 0.028754041545213233, 0.0847076211545256, 0.03771395692902227, 0.025926863008569327, 0.08377916855557312, 0.022715608206307216, 0.026154653507194696, 0.0935864729446269, 0.026651003788555824, 0.03328978384454404, 0.02407749037017986, 0.03572854048181926, 0.01799214755245034, 0.010778066108844454, 0.024484043655496453, 0.018427609165589658, 0.028378572277424317, 0.015498428894657523, 0.03892701119184494, 0.028352793418772282, 0.10600122653188244, 0.030693320347176447, 0.06475409507871636, 0.03972537440037535, 0.047221694126605034, 0.021975339360294804, 0.03289141046303896, 0.032239511774312106, 0.06571473103136787, 0.0355061374965214, 0.0672324967660731, 0.011267155791903216, 0.021981921970784184, 0.026632458715128805, 0.03393911230828493, 0.007251727961814933, 0.027841506338107492, 0.025189978355962424, 0.03861581478568335, 0.04343524710425446, 0.04955755366433052, 0.015058135181935805, 0.014275959411245442, 0.07865256945332212, 0.08231900497189454, 0.04014597199256382, 0.022573814907621954, 0.05883606969408932, 0.04560984896435853, 0.06059735945816483, 0.04285828713628073, 0.09648378683073867, 0.08537573409416983, 0.043834532130389445, 0.03931506153857035, 0.06347768151411606, 0.02651038260439471, 0.06752622253712147, 0.07307168021197281, 0.07981761298593014, 0.10992725860447654, 0.054822040932072755, 0.05588270881543717, 0.027936054994502378, 0.02550792782717655, 0.020878786003337275, 0.023560390597389593, 0.034235289560691, 0.03793458642077543, 0.023359334652101802, 0.02117693593214837, 0.022984464848113638, 0.024623138409468438, 0.038399421760151466, 0.06584018558984803, 0.07118924130355159, 0.08267307548873848, 0.1014971198333848, 0.033872964446462935, 0.07545139445292373, 0.03294889770087696, 0.04846772847456798, 0.028477476143668738, 0.01235664007253945, 0.021348976297304038, 0.09131408762186767, 0.04386821701642006, 0.02256407793010435, 0.040540403851698485, 0.027599730904424385, 0.03013909786879536, 0.02935357812431551, 0.034331648099807, 0.06702294107526541, 0.050238268750329176, 0.05541229635597237, 0.026914809995721427, 0.04718464994502645, 0.0589552614837885, 0.07416587593334337, 0.03168394098118429, 0.03431069176463831, 0.0719156918386298, 0.0437400083718521, 0.03863521596236575, 0.0437862724215994, 0.021778893349091374, 0.003641963558038697, 0.04936797371614845, 0.039679386142280795, 0.06301021466272012, 0.028180867966805256, 0.0319955529900448, 0.03770337725478796, 0.052278736275770975, 0.006983059490354913, 0.008505079407064665, 0.044624778637362104, 0.01922029374738134, 0.016487688764989857, 0.03113352212934725, 0.030021614455167326, 0.0300983170933661, 0.03581978921448031, 0.0472001402428554, 0.028663198839152054, 0.014580757068019482, 0.08849664606274137, 0.05610994964597687, 0.07494089644282095, 0.06597104872907363, 0.021229430191939878, 0.02252755468831428, 0.014374693780536614, 0.015849770223271224, 0.033417620936468724, 0.0906688270850047, 0.05726879169683784, 0.01820636871871689, 0.05171630899572084, 0.03592899504808649, 0.038861905209599965, 0.019762818063158664, 0.007465774843078708, 0.03275271024434798, 0.06682269335273774, 0.04927941395210163, 0.008759959732302496, 0.11738543098251666, 0.12652769444450257, 0.14811907053714798, 0.1418303466972805, 0.19047746615063763, 0.08450275392181451, 0.11947559463160655, 0.15932062430487526, 0.1376483646491843, 0.22234172890743903, 0.08069421675416731, 0.12356435910107628, 0.07737325624592843, 0.15088904528848587, 0.14561927967494534, 0.11586586494118938, 0.19413872291484188, 0.21335436842374264, 0.11114328528844541, 0.12866115738307277, 0.18396905893760343, 0.17138413423972745, 0.20312948482892207, 0.12201677722435807, 0.13270515167424757, 0.12314027580883234, 0.09029547413510662, 0.18879104615940204, 0.13239070322484742, 0.227024364735811, 0.1501813179422771, 0.08484204660259909, 0.1485030031612804, 0.1352281550005559, 0.17219108529388907, 0.2105082598544898, 0.10818191879098454, 0.18638454948461827, 0.16853070186991848, 0.1052354833471679, 0.09893736726934872, 0.08385069052418394, 0.09057498131428035, 0.12950881834953062, 0.23102913532526265, 0.12170235175759563, 0.1303973730893866, 0.15652838703845778, 0.15693943917510972, 0.11675053561526923, 0.10056713505858376, 0.1361489313985071, 0.20910466420314006, 0.15177468889422957, 0.11989852879196407, 0.07460762521312123, 0.2597389238015298, 0.204098999740616, 0.14227659291317388, 0.20823736074230365, 0.18349601496611873, 0.11636597479903892, 0.12566644307826796, 0.15581537368557147, 0.11046542771040432, 0.11907704504987887, 0.10775679361916359, 0.1533834275699431, 0.11299849743203771, 0.10483745470522873, 0.11198617352713501, 0.18247587696438838, 0.20608097645303897, 0.14374401901037465, 0.12063663152437057, 0.18072729659897668, 0.2769257693040756, 0.18966271632140685, 0.09591551046938666, 0.1720604060157653, 0.15577495488668644, 0.13064771530128297, 0.08755793554648277, 0.1363216382601569, 0.13130835888366546, 0.19039043856243934, 0.2259952022183326, 0.2011125745071519, 0.37684082564327026, 0.16369988931523216, 0.1602702056087794, 0.14498171066084217, 0.16429820398409523, 0.09901055164875523, 0.13726715929806232, 0.20378278928898996, 0.16009087974746383, 0.12838106031619734, 0.10178189769747759, 0.11091935778817824, 0.13455257270364993, 0.10077762537665906, 0.1597017683689633, 0.19512722148529946, 0.1563752460623941, 0.19365665442760915, 0.09864690503285778, 0.14117419239013426, 0.07834912968739387, 0.1267053655559017, 0.13110244977137736, 0.07837969659557266, 0.12307594740583051, 0.1707626224285172, 0.23604140346569402, 0.1722047523024582, 0.2599746950211064, 0.09777896571904422, 0.14717358014275952, 0.13466146444120716, 0.12747411946615866, 0.23726388060998535, 0.10321618283107396, 0.20429304981183624, 0.08796341822392519, 0.18668963633958371, 0.1729691241897883, 0.1748614379715535, 0.1704785723479525, 0.12315091677010061, 0.16715787230960785, 0.07729868524737897, 0.12718239318459265, 0.11217244014504457, 0.14077213412571338, 0.10992683725611818, 0.13702217970163594, 0.18569827260028932, 0.09532391439161955, 0.11515659775825278, 0.10018133317991611, 0.15500825409206653, 0.1559533461207344, 0.12489037302833413, 0.15978504212633257, 0.11930329379655662, 0.0911938424612726, 0.08836218231027165, 0.11831410574696719, 0.16539786191236588, 0.12047966776956474, 0.14843909610663691, 0.12774832531689637, 0.08065964320614454, 0.09861210165845771, 0.2541295207676388, 0.15664906120829045, 0.17556720413267615, 0.15249145607794487, 0.07666911419120527, 0.1095232927811242, 0.10543109623775368, 0.12836339432866345, 0.14424369219810734, 0.12957430354529811, 0.15008538841239868, 0.16592250956643015, 0.1105299782789042, 0.08787844375136399, 0.22857023823645808, 0.12812078194392304, 0.17557799065065, 0.16303929169812512, 0.1385831910996668, 0.1679234546158583, 0.0863098404220035], [0.03326805759101145, 0.010113616027088176, 0.015279468516969394, 0.02541981239412581, 0.012592717727285721, 0.04271763339338284, 0.03910516493863637, 0.02001832945332412, 0.02753151460520683, 0.01180738375912751, 0.03927834294435959, 0.021874650509186813, 0.046819022991844726, 0.05392314017479939, 0.05995559611267621, 0.01961416253189166, 0.01792807770412295, 0.01577678789955474, 0.05416946808597254, 0.01515597131313576, 0.07659313359087513, 0.0057820261046741045, 0.021005234560899196, 0.05940848676067206, 0.04279439157295612, 0.04476128401415003, 0.028735387304257003, 0.03294452716926894, 0.04586411354642722, 0.041652978022372535, 0.06650362539315416, 0.04286626977245173, 0.03049699882526071, 0.05773729659737118, 0.04570489366268439, 0.0538167956795904, 0.0177814542210751, 0.03197125651152625, 0.07096072493661797, 0.031320997250957355, 0.05540203077778701, 0.02029529322058924, 0.012883037279900766, 0.02714414990717365, 0.07875769969917114, 0.026107650182600466, 0.10635494464828123, 0.02907639410677216, 0.00975880336256758, 0.0611917594177348, 0.03063522789987826, 0.02243338524544191, 0.06399905031186438, 0.04816907675816648, 0.050378857375753504, 0.048633666949406754, 0.0268077434626438, 0.01551815278587803, 0.042855345358651493, 0.05624057912838556, 0.008278841194095872, 0.004797739581385207, 0.011496107871343773, 0.06268426340313689, 0.03906873362739721, 0.026815080669738596, 0.019152650098887183, 0.04985823934417098, 0.017274484045863632, 0.02072232212090204, 0.006761314383062024, 0.019593317279471986, 0.02634925516172042, 0.013938829013627144, 0.009649157986014841, 0.09281038757293456, 0.021792035587432406, 0.03696191522683348, 0.04416808681262117, 0.019106809312718052, 0.016686463683483102, 0.013561347807427088, 0.06608717233663605, 0.052001060046736276, 0.06122668153576313, 0.09756850604448589, 0.03137753070932964, 0.04257020360279468, 0.059126221664970925, 0.018011753657652486, 0.07988954098114083, 0.023162570714409796, 0.11675500190786778, 0.02941289822751236, 0.05198982153688708, 0.07120981076431852, 0.08722185277410092, 0.02208477118983865, 0.05698800132039094, 0.047511964841114904, 0.018071041202112552, 0.047690857862753254, 0.030615395798738447, 0.01280876792847149, 0.011509658051504484, 0.01634762874023328, 0.11256353569126899, 0.05769882749225344, 0.0716740983508287, 0.010843599185107217, 0.022593049460180828, 0.04654639911267065, 0.015904088729932424, 0.011609556874440563, 0.05141636259072731, 0.103568299823711, 0.08478140308251304, 0.016204483296361663, 0.055551712866872556, 0.05059207496683925, 0.047628881349678964, 0.1255433863749908, 0.02695879493389399, 0.039769999021964694, 0.008838700164379853, 0.039276370267954566, 0.00854122726577184, 0.013219279973136802, 0.07461403736904745, 0.038603185826251586, 0.12376317423918556, 0.11895469314749203, 0.013066013550175535, 0.01403306453158298, 0.011523308780705257, 0.024579733782898516, 0.01911821636191059, 0.049147520424617876, 0.03332551035489286, 0.02324031906262521, 0.05089480227099792, 0.022910539278640382, 0.06362573183592289, 0.0620088228324969, 0.030999887667055574, 0.07264576596958984, 0.03150822339399207, 0.025814539197111325, 0.0550248971839826, 0.025978401573675296, 0.039462533463994344, 0.012428329622883712, 0.03516839997422311, 0.011932998238461874, 0.012487708140284786, 0.04419698364912503, 0.06689685832468734, 0.0439545972603223, 0.03656884317376441, 0.021311250297472845, 0.03813415615549011, 0.0061870520021916646, 0.005739559457006474, 0.03373401141875694, 0.047729307815672896, 0.03291029069993285, 0.049929929852125146, 0.057387650238289956, 0.0671383215775413, 0.02028518660564817, 0.040073086387447776, 0.023640019691459114, 0.06998562524395605, 0.04077275065825351, 0.017517605879073663, 0.07508044701910789, 0.04951347679560704, 0.027661789771950537, 0.0038491462915009192, 0.032185912432689825, 0.013535279750583634, 0.03322371259151447, 0.04128963018076555, 0.04770820592379859, 0.023392986979395635, 0.07266479559362897, 0.04066394702080758, 0.0306472976151253, 0.02434310071440714, 0.006846215119660502, 0.04139195654481169, 0.03253985271458665, 0.03090168285604206, 0.0409861559408807, 0.05829990773852314, 0.03417818536681514, 0.05851462303150085, 0.024241858364773855, 0.027608221073845224, 0.02808374142454517, 0.07206052842159426, 0.028742916033332868, 0.02564075981236754, 0.058681576572839296, 0.07762579713016748, 0.0696735593280004, 0.02497145560600104, 0.06762067351730601, 0.032995452864035484, 0.0459533091634512, 0.015153441307765823, 0.03586191638943649, 0.04065803665247175, 0.02914932376194385, 0.060022521553741354, 0.05593423205878466, 0.08455435760439405, 0.05818333979996462, 0.03140273691725827, 0.029207956301228657, 0.09699230067311757, 0.01131686244926025, 0.016598430604884223, 0.031926863631534005, 0.04451666447904803, 0.03289869212875924, 0.06816651882423509, 0.036291764493310646, 0.0544243187253033, 0.023524066538459832, 0.05981423756888798, 0.040474317276910435, 0.03194466751489428, 0.011718451484827506, 0.02652747594120522, 0.028735410286894733, 0.03333419013107496, 0.02715132432058454, 0.0630750333619935, 0.06445549698846956, 0.048566105655364455, 0.03478539431647908, 0.06784244064962672, 0.02968158632997544, 0.029477921855305473, 0.047176203825661255, 0.023265132650492654, 0.028374676720329353, 0.04502404451129898, 0.009694760327317543, 0.03891706737058778, 0.02251901089273874, 0.052604668383156104, 0.0654386176216987, 0.059241697928237344, 0.06201723830834512, 0.047543355293812296, 0.02266816821159615, 0.10577513100278955, 0.02166296317872982, 0.07626850383296128, 0.027737203467216705, 0.014104530001209389, 0.02919160415448489, 0.048848393733703324, 0.02592719625681639, 0.0032138705137185757, 0.10666250596724211, 0.07767466587885734, 0.09456960123873527, 0.043603579603856614, 0.02833539173157225, 0.02115085446876624, 0.04893018511093913, 0.023896251204273394, 0.04890860824455177, 0.024091509779194192, 0.01625495508403307, 0.008278566360053035, 0.0765683200030077, 0.11600272654886208, 0.0172564733187638, 0.08970483566724485, 0.08781537173255798, 0.11153703149888786, 0.1010514788269516, 0.05583141156802735, 0.03398485541824372, 0.013158267773237201, 0.02177897187310361, 0.03680262256473784, 0.04818904867035247, 0.0697696344145844, 0.035123269734603745, 0.012622327025559162, 0.04639599690093629, 0.023156129830186407, 0.031009450359570406, 0.02385250949901679, 0.03192101838067174, 0.04443356692190132, 0.043101696252462365, 0.03143003646044001, 0.03978998625590917, 0.021779067634094148, 0.023541657832421126, 0.04916352783179572, 0.04997331341127715, 0.06328510233171045, 0.04581466257091492, 0.004275974811941025, 0.043211622208717375, 0.08181800645205282, 0.045005011056820234, 0.038155457230224725, 0.01606404310047266, 0.019495384429671594, 0.05514223504090502, 0.04508512087106224, 0.0626065552745375, 0.049852072336380525, 0.061040878401047764, 0.03315181140938113, 0.04820306424892718, 0.03291905091534699, 0.027365403760585095, 0.05130766237515116, 0.09292287992373591, 0.035932829318147515, 0.06566821417260556, 0.07489002820464873, 0.02690509408562174, 0.049380081735791705, 0.04782108897944132, 0.0879240106611002, 0.0208577798724535, 0.01696285288480501, 0.04669159958739916, 0.028965972108586185, 0.027285962358057022, 0.04296106166176258, 0.015202159711700535, 0.02223398788051019, 0.0205012119089764, 0.04550415564388518, 0.017021533304585085, 0.005691419928259547, 0.02509685845354632, 0.024192095208432407, 0.0403267304382978, 0.026759918508750778, 0.05337667816709127, 0.18677215933078722, 0.15279421402562052, 0.09831463737833886, 0.14026669995679011, 0.14130519342518624, 0.18221142341292676, 0.12957706146182554, 0.10717633645981552, 0.13015286846747323, 0.19260555115197936, 0.13818634223313103, 0.1786032871853921, 0.13174106066505756, 0.11063028217083025, 0.13198415568519023, 0.18552568831270744, 0.06327275299437105, 0.12430715795245864, 0.20121539882834882, 0.1228325076461319, 0.28146563698687865, 0.1688130205917743, 0.18685601531497895, 0.08941667169452676, 0.10381552405775556, 0.13856604605192138, 0.07826323590932355, 0.11849236674606801, 0.17117724453489627, 0.14651456066677648, 0.1236834857733019, 0.13782323187878057, 0.07573018917032788, 0.2111929739194532, 0.06578534135534879, 0.14648342685353372, 0.11988719835156396, 0.1752080008267395, 0.10668927307931647, 0.2435782990388332, 0.21962302075999401, 0.14528240017112226, 0.08057269222673871, 0.16555120207128987, 0.15433014370501041, 0.06634223365014599, 0.1521546225393972, 0.1552500774062449, 0.12131186142083138, 0.2633162786162669, 0.1624441486332686, 0.12669739058060994, 0.09887348319734297, 0.16900417485064076, 0.09933162675870043, 0.1765177200638479, 0.10430500827609532, 0.09104751966773503, 0.1142650476146129, 0.14374521410753652, 0.13370023860085395, 0.06655428678758683, 0.23318804770467744, 0.21029256013852937, 0.12702152238137301, 0.07833715573313736, 0.1670878825168456, 0.11797077578282165, 0.1404210973170496, 0.08814672774244701, 0.09492330403337557, 0.11705913881380713, 0.1492389378648612, 0.08173913770024815, 0.10479243937879802, 0.13960320652732927, 0.08223309587206572, 0.22848071320162666, 0.10581774847401727, 0.13316436009781976, 0.12347288054203796, 0.0981310214246473, 0.21960074292315593, 0.1278540148069301, 0.1719448799567838, 0.15750937794725742, 0.16193823948983224, 0.1508515529454716, 0.11480147770095257, 0.12314662667772464, 0.12987381328017483, 0.21523787219437862, 0.29371271691014694, 0.14143784921015465, 0.1988470992974697, 0.19376870244741443, 0.19064684819069602, 0.12637054682859492, 0.1537034684611905, 0.0958737816601511, 0.08980625038666111, 0.11666825011132226, 0.08396696734933123, 0.24819828419675752, 0.14334654195174096, 0.058292848238300894, 0.20996233027788902, 0.15978458247357802, 0.1584239949982974, 0.1977490348320815, 0.14764797242899097, 0.10832863995024275, 0.16099019036177667, 0.14181727723729226, 0.05525480017005917, 0.17606267915858378, 0.21205456236437445, 0.057488996009793014, 0.1516960882731984, 0.12186009692208422, 0.06527705733934719, 0.41620701972034674, 0.21120841825200667, 0.15578367296726475, 0.09651161880502779, 0.14251542848444756, 0.06847226451481543, 0.15413676779116356, 0.18541422251972461, 0.09136471071190412, 0.228470248440581, 0.14082081135242216, 0.1375408365481323, 0.08509890056185185, 0.07938648168478282, 0.12507676222031155, 0.14559891705791797, 0.1653843634431401, 0.07799010258167982, 0.09983091690247098, 0.13137971231293294, 0.10530169632646347, 0.16058275416012735, 0.28039709755009223, 0.16334813238391954, 0.1925373846484769, 0.09621574798779142, 0.16019420968669076, 0.14988070504078943, 0.08701094110766727, 0.09033266770383043, 0.14539279344101108, 0.13410565233038318, 0.0920408828965118, 0.20309631322180072, 0.10156230625486183, 0.15583083333988346, 0.16230138048769968, 0.20756092042692248, 0.1521647348999977, 0.16908557935347482, 0.16068081341443524, 0.1197369225443371, 0.04810955172644989, 0.10526690827382189, 0.110197197345476, 0.23254643374633407, 0.10555189298165422, 0.2061153431573222, 0.1341370619352787, 0.12091115147115723, 0.1907627266501227, 0.1145027417148794, 0.11281278239743364, 0.14800325336475528, 0.15544709989861136], [0.052210251845779924, 0.01349134843856577, 0.04094034388300873, 0.045177009287140066, 0.029941885769667647, 0.02857565222638509, 0.0007542112871306018, 0.09239159028736815, 0.017103060381487012, 0.028536200613504457, 0.08791383701346575, 0.09128305340005506, 0.03453920047069269, 0.034172730820794264, 0.04996582107137769, 0.04644391187016041, 0.042658958719262195, 0.013729049242101611, 0.027988763758912686, 0.0743580797326661, 0.01526522502723721, 0.03279775621429567, 0.04932296222015735, 0.006662144780068869, 0.047083917043862805, 0.0395026151841927, 0.042798570582583066, 0.02849318669177592, 0.036573830406151475, 0.03177023312497524, 0.060354394672979275, 0.018037358231301752, 0.06458507309998236, 0.05375220680669431, 0.04761885708918975, 0.04694672218794304, 0.03618109160132947, 0.02775130714590271, 0.04976400286860524, 0.053480142171704964, 0.04091127850716153, 0.034300954787120704, 0.02913935887326877, 0.04130677522851094, 0.03153565891778037, 0.011004798448524408, 0.049900983219906214, 0.0039013693082867373, 0.06000731087800476, 0.024740550959963473, 0.08660330572315762, 0.03613947004440331, 0.011225926855038251, 0.016942381100248427, 0.05360998641399126, 0.029709328288933443, 0.03890133192462306, 0.03760862750031295, 0.05523838290584184, 0.05159894049528146, 0.009954142376720425, 0.031806421203298435, 0.04465483226663163, 0.02149478964237196, 0.03760745921622842, 0.05346295881956335, 0.008596844291464697, 0.015429142945175691, 0.017031456058424328, 0.014099381890358224, 0.028648168194077672, 0.0448234022534903, 0.056804036796693845, 0.02481977785787275, 0.030403890414163474, 0.08162593288767724, 0.03640451731400625, 0.05101361484717458, 0.032228798034691045, 0.017240829803349993, 0.015925759442090508, 0.0731451097395151, 0.009834228549152613, 0.028118975723402637, 0.04720289049850357, 0.036896403217988635, 0.030265663254765734, 0.01665392409889929, 0.022912952455601866, 0.013184695891405066, 0.020244059175433173, 0.01430071841534828, 0.07526716562889277, 0.004314999809608825, 0.04213809170910428, 0.011050495593207739, 0.0026261561077028034, 0.06789078845852806, 0.038090650022270224, 0.006195730341958904, 0.015870384691703706, 0.0841355909623446, 0.05448831388005807, 0.021318350017311114, 0.04628945322286698, 0.05713899725026662, 0.028920445418466004, 0.022854875330062165, 0.03987929678612179, 0.02314829658116064, 0.043607563261062875, 0.01106464715238901, 0.01766435576662902, 0.02801404082997432, 0.012010852881376783, 0.024728368246747602, 0.054562624408713276, 0.06439388053671968, 0.17142128950405508, 0.09708932570872769, 0.02627009338128471, 0.023733731396796725, 0.037603479389461784, 0.0420755980866811, 0.06366799690670545, 0.05363983702996085, 0.014553447948738694, 0.02276098550928216, 0.04659382378562324, 0.05860888248970432, 0.002390883802886932, 0.04605588067563311, 0.013325962504642385, 0.06837441976512633, 0.022531950117779836, 0.053394409272098736, 0.01960280144797458, 0.024018867406994108, 0.03133869388200824, 0.041767393253863826, 0.07915180597093799, 0.019451476100291458, 0.014741062881394982, 0.05498151745527022, 0.10294976043364695, 0.06654413612259012, 0.017881235257992824, 0.03840956859470856, 0.01601131518386425, 0.08589793792775563, 0.047043383331789125, 0.054594792440653815, 0.043613764742809924, 0.04452991396969846, 0.08212360658592756, 0.03838055684501606, 0.012402771014509904, 0.07393240297753965, 0.01043980860436756, 0.05030151696935777, 0.03815796233773713, 0.04018290126095376, 0.01693755666154527, 0.03001787786131665, 0.04345326932267316, 0.0242422241717577, 0.01867787093825398, 0.04918202119428785, 0.029926341845683997, 0.04581881859790414, 0.034767701515867826, 0.014679515377558289, 0.04975537288813822, 0.08010940821540934, 0.021857402039571636, 0.04453074134465668, 0.059971431150071086, 0.0400804638141586, 0.049652111896824454, 0.03283842399175609, 0.024615598189073707, 0.042889738876012065, 0.04875854311150409, 0.048393881429106965, 0.026660679479039488, 0.049387646854043975, 0.090143344395103, 0.043085225362090335, 0.025894317678326083, 0.0882363906731048, 0.08398798114109425, 0.032326918576032884, 0.018517406161634192, 0.026679086656640136, 0.02044910260836684, 0.061049991016907085, 0.06513808132900346, 0.05344213271934179, 0.017018495765965314, 0.01988350755474981, 0.037434890250405, 0.09900570231219454, 0.026887972020514073, 0.06155521451165119, 0.059217857272033735, 0.07703675978606747, 0.09610187667872637, 0.03720252812209149, 0.018799292043812813, 0.03593246159594386, 0.03233860907775741, 0.015602798798241684, 0.03584584769522471, 0.02853120572023815, 0.032384436457387866, 0.030675640953103864, 0.03071204162082605, 0.01737952427638154, 0.03029489142429685, 0.002219284177690204, 0.054133040605173, 0.009032849827030254, 0.04004042422879608, 0.0602249487964136, 0.028080541092241486, 0.04622661103043826, 0.04267929452321222, 0.04507943649866408, 0.00937210803385824, 0.011016815495226654, 0.0745467901710541, 0.008846427118706127, 0.060939402394597574, 0.004699312604873652, 0.005137339654949404, 0.05478799981515735, 0.008429733702101776, 0.058224471060619246, 0.009472904137275633, 0.03911801606356617, 0.09604400639692623, 0.05597512966262237, 0.032888372924419186, 0.003405021660352847, 0.029815691936340545, 0.066870060569096, 0.06228980473092487, 0.0220666149060332, 0.06375495554699052, 0.016534038999628638, 0.05423400716315355, 0.022886604776666052, 0.02139809593978909, 0.013377525967605894, 0.06660433531168007, 0.018618585309013724, 0.017123068682849407, 0.021968741428046938, 0.0798993239239339, 0.03198621629346763, 0.029203687276270603, 0.03356026267753013, 0.027991414423130696, 0.07565510489286915, 0.08045980151021674, 0.04277579478859421, 0.04761096255313005, 0.015670208789918934, 0.022881125332787636, 0.0470704032528785, 0.04252094414926345, 0.06454054806982318, 0.05856339218876055, 0.06234633818929715, 0.05931113613769413, 0.0031244498583668425, 0.030882978819370754, 0.06361087356063147, 0.029039690834319884, 0.008591084267884012, 0.05322685052130011, 0.03222197602172533, 0.07719507185562004, 0.0319334136832866, 0.04123178288160313, 0.020597599176389557, 0.026266149943694476, 0.04988240175730279, 0.03397080919615204, 0.04562341255105792, 0.05881949538184751, 0.040465070595664364, 0.02198086668466849, 0.015820130281480813, 0.043017966672778137, 0.0672841847183243, 0.014060273101823706, 0.06496476159701425, 0.04647075942146682, 0.09221875319077123, 0.02402799917505153, 0.07157236187448425, 0.023107038915998513, 0.00642739006340684, 0.02921258538751112, 0.07173102634448199, 0.07712665254310255, 0.03769397735595703, 0.024864029011599002, 0.05425783249759867, 0.07470678763404008, 0.07599995171110477, 0.03841978820761846, 0.032787590227540464, 0.014972843740495944, 0.04558842914599565, 0.03047162216276892, 0.07443998985353016, 0.010905877345301693, 0.0439140405656109, 0.10877711548199577, 0.04988483025602276, 0.0514770865500454, 0.030681706454244353, 0.047142300604572224, 0.08917880139403767, 0.01684675800553974, 0.024032597617817023, 0.03065113380040613, 0.034506373603137276, 0.03627197644222648, 0.05758191098368937, 0.07012556652508437, 0.06253445107910423, 0.035994116352089954, 0.02637873039460711, 0.04208657612663604, 0.04224935831922678, 0.03306708974583495, 0.039675164997818015, 0.02359463664282474, 0.12155475725810375, 0.021133611744810498, 0.03238144488404355, 0.04094936456831713, 0.021183750284234845, 0.02529465277949649, 0.016689114347701112, 0.04749240661640802, 0.033549675342416575, 0.01948549423456913, 0.0129303815136213, 0.14445862582614347, 0.11323792289101309, 0.16310474625037563, 0.1872562962554155, 0.1447760620184483, 0.11628457029620487, 0.17572662702971892, 0.26017798411269344, 0.10567497266756912, 0.13077988078997982, 0.23737778256256736, 0.2367483953674955, 0.17350481883172067, 0.11794182532016309, 0.18145034570367108, 0.1386203463639944, 0.10904020539695218, 0.09426004809117126, 0.09660689716017055, 0.11567980516701938, 0.21251049193163074, 0.10312899436441161, 0.15261576150453862, 0.07921812620254294, 0.20431237054928658, 0.1981640706259397, 0.10827693667623306, 0.14535128679727355, 0.16416188629884876, 0.1846441356164794, 0.2783939921327176, 0.17337559512065304, 0.14043560702233546, 0.14612442273045742, 0.18108763371504125, 0.07108590370344539, 0.22291557472800055, 0.10109100130296524, 0.1450336514221084, 0.16067610963458018, 0.11241061688070336, 0.11003279487692541, 0.1592265793512906, 0.15640602747519172, 0.1592522279749955, 0.17927787356799652, 0.13661672000683125, 0.18292682696013682, 0.21399673314825182, 0.17265786266615316, 0.1485200562784749, 0.12053243590578919, 0.1328764336123582, 0.14203715979331924, 0.15389007215778674, 0.13909660790476108, 0.1915349279560389, 0.15170145088866835, 0.10851994742669406, 0.125211532407951, 0.055969100550658284, 0.22668584580382994, 0.11205162807938554, 0.13364724063825223, 0.20190667060594406, 0.15839135965272305, 0.06727126081504169, 0.2193630258402517, 0.14510894254330667, 0.15338158895892484, 0.16237503218074, 0.1770913820233076, 0.2177765956448932, 0.1096757595998145, 0.1154080201541224, 0.1487748264785736, 0.11042992719599318, 0.16959508911015528, 0.12974609110143878, 0.13877607671724213, 0.13273778701982192, 0.11987956045495889, 0.10711003154996904, 0.16613125320403807, 0.1570239080296409, 0.09650753555639137, 0.10306563889307362, 0.17013511980973905, 0.14059031081776466, 0.09616733889185614, 0.12549414224321806, 0.0977098262838779, 0.2060096230237715, 0.1354198301992109, 0.0967358910448609, 0.16271088512674456, 0.12582323829373046, 0.1551949497192137, 0.16019379599921166, 0.13751023899643652, 0.13280592287980741, 0.179098992037677, 0.10212964798894622, 0.10726304229108558, 0.10340615731453705, 0.15236638456342683, 0.15613834103268964, 0.12887006956002406, 0.19620892231262502, 0.12379838364018549, 0.14082787468308403, 0.09549853647308004, 0.11973388883615695, 0.1275009018999915, 0.11095721785339618, 0.0779284937908092, 0.17962578473792923, 0.12041778318704137, 0.15191526602833502, 0.17663510005560615, 0.15946199817042198, 0.1089813085573335, 0.17157695857026886, 0.2093716611665103, 0.12021607989745757, 0.242526582892864, 0.21446582410604725, 0.10466474018269971, 0.11506632195725558, 0.1635801804161841, 0.1898884824326923, 0.2034626105019162, 0.1033371021490424, 0.1442263632892601, 0.1552608332807018, 0.12152013008392627, 0.11574593387664327, 0.14675823791373163, 0.08547116566689746, 0.23748564774230604, 0.14886920851084495, 0.2080536375363027, 0.06275609563735705, 0.12918908389345293, 0.25520406633375153, 0.2734355033645707, 0.16570080372114337, 0.157278785482049, 0.14433638883694527, 0.1472781664661823, 0.09449965741124847, 0.14021950894065444, 0.11147369901018758, 0.09486324274011197, 0.13817693467342085, 0.12665456626564264, 0.11709539775526333, 0.14630609282082127, 0.07799436969141807, 0.11825959859115463, 0.16456284139665867, 0.14759434627429133, 0.1465234626084566, 0.16795216759126033, 0.26530446064087654, 0.1327241812982867, 0.08658195485270793, 0.2845516230069822, 0.11495314012732237, 0.11428662065056064, 0.1297614128599244, 0.10542419378555591, 0.17548406827113322, 0.14090514231112697, 0.11842236163154726, 0.06667246351078635], [0.04516082951017926, 0.0067006268129203355, 0.03348397181159066, 0.031229976429453785, 0.01248963293619454, 0.0032387240817995685, 0.018065962039174575, 0.028645136401117332, 0.07730783999807413, 0.04331508238289145, 0.024870023649606495, 0.037222940534833944, 0.0475051275063907, 0.02815765550269956, 0.024279469451416406, 0.05357278901482782, 0.05438725156108699, 0.07090344454251951, 0.0701052422124532, 0.06739238697674967, 0.017247100233010227, 0.02806152295952122, 0.060252669687953696, 0.0217102442101966, 0.036890745658667824, 0.015134898149558615, 0.03207059321744788, 0.032297994926451676, 0.021704603887854085, 0.05987670054779418, 0.024918614691423795, 0.02044800135697569, 0.02243250424432899, 0.03636455050699654, 0.028265771576233452, 0.08455841020951349, 0.031553326820534085, 0.02393876908407096, 0.013636268333592003, 0.05613263350941482, 0.01242445992125619, 0.014341712737786434, 0.06288066536428467, 0.0242589938364202, 0.04353326805416615, 0.07017551545774744, 0.02495315376548998, 0.016576838416738376, 0.012483988783412404, 0.046254649848466924, 0.030241895376914935, 0.038990466254613096, 0.020893232506369392, 0.10703026647529296, 0.048091939365070675, 0.07562787046716099, 0.09126729497145261, 0.060540680443086935, 0.04288468652615144, 0.045420916360472484, 0.03251417727780438, 0.01145580973130681, 0.022046983902973515, 0.05127613019618777, 0.11191779251901374, 0.037996616560004415, 0.016349990206259876, 0.05493215074942959, 0.028014774359161818, 0.04418662230994913, 0.10883172989011773, 0.028320186801495093, 0.04994722428701578, 0.012026434152146742, 0.018469851253734484, 0.016032328018017353, 0.0888772921696786, 0.020684157535734198, 0.07704763823459226, 0.03940608810573336, 0.05112657834204936, 0.02132989496233002, 0.0175780157423428, 0.0587410862827974, 0.05969510323578312, 0.027361525440468427, 0.05359156199941232, 0.00431660428500524, 0.03378065851246638, 0.060786675106013016, 0.12350395306824677, 0.03448666216084554, 0.024610247064922607, 0.03406190854166785, 0.030547564458702842, 0.04259026361509197, 0.05243007311477296, 0.02369078642298137, 0.03077832737847442, 0.011265761511881026, 0.01228236114501112, 0.04366268328721485, 0.046826526823063055, 0.07960899958326932, 0.061551479833020326, 0.03198330132891575, 0.08764243504453091, 0.04284790281446711, 0.023449717705408414, 0.016372191434305523, 0.0396860970724975, 0.00846427469138777, 0.02071729658411876, 0.04859996674161765, 0.03134745218220257, 0.05241788082545804, 0.019232553069389636, 0.03217158658850578, 0.08613042263013702, 0.05261029146852032, 0.09502896287989232, 0.03337599937954257, 0.024438300545537667, 0.05269087242683577, 0.10634374444282825, 0.05527509000873374, 0.024132572091935624, 0.036174579853973085, 0.014077812684850107, 0.026876727765005444, 0.06496796384453773, 0.06620790013262341, 0.05567068249107369, 0.03600512120512224, 0.015556458139701959, 0.02774701513830693, 0.037731159433361985, 0.09076856407186679, 0.035538106345601624, 0.009316791697675663, 0.05716178070513472, 0.040214567505303896, 0.0126178952069172, 0.028088031516921137, 0.008729631268990137, 0.033475322678925536, 0.0938281430412204, 0.0646712733132224, 0.07996221974251733, 0.027335198828950528, 0.07049082192562281, 0.03376774227006301, 0.01971107073909333, 0.03601775399499363, 0.038278655659767895, 0.08390901279785941, 0.07351634062586293, 0.05992550417901047, 0.05584789778015787, 0.017353806704763445, 0.0461091046341725, 0.012907843206888966, 0.08523111967670341, 0.03672441264854805, 0.02489989724821381, 0.057588932179515405, 0.037773650500082204, 0.020675219204877655, 0.05229452151745077, 0.0254566612232837, 0.0160660550388838, 0.024434989130484964, 0.04904509446914158, 0.05022519162946171, 0.01616369677527297, 0.1132777288195587, 0.05283013955059071, 0.016402999660180464, 0.02318120963360754, 0.005428787750837904, 0.0443985911777183, 0.020431492162207444, 0.021308793070455714, 0.08042308291600597, 0.06215869261312389, 0.06195823804685666, 0.03978858431500774, 0.047405934441954865, 0.025041204081067157, 0.007864651927394013, 0.05910232738261262, 0.028166463598608974, 0.05854629310629061, 0.04464460116240286, 0.009000641575473691, 0.06544400321980638, 0.0143962036142306, 0.09477337296571463, 0.019156537995102908, 0.03404005588362775, 0.0401874901276202, 0.05613497007758387, 0.03732667267022114, 0.05253129631220814, 0.036556152927298705, 0.026399579477466406, 0.0753575180386824, 0.025343615373957063, 0.02873739636983843, 0.09288293609936392, 0.023181885706200715, 0.06483190662918553, 0.05426227197711987, 0.0136569393010089, 0.07884917059733022, 0.04895918919975239, 0.022151821120191487, 0.03969565018891327, 0.11301616341957163, 0.06779128895892252, 0.04142240470936222, 0.05824579511799159, 0.05484634507147055, 0.035820478693612164, 0.034246505087902473, 0.039342246168563445, 0.0483545504750744, 0.058313907995339365, 0.0413692458682964, 0.05630672315976793, 0.016505755033464204, 0.027252461333128235, 0.01862938906396589, 0.06980571715581803, 0.010701659372106436, 0.027691864468637976, 0.025287215980971535, 0.04168013200884865, 0.008881859642814004, 0.01770201856420646, 0.11170032313994824, 0.05530805860255515, 0.02749417164933778, 0.030301382104235313, 0.06335722950978145, 0.0227510244510467, 0.075348102818093, 0.09425893726368105, 0.05842558829294098, 0.07045747411827888, 0.05385452167942159, 0.03287364105363527, 0.04039077538876765, 0.034588000271469355, 0.051342159314381505, 0.021567343914460753, 0.07332321752103106, 0.007528843031445098, 0.017292132796419245, 0.07326103416421721, 0.049884251859639926, 0.02052396855076715, 0.038620962896534515, 0.04494806008052923, 0.05544927158963777, 0.006933368633561318, 0.049727023804500226, 0.043299274158573924, 0.1242589710220214, 0.030538183712070028, 0.07950373144159395, 0.011641067028376124, 0.028393311809087475, 0.035919713892883835, 0.03900540496913656, 0.012034746206125185, 0.05861596880300392, 0.01603430069442238, 0.05813991793641641, 0.02577156166455919, 0.06831356940130073, 0.04247364971125799, 0.02154695639957584, 0.020142868536734776, 0.03060772151295697, 0.03018761421704004, 0.01297358216928138, 0.046983421629955696, 0.03846665363638632, 0.024044565826414094, 0.02694904646505752, 0.008527113053376877, 0.03489941118224975, 0.04634112202292008, 0.02887265685374939, 0.04959648625264245, 0.0169707435904251, 0.037072787301674966, 0.0036926838454805436, 0.06887110520995433, 0.015540939113575847, 0.03147976514282486, 0.02543805294760293, 0.043665617403964845, 0.017616293325479475, 0.027486129641352643, 0.044931481937847795, 0.03319414542807687, 0.012423714900749826, 0.04374733983328746, 0.021916421453258204, 0.02170655358162138, 0.03109921479687816, 0.019768128967693737, 0.02516546162716564, 0.01567684406895311, 0.029408276802109137, 0.014664409081301382, 0.06452573959024684, 0.07556562582331319, 0.034021114359699914, 0.033478118899849155, 0.03646808728996304, 0.03904350252161103, 0.07419882537496668, 0.05677087668089136, 0.015552802942693235, 0.025685338468681422, 0.04642852116376162, 0.08649888027819895, 0.02726351023621617, 0.017965995225935213, 0.03463854292227376, 0.07691866733253964, 0.014801247706336361, 0.007909374703998648, 0.07548232908330618, 0.020941676076261267, 0.020682370635650812, 0.025490738729375507, 0.03034393062754985, 0.08142359374511628, 0.036117973617248, 0.02278015877480709, 0.05475604245739599, 0.0011390289822180246, 0.020906685010319757, 0.05495694901553854, 0.0509024056936464, 0.056384216783748525, 0.09327603113507071, 0.05477500313352193, 0.1562101234711947, 0.058469289778581554, 0.12644751568234738, 0.10611369590004606, 0.1073605882664842, 0.16192958269628788, 0.11305280540498996, 0.1815187726770678, 0.17385323561968344, 0.21436005800722108, 0.20118706889690893, 0.13091776129459182, 0.13821231261376413, 0.07699985733075489, 0.1009701892373062, 0.2194063710950075, 0.18199402298177444, 0.1942006534626407, 0.2420243509714642, 0.23063004948198798, 0.05713073499200325, 0.15058181338733242, 0.15612372407509437, 0.09168081391122072, 0.09581371270600827, 0.11439066305155716, 0.12067087565458591, 0.10761909697565342, 0.13010618306936758, 0.1267721760837782, 0.15932572645045098, 0.1797289921030883, 0.12788328702651686, 0.23969588801264766, 0.09330356433506935, 0.26039965931446324, 0.15980594100490694, 0.0613208337416572, 0.13276008017841848, 0.16763594181787583, 0.1086902104678654, 0.07612323057987998, 0.16047960808200223, 0.1949881458835256, 0.15105574602080932, 0.14156814544431626, 0.13866588263021362, 0.15235325381640466, 0.1669240316316005, 0.09410135297765655, 0.20465160960391646, 0.2942639324934252, 0.14847645055382483, 0.2529633204422651, 0.1599924068056768, 0.27766384905384434, 0.15883414315119868, 0.20634107862509068, 0.11010456965455126, 0.14628523990752237, 0.1481646374468842, 0.11583199619405693, 0.06812357959607918, 0.09101119177836565, 0.19018356417936666, 0.1648042969886334, 0.1340746410912083, 0.10353033250618367, 0.17345162168625863, 0.12471169834175419, 0.2535259967008906, 0.2258355188513956, 0.27252588120679705, 0.16749174874876777, 0.14864989285988195, 0.13215484007471992, 0.12029845733195545, 0.08513171976852803, 0.21874329135302575, 0.09639075311321406, 0.19893256406630241, 0.09654634557063542, 0.12893641277426673, 0.1641639700580028, 0.12598288335627125, 0.22976608616450142, 0.23106967669821557, 0.11701452951397627, 0.08567563453388792, 0.10992949558121544, 0.30151406603474773, 0.10456468143890943, 0.25422577205444535, 0.07449214511941518, 0.12010602370625544, 0.1695444966636358, 0.07118181025068607, 0.1417990290229359, 0.09481048992564602, 0.1933591211995771, 0.12343976256107131, 0.14311089330623228, 0.15949003698845066, 0.1509100054540942, 0.15414940824191417, 0.11610414892915757, 0.1614328819297014, 0.09049506302201941, 0.09742494882835497, 0.1264230008687704, 0.13011859369374093, 0.17057231086636745, 0.18579035636878785, 0.16275948574466093, 0.12169097535192006, 0.08144623930415801, 0.10628887722569128, 0.08335130844986247, 0.20878578776553755, 0.17002523215788026, 0.18200998825411643, 0.1017411494807851, 0.149069310676667, 0.12032108756923869, 0.3103367329364823, 0.2247764635831118, 0.08274301165534605, 0.09090283630235542, 0.12347844234036824, 0.13278470224430486, 0.2838840539897642, 0.23681551999142095, 0.1435657197068776, 0.1300321636541236, 0.06880765780806541, 0.09168325007081994, 0.17938652015741796, 0.2015593416628338, 0.09657342677875873, 0.13909037194905743, 0.18276740406309405, 0.07893258225052588, 0.17133418530706437, 0.1188068918042606, 0.07476609816113788, 0.09226179201035731, 0.20727192141836692, 0.13371387496590614, 0.11203652848639797, 0.16186319351676973, 0.2130473357054495, 0.12175553358129917, 0.11865702968451286, 0.18179966647538448, 0.13800018286753085, 0.24195520387541866, 0.12972320039426127, 0.26774359266123465, 0.13369915075600147, 0.18941605133154701, 0.14987940269131816, 0.09881325336473604, 0.18290252665117865, 0.18359257268809503, 0.05317137426426334, 0.18882130663241112, 0.1581234280620852, 0.13531397216983382, 0.1399139624329344, 0.16926219326353845, 0.06168943694642475, 0.10224293707118881, 0.16896516565353642, 0.11502631684584964, 0.13375996281543087, 0.22013967045612876], [0.02728016690290984, 0.01392578828193608, 0.05387618281548062, 0.02129637286998332, 0.041271699892897765, 0.017284004603542628, 0.05351002726163115, 0.03722963997373178, 0.040139429601690466, 0.018600490312242222, 0.1349073480213842, 0.043563103348377256, 0.04548209997254514, 0.03984995178818222, 0.02538780524064937, 0.01057587635342873, 0.07002997407389265, 0.014582969146900842, 0.04828108647357553, 0.06171647601971223, 0.04641509547288861, 0.07039263243636779, 0.0676441004860305, 0.03093038625534504, 0.04877481864945543, 0.037649241651618676, 0.011488197055915672, 0.029229123310576526, 0.011901966889478989, 0.07784347335297255, 0.012819135970916721, 0.01659126576757239, 0.0684899764676248, 0.039274769144192825, 0.047779904092632, 0.019010127101454045, 0.1339121691642269, 0.02640505700612501, 0.0050145908232568015, 0.0163244909697002, 0.001083281960980516, 0.07111071729131284, 0.05211726792397038, 0.03268487698909256, 0.015437506710089024, 0.06537383722682154, 0.026625751615351727, 0.05225614434288395, 0.021659450665596994, 0.012422185597730982, 0.004308648461911587, 0.017419121445967786, 0.025598190221635085, 0.12222755865584459, 0.04428097752914314, 0.04179907098953282, 0.039917570538818836, 0.03158727409167877, 0.09606508147572318, 0.14308688411068532, 0.00962365204618583, 0.04067730759420703, 0.032894467153856834, 0.05248882822812565, 0.03133635731383918, 0.012018010057809373, 0.0943397518788134, 0.0251224477054371, 0.09891826103651717, 0.007923518123495723, 0.02350666102082018, 0.03919391622466426, 0.029787059400170564, 0.01514798388891523, 0.03770068445573411, 0.055472296362202016, 0.0278587969425585, 0.07025976980765981, 0.0535693301278497, 0.04287371231663612, 0.015284918274940744, 0.04365768839394854, 0.018999476564086733, 0.013506247891083121, 0.018868697694532813, 0.010478248023578237, 0.08114573365497975, 0.025833771834450386, 0.028551899670292775, 0.06706856927203556, 0.04493766426739674, 0.07979348121631531, 0.04456159936624669, 0.04306911453304272, 0.009637537389813412, 0.04192905695808511, 0.08639674543613389, 0.052311655073877306, 0.03098656922849196, 0.03857703158451665, 0.018175386207839175, 0.06846263478960722, 0.020709472911192045, 0.03550769648544731, 0.014899544447900788, 0.033376861228457386, 0.009478844191518523, 0.041477988218708385, 0.00660018454636297, 0.008235962295363988, 0.02794663083829707, 0.05835335386256057, 0.05435966473493365, 0.024428442909171986, 0.03414588326948785, 0.02036237379445905, 0.027043020555509195, 0.05334107806124995, 0.007106019953836597, 0.07024970341233477, 0.038493983823085026, 0.038640115094641526, 0.10582770761703292, 0.02475960739707995, 0.03373619859978076, 0.042013368764591795, 0.02498158903401946, 0.03180601709191838, 0.056854548803981275, 0.02207365716927715, 0.03467310497897767, 0.02986022845781859, 0.019485846635014303, 0.04742053990823127, 0.06678056617778155, 0.023922706135518612, 0.055663328047000596, 0.04285544111964203, 0.0596687191676709, 0.012992255562435717, 0.10785959495772278, 0.02072483488929368, 0.03563384052305933, 0.030097376720439044, 0.04724381108497901, 0.07236899372430579, 0.015138663471706454, 0.1310453455775015, 0.06226707490221147, 0.026660235148043405, 0.0071062923938546695, 0.005953107902314515, 0.03462477249183482, 0.05035616585143632, 0.03129667204414164, 0.05204673420878188, 0.006109657012031324, 0.04278303048903904, 0.0164193288242865, 0.04756244237444574, 0.01805997314682651, 0.07566244401518377, 0.01795942602198451, 0.05701792854515295, 0.02915961998364618, 0.0333622595926206, 0.03230797322166543, 0.01843423008047525, 0.0100315076809737, 0.10750537122329397, 0.07172564840725354, 0.09760546212595317, 0.05446200259029866, 0.04829763014230037, 0.09639878171466051, 0.06747006829227171, 0.053484175624626304, 0.11241486100780387, 0.016144661405574412, 0.040915763951958194, 0.006282387813928748, 0.049805114977061755, 0.041030412840266386, 0.04152958424040868, 0.03987903248578791, 0.01738529291845137, 0.06541305326766546, 0.059115136372706586, 0.04946901688292142, 0.021029546361176238, 0.03647567922129266, 0.02980185255798842, 0.04669427706469451, 0.03546591021961743, 0.09724076596959945, 0.05142741723947468, 0.05125160006085231, 0.07391239276095744, 0.0036993782569263735, 0.07167384554181369, 0.060506149029899994, 0.020043313495754715, 0.05849196598114026, 0.030739367977085135, 0.01724782035565905, 0.02780262929117007, 0.0380182700351842, 0.02480507854582562, 0.06502053279790186, 0.04458396530319606, 0.014069661509335763, 0.11021995015682713, 0.03142403799199289, 0.019729305546911016, 0.011282114616234698, 0.024193600571203618, 0.04678281001566399, 0.055210799910128124, 0.018180595605724284, 0.07320584519015205, 0.02900900518251283, 0.028728341210573435, 0.03723805161914037, 0.06149334908132592, 0.01465940461193602, 0.06575569375267913, 0.048375617892992114, 0.03679771577158282, 0.020910373723675168, 0.02512818570398996, 0.03913137663696562, 0.040331522318264174, 0.020149332403595892, 0.02147938552943449, 0.04345083316307395, 0.0452065994332154, 0.057297405080809716, 0.026747126755635106, 0.03762383434560992, 0.028480823947897846, 0.017378501549002626, 0.03421391570760358, 0.009322061424984807, 0.04179690296070711, 0.07786743658324403, 0.0591064949009207, 0.0851500062872806, 0.010332834001840844, 0.0329388466273104, 0.05627584981641943, 0.01256954260996633, 0.04766553099597654, 0.007541798535854586, 0.0348900955530905, 0.0016606966739580518, 0.04263755805309742, 0.06940117676652248, 0.014875421296775103, 0.039356074055596706, 0.025789413428414735, 0.020572216768238335, 0.01881943441056196, 0.04510778175186246, 0.02665455077564524, 0.02442850419620593, 0.01027140811446213, 0.010620345842213401, 0.037873931409370516, 0.03294136322614166, 0.020340505814660462, 0.07770923176600088, 0.08230412754440501, 0.01432702012900864, 0.05699622910469771, 0.09913385350016818, 0.025093412973106872, 0.014664348751877346, 0.03020626462755665, 0.006569749788351118, 0.01938576873902592, 0.023961830245811614, 0.04259024446289386, 0.04923997191532005, 0.02904323399096968, 0.02202616163319157, 0.01443724390194421, 0.006723790917725813, 0.055211064210462, 0.04340337401616477, 0.02001966436153218, 0.028569682486235138, 0.021266612269344832, 0.006288431290041415, 0.04394521268324987, 0.025729656655101046, 0.09268021391284081, 0.031046732028405515, 0.0765315937479177, 0.13102613209236053, 0.02591294510620496, 0.04767741685012176, 0.015584890535401722, 0.014429429805116549, 0.09481222128435489, 0.11890927945534069, 0.07630352171198015, 0.03444955286179339, 0.018610056835196672, 0.0571522390800378, 0.05697738717220003, 0.046965069993729555, 0.013642314682534386, 0.06709297683330313, 0.03687569586139533, 0.008376504955512863, 0.059863202078568364, 0.03952485854707418, 0.059003613123129454, 0.011827271401641831, 0.04730052074357387, 0.07337276042709429, 0.0019620743466563706, 0.059263067950885144, 0.1280178963356922, 0.015733183132514598, 0.01237199247454203, 0.021778311122268922, 0.05141951887297535, 0.061609001544814926, 0.08076190828315674, 0.01564881961507302, 0.03987455087143087, 0.028236968585500316, 0.024800476272620504, 0.029312107869754397, 0.06379714783942027, 0.012599685296957052, 0.07535258443245003, 0.03978183891083445, 0.016614903410476063, 0.02329636988560519, 0.03558958362367365, 0.030461643867555167, 0.032343902745314186, 0.03504637748964372, 0.07381356741872526, 0.004210492010198293, 0.030966696907736124, 0.009654019771504306, 0.030924496954427134, 0.03349517201704364, 0.03368935232321101, 0.13434439597110595, 0.2741371786161777, 0.14119355909286008, 0.15928593584366385, 0.07622966317520027, 0.10594073622938126, 0.14514992824725567, 0.11763425634032297, 0.13528804775447617, 0.14572823269953653, 0.24439266582410185, 0.21025057852027879, 0.10914047864536125, 0.20752358130149304, 0.05953643493534577, 0.10014138935554413, 0.16613085483831747, 0.13393014158693053, 0.16925057937060634, 0.12046942517401711, 0.10518436229998067, 0.14596328379646425, 0.19443040323113242, 0.15242233962541626, 0.23354931944800963, 0.10849052965040169, 0.21962819951436213, 0.1680476221466257, 0.10369359350372707, 0.2757442472202163, 0.17396490059552655, 0.1166044349872297, 0.16710404697204792, 0.13173585126717247, 0.19700369256879055, 0.2168939551038127, 0.23829652116663996, 0.08557665597407088, 0.12746553162052748, 0.19737953530444255, 0.07594591186892602, 0.19447946350180334, 0.12192293911451295, 0.14461997926475542, 0.11931077847557685, 0.12999134648951793, 0.11098574696769638, 0.12626519441724787, 0.10678595337536066, 0.09073900839974804, 0.17286613132924805, 0.17309960428505175, 0.11498957526900115, 0.22035155505422624, 0.11618353862075076, 0.12116050542963129, 0.06475456239235017, 0.11458720290853132, 0.2293546050186119, 0.32758609121364934, 0.10100781181526762, 0.08399151280642518, 0.10326188763663655, 0.17883622387964881, 0.178721540517384, 0.08642461571481921, 0.20857002676254321, 0.19627692027678414, 0.16201042029405796, 0.10909095872193576, 0.1658941030261978, 0.10177078942257552, 0.09403180751589038, 0.09617824798389789, 0.08311267206144911, 0.09335954237969653, 0.06502574219578697, 0.1396125528000055, 0.1712928472026702, 0.1291515302634047, 0.14841298783017745, 0.09178959073558932, 0.20850621163845065, 0.13929382957998784, 0.13299529981468955, 0.15081349369739333, 0.17252405774929833, 0.161434352818516, 0.10037814116766376, 0.08957270082206496, 0.09513003285974266, 0.08520613754949263, 0.11307137537627451, 0.10283166798011911, 0.12009129183547151, 0.29924374914938406, 0.12036971883067202, 0.16693745349203387, 0.27103185653686523, 0.11259101526511293, 0.12651094010159855, 0.19039416174975135, 0.08625854317459368, 0.180543803219353, 0.0811194185347807, 0.11576775972160602, 0.18311718448756203, 0.14583989767537964, 0.16457027244952419, 0.14689867715201071, 0.10267240596154045, 0.1092024474975563, 0.1491206232458353, 0.09812398107662317, 0.15013867748841164, 0.1431034162880913, 0.1595334128867234, 0.1138439597261529, 0.07597747469140638, 0.22427725004813365, 0.11171526185447171, 0.20202454089397387, 0.2703515398165872, 0.08345528956382506, 0.09083756561120672, 0.09320488454954279, 0.061403195854396596, 0.1311914079011448, 0.24956683898645066, 0.23329612738903494, 0.18800693984714248, 0.19844038321846919, 0.16542861268164652, 0.17322810787347057, 0.13819633201966364, 0.11582261927786375, 0.1361868374290005, 0.13989556100099318, 0.1359865667238351, 0.13258924257130394, 0.23855098493156895, 0.23011028946888065, 0.0927692486514007, 0.11232217202984518, 0.22669241883822028, 0.2388473537059561, 0.1745142622460281, 0.24430864130056676, 0.1678999357165829, 0.12845354755559277, 0.09920952000444937, 0.11409983309286256, 0.1745144614288884, 0.1652945779384144, 0.12400283718541746, 0.10999297362662132, 0.12046004825782393, 0.0849852973835603, 0.10449187244258581, 0.14964664985816326, 0.11481752724296625, 0.1547846023834521, 0.17497411418345668, 0.14609966276874467, 0.13047972754124673, 0.08142489609458754, 0.12045416470256545, 0.10215036300641876, 0.11108536138049058, 0.127894870275932, 0.16900635054034574, 0.27508951783660923, 0.20391506202999624, 0.19655225227677053, 0.13508777704931077, 0.130943134126644], [0.04944224594040744, 0.04940802479282983, 0.03251191731842776, 0.05024110710608864, 0.05850017461324892, 0.009748410422264809, 0.04098917815774199, 0.049873059315066186, 0.058705049506839246, 0.04035421001214174, 0.011747303313665814, 0.04537704250504894, 0.010794175980282168, 0.06109554643532442, 0.0062897618890049006, 0.02722221043621821, 0.028610151080835252, 0.04345813015055272, 0.008173606568767179, 0.02461189606917962, 0.06303592074301935, 0.06453524674138715, 0.03527156903498596, 0.02700932992381915, 0.023951212267181086, 0.029979443230155497, 0.050810777747462836, 0.01702878624200821, 0.012702219462352655, 0.022657395100160953, 0.03941974745342328, 0.04453238460325426, 0.03638084519714598, 0.056754574329862674, 0.014847562509408642, 0.017992463563719106, 0.05811844066145921, 0.050130051170145316, 0.022169176842116063, 0.03301802947516403, 0.11135210553484579, 0.027188653869914915, 0.06397138687691863, 0.004233016431586998, 0.0869642174051654, 0.02316413544899514, 0.06472713644466092, 0.03555429761388129, 0.05338135130342938, 0.010547250520528085, 0.058024801734474406, 0.0714295324418814, 0.0595918499053486, 0.018783096945093527, 0.051559084771020766, 0.022472296766335928, 0.02573274781987552, 0.10786681150596951, 0.04362875708348809, 0.0442789473961438, 0.021936443161159273, 0.09578475458247047, 0.06798057396325373, 0.04349071570041199, 0.0003505967569869808, 0.019377198130373034, 0.018520468598111503, 0.03721045330166817, 0.05156795606918393, 0.04907737741427076, 0.024725424553898555, 0.0183040181159853, 0.03130909607505366, 0.03531972149146661, 0.05079174429298409, 0.015623182482686977, 0.05766526134985109, 0.04535285710927941, 0.016962341521115556, 0.020608950684207584, 0.019513753302876028, 0.03834151317395511, 0.055462452132375016, 0.032073598197330876, 0.06470750927204086, 0.10047713504923929, 0.036638549513994687, 0.009807606993783868, 0.06745782620724171, 0.038277755506456866, 0.006629092874185693, 0.08714574193882366, 0.04764174013548801, 0.01933561104740347, 0.03960381156855053, 0.02059907964130323, 0.03616420702347833, 0.02793330856929383, 0.019433722012646256, 0.030318542473739198, 0.007527726458295459, 0.0293740862980485, 0.02731350130371509, 0.006506831944739867, 0.06682696046247598, 0.06419381667529384, 0.030350578355512796, 0.0395694793382239, 0.10043208141841235, 0.041791111335999546, 0.04981060782747884, 0.044455641745439464, 0.01590607289765631, 0.07173377660013015, 0.044084142728318135, 0.10420888722423585, 0.03960144818730412, 0.06452407717945115, 0.01882350616787951, 0.036480264257519476, 0.05484100160819869, 0.03021315175799593, 0.02879304691187797, 0.048421916416696006, 0.024532828134514635, 0.034623251807305126, 0.05374368024809707, 0.06828128645617156, 0.0369334627213257, 0.024892824341452895, 0.06464059149185497, 0.08047502367727219, 0.07963998017892723, 0.018803614694925568, 0.05795636710019843, 0.06440861240750359, 0.034150587049342936, 0.07278358518716789, 0.013862582197743318, 0.04581597641170506, 0.025784543024436123, 0.014019471258976528, 0.04420891163810607, 0.09942967835212908, 0.020585554359000058, 0.03435929238255467, 0.05428094920071383, 0.04242235629428779, 0.01291371239799886, 0.01740206066789406, 0.022757716229065292, 0.012913617594618232, 0.038759751215336785, 0.006050152090122743, 0.07478010224839372, 0.055601228959858424, 0.015303669234497413, 0.030634839110256686, 0.04340122896997679, 0.02817877654677197, 0.04215850795228635, 0.09129721070489577, 0.040872832384681514, 0.05093398383788524, 0.039572965038279374, 0.024764730610073577, 0.01751772653792174, 0.057431815207124724, 0.0067964524421240055, 0.03719633047078406, 0.03799401569150148, 0.05581936866585767, 0.04437162488278362, 0.004087206916958695, 0.009274404052825225, 0.061419999993015686, 0.05370925608721953, 0.019978898907861403, 0.0469189208571709, 0.06733918983128763, 0.0424509926608974, 0.03442172088750428, 0.02880784198491564, 0.0139453177783458, 0.07687535272130082, 0.013941763130377137, 0.124052043012794, 0.11728400094134193, 0.09920773501958578, 0.026508561230354735, 0.05861543637189654, 0.06290869652143409, 0.028459486483986822, 0.028988544889275106, 0.023762226037140337, 0.07071880203100943, 0.06092666235241679, 0.022621105515187787, 0.040045223769641695, 0.09271259644940015, 0.015714398656611242, 0.03501808203216042, 0.044788721453158126, 0.009569908105467838, 0.010797586986765025, 0.046681085030638406, 0.010669156176699026, 0.04824076726612064, 0.05659243182068872, 0.058953457346726815, 0.06086731352092278, 0.07073886587374634, 0.03931196654335626, 0.09051295883593061, 0.02668926604993401, 0.029446023869358247, 0.09816899640305389, 0.08358070581790902, 0.023829433015517654, 0.029832762290513324, 0.07411522219978994, 0.04847231734123442, 0.08757600756061655, 0.02559986220852983, 0.05427658249954543, 0.03401654081479196, 0.03865585437104587, 0.0005942717595438984, 0.03560349578037858, 0.04764539437488683, 0.07424998472655013, 0.017271247324383548, 0.031559660452448075, 0.05059202134068455, 0.029544378067516995, 0.03956334680439003, 0.027064290986726844, 0.09603032406659857, 0.05601843278254232, 0.03764379859691666, 0.01349497586488724, 0.027078909859541925, 0.031327062752097845, 0.05512246614201896, 0.045908971824833465, 0.013524831268906355, 0.03303279965034416, 0.05918181666563596, 0.01692502154788423, 0.02900645027928535, 0.11119337977781413, 0.01072210051314605, 0.04709673752527564, 0.034874160924265464, 0.035986834686369665, 0.034929579724707914, 0.07031253794388426, 0.044228370271382794, 0.036386675126249754, 0.04239492268571931, 0.06846411333930108, 0.07666087874601926, 0.014810673460634726, 0.034248864638709256, 0.07881471962337533, 0.019970157844645363, 0.020925431181826902, 0.034512912163571004, 0.024109480286678, 0.047804265688624115, 0.0651783928755791, 0.03302278688117381, 0.05184910650695524, 0.007590169806198608, 0.030926460054733103, 0.05792873430876963, 0.05346859339624644, 0.027760582555445935, 0.05429095047856531, 0.02399563387547049, 0.05869839986365649, 0.04577230173914183, 0.061016938153414, 0.03274267832297952, 0.05734899344163076, 0.07654328424964221, 0.008902863858477965, 0.129490340308797, 0.06030671719101168, 0.06680015504600541, 0.10140763310294959, 0.07610582506224033, 0.09277841872385434, 0.042311855772089575, 0.019219855162044688, 0.014321497592684484, 0.023693435171979572, 0.03920631918815836, 0.018789589540251804, 0.03458982356072914, 0.08486752668696065, 0.007596019845110395, 0.019473119999372193, 0.06337838119737084, 0.04267765509505426, 0.03953942187851475, 0.0354188341166704, 0.0858017709106207, 0.07321804897078583, 0.016841152157153816, 0.03749417013398582, 0.06090767869365312, 0.004412127309478819, 0.05398696679021082, 0.10493712274417763, 0.058277737153994466, 0.03625865800366287, 0.02925159075417586, 0.020900374361043497, 0.08636354318549556, 0.036602616159906315, 0.03815318577952924, 0.03988156057593804, 0.017188008040970853, 0.027210460562679558, 0.019733049801640937, 0.020519956165263732, 0.020826705431024876, 0.02229459692663964, 0.04006826769440405, 0.07208099829093104, 0.03435883656023972, 0.04483172196834799, 0.030145017813230236, 0.018824038598986886, 0.06525008338353326, 0.007025807196529763, 0.03842236992392329, 0.08767172258587615, 0.020464307538444, 0.03559872305261032, 0.04094667943014253, 0.07973310582700276, 0.0491363202191649, 0.030906606886175372, 0.043870944289430495, 0.05075569602570707, 0.05526829863928499, 0.07184108253568411, 0.010933191252632007, 0.10849066754622806, 0.018128396289783622, 0.16270990453420148, 0.13352028454744047, 0.1562906393120366, 0.1327875214478662, 0.10701994727095289, 0.1181527829518722, 0.20515664540711911, 0.10584943387056552, 0.12566523265934762, 0.13872087242141848, 0.21139232531910945, 0.18469327249594275, 0.20919302478432658, 0.1157894859751386, 0.1474160469707943, 0.15612902540353038, 0.1694142770382666, 0.133830075182261, 0.1724814019736744, 0.1902623946267751, 0.16737617672451083, 0.12531658604500756, 0.16077089003257214, 0.13634679658759025, 0.08319246011876291, 0.09759624608822408, 0.16508902122657146, 0.07855285544909778, 0.12011391441187552, 0.09877828911187188, 0.14102033129142177, 0.21732733104257815, 0.10881496788633448, 0.1635873356773969, 0.1267997399272938, 0.1942414553054879, 0.17152541617472328, 0.17512321021528016, 0.15523722245087548, 0.13159150498047953, 0.19721643518536322, 0.135641704583841, 0.12340281414048326, 0.14344119977566505, 0.21813002264788076, 0.17009076331892323, 0.23032951318929273, 0.1714882302668787, 0.18813334435464876, 0.16683603877261763, 0.16294780547820753, 0.16148410256831877, 0.11153343854652298, 0.14347912112791694, 0.11344292801955055, 0.07066662378248668, 0.10493217381618677, 0.1909032424971942, 0.1189381686309653, 0.11337486876835746, 0.09065293076057589, 0.20923387259244922, 0.16646379665020974, 0.10944592556165111, 0.11436190411087968, 0.14808940761271985, 0.08191084864759639, 0.2211576021246372, 0.13220474304210755, 0.19654549538127838, 0.17443321014363922, 0.19478926945838237, 0.11726910053121468, 0.10526368304366067, 0.13130851210125033, 0.11871344439925686, 0.16399973612879554, 0.142967987264837, 0.1336834919188292, 0.08797748359821497, 0.1812909074848698, 0.17161368482535885, 0.12730089166472036, 0.18112406885672003, 0.19899797265327748, 0.24113699132877014, 0.09078177142768137, 0.10657495743925534, 0.1581292809738267, 0.10358038869115616, 0.07887912463516959, 0.12244397849445382, 0.10653687520853936, 0.1975488713792255, 0.1724196552869774, 0.18845523917867293, 0.1050182820988759, 0.09368845456910711, 0.2002821045537149, 0.13196670420227513, 0.11071722548935684, 0.08032880047516477, 0.1647268761430056, 0.11202283083431183, 0.14842924421593068, 0.19254380446528235, 0.18421204670542674, 0.15303565429583674, 0.20619567513706225, 0.1181284596602763, 0.10667133896100907, 0.21086455202631413, 0.1877144321558937, 0.1328579096063491, 0.15822864257760588, 0.37032628972684184, 0.1115359130105184, 0.13602123986328804, 0.0727936439216137, 0.1482701583975746, 0.12511572545214047, 0.16460206509838182, 0.1501894844395499, 0.1323907951553983, 0.15403607319439613, 0.06997052565096848, 0.3123197668502408, 0.13621947277457486, 0.09539953493062528, 0.08443061142198502, 0.16476695786320394, 0.20098638450426443, 0.15265297805590017, 0.0917136867440516, 0.18781820642611674, 0.20827931171703726, 0.10882047605851006, 0.263727177535334, 0.15337402001023293, 0.2616025092861345, 0.1169055228632304, 0.11203364799580268, 0.13131278687186781, 0.20469348396985762, 0.14177437631353257, 0.07350706330109989, 0.10931115537401169, 0.11999030612529286, 0.0960408501146782, 0.043858407260549646, 0.06554320394512146, 0.06503031574069493, 0.14049448854019567, 0.09196265765856351, 0.23050647949980152, 0.18970445279152165, 0.18263339996337893, 0.15674846877734508, 0.12001796189935938, 0.10390372376047796, 0.09449501491842732, 0.21399621220846332, 0.2134535308446615, 0.1301769389500541, 0.14603184866568736, 0.11256690647813583, 0.1280010040969618, 0.15991221272176312, 0.15904477136510034, 0.12586450745021144, 0.1486417263626091, 0.2892825836616178, 0.14651215515069424, 0.15728373441003984, 0.19623935132497744, 0.19322194549585545], [0.061910798052145596, 0.012879668408253742, 0.03568737474720805, 0.10590487565364569, 0.04905714120175089, 0.0077690441544438086, 0.004498676092724406, 0.03384035974440556, 0.06794492789213696, 0.039878879268203056, 0.07248474960966457, 0.05145537561827129, 0.052780175296169136, 0.029243215497943665, 0.05683471095718204, 0.039918260017950694, 0.05675327581083102, 0.011772787228467004, 0.047495061111065655, 0.110048400087943, 0.029807174953842358, 0.030978465933472882, 0.051007949626974525, 0.037140632048249245, 0.01622165898762403, 0.02791273719330709, 0.056572138151574525, 0.07812691056319783, 0.011231213819325693, 0.04621304744373887, 0.021941516578437823, 0.04557211147320848, 0.0054720492147269754, 0.033643858191827615, 0.04280280704880434, 0.062212916316404465, 0.019093385537064845, 0.05257336220013038, 0.049239768902020115, 0.07346027831156408, 0.07314058982076184, 0.02507749175082051, 0.09467494598920308, 0.02454791815140315, 0.038813902140264554, 0.030071084582877737, 0.021415488050890066, 0.037482077436101054, 0.06028841535050062, 0.06463557361595093, 0.00721728225471452, 0.07790451523877921, 0.062170034544842864, 0.07063001244058532, 0.03133512774272071, 0.024764648255621715, 0.04056760763388969, 0.02300776349711082, 0.043305199848668235, 0.03733132665436115, 0.027821461647568692, 0.037807293251276984, 0.028898324629652406, 0.011315543820420581, 0.06420384476622266, 0.034472941526121674, 0.0488853651369291, 0.04636753290410965, 0.05869789424562647, 0.02304972021750385, 0.06502124525967144, 0.03363766437095981, 0.058441189673518947, 0.06478974881071238, 0.029243543000531294, 0.07388759449484848, 0.008192990508471287, 0.023131867825624444, 0.0208071835954944, 0.010223955670822292, 0.02669097251078535, 0.058876634049679966, 0.04693354930608504, 0.055807023158957886, 0.08670626794018092, 0.02457493615727271, 0.029555909605997226, 0.08128425001256889, 0.01769439981979949, 0.09077401095700842, 0.02107729279105702, 0.055870045382048816, 0.02147867306766491, 0.04523943396165006, 0.029106798221267043, 0.028210094221116557, 0.005359602350396135, 0.013448826728328584, 0.053441240226910006, 0.046539626895420017, 0.015715811131221634, 0.10185863672485275, 0.03604032294524293, 0.056313349820312955, 0.013797711787535059, 0.0333664117891702, 0.03962392137656289, 0.039990655326795195, 0.02314448146329772, 0.04225032359001137, 0.054578248771928975, 0.06266149143958766, 0.028459794834376346, 0.026488782755369623, 0.02761078363795194, 0.024967916279790864, 0.013899725013142152, 0.03708990170590339, 0.020499624191753326, 0.05848916209933739, 0.03057552092227965, 0.07415470637140736, 0.037028143527887525, 0.03706835165259339, 0.055645983816394885, 0.035989971816419594, 0.013290373890119936, 0.049385271981478705, 0.03841188218023989, 0.08433308842922412, 0.021111014066264037, 0.07275764545005176, 0.01828550177085544, 0.018366278081591574, 0.01715000624948692, 0.026811935878809423, 0.04303982316125785, 0.032069195106986075, 0.06068787657685819, 0.11148653864379852, 0.03908602423184822, 0.053740922331569664, 0.01728447000195663, 0.020051531703962434, 0.04477388233006482, 0.04272780321057766, 0.09238274963272196, 0.047700165831033266, 0.04701345610702711, 0.027739116771807595, 0.03636309877038002, 0.04836603796349899, 0.05204125668012327, 0.04251067091019885, 0.028674515873013486, 0.04505395258386289, 0.0794074724939081, 0.041520981073019006, 0.022049437299551024, 0.03930645071030144, 0.04924557967892578, 0.0500301456439399, 0.024694934254512194, 0.03720815886833495, 0.03406561640722137, 0.048091583134185885, 0.03597537018058281, 0.07290094219628843, 0.021769656243944363, 0.03227159170614135, 0.02478626342640529, 0.032180932861182, 0.04002862647476216, 0.018100903309401006, 0.0541256133827471, 0.02002540619052466, 0.06612005283034618, 0.01901312059001817, 0.021703609888772332, 0.030020304444816806, 0.04404158654412435, 0.010186041979449651, 0.03727946250188736, 0.010511979832494212, 0.03839753718385774, 0.10292142284132781, 0.03427226862479602, 0.012912756703313322, 0.057737905637270985, 0.03010402444840199, 0.04671959244015236, 0.06956036983718795, 0.06898417978757812, 0.051518122049709486, 0.021121314118405985, 0.0876847614023474, 0.05509586756928794, 0.024898625542259505, 0.0029633293583643653, 0.0335561947506522, 0.031476356051561814, 0.05393661183094787, 0.005010411334824899, 0.07934649955601462, 0.03957136391451763, 0.033480221811201305, 0.03653259189318746, 0.04087555965769195, 0.03262128020005842, 0.04300477846916165, 0.0695715623817617, 0.03714363894335205, 0.06409373111842621, 0.01980482074882715, 0.05724836779277652, 0.03933243641269304, 0.04889587586325023, 0.04506565074646666, 0.04482728248882679, 0.06847227983657392, 0.064187511771677, 0.013503546473540127, 0.027417156830309864, 0.044141097535048766, 0.07254254328267229, 0.017524052508956483, 0.036153175357368686, 0.07374532430643037, 0.09500269372496875, 0.04974382411267969, 0.08384546580454035, 0.05916354546864187, 0.03684049795171426, 0.030380354277909766, 0.037797809082774386, 0.002025356441135368, 0.04165742516277298, 0.06098880740483442, 0.006816686260619111, 0.053555770371589935, 0.03733650157828966, 0.021019501033269113, 0.05863383780383776, 0.04758945846509549, 0.039342430029665275, 0.004792441604583855, 0.034757933894833254, 0.019724151690400416, 0.024888735347157045, 0.03607624480801244, 0.05779856830955513, 0.06354650685323343, 0.08837443971706015, 0.017817322457689914, 0.03697754725092842, 0.01467021794298724, 0.05625355665782287, 0.04243781594859977, 0.055429043037997144, 0.030681978415457473, 0.06923407000759918, 0.027845183560144038, 0.10445113188677257, 0.02375781337069648, 0.03603693300617799, 0.0334558448934507, 0.012539701570095796, 0.05543383874840314, 0.016995727632855697, 0.032013519667088985, 0.02348177082416031, 0.03863263807650055, 0.025556047724920417, 0.019083878385924527, 0.045254104545400034, 0.0029319824769176665, 0.016342063111463384, 0.0740071501763117, 0.05672613331567376, 0.040213008516377984, 0.052236049856630065, 0.0950581661515659, 0.037219213517082315, 0.01989844435405347, 0.025598136595480388, 0.0273582638211308, 0.028042895531642343, 0.076248049285383, 0.03425588583453529, 0.02488235191952798, 0.03672623210736821, 0.0463413403579785, 0.007818941376172006, 0.030905509465223843, 0.008356004442659118, 0.025780513401954405, 0.010203863099788227, 0.02990897654766037, 0.03458069562311134, 0.03904200481971906, 0.04312857061684613, 0.060277088740540136, 0.14013983579652925, 0.02570038060507467, 0.006167280709280843, 0.03618032934384481, 0.036701793902583664, 0.03358831681731728, 0.11888595973892559, 0.0691862354776071, 0.048579466228763905, 0.02492111788371638, 0.06216883178680174, 0.03643786512135017, 0.05141630896457261, 0.051660587590548306, 0.014159160688699735, 0.02024216502304039, 0.08205350954085588, 0.033580763190383875, 0.03596447641029954, 0.02765803594112156, 0.0864162730173238, 0.08518497054014476, 0.03561326723185278, 0.023584547264861967, 0.03988283611233196, 0.07522338370402014, 0.076339612114093, 0.03911749895421728, 0.022580508600860354, 0.02816752079994448, 0.017078430654721397, 0.03580838982616702, 0.10824416343483234, 0.049839451037828005, 0.04271020617095694, 0.031431528416672544, 0.01919915355111082, 0.03718595380984968, 0.041227561737140345, 0.07316641464468933, 0.03894172007999113, 0.047313073094213204, 0.03945096553633771, 0.05754129683238365, 0.022344189628417936, 0.039372533454649875, 0.03408677192525037, 0.03506442269070014, 0.07373865168060988, 0.04684030108394162, 0.27811216370713326, 0.11335829062567604, 0.12024188173874734, 0.20024989821737815, 0.142253028048623, 0.13817904907609188, 0.13085373166588046, 0.06327703159542815, 0.18715437591796924, 0.14365761961427428, 0.20319235000398853, 0.11590436852026371, 0.17905956915309354, 0.11357450362054572, 0.16231726915124925, 0.14047000437013565, 0.10774239882706635, 0.16124646209420698, 0.14306862057457048, 0.15972957736061466, 0.10728141307950982, 0.113461620564903, 0.1313021688932373, 0.07288441001888245, 0.09337543870412535, 0.1808941045836095, 0.17680059036900922, 0.22617226045939232, 0.1289625516942432, 0.17043274496832203, 0.14277007611047837, 0.27265087611252264, 0.13862497353505704, 0.13577167906107443, 0.1720997982568318, 0.23065255714520333, 0.10141303402281578, 0.20413325919258982, 0.1111969574084205, 0.11554037716480033, 0.12367764818331889, 0.10164358818362798, 0.19646643510749265, 0.1585316303516588, 0.20884986335952438, 0.13429348176765826, 0.14410337553389613, 0.13540464633655164, 0.19741138924033413, 0.08060659161738812, 0.1327221281826496, 0.14274792084770818, 0.16875950168938408, 0.18322705681766235, 0.11086022346130303, 0.23114898212013707, 0.11553168206685975, 0.1364580172324373, 0.1535617728387156, 0.20168504136944973, 0.07702103966186125, 0.1425304897730389, 0.13033271526857731, 0.1540746380605044, 0.1351137167864269, 0.12577993134337087, 0.11518620705652623, 0.1344865818898524, 0.1942857505092698, 0.10949707725235533, 0.2605221720953142, 0.1016898905377715, 0.09599013509409082, 0.16235445505909382, 0.14763226762654322, 0.17256092190021471, 0.1867418375707442, 0.08275378285156143, 0.11310919713709625, 0.10439624168699789, 0.14213736409381514, 0.13377180653474025, 0.133145468369607, 0.17178662151338595, 0.1277752456465556, 0.11483435053378345, 0.2795304682466292, 0.18289227639475178, 0.1688632912813656, 0.23437261881847538, 0.1116936045488523, 0.13570806311984218, 0.0990351890364001, 0.1303276131230016, 0.07924749035268061, 0.10664172200185638, 0.11861104908729754, 0.14555882001596113, 0.14267768590681015, 0.2556716251156984, 0.07385301328594647, 0.20185217111101075, 0.1771962747819001, 0.13407048889465872, 0.09368422576376507, 0.244875347181674, 0.12151288289216258, 0.12585622603974997, 0.14587452484955712, 0.08234506728307855, 0.11061731996315141, 0.19168120478430103, 0.10214040386340312, 0.11370947299104546, 0.1584370951018026, 0.10380364969492921, 0.11116516475956287, 0.12131916989962901, 0.24197286986295255, 0.12578127199723838, 0.1182982860313308, 0.12699549071370594, 0.13857343113951145, 0.13976526476683157, 0.15812880599931364, 0.15109523019242674, 0.2527160885473413, 0.09132575514095445, 0.07569211460049115, 0.20148572061331044, 0.14362089335918427, 0.11854361802820237, 0.17393050324772635, 0.1657110999428457, 0.1233100945190076, 0.12958377239204225, 0.24208151645237402, 0.11578764736412034, 0.20859489397656536, 0.28229292001455064, 0.08853852042868253, 0.18745310424316317, 0.18257980445219626, 0.1348526646653491, 0.1118895238746078, 0.13667141868462487, 0.14647731347189796, 0.12780853982774482, 0.18354660741263823, 0.20118435694565698, 0.12774821040370773, 0.21000477154889416, 0.1451752551140324, 0.106524464584166, 0.15076480114892607, 0.10833470736660304, 0.13629631139338017, 0.19070625064834473, 0.2215595071714732, 0.1705700126025946, 0.10851403322791862, 0.14159822205622352, 0.0943253800693539, 0.12616122862504375, 0.1765434759398622, 0.172936458200697, 0.11804353881386981, 0.11133769542099008, 0.19808764569461348, 0.13552994767744697, 0.10828036875013383, 0.16437340317474258, 0.27203230607894163, 0.2248333992376443, 0.17530688745600564, 0.12286570223589098], [0.03991107028278132, 0.02851281769483561, 0.053658035448602134, 0.06845223897647473, 0.021290083288124973, 0.027165774654056278, 0.09413057157108862, 0.05691097117960454, 0.02149883841705178, 0.027836597629732666, 0.021810147821182208, 0.023587360722763885, 0.020859459520227486, 0.018547796869590398, 0.045808319362901875, 0.030923989421177297, 0.028402158209393104, 0.05475239970931604, 0.04050356651385946, 0.008469713915650164, 0.036784217302357, 0.03544855449769286, 0.036053714162159356, 0.008172568519629778, 0.030549178989003264, 0.04143802907257792, 0.039133893235796885, 0.07599475763497815, 0.055247851752585946, 0.057136932643310684, 0.025590590629426223, 0.02155018546017668, 0.003772180310578176, 0.04786453765606688, 0.07189503810819119, 0.024516834133875468, 0.02126974939939476, 0.03654303750203502, 0.10618125719408836, 0.044096308204555706, 0.019577261991798878, 0.056362911878574284, 0.06368239552924229, 0.007367733304554056, 0.027311871451656186, 0.037933054244926864, 0.03813134078236838, 0.041365821455274863, 0.044219954795534575, 0.03504552330160814, 0.020920800180324627, 0.045891957012035196, 0.08191490125271582, 0.046387343937831546, 0.08261445444077253, 0.035669107380653584, 0.05127290496602655, 0.028033451582755775, 0.022843207810975374, 0.03511347530049182, 0.04667628548979279, 0.07228824805708663, 0.06972189947602249, 0.018328052209389788, 0.05916491293558671, 0.03493468953116286, 0.030468350967332244, 0.02480038242684978, 0.04622580280767814, 0.051028959588297916, 0.04618666337562665, 0.03816254737396394, 0.01897122132621946, 0.041454810228559284, 0.019406232862703262, 0.06677305085524436, 0.031597487958929235, 0.027340542292222384, 0.09606934092458218, 0.015907895229306194, 0.008501435701374807, 0.0216875143814832, 0.0364239989299207, 0.00790656699175616, 0.034015797709505406, 0.01355341975502069, 0.019033632594190778, 0.025276264754093947, 0.041546300278916475, 0.07165372041204283, 0.06833413886206766, 0.06386351020586106, 0.016568009253411044, 0.08234895134885466, 0.017768108969434135, 0.06375580207414686, 0.0767459528100106, 0.06819775988978725, 0.018727436826954928, 0.005910641254646885, 0.03909031432422419, 0.032850719702940796, 0.04084886915441002, 0.01264923011824008, 0.017515052891066, 0.03878636127938667, 0.01581579039338976, 0.031427027650117394, 0.022833761946868994, 0.07986561605526556, 0.01696484088296852, 0.031812657159002077, 0.05797666076931262, 0.041048906202758514, 0.026031202268636516, 0.030486474692400907, 0.08157244462880396, 0.04955753834257203, 0.08240567249876839, 0.05538824119514996, 0.06743838289572347, 0.05937614635894856, 0.01615145660546278, 0.02442397661657343, 0.050715035909125884, 0.009302231239064807, 0.032485004649647785, 0.053704766811983246, 0.014645996158041302, 0.10560961770674876, 0.03816398378882197, 0.05881413659681717, 0.05061450219082256, 0.04840710027624042, 0.04241664510881228, 0.07250931804939624, 0.051519110303131804, 0.042148686705097076, 0.05026168422773481, 0.04236856160024482, 0.10317256944554468, 0.03422806152112542, 0.034846378745691436, 0.006652977101639995, 0.05865089092103224, 0.024847083146713918, 0.029394663419694673, 0.06415171248297538, 0.03674885468377221, 0.06733312241492734, 0.042574482203851786, 0.09014751191341108, 0.019206933173981887, 0.02673750086086652, 0.1081166940651113, 0.016704275227722623, 0.017683073209839004, 0.07584774536230872, 0.04463437771905334, 0.031673428339643345, 0.04003670870236332, 0.060020070072383656, 0.035700597424781134, 0.07649099874881006, 0.035421021297694213, 0.02472822843570142, 0.05841500861870666, 0.035143973260757425, 0.08209267195554511, 0.0014677859191226984, 0.03679405004086514, 0.010000815325897309, 0.028741971829966195, 0.07947071305205745, 0.02975468835493009, 0.027412679046392444, 0.024516669424971747, 0.03566906524581775, 0.03324366918194198, 0.06467107413036209, 0.06342550709603295, 0.021564155073475935, 0.0856560533265433, 0.011529815740012115, 0.004185826373061225, 0.014145316522298081, 0.0554463949294821, 0.02063587292908661, 0.02957850728454369, 0.023582821651812524, 0.07590953035340195, 0.09695091660344794, 0.016864035203452074, 0.044902818758160844, 0.04629277804445836, 0.05252772634248099, 0.036080178669503624, 0.022261907954910592, 0.03226334860007609, 0.016674995347256624, 0.08015741894562399, 0.018401106353849173, 0.0048295236117536985, 0.0821419773743518, 0.04490729271163864, 0.05764188417684167, 0.010636750657501961, 0.02523311868219847, 0.016514656975144343, 0.046307977228876085, 0.014606010198833482, 0.027252384724335808, 0.08127071323894686, 0.08435884430523842, 0.029418048253583334, 0.015368788623281065, 0.01290331754247628, 0.06803971595100819, 0.11140303506005196, 0.029955707911041476, 0.03914917285944666, 0.005248420967555215, 0.05341169987654975, 0.043678062502294786, 0.06700090072568386, 0.05729812903389816, 0.040065548082272855, 0.04512676158018651, 0.03403847774250373, 0.06431501944579425, 0.0760272704064846, 0.05727051156422785, 0.03488389790178307, 0.03591840388253331, 0.0368162167949542, 0.019091661839235215, 0.04860310387166758, 0.032331197177089994, 0.08880253731002731, 0.010406620717877823, 0.06178312566912463, 0.04508770258736707, 0.026151863031930504, 0.04157790906667229, 0.0037275303123263464, 0.0456008589225671, 0.06896509653738431, 0.04488755062582993, 0.0031243933593824266, 0.0609351123022216, 0.024797689627795935, 0.06030674400408903, 0.017816722993889166, 0.034477810014880476, 0.035268883896811355, 0.03368241539705665, 0.07616667542606592, 0.00880955913735013, 0.06627291035387786, 0.010807377590437331, 0.04774273350654591, 0.08630041754053486, 0.017620307626202703, 0.04146608704280469, 0.018201442773363764, 0.023090916595632033, 0.012014209304095037, 0.043243089270207195, 0.05794097639379963, 0.05063489162092728, 0.026946813318758246, 0.031152281707393068, 0.07183382768304118, 0.005487502644574571, 0.03543177334171149, 0.039039825299574483, 0.014959643087950687, 0.03444344714103687, 0.03643983396731558, 0.021218718367538626, 0.010823835074270685, 0.057513878545573646, 0.018485347297222867, 0.06598689908822698, 0.012949975169894677, 0.01566757919311884, 0.015094348158116545, 0.035886684012028484, 0.031003687463160005, 0.10560091494792893, 0.01053016675981663, 0.09270091360855488, 0.033070403076107466, 0.02194696537879927, 0.06492205219523561, 0.08443395922621412, 0.026110567062372164, 0.020152243537708156, 0.04479152916540061, 0.04989811422062978, 0.041335618438860106, 0.03762311039252147, 0.020070323840745037, 0.04252873526345338, 0.032419423692889755, 0.021158676226473144, 0.030124643704883998, 0.09695215000500602, 0.052485610658843676, 0.06216513158212747, 0.03389600071034605, 0.03494025899037238, 0.014699030509819428, 0.01926072978324467, 0.012450240695128038, 0.0785871685272263, 0.09587179749242722, 0.04197426763693652, 0.01995763996796262, 0.02341013011192122, 0.0697367385991158, 0.01969451940948925, 0.026985236458600532, 0.06785420009926443, 0.01753179382743134, 0.055009606069013964, 0.02464286900395828, 0.07515712475944912, 0.007112714604684904, 0.023680574470950712, 0.08102258502115166, 0.0961267055883523, 0.037538074632926334, 0.016967870760709047, 0.023080775506734368, 0.030335476847305417, 0.054928649727615624, 0.09311381201710432, 0.014976141749009972, 0.02546630435503058, 0.06451652355251775, 0.05377394455154577, 0.08022082804311668, 0.02618020062424964, 0.03596829535860208, 0.05195920483299321, 0.011427517146653226, 0.07655731898041503, 0.02600154508986781, 0.047054909124609925, 0.03669477653719726, 0.06330405151651752, 0.09582217797757157, 0.10195662703124747, 0.09290064805217328, 0.17785653532032045, 0.18764254246507922, 0.11582206769455826, 0.19831704306266001, 0.06882366904568288, 0.09667729297953268, 0.06365114297237127, 0.14049355391292803, 0.12801327682550878, 0.1337904837583342, 0.23849213405722575, 0.205660899800639, 0.12452956859863575, 0.06668983072402977, 0.13198357345836778, 0.23567768024100413, 0.07101420553461199, 0.1041784888554004, 0.09669675927368865, 0.08732510610453545, 0.29121821205462184, 0.17662457400752654, 0.11929757111976225, 0.16844280094148653, 0.15632445443301432, 0.21243330091238025, 0.15771242189070872, 0.13582599469490592, 0.17847384896970567, 0.15591792221511566, 0.18384642358268463, 0.12808384118421426, 0.1367779355496168, 0.13868109713638985, 0.09770794170758418, 0.3189775918520266, 0.1410525682712755, 0.17131354689838427, 0.14271125587965214, 0.2850455965005583, 0.1059943623840809, 0.19232971353396294, 0.11537031330648931, 0.12662701008300628, 0.09830574309753795, 0.09427991275104786, 0.1348795849950083, 0.16484966471550927, 0.1767059631886021, 0.12699120062132999, 0.15578306009692533, 0.22302074327824578, 0.14435584747022198, 0.12252879974943016, 0.1813708870641647, 0.16448791799766405, 0.08180226334520886, 0.18566666381253352, 0.1250196963308319, 0.1685634751113192, 0.0687485234811902, 0.1907748308393263, 0.11136415609789473, 0.13282991675359587, 0.08977022893246143, 0.10958843323732577, 0.1732480721247773, 0.20849047619248592, 0.1111986734453709, 0.1530109862646749, 0.25884067038855246, 0.13438718964255628, 0.1584236885631277, 0.15683727368952768, 0.09979957624548867, 0.19079897793069964, 0.10701491407329038, 0.13824059657992857, 0.08342751887656989, 0.17835262321656753, 0.14550044411613097, 0.1275875770877446, 0.13052472754591896, 0.08211101210045238, 0.15997682457729695, 0.10857407153854448, 0.11489949865086425, 0.09687635326577772, 0.1651873869160491, 0.1005290375061093, 0.15975882659756369, 0.06999522432564728, 0.19795885099278343, 0.14563693034072078, 0.14543387107551098, 0.14948666005605651, 0.11913084740480108, 0.15134330478406724, 0.12808835344208827, 0.43350249649055544, 0.12359277330218785, 0.12808099899801517, 0.15952250379468166, 0.15216959189743767, 0.18747001946453126, 0.15664425017612596, 0.1447133653827252, 0.10244112401720017, 0.15941961818645078, 0.10490288627484154, 0.20405609881685627, 0.13016583067515206, 0.1845699170183751, 0.1491261544006486, 0.12655142784839676, 0.1937970477006128, 0.20259841735805237, 0.2031149751236362, 0.1946623286893291, 0.10531416823787075, 0.11552460341443939, 0.20349161459072945, 0.19069780835941916, 0.1166764549129913, 0.1931294480398778, 0.2282924394333555, 0.17799305218842723, 0.11602391654084768, 0.15463774332836752, 0.29068878401191006, 0.1545660068551379, 0.0893269244941973, 0.13883662830677726, 0.13366950315333184, 0.08418977636122897, 0.12611410655682126, 0.15297706389138777, 0.17718714301384267, 0.18769782336969532, 0.12266358525882806, 0.09410771150742808, 0.16630141665377926, 0.10181285531049776, 0.09994539342099622, 0.18018104526544773, 0.09517265033097037, 0.1595649297439283, 0.16380727952045782, 0.1460204952426495, 0.11313718232897021, 0.07041101088567127, 0.17967656104555055, 0.15860693679461557, 0.13468093839624237, 0.18378571877556463, 0.16312173808053618, 0.11947063804273644, 0.11396897761451621, 0.20794699809724287, 0.14543454523288435, 0.13339893622023444, 0.20369936231403582, 0.16192553775204768, 0.19234095970469137, 0.15579827460310153, 0.16359344905903264, 0.09770912914386681, 0.10815008017685145, 0.14250700151728046, 0.19201164914956018, 0.15809385706820797, 0.11486894706444395, 0.14619197636362047], [0.05383609343440302, 0.02524167588431268, 0.06251072533608926, 0.012784360367203913, 0.017361505888402462, 0.016995482484719927, 0.034835078948808294, 0.004880106482174127, 0.026246237403322614, 0.026882977127247763, 0.03156652268502982, 0.010472679521978624, 0.011725107831279597, 0.008511186085431086, 0.039155496915261594, 0.08327933448937633, 0.024992888830902598, 0.04272619442593667, 0.03763217321266571, 0.06995371768190976, 0.01660857935466113, 0.0956403470087436, 0.02333506690188041, 0.0195258823899372, 0.028582181210719773, 0.11467803029283402, 0.04319030198178465, 0.02570466878223083, 0.01515548101686422, 0.054438882056743874, 0.021405810445186593, 0.02410802855006149, 0.037336880791812174, 0.04021822940558195, 0.02636911407593758, 0.034431511491176583, 0.040623045586530244, 0.03731156541635433, 0.026447055861353878, 0.04029212624675805, 0.04026276209662038, 0.021929238104231415, 0.03848380251457134, 0.03446164939011778, 0.04699931029350527, 0.016340670746661002, 0.06634702169967276, 0.07302864905326598, 0.0594237587234426, 0.06749023938731802, 0.031005139199776516, 0.11783873286819267, 0.04776959254917118, 0.05923392979668514, 0.04196631181384287, 0.041178122252946904, 0.019809727541982167, 0.06249993115723614, 0.024025635793805126, 0.02961794357566584, 0.059713148436839544, 0.07193995384319175, 0.050233974827513586, 0.04521232211000977, 0.03773886627788025, 0.03878539217816245, 0.03746392498273523, 0.02299313313297687, 0.04174447190316935, 0.07121698134728978, 0.09555559470168046, 0.027397161935486143, 0.02624270573799168, 0.11495600529615918, 0.05149156944225392, 0.03262344056800489, 0.010837945456226027, 0.026603140530266592, 0.07078884544992639, 0.07622923416596267, 0.015541020510417801, 0.018321168909390128, 0.042422333311650066, 0.02226698137218914, 0.021076844629621314, 0.02260673945138772, 0.012469112313532782, 0.08130151763438218, 0.052506203102248336, 0.051611910363839525, 0.06551445266532321, 0.08940976924232899, 0.1275009402043877, 0.016753341244052977, 0.0063477317622352035, 0.10197636145617693, 0.05865390930745391, 0.049389458651984894, 0.09479453231418326, 0.03385951960339181, 0.055886075771864385, 0.06717364589172987, 0.08276747284276832, 0.02554307977158216, 0.04386879541280289, 0.02299280179994962, 0.025524816235467315, 0.024573233526860996, 0.03985969259613945, 0.02860654280671189, 0.03634477777767085, 0.0271870584918126, 0.042386549344706925, 0.03687065117241394, 0.06871209600039067, 0.011929385176288986, 0.01499228130635475, 0.017796898553628596, 0.011208235969646804, 0.01232082067402981, 0.056909550086504994, 0.02484329675714816, 0.02082425969532661, 0.051377380206700296, 0.025469071847657045, 0.05049516101397815, 0.021130622086685993, 0.03719728425024979, 0.02947089108338039, 0.02918078507777424, 0.02474674095039166, 0.03405980946075532, 0.0625276482183366, 0.03194650421069274, 0.012522596741966423, 0.020492673859060295, 0.029914289367415255, 0.04393366390779134, 0.01653415391281728, 0.02375185320664558, 0.015650798037137478, 0.009505718555902282, 0.01427211460747546, 0.03140101321942864, 0.03238444794870673, 0.022122152450103915, 0.04332712528506114, 0.007080989946130544, 0.019054818755736756, 0.1125732726687866, 0.02919214616169132, 0.0717840779332384, 0.08089490114681183, 0.015215192782512356, 0.05025104709690617, 0.026237774046979127, 0.04300738699854382, 0.07579688478501574, 0.11349312210034941, 0.06186973956984378, 0.011428553280570816, 0.07422129473378582, 0.05155063482121595, 0.04948809630267563, 0.021190309912086498, 0.08440788925415085, 0.05187444869549044, 0.040642358663101355, 0.046039911572851484, 0.0453536078754452, 0.0347900329788606, 0.02932610238091119, 0.02653026641646941, 0.021004106496430693, 0.04118870958806046, 0.011425922726160817, 0.05116658728389491, 0.042718139011412866, 0.030066867268854575, 0.02044292602447733, 0.013730611103857237, 0.01933881137970715, 0.02917210147115252, 0.018930509498703386, 0.0235928037774659, 0.06521678154146479, 0.022483087114749417, 0.019857111995318727, 0.03480759937496435, 0.023856366751715544, 0.029868898657901637, 0.04769540842502348, 0.021640800255080386, 0.010316628369412596, 0.05500446561904204, 0.06593628365906977, 0.014367132492723965, 0.03435774488494762, 0.08691518777801145, 0.02493687631231883, 0.02166515227497345, 0.07624018922327988, 0.09869274773424673, 0.03482205545409553, 0.032480810318262346, 0.02246127084588572, 0.012337472552673952, 0.04768586296948695, 0.021723193011336753, 0.01806278851994824, 0.04077069371217682, 0.02720842085358116, 0.04292150854223198, 0.030855098964586377, 0.046778489279771046, 0.012529982787166393, 0.02778348666916211, 0.06258878586513382, 0.018578597434586095, 0.07063797975499785, 0.016055247453492016, 0.04202495201400692, 0.07034353386130064, 0.04808210662656254, 0.002145306418477107, 0.018504160501423384, 0.05258292680786503, 0.07217796203950722, 0.04294333821763435, 0.060225657427743565, 0.05108192690738267, 0.06904961135719093, 0.03286416454601192, 0.177374160397918, 0.025707271565953572, 0.03350449530708213, 0.1303316427454833, 0.03337081679473481, 0.037846206687390804, 0.037528203590021986, 0.047392370855255474, 0.03951665374540514, 0.03544367068717557, 0.04920016598677443, 0.06638537206116223, 0.012058081244298769, 0.08539963603740738, 0.028731325123038505, 0.05956820460156568, 0.022962575800897136, 0.02102515284693049, 0.04190016395202087, 0.042553679086267955, 0.0720787383315544, 0.06609648030491606, 0.004836591251660138, 0.03901432989345443, 0.0799056594710677, 0.07842376963385651, 0.03200556384399533, 0.020523685098235166, 0.023461540357299873, 0.01265772220288073, 0.011120923013696748, 0.027847903172275233, 0.0627056717301809, 0.005644946161942978, 0.04576917993085039, 0.07111488480962093, 0.0175371200537249, 0.014528479228066582, 0.05435977198724305, 0.04201353730393514, 0.022206987111618923, 0.030933534876713832, 0.04296737039581903, 0.08360866802714526, 0.04608373563255995, 0.07917732435969577, 0.05348970677943961, 0.024238841893572, 0.03165168101869283, 0.07454180293866704, 0.03700472805048189, 0.04038871461225133, 0.0599636132228038, 0.0669759032767146, 0.10268353721908025, 0.05908818156909078, 0.057820769537600784, 0.023726112652389754, 0.0324363082707409, 0.03839266486465931, 0.04659718308117121, 0.08105827705754388, 0.011125034033020419, 0.04138086742210773, 0.0608209805232623, 0.006855586768999215, 0.03398347262954039, 0.016778796430557005, 0.01737330364243638, 0.02725901138488083, 0.059709762328214226, 0.028134592425739093, 0.03034343650083869, 0.03868251040037121, 0.047812593064361045, 0.15636606832906125, 0.021652236032570084, 0.034622715545758125, 0.11102092572517934, 0.02953680528838548, 0.059138264567140615, 0.01903595575582116, 0.015836763007926847, 0.007036906852942682, 0.025538492820135532, 0.014609215319186691, 0.05944571480335248, 0.04716815607201669, 0.016280730112245487, 0.08728165359747025, 0.033387184263237064, 0.03258192243294851, 0.03410168382669649, 0.03638642231723474, 0.012759304504030415, 0.039481647357705145, 0.042405912216993115, 0.04322797052502152, 0.02739641691497978, 0.029761328422013792, 0.060052241934763814, 0.0828466480297427, 0.06941218544999439, 0.07084264780484861, 0.016767757103568124, 0.0380597192223274, 0.05182109833244355, 0.014590902944966672, 0.036929877429840066, 0.020278429710156014, 0.05153068972210731, 0.049057937933192144, 0.05568436099096172, 0.033451964658114224, 0.0343324716443256, 0.036934427992110296, 0.03668885850798219, 0.025134063513589003, 0.023089528061269272, 0.16294645716346082, 0.1772968774481166, 0.2002851842271705, 0.07800116489130644, 0.13615863007162848, 0.21454822452318287, 0.20641800917444691, 0.16757106949244777, 0.11462402875505148, 0.19784108795706304, 0.13145149475143802, 0.08032726829931622, 0.13944039752166118, 0.11382016503522474, 0.1368090540411011, 0.17968760803341868, 0.10169391249937397, 0.13650841049609647, 0.10476755684301739, 0.23780136789766051, 0.1140106221540801, 0.177061673133604, 0.18195901276363483, 0.09961107265084021, 0.18459352784820143, 0.35600305024173956, 0.25918062956583116, 0.2900012660651438, 0.08320353008926877, 0.17005391448976534, 0.06423363792559793, 0.12600441808782278, 0.09744028590859906, 0.09853111084310279, 0.1835449220192048, 0.1482964352133774, 0.16622945035417236, 0.12414477795602814, 0.12343875132501127, 0.10595953602704311, 0.08238508771624296, 0.1155238526482736, 0.0828760504842766, 0.2364356782768042, 0.17420923667809657, 0.21268388827241239, 0.2545436066124709, 0.1848434410508602, 0.12136233895416222, 0.12658985481867868, 0.08718020823453704, 0.23434473321803156, 0.1597383720499854, 0.12220331197304111, 0.17071256624354472, 0.15708455154972692, 0.13126576439507548, 0.23015171950382574, 0.18433071372489776, 0.1339064235047948, 0.18340730198448707, 0.1675688171939504, 0.10308367260281118, 0.149728391439684, 0.16648221340390945, 0.13976045373466708, 0.13341695460821354, 0.13581389050570228, 0.10337188254080473, 0.09007433519488381, 0.23193212316161205, 0.16493114582713575, 0.11509901858986386, 0.1909838655903455, 0.12710785282956016, 0.08871940910936364, 0.09164026487738856, 0.15954206968026777, 0.25488197232686705, 0.19621805408068244, 0.13517462077640718, 0.16649189675527234, 0.1662812532196122, 0.12125235937175252, 0.09837543411600976, 0.11677539516841212, 0.11538895988656629, 0.2119180301745092, 0.1583275138851135, 0.12029926938515519, 0.1917810107190763, 0.22802512071305708, 0.28019635187041375, 0.13319855826275964, 0.1032018876304069, 0.1858715310452446, 0.30389111428972215, 0.09790368483311708, 0.21268785660786016, 0.15979538431331036, 0.13702392638210328, 0.15053753350530902, 0.18373341029209478, 0.12394505883416823, 0.11827355671313503, 0.15628526137480814, 0.13953220549850695, 0.096240691810606, 0.1917327778233636, 0.18012459990718674, 0.12188153206220559, 0.24023892177689463, 0.08814082886543005, 0.16701796933287577, 0.17529239307247824, 0.2790243905638495, 0.09789500505693498, 0.08553085157707815, 0.13344718443770565, 0.14220635797227585, 0.13995082658385077, 0.1505037183843313, 0.14257671551839, 0.10650343547064452, 0.13192461533171515, 0.0819925902291171, 0.14227562764238927, 0.22239530909686323, 0.07338002294061646, 0.08202580014063467, 0.1602871208301475, 0.17645686203914304, 0.2030337391601455, 0.10261465059292894, 0.14424982090150157, 0.1712016214526469, 0.06456972835885902, 0.1548797964689232, 0.09329499181119666, 0.1256246759646362, 0.0830865254805934, 0.08459758794596119, 0.08863769051048065, 0.1739941345107171, 0.15262458683742633, 0.07916220178407046, 0.14887711453822353, 0.09616085778801672, 0.07773032216655631, 0.20393206918191528, 0.1241995532426142, 0.18396970245145983, 0.2109948942257512, 0.18395700071367527, 0.21050806067162947, 0.09933981623861099, 0.1313710248758716, 0.14856524014424893, 0.18958745584372552, 0.17656373130458017, 0.15043063359635492, 0.10914116812449311, 0.10976458749463482, 0.10013526831302913, 0.1355138291875201, 0.10670942119172505, 0.12138044161181297, 0.15686607859548063, 0.12622338133834063, 0.19008086243223762, 0.1334014336668676, 0.18678656178376368, 0.15651058315509753, 0.11325038714154113, 0.14608817144988046, 0.13001707172201526], [0.09082338532372829, 0.02201444048795008, 0.03838765464963452, 0.051101638349674405, 0.05210000796303634, 0.02010937134224561, 0.06006092937182515, 0.03653835670481767, 0.03622744758162768, 0.05164012155165115, 0.02488543925386283, 0.061364447127186486, 0.07420713742894512, 0.05465435577676662, 0.06922274722807831, 0.043668187628950805, 0.04335773815851539, 0.022733057774002516, 0.004429064555874756, 0.04049368014919662, 0.03699639684430534, 0.0508804457832969, 0.04885826477660768, 0.051006643447063627, 0.09717605452263549, 0.033824754533387964, 0.0408434069475099, 0.059027043922293576, 0.0720132684575454, 0.036780754584939256, 0.07525117737391303, 0.05199396990299706, 0.036656644510766195, 0.06068890696511634, 0.10488067738591664, 0.056791358041547, 0.04077367762464189, 0.04333210102612934, 0.06645973621597213, 0.023983650345114932, 0.02611258378883283, 0.055258707218473, 0.05615173208136713, 0.012007847901493793, 0.0790835475368846, 0.05339809415501453, 0.021470062239395998, 0.03717500258297209, 0.15320057770417583, 0.050753416914132335, 0.013554191588604403, 0.02435109675711682, 0.020946429651831428, 0.013491301515680409, 0.026440055732945764, 0.04044910149288274, 0.011023401936155655, 0.08665889306294342, 0.008435361575515521, 0.06842435337603092, 0.045283936009171515, 0.004698251573098523, 0.06687769846570107, 0.027971304615118334, 0.019471744871548107, 0.03765933102958145, 0.037741792733751, 0.03853131528763521, 0.013757543882445223, 0.10672479657636535, 0.07916446940432634, 0.041146172556064786, 0.04272209585554177, 0.0012010175851173699, 0.019639301707126924, 0.015343000188529974, 0.017783846330618667, 0.027054670837617693, 0.12733686715364456, 0.06356418816252582, 0.025472304738697507, 0.008228468040244715, 0.029752319228024255, 0.052867984294050166, 0.018567238265888828, 0.050596411024490674, 0.011194387015195624, 0.03953708914078532, 0.018031738976377155, 0.024919874906059236, 0.03125822592166162, 0.028724355638147365, 0.06607061717659235, 0.04340460741772287, 0.011554005923831176, 0.05403021628397608, 0.004633833633570542, 0.06343205331734593, 0.030323862954373323, 0.04241508228944675, 0.049357137402459506, 0.035550528461293834, 0.019419949666987506, 0.05490582413791169, 0.11228045854236811, 0.00955124524602246, 0.058254440420217095, 0.07611329441950207, 0.0066309755352596126, 0.014415507114702656, 0.02804425342248813, 0.007333133901063834, 0.0450096037539263, 0.07027322231161018, 0.05657171297277655, 0.04876589372513756, 0.024052134775105986, 0.057839626791856946, 0.0056568171731346565, 0.04166432378453113, 0.017812605271296158, 0.035370616542716185, 0.046232444789981654, 0.025936875777739673, 0.00864821910527685, 0.023151067904226726, 0.06034222536630208, 0.04213828706152497, 0.01207538812811817, 0.012718527559040776, 0.025923421358569496, 0.04538598275112529, 0.014914102033681929, 0.012131670692695246, 0.028441659617988814, 0.04273092884930872, 0.04711500489183011, 0.07564071776165117, 0.03548172993525382, 0.0236097170836142, 0.05566519347109622, 0.042880905882245114, 0.03637070985390775, 0.06158611849851667, 0.021375856407347228, 0.1453638199957148, 0.011744828849670388, 0.02554176784601183, 0.050466061164174354, 0.036672429752445994, 0.02501237236203686, 0.03162497902409204, 0.049202445098349167, 0.007551807474585311, 0.03788938723324287, 0.08027012580104413, 0.015080914806364285, 0.025023501704356847, 0.025281098768896153, 0.0329683946385499, 0.013169975511940017, 0.023341084522525632, 0.06986490510884794, 0.052045765107557665, 0.027458793708994508, 0.03272696969009215, 0.04456184451438246, 0.0670230636493333, 0.020420018080321532, 0.07525329943746328, 0.008875937783159316, 0.04081491996804553, 0.05100102802257865, 0.010766437851763781, 0.014856906866865053, 0.021451697196631182, 0.04163612025759874, 0.03204704175943569, 0.04574692890708966, 0.03174877117177652, 0.024784859570284045, 0.018460097039238583, 0.021379472342349833, 0.021138187204938264, 0.012245345691729699, 0.030223984241245255, 0.03045643446967006, 0.07942928301711237, 0.0304701512739543, 0.07059490263101555, 0.008144379356845973, 0.013478022339122911, 0.013172659692504715, 0.04325115617604987, 0.06126513914956201, 0.1128239059940942, 0.1128223508356079, 0.042097423931643854, 0.055635266246334206, 0.01614594460284758, 0.13786253218929614, 0.09305479260341776, 0.06630621219594633, 0.05283277106261062, 0.040275938808918, 0.05073083647256417, 0.06065066002549664, 0.05955239254680853, 0.03396515929771047, 0.06612984343401848, 0.0532962006306456, 0.06389105489717857, 0.07296153209021977, 0.0702810287475586, 0.011670261681560549, 0.053763962425892396, 0.010494045714186806, 0.04306676264311518, 0.06820255560019324, 0.06529149809671987, 0.031320395871936794, 0.02357606667154018, 0.058073961596575484, 0.046407116667157224, 0.030175216999205372, 0.043004583116740956, 0.05373100149295023, 0.024669345002621416, 0.034298985941155304, 0.01700957658730688, 0.022895409042135845, 0.048889908038320086, 0.07270875371872418, 0.10391358331206346, 0.11754592640265343, 0.0523584553851716, 0.011040402384805343, 0.032540151488877116, 0.06705710093580908, 0.048570855400494994, 0.017092438572416865, 0.039216167248424985, 0.006979463186355369, 0.020393289272643386, 0.010230124593832561, 0.015583469442302182, 0.051117534674103224, 0.08234034818146499, 0.025066207275695862, 0.010661994212216908, 0.021929806924515197, 0.04704286239200062, 0.01577868205194752, 0.0798668954220991, 0.05803342022362256, 0.0035384143261434214, 0.019770496179379766, 0.04193914633604788, 0.02034908216897278, 0.0862482009876159, 0.022883586390244386, 0.05131387151777745, 0.04046847202604817, 0.04203165145290475, 0.029597835682873285, 0.021906950691294287, 0.023208976490423087, 0.0541727546031677, 0.03397442513115464, 0.08909047145636813, 0.051630905513922055, 0.01755316193485933, 0.03310925522518735, 0.04587982217931459, 0.0839751568292418, 0.036828991311091575, 0.0283259688501036, 0.06247837344304689, 0.01735095685768512, 0.04422870351962986, 0.06861857964747375, 0.031311239206021836, 0.03253940838359056, 0.04236331006752388, 0.0597636642745666, 0.030304885041269086, 0.01250798648764049, 0.04499807413066587, 0.01770395485143508, 0.06227558996948985, 0.01855544434229453, 0.039920512316448074, 0.0659748408642988, 0.03855764189915311, 0.08135736544406222, 0.029358785606980808, 0.062095854251134786, 0.043510197316326445, 0.03516768751245353, 0.02253532090464667, 0.026202589543836734, 0.06428128859448819, 0.06197932461697248, 0.023456225622325175, 0.018573020314497334, 0.029860190153422377, 0.051799586583529754, 0.059772037615578984, 0.043714210361001954, 0.06074920191519684, 0.031446007478441444, 0.02254438372479091, 0.05204961086893755, 0.14662512247600865, 0.04068812858613749, 0.046649729051897605, 0.01762130545572408, 0.04646933449792766, 0.0054148688908636335, 0.026513818508735108, 0.018965006437933734, 0.012399492158193984, 0.03419963965913461, 0.04613674125604091, 0.012130579017403146, 0.04956029242865982, 0.04993733409191332, 0.041119727200918624, 0.06070736202321226, 0.054801092257783304, 0.021764695824634646, 0.04855901168118562, 0.04102570139953206, 0.03785214003836436, 0.04296344419520709, 0.023139904087950146, 0.02075043563250332, 0.054838465857169325, 0.03243694412371805, 0.05848853007679986, 0.03575921847274707, 0.08472561655986695, 0.029397247051219308, 0.027245059008559874, 0.03449763637036085, 0.023234065869943272, 0.010082684269535446, 0.02036857910664572, 0.052297643325742216, 0.07386739275628522, 0.040845471554465836, 0.07701214538106034, 0.15564493444417754, 0.161257601012626, 0.17874820037714897, 0.22567172925318443, 0.131622945228892, 0.15298909147179898, 0.20303559309292227, 0.08217505705092223, 0.15224249282431218, 0.14304605162432119, 0.13017920657030999, 0.13171458466639444, 0.24692509203187882, 0.20154362153862754, 0.13136642834832593, 0.12631463773188092, 0.060512074719994306, 0.1230202834572523, 0.19557332980536646, 0.18627444732814066, 0.13909257828227936, 0.22005811273570985, 0.23106118844401455, 0.19985245180226144, 0.30464623183492695, 0.14448003032274787, 0.12312878448996814, 0.16578740230010403, 0.13246625481593993, 0.1256584681029762, 0.3312965308225924, 0.1768811062098511, 0.07069071724770531, 0.13538592314768222, 0.2084122432936584, 0.17540422658766472, 0.2029868852226965, 0.2137878516148175, 0.1377499325861854, 0.0959137254845231, 0.11147677102276396, 0.17700338916432473, 0.13180697487006265, 0.13310627531140082, 0.22299160129360615, 0.13201329766982986, 0.16229797905731588, 0.1483842748547754, 0.23653232792933143, 0.12928996235132217, 0.13165533542633057, 0.10138865710506517, 0.10584361926322022, 0.2187855181194121, 0.06322977163137929, 0.1097863826960806, 0.1407396673194824, 0.22936692371243433, 0.25495494986253403, 0.15807081314344562, 0.09920942041301921, 0.1323120259950238, 0.15321167065731942, 0.09979642762411987, 0.15138139467566245, 0.08855850766262702, 0.08119277145353057, 0.1298707489284777, 0.1145870726735842, 0.23338454925725538, 0.1563110785378564, 0.17491900181818396, 0.14586585273425426, 0.09530615647353473, 0.1173269478303771, 0.11675206013023855, 0.2279162749407753, 0.1263808507111765, 0.16592257085346407, 0.1411799993366003, 0.1968836159475388, 0.14294308940729789, 0.12379041632577298, 0.2903338095113155, 0.13941346187024348, 0.10370084069549076, 0.18579826239616642, 0.1678105026123024, 0.10961804253559922, 0.11346329063657792, 0.11161912548085375, 0.1262144793966605, 0.14708056174699338, 0.18347038166417232, 0.13251450303341114, 0.18589724095598345, 0.12122622045177607, 0.25754319323647407, 0.11045840268413867, 0.18120302187819637, 0.13829321149856816, 0.2537611244066108, 0.11424730501828656, 0.1540075594018544, 0.15763687029961618, 0.09860143005367249, 0.11988041847343407, 0.14063730265104002, 0.14816053121561004, 0.1990720533555554, 0.18664767004309163, 0.11698052287101747, 0.12875412981356346, 0.17536106519401076, 0.12823980902471852, 0.15939409213681377, 0.20739040457673613, 0.12584839662116382, 0.18394124994595207, 0.11837179216766551, 0.21252731522244794, 0.12138984917152314, 0.11350970790391007, 0.2547733563809626, 0.10254673689844147, 0.17407628977971693, 0.12090615657789093, 0.17040469082853488, 0.08556600735192338, 0.11309164606275098, 0.13132245490147224, 0.16554858205058884, 0.13975492257985378, 0.15021926993804594, 0.11177282570110214, 0.1217800024296007, 0.16210961335849378, 0.16771975183679214, 0.15615246769401336, 0.10480073611101798, 0.11058730463827811, 0.12541034754606026, 0.10995328261126434, 0.1162181964384452, 0.07473481879118951, 0.2610666154613418, 0.111164758732963, 0.13967839039621816, 0.09167121482952949, 0.12943438524680753, 0.1886017764768293, 0.12943504408242243, 0.12119320206223957, 0.213993898622932, 0.08637930927497726, 0.1868198712867114, 0.16157296876753532, 0.12873657107833894, 0.11131822146595487, 0.2012195816684154, 0.1457812766274137, 0.13918542813870216, 0.10815761848202637, 0.07935358586931422, 0.12195650142647567, 0.27953815976938895, 0.08585722801545936, 0.1126679151709522, 0.13606430932639108, 0.10548020247370006, 0.12199801573109244, 0.08385751636758929, 0.24513071493035365, 0.09840294433337066, 0.15856949041687673, 0.18313868091471736], [0.02854338843345402, 0.04470487696028525, 0.015615672905809216, 0.0277800124604255, 0.019823191537251397, 0.017970229776936675, 0.050471067548759525, 0.05201769947645165, 0.0640635893890454, 0.025733197896531033, 0.02307241365704085, 0.022602269328349543, 0.011615593647283894, 0.015284922105380365, 0.0639497257408596, 0.018488532307768063, 0.02792070642293942, 0.03879168942090004, 0.03886029642495898, 0.11945683313834092, 0.036108075761266296, 0.047874079281163794, 0.014671717560099018, 0.026225484081453858, 0.00912781025568444, 0.009943214132480565, 0.024470585405886657, 0.0769465452721042, 0.015654960767396035, 0.06264762141771855, 0.04080469652469601, 0.07298452238882742, 0.024767049941264337, 0.003614554847327752, 0.04325635408261611, 0.05959099571731302, 0.059701362174124493, 0.025413497914409926, 0.04914552476557513, 0.007464927837117425, 0.051103373538822904, 0.10750352495139646, 0.07692438234845478, 0.029113968804238305, 0.07044125603692186, 0.0386675103988138, 0.002748471860315711, 0.014993678459206657, 0.06902512718713091, 0.02144766948936928, 0.012746572122728873, 0.02375570662890471, 0.026168531189943035, 0.07394224720736665, 0.045894270597566525, 0.029212667741962982, 0.04063588522014119, 0.04643761845786245, 0.02562759267616897, 0.12609906825086764, 0.006981545509094553, 0.027131926974341757, 0.044716816440585165, 0.1177263630914592, 0.03823617991480616, 0.05610769351703986, 0.03346475066557046, 0.08686390585236012, 0.06931106950486861, 0.06545186328190951, 0.06275259461554308, 0.03193046424477812, 0.030937101016001358, 0.04421095326242428, 0.043552807126674926, 0.04098771109936699, 0.018991631823742104, 0.01497193018064624, 0.058110143929239244, 0.022308784874997312, 0.029632740563923315, 0.03062684498276682, 0.04023201515777938, 0.019631600608268095, 0.027687631832856326, 0.05282502591369614, 0.029514766854023742, 0.050741090559430664, 0.06136093461405366, 0.04086886787967336, 0.013265009676556916, 0.02395294171067015, 0.053815386077809724, 0.06577731275390233, 0.09552894250279474, 0.03431217414477179, 0.032647805994436625, 0.05317723100644447, 0.021262017657018958, 0.016615543093892838, 0.026056732148713162, 0.04404128776983388, 0.054313308754635435, 0.07011105681979848, 0.009505842087580072, 0.0020779014542518606, 0.013111679093731989, 0.055654801488403356, 0.058842225210560914, 0.025161924216175274, 0.019852134339030714, 0.010472028347242986, 0.016107257162671418, 0.059250998235638105, 0.031942083883369644, 0.07119532404167038, 0.05210980622758789, 0.07061672081509907, 0.0696245756661219, 0.03479352633979532, 0.07779384617723765, 0.05612377370257051, 0.022133046220387184, 0.030010787717577432, 0.020506044008558797, 0.07499728817492723, 0.02488929842178139, 0.023081237074708747, 0.043437813498800805, 0.01008908493414281, 0.05998137497132825, 0.023602806970537193, 0.020689690605767315, 0.056225008391324556, 0.02726574721295507, 0.09752663933942396, 0.0073665870454973515, 0.036939756133623665, 0.058017929925793604, 0.016108017504936265, 0.026707893477812893, 0.04604964471992947, 0.0900582779919909, 0.027176685661317843, 0.015741412832041182, 0.01781385016417311, 0.039893898421958576, 0.03937361363862311, 0.026046353572558974, 0.009866100679632398, 0.05194386775274912, 0.04341224531432794, 0.02545264883778028, 0.04020837751487571, 0.038275384464331215, 0.025491353514934742, 0.0996719230146658, 0.07303839369166283, 0.04859230203193523, 0.00951303469557916, 0.0700867182064441, 0.04984690124289163, 0.027058376787951397, 0.042897009050413486, 0.14458616414377767, 0.0614982673657998, 0.06588765239763646, 0.07846455615494521, 0.03134319081812376, 0.06647108963900997, 0.031292481543195826, 0.03828623226933903, 0.08063522798399772, 0.026497357194462133, 0.03209438407793641, 0.001770681403520998, 0.0605064363128716, 0.05634477474696695, 0.009027153005703323, 0.015010102426693326, 0.02007675323364956, 0.007540883539590024, 0.1316080371578855, 0.05839774099689338, 0.02114450934553339, 0.03552168525094467, 0.026672203356640476, 0.07099110032281569, 0.07860943870318514, 0.01585803631197421, 0.05604699637079912, 0.047992593083049984, 0.06523312985776894, 0.057220436227057254, 0.03006078836117541, 0.014464002395529422, 0.05805867814248609, 0.03062212205071363, 0.015833202614298752, 0.06505017273969228, 0.025891395052894953, 0.039582682863598874, 0.05614373795387726, 0.02439919558744277, 0.04292048581485306, 0.09020900579109307, 0.046430340622581785, 0.024491043783904567, 0.06190039840857349, 0.052183863947228085, 0.061077091377228505, 0.06773278282414522, 0.04384322339789041, 0.04019492118048572, 0.039690616991250746, 0.028290318948547208, 0.04604626627218339, 0.035396487331919135, 0.11735697847700889, 0.040225851980428544, 0.04081126572864671, 0.04191588407622711, 0.05755796690561599, 0.023631885752923066, 0.0044371530079402996, 0.030325155727745547, 0.020122952165923292, 0.032503555468734235, 0.0354235417269651, 0.03730165606905376, 0.031833557952796264, 0.022501975012522553, 0.02287101488740694, 0.12159746665988239, 0.030000805591924057, 0.029009106689162796, 0.030994124770645174, 0.051831386893266634, 0.02435028278869727, 0.016443167565270297, 0.03884935285896063, 0.03126355789361462, 0.05987491939337023, 0.020598732986517494, 0.05197662950283097, 0.04564467915183595, 0.03206252248116559, 0.034055350829036005, 0.01473145901165422, 0.027596559300417864, 0.07240967299308508, 0.03433180131739186, 0.05547244574934725, 0.06236056444205104, 0.05311441945753271, 0.022143945736329884, 0.03522276157333005, 0.019466081566567865, 0.035743184252491886, 0.019311276264488697, 0.05473834582634511, 0.06763375063817348, 0.013690469054234846, 0.06711175364832725, 0.06051072257480795, 0.01366323175569696, 0.04415622394111368, 0.027746356302692045, 0.06388810545867009, 0.03829402721396858, 0.026760431787660046, 0.048875789037875594, 0.027097776689897143, 0.01751306297768268, 0.02046335758941789, 0.02574247139085445, 0.030896795215085152, 0.03893893535038637, 0.0570825633833245, 0.015623253345819972, 0.010645932221274463, 0.025008574481152242, 0.02707455464969239, 0.03388721751229417, 0.03634875377399787, 0.053567319147048466, 0.108751313640706, 0.03743913437750551, 0.024155706032029083, 0.057874885988571954, 0.013788717915304007, 0.03544162523241774, 0.03454674260630723, 0.054761788116828095, 0.03313317249018339, 0.045103016684973435, 0.032704366265886256, 0.07067613859450625, 0.0288662695956807, 0.06931352864710555, 0.02864988231580825, 0.06462375287927928, 0.07995914006906171, 0.0864217505459824, 0.04670462691255155, 0.03190401697441215, 0.01921116772498335, 0.0231839943632123, 0.029171837170818643, 0.037221121076013775, 0.03156649395673266, 0.08496066765679468, 0.055347025664823676, 0.02809452985773885, 0.030993462104590672, 0.05576009644315608, 0.042703587171291156, 0.01652213399328532, 0.050702004753533876, 0.0030179389784367938, 0.030931569861188054, 0.03255306390084086, 0.03642347799013219, 0.04155128751130354, 0.04003963898867369, 0.03174850112578321, 0.07431669566299647, 0.04398166697712676, 0.021711355037686807, 0.03884895832367963, 0.04057559027006069, 0.05768257493693983, 0.006883706026259931, 0.05341678286992735, 0.03699466548559647, 0.04157695911764618, 0.04217974007910779, 0.033092780504375696, 0.011734452188736009, 0.04659019635930177, 0.08813182733231976, 0.050100541463302034, 0.02174526591965508, 0.04407680360600353, 0.025190311604209488, 0.04619862200812467, 0.06573995064583517, 0.02257197246616406, 0.09550805894597884, 0.045898024428395495, 0.013866184726207247, 0.03171021779698711, 0.21907220354243634, 0.07204139920612497, 0.09466294905230885, 0.07705851668311704, 0.13124959993987315, 0.12862764869726476, 0.38007576979937097, 0.16901088578085746, 0.12012817896902563, 0.14053391142477914, 0.07090717539071076, 0.14783080697299975, 0.10195238290414696, 0.1695150176003095, 0.29030457559612494, 0.09814907045614335, 0.1509289431475824, 0.18288551949925963, 0.17478677504245313, 0.21212904143237302, 0.1437264755969086, 0.1257046555439311, 0.1501375590000422, 0.1469609754220132, 0.11308779264049185, 0.11283018025419406, 0.1935145910829306, 0.17660067206428898, 0.21034146719161542, 0.23876323725187013, 0.1715070913515745, 0.19607226754869186, 0.14520916216556104, 0.11515551757427955, 0.17464241343400172, 0.10807102756394495, 0.13102823117327306, 0.11862607207149269, 0.11030993484441312, 0.1157530278508221, 0.07645661672276836, 0.13752162306299134, 0.15645436762321382, 0.22995440589804805, 0.09660394772166207, 0.10336275077274731, 0.24488153717210218, 0.1531397350012295, 0.17492450232948029, 0.11780693255845578, 0.0878729509009469, 0.16279372987487625, 0.15125597076069924, 0.20661334627337996, 0.11017989908014575, 0.11343928144103098, 0.11883087035629059, 0.2332775114524749, 0.09179474650731972, 0.18114024863368083, 0.09602129188997131, 0.10453041432605636, 0.15453703340984162, 0.164497003800446, 0.11365500413962912, 0.1948907148213156, 0.16399667177709842, 0.09504739495535051, 0.15129815156181015, 0.19746021968462776, 0.17870266411092975, 0.12215900144750073, 0.12513490829376445, 0.12315329930354511, 0.23124043769653768, 0.10675122660975303, 0.13795610216836776, 0.1698121524626209, 0.10612210754545466, 0.12039968819026986, 0.11036969736338624, 0.10685797330112227, 0.1014296657916519, 0.11188130375118026, 0.12827639738398214, 0.23488350753341955, 0.06213055037322545, 0.22343401706987814, 0.11652434049474618, 0.13720665367380266, 0.18728464150861387, 0.1564453277857073, 0.16842986937732468, 0.22854045273796206, 0.16763448625081973, 0.14469071982368348, 0.12533646602664264, 0.17639742893797739, 0.07926107309157811, 0.08771124506188978, 0.11592335983990662, 0.15529581285532446, 0.33124048383005206, 0.15063835067614434, 0.09680271689449588, 0.14901076623749349, 0.09993725756724035, 0.09507342662301757, 0.15554666068525086, 0.13542281794211558, 0.22727283769317214, 0.19309448378701366, 0.12996441083810023, 0.1808574855808289, 0.13576038692507053, 0.14422002008124707, 0.1456271857023239, 0.15671431657768067, 0.1609937756532623, 0.1081122201116335, 0.1867535280724687, 0.18230215886667853, 0.06412458914001623, 0.10730441869987596, 0.15292861649105627, 0.24392676179207143, 0.12255306941487136, 0.28116536116407764, 0.07122553088852475, 0.08018426266649077, 0.13344638770626438, 0.13690708265189203, 0.14728895298415615, 0.10018335565203622, 0.1563069110195483, 0.166239409497188, 0.14361663391032528, 0.16839303586992527, 0.19142205256127542, 0.15224411693071166, 0.11158291250467302, 0.15446399458714072, 0.196976573056271, 0.152289025004833, 0.09445166200279229, 0.08862557866039777, 0.12367937188114851, 0.09680264028570346, 0.08811902600310503, 0.11607666935531363, 0.13553838996637252, 0.1849851673168521, 0.15109132314401288, 0.1630957217346276, 0.10425377997659868, 0.12865427791351272, 0.22644360880217246, 0.13896143935140104, 0.19674000510525322, 0.09962285508311565, 0.19643951477783342, 0.14058386035744222, 0.14604134815594844, 0.14834402459523371, 0.2980454957052585, 0.1156514062876663, 0.19070003001439959, 0.14424833469092846, 0.10573977604508401, 0.12299874872570077, 0.18971744564271745, 0.11053023874879846, 0.20014707389618122, 0.1434299689266951, 0.19249825287730465, 0.17949872139480808], [0.01882582549907027, 0.07338288044857402, 0.027496368406460654, 0.08294243966379473, 0.04989246432218821, 0.01105304953882531, 0.05282425982577186, 0.0822135299864796, 0.07365508680982936, 0.04791410737520745, 0.040703304787917484, 0.02169540891754291, 0.02065345847738847, 0.08588324436136792, 0.09298694019596423, 0.06028193424666121, 0.06522251954001766, 0.03413303980543729, 0.09578127654329424, 0.04417426914217011, 0.04827667380713167, 0.024971654788861354, 0.06487129887025203, 0.02714237066796951, 0.04319929968445532, 0.04926292390953149, 0.05619410440445908, 0.032491830493053125, 0.04637315598947387, 0.04642330793543689, 0.013012940894001195, 0.054352252834266236, 0.021441081133220467, 0.03968186443671584, 0.027182569216576316, 0.015846182058955875, 0.048207656946033246, 0.024319618204308134, 0.10224790898181739, 0.05966912519427077, 0.051526231090387994, 0.0403339431561049, 0.016112437832259362, 0.08577688837484007, 0.007009410520925397, 0.0403886916296136, 0.019392366671273788, 0.017731511034071445, 0.02489039392751311, 0.07756934411102727, 0.0018577756653089198, 0.02332526097644962, 0.03366926549783638, 0.025240532498085694, 0.06808400349391085, 0.06715686090530888, 0.05262315025432937, 0.04003260630152879, 0.008008615170124798, 0.034124386842332544, 0.07384709908717102, 0.01961799105629325, 0.045523598955403415, 0.02440356994949041, 0.03489373064029121, 0.07683349367711814, 0.02805832071199773, 0.0593294762826014, 0.05905156639674979, 0.01339337536914935, 0.02606024274662618, 0.06016650777910987, 0.07675377456771751, 0.06612751452672867, 0.01381150903105135, 0.04669585137537891, 0.0631454061987179, 0.029993908885385723, 0.03539311271461268, 0.01330883373626538, 0.052151400971436696, 0.00731647436154045, 0.04599710641008231, 0.056630042907331264, 0.012397017694198558, 0.0615154124135452, 0.0349804403020009, 0.07438963489426721, 0.15198036818014038, 0.010173902358679522, 0.013892894381687287, 0.03248675899099439, 0.05676480926453106, 0.08307124968738326, 0.02941082021401775, 0.06395898774386415, 0.034729726537461245, 0.11757682272863966, 0.027259292922193007, 0.0442552522966458, 0.013799346427643492, 0.08192277663657743, 0.04238566068271476, 0.03450079648304851, 0.07363049538745996, 0.03825373098915143, 0.0258656315160014, 0.04231068748800505, 0.06599757835389146, 0.05499633742616542, 0.03594348560117426, 0.06840717002388931, 0.03316061759007073, 0.059842341504390203, 0.03270363848235819, 0.033429280794676275, 0.06652867646827813, 0.0059121265076100835, 0.012009387738221597, 0.04781598300342599, 0.06775333696315367, 0.05423505287317019, 0.07499173403747621, 0.03832719116021068, 0.043588215710535165, 0.02133709810403807, 0.0157381234420163, 0.05842743456483849, 0.06575609211839976, 0.03060674858129313, 0.024756891615388375, 0.06085438961764017, 0.029208806658824606, 0.030815430931867133, 0.012094586291500639, 0.05766767835725219, 0.09394322476920583, 0.08053958190665131, 0.02420756443884344, 0.07214397837918612, 0.036135386795766895, 0.036466290813780604, 0.0421667127539554, 0.05259724499116983, 0.06608633730079859, 0.0566484481697121, 0.024597349974717346, 0.029698534110080332, 0.05587622005071852, 0.021214750032090855, 0.08803907706732712, 0.022846275993112116, 0.03457032662305621, 0.03672244380258265, 0.0612457724468362, 0.014229551720012341, 0.028009928853040742, 0.035788417913981026, 0.045381918654686985, 0.03478267087390827, 0.07060390416412585, 0.12220889675400912, 0.03949069868653052, 0.029275111568671082, 0.04820426317652868, 0.016177013298616778, 0.03670499615010716, 0.08457865025247298, 0.03896004873357954, 0.02957689658468289, 0.032407763834682204, 0.011035466863353167, 0.06299532574391173, 0.025464392965659503, 0.05763166456393177, 0.0069233869867128955, 0.037635352477551474, 0.04174832532542848, 0.03647854822056909, 0.04454470712751631, 0.040148277917215903, 0.08009151240149814, 0.032464105771073413, 0.03378382245559366, 0.044687084568243836, 0.028785156206257885, 0.032460022522437, 0.026576932662376956, 0.050349688578036525, 0.09103123263846483, 0.05205814891885366, 0.018120189572894768, 0.029136261962834867, 0.06500036936373481, 0.0575716071011078, 0.042129714537652276, 0.021145396092305743, 0.020532772816236944, 0.05129261257787866, 0.04651600840471445, 0.051607271701458006, 0.03160092386326963, 0.004941379630772938, 0.07556600886727534, 0.09306959342211486, 0.0890100015808017, 0.0228263174874648, 0.034579435408475905, 0.03321693271338459, 0.04354241514398206, 0.051064647794250524, 0.006616331764586991, 0.030648573151519223, 0.02561754543304203, 0.04772336297338048, 0.0811028097485823, 0.0658117943713742, 0.03383322363539088, 0.04268793216455848, 0.013952286305627035, 0.0365142364265217, 0.003064612406418629, 0.0372797038195835, 0.04900024002117496, 0.01642755086293384, 0.014437125158315946, 0.026867302968316985, 0.020747143369648727, 0.046286450158203804, 0.04553195314421769, 0.0029324957558269343, 0.053301076780283646, 0.054405557232037674, 0.019544138265172803, 0.07236645031239718, 0.04750491683221152, 0.02084170926302191, 0.022255365564037236, 0.042112665250897414, 0.04650164425613419, 0.04440884143414517, 0.05267234459038704, 0.020184848239765536, 0.07912796531473437, 0.019920174438025684, 0.040543724842850244, 0.05826921825627646, 0.042174591968256625, 0.03410343050716385, 0.02065985914199583, 0.019385642334518415, 0.015097321536872658, 0.14571124086937598, 0.011636689793498767, 0.07288954280797513, 0.006596336869763271, 0.022824678059306838, 0.03249656491642518, 0.03259556645887994, 0.09735164187488057, 0.00826354050302818, 0.017076272201994737, 0.03058491890589076, 0.004671450944677477, 0.02630005508000332, 0.05990131878324094, 0.04926858529929192, 0.04173154416944712, 0.055956184308254914, 0.05478756697548013, 0.07447211958107448, 0.10333151736807439, 0.02619033596748787, 0.045279619103718194, 0.065933387846716, 0.03447951839095162, 0.08228688290522945, 0.05395637306895468, 0.008289884351524375, 0.024302404208649552, 0.05310887298096092, 0.0275656572287722, 0.02693494470159133, 0.0578438785798367, 0.03998751053586602, 0.029487731611175887, 0.0454821459378206, 0.08374676303637606, 0.02829684793288189, 0.007217852032608203, 0.031919187430532715, 0.042329422168193326, 0.0362877999883025, 0.014433333023090758, 0.030548907027790145, 0.0351407825045528, 0.08262875730231886, 0.02827860354896515, 0.06275177873190373, 0.029796022628884644, 0.006904501482964524, 0.06408550716455906, 0.019027915663055835, 0.04947951994836331, 0.056249094195663936, 0.1033818110403034, 0.026555181510986823, 0.0742520378421872, 0.03086278282646691, 0.07067133522322101, 0.03913414987525152, 0.013708565008616256, 0.10794391825554833, 0.0268132918544354, 0.03146633945195185, 0.03142475619942191, 0.054175443571781924, 0.06337756531373148, 0.030196973896254937, 0.10090658095695319, 0.0688007093905922, 0.032802919646905314, 0.003819871677889399, 0.026802051429366393, 0.032938287383125674, 0.01300711288011723, 0.022954129681531942, 0.02786217539030458, 0.07487486732462723, 0.053552571954506065, 0.0528538154978906, 0.016472039503916618, 0.018472272091575207, 0.05722006467441398, 0.028348991707448038, 0.10390131058351648, 0.06890098263900127, 0.08503516970743095, 0.029863193218085556, 0.01175842020705703, 0.0510542979463935, 0.03148871879543989, 0.02125095534739235, 0.016937483883192463, 0.06030316254304302, 0.0895726548567895, 0.04603302827285183, 0.021992520797216607, 0.02534611665102984, 0.02622473714572768, 0.041718620266164505, 0.05953161624230205, 0.08850338763647503, 0.18441429391743677, 0.08661788437635669, 0.17175594735289776, 0.12200089622168772, 0.21505428688420405, 0.15313840200824125, 0.14531269128764832, 0.17394829180932816, 0.11167693447561995, 0.18589172512292865, 0.19153417718987312, 0.15954778469618291, 0.23031094321800819, 0.21230718751828517, 0.09173060196541971, 0.16162265723030414, 0.11584272142499687, 0.17293555421694634, 0.15986371935615618, 0.170253373141731, 0.11461909514881911, 0.1106834639945338, 0.14159128129962953, 0.14508173110023623, 0.10046713760182743, 0.13121370105974137, 0.23849584192277926, 0.18580883440952148, 0.17308342450809094, 0.0909095089281759, 0.10056836846014185, 0.17711670889008432, 0.09925195361457526, 0.15010590424701092, 0.10040406558302142, 0.09778485693518194, 0.14290763485816219, 0.17240329164891474, 0.27189765846537006, 0.11296593103437655, 0.12446590669212804, 0.09973343221410629, 0.13353689333363888, 0.12730615468876016, 0.18854677136386597, 0.09272501473465274, 0.10923892860451054, 0.1444699639274228, 0.17965792978723205, 0.12889093779508146, 0.0937035771447324, 0.26754140673625854, 0.10845787898306886, 0.12715600911648045, 0.18002133125499373, 0.15028124645112023, 0.09600168769998897, 0.13530690883917196, 0.136850131675601, 0.13662784360349178, 0.12318328398490146, 0.1376977773203004, 0.14787957613025943, 0.14092859992336843, 0.1542461651467508, 0.11637074752680718, 0.19267475953505886, 0.12146847277519204, 0.12937934949032723, 0.13160428332705654, 0.1510136111849739, 0.14218516798029024, 0.1514901638391518, 0.1302891861527197, 0.12640852946788073, 0.29242342157709983, 0.14503152169767888, 0.1460474768593427, 0.08804930434111627, 0.08752102543029093, 0.1434249587116703, 0.12687025065984459, 0.23584925329252598, 0.1829254633236316, 0.1235092543966828, 0.1416544682316242, 0.17322570235738832, 0.20654890295718947, 0.16081455704425612, 0.08616305031483212, 0.10539470706135036, 0.18928793078709036, 0.15439377496800116, 0.18345562681075067, 0.1675679591754752, 0.1140476701660983, 0.2083799756702877, 0.11554606153719849, 0.08921957259336788, 0.0936703212679394, 0.24667010732716133, 0.17623134107599336, 0.1506009042984055, 0.11555452680876178, 0.1922221088241185, 0.13267046321303616, 0.2144943991856229, 0.1646527801189692, 0.17890409926974005, 0.22388433887352868, 0.1911695499814326, 0.12735986511313147, 0.1623362681317714, 0.0930884468459314, 0.08874156437213383, 0.13617385989956318, 0.1240318719177477, 0.06445815531356681, 0.2059623094335679, 0.15565832566109397, 0.12667990845417784, 0.14562459632513985, 0.15932702879992225, 0.18865501958756678, 0.24206738979105027, 0.1504198011131056, 0.14661075066654913, 0.17049225467828014, 0.16180754488995, 0.07814109085067626, 0.1400282014642031, 0.09026505278363343, 0.15257609347181936, 0.08118088176894574, 0.20622599689710527, 0.32974054496134486, 0.24027315058535148, 0.22174203528031228, 0.18222378807202463, 0.0983610163412748, 0.2516647707670927, 0.19460252786595977, 0.20267485761113707, 0.17387398128067294, 0.13573394156992435, 0.11741790544962692, 0.17472535011268434, 0.16849420544120575, 0.16060403608266385, 0.19857942817672608, 0.29119434075490125, 0.3473621913261952, 0.1633444398401245, 0.14762787028185784, 0.09413636319579617, 0.10657386959440286, 0.11900146281526935, 0.1291135476241189, 0.17699787333126993, 0.18346449810891383, 0.15499458708349736, 0.1421407961677159, 0.18722205212520016, 0.09859827377142445, 0.12849975797918536, 0.15076975007691693, 0.1420287021826352, 0.10342351686690124, 0.27789416572740006, 0.14013067338495486, 0.06987476466043342, 0.1279849851984651, 0.10146400185241815, 0.1310034099245264, 0.08282829256307694], [0.05028829429178469, 0.10065171116542432, 0.043744876860610904, 0.020057834692359455, 0.01993759336220401, 0.02994872118917204, 0.04104113424076669, 0.12047953753461761, 0.05536994318507853, 0.011415389974811866, 0.05050546489655972, 0.007269663037732244, 0.0616402464408067, 0.06058121798560024, 0.015135492825309838, 0.013294854546867073, 0.05465735501099018, 0.04662960009168714, 0.0357017005913921, 0.07219535223538838, 0.043558836238639015, 0.08194395896768378, 0.03764621943475739, 0.03965749517984448, 0.021958083229800387, 0.011523852703131495, 0.055890159020500804, 0.050809942711625374, 0.0638356131140984, 0.007899233136296032, 0.07227988237695349, 0.022801004027226762, 0.03036455371447148, 0.03287208206470936, 0.027266904005720734, 0.03342537374626244, 0.05123032962963466, 0.061560523500966455, 0.03485820714324232, 0.10135294208603521, 0.08009473763165936, 0.07221217552620558, 0.07425535500289933, 0.06218382029704029, 0.07545763040862738, 0.014595080996983716, 0.031209353342532154, 0.050061053461244995, 0.013220065213259191, 0.04441050384494086, 0.029925650451332334, 0.0038147939513662773, 0.031879257012699405, 0.05108119146297536, 0.12205239265195786, 0.06133295325261932, 0.08048218659936421, 0.056113887337907675, 0.03697729827235303, 0.05212646097906175, 0.03295915178774345, 0.05593742664542891, 0.025456149859594244, 0.03591995521057998, 0.06486247353736432, 0.07901867521145652, 0.03675026428555289, 0.04470812134264458, 0.041791099844680685, 0.04917180158137795, 0.09543714984770744, 0.0076416676728836, 0.09101162844848248, 0.021289855376967502, 0.0504518234201016, 0.014185358980490316, 0.010508334211584543, 0.009110025524522268, 0.07997802413639524, 0.05110124764483302, 0.020109359850926746, 0.05681263996408351, 0.027797892952578205, 0.058282057889887405, 0.01695705742965783, 0.039256260459942204, 0.05069615950267162, 0.05326721186359083, 0.036199470050632954, 0.009880441845574928, 0.015618019050077326, 0.046454514527032455, 0.043094119642891233, 0.08451832082843588, 0.007659467725804257, 0.04225051128155282, 0.010535078341021173, 0.011178766482419545, 0.04268381061152585, 0.04719904090668406, 0.03945673417840754, 0.0340335862711072, 0.007134212947060024, 0.0507290514877006, 0.02178775890159511, 0.004686156959993946, 0.0418528120574211, 0.049223125641865116, 0.033174303750838005, 0.04278972226705763, 0.03837446644601803, 0.062334322100204814, 0.014103503443390853, 0.07741390487119075, 0.06865694533072172, 0.032146991335696755, 0.0302280904725194, 0.028697151855956164, 0.061369541611882954, 0.01967720582240051, 0.013889383783774271, 0.007334186793154767, 0.020856898871340582, 0.031347950139353355, 0.048403576271788734, 0.039141063818768154, 0.03498237084357008, 0.059966819300766916, 0.0382927248644973, 0.05034300446089718, 0.11123927610535776, 0.008554099458119562, 0.04066601928864275, 0.08343375483227354, 0.019813102159288623, 0.06903084220304605, 0.049720837644511656, 0.05622663632816365, 0.04886576477738638, 0.04604252010223366, 0.03837654254429283, 0.01893828146069521, 0.04270241122632738, 0.06651671783578011, 0.04959386623194141, 0.07731381548388351, 0.060660400833453865, 0.04723376001141245, 0.03440831434882937, 0.02637930304533051, 0.016578828330121694, 0.05620684827707949, 0.1030523932328628, 0.058630612573676535, 0.015650446594302213, 0.020635307939242453, 0.03444606716173791, 0.032983567009890274, 0.06437665888018186, 0.0718931611927767, 0.030654751650628545, 0.01955068257126597, 0.049688167824980714, 0.17618149939563968, 0.03730343722347771, 0.020797588344242786, 0.03663839629640983, 0.0591323388770463, 0.029991668078207204, 0.07377411389062483, 0.02550727090678148, 0.03146522862446164, 0.04075798814395263, 0.05957427967880523, 0.04120040775066422, 0.02929228534471364, 0.09055896241578365, 0.10032336588107771, 0.05519463162448618, 0.05156044457708636, 0.09104057891114105, 0.06364553903920517, 0.011173965026354118, 0.025828005107600364, 0.049587584310962315, 0.024445586041697574, 0.08130011569348075, 0.06831206786896914, 0.05019025035923527, 0.01491989748882911, 0.08693804784167199, 0.02289750620782856, 0.03456722779740249, 0.0316613030830218, 0.032331691303801154, 0.03492904346316092, 0.06700356671166036, 0.028942185078537273, 0.024234253026905562, 0.03003001077881744, 0.05439745968267803, 0.02288411882135176, 0.027257073182432402, 0.043281803523460706, 0.019086714826464173, 0.043773252757326256, 0.0999941779000144, 0.0033257803982949907, 0.04416649718017828, 0.04423651761645752, 0.009990544002052518, 0.04260038363657171, 0.05191466448107555, 0.08803341567756669, 0.05257160785878378, 0.052418355799971096, 0.06262670338694608, 0.06690825771300063, 0.08138609374122274, 0.0560731046472586, 0.020847782425041643, 0.03940699591992363, 0.04143945016567746, 0.06128167132696798, 0.03806676723123078, 0.013254478840427774, 0.035999061449641184, 0.035112755177843, 0.014803057589057474, 0.03537218702296096, 0.02316348235903969, 0.008279497156881036, 0.06459473346870753, 0.08769710307880756, 0.02946105834487225, 0.048360568095719626, 0.044721554694396835, 0.07794494935942274, 0.021934524110908953, 0.03749091426030763, 0.016819789795385256, 0.029740490830473365, 0.03460133786223108, 0.04038725521475558, 0.04736084633717134, 0.016074018522856698, 0.022235094877560774, 0.03898509597826389, 0.015989271003843075, 0.035688282561398325, 0.06108155000894781, 0.01956805553016884, 0.05140399027075018, 0.04467522169673636, 0.037611684191130826, 0.053732162116155516, 0.03458037769662277, 0.04126162966713309, 0.06173244895293348, 0.01278588105173361, 0.06677328068162165, 0.036036802771230864, 0.049519509738010746, 0.055928156981545116, 0.06721339819412078, 0.07634204827369222, 0.037096156813805146, 0.014521159257950082, 0.02535401501752917, 0.014671919615789047, 0.018716719256894245, 0.0370415079317266, 0.02498469552055242, 0.05921166728160555, 0.018219072371721268, 0.010272885706546086, 0.03959725768635831, 0.024444714616683703, 0.06975961398453483, 0.03468132510240521, 0.08710049678601565, 0.09040077292029897, 0.019832378846683332, 0.07660942828102459, 0.0564002126996075, 0.049815882342837514, 0.006569246085540902, 0.025848934629691706, 0.04006256033936816, 0.02260092675926224, 0.014819816720011014, 0.04977508816086958, 0.021610200788164814, 0.06995269112409123, 0.029019284167236863, 0.011236678899055528, 0.043790612309690446, 0.010335297932127311, 0.019319959871110418, 0.08270171951622733, 0.05475217371337837, 0.023460571256075657, 0.029056960371352976, 0.0220725386809077, 0.0006437679222736118, 0.05226429551839829, 0.013017123734067767, 0.04523939948769347, 0.021490878763518507, 0.04846367203900891, 0.02893872619155915, 0.032300270207586794, 0.04976407181651843, 0.05815093811120718, 0.03606149761547004, 0.035544564466803305, 0.04412536208908405, 0.006779428053226683, 0.0544324430877403, 0.07631087615605324, 0.012788203255754086, 0.03928096296506063, 0.04997948807994685, 0.010156984264481693, 0.04901083884760738, 0.028582592982979074, 0.014454358306172636, 0.028140242324180664, 0.016018673458376962, 0.02711860279011871, 0.02993771442091994, 0.04609865519488531, 0.04510417730817872, 0.00854913233554051, 0.0738691087932356, 0.04092409515813474, 0.0009833665594229505, 0.006572472752116982, 0.0594713289531008, 0.053360839299256765, 0.021384892414414117, 0.050267031521446286, 0.021681801280787876, 0.0596739094133579, 0.0052498564248033355, 0.07967443881376136, 0.11085690630059089, 0.025203618551454237, 0.001691287881488191, 0.02416959137565667, 0.07600575099669157, 0.0283071230871663, 0.1522627175455132, 0.18442773109962865, 0.13574702635167107, 0.24371849312897653, 0.2502480596904793, 0.1367882777365946, 0.10030124126182449, 0.20928193694881855, 0.17188339373998104, 0.14078236906038177, 0.13994820656314974, 0.13319782281835235, 0.14596296203953607, 0.22632852707418705, 0.19546068423698026, 0.08266398202507727, 0.1725969127108974, 0.10093628218577755, 0.11688294625210187, 0.12883184177260246, 0.1266162388867909, 0.13155439568142738, 0.1707043844245134, 0.14950503084448077, 0.16904819426276993, 0.10069093486714749, 0.129568588529383, 0.15212563377234245, 0.16739298469356953, 0.12018018101732578, 0.14588710401327382, 0.1448622009446544, 0.09168470563787608, 0.0660453362750911, 0.16928595731094961, 0.12748112917066584, 0.19264839078870513, 0.20506503661313366, 0.1882666130099566, 0.26613811752007854, 0.16503432254877784, 0.1957249079620646, 0.14385104149339661, 0.20153056740039782, 0.12524368511813302, 0.07344472672670119, 0.07239211425786057, 0.0947094199457957, 0.09856364659724698, 0.11617554832370051, 0.08460857364679537, 0.04939713868342581, 0.09526499456936315, 0.140365295472645, 0.2116947615098569, 0.12660874654689144, 0.17154918022213445, 0.1545103122630427, 0.22270202005822815, 0.13548038178874602, 0.09714802336548606, 0.16859250984364943, 0.11284148771195643, 0.20753550162959486, 0.16799891427639993, 0.16193934265644322, 0.09905674675058934, 0.11768196063536791, 0.1206227653329411, 0.10465086633039099, 0.1834063826789779, 0.1038552457166295, 0.21158888815872132, 0.11370176614652719, 0.11840599799348463, 0.12608558510340032, 0.19537168014193737, 0.16868157522572627, 0.17995370101303826, 0.11205393400403763, 0.22522647895159262, 0.19210102096680673, 0.1339607391386263, 0.14361455015117122, 0.18719798164261928, 0.17557598350028839, 0.13398090257279335, 0.11890416198800649, 0.12104998958567459, 0.17796171919232417, 0.2133173663769999, 0.1816283538937569, 0.20142469404926225, 0.08340016187679383, 0.19426737972084554, 0.11605969284691157, 0.13286647446934255, 0.15994186032443278, 0.2355574044368921, 0.12105339101605839, 0.124798932773692, 0.13479762890886876, 0.1281422630493199, 0.19243808433173165, 0.1846511683036243, 0.2096839339262055, 0.09010831119432565, 0.25455100702181943, 0.1269728604764227, 0.16034327507499727, 0.10396265124361362, 0.12365347810930784, 0.078246244079163, 0.20656874463442834, 0.20530543500377288, 0.1469833451894022, 0.1236457559430311, 0.12183094727656535, 0.1514683303333098, 0.1502636264288618, 0.09320706023924774, 0.07390215782628906, 0.18371228158714312, 0.14899241077082773, 0.1453239834236522, 0.19178402910549797, 0.11323112769112473, 0.11228410512088768, 0.17112626904441466, 0.11091601764482838, 0.17867700016546637, 0.07619165755327671, 0.12767146371545332, 0.2422086564042876, 0.11418317579814505, 0.1420643712363897, 0.1611076009970519, 0.13023804212289472, 0.1571172788258522, 0.14672307447800714, 0.09034703951328994, 0.08755202134770733, 0.16968561005928826, 0.27014252038732656, 0.16356231524578987, 0.13696706733636319, 0.12538361107750287, 0.14917432600932737, 0.14755055668853945, 0.1234042160813847, 0.12089173880315597, 0.13334920179219018, 0.1516641117632389, 0.14968372851369843, 0.12448060791939498, 0.10479218656978301, 0.11744785948746628, 0.15548138999410216, 0.2116472640585515, 0.13076524851062607, 0.1468593155544612, 0.16442902115804536, 0.0830993191489289, 0.28299220507183387, 0.15658711533873312, 0.14833719109094914, 0.1036600235308851, 0.12799745710987237, 0.1301135988004746, 0.2504036368261422, 0.15485301403509033, 0.12479550836067047, 0.12595949469194298, 0.17143866437817776, 0.2110933058805043, 0.13835600006484217], [0.0670584109461596, 0.032584239848919457, 0.013029506587753854, 0.009422293496167949, 0.05238699599079067, 0.03386590877668031, 0.0195193495751629, 0.03160163632503921, 0.04297883107116626, 0.030029110625506412, 0.01311741326184523, 0.02777629693399274, 0.015778465632108912, 0.04020250928137572, 0.059746852475068266, 0.01530375254655918, 0.017101361581514922, 0.03942818208146961, 0.02167295871092187, 0.05124989168478116, 0.08230472509298595, 0.012896535749126588, 0.04399893842937966, 0.05185721554763375, 0.022069981862460415, 0.04709836163167511, 0.036092999150916454, 0.007479705673176796, 0.05172698443094569, 0.020973079935497334, 0.05165781818270203, 0.056202339849645094, 0.0667404844575832, 0.050139845604257244, 0.025281809315445925, 0.034837760256543275, 0.01536526174599966, 0.056519894785578215, 0.07993519216054872, 0.07405313077352702, 0.02315826146983572, 0.020453210754860795, 0.06705368418366679, 0.01388085914039684, 0.012374858600988746, 0.03061687817887193, 0.027827808686021357, 0.06992223912910109, 0.013312449671267984, 0.07057742050458347, 0.017059883666074565, 0.022418371837345824, 0.029906038600470752, 0.09412854143808927, 0.035807068324497635, 0.062144558290920915, 0.05063555045654217, 0.030413347769588716, 0.043296148519842856, 0.045651941665358124, 0.017511837237003832, 0.0902002570669978, 0.001767063912402298, 0.02797886207249136, 0.03598583111118886, 0.0703747213006981, 0.025554176555165363, 0.03537131368272728, 0.018816398787161997, 0.03788182211499061, 0.08204337419761766, 0.02441523172291777, 0.016176660898171605, 0.015343788301482078, 0.04299386554668027, 0.022704465457448558, 0.020167096067340146, 0.05118508830726628, 0.04736114128102218, 0.026209005530202584, 0.04470608737920562, 0.048028246815046, 0.018665967847130472, 0.05941977506623634, 0.10332781716340012, 0.05182870941597128, 0.014531280237039732, 0.037098531686370416, 0.030751387896617095, 0.0382617442688394, 0.041663423631220095, 0.04448740758121975, 0.043798525997948264, 0.028527511261223305, 0.06463591835551685, 0.07303649379361062, 0.010840285854834703, 0.043505190931741274, 0.03135192039002094, 0.009096312550677648, 0.036722876642259865, 0.055262464879741596, 0.03025969159939597, 0.07976519725015087, 0.06230999880860891, 0.04581287758605135, 0.033302439617053155, 0.06939724673547092, 0.02574099858682002, 0.020985844875535658, 0.021902302452813716, 0.028326834529458035, 0.030096560836799686, 0.027303316164761785, 0.06676816321428745, 0.03833030530762288, 0.04815188957558525, 0.05890979416548245, 0.015533566474914553, 0.021930293390347112, 0.018081346999913938, 0.04861092945981411, 0.018287685121439638, 0.009400402533731634, 0.038665545383288015, 0.07365810519625103, 0.02160832961840976, 0.03745042651350941, 0.034414213225846334, 0.05101787429603358, 0.0626363177903958, 0.005048207718984134, 0.02929370260737356, 0.02172277932385764, 0.025212168092689207, 0.04753271816298366, 0.018366226370656685, 0.0801911038316546, 0.02131968301029936, 0.023031874199307734, 0.028629739949059103, 0.024878523395126386, 0.02877894323319197, 0.06988146026889164, 0.016396455354087295, 0.03871295856492173, 0.0913356070316607, 0.04222146505790372, 0.03297243575235048, 0.008157992739260437, 0.06577779538929462, 0.07251279608857247, 0.007812109308302283, 0.051635187945418784, 0.038363710571561134, 0.02976820789157383, 0.026996861842851487, 0.03971908864895663, 0.021986755985586394, 0.018286792629007852, 0.012076214545466488, 0.03051461310185973, 0.03846156298212948, 0.030301175260495757, 0.026042854465964823, 0.0023783795721453406, 0.03689928753902355, 0.06472785656730976, 0.03352965746495513, 0.03205573111171684, 0.06694640123075055, 0.032883554231375456, 0.01856005810681851, 0.004888360121948344, 0.042512854260783044, 0.015392964442951546, 0.03832585433678281, 0.08123946451251546, 0.03588911251074845, 0.027605694898914908, 0.02626463500482421, 0.048417599511242686, 0.05856015163684084, 0.03605923765609342, 0.0449493624300005, 0.03762154757315594, 0.06358242871600293, 0.07388408581215529, 0.03901732529723837, 0.016362916024762298, 0.04762765560900012, 0.059100511754232074, 0.03731392113672149, 0.021183428527306647, 0.06227897607811517, 0.05010467067721391, 0.038713965970542163, 0.05399788354313182, 0.06223877178384893, 0.02636119272680052, 0.05787175651940127, 0.017947505693882704, 0.038195707489766424, 0.04326819397148587, 0.03316411095100545, 0.03688921348281926, 0.024043223257326794, 0.07849548312444841, 0.020225523678105206, 0.03971608941473308, 0.028016724052929112, 0.04656754696982042, 0.0664624864716203, 0.031596185609457955, 0.07739965563579913, 0.07436949444273788, 0.014902731373665795, 0.013491242143866277, 0.03583800295488008, 0.05185786289192977, 0.04418899335207478, 0.01148421627153913, 0.008543136739923109, 0.045025936748471954, 0.06705699368349968, 0.027997209878277876, 0.046818578660848646, 0.03079010406509042, 0.028310878833215085, 0.12079956310410654, 0.06636218257969426, 0.11624362289665208, 0.02987051893386149, 0.022424600132170226, 0.09330998415187483, 0.02350706130176062, 0.035529319317110127, 0.007931233586503134, 0.028778389734666676, 0.0656934567697106, 0.05529885788658454, 0.025676064974358006, 0.05751996128369243, 0.0932233013032425, 0.03132276116840301, 0.0075639499681851565, 0.037390955107947516, 0.028453876805161277, 0.01639756235113788, 0.017763338156885678, 0.05112721419502651, 0.007619017325792342, 0.050854831633548585, 0.04522244596192914, 0.024466586426921913, 0.023889251075865283, 0.03202630950498485, 0.015951729822723616, 0.05414406461040339, 0.009262406158321088, 0.05927085906507508, 0.030657586175948385, 0.025910418931274645, 0.04634763377027647, 0.00886446082844369, 0.046910704564182996, 0.017715269970076702, 0.03183297189553419, 0.08022973764567606, 0.04903241571399474, 0.018884071163953315, 0.03900789475489048, 0.04165867005564994, 0.05727840993072718, 0.0762902147647354, 0.016633337401154063, 0.018082706805979534, 0.014472439896405466, 0.03258791324051638, 0.09507937146530998, 0.06588536179474284, 0.03931368641074627, 0.0641454343924359, 0.045096029963103995, 0.03171730219506689, 0.03174838621259457, 0.07499442300609044, 0.018199090883436225, 0.056958740592123046, 0.026636674113932158, 0.0352490613717706, 0.022738845568270456, 0.033008970485459414, 0.060231364782779455, 0.011339717724871252, 0.03157002945250321, 0.034643491850264614, 0.0035282121896142923, 0.019539790716202512, 0.046946063352328156, 0.04774880475334583, 0.0421315799617479, 0.047364366511183406, 0.0444274420489467, 0.0016001684261643659, 0.06202348575536763, 0.04775690996358472, 0.08039931886859479, 0.0077379567852814595, 0.05820406630875603, 0.07267277056892073, 0.028167434615053, 0.02055780473916281, 0.04797164440876053, 0.10021922388865102, 0.03894655409479334, 0.03278913389470789, 0.037976981726505106, 0.01982593604724013, 0.014249427871207797, 0.07581347058857642, 0.020674575691021258, 0.04771223171584068, 0.07929586880509892, 0.04180021246054, 0.04361079232166371, 0.06041452491415605, 0.008785724226805952, 0.01574769092258066, 0.007645531150046737, 0.019426639529786283, 0.009413392512097715, 0.014524553027454645, 0.021619110390724196, 0.05051690641970885, 0.04041177002833255, 0.0696704643327863, 0.044678695905472965, 0.012277664068425375, 0.07186896047524868, 0.018682030795682824, 0.04604712812109821, 0.021540115234412013, 0.001810397077333032, 0.02520985259193807, 0.020764014540961193, 0.12132520667247235, 0.05691192878950989, 0.01186403021546862, 0.05565961635100746, 0.02024525618781486, 0.05087140977623002, 0.18873461612289955, 0.09545750480385558, 0.07735536043201724, 0.12251037533485121, 0.1469405361961934, 0.16041697273331304, 0.12439819984138013, 0.20695341270296805, 0.09290023436469418, 0.11381500926349433, 0.19778508692979815, 0.28737410542465025, 0.21617927167925144, 0.13363745003457994, 0.16964048748054814, 0.11683285176273316, 0.1159425043771344, 0.2215748442517173, 0.19488991808987435, 0.10794012612032314, 0.16390818862184403, 0.10535116262373426, 0.21216435808568232, 0.07559757935063494, 0.13704755253368808, 0.10269308267461677, 0.08660500643834954, 0.1409456683623214, 0.1235179877990196, 0.12590723217374858, 0.11603157742009049, 0.15458476068752428, 0.09607167749275124, 0.2017032742620476, 0.16983200946161825, 0.08243260048930684, 0.22464366990231702, 0.1077841429580604, 0.16319479222499556, 0.1149728515696141, 0.1489067314973762, 0.17380134082369267, 0.19543906523575708, 0.08608706971450199, 0.12009911359317842, 0.12144708360034613, 0.09901982131263903, 0.11702116383540055, 0.15714177831767068, 0.15281666040180192, 0.13569516219919728, 0.11259184264007116, 0.08111972496995042, 0.40594275920621814, 0.12943173458258952, 0.2042455983258063, 0.0833428278565407, 0.21534959845725568, 0.12943274581864958, 0.1779035424753543, 0.1356364645424389, 0.10404040916792809, 0.11349565785137877, 0.16419256045933694, 0.12739197185803808, 0.16986321988365344, 0.12142412394525544, 0.16934991033086855, 0.08344952092175523, 0.11219562196563329, 0.17237879215709626, 0.12139692782394348, 0.14668708366732444, 0.16134836710989475, 0.12831616500813153, 0.090156911812242, 0.16189533856607255, 0.1667423768629951, 0.18801530552727563, 0.09426999957330766, 0.1578612727743964, 0.10573512589138363, 0.12708716079472535, 0.10101846043741512, 0.19709654242521335, 0.10189720159096104, 0.1158229333739127, 0.12343973191755435, 0.1690401350178065, 0.16046581849936517, 0.18110595853819003, 0.13965775198753805, 0.15896621670934463, 0.18453688330708012, 0.10263345039059078, 0.16922425658952805, 0.12233667255889986, 0.17394818455701874, 0.17837500830571498, 0.08587865549470149, 0.20028409638231803, 0.19291420797667197, 0.14541940733550057, 0.1856465769871589, 0.1848090590248185, 0.09971950473564287, 0.1815020413168015, 0.11874073245111974, 0.15977430157363415, 0.10714347894874313, 0.2313265613009853, 0.1673245730419313, 0.14161168988193237, 0.1270842343388546, 0.11593243798180936, 0.17198791877636987, 0.20284673709782863, 0.18342574938170372, 0.07931226308667853, 0.12794738560314142, 0.1172725249442362, 0.07623574591331905, 0.037801022821616743, 0.17950002374427934, 0.24615583250359183, 0.1357318884542873, 0.10514660182619288, 0.1298128480031606, 0.09911995666522173, 0.1402076192560696, 0.09093049973730119, 0.20043716074958925, 0.10579092773578821, 0.18103249070625152, 0.14065668467552433, 0.09716169803493446, 0.10700228128341899, 0.12683867251560574, 0.1658859212071665, 0.094490020025161, 0.20091886151461832, 0.1447414808095463, 0.1611978921198076, 0.19118110258733073, 0.15103365204507305, 0.09991645061921689, 0.12056867952548689, 0.1693597622215748, 0.14639243092988768, 0.18342639289556012, 0.16174444988850625, 0.12631946408580388, 0.09712908567199785, 0.13914628104577142, 0.18030571841424514, 0.11603042828820406, 0.08180475313096278, 0.15392145111916528, 0.18250880342337394, 0.15600468933341965, 0.1945535135605643, 0.14911391231561863, 0.1172449611007206, 0.10452477591893367, 0.1387678029676599, 0.062199241646956054, 0.1066745488694118, 0.15316061855804536, 0.10006462734553123, 0.14295770636489316, 0.38374977426663526, 0.16185410771398775, 0.12713877213818411, 0.1758948752596494, 0.11362680444313634, 0.059012813839100065], [0.037238327410793116, 0.01368018049341176, 0.03077581652530259, 0.02034727994713091, 0.07094928724390846, 0.02314220043650318, 0.0270860995947113, 0.017793642679950403, 0.07235341915680517, 0.11231213627803711, 0.03025848501091523, 0.05305742251596624, 0.004830259056161008, 0.021500175240479653, 0.03507236702247493, 0.015313279807507513, 0.012150882262616389, 0.017442803138927106, 0.015817910541720208, 0.03122095574414538, 0.017901517435788147, 0.03612065109454336, 0.029409747690923756, 0.02432255423627794, 0.017586230120110898, 0.0193048334650455, 0.07035431271839528, 0.03706394281658915, 0.044709473487830935, 0.03925244917251891, 0.045187554487417785, 0.043185395188629634, 0.01295794535713691, 0.042311694893625476, 0.039859029930084944, 0.07093646293205601, 0.05870599179498612, 0.017419192309100783, 0.038278471798666065, 0.06246980858005344, 0.030137780197565595, 0.028102357361105182, 0.04626609137161605, 0.034328924657236186, 0.017815715588268735, 0.057034311335413694, 0.08031047565201599, 0.031046054040592526, 0.03893608933374767, 0.016245017008435343, 0.05802213191805829, 0.022970573758826624, 0.03218396656936215, 0.03480239380751887, 0.04168593512487508, 0.033783102332944834, 0.06469882949585877, 0.02104187463109772, 0.027361027483317642, 0.05694360269473926, 0.03451166727069405, 0.07792472463822173, 0.03515949037166373, 0.011300684587519256, 0.05635404824129036, 0.018613914087895426, 0.038106799155714056, 0.0422730227752078, 0.02607445367762158, 0.015234345938229274, 0.04618032016761361, 0.041695641458875714, 0.005441990797407926, 0.0827996102311919, 0.01796967244797176, 0.059660311352701924, 0.014219590661776884, 0.037348678545846094, 0.03429474564449441, 0.012762915650983492, 0.10708875728831177, 0.025945787295518864, 0.06230511499809162, 0.0279001752665687, 0.02475045647682442, 0.00887602971371023, 0.017574225522337422, 0.11009416618053952, 0.013995270541448508, 0.09818212715007606, 0.06618625814876249, 0.0611867300505119, 0.02625564113259316, 0.0060698975275661204, 0.05377677907686561, 0.06604383474275952, 0.06251590792089701, 0.0380832725955594, 0.053968982876188336, 0.023254416995651783, 0.015888972857576466, 0.06298152850039544, 0.0304265532101835, 0.023123726226209153, 0.007956593969626533, 0.06928073242306709, 0.008735309895728866, 0.05331346059157964, 0.041050258347944873, 0.04758805652419406, 0.03217653551649663, 0.02360544997387596, 0.06122611080025954, 0.011522023668212276, 0.06340948436709662, 0.06255381778183003, 0.021793155991021666, 0.06630573722143328, 0.1530014101656214, 0.02819819496043267, 0.023423155521853797, 0.09500064827021092, 0.04427816981690065, 0.07037796185261781, 0.04659020402018101, 0.02775761779517897, 0.032559131317201166, 0.02266276537651016, 0.07797491871902058, 0.07219466275625652, 0.05822847770046323, 0.019189661721728982, 0.040764503721748634, 0.06708776743541803, 0.027084291627209996, 0.03338868962600827, 0.038497209053246245, 0.013971585975659472, 0.021693189177782308, 0.03248235398542977, 0.020860735056621414, 0.02732554420588478, 0.05500826158470685, 0.015716150125128128, 0.053357663864810626, 0.018214740144509464, 0.034271464232475526, 0.05993037266776927, 0.05716677176796141, 0.04250097606751708, 0.06666465707483792, 0.012799202363126943, 0.0699054541426801, 0.04811923124737317, 0.046163531350753004, 0.02579297956770226, 0.019271196459510156, 0.047695174768206575, 0.04490442371236221, 0.023847506944871238, 0.030423858495909843, 0.04060423046710991, 0.08773337734202225, 0.045580051974543644, 0.027845993698123964, 0.05462089688667367, 0.05124556328800898, 0.05002720386631066, 0.06866781611836727, 0.0157182568669199, 0.04584146415694587, 0.019365942383545543, 0.02945450446268003, 0.03655309623648082, 0.04357464829339616, 0.09644991808360624, 0.04585577467937143, 0.020963534479960803, 0.007581492902846226, 0.04150053035588034, 0.020322460613604036, 0.02871467037156465, 0.02179138632791658, 0.014584440993325365, 0.02711169842270113, 0.015524337030646783, 0.025346470966694817, 0.04690495507431127, 0.040554216416973266, 0.022744528025448806, 0.0216004982846038, 0.0006153940604793119, 0.058698407524535735, 0.03958368260834006, 0.07401234425243831, 0.04129034647297475, 0.0722578190447342, 0.06395266368804921, 0.017955777528245124, 0.04484659173495827, 0.019785362115550428, 0.042199834565361666, 0.06520081626912279, 0.016951484140008688, 0.06807406733353293, 0.05259896868899946, 0.03559902948778003, 0.030919971290014447, 0.04934075844263838, 0.04477116271793362, 0.06199423268797898, 0.020241803046496167, 0.03487709121057584, 0.04090092482886488, 0.013239544913953832, 0.050739566044461344, 0.014619584319241827, 0.041460693783817754, 0.042980968456475005, 0.0625287360631891, 0.02588278805506566, 0.07563996699548538, 0.08219931139460496, 0.04618436511185381, 0.01942488135800006, 0.026299940166814674, 0.08346831305853783, 0.013903371591661728, 0.04590316487836742, 0.054968394369127295, 0.03450755337854067, 0.044212251781455936, 0.035501950826015205, 0.04664547726391785, 0.007474147226481188, 0.07198729041603304, 0.0039793647198577324, 0.05547958951924117, 0.03283726336855081, 0.020230058918616945, 0.00827189852228208, 0.012331010601032647, 0.06052174274959873, 0.07674062849893686, 0.031723764146708196, 0.02020922898795576, 0.05363180459807477, 0.05860812023221966, 0.059754505693431825, 0.05527833822153269, 0.07610943333636369, 0.019630405511106216, 0.014330735655441402, 0.06365024664949986, 0.04921600102416931, 0.02655375275700804, 0.05615480026350387, 0.05720558561264508, 0.0539051907347335, 0.03946150690617581, 0.046504543898927594, 0.04552891943603755, 0.0450523974253766, 0.015165494743644472, 0.018985303937487544, 0.010499227341384658, 0.02932380220191854, 0.06894185342976163, 0.06106661895530359, 0.01845403153809809, 0.047489108607893994, 0.008070184698989315, 0.031089226925565355, 0.052884087462218544, 0.022613427398966688, 0.036281135023361256, 0.03666943051822243, 0.0723358680824599, 0.05745392833505908, 0.030281615120569066, 0.08767086456740096, 0.018603610205313852, 0.07373793155796106, 0.09026643940277639, 0.04315544498122988, 0.03326525753964821, 0.040532321624097326, 0.04193386415980997, 0.06959786984108149, 0.022256510865484035, 0.010135661164719251, 0.03136337340448893, 0.02526319337888591, 0.04976107258229487, 0.050615206991712895, 0.04598573766528599, 0.02776699088093254, 0.09032409517995774, 0.02152756479899249, 0.07442085297718164, 0.04943912796255562, 0.01692633155823475, 0.01735892417209764, 0.0457629899404222, 0.050177759295629884, 0.018451752426523357, 0.06191989917668605, 0.07288370521799212, 0.04029477691097606, 0.031092436833968087, 0.02773877011702186, 0.07742056983613199, 0.017182492207916036, 0.0036709348487126976, 0.04123829462895951, 0.03708545073506333, 0.026921685634841843, 0.0823908563583128, 0.020534933184183413, 0.018625104717249354, 0.03453912003146064, 0.027618789256760673, 0.009905204680117389, 0.03402263504422961, 0.03986965940003434, 0.019142790547301693, 0.036749620771696495, 0.009043678479839959, 0.06637733579883653, 0.03784014693190975, 0.03193430426049858, 0.018679655923117554, 0.03617962071251485, 0.014136450012184441, 0.016662354896505995, 0.015517188472703341, 0.05556246108045021, 0.055093688049143365, 0.023775812606477452, 0.022874544637518066, 0.034666581740302425, 0.03014306237380351, 0.05316485485602772, 0.063370214700098, 0.030103683539275682, 0.0096462688769304, 0.1052112673078814, 0.060827982566890225, 0.040510890314415585, 0.05235717218789843, 0.02681777538401225, 0.042576339967068166, 0.12142106725443756, 0.09037992000700006, 0.16638061482339137, 0.13463800682896568, 0.12527541647995674, 0.12457370292395355, 0.14662636353844596, 0.09406376104321211, 0.2558391379012216, 0.1833641252690746, 0.18031046815937568, 0.18722235856036987, 0.07713999779474351, 0.1401357448870136, 0.10837288918874918, 0.13150175011927082, 0.0609726429496321, 0.16429005280858086, 0.22281985970274096, 0.11316333657070515, 0.20195634374695443, 0.1440508831893244, 0.1708187307080915, 0.15967867847892547, 0.0800468341537541, 0.09568736182465669, 0.24458578126805447, 0.13315892087355738, 0.17610957906130822, 0.14615528075204742, 0.13665853308573847, 0.08328758525632082, 0.1096929046475599, 0.13118337929969834, 0.1560126260043152, 0.1833302948263384, 0.10118618006667784, 0.08460743983666744, 0.09885636113223531, 0.12647007697171744, 0.0899551548965035, 0.18260313949036985, 0.17595495187467144, 0.11959678208034848, 0.0904402953963126, 0.19768177231232967, 0.2240450947635597, 0.08258435484622756, 0.13103016171484225, 0.12541768666837486, 0.19602564343762016, 0.10424781215166855, 0.14972877448364613, 0.12179953767166984, 0.13128572864638222, 0.2020422834903002, 0.10848252403159296, 0.22108905257717257, 0.1253481105630917, 0.19396711921980306, 0.11599991500617997, 0.14350720591122104, 0.08916324980917478, 0.13367457465539057, 0.1072799421906952, 0.13340328759964437, 0.14005073977093543, 0.17310228559278673, 0.11912959868148451, 0.17493881285190585, 0.14187147029705588, 0.17316790868438062, 0.13812510116446403, 0.10813079774379732, 0.135582608561362, 0.13499486590585402, 0.14687747183826663, 0.17914426783400197, 0.10934523096488369, 0.0920165442831574, 0.22979437013066586, 0.17259272987083082, 0.11490299201179897, 0.11758927165740922, 0.10438895619083798, 0.08596007531929402, 0.09948168806130848, 0.20002318215706658, 0.09934436680088121, 0.20600170167463444, 0.12666371335545856, 0.12103167242340504, 0.08830999640086967, 0.09627662133425476, 0.1499834987184694, 0.06370591059807809, 0.14959169071047537, 0.13212673996965732, 0.10336792186623621, 0.15508167595872957, 0.10531982196675194, 0.17293124880281188, 0.20596676806528724, 0.11236111227903636, 0.14377719061749597, 0.14748766086995602, 0.11761362559252209, 0.18757229220242272, 0.26427327565127806, 0.17429143791237187, 0.08303518992878738, 0.1335880680069808, 0.19074146004934467, 0.20180069000249912, 0.1594077744671414, 0.1740882713948527, 0.08123350434846456, 0.14657100602503748, 0.2434566136329405, 0.1390105609091059, 0.12889043217705143, 0.2274730471113036, 0.22654853220428192, 0.18328190871304084, 0.12919801647865004, 0.12001192512651605, 0.09223148557207278, 0.1505292444339683, 0.20346150733530524, 0.16580241762341993, 0.11130954935065202, 0.12085620764522784, 0.11612034402787687, 0.1193781559085173, 0.15965410237831457, 0.11843483354295455, 0.1968925791762529, 0.11554322701187865, 0.1143650757148862, 0.14329999444946168, 0.11037681432020281, 0.15597157901333225, 0.11902194034548537, 0.07918136930393596, 0.17807062625163989, 0.15622254941732655, 0.11072795072029676, 0.1464975228713405, 0.1310706877660367, 0.11278352549960537, 0.13324725081122693, 0.10022735208152764, 0.22158820482511676, 0.11663281088394505, 0.11330152351048686, 0.22214112112358694, 0.0659946518980207, 0.08982805324898613, 0.1244598316148885, 0.18129352750557085, 0.1975651737302542, 0.1254558148643663, 0.13403109665359222, 0.13772688866142305, 0.08741257802372979, 0.1819553968286322, 0.246488391271522, 0.1680500583062249, 0.1871132063529184, 0.1332186297663758, 0.1917753723119536, 0.19964525566226055, 0.10217306219161519, 0.08952173299246258, 0.09264071441946492, 0.212185456147117], [0.04335170521611168, 0.08757493503752255, 0.05655065321573808, 0.02718435803187951, 0.028737361895881837, 0.026756741159084826, 0.01805068433074461, 0.05217174443626597, 0.030880475627078168, 0.05417758861796991, 0.025920579172370416, 0.04175864452976854, 0.0260113337783203, 0.010348551253217363, 0.06920080646992692, 0.05268573197686384, 0.039774488297200976, 0.03330659181360276, 0.11388534379582252, 0.046600879455405864, 0.077159985028688, 0.024293201577459133, 0.03869539599925761, 0.01183942155612092, 0.011138589958840562, 0.04437759270771377, 0.05993785351634987, 0.015294816130922448, 0.013730816989986887, 0.036644475204089, 0.05198792929971411, 0.03759976769346864, 0.0752739914722981, 0.05738901387479517, 0.02567658782936633, 0.031399628515505505, 0.02469413943829075, 0.03908141621298367, 0.047138202034177325, 0.026856165965117758, 0.04184930337472789, 0.04067894319192537, 0.05924490400620046, 0.026685935482683203, 0.06316574583310755, 0.016957507506313346, 0.04959137261574788, 0.07314938451013259, 0.02460615807062676, 0.050690210829939575, 0.05869913913850343, 0.03551223172595905, 0.04014635503652596, 0.05906002017699423, 0.046225864094712084, 0.07109103649253808, 0.012845343838806355, 0.03614193684751949, 0.05561982574422033, 0.02934920184704806, 0.03147404821168992, 0.07029785969925505, 0.04563562399257095, 0.07242627411840424, 0.09522406249156884, 0.024136063537650534, 0.02917199996450255, 0.05820373689094859, 0.007523156743827126, 0.02023503849012477, 0.06880921296655171, 0.05025870797614898, 0.044551349109819824, 0.06263209664593301, 0.03933231383862515, 0.024351903064657125, 0.015952447072542723, 0.06916682280960583, 0.04007851795083092, 0.0204054260205838, 0.0488301876541828, 0.03962324721918952, 0.029938570524175322, 0.050566039468732574, 0.05807351343513978, 0.04001840303141264, 0.024519254971716194, 0.037825300147937196, 0.05588984492445185, 0.012627109329426482, 0.02109761518846837, 0.07112499717022143, 0.039593396603219935, 0.03085428499616683, 0.04455586902857308, 0.03222647678828047, 0.04181679826410067, 0.04016886269974132, 0.03763257923926558, 0.03223070942406212, 0.070254790236152, 0.040494859924600016, 0.03894442437036384, 0.10146252330272429, 0.02427308985422696, 0.025707987858162775, 0.05486938516579328, 0.0061441587393112, 0.056955902236363584, 0.05554992788200898, 0.014274860075074098, 0.04259702817146336, 0.05028016609890808, 0.09978924938026937, 0.024524828261365334, 0.06642906971636318, 0.06175466550273761, 0.04196525078206774, 0.030909855098974322, 0.03397296956409851, 0.02432484866961116, 0.028954812122749227, 0.037280217098492774, 0.0718088302340719, 0.04374864601319836, 0.048895814576216286, 0.05901121654577794, 0.017635665773864717, 0.04695004700953442, 0.04978243494406343, 0.007228063505833909, 0.052236789131477, 0.01120098303222368, 0.030911017637399417, 0.06454939638534862, 0.05578725426007183, 0.02372336622718121, 0.036849917002743295, 0.026455002108348474, 0.02791502779620069, 0.05794441995901927, 0.05794949529151763, 0.03541745515840669, 0.009876104830313596, 0.008165201626627917, 0.03629195601529172, 0.04026301873607501, 0.022283534617013028, 0.00997289237866719, 0.025184730653681105, 0.08169536343625478, 0.0377519931944628, 0.016237421246666103, 0.02559519481785115, 0.059378467605359135, 0.04782192401527878, 0.05999954657689218, 0.04246935195800278, 0.08809277216993994, 0.01687519710450884, 0.04755129962558708, 0.039888011036260475, 0.07968108845694412, 0.03992513948751073, 0.05731376488843272, 0.062338236809497884, 0.056384527049357855, 0.05759370873772329, 0.015777818287812894, 0.04517163134991162, 0.037327653262764215, 0.04417719942848048, 0.006879161688454089, 0.06157516727163907, 0.04141398540307437, 0.08082089705332633, 0.03655175175217371, 0.03822696770751669, 0.04971715659203549, 0.037562183419903444, 0.03933384601447371, 0.01917746560197444, 0.07445348066187675, 0.05129015343564172, 0.09580264273550242, 0.02678715676489857, 0.017908663120901874, 0.06993176160199989, 0.014725372443095812, 0.05529961248318996, 0.06775466229526267, 0.03734468339732097, 0.07883575639777607, 0.08843908987699017, 0.010452436606189417, 0.03948241727606904, 0.06000379453443232, 0.03980527354043819, 0.07320220627251171, 0.017918800379359917, 0.02354702810877033, 0.009109960407048706, 0.0018172257935680871, 0.031637077467636235, 0.07861210468916163, 0.04730270409415807, 0.04587189699973791, 0.07094421574184973, 0.046594789056407834, 0.021150096041721203, 0.02965449554575307, 0.029713317691799135, 0.040586311670560996, 0.019848782704361988, 0.04153062995042532, 0.06280486479461675, 0.014792851382686246, 0.07745363419094393, 0.04174441444657503, 0.006165992245153194, 0.02299691952254263, 0.021374285927102454, 0.07052389394131399, 0.017400051602312637, 0.02623595267293915, 0.044616248248325246, 0.056576271195926016, 0.0407234414090072, 0.010333150970719514, 0.046193715214969656, 0.04211561468940589, 0.09983667022278232, 0.03122278669428441, 0.047607990131983836, 0.06676168211044804, 0.020423375460649693, 0.01176885623980554, 0.01802604502787994, 0.03069936669611883, 0.07417645560757768, 0.11388060171157123, 0.044038713714408304, 0.07444555931273969, 0.023136504572786154, 0.0730869789878207, 0.003358903406713639, 0.03318420160681971, 0.023738517531103665, 0.015762005275445842, 0.016686115113477555, 0.03692837589750848, 0.03546722022996795, 0.0698480741571515, 0.13252882887759518, 0.021573003389001377, 0.03536101363058533, 0.04705055774520001, 0.028594840813668507, 0.033204269279996236, 0.05821161610524982, 0.037010282187932925, 0.01513097960982592, 0.04266399574736434, 0.04698887617597657, 0.03361501498147845, 0.056854242368811564, 0.05946525387586125, 0.016546089562677568, 0.08763079816896109, 0.02058081418996857, 0.05115073309430192, 0.06568979486943254, 0.05062083390751674, 0.033147019529414755, 0.021796051803375446, 0.038450611755251884, 0.06940362824788017, 0.05158385239361275, 0.0217355863987318, 0.05689442368044008, 0.05364018943040602, 0.02016836394285483, 0.03530670565763309, 0.02054990828788329, 0.017502467981689883, 0.08577848949860181, 0.025112007842248967, 0.09163667192502369, 0.016697240625357917, 0.036088689906342376, 0.00986658618785441, 0.029774177631723787, 0.0772837465328555, 0.05950101869060628, 0.04643394889670514, 0.05696553196157179, 0.017344092709883567, 0.011641838861959837, 0.03630428620043301, 0.029228129311494773, 0.10751034313392256, 0.04997653481099875, 0.07354212714539421, 0.06133756510192349, 0.07194916988092084, 0.027389380397395264, 0.03678463482027573, 0.055966070672917756, 0.008661350809908923, 0.04789942530013862, 0.006966957279796442, 0.04493641554408016, 0.02750166207401743, 0.03442413406446576, 0.030791854575997403, 0.0736391828245213, 0.055408228429094444, 0.02956839875438281, 0.06535616357840839, 0.03353814571915615, 0.015870100281561817, 0.05965734276199534, 0.05494636934130423, 0.0029406596196725246, 0.011083493872936214, 0.04449059833742438, 0.06286707496450794, 0.008625143579387618, 0.015498449004465535, 0.04148792054864668, 0.03458350333535383, 0.020426006972669594, 0.08296782015672616, 0.04801503179835216, 0.003567799783101486, 0.025509038654666756, 0.043978016568167556, 0.082369880870946, 0.0069048692051681786, 0.027586268824374968, 0.043200050450621114, 0.07695728582480262, 0.015449184762884774, 0.04702816116473368, 0.01987895507725977, 0.026793635953518174, 0.0498089530775624, 0.05144694099022497, 0.039330816136733185, 0.006860175156860703, 0.052445682156230175, 0.03728869769181456, 0.1660950325669781, 0.23138400257354785, 0.16753541576045175, 0.10799051938398231, 0.10944974067951403, 0.07423003579700187, 0.11841962669765758, 0.14004528522491455, 0.16367232547171656, 0.10767329769629626, 0.20355251858070975, 0.14762623085369989, 0.08745636760948167, 0.12081827097121747, 0.15844832595077255, 0.11695057649405734, 0.2013641424597271, 0.17988331285455536, 0.20105770729001493, 0.12184128946354314, 0.14721067412005318, 0.14600983129874354, 0.2066390715058773, 0.07171581949918501, 0.15140655300309583, 0.1327087216439747, 0.15043182869351682, 0.1147320931176505, 0.16169610974048415, 0.1102027438220478, 0.1264705749288682, 0.20163705362187279, 0.1431643049563131, 0.16106428638581308, 0.19414281382435755, 0.19549371794827525, 0.12351810271220824, 0.09840240807182367, 0.19511574548819374, 0.12838495970373193, 0.13471224074882848, 0.22748617785832576, 0.10685929863323128, 0.09624618466102308, 0.10791408679177684, 0.1578576874829108, 0.16789400619604897, 0.16194608423017687, 0.07575445117488985, 0.2111359922996452, 0.17387274021823562, 0.10690962294897727, 0.10020885105815627, 0.162490542917963, 0.17945902271857186, 0.20746807057049968, 0.10139243391853187, 0.13517255233901163, 0.2409013120397445, 0.12400260735904017, 0.1301847530468818, 0.19152830895637313, 0.15010811058023285, 0.1335477258168882, 0.28260563710524195, 0.11985489242379704, 0.14935899916435444, 0.17579373633188589, 0.14581594976686663, 0.08979197816863176, 0.14353775749764136, 0.1712411056242643, 0.12025603904358803, 0.12160264541425052, 0.05969579271491497, 0.11885535452635058, 0.16211607914057471, 0.18644697032868865, 0.17540356775204982, 0.07850808527080283, 0.13865327282297996, 0.16768206031091754, 0.12242973691994145, 0.22242057467660598, 0.17301006392846185, 0.1257580135678572, 0.10909273604592008, 0.10367316193878652, 0.16455796907746023, 0.11976871519319474, 0.1284901359148564, 0.11044185518497422, 0.23806326271545505, 0.1001127146845383, 0.11730686100500247, 0.12170278076683322, 0.12333055672746514, 0.12742403263766922, 0.24711354966125182, 0.14336174113615868, 0.15014004112491686, 0.1285607232561996, 0.09835615168295561, 0.1727288177297, 0.13412564722520692, 0.09506565083058612, 0.13750864553355402, 0.14562563820471688, 0.23741142914420177, 0.21433401101779556, 0.10595659424941387, 0.18276155115135256, 0.14148488700870546, 0.15231760008440864, 0.10202430323847841, 0.19224930494543047, 0.12964224022242332, 0.12147022711653864, 0.12365903990763812, 0.16074681954999126, 0.1068344773844846, 0.1346710865055361, 0.15336614462637133, 0.1639058597145542, 0.23883420763717544, 0.18989418212684894, 0.17961590220370602, 0.08587438838496324, 0.14555443799303425, 0.22512069753100797, 0.13958259876216614, 0.17581653510851247, 0.21661612565719315, 0.12054758912493145, 0.1682131584253042, 0.12533883323832867, 0.15165321799295564, 0.0942974255209969, 0.12363172887313752, 0.12106230827949702, 0.12997640777499447, 0.13477467691465733, 0.13687149020692996, 0.10216019191448727, 0.10865768237460045, 0.1958022981641754, 0.10148859327478756, 0.06507763699177774, 0.12136583231509694, 0.24056561231132478, 0.20858988376154056, 0.16514163614521105, 0.19258983102777313, 0.1532977329747331, 0.24038994835028726, 0.11718998663127424, 0.1446963275872892, 0.13176281756210712, 0.09085398287542405, 0.14873878970261545, 0.08481128051155999, 0.18654818586524458, 0.24587674667277645, 0.179690457880497, 0.11110472042233714, 0.16078506265917133, 0.1525692599675348, 0.1007229037162277, 0.09761190492539637, 0.1913151832958383, 0.142720969874532, 0.23616039224209326, 0.1185821905551899, 0.10066933884856202, 0.16465281076248617, 0.18004203095070778], [0.04578044525377693, 0.04872458243382074, 0.03985933636525466, 0.030073087902799733, 0.08189987060764144, 0.01135271249128686, 0.04764172481372953, 0.04183866241345963, 0.07438661650784555, 0.036704892728237376, 0.1014087975565945, 0.02438810837995862, 0.004737344082264651, 0.03130353236150357, 0.05751613467451065, 0.024658638923879594, 0.03643668917638641, 0.07830152498377908, 0.04654633016475747, 0.055085038916478236, 0.047376853744349176, 0.022433731900227648, 0.01087858354777939, 0.07812254386202944, 0.043832674367173065, 0.1299218623147857, 0.031387204484593485, 0.018461062310023174, 0.031902691642303145, 0.0029010851933215297, 0.046018599006798, 0.02340603537196594, 0.03255137467696782, 0.02156643610027048, 0.033714334450421796, 0.012738107808775479, 0.05726522172711069, 0.043368827281219345, 0.03721394283216327, 0.04512525238697568, 0.016899704257206574, 0.04971136879776755, 0.0812739767735043, 0.1176130893309751, 0.06283258568615684, 0.01897600363008678, 0.033202032303257335, 0.01965893271018661, 0.044356758946612965, 0.04598609006573116, 0.09348841369031899, 0.07786251063789092, 0.042529099155217416, 0.06774244319287039, 0.047938082096797806, 0.03624294554033587, 0.0707965063291692, 0.04579763243635816, 0.03189806447124049, 0.02896276794584288, 0.045523966677607074, 0.03588700193851706, 0.009876537669990814, 0.03674424283446805, 0.015596007428792937, 0.031850189721632394, 0.04334896645178238, 0.08210423988320174, 0.06063215900212527, 0.034019946075615384, 0.08295826704031037, 0.0132051762944508, 0.03514117320939418, 0.012419420977934234, 0.06092767358847684, 0.04017515994247891, 0.001236390378307401, 0.01173564632828798, 0.017731746606108163, 0.009548451897928552, 0.05169362130184328, 0.022723282492088697, 0.028880490102775158, 0.07334569454072945, 0.04411104007533962, 0.024761568582166108, 0.014785328399269812, 0.019777103687726685, 0.012330434119869626, 0.15577490892141097, 0.11173737881284569, 0.02908912074241427, 0.03356739112566556, 0.02220435368437921, 0.11365588514074204, 0.0332916914034755, 0.06089172491262998, 0.020926258556785125, 0.14055286444002582, 0.030530356208703695, 0.09675032414135434, 0.05151314630864128, 0.014131351697048353, 0.011655099843929132, 0.0805147223535084, 0.005315976037133125, 0.05632015651152019, 0.023339552346677072, 0.09449280092432615, 0.023631276713023265, 0.027222233418855938, 0.02725312974484217, 0.10045653494495539, 0.055124465631501335, 0.06408230108659595, 0.021456705496436166, 0.017987407383418853, 0.01477427470813235, 0.050354212327229406, 0.04447845201338491, 0.03012991822024267, 0.03173991328015203, 0.04152583424001933, 0.06283473456278443, 0.008229549181827856, 0.05860355051775133, 0.07658836852398611, 0.024340505591563644, 0.04001362647320475, 0.05264294596629278, 0.02164722390232548, 0.0448308831020709, 0.04994575722864078, 0.031369281857604944, 0.0549456300664573, 0.049845062631873355, 0.01582927545607691, 0.0208410274447693, 0.016102907698481314, 0.026420495593019074, 0.03534628942068066, 0.046350552565267975, 0.004767958392133756, 0.02975796146558658, 0.0398915580233499, 0.029845441045660167, 0.03311498173242135, 0.07214568675525727, 0.014113809241192236, 0.0441543661778973, 0.026092872346541094, 0.06033000626390981, 0.05384108066679009, 0.04899003573002354, 0.02648339715726193, 0.05581401754170657, 0.05082104715608782, 0.06480894697409484, 0.010345135458684977, 0.02516737684697634, 0.09471993833299606, 0.02700042032125977, 0.05385730640902635, 0.038099509829114524, 0.054631897909266335, 0.06411743387880345, 0.004890956681206702, 0.03657754210214462, 0.031025911673843384, 0.04020479988426932, 0.038119841802624926, 0.02386354308034624, 0.041501311765563105, 0.058217890365349675, 0.04506867679376756, 0.027329460830397667, 0.0913183164272097, 0.025644235936323964, 0.03370196979132391, 0.08733473582974366, 0.06131180156502993, 0.047305396893211914, 0.022131077374421784, 0.027266446268185977, 0.050483849725776145, 0.033637484340297605, 0.022770477338663997, 0.015548988782440223, 0.03232912490925482, 0.038035564470074834, 0.028334813335189418, 0.02159415699181057, 0.014061699940582678, 0.05737838057440616, 0.0794561343988584, 0.033988268339946386, 0.03782576363113138, 0.03674769406056693, 0.004868720021594557, 0.014784975041214739, 0.05022328024009063, 0.12910942607108625, 0.04005321023625232, 0.01651093378783234, 0.03834592584039896, 0.03319190462089835, 0.05704163896640944, 0.03161205129036981, 0.005622835428033385, 0.00302309091972758, 0.03971588257099352, 0.03114846084387072, 0.04410049870550152, 0.01147722380401026, 0.04367621239995764, 0.02868643428589548, 0.0364748097114986, 0.09175504017020426, 0.06404162181781665, 0.09352208325459112, 0.033893150863267725, 0.07261031142045414, 0.04393964322404035, 0.07779436711702617, 0.03422649870175989, 0.040258705661061316, 0.06835725939562244, 0.019189272932107412, 0.026476190185114264, 0.052886722804678064, 0.02325776863032051, 0.05204136776287229, 0.07946353480820695, 0.08783771851730925, 0.017932773823098793, 0.08296628031999835, 0.040241411226170684, 0.01202011967243086, 0.05020853304754823, 0.015202098424666593, 0.029958931225982886, 0.017684636029204535, 0.058236935311147285, 0.04911061796930529, 0.01917741389103955, 0.0508096975634896, 0.030749798264174216, 0.016279490965027964, 0.05281943347184889, 0.007048794622307704, 0.016071816020074393, 0.0283334324617059, 0.027730756837333885, 0.03833152721786211, 0.010999528721215264, 0.008910204896012382, 0.012776789503292212, 0.025837207738790783, 0.028360469619773572, 0.022718745336357146, 0.05590138603903114, 0.015569089971963438, 0.02971079534730844, 0.04103706248344914, 0.0639222193539383, 0.04577686379273092, 0.029408575576399604, 0.015197723105009046, 0.002951645320506707, 0.07079936383712677, 0.037969420438692454, 0.010416067539594107, 0.03370479282532488, 0.0166900604662876, 0.019846777469220183, 0.007895948055515727, 0.09550094198916229, 0.04792721513959189, 0.061687203800125476, 0.013185921632083914, 0.03539998452329347, 0.009979316025912281, 0.015691373884046993, 0.057864589766869624, 0.0323622313989026, 0.03166661590277668, 0.024163878274961345, 0.06988779581602543, 0.0196679514802752, 0.013058251164282763, 0.0315229571799958, 0.04675224693792482, 0.020302004150805936, 0.04234929831938879, 0.04904738124159556, 0.040457930656210075, 0.03418136080126128, 0.006850998381137729, 0.03008020869005592, 0.09095805591993755, 0.03656954797465475, 0.025378776894461726, 0.043116554527753786, 0.032823458464155277, 0.05195014967372821, 0.027533650075295762, 0.028549003857938994, 0.0660202622173294, 0.03922522240768998, 0.05123463887420874, 0.015130147446818171, 0.043841124316977884, 0.03254190966066334, 0.06612059675277242, 0.035735511881930214, 0.0320805830039805, 0.013791670226642202, 0.06971230039433127, 0.0187175523775119, 0.06393475255237953, 0.08800657961757914, 0.0304413004027259, 0.028749492898162816, 0.04463893594220281, 0.022259651825973586, 0.04559075039240622, 0.017095719343952594, 0.1152075732487344, 0.04398861156416036, 0.02191389527832789, 0.07215402945275269, 0.09561061513640227, 0.061166666207775, 0.06173166754325071, 0.053416418978163314, 0.02049826630090754, 0.07687396610215788, 0.0245500210627553, 0.05685203603558964, 0.035818766487101396, 0.09967014569068149, 0.02210279723869697, 0.026210556858249252, 0.022533149045381336, 0.019500762366900043, 0.03359939061826275, 0.038730252999812365, 0.037180782716360786, 0.05997847149809522, 0.034979643570559646, 0.02637986995039448, 0.04238058918065602, 0.14171039265009666, 0.12945621875264954, 0.09526641949290231, 0.11581349517068557, 0.24493245137554986, 0.09555764015643828, 0.1705032557008728, 0.16781774980406608, 0.21533801520784057, 0.1407723333085737, 0.1874260306959191, 0.08243391049965736, 0.08196792219795528, 0.12455946134944117, 0.1538084684720924, 0.05951132257318786, 0.18274877280477556, 0.17918453341530216, 0.2253684044004448, 0.16552907745203665, 0.17888768966640198, 0.1104284103419031, 0.12527407582608924, 0.19329429483942448, 0.08896854090233965, 0.35829503209360186, 0.1030346199930195, 0.11353575489333562, 0.13120999319418786, 0.10813119610951794, 0.09710404225775311, 0.07560265085269367, 0.22414860856388846, 0.10049402728796968, 0.13070189303928806, 0.13502161769616988, 0.15037952021004694, 0.15109041916026225, 0.1453813787309393, 0.16891261202193078, 0.08917932999470542, 0.2076161553662631, 0.18623030534194362, 0.21515003255298062, 0.20609260566772955, 0.20985169185986444, 0.1575775597725184, 0.17295214768138625, 0.14577203760704688, 0.22316600887044785, 0.15520667086445517, 0.14349237444900698, 0.08012940311023305, 0.17943046296075468, 0.09326974155321237, 0.21479311218905836, 0.15746848417385934, 0.1684567743852254, 0.09060513453498002, 0.1709993129536029, 0.1419896316984969, 0.08311817257274544, 0.10800682939589025, 0.0612946143824487, 0.1517338717296239, 0.0812426590991597, 0.13189735792336926, 0.2117402211672837, 0.12268731866272227, 0.15778372935470075, 0.17880421672617236, 0.11899318906568712, 0.10693640538281012, 0.0881620801444496, 0.15990188585654383, 0.07842767668227035, 0.09068269327643419, 0.10256554435698256, 0.0832547200843692, 0.10663160198037663, 0.1002977172573728, 0.10170358818985763, 0.07852073338243269, 0.24078091366156457, 0.21965053863823417, 0.15292382078065028, 0.1599134997494759, 0.14199341617284283, 0.15843260582656632, 0.29625036783756753, 0.23666737390862358, 0.14648538803861988, 0.08443832592738253, 0.19421145530237308, 0.17561013569995282, 0.08387057816669827, 0.1565885555840308, 0.22247367989151712, 0.23472411527989373, 0.13590890073007153, 0.2690720810524879, 0.21401239198542413, 0.11689174860235184, 0.10086335827626529, 0.21067451625581712, 0.1227981792462449, 0.12707563117146492, 0.14978146601107814, 0.13055480415782622, 0.10454820288765816, 0.09226770620913276, 0.1461169916775919, 0.17375557473109615, 0.11589472347329702, 0.10292951272980821, 0.12206861839419413, 0.1386409847726745, 0.16544391911837364, 0.15976987358543182, 0.10956646949653664, 0.12187794677071995, 0.09436428201414886, 0.17245648879437678, 0.1548425033087692, 0.19491697631535992, 0.11947937144507324, 0.18175837433626577, 0.28624084688002066, 0.14234623030549096, 0.1571970285787698, 0.0772352455063693, 0.11727198102180997, 0.0967157046280561, 0.13285210265988304, 0.12644379249503537, 0.3132433318082364, 0.21855523208937339, 0.13243087687559668, 0.1282871992237145, 0.08589567796837899, 0.1640917892537771, 0.1731630057216652, 0.10795853521314361, 0.1633052774254353, 0.18236621913890685, 0.13054702070451554, 0.11724147540066512, 0.13792224108211457, 0.146287216414367, 0.3499647452225608, 0.1425262303241799, 0.2606227134744967, 0.10801500355404232, 0.10638023321066173, 0.2061942195700061, 0.13748028495859715, 0.21686326562156602, 0.1310062444498462, 0.09898543162571807, 0.18297610173542656, 0.21261576773418536, 0.07984191329488832, 0.12336139176641742, 0.11773490497181494, 0.1605802260699772, 0.161552008601927, 0.09741444576291308, 0.14159027006356947, 0.10239611635164869, 0.09625877914649826, 0.09394081925312359, 0.15629918885327157, 0.16129538446905153, 0.12967582551702378, 0.14938241081132045, 0.1109588496206749], [0.03074858593003404, 0.01670184289856303, 0.048508334964994466, 0.04395533653516923, 0.039514566155811476, 0.025562842924808784, 0.06575731019819937, 0.05311341971279152, 0.017943956791573477, 0.02581119330810203, 0.019469345101125298, 0.06500668958911011, 0.07786471697111284, 0.030526696223645445, 0.01165415085251293, 0.05506768702499329, 0.0413430801352426, 0.0051207481057293, 0.031381163881310535, 0.02489191461204281, 0.03975100004144254, 0.07501065640920594, 0.025944837346492756, 0.02997363819890926, 0.10410266147265512, 0.051045997383733915, 0.043950770651140524, 0.05475236140491982, 0.03776287930386682, 0.03938838381380324, 0.09525737199451655, 0.0890872079218107, 0.019921024795621634, 0.06895706793593784, 0.034093298994365244, 0.0459704005850419, 0.039325415216867006, 0.004480918653444538, 0.07387334525945687, 0.029648610075274785, 0.05777596488534924, 0.0234968206214328, 0.016410783113491152, 0.051457685373362996, 0.039051102113819895, 0.023074562533668453, 0.016501957152579582, 0.03884935285896063, 0.017339522995415236, 0.026297402500565496, 0.04098622105835427, 0.008447426502713034, 0.02392483777516792, 0.03090788050734949, 0.026202694880926324, 0.04212244436325085, 0.03249459224002015, 0.006813062185932312, 0.033685234600618, 0.06052793657046653, 0.04713455928609737, 0.05549680351489975, 0.0325897595124139, 0.020098839548506567, 0.03940835955642885, 0.014952581672508632, 0.0554685348704938, 0.06202319081151678, 0.047476855031545126, 0.039437164462381796, 0.07037136583558976, 0.09198807645589115, 0.004596451415695371, 0.09661258153256871, 0.11116299673073715, 0.06580971061222016, 0.021309641512831854, 0.02076854020537388, 0.03213376482768405, 0.05079828285341782, 0.039218492325275175, 0.015816875365412524, 0.023491693577999552, 0.052230832797865716, 0.046906257423782544, 0.04682725460659112, 0.10214539875666942, 0.05270755399138697, 0.06742701415092715, 0.0384251278404507, 0.032702129289147355, 0.08901371710723446, 0.028445557090303594, 0.049499729347805825, 0.09718607495268507, 0.061503197141592546, 0.037707525620897936, 0.07960250315767142, 0.03501761854896623, 0.01491066421412172, 0.015356507276244944, 0.05910082585028103, 0.03665749869880177, 0.050514002946475824, 0.04834381758325523, 0.0336490101331184, 0.03351983621776585, 0.013879118205588913, 0.05808827594944066, 0.016664724023411834, 0.09565767591759082, 0.07588783474338633, 0.04171117006110088, 0.09086463915845079, 0.06255252692367762, 0.01084602481099747, 0.02046369083766495, 0.058545952197164304, 0.03107389367576088, 0.02723337999815422, 0.02685047393184035, 0.04896192030320245, 0.020742529605124748, 0.03824530402198434, 0.035591567791397535, 0.05432342494567556, 0.027266610977089694, 0.07137576073047615, 0.04546097509803311, 0.06508659255961258, 0.04872932834851165, 0.05295277107506991, 0.053568713427070654, 0.06387376046228795, 0.03829500780651166, 0.0328142271046677, 0.01831059881125487, 0.03247485015421145, 0.11610561215709295, 0.03558336682016811, 0.014444584939478627, 0.034547600624782425, 0.029361160479546077, 0.012505331992982857, 0.09677545182527074, 0.008271102748450734, 0.035770824704799926, 0.03310678842207117, 0.13989926886654672, 0.03931654008826421, 0.006624563858138338, 0.0532407550171258, 0.03561064338071212, 0.09981644550158132, 0.03875328543325586, 0.008918617499030886, 0.0797527636431398, 0.04414657506370737, 0.04164614068764833, 0.023713763315050353, 0.05740095335509508, 0.02658953289351156, 0.06472560426881237, 0.006914000973225602, 0.03529028073253651, 0.03496725209838441, 0.017536380778877966, 0.08696417910076919, 0.05405030693979033, 0.03005473626657359, 0.034832455097667636, 0.027315240323303208, 0.046554967806103735, 0.06694511420303775, 0.04524588059153288, 0.01616716332313034, 0.03114310780449981, 0.03211971669037256, 0.023512081092884465, 0.03561239006117948, 0.035476409454619696, 0.0656105737171827, 0.0035966939861781055, 0.07620957634982563, 0.00590449818710406, 0.023248554507811225, 0.019247196840062257, 0.018988634504738356, 0.02973187425654502, 0.06232353175179132, 0.015206320526739283, 0.03563194828588636, 0.03611316258508352, 0.015902049978443935, 0.04299145620015841, 0.07568880510065826, 0.008811147812183106, 0.02695543563834602, 0.01722913164074623, 0.04021290126406858, 0.07598116723520142, 0.06576554564338538, 0.03209256270389644, 0.022808398690915877, 0.059364800596789974, 0.014551354613485596, 0.05777605681590015, 0.07915906848446017, 0.02933156075737169, 0.04056177770478591, 0.03280021918697223, 0.03949200103600179, 0.03648206839458116, 0.011019055344795269, 0.015103519188180087, 0.038829855921287695, 0.055950588035968044, 0.025870773881193132, 0.01867358467631763, 0.03564248965572446, 0.04027142655104399, 0.028430702645451795, 0.05207985985062776, 0.042485209978035385, 0.03008144209161401, 0.023395235447453398, 0.038002572893615694, 0.029853088518364296, 0.05657167466838033, 0.02121648713645916, 0.038822696829635295, 0.01820339246713106, 0.06416354471096589, 0.015830034840731852, 0.04500136064786104, 0.02764208216009842, 0.007426772349243684, 0.07642954317552429, 0.01287739695755825, 0.03984773779408105, 0.04420094432369356, 0.016550801003411893, 0.05102083522586092, 0.06030424655745588, 0.07286764801509919, 0.034072741024917176, 0.044434172131361506, 0.016826895260882956, 0.019216329242373188, 0.03147090342076075, 0.03429934983291934, 0.11938285202749314, 0.020360973768777425, 0.05963249086973168, 0.028554866345779552, 0.03132729257847513, 0.008065624560620035, 0.05693925514576897, 0.06241003073932183, 0.03825931193967981, 0.056766862380168134, 0.014388081167013416, 0.0977999029020148, 0.014179763665813354, 0.09340123288453588, 0.10675520260608005, 0.028065031642214428, 0.03204922511001989, 0.014835308933059775, 0.03636523615568876, 0.09966960176825525, 0.028457663194727034, 0.01223147375464079, 0.044413679279387004, 0.0012150545902137135, 0.057979349737926844, 0.03589847410518316, 0.09198776235984218, 0.03460372805655484, 0.030985309013856516, 0.04662355565796456, 0.03206020314997483, 0.03218388996056972, 0.06593079080865269, 0.014409012604324568, 0.044675397896958936, 0.0946260542578755, 0.009841280388495615, 0.020094061075078867, 0.046493684602600914, 0.05752585249983015, 0.009874700016582446, 0.018226430646233985, 0.00879856673324661, 0.08913663591468528, 0.029922107294682535, 0.0262601055099719, 0.08308612711487279, 0.08398300923046567, 0.07449151692731727, 0.038357352041789604, 0.058541313534782785, 0.016163985973464388, 0.02405400019920161, 0.03441329775077682, 0.002488081447682494, 0.07758959947574524, 0.1393417866840478, 0.025921529121396523, 0.023597001939290957, 0.0426795051973914, 0.037598955640268904, 0.05951583483106187, 0.03352876114208372, 0.05391789247251807, 0.04099896493097467, 0.05534480400984326, 0.07366435647371315, 0.06592024943881458, 0.05479073091860741, 0.06780694013521557, 0.01641071799601759, 0.027260623999961445, 0.05352563630308836, 0.058860814334043575, 0.010174667488993898, 0.0403823560824798, 0.0181097075748708, 0.028558562720014204, 0.05923090374938423, 0.011297346359389204, 0.04979491451634996, 0.06685156720660387, 0.07065785207575367, 0.05036921615922644, 0.027659658132301226, 0.01974018974109523, 0.037098447416698745, 0.05575762197916066, 0.029504627680345893, 0.03851878975007323, 0.008839862702804948, 0.053339718255184354, 0.127673662387796, 0.017268995025886164, 0.06082074303600577, 0.02174517590432398, 0.050602068583811485, 0.0331945974199522, 0.048228080850094564, 0.021882058579414602, 0.016598721718295448, 0.10512467638979997, 0.11477929945554464, 0.17050705549697723, 0.1704671729596392, 0.2289628889411688, 0.09525812276068235, 0.1264055876902515, 0.22847104517202224, 0.16604057903732025, 0.12424173404372509, 0.14976274282220872, 0.188991270899292, 0.15474727857978116, 0.11659725674337919, 0.1278494336011429, 0.13832134224714773, 0.1840792836681489, 0.10065297521049939, 0.1341209740888688, 0.26074608427382284, 0.09086057889245211, 0.22382553396446092, 0.08804299943749944, 0.08845059651761286, 0.2863091819228665, 0.18308802718116393, 0.11950976981390869, 0.11860956287672443, 0.11825657254385373, 0.09100612027630692, 0.15627426035221548, 0.20863276936354178, 0.1500734680842969, 0.13000096855384688, 0.13947959057986736, 0.11744307143793953, 0.14302711393083298, 0.08971421258343805, 0.13453392612357296, 0.1497633097272727, 0.19168888098530232, 0.07618634856396145, 0.13860162317512498, 0.20460431133547138, 0.19660007148500414, 0.23864092365387948, 0.12603519950062037, 0.1775479091391448, 0.10993986075083095, 0.13913659769440853, 0.09880037542672888, 0.09725367455112358, 0.1567985862493515, 0.14472511717148367, 0.14222025480722228, 0.18838653641362346, 0.12298528856087117, 0.10099138689017105, 0.1893709287528069, 0.11390674063154768, 0.10359882076661434, 0.14553177711223403, 0.10142949725230856, 0.07757467608298026, 0.19167745095347205, 0.10765331812323102, 0.1420355356869198, 0.2728179752105667, 0.15212630792971582, 0.11711869448904069, 0.2056762522026416, 0.16934618714355654, 0.07295098305950243, 0.15815895922001333, 0.20472452585254947, 0.2688497010498278, 0.10440443882778769, 0.15755831564386047, 0.13075743441379842, 0.12418482903270953, 0.18136750095553938, 0.16755533404648307, 0.16234668692754162, 0.1380204841975243, 0.06895791829353379, 0.13581914586886285, 0.23912512186554172, 0.1251675972654935, 0.1988972014477176, 0.13247783806535507, 0.1622895214466318, 0.23990933543011067, 0.11893062266491114, 0.12184234666487864, 0.20392206407362418, 0.19287251747183262, 0.08794117103060407, 0.13222343558746, 0.13506893128637346, 0.12325240043743003, 0.07789983444156186, 0.24440670055487465, 0.12184614646098307, 0.1356905503498931, 0.1123136914365234, 0.09641563564899469, 0.06618775202021485, 0.14214968278763757, 0.19340652672033157, 0.14182624046600636, 0.22644520226505496, 0.24485602644422363, 0.22277150423296038, 0.2030803632712172, 0.1551389333701903, 0.11208306066691877, 0.08472771564077947, 0.09014821671430143, 0.22318082501090344, 0.12171879966532993, 0.11443513445556165, 0.23435994772420776, 0.1484598877329019, 0.1954052960800548, 0.15396950015377614, 0.1044144439360788, 0.13733903366711833, 0.20398866775776112, 0.07881728601792166, 0.11186652591512089, 0.23780297668230152, 0.2092805273470379, 0.11851570944512084, 0.1799118113253386, 0.1521180188583751, 0.1712351301384549, 0.13783616344294242, 0.14287241013540378, 0.21206062978073476, 0.13327412517561069, 0.1112622280995692, 0.14926550579407524, 0.08623784347887962, 0.1224446909562234, 0.2317010250783736, 0.08697355601696238, 0.16522751460152288, 0.25006444373678777, 0.2653046445019784, 0.13410346131891976, 0.08564603289649372, 0.0752209781879379, 0.20534657392530672, 0.10155901973766666, 0.14134886043687023, 0.10351837387368565, 0.23595800713425685, 0.100000727951767, 0.13086491654957497, 0.13052183173356519, 0.19849203286632416, 0.18916531075393, 0.10974410230353956, 0.1022756873299518, 0.23561804795697813, 0.12776678803587152, 0.10387103478874891, 0.20236050109228781, 0.12193861327344373, 0.10416196433887367, 0.08822150558473603, 0.11089785370014368, 0.10589717647000667, 0.1318340790608237, 0.10833078499643073, 0.1377502543431136], [0.0571702612984565, 0.013680079944371698, 0.043317824977660374, 0.014195109364546597, 0.004453848936640087, 0.02937490601212748, 0.030051022655360644, 0.01652893685405293, 0.029634207622298313, 0.05615485005921895, 0.07401320993179276, 0.05242853710848478, 0.053382351048170566, 0.0031314571688492456, 0.011369393098228162, 0.10677104530435418, 0.08127765399554084, 0.011051835289465324, 0.03138593469385899, 0.0635478436766613, 0.045208798105558085, 0.021041275167296973, 0.05536573353193461, 0.054053287021815784, 0.06242330321260999, 0.06560080609614811, 0.039732862909835194, 0.04730918519799748, 0.06049599453446366, 0.03876132169558156, 0.035211446454688426, 0.06458210067883616, 0.0397620355379918, 0.058720819426760565, 0.013824284504798633, 0.05777959231167071, 0.0674006071001772, 0.002054505847251764, 0.06289039851136266, 0.025897062188314817, 0.04882401681595272, 0.04452382740114005, 0.027919289160279498, 0.02890226423680302, 0.025241214316338304, 0.00878486812355057, 0.05466712263202476, 0.01639200821368685, 0.01487470691978571, 0.04820182701692947, 0.0683295806389182, 0.04690094460402766, 0.04893745145490093, 0.09612336544500244, 0.0693593024005813, 0.0669939982734861, 0.053155133200268594, 0.05709696966674059, 0.03933605234769564, 0.015925322771973668, 0.05146310161498766, 0.03876235591427934, 0.009564155742766397, 0.02507027520257379, 0.06474067321828296, 0.03225574900786723, 0.028921973763874946, 0.01545347389765084, 0.056639121049233986, 0.1215461234471971, 0.024449887625392408, 0.08087469940824855, 0.048465342110683846, 0.05195371964345536, 0.017792968522577036, 0.02907019262502511, 0.07782536303444255, 0.052294601956682826, 0.037935907922444806, 0.014293255761355884, 0.0658638040805536, 0.062473600715278625, 0.09489456041445656, 0.042558750588326685, 0.019874484954221595, 0.07137680261005318, 0.027379423169599428, 0.07222267859164747, 0.011251997784711422, 0.021369944123791593, 0.03772988389696806, 0.014011662907808298, 0.02303253878058205, 0.043552611774254235, 0.027708708826873093, 0.011484702737371047, 0.06728360249150185, 0.04835268122053916, 0.014132951863200195, 0.07946362673875787, 0.01616400129522287, 0.013204024289734663, 0.031898610308886535, 0.0897209158527755, 0.04182058273844662, 0.009834383681957281, 0.0316423328307968, 0.04658541214021464, 0.055791398795742186, 0.048191546116985624, 0.0608557187801888, 0.008872853321654182, 0.0375590079854573, 0.03117061036098148, 0.04044717095131355, 0.018961034272046342, 0.0662391105546586, 0.07606739043107918, 0.08290670166212706, 0.013844895142791493, 0.03711337847034297, 0.036700315352889805, 0.04088839163042365, 0.08659837211692527, 0.024174231953257998, 0.0458620872438675, 0.009982447410302778, 0.09172511677588187, 0.030969328419756026, 0.03856987249286425, 0.061166685359973105, 0.017522997222840786, 0.018832266383293658, 0.05111612507232255, 0.06343262788328914, 0.006574395154001973, 0.040817042031595786, 0.033241593083667184, 0.021814330661248778, 0.08546745780134395, 0.05848380331430705, 0.04186334576637995, 0.018097438676763448, 0.032684968919643474, 0.08247886453905413, 0.0352493831286988, 0.025070524181149183, 0.017189153342417652, 0.012021132823710722, 0.02654001105486626, 0.04376736920206778, 0.021927979804815787, 0.022575588401166663, 0.013510718014121298, 0.06543575245286189, 0.02712437717784797, 0.10584585623995912, 0.040831658989191055, 0.07787671390800707, 0.0269702690157799, 0.014357405091305415, 0.09866299287926766, 0.00821756948191192, 0.02388034338852571, 0.019663215141683336, 0.011815283083236747, 0.04721945714986613, 0.020480192371553952, 0.02824132379534985, 0.02785245756498508, 0.04441389761444542, 0.07055564062489618, 0.03587810382727654, 0.04621908038614258, 0.03511188566804894, 0.08120397931986278, 0.042208311328243826, 0.024027491641801693, 0.0808488286190456, 0.04131006557614573, 0.04602238731158357, 0.013726955906848514, 0.026061027986748565, 0.02526127815907521, 0.04466859886663095, 0.05126171242145281, 0.0303470179618847, 0.03439538278466752, 0.061662650682152285, 0.04268697838509276, 0.028091586164889798, 0.0670038961294678, 0.08258146669475303, 0.046438890163816755, 0.019655196116335934, 0.020856496675180334, 0.05886020529414377, 0.06507708540847225, 0.07771338396255048, 0.03108441014774144, 0.04813496286289827, 0.0398545291635298, 0.055701586477939165, 0.04222049978711913, 0.03492020663895434, 0.0298227533517826, 0.025013339548041264, 0.06736199626879347, 0.07706345028934941, 0.04070512424673765, 0.035540599961795157, 0.05423092748969794, 0.04654209752897582, 0.0123419733192291, 0.01246620884029976, 0.06706060195762305, 0.05711425261031236, 0.010110520074264178, 0.038034055276864, 0.04943303756355759, 0.0011904747788644126, 0.048655527268326094, 0.06886861542420042, 0.0333820897785406, 0.02325968768057083, 0.034030816863260926, 0.0786650413647294, 0.02608149594086553, 0.07990349910312122, 0.061940384367781307, 0.07406982382939709, 0.028496526835125782, 0.049904511054797526, 0.02829338330024433, 0.010755253925679192, 0.04118125172211759, 0.0069428015699339735, 0.042801975843406496, 0.04354800758582931, 0.06244507926185766, 0.05969328377696295, 0.042735364498390306, 0.02908806162585895, 0.04507172965414582, 0.04264860887140517, 0.03617183342876454, 0.034438482891287536, 0.1073462700831794, 0.07639929036339445, 0.04619666465347813, 0.03334504559696202, 0.03391169785191456, 0.006394227553579596, 0.07887856539098487, 0.02401447963840779, 0.06551695011195637, 0.047940778726291274, 0.013857031890731907, 0.037813801168193745, 0.036810566896512624, 0.009509844896984438, 0.035200594819240996, 0.02827852119451329, 0.021708317499067036, 0.0278087560793445, 0.06818342638472397, 0.032841840743898384, 0.04654901913337169, 0.07637928014681225, 0.01575906445542651, 0.008075171931376381, 0.0474516507388363, 0.07391383300625509, 0.022288646338687792, 0.04592582192872802, 0.12331475233358723, 0.050956958814734415, 0.010912214807655302, 0.028111220998389107, 0.037895619358506896, 0.0997688178153288, 0.049343412937296015, 0.009242301138358252, 0.03745649776030933, 0.050708428400778965, 0.05313359846871707, 0.02840577989005514, 0.010774798743847397, 0.03812137014803387, 0.07230201465708595, 0.0369553690055205, 0.03736540224523314, 0.08035094807705573, 0.05204690657856484, 0.047630773586851936, 0.04110473486024045, 0.06578606913887686, 0.02487183927798704, 0.02563180232931289, 0.04214779421266529, 0.016834575292323867, 0.03710719997123365, 0.0295195912927269, 0.08111454621558228, 0.025165203072491194, 0.035579892611431505, 0.06202251665414341, 0.017236712080756986, 0.0067692759518151084, 0.07227707849515062, 0.05189154777796038, 0.03945303014329365, 0.023043771544771812, 0.04201526866264401, 0.09085308655255264, 0.10018660386483516, 0.020624232223077167, 0.0314420985148078, 0.003692583775245435, 0.023970329991331505, 0.01323996147426266, 0.0765259400190365, 0.019216541831772176, 0.02082625726958917, 0.03820227286327751, 0.04047589541803445, 0.02157151334798865, 0.08422613489411532, 0.01608738675713539, 0.047495126228539214, 0.008874141306976878, 0.01346940097714504, 0.07202659838742788, 0.01876562630998031, 0.07585807222752802, 0.03687015704570278, 0.01625293644235259, 0.07932658893086257, 0.05414904418191122, 0.04722370510740627, 0.05589108981732881, 0.03417141698000412, 0.044824064919544805, 0.022797922438551343, 0.016449685058286114, 0.009107823979349868, 0.040903916402209195, 0.06502876824308788, 0.019827090924785986, 0.061061336779065674, 0.04808069702478186, 0.053275294091191985, 0.19288995363298925, 0.12473727035666667, 0.1509910422347246, 0.12101225209452453, 0.15614253919451468, 0.09122932765392527, 0.12092675668217483, 0.1965720020234585, 0.1753975309792065, 0.17140727009504073, 0.11284494276849494, 0.13543179649258816, 0.12067219332581568, 0.11635996866971256, 0.1190839245194389, 0.2879404282617954, 0.19240380955799935, 0.15297225285922328, 0.11632268317043783, 0.08310639014047, 0.1767147885214898, 0.09882904243685546, 0.21074646723366555, 0.23478563214021347, 0.1300398245333664, 0.16007851508836593, 0.1847775268458551, 0.13087803197483863, 0.10947148991568435, 0.10106938996262128, 0.1250221478121896, 0.2045583000947391, 0.1443654235692755, 0.13199842024234035, 0.10151190533032341, 0.2304324141192821, 0.1170079488187067, 0.06597674076235102, 0.24163205266719867, 0.1728119842347599, 0.11889953481694383, 0.13806546888043805, 0.19794394292177694, 0.11441375294159498, 0.1372420929011799, 0.19525779351111383, 0.17836265896837558, 0.14156005555583587, 0.09513110538283664, 0.24195200162789515, 0.24138941729982055, 0.1285343085445704, 0.24620634834131888, 0.33575663343071943, 0.1462972521661751, 0.17958550383487057, 0.1488253882815761, 0.2223100128673738, 0.1086855756359235, 0.19899478572751247, 0.10593839966121221, 0.05983080805069017, 0.1386901829391718, 0.22683127993537536, 0.19086133748773607, 0.12137448144776207, 0.1545609200313207, 0.16003337718786734, 0.13086402788758278, 0.1448563786764299, 0.10033703288964688, 0.22776250577261373, 0.1932259444748202, 0.17095559997664345, 0.12126287775895289, 0.12541555694394535, 0.23535022361864968, 0.18436238379968753, 0.1527863539635174, 0.13316003936192683, 0.15182672158604668, 0.0836324780398319, 0.1153257652936924, 0.14651929509014855, 0.15096288084262802, 0.16361687602775712, 0.14825319721093103, 0.10064397367738909, 0.1412040544974227, 0.1748804063085587, 0.10713932675219352, 0.11543300994221242, 0.1448528546719782, 0.07346417003821942, 0.10466683160273299, 0.18203001379245715, 0.1086988366178928, 0.1588682953508631, 0.07182716271809994, 0.2565709970170452, 0.09754862606285081, 0.16180933753569282, 0.11997678467342932, 0.24338826326833618, 0.10154434149303745, 0.14940540877080735, 0.08657834657858457, 0.135411188727425, 0.14626000497129657, 0.10274720678646719, 0.19197700665362422, 0.1248742621992865, 0.27596298064435687, 0.22159992597035824, 0.21000677869925577, 0.12033436387296646, 0.15192629769444466, 0.20740295309693585, 0.21610745859722938, 0.10671898962989931, 0.15457087917433632, 0.1266458788285813, 0.1990701381357447, 0.111601022823203, 0.26316514479056485, 0.12200818937872687, 0.11315859448645385, 0.21914861315200407, 0.11564348493852925, 0.13685183239079293, 0.13506629594391392, 0.08769691921770574, 0.038557189907277786, 0.1262109400704503, 0.16231202910984718, 0.1336023632076479, 0.14873080706644445, 0.11327317825728848, 0.18178140293926964, 0.2760109377484168, 0.16088365817502623, 0.13336771047644078, 0.10295574358033557, 0.11577285420630248, 0.09994685664893159, 0.1553054502414119, 0.0907609261752617, 0.13074280213444464, 0.22302987504630323, 0.11492657985898758, 0.09123205492693572, 0.2798031649041561, 0.09019612019220669, 0.13013658143820303, 0.09532880203257646, 0.13382800674486545, 0.21235859201800442, 0.1260057434199318, 0.2489236928522587, 0.09668401157062861, 0.12797125690286199, 0.15423727852682914, 0.14113726695218395, 0.1558008639802856, 0.15846829020207928, 0.14550237465770016, 0.09998372846072721, 0.12573044206346237, 0.08956153126012895, 0.11919647815727419, 0.09816373337901409, 0.23381558096697255, 0.2238058608265654, 0.19659025023781485, 0.13106129552808501, 0.13559014686653692], [0.04112750299335007, 0.06444206746715693, 0.023125802324483954, 0.024879042419695088, 0.04173858068703164, 0.03997070639724693, 0.13496950839556035, 0.02320658246565971, 0.04589544654253029, 0.06553620956237279, 0.023235498454361674, 0.062169356557029876, 0.0038787294949044386, 0.04222547935862695, 0.0008863573243762668, 0.020002142015484073, 0.04880978673275921, 0.023166696097882047, 0.0291332071872368, 0.04129121598276881, 0.05383029797925584, 0.0309552381476087, 0.06433463129665583, 0.052507877004362886, 0.02843639850916882, 0.050684733301280975, 0.004013467123807078, 0.029702364549701734, 0.04778242452190288, 0.02172215687741916, 0.04934388791180907, 0.05804513370798481, 0.04969404371935995, 0.08460392349309499, 0.08711314489764553, 0.04083234846832291, 0.06554033111540541, 0.0951457912883451, 0.042698400756043774, 0.06726734610574861, 0.05740082312014796, 0.0839859510080949, 0.05209631158880169, 0.03711194588592456, 0.025447167478682056, 0.05561859617310186, 0.027640571051667777, 0.027867131979174675, 0.041417497916207205, 0.006605009463871079, 0.03773301336613875, 0.05050962475398856, 0.02470625703403306, 0.03411822749542133, 0.041857075336719715, 0.05092716948579877, 0.034373135591346415, 0.07855487792121787, 0.04983520308028787, 0.030748601251792525, 0.06344265980465759, 0.0013946281133910582, 0.051660909347476504, 0.0909861636858794, 0.024607077376135898, 0.06265737371699465, 0.033932922317856745, 0.009318481879158607, 0.04868280765930972, 0.13281123953000193, 0.03347249964492456, 0.029628726263200084, 0.020350487940313838, 0.0652452034034556, 0.06235486857833401, 0.0019770674055419684, 0.05246129502812701, 0.008349299258101852, 0.03550039183708929, 0.11230014700202212, 0.036337185846341234, 0.0791239433531319, 0.010323526991170742, 0.06733882976996322, 0.07033806399352129, 0.04887318050849342, 0.0683661460155441, 0.021723503276946086, 0.10088833274259683, 0.04977598831418061, 0.01095555623197147, 0.04368624815176572, 0.02241874147476929, 0.03296456802936812, 0.10068659880949606, 0.013111274982351932, 0.01460921340396688, 0.01966622778244557, 0.017931607454234076, 0.035635682964517225, 0.07251266585362535, 0.020433189046959725, 0.0205341613505997, 0.018127394629822626, 0.09461989491096429, 0.017085333106919162, 0.05452356158545422, 0.05956055138320212, 0.05388560952738889, 0.035512653074317405, 0.02479276942810224, 0.1182191108443564, 0.07163051560881638, 0.06552071926454384, 0.05660510291495631, 0.020735075569621498, 0.05014926082484665, 0.002987198982267611, 0.039037473409646944, 0.023397987618321375, 0.06981101848425404, 0.004274822807224889, 0.08638867853029121, 0.09405155726257833, 0.018038518854507038, 0.050330582345204974, 0.03832246822815749, 0.0340557606860755, 0.0639571184893289, 0.015714297149961275, 0.05084967203137856, 0.039260906783202966, 0.034828459949142514, 0.018998055470987193, 0.054398003605104266, 0.012956621940247716, 0.11996349304794304, 0.025538582835466634, 0.10380630035914722, 0.05059084156528116, 0.02434172750180287, 0.051136487689349926, 0.015263920762546122, 0.03139677675320737, 0.06589412584059662, 0.02879358508864478, 0.006896430267877276, 0.02306755857482072, 0.015256387245420729, 0.031278063768460866, 0.03495062032954828, 0.04934405645115241, 0.02342143565446379, 0.0597514758156913, 0.014739895554920359, 0.08262633646447813, 0.029757440525798068, 0.09585747930912242, 0.03297935352630673, 0.030609550547876188, 0.02033992550305782, 0.026669085378788655, 0.0982268590239748, 0.018025187009404746, 0.027266494148681243, 0.061619857010701974, 0.04640361181490364, 0.05437778271434288, 0.015145970992894183, 0.047606503921410734, 0.05900228779102045, 0.028139968447747733, 0.029988781841952476, 0.015522148892013057, 0.014739973121322693, 0.03053662663836393, 0.026127694873139266, 0.04501330395860057, 0.07651316933333874, 0.02478064417148069, 0.0434852764761496, 0.020436462157616214, 0.07731414490169095, 0.05380431993774349, 0.014175456336459086, 0.037372086362372485, 0.015368823097237657, 0.07658047015748679, 0.09065199613330827, 0.04369980790802548, 0.01932725685858919, 0.02639712799610871, 0.039016992048991304, 0.02297389474997838, 0.0473585672255966, 0.0430444848062771, 0.007456838906246929, 0.019117325784698613, 0.017918411589738344, 0.0035055735732443753, 0.0535778681777658, 0.050702203936394186, 0.013344075696002091, 0.025001068734714103, 0.03407339986053205, 0.03189314044110718, 0.025152938004823464, 0.011559636670074636, 0.01626170048820636, 0.02285638835371262, 0.011158550379707689, 0.05091052622564378, 0.041729000757538506, 0.03587698150846747, 0.09831360315964108, 0.07400148878655127, 0.034892562356206684, 0.02030133382387219, 0.02149762991335123, 0.04236437492973862, 0.010910264156278103, 0.04134393815371779, 0.044355923910775495, 0.017913064296026866, 0.06673148292447291, 0.06401396604375013, 0.05641807787000172, 0.02671780474033327, 0.035742670973582615, 0.0871660279470586, 0.054435181852069595, 0.03657622443091485, 0.013479882975169008, 0.06282554916857232, 0.09165322708506739, 0.05947394514336221, 0.06238087726336333, 0.043219030278945164, 0.04332661200615187, 0.06007779862791781, 0.02740032587861342, 0.036847025020829136, 0.03422086029463718, 0.05344312097276411, 0.07530982906539595, 0.049301561553992575, 0.025533055511092948, 0.027409089924467188, 0.04833879970735119, 0.019193124439146732, 0.13317333864829234, 0.01841543985891246, 0.054990388753433386, 0.031195017922249053, 0.038452097965824994, 0.10771089729161994, 0.07176956822795254, 0.05810775756535511, 0.04607615519254919, 0.021707189434598533, 0.05079238014596124, 0.036709420307869875, 0.018073370109402367, 0.050977884506386135, 0.04512938543132717, 0.0676577904772374, 0.01463345721394064, 0.05596721214392493, 0.01849502490292634, 0.007515727127376463, 0.10157986499008634, 0.01606264690523066, 0.06268802489484511, 0.023799950121751717, 0.04423281741178325, 0.05226886523286662, 0.07315116949499616, 0.05809425143525005, 0.06765153919977528, 0.039352680286092144, 0.08400895662846104, 0.02462794752641311, 0.04102986508740052, 0.040717029253080975, 0.06948294899156017, 0.003283929493796501, 0.04258300110156979, 0.06448322171044928, 0.042596219948703246, 0.044631110354056286, 0.05542107955402425, 0.04260017296239253, 0.03843405659520819, 0.07750981907931066, 0.009796549472206784, 0.057188758491388256, 0.047725412258577925, 0.07324725224245941, 0.0595812549093558, 0.04541596360204201, 0.04341341359841247, 0.027057920965636452, 0.08250501878078907, 0.026840999339436813, 0.0346430781627855, 0.09628124084443816, 0.022102517616604606, 0.049014267091068535, 0.03437587435567572, 0.035234302687909336, 0.020586123179283836, 0.020076385511445905, 0.01933660696170503, 0.0055445048529955175, 0.07177022706356741, 0.03278068394490308, 0.03603889036082453, 0.05227950236369526, 0.1260388920444154, 0.02410808983709543, 0.019250866401219563, 0.026843506362169024, 0.07317399125426047, 0.038997652159342845, 0.019470051817235448, 0.018013695690540538, 0.05999757007004754, 0.05403351046205048, 0.07233141711161983, 0.06436225642720539, 0.03489563053834342, 0.09674033435482172, 0.03500735680122049, 0.0737509167482776, 0.04813796592756145, 0.03162478941733078, 0.03966566550755694, 0.02332512499584306, 0.0729534115582224, 0.06051832982789605, 0.051460044924169786, 0.019472641194419518, 0.0500132151008133, 0.015068109646709937, 0.03729067802909882, 0.07542126421486178, 0.031042141246519266, 0.06332544452180305, 0.03468598674742445, 0.03808455579283257, 0.021574719425951763, 0.03512672862158187, 0.07813192843910187, 0.14334816605814044, 0.16367992506392542, 0.12071212948930841, 0.07055707320931458, 0.1466856434220268, 0.19644164450226292, 0.1529039637816529, 0.0950438479682611, 0.17111842430407004, 0.15700621139859, 0.16033115556403515, 0.2342459998063503, 0.16543472606328227, 0.1580795465457824, 0.2247858251775465, 0.07238286757661451, 0.13614367603534652, 0.18346141843545824, 0.11009700836673861, 0.19716693058369622, 0.13263310876584825, 0.16432693228125572, 0.11102917649212385, 0.177939533286037, 0.12734259749131818, 0.067843742999098, 0.19819837604318896, 0.2141688118178037, 0.14789457613181684, 0.10464950269388576, 0.07485897866107764, 0.19391833474078488, 0.16194757044074998, 0.14938090927898884, 0.11382404144012159, 0.11531392923526226, 0.21486506316690676, 0.1766848498054089, 0.21147731511342913, 0.19571281909461946, 0.0969265703292143, 0.14241173082301695, 0.25198044495717176, 0.11900576822940381, 0.25582563943199577, 0.10503174226370551, 0.06256778739512929, 0.128339906072905, 0.1631852620912175, 0.1416577470879401, 0.0944992513846486, 0.1099280400141593, 0.13924417176073597, 0.1158673894561587, 0.07167741551154083, 0.16136690643766236, 0.15164315159763062, 0.1345972356296355, 0.1648082040370472, 0.19186952451784767, 0.12077804369431351, 0.10553404313301849, 0.16668666694914142, 0.08995048942104464, 0.1240886083894199, 0.10069327143531653, 0.11650614590654451, 0.24157378401967788, 0.2681454823863122, 0.0848528944076069, 0.16950659063314238, 0.1097635992412125, 0.14980762025281308, 0.17011235167662944, 0.11556987921076438, 0.20748425034746049, 0.10999421468905865, 0.14667713984606728, 0.22581609086163584, 0.1742131590482689, 0.26834325564484446, 0.11503556352709571, 0.14091114844045333, 0.16339656446249257, 0.15101393294190207, 0.18305082595156086, 0.1345804123388183, 0.13432771057611512, 0.12242968329378676, 0.12147689208147988, 0.1899992127812678, 0.08271494985467966, 0.12343543416429913, 0.17252165223321608, 0.17487576381573755, 0.18806068857591, 0.1088305424538351, 0.10715342277000028, 0.15224008730822994, 0.2114543477974592, 0.08653478681920998, 0.1712882813186415, 0.09519185615523208, 0.3843910817898089, 0.16715350560843947, 0.18022595333956903, 0.1669568048730012, 0.16922342921456984, 0.1559138313056, 0.07593739297120802, 0.31998450717618393, 0.11716167968247207, 0.14394925396528938, 0.21328454717032372, 0.1290376129890642, 0.14053118415176868, 0.07673479856983309, 0.11248148001369931, 0.1435689066326426, 0.17956463559981317, 0.1698993485901625, 0.2518976461743155, 0.12708611891514834, 0.12217661380887994, 0.17201094737937375, 0.1539432539814903, 0.11325991727531919, 0.14812156798378115, 0.16769171301876346, 0.13061652020100625, 0.12602380011230707, 0.14607933079523427, 0.13192280736421386, 0.16921425148123698, 0.10840350206220344, 0.16742148316435276, 0.05384674971742977, 0.17392622847710887, 0.14792526561406352, 0.05476199879100727, 0.14735371805727482, 0.15154895342646107, 0.12793473749151155, 0.2068609458905074, 0.14533317647874355, 0.11363497094040918, 0.10802787383117023, 0.10501301141395684, 0.13683678642396005, 0.11697448609817414, 0.16234881665197112, 0.19418517848657024, 0.14678713475023547, 0.10141558509560362, 0.19818614927991746, 0.1288767192032068, 0.20826418914141195, 0.09619227505379147, 0.17089065104242296, 0.15147694116157873, 0.11124918928309796, 0.18328978409690244, 0.1274272731895889, 0.24091569917096248, 0.236885724288802, 0.13911433517932892, 0.1330261118710041, 0.15847578254197875, 0.18398612737655642, 0.21262523658092947, 0.07687788081145094, 0.1364842174394477, 0.12700154280830778, 0.15736123186446008, 0.2557663748701734], [0.0534574544778274, 0.04445155083592381, 0.05030342452828923, 0.026634207310815974, 0.05005526183653743, 0.045614491457179676, 0.03153186486733537, 0.034238997426244526, 0.03253376231558862, 0.02960164697029658, 0.06299606884919828, 0.054020785741628184, 0.07214323527389957, 0.015486547828561839, 0.06522711606756335, 0.0348044392622767, 0.030121489337855772, 0.059897894370219404, 0.016522212517297557, 0.0759490758120533, 0.06709400339112168, 0.05370692717992971, 0.0785643314462035, 0.07656211469082103, 0.02010138870607461, 0.03797854071543102, 0.02408864077991776, 0.028893094164349382, 0.010982834707735287, 0.04419254416960382, 0.0423140429531134, 0.04919364274809918, 0.06411930696377832, 0.011555417440831663, 0.05381794864191644, 0.12140062802861776, 0.05039732392516829, 0.10744851217755388, 0.05133333015105417, 0.05127345271889241, 0.013274004506397874, 0.04898966034694065, 0.056621282691917116, 0.02150592664557119, 0.08726335941783844, 0.04263522531536799, 0.028186630863215656, 0.03941444995542688, 0.025395297580548835, 0.03350843682945256, 0.05343285539457875, 0.05125235465745773, 0.032544828455654845, 0.019001608203736045, 0.053458097991683794, 0.05811606195845431, 0.03812566790128908, 0.06755758617674151, 0.026493588041874672, 0.03711343592693729, 0.0463587726886955, 0.0886677671223879, 0.04174264095303032, 0.005416243539882764, 0.010363376012162097, 0.022106857504695657, 0.08100684957518693, 0.08075534290964566, 0.04781002666981471, 0.04697911621582124, 0.058708213449966525, 0.05814111303357829, 0.060388209793957016, 0.06693338539691703, 0.046962790882154826, 0.05594859620736492, 0.031081227052416054, 0.06498027487748093, 0.0429049572126279, 0.00411590792223691, 0.028682103973903486, 0.021310622105374936, 0.03716813460473092, 0.023934496228673288, 0.05941717802817303, 0.09752306170881757, 0.039092080156889655, 0.03797060021409585, 0.010741585001890219, 0.025613127020938743, 0.01446461622347875, 0.09357678959326399, 0.042842141833276524, 0.006473398910114362, 0.022576459826180534, 0.06866822980584637, 0.033999817115404916, 0.07839061334849366, 0.06250600240403606, 0.05052580453094937, 0.01075668172204807, 0.04857468967055602, 0.019464024620491172, 0.1024987414899853, 0.012972758624762779, 0.02514530585387782, 0.049870512072717955, 0.019049620849170515, 0.013378562101523482, 0.01727267224792271, 0.037569158650454015, 0.034892711743351915, 0.008582707096432007, 0.05112514958807057, 0.0069503001342978215, 0.0822243394870912, 0.047837552208934105, 0.03127513156693069, 0.0585826056739015, 0.09421055881126274, 0.013762610596454432, 0.03061860187670156, 0.02981518631831052, 0.0673343328338477, 0.13327392599275037, 0.04155443613267234, 0.04521509534829567, 0.04879181047961597, 0.05505051899461016, 0.030393766562244108, 0.020272170771814643, 0.03388704131207159, 0.017336023888821085, 0.05687971862273351, 0.044766776864567114, 0.03110189035895371, 0.07881295762114948, 0.03152547952448649, 0.03349715618476753, 0.00391791656804872, 0.10468719421976036, 0.08207284560006473, 0.0695755383780887, 0.01767050553744118, 0.017418001042378527, 0.01758847475772904, 0.037799854537532214, 0.03147542525473381, 0.020903074820976586, 0.045777197040977984, 0.07666474749003688, 0.0303167000322813, 0.05719908918704718, 0.07236926185507929, 0.0794394183603506, 0.03938982405910089, 0.01581025445052693, 0.007963884253835967, 0.07388964761048555, 0.014358333972913605, 0.01654712952703478, 0.08304713323952691, 0.026357896633506305, 0.03785402461465809, 0.01950130245888666, 0.024637226766395955, 0.020218368416892427, 0.0343732581654143, 0.022368415243803494, 0.012463999634248116, 0.014920439496035538, 0.018248237338998628, 0.01711995836587683, 0.056590198674389434, 0.0658796084744315, 0.01853448992234565, 0.0478408272348104, 0.0233915314123395, 0.01287274871907768, 0.04609029334519179, 0.06859151376110893, 0.03454646298421487, 0.021260360991882703, 0.051358224178153666, 0.014319566093505392, 0.016387497871032646, 0.010379420766126244, 0.0070990830276822375, 0.01485688292661742, 0.06170299670268452, 0.06768719293177128, 0.03261136319187861, 0.02787577536618037, 0.13165954890991413, 0.016899920677045183, 0.0582507363851032, 0.040217915309532996, 0.07818479616675647, 0.02657207566493702, 0.08670380113706475, 0.0343891506594035, 0.021049778743256486, 0.01212011712918719, 0.03608543786310381, 0.022816766286268834, 0.0039559236263871315, 0.015374297753066547, 0.06347626808189577, 0.05833351984620095, 0.048148426858167497, 0.012197954535123803, 0.02710642390734246, 0.007034627262562995, 0.09713216534545345, 0.0741105260808141, 0.007261204469438283, 0.010502152839645503, 0.03819694089132451, 0.03690386874481075, 0.042695397691380595, 0.06700966477153764, 0.09016444245653768, 0.016800679732114077, 0.06515791534536308, 0.07288954280797513, 0.062398658164085886, 0.0330608154857351, 0.02148006160202767, 0.033894702191314394, 0.04471503911660083, 0.007643019339265002, 0.031153365721805926, 0.053051217203779574, 0.06326233419860083, 0.1027909121025474, 0.024142902787594546, 0.022546291283722368, 0.05273951134914833, 0.025198141022795634, 0.04141191696567882, 0.030849690383840955, 0.029831871713301348, 0.0255410113341866, 0.06678369947739186, 0.028580601154375943, 0.03150543866438731, 0.07960283257547887, 0.036533296694077795, 0.03862274405095847, 0.07295056171114407, 0.09599512998735714, 0.04049955221313623, 0.09232374554079387, 0.03563570211671534, 0.06352131022140384, 0.026268042180867448, 0.034880347084254026, 0.10807163277340513, 0.018669474614603866, 0.09763922362077622, 0.028317130110677213, 0.017162503058751746, 0.037273153767830906, 0.05300495698447189, 0.07809400708684999, 0.005688312005311732, 0.03794078790252248, 0.036375635799260876, 0.0398981808534553, 0.08304753160524754, 0.08927939639937493, 0.022096635976565943, 0.029802388819535414, 0.04172845683511227, 0.04145906584697866, 0.02089404072912951, 0.03523458997088094, 0.009332724411280887, 0.04878425685268256, 0.15605211017593262, 0.021314665134395325, 0.044727668076032595, 0.06428022373227343, 0.0737430949905707, 0.031124129891395572, 0.022205158076699705, 0.026517683422313105, 0.028962176142921372, 0.03692869382399706, 0.026930541611246528, 0.04244278785922835, 0.005150698313129045, 0.0632369154012732, 0.08725782826302514, 0.05738133384335426, 0.03298464336342389, 0.024691465791435014, 0.017817471844835148, 0.06270127438549554, 0.06233842833147896, 0.05272151594380698, 0.060414402340088165, 0.016857810739067294, 0.010561738200786134, 0.05705576179729355, 0.021547379663154002, 0.06538479228413875, 0.04952722807384787, 0.039264633800954594, 0.027528927143242572, 0.027051399642181014, 0.0248255675673605, 0.046157624812856804, 0.02172507184197105, 0.031989221273350625, 0.024507321237075715, 0.03342827721949547, 0.06300162681708894, 0.024525027444225647, 0.012530066099228158, 0.018147550403110443, 0.017945058042964628, 0.008798429795030144, 0.02805179364288286, 0.044216790852407296, 0.01681903519877984, 0.08357142083226674, 0.08472467427172008, 0.011568318361476546, 0.040076545274425904, 0.09270095957383033, 0.015868068233342664, 0.056981711738532594, 0.04062221821157202, 0.023997909156605605, 0.011291921499275394, 0.07046377902189571, 0.037385358835660645, 0.030709624613424948, 0.05949584376667777, 0.013635341367203624, 0.03581582470947216, 0.011889819607829616, 0.024556615164563544, 0.03644537278300813, 0.035947626306404995, 0.06131410748968202, 0.04380897160679583, 0.030770155135542158, 0.018963458940326687, 0.09230450141213595, 0.017644071673613884, 0.1155579665435418, 0.11774584470737366, 0.13496595374759168, 0.0684932706456992, 0.1481217365231245, 0.19125339064386584, 0.08436226105738072, 0.15704938811400246, 0.16564947583021658, 0.13192671441262768, 0.16822556904967756, 0.1501736417412758, 0.13913943221972835, 0.12130354936685293, 0.1504167061178915, 0.06815543353197075, 0.19406626631896343, 0.19127044376106034, 0.11443616867425943, 0.1831920772430397, 0.16141121696320274, 0.2573418040429392, 0.2657818559917712, 0.18516591810170682, 0.14146230273669766, 0.1048943980206405, 0.09260088550828158, 0.13613869646383872, 0.13666129100226587, 0.15865158439884264, 0.14028370710870913, 0.15444508753716946, 0.16450449614034546, 0.12258654745716242, 0.16024896965151833, 0.13249018740269447, 0.150802691857661, 0.24878306975287778, 0.14404809462928003, 0.07149675665723701, 0.09096961618671495, 0.16971669790725555, 0.24075229261671346, 0.09065394199663594, 0.1539956390737526, 0.15493967390108496, 0.1892303975839769, 0.11826808684535565, 0.19832982140923702, 0.14772813586938768, 0.2172414985515418, 0.15082809533323013, 0.12634367246421116, 0.12347088105255559, 0.14059066321820984, 0.15514536850875424, 0.1039467012930301, 0.13924283876774773, 0.17127714240022246, 0.18009666834146748, 0.1298035630175183, 0.16068260606017806, 0.11187330579325078, 0.11518616109125077, 0.15785195714523717, 0.15262964301772658, 0.14709067410759388, 0.19360852878420584, 0.2388356325607146, 0.09920210427334232, 0.12815717112032637, 0.13444420190588122, 0.14439104154946344, 0.13854169977768777, 0.15076316172076812, 0.10566666827446992, 0.13242934469974812, 0.13072659171396686, 0.19494662391802958, 0.16987926176478788, 0.12386719365754437, 0.20419531231445653, 0.15688418891401062, 0.24119286978196716, 0.12499987763623077, 0.16440602319855846, 0.1456942796827324, 0.15918724839725804, 0.19506751259248103, 0.1327298197054094, 0.15837795311404815, 0.13426276164189463, 0.1206459624752883, 0.13394288928999057, 0.14637790590284333, 0.14507402425571797, 0.11912414413546363, 0.16409371979534626, 0.1364811071224751, 0.11075309372597164, 0.0934168993825874, 0.11749051526309022, 0.1474343717939431, 0.2610271466114829, 0.12131048246256768, 0.1843424961571732, 0.2888984978199005, 0.12484707373885379, 0.10161548041768613, 0.08507562681071221, 0.23484783847966503, 0.1470917006654124, 0.1994945508457961, 0.18745100516225063, 0.12211428489536048, 0.16203514961225374, 0.10456354762878149, 0.126068600934119, 0.1435154643390448, 0.15373759001733797, 0.1646671366066702, 0.11367412569421916, 0.18613405405513703, 0.1907945346207388, 0.17071933846079534, 0.19422973416024641, 0.08522154357764991, 0.16534032870925244, 0.14231482070059548, 0.1831968729534457, 0.14158833952200028, 0.11002798384476094, 0.11847085499715422, 0.07148557177354252, 0.19426287512385076, 0.10397266401278396, 0.3042483257670557, 0.07940989333174883, 0.1344698811731031, 0.10559143077942634, 0.14520767595498793, 0.1880190593581046, 0.09762945599974164, 0.12449311047431924, 0.17611204586442442, 0.09054615342568967, 0.14076505547329304, 0.15333240611418603, 0.12587399161871404, 0.16032088998584978, 0.29077142957718144, 0.29112165433264553, 0.09159687365735732, 0.11435404404877655, 0.2026223346230484, 0.2049802460016743, 0.15381735509201405, 0.1241216267789564, 0.13594846151048137, 0.23722226671393842, 0.18588403360016886, 0.14563654729675862, 0.1410013782761751, 0.17156433344127672, 0.132748864651207, 0.11492379895982244, 0.15765449032187462, 0.1462779773940002, 0.14042413102522974, 0.1445534368676524, 0.15461093025101771, 0.10043015087684316, 0.09439882491865466, 0.10477625960183722, 0.13846438618436938, 0.10537894863274791], [0.050377206456276684, 0.029918552646713874, 0.0682601041250652, 0.04480880444809314, 0.036004251695328185, 0.01798958498834362, 0.010667280218894444, 0.0018213907981501714, 0.05460994565979608, 0.009770550363276516, 0.10496137708786035, 0.010619231184283573, 0.018395119376720923, 0.03093465528030309, 0.049535329453647144, 0.020196272525936365, 0.03323271412462477, 0.04917480847648075, 0.04001830343998248, 0.04197839685084839, 0.06009588213337045, 0.046040696812973875, 0.018314492453130025, 0.04665241419007221, 0.027929439825276216, 0.11035856610584645, 0.019223942241120725, 0.090360009381848, 0.039260466282646504, 0.07772613932648975, 0.02226127784759287, 0.03129979385243308, 0.008334172852036935, 0.04608084748108541, 0.02367550871455141, 0.010405800046188938, 0.05973494746872495, 0.02741531630407178, 0.061369062806930275, 0.027641057517499696, 0.05100744017850488, 0.12569837362295197, 0.02967648226917992, 0.053892308966286724, 0.03810517504931458, 0.04295726569609777, 0.044783063893837315, 0.04834138525409564, 0.024563937049899853, 0.024262889393515164, 0.04196822320321395, 0.005940251989335183, 0.028289577758480466, 0.05065628845665244, 0.05630457428314033, 0.023179687033858032, 0.04705625743935666, 0.028834716349299398, 0.03934454060189667, 0.054515425731698354, 0.010170953877780949, 0.03620852520989795, 0.003342222799772337, 0.03484266321925867, 0.02242090375793557, 0.034309377923848174, 0.04841984414886083, 0.010895086039278296, 0.009159345307477541, 0.045019624183975884, 0.06222757923927519, 0.030425720089565844, 0.008791046622659891, 0.017702554825753454, 0.01022982198910247, 0.017864662860970826, 0.044249564093808015, 0.05059651061592083, 0.041686819956427625, 0.041499404206631646, 0.0379701980179356, 0.028959992792337175, 0.04120961612751407, 0.0854011222479805, 0.06992144239765984, 0.0178453651061582, 0.04476513360596953, 0.03376482730551112, 0.10091614939512746, 0.02990180213424948, 0.037292053156922904, 0.11477029026155511, 0.034197073264588276, 0.04380984494702951, 0.060678963143859184, 0.0499583249010386, 0.06097029489014418, 0.012576059145372243, 0.05734080013128058, 0.015988405324488638, 0.03531955678256289, 0.010918708360423485, 0.05277550599027065, 0.029206590749503627, 0.03498148984245716, 0.02059596932433065, 0.03816616330896655, 0.057863295078277595, 0.03214693387910243, 0.04435711134705813, 0.03165347749487527, 0.0459484406746924, 0.04562625856769662, 0.01052194089072967, 0.04916743488020955, 0.015301868927875354, 0.01809105333391457, 0.03842117865720103, 0.044669135128177946, 0.02408328774054685, 0.05864820961329726, 0.14784706335875297, 0.04561376750409123, 0.04422315704305807, 0.061635370291168654, 0.11336276457915384, 0.0197474331024193, 0.022749777642949935, 0.04119961868010221, 0.01950799232168544, 0.004972933355959193, 0.026169756930621884, 0.07507265590491795, 0.0635651151289142, 0.02033440583956338, 0.026914666354235624, 0.0054411270332732995, 0.033594368911919095, 0.049559698710518504, 0.03810130630529696, 0.046352743576731414, 0.04287139107022555, 0.0813859788280341, 0.006514613482830746, 0.07007742555992258, 0.04104270089057185, 0.007508035604616688, 0.05302899682353582, 0.09380213435619109, 0.03389814192609441, 0.030562064587889664, 0.049069996157120314, 0.045505955950507236, 0.026083190910398, 0.03599022079499499, 0.0614353945298541, 0.036666427453559254, 0.0396053820487953, 0.09029224124406615, 0.021377769711938117, 0.10850086417650023, 0.09149016527038428, 0.04476973396395484, 0.019099878132223122, 0.08699529759225347, 0.050832074991757834, 0.06983009407356863, 0.0324299727236071, 0.010532785822907764, 0.023556242231279615, 0.05017469877437238, 0.1520062313084641, 0.04023720540346638, 0.04666338839958753, 0.024190204886479244, 0.06437016245458396, 0.02214492058321353, 0.045099006214689825, 0.023549745805681716, 0.048923259676103635, 0.032960906129090056, 0.017343918424880794, 0.06040522077631566, 0.03856759338128952, 0.0785637415585018, 0.055146977125156316, 0.07921381312752925, 0.01917336511635973, 0.018470127045387225, 0.047313781725543166, 0.06912148572624692, 0.006458344803597298, 0.05382064910184953, 0.04340297182000453, 0.004305582194994655, 0.017474944357790293, 0.02802199665306797, 0.05276581114758888, 0.02617682217650356, 0.046028554319374027, 0.04126172159768401, 0.06138324309440871, 0.014502160277427926, 0.008824463377917006, 0.04877349331734642, 0.04477839458793883, 0.07529281425259768, 0.029894470672814116, 0.005118628436203806, 0.05319256425624894, 0.010658750787467487, 0.034898108832778475, 0.026466638983918295, 0.04099893045701808, 0.02325733196020367, 0.02159200619996315, 0.04573327338983936, 0.017521129883525353, 0.0729827297430846, 0.047346838419475866, 0.05157290116673516, 0.022026253563742486, 0.01504823158029467, 0.027786738712400682, 0.07034955531238549, 0.009067262496588933, 0.005805319008011852, 0.013042766612113245, 0.026692361045148105, 0.06731875826634708, 0.05401397905042095, 0.02441908706039671, 0.040739701625200055, 0.07225761220099465, 0.03690642364803822, 0.08413628044147646, 0.04473824008938767, 0.049352908597117474, 0.015128397893521096, 0.006763051008625377, 0.061371361070703116, 0.019855556836832437, 0.011948919460748234, 0.0388041383496696, 0.056031245603075916, 0.05425919996454351, 0.06179436034853421, 0.07037834489657994, 0.02050591760405129, 0.05369068611593497, 0.0025380995676612425, 0.024004913115453337, 0.04423879289759263, 0.03198602860192618, 0.017994283022539272, 0.054118768387143655, 0.05593327444887931, 0.05209929933170638, 0.01234037315307726, 0.042769934215973464, 0.019701393133389856, 0.033978424110119386, 0.047783834123683554, 0.01011945840512072, 0.031738293004192175, 0.012136438632413987, 0.09973327899652143, 0.03189759332716706, 0.07764084309700035, 0.012578383264612528, 0.01457494916394353, 0.06747017554458111, 0.020379955512321284, 0.0084497831806901, 0.051280320697133584, 0.040134756465352354, 0.036312766793754794, 0.021130434395144546, 0.022989235660662095, 0.024591410878084363, 0.034429787793346954, 0.009140376970472356, 0.01563584208563571, 0.01700848682723459, 0.06532044855937844, 0.06518880401047007, 0.08739852797119849, 0.03362200170334789, 0.06217743495419141, 0.06726171535950515, 0.044762617007138274, 0.048936964989069014, 0.02062958717766789, 0.07651662438987725, 0.0416457767958843, 0.0543957359848484, 0.029964908627012087, 0.057450810357207255, 0.030746869893083652, 0.03649772723175345, 0.038294609440791036, 0.06801221339452652, 0.028329431567521348, 0.059986745247677456, 0.01919349982222963, 0.056796015856126626, 0.019735068443321416, 0.02620221990641327, 0.027590796404007464, 0.029796357792351517, 0.08925672019681624, 0.07400531922617266, 0.03154063657406838, 0.029581548653603084, 0.024364779087444468, 0.046357868704944856, 0.0225873708334421, 0.0616333018537731, 0.039762855252070774, 0.03736619897667439, 0.030863889823517496, 0.02198024615344982, 0.026363441194858284, 0.031178861127925978, 0.08078032503685645, 0.025010225400629065, 0.010118041142460801, 0.07480503074944982, 0.039622538587859565, 0.04637477626543372, 0.018093478002194918, 0.0390308084447057, 0.0328808767540801, 0.012767089872560915, 0.03554770925773248, 0.01841310903640284, 0.10617481439464516, 0.02720976150744865, 0.033016324929532506, 0.016129600116983056, 0.05271105884364056, 0.03792403355961846, 0.024587611081979932, 0.03455953627464271, 0.08026474786381568, 0.07349528086882445, 0.04386187380840702, 0.05472591604977366, 0.055360485829653285, 0.04387751732382082, 0.05455204090403934, 0.04186629520488843, 0.2583337346872976, 0.1351210559087415, 0.13722104080502065, 0.2396333292727509, 0.14001421269870576, 0.11247270064608705, 0.18592226138759047, 0.15659134414407516, 0.30238725305084263, 0.12801089429206428, 0.21653818387177684, 0.13114263874388513, 0.1042433305373115, 0.1288891757928556, 0.2294560657033036, 0.13885674577566887, 0.15994956716895103, 0.10532288631844906, 0.10590214071975601, 0.15085306979956167, 0.13843460068587335, 0.11975202213732467, 0.19987682872001203, 0.11066457226632104, 0.1511976714696615, 0.2828933490860847, 0.12429552873776806, 0.1653251448465932, 0.1934690854602283, 0.131833772625654, 0.185622475861061, 0.13044533019344653, 0.116593211799139, 0.15112297789704415, 0.10832389020511221, 0.11837772168819943, 0.22259588623719834, 0.20055613420423002, 0.09641286241070879, 0.13961154156394545, 0.20634305513193532, 0.19939673673962394, 0.10753825937788333, 0.13883037702931514, 0.11276228954234432, 0.12782169355740472, 0.12580732664754316, 0.1654649405710159, 0.1153959389475565, 0.07774831757189767, 0.14413535204385558, 0.09165624547148905, 0.10256302392771167, 0.13733325736416926, 0.15127025063960783, 0.12862424726688093, 0.15528865759411167, 0.14952294198015045, 0.13268933961949042, 0.13688023893102524, 0.14986835570345003, 0.10413973246731105, 0.0816631724216765, 0.1053812545574, 0.16291216706797002, 0.11979527546152954, 0.16196028750029304, 0.11289448567455816, 0.11421570389140999, 0.22294649403662453, 0.16376166664544614, 0.17251710167094586, 0.07382732635784535, 0.08758254229061066, 0.10735201574261151, 0.12299486465992467, 0.141764861501513, 0.08311661741425914, 0.128287183901956, 0.16700831662502982, 0.24129287489960272, 0.1160366795656662, 0.10995276933235508, 0.18926824232743633, 0.22993837933867212, 0.12526583272002398, 0.16945795937170907, 0.1503229216342011, 0.16871350577041028, 0.08212512344001763, 0.13427561659726406, 0.17291166759546728, 0.17720735241328517, 0.20187516907049766, 0.14702892742089688, 0.17493706617143848, 0.09526864114788272, 0.1525986164567932, 0.10937303229565583, 0.11558723110224932, 0.08515069576641245, 0.09321949384625881, 0.11588730008131075, 0.22623204596100316, 0.14517337053773866, 0.16517784146051254, 0.14054763972038223, 0.12579388946535128, 0.11593561724669511, 0.15387591485294605, 0.1793595232189663, 0.21618999691019136, 0.2152221520701724, 0.14580093444355074, 0.16917948641123312, 0.050444683480647304, 0.12661265359530527, 0.18591852287851995, 0.10541190573525046, 0.11419373248974163, 0.14247667975723743, 0.19999391759835905, 0.1383824913852638, 0.09469907775881792, 0.09366178704846291, 0.2390465518880275, 0.09662956570185001, 0.2607715796799429, 0.16963282660130533, 0.1565474166624969, 0.1408775325023359, 0.04572106194832633, 0.16130512910744838, 0.15817349956881616, 0.1908134110271931, 0.11102388282456707, 0.0944131124584425, 0.1142669092082689, 0.15381884130258716, 0.15243681868718517, 0.12000784953875888, 0.10183104223782018, 0.10220539110201983, 0.06293678513517784, 0.10411052153475824, 0.18361921722610153, 0.14270534168087667, 0.20123229872795845, 0.20446946453903952, 0.10612496505341223, 0.07950799855133218, 0.14343015278779692, 0.21670914405295927, 0.127468986677066, 0.13147806268065207, 0.09676337061870484, 0.13661785381695918, 0.08548130867101493, 0.17278589128005892, 0.11894353890731452, 0.20003622097353782, 0.11627728480004496, 0.17679810824413456, 0.1328754683415736, 0.16352834690722728, 0.09118430466661531, 0.15868254967274206, 0.193162803508101, 0.13642420211145956, 0.0937434673429497, 0.17952323620838506, 0.27585039636300457, 0.1117869753450636, 0.1730753959066445, 0.1790886804942162, 0.0884244192932402], [0.07242233642647344, 0.022747500446595015, 0.019304902412958683, 0.014395708529909533, 0.031129789365936193, 0.042554406869796016, 0.05838910718598674, 0.035347672209383986, 0.019122542843462962, 0.05979495896627346, 0.04995822914004807, 0.0065942478437547485, 0.0515018924770336, 0.06778994830505503, 0.11038141850862773, 0.03382892205169605, 0.04581256732044201, 0.05517969674040234, 0.046579474958801464, 0.05763384791451597, 0.08472517222887085, 0.05275562217819595, 0.025536684852634228, 0.05217067191317197, 0.03371644119221357, 0.02977025526155147, 0.008562564729682861, 0.10731482983476694, 0.05390585723122763, 0.022767995213789326, 0.03745332232586319, 0.04456016295138867, 0.02948790206573904, 0.031282120204019936, 0.015894967495583962, 0.06110792641618079, 0.03175777653532644, 0.01730490156689719, 0.03325208082735058, 0.013837963962296565, 0.006915859215246935, 0.03907011641610054, 0.014288706156695563, 0.06778902899954589, 0.02320311783302215, 0.07337436155085603, 0.09652682565032475, 0.049226645815877185, 0.0552311280531989, 0.06252283335573251, 0.03254818009032357, 0.027002444708599683, 0.06894787488084647, 0.05776517070649613, 0.06027929124332244, 0.02250164559471511, 0.06064565747135109, 0.050672123494047316, 0.0406510652523608, 0.05257370693969631, 0.01373191441093842, 0.09719218833432083, 0.01462407359447811, 0.02224967161554002, 0.0724232250884656, 0.07519263293473952, 0.08695210555508252, 0.015278454408079628, 0.06335934008201284, 0.027050805924039696, 0.03536212445807553, 0.026225587503323634, 0.031921219478751865, 0.06562405686465002, 0.048213808632065216, 0.02604432343955963, 0.05896640040220753, 0.03685674667658825, 0.027224931963569215, 0.041514411869068304, 0.06628525969121726, 0.03133570613910354, 0.03831841179259843, 0.026685527540863525, 0.05405653906505435, 0.10708259794140056, 0.036803737222667665, 0.03363272693428782, 0.06333031301056186, 0.018895279030285535, 0.058807866167156934, 0.02597324963238451, 0.0017549175883628308, 0.03222160446908205, 0.016429002599550352, 0.07977739336990541, 0.05004231112017747, 0.045266162769328204, 0.03608528847595857, 0.03293402410382706, 0.04031639591219925, 0.07441788821691468, 0.003428104847121323, 0.029413497691313108, 0.05791187271355622, 0.02251291474808128, 0.01504924281635472, 0.032438675482426925, 0.03502675031702365, 0.053532262963633385, 0.04751121024450949, 0.018954357815786235, 0.07750116994664555, 0.02164749394831879, 0.04509607209793983, 0.026231329332316117, 0.0029129708080642648, 0.034968562108734925, 0.017599159769052942, 0.090158520596883, 0.04524414923282401, 0.016578694264734947, 0.08847819866552468, 0.04936245022221439, 0.019964732026921648, 0.06595265495801164, 0.07293160103501813, 0.025104256947675062, 0.0060115742962807426, 0.022546308520700664, 0.09847537028573214, 0.0341340970067728, 0.012158147648968285, 0.041134891911379756, 0.050221908942706166, 0.030294242164781018, 0.027766569532574188, 0.059801003399996035, 0.013072773318497405, 0.043869442757098906, 0.027455095419540044, 0.01747028845843048, 0.020125520475689444, 0.031332302793499925, 0.04811163165516431, 0.09453760940701732, 0.040711938598824125, 0.008771179089953583, 0.03517156008691077, 0.014262655336830406, 0.03417831943220189, 0.07164736954315055, 0.056673330705492735, 0.017283137008968382, 0.039490668043013544, 0.04561897690197633, 0.06898051022642082, 0.08451804503678315, 0.045647732012214205, 0.03772296995345143, 0.06313130252003189, 0.07704874906208246, 0.03400238734039088, 0.06643987155609554, 0.024874725514241768, 0.030315043367145043, 0.07333871547973926, 0.010577877758130913, 0.05310216588118384, 0.02892147197628454, 0.040041079233971336, 0.07870492390206746, 0.04448558812239959, 0.055479715923748674, 0.020137289501426202, 0.006400886294056452, 0.06149154494426424, 0.038468913595762946, 0.03280060989181361, 0.026625952713431853, 0.053672487697293686, 0.08634947781120578, 0.04303633363076276, 0.04570456807531657, 0.022714974268549876, 0.0007731782475715474, 0.0369206115963959, 0.01892159798092419, 0.026093709297598373, 0.04636899996248465, 0.0379720940855482, 0.08243225574974092, 0.06327823435346927, 0.11094360447098171, 0.02726765860232615, 0.054258142763208, 0.06271752694080915, 0.04438235011372355, 0.05352622619079006, 0.018377175682314464, 0.0016083168485502323, 0.057069739071472045, 0.002327620501502327, 0.07657712235325768, 0.09279701933865586, 0.018043697608875173, 0.06580732807877564, 0.021830707705850085, 0.016088311808303963, 0.05956380725688031, 0.031059994925594622, 0.11436591075072366, 0.06774188394868566, 0.041783779874564185, 0.02800577282605152, 0.05732148705470947, 0.04252734098343119, 0.05502162981898554, 0.04684432304554409, 0.03733240683833438, 0.04932502299667366, 0.05359000301048641, 0.024014311099064448, 0.021532770366437977, 0.015196534711116505, 0.019991271227838534, 0.017819078714256326, 0.11901767323574713, 0.08917677126103833, 0.0681242460925733, 0.034660456867347804, 0.043575038998237545, 0.06221113516198051, 0.06763696054657621, 0.04423690066041966, 0.051018184561642914, 0.019509920948034814, 0.02842186773646503, 0.07799749533014913, 0.03988637926898176, 0.03354070445282325, 0.10963569320137463, 0.0898579536606708, 0.08626984297147683, 0.05380071549405975, 0.03739921736621088, 0.012741394325970642, 0.10591242161969985, 0.021643200025503195, 0.02697040499638646, 0.037777699274762024, 0.008028136526850324, 0.021746064566316146, 0.060068379576888785, 0.11696538497363368, 0.03797872074609322, 0.08435051692950149, 0.02173793828865934, 0.0058927866179616225, 0.01628933327963516, 0.041507091898951805, 0.037413382331930825, 0.019274255065547845, 0.031132579841200384, 0.047977041498187094, 0.014645578640122569, 0.028508583143834147, 0.050352875503801534, 0.02036218801813741, 0.06959996126111477, 0.023532426472933545, 0.06062308469066217, 0.023417325592750025, 0.01528280578748954, 0.031693835006726366, 0.011737456211009094, 0.050325920700185725, 0.032952885188522844, 0.004041466679829624, 0.023995869447507208, 0.014982982914173796, 0.0457437151682473, 0.040592402069559025, 0.11005751653424195, 0.021011326875117038, 0.04506694926549831, 0.05500829222822382, 0.07116153190333037, 0.05272462626077956, 0.03504279219815808, 0.09156950133582277, 0.03335215489289934, 0.05144935416718645, 0.05001396969741872, 0.014489735288906002, 0.024934371204806433, 0.04130397134670808, 0.07749751570724672, 0.00886696114790656, 0.025608459630260066, 0.022192096277590723, 0.05033168168137631, 0.03674919942333814, 0.015383872894510148, 0.032732244205450824, 0.054596677016947544, 0.049002852380996754, 0.027878650111116232, 0.048653190700157035, 0.02192719073425378, 0.04684252656936165, 0.03680580949050285, 0.07094806916410885, 0.01715246156128424, 0.09189252230909564, 0.019806079048242782, 0.031223238686159737, 0.047385797820865154, 0.08098467899065825, 0.03788079172673245, 0.07665712491519029, 0.031067515993791244, 0.0290950502629482, 0.05173867493267021, 0.03080798838768275, 0.03628902955942097, 0.0515513587743044, 0.030054062109200225, 0.09994119525917115, 0.06477425085200418, 0.018197348033408486, 0.030000840065880652, 0.003172181924099043, 0.0420074813788937, 0.06380216954576393, 0.04627853646994599, 0.030602684484854824, 0.06553212631373637, 0.044069012491813594, 0.020102057117788542, 0.012912702119548716, 0.030196004795030724, 0.07210011218464182, 0.05195310294267632, 0.05675297320610093, 0.07333997952481432, 0.047306710734002055, 0.028811113180352316, 0.05398221321464066, 0.03543965255601272, 0.022929383126357873, 0.011372841451497329, 0.1488202708142419, 0.09815442541073408, 0.14798131260660388, 0.10134489050195103, 0.13717558114759384, 0.1499382229221444, 0.10164931086042236, 0.12657703816770546, 0.136243267465503, 0.20877708500671774, 0.16340937345258652, 0.1264254676718866, 0.1485515731356798, 0.1541831467540995, 0.13163999834608647, 0.17812484995492045, 0.09973999758761737, 0.16978435879272802, 0.1166648563418177, 0.17193260722823683, 0.17308949192445125, 0.1278756184863948, 0.20929986340624673, 0.10539745731699852, 0.15180854998048277, 0.1485759194099134, 0.1466401684428415, 0.1421701833004913, 0.285551643539821, 0.08009871362798637, 0.19505470360238708, 0.11272927115280783, 0.09372001739158746, 0.1395926498357327, 0.11113165607375484, 0.14001431995101515, 0.08911766757768008, 0.12670115207231816, 0.1436901936728147, 0.2038011753991727, 0.12179943808023969, 0.13860082644368374, 0.17032495639737577, 0.23014294013621348, 0.255913770186805, 0.12457196390436542, 0.1445688965219644, 0.09821935136231685, 0.1603810432096643, 0.17121807702126043, 0.17285238771188646, 0.24924158869731813, 0.17135522208146511, 0.1527431312828295, 0.11054480974111827, 0.08398995764793889, 0.12181961683616524, 0.15670530738369112, 0.09793999740072797, 0.19355183827780909, 0.1382618478589481, 0.14474460644827736, 0.18693066292232086, 0.17031452227984706, 0.12212156273064115, 0.21040160509367145, 0.33050491684867495, 0.14238327831750916, 0.29182902927840915, 0.11639500953136914, 0.13487416109250439, 0.20135700252027283, 0.10825206180133166, 0.1335679658598477, 0.10659475315121875, 0.05889575943470963, 0.10436176773040526, 0.14900958646209012, 0.15025354471177826, 0.1863285178138364, 0.13440712325034604, 0.1481521961789939, 0.11728579358708476, 0.09600620761874223, 0.1866672972157117, 0.24189612317469814, 0.1354547638085581, 0.07798824864890307, 0.15126727821846164, 0.16687777524273242, 0.1638319935168951, 0.16762625846651294, 0.12018291595121545, 0.12019531891470957, 0.054538228338764566, 0.154947595250222, 0.12140089615939126, 0.13446791998801694, 0.13808037695144454, 0.11512835975736381, 0.189588007427031, 0.18184817516274993, 0.14473061768278, 0.2267335884032711, 0.10844222780677581, 0.13580468212885244, 0.08108730412899487, 0.15360389235279254, 0.1176438017958595, 0.13629888544880575, 0.18935971322559542, 0.25387271277366147, 0.19702335038492758, 0.07878412207167956, 0.19265934584602235, 0.10888250619773904, 0.14472822748845623, 0.14473331431227346, 0.12575561571265423, 0.1782552227978745, 0.08839025943269653, 0.17026852636087328, 0.229339589695296, 0.12518127959582115, 0.08157363972596585, 0.1311019747968643, 0.1302156110684718, 0.23488405911672502, 0.1567452512080631, 0.11672351569417985, 0.11666026747515125, 0.14896952006365025, 0.12113332463007782, 0.16918671828123832, 0.11079275409781164, 0.1368189672188413, 0.25154878505535666, 0.1625124836761144, 0.19209153679830415, 0.11912857978454522, 0.17287293419001565, 0.12438116204594413, 0.1674033575240643, 0.179688312834309, 0.2730183531680415, 0.17649936459718213, 0.2101208798346981, 0.1281642804162637, 0.09928546996126253, 0.16295420997325452, 0.16068899523346655, 0.10920566506683828, 0.2031842907590251, 0.20217159913191873, 0.12337236980637237, 0.1428665419019038, 0.13522374233411205, 0.18157694939403765, 0.25525689575700994, 0.1359803767334069, 0.14719567411849577, 0.14629046462716597, 0.11659616889852671, 0.13215042740827607, 0.07277721899651712, 0.06427778757267422, 0.2081095466330167, 0.14778638919514997, 0.1865233339729809, 0.25335597114697583, 0.14879970901435421, 0.12257826604670095, 0.18678009600168277, 0.2501665019700604, 0.09541853391114744, 0.13636988647762807], [0.027424894318345095, 0.02322554505700546, 0.03673951607197523, 0.013781338573373375, 0.01508091193353457, 0.014605042055219173, 0.04363820294759447, 0.045332862214455684, 0.05517799602521043, 0.024583259702570016, 0.010160372288326823, 0.0374864709503468, 0.04190026737389065, 0.02991662593558431, 0.02189974563436643, 0.032930706943114924, 0.043269339272932666, 0.0031740286748015113, 0.05212133585084831, 0.06085767613483533, 0.03291810862720013, 0.015877750627095663, 0.018233402046344934, 0.044355318701315316, 0.07240936655791537, 0.026300916928918134, 0.021947133918142608, 0.020130103596696453, 0.027781889375839985, 0.05298345672687697, 0.04801328128744518, 0.035070899964099934, 0.07435631773044026, 0.033089938318176616, 0.04628996267133663, 0.02529433676822772, 0.037833041466412046, 0.040542974076684446, 0.038820547953007684, 0.04268973247118054, 0.030689815494922862, 0.04633343816103955, 0.06932354141627589, 0.019958017266265327, 0.07807257960760787, 0.062124310587082184, 0.014978641110862938, 0.04792852131950279, 0.02971187744650149, 0.06315774021429882, 0.06238407568044721, 0.050847205228262374, 0.012603777164082616, 0.05536051647317025, 0.026115602175254497, 0.023127139147911823, 0.06858878648809849, 0.04121000300191584, 0.04005105369874547, 0.005744769333696534, 0.0681521316930171, 0.05104999253225904, 0.008698032057333377, 0.05930869614765529, 0.041757763528655616, 0.02267844336588056, 0.01900243366347446, 0.0447640534219963, 0.06289988267986525, 0.0551652291699523, 0.010434991826543645, 0.04564419651644365, 0.05353586357687751, 0.037474462522133704, 0.03436802195445184, 0.08160026128133459, 0.032330817963567474, 0.06237586321789892, 0.05222679934494438, 0.020010057618961703, 0.06121792898122823, 0.06919792597933162, 0.020872806687088265, 0.05035723071365107, 0.0444519798451614, 0.013962312481336057, 0.029754514069927317, 0.058520793869730935, 0.09440843166122515, 0.08790486612387242, 0.04716641705242857, 0.048496368671617204, 0.016788761319232084, 0.023067882246968728, 0.07345365165101905, 0.07478942553843222, 0.005267640677160554, 0.05520474015464706, 0.05609216108437508, 0.0388439595999737, 0.07839055206145971, 0.056410738747687116, 0.05979448016132078, 0.09792498973829132, 0.0703549255887347, 0.08263430377889065, 0.026482474021313172, 0.04328627747693851, 0.022394176865477237, 0.018718230365324887, 0.028325896071750793, 0.05202039610594512, 0.04809437169423027, 0.028880903790254268, 0.04750254579008587, 0.10411927791973276, 0.031966907047336145, 0.012815442469511783, 0.00858931364716902, 0.014709650403669765, 0.009690492259969395, 0.007987082832598039, 0.010937339618741986, 0.031042713897242665, 0.0033614391577430074, 0.032160252317666047, 0.053269671005827766, 0.0661848638687403, 0.04630194045603276, 0.0035015772277068712, 0.03807100752789167, 0.039106383018435976, 0.008134140591737966, 0.05149449589812467, 0.03956558761156855, 0.027363105496812253, 0.040865903119406397, 0.08975657724565075, 0.028270720504224304, 0.12080877914183563, 0.046395069934547915, 0.03393940342169616, 0.08570457733566723, 0.006773491829423415, 0.02635930048962755, 0.015989136938456328, 0.006474541817536398, 0.050924813765431606, 0.040256736815095916, 0.07697135119909242, 0.035616530766410213, 0.039591806970777056, 0.034113389650179494, 0.03319899859507719, 0.016213741468926592, 0.04435306640281793, 0.03236681643512941, 0.06620618409567303, 0.05963160220773951, 0.11559486133797515, 0.0671286229044199, 0.033979090606613506, 0.05557874044884117, 0.012087470292293978, 0.019045200521847414, 0.02945423250146691, 0.06371732913858949, 0.016906397950444973, 0.03350770904592449, 0.1107392351954214, 0.030249131077359763, 0.05640730667378634, 0.06314487759805014, 0.12497862635721123, 0.015461426847914775, 0.033286263670531974, 0.05939904855744493, 0.08298934722739844, 0.031581865510933345, 0.04804109027909656, 0.014477728775912716, 0.059744194149971015, 0.018939340577250528, 0.010804653190256608, 0.08093865242816749, 0.007044634286073909, 0.032201303139088616, 0.11148483026772739, 0.054556978340711326, 0.07162224185923416, 0.022370594763948072, 0.028095326589180097, 0.02900360234742684, 0.03773872838205388, 0.03265461651608348, 0.03619750503510718, 0.08575333883204768, 0.032574571819315036, 0.04147248387697243, 0.06000389029542285, 0.04109970166257793, 0.07950801387309067, 0.01992278296740786, 0.04330904561004812, 0.06244293038523006, 0.047456963558591185, 0.023337185134991043, 0.06280766484598, 0.07483576619697195, 0.09648243851599195, 0.026570189173423478, 0.02460307073629191, 0.031167354487303286, 0.03289615254729025, 0.029962439908676093, 0.04281529428197011, 0.04360323103385107, 0.03056864145271961, 0.042688334360718734, 0.03289936628613261, 0.03389973538897691, 0.04023096561732312, 0.01362065450408526, 0.04200323725179319, 0.015092388888250197, 0.024462233132292188, 0.05014884330692792, 0.04581307676891166, 0.02861292240390134, 0.01715481536643159, 0.0496980082243681, 0.021736517195559798, 0.04966263411446445, 0.06339672517271773, 0.008397728463845148, 0.03677265703557961, 0.07479720133086366, 0.020549904457443667, 0.062361977874271335, 0.042132311575715585, 0.020535538393643596, 0.07889197192965977, 0.024462830680873127, 0.007866752444721398, 0.06840499433418436, 0.06698017038645283, 0.09981887400030129, 0.05711473524570466, 0.06251216941182652, 0.04208998521789909, 0.018291676439525142, 0.07507240309590295, 0.017870883494915984, 0.05162504494130131, 0.051903816676067735, 0.04614975708987444, 0.027957947872158502, 0.03384387991841763, 0.05512182645860219, 0.048890317895359574, 0.006190819718364266, 0.07261085534288038, 0.04731666221613846, 0.04437946196224901, 0.02130640479135177, 0.06866374053061008, 0.06385226403513262, 0.02767390928291265, 0.012868000889166951, 0.04255113950479896, 0.1078438135464826, 0.041140898040706114, 0.037050743121653795, 0.017738118542418364, 0.0606565052763589, 0.03275245743533296, 0.02801057619733676, 0.02418005805192215, 0.054744125959733804, 0.0458003060832139, 0.046474857991861726, 0.05533449629682207, 0.022276013548816406, 0.11027251144931202, 0.007400633908072187, 0.04520392961679928, 0.028991000201072425, 0.00885566613907295, 0.09448562268047564, 0.08924529782586521, 0.04272730142298726, 0.04517148196276638, 0.009542426616404085, 0.046794653734973365, 0.05042748097630759, 0.01190190272961533, 0.02543187827893323, 0.04024339539389457, 0.04597953235309932, 0.023192773730824554, 0.03211909232871427, 0.04743095104312224, 0.037878102758118225, 0.03696784474736741, 0.06122982249625268, 0.026230731783735178, 0.10086536542662691, 0.032362614442864736, 0.028214455176625523, 0.01145983839617862, 0.11740648307867589, 0.02102848149896149, 0.020872944582914634, 0.07487438468923492, 0.0170039247736455, 0.02178424255802266, 0.025524410208867445, 0.026022072415798906, 0.08579870655892358, 0.04304618552146901, 0.0778319207470744, 0.046435201450461344, 0.003741714190841923, 0.046985907585269986, 0.013364737087319936, 0.07568436179069743, 0.044826190813534686, 0.0865827362623907, 0.09535257374086688, 0.027851614868268374, 0.03291385683922037, 0.027369588515871478, 0.030030960727843548, 0.04059162449031588, 0.04712381490295933, 0.04755252919670555, 0.044038602631659284, 0.06230455958434652, 0.025629140173776016, 0.02735348151726348, 0.038258358160214084, 0.053293672540495475, 0.032568469928998145, 0.05514795388725977, 0.02271627278758153, 0.06488683513335644, 0.020517098657306165, 0.024175869466196147, 0.037975173759003805, 0.013016268588422288, 0.0406287835850831, 0.0396900347644283, 0.14608055653591312, 0.17190426197503844, 0.11804556894686916, 0.10479620087050623, 0.10078199207782747, 0.1452000457192621, 0.12181820723438457, 0.10078494917721519, 0.28106252152112227, 0.14652482624496185, 0.09387677430265373, 0.36112070143703495, 0.15747056793301337, 0.2521332335327902, 0.08763901829238861, 0.1664557680487633, 0.0750041370009703, 0.10501857321228712, 0.19372727241246931, 0.15543505699644167, 0.2094322280778039, 0.18108227109957128, 0.08847314248522443, 0.1474553166377929, 0.10162666530138063, 0.19295473402786642, 0.12485838885749541, 0.12391612369326815, 0.12030519124480987, 0.18945593386888507, 0.13153748046005928, 0.11526041033287203, 0.18349164826495035, 0.24264524991233505, 0.177654211499518, 0.12385548783406136, 0.1943783705393153, 0.19534362600215022, 0.09711399373988952, 0.19331263498433177, 0.1470712767613511, 0.09163523167972604, 0.11577387310324178, 0.0991746093777399, 0.23572419709976644, 0.1583470031619072, 0.18083025881599996, 0.20879210033003362, 0.0827908232027004, 0.09952752310181819, 0.14230069403927173, 0.17472574847840494, 0.11150446510122669, 0.1287814331871848, 0.13780936568735108, 0.1404196111064765, 0.152557845257463, 0.23259082088066688, 0.12465860844860155, 0.13978446293021404, 0.2598573609946236, 0.16391482294326828, 0.13623447277613226, 0.15756347907647011, 0.12332407562362573, 0.12072393490422158, 0.13753783348346912, 0.18475010089816588, 0.1350962653035118, 0.153495843311952, 0.2137387760223881, 0.15583218165463017, 0.1752616729467146, 0.0966055105410276, 0.12769214042852964, 0.1965389989556805, 0.10839070839386795, 0.12212104945173188, 0.17636994170325418, 0.113760256959546, 0.0918302853261271, 0.10642630573842796, 0.19258825288664913, 0.21485337266518226, 0.1770966833517436, 0.16310784124558972, 0.1941695809364319, 0.19490386089009626, 0.17148007909136434, 0.15194967869789372, 0.1553291989670646, 0.09861993107704387, 0.0932034366433659, 0.16122387782219919, 0.14812455572668584, 0.19708627684702798, 0.09516511202579546, 0.18788698579995863, 0.13768450867745186, 0.13365255728844674, 0.13821697042834374, 0.11076665348223141, 0.16080997583846893, 0.2110141843196846, 0.13338307820020184, 0.10143644566978179, 0.263459904780311, 0.1420777624533061, 0.07321113885770883, 0.07760333543222758, 0.1344781855662023, 0.2329704634124233, 0.20025169086312095, 0.18267925798652634, 0.16085591047040879, 0.22561434926765583, 0.16586626339102947, 0.17389152469413896, 0.19193755312552377, 0.10750350962963798, 0.09292561485762559, 0.1716377399861813, 0.11211785638043958, 0.22373007940909556, 0.1422990239675968, 0.10045541645658594, 0.14077395741497317, 0.14618846768092725, 0.15135766127176825, 0.10561776122138386, 0.23934399318550867, 0.13409333363656076, 0.16310048680151665, 0.17151211688835777, 0.2559558437356065, 0.17452676480095233, 0.10622957435947274, 0.13894798684745066, 0.10902790968576748, 0.18831784897033246, 0.15426700273829122, 0.1756223011761904, 0.24933571025969523, 0.09914882285820861, 0.19911446398304355, 0.13148927820786355, 0.11502381939921649, 0.1722347982708485, 0.1264164508170178, 0.1870027824395126, 0.1818004019197918, 0.27089267368278197, 0.12271924920740629, 0.1679429592144105, 0.1217277782158025, 0.11217587221894534, 0.15662682933672784, 0.1434802396162864, 0.2962692442440218, 0.1386312094907607, 0.18396915086815435, 0.10824476098341328, 0.15429956147507315, 0.0944031073501514, 0.11453461097252947, 0.08922928658824775, 0.10249987530011324, 0.11939716254991871, 0.14431702213421946, 0.2159979999546082, 0.14252489733119167, 0.12275919303177826, 0.13915509105690066, 0.13770614300043355, 0.14169326292410975, 0.12981540673682768], [0.037331935694260944, 0.019488095103072065, 0.08279525885178197, 0.03658082478890016, 0.06720327817264103, 0.05174433632243065, 0.02877500745648098, 0.03484026536405568, 0.040169138491394064, 0.07106376376243369, 0.03129158905076404, 0.01925149650853728, 0.05675943898818186, 0.03457697243579934, 0.02382809236165016, 0.04143822442499861, 0.02138175911480381, 0.03539674780181339, 0.03692845633674053, 0.051756716303287015, 0.03212428640484089, 0.017961542339875333, 0.10761365009051178, 0.02717053780572549, 0.04174930591797156, 0.040516390825711915, 0.03924051735309824, 0.044749367516487844, 0.04021316173396284, 0.05975399624496218, 0.03759117984783746, 0.033639970295611894, 0.06596252217047638, 0.04396744072437287, 0.0495196629555956, 0.05744868446321738, 0.06456746073860316, 0.025193040792439735, 0.04888396319602767, 0.047557098911173885, 0.06067818173417642, 0.07558624124935559, 0.03374720728325267, 0.006618970937486137, 0.0681534723468846, 0.03208698749902748, 0.07279573534164699, 0.044035097779405695, 0.03829018911346793, 0.050443070865566694, 0.012997880563019745, 0.02951510776315005, 0.04452193899440669, 0.020305150856954918, 0.007712828622560107, 0.023792363936081532, 0.03833027083366629, 0.03044288428950935, 0.005394558942381052, 0.06964679221592604, 0.057770835926696185, 0.037464813644727396, 0.058475180994719274, 0.01540431212032995, 0.07715617757170432, 0.02334889861935329, 0.03968658736876903, 0.038441039486638004, 0.03527140815652186, 0.029688810539101402, 0.018704029010428537, 0.028511743256521803, 0.07869897905977503, 0.03447723927937689, 0.10839652300121323, 0.03957997091234692, 0.037844889016161044, 0.014579603148083535, 0.06499590307113624, 0.024260156374845295, 0.10565070300212792, 0.017050259686525793, 0.01756488308010082, 0.059906712042227875, 0.0466926452974158, 0.03383968175659257, 0.004489783727143321, 0.034981428555423216, 0.04485744337040571, 0.06351409367315712, 0.028462110335127484, 0.029077313412281296, 0.06755205502192821, 0.02461978869001952, 0.0684294861651236, 0.034109835002210834, 0.029034868310836535, 0.021063156553634235, 0.034340278080274025, 0.017608969524923353, 0.02302716658901303, 0.0359018640442481, 0.036521054609047796, 0.00999074318491283, 0.0045327626961103136, 0.08104431893556349, 0.07090159060974276, 0.031007707509542667, 0.07299730839628367, 0.032309838645761056, 0.021125295860392433, 0.04450127760308885, 0.02757327214273955, 0.03927003855126039, 0.10301855512924733, 0.024157615506180355, 0.047428767692538044, 0.033031504961752126, 0.045987200893221364, 0.11467096696217215, 0.07314076602098442, 0.06130496039986611, 0.02021546111321978, 0.049777746485966834, 0.0656848152979247, 0.027282779262731635, 0.065175581332897, 0.1058558383656125, 0.015449344683738967, 0.037428612159865524, 0.010059355934631201, 0.03486854549978049, 0.00670014800796766, 0.037010220900898984, 0.011363826511848358, 0.07284465771649154, 0.06012422355612921, 0.07237224193710474, 0.04526802436298421, 0.07141578116364057, 0.0379487207429784, 0.008332761335036448, 0.07309221902922278, 0.049330136633568236, 0.05396387306973339, 0.07551183112927022, 0.02823878995954029, 0.04181428549570903, 0.049029742067139, 0.08262858876297552, 0.016142022232675267, 0.06557062223193146, 0.03578810381793207, 0.03466059476317417, 0.011512399688663503, 0.10011255380607421, 0.08927273909531294, 0.059513567210806, 0.03682598441598877, 0.018699972574869474, 0.04023769953017754, 0.02921146306870205, 0.10958739135774875, 0.05521100675386768, 0.021595964959311872, 0.026559211133468538, 0.03169588620714363, 0.016334392656121525, 0.06468490201739535, 0.01128774919291778, 0.04877899382864276, 0.011010488566582002, 0.05078940006393579, 0.018627460437616514, 0.03441602502378725, 0.01766356095040758, 0.050133544531080036, 0.04335755429741356, 0.03683060009573256, 0.04259741887630474, 0.035791911274915746, 0.04701152939589755, 0.04973751154818362, 0.014853601197471783, 0.07001872024228496, 0.0702753367142812, 0.01804338925848565, 0.023857797420914137, 0.052236172430697954, 0.09040823461668146, 0.10215640744014133, 0.0658000885478912, 0.042573658659333186, 0.06817050248144135, 0.0172880801912998, 0.04329902901043815, 0.061068963184351885, 0.029809162952005867, 0.06265314491165262, 0.025549296575087695, 0.02011060282858389, 0.01632222143422452, 0.07758871081375307, 0.0484824258713953, 0.022665352838474418, 0.03792009586768766, 0.03764397479713925, 0.03713016728720358, 0.04571866026268371, 0.08012471465213646, 0.024587777706103462, 0.07525110842599984, 0.11203583134638687, 0.019656527194104368, 0.032358358824445356, 0.03737448038713586, 0.03960365069008643, 0.12123444057520359, 0.040184847124281435, 0.028286097804084424, 0.05266566813412694, 0.03832535637963203, 0.03419886207989147, 0.026885353915032842, 0.017659749662984284, 0.06299442176016108, 0.022241593218378486, 0.008580315944498346, 0.014343220973387362, 0.06604430971727257, 0.0390610535959563, 0.006080121449720596, 0.053224586731483864, 0.04808884820029621, 0.03976294718262169, 0.06420292163027391, 0.019750824956704053, 0.014319027916738584, 0.010335792058838472, 0.10198105757515277, 0.11382309149109548, 0.006364127480229664, 0.023921922810616034, 0.06203195485737055, 0.01763067854147765, 0.029347813312685298, 0.06374169456502123, 0.09904704807746796, 0.013375424013863648, 0.03741716680627677, 0.015606823632673872, 0.02804299129263288, 0.06945309454515096, 0.023110298620116328, 0.0894164648507872, 0.046357133260537545, 0.0791061547915301, 0.023468134459108118, 0.02542207809916187, 0.05855582707050828, 0.03753005752279874, 0.02501412478816365, 0.046956826887664296, 0.03282977868953059, 0.04532246257088358, 0.022888945175274726, 0.014184462657618909, 0.029352392603252685, 0.09120256820273015, 0.10268101678980936, 0.05174528244101713, 0.02954367709706628, 0.04140996727191153, 0.028643834051646055, 0.027755342514043855, 0.03871462097571742, 0.044931887964447664, 0.008460096639370727, 0.03753602534772889, 0.048327599501898216, 0.039274830431226766, 0.020447528297682444, 0.03333535841515949, 0.049614684671283736, 0.03816093092844371, 0.00991680229368109, 0.018920370325025533, 0.03879892512134487, 0.025172743292885925, 0.032673749561992385, 0.10652088695355963, 0.011312531179658348, 0.02905593955919387, 0.011600347539980807, 0.078381473919557, 0.05072048662470714, 0.020738120769120513, 0.009131164763182884, 0.02767642013608448, 0.022128658451800867, 0.06022225599735976, 0.015909230137514253, 0.07148711927114956, 0.01861581015550802, 0.029176902927217946, 0.05394732940100855, 0.0764708889407977, 0.0564204182686104, 0.03939904775770922, 0.011983663463334163, 0.039274501013419325, 0.043404266508596565, 0.029379837703140035, 0.07119025253961164, 0.09521298486018374, 0.05945572757252282, 0.07657946658230598, 0.053704494850770126, 0.05767192248435271, 0.04432466752346485, 0.03823822920000361, 0.03639023743509766, 0.0692738606143863, 0.09277880176781647, 0.03314518091839648, 0.03978818977972673, 0.007865504200209775, 0.01671937865114981, 0.02092687717278398, 0.022466472582891587, 0.01564654050349829, 0.10576078217596778, 0.059269070249771884, 0.004930185649784343, 0.07477183615969074, 0.036629643741874926, 0.024012139239799113, 0.03449094076190264, 0.10345452044519687, 0.04511825417378738, 0.018582703665860238, 0.03486127532537907, 0.031209238429343512, 0.014415168120796162, 0.013954494554068775, 0.0344870490352473, 0.05723852356294951, 0.029207983114306005, 0.050316474836079345, 0.031406260921709964, 0.10262536816298963, 0.02000506081047558, 0.13735639321948254, 0.11085056309257785, 0.15845761093641483, 0.15346464821167533, 0.16420858701871288, 0.10495368556510057, 0.19147177166756124, 0.14313157768018786, 0.207510327980403, 0.15558274342648445, 0.16949578879341004, 0.10998941897865265, 0.16538044107296776, 0.10906334891314469, 0.18053876236081126, 0.17804923707679396, 0.15842112982946058, 0.11560279034799147, 0.1140335281830161, 0.19213840605751162, 0.23024294525384906, 0.13186034055486803, 0.22468908359446835, 0.08363048621122876, 0.14660396312754, 0.09605027299614684, 0.1563305678146501, 0.16943680002324044, 0.1907601832382141, 0.2671482504135178, 0.11053963098675014, 0.1704862179054368, 0.12686963778950516, 0.17164178493042148, 0.14590375876474768, 0.1258333966196064, 0.18738035653387347, 0.07829662202106369, 0.1495483301339611, 0.12563443592479154, 0.14616275777018842, 0.1499655109740073, 0.13234366542629658, 0.13828924316312038, 0.15857843832383234, 0.1620816051839821, 0.1711331485139747, 0.09289237430259105, 0.1714540627454558, 0.1414715417570645, 0.07019910330493605, 0.052287691843605814, 0.13027858349584764, 0.06983434586154838, 0.09127819640261513, 0.13806065784827357, 0.11246827265788471, 0.13390469214608594, 0.09668120002794652, 0.24180791581109648, 0.17778484481236628, 0.17200776045360874, 0.191033891131801, 0.18331279737814782, 0.16218570121113332, 0.12233910105761983, 0.1639862376595697, 0.11554944764582381, 0.11777691723358248, 0.09862058991265875, 0.11116360960107659, 0.22495853203919627, 0.12568741090475552, 0.15026917290543357, 0.15520023572589123, 0.09720016330961259, 0.20954161011163266, 0.14070574494619525, 0.2694822445271477, 0.16589664643810642, 0.176371734348997, 0.1139265210217526, 0.04126977701220782, 0.1660838476832836, 0.18427037663998144, 0.21218943980432328, 0.08499695724176784, 0.11736221851841097, 0.12869558537438994, 0.22100219352831765, 0.06481352817988204, 0.1090469393098066, 0.17533681085032804, 0.16818438416286824, 0.21732631980651812, 0.10417837394221176, 0.19646101120498874, 0.12403020184607276, 0.11478345165209425, 0.13572974340809932, 0.111865330817959, 0.11425353331311096, 0.15986119126600606, 0.1370844932933969, 0.1818143447200137, 0.1263539380423965, 0.1526437696790503, 0.11281180946576981, 0.13179673993539426, 0.1397584159407885, 0.10212330478093318, 0.16893400119677668, 0.06727364334848619, 0.1181055153269441, 0.25608325947917276, 0.08935864819514175, 0.21857655997718536, 0.12356872580224469, 0.18387942665046264, 0.14405235407813904, 0.1295351411306089, 0.18803379888976776, 0.12165080936205004, 0.07968606802845195, 0.18301935505963143, 0.1331453764390561, 0.19724114918180052, 0.12270055666205384, 0.11279466441802441, 0.16401409261649655, 0.1495150053092549, 0.0987317416095926, 0.10596793235069323, 0.14885535764117397, 0.1022191500411399, 0.14387322739968378, 0.11636050493125955, 0.2001953067918939, 0.1501507510340983, 0.10945998327506166, 0.12392756138597766, 0.11182802233604655, 0.16811802562686706, 0.1134377109607862, 0.15953093076184874, 0.12626109584685297, 0.1615569268864009, 0.16713750969258048, 0.10158453812642444, 0.19218297705294626, 0.0926263043056092, 0.10176754120977656, 0.10279003876231371, 0.1881072207564308, 0.12728039881274586, 0.3097050168341206, 0.21272168705059638, 0.11938682036294092, 0.18909351299366645, 0.11627342371690659, 0.12091577098134065, 0.16896567127156645, 0.3218046707972404, 0.14032113816468947, 0.09906173398297641, 0.141793068858885, 0.1855897945502112, 0.11202673788272566, 0.13009616263931797, 0.10015085820228824, 0.15830188058316708, 0.10851360421868102, 0.1596196590652389, 0.12751675992002412, 0.24386495381834047, 0.09588157277434103], [0.02900205293459998, 0.06414151585270321, 0.057913780272487676, 0.03449649106891405, 0.014537757510439524, 0.03909861871732339, 0.061313900645942464, 0.05195477301435125, 0.07764304176934304, 0.03832854713583666, 0.05223526461650768, 0.031015389456203392, 0.03571714492394559, 0.07476877180799361, 0.05136846677370129, 0.057762336181176294, 0.05602501347781189, 0.027345975770825343, 0.018909003495449023, 0.008022427256594623, 0.007031773106240097, 0.0752212463187114, 0.062098573863265984, 0.03810820109661549, 0.013579498345573104, 0.06815662862913263, 0.03739681568056826, 0.04416285060165871, 0.0707465190921099, 0.03982512670899591, 0.019748283460015253, 0.06805453209146377, 0.009850641025320418, 0.02958039186083742, 0.040929787191412145, 0.09030638322714837, 0.058335285678866415, 0.022254266227865895, 0.07623239810908995, 0.06468105625601546, 0.008783185602946868, 0.03756736983515082, 0.04637938428429827, 0.04614725964324129, 0.01125484667417984, 0.009410014064351638, 0.019345775118938858, 0.03714238255915623, 0.02408555344558291, 0.05748575928831293, 0.0667501295045499, 0.05695566857954668, 0.014598129069312446, 0.011548883668447455, 0.026933376136566364, 0.062279248039328286, 0.08307289677642046, 0.030623412908866044, 0.011681020428847161, 0.034143205792192495, 0.08926376054484038, 0.07870835597596823, 0.020631102116538153, 0.021998898479186242, 0.06499997865889343, 0.05698029064543306, 0.01234028218013625, 0.01082645796780144, 0.08686683230823086, 0.014446964600093424, 0.01514787280616621, 0.03859747081033645, 0.06475645462952315, 0.06364190395200445, 0.05727940584502875, 0.04044947304552601, 0.016466862664768295, 0.047340690563883514, 0.05075000016199005, 0.03635716541940647, 0.08145491141946086, 0.04148719659555824, 0.012386403546007651, 0.06705419746257606, 0.07002245875135546, 0.045205637992870425, 0.05543692225229837, 0.0362695096391103, 0.06452852815029121, 0.005542374170956112, 0.0460164692823685, 0.07069007373384892, 0.12349682078967172, 0.07827120322373607, 0.04404735518619419, 0.019448210650514212, 0.04855633420389026, 0.023504966051287712, 0.03187683042919925, 0.04858481352247539, 0.03391493457339464, 0.03360271160941451, 0.03827809641558317, 0.0177411311831806, 0.034767146102122726, 0.03141103364947823, 0.03800376799077757, 0.019459627275805802, 0.04867593202018931, 0.04059164747295361, 0.024216726850417834, 0.07609138430486764, 0.07087256353829177, 0.07991630809321519, 0.027657986145406484, 0.0667764752682659, 0.03346400372984429, 0.02587595646600089, 0.04112470294198683, 0.029246482862940723, 0.02264489446045651, 0.016334714413049723, 0.01259562215812865, 0.013314475973827705, 0.028898701927955114, 0.02445000636902067, 0.013641513163043607, 0.044556378477042725, 0.05580392816374379, 0.011724412606488313, 0.0658885563813871, 0.008995545175557416, 0.09355864863121703, 0.06452670486103143, 0.030414349429549712, 0.05177078550801643, 0.04058032852387236, 0.04104155175868542, 0.01932728175644673, 0.055239290720032114, 0.08558244759877844, 0.022202507412481694, 0.05580374430264196, 0.04591962044698097, 0.015895865733675178, 0.08466501134417712, 0.016260212362413446, 0.03863767510460269, 0.06238058614995211, 0.00992035311121013, 0.009240329419563134, 0.016020481425878263, 0.02202910532604062, 0.018679295861793142, 0.026179735225835638, 0.022523971312048457, 0.08818235083092606, 0.0156952052812783, 0.04199010650477102, 0.0932107757656805, 0.034740290889937075, 0.06631377348375898, 0.017530031825205492, 0.024601864147811167, 0.015862162653056365, 0.029105628021962704, 0.04889959905056223, 0.015174208993783161, 0.0025878816367983217, 0.10801612204241176, 0.027888992298094016, 0.030884597180110794, 0.08879744282533085, 0.037752969956566254, 0.03733162925909123, 0.030160366384793195, 0.012413769164272856, 0.028605137035370837, 0.01825196818718987, 0.05294466969527064, 0.032356156321663054, 0.05378478469567434, 0.017192652449011803, 0.04018631035221681, 0.11177001415842003, 0.038042811661838524, 0.012218848625648648, 0.03156331852228651, 0.013622853176427946, 0.016116478946059942, 0.042739080024823066, 0.04168885391986659, 0.014372864745617395, 0.047969104827291546, 0.025412915687587474, 0.031208784522248373, 0.029063332307663177, 0.03751495026893193, 0.04955281158007922, 0.04837263015008742, 0.0854955655672858, 0.05797622026875616, 0.09594994612158307, 0.10793231968437472, 0.0775574850699594, 0.017224667263367487, 0.022700654170025262, 0.013424987987344785, 0.05684077454310271, 0.08749349989117154, 0.03457530619456403, 0.059784026891593976, 0.0455060210679808, 0.08050171418055412, 0.05850000607390558, 0.031110213904251015, 0.02796230691244766, 0.021895790705457333, 0.07251161631316909, 0.026222253105633204, 0.016193553136901993, 0.04090740593270429, 0.07189743596339418, 0.029433295318496325, 0.028265174027652513, 0.04794002412968586, 0.06257778867298076, 0.04367745346239498, 0.05544865871929834, 0.03601734413795414, 0.02670051605110207, 0.02842594140900239, 0.013016466813672696, 0.06463463132780406, 0.04546389389302462, 0.09019282601413228, 0.03828070494496534, 0.05391835595571226, 0.00992752082135168, 0.054102048518196236, 0.02878948651824988, 0.1569578712505679, 0.03029148424825361, 0.04300173326966263, 0.01511362101507163, 0.013097894299144467, 0.09972318195767942, 0.04727207972938496, 0.030931650300420103, 0.08155708456592214, 0.049223692546929085, 0.04183946297534051, 0.0198890004051669, 0.031528601332777934, 0.04500356315064334, 0.060332078531744986, 0.056983125170752894, 0.02700957315673511, 0.040042186231021924, 0.05432588791835213, 0.012036471819174627, 0.05696895637459332, 0.06015138520348457, 0.018983976690158732, 0.014946819733708136, 0.03405888249436694, 0.03234566091710041, 0.03834546235720477, 0.0128941398091434, 0.010614143402856446, 0.01759377417094525, 0.06714049726724625, 0.09497231833877103, 0.016764336520986214, 0.04117860871877882, 0.055666403890016584, 0.013266482480591344, 0.05153446270513439, 0.04565785969457319, 0.06297582114535956, 0.07367154237844291, 0.05528977208380258, 0.027263088887857816, 0.03952162948647334, 0.06648602835353344, 0.01658898091033822, 0.030207392692025152, 0.057309869331337755, 0.0298652769772396, 0.029118615127499067, 0.0397839954483413, 0.039468980093877164, 0.038133462845918634, 0.07961691327152715, 0.020036692580869122, 0.07112361055107848, 0.036461590864365144, 0.02842435943743875, 0.023826648285912893, 0.03857251549620302, 0.013337659709636244, 0.04750999216470988, 0.03948005389482264, 0.03514073270883772, 0.06241933487716222, 0.0589040753191277, 0.04305778409264261, 0.02834306601735373, 0.010966446171815117, 0.04119244809713095, 0.06492533105155153, 0.00626778761450682, 0.027738103620527733, 0.05438252479859418, 0.0479766316411476, 0.02940214043783565, 0.0518545035963818, 0.03148798143581277, 0.04571043247837694, 0.035365330536038644, 0.04281058284123579, 0.10232405812149087, 0.07488838111561152, 0.007365452756564464, 0.012849457730959742, 0.007447366229063201, 0.007615309939043777, 0.04112814267676684, 0.015933350415810222, 0.05398975151981558, 0.040066026887225534, 0.018954953449147365, 0.012235098308132542, 0.09135636035352947, 0.053126121450576096, 0.0157187758914886, 0.045612036145382354, 0.04989143010349043, 0.031542992294435544, 0.03772248348761951, 0.04340505557915857, 0.03805976901804248, 0.0422243072441028, 0.033647696292328264, 0.020738540202259056, 0.1235360138478779, 0.072077305747136, 0.059831256212125865, 0.04203328705062309, 0.006440520810429008, 0.03908343485466415, 0.009757280762818073, 0.10372656592798811, 0.11456607420357967, 0.13895227693982665, 0.15045821276162902, 0.1903427878935491, 0.26126037441915084, 0.11813006844491729, 0.1612959513741155, 0.18641142384900203, 0.15065514332344457, 0.1257743695450406, 0.11983782398484408, 0.09364749184779583, 0.2396457705406412, 0.19347210384664998, 0.1145613014758114, 0.062013212516303026, 0.1000085497094739, 0.11452439902049881, 0.1555809048154662, 0.08355516444651351, 0.1198207172414949, 0.1468913686732131, 0.24799029132531536, 0.13795326764304794, 0.1486564199289968, 0.28762106152792133, 0.17983808302350585, 0.24204238468120176, 0.23378092314927812, 0.09403363080515016, 0.21404718769894493, 0.1685367386427618, 0.18782052001164806, 0.1361752235360684, 0.27409302130822216, 0.13298846631040498, 0.19750557208974517, 0.16367698328629618, 0.1730835777256758, 0.0852094776928425, 0.11587019333796156, 0.11800167210880788, 0.14153714952689989, 0.154454096731159, 0.09330231561175278, 0.16620614595951574, 0.18583019294085043, 0.15661841769131923, 0.08841466699396411, 0.14766398366660843, 0.20268071052287856, 0.12135188951487504, 0.1366034513639827, 0.11860164152758738, 0.14750046986005, 0.14554964228262826, 0.11422234587371351, 0.09988657319016996, 0.1474034678070776, 0.2275939051422381, 0.20282640512431824, 0.1352921846292673, 0.10952257265847538, 0.19747932591745931, 0.2739582817640997, 0.08364504188179009, 0.1075514437510602, 0.23777168965147388, 0.10063357786425661, 0.18281991172942424, 0.17904720449399564, 0.16294175338360573, 0.14144112806647055, 0.1751588179820007, 0.13124373170637316, 0.08839991980142171, 0.2213344458610781, 0.15180519451537441, 0.16991676942956063, 0.19727850362898844, 0.14505127144436683, 0.10430457160597849, 0.16146525680538149, 0.22618422675276958, 0.1062812929552409, 0.26789267337129963, 0.1189422135752055, 0.2121808136542959, 0.10632173473676367, 0.14738848312727867, 0.12163754838008074, 0.1299217550624763, 0.15187821801631682, 0.15776155877017206, 0.13102070818985664, 0.214440543204546, 0.1290827355678043, 0.15853634945327238, 0.1950244278076195, 0.12086488742140994, 0.1828755450344855, 0.15049614943563938, 0.13092634147934376, 0.13301909450561772, 0.22196089127852073, 0.16456382198920175, 0.09555584751069547, 0.15457112432247208, 0.07702835580153812, 0.08385645150537453, 0.14716222671972168, 0.12267561283923926, 0.19596791105164638, 0.17990995739256183, 0.14258169508989782, 0.08942935811055285, 0.1921338554952414, 0.1436863479114348, 0.08057068507637709, 0.11595375054786283, 0.07983983719661351, 0.1384070828076332, 0.1245462769762643, 0.10465974528943339, 0.07890988306532945, 0.20468556262072057, 0.1503763486060404, 0.1329003815208712, 0.11938846745197812, 0.23872424337652423, 0.173000886195129, 0.18779479477915073, 0.11514113044306157, 0.19703560779171606, 0.12049371016121681, 0.10780317258209952, 0.12075338332403092, 0.10909220744525233, 0.16244745813310146, 0.219648041191601, 0.06581452164438463, 0.23881913102682562, 0.15003095020449933, 0.11107405392272819, 0.31999661136538754, 0.12242250504993624, 0.13590557590848015, 0.12053255081897783, 0.1162159594617063, 0.2174406660900962, 0.0994404572092237, 0.1415105049888934, 0.1871768682594261, 0.10614535831395658, 0.12656474245652077, 0.22419636648508812, 0.13677919193381263, 0.11062845122069122, 0.2910718279740503, 0.1301474598867278, 0.24008427926849937, 0.15482799360348334, 0.24023369705725103, 0.1797975569723114, 0.21470184047375956, 0.15671776397333992, 0.12939191333228542, 0.07910947961312148, 0.15900072130945422, 0.16874805633579532, 0.10563322087569584, 0.1623686430074515, 0.20167045505537143, 0.1781185067469074, 0.12273768894374372], [0.045223081814906294, 0.012928724848485042, 0.042340308277597355, 0.06869825279159893, 0.016803205907044393, 0.01628784132340262, 0.10740098408273152, 0.033224838740763166, 0.0452319416217506, 0.020715337314252413, 0.0302016202195157, 0.027788418360174667, 0.09143007333360373, 0.01915886690239272, 0.02744096109733707, 0.026650193650575898, 0.05402992900100447, 0.03230081413001303, 0.057642159968494415, 0.027213354459813526, 0.021530142684857694, 0.06841827829879138, 0.030837756649200476, 0.02901472402886758, 0.04454202581978133, 0.018605259209570867, 0.03555910864604577, 0.01978866970016351, 0.060435155661956924, 0.04665764274015542, 0.07807965826002822, 0.03196360520838249, 0.022705162597459652, 0.03542097533241876, 0.029061855673189127, 0.03303905092780629, 0.06113558985112656, 0.020332862172395955, 0.055692964158351385, 0.06067803234703118, 0.03990105751361098, 0.09673757643829431, 0.0454848655499518, 0.02460347293245216, 0.016521092113708297, 0.04027431470251853, 0.011564870965817283, 0.03659425047977317, 0.06096374866883121, 0.06155697268343741, 0.1169450376783648, 0.02075275496369408, 0.03272544517512283, 0.043230418175939596, 0.03166628073930981, 0.004456707881012511, 0.03345603258499215, 0.01811325839239984, 0.04398467770266918, 0.029526526303661448, 0.04055699348569878, 0.05351524048995587, 0.04949935013428331, 0.028427994524639462, 0.08939773400103854, 0.03914915370724855, 0.0954168102133178, 0.09144480520438764, 0.009417000786221076, 0.07161142469774331, 0.038486625548572316, 0.015288512184915524, 0.030112108591222958, 0.05433948980944772, 0.020614499075999184, 0.09278774967477207, 0.01585021838470693, 0.0756675155172425, 0.062009680850972096, 0.04134031072739632, 0.07805418583654589, 0.030160335741276224, 0.08966205731755303, 0.06378880897236448, 0.08914178402553644, 0.018921469661196875, 0.035542886734249136, 0.026278579720265927, 0.02198778062818512, 0.02662804221824533, 0.06658005032448039, 0.036799209643035166, 0.02372393504746499, 0.016268355877048547, 0.061413901933138414, 0.032567696180194616, 0.03844684643310405, 0.015700822620983088, 0.06795557651428447, 0.036376980283567985, 0.010294360108673573, 0.03874656684215992, 0.02931952168564162, 0.019494539817735072, 0.017946278037984046, 0.03327258517064395, 0.058694937146238746, 0.04409144737667615, 0.015441938528730987, 0.021663874823359713, 0.02428087139231784, 0.031431047696500056, 0.02432702818975574, 0.06351801987376905, 0.040671918165659716, 0.022693031595178673, 0.08078594812222066, 0.054964471998954975, 0.017571938749883446, 0.031437695424463, 0.006478403379479724, 0.039214558463784, 0.07798521494072291, 0.05022236859546073, 0.038209424294050665, 0.01956306255212234, 0.059805090479072065, 0.006711613471364423, 0.027873327715262294, 0.043225388808716694, 0.0839774474321354, 0.03764518521605961, 0.02353744051839796, 0.0313622223573827, 0.016804356954150626, 0.014463785975690813, 0.12571476024365233, 0.04617545550929443, 0.060430946008813005, 0.00951042712380689, 0.022794902136909868, 0.06203420332542831, 0.045038849160435705, 0.048366413346581885, 0.05098377189208424, 0.0150671185204579, 0.012919463803090397, 0.08690643139303693, 0.060036433710446285, 0.015051004818580566, 0.07183989509940147, 0.01502410268350955, 0.028699586100335565, 0.02162826705663916, 0.0052729228533984675, 0.06494609203429953, 0.01582090881833386, 0.056674158080450954, 0.04572953105032925, 0.041933515589804425, 0.06257201620047131, 0.024394574162039547, 0.025178224651984153, 0.015413947591197588, 0.032265531950660294, 0.025241020879137422, 0.05058624120729585, 0.0062105934052998505, 0.0463874971554164, 0.0062687864016381005, 0.033454278243645545, 0.005035263227088558, 0.019894669455806577, 0.08178203096312862, 0.018180022955000884, 0.08274907907170635, 0.015419097617268564, 0.06096190239693369, 0.03691086695799905, 0.013900613675134317, 0.040582082865218964, 0.033742580112190015, 0.026261260387517756, 0.032671976068447676, 0.09914257158074649, 0.020831734798247778, 0.07854278905377274, 0.06709585732389843, 0.04462059962773516, 0.04279737931586081, 0.015938607694190598, 0.08670083637679778, 0.08274678846881275, 0.040473727389208736, 0.04446850053124851, 0.056864695638538375, 0.0327431035017775, 0.03522327868267894, 0.033492214917655916, 0.035051931627094746, 0.048715462157082175, 0.005842213323640247, 0.03977756030977734, 0.013349127088252817, 0.04896893383814924, 0.028591420231086594, 0.03389995755447495, 0.030195683038102526, 0.06225710043743734, 0.029909562604922443, 0.03932807737240388, 0.029277821604703224, 0.06713029297609484, 0.06683089815440678, 0.03785759075394562, 0.03016105586392505, 0.025142120843332623, 0.037955270794730996, 0.025860228680915413, 0.013131041966018178, 0.008921009608574452, 0.0803204118123939, 0.022454060043298432, 0.03818415871430789, 0.03724337976065375, 0.09050162073465125, 0.11882161601416527, 0.011011134953268114, 0.06543321670183251, 0.05875583730577942, 0.02998808470194138, 0.020348160948243835, 0.12161556931753313, 0.00913460928601243, 0.017169409341389136, 0.07563262021229153, 0.05248887802384073, 0.06878690448619666, 0.009831317415040348, 0.04446915553642377, 0.043721143456716696, 0.05919962054899624, 0.050469198294224284, 0.06301817814669301, 0.053510352848998965, 0.026167985352296984, 0.06610651605672414, 0.03559241431855387, 0.013562170394335785, 0.07222768880667225, 0.06034740412067022, 0.041094702938872005, 0.036677926433302706, 0.08872941421765475, 0.02944754072344832, 0.0693416364130474, 0.043635897022942384, 0.054895447476977305, 0.043522412588279095, 0.033367844373588605, 0.05812414418605547, 0.05958688565559926, 0.026852743467316035, 0.017585132699159366, 0.03177687893771837, 0.009385889955616046, 0.07283877416123306, 0.031202209572638237, 0.04781134817148409, 0.07747323072004704, 0.035660262895567764, 0.08378114506241777, 0.027116327508983594, 0.008739128844031404, 0.036526578102981856, 0.06584838273063784, 0.03863644553348422, 0.04561972766814213, 0.05459349775206178, 0.04224127226118599, 0.03145950786288708, 0.039292446623045596, 0.029521870404301636, 0.0511073648569084, 0.01680850340504079, 0.014350526579355281, 0.06424665758987108, 0.043384486118391644, 0.03094104062315197, 0.006931937964362724, 0.03418875738017021, 0.04649063557266228, 0.05459414892679742, 0.06461498117254627, 0.03721748215837344, 0.06873941469577051, 0.012141845297939595, 0.03218223138021366, 0.009450673223322919, 0.030145094422022664, 0.018277296969186396, 0.0488688291290835, 0.027685555734581528, 0.03315437780392747, 0.06321655278424583, 0.09030917178719275, 0.061070732847456975, 0.025880727278549346, 0.05646318895742298, 0.062006838664773016, 0.03405905869458953, 0.04748333230494492, 0.07712667552574028, 0.06804660308144747, 0.023897825514957793, 0.09429524983129195, 0.03725759069164915, 0.07197884812710748, 0.04765516199592141, 0.009004457650946514, 0.0113612390498841, 0.02173791147558199, 0.0045162008327972744, 0.04545736299347013, 0.03198208324911614, 0.02355831449911479, 0.1241734602879132, 0.029762433503844568, 0.08957067068906562, 0.06005236067839208, 0.05183211850723432, 0.0663840237464155, 0.0780218645870205, 0.050086430123736786, 0.026006727674675566, 0.02382141782060987, 0.05013080576675073, 0.029469104183297005, 0.04550033669558264, 0.04410584982965262, 0.03385358242197864, 0.007387174700852484, 0.09630620764989047, 0.030166845573412798, 0.02134918122582378, 0.048421916416696006, 0.10615895637461256, 0.022860174743278373, 0.01179585796630671, 0.07008493322158052, 0.02790675404661846, 0.059733947723983764, 0.14520274234875558, 0.13357198016057092, 0.1904787531783504, 0.17713281205825268, 0.11452369421960847, 0.13028973773602517, 0.1769117497268223, 0.14107889105235377, 0.17703277629710015, 0.08423898984948475, 0.14911567431784448, 0.19138649075983033, 0.11191282060838516, 0.13733486614881024, 0.08049558547715988, 0.2308822456266611, 0.15758502146890088, 0.11342920738482669, 0.09926517629214834, 0.09335458579082644, 0.12974272031457196, 0.17005379191569744, 0.2006522016299348, 0.1330777461971006, 0.12027198899417155, 0.11349257817792316, 0.17796777128692598, 0.12595206363907746, 0.16280897502456942, 0.10990020037899095, 0.11627782106159196, 0.1406867459656731, 0.18830165387161318, 0.07878177784263127, 0.15322112418230505, 0.22867621883990305, 0.18871564778589434, 0.12183587322191847, 0.13446888525880155, 0.11841546684022873, 0.10016218864268835, 0.14988470401975418, 0.15042720152245415, 0.11862920537110298, 0.09868804395439164, 0.21293410791024087, 0.23267366562879857, 0.20872624741206247, 0.1297349828265367, 0.14900206347867367, 0.2671271063868077, 0.12339798012568105, 0.08828843102580117, 0.13475531021193152, 0.12104856466213543, 0.0886627032812084, 0.20840216157657487, 0.05715137723112299, 0.1052444848802782, 0.20996678890960835, 0.1896768123392136, 0.15638183441854295, 0.1970389019697905, 0.23854150076306638, 0.14144718016107238, 0.09957417785640686, 0.2394477368122147, 0.15278538869273278, 0.11368498116010621, 0.1427004233964028, 0.15782353528324636, 0.1498019358804149, 0.1447054899988636, 0.15425831530122988, 0.10996326473691773, 0.19632650148724357, 0.11549806612874232, 0.2802319902806513, 0.1736943030189122, 0.2054532133643666, 0.1840790844852886, 0.11035614526800572, 0.19958517904723846, 0.1624293478145715, 0.2223184704780579, 0.11791461387709265, 0.11369625797435162, 0.09690865919354463, 0.20505196715314544, 0.15802912263860627, 0.20973688592353176, 0.15116304429548402, 0.08422668647742079, 0.22319291387834858, 0.1330035582425133, 0.15832968957481847, 0.12312934373415287, 0.23321507528664606, 0.12482120294965084, 0.1358760662016369, 0.11044350227401142, 0.1705259625469485, 0.18251499341380212, 0.15394530709712737, 0.14656584259242783, 0.12243072517336377, 0.146372941653094, 0.19268459610400662, 0.09829104187027102, 0.11058577246242955, 0.10408774574076939, 0.17069251006168706, 0.1426781608813232, 0.186421551531361, 0.12613382565999223, 0.11554661312050397, 0.21976730575965298, 0.24550536256884378, 0.18106664290591595, 0.14643199171029753, 0.10837970737127528, 0.1708030718709192, 0.165218367511707, 0.14290074006684367, 0.1491283913773875, 0.14676828898729818, 0.16677456787757336, 0.1041635271582392, 0.12854642805553254, 0.1406070728215479, 0.19945506667417867, 0.1335482467566767, 0.1341546053487447, 0.15106667043460956, 0.11585431999617046, 0.1461618997517132, 0.31678584494417716, 0.1546013541519642, 0.17333701493278628, 0.1275266194716096, 0.08072050123084938, 0.17340908848470257, 0.21844402676628483, 0.14126534153136516, 0.1435206890586884, 0.09292339320264517, 0.14417544908581242, 0.25111367775788235, 0.10427071818060453, 0.13095605036904737, 0.24162646022535142, 0.14323913642475683, 0.20695321352010776, 0.21406273928380784, 0.10427930602623571, 0.1846033644171492, 0.1503616550396527, 0.14546520407161406, 0.13713810412633803, 0.061701181074303973, 0.13257208220180006, 0.23615188866613374, 0.0850152054561242, 0.17836259768134166, 0.14011542823526169, 0.10948432188841606, 0.1910154896998598, 0.1857764595338414, 0.13162280733306564, 0.09444401644530798, 0.13969081634234998, 0.15280138460859177, 0.08323009801848281, 0.1293723780902163, 0.08816633959330859, 0.17144612607456025], [0.045470122187849016, 0.04790656907003253, 0.08548465647524403, 0.024226852617557013, 0.053107854084021626, 0.0426356926290018, 0.0791538667474543, 0.011856284108944239, 0.02799005844750472, 0.10970858646736992, 0.05973549522159081, 0.04029000801364741, 0.034860237276241664, 0.024374157918857473, 0.012711346442360553, 0.025777337967508265, 0.031862037271381385, 0.011364597387822166, 0.04345982320486538, 0.03696971783234227, 0.025304625329050808, 0.03244929346105745, 0.049345182600401105, 0.06714914639991137, 0.11301419457360623, 0.05409529162270408, 0.05407740730011175, 0.007813151187879305, 0.017570128867162332, 0.031584560225207, 0.014924759274318576, 0.028932436609700806, 0.031437975046555364, 0.042617934710916974, 0.03990509862741155, 0.04975618877177758, 0.03294602870160053, 0.022192065634073752, 0.04025110606885245, 0.03766364410459515, 0.013363801502442409, 0.05255036041020386, 0.14758207354574435, 0.05371106022428121, 0.04339151497509691, 0.03755029373531861, 0.04216807639046062, 0.06534214416939406, 0.030558450568106868, 0.09987417022667586, 0.024986344524809433, 0.029236874205150434, 0.03088095251681103, 0.0714212280487822, 0.015999791306263257, 0.04902825968700552, 0.056532611845121275, 0.005702771914882526, 0.01761346454581907, 0.04734251768358293, 0.037470475034487825, 0.02128234196965012, 0.05696819411710866, 0.040527633166000734, 0.0019941217197488336, 0.026310483451872587, 0.05255581495622474, 0.04476905597614185, 0.06339240826726442, 0.023405769156412255, 0.009521715429371164, 0.02953807507911998, 0.035704401051325184, 0.06016045185406843, 0.046674887379330975, 0.024967086989612832, 0.05734551540245453, 0.04208106029358122, 0.027881645514900168, 0.015144607356388964, 0.035070444141784986, 0.05344120192251379, 0.07640017902538662, 0.06626084446907043, 0.02172436129542128, 0.02039611805230379, 0.05012813978077424, 0.0701106124888024, 0.037611239860134746, 0.04960517368970379, 0.07781754127673565, 0.08528103030497029, 0.019302203868245407, 0.019255307795960578, 0.03291743830026638, 0.02856018682641368, 0.024961550089140094, 0.03503750619148055, 0.035018518702277256, 0.031110192836833098, 0.04107770727827184, 0.026459345826879147, 0.03373911739477227, 0.02916057759355153, 0.033371548408702496, 0.007267206289520067, 0.017381094756626317, 0.04874529745129328, 0.0777614789624368, 0.02719746196582433, 0.008702815318810604, 0.058602443520700744, 0.04982168162842432, 0.02476643324048529, 0.028577513820041093, 0.0063661020718544965, 0.06220256263810781, 0.04210435702735859, 0.026726825425641674, 0.06676162848429334, 0.0688690597551965, 0.05572290287443227, 0.054278455584520297, 0.026266393176610434, 0.01533673933496879, 0.012317673967880829, 0.02219118654818064, 0.014045431105900678, 0.08278326957576698, 0.06298605224958832, 0.05565869704549832, 0.03371652546188524, 0.02612060472940005, 0.03280902153722221, 0.07050720854632317, 0.042475825400962945, 0.019581462068843748, 0.013126477039599372, 0.044936231682978334, 0.017320922380613706, 0.04584059464715181, 0.06834774458360288, 0.044732965574029, 0.026385155957072016, 0.013758623108808554, 0.03200372140253744, 0.05482414001298528, 0.009406116592036861, 0.033851720828322635, 0.015073475135009617, 0.05053575984352539, 0.017338073174018535, 0.06625326019862006, 0.04127499790141179, 0.02839269893874805, 0.03183620478657465, 0.04651323133598893, 0.03817649017418585, 0.015637199976481497, 0.05158572930902724, 0.031087817323784676, 0.01838984103092263, 0.0014308802318766774, 0.023964189796618397, 0.04846931810701086, 0.07496817683380458, 0.13543412539987795, 0.0745716650459555, 0.12269155512894354, 0.023055678466334942, 0.010145970792960255, 0.023783241744123162, 0.02388962454372837, 0.03177962536292692, 0.04641488862914905, 0.04244742269117025, 0.02620930047405343, 0.014288280977897588, 0.04123509238143602, 0.07757948711514473, 0.02008235716681567, 0.04076165387467031, 0.06160175435305123, 0.01833767618893856, 0.023178763897909273, 0.05899320964911773, 0.03951439761646813, 0.019529408309608698, 0.017511088386057846, 0.0472369545980567, 0.04537872789848236, 0.11158825213750524, 0.04177282864768659, 0.00961341328107782, 0.029843384099583474, 0.04858428492180763, 0.04528235403760787, 0.02875603337381636, 0.014391648263910846, 0.027353793698092623, 0.0803744976198481, 0.06938921813402446, 0.007296393281825248, 0.010341082853565534, 0.01728963343456628, 0.0629473188441367, 0.061807640482701605, 0.007526034361592705, 0.03115032435274653, 0.05388298184580861, 0.07388848315684066, 0.019793530528043068, 0.04028191429472739, 0.05661269101584631, 0.029936982806952252, 0.018331106984987855, 0.05994590893087368, 0.04632643611741163, 0.05511130807140181, 0.03398099050466572, 0.0702733142421611, 0.026510124049720266, 0.11154453916054581, 0.025721457599091436, 0.009619121593723615, 0.05971498704785782, 0.08002952822754461, 0.03787300444298214, 0.06229042143170392, 0.041795255871669906, 0.02418426387462645, 0.027182075089865157, 0.045498367849617236, 0.024884933635832805, 0.05256735990124364, 0.004453424236647064, 0.014192621494012495, 0.05695983226741514, 0.013954511791047071, 0.06004574167872629, 0.018643774279964068, 0.036275898812398795, 0.05356386026007034, 0.07803041412825547, 0.04468875463991877, 0.02964851048384463, 0.05202240708674635, 0.030777938588852846, 0.010208452924064571, 0.014091728671994663, 0.009055842040857721, 0.058380163109470765, 0.028056775129610495, 0.03315039414672121, 0.016821002129525427, 0.04714144258609703, 0.04220099518856695, 0.0726367567756003, 0.012432027912338176, 0.013462927534184871, 0.048888126883896134, 0.02285178225006788, 0.022933579372963118, 0.025679477896060676, 0.023733756294654264, 0.07241286757972933, 0.058688233876901294, 0.04819398993746408, 0.06404874643551246, 0.02370350731296405, 0.08818024408913429, 0.05098277214734305, 0.017209703650986476, 0.04565044396346615, 0.03296680883654664, 0.059008125381003466, 0.10986002672824169, 0.006343040431308891, 0.06216878582152629, 0.012266875635231695, 0.02768769503511008, 0.032862655352801085, 0.02701538584886059, 0.05588422566952725, 0.023275141589223378, 0.011160092131655303, 0.010739238857622109, 0.033743549213414235, 0.04803760840948071, 0.07199551053946057, 0.022131364657393387, 0.026001079691453807, 0.09797942794619069, 0.07597818715317596, 0.03522425927522202, 0.041990635105438774, 0.03246125975443471, 0.05930237592227998, 0.03303572993665453, 0.019383311512008793, 0.006047558403694101, 0.05967756748319634, 0.033981009656863834, 0.04517849549771317, 0.05923145150225009, 0.07798124660527514, 0.0647428106035917, 0.04897287919095928, 0.04291462907267194, 0.03562359409707208, 0.018423556560470213, 0.04556018348422743, 0.025165589946892955, 0.07076438426250412, 0.01413700829875926, 0.022774357574000474, 0.04650992566659566, 0.056103234885320555, 0.025813637128580483, 0.01279723160194173, 0.04128963401120517, 0.026061081612903266, 0.06257121180815083, 0.08404886980931606, 0.04521005832019352, 0.04519090229164689, 0.02922134751814508, 0.08612759576569642, 0.09588772446037301, 0.07225315356927534, 0.0076318694083320525, 0.006258851198870088, 0.030992274668308038, 0.01719447190783197, 0.026781704134097504, 0.01853299413567349, 0.05399613686266446, 0.017225565501458703, 0.08368809602313465, 0.07579514576542763, 0.046048472605405316, 0.008260085446489675, 0.1196211436763406, 0.03126525286314709, 0.07829675225601082, 0.04069361760611496, 0.011440540641365994, 0.025702247944390102, 0.031898388143388495, 0.023167942905978813, 0.04205785932079439, 0.029484747698710814, 0.18874452930063973, 0.11880633256007588, 0.16144576752858777, 0.12424781678184388, 0.14429063806610723, 0.2288252076194171, 0.1012605365606085, 0.08836040498628732, 0.09213589312088105, 0.20882609931211318, 0.17664942589979019, 0.1804909891178531, 0.11573657228220856, 0.10472433416232949, 0.1805189053618139, 0.28528706741429144, 0.09538468048577348, 0.08615967952796529, 0.20839203389421587, 0.11165883947884846, 0.14444054615113044, 0.10769111690141502, 0.182480534778968, 0.21849244352309935, 0.32758186240830733, 0.2551289437518966, 0.2621660435632352, 0.07145233121850798, 0.0646371440961957, 0.13071339967991077, 0.1497538408805286, 0.20657913278668158, 0.13262439068526993, 0.11727995599710173, 0.19709887133250314, 0.12884803687132176, 0.15573733996960426, 0.07610267644087154, 0.19473811010679892, 0.12603179807023657, 0.12695726292628434, 0.13628146460940763, 0.31976129979856555, 0.14102175621496094, 0.13987579593254676, 0.27389656572091964, 0.3066451084469595, 0.19318307419457745, 0.13305704650138656, 0.20952069591129982, 0.18756925849424255, 0.11040352014524323, 0.16726466496625256, 0.1445560262448365, 0.1416227062262835, 0.1137524888279938, 0.1423229871978683, 0.09524274737604203, 0.14122138340626994, 0.1320835479324864, 0.17869288882901593, 0.12297721399414925, 0.21922623318049217, 0.17401938476870138, 0.10249975272604536, 0.063105512170061, 0.1022336291029088, 0.18751244541377793, 0.12006281634732602, 0.1354403613555816, 0.1299981799938025, 0.08905874009454444, 0.11377695001541607, 0.16513431234465492, 0.14585376386680912, 0.11955785715291578, 0.2008452251433365, 0.11241852290808194, 0.1202192361797056, 0.2397269298953395, 0.14677985691495482, 0.13616914079794962, 0.10997175299111875, 0.20515184969671313, 0.12469333521420918, 0.15304444898520747, 0.09855407815907272, 0.16077475111571052, 0.1256373470589038, 0.10913714616289062, 0.21297031322554236, 0.20981824446109035, 0.2541712419159951, 0.06844905205070972, 0.24319655742616425, 0.10465594549332896, 0.08107976582381995, 0.17727911953003178, 0.23347168409776306, 0.16639788244520465, 0.15130336095969524, 0.15637158416211605, 0.104095873933646, 0.18178201580960907, 0.11516349254957131, 0.10113243899878957, 0.12996768969441616, 0.2193877245149305, 0.15203040904335438, 0.08274439061360975, 0.06766905963060356, 0.12459572029089737, 0.16231762155169444, 0.1508679625488097, 0.0888589290421336, 0.11355702149411363, 0.19239165940352027, 0.18389980458924848, 0.14160606679656815, 0.1401282065818387, 0.16877931272310598, 0.13791649542268247, 0.12281158578491981, 0.10327620581994135, 0.0725200662629739, 0.16010158965664525, 0.15928115545501634, 0.16176855101460413, 0.1935516390949488, 0.31387826547988, 0.18450303754258543, 0.14162647537887096, 0.059296281692842324, 0.12495758192193125, 0.12408257161657657, 0.078370020905089, 0.1152008776402762, 0.12667420109914196, 0.12424063853799336, 0.1319705652854135, 0.10663989105171735, 0.07927914510571188, 0.12588208916807367, 0.1246289072197772, 0.09785578901609106, 0.10945080554172879, 0.20032227820446416, 0.10702229916088044, 0.11198591305724076, 0.22546303158085193, 0.15756090502104453, 0.15015294204556173, 0.2336159078103881, 0.1670004565629267, 0.09421722377620398, 0.1623374325854163, 0.1370406424206111, 0.1842658413994697, 0.07425523242883145, 0.1070905346122961, 0.11631781851211864, 0.17341065130406813, 0.17945764376030815, 0.19005127611660189, 0.1308570718092303, 0.14798027072702685, 0.44100540840337354, 0.13079763870806466, 0.24811689501568196, 0.20152708936122157, 0.05893878293253722, 0.09083230258716692, 0.1493592443124902, 0.11197773889908869, 0.09092642414954402, 0.10367286316449605]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.016414559926957856, 0.03697094740346074, 0.04151691314614108, 0.05694634911994781, 0.0400447411342494, 0.038567719785797025, 0.05087212989887884, 0.06307723969521542, 0.05051935407062692, 0.04917645939595757, 0.05102186561411908, 0.03593652569238217, 0.035017833053585024, 0.07777652492926967, 0.03482383660851948, 0.05313244933683065, 0.03138808740092622, 0.052614941622220704, 0.025651282030007532, 0.0723452449986531, 0.013694930558783874, 0.029184058188430728, 0.041491310487711625, 0.03517010451985463, 0.05356972849357033, 0.019247562647046104, 0.11572693489612111, 0.02824743334654599, 0.02390792446901962, 0.05838249967763982, 0.05313275577200036, 0.028372998987775178, 0.01790868035788017, 0.02083772752103546, 0.04180933656771818, 0.07152514787571085, 0.07236502538885801, 0.028587513182672764, 0.09387642956308781, 0.03415710262713894, 0.03164421357665091, 0.021303424709326318, 0.028247295450719617, 0.09462699654602236, 0.052661071606581254, 0.03119724340766909, 0.04881700328100593, 0.06250021844020774, 0.10907234278537574, 0.05018498350475585, 0.029859797533361182, 0.049810025600656394, 0.030524713971141367, 0.0315343757205072, 0.07192636344341502, 0.0893985843586345, 0.001686296339856551, 0.06404552886623048, 0.03115927800536156, 0.05011182976886631, 0.05164564887602484, 0.0829389616246185, 0.04172081893850719, 0.06148750766090328, 0.07259763266530729, 0.0188406856895815, 0.08306208727580887, 0.033162961819119034, 0.08078159674281075, 0.07481539591906533, 0.07347180027394526, 0.030300930112359986, 0.059637049092881145, 0.0862599604372536, 0.028013860799312115, 0.0029275836958174385, 0.02828094969323326, 0.031086603074424693, 0.030690604565484874, 0.015797188820978327, 0.07075948896066797, 0.06276658721148007, 0.034916437486366886, 0.02799959624216201, 0.02936083872261788, 0.014721484546880088, 0.03453717033769335, 0.02554949958838763, 0.07486905271728193, 0.042816087182971745, 0.04537923351651238, 0.032564520745748476, 0.05408152885314438, 0.026015905408008445, 0.025736672105267647, 0.024572319967011293, 0.002414170960565248, 0.017782909788131233, 0.06443809913170916, 0.04738085272331392, 0.008063144350965178, 0.0344096971375327, 0.03809310533406754, 0.05159038712360686, 0.03346688038999996, 0.04186662462269587, 0.02669532005975564, 0.06230509967633313, 0.032653536332110246, 0.0060521654649487435, 0.028522566163672075, 0.01753367648850526, 0.07427819208392213, 0.030049561342645078, 0.07532815388854473, 0.007828634782438918, 0.039922921662969936, 0.011233775425822505, 0.03620533828413294, 0.07977047559594916, 0.017907159673350475, 0.04620472006800194, 0.010384644528159933, 0.05900057558450968, 0.07204244874658124, 0.021183440018625512, 0.050612682732002395, 0.12587611368226428, 0.02706338317253657, 0.04883840777761033, 0.03231857204809785, 0.028433830199402668, 0.08437091785092508, 0.08079289653969389, 0.06813268072061962, 0.026904584637152094, 0.01208429390023793, 0.03026941900081452, 0.02856086864466629, 0.03638317410443579, 0.06868843154440965, 0.06075714624697163, 0.01659782539542404, 0.026698587424752694, 0.045329686780009544, 0.061134934845951304, 0.03370008138459056, 0.03311847509335607, 0.02148448959023001, 0.031781213080149986, 0.061061126104886496, 0.05483924726685209, 0.038930129169696764, 0.023920390634767474, 0.0462316480585404, 0.040752054792979074, 0.02739005072432901, 0.0499308874620305, 0.11469787197007288, 0.03289209611173118, 0.027756483985051036, 0.02241210140768559, 0.043422449605479356, 0.05616092513645849, 0.03588207982360356, 0.04019394441838226, 0.044012115141677285, 0.004695841747771708, 0.023248288292257537, 0.07318995652660247, 0.11749551015635652, 0.0919009109718665, 0.007439344809691032, 0.05439192852786472, 0.0069310928736212515, 0.03309865639875493, 0.015302101627082355, 0.058064389327961596, 0.009584948326641274, 0.02434924090912025, 0.06453294081673508, 0.019132390903729587, 0.024598602528473543, 0.01394949678797275, 0.06681091858134156, 0.06056120393857841, 0.025303979899974603, 0.04659113098656939, 0.017223882023245096, 0.04492254552221106, 0.03885235975406343, 0.03314541457521339, 0.017646398665683887, 0.025405973015773683, 0.009786889103481607, 0.0723369406055539, 0.04002137928299847, 0.0299789605947632, 0.06114430027082563, 0.045856690154440945, 0.11927545416138827, 0.029549041627756054, 0.02581545084174122, 0.02839723226403998, 0.02675382619453294, 0.08423254705004155, 0.0368064989696347, 0.03544056037020299, 0.030086982822526368, 0.026906549652677872, 0.033281709277822126, 0.07089468049666575, 0.09316678699706832, 0.0039059126884826733, 0.027798431129345012, 0.02109805568902483, 0.033248346148719715, 0.03841964265091285, 0.06052862988003801, 0.012572495878914432, 0.01634686648274862, 0.07154521171844776, 0.08260483237644357, 0.06386295862255559, 0.011891696523244103, 0.015594559522616047, 0.09532376883491393, 0.03777557338077215, 0.003021546055547773, 0.03496353657195165, 0.04680212692267472, 0.04233238309802067, 0.03530079145885764, 0.030883453793883808, 0.05404024054446528, 0.02748969961107979, 0.06488488160914953, 0.11328820124148362, 0.05714277789417294, 0.0074780365591117694, 0.029566152201544856, 0.02583681320350978, 0.03728639942804172, 0.04387893075604112, 0.012166646436878271, 0.039109340117823695, 0.050805464927707954, 0.014355539667209791, 0.06545940158708442, 0.022779635919798768, 0.051975273527205, 0.03405107605841852, 0.052472771025232734, 0.04009570896385178, 0.024276328490926855, 0.01527154812544224, 0.010422225928895417, 0.01620351802557707, 0.05258939258994595, 0.09985797512795656, 0.03717090018213757, 0.02424007337991028, 0.013126466505890413, 0.008038968531294696, 0.06842469045471761, 0.06283198047669665, 0.0440937111664924, 0.05498877613835278, 0.06281640590919603, 0.003684038064450086, 0.014365692247426318, 0.10731887477900713, 0.0340400290705504, 0.05516933540122644, 0.025233900091881235, 0.06174225104792465, 0.07620147880046599, 0.028137652946996595, 0.07020592914834138, 0.0817485069555621, 0.06009605067271379, 0.0560910732395226, 0.04439870609090694, 0.09033982296504321, 0.0648350705723128, 0.00705673129320325, 0.07761000039716882, 0.04028292553078744, 0.046273507102723085, 0.03741563463042821, 0.01773264101375976, 0.05053110585938539, 0.030755748852126064, 0.04252916044225136, 0.014333486868699473, 0.059072239279386506, 0.025242319398169077, 0.0658461763974159, 0.08084682912956323, 0.05584372643141016, 0.05705116143930824, 0.02208657532690033, 0.0253912641276275, 0.011060914388977954, 0.05447797169308028, 0.014034580428063149, 0.03945948443405571, 0.013109366465810568, 0.042104448957909504, 0.03814448685114903, 0.03326167607860219, 0.004226279645902856, 0.08181205394888118, 0.012043804238219897, 0.011130711702149243, 0.040808419712008014, 0.007735750930864485, 0.018528152459992037, 0.05724200543256537, 0.028516655795336254, 0.07563168558502391, 0.02649024406808519, 0.009189218906084857, 0.01174318271824309, 0.0382827733823609, 0.022274178768237753, 0.11007325964108591, 0.02522139753695698, 0.07585879235017685, 0.057626646688027736, 0.06019340895657098, 0.03794314745332926, 0.05858113095464726, 0.05156043308576749, 0.09425816351487752, 0.06665211621551745, 0.013283300983359017, 0.016565281980400606, 0.10996356351120819, 0.06696791297966434, 0.028365146586551305, 0.03495856466132306, 0.033118038423239224, 0.04093130787594184, 0.014103546535836594, 0.09045734851350708, 0.11116713360552827, 0.013896482546002635, 0.04033329198136926, 0.036880706076420126, 0.0973131153131685, 0.04347975681265516, 0.29683694603943056, 0.1678517028208702, 0.16949663149012675, 0.1587317938045148, 0.16943753546764775, 0.14973321779360696, 0.08374297090115086, 0.25899517500112135, 0.13973491236327157, 0.23656859453166687, 0.17699969662052972, 0.2141952112076744, 0.12138986449328162, 0.17545648910585912, 0.14728858526195251, 0.16988512999828786, 0.06893622268351816, 0.12601070000880188, 0.13319822118407296, 0.16505523674911068, 0.14673166998451756, 0.10099350129284206, 0.20944283073467596, 0.17814633106031727, 0.15583984253387298, 0.08935753736765155, 0.2109367787958153, 0.14288094435488025, 0.07337400148953162, 0.21177900053801077, 0.11135421227663757, 0.09808887892793264, 0.09044345167856063, 0.21909512489313082, 0.19261034686238537, 0.21367254006045483, 0.21893974694032825, 0.09200834714236761, 0.20110952547721325, 0.13486879847703442, 0.15912249864589784, 0.10856804242658039, 0.17884553950880805, 0.17061338850086735, 0.13928190925188605, 0.12148760965154057, 0.14115785939558861, 0.18517270564071595, 0.16337748887317796, 0.10357580748536896, 0.17154567153944125, 0.12482982143879899, 0.1618874938257279, 0.09047189652318917, 0.1481699540970787, 0.15279727837731763, 0.09462881983528215, 0.14739560774497448, 0.11625669235664031, 0.15460722238546418, 0.12825322322427266, 0.2371847284056487, 0.2183436845699626, 0.16211329058053034, 0.2037462622167603, 0.15511732969072559, 0.11987308701199871, 0.13341565225874225, 0.17112003308871102, 0.17975825666179582, 0.18016374700011747, 0.14871401441914422, 0.13291993208469885, 0.09028156963928093, 0.15741969969484115, 0.06851400864580948, 0.18102766435232856, 0.10425874422634802, 0.10089583274337555, 0.09908411907212389, 0.16342052769276405, 0.11067532814077793, 0.20924547116362283, 0.18467272601781354, 0.12995175506559112, 0.10171340177616767, 0.12217031656614236, 0.16743663638349504, 0.09447119724486144, 0.2061044800305559, 0.13717697542761603, 0.1619601189609497, 0.09382571454250044, 0.08308879310084928, 0.1601830094812378, 0.2518342294159436, 0.1625511404727736, 0.10518328977688667, 0.12319514302596932, 0.19114828338065457, 0.13530882405898265, 0.20257482184998452, 0.15086705856505903, 0.15978761618175816, 0.16938827601411652, 0.19931398392204316, 0.096735515661778, 0.17458716317290263, 0.15788937287945903, 0.23249524375123365, 0.14963984699739566, 0.06972610529872679, 0.16456573720901244, 0.1485568591423573, 0.20026895848493423, 0.13340128044928276, 0.20402888737378583, 0.09999019424280814, 0.10821693667000341, 0.20796492455467103, 0.11056796091819003, 0.12350404499879769, 0.20487683945365492, 0.15943192155851474, 0.21270869419940058, 0.1477467211624307, 0.13492214884008133, 0.2724895992827031, 0.12807647907926192, 0.12066347524523736, 0.10886048883079522, 0.07655267648759388, 0.20900249871755802, 0.2748346250624426, 0.14469206813843022, 0.12029163914942935, 0.12792848621404942, 0.07063599558727396, 0.18175255206804122, 0.13774423289202875, 0.18620301729008076, 0.1832808668334638, 0.12794636670620213, 0.18841834438423957, 0.16234562972620611, 0.11375050466026991, 0.09593250996042645, 0.12060371272626424, 0.09775711689144374, 0.13419090259459712, 0.27644463544411046, 0.13429610178835932, 0.14234223132652624, 0.1513530034571886, 0.17588951264417943, 0.157644531178859, 0.14119392681506374, 0.18493506516660416, 0.22210398118101785, 0.09732389417026313, 0.12351641731877482, 0.06856830129700323, 0.16032530265229364, 0.1459185289399278, 0.0990888994607714, 0.09945716558685226, 0.12175125114980245, 0.10795943919689426, 0.07490511247587782, 0.18780179682277864, 0.29674020445635246, 0.14736583756823696, 0.10890546585282973, 0.10881874469980117, 0.11859786471412068, 0.1804599319134028], [0.10199367504326567, 0.023510050959885124, 0.11161997583844971, 0.07331442283166033, 0.0358043065775306, 0.12370806953479206, 0.024960671003246983, 0.06188808354519068, 0.07962039897158261, 0.020959861088363875, 0.027785729391560442, 0.05349022005834887, 0.021132776708973032, 0.031376291562112114, 0.0574226298129126, 0.09037511663571482, 0.04258359481971111, 0.05261424065176999, 0.01821609803535525, 0.03688183605610844, 0.015930332986998464, 0.033063960276664264, 0.005365729138570568, 0.008074536078399228, 0.040156467397126465, 0.04490737315087069, 0.009424757426454416, 0.00525977582700791, 0.0463265931654361, 0.017027426435942614, 0.04892225610092283, 0.04683678474036917, 0.006352997180299774, 0.010624674238985585, 0.05185279522031065, 0.03977696659163602, 0.0327431226539756, 0.01198283608837594, 0.03589642481998571, 0.013276489504102259, 0.01594803632131868, 0.020445862056447134, 0.06972512470618372, 0.04344370471493852, 0.05130704950481173, 0.05997886603337623, 0.04147350277391173, 0.08498544294026592, 0.056383910348578814, 0.04478273447602988, 0.07393529112901419, 0.026072241598740224, 0.02533435528617232, 0.007625818271340142, 0.01804033065244796, 0.022542070139259584, 0.007867314561735839, 0.03452193284887941, 0.06658607943644447, 0.014382575867667556, 0.07663532971374451, 0.04878248335913785, 0.03836479841641361, 0.03279211397673334, 0.00973007985345659, 0.03857739930672031, 0.05419219408424632, 0.0733538457162438, 0.04877777191840353, 0.03170300890961963, 0.043989446599997824, 0.05681915937231914, 0.06816403669936043, 0.0534769092806645, 0.06405826890841126, 0.04232587518110391, 0.02836737590241096, 0.0163273369863389, 0.013480906660157829, 0.04126012047392227, 0.03144757221302679, 0.054224932851690444, 0.013217887608334424, 0.031423643456711885, 0.018684551224953706, 0.029827491605594277, 0.03971056592079901, 0.029342123194627708, 0.07069614881108846, 0.0893030838379937, 0.03647996548322901, 0.022607595554643103, 0.09470709869938512, 0.011570333172717403, 0.025329339325488098, 0.020282365486867005, 0.01801157554221009, 0.03128849214033014, 0.05598227726295591, 0.06681430468996687, 0.02468915986678293, 0.06006090638918742, 0.07543090926182848, 0.03935018283945899, 0.03846016104122804, 0.01749747117320376, 0.036316466998429074, 0.12765550610399054, 0.036781359794399435, 0.07423194335593332, 0.04211125564911673, 0.0410872757164461, 0.12376686678298059, 0.034712600641913956, 0.07694810809146974, 0.0221793849637071, 0.029960482554029555, 0.045149974044292204, 0.04101556605629383, 0.021205024545892112, 0.061674865954104936, 0.05940597782272005, 0.021658270890193603, 0.06509255272366347, 0.08095196703629148, 0.026776155742305904, 0.02485189609409821, 0.02990081196560735, 0.005114866465690636, 0.026039805436026187, 0.06257788826441092, 0.02264706248928222, 0.013607760286709715, 0.043812020636734464, 0.09429941734960003, 0.03837133314640772, 0.019425034575584917, 0.12548977554204965, 0.002035922230026054, 0.04345827953769796, 0.06585902369190609, 0.05413388330188971, 0.026311655566396735, 0.0428330100652191, 0.04744252663165812, 0.07298975476935025, 0.021563310461539417, 0.05350101040676237, 0.002404891241777448, 0.020804617200948058, 0.05283530681363998, 0.08302294018287813, 0.028006372289852272, 0.029447690110593557, 0.1282164893083034, 0.04982404500967072, 0.04627394377283993, 0.056418380474731814, 0.00976223064841883, 0.018254519259977727, 0.047605442889635606, 0.06270662934008626, 0.024576596652848587, 0.05435645099609129, 0.04516532644629479, 0.009097016393958081, 0.06026810252918832, 0.045525529496972604, 0.08747311429150643, 0.03429292618567425, 0.0514264366469316, 0.01832713098866084, 0.009366640081298689, 0.05888992184472661, 0.06382151709629164, 0.024033834849814736, 0.04578154075950865, 0.06790441716270101, 0.12211555660131479, 0.06621572189033031, 0.05147815141226015, 0.03327519370002612, 0.05009818191249525, 0.014841205894856926, 0.06191843594875067, 0.07471264054578158, 0.054056496930218516, 0.0858634103450083, 0.0510265579026553, 0.04665038788751249, 0.034279745642937, 0.05752152410305797, 0.018398963222881, 0.04664170045045115, 0.04827702237713722, 0.027638431751139225, 0.03458120890202061, 0.008258644243582122, 0.029030842518794443, 0.04029744289695256, 0.07687070256760044, 0.039428381264329924, 0.04053071283945634, 0.05368207528766605, 0.04094730762224044, 0.029015440321076783, 0.0460869302192042, 0.022293059005131646, 0.04561145008812028, 0.05769667861562583, 0.042754915062217944, 0.013526800114871755, 0.030371494471065463, 0.01871938332765093, 0.03500389025336312, 0.032748971735277486, 0.020517156113900488, 0.055525436051069736, 0.04456297066363116, 0.029032399592500542, 0.048704066599208506, 0.05352172542423491, 0.047631463065983794, 0.08835587740665482, 0.045103533794322324, 0.024996315159143943, 0.017483913332163807, 0.02783827727750665, 0.016276983942295757, 0.04815520290585776, 0.06754087779911296, 0.019766663824538552, 0.03870400682752652, 0.07201207336038351, 0.040151893852218505, 0.010774770973160142, 0.03844563601418369, 0.0560514664938373, 0.0667017204086146, 0.004757908754982054, 0.06761906473266502, 0.11005269784119823, 0.012997620093125491, 0.0460214986495914, 0.04026860351704302, 0.03906297264620662, 0.0629442774750773, 0.058240784902966795, 0.03448099311020586, 0.043282458528635964, 0.03691567799016353, 0.021365284393992157, 0.03433292746664055, 0.032621352978411226, 0.01612583671005503, 0.02504072144567486, 0.07546220395353533, 0.06020895671099425, 0.06628257072260303, 0.035686041754219806, 0.03943731767996665, 0.013895856269124537, 0.009887953337672497, 0.10313447189307022, 0.09529789804571098, 0.06391065908716091, 0.042803998315526594, 0.009029258789885189, 0.015369027068147497, 0.08576504465553068, 0.026551714963129452, 0.013068051344054121, 0.025549106968326435, 0.03574843195477321, 0.05509698988809701, 0.0094833325091449, 0.013184164417907597, 0.025582021935993147, 0.06256230986647068, 0.020465115761204113, 0.05877811131217788, 0.02916358065821471, 0.04272191582487957, 0.13439670445457583, 0.11491508087924412, 0.05938964099773477, 0.04738847146772089, 0.0732959830953229, 0.03530270284822872, 0.03794998861849308, 0.07176106465199301, 0.021966261218392083, 0.007490362913813443, 0.03996183892952339, 0.017878123025800434, 0.02748098153050148, 0.06331920090522017, 0.050408451352268464, 0.020942269794402585, 0.10144267396460618, 0.040370148471406395, 0.050011636959689285, 0.03046432900572977, 0.05588157117486962, 0.027238855611593015, 0.04156545247702349, 0.0725324156003133, 0.028684637809713042, 0.032401512557220076, 0.055440090025865266, 0.009388681388490144, 0.07150205798567304, 0.0363234345681004, 0.10132903248191842, 0.0634069562769465, 0.027821925130762884, 0.026849654217761372, 0.03718468593433499, 0.03743459530655415, 0.019274176541535605, 0.05906327605067242, 0.017889129794052532, 0.08670998346661368, 0.025411473527070016, 0.032630890773068515, 0.005488170577483553, 0.02536483409423982, 0.11501685565998478, 0.03190604519219168, 0.09212692223128774, 0.019130117537814285, 0.04376968278759911, 0.004732680522025593, 0.11191193960727223, 0.05424362539704289, 0.007141907342649516, 0.02136567509883354, 0.004189568233766383, 0.06745545899555569, 0.09006138830896347, 0.0753564072111922, 0.05887645018857814, 0.044840168087713184, 0.044893395876692194, 0.07622962487080405, 0.06763383490784515, 0.07773592993016205, 0.03792532441777088, 0.05183773776215892, 0.0686463809782459, 0.018052992170616504, 0.016178018789017395, 0.16776499698960012, 0.15977575714069028, 0.24728737501127107, 0.17739743414905765, 0.20947201868459103, 0.18714703679565461, 0.06864150865904747, 0.16439588019444099, 0.1809406367641303, 0.14576059225345814, 0.13422136225046652, 0.26055958782953603, 0.08574409215080162, 0.11222279510430752, 0.14482924384215187, 0.187489478097808, 0.053994669804289463, 0.09368637080995307, 0.10815192644874896, 0.15546491910373011, 0.12434521720053689, 0.2285501973763589, 0.13895937091400548, 0.14006691954789624, 0.09712383030883728, 0.13878366098769251, 0.15258805976519663, 0.17353846541335508, 0.19248985655365453, 0.11205855351422103, 0.15844031267108458, 0.13849976412471265, 0.16003464889382163, 0.1408693200397876, 0.15306421405365392, 0.08699336705068428, 0.07350121805023763, 0.0851419163988002, 0.22317529385609014, 0.1275798855649848, 0.1233926021884526, 0.09949321002368966, 0.17384169833554378, 0.21482826030302435, 0.1569688416296436, 0.18541238390870635, 0.11355156694809276, 0.19420310494399842, 0.14771961697166966, 0.1273773549004428, 0.23125784321417733, 0.15241942849130402, 0.10013655534074192, 0.11776578597604268, 0.20868074178936022, 0.1624401802978208, 0.10910733002087764, 0.1637988831968077, 0.10137560296683543, 0.08954664617176018, 0.1068928073190393, 0.19384338069827328, 0.1567894391595356, 0.10752120626068885, 0.19671778855544908, 0.19105630686446545, 0.16736958836836202, 0.21729158538003124, 0.17337735712287888, 0.14433690977673377, 0.16247045609258837, 0.18309015690559344, 0.15118706881278945, 0.09250942993188098, 0.17239405262854793, 0.13967043840356413, 0.21052787170535137, 0.1517544182077531, 0.12789162972401227, 0.1372681398906054, 0.15065548040213125, 0.15724607352768222, 0.1424242486996997, 0.08328070578676078, 0.23435521330083572, 0.12744467104634932, 0.16493390374366315, 0.19352332448526738, 0.16754765784548176, 0.17760199494659903, 0.13954660795148344, 0.1710951352311719, 0.1610478614607165, 0.13538118872431018, 0.11423600522140342, 0.11222306323508102, 0.08766003974503087, 0.10490150731657782, 0.13814480494587653, 0.1207109650356635, 0.16687723898118542, 0.2360700551540621, 0.18247028452254113, 0.24055839576307805, 0.1333031752296994, 0.19245388106473033, 0.23922465200866425, 0.26283312228418165, 0.20057448967089578, 0.2935981101566746, 0.14297241525303933, 0.16394647769629955, 0.19291567886548658, 0.14482631738628113, 0.1369382011433763, 0.15441565443911862, 0.10385467115068629, 0.09423891172534037, 0.12378207362827756, 0.14314172068430533, 0.14357946332423918, 0.20582090492450422, 0.1810823323866052, 0.16443478213923593, 0.1595118245290172, 0.19333255327036306, 0.10739019756475765, 0.19950818721084826, 0.07128747675808207, 0.11517178162091202, 0.197158656834114, 0.1360559896115334, 0.13922299709050887, 0.18181085135907898, 0.153411757501383, 0.21104482783665582, 0.08359213584973928, 0.2936053113831628, 0.1364162807623225, 0.08178001615188776, 0.19369259927301638, 0.12376531928537354, 0.14700075070704186, 0.11772169761600033, 0.14328189945269015, 0.23984568884536145, 0.18620859441016951, 0.10132706363595302, 0.08349856587066766, 0.129279512912035, 0.17939323108763466, 0.1898400503541193, 0.17122794423372517, 0.2047333511854372, 0.25365339712269847, 0.14541254318769903, 0.15973058859667472, 0.21532108466471397, 0.10821060878374886, 0.10401030191250386, 0.17236604445403622, 0.1207261029330473, 0.1648050324330407, 0.15031916780337212, 0.31011683505869686, 0.1231155158471196, 0.26245118148865243, 0.13647842581474012, 0.25506224813720874, 0.1286241706580885, 0.16531910807374986, 0.08738273123819983, 0.15118155297973465, 0.20877659471044618, 0.16082762650424437, 0.11552534651972594], [0.06082571111619473, 0.013156771028955138, 0.023233837958785798, 0.027913876749094457, 0.032349613930789695, 0.012918580886757663, 0.03532539437254591, 0.01184018955926501, 0.012836048319455118, 0.05815989367904202, 0.02783693853885897, 0.03737412032581145, 0.04310924604895615, 0.005365517027976533, 0.020013152614175793, 0.01937267629639997, 0.017552516505783124, 0.013549271388910713, 0.02122126944032648, 0.01709791801629528, 0.0712390523403883, 0.045988966725886836, 0.0309944867471894, 0.016756114482338873, 0.036958464000734596, 0.01967135482587882, 0.03210215603992824, 0.04770655500432176, 0.07050095726886103, 0.027389487649704662, 0.028967044631680174, 0.034101059465038205, 0.03003839944158831, 0.02921089233319846, 0.06986508130907051, 0.05616678953951886, 0.019347929741225896, 0.03936191930645897, 0.02765677955692574, 0.021842153059438835, 0.029570547631010417, 0.04622692512648721, 0.02667778622238867, 0.022525685433779034, 0.015198041989107527, 0.03193976838261851, 0.07570428007672872, 0.045468881125411684, 0.06083049150484224, 0.02654397747509422, 0.008030128355453452, 0.09712719343482487, 0.08477437039536816, 0.024678417398864706, 0.02809112651213523, 0.08734358414526909, 0.026638166070164695, 0.04069115846387802, 0.020428705517382875, 0.04012473603530277, 0.021217927381756808, 0.027190948303248134, 0.03765946892540782, 0.06645291803344604, 0.045589631904036775, 0.035051242147962895, 0.043950655737951885, 0.0287358163134946, 0.01397814847634084, 0.015321667512668478, 0.02606008186816208, 0.029390019011653723, 0.005601457265701386, 0.014967102869113368, 0.007833933238045224, 0.021016181957337166, 0.016253905543576808, 0.12665552387554802, 0.027133371050079024, 0.019578912911275705, 0.03354662248203832, 0.01928519863154619, 0.026800281766261307, 0.04455999058160571, 0.08443909967618604, 0.04784284587649088, 0.0360724794858646, 0.031877671210696144, 0.019130107961715232, 0.06048372946679593, 0.05612939678793473, 0.06851410823723963, 0.026630595206252994, 0.031572973145352255, 0.023465422507856163, 0.023009014135647207, 0.06708805088795002, 0.04063141509710301, 0.06632318870434839, 0.07040434592073003, 0.04253733843084305, 0.05354842358839609, 0.03312473786213706, 0.04313109870699625, 0.07249810252218478, 0.09014410282214803, 0.06118641212402333, 0.0505724516246588, 0.04568270392595761, 0.016871747793629766, 0.03291867170182448, 0.022254815895951564, 0.004693931794815487, 0.025186990613057732, 0.057971956989457535, 0.0384535305502434, 0.030451587048329176, 0.06175217954742332, 0.02750747668136272, 0.012772545376191697, 0.027611346712576288, 0.045584234814610214, 0.06129603547554824, 0.0677253517712797, 0.02391705240663742, 0.0846640230907548, 0.025374860269948844, 0.03266477484195944, 0.07672537568836443, 0.0037143040437161204, 0.006891647964009956, 0.0953727448359132, 0.0400003923043128, 0.030405999071175055, 0.03926931842861157, 0.0438903990922676, 0.06277420978632665, 0.0848870236246336, 0.018798439770997055, 0.09021141896805457, 0.013479640699862955, 0.02645129232757515, 0.044606484457730286, 0.017867390133981264, 0.033153240163359916, 0.044397488011107336, 0.03156882286402247, 0.02828510188978286, 0.03944847958102342, 0.032046268010632165, 0.030210422569765683, 0.01506103195189949, 0.04647335645953014, 0.03283371638146139, 0.027501960848307902, 0.018927998645531557, 0.06865902142899652, 0.01636688627542988, 0.08315554234169184, 0.08563278723628291, 0.014270555618549547, 0.03528991301033286, 0.05697577455711942, 0.05240938874081739, 0.024380562413904457, 0.04623279719042682, 0.031469258246943355, 0.019579384055349137, 0.049870784033931075, 0.12028745630936277, 0.05372771497575506, 0.03699056691520157, 0.06176782306283713, 0.05836262735688399, 0.011723969233102136, 0.02493973956593583, 0.04926305414447862, 0.0456635708800487, 0.04991726258829717, 0.05341645345211991, 0.03699288050073289, 0.007491653771965855, 0.056393700952251116, 0.041653272966223384, 0.012579566870455541, 0.03768074318706509, 0.060622153893834164, 0.05374596319011143, 0.018331097408888802, 0.04956829421702893, 0.06769293859120339, 0.052620304237690665, 0.039570885109564954, 0.02366585026104604, 0.06631457787607947, 0.007174095484398066, 0.010576761184981274, 0.01727212449505685, 0.03525013772530421, 0.05373799204525929, 0.030355448759491407, 0.05629662229048629, 0.009632218824399096, 0.051676162158048926, 0.007719967125599543, 0.017240509961641604, 0.03400773846454198, 0.0522894959806675, 0.01532957832809658, 0.010798271677847351, 0.09313079618638562, 0.006503218403762027, 0.0379834589999049, 0.019053769215280493, 0.08703318830098837, 0.02242926177718947, 0.028009287254404158, 0.04287356675993051, 0.043363376565638094, 0.05656910444339437, 0.07512699452138717, 0.033922231560873414, 0.056874945894965244, 0.03940915245743048, 0.05774621386080981, 0.014257423913917475, 0.007773663185822267, 0.06774842633955902, 0.1057393087314502, 0.04054910661051831, 0.05523486273182977, 0.031335363314757426, 0.025801098184479822, 0.006618963755411848, 0.06311491589933153, 0.028979083703410242, 0.061452635338590036, 0.03077999745014935, 0.035774260609140324, 0.06620771627152158, 0.07307660615732593, 0.059304582255501906, 0.06321685155853629, 0.0657573868069918, 0.026854133916898604, 0.014862937894048951, 0.0335877652340118, 0.029084600823661013, 0.019472445841998826, 0.03772667398856532, 0.012931086314511637, 0.0687556097944898, 0.028462200350458586, 0.024849785521866816, 0.026867963719151677, 0.04752156392280613, 0.038731172305321505, 0.07361835289386011, 0.04214112541728443, 0.04892127550837975, 0.10240897896789736, 0.04472144744208744, 0.04455542852801662, 0.02607709285052073, 0.011580073023064723, 0.021033125907002438, 0.0056952355249274165, 0.020356654948104295, 0.04528534944139181, 0.029449921341673024, 0.09028640365408314, 0.0254833459809062, 0.03425005590543151, 0.046121714441406156, 0.02972373840278916, 0.05219828555240266, 0.04493903939522082, 0.0252237819856213, 0.02249803157493232, 0.02507669501937926, 0.06806755558617654, 0.05125194863085786, 0.03839956731685708, 0.05818349301754948, 0.03444094969440372, 0.061151601088744026, 0.023681723602837133, 0.026881404731783177, 0.011123920332700496, 0.05790461020003404, 0.048001115811207605, 0.025504625988222902, 0.011931015028347893, 0.02672968293359924, 0.02541770948277366, 0.016341666660962567, 0.042088552633480686, 0.05895416214761715, 0.04999971280114786, 0.044547756157454946, 0.041228745342983354, 0.06055387247714305, 0.020024737778810725, 0.01616025512527314, 0.05490648680396619, 0.05262466710841945, 0.02208928727815228, 0.023184829399049766, 0.06029510329807959, 0.028544416906492367, 0.047388996237949024, 0.034068979533208955, 0.06445014203387885, 0.0635684246287471, 0.02537671611794541, 0.13386903841408992, 0.010355582982752352, 0.017979985906652386, 0.05041800829912386, 0.010538758435887436, 0.0396553156596999, 0.07320415979671864, 0.02246192393584117, 0.09258937120677964, 0.05966415328364219, 0.036062669729994196, 0.06362421498183282, 0.017349635356015736, 0.026980948281444372, 0.03252358866795417, 0.008417668774904264, 0.039653576640111786, 0.08787053006310618, 0.04501059200734862, 0.034174492823020104, 0.03478680008782014, 0.040617537414354664, 0.05026731114353865, 0.02549085555778396, 0.06088987481029284, 0.002774476236100459, 0.02966782164519593, 0.041273289525340644, 0.04280481419916596, 0.07411237235271162, 0.04244792830920027, 0.023722479480408856, 0.01575808386288343, 0.013838355624747854, 0.13675361991890017, 0.03109127046510337, 0.07280646823346615, 0.12307489020449501, 0.15566728888980805, 0.08589405386197953, 0.1034341961325657, 0.18345648482922586, 0.11162839514473755, 0.10240183902844306, 0.07896957663638939, 0.08611853294555219, 0.11198439620315068, 0.14597031648360914, 0.11948283416249099, 0.21047623737925486, 0.1138895266358891, 0.1384512554373472, 0.1282730265971153, 0.10806466903417342, 0.14208922312865335, 0.08619340271839211, 0.07092934597523944, 0.14868842708247323, 0.22558877725274334, 0.15972969993468256, 0.15647963320295658, 0.12107003810665301, 0.24773460181970752, 0.1490896426501774, 0.14906287553810305, 0.10136397375214486, 0.13588312953229875, 0.1056533843098629, 0.1676121471269477, 0.1398477417927596, 0.2572100982069969, 0.1736789659386681, 0.1626037247478962, 0.14234264501400534, 0.17992347118354615, 0.19353942765343576, 0.07873435700011831, 0.10155145078897478, 0.13612630116122384, 0.14862131778030627, 0.1274950106838538, 0.13659102541785087, 0.11448115335717318, 0.16096051211559004, 0.10475519984479874, 0.11611282104446043, 0.12099164432936138, 0.09167751207226708, 0.20512966379042596, 0.173978797430473, 0.1131303794682026, 0.1756165248732413, 0.1384423228521501, 0.07199807693400691, 0.13040740884119464, 0.22844208704848445, 0.18388483523120805, 0.21615212152321495, 0.16588765256587537, 0.10088813355973653, 0.12771473236141667, 0.2218257993339531, 0.1230755490401099, 0.25185099141972683, 0.1717319381573508, 0.04723022068520227, 0.0807224011289016, 0.17543560554904325, 0.1253923674624774, 0.1304780421478133, 0.08071013606123387, 0.1361241254715189, 0.12817643823162203, 0.08368161491929524, 0.19830101650328408, 0.10024455075542774, 0.13226224560170405, 0.1973073851437338, 0.15791246276949683, 0.21913096248622865, 0.09313255052773223, 0.1911528492646833, 0.12925159666807423, 0.14016059677927725, 0.15359233974689437, 0.10526359111310975, 0.13622034611480852, 0.12095068926892935, 0.10113207893746515, 0.09965316918227943, 0.16657630432276957, 0.18771504502623312, 0.11671150343552714, 0.18453262385822114, 0.11668344163486075, 0.1568810326317626, 0.11365345664202206, 0.16871778054102776, 0.08269414290665619, 0.15844265690013287, 0.11705546159177058, 0.12773382327248975, 0.1954132787162258, 0.236778732449297, 0.161973632751934, 0.1769453043779058, 0.10673514642422238, 0.16975472651181683, 0.07050936891426964, 0.09636487466313186, 0.20245753378877718, 0.125596935920898, 0.10100902223418798, 0.11916621768426512, 0.13916307369307165, 0.08752373738154288, 0.19604067408269454, 0.18909864578275912, 0.11027148489149348, 0.19475767599238505, 0.13811365581087529, 0.1456565881568578, 0.19851192050883848, 0.08712103560326562, 0.19914334549778895, 0.16656663629316515, 0.09602187411679376, 0.13629048912515565, 0.11445662322183771, 0.12720293966272186, 0.11452093630308106, 0.22084110055959996, 0.16872760178821702, 0.21788974683130943, 0.19030759381430765, 0.09268848000154381, 0.22266653486557547, 0.10411302664227064, 0.09936501287044057, 0.15266460727059072, 0.14368895261037734, 0.1068920182484773, 0.08346946219042425, 0.11178567299559233, 0.19636862100132052, 0.09682609023706568, 0.10294019965635193, 0.13117648450837982, 0.08479729174606263, 0.08676199317579308, 0.07823780945111668, 0.1156294655295149, 0.2042691172250817, 0.15859048122600203, 0.12340049289407269, 0.33570527489627566, 0.14817516349496382, 0.07642042672922535, 0.09633496659056795, 0.10664673221688117, 0.17097990028560164, 0.05517417324646827, 0.15628706934230943, 0.19578074044998617, 0.1818611986574627, 0.1527715378230618, 0.21557576293426178, 0.10683435481041671, 0.12507509980951587, 0.1673937661032523, 0.2480931156465123, 0.15488931128094274, 0.16752374058048572], [0.014877358541613626, 0.022885662488519184, 0.07367579416642267, 0.021445032231689944, 0.047216959703232975, 0.10172048042858801, 0.05192164737250536, 0.034239357487568935, 0.037896358633353826, 0.06273316279534372, 0.03595293529572026, 0.08648349723267941, 0.028814912976456747, 0.04498363337329319, 0.027110005368388472, 0.05695627761944648, 0.04461163256858145, 0.03708104572949871, 0.06229712470104137, 0.008535348498562892, 0.024673803634340727, 0.05636711387083896, 0.028167970876599994, 0.05317372232375126, 0.019657350738622972, 0.03788208258488486, 0.04900462970498109, 0.08921285400227194, 0.04391522417145391, 0.034971392803615144, 0.027624783894768166, 0.008543819515785624, 0.03720394155431179, 0.017680548950128498, 0.08187573883802661, 0.033624185053932096, 0.022621331511125452, 0.03223864226451805, 0.041947726520799825, 0.038942455524398435, 0.05375518305828014, 0.014493898019164562, 0.03790236476268019, 0.024034497515869238, 0.029232095731722734, 0.06762884767545808, 0.006696032679399416, 0.028766862026626067, 0.013719489422416496, 0.025644325951655066, 0.037980440613483234, 0.08666478427908114, 0.01930149906735507, 0.09985583774264782, 0.06742978738921304, 0.0823968701485184, 0.022509134104174953, 0.08860210572639782, 0.03578665208131556, 0.022549755916359927, 0.01650386471151104, 0.03506234276198572, 0.02583446897446148, 0.03356573637574911, 0.002160946103451293, 0.011705168477830388, 0.04861235438335327, 0.03209150550256093, 0.028745114705675555, 0.06685337517410517, 0.022113436284745415, 0.011673758872934889, 0.07252387371995757, 0.03205959985573446, 0.013477918917253135, 0.05122081864805472, 0.028197153080855648, 0.0704957785144929, 0.06136835417560032, 0.043337161036869215, 0.014779368235218911, 0.025135835091913902, 0.04342487810419933, 0.011681927285427529, 0.014087876207345437, 0.02067840421542285, 0.06319890594891002, 0.047803442144105514, 0.05104976653632137, 0.06908630696876396, 0.022483468243491747, 0.03269041197434549, 0.09144384759448229, 0.0661876907331809, 0.0551510910173097, 0.06712880676552173, 0.06145838099802214, 0.05512407109622033, 0.04758618726965882, 0.01919715980728788, 0.03642776808250816, 0.04324552159936678, 0.05488370717953771, 0.05179417800278433, 0.047349868297216394, 0.020539962551406315, 0.028813300361376137, 0.04812898354664926, 0.048215620430006136, 0.02953201915407854, 0.07014035202202297, 0.026811884167874535, 0.020888461693820935, 0.02053087866384416, 0.03583388140184745, 0.0578930958985321, 0.0769082255541317, 0.01690929184757894, 0.047638154844002384, 0.04386910567841223, 0.03203884078820627, 0.04500947734941879, 0.014633748327351868, 0.021029965794314782, 0.03309384536659045, 0.06264590538076817, 0.032427027115538236, 0.04572965745483676, 0.07383742339668736, 0.047111557496170846, 0.05581933036146145, 0.06842449893273654, 0.029260237971621177, 0.07234067911462438, 0.042929069830044624, 0.04994502944511272, 0.038828653163246574, 0.03603144781664014, 0.07409661392410917, 0.03134520945980424, 0.0025552326452828226, 0.029468424280264208, 0.02276587506545888, 0.05355675862501225, 0.08196576183000881, 0.014426412376304789, 0.039167873065678344, 0.16186135490575146, 0.09569273976188514, 0.028736519199165127, 0.040173972506196275, 0.10121757434981485, 0.07581314117076897, 0.047166842231226545, 0.061864426750088894, 0.005914482227977246, 0.07274439212896171, 0.0588574358862975, 0.01974521527787851, 0.07243413418050736, 0.016807473016782634, 0.014506218628206802, 0.07313297490679449, 0.03370393480684969, 0.0830287854337404, 0.028047932559744488, 0.027160934893594637, 0.01872096529921457, 0.025712607368346185, 0.02265680712767907, 0.0534041385887371, 0.0147262831301158, 0.012434886377905647, 0.014136488316580655, 0.08452569059426747, 0.03004049660728103, 0.0709945936837504, 0.040227081551547014, 0.05162094254046679, 0.04277400980373064, 0.035123265904164126, 0.0200589167915525, 0.035331117049340284, 0.031027533865023046, 0.07598410901283065, 0.05859217794251539, 0.023382912923191345, 0.057366494720260945, 0.011154757286872596, 0.04802861836768928, 0.06372694354203921, 0.04653409191016709, 0.018682475126678907, 0.018521399394939506, 0.04997312955017533, 0.046144769857487375, 0.03918517516144822, 0.04890918281049498, 0.08490707980649126, 0.048154210821995815, 0.04049565665604126, 0.04580831553246226, 0.027394744928085038, 0.0935324943894821, 0.06431586214251096, 0.05146050074648473, 0.032922659189470356, 0.05525393832114436, 0.07270002031638738, 0.023221509688864314, 0.052000293958812, 0.014450867818067632, 0.018065261068723856, 0.051469027305081974, 0.05233711983648039, 0.0855732928480833, 0.05571973893130499, 0.0473078100701734, 0.03251927942338009, 0.051215701180720524, 0.13013995222506985, 0.1035747962493089, 0.11079730466008188, 0.020767818167505246, 0.028181000116972194, 0.039767708419071096, 0.012798386479487583, 0.0351278432795117, 0.03098214124028962, 0.04922509448783052, 0.028727502344296347, 0.036332424609891834, 0.01892828018284373, 0.04629402676777494, 0.03208685534886055, 0.03599613882421005, 0.026248344145114386, 0.004302269343527094, 0.05730294772694188, 0.006192875706831054, 0.03476154599939624, 0.005505094417340813, 0.04520568012770626, 0.07932091221934365, 0.03756294950782772, 0.04095044858272999, 0.04135010899194787, 0.038396924313518314, 0.056629192549735315, 0.03206631270117097, 0.06715568879078473, 0.04260565432149076, 0.03809880885866381, 0.09314832427809316, 0.055377596403442086, 0.04454844946702642, 0.015088732733631567, 0.12421905018028714, 0.07363210417210095, 0.03392665571863613, 0.014598644263441525, 0.009249855722901563, 0.006195344903972001, 0.020462708329902064, 0.028875081522029736, 0.012096630788648562, 0.04202285676353401, 0.019060621871763182, 0.08416408943312784, 0.03163485581265583, 0.015149760255289656, 0.08592480463126013, 0.03784300060942769, 0.04309573225797184, 0.035429237590682124, 0.06338846674489398, 0.06524037704953263, 0.05604095193707655, 0.04364489472561306, 0.019301370747627753, 0.04384039270301019, 0.031503885421120835, 0.042164138698529814, 0.04200071299208268, 0.05213964535223861, 0.028238190495739543, 0.02893946355118627, 0.04440098137204205, 0.022036105454448732, 0.02735241857026854, 0.034359211943322615, 0.09699077615814825, 0.058910387883623766, 0.030562072248768904, 0.06698496609685883, 0.02417487355189458, 0.014726838543860903, 0.07387489275706392, 0.04696488230218811, 0.020022274806134163, 0.03384179998970321, 0.058362975926889535, 0.03276096101129248, 0.036469439435149395, 0.08091221473390058, 0.008141629101197806, 0.05074331221441108, 0.04146159393712878, 0.037765725320505525, 0.07471372072975482, 0.08505937042495898, 0.03425080284115768, 0.057048755923226, 0.014466386844193744, 0.05551875576437001, 0.02262080099523789, 0.004646564578457225, 0.0360470645189766, 0.04322460739903393, 0.03960316805469413, 0.015853812294681708, 0.015066637800285413, 0.10212806218694295, 0.05448709580025846, 0.0693559009701975, 0.02554162803496565, 0.01749743478402736, 0.012171986069710506, 0.09710394266632297, 0.010360311660464975, 0.03646450199847741, 0.0197987265193895, 0.06817415672084016, 0.07211940227857522, 0.057650012369718284, 0.027792938278927922, 0.041816679520472404, 0.010788506929642491, 0.055576158732536345, 0.09820163174862824, 0.14589004579090303, 0.011496532092531844, 0.05403288610039219, 0.01046896686837558, 0.03835013166310326, 0.055409557591643066, 0.05995693293610408, 0.019665835162384376, 0.03225761060152323, 0.05211636394021973, 0.0754789659573186, 0.0131188937267589, 0.16114343859014973, 0.13749730743227467, 0.11755639882457834, 0.07829244684187636, 0.14269248672550724, 0.17506723983153222, 0.16761732588131584, 0.1396919807959949, 0.1542572274563774, 0.18848804306359063, 0.17002794410913222, 0.31186657987775346, 0.13801594895701255, 0.14503475458871934, 0.21118643152857983, 0.23292046851448475, 0.10915198528598394, 0.08901789994730104, 0.160421829730753, 0.09584261720339138, 0.11492673307657243, 0.07507687704938074, 0.1502475232606934, 0.12061217799782754, 0.07283104433407707, 0.1465088150073444, 0.1424887533029241, 0.1907604743516253, 0.2053583103923067, 0.19045141916121208, 0.14741331969778385, 0.12206003054856293, 0.14785123087706106, 0.11864205266559318, 0.20974635477027587, 0.15768971504463306, 0.06854197085504571, 0.1078758130390798, 0.1643851089982256, 0.14896591945040613, 0.1268892419794875, 0.16135437323922114, 0.19903240064459465, 0.16269349493086338, 0.18671248108148578, 0.18939878370973373, 0.19111431504209198, 0.12367616197274578, 0.10717995239481812, 0.12300227273015246, 0.12642378227845316, 0.16955249462156527, 0.10409189027643974, 0.21184856132153543, 0.13330148983626597, 0.20404696704879885, 0.08226997534474058, 0.1744944512123062, 0.07984740614530542, 0.15077578684976026, 0.10086838381304856, 0.11219211328294008, 0.1707370504136047, 0.1166539395888967, 0.12237855458572028, 0.08570374229982977, 0.09707215767834457, 0.1796666938330858, 0.09107342110045495, 0.18066303714388804, 0.18442105081292892, 0.14217562252475371, 0.14986133833806362, 0.11006859416562705, 0.1943583450009746, 0.14875953536360495, 0.11556223365328006, 0.21985323018124028, 0.10370903017540133, 0.09016184541847437, 0.11962895011228901, 0.12397839131975368, 0.12443508697493423, 0.15118866227567196, 0.1325479657539437, 0.07042297717904852, 0.13982800736783013, 0.10335900460279758, 0.08134804981490297, 0.1902737940150884, 0.1674600939957365, 0.10830031001880285, 0.18250861956227213, 0.08848205974866306, 0.0941697110031401, 0.1669855331701617, 0.19552733388639268, 0.11534846447888883, 0.12586275310886483, 0.1380291869563441, 0.1624583825469017, 0.14662116946231935, 0.18575822664124353, 0.21443770867922615, 0.15803024112697572, 0.07077604412071167, 0.26576006845120465, 0.20382795783300556, 0.1826237319337745, 0.14265171552617706, 0.15841774372083528, 0.07764662706082867, 0.14462465240109354, 0.06856449384001956, 0.0995864276023161, 0.18600988652436964, 0.1161349916289891, 0.14329054092447605, 0.10554443128527173, 0.24185548987119432, 0.12431102669647626, 0.1867157446160432, 0.1518586674524892, 0.10971178105401416, 0.10692189567752423, 0.21098285132358152, 0.10518120601773263, 0.14785572015229734, 0.12308396834639773, 0.08918565022008074, 0.17310110581738336, 0.15214130793127323, 0.1104417632544233, 0.20384612943856947, 0.18474098445186693, 0.12728974508542207, 0.19130439677786445, 0.11397162827873424, 0.13032503906757603, 0.13735406431219271, 0.11193297638167297, 0.07679164995469394, 0.1183039780646082, 0.116623280750167, 0.15880987348575748, 0.10493757473605295, 0.2540283971616338, 0.20784380605384228, 0.17538611626913472, 0.1822705654006812, 0.1434784010052681, 0.22646452300250533, 0.2957522881127173, 0.09901136370195497, 0.158678351510917, 0.12763309803220535, 0.12827198471753828, 0.10695495237145694, 0.18718713383761146, 0.1469241265928553, 0.07997291432994028, 0.07460826106609837, 0.13180355811792036, 0.2179957274347544, 0.16735898571148997, 0.11496080100656518, 0.08736632929574098, 0.12641711731351193, 0.17829340462002063, 0.1796540533823352, 0.23764603591013342, 0.15605252386341173, 0.11250211842237942, 0.11377623755364649, 0.26443780069389655, 0.09078614578972902], [0.02932604492431687, 0.011239203158766033, 0.08744656168405088, 0.0030413896480064482, 0.09603940986938055, 0.039897778657295054, 0.030932611740765073, 0.044189445343950105, 0.06058117968120402, 0.02874370127345526, 0.043074703144450346, 0.055674390356627204, 0.014874397611786282, 0.0646352825025397, 0.016332594264719277, 0.01561969486741169, 0.041553666214308435, 0.06107055281679477, 0.04024326132850782, 0.05184500793656034, 0.04159339553406162, 0.053024377313352404, 0.025214180988710255, 0.02152576832281005, 0.043471031071197604, 0.07583513555507507, 0.06624737664336158, 0.011710068567716067, 0.11383758587462288, 0.019415439324333303, 0.022282109693473866, 0.04628436256861014, 0.03503030496499231, 0.0371216522199252, 0.02575296104975766, 0.020675650129335064, 0.04181752221718912, 0.08758506271988155, 0.033329907699578235, 0.02609400615666903, 0.041428054607803785, 0.005884355820354916, 0.03446552579501464, 0.14674406528713244, 0.059924772565042785, 0.022776508365847895, 0.1068979784125282, 0.0236017708366196, 0.07350117208496218, 0.04104963398628658, 0.042683082827997786, 0.029944645601414868, 0.010089948698277435, 0.023420012646144437, 0.059858233998379404, 0.011392788465825782, 0.009611134169503086, 0.012228941834051044, 0.0253878282232871, 0.061796988030114484, 0.010191836476986928, 0.0179856262289949, 0.03227869717163905, 0.070608799465962, 0.023959685199623628, 0.07910623140032254, 0.014437059083232477, 0.03808477412789099, 0.0754905492067337, 0.04284068626622039, 0.06320470906493646, 0.14371159816941909, 0.12730259237991226, 0.01255939290257952, 0.02312264987267554, 0.02971776291697977, 0.07076243839917645, 0.041041241493076086, 0.059268036031074105, 0.07751571795632763, 0.07102167489187372, 0.06578716464460858, 0.04471837159907145, 0.04823425934920388, 0.037577558804543755, 0.025632579908556035, 0.03806150037675135, 0.06607421012895723, 0.10749368072156945, 0.06975686372888666, 0.05772889261284183, 0.038144984808299816, 0.00864682482525466, 0.08479523863042555, 0.025630793008472652, 0.08965012932857198, 0.06129720759007239, 0.024082067745527434, 0.019475621276444966, 0.032879398204386234, 0.017455196526322155, 0.08754147997786922, 0.05751445311151686, 0.023084615522454825, 0.05749828482587492, 0.010225673622992492, 0.012615634289930665, 0.0787565122628885, 0.032274115965851856, 0.05887178088267965, 0.011453697243855606, 0.0721970223070633, 0.030362546564109867, 0.015738279532430875, 0.032880290696818026, 0.021739675393027645, 0.07671792931374043, 0.021009369520470503, 0.02458640832393881, 0.03498104551146108, 0.02373862861385269, 0.05722170793301156, 0.018400928238406777, 0.044860216608691605, 0.065763040535873, 0.08537754206167114, 0.051891099616524675, 0.07588055690810566, 0.013449292126742583, 0.08784631402381966, 0.03533604682513303, 0.06871369712415241, 0.13909015744443864, 0.020726937800645828, 0.05917458479563075, 0.03262530982254013, 0.03642066644745008, 0.08661625260907797, 0.031051027866440917, 0.032627102468282945, 0.0711202857294871, 0.02930083105550899, 0.028536710061974106, 0.08470320848808174, 0.03144409417385056, 0.008382096439750205, 0.059796146402556094, 0.04307156601440042, 0.043082406158528985, 0.027819059961926074, 0.019559417888822577, 0.08794231250161126, 0.0019577977805203127, 0.029279562539511153, 0.08855426353552649, 0.06661529036899728, 0.04261906852104491, 0.14150302797075243, 0.005589210392621857, 0.034455991830796964, 0.09921336576582925, 0.017906814933784546, 0.051017533386907274, 0.08182143852595361, 0.05574183290704124, 0.07521925449010826, 0.015132901532905958, 0.09810046217734776, 0.0766259681193098, 0.04731665838569884, 0.011300326441414656, 0.027637508615190466, 0.04037884356934698, 0.05905487972702231, 0.0286104460246861, 0.04628073514228867, 0.06956219312644775, 0.022397779393941167, 0.024654099852928234, 0.041770928749634374, 0.06561019833409978, 0.04753192526198203, 0.01401502220335627, 0.025015180074279348, 0.009006074096466745, 0.05700355290525383, 0.048077828025505434, 0.06420423930150367, 0.06591186843692295, 0.05459365863052588, 0.02560606943593631, 0.08569582095069271, 0.03358572744013321, 0.013210275567196792, 0.07181273728248573, 0.016900533547384605, 0.03613350221947317, 0.03562557826479597, 0.024134696070705692, 0.03653053111667114, 0.05820735665639082, 0.06301645827930301, 0.00936326833682195, 0.0428245984198105, 0.03730001281045618, 0.04536024985774871, 0.043694560205744165, 0.04992154885023352, 0.012961680035767777, 0.04089450118161979, 0.02934645542183951, 0.0891014188528061, 0.056752050070152174, 0.02697343104368737, 0.020481827969272292, 0.02766008905675863, 0.03160644735720369, 0.00928789773400152, 0.059382098862120224, 0.06417654905348055, 0.009316126158791444, 0.005987218445948055, 0.07341135593671953, 0.08758497078933063, 0.012490952522644113, 0.01841857507374258, 0.035249838951013746, 0.07346407044678926, 0.05187535650968071, 0.04215625948422859, 0.049625068993097356, 0.0070980406693002636, 0.07735094776557339, 0.03254287110100831, 0.0053379014735260326, 0.0517318720719026, 0.023510843860886754, 0.0404395368851481, 0.08010876470155294, 0.07581402217188189, 0.044667426752106804, 0.06516677132176776, 0.05591790289467862, 0.06584151858283628, 0.05935632766434743, 0.03426537000303788, 0.060757483325658314, 0.019812179023339864, 0.025500219067438476, 0.0169675221907035, 0.037140026838789066, 0.060158034846667326, 0.006914207816965157, 0.02828477438719523, 0.03770100621266231, 0.0325044249785283, 0.022083093457284476, 0.06508404914770397, 0.03417855308901879, 0.024293651654114647, 0.0871473583843439, 0.016253438229942997, 0.03605795828925987, 0.12019300532917823, 0.026624717396653952, 0.06680869692636114, 0.054913270512535695, 0.014004510519425235, 0.06821122005461686, 0.07852749793880409, 0.02238916473523263, 0.029879959052308436, 0.04355211381710345, 0.02600209284273367, 0.07150130721950723, 0.017742358839079257, 0.026394280064250195, 0.13548002938830084, 0.040130918364851706, 0.012859165022570281, 0.03556127667487149, 0.019985123372246182, 0.039365596528495514, 0.055279812940786925, 0.05860045552253724, 0.034246639153289224, 0.050412094100348415, 0.08109114989037476, 0.047123899172631004, 0.02470735828542421, 0.04339220828466839, 0.0380686862814811, 0.06302689622727133, 0.026328664633535573, 0.020788054380025116, 0.02773549700636537, 0.03643256379291415, 0.04661057812852725, 0.03163065765083077, 0.06582214421923123, 0.02524041950011686, 0.03779626541560696, 0.07204267857295853, 0.06326912556804958, 0.03299521920721858, 0.047008679548819224, 0.021122675839691393, 0.07279824044915938, 0.07175232358877698, 0.023081773336255745, 0.006670840356814405, 0.0507372486284904, 0.08341942132721025, 0.09077972597292355, 0.031869159973857385, 0.02919763901210841, 0.03487287006611305, 0.036761947126398166, 0.023576309904456142, 0.03980783227410528, 0.009007171517418278, 0.020127071803736112, 0.05568780455618136, 0.09224303051709168, 0.05366594147598071, 0.05810877263185479, 0.00988582935890243, 0.052709319824052435, 0.06528291791196793, 0.011221641550711807, 0.003594224549634683, 0.04254012316044781, 0.012266801899268985, 0.011899309521991641, 0.006067257875862021, 0.020954100107173287, 0.08896429677523914, 0.036501607467089935, 0.07991724272048281, 0.056287230052534616, 0.042433184947097496, 0.10767383395784325, 0.02811908872137147, 0.018260521558864463, 0.027506101553538637, 0.05136974614053484, 0.044744901223889286, 0.06964835503529157, 0.05684236800598522, 0.045516734807601864, 0.060128785609718294, 0.004481381657833775, 0.14024177145573402, 0.14695092434844664, 0.13148714848343404, 0.0960061310099498, 0.16948106458350537, 0.10566886694681261, 0.09539974177436483, 0.1630265286733066, 0.18232979931898657, 0.23581102550510438, 0.1500340605214719, 0.09656929756484686, 0.11890256086424475, 0.17597712245920014, 0.1900918328113133, 0.3331413931183277, 0.1497829981869267, 0.11448211096707853, 0.1765707180264496, 0.19189351839163613, 0.15786493467467447, 0.18159695961061986, 0.11618032105146878, 0.1321359023812317, 0.1952825075075511, 0.13421250627406184, 0.10592208964930427, 0.1460682225203322, 0.1330524193303239, 0.08964715690742578, 0.14235186871261368, 0.15912908700204667, 0.1483231716819348, 0.23166572374682273, 0.13544253704528655, 0.24016487171813367, 0.22614137179428534, 0.14079294107373685, 0.10784277166690558, 0.09249243810172043, 0.1067959814662895, 0.09089155948811001, 0.18708513689137277, 0.1918969504655369, 0.11428449092613113, 0.13106990635635393, 0.3297661322980158, 0.16710452194656097, 0.1290090685530055, 0.09279807653999136, 0.22394102937992544, 0.14413729790718327, 0.14957056200552374, 0.17865740363636326, 0.21768903179514795, 0.07984814158971272, 0.18935479494112153, 0.20892828011945372, 0.1127087016920409, 0.1587936630652797, 0.1682077498445588, 0.14108330371879763, 0.17793213287668844, 0.3287642425106418, 0.14358623554148983, 0.30030024568400077, 0.1620694397077445, 0.2004988767927693, 0.19532471895217898, 0.10497877494462075, 0.1459818537677488, 0.23032652544638804, 0.17152097286476245, 0.11902053840458394, 0.10858999084561102, 0.19870543431851173, 0.13978401859921796, 0.2086651289174634, 0.1321617961530724, 0.15739124718933337, 0.14216616899976808, 0.16782462927362612, 0.16281963896847543, 0.14849333513167598, 0.19700805926995893, 0.09807030129576884, 0.11240898511342465, 0.2573759102773282, 0.23677038209092235, 0.12011274229735137, 0.14204534161235058, 0.1972932278388931, 0.10639197733854094, 0.21297235101942094, 0.08465936527617517, 0.21298309157211937, 0.1255359629830045, 0.11435687091321715, 0.15441199253884055, 0.07109983884278806, 0.13229558574816874, 0.30553045051713146, 0.15436164524045684, 0.11074762385819228, 0.1987037642468368, 0.08063554208004668, 0.1552488210220491, 0.13832338004102632, 0.10316918333691937, 0.14455927445763542, 0.25088434167686974, 0.15534001612855544, 0.10741288142819559, 0.14233780333832388, 0.12242622823724825, 0.1529574213970092, 0.09651161114414854, 0.12800003882617722, 0.23983454992694242, 0.11056579288936431, 0.13762680693499504, 0.12438123099385731, 0.12463990824236987, 0.1952504850323162, 0.14772122575631066, 0.11911331931309355, 0.17528119286702526, 0.14396819165877758, 0.1300972198406535, 0.22415680570467827, 0.2164219683336635, 0.17002334758158655, 0.251248677771899, 0.12659972969202266, 0.09680224958086207, 0.09651954015416485, 0.15853567529589901, 0.2172869428872101, 0.16666218277908143, 0.14747754850935552, 0.18137309339738664, 0.11117323166540555, 0.16786688668352945, 0.21190656949916195, 0.06964346739433466, 0.11163551976243336, 0.15333832031296146, 0.12144531393724105, 0.1843234358896171, 0.13491286385443904, 0.0613743105092116, 0.3046150980216842, 0.09668309992599873, 0.19656185901934103, 0.13892089797844812, 0.17518088131422, 0.16367874528852203, 0.2101874528753181, 0.061982959704173196, 0.20567309592039357, 0.2225002937860066, 0.18000237823974702, 0.24685084279025757, 0.160647549876763, 0.12541345786303282, 0.17797408385142205, 0.12008611308110338, 0.16939247417594158, 0.1764592369117083, 0.08992142404519743, 0.1659135003724406, 0.12118947887492758, 0.1039044285613683, 0.11170875010711533, 0.20674384169040189, 0.11040587203517077], [0.02462541560582336, 0.07233818166799123, 0.04011666912946009, 0.021904662003620498, 0.01252881737591158, 0.02046933307522728, 0.08400353272595713, 0.03482528834513599, 0.044103482617966594, 0.05441686468980005, 0.05097742485363157, 0.026200482802044962, 0.07259062296080013, 0.06427652352759916, 0.046045029040185675, 0.022699231161705913, 0.03936168564964206, 0.011625889868986224, 0.010899433588248589, 0.04815990668571284, 0.032549011295721415, 0.05029289848020962, 0.018986972093942667, 0.05185498240133447, 0.05198520585714329, 0.02964389288888103, 0.053629874056505586, 0.07539241334363338, 0.03859366335335278, 0.0306568909511571, 0.05929544282656524, 0.014653615860058176, 0.04694214481259546, 0.03180610327680986, 0.03809419700935964, 0.01087139764304964, 0.03594453514163052, 0.038444950365491455, 0.09376125590455148, 0.019787317554977153, 0.04046923045309321, 0.05247053404849383, 0.012335496045829309, 0.041895103941281, 0.15266874414538184, 0.09391520893381489, 0.02630186496272443, 0.05600579616223132, 0.05116282196174707, 0.009661995704405972, 0.052993523122202006, 0.07731693346173533, 0.06856805614886746, 0.07544305941630756, 0.016856600320146933, 0.006823105598619629, 0.055290993994041804, 0.03628846648479662, 0.023107628803700212, 0.021650654061006445, 0.07229682058095932, 0.005275708540613133, 0.07497632800931893, 0.07242319444494863, 0.051453981338249105, 0.09003820648837475, 0.01579402870829067, 0.03924802501475619, 0.04552916075373369, 0.03980051230398878, 0.10751314701572542, 0.07707125672529783, 0.04348087530102461, 0.03846886380004787, 0.06327964395524995, 0.02198952730865248, 0.03533492067588433, 0.07610486745233498, 0.01952804658832329, 0.06513864823406743, 0.033008108636544596, 0.05242019824142899, 0.051698305929500254, 0.011505777816168003, 0.012893183156847956, 0.028121136091349107, 0.014547885192798512, 0.018443467185622262, 0.032279650951104785, 0.03200427298584292, 0.07787189521496335, 0.030606689209479, 0.022458066683142416, 0.022007972790649342, 0.07472770949525219, 0.005243031060202949, 0.028624149422431668, 0.03767643394249101, 0.007542072891092469, 0.03185117222939528, 0.05245130907203402, 0.014709794045155569, 0.04168328446065707, 0.02850127083459689, 0.01531193723842021, 0.017136812300211, 0.13815214406819115, 0.013469445027200686, 0.014906236225919378, 0.018363198408135967, 0.040880286420184764, 0.0737376174619121, 0.018772337240197005, 0.042717602749865864, 0.04345087529790979, 0.021088833905636303, 0.03259089332254183, 0.06469326003664924, 0.013496616250655104, 0.03824890080478884, 0.027399471690577847, 0.00910974302960019, 0.05921805645489405, 0.032566945414028825, 0.05266269954342035, 0.01413914185362838, 0.005401581095816989, 0.05440317852903278, 0.04925313330585918, 0.007868690168364875, 0.022685838029569676, 0.04334862171221645, 0.07692774547444237, 0.025606297347093784, 0.03655251784009799, 0.05522651237345511, 0.05372936206479227, 0.003827849765413351, 0.053157366346567876, 0.056996225274258086, 0.015809180969823033, 0.06435934529309312, 0.03659210543358519, 0.02429155257320212, 0.011646587649480471, 0.021567703975785165, 0.07739193346952239, 0.0687392691390649, 0.03768370794733206, 0.026435145109351126, 0.029682392637515743, 0.03488954013934539, 0.07388248468839353, 0.02878887939356989, 0.03677349207141707, 0.08264059336074898, 0.0177427418830414, 0.054995349172743103, 0.06814327571661243, 0.028865944008312883, 0.04229334325739934, 0.03915493767107687, 0.04233689535589468, 0.010020941413278061, 0.08828915880932924, 0.015163141896107025, 0.025461952975620667, 0.029132782008438825, 0.013265709689397727, 0.0382135113731267, 0.04172465320856821, 0.05090976779859874, 0.10548485262740044, 0.07387707610764811, 0.01786049342744293, 0.03066983975229725, 0.0268395648397986, 0.1046777866600502, 0.017677934675086892, 0.01285808196576733, 0.05183460446254862, 0.06326061433121082, 0.0473139311126884, 0.042472132857167916, 0.039851905312389135, 0.03827433109343533, 0.02205827986941703, 0.04881932835785612, 0.05304469396510432, 0.007718598701044798, 0.03589783442176638, 0.03229608736752022, 0.0590691251319743, 0.02435117145068944, 0.031820660862591, 0.06195710806716835, 0.036875592439525554, 0.03688454800736039, 0.029751662307629184, 0.04334946823937278, 0.06703080113736853, 0.004635479764997839, 0.07565127445324775, 0.04638540956582274, 0.008067855791699502, 0.0665048664555915, 0.004565225671901698, 0.04240541809028195, 0.02504545012338748, 0.01864536391240695, 0.04117487787058757, 0.03297665689681326, 0.03954919332998895, 0.04751766453527155, 0.03323095978327817, 0.04403163506198795, 0.022091288682854465, 0.05737237827551942, 0.03666343971065456, 0.07138343693147745, 0.048433308144130056, 0.048116258826226964, 0.03478596505198268, 0.032184721165967566, 0.022145466420859582, 0.0336393459339536, 0.06404956614959144, 0.037228598094154755, 0.010930699551658285, 0.06763649323294241, 0.05893457710983292, 0.03821310534652683, 0.06923378655506719, 0.009364668362503572, 0.037427194897205605, 0.025290201808656418, 0.045539131388068206, 0.010842397384676001, 0.04514814309415318, 0.04338728616975489, 0.045999128882202416, 0.02265760194390051, 0.06926788512857691, 0.02913949293865552, 0.008868675269637137, 0.04895330947493354, 0.07689366988357037, 0.051790592711298704, 0.02349953257268475, 0.039226953766398856, 0.03205002375668095, 0.040057048336752964, 0.045404196491525065, 0.03570564211376252, 0.011544595491291295, 0.06698776231778246, 0.012570788460453192, 0.04620183191652741, 0.041868712212289536, 0.06723745335494319, 0.04024481265655449, 0.045277960523362124, 0.039264810001177174, 0.02899578825059918, 0.04156064910573825, 0.02557252244573207, 0.01309522639794816, 0.08134874695491406, 0.0292880546241518, 0.024321962433356433, 0.056564967568603255, 0.06164398494987719, 0.031051928019751946, 0.02972794231027365, 0.028865957414851557, 0.032746945432717764, 0.03557816508316225, 0.017267300056353692, 0.07404902454225287, 0.03181066341517914, 0.02056682733969102, 0.043059331590249654, 0.02962679380641109, 0.013979810887136528, 0.044792053935628746, 0.022214751412731507, 0.03351089214124987, 0.05998537395029299, 0.01562448770498797, 0.061371656014553966, 0.03687135214286466, 0.07549968097479114, 0.025282240239903334, 0.053256272128032106, 0.06516579839010393, 0.030304586266978618, 0.01437503852010254, 0.0797005394293416, 0.11055994763850205, 0.058699920548186194, 0.08354631613098806, 0.02997291807626044, 0.012764844277332868, 0.060779971836675564, 0.024876928017024073, 0.046131497384199215, 0.09432934074392242, 0.007120308930039287, 0.014771160560720151, 0.010185888761864796, 0.030337853635090496, 0.08615127554343593, 0.06154199183407811, 0.022751409410228653, 0.06777888599542842, 0.05189225257885072, 0.05646010162308813, 0.06271175063786007, 0.07909713793666133, 0.023375941523080392, 0.026833439966843977, 0.09133655698068681, 0.035736063465235696, 0.008354214669746018, 0.03449832584949271, 0.057966667152340376, 0.05353456888828547, 0.06135562179429878, 0.023182833740007014, 0.10414184686998207, 0.051144458834202065, 0.04965713360316811, 0.0033781214405016434, 0.03520312290939112, 0.08149957434544641, 0.02072398836213735, 0.04439229010454109, 0.08781305814702665, 0.014687998843709789, 0.022995684205764727, 0.02007569220187443, 0.05384822443668401, 0.08837302245440022, 0.033134838731418696, 0.03336940336251452, 0.06217475364645643, 0.04467928962361428, 0.010212447114979789, 0.03758398628222846, 0.030722458501376455, 0.012925582930385586, 0.04377616772187814, 0.13701343097754065, 0.22205551845892785, 0.10422726567353933, 0.12296055158179615, 0.18468132152432398, 0.12207100092763863, 0.2109747920786181, 0.17029431288040456, 0.12740608319760333, 0.12605213770462623, 0.1385154536054019, 0.12634286041101142, 0.15867467428888046, 0.1289971482249037, 0.1882359388494684, 0.11756126348289753, 0.1641622693428109, 0.14104018829041912, 0.17083728535761758, 0.10239268427774792, 0.12363811038554677, 0.23641047398409537, 0.05161952144736725, 0.21581842894515685, 0.15150167047977448, 0.08591754977861721, 0.17587711734156455, 0.1530503785057414, 0.07359463481172439, 0.150970357860769, 0.1557978915591394, 0.0813903455292025, 0.19274056648775456, 0.15208028136722504, 0.19600871289449354, 0.0761073572380889, 0.07713142527087082, 0.08334503418976262, 0.1940985799076096, 0.07387281665878911, 0.1705397827731025, 0.18310607621265998, 0.08644611980285376, 0.21013509842657277, 0.25280601194789337, 0.1119988063170064, 0.20964723831463247, 0.14608133794559588, 0.14337870232280225, 0.14255174105205845, 0.13898216969063207, 0.10484939801596826, 0.11943131474958313, 0.15513815196050754, 0.15765413792142946, 0.09042662838774343, 0.19441832968544578, 0.19392856967545327, 0.171071095392108, 0.060345243752723744, 0.17314189233847205, 0.11137600747808335, 0.18296511603459237, 0.1515826919386464, 0.10466752108186485, 0.17502856771311454, 0.1960194994124674, 0.1667730357017248, 0.14499288022277818, 0.11972500987711454, 0.2405142997421565, 0.16568218778458335, 0.11972963704817718, 0.14629518372877953, 0.14310785959805214, 0.12529076122108007, 0.1509739891175301, 0.14325315583377116, 0.1139101114184145, 0.14481373822256444, 0.10926391073172131, 0.12617828174223825, 0.1659553594166233, 0.14421808953967788, 0.1582844137784935, 0.1143579894015866, 0.12227020677058928, 0.11501699355581116, 0.14506959626751562, 0.1571147047704266, 0.15385307011104402, 0.2093743271524868, 0.1713161822408438, 0.15670973537189348, 0.16683675889526645, 0.11389187086493739, 0.1150496289013855, 0.16438536946811985, 0.1285152482770143, 0.14667292636248375, 0.17426559010580664, 0.11814255567808306, 0.09578222649232035, 0.17551154018409793, 0.11477901600301267, 0.14011781842958543, 0.3225061315442285, 0.2763052993724423, 0.09094091087219217, 0.13713862506612656, 0.11581819895054064, 0.1683673259591864, 0.08081853750251955, 0.12718381044725258, 0.1628975807538917, 0.1986932228769987, 0.1373591664577684, 0.14768725741774807, 0.08299852496073132, 0.11544372751227311, 0.15492985265389567, 0.17056495642229436, 0.19548806421939405, 0.13621830832092993, 0.21384743793356806, 0.061591718601243156, 0.07196952483706898, 0.1519208278266653, 0.10726470470188126, 0.13927205736117979, 0.14692069451895454, 0.07981580501842885, 0.11785177168466392, 0.09713277055491364, 0.16022341295836434, 0.152297513259034, 0.15082657847914005, 0.169712484423672, 0.14444233879687327, 0.15418455635588016, 0.13816034120898094, 0.16009435778664005, 0.16880808698554195, 0.11982301550526774, 0.08032035052535996, 0.19815847818409243, 0.13248906891432502, 0.13711043303051304, 0.09805637381730542, 0.13093942626109048, 0.26863041604238175, 0.15309747759132616, 0.12798120072411914, 0.18404695475774427, 0.12060563560695418, 0.23195008026255717, 0.10258825886393748, 0.11725519603538899, 0.1567988313974873, 0.14965366722354967, 0.15391690055689505, 0.18554225113363038, 0.1321158002340986, 0.10696825165782245, 0.17596688752453174, 0.08932615840627302, 0.17671679567185142, 0.1122684309619569, 0.06895112309364543, 0.13391103535409898, 0.11924808183985373, 0.165429700526499, 0.15232109344534336, 0.1523470638259765, 0.09761883802111111, 0.09827235698579781], [0.007155422091243729, 0.02782989052995559, 0.015369734741867551, 0.012074437221482158, 0.07109309726905438, 0.07088549510245362, 0.09789882783567715, 0.014733179836654136, 0.045418384439882734, 0.1288544873316442, 0.03132444656183643, 0.01238250894652259, 0.03888015725439595, 0.05446452685000916, 0.0498334372476224, 0.030252254800871018, 0.068849892235331, 0.08183905088733281, 0.027729197848407973, 0.02179748438779385, 0.03672885212806925, 0.03852307601200958, 0.018099438166245818, 0.05162967211236397, 0.029111513492440986, 0.009529903951671817, 0.02168973029080418, 0.08016923202141639, 0.08080652524386683, 0.015351926070457746, 0.004219528496070135, 0.0313213630579412, 0.046052594158437946, 0.03905350379946251, 0.01746913549610444, 0.07112840626148448, 0.05385891519366734, 0.019928800588053082, 0.0607060979781372, 0.006999490161110918, 0.013507812625668464, 0.04008175850275063, 0.06663652632625834, 0.015609333528235797, 0.013060390464811316, 0.011980594323587515, 0.031043995179296024, 0.06426154650867948, 0.02150265928057413, 0.044877748530838764, 0.021038030784937645, 0.05819176676713171, 0.0551029462217083, 0.04557652797009196, 0.009685443740548387, 0.026071395071583892, 0.013454235309074003, 0.015435722682835355, 0.03148932592011988, 0.0502788829016349, 0.0434789409290158, 0.015428165225462328, 0.06987513238263708, 0.031345638469041835, 0.04297244955875701, 0.07159836289863433, 0.04062455094930145, 0.04554928971394416, 0.06469115329485747, 0.04965783074317921, 0.02182468625476524, 0.05713520128460181, 0.03111986661209695, 0.06375306330981755, 0.048883220090741114, 0.03212046362609873, 0.04375027011959784, 0.062291302432816845, 0.009138840006574268, 0.026715383902492545, 0.09354428448263677, 0.04249838285989339, 0.011572296273023372, 0.06752213928848505, 0.03494487083967655, 0.01437245584618781, 0.04551395773887635, 0.032773172452805505, 0.06264576365450217, 0.00638352578408235, 0.03901533346863524, 0.04212971070721265, 0.02452112422625144, 0.006918663097049802, 0.06472054042763288, 0.03508486957739919, 0.01630831885361864, 0.06522988930584923, 0.03646701093642943, 0.021007306828734376, 0.054652314152448415, 0.022778461890054807, 0.021024526570052392, 0.07138794152847222, 0.05854733881630725, 0.03563938699963112, 0.03420852627905627, 0.011319837743236173, 0.09116603346962122, 0.03562079021526921, 0.06676508354083185, 0.07568517384389717, 0.08232470466605118, 0.040087860393067526, 0.038992680248714266, 0.015574569415841854, 0.051261363851447264, 0.010607236162609151, 0.009976559066994777, 0.02130894054238114, 0.10125476025765943, 0.07726461731738622, 0.01738911761241334, 0.035140476069383086, 0.061160598791414694, 0.04747042755386041, 0.04726651793105468, 0.047803219978607474, 0.08328246778898662, 0.03526093190415733, 0.03847208903020909, 0.02681523197210364, 0.04755427204673329, 0.008722981625807383, 0.03554001390453308, 0.04287796027417626, 0.08878505518359524, 0.024530347924859777, 0.001211000788081888, 0.035892563736847335, 0.05047025166512017, 0.1096553203739947, 0.044173380480177944, 0.03683129723574366, 0.025979295981326894, 0.09735355709469128, 0.0704941314254557, 0.018999093520124594, 0.04003948960152846, 0.009152092370054415, 0.1436009597513945, 0.0027818213434769746, 0.03131816272563752, 0.024510241947287036, 0.01965655400718172, 0.0658912223673636, 0.01921116772498335, 0.018859539113398043, 0.0377239850199511, 0.031840347407025196, 0.021114593612090237, 0.08045096085557053, 0.016215151070707267, 0.04047866865632035, 0.07848195401170562, 0.05215188360682899, 0.02968129521656421, 0.051048176903878494, 0.015552169962545798, 0.056576405261312766, 0.06937090863263415, 0.04766685632808555, 0.05371877472967871, 0.04708726867853154, 0.007829248131583295, 0.061411795191346645, 0.035890154390325474, 0.09346769867284645, 0.04400399460967991, 0.03597020674797316, 0.02169426361609611, 0.04708690095632788, 0.08147761060465729, 0.029802586087175918, 0.03975353579247191, 0.04090348356253198, 0.03994936318767648, 0.015268782548035587, 0.011669220759593433, 0.03378032909465894, 0.018774036040169098, 0.06130879850036675, 0.0760883889010837, 0.06701904168773083, 0.017310212471432263, 0.036354039780675404, 0.021811612964337392, 0.06095983778997775, 0.05472929832795936, 0.0267975602389103, 0.020991362623810288, 0.1225102297781456, 0.04391741518291735, 0.04844189982020086, 0.05858080153683982, 0.04373017180290434, 0.021795982855462262, 0.02332542760057315, 0.07037524990136586, 0.08702770311145053, 0.05149661030079569, 0.0558448602415381, 0.08337612969860916, 0.02727044524715072, 0.037405989583461516, 0.030489548620197083, 0.035290177310666734, 0.06567021366208792, 0.04354763603318603, 0.057253048589993874, 0.045952861002015497, 0.024269822489229903, 0.008666586063261475, 0.04368053313585059, 0.03029213925342887, 0.015183590698025882, 0.009536428147956971, 0.1049233178397821, 0.046939356252551086, 0.04213768568250441, 0.04073633849921246, 0.06594261920620358, 0.038619461364202926, 0.03931086720718492, 0.032838209487137296, 0.05078360460878861, 0.08913534122609323, 0.01877257472745353, 0.06455129628340084, 0.030970117490318035, 0.054708426262462334, 0.04501532260028105, 0.03173619583849946, 0.056343020405620343, 0.0348176657702894, 0.049598891768724694, 0.043923421312243714, 0.037289184157646475, 0.08787341821458071, 0.02963376903696166, 0.048198211081926866, 0.042887953891148495, 0.02932637051168469, 0.016306803914748372, 0.016310299190902905, 0.017988746122066534, 0.03986122094154839, 0.04572171695350159, 0.015398541563040307, 0.06841061741954858, 0.029995577041840846, 0.06361590292785438, 0.03736277073321324, 0.03552780246302005, 0.047066641761170286, 0.0962789579024238, 0.09711542632430793, 0.06415354343311441, 0.04000638311188068, 0.045894937094060645, 0.04345945548266173, 0.006636050867757971, 0.05616212023362037, 0.050498512648646875, 0.004614467409649684, 0.008711332301308793, 0.0635731169172833, 0.030160523432817672, 0.006114735217359398, 0.010655088887189426, 0.017490685549414447, 0.06035572000508828, 0.061076601080956965, 0.018631746699552865, 0.05784418501500642, 0.019227690326290268, 0.02057714462881127, 0.021844531762443727, 0.025602664175112883, 0.035098900477732384, 0.029334387621812286, 0.009491784374169525, 0.006959459194237547, 0.06826879922300577, 0.04689165961838538, 0.02175424063968803, 0.07433888923016287, 0.08026239597388814, 0.00231191617785953, 0.07115133527305818, 0.010045907261120457, 0.11818426916556013, 0.04463543875082847, 0.05627506074585742, 0.044972065445636554, 0.023018165055902737, 0.011634528467942391, 0.021153056971548546, 0.013404844662985735, 0.029072010168625467, 0.05320936456442841, 0.02375086878366288, 0.04539755450922155, 0.016018801778104278, 0.05915589608071793, 0.048937742568312154, 0.03103396134270776, 0.020998152078039223, 0.030122784026447805, 0.03399242819737523, 0.03856750528117822, 0.01894715467407819, 0.029341251769613837, 0.017208880106467875, 0.044264905004491734, 0.056553564349850344, 0.023864812871080734, 0.043663081652935476, 0.04002167039640969, 0.09266998663905168, 0.0686485643288301, 0.028600519440407236, 0.001178969694357816, 0.09650554372778825, 0.019276118574423656, 0.04301879021729674, 0.030207187763505408, 0.014597746982960211, 0.06036412015917802, 0.03908076503824803, 0.043507749665408366, 0.06534566817384574, 0.03446287513079663, 0.038932132489618756, 0.015956959330416735, 0.05194717342214239, 0.08426692907608326, 0.06400698315232031, 0.01874364341699308, 0.017986189303619247, 0.03513275007266672, 0.07635136390285147, 0.12325449951834257, 0.21975679503333187, 0.10526784290108951, 0.09498957829970507, 0.2589069523157612, 0.12718981657657893, 0.22325711204640328, 0.10213147893908525, 0.23925213924338742, 0.22819557527620948, 0.08681771841140525, 0.11492058905141969, 0.15971206459066561, 0.09811173133071392, 0.08492323660081433, 0.11195473327872255, 0.19202612821132908, 0.1499888000469054, 0.0872731959867862, 0.20205950514683801, 0.15164762555110842, 0.16444403648136124, 0.10360945406700335, 0.1395128847610566, 0.10245429306861856, 0.15630835126484596, 0.1408360258585984, 0.09841847293559583, 0.22558836356526424, 0.09709649629169896, 0.13161361427797427, 0.09336434575098176, 0.2114913804877189, 0.10149206365308455, 0.1330691506905902, 0.13093521277750694, 0.15419594042243498, 0.09982903232617725, 0.13833856390368554, 0.15104546512086547, 0.10779636972133191, 0.1536559863316436, 0.19725046481095976, 0.17265225490254743, 0.2177866160749428, 0.142744412165015, 0.13293617314869358, 0.1658360795268128, 0.09471792352175522, 0.24505217559635642, 0.09173663873826304, 0.20261490357018289, 0.09981984693196513, 0.07855757455071134, 0.08636280774108826, 0.13523745530795667, 0.12581830468749808, 0.2085879378982129, 0.10928278713817559, 0.16072809636112184, 0.13477547364609857, 0.09571752270623561, 0.20107427011093787, 0.08736562449485065, 0.17606205096648586, 0.10453587653295648, 0.10479430863333326, 0.1985895252155681, 0.09237187884507642, 0.10470106807206908, 0.13395906906695138, 0.18048590229403588, 0.20390665038458763, 0.15139739059152144, 0.168515763155395, 0.23536621953450867, 0.1674230459837183, 0.1944704849513308, 0.06943263233669343, 0.1258264328803747, 0.186647271677371, 0.07989839695754551, 0.07357071754672835, 0.1506542546614524, 0.15790627277906866, 0.15549873422470786, 0.1342073428414522, 0.12381935912755229, 0.09051893432173999, 0.28139567783763336, 0.2920826350248629, 0.13563007536915042, 0.1423161690153422, 0.1775827508179411, 0.1486612156394028, 0.0870266076057188, 0.14290371248798986, 0.19942270712025706, 0.12539511005724632, 0.08111375714502028, 0.2552920438709759, 0.10006298791737327, 0.06703256313959438, 0.09625953757354329, 0.13518539197262258, 0.168940604874684, 0.21831926168693652, 0.06135767874037547, 0.14924920344304654, 0.16048458765351004, 0.14993817695686895, 0.14730963735811173, 0.11690962143362531, 0.12015994863524554, 0.1306075110070167, 0.12621007439109588, 0.17912506967061953, 0.26205379636056964, 0.09784681812649774, 0.1864481960693675, 0.19468252276701314, 0.21367581891677073, 0.09287003517871903, 0.21307496083599908, 0.1551871509441445, 0.17993451817141426, 0.26041773898947623, 0.15467568000237789, 0.24394608252952177, 0.17081113111588264, 0.12238376398360538, 0.09413799496307489, 0.10339026099010822, 0.15268469409596536, 0.15464857581161684, 0.23646345662493862, 0.17206992082778486, 0.06447000669375544, 0.0924956020448477, 0.06833838298916817, 0.12519839400004956, 0.21856995629927806, 0.0900985818776873, 0.07907472986487613, 0.15984275919054786, 0.22286119780713515, 0.15449169632648269, 0.08467421206014772, 0.13850146483990455, 0.11534782862591168, 0.21951126385359995, 0.11232004996629492, 0.12873836372408176, 0.22229412420382424, 0.15881830045292455, 0.18842200628451763, 0.13158506984191556, 0.14211923845352667, 0.1075958998333062, 0.17969978883141474, 0.10720380071190097, 0.1312025774630808, 0.1452345349976132, 0.17991165810775372, 0.1249733939766884, 0.15186925478760274, 0.14062175106617714, 0.18414476886391642, 0.1234183733862254, 0.24945912702429682, 0.26215632956835533, 0.166189904895521, 0.15755384169038267, 0.16791881212303716, 0.1528722630633462, 0.22071298001514328], [0.0524528450783222, 0.01825141660388439, 0.07027534437516043, 0.00808808817377975, 0.02632106121088709, 0.04004841835628595, 0.006887393782005436, 0.025955265718362024, 0.04093245317738864, 0.016083265204102765, 0.027283022495647593, 0.015637989047043506, 0.02818748696647104, 0.018211361696763385, 0.026037037943399725, 0.038668900848396366, 0.020097043072324128, 0.04895733526697563, 0.02668759214781946, 0.041293767055556665, 0.010138434403005147, 0.016478564657811678, 0.029015938278227568, 0.018189689069385492, 0.03474259681458916, 0.035011198732160756, 0.012729932693013502, 0.10516003134750551, 0.033299019034471244, 0.036043222588036335, 0.025322521142962, 0.07915895357127152, 0.024565858015369986, 0.030473828495990847, 0.024937184662708355, 0.045278929624586337, 0.04160353087729985, 0.06511747356384032, 0.026094293439640634, 0.029269957712160486, 0.03614113628563862, 0.027325105620548133, 0.049707810319359266, 0.06913709859814375, 0.017360722563499888, 0.03276318649671251, 0.01277532148730731, 0.05088926728574499, 0.07764134871503038, 0.08099782505943891, 0.020429996375535286, 0.02030453032573625, 0.08988540259099777, 0.005272831401652507, 0.07551946136499606, 0.0841205909607872, 0.017328985456016757, 0.06714616631788593, 0.05922525768138229, 0.02184112841684011, 0.0685299969007892, 0.020399670785052643, 0.06204899648324617, 0.050170328242764364, 0.01228075906363947, 0.03736554397149913, 0.027936068401041052, 0.027708823740061735, 0.020455570305667577, 0.04403540038413579, 0.05355097083074432, 0.025537274740335923, 0.07289249224648361, 0.08363764147244154, 0.044932351447641856, 0.03680439605828255, 0.027250714652660876, 0.01791908766233152, 0.013531718399345636, 0.05367089806485081, 0.020031205476111463, 0.012722314906216437, 0.01651260194428746, 0.011920477488949414, 0.06362395451193856, 0.03701246553851712, 0.010585851775812767, 0.008019360510872738, 0.02715062718057344, 0.04261244186049989, 0.024655752687624866, 0.08081464577586421, 0.03299251874728549, 0.0797357794738585, 0.017943533527995312, 0.027045414580272573, 0.08298775376451593, 0.026621344694567305, 0.06375500917314522, 0.01614817774914686, 0.012958609938411223, 0.04852902699982928, 0.013745558436869854, 0.00785116064024248, 0.053262090565817016, 0.06644775460083639, 0.04740723679142614, 0.043926608238008716, 0.04510346101596952, 0.027735757476259625, 0.026970362861550627, 0.04670542747443242, 0.03742606108707767, 0.02154539549543012, 0.036975260478474443, 0.029455557833575917, 0.017874612427887418, 0.08144530467689037, 0.02320836553530347, 0.09550790572839399, 0.030947810925182798, 0.04807231985332985, 0.06484890612022531, 0.03662626912456848, 0.05525339056827849, 0.0272246063762014, 0.02436721716226349, 0.1094127769371675, 0.025911089258208394, 0.06705870205957083, 0.06441173804623467, 0.012503933882521046, 0.025385547196492556, 0.028436549811533866, 0.05050741459032701, 0.0067114363135319325, 0.02319350917523186, 0.020831572004563866, 0.01886310908312519, 0.028396881778814623, 0.011609802980186238, 0.04941036519143851, 0.007140762041202717, 0.011342347321671345, 0.020827869884669784, 0.034530030398239056, 0.055327038430879195, 0.027814938408893444, 0.0110117947464929, 0.033151470500254826, 0.019430439325890714, 0.022196528096232685, 0.02832137998343716, 0.051171019102536866, 0.0376483874635831, 0.04578467788955858, 0.04990882796025084, 0.016690629286571376, 0.012745720807523018, 0.04395070170322734, 0.0824713951817924, 0.0362963380382186, 0.00761310360582185, 0.014431669654685163, 0.0644202646048319, 0.03812882801397674, 0.007515371854101578, 0.06374709931532703, 0.02597885165033081, 0.018893476808443666, 0.07311363884758565, 0.0359384638948306, 0.0390949874605623, 0.06213190634885143, 0.03296079887678066, 0.055625460320903417, 0.03579487603518271, 0.015711194493867937, 0.03161269863466582, 0.016104411146032716, 0.042052634601150794, 0.10505555227639214, 0.012307400728816227, 0.026627392958729502, 0.0268759501857623, 0.02313002538416655, 0.02305100532999683, 0.026602416577178146, 0.04074591076782635, 0.04353592254882378, 0.05333798689647548, 0.024942711987082037, 0.05754415050990159, 0.024404805266268315, 0.023327114909226378, 0.05206219769353348, 0.027944671568430723, 0.022674498013070515, 0.02257032729234667, 0.04550335125156468, 0.024032630176553806, 0.06725329605321731, 0.010692368640804724, 0.0712394813496259, 0.004498308370520752, 0.0363933592433891, 0.041186484102640426, 0.008069304655486298, 0.032020100362358556, 0.03299699653120291, 0.05477953071315443, 0.03645600991383676, 0.051167759398419055, 0.05316560562219351, 0.04500890278347558, 0.08288279971888951, 0.025765352521932898, 0.01915540418497497, 0.046062825262666716, 0.03269681263895285, 0.035685578271025614, 0.03425445325011688, 0.030309701819093, 0.02134750540848942, 0.028439397743392377, 0.029767231129470374, 0.02250359720370222, 0.026226652365538384, 0.008117807597192305, 0.0335166952572763, 0.008669826615181182, 0.03674194074025558, 0.03873561178484271, 0.03782800060787028, 0.04281204223873154, 0.01132198278942416, 0.03997976538695155, 0.009632646876026787, 0.04087406961667923, 0.012632876056276504, 0.04536178586403689, 0.04260314155309912, 0.038168779499227964, 0.040273923997677145, 0.028597547019261028, 0.01055962379811512, 0.021685214202490546, 0.024519413934960484, 0.08927601795162886, 0.08745745545433414, 0.022968999448142225, 0.07029662629769695, 0.07423796480701816, 0.04078427645107431, 0.06997234894022827, 0.01779726244539263, 0.037138747471955516, 0.046570519390966625, 0.02033342333180049, 0.010257953695291954, 0.03958996069887954, 0.03407179490633069, 0.022485712881109888, 0.02840957968615957, 0.05680831156731133, 0.039427852663662166, 0.04144413862377405, 0.04747248449993711, 0.02906287265490861, 0.06908943260749502, 0.01914031991374589, 0.001472773510613479, 0.08096268460635217, 0.08022532497923221, 0.07005887857127575, 0.025137095306549343, 0.030694124739496943, 0.03254882743461959, 0.033594464672909635, 0.04303164517266616, 0.034568020698404124, 0.054761271007479205, 0.04934620915821964, 0.04011057490002244, 0.029286482228687214, 0.06061831962377314, 0.014090375569198402, 0.04009601922946111, 0.04574392584242648, 0.019443470481482726, 0.031186165776283994, 0.017300626796279705, 0.051667601125495094, 0.08807308371028594, 0.060820911575349114, 0.07539999761408375, 0.0415471276538747, 0.034348164955454494, 0.015329991057965786, 0.030301027788570335, 0.03771826234315673, 0.0270604528862262, 0.03032502549279842, 0.06965221611842995, 0.08169691093386182, 0.021639781358141093, 0.025551150507864454, 0.029736917030306596, 0.048372124532057394, 0.02480822142153498, 0.06256953407559665, 0.03381797082481846, 0.04750898858952907, 0.04243152636674143, 0.024203831675432386, 0.05042077004609089, 0.056205228001119635, 0.06553467738652421, 0.01426481091672735, 0.01996037107141268, 0.02388621545246532, 0.07554568455464418, 0.03344360663886032, 0.005733083620021541, 0.015554472056758261, 0.04204011289402843, 0.013709992804985135, 0.011268032962576518, 0.056789680308992826, 0.015954408257628883, 0.050245048628459056, 0.01979965540099769, 0.006688764420217805, 0.03209436109529869, 0.01818151299601361, 0.012637311705358088, 0.006561554083976174, 0.05805240388238623, 0.05718897682644668, 0.022338798284650813, 0.029743899921736414, 0.07226875878029293, 0.01396769137617441, 0.08732667658478023, 0.0023209263294589736, 0.06315572157261834, 0.04886114526720298, 0.011489398856346887, 0.07168986444031039, 0.07887679572787978, 0.048882702981392225, 0.07907925744450862, 0.10220442583123523, 0.05912209628149868, 0.09616343950432155, 0.10515916566815108, 0.12267905257401929, 0.2345979712422817, 0.14975673669288236, 0.07106338837935079, 0.1477859295423954, 0.16991698393417945, 0.163025563402522, 0.10508759773426479, 0.14101740483555103, 0.12903318500086186, 0.23420646966945743, 0.17582805707089363, 0.1339870312761876, 0.1539199495868337, 0.13065163767145527, 0.12561120813892734, 0.131449410992284, 0.09284229513498084, 0.1289177202289143, 0.08128710752052647, 0.1874374147624739, 0.14813400925167147, 0.11588713920284664, 0.20454107843820127, 0.16934296957427458, 0.1574455015361309, 0.1154410079001419, 0.15646772819661325, 0.09199684816262416, 0.1319604376030545, 0.1045147248453671, 0.12214151166018941, 0.09854825589084819, 0.2563817886215064, 0.20190342239314513, 0.25464724298686753, 0.10513867281617657, 0.11008400785466356, 0.1307393547387854, 0.15178012811849195, 0.09082923823546979, 0.14004254263014565, 0.1531896532903756, 0.09332327577736109, 0.16062498092651367, 0.20221854499991865, 0.12120271687425914, 0.08852319100931769, 0.13561075463170005, 0.12867215840566543, 0.18145753160840083, 0.25554230947407985, 0.15469432658245488, 0.1880464086970014, 0.13919638319601937, 0.09116006564469108, 0.10234049070746669, 0.09027541029236971, 0.11323337232874287, 0.07765604994229733, 0.07436423907957732, 0.0928917920757686, 0.15627629814609406, 0.10584805491230181, 0.23499026954654725, 0.15674062403700045, 0.16187379617364178, 0.12084298496765476, 0.1551936473697424, 0.26581804598531417, 0.11691055606089293, 0.13230375224544158, 0.18249718953044186, 0.10284663733815956, 0.13532895684963273, 0.11784939681209865, 0.13639345134217895, 0.0882158978211303, 0.07980752360796736, 0.14453407016492661, 0.1879613422938893, 0.18537383436435656, 0.07010276774845778, 0.06794822207021137, 0.16359049195964492, 0.14788798777566803, 0.11591359221887206, 0.10673752129678765, 0.07173438180959033, 0.11470950118476346, 0.1779471022347289, 0.09322002244692656, 0.20567179357092227, 0.13066197985843306, 0.12518615191501956, 0.12191378436381779, 0.14767136875419848, 0.192360004650489, 0.08747621694759977, 0.18215851738087593, 0.194526685161456, 0.1835044725768028, 0.2079496027961854, 0.1709170963975691, 0.19303691994038322, 0.09574582199415854, 0.14385640410886658, 0.13905838011733948, 0.17927280206593776, 0.13266516188460012, 0.08498333619847413, 0.1346649118368664, 0.150821813412251, 0.1260533328017881, 0.1344908566604699, 0.16803724931613093, 0.19270915688285906, 0.1068658180414669, 0.18670365574859804, 0.19536516839458098, 0.16090417400963847, 0.08261407905768964, 0.10914763390657403, 0.24571271192642952, 0.12389983666399795, 0.13522532047523608, 0.12963706146805518, 0.1035735245433546, 0.1363702848433487, 0.09531212429846488, 0.1276408738246368, 0.1002000870123025, 0.1640059414409822, 0.13016949257543012, 0.08424224572316294, 0.11009669427068965, 0.2517661395212335, 0.16555783639271415, 0.11964404970527658, 0.11087530007165287, 0.16251257560666532, 0.13545790476904762, 0.1325979912953992, 0.11556408758605681, 0.05830970983351431, 0.09338147547696868, 0.07080813554385978, 0.05687353629318457, 0.1503069410401006, 0.13800873240876582, 0.21171736110362316, 0.15803604807344176, 0.13276973288626442, 0.10994036636886098, 0.12748373386960837, 0.11731839062826288, 0.2050725595965501, 0.14439664931306917, 0.10665370361699213, 0.11351168441075472, 0.1573412829349118, 0.17854011557515592, 0.12137743088627055, 0.1795442729827858, 0.059977261079174865, 0.14807111343308804, 0.18069427820944017, 0.15072491861158802, 0.15531367802571866, 0.14004427398885452, 0.16091345899528073, 0.15072926999099795], [0.06602907988933787, 0.016740415425550555, 0.01470142932263233, 0.035153886438497615, 0.015244842300401821, 0.050822081374785597, 0.029445223307477373, 0.022222938977422255, 0.01378558653091351, 0.03300865255897084, 0.06710959328038078, 0.03977372987015594, 0.07235923376415046, 0.00907639330703645, 0.048233014456326925, 0.043275295606543945, 0.06717625059067242, 0.10443214056712967, 0.014020954596719915, 0.03477081949371965, 0.10900419160363176, 0.010721728002892868, 0.028240302983190746, 0.06087957092771127, 0.010663490956498971, 0.06662681233137846, 0.028086405495301853, 0.04184768309876804, 0.011850414917834345, 0.049072662143096815, 0.03943146476822515, 0.01791698283575956, 0.03171291251126076, 0.050351102010256825, 0.050670759857542096, 0.05586521519768623, 0.08944376056352932, 0.07164655748995082, 0.021370788735728112, 0.06133763404983667, 0.03321200676803147, 0.042374690303639065, 0.016561872889137557, 0.045777526458785425, 0.03998555318121949, 0.04982360067867464, 0.0013365919256748092, 0.05918924771850148, 0.10088755133291406, 0.02495369768791622, 0.05848884034240919, 0.0708017310488128, 0.09773606479528452, 0.07551191539894189, 0.015436753071093512, 0.021361063249529372, 0.019281988723143455, 0.07615277093024024, 0.08732086197743494, 0.024695428381223353, 0.0658041181703729, 0.10594463561691585, 0.06276120161337238, 0.044927544245916995, 0.009675846574076963, 0.025661099446757187, 0.01671448909497309, 0.03939373493795434, 0.016123421617873734, 0.03503267983755758, 0.08231710507384232, 0.03138792077680269, 0.01307892021647985, 0.05026870159312122, 0.0400216895486078, 0.07971473503857851, 0.022842813275694367, 0.026113652481487202, 0.05132643535973565, 0.039267330430448055, 0.02210080541009384, 0.04247191835254912, 0.07246100088401188, 0.10037977293494249, 0.033634128875189254, 0.021044147997013023, 0.06826762710848162, 0.050276860429514805, 0.02791732989041315, 0.01216050049650573, 0.01701026415121892, 0.06261598581688539, 0.028438419066069108, 0.061269819946779366, 0.04286442350055422, 0.018943111645057797, 0.03510613617817721, 0.08941153890543407, 0.08794555305353097, 0.05810561634960675, 0.07494182340920934, 0.050658188354704654, 0.038880356437256264, 0.01795745717601911, 0.06788938651762663, 0.017419353187564882, 0.007096133589173758, 0.04698956948554805, 0.020731620513082995, 0.03718057587262123, 0.03537167757449131, 0.0014198386305642706, 0.029775868770816637, 0.038966269367524696, 0.013397774629054532, 0.05168006920646276, 0.07209993598441924, 0.052841263147251266, 0.0680436383211805, 0.03990237135440111, 0.020167783631252188, 0.05847480561163637, 0.10667155346562786, 0.03523034584378043, 0.06269443322033172, 0.0680829233099376, 0.05537144088697049, 0.031703296192591233, 0.07626607533424132, 0.012085940989275134, 0.060624636018708836, 0.034313683337982626, 0.08263160714939718, 0.02083037307696237, 0.033928823747461846, 0.024722116969285474, 0.005496478801022374, 0.03744666119136157, 0.0293277149959918, 0.037971864259170915, 0.04307021769965368, 0.022372753216674732, 0.04593200808871658, 0.00819150046745856, 0.05128959802189662, 0.06628231791358802, 0.019200086263158632, 0.09320746626584761, 0.02269909518109935, 0.020937864788837975, 0.03119653477633913, 0.04390921038124831, 0.045826341581320575, 0.019631296088318193, 0.05716875210524567, 0.06029506882412299, 0.04616576066661266, 0.049170955054221616, 0.031844616431983254, 0.07208570973166535, 0.04402226197623438, 0.06885003779203662, 0.045092954120088014, 0.03415375482290983, 0.06313134465486774, 0.09285617664816881, 0.03113043671023221, 0.03516689844189152, 0.0250091222340181, 0.017408382808489185, 0.007093876023821894, 0.0566272926516831, 0.031952464374743646, 0.08861774924181162, 0.0302286094970881, 0.021371070273040284, 0.06936052048038091, 0.013160092020106894, 0.028372441658810265, 0.09080945784526487, 0.0695396701414739, 0.016575683539192525, 0.06019791355356575, 0.03063719866106347, 0.01426151961148266, 0.04082726930538493, 0.04893355206736634, 0.05742533027284569, 0.028201025655312885, 0.006624380954646416, 0.04535679480121021, 0.0604562345711935, 0.007910295924727596, 0.059386189771635886, 0.024483993859781374, 0.05624198873016623, 0.08652347170056836, 0.022645589685247793, 0.056369933074400316, 0.03713606999466016, 0.018566906932861577, 0.01996001101008827, 0.06048365668844312, 0.03070816521592919, 0.014366121256663917, 0.046088171281641534, 0.05380328571904571, 0.07280092941777361, 0.006137965397248346, 0.09052818100298606, 0.011696324950354475, 0.02859205799928356, 0.06746094418509353, 0.02452853421169904, 0.04222775463976207, 0.038878682535141706, 0.07099689194752325, 0.023352790346008637, 0.03339419396774423, 0.0667286177556361, 0.0170426543486575, 0.05187135753071597, 0.059075686675045765, 0.03909167029985017, 0.045731913583773764, 0.03657127933336362, 0.08401896939763139, 0.02932136987275895, 0.030605737345233083, 0.057940317558184753, 0.02516825784808926, 0.03782063850291795, 0.016671936741218935, 0.02641727036285785, 0.018849001573999564, 0.03975088512825389, 0.0061633516358391895, 0.03062048070733586, 0.07817485234549931, 0.015764175219491364, 0.033953553065657616, 0.04144349510991766, 0.03983142778217312, 0.030041540402077863, 0.029920948586697062, 0.03605426574546484, 0.09971450984237656, 0.014075335348024966, 0.08539773613935517, 0.01975188024281975, 0.03440806153981436, 0.060555772375195265, 0.043611156213427746, 0.03546661119006815, 0.03356467534397398, 0.04604630074613998, 0.02167924829278021, 0.047406110642177444, 0.015920502163710135, 0.08453548885881902, 0.05406976174262743, 0.033417728188778126, 0.05405842364134808, 0.020927486212683782, 0.06360283346786615, 0.0347977819582147, 0.037370768691142725, 0.0595511514843712, 0.02795928278036656, 0.012001002905890347, 0.05566137069235406, 0.05004157184533054, 0.05376022008638229, 0.03795586834331194, 0.028442391231956504, 0.10700190590033609, 0.005555833378175815, 0.04375043099806194, 0.01500936219423649, 0.034790580731726466, 0.04968875771268241, 0.032228549056115656, 0.021610166314208222, 0.02776330216757713, 0.04881410363821253, 0.007119861726213488, 0.026962824556375706, 0.018818080350155794, 0.05943089483245727, 0.09687177205999052, 0.03620834134879612, 0.0577320910299257, 0.02067313161528399, 0.03989818468389492, 0.03443213968327449, 0.03301754683977173, 0.002289830820612429, 0.013468209710422785, 0.059133859561576005, 0.020444801024672006, 0.08700825213905304, 0.06415886391374855, 0.058726875351802, 0.04008989818694611, 0.07010286733988794, 0.040721127823475874, 0.029200396928635818, 0.05104610463604332, 0.044685249787665186, 0.02962100026648372, 0.0021068928547338735, 0.03337257879696066, 0.020449025999574412, 0.07505848327831877, 0.03976862772458023, 0.028390651568770412, 0.03268931646861377, 0.08210683692126505, 0.04970572656020523, 0.037915074161344, 0.101244303157493, 0.040316759803963285, 0.021368011667002595, 0.04720507001864815, 0.04105394706130028, 0.037374484217575485, 0.04701908302283095, 0.06433531311490844, 0.02161939575847599, 0.012884848120231784, 0.04406721984607078, 0.022653409527734886, 0.022840643331648845, 0.0022745030770649115, 0.03861340926960111, 0.06784654688090086, 0.01985837987083341, 0.04708403195705145, 0.04373004922883646, 0.036949374367513006, 0.043426643936864795, 0.08516797104910498, 0.04577574147392185, 0.03637674279631146, 0.013718797070454928, 0.1271751536537082, 0.0468668038956821, 0.06506238418120532, 0.020698211418705124, 0.02264298115586562, 0.03140769733656799, 0.016703124180616393, 0.11569635266618383, 0.08341904594412736, 0.13043820557575073, 0.21930215249378837, 0.14886588368925358, 0.11149667398703676, 0.1438680792888326, 0.13707209799078204, 0.11274412559765963, 0.14105486653504834, 0.22843272545404975, 0.21382456254814902, 0.1939486411790694, 0.1329776644706726, 0.13257845605333007, 0.13836097963635, 0.1412120677771107, 0.18133247541564126, 0.09299044887865744, 0.1267958175571215, 0.23674951385586496, 0.06810473383314188, 0.16340491482086722, 0.15136754380599146, 0.08302200555561051, 0.15562300900778464, 0.13866651082231155, 0.14678983137972895, 0.07495670083669886, 0.11922583464653262, 0.10330871093056856, 0.113070601627471, 0.11983251499552881, 0.15324942347022796, 0.13250534062183675, 0.19794245671120383, 0.21009691660442661, 0.1373457599190935, 0.10305392540871136, 0.11976730559141406, 0.20307826419030467, 0.12982268457210835, 0.11639008358601602, 0.1787861830164348, 0.1984589072244783, 0.12628110606343518, 0.13775809908345824, 0.194292446117728, 0.12291496935030147, 0.11246209032833578, 0.20543715616147365, 0.1591922892557998, 0.19694459654631155, 0.41822890961362474, 0.18630430943542914, 0.12541765602485788, 0.13063035574891876, 0.15525153297330105, 0.161329506025199, 0.09529186127286765, 0.23931223118016798, 0.17964970200292527, 0.3074024629689032, 0.18449920710296402, 0.1040383330696533, 0.11519130920210194, 0.1302442627568399, 0.1320385172842972, 0.10274011281228836, 0.19250637340930202, 0.15962724333568928, 0.13345303734944713, 0.11903056649551277, 0.12100986190020077, 0.09171059940971675, 0.19504909583878136, 0.18531049421477705, 0.17107679508626464, 0.12680954585272458, 0.14968768152738773, 0.06697875312379292, 0.14801747195662993, 0.24787936179387957, 0.3366223434286733, 0.16590363315997586, 0.1998859298445525, 0.10294484214917307, 0.07887530185642742, 0.15228254390099358, 0.13871995311590934, 0.14485418766496644, 0.1778489204063531, 0.045863665384991516, 0.07621465551276362, 0.11633039767583532, 0.08232954634173263, 0.14478444302033994, 0.18549553509200775, 0.20112385132139732, 0.21143084421994227, 0.1945198823006884, 0.14823625134604593, 0.16537147784425368, 0.14000932505774882, 0.1410314702098408, 0.20193002096587614, 0.11639128634405714, 0.11652791812535256, 0.14439740007923496, 0.07533421364402579, 0.12439025550960534, 0.09034424329236632, 0.16150892381706547, 0.13385455935232102, 0.1792579552819652, 0.12368067423061979, 0.1484020480946187, 0.13492090777764398, 0.1839270466758359, 0.10728525884088971, 0.1626221415015959, 0.13200163781162233, 0.1862442787856825, 0.13053601968192285, 0.12046679749243683, 0.20477688030129482, 0.25164270743487344, 0.14614729811587643, 0.2050142296619954, 0.08762699071197741, 0.07384048008750524, 0.2183643229786427, 0.1542192448170916, 0.19073755300093084, 0.07868584831275287, 0.10161174190861565, 0.12991706660437968, 0.12042266316711904, 0.11721955762515146, 0.15936609928406056, 0.13258331305077, 0.11209561684799772, 0.15101558769181853, 0.06455603836765213, 0.20015681853457806, 0.11420170746503339, 0.13239620373614375, 0.1504740861034201, 0.1227622420617169, 0.08620733785773478, 0.17139806171819089, 0.18179290957989233, 0.08387877530748807, 0.19031919238548126, 0.10281943355596836, 0.14471183320687664, 0.14491264017358904, 0.17985752633502408, 0.21837460387858654, 0.16434962380557291, 0.10103699210430346, 0.1482870889407012, 0.12069392724022751, 0.09069200124471419, 0.2652103544002579, 0.18718693465475114, 0.09490743835246372, 0.10055823311690362, 0.146504953924206, 0.22419938487150978, 0.12767782990610407, 0.17724303678879816, 0.10036912431279499, 0.1550095564415378, 0.13044945174647918, 0.12360179015705663], [0.01200494634348058, 0.08802871955859085, 0.030043945918160102, 0.01268192483562856, 0.05042000012772699, 0.041450577592777635, 0.04934331717630548, 0.04053829327946709, 0.024037270754155134, 0.040055213556174314, 0.07058923358037587, 0.016477963278791117, 0.015301066450774671, 0.0837650265724909, 0.04859461561746655, 0.009248536136451989, 0.015790207844768322, 0.06666192214094824, 0.0725320019128342, 0.02819991291260287, 0.1091058208276668, 0.05644606306187569, 0.04657647572457791, 0.012427842199441888, 0.022491487268839153, 0.0255417984895288, 0.005486732726210668, 0.015991532878439515, 0.011467890937872713, 0.03211758505072325, 0.07741734460597077, 0.06570048945685548, 0.06148512895789839, 0.05994635326186976, 0.024833207379185387, 0.0068343316595400536, 0.03572081448510289, 0.02006842202747301, 0.02928315932231565, 0.05486323347976131, 0.06979824013767705, 0.034046663391974666, 0.009473112896235, 0.01840249297299212, 0.01904362429594321, 0.04694202989940682, 0.037301755660483916, 0.02497366960010221, 0.035222822860363996, 0.029606992348788247, 0.028014117438766747, 0.023638838000835913, 0.01145444609480159, 0.06013805910404171, 0.04817710919005256, 0.05900364376664643, 0.008991697498957717, 0.02343378499180319, 0.0731111414009525, 0.01410694988144021, 0.022960177945694136, 0.025383610909263936, 0.005684384368284936, 0.018641194478879054, 0.021104870041111307, 0.04121870576073566, 0.03176090600449712, 0.03784612241771914, 0.013675310089433146, 0.014004047036231046, 0.06396054673279006, 0.03197427489794791, 0.023171332845043753, 0.049508891759380225, 0.02964490987060051, 0.040887594898982395, 0.0434050785617963, 0.05132136385767691, 0.025230814672766194, 0.03226737056167857, 0.04021034253040149, 0.018512564485952742, 0.073980467333909, 0.03708090400323272, 0.0375068910239685, 0.04571946082456459, 0.08187886447675767, 0.009083107110082863, 0.02129073063242099, 0.0423437709950151, 0.0336813850087985, 0.04985418673905154, 0.059455930585822755, 0.037222312342736034, 0.0705471447098159, 0.05531480400672844, 0.05831752393034197, 0.020337236534443595, 0.04431423723637577, 0.012354511305719856, 0.03161473259810479, 0.03848186048168329, 0.014689686152363017, 0.0462060722131883, 0.02199684919398879, 0.03816895952989017, 0.026271979872798248, 0.052181558022576, 0.0663435053561003, 0.03448072114899274, 0.06339105612207806, 0.026991290468422156, 0.02662195756490673, 0.015244984984277718, 0.046303300262098356, 0.0366812550853337, 0.038520555582738696, 0.017240456335486907, 0.05392154671191689, 0.04887137637143174, 0.03944397115358903, 0.04189312743443636, 0.04647214604060977, 0.037134809780024716, 0.036578197107319875, 0.04994142500142898, 0.024084444533312516, 0.04906051581905735, 0.02302817207941365, 0.04336944781243802, 0.05972880727401184, 0.07366931306258326, 0.052357045783390926, 0.042433334334242734, 0.008471654990928308, 0.03979020459096759, 0.021547492661122835, 0.03961408097717551, 0.019903402858143373, 0.05114500658706792, 0.019109634261938836, 0.035208703859919505, 0.04142944122694674, 0.014869667976463755, 0.012836221646847985, 0.08165818518928944, 0.028934623790724628, 0.02591047447264916, 0.01736048124580374, 0.07032875602524127, 0.07201850083806823, 0.03594892865587627, 0.07366206587081955, 0.026240694757190444, 0.013502538110309792, 0.03992769056029859, 0.03263467141697484, 0.02999611138816803, 0.016778131849282694, 0.06007716277494066, 0.052878625255318425, 0.036248327308003946, 0.07298161125471515, 0.027421552259775422, 0.02359728730704275, 0.016832956931583824, 0.0892664878178508, 0.04903409344654891, 0.014235882479096613, 0.06340818584806497, 0.06949806390630622, 0.08577983781334855, 0.0619595327354487, 0.10372811342559515, 0.1305307796405208, 0.036701878172255335, 0.04216511546063327, 0.07050170803502684, 0.10653552689379263, 0.018325608388911334, 0.04031084560518784, 0.05107526960332067, 0.05014813084515834, 0.021096709289497906, 0.023663726282275976, 0.02025351078519898, 0.035720626793561444, 0.032630346850642276, 0.0448931468981168, 0.08506781271388454, 0.09142132460950844, 0.03498020664518399, 0.011542597917028734, 0.024048637583731644, 0.04832096901091357, 0.042508372646426006, 0.059599024318759485, 0.019499186140995835, 0.030829532695333325, 0.03940800332554406, 0.07333827880962242, 0.04012523782289317, 0.024553131379727876, 0.053342606406658895, 0.03804498352110386, 0.043296811185897364, 0.037397183402771914, 0.018916470937490947, 0.026982671979274002, 0.0031472041061328306, 0.009518236432585024, 0.007232930558177853, 0.03744112620610864, 0.03551420057192445, 0.011316700613186246, 0.05339656580960559, 0.04323276623542752, 0.043584818110590985, 0.03047197264799428, 0.05051367735910801, 0.026720746517962506, 0.029841941939066016, 0.03305620363643093, 0.012367626730983537, 0.08809299433543798, 0.025116366882538124, 0.015877978538253134, 0.01949348453161938, 0.021188379370517308, 0.13324498319097106, 0.055634258840713775, 0.03572525779506372, 0.061303799776660825, 0.04623669657796141, 0.007963599364889126, 0.04989198934767516, 0.050873210082852074, 0.04007509736824901, 0.0018555890827912898, 0.06234489028312026, 0.012362570550683285, 0.0625478346351414, 0.03917353445543878, 0.02407975990565554, 0.07060676933296266, 0.01193729982215671, 0.006807032116358319, 0.07905720943404783, 0.014917793619867056, 0.06889711389498365, 0.05970733382949426, 0.00647365267673928, 0.028455613909529585, 0.115469123326963, 0.049609605508345755, 0.029621764439188188, 0.014217471471056344, 0.013418729049003413, 0.02996749225853672, 0.016222541903956764, 0.064996178862789, 0.07947386167342625, 0.105964959929547, 0.05871786998825208, 0.007678992912969402, 0.05350536178617228, 0.0356989273531062, 0.07158099568539089, 0.015197083421592272, 0.03292291965936461, 0.019921733426951596, 0.016484672293788003, 0.02384402124481576, 0.009015703821674952, 0.04867780127472455, 0.05392780565025826, 0.0325167743158677, 0.021560663627761028, 0.0560354475953406, 0.08716137013247899, 0.08101028930996695, 0.030733415473913474, 0.06015558336530963, 0.047226677528552474, 0.06458971559280349, 0.02583544765178475, 0.03453392595533402, 0.050353564982933384, 0.09683419544730457, 0.07709775570659869, 0.023984345569906217, 0.04618403952448599, 0.019719233405926538, 0.014355103954702858, 0.1193115062591049, 0.03289109636699, 0.020711219591659405, 0.04728793391897794, 0.014158568885778228, 0.01828083438017676, 0.03991139203970952, 0.025833689479998527, 0.023311467563372948, 0.04347113449306738, 0.006626062038835259, 0.028896568373085994, 0.005828473057913324, 0.10835462565263433, 0.07854131050407887, 0.04213867776636635, 0.006977142418749751, 0.03605580941263226, 0.02994874800224939, 0.03532323783503906, 0.047069893804408854, 0.04681084883369265, 0.09660267601570777, 0.03737873600555524, 0.015065896610218673, 0.008486370582343831, 0.03833356884218032, 0.12427621566119695, 0.019665919432056048, 0.03149436294822203, 0.013762592401866232, 0.004537939535258639, 0.047667553468096646, 0.04499079246494559, 0.03120781733624397, 0.06490797916006658, 0.04789178357309392, 0.07011269624795645, 0.04632925149053336, 0.0054890410448875165, 0.03300201823754657, 0.05279340180418184, 0.012763177078487653, 0.03613360564134294, 0.08230870875019221, 0.03437233885990516, 0.05982801566020616, 0.05843655484157705, 0.051981858052914186, 0.05716372656846239, 0.03534405244394176, 0.04951763282259626, 0.0814752510538505, 0.07504426468644412, 0.04632457835419525, 0.04657950560231844, 0.08530419680380052, 0.05675275870148213, 0.08186232463847246, 0.15744776915638678, 0.18697374770718236, 0.058021645452226364, 0.16619751980948835, 0.1269668083818209, 0.10320273798800285, 0.10040826374484647, 0.1477781307673262, 0.11430107672969181, 0.10969377798779358, 0.11836996121752648, 0.10487337656799825, 0.16707688149425293, 0.20110728850047435, 0.06337764575296352, 0.12597765097574842, 0.11198775166825903, 0.1397388194116854, 0.1217294789309944, 0.2625688525938219, 0.11800564810513489, 0.0808765686627838, 0.12101680265679476, 0.061760882306243145, 0.0823332082420107, 0.14671348305719514, 0.1022686546428069, 0.223810518641145, 0.0819806162748606, 0.16661342894358022, 0.18428945222929602, 0.2490959707046709, 0.14271116394910122, 0.20142406585716432, 0.06492966710920296, 0.13815709299618198, 0.1881135179991684, 0.08294997796896966, 0.16983545685727752, 0.14056532102967464, 0.14836408077709137, 0.1446265982644212, 0.13587579040998413, 0.1097526288621368, 0.1350699425224335, 0.12895962523837246, 0.11222875526835842, 0.20809810127942793, 0.166344286934022, 0.12541750280727304, 0.15150591460687501, 0.11920183311186491, 0.2881002342028003, 0.21374223873980586, 0.23991546413350492, 0.16792278045848494, 0.13117672965651558, 0.12577747986201318, 0.14548662388997693, 0.11040757275036267, 0.11066426583115133, 0.08674982769955551, 0.1876880480877815, 0.1367913880535672, 0.11715057140757, 0.10884210272061248, 0.15345228355257742, 0.1623454305433458, 0.13849653123367217, 0.09532849559740675, 0.14713798769779746, 0.09346773697724266, 0.14089899828597424, 0.14721275787920723, 0.1554110631226532, 0.10350273035827184, 0.1638657320290804, 0.12910423199495963, 0.15567663516248428, 0.16104685022465645, 0.12963099405169487, 0.1072529529131228, 0.11020003953167509, 0.25140312109743396, 0.13286155618486867, 0.26225383723935775, 0.1136746542948869, 0.08640499620307839, 0.112585085744579, 0.1229107175623217, 0.18042400238975403, 0.1468352297501218, 0.16064751923324602, 0.11660579862373492, 0.1499371810425674, 0.17005762235531885, 0.11066898493276489, 0.11434577029919434, 0.14573373321083286, 0.08148375462981002, 0.09515994093230656, 0.15105177768536154, 0.10997624226635504, 0.1662752930555613, 0.11814726711881739, 0.1634296288173045, 0.166900037757812, 0.12129347531064866, 0.06791862043281717, 0.1282717702129195, 0.15047318211966945, 0.15819740151205372, 0.15206427012960758, 0.11492413603850912, 0.10852961545629848, 0.08887130136211073, 0.07289970879473033, 0.2057598017516636, 0.20624177830834545, 0.100153248396612, 0.1462233400032405, 0.13375106087375072, 0.09754547744148201, 0.11347643670535858, 0.17930479389765572, 0.12218781401433292, 0.1521717829089011, 0.11706513728225425, 0.1221756945033708, 0.11401539488184838, 0.23329747570378168, 0.11876343929719542, 0.14472948387265205, 0.08436480446928933, 0.16397650834293137, 0.14838412163719056, 0.15407531221787776, 0.16636081911142797, 0.14210350300756194, 0.13791048929335611, 0.09785856225437696, 0.1931951324185056, 0.1142004051155621, 0.1272831260857563, 0.23656839534880655, 0.13491050430363224, 0.11956542610160767, 0.07152389915239427, 0.20393796805893222, 0.21462927662557174, 0.13280803728247845, 0.11885130958211039, 0.12337693569040108, 0.10593019485954316, 0.2070281062755854, 0.14041754266908094, 0.20180246732648344, 0.11193622459447193, 0.20814123202956494, 0.13601705702322145, 0.13197683188463413, 0.22408237260195518, 0.126242165814244, 0.13919863549451675, 0.13647960559014352, 0.19082729254038105, 0.1602015488090054, 0.14876829940945874, 0.11750086511094725, 0.31447265777857075, 0.21059559387785776, 0.17262001792269369, 0.1098291380631347, 0.19115465723218458, 0.1444629618837949], [0.03058934880931291, 0.04097088397811017, 0.03601894909215551, 0.035944661546138026, 0.01793530957412816, 0.041876254347904075, 0.012334339253063644, 0.041855930035272916, 0.03785687829217604, 0.0254363656389497, 0.023235933209258704, 0.02221273468627084, 0.054700367017498905, 0.09698141456371355, 0.006597037361409035, 0.02577407826339045, 0.025123118032370845, 0.06328460054412004, 0.040035739601139105, 0.015247368475332137, 0.025684206573773297, 0.05261374269461921, 0.07336490802587041, 0.042566855798565575, 0.036557382498417175, 0.0488336235585232, 0.08584913046609971, 0.046017166422379595, 0.027213536405695543, 0.07437804398397285, 0.03707838740440146, 0.001969019053391211, 0.016858011837147416, 0.08804018789481732, 0.05344988169869589, 0.05253001311493497, 0.015209133984641203, 0.02080820057721388, 0.07193066885754948, 0.05607335745627361, 0.07266396821867074, 0.042041108808329994, 0.010936565869938462, 0.052441721481661645, 0.09628304115106022, 0.04406037102002771, 0.05538912219626289, 0.10608836903326935, 0.06544674581457531, 0.08750296873791565, 0.034387553366081375, 0.10101911927302999, 0.08304399227903736, 0.042327882331465526, 0.03131872388504205, 0.048664766288692915, 0.02939632583049036, 0.02911988300301375, 0.06326804155363672, 0.026180880527282437, 0.05617972493412034, 0.07443527841279585, 0.020860185388535745, 0.02966992455654808, 0.03626354181418016, 0.03979837491868004, 0.021570946442924684, 0.08012479126092889, 0.04985339766848953, 0.04086913601044686, 0.17684252602198433, 0.004385576138438116, 0.023022617941962618, 0.04091636916141837, 0.03156986474359949, 0.10283739831779273, 0.031412211509661815, 0.08748187833736021, 0.14867094495604116, 0.10226235740006932, 0.018169975711873943, 0.007782515810592281, 0.09876092189862844, 0.05658963943020471, 0.010102669588260112, 0.024402116297654087, 0.05256288211732622, 0.016554112418464596, 0.0161404000414956, 0.041013091592298406, 0.033591687604184114, 0.01756867904576563, 0.08004288880094405, 0.03609337070355973, 0.06661263970477928, 0.02937427782002957, 0.04261613823473454, 0.02566028930877726, 0.007487043359076545, 0.07910059299319983, 0.03188481498059006, 0.06633067338336861, 0.010331137117088563, 0.029337281518946254, 0.022182372706611792, 0.025878754602144324, 0.018352653207858245, 0.029077755828057567, 0.03603966410962805, 0.028498194991580905, 0.03882917410303508, 0.007467357772252253, 0.01706456254807211, 0.024973079712400516, 0.03992816553481164, 0.059405418578535325, 0.00943669403392461, 0.023520102033451683, 0.020912403856674512, 0.08312190342093669, 0.012371771266653895, 0.03645212584806066, 0.019084087144883893, 0.007347949562714466, 0.03415635952185239, 0.05949022068131355, 0.009048181161614917, 0.032547582541742635, 0.017619461099046375, 0.06724056367191576, 0.07169757128482865, 0.01930685976760522, 0.10446843781298208, 0.04000496967966038, 0.029566862748094627, 0.07149241293870634, 0.04263883741993097, 0.020714661241659237, 0.03378290698052414, 0.021894101481584292, 0.07067047720474583, 0.016957992056925452, 0.021571534415406567, 0.03814380886333604, 0.054782575912653446, 0.03234393721927078, 0.04353890263084923, 0.12524358552670287, 0.03807720900963872, 0.02910486384925823, 0.04914524897392239, 0.043506121728569276, 0.037303847080517205, 0.05305364570249954, 0.0068739168590024845, 0.03326679737637601, 0.009948476198910466, 0.011726937823808722, 0.09692485429226391, 0.04315169498084053, 0.051820056452866525, 0.06290235714386068, 0.02289735490546352, 0.02945693679183962, 0.01759771186287605, 0.02741529332143405, 0.04704693414931817, 0.06446889586626522, 0.0652522897167552, 0.04110943480965592, 0.05996884177288702, 0.017746371224582676, 0.012182934423758379, 0.04501058434646937, 0.09968172894009661, 0.054515647897196394, 0.057852975873937534, 0.05375090445722303, 0.09569296958826243, 0.0660952698859957, 0.027348494284876415, 0.047345765896381876, 0.05267794086267391, 0.048775937137824875, 0.04667698262980388, 0.02019442242359923, 0.03226268210358197, 0.029063056516010436, 0.0817682643631293, 0.03295693013276304, 0.0749276967478856, 0.025949443450137496, 0.05527391789420959, 0.05916512360976589, 0.05195035268702815, 0.03312109511405711, 0.03287712675369075, 0.02634739931372385, 0.008795035067915676, 0.013890781894236082, 0.0324212393212703, 0.051154460112053546, 0.08323945961291752, 0.03406295808212411, 0.03746977023359749, 0.09871797500959328, 0.031162296391783223, 0.007820576495085394, 0.04636317769426011, 0.048347544601006855, 0.061040457052689415, 0.061047865122917204, 0.03500918009048028, 0.03049047367136565, 0.02231311518698931, 0.058150712115269516, 0.021377769711938117, 0.04230345561799984, 0.034489646073310606, 0.030123793347288045, 0.04300067989876674, 0.0734407200868572, 0.05026656037737286, 0.051530103664845235, 0.06013658821522709, 0.015213660606663796, 0.046934771216324264, 0.0648064342057032, 0.01045148857238312, 0.05865368331151624, 0.03220068260786995, 0.049653636411793774, 0.035550543783052314, 0.02157850581551752, 0.11476974633912887, 0.05095549558679904, 0.07965242144681754, 0.08017024325747645, 0.0265862291393381, 0.09828751020494009, 0.036028402617141124, 0.019090650603175163, 0.022692112289669535, 0.11152077511313463, 0.03626504334651175, 0.08154475821122047, 0.034602931325113585, 0.029328787519085794, 0.043203133954516346, 0.05132671498182801, 0.01384872462480299, 0.10001460946495495, 0.029427068938891736, 0.12019477499228333, 0.07362575330320867, 0.06295074708759785, 0.08719921487593844, 0.05676614225751931, 0.00874270934746751, 0.038344765217193676, 0.040646786651303696, 0.023827751452523856, 0.027944978003600435, 0.008655736343033852, 0.035849704947923465, 0.0502475269228941, 0.0067265253728105425, 0.024625323675272447, 0.04955458507362393, 0.01218683093846325, 0.06414661416783929, 0.032812495745958827, 0.04901961438478001, 0.02454279302318971, 0.004517060287687327, 0.08054030969017938, 0.02317673184969012, 0.054141084528377945, 0.03455783938989043, 0.016595730144951134, 0.07039832446964518, 0.018354455429700114, 0.046436331430149656, 0.043390967222231056, 0.06198791246260367, 0.005444711367149027, 0.08045472234727875, 0.031962356485065915, 0.00638823626720677, 0.02638967970626489, 0.06106360822976117, 0.045012794510130925, 0.04021491224486982, 0.01140741021147058, 0.007503477860272172, 0.04191071298273821, 0.02595811365022054, 0.04593088960034713, 0.03383006352270323, 0.07726004377247826, 0.07495359051972628, 0.008730010482512655, 0.014288826815543637, 0.0414519144162055, 0.03538070209023934, 0.09784870270279147, 0.005048088017745965, 0.03469994869984446, 0.02287326718590433, 0.05122778621772605, 0.053557026755785754, 0.02317041545475443, 0.058341682513034156, 0.02421617143667273, 0.08364448263760536, 0.05217600771556458, 0.0037420390600023134, 0.02426732312737694, 0.03198743437326724, 0.026308623773436395, 0.046261314813408165, 0.05558177798746094, 0.05483408000380282, 0.05857801297679544, 0.018728631924116806, 0.058737129438668496, 0.05718615762288532, 0.02245603080448364, 0.044686663219885486, 0.03969607153727163, 0.04640767974178157, 0.06315449200149986, 0.029405231602610122, 0.07164559221916622, 0.16476139606487367, 0.08627260088800423, 0.07336962712748397, 0.02134636776792186, 0.02943199105380524, 0.09966712730425982, 0.011395451578972562, 0.08581133934879497, 0.016942291084917325, 0.031048202917220134, 0.053565844427794225, 0.06164703781025545, 0.05977355063922944, 0.07584891747683287, 0.051287407010433175, 0.015953194008268896, 0.021771266943805163, 0.01350996150229607, 0.12695130276223346, 0.22734828203195528, 0.12502357273572876, 0.12628011781001283, 0.12638075111974634, 0.20591372413741005, 0.11639602076742919, 0.19001611268087742, 0.16653803057007252, 0.10569011056495291, 0.11004236331509967, 0.09713129966609901, 0.2025237697507105, 0.36728017092231785, 0.20094536815679845, 0.10965823150810697, 0.26637131468422953, 0.24350216522091822, 0.11164326491134782, 0.13562837465395852, 0.14178890134057692, 0.13546299159286485, 0.1215218001556012, 0.2635473920212638, 0.15349506190226925, 0.12311307202664115, 0.16327242757524216, 0.21011597687198272, 0.15306640506511734, 0.25661383665377097, 0.07071560744436518, 0.04153268306606239, 0.0582270221334071, 0.16036290224761734, 0.18178114246937538, 0.25397645640036753, 0.16665199380968848, 0.06554694245419194, 0.24941342221873425, 0.17880052418237735, 0.2243199977543085, 0.09808712458658604, 0.09628634299001387, 0.10188491354065557, 0.2219110955634425, 0.1284412212008911, 0.10196503867665607, 0.17284697913114103, 0.32855182165099733, 0.2111478973059885, 0.11780803572506675, 0.19788291635772876, 0.11432436580258994, 0.23279558086106855, 0.19460588333106812, 0.1391534363069842, 0.16131836710677994, 0.12129829400369238, 0.19213849798806254, 0.22401009986717857, 0.18384081581907888, 0.24587971909392267, 0.16071029247776156, 0.14959648642088139, 0.17996287874637112, 0.101846402300702, 0.11506724126276471, 0.17205439988643895, 0.15140215565841045, 0.1444868944705494, 0.17579100905887543, 0.21806184082261978, 0.21012501670948922, 0.16145476140081882, 0.15444202318547234, 0.18278203634244783, 0.2989269871144526, 0.2037802152335644, 0.38067031531564655, 0.1559572838126652, 0.18145694938157836, 0.08270070828016728, 0.31578999192964646, 0.1457365677361527, 0.08047840978589751, 0.09618642980292921, 0.1539144031102619, 0.057121258484379905, 0.1136955225299443, 0.11265571905119766, 0.13361408435288938, 0.052648569051657, 0.1921433243419855, 0.13327786368468117, 0.19152328341958985, 0.19387635312253432, 0.1377574708913603, 0.15492845837387348, 0.1229106792579255, 0.14182988704452593, 0.10736939827761344, 0.19406527040466187, 0.14350017322407616, 0.06006819188534733, 0.18666599486624041, 0.08628198546507666, 0.15399790669400848, 0.14216811486309575, 0.12647904020043152, 0.09815223439927064, 0.19579960153468196, 0.10981830557988537, 0.04925430158994371, 0.1737173009783991, 0.1142504996049308, 0.1212322572246194, 0.18734482537594535, 0.10734213320838829, 0.12744363682765153, 0.12484776321798564, 0.13091293494066886, 0.13274903319055034, 0.10374431618519368, 0.12549242620626766, 0.24692435658747153, 0.12124334251688373, 0.06664160548919631, 0.09418382234270535, 0.10179269953720993, 0.12226266846541436, 0.17376400169826325, 0.10470577951280341, 0.1975369357293652, 0.10706292480350503, 0.10613732205163087, 0.16219673287724296, 0.09708297483983541, 0.10660091249812996, 0.1811987011423034, 0.09301407503024225, 0.09764923638994656, 0.08279419398956722, 0.11777376095133445, 0.22015831703620575, 0.14724646574787556, 0.18067118831940238, 0.10488650731502042, 0.2118972691917612, 0.14237767055390343, 0.11337198827776218, 0.2552255321173899, 0.12004713452751599, 0.13731294071241734, 0.20517688545007862, 0.15798056798596538, 0.07975662472627817, 0.10856646428545637, 0.1111196055107059, 0.28598365584208124, 0.15751340756973914, 0.18152873182008344, 0.18226193925065381, 0.130176525262575, 0.21155256026935196, 0.12297173646549064, 0.2036647044963414, 0.13871068345202556, 0.144105643154152, 0.16377190158011454, 0.18070124960955114, 0.15266621605523173, 0.18279502919364363, 0.1551017781058627, 0.12777206638166982, 0.14560910602731092, 0.09731359028768155], [0.07123912128830148, 0.014069436471008006, 0.016199132172210563, 0.01413861708340025, 0.022374116853179953, 0.032226817697406776, 0.0603165997252349, 0.011801891866320325, 0.022763963676087802, 0.0689386818257551, 0.01943733220198943, 0.043891969572512374, 0.06024250753163811, 0.027823631591614217, 0.0375083580823435, 0.06404779648648636, 0.030292449519038204, 0.041588580671457515, 0.0485791253196376, 0.033366909746320984, 0.019489330419849966, 0.0231614081759847, 0.0231720567981322, 0.07638589148559878, 0.0049691555848825845, 0.027441916792022607, 0.0437196763983417, 0.021248603457464807, 0.07454013286699211, 0.07139568667738669, 0.05170907712571564, 0.015586554861417221, 0.041147746866749185, 0.04508186499738405, 0.0675107092566548, 0.09154368417277452, 0.024483070723832618, 0.029502287281737215, 0.00623372016331902, 0.05675958454488747, 0.018316604940581228, 0.028650190666197773, 0.025141584581785628, 0.0515906092891049, 0.056109214201569564, 0.026054089145374396, 0.05217699979942653, 0.018365077238770264, 0.01063619907419648, 0.0651608188185961, 0.026553950024648543, 0.009780784340334997, 0.06565016514110951, 0.049983207436819235, 0.030652489776032108, 0.008599232570568641, 0.0356331012482124, 0.023323468330706802, 0.033468090808920326, 0.0335068701796474, 0.04095458162708148, 0.020621058703850836, 0.01444265439790944, 0.05749558053550221, 0.029040499057079998, 0.022466989692240473, 0.04741064588268919, 0.058191824223726034, 0.028688382064442963, 0.03573805146339921, 0.04167411438820343, 0.04591840236718136, 0.0674381913737424, 0.02811341775551198, 0.028937780072972662, 0.03879513298611968, 0.04701712183774479, 0.03941392901563837, 0.09421166963875295, 0.012762303738253973, 0.07634776328960735, 0.06727490739356126, 0.09093534907386189, 0.017809345567178343, 0.009854862169783202, 0.04297143832269696, 0.09395420280916077, 0.09894227789294335, 0.04832879076862047, 0.048342595673016006, 0.015658754817841035, 0.0420505240289194, 0.0404364763638906, 0.026120834555777333, 0.017686624027368043, 0.05249436321337858, 0.02865979740876825, 0.07706728838985005, 0.0645363652297566, 0.05618010031720323, 0.03367718684697344, 0.031299357182316245, 0.030485220223424897, 0.06898956538568582, 0.06804238959786392, 0.012400828024011948, 0.0073615591146893086, 0.029300407791930824, 0.021372954849334016, 0.04204982305846868, 0.0382403206200369, 0.048830911607271245, 0.02823763891243406, 0.02718836850216312, 0.05144334420742047, 0.04988280778390266, 0.04114531070714997, 0.0063714364378322525, 0.031670400377122626, 0.054207780143065806, 0.053931758663947546, 0.026867352764032064, 0.04791391202278676, 0.02972534718743015, 0.017588135763822545, 0.029013948364844246, 0.07640166523595972, 0.02178586857964195, 0.0415020625317289, 0.07012252515602498, 0.009464396730876498, 0.009211837652049238, 0.015563862379490128, 0.08519783315639343, 0.07660149161012904, 0.05467767549318172, 0.046138235127493266, 0.015681573704275635, 0.018855614828005917, 0.09499953744272072, 0.04286717375620239, 0.02665356635266254, 0.024821260238006234, 0.027308104214288538, 0.030354328355902148, 0.07941809813341788, 0.04224218390581589, 0.003962400660384446, 0.04911256383263296, 0.03814486989511117, 0.013238638057373466, 0.13982288990049593, 0.05721347631826516, 0.13979128111274014, 0.05303781832598391, 0.08913668954083998, 0.056562136873723044, 0.029107497276497946, 0.00835524793083389, 0.012924683734684462, 0.01975917723029852, 0.04318232700649289, 0.009987742035469462, 0.04373672185465694, 0.06338265979842794, 0.026567450409094175, 0.023838867388305165, 0.07553996953872905, 0.0630564940342259, 0.03691763534481007, 0.07757668323334187, 0.043413543833359595, 0.03496027686783383, 0.07532996185604604, 0.04911503829662839, 0.03174706854136481, 0.034119254053239866, 0.057479163271284876, 0.01665673947202102, 0.031787809097178044, 0.034535607518327814, 0.020166331894635674, 0.050948570151963544, 0.047103846821212964, 0.07642192826155694, 0.09961894037382257, 0.038046822132122134, 0.035286143857745395, 0.09021170242058654, 0.011835725181886267, 0.04576833723413368, 0.03528057439853588, 0.029752370938959143, 0.0481982532167627, 0.01490570858286153, 0.023850739835911704, 0.008680414907904643, 0.030451089091178392, 0.025554490651214318, 0.10454811095710724, 0.022371799437209003, 0.03064902322817474, 0.0230954920557598, 0.01959307787699565, 0.027152375776260614, 0.05106487379018819, 0.06745932007869405, 0.08971551493290933, 0.01755064725124788, 0.04527539412881579, 0.05456447834149004, 0.046835616456284646, 0.0209976464600092, 0.06451067064077624, 0.030644177722053665, 0.025392545409680858, 0.030265303193441326, 0.05754300137801517, 0.05320779025374402, 0.038990320697907484, 0.01909787481230113, 0.06466044082997308, 0.013581479640467273, 0.011064411580352294, 0.0198550129144062, 0.05145629492378043, 0.018775005141393315, 0.021016268142228647, 0.05989877537133233, 0.015515310599678948, 0.07553073817924147, 0.08321982477941821, 0.053580066850108486, 0.014362075354813809, 0.015362495210983101, 0.07265109794154283, 0.03180292018148447, 0.013919470929390481, 0.018339681424080365, 0.007030748942446325, 0.0344548350380313, 0.037116101912913785, 0.02099572740975888, 0.06745443243773715, 0.08888065529566619, 0.01803226949226472, 0.046031741245139035, 0.04038782978069879, 0.04346493301132033, 0.05955630725610161, 0.011200128844188107, 0.013938275515101852, 0.04817479560452123, 0.060012041470937194, 0.019854859696821343, 0.014234328278220229, 0.05381111513763186, 0.03000701281933054, 0.02879311585979116, 0.03323892709769068, 0.024814005385363297, 0.04525737191039709, 0.0746647677113933, 0.08597407174567062, 0.07895757969949516, 0.061742197421769944, 0.03282941096732694, 0.043979552574455745, 0.03453257381014767, 0.039921791683281624, 0.09126954726995, 0.07680240582915084, 0.031110451391507542, 0.01990257165274553, 0.04796764542979579, 0.0252689543600765, 0.028508814885431243, 0.006503441526869973, 0.042758021548750906, 0.03790859688794421, 0.08274776140047659, 0.08280178592089685, 0.05246910529451505, 0.05193942061234867, 0.08206236551726058, 0.08143660191807055, 0.09062489194254722, 0.05810872283613971, 0.026048462229570555, 0.014027223111160341, 0.03838823304601735, 0.1223090091239541, 0.035509561909542936, 0.022949678710691875, 0.014915167853506583, 0.050865606660203594, 0.03799570874581414, 0.0064117834159743885, 0.060272074695075714, 0.09820016852069287, 0.05566877493214223, 0.0648601446300745, 0.0031110646265123283, 0.03155973897646031, 0.0832912854609951, 0.02979619882910723, 0.030112673581067114, 0.01875562886256845, 0.09486829125953299, 0.01864407305425454, 0.03701313203501125, 0.10244142279149064, 0.09144508099604039, 0.035609773870918064, 0.033113449556572784, 0.04878524127566526, 0.011224129421245909, 0.062123854764767235, 0.02710651392267356, 0.025655654476835363, 0.057063169867521336, 0.02782229859862597, 0.03514645155519247, 0.02803870694591634, 0.01931748349189518, 0.05144627066329122, 0.021425100539119977, 0.029664588754155466, 0.03836049683271878, 0.09602701456676568, 0.023631200104230837, 0.030124092121578516, 0.025143549597311406, 0.017786316964174473, 0.02888601551192903, 0.023403731362533667, 0.01939928827566966, 0.024272038398550886, 0.06532062475960101, 0.013952620511484003, 0.058943678234373374, 0.05017371435138968, 0.01384989865454695, 0.04367345831386986, 0.11940592659577248, 0.04318996490309796, 0.007690308031611025, 0.028696853081665696, 0.03679665473980769, 0.013785347128437172, 0.05144817822222268, 0.027291706102269313, 0.11563803039250836, 0.18206438049674037, 0.10928029735242167, 0.089391658923799, 0.11526430972040662, 0.08444541990156136, 0.15728276913925526, 0.1289004679288595, 0.15220398924523784, 0.2806329607002197, 0.14942751806830207, 0.07434104959810935, 0.2297597123129714, 0.07075982603935466, 0.17574213264930635, 0.19616654232865383, 0.12487492869578062, 0.19508206826304236, 0.12742661435397404, 0.08681752688942418, 0.10198959179462926, 0.11900137088471845, 0.05430147652664492, 0.2624321212210963, 0.12447961966597265, 0.15154401982022872, 0.1392179715537256, 0.10750357857755116, 0.17037412392035609, 0.1847987321595992, 0.16815754044200146, 0.18323874731938686, 0.12320090400715991, 0.14553966781785413, 0.13764130131852242, 0.18565632162555573, 0.1770233534156315, 0.14404896796951372, 0.14383844700792145, 0.10140767140734581, 0.1218786362498518, 0.14128355910220455, 0.10612158660566616, 0.20852991439882787, 0.18067215359018696, 0.20714020026066612, 0.10758055509218287, 0.07761989825315053, 0.08961741737420521, 0.1812434559988399, 0.12138508410463411, 0.1402450962773254, 0.19805061300435375, 0.1165946290617989, 0.2965665782891935, 0.09878911393424196, 0.17354946643594774, 0.11276111742782016, 0.18497169949114325, 0.1670066312315964, 0.07969139233952569, 0.1545944440388872, 0.07201268623072295, 0.12294899131501875, 0.11923255323762856, 0.14330195563454784, 0.17268181057466617, 0.28245637253407513, 0.2109630709333766, 0.1005130569120088, 0.1454826402327707, 0.1241281232045543, 0.10593595584073376, 0.1380961890062017, 0.11498962889515585, 0.09837826098045034, 0.1020372424635195, 0.1966510010102103, 0.16301850007186014, 0.16827564055640853, 0.155791379811783, 0.2144423358502888, 0.2189020094491782, 0.12263695604258007, 0.14955262022633709, 0.10680513621698465, 0.18795331369244284, 0.2899725224462248, 0.1416530586298435, 0.20053393297618438, 0.07763745698837504, 0.06822462659329176, 0.11615880930255498, 0.11940804865932274, 0.1467215423021586, 0.13622436041553176, 0.1285012518506377, 0.09547781379472825, 0.15047086853413813, 0.1623911200271499, 0.16304911294531438, 0.12487476015643728, 0.13197583597033255, 0.1988969103343064, 0.15124296258774497, 0.131353052453168, 0.11712165924930766, 0.1425599075493313, 0.1918415929521284, 0.15393214570658822, 0.16647315824464445, 0.15768260574869572, 0.08970164874147984, 0.09369275998324157, 0.07651914481914814, 0.20021220669150355, 0.10536015649596531, 0.1795192678729373, 0.12962976831101602, 0.2448469253196832, 0.14610519392355797, 0.10929370389109659, 0.11697837782482948, 0.1606836479397551, 0.11344848981788082, 0.14649496413767338, 0.17378517636849036, 0.11005656658521584, 0.2939072419558802, 0.14025177656402513, 0.13876487651178915, 0.13488620399467408, 0.16519454217726187, 0.15460149204779058, 0.15330628251596806, 0.27086739278128075, 0.18833614314996427, 0.14268735393641457, 0.10258475784212352, 0.1645720497735085, 0.23484227668133476, 0.14966079184124548, 0.1756959528692307, 0.06773872000555839, 0.15533892828370297, 0.13686329306614015, 0.11432308643575638, 0.13687673024833202, 0.16360395978535378, 0.13595860451459885, 0.07154944818466902, 0.2031030701172929, 0.17726733709775633, 0.2743204881346995, 0.16201714654603314, 0.1771642063413897, 0.13984024945286014, 0.11146483537290366, 0.10122089151052699, 0.07555712224735368, 0.12981140775786293, 0.14502462690636037, 0.10678861936133717, 0.12052467543511622, 0.14602002026813646, 0.09232394472365418, 0.07648684655226047, 0.1454217209210319, 0.1351347842043446, 0.1282255980937231, 0.1932577677671948, 0.13743974358564423, 0.17954643335073225, 0.18780155167464288, 0.11752773181445177, 0.1553698629140854], [0.045584070105706496, 0.06353955460532058, 0.013486023169882117, 0.04068253231385062, 0.00962917170968027, 0.054101362869504004, 0.05893590627238155, 0.016005392366599654, 0.025506311381656318, 0.0027047270428269144, 0.0405301152908754, 0.09080607173663956, 0.05101407833036877, 0.06509960073256685, 0.06698643698567344, 0.014785966167466776, 0.019100782115973772, 0.08625033837292465, 0.03359035461119587, 0.04863341414039174, 0.017707273927367023, 0.031315893190161835, 0.027360504628309322, 0.07609846295728799, 0.03379842026099082, 0.015850309357647935, 0.0602060838812782, 0.030714376273775296, 0.039291282169400685, 0.02225215374041469, 0.020041040129839413, 0.03095398750907231, 0.027725765774507197, 0.03537107236503113, 0.048274126564783436, 0.08616825971271723, 0.08891424059026665, 0.04306037346982668, 0.03193601455178953, 0.014845982453064814, 0.020509493319437872, 0.050020270770595926, 0.08924489179926534, 0.0660454971535552, 0.028591864562082677, 0.009706841533883445, 0.08004999043600214, 0.055246216154867606, 0.06252374116992278, 0.005279195198278514, 0.02513435654222004, 0.04313508619464213, 0.05108271597794468, 0.027038485314997456, 0.07864814146511978, 0.09602153703810708, 0.03372479538102785, 0.024708099475490953, 0.06041620264671022, 0.04588626497875779, 0.00978296673330929, 0.058410584460943944, 0.06847716747753083, 0.010179517783164498, 0.12854670384718528, 0.04026085453768892, 0.01546781506359337, 0.035465293518838384, 0.046415578108280904, 0.057071485751939405, 0.03146148628495153, 0.04424681383815985, 0.09133347730723121, 0.08095921422805517, 0.021120429286853443, 0.036727281647824475, 0.011505059608738991, 0.01898744898367553, 0.03951026840255626, 0.03184186617633508, 0.043138514438103286, 0.06917904957287735, 0.08286333342473354, 0.033453404903411865, 0.04552194420548697, 0.02971647397404717, 0.030895910383532607, 0.052832472288320144, 0.03153464385128069, 0.059313154779374606, 0.03817530656834284, 0.025505020523503907, 0.09927446893866985, 0.03190844113217487, 0.06751600292421157, 0.04002013822056113, 0.03703320736906702, 0.023082673489566774, 0.02379993096955361, 0.048800834995363994, 0.0321051208001952, 0.010991175490010892, 0.02337271246247955, 0.016514616755528316, 0.012058601226477374, 0.043900971105622674, 0.02000328348649125, 0.036731648348992875, 0.03047254529871768, 0.050804848226928906, 0.045278316754246914, 0.08508739392122916, 0.02502463742970459, 0.018979947067677014, 0.024492244626725876, 0.03085119766183198, 0.013377226235705518, 0.012080790963204158, 0.057242568507189714, 0.028955254538525498, 0.014135543155604073, 0.008408831950697688, 0.03234902021264838, 0.030045186980597438, 0.02631374507121021, 0.018460819077107216, 0.05323522003187288, 0.00789257678984394, 0.03973548676097586, 0.03833461455219696, 0.045986656970795126, 0.08180427815644972, 0.01886417394533994, 0.044924024071904926, 0.0486245121987116, 0.04293171666382302, 0.04670381485935181, 0.014482453623185716, 0.09548735158938555, 0.01790163617941641, 0.08809807349837596, 0.061421896060628284, 0.06884712665792435, 0.0893811711801156, 0.01175685451486178, 0.008031673937840688, 0.05227479475340056, 0.07204445589694285, 0.041141832667973735, 0.004172942689394638, 0.075770263229647, 0.026504650351501284, 0.04377849279872833, 0.04909882404571099, 0.10650879042523523, 0.011923735277847418, 0.0606342044568831, 0.017241578654295975, 0.026009079564603108, 0.005539894440106207, 0.027453325756434954, 0.02964602261331053, 0.07676609326153994, 0.053281012937546744, 0.02050766236929884, 0.05069883697996697, 0.03350870496022605, 0.017870672820736806, 0.05932020278827799, 0.008394451522749037, 0.014650029610962638, 0.015611275561123848, 0.04768565612574739, 0.06265338239890915, 0.012155846512365726, 0.04199703960048576, 0.05829556785043209, 0.04545080145039866, 0.06848229260574426, 0.05879439834144808, 0.02612394104231029, 0.08102055488815231, 0.011634560069069268, 0.0654196492846935, 0.027783249181905584, 0.04501313541925723, 0.029379391456924142, 0.08674222810734665, 0.04850900912236783, 0.02500822591114669, 0.008619358657949395, 0.10514339191779014, 0.035006012316913374, 0.03774029120141941, 0.019027712649755904, 0.03365712683467615, 0.05459359351305231, 0.06801253515145472, 0.026472091614719362, 0.04295420517484027, 0.07255304634811417, 0.021117158091416764, 0.02795603073712799, 0.04642183321618265, 0.011260758000125569, 0.13037941598844144, 0.05179954827913354, 0.05115890725245399, 0.02493146007069417, 0.03659671728288935, 0.05032341942311295, 0.03814344497157201, 0.05965883663344768, 0.06985267068469717, 0.011925633260679823, 0.043630434816042264, 0.05295285151430196, 0.05174972575097796, 0.0809687750053502, 0.06231969365129068, 0.035003143317636945, 0.053580794633636554, 0.022223402460616444, 0.0563827267427358, 0.04654693154377803, 0.0917174252531221, 0.021884958222208005, 0.0826470744645884, 0.023410250770769293, 0.023904356414512284, 0.048385220805122975, 0.04876336946542706, 0.05328685435796938, 0.012723131747465703, 0.021161411160362825, 0.0649451191026357, 0.02278917754489568, 0.05697557920469873, 0.02542093279771507, 0.05882588072469639, 0.08969331370486368, 0.023373744765957518, 0.050464176587880626, 0.043969945831885265, 0.05324800986976874, 0.03918940396679025, 0.010408869185935586, 0.03751521839970543, 0.03401519250004523, 0.05578807397415081, 0.06049401036673977, 0.013697492165280687, 0.03733958891262451, 0.030274293235232754, 0.04550608235501474, 0.013472872313051937, 0.07228388901679747, 0.04979139434233789, 0.055456170211395914, 0.019249973908787774, 0.0614368079620744, 0.036869007913816365, 0.019156993817417853, 0.0033545738129290726, 0.015290090326039542, 0.07130813048852068, 0.0701192922649845, 0.025469765157228517, 0.023222032543872635, 0.04962477787968613, 0.06823000453052021, 0.03514709889948849, 0.05198288844117234, 0.03685048773824688, 0.05072068580756745, 0.02424158831878055, 0.02049132745953337, 0.04477310092038205, 0.026564066215688666, 0.08419962825193521, 0.021681017955885302, 0.018673069482188553, 0.05608214448476511, 0.024342715755225192, 0.007836066792914344, 0.013340808331005037, 0.018005326179967775, 0.027755932401745554, 0.03561367325845265, 0.037970289948486516, 0.0569805319631292, 0.027707010026901003, 0.052570336152829474, 0.04600488220251376, 0.03836402466761009, 0.03367298485470876, 0.06917322730465282, 0.04669669407209562, 0.032571043984423724, 0.03331446719746436, 0.023728569879406886, 0.025378527915886333, 0.07139871272468759, 0.04682199541299094, 0.04045405042087359, 0.03241117675638488, 0.06077871928291936, 0.0499776532993682, 0.009372308174328459, 0.019502202612197688, 0.037015204302846424, 0.01064716275000284, 0.06722767041215012, 0.017959326430554354, 0.0381104227515959, 0.03969128348774487, 0.024319181534191294, 0.02616169002477921, 0.06321928771813551, 0.06593609979796795, 0.012529534625730688, 0.017709823084935065, 0.01828287983493459, 0.03688574693496189, 0.07634209423896766, 0.0770532306764395, 0.047190410926217036, 0.028407350370299914, 0.0930338784030849, 0.08165351971383057, 0.08008051137890547, 0.038099544303071116, 0.018668233552166534, 0.046817559763909354, 0.013393102450326327, 0.03591191894825428, 0.01964091240698772, 0.013583018519585172, 0.019920281690335082, 0.010183943856147029, 0.0786685117430264, 0.039087537255498676, 0.02657590801977823, 0.0430791158108942, 0.08396128297693307, 0.030624594599489244, 0.09983938983491353, 0.05984545565180241, 0.013515378701530639, 0.009729166293606884, 0.03742899903426728, 0.12825682383751677, 0.17923158653561147, 0.19849546494022494, 0.2091697663549454, 0.22628129009277592, 0.12818619819177737, 0.18878988170575714, 0.17290956851455475, 0.26162693216916055, 0.09689640178675614, 0.11834765273717143, 0.12198398866119886, 0.21570939931177327, 0.12199972410716357, 0.22368092720787372, 0.1496929368905483, 0.14629196615949755, 0.11605532614574318, 0.26141251948091293, 0.1646442458994927, 0.11758879668289617, 0.11817922830701837, 0.12240887634576329, 0.0953893919265078, 0.19647029619063103, 0.16130859182486612, 0.13720365060913947, 0.08330800916038214, 0.1556543573256462, 0.13205652035051776, 0.21592692231699345, 0.14401780351275398, 0.1776863259053038, 0.10624052941678994, 0.14395708338387553, 0.14915753336202714, 0.2493186877860177, 0.13853918700929613, 0.15856872432895247, 0.12217772463637015, 0.08961021614771697, 0.16760929727986937, 0.1984508939447903, 0.22536932370595394, 0.15635253921631845, 0.10585236032643627, 0.1283547605177568, 0.1649595217238511, 0.14853496434948138, 0.14867537294424352, 0.12301079162787046, 0.12551225256174803, 0.1955464707627412, 0.1353351774835779, 0.20917076226924697, 0.16678011435414516, 0.14745718589232815, 0.10174256674344502, 0.13702343608583176, 0.19839316155881653, 0.14301595969065545, 0.09798001783389239, 0.19471007128877027, 0.08842142388945626, 0.1721960342218799, 0.21646928192386705, 0.20495433690807513, 0.09444790817196332, 0.0724215779994284, 0.1318060862080705, 0.15233548057656135, 0.13049155593879763, 0.15835225852506776, 0.16032444463381845, 0.12383449702493607, 0.13245701579557312, 0.13546732765051628, 0.13361265942935022, 0.19260941223511774, 0.16950685110303665, 0.19748441274127654, 0.12088472143776956, 0.20987433741890618, 0.155094530914099, 0.16590452182196802, 0.14093178684913343, 0.12180093961257128, 0.16641694271276075, 0.21362493535684002, 0.09452647814947752, 0.12098058201973477, 0.2041311141464018, 0.10975714878089006, 0.1582614004972481, 0.27306952784138344, 0.14198411586544207, 0.1573745311508256, 0.26113351025889, 0.14076864076477869, 0.12561036544221063, 0.08734646463586439, 0.0875962935688515, 0.15648937784135342, 0.12232886612295144, 0.19057632213638676, 0.05875966391496121, 0.07192234914269179, 0.12978543737722983, 0.128952132898473, 0.12434655785440438, 0.14886049043026664, 0.07798958930277056, 0.11420697048907319, 0.1295085578796364, 0.09313837279595676, 0.161936370235297, 0.08140274083181735, 0.1088925572713056, 0.11624821942419776, 0.25605598674906843, 0.1409699686712796, 0.11704046925109242, 0.10292768944054843, 0.11204337731244103, 0.07338065879359361, 0.07636035011420328, 0.09657890430741733, 0.22537689265464583, 0.2531126922657413, 0.14576069950576753, 0.08795681454601788, 0.20181999541819098, 0.17686662714808218, 0.16308354093663155, 0.11917813035148768, 0.14220278800254868, 0.1719706664763151, 0.1086334586744347, 0.16130885229476039, 0.1757570866855883, 0.1451484113931656, 0.12016567897291915, 0.2568929684498618, 0.1805116734918087, 0.16855126366980616, 0.08330249332732732, 0.08893294845737758, 0.10822645148202296, 0.1379186864341459, 0.10035812329020231, 0.19478324800729754, 0.12946631579149154, 0.11363112517902929, 0.10871278707899394, 0.13480429387381002, 0.14943583778315975, 0.19014142934353123, 0.12123654731699537, 0.18243433967713388, 0.11986192511094194, 0.11489913858953985, 0.15103539872554042, 0.06356554796859142, 0.10356312106934287, 0.08745460560725582, 0.11006695473746908, 0.16008969997206043, 0.07987008234786411, 0.12919332802055344, 0.1378690745801695, 0.12923782240719567, 0.25000413729538845, 0.16294362263814097, 0.1280517957263416, 0.1459384165824421, 0.0977553931936141, 0.2971446375933386], [0.03457944306935515, 0.033326054277319106, 0.023081277294324774, 0.05276355118821225, 0.03780439360848358, 0.02378992969170213, 0.024735835688789527, 0.06531825754791498, 0.06620258348242891, 0.016463511030099565, 0.02038417857200388, 0.008949232287704945, 0.018392204412169034, 0.038833008373096105, 0.07078332195599234, 0.025767815494609457, 0.09718473429881758, 0.04750744492236165, 0.04448111033848217, 0.025255568888819507, 0.029073050132982677, 0.02933451402631979, 0.03523779221840444, 0.01637576331925248, 0.013404972025103146, 0.015680230177578428, 0.017687767413595033, 0.08223056778191559, 0.06746339566645122, 0.03108645368727946, 0.01830260085332538, 0.01693339871933624, 0.014562764535507849, 0.018727835192675554, 0.027794286593674656, 0.041786821243623574, 0.06702040532423605, 0.02789317896860021, 0.07402148368137498, 0.035307069549397115, 0.019031223247668917, 0.040681785378124447, 0.07263179252585096, 0.02973763906817523, 0.05658239606888064, 0.03156131903280414, 0.01587655074188426, 0.03555022968700336, 0.03517089359041664, 0.061659069221106276, 0.07309165978503805, 0.07096990266995085, 0.035270902538491834, 0.06687183023220108, 0.02166840431821202, 0.08249265412169118, 0.014841269097110678, 0.058903401161754326, 0.02632705584889458, 0.04463152787197502, 0.05168591445732502, 0.014930596864301593, 0.03155869135122386, 0.015036175271586306, 0.04882433857288092, 0.02769378543410811, 0.06857390139972971, 0.11065251404239286, 0.012104418072398874, 0.0058358758612866365, 0.04003466324760549, 0.07370949437421176, 0.062062728609288895, 0.029298076969421202, 0.010081552374627321, 0.08500555274827827, 0.05700461393702896, 0.02801641378731978, 0.033897272416300354, 0.07991017938982095, 0.04210271759920063, 0.022900440324578556, 0.018677438098576762, 0.0708177499473095, 0.05899095735062034, 0.023305312046901356, 0.03921931586979378, 0.028007320323658567, 0.05750270515319802, 0.04230103478015911, 0.04202867520131892, 0.026172225648957877, 0.009506910780234443, 0.008960992694952557, 0.025652898475527767, 0.050798229227263125, 0.0451051579007218, 0.030826665611276706, 0.006338362506921253, 0.03532052971422672, 0.005866465273298204, 0.019637700583365177, 0.025939580068112384, 0.06821752495823369, 0.0435778237278423, 0.027021323030273763, 0.07243283949191533, 0.03365920293295095, 0.03741470766403983, 0.0712237152601442, 0.022111911769776095, 0.04435237692368608, 0.021546253513905312, 0.05758992043293773, 0.049944248035429954, 0.030156750449790593, 0.11474621977897421, 0.0027932566421617184, 0.031733914811704914, 0.059684481426712975, 0.08450765688452991, 0.055553352295030514, 0.0622210483397207, 0.025262180227606047, 0.044339770946892045, 0.10474982956844954, 0.017744873522690708, 0.0060348202767331275, 0.03162727920308469, 0.04900319329012306, 0.06875350305269803, 0.0360721385767383, 0.024684898502704118, 0.09018924838352589, 0.06822068124048172, 0.02437350291368221, 0.04696823393685683, 0.040252190083265305, 0.022783046926281626, 0.005412441828558523, 0.0372793629104572, 0.010358441448319825, 0.01846355975665633, 0.059832887979404586, 0.05188201381374271, 0.024537420831620697, 0.02488746555642255, 0.008687272352436859, 0.017876485512862285, 0.1249861723232654, 0.06667381948641231, 0.053501420263801856, 0.07974835097669594, 0.07690390481823876, 0.05157864299572764, 0.05489147531108991, 0.0266740151545814, 0.03869700861433822, 0.0312736127976208, 0.021014590409674475, 0.06159153090970171, 0.08166390786608381, 0.050696347194213065, 0.04318380172574713, 0.049513825365612586, 0.03724720636983553, 0.014831288886677115, 0.026203054942250736, 0.018077353766608625, 0.027622677152976397, 0.07466001796626276, 0.04882908448757184, 0.016684347365592277, 0.06722452179078134, 0.02942582596123459, 0.05592530330402717, 0.018803011400685198, 0.0365048595103285, 0.02656179093455355, 0.04877068943554356, 0.011644729886264091, 0.02203153190954078, 0.03375127137969098, 0.04685707840948336, 0.03658580436040798, 0.011835683047050431, 0.07195087059611274, 0.015907989075076918, 0.022092818943483215, 0.0277440925128758, 0.03879201500826786, 0.05531881447701205, 0.05766722253493725, 0.018263176053522095, 0.07609099360002626, 0.052951204425264756, 0.005295578946149158, 0.05070003207712885, 0.00822449395913751, 0.024654932973545887, 0.0613297280224581, 0.03137641222096019, 0.07187249214057961, 0.06648891650500798, 0.030372603383335858, 0.04853543532531589, 0.057690274120578845, 0.042161514847389156, 0.053015065514632774, 0.0350624653360536, 0.03276194543427518, 0.029846743395131443, 0.02753279397204038, 0.03560062678110215, 0.009546721496829584, 0.010851484145067874, 0.03426996270014394, 0.013126969251090722, 0.074636077718629, 0.02381732882631402, 0.05615147927235212, 0.014570258790627124, 0.015040881924271105, 0.02119283225657719, 0.010388707666988335, 0.034136575301207846, 0.03906770323913905, 0.01524941105726025, 0.02375239904429163, 0.0505977401870393, 0.011099803884844146, 0.011966670675563717, 0.02107363280599877, 0.04347106937559382, 0.05883940217655994, 0.01087721799605436, 0.004427789498285781, 0.02798186322193473, 0.034336401675377166, 0.022352160773270076, 0.042145243139877435, 0.05411474259510156, 0.03334647818138042, 0.013726594887914197, 0.029927106018388466, 0.03265474675103061, 0.04071325627005389, 0.030403744857457858, 0.020273339055899172, 0.024247209488924955, 0.010505637582091075, 0.030872722817284447, 0.01747124989877545, 0.010171201898746434, 0.05713350823028915, 0.056042415165011926, 0.03356528821431341, 0.014732382147602979, 0.008546014357688687, 0.030940602037815318, 0.027902373938911387, 0.07092576834463304, 0.04755288542759034, 0.051502685378035234, 0.03649714883537062, 0.03361259797407735, 0.06630029033629165, 0.03845908851813405, 0.01856967634070785, 0.0498941267329839, 0.02323366175856321, 0.06143123850286488, 0.0693349791089854, 0.03414025252324439, 0.08909943468508222, 0.08677260349354438, 0.07430003325064337, 0.017684934803495006, 0.008217649921143969, 0.03516862980060039, 0.04496464205365028, 0.016899842153032942, 0.05102250912797548, 0.04669251889290829, 0.055971165157614224, 0.06565866871706902, 0.09667358511397917, 0.038916534939480406, 0.02121053080284788, 0.03826064110222844, 0.05192067827128115, 0.05676243822240541, 0.029998752476286986, 0.013281108056675765, 0.015113438111579707, 0.0822213517441865, 0.09130218261552435, 0.029075400107690406, 0.04056584563166384, 0.07899444385041153, 0.024933601286442533, 0.020636242566510074, 0.06992560991596791, 0.015481258949054586, 0.07289751012238764, 0.047071835837296905, 0.09876777072467151, 0.014717627294181336, 0.013549362361851721, 0.13946065288637916, 0.024715624374127197, 0.02674538773604699, 0.016737473647921317, 0.08624390323436068, 0.06836139627041356, 0.017202831842305682, 0.009254086443463401, 0.022410525181781382, 0.05573953847370802, 0.024458540588497155, 0.07976666813896549, 0.03841288958586032, 0.08687199574084052, 0.028941235129511165, 0.024225467913633874, 0.11603475668497625, 0.05052469753389878, 0.04129992640246788, 0.033394282067855524, 0.03113097871743864, 0.04553843041761749, 0.06203333381563426, 0.04340480660058318, 0.05502672430368201, 0.032587453587761814, 0.05468732054014841, 0.04593051804770385, 0.013971402114557644, 0.06556964163938839, 0.08043142561350139, 0.049408327397559924, 0.045509004980445876, 0.021637500331346548, 0.03930799437746887, 0.005294304367365135, 0.04395834343027204, 0.04431110393676547, 0.08302553722094144, 0.04905745146736022, 0.030503897447018858, 0.03668451478945152, 0.015273662528113253, 0.10599587157729173, 0.12020078112160969, 0.08270168121183112, 0.14105069901674025, 0.1437822927630717, 0.3181185008537385, 0.14200905968825664, 0.14578855446269437, 0.09098769586172797, 0.3099818810099556, 0.10125267649850539, 0.08554418916783987, 0.14883890207256043, 0.10038490572403516, 0.23453813977539542, 0.1396270165400159, 0.1809490330877804, 0.1406074099002346, 0.19709406030033866, 0.09579943282709968, 0.14767555159426507, 0.1302825977965709, 0.13521818053578177, 0.10109556718699395, 0.09982900168266028, 0.09199083437241855, 0.28069228654907596, 0.18771366606796944, 0.13485249612600575, 0.17246955825436502, 0.142621960671198, 0.09897037033712673, 0.24307205281671018, 0.13454828261127397, 0.11654434305044914, 0.08075348131598965, 0.1619364928093649, 0.10426261297036564, 0.17534529910452906, 0.10414880294833453, 0.1492980338873402, 0.2692028369394041, 0.2885661382348307, 0.1355045748453948, 0.12465934389300885, 0.1084791302620884, 0.08603587971940156, 0.17649064651660382, 0.1204980768623852, 0.11432630400503836, 0.15550676282615433, 0.15410856043379154, 0.14367231318066198, 0.10143174955080594, 0.1394849991606128, 0.12113448142284348, 0.14791274773738078, 0.19556580682195004, 0.10417708691449896, 0.09288122006241353, 0.14574563821717618, 0.22187761752115143, 0.14664075066966398, 0.08542470243428985, 0.11842355672870913, 0.1706626632761571, 0.13519977910384057, 0.17165606480933007, 0.16500461365907423, 0.08879237132327211, 0.10591026891263262, 0.14200872260956995, 0.09736828896547518, 0.12925196439027786, 0.10324294228226909, 0.1664718252516562, 0.1502386979278057, 0.08276051676441586, 0.1357874604723146, 0.21441494054611654, 0.14075086752493537, 0.0787324034759114, 0.07782288857044713, 0.17633381299674514, 0.11172340536910681, 0.20791229431427297, 0.12169580170584303, 0.15869163547552403, 0.17312995668861175, 0.23155156132434648, 0.17311633564531806, 0.11095411519730285, 0.18195175025011265, 0.19907911668621725, 0.2255062082962644, 0.19302080145045636, 0.1812139309702381, 0.1162260871440653, 0.19620202752130647, 0.21692862824326564, 0.14814605215384116, 0.17445030922610916, 0.1320048553809043, 0.13219637736197443, 0.11281035389871368, 0.11560736389289941, 0.25624257512390614, 0.16143953157288415, 0.20383212535131365, 0.13608827255666256, 0.1373419448012306, 0.11696113318565393, 0.11196420978634589, 0.1386392840574826, 0.19413003547778054, 0.179737817435976, 0.1934397289709699, 0.12375090917151783, 0.09041139855980874, 0.18313598428522387, 0.2103103946654066, 0.12125789818744506, 0.11411525444277834, 0.24115032125865263, 0.10268173691245819, 0.17881903286662795, 0.152707967847105, 0.1826613315290982, 0.1599217275337827, 0.1859607649666648, 0.15514008250207673, 0.15400869321198235, 0.06500708795483075, 0.2854644933775548, 0.08922592346226016, 0.2264127967458579, 0.13755661795937246, 0.13062300130484567, 0.1482837947626268, 0.08405023344582127, 0.16713916444249693, 0.10434218652306065, 0.09254126854601408, 0.10528346343386559, 0.1493961697504405, 0.09833006638913386, 0.13636660762131214, 0.11358427890245953, 0.1074865484429944, 0.20669721757933018, 0.20846927087874184, 0.238389631492957, 0.1596865385410286, 0.16725093667064944, 0.12622145845765068, 0.0902606247954311, 0.11628881442330538, 0.19365915187424232, 0.11991218047877474, 0.08246477618212662, 0.20022858565132465, 0.2337923072158329, 0.14305685346405353, 0.2674863096927443, 0.155528933410683, 0.19531302845045445, 0.0917258905246854, 0.12542801353359415, 0.18169494225613533, 0.1641938781305667, 0.15456007733460397, 0.2007154345272049, 0.1407637071585463, 0.11670265512000169, 0.13244932427281333, 0.15731975586423952], [0.02376750438293863, 0.03675695223313186, 0.03963484579036313, 0.09580533170411665, 0.05772890410416069, 0.04441330006586448, 0.005681249632259772, 0.05056776316656221, 0.012891534152590941, 0.06300726522421164, 0.022703452306168697, 0.01078361162780634, 0.027827364355025273, 0.024659276692076557, 0.022939397810748028, 0.012746357618110075, 0.017220375255771705, 0.034794135379695126, 0.05502091735721596, 0.013127792795609324, 0.04266127996567277, 0.17472193336054204, 0.06485420744866133, 0.03705294945487573, 0.043615817858446995, 0.01986343796635347, 0.08061452062740442, 0.09539188171226172, 0.030122255425780054, 0.03639321751712311, 0.0659285385101553, 0.02680765919297213, 0.0730639810283338, 0.035441314966808406, 0.061868272511468786, 0.01491022562878507, 0.021502617145738295, 0.045713914347992796, 0.04016462623352005, 0.08474047100471874, 0.09997401446584733, 0.03742012773610411, 0.048844245367593346, 0.00795534045826043, 0.03461677070346571, 0.03122977533137366, 0.0699272723267636, 0.06966376106344885, 0.02683400112624851, 0.019275128405781525, 0.017168547492474318, 0.07913362670449481, 0.03987454321055163, 0.03231389891175974, 0.02236424772549541, 0.02157130075858966, 0.014058187427449853, 0.08143978884383556, 0.01639495956741514, 0.021658025742057833, 0.05388339553328772, 0.010489861916510329, 0.023375705951043678, 0.10142778887623742, 0.07655577148280798, 0.07010015538863598, 0.059063731872987364, 0.02403239843495671, 0.004332855882708945, 0.022207036907334003, 0.04101840824249291, 0.12577451510174623, 0.08804935796727097, 0.03298343677494315, 0.07258169803648226, 0.03586371286561893, 0.02733758519283466, 0.025265478236120076, 0.06475162061472094, 0.027491519069899956, 0.049545503101281585, 0.014893739416654554, 0.031701583986080466, 0.03857178005179571, 0.09903195614535963, 0.013278855758178379, 0.04332691078044234, 0.04766441633804672, 0.0355246078763758, 0.041466596491274335, 0.0895068632258523, 0.04067489441724555, 0.042040269942052906, 0.037839093561013865, 0.03457855440736298, 0.06927530085968395, 0.023531798280835636, 0.024402742574532187, 0.008723632800543021, 0.033740205239624746, 0.009768882206821395, 0.03254462544235491, 0.041668759433612715, 0.07007647561089647, 0.05823012861994006, 0.028068130467868144, 0.030316677049643574, 0.08036878260393297, 0.07043285971327175, 0.009254077824974253, 0.11326233811315992, 0.042261366747439875, 0.026490092765720143, 0.036593721879105416, 0.10658552179173117, 0.03541292757877419, 0.12017583729879511, 0.022776328335185687, 0.05337912198756972, 0.039711780170159, 0.015110688813541447, 0.029241131738789623, 0.05731643087440922, 0.10095250792801382, 0.04550851851461395, 0.09528547209957916, 0.044747670631735556, 0.010364570151714068, 0.0804389256142801, 0.024594094101039153, 0.13542792008769128, 0.06874706791413408, 0.07293525527441695, 0.025424657900246884, 0.01878677225191026, 0.05120410643998654, 0.09191431751054141, 0.021085832756192937, 0.08570399510884479, 0.04913943053613748, 0.019242071711848822, 0.05596260795550001, 0.06658994051958285, 0.03623023614167206, 0.07177720612455761, 0.03264304858842685, 0.024074720962333585, 0.039141569436798175, 0.04285729888285841, 0.027964909696170402, 0.08762054025165497, 0.01987112757389344, 0.07190396303250905, 0.018116684720641183, 0.017800797941163182, 0.02977451087997085, 0.03179712855677692, 0.07591881533904422, 0.06209393903132408, 0.02529266478133298, 0.019015533766979655, 0.08137523827533569, 0.05413292569198436, 0.03841280148574903, 0.03756024521745501, 0.10048198438579999, 0.03894856124515495, 0.05187564762309194, 0.04019248885132613, 0.022075664319638765, 0.040859556080953735, 0.028289156410122113, 0.07465791122447099, 0.013835692511601074, 0.024366328500271327, 0.03164781802033465, 0.05347729232462664, 0.06156127043669263, 0.02445803114002751, 0.0639299874854905, 0.07444320742281214, 0.04602951959015862, 0.016296969261020422, 0.04471944029172582, 0.07214046969649292, 0.044269011235765876, 0.07084137609889431, 0.019516223936431834, 0.04690714991621433, 0.016498691702802337, 0.09480861301023154, 0.06798640389235751, 0.050224984785722154, 0.017619451522947322, 0.07735238034999178, 0.014776430288029295, 0.06048357241877145, 0.061248001762695854, 0.04163698210651356, 0.07615097062361818, 0.004986915418187217, 0.0488405145194021, 0.028503603572326324, 0.07552879997679303, 0.027932718681592136, 0.0427787633793008, 0.023153890938227697, 0.030026751074699626, 0.02954769905866875, 0.009601023724122394, 0.0603250649967982, 0.010809456561541846, 0.034366003312771363, 0.011955124772934905, 0.037835799382939454, 0.05661876609308585, 0.06671889609987698, 0.07933988055634884, 0.027611162851474462, 0.0668342306368774, 0.06062154485393436, 0.02656323692551063, 0.0299476582421771, 0.035605924279098554, 0.03546586425434198, 0.05918188178310952, 0.04667655362056629, 0.0666216642205273, 0.06801313270003566, 0.014727904363685559, 0.03375459237084274, 0.020198894461857218, 0.01717291802408234, 0.09090010902934498, 0.0321038490942409, 0.05275458029861893, 0.033827684819698334, 0.08876018796957309, 0.03007621737197042, 0.055383196506168575, 0.031154290772974495, 0.08197922199483841, 0.029007541954577453, 0.04877161257149232, 0.046184430229327375, 0.057164412217154625, 0.015954791301591022, 0.21110997595373662, 0.06350076374327464, 0.060960776247685, 0.06714778276340616, 0.04518866148446837, 0.016043921801141434, 0.023115506102781624, 0.03938762155631858, 0.05094401192881408, 0.03595002799204761, 0.03071465972630728, 0.011449185943591499, 0.0673538067888829, 0.0203624369967128, 0.017051021944010453, 0.0594998044412463, 0.06569790007967143, 0.042755451323764945, 0.05844490136951209, 0.07460505881857488, 0.05407290270311698, 0.05729165942137761, 0.035355325427747546, 0.06872657506215958, 0.03945546630289286, 0.0357300152010735, 0.040222404584769285, 0.029084187136181903, 0.012381590598623359, 0.03791708131170562, 0.04926067544147373, 0.037309680840060595, 0.051518665972135724, 0.07907777889481477, 0.017385850247416287, 0.039496432854643757, 0.019766462726458427, 0.08931751693448714, 0.0035393973127112637, 0.05409024693372269, 0.02756260436839394, 0.06141551837865865, 0.05930826713841769, 0.03760334915451465, 0.027024034981525717, 0.030902431706988046, 0.10411431366998343, 0.058583360270506916, 0.021843874842048656, 0.04307612423754988, 0.03449261466401719, 0.06402778626990414, 0.06026202745194878, 0.060614473862393256, 0.03129206977093653, 0.02795618970037228, 0.06312620420489581, 0.08837617107576902, 0.07806904794227693, 0.002458596638696749, 0.03693366190418601, 0.09273550247833615, 0.058338288743529594, 0.007516575569752605, 0.020470269617714712, 0.02464810904536036, 0.03899608550953769, 0.038923805113881826, 0.06023535610086495, 0.03906487254425883, 0.005822648395664029, 0.011090678820056061, 0.05965822376310826, 0.05564739341817557, 0.024141110141851732, 0.017898315188264655, 0.04931768004391943, 0.02998193684634903, 0.025238745598002307, 0.06449764714606347, 0.023566517385564024, 0.02500572846451354, 0.04433596732034799, 0.02809450687510112, 0.05234870308589551, 0.07462525289625892, 0.04278838161319014, 0.04296846590155075, 0.05315100398635673, 0.022347355486765023, 0.08019680352581125, 0.029356207721115603, 0.026051273772252664, 0.06726386040569314, 0.09457670287379334, 0.026474964444435416, 0.031063865584832047, 0.0194500703289504, 0.017438700738092585, 0.09970024528522646, 0.024751431323708068, 0.041477517074634956, 0.12945526880362343, 0.01767792892942746, 0.0244651346903054, 0.24302844709206015, 0.14064861010880242, 0.12839639739644143, 0.1733288790790304, 0.23212202103628268, 0.08733561683085658, 0.1191486053228859, 0.15497132865411622, 0.13362214359785282, 0.11763684571750703, 0.14089887571190635, 0.13448250630209524, 0.1710741597438051, 0.08094938531998666, 0.26280373515140626, 0.16983190220930885, 0.16512173318093823, 0.16127756526393278, 0.173376162025717, 0.09369452964634666, 0.18845796645168336, 0.2147909211775949, 0.1730923111280126, 0.1240031666032249, 0.13626729198280843, 0.16181643150987166, 0.12157789311341702, 0.13037658146312162, 0.11416860480582523, 0.18189049385968717, 0.1818152793472813, 0.13824891629478625, 0.11414487906281026, 0.1358514441357505, 0.14913951497404807, 0.08877855109711809, 0.1877556630079785, 0.11300791265262712, 0.12005314065684235, 0.19701648623712603, 0.1551225390886107, 0.1334257186540673, 0.19562222153669406, 0.15287731924364645, 0.11170717962687055, 0.12034005590624387, 0.12077766065035137, 0.18253773090339478, 0.11758530332196145, 0.13138504428488593, 0.22709654554003672, 0.13294006487534893, 0.13361918649846508, 0.15692879055296222, 0.04463452327575895, 0.25103817213206525, 0.10170338900699731, 0.2333202438368913, 0.0931882068154312, 0.07984650216155476, 0.10392313642847924, 0.1292924138326799, 0.09146508355174335, 0.2121485307091667, 0.18226080544052586, 0.20650466904044154, 0.11246069604831357, 0.12434651955000817, 0.21110069096809436, 0.21798792865968522, 0.12077253552213793, 0.2031339281388829, 0.1708374692187194, 0.09770843200385572, 0.2335213572387734, 0.17986576944108934, 0.1465629927453495, 0.13218428849452926, 0.21046889825694023, 0.14717169556646578, 0.164326120228056, 0.18340846643813197, 0.14585682821850623, 0.10957872690332514, 0.16940113096948595, 0.12838797042927436, 0.15368768704995034, 0.24170449394131863, 0.13186426292504036, 0.14254878395267073, 0.21666860268000634, 0.23838224640536695, 0.11042269532598796, 0.15909475094128042, 0.21391660035137208, 0.20718199801781487, 0.07617890218933744, 0.2049384176010086, 0.12855410425653382, 0.10833037130895162, 0.1409348205573136, 0.10681121129422419, 0.08549412532198815, 0.12528601913682877, 0.25230946439889174, 0.13678072410966122, 0.0943642360488734, 0.21727123808476234, 0.17792051898375635, 0.10947703639225614, 0.15602546563792616, 0.12951905328419902, 0.1506720432230542, 0.13047218923607182, 0.17424645322945811, 0.09680233385053374, 0.27100884325561986, 0.29397977516055107, 0.12111153708951128, 0.10144904015525695, 0.15215237024089984, 0.17382970139864953, 0.18289645923481834, 0.18583656679238045, 0.13184063677345553, 0.1871858161663817, 0.15450792206871897, 0.154813974194469, 0.16739011952473273, 0.11924567632377149, 0.2313548759106667, 0.22935808305778813, 0.1638282396860661, 0.29949514856261594, 0.11618124801785716, 0.10103587361593401, 0.14242752755601562, 0.06810757601934095, 0.11900447354081178, 0.19565303359300862, 0.13214819043153717, 0.1261507638639981, 0.12595012543662903, 0.1814304120958813, 0.20785595620832137, 0.12684175218906135, 0.14230628648111898, 0.18252294540645617, 0.13213734262652937, 0.12511049307161762, 0.1999321402681451, 0.10535709214426818, 0.11257519554947654, 0.15158048560542448, 0.12965474277734756, 0.10418277894777637, 0.14055890121286915, 0.22328916516515518, 0.21032165615789353, 0.15832000622345557, 0.10819121909838532, 0.21036411275065717, 0.08604469739141003, 0.12802384883886384, 0.13182818018380674, 0.19835085818363776, 0.12391903482738043, 0.1097814261072105, 0.18576438598815473, 0.09072754006352156, 0.2579321207538728, 0.127457280853583, 0.19815283977696974, 0.1517703068713027, 0.1043936676315723, 0.14128077054216018], [0.0981208171334959, 0.07040100577738016, 0.01309878774918616, 0.05006942680225738, 0.08207376490557387, 0.01726267480051085, 0.031781889152743166, 0.05929659195845166, 0.030981135749888998, 0.030704242845756874, 0.051594604437630025, 0.026173644826837608, 0.015855200829044465, 0.025845272729413647, 0.08435661498937877, 0.07794055201473736, 0.012261325328220284, 0.058679217022032513, 0.0803460757578573, 0.02959986581587263, 0.06728678175638761, 0.026006555304892605, 0.062260536341777736, 0.06551528770116068, 0.031159647642785025, 0.014314776128758828, 0.0419116591013247, 0.02351206577112598, 0.024915226667578665, 0.023657850387896744, 0.013884220351164621, 0.0804597249014243, 0.036152757839449955, 0.10271089421885629, 0.11508106914979797, 0.025334556384252447, 0.02282074802825528, 0.036135670248298876, 0.03630305662931454, 0.01912404246057474, 0.05387199997541405, 0.03668002551421523, 0.05576925502429086, 0.10335523545021012, 0.03032317730568109, 0.034096447615734035, 0.017528407718806018, 0.019956801101685535, 0.07881950767290208, 0.03249621634641963, 0.03727549033599996, 0.014359894877059326, 0.0062290728824483535, 0.03015516273256752, 0.03742213488646573, 0.032770058305393306, 0.027303542160699447, 0.02892969401493188, 0.06568164369391818, 0.04632074791457384, 0.052900964379190445, 0.05144908986685257, 0.0933814065290555, 0.01131859668079884, 0.03827698558809296, 0.04796482239579482, 0.009370091307397571, 0.044494712229577765, 0.030072191579928322, 0.013403459001452693, 0.0524008889952975, 0.02979207919129441, 0.13508353292221023, 0.0686807630042876, 0.031035583533887422, 0.06415555824435527, 0.05562251471283455, 0.06319032193371846, 0.014650722920534112, 0.016221013558547825, 0.04259300237942127, 0.02586893143973524, 0.04802460406696604, 0.04075299708112594, 0.07247377923058887, 0.05179026329349126, 0.014570503938762892, 0.06633555336344628, 0.045757477937807, 0.08341462561680425, 0.08983009104286471, 0.013224290188161597, 0.0565176731305978, 0.019753234303225915, 0.05022449448945061, 0.0333556559147133, 0.06988863851274214, 0.03349087043334881, 0.12442257675913074, 0.006845697052701707, 0.021520754277345636, 0.04859455433043261, 0.025237305352704662, 0.1194694123020576, 0.05075123739398776, 0.009191679005931703, 0.024321069940924648, 0.033427311948710875, 0.08426999342778037, 0.03651997825551418, 0.049145957605252345, 0.05011096791995149, 0.06437848216944164, 0.07244466022858698, 0.012497669198520243, 0.021852420552844004, 0.04130290265405371, 0.05548918094005316, 0.04027057619344804, 0.0410929485975254, 0.01919569083369307, 0.05651104263961316, 0.07077648845170775, 0.03744565761618076, 0.06819662607965932, 0.03624594860499905, 0.01955814618286827, 0.03710712719288084, 0.03933200740345544, 0.07223867450750644, 0.03485085269916923, 0.03338833722556311, 0.05758878662280979, 0.022321354462614944, 0.06768075779320733, 0.021694610270881848, 0.004785187709550824, 0.0261917015192129, 0.03496720996354857, 0.018794358437580448, 0.01893866641987716, 0.054605728345772916, 0.013014386884958274, 0.05098241974689788, 0.04752390049097519, 0.04419103880683261, 0.06475235605912824, 0.03895451374832661, 0.05244107030692601, 0.09987443835744936, 0.08744671490163573, 0.03415226478189711, 0.021006954428289207, 0.043373672787340424, 0.003643670258292508, 0.05186276202420554, 0.030079519210924065, 0.027156696512153553, 0.040082176020669366, 0.06627735366383869, 0.034174676684121934, 0.023243741560426932, 0.01942779823777176, 0.10133366731386032, 0.02265627086613207, 0.02684434714366592, 0.032931970988189986, 0.04552900370570921, 0.02386354308034624, 0.0803068443952549, 0.07385741063063184, 0.09799088096065868, 0.0751855772649569, 0.06166578398176259, 0.046097494571680026, 0.03581401674197086, 0.07743597586428927, 0.006793461347584643, 0.020009440918182655, 0.04563496132651645, 0.06581377853909809, 0.02683705781706639, 0.021927324799640525, 0.03108321313535975, 0.027990862839825215, 0.06486987394671287, 0.06759039772253844, 0.030600003177119844, 0.04749254068179477, 0.030996419203978394, 0.06070089241069171, 0.04673733120603908, 0.015279713665105164, 0.07787831503176883, 0.007120788692601867, 0.05278146232388193, 0.039609649158533544, 0.018524312444271582, 0.03850158341529389, 0.035233429347675656, 0.02398413106528742, 0.020324103872201616, 0.05970114766950569, 0.03507574930066063, 0.04696079522311207, 0.03916872725371392, 0.03685603421481867, 0.006441071914929536, 0.05444171658206371, 0.02601553194014536, 0.031489494459463224, 0.036874519916431564, 0.027899177437047326, 0.04152214169622429, 0.04493690967079132, 0.024869286289979375, 0.126365122926091, 0.04864470244595601, 0.10899698271626428, 0.04391525098453126, 0.10708868834039859, 0.009138680085720075, 0.022977382365253665, 0.019002079347809477, 0.05245163082896222, 0.05263812344280943, 0.033713361518757964, 0.03996425976736411, 0.022608857684498353, 0.025279482323375922, 0.06754712907657509, 0.07875097344719595, 0.02634182985451433, 0.02524308548609336, 0.039873960983729174, 0.018006130572288268, 0.015113859459938062, 0.008228790754782818, 0.02114001240941786, 0.03565215002444964, 0.04373816209995458, 0.019192750971283645, 0.034802045237513325, 0.020103455228250355, 0.09814469609409572, 0.03813740819872868, 0.036971115942804084, 0.07471796485685533, 0.04411067618357559, 0.04873271062669735, 0.014733952627847753, 0.13427678105090896, 0.013360026604195517, 0.009979427108661303, 0.03840512145430811, 0.014359017706386024, 0.03074915858075744, 0.04777243090493064, 0.05128872085122332, 0.07798853976231429, 0.10546618306468572, 0.03863350758629461, 0.022641550486667023, 0.035034487805058884, 0.049495435424990235, 0.011560270607831978, 0.05640849027962935, 0.014845855090947402, 0.06269413444604124, 0.017172663299847516, 0.04419948109575818, 0.022925772937014702, 0.05691541832000498, 0.031630925781604265, 0.06728863568916436, 0.02491198994609858, 0.04889674537304429, 0.10230024810880424, 0.03890490572478983, 0.10652408920108311, 0.048385826014583154, 0.009877781605257863, 0.05647946066493469, 0.012444597499955808, 0.06993667222559452, 0.009511377072832998, 0.01877720764417562, 0.027560892161883177, 0.06283371566584514, 0.019729855214996685, 0.02053342207575277, 0.047759338462304686, 0.01792301769338308, 0.05273154403473582, 0.014439563233134969, 0.06723378379378589, 0.00870586434874924, 0.040681034611958655, 0.07054616411727282, 0.057453204381970636, 0.01468059460392162, 0.07348303112291521, 0.07308397592315752, 0.03797122457575414, 0.04155007326194356, 0.049830985766264706, 0.03205714454393714, 0.018284320080232237, 0.04978168800833726, 0.05981602638419117, 0.043138204172493956, 0.09055186078072557, 0.047350109614912546, 0.01317631871995306, 0.049274127945424094, 0.06824378645227802, 0.020623485287350994, 0.04016586346551776, 0.03195670467140454, 0.051075078081339605, 0.05094699201083953, 0.05892488226715115, 0.013067274722420882, 0.047735842545667005, 0.010454650600290587, 0.017943541188874555, 0.04793622050314181, 0.01961835111761766, 0.0507406309066761, 0.09104301507074027, 0.03556836298817108, 0.03014885591373088, 0.027277908858753024, 0.02959896183212198, 0.01436315266595733, 0.03989171507137437, 0.028217308854143468, 0.006830298206618717, 0.026680283669021823, 0.023596938737037203, 0.03933641240902005, 0.05379937484019226, 0.00984575913002294, 0.02515330572702712, 0.025415208205700885, 0.017279861983092084, 0.06652565808185647, 0.08323913019511008, 0.059325358560008395, 0.0277482810986018, 0.021227700748450814, 0.015228393435057615, 0.20326666053264372, 0.16779513488854134, 0.10747221493793112, 0.16807117168941807, 0.14904668043938377, 0.0945693024644448, 0.11576252734108318, 0.15924816770899683, 0.10465741638214358, 0.1271895254631677, 0.2232906513757283, 0.06520086223439825, 0.09413316860915193, 0.0939248922851778, 0.1652124839564485, 0.18530972812685276, 0.0829464616253972, 0.12138692271565238, 0.2203386234900644, 0.143402389761421, 0.11914517324898513, 0.12417511503782966, 0.20457801919791008, 0.2022258381569578, 0.12195758927132815, 0.22076985438264188, 0.12372604961837493, 0.09305869199095235, 0.14663213984139506, 0.17593270468135036, 0.07067963195544097, 0.20572089980686867, 0.0903076242895857, 0.1791030523036757, 0.2799113671625814, 0.06920148062730028, 0.18375663807795894, 0.11371154908932025, 0.14938504615377995, 0.20646896934317005, 0.29973977575859717, 0.20997029759230154, 0.1930005154422214, 0.23999614851369014, 0.20316444908178624, 0.1263939354929232, 0.09515198893965253, 0.10023329692382006, 0.2669919684769646, 0.15938601757009185, 0.12063827095252853, 0.14938978057715202, 0.07687131543793986, 0.12786595811766963, 0.1252769869602015, 0.15986125255303998, 0.07735172917525615, 0.11134062187686083, 0.1406069962127555, 0.12057994101797381, 0.18395742972291287, 0.15494446961149094, 0.26356191704830817, 0.1472929519631209, 0.144436776998543, 0.17412441542312024, 0.11890076821850193, 0.13920033620970865, 0.32120408850812143, 0.12077423623732983, 0.11883752766035258, 0.07430433866477783, 0.16367385764756512, 0.15608687524593648, 0.1105730937072827, 0.18804127590790873, 0.09916717066399514, 0.16425761664586683, 0.20174047549165067, 0.11847910576409872, 0.17247944078858823, 0.12166413929193251, 0.1230919816260857, 0.15933534851477993, 0.25497437785229377, 0.12631718880466877, 0.10461751852304706, 0.3215497167360398, 0.17913783269543804, 0.11290590038462994, 0.1872368223003803, 0.13443185256854182, 0.27725203082926814, 0.12287584524000845, 0.1446453520968076, 0.09727455810793946, 0.18161795041974516, 0.1386797488216431, 0.19735322784512274, 0.0998718872846615, 0.14617677717920274, 0.1374704637114079, 0.12248353161398443, 0.28312391090777617, 0.15543326435069885, 0.05928264149735051, 0.17450493129511035, 0.11608237671034953, 0.20019378993780385, 0.12982763350009918, 0.13410261862220305, 0.10418387445350809, 0.16046293800876987, 0.13019272036129428, 0.09265425885396619, 0.16954998185317363, 0.16759779063924668, 0.10518070806058184, 0.12195628692185688, 0.18631250657621892, 0.10124758967468817, 0.21319378107305498, 0.24549354949305136, 0.13197292483622028, 0.12773357046347472, 0.21995793907873093, 0.20702197757219115, 0.16776191731614454, 0.13054774082716436, 0.11782546422534412, 0.15619631856679916, 0.10077728829797238, 0.14650971899109502, 0.13664181704723066, 0.21989617707027545, 0.18391731735919753, 0.1569966352995365, 0.16890220854791904, 0.16542157999450163, 0.22906028935986184, 0.11176907953115241, 0.15931012890031263, 0.19298761452157653, 0.12647661170171154, 0.14635231856617237, 0.11489754512665734, 0.13921463141037574, 0.21643562002047417, 0.1589986222285417, 0.11163342834240007, 0.14982691034674644, 0.15517835625477377, 0.13995084190560927, 0.30727575202622726, 0.13828933509367128, 0.20013526082038882, 0.13678611736864815, 0.1456245503598644, 0.14042393184236943, 0.11347920228276523, 0.07214338849148444, 0.12577382562261435, 0.0967620223039581, 0.22948180625755943, 0.12033653190179218, 0.125484864918455, 0.07324807961741764, 0.0708399971406306, 0.1350035380211569, 0.13951921264731115, 0.2320704786407371, 0.23734277234442774, 0.29743872342571137, 0.1520151485719027, 0.08215526133895883, 0.14853246690284821], [0.05362453825411297, 0.07544896595420376, 0.09213728740090325, 0.03555425164860583, 0.04434241395023081, 0.08181056007742882, 0.008500653334082136, 0.05628038505693117, 0.10209661427765124, 0.014973522685918839, 0.039978662220340584, 0.03399956813682953, 0.005986602223973962, 0.021968373705843286, 0.03516350084194734, 0.029254074794270342, 0.04408091366771729, 0.05158575229166497, 0.0699185389244268, 0.044775211492613445, 0.08843360468745233, 0.06932841373547431, 0.020535433056554007, 0.049568026086255434, 0.05623053188525862, 0.04703489124714848, 0.0291805993014526, 0.09573816877579498, 0.06980778559321357, 0.06796865363515193, 0.02370492649084378, 0.06713930217008438, 0.06710197836641343, 0.05410606281891946, 0.017121088345565142, 0.09158187365579991, 0.07178276792288789, 0.06492369928427282, 0.04698203884125237, 0.05418218131507597, 0.022793890900849816, 0.0715779543163315, 0.07763168834630521, 0.03320512729847143, 0.04056335201547031, 0.02306807759938942, 0.036861063582041574, 0.07075688426172541, 0.06916632485245505, 0.012982179591011618, 0.06222548015836266, 0.06844414908799433, 0.07846288608327028, 0.020015041020909147, 0.011044358271324347, 0.013332854423131193, 0.044848935964006575, 0.07053688679250979, 0.04916751914988122, 0.08750381143463236, 0.0219171185932693, 0.01366550129117264, 0.031975592569177674, 0.013078589841062504, 0.041604829396331505, 0.01968100370328513, 0.04143131814236122, 0.020408750842175177, 0.009492540885994752, 0.007610603765163932, 0.07332638912503758, 0.023482946769124078, 0.03046995975197323, 0.031262613690247944, 0.029681852545529127, 0.0457434815114304, 0.022632778779934012, 0.026549703982328216, 0.06525554559043338, 0.040856641116401846, 0.09466115640656603, 0.032950931664315924, 0.047128828948423754, 0.10604085626020547, 0.025530435490391912, 0.03765515585039412, 0.02918513454196434, 0.0038996606928131156, 0.06428776203744835, 0.08677167652715599, 0.05475047682862609, 0.06536821414145731, 0.06854662100874609, 0.05747853507918697, 0.0737311210363142, 0.019787185404810215, 0.04194486518240264, 0.06893104392915003, 0.04815883033217923, 0.028402920466877764, 0.07706533486564314, 0.029821991094297944, 0.04617206557022949, 0.0016376659163318936, 0.006163826610352243, 0.012227206644902547, 0.03882457374504978, 0.07759080223378635, 0.03762093087237689, 0.038658658252848734, 0.03419252653275767, 0.05705806006106639, 0.014309789853981666, 0.026827885829392942, 0.10832461798864026, 0.08591991699030323, 0.1832134664178856, 0.014651816511046023, 0.08156501357593844, 0.060671198842746604, 0.02668264705026823, 0.06493473095038245, 0.01858748980016718, 0.03686995403240285, 0.06339551092335774, 0.07746681856412081, 0.0314012564523446, 0.0256877324934448, 0.046641363371764465, 0.02454737422897691, 0.09886488769083254, 0.03676760468571898, 0.016817221485619104, 0.03570488368671748, 0.03334303078572116, 0.018501111471484748, 0.08603559626686959, 0.049431428778916604, 0.05793454125523568, 0.02604331220349958, 0.07790139726092739, 0.016643036074275454, 0.07673077660823062, 0.04990245410872083, 0.024115737309799563, 0.05319366742285991, 0.019006030446278955, 0.043014281789862344, 0.014925578988397555, 0.035930665119761424, 0.09991400679873844, 0.0817133741633546, 0.040893275440940936, 0.06851980027051703, 0.020837304257457296, 0.030069812876923434, 0.06627837256077798, 0.029693544962473457, 0.029333439588005987, 0.012247644913112445, 0.07041958340954396, 0.06614668204659416, 0.1084355321983176, 0.027100724213185812, 0.04051615333845539, 0.010983648676154836, 0.03734307461267999, 0.029722897621292262, 0.08629291753975615, 0.10493213551179056, 0.031383429586346594, 0.025486990644205964, 0.03926128599672549, 0.01142304702361505, 0.03583024631464674, 0.005306569435032866, 0.024114433045108474, 0.07352107504923498, 0.036679860805311514, 0.050208732230408545, 0.02876186904857957, 0.04989381646737457, 0.03172331215483287, 0.00778517700851925, 0.05556854764900862, 0.05510792962365574, 0.019804983542511062, 0.045943602829450564, 0.0385343183522984, 0.030720872699373195, 0.06521566305309534, 0.034463825079822735, 0.08795095397339714, 0.0350383029229218, 0.0904535563782819, 0.06319980227178143, 0.03362802698487236, 0.04588351089267, 0.05912478908055252, 0.057208328207414, 0.04140826655671962, 0.0252490705480018, 0.08239642581752232, 0.03313198122346113, 0.056839491345829544, 0.0200253238360728, 0.01451456898658146, 0.04765420055557643, 0.04577090362868002, 0.03094819013870532, 0.06365315778361214, 0.058985207860748616, 0.030345085505095702, 0.05461839177916127, 0.08533951345710986, 0.017930400865753333, 0.021020129225367022, 0.04929242978593515, 0.05392979364842177, 0.05870660849576516, 0.08326590496806369, 0.029423487477845726, 0.03840166639776961, 0.0566811639545185, 0.00899412120962816, 0.0029282940029647323, 0.01140970272958399, 0.059592750058659626, 0.06497139591843852, 0.002486090816091746, 0.020176825383978508, 0.12471657832183185, 0.00758995003472533, 0.03912806330669311, 0.03296074525062596, 0.0534459823111613, 0.05944741551854438, 0.04350790288299323, 0.11062411516303979, 0.01857778729660617, 0.009611307496895954, 0.037826671445321654, 0.023316403084825126, 0.056660475750123306, 0.016966846118110324, 0.015791169285113295, 0.05493073348676967, 0.02388342880764075, 0.03418448643999235, 0.0667452265418345, 0.02461063202410456, 0.05491554196323118, 0.046083199371012955, 0.03964567444317284, 0.062171447977063164, 0.07101750737356563, 0.09838533197199145, 0.03897573055338956, 0.07099099307050628, 0.06933895510531242, 0.025067526862145435, 0.04958915862164671, 0.03293527665758326, 0.07809801372669398, 0.09040879386086619, 0.06905273699592199, 0.026560461772004926, 0.0010508341872463784, 0.016747566856323712, 0.00860873589126934, 0.04506963823411254, 0.05665103371645655, 0.03997213898166534, 0.022642232304919633, 0.052686092038188255, 0.06596602319229035, 0.030226217387544534, 0.04217060065017112, 0.018272809609169924, 0.04779227641260913, 0.0174986949986628, 0.01086022999633344, 0.045175201319638765, 0.054227024271723726, 0.039807885900259986, 0.019655768767059333, 0.03257717651825759, 0.04865223692069131, 0.04759760197973059, 0.031096255782270626, 0.09125692214095786, 0.05892859013270467, 0.05670709220031577, 0.08206469442455039, 0.019893826759089867, 0.013220369733209092, 0.021557804204583652, 0.037836557809984496, 0.02191837689268493, 0.06763240998430599, 0.08471583361707388, 0.07219792629081397, 0.02911157477947493, 0.007171597080155006, 0.013848138567540916, 0.054837431638471545, 0.09237346464707967, 0.02743143862443826, 0.04290535557834853, 0.032500590708467274, 0.0393137630195387, 0.05051079686851271, 0.03986257691717437, 0.07254400651060766, 0.07632208402238547, 0.05328298944439139, 0.014172504982730795, 0.026951946107850924, 0.036407079878112966, 0.07012529073343163, 0.04059632060929172, 0.024626760090130474, 0.0728003012256757, 0.03075429711550955, 0.057474723791763674, 0.014605371473026613, 0.04538512856308972, 0.04716407665381989, 0.009242959016363227, 0.032220332763127746, 0.03623352265886722, 0.07273260203580703, 0.01703206701354394, 0.011401572621487563, 0.04133066568042963, 0.058255696804412914, 0.07581810542051831, 0.024167373551115878, 0.021361702932946144, 0.03705098060891032, 0.013640137077609618, 0.03569018245945054, 0.04602115391002548, 0.03320031626630695, 0.04555619599658155, 0.01779925618921557, 0.06778110765040883, 0.028051672984034787, 0.02828052451443528, 0.022789922565402045, 0.10962612476320037, 0.029729081866061016, 0.12488271980997055, 0.15851442401687946, 0.11884619211477619, 0.15007942824834777, 0.09068859981433039, 0.16398182499312586, 0.06759789006243791, 0.19857723716526263, 0.1633304970399026, 0.1507333609005136, 0.161434352818516, 0.14306010167685249, 0.11909867937286055, 0.0987805490712485, 0.14653683850361457, 0.15298048064353006, 0.14334865635441196, 0.16945848031149757, 0.18661275175550293, 0.1843847535670765, 0.1517576051335181, 0.13652065258112647, 0.1194540752218135, 0.12533499513782803, 0.13689477927982807, 0.09276740237950318, 0.11370371200985487, 0.1471769049643509, 0.22169424671559568, 0.2342157546550997, 0.07482972942412862, 0.13511812945287074, 0.12926989084770604, 0.15076227305877596, 0.1487433096213687, 0.15673878542598219, 0.11419313494116069, 0.13747745043327733, 0.25595386722876184, 0.09617584246781566, 0.15323260017941076, 0.14294623036778745, 0.12427832240298872, 0.12413300318463195, 0.1394082065070829, 0.11473962376194616, 0.1355635482938059, 0.2868224301886174, 0.13553334910783077, 0.16413066055505507, 0.2938736260177628, 0.16591150854383746, 0.1660508599372641, 0.2042819875022096, 0.1052523066379851, 0.14803739024266122, 0.11079152069625356, 0.1588653995385093, 0.129049533317166, 0.20602725836778843, 0.173440053758602, 0.11408716965947421, 0.16583575776988463, 0.12975994197110977, 0.21521908771847525, 0.13030656102684238, 0.15461108346860256, 0.06920522679725001, 0.06797065312463431, 0.09342485903612069, 0.21647826047433963, 0.11537125559463618, 0.11458244550252154, 0.20604400504981318, 0.08711105347761224, 0.1405289318532713, 0.14584771177220732, 0.06624542311915467, 0.26070024157243393, 0.1325788390972922, 0.22947454374403725, 0.18543673018293996, 0.19482231849143583, 0.22365878726686203, 0.13657651571256502, 0.1421751935155161, 0.10767079258878386, 0.14157534667080449, 0.19799568450018284, 0.24539922874781395, 0.12828586623072624, 0.08862387028432663, 0.1832880220946766, 0.09768355712895432, 0.11628018061239874, 0.17154697388891252, 0.10140356517607167, 0.17382599353309602, 0.2045231826242901, 0.1934646115067505, 0.1558825136312554, 0.08854435801866556, 0.15255073596152569, 0.10081034499190508, 0.09499737707477424, 0.12992411461328307, 0.17640297541454916, 0.14250764503113686, 0.19160269609382077, 0.09774431556222901, 0.1525617982711523, 0.10896576463334984, 0.1499113025924852, 0.08312792487202153, 0.25368290682954175, 0.2509352865238344, 0.15690240648485002, 0.23315622441230283, 0.1995550105047803, 0.1400923996322578, 0.2437850661695965, 0.12320771452880676, 0.15369481166764615, 0.15289904549717903, 0.2292513210446604, 0.21363589041415723, 0.10374794744195477, 0.11205871439268512, 0.10099889455182899, 0.17584610610238968, 0.23617093361193137, 0.11294508578195689, 0.159864439478805, 0.12336608788539326, 0.12150147584297004, 0.15562426539198046, 0.19799571514369982, 0.16753149339027945, 0.18889725658922427, 0.12230523997136664, 0.14586694057910674, 0.14856663442427112, 0.2240196606444736, 0.17345096285064376, 0.11178154378168045, 0.0878281883835312, 0.1871611328134614, 0.1674315648814363, 0.2206554621337883, 0.11760360516247251, 0.19446222652350703, 0.15145023533653829, 0.06550927391095508, 0.08563725352888146, 0.1442844940409545, 0.1550072122124895, 0.138029845791959, 0.08794400555592391, 0.17945860903109276, 0.19159678189504534, 0.19124712404464522, 0.08431117065371045, 0.24547548513979683, 0.26831644256749465, 0.16576984356487953, 0.11852103375619459, 0.1149937887525847, 0.09913337086477589, 0.25337238075031393, 0.11942389135759686, 0.09245434054924596, 0.10107309016729556, 0.12479220652171683, 0.1941095196431683, 0.2063152767838009, 0.151238136233822], [0.022329574586042476, 0.034109670293307116, 0.02237626572980756, 0.05887981331456573, 0.031752969333601576, 0.038122967441355994, 0.025445893857507937, 0.015213143497314906, 0.023072430894019145, 0.039117728780594566, 0.03025903084856128, 0.031116873123532826, 0.04282203585570378, 0.04580134796279092, 0.039355246680638487, 0.07093403443333603, 0.038083713096115863, 0.04746539052575827, 0.0983777170580241, 0.011532272967029245, 0.08153517445128772, 0.060085493981117205, 0.04085427773515544, 0.048405679183140884, 0.048622114343508605, 0.03719640324913687, 0.032534137698671514, 0.06424409119532475, 0.017309984560274792, 0.040555802218976526, 0.043291188100533146, 0.029626567810473424, 0.05633971473622707, 0.07875831256951056, 0.017122185766516675, 0.07227724703449397, 0.04025625034926399, 0.053999136096888015, 0.049255799291835684, 0.03827302874396405, 0.03249014126918009, 0.0311151149517466, 0.023095130079215574, 0.0337377269451897, 0.02688972253142105, 0.02967790527749927, 0.003977858638879092, 0.006876797349597778, 0.11991092409457892, 0.04533016941540184, 0.03323111683130264, 0.04727517472459905, 0.014965292986392256, 0.04631817002870864, 0.03656921089596806, 0.02393775976323072, 0.08494812679747421, 0.049421649666563164, 0.045889413600126584, 0.04230835858071524, 0.03739279754940541, 0.02498351957558865, 0.044968828724156466, 0.049494795741573464, 0.013364965956087315, 0.04596300783657259, 0.02394477521339732, 0.07104400635486649, 0.05713194158048399, 0.05320220547277601, 0.065114623716762, 0.028840885272309668, 0.03655122698194558, 0.040733354586747386, 0.04002492243964826, 0.02102018093630191, 0.05622930614457977, 0.07722797533196789, 0.05220868136553515, 0.012292339440224873, 0.05015789846619291, 0.06492479479000454, 0.07479551593743025, 0.03544471639719221, 0.052641314199014064, 0.026418408003425407, 0.011885258511850431, 0.013950120192021133, 0.05030330578466097, 0.07655967853122181, 0.04597338066706735, 0.020642174002263817, 0.0555916681825634, 0.031518948624932, 0.07642109322571948, 0.09115746860662777, 0.03477319436628492, 0.027879017833319884, 0.008314634737138065, 0.011845867228393835, 0.04660335391940129, 0.02672859508874676, 0.046341719571501024, 0.019769952256953525, 0.016824102870398955, 0.03979182486692744, 0.023875781334936622, 0.06349653876837223, 0.012379058678033612, 0.011650718778612153, 0.025847155390487566, 0.008016995693211475, 0.029385284588281668, 0.01743688127927242, 0.058994063837153304, 0.035220206670102575, 0.026309221322017334, 0.03319053332351389, 0.0739012002163837, 0.023508612629807284, 0.09645832972901483, 0.03644120909513966, 0.007642612833860181, 0.01656618787937107, 0.0450112508429635, 0.01809113760358624, 0.03773464896385709, 0.08655891858882482, 0.020374466492343816, 0.0262183154137024, 0.06616318358048316, 0.011973283929570068, 0.03967965044261467, 0.02920441505979867, 0.08445484278303, 0.05596691720007409, 0.02214732226885615, 0.07449068955235905, 0.05169844765576625, 0.06041832471026048, 0.06499945005822567, 0.06285613905938883, 0.04378785439316304, 0.009188239271151684, 0.013897485163573538, 0.0180994170988279, 0.017398111484644395, 0.08049046800982568, 0.08947267272179166, 0.010650609188052195, 0.0319682419555442, 0.03303029071239214, 0.023885024185743065, 0.030224530078891306, 0.026070663457616203, 0.05304695392448095, 0.03817884972499263, 0.007843012816362805, 0.009641077673633494, 0.08269896159969992, 0.0693112840094874, 0.012580597258713699, 0.03238327200374296, 0.027710564674869664, 0.05442064150326675, 0.04477495102271919, 0.0349244775791322, 0.05572597488700863, 0.01828071946698812, 0.009917543483747831, 0.058376742526888854, 0.022613808527709018, 0.010342893693896552, 0.02944532672934715, 0.049587611124039664, 0.043304341830193036, 0.08221064183500507, 0.024790538197022774, 0.04849683981569064, 0.025522439447682232, 0.024908063745486642, 0.04581110409250663, 0.07778940286727683, 0.014443788208037376, 0.028692128234392697, 0.015249488623662582, 0.049861161969602115, 0.010936548632960166, 0.025121507332510045, 0.05804252134816301, 0.026013846546711943, 0.04911493487475861, 0.04793414823530663, 0.030102507594311913, 0.0152891164367658, 0.058193681986942414, 0.030852741328999404, 0.02153816554064472, 0.055128598675852826, 0.018292287394644755, 0.013165082125323675, 0.03501798244073026, 0.007313888814796003, 0.04251568495566326, 0.008135636378410123, 0.029720762151203332, 0.020562684719240474, 0.04349788628338326, 0.022479356266558174, 0.023143066115857616, 0.04368519478086983, 0.0719891443488098, 0.01685015369026411, 0.018630158982329795, 0.02134122540273013, 0.03209822217843706, 0.052435508508595734, 0.07902288103416082, 0.03409662381595662, 0.005238967442569594, 0.024896459428653605, 0.02707637602373237, 0.041505322235846714, 0.009492109003927439, 0.02236525321589603, 0.019273850954167785, 0.03993328300214583, 0.042691693656266703, 0.018243200310896483, 0.05811088320408618, 0.06692798447705085, 0.016571006572414792, 0.030741175944586436, 0.04382110260907681, 0.1428831200445852, 0.060813074495883725, 0.026871483893163746, 0.01218799060405863, 0.022261754737325737, 0.07685066170750127, 0.03938303268965214, 0.02828869101170811, 0.014107166301278819, 0.07971945414019209, 0.04693187540397049, 0.06956819925577411, 0.06861616647051227, 0.015085367692424165, 0.02810250866347023, 0.009036093251779675, 0.026032299689588048, 0.05229751309079509, 0.01948182850385145, 0.025400886191956462, 0.03060690945975723, 0.05358604999679712, 0.03970760882141129, 0.03158073936168465, 0.03219820048299528, 0.045533538946220954, 0.05252792552534131, 0.014728172494459056, 0.013970044223711857, 0.009330519035668864, 0.06723720820680743, 0.07780454842553985, 0.018556005501699065, 0.013373157351217685, 0.05932718184926818, 0.020897574309680252, 0.05422689020633698, 0.036535855427744894, 0.0014733735729204193, 0.029988856535525094, 0.00917995211503078, 0.03071130234597912, 0.02344410228092344, 0.06172802862561038, 0.04302083184161494, 0.017974441345300407, 0.04300500829553893, 0.042978827240726644, 0.02448829161303659, 0.028610264078804085, 0.06335012021384413, 0.025732236456186063, 0.031030280290231593, 0.06430850003755863, 0.02393057194328116, 0.04649428215118186, 0.004746773667002638, 0.05041100625549594, 0.03201035763918152, 0.04161083935609749, 0.04438212028734627, 0.012747408116176244, 0.03293592400187927, 0.06606980512339262, 0.023769492381102136, 0.01260747545353708, 0.09922996689114841, 0.0838770822531754, 0.08356304749125436, 0.043211242995194854, 0.013792515796188627, 0.03700776175866204, 0.04770312676086061, 0.07665226025687111, 0.0727886337065889, 0.05210547016993646, 0.16801097250032812, 0.04847232500211366, 0.007600655634662197, 0.03817337602677365, 0.008288378988753163, 0.006373019367005797, 0.056391563566942374, 0.02699351212340257, 0.022036436787475983, 0.018241313819382942, 0.043869745361829, 0.03559234154020106, 0.012727540583469936, 0.045564856620565544, 0.08813640087722771, 0.07406156540157334, 0.016213034752816442, 0.06969358486634109, 0.03191123160743906, 0.05299982802581884, 0.06683495075952622, 0.05573162095501058, 0.006667727645817063, 0.0260619109030813, 0.024370202989948374, 0.0938172416100579, 0.10743492943865639, 0.013278041789758832, 0.03942748111101889, 0.028394054914374026, 0.03784553636045706, 0.01681696484616447, 0.02207029978894899, 0.016557251463734334, 0.01805862483207978, 0.024247952594211506, 0.007160329842008651, 0.009873802736101132, 0.032979935753129186, 0.024117704240545153, 0.015103058577815612, 0.04498538388420017, 0.14905616460788637, 0.13372175034976777, 0.10428620081755424, 0.11555648033296871, 0.09474198634345686, 0.14170688396740344, 0.20757912267600337, 0.05184100129671636, 0.11383832897990943, 0.13177430888097133, 0.13650404379492806, 0.10410916555913226, 0.1271102583456424, 0.13091137212130333, 0.1714344662163527, 0.16349080859893755, 0.08398215887286971, 0.07776066690923707, 0.2136785461897812, 0.12031976223712969, 0.13668177619336114, 0.12397296741724977, 0.1352600855452399, 0.14275752759027865, 0.1022021122457039, 0.09709766840622311, 0.13962378364897546, 0.14611401925644568, 0.2025770894702404, 0.10899485299183477, 0.08392834885706825, 0.1617760127109866, 0.12251184622366583, 0.1494365579058086, 0.0946518101338898, 0.16623645239780027, 0.07505010993730638, 0.13498441646656684, 0.21458614587543473, 0.14346556137165717, 0.13493417642049252, 0.2640740315039312, 0.13272398211542638, 0.1601408286801269, 0.08250417608407237, 0.15935198794449532, 0.1582240154065432, 0.049810581014401493, 0.1948732633384005, 0.09077014987387004, 0.18650033601349403, 0.14088366120573015, 0.051908516625483195, 0.09882944846345533, 0.23183332846289684, 0.1026202813391724, 0.08610261363848563, 0.15573312648602072, 0.17373888933610532, 0.1857699631082435, 0.12969690825669997, 0.19973329448651886, 0.13074539151162873, 0.12437836582502051, 0.15994268769939102, 0.12145721128270512, 0.1587016865490906, 0.2525184838281524, 0.2118503080020028, 0.1622138319597129, 0.24241602108363183, 0.11406883717544618, 0.18905091850507647, 0.10978526420771115, 0.10608989354823867, 0.1088705245826033, 0.12034316622321645, 0.23903339049748837, 0.1250006130806381, 0.1458959599896785, 0.14347507618367672, 0.12845945409348897, 0.12556317442607495, 0.14694632782090097, 0.16502788741021387, 0.13264971755204663, 0.07908294998830365, 0.1898436662891219, 0.148514601732454, 0.18768224114131546, 0.08705673018290151, 0.10186561578584295, 0.11365793059549986, 0.08684951872114213, 0.32078733667731285, 0.3317159486393775, 0.09804612356087855, 0.08544272082226892, 0.061540555419220086, 0.12207244117293628, 0.09753231605094287, 0.13186775628597508, 0.16204972060457354, 0.1323632313118827, 0.12968777648864255, 0.18453984040646784, 0.13045924235015147, 0.17787375697685828, 0.14409776777029037, 0.22090339882960244, 0.10979936788639716, 0.12359841170931056, 0.19596562810963203, 0.12342484682918557, 0.24558782427301332, 0.12226266846541436, 0.06351063861661861, 0.15533244717986355, 0.16982603397580887, 0.07588812585679755, 0.20046601162081767, 0.15995126788414296, 0.12875975289892766, 0.11207293298455978, 0.2781375978262194, 0.19891977039796693, 0.15340222736760495, 0.14863164464552558, 0.10298116237766321, 0.21186942955659283, 0.15571999573899856, 0.1743685982881054, 0.11859054091356455, 0.15110808514779614, 0.22086889422949285, 0.10111110345009836, 0.11052227909526519, 0.22908642827983827, 0.16179001679824245, 0.19971783483220687, 0.17041789818434946, 0.11121132155700077, 0.10364036571474806, 0.14504597011593082, 0.13317522322458605, 0.2056978712038648, 0.15632776393284722, 0.1636737657170142, 0.2542342449868879, 0.13165890539605773, 0.15572681392152465, 0.13792493771160805, 0.15459642054573183, 0.11974685870471502, 0.18563148505505056, 0.13680888550175777, 0.12863796024072555, 0.16813215228819078, 0.07925224009781115, 0.19686538305494095, 0.1823486144384069, 0.09373911596353977, 0.17183387381655557, 0.059401929048040224, 0.17042342933916277, 0.11242316540090308, 0.10742280226681503, 0.0824510095821273, 0.1310259482312587, 0.15321292704151523, 0.08911587493193728, 0.10761692128594845, 0.11252883190829908, 0.11747331658919012, 0.11876326309697283, 0.17215343973328992], [0.06849053571180952, 0.03514834762280507, 0.11645792833259029, 0.04086645087227225, 0.010995204154882702, 0.06805419501277708, 0.0298346909168627, 0.07581566160003986, 0.01952823427986474, 0.034430749233691924, 0.047394680610347184, 0.02971617711497651, 0.015300143314825912, 0.030760111722854838, 0.09378597756186802, 0.04724260449649827, 0.014425081298536351, 0.0330240547566885, 0.032054911397637866, 0.009201750189306275, 0.006971844920753352, 0.04455609885495036, 0.07921383611016697, 0.0483858528276605, 0.12348924418010059, 0.025520531888750773, 0.026654809330319686, 0.10210314134676611, 0.09191650852200486, 0.045771439890227014, 0.07941333306652885, 0.05551331270966799, 0.03894891747603974, 0.023864588790362882, 0.008794566796671961, 0.08893568339126726, 0.08951699856909053, 0.05139107019790719, 0.08694149523733125, 0.011017142040204379, 0.02955319190908584, 0.044882482954210816, 0.042910637754586436, 0.023309787915598963, 0.021155179035098805, 0.07930224265662894, 0.03364281631225059, 0.01919079936229654, 0.03437562920753995, 0.047861477134809385, 0.02737358941005603, 0.02687644239725365, 0.04564416204248706, 0.0353741635298056, 0.02624180175424103, 0.025372132996938405, 0.021935276792294556, 0.028434693963537296, 0.042019298285125725, 0.06519743016049748, 0.02317596384654603, 0.014131417772131822, 0.07578607528440415, 0.027592594795409712, 0.016358951519754146, 0.021372131304815415, 0.017947291189263907, 0.02843718757973083, 0.037061736483367226, 0.00970024360163558, 0.02341310827872686, 0.02658032451666171, 0.04488842779650323, 0.05571063780676454, 0.03481355953901526, 0.04422143717566806, 0.007536348299078284, 0.06768022919253958, 0.06414706615971462, 0.04050904021207844, 0.039600161159591335, 0.01921251412451027, 0.02622566028167644, 0.01979419319409757, 0.041651231341905175, 0.06670453961217596, 0.04088371466364592, 0.06750060455693353, 0.04279781598597766, 0.012491402599299628, 0.06464637545568329, 0.01908241898842877, 0.040688488647461905, 0.014173367789255516, 0.009449400559758708, 0.05429938893705126, 0.0016274654556200992, 0.018953375308023348, 0.0427949431562616, 0.09425257873390952, 0.0288352181368898, 0.031175927011175986, 0.005382794225888868, 0.01744259437996774, 0.05515914260139389, 0.040531187813969395, 0.02372222092573441, 0.04644253674233633, 0.10188780169213012, 0.027180186683131803, 0.07106766314996828, 0.02830707137623141, 0.03771792526447004, 0.029329519133053483, 0.01188074816919623, 0.04643135951952108, 0.02415011742062146, 0.03782432721627336, 0.01199734004800238, 0.07464702511506696, 0.052113855002267714, 0.030540874595904065, 0.019305013495707707, 0.02819574156385516, 0.08099654569260537, 0.06561399813020422, 0.04751163925374708, 0.03426392975774023, 0.05450545509736385, 0.03648970246074661, 0.036099369172006845, 0.02275522644331138, 0.033507394949875535, 0.04569366281371444, 0.02913823846967951, 0.038950453482327924, 0.008179782195046784, 0.02059635045307298, 0.011812036785657608, 0.038984896795403574, 0.02831602119840682, 0.009458412626577963, 0.042690169141297384, 0.036617007121563926, 0.05464034785907115, 0.021423505161017663, 0.007223021689682238, 0.013787517072482696, 0.037728723273762775, 0.01769852903371136, 0.12429489288479091, 0.03901309649189634, 0.02018945434341027, 0.046887633826343283, 0.04221005417827157, 0.11015480970062556, 0.021741146281842264, 0.13786124516158335, 0.006780606392215217, 0.05372355894876584, 0.05335092612151658, 0.015074133013014593, 0.0406200846567029, 0.04970903989047774, 0.04438046936786944, 0.03347290567152443, 0.05821846110085326, 0.02435724269748936, 0.031674732604334434, 0.034286054376993454, 0.04599142203768415, 0.08830621192652373, 0.05053867097763766, 0.022833997518905712, 0.0708719430070731, 0.054961285073189974, 0.025175575902985952, 0.03938022497740965, 0.14948364166963488, 0.02150388693647279, 0.026137364817963495, 0.0378160304840534, 0.02081194100150418, 0.05214506159386328, 0.057458386966778394, 0.020197013716003107, 0.03166911909506927, 0.030069305343673598, 0.026992345754537853, 0.018197039683018962, 0.07195421840034186, 0.058689486430657495, 0.03675222164019942, 0.054032583495662104, 0.03051897788780832, 0.04662636337020705, 0.054122889940176284, 0.05769711528574267, 0.061095328100266, 0.035999846689763575, 0.05531489976771897, 0.028014383654320435, 0.021767183695168748, 0.05648636311713246, 0.06410082509260505, 0.015904160550675325, 0.0532244679878556, 0.07777925986315935, 0.017963708453481237, 0.01770800745655452, 0.027012235312271985, 0.015357454352441336, 0.034168364119625864, 0.019540704276052215, 0.02590834666343947, 0.021159580210223797, 0.03462071605627576, 0.02139665569449144, 0.015015379814881713, 0.02369072896638705, 0.0672236561114269, 0.08211080525671283, 0.038488571411899986, 0.05046122331893252, 0.01819167898276881, 0.06344575479987168, 0.060989872267049175, 0.04402859752336818, 0.06439691424489984, 0.07130204775040189, 0.06005332977961629, 0.03601713346377496, 0.05061165617418386, 0.004562354278600505, 0.012191808594751262, 0.05073984183611409, 0.007777386373134271, 0.027167624756393415, 0.0295937754168746, 0.0064327909832730176, 0.05007273247165065, 0.02321811783457956, 0.03542414693642528, 0.04101696033631602, 0.04475504805844638, 0.07960664769334179, 0.011440783874281954, 0.007933990545420638, 0.07169456055928623, 0.08534872183395971, 0.02796056406241992, 0.03622737097283525, 0.0013671930684077164, 0.046951219124058564, 0.08242242684167239, 0.04326245980337263, 0.012219886674786047, 0.03059841354467696, 0.02368560000773399, 0.03400356328535465, 0.05472412723447046, 0.07015843169703599, 0.05910510445133813, 0.014585082591961951, 0.042931268502387314, 0.015297081835958508, 0.05434929190443889, 0.029172679867535353, 0.04009012035244415, 0.032160485974482955, 0.05556434182630432, 0.035716551205804276, 0.048568453714852376, 0.03366566105415264, 0.04208643056993042, 0.056466812553304824, 0.01642971123088031, 0.03932904264318847, 0.10317316699412563, 0.05739077970746064, 0.04457897040992976, 0.09154030572502844, 0.01690792629585391, 0.025565077986327872, 0.033790579351085814, 0.03123897604734427, 0.07338803622030443, 0.054336655284127885, 0.05592219681749421, 0.018329184104297912, 0.048085071386829506, 0.05445962005685415, 0.04387626860050425, 0.06480732286769537, 0.023644847960601893, 0.019140747007763675, 0.057361189561385306, 0.02998153081974916, 0.018699671885359193, 0.02316840064351357, 0.0038391457318568667, 0.07593132555484772, 0.019668474335283525, 0.032985865273663116, 0.021494536833356948, 0.02615521658181904, 0.02338742901150498, 0.028954595702910618, 0.033245909989120505, 0.011124398180043266, 0.05461772528266715, 0.032162071776486216, 0.025065533118322495, 0.025540498055277333, 0.028417481883098523, 0.018810986375976956, 0.025941970262436137, 0.06277392633379468, 0.07170875616852315, 0.028798949619334553, 0.03901716058833465, 0.02294489066116512, 0.04519788901351633, 0.03564874859406583, 0.05610500837886526, 0.008543963157271427, 0.06865662357379353, 0.035937575232838435, 0.023052658164693464, 0.04290469291229402, 0.045797529014488386, 0.06212258305881293, 0.034084688166096326, 0.05640394737823837, 0.027535772138846018, 0.011188304277076837, 0.020680620124743834, 0.01566050054069849, 0.034802240589934016, 0.026375928428024057, 0.0960351427596423, 0.022388714658577117, 0.011971950936581821, 0.0205330869122859, 0.07786735997445161, 0.03554484408889567, 0.05462719029897163, 0.017305713620096926, 0.014761545199660525, 0.04179186976304458, 0.03387263885909512, 0.024258809975318374, 0.25472683952220027, 0.16546498653629135, 0.20685619614537687, 0.12218381503536818, 0.12489450990312523, 0.39997640516488786, 0.1095681242464531, 0.13105395640577042, 0.12286942542320299, 0.1359181091069214, 0.09805977524768922, 0.14021667441533459, 0.18692703166555974, 0.13557266474010485, 0.12304529622798005, 0.20819272845983508, 0.1823596767480335, 0.13007279695762744, 0.11366868646995676, 0.12741100914295644, 0.13694952392289717, 0.13039571833947014, 0.11257269044196415, 0.12756995706548616, 0.21314298944367518, 0.17755382333792027, 0.1772670613061036, 0.21133333654893985, 0.1485860470922724, 0.17447537562299162, 0.12237359799685017, 0.1396353362548736, 0.07917809810849928, 0.11334515987865387, 0.07753189773328843, 0.13840734327752746, 0.2819598249850735, 0.13965196036283048, 0.11450144702628737, 0.12244436153841597, 0.08442746280061622, 0.13377980449266974, 0.11389001693216064, 0.04786272585812596, 0.23796938630121373, 0.1841800242301918, 0.18885492257052855, 0.12479357781910128, 0.17244067673961963, 0.20155431612605051, 0.10128680571553209, 0.1134021491593411, 0.13186170419137325, 0.21140550203140707, 0.11075683223504214, 0.14358798222195718, 0.09602460905068344, 0.19952580723310673, 0.08907547911568996, 0.08826773899096636, 0.08441218700740608, 0.12883155065919125, 0.1804605601055007, 0.15497757993157835, 0.13997259880265883, 0.12563894818266555, 0.15498044510041514, 0.17593439007478376, 0.11119887262823121, 0.151116221001552, 0.0932467665763632, 0.1031410372665813, 0.21789615132635642, 0.15235858578835765, 0.14764447906805625, 0.11923850574080022, 0.07047307932929647, 0.19935264071870237, 0.15493158401260454, 0.12900753637715695, 0.09805972162153452, 0.1731737769178806, 0.11044669686065567, 0.12767354747460735, 0.1481368437769913, 0.13272401275894335, 0.07207341402048065, 0.15778251893578038, 0.0894103974344269, 0.10018248231180253, 0.21960078888843138, 0.19863716056269987, 0.164022688123007, 0.15591792221511566, 0.1344719036452232, 0.10674705909144495, 0.1026953579557519, 0.12505151196232728, 0.15485089963241933, 0.22559933394433992, 0.09617948138545598, 0.12100039305345667, 0.21122139578144397, 0.17783355268259204, 0.10839057049804157, 0.13064166320668114, 0.13527422752832213, 0.09600473672992761, 0.1718670607454354, 0.18668352295794796, 0.1452971397027854, 0.12506401451725152, 0.10747012351789784, 0.08729522867548851, 0.13423781781908006, 0.1046925338525926, 0.1375820367567001, 0.152577564360634, 0.09712441253565973, 0.15989594101425142, 0.19251222632104353, 0.16523716730936883, 0.10977705940604211, 0.09137322960962212, 0.15201383090067297, 0.1741752223742585, 0.13856252204746972, 0.20419091496977115, 0.1126442736976089, 0.10712245749610086, 0.100088284140633, 0.1396023025435786, 0.10487541436187683, 0.10647345078928817, 0.09348352604936208, 0.22667115223744225, 0.07342232631579523, 0.18564472305438212, 0.1442193459238737, 0.08566811155047148, 0.14028431997904856, 0.15190585846862487, 0.11563249923769506, 0.1433667207076665, 0.1225818360164281, 0.11376073193405906, 0.10586362947980243, 0.10738167866703965, 0.19468155749622854, 0.08231331293861713, 0.21078294834061978, 0.17332461963017143, 0.1419449074854774, 0.13374566761476378, 0.13425208237623015, 0.18599940644156548, 0.15988107890852038, 0.21261530808143078, 0.11251213119154978, 0.18124587683668061, 0.15195530178325792, 0.15479673721617268, 0.1699873108056284, 0.11491200886666776, 0.17519295485990663, 0.12628241607378568, 0.14034968260074818, 0.10867411496057626, 0.13727324203618113, 0.09793690240551388, 0.1303186805378045, 0.2630371161766591, 0.13490656661170145, 0.09538646547063705, 0.1517667675450925, 0.09400363846291458], [0.01583135155435171, 0.07458134073643916, 0.07732958923424445, 0.008253357279294682, 0.03526884942285476, 0.04211120968384128, 0.08817265215780466, 0.05821334363351907, 0.019734631773204576, 0.07721467604560238, 0.06394853830457696, 0.027619974777823495, 0.0164152838800463, 0.0072194675205185296, 0.041268378901746006, 0.060970869456087394, 0.02121867431748298, 0.031385528667259126, 0.005926572053032297, 0.04606909952276657, 0.011476080417783271, 0.009942797572171737, 0.009321048273704946, 0.04578240643886309, 0.039305293917535775, 0.09976853436279683, 0.034770049575355746, 0.021768164287711826, 0.054297573308670716, 0.06467295104577657, 0.01783365162179595, 0.037802286866691806, 0.03366289164630636, 0.06458663591934789, 0.05553678947410757, 0.05180131411179901, 0.03733650540872928, 0.026343630161136392, 0.006553690191433435, 0.05377334317252521, 0.027168930936304313, 0.08419598933429488, 0.017279572784900665, 0.030800762263336973, 0.08651672246595545, 0.04491480803417583, 0.018843265490666516, 0.0942843943654049, 0.023745439135499542, 0.01909174993934651, 0.07438860067556943, 0.0019465212056773806, 0.0021908273629378527, 0.047036224240136724, 0.020437555748128125, 0.008425031837466504, 0.03850105481462614, 0.028862153788307504, 0.018285819697344018, 0.025762590774965864, 0.02889615468560688, 0.04757157414250317, 0.04176854238575024, 0.05036114542294414, 0.011948804547559592, 0.03241720203790934, 0.07514857521821415, 0.021525959844791123, 0.03372929997802262, 0.075054231490339, 0.01962755183358827, 0.05311879381958035, 0.021582510540141694, 0.017376716564139052, 0.03520665074428243, 0.02577155783411957, 0.04705316627458219, 0.042384940560065934, 0.030599329019746477, 0.018263327355887142, 0.03635660234478213, 0.02216777490121463, 0.05850323513450642, 0.018103711021643494, 0.10101953296050911, 0.07040531119151462, 0.030359585634282524, 0.05256917552962419, 0.06813717765673515, 0.005569939929691534, 0.027288383195897745, 0.02787307490624728, 0.07096863096399654, 0.05600418737759033, 0.10024151704724758, 0.027957951702598124, 0.02537152204181879, 0.05188947167968558, 0.05304819498691828, 0.0999177223251712, 0.035604890060400775, 0.010715858811782974, 0.0173591501680353, 0.03778710300403257, 0.058689597513406515, 0.07365841929229998, 0.027295109447872928, 0.005881454262341703, 0.034384971649776545, 0.009102092684066344, 0.0485708017743403, 0.03998220920743, 0.04603895779338576, 0.026728543377811873, 0.006283551309963749, 0.004761630984684152, 0.028565698829028877, 0.04853279998285636, 0.044172924657862996, 0.05873369736476772, 0.08214305755832503, 0.0061090350443977984, 0.08270688294883698, 0.04201491243175922, 0.022385196399784858, 0.17970308300948915, 0.010245752787487883, 0.012756404861237013, 0.025907057720506867, 0.05897280872769414, 0.042841333610516404, 0.06321849098669426, 0.019458275130619446, 0.04572869601449178, 0.033786235632555145, 0.02870270982384682, 0.016759098394803943, 0.05579598000152938, 0.07135785725568572, 0.01897960041289128, 0.047327820286755605, 0.05018502180915206, 0.041709488498107086, 0.021353480894298806, 0.05398194125342754, 0.06750184561937086, 0.1002138153079056, 0.0183062914819006, 0.03368341514179784, 0.03215629930397676, 0.06005937038289924, 0.020001216964315505, 0.007676796634651481, 0.1311661882866775, 0.052365894098916364, 0.027714149966355295, 0.057813154623633435, 0.025666642092889356, 0.06707652892556883, 0.09777651423768652, 0.04389132222821636, 0.04260406468904788, 0.015454163376782692, 0.0631425601820792, 0.06474350008272356, 0.04983723321328721, 0.06563708802024204, 0.06047922870024078, 0.010952376009475802, 0.03823939365364852, 0.09071652371917041, 0.04329795265690454, 0.03125127367374878, 0.009790926386842565, 0.024911080216688496, 0.06228605856097514, 0.10659859891259864, 0.032092840410768986, 0.03283860785285792, 0.009525290187147838, 0.038484365589195685, 0.027688250448855183, 0.00894112037419672, 0.019676788304481777, 0.02449673390196216, 0.07183136854080424, 0.020856119376877626, 0.0622986683682088, 0.014232755882755644, 0.012669021042153962, 0.054405285270824555, 0.0420951946157842, 0.003756083127471709, 0.03460716779133485, 0.01392233226778767, 0.046592387370765216, 0.06890880439670817, 0.0161394156185129, 0.07285226496957964, 0.049845020497037526, 0.017156332220521667, 0.12993560593214729, 0.022206586830678488, 0.008651806311982294, 0.04567379815383785, 0.025798043408881755, 0.024329014272699435, 0.07013560993777168, 0.024902883075898694, 0.07657861622471003, 0.024900611625203205, 0.027988076195000645, 0.035973596687038104, 0.04248922427875861, 0.010642393852674193, 0.012923456078785802, 0.051528088853604374, 0.06502959561804611, 0.02085110724663302, 0.05454834836024431, 0.10513770754539198, 0.028004840114003712, 0.05948327992471957, 0.028280993743288903, 0.03543981726491644, 0.022930394362417922, 0.02326987281952414, 0.022815651628339005, 0.040093065960513014, 0.048884671827357624, 0.021001406036497607, 0.03228164277970791, 0.06774997383716606, 0.08997928666611833, 0.022863987945921482, 0.01732241242162643, 0.05581599021811159, 0.04600064190585287, 0.017272978683092424, 0.043210542024744135, 0.00860285999689011, 0.06946941221793813, 0.02538359750272526, 0.059867902027983824, 0.07088970858603716, 0.051311910332691286, 0.01995283085101795, 0.04089708289792461, 0.06640011159282538, 0.0375459615081068, 0.06594774433441701, 0.029429194832881613, 0.03018897402310564, 0.08007224529020249, 0.04775867962668981, 0.05138473465077339, 0.03894481890564484, 0.012133971829297803, 0.015257051826695041, 0.027645077563882358, 0.039831741878222075, 0.10572450025187385, 0.024022736151011723, 0.029751696781585776, 0.034789734204570134, 0.08479877029575648, 0.035922069613251, 0.03387723921708042, 0.04198780824099818, 0.05774303842636366, 0.09404321456508291, 0.04059345544045491, 0.0205197359149855, 0.02718512220458398, 0.06885033656632708, 0.013111374573782088, 0.04857188195831353, 0.054456130526359045, 0.040276632118489475, 0.07108144507172608, 0.04647765038234573, 0.02893758663577178, 0.037818167869362145, 0.012627259674181622, 0.05914664939947187, 0.03190545338927017, 0.06297518146194278, 0.16578747890889645, 0.012171542696324329, 0.05423627861384904, 0.005797907107344439, 0.03320091764532751, 0.024875462873868888, 0.013701106185063481, 0.022994983235314008, 0.04735085655063872, 0.08064233727993504, 0.01733543783155901, 0.03036359993500575, 0.043963698384862755, 0.01267809631122697, 0.02963376903696166, 0.03217678832551164, 0.012797930657172637, 0.06743322712399306, 0.04616041337290118, 0.01521785302282942, 0.060136151545110254, 0.02873018556725114, 0.10686682927752696, 0.055297341032494465, 0.03899449587709481, 0.023363902451350324, 0.011775004095397891, 0.06532145979543848, 0.028807738563045863, 0.039360379469731165, 0.03134332679873032, 0.001802270201170036, 0.04095247871572933, 0.024038071316036008, 0.03831219498909289, 0.09498223151651122, 0.02226226227057557, 0.0055800293076543085, 0.07251176953075394, 0.09262428949436835, 0.020770970619313663, 0.051443217802912965, 0.08642627046473565, 0.027682250065188256, 0.018421712203792507, 0.033994343417185935, 0.03651248974605434, 0.05999284330755473, 0.032658703595159516, 0.017512919336196878, 0.04306493169297615, 0.041249111790450356, 0.06204182206983529, 0.07662060550383984, 0.0264948635782686, 0.053677520894956206, 0.05654491904762484, 0.036024683260268746, 0.048307390102455695, 0.07558933624456968, 0.0242057315734846, 0.04252395870524549, 0.00626126581224643, 0.041390363081929185, 0.03760891478328455, 0.1729929954895089, 0.14233919761834607, 0.1800570309522652, 0.16276742241555647, 0.10677934969745337, 0.14033903397860067, 0.1510158481617128, 0.11176899526148074, 0.1511552148768979, 0.22093905256159846, 0.15513802938643964, 0.162531023003882, 0.09304725429824284, 0.21270343883624002, 0.09994121058092964, 0.1438297595708601, 0.05717791451682007, 0.09210537217797772, 0.11331713638238369, 0.1252622014632629, 0.14837229323963966, 0.06406321783640212, 0.18011863974313583, 0.100627027812504, 0.11247905917585858, 0.3078514211360486, 0.09932737497072067, 0.08238494215953736, 0.14713671599184314, 0.08794462608714258, 0.11747255816214508, 0.1810946817239446, 0.11435664874771911, 0.20995632414856266, 0.2127339138138679, 0.09616158557154479, 0.22974799116772993, 0.1307910809954328, 0.11830996887217607, 0.14215129157227857, 0.14620832467992462, 0.21481013466273585, 0.12969470192347804, 0.15265054189630095, 0.2220111772898705, 0.10207471182389606, 0.12992581532847497, 0.14496939196701975, 0.06818592383135712, 0.08295318021649316, 0.13276306792132317, 0.0933656940657285, 0.12976027904979645, 0.10191460710860069, 0.121214575915327, 0.18642265469797198, 0.11515111256871494, 0.17625970165095023, 0.1386180021349461, 0.09333200151881865, 0.08582957224139283, 0.15963787663607829, 0.12799237028605517, 0.16908268354112105, 0.09429792347814768, 0.22847605538704704, 0.15133783491628786, 0.10444434434776345, 0.09618580927171054, 0.1740503500426008, 0.13392919163790443, 0.08896633456911772, 0.20062784003394268, 0.13293148469059698, 0.0830834075027416, 0.10434567222311612, 0.13495397213245594, 0.1583218907997493, 0.09707415716782694, 0.1098376952652489, 0.1838278076461246, 0.14180175629594635, 0.10063124895696679, 0.14731971907519525, 0.17514694361917435, 0.20630813684434662, 0.11102701612417737, 0.15933979182474076, 0.1685916977904497, 0.16227343360022192, 0.1303288848289559, 0.13755358425119232, 0.13140972763780626, 0.16471012946098082, 0.16761302046718138, 0.15173033240341371, 0.07883993923784265, 0.17338507928915564, 0.11312382175557076, 0.19135138861113982, 0.11122888029222527, 0.08740716178210513, 0.09858080696675087, 0.12586015607080153, 0.17517993136519389, 0.11719942483450137, 0.12741958166682912, 0.17838216356692776, 0.15967340779400643, 0.08991344140902643, 0.17555781189472447, 0.22168831719506174, 0.22377555438828087, 0.17589924196081777, 0.08912067830322251, 0.07892803934913489, 0.1042434914157756, 0.18910371728481787, 0.12879517680454639, 0.14809898371177335, 0.1676883728754136, 0.11253980228737478, 0.13596284864169939, 0.19935630261898044, 0.08644017496056135, 0.18289719467922566, 0.11409613288818829, 0.09655634301804727, 0.12189722920377409, 0.10336623647280278, 0.11747745346398124, 0.17571636145153355, 0.08254336148139932, 0.19214592904092806, 0.16906054360010933, 0.07863351684664527, 0.1209534012201813, 0.15841766711204283, 0.19333439188138132, 0.14610954530296788, 0.11995940213842739, 0.16011799925998335, 0.08586266723972175, 0.2005317572864794, 0.09323581917992524, 0.1214619686887149, 0.2622842356081932, 0.12038710136567393, 0.10958220494250137, 0.09799909342320696, 0.21065046109499472, 0.07645932867402032, 0.1106577464229157, 0.23372349719847405, 0.16300967473897243, 0.18422519277420737, 0.07666048804117788, 0.1785272606197865, 0.11752934059909276, 0.18712560165553324, 0.10339147140902859, 0.16107275931825563, 0.0992943948855804, 0.12361528862628246, 0.1896716948718794, 0.11458794601381787, 0.10616196710015498, 0.15796097145686228, 0.10329326659801508, 0.13010405334493808, 0.15417635921509037, 0.10565041954959593, 0.14804243110120296, 0.09255174096793899, 0.07416609809884141, 0.174902975258808], [0.016792520895720493, 0.026137393546260657, 0.037407406846121434, 0.019074484232753035, 0.06693604372201428, 0.008757616460864103, 0.04073343885641906, 0.020479870614625757, 0.0794148805641359, 0.019807978946294998, 0.031453928827578505, 0.04549645262980654, 0.029746891495080727, 0.05245167296379805, 0.01903707615941042, 0.02236402939043699, 0.02369365159181818, 0.03452431538232392, 0.016040580700181665, 0.0334584572532725, 0.08077709214581598, 0.037985339745759, 0.011799370479439537, 0.030401310613078457, 0.04090916793493014, 0.034558731882322224, 0.02977205365295372, 0.014736764170529862, 0.028314824186025128, 0.046990557738970366, 0.0368297842120932, 0.026192536555050362, 0.0806207642439873, 0.025530561894899415, 0.040991269577775276, 0.08452563696811277, 0.11448446285700607, 0.026399012572402437, 0.04616729667290084, 0.017503848855173396, 0.014303921620481679, 0.05106487762062781, 0.05846188553879338, 0.054461240332814, 0.08967465946390744, 0.015097102244204332, 0.050082163013998544, 0.04582505072316816, 0.03797420848821921, 0.04076998125040724, 0.05147422138120859, 0.05231031825044944, 0.03790604198471673, 0.024370739251495372, 0.0648443402361966, 0.06094920832002836, 0.07846847852511753, 0.04309419625168366, 0.0457070961654667, 0.023044597004510226, 0.04898780258372427, 0.09128884502476262, 0.035183162488523996, 0.06241790612318343, 0.022581879898244818, 0.05270681471654004, 0.004587991410986551, 0.06183587848359059, 0.05462723626424709, 0.020899853421254985, 0.01221287505505907, 0.04632056788391164, 0.024518862351655, 0.0690736435353756, 0.01940387331189648, 0.04223369182117524, 0.05215271864266646, 0.03398740266059195, 0.07650746197830285, 0.038442675084356344, 0.010051791773988836, 0.04942435012649625, 0.018569701238565387, 0.02056072927981375, 0.019508233639381586, 0.05637352602676519, 0.06901099286492794, 0.07051665441042955, 0.03470782025326644, 0.0143528028181003, 0.06199239407696071, 0.08869233556211957, 0.045579753200253176, 0.04153818740779835, 0.05709073754147657, 0.05388611897585854, 0.0468194481706427, 0.021855103775798794, 0.047850591025405356, 0.09748376905918123, 0.0141280489004848, 0.020555575423303152, 0.01495451604451744, 0.01603481684616136, 0.038590675610448086, 0.039411565634391965, 0.02334015181047782, 0.07531349096567401, 0.009616270789035387, 0.05771933566598643, 0.037610799359578284, 0.03897866467013955, 0.058956433598312645, 0.02269226167681477, 0.014849232581083574, 0.02484262068455498, 0.02079578803762073, 0.08293118583218706, 0.038520172538776556, 0.11021569070796813, 0.03638921087727912, 0.0497236376958749, 0.03790477027876243, 0.014928132934015126, 0.00379643896350547, 0.024297112456312584, 0.03590222027513289, 0.01660508982416603, 0.03423379185879904, 0.0349656931094585, 0.0633165234279248, 0.04775409842090261, 0.13787881921856635, 0.05480044874392691, 0.08840861489936229, 0.00929038368931581, 0.006614118249290773, 0.04187322447016355, 0.04611438297997079, 0.059539234986709016, 0.053620566088225574, 0.0525071453903952, 0.049877207681176164, 0.07013659053031476, 0.032681904567946354, 0.0307244350082211, 0.06811320676558441, 0.08844190141967229, 0.005768602329020899, 0.020150282352622, 0.03020798449494666, 0.06432308635163693, 0.04828497436979125, 0.06845694275632982, 0.061165528567207444, 0.030324661601034385, 0.02056491403510013, 0.05633301912776886, 0.03887444989936006, 0.05422064275931447, 0.013417946681710742, 0.02053283984893032, 0.05354422925701065, 0.03456764914576085, 0.021477487546602086, 0.005609997230837303, 0.026337141396417737, 0.04187805848496576, 0.08282545037687787, 0.013437777825240648, 0.04477191348409942, 0.05105933880493526, 0.05721632616534349, 0.0794974418597356, 0.026366572579248782, 0.09601478780349416, 0.06330016745074142, 0.04096700374277369, 0.015981849527076607, 0.020583361432316805, 0.023558889065058004, 0.03320165308973482, 0.026080379367715893, 0.014548086290878635, 0.04790757264521334, 0.045581476898082805, 0.05341350018317181, 0.0017350645395063406, 0.04286341609493379, 0.01723492326545379, 0.03550385072406742, 0.03698431563773944, 0.022128622062624465, 0.015796436139592723, 0.012830970114127043, 0.017394719630359642, 0.044568053657008756, 0.040536171215916836, 0.029189897693633556, 0.04847350094707743, 0.009988427684161692, 0.016506415784298893, 0.10446076927286004, 0.04719200438909954, 0.0553449533969885, 0.023488290232395934, 0.035371555000423424, 0.053703265279651656, 0.011951244537598424, 0.05571917202624102, 0.04784939592824348, 0.11765256584171327, 0.028492213760112083, 0.009979803449354105, 0.020818879842878352, 0.03410169531801536, 0.03054285684840814, 0.06617409267252491, 0.026774648464314883, 0.0564532604579243, 0.020166033120345206, 0.03596260332532468, 0.05542091867556015, 0.04069672409264792, 0.018395839499369748, 0.04764992195451933, 0.0367712052989631, 0.06081093328013536, 0.0972559498322587, 0.010932395478800662, 0.040105809833133416, 0.03823051852504573, 0.03366203745827079, 0.020580934848816648, 0.014336592397622526, 0.0050391750635519145, 0.0322996458459285, 0.03855723587255325, 0.008498282291956486, 0.06368523771544138, 0.027858538387884057, 0.017765841349178267, 0.06044237221020365, 0.012291710290517057, 0.03048464374226188, 0.06832241771682616, 0.02533134073019028, 0.03658362867070302, 0.02190936195303596, 0.01316554848134758, 0.00814964238088578, 0.0309117128621907, 0.026096695125283256, 0.041702088088758534, 0.025868400923847675, 0.058964247695140304, 0.019980379372775074, 0.0919811050557802, 0.0012466303404277913, 0.019563121923936472, 0.05292328818130398, 0.0636711914933497, 0.0379348507211093, 0.009453380386525346, 0.07743540895922531, 0.04506624063416835, 0.04783125879663614, 0.0807662136972912, 0.014436785206799547, 0.008556599777582432, 0.025325953216862776, 0.023339759190416625, 0.1062125289031575, 0.06729089564854099, 0.04541931140627112, 0.07828958167303955, 0.002972616498628932, 0.06997943525352786, 0.07172935627280705, 0.01310485516554646, 0.023314078007974935, 0.013789574976169295, 0.017786655958080967, 0.13477997824309335, 0.03802953918855037, 0.060307058100137985, 0.028770878242569107, 0.055754569118782404, 0.05589640646752331, 0.06978619723550736, 0.014287369333267694, 0.006667731955061637, 0.038302978951363795, 0.044130333999712626, 0.06847343662933958, 0.030071557642170982, 0.044167562042393034, 0.11076045583092398, 0.026706026138497457, 0.01747007586903149, 0.02808855437192946, 0.11474672539700424, 0.07764932369032214, 0.015101995630820673, 0.036775384308590044, 0.04617670040217139, 0.04770404606636974, 0.02641230036744908, 0.042937347410066475, 0.015680222516699184, 0.025511631862290447, 0.0672261458971808, 0.042368193878041166, 0.022830613325500203, 0.03152792909062438, 0.048227808888881445, 0.0225096971787993, 0.026317046910163858, 0.010029409557671077, 0.07307449941553416, 0.013906945391828495, 0.014451428977472168, 0.04519395515202515, 0.027212904383158012, 0.05019012395472777, 0.029882933388674454, 0.009865596019212278, 0.030686387251461708, 0.03079750064399935, 0.032553178814029506, 0.03665865549156743, 0.07478542655946747, 0.037406828449738604, 0.026379860374295426, 0.027108974980130315, 0.014879398250712023, 0.03255112186795281, 0.034061127131985086, 0.08582346652063631, 0.01616104228061534, 0.0316798443260092, 0.033276503710376645, 0.02837139594879362, 0.0254081774337758, 0.07363444074027001, 0.03139211510818812, 0.013532473953560957, 0.030998217595380642, 0.08575911513499676, 0.020526598147567243, 0.007620345051926111, 0.051713413183367064, 0.18706598469326574, 0.12378708384330235, 0.13754000917317408, 0.16342146232003169, 0.1773568161673123, 0.1259641678282811, 0.12995377753771123, 0.12212334005462548, 0.09909472172899593, 0.22397277606350763, 0.21108475633926932, 0.07713660402523895, 0.13043670404341914, 0.18167163786147872, 0.15107796257061346, 0.08407261853496875, 0.12132814845010159, 0.09049107936481315, 0.16067419441476946, 0.09554140675332277, 0.17331366457285421, 0.15320952561113144, 0.11279711589938211, 0.1932971446865028, 0.10406916044772634, 0.09373162362364032, 0.21677649850326203, 0.12104214484532996, 0.20532017453543602, 0.126082198994775, 0.12330858532579676, 0.12674854227131413, 0.09209067095071079, 0.15226178291824558, 0.16069202894164672, 0.25125454600539904, 0.21749936374685458, 0.10180934662780455, 0.17323140205154497, 0.08670210808275208, 0.12139636857975876, 0.11344546377057992, 0.1532518136645517, 0.15494063917186954, 0.17862430863803436, 0.09835666496186488, 0.10968957216508927, 0.11721787223171805, 0.12018542871960711, 0.07814890494750393, 0.12858727586365518, 0.1755576586771396, 0.14110323732658742, 0.11273161538185612, 0.110151952192668, 0.18378525912281007, 0.17091916483496467, 0.11754736664795107, 0.09676971382671788, 0.06000396690421528, 0.16128424555063248, 0.18451364019945746, 0.12316335803799092, 0.17624136150604294, 0.07111972648530238, 0.21413956258085468, 0.21313897514295196, 0.09895497196984869, 0.1271820407841475, 0.09048871981400637, 0.08196008511848989, 0.11734619195903502, 0.08607610699630554, 0.08577800686320952, 0.0862203000654136, 0.14517989760685354, 0.18820978460773347, 0.1716144049480077, 0.29691671111410667, 0.2118714673504714, 0.15912709517344353, 0.2313173835676524, 0.10558162485399555, 0.11419015485913524, 0.14743155259038174, 0.15247549080560285, 0.28327299161784114, 0.16296985348866833, 0.16111690130445266, 0.12875031469570053, 0.18610083648274023, 0.23096384931235547, 0.13027377246368316, 0.11382283868208048, 0.12278517873416986, 0.13848110222287718, 0.3395311486336493, 0.1136190286507049, 0.15376732955055852, 0.15291974519289311, 0.1286797733196328, 0.26364103860912785, 0.16987825052872782, 0.05418923698485859, 0.10892558332172134, 0.0979450689027867, 0.08142751611528859, 0.32748794002879056, 0.1490093872792298, 0.11753664141701115, 0.11547905182646168, 0.11896831419078574, 0.17687309293016312, 0.08711085429475193, 0.14947017384392602, 0.14425270139209687, 0.0739164836704731, 0.21657339327277678, 0.12465960436290312, 0.15927741694594585, 0.08942931214527738, 0.15722135953124494, 0.07434543162103623, 0.13195902800127385, 0.09217870977496909, 0.2154389396309853, 0.10678824397825426, 0.12968440570177572, 0.1610458543103549, 0.1218931306333792, 0.13646843602820752, 0.11445007317008511, 0.3274526693407567, 0.12452315644270952, 0.11722315057751634, 0.1435483754762719, 0.13334048371161186, 0.17038676437110672, 0.10340315424987387, 0.19137435592710975, 0.10938984026471454, 0.12736320525648134, 0.12559806973102594, 0.11263406174557825, 0.1636794194458954, 0.08050980406903452, 0.23212981981135186, 0.21052891358492837, 0.18710994281836096, 0.08793339523817263, 0.13177417098514496, 0.19567048507592372, 0.1771020306454551, 0.13902116356597793, 0.13869759867027884, 0.2400147184849747, 0.06355617105239822, 0.18894348233457536, 0.11800769355989273, 0.2034926258267895, 0.08067321062328354, 0.12679099886407777, 0.12808607816095316, 0.10672553202077266, 0.11120693187319464, 0.11954522436304439, 0.10653606315533962, 0.08840810928133228, 0.2265410858296579, 0.12665597586742333, 0.10864010831761746, 0.11170694980049327, 0.18576616331213908, 0.21890853651829306, 0.08304562404631607, 0.2087596335238026], [0.021670382740276477, 0.05341984722162447, 0.049289813595673734, 0.05457467497176221, 0.021008699193536755, 0.057886607133813446, 0.06116383551289478, 0.04796406013831016, 0.009637020280464523, 0.046691764296302875, 0.049579011787089615, 0.05029854071777194, 0.020967761370083018, 0.011580171656884975, 0.02153218239395609, 0.0514327185679107, 0.08170525363135724, 0.02831436453327056, 0.07516519166529179, 0.050884111514014584, 0.0071688324603582584, 0.054875172960061225, 0.02480147984780131, 0.025317307914637273, 0.0776820662882059, 0.07619924182372709, 0.05944723548788217, 0.0032388765811769953, 0.02786007056373262, 0.016171773257214698, 0.021466649317693327, 0.03209459283689578, 0.03205663126502787, 0.01926806699033947, 0.03448867697208639, 0.033662520093663086, 0.03289120744973902, 0.03337134156496294, 0.046167047694325454, 0.032773356313907334, 0.10471513344635887, 0.05684207689257399, 0.0088411248326602, 0.0238947305197437, 0.06242292399908747, 0.02377952238725078, 0.06010792886597976, 0.005105566158289871, 0.010927198529844324, 0.013982721063638888, 0.07524608288921657, 0.017803557772910403, 0.07420739789883937, 0.07930911446530974, 0.11914340358588005, 0.03126816974291879, 0.04937193056027736, 0.02764705024028738, 0.013239596624888722, 0.025343439173734477, 0.034756853710860014, 0.038976810737362796, 0.06172807842132546, 0.013830847963089905, 0.011653741953083345, 0.07792581248307422, 0.02224622038944114, 0.0344943881575619, 0.0233664573545778, 0.06247466174705375, 0.039911981927411216, 0.0441144721492404, 0.012828863372335271, 0.03479086035381883, 0.05824502136918807, 0.04334495598149877, 0.05566092253091836, 0.016918835387895667, 0.02662367934751655, 0.06319755380372367, 0.044160104176450166, 0.05744603762943899, 0.04064257699815978, 0.040269607092223825, 0.03188603114516985, 0.02190053662014825, 0.039816079210610165, 0.037160952530440786, 0.05017179530113936, 0.02978240924647018, 0.020873406150889014, 0.056290662126435395, 0.04755467041245392, 0.036208950388695926, 0.032425843509695226, 0.02088273518658694, 0.03814523761731483, 0.03577522204948529, 0.059915790184130596, 0.04722807563901429, 0.060869228740733486, 0.03136333701531253, 0.07615080974515408, 0.06356623361728365, 0.042349681363350926, 0.016638663627447623, 0.03003036509448242, 0.07128111822831054, 0.021799740516730857, 0.029091673730421933, 0.044784477326057615, 0.025087175102183418, 0.031818906521244396, 0.039335393512080756, 0.015199206442752434, 0.045175155354363304, 0.03127561994798241, 0.05695658405461619, 0.06178921606812266, 0.07887665017117416, 0.024122385037762505, 0.03946577018547443, 0.05582033393664226, 0.02023053772356962, 0.049705339685803464, 0.033033251642219486, 0.059876118320971734, 0.045495008554069266, 0.015322689282437487, 0.04325914264266049, 0.04378246496461573, 0.0334314679757001, 0.04597335002355037, 0.04092102314555838, 0.036275933286355394, 0.015933701858645486, 0.040476102261774005, 0.042733556530889005, 0.0513606105420378, 0.015792551116206716, 0.009054890176611803, 0.024785131531497164, 0.05751534943438827, 0.01854326162907866, 0.022478810428912123, 0.042808288407902566, 0.036475035707436265, 0.04394585619710627, 0.0602188622278552, 0.031088006930545937, 0.030106537216793627, 0.04524536348218399, 0.037777561378935655, 0.04962458252726544, 0.03132010284330576, 0.02636812582251526, 0.06349865700148287, 0.030806582616341692, 0.04984212468468374, 0.05005818063152894, 0.03791796614325816, 0.030563248193732677, 0.03391619095759046, 0.11331093107019702, 0.09462479021280043, 0.03632748334278022, 0.03470783174458531, 0.041690807444073504, 0.0948014500881395, 0.07989596845882554, 0.0282071313760694, 0.045620041764191085, 0.01672879578695903, 0.07025017072596858, 0.021608461768576698, 0.04228455239846822, 0.019757687189285795, 0.01381019710548102, 0.09628501765790487, 0.008492659206592269, 0.0631873571734515, 0.052352445425405625, 0.07044157779385006, 0.032631381069340056, 0.043454445267636935, 0.031366301775579496, 0.01350186299532652, 0.02946835916279064, 0.03999864179340582, 0.011161717195664684, 0.035353111433646375, 0.04168847087590445, 0.05125774791644466, 0.0448805294300039, 0.04651482479887144, 0.058236579080262495, 0.04711865913122893, 0.059894780222807205, 0.1389186763234677, 0.06926635295272836, 0.05826320829651049, 0.08798502190338989, 0.03742957360021049, 0.02826891062150319, 0.022995716764501507, 0.004639382025362143, 0.044212791873442556, 0.0715926478827192, 0.09149945791690581, 0.01596434058756718, 0.037569476576942595, 0.020685523087459228, 0.028376948171024843, 0.02402745142218567, 0.023942241377587763, 0.03130158266773628, 0.0283579874948989, 0.05077615057328536, 0.011662551964212571, 0.051161190194468346, 0.0160315130919879, 0.025880476384754145, 0.03733910627723221, 0.0692216900267428, 0.0190777171237935, 0.002957580107895117, 0.07400290604921118, 0.014160768515730818, 0.038647262694975065, 0.027778865243758888, 0.0481351122500435, 0.04104864190242464, 0.015045620178082779, 0.09624109017632662, 0.032739506718973, 0.04703379957185638, 0.019067928435341008, 0.012061132189457216, 0.053676819924505494, 0.0416433253145266, 0.021889594969369715, 0.023206170693400408, 0.020710376894942695, 0.020677151661666653, 0.0639692341698514, 0.010243910346029988, 0.021375094149862568, 0.05009156674326909, 0.018188076454304883, 0.04536914796898923, 0.062075641021252646, 0.07470876414088473, 0.050374693687885046, 0.024586772215702844, 0.024639540351927284, 0.031006954828157064, 0.007912478796506842, 0.060202176832864364, 0.05892327731294979, 0.05948084759555998, 0.06843205255966994, 0.0224646856828082, 0.023035097514249148, 0.05010260223981835, 0.03637084774973412, 0.021673240248234044, 0.023724143806424354, 0.06098267487100056, 0.042320673444098046, 0.04226563002673849, 0.011535670566973428, 0.06385073185928407, 0.04900811923547618, 0.02671499128243135, 0.03771316402802064, 0.01621867890559858, 0.04373762583840759, 0.024957382570832007, 0.03851150425391332, 0.1514466040797772, 0.035067701547016064, 0.0531366819726123, 0.04456513486201725, 0.02914394199427578, 0.023510083518621903, 0.019820730479794647, 0.03881815392824431, 0.05111228314138228, 0.004969518519036713, 0.04331994321077101, 0.00558544363405916, 0.03977483686720652, 0.03436014274015062, 0.031239696169993093, 0.05443767163782351, 0.004862162308962715, 0.024544160490134553, 0.05598764370886549, 0.037883649234690016, 0.04615032782537803, 0.03525069313904932, 0.04091589418690532, 0.08126697472987637, 0.05746179988848106, 0.11805047190958455, 0.06900859500972495, 0.03457388127102487, 0.03827993885704106, 0.043240197288293036, 0.03566529609323029, 0.03427824028016579, 0.05271378611665099, 0.052839826732393236, 0.04269821689494195, 0.0265820233166338, 0.05268081752282958, 0.0418653222732246, 0.05852246011096624, 0.0501650192534491, 0.016266735601088694, 0.04462053834070121, 0.07387708376852736, 0.05140548414220253, 0.04072205478986425, 0.05608634647702979, 0.06808319144071111, 0.032668409929160154, 0.058553038510463895, 0.045526414328525146, 0.04523528176510046, 0.019724199570895686, 0.028861412598240762, 0.03689103294163942, 0.04222716092162075, 0.0437086523931113, 0.027401616736765833, 0.03359101727725037, 0.1005345686609226, 0.10363300360979573, 0.052663147704856056, 0.02777171572820554, 0.03297101082881132, 0.05755597124657324, 0.018888606404465054, 0.03783834662528769, 0.0454006418435564, 0.008790389702264822, 0.05543206525485843, 0.05415857431568927, 0.02085406051558112, 0.009669290776664933, 0.007996966324431162, 0.22924670919535622, 0.1526392037950216, 0.2135221416791601, 0.11133343597213108, 0.14730709394620312, 0.24217824271369368, 0.08188208204603965, 0.11490915135871019, 0.12720687735465266, 0.10268375172369903, 0.12816898419611877, 0.10649680881009949, 0.15108372355180402, 0.13524851761758327, 0.11020418406734545, 0.18280244492475065, 0.2516380342985353, 0.12452471160119581, 0.1870270674267123, 0.15175668582800897, 0.19788781932044416, 0.1365501163226943, 0.3146130357298159, 0.14329611804456482, 0.20092391769491857, 0.14373815077687466, 0.16302283612951157, 0.14590320718144217, 0.0842085914806493, 0.13601391606273192, 0.18984970306196522, 0.12717346059939555, 0.19080214953470617, 0.1593850063340318, 0.11980687403270315, 0.09351620736021189, 0.08400757000931809, 0.09192830627603878, 0.10594336391096154, 0.1520700004672812, 0.1763298753048143, 0.23449425825909262, 0.06188459401469558, 0.17731391524355258, 0.19988246712713473, 0.1553364461588283, 0.16130609437823296, 0.1590270440905325, 0.1094718729596465, 0.1242449592738863, 0.2745877915332394, 0.10608859885964664, 0.13741247085553987, 0.17617000807677546, 0.1487496068641063, 0.12344449698444336, 0.142208824775392, 0.11215878079735464, 0.09744587068956706, 0.1264262567424486, 0.10236255403968597, 0.13115342526185897, 0.14360480551277438, 0.1416360514779245, 0.09786184877157213, 0.11291533858785707, 0.16929798489136083, 0.11760113069847708, 0.09980231884025759, 0.13805626050358819, 0.19934778372126244, 0.18573686810991458, 0.1612030861959342, 0.14369105169128987, 0.1424355408357036, 0.13554850232697305, 0.14640183848959787, 0.07700471432819482, 0.1634938423071177, 0.1521433763686688, 0.171206800207015, 0.15031547525957709, 0.1803341709197529, 0.16388614061138324, 0.12208648356458834, 0.14905617992964484, 0.07482524014889233, 0.1278098958033708, 0.12914518705539166, 0.13845730753194901, 0.07591847826035754, 0.17684900712582374, 0.16526592625004632, 0.1271832052377924, 0.15426456657869203, 0.08737593603831145, 0.09500338320410061, 0.06963864104041169, 0.1629169781001345, 0.10155355753076654, 0.1565507414840883, 0.15601630322635174, 0.16778021149577635, 0.2107174631448523, 0.13769048416326124, 0.13076802174891197, 0.1507159094175985, 0.20839388782699264, 0.10913675545804924, 0.22705741376886446, 0.22008742325969283, 0.11101938588845153, 0.1481939020055917, 0.17408647874910987, 0.11302832123492995, 0.13397707213317195, 0.18409040726480946, 0.18528683741967525, 0.1812626235187054, 0.14976309522265388, 0.09141612287250259, 0.14599313058199423, 0.12720791157335043, 0.13347237340865598, 0.08358720990438616, 0.09533064064359474, 0.15509673724732093, 0.10204547024782627, 0.21887757124439364, 0.11503301245430786, 0.1695158449752677, 0.1730974439171053, 0.18701629623049693, 0.11285292540466595, 0.12937484489333245, 0.18898223106178547, 0.23615830848293923, 0.19358237454247093, 0.28473851781698967, 0.11838991014707474, 0.23018170418518208, 0.12978218916443088, 0.09856821248127569, 0.12310610828740944, 0.14665948918029187, 0.24387102123470078, 0.1644077852007843, 0.1469962154665301, 0.22160332740074207, 0.11159015203555746, 0.1440761640908257, 0.1660144554391023, 0.15187202802588864, 0.3148519938751575, 0.06664046401818914, 0.13590471789000497, 0.12532490575986524, 0.09829026046058825, 0.1581585608542927, 0.21795861813570225, 0.08220955399015258, 0.1908094580135038, 0.1993927530824177, 0.1363632674779623, 0.15670238092782038, 0.07724915766307423, 0.11877411856285988, 0.15346003636237115, 0.23000463062236387, 0.1730248187818835, 0.09359041829743693, 0.15841285607987837, 0.08409295050847916, 0.14122927411189004, 0.14402647562805684, 0.0902347999715036], [0.052355352729078264, 0.017276048780448975, 0.06713231544821494, 0.09762206325127233, 0.024936887803637696, 0.03854467203059504, 0.01150349008610412, 0.029738368766923106, 0.07106316621385275, 0.00633482365951603, 0.044137236451910394, 0.05553182905479785, 0.07854982940179688, 0.0234790492968093, 0.046665621545886805, 0.020787131244076357, 0.0284183724603105, 0.007782682913520764, 0.02111272052711537, 0.014809996430431644, 0.09013474888859258, 0.04596349813284413, 0.031616779968082424, 0.02716196336663298, 0.039452704555925824, 0.01152219986843486, 0.046798913183832364, 0.01779922746091841, 0.03562679251415595, 0.09546257630591432, 0.05004945105963177, 0.03427166341533584, 0.06070599455626742, 0.016483389096514835, 0.017777003250235034, 0.05867796829871594, 0.06445462364823588, 0.040095130567468946, 0.03585248201664898, 0.0435697683133185, 0.04759335785263008, 0.029850439769366098, 0.020642694942052328, 0.05629515906255092, 0.0428456811594867, 0.004233137090435071, 0.04728729423556117, 0.021594838810063178, 0.0489856613679759, 0.035539887500025576, 0.0674245703304487, 0.06876012205236381, 0.07145990016719989, 0.09464047203261046, 0.019631629336565252, 0.04473594948649407, 0.02538203851379935, 0.06995601594568261, 0.04045713392476882, 0.018879348231900125, 0.07927276359330263, 0.03692333886940633, 0.017990121249890616, 0.02682342336723401, 0.025297240241460746, 0.022419626306321834, 0.024775492230189905, 0.0471705386054612, 0.06422742495253202, 0.09628585269374233, 0.03082706589221714, 0.005071398636866962, 0.045185915059259826, 0.11739565825630581, 0.03458488995449678, 0.026440134256958004, 0.005539912634694408, 0.028148330297441255, 0.03494811139159626, 0.03604352519276642, 0.06874915167328811, 0.04434125332702552, 0.015339498209106106, 0.009106752413865781, 0.07802899686559554, 0.059722395118085615, 0.045459347161194014, 0.049029190483833515, 0.034498762519609545, 0.009142728860399896, 0.04463937644275927, 0.03344991920335639, 0.03767268394210166, 0.03286944672224983, 0.05247939002489852, 0.0536809912732532, 0.051909140987141486, 0.05952387492382719, 0.01825002423908201, 0.004188571840659866, 0.011652150405420652, 0.017921688530834454, 0.06228097556759754, 0.01897455572390989, 0.06130221780509718, 0.05389931484035427, 0.03232769232483641, 0.12278088098091465, 0.038064005484263745, 0.05550352210599569, 0.03915723593484971, 0.05827919655149022, 0.055803219532413836, 0.038143693950147405, 0.012249377229431225, 0.011703336570081452, 0.031625756603335185, 0.03603731221970051, 0.12833278911608842, 0.054764764368413925, 0.02714880963697309, 0.015527119845031731, 0.04521997149793371, 0.030677531275057027, 0.02667639960324572, 0.0411131005403736, 0.013716062136565246, 0.06339211332341356, 0.017477395839147994, 0.006399259793632214, 0.03672096525288878, 0.03225410957970927, 0.08705974856932318, 0.018981050234287977, 0.05726591120624254, 0.02047313478655152, 0.04692257509656972, 0.04335353999669033, 0.03154431571132474, 0.021546180735552506, 0.042261922161184975, 0.022454927637872678, 0.10596358863216256, 0.023394494257386655, 0.009768588220580451, 0.03939608682788188, 0.04220055851845011, 0.05004188977181912, 0.06064739266049959, 0.00921159250391347, 0.10003396084592228, 0.029295052837340102, 0.04729702355219953, 0.012970490046897003, 0.060721477193217126, 0.01841529813264647, 0.08700182466136833, 0.05707517063485519, 0.00825099102521856, 0.037782196210877556, 0.05215386777455288, 0.011571655631996693, 0.015730378293101827, 0.01574489182882732, 0.053665171557616805, 0.04575549377008312, 0.17160254590693982, 0.09185745080392207, 0.03537083104733498, 0.08277205404855552, 0.06544453948135338, 0.027407251313448917, 0.06318305175931704, 0.060539918185602275, 0.030185783266901012, 0.046731842186061606, 0.1316700136709598, 0.04784273479374186, 0.043653735380259254, 0.05029708132027619, 0.008628980722278357, 0.009751069704971967, 0.05257893932021914, 0.05266987012639161, 0.007564354558370167, 0.008523507652083233, 0.04809549018259972, 0.05497756827202055, 0.010905943420385162, 0.032007115172042, 0.017325884715143233, 0.012781679059468932, 0.014805749430501414, 0.007929714338388294, 0.03921935800462961, 0.05450932001094184, 0.056076073237965186, 0.05304767021669015, 0.04502967908798207, 0.023360169687939268, 0.05382579721270069, 0.02137383776566675, 0.06915843414683497, 0.019838348586833286, 0.04233273166802622, 0.011383991861235232, 0.028783263969084913, 0.011370471366981586, 0.0342041289343709, 0.04867553365446868, 0.04723299392348817, 0.05073662426683211, 0.0737900025541744, 0.013616163313629167, 0.027722862301274177, 0.043910972383474155, 0.07322035489543792, 0.0388384475973585, 0.025312000840541818, 0.018873058650041782, 0.027032856483973806, 0.03446842160736842, 0.02771489881730128, 0.04474162619801299, 0.032830042989864465, 0.04559497919774825, 0.017745065044671778, 0.07744538342399944, 0.039725332265539516, 0.04187129009815474, 0.028234101501443697, 0.10290463019402758, 0.029069639126499815, 0.026830534578391144, 0.05177283479321388, 0.012765734854544844, 0.03241927430574452, 0.05480083178788905, 0.03273528940494984, 0.056998672925176165, 0.04290876466961157, 0.040512035615862384, 0.004592228834817727, 0.026255175734179157, 0.015366321820164881, 0.036973954298563545, 0.01598721501537629, 0.017667636538164753, 0.04535751875429865, 0.05709273703095894, 0.02390778848841306, 0.03392579003928169, 0.005876638920932648, 0.011334841575233207, 0.06767187883416492, 0.029036727989272728, 0.08137244971529131, 0.06204436548174389, 0.07278199938516464, 0.01566174639118535, 0.05016942425901371, 0.03043763850244784, 0.05663678448106493, 0.08293903057253169, 0.05000508307749706, 0.033695155439237436, 0.014439192638101598, 0.038045944961448835, 0.03670733271827621, 0.04276576669766538, 0.042912284843623645, 0.054953103254158656, 0.07663457894757872, 0.09207432263440664, 0.03469853526762417, 0.042431093527064215, 0.003831960784737021, 0.048167483295283975, 0.007295947514414307, 0.05279530553267368, 0.09213708055716369, 0.02596950537765459, 0.04168487409309995, 0.04623090112281423, 0.02078107531903492, 0.05063368886288616, 0.04055325114618867, 0.06153073800247043, 0.026592696836638837, 0.01971413126035083, 0.008000560234405943, 0.049614588910293196, 0.018938331256410288, 0.04929872702867274, 0.04211716984789218, 0.05125450353408533, 0.05222199597365914, 0.031687353902886954, 0.044165076087078745, 0.02766674444560082, 0.01144469188030569, 0.03931868130401258, 0.07922954857349396, 0.1297814383982651, 0.06721504528315798, 0.11222992738288258, 0.013304032280199952, 0.03491559478965017, 0.1212194252518877, 0.0300313456870255, 0.02582025995868589, 0.02228572179803685, 0.011091843273700967, 0.05338135896430862, 0.006021031651705985, 0.04448572601822596, 0.05525688775965283, 0.020758535097082777, 0.019955081234295523, 0.03590380224669653, 0.02499868045561016, 0.03442182430937406, 0.013192374965236073, 0.046129011428884925, 0.01586456050825936, 0.07217805397005812, 0.04418677935797361, 0.028309235574617505, 0.025443563034998316, 0.04965045714690801, 0.034506890712486166, 0.015553738527570762, 0.08012969422364428, 0.08574018510238779, 0.009359540361460418, 0.03263329628915076, 0.06180726126917909, 0.05676811110348471, 0.05973979297484602, 0.044508995938925974, 0.027296241342781052, 0.08804636256348702, 0.08535323409183372, 0.05064362502326408, 0.033516990201127146, 0.029612337727279916, 0.05946344973879957, 0.043822117675576484, 0.04086603718479315, 0.03008084262781326, 0.042121142013779575, 0.06658234858825322, 0.2766583739749847, 0.13914928411043462, 0.1613664314631493, 0.16896012479499464, 0.0835949856968176, 0.14530369741541727, 0.14941561306195875, 0.08727134971488869, 0.15648286609399706, 0.10835867825775378, 0.1446225379984225, 0.13429479943888803, 0.15752050154391797, 0.1251230339309381, 0.08920743009976803, 0.09356998673249638, 0.13694431452501205, 0.07668104218018633, 0.053508594677212744, 0.09609289046737457, 0.21136598721627267, 0.18532206214243369, 0.1591596232667085, 0.102832326815734, 0.17044290329419798, 0.09246364085664673, 0.20467525107725976, 0.09540922594286742, 0.18293602001522818, 0.1707375100663593, 0.12733399432392853, 0.06604653903313222, 0.0981041547211428, 0.10512048588885416, 0.19101861533859085, 0.2275864434458556, 0.1528416961551674, 0.18377145421841454, 0.0916727546662573, 0.08217124193305932, 0.15022648648629267, 0.10089190271232398, 0.08532829792989839, 0.1595471718258435, 0.14394246642628025, 0.14353348272702388, 0.163922070135032, 0.10987272080514701, 0.1101376340093632, 0.09265605149970901, 0.2408657502382994, 0.14659811021579852, 0.1528962109718592, 0.15849087447408708, 0.0845569086771819, 0.1318742986768484, 0.11894513237019701, 0.10708390795175107, 0.1906749789392756, 0.042290079722841906, 0.1728167799451659, 0.11652930474449551, 0.09845893003887708, 0.1556404911342167, 0.13027922700970404, 0.10648389256769612, 0.0858250216791226, 0.08555719734079416, 0.11883877638366916, 0.16647686611019796, 0.1403536815797129, 0.12127338082439477, 0.11923711912165727, 0.20953358151018622, 0.12372984941447936, 0.09899895307758162, 0.06188129600618155, 0.09711016330026812, 0.08623485573597493, 0.10797162765576955, 0.23884764481936735, 0.1252795839982648, 0.1448244174882289, 0.07720837880286478, 0.18814981524502078, 0.2297656571552638, 0.16881769372811242, 0.15651237580084032, 0.15732922471098362, 0.0927442282197937, 0.11445131423252244, 0.1324818523660783, 0.145866664787454, 0.15799685501523558, 0.1309506877535774, 0.08509897717064427, 0.17388202520387788, 0.22073528849549834, 0.1047998091446296, 0.17464409882743515, 0.0977013763340731, 0.15419022540651983, 0.11987569937182051, 0.1562706290954544, 0.1493039787296326, 0.17022295945113705, 0.1480601890192878, 0.13792073954978298, 0.1114753997253795, 0.15430325401886819, 0.23973059179561756, 0.13936354358109737, 0.11727841616037393, 0.15331397403872785, 0.10994388271243342, 0.20538147689113695, 0.16516930724103607, 0.12921378256813174, 0.16195667156529042, 0.12107554627882859, 0.07761306474886595, 0.10104888944976753, 0.18397417640493763, 0.0839965996302424, 0.13053421171442156, 0.13012210237643412, 0.173722188619356, 0.21979963467005761, 0.12085833736965734, 0.2864929204506259, 0.12837872374802828, 0.20583944425227182, 0.18534357389134748, 0.07725422916513297, 0.13215269502853194, 0.11336821912517471, 0.10691569802621681, 0.12923155580797505, 0.1246208020095383, 0.05846855433417424, 0.19744863643521265, 0.09297142691549756, 0.21633760673144173, 0.16013033327556428, 0.07271053870358775, 0.0903070497236425, 0.22542374659209485, 0.12556624643865133, 0.14534785472337278, 0.19437501507420696, 0.15509221732856768, 0.15755851482672079, 0.17236411391246706, 0.1138014724898723, 0.12554051354527473, 0.1091966865163657, 0.19465803859695313, 0.17411408855790095, 0.08554820346856311, 0.17576225011819796, 0.13611574446962726, 0.21757410328474738, 0.1718932303089288, 0.10388248014233767, 0.20281071564362896, 0.1255973802518941, 0.2563885761605155, 0.1488599848122366, 0.09986456348410538, 0.26832781131229094, 0.18766955472528937, 0.09765282168143219, 0.13082275107022256, 0.12850869056438247, 0.09200525214715351, 0.09657240788181944], [0.03578397843445982, 0.05792149094744556, 0.04056362780712305, 0.08170735271226975, 0.044504391750501054, 0.033358865823116035, 0.07974045261019662, 0.02133204958461706, 0.037233815152919104, 0.017255373982592456, 0.09247135536204423, 0.04901492209624379, 0.015886104815909942, 0.012320814928370378, 0.05246635120842726, 0.015838613110263983, 0.015857471322130053, 0.03546264285462038, 0.0509186199445638, 0.05481832157520037, 0.02603275934234262, 0.05627005436127225, 0.014402117813006045, 0.013211097196495582, 0.019598193429110032, 0.06787712911083814, 0.029925079715828744, 0.04252187494609145, 0.008733659933861947, 0.044434126166086045, 0.013663190578471028, 0.033157005485507755, 0.015235993984876382, 0.014258843091797205, 0.10110938741314797, 0.03165603622854237, 0.012986699509764872, 0.039900360373599876, 0.054408407079116, 0.07609017388594728, 0.09857121554593887, 0.06745850036461508, 0.05297601418269258, 0.022642749414268522, 0.0223659101362911, 0.025056868663898883, 0.0576845744264222, 0.04724216782638142, 0.07382176455951507, 0.043697969297007214, 0.03805785762867139, 0.039229167760500026, 0.04381977727696781, 0.028776803932663415, 0.05524210992359346, 0.058498087023655256, 0.01227121648093265, 0.03487754703289078, 0.050502917654211485, 0.05609668100312833, 0.038499763956473726, 0.07076981582588728, 0.11656512701583487, 0.06498991992444762, 0.027516853597555912, 0.011080358658106098, 0.03736489662720311, 0.07760577925270604, 0.03769360580331376, 0.033904469812348965, 0.0400963563081478, 0.017591908746849627, 0.007265120136341261, 0.048680409804106727, 0.04950782306672585, 0.05429293847672882, 0.03745893008946892, 0.04389149459799932, 0.03917481382227233, 0.08983142403585297, 0.0455806342013661, 0.08601701097382654, 0.06570555329803499, 0.016771962926272425, 0.09733537016736885, 0.017158544299403028, 0.018380517740884138, 0.0523280110510607, 0.046386474428037484, 0.044105953251522396, 0.018165572621529142, 0.032126607651251464, 0.11128753964458743, 0.0490572676062584, 0.06150772855166466, 0.023694528762491483, 0.06734023171086466, 0.011670342120792598, 0.008274312656853468, 0.02124579574522232, 0.023971163111949162, 0.0548193826069755, 0.05551538114706355, 0.04335286200887734, 0.05570874173915195, 0.005651711197119327, 0.030109180220132394, 0.03157105984076137, 0.06197165224641081, 0.026635496253748576, 0.03658722928394714, 0.04277900469699695, 0.037904858378873724, 0.006951370742172004, 0.02731753092619681, 0.023914489842530702, 0.030915681197638475, 0.02078151581959138, 0.05613878902588641, 0.046502084756690654, 0.10417343267510015, 0.041042704721011465, 0.04582627646384701, 0.06362162560464875, 0.05639262076827788, 0.025533130204665567, 0.05713264638137433, 0.05325010895068127, 0.028835614587390618, 0.05061213880957616, 0.028775273672034665, 0.06306453795743085, 0.02793441748156423, 0.0006040353107363767, 0.0782173395817799, 0.019600556810356436, 0.019692621426656842, 0.05008608921461048, 0.04352684440692106, 0.049421649666563164, 0.07571026322341735, 0.07529063090201348, 0.017548373885332577, 0.07625218616017411, 0.15192121087062746, 0.03672493741877618, 0.026244134491970463, 0.058667530350747614, 0.03689248467825594, 0.02147444426232288, 0.047088505910529245, 0.009880469616262183, 0.05311936072464432, 0.10042212993627596, 0.039764103975387356, 0.020046645978225336, 0.04953983405064191, 0.018634412685529362, 0.054614572830858736, 0.04662045683231085, 0.011799652974361615, 0.0035082235192549567, 0.08732368884187552, 0.022047196492372502, 0.05910211670843344, 0.02339027311292387, 0.06262884843313406, 0.0650383979682961, 0.09291508880954596, 0.048715546426753846, 0.03087641536107948, 0.08054037863809256, 0.009789414320802017, 0.03737574443221092, 0.011312136644377344, 0.12523587102130537, 0.0665539573697794, 0.044957042461441415, 0.04818410740324086, 0.03423738098072429, 0.02527285949327052, 0.0282256726190568, 0.03825852669955742, 0.013823117178324011, 0.02778288912058117, 0.020662618973743052, 0.02739279140387812, 0.0353292056599692, 0.007216755569266577, 0.05644477220372327, 0.060385528486222036, 0.0567432860242984, 0.05487297428771854, 0.03593001777546541, 0.018887926501432256, 0.03743278733905285, 0.04443421809663696, 0.052492578228515004, 0.03254486676005106, 0.0467947494959639, 0.04954158456154889, 0.040282573130342274, 0.03729566143104627, 0.040246283545369105, 0.05784110151111119, 0.10694752131859142, 0.04448848010431375, 0.07481361093420176, 0.026721654332152782, 0.02407959328153201, 0.0484798671377282, 0.015889114583842456, 0.09818195094985348, 0.03389579003616687, 0.050208364508204886, 0.04808777567720221, 0.02158517269567857, 0.019547097279780337, 0.03154339257537598, 0.11836135805013681, 0.03398040444740365, 0.017674671140529456, 0.02145729538413786, 0.024611212335707202, 0.07228706062080399, 0.004926157942522438, 0.016888825808681788, 0.04006908357804341, 0.0202454419641365, 0.0483695121722356, 0.05143236616746553, 0.027778987817826773, 0.010637821265376143, 0.04072324988702613, 0.028373864667129614, 0.03143705957148585, 0.04093948586453353, 0.007735040863119667, 0.04178564146822018, 0.03083913177702456, 0.03683960545928248, 0.06960640406055797, 0.04720317012059593, 0.04888038173498166, 0.03880128467215165, 0.037696199010937445, 0.05888652424478243, 0.015812055714758896, 0.0213947864399562, 0.01958081855498735, 0.015017304610791466, 0.024038423716481176, 0.042987510847348365, 0.00808860911356826, 0.06418766115882224, 0.04628596752281151, 0.07183749724419848, 0.08041867791044136, 0.007860166003792397, 0.04931448162683556, 0.026202049451850118, 0.04889001146018986, 0.01759970943713861, 0.05552710229230504, 0.0809835605022888, 0.048697845965263345, 0.021211804424021995, 0.02244141001644875, 0.06492146996841316, 0.045006447471678264, 0.00939219773206259, 0.07921948983904817, 0.0038682826890444927, 0.04683362845812113, 0.026515281736670483, 0.07769481399126592, 0.05043296233540581, 0.024220390665915706, 0.057302955387821125, 0.03980176102730536, 0.00976720255904741, 0.14769335547762533, 0.06954464205210248, 0.034761760504015034, 0.04109697055912787, 0.05120706736981388, 0.038179765200062145, 0.033091022332589475, 0.045218956431434046, 0.020680288791716583, 0.013593896968109954, 0.021478688389423396, 0.05454108201628251, 0.05500143957174113, 0.043035598186355446, 0.009447533220443274, 0.05559551777438291, 0.05868522698179849, 0.05235618776491573, 0.018978717496558543, 0.08456907415341947, 0.030159627109946265, 0.0557922070185023, 0.03877375530259263, 0.0616760763730253, 0.09614991039157876, 0.03363557295092652, 0.0350594929149074, 0.059089231109547044, 0.034990962519640886, 0.05642416826899975, 0.03590492073506598, 0.04451260804348896, 0.05291195391046424, 0.006648986262359447, 0.039210754837239944, 0.052248521768037355, 0.03174682722366866, 0.005795447007497592, 0.0370257226900468, 0.04912832609167503, 0.012532851786442823, 0.050997653405272195, 0.040837527222691045, 0.04795095620436534, 0.006975117073799934, 0.027663664772145213, 0.022300093607496352, 0.00967709338217373, 0.0286175514901838, 0.08918791017945736, 0.017593797153582977, 0.019629961180110133, 0.04488531747953065, 0.04317883364555817, 0.034192549515395396, 0.06309232779688413, 0.020997709662262953, 0.018832484718352076, 0.06492595924364944, 0.0816715993888436, 0.04786657928038509, 0.024462803867795778, 0.05556346848607064, 0.08273833085812869, 0.021740113978364298, 0.0032718583421346044, 0.016139827390772202, 0.022707307643647638, 0.05372125685455338, 0.02320650011120785, 0.017978647168004708, 0.1496330901019035, 0.15109978075469696, 0.200078095339479, 0.20579187019217401, 0.11551764733608692, 0.12247878186885389, 0.20251669109829012, 0.11298902092441437, 0.2163062277700632, 0.13971392155414628, 0.17262026307082948, 0.07399893005288417, 0.14692809492830308, 0.11825697090957435, 0.12778819253247592, 0.09854715272423722, 0.23223003943360623, 0.10462279686884535, 0.132598236443535, 0.21183820381279916, 0.10310655564910944, 0.08966401084175996, 0.17528522248950698, 0.09979147103524978, 0.09662198143139963, 0.1982594638942711, 0.1342309536712785, 0.2108330658126262, 0.1220701352482842, 0.12605392268948978, 0.09594437666237356, 0.18139100453305632, 0.16009362234223276, 0.15248834576097228, 0.1602008899733905, 0.0962249257211243, 0.25897930165933025, 0.09564948643768027, 0.1807637623841724, 0.18045185734668087, 0.16357236631935643, 0.13323811904316948, 0.18927216469760866, 0.1963028446921418, 0.09513608495434446, 0.12455118759985893, 0.14462491287098778, 0.1747488077249258, 0.22427309785158406, 0.08782718480835039, 0.09276795396280867, 0.05361387814064661, 0.11925857724441637, 0.16962176429167872, 0.13549694460966896, 0.10789917872077036, 0.06954649598487923, 0.14713518381599458, 0.1558943267070478, 0.09895161650474034, 0.13282194943918338, 0.20217466348361587, 0.24342898850239095, 0.13762296117361517, 0.10517035055184558, 0.19317265539880724, 0.2063089182540294, 0.15851578765338467, 0.12377800570139963, 0.1377736813118381, 0.06370204185406048, 0.14912273764850634, 0.07083570704825463, 0.14746892235932813, 0.1668339550134636, 0.11304116852942014, 0.16541410297636064, 0.15367032749758613, 0.14858567937006875, 0.1944734420507185, 0.20623952600984805, 0.14425031119777312, 0.11829929726739084, 0.16908066106900094, 0.16351973607895837, 0.15405102723067807, 0.10679651006695726, 0.16256730492797591, 0.1333832160960282, 0.22025561020258935, 0.061168826575721466, 0.11829272423300052, 0.2071442758484233, 0.1751640427016443, 0.08799582374312225, 0.15647094576589524, 0.18455078014202658, 0.19009885017669972, 0.08815373744695418, 0.16588573734606468, 0.11470745573000563, 0.11976444042257725, 0.1398760717241995, 0.17310317425477892, 0.10261140238012999, 0.1309139461767289, 0.19879980102902461, 0.19204069920364888, 0.14628258924330437, 0.11441296387103297, 0.10341381053290061, 0.13520535622392932, 0.170109118785589, 0.08788756785854217, 0.16108650293561722, 0.11658613314671863, 0.1902922107687881, 0.17616662196815017, 0.19818423406010677, 0.1415832373764246, 0.22692403786124724, 0.14062581133217583, 0.1330857441550301, 0.12247404744548183, 0.11997388886107553, 0.11367447809466433, 0.17247918031869397, 0.10032011000739952, 0.1784811727702618, 0.17190000252617946, 0.06676120713593499, 0.13078453860455944, 0.11855324009253133, 0.18076861938161237, 0.12805792442973585, 0.1604001187989789, 0.1083554070623171, 0.14506086286517883, 0.13209494732079968, 0.17038362341061716, 0.17653765367163768, 0.17471447166415954, 0.14969753341809397, 0.11171987370377588, 0.2877634619512866, 0.10039030664390135, 0.09228089824318887, 0.12480739038437606, 0.10554910442160984, 0.08643851254976566, 0.1263989840123442, 0.13705145958210194, 0.14700979054454835, 0.15978685009383387, 0.11489346187802092, 0.1569422277351541, 0.10625958202346679, 0.1353492122143507, 0.11502793329136987, 0.1766525055732458, 0.088919457649031, 0.14122202692012634, 0.19831618504418483, 0.25168836627516056, 0.15245047037399587, 0.10480958442654341, 0.1883557243573089, 0.1989100104378116, 0.1487503269867551, 0.16177241209774249, 0.09273568633943798, 0.09291173334443763, 0.08075112942606211, 0.1510399952530861, 0.13065635677306883, 0.1851199681480085], [0.031223349768908757, 0.026470955889371615, 0.018525903991934274, 0.035774138035072435, 0.050494084660444534, 0.022997172331557642, 0.016163491846753225, 0.025375634018752365, 0.02077807033915193, 0.010367017802632144, 0.05548198354400455, 0.011526760964414046, 0.017090289695789258, 0.0014819106652266198, 0.06738663365643832, 0.021053877313651388, 0.027660043091483177, 0.02308683717743524, 0.02772093942058423, 0.016697748158607754, 0.036107742513019236, 0.018234819309004856, 0.06367861105489635, 0.015569199139492647, 0.05230307105868574, 0.050626855358601584, 0.04737049138413803, 0.04492377126288991, 0.04266468139605657, 0.0247237678887623, 0.05719450032038074, 0.031023121198579192, 0.015362057583256355, 0.04063162194084256, 0.05500375315727246, 0.02755855367849431, 0.03577949298966316, 0.042803389275626796, 0.10438996742689803, 0.02442383489030744, 0.033571340308915225, 0.047152769196057515, 0.014693896763116844, 0.051275708847829414, 0.05373873515054584, 0.0372856448314363, 0.02012641679856085, 0.027371254757106788, 0.11124614791403856, 0.003479422204339156, 0.01734530121358412, 0.05458772910999195, 0.01810350226268413, 0.039546994657646266, 0.028556779650370442, 0.021790511072463086, 0.014198686995152986, 0.038133891855156234, 0.06174428118092399, 0.05875720477272427, 0.036986514310082125, 0.004630674957297742, 0.017386013041100195, 0.04767123069013319, 0.0387823048438276, 0.041705347792876345, 0.08344765166721999, 0.014013898926937293, 0.032657228875905275, 0.02442812498268341, 0.0548178427702477, 0.018532084406263406, 0.010124477238634662, 0.05792304227549223, 0.03351833085499464, 0.027646184560932943, 0.013144809523627404, 0.028296629597823468, 0.03937183631463878, 0.007332388880557471, 0.06651038994952556, 0.02835962117739743, 0.09008990210150519, 0.06404794587363159, 0.025553230436578877, 0.010571645632866892, 0.10827734270283293, 0.017626894067131707, 0.0897547769390287, 0.03559047994654506, 0.06865182020250829, 0.07639319230351718, 0.012973615685628067, 0.0753682739131393, 0.07041570700464711, 0.022803915161339026, 0.05897406511188996, 0.0377880567834983, 0.01498660076439621, 0.005631035920457855, 0.05851660719922474, 0.038564720551573464, 0.055121596632224906, 0.07177563564431283, 0.05347703951561163, 0.021700853887464733, 0.0471133922767495, 0.03482151153166929, 0.03809070364842492, 0.005652807660460953, 0.05323158877511179, 0.038742678945944194, 0.045900472079313574, 0.05806252390386597, 0.020691850973713784, 0.004580639360938221, 0.08665998856867514, 0.04956960805781907, 0.08847064503859128, 0.05138337867514742, 0.07167542368293771, 0.08713245797421663, 0.038411047144402424, 0.093621498484525, 0.016736765016591357, 0.018625880381272688, 0.05495421408164886, 0.04418703982786787, 0.05491723501754384, 0.0641691103397358, 0.09779610310591037, 0.05833529717018528, 0.02718180887431147, 0.032137943837311, 0.03255710118420182, 0.005833026971818219, 0.02429043791527229, 0.023260028589697137, 0.0004865926853052506, 0.11395830600973099, 0.017927403546749585, 0.020477459352884083, 0.0047660154016358, 0.05695763742551208, 0.06439743518468834, 0.011013876590427133, 0.009599285662144182, 0.020857871803004416, 0.037711551412940025, 0.04044326390289972, 0.04656288149436155, 0.006743297431497805, 0.0861944905632446, 0.0528509694812519, 0.03589630990679707, 0.021226994032340667, 0.017700942210672845, 0.0036024477852944045, 0.05156661924575606, 0.05180432483734143, 0.06418735472365253, 0.023993222613728816, 0.11488921775092041, 0.028958431888191454, 0.011023356928490104, 0.017540611499439807, 0.06811552035111575, 0.008372984781500795, 0.020832732627769152, 0.04147185568487452, 0.003496266562574273, 0.0695545782124804, 0.03444242441365796, 0.03428870121077184, 0.006528737750129715, 0.034200398086179654, 0.021183639201485825, 0.08036008750599238, 0.017719981410811027, 0.030310753274769075, 0.058673226214464635, 0.018162483371974483, 0.026242768940245433, 0.010871212824337907, 0.05576299991638911, 0.045213620629041426, 0.01984428002258703, 0.04828196747468845, 0.03396751501807763, 0.02515623984377711, 0.07662104983483592, 0.013865524932982461, 0.02927646179863763, 0.015077966325465712, 0.07155700947248167, 0.038598401607164455, 0.06340299943281759, 0.017931176529776667, 0.08934683511934935, 0.06329907960588894, 0.06561474123549077, 0.04336790031483097, 0.015344040152887184, 0.04020797148827584, 0.03989137416224807, 0.01998651190660894, 0.05896902808378782, 0.04482851205994526, 0.029619605986461527, 0.053552522158790986, 0.07551334032248105, 0.060132225344498316, 0.037540212018235077, 0.030191973257329197, 0.03597961430768332, 0.08777928899132437, 0.06325315646526795, 0.05793330019279834, 0.02597759335091518, 0.03074656537313375, 0.016878657906706777, 0.055978469805972236, 0.058146429683772795, 0.035965342089653976, 0.03157913057704366, 0.07799950248051075, 0.05856212431324586, 0.0074389268129673464, 0.059634651237678145, 0.025537190470664252, 0.036442070944054474, 0.029803947808461326, 0.057566010828820936, 0.030461950302724878, 0.05009333640637417, 0.02245452161127281, 0.05624111922037217, 0.06427888307840594, 0.05720797580696883, 0.01626627977877375, 0.026859802967538277, 0.02937165588410872, 0.03228909298477154, 0.04121971699679571, 0.022328325862725897, 0.008661399648014096, 0.05762736681067656, 0.033054644647505016, 0.03726931949776988, 0.0411066768931285, 0.052807068812751004, 0.012842530380904436, 0.030149079994448734, 0.026749266056163658, 0.053092279516521006, 0.0751152963587834, 0.055527650045170907, 0.03820115437490806, 0.07452388414211812, 0.052316722745496425, 0.061112273965151086, 0.04072973099086554, 0.07696154527366161, 0.02362897078837118, 0.06136751147888361, 0.0394263549617702, 0.04241333943941901, 0.002215329966988535, 0.05219045230337689, 0.032065280397693, 0.027335227557247686, 0.04563927823196977, 0.04001926104988783, 0.05536934946693721, 0.01716892670599684, 0.05301905300227865, 0.009771347094717766, 0.028512494022687598, 0.05093542408318289, 0.07115876632592372, 0.008287274864532294, 0.08207318267875141, 0.0749497983845011, 0.04262052408810105, 0.08121224540856578, 0.0035753215695055384, 0.052270765130918835, 0.01193913268751555, 0.03532788415829982, 0.04400279185163879, 0.026375574112359076, 0.05061394294663783, 0.12430780912719427, 0.041025766517005624, 0.06037951852645605, 0.00259684247148764, 0.019002833944414894, 0.07305935385727114, 0.04300891151351314, 0.07180029601459542, 0.03766154502368262, 0.026774223285516905, 0.03111438333777891, 0.048174481508472276, 0.04634070450500135, 0.054821144609201344, 0.05107503594650377, 0.050001007489739895, 0.02442985059573285, 0.005562268037934818, 0.034912702807736014, 0.048386710846135696, 0.05125790113402952, 0.009069033117303926, 0.042829018747133595, 0.14725055665739123, 0.017619602825312365, 0.05242462622963133, 0.016712357455323783, 0.027026658832666375, 0.022976725444858594, 0.03570787909050142, 0.04121057756785904, 0.03608861329754995, 0.049217628961008404, 0.10027129488486437, 0.012688967098872508, 0.018728237388835802, 0.06332872337811897, 0.031325953839827454, 0.060141920187180085, 0.06593190929702213, 0.05147006152377975, 0.03291601337672722, 0.022779239469297954, 0.023328532171886296, 0.09442299499266571, 0.03138377432591252, 0.09371535191612859, 0.01558223221030447, 0.02467269089163071, 0.023925724521940275, 0.027925641944391594, 0.04794261350686993, 0.06373044073341355, 0.05895701965557472, 0.04855901168118562, 0.05446040529697653, 0.04343373791104363, 0.07573807221506873, 0.025306931253702893, 0.008510518631327057, 0.1087865153808267, 0.2128941487641104, 0.15056197171009358, 0.12156236451119186, 0.11659981547704629, 0.1318008614884269, 0.1519767369233793, 0.11371600006016032, 0.12094041602986476, 0.1079137190695732, 0.12308101124701001, 0.18676143409984727, 0.15854636988332196, 0.09349257354774783, 0.14240673592975064, 0.12166113622726933, 0.1338810966380181, 0.139798344443402, 0.11001243225989804, 0.09942360327488954, 0.14802545459280092, 0.10707070825681572, 0.109041461781148, 0.13307950819932646, 0.17775007974236243, 0.2158509570384218, 0.1789011881356278, 0.16538650848932807, 0.0696964883395741, 0.10763270269718864, 0.27267471676872623, 0.15065149674492498, 0.16674156480979535, 0.20320587911673132, 0.16885069679589043, 0.10643985783380848, 0.13492348183306957, 0.1550627842305168, 0.190640474339166, 0.17881022285549872, 0.182025907561183, 0.11951379177551116, 0.07130390934405789, 0.13223563170721456, 0.14124416686113805, 0.16487077809870243, 0.14037897780297265, 0.1159374405359549, 0.18289167884617083, 0.16595477718980084, 0.13822273140953434, 0.09269953465029117, 0.13093305240956046, 0.14225544888646374, 0.15224394839136832, 0.17567882314324382, 0.15485488328962557, 0.14757657303444802, 0.12395448937651612, 0.18024866018564473, 0.11846891679470578, 0.18224119358966429, 0.17961274592145798, 0.07826197186424848, 0.17306882287225417, 0.15289487797887097, 0.22959791454336337, 0.17394271468923939, 0.15155707395845844, 0.10846739379508842, 0.12628595539999585, 0.1543937443244842, 0.12778882072457384, 0.09013020598720159, 0.12843952048569918, 0.10314440805344813, 0.05670451048401095, 0.15180592995978173, 0.24969446923463579, 0.10989038679268091, 0.18179666341072132, 0.11627196814985045, 0.16548640635465423, 0.13774043309592432, 0.13418503436109713, 0.14656688447200483, 0.169373904204657, 0.06770386300500363, 0.2306094723603418, 0.19200582688133563, 0.18677854850407571, 0.11716866640434151, 0.11722200910650915, 0.21677312771639518, 0.11829018082109191, 0.09607097269186089, 0.15096683385631732, 0.10988196748639308, 0.10095708147292176, 0.12834504652287693, 0.16016094614901852, 0.14922003081488996, 0.2925736973843267, 0.24351692007433987, 0.1260653757039578, 0.25531171700887145, 0.14747787026628373, 0.09710447126699072, 0.19919599105994548, 0.07478479836736956, 0.1504410830356421, 0.06163097294648329, 0.12213382779830888, 0.1779006466630005, 0.10079301608305785, 0.13611511627752937, 0.21999593703977524, 0.15877771311469618, 0.24494063319458118, 0.08395533047376141, 0.12185971387812208, 0.2596419370703159, 0.1248548265486475, 0.1976431155156705, 0.16429883217619312, 0.08290127775962315, 0.19661773747253805, 0.18080696974310184, 0.24130105671863405, 0.2057502562961271, 0.17281699444978468, 0.12060561262431646, 0.12032104926484248, 0.10724512349453666, 0.09615916473370406, 0.09781632016623214, 0.31146882702746703, 0.07304503567396634, 0.17394810794822632, 0.19210888102890986, 0.09948533463982806, 0.09619109527838808, 0.08645044819962594, 0.15793664050438713, 0.15045105750041624, 0.1527459045211154, 0.23742540258794065, 0.17110723942037553, 0.13380150010268535, 0.1560969416412615, 0.09793114908520253, 0.1406988654766352, 0.26857844463759856, 0.13833533101264509, 0.08465315230310926, 0.17585329200711944, 0.11405078814395013, 0.10297535543119717, 0.147614938717696, 0.2245019742798421, 0.11407805321317528, 0.14018010137782944, 0.2672943280589196, 0.12811204088070702, 0.04128578441938566, 0.13456311407348803, 0.16506122755667857, 0.10830322115291512, 0.15065175721481924, 0.20682130850130515, 0.09866573547403659, 0.145410965046575, 0.11290957760666648, 0.3441881971253503, 0.26051110978568753, 0.12637847583861123], [0.025734042508467555, 0.029163779841075023, 0.008580689412361432, 0.04908733655728641, 0.021695064177976984, 0.03497885066955801, 0.023543080840740475, 0.029205744222347296, 0.018776479860647552, 0.03146769925801745, 0.04527699142213791, 0.04853537020784232, 0.06894731563666175, 0.05788563803258923, 0.028526651327528303, 0.056395045436558225, 0.03793883054787594, 0.027724867536415978, 0.046669520933421395, 0.027217024020970832, 0.008413135449612334, 0.014016052591614427, 0.032062566531221234, 0.09310606686818985, 0.06104317283438099, 0.02510577954742457, 0.022067497822365934, 0.005442042987147767, 0.04398891799933007, 0.017431917029523084, 0.03527050417277121, 0.03594608263923757, 0.015530858354102221, 0.08240021029186827, 0.055681806087734244, 0.08077042718087474, 0.009705715384634753, 0.06450308637032587, 0.023445234175831563, 0.03165458449192586, 0.029680352928417347, 0.06915187643420312, 0.041372586011646256, 0.003924477392912753, 0.05026986987720575, 0.008881538843495712, 0.019780382544042605, 0.012418382928796835, 0.006485096115108219, 0.06987513238263708, 0.028246992845989527, 0.009656777688031717, 0.040982746849617654, 0.03020088860554801, 0.015480837600696233, 0.05241034635072274, 0.03671761744865968, 0.08904932487395503, 0.0814550799588042, 0.030603801058004462, 0.019563600728889147, 0.011591752991080286, 0.02079352999346391, 0.03730137261652178, 0.029125879556241057, 0.00933874203192611, 0.07272812042145, 0.05257000673502203, 0.05834262480118102, 0.02810235161544575, 0.03220631718455303, 0.029591157311393373, 0.02436645490477883, 0.06670616371857543, 0.02328517542581164, 0.01685072251054789, 0.04330519601822861, 0.0427774035732352, 0.018451401941297997, 0.018177138633965965, 0.013795097512493451, 0.01501586628071363, 0.03823977669761066, 0.055313777448909904, 0.014921208456789535, 0.03581608134892679, 0.07738431855555504, 0.02214354545538945, 0.026154791403021065, 0.019387875480817694, 0.03852151319264405, 0.022431159760021878, 0.04743266708007263, 0.04456652531159982, 0.01498660076439621, 0.03200672638242043, 0.08283437530119574, 0.01919715597684826, 0.04190747626125813, 0.053399542061191414, 0.030009759244539087, 0.04018674702233365, 0.023780547029849504, 0.04991035247522016, 0.09487555377305516, 0.020070189775358287, 0.02240030365365167, 0.03585976368236927, 0.0488677183015933, 0.03592914443523173, 0.05065345010089298, 0.028506533858636697, 0.05081201497946055, 0.08677799675253131, 0.11370404908854155, 0.014549374276201331, 0.028589951257491787, 0.04263201540696525, 0.05388573976233602, 0.11034054005698812, 0.028227516975734505, 0.008200737572605572, 0.06523921259588773, 0.03431455284777669, 0.029246601606568987, 0.03408588709369783, 0.024671938210245103, 0.025462111938864957, 0.010548636182061127, 0.026236456375749364, 0.046609919292912375, 0.025958933364299518, 0.06693560705189744, 0.04449005058455852, 0.07053291845706201, 0.035724043545703736, 0.047233442084923874, 0.02956968195165598, 0.016238443974045016, 0.06459051232424474, 0.03515430012597673, 0.08697326490355116, 0.020823556809656082, 0.04173422164674248, 0.03111303502303218, 0.023729121462712367, 0.0237266757270141, 0.03521276029547857, 0.06496732799156059, 0.042352033253278465, 0.0802915609411655, 0.07155172346580414, 0.012607527164471968, 0.0113600755538491, 0.02491851126955402, 0.05739814181241298, 0.04937250895666019, 0.05193441805820312, 0.03634572389625734, 0.03384191107245223, 0.10921015434207455, 0.007627116311566845, 0.02818926237523556, 0.026789428215594064, 0.029525344613038247, 0.09343896271480669, 0.07599139450899056, 0.017491602939703775, 0.07454523501256782, 0.10450324118738213, 0.03455390552839926, 0.06027537270358974, 0.038918404194015654, 0.030161513601459806, 0.014684243097661004, 0.02187011335345526, 0.05145684267664629, 0.01407661758768823, 0.05898176046508936, 0.08667401563856872, 0.06947338055338591, 0.02362733327543303, 0.03633999355858372, 0.05928384808583125, 0.018843411047372128, 0.03727422246048528, 0.055808130156008474, 0.040270664293559334, 0.05142400048733239, 0.04802866433296473, 0.03518980447082751, 0.04442227095545781, 0.033140032807545315, 0.07104025252403752, 0.049026413415108, 0.043670267557665225, 0.028113862086508064, 0.03641796598751699, 0.0899254460067999, 0.10201540895767751, 0.034957300616248, 0.013842347900443261, 0.017248534732648445, 0.032172751042150685, 0.013487361908529796, 0.02404228288439974, 0.013522410431065628, 0.05083242356176338, 0.02145389969941349, 0.06365178648622767, 0.021119762790359316, 0.03002758036487766, 0.02612090924934995, 0.013609841173034043, 0.034693241600067384, 0.022678382078846617, 0.04756170693003843, 0.022420200872265046, 0.029728302371598063, 0.007411099626727763, 0.012458339202097587, 0.02835650702998523, 0.023353472164261247, 0.02853104292655424, 0.037670979396470135, 0.011362723345237394, 0.0223847022730737, 0.01214684497925543, 0.06030472153196893, 0.01805731865216888, 0.07692428275702462, 0.037901954905640696, 0.06774284921947026, 0.09410718290676033, 0.019112449635060567, 0.05355467869629783, 0.03537347405067375, 0.05216576128957733, 0.05612387329400067, 0.040462079022320054, 0.03888547007415084, 0.0128669896531069, 0.08458240408330195, 0.014092805025528276, 0.0041546413276885305, 0.058201553540364395, 0.014464351923144875, 0.051248263747942065, 0.0418887147679925, 0.06024723812457054, 0.06008500368484567, 0.029940458930908676, 0.03219735778627857, 0.05851061256121724, 0.05049845519205255, 0.019636735312580582, 0.04302570033037374, 0.01076815388871417, 0.04433340475624127, 0.02390380291598699, 0.03918810161731897, 0.06000484024444896, 0.026759723156330087, 0.04739028326566181, 0.022897990758440668, 0.01870362298382867, 0.027470874915560408, 0.01646289432932052, 0.030112865103048184, 0.024023155584150267, 0.08169564688878675, 0.03467644129188792, 0.0947840139269829, 0.07552730610534068, 0.05715366783401659, 0.05422470302531316, 0.027015362866222862, 0.006084808950207287, 0.06412689506466832, 0.05606711000925111, 0.04691641958009812, 0.05699338691849863, 0.023013767711217367, 0.023095806151808753, 0.015426891604288211, 0.025620908559029622, 0.061947757964052504, 0.019271165815993183, 0.07009580400922606, 0.046223129160822406, 0.07405585804653746, 0.07209095743394668, 0.028983620859141794, 0.030248568002735416, 0.03803307468432092, 0.022257027974832925, 0.07833063632490174, 0.09060391645518043, 0.07498432596724841, 0.009206758489111259, 0.047141316181589524, 0.021213104858273463, 0.05629589833739785, 0.05145410774275661, 0.03379984901496961, 0.0233424749721082, 0.04004564128756043, 0.012356167013246206, 0.05840723665671484, 0.032618426522540475, 0.020175613049838333, 0.02675328610254632, 0.03490696097874353, 0.03255089970245477, 0.043638758361339576, 0.05485563005711283, 0.009991566729431432, 0.06850448617291066, 0.01710143819030735, 0.04772465383153289, 0.09139029804857508, 0.04534811885546773, 0.009161114970582628, 0.03004396698557802, 0.048352945520873034, 0.06813842638005173, 0.05713867549333842, 0.02433833947795774, 0.04127973615522346, 0.04050773403216754, 0.035156173210951595, 0.03554356855250174, 0.04067885126137445, 0.031323864335013975, 0.05361895730358459, 0.03325641305456239, 0.04110908240921075, 0.013692353630528576, 0.05191942954796457, 0.08840758834154376, 0.09634558456919848, 0.04839693811992484, 0.026030434265492425, 0.07225652435614217, 0.01333438564136985, 0.04957129728169211, 0.02282066375858361, 0.06325866463744352, 0.053314559927750985, 0.042943104560817444, 0.09889671098320715, 0.07904013333421561, 0.19710026561252533, 0.15436778926560957, 0.1578865230323807, 0.17164224458317603, 0.22147111594676974, 0.10523745985401255, 0.10455600932360658, 0.17037482872124643, 0.05188643797150543, 0.08683440380639608, 0.23456954938029093, 0.15034726790843472, 0.13437721517778214, 0.2038942244384558, 0.12072899874540106, 0.09718930784372554, 0.19972096047093793, 0.14011677655000843, 0.2268363361156756, 0.1387111584265386, 0.08907852048474936, 0.16456581381780488, 0.11160494519337533, 0.1808820770031983, 0.16216492490662685, 0.13887442708496125, 0.13544459016092364, 0.12389765331341375, 0.1411636203767792, 0.06881211643978473, 0.14242685339864225, 0.11560448340230411, 0.2091437040437614, 0.18871411561004578, 0.12748333550388777, 0.1510424314126853, 0.12736492895431098, 0.11501939907189339, 0.12417352923582639, 0.08620867851160227, 0.10366836622838052, 0.1327986910098022, 0.13153418628198485, 0.08790661280433978, 0.1422856174289219, 0.07929176257382478, 0.10399151743660051, 0.08488477898701545, 0.06815990748544855, 0.07941511805139242, 0.15578632363148276, 0.07971625955354783, 0.12523731892748227, 0.06999985149670994, 0.12554366982752277, 0.1869761532232646, 0.1732323213570541, 0.18506467192163392, 0.22900401254094419, 0.10262733700895503, 0.1298154833456201, 0.11959347258051557, 0.13290617314557876, 0.09731462450637933, 0.08945739692858151, 0.059214992103196924, 0.1768070867946071, 0.13591132156791227, 0.12539874897488665, 0.16553811728954315, 0.17409452267231482, 0.2900667206173943, 0.12248392997970506, 0.16030057333409786, 0.14716493867097363, 0.14373824270742555, 0.12094990785924659, 0.2078507008451608, 0.09845785751578309, 0.12371510222193696, 0.10083811567916025, 0.1488432687737288, 0.14153204738132416, 0.138766638514015, 0.1095271232207456, 0.11153661781140875, 0.10922785863400468, 0.13566865555701718, 0.17459148390879556, 0.09660810757909091, 0.08756638549628758, 0.12225993353152469, 0.1294411268205412, 0.13956788987401994, 0.16448948081702958, 0.11962809975469306, 0.2919280691252601, 0.17993988078688422, 0.13858982542109105, 0.13615259329878515, 0.10705330273917607, 0.11435515487626677, 0.13581729193608608, 0.1762469539478902, 0.14177835997073882, 0.1901380279131474, 0.11723009133411032, 0.10514233471645464, 0.3175420350124759, 0.13524954417540183, 0.1303595589894441, 0.10535090981471924, 0.13157166330324066, 0.22020546208706596, 0.21376280053969354, 0.08255334360705269, 0.13290957457596256, 0.16438867896795273, 0.14847363135026348, 0.20393318767028473, 0.20312162476681894, 0.17699634115542137, 0.1615332854130576, 0.09616413664433265, 0.13268580029328025, 0.10324832021949754, 0.09975271464716043, 0.10775786614225757, 0.12899909408823138, 0.0983162385021006, 0.12125986703341046, 0.16029611470237856, 0.269891825774985, 0.15087352434713996, 0.18587922256800438, 0.1613085152160737, 0.10502438015875318, 0.1396311687365655, 0.13273956434380624, 0.18852827800137384, 0.06738731547469093, 0.16507500181755713, 0.0839725980955747, 0.15622435738482784, 0.20778463342257086, 0.13293310879699646, 0.09643334760180405, 0.1543495563730117, 0.1304189614470928, 0.15211316186093515, 0.10068820759413705, 0.16453707019888586, 0.20089436202279984, 0.11616813259259348, 0.11389072173305097, 0.1170030075515951, 0.19700591422377095, 0.17224851124469312, 0.10837334118062451, 0.09685509432587894, 0.19424873314076857, 0.10075824335217477, 0.2016734734417931, 0.14943190009122895, 0.26931450191524725, 0.2020004550896345, 0.16176211587604017, 0.2289784405260317, 0.1087926900494964, 0.30107454607082956, 0.09175990482852345, 0.08573713607244915, 0.1456447750810654, 0.11502977190238815, 0.2459108529071654, 0.15859135456623571], [0.014493943984440018, 0.01142143440853444, 0.028502492744836117, 0.0320896381632455, 0.07426561292020545, 0.052984640332719976, 0.018550374755455602, 0.019925372344591928, 0.02134049187354263, 0.016033911904800805, 0.039706291150181525, 0.0217528214618083, 0.00413887380179198, 0.07969356802923065, 0.0465885914051004, 0.02303330486850633, 0.06252567171149197, 0.008830476210512703, 0.023325253315570376, 0.10263575631524287, 0.06726297174370097, 0.043186613268429236, 0.05513538621486195, 0.05789092786970639, 0.021017156804220814, 0.043642561987883625, 0.03342425908833262, 0.010612467585522081, 0.06734474396873867, 0.0078068204287950315, 0.03330367684905087, 0.015508328665859036, 0.016046352215081213, 0.057389324140404506, 0.038319855868335695, 0.013961689077287674, 0.028352251411565853, 0.06869495095264527, 0.025013891131346746, 0.03871968864733654, 0.051183785957795, 0.018343983007775202, 0.003219574995924749, 0.038160203144915646, 0.0491735291096472, 0.023946889616068334, 0.008383442839277128, 0.031488707304121025, 0.057904617860913284, 0.02729831552583604, 0.07722857288054882, 0.01746015503041206, 0.06860770885982821, 0.017561567834608497, 0.024615774389296293, 0.05926157024899318, 0.07727157339573869, 0.05032859817748109, 0.06453001436086432, 0.015930172108534365, 0.04508692883856354, 0.04602066744419356, 0.030165171671298244, 0.0702460568338152, 0.02851088523804661, 0.054167556696601456, 0.0357745785356289, 0.04402650227289527, 0.06181584528437065, 0.0374830158938083, 0.041227511941425266, 0.007092589953719008, 0.05205166398457462, 0.026854957461417205, 0.044784021503742666, 0.13418253691446397, 0.03811247969767259, 0.04188897906832638, 0.027966164165146412, 0.06035488113881119, 0.02107450614623245, 0.09240973124941511, 0.00444037105602723, 0.013953780177079383, 0.04762176056242278, 0.030320187647556587, 0.018305944827114864, 0.03817381652733011, 0.044180872820077405, 0.05073361737172931, 0.035388834113555576, 0.028096471890626896, 0.004759976713572659, 0.019625642359437003, 0.08532491948215232, 0.05133395451271246, 0.019935362131124543, 0.08637897219629058, 0.07035877135011458, 0.07415898114202485, 0.02924707658108204, 0.03420008782057032, 0.038663821685458385, 0.045002854519313386, 0.03138401755882848, 0.07131285725101348, 0.05754752895764767, 0.006729891371627849, 0.04266292705470997, 0.019450261850931475, 0.02293825442452104, 0.07209203761791991, 0.06023096641705883, 0.034053133004495216, 0.05251796638232566, 0.06978644238364312, 0.04439992034026692, 0.05462260143230519, 0.04217531975178469, 0.03767842577109414, 0.058570761954592127, 0.01795533319724904, 0.03383702343149531, 0.0700683550788991, 0.016037149583890794, 0.025678131496533755, 0.04586536993062304, 0.026002623358621232, 0.021683706924499526, 0.06561743786498424, 0.018764710834910794, 0.04462893849479095, 0.03776579809885833, 0.049960600182173714, 0.024257618708596117, 0.046531288028364225, 0.07173038283062559, 0.054056408830107226, 0.06635663610312247, 0.06189412414847363, 0.006930504901139367, 0.021505819393261787, 0.008649300246859991, 0.05661005567338678, 0.03440703498199582, 0.04173027246349281, 0.03487683840156083, 0.020578471876140085, 0.03686310137592016, 0.04084791154450467, 0.019011412213947025, 0.05865097519070391, 0.008640962337414104, 0.033547043830396674, 0.05325923305785945, 0.05577916820203105, 0.03991571660604208, 0.07795389726637833, 0.015234928165051728, 0.04074088906148269, 0.11656315816986947, 0.06227762776336843, 0.06702012187170406, 0.017896553186038812, 0.019422770785768668, 0.024806461334528945, 0.0344869073089813, 0.021264714286512425, 0.04876413172291172, 0.004382140234097718, 0.039006718809926705, 0.0408517113406091, 0.021469591095322565, 0.05352287838656095, 0.022678874290337967, 0.018560598198805126, 0.036074789240956306, 0.044604883333968545, 0.03370791846405595, 0.007749516094448947, 0.009081241685987241, 0.017059611704861446, 0.02670922072514171, 0.07152348546491516, 0.027836300770662008, 0.014825183165920599, 0.0626304840308524, 0.09107207278570822, 0.044887159920988545, 0.05211388947622431, 0.07603121575929465, 0.026796447496200283, 0.021496069009205507, 0.002345177560909501, 0.010751162058553629, 0.057253515903627684, 0.03755034736147331, 0.023736383976234544, 0.027527077040905436, 0.07574498232814574, 0.04150029669906344, 0.042030808756188046, 0.04991797888050637, 0.008915052317353267, 0.029818241093908588, 0.028197574429214004, 0.06624314783801956, 0.03511455548446506, 0.034007114102883686, 0.017228984168820807, 0.012318323227396656, 0.045924668966401974, 0.02422454477768512, 0.01273335806364494, 0.03968891627605885, 0.03542259560837861, 0.07171408814047614, 0.036496022686121926, 0.05565209336759103, 0.025661509303796678, 0.04787324807576595, 0.03660811284076303, 0.06345158089853584, 0.09175625058912462, 0.027821934706861937, 0.0426826193448036, 0.062140019219969554, 0.046453936130649624, 0.03748568571022442, 0.0531964406611458, 0.032963246527698734, 0.09931723962748244, 0.04742872938814183, 0.00929875224227867, 0.014417775692568432, 0.030367702335840276, 0.02661684967367159, 0.06827668992862587, 0.0450136486981665, 0.04669313942412696, 0.03871544835067565, 0.01654789369973925, 0.01908222363600808, 0.08762541257085339, 0.020761586042241226, 0.004451305524731476, 0.018847563243921728, 0.009324676657636321, 0.03417340114772801, 0.04488181645771669, 0.10458216356534152, 0.05538164900856153, 0.04818190873089818, 0.011192864415446117, 0.05184345660851367, 0.01934310147208312, 0.012387494263689847, 0.076717316443401, 0.030600667758394155, 0.024139509018089984, 0.04107249404994711, 0.003455632301460531, 0.03316282009285304, 0.010502462147644932, 0.00465191139336375, 0.02438736718989188, 0.004646875801676464, 0.005543259960118561, 0.11102310907576354, 0.06547162835035594, 0.05601512711314906, 0.01543390705445481, 0.027490890877802047, 0.0444431736644718, 0.09224484614547222, 0.06490329070196998, 0.02734206297675208, 0.05506157364335753, 0.015424814548403507, 0.062091177284357056, 0.06085470754412874, 0.028285506001162915, 0.07001968551306956, 0.062105817224590056, 0.014156383619974218, 0.03533849064561148, 0.004408861859701574, 0.03440957839390443, 0.02548668037859663, 0.03184296359728662, 0.030064327687385584, 0.03583115029839739, 0.07597081738734439, 0.02939804952831999, 0.04667327093381075, 0.023120049004172607, 0.045765211595402616, 0.033268666630911256, 0.03885540112312283, 0.06143271322211912, 0.018252251639721856, 0.010926400840793167, 0.018355026165203705, 0.03395434979709887, 0.026112045612066027, 0.030654119628091014, 0.059752881587032354, 0.0413494156823764, 0.025215567607853203, 0.018530008307988607, 0.033926253522475885, 0.02930097278177498, 0.05107865571194599, 0.04173206127879601, 0.03368380967707884, 0.033981009656863834, 0.030214450277027585, 0.010478159923466944, 0.005822671378301758, 0.024331362332187356, 0.027697073866523085, 0.07253542632585572, 0.019793168551498846, 0.039188254834903825, 0.02698506217359776, 0.018515812698751688, 0.08431615022521827, 0.041869152712846, 0.02230535854675597, 0.08871005517580817, 0.01540916241450055, 0.020069046389131297, 0.030431590238285643, 0.01047517026534244, 0.05869329388764116, 0.030241332302290588, 0.08372463075624359, 0.06231464896230929, 0.0628747090306734, 0.0605926480174305, 0.04770023094850683, 0.0808388235107545, 0.0035420666503224283, 0.03681587205538827, 0.041104003246272766, 0.031686553341006084, 0.04757473425519082, 0.046314151897545786, 0.026619396916019823, 0.02373950195408637, 0.023828561590503783, 0.08111910443873176, 0.19435809985283883, 0.08113414274468538, 0.12831808788882149, 0.10538317743808993, 0.16463364324262067, 0.10906151796300566, 0.08936234073893679, 0.1862816638763874, 0.13692995803731103, 0.1282116552935012, 0.2042753991460608, 0.18404015189697667, 0.08859208529634822, 0.11542423057460016, 0.22783404306298305, 0.10223529917458374, 0.1799083026426454, 0.189318114651307, 0.11741426653198658, 0.14927197157615615, 0.1455502245094507, 0.19580033697908927, 0.11075834908913221, 0.17592683644785037, 0.11875810732524242, 0.12620442066221468, 0.14562792114673123, 0.1604804967439944, 0.16774406746750878, 0.13026071832545344, 0.166579062239297, 0.18764860988143953, 0.0673919273239951, 0.21688486930103074, 0.07561333011835814, 0.06121744634583593, 0.16438768305365117, 0.13649960048496723, 0.15985064989616796, 0.12825686980279224, 0.12605096559010207, 0.08842315524816514, 0.2576328561671319, 0.15432606811725325, 0.16002931692186864, 0.08946244544800251, 0.1875685690151107, 0.19697943822510783, 0.10224017915466141, 0.19543557187482236, 0.22171418032338544, 0.17611838907243746, 0.190918380394578, 0.11330153883224535, 0.14754094994596897, 0.23356444202363494, 0.12220415466975783, 0.12000532144860876, 0.1464931255266551, 0.18351994755287326, 0.1013450283977774, 0.18076236810415022, 0.09191361270965108, 0.09792115163779068, 0.19775487242206452, 0.20010598093992282, 0.10898557566707173, 0.1251885574311018, 0.12563461212501412, 0.1365529661697726, 0.070316000661302, 0.13435432447060464, 0.1781345945933173, 0.13259051427725824, 0.24038627112825073, 0.19049029046249008, 0.1597097510051343, 0.1781083943863069, 0.1337422508626215, 0.12470142510268958, 0.08005634130489442, 0.18058615255980723, 0.13380807313707568, 0.15435885668041247, 0.10828461287723434, 0.1131274606732111, 0.07361534982919693, 0.11224170215427877, 0.1538522274143273, 0.12388213237206783, 0.10295462509196612, 0.13993104619364585, 0.20689759553680498, 0.1891113475205437, 0.191592323263326, 0.224151780167895, 0.13328799136704014, 0.1565007772296667, 0.26950963983132, 0.1618435357006327, 0.12718476039627868, 0.17506815913704135, 0.08852057098861664, 0.16055267754822009, 0.11219395189395837, 0.15671307551524333, 0.1901850197464228, 0.19263484635420386, 0.11829706795153119, 0.09998505379283622, 0.12063453244345805, 0.1664845116676823, 0.1233514019798848, 0.13076503400600728, 0.06891230541852213, 0.20758273861100598, 0.18337365540285266, 0.09115451150724004, 0.19063904941562684, 0.11217263932790487, 0.1947435646528198, 0.18328429890736458, 0.22138428754143177, 0.15362731932151705, 0.12375984175671494, 0.14724242080363537, 0.12079959374762352, 0.14001646499720313, 0.153961701378707, 0.1235806461303465, 0.1620298482838177, 0.2127026114612818, 0.08815346165530144, 0.12960462530534114, 0.21583634008082653, 0.13693971799746638, 0.13730077523617976, 0.1078405193684082, 0.24529988246579326, 0.149175796898142, 0.1289652023584612, 0.15926345882396545, 0.07416609809884141, 0.19003106671715939, 0.09121435063500559, 0.1335163162119927, 0.11510490214512234, 0.15764739634769578, 0.1303024701173267, 0.1232323672382101, 0.170066524296999, 0.2338211580870613, 0.13146522304704114, 0.24096777782805506, 0.11002617587725963, 0.13894548940081752, 0.1433173080365504, 0.10302787841928583, 0.07346528086570964, 0.183476586976359, 0.2870351881269486, 0.1546375441455072, 0.23940456009680228, 0.323292474833227, 0.11813181512538465, 0.17778901233067437, 0.1691865344201365, 0.15361835609280294, 0.15128079200944594, 0.09756879715789711, 0.1128668605440086, 0.13570368109691527, 0.11440470544320923, 0.1570474422506748, 0.1576208897055157, 0.22880364990522786], [0.028315986724450227, 0.06989610787000387, 0.02307773988333441, 0.04486907258509629, 0.07046985409913525, 0.0661789573308441, 0.05294483823461398, 0.07097365650077982, 0.0722635800259248, 0.03355475067491493, 0.04108052265139357, 0.04336024326602778, 0.04694679879673547, 0.02591662807390094, 0.05916017851221466, 0.020161936465170116, 0.05756335250372368, 0.039036707321722666, 0.02887457207356009, 0.05042014185399298, 0.05561537860381988, 0.06790500705040271, 0.04623595730311448, 0.057769016467876015, 0.06542712630283448, 0.041208616382772886, 0.021444350413437334, 0.04445347371661375, 0.047268463794382355, 0.041841585038890766, 0.1159222796559334, 0.05681523700214683, 0.05547258364517362, 0.06348054668295287, 0.023880923700128353, 0.07227471894434384, 0.09975686684371003, 0.03595206961636582, 0.05336299583676362, 0.04533968039698178, 0.020243329476685296, 0.03472777301325433, 0.07678255649103273, 0.060286293286950364, 0.04443315706486183, 0.01943066723704819, 0.04496839588447925, 0.050800286173339815, 0.01989000398034771, 0.02824200369838265, 0.041346902913984754, 0.051257770899082386, 0.01557603264377723, 0.06786943758807837, 0.05484657872828746, 0.04322178053459333, 0.038084348949093016, 0.021129917285795656, 0.040908784890968, 0.021909787131833936, 0.030021442085384365, 0.037982432442086364, 0.006483810045005333, 0.03726424416527152, 0.005257652805847747, 0.04142269582277344, 0.0503586862807072, 0.0760220073824448, 0.05616205894658643, 0.011489663156680765, 0.014330969312258307, 0.014344159431094605, 0.03108492917231014, 0.0672444170941749, 0.02148503542787606, 0.03168043421371089, 0.03799306574247537, 0.053942127664002686, 0.021474292959957834, 0.0296022406884379, 0.03900314884019956, 0.037214781698440356, 0.019620973053538514, 0.07449491835770107, 0.008299286165575107, 0.07057765799184, 0.025338214454090884, 0.06492300214426172, 0.053442990737816984, 0.04226911189635435, 0.0234490531241341, 0.019943940400656675, 0.042345448727569276, 0.054626163741153096, 0.016732905848672795, 0.021154451251570738, 0.027574419359406157, 0.04848010079454511, 0.021152524540441173, 0.08511897972634724, 0.07340346523109945, 0.05276687217936401, 0.06372169583975788, 0.0517513805008944, 0.06158835164481594, 0.045105858871172515, 0.06676307639047023, 0.04496507106288787, 0.024229376877267516, 0.03413860926464681, 0.047359605274734, 0.033923116392425956, 0.028372125647541498, 0.03998638821705695, 0.06042150397514624, 0.07100020144735614, 0.013380802908702003, 0.03021273615529701, 0.04173114963416611, 0.08158922961522495, 0.050340656401409264, 0.06051518120652726, 0.03938690526410937, 0.03572107112455753, 0.020360154054698446, 0.013906165897365541, 0.006226053538416783, 0.03476473292516124, 0.020535341126003095, 0.011181515780457807, 0.05197908864506791, 0.030886839902509126, 0.029900164621311332, 0.002931690645299011, 0.08197903813373658, 0.006689131184811554, 0.037941691886273124, 0.09330827577580368, 0.006133470855157582, 0.04857280509426229, 0.02078328739791628, 0.01756419168574916, 0.02794286360092942, 0.02105825742135846, 0.053188703173110564, 0.06547037196616012, 0.05527369955915117, 0.07247196360220833, 0.02632218736013578, 0.00820433627062988, 0.026934054124379353, 0.07569646597990105, 0.02763820192476194, 0.07621635622795551, 0.03670970759084148, 0.025719726240382563, 0.03928807609143757, 0.016107218858275204, 0.015940653148948426, 0.008837490703069396, 0.04631468815909279, 0.011816454240150992, 0.0791789791096122, 0.025962463114410642, 0.030873067556850375, 0.041978749251293565, 0.03722734937083818, 0.008738271783166116, 0.04031040127419176, 0.04812832471103438, 0.028569278374855078, 0.08695130882364127, 0.05578360002067301, 0.03375579512888386, 0.008762399722341328, 0.02285178033484807, 0.023419079934096625, 0.07806672669586637, 0.0084379710625076, 0.011610479052779416, 0.011405611820068332, 0.07940116759029128, 0.04661695964093651, 0.040759753976618095, 0.04301752234178205, 0.008957913021496948, 0.04054156064446415, 0.05414664632670822, 0.020150401096250263, 0.05882588072469639, 0.08633664583847409, 0.0328838836491829, 0.009399667089324324, 0.029085043239437287, 0.030544615020194364, 0.019674003574877016, 0.04962388538725434, 0.054373906309446024, 0.06419249134318483, 0.07977067477880947, 0.12068948393026668, 0.03312686375612694, 0.03763928633904265, 0.04485220715944325, 0.08700444468206937, 0.06603331635555913, 0.015695920615877598, 0.039353342952146646, 0.022815952317849286, 0.03151305166313485, 0.03676133808649836, 0.03444810112517688, 0.018599193708430377, 0.0919693839105387, 0.023756398023256374, 0.044216066899318854, 0.0319157304587744, 0.03712003960484459, 0.056012311740027326, 0.047444430360149954, 0.062244938791639386, 0.032448676760278405, 0.035252298093250686, 0.047678688556076064, 0.05996688441824048, 0.013118503979527423, 0.02846950691403641, 0.0632402440533042, 0.037984489388163054, 0.01722508286606641, 0.04408515396437818, 0.08475306549019392, 0.01729859091762093, 0.04791314210442286, 0.015283547935166187, 0.03765006136569766, 0.023358873084127423, 0.05993957338373988, 0.023371163049652692, 0.02072653368926577, 0.01772968391437204, 0.0040193267388179185, 0.02414400978464513, 0.05509929198230948, 0.02551230027400438, 0.04747702357088847, 0.009631102251249456, 0.008245275051693523, 0.02561286463582468, 0.03600313703739836, 0.062474834116836714, 0.011249416068406596, 0.1170513476996172, 0.08812207503304367, 0.029911098611210624, 0.03724914840272358, 0.058095929167804226, 0.019591172233284004, 0.014009654799836778, 0.0419976907752214, 0.051093912352958036, 0.04971371302681585, 0.061842060813139525, 0.021292509871625134, 0.04500506085253531, 0.054909210246537006, 0.05354084697882495, 0.04328919244149039, 0.02174700110880358, 0.03395074152297551, 0.027768065319246346, 0.018005004423039577, 0.04010458792289419, 0.03996342856196627, 0.0395522270381691, 0.050259638772976976, 0.02349903653075378, 0.013776362832305173, 0.01638431094526764, 0.015846070976206855, 0.06311965032270359, 0.07823055459847374, 0.008533300170975347, 0.030331571714111397, 0.027441604611193462, 0.0383222728757368, 0.012588116411690511, 0.03085290029224369, 0.03035704222237391, 0.017318871180196444, 0.03309677565290082, 0.0747831589392116, 0.05120563478539548, 0.09022446544540506, 0.05541164135079711, 0.07340125123699827, 0.022701640508227774, 0.012964419757706985, 0.045897223866514625, 0.043348836216835246, 0.10998183470820228, 0.029521581206110217, 0.07254701723615009, 0.016449392029655077, 0.061590515843202034, 0.007655262860709862, 0.007872633127150157, 0.05444743542841846, 0.035668923519551754, 0.023949082542751587, 0.03225275360408329, 0.04039078688008651, 0.015997054457153766, 0.03873187327577222, 0.020627308066093156, 0.04604864114474866, 0.017347967199560617, 0.016938993076403296, 0.0340600392871326, 0.04956222680066863, 0.01049289370947067, 0.0395512426151864, 0.0779610142231949, 0.033346822920946345, 0.11213891613747805, 0.07095660338358534, 0.016445833551246795, 0.06811250962557332, 0.05131564118088253, 0.028787395098216595, 0.045791649289669535, 0.01433304253770339, 0.02678682543187132, 0.03959408225191217, 0.011279453418307729, 0.060004009039051114, 0.024833375918528727, 0.04253163490624678, 0.04864398232330719, 0.09178082668973554, 0.06624143946194841, 0.04158831254068402, 0.012245530510441431, 0.018360632013589628, 0.04869894530143469, 0.049106749225287676, 0.03836968988781014, 0.040420978405182405, 0.06288346541564792, 0.021757285839187044, 0.03965538077717347, 0.018377070345224875, 0.13779359959786938, 0.16863121260558406, 0.12226837582045025, 0.09814380743210355, 0.22701235247715829, 0.2315420618340854, 0.1469071194409363, 0.19850163960889464, 0.14056786444158326, 0.13217524865702276, 0.1485505772213782, 0.1529909913698512, 0.10863625489535833, 0.2409424049960029, 0.15446797824434697, 0.07730859076423992, 0.100099737155101, 0.14449109263237447, 0.10149104475614526, 0.23577072928028725, 0.10752587939702696, 0.16138633442742212, 0.15467613965513247, 0.20272941839310432, 0.2697073211593013, 0.18591366588108002, 0.16944933322168168, 0.15979932200524116, 0.16817678457065938, 0.22383636644771024, 0.15921332603020055, 0.1603866969385455, 0.1264730417319844, 0.1013666320772421, 0.09562548490301256, 0.18890473360736526, 0.2510408840833172, 0.15406777391270285, 0.26980087581661444, 0.11738084977672947, 0.13534859934401128, 0.08739322664276247, 0.18583837475988174, 0.28992952959191415, 0.1361321234294484, 0.13080621889281657, 0.15410175757302394, 0.1581017018085526, 0.1697663710482659, 0.12582130009128203, 0.10596548853021477, 0.13412583108630874, 0.11141012137335156, 0.2007112823306553, 0.19182780336949135, 0.1665751245473662, 0.12007430000531098, 0.08389202862857811, 0.13452954410064605, 0.14338101590833358, 0.11869060731823407, 0.1701157224634963, 0.12436214008278425, 0.09226643450317845, 0.09463826569938853, 0.22299845011964922, 0.1546083868391091, 0.14493531637614773, 0.15982539963818368, 0.1481870991448241, 0.12165613367312378, 0.059706812889705745, 0.11608776996933645, 0.1788348602431436, 0.17269488003465439, 0.09943409867945219, 0.22568536561823663, 0.18622425324734182, 0.11716705761970052, 0.11171497074106049, 0.13554453399152527, 0.17691521244424005, 0.1541443827051309, 0.1813344672442444, 0.11764379413498026, 0.17977618311922397, 0.1409664293450694, 0.13992894711273332, 0.10525611409496878, 0.12825835601336535, 0.10449726570157275, 0.09022017535302909, 0.14001559165696945, 0.14460421317527372, 0.09052646496603567, 0.06991657773934065, 0.1824049219008415, 0.15983244764708704, 0.09898357003206208, 0.23343860442119263, 0.14224837023404338, 0.16827675904477798, 0.14343361550521466, 0.10113128986690315, 0.24387787006074385, 0.087185570850007, 0.14644083236494373, 0.11022214882916982, 0.1168927981428081, 0.10489606043143619, 0.1814570259903708, 0.13827669464292067, 0.14192652137529466, 0.16659613067824997, 0.21808960384899573, 0.16126543043121216, 0.10764358114571342, 0.24379223675256778, 0.15154431093363993, 0.19136669504786694, 0.12197183084584053, 0.0967153445667317, 0.2330896973369583, 0.09550798999806566, 0.21117749894338272, 0.058092707768082626, 0.17603140744951465, 0.12971245984156288, 0.15950428622384227, 0.09124727709399116, 0.12806617519668034, 0.12414641738418611, 0.1288804577122773, 0.20611226348386658, 0.18060584101946126, 0.11313620173642713, 0.10382860117862303, 0.14753171092560216, 0.12106174903531229, 0.12951500833995883, 0.19699587847196287, 0.0813027203924233, 0.12264798770868972, 0.13841045359450002, 0.23865105133623848, 0.13759838507300423, 0.22928470715640054, 0.12409226262881873, 0.31283393442150087, 0.16564631954796855, 0.1068407976098599, 0.25190809561360267, 0.15267429062195365, 0.16899145779109773, 0.18354435511414083, 0.12321152198579043, 0.11215858161449434, 0.25977014954532346, 0.0967206075907715, 0.13192810869264987, 0.12636609585775485, 0.08257613472280004, 0.17036129960850363, 0.12433518910960806, 0.09479843936259709, 0.16430733575215264, 0.11094506769891709, 0.10474182394964081, 0.1556741683593681, 0.13513196500078326, 0.14065573472649823, 0.1617294039216734, 0.11657191455484399, 0.14069187875476577, 0.14477832963870418, 0.12445088370793289], [0.03205690897190042, 0.010829333670347208, 0.023770965185136567, 0.0410234184575177, 0.003385789980623691, 0.026808319943806818, 0.08917305573460557, 0.01620617060501489, 0.019903238149239652, 0.006500500706850642, 0.045420544807829207, 0.10112844001982482, 0.02752268735709931, 0.03558977897609434, 0.025460932163461566, 0.1058999190647756, 0.006850158078445783, 0.038157188588933605, 0.08557964371697557, 0.050144924767195224, 0.06422030033483621, 0.03955495048073992, 0.03519150135557979, 0.019446450563508178, 0.039414656799166434, 0.018390488375218648, 0.025119572960501237, 0.037875432941702106, 0.02364746032042369, 0.09625256617343235, 0.07687491605118399, 0.039907986778886094, 0.03088491127615975, 0.01793618482958165, 0.07318815621998041, 0.08374436518117305, 0.051840231378352454, 0.06415096171680959, 0.022159840145538894, 0.05944047859239002, 0.04707748573573847, 0.029964008473701058, 0.018054189182998195, 0.05342254002067832, 0.08712124244700517, 0.030253285189129175, 0.03647098310231682, 0.019965358303799745, 0.11578894205271237, 0.017581279276900234, 0.07956709457381118, 0.04955567674891603, 0.0179867351412653, 0.03987694106575462, 0.05844119733439819, 0.0659848076681937, 0.054531291412610206, 0.0485270428321054, 0.053082010107896024, 0.05158803906411894, 0.0101302468383144, 0.009820852653994676, 0.01094132806399777, 0.02701240959727476, 0.10721536097867836, 0.04440212667348885, 0.10861490402490863, 0.013860738798675519, 0.0397041384431143, 0.05950452737329949, 0.028159551570312153, 0.06330840289592743, 0.028229187047409437, 0.08734313981427301, 0.04444766293970808, 0.031789184225002126, 0.03863837224461379, 0.07588126936987524, 0.010694840231970435, 0.02058394557435907, 0.06439754243699775, 0.049037740025068485, 0.07686241349625973, 0.028785929955061407, 0.0409081950032663, 0.05466953580898624, 0.0006950623567043353, 0.010848796134063554, 0.027871460375946858, 0.04339493555767883, 0.042794127272622245, 0.01896176971645365, 0.021472481162016912, 0.03996772631522148, 0.011477354996567293, 0.09652787519078102, 0.07042866155144668, 0.05320403642291504, 0.03499993340923421, 0.007511527529136548, 0.06597673310147179, 0.03133166694052277, 0.029290306922649185, 0.04334969040487082, 0.026284040011946234, 0.03124250579745539, 0.020402681510595065, 0.029869492376042955, 0.02286119364021767, 0.01778704666292235, 0.03492789816171412, 0.015366803497947274, 0.015325886741911453, 0.0096622513862507, 0.020871529235474525, 0.061589102410981734, 0.04342485129112198, 0.030631341918882345, 0.02972002096113659, 0.06478902868806355, 0.018004119591487032, 0.10527404821327618, 0.073448128157085, 0.10643253403325235, 0.0422285666929618, 0.033197068053508, 0.08307648206790609, 0.029189317382030913, 0.022263208389162056, 0.029841239053395488, 0.030266695558243704, 0.018772726029818578, 0.029649312960945313, 0.009441684139141393, 0.0487528357564682, 0.103701920879464, 0.03301057543966078, 0.028731604745130868, 0.07459701489536993, 0.027348471302238685, 0.020946397093094645, 0.07237719086509559, 0.02104751686866005, 0.05467444260214126, 0.013770061759127965, 0.02528717576135551, 0.05022942426524336, 0.013999293460660886, 0.05547189799648139, 0.017537430319334232, 0.021692618442278717, 0.029958630536472606, 0.04098132192607849, 0.012569103067019775, 0.054754728616605845, 0.05864897953166116, 0.033753477712912906, 0.05493363696000269, 0.053940626131671096, 0.04184113304701544, 0.02364582280748554, 0.012224191131310598, 0.04550874068011199, 0.02338398353106553, 0.02722155351582314, 0.0562650173331701, 0.024854747856396343, 0.021839362584174644, 0.04978536906081343, 0.026977700068645423, 0.023053058445633903, 0.02361530952546145, 0.04602553593295236, 0.04187857942475427, 0.06609681738360275, 0.05302163088814386, 0.053922841400508924, 0.036288841867879514, 0.007462880945944738, 0.052686337186324025, 0.016361569625235373, 0.04452205390759534, 0.025723070214172045, 0.06178488767135048, 0.022790332422441533, 0.05171463509360629, 0.05373338785683436, 0.043301572422346765, 0.039571597571334535, 0.009191999805249996, 0.04273816071931393, 0.07675032717205825, 0.042481555738636566, 0.040425728150312944, 0.06943654704598651, 0.01406934262523728, 0.04059384614529629, 0.03238543237168943, 0.058347661829283165, 0.04655941111606456, 0.050096730175878734, 0.04194584960538534, 0.02287106468312202, 0.021735272302682844, 0.03815829941642381, 0.008048320549630351, 0.05171512155943821, 0.07036626369001404, 0.0082418525538918, 0.004596230207807235, 0.07995018450122687, 0.04507866658030018, 0.08642080825783553, 0.011442245186997518, 0.03431515422679725, 0.08724867351232998, 0.09250498662192015, 0.022635927401302804, 0.008259865196211445, 0.026854476741244717, 0.05312991358580128, 0.030926281939290708, 0.05218492497900321, 0.031165132832322872, 0.031126998890672, 0.07307483649422085, 0.07598826120938025, 0.0721306407884244, 0.03616422617567643, 0.040972312732088956, 0.03567303358126552, 0.022827669632651156, 0.03938067313884536, 0.00689952526309137, 0.026955621414667657, 0.024949198836580883, 0.016322976030829935, 0.00784600247448731, 0.023725997739201112, 0.03361452851564654, 0.04922787155655604, 0.021194728324189786, 0.0408609810044929, 0.025548021038693768, 0.06753468780868477, 0.011326713382356591, 0.07431998218019163, 0.029151327081865845, 0.0672446315987937, 0.04620187788180286, 0.049744617013681325, 0.043369528251670064, 0.026107721045733463, 0.05253721051098359, 0.07560461203777984, 0.060373462601414615, 0.04114960846040518, 0.11430948837510041, 0.0704353571599049, 0.02704687780820795, 0.018375224073327357, 0.050093010819006356, 0.05069781808302768, 0.039377907561438705, 0.04485409939661623, 0.07469233921578816, 0.03788810786640933, 0.08021575654105795, 0.026901005091325893, 0.02593872013441738, 0.04149767284792277, 0.005325771428854956, 0.035314312910721186, 0.05974342806204673, 0.023353516214316892, 0.027260851911118916, 0.009523203555164079, 0.08401260320698062, 0.03770150416981309, 0.08733893399156871, 0.014367653432512477, 0.011783452129982894, 0.04646083475240777, 0.05443005672385616, 0.023402308354214318, 0.01219182391650975, 0.07054989496546407, 0.005181710988718776, 0.03520278966114406, 0.03264029450233906, 0.06628546653495682, 0.1039719898554106, 0.04175763712414811, 0.03501198014184352, 0.04195828321239641, 0.05423550486504551, 0.04694410982812124, 0.018636829692930467, 0.06483453431076582, 0.10586110905053155, 0.0700571701952046, 0.019772844238867684, 0.049469848088319265, 0.04213945151516988, 0.032609582037454656, 0.04964185397951834, 0.031721107736830755, 0.02502783393156865, 0.03491853656727941, 0.05413323212715407, 0.028831992906728582, 0.0882114774938072, 0.033158189091350765, 0.042286341213771415, 0.026887726872378302, 0.016192584035677776, 0.021628290039276885, 0.036657222907149026, 0.022147354827592933, 0.043646338801350326, 0.014176165925398951, 0.012253350352928525, 0.05220791910805049, 0.0798117524133094, 0.020327269730548707, 0.007452542589406573, 0.03309729276224971, 0.04202176508824191, 0.03450917365450052, 0.026516124433387193, 0.0819140738777576, 0.046010007330727194, 0.059033517365253745, 0.01958876480198195, 0.007189907539155215, 0.044121271179568385, 0.014127128637365758, 0.021446918723203486, 0.022296604077001254, 0.07984615742198883, 0.0062893209096434866, 0.051829690008514354, 0.05467023294899733, 0.026134221942254135, 0.06543707012409164, 0.08485780503120154, 0.019704781157234987, 0.0506707253835855, 0.030519018107424342, 0.04439074643737367, 0.04210393950943986, 0.028133772711660114, 0.20047453051853567, 0.08764349224586641, 0.12752255154473166, 0.12294493870989931, 0.14311132231546989, 0.12558361365189477, 0.17896224534319294, 0.18282476872686418, 0.12698999786328885, 0.12094757895195678, 0.0841572099635678, 0.17570750547512887, 0.19814424427045932, 0.19974706874739742, 0.1498703934973286, 0.18396372696565044, 0.09494855429135984, 0.13154909435299136, 0.21365260645266504, 0.17913070807774223, 0.12348943570208167, 0.15078131800457356, 0.25537358626963635, 0.11331693719952338, 0.11637667704734111, 0.06342281046653948, 0.08410723038738774, 0.14541470355564548, 0.10459940054363782, 0.2033762570710913, 0.22999782776159627, 0.1748088383746724, 0.17964602478088873, 0.06445126052224828, 0.16918814320477749, 0.2008369207502373, 0.1303264486693567, 0.10810593819065441, 0.11056982251184602, 0.22709525851232393, 0.17906330766216402, 0.1658847567535216, 0.10104855237108085, 0.14035950384793744, 0.14123832927115504, 0.1861115004266462, 0.16268091576714672, 0.04971560526398882, 0.20781277949290894, 0.14468949408300463, 0.15842450061632743, 0.13285294535659975, 0.132267608217174, 0.10303891774627472, 0.11981612071394922, 0.18738423293877035, 0.19267384022954973, 0.11387765993394199, 0.13529569331196048, 0.09907756135949206, 0.1883554179221392, 0.12509982912771164, 0.1491439736057674, 0.07481865179274352, 0.22268611607292008, 0.1292868673561081, 0.19542613367159523, 0.10878418647353688, 0.09939518141289873, 0.1302352075975749, 0.20232958178366386, 0.11306503982914072, 0.1420677726667735, 0.2578281166572725, 0.1278463003015326, 0.10794830793935446, 0.12318489276954245, 0.13892204711033454, 0.17435275558983127, 0.14380821717842934, 0.17308075852211446, 0.215652157222071, 0.2191970299088186, 0.07851571550652867, 0.1269767981683535, 0.22162444078393523, 0.12215671850548637, 0.15602321333942876, 0.12361019414158599, 0.1656454002424594, 0.14778939225981313, 0.15114672662269685, 0.10986611712723972, 0.13666452389330636, 0.06735328584909439, 0.156197574950995, 0.11703516026177715, 0.1915909596268208, 0.08587226632141298, 0.2608294346399846, 0.11907904453936125, 0.17576817963873187, 0.14320014254941096, 0.13944343122984135, 0.09972589390893137, 0.1227052374592712, 0.17075490026224047, 0.12496772492604873, 0.16938240778061653, 0.15635414800095945, 0.21975245897568044, 0.11142403353005649, 0.19657056177816085, 0.1845541509288934, 0.14685850350126145, 0.176403664893681, 0.16428659009116311, 0.19736378453671935, 0.11362550975454432, 0.1911910464085879, 0.16572055346783132, 0.10735259796943396, 0.17020818927595693, 0.2973910114697872, 0.2221837768992109, 0.18003676026578874, 0.12440647359096235, 0.1407761790699536, 0.14677472412586212, 0.11080166370037103, 0.1678680051718989, 0.10670075673730144, 0.11767799229992014, 0.07671978324651718, 0.11821570941397261, 0.15191322823445644, 0.23316475863177932, 0.15952843331521557, 0.0947980486577557, 0.12231543660163881, 0.055314796345849196, 0.13115480422012268, 0.13859567833283257, 0.14364052053180434, 0.12936988064358312, 0.11640185069653297, 0.14185086253189272, 0.17092955298721793, 0.15112852437361596, 0.13040923213045444, 0.09808167004056516, 0.16693825022347514, 0.1811213262619511, 0.0999644690103108, 0.2391434466886905, 0.11100946504983211, 0.17493282204433797, 0.0959273465278168, 0.12342359044498975, 0.1719842721978503, 0.21246789744304073, 0.14011512180009197, 0.20642643614161402, 0.23504323686563203, 0.09282522669602787, 0.12304593974183645, 0.1278591705786605, 0.08434209762321365, 0.1522924417569753, 0.15020240068195329, 0.262210997602632, 0.10492363193583105, 0.16300074215377533, 0.12666640998495202, 0.11608194004023269, 0.10354486519410726], [0.04387151885537371, 0.03943935930428486, 0.04256148935265599, 0.033454006282432426, 0.04999898501761979, 0.04438802299480285, 0.0683785872834344, 0.09706914695280214, 0.0031931392168776406, 0.013312092482773288, 0.02556711769542627, 0.06509367121203292, 0.035496806545603665, 0.039704640230704705, 0.07596117234037769, 0.03714167009738665, 0.047299612929383596, 0.021730166326667515, 0.02690940524541563, 0.04937722422783414, 0.02079803267523887, 0.04733270792771251, 0.06114859419364122, 0.08556006250963097, 0.041503441489992604, 0.06072715390473605, 0.030583568675924214, 0.05135432479061908, 0.04073145085825555, 0.03104903220739817, 0.07188579142694512, 0.056207012985983205, 0.02563347048576801, 0.05937116678744074, 0.008668951359727691, 0.0522444308585217, 0.04023274677174707, 0.0387456322148923, 0.004398698745776088, 0.013995791481237018, 0.026497171418140494, 0.08899930699337875, 0.012214565236542014, 0.008430329335462904, 0.049403910900676445, 0.013685135167062044, 0.018562538316473365, 0.07825512303820542, 0.08140389762458303, 0.02233873891283668, 0.02117598215268264, 0.06915363843642897, 0.041521264525550994, 0.01528429487089236, 0.05969729041680694, 0.034001728504775994, 0.04085115975730362, 0.05932044793641376, 0.04876639551272796, 0.03623240417049777, 0.04776606088384025, 0.060758862283922015, 0.030784329677361156, 0.04279409279866565, 0.03282736934300873, 0.03649349076553218, 0.03902333142656473, 0.06461786166314157, 0.01856852720882143, 0.08269474811611638, 0.049200058734465035, 0.06165038178404493, 0.03686408579890286, 0.03598925935465001, 0.007138905235596242, 0.056664513033484264, 0.010888097402189049, 0.03718711060261534, 0.049512840942629886, 0.02646621380512032, 0.10497636942853851, 0.060493956740585074, 0.036803292891671585, 0.018240329396400242, 0.06301218350868552, 0.04590265542989777, 0.032982705160975456, 0.017730417443559538, 0.07743763827508496, 0.01891580444099682, 0.06109520552619811, 0.028992963301378395, 0.06514057877563662, 0.016401457908232848, 0.044870918856993805, 0.032756069539895946, 0.09214149322360755, 0.030538312031797347, 0.04259717372816898, 0.05038785124798456, 0.011843492355828565, 0.03111590976796804, 0.018923323593973633, 0.0208494390901779, 0.04862677981896747, 0.06465025186058014, 0.026441105273402026, 0.033921051785470016, 0.09591685878413339, 0.06539449095726013, 0.04450582816535908, 0.016078708896173105, 0.009027707461838522, 0.03431063813848361, 0.056146116656882156, 0.041526630971460574, 0.012904834396566355, 0.025805748338180206, 0.0451076630082342, 0.011423272061942807, 0.01235916337464005, 0.02943240474128435, 0.03246511700713346, 0.045219327984077316, 0.009096074105811217, 0.06052942661147925, 0.04819430786395266, 0.035273139515230735, 0.023589547903787707, 0.016037659989970348, 0.056593837592029766, 0.04821931680424079, 0.026118304550407395, 0.03400146420444212, 0.02534713171752951, 0.09865890963063126, 0.031150058137192845, 0.04900322010320041, 0.12375693828348192, 0.02367368734051143, 0.05255861883802761, 0.11460357420747319, 0.08665176078436837, 0.05546183160115635, 0.005128430052390022, 0.030280345329834573, 0.03483252404558082, 0.012430517761517438, 0.07636251814302898, 0.05439063766971231, 0.056790097826911565, 0.02345006244497434, 0.03133034926929301, 0.010234613869068845, 0.058545990501560514, 0.003399796222501825, 0.03896698949017352, 0.015254172293709652, 0.032484414761946086, 0.013378283437041026, 0.08867958785905954, 0.04724995894057136, 0.051670121554765976, 0.03303321333782327, 0.04556915437382075, 0.006984510748166472, 0.015678352304554034, 0.11169430934974264, 0.05906054111678274, 0.07918814152118661, 0.032478864454934676, 0.022902533659831654, 0.12207509183715429, 0.05623939169210292, 0.04427653804962193, 0.06976197353534161, 0.11919686120123633, 0.05417571936343467, 0.006534759680019512, 0.019199029061823122, 0.04383363580751804, 0.05041753715505043, 0.052198331517678116, 0.039022599812597036, 0.023822390752273704, 0.04082944116465027, 0.0345467196236695, 0.0070948274092628594, 0.07388328141983479, 0.027143500647657824, 0.029612778227836378, 0.039870310574769974, 0.022080113375259024, 0.01755195151593897, 0.024764502698916103, 0.006551075916391828, 0.02907022135332227, 0.0485352591250933, 0.013518268768224987, 0.024022192228585485, 0.027317247473664825, 0.09008742763750976, 0.03536890433620542, 0.045409536124357296, 0.025808278343550144, 0.08121534040377987, 0.09912677484774783, 0.030778559120071512, 0.10366649697384528, 0.02025156875231093, 0.031419052674825636, 0.011309883388270055, 0.033771768062105106, 0.037546532243610396, 0.02017812007257054, 0.030910002570899747, 0.017958709729775306, 0.032519064918761297, 0.043533654928567915, 0.043080709273776704, 0.05534999425553026, 0.023861026481514978, 0.028660793323069814, 0.0491340296162713, 0.0352889017742728, 0.007484256235447022, 0.010316496219245658, 0.033689164631669564, 0.04536261706943474, 0.10303118025823947, 0.040557196498998714, 0.014720077817929129, 0.04209855008089254, 0.016395273663464095, 0.011703510855084226, 0.04649012229375301, 0.03701749490574002, 0.038423756543066234, 0.025074172674888567, 0.038999716766298785, 0.09231542582593619, 0.06298502569176978, 0.07191979806990394, 0.02130867241160764, 0.0530534771631562, 0.04313930733910492, 0.012855197644732412, 0.03054701287539736, 0.0379603001619539, 0.005920388765873448, 0.020241008230274724, 0.027419863035902384, 0.024319380717051607, 0.03970027735997592, 0.16628447078889416, 0.012627023144535, 0.06819328593630945, 0.062194599154134916, 0.06371554032328629, 0.02227277874255613, 0.05939254447096779, 0.021701127763897664, 0.04240994950035407, 0.040573579289259455, 0.047037993903241815, 0.01653345102714675, 0.04269200392187603, 0.0430916796528524, 0.014570351678787943, 0.04918509320686421, 0.04922581461047934, 0.059822890531992724, 0.08705687573960713, 0.04452738970998795, 0.04443548597215165, 0.03775564360342199, 0.034495970129125544, 0.09769177725238186, 0.06518374783016982, 0.05981356341151461, 0.03730981873588697, 0.050781670236779805, 0.006777376852809422, 0.02353306998678994, 0.13286207712465717, 0.02942799973571974, 0.04266720565576707, 0.02056136130235128, 0.029919883724482312, 0.02875417369538017, 0.05249280422445267, 0.02412111141658839, 0.1505057102129344, 0.03684330183351713, 0.060792616117865815, 0.06279310151453942, 0.03227017444348143, 0.0376640118267988, 0.009629380468639636, 0.021267577540129427, 0.07181317395260257, 0.060773969537788824, 0.03567936912839932, 0.03516446228229231, 0.008598352527065624, 0.027517387943883097, 0.07963549090369094, 0.029482782683185035, 0.005347630790164394, 0.007898294199783837, 0.05390182377830629, 0.009871277518780723, 0.026233319245699434, 0.03978627072947641, 0.042509062125557856, 0.10362354242393088, 0.07398686416807675, 0.055125450054484035, 0.028715043839427735, 0.01283882826101035, 0.029298341269755078, 0.04942185651030272, 0.02898165009795658, 0.08730055298656227, 0.06461750160181715, 0.09475177694712916, 0.02412562175924259, 0.07029405224227137, 0.04226619693180246, 0.07681898397183226, 0.024602201226497852, 0.026927808592576655, 0.03535236832835982, 0.006471130811053539, 0.060200993227021354, 0.031180130918660474, 0.039413289332221595, 0.04956008941535989, 0.0412537734354696, 0.005160215519173372, 0.054699210224733244, 0.019771185658511617, 0.037670952583392786, 0.029031610521938533, 0.06311000910617652, 0.05609515648815901, 0.0626338318350815, 0.031261826534905744, 0.061246818156852845, 0.06710695027704201, 0.02810691175381503, 0.08572035108602817, 0.182700386691478, 0.1521666654415669, 0.10350464557808253, 0.18523235324650042, 0.13307394640099618, 0.23969930476478993, 0.16397270854682694, 0.14155008109106174, 0.1044626078838783, 0.11216163064443296, 0.1305157489954464, 0.15097886143672853, 0.15315220691263676, 0.1312261423276317, 0.17722066702140918, 0.16308858179517333, 0.12864183664562243, 0.07383897855517364, 0.16493204981088638, 0.10090759985389249, 0.12200084259553302, 0.12250023233073375, 0.20965405649715857, 0.1617667430471028, 0.17755324111109783, 0.17392910896770417, 0.12631502077584306, 0.15564819797873497, 0.1575752155434701, 0.16373068604978824, 0.17116353156105166, 0.10908513645371122, 0.24571930028257832, 0.2208826991338884, 0.12395599090884771, 0.13900953435128735, 0.19253697096099778, 0.17980889507359077, 0.12710017662855888, 0.09135390121129253, 0.06948521661181604, 0.1860661633432873, 0.14220965215035025, 0.13213841514962335, 0.1021222169360807, 0.21935721889378565, 0.08120728881969567, 0.20643055769464663, 0.23408994769617436, 0.15711738607816159, 0.1009469231470458, 0.12161222151330403, 0.1344755195802258, 0.1623948278927034, 0.1339575522128613, 0.11670155961426998, 0.14609512752823292, 0.17949642313103523, 0.1297241196997704, 0.17653279667419775, 0.161676574498415, 0.16486227452274294, 0.1478377630513522, 0.1498919205680009, 0.14962017385950013, 0.15853190614331156, 0.11291032837283228, 0.11878456800214707, 0.1420130280237044, 0.15669850452292353, 0.10822691879565678, 0.1445639782374905, 0.14383493832522823, 0.13793734833598137, 0.11779816851260201, 0.1612401495297109, 0.12526286029887776, 0.13645548914228717, 0.22532037068759242, 0.08405601740964959, 0.18371536126059873, 0.2372373126807713, 0.19152469302137054, 0.15644830020685352, 0.20827804001108294, 0.1976722881438271, 0.15389275346552173, 0.14165333442149625, 0.13866888569487681, 0.12073387872547874, 0.1626157523283074, 0.20972271329693257, 0.0865390845724652, 0.09477189441602077, 0.1734605236279388, 0.10937664823065843, 0.25662221765566257, 0.08542477904308228, 0.12072244869364847, 0.10205431856335172, 0.07903463282291928, 0.140286510990512, 0.15807643622880982, 0.14759482124880438, 0.1387646007201364, 0.27565516651638095, 0.13604377817002036, 0.1471355668599567, 0.3192664989300313, 0.10846668899419809, 0.1472487640116484, 0.13034083580057468, 0.12421468347911874, 0.14244928445306518, 0.17677232172460328, 0.09545670041153509, 0.21810247412612363, 0.11341545610658585, 0.13405343577746423, 0.19711097552170678, 0.12948056502688315, 0.10697077208709334, 0.0782409810551232, 0.08322398463684706, 0.22871593283789776, 0.3600617840645775, 0.12497404515142403, 0.13584082615711998, 0.12638530168201656, 0.15233613941217625, 0.16587852079781795, 0.2105862782486985, 0.2093559870075795, 0.10283862405847158, 0.12026633526529036, 0.2867521952477194, 0.09143730520360893, 0.09845940501339014, 0.19605297745475847, 0.2275386395593805, 0.12049488227574096, 0.3107013295014059, 0.23759564264647423, 0.1572236577950178, 0.2477728449288876, 0.09626364380481744, 0.11027025915081463, 0.08798833906410203, 0.17103142735938873, 0.12512791391101577, 0.15913495523554666, 0.16034637007021135, 0.09030229231763272, 0.1272571557051232, 0.09822746423343498, 0.06364340165389643, 0.12451845266285444, 0.1703008552712779, 0.1932530946308567, 0.22175015581230964, 0.17790487546834255, 0.18224041217998152, 0.17113330173155955, 0.17491281182775575, 0.11167927104378901, 0.13411438573272, 0.14866331472031533, 0.17165968074433266, 0.17181222417181538, 0.17406190264849894, 0.12729981914162636, 0.11157753456744457, 0.30652308596238015, 0.19640309495791314, 0.13739022366221876, 0.19929694612660717], [0.062483195966530236, 0.05798532522373623, 0.07842742387325534, 0.015857590065758317, 0.026137575492142674, 0.05178323060634637, 0.05031734051543379, 0.041488000987878734, 0.04544424373776682, 0.06813025222189965, 0.009801636296024006, 0.02548326171123453, 0.0698928366745672, 0.06832226449924131, 0.048667363326756224, 0.03499309990494963, 0.04267567092733037, 0.011653901873937538, 0.018449163049339287, 0.05846073257646734, 0.057048300100911054, 0.08241354022175074, 0.03561416355472419, 0.018304412651266304, 0.036043996336839856, 0.03541275903943085, 0.06877591878536247, 0.03460693796495757, 0.0488338572153401, 0.023304356352215814, 0.04158154032343338, 0.013379258283924673, 0.05283305834558222, 0.07048088576524489, 0.030961843740735805, 0.08711053253782373, 0.03699328269689314, 0.03447378039239876, 0.021220689128723838, 0.032245517903638464, 0.05144190396212282, 0.03178788570597047, 0.047581123428479324, 0.06285469498365157, 0.05539018705847764, 0.018876335591137893, 0.035942390095442533, 0.019241753785360246, 0.025156446687516668, 0.04746889154757223, 0.07414106234547592, 0.021656529955385674, 0.1125159846138089, 0.008677287353953768, 0.08199943905516018, 0.02595584986040429, 0.02888748257030403, 0.034364612863188794, 0.0105425821722395, 0.01617270596926251, 0.15172840186184453, 0.04009305063875453, 0.06463081620994114, 0.05186775308703223, 0.023302502419439056, 0.06628185826083345, 0.028327340147488063, 0.05861061767885282, 0.020659215628139434, 0.05648646653900224, 0.08512788166802737, 0.08539232755860976, 0.04046732289416175, 0.04961625515152851, 0.044424281936259045, 0.12505139704913865, 0.04019384865739173, 0.034764441811750015, 0.07977013085638324, 0.03996810935918362, 0.019391008780428, 0.08534279997430502, 0.06939265786880447, 0.025804463225687226, 0.06256021078555815, 0.010144160910239144, 0.03128541246687453, 0.02054450736801711, 0.03485941756216269, 0.036698764024843136, 0.07027536735779817, 0.008154743568851583, 0.05827042867519683, 0.032746868823925336, 0.024271929231021675, 0.04728458611474884, 0.06345710056203027, 0.05540648940950633, 0.008189659941220477, 0.01702477385650479, 0.06010936145039816, 0.03832465540918131, 0.03612429767306294, 0.08362985801913085, 0.013157659690947303, 0.027862003020521615, 0.04015895718288037, 0.044422374377327586, 0.014636180656511458, 0.02574353816828901, 0.009089641840076976, 0.04711690478988233, 0.03492838079710642, 0.06682882971701122, 0.052166941064980724, 0.12022724945939357, 0.03961472449103191, 0.08420920435098872, 0.09384611546392403, 0.08497409717810732, 0.060910995854365255, 0.031421255177607944, 0.016922650505758582, 0.028198857626487172, 0.08893893160406621, 0.05773961018290251, 0.049911402015676426, 0.01566091231295779, 0.056828704827855674, 0.05767577207617222, 0.12130692015371977, 0.07411647858398576, 0.049372688987322395, 0.011054837396518599, 0.020766481344077378, 0.05418014735163701, 0.04225783891254856, 0.030169025093557376, 0.04536899475140437, 0.05582871876897351, 0.05093537428746781, 0.03562948914364942, 0.019887102422334497, 0.024222512729465965, 0.04326362808745715, 0.04397418995898578, 0.022207531034045165, 0.06154453524598672, 0.048216911288158554, 0.05404311720462096, 0.0901993990485226, 0.03556932059807643, 0.07250479046976374, 0.05030881778727617, 0.07507321514910267, 0.047943505999301715, 0.010614798408031706, 0.012504531431101985, 0.02863488997513008, 0.07716972966708484, 0.07358795452502466, 0.02912167564875657, 0.018762332131905902, 0.08142524083415348, 0.03491463717974482, 0.0025517663368279297, 0.06791347998284525, 0.05036998990802996, 0.08418815991570873, 0.02597699963277386, 0.04217226306096681, 0.011182662039514513, 0.06251306190425832, 0.05848702854446827, 0.028683879382668004, 0.03396280740778293, 0.10886847146696622, 0.028183650781190204, 0.017444042286144632, 0.07121139656632178, 0.04399179082904612, 0.08236286350555959, 0.03410959751495431, 0.023280965772667722, 0.013797263626099355, 0.019964590300655654, 0.031104546768831152, 0.009465319866825257, 0.0319055299980626, 0.0829116505901179, 0.010009757487193472, 0.010831698009203519, 0.021469177407843452, 0.04338522156279895, 0.020562156118572723, 0.02208073007603807, 0.07680802125363581, 0.032995177072382746, 0.012086440861645726, 0.03173136182369725, 0.07740534766907654, 0.030582170565462405, 0.011517427140666593, 0.055882149571252454, 0.051224986166362806, 0.030345834356041688, 0.0400067278514466, 0.02079827973859445, 0.0398847934669785, 0.0398686673161724, 0.032999026664202256, 0.08368168386720842, 0.022049061916468125, 0.043107920716847145, 0.06165836058977631, 0.034844340951812845, 0.028865620336164872, 0.04599366284486267, 0.08035935206158508, 0.03667318434905141, 0.07164333992066883, 0.025551470349572843, 0.038340069098217834, 0.05005444212245846, 0.07215993599064889, 0.02834148021535047, 0.09635143748093998, 0.028442123101183006, 0.005066036021396999, 0.04025444621220231, 0.059940469706611293, 0.03109009260491979, 0.08905943723455553, 0.016705801657911752, 0.08656399009088356, 0.021377991877436157, 0.09014872999321069, 0.055621786929306485, 0.029049646146895907, 0.03254959352254387, 0.08682938593049204, 0.08815468739598029, 0.016679444402876883, 0.04967036011118082, 0.06070033316650699, 0.04307652260327051, 0.03549694061099041, 0.03369825809533077, 0.03896589781488142, 0.02750616475579239, 0.04267864334847658, 0.036081297157873074, 0.04986200466631882, 0.06204346532843286, 0.017353316408491904, 0.018687990959733725, 0.006527103110021281, 0.051198893211661815, 0.054678296024400386, 0.016433409520334775, 0.06110530639547975, 0.05106968482235267, 0.06780731551829847, 0.025018072056193507, 0.01380473681380071, 0.03602977391452559, 0.06041982241215245, 0.06331970269281058, 0.06499236374492608, 0.04671753166363605, 0.014160318439075304, 0.019178036337478027, 0.046883044959676844, 0.035895428905684146, 0.039067622799907005, 0.02935229492704234, 0.06456937595841385, 0.014292949326186171, 0.055353843847349773, 0.043987795680521, 0.02160931595661227, 0.011669166175828827, 0.025083884754548633, 0.06731640637641953, 0.04271145489427351, 0.07890198469883011, 0.02225565093178903, 0.050705390862159194, 0.058727204769609444, 0.042089502582506794, 0.042451923457725395, 0.02364429063163698, 0.02125533353987961, 0.05849368967896989, 0.06641902630367587, 0.053295392407885486, 0.03394820194150652, 0.028641771359909928, 0.034846627724266825, 0.05972654731463521, 0.03633832348690879, 0.06160682202467035, 0.021776122026025288, 0.030041710856641014, 0.09528494349891141, 0.0396425181609248, 0.06132232378266993, 0.08430574675120654, 0.013687091564098674, 0.02297854490367876, 0.04392683040350676, 0.048007141092732075, 0.012077431667656189, 0.016219749513472763, 0.034850944629720146, 0.041173533386280464, 0.02027611995506431, 0.035931756795053525, 0.022418009860801603, 0.038938655728294004, 0.02656984251863774, 0.06715796407191985, 0.06405233555743772, 0.06647744050790226, 0.023261817405000332, 0.037533937758135225, 0.04269678048008392, 0.03436404212768521, 0.022340841824188832, 0.01600305292560088, 0.02517791630159463, 0.04562648073319466, 0.06186960933489665, 0.009904444337852541, 0.013366220425063325, 0.05329388704511428, 0.057562421706895676, 0.019710513410128413, 0.03361948510451663, 0.07830642028561524, 0.06100252420911866, 0.03675946883196312, 0.027057195097328197, 0.048678356688469655, 0.041669008412188104, 0.027367041273523244, 0.019726193314718626, 0.05638167720227953, 0.0476309995827896, 0.009632605698800856, 0.013404549719134887, 0.04750525774133783, 0.2217134755224951, 0.12587982920869706, 0.12425733159386343, 0.14803503069185442, 0.13874627589698763, 0.12358718086034061, 0.16053121176458177, 0.18523878838506438, 0.09923250264217777, 0.20182404036243118, 0.15824771816692046, 0.16501172295501157, 0.15782981720422545, 0.15389911199529327, 0.10111894819044298, 0.12031983884592211, 0.07418823037897387, 0.15537196199499792, 0.14611789566134253, 0.11337788715477913, 0.19976727814683992, 0.11421804045957905, 0.08816561947065978, 0.08063060847381431, 0.13296062667523662, 0.18850279791701227, 0.13214270524199934, 0.21229592602579825, 0.11613798703277305, 0.13938900834370044, 0.18300642349546958, 0.15631578231771148, 0.17352947154112403, 0.10909784585237504, 0.0984308529164522, 0.1683732095144449, 0.1260616371948873, 0.08838113532551835, 0.08282008776140791, 0.14883671106109697, 0.17849500831817428, 0.13273741929761826, 0.12711417305493547, 0.11892638619868987, 0.13323680137193974, 0.08834021856948253, 0.15189790647597085, 0.08933313746726321, 0.19424378421277771, 0.23911788999553651, 0.12697613933273863, 0.13494307836217267, 0.1300278122747137, 0.09821580437522742, 0.23684683766576553, 0.11868516043309243, 0.1231647140136169, 0.10753265927515684, 0.238598313843531, 0.1090930961072445, 0.3130690008401871, 0.08822424817950496, 0.10073167542296071, 0.12326450462663367, 0.15341093012642476, 0.14606433079367684, 0.12569492622729272, 0.11673516789150816, 0.09705392478574669, 0.19716230341263358, 0.1164492485564082, 0.1570446536906304, 0.15415038883445725, 0.0922330100870421, 0.11388584175297331, 0.1857013829172619, 0.20367461767408157, 0.1871226751996625, 0.16204394430162447, 0.160003392506511, 0.09777132782243914, 0.14553462695931235, 0.174627214249584, 0.09539704514487136, 0.18342605581687343, 0.09047289243749074, 0.16765330137024004, 0.17316400163596676, 0.10010589650201221, 0.1297385221527469, 0.23985387066439276, 0.16203579312611013, 0.14696479053987613, 0.09913369262170407, 0.12363007412322106, 0.10017557219872553, 0.14716994888599844, 0.08770565262004253, 0.11194407699569581, 0.1365576699496277, 0.2252738538288301, 0.12424453026464871, 0.10152538081691151, 0.1463530233670627, 0.1355276647354326, 0.0694880358153774, 0.09442743830262654, 0.17547052383663195, 0.07921432640643851, 0.15717377014938863, 0.11806363330012369, 0.1184480332378899, 0.23121793003332233, 0.1835010558246605, 0.17532947172801341, 0.19440746655867946, 0.11669685583441489, 0.24508790593714486, 0.2572418448905791, 0.24470536759303463, 0.10212767914298082, 0.129590422035225, 0.1283608126123586, 0.19260688414496763, 0.19607056683349997, 0.1743044001200507, 0.10584070812910797, 0.13708371188371413, 0.162459684896373, 0.1334869290792173, 0.19511372301607363, 0.16366636530766565, 0.10362976305787602, 0.12112406262707327, 0.08672718214051378, 0.14561598549687094, 0.1449898618363565, 0.11306396730604673, 0.11178063213705056, 0.21884095224161304, 0.12485790622210312, 0.09502144755735513, 0.08655552481932026, 0.13060459987290446, 0.3182022189421039, 0.21508336758180974, 0.1243312054524018, 0.15168194629011617, 0.10291282733481738, 0.16593826033415335, 0.2528165839612484, 0.1370006985962391, 0.1254003884030446, 0.07095366926683534, 0.10458034793696097, 0.1641463960010198, 0.14290510676801205, 0.09714027821657159, 0.09588524233549835, 0.1836417095675584, 0.1685818918650189, 0.1700719481995029, 0.16466264733143393, 0.16037197272864082, 0.1697364476539435, 0.12424950217527729, 0.0840602768585086, 0.185098119320408, 0.18674186821426117, 0.2065155628107248, 0.07587024536464484, 0.16004152836338167, 0.11978564573632133, 0.18923444252821708, 0.14369160327459538, 0.1372109744096956], [0.07102503801786131, 0.03861368506125385, 0.013449536317268447, 0.055347247830321716, 0.07303875375298724, 0.0755481053924849, 0.06944296686279197, 0.02554311424553875, 0.04867212839364525, 0.03338088319005986, 0.043252071651119384, 0.053613158017997785, 0.01859018642966065, 0.036971495156326604, 0.036758342682714426, 0.04872827114717615, 0.03371024354090614, 0.03819456984919887, 0.026912009944358183, 0.03903876809823898, 0.08749946005522244, 0.060510894944590915, 0.036964799547868396, 0.045070699265887665, 0.10145143801045996, 0.04419871117739428, 0.03228526637558976, 0.014914909298832138, 0.02831903192394924, 0.01868016154114758, 0.023548205968953913, 0.016642063142611616, 0.09294262200954462, 0.00043104089678719555, 0.05174162437117869, 0.024073181125605782, 0.06877956536388205, 0.060324206978323004, 0.03249331670362623, 0.05042197280413201, 0.05138533602979395, 0.014175090529475243, 0.04179830107116892, 0.033893373028765765, 0.06156860955900723, 0.0201715623599387, 0.027531911055707646, 0.06296292022471467, 0.030377921948750174, 0.04245957667608896, 0.05909752401132738, 0.0420878746456677, 0.029826811702561476, 0.046502996401320544, 0.0317958204616462, 0.06018602769942053, 0.018201189964348753, 0.01422142448474563, 0.041248437633076986, 0.055032592537182, 0.012949128642738348, 0.03810320620334918, 0.04318830249230227, 0.07048978004604578, 0.00886007593268709, 0.02179505205863426, 0.036381641928587234, 0.06069039700612907, 0.016137372078974883, 0.06563256044060954, 0.05382253750858288, 0.01874017878435552, 0.057737189345061786, 0.021229054808856982, 0.05906523340531896, 0.04017435171971879, 0.054365724490414706, 0.028970808038608204, 0.03724366704362535, 0.07787911176321008, 0.03971989304127713, 0.02748974940679487, 0.036097817843960184, 0.041647986959545844, 0.025380604014161135, 0.12873744441857263, 0.034007359251019456, 0.012538081294135943, 0.029002907122635556, 0.017588139594262166, 0.028131639156790993, 0.05721981952627821, 0.019860118890421528, 0.05596705126546084, 0.03165820234214827, 0.04607851091291636, 0.017851275474494024, 0.06739201925454602, 0.03712901049443791, 0.05042605222232881, 0.01567508685477679, 0.01879433353972291, 0.06252185659362905, 0.04492776258097542, 0.029689013552401337, 0.04745625875770085, 0.10276080484712317, 0.10966032292814025, 0.020879410364995563, 0.04618486689944421, 0.0025006153643311515, 0.027746118815435518, 0.02407342244330193, 0.06551514214445507, 0.0430584620804556, 0.039902130036704966, 0.02659070692325552, 0.050849059161039135, 0.03541584254332608, 0.05326388321155983, 0.06153999617503536, 0.06828902394420679, 0.012260975800604831, 0.009942645312196786, 0.0285990811103294, 0.030538685499660434, 0.0571719428614503, 0.028232575071254568, 0.026811803728642485, 0.014754259703500618, 0.05286961223088926, 0.1147505481757464, 0.03748732513838238, 0.04044827411792452, 0.030752481487129005, 0.03846943453555146, 0.028960933165264227, 0.04081824478963691, 0.028433079433236873, 0.050366144146650076, 0.03625287787027417, 0.03249310219900743, 0.01892991961100169, 0.029382247049661896, 0.010196606331925479, 0.019956251433599862, 0.035390753163805896, 0.010504533457870205, 0.08492494497688548, 0.018264729296788573, 0.03717441652571002, 0.02759078299746879, 0.0340570860181845, 0.0416576434978314, 0.023879596452799537, 0.018568241841069633, 0.009994077582603261, 0.03501435118396917, 0.04307450396159003, 0.03683974718554847, 0.08534520549038727, 0.012937640196703857, 0.021738254299928105, 0.08344058067567887, 0.04161078956038241, 0.03005609224219957, 0.03365572489377472, 0.03560659843647192, 0.06956476718187332, 0.038129226379697366, 0.045347770285462184, 0.02731433825477237, 0.08411643876423759, 0.036181984093761256, 0.016935379056620504, 0.052558044272084395, 0.01963743436781149, 0.06018828765879716, 0.04123046137993375, 0.02053964270969793, 0.008671092575476056, 0.040762385488637996, 0.05424437616320868, 0.0738218794727037, 0.052316109875157, 0.08516653080380733, 0.03884764831332911, 0.033162640062190836, 0.014439230942497812, 0.06591094147053457, 0.04828170700479419, 0.014975347890398436, 0.06961738210051291, 0.018567276570285042, 0.03929117491709129, 0.030142227337966045, 0.041105861009489146, 0.028054570711608377, 0.0236110768896798, 0.045795981516881336, 0.026391945411300948, 0.039656024291029865, 0.03258236293350497, 0.04148869429745021, 0.016136443197366693, 0.06596462125138891, 0.03860397872725322, 0.03523473935802618, 0.06444998881629398, 0.013439203706389714, 0.05019187829607437, 0.05933989507837161, 0.03758893521021932, 0.036040947306901217, 0.04774836042234975, 0.049594007958207405, 0.0698786257435718, 0.06224115814773306, 0.06143972675706591, 0.054139889431216066, 0.03577529865827772, 0.011331360663227256, 0.03604753183261041, 0.10871976613998414, 0.05388737919049398, 0.08205867297346554, 0.025533649229234266, 0.027013849842572407, 0.012840182321416515, 0.04344317994471039, 0.012716945587477137, 0.059268821271196495, 0.019369941362510287, 0.033145468201368086, 0.058678527542900656, 0.003808660459922507, 0.11665081395016563, 0.012664684984502534, 0.01778778593776928, 0.04837549148848461, 0.05332638449486225, 0.04419652782681008, 0.04620097006761259, 0.025032079973888975, 0.03687436286840708, 0.08462644647806884, 0.06820073231093346, 0.08087503648693524, 0.021737114744140737, 0.01501146319036883, 0.05394858195476475, 0.06364947673113597, 0.031171259620497306, 0.026570085751553698, 0.017157255356470426, 0.06111676707082699, 0.03404531507722793, 0.06541985612843307, 0.06135561030297991, 0.08507522078411234, 0.02498202953457592, 0.016631106170074596, 0.0028980936199772146, 0.01184110216150481, 0.027268819225531434, 0.05141483424531837, 0.015457766862856525, 0.059323588896903305, 0.0072760507746058856, 0.03706104317379575, 0.024705649909353065, 0.008780201690481796, 0.07561117741129092, 0.03454119612973544, 0.045920547413369345, 0.027229166514570677, 0.018266504705553094, 0.01913971853472533, 0.03804461962933983, 0.020656017211055564, 0.02565466622341304, 0.01363126003378702, 0.11440488164343181, 0.015247358899233083, 0.02717353512472924, 0.051424483122724685, 0.02282683842725331, 0.04157659522588215, 0.026020463631157915, 0.08985319625466101, 0.03819195365893745, 0.00815288005997577, 0.03910082505054532, 0.07808598614628277, 0.05760923350950884, 0.05307843247728963, 0.024799465036560452, 0.006953628307523867, 0.036930605213368134, 0.002567043805855417, 0.049739966859980944, 0.043735024969904654, 0.03312482213180873, 0.08849505259985886, 0.03237615504692639, 0.05735449012248747, 0.030134018705857378, 0.09737683850671015, 0.05181403117134206, 0.023628162565611066, 0.026187714031567017, 0.05654232200956153, 0.044476272493240335, 0.03619727137829027, 0.03155523629468535, 0.02560620350132306, 0.0292475170816385, 0.11139380370056438, 0.010205204711265622, 0.041956789340944066, 0.018934883860751026, 0.045537273624851826, 0.01115154737846986, 0.010537398629821839, 0.1294766886219863, 0.019485934735125592, 0.027657158770448262, 0.03967264839898675, 0.03042987803177488, 0.013094298473949875, 0.009346287997980273, 0.031022856898245313, 0.049681115985637715, 0.0486149016257015, 0.01176603224819466, 0.026187300344087908, 0.04198305849586764, 0.030858042657435424, 0.05799814187470944, 0.04271515126850817, 0.039836376710163976, 0.06827737174687848, 0.05910770531984107, 0.04378114729338596, 0.10420468140153155, 0.04840555277863338, 0.010310763008742323, 0.013458939088929086, 0.002973439564342581, 0.055181830295271454, 0.008292378925327814, 0.05285476544691671, 0.1004286340227531, 0.19121732322439072, 0.1238534193966658, 0.1789039460521552, 0.10876808330536851, 0.25997959798382175, 0.2218955286568211, 0.17563599882827652, 0.15085578175081363, 0.2621179638851074, 0.1064859839877294, 0.09830058732580754, 0.11102056566385493, 0.189384120786863, 0.18423484548205332, 0.16907923614546178, 0.12380531673590023, 0.10042554668841824, 0.15046190530542405, 0.1749694104036016, 0.18514973832474602, 0.24337989758820305, 0.08332063428937428, 0.13623969749577586, 0.1523420382891932, 0.21577975682673917, 0.12268844481197097, 0.14379896283630403, 0.08117861414868986, 0.08584745273354553, 0.11462217482227473, 0.10892913796968999, 0.23177581058154184, 0.14019359984705526, 0.13463472797264978, 0.16997658557468848, 0.17592780171863495, 0.11386874267050337, 0.07410597551854388, 0.15582488849759102, 0.256154352438546, 0.11135764435053834, 0.10945986070099378, 0.11790701428488379, 0.1490566549041579, 0.10628444923748893, 0.17447286285459998, 0.18052164795658282, 0.1745765451942721, 0.13036435469985008, 0.19829542406143683, 0.134868185606695, 0.10131716577997131, 0.1380577467141613, 0.13820466705627982, 0.1175957834047656, 0.09962117735056147, 0.16040125260910681, 0.1456592694645928, 0.10385672426632336, 0.2100817174200089, 0.10844477121868443, 0.10016373614029539, 0.2214669943937371, 0.1063919313732655, 0.17034628428518775, 0.10889198270536239, 0.15057634351955307, 0.1206079108880893, 0.20279793729705198, 0.17395979844995085, 0.13589580062656634, 0.1634896901105681, 0.15146638446998212, 0.26513674867249304, 0.2723480262342961, 0.15981410750217978, 0.2024776359359103, 0.11830374823823092, 0.14448298742213558, 0.14980017387818906, 0.1296324649405095, 0.12529738022074585, 0.27596435960262056, 0.10910723809032671, 0.23862541803429205, 0.14314524468875703, 0.16100235583801425, 0.10607933685664209, 0.08357042491796517, 0.1177852446093194, 0.18660262407314393, 0.08284395140024924, 0.17538721943574567, 0.10868132384794374, 0.1524518033669841, 0.2098674885928631, 0.14656087834267847, 0.1299285579232439, 0.1089007544120954, 0.10767482987214481, 0.11574630159884693, 0.09212113060658017, 0.10971510587560554, 0.18316629072350843, 0.10158531187522797, 0.23244690360321155, 0.18260199035848343, 0.07607799308795123, 0.12298988508841685, 0.14292490247997547, 0.11438822689195795, 0.15757777427713718, 0.3169408398530176, 0.11103357383680922, 0.11394655422097254, 0.07644697933668092, 0.16402552264832682, 0.12755998260071202, 0.19457951458471437, 0.10005048536244901, 0.13794165375011583, 0.11468693223451415, 0.08461662523087957, 0.134886832186772, 0.1753739814364141, 0.15124988802258046, 0.16549213669232785, 0.24508516334237593, 0.09537600070959139, 0.15000292670822915, 0.2263090837626688, 0.171848843174596, 0.0967033552907167, 0.11229043300714224, 0.1532100925161954, 0.08192115253017795, 0.12821810575382364, 0.1305414129409098, 0.15715817259925027, 0.15969518001281446, 0.14139287984899937, 0.13043915552477683, 0.07817812354093598, 0.23666892140623064, 0.1518452302702973, 0.17235242341074253, 0.12830337900067532, 0.24742373866179299, 0.12567259476429996, 0.10422252358928805, 0.14891449962892842, 0.10024770703767577, 0.08984640871565189, 0.14505484141409397, 0.17234375129543966, 0.18220246018421266, 0.11977198638863142, 0.10835580542803773, 0.2023977023218909, 0.23032761329124052, 0.11233632933468589, 0.15601447993709197, 0.29385438188910484, 0.16249987386888073, 0.143987451109194, 0.1541073500148712, 0.17447428777813914, 0.1768907742394555, 0.12873168343738203, 0.08234249322765297, 0.10009193838003183, 0.16458188634245627, 0.15147882573787244, 0.0786676000983965, 0.12098408304154874], [0.08713242733069966, 0.05831640927241214, 0.030607106727397734, 0.019130021776823748, 0.05409927527991034, 0.010449383745811159, 0.03576093067925784, 0.06505537447669814, 0.030848455067063053, 0.007283252479899074, 0.04499617806305328, 0.03821037424307677, 0.05377029031214695, 0.01603527649891593, 0.054848195173807686, 0.014942154258249268, 0.03921564630863648, 0.05433844409943108, 0.02256571352782269, 0.03743759071033809, 0.02989616372712678, 0.027179035636025573, 0.033886803824815064, 0.03230961264982339, 0.037146178524821036, 0.03983825362557846, 0.04074133722291839, 0.0503344357674641, 0.04062645084735367, 0.006801902678900309, 0.020705763130418716, 0.011615835922589947, 0.0721605641827468, 0.037772700551056096, 0.023043660462022792, 0.024299270909039244, 0.03854693582041129, 0.07296327110980788, 0.01836299731005584, 0.04334378769741424, 0.03541794162423861, 0.06217368112336244, 0.016447848362487652, 0.015787776473218638, 0.08853780796691295, 0.011725136559576759, 0.0363588163388833, 0.01670268368005993, 0.05834461279934453, 0.09318533398571516, 0.06579221316402958, 0.04577562656073321, 0.07739472969044602, 0.018193578880821026, 0.050440722806078774, 0.04652344328801959, 0.043340225388566335, 0.042250764090567834, 0.021214072044277867, 0.08625163306151667, 0.050262764411708044, 0.07551331733984333, 0.012830149442438158, 0.024619549287543185, 0.00959175597545841, 0.053402307638598066, 0.030146128640720443, 0.015981347739486205, 0.015048052507242369, 0.03708684118464589, 0.02251338206171509, 0.044702398665850206, 0.021300789366866794, 0.002714144896843561, 0.1025527353668886, 0.040127670152052757, 0.03867310284066104, 0.03863834926197606, 0.030219891416509787, 0.06386517261665675, 0.040311148209917935, 0.07293975987141171, 0.06914207816965158, 0.02736849875579919, 0.007235627187671321, 0.04242504909334164, 0.029000371371606187, 0.02609589456340238, 0.016576085735352773, 0.02945676825249628, 0.0357073926246695, 0.030005082277761354, 0.042590719437406915, 0.06899526507984247, 0.04638851222191607, 0.02169548744155515, 0.02708961976872337, 0.0117481239853547, 0.04307889747583578, 0.0210394365562787, 0.02301849638892999, 0.023594734319035086, 0.020998552358979662, 0.043338451895021626, 0.025546335645260352, 0.0818994492592831, 0.021285551878052856, 0.06399757942304977, 0.06761577821546985, 0.08163406108055385, 0.025164389104071646, 0.03261353122070432, 0.0279626363302551, 0.038547165646788575, 0.010499934057494806, 0.020802914570536346, 0.039029475451717456, 0.020987940126008565, 0.05471005419930143, 0.025216057904124744, 0.04441384781873034, 0.02186912701525275, 0.04201703066486986, 0.0080469693620539, 0.05536207929253579, 0.05595012072233423, 0.005003017628745687, 0.016692615369515076, 0.039421126411686984, 0.016392071415940603, 0.015285768632536695, 0.019495066503183018, 0.01927162163830813, 0.0719934574238235, 0.06553418709025269, 0.11875313541461384, 0.03379871520484167, 0.033372938858285066, 0.04630385950628308, 0.08033034797277182, 0.02369957153625306, 0.02915689271063574, 0.014627860941653772, 0.10475238064123739, 0.02484424670617427, 0.04244587136312358, 0.025632633534710736, 0.03947193719326489, 0.06660088025514158, 0.077897030559759, 0.054538339421513586, 0.03698003703668233, 0.00517995952020189, 0.036478663133757736, 0.010913991174029728, 0.03029345500943882, 0.029292946095548333, 0.02198526594457367, 0.01563366543832085, 0.03405390292285912, 0.03945999388252536, 0.040838607406664285, 0.006085205879513055, 0.035426567774266005, 0.04372583957569253, 0.023980241253851883, 0.04138475531832345, 0.06600939909056311, 0.03484074416900835, 0.036229615610453396, 0.02829731716173551, 0.05403053038002503, 0.10066890983932442, 0.020302841101863214, 0.08043751601249942, 0.04039258335626895, 0.039291929513696706, 0.04750198654590115, 0.07204685375214585, 0.036972441274913094, 0.024102501225687807, 0.0604209945266766, 0.01293520690993436, 0.018109506476790677, 0.04989496942970061, 0.02266554819089511, 0.08939962623821152, 0.10924059867618546, 0.03696573417513602, 0.023698820770087264, 0.019806988777652867, 0.05902505975456969, 0.037313871341006416, 0.025328437256957256, 0.014370234191207396, 0.05585707551349075, 0.043059059629036535, 0.028409696514568025, 0.04131124535154912, 0.06543215950049701, 0.0236655380802169, 0.023451060274495714, 0.04315369830076252, 0.05255279656980307, 0.09080677653752989, 0.03697011236762328, 0.013812610282442503, 0.009141078898532978, 0.04627063044256741, 0.012206468644792275, 0.10173271485273877, 0.03234477225510824, 0.054424969900038936, 0.038506988165599686, 0.027032065498191985, 0.038777060971985904, 0.013033801468179352, 0.06416674695848938, 0.020456725183213433, 0.031693208729848266, 0.0609415551016648, 0.018223944690919692, 0.06836950148065245, 0.09667217551219849, 0.055560450099648974, 0.033874822209679314, 0.08223293499360163, 0.14652749223093833, 0.05780077464277706, 0.030478430769195965, 0.04788760839390659, 0.053650025999353784, 0.012085470802811606, 0.024010348509276108, 0.03049762127169919, 0.06366405538433502, 0.02312291800344904, 0.047147000553987684, 0.00350873775577413, 0.016817075928913492, 0.010488233979671233, 0.019866069478373376, 0.015920219668788056, 0.04626772696933439, 0.03522494875435387, 0.048498521378684434, 0.024496170827337814, 0.04488310731586911, 0.010000975246751502, 0.013083658470291526, 0.12045137614252106, 0.014245652015351001, 0.008496470494015564, 0.0349104275266009, 0.04276692349043104, 0.06771700141290504, 0.09923496178441471, 0.029720744914225036, 0.040934548427861546, 0.04272195412927578, 0.025790744506183173, 0.020033781446756858, 0.047956326480714545, 0.014626519330176375, 0.041051327040599245, 0.026576685599021377, 0.026904917885399154, 0.04449224159602196, 0.02804480117535399, 0.043824109504179615, 0.009076567592039224, 0.008811142066523673, 0.07515659615878137, 0.032609141536898194, 0.04878298131628864, 0.019582978922933824, 0.027715289522142663, 0.09126999160094608, 0.05602271521403905, 0.019048803050311345, 0.028101315481528163, 0.0415713245409631, 0.011578521695018057, 0.08030050118724186, 0.13132532007030903, 0.04017616734809933, 0.010069173351380854, 0.08697648247283313, 0.03739347170677878, 0.01935894417035724, 0.021709144874025258, 0.023155107102807493, 0.0350142669142975, 0.03982729473782163, 0.04225600413196991, 0.07368743870287173, 0.018530408588929043, 0.06323712224501275, 0.05613064168081169, 0.018958567468930158, 0.06185080570679519, 0.015643291333089435, 0.05950206823106255, 0.00850849137115743, 0.04357544119439779, 0.013289061964549606, 0.020843965391958916, 0.03422428470765872, 0.040389484530615236, 0.01863367532590224, 0.034766655805851185, 0.10340356793735297, 0.05526978101941848, 0.061097193524361625, 0.015035530800120005, 0.042277102193404595, 0.010392967115847335, 0.05168614811414192, 0.0072812156436303935, 0.05530254276950033, 0.029113003533453714, 0.058772721883630565, 0.03632444580416045, 0.06069805022449263, 0.023011314314639857, 0.043958726474234176, 0.05813057166374019, 0.025382785449525522, 0.009799075647137098, 0.023323246165208762, 0.01899820868857205, 0.0536985844824343, 0.010399668469964977, 0.004257642806717946, 0.04021619544214299, 0.0483352565507014, 0.03151853876789251, 0.024286927317359278, 0.016968793896657806, 0.05135045987704108, 0.059911423482962196, 0.01484907457544919, 0.0552804334720056, 0.0387469383948032, 0.058854256621411735, 0.06327535769331359, 0.03255462288976677, 0.042632130320153894, 0.06691647783642815, 0.08220661221252334, 0.028962340851825093, 0.06860295145381844, 0.14070485628420307, 0.19992222709040489, 0.1617465183259018, 0.08212448758704048, 0.0930306761555614, 0.10832519255458348, 0.10565170657730873, 0.1744300232178742, 0.12352129729885249, 0.20841847924936205, 0.24530758931031152, 0.16771362313339788, 0.17994982460814138, 0.11313101532117975, 0.17063479299747175, 0.10601300896415788, 0.21148569611532075, 0.1526971200420972, 0.16037257027722177, 0.10088695378433313, 0.17340587091542062, 0.14274275741509854, 0.11552905438527947, 0.1030797578935181, 0.07772115209410269, 0.14832991325566847, 0.15478051147393643, 0.22070682066823208, 0.20804999095778312, 0.10687560864513922, 0.22250770951711366, 0.1130898610778874, 0.25006179307256976, 0.065397042030048, 0.20054691050562168, 0.11460502977452933, 0.19402704261724027, 0.13682909490120027, 0.0893589776129492, 0.14208419759187008, 0.12828827940768775, 0.16897903184496588, 0.11962538014256185, 0.09934085045730877, 0.19940203806805998, 0.14864543422816262, 0.14420886584106954, 0.13217241413170291, 0.1341206676536991, 0.18367201600584293, 0.15053514331098528, 0.31610166714076077, 0.11882016810798839, 0.1324047685991372, 0.11463335204508998, 0.1341043653026704, 0.10866834631850643, 0.19840666002804236, 0.1151363960196895, 0.16447786692409747, 0.12803686467269737, 0.14989657838258053, 0.09269439420031925, 0.09287552036825689, 0.09331507097569205, 0.18893819632789782, 0.20962797886421605, 0.14275051022489227, 0.11834137847707157, 0.2339991049901132, 0.1165115315046522, 0.11369075746305528, 0.14002515243426447, 0.10084776838700618, 0.2324323632544087, 0.1326757338979552, 0.0878561812362844, 0.12315294690309994, 0.1678297773844773, 0.14764288560517375, 0.16171072669807943, 0.19228774723747086, 0.12076146555163207, 0.15567881085218924, 0.13687351267905007, 0.14967594506038776, 0.11980027035479585, 0.07320949942955086, 0.11600621224891756, 0.11090086442568611, 0.14804215530955023, 0.10910473298281433, 0.11084101763704132, 0.1616098022749347, 0.15163968888021287, 0.11009985055293768, 0.09283628134477524, 0.14937360080019121, 0.15530590989416646, 0.10831260572998755, 0.09223092632788805, 0.21971628430389592, 0.16217269303817905, 0.08724675829251928, 0.11389082132448113, 0.159462503788452, 0.14413742048125114, 0.12484002572995041, 0.22310646851697277, 0.11840255059782537, 0.11442500677320266, 0.18513328275613247, 0.18075479915545833, 0.12320953781806654, 0.11897577588716823, 0.14330132744244992, 0.1523725898756135, 0.10578960240367921, 0.19866185923737867, 0.22101754593032025, 0.15133202796982181, 0.16637330634459374, 0.10472759003600768, 0.10480637451814068, 0.21152636006234155, 0.1257758940600099, 0.160118903243734, 0.11083016217115427, 0.13424313446927455, 0.0914024328812957, 0.09343543871035499, 0.14245018843681584, 0.07103779338180058, 0.13404185252804912, 0.23276441640430884, 0.22541971696961313, 0.11113966169256358, 0.1565715177885948, 0.11277090037061323, 0.2092813547219961, 0.14982864170545532, 0.2026191476972834, 0.086420570770579, 0.1971209653082394, 0.12505682095164253, 0.11544687613364189, 0.08144474543270566, 0.09477613088224204, 0.11531944506831708, 0.15470842260026163, 0.12843722222192636, 0.12349706593780749, 0.07536956860173134, 0.10319644074526527, 0.10610866270238355, 0.19096672054260008, 0.1305922965008405, 0.12113917754181933, 0.13147365001420822, 0.1212652602923974, 0.08239190589876906, 0.1115148302708422, 0.19916389197591813, 0.08572908448836497, 0.24520185385500234, 0.11960348534968593, 0.1070933461549782, 0.11709111532376659, 0.15874794293795863, 0.09228348762037293, 0.15319876973667454, 0.14712481098549982, 0.16176873487570595, 0.16420510897953666, 0.2207457685783025, 0.15199509239004505], [0.030229475176442536, 0.02185225392872047, 0.037294508468720226, 0.04140087763868994, 0.05937123956579355, 0.0279402110214916, 0.03014028147463837, 0.06046386097647971, 0.01881836380268778, 0.01614632573158991, 0.027635643191094843, 0.058299697064343965, 0.008537553874174915, 0.005237862360738819, 0.0069889047412171725, 0.0965905105394702, 0.02997685768341105, 0.07530402977980914, 0.07848950763863903, 0.0217848937327583, 0.042750054234338385, 0.03271852740116658, 0.06172205313980099, 0.06880698365069206, 0.020582480431203882, 0.04036092860323768, 0.06357606635579179, 0.026284047672825477, 0.021859144889599374, 0.08018809310611218, 0.02653420410840021, 0.030962219123818704, 0.04159842490128452, 0.05114124126492008, 0.037697635425795475, 0.02760859454170831, 0.058357172810863105, 0.043941615900445374, 0.03520186269475568, 0.028480165112282962, 0.04036215817435615, 0.026744916591973558, 0.06128075585189847, 0.023146379446130128, 0.01724918016172465, 0.038171066271681944, 0.05325398918601775, 0.03507451206866292, 0.08515603539924468, 0.02509442420916692, 0.043177845392135844, 0.020598901525860833, 0.027517431993938746, 0.05901621526948387, 0.04970435909326038, 0.10615804472998266, 0.0456647161814955, 0.02485102275386453, 0.027604262314496503, 0.0390510484876652, 0.04481062390691331, 0.05511256445559764, 0.03147020628074965, 0.010570239861525837, 0.04759772455379848, 0.045009485010298035, 0.017947568896136457, 0.04227505290820714, 0.05908204903525691, 0.0157359037022557, 0.02808178981555806, 0.01656332079531445, 0.024244947614328518, 0.023119664044990655, 0.024098285826884454, 0.05071841052643234, 0.05743174625921154, 0.0127669079266789, 0.05402005029722087, 0.05391193230846717, 0.04298214440143878, 0.020511912242058786, 0.022056730456590172, 0.0542461688089515, 0.004066521106588264, 0.09229785942983243, 0.046341462932046384, 0.13004753137788466, 0.0386963612700422, 0.0018943538499673108, 0.03294616276698728, 0.04737998704395948, 0.01300294248897943, 0.028998536591027534, 0.05309387297940351, 0.04066611121919367, 0.031174567205110387, 0.06098995270628122, 0.04229630035678706, 0.027158498733995423, 0.05099375784817723, 0.007874336236366823, 0.057884465918065085, 0.14100332413950276, 0.021108424689079967, 0.043448354868638905, 0.022521586863384135, 0.04383532503139108, 0.02008093798893594, 0.022334060030839136, 0.04148801630963722, 0.051465016834798365, 0.07347153214317176, 0.03149993815309098, 0.01349418487910542, 0.019649940753175367, 0.006103439250915882, 0.020663731716453068, 0.02787520654589659, 0.04900473695729048, 0.04417056510705621, 0.07870495454558442, 0.1452143102764122, 0.02298299778973864, 0.05366747365182927, 0.05158317057536014, 0.06595766517303644, 0.05595478236735348, 0.020149769073712732, 0.01655168391974463, 0.022492073326101227, 0.022055048893596378, 0.02650800773182944, 0.07374228293737096, 0.03353572105087581, 0.016785436497640707, 0.020850601628602996, 0.005962082143542507, 0.042949436277511625, 0.03586261352944759, 0.026479338806483056, 0.06611955487319539, 0.05679737566219223, 0.034722134606131626, 0.05641885161880524, 0.03960977173260143, 0.027405154147756197, 0.040169238082824216, 0.005073600182039363, 0.06414572167540751, 0.04205192980026046, 0.04779850470743353, 0.03612346263722547, 0.04051692325681929, 0.03716556054930534, 0.09754743862656817, 0.023379113127086914, 0.03337202338321555, 0.08014307011880221, 0.02888762812700964, 0.02479022410097382, 0.045120460507009304, 0.07731172406385023, 0.03005614778357408, 0.009443724805849695, 0.021652138356359738, 0.07894032739944036, 0.005859876438344439, 0.022710691837053147, 0.036985284738963654, 0.02212396807848446, 0.02571838750173488, 0.05802840617815814, 0.04651571729130322, 0.008340944111677668, 0.03907573950146476, 0.07331865163700235, 0.037093946650143594, 0.04724846123867939, 0.02077749577320872, 0.030856493244608565, 0.04674363610965591, 0.07052312019251047, 0.06836469810936721, 0.01855418987331852, 0.07005898582358515, 0.0189409819206283, 0.018275730319381244, 0.03310862320264982, 0.04147362534797961, 0.049313654251877344, 0.056170033921878186, 0.02307086424421399, 0.0831692629764157, 0.04103343505712767, 0.02368414827111748, 0.09773260207786676, 0.05695573752745987, 0.018847996083598946, 0.06410709552226529, 0.07308596775176064, 0.05925982739896544, 0.04754142092180349, 0.06104800301874357, 0.027480581249561042, 0.06134465907610232, 0.018578913445854862, 0.03194917402710886, 0.08121879546031838, 0.0378462411613474, 0.016198785517424825, 0.007072502170734469, 0.07042076318494736, 0.06057681681047525, 0.039931815943770835, 0.07803183139091538, 0.03209307981324533, 0.06050608391242643, 0.08319065215126162, 0.036693378426735444, 0.011235337287578131, 0.012736588081855689, 0.07665619028792267, 0.04750192142842759, 0.03283919774055962, 0.07136255337466156, 0.08478707979403197, 0.026472752365554054, 0.014294950730888354, 0.04139577932355385, 0.06977877384352107, 0.02314184995127782, 0.037270966586807085, 0.060975125074506774, 0.05225069745774231, 0.06630693231859515, 0.04289739209437563, 0.0761317341558395, 0.028641250420121417, 0.03656403214159993, 0.005317158685366233, 0.1721553702748591, 0.06714794364187025, 0.04902547112696114, 0.04401126095364171, 0.026739289676169717, 0.02745703745242809, 0.026264349637072415, 0.019158863071953098, 0.04903438455996014, 0.013397013329179778, 0.061300256620011026, 0.03949450997395381, 0.007368965748502243, 0.01588541054872856, 0.06407783096355778, 0.06582785923514636, 0.01966914083177765, 0.04521504938302021, 0.058713208343232834, 0.04818806424736977, 0.06440724877099838, 0.07059965237614609, 0.10705082827518064, 0.050667511644743146, 0.0563521943085136, 0.06204437697306276, 0.06816872515745702, 0.039572421115853136, 0.022856528164758798, 0.050545776443135355, 0.03746564485012524, 0.012323237681430916, 0.01951787868634828, 0.07327099330723286, 0.07598833781817267, 0.04933699312049055, 0.01203169909140636, 0.03129227278423646, 0.06154169305978764, 0.0363111924830704, 0.02621749761484323, 0.06652007330088847, 0.07462501540900239, 0.01889162670610653, 0.014077271635253585, 0.02970830556155453, 0.021137428777893225, 0.05969151411385787, 0.047932286641650626, 0.012233585284482087, 0.016167331862473683, 0.02573818321369829, 0.028410125523805622, 0.030420087428102573, 0.05857534316037932, 0.03758973577210019, 0.01742349580801543, 0.06316623229893946, 0.03331180504192749, 0.00841946333586689, 0.04683300792690247, 0.07296357754497759, 0.033512784378422845, 0.0037139552343080965, 0.004491975217411716, 0.03819577643767961, 0.05180479598141486, 0.04980760476281566, 0.07978721461709469, 0.04253268827714267, 0.06388552757280488, 0.03878969376185729, 0.03575095621448371, 0.03627210667717361, 0.015586698502903024, 0.02135158674190602, 0.12718258470657373, 0.07065435871481895, 0.03681831970630634, 0.011260625849958631, 0.020751335785814354, 0.010560781548490689, 0.055120654344078035, 0.03183401952077064, 0.028418165616570946, 0.01627592865618006, 0.07311052086973384, 0.017864793095917954, 0.045329391836158694, 0.021165341191414385, 0.05319930199954299, 0.009047481148774105, 0.04877968330777461, 0.053514757854563576, 0.04373817359127345, 0.0683333957567811, 0.014998621641538076, 0.049774536577564095, 0.0178768111002301, 0.055498891104493416, 0.04146412585771853, 0.034353565875320666, 0.03137183676083242, 0.026480129792264877, 0.030194283012420903, 0.049266919058056614, 0.04657790447855669, 0.0865929558753006, 0.09418027535561593, 0.053322186333037196, 0.03000823664478958, 0.22134224463614727, 0.07180251766957584, 0.14528701202042643, 0.14202608216193416, 0.18499789969815364, 0.09243182522515137, 0.12245311026251125, 0.21015926083970457, 0.16025278476938126, 0.17660563631403833, 0.1229776889686623, 0.1863167813468364, 0.12089221377766902, 0.16446043076294084, 0.07404607510374439, 0.23584982019758996, 0.06872554850434104, 0.19225048472083386, 0.2219903090548131, 0.12155258922927803, 0.2685699870269145, 0.15479574130187113, 0.182168553132684, 0.1719311516611807, 0.10755234773481086, 0.1201308755985191, 0.17600880785574838, 0.15974663047780915, 0.11627880165413504, 0.13842962111436552, 0.12554446655896404, 0.20311384131350826, 0.14893254866042446, 0.1457356024653681, 0.12960149966661008, 0.10971656144266168, 0.12546802630587933, 0.18128502392961135, 0.09899970384374743, 0.09791818687752371, 0.11084223571684092, 0.12805608581871758, 0.1717074233437738, 0.1555052919373397, 0.08442471254496806, 0.19788394291554728, 0.18397661256453685, 0.14891210943460464, 0.15083816172855516, 0.21384540013968947, 0.13769390091540354, 0.10431924218972845, 0.17166718840599063, 0.17077696359445974, 0.16732610521777985, 0.16954248951327416, 0.16831598274650114, 0.21264788213997118, 0.12390732900389742, 0.17832545773877254, 0.11296483552864484, 0.1956245044787084, 0.1446454440273585, 0.1387758775343818, 0.12245924662678473, 0.23878861008392227, 0.11840265785013476, 0.132357623548277, 0.19992313107415555, 0.11469206502360683, 0.18079546310247915, 0.0969414247740661, 0.12655353459018853, 0.09243835229426624, 0.07328874356443844, 0.1318822966347779, 0.20662888253648437, 0.17305820489362364, 0.22570706122825224, 0.19346992815694503, 0.15621873429946362, 0.13911557624176626, 0.07138256359124376, 0.2012201945387548, 0.06426950616221275, 0.13837426360095703, 0.2389053005965487, 0.21762874067550708, 0.139303773401245, 0.20216101179680518, 0.15492986797565414, 0.10882435246340691, 0.1512852046758898, 0.19139960618509402, 0.11214621695539645, 0.12158618218475774, 0.1480135495864576, 0.13157560099517146, 0.19442854929835568, 0.1495821912202143, 0.23440177612487348, 0.12355831466735372, 0.18067768474500026, 0.18006308304686702, 0.16856978767581526, 0.08830118638974044, 0.09816741060105064, 0.22466734201917726, 0.10181813365629605, 0.07932939281266543, 0.10375550106888819, 0.1622050985573761, 0.22169986980095988, 0.17402414983559042, 0.09420912622684434, 0.13466189345044477, 0.058692094960039666, 0.13670834412257518, 0.08281647948728454, 0.08895611495620782, 0.09329106944102435, 0.10379708432141813, 0.22694055471689473, 0.08296753670419417, 0.19090270623564723, 0.13128453354922034, 0.13084957946933087, 0.14635455554291127, 0.10893670691838188, 0.08581470247478255, 0.2255485576367186, 0.07952239334342942, 0.15465456661918472, 0.1663537404590076, 0.12775390243698515, 0.15956137509595963, 0.10028551347673902, 0.11135611983556902, 0.1696644966760951, 0.12891810327287645, 0.1140627544373274, 0.20072217610093857, 0.14507875867909, 0.1441413888166989, 0.17637496724003748, 0.15509695175193972, 0.19346789036306644, 0.1335983029416492, 0.15001374386971997, 0.24763566922516594, 0.10106668567224857, 0.204443417549614, 0.0855985660887053, 0.2067237088997518, 0.14112105653170617, 0.16796827075942872, 0.21281925600863275, 0.08501168145167251, 0.1333182824835662, 0.10910289437179604, 0.1311022965537925, 0.1821219136998538, 0.19178491776749013, 0.15198116491158165, 0.18220213842728447, 0.11116288947842776, 0.14630805400590743, 0.14110587266904695, 0.11416770082207457, 0.12305134832258187, 0.16528860245260502, 0.10029212481552556, 0.19477800796589545, 0.20615737074084822, 0.22254219879546475, 0.09970970647109133], [0.030202978110361486, 0.03442399616863939, 0.10432484995333419, 0.08754381654603828, 0.044054839865214405, 0.022331836460638913, 0.0603990346163271, 0.021450827686837124, 0.014984336974579963, 0.06203725618580657, 0.021529635151607857, 0.056770872850451744, 0.01710051313913878, 0.051998983948461475, 0.08738696004354185, 0.014539180518758875, 0.0534238615223477, 0.04233969923769755, 0.026060972445374055, 0.022972496639516567, 0.04311373532419244, 0.07096922851257748, 0.0815888082668666, 0.006129188902465808, 0.004222408029055524, 0.01590047758297935, 0.024520951856468475, 0.00930361498537804, 0.01067114513247244, 0.01774960603084295, 0.021237941428778634, 0.02463994063286772, 0.10280650965268574, 0.04612282909933598, 0.061231331689463514, 0.023817143049992384, 0.03852140210989503, 0.08400419922245127, 0.06645744561307854, 0.01925416824017321, 0.018754477815462217, 0.08957945771755711, 0.029950804948326082, 0.02123107345053746, 0.0409835780550155, 0.05782807801639842, 0.06042229687614788, 0.054888016424111785, 0.07316838349065474, 0.04867608140733454, 0.05996188186409493, 0.01192263498406617, 0.044725415777535214, 0.07036256348533977, 0.07769910408364189, 0.020029200240969658, 0.04371801398754601, 0.06638523416533586, 0.029979876069832715, 0.038045404869462215, 0.012351511113886392, 0.09445843422004292, 0.007602372150417538, 0.019794325344264507, 0.02468443501950993, 0.035020464565604925, 0.06444313232937167, 0.04446508377910622, 0.004289923357822362, 0.07045106962323189, 0.050977685323525826, 0.03547722916869867, 0.08278539930019649, 0.03671076479217699, 0.030753109679226915, 0.06426627327117228, 0.08134358352230442, 0.047570911476448666, 0.01362825696912384, 0.0026446485125850286, 0.02176405614121787, 0.016368858951834903, 0.027189996439002218, 0.01691900584245882, 0.08293329257397883, 0.019394686002464547, 0.051238580396579164, 0.03821878971892499, 0.09126459834195914, 0.03481096250095195, 0.008675629731207606, 0.05839530483729417, 0.016161092076330416, 0.031147792432156783, 0.032287955344203985, 0.07179849570797336, 0.02343518118704519, 0.01610377146261594, 0.06337240188112182, 0.06422039226538713, 0.010079978063942925, 0.03148730536321959, 0.03531943803893463, 0.024393505469385176, 0.014111515765468922, 0.03864143659631091, 0.04132478595561078, 0.033228221018948866, 0.016868005454119657, 0.03993923550531749, 0.0872925780112705, 0.032148381785279324, 0.034317165207598484, 0.04932357509049678, 0.07201313056171903, 0.004554250983581428, 0.05516916303144348, 0.06554669730605618, 0.07743744675310389, 0.10240949990768587, 0.043738380435013005, 0.03153256966822571, 0.02682653942986602, 0.021028688342701045, 0.04947637515743414, 0.037215559277683496, 0.02410461562835882, 0.0372026736787971, 0.08820696523593319, 0.011189907316058394, 0.04661571091761993, 0.024370990145290573, 0.03361720982338152, 0.012183284908983738, 0.02360910421327478, 0.03573443169795698, 0.03698950971386606, 0.028961118941585866, 0.014989994533900774, 0.03617108266259875, 0.06809623025718235, 0.015315026487974871, 0.0658454256312501, 0.01673693547115451, 0.01628387490317466, 0.1032847706829348, 0.05194208276788554, 0.0703942642036465, 0.052224838159858226, 0.051302809208150835, 0.08167634147309488, 0.04454936111165632, 0.06595611001455015, 0.08559886486299577, 0.009641067139924535, 0.047597816484349395, 0.054791975811484366, 0.0557250747336976, 0.06331611357088532, 0.06327388680449898, 0.006071444546368214, 0.027195150295512813, 0.013803648968948232, 0.042135241862025954, 0.006060625948462516, 0.04877677983454159, 0.011817234692223852, 0.0443029489308115, 0.054447764846225905, 0.06612451146206548, 0.02879287071165539, 0.03707331973278234, 0.021491344161932508, 0.04595294144124754, 0.061283724442605055, 0.03949791906521686, 0.02021425069429942, 0.013940976932644846, 0.019774512395322807, 0.05669990629558602, 0.05289051877034288, 0.01978722753964605, 0.0035539132424615206, 0.011922824590827429, 0.039284835539517865, 0.018746173422363017, 0.03875822670036747, 0.018196421067020106, 0.047839789185673005, 0.019554790717759923, 0.017962580389012734, 0.06385613277915024, 0.01145448727202752, 0.043444532089896744, 0.04730797860951674, 0.028824902762989366, 0.10206934154754686, 0.01624011979137938, 0.024324048107730287, 0.02632764765181609, 0.021225534634844914, 0.05477281595249811, 0.0068138335407110714, 0.03527623834088445, 0.046863865948492484, 0.09645253810430728, 0.0372722765971576, 0.025479396797656536, 0.02986550105795745, 0.014849145438582187, 0.06974996893756813, 0.013698059070344656, 0.06517605630741005, 0.07356022214216572, 0.0388441204784378, 0.02632319859619583, 0.04572743196941672, 0.02224538343838386, 0.020584997030035145, 0.017376143913415652, 0.03042584266363373, 0.046719764809935324, 0.047863043784614534, 0.053769834489832004, 0.06339765213910611, 0.03643024254650359, 0.06367990574348839, 0.030054690301298138, 0.0026799438590739645, 0.017995554728493575, 0.06643191956344151, 0.03137110897730435, 0.022632945404057542, 0.005507309847856842, 0.0018234938292035594, 0.01011115592724133, 0.01242638758999566, 0.01758370011474096, 0.03995702789735891, 0.044185285486521265, 0.007458635861234319, 0.03728323548491444, 0.07549701498881464, 0.020137737662861907, 0.024245292353894443, 0.03344729535221573, 0.044215806429424596, 0.041552325560440945, 0.040419319824826334, 0.06832783395845084, 0.028422700857082685, 0.03568375881220545, 0.053142029266323776, 0.01854465207866123, 0.015053766565547596, 0.049056696870754805, 0.08122832559409641, 0.02977781654936412, 0.020146084190796942, 0.027539615985006097, 0.08397220739073331, 0.05153435545282499, 0.02632912811672976, 0.07886637693210956, 0.04736683714473921, 0.03900648132267018, 0.01074762368995336, 0.05447570790326404, 0.09217369189906506, 0.021702263489245407, 0.05113045474694622, 0.05530112167640079, 0.007496449003566898, 0.03204077132977545, 0.013251795617472983, 0.09309383244403908, 0.10780968432945591, 0.06720515508805552, 0.11329213127253518, 0.013698996570441994, 0.029136231319317897, 0.04849109415625853, 0.03042177090631618, 0.003672616890511446, 0.01483245142510221, 0.030951168305510958, 0.050644287689318584, 0.0611883043611963, 0.010477542265077994, 0.030886428130249825, 0.054310156302827026, 0.06902574771834959, 0.043182418937043804, 0.15750064454492063, 0.062415761076995445, 0.008510467878002073, 0.03655235696163389, 0.02213839159887885, 0.02374977902359059, 0.047631141309055595, 0.030072595691308383, 0.02946704149156088, 0.02704907265011101, 0.028615314513444904, 0.05291432878302951, 0.04593049506506613, 0.03811512653145098, 0.05154714146028123, 0.026570681384914828, 0.0038118066872665363, 0.03002643314821105, 0.04775671461116403, 0.07147705287582452, 0.02976743988842974, 0.027410392273938464, 0.038812105664082115, 0.008631131514125775, 0.05337959313164315, 0.053170408993478746, 0.0441135413524124, 0.009163682322738873, 0.0693052702192818, 0.0447488235940616, 0.04319763344322001, 0.024914157974924293, 0.019216842521282456, 0.02756003414340798, 0.023634992239456025, 0.02811922853241765, 0.06107253698451866, 0.03245988079617101, 0.07266170059841487, 0.00926732827323459, 0.009455929544093388, 0.035401926556181525, 0.05218688616408937, 0.021619236795231703, 0.05284424705971634, 0.03090487935790612, 0.036200094412291245, 0.024728285892295743, 0.036958467831174215, 0.0458840816281736, 0.03747401053025838, 0.0360871002738995, 0.05854586792749263, 0.0626441203959046, 0.020423036466743198, 0.01676916287490918, 0.008832901836402954, 0.024856699465383447, 0.05510201925531991, 0.11590397781542233, 0.11546761413375217, 0.2152041490039518, 0.13657752694862504, 0.22582491619452355, 0.1392392687980206, 0.1329387318823607, 0.07883234730651302, 0.20873018510399327, 0.07753830222833542, 0.1570156802453341, 0.18894755792233253, 0.18281770539620232, 0.1351370211810835, 0.2823842376951249, 0.1691432964176901, 0.1323632159901242, 0.17171070220008974, 0.07896815171285022, 0.10035610847896147, 0.19322148584310087, 0.18355575450245412, 0.2773130727150748, 0.15148542941577975, 0.10621615249903933, 0.14843286015093327, 0.1501520227400526, 0.11360733048810114, 0.09080466979573812, 0.17412858294142833, 0.14045397781075972, 0.12675849375345055, 0.26823563561324154, 0.15522905595360265, 0.1474480694460292, 0.17392235207221202, 0.12257009188854888, 0.2257771582733239, 0.1410465927854661, 0.13829747094742714, 0.11375061957345856, 0.13400733260618103, 0.1036691859424595, 0.10538344556886343, 0.11310117619652903, 0.1516106694696411, 0.12482098844503203, 0.15487876991110464, 0.1622285408478591, 0.1430707043337245, 0.15708475073258724, 0.14052602071915904, 0.13001843535852048, 0.2121173202871315, 0.1859088242053986, 0.13790406947655065, 0.12253002549010901, 0.13552648496002923, 0.07358332735396202, 0.0812925007795134, 0.22328470653343588, 0.21505765767107088, 0.12793443871722107, 0.13831660782377567, 0.12417631013499153, 0.16524171787163905, 0.20767934229825774, 0.15316104756728297, 0.13742814501447065, 0.16257006284450332, 0.1219182046911409, 0.13167571336511644, 0.17007093696344286, 0.1410486305793447, 0.0596671793309431, 0.14844622072433272, 0.17118709642560254, 0.11961078616760432, 0.06298375781625509, 0.1494587897773712, 0.1796503301950232, 0.14838926974804173, 0.13188223534774396, 0.07653933889683216, 0.34103212938193356, 0.11362789228798882, 0.13804014201366133, 0.1674309213675799, 0.1671856353359838, 0.11910422584943234, 0.1127747767755101, 0.1288402074527356, 0.2691929697269394, 0.11178694470154663, 0.18883258344665652, 0.16957343946541512, 0.11041963863517008, 0.08344879313822716, 0.13827497860597027, 0.312032054869398, 0.12292760214017284, 0.13050988076194642, 0.16715630949024232, 0.10241665516889865, 0.20556536863648123, 0.1522237696354428, 0.09883514049673274, 0.12695883340652914, 0.06591886281967163, 0.1258004471779831, 0.1510597143562571, 0.16334666149510493, 0.19097695547726848, 0.1452018843302804, 0.17100046208548933, 0.20051255912309696, 0.10432441328321734, 0.30108781471367807, 0.18417133679313047, 0.1771169540382201, 0.15020168055930447, 0.13013826683163643, 0.06706403403152382, 0.16464495070038304, 0.12000944300164139, 0.09682332465965902, 0.18465121426889974, 0.15900698790867485, 0.2711251047590087, 0.11365505010490456, 0.2933039936807848, 0.15859100216579053, 0.10380920383238024, 0.1230873621159023, 0.10148505394857738, 0.20301356040421994, 0.1529428504046894, 0.10861969207443538, 0.0787602354502005, 0.10781347646468109, 0.18765219517292517, 0.10586880057329133, 0.17651647900141057, 0.10202053408589094, 0.13840843112237994, 0.31828863365996274, 0.1609595928100809, 0.18620580585012514, 0.18123004946016497, 0.13963679182192973, 0.17099804124764859, 0.10795051427257639, 0.12625760248591825, 0.1768250898608277, 0.08580009317806653, 0.3285109738428747, 0.09352483351023928, 0.2593228767716116, 0.2661768202820132, 0.15172475528332496, 0.0888280556987851, 0.14730410620329842, 0.16795032898024206, 0.23102257761263081, 0.11184686809898385, 0.11575684296868502, 0.10311991622250888, 0.10606827454701548, 0.14687426959074315, 0.23423849214469236, 0.10992420191365866, 0.16243651839754275, 0.08827471805195655, 0.09547730817669824, 0.14531463715097598, 0.17335846539466612], [0.042832707460489006, 0.05387597597174106, 0.04229595944766076, 0.10508470192191102, 0.06676121479681422, 0.047728438305878834, 0.10849580799619998, 0.017257442419988014, 0.07489211962468202, 0.045470344353347056, 0.016690213683872454, 0.06272789211042466, 0.022535138958764654, 0.00248401447841447, 0.008004019600189021, 0.05243031443246911, 0.04129127726980275, 0.05984087827645483, 0.03884062711750308, 0.016689367156716126, 0.02310049652512516, 0.03031331009321636, 0.016575469034573725, 0.02499928566507034, 0.018931689274106777, 0.030129502617543748, 0.012528638302859281, 0.08773897744474873, 0.03933841572894205, 0.03470438051848643, 0.05487899190836376, 0.09857409603653416, 0.052654870124834205, 0.05329825374628267, 0.0935041644580422, 0.07854164758276555, 0.05523127360990452, 0.03553007008327592, 0.018749532717910987, 0.07042037248010598, 0.07661007945576022, 0.03281961653321501, 0.009496108940502089, 0.024988177390168273, 0.05712790812756266, 0.02455966419450218, 0.041650714232556285, 0.021415308020227862, 0.0750716063644617, 0.01423487411586628, 0.02507849532600132, 0.04289664515864946, 0.03698179903890818, 0.04329270878506284, 0.03961816805625155, 0.09562021421809351, 0.06033112858271888, 0.03250020000362589, 0.021818611177525694, 0.014736402193985641, 0.05558060204249717, 0.03765772607538008, 0.0011273223208263516, 0.030415774353088874, 0.01723369560955513, 0.06041185892817955, 0.09107489198926957, 0.024721383440097975, 0.06645500179260008, 0.000889933877671513, 0.023049268225628524, 0.00833292125589064, 0.010580718986720089, 0.033260205189787576, 0.028224843328878767, 0.03623985820600102, 0.04683165195127649, 0.07306681555365363, 0.05760077206838516, 0.01396782735678097, 0.046099597483032176, 0.059530750562947606, 0.03016933727438652, 0.04565557292211921, 0.06033501264849498, 0.017854634770041993, 0.011816662999110357, 0.017836779175746827, 0.009318104580855899, 0.042129442576439156, 0.05922146937659672, 0.03291517451045013, 0.03201738649588679, 0.04174801889025877, 0.037721897430357434, 0.09489908799408905, 0.024081330385900313, 0.057249873155547734, 0.034657982403352376, 0.032063721408767086, 0.023539411279583172, 0.07342750507016337, 0.05936681923847045, 0.04800441765016125, 0.03394156762008225, 0.012208890440242906, 0.023646133073094874, 0.019523434739019123, 0.08152724544127142, 0.018115098918637922, 0.035611420959955266, 0.08180210246674477, 0.02379888717475678, 0.04776747431606055, 0.0476095950861852, 0.011431327476466616, 0.03707421222521413, 0.0776295203174795, 0.04330608468022078, 0.07036784949201731, 0.029666258825830398, 0.04749419160127159, 0.026682524476200346, 0.032859418631321004, 0.03971590172319163, 0.022780957421468153, 0.060431796366408955, 0.051298044141261816, 0.021746685097534812, 0.027161432850745418, 0.03325442122595926, 0.04900339630342299, 0.031804701335908424, 0.026078918055000327, 0.047085357289160454, 0.053091210823866634, 0.04521958079309233, 0.03717646198046785, 0.09896215787457843, 0.053859673620712374, 0.04800879967308814, 0.06572978465907997, 0.052298505174657034, 0.05930791473797253, 0.01330190925903979, 0.023239070339308634, 0.017490867495296464, 0.013958498321083045, 0.013764156178841669, 0.0020052137152825095, 0.03380228517456882, 0.044439684133976705, 0.05856778187256667, 0.04212517163626129, 0.05622583193584316, 0.08034432907738993, 0.052596452090168194, 0.01076428610230646, 0.014353368765554361, 0.03853650936376184, 0.028986411334405986, 0.039433820488592314, 0.052748650778085, 0.0572882579909938, 0.035678698801465576, 0.04875753953632328, 0.020842785616555524, 0.06583216464928081, 0.012879451988415133, 0.06404222702727684, 0.06484302256496684, 0.017206641214509166, 0.03602995777562742, 0.040271552955551494, 0.0370922650871498, 0.02217370825218818, 0.06987002257618212, 0.07457132030638956, 0.032545073603790615, 0.07057910589801689, 0.01051977190429405, 0.03877506148250353, 0.06834134774943514, 0.052214074624522086, 0.04000463643141332, 0.045397359156800855, 0.022376480234426357, 0.03753286906548085, 0.07073772440273916, 0.019940937335993496, 0.03862116207939483, 0.07193291349516762, 0.03425292107426832, 0.04566448635511822, 0.0736971680195101, 0.02129903502552019, 0.04227014611505213, 0.015669049124323552, 0.056212130453317403, 0.03461617315488477, 0.009307324766151367, 0.02571562575476785, 0.022147243744843913, 0.031295042192082734, 0.040369899492831006, 0.05998209126353745, 0.045221687534884106, 0.06239601899118674, 0.034304888648611885, 0.03916699206456542, 0.016862405351393165, 0.08627207228733648, 0.03037170323002483, 0.020411171680015903, 0.016196874128053748, 0.04550948761583817, 0.04126469401883022, 0.13549757280176686, 0.02886768685834062, 0.04903236208784004, 0.029440444834049673, 0.008264564188017, 0.04984825721851761, 0.0377091305750993, 0.03919261004475336, 0.07015715233020245, 0.03905146983602355, 0.04831963984836494, 0.035732715661006595, 0.07522391996556714, 0.04727889408147143, 0.07456770437138696, 0.027115101768304745, 0.039010212170861425, 0.01307555900571207, 0.028582983687820456, 0.035783204685656295, 0.007468523183507064, 0.04655799768384426, 0.08058691847949259, 0.06650217748697727, 0.03274691478920079, 0.11184316789430958, 0.038836302551170515, 0.09024674328224314, 0.009894614472174117, 0.05416022140472647, 0.04358904308549339, 0.023663837365024996, 0.06926115121572249, 0.075008986337531, 0.029315438437005206, 0.022065582602555235, 0.04815995648142792, 0.03716270304134777, 0.027723582423922997, 0.011935858619249156, 0.044486358040763486, 0.0541325388175826, 0.029196570319454038, 0.07759222715732551, 0.08009448482264435, 0.041422504300792376, 0.00982726576753081, 0.02288782860212509, 0.05292400064307356, 0.0834695081556997, 0.0338568153130191, 0.030959675711910092, 0.033560553790941354, 0.008585910301565403, 0.02934819827186725, 0.07615763558855942, 0.08480507519937332, 0.019734273627099973, 0.0668416387071052, 0.0016270801373344337, 0.012545093871472825, 0.040468954661440466, 0.010655098463288479, 0.0114330071242406, 0.02270002023226792, 0.04162631433216795, 0.07040499709546566, 0.031185288605610692, 0.03958951636788346, 0.04804549528466118, 0.03221048470286112, 0.015985892556097, 0.018006172707124103, 0.03726006132520495, 0.056484106988195455, 0.16562036448909392, 0.05379831763885675, 0.09747681298082876, 0.061062156493144656, 0.037037332752539266, 0.039884502353567275, 0.020682738357854467, 0.03827617736533284, 0.04358424354464777, 0.07084888376055226, 0.04559801673636802, 0.03364177443267357, 0.14688577623136584, 0.07405515324564711, 0.07971886425249039, 0.037328350402775316, 0.009523661292698837, 0.025615398471634236, 0.04351593531487931, 0.04060450242832303, 0.039772634364424214, 0.05714018085610963, 0.051797184897887136, 0.05235439894961254, 0.012336767751783615, 0.038883960880940004, 0.02596694089832806, 0.06043037527330941, 0.06908634527316017, 0.03522165457627947, 0.01992027594467565, 0.016689445680728363, 0.014363450482637893, 0.015338041684440067, 0.06029142990648266, 0.03849568453827693, 0.03610114649599118, 0.017446206484530723, 0.004007939799433394, 0.05542165411996746, 0.0310362059803259, 0.023843335596123533, 0.020105062097671534, 0.037255832519862926, 0.0368960393262246, 0.021278616867118308, 0.031110313495681174, 0.028754367132581053, 0.03812314364157858, 0.04284558156805654, 0.06544669984929985, 0.04665820198434015, 0.0599986732366585, 0.047656567767262466, 0.02013550643178244, 0.021916919410408988, 0.022903521913253976, 0.014915741461839889, 0.009589196284181409, 0.037605892566423264, 0.11585893950635388, 0.16461386285241575, 0.1934184317266749, 0.26781545170853216, 0.16522616628677617, 0.16747040553919731, 0.19513043905458144, 0.1509789840107964, 0.20989162036247794, 0.1579147457115112, 0.14782420329509244, 0.10156059787879068, 0.10289305460549171, 0.10917135964958899, 0.1204524027003396, 0.20218767165657014, 0.1703112893888066, 0.2651524994402163, 0.10723431399392505, 0.08303686000046231, 0.12186279355157768, 0.12129508409528963, 0.17055407797376956, 0.1090389566736356, 0.1691603495348846, 0.10862769769324411, 0.1203089910409143, 0.20404440831513176, 0.17526815405055401, 0.11707423840679469, 0.27691136685109907, 0.18969434043092115, 0.14989795734084424, 0.14801770178300722, 0.2917113581732396, 0.1598779685915478, 0.13217802189530867, 0.11769807146441554, 0.09586353906460347, 0.09498968555201447, 0.1674873514040824, 0.22981462549538384, 0.09009377084552281, 0.0998385624599553, 0.11119869642800863, 0.0624241459093267, 0.16513035933096565, 0.2016117114333376, 0.18099164289812888, 0.1998617367879037, 0.09809254848908994, 0.06792761430504822, 0.10548969430308189, 0.1124816025877672, 0.21378461872377705, 0.14239259394666842, 0.1698915804586103, 0.09714993092441752, 0.11826048725314679, 0.11784333705661759, 0.18322546335477985, 0.13324466143404284, 0.17287325594694386, 0.11364074724335825, 0.15345882594345078, 0.11577753500351984, 0.22004619240760806, 0.11262349739310243, 0.13724763937775167, 0.07610816163040938, 0.1711956459668375, 0.14791435652202176, 0.07618640219011615, 0.11318458018884545, 0.22856699002365913, 0.09655732361059036, 0.142956281441354, 0.1986360727178474, 0.1929734725384943, 0.20207841219680928, 0.16077203916445856, 0.11221895700380688, 0.12299638151401475, 0.16185295858210133, 0.175356529953499, 0.21312769832870654, 0.12795658631911203, 0.1629627595144895, 0.11511750429147675, 0.1809138236867805, 0.14828710426245967, 0.09548778825950238, 0.1178037686153285, 0.35289267198212687, 0.08686421228752983, 0.18083860917437464, 0.22054148357241388, 0.18430246040225032, 0.08626324695444877, 0.22306019680634623, 0.09112153908297901, 0.1531955062021171, 0.14048972347330663, 0.11105786648488815, 0.09622250488328357, 0.09031363041891206, 0.108912889244816, 0.18544731751805354, 0.18521807336759183, 0.12741971190177626, 0.11565058657358732, 0.14642760968737065, 0.09128374287918692, 0.09899937442593998, 0.10991156912378727, 0.1716119381448915, 0.18388993737678375, 0.1325864080459841, 0.16731312768834253, 0.1815514386661591, 0.15826691633030293, 0.12648840945574547, 0.16201742233768587, 0.1718303191685869, 0.12337763283041217, 0.15043337619112385, 0.2124447309442105, 0.16376548176330907, 0.2478375793584893, 0.14103139360104838, 0.1718643947594589, 0.12970450784890883, 0.06826996367665068, 0.105723810772742, 0.16311190151158841, 0.12021428725171475, 0.17663159137291295, 0.18241975336305558, 0.18397364014339063, 0.12775198721717443, 0.2234600334157867, 0.1456564809045484, 0.1113151494533785, 0.1324866327547258, 0.1413058829043181, 0.15967878573123487, 0.1498552862434618, 0.19465227761576254, 0.1247682203088076, 0.10029521981073965, 0.18773364564103467, 0.11153293292849295, 0.13180729662699084, 0.19470697629355616, 0.1388133851991546, 0.21656657509025068, 0.12099794923297821, 0.07754014083935369, 0.18940037717261624, 0.0849081599904645, 0.1883425323232528, 0.13503579032276908, 0.07809594528929842, 0.12873165279386506, 0.14816247707893773, 0.17939689298791273, 0.10951716407772996, 0.1438523285211094, 0.1232576558005906, 0.24639050055655742, 0.1689343229537049, 0.10759252904643936, 0.16674806123539326, 0.15434823870178194, 0.06958106187202277, 0.14461527548490033], [0.024677486602036704, 0.029997691444511858, 0.06162918413118009, 0.036229692219245824, 0.03496591527495654, 0.04217636163136171, 0.03732370024907493, 0.005797054355723724, 0.026630332821138927, 0.021412270481608087, 0.03546169290559427, 0.017831092888128855, 0.07393925180358273, 0.012439246375804708, 0.023677529271451697, 0.03600507907028641, 0.08027269985646972, 0.0388344754314711, 0.028707011407541654, 0.04659501888278512, 0.018972113818651246, 0.0501786747706994, 0.03701973571291855, 0.0369245492883267, 0.022512748123957746, 0.03574871923774481, 0.025539536614932364, 0.03246223268609855, 0.0694432043500485, 0.05499819901982143, 0.033953503269942543, 0.030977222955815738, 0.035373152293745554, 0.03531672991812229, 0.033481991474306395, 0.03535059483481511, 0.005851302478056882, 0.05265113544620333, 0.022154004470775687, 0.05351756556680607, 0.02862013703692825, 0.04576357216724465, 0.06663720814451095, 0.03635372185418683, 0.038219659228719054, 0.08016162476832829, 0.06168672882561242, 0.05342185820242571, 0.03757498091867855, 0.05401137052103878, 0.02723567634670725, 0.03190468347090627, 0.03261154705298043, 0.03545479428383612, 0.05919634552311994, 0.07361657556987579, 0.04091802391133482, 0.020040406192082073, 0.038385643668833284, 0.021982613365135847, 0.07593455078500895, 0.05408259754579875, 0.048145599993726904, 0.04742847657912681, 0.062210334600099636, 0.02953884499748388, 0.037283132063044656, 0.027284884089303595, 0.034685009985320994, 0.06156963611682577, 0.010670577269798566, 0.041657317910463586, 0.024139673726993705, 0.05900584243898911, 0.049435477553596424, 0.035387608372876724, 0.02065321907491213, 0.02682915562012744, 0.04941171350618524, 0.06913606437944597, 0.01987613778891823, 0.03774232133441875, 0.022105727525007342, 0.010708052375834557, 0.035156556254913734, 0.05980219466671829, 0.03573307955277062, 0.053928414690158064, 0.029487268127981695, 0.0692921854375351, 0.04545018474961962, 0.07787292177278189, 0.04528709229141955, 0.06982439437941199, 0.028604776974046425, 0.047440787612070004, 0.10231573074575394, 0.027452270470319257, 0.03888376169807969, 0.02098885560107808, 0.07013673608702037, 0.14443052572108087, 0.019604538552342884, 0.04772108769224537, 0.01740143247579615, 0.024845319229268262, 0.005350651570610823, 0.0683458676681884, 0.051452640684381615, 0.02325253241935805, 0.07336485439971571, 0.034525606240476334, 0.03152799420809794, 0.03925109702733256, 0.012387723132457226, 0.013305026279281706, 0.01543042614244886, 0.006075710219691598, 0.07513523762745243, 0.03966763052308271, 0.07006828613098591, 0.017239830058608806, 0.03946997983861835, 0.05206873625396721, 0.08145011570905486, 0.11401322685302266, 0.021383199360101454, 0.04837272974151758, 0.023665178018892487, 0.04466176919278599, 0.040796215931374225, 0.05173267263378348, 0.025847785497805285, 0.11195971285023036, 0.04224321812451367, 0.043556721835967996, 0.014906883570215395, 0.09587329136387956, 0.03120696697864802, 0.014113906917402582, 0.027146997839032162, 0.031013058633693767, 0.030858349092605136, 0.052134830489634514, 0.023169595740675446, 0.03963069742425315, 0.018444645045805844, 0.06266113137826324, 0.03746457998791049, 0.011972674889670265, 0.0654372769678312, 0.04371774585677251, 0.07626869535494236, 0.055675849754122965, 0.024987962885549473, 0.0508878538535247, 0.07026822741834388, 0.02108551099926474, 0.011965141372544872, 0.026297789374967257, 0.06122791493732122, 0.02394002546826678, 0.004177415685262531, 0.053878274235513904, 0.10949382903955637, 0.1203403470196551, 0.08033289138468043, 0.03256200797735684, 0.0680365137034847, 0.011172045018493889, 0.019775357007259325, 0.05847356454919904, 0.016614070289858406, 0.02840985164737269, 0.019528579019430666, 0.05960210016177547, 0.007382917646018248, 0.007028636454995121, 0.04753985427199833, 0.0077088047457378244, 0.04008271611265598, 0.029501749104970408, 0.002612567144340926, 0.10062652985535323, 0.06919958839012731, 0.024564919557662743, 0.040835386006942684, 0.016550389231152592, 0.04337568376814166, 0.0353292056599692, 0.021233484712279132, 0.03179464068624281, 0.07363490039302457, 0.05829646034286388, 0.04747973935258004, 0.025836357381194833, 0.013554555480368437, 0.009417834864448636, 0.006454582833084128, 0.004268809017019286, 0.03879483804226883, 0.07214040074857973, 0.02590811109140275, 0.03892609571677543, 0.07292539572283145, 0.025940055042625438, 0.01766137568460357, 0.02818342095481292, 0.0800615813462965, 0.06284887654586666, 0.03030255230353965, 0.043390722074095285, 0.05962915455682143, 0.04869610694567523, 0.08254862450543912, 0.022197912800155824, 0.05298295493928656, 0.04683702988850494, 0.11413566302508117, 0.018412955818817984, 0.09508664930059064, 0.03501557692464802, 0.041531510951538245, 0.03656272596168903, 0.0167207901681503, 0.025375231822592118, 0.045653182727795456, 0.007635083147174409, 0.024322816621392004, 0.019176967644823656, 0.05144434012172203, 0.008660638348139342, 0.06128808348289421, 0.020422908147015882, 0.07491435915712388, 0.02430700839707448, 0.02943909651930294, 0.0436000517689653, 0.06952751232611556, 0.042847481466108756, 0.003612945105076858, 0.03042155448647757, 0.060848613314691095, 0.03963240196988468, 0.038987045672031186, 0.05470760271794373, 0.023915125695507855, 0.0401652084603425, 0.041246985896460475, 0.08768170471152953, 0.02908893496609263, 0.04169952169421219, 0.015718595860826395, 0.03162595961663512, 0.03945872217657105, 0.034136035209221226, 0.07725547788844955, 0.012793766969304173, 0.03710281028742752, 0.060186403082503434, 0.04824037656127926, 0.05466841732061679, 0.017073964362122843, 0.05743653430873829, 0.03691744765326862, 0.05283391253361779, 0.03659631508672911, 0.03839120163672394, 0.05599351194236548, 0.031328254018820105, 0.024598997063754548, 0.030025764736497117, 0.06527271362081652, 0.032299408358671976, 0.04905267873959196, 0.06798864852997565, 0.06819550759128987, 0.03210699580038988, 0.040410475339740515, 0.0427233369179791, 0.011419253930779956, 0.01881641219370067, 0.04651241162190995, 0.04938312693529072, 0.05382076018459855, 0.04386713683244683, 0.07114021167639764, 0.044462961715555964, 0.045494430157686436, 0.020746806290962046, 0.043927282395382086, 0.018540957619646387, 0.016902525375987736, 0.012851074176479974, 0.021440502736837636, 0.07565208650644749, 0.08892489687329339, 0.034477503579710765, 0.014532653449644006, 0.06434660525091233, 0.05602339320185204, 0.11853107716888191, 0.004312339569291761, 0.08418530240775117, 0.03194093283626341, 0.037499996232649976, 0.029054370994168906, 0.03523476617110353, 0.041028804055625395, 0.043612240227840604, 0.013866312088324659, 0.0632237425194152, 0.03923411668849088, 0.03319881473397536, 0.045924963910252824, 0.06390793947502971, 0.03116561546771517, 0.07691172657594567, 0.0576416390287059, 0.0471053751666219, 0.016075937573107022, 0.044517702528185425, 0.02006853502544184, 0.02721073826955211, 0.04077791409086316, 0.04281862676444073, 0.026461420009934136, 0.08359793513532608, 0.07670265352053028, 0.02985571045428515, 0.047472917339614326, 0.09458368193478355, 0.059554974263113354, 0.04603008649522259, 0.03460338331698891, 0.029172237451759078, 0.02160647760085281, 0.04023434789550882, 0.034263592679053545, 0.05234187341205055, 0.07124968564077731, 0.08187946968621786, 0.020665606716647744, 0.04431081282335424, 0.008127357840778367, 0.0680230918430513, 0.04443350563486738, 0.031202801375559745, 0.059499429058163404, 0.0385683058430591, 0.04674011593564384, 0.04072515744595759, 0.12404881012175353, 0.05851345857785595, 0.15738305004854358, 0.10123733175738205, 0.11581267545660658, 0.06751793346578075, 0.1604173557772752, 0.2346282317152908, 0.14926152213686897, 0.11759867921711938, 0.12661442325841035, 0.17211082992294144, 0.11696880938665521, 0.07023068144917488, 0.06996828101335034, 0.068017560688238, 0.16862067123574598, 0.2819130016911415, 0.08492152056386394, 0.11567340067197239, 0.1091400419752444, 0.12243129207842773, 0.11100184247498551, 0.1368478946988621, 0.13464225095606622, 0.26223198841175727, 0.08902838769098444, 0.18232354804152445, 0.24698814106804712, 0.14884659359532018, 0.1228744049947108, 0.10365525846399608, 0.25573534830924005, 0.14959032707397016, 0.16857839850408418, 0.08092715344842404, 0.09869507664153654, 0.17645641770814696, 0.12593325618053638, 0.19046145491302016, 0.12348184377075204, 0.214245144818579, 0.1563893267584424, 0.06975252767123523, 0.19932457125715672, 0.1638626370338663, 0.14861963238687287, 0.10635357335089676, 0.10767423998444312, 0.2535851080451281, 0.16947930258127952, 0.11756683294210704, 0.11963051293165454, 0.12255202753529434, 0.14771569460149736, 0.193261276449888, 0.1248832637323968, 0.17541268419834877, 0.12980759264000002, 0.08152074135479428, 0.1125489340554322, 0.15626355044303403, 0.1832249883802668, 0.22385829188410314, 0.12562319741494235, 0.16410085973480057, 0.10802691622126488, 0.13326634172229998, 0.1351554226130247, 0.1911028084014693, 0.12837075643361578, 0.1225835214098615, 0.14202203721769396, 0.17605959948512817, 0.18503294055981023, 0.15775599697184178, 0.1151986406635373, 0.10816663533689515, 0.11623030828852808, 0.2136948332190514, 0.21040597179483986, 0.07960629529289662, 0.14052461111737838, 0.1940598924674334, 0.10759641311221546, 0.13328052967065765, 0.17702606536688345, 0.10671322864870872, 0.10633849674054693, 0.15892394397768284, 0.10940031268663945, 0.16417622746479127, 0.1534614919294273, 0.13242548361660975, 0.13506355334914502, 0.13154336401531774, 0.16740789276457604, 0.0884195699566795, 0.15495173212501312, 0.1863908007620804, 0.22137589121778167, 0.22964746511030584, 0.07058163398816701, 0.13224407399614013, 0.14385047458833264, 0.13708463118922326, 0.1407307040907683, 0.15514821835583256, 0.14873158847612722, 0.09129511162398324, 0.12733630790945985, 0.10840899491262053, 0.14321112825024512, 0.07623550842606253, 0.19364219068759875, 0.07056006861309852, 0.09807367208263568, 0.10423514105740095, 0.20406477093215913, 0.17357390464073227, 0.2776871994137764, 0.10047834546815965, 0.12727223231547302, 0.11782456024159348, 0.1523718391094477, 0.22198730599014993, 0.07145544919635981, 0.14981200227573996, 0.15328700774379317, 0.16710816852508054, 0.09616382254828369, 0.15644791716289136, 0.17446575355866265, 0.16515971582022407, 0.10287186461350611, 0.1146012299784249, 0.12860265890917472, 0.24264767075017576, 0.26573650358665374, 0.10518757986926264, 0.12129044926334774, 0.12082889661072724, 0.14578058714828185, 0.07707082771606023, 0.1284988693171932, 0.11361392650512919, 0.10961103283109204, 0.15695920424355617, 0.17365371568068383, 0.12323962975173228, 0.23680553020488834, 0.322953925257729, 0.1186237125206859, 0.1431779566431238, 0.12587676485699992, 0.19246552560117938, 0.1381734872777616, 0.07868013329683773, 0.07396175946679807, 0.09332917465437805, 0.12984578978390465, 0.10079228063865055, 0.14160841102561644, 0.23247471259486294, 0.18176528444934278, 0.1793720870609245, 0.1330935122865823, 0.11894415177765394, 0.16438708550507025, 0.149028861234265, 0.10356876713734481, 0.10363393057618411, 0.14923662427932988, 0.13736816032999946, 0.07738044981153742, 0.21728939436856778], [0.0724125764663181, 0.03504940353694462, 0.0667612990664859, 0.05594422184531728, 0.020474925517074524, 0.07479943064672333, 0.05290179558458829, 0.06558949863838573, 0.05668767187143526, 0.07454830702514419, 0.025227292583534316, 0.025877938718504967, 0.03399230945374697, 0.03925698441303065, 0.042186401213609406, 0.03841704178240992, 0.019719807971869747, 0.022654399696377017, 0.015976804838095222, 0.03155560401688901, 0.08242879303232317, 0.027574258480942058, 0.059313380775312265, 0.029049456540134647, 0.0448565470475343, 0.03465230569183346, 0.018988307002150727, 0.05112437583926705, 0.04356637071337431, 0.03862862377577732, 0.0705374077322983, 0.08290192893435878, 0.03985597706970669, 0.07056566105494577, 0.08812599740321599, 0.023901977711507393, 0.041568884550924265, 0.02780733115580534, 0.07756133083133929, 0.030811956723130522, 0.03697144919105115, 0.11629124292202535, 0.06963736167357815, 0.08481084384144315, 0.0027870058435045426, 0.047080580730952566, 0.04283759893188554, 0.033959494077510415, 0.0866877745776888, 0.044324135092357476, 0.07408031157308048, 0.004813078576849113, 0.047934784088283784, 0.053315494555018605, 0.05377228214075008, 0.07485890205228522, 0.027099090530687285, 0.0716377474788216, 0.0230721723393447, 0.04285415792236886, 0.05233982029641348, 0.047261649442295876, 0.014566851614583886, 0.03592117329037959, 0.007874839460372084, 0.07651000539021147, 0.028635621589097767, 0.1273578119974944, 0.023903377737189015, 0.03898868893062876, 0.011140836511678513, 0.05907046195540217, 0.05231456237754995, 0.04641498439013959, 0.16167341821616696, 0.024861972065522306, 0.04171921398430582, 0.03261941477596279, 0.02509054397383044, 0.02413916427852406, 0.05788682546887187, 0.0747679980591901, 0.06546099504996693, 0.04921854443607792, 0.06668877352269427, 0.009276198613787852, 0.049159969353387435, 0.07067558701120077, 0.028547092468567917, 0.006814432046901916, 0.09026200375369481, 0.14899218094445046, 0.05376847468376641, 0.055823482558011055, 0.03153552293717381, 0.04387790802866221, 0.04992083638846394, 0.02694820376834081, 0.04555029711956459, 0.059841196202943404, 0.018488959401785847, 0.042888827231382175, 0.01332285984854905, 0.05038893526239742, 0.03257462927590936, 0.06106339372514237, 0.05865357605920685, 0.032776616018025145, 0.01567313045774016, 0.0107957569942359, 0.036321266539274685, 0.0390296439910608, 0.022309324966983932, 0.01132300647441298, 0.04394457683027272, 0.049674496985971935, 0.034983619566886656, 0.02309418779106871, 0.037420453323471936, 0.07663504626121252, 0.009360428065842679, 0.07379960929674488, 0.049133298002303614, 0.06901463944344752, 0.009251927033126836, 0.05610721854252681, 0.02606982842177874, 0.06322938475697752, 0.03927181587524472, 0.05517097099894478, 0.03547149500058543, 0.024827850509374857, 0.061558152458840804, 0.06253001926046226, 0.03741689484506365, 0.010139116221257757, 0.02996109350914917, 0.02366414954585414, 0.05878017208869419, 0.02557536271671134, 0.03647328519652929, 0.04253099905326963, 0.0388771771723705, 0.022047575705895023, 0.019295125215825056, 0.027996857477832707, 0.06104211563304548, 0.041298616392117356, 0.01260648241206523, 0.03507598295747753, 0.015957678495455655, 0.04514785964162119, 0.04629056021991757, 0.0993717850876912, 0.028104253428717776, 0.023961343779979695, 0.012506566352150854, 0.04939935267752698, 0.1648232500038801, 0.032781327458759474, 0.029591885094921437, 0.016518493160425175, 0.0342110735214045, 0.03628551321584852, 0.029849204452588197, 0.05547382853805058, 0.01217128892969941, 0.047394297566385045, 0.032620900986535896, 0.009395578095028478, 0.10393422172074357, 0.023886910677256606, 0.018345191511475754, 0.025757559492523154, 0.09094338533618758, 0.025767007271849343, 0.06625050228209266, 0.03581904227875414, 0.028780634372284817, 0.15235785034395036, 0.06862824767707817, 0.026576662616383646, 0.03696187692243726, 0.05252305320614288, 0.03951816676905559, 0.028801215324370615, 0.0485801978427316, 0.02289542436389433, 0.048122207498959, 0.04852594732637367, 0.058073088256341804, 0.030974353956539306, 0.05570514878678707, 0.01842221016094329, 0.02220576711659951, 0.024901540506811395, 0.02638902470108963, 0.05228841962713388, 0.0710180742786296, 0.0349742311593746, 0.06911773189541794, 0.04786880859624475, 0.00963967190229244, 0.09932327640032577, 0.035422568795301264, 0.05002535759441314, 0.04423021654328031, 0.018445372829333912, 0.03795585685199307, 0.019487271558553464, 0.0407165159741717, 0.0332996740396465, 0.033015803989744, 0.015548312709847046, 0.04915895428688777, 0.02384524123983518, 0.025230734233534145, 0.014158126470001956, 0.06616532862667115, 0.02470818182994281, 0.049474571020372456, 0.027711095190757228, 0.045876608440472234, 0.08026781987639205, 0.11040321371007351, 0.031446032376298984, 0.10153981391340496, 0.03036694773923486, 0.07158730824988696, 0.019534985429697463, 0.07852751326056258, 0.033934584728652434, 0.023761122870529373, 0.05365640751176304, 0.052588626502021674, 0.02739740133796248, 0.09106743795376632, 0.04583320189868251, 0.02381248715063257, 0.03838020827501051, 0.03257957437346059, 0.0456985427937921, 0.05007424932574073, 0.021556007728401213, 0.08266205914438733, 0.03345684080775226, 0.03005759185931135, 0.0794870077422069, 0.01705803164851762, 0.0646789341924652, 0.042582415044307716, 0.03744655393905217, 0.050141699537034, 0.01954227858673661, 0.07774205097267706, 0.018596759464050976, 0.02754684019413206, 0.060324452126458775, 0.01858177669947186, 0.025652595870797674, 0.0433333650712044, 0.022130228932045644, 0.005982916862253221, 0.04443244077265263, 0.021869444941741326, 0.034513375646765196, 0.033144311408602425, 0.04976926589264505, 0.060820972862383055, 0.09150149571078439, 0.04314797179352853, 0.0028476421815162947, 0.05907487845228565, 0.029955997109232895, 0.04939775538420485, 0.04596188551776352, 0.07781063116365865, 0.021797995751483307, 0.08396826969880251, 0.010905082529080252, 0.017129367840806806, 0.08260285586959894, 0.0780722808333174, 0.055604059654738636, 0.011791322725794971, 0.040645262136334376, 0.0397138217944772, 0.03183208706398164, 0.025491365006253607, 0.03948526329270775, 0.012476651576317608, 0.018927180846672387, 0.023419507028114413, 0.015800589293752228, 0.019865035259675597, 0.04112760258478023, 0.02731895393451616, 0.13406874221419135, 0.08969727437943222, 0.014121448095407219, 0.03677779748555153, 0.04331553054432716, 0.02765775440380939, 0.06512306600568757, 0.0016538277381069719, 0.004820803615955576, 0.03301257875958278, 0.040564960800111294, 0.09124376841129796, 0.046644048509939064, 0.07136950945301403, 0.0372563113248156, 0.01481240098890398, 0.028012696345667207, 0.06053082855238069, 0.01698686016513215, 0.04000302764677233, 0.0535122910514474, 0.06554197820444262, 0.06171708122917241, 0.009280374750585086, 0.05343312735579187, 0.022101912407144424, 0.08053967383720222, 0.07110061259159157, 0.07912732946175723, 0.06094886741090206, 0.04228811853775575, 0.0487827783029887, 0.05798806781850516, 0.032924988096760165, 0.06180525794925709, 0.041796722930044904, 0.03668749104103735, 0.06358321778656495, 0.08449873196021204, 0.04267588160150955, 0.05691175641972692, 0.05053207879104922, 0.024266304230437647, 0.01831855654956833, 0.03189504991525845, 0.09026262428491347, 0.03524208614122003, 0.06588219785161557, 0.028883033514683767, 0.013214972643782536, 0.052623514146093404, 0.029031141293084914, 0.042439041689278624, 0.022943423602790124, 0.06774055095569742, 0.15969075202461214, 0.13615248604647576, 0.1769556159213666, 0.25935845389481516, 0.09497473917661176, 0.17762444132278044, 0.09083619431382225, 0.14542605697868333, 0.19754730855985997, 0.18925334957818832, 0.14256269610937566, 0.15034333021650392, 0.16214086974580444, 0.18166639782007665, 0.12016327345683692, 0.13784664352574658, 0.18076423735868546, 0.08713764438946402, 0.16691882223371537, 0.09566104670445766, 0.13797969767643561, 0.11304034881534115, 0.30238054212062593, 0.22483699985088842, 0.14425513755169608, 0.17846649452563257, 0.14538217546238055, 0.14638431039789032, 0.1640066002765971, 0.14931663450214172, 0.1375087987511389, 0.1763780315917346, 0.3492483304392907, 0.13748866596048878, 0.09532428977470245, 0.060826952178632064, 0.15754870890129, 0.08073468151832781, 0.16976686134453745, 0.15211688504824716, 0.10956522843409931, 0.21484180473752562, 0.2097094906193595, 0.15135254380443405, 0.09507353387532697, 0.08116961261557956, 0.1335905194883385, 0.156363126551432, 0.17821566201746467, 0.1250075768198698, 0.2456841981338878, 0.0928384953388764, 0.16472627859442465, 0.13608902332282838, 0.20145984216322824, 0.18954889097761726, 0.13516211822148294, 0.15962024129206137, 0.23304157169355502, 0.15602970976502667, 0.21027232009556987, 0.14046626586106517, 0.11049387255503286, 0.11923085252243666, 0.1727194714570238, 0.21919805646663715, 0.09897952508782187, 0.16227121194524152, 0.20477084352845148, 0.23375694459724813, 0.2001049237385873, 0.1329455040996113, 0.09813020171056833, 0.2584975549290257, 0.24899357539271158, 0.18088961530837322, 0.16861566102072117, 0.1412113016891864, 0.12384313083584271, 0.09972194855612132, 0.11826609501675253, 0.17470609066226792, 0.1861855964506826, 0.15295506184620244, 0.0787982487330033, 0.11888773706290992, 0.1522243825057822, 0.12699118529957149, 0.10524207936419595, 0.15792350975736497, 0.13365105575611516, 0.3334043451374577, 0.17058979299279953, 0.17984212796774604, 0.12228400401410558, 0.12141260964375351, 0.22080972159822143, 0.10904599702165974, 0.11927743832911215, 0.14706960668967617, 0.16892074787568662, 0.07740669598382327, 0.1116324324280985, 0.16230985342014223, 0.15397377492439362, 0.2671785874953193, 0.12394960939643845, 0.1597882137303391, 0.12439793171060663, 0.07248527821033232, 0.12098258150921715, 0.13242911487337083, 0.049753116759201216, 0.14945115954164537, 0.156249760860397, 0.1327994570977265, 0.22013070722741468, 0.09132215452771034, 0.11532158245362582, 0.1331047124920353, 0.09978206347553961, 0.21219317831339377, 0.2016073447321692, 0.22049237733646748, 0.08742413829050719, 0.20244821815961794, 0.10691326952749684, 0.23898627609014514, 0.13621654631870408, 0.14039026993897655, 0.09931341684874027, 0.11608412339081688, 0.20635192643009848, 0.15325219670851387, 0.15705516441695153, 0.16246625793076333, 0.151950414142301, 0.12719603721052408, 0.14502038277925985, 0.1053091120575705, 0.12656484970883017, 0.12079436902797992, 0.18060181139697953, 0.1354826340872434, 0.1264821351956456, 0.08899802762654521, 0.157191482102198, 0.1490116089342102, 0.22466269952635612, 0.24753368760068573, 0.11479744041759161, 0.09989816410046432, 0.0843457212190955, 0.14590173629262757, 0.16324711603022393, 0.1741569281946267, 0.13141510557503472, 0.14605017348883614, 0.21025912806151376, 0.15984007788281288, 0.12981146904489688, 0.10217105504125358, 0.1597471054523222, 0.07814833038156072, 0.07369526046057863, 0.15565921432308613, 0.15671649226738563, 0.13098067243493375, 0.1682956814165077, 0.17891718405148677, 0.20135976043680023, 0.09894744132555301, 0.11436329073002262, 0.14289764507162955, 0.14480828367654355, 0.12468912939150488], [0.03708086186839688, 0.0029748197196186672, 0.035934438102788506, 0.03147738452460016, 0.07059330916813306, 0.0254781557352192, 0.05965694822671433, 0.06739055602661065, 0.023126292620755495, 0.037102457886982354, 0.03283220335781094, 0.06005455935073476, 0.029840348476183512, 0.01767437811189842, 0.0054955609319280955, 0.05612861920869159, 0.08890594385804669, 0.01835561222246578, 0.007272266779064893, 0.06631249411692543, 0.05035603944692881, 0.05444466985101181, 0.09061337764104528, 0.04244918086295647, 0.06128232250170362, 0.025502042356698264, 0.049603074608791264, 0.047767765429471774, 0.02433599333368963, 0.016509298190114, 0.033214925563022975, 0.012034661936453514, 0.008913048039821368, 0.0038083324785299242, 0.03907552499684595, 0.051239947863524, 0.03849331349615128, 0.01905662672323806, 0.0265118841367263, 0.04017042168866723, 0.09660629195071037, 0.02938621155467005, 0.05638229007261896, 0.041732988245184385, 0.03367041846016242, 0.02988068492061669, 0.02623324646734663, 0.03945715935720552, 0.012853598436190477, 0.01706462383510605, 0.027216075987164533, 0.03562900650825712, 0.07662795994791292, 0.022273870417848233, 0.06846112559639639, 0.010914821421817667, 0.05257872864603997, 0.05949137747407921, 0.04009013950464226, 0.05192933506482551, 0.10058382811445384, 0.029084761702125112, 0.03484881107485102, 0.024661779884369146, 0.008958762421482995, 0.029940175478376692, 0.03617938322525832, 0.053041717713518496, 0.03822709794246382, 0.06572924839753298, 0.02497292841003547, 0.029490987484854077, 0.01019785218241234, 0.0297506453259097, 0.01134442629277586, 0.021722264129728563, 0.06092322644807639, 0.016109509461168802, 0.036046283109293836, 0.02550385798507881, 0.003048352908433205, 0.04283559178152392, 0.05843959621063644, 0.04206633991411617, 0.012905877233753282, 0.01715573658716054, 0.012519511322851383, 0.0037932630502543747, 0.04842459389399137, 0.046878923406644214, 0.017006516066049377, 0.03622989140210613, 0.045007910699613636, 0.014522118783075244, 0.06502100011153568, 0.02641079308945806, 0.018002999187897772, 0.03525724319080192, 0.08056643328839734, 0.010691427310267764, 0.006811477341538957, 0.00587567987461244, 0.005159128153125846, 0.04369851321943345, 0.10203234716168336, 0.060818402637397094, 0.01393497846419773, 0.023591892132836006, 0.04870277957149571, 0.01905299929691659, 0.07709908869958694, 0.03924328676094452, 0.060127602003875284, 0.043988768612184835, 0.10602721223427404, 0.06313834669849565, 0.012981156863632702, 0.02606701879431644, 0.025992378847853794, 0.04332104254694235, 0.029119076695473447, 0.018607827519337018, 0.0723095606231401, 0.030364908030136462, 0.021087543047483892, 0.027480456760273348, 0.0358820874844828, 0.05429739710844813, 0.020970124751329425, 0.05515701287696439, 0.0064160217974154705, 0.10555669635293946, 0.03877256786631, 0.0369752528175952, 0.02872005788489215, 0.0824870540189647, 0.012917387704815597, 0.006856753137863933, 0.023353738379814935, 0.021490673834998763, 0.06425101663016024, 0.01882098956904825, 0.056756267384175337, 0.03872928389858815, 0.010063301287441245, 0.027330441422940745, 0.008017002396480812, 0.06379601402929233, 0.05882786489242028, 0.05745573630256038, 0.023137282152029297, 0.07059144757447705, 0.04525312778329657, 0.0406774454900334, 0.04629939321368452, 0.044588389460958784, 0.040360503424439705, 0.004858996450615626, 0.036992041634455804, 0.03217883378026947, 0.05091074839114182, 0.049118179257117936, 0.052763064722380335, 0.04997948424950723, 0.047040184914705255, 0.015520117801403808, 0.036012533105789654, 0.07664525821324318, 0.043570588027397474, 0.0975634268815479, 0.053911039816035386, 0.00985264626046222, 0.03636536256019627, 0.007907198056683787, 0.04963312057718154, 0.07365887894505456, 0.0473990319897571, 0.01386107204692258, 0.06963586014124655, 0.0446164550920648, 0.02304363364894544, 0.049492125925157344, 0.038342110722536044, 0.04612005203061047, 0.01598005113567436, 0.08920615073293449, 0.03808791125794092, 0.03540869877343217, 0.029392323021085996, 0.06865005053940319, 0.01855948545609511, 0.03953487897712377, 0.015896785039184316, 0.025656389921242674, 0.017738386673191865, 0.025689913928809188, 0.013998891264500638, 0.08865041523090295, 0.040707472306225574, 0.04896730207087052, 0.04019831111955066, 0.03688340653635321, 0.07685364945040596, 0.04889477269663926, 0.02047234188554989, 0.038193160247418194, 0.005349375555411943, 0.009072520732579213, 0.03834524785258597, 0.030856410890156706, 0.0856305655813025, 0.06483782082796097, 0.018835616102742574, 0.041563334243912856, 0.059659978104454864, 0.05177777222988587, 0.03347372921604303, 0.03599842559666403, 0.06843490240674827, 0.04770984535195655, 0.028406852413149133, 0.06254071767832484, 0.07160103654549008, 0.0772918900474906, 0.06387984320040672, 0.02263135960205428, 0.018295730959864396, 0.008696583193546582, 0.009003611123790185, 0.007759531736449009, 0.04401929338552779, 0.06432035907862649, 0.02704352425831941, 0.013308091588588733, 0.027100205188617114, 0.020734952995553613, 0.03710983148325355, 0.030702417641277277, 0.05737465355665453, 0.019546580170431448, 0.05471463540508863, 0.01277735832357599, 0.02232535727201931, 0.017725204215234807, 0.05447195790287468, 0.051193974927187934, 0.029649265080450043, 0.051799057982862, 0.04710668900741204, 0.11391206494262142, 0.06011349832518928, 0.06018933719925343, 0.03200601392065085, 0.027092333635195132, 0.04315014748323349, 0.025706758287044305, 0.005101183177753082, 0.07576475505747142, 0.0048401368023347, 0.025618909069547252, 0.036797807702133735, 0.04036019315883037, 0.03304804096959772, 0.016361261274845853, 0.02369299084098349, 0.041415571205077634, 0.02660944734910323, 0.06433252455486406, 0.0640141575657312, 0.013845395972771991, 0.027488625172765988, 0.012787334703569932, 0.0339536564875274, 0.06278321131943695, 0.052471652536863284, 0.03570993220613849, 0.1001764455389592, 0.05672217647154486, 0.01332018620169331, 0.03223748547175238, 0.061972062103450305, 0.05807076317949161, 0.07818031455239943, 0.03874057603459205, 0.056584686671774236, 0.008818406495265663, 0.1223532890059775, 0.02821597586115522, 0.014559167752703352, 0.034298392223013986, 0.05242140099947011, 0.04150591978442766, 0.03371054997607585, 0.011146924995456733, 0.036407845966037244, 0.011035404618709319, 0.026324431997753923, 0.034574394549934134, 0.05614719684085539, 0.01030918199478859, 0.018771789487331145, 0.03410993459364099, 0.010572251799936977, 0.02674666901810035, 0.07910140504639956, 0.03859328797026988, 0.14596371280570186, 0.006456679998776846, 0.030028032356752988, 0.05515382595119938, 0.06347639065596365, 0.04210098241005213, 0.058497091109353694, 0.021096220908446178, 0.011402391377956638, 0.014736700010666204, 0.07031395520654417, 0.04029233692093723, 0.021068352544980667, 0.017838202184066176, 0.02268912837720446, 0.006082646188236052, 0.028784200511572343, 0.058696706809343836, 0.05096696775346514, 0.06257631395372652, 0.028918637450964704, 0.046841634076929865, 0.043451258341871926, 0.033016868851958744, 0.015921232820067917, 0.0253307891468848, 0.021275383976077842, 0.03583536761242055, 0.010992027762826654, 0.05926474568343932, 0.026146381672832276, 0.029611629095949957, 0.07631799311286981, 0.02999248013140694, 0.02935119367565119, 0.020284054710740046, 0.040577099463271524, 0.06333452266370578, 0.03165400992598265, 0.08336125227111964, 0.04362211510118458, 0.040046146905590455, 0.04744656008457945, 0.046264735395990075, 0.003258839635471363, 0.0450067768894857, 0.14810468340593, 0.07660182102793649, 0.15621095084615294, 0.07418149646611945, 0.08998476419477694, 0.11445129124988472, 0.09349695557067472, 0.11872965481973465, 0.1226049795326206, 0.17567041149783522, 0.10141058254145807, 0.20744076719687832, 0.17192915983257756, 0.1878789418767537, 0.10369150208369379, 0.17981390528861554, 0.16328882185682175, 0.10224721950268555, 0.08663935782087427, 0.1588344495863684, 0.12999837917666282, 0.3031293777448516, 0.15930507272001238, 0.14937626678616772, 0.14044202683914092, 0.1353550957696092, 0.2071527028155904, 0.14538439711736095, 0.09974696898772832, 0.15931661000415204, 0.13105158153320515, 0.08169813667454066, 0.135073681031504, 0.13949800733356707, 0.17156027317527803, 0.23510473840419324, 0.10377499800656112, 0.1303693802366334, 0.13514318052799473, 0.21259931216557182, 0.22849295528665667, 0.155080710687945, 0.26864043647243135, 0.13697826754181616, 0.19832573049972135, 0.11902692757787244, 0.13247777677832112, 0.10493876983321483, 0.1251068694757358, 0.19224493824426206, 0.147804974488193, 0.09657679756562557, 0.13931181732444994, 0.08505531781983953, 0.21118105359135136, 0.18361915593906758, 0.1950574308753975, 0.09828990806014308, 0.13935761406056343, 0.153270153809459, 0.1628283723708122, 0.09966670595590146, 0.09162871993236965, 0.05675050640298475, 0.17945879289219457, 0.12213852391728472, 0.09877062057174983, 0.13426945725035283, 0.16211935799689065, 0.15593390280921615, 0.07664914227901928, 0.1417928696760247, 0.13333080036024894, 0.21796928207960822, 0.18579565769722386, 0.12707917049767511, 0.16231651838508346, 0.14388110278354538, 0.08725880885556822, 0.07517866715187989, 0.1485728550582163, 0.1485077682281694, 0.13272821092076842, 0.07757071540841172, 0.0881712272342655, 0.11425254505968864, 0.10444611401086855, 0.11156391352415086, 0.11721326804329311, 0.14742778343779428, 0.16094810149121672, 0.1397966284064516, 0.1255846785141095, 0.06482663594426648, 0.14549932562776152, 0.12612042678219657, 0.10191199474877889, 0.17629134108222302, 0.13949322694491956, 0.0966502194322886, 0.15296685960023634, 0.1295918009934887, 0.10790420425755363, 0.167904103234891, 0.18926983579031884, 0.20775769777115316, 0.15036095023876236, 0.0951796523745983, 0.13816967215989867, 0.05824958725321678, 0.1374565975199784, 0.09198933284008697, 0.1708183170206124, 0.09159413872346764, 0.3116782141789314, 0.13265992184319805, 0.08903063998948182, 0.17867834848021308, 0.09326529824325154, 0.12121436141070821, 0.11139795589711397, 0.1132077849920719, 0.1453532479823597, 0.1023238665995098, 0.09325759905961253, 0.14817658841850298, 0.12129796458588493, 0.19181467262246918, 0.15840312676324, 0.09003933263762344, 0.23112367057511884, 0.1521679524692797, 0.1738789455304223, 0.10207795237581577, 0.12597572043417923, 0.21531602848441372, 0.12023129440363377, 0.11429998122396008, 0.1606639441583426, 0.09096020096612555, 0.19106942228972915, 0.20171473493739484, 0.13282614760100842, 0.10063401453437344, 0.11039552218731373, 0.11792650356167748, 0.12225806427698944, 0.16289998626997396, 0.13890401340059697, 0.12412335813766527, 0.11468215950674589, 0.19911450994831903, 0.13971462635503662, 0.18872850274126377, 0.13475580050820304, 0.1353303970949304, 0.1268686955013583, 0.14829928506045573, 0.14668431042903854, 0.1488981206691073, 0.12719078184736352, 0.10437622380953643, 0.21752473657890675, 0.10559538379311563, 0.121529744487376, 0.24444589361308083, 0.12585958150485832, 0.11231919960869897, 0.09698882263394133, 0.20341273817804553, 0.16880992559656022, 0.14474569429312983, 0.1209390447324803, 0.1322120515209052, 0.2276004781766284, 0.19724930035731486], [0.04016146995127201, 0.024729431193742542, 0.02711524732501036, 0.02151612902150279, 0.0358605029572162, 0.025233130173517332, 0.09025192203661127, 0.016753256974381306, 0.05141542030258044, 0.056991686203306725, 0.018087734257982626, 0.07322765571335632, 0.024995564392978148, 0.011215319410116683, 0.044566157589396166, 0.024807575992458773, 0.03498860679927372, 0.08970807621916456, 0.07991195671380528, 0.02150824980720157, 0.0648437503484949, 0.020543298864316557, 0.057371968418479934, 0.032086041380441, 0.048967891958572214, 0.006466918285079902, 0.0427552636322235, 0.019200950027293256, 0.020737019517729362, 0.05455111776809058, 0.030915236866642392, 0.03162692871785933, 0.16537259633262313, 0.020880919558206396, 0.041382280854328025, 0.04538479914528228, 0.07176795944331155, 0.011730946378872521, 0.05851252395058832, 0.04246113183457525, 0.06280858798192875, 0.02169038912641906, 0.022376028242551034, 0.04517432414896546, 0.03927958783723655, 0.05001885350793601, 0.017253320866955385, 0.028561402990993474, 0.008990336735282213, 0.06283091944492152, 0.01868527517804215, 0.029584810272940708, 0.027327277479813467, 0.035211300897982814, 0.029916143300192013, 0.06973393471731294, 0.025261649711718483, 0.026883471253958922, 0.055837065296908545, 0.04540612320265463, 0.017625821544037714, 0.07489457876691896, 0.03492949545503624, 0.06618173056913, 0.08926797402842392, 0.07093062534207298, 0.02532408396232753, 0.017533906314882542, 0.05652247267144342, 0.0068454667475194705, 0.05875962178012537, 0.06153009448861403, 0.08492558849074187, 0.024369613102246678, 0.030501991803307208, 0.05240732030342183, 0.03219805109585005, 0.011931081103431362, 0.02153666592353294, 0.02985738052596008, 0.049744027125979626, 0.025594961161034244, 0.03837970648742011, 0.025471442889782692, 0.03786500265461303, 0.01192353896781682, 0.06235540100944139, 0.06273916892467007, 0.02238500870824341, 0.018010684964998115, 0.02727806782199731, 0.04890344864238174, 0.049188421858895215, 0.018254030878926, 0.03471496402316036, 0.1045857565177064, 0.030942967334281535, 0.02266847081632624, 0.025693895670795636, 0.03025510081750972, 0.08633308352962618, 0.03866661790638201, 0.026200542173859094, 0.03769188593592375, 0.04718424391842658, 0.035222604525305574, 0.043482813503473036, 0.05376863556223051, 0.012446398764187771, 0.04002967984565804, 0.04037736501965312, 0.04942791626578377, 0.11457722844375719, 0.07610858297876774, 0.10558278164676121, 0.00988062474906685, 0.046632813830529495, 0.046917155024505434, 0.09753735690948465, 0.0059218232655116635, 0.08323136206355788, 0.05072511379576979, 0.04756605064856911, 0.012680563114343152, 0.042726975835619435, 0.06714858715572665, 0.05992952614061295, 0.04739777560556128, 0.014798768454291409, 0.032270105495568246, 0.09531345729145313, 0.032122792533388546, 0.06066969347997539, 0.03879466950292549, 0.020827534721202908, 0.020560771414649584, 0.055682959050060286, 0.04186364837111004, 0.0010670817151079857, 0.02376108456613316, 0.009132176956852839, 0.01869188268638907, 0.029859722839788567, 0.03706886876194227, 0.048385837505902016, 0.02750575298353309, 0.013442581196525886, 0.03875924176686714, 0.03228934962422617, 0.03986739561021809, 0.059205699456675406, 0.04211392929597248, 0.07952036321043007, 0.07506218348299304, 0.029729177627051552, 0.10041305179437322, 0.03519385707594695, 0.01815546026092864, 0.026563572088977503, 0.016149292407076687, 0.056906351669421124, 0.05236502458912231, 0.015927050300242922, 0.04865309876960613, 0.02933002858152313, 0.013531317160795293, 0.07257728537003841, 0.03593970878770755, 0.025546446728009372, 0.061259577351231734, 0.031019177760988958, 0.052902293541739066, 0.0349012459628284, 0.03571521821281603, 0.06263480093630572, 0.034957269972731034, 0.030912884976714853, 0.04529674116882586, 0.06343113018139716, 0.040430056547085126, 0.03410147698295694, 0.06231993496898682, 0.03952246069187119, 0.039088659574307745, 0.05927355186412892, 0.013251869353435695, 0.018830753359643203, 0.037590107324743466, 0.04449743567214859, 0.061462690242596214, 0.06509272892388605, 0.04769818932418862, 0.055663871969426834, 0.03425518486408457, 0.10397745206231072, 0.007006399795382976, 0.02358387502270841, 0.0038111021257786746, 0.03757901820203951, 0.05208144565263102, 0.014117086182288347, 0.11996764524449265, 0.06063971262905867, 0.0118943807038088, 0.06752849015737734, 0.03162134968255076, 0.040463323915197004, 0.01778488821019569, 0.09539444810680806, 0.007378806147889625, 0.05872161615820182, 0.10069353956609003, 0.05021489157731976, 0.025938986349971067, 0.03973763946804308, 0.02271324099462119, 0.06540592864996965, 0.0247289045082946, 0.030090849651324175, 0.02385349009155987, 0.010724514647717438, 0.04347965339078538, 0.04361193762311051, 0.009764165020427637, 0.004782788417932968, 0.03664161769613143, 0.0125094918504117, 0.03319480426369175, 0.06073314471230392, 0.02490229510341681, 0.01904707360682228, 0.039192227000791224, 0.03532564718156092, 0.03413702346264355, 0.028614397123155576, 0.014741385595933085, 0.08858745812528557, 0.04428669254505827, 0.014498755974214406, 0.03338032394587513, 0.10903438312872764, 0.04865461945413582, 0.04170265116338288, 0.032000183991547075, 0.042684051929222006, 0.025235369065476042, 0.037581645883619785, 0.0521219602125066, 0.032634062377075036, 0.021594338937692588, 0.026936798634368087, 0.05235268291266215, 0.06985510684429638, 0.05005063466547478, 0.0734528549195778, 0.026025567691953435, 0.03425786234137993, 0.03702753448798772, 0.042774618843630444, 0.028362528481070074, 0.017309067169985464, 0.02852998189477911, 0.07249011222513453, 0.02289588593186871, 0.03412945068351204, 0.04686149490636684, 0.030371586401616375, 0.03823575856644781, 0.03499277814802143, 0.026738063935490868, 0.006172895654960866, 0.02601424491243257, 0.010019509786469562, 0.03176234624979477, 0.01969540232582198, 0.009370077900858897, 0.03198694216177589, 0.007731336828005771, 0.05843385055120434, 0.04835156273216971, 0.07667639968736518, 0.04895144022039829, 0.050627717207516396, 0.11951761455425333, 0.030750401558414586, 0.06959965482594506, 0.06437834427361527, 0.025115633353350625, 0.020226374035701156, 0.030358141558545253, 0.04797157163040773, 0.02533625135378492, 0.02852463077062801, 0.046841362115716746, 0.048412493535227356, 0.04561608492006217, 0.07119458093638383, 0.011246962671829088, 0.07624040372789868, 0.02932540907133972, 0.009743811979499317, 0.037005333259942076, 0.06192679779844419, 0.05155983170674694, 0.040664647991258296, 0.019736974087033062, 0.011129210169817652, 0.04875314985251716, 0.03969183124061074, 0.01294995410247676, 0.05859357988341682, 0.03969540887121712, 0.04846365288681081, 0.02000051982430441, 0.05549704100215628, 0.05389142413473418, 0.012056434155261565, 0.0481626186369648, 0.019921951762010014, 0.05616146522844511, 0.01458836144827787, 0.01016677869859362, 0.04047566176121754, 0.04800396182784631, 0.05110148130164993, 0.034875168329885894, 0.06130272342312721, 0.011705361915031269, 0.009459993640531697, 0.09239370469003917, 0.02484629982181134, 0.152024433557545, 0.08589713353543513, 0.04429133503787941, 0.022749718271135803, 0.01551816906524642, 0.0360766661563708, 0.062410122669872746, 0.037743696462242834, 0.03758294440265145, 0.04819054254180482, 0.054555660669481566, 0.05487911448243165, 0.037769023329019547, 0.030633636352215565, 0.03891981762623595, 0.040893926615676576, 0.027672662474815885, 0.02642975185036419, 0.011261990444073755, 0.07365161643153237, 0.11476480507201726, 0.1164354513128919, 0.11075703907878169, 0.15490893845356282, 0.11489695523895564, 0.13147640793073562, 0.11787837025739493, 0.14461426424884027, 0.12257912406517614, 0.18374704665714697, 0.1309516683461205, 0.08529367075572092, 0.15635296822555605, 0.13116255702991642, 0.13054075410529492, 0.17388001805351627, 0.15345865740410744, 0.1366775473880191, 0.1894492689039438, 0.20938405646912514, 0.14436024481490736, 0.16829715230532233, 0.08907243774663057, 0.20002019441416188, 0.19284533667227916, 0.14077283892660372, 0.1633814112433503, 0.12042976480217711, 0.09507534184282827, 0.10851995508757331, 0.12554672651834067, 0.13963467741925872, 0.15140590948923943, 0.2330748199094688, 0.1568692042342117, 0.11195183746636876, 0.15395609361510124, 0.1271309810239942, 0.12156773478754106, 0.13188343044490586, 0.15936237609674855, 0.12958556503778504, 0.1264777838162357, 0.1657334697102347, 0.13783881410716042, 0.11450144702628737, 0.1260275769257738, 0.07076229284247083, 0.1328174295204301, 0.09335365116355882, 0.17897316975699318, 0.17405407322991281, 0.1462589018046856, 0.07319675172649084, 0.21372144711354088, 0.10833432432264091, 0.15347100674144684, 0.13321504447489016, 0.10162906315658363, 0.22800134134388741, 0.18789711348231763, 0.15890872947150664, 0.11977387096492514, 0.08721600752323867, 0.15860568041041975, 0.2867476293636907, 0.16256091575468742, 0.11542537204560735, 0.09203499934125332, 0.12875734738284542, 0.20067942839476371, 0.14934862633385967, 0.15044871327136794, 0.14999718104879703, 0.09652540072678559, 0.08016674223566249, 0.1296210502304377, 0.12838528146066014, 0.11578153398248459, 0.1550970590042491, 0.13845537699037982, 0.10708443655241882, 0.16944378674510988, 0.13934190925811568, 0.10332164249473041, 0.11486667178330884, 0.11541474640609757, 0.13679459030109067, 0.15650344321564322, 0.1558638057641445, 0.13962652624374436, 0.1458429313835598, 0.08047673971422258, 0.12663484716247167, 0.14501192516857578, 0.14981316672938486, 0.2277991554189113, 0.10664764386151107, 0.10368597858975973, 0.1442292284580969, 0.1201203189069225, 0.18182122418957372, 0.06508743525632928, 0.11055203395024424, 0.11156389054151312, 0.13354044798160755, 0.22155189225750588, 0.13382759305738634, 0.2722596503313511, 0.09276406989703256, 0.13710615825989556, 0.12552370557621603, 0.13754376300400303, 0.1963800510331508, 0.17934155079626268, 0.1897077929348715, 0.13699319093458115, 0.11793478497213895, 0.13586056058204946, 0.22691495205846526, 0.1427713324946742, 0.18563690895755447, 0.2036932336106416, 0.11206030785556763, 0.12644681854233628, 0.1321418931887996, 0.14896814110538653, 0.16013096146766218, 0.11574263203768961, 0.0955692234058534, 0.17768903785655576, 0.2719880261969182, 0.21539757088307412, 0.19059423327205643, 0.2987566091600926, 0.17443134088910398, 0.09140110754918668, 0.1589520900480209, 0.1591389388927529, 0.1264901561362128, 0.09183452179234836, 0.0730110060483698, 0.2103974988623973, 0.13411188828608683, 0.104566466423773, 0.21706712161821706, 0.1127799861733952, 0.11154058614685652, 0.11633065048485033, 0.11964249454679028, 0.09852905006658647, 0.15105562344674142, 0.13162205656689982, 0.1575779734599975, 0.12896098887487767, 0.08578761360578, 0.18017654066845296, 0.2322213519965449, 0.1694045936869037, 0.1411674508164006, 0.14405079125877351, 0.10501523306893726, 0.17095127924075051, 0.15156913218238663, 0.17981336902706854, 0.2002583405063037, 0.10135265097262398, 0.2481331514014352, 0.16050738643013662, 0.118224335564, 0.15666331044368206, 0.1212141622278479, 0.1625026777506836, 0.23391983021170865, 0.19577075066345354, 0.2185878214696723, 0.26334284654548096], [0.035457406643657916, 0.014251308617061906, 0.028644879761662696, 0.06896262207338888, 0.027942444167790875, 0.15416610895866348, 0.03885406046925534, 0.03357935741904282, 0.019450131615984346, 0.05245463006318577, 0.04001543827114567, 0.030799616961890174, 0.02890835272058124, 0.06841358217981554, 0.009590052387436793, 0.02158374777213941, 0.02869913219324043, 0.01996372270608141, 0.03222774849423478, 0.04118137429618547, 0.0484470249484143, 0.0331847187161686, 0.04089100782068507, 0.03353073764892836, 0.0747359985665929, 0.019028128252454826, 0.026795503292833606, 0.029184898969927625, 0.02970567979519406, 0.06434948574150763, 0.03639823922346677, 0.0252323008833393, 0.013346742639588493, 0.0904555635286435, 0.032732355288199844, 0.024041064804600134, 0.03707952121452939, 0.03640113503582055, 0.028328393518383947, 0.02150183573605553, 0.027700649581909664, 0.05425505542887315, 0.06886420275775657, 0.01357772772485811, 0.07981863954374868, 0.1605620544644133, 0.03794558361292847, 0.04166282991307878, 0.06672939916531886, 0.05830566871971373, 0.043845973653538574, 0.03454275894910097, 0.016361741995018338, 0.03339304866629743, 0.02181117054856112, 0.031037420229685884, 0.031212875431764032, 0.06072096391430786, 0.08134054981412427, 0.08285476090086084, 0.014828974343535882, 0.12450578922946608, 0.02000055046782138, 0.02703932226605473, 0.050440496810141115, 0.053094141110177004, 0.005282599980296988, 0.037300392023978696, 0.001736063206936383, 0.03335338829445743, 0.014213833511025916, 0.13560678629625228, 0.08128503142225166, 0.07941574624349033, 0.004332301905378699, 0.06811893710325803, 0.022460746075657588, 0.0073317755314130945, 0.03579505606584492, 0.02040294389570913, 0.05278800854519491, 0.006971124798104528, 0.05843433318659664, 0.028337802993313923, 0.023965633872355667, 0.08748707241348683, 0.027301019816208753, 0.012010593369092432, 0.021294811965837594, 0.011017369951361851, 0.007834670597672342, 0.045401235561697714, 0.04836878055826791, 0.039495613140564774, 0.045031038894047665, 0.01714459575352169, 0.03284086781223455, 0.05587433547442479, 0.013822434402461496, 0.043180388804044456, 0.03364021161330804, 0.03828227925564974, 0.037663586648000826, 0.05461384121689105, 0.08304876500680562, 0.01533912665646283, 0.016476528779152903, 0.07934877483714974, 0.046945262790447286, 0.04628375735914996, 0.05896889018796145, 0.047949274641371546, 0.010469563459346612, 0.06255605475856893, 0.03558414439941126, 0.04063790003138204, 0.08115643590328195, 0.03852129102714601, 0.029833627969867764, 0.04902941647977118, 0.02624226332221541, 0.03465948776612359, 0.09508262733898817, 0.013184754305609293, 0.05699021531449211, 0.018394801450232347, 0.007146312348214129, 0.03374294400395405, 0.03865340672012779, 0.03698460292071104, 0.04139171139667592, 0.014449838387419381, 0.019632236461245248, 0.05360455102016849, 0.021919949288149516, 0.04959134963311015, 0.019771672124343536, 0.05060984820668256, 0.03445341394493177, 0.020824207984391722, 0.024370172346431403, 0.07917157103938442, 0.05602767563334877, 0.026589517571753072, 0.09142055086070493, 0.05632462663455837, 0.008197115891943536, 0.04720544157129142, 0.0156322251930232, 0.040072396908315926, 0.010335094918827377, 0.02550012139122813, 0.05535373659504037, 0.026387235885786436, 0.030590478789001226, 0.024396724953886964, 0.04759621153014803, 0.0728867082826553, 0.054649364713939934, 0.0991657687230937, 0.029187298740350434, 0.03858068582391547, 0.017256258814145, 0.04939174159399925, 0.033560461860390446, 0.025434412114742785, 0.026122228835799524, 0.05413326660111066, 0.012084686520299124, 0.01845933286653411, 0.034203780364365347, 0.0341321817869621, 0.04862240545691983, 0.045145492429935166, 0.064413768179234, 0.01831478739698087, 0.04340626982851856, 0.03279728507022223, 0.06291615055693735, 0.035268305500428525, 0.026461691971147255, 0.05547790029536813, 0.0182806983995702, 0.013237287827406921, 0.05161731511414532, 0.024304139397798047, 0.042014709418459285, 0.02206477821023474, 0.012115684352935323, 0.04195700767600248, 0.05693110397025462, 0.018453750000785918, 0.0454724817386558, 0.03722795458029836, 0.03241963053662931, 0.010415313900598596, 0.05788345085156541, 0.09145545382653514, 0.024415917371610002, 0.03854752953855261, 0.04689359399039419, 0.045156010817135536, 0.12276067158147214, 0.008726191534210117, 0.008209632811016374, 0.02197328241421811, 0.022238461833987987, 0.022091123973950747, 0.017151569068852453, 0.07461399906465123, 0.02211307430820119, 0.009630674199621764, 0.025199927922879017, 0.043428697052501866, 0.029082520894946593, 0.028071252276159586, 0.0404736852543729, 0.0064724958839736165, 0.01768606669840313, 0.03606915083383361, 0.06237591684405362, 0.042431353996958465, 0.09004760638720567, 0.030417256733222358, 0.0019270851959346704, 0.04451410957582055, 0.09147305086615587, 0.029885425089648174, 0.04748260452141685, 0.014157212910152251, 0.04374245602277018, 0.04777724193709512, 0.030810439869040446, 0.031369862169207584, 0.15293555724765026, 0.07574623871234155, 0.015554980547618003, 0.04052190665876673, 0.019150824894407587, 0.0320448947980279, 0.033496493518713026, 0.047127070776637525, 0.04775104939096397, 0.029300243083027103, 0.05016401950870791, 0.033503457257944735, 0.03699730848893523, 0.031508807536034335, 0.03909346677603261, 0.05464651869730123, 0.011246979908807384, 0.004256900180236347, 0.11064213355101886, 0.07069601857614133, 0.015770062605189462, 0.04175538482565073, 0.04620391184524183, 0.048466315042347684, 0.0312929067219938, 0.035117581531765966, 0.03911205206907565, 0.08445898731870037, 0.03927860724469347, 0.022244973581344373, 0.02809000610854597, 0.008043708700326183, 0.007287089622789815, 0.0600314962737743, 0.028262833629043835, 0.04339213167587596, 0.03608413168319291, 0.021118556201878576, 0.040184663263179606, 0.030619683975894606, 0.013346779028764896, 0.04927353422728278, 0.02337595684483888, 0.11010971776540242, 0.04649399486821025, 0.07976245465538195, 0.035745965151657025, 0.04898781790548275, 0.022927533024020737, 0.06363497085628972, 0.0076652746722703025, 0.03894256277670784, 0.018974322067092986, 0.05911181921199445, 0.0404614967954976, 0.055083353523044824, 0.021571390773920764, 0.07382144280258687, 0.04980762008457415, 0.016887716896411394, 0.010477268388645064, 0.031552920793934215, 0.04613698640417668, 0.04000284761611012, 0.021195164994306622, 0.019863932093064633, 0.03281890407144543, 0.01256575717801048, 0.07738880783079133, 0.07437036012209232, 0.04271678303578689, 0.07495156038672694, 0.03852701370394038, 0.05913859398494806, 0.05794316740526308, 0.048220504240523425, 0.06455989178991126, 0.029168640668954582, 0.04242794873613504, 0.014560143557196904, 0.02544502243249407, 0.01703244814228627, 0.04712062797719433, 0.03080285559859007, 0.025871626154008894, 0.07612592720937345, 0.11104092062000306, 0.09254306885263613, 0.040375361699731126, 0.0184435629466128, 0.009518418378467041, 0.05243280804866264, 0.018576624758181073, 0.056795720912275784, 0.0014457144472192253, 0.013829764906286955, 0.041580877657378876, 0.03759853812235017, 0.03544203508945723, 0.06084522337562615, 0.0046437946918059985, 0.09952023760565828, 0.022642906462293, 0.05468293085634228, 0.03726939610656231, 0.0448288414777527, 0.029987278394401077, 0.08061229131154476, 0.02837933645012879, 0.0057547897637461225, 0.04654208220721734, 0.05263040893741193, 0.03319225702134352, 0.04130583294036408, 0.006004933750392088, 0.021062696900879665, 0.015711716391266357, 0.041276108728902, 0.11390220539103593, 0.12955648434017936, 0.09167571942652426, 0.20289910686833246, 0.16167024661216045, 0.18913740983172772, 0.059382589158391764, 0.15144269703136337, 0.1516409452644087, 0.15501341752467618, 0.2033912877161657, 0.1200987152274578, 0.08362742952041088, 0.12427676724450243, 0.11268659239454616, 0.1016122705092834, 0.14865995925520697, 0.11685663879278207, 0.15234634370332764, 0.12389045208692552, 0.21407035419777518, 0.12997521267783257, 0.13652227668752595, 0.1013633378991677, 0.17595611632831637, 0.10215784002455974, 0.2931943818205788, 0.16623318886324284, 0.0974003803886233, 0.1065256443595694, 0.17376801599898647, 0.1810654018434786, 0.11712767303951326, 0.21886853140688714, 0.13623499371592077, 0.06777867149080961, 0.07817430076219382, 0.15765343312053912, 0.11412014208373525, 0.19048262958324727, 0.09510950936425118, 0.08670738642855037, 0.13973128110651048, 0.1251166294358911, 0.2562902257927964, 0.19147143458887456, 0.14770257917623367, 0.12492751297090324, 0.126726609174042, 0.12180689977662218, 0.22539498765141736, 0.1123225320911696, 0.11646944263409223, 0.11246827265788471, 0.17275420588351068, 0.17940728114016596, 0.11292928904895821, 0.12334954804710804, 0.2373614648897802, 0.1699380973173726, 0.07961470693830522, 0.24923014334372937, 0.22035601368594557, 0.0866615743706784, 0.1906741209208004, 0.13763578548546762, 0.10443361911682353, 0.09022414368847687, 0.16974193284348135, 0.18798078560540754, 0.10612311878151472, 0.29538717060800523, 0.11656730270553982, 0.2268917242726011, 0.09493111046932398, 0.10340414250329619, 0.32232524286354747, 0.3349441818652615, 0.0968852628683371, 0.09590326838435666, 0.19252976973450955, 0.14574591400882891, 0.12523500534195092, 0.10006186942900382, 0.10067945120916252, 0.2597912629285167, 0.15657217662420966, 0.19561132776641077, 0.07495866202178501, 0.15332109865642365, 0.08005079482832263, 0.19062844675875482, 0.20355264115477764, 0.13935614317174883, 0.2813018780321844, 0.16275614560131105, 0.2313001465893561, 0.13398626518826331, 0.1254788128238532, 0.10695778689677678, 0.13441702110632775, 0.17446472700084412, 0.2202090320567931, 0.23239503945073775, 0.14578509174527662, 0.13464646443964975, 0.20870746293615913, 0.240604774726014, 0.15104581752131063, 0.1814412599008891, 0.22707642807114511, 0.14427903949493362, 0.1552296535021836, 0.19282967783510688, 0.09789108268676266, 0.19014464691281321, 0.13822112262489336, 0.1015308736673286, 0.15433279436922845, 0.10461888215955227, 0.19873371828467618, 0.11116909479061443, 0.19326902925968173, 0.09721383031818176, 0.12672214288144343, 0.15263690553124876, 0.22800411458217332, 0.25050365726553625, 0.11942158543294477, 0.187702956158788, 0.1360689671409707, 0.1946004747503227, 0.20015715561326475, 0.16155205456720245, 0.12935037604503094, 0.13865549447796038, 0.15144068988100176, 0.07670711981312883, 0.07608039860403346, 0.06936330904042529, 0.09025416667422942, 0.139231929675706, 0.09016737657328767, 0.14936590927743143, 0.23436590788825867, 0.14175269602527543, 0.09232533900367637, 0.11533478214856117, 0.03465894767413697, 0.15745714607258, 0.1226333630902152, 0.1313739206882254, 0.09801561793973369, 0.08510528973514035, 0.1824267860502005, 0.12470054410157666, 0.1768885525844751, 0.12366180548504477, 0.11348119411136835, 0.23828046396374705, 0.1108652106936901, 0.159790956325108, 0.134890019112537, 0.16290170230692433, 0.1239425307440181, 0.1728004929158957, 0.1219268691455645, 0.17466130516221448, 0.15260115986870182, 0.17397619273153045, 0.16391905174861032, 0.19192670532051595, 0.0746240501382178, 0.1242130287292023, 0.18353594346873223, 0.11294356126698757], [0.036477253531977054, 0.048366991742964716, 0.03771789079051345, 0.023635287183306875, 0.012953070165108771, 0.014080785105996316, 0.07099797979237572, 0.02542188274674118, 0.05681123036230284, 0.055989371237134745, 0.008292741859481942, 0.07735419597837233, 0.02876763960586921, 0.0516441741567706, 0.06422658608625494, 0.03275131596432578, 0.0504222026305093, 0.025974772232134017, 0.11755642180721607, 0.0177865908406074, 0.09714819956570865, 0.047649163527474295, 0.03739226894873766, 0.016959305897715594, 0.050683971043796315, 0.019646715523014148, 0.013096816030391043, 0.046043673064559705, 0.05745177179755223, 0.047103119037684896, 0.013763194738496697, 0.029523352784435117, 0.03412517974333417, 0.04030491225421429, 0.008551170129419096, 0.019354615773585056, 0.05166980745871702, 0.041403991786102136, 0.03905932989812667, 0.006301700890499858, 0.0506802287042862, 0.0453309852990412, 0.03145850045726665, 0.0652768275129699, 0.04973007283443886, 0.05639951555959641, 0.04093440670159556, 0.020041863674358017, 0.07589605486681385, 0.03125923524250186, 0.03294320183715994, 0.10786758525477302, 0.02751815977746681, 0.040878390352572166, 0.02252472207821425, 0.07284794423368669, 0.05964181799020979, 0.0054787725938724415, 0.03813254737084912, 0.06713435324209352, 0.05013361347899322, 0.04211258864210498, 0.03557818806579998, 0.012472170919570471, 0.046654831197473316, 0.07627700740892081, 0.10761447746547, 0.03772134584705195, 0.07160387873168915, 0.030081507209087574, 0.03731809631590882, 0.0669712531230142, 0.04124015239217589, 0.04508486423160761, 0.025015176243839726, 0.03140718597287853, 0.013215228325627265, 0.06151520173936602, 0.07127200178201161, 0.0057836851638351245, 0.05265213519094452, 0.03372901652549063, 0.015011279329267001, 0.03033925174555231, 0.01618476036275106, 0.03655349843264107, 0.0520697896248631, 0.029685223332395958, 0.012430266867722235, 0.028640231523182125, 0.02460448991417164, 0.057145049344868436, 0.02439460289033671, 0.05762986425730971, 0.017433566033780094, 0.03727259069320656, 0.03931830209049006, 0.04975320102887289, 0.005961876257412857, 0.06633059677457617, 0.007514759462567107, 0.038744632470151114, 0.08641346913552092, 0.003485680903278051, 0.02861593504466357, 0.02479811480659391, 0.026764693151738857, 0.023097863097885446, 0.08038046544477825, 0.057833413818791035, 0.03169937956807835, 0.0114408279243376, 0.0009706578789665665, 0.027360182871381124, 0.027971992179030375, 0.0290208661388005, 0.009053248833234032, 0.006220273405028087, 0.03772935529630031, 0.003961272595915943, 0.034088809719128955, 0.01942225176119997, 0.027525376325713533, 0.04094632702969736, 0.04302960354834796, 0.032733734246463544, 0.01424510426248514, 0.09378741014628642, 0.02347595047115559, 0.04612911868119433, 0.012012515292172472, 0.04316861403264827, 0.05390281969260785, 0.021386805719005007, 0.053681914409201954, 0.043217605355406, 0.08597029493220391, 0.023566210950394312, 0.03795870669907139, 0.10136039612153847, 0.06647611517579326, 0.01835209779411314, 0.026784327985238165, 0.05481076411782734, 0.038630830108999245, 0.06015626135312262, 0.01728248008857331, 0.022387481257019025, 0.03125238258601918, 0.012246956391590498, 0.03871029257894524, 0.043271729467256416, 0.028689309030831344, 0.02245531068183482, 0.02443240549896033, 0.04543012090688271, 0.07527386889823022, 0.021412613305954203, 0.03059980590947934, 0.004920664613300394, 0.0343787165418748, 0.0038714957096794202, 0.05263871716095075, 0.007279804605434859, 0.015325802472239781, 0.06489013697231008, 0.01684226106942421, 0.09187278022328693, 0.0284678942989558, 0.012828273484633576, 0.08764284107113078, 0.0485496654085094, 0.033947117927093665, 0.053257589799261866, 0.016497898801800706, 0.008963975649807722, 0.024868186953808033, 0.010948099323638506, 0.04030685428710234, 0.019845611100355466, 0.024501970112924615, 0.044578047273981, 0.05135178903958971, 0.020300889492876107, 0.018838544473833135, 0.016984740016801704, 0.012377251668142216, 0.0226984057019675, 0.030748168412115306, 0.04147609598153541, 0.04615675530306274, 0.04019241990341295, 0.01998112247806163, 0.014661902058569175, 0.03139808293311827, 0.0580893216594573, 0.04331513217860653, 0.025267989089291905, 0.04522171817840107, 0.07146607483586959, 0.07635678780535538, 0.02742438870031507, 0.016551710732821977, 0.03728254983622221, 0.0362995594379402, 0.01719577425730325, 0.04279071435091957, 0.03800148121832359, 0.028196185894851244, 0.008037067675632576, 0.014204438400244521, 0.02051918433168002, 0.0633021133140691, 0.021085223716293133, 0.03978412568328842, 0.019382229412815744, 0.03531835402452177, 0.036254923325031996, 0.04042331880379108, 0.01009136500332745, 0.03282904324512328, 0.02720412693076557, 0.024519971263925397, 0.038965629684107925, 0.04686830542801369, 0.0674848691109688, 0.05989432057005264, 0.02160425977631202, 0.06508699858621245, 0.08761152339678618, 0.016747856054515127, 0.025191774832144864, 0.05551577951278418, 0.01627933774744311, 0.05269288723807662, 0.10456474272594338, 0.037962885708698345, 0.010805934472309967, 0.05897875356998655, 0.06762869445787323, 0.04124753747976596, 0.04743316503722341, 0.07693624905040188, 0.07327921343066039, 0.06209807973655482, 0.02269546392433826, 0.04080601419592577, 0.05824304486234343, 0.014531606782017457, 0.0728789784554993, 0.07711172148945832, 0.06574846188267393, 0.028706308521871126, 0.045998910547143994, 0.06511229480947218, 0.044054594717078635, 0.01778619822054621, 0.035057849656309814, 0.01845542007246085, 0.04093090184934197, 0.064934937794122, 0.0019028441390893875, 0.028141759178270737, 0.04321995341489392, 0.03863053899558802, 0.04225939024059523, 0.04515773068452555, 0.018962238945307273, 0.01856465846480381, 0.05974496789877454, 0.05409782737373345, 0.03323990385979414, 0.015999751086647234, 0.043177891357411305, 0.038607985367097204, 0.05767740001301131, 0.03872261893364691, 0.04672791215501005, 0.05209252711445574, 0.02939765882347861, 0.03390043635942763, 0.05157026582427564, 0.056688426468040676, 0.04777026670654455, 0.04789613878294345, 0.03465844205610695, 0.015343639871946748, 0.05886191750065454, 0.007772704139502058, 0.001287291654021359, 0.022814446955078074, 0.06627042822900318, 0.027156047252637726, 0.0401930212824335, 0.019458098930396864, 0.021952214996300397, 0.1125944090346175, 0.03489023727935649, 0.04575545163524728, 0.04093845547627538, 0.016557048450434403, 0.019502127918625073, 0.1360449119801483, 0.013953787837958625, 0.013100673283089795, 0.07737297279339644, 0.046457490778618285, 0.013810538014607325, 0.04906805412423226, 0.12228274762990976, 0.013117834610203582, 0.03784174422523187, 0.0157866962892454, 0.04679592927136729, 0.10512813144633848, 0.015279250181910974, 0.033165570348501205, 0.038099912025274775, 0.021413053806510665, 0.02295786436016281, 0.04536450547616809, 0.053264220290246515, 0.03150535056427602, 0.05308770597161305, 0.06211378453900257, 0.049257323806804997, 0.060541304804745226, 0.0423369336602909, 0.028878785557143634, 0.0646577595222381, 0.03889240316986557, 0.012011318279790783, 0.034414469865300966, 0.03451175537080534, 0.04926756640235263, 0.02560529568713279, 0.054309650684797, 0.016889743198971116, 0.06737848248092398, 0.05465113437704502, 0.034076284181566975, 0.06845423080507787, 0.057140104247317205, 0.035843947797172496, 0.04719477379694582, 0.02150557424512602, 0.07223063058430149, 0.05192489558530431, 0.0269637362010056, 0.0156470260117203, 0.0057033823911971865, 0.019027231929583416, 0.1725193999347187, 0.15029865196875988, 0.18154106583566437, 0.09990854459183832, 0.14260296169067585, 0.0874354151047526, 0.228367516049935, 0.129296550707471, 0.12010976221532592, 0.19422316112585608, 0.10862888512952674, 0.15550841757607076, 0.149158222841159, 0.22816367537504245, 0.18156342028129488, 0.1993816601292741, 0.22870113201920064, 0.1319642986861929, 0.24928738543343162, 0.10377037083549846, 0.19316952976007618, 0.12946064674085186, 0.12778907353358884, 0.23491882418672885, 0.12553342723197516, 0.17080405246346228, 0.08413594336278978, 0.14580356978601025, 0.18198220990598205, 0.11871731314327448, 0.09965387398316976, 0.17410175454232002, 0.1382228846271192, 0.16078578278182015, 0.11220645444888262, 0.10369938512843463, 0.24659818699282987, 0.09513443020442802, 0.13130210760620334, 0.12681950499574024, 0.27449402237130754, 0.2365476956530925, 0.2503968339653746, 0.18821019829521257, 0.1267343619838357, 0.20394981177824162, 0.09770412658972126, 0.13114994722268275, 0.1599579328490842, 0.1930411947110007, 0.11952958850850982, 0.17248092699916134, 0.1332586655212987, 0.1387763218653779, 0.12161863366923026, 0.12000143738283266, 0.17982435472790273, 0.08626641089757604, 0.09664281136206082, 0.19692401942466536, 0.14604646562328263, 0.16926199408067813, 0.1262887516209195, 0.1600876008911479, 0.11555781332595695, 0.1725959474401128, 0.14438016310093865, 0.12979165801117498, 0.1613721924443399, 0.11011348691798988, 0.10686053203478937, 0.10933581574429428, 0.13627516736667003, 0.2212225663806162, 0.14171046925888908, 0.07525651700674527, 0.1997045815111168, 0.09415264256418714, 0.12460865951593846, 0.11867975951322626, 0.15439484749109517, 0.1411561740021552, 0.2628683623286986, 0.18116362963712987, 0.09605351354806654, 0.1192831380232688, 0.17678647902944397, 0.0967100662209334, 0.1570999345952465, 0.09903061549149214, 0.10702384665848748, 0.1189615955996898, 0.17521262799780216, 0.12399063340478367, 0.13635150036744534, 0.198197303520095, 0.13523241444941492, 0.15863134435588316, 0.19806283976762526, 0.09872617215038308, 0.11941232342994022, 0.141511470259678, 0.18125615773662446, 0.09200322967503341, 0.09949459664283261, 0.1423196776980354, 0.12344242854704782, 0.10076130770387189, 0.2403277420108357, 0.1309659175815121, 0.1325347890416461, 0.18471976381636437, 0.1001107611603314, 0.14528313561552955, 0.12368739282171573, 0.147857160397595, 0.13461868609151534, 0.08529275145021178, 0.14577324802596725, 0.0893694500348741, 0.175732372689151, 0.15666311126082175, 0.1328028432063518, 0.0855763188953842, 0.078652439218375, 0.08604014682913981, 0.30414698765643183, 0.12575420611087354, 0.0940132528663643, 0.10335478345833479, 0.15304970434836804, 0.09692141455748389, 0.13265817516273068, 0.18062799628223145, 0.15075429042260494, 0.19643951477783342, 0.1965064248971401, 0.13651130630845024, 0.13392638775610155, 0.13821370689378631, 0.22662385396899717, 0.15109990332876483, 0.15259792697766136, 0.10968490668963041, 0.16370280044934443, 0.1981731104634462, 0.09447744086144433, 0.19229294131359748, 0.14560680776353807, 0.11588556872260188, 0.09881177481504218, 0.172639936208725, 0.12349816910441845, 0.14657581705720196, 0.08751452900469305, 0.0930471393850542, 0.13164453358659822, 0.0766916141935414, 0.17085519649328726, 0.15069976028415466, 0.1565050673220427, 0.11885839589540997, 0.11020501144230367, 0.1415723742496583, 0.10383515889125486, 0.1844110763481548, 0.12418100625396737, 0.18582251673984915, 0.14211565316204103, 0.08209086398804381, 0.15410728872783724, 0.11782461386774817, 0.11295536668190073, 0.1414949534040305, 0.07377376915105889, 0.14182440185498807], [0.018726850769692854, 0.04940550436355895, 0.02051605294728952, 0.011556699680494926, 0.03094735318764804, 0.0359055144532073, 0.0409081413771116, 0.035091580507615884, 0.03146150160671002, 0.02824730311159886, 0.07894716090372494, 0.029628285762643623, 0.02933899181023721, 0.041267172313265266, 0.08339264655425664, 0.0478139988357021, 0.07530236736901345, 0.035876154133509246, 0.036993512523270426, 0.037006026569513545, 0.058094381670197176, 0.03405286870416134, 0.04294513469381679, 0.07503626672851463, 0.06330982015858735, 0.01932805167481063, 0.027577937618198416, 0.0356999654022436, 0.050554670723936254, 0.052421875973983165, 0.05657347114456277, 0.008523391781284684, 0.04275235632855085, 0.0633226789443964, 0.0445104859799387, 0.09836267109119123, 0.011292886770059987, 0.02609933238296259, 0.030691755612591104, 0.04262217117713825, 0.040449940359159824, 0.011248687327268624, 0.042106973217620004, 0.044240447647509076, 0.02625242547853099, 0.03242774723818706, 0.03281560223249178, 0.06801000706130458, 0.020055500039410208, 0.013765744853674645, 0.011199322536647802, 0.059296883071862885, 0.017036056416409633, 0.021751798734429385, 0.04699818414425658, 0.08430763132750027, 0.04443823622779981, 0.06483271102150602, 0.007362549283331441, 0.09235100294913977, 0.028188904229130958, 0.015523821836517704, 0.03239656362922923, 0.058313930977977095, 0.016282220153258215, 0.06250206854254489, 0.0668906070472252, 0.02209110482175264, 0.019787819342567556, 0.06714930727837548, 0.0180421635178068, 0.023705468498050206, 0.06272513802433688, 0.05204129115407986, 0.055589515475496176, 0.10052954312413932, 0.05254354605811739, 0.03172838748733123, 0.019474567905549082, 0.03240569922772627, 0.008109992542754739, 0.05317508596025648, 0.02824711733527722, 0.030234293869486263, 0.04232931874632355, 0.008117188023583544, 0.06288246950134635, 0.06837545398382411, 0.0666226831174666, 0.017693637562314832, 0.02064609254199651, 0.02796290254580879, 0.05375981022934279, 0.09838189223721143, 0.04699561774971024, 0.1199796804857831, 0.030490726480380665, 0.04413547444968455, 0.024865783352945602, 0.04192071426058969, 0.014225973131796046, 0.03120765262734025, 0.1001676585104677, 0.025887608663329197, 0.03413855946893173, 0.03232703731966115, 0.11745409544316993, 0.050757017527376457, 0.011395628736805052, 0.049037211424400734, 0.04114929053391661, 0.14327790047372543, 0.07612044968071484, 0.03748863514873289, 0.07227328635992543, 0.04567772052401016, 0.031105102182576255, 0.017422620552561937, 0.03955832126760676, 0.034395539832691994, 0.018428229696808324, 0.029372527309122588, 0.08586196243883142, 0.08795551219654661, 0.033461805057501605, 0.0759474823491708, 0.06375445375940011, 0.03895575864120357, 0.05037220773257075, 0.08192762597313813, 0.07964351184425816, 0.043343891119284016, 0.03575371413101112, 0.06625607174130217, 0.0314363528553757, 0.061010886058812185, 0.04846687811697203, 0.006446968397921733, 0.025032292563287963, 0.1193327651990037, 0.014453309723326277, 0.06256540103124515, 0.05400979621035438, 0.034301962192741134, 0.057340646913695725, 0.02542495667453735, 0.048729358992028626, 0.09844305669708599, 0.018490397731863686, 0.08041257218968484, 0.07948021254231853, 0.0458964501177111, 0.044256194584792664, 0.061485791623952894, 0.020022498886852015, 0.017537296253947482, 0.04667550791054965, 0.03630242460677701, 0.05489867270713853, 0.05192693720962252, 0.052553834618940476, 0.0463730180936475, 0.04007876692940632, 0.02337972791264615, 0.009750381183450021, 0.00830099932969578, 0.027401444366982868, 0.023432591809861125, 0.02882608636883238, 0.03762834660348393, 0.04916431690235773, 0.02182280933935075, 0.04915339248855749, 0.05554995469508633, 0.0771934707318583, 0.013805306591694395, 0.023470643397060134, 0.039428986473790104, 0.017983875718087922, 0.007654332542686814, 0.036323063015457124, 0.024517818556858167, 0.06007703637043315, 0.03629953645530247, 0.07610590167103276, 0.050407466929285764, 0.020976088745819948, 0.08226003918436267, 0.04079891639130731, 0.11378358433684034, 0.029064862568291928, 0.05052603818776627, 0.03881244657320842, 0.045403411251402674, 0.06118368102057327, 0.01007049676827005, 0.004080846471967356, 0.018856570522691456, 0.02806058258659417, 0.06256973325845695, 0.049933300638991984, 0.03263002509371408, 0.02496435397094296, 0.017487019818696766, 0.07573454821061704, 0.039843623901927666, 0.021735446587685617, 0.014183778924146488, 0.05248618139434726, 0.028549448188935077, 0.040952892403208443, 0.04369371750902745, 0.05991407797761983, 0.0273840177819253, 0.05608721981726347, 0.0851674577701957, 0.04995490048801707, 0.04285175240628662, 0.06973705269516477, 0.012244595883173809, 0.04371646265949934, 0.05113882425751898, 0.030552377406087135, 0.015775081438703403, 0.009416751807645686, 0.030459588836698286, 0.008246111045140893, 0.09265077315391072, 0.006987946173701917, 0.03254355291926092, 0.037584744709273504, 0.06480268803575347, 0.03444046705901142, 0.03646488887287917, 0.018799244163317547, 0.03330737705372515, 0.02482414647426096, 0.030078592244535688, 0.016747599415060495, 0.04525360658824925, 0.0324724254859311, 0.031656007500245206, 0.047504533788249384, 0.0573675595824757, 0.027451146236290375, 0.03945381155297641, 0.08376357866631401, 0.022656257459593397, 0.047543726846455574, 0.042126382055181655, 0.01280024520031387, 0.022931882488210837, 0.004532894846277251, 0.04700339354214169, 0.04019438874937835, 0.019828768657340158, 0.0296745459819513, 0.05583123536780477, 0.012549233619093656, 0.028084750745385408, 0.005913194242654549, 0.04476637849884649, 0.039089360544758464, 0.022550975911379344, 0.051452690480096694, 0.10505954359447765, 0.10214611887931825, 0.040439257263055736, 0.011632167001915796, 0.06378073057520293, 0.051683037797169346, 0.02955359793568571, 0.014351942884405295, 0.01593065282870685, 0.009890558994224957, 0.06144423901493992, 0.04487380700846834, 0.07876152247791329, 0.10566774079756391, 0.11139296866472691, 0.03967838256709999, 0.01629591397490473, 0.03886415750809735, 0.07157074542896402, 0.058486905970400384, 0.05405238303806513, 0.010421383232178708, 0.07686317192330476, 0.03559140308249382, 0.04699623828092891, 0.035499242705202876, 0.08296724559078295, 0.025166656724327517, 0.007891834163362341, 0.027154867477234335, 0.011602955111753077, 0.020006732797370325, 0.0349381330963825, 0.07729357544092402, 0.05795768860186781, 0.05116080332006659, 0.04781402947921907, 0.04932529495788678, 0.053113932991700794, 0.0777173982632737, 0.0719827551755213, 0.06773367914701663, 0.020439890401077368, 0.07838964807770907, 0.10282453570154407, 0.061440312814327984, 0.05857363478430818, 0.03453947243190581, 0.010197411681855879, 0.03556637115956795, 0.10448014363646509, 0.02069028623912844, 0.036097672287254565, 0.04360575146312195, 0.038679139613504374, 0.02440481867280699, 0.04003608817114465, 0.03707061544240963, 0.05951753171581415, 0.0860258975937482, 0.08145404574010642, 0.01122340834098718, 0.04165387817568356, 0.00792454659653407, 0.06831851832929157, 0.01713727578340519, 0.012085110741487194, 0.023042310232056246, 0.03905011386039757, 0.06287902593612671, 0.022947968419400916, 0.02002509975535495, 0.09770593455722255, 0.04114891898127333, 0.05018687574192882, 0.0449031328542098, 0.03557051186479869, 0.01418790622283855, 0.02646891618027322, 0.02038780982876497, 0.04149398796500699, 0.04438622651862041, 0.04445872141889507, 0.016751680748477098, 0.02913681163092054, 0.048284445769123496, 0.04107410666502772, 0.12515947673349612, 0.13007296549697078, 0.09465620747857517, 0.09019062734178959, 0.12165689976104807, 0.18290988109525175, 0.13623120924157484, 0.10605807025586406, 0.18136972261051978, 0.1340163111566536, 0.18065814950293113, 0.23462061680132346, 0.13025112690464144, 0.24276011713570167, 0.17047325569775798, 0.15205858575720943, 0.1807380065081581, 0.14515495378403895, 0.1256441116152752, 0.07728964540987246, 0.10424922941432846, 0.08290353771899978, 0.11362576256355933, 0.17710422165691855, 0.15409031221943517, 0.12215979817894199, 0.1519262670509277, 0.1178089397088174, 0.20217290148139003, 0.1476653932683891, 0.13290195966199522, 0.07073547210424178, 0.1981208173017348, 0.1270667292297848, 0.10971540464989601, 0.20016277869862897, 0.09051424586364339, 0.18224914558231833, 0.14791513793170452, 0.23250272076937462, 0.1263441474387242, 0.08998147001670254, 0.20842804002665705, 0.06936674877520531, 0.15852773862500347, 0.12072775768296373, 0.10098507432567497, 0.1681036078521321, 0.09091343129834822, 0.10435236783157434, 0.1282907921760794, 0.17030961931713168, 0.10269076142820621, 0.14948364166963488, 0.09777036255165454, 0.21090700861907777, 0.10008390977858536, 0.12198044933498868, 0.12474021213429591, 0.15871333108553964, 0.0806907770193873, 0.16216480233255895, 0.09102701915488129, 0.1503233199999217, 0.14281095456211798, 0.13726470781670463, 0.16038010858239668, 0.1579329479605921, 0.11137900288186728, 0.16069069594865845, 0.1359575013479879, 0.17267064101273016, 0.12534518410722095, 0.14621391712177187, 0.1391113780799412, 0.11513853340499824, 0.14801287542908423, 0.10850209757805833, 0.12127840636117805, 0.19544078127270748, 0.08834276198139114, 0.16842881217598918, 0.15427028159460715, 0.14064110244714445, 0.07906363691173254, 0.12711659389277621, 0.12817753373735374, 0.12786760520670684, 0.16580753509075413, 0.18397632145112564, 0.15717078240648394, 0.12432372843426083, 0.12746591466448962, 0.17922095323522247, 0.10929812421841968, 0.26729141692480735, 0.1312932056645232, 0.13326176051651278, 0.09358651890990236, 0.19309661351144317, 0.08177926538572197, 0.1744872040205425, 0.2117052875579365, 0.19952536290211065, 0.106415074889458, 0.13889212371601214, 0.1756937158924918, 0.10003862632138115, 0.12782596066714297, 0.09478806653210232, 0.1146139930032434, 0.34534508182156476, 0.10668142833897185, 0.1294214383608872, 0.12552693080637725, 0.17648177521844066, 0.155753611677116, 0.1634875603861386, 0.1440495348745777, 0.1991695763483163, 0.09750852902089396, 0.10696504941029895, 0.25553907658303937, 0.15994115552354246, 0.15725250866624618, 0.19889643535979334, 0.22753620339978128, 0.14351137342952913, 0.13929914623018236, 0.1861204636553603, 0.19829882549182062, 0.12045483885993881, 0.11394945769420556, 0.21656095200488645, 0.17516456364143282, 0.16087449576345184, 0.18029837929193052, 0.18741676103203528, 0.13201656120438732, 0.2431263531287832, 0.10651623679985923, 0.19587535230863481, 0.10672019238794044, 0.11294358424962529, 0.18515715405585306, 0.1281775950243877, 0.17871959465405635, 0.27207272487782663, 0.14894065387066335, 0.17893082041653896, 0.14547044411301613, 0.09665648603150923, 0.09179147531188304, 0.1457099231981462, 0.11814634781330825, 0.11543938379374244, 0.115072519608563, 0.1886779869035367, 0.17272514050766347, 0.11340873751548991, 0.11414533871556483, 0.17813848631997264, 0.15586930627544082, 0.11031694454892028, 0.15625300907319592, 0.14590003557743567, 0.11064860699397903, 0.10562572087491713, 0.12310027835830567, 0.10922510071747726, 0.14794847807816922, 0.14679767612007358, 0.11683129660424688, 0.248312232114615, 0.14346504043186867, 0.09162043086102895], [0.04415671806782485, 0.01642078056090301, 0.014080719030912847, 0.005321186392628138, 0.03510288796537826, 0.047029666527504885, 0.01375710146666895, 0.010196098798675644, 0.027079074568445646, 0.0820263057586647, 0.020241111652144504, 0.06427393415041509, 0.03994409633319705, 0.019066853997027202, 0.006665177530639115, 0.049281459406859456, 0.06391699080385509, 0.023584681330248717, 0.010627537492602583, 0.03539132772974911, 0.03502610297272763, 0.020950181567440593, 0.014262665870539365, 0.029028437002712203, 0.08474505987138518, 0.06472943470843377, 0.03651672238183599, 0.11413869673326132, 0.05710926920836491, 0.04709102250936051, 0.0015722864167577017, 0.06299814111703346, 0.04502507489955714, 0.03399196088374142, 0.025390017319530733, 0.0927509391500104, 0.06846924612839377, 0.04244717754303448, 0.017314167400341363, 0.08987060943317991, 0.06717223628994919, 0.0472554786040658, 0.06593009366864158, 0.04519569034117364, 0.019246660578515262, 0.014747218397866576, 0.021367573081665946, 0.08077785057286102, 0.07156637872779562, 0.04172556868363773, 0.059021409345610495, 0.025047122110282222, 0.014622716661242229, 0.020022763187185894, 0.07414576612533101, 0.029586472683736396, 0.06426275309716022, 0.08273621645545767, 0.011997101603135949, 0.05147761898115278, 0.0065635224511366224, 0.028938142049516884, 0.049460609067952445, 0.04774706956419734, 0.029461811026257854, 0.011300984319419631, 0.039326292387540304, 0.02587194216527766, 0.014924146403979151, 0.035027424474397016, 0.019924874387441144, 0.06554389342425332, 0.05818925782917969, 0.05213700234889985, 0.057212982191554004, 0.046994901457501036, 0.04626406123861671, 0.03871607271233394, 0.05656182660811371, 0.03531675673119965, 0.017221961057774963, 0.013409028460662211, 0.03755623857761103, 0.012736827484332027, 0.04291549475202638, 0.05830993582945197, 0.03979097833977111, 0.06676936597232858, 0.0159916200209409, 0.046910842460009365, 0.040898270334207246, 0.02134704384051504, 0.04149559291920835, 0.03634650147550049, 0.01799603161822644, 0.045116879045963294, 0.0775101638188766, 0.017136992330873208, 0.05405829723684057, 0.051734043931167935, 0.013646855668705559, 0.04213107817415749, 0.01522797400191907, 0.087025604030538, 0.04284169750228044, 0.01584949060117886, 0.035238225058081656, 0.03127550311957396, 0.049190390704860615, 0.0837716302503982, 0.01953948811147242, 0.04139816568743798, 0.014316677942030854, 0.05438168210187747, 0.06569682755657742, 0.0282210013979385, 0.07784490593739095, 0.0459939539582739, 0.009783882208378806, 0.0386574171904114, 0.04073338906070398, 0.03159568382186755, 0.1308049318651038, 0.026835043005825534, 0.03150997965055848, 0.05502366378242451, 0.040904962112225836, 0.0210506405921713, 0.057033771243427074, 0.034902180590096026, 0.020460965479874325, 0.02479858403544753, 0.03186376671487045, 0.056760929029194586, 0.023409235704269622, 0.018398327369903846, 0.04136786307959307, 0.03650186027610495, 0.06096702752514713, 0.005880565121544586, 0.048025780011929815, 0.061364324553118604, 0.006687306937941861, 0.04998359814166062, 0.011090764047337637, 0.03570975983635553, 0.022622386797241146, 0.04383597620612672, 0.10286630281517584, 0.03968727684790089, 0.044457917026574575, 0.033116759056405674, 0.08334183960311836, 0.057029699486109524, 0.013970587188528191, 0.03238432154419922, 0.004914592887695518, 0.009435187713543495, 0.059715814422816045, 0.09894414714747861, 0.052332025351783926, 0.032638616769784884, 0.10879116553452708, 0.052381426531581156, 0.03801958004553472, 0.010384988310115953, 0.03332446464487622, 0.032366575117433266, 0.07611087358166134, 0.017663731404970733, 0.05377263071075563, 0.09180003251399725, 0.06271364287503305, 0.042253483702699025, 0.08631672755244278, 0.032191707887837005, 0.03945951507757268, 0.03841881527595463, 0.048682466750183416, 0.027791118820107756, 0.025717389672213507, 0.02105947933159769, 0.06840033651960474, 0.05524142427490123, 0.053500730784670006, 0.0251006486735517, 0.00752447106342222, 0.01872990746051073, 0.031525730418281696, 0.06847257094998514, 0.05995316761395624, 0.029340150518222686, 0.030346104402034998, 0.024363315859509092, 0.02117499964491975, 0.078049803813619, 0.012246610694414666, 0.01635191500216963, 0.024682228686288003, 0.019054673199031143, 0.04496746891809087, 0.07040606195768041, 0.05935625488599462, 0.024024768199230877, 0.03359088321186362, 0.071732604485606, 0.044857351439854795, 0.08732387270297735, 0.018511654756542657, 0.036776276801021836, 0.01686681993305683, 0.059202072030353936, 0.044958287354318366, 0.03425391698856989, 0.023680928786615693, 0.012230179066048756, 0.017898196444636392, 0.04378122007173877, 0.10977229433915309, 0.021070938091725114, 0.008006129214810509, 0.007450113133076699, 0.03037878762810461, 0.01800023361049112, 0.03593980454869809, 0.05505560964886701, 0.01980279827670705, 0.034525123605084036, 0.01855831717201058, 0.014408776074677948, 0.09224485380635147, 0.010747006031564407, 0.073173156218423, 0.03179074321392804, 0.1289065506669783, 0.06886715219626505, 0.06318744144312317, 0.04492096738108704, 0.015250580298954682, 0.0464754440491238, 0.03815136249026945, 0.039079075814374996, 0.043047112487857385, 0.06083861586727923, 0.019254449777485385, 0.034272594212163845, 0.05093766105992179, 0.06335877317694888, 0.043471310693289966, 0.051344327343207215, 0.056199064823768796, 0.04092408366681587, 0.0437308804342343, 0.05368073463379856, 0.021287629891547467, 0.004482190838203796, 0.024053850812056375, 0.020285360890650944, 0.052266517173378706, 0.04516593165575497, 0.022471986500726595, 0.06535540515136334, 0.025672701848370415, 0.008051563974379772, 0.0229659523334234, 0.03510243980394256, 0.005889731363558601, 0.06815737173441919, 0.013152481894189072, 0.03000350796707696, 0.013433535613359944, 0.11280013428580378, 0.03498703248858933, 0.046244683044572035, 0.028848402510066668, 0.010941308911799664, 0.023295349073446086, 0.03259236038091683, 0.03725154625792657, 0.036858795961785706, 0.050916497881013545, 0.007056424858033538, 0.02785277932191328, 0.029458129973781687, 0.07000129940288682, 0.019490255471018535, 0.06091304513956271, 0.05212488283793773, 0.05816474301560272, 0.06792128641879366, 0.06298223330128579, 0.03435018359713497, 0.021423489839259176, 0.0755395328686122, 0.02193318537226127, 0.06930402915684447, 0.05386615089411217, 0.04979829679453566, 0.058030214145659446, 0.014910156680871884, 0.08422206696723739, 0.054591187996970075, 0.03128048269108179, 0.05921049899752102, 0.05027982902022139, 0.05816253668238079, 0.1021900846652927, 0.039345161133115335, 0.010689468998011323, 0.06636541547073473, 0.02798300852338153, 0.021272940155599388, 0.02143888054565797, 0.10209079967030596, 0.00898192413226371, 0.053223552512786085, 0.04048406957618652, 0.028940183673835093, 0.03168538697214136, 0.04884419940231789, 0.036486032899589314, 0.051284932546437755, 0.032896252138720404, 0.04667658809452288, 0.03532841658940719, 0.045428075452124884, 0.057634215636719624, 0.03159985517061526, 0.07459546739776289, 0.048125608929342804, 0.06168777453562906, 0.04833300808264364, 0.03767163823208502, 0.01839757277329843, 0.05981340253305051, 0.09495157267778151, 0.04009742883124179, 0.038587255027866176, 0.0665673102822996, 0.05016775418733878, 0.08492622434371903, 0.024034673716091824, 0.03305632238005919, 0.048934494355513204, 0.091631286326916, 0.03501841528040748, 0.04078038855485859, 0.05584815825005213, 0.013648765142856827, 0.04740394644379135, 0.03562479302467358, 0.008673383178369654, 0.1159110258243257, 0.13283923238275513, 0.1281006951185484, 0.121770357382634, 0.03763511115985532, 0.11251862761714768, 0.21448425618150543, 0.1212477398615691, 0.1676727293599998, 0.1538582029001367, 0.07948304706763837, 0.1982820481662789, 0.07799574864968177, 0.11764685082579814, 0.24112120991752994, 0.19269404962899225, 0.18352189341620093, 0.11909871767725676, 0.10761571086702809, 0.1360935738850986, 0.06832843916791101, 0.12288985698814354, 0.10609318006543383, 0.0809579655047386, 0.11103843083424915, 0.11820082432560383, 0.1432240444926485, 0.18114778693885575, 0.16478523672107728, 0.15172360615143854, 0.14468927957838582, 0.2283931646736399, 0.11657541557665795, 0.15188911178660008, 0.10460493169845113, 0.13291020276806048, 0.16982134551771227, 0.17199648363936335, 0.1635760282196345, 0.10259232679081541, 0.12636201260911842, 0.17255425693527346, 0.26407853610092596, 0.11825632739571795, 0.12500826629900164, 0.07175996148538205, 0.0921747031351251, 0.2713516216364599, 0.19588338091008126, 0.153938259088224, 0.12076024747183248, 0.1132098610903467, 0.10143334301368845, 0.19825005633456094, 0.18206589735083042, 0.08922399292069097, 0.14884129226688417, 0.10149433127334041, 0.2031427687935291, 0.18831303793816798, 0.17470808249087105, 0.13019937000447704, 0.15765622168058352, 0.20269872891085766, 0.10084949208483582, 0.14563021941050408, 0.10982661763386381, 0.13485047365388564, 0.18439730208727623, 0.126499816504938, 0.17372493121412494, 0.14079847222855016, 0.16129503206860635, 0.15520215094570192, 0.1958993155389063, 0.08512959004409852, 0.15614598659017395, 0.19935927504012663, 0.12971967638980958, 0.07074137864213798, 0.15707221753414602, 0.1362352695075735, 0.12989399203610036, 0.1528688616329624, 0.1379224096214579, 0.19286369213894491, 0.15765763128236418, 0.0993941548550802, 0.09613049006269825, 0.10054878725279724, 0.07288084771003454, 0.10372559299632426, 0.26693025243378454, 0.07916828452218926, 0.13760039222336587, 0.18701315527000736, 0.14173273177396867, 0.0795504704658543, 0.16050073678695387, 0.13287200562415585, 0.14419935102905, 0.14300540299905887, 0.10691413520685128, 0.14471148080643148, 0.14963325864124685, 0.11376970282365238, 0.14523916216867586, 0.08433973041152762, 0.2683101606465155, 0.1570660581872348, 0.09251070163783529, 0.22322911919365007, 0.142960004628666, 0.17482713255430424, 0.18776775187542363, 0.13953943736851215, 0.24606379470036877, 0.10304167566280212, 0.13161266432894816, 0.1635086124822978, 0.10486840465736967, 0.1350912704102455, 0.2719874133265788, 0.16086567043056413, 0.11819392953428531, 0.18688399284597368, 0.22973594826556024, 0.13997177142770062, 0.15610254940486726, 0.2972181207470356, 0.19067287985836306, 0.10205961989178773, 0.0852654787201074, 0.14063483584792386, 0.12033964221876477, 0.12113312544721751, 0.19444825307976818, 0.23196770028481561, 0.1505464048034722, 0.17167730076659113, 0.11441607418800555, 0.20432959220582442, 0.14846506648727004, 0.15971627807424915, 0.1630626267362987, 0.07869573084697609, 0.11455271363018021, 0.15171453567041507, 0.21078895446994614, 0.1448111028801049, 0.128850948005434, 0.13421386991056705, 0.22734394597430385, 0.1865212348920684, 0.11639493292257672, 0.24104955005309275, 0.16482315807332917, 0.09143766526493335, 0.1981389276202648, 0.2660239397758438, 0.14740536770512983, 0.13227278697154216, 0.1706290933033151, 0.1368088395364823, 0.23364483529040891, 0.10839383403259902, 0.21376356662761783, 0.16026326485218542, 0.17851619831015988, 0.09572651657846667, 0.19119119962617276, 0.17469210189677056, 0.16799059456154225, 0.14584395794137833, 0.1834003305843761, 0.12670265360464975], [0.010771640546379552, 0.01688203060879342, 0.023505881526357224, 0.036976325340689196, 0.011334883710069042, 0.050050642326354026, 0.06016982110938238, 0.03948398009543458, 0.032233363918719754, 0.01574963965873805, 0.04304134767622717, 0.03568332980296785, 0.0357322330256143, 0.01860133683939855, 0.03187378331448042, 0.09689412650562103, 0.035557074682606805, 0.05833024865076427, 0.10297219914894912, 0.07362199181150045, 0.05151431842316544, 0.003971643032385938, 0.058628249192430135, 0.01024867828574873, 0.054426360349621505, 0.059681072335449926, 0.05428923827205455, 0.05991354937695208, 0.039884119309605136, 0.04953344870779303, 0.04324891536887135, 0.03253899086567183, 0.08884394436233467, 0.01430810637576806, 0.030595636475951444, 0.012898819648750849, 0.04891295962396169, 0.07418810014402674, 0.043043125000211506, 0.06974151132688408, 0.059686917586312185, 0.045267166344509016, 0.039799095041328864, 0.024580677986265193, 0.09980789596034635, 0.023999094677668427, 0.047962018513991955, 0.03935795863189044, 0.0222890600261669, 0.06158290859011393, 0.03445928983931099, 0.021971231213800853, 0.03572119752906504, 0.04687924899401204, 0.0716043000800475, 0.06632710341364145, 0.025463557929822037, 0.03759782183014097, 0.04980436421089596, 0.059909063932155414, 0.030008338151439547, 0.0522684323931894, 0.024734269038984374, 0.0013375677301683615, 0.03298617553927245, 0.04234561726691262, 0.044934431376356276, 0.018561800956846248, 0.028381452768019615, 0.032060440637231354, 0.05241054170314343, 0.04997727025540606, 0.016204546498615417, 0.03627687174406263, 0.03372390671903568, 0.011407057811025412, 0.022813958574026343, 0.05902632763008437, 0.019616817026549292, 0.003642988918844851, 0.021720753021297917, 0.03812814236528451, 0.047789637239709984, 0.03227164533229605, 0.03175650674459194, 0.031000075358597022, 0.0560587328377991, 0.01082370005127403, 0.03324890539290444, 0.004174366176518942, 0.01579299065915327, 0.05331732167471802, 0.020144230258020184, 0.02262583419290041, 0.01847722485000568, 0.043218942178833875, 0.06703251717431892, 0.08062493942317464, 0.02386979435780837, 0.011219301152103131, 0.02513700337599843, 0.044010234395823175, 0.03471072372649947, 0.04595591003195413, 0.032286404016157316, 0.023775871978291584, 0.002663533776930924, 0.028894026876397194, 0.013961629705473542, 0.009610828691943279, 0.08287710002473286, 0.007510947217533906, 0.01465141718771549, 0.05854975582370835, 0.09007682498063772, 0.04280379530222666, 0.05755235531157064, 0.024620183225300525, 0.05319062988424013, 0.046192623539677555, 0.036167803806282824, 0.08909486114017426, 0.050431591038021355, 0.028464500529451237, 0.05590017945055039, 0.0720217337291087, 0.05299066561424444, 0.03556518755372494, 0.03776272991672158, 0.01448179382996093, 0.04675606971666698, 0.07709599370437284, 0.017318499627553167, 0.04798968960981696, 0.04098643173253344, 0.039856972984008254, 0.07113488736532389, 0.043335858687397935, 0.02935639158221743, 0.03194122586489445, 0.07382838355918085, 0.024419780369968187, 0.059720564167946584, 0.012693439137130495, 0.04168959319471352, 0.05995749984116805, 0.04990331212719602, 0.06557973101735115, 0.03248256465960895, 0.02411428557318305, 0.025327200024959542, 0.0458662394404171, 0.01893525158295468, 0.04718291475587795, 0.0467219251778818, 0.012401339387701405, 0.03745729449175058, 0.01885431439375445, 0.062959112767731, 0.038763183289237564, 0.038618415654186285, 0.02309612982395676, 0.0038289002634795204, 0.06130647725395619, 0.09793082732827434, 0.0336085262167598, 0.011808384461478602, 0.037730630832694234, 0.03196916700671277, 0.05199958149704242, 0.0464654925669874, 0.03217996759039741, 0.030688863630676945, 0.04351401243418936, 0.08986279533635225, 0.041161467501473044, 0.02454743168557123, 0.0945163811106355, 0.008524890440786559, 0.09134302276276773, 0.01629351420448192, 0.03250048345615787, 0.09483216255302392, 0.06975546944886446, 0.047062730882316835, 0.06634374284335683, 0.022327475505129948, 0.016751449006880005, 0.007671476632822306, 0.05936663920780825, 0.027926609130395998, 0.013501069136714984, 0.04290170133894971, 0.03628035361367849, 0.07011068143671559, 0.012308313331056026, 0.02777332642806634, 0.029166800142716498, 0.009864051394434947, 0.07988058541330599, 0.04475481057118985, 0.014089286766736018, 0.034679091956105926, 0.040028323870032065, 0.014169960613212278, 0.02405354437688666, 0.025185360760998823, 0.0075454072887829, 0.02733217852730905, 0.010563451364906806, 0.06650261415709412, 0.08812870169358869, 0.08940234585034271, 0.043599247376644806, 0.07552348332659853, 0.032205807736083385, 0.09447197865454421, 0.04396385160244761, 0.058182769064461036, 0.05373875047230432, 0.042225755150279695, 0.03876025683336681, 0.06075747949521869, 0.07561952010878632, 0.025925740689760255, 0.007661623784506153, 0.061855601417201186, 0.02633510168731934, 0.037979379581708106, 0.012837554639836234, 0.012243459200216158, 0.014846770566016918, 0.013255380908958616, 0.01784175874725465, 0.033135961050227765, 0.04994984813815644, 0.05325947820599522, 0.059716285566889474, 0.017559476414575212, 0.01359913988234175, 0.03295485786492786, 0.021878373696498817, 0.07445859812921093, 0.060946427420863224, 0.05273620567975506, 0.04102315415718383, 0.060344944978433276, 0.06913421810754845, 0.036195122501662666, 0.038423829321419044, 0.010167053532636455, 0.049153622314934774, 0.055710496080498544, 0.05612979132321574, 0.014221225301885318, 0.07824281200526223, 0.021912418643853838, 0.054153954805505854, 0.04329945801967575, 0.03807968347363415, 0.007839218287112853, 0.03847927110449922, 0.006504387166651507, 0.03411621268418047, 0.015862014223521036, 0.07818818227538178, 0.02758712875806997, 0.1064562904197843, 0.09460613597184421, 0.05841272950713193, 0.05314056986882802, 0.01696260390622962, 0.09626120764521823, 0.03421945069285651, 0.05743563415542726, 0.03209581857757463, 0.00660763523023155, 0.01854951099132098, 0.03123201230811256, 0.056891171637201504, 0.014178180736639808, 0.04828346900702004, 0.013817908738048808, 0.04536776134984628, 0.10878196481855647, 0.062470241419730656, 0.09535524738772262, 0.010239214227054148, 0.025555224180401816, 0.059701174482583046, 0.032310321281153354, 0.06589021113130354, 0.016422155688727097, 0.027536892542435278, 0.06381091060897996, 0.025260891284673445, 0.05927400385600425, 0.011385346879251303, 0.030796069974800756, 0.031383781986791766, 0.038034281272801666, 0.01758134822481342, 0.044195068429314324, 0.043154483540884914, 0.05317754510249342, 0.011497792307167284, 0.0754144843367319, 0.01449629970480718, 0.04120667818032446, 0.00810226463081856, 0.0776637414650571, 0.021396713151085763, 0.05017620413714359, 0.03704869383645635, 0.02239718567579985, 0.04398591876510651, 0.022921030852763404, 0.09468206294601965, 0.058667036224036455, 0.05409475153071746, 0.0352276913491228, 0.06003639923648969, 0.04884954669602937, 0.03519748833270804, 0.02381115415764432, 0.022606546014186837, 0.06407535266912272, 0.047243014353537754, 0.036355254030035394, 0.06474346177832735, 0.04682878295200006, 0.02577607009199358, 0.05011007925795932, 0.011900960441468465, 0.09215974909884316, 0.030993226532553955, 0.04101327162296061, 0.017751059682679274, 0.017738654803965363, 0.07298219348153762, 0.06301263933100047, 0.037318942843065146, 0.04182869944000437, 0.05327263959653435, 0.03695816522644412, 0.016250061697416728, 0.05720477738988496, 0.06831981301788362, 0.027571305211993958, 0.015325273871572028, 0.041613478528996634, 0.025486573126287233, 0.1416141873285655, 0.09614094716286468, 0.08531542765277048, 0.1527673856265122, 0.18680330846578846, 0.12541917287894797, 0.19511436652993003, 0.24317348285788493, 0.05464887824810801, 0.12537987256843236, 0.14739202245348884, 0.12011181533096299, 0.0936520500709453, 0.20492092015281801, 0.1257580288896157, 0.12153725214903394, 0.1127563447000519, 0.21531890897500902, 0.19637998974611684, 0.1274909887222513, 0.12228779614933076, 0.15300258994102478, 0.11829425640884908, 0.14134630170320311, 0.12759055716977005, 0.221425028097245, 0.13591263923914204, 0.22316035514156665, 0.10838702351095215, 0.11883101591299619, 0.0722760749199698, 0.13419450320784124, 0.16523128375411034, 0.07962321817514398, 0.11801654187541817, 0.19862075095936177, 0.25621413794015685, 0.28295160241184697, 0.19839860078307892, 0.1336731497318514, 0.16408789752712175, 0.2547883717042785, 0.12987805740727534, 0.1044808254547177, 0.15267855007081263, 0.14750456076956567, 0.1635621773499635, 0.0976651020708584, 0.1748621887377193, 0.11014886485833315, 0.22816416567131398, 0.13079157129170435, 0.12024520656033871, 0.08377161492863971, 0.10114323317764268, 0.14506072496935246, 0.05719167728637976, 0.17834441075401922, 0.19680712972917866, 0.13722934519811986, 0.1522625030408944, 0.13871822175720047, 0.10681175521665043, 0.12450897615523109, 0.12829133609850563, 0.1381919959620122, 0.15883533824836055, 0.16648454231119927, 0.12135330677753496, 0.1352958924948208, 0.17220194842065537, 0.1391617713436004, 0.12721054691580996, 0.16458737153199413, 0.10060931585969464, 0.14251467771828175, 0.16208929670674188, 0.1892370931924351, 0.0995304265750512, 0.17782534022004376, 0.1327495234868219, 0.19694844230769143, 0.10660516428610972, 0.13514604569683153, 0.16517679958093553, 0.13078741909515473, 0.18616653618312654, 0.10741767713860159, 0.10165630524317104, 0.12269789067607735, 0.10854568798094989, 0.1659231837238035, 0.17632178541633392, 0.10575691343195016, 0.17256846020538963, 0.2679006100421952, 0.1693034241156232, 0.21582811229651977, 0.12650719393164883, 0.11811478499082789, 0.07563426730132873, 0.10410315176892666, 0.10545580257331172, 0.11332603066318458, 0.0690545449634233, 0.07226168778875182, 0.15679687021240113, 0.11044195477640438, 0.1385499582055115, 0.17775956391086503, 0.2036859864188779, 0.14684007142580327, 0.10191712753787156, 0.1529412569418069, 0.3274840483021352, 0.24499646568250275, 0.14952680306328883, 0.09366840604812869, 0.1777802636065791, 0.1422432221231922, 0.10845427836982474, 0.12910090717336825, 0.07867539887346568, 0.1377095903960928, 0.20267361654869973, 0.11371491221530784, 0.15404194142789612, 0.11421306854895047, 0.12693511532439342, 0.18928572445386843, 0.13594931952895659, 0.13070967649259876, 0.07807532220237678, 0.11191036146614822, 0.13294433964596641, 0.11702041306923475, 0.14791702250799826, 0.13464589753458578, 0.09361230542943363, 0.08454575443700438, 0.20387821320083835, 0.16442820910484562, 0.14521237973484302, 0.18432129084342913, 0.17268551844021968, 0.20382984240929927, 0.1971073442649457, 0.10419361143102569, 0.15081720156294687, 0.10983722029073585, 0.14900667532797784, 0.21812855175906615, 0.08601698033030956, 0.17712127477411302, 0.10955526163020443, 0.0730204748951139, 0.12409032442637029, 0.10995431682996212, 0.11763263223392349, 0.1632099760876548, 0.14435460640778466, 0.10733508519948491, 0.0856668781489134, 0.17150785743949876, 0.1632032804791966, 0.14611988748994567, 0.10937297100862188, 0.17938662740972736, 0.09064461870659744, 0.1476391164525863, 0.19936227810478982, 0.1575922380171476, 0.26287850533281604, 0.1536775900111083, 0.19424946858517586, 0.10364801127223239], [0.0735240321486227, 0.016470114708006862, 0.026517633626598026, 0.021163217212644317, 0.049099521185722084, 0.02884662901652196, 0.07527482650813556, 0.014777766153847259, 0.03554105195367048, 0.036783144779263005, 0.008605987550840985, 0.029010629288912303, 0.053257528512227925, 0.060112261093191566, 0.04041405680078653, 0.048234588767011324, 0.028737189526098873, 0.052603683960173404, 0.029209844707962007, 0.09229333185019994, 0.008738420212701445, 0.02924151095231214, 0.06237670591461563, 0.05831918634113766, 0.03058234485046518, 0.0787508202296111, 0.015471445362744553, 0.02297097212454725, 0.03804228306117077, 0.047192992642521865, 0.013461660616280091, 0.03730519922570356, 0.04843628056527627, 0.10104660650775318, 0.022711731801410357, 0.03827199069482665, 0.052518939313989495, 0.023086528827045715, 0.036103134494154684, 0.05692572220258656, 0.06183297117991794, 0.040028913757733764, 0.004468774244624881, 0.051883668563659155, 0.030892110587428176, 0.02478575014749602, 0.03802043806400992, 0.027988355817093004, 0.01931403992667554, 0.04208763715841117, 0.12026936897347051, 0.010932672228063307, 0.05120051348762167, 0.03161458129573974, 0.0810969568368408, 0.03213677555322647, 0.035684570865405184, 0.051822576882137414, 0.10316052654337499, 0.12388698936950777, 0.11395118905291443, 0.012283752552203596, 0.0328687610735576, 0.04788223811755738, 0.010290425289572488, 0.07809403006948772, 0.06715699880113525, 0.011983362773823883, 0.040679127053027196, 0.025806805539515712, 0.012006970730820491, 0.05610738325143053, 0.02474757981666875, 0.05517776236839353, 0.04811063191042312, 0.06501114822082943, 0.07545655788553339, 0.03879486102490656, 0.02458231166876372, 0.03976483941979466, 0.0754829419536456, 0.01813429133636096, 0.025290749561522278, 0.00398979835858148, 0.03478303093523268, 0.13376019264180816, 0.04208868669886743, 0.02133183316477845, 0.04452981054782868, 0.05027097687425633, 0.05195428271807971, 0.02164870053679953, 0.10881251640497677, 0.053803910080704, 0.02353282292343436, 0.01916383115214206, 0.05107075351500704, 0.04564933696641557, 0.06844190445037619, 0.010352134629483185, 0.03334237961098552, 0.056426941507285645, 0.02014626996711858, 0.05052311939277476, 0.04092260894756164, 0.029014950024805246, 0.04632689960060581, 0.05384076657074113, 0.11988967281555939, 0.0454828086038751, 0.013514794559488374, 0.048201080081203294, 0.03205371438525617, 0.052492785072254564, 0.05239731519513073, 0.04858296342013825, 0.053933961166729855, 0.025401253914160114, 0.03739138028674549, 0.05250274804570983, 0.030350710505679734, 0.024877198063017383, 0.04274934943344805, 0.03584901163835199, 0.03213463816791773, 0.04001309021165775, 0.007957887700608662, 0.03775178635072324, 0.07932236778639978, 0.01111736549289837, 0.04870177599631491, 0.03639959902953237, 0.06044413421242949, 0.06632072956211145, 0.02512001537627751, 0.04433881333698669, 0.03649338351322278, 0.04581804484910062, 0.049815143067990585, 0.046388910587636695, 0.06138876275790315, 0.045045268977241176, 0.016513714686997475, 0.10300064399357765, 0.02378264228032241, 0.05419165016182008, 0.03406612968613063, 0.03234298343980505, 0.043081988640610254, 0.020004223859418305, 0.020418393973922058, 0.029281811007568916, 0.029136328995528243, 0.03697021195905344, 0.05858499203778564, 0.0773780825998514, 0.005817200074107537, 0.03548924908823064, 0.07416917777229702, 0.045758657713210395, 0.04774274882830439, 0.043997318153419805, 0.03979036929987131, 0.04939165349388796, 0.025317081918699608, 0.04144494301609455, 0.0732967721658849, 0.04054953945019553, 0.034246321226800644, 0.01853504725131056, 0.08332649486199503, 0.037421717368547, 0.042678616535399234, 0.09318907249478564, 0.014837953851618355, 0.0536196391218372, 0.015098725392993902, 0.03454314199306312, 0.02868446735514989, 0.028897774961566734, 0.021908216651589162, 0.033754228479078704, 0.06725935580869837, 0.016927733499136184, 0.044776778142418594, 0.02482884642367642, 0.04908692670024691, 0.052507819547768564, 0.03885283089813687, 0.05686982459719143, 0.023821007963570378, 0.019091631195718245, 0.011718619066560942, 0.03622438706037018, 0.08214630577112399, 0.05346759365150525, 0.014607251261270817, 0.07403810012845263, 0.019611983011747082, 0.02589040679947263, 0.03790495030942463, 0.00630528761840035, 0.026883252918900504, 0.039051837558227206, 0.03822944217151211, 0.004485193424062023, 0.03180550572822892, 0.027236792919856888, 0.05510176261586528, 0.05767038647806453, 0.022944203097253077, 0.01390848331333649, 0.04934442417335607, 0.01012392565532918, 0.008389649109073706, 0.04107055201705906, 0.04433520889330295, 0.05653053957728609, 0.05682707689101658, 0.03248711139143955, 0.10433429581744057, 0.026366361905069604, 0.0419406172248625, 0.06954282642372193, 0.024039358343748797, 0.020800461173958836, 0.061393998968865604, 0.031983552222710945, 0.034405885850109404, 0.02182540446219425, 0.02164288401423443, 0.039029992561066346, 0.06950092907514303, 0.05921537514715906, 0.025858397730776382, 0.00768850485215925, 0.11835715988831175, 0.010404740929633621, 0.0348120809893214, 0.08646981490235175, 0.04645547979781705, 0.07286510460319058, 0.047918929898690794, 0.05024719367464704, 0.04121520856936132, 0.03662598567203649, 0.02501712593760702, 0.04035982160618709, 0.04334668350976802, 0.009272245600098565, 0.021424060574762767, 0.03586051061809544, 0.026584405850078312, 0.019908482021081354, 0.0315258395858109, 0.07646536544686364, 0.019216878910458857, 0.028812693236696146, 0.054945856062394965, 0.06203454806499424, 0.04792618092089411, 0.0546475146116028, 0.08130301916671377, 0.0943994760933903, 0.02673514514049936, 0.06772174349715633, 0.021964713720785036, 0.01710111643337915, 0.03674251530619879, 0.009083104237253148, 0.05828357091353786, 0.02305089616246762, 0.03637922492118613, 0.0734946603376058, 0.040377702098339796, 0.046505727504770604, 0.03446670557041803, 0.04257490738264976, 0.06603246599796318, 0.005310479835081365, 0.05958691629911623, 0.014150795966176497, 0.03563158056368271, 0.027269284623945435, 0.04345189036440946, 0.02303650903124963, 0.04042782340078585, 0.0646890465530657, 0.016284411164721655, 0.02604232395007726, 0.07311628185092442, 0.01810156789067532, 0.05162041777023866, 0.05834147183885498, 0.06722443752110967, 0.051930622092538306, 0.03703379342632909, 0.057763247825806184, 0.06996713188146392, 0.03266938669126361, 0.018083714211599964, 0.0518361404688368, 0.030101032875057672, 0.03804793295961234, 0.034070013751906734, 0.003973763659521337, 0.02177038977313186, 0.02683285007914228, 0.017251717827973828, 0.07602799819001267, 0.04224722476435765, 0.056857770203702876, 0.03072894918131492, 0.03065626275905919, 0.045572433230136676, 0.07259374093865195, 0.006942334735105115, 0.04073183390221769, 0.00821411538298332, 0.044628157085108186, 0.06504990460891878, 0.07401848827759105, 0.0546975554748168, 0.03482281771158019, 0.03616567791229294, 0.042760802447916045, 0.07233258922614398, 0.059617525342130856, 0.06227459405518829, 0.10909436015231956, 0.03217774210497737, 0.029483349588249, 0.01135479050478147, 0.05708837416023017, 0.03498992447050349, 0.011376871073979044, 0.11145541249143501, 0.06399410138387354, 0.05716465353485077, 0.0954572749774783, 0.03140113579349653, 0.04833538295520891, 0.0658310691435491, 0.06172543541798669, 0.03315684077660403, 0.012338604447582077, 0.009475739620205377, 0.025937096028017904, 0.044294181054518114, 0.06336846801963064, 0.040649896968276276, 0.041300792081822316, 0.15248626200181825, 0.14579636855952202, 0.062052037852305564, 0.09984962476958191, 0.12936027390101265, 0.0917013374067122, 0.16415808650274433, 0.10345895609427845, 0.1445159751681551, 0.16540596712260477, 0.14475142463080345, 0.14104768063031858, 0.16925695322213635, 0.17859299096368975, 0.15576642066720994, 0.11870053581773274, 0.09234791561480492, 0.10471350167908015, 0.17200261234275757, 0.13180133646293996, 0.11480950630239903, 0.17233461952738224, 0.09489552568524115, 0.1600035916893713, 0.137355872279694, 0.12946568759939364, 0.14424364623283187, 0.07595495170643253, 0.12272049026984362, 0.14326348269899047, 0.14255776250314328, 0.09580320964056639, 0.1059508715726195, 0.14409822742304496, 0.08652044565326746, 0.10114081233980195, 0.24763194603785393, 0.1297448960042769, 0.13150653050791833, 0.08159764126063355, 0.12653321793843664, 0.2003759043591638, 0.07570369018902702, 0.11474204459978689, 0.21650960879220119, 0.13609029502878267, 0.11354899289266718, 0.1807278941475576, 0.24331936132042642, 0.19295471870610792, 0.21122524154282388, 0.12888606547588302, 0.16538840838738028, 0.09550514781186659, 0.08668121686505695, 0.06537198329404478, 0.10541450277331377, 0.2007074672127924, 0.2354230479367318, 0.14612126644820939, 0.2129795369241507, 0.16322895974641846, 0.11629539511857495, 0.24011965720884262, 0.20892196755495765, 0.14267334984915872, 0.14226546931651332, 0.1313597480616262, 0.06527443731864614, 0.10664383640452739, 0.11578323469767648, 0.1352462653190859, 0.15484420402396112, 0.11461355633312657, 0.12021553597503132, 0.1432666389812385, 0.1821964693766448, 0.1384823432853145, 0.11940608747423657, 0.1336960710825459, 0.3114988576740988, 0.0753147779933868, 0.18222780237274785, 0.11799953472349914, 0.13992272647878817, 0.24560910619554982, 0.19558537270753615, 0.17909863963723185, 0.1633120956079614, 0.12625436193399853, 0.14634223684908884, 0.10517099406570198, 0.16437427651497627, 0.16246782075012886, 0.18367554001029462, 0.11821512718715015, 0.17253916500316513, 0.1693560390342628, 0.15296132844542304, 0.1401253260912434, 0.08948169723753968, 0.15910064981829736, 0.13439212324878863, 0.10684678841742778, 0.1933442131285706, 0.12638615970049175, 0.12366302356484438, 0.13872603585402812, 0.23586322673626486, 0.11663017554148553, 0.09792954030056154, 0.2522526206749101, 0.10773123692600958, 0.1930236359757762, 0.23120944177912128, 0.108991420917934, 0.16237058887077918, 0.18570443194720054, 0.1959687537483631, 0.21635646781613752, 0.14176950399433413, 0.11895527537431448, 0.10970942916408663, 0.1411804283458379, 0.13333421711239124, 0.16027186035869584, 0.10394575900488323, 0.1020705289838295, 0.13613059125359983, 0.0414339802978981, 0.14958940776846102, 0.09476581167790199, 0.17552281699834332, 0.16479205490360338, 0.13168869089455376, 0.1304970104848185, 0.19318123558355918, 0.16339480246026672, 0.2552980193567853, 0.24648200209823348, 0.18287834891628835, 0.1329022967406819, 0.09365931258446748, 0.1411518992315377, 0.11251241464408175, 0.17745495203041262, 0.1846790385823096, 0.07503388419507012, 0.18818431984513037, 0.13341024367799684, 0.15428825401731078, 0.21274641636879216, 0.11986893481544911, 0.1996467725163506, 0.1723592569150271, 0.17862092252940903, 0.0824150877193578, 0.12943944142710778, 0.1334798044615215, 0.15912013909509107, 0.190669217958085, 0.19673018385806393, 0.14640024502671536, 0.2865598152481741, 0.14142333950486877, 0.21083046111368367, 0.15902102263944765, 0.12461736993563753, 0.12882462522435573, 0.1031612236833861, 0.16676785694735666, 0.12490693584925706, 0.17623051370103515, 0.18594407957167397, 0.12188922358496536, 0.11016437813879983], [0.05812222513580515, 0.0012104103018740014, 0.06915964456575532, 0.05604029310146167, 0.019251686115298542, 0.036854161129843806, 0.02360053743506151, 0.006345237188431765, 0.017017404090673212, 0.04244668341632332, 0.03811812193523492, 0.011018096777280013, 0.019486566757663124, 0.04736067013694875, 0.06824138093619578, 0.007841090893282766, 0.08342508271697067, 0.03695250383668369, 0.012938626534906367, 0.006047233773936188, 0.020385392821363865, 0.010603018848585987, 0.03128102086784859, 0.0064150177434297104, 0.06446897247505766, 0.05070708008603223, 0.06248159101232887, 0.008685060273555499, 0.08789217970784634, 0.06404880006166716, 0.04053737397395796, 0.04585637605839199, 0.051966616733660626, 0.043863045922931165, 0.04512585759643586, 0.02297750493932155, 0.03953784756783036, 0.02891237851262333, 0.07940148934721947, 0.13598128071715757, 0.04753075314745788, 0.06612854874542644, 0.0711746932938695, 0.02443192286356803, 0.011443238228469366, 0.056877205854341875, 0.047878518760685, 0.03390600964907677, 0.042655492171404824, 0.04015407720280271, 0.037118683629218614, 0.06362769302100905, 0.020400839069137172, 0.06157440501415442, 0.009706283247308626, 0.049223447398793314, 0.03364242560740921, 0.008862682546849453, 0.08584243485764151, 0.04462537235550342, 0.03399357732926165, 0.010555042592327922, 0.03028099075891078, 0.02580304979346693, 0.019394143995258118, 0.037151184909406214, 0.1115506065769061, 0.045075644363438895, 0.04399070681463327, 0.03726717062114227, 0.019110921289651625, 0.03175759841988404, 0.04571259667676303, 0.021106812073999358, 0.020386727729571924, 0.10943698531557476, 0.04193525843983216, 0.02835584627915054, 0.06417935293528342, 0.07057312275132827, 0.01963686554752771, 0.042659743959384586, 0.03582023354547639, 0.026119446021414576, 0.02815142529265535, 0.01587476096897116, 0.006344042570074841, 0.055412656417296785, 0.12034799257713942, 0.03808613776439621, 0.06609180716857796, 0.03007357245341184, 0.04982509838056661, 0.0566173066955901, 0.05191848342937808, 0.06087217051836272, 0.048011867855224884, 0.012150378559806175, 0.05277370185320897, 0.046746271452115434, 0.034942752606565916, 0.05574344169168223, 0.07424413947568786, 0.04119158241777651, 0.08350217414479102, 0.033959287233770855, 0.018018169644018336, 0.05933472398488272, 0.03632028977717123, 0.0558086013000819, 0.07092716262465523, 0.04568136327209012, 0.09369817622486623, 0.03180826172953652, 0.012659964925279061, 0.0498597638591403, 0.023231882519359072, 0.016997765426734285, 0.015734089989094965, 0.05165908222777709, 0.04400401759231764, 0.0664286253853671, 0.03900849613391104, 0.017829472612169002, 0.023758617763016975, 0.025027927777339375, 0.04197280440900115, 0.008812853315424536, 0.11196603307560568, 0.03182054594940236, 0.007678353229552628, 0.04647430257811662, 0.05246702536580063, 0.028329142369329933, 0.06461784634138308, 0.03428944048561877, 0.041773322774397756, 0.06554687350627876, 0.07742204072494661, 0.025007116998876297, 0.04747942525653109, 0.03344433442238839, 0.03142954233372885, 0.049034396051279, 0.011823681322106672, 0.05166420352555091, 0.013378900137820072, 0.05606370474842768, 0.01730623839032506, 0.035925260369455626, 0.011916874002875581, 0.00599992640819701, 0.06198101384084552, 0.06790284668245623, 0.05633850814774633, 0.02163802127113506, 0.08599776684516862, 0.04792579787693197, 0.07316801576845108, 0.05237197300659553, 0.035580064981214465, 0.07005638878552184, 0.023181992958510117, 0.09491142200966997, 0.04386191977368247, 0.029899770086030328, 0.028909208823836623, 0.012506301094207072, 0.051222343163024035, 0.05474516017843158, 0.015106008016324092, 0.011678494253916847, 0.01642596697615039, 0.0164211367917878, 0.046829614157397906, 0.031004269689982458, 0.05549300754923494, 0.02926814399899975, 0.07555319987718137, 0.04108855508327965, 0.0478590103316932, 0.07875153269138067, 0.021492418600246314, 0.028447093096591776, 0.03809859435404501, 0.11220144423385782, 0.018243723165904804, 0.03558863367464754, 0.06941030087370066, 0.022810246878033204, 0.05092476013927691, 0.010099899222803934, 0.06411748367451853, 0.012754163096448588, 0.0575118828865309, 0.01827665154011019, 0.03754003198757287, 0.050265962828791914, 0.02992387121212819, 0.06645005286460923, 0.02500680481804715, 0.08257515413025696, 0.026458997256873597, 0.023101117056343826, 0.03430754314326952, 0.017169417002268376, 0.036075402111295736, 0.027792078345232916, 0.060639138063115466, 0.04185774183321384, 0.06997835506955463, 0.007698772824369372, 0.016099487115899404, 0.010563026186108831, 0.010461924605131631, 0.08557405893600757, 0.02879506363833864, 0.07826427778890056, 0.009728657802747143, 0.033006396430033835, 0.031773058074196024, 0.0365155617586307, 0.04269603737479737, 0.07930863182991743, 0.0430274470108411, 0.03502453249248286, 0.025966031168917977, 0.0076691788478544165, 0.04754684482430739, 0.02847529662352416, 0.06102106736732587, 0.05719038642822735, 0.06772725933021115, 0.1433789627926965, 0.04877734290916593, 0.02870427264321235, 0.034432419305366856, 0.02469978167585308, 0.12698859592238743, 0.012374510030983197, 0.05918757381638693, 0.035228151001877366, 0.08132465348969545, 0.013515125892515625, 0.09675948655292874, 0.019550040972629384, 0.05742889258169359, 0.027724863705976356, 0.05598657501621112, 0.0402105417132618, 0.09579410851602593, 0.016740172192634597, 0.027372553276138443, 0.05670645634733862, 0.02950658886543205, 0.02229211288654516, 0.06981293370406474, 0.026429361145522808, 0.030545409836415804, 0.09327698874497607, 0.034080309973609064, 0.036783546975423256, 0.046857836836528395, 0.03346956169773494, 0.03289812139325565, 0.06669526994829217, 0.03932839912933208, 0.02458146897204701, 0.029711486741660104, 0.04741429629164839, 0.0575386576594845, 0.01173225255878342, 0.029604276567096674, 0.025775681302372008, 0.01733549337293352, 0.036170806870946, 0.0618567313968895, 0.0737489479023122, 0.057690814212565465, 0.02736689188637801, 0.03702408709232846, 0.053870827860889904, 0.029053553195309736, 0.03082293859352508, 0.047436175762765834, 0.05108301092179553, 0.029311414560182925, 0.05249334814687891, 0.06585303288433822, 0.054865206156166337, 0.03723397986182282, 0.027796084985076904, 0.06035121157765389, 0.004150394327758301, 0.013954323141895717, 0.029735032454012867, 0.07614511771187668, 0.10294098106603469, 0.034982340200053114, 0.04525109765029723, 0.006462949470827177, 0.05889372547127067, 0.022617734728320953, 0.004740870001936151, 0.05013420336669491, 0.020982849471751722, 0.06359915241538998, 0.038069674534903425, 0.04837516207067717, 0.06674034656175683, 0.015916004269984702, 0.05083767509448433, 0.050568988907241055, 0.03328940846146115, 0.008132633313746944, 0.06821822209824478, 0.047171749024381565, 0.08578806559765532, 0.03061296921523829, 0.038520689648125446, 0.08365546833843955, 0.01218757691657952, 0.0038535723644834495, 0.04731390813005067, 0.019139707043406465, 0.014240959726814783, 0.005406352387170398, 0.042201313115055525, 0.038561204208001014, 0.024679558869871884, 0.0668836433079935, 0.0406394858333853, 0.04263898297663658, 0.020340860130325444, 0.03932890091692248, 0.031642807805309855, 0.012657642721258586, 0.024726625396719864, 0.05432320661061714, 0.049930875970711636, 0.05729611039221768, 0.03035321369797232, 0.03722834911557936, 0.05851082706583604, 0.04120066822055848, 0.020164742262192795, 0.02230128870465823, 0.026034358550884554, 0.05030118372111071, 0.08591999359909566, 0.06660422805937068, 0.027466100272572333, 0.10585236032643627, 0.13169538650301196, 0.15423101192760855, 0.22446173934205887, 0.10893041733652355, 0.21661948112230148, 0.1213281331283431, 0.0985495275968025, 0.16061531289690928, 0.22457237776008346, 0.14215757349325767, 0.09175477203943076, 0.1918853212508463, 0.12759943612881247, 0.1538314511098208, 0.13859770080495265, 0.13388699551503505, 0.15360698734800662, 0.08921654654606696, 0.13085255189047706, 0.10281958677355321, 0.182122802361846, 0.07413732383640544, 0.18097868069045006, 0.20889428113737415, 0.11165107900817549, 0.17567603458319941, 0.10760791209195891, 0.1168732169354635, 0.12743231404813068, 0.1159003235760235, 0.1464036158135822, 0.15197560311325137, 0.19647081713041953, 0.1372625014834827, 0.09876883558688626, 0.1249004470845384, 0.07910741117572592, 0.10945740921963608, 0.16221570121424814, 0.15927243737443803, 0.1292812289489854, 0.16701435339787316, 0.1264397705334329, 0.09408747912534783, 0.10972859668395213, 0.16894776013589677, 0.19795060788671817, 0.11568072447252851, 0.17684257198725978, 0.12050130209254643, 0.13137494724604393, 0.11632384762408272, 0.1474129672973387, 0.14050119947041237, 0.14553476485513872, 0.11992810744672053, 0.18552342069245156, 0.16438886282905457, 0.10466207419672321, 0.08081885925944775, 0.10834090501791048, 0.22396583530691364, 0.14840575596017225, 0.11447215948494212, 0.1297847325763395, 0.23252242455078712, 0.17205295964114128, 0.18711167417706984, 0.1546637443525176, 0.19549085277943842, 0.14570220103186948, 0.3848008162552311, 0.13367386985450022, 0.1835648403052361, 0.10665363466907894, 0.07806106530610593, 0.1947556075549895, 0.15848551185861712, 0.09523284185918109, 0.1885533290764978, 0.10018107271002186, 0.12568997729930187, 0.12033206560919363, 0.16110968475620593, 0.08286974558065976, 0.10724503156398574, 0.1219277807901944, 0.21649955771863463, 0.1523813232779503, 0.19957710448051655, 0.16532083943245873, 0.15522406106033634, 0.1880818785678956, 0.14118142426013947, 0.12954251089644048, 0.10186604479508055, 0.07891533761135033, 0.19240949393039752, 0.24654909607864198, 0.15028302377510458, 0.25073671653386087, 0.1376143043800708, 0.08637485064325795, 0.23647085703428716, 0.20074701267144374, 0.13633627053951064, 0.07553483674963636, 0.27969223537272025, 0.1660018762753856, 0.10625820306520309, 0.18893159264999052, 0.2117000628382929, 0.10748916846369544, 0.12010617692384029, 0.21445561981489583, 0.16302784634453638, 0.16203606891776287, 0.11720549225086167, 0.16143933239002384, 0.1425930791564526, 0.2593705274405018, 0.1763210499719266, 0.07676445383338198, 0.0977929238410246, 0.11769941211828303, 0.1104939874682215, 0.07747247995388123, 0.16590193244478396, 0.0946365956277136, 0.08567453136727696, 0.17639153006096042, 0.10733176803877277, 0.11208982522329015, 0.12705864700218364, 0.16724699897871864, 0.14054485116033785, 0.1849872817195231, 0.11804630439127646, 0.14482830921488424, 0.06892744331590592, 0.1738791293915241, 0.13258024869907287, 0.19289455016053494, 0.13738757299800075, 0.21838223411431237, 0.06313437453260826, 0.2819961375526844, 0.11002627546868979, 0.1553727587264392, 0.0571171943879416, 0.1966849387052559, 0.1610359717761317, 0.1734324848099101, 0.11203135739290908, 0.19532586808406538, 0.18137390545058638, 0.1289389102208999, 0.14415223662170673, 0.1372757088392973, 0.12496789346539205, 0.22755952311619637, 0.18810100012248565, 0.21078022106760935, 0.15873609921864926, 0.09078005539073099, 0.10470668349655406, 0.08973452157431072, 0.1794547173044374, 0.1597536018779201, 0.05330288474778495, 0.11618130930489111, 0.17165758166342013, 0.19867166516280946, 0.22808959467276452, 0.12560101916953442], [0.04857077496126295, 0.04486246124630974, 0.013175501878703795, 0.012400557978018638, 0.017899328339544517, 0.023564985209715464, 0.031844099322634364, 0.08180992422445167, 0.010800525891564546, 0.02205152297392488, 0.08416536113908214, 0.045323757259475614, 0.03954918183867009, 0.032182311819445704, 0.035200261570993936, 0.02870522067701865, 0.06751339822526901, 0.06194342190640108, 0.020217316961216352, 0.023285782550491636, 0.031789036753076705, 0.03488542624719201, 0.014360827589107138, 0.010657575800113622, 0.014181140708857247, 0.07626297267814798, 0.041967384336936864, 0.07073445320730248, 0.04282351440539764, 0.05807548994198442, 0.021040235202939763, 0.05034156038515991, 0.037381287078343095, 0.0660888270865525, 0.014911108545117803, 0.03574561275121185, 0.008963435557821106, 0.05716982079790004, 0.023491486734259995, 0.06828282629289935, 0.024717501289541685, 0.0456937624051446, 0.0154589791969967, 0.0022546286016867888, 0.028416740693031784, 0.02395966030176609, 0.05476680216229251, 0.040482548891656825, 0.020421598136665362, 0.051238113082945354, 0.032275640480821176, 0.034824422665781556, 0.05953763769338689, 0.038100111208135085, 0.021001082364349596, 0.02676735722249554, 0.03990753861745039, 0.017387537556069515, 0.044063711163377574, 0.04163805079916793, 0.033950599796709516, 0.08755121695538683, 0.06391577272405548, 0.042774657148026654, 0.039023005839196906, 0.031211787586911555, 0.006806438398217002, 0.04844804384535359, 0.02380702685895226, 0.04942805033117052, 0.042318413484721415, 0.027324111621466377, 0.07287880991615596, 0.05103115443020098, 0.02328437486393077, 0.05235891120748655, 0.04025328941943665, 0.011003756568947387, 0.01662426308969096, 0.04484364995732904, 0.02180740139597366, 0.029752784626438256, 0.08535744757541726, 0.05073229970049955, 0.025472925269916177, 0.05682775870926919, 0.040596362744127555, 0.030276254420318914, 0.019406039425502383, 0.01971178511608272, 0.0451401834406199, 0.04765700826781893, 0.09380817112903442, 0.004737466177527583, 0.07716009228099739, 0.02233256232894717, 0.04456337669023103, 0.031319361653239015, 0.021416476304312388, 0.02372358839267925, 0.035933503475520885, 0.04328071950904785, 0.10495727085658621, 0.029137106574771386, 0.05734188797613306, 0.021535097358507976, 0.0747742799801692, 0.09072209317837993, 0.03369794016884219, 0.017650596827508944, 0.033350894678263895, 0.009480786224406575, 0.049034491812269536, 0.06482493522907458, 0.036483512470318426, 0.026846193415563435, 0.011440919854888513, 0.03468078117997896, 0.014014486899419178, 0.057516797340565154, 0.04854549789020131, 0.012955029434975118, 0.06853293867841845, 0.0634732113910779, 0.035190903806998845, 0.017005807434719418, 0.07132555132791882, 0.0338596077035031, 0.02053661091673759, 0.007005096967106746, 0.043038133937384815, 0.006739072456595398, 0.07820793968294898, 0.026691131474029635, 0.07645179802972464, 0.06994711400400247, 0.01747265950055613, 0.019041839311079636, 0.04185245199609668, 0.05836694043189768, 0.014586212571650265, 0.04388763351486095, 0.006579644771503105, 0.07073693533217715, 0.006537537706354934, 0.03333280351193201, 0.03296565204378098, 0.049733780699992375, 0.02933705360778878, 0.04655305641673265, 0.008528762057633891, 0.036262722100101175, 0.07286395547130416, 0.028638069240015843, 0.031104255655419924, 0.022864742542526895, 0.06742167451809492, 0.03752484046403439, 0.07235400904450687, 0.02696278242153987, 0.04221871480225556, 0.06996750726454681, 0.04691904726167841, 0.020049507316622524, 0.018312713213925882, 0.04140612534097126, 0.0196778665732352, 0.037383194637274554, 0.017322833769984784, 0.04808911633106971, 0.019788466686863574, 0.012944310907304529, 0.018738238666687283, 0.01688778775954439, 0.023839269584465413, 0.05430011289013971, 0.06196627430918236, 0.01695159522275771, 0.03953666779242697, 0.02340461236364659, 0.022328090290689183, 0.03310183949408031, 0.0060100799460234425, 0.12166973173377976, 0.05577079869145828, 0.03400545935296724, 0.059433415261728156, 0.02634909428325632, 0.03868644809230201, 0.05138610977859748, 0.0615199055192211, 0.010604099990169128, 0.05004399651361089, 0.02783147441673904, 0.009971268272267715, 0.007996493743942871, 0.045750602298686584, 0.003912163247737373, 0.04004418189006467, 0.05833936509706321, 0.08932418189942838, 0.06746341864908896, 0.047077520209695065, 0.024337753420695666, 0.008783888488617397, 0.09300364857359279, 0.013509837013008374, 0.044514542415497765, 0.013530861338480346, 0.0231409517131866, 0.049786529684018706, 0.06088853798686497, 0.03571755095054546, 0.0130829919737974, 0.060971398056755145, 0.06981337037418159, 0.014384097509807157, 0.062422387737540476, 0.054819348133018905, 0.04545294266614703, 0.002733625315745632, 0.04511776004707621, 0.06376857275984461, 0.046767580187729293, 0.01208654524112541, 0.020533056268768928, 0.04949133302415571, 0.015423402073793115, 0.06410506155882632, 0.060194791745274305, 0.05714689178632633, 0.04649800533849386, 0.03842428897417361, 0.03508329143627517, 0.039033623817827434, 0.009989317303763763, 0.06352360465473707, 0.05242336984543551, 0.06959163388537784, 0.05898452987293563, 0.014942710629604278, 0.03697991446261445, 0.03916302372911765, 0.03346248687575421, 0.03396586026816118, 0.03469601483835328, 0.0288828247557244, 0.07642221937496817, 0.009743917316588904, 0.012913043028675021, 0.02868006809524471, 0.041487100834567706, 0.058279411056109016, 0.0308787998097438, 0.014029585534796841, 0.026416956266808896, 0.07096342922699067, 0.06799288499619692, 0.0453376617553013, 0.010665902218240644, 0.038703037726302306, 0.04116170498872957, 0.03799250266785103, 0.02656626680325116, 0.05706668621109379, 0.032999202864424836, 0.06516223608125603, 0.028204787147021102, 0.0314061421780817, 0.051192890912775076, 0.05864704132921273, 0.018399765699981682, 0.018333638905577602, 0.08664122707540951, 0.020320307906536807, 0.02320999538736238, 0.04304161197656105, 0.054621915783612966, 0.0668362531089975, 0.007876759947037265, 0.03177274206292725, 0.028091823652146325, 0.022669909146404075, 0.045484697010608456, 0.059982045298261996, 0.09071033372874222, 0.056615379984460534, 0.04241373397470002, 0.008563538618956604, 0.014737173069959447, 0.05820002136451583, 0.05514636425481689, 0.03571278588365644, 0.019924460699962034, 0.02458551583150702, 0.03338518094331507, 0.06595609469279166, 0.02200605182517921, 0.060776861519702984, 0.017069335275840376, 0.02765300274345904, 0.024413553990363598, 0.03399377268168234, 0.06404181717023735, 0.016697457045196526, 0.055391462594871564, 0.0133269134112784, 0.03863064624789742, 0.08394259043158063, 0.069970763138225, 0.029564895817349036, 0.05409300101981048, 0.07908052148958368, 0.04991314103526454, 0.0918307526397609, 0.017747338410587083, 0.01339568225141134, 0.03648867590292808, 0.015590748235192752, 0.040434300674185644, 0.019411319686520486, 0.03270558051524624, 0.020436111672390855, 0.037069060283923344, 0.04121052777214397, 0.03718849339131867, 0.06818394732451247, 0.028419973584072247, 0.027431124528389306, 0.05013237241655589, 0.030860235584118677, 0.03297461527249506, 0.051248198630468506, 0.020196847091879577, 0.07595807734516359, 0.04452277403024416, 0.010476642111766963, 0.01911660566204979, 0.056727347565033746, 0.042974211560982856, 0.029165078360106678, 0.019066223889709483, 0.0500089020257996, 0.0788321098192565, 0.040340290194557565, 0.03051463608449746, 0.02366955621137975, 0.06716536448126839, 0.034299683081166404, 0.05927800666540862, 0.032625600935951356, 0.060416064750883854, 0.11164167144846533, 0.08894606388264126, 0.11000654104376033, 0.1136590644056278, 0.12215367713642698, 0.06772373532575947, 0.13117250085117357, 0.20283408132531952, 0.13125405857159247, 0.10857227889280166, 0.1641822642376346, 0.09023350528291157, 0.13893703179013345, 0.16109899016878299, 0.11371605368631502, 0.07255986453064027, 0.16674404693467004, 0.11547670759741338, 0.08709237625401828, 0.14845375902950764, 0.2818437779863035, 0.13778840552174276, 0.14020385010348213, 0.16796899088207753, 0.16832522176686796, 0.2584984435910179, 0.1270530392385779, 0.1297584097952612, 0.1500471299814601, 0.18317526927398098, 0.1548482642899598, 0.15002733426949671, 0.11108205954153692, 0.1772312850000397, 0.0879823022912587, 0.11636906213337377, 0.08678673781574735, 0.12271734164847482, 0.20953304524863922, 0.16912144759008962, 0.17114467047635587, 0.16470943998184898, 0.08334472775459291, 0.1253896861547424, 0.2079691227164961, 0.11412289233938341, 0.1955246525786577, 0.28994108219781234, 0.08264080020448855, 0.13321279217639279, 0.0965158093059736, 0.16387196798478404, 0.1442330588977183, 0.0995332151350956, 0.12769767924422218, 0.082001231700903, 0.1635368504831868, 0.1586358489528779, 0.07150520660704182, 0.12602653504619676, 0.15959503699935254, 0.1891727724503125, 0.2329600292948946, 0.15280978093224187, 0.12336276306380188, 0.10983992458110857, 0.10457221208320511, 0.13906250167037212, 0.10906603022087967, 0.23456611730639013, 0.1210656714054846, 0.12670265360464975, 0.18900919735672014, 0.2314176797986992, 0.0957884471262655, 0.19912532710980987, 0.15548535832954993, 0.0758097090968682, 0.15830758027732372, 0.09642959377097507, 0.13951126065465713, 0.13845257310857698, 0.22438310807751072, 0.18629882424589128, 0.13820842088710877, 0.14997703293638845, 0.13005445681272015, 0.13819187338794434, 0.15543824392220668, 0.11429483311310892, 0.14526358505170192, 0.10893122172884404, 0.16337503739182027, 0.11545431484738666, 0.13226842027037375, 0.11820132994363386, 0.12201103156492596, 0.1414150963988035, 0.16053674291939507, 0.07997409410534367, 0.13137195950313924, 0.20300885662436488, 0.1696843843186094, 0.08744460049896471, 0.2514470792225292, 0.07651789609583155, 0.1598856294707906, 0.22097810772397827, 0.20024862651142383, 0.10602673725976099, 0.15027997474516594, 0.09285047695401216, 0.09391971353080966, 0.1391166027995848, 0.15413065440952778, 0.17907024841875802, 0.11352733558704776, 0.11093511621678069, 0.10167452281401043, 0.09190903916474312, 0.13128100954476865, 0.16683259137695836, 0.16849428204999817, 0.18287644901823613, 0.11764688146931511, 0.157177631232527, 0.11547169738238859, 0.2082262524674016, 0.12853830752353515, 0.1604271463809475, 0.14848967323139792, 0.17602222971618178, 0.20009680320658993, 0.11878266810409485, 0.1774738131151084, 0.13216649993292748, 0.12743470424245443, 0.1448542489520004, 0.1904630177323857, 0.12198418784405916, 0.09353205005848601, 0.12381290866722985, 0.1453683858797435, 0.19749143010666295, 0.08384616294455144, 0.11355765734709079, 0.12175904226399238, 0.1054407106412034, 0.09378191729586932, 0.09062296906185728, 0.1531869719826406, 0.11278272110728488, 0.18893344658276728, 0.11161111986204503, 0.23901885014868554, 0.09764096264036433, 0.13141358872094464, 0.11392019313549805, 0.18633792537354654, 0.15899505225881455, 0.1125338804277201, 0.09098042568732655, 0.18589509590979547, 0.12296025280750568, 0.14408181781970686, 0.10815231715359035, 0.13986229746332093, 0.13023865499323414, 0.136886352312661, 0.1847528281711763, 0.16250338255157395, 0.16072789717826153, 0.1786228837144952, 0.19070099528518417, 0.14920287044538608, 0.1549036064816098], [0.05217666655117947, 0.014575928798876705, 0.024467032673137806, 0.01782982118217455, 0.11641015508963216, 0.05713567242867524, 0.036372958321965514, 0.05636122265470125, 0.028996837791055444, 0.07981533770479503, 0.021288288727162347, 0.03241673855471515, 0.03608539189782835, 0.10591627504195898, 0.05119996956519542, 0.055579751684901216, 0.06392752834325356, 0.028192550807650534, 0.035891889579473965, 0.09392275489986905, 0.05830450426606883, 0.04935281666656656, 0.06756649577930089, 0.02638505445042205, 0.017341248608464678, 0.07581350123209339, 0.09090013967286195, 0.04723772834686022, 0.020634729542859623, 0.011913053139353232, 0.03039303494827642, 0.048730174875667984, 0.025505487837137717, 0.014060896505872089, 0.016798814308018457, 0.033839934565607584, 0.07564356760872949, 0.11680704992144339, 0.0477591086359274, 0.0472264132282186, 0.046256208837392836, 0.04040020976155516, 0.06810622004371497, 0.11458623763774672, 0.11289792540933817, 0.07859587128604613, 0.0755935650499117, 0.02271655049445408, 0.06688426383921216, 0.04541209102758477, 0.0020347244994369366, 0.06543448840778682, 0.008161213181372131, 0.005907604673637018, 0.027823625845954787, 0.04256389486873823, 0.0157862126962432, 0.03411954133621147, 0.03846512146053776, 0.0322650684674661, 0.012552048992215386, 0.052649135956720966, 0.019129223130162687, 0.027457447309467583, 0.014446699342149642, 0.01748683212715532, 0.00914141406199985, 0.07409886622260656, 0.07357266341005603, 0.020504448630456484, 0.030343978508045117, 0.012230852265812218, 0.022313877444473967, 0.05002870156820263, 0.007373022184061308, 0.06400359704369499, 0.04595516692666758, 0.022749091994257706, 0.024856285777904337, 0.027277776708586082, 0.01674000173807144, 0.033673957786372596, 0.0683999534756426, 0.03294494085674805, 0.013549565375151654, 0.024397738105166825, 0.05343313884711074, 0.12506410644780244, 0.08239456422386632, 0.03420399869942377, 0.05132070119162241, 0.09802128699037338, 0.03931372471514248, 0.07266178486808654, 0.0747106563780577, 0.07625018667069174, 0.07116137102486626, 0.03906333653797065, 0.05723757744436303, 0.10073940525011671, 0.057941520316225875, 0.0362189325143493, 0.09025275707244874, 0.061263338842939954, 0.028082132639904177, 0.03852346288641134, 0.012667323199791775, 0.017873080252038858, 0.03407315471239629, 0.026871240660247785, 0.052269263598587246, 0.05276044853211892, 0.021703531364760092, 0.0676184518623256, 0.043612879911257375, 0.054357496706107934, 0.03298838953337362, 0.05734456928386804, 0.045147388497547764, 0.03494181414885867, 0.011475966462204534, 0.036287091356972535, 0.00884740483841949, 0.001916366428861605, 0.028162485687062148, 0.047613735791415944, 0.016498245456586444, 0.01631558328236063, 0.08092459471475694, 0.015675205598405052, 0.10220596566796304, 0.06737098248014528, 0.01856558160075257, 0.03156419569295982, 0.06611546396367973, 0.01978064109871705, 0.06782114340533173, 0.024358204137834332, 0.04616748053400267, 0.023290210538693977, 0.052024609589528654, 0.03534300290348549, 0.02961562999013451, 0.05655318896676745, 0.06999117938140709, 0.07348780385068349, 0.039990628513717846, 0.03446726481460276, 0.03566223940241241, 0.04310145876520584, 0.0075579926769639705, 0.04492133127285108, 0.1285975720853575, 0.016856182802228198, 0.04340299480264226, 0.020727343827245698, 0.04844651166950503, 0.010096470979342778, 0.021987357364606955, 0.020382853239894878, 0.02084703740453528, 0.04356360896640728, 0.01886190632508407, 0.08299728389829397, 0.005889197974841321, 0.012668025127852396, 0.0494206001261069, 0.0627520966583923, 0.00861679322101296, 0.057129072581207564, 0.02813826773255583, 0.02099862322211266, 0.02947569636988544, 0.02836059602428108, 0.08078603239189233, 0.021068714521524888, 0.04173924718352576, 0.006616277180822387, 0.022158097295511155, 0.02242031961589331, 0.03493898345397846, 0.04019413977080295, 0.03862982270337882, 0.1694947622355915, 0.06941511190586513, 0.06396067313729756, 0.018039057031273842, 0.012402053764690796, 0.05879064834105873, 0.016594755298067487, 0.04828230072293551, 0.05874146932675954, 0.09541786741465332, 0.023429500645086653, 0.03953499005987279, 0.020347578721421383, 0.0301518302500969, 0.016603059691166686, 0.06700640123698019, 0.017631814266825398, 0.031561405217695626, 0.02839477503702285, 0.11721907498975916, 0.062080907875732075, 0.0972095249040473, 0.02132784184669295, 0.03521157285919593, 0.02274667307163679, 0.017990768594186635, 0.021907925538177934, 0.06425111239115078, 0.03880557859496724, 0.042591619590717944, 0.029337411753893382, 0.04703292240118308, 0.01459062523809412, 0.03291641557288747, 0.05993233002241581, 0.04189490858886031, 0.050282717171695926, 0.06298348202460236, 0.04748240916899616, 0.09173815559235313, 0.046813166249663606, 0.07871144331030308, 0.09160261931678942, 0.04346940696479813, 0.16218482787089963, 0.04677251762440128, 0.004521553393363232, 0.035266198758636756, 0.07838181099824368, 0.035884309139463215, 0.04114715314860787, 0.03163068829434774, 0.0650428566000154, 0.027670115232467655, 0.0815364231746043, 0.05806262349529613, 0.04362901372294273, 0.030937392129412586, 0.024192692757013346, 0.05254430831560204, 0.03404248821278734, 0.0294733444799579, 0.0255304335751721, 0.023680639588424278, 0.07002910839453821, 0.04469463436473762, 0.029034452708137613, 0.028736480894768913, 0.034834607804734866, 0.044194241054356105, 0.04152755793784896, 0.02881786241496523, 0.04561224298912191, 0.009128829152623733, 0.02728012093763438, 0.055115510063666495, 0.027195567813431545, 0.008606967185774158, 0.043237799433090036, 0.02563753266698651, 0.020722902432504683, 0.03135670652432788, 0.03470740656578734, 0.013892721054294418, 0.0056379675797577355, 0.04398683424017603, 0.05571149199480011, 0.024123015145080227, 0.06020540972390483, 0.061476050815995664, 0.052235199499034116, 0.03336294141087321, 0.09174358715573627, 0.008086698681807086, 0.09923595003783704, 0.008594414835134822, 0.03195165998242315, 0.06671052275886459, 0.03840016486543802, 0.03402776783332229, 0.10534061359301691, 0.03254472503378507, 0.07234553611206432, 0.02114579637324618, 0.04226878247854691, 0.017464341700918252, 0.04496398704847501, 0.04890699562947116, 0.05590298716279288, 0.047819001389847654, 0.04711660984603148, 0.042675935227664254, 0.017477139199693358, 0.02849023725326744, 0.06906114098045134, 0.03010673065399451, 0.02177910785371017, 0.08220183182387583, 0.042196540387287255, 0.056282177702673984, 0.04382424740000598, 0.08837787945184017, 0.07012085508435004, 0.022935356696947448, 0.013891869739088562, 0.03549437804688369, 0.06361118765668043, 0.011517466402672713, 0.026896634559717872, 0.11450555325756151, 0.04006615712217266, 0.04211918848957266, 0.04841055916321855, 0.019556903205211126, 0.013032414849036405, 0.019680494254815484, 0.02766319554329159, 0.027746919377316392, 0.025586415450238896, 0.022002133285446514, 0.12155504071063573, 0.04991485707221493, 0.05021959152673522, 0.017932919379804405, 0.04694992060502691, 0.08321076195927397, 0.04591782397079853, 0.013635298274757882, 0.04913715525500236, 0.07990110124791823, 0.11768724664204544, 0.012145578061350653, 0.06866079875298085, 0.033437029774030375, 0.06479572429652176, 0.027912199016540285, 0.11484735104585848, 0.03782652971905567, 0.0888298636662864, 0.07774428028853671, 0.03524238874595012, 0.04021130014030684, 0.07231644775357939, 0.01714705872619825, 0.07330191261585682, 0.02211807303190712, 0.04231044233986928, 0.07113944558847336, 0.04048996845320348, 0.18469993746088398, 0.1416746929528252, 0.09920484686811125, 0.07788070522609257, 0.2667474944985682, 0.08900483814819206, 0.20959106874802422, 0.23832687357019997, 0.19332905990942834, 0.2688071065612378, 0.07300707601731823, 0.126915066803415, 0.160774260819439, 0.13348213336881132, 0.10984860435729066, 0.1175327496903558, 0.21876690218285208, 0.10636092779496986, 0.06510757570785862, 0.17592505912386602, 0.2099035713340967, 0.08604809882179384, 0.2081801492961184, 0.07607802373146819, 0.14554922859514915, 0.20126988300152365, 0.32041069721021964, 0.2284673832717442, 0.12908751595645182, 0.17467282712459567, 0.11783778291916656, 0.14368173606213064, 0.0878106143265482, 0.12512134853750467, 0.1394039623799824, 0.09652207590519421, 0.22068011484319167, 0.08990244038643376, 0.09853221400971375, 0.13522829289638227, 0.11406933513259697, 0.1315623629958399, 0.1316933180656164, 0.19818398891197098, 0.14313116399270875, 0.07841279159390158, 0.23284310895589092, 0.10719267711524041, 0.12065937667484246, 0.13641815001685775, 0.11530558653776685, 0.23425431952120798, 0.12230176959306964, 0.09414972376919563, 0.14926143020631807, 0.11955958851162465, 0.08378048622680288, 0.12294201225402857, 0.13505331841447663, 0.14585439205890702, 0.08529048382995591, 0.14349111806481116, 0.10528603748929118, 0.13681512145746139, 0.11996108753186081, 0.1538332743990806, 0.12470877954676268, 0.21196099238530283, 0.11794938660797574, 0.0905853005186204, 0.1144412095328012, 0.13278860929271868, 0.11900634279534703, 0.14771621554128586, 0.13389096385048282, 0.17470720915063737, 0.20562697742735186, 0.11627120972280541, 0.10857211801433757, 0.11594395994419053, 0.13631241456154855, 0.12156828637084655, 0.13406449808709084, 0.09730834258540023, 0.18787616863846782, 0.13610938593985575, 0.10418472481110405, 0.1671193993740505, 0.3210697779732366, 0.12473738526985531, 0.14544059732748618, 0.2102933568699706, 0.10914732747140432, 0.23995595954118237, 0.17618595802735898, 0.16967686133519297, 0.1919655306565185, 0.1923911691072487, 0.18461661773823923, 0.15467520502786483, 0.13508290473011234, 0.21737196332504674, 0.20962563463516776, 0.14129955501806352, 0.16755841371993865, 0.1405361637232765, 0.09402169515528987, 0.18505402329948642, 0.17248058992047466, 0.16792849547440009, 0.2269791042612445, 0.09295295653564316, 0.08767988142226973, 0.15829510836591645, 0.1840374552674832, 0.07192637876517351, 0.08271704127471294, 0.14929552111894856, 0.18013990634391386, 0.09949539337427386, 0.10993071366101505, 0.11809696578570913, 0.10057380768440424, 0.06306919194157086, 0.15892795827840606, 0.14523136339360668, 0.1422088400971505, 0.16608156474126926, 0.19199945302980562, 0.15369776876703387, 0.17014422093427953, 0.16333000674363107, 0.09687529606444222, 0.12064900384434771, 0.141791460074244, 0.11133512136556449, 0.23399587209907272, 0.11737078338140443, 0.1284117268158063, 0.10420569263759161, 0.10841075691484636, 0.17168630996058065, 0.12979371112681207, 0.1953175636909662, 0.1366188803747777, 0.17558594264330404, 0.16810739232647806, 0.14903704305329632, 0.11768116390392666, 0.16317671254998253, 0.08161284810593052, 0.1542985502390131, 0.2001392138340781, 0.14797565887772268, 0.1522885806738369, 0.16624402134649216, 0.1597456192417491, 0.2012692854529427, 0.0829093063610696, 0.08729271590709688, 0.09859547755050083, 0.11017659724119211, 0.08436960017969532, 0.31190853085248704, 0.1083956036957041, 0.13984253239487449, 0.10370080239109455, 0.11652128380392829, 0.1449059752086478, 0.17759133100269303, 0.11046821627044871, 0.13594787928365892, 0.053763571721051014, 0.11325214914376698, 0.1818308462539027, 0.09555316620296049], [0.007058717376146947, 0.04324816460270555, 0.02117065401116927, 0.053330111512613874, 0.018791719264681303, 0.0628501022865455, 0.007360818882232473, 0.025285626348528652, 0.0374726354024343, 0.06643591088152702, 0.02574498415924609, 0.016688790675553105, 0.07144885317933175, 0.02171570641709672, 0.0447106839067513, 0.05157619151436994, 0.032615672436452685, 0.08088570809172047, 0.02142251499237553, 0.01850647408695471, 0.06845654439060919, 0.007315789670458124, 0.008155737567933337, 0.01471769049643509, 0.06877593410712096, 0.07075256352583248, 0.14971308500295685, 0.04580130199751547, 0.014008209766489605, 0.006405264965348667, 0.060120860430141615, 0.04399699256605199, 0.04664380719224292, 0.02671468676248145, 0.007945275499350242, 0.05857192257779741, 0.024867924568693967, 0.03183075790143302, 0.02159030739999106, 0.05195363537378369, 0.06940529831955511, 0.03764947147799596, 0.02241904024905976, 0.08013042966805159, 0.06924089585100451, 0.08458588978335743, 0.022978060353066654, 0.00782293652469713, 0.02283538796848828, 0.0264587291261001, 0.04790934230831843, 0.04889615165490297, 0.05406912205921066, 0.035750642118434754, 0.08215683948008284, 0.06084271826811376, 0.06260628331332438, 0.06646528269254393, 0.08801254744250929, 0.06212790353944706, 0.043795990246918895, 0.027447846312556538, 0.02370850795188979, 0.08959657212178554, 0.030711829031427062, 0.02375862542389622, 0.08889377072092988, 0.048403748641571695, 0.033320484818109584, 0.004513572193607087, 0.0632524861383342, 0.0251482016662316, 0.026613360143176494, 0.05466772018060569, 0.020124595424520875, 0.03067928178596401, 0.037242192324371114, 0.037941825951659874, 0.058074712362741275, 0.025645515303157514, 0.025362394104200988, 0.06512200114347282, 0.17245337847740422, 0.03312667606458549, 0.10390624418974885, 0.09913368496082484, 0.06671776228974904, 0.015668743646763746, 0.1147682294850388, 0.04103439266703302, 0.06220735451807419, 0.011176153164987844, 0.02167285337383228, 0.038454311959926164, 0.05147286923602224, 0.01300594938408223, 0.03930977936233244, 0.11310143666642328, 0.03418711412157263, 0.04398342514891298, 0.07008214466153614, 0.04844085794062384, 0.013795447040108905, 0.05770490256949298, 0.03943104725030642, 0.017756908763981154, 0.01368550671970532, 0.04117846699251283, 0.047502281489751996, 0.06521750166411362, 0.024681230856766625, 0.019375219708308578, 0.039656047273667595, 0.022277735331426227, 0.04619868329515861, 0.046857009461570176, 0.01795667002067691, 0.0862642198861126, 0.03769924421043646, 0.07622429289885106, 0.043457038475260626, 0.016857423864665533, 0.0132734902698787, 0.02351930721723024, 0.014500543831907695, 0.029623151058331135, 0.055905599522614674, 0.01114061913423, 0.02480606105358851, 0.011094379024730336, 0.08019118044044703, 0.023502200473881057, 0.015769823202713123, 0.02375594986182067, 0.020557843043559024, 0.1364983747442884, 0.07336788044701661, 0.0436702445750275, 0.03240633891114304, 0.01780211752761276, 0.09741913422100967, 0.0378140271641314, 0.05122659112056417, 0.04324752491928878, 0.03694816011815302, 0.023506768273129582, 0.010088348532125596, 0.05437996606492708, 0.05484082157753649, 0.012440484565412326, 0.06386094381131473, 0.009745239775868194, 0.04435272932413124, 0.024916509864851836, 0.020213664637037346, 0.03536539565351221, 0.009337324769266192, 0.06807162351305447, 0.0286244060618863, 0.03208950984351818, 0.08249030223176365, 0.024131673853844408, 0.02488420776752455, 0.06807317867154075, 0.03630320218602016, 0.02914784904268961, 0.03983522374783793, 0.05307672410121849, 0.04366019733190056, 0.03479326970034069, 0.0351822508438941, 0.05127843229040023, 0.012276636552996935, 0.00538794904000937, 0.021211664612975814, 0.07738189771771431, 0.021745825163839806, 0.046754169818614764, 0.059682884133390846, 0.031290537595087965, 0.022855011310668725, 0.061325008920844526, 0.07625727298399133, 0.03744820102808937, 0.09242791817673753, 0.020554386071800705, 0.04388065445387075, 0.05785457699769928, 0.029983043843399615, 0.08317771292622052, 0.02444762575079597, 0.04144210849077471, 0.03159967322473324, 0.0619671936146915, 0.026562777272756063, 0.027928947613784866, 0.053493843654230724, 0.029029455899651495, 0.030386437016028552, 0.017516575490815506, 0.020486702203690525, 0.02610716563198836, 0.04564234641410651, 0.041531353903513764, 0.026854993850593607, 0.02599837731630091, 0.01852304839919652, 0.05974122555926443, 0.03386092537473287, 0.03819708261759051, 0.028075988614751447, 0.025690702999371196, 0.0190458957466387, 0.047722842033591964, 0.0669361739569614, 0.010378263015750675, 0.007103780583072935, 0.025833574566809882, 0.08384454649903121, 0.026711394499626853, 0.08040934695952362, 0.054402259223523645, 0.05249819365299998, 0.0790955751172958, 0.009419855421348926, 0.06365049562807526, 0.10250914496399703, 0.042673204124214194, 0.04189187105024054, 0.029359601490620165, 0.03582813191197572, 0.030375324910686865, 0.05368226297920751, 0.16388224888472788, 0.01926702894120207, 0.032067990433725144, 0.05813880327848658, 0.012271890638306016, 0.08193938542277583, 0.034580469627173684, 0.08064244453224444, 0.044562602941427505, 0.06998937907478503, 0.04042338392126464, 0.05185136646633187, 0.006640453958102773, 0.1382823790153188, 0.026449038113857952, 0.010457577056161339, 0.002723447598269089, 0.07134819688696055, 0.013497911896857043, 0.035843763936070666, 0.09547455792105007, 0.06469860733036073, 0.05999980704678644, 0.04291877743878192, 0.029870990077934922, 0.1423339422551855, 0.019056126850867466, 0.012843142293633954, 0.0119784081001736, 0.016433353978960265, 0.06397870684703512, 0.051875034752752514, 0.031847814849067124, 0.04010752970052343, 0.026203545238522273, 0.01904794311661634, 0.10452393322221695, 0.0030735756351327106, 0.03421398848595639, 0.0528797667263256, 0.13184452850011089, 0.032329611375086734, 0.017404109953091513, 0.06652838535486691, 0.035041509000884916, 0.012817102007477755, 0.03180992988599164, 0.0692261103540659, 0.032881110410897, 0.02845622869508882, 0.04405043102921017, 0.024375232357171275, 0.012256198284787037, 0.00929209110777705, 0.0641525551796921, 0.03353553335933435, 0.05283362142020657, 0.01950523823559765, 0.04025916148337626, 0.021296725270428488, 0.11249974354981415, 0.041455744855826905, 0.020903350612629327, 0.026607275489837896, 0.004570525085117909, 0.056697159870377475, 0.021437993798885616, 0.03020746738559777, 0.06773875064907536, 0.055379120918411406, 0.013256688046479418, 0.06538021873923079, 0.018040650494156346, 0.03198784039986711, 0.034873528901727936, 0.08323621906099782, 0.012243943750828266, 0.03930516368258865, 0.06598471573764278, 0.02757953299630073, 0.07447092448391261, 0.047010092981039524, 0.03409666595079246, 0.06824146520586745, 0.040784728442949635, 0.08577596140845169, 0.04017960325243973, 0.035639766213153644, 0.022023422868862268, 0.04673764147164841, 0.03788706215639268, 0.03945448187991016, 0.030301328478080612, 0.07541885869877954, 0.062323976082787405, 0.042661827718538624, 0.034083814825862646, 0.08013028411134597, 0.10225308773618552, 0.024112609755848686, 0.03192069853896336, 0.013954326972335339, 0.018000160832138314, 0.05064024657551801, 0.07082678212393677, 0.031046293443068865, 0.01805224140445071, 0.029473876911065275, 0.02004731630515908, 0.09582559472971386, 0.10735996773526554, 0.04811861454659412, 0.06521285151041324, 0.012362876028243092, 0.026176619163203626, 0.0478876275461047, 0.03572087960257646, 0.07356423644288894, 0.016269282843436927, 0.13699991718655632, 0.18344860944536426, 0.1964132379620306, 0.19758406545846693, 0.1254968388727115, 0.2118266665286595, 0.26018371445036703, 0.20432634399302546, 0.2046041887614035, 0.17189594226018076, 0.13950943736539734, 0.10701564951769768, 0.1666791286439665, 0.18980016781678125, 0.13395598939349576, 0.1602985202184608, 0.11244842331976661, 0.0923836536164726, 0.13827343110836324, 0.1230606792734996, 0.17242700973105046, 0.10813850458831557, 0.13972706762292694, 0.07266067404059634, 0.0950442616557402, 0.11291011386821348, 0.20364461767096675, 0.18934224642092184, 0.10221545749734487, 0.1648522847362103, 0.24036232321973772, 0.21120575226603017, 0.17540185171509945, 0.11701665923840578, 0.10974471517387899, 0.11145539716967653, 0.10845983250727577, 0.135681617764696, 0.12377042909182849, 0.13486366568794175, 0.09715722408145668, 0.07480485454922722, 0.14383715998020866, 0.12344074315361439, 0.27975505458251126, 0.17305586066457534, 0.2212599208278041, 0.10815404851229922, 0.10960823661016841, 0.13626087216600297, 0.15679774355263482, 0.23232008540822616, 0.13237864500091923, 0.11569352580174325, 0.12018665446028595, 0.23635680186412028, 0.12092053604822968, 0.2693753292964351, 0.10353547295615559, 0.10969721006169435, 0.12096378937243454, 0.05077686686549456, 0.18960167443560016, 0.23456271587600633, 0.1668342461268748, 0.08267215618322935, 0.21017991457014315, 0.16445929695281292, 0.09813403215018973, 0.15230138966393086, 0.16170473589051157, 0.07000397304974257, 0.16272401587376673, 0.18579495289633352, 0.18486769539454292, 0.1380127160659721, 0.08790056070973797, 0.2127191129951708, 0.1849579252302647, 0.09928779886855234, 0.15459992922842503, 0.1118087015985962, 0.3763972300915949, 0.1438274306635703, 0.1804239257809616, 0.19404686897272067, 0.13512709268158482, 0.10761042486035055, 0.18025322606967342, 0.12641486501501453, 0.16827326568384326, 0.10278678288863552, 0.1245430364243446, 0.3516480855403408, 0.08738302235161105, 0.18063956420988808, 0.1161169502583723, 0.24244265029987982, 0.20060266638475083, 0.12824828195716106, 0.12230026806073806, 0.06891176149609589, 0.11216816537442709, 0.13988854363560677, 0.19191009653431756, 0.10654602995923451, 0.12445521976558432, 0.1197318587031576, 0.1504115120417649, 0.16577843907138995, 0.0916672618158402, 0.11730182014646069, 0.1303598654246138, 0.19213696581221398, 0.17775061600390943, 0.1488135905275422, 0.12673230886819864, 0.2384142382370849, 0.13759590294812957, 0.143562103771875, 0.10642505701511137, 0.07695776079931567, 0.17136038551407476, 0.09844370787182162, 0.15899215644646078, 0.1731372498456509, 0.13110396662546744, 0.11633651105747109, 0.11399393675908928, 0.09976546235022046, 0.14523519383322808, 0.1321203814398858, 0.10858518747432579, 0.08280079766747453, 0.2065109662831791, 0.3485174519160102, 0.14153941714715573, 0.11771612815679082, 0.09969240820576107, 0.15611947994799386, 0.27201821006113486, 0.1268411546404804, 0.14719503060463937, 0.1201439067541111, 0.10679253407063023, 0.12800216088972746, 0.08571976885920571, 0.16111106371446965, 0.12413325599364697, 0.06695745587949792, 0.14345675136052793, 0.0746132406376062, 0.132262843150285, 0.1569281776826228, 0.128977122686563, 0.1688186743206555, 0.08837005769413325, 0.15878966408631495, 0.07155510957442945, 0.11831466499115191, 0.09772024507964812, 0.15621622153107198, 0.1468492798026531, 0.14211830382625903, 0.18649137278477992, 0.09271123281289494, 0.15786007767723453, 0.21846235158943364, 0.1101120773162092, 0.15542263105030985, 0.10391411191273121, 0.10619166832897933, 0.16597065053159193, 0.12313852146748575, 0.14509029596322967, 0.20360530203869268], [0.11331714404326294, 0.03676290473630352, 0.08477672228529569, 0.04299629021496062, 0.0265165017316899, 0.11850630188541067, 0.016814967271901907, 0.053572919249774954, 0.04906001020102732, 0.04766165842151931, 0.04496355803923742, 0.03693334014725782, 0.032150051856954256, 0.011911452015591486, 0.014547287644217572, 0.030560787136275924, 0.018512338490015077, 0.014296968414958929, 0.023887326279955528, 0.02382967050277418, 0.06679538997911638, 0.038260311684421, 0.07243858515134743, 0.023795026091618404, 0.017115844473723444, 0.0009553082899430828, 0.05031622202706434, 0.019407332198874607, 0.033733452174572215, 0.008394462056457996, 0.049284106240637844, 0.0595834037859834, 0.032736538128266414, 0.0347081343493154, 0.02228170558209381, 0.050875021880793, 0.03547449806524861, 0.06694582666480733, 0.025123635141719735, 0.0758978551734359, 0.04034005653774066, 0.08681474599025904, 0.03959763306944121, 0.044428579689514254, 0.017790785171992837, 0.09426318139078156, 0.051788194856095704, 0.05793920290025492, 0.051809377187202056, 0.03204744970125537, 0.02055478443752133, 0.02855461162154473, 0.04107520217075944, 0.04228658253146757, 0.037069355227774194, 0.08753450857775827, 0.028939670394925825, 0.05221869796514512, 0.040961698583898046, 0.03326163777420598, 0.026234719271381057, 0.034241644260022915, 0.03662565242378943, 0.1420063170934877, 0.04716972655226146, 0.017717416931484497, 0.02090753919835533, 0.0431929066807272, 0.01597442613509033, 0.0502043387161628, 0.04619890546065666, 0.036958624879198695, 0.08922547147038484, 0.02662782962884634, 0.03897124893903252, 0.05541550243393548, 0.04073162705847814, 0.10761858369674414, 0.011796269738566012, 0.05643961643199286, 0.11373833918403234, 0.06259055935867852, 0.19863026577138132, 0.18972657741077487, 0.1301419287319145, 0.028490137661837285, 0.08154144871138758, 0.02458028728142381, 0.004357987397064966, 0.016490977197404832, 0.06488818344810317, 0.04431776890170671, 0.04253363056528953, 0.06013518627432566, 0.07136872804333126, 0.12689811327765066, 0.062386592279278466, 0.02886817906983197, 0.04581848534965708, 0.03215731820091605, 0.06330061561217712, 0.04893726376335948, 0.019807616969750776, 0.03717374236833665, 0.027393180193499695, 0.09850644281194096, 0.031130946158701857, 0.031079348221781756, 0.021886319943493413, 0.005690114227153602, 0.050462368620379325, 0.016705763353515538, 0.027334101407998995, 0.04718027941341843, 0.040970160025021726, 0.00392646539107626, 0.054679835861128186, 0.05614169632955905, 0.015675832832893057, 0.06547853080255371, 0.050308538165183804, 0.04933171860513188, 0.0058486034545386515, 0.04299294241073151, 0.06602176374966098, 0.028291699822030725, 0.034307642734699675, 0.07217619237640212, 0.016129182599064325, 0.05156972573228902, 0.02255187414947056, 0.040807228445285754, 0.020647052067121672, 0.07450929782803982, 0.022677719412792115, 0.02898784008838477, 0.022987707315253156, 0.019012498143579692, 0.022124745657727606, 0.029031698622049826, 0.0328135644386132, 0.04200163995847107, 0.04965418416465964, 0.05421525333076716, 0.017270644030143178, 0.03318702081038106, 0.051126731559634216, 0.02106041012842569, 0.029093673219904307, 0.04161584957112228, 0.016476095939475684, 0.06710493546580115, 0.04690117826084456, 0.06839868943056754, 0.033051767987349344, 0.024179696075377927, 0.017616530812736002, 0.03172026312489423, 0.027761752754750273, 0.07739274552272213, 0.015665223472751677, 0.03691344101342463, 0.06330264574517647, 0.03209738331215997, 0.02663486997687048, 0.01560562757790209, 0.07649704318253264, 0.01563075526181849, 0.061506311289004745, 0.036223689920359084, 0.051211468544938875, 0.03837428641535583, 0.05721495869839865, 0.03872299048629019, 0.07369499232980513, 0.07798821034450686, 0.08223160200061337, 0.05806549632501218, 0.047961501404643066, 0.05777596488534924, 0.05446248522569096, 0.030526753680239764, 0.027409382953098225, 0.01320028673827408, 0.02170377268245624, 0.0827151720201777, 0.03467933327380208, 0.05956094591848313, 0.04709548114107982, 0.017955773697805502, 0.031170765493786147, 0.05479103735377712, 0.053571613069864056, 0.05715478632238604, 0.11736811739542793, 0.045915897259668964, 0.1076639973888955, 0.04136497875855815, 0.015547862633191531, 0.02974495903829173, 0.03109817866296057, 0.017903336894608313, 0.04141835210424277, 0.027979888630309896, 0.00560026791419894, 0.07151290579068084, 0.08004215335653675, 0.024514945727142117, 0.029855637675932342, 0.005712496443471361, 0.045735774666912136, 0.0227999008606158, 0.07209140176494276, 0.0466821230797758, 0.05547300499353198, 0.07152576074605027, 0.027675585100247015, 0.05783756601534063, 0.03469286238654487, 0.05091158725741891, 0.0614409065324693, 0.06434895714083988, 0.04199222473788165, 0.04067719651145801, 0.05008842961321916, 0.02390489076083947, 0.059828846865604, 0.029336297095963554, 0.06781134514078017, 0.006673017004129267, 0.018345492200986035, 0.010396585923679655, 0.01762125757522881, 0.043857162367672696, 0.057013263069694085, 0.021741496767067624, 0.02519689804513849, 0.029847183895687905, 0.014106197200054604, 0.053052373996545235, 0.0357419163769772, 0.07737072049489907, 0.026795147061948816, 0.05907389785974257, 0.05513533641914687, 0.028290749873004617, 0.007120330955067109, 0.053618922829628, 0.03967368644812415, 0.033374808112820314, 0.043470808905699564, 0.030604080680096825, 0.03470928731164144, 0.011127748857102087, 0.013232449024555185, 0.19042290536867035, 0.16730750460297833, 0.23477674552029182, 0.2508375030611792, 0.33403603059630244, 0.12365766094937441, 0.03993585705757141, 0.1367250448393245, 0.11462351547614222, 0.055024747796837366, 0.016263722960326462, 0.05326619679709116, 0.0775762235805873, 0.08593751402992396, 0.03722787031062669, 0.08133911722970587, 0.040147711012151935, 0.05692104523580882, 0.03799960047246949, 0.042801807304063154, 0.062345947484455766, 0.04201400844800857, 0.05754093294061961, 0.059116492348332564, 0.031807340508807576, 0.018290416224889697, 0.04076278768479824, 0.024984415898460056, 0.04886105716709168, 0.07662418313444623, 0.032159896086781256, 0.059616774575965065, 0.022518198839539004, 0.033616152622046015, 0.022669217752052412, 0.05020335046274047, 0.015154108761869853, 0.04750154221490507, 0.05930511468660928, 0.04695931667341821, 0.05706599290152231, 0.04075621848084754, 0.018261266579370827, 0.04800596131732868, 0.016154963372936173, 0.058543738203063134, 0.038298891872287764, 0.07952372633641766, 0.02047089780981262, 0.017241931054741144, 0.02715994089451288, 0.013069798982131385, 0.0719051351470332, 0.04438279827515926, 0.03591427083818182, 0.05759250597968217, 0.023181360935972586, 0.058131720795626604, 0.015755034832944794, 0.05556211634088428, 0.04067654916716199, 0.03628858905886451, 0.022225005499598, 0.022706757975561966, 0.010500130367525404, 0.03653136232206899, 0.04142595935733088, 0.05207700617310982, 0.01774989714425418, 0.03744084658401628, 0.05102069733003455, 0.01348584696965953, 0.005496380167202123, 0.025237042967590596, 0.018747667293815364, 0.024509650144365527, 0.12600364433901926, 0.02711131537873899, 0.017256262644584623, 0.057794147982232036, 0.047599739365039334, 0.07924641782958662, 0.01632462695030676, 0.04451498674649385, 0.04085854101445406, 0.04966182206126471, 0.06000376772135497, 0.04096238040215066, 0.038861472369922746, 0.08273018734349359, 0.03303970593298155, 0.03382252521752831, 0.0321457655950179, 0.026579251993567716, 0.04726294413088791, 0.05736359507746755, 0.08098509267813737, 0.4055876008445217, 0.17511885883587022, 0.20345265135890056, 0.12091914176820748, 0.2324989975820626, 0.16112319854719026, 0.10947908184701398, 0.11571909781665572, 0.12969808803210336, 0.2044468189799978, 0.12952348127240135, 0.15150504126664133, 0.07682230879342364, 0.17006430264201858, 0.14760167007484745, 0.16195795859300322, 0.11642985887104466, 0.1131840898925739, 0.22833676528065439, 0.1309109890773412, 0.12315332994706209, 0.13981853852108603, 0.13278333860779964, 0.12434701750715896, 0.2626636329918139, 0.09392549749463798, 0.11880588056820056, 0.1063243164530685, 0.07358115166425705, 0.20085121595090438, 0.17211525791114377, 0.12202050041167006, 0.1376766792588657, 0.1063925595653634, 0.15372079737003774, 0.11701128130117733, 0.24735370290375527, 0.15152978590659558, 0.10463028920874481, 0.20392793230712417, 0.13100388489903944, 0.14400646541147463, 0.14724782938438077, 0.17790015636672898, 0.17976535063597465, 0.19121301781025626, 0.1628159464246804, 0.1826721640123475, 0.09769576090958812, 0.14973490318704039, 0.10005977800897053, 0.12701260511793439, 0.15330331009482184, 0.10245270726661529, 0.10005757933662784, 0.12388215535470556, 0.07876025077195899, 0.14342728761896012, 0.0756106181671062, 0.08102247010796301, 0.11917787754247267, 0.09802548515219843, 0.14554893748173792, 0.2524500568547557, 0.2408913835402458, 0.12602593749761581, 0.2077112268776663, 0.08244512602686882, 0.11924049756940334, 0.21892462436470295, 0.10689076186428148, 0.09021354103160482, 0.15174380022912257, 0.15699016951745556, 0.13504055538965812, 0.1444057810811266, 0.1365945187787856, 0.19459923368788537, 0.18006881338454064, 0.34326270162578554, 0.486904708368163, 0.5509022226737392, 0.32183951247603665, 0.3667794864985251, 0.36143528778226147, 0.21077102801251799, 0.31548328096828154, 0.24690281419504076, 0.10906572378570996, 0.23634960063763205, 0.154581343935382, 0.1544270538274319, 0.16824154964377805, 0.22383823570224548, 0.23602137792735334, 0.24781231377874655, 0.15548135935058519, 0.16187618636796552, 0.15562487826231988, 0.18706233811474618, 0.20924701866122986, 0.22858313915710296, 0.15278256948917143, 0.14993373364690812, 0.16086456726395315, 0.2395880994417014, 0.11548625305294992, 0.08900512926160328, 0.14475134802201103, 0.16508540529156887, 0.24780321265420607, 0.11157617093093934, 0.10293472212769332, 0.09980950474498734, 0.13376702614609273, 0.13871575495408428, 0.0919408011700838, 0.14286841115643903, 0.08513922743018597, 0.1028633074113919, 0.19125571955115567, 0.2019955214834021, 0.11552001454777296, 0.11531310186030404, 0.19764467833503602, 0.10726198508975007, 0.2607453794729325, 0.11410226925246178, 0.10923318294507843, 0.10929130603589358, 0.08537162786289569, 0.26249353082910665, 0.15713693664198922, 0.129350314757997, 0.19282837548563558, 0.14009505029647581, 0.1538955573473246, 0.23819440164633338, 0.1690599154080114, 0.10653086141833376, 0.11879673347838464, 0.13229452854683324, 0.19326231832946503, 0.07154039302540403, 0.16328457772972124, 0.14475409061677996, 0.14194473894613405, 0.12198795699664663, 0.1439201732676837, 0.15642259029611466, 0.1984680389925357, 0.19996250799346357, 0.10136094770484394, 0.12774621091422536, 0.13984959572553635, 0.16169480739101288, 0.11374298167685348, 0.14958799816668034, 0.14083467754385165, 0.17467195378436198, 0.19806846285298949, 0.061461889680715344, 0.11460728973390595, 0.17083658055672724, 0.10325539887191788, 0.16256289226153206, 0.20120214550725876, 0.11003284084220087, 0.22445775568485263, 0.10843583097260807, 0.12346535755862152, 0.1333716328466131, 0.1534666706837954, 0.07591080205935626, 0.20217486266647616, 0.1441076503045136], [0.07820723488205865, 0.004414963750018468, 0.0783533048665812, 0.02182086539124289, 0.04624049637406584, 0.07284212196546216, 0.1167952215238925, 0.022134733529040412, 0.05127754362840807, 0.027437640106185313, 0.017861025858550303, 0.06730625571142282, 0.03397982605102082, 0.042028299818236026, 0.05753011577912877, 0.09137185831223765, 0.04414863584022369, 0.00952033647110746, 0.09515286994076545, 0.032744386699050665, 0.05539172306476582, 0.06719550238020959, 0.07563013042653761, 0.05485798577747999, 0.0705245910813251, 0.06050232625115783, 0.0870869753341521, 0.049996767193079, 0.01284613386697827, 0.1050015124342134, 0.05753979530005206, 0.02891977317631245, 0.035872254745974656, 0.029969244684663512, 0.022984100956349604, 0.026200982674415556, 0.02512837722597103, 0.030042995969133995, 0.011879639256925834, 0.05729974164897877, 0.03910447545950452, 0.020300487296715863, 0.01852237232660334, 0.04659488098695875, 0.009213629340182149, 0.04617807936043509, 0.04507659814290462, 0.03197807277883253, 0.05357714805511698, 0.10134515863272453, 0.05359233574821584, 0.042100599366089994, 0.038666380419125485, 0.02896836804856937, 0.08440643368709473, 0.03704988893361823, 0.03310689950482019, 0.057707806042726004, 0.009257205378925128, 0.06645283376377437, 0.03169042591546332, 0.0496672076593724, 0.03453673366757651, 0.018359752927696513, 0.019245467396573197, 0.08369879061055761, 0.04485747018348306, 0.04564137731288229, 0.034300506625685005, 0.09131870713205108, 0.07399423393390833, 0.061038698880903186, 0.05585272030364122, 0.10431666047342363, 0.05677996631411295, 0.030078965712398775, 0.4320500857166706, 0.6404725486232389, 3.904374828261714, 2.2732772942512267, 4.384705337785906, 7.812770085950052, 7.257419834213873, 6.218594312667848, 5.477848331774435, 3.248613371003059, 1.0775448309798394, 0.4863790801215557, 0.13035788891776917, 0.06564637300588431, 0.08561279234145919, 0.01839121232830709, 0.03849772999303476, 0.05784537628172867, 0.03251581670596235, 0.12499436946405519, 0.11417386016898579, 0.21980553354707458, 0.3477460013762597, 0.29250015294359577, 0.29380906012750446, 0.6141801046267633, 0.5455372170094521, 0.0798512519066853, 0.05244630268744884, 0.04879544556681668, 0.05680593669474606, 0.03617027827027825, 0.06622361259595042, 0.017468966956761096, 0.03479458354113083, 0.029640186938547322, 0.0655574225369961, 0.02003720969021801, 0.08199795284458707, 0.055936522661678256, 0.036395197854407375, 0.04544303331884646, 0.06420054292726902, 0.03065169495981067, 0.02115538204839874, 0.004847580304128989, 0.03842166512303295, 0.019030696562220974, 0.029259081178855513, 0.06628167439973162, 0.019301612065323902, 0.01769412785858637, 0.04410566596855079, 0.07001995364384306, 0.020581723919378656, 0.052141422676222945, 0.01620966013550999, 0.03572888522138519, 0.06240337726569945, 0.05332003745640959, 0.025865095254454403, 0.024147077966781876, 0.029239128418867628, 0.03256487314619365, 0.044615980117551746, 0.03374236560757122, 0.019788556702194676, 0.022069792255699154, 0.030103765893727544, 0.01738389097754994, 0.04268401362482579, 0.041987992102100004, 0.0299018768278221, 0.03583389289316631, 0.042404414515101144, 0.052109928801655776, 0.0052356067106067656, 0.07131029851734638, 0.009155691068078722, 0.07990499297457357, 0.061694860848928654, 0.050387242208084757, 0.0211643950728279, 0.0397293733793401, 0.03198172510301154, 0.05484869313095847, 0.05742194416422037, 0.02499204996462551, 0.015125607418256904, 0.03381170805603747, 0.05644295657534273, 0.053750601852492946, 0.07019788522513644, 0.02027751806552612, 0.0479617580440977, 0.040877788973551606, 0.04693347269729261, 0.06355245169552584, 0.09147217752592218, 0.0560821598065236, 0.04362252112778445, 0.06222318189458982, 0.03510378811868929, 0.01803477843021674, 0.05451043849931129, 0.03217686493430407, 0.04176218768641834, 0.03508312289693183, 0.015144398597429599, 0.041859178248071865, 0.07463639181467795, 0.05274259102260394, 0.06450149290744336, 0.05529676646655125, 0.04919823161476562, 0.025762870397058227, 0.045164522053974296, 0.09651396303407608, 0.0904288960079993, 0.07783993402676237, 0.042311771502417904, 0.0637683391030277, 0.015690163465126628, 0.03452739888621915, 0.02452544113170476, 0.069481271259006, 0.09821270938001334, 0.04391173847139843, 0.004129341273989168, 0.06459268801394971, 0.033476812719938256, 0.04496927688559217, 0.016515599263291207, 0.030259366012028152, 0.027662640129546487, 0.023037997157042547, 0.04897806560620666, 0.08582232504962914, 0.03528917756592555, 0.0338110875248188, 0.025185778278917558, 0.033917336259037256, 0.023963274321548884, 0.03190080132034998, 0.04512210376560689, 0.03574990667402744, 0.10485498279693628, 0.00253136613361177, 0.08058027649718909, 0.0360166929632185, 0.041091274695410844, 0.03162921549031331, 0.014365375278547648, 0.023060771035811594, 0.02038078671771913, 0.03756750007009795, 0.028512484446588545, 0.0030782820484150323, 0.01689355640161422, 0.10875667625617598, 0.02798653444305303, 0.026887353404515216, 0.06710380931655247, 0.04897159216324649, 0.012017658614974109, 0.04829182319583432, 0.015868843897365998, 0.03370627137501875, 0.028886747125896717, 0.052106646114900235, 0.06036588216140386, 0.010621949838804863, 0.03639483779308297, 0.08532580814414448, 0.049080514544320684, 0.08735761887604192, 0.8092785518496268, 1.6378324887444897, 6.767194655633743, 4.727244944341721, 7.46056919136355, 11.421870358528631, 10.825805414107538, 9.42078790357036, 7.938070691400959, 5.747686316890102, 1.9683239224456974, 0.6816752699594344, 0.14975918817424005, 0.03401487840399627, 0.021508236400662892, 0.08037052928440033, 0.032730520507621194, 0.025768573921654495, 0.07345326094617767, 0.19773792655717945, 0.20143690549077528, 0.18746464152730283, 0.28467192945461123, 0.5435443465267459, 0.3983659351304655, 0.9465795875557008, 0.741020608092508, 0.1701175304309976, 0.022020756882885774, 0.03557457213079737, 0.04223277634610573, 0.06961385809606122, 0.04506752766188114, 0.10819732481914182, 0.029185707192687742, 0.03313973786369447, 0.023871837897346388, 0.03014508484592361, 0.035755119902352174, 0.14278535190368855, 0.09300852089279121, 0.037563930100370804, 0.03741523243426796, 0.11808813279194218, 0.017095732750491272, 0.008571148744874425, 0.028875121741645762, 0.07359841928607033, 0.021729518982371496, 0.05594677674854475, 0.06634739708275565, 0.02328385583936207, 0.044459108293296835, 0.021061622462565863, 0.013310631170057723, 0.0018442230911234455, 0.020720632897029002, 0.06457276972791841, 0.06832205765550176, 0.01755886354423579, 0.06778283134823845, 0.04578523713374331, 0.03204062194263022, 0.013433935894300381, 0.041388221866180824, 0.03992732666853455, 0.005669034360307119, 0.0332585810833881, 0.030710520936296355, 0.024119251738152197, 0.026881644134259513, 0.03466386978905048, 0.02337936976654155, 0.024010130174217686, 0.02566310085145937, 0.07395812054915775, 0.027083366576041427, 0.10211651724192405, 0.04862806301624064, 0.03175265523755262, 0.02581745416166321, 0.03503523474078506, 0.025301775481972485, 0.1136678897385155, 0.07582040368429116, 0.053742684333795504, 0.06597254260052597, 0.030854164337318753, 0.09367730798980883, 0.03610068301279699, 0.02044528174484449, 0.024024798842747847, 0.07732198198115633, 0.025711142225191, 0.03985264458723607, 0.05666774209408511, 0.06479042296808574, 0.07665346301491223, 0.0458161449510484, 0.021178479599315795, 0.09615839864577978, 0.12899889490537106, 0.22021779610264688, 0.14525400895264842, 0.11361094642310374, 0.14915422386219426, 0.25069167056391317, 0.23903634759687611, 0.2103420340966794, 0.07885040399888832, 0.22484539617453853, 0.15256100153971106, 0.11726764496415855, 0.1527287441516115, 0.16087769801097532, 0.15727653318355161, 0.12065429751190448, 0.1169295397196566, 0.2290969390061594, 0.19539193550665535, 0.10877086420453365, 0.17583007954301375, 0.18625304283153626, 0.17579566687345508, 0.16451226427189766, 0.1447393510851168, 0.13117253149469055, 0.11167393141095677, 0.15999455185186479, 0.1971866650086257, 0.08254015923387582, 0.11046156662726596, 0.18988308917370536, 0.19335573509095177, 0.14368256343708885, 0.10904396688866039, 0.14715646573853108, 0.15270047550720556, 0.13533151558329984, 0.13628745541697548, 0.10596315962292495, 0.16200262151898878, 0.11979625605407263, 0.14033590833986961, 0.1672640827394301, 0.1490939174207949, 0.19628919300533113, 0.15426686484246485, 0.146410204169731, 0.14906909617204822, 0.143433784044558, 0.20080117508769038, 0.09973131781143528, 0.15852677335421886, 0.21158249898543283, 0.10257800094663136, 0.1362073992288882, 0.11804299489144357, 0.08715218473826686, 0.36553873049636043, 0.15082593496528365, 0.1527173294415397, 0.250220695029824, 0.08685471279726875, 0.14283360012115973, 0.16837771411143965, 0.1034865275986733, 0.12624310810239087, 0.09992975756646165, 0.17289807719569053, 0.1978958479218906, 0.2315368217926833, 0.1699290421581076, 0.2068979019719747, 0.13674015209319132, 0.22622325127163243, 1.1225057345244194, 2.2506895901695376, 6.368737249605118, 5.1223433306140285, 8.813960955988977, 14.772686477630371, 13.827833590968964, 11.654971914906657, 9.022722244262695, 6.634150801166412, 2.634890406362472, 0.7315977266238582, 0.2794194467846425, 0.15487884651989708, 0.15244602706403504, 0.11746760923415424, 0.13475733268405163, 0.17642684671426975, 0.11604787977111918, 0.2591408849243195, 0.4659205795295777, 0.3693728166962824, 0.8061700734880664, 1.1185598301310693, 0.8567723872200136, 1.2315286263342828, 1.2833882435675592, 0.24222949399582802, 0.148259632349495, 0.15621897944759938, 0.11218145699991335, 0.13991100533354667, 0.17133423127233985, 0.1428199943996245, 0.12948071824446802, 0.11346270840975548, 0.16329801491191312, 0.16250275435947603, 0.13232763886692064, 0.21383795376506545, 0.14133033643086113, 0.15666288143444448, 0.10670910709567609, 0.19664189988566985, 0.13587197529212122, 0.10183779147243309, 0.13425381373493903, 0.20640051172625637, 0.12506252830667844, 0.1603198174627558, 0.11228494015672516, 0.1395627111196518, 0.18504444720043292, 0.16760451689122186, 0.09393033917031943, 0.10126133329204975, 0.16907915953666935, 0.1420623487642696, 0.14890434130305244, 0.17961907380771253, 0.13784665884750505, 0.08145267444272196, 0.12718082270434788, 0.08485189849330534, 0.0642741869594301, 0.20189755415964514, 0.09171344925679507, 0.11487270855615217, 0.19617271699732353, 0.1336434561639063, 0.09956987244227242, 0.22073240800490304, 0.12632118778363352, 0.1451060314091944, 0.09525368711160076, 0.23612545863274606, 0.15096995949504838, 0.24837194100743343, 0.17367562579531826, 0.12989986026960035, 0.12176218322448193, 0.12917553945895166, 0.11759964448790397, 0.17065736194772108, 0.1497916243369541, 0.14780402453916688, 0.2064708385977053, 0.12276184369599628, 0.23242283312063064, 0.14692974967821953, 0.11073523621645667, 0.13331854295346046, 0.2654894555528318, 0.1723623365884827, 0.14014486133331253, 0.18481612235548037, 0.13842824215610183, 0.1235162181359145, 0.13317349186587718, 0.12235715008911588], [0.039091697112927516, 0.047291998015416246, 0.03232979523618856, 0.04818828258242819, 0.018723606387333527, 0.0759323597735455, 0.04495701181792444, 0.025578691368742336, 0.06902281360159959, 0.01691043140336631, 0.0290364368758615, 0.09155278529731498, 0.008932716389667363, 0.05968720486928379, 0.013375290906086806, 0.03590981603690213, 0.022311458521853053, 0.07005529327979011, 0.0350757263180229, 0.04443975691232951, 0.07266679508311134, 0.07050229792272852, 0.012180883223341118, 0.09625962950409421, 0.04148340446033305, 0.054239243374116, 0.0034657595050145663, 0.03746209786303582, 0.0023414014656502275, 0.01598067741255246, 0.08530471774358904, 0.02926861131263356, 0.05836945703072895, 0.056638492857136076, 0.04100751064177002, 0.026200624528310956, 0.04860786510811699, 0.024338841265548142, 0.02136967024735866, 0.017718832278924606, 0.04626152931802696, 0.09820583757133254, 0.05674146656547824, 0.01361141739893825, 0.020715842932282437, 0.03899744531560329, 0.019589806681558974, 0.021228196790381786, 0.07966041174386779, 0.024341940091201858, 0.0644721287573057, 0.04002139077431733, 0.026349153655070453, 0.01856664646296732, 0.035053823864267725, 0.004290903471560488, 0.031201763326422344, 0.018073994471060655, 0.019837496314017523, 0.04984315890338152, 0.03195684831289034, 0.13330928861133515, 0.02446586630427309, 0.023008213573766333, 0.06706346712645984, 0.010444880106426295, 0.04638026528541119, 0.07708640228356085, 0.07541715798358764, 0.04028929555187783, 0.11587067597335386, 0.4714724187168383, 0.22218743879948893, 1.649858107970607, 3.073981115894933, 5.521543535494036, 11.129496885884194, 25.675338968153923, 34.70775142792733, 33.51358582896571, 32.72070615522323, 31.619916500583773, 37.59906384252733, 36.48931157204413, 34.3098505081669, 30.50494943895648, 22.95102342482536, 13.375805924015662, 4.876870128416247, 1.9143153366542633, 2.338488659551067, 1.3965111153741039, 1.2164154889122134, 1.598218511189184, 1.3495489450231677, 3.516238403897132, 3.942573565629221, 4.698368945429403, 8.212725347088229, 7.771434678185371, 12.755251661423715, 13.383283922749182, 6.597370736060604, 3.2008389023042496, 0.9913712775995656, 0.0597392337306613, 0.044655272767188094, 0.050286421206809824, 0.052578230688889185, 0.021333298307933637, 0.02983025909822074, 0.030229802679030165, 0.02423801451861378, 0.038686815814505664, 0.06387514708143088, 0.03855804792575298, 0.15622097127620252, 0.06789644984828849, 0.05097329180928008, 0.05555452823999429, 0.030206145883928386, 0.026170900316848874, 0.03146903033578589, 0.017473954189148162, 0.02267358636844062, 0.016812190203176394, 0.04278683028514347, 0.04730291476833725, 0.04123851296401793, 0.03334054099996725, 0.027817181131291776, 0.03628855075446829, 0.043078824697482976, 0.030216587662336328, 0.03476634170980223, 0.0718210340147057, 0.03845349607628681, 0.03214552427732176, 0.01004597046337421, 0.04122088528088024, 0.03782670974971787, 0.05623030971976058, 0.04613661102109379, 0.04506270896883742, 0.026508072849303007, 0.05059563727568715, 0.04091565286920917, 0.0314508855432993, 0.008507349900150252, 0.06049619371732397, 0.0185907322673067, 0.02258142407592987, 0.03854002570733428, 0.037412826918185725, 0.03394888759019875, 0.008091118051520279, 0.037086599866949746, 0.04083908621161696, 0.02766587685102657, 0.021823119604960087, 0.05558066715997073, 0.052071831249181307, 0.05819783035305239, 0.006073151486024502, 0.02591146464129129, 0.033371264956170515, 0.08575200583905944, 0.07812729360715998, 0.0063046852817698834, 0.059318728069023746, 0.10436288621877471, 0.08663167395899374, 0.04678331946413364, 0.05942600719150036, 0.0472828624169192, 0.009313233219267381, 0.030674583751768358, 0.04850189982643051, 0.09890627942138142, 0.10582953090629271, 0.020009770335990096, 0.09526782909468298, 0.1014723675325513, 0.009448620107685848, 0.09207662089817947, 0.03406185108507353, 0.10125204064552823, 0.07521929279450448, 0.020586607729895942, 0.08932752204277823, 0.06483835708950797, 0.03160914015625754, 0.03814874630000803, 0.03366288398542712, 0.029498539196567673, 0.04292913111707857, 0.026595228757228584, 0.06529029533867875, 0.05478143827208588, 0.037248627462935065, 0.01799807515776446, 0.011893548540801052, 0.026359786955459465, 0.05059802747001091, 0.05123985593297309, 0.012848716540893, 0.04186530695146611, 0.02222951009659277, 0.07096027294474264, 0.08179826436624413, 0.025968729713631254, 0.00872345372749072, 0.0178560673544604, 0.04492259531792614, 0.051777170850865306, 0.039204358003072204, 0.07216081699176181, 0.07330834775442079, 0.017982910447303328, 0.02893023219169869, 0.060290472296577316, 0.007049174314635176, 0.046445570450516484, 0.0634517724205169, 0.017929470068925334, 0.022274481372967846, 0.06360928775862822, 0.021174457637713324, 0.033350182216494315, 0.045241337690141895, 0.014641344089121109, 0.03511819440210539, 0.03631821750933605, 0.061825858053540995, 0.0215878980534692, 0.03546569954543825, 0.07423591935226033, 0.14564114382430432, 0.030592330806558172, 0.0706752346107556, 0.04357939037764746, 0.004829763971839942, 0.07157752530709391, 0.03468780620624462, 0.06492329325767295, 0.035005541172839945, 0.13413675550010898, 0.6931847910727225, 1.1683749119120261, 2.6669552922248845, 5.183895614839369, 8.902758513727496, 16.417397087620152, 35.427639715133175, 43.844281242739775, 45.04230645395095, 44.19219547702421, 42.04270916600382, 49.23836000504033, 46.710729752817464, 43.318514977732015, 39.385111178121264, 29.593845605850223, 18.720088235793575, 7.775134453850408, 3.3561647611279644, 2.961940573107812, 1.8539346153697662, 1.8685753523342072, 2.755825904107863, 2.0427831334452478, 4.286237176387541, 5.140409277331445, 6.096526720831472, 10.562071127276267, 10.128569795239358, 16.13111113348315, 16.79523802572681, 9.19738538803593, 4.458202219778492, 1.8144046010509616, 0.11132354577702862, 0.015221713148357888, 0.016132162681089777, 0.03174053764181032, 0.02433530960021721, 0.04340530838817359, 0.015766666920465088, 0.07080536996645313, 0.055485480735378886, 0.01753401165197213, 0.009287900606831236, 0.056185531880586385, 0.03996445895022443, 0.035944106132392926, 0.007226382421645066, 0.025984175961404562, 0.042088824594693805, 0.0825032874220802, 0.08004957674852303, 0.03585037910529683, 0.05166744407747061, 0.06229899778601624, 0.017008862210317485, 0.047903244248441154, 0.08070984494782264, 0.01252149549057527, 0.032505034018428094, 0.06492330857943143, 0.04509969186338206, 0.05138203802127993, 0.06258816150347553, 0.028225448538338947, 0.03352109643240129, 0.015593110658829252, 0.026725992305024017, 0.016008668350085856, 0.05147067056367955, 0.0028654144637496964, 0.024128006207906914, 0.01920544121774935, 0.049427234447531165, 0.009274492152936516, 0.024838807481911876, 0.02148247286376934, 0.08208191608108821, 0.06210244643772322, 0.018696896731853485, 0.048983106464748426, 0.0872679329627464, 0.024473540590054566, 0.05003303379541443, 0.021414754521702568, 0.07918252609670162, 0.09151875567171844, 0.01056340348441154, 0.04504794645453653, 0.05618085108336903, 0.038627436339494683, 0.026323483963947625, 0.06192440377368082, 0.04862489141223412, 0.03516127152608768, 0.023570194607600573, 0.027184340794901216, 0.02087940270411632, 0.0878394805195351, 0.06117610058056251, 0.01671811269085494, 0.016021512771746325, 0.024281731326012843, 0.027682497128543836, 0.09550666466595666, 0.14184530073356244, 0.19099357958522536, 0.1338864132882126, 0.09747711941599847, 0.20099733956158164, 0.2145857628314726, 0.12346323549507127, 0.2044427740357576, 0.11373941170712633, 0.17094763266223093, 0.16018878578418688, 0.09000335714869923, 0.21290462884691455, 0.15435375453483674, 0.15775008277306635, 0.13847471304958867, 0.13301417622114384, 0.14676750757761542, 0.10529724535562339, 0.15659969450244982, 0.1664818456817058, 0.1341079046288806, 0.17022352635620103, 0.1707617490882835, 0.15548748805397944, 0.07299896314620011, 0.1077697175224462, 0.1470577782921253, 0.11432178408628511, 0.23338703138213004, 0.15154739060709554, 0.14420885051931107, 0.1514294590320318, 0.13823106644615052, 0.11160718983099346, 0.15544745229905652, 0.1195254133293225, 0.17469585572759952, 0.11614669745247211, 0.19468008660741393, 0.16346791789176005, 0.1405123230670729, 0.18464677095893892, 0.14358951439780576, 0.16271800974444037, 0.11039288684485421, 0.18173415063610002, 0.1549394900399831, 0.07344417514339571, 0.20633868843076691, 0.17028927202186278, 0.2230035982305004, 0.12150779606834536, 0.11479528771052439, 0.16862770392289086, 0.16806798476365306, 0.16827004811456128, 0.08236212040027303, 0.213188449101102, 0.2335493347697681, 0.18549662293686023, 0.09392408023197805, 0.12561741345111402, 0.15349008233076142, 0.10956318297934149, 0.1566300775495268, 0.13697652086134882, 0.25576154851625044, 0.05539996617083108, 0.40528517997553276, 0.757113847761385, 1.7853783263314156, 3.288303589628589, 6.94388811626742, 12.248023498442866, 19.48157718104701, 40.42311153104229, 49.22462386469687, 52.61539520755891, 50.19522220857682, 47.80709889627273, 56.4448405081226, 54.47796798521473, 51.60616151748165, 45.209277829816266, 35.64263266901816, 23.29744519725923, 10.110644563551872, 4.503955196949744, 3.80050384709912, 2.9140844700797914, 2.622114266118696, 3.306532559856292, 3.0846632007629644, 5.954369239268765, 6.828403732469005, 8.49370825675226, 13.92507306991085, 14.575430481664597, 20.32030740091878, 20.18804507870828, 12.01055830524814, 5.968544194775244, 2.459435679258839, 0.21393707022070887, 0.11495022133233086, 0.15764074670451303, 0.12054957329265534, 0.12761963786737573, 0.10582210751430643, 0.06603455741799648, 0.18825282342731955, 0.14038685318683425, 0.17653616746106457, 0.10594230670962604, 0.2241603143873715, 0.13928722590208054, 0.1363709283572051, 0.1743628526286733, 0.1981709807390167, 0.13227074917766357, 0.2818897432617603, 0.18064344061478493, 0.09253875577762243, 0.21404240731029742, 0.14148903920525505, 0.13597199573151528, 0.12078515299025083, 0.28538485087694665, 0.07391594740892611, 0.18155499331412778, 0.10073027348205929, 0.0694093432637953, 0.19706364660974474, 0.18293082593910157, 0.14440982602536678, 0.21447371481166733, 0.08521389802016559, 0.10778974306078688, 0.08222194929276744, 0.10773257757987707, 0.1530412314159255, 0.1351688597952166, 0.10605900488313168, 0.122695324281531, 0.08190191606239927, 0.1426519913178298, 0.0820536167931653, 0.19648240037983467, 0.2030472529511298, 0.09486106705040702, 0.1455981356482352, 0.20228180854070574, 0.10633455904861612, 0.15999387769449144, 0.12886839948834913, 0.166592346203904, 0.29883940794294883, 0.09508860282479756, 0.1379272206536224, 0.19663658323547534, 0.11712994065976913, 0.13495619378743634, 0.11474461099433322, 0.15149474504493898, 0.1508088512045722, 0.19536991813971152, 0.12339231873592063, 0.14079061216644703, 0.2126950578343484, 0.27705165287179334, 0.11380969261329983, 0.18179877781339232, 0.20776764159241032, 0.1891652188233791], [0.07383032942250853, 0.02930203955920954, 0.03882342078272374, 0.07269437424838543, 0.024670375390879573, 0.04688945328516345, 0.0769320125841806, 0.03995866349507724, 0.03172051210346962, 0.03615416744123063, 0.01312853302806616, 0.04228532231683212, 0.058320438894893856, 0.024487433594561393, 0.022553186075040893, 0.11130065506985111, 0.04343870216079297, 0.0033711344792297293, 0.026755233881093805, 0.04916263150892431, 0.022527600653589736, 0.06687101051812211, 0.03224167980313782, 0.011088707101260944, 0.12218614394265799, 0.04148182248876941, 0.010179315727474469, 0.07448131263616585, 0.03333409437008443, 0.048273437085651585, 0.07457322786532103, 0.02490229510341681, 0.012668625549263051, 0.01446263109814496, 0.07916466858718665, 0.05242649165372695, 0.06747155450284481, 0.014966168241845745, 0.015850805399578907, 0.023212253431519194, 0.053489710609879226, 0.0926719401632586, 0.052425924748662985, 0.0385890323518505, 0.047008472705079664, 0.019346056656251033, 0.0650008519991271, 0.029997090065491297, 0.0712910620495677, 0.012805342557840051, 0.017017055520667665, 0.0946973387392298, 0.038940203225901054, 0.1397346672151358, 0.11147887776455573, 0.043544728729513385, 0.037933571354275754, 0.04263775340551811, 0.044020396552138755, 0.08327964092454604, 0.023838040013346943, 0.04705873190335209, 0.0665642152870855, 0.11138566784680852, 0.010918701657154148, 0.05182695124418505, 0.02955947191484513, 0.06266817172628737, 0.1979973239283408, 0.8227711375201903, 3.46180203460878, 6.1802977611941685, 13.856697332474495, 16.200779291891283, 27.50178083296745, 43.39481292232391, 54.342936469662575, 65.44425995119157, 66.73723005479383, 66.89990643532046, 69.22153380609328, 69.8822021484375, 77.60335645368023, 68.18412180869811, 59.46398688900856, 70.95504883796939, 58.09555038329094, 47.23303256496307, 37.43559122085571, 31.014241749240508, 26.996514835665305, 24.669635411231752, 24.69699590436874, 25.7381792606846, 29.580203602390906, 22.72413588339283, 32.43942318424102, 32.96117098100724, 34.19854540978709, 39.28792661236179, 41.620081624677105, 45.004181015876036, 36.66618301022437, 23.866979229834772, 16.828032962737545, 7.319165785466471, 1.566165515011357, 0.3773840432686191, 0.02078194291360917, 0.018612793684306166, 0.022237958131177772, 0.021040457368437803, 0.048617069654527216, 0.05654035699403575, 0.06398199336423029, 0.015078511205501856, 0.011021093138673855, 0.0850250496859512, 0.05308289876988819, 0.07523767890468722, 0.021159379112143672, 0.07385216292835052, 0.0722382914635443, 0.05368552651376494, 0.04260534405588143, 0.07248555400198506, 0.029256344329746022, 0.05556009003832456, 0.04495294389104651, 0.08278556783953983, 0.0021656458134642776, 0.008152540108459371, 0.05811293248928363, 0.03017692537527652, 0.023698173425791245, 0.023486890206714312, 0.03191996117933624, 0.019663561796469074, 0.07090447876121729, 0.05096433241100562, 0.03892420347960245, 0.015958321051702144, 0.04750565610705845, 0.045904593632346204, 0.10142849367712775, 0.02855155301550704, 0.06686632206002552, 0.03596542635932565, 0.07307620779160531, 0.07206033689961319, 0.042666435737403176, 0.042117449469984546, 0.04058499016889161, 0.059579489076690334, 0.022511237015527104, 0.03019337711345044, 0.024746566665388887, 0.020243402255038102, 0.019739076998385213, 0.015174974124097537, 0.08056336893670021, 0.03548860557437424, 0.03955697295286002, 0.02114484642422007, 0.03315784052134522, 0.06188017368737248, 0.04180284014212028, 0.08332802703784359, 0.03640008549536428, 0.002802348190603117, 0.038597394201544025, 0.02058466569700789, 0.028820645229350177, 0.05760465996460088, 0.07850709701738051, 0.07422912415237197, 0.050708267522314866, 0.04931946885922263, 0.019336832957642696, 0.07732434153196312, 0.14374262473035243, 0.09009447564641315, 0.022698800237248504, 0.04970653861340496, 0.0945370884672288, 0.048455202937005996, 0.023712884229157242, 0.05945607614252837, 0.032836868833269806, 0.0652251395607187, 0.12418520441579244, 0.05855481583444823, 0.06464712622184908, 0.02193841966800392, 0.030254576047281587, 0.039569444864267306, 0.06520839287869393, 0.007445306888961744, 0.07435896073377903, 0.024111163764891606, 0.06548365593076715, 0.05441258608874294, 0.0641328705504777, 0.04532345465474552, 0.06907693005257076, 0.06386805693769167, 0.04009226156819252, 0.012744319824231489, 0.12178430018285591, 0.010460550434917453, 0.0590584573576287, 0.015451163184949228, 0.021012077641282833, 0.059909220980179895, 0.04807115539968495, 0.0287189930226774, 0.052961393394657684, 0.051647449182646896, 0.029067279575693033, 0.022192557845565102, 0.054691139488450946, 0.035646002168857285, 0.07283675168911297, 0.02058072417463747, 0.02335304315502365, 0.05663327196793211, 0.02817733055581489, 0.0748051533235177, 0.06428557102598491, 0.01793410107042761, 0.08196698757068765, 0.038496125038833394, 0.0043295090360897445, 0.017371518657572808, 0.013504663046689765, 0.01879684630811455, 0.07107018357923917, 0.03767184890626419, 0.03283607593226818, 0.1274344284508017, 0.018832875423193462, 0.015454804017809371, 0.05815351982751201, 0.031299531467319015, 0.554923816554008, 1.9589055762175593, 5.9846210095190235, 10.282843478264349, 20.689869196184222, 25.335918626477643, 37.64083316249233, 55.39590458716116, 69.14202736270043, 76.1592338931176, 79.36111957796159, 78.56293293737596, 80.40501133088144, 83.53923613025297, 91.18424154097035, 79.98123845746441, 71.47844206902289, 84.61527562910511, 71.59627006899926, 58.317666361408854, 49.40439393443447, 40.276552169553696, 33.282107153246486, 30.037216601833222, 29.132145374051987, 30.183575922443023, 34.237647518034905, 27.88162708282471, 38.76616508729997, 38.91873744226272, 40.498350435687655, 46.80793785279798, 50.9344046346603, 54.60151480090234, 44.34122985409152, 30.369335451433738, 24.003950357437137, 10.890324481071966, 2.869045119131765, 0.7417981566921358, 0.04626937788881121, 0.03728870918313342, 0.041608862849252845, 0.03461078372633746, 0.006001245037036678, 0.058324139099568136, 0.06762238189337716, 0.024103836133895863, 0.05923936902094753, 0.04176284652203322, 0.029910926241427663, 0.12228099328856315, 0.027640726184472445, 0.037934774112316876, 0.031376356679585674, 0.050772729990703445, 0.07248945338951965, 0.033576557367679574, 0.043996283934722026, 0.05081810154801896, 0.056321772957040425, 0.0453795591038802, 0.024460856089248292, 0.03729994003210337, 0.0699281303452388, 0.019225849800052184, 0.056562738252743605, 0.025313554083808296, 0.08450888262520875, 0.05120916262028679, 0.05126788709012251, 0.06724568880012921, 0.04858433854796233, 0.08075197978365807, 0.034367673384446296, 0.009984150998324398, 0.015573104272686667, 0.009466610724977668, 0.036470090609885035, 0.028638978969425927, 0.04889428240036772, 0.08848572164894113, 0.02175276592043379, 0.032857595342061216, 0.03449086798354983, 0.03532169799831125, 0.0906573893922952, 0.03749662544578314, 0.06750690946055037, 0.03161233857334141, 0.03475734017669194, 0.0061854441751605805, 0.06385789095093647, 0.04062358184807724, 0.10320089937698457, 0.06822375325305809, 0.024427801310535402, 0.0368938023494857, 0.07907774825129779, 0.07213073271897531, 0.031346373913449146, 0.012721784390328873, 0.03020066452483016, 0.05180050205859927, 0.036660126380382047, 0.08843053267487595, 0.036951232130729386, 0.06192757537768734, 0.1737438076205792, 0.2156543175900175, 0.10176743395746717, 0.25297511819629903, 0.3058997661836686, 0.1757845739203115, 0.11630592116665457, 0.1900753312774243, 0.1895474660540781, 0.16292077789623893, 0.24727107266024237, 0.3686316419512995, 0.1563522634246657, 0.1410209594835197, 0.23731007571181945, 0.168952310698167, 0.18327170442188942, 0.10776719709317531, 0.1600123250917081, 0.14845719110340844, 0.13004043740370583, 0.11369142395954941, 0.2008020024626486, 0.11505994044484631, 0.2632026524553376, 0.15450003136309887, 0.14796899391278145, 0.16969101864003366, 0.23498953410213996, 0.13630968728853812, 0.229733542749478, 0.12372576616584294, 0.15750626763028486, 0.14043752224214617, 0.19801624630007053, 0.15574169134901417, 0.15767670687167876, 0.06041371669139593, 0.13671310918946422, 0.11503014728547105, 0.10509934186214402, 0.1417865877550456, 0.1146209337598374, 0.08931696535118165, 0.15149819244059826, 0.13748112765531387, 0.1365019753575325, 0.13056920661080268, 0.1969748723410791, 0.06635813763545406, 0.06966848782594166, 0.1956247189833272, 0.17615545240621414, 0.2676375967360312, 0.1366328384967581, 0.14524164429355055, 0.1986201993760563, 0.15343152256982942, 0.10495456656621349, 0.22633437998592856, 0.16337039489899913, 0.12563239813091295, 0.22118629977828075, 0.34018422326733994, 0.10948026928329661, 0.10913526924747614, 0.11124912799606401, 0.19336448381504706, 0.6380263992374944, 2.331353868207624, 7.08585536287677, 12.929171516049294, 26.311480729810654, 32.607182956510975, 45.88725166936075, 63.67227039029522, 76.81989439072149, 86.49124330089938, 91.35379775877922, 92.33049146590695, 95.46476333372055, 95.01425558520903, 103.03198814392091, 95.69487310224964, 83.25679409888484, 96.03408751949188, 83.00492302063974, 71.17223831915086, 58.908026218414314, 47.97776906721054, 39.55964488367881, 37.06093818910661, 37.10189165607576, 37.41063710181944, 40.856572658784934, 36.16008350926061, 48.38913156140236, 48.86750774998819, 48.124375497141195, 59.73094340293639, 61.780142553391, 63.957238428054325, 52.642949858019435, 37.710616050228, 27.582850340873968, 13.326633130350421, 4.196442846328982, 0.9779171188992839, 0.37517617787084273, 0.16218439886166205, 0.18090171949757686, 0.11284751682392052, 0.12934855275577115, 0.16122568578970048, 0.22590953826663956, 0.06279793552934163, 0.1827622559522429, 0.18369288424090033, 0.17919063147517944, 0.23877990732510246, 0.08970954710797918, 0.1572146945663037, 0.14911144551250244, 0.14266896782623184, 0.11114592829178419, 0.1833437013650133, 0.14619733897909043, 0.11502656199398542, 0.1515481873385368, 0.20585850451982793, 0.11677903408605246, 0.12991499816698412, 0.0850933081200046, 0.09532366924348379, 0.08787170983850957, 0.14697807450448314, 0.2644566771003508, 0.15279519461816357, 0.19304326314839626, 0.11953914162492561, 0.17128245905041697, 0.13804024926597072, 0.16746888868510726, 0.10934660226226815, 0.15202362150434526, 0.13852328302398806, 0.16194173285076696, 0.20828136483267432, 0.23904786955925728, 0.2082054761628951, 0.15032508200214756, 0.18380517740884136, 0.16829218805557297, 0.18919163353500829, 0.2106927644701735, 0.13616431444402666, 0.09888961700902832, 0.18589926342810356, 0.19862505637349623, 0.1238042212301685, 0.10035445372904502, 0.14202499431708168, 0.17501696914194093, 0.1702640217638785, 0.18958028526075427, 0.20360173206896554, 0.13775380899108228, 0.25316843282311197, 0.17192606483736347, 0.1162882781617584, 0.12308292646682072, 0.19838047514279045, 0.1642517024470914, 0.20029325879389243, 0.2780654017002352, 0.23081412508843407], [0.04734480062559728, 0.033273688337254914, 0.03736739407383627, 0.050032317503205234, 0.01806860312729353, 0.023115283937283584, 0.04480564050496586, 0.024118456921930757, 0.02943309613563601, 0.034620685412758784, 0.06544339034946696, 0.06780442736682392, 0.032223002579543865, 0.006815895753642244, 0.04445492162279064, 0.04037720797162864, 0.03794869776034067, 0.05294912066611071, 0.06664780314050375, 0.05310943605558527, 0.03819088113584346, 0.013917746273950945, 0.038028133417209314, 0.031064754246824214, 0.005440667859323684, 0.054330457632820454, 0.04579110153680367, 0.04919054392244547, 0.029026554341638283, 0.06650460598569724, 0.026572732585332087, 0.08370366292975603, 0.042967768761539654, 0.024035863067594268, 0.03927841955315202, 0.007040482568329261, 0.08580783066610176, 0.061772764329948736, 0.032493171146920616, 0.05864809853054824, 0.07915578962814424, 0.025186475418928652, 0.06125459011884467, 0.025938164720672275, 0.05002858282457437, 0.05771202718718879, 0.044124871792812506, 0.08098245733567784, 0.0971542593211897, 0.030109174474472963, 0.05693964585061035, 0.09184359227337184, 0.04658897827950217, 0.05645779569843604, 0.012935253832819722, 0.08177053198338517, 0.041348132485103224, 0.05689746504949947, 0.04036704198487344, 0.034447836824843, 0.019826139060540066, 0.13163586147129536, 0.06587675096647394, 0.033839750704505754, 0.09720306678284561, 0.15155155812540363, 0.7988977540404567, 2.7306621834155056, 8.876684558007026, 23.29959465611366, 34.962501525878906, 43.514802148265225, 52.63716043964509, 66.25252708312004, 68.7849896953952, 71.0758892182381, 77.61585312504923, 70.26053044103807, 73.12035406789472, 71.7246727789602, 62.96917376979705, 69.66450275913363, 75.49195243466285, 73.76763928321101, 75.4668963340021, 78.39273345085883, 73.16540641169395, 74.63975475680444, 77.48031954611503, 68.86806549564486, 70.60986457332488, 66.60581496454054, 56.883122228807025, 61.517151555707386, 65.40904098941435, 60.52583525257727, 61.46965557529081, 61.06505916964624, 65.22235970343313, 71.38345010818975, 71.34188867384388, 68.00142565081197, 67.7737791307511, 60.52830634578582, 64.8904408947114, 48.335136213610255, 26.26998793694281, 8.783453741381246, 2.3286775860094258, 0.3739093442357356, 0.08015447716799476, 0.04359156351476427, 0.06633563763311794, 0.054017403463442484, 0.052000596563542084, 0.04584067125594424, 0.006574733190298562, 0.06777236658719278, 0.06065596518437229, 0.029699185284815972, 0.04885032810571213, 0.01386655915168024, 0.014068614841709215, 0.027877456929174163, 0.031469009268367966, 0.05103680432864255, 0.15723303471121097, 0.012659079136116611, 0.03791071895149447, 0.02924606534502199, 0.06676772654417061, 0.040005268453950846, 0.08405327481488067, 0.02846011084564511, 0.021108746446008166, 0.06284932853774199, 0.1002913434058428, 0.013862214475539664, 0.06202247068886796, 0.09793046726694993, 0.04425656230699632, 0.0636516294382032, 0.014478993778597685, 0.06476929426313409, 0.10694080272749548, 0.023600355489179495, 0.032241442315881295, 0.009931528418805572, 0.04914131128199158, 0.08705353559625727, 0.022020159334304835, 0.05139118894153545, 0.012667585584905841, 0.053604991520724954, 0.0482624322326193, 0.013970603467896582, 0.06470990712724387, 0.04400549231157188, 0.02039752765408447, 0.1240655031776236, 0.031449451043661085, 0.05838067255794041, 0.05486885273468591, 0.06876223645503483, 0.020950089636889678, 0.028187232242236217, 0.053324683779670354, 0.01963159103216904, 0.03007551448629989, 0.02153971686869139, 0.05853619223700897, 0.07464304911873995, 0.048067520312484235, 0.03398434980021369, 0.054984191102125955, 0.05575958316424682, 0.05884643103326521, 0.09232575269115549, 0.06101168279025344, 0.01489009475335479, 0.037287870316856334, 0.033072777948672735, 0.09009709566711419, 0.012069459565194144, 0.01884453719662082, 0.04508015662131291, 0.07320913936822646, 0.0304865627925122, 0.045821480753441016, 0.02655653365617318, 0.0922863451283305, 0.02028125657459661, 0.12685567200664552, 0.03412771549436354, 0.04763406393448672, 0.011378620627276119, 0.07552767382754434, 0.009335081089257954, 0.060389515973867915, 0.0033634518143615777, 0.03711399134068239, 0.04197823980282392, 0.0549258726588901, 0.0207724089493915, 0.10339384628159386, 0.059432312095117186, 0.07936227330637556, 0.07410704038075863, 0.02553521587903942, 0.016937018484778462, 0.043838948627272924, 0.0419926077818438, 0.07619242364120099, 0.08075663759823769, 0.053979980068341385, 0.04993334277382782, 0.0958491902377817, 0.027544036312329195, 0.011670426390464268, 0.014198754985456266, 0.021406706768058, 0.05648486158480087, 0.061691202779090216, 0.015014917289297429, 0.025678188953128074, 0.022172411648376335, 0.03168093600130129, 0.018218840630124175, 0.05552764621473128, 0.07497959154387636, 0.03341517328555065, 0.0658799302313597, 0.02316233705759289, 0.031914749866231315, 0.023005001750143788, 0.06266670466791238, 0.0055669138823906264, 0.049072566382106275, 0.03917289860246163, 0.060513652861118324, 0.07450693827723304, 0.28159332852209773, 1.4016888891496968, 5.565762375631641, 13.997432954849737, 31.30397938912915, 45.12074993502709, 53.052139359135786, 62.79016856224307, 80.82222600137034, 83.18727400995071, 83.07909504059823, 86.85283876234486, 79.07635550345145, 82.55301106360652, 82.04544851856848, 72.13871817434989, 78.0020732264365, 85.42244449738534, 84.6015630229827, 87.30643733855217, 87.15466514710458, 85.315748183958, 88.02935369553106, 85.79463820303641, 81.4830041700794, 79.25941251939344, 77.64421186139508, 65.05385468083044, 71.17863962727209, 74.13620871882286, 69.98198724562123, 72.66352345866542, 71.86038678692233, 76.0510313895441, 82.53830217546033, 82.7128319586477, 77.46914863586426, 78.30655897817304, 70.15758391349547, 77.07945331450432, 57.59723678711922, 33.30017751263034, 13.090321113986354, 4.152069562865842, 0.9277028746662602, 0.07216841658397068, 0.12522192822108347, 0.015037699786555624, 0.05209763309047107, 0.07360192796876354, 0.026818468693583727, 0.02208292108750151, 0.02389749801237016, 0.03996842345523258, 0.06581369426942642, 0.024610591804488532, 0.04828426956890091, 0.038990983363961985, 0.038912302303698756, 0.008342815281432724, 0.1085190051385472, 0.0453335440327083, 0.02280881812405442, 0.02571092580535239, 0.0695242947568336, 0.14674581196759978, 0.05263686705861361, 0.06652980261752683, 0.019138044632610776, 0.051865987254366766, 0.06952365890385644, 0.061870566944802, 0.017408570500030633, 0.04544184971300345, 0.03146173334830711, 0.02516065251022097, 0.0526781362150946, 0.007425921991647732, 0.02585850115264616, 0.06792753003537655, 0.06070136738520476, 0.05634310850573163, 0.07095992054429746, 0.005630955960030758, 0.08825046370827383, 0.012483941860527042, 0.013662670596292423, 0.024491296592919577, 0.028013479670569785, 0.04978740685469201, 0.044815710730730526, 0.03227514252367039, 0.04326039519641669, 0.056823242620955554, 0.053178234581625274, 0.013587018456159821, 0.04747085656309801, 0.037378824105666536, 0.09180602332156512, 0.03565688827826131, 0.03891196139457245, 0.05481313132951337, 0.05412146884707674, 0.019397911232625766, 0.0301602955216602, 0.03895207375828778, 0.03241159427430361, 0.08029498535418704, 0.042534247266068574, 0.06250044826658503, 0.03366882882771954, 0.270176105681927, 0.17832945671773728, 0.1624813805063886, 0.09381418491924003, 0.11401731776253832, 0.1030347272453289, 0.24697225240449755, 0.09871327889061744, 0.18726190401902124, 0.20301305478618992, 0.1893760308983826, 0.19024862036589654, 0.11129780522277279, 0.08861382687163931, 0.24975017914848946, 0.10934187549977534, 0.23340229185358172, 0.1575776517030693, 0.1831805859241755, 0.10826451839098047, 0.2551319161730428, 0.13316170943360175, 0.17627802647409901, 0.22035376138744817, 0.13043212283763195, 0.187482001079667, 0.11799191980953179, 0.14631655758186696, 0.20785420952785402, 0.10357809042738331, 0.18098061123201925, 0.3191718104625902, 0.11824043107128913, 0.20387118051369346, 0.14330342652336245, 0.14689803363815432, 0.10592817238742307, 0.17084870006768935, 0.20017048554314723, 0.20048773787435026, 0.24728389697209482, 0.06283982904748091, 0.1300250390364278, 0.12999120859369157, 0.12387225749872385, 0.10762009288995497, 0.14794585805746818, 0.16656536458721086, 0.17885704614943077, 0.08175190838594591, 0.19959417291946951, 0.2673900584059377, 0.09984519678137957, 0.19362107730440556, 0.21166702912699795, 0.18299908437315496, 0.18270011089982527, 0.09317345196200956, 0.19611233394713173, 0.1851787270918008, 0.15543858100089336, 0.14254129161277126, 0.12196683595257422, 0.1701006918184219, 0.2309721077401792, 0.43876080142874874, 1.689395109011281, 6.456593438502281, 17.20974429961174, 34.5237216641826, 50.540822244459584, 61.358558362530125, 71.33494607863888, 92.11847951335292, 96.19160206087174, 95.14701997080158, 98.9463375460717, 92.38123909119638, 93.91855716705324, 92.62677161924302, 84.61415383123583, 91.8939002867668, 96.8963578439528, 95.84778278104721, 98.82468131280716, 99.59574084128104, 99.5955054990707, 100.58027928875339, 100.29357756337812, 94.0423785486529, 91.46784459390949, 87.30049102537095, 80.19871819403865, 86.30602113662228, 85.99275712044009, 83.20942755668395, 86.55196943590718, 85.19312704763105, 87.61346478616038, 93.12794070090018, 94.85319522119339, 89.48213684943416, 90.48491431820779, 82.53458376853698, 87.61057007697322, 65.73727669254427, 39.01479236541256, 17.948357982020227, 5.80633016363267, 1.1138292065551205, 0.2585496795513938, 0.20777271309446907, 0.15039239048717484, 0.1310513976721033, 0.22860128011914993, 0.11734645242892927, 0.08126326686432285, 0.12884474269324733, 0.1463275892479766, 0.24212567376032954, 0.18374419681006865, 0.11654749933269717, 0.09110204980618532, 0.13444904358156268, 0.1059174394956039, 0.24351192518107354, 0.2424137074981005, 0.08806625020600135, 0.11409904402230056, 0.10004654000963896, 0.19130839575682917, 0.17260635091412455, 0.20836076218514674, 0.1628676880030863, 0.19304574527327092, 0.22740748530674368, 0.19875994913520353, 0.1523601179642062, 0.08343763123717039, 0.14914731374911724, 0.09794696113995968, 0.13232537124666477, 0.0821414411128048, 0.10854928859419401, 0.20272402513411739, 0.17250902710422394, 0.18790298171581762, 0.20603501117758213, 0.14485141442668054, 0.18672397240034996, 0.1992077888139794, 0.12771153777477243, 0.1837665818992161, 0.14982715549488224, 0.13336466144650214, 0.0805633842584587, 0.1370178436439845, 0.1041960629123834, 0.11463168963429429, 0.18330628563079143, 0.175822357376737, 0.18406149510654712, 0.1530418596080234, 0.2056196229832788, 0.08284513883653187, 0.15813899496870656, 0.1528741782831569, 0.16795780599838303, 0.11850755826960649, 0.12008199152807075, 0.18045873681624092, 0.12324973445145354, 0.18662517770163475, 0.12403876670906622, 0.13305845610316724, 0.11893594697598489], [0.04728101614502169, 0.07983072841119382, 0.030426846238814538, 0.04093886916375449, 0.036551985408990614, 0.08189057030024068, 0.11235971033813492, 0.014759712334301685, 0.1313606214018599, 0.10306668077265063, 0.028752405947494893, 0.07609976530675927, 0.014965855103406697, 0.004049946315541503, 0.04469505188265636, 0.06307133315731922, 0.01147551638554902, 0.04186421144573439, 0.0849021308785004, 0.01509041525423527, 0.014772022409634966, 0.021109242487939137, 0.0612566010996459, 0.04611917869037679, 0.07491763035256056, 0.05061105862560292, 0.026982790722902265, 0.015578822161431517, 0.04053807111396905, 0.0409680073179545, 0.02207385060647803, 0.06928119207582167, 0.009448419009605724, 0.08316578493723947, 0.014268081154554121, 0.043813901382588574, 0.029345668266497316, 0.028829621864602934, 0.03515323143332236, 0.03065145747255414, 0.04697565349840349, 0.05062552236561334, 0.014907014762772428, 0.05579299608906431, 0.006801020720177481, 0.034986316196380124, 0.14024431486764263, 0.035879524920376084, 0.028083601613498987, 0.05075957243060393, 0.03492203375865375, 0.04668358630771118, 0.020176440424796556, 0.024778460820896492, 0.029846044339900537, 0.039620190528371645, 0.09631556924432517, 0.13876054045413772, 0.09568641187563058, 0.07684166017439097, 0.0639654956607809, 0.10978747054093307, 0.13590962085272038, 1.3786569766459928, 2.5045882886455906, 6.5590884031788, 18.34569800284601, 28.581434795933387, 39.87041819480158, 62.68928912378127, 69.3448531243109, 67.27159807758947, 72.9782779755131, 69.33681226545765, 72.46942889305853, 69.9617164365707, 61.914397439649036, 60.09711627037295, 63.99104533656951, 56.098220655995036, 55.441506062784505, 57.59773885050128, 47.1087718779041, 48.79980764081402, 58.45796562010243, 56.64082565615254, 50.471074658055464, 70.45697842874836, 58.11995144813292, 70.05238594547396, 68.00595206599083, 69.60722046513712, 63.90095633845176, 65.10767352196478, 69.0803284798899, 65.03108532198014, 68.97442448523738, 75.75300970385152, 66.2514131299911, 62.795365702721384, 58.96144497779108, 65.28654536893292, 69.69118272104572, 69.77654134073566, 71.16113801156321, 68.96509708896761, 62.193175977276226, 36.574270109976496, 27.653172554508334, 14.166564576087461, 3.185514937485418, 0.5758092119809121, 0.038116053497839364, 0.026313208809663213, 0.026948460407795447, 0.0601571538455544, 0.10746859900292852, 0.04730686012114729, 0.010370822386786101, 0.06840318636668306, 0.07619715806457304, 0.019127826934920687, 0.058073015477988994, 0.04118249278455492, 0.0021869179204992593, 0.021769725191857547, 0.0046245898251541925, 0.028961111280706622, 0.01527756191564784, 0.04642576707767383, 0.021997377794656544, 0.025402025747743827, 0.02925985875809866, 0.024220913520924026, 0.03298368192307892, 0.06483161551577431, 0.03360827723818441, 0.029651019421796647, 0.056233446849810506, 0.10693554736433492, 0.04770508028506752, 0.05482092627414292, 0.04064884742782001, 0.033400812967410015, 0.030678121162758722, 0.08045672949764036, 0.028096491042825005, 0.04109330482841019, 0.058078094640926975, 0.03612709006354694, 0.04075397001278978, 0.07348452499436756, 0.04649293383643512, 0.012405534676696747, 0.07618872343652672, 0.08966436324220511, 0.1022068543299552, 0.019823923151219086, 0.04378787737580077, 0.021025279251437996, 0.07346462203009475, 0.03265923985670651, 0.025660630217903567, 0.009877805545505498, 0.11794547189868267, 0.056578140450461264, 0.0237280355330797, 0.05926553092356171, 0.07467181572029669, 0.07095610542643456, 0.06849533908309476, 0.08203071842510855, 0.027908169394058567, 0.02700312461163248, 0.0482167580705737, 0.040778193712955525, 0.08420469209311471, 0.08657984045003692, 0.03385506863255174, 0.016658534032983646, 0.08822942693387309, 0.053178292038219596, 0.07471706087310469, 0.08632536902422867, 0.06662462131991502, 0.05927982612422878, 0.029977805717217348, 0.0656631043661506, 0.10738249838111863, 0.034933295251140674, 0.06013805527360209, 0.0475656024871334, 0.013179401266238382, 0.016451224895013918, 0.01570169500360686, 0.024508320981816902, 0.005128679030965413, 0.04894701989307519, 0.01723697638109086, 0.03200409103996091, 0.05111858421455949, 0.04453344563502939, 0.020105931607465592, 0.009406147235553832, 0.0230449149309988, 0.0723235723712752, 0.04251231416879643, 0.01459271378529769, 0.051397999463182305, 0.00545069690786242, 0.06040812041910906, 0.0641744269899303, 0.04528663263866498, 0.045976360749092796, 0.03557517734025756, 0.023971230144642537, 0.03659547622045202, 0.1044659173837112, 0.03775126924137435, 0.00807907323413078, 0.04829272334914535, 0.07605425202317777, 0.036102467997660564, 0.06088348563700434, 0.08174780215467177, 0.05309932369498476, 0.01633298880000028, 0.019103369577938033, 0.06343910515668892, 0.03970873114022036, 0.011381710834440686, 0.03771447020793154, 0.09129482051057201, 0.150970357860769, 0.18340216919539437, 0.04426519611790296, 0.05861444045759498, 0.09123076789922292, 0.3597864520645911, 1.4651275882797858, 5.595353226507864, 13.490460726522631, 28.79074815780886, 39.31326512367495, 50.91753844291934, 76.37608605046427, 80.10331046196723, 78.97411500253986, 83.71817465751403, 78.35444327323668, 79.19279498438682, 79.34088799261278, 71.59357932306105, 69.3693208694458, 74.28048133850098, 66.92934774583387, 65.50129513586721, 69.57831259696715, 59.034342227443574, 63.71840923063217, 69.5339584350586, 68.85753785410236, 62.1365487190985, 83.76212089292466, 72.74637176144508, 81.0364580154419, 77.28231045507616, 78.82351167740362, 74.31713981013145, 74.73447999646588, 78.40506538268059, 74.30976575420749, 76.80790762747489, 83.0766474816107, 75.4500929001839, 72.59137538171584, 68.69075082963514, 75.31929754441785, 77.66333733835529, 79.08589470771052, 80.59927848077591, 78.16158817660424, 72.63799667358398, 47.14328481305031, 36.6861008059594, 19.589481584487423, 5.582807525511711, 1.1825519511776588, 0.04708905366339511, 0.06954399087736685, 0.03391903314378954, 0.011906123874078115, 0.054275123102049676, 0.011016596202558328, 0.05460064152195569, 0.0554110667848539, 0.012741888452681803, 0.029070315199092995, 0.05151105871904762, 0.00354359355931651, 0.04712401408581965, 0.06595185822657039, 0.012146082721770772, 0.059952696469882806, 0.07610495172200665, 0.03659189858984563, 0.03427095095356626, 0.043920529330329555, 0.06929405469207034, 0.01051044382620603, 0.07047664929902361, 0.06039262246040087, 0.019725637900973522, 0.0532565402588056, 0.02568065958668388, 0.0319385139136425, 0.01796453965887908, 0.02826185686694038, 0.01901798716355716, 0.02327249475544499, 0.07427021710863037, 0.046311160324201475, 0.013222525313106036, 0.018657847315133102, 0.05959475720902124, 0.0393723764066254, 0.032522351435956456, 0.05759434076026083, 0.038523202416517084, 0.06054177977925828, 0.03430568921049276, 0.035772107902073094, 0.0739385699853301, 0.02249486763180504, 0.039653649418464595, 0.024361525128986088, 0.08384284578383931, 0.11330204445027536, 0.06028921591238149, 0.0245289919492338, 0.04228402379780047, 0.02132909631566896, 0.03323317377737934, 0.05471481160531121, 0.08857517773585935, 0.045892386021272796, 0.03940130005620661, 0.022247769802267996, 0.07890887949014865, 0.029538446631763252, 0.025516052189613544, 0.055475027465652076, 0.15984455183629068, 0.17477513050600407, 0.14255883502623728, 0.14445202214823616, 0.3846250143983672, 0.1967998365721395, 0.30244287103414536, 0.17360614162058602, 0.24229523966148978, 0.19743394286882496, 0.15313734480690572, 0.18550400802445027, 0.2268373167082187, 0.18251572885820944, 0.1561548732100956, 0.1448476299523346, 0.07927738310348603, 0.14715488759740708, 0.14997468870734015, 0.15420703337557856, 0.13153964082800573, 0.11265885235080797, 0.16120751418413656, 0.14810920332468328, 0.2393219145315309, 0.28470321648543884, 0.07872855005365226, 0.15523929088827104, 0.09605338331311943, 0.12233877163981238, 0.0809752714309481, 0.13562819079285668, 0.15722748823463917, 0.19826285000289642, 0.11700989468203438, 0.15349503125875227, 0.08365693156637492, 0.14077023422766116, 0.26897579912216435, 0.1198822494235731, 0.14418880965921188, 0.1502113332671504, 0.11938231576594616, 0.12308694842842319, 0.09644558202595481, 0.16913119222848647, 0.2167548028932464, 0.1878597743568882, 0.2145547822358147, 0.1555224369850851, 0.1393407141609538, 0.12693895342489406, 0.20234447453291188, 0.1674321011429833, 0.11082548903481615, 0.17080275011399101, 0.14457369223237038, 0.38502742506323323, 0.2942160673199162, 0.2058982644830981, 0.17336598837808256, 0.2331272050017311, 0.6355394326871442, 1.6774321251338529, 6.318378919555295, 15.652238765070516, 31.72500268105538, 45.491425683421475, 59.74167893009802, 86.67636348355202, 89.54553804089947, 89.89521734176144, 95.6525585728307, 89.70739072368991, 89.56303965660834, 92.73190682934177, 80.7096225984635, 81.07896866336947, 85.30255333069833, 76.94884623250654, 79.02338781664449, 80.93051479708764, 70.02499995693084, 71.94298405801096, 78.65939186465356, 80.7961187055034, 73.55187754477225, 97.85962135561051, 85.72805204699117, 93.06504941755726, 87.1783091945033, 91.76426595257175, 86.0449089542512, 86.26539322637743, 89.35922545771446, 86.30100834754207, 89.90933002964144, 96.9235477139873, 87.57624149322511, 84.33444961424797, 77.92112335082024, 85.74699709492346, 89.96097195533015, 89.67792587895548, 90.29983335925688, 90.13360331135412, 81.67623581424837, 56.91876872893303, 44.92063060883553, 24.31648481276728, 6.7217338950403285, 1.6092713826125669, 0.1725967135280371, 0.12921784283413043, 0.16719712665484798, 0.26050375534161446, 0.11798064299528638, 0.19761086321405827, 0.09874208379657039, 0.1303493393765342, 0.175032873127249, 0.08751776955661275, 0.1789531442186525, 0.20606991414341236, 0.1697757479644591, 0.1647233521385539, 0.09426139640591799, 0.15503537360458605, 0.11273495552520599, 0.17241398623633772, 0.08458817272537178, 0.1306936499332228, 0.1502726662663683, 0.12401035250795465, 0.14104597991512668, 0.13461657168884433, 0.1188651834344191, 0.17984326177787396, 0.13388273606617607, 0.2257522604157848, 0.1305988848569893, 0.08783047132554554, 0.1149109593262115, 0.158715614027554, 0.2182497315469288, 0.1553930753781911, 0.12503253596444286, 0.35524581829386376, 0.19330155735294666, 0.10540950021916821, 0.17783100927068343, 0.13573533584994657, 0.1108146335689291, 0.1681866517831241, 0.18799546385003676, 0.15971417899333662, 0.3767233690427196, 0.14647274758786927, 0.10554793230708569, 0.11590413869388642, 0.16179605357108579, 0.22175780136979398, 0.1418645295404619, 0.1044724521137053, 0.21455806109213063, 0.12206445087588604, 0.13196446722553623, 0.10448840206428882, 0.1363693348943226, 0.1861621848037166, 0.2541370437510552, 0.1589101390732873, 0.12431355478662638, 0.10640370614466169, 0.13010517183330753, 0.18475481999977944], [0.036820725222388585, 0.02343312998662793, 0.07797592995508064, 0.04599190850351607, 0.046613401162528226, 0.01071043873971869, 0.05578362683375036, 0.047603045034432606, 0.08679558613127278, 0.018524492474933787, 0.06555749148490929, 0.05970543010100242, 0.034182781894360824, 0.014084207603798039, 0.05742125085464889, 0.04731477763984473, 0.028229234927904703, 0.08565201604318234, 0.07148519639045962, 0.05697090989880024, 0.054775455125397256, 0.07454896586075907, 0.07476321000966334, 0.08992109462739, 0.08256384667249457, 0.06106176195786365, 0.04517988977773536, 0.01446690491115254, 0.013369425545416534, 0.08353120121624201, 0.010116131668309531, 0.04235895102723472, 0.04152023796773246, 0.03602102519043031, 0.015662148587345597, 0.039435751030161496, 0.030287872143690626, 0.045553721532586126, 0.01731528014305138, 0.028019830539462068, 0.10224767149456086, 0.02416085605810006, 0.060879835228045145, 0.04577236685661539, 0.02746713832170973, 0.009451881727023471, 0.025328262971954483, 0.006776307681350098, 0.050955112542836904, 0.0326332503238753, 0.06232977919881383, 0.05531135661106917, 0.03699558862154523, 0.03557868985339038, 0.11514889091373452, 0.023797027496320587, 0.04409301785692092, 0.06978950673534025, 0.37092371573371274, 0.30320292218558254, 0.4220994003117085, 3.9221676799558827, 8.340712285810902, 15.418627300570089, 32.0104786657518, 49.03433792052731, 63.12961832169564, 66.75257436690792, 70.32602617817541, 64.64190383111277, 68.69945064667733, 72.74139819606658, 59.12458812036822, 57.20178734871649, 41.43544781592585, 46.621460530065725, 55.338316348291215, 47.46273048462407, 35.47269598130257, 27.797707972988007, 33.47568004362045, 36.16020510273595, 25.747218362746704, 28.127773461803315, 43.98903631394909, 33.896981823828916, 35.47522983243389, 50.48721913368472, 34.39654273371543, 40.58619976043701, 41.85451384513609, 47.812770643541896, 57.39499938103461, 59.71962344261908, 51.32605329636605, 51.23690566708965, 50.96772516927412, 43.51697906371086, 55.21567167774324, 52.537995076948604, 52.4373431359568, 52.32020155076058, 54.18459038580618, 54.99381065368653, 64.97131232292422, 66.50911285031226, 65.2551232614825, 69.13505338853406, 54.21780501642535, 49.866378538070194, 29.181679025773082, 11.52960806123672, 6.2289194618501975, 1.091928407549858, 0.4167413507257739, 0.11780022162823908, 0.015221361705522626, 0.051918000793985786, 0.07721490587197966, 0.1149101013077363, 0.07206292627679725, 0.08120850689949528, 0.03014975032138248, 0.09335044891603532, 0.051480503302187695, 0.03286490765129847, 0.06498434280435886, 0.04701516831353788, 0.0404141410704582, 0.02141937211666617, 0.02055122978955267, 0.00595784998656581, 0.028988740241695798, 0.021268347458493327, 0.118013255358223, 0.049264582489887555, 0.0540323689910433, 0.015187056288273345, 0.06554359464996284, 0.03584742583634873, 0.036002259866725055, 0.027451722717453397, 0.020597880713701732, 0.14962800327808629, 0.027392226414033966, 0.023196270922198895, 0.10645881084905517, 0.09069433781288325, 0.046224274462269205, 0.06250392630576126, 0.03127861918220597, 0.028543947677638744, 0.01133481188932614, 0.04182756946031605, 0.011229221990722562, 0.025958460305006276, 0.02332962959283783, 0.041473533417428696, 0.02625452647466333, 0.03163357453060246, 0.03941516241719646, 0.06250651568294534, 0.09269770370015214, 0.023459496817761855, 0.047907488375541665, 0.07197300287624521, 0.05799732982150971, 0.04057125038196964, 0.012904262703452862, 0.05699683431415789, 0.10710131346939072, 0.02518578402457699, 0.03442516445272392, 0.07265764799329542, 0.018035868190289024, 0.06528388318275252, 0.05101691285568861, 0.07440164715291993, 0.07644228321770508, 0.010403257591890232, 0.034139122543556076, 0.10460947459984211, 0.07605707122673912, 0.03997866605078021, 0.09667982873056205, 0.08451580806004425, 0.0669103108286377, 0.02740663269745006, 0.04008865712450878, 0.01845407941859336, 0.047280437748638854, 0.01970566790400734, 0.04073874784573432, 0.07100095987440118, 0.017025158815686742, 0.0306426091570287, 0.009124159846725243, 0.08468002666749301, 0.055290400275900486, 0.06843818892394343, 0.01768489266865917, 0.03705030262109734, 0.06301039469338234, 0.021003321256308306, 0.0446333320090367, 0.058367220053990046, 0.05714340991671047, 0.040892474879060066, 0.012407129097189154, 0.04561778563525408, 0.01134688351979299, 0.05690250207760161, 0.005696274531674722, 0.024217073505203572, 0.006830252720148213, 0.013317306668707922, 0.031974313202344125, 0.029427208749937917, 0.052002416022362254, 0.05330031069235937, 0.08491338471010809, 0.036868873848429615, 0.04636940215864489, 0.02544794888836482, 0.06135007148728736, 0.04056987525414556, 0.0485084843521397, 0.06132523491678219, 0.07340321242208443, 0.11965298229047369, 0.05894529851033323, 0.059320773523781574, 0.13902936070676775, 0.14764031154974816, 0.7566150325921275, 0.9521367280713974, 1.3567847373985475, 8.002950126124967, 15.831550898090487, 28.895889251462876, 46.500890793338904, 62.87780215663295, 77.08136743114841, 78.47114947534378, 83.43567771296348, 74.9209337849771, 77.22947612885507, 79.57608899762555, 71.21398018252465, 65.36446325240597, 49.09317739548222, 58.43172104127946, 64.7895339996584, 59.19123311196605, 44.03136653284873, 39.87410522276356, 47.182743856983805, 49.041186378848174, 37.146308575907064, 39.592918349850564, 53.188116165899466, 46.5504381733556, 47.32393741607667, 63.82426615684264, 44.455057036492136, 49.20992282129104, 49.28595796708138, 59.98938052884994, 67.16614907787692, 68.93054885248985, 58.92373923332461, 59.472588646796446, 61.10396515938544, 53.0907747053331, 70.4646348953247, 63.16851254432433, 63.21219598093341, 61.54005035277336, 62.39829632543749, 66.57944879224225, 74.19961775502851, 75.95726320820471, 73.96687999848398, 82.44836222740912, 64.12044040618404, 59.51283608713458, 37.487433187423214, 16.817391572460053, 9.815376381720267, 1.9710144232357703, 0.9922245769731461, 0.18892857426356888, 0.00762480847169495, 0.07146855696074425, 0.032954459499207236, 0.042654503917982506, 0.13815238921632692, 0.09178045130665265, 0.04737382386660865, 0.05947101868749146, 0.02239779471569965, 0.01931100621849539, 0.09219835226934764, 0.03195518207165503, 0.06347450607966992, 0.07193998448670873, 0.020613077982899644, 0.013216888821203143, 0.013356023794791151, 0.00853486299034088, 0.020688164175578186, 0.017872072846418428, 0.036734762496405074, 0.017636690416463444, 0.050216634427347494, 0.02212428792019285, 0.02646042026519295, 0.015264292315189398, 0.07620787563463373, 0.061472714503085425, 0.009771355713206914, 0.021711153939606685, 0.11777258883681029, 0.05274711094135719, 0.07019004048479181, 0.04347326038705726, 0.02623860908281659, 0.026470712656455658, 0.024521474711476796, 0.010060403559867655, 0.019516741045780724, 0.05295315411903205, 0.08376464352852876, 0.012730271686919996, 0.05639434446610751, 0.04092764597566378, 0.10543594557431438, 0.06394099616896241, 0.15124945901334286, 0.01778554704581057, 0.036883268640526844, 0.012829506886191668, 0.09207449117374998, 0.06049675296150869, 0.06297852160529264, 0.05622175634808599, 0.06957831927725384, 0.055775088783834255, 0.06345318968317683, 0.05071853310050023, 0.03453001507648057, 0.002819084099516453, 0.10407809303292345, 0.1681942054100575, 0.19425522956636646, 0.15436703849944378, 0.144492119190193, 0.17831802668590702, 0.16155115058345182, 0.1346111784298574, 0.22071897082271116, 0.1652053746605112, 0.18831032598691602, 0.12194647333554684, 0.0952758500352502, 0.15890925041129514, 0.1832848045253946, 0.07033391945785092, 0.14099823731568553, 0.16461461361858154, 0.15956624741515807, 0.13776336976837728, 0.0991551354227047, 0.16414517026034095, 0.11716839827356801, 0.2602920392828603, 0.25782051706506365, 0.13640881906594002, 0.1871683646834666, 0.1218528803738375, 0.14403815080802287, 0.19291952462686648, 0.11066241955925381, 0.1004089838674953, 0.09131322960339247, 0.0648737809951267, 0.0955146013368522, 0.17091059997197122, 0.12390072532599011, 0.13050341497986548, 0.137557138899161, 0.15114468882881826, 0.3331844472596723, 0.10869581823147113, 0.280685851410512, 0.19944431079972177, 0.1401183853346494, 0.14464328365941204, 0.1332867656263613, 0.15556233484418164, 0.1627147002446075, 0.15530353502160119, 0.1787347785167156, 0.19365627138364702, 0.11330054291794378, 0.22026498711878256, 0.19929215041620119, 0.1783491145338743, 0.297905516119734, 0.27539693359886447, 0.9642148702856034, 1.1536439604336217, 1.869941808042988, 9.917826729436076, 17.03436532328206, 32.497154589622255, 55.338959616999475, 71.60722917126071, 88.4346051369944, 91.07431319452103, 95.24651481259255, 88.57034267917757, 87.99861015812044, 90.74812104625087, 78.54179136214718, 76.64024199208906, 61.77161139826622, 67.83636446922057, 74.32296060746717, 68.19857966515326, 55.110320737285, 45.04457358391055, 52.92728247181062, 53.063106306137584, 42.6233180107609, 44.278079694317235, 61.035735530238, 53.61011220562843, 56.010936152550485, 72.24244133118661, 53.432130736689416, 61.319495477984034, 61.37060003895914, 69.60194095488518, 78.38302166231217, 79.62618550946637, 67.35162227384507, 72.44451399772399, 72.11865917328866, 63.91637125322896, 76.81214378726098, 74.36924457550049, 70.50493332647508, 69.91140811674057, 71.15680771489298, 75.53043873079362, 81.78559933939289, 85.61515838869157, 84.99192514727193, 94.51171367399155, 75.71021664527156, 69.90257493911251, 45.181232883084206, 21.831071030709055, 12.496272267833834, 2.9735385314110787, 1.3414671464312462, 0.36576491029512503, 0.15072957642616766, 0.12136560248871966, 0.17513068723342112, 0.20560474555578925, 0.1783939613209617, 0.26065792287549666, 0.10322595045210854, 0.13810919717915598, 0.15993646706544584, 0.14054099007719947, 0.19173984115402545, 0.16248698826999436, 0.16024420458462932, 0.147630367728491, 0.13754097444395866, 0.11686472102038323, 0.12356544694592878, 0.14362558181728088, 0.16443700379421636, 0.155702467647291, 0.19879393279552462, 0.13055350180835495, 0.12180326085898185, 0.12977636689620634, 0.2073588111107388, 0.15515345839723466, 0.10931965894997121, 0.2463308069854975, 0.17607689775045843, 0.10737753413136929, 0.21592876092801172, 0.19168802296682713, 0.15923496035318221, 0.1510061341668329, 0.10227951010869396, 0.17416062073842173, 0.1457081305524034, 0.08105207174535721, 0.08574242974000593, 0.11969170803504607, 0.1004871401575304, 0.17988000335472246, 0.1422493201830695, 0.0890215618475791, 0.24301499458810977, 0.1926772723034505, 0.31578082951807207, 0.09980673916758069, 0.12754210210855932, 0.30451627267945197, 0.2279804884305885, 0.1836345696281041, 0.1424289065142793, 0.1670072900672113, 0.22859038634886666, 0.16355413342675856, 0.09855619256174374, 0.13407897714885975, 0.11345603578393498, 0.15918905636475933], [0.03550480833397277, 0.0123199597827249, 0.07715740331238316, 0.04618929488764656, 0.014187000323868087, 0.09742220623358604, 0.0827858129876756, 0.06097165086577016, 0.025372569667055242, 0.042320987540147, 0.08849519049568523, 0.04812610688649359, 0.028264178113350948, 0.012496548794930982, 0.0882304305090539, 0.045007466368617556, 0.09780375632427393, 0.056020459085102045, 0.028741284266054153, 0.01240628735808235, 0.039965435712327885, 0.05624876094741687, 0.11991801040787851, 0.050692631667780305, 0.047414598896378474, 0.08122872395981705, 0.026389834839069558, 0.02320639477411826, 0.04100162325607192, 0.017383370037761428, 0.07145652938033305, 0.06842043866673786, 0.08401108635289055, 0.055908353608702464, 0.03705289965916065, 0.028050610037039847, 0.007926139101806668, 0.021544376598490823, 0.03853894169292143, 0.03567491815755925, 0.06423274160272653, 0.035991090304789045, 0.028565248752373363, 0.10181417298172751, 0.07677137160733824, 0.03990580342830189, 0.03136951168398223, 0.023296898486272945, 0.039614529138611215, 0.044892989850092324, 0.02759786739554857, 0.007374392045030912, 0.12270897596834168, 0.0370727030320033, 0.16274879115723795, 0.17913657631124222, 2.1057337426370193, 3.688622895748385, 7.794807591745931, 14.028529505575857, 24.114300358679987, 35.509217169977006, 53.967310690110736, 62.94032865954984, 69.45933142016011, 75.30101145467451, 71.51373555583339, 65.58066037393385, 59.23370061382171, 56.188843096456225, 42.3966520832431, 44.09583460900092, 35.008640366215865, 27.65652421982058, 32.135421845220755, 19.826447656077725, 22.114024931384673, 18.618416478556973, 26.54525006971052, 14.866942994056211, 15.70256865793659, 17.15139904329854, 18.218842667918054, 14.149069824526388, 24.019224066888135, 20.56062121545115, 20.324423928414625, 23.571785573036443, 26.09086113591348, 29.38841146807517, 34.4323500510185, 39.7323586094764, 32.96996885730375, 33.37785613152289, 36.30641537327921, 30.819503914925363, 34.80681480899934, 20.578424853663293, 25.471134493427893, 33.73291692426128, 30.482072214926447, 43.39418534309634, 37.978360960560465, 36.877618374363074, 42.38108419602917, 58.2826356733999, 62.335895338366115, 59.821381491999475, 68.8423582815355, 68.50682304751489, 56.75241708755494, 47.20443456403671, 35.12398158350299, 21.611806615706413, 10.578806900208997, 2.9115599345776344, 1.1273778085747073, 0.3013298678542337, 0.15873611454040776, 0.12674327924727433, 0.017300894927053202, 0.07993400472426608, 0.005271831656911321, 0.014423296313672779, 0.04708468313178709, 0.08397573905606424, 0.07212681800968225, 0.0209096095509707, 0.027350317574136203, 0.04317268578996582, 0.04650779977260579, 0.03292922456298144, 0.04574312911098523, 0.10113859068482153, 0.008551641273492528, 0.07298479818048016, 0.02787679043268004, 0.030033538613708752, 0.05486206519567678, 0.012525843039545561, 0.051840993635837114, 0.015220683717709637, 0.006069986585287318, 0.012028048682447163, 0.11397306086315263, 0.048895952472042654, 0.027378980753823157, 0.05937008277302789, 0.038019189340693336, 0.031457470069008495, 0.034669803140024026, 0.04335207676875495, 0.052739086170350356, 0.019286929990255067, 0.08074755945633497, 0.01419652566959661, 0.05225770716224948, 0.03173540676793745, 0.02664489998301912, 0.07632536287870138, 0.02925873452406978, 0.0732728089356134, 0.006903000429437887, 0.028661538343576175, 0.08755726904998865, 0.021304612145608953, 0.017392461586202827, 0.04489375976845623, 0.03649306558673421, 0.1129556501344327, 0.09218204225743971, 0.01058225499300827, 0.061518070738642454, 0.015595186757104052, 0.05632245477529303, 0.014398587105285018, 0.03476748701124903, 0.0768182025621495, 0.041917485199988856, 0.022081888784023545, 0.04044884868386773, 0.06800382473175565, 0.031737888892812115, 0.11940604150896111, 0.11516656456214767, 0.0907690160637421, 0.05017371435138968, 0.06276075728237629, 0.04169931485047264, 0.020214624162162506, 0.03512426181846569, 0.08890456489978299, 0.038300876040011644, 0.049438492109578465, 0.03326264517982641, 0.027080438204950867, 0.09324020886373136, 0.060711035414809184, 0.07442458382537288, 0.021003512778289376, 0.07150403449251767, 0.09254368172297556, 0.020637906892525575, 0.02018835692245874, 0.04942427351770382, 0.07041048994588275, 0.026563487819305835, 0.10226045750201711, 0.08454684994273609, 0.051755716558545835, 0.0130327720375311, 0.065099983776529, 0.05231957259257475, 0.04591267585994736, 0.051104151118066043, 0.058302516267905315, 0.052717176055715936, 0.030775519666231932, 0.014934885999067657, 0.060338969492623885, 0.05257433896223384, 0.02061159943320578, 0.039183937929450505, 0.01872583378797337, 0.03769850493558953, 0.06004648861445247, 0.032303729094564915, 0.05990691888596743, 0.04677236823725604, 0.0364128676723809, 0.19417535723938098, 0.42684675524792365, 2.721540221283513, 6.259436482383359, 11.798878773566216, 20.090138796837103, 36.77978269515499, 50.33287386740408, 66.41593302449873, 78.39816201117732, 79.4046578868743, 82.61018353123819, 80.92724354036393, 75.80655005670364, 68.85187395157354, 66.7560495868806, 54.45928573608399, 55.29913579263995, 44.062910233774495, 41.279545368686804, 41.24848411929223, 31.85657858848572, 37.522911025631814, 33.63319066263015, 39.447880867988836, 22.397071007759344, 31.35191075263485, 28.29132845324855, 32.22367517409786, 23.678454429872577, 39.19154221011747, 30.27652236723131, 34.88943953667918, 39.46952058422951, 39.346173809420684, 38.93847480896981, 40.04028427985407, 44.29996651987876, 43.68857883637951, 44.928949955971014, 47.79808136724657, 46.57910677694505, 46.0489200007531, 28.28708640990719, 34.43091054116526, 43.4446152564018, 40.044018376258116, 53.36244983057822, 47.0408050475582, 46.715491510206654, 50.16531413601291, 68.06873352296891, 70.84979595676546, 68.2292055314587, 78.53672365988456, 77.98115130393737, 66.99794215540733, 58.64642373977169, 43.998104833787494, 29.26638457082933, 15.222899067786434, 5.695346699606988, 1.4885316356535883, 0.5934186315824909, 0.13467787404454526, 0.08454337956443911, 0.04680840118277458, 0.024677695360996073, 0.013215570192363475, 0.033001110423356295, 0.060337000646658485, 0.0658294220545119, 0.06050038038783016, 0.038201453149198525, 0.027774837536496982, 0.017161811664400083, 0.015667852111941865, 0.04432289786035976, 0.03215482458472252, 0.02140547528171972, 0.03831994396844699, 0.043736718024217316, 0.008461127985238789, 0.029606875520379796, 0.012863573858574515, 0.010088119663358217, 0.07291497692706124, 0.05816589980836838, 0.06687199111066519, 0.024586783707021706, 0.15387513344326328, 0.05507404938520444, 0.06476289742896635, 0.07853512817452993, 0.01934015586401426, 0.040064464067859996, 0.02793907146570423, 0.02605555237330977, 0.026636834992396257, 0.02507562632672489, 0.01735023865025611, 0.1107496310085539, 0.0403937746229912, 0.06367507172868618, 0.04924135087358375, 0.16050282054610793, 0.020469074520552834, 0.015215969404145597, 0.06444574468919347, 0.043260433500812906, 0.016014441780205217, 0.06201307845091628, 0.003807975768840181, 0.06994097763972898, 0.040093778422282594, 0.12937296031703874, 0.06989366404952542, 0.062385462299590154, 0.011041089948717385, 0.021128626427643245, 0.043911734640958815, 0.018893857937185995, 0.10317901224498788, 0.1775369540818276, 0.21138114043541495, 0.12002127139919228, 0.16098533336433674, 0.16492546145473758, 0.15196516899572265, 0.20548382623782083, 0.17139351115592066, 0.12442030147799563, 0.1855368731964019, 0.15108346308190979, 0.12209764546564511, 0.10889326207219593, 0.15065633842060644, 0.2588365948007953, 0.15649628795443044, 0.13993570400822547, 0.12151187931698178, 0.18084699017626626, 0.1976692850791639, 0.10618704115791668, 0.20050181857039853, 0.1687493433635081, 0.2391371647677114, 0.17234773495264594, 0.11967542100577586, 0.16344361758280188, 0.1771775209495137, 0.16739171298761524, 0.149604867422773, 0.19845205839843522, 0.2689166877779269, 0.1302578991218921, 0.09605773469252933, 0.1294316426520386, 0.13698692433536053, 0.16164887275907303, 0.18398059622174312, 0.1679893534991049, 0.17079875113502627, 0.07300463219683978, 0.10512220958668379, 0.1838918219530775, 0.3199125255548185, 0.14348112827827855, 0.1279843953107634, 0.1253090400789534, 0.09506846237326823, 0.22175620790691147, 0.1311199625413264, 0.15940144658088684, 0.32504902251305123, 0.2098694038126738, 0.4422115985183947, 1.0400648679464095, 3.6994236323141285, 9.709470425882648, 16.01248787295434, 25.768228538574714, 44.29616182081161, 59.32720599635955, 76.32154941558838, 92.41235133140319, 92.43264567467475, 96.08183060922931, 90.9125546486147, 87.39524764399376, 82.19647545968333, 78.57009518531062, 63.926855748699566, 65.44888050325456, 53.977316656420314, 45.01568924996161, 49.13790810492731, 35.611088968092396, 38.0566357797192, 34.21583913987683, 43.74801058923045, 24.490390939097253, 28.00535824991042, 29.024760684659405, 30.706951502830755, 24.665012897983676, 39.12583074262066, 34.80471241858698, 33.53166795546009, 38.86670720192694, 39.94627683393417, 44.76179422870759, 54.01852115508049, 56.924397330130304, 51.62610676980788, 52.02540013097948, 55.677636669528106, 48.811935609386815, 52.210637984737275, 36.60788482235324, 40.64372916375437, 50.05560151992306, 43.55451222388975, 57.52103690178164, 54.890256158767215, 54.550935837530325, 61.62500889070573, 79.2159761921052, 82.35433516963836, 78.84802649098059, 88.7079002011207, 85.20243875442013, 78.13565346502489, 68.43366299906086, 51.018625767000266, 34.098905440299745, 17.19963242930751, 7.417546183832231, 2.226737391564154, 0.7401464711273871, 0.30768894920906714, 0.27425846565634976, 0.21038213113863624, 0.14525177197590952, 0.10194433898094202, 0.11306112511984764, 0.2191688225514466, 0.19663494380731739, 0.15264945405144847, 0.11961801037673028, 0.12328832230019955, 0.15727258016986234, 0.13591555037325428, 0.13704588246201316, 0.14645799273444762, 0.33870634773085195, 0.18162867565068508, 0.2182412432927278, 0.14214399841523942, 0.12379114410930103, 0.09928498732587022, 0.07203767601881297, 0.23813803289686483, 0.15869649247296397, 0.15727330029251116, 0.09053990980910678, 0.3787604887639323, 0.11937503793066549, 0.2631867178265126, 0.1753446096253972, 0.17600555964294942, 0.1186642692153973, 0.09227783389149175, 0.10061889195874815, 0.09494467788646299, 0.06046396439834949, 0.1314411065991848, 0.21178414864886194, 0.13288604035492868, 0.12834460219188085, 0.22641118796121693, 0.30125043985824435, 0.1533511905900894, 0.13914988165901554, 0.199520705087531, 0.13258613225433136, 0.15446181889743577, 0.12000490776112965, 0.166995354417351, 0.24861954062456088, 0.10430451031894454, 0.2634683317474781, 0.26565232584553383, 0.10121222705610337, 0.14598045948772662, 0.08063081531755387, 0.1418308523153105, 0.19330262987604066], [0.03242642190607806, 0.03858668812280221, 0.042639607338294874, 0.039458274015135346, 0.008491740858693038, 0.017116587579009995, 0.08124620608624913, 0.06200625260751094, 0.0861406575648054, 0.06426310166716576, 0.03950560675753702, 0.023558546240711888, 0.05788612449842115, 0.05021159739924535, 0.0418803031225839, 0.04344604128310758, 0.016831648836453116, 0.022874410572131316, 0.044856727078196504, 0.05030696768493903, 0.036287581653244076, 0.010046672391434832, 0.006657874318695958, 0.046104508106626814, 0.07257550038517484, 0.024047783395696073, 0.02939220619267754, 0.055794601043265675, 0.037820787890063184, 0.07301193301475818, 0.010749534121714534, 0.02356377287557529, 0.07878755414558035, 0.04070543451234698, 0.022602602576596603, 0.05030170466089922, 0.046545901155519875, 0.03486584120940778, 0.02831843246014849, 0.0671771775570608, 0.10996006248939423, 0.12471025809645654, 0.04039464796322488, 0.030618718705110015, 0.06798857958206246, 0.015528939303851899, 0.031140060689780983, 0.04574676036774632, 0.025982879357592716, 0.0754557917976091, 0.10221196413641015, 0.35666583887031006, 1.2926430759891387, 2.3404334197121286, 3.266521687469175, 8.977868960749719, 16.502450743029197, 22.094583703625588, 36.62586104485297, 43.79850326045867, 70.33409841599004, 68.83383104878088, 72.64667295640515, 66.80220803906842, 67.42191114733296, 54.590567465751406, 53.161232240738414, 47.45942784893898, 42.48889054021528, 35.71198409603488, 39.24926773194344, 38.10880330301101, 28.641904015694898, 12.867939395289268, 13.448935574100865, 13.356444124252567, 24.556269107326386, 23.01282625044546, 15.041920908035772, 24.881892511921546, 20.344092653643703, 25.91777870731969, 23.905744014247773, 28.278718033144553, 19.014062035468317, 29.608081848390643, 16.84606409841968, 19.651878649188628, 18.891619366984216, 21.16447598703446, 13.788668724798388, 31.641564061564786, 36.450954714129054, 18.908811115449478, 17.690622960367513, 9.341348140470444, 9.666186090438597, 11.154323527889868, 20.48324658024696, 24.552815460389663, 32.1123210460909, 20.81108024043422, 24.223032382226762, 22.948571943467666, 29.49048330706935, 35.552092598330596, 37.727344959012925, 43.73997757511754, 63.04492650493499, 63.56438952107584, 62.32860757458595, 63.22759520622992, 61.71551758243192, 50.71182973923222, 41.8239938828253, 30.28073499279638, 13.361388271854771, 8.794132394175376, 1.866246077322191, 1.5423074532901089, 0.6713581493785304, 0.09092809422121895, 0.08341408935525725, 0.03453864122650797, 0.024364463076175704, 0.09666497428571025, 0.022209239410116308, 0.07103236947929667, 0.09198493549540158, 0.006376242681947207, 0.08490818297310222, 0.005628744359954351, 0.06862008117980535, 0.014584313631207954, 0.03368975068893164, 0.05757364872542601, 0.07785954587762395, 0.03297916966520491, 0.041723703259542104, 0.10828443667701176, 0.027370923424079537, 0.007425087913420172, 0.024246701955675118, 0.03542526925523435, 0.06567605891295018, 0.01235196885142115, 0.06680885780482523, 0.0482745134391852, 0.01992778169111379, 0.07217692015993019, 0.04897653726079772, 0.008040292905793797, 0.02770479603279983, 0.010930651671163017, 0.07313128185248183, 0.027112922248160167, 0.020302921541095264, 0.020236660681304433, 0.03100618490979316, 0.07698607540899709, 0.10600684195636742, 0.049512879247026104, 0.009488517966782375, 0.033862645242122874, 0.001634221034398633, 0.049060374092791355, 0.05948175540975025, 0.035984950110075936, 0.036970866964228695, 0.048468394971062104, 0.06089907935670307, 0.03169307849490114, 0.008836897942537983, 0.012340190249585338, 0.02767507565177737, 0.016416318098744078, 0.023976564031815337, 0.027991085005323255, 0.02087055055815126, 0.037402726048904086, 0.05872296447294855, 0.05309809412386629, 0.11960928463527273, 0.04724314458848489, 0.049818008236827395, 0.020055519191608317, 0.05377520093574159, 0.03143321764054558, 0.03197428255882715, 0.03219124823508244, 0.022537176752643242, 0.09383304600393581, 0.05174429801803443, 0.026927241687512687, 0.07930781211583846, 0.008222919648453113, 0.05900517977293461, 0.03856119271668215, 0.010140603389440766, 0.06026836299908258, 0.009249199760116397, 0.04095632447710922, 0.015815813376027492, 0.07169449161137305, 0.019115747643574592, 0.048413198336117694, 0.028504011514146003, 0.021229284635234266, 0.06146938968149405, 0.037791634414104686, 0.06738009892644421, 0.05833656121526034, 0.039128959629564516, 0.054170644030936306, 0.013645326365686715, 0.07200497172532544, 0.02055736998426578, 0.041293376350715276, 0.07740749271526452, 0.09229449630384484, 0.07258746667855209, 0.007808637972395387, 0.037723693906539874, 0.011057739912141717, 0.02662122595093904, 0.19292373811045002, 0.29207322746515274, 0.4746813465270304, 1.7473054725316264, 3.25051179816646, 4.439976436476554, 12.219250952043842, 19.619623038076586, 28.841654639090265, 48.93694154677853, 55.980573085046586, 80.5388661353819, 79.83256493845295, 82.57412910461426, 73.71590322063815, 79.13912127094885, 64.0216515910241, 64.78960852469167, 58.11888456344605, 53.52904858127717, 46.85742247489191, 47.27691604245094, 46.36417265861265, 41.649495478599306, 25.126175765068304, 27.76464435362047, 25.059654328130907, 32.34470186694976, 29.211288998203894, 30.679108558162568, 27.15710451526027, 26.793600820725967, 29.685717321211296, 29.241228449729185, 33.866873710386216, 24.618397489670787, 36.55846295818206, 16.509030518993256, 25.05629089570815, 22.517952572914865, 32.10064022771774, 27.26890971583705, 46.89292384732155, 39.14912962144421, 21.861355650809504, 25.805857796822828, 20.03247211056371, 24.348420750710275, 20.505551138231834, 29.526347498739923, 39.165658489350356, 37.70510119776572, 28.818310653009725, 35.239448316635624, 34.19217548062725, 39.260972084537634, 46.494920945936634, 45.1575300001329, 53.143601186813854, 71.55205711241692, 70.76341752083071, 69.66084711013302, 71.46527074998426, 68.84131493106966, 61.179525698384936, 52.50969125378517, 39.05385917232883, 18.98896278873567, 13.202506784469852, 3.3572186529636387, 2.4562889577880984, 0.8306886868611459, 0.12536366980883384, 0.005934107006572548, 0.037698707948889465, 0.03818536530278864, 0.013539042199901758, 0.0714602066023696, 0.004118475753198108, 0.03137411012674772, 0.04728290838219466, 0.014212849088043216, 0.06301021466272012, 0.031613468553029725, 0.013320082779823533, 0.050293691381211245, 0.03565741304848944, 0.041850946633325475, 0.013073512593344336, 0.013482067283363113, 0.08725130885478952, 0.025349931768892754, 0.0400516320951283, 0.05113038579903303, 0.05096355100132285, 0.036944774009527705, 0.02665391875310771, 0.04879382912129645, 0.0544610794543499, 0.044964622901452166, 0.02385264547962335, 0.1052200543363729, 0.009956434894833836, 0.03588758033489989, 0.012742268623814229, 0.06501051236785228, 0.04000791911816886, 0.050822380149076064, 0.019105585487259012, 0.010060452397972828, 0.05993969978824739, 0.07065383777503045, 0.05656054341084054, 0.00961854990061012, 0.08345409446666319, 0.047116824350650274, 0.02237692265020263, 0.014263209792965604, 0.09742530888967937, 0.0479027156477734, 0.04487942626339294, 0.028385932467156844, 0.08348361949526495, 0.016624167328700423, 0.034700473470072594, 0.05192650820038492, 0.041375577584990574, 0.10799559088604105, 0.15558766171095834, 0.13347419669791577, 0.15518788638855183, 0.15000666521729963, 0.14371357467626372, 0.1924018177293962, 0.17628869041800502, 0.24198871256122667, 0.16801820437033332, 0.15228928547472725, 0.11382270844713335, 0.24523569961949704, 0.24224640921719615, 0.12077667239692905, 0.17597398149871057, 0.15306537850729882, 0.19870531174444384, 0.21381964426367514, 0.2041454093470689, 0.12660175216414277, 0.10738580022007228, 0.18031803710806757, 0.12479433624614632, 0.1848949528028888, 0.14799989789964693, 0.1827331752546372, 0.1698042770787593, 0.12513927499493285, 0.18911376835838442, 0.182629048583969, 0.17043925671567842, 0.1571824422646915, 0.17457427757401622, 0.1033342216584471, 0.15877251903856957, 0.13452825707293328, 0.20221427022930116, 0.14049739967430794, 0.191814856483571, 0.14627489772054458, 0.16864062016529424, 0.18483752685208477, 0.2125993428090888, 0.23229238366888416, 0.06109946497505712, 0.19528754836609288, 0.24880910142054483, 0.15417223766205773, 0.43223324201760754, 0.45033700283496614, 0.9943117682010898, 2.630702295610982, 5.193493164354756, 7.034548309541519, 17.326352442464522, 23.7569155616145, 37.60826180058141, 59.52770187008766, 68.78431504772556, 92.2653252078641, 93.07072116482644, 92.5203420269874, 84.4926780269992, 90.59605859941053, 75.0219112826932, 77.50626994717506, 69.38799919620638, 62.336640588698856, 52.985290404289, 56.67602500607891, 53.19877716802782, 44.32146503079323, 25.024239247845067, 27.74859597606044, 24.366077300040956, 36.615564823150635, 33.465827049747595, 26.344410988592333, 38.31708508153116, 28.245307284016764, 37.492583259459465, 34.209884981955256, 43.13422241518575, 29.55977197616331, 44.77654626292568, 27.32658620803587, 33.782170126515055, 29.22227751824164, 35.12023571998843, 29.882443797203806, 50.07398174655054, 48.831990688077866, 32.890034875562115, 29.842739605134536, 19.224289309593942, 22.016365758834347, 24.877503379698723, 34.720679560015284, 38.916674275552076, 41.681333357288, 33.209657053793634, 37.617036142656886, 36.10927312604843, 47.423997079172445, 52.58865248772406, 54.77517381791146, 63.298574416868156, 81.525083357288, 83.01831399240803, 82.57998128091135, 84.97160726977934, 80.94345077391594, 70.2013183409168, 61.00745131892543, 45.99432060795446, 24.59707940778425, 15.920047413918281, 5.049612781693859, 3.167445803842237, 1.4177524658941454, 0.29653777338324055, 0.12709675221553735, 0.13652923276587842, 0.08982996846879683, 0.17022652942086422, 0.1826095899506923, 0.12603452534324702, 0.14414719576316495, 0.1960937180105717, 0.25210784537897957, 0.16029072144339163, 0.1715921424329281, 0.14902774274589556, 0.10608052429292472, 0.1661788119423774, 0.1507523139157603, 0.0784052609496059, 0.11096303246074146, 0.1903928287567631, 0.08496613752457403, 0.11979754308178542, 0.15907510844690187, 0.2310571741432913, 0.11551236899028863, 0.09748472666908657, 0.22670721965691737, 0.14986947419181948, 0.13969748130729123, 0.19837261508068732, 0.17793231673779028, 0.10382203580511194, 0.2134054205230167, 0.13369129069389837, 0.1860376495507456, 0.09818987995986977, 0.14439473409325848, 0.15620025625873, 0.11566584704503899, 0.16160813220325979, 0.23853091342795282, 0.12928084590502326, 0.19367638885253863, 0.12911152515199878, 0.1362755350888737, 0.19649007658083595, 0.11726709338085306, 0.16416222337753544, 0.14664957600255168, 0.10722179611724232, 0.14973122596500382, 0.22735994189016281, 0.17709110623165486, 0.10678262855376928, 0.2460014044998154, 0.16853932801994587], [0.04776849704343946, 0.021767838700344006, 0.012689714034598683, 0.043612975672247915, 0.03470010191742932, 0.026311743666508028, 0.07846529926023177, 0.008838502896739351, 0.03659867080709627, 0.023702563109597372, 0.02575260673409268, 0.07237290077271961, 0.03538837829124063, 0.03994332258439353, 0.03861141744099798, 0.04472737696262137, 0.05267240970786061, 0.043528012691005584, 0.026061271219664527, 0.06334792537194106, 0.04739336293911742, 0.01784025146926363, 0.08463168651947091, 0.03254878529978376, 0.07509253588655303, 0.0119222289574663, 0.05467024827075582, 0.051289643987172076, 0.07320169299360245, 0.028230495142540144, 0.004952643038479672, 0.019075828717060147, 0.05354786817465098, 0.06537212118987115, 0.09162540277165752, 0.01691748515792912, 0.04394668740250411, 0.006365658219663367, 0.050050975574601086, 0.05534521386688275, 0.02182271932401965, 0.026109454319662145, 0.12091431541428452, 0.007218764634848002, 0.014043487157792816, 0.04097747233425898, 0.01900061037421467, 0.11742930483794022, 1.1285850405693054, 3.0992389734714263, 4.874834908593086, 7.6824321766053485, 10.716589958437028, 11.985753236278413, 24.940588820365168, 41.27877266176286, 43.95317016109344, 58.00829725880777, 72.24984676607194, 70.1642676322691, 71.34123756039527, 59.046529031568966, 52.14248680299329, 46.047927641099506, 52.980701231187396, 34.200133969706876, 31.044471456158547, 26.216957492213098, 28.506766596148093, 12.839828748856823, 24.014717263560144, 53.051962852478034, 15.908856891816663, 15.971733466271433, 18.239595928499778, 15.118919976295965, 46.89450456250099, 43.25678079358993, 22.444731727723156, 38.573733606646144, 51.837424462841405, 49.161026554722945, 48.72395684642177, 40.68228998491841, 35.72690871454055, 29.27487846343748, 38.27720634398922, 39.68439586700932, 37.37708122499528, 31.1115086847736, 22.146213862203783, 17.169190914400165, 50.843397801922215, 33.70991614557082, 33.8433708683137, 37.18152753768429, 32.067835484781575, 23.25706635752032, 19.54545101811809, 18.10010663924679, 25.903632679293235, 41.349642046036266, 21.81318110035312, 23.160170085968513, 19.244346349470078, 30.236400442738688, 23.31002227721676, 26.732254951230942, 30.180998925239813, 42.87662075411889, 41.743573527182306, 50.59536672407582, 54.65463153777584, 61.196387967755726, 59.61379397299982, 59.3345957417642, 58.91292133638936, 45.43498277664185, 25.214087847740423, 15.826324339835876, 7.358291918231595, 3.871536254882813, 0.9500740516570307, 0.20610066491269297, 0.09428962674592772, 0.11059703395491648, 0.016705290294222293, 0.03622331836771581, 0.013446851179093845, 0.05830460385749898, 0.035043171411680604, 0.12533693334027646, 0.0007282713106119886, 0.051720510987985524, 0.027996844071294033, 0.027197969499074166, 0.02403548385407175, 0.06111181431239652, 0.011299827526653967, 0.043260659496750564, 0.03884577139791462, 0.007578205428041158, 0.026990798256930806, 0.01529647566888842, 0.037924837951938954, 0.06271851519423147, 0.038795351321178104, 0.00874406245026377, 0.0064487892931567575, 0.023809855638612664, 0.04199761416642897, 0.012262187177135099, 0.027701026880212372, 0.012340668096928107, 0.08983144701849069, 0.02851475972772366, 0.03854728055997722, 0.08323533039900564, 0.023206915713906772, 0.055435489667879964, 0.06140531408750723, 0.021733860785682357, 0.021250375035789706, 0.04352707040285872, 0.019228102098549568, 0.01810386423922835, 0.048317414362944906, 0.031036866731160594, 0.03225098394097821, 0.03177439489762389, 0.038666502993193366, 0.05408342109031735, 0.005758104530433494, 0.024580034472408797, 0.044098755855473785, 0.08694797634117066, 0.028009338965339046, 0.007420028381485253, 0.02541926272604014, 0.01813729440102414, 0.008903395331975435, 0.06509491227447026, 0.025002196799182606, 0.031096807365576108, 0.035223527661254334, 0.019723297502364845, 0.02822010315984728, 0.0360573913841959, 0.05929291473641511, 0.029904730505340045, 0.03602267227946751, 0.05161610469522496, 0.04506230677267717, 0.04779432186736696, 0.053335018305768894, 0.07535923407563279, 0.023281770164988214, 0.023829281713152607, 0.05019135735628586, 0.030042746990558603, 0.05427078704439825, 0.03060371678833279, 0.024585351122603304, 0.03948755772604097, 0.04622486818041052, 0.019815831347518874, 0.021074115441391067, 0.06318660257684608, 0.10486685715976263, 0.02426483908728246, 0.047956131128293854, 0.06048225091710206, 0.04470191603045791, 0.016523873012873436, 0.053452314027855476, 0.018751189383047245, 0.016108670594891714, 0.10445847100908719, 0.10308286054961144, 0.03286871510828215, 0.02468389109708369, 0.05259682364281147, 0.040399796074076046, 0.15425267689410718, 1.5734098875714888, 3.8401928399839713, 5.792790141797835, 9.927777782563242, 15.341732175119462, 15.45821087975656, 31.516756203866777, 49.26949970183834, 52.96478817539831, 73.57272101986793, 84.4942940435102, 79.83720902473696, 80.08125889685847, 68.13844188567131, 61.88617598625922, 59.53447580337525, 63.792220392534816, 48.57937043712985, 40.76259266945624, 37.85275882290256, 41.409654309672696, 28.482463590560425, 37.914324345127234, 62.166095933606556, 29.366144172606933, 26.6723289797383, 27.020690364222375, 19.796561156549764, 57.52381001749347, 43.986890777464836, 30.399718130788496, 44.22399413201117, 40.03782495375603, 44.52407506204421, 35.74403770508305, 34.01018534937213, 26.9370222860767, 30.285708558174875, 29.160304069519047, 32.621374091794415, 32.53892783195742, 25.568805433088734, 19.738121763352428, 16.072270677935695, 42.31214069551037, 33.14047036632415, 28.393857248367805, 23.160521138098932, 21.127515492900727, 16.54008980720274, 18.521628072184903, 24.111503708747126, 23.264675755654615, 43.63693691069081, 26.400949993441184, 22.891360252134263, 28.89504005832057, 37.5468570955338, 36.518415558722715, 34.2342625125762, 38.06101706720168, 52.33949176726803, 50.50879216963246, 57.314277002888346, 61.335114356010195, 69.26902586413969, 68.33483496019917, 68.49758194338891, 71.98277258103894, 56.959659437979425, 34.574916439671675, 21.758491493040516, 10.359147306411497, 5.355388993217099, 1.6783525338096006, 0.26280931227149507, 0.2081715078243325, 0.05178941676633493, 0.05833667229800936, 0.01893303950407332, 0.01671532796125018, 0.13084714330973166, 0.08199309584714713, 0.06365442565912682, 0.0514865170923933, 0.018040585376682784, 0.015541135423606443, 0.01969310789248876, 0.018938216343221646, 0.013851270909541318, 0.0535186265985812, 0.05449659529051954, 0.025397620742179217, 0.0625350371363663, 0.011434729864460327, 0.01853774771124365, 0.04068665003644363, 0.018973341474549908, 0.012796989326635677, 0.027783969304554408, 0.05227710450849226, 0.024218862320506768, 0.007234013136175852, 0.03982804550398742, 0.047965894918888814, 0.02205644508883838, 0.02323938826579721, 0.003579295411210267, 0.010610544704832138, 0.07576560541506737, 0.02956681869803898, 0.03830256526388469, 0.0060924545076916055, 0.016719763610331763, 0.0150277444739796, 0.019671151812578884, 0.06642925357746501, 0.042492529948151885, 0.010138500478088616, 0.004901546889149975, 0.03175644737277781, 0.027830532128592173, 0.047626889521075834, 0.012215492202930394, 0.00978965659610807, 0.023037910972151066, 0.049762528149351004, 0.05276000803156246, 0.0896409515952391, 0.18061181650527064, 0.14966592463033815, 0.10426594545283627, 0.13405325191636241, 0.22210940508352173, 0.10039414474440199, 0.09335602603612408, 0.14604995898421735, 0.0798185705958355, 0.1421259187402264, 0.19965261010633362, 0.245011618901645, 0.13188356834073223, 0.18061226083626672, 0.11475237912588543, 0.13307671963928208, 0.20438750845290002, 0.08953291787615708, 0.17494319487483273, 0.18694324208603752, 0.1513002199992057, 0.25600121146248234, 0.13536517748669272, 0.2577962473996224, 0.09096929442978675, 0.1655432960439113, 0.1456148670085015, 0.15305382590140068, 0.1694254619219611, 0.10376416552331179, 0.18427868103308065, 0.2809316430601382, 0.14282963178571195, 0.15898993479148035, 0.18395223564678626, 0.16092229964992694, 0.10178312343815643, 0.12884275086464422, 0.10761116030475787, 0.102989642970985, 0.2046212265568395, 0.18282683716425974, 0.10611850693221055, 0.11086878066341724, 0.14559876384033313, 0.08718085940927268, 0.4332947640890076, 2.4771103695515664, 5.628091779447371, 9.16905116650366, 13.006897203383907, 20.056881020146033, 20.414603141046342, 40.40016958790441, 57.79451239493586, 65.24350127866192, 84.68205790365897, 96.6955795595723, 91.83060892166631, 89.0779915163594, 79.4510595260128, 72.90799694676554, 67.11008271863385, 72.6707249303018, 52.269736336123565, 47.32697725296021, 43.483693830428585, 45.395939503946614, 27.084162158350793, 40.667573252031886, 66.47536477734967, 24.940349555784657, 23.614582553986583, 29.001189201108872, 23.01875295177583, 60.7580356444082, 56.53186613513578, 36.98013736355689, 56.53406266243228, 69.27311297385924, 64.95387738750827, 63.037556371381214, 59.016722940629535, 53.5269618803455, 46.780830352537095, 59.26450690915508, 57.79044097469699, 58.15180109393213, 47.8010662909477, 35.029370092576556, 30.306655976080126, 67.22406679584135, 46.462686907860544, 49.5271013629052, 52.594300700772195, 45.89255079146355, 38.41006486646591, 33.181541504398474, 27.654592452510713, 36.96211799498528, 57.20054787974204, 32.930560804182484, 37.11785962504726, 32.61332734938591, 46.714758026984434, 39.59108268060992, 40.14231689514653, 44.96409831508514, 61.80350811250749, 59.36061282311717, 69.37162722310713, 72.26297101666852, 80.21274458977484, 76.7508763651694, 78.43439686682918, 81.24573215361565, 66.70669832537251, 41.33155991954189, 27.455153657544045, 12.752063755066166, 7.44280134477923, 2.050150815517672, 0.461957422836173, 0.3430101071153918, 0.22093925174445878, 0.17374301088913796, 0.101944875242489, 0.146661481008895, 0.14916315644739137, 0.15988516981803602, 0.24238548481897002, 0.20146246218392927, 0.11886247914404639, 0.11226266231988707, 0.17177200455579067, 0.13654772612837054, 0.13436920189809415, 0.09732283696892763, 0.1650246851626904, 0.14148064288160495, 0.16165460309674665, 0.11392953174729502, 0.137683282936773, 0.16320662062254646, 0.12764403776776406, 0.17120560510985314, 0.11298142133220551, 0.10763664804999867, 0.10373542190439279, 0.1352314645003888, 0.0594262293569984, 0.257932978772348, 0.1116301035208087, 0.3338325576436135, 0.11126259582177286, 0.1397969808068968, 0.17510652482028932, 0.281244850447101, 0.1739808199025931, 0.1442318025135225, 0.12920760789946203, 0.07489668550871073, 0.20795447511538384, 0.16251574721067183, 0.13778607661445297, 0.164965481887902, 0.10078042159758269, 0.13628891098403162, 0.2089754864573479, 0.16492797422312921, 0.17368045214924122, 0.13428649504578885, 0.10999816770274794, 0.1310166019585825, 0.12958484491513622], [0.07323764549988894, 0.0670386688603509, 0.02173736755315575, 0.025572229417101033, 0.0569223475852801, 0.06859886054430278, 0.04116139472312024, 0.07141879188918299, 0.02461940373083757, 0.01325377978519687, 0.048288122991160046, 0.046375956040837114, 0.012020718178621704, 0.04130332017197244, 0.031984255108381474, 0.05733951310356779, 0.08904166399471222, 0.043870450162719336, 0.02416874293328053, 0.048323960584257884, 0.08816353571150573, 0.023487964645028118, 0.054942090740247126, 0.062330506982341896, 0.013947554755084699, 0.010864542113737235, 0.006790655071757013, 0.06075511611397229, 0.01922171675570069, 0.0332414360356427, 0.029200749329080986, 0.03059423836548963, 0.022547819629131306, 0.069435742653666, 0.046365633006057436, 0.07442645307990813, 0.06714016018855958, 0.11970948893576862, 0.01882426651014436, 0.01669158881169654, 0.021028554277314294, 0.07177912134436831, 0.06300549556110656, 0.022513650192488587, 0.05784812653737684, 0.031058365073535713, 0.4767067604247601, 2.4041939983444833, 7.894676529592084, 15.12319535978379, 21.315616676884314, 28.831989918985677, 41.46943907583914, 46.22361452348771, 53.03285698736868, 61.14063539812642, 71.26486116839995, 70.8704197791315, 67.35393647224673, 60.97149887392598, 41.62651038938954, 51.048655433039514, 45.697412875390825, 32.314585908766716, 33.685079697639715, 15.151537426056402, 17.741556898240123, 7.098628071046646, 11.123099500133145, 14.575957059860231, 9.918312122744899, 11.19814326686244, 24.195679733830115, 31.47124690394248, 34.45563324036137, 49.270080212623846, 38.40891953437559, 40.368774937045195, 58.07605228116436, 36.10247958090998, 49.7055378267842, 39.02789700415827, 40.247565853980284, 37.63511042441092, 28.821648590026367, 25.99239787747783, 23.12034037805373, 31.713576816743423, 23.624947417166926, 34.83591487330776, 42.8241825872852, 46.9249225431873, 31.82379737977059, 32.33020478679288, 37.13144671532416, 51.970706601296705, 60.37808349055629, 42.77351340939922, 58.54157094032534, 43.791172350606615, 75.43422299046671, 51.828559906251975, 38.83121759660783, 55.258123490118216, 39.59142000444474, 36.542059606121434, 16.958840085614113, 31.82857482664047, 38.08045633377568, 28.230761174232732, 26.43955788304729, 39.69394291600874, 33.353819847106934, 40.635398049508375, 52.64418932699388, 61.056641763256444, 56.754511633226954, 60.88494393133349, 57.96260949104064, 47.08951304035802, 36.82460361911405, 25.656176228677076, 8.627825860054262, 3.402031977330485, 0.34504459149414496, 0.1734314276085746, 0.10419147404571695, 0.03964878476014541, 0.006714956966348954, 0.06294602415554466, 0.07912096327110645, 0.04884717565390372, 0.017311501414364865, 0.0800963387554211, 0.0326732516048416, 0.012024565855221403, 0.044342747198477875, 0.008164829116374736, 0.03984439382029157, 0.025210524834091627, 0.027720598511457927, 0.02241144448729052, 0.0384107215570346, 0.0362754506509631, 0.007037959266228662, 0.02433165153037877, 0.07752715564903713, 0.05494540790095926, 0.038178447528832385, 0.027743341746710004, 0.08512076471121081, 0.031246935700877543, 0.09553969071637239, 0.08775492739533225, 0.03520752025407649, 0.009222995722666383, 0.05535875830138403, 0.036086295881579, 0.020651997164672902, 0.022924370996113268, 0.03977340811322774, 0.014602608768449677, 0.029711186052149827, 0.026898626388321002, 0.01671229425307003, 0.03832790362198026, 0.023516827007575382, 0.07581360082352355, 0.005609119581359049, 0.03812413955588014, 0.022596757325734344, 0.0096260451133393, 0.02523552419828071, 0.01701078126056781, 0.02915727192415826, 0.10366183149838641, 0.11169109178046066, 0.05703316220352727, 0.059045667519732836, 0.04647383143404319, 0.027343087619350805, 0.10052083270444025, 0.021520216100578828, 0.02231573712291016, 0.02701962231508186, 0.049664105003279065, 0.031367337909497084, 0.05886053854239084, 0.061785052380254196, 0.039957192606262626, 0.053398691703595465, 0.01892569272087947, 0.10085873876608188, 0.032292877459117485, 0.04678134678772861, 0.04619029080194812, 0.01802219926650005, 0.026762256992139646, 0.05192694104006214, 0.06762225165843003, 0.06440026971000819, 0.07810913732335453, 0.06803012453019619, 0.057856381134760965, 0.008318391440796756, 0.02164678723220864, 0.03576029099584107, 0.05228002330348377, 0.026638652535996614, 0.057741130867432204, 0.008222166967067507, 0.03873550836297293, 0.08156207179830921, 0.01776093455602325, 0.06940675388661123, 0.07732944367753883, 0.014042532420717182, 0.08548873972388045, 0.034784873376690575, 0.01991407063248898, 0.01832863443621224, 0.01962019738951518, 0.6184054166078568, 3.0349545132729316, 8.672158448926865, 17.424399929661906, 26.643989855243316, 36.02253775442801, 50.97147887752902, 57.73162895633329, 61.551025144515506, 72.7297487566548, 81.72563414419852, 79.78493167508034, 76.6468394187189, 70.60118829050373, 50.26686429977418, 64.3670202070667, 54.684986760539395, 42.05852024016842, 46.02313826161046, 29.236168592206894, 30.163569873379124, 19.181764933370776, 22.126525525123846, 20.003001382274014, 16.62191241018234, 22.829741777912265, 27.09231676593904, 25.5294934780367, 30.575777638343077, 39.20093236430999, 36.14165621419107, 35.144115109597486, 40.843236600199056, 32.41076830894717, 38.71429566414126, 29.722214975664695, 28.51002020220603, 23.035927049575314, 20.06926198159495, 18.374260702440818, 20.394483343247447, 22.12129504449906, 19.950065074428437, 22.963543630415394, 24.797563514401837, 30.852824449539188, 31.44651439882094, 29.736963087512603, 40.874419443068966, 42.82855210765716, 58.633864310479936, 48.31596366820797, 55.84420011889551, 32.33317990456858, 69.37998971631451, 60.5067882230205, 39.32845646335233, 54.02592658996583, 43.73498439788819, 49.5915812061679, 25.399766968142604, 34.72982260488695, 45.6392833494371, 40.150491114585634, 40.0841599126016, 50.97531495555755, 43.25372918959587, 48.797795464915616, 59.839063536736276, 67.43003829833, 63.42759293894615, 68.80750410018429, 68.54864335829213, 59.322385403417776, 48.64398756334859, 32.66665981661889, 12.250001353602256, 6.124511361122132, 0.7191410144009899, 0.15437512838792417, 0.0588292476811236, 0.05230009863753954, 0.048996083994185737, 0.04814723942188486, 0.060101030244221615, 0.005451105328487052, 0.046951893281431935, 0.03557394393869946, 0.12424891228757559, 0.06022935380197822, 0.07261504584382619, 0.03800611605026549, 0.03075664134455785, 0.0352932684754412, 0.025699555145336256, 0.02893367575691833, 0.07008763751195324, 0.09366224670121748, 0.027689870724815036, 0.014967505065273615, 0.03143268712465802, 0.07874855260935523, 0.029585591682623473, 0.02610662362478193, 0.056460067149131536, 0.04732932947996644, 0.02849190157928294, 0.04148806993579192, 0.047547319798820445, 0.03257249955147986, 0.050748923808456435, 0.07345329158969464, 0.03475579650952451, 0.032537087137179996, 0.0656878030408294, 0.041303117158672506, 0.03286712547583926, 0.05020233156580118, 0.029578486217125773, 0.033181796090737466, 0.02933803420033186, 0.01965275804151691, 0.043126938849567406, 0.00548323936527595, 0.02360384501967459, 0.06716022403129647, 0.012755618663504721, 0.05935044027864934, 0.012284663239223583, 0.05769592784946004, 0.2506157359288585, 0.24346314070205538, 0.17124496670740266, 0.09870809247537006, 0.1761957486310313, 0.1798582464576729, 0.17606453309136053, 0.20248054707002258, 0.12526271474217215, 0.1420543508063401, 0.2004807817959978, 0.19391286487300552, 0.13694978439279143, 0.17681528393539692, 0.15822930141322075, 0.13280227630128785, 0.22342843994978936, 0.09585996909487633, 0.15910760589664982, 0.10844722270004212, 0.17646410923090675, 0.1025796710183063, 0.19074262450298957, 0.24051877369563426, 0.1669789448140129, 0.14219911078051214, 0.12872699497928544, 0.11250812455170578, 0.1536089178895758, 0.10967632650487846, 0.14691704794043495, 0.14784594487038352, 0.08458301695364137, 0.13750479977217414, 0.1273923395802417, 0.25920450086555175, 0.1847625268442977, 0.1778534096815894, 0.13695254230931883, 0.20185785548340893, 0.08288848409128767, 0.20165779928286232, 0.269668250675163, 0.13992381432364065, 0.1896555304166771, 0.10062312842496943, 0.9076394609385922, 4.901667352645628, 12.69781541439795, 21.951764322096302, 33.65266130816552, 45.51061391830445, 60.76689627862746, 68.47549115457844, 74.47167335018035, 84.7223328005883, 93.25245241965018, 90.91050717138475, 87.58680835846933, 82.55239917385964, 59.892031223543235, 71.4322522378737, 62.303857418798636, 47.32533770222818, 50.449893859124955, 27.939113340070172, 32.63549658559984, 17.96343361177752, 21.032299956967755, 20.8884136907516, 21.94489625192458, 22.367900340787827, 32.49727422191251, 44.23963654425837, 49.714198420124674, 67.31143366905951, 50.06696462631226, 53.204307709970784, 73.16158602314611, 50.63292341847574, 64.94447546620523, 50.061092838164306, 51.44341061192175, 47.53605919499552, 37.769526127846014, 33.98380348759313, 31.498258306134133, 41.07077329389511, 33.18208279148225, 45.29311456987935, 53.029126813334805, 60.05886139408235, 41.05788046313871, 42.95930039498114, 51.20986092475153, 67.11767642728745, 78.58031688197967, 59.399793378768436, 76.20204264117827, 59.93253361794257, 91.73543653180523, 61.114488878557765, 53.78226895486155, 71.75606742981942, 53.77796219241235, 52.656521258815644, 28.85853652031191, 44.53707771916544, 52.65911394549955, 46.44220821319088, 43.651990967412154, 57.15084360491846, 51.12917384793682, 57.81209638041835, 70.19858052653652, 78.21101004077543, 73.07851806763681, 78.68300453309091, 77.73591687602382, 69.84872864138696, 57.8766978171564, 37.39851305561681, 15.986728687440197, 7.18483784506398, 1.3080861828019543, 0.3522286576128775, 0.21503956267429938, 0.25174278916130144, 0.19013738439929104, 0.11561912334253711, 0.1680026834289874, 0.15071851411654105, 0.10998687556674404, 0.18829842098057273, 0.17856029433108148, 0.1486964556839197, 0.1708956152921723, 0.1439993714372958, 0.1555066708956034, 0.16844647816352307, 0.14997277348752946, 0.18200252655773394, 0.13915213395751294, 0.26131164102304366, 0.18057041711384253, 0.1382815363186021, 0.17620610613976756, 0.16904065595759502, 0.0922213425679553, 0.17017753043722722, 0.0988925128213821, 0.11587245329733818, 0.20460228886335127, 0.13665313982675154, 0.22358783220331516, 0.1611992557563128, 0.24436027562666326, 0.16771558431848405, 0.1326692527941158, 0.19076936097154695, 0.18700858938597864, 0.14049554574153117, 0.10361910677484928, 0.08480975599659067, 0.17406659110659556, 0.10338680593356972, 0.13985486641045541, 0.12698777620830845, 0.12096934350988559, 0.17658928799773418, 0.15689673743421034, 0.09526381479395975, 0.13231890546458383, 0.13352842040119633, 0.10704147434162517, 0.16695528801891113], [0.06164554776924272, 0.06651468770278078, 0.05066820878475424, 0.02920062100935367, 0.04189230005947813, 0.021606242028816093, 0.07668597578641868, 0.0315639601209231, 0.07669468620611776, 0.05922434220631277, 0.017270289714478197, 0.05260565663657842, 0.0416172132076275, 0.03917958655004059, 0.039452344494601416, 0.039798282988129124, 0.12642206624150276, 0.06616896754431148, 0.022033004713575208, 0.04696847142411336, 0.08492086938912831, 0.029052679855076056, 0.075632382725035, 0.04986901820126561, 0.07623699463663564, 0.022651367903416677, 0.03008589497767389, 0.07399115426045272, 0.03043433666349419, 0.0166050304523519, 0.044229312559529665, 0.11263238401302408, 0.044363416250674956, 0.017014845357006116, 0.10992753439612928, 0.014208767754626612, 0.042285249538479314, 0.05506957926216626, 0.04992226897288234, 0.06051356476100703, 0.07013277541245184, 0.06319921621451936, 0.04017514462072042, 0.06655611773772586, 0.10505816463621394, 1.3297279828017758, 4.895315564447834, 14.720738607068217, 18.837229820989794, 32.435185063269834, 49.291704239383826, 60.47684092675487, 74.6678153930172, 68.5600653002339, 69.92523839396816, 64.81100113161149, 63.87830465070663, 53.89739051941903, 49.62418002467002, 49.51134520192301, 35.65146584664622, 30.13828039169312, 23.49808031512845, 21.24835979553961, 12.605918203630756, 14.806789525093572, 10.944612045441906, 14.524019975816051, 16.22823980546767, 32.97612305610411, 33.38293560089604, 30.533276796340946, 50.25071590177475, 58.83501522002682, 46.501659577892674, 45.18601425232426, 48.81570892949259, 38.176201389681914, 36.30330885610273, 27.71318481814477, 18.80938099276635, 14.832819354149605, 11.668555082813388, 10.053927090860183, 8.619103489383575, 11.559804428008295, 10.28461148661952, 11.619394056258663, 19.228594110858058, 12.045372282305072, 11.57160193689408, 6.47999478924659, 7.131245030510811, 13.903937378237325, 17.148327827453613, 21.011111313296905, 21.9036486071925, 22.759531351827807, 28.905506903125396, 50.47360066444644, 38.186772177296305, 46.59956585976386, 44.50799726670788, 41.17424149667063, 45.02296916900143, 43.38741533217892, 44.05199427758494, 55.24028062820435, 41.654112108292125, 20.40944718545483, 18.424639624934045, 19.819801199820734, 21.96373147349204, 26.72844829097871, 35.80222998895953, 41.67294340748941, 49.559217729876124, 54.629183200097856, 58.84538596676242, 60.61548494523572, 58.331696679515225, 48.630208276933246, 39.46504515986289, 25.048905072673676, 8.649584227992642, 0.9048999918083992, 0.21167957764719764, 0.020735020028246988, 0.06814142178383566, 0.003921031912473301, 0.018470079164891955, 0.0834453993687226, 0.046934526068188494, 0.005965519484297763, 0.015964350163666232, 0.06499039489896068, 0.028507897495141918, 0.03193687257026473, 0.029424121415603067, 0.03774011117075721, 0.05506748784213297, 0.03675431689067233, 0.02603812195781258, 0.056367918263159456, 0.023095264144602324, 0.016007993235102585, 0.021480168854337067, 0.03307919010459896, 0.03826223839555056, 0.0801291962664935, 0.06721043343385381, 0.07045241793797863, 0.04128499534882365, 0.057562460011291894, 0.04714011725398803, 0.05934767087080306, 0.1524280393195729, 0.023825753878261295, 0.053218396741055676, 0.056908898911769354, 0.030545553477901607, 0.01793295959942043, 0.03880201245567972, 0.059966608626587745, 0.029138772816006697, 0.02560822597344316, 0.012260077562513612, 0.098420686929697, 0.0283385863182165, 0.038058677342750376, 0.03965014839665063, 0.024311890292371956, 0.04648388250760975, 0.09472081933410899, 0.03628276679063997, 0.0880664723714994, 0.032854622920915004, 0.03166480602005557, 0.028000272314755187, 0.023873190042532744, 0.05635649589220843, 0.07340540343354787, 0.09775600606395353, 0.06774335483750028, 0.015117006166087044, 0.07956109610536406, 0.024980932113624392, 0.05959073907785839, 0.04610627393929228, 0.014334206033738391, 0.030709115164955298, 0.02637843353553645, 0.06000354555585693, 0.035647342822724776, 0.09963577132551901, 0.012806001393454931, 0.03925051863094972, 0.023824060823948636, 0.10660091249812996, 0.09504595471005287, 0.026503367154228113, 0.03476232357863938, 0.045962103852821935, 0.04682155491243448, 0.0396775245486248, 0.01597688719254708, 0.06495520081971923, 0.022814456531177127, 0.030759795711586074, 0.03914209420702631, 0.05489295386078377, 0.049926532252180966, 0.0383185688406229, 0.0682960259878347, 0.06604035670358328, 0.017756330367598324, 0.05215935296409073, 0.03107149390533807, 0.01664565609497649, 0.04842914445626159, 0.08488975089764403, 1.5515891294325552, 5.8775697215910885, 16.433260133189542, 23.890138864517215, 40.55799791889806, 58.46429632556055, 71.89491148917907, 86.49814667240267, 77.22506738478138, 84.30289022384152, 76.64905163549608, 73.51569760230281, 63.53592880310551, 58.62192853804558, 58.597782427264804, 46.14186056198613, 44.805120729631, 38.84304746504753, 31.6399323555731, 25.78949562964901, 22.019107495584798, 22.58088896351476, 20.313815878283595, 20.14511669835737, 23.028039163158788, 35.84508972783243, 38.52282908654983, 39.34862921314855, 39.773959267523985, 37.19558923475204, 38.73171491007651, 30.826444548945275, 29.589530998660674, 23.215926577967984, 18.813797581580378, 11.836095202353693, 9.777945203165855, 7.699141473539415, 7.8233496988973315, 5.949546685141902, 7.417728574045244, 6.942343192715799, 9.29212337540042, 11.273742048971116, 9.646999816740713, 9.63724684330725, 7.534254347124408, 7.677570889073034, 11.31030148075473, 12.353694112070146, 19.258366861651023, 22.081885030192716, 26.061478660952663, 36.773805003012384, 49.17995199080437, 49.37397595374815, 38.29996001335883, 42.59573590370917, 50.48022947003765, 45.72536760760892, 44.30249644863991, 41.79833765952818, 59.85549434538811, 49.51893498820644, 30.465782611600815, 26.857737456598592, 28.073329002626483, 32.00527171934805, 35.37856694190733, 43.821323610121205, 50.41494554088962, 57.90085177267752, 63.01976842264976, 66.82157670297931, 68.8894973262664, 67.29761908131262, 58.594099321673, 53.48234884200558, 33.524446871972856, 13.86915478014177, 2.0034285226175865, 0.3326791050212999, 0.07251213725295759, 0.11884615381037998, 0.06256436298210775, 0.020730553735648433, 0.15282766142439458, 0.07185766833924478, 0.02580346348094604, 0.01689497749471376, 0.014154397537030522, 0.06803709593030714, 0.05882444047939874, 0.04259893573039482, 0.013672556003345358, 0.05446646122201797, 0.02282213656261804, 0.036105827293208534, 0.020804333748416077, 0.011083610701344667, 0.0025505827309849163, 0.032214736490840876, 0.035586779741870786, 0.03484359401608667, 0.01783514740846811, 0.07666991858352577, 0.034693459935125806, 0.026181091201461615, 0.021733665433261665, 0.08334862714212748, 0.052036491613234245, 0.09038937353198567, 0.026372029040489468, 0.05823303209317308, 0.04106456887037043, 0.04021173297998406, 0.07180049519745574, 0.08416479423401818, 0.05611091491676146, 0.06104396956582224, 0.032914726349014434, 0.023906051384044752, 0.0574141645413493, 0.047253222475128795, 0.07299153975421384, 0.02749444744099052, 0.08250649733048293, 0.02980330429460493, 0.09537730305906265, 0.011622677087753771, 0.018492820484924222, 0.13433938575608118, 0.1596563699985704, 0.1363596362212012, 0.16721917466530878, 0.15698612457321537, 0.15573576182848023, 0.2326432825817216, 0.19608742076783411, 0.2098449043208553, 0.19188218029035678, 0.08459197252147621, 0.1152956273947512, 0.16394359720570428, 0.12064409322075306, 0.16235966445697894, 0.131719840029555, 0.2680589144508685, 0.20320604765607467, 0.21472595692161592, 0.10740237070187446, 0.1518364049374096, 0.15329008741724878, 0.30693950071450204, 0.3001108074620847, 0.2328736911858282, 0.1896376499245244, 0.17461918564813753, 0.19103916181672007, 0.14862816660634934, 0.1068274293755812, 0.22053328643162406, 0.14596858512490027, 0.11085617851706282, 0.1050832310330964, 0.22235919571211263, 0.12521351657567487, 0.144626276507493, 0.1579147303897527, 0.11208699835884957, 0.2254220765204199, 0.14114053048674138, 0.11520626323838389, 0.1018319232389331, 0.20516885684863215, 0.3231935882039609, 2.4835307992273763, 9.407798974744736, 20.875140390088482, 31.55427367456498, 52.51329591197353, 71.26869724642846, 84.55005445787984, 96.55893202750914, 91.5986164154545, 96.11601798765122, 88.83648334010955, 86.32830804394138, 73.01062183995401, 69.93531104057067, 67.58280677180137, 52.67874148584182, 47.01233256247736, 39.66691778552148, 36.48509894647906, 23.20948212377487, 24.235950708389286, 20.899192363985126, 22.36106953313274, 26.027934551239017, 46.90787984478859, 48.1509966235007, 44.99551257779522, 66.74624366144981, 77.05948060558688, 61.12544013607887, 57.35156305374638, 61.58603229830342, 47.237406007705204, 44.25514167354953, 33.769924486837084, 23.37422167101214, 18.399903197442335, 15.958296406653622, 12.58545715962687, 11.141953352958927, 14.485101238373788, 13.173872501619401, 15.244819233494422, 24.186115034164924, 15.670257153049594, 15.450117068905985, 9.016769066933664, 10.732473596449822, 18.219164302272183, 23.10490781261075, 28.621378252583167, 29.265986450256843, 33.14680107178227, 41.243067326084265, 65.30027758690619, 52.27294875729469, 60.435467766177275, 62.7339021621212, 58.625038977592226, 62.32656401972618, 57.45233266584335, 57.47718088088497, 71.61150455474854, 53.46157204720282, 34.061627234182055, 30.36409124251335, 33.13763841505974, 37.88561651783605, 42.133637551338445, 53.734247376841886, 60.0717620695791, 69.12933457282283, 73.91512824643043, 76.63489187917402, 79.09510443287512, 78.52741979783582, 67.70021115579914, 60.84906601136731, 39.12217509362006, 16.300881120466418, 2.890631393078835, 0.7203113516011547, 0.24033236918189835, 0.26734072234361406, 0.13709252189484336, 0.08214600699683351, 0.30145697716263037, 0.14545863103722373, 0.15596414796046673, 0.10769216644187128, 0.0958769839076746, 0.1938989527163006, 0.13593487111070465, 0.13643083643288384, 0.13247380844287335, 0.14363030091889445, 0.10642858101956307, 0.11134200849600377, 0.22391597830480148, 0.163065507226894, 0.08420244745549657, 0.14167910561926905, 0.1124816025877672, 0.15232323849153134, 0.15707401017988884, 0.31267985881816956, 0.16503783123147103, 0.1845936504222693, 0.11924989746823428, 0.19446124593096395, 0.14249894227231705, 0.2640791183277484, 0.12234165213040768, 0.13520302731663952, 0.15731333604743405, 0.09971352158895425, 0.32605875704076986, 0.20988170718473775, 0.15028516882129256, 0.1390865874747115, 0.07138654724845002, 0.1396658878412939, 0.23007662756548775, 0.09104538228242628, 0.1622886787499151, 0.11458247614603852, 0.2029247248485204, 0.1926470577957169, 0.2851963626040567, 0.11628303045947706, 0.18370546340461702], [0.02771855497191991, 0.04014015355477891, 0.04889992080749043, 0.13152237320619245, 0.04154759113706889, 0.06576487914689126, 0.03435964478299983, 0.029705641490797845, 0.04175034779754858, 0.01263428374283737, 0.025344548086004875, 0.04168899181569296, 0.05887106842091007, 0.045119759536558585, 0.03588843452293546, 0.0198843828102033, 0.11218915618355237, 0.028789884883970506, 0.04030225775955666, 0.021604512585327033, 0.04290306497545492, 0.012916395620953654, 0.05157328038025768, 0.13145561630447067, 0.10861503425985576, 0.03606777953644914, 0.034838534005346804, 0.038853780847162976, 0.01638220228825606, 0.05642661591991783, 0.039997469678881674, 0.030390598788677208, 0.037712853762411305, 0.03935454571018777, 0.0382419677090741, 0.02437502359821191, 0.02507496940632982, 0.05275857927758367, 0.050470527456772905, 0.06182819845214967, 0.07770727058091471, 0.05604538758615813, 0.04715234018681992, 0.16526339815989619, 0.5582865135323617, 10.37834240544227, 22.029733196381603, 30.58645825232229, 52.8543459984564, 61.40075129847373, 66.2237133518342, 78.55242883005451, 64.89887791295206, 58.877608237728, 61.504333249984256, 55.36298413430491, 47.197688087340325, 44.303104416016616, 33.268951523688536, 31.108643393362726, 18.954563602324455, 16.765302496571696, 12.283647444940383, 17.399998864819928, 22.43677519982861, 24.692891143983413, 29.18686636032597, 34.99506504304948, 34.437621716530096, 37.52426816571144, 34.6137910504495, 34.65389336309126, 37.91424197535361, 20.25253080552624, 13.847255206877186, 10.951200646738853, 8.867761165865007, 4.812707506841229, 4.815149182273496, 1.9433956665377465, 1.3864933819540086, 0.4121083267513783, 0.6553801906204993, 0.3498786675833887, 0.4699925513517472, 0.2800278125270721, 0.780169110625021, 0.663785278316467, 1.1190774604197473, 1.1398542552225053, 0.5810609592064735, 1.5757242085472232, 2.2264993527243218, 3.0619249757259124, 7.689186007745805, 10.63824159483756, 17.128925823396255, 23.966564286139704, 24.16853693223769, 22.010291968622518, 21.301125480282693, 39.76853462957567, 33.84071150133687, 28.53081072530439, 45.07796864355765, 67.33758018862817, 63.857492554572325, 53.73738919534991, 39.50365697183917, 38.29801059538318, 50.99838633691111, 47.94679803232993, 28.066127530990112, 22.69006813726118, 21.573477214382542, 23.576361017842448, 32.740998537309714, 36.691207731923754, 50.39285475207914, 62.0640633183141, 55.896261738192656, 55.91887812460623, 65.53554134984171, 56.734664440155036, 44.954723850373306, 15.661385732312358, 2.699983610260871, 0.7169819334822317, 0.29359216531438215, 0.05762611425692036, 0.10247205864758262, 0.06939688667414651, 0.062125819780293016, 0.00882554164667043, 0.03873917409369061, 0.021256155169178403, 0.14042953960597515, 0.043539990475701715, 0.019919546245927774, 0.008980761593838614, 0.08454403840005399, 0.026036415496961247, 0.0316933389647954, 0.053896821224160736, 0.08659035117635805, 0.05534923965892485, 0.06752171794012671, 0.022641933530629165, 0.05688768593714603, 0.05284852949121306, 0.02449604825326993, 0.0717736055113135, 0.017975781999167897, 0.05089762147455927, 0.029644203154490362, 0.018941811210806334, 0.07533783723990764, 0.021927533558599895, 0.039349393768896984, 0.059965061128980694, 0.04856290340784097, 0.05863360414702085, 0.03714863383661836, 0.021892557814416867, 0.04855589753377342, 0.05583137326363114, 0.050928713152966196, 0.05712693902633845, 0.04116923180258563, 0.07370347292312691, 0.020269004913467555, 0.07242799781623387, 0.08713772099825644, 0.020776419419675105, 0.08015420137634201, 0.09390131209886844, 0.03218626483313499, 0.07937513592262423, 0.045942859724164016, 0.03782462982100345, 0.17193819967008409, 0.050155458476154074, 0.04011895590191407, 0.05527990104089822, 0.03362875859884005, 0.07804340697945127, 0.0718361948947272, 0.023040506094994567, 0.029807736113246892, 0.07673107538252108, 0.022061397847268852, 0.043722644989048286, 0.06971760172276728, 0.053286046135209264, 0.040270258266959465, 0.011550598747787938, 0.0458316084358, 0.03596030123111221, 0.03300228636832007, 0.09263520624728934, 0.023135715502224142, 0.09304001476735839, 0.00961568090133369, 0.05561362043203366, 0.017827628255491296, 0.04240907232968077, 0.009116554508856949, 0.02694382940629317, 0.06036159589946751, 0.026147653378786582, 0.007812486127800038, 0.022805968276976098, 0.0400878029364732, 0.038767316333589055, 0.07773041409710724, 0.05436019716604103, 0.06740345694725552, 0.09492861302269083, 0.0249575779232527, 0.13145006982789886, 0.9243947231481153, 12.183620141398523, 27.744110745768396, 38.55576130651659, 64.51402671875493, 73.92491848238053, 77.66350992264287, 88.45511128825527, 73.68405357483896, 69.49944157754221, 71.32062158276959, 64.8558416674214, 58.563140053902906, 52.69744726919359, 44.86048498461324, 41.76029066885672, 33.24539769080378, 27.831512920318115, 25.71564720522973, 28.418650550227014, 25.307408878880164, 29.88992375712241, 32.32067342727415, 23.883255104864798, 29.9967691206163, 34.36232005396197, 33.392070801027366, 28.689978545711888, 24.809987621922648, 16.551601963658488, 12.021924353414967, 8.464526803262773, 6.622378297390477, 4.441531656249877, 2.853111225751139, 1.2583843594597233, 0.9073630564155117, 0.2901468227707571, 0.3813782112011987, 0.22789206656236805, 0.40025026627605964, 0.44730353980295123, 0.7585529898924213, 0.7086369683665614, 1.300651452714397, 1.1942407368652284, 0.5523894138393864, 1.0851607255397306, 1.4645168016995154, 2.2552562096426567, 4.940545885793624, 7.183095822411199, 11.763991252068552, 16.076709820378213, 16.93324662023975, 18.039305979205718, 18.64875012828458, 31.93546921976151, 31.355170242248047, 28.43150611846678, 42.637603282928474, 62.96879722226051, 58.237202859693966, 52.81022325638802, 36.72992152552451, 35.83141242304156, 49.083563666189875, 51.44168084667575, 38.47045760000906, 31.195920052066928, 33.40476751327515, 36.93451627608269, 43.47612757836619, 43.55023684040193, 58.6028697413783, 70.0162216924852, 63.739362532092684, 64.52152236815422, 75.30964851379395, 66.27886187645697, 54.946773590580115, 23.910297886017833, 5.815265322885206, 1.3386214668712308, 0.4178204008888814, 0.030259777784287453, 0.035487755216778286, 0.06918913128996088, 0.07440184633578024, 0.018933485750289216, 0.052245411451064774, 0.03285499830399791, 0.013116714206614323, 0.03869490187254645, 0.03302152666653837, 0.04138570143690994, 0.02624690964547617, 0.05754733360522697, 0.03323304737287183, 0.03228898573246214, 0.04532724678997071, 0.021453173831105236, 0.01206215491683613, 0.029149176290018425, 0.05941466525978139, 0.015440118112300914, 0.013576608278878756, 0.0598133833808524, 0.05461381823425332, 0.008651745024948351, 0.06663860242453314, 0.03740723447633847, 0.06334817435051646, 0.026355879907045635, 0.051566849072133346, 0.03128935973490438, 0.018614467586420717, 0.026987921596775134, 0.03125782564072119, 0.07165218823619428, 0.07223555652965462, 0.023526860844163645, 0.04755632133193074, 0.015686384736440115, 0.07099510696265968, 0.042181666790237354, 0.059774186492206595, 0.017785510656634168, 0.061440596266859965, 0.053243409511783434, 0.05946826460140367, 0.061716004875638796, 0.08716600496442088, 0.1658688834117305, 0.20382057274541548, 0.2794548706902612, 0.2472017263813365, 0.16803594696665966, 0.19441387105372646, 0.104388136476759, 0.08150239354900776, 0.12612771993923572, 0.2261971736386899, 0.17229735701074525, 0.17475191804189838, 0.1315845948674025, 0.15384640514610276, 0.08944222072680151, 0.15611551161254608, 0.15376824885606766, 0.10004317688365137, 0.11966785971796322, 0.16634635537141756, 0.07604229339067975, 0.18875704717732247, 0.325098236001307, 0.3172347724678055, 0.20329119066797918, 0.1567348170905344, 0.1355532214285866, 0.16183896981660398, 0.21941251512016022, 0.1329561527217588, 0.16169154385645546, 0.10991095625344785, 0.14651115923639269, 0.10661155345939821, 0.11408913850543961, 0.22050932320135258, 0.14044159782990334, 0.23434533076661251, 0.1597134741924463, 0.2229249210006768, 0.17899086638804407, 0.26824102887222845, 0.6081752623281171, 2.208993569497139, 16.83327324928776, 37.226905438207815, 52.69029678836946, 78.0108436461418, 88.28633954448085, 87.50952982133435, 97.91793915533252, 85.21852047212663, 79.39704064399966, 78.77347792348554, 74.91731735967821, 66.23601390469459, 62.616489933383086, 50.114935213519686, 46.850213158515196, 31.279623431544152, 28.644910512431977, 21.898655429963146, 29.788673654679332, 32.82044810633506, 36.15478830952799, 39.526594992606874, 49.7321746426244, 49.195578713570875, 50.61448827866585, 44.779817519649384, 44.67951074723275, 47.689027709345666, 26.177653381901404, 19.083517405294604, 13.495713760775905, 11.454690790945484, 6.335338267587847, 6.360961150738501, 2.993020453760701, 2.374435466143393, 0.8280662146787491, 1.400222413001522, 0.7956122787248704, 0.8359020071164255, 0.5845025938845451, 1.1940957317429206, 1.2563259731377325, 1.8741559044968699, 1.7714235138508583, 1.2188249273646263, 2.3672469873582167, 3.5784501366076933, 4.477926838782526, 10.277310975136297, 13.112252066212317, 21.292419779685236, 29.063690208619644, 30.533680800468694, 29.755912057815063, 30.635293722152714, 51.676662198958866, 46.07029299582205, 39.38287542712304, 60.44276337469778, 79.59060176726311, 75.50939129244897, 66.31268839682302, 53.77376525632797, 51.81671827070175, 63.38610210726338, 60.743060035090295, 42.22188303547521, 35.62499769272343, 37.142080260861306, 39.295363426208496, 48.08749345041091, 53.16129107629099, 68.95561279789095, 78.66721307077717, 72.37406822942918, 76.73427689460017, 86.83099116048506, 75.67584883782172, 63.601322558618364, 29.532384026435118, 7.935292672726416, 1.8349350219772709, 0.5454703528554209, 0.2011735857494416, 0.23161718441594034, 0.2654602829246752, 0.18308370644527097, 0.11883440968250075, 0.20277366763161075, 0.12410513290594663, 0.18437704672255825, 0.13555616320621583, 0.16253909757060392, 0.12346033968271748, 0.14140719037142493, 0.22713846587125333, 0.10201625165439422, 0.08021994704200376, 0.20971817805642085, 0.0821833384613837, 0.1335114438927943, 0.13194358366872036, 0.16787542090300592, 0.15943575199813614, 0.08659394412872293, 0.1536861242305848, 0.17850171924839098, 0.1463029825038487, 0.11744370729091669, 0.1627079433491153, 0.17655692844381257, 0.14955531685583054, 0.22591341467153644, 0.2068845720420922, 0.12107326333681423, 0.19158991774724377, 0.18206644893413593, 0.11303755259441753, 0.267895461931344, 0.15397694652840016, 0.14232398311216987, 0.12801616497698332, 0.1558439794086641, 0.16177743763452576, 0.07276133033296756, 0.1831827003268465, 0.13933259362895645, 0.1923194326340191, 0.14371728254181726, 0.17078506880469863], [0.05112157578790381, 0.02002248548031334, 0.028533622727639256, 0.039226758413978165, 0.03966281949091823, 0.03442349055060937, 0.04414506970093616, 0.022035381501360286, 0.05730041197591251, 0.04243630292494932, 0.03008174086590448, 0.06720945284131073, 0.05672510675785523, 0.03572063062400107, 0.08554269529638753, 0.0914492178708315, 0.04017106520252363, 0.040276115009140585, 0.03990702916898074, 0.08908605878992427, 0.060319790481439525, 0.03495120638681035, 0.03172895056195557, 0.06568516003749063, 0.019502961039242726, 0.04671098161188345, 0.06333705841473515, 0.029587955063869877, 0.05140423158844633, 0.06459596687026563, 0.029084893852292053, 0.03802500394803863, 0.09478144753243654, 0.02084260750111313, 0.041925161400990146, 0.03836983161407613, 0.05253457133808444, 0.02209168130291566, 0.020133424587848208, 0.1113518374040723, 0.07434580700411912, 0.05201882945613996, 0.34917699233178173, 2.467016395061247, 10.795462939047045, 27.774805253551854, 43.39495020527994, 62.29880540601669, 67.55971970096712, 67.25885037452944, 68.83472534918016, 63.518187922816125, 68.18613790696668, 48.386946801216375, 39.69753580708658, 47.70818848763743, 32.00647196462078, 34.62539734378938, 20.356765831670455, 18.57126174434539, 14.616124091609834, 21.145154391565633, 24.037631750106815, 27.9565365083756, 41.611181766756125, 42.92168094265846, 48.016082779053725, 41.08870244795277, 31.49746794854441, 21.363655905569754, 18.86125433829523, 18.412393985256074, 9.054911175081807, 4.34725356678809, 1.745441611255369, 1.5475463915255763, 0.9067424026227767, 0.36252950648626975, 0.1423894070209034, 0.051888230617248246, 0.06411808888397871, 0.0174629723187536, 0.04864073794094786, 0.07225908308980927, 0.06182103169961803, 0.12250407043123439, 0.02009762529914658, 0.08676236089799674, 0.1723924898091824, 0.2680405896277197, 0.17298481367047758, 0.06639120965114524, 0.046411828107891545, 0.1560991939397589, 0.17643844528544336, 0.4389691467006361, 0.8529004562766322, 3.07938467110357, 4.59435063023721, 7.17942399363364, 10.060202883135888, 6.872228864700564, 9.238097629239483, 17.33476200411397, 18.600118621703118, 20.04665343992172, 31.198773576367287, 39.43796119382305, 56.648646862276145, 72.64944999448716, 68.00666593736219, 47.7833842462109, 27.76324995102421, 21.218583122376476, 10.273678860356732, 12.90538332154674, 17.922136937418294, 29.261522793000747, 38.45875716978504, 46.70930593244491, 52.180502414703376, 47.522546629751886, 54.6516191574835, 57.484433343333585, 54.89257035716888, 53.09176314261652, 32.25991591330498, 11.41754496482111, 1.5924981020150648, 0.4000857105899242, 0.0295382761772001, 0.0373440437139042, 0.02555326491053547, 0.0327583524819103, 0.07258994880342677, 0.055526719248342904, 0.058184871975813186, 0.04580650373452133, 0.055038020270125526, 0.0426993009093548, 0.05563004152669061, 0.046358056396486304, 0.028883209714906353, 0.06409718617496472, 0.06136352782167735, 0.024236796438814174, 0.03697138024313796, 0.02764313936143393, 0.06515341840924756, 0.02153013310875864, 0.04740503045820421, 0.02978596389443884, 0.10094437207425795, 0.03913509216339838, 0.00473360700960902, 0.05323312478139997, 0.019106303694688024, 0.024122496120511525, 0.009514887670746014, 0.05412577043077158, 0.02851506041723394, 0.11012778977953619, 0.01717126135894608, 0.04660028190682492, 0.0411312491632998, 0.06825699380809261, 0.07579699203732514, 0.0720889196400681, 0.023272169168077173, 0.07535867483144806, 0.017902385030362396, 0.021962859788008278, 0.0416393339964411, 0.02527659991756082, 0.11502375811218254, 0.14477653699296136, 0.06367900175973773, 0.007123829104051355, 0.03223994844442895, 0.027356900184625582, 0.019482625235292702, 0.03248908023740495, 0.05474928556190384, 0.037397083811341755, 0.007692936670801212, 0.047455377756587924, 0.016619396516151966, 0.08811407707511418, 0.04061877464635238, 0.012357415736562783, 0.09072075252451244, 0.04865677216120305, 0.0420830789352617, 0.023106678854674104, 0.009065379835515013, 0.09343717006906387, 0.07441415736872344, 0.017255481234901858, 0.03975265096091936, 0.07169418517620334, 0.03905326248176637, 0.04084074479197303, 0.06950177943273898, 0.04208355007933513, 0.06175214124302711, 0.057539898721921834, 0.02666920986807635, 0.023448809891218142, 0.0755964991666617, 0.029668218095696745, 0.03386204386310231, 0.02445879531273198, 0.03839940260795336, 0.04848389676020992, 0.08727177872412628, 0.026978808980915817, 0.10164517398563125, 0.030025561723197182, 0.27474284772911384, 2.6956170316665404, 13.450059333155233, 35.11165749642157, 51.791375837018414, 74.51896144497779, 77.4299955368042, 77.07796281383884, 77.22880932592577, 73.68205316605108, 78.24518957445699, 57.67223642718408, 52.736674893286924, 56.878399695119555, 43.3003818604254, 47.31783420808854, 31.70235687686551, 31.729283948098463, 20.163761684971472, 28.70946291954287, 25.154989496354137, 34.219655606054495, 39.322992601702296, 37.138267717053814, 33.67911377260762, 34.2384555262904, 27.12752788297592, 19.32252703174468, 15.008679801417937, 11.584523204834232, 6.1170377750550555, 2.441606055344305, 1.2972741694219652, 0.9741635945054793, 0.3262152228384249, 0.12438280147410209, 0.1335642426725357, 0.2436193919950916, 0.04170974896800134, 0.09150361011345541, 0.01873236085708824, 0.1665353032970621, 0.12344204550308567, 0.168576467962515, 0.06472788721082673, 0.0353769559202896, 0.04316918859859148, 0.13790655160142531, 0.09185090075216948, 0.0627471553912807, 0.09258046160422026, 0.19497798755764964, 0.09398920536642114, 0.3871353619521664, 0.8241099527766629, 2.4365292826006493, 4.468184161570765, 5.929107704470235, 7.5640677925079105, 5.917967192588314, 8.811243734052105, 12.009980736240266, 16.954092056520526, 19.20192003250122, 29.556149667309178, 43.101968765258796, 58.890446155301994, 72.00309045853155, 74.34748326578449, 53.83238115618306, 33.33998564750918, 30.90950465971424, 17.075224653367076, 18.244181179231216, 25.290972186673073, 41.475546206197436, 48.036769359342514, 54.36940854595554, 62.95699481041201, 57.217010067355254, 62.61763918784357, 65.83419845950219, 63.86946755070841, 65.03643543489518, 43.88505035831083, 18.068698260091967, 3.757703679223215, 0.6261034970802646, 0.0847245900020484, 0.036857210159782446, 0.039060218560118834, 0.011084766536500427, 0.04724680648876294, 0.10486218402342451, 0.039148885576475057, 0.04590378924002571, 0.06445889841885337, 0.026273391389798735, 0.09888286011353617, 0.04327795010120158, 0.024084369839739897, 0.04686827861493634, 0.04413296934217215, 0.035939923292326356, 0.017399415749335484, 0.03240784427391426, 0.011757678059380383, 0.05178343745008592, 0.023835171014070514, 0.0542708674836303, 0.04496385681352789, 0.021096125147455645, 0.02598351904100949, 0.06433787950945478, 0.02708525689799459, 0.010396550492113157, 0.02582288764026617, 0.014239826874296754, 0.025960072920086886, 0.04940944205548975, 0.02413695028442289, 0.06254290485934866, 0.013937483571710126, 0.04533730935485614, 0.02352944256046847, 0.010862197884688935, 0.06609938377814908, 0.06617806100797269, 0.03625899508234955, 0.06534381424106898, 0.02577783783987886, 0.05937934477603244, 0.07737774552116472, 0.05403290142215068, 0.2069344290442044, 0.10148162953555585, 0.09575828624468657, 0.1779898959061792, 0.13477772594459597, 0.09964389185751639, 0.12579788078343676, 0.14521126124647357, 0.15526536852121353, 0.11461547921381651, 0.20317932650927575, 0.1475149336000604, 0.2030691937092812, 0.20463423472979378, 0.20739726872453768, 0.18625960054416812, 0.1361258261867108, 0.268270293430936, 0.12543077145012158, 0.19172333962013646, 0.1406787480077436, 0.14307571454874932, 0.08232102744401464, 0.20813544040485737, 0.13460572388383651, 0.1506156131865517, 0.2528524215543463, 0.2565048683074213, 0.18164278699025033, 0.2320284970224865, 0.17131890951385423, 0.1450344941188251, 0.28471323691548844, 0.1595001953143266, 0.1665165647864342, 0.10070798032346273, 0.14298197603033436, 0.09794591926038267, 0.2268091706378806, 0.25135309555597846, 0.20869425558034452, 0.1740376942700917, 0.5861596727082806, 5.058002241196172, 20.973244751653365, 45.11316014874367, 64.374288358996, 90.00753048927554, 89.5420628209268, 86.70140389473208, 87.91963715707102, 81.72938393008324, 85.85738043631278, 66.14440302694997, 57.748000929432536, 64.38005032077913, 46.546045118762606, 50.149048066908314, 34.81708357411046, 33.288830095721835, 25.144807023386804, 30.92764758294629, 34.04986796840545, 39.75193515900643, 57.68359953357328, 55.5512971262778, 61.78048772196617, 54.237271739590554, 39.16104185965754, 28.46414023830045, 24.719327918944824, 22.754173394172426, 11.40798810989626, 5.971054511685526, 2.3561412865115754, 2.1737356291663263, 1.2949658545755571, 0.5800151572592798, 0.43189294576164217, 0.3643686384443314, 0.18750472324750117, 0.21535845443366036, 0.2712343182534941, 0.570709272738426, 0.3039087343119806, 0.24363050026999367, 0.367139486535903, 0.34017469313356186, 0.29253802833057224, 0.41473269883182745, 0.3928055464019699, 0.30616173761025556, 0.2358830990570207, 0.42861237340877134, 0.3104898585907875, 0.8017760383025293, 1.4972522902873255, 4.214075371142357, 5.866077667282474, 9.194094519461355, 12.144807307950913, 8.86275916330276, 12.607127274236372, 21.568242811387588, 21.345356087530813, 24.705783974739816, 37.02455036101803, 48.47870280665737, 69.03791196884649, 81.85057732366747, 79.51362133026123, 60.3039820732609, 39.71267615595172, 34.636478039526175, 20.83357503337245, 22.576976399267874, 30.33791138279823, 46.00659762659381, 53.628904281123994, 61.811925518897276, 69.55625318711805, 65.27523717572613, 71.84470515097343, 77.2094798857166, 74.02096948316021, 74.26469772092759, 50.19102135012227, 23.700286342251687, 5.157308318922597, 0.8730111835945038, 0.28616969263361347, 0.13438285358490484, 0.10139136139543788, 0.11653230780915869, 0.10815918896227114, 0.22540945139142776, 0.13811845152128127, 0.13965125556194014, 0.15995267748592362, 0.07701330217382601, 0.19738207871635116, 0.14576138898489938, 0.07414512261147461, 0.22498045747558917, 0.12847178810906987, 0.13748785390728904, 0.12288937435275125, 0.16511525207709882, 0.11917852105632906, 0.23286960027631254, 0.1274457205868056, 0.15791808585486106, 0.156753325774785, 0.1930192539528493, 0.10246057498959765, 0.2129291743040085, 0.2030673704200214, 0.09431236423552038, 0.10736107856275574, 0.11562358963513568, 0.15594179351483622, 0.16135022104267152, 0.07915412721734855, 0.16453573720589762, 0.15164197182222722, 0.18495041756860672, 0.13969925863127555, 0.15311517422237705, 0.1813679146430185, 0.16443297417173464, 0.10457064926383958, 0.21596069147269573, 0.14281640910813886, 0.14081633739894436, 0.28659220544561265, 0.33636496852963205], [0.03655193178283592, 0.1002495916139695, 0.041718313830994794, 0.02882876384612774, 0.019207195559095953, 0.006664146184771052, 0.06911816090465554, 0.06717724650497399, 0.01835263980131957, 0.04843057321024038, 0.07463453788190119, 0.04899830564916615, 0.052933009837063096, 0.06308858545737402, 0.049026781137311654, 0.05812310996735769, 0.010178219264132843, 0.09035387301757451, 0.005578489949731457, 0.02511103682580494, 0.10482601701251923, 0.03304572355362677, 0.017566604862710642, 0.09647945843396649, 0.013000755307955608, 0.04664829263703958, 0.02505989854163941, 0.03387294529426483, 0.03608716539137306, 0.052631017977311734, 0.04489994592844479, 0.024191001617920496, 0.02546348132102961, 0.019903550330068798, 0.04691296835399924, 0.02187289999827983, 0.014501620185441308, 0.04011945385906485, 0.06839075275967199, 0.03692577502900555, 0.023519931578888528, 0.3115291028253494, 2.931268373804708, 12.37691258230517, 30.481224982969223, 53.53065675304782, 71.26092310874694, 73.94367525654455, 73.24222210914859, 61.44881210019512, 58.446739796669256, 60.60447092979186, 49.56215166276502, 39.95862053286645, 30.596309285010065, 22.58371110885374, 16.94700825598932, 12.458641048400635, 14.838323420093907, 20.714733100706532, 30.256885020963608, 35.14491527311264, 48.970893582990094, 40.46785400759789, 26.854001399009462, 38.423691180444536, 25.99495526283018, 10.654113465739835, 10.856780371358319, 6.465121651849439, 1.9639160363904893, 1.5522195278636872, 0.22539491104262493, 0.1481714403076518, 0.06192193314012501, 0.013064578092927414, 0.03608560640244715, 0.11213711583085599, 0.1157338603309566, 0.05880330411356784, 0.020096493404238455, 0.05195669589504119, 0.020015720923941945, 0.05388611897585854, 0.06494344137008153, 0.05422811211657621, 0.08484549399825835, 0.045694961332746094, 0.037070377955153104, 0.06674864329397678, 0.037800061381271774, 0.10273864958435298, 0.02548779886696608, 0.022272728946841052, 0.1715982251710469, 0.1572157670893977, 0.13654921233894365, 0.17535018674548597, 0.0547578695770954, 0.10797476095537986, 0.21421865349815739, 1.1699711939980908, 1.8008700950491814, 1.2823116755293262, 1.1388897198823191, 3.8115271781721427, 6.9976790105142905, 10.3107903657421, 17.489730927252, 24.38307881355286, 32.06011429909737, 35.99721493259553, 35.650732363424, 25.44119896427278, 37.619444477942686, 52.27231333332678, 18.08340714823815, 12.303360296833901, 22.153456518726966, 22.547405650538785, 36.889938539074315, 41.12605125673356, 44.988942607756584, 54.61938119703724, 62.517606981339, 56.46146351291288, 63.09358742929275, 47.22822766150198, 22.550771044146632, 11.966464980956047, 0.970577935297643, 0.266766861201294, 0.06839228493552055, 0.033398342333854206, 0.015416721787093388, 0.02776010566571307, 0.030724182199206085, 0.03229114993084823, 0.06081865161597248, 0.021608019352800423, 0.03300474168011739, 0.06477657209841475, 0.032010727276604985, 0.024023781861028364, 0.0670156172747093, 0.031019966831550966, 0.017881767689100197, 0.02030392894671569, 0.01732225154316233, 0.04717091015810448, 0.03412670042786387, 0.016007832356638486, 0.04345877366440912, 0.015781956120213915, 0.02457562180596494, 0.019235420153446255, 0.01820047941779898, 0.05221150439953612, 0.04354035819790537, 0.04711777429967638, 0.03598370138675936, 0.10064663200248634, 0.07091282145871271, 0.032749672705728206, 0.03977229345529791, 0.02013632997630104, 0.06480283359245909, 0.03473028578164597, 0.032786873935331265, 0.027617659277072357, 0.04129687354208962, 0.02929892158135772, 0.04154436973734729, 0.055022311637238155, 0.0984940858137223, 0.04444795788355893, 0.050044889006042675, 0.06399730746183666, 0.011076169114770188, 0.07750774298103587, 0.030804119643665133, 0.04254473117931236, 0.09605955798178913, 0.03699435905042676, 0.026897705167592056, 0.02388269336323344, 0.03623293660160515, 0.017179517871550015, 0.03932782456338887, 0.030364593934087507, 0.012247253250661156, 0.057217115235905495, 0.05078843096271158, 0.022295860971714702, 0.033864633240286386, 0.01697549525077545, 0.07048545931015285, 0.04862173129954646, 0.04405200917033419, 0.09875844743463302, 0.026749359901934385, 0.0790324877767313, 0.02777586217909571, 0.04565403691583103, 0.05401499411692062, 0.0725107965990901, 0.003742516907345083, 0.01200071370769893, 0.042906937549912164, 0.024837771347994288, 0.0250109474384977, 0.006072933150966082, 0.10655568266708045, 0.013468946112439999, 0.07024663139975841, 0.046645779868647944, 0.04194246732719964, 0.39694514846609485, 3.7322006735109516, 15.219956309564653, 36.31281668140043, 60.88237477887062, 80.0895586321431, 82.32755322610178, 82.70854088567918, 69.2419615099507, 69.7776552938646, 72.23962506940289, 60.716136886227524, 50.53860218294206, 40.02484975322601, 36.1712779537324, 26.647996556374338, 24.094082501626787, 23.935571678223152, 27.152546721120036, 33.22793529879662, 32.239260711977565, 38.33073885210099, 27.480035212732133, 26.620561538204072, 26.484939705940988, 20.084688663482666, 11.6413357950026, 7.390766201480743, 4.592355124412045, 2.116766634487337, 0.9939524423210853, 0.2849248304001747, 0.14839820233323883, 0.12606733688904395, 0.10065713506792823, 0.036831511740362456, 0.08192134405215902, 0.13095935986888024, 0.16892770395403908, 0.18510852279441972, 0.08370638254188723, 0.007500638068097854, 0.07973914259984609, 0.026122129244369366, 0.07701176999797744, 0.11354710065549421, 0.07178529601303801, 0.10679208207875492, 0.296836517030193, 0.03887253850998898, 0.22333073309592663, 0.050163536873315616, 0.12284375381686034, 0.25122636929154396, 0.09148938386070152, 0.12865222479787566, 0.3440072165141183, 0.035056148941117915, 0.12779738558756729, 0.19671031153730809, 0.8908748218128759, 0.7967171000857508, 1.2473583317572072, 1.0617672195357661, 3.5327278029534126, 7.524246419629744, 11.220844964827261, 19.276431337479625, 29.431292779984016, 32.53928869001327, 40.86284060632029, 37.986139020612164, 28.762322741170085, 40.65597480343234, 54.06944528702767, 28.48059065880314, 19.19604628316818, 31.50205319927585, 32.83452157051333, 45.477607173304406, 52.56327867507935, 54.79601337063698, 63.211968483463416, 71.81591495390862, 65.52880271788567, 74.31125625487297, 60.821911442664366, 36.81124010393697, 19.508247337033673, 2.0457418262958527, 0.42520086130788254, 0.07241938698796496, 0.03913749384904101, 0.03360581809594747, 0.027364494031175014, 0.019188029954450268, 0.046014642162669095, 0.027525456764945583, 0.025478510050884178, 0.026466907114691796, 0.09179352842752012, 0.029495411642616796, 0.03904118127520046, 0.04587922080029403, 0.013117179605028322, 0.04102437989786267, 0.042652561885094455, 0.024198842527825507, 0.035409353778607426, 0.02449058987680943, 0.05462378120770859, 0.044941850937902934, 0.08082094301860179, 0.008752276828031867, 0.040218566484268636, 0.02206532404788079, 0.047078834050485206, 0.08597040218451331, 0.03160867284262373, 0.03980890479719928, 0.06456722325134663, 0.05434433914600842, 0.06845341875187813, 0.032834214338612173, 0.047477739863097675, 0.06747646512643946, 0.08346851224139815, 0.034138065342220573, 0.0422323243542304, 0.0157465887135796, 0.04746476616409998, 0.13312095355603004, 0.11203082113136208, 0.11160050954429374, 0.03395723411813378, 0.10668695949378515, 0.19751769160070728, 0.17713851175240933, 0.12738296266404853, 0.11891843420603584, 0.0984045071527362, 0.1451963225319501, 0.22583887431650396, 0.13590615813530263, 0.10034947415753719, 0.07513031934297855, 0.13787725639920081, 0.11401714156231574, 0.15923793277432843, 0.10511966617477518, 0.2662243177333186, 0.09431003532823055, 0.13558311417939203, 0.14098334456643752, 0.14054433022054935, 0.1985824005978723, 0.16131066026226168, 0.12982119836153524, 0.16479093641523393, 0.09545961154564735, 0.14847035249394758, 0.1134282804184383, 0.14750080693873668, 0.24070890139668222, 0.315701064443396, 0.13697667407893366, 0.17247349594629582, 0.18745704193509397, 0.1697567949492124, 0.12987716874528316, 0.12692494167675897, 0.21356492002885188, 0.1021928579035786, 0.24225996897345592, 0.2749342164925991, 0.19949510242910157, 0.8870954342907476, 6.342510811744198, 22.60529395072691, 47.29395089610931, 74.88674640655518, 93.21073409049743, 93.89307745041387, 92.9533403150497, 78.773328873419, 76.3151559522075, 80.01530816478115, 64.806961090334, 54.70257074602189, 43.297259653768236, 35.05899575448806, 29.251118706118678, 24.56643000725777, 25.932626839606996, 30.477816443289484, 44.663127007022986, 50.66864836600519, 63.655765056610115, 52.88506992401616, 37.78880457724295, 46.41848179601854, 34.56740902316186, 13.87583653773031, 14.56927824404932, 8.486326356087963, 2.6657344545087507, 2.6480342688099032, 0.5497158282706814, 0.37784348151856856, 0.19136078084909147, 0.19525509688162035, 0.1817902895591913, 0.24897941808787086, 0.48188922265844963, 0.21178606386867263, 0.46306448117379223, 0.24813390216760098, 0.12249168278949878, 0.3148390623109956, 0.333981148057407, 0.22140370020943306, 0.3350004127189037, 0.32374324096787366, 0.33437988150023645, 0.3466023240358599, 0.20591157909122207, 0.30263788637615024, 0.20272163493979364, 0.27792257226763234, 0.3253898703523221, 0.31761478272176563, 0.42769288403853295, 0.42935679636655316, 0.14768767110522718, 0.254933116356692, 0.6493470337121718, 1.6007739353564479, 2.215667482345335, 1.9283705372964184, 1.8499928784947244, 5.345818409996649, 9.121554205494544, 13.562274421415022, 23.180509536497055, 31.951741172421364, 43.56941330817438, 50.71635615441107, 49.562069292991396, 37.93049235497752, 50.49342040092715, 65.17905673673077, 29.141376672252534, 22.669359983936435, 34.64122802980485, 36.415920103749926, 53.43544121711485, 56.459490560716205, 63.192733180138376, 74.4041693595148, 84.47187377560525, 78.62476518077236, 86.437514674279, 71.12436186882758, 46.27294617314493, 22.932533371833063, 3.2328915307598733, 0.626601392944013, 0.1477365168712793, 0.11535584190559965, 0.14401742046879185, 0.1599455528682278, 0.12211218581444795, 0.21814667739935462, 0.13370089743646885, 0.20169942850066772, 0.1649243889316436, 0.2538347914214096, 0.17421199459462397, 0.29487618996251014, 0.15195392282499423, 0.137931909111719, 0.1667881582773501, 0.18103126496557267, 0.07786010512180867, 0.16381604356631158, 0.19195791574255114, 0.09851681564243571, 0.17625987019029357, 0.10263671392514821, 0.13098992677705903, 0.09289062762212369, 0.09390261444833972, 0.10235284004480609, 0.24346455030383604, 0.12714960462143346, 0.08976269062728652, 0.2357614902599204, 0.1016887643885228, 0.16249541523716143, 0.0846617861140159, 0.163787912817732, 0.22948723016006334, 0.17270963488807603, 0.10977332089697162, 0.11911080654470191, 0.09707049526754888, 0.13616676592538435, 0.19156108219777385, 0.17924900737500962, 0.21388978727402227, 0.101395214817697], [0.020005378736964157, 0.05476163872968286, 0.01778772848117496, 0.04620693789254274, 0.017875583444331444, 0.06956099036840663, 0.012683202287242299, 0.00871564154588287, 0.010385367523638472, 0.03228551918460477, 0.02954043654514657, 0.07404589124264256, 0.03635126654238951, 0.055984403156945785, 0.07142531129741861, 0.0575590432591496, 0.005063502664392394, 0.05012236730826478, 0.048780043369099024, 0.05487553685182526, 0.040283975071243705, 0.06484112266691462, 0.03163294633850455, 0.060543729473025575, 0.05612509903467952, 0.022035465771031958, 0.025791987483840317, 0.034837721952147065, 0.07346810006927099, 0.105280100307878, 0.03769429911288523, 0.044736340191335454, 0.02872707908071818, 0.031595360149719545, 0.06416707637629683, 0.03319277796113203, 0.041165340075930285, 0.013674386953484389, 0.027081118107983665, 0.03386989243388657, 0.0996966370111031, 2.9514408784527935, 12.273239435688144, 30.122675241962558, 52.15117485292497, 72.14421733733147, 71.79910367535007, 75.26453341207197, 66.88944155170073, 55.03425029016311, 47.38729153909991, 35.89970088774158, 36.96271811762164, 24.812021370856996, 21.086193323135376, 20.533900068652247, 32.724891324197095, 35.250658450588105, 27.839808733232562, 40.51634627003824, 37.456030691823656, 42.21201827449184, 31.13401720600744, 33.49038108702629, 18.28658788434921, 13.838168055780473, 4.367115468748154, 2.473385588776681, 0.8920172734125968, 0.226104982617882, 0.1072603073571959, 0.01010456086782318, 0.052033749018465324, 0.13965137813600803, 0.03539555653509113, 0.05013246051666718, 0.12916340462623105, 0.11237935283251348, 0.14758711440428612, 0.03456011850146517, 0.03862341820833184, 0.08393338971561001, 0.11456911557263906, 0.009376831923521334, 0.06792736915691246, 0.05771388495040517, 0.19621954029125555, 0.033675106918259014, 0.031520875336061564, 0.4198511467585641, 0.19667042899997006, 0.12758846574973676, 0.08116375970383806, 0.11243274149995659, 0.18578707751247192, 0.11075332355234893, 0.014730699626999277, 0.016177469120931723, 0.04242645103424307, 0.10122665249171758, 0.12427562577349525, 0.03036405192688108, 0.02076244214549661, 0.10044734188986403, 0.19122218022183066, 0.21824233113758026, 0.20907330056352003, 2.3774684388791365, 6.283317833177506, 13.789967029325425, 23.032420450641265, 24.53458232264365, 36.89648497489191, 37.49707829567694, 38.58568506856119, 38.43120251932452, 26.913115439876435, 30.36390296874508, 17.63993613181576, 17.155831321593254, 21.4539449445663, 18.34768468333829, 33.34260579078428, 40.62399571941745, 38.5879639656313, 49.37698833404049, 66.80402017408802, 64.93622672173285, 65.12976431077527, 51.756533422777736, 27.54119476964397, 7.323561291540823, 0.39250566894488953, 0.19761613389897734, 0.04362881454008241, 0.11124241706584731, 0.019097256196302273, 0.07230312548457615, 0.05913260317738018, 0.12421818450093271, 0.06352496446080266, 0.028235735183942224, 0.02550907695906297, 0.035874319352930596, 0.04132141516874394, 0.055897095946655165, 0.006224269989968068, 0.030502886210958806, 0.020759253304511793, 0.027440014978750583, 0.051763974986369574, 0.031999582612526514, 0.08935814257711173, 0.05706009402450535, 0.054376120303547194, 0.02373394015575609, 0.04106205610197879, 0.05692554600236397, 0.06503508846846319, 0.06868817873539464, 0.09077592617681912, 0.03583143375092938, 0.020703478273184552, 0.009996191985274275, 0.05745852103216514, 0.06107615291952126, 0.0678228211378859, 0.024799489934417992, 0.03166622711315511, 0.050469531542471344, 0.05302968630266767, 0.006687553522492489, 0.05847657144430184, 0.03941350383684039, 0.08209233487685842, 0.024650640965950106, 0.04573492047887656, 0.08834820120565354, 0.06645688636889381, 0.012293019343257673, 0.03471933455476838, 0.05370879643446496, 0.05781159563470752, 0.0068822135912224415, 0.022173740810924963, 0.039082595988387064, 0.027831932154273795, 0.045176580277902466, 0.048224426610695745, 0.04665963839919818, 0.050193061901917385, 0.07129650893470935, 0.05135658474999571, 0.04657838328350936, 0.04824858902382755, 0.034709892521101626, 0.02584613457832846, 0.031075598221392404, 0.08836605871516852, 0.04444639889463302, 0.11592932766483677, 0.03983618901862253, 0.02598753525695253, 0.030123331779313665, 0.04531345337689404, 0.0640370482729087, 0.051225798219562545, 0.043373822174485654, 0.039553736231379935, 0.061580437956558126, 0.05754636450400276, 0.0625414799358095, 0.038617825766484586, 0.06019173505445642, 0.12206849582012623, 0.08760291256851728, 0.23884989711786472, 3.419044032212227, 14.954669744737688, 34.797087330972, 61.46633332775485, 83.66716031105288, 80.5214665012975, 84.11922131815265, 76.0803158052506, 68.28859806060791, 57.79959186430901, 46.6894861959642, 46.885283070225874, 33.17131588535924, 34.885909403524096, 27.834907731702252, 30.0951970777204, 40.99510685090096, 31.679977793847364, 39.16306972503662, 33.64906841708768, 36.91487304625973, 26.202966397808446, 23.2500845386136, 11.405075750043316, 8.771329695178617, 4.391873469275813, 1.993017081291445, 1.0142132615850818, 0.23353389043721462, 0.0661857755133702, 0.20789845876636046, 0.18821905427161725, 0.21567086508918196, 0.08499261352323717, 0.47297863950652463, 0.21018518525506222, 0.28926986660207477, 0.44795692087181155, 0.46986519689521483, 0.32040631518729273, 0.05324558903192801, 0.20756263646387285, 0.16028304524239034, 0.09449810991364141, 0.06318367995141495, 0.18816435559382363, 0.033071238111944935, 0.286466199303827, 0.8335987178068008, 0.6830241362894736, 0.34358127162821833, 0.5196517802053883, 0.4082378054097776, 0.494019152416337, 0.46566599319058083, 0.07942281723503145, 0.04494243316472538, 0.3520569619872878, 0.25900093598231194, 0.16168069605144764, 0.019837122846154437, 0.07199520410429086, 0.09453865128659433, 0.08533109415082202, 0.10438737804971396, 0.2286443342604945, 1.8562404787348163, 5.654613865960029, 10.18334275291812, 18.623321402457453, 23.838761698815134, 30.47116606466232, 33.34936403459118, 38.058804850424494, 43.885948581080285, 30.67469393053363, 39.226514062573834, 25.75678110122681, 23.85704190500321, 33.39492236414264, 27.96610709159605, 42.949972998711374, 47.95912604178152, 48.9928392441042, 60.76255029247653, 73.96560915054815, 72.21256071521391, 75.93850643404069, 66.18044176409322, 40.60743939492011, 12.642221700760627, 0.9720179967341885, 0.20693732485655816, 0.048446228216973045, 0.0258779980903191, 0.05017884714048236, 0.05004429528790136, 0.04849012888547394, 0.08250127261083934, 0.07588686181172248, 0.010262364446515999, 0.04088709311139199, 0.04968974213566511, 0.044178999735102545, 0.08532904103518495, 0.02095708210441855, 0.06965511193078372, 0.010073985341155242, 0.08456499090478306, 0.048297093880753365, 0.02018737249947604, 0.02045008128569011, 0.05446295253932477, 0.04613576832437708, 0.028383814234046206, 0.025402290048077706, 0.04678742569540778, 0.06930994335561991, 0.043646656727838906, 0.06396344254514383, 0.04706130212833805, 0.07826448463264012, 0.07007262984951658, 0.031030803145239913, 0.029582889307470574, 0.07416019922182446, 0.054733672690007, 0.00903264681373032, 0.07643669077585782, 0.0454473349025413, 0.012693718759222858, 0.01507014839819843, 0.05735504553623258, 0.07842332530286043, 0.01868740490247165, 0.1434581762840671, 0.1276013053833477, 0.14799147093247983, 0.18640883447181794, 0.12912274067921023, 0.13898411555395973, 0.11238633189350368, 0.11495916923928647, 0.07589262279291308, 0.12961591744134504, 0.17716691829264167, 0.11047836693544542, 0.09359850818591733, 0.15079581238810094, 0.18546058616090208, 0.13012378776986755, 0.18357764929533008, 0.1718872701448779, 0.1850977975634798, 0.17745384886380167, 0.09648263003797301, 0.18462086186533977, 0.22094490547333995, 0.18221300155405076, 0.17479898648396616, 0.1802157643701761, 0.1192104209574961, 0.13557831846898602, 0.18652468228772764, 0.26265054821006717, 0.1344810507350391, 0.1755032511127572, 0.1499741064805177, 0.19366135820746425, 0.13077312389448767, 0.14216813018485425, 0.1960965831794085, 0.1550260732971853, 0.24041438655507183, 0.11960348534968593, 0.889007160740514, 6.375008138918108, 21.935347241740075, 45.056313237836285, 75.48537854225405, 91.6447199544599, 89.43490366781913, 93.08214310676821, 82.98680951518398, 71.39927294946486, 62.60617409982989, 49.898020298250266, 51.459766895540305, 38.93515648380403, 34.16965323109781, 30.60604460777775, 47.1087718779041, 48.12366947051018, 40.95769136182724, 54.689799508740826, 51.99674329450054, 55.23481676655432, 40.113385492755526, 41.62198397421068, 23.42906621194655, 17.675347289731427, 5.535161024139774, 3.366007703927256, 1.7882830865921515, 0.40290629310954007, 0.21409454725442395, 0.26874327611538673, 0.3662592515109047, 0.2894192843908264, 0.18991950899362567, 0.43100118877426274, 0.39729975524448585, 0.3849778744962908, 0.7051314113120879, 0.3392463477869188, 0.322450299056307, 0.34935904546610774, 0.28791404419368316, 0.27097087593809255, 0.1675545373150418, 0.27833031490445137, 0.5516356446089283, 0.18957323725185088, 0.3798082825397292, 0.7638234296633352, 0.5495729069075277, 0.37637182661602575, 0.42598628529137184, 0.24553986716895337, 0.2911959648613007, 0.3711812132068219, 0.16121169702420313, 0.16527496608755282, 0.4576141333147403, 0.5017866098111676, 0.40193008258938795, 0.19714633814029156, 0.23767939137835659, 0.22106970119620525, 0.45074321329593664, 0.38539955993333175, 0.5241489001820164, 3.31375168215844, 8.939548384758735, 17.62580579326999, 28.66078826688951, 31.54210844347554, 48.582790743920114, 47.84234923701133, 49.33212426400954, 49.39911050181235, 37.94217709572085, 47.02118142958611, 30.02474346468526, 28.424565484446866, 35.36355995362805, 31.476318528575284, 47.135553821440666, 57.137476167371204, 58.579955254831624, 68.19419445530062, 84.5118191934401, 82.45346130863314, 84.22041062385806, 78.0933310908656, 46.01928257173108, 16.17388850258243, 1.443724685138272, 0.3906250150213319, 0.2947222369332468, 0.16811791837455767, 0.12540026582897673, 0.15093729350595705, 0.2034463387944045, 0.2430214450484322, 0.30597554760113843, 0.12930074886929604, 0.15078738542093387, 0.07698130268122881, 0.10428899703847785, 0.21614467514859093, 0.08906109198447197, 0.18796771614541932, 0.11487723613578467, 0.13688180175039077, 0.1698996703470907, 0.1073787905155651, 0.15141036812095873, 0.2033687187659164, 0.18594922768252511, 0.15005076123822123, 0.08516676063018461, 0.13443044296676113, 0.11879057413147343, 0.18379598435375, 0.17389316412229694, 0.23014991153632441, 0.1510428757436814, 0.1538025236298, 0.16079378073974965, 0.16688211130038386, 0.16938746396091678, 0.14641587322037067, 0.08633614022044406, 0.1322162037174548, 0.24996070011008173, 0.10153464281991606, 0.1374800398104614, 0.21697368953497181, 0.2690585059744697, 0.08984144446590255], [0.028450758827309457, 0.0025039897422351304, 0.02568219750819187, 0.048152238145590796, 0.038987919012264866, 0.06102379464033631, 0.036474962929083456, 0.017492095151195125, 0.04537979659113673, 0.09738953258361548, 0.016325521357958356, 0.05325126574344693, 0.1663904820358561, 0.07428996685531832, 0.04243625695967386, 0.03174359241740839, 0.04090911813921506, 0.03111604000291517, 0.04678608504154029, 0.01148279900887921, 0.06813739216135395, 0.034944882330995415, 0.07426333763907034, 0.06537024427445666, 0.019643239399057724, 0.07720397379730018, 0.04078227696159194, 0.019868748870888547, 0.06185249493066823, 0.022615137690257643, 0.04248119567731216, 0.03012967498732671, 0.00932710515635629, 0.02873494105804111, 0.06427752710277997, 0.07147604163976447, 0.012682485995033096, 0.07866232941347746, 0.0572616440965043, 0.4135838120935425, 4.362086499890974, 18.94151976031642, 32.68715812313941, 54.82380336330783, 73.80683160597279, 76.15686478153353, 72.0683116297568, 57.88777851289319, 54.61091672220538, 39.85881582383187, 38.58019767269012, 32.43805819942106, 25.801707929180516, 29.69352872140946, 21.804685246559885, 38.82893085479736, 46.186026450126406, 32.058663022133615, 46.61330200010731, 38.92577417435185, 35.95990534751646, 23.994522940727975, 16.856179891094087, 4.963337307976139, 3.903303040612129, 1.866130122253972, 0.31322283129538264, 0.060384053766967795, 0.07150662386970175, 0.09324449129522809, 0.01369494588054236, 0.02518922758979663, 0.08686130115341756, 0.006212511019135315, 0.01847416241352837, 0.21984984407261496, 0.12315648622931012, 0.11976058700031812, 0.056674866711780916, 0.5117459060443986, 0.47618373687709536, 0.05837885309912025, 0.09305047952840406, 0.04503698373634008, 0.07002146283705389, 0.06670912081796317, 0.10506545013237385, 0.030988367619894208, 0.6635148799227131, 0.9788793253321803, 0.31798026794868134, 0.7043100424831914, 0.29166640413384287, 0.5415860419311832, 1.6466127143752192, 0.6237799217624049, 0.3117994705755865, 0.24199297201008568, 0.1226194202899933, 0.08076192360491523, 0.10256722208953674, 0.19837460690929046, 0.10643782770080913, 0.013185635306722215, 0.030526565988698316, 0.04118194120124944, 0.07213353660077819, 0.07490591686819831, 0.16663187634079688, 2.1907552836402773, 2.8905566228974253, 11.8164853126772, 19.267590315111224, 28.821072001611036, 40.20448254000756, 42.01109878478512, 48.517502892401914, 26.097772352157104, 24.168130966924853, 19.062287576736946, 15.336242818063306, 25.985439592792144, 27.165867090225223, 43.35965671846944, 29.504017445348925, 41.732092749687936, 47.91856873419977, 50.211994263433645, 63.54803715982745, 62.207622066620864, 60.075147075037805, 38.97398010376961, 17.283047514577067, 4.901719814346683, 0.7007446079965561, 0.03309970210877157, 0.04849988884562927, 0.022991447739543456, 0.022144357508589185, 0.02173482414124714, 0.04203602198451277, 0.04976768775152103, 0.06417944103539472, 0.052089336358251116, 0.004190564626872901, 0.03348878667419476, 0.054564727320065426, 0.05944135576306332, 0.02016131784917126, 0.12218056682256923, 0.026837458098006826, 0.09354455261341027, 0.018542156547247883, 0.029490822775950356, 0.05131270706413254, 0.06918723905278791, 0.0529707741412905, 0.10136814127045293, 0.03894815904899471, 0.04297404302163951, 0.011989056722321098, 0.026811376634624698, 0.08960544341994871, 0.04117590059796649, 0.04684257253463711, 0.034501198679208755, 0.05444594921784536, 0.004767949773644608, 0.04360035820413501, 0.040696164848463195, 0.04172467619120594, 0.0109555255884545, 0.025900436805621273, 0.05375481916651611, 0.09119361263489531, 0.018337858134820577, 0.018646005511043534, 0.04101057116302752, 0.04710962695460166, 0.029661014953988697, 0.03354013371731966, 0.07134161619169098, 0.0619863075084023, 0.055206421717640855, 0.034159676682564526, 0.09853980594104338, 0.018271323398596818, 0.058294127605134444, 0.02822840755294648, 0.027930916459750266, 0.043157793040717804, 0.00714296933203455, 0.049649403776012124, 0.061391965005426645, 0.057510592028378486, 0.006940741751027564, 0.03844571645341573, 0.04339760920453457, 0.026856639024411, 0.0784917599371364, 0.011430032787874583, 0.05263947558799579, 0.037842487330518426, 0.024161874955039353, 0.02441722546674071, 0.036384296423244866, 0.11540453445406691, 0.03427726351806233, 0.042824479676182234, 0.008944752588567716, 0.05628174869343639, 0.08131508505152119, 0.025596219460449876, 0.027671009640119253, 0.007703975997790094, 0.45894252977544264, 4.494313030473648, 21.061660858892626, 37.463804829505186, 62.89542928818734, 84.21830038870536, 85.13041619331607, 82.49708590968963, 68.76729980591806, 62.505192679743615, 48.96315866901029, 46.24034343227264, 38.068748058811316, 33.22926105991487, 36.6455081970461, 25.064796555426813, 43.17192031491188, 54.700786067593484, 36.775181754942864, 47.11358070373536, 36.340473313485425, 28.945507234142674, 16.260953353297328, 11.212126516526746, 5.016531021364274, 3.1800015559119568, 1.1381007106073442, 0.1582041277640289, 0.19884855486452582, 0.06630094151102728, 0.37422092751629893, 0.43959672592820664, 0.4769058207110052, 0.27783615754977353, 0.4738452075229537, 0.501083494314263, 0.6187275412582582, 0.41667129964597766, 0.6318488500771985, 1.1189162755204787, 1.3652123174359723, 0.9125456718667861, 0.10781408933502053, 0.2804445643578806, 0.10255301881942058, 0.04654468690615989, 0.03445226864348497, 0.04265755294792114, 0.012908315308572305, 0.1443593561529152, 0.35145864731842474, 1.7413267997964736, 1.7569994878384376, 2.4079629057838075, 1.9215212209570793, 2.2807825044278176, 1.4734551478778164, 1.5402236941360659, 1.73352214117204, 0.6189935269855684, 0.16906290315091613, 0.39288258420363553, 0.34621970908295724, 0.25528891823224487, 0.20157555208331157, 0.0642006655013369, 0.1043595920407003, 0.1879421747740238, 0.11286923541657387, 0.37165398138665384, 1.8623908777390759, 2.4839448544286915, 6.7118759982047544, 13.50617374143293, 20.54400605540122, 31.745302907882202, 35.69460799617153, 42.37889159110285, 33.68098474317981, 29.63620916489632, 28.430188202088882, 22.767203507884858, 33.27226592648414, 39.92605701569588, 55.375876965061316, 42.16894672762963, 51.30729259983186, 56.16479896729993, 60.22662116635231, 71.33074129781416, 68.35596084594727, 70.30401383676838, 52.29614957686394, 24.688376495915076, 7.824405306769957, 1.177274892407079, 0.13327305265251668, 0.07659926229426939, 0.04955568057935565, 0.05182637284780222, 0.015198879897774709, 0.06591745321789096, 0.05638986285175047, 0.030499094075733618, 0.030732902195004207, 0.06865353623945868, 0.02795575494547525, 0.04222307001210509, 0.05068811940990629, 0.003566856058539763, 0.033087391075828386, 0.08868819868732845, 0.002391850031281431, 0.03587846005816133, 0.09566829389622135, 0.01322222558120566, 0.05920812412495575, 0.050541727668455536, 0.03853247974128012, 0.06622845427163186, 0.03392411996760676, 0.024386283175479022, 0.06569279027321646, 0.049184733145539804, 0.040054022289452054, 0.07903225028947478, 0.04180591598513626, 0.1058565891317783, 0.051530030886492426, 0.007463060976606944, 0.015555621188644682, 0.05390884880457194, 0.03214365119234689, 0.01700794673524797, 0.0839213238308026, 0.047428805996934255, 0.025093884117180304, 0.11921003791353396, 0.10946366049709821, 0.17835436989703488, 0.14941346801577077, 0.0926200223846301, 0.25026813119409547, 0.16779055368275414, 0.08859729469423333, 0.15647016435621247, 0.23328206201474513, 0.07234990281323272, 0.21380910289383706, 0.22026297996842095, 0.19499488745725926, 0.19360031632165756, 0.07756932112838953, 0.17075948146802766, 0.1502076100798384, 0.15569358102736935, 0.11475792560245722, 0.1890922872529876, 0.12480028874931798, 0.15564821330049347, 0.15118781957895527, 0.1379439366921302, 0.2089301034087135, 0.18630334416464453, 0.11353889585382516, 0.19343862580435892, 0.1540486523581128, 0.16794320436254626, 0.14487271167097554, 0.12305869510577572, 0.13706186305611365, 0.20510712548369364, 0.20698937287013378, 0.22347544710482323, 0.1055610324105909, 0.16373113038078432, 1.0103154062263429, 8.25665295124054, 28.138661961401667, 48.77454365453413, 75.26336454576062, 94.87166958470499, 97.00381509719357, 90.69022686250749, 74.02941826851138, 71.4142720930038, 53.84421886936311, 50.392968500814135, 46.28975745170347, 40.26746011549427, 41.859228534083215, 31.77121408524052, 52.222063849049235, 63.409416675567634, 45.949483994514715, 59.05460126938359, 49.426665152272875, 45.85591193168394, 30.30831317747793, 19.894255630431637, 6.048802752648631, 5.338741473613247, 2.5777510337291227, 0.7187540480686773, 0.36682082460291926, 0.18018516681848035, 0.2958711849585656, 0.3529030601343801, 0.3120467944010612, 0.24519010206624386, 0.5364097390444048, 0.5269995439917811, 0.45027556258343887, 0.44992613455941605, 0.6513514874442932, 0.5089476013616209, 2.080124342633832, 1.579682983217701, 0.10994395166034661, 0.4334841103803727, 0.33944749183231787, 0.32959560112607095, 0.2634974737321177, 0.20256650213512684, 0.2930217362459629, 2.218322191507586, 3.4774331700417305, 1.4651445035011539, 1.9925819433504537, 1.9911326275717829, 1.8605878132004894, 2.95222167526522, 1.5008039964783577, 1.3133241404448788, 1.5837689897706433, 0.7041414418528158, 0.16515321939462618, 0.41332420021776234, 0.5666545225727944, 0.23286193939706973, 0.3126829844569007, 0.12149399882482907, 0.2828066892200901, 0.3667451964030343, 0.17699387435230518, 0.5615090470640891, 2.931546126642535, 3.9601381844089882, 14.20856825767025, 22.83235407644703, 35.62961824478642, 51.055480357139345, 54.580000600507184, 64.70177096705284, 36.321830288056404, 36.15996583815544, 29.641359236932573, 26.212385969777262, 37.081126628383515, 40.9152199376014, 60.28828474783129, 43.71087358843896, 60.089691223636756, 66.37343022131151, 69.36758718182965, 83.35792064666748, 78.507415709957, 83.57114853397493, 64.20362603279852, 30.974039416159357, 10.53105498513868, 1.9617566490365614, 0.30654640567879526, 0.20100743660042364, 0.15515154317742394, 0.11857573243398821, 0.11534869430526612, 0.11230458265110371, 0.14557624085535928, 0.13101813413443106, 0.1497343209602179, 0.20243364716729811, 0.15053880521126334, 0.11869586268139463, 0.11921288776061228, 0.08011441843043413, 0.17244728041752694, 0.1112307112423643, 0.18272312418107065, 0.06634362026928894, 0.14471981584304763, 0.08644189099751173, 0.13803575999073445, 0.13345866043481136, 0.15591525622913915, 0.18455090271609445, 0.11277647749070199, 0.1314264896415895, 0.12955201038670155, 0.15159936201187874, 0.09684718063762111, 0.1698642311197135, 0.11982161356436631, 0.1695157377229583, 0.14346193011489608, 0.12500259724836196, 0.1020866015084809, 0.2178764781884609, 0.13906259360092302, 0.13357406391972496, 0.19109249685800847, 0.18963512183437425, 0.16623583952746085], [0.01924080958199357, 0.06752777003472851, 0.08358295045552716, 0.042445978615432985, 0.03294584101005908, 0.02485369448550046, 0.09301600557181144, 0.08188385937002399, 0.014701171725567792, 0.05645002373644421, 0.029330093698996692, 0.03714585676789284, 0.07979453841765081, 0.029780480620120803, 0.03792378075060345, 0.03456978270062997, 0.018525886754955978, 0.03752782820693908, 0.05267052130112725, 0.03036375698303023, 0.01955489797006932, 0.020693959630725366, 0.015524304471910002, 0.029350703379379648, 0.02543683486780332, 0.015833202614298752, 0.08848237384471203, 0.018564089644520033, 0.06336469120616395, 0.035495776157345504, 0.045416277698090965, 0.010917126388859846, 0.05311818094924093, 0.07277893503346751, 0.09855823801650156, 0.056101442239577734, 0.08744303001871995, 0.09510626115145222, 0.5016830040802879, 2.8618804197157584, 12.388334524246956, 25.595856058982115, 60.652688626320135, 71.02184680200392, 76.61295014043009, 69.52275614584647, 60.66239257012645, 50.127059259722316, 40.467634354868245, 38.724701712208415, 31.266375626287154, 34.761970350819254, 28.280224223290723, 26.003488379140055, 35.09324196846255, 39.762564782173406, 33.490985132032826, 40.54359105325515, 36.99645442347373, 24.47507408357436, 11.888473553042259, 8.2259202003479, 2.985268624559526, 0.6848754950108067, 0.08193013108065052, 0.03639993227777943, 0.06489038212044586, 0.10059171882007392, 0.01752259119624092, 0.12128715508527334, 0.3045462113955329, 0.646300639115995, 0.4873940240471594, 0.5897905617471665, 0.4972679474421086, 1.2822230544782456, 0.7871346884677488, 0.5475617116016727, 1.1718953617157475, 0.9998718504944156, 1.1630540941992116, 0.43812813537736095, 0.40001412733427943, 0.2581485559142405, 0.08718339516030205, 0.16404018557119757, 0.1305606723913262, 0.03965075360611081, 0.6045357931044795, 0.44530683888062356, 2.9614990613152905, 0.8241423123305844, 2.070118376324254, 2.052236413282733, 1.8429424181099863, 2.1742487242144923, 0.6489460326490865, 0.822587153844295, 0.4093862631388249, 0.5224541298324062, 0.19806849349650646, 0.11537329338851476, 0.18297394136748008, 0.2805660965461885, 0.2624354613644462, 0.04905491571633085, 0.05767044776509847, 0.1437730077774294, 0.09263484618596493, 0.06240511628528757, 0.22825821062489865, 1.0298928137748473, 2.008017818293264, 6.612642974622789, 11.733381075243797, 27.913645390541326, 40.66268597879718, 41.33292490436185, 38.706839238443685, 33.68964533652029, 30.308976058037054, 15.814336595996735, 15.182939921655963, 26.104987552089078, 28.31957540204448, 31.02262777666892, 28.336398447713545, 51.36544566000662, 48.03658108557425, 55.127732138479914, 59.30924546334052, 63.66183296326668, 56.18598368860061, 36.47437126405778, 16.388099924210582, 4.886334317345773, 0.5705199570905778, 0.10404584073131123, 0.061312483383282546, 0.11217617865411506, 0.05871457581017768, 0.04762828763153765, 0.06308230736683454, 0.03504694056426806, 0.050061325422458114, 0.00824321810561683, 0.019362458598709876, 0.012896336566266275, 0.010585568323280784, 0.05065650679171086, 0.04188439403209956, 0.05088562836810466, 0.029921392917693145, 0.0334404541870519, 0.06347206225919147, 0.04294376339643233, 0.017664968636968446, 0.007961927856799335, 0.061740745685153434, 0.08600711311784484, 0.03311285583843147, 0.047103980886599714, 0.05601207808321042, 0.05425002223121063, 0.037328978594873226, 0.060555389331233125, 0.016577568115486253, 0.042463384133072636, 0.043892310481638684, 0.020705998702455434, 0.02261034581029127, 0.023797996597544804, 0.03725501663622357, 0.048267434786764846, 0.038708722098700465, 0.05472154168772602, 0.04141809929522776, 0.03744700593092749, 0.04917975357403198, 0.0700834240283697, 0.05509022533172562, 0.09113726686806449, 0.02625001996244875, 0.01514090715171469, 0.08317003672521922, 0.10507296545491104, 0.018055152538562977, 0.04446861161399753, 0.011547905948734092, 0.038265061429551536, 0.02151843686137469, 0.038091718714924595, 0.03900277345711666, 0.07922417063626551, 0.05039116457825707, 0.008197663644809396, 0.03521297480009737, 0.041136803300750834, 0.0724325483785041, 0.05454012823681678, 0.03702358530473806, 0.027407484970265822, 0.07442577126165552, 0.03547957722818659, 0.06986021665075133, 0.040562042005119786, 0.03688052604575792, 0.06131092439435663, 0.01836613444010577, 0.0770486111662561, 0.03518875109993162, 0.05997545311167356, 0.07084146802944523, 0.13162217914096772, 0.5472523346543312, 3.412189690336105, 16.17634782868047, 32.0284293928454, 68.96194350334906, 81.98448704135033, 86.85877723078575, 78.99989281931232, 69.37497692723429, 56.299414711613814, 52.007133653087, 46.170588001128166, 42.05457825814524, 44.51172744074176, 38.26512152148832, 35.02751088911487, 34.48316435660086, 44.02028975948211, 40.803338250806256, 31.76572668936945, 31.060506105422977, 21.230944471974528, 11.147143629289443, 6.106319898559201, 1.9925150179093885, 0.37285998764057315, 0.1613494855982642, 0.22260834282684713, 0.20427279444711827, 0.46038161061944505, 0.9172896560161345, 0.8052203083230604, 0.9637714585950299, 1.6474324897412331, 1.6961265090973148, 2.025052304229429, 2.0943005238809893, 2.6143028659205285, 2.9608403482744774, 3.2039574317393766, 3.863261769856176, 2.6848317394333505, 1.2543608656814023, 0.9718813879355308, 0.28830726180345784, 0.37514115233094464, 0.12209088090927371, 0.09478955274267543, 0.2601637042337849, 0.11374963898091547, 0.2453340193436992, 0.8056224125527567, 4.076981424323974, 3.593970710231412, 6.2138129434277936, 4.716825658275235, 6.639922078578703, 4.821037640494685, 6.115583556313669, 3.5550433926043974, 2.925927576518828, 1.7767341579160385, 1.7917187151408966, 0.6940202559194257, 1.5253012819636254, 0.5246507184159371, 0.48572569905269536, 0.2560366506898596, 0.26630080395167877, 0.31017398521784817, 0.16298710578872314, 0.05061513804379971, 0.31605726468466944, 0.8568162687363163, 1.4820599700174024, 4.851903751973183, 10.62946136920683, 24.498372962397916, 35.11179870174777, 31.253374930351015, 37.47375980500252, 33.02716878152663, 34.919410367165845, 25.802704211204286, 25.22823779813705, 41.32904175789126, 37.53431335572274, 47.335747672665505, 42.25691372348417, 62.910389208024554, 61.004329112268266, 66.9990090400942, 68.01718573416433, 71.22813209410637, 67.6034305941674, 46.414084819055375, 20.40966683818448, 5.817571186250256, 0.5522866354834649, 0.06858874818370228, 0.027986193533926725, 0.031140658238361922, 0.0848363392475632, 0.015137276852563506, 0.04683139148138223, 0.15676552189453957, 0.064365052648129, 0.03567600983285135, 0.02674092910432768, 0.005571700495502522, 0.04685420557976731, 0.0338819774708921, 0.049094434361904866, 0.020182994306988774, 0.01589554014630736, 0.036485803073212024, 0.014899611480594164, 0.05585128771922281, 0.014714896190731276, 0.029129514643441767, 0.02134822170069862, 0.1191780614035745, 0.05607306634286239, 0.0512252006709816, 0.06628209574808998, 0.028003294531616475, 0.08400350208244017, 0.04337271900787469, 0.040461109921095834, 0.03692614658164882, 0.037274360356311646, 0.01219603356965367, 0.01988616396462725, 0.004761077964963813, 0.06844749689222344, 0.04233064790887218, 0.0612447343976988, 0.08858591828855777, 0.10598246503861682, 0.10534952319557629, 0.18308502411650074, 0.13767651071952236, 0.14378460634860302, 0.12340363385456225, 0.1138944679030007, 0.13545431947756198, 0.12796924209162114, 0.175262852722118, 0.15243579212936664, 0.13330654601656622, 0.14143708312223036, 0.16824875087026628, 0.15983958758654135, 0.15324464308158045, 0.17933499308363085, 0.10752854538300347, 0.16808011959637367, 0.1390710512116071, 0.08720757289519233, 0.09478896285497374, 0.21020370926107132, 0.20341252367342674, 0.21688991015957249, 0.07437296482103486, 0.16584682007951124, 0.12149698656773376, 0.14742524002588567, 0.12977947721317892, 0.15200177267674478, 0.15965151300113048, 0.12833599902449117, 0.11957497155714421, 0.09748720879396124, 0.21829676934547965, 0.19582413167001742, 0.27616731161552094, 1.1215728232937476, 5.62459743792011, 21.435309763877623, 41.33951056388117, 79.64368712517523, 92.48288339184177, 98.36593658693376, 88.3184951351535, 77.53447963345435, 65.60838368631178, 54.476791274163034, 51.104878687089496, 45.04525607632053, 46.34942846913492, 44.11897267064741, 39.22584333727437, 51.05837114395634, 50.629244235254106, 46.9325593979128, 55.42331018755513, 47.07525130241148, 31.44218606333579, 16.65186559000323, 10.673648830383055, 3.752432258859758, 0.9755649225365732, 0.2011232231292994, 0.2505953886335896, 0.3423239987704062, 0.3006923601271645, 0.7791112964191745, 0.6597990470547831, 0.7176957435665593, 1.673544688570884, 1.758431152951333, 1.8797641583988745, 1.5660436763878793, 2.472855333359011, 2.5162286575763457, 2.700777399924494, 4.431796823778461, 3.9649597579433076, 3.9675801463665503, 1.7124914954746924, 2.572652933097655, 1.200216222674616, 0.44395046488892653, 0.5729461881902911, 0.35272673733772775, 0.44737037331346546, 2.543771540926349, 4.281769596761273, 10.05141383217227, 4.365423946611343, 7.009360809479991, 7.936323275489192, 6.772276086191978, 7.944853940317708, 6.362976268414529, 3.457941196618542, 3.5175384244611188, 2.104508247106306, 1.1826373853029744, 0.5619482299493206, 0.9048795219390624, 0.4962856695055962, 0.7367392184753573, 0.15993240679944717, 0.26556456281292823, 0.3440177578839564, 0.354545001060732, 0.2201869993680908, 0.7343485338553306, 1.548457116849961, 2.9789825360621176, 7.963952450982987, 14.575479511291752, 34.754290350021854, 51.41515385720038, 53.42478805972684, 53.73495732584308, 44.33714666674214, 44.37507598630844, 27.56677450672273, 23.505468099348008, 37.50823351644701, 39.82053349095006, 45.34672944776474, 44.40778463117538, 68.10863971710205, 67.08637591331237, 74.95731769069549, 78.99542131731587, 81.43376273493614, 82.61936972218176, 59.29643892472791, 26.99708946289555, 8.012549146529167, 1.0111134246953073, 0.15268310063308285, 0.14262681766863794, 0.20777616049012831, 0.2256190683692694, 0.11892847761872316, 0.13752059650517282, 0.3405068382140129, 0.2208515959641626, 0.14130775215885333, 0.10604618823215847, 0.11308668181300165, 0.10028960438625467, 0.267715553843206, 0.170174052398051, 0.14267952451782842, 0.13189941103900635, 0.20178993412804222, 0.15160458673152233, 0.12534044202296965, 0.09371000462241712, 0.11987956045495889, 0.11261162303027608, 0.3481547858926558, 0.159968244392545, 0.15936928620982557, 0.1530682896414111, 0.21089288195775402, 0.1798084354208362, 0.18606614802152882, 0.14643205299733147, 0.10186132569346698, 0.08638324696690806, 0.10850003680154201, 0.12581059784297982, 0.14941650172395093, 0.21645098774423524, 0.11461305071509655, 0.11520627856014237, 0.21002956215412388], [0.054797552931573124, 0.0842486119138137, 0.03023554067758303, 0.027444036940353054, 0.102299704186378, 0.07925833815768843, 0.038573331379842375, 0.06120247698779549, 0.09152325260783396, 0.04901865294443504, 0.020112632961583235, 0.021184541270016663, 0.06199234045080601, 0.0584366352808091, 0.010177525954561369, 0.013087217906309713, 0.07314254334496875, 0.11073654622680719, 0.06106770296971645, 0.019468326204186006, 0.036525815845497196, 0.1711543538277188, 0.014150149579490385, 0.06542450628213345, 0.04718980188631723, 0.05787874707171033, 0.03683509703184809, 0.014555796008226613, 0.028044023596110846, 0.03786779121465741, 0.05018498733519547, 0.020015500673663714, 0.036450038258466995, 0.027651731037504734, 0.009551445386492679, 0.013604321509539602, 0.17344262781402758, 0.7438778709019385, 4.243893719488575, 15.817160702520802, 37.944134358436834, 57.34065494229717, 71.9572614854382, 72.11526240071943, 72.30679958097397, 66.94875563344648, 52.53081321716309, 51.67858808271347, 34.34576372946463, 32.51401685899304, 27.288809860906294, 19.399140727135446, 29.958522089066047, 30.166847013658096, 37.659260457561864, 49.04459884089809, 38.004852648704286, 31.160608914590654, 21.97262348667268, 6.373938312453609, 2.904120669249566, 0.6802885282424189, 0.10243249786717278, 0.08505523355016786, 0.0583579772031836, 0.10354566192554851, 0.04148248132438429, 0.3397000250556777, 0.7666671480382643, 1.683534965399773, 1.1910881318392292, 1.7475243898168689, 0.8178158969648424, 1.3155001978720389, 1.4755734729190029, 2.052874166157938, 1.484286650534599, 0.6739660965338831, 3.857593454660908, 1.413954140678529, 0.7146300435546906, 0.2568772330038971, 0.19208427428478198, 0.08039054716186178, 0.04465934069406602, 0.0732273645999451, 0.04760566888557327, 0.07427699698676025, 0.04019406699245015, 0.34810321285359325, 2.1087488195588513, 4.765652302772769, 6.455292682493887, 3.925693645592659, 4.893734849268391, 2.622039741085422, 3.622935207620744, 4.337438816024411, 1.5241243257637949, 1.5577167296601881, 1.5216153571682594, 0.5670492723584175, 1.103703240233083, 0.7525313549464749, 0.4279516685393549, 0.3077469267431767, 0.3327892991083284, 0.20153979109900616, 0.022340091058023037, 0.11050120401646822, 0.0716000023267923, 0.040372297348034, 0.059037144791575215, 0.36731240790217157, 1.6049034557034894, 5.992009774331124, 19.21358123902352, 42.830293640013664, 47.912273330073205, 55.624743507754424, 28.77404082205988, 35.004259078733384, 33.044572337981194, 25.360658976339526, 31.144578187696396, 10.74425345466983, 26.985840105241348, 44.446125799609774, 30.44912038310882, 43.18572313554826, 46.49062595059795, 51.98707465202578, 56.458423676029334, 60.198960611897135, 46.03516817092896, 17.85119106692653, 4.903922225198438, 0.37410092750383966, 0.07121120504434071, 0.042684584360329375, 0.04962273625536792, 0.10903993726617868, 0.060212863759408077, 0.043633227206526265, 0.07497298020508981, 0.017217550306550918, 0.007882840769936242, 0.03954093490216521, 0.05989432057005264, 0.004571768541580006, 0.112001885990462, 0.031940249102790995, 0.03856828669086099, 0.038605637307609283, 0.014114605972633488, 0.05943529600758226, 0.035802824197397116, 0.036740113620556174, 0.017148933726392927, 0.022975108999338363, 0.05041995033201191, 0.02096923608933726, 0.018650196011989348, 0.01641194948235587, 0.06243029759535867, 0.032961779469323736, 0.050952910040054596, 0.04671467798611811, 0.04684697754020172, 0.0013402704644249754, 0.058033121449332085, 0.07614744661916649, 0.05429518311434696, 0.015566672006952427, 0.013370719276398662, 0.015481165103283862, 0.04357133113268403, 0.04880339372903109, 0.05833920421859911, 0.052163432382287524, 0.08379329521689685, 0.027541008349808476, 0.041120278784224105, 0.031644336150718794, 0.04704896045187789, 0.023741126060485843, 0.01943681509264054, 0.10898534584069446, 0.036997438723882364, 0.06930802813580922, 0.03820999502955425, 0.026397754272986806, 0.037616629288682056, 0.017841320161918, 0.045595155397970835, 0.0192484570546977, 0.0351450611056099, 0.08431618086873524, 0.04134429438460258, 0.01933924613460418, 0.060433382168412215, 0.057557059091425715, 0.015099425405834713, 0.06147501276685827, 0.05081943454100721, 0.005266662957447191, 0.046853680809539174, 0.022261295084571166, 0.0244897969758078, 0.05266734203624149, 0.016079413697063442, 0.0970071244744524, 0.029171806527301673, 0.9360433045414187, 4.860298604734482, 18.530151382569347, 44.7795743326987, 66.97792237804782, 82.62992874268564, 81.40724751257127, 81.52713867925829, 72.43369610078874, 62.29083122745637, 58.412101345677534, 38.65216924298195, 34.416711561141476, 30.684350805897868, 28.330636485930416, 37.69960987952448, 32.625669087133105, 36.03578359849992, 41.03803719243696, 36.10944571033601, 26.707634233659316, 14.783178817841316, 6.478925453078363, 2.211037369505052, 0.505328448789735, 0.14794973446236503, 0.18871717996174292, 0.6519658286725322, 0.8918753326419862, 0.9559674128409356, 2.0113273181261557, 2.3581502754842085, 3.0243106715140806, 4.245786753392989, 3.345355199229333, 4.384045399004414, 5.261438911960972, 3.945390562857351, 4.969394918411009, 5.72636039026322, 6.2909414499036735, 8.224204163397513, 2.4398743289132274, 2.235589445598664, 0.8767143913334416, 0.13879006548273948, 0.027469896238237142, 0.11096266473853782, 0.021940532155455123, 0.04561508900576061, 0.41417244341104265, 0.3357330685661685, 0.782765903540196, 5.6896867194483365, 7.893612096386572, 8.408763447115499, 5.395188793059319, 9.780075050169422, 9.52514256200483, 7.366396515600144, 6.8581887406687585, 5.908579489877147, 5.485794563447276, 5.4355980311670615, 2.991638553719367, 2.578687744755899, 2.4648426665413767, 2.516947922206694, 1.3496205282788123, 0.8762354944502154, 0.8330784521756635, 0.16001846911686082, 0.16224447547668414, 0.17243906795497865, 0.034558548021220395, 0.04271006444469095, 0.2653868610580122, 1.0622459938449245, 5.38585159086412, 16.41417976348631, 35.4606346930227, 42.787233860261985, 47.950014375871234, 28.35047583426199, 27.357961247044226, 25.765212235912202, 29.35344157680389, 34.96071292508033, 20.731775799105247, 40.59399743233958, 60.69144164362262, 40.64469406681676, 52.40903931279337, 57.422459894610995, 61.86641508533109, 65.73645691717824, 69.55364088858329, 54.66962283657443, 22.048562534393806, 6.251015153623396, 0.5629116621228957, 0.11336187591716168, 0.019929687334825436, 0.028573671889100826, 0.09435693523095501, 0.011402708346835308, 0.042364099138085885, 0.048329706243689985, 0.031024214789091103, 0.023093295298636924, 0.039541114932827415, 0.0494880733200379, 0.08582227142347444, 0.03719932970500762, 0.02104191868115337, 0.07867680847524636, 0.1012921606701228, 0.020019432619935083, 0.07580309775808165, 0.06564745318985755, 0.03852233290672302, 0.07970267681465035, 0.026825897831229434, 0.04683519893836591, 0.07318280126538969, 0.05393577296467078, 0.06835968789434241, 0.0902222361295454, 0.04284344801318742, 0.08206410453684869, 0.06398538330329523, 0.08981867633279293, 0.06207534224696218, 0.10418361398361384, 0.031673784570528135, 0.07607356509974889, 0.011139530331767615, 0.02336774055185097, 0.08870895967007646, 0.09735521950548696, 0.18416845630253517, 0.10918779223556481, 0.17555375162872577, 0.18638130127181932, 0.16498918464827925, 0.13426496797511656, 0.15791123702881799, 0.20983103812942583, 0.16285300975845707, 0.08652288947374591, 0.21130371958978716, 0.1360125524262267, 0.1859417966296596, 0.08771619398988063, 0.13484861972110887, 0.17088337320714228, 0.17418947160965012, 0.11095147985484331, 0.21390271883818412, 0.24208913136634136, 0.23053097899162003, 0.14142739977086746, 0.180500166851186, 0.18136189319193366, 0.1991247602047459, 0.18019503403094508, 0.070211123224468, 0.2031555318183476, 0.19888935670737298, 0.14582773219914208, 0.10082318462551602, 0.12382630754502551, 0.10094850128816982, 0.12556617749073815, 0.20257503635460333, 0.4440799643916469, 1.9255854093259381, 7.863660387454495, 26.27100775318761, 59.53354620164441, 81.76843504751884, 93.02930093580677, 91.99315978634743, 91.69214925458355, 84.24444690827401, 70.7447156598491, 66.91510954210835, 46.583864611964074, 44.05263362392303, 39.8090527134557, 32.872378326231434, 43.29120743659235, 42.97602930376607, 50.40336670414094, 64.31755519682362, 49.03708357964793, 38.533368495202836, 26.405390116476244, 8.351421336973868, 3.5529201646004958, 1.3148081446847608, 0.34974126205328976, 0.22172314355209952, 0.6649823366634308, 0.7419183405656969, 0.4662878114369608, 1.2538698339654555, 2.1774645774595203, 3.9984585152518366, 4.793746769428253, 3.7887443361743807, 5.082733765725167, 4.695856177037762, 7.351766074857405, 7.719240188598634, 6.860337709226917, 6.788650510772583, 11.385773766425348, 3.753390297774346, 5.340758552474361, 1.7766543621978454, 1.559238486712979, 0.26177074219430646, 0.12794250562306375, 0.14427240517350937, 0.3394598718131742, 0.6334968584199107, 0.6304092789369246, 2.2346998030139558, 8.4731089491998, 13.55903454365269, 14.709396093122422, 12.790809908220846, 15.30515411207753, 12.336843609809877, 12.981372379487562, 10.060885375545872, 5.452268594695676, 6.067317810750777, 6.048078585055567, 3.617645891443376, 2.7603064765853267, 3.1706942617893223, 3.6942608125748175, 1.920165306618137, 1.9581717252731325, 0.7240016277759307, 0.22324388936883022, 0.41023864320689635, 0.21076123740884567, 0.2300799830305961, 0.2795046051183055, 0.6909356795011029, 2.216634591740947, 7.487139817207091, 23.861538902405773, 52.29270965822282, 60.80939123707434, 70.49065589904785, 41.731720124521566, 47.738429961665986, 43.29625160463395, 38.087775476517216, 43.003866364878995, 18.64435315132141, 40.22955825251918, 59.95345946281188, 45.95248460769654, 60.97923378790579, 67.13737457029282, 72.77793115185153, 75.63189475767075, 81.3247836020685, 68.78759414918962, 28.205481498472153, 9.544456312733313, 1.359836954262949, 0.2399671137813599, 0.10235324607140596, 0.13320131617928707, 0.23834245579857982, 0.19719382026983848, 0.12265458372571778, 0.14098415661963726, 0.08684196509420873, 0.09815391213182481, 0.1643153796753576, 0.1446453367750491, 0.12459906043424723, 0.24369914174800922, 0.1240252529180819, 0.1470331715479974, 0.2045249752700329, 0.062261264125305804, 0.2627857167634272, 0.1640500374619038, 0.11921082698409596, 0.23882421785064284, 0.12527774538724654, 0.14296729778570516, 0.1766814636967836, 0.13848646483834715, 0.1214633629687371, 0.17937066213738534, 0.1567888109674377, 0.2773644006060016, 0.193541833169518, 0.1730926175631823, 0.2585993833359211, 0.1428859086046296, 0.17102712194525427, 0.1681647263467312, 0.11999430510425761, 0.08555392614535748, 0.14024226175200555], [0.08247102745958874, 0.03686184499172434, 0.02343414122268798, 0.01110443297112661, 0.1069219799471959, 0.05352243022512525, 0.05114488784343966, 0.04773612216775937, 0.017623237912513075, 0.04495724930518097, 0.028711493021898696, 0.0069827056534948855, 0.01345014535716825, 0.019316489492813428, 0.06116451350070777, 0.07487022483180608, 0.044444824583948626, 0.04565839212568057, 0.024794142640706514, 0.0756966881453991, 0.006888057405669844, 0.05112185540999617, 0.021261512038988933, 0.04792780502729359, 0.02869597016533296, 0.02778271866601802, 0.01691797162376104, 0.018943814530728326, 0.02613268210552633, 0.06344919070421208, 0.05973945589615934, 0.023740725779545405, 0.056366600591929696, 0.04273362164836257, 0.030390240642572605, 0.04419808298529637, 0.968861714486153, 6.595261481500442, 24.11563200335349, 46.87323747142669, 59.50951383959863, 75.84701322740125, 71.12634658813477, 71.84768615230438, 52.326630315473004, 51.25026525989656, 38.78009342378186, 32.4949090326986, 28.334254872414377, 32.477236793887236, 25.074300458354337, 27.852809429168705, 31.560335697666293, 34.420045575787945, 39.16501129827192, 27.75188292226484, 13.81521140375445, 5.563552610335812, 2.4151079933489523, 0.5280286145787085, 0.3276647224781975, 0.03399958728902763, 0.09310435083123947, 0.08848397496847377, 0.6955960681361537, 0.8876595814381877, 1.149306922189651, 2.478033107134604, 2.850832573829159, 1.4020948544625313, 2.974617673504737, 2.787300963555613, 3.5784604328293956, 4.467833599736614, 3.4394303060347036, 3.351034055794439, 7.7867216256357015, 8.068469397483334, 6.491518222516583, 3.5265378125252265, 0.64430856536473, 1.2875648323566684, 0.1875353361209554, 0.14782667009820863, 0.4047215844113981, 0.05856616159660682, 0.02916383155200991, 0.1144253361910101, 0.30189147158976526, 0.4476580546507913, 2.5855035983747054, 4.295966615599971, 6.633071659072754, 2.5321824079559696, 9.901262560198385, 5.055140381859196, 8.814542447367023, 4.289129434093352, 4.907345964062599, 3.7285842482120763, 5.530801309693245, 1.6342161860196822, 4.002019291923893, 1.3560089661229042, 1.1145875723131242, 1.0973822181263277, 0.9316615880497041, 0.4711042062169122, 0.2150434697227132, 0.1380593401770438, 0.2323250190144585, 0.0837323452616411, 0.10028826373238718, 0.061424615672759475, 0.12027861565471658, 0.8611020710199111, 3.2106134487736613, 9.61538649374439, 26.66574920377424, 32.15485130586932, 49.012109848760794, 63.45255098035259, 75.65100454515027, 79.07120935378536, 62.49401784712269, 39.4927292485391, 27.878081260188935, 21.899845869310443, 26.745330172200358, 32.819461630236724, 34.17659582630281, 48.114157722842315, 48.110058846012244, 51.75827887750442, 57.62378338844546, 51.130283878695586, 19.63146467362681, 4.741112974382216, 0.36728311269994707, 0.08534014164920777, 0.016278776588038574, 0.049029018114050554, 0.03550526415628772, 0.03631414192157888, 0.018248562926366445, 0.046999007688775185, 0.034965474774400075, 0.016044199508013987, 0.07038940720620655, 0.041364871506248756, 0.03193614287151685, 0.07273486199518366, 0.049662614962266344, 0.02390159275232544, 0.029418333621335127, 0.007051322233652877, 0.03937970020718152, 0.08817871191328572, 0.037490600164258675, 0.05250703430764618, 0.03760845130009036, 0.019397706304106022, 0.07232525776470862, 0.04178541930272214, 0.0626124618124337, 0.013782468553061688, 0.03737686292058037, 0.01227144918013965, 0.047207670887151075, 0.032906973539220716, 0.025208113572349953, 0.027614537468780915, 0.01835034728320616, 0.026296958169569413, 0.035914178907630906, 0.06876273441218561, 0.08578893127700976, 0.037996911503855264, 0.008010548584523701, 0.07414082485821939, 0.026478118811463638, 0.0361065014505819, 0.02427404363369269, 0.013382167502817129, 0.040452805527996634, 0.01604684729940228, 0.0357556255203822, 0.029791699977771893, 0.019426442262145783, 0.044356107771877325, 0.03135152585473994, 0.034123976985293056, 0.04957770177673909, 0.03067964567772804, 0.048252599494111155, 0.08170549111861376, 0.0389090885648564, 0.030110687498123418, 0.030886424299810204, 0.034045483616571275, 0.07653196913100059, 0.012402692490497665, 0.060482653113262314, 0.045852924832293106, 0.05595759007959597, 0.029683114675384377, 0.029443064854750713, 0.030616803485299313, 0.030530557306783817, 0.14616379964976542, 0.00930005363414004, 0.023093984777768774, 1.2479965749286837, 7.703134446374833, 26.71597319264566, 54.768443030695764, 73.69316916311942, 86.4669716742731, 82.10681792228453, 80.21418017725792, 63.35069879408806, 67.11328337269445, 52.86439118846771, 44.63467021142283, 39.13527188762542, 40.0746952333758, 30.166219434430523, 33.818099037293464, 38.66571318718695, 35.183574153530984, 36.9416275332051, 22.798247106613655, 14.02300778896578, 5.588657250327449, 2.253554146136007, 0.16633794372600896, 0.3515902918673331, 0.37733553458125363, 0.4098201446956204, 0.6690703656884932, 1.398400594630549, 2.3154976867860366, 3.3563424935263977, 4.992305482587507, 5.605352818965913, 4.86952401937977, 6.1507628040929, 6.7676775974612084, 10.21484919132725, 6.3353510152909065, 8.349398374557495, 10.213842122785508, 9.197706041797515, 8.49107046281138, 9.073974874711807, 4.94810821548585, 1.84269996660371, 0.6794974964953239, 0.23687043317383338, 0.47513073370341335, 0.6452468698543887, 0.0686570679047896, 0.07492001288600507, 0.07697450748134045, 0.5725031442219212, 1.782428703961834, 6.335099003007335, 10.129741603328336, 8.512862170896224, 9.358740910407036, 9.485237348464228, 8.918278351906809, 8.702761761603817, 7.83944171282553, 9.727466260233234, 8.625188066113381, 7.934610180316433, 6.979165913597231, 8.809657135317403, 4.2324918796939235, 3.8810124560709927, 3.5957789228808497, 2.717272682536033, 2.8362739614902006, 2.106538809114887, 0.6939886318099114, 0.8026389597404389, 0.6704961472461302, 0.2357741766759465, 0.06222096023960941, 0.08887377582610616, 0.7435530496220435, 2.9926056631149787, 10.739273025143532, 23.669817370753137, 30.291441102181714, 36.663127483860144, 51.5230151145689, 56.34973479855446, 65.05222297483876, 61.89426391355453, 39.2267180258228, 36.817535508063536, 30.865740814516624, 39.0267595168083, 43.50179164640365, 45.77375004368444, 57.099346806926114, 60.957048862211174, 64.78207365159066, 68.53937871994512, 59.330944015133774, 23.442800391104914, 6.142700372203705, 0.27885324652156523, 0.06258823045138871, 0.020631632632425716, 0.035280126237100175, 0.034519293675980264, 0.039249453768734975, 0.027222400042979468, 0.025425014131131674, 0.0657659593308645, 0.01687673502601683, 0.021908664813024864, 0.02928079019540981, 0.017640603210536704, 0.04815635203774418, 0.06961247913779751, 0.05055079814947901, 0.02078427373611879, 0.03441296450252976, 0.019158091238369385, 0.018664221166663112, 0.008187870168307377, 0.09936268396315076, 0.025785232503567974, 0.0505161824666204, 0.06103373846159347, 0.05224808509792051, 0.07757302899394306, 0.03011140570555243, 0.05047060789600496, 0.08055708701572112, 0.06323106631997132, 0.01862334654546313, 0.02271389791501626, 0.020754193293771917, 0.012115066694546373, 0.04825984668587485, 0.04963430035258493, 0.1123325908256154, 0.1988989328064265, 0.14872974986510892, 0.0795978989692465, 0.19703029114152157, 0.17609114698585004, 0.277800488496019, 0.23326076477045016, 0.14495285978961378, 0.09550847263345796, 0.1548959609241255, 0.1371993911602805, 0.15951418407982396, 0.08994901087135078, 0.10924799908553401, 0.1226610495077987, 0.16233370939810432, 0.13356810375567407, 0.13425039698279675, 0.12470190007720264, 0.2085561912146307, 0.12115590124120637, 0.14790940759403093, 0.1446064654737711, 0.13695284874448854, 0.11028767999021277, 0.1331294264884726, 0.2781857387913812, 0.06256258565812342, 0.18090649988622437, 0.1429588248532626, 0.14691527061645063, 0.14024301251817134, 0.13654024911022958, 0.3332091152908341, 0.18304711808600735, 0.21613975686411704, 2.0865305537177674, 11.739071453771285, 35.80565421811996, 66.95676511333835, 87.7481040646953, 98.48910685508483, 91.29764510739236, 91.76922382846956, 69.53691590216853, 69.79155617375528, 52.589448728869044, 46.835669009916245, 40.40488819922171, 45.73529120414488, 41.215967670563735, 42.46170851492113, 47.20392073354414, 49.87134033633817, 51.705424939432454, 36.05508950448806, 17.638139686276837, 7.477223575115205, 3.539556404275279, 0.9894827176486293, 0.6547334285513048, 0.3220340681652869, 0.40219784564068245, 0.47263877225979684, 1.469391572379297, 2.5252126013079, 3.0946635286654196, 7.48289090971793, 9.273248930131237, 7.153542724347885, 9.80461928152269, 13.268127056860155, 10.808284186547803, 12.00087103151506, 13.775967109587885, 12.870085912366068, 15.819533736475053, 17.36357181302963, 18.586596250534058, 9.63466396254878, 4.320986434336632, 3.958843311955852, 0.6328928134133739, 0.9584836745935102, 0.8948880193694946, 0.5249506571600514, 0.3810760048368285, 0.21388042567958757, 0.709544568052215, 1.6458186795634608, 10.71839620990138, 15.584266051169365, 19.78229549623305, 14.202571934269322, 19.927387891277192, 17.32243399466238, 18.697138447915357, 17.03497721302894, 14.438106340746726, 12.152173519134523, 14.85731847824589, 9.370633536769498, 13.030311792127549, 7.5321480343418745, 4.561259063982195, 4.984993203993767, 2.983128726482392, 3.413461518864478, 2.3557757706411424, 0.4317529048890837, 0.8154255187799855, 0.43199946262663413, 0.22324545218819575, 0.28074183711601847, 0.29693751806213015, 1.3147457544842076, 4.189639004968828, 12.67186011037519, 34.016614114084554, 41.4366598283091, 63.676836029175796, 76.49752263099917, 84.32484765206614, 87.82042472593247, 72.44075636709891, 49.74474976139684, 39.25065232861427, 33.15687371838477, 41.774615164726015, 48.61201240170387, 50.0778962719825, 65.7970340021195, 70.0096321105957, 73.77514669972082, 79.86683860901864, 75.10895652155723, 32.792875805208766, 8.858397487671144, 0.6221249266978234, 0.4086609004485992, 0.146047676042203, 0.11303814248211923, 0.16371654406670602, 0.17126462452353972, 0.08093457684041032, 0.13759985596181887, 0.15365017938517755, 0.0945100991896564, 0.10716170418046175, 0.08099057020679598, 0.17996952838955388, 0.2958972932350251, 0.2132366819968147, 0.11790527526529566, 0.16390543070531663, 0.07617928523329959, 0.17541286805945058, 0.24143774212608415, 0.09536545933975328, 0.23050401269668536, 0.11524512687878263, 0.21595523692667487, 0.21213327023771503, 0.13604581596389895, 0.2195954262729614, 0.10899139793529626, 0.1965776251088227, 0.2481378398595318, 0.18559445236479083, 0.1423910311273029, 0.10657277408867113, 0.11805963432115894, 0.07477391225796554, 0.08100099666344543, 0.12231652444649128, 0.21771362321751736], [0.03250166706200088, 0.0017975179423134957, 0.06766191203027003, 0.016370483058234377, 0.038958681266634695, 0.036638832966526674, 0.04223453451789195, 0.052693239638521794, 0.02236282280195625, 0.013582787735597983, 0.02254397578297123, 0.037638439811886325, 0.08157338691695083, 0.03401121650371821, 0.056243854154261856, 0.06710518061393692, 0.05543042582670047, 0.056420299524982134, 0.0489706268924619, 0.052371467388565504, 0.03572336938833037, 0.017012662006421916, 0.03773563338683979, 0.027419131421934695, 0.039974364467085376, 0.03106338677987937, 0.045375632903268265, 0.053555747388952205, 0.03572090258521419, 0.05309727824022693, 0.07263060508956833, 0.09803463990289359, 0.03726630111134822, 0.06085630100701125, 0.036923591678421346, 0.7232019545570497, 5.217772635721392, 22.395911947373424, 52.10328271312099, 69.29975371206962, 84.64375988129648, 79.37120791404479, 71.20963419637373, 60.28975171427573, 47.53960894000146, 36.24657177156018, 30.869818118310747, 22.274757777490926, 19.466538813806352, 15.79850689057381, 26.683395947179488, 36.63853422287972, 41.690288128391394, 22.641789643995224, 14.910966696277743, 7.899173036698373, 4.055060768319715, 0.9601788739523581, 0.3318763061636879, 0.09565697111670049, 0.08513115286346405, 0.11348740708443428, 0.4047143831849099, 0.9421295360211404, 1.6297805982251323, 2.609558023752705, 4.523449867002426, 3.4062850523379544, 4.645229164631137, 4.361613363988938, 5.701021878950058, 4.153136937848983, 7.6293075949915, 8.092041861626411, 4.028816189496748, 6.715083026116894, 6.5799289364968585, 6.675645555219343, 8.353544319829634, 1.6740310624722512, 1.6211897495292849, 0.49201699694798845, 0.19394724689904722, 0.287524503805945, 0.7104563965432106, 0.24791464780367192, 0.12842267421224426, 0.3022755880749995, 0.38131756768111263, 1.2731499993993391, 6.848293091020277, 8.246198854138775, 5.840792107966639, 4.23438246211698, 6.893505271404021, 7.840566452472442, 4.304773317229364, 5.447000851554256, 9.509539373459356, 5.676874297280466, 6.695060306979764, 6.0573196891815435, 5.010315535529967, 2.4079327525631076, 2.443615289465074, 1.7678649435120246, 1.6114131193007193, 3.00600913743819, 1.6131812502299587, 0.6326322822320847, 0.43109094363547146, 0.4204805952406699, 0.37560981427950246, 0.0384546758516902, 0.023937786576308073, 0.12253352651192297, 0.26081926099235014, 1.8652241773182348, 6.513356508747225, 20.583145426165675, 38.67397762114002, 54.36314059842018, 78.05583323201826, 94.33257118348153, 82.81698657620339, 57.535082909368704, 42.35427087353122, 31.7309078093498, 15.94864933721481, 17.425617825600412, 27.456791247090987, 40.47180383436142, 40.58513679812032, 58.610828230457926, 56.746400171710604, 61.7960673762906, 36.084334696492846, 15.498509310906934, 1.4113069085344192, 0.052776092047532724, 0.07902749288346499, 0.07013757878373708, 0.053788324021884514, 0.0606616227436931, 0.08551973564129683, 0.054030626141015566, 0.0281101101708989, 0.06626315805460177, 0.04641061002809194, 0.06254083259151348, 0.014616461553340478, 0.0463647137005483, 0.04910655004242736, 0.024647748984035947, 0.029139372279807448, 0.07592162688172634, 0.038924839332579605, 0.0456198119378138, 0.09789342691581096, 0.020313694652530457, 0.03701143131981935, 0.0031413370696452237, 0.04461679983163073, 0.04033929811069562, 0.054727846591342846, 0.016813557670121233, 0.05004947021182987, 0.05693059069134536, 0.024928502971306447, 0.025036684162313902, 0.03614209772598359, 0.01734778908411822, 0.10324907098566333, 0.03672859165817499, 0.041397882234906, 0.06599975404359641, 0.039663321278508634, 0.029744449589822083, 0.06894748417600509, 0.01971670914621603, 0.054236002822196296, 0.01977225818160561, 0.013765053459322982, 0.025239170776800286, 0.014772069332520328, 0.045789879626564445, 0.0852908209086426, 0.036363412866428975, 0.048524809685806115, 0.008116279251783366, 0.06385183119545541, 0.05229418826920371, 0.024712772611829064, 0.048464334705063415, 0.013499120400557596, 0.052507302438419674, 0.0643154407941526, 0.03008624737811906, 0.019649276171901056, 0.0459009776973436, 0.060808569898888956, 0.05106051091945941, 0.11929360278431447, 0.07717675469335049, 0.09585429238335741, 0.037469697455244685, 0.02175132567513614, 0.05176037820356508, 0.03390193023087998, 0.05211338002775466, 0.03130111343888266, 0.8873051585208986, 6.339131199544476, 26.689395212358047, 60.62307865388932, 80.21314467153242, 93.1565426241967, 89.80166096841135, 80.18137347313666, 69.8740985316615, 57.636362429588075, 46.55561570198306, 40.59522121183334, 33.208299913714015, 30.955882764631706, 25.49587876565995, 33.383657317007746, 36.75325570567962, 34.980273785129675, 23.24400486484651, 14.265369080728101, 7.053876278861877, 2.8570201127759876, 0.5542678614297222, 0.32697432404083593, 0.33640976935144395, 0.1203343332294495, 0.497029050583801, 1.5893418197670293, 3.226397066347061, 4.611307036492133, 4.8255292446382585, 7.676989397694988, 6.2149773970727, 7.141341211334352, 5.653938237697848, 8.71416703347237, 8.228623693989169, 13.769607966946019, 12.966004533152427, 6.870516259824076, 9.08734917640686, 9.68782776786435, 9.485476613044739, 8.3705017066771, 3.5476788974577382, 1.5428940927790058, 0.6759626442386258, 0.08511635204476696, 0.4748136039462782, 0.59153295212215, 0.4081800117367699, 0.14358301797220785, 0.22828867028076805, 0.888015842966495, 3.396245010437504, 6.014674209779309, 9.261582820646225, 8.795041403462811, 8.928305891252334, 10.572168288692351, 10.215818016759812, 9.930867629666484, 10.922149612057595, 10.623255199001683, 9.876028972287333, 8.22034945411067, 7.691001574839316, 6.652267738696068, 7.6190275530661316, 6.961593204928983, 6.627796071190988, 5.241644180590107, 5.083950190774856, 3.5965386369536003, 3.6348114090581096, 1.3458921928559582, 0.7290732524087353, 0.7078056710381663, 0.5327953362176495, 0.26575476712276863, 0.0453808116576364, 0.3513177484273911, 1.39520974649537, 7.626707063567254, 18.36712787228246, 38.26757692521618, 56.80627515239101, 79.77989535177909, 99.69701643913024, 90.0913123161562, 58.85125775491038, 41.3102065363238, 36.06293424483269, 25.269563890272572, 26.737599180590724, 35.91859494486163, 52.83642468913909, 52.782366583424235, 67.78296532169466, 66.61306350461899, 73.05587030226185, 42.6607217327241, 17.604905443806803, 2.6758549049977334, 0.011427818793773411, 0.10595867800856791, 0.10880159965205578, 0.03346280097180317, 0.041455683568792964, 0.031415942357853055, 0.053348018817843935, 0.08609532048144648, 0.03279674497823561, 0.03454053346368094, 0.019587558213501208, 0.055290270040953354, 0.010907869173904822, 0.0750173060523887, 0.02248066627690869, 0.052719148732120955, 0.03987999392613288, 0.05463652891076861, 0.052034116740668976, 0.03512049266587823, 0.04675612334282168, 0.04960319335241953, 0.04271766020646019, 0.07572881021206418, 0.018145123819610285, 0.06046970239690235, 0.08836148517026056, 0.09236603359421415, 0.05235932872540528, 0.13975984086432766, 0.03240031362961858, 0.04279207798742479, 0.03131319847588818, 0.10352227326122024, 0.0745052145794034, 0.09466893219899747, 0.04933432330407443, 0.20370343790179302, 0.13240665317543093, 0.19886971421299443, 0.13182638753806392, 0.19209293107832634, 0.15414802928365048, 0.1535492089967574, 0.11046433220467261, 0.11387434277322986, 0.08858879877915306, 0.11820820941319389, 0.11516860235602626, 0.21563040032502145, 0.23224542247912577, 0.20856189090878735, 0.1252945227127883, 0.11528289501344967, 0.15304187492978188, 0.12915137704581986, 0.13646932469019968, 0.22140592186441346, 0.14126472866102574, 0.09568750738136231, 0.10198340946508032, 0.10299200252179178, 0.16337039489899913, 0.24278046443097054, 0.16211702908960082, 0.16565946561674919, 0.17102860815582738, 0.1840151927524036, 0.22414608047373835, 0.1335182161100449, 0.17027523729108995, 0.17408715290648324, 1.5683560361785274, 10.35901394582564, 36.79317758929345, 73.98677425999796, 91.61493347537134, 107.24820660006617, 99.38237959338774, 90.42836942980367, 76.2116289138794, 63.965047867067405, 48.55327490837344, 43.11298670307283, 31.409801014008064, 29.01198748619326, 26.398882904360374, 39.601112181140536, 51.58079162720711, 55.59505116554999, 32.677893484792406, 20.627234828087595, 10.360547592563014, 5.596656924293888, 1.3108825875866799, 0.9023196238183206, 0.44686187479284506, 0.26056522623665873, 0.34934945404529577, 1.5864415947468051, 3.2300041760167773, 6.2272956005988584, 7.735869567240439, 11.767954807127676, 11.784868067310704, 14.033057881939797, 13.311745774361396, 15.518477116861652, 13.00943301570031, 19.1712627872344, 21.97730483547334, 16.304963327223255, 18.680941020288778, 19.334984479411958, 20.685023107836326, 19.166175473120905, 7.374792348953986, 6.123993608259386, 2.3511613472815487, 0.5318944168186958, 1.747127985281329, 1.74786391998491, 0.8231717095740381, 0.3263514945583959, 0.4992537086288776, 0.8838369865571299, 3.174015283584595, 16.543180634898526, 19.176865893025553, 18.556384194281794, 16.624977742472005, 18.48109429882419, 21.14206748624002, 14.519404326715778, 17.802306567468953, 21.31191788181182, 18.69740320790199, 16.492366329316173, 16.563349462324574, 12.40610089994246, 8.24098994654994, 11.594083001536708, 8.774267550437681, 6.1441040904291215, 9.590785388023624, 4.610300948542934, 2.906221833921248, 1.6245311186198266, 1.0850842393213704, 0.5816430634548587, 0.504898275098493, 0.29064208329204594, 0.3094675908646276, 0.6790439111571158, 2.6362423983312424, 8.90346061798834, 26.205280596210113, 44.54960969186599, 60.258576716146166, 82.54076542392855, 98.49976001247283, 87.95468745693084, 66.73263303695187, 54.231599992321385, 45.79743331478488, 27.15343317677898, 30.774828118662683, 43.389200010607325, 57.722972285362985, 58.708510937229285, 79.58482803836947, 76.52089211248583, 84.55819729835757, 54.810549674495576, 26.02299628719207, 4.466754457642955, 0.22572802139386056, 0.18327527439161656, 0.2505855060993664, 0.1661580662813879, 0.18064982978807342, 0.17616957906753788, 0.13105582566030566, 0.20578874455344295, 0.13871737906048376, 0.2313432620177346, 0.19235677175944854, 0.09513078362590845, 0.1008041933058731, 0.14633256881948442, 0.11685182009973835, 0.20201729370221017, 0.09060135772151333, 0.17528163719802134, 0.10652153046741601, 0.2040629782864163, 0.21979630984846624, 0.11064573416426299, 0.08338968179398969, 0.09320659292561394, 0.11340753475744879, 0.11690942991164424, 0.07126494611222899, 0.12862729629681957, 0.11230568581771468, 0.31036869412468326, 0.19996218623653536, 0.10627792982925331, 0.08825128342235282, 0.15232268690822587, 0.2399602955988338, 0.1512021454231393, 0.1781854628314895], [0.05033139822884433, 0.04584291972400201, 0.006979512982070447, 0.007818002439659811, 0.06705683280503558, 0.014059606605329582, 0.031077530678181402, 0.10356636928214182, 0.03924368129622552, 0.03195900101995757, 0.03222886698260423, 0.02790170169675783, 0.06462106391066505, 0.012504926923992894, 0.02144308828358208, 0.03134335169658786, 0.009910137328739849, 0.026975654613887592, 0.03514407285218758, 0.04400601325136039, 0.06091563834718639, 0.04078637170154722, 0.07948664002000325, 0.05037583515889222, 0.0235264050218487, 0.051306091894906376, 0.0781095433499544, 0.05629780589632931, 0.07225490791062195, 0.08152311622735955, 0.022618554442399935, 0.062497839737202854, 0.03819291509928242, 0.009817940562272505, 0.4387202906993128, 6.899360389478746, 33.11169978111021, 53.04106258576917, 76.05033320765342, 81.57934542625182, 73.19356118479084, 65.48920246862596, 60.27048503198932, 41.957742783331106, 42.38356705634825, 26.034220149440152, 26.2420214376142, 24.74798475542376, 33.44523068397276, 33.111260475650916, 40.859192802060036, 43.48948324880293, 31.412032842636112, 14.96393144130707, 7.003652289990456, 1.1146704323830143, 0.01484661351799244, 0.11197151826514352, 0.08301901781270582, 0.021483328967024724, 0.30117226824645077, 0.9674944007588971, 1.6143551420780922, 3.0043124671905272, 2.560863268952216, 3.8830064910073436, 3.8604388890727876, 3.418531917756604, 4.525553238007331, 2.4355901200925154, 5.462758483425264, 6.054109229195503, 17.730401677470056, 5.1376954874684735, 8.111658615450706, 9.835068641170379, 7.3691779663485875, 6.965667076649205, 5.57541827040334, 3.9376683965806043, 0.7188225669726249, 0.09947338366820928, 0.051958622606170755, 0.7623978319668001, 0.21659118183437856, 0.2356918835111203, 0.855415553575562, 4.3076121326415775, 6.230679135168753, 7.404788184550501, 4.482041895389557, 8.861460858775724, 3.9765484006174154, 9.725124605240362, 4.5248496628576715, 5.655370883403286, 6.819624487430819, 5.757667278089832, 7.232585347467854, 9.228009293156287, 5.23645390425959, 6.610548428950771, 8.517608238804726, 7.077553666407063, 4.516709273861301, 6.407970266957437, 4.983895920938061, 4.225822379512172, 3.3869561024250525, 3.6009309561021867, 2.125473805973607, 1.8396700582196637, 0.42428443628934126, 0.43781063789802216, 0.05567446696541964, 0.15979515448693307, 0.10977443172446183, 0.0029501990901471507, 0.24132960115469274, 2.7554488662750494, 8.42263687041498, 24.103056884581044, 35.908977293199115, 33.35452195136778, 38.543017525826734, 64.33259356406428, 67.54217886155652, 48.82021965519075, 37.1190716374305, 26.445682664071363, 48.28174883319486, 31.42994434602799, 32.27243611889501, 47.16264563222086, 53.69754183676935, 53.59188495143768, 49.652742724264826, 27.327421672882576, 9.170692678420775, 1.1041635058579908, 0.11280974102837425, 0.09214453459266694, 0.05106182092980993, 0.02741211980220772, 0.08643592317258159, 0.03811898761458936, 0.02324417248488434, 0.04916712461460022, 0.014142692671157421, 0.07144083989964378, 0.017726169486019402, 0.01257206782728674, 0.043688113575861345, 0.05268848606295163, 0.02044901642347536, 0.059046073546332706, 0.023433338745587298, 0.11840133251802576, 0.019094835358461546, 0.0361033873031697, 0.03779821127893464, 0.007935852617881592, 0.06657327810722975, 0.027438639850926497, 0.0898585971745272, 0.01880391538443585, 0.06433034120427986, 0.06098351756771726, 0.022450089792630846, 0.04907713609657461, 0.13657936555964334, 0.06276956729350552, 0.017727270737410556, 0.06986855934824675, 0.02998597221449018, 0.002958586077100688, 0.026709536736410473, 0.01152604562981475, 0.0990584015005058, 0.003924154438972173, 0.08261249325568638, 0.032991760320240454, 0.0429529756037218, 0.08764913065298911, 0.007326616886852971, 0.03774152077253788, 0.04283721971836302, 0.037287119550690535, 0.04971498856320978, 0.01316562892057963, 0.025082302782984994, 0.020599885948843533, 0.03745750899636938, 0.04889987101177535, 0.034876547288149595, 0.054587131561411005, 0.029828194491264802, 0.03483707460785105, 0.028753315676904978, 0.0123184563351735, 0.07338171599492913, 0.025179869825801542, 0.029090470972380815, 0.044317581210165255, 0.07071217537046441, 0.027495418457434546, 0.07492512269246002, 0.052462988082439675, 0.07586750276987592, 0.03740514688674481, 0.3047385607515612, 8.2558370982447, 36.815656692751, 62.11216726610738, 84.87892950734785, 90.16542942293229, 83.45374414997717, 74.33406875979516, 71.58099635954827, 57.7087733053392, 52.59489690103839, 39.04116246008104, 33.33503169398154, 29.061095560750655, 31.303500859968125, 20.66056320744176, 33.9459643825408, 32.5719992960653, 24.14628532625014, 10.681323928217735, 5.656607900896381, 1.6015475002988693, 0.12494056710913298, 0.10033606761886228, 0.18943679699253654, 0.366404808216518, 1.4083257846293913, 4.687092621480265, 5.22719269798648, 5.572704480540368, 6.340385867703346, 9.668597367502029, 7.553467096820955, 8.633752561384632, 7.428617563939865, 9.200187921524048, 11.286734900166913, 10.800014849632017, 11.55398755304275, 11.552147961431935, 11.37910181476224, 11.359812578847333, 8.698279473089404, 12.81621019686422, 8.19029527325784, 7.3711416029161025, 2.5036719249140833, 1.155645227239978, 0.37928216399685033, 1.2111034965322864, 0.2858983136473164, 0.23003479916482206, 0.9717452081461108, 3.0655600322831065, 5.641573456025893, 6.634725428396656, 5.210003891298848, 4.408692592574704, 5.703940612654533, 7.824373437512306, 10.178008329483772, 9.3135630507623, 7.777264791150247, 9.727841827177233, 8.230673132404204, 6.07082195820347, 8.440317934559237, 7.0992914419020385, 9.200597809207055, 5.627646100136542, 9.12265246914279, 9.675381106715049, 7.025825448574559, 7.332166971698885, 5.855710352620771, 8.283919307493395, 4.195880966801798, 3.7818885234094437, 2.93769909970222, 1.5688773436892418, 0.5716135016372127, 0.46114294879859496, 0.17608921644428085, 0.0789740352681087, 0.47370029433119687, 3.060710757009445, 10.85626163790303, 28.115814155147923, 47.56791668553507, 41.56915749272993, 40.57104372209118, 50.76851191059236, 58.68715755401119, 42.737584498620805, 35.098356739167244, 32.15967385999618, 57.89921222194549, 39.41950251979213, 41.973914715551565, 57.13363224460233, 64.86801670443627, 64.20635600243845, 60.240212178999386, 34.08642053604126, 11.060806378241509, 1.2482501806751376, 0.09300292079006472, 0.09526356964582398, 0.02643985080442602, 0.06618719277603012, 0.08947006802284911, 0.033318983285777995, 0.046593375624187534, 0.04477714969506187, 0.0408418134846274, 0.1330928994162429, 0.052844021063778675, 0.018644480996074218, 0.03851628081212121, 0.03163045272231102, 0.04829672232811009, 0.06221583128095635, 0.04225234606213147, 0.026112750412956364, 0.03249168110590789, 0.027212774148210887, 0.04778069699363363, 0.030118193244561556, 0.042786723032834074, 0.054368455593864766, 0.029694872209802273, 0.021375712765861424, 0.025759145294526414, 0.05229906824928138, 0.05701128656284944, 0.03206219306335815, 0.04734551691780648, 0.0239089950768938, 0.0963205871202292, 0.009582439388689256, 0.03732587210834026, 0.010487405647103105, 0.0974365167560116, 0.17384421110393541, 0.1779786037701753, 0.0900678004648897, 0.19182490755713758, 0.09787751526962366, 0.1595857979789857, 0.19859085820855635, 0.14280962156912974, 0.15802688566186737, 0.07144162130932655, 0.14536450947484664, 0.19428397318528545, 0.12472097566651723, 0.10577934448637309, 0.0842784816819814, 0.10131456108102876, 0.16590148811378788, 0.17180868484560521, 0.14239990242546605, 0.15426570038881995, 0.0887364928700751, 0.14763596017033825, 0.12184333491830096, 0.13001143331489257, 0.14024048442802123, 0.19349111814893064, 0.1754372449772012, 0.13714181199189157, 0.13787246068879483, 0.19197176661222212, 0.2679605181178739, 0.1484311287922244, 0.24358258913120917, 1.123608165690976, 13.395029460230182, 48.09746019301876, 76.33726243049868, 99.96573017489527, 101.07984804338025, 90.27812696272328, 84.00211503428798, 75.50089543865573, 57.2846003501646, 55.16173516550372, 38.59627154565627, 36.521733883888494, 34.85586404800415, 46.069022147886216, 49.4720861988683, 55.476254340141054, 57.06212351399084, 39.24193289972121, 18.028741075146584, 9.12962350153154, 1.9386267998526174, 0.13719047389684186, 0.19224077072595397, 0.1682918662986448, 0.31479275995685213, 0.7722076797677625, 4.13157174664159, 5.23495702974258, 8.320829791407432, 9.090835182897507, 13.657172245364036, 14.177310889767064, 13.634302866074348, 13.445600578861853, 14.435116514082878, 17.43236626348188, 16.63750187043221, 31.887777120836322, 14.01928840144988, 23.043389358828147, 22.107729527258105, 19.9697926352101, 14.948413564312844, 16.84541298497108, 9.455945088017373, 2.1673259860084904, 1.1741949738033357, 0.4363131811541896, 2.5915489514027876, 0.26401007848401226, 0.4125085617265394, 1.1277053264840957, 4.685822754136978, 9.544669101315161, 12.503554148058738, 14.231548443917307, 21.358068489259292, 14.266975291313665, 21.460669848226733, 19.60154091158221, 16.103434889547287, 19.749959476532478, 14.887106918519544, 18.512843924184, 19.02326979944783, 13.6310012109818, 14.771363658289756, 23.798771173723285, 18.3565668905935, 13.978668335945377, 18.818267122391735, 14.167779530248335, 12.799519531188473, 9.791397952264356, 11.255690320845574, 5.870221161073254, 6.550296410437554, 2.310917829313586, 1.9125942741670918, 0.5698502123836549, 0.5685622653653545, 0.17033747427405851, 0.20054332521413604, 0.5274149475078429, 3.473096254371828, 10.846808725787747, 30.551662906523678, 44.3863881018854, 44.40840436566261, 50.85729083707256, 74.60495548863565, 77.95620502964144, 62.30328083038331, 49.72587139375749, 40.854093720836026, 62.15924355291552, 44.64420157094156, 50.10334068729032, 67.27334745468633, 73.76221856763287, 76.46426093193793, 72.7795079446608, 45.763324383766424, 16.87628596059738, 2.4540730637888757, 0.26998703518221456, 0.20689963333068356, 0.12005360797047616, 0.17840045774655958, 0.17675520732037484, 0.11912309459500736, 0.12838715071519538, 0.12015601860419398, 0.1593000318614706, 0.21391258605064886, 0.12522722954951948, 0.15440551143500114, 0.1477544126851905, 0.1820146154251791, 0.16622099274348828, 0.10175441812363364, 0.13605667909066524, 0.17855692354421462, 0.1473129621797031, 0.12543604979591985, 0.13221925274739343, 0.30796921481528594, 0.16427678416573233, 0.09959349093297798, 0.2215407839826038, 0.12494577650701809, 0.17138762760066217, 0.17782857311108421, 0.10816766189471369, 0.1613212782408922, 0.24086038762282944, 0.20677701329752324, 0.1877125475796, 0.10544402780191553, 0.14433971365853665, 0.08936375034071746], [0.01824196307889877, 0.04130931097954031, 0.04116083164849589, 0.025296225174961072, 0.0332536589684746, 0.007738793257533783, 0.01831686541047548, 0.028153522458348065, 0.037894929879375046, 0.00736109946193474, 0.09144375566393138, 0.0064441999476853645, 0.07926954602402064, 0.07545633572003535, 0.07006708337294479, 0.10336805210118333, 0.010322140372027794, 0.027269864935548078, 0.019860390851634647, 0.028295725614072818, 0.05648861541562984, 0.04859872950961994, 0.054817517182879874, 0.06581856658862484, 0.07087685363066774, 0.07499495160675819, 0.04268284534074126, 0.046668697388902794, 0.042587609120434335, 0.044626008208480575, 0.01884164521470666, 0.0577044582384969, 0.048169613019713474, 1.05715291875024, 6.273796279584208, 24.492371736034272, 58.92857943811725, 73.18353560663039, 74.0003848844959, 71.7862775248866, 63.67570246419599, 57.769679869374926, 42.96351302054621, 35.11377165394445, 33.63750919218987, 24.795804331379554, 29.193534389618907, 34.63484633353449, 46.925985505503995, 48.34020783824306, 46.848608909114716, 23.96401866789787, 8.003786081267942, 2.4822177858121934, 0.3186225560643981, 0.04115135514087254, 0.03868809901177883, 0.12089595228673951, 0.18908183781370042, 1.1943338931568208, 1.2446896491512176, 2.927849537903263, 3.9884721607931204, 4.888805900850604, 5.6528071241994065, 4.406448506539868, 8.057941755940838, 4.163520922583919, 4.411863338562751, 5.586877965158032, 8.275759796942435, 6.549535470624124, 8.826796912377882, 15.897263346179841, 3.1754364073276524, 6.068588658686608, 6.53467704211512, 6.717098634089194, 4.586013142139682, 1.5031069180657788, 0.30538896939927535, 0.6713885477473659, 0.88744213504176, 0.0723778190571935, 0.16006754470929024, 1.1384258996094427, 9.385759176746491, 14.42565183485708, 18.62319196424177, 21.358035149112826, 6.389866077130841, 3.256354903982532, 6.967260049235437, 3.2767083279548155, 10.017691254615784, 6.393544770056202, 6.617798930214298, 11.18287838274433, 6.221901361019381, 6.234247511433018, 6.667994481901969, 4.5295520943980065, 3.5062253282916163, 6.33805597982099, 6.882233360121328, 4.774005480350987, 6.062280506856981, 5.177434490573022, 2.6598212363258487, 5.969827790414134, 2.8300351865829962, 0.7133343743701136, 3.6717694517104857, 1.5626375881894943, 1.1217789928759299, 0.20139953572182887, 0.19893196651772146, 0.0929679641980798, 0.030791965658746423, 0.162806247751559, 1.4118424346370082, 6.6344474304106935, 16.872253764060236, 41.047513638773275, 68.34212272397934, 87.85163894776376, 97.81504754097232, 64.26122996114916, 39.88027903341478, 23.9142692858173, 18.511243597153697, 31.872899570772727, 30.93535896270506, 39.94585321795556, 48.91762779605005, 61.80393565085627, 46.490582804526056, 33.11395122158912, 22.018654461829893, 2.341550804914967, 0.048988595484725894, 0.05862772825264162, 0.032048443700337124, 0.033735466985813076, 0.04362486918727237, 0.0420693697918567, 0.011315135878600903, 0.021314875808574503, 0.025432558181966027, 0.07350163939859598, 0.09137237925202617, 0.018977876715061646, 0.07619813865711612, 0.13054574899856122, 0.06450714663632455, 0.08739318067748701, 0.008458735875695223, 0.10989436278900794, 0.02093593999292822, 0.03405597902113392, 0.07391970890063433, 0.04598502903395603, 0.01761366181345957, 0.022173028349155383, 0.0741376379324544, 0.02910689972791701, 0.04537587422096441, 0.04256940687135343, 0.04265655320317995, 0.022462247607989178, 0.07462017373332093, 0.04970299545675517, 0.024554663555576436, 0.017235714251235608, 0.05563913499035182, 0.09213752488815978, 0.08265265924555641, 0.03207196834527197, 0.09682456572209636, 0.017472569485225024, 0.03253235271380794, 0.016723887078584205, 0.07122799769164094, 0.02476712080439733, 0.05279308387769326, 0.02990076216989227, 0.09607195328440397, 0.03764166887248716, 0.04325053181439158, 0.06744716226333572, 0.04328607063319895, 0.058010115828965945, 0.022299197284624945, 0.021861985160578645, 0.04155258986077482, 0.014582724956374978, 0.061441469607093645, 0.05867035721518821, 0.03370311126233109, 0.042832462312353235, 0.06121345502775043, 0.043248907707992106, 0.03212799043995479, 0.055085433451759244, 0.024331856458898515, 0.035364085643161694, 0.06759079608825908, 0.07222978022670554, 0.0427064408488091, 1.2710089981555939, 7.992307264958659, 27.045903359690023, 67.93531802392775, 82.754926835337, 84.93400742930751, 83.10070730024769, 73.42088607049757, 71.8468467650875, 54.9532219671434, 46.55709443553802, 46.15228622190414, 28.819661909534087, 31.278829151584258, 34.51391966112199, 32.90809739020563, 40.65368021688154, 37.55721607515889, 18.86643186692269, 8.39292001339697, 2.500407042041902, 0.38453712879169377, 0.0791124520342677, 0.10619302430460531, 0.27328274543246917, 1.1291629772993828, 2.5760220039275388, 5.072266430624071, 4.937848766003886, 8.027922386123288, 8.980722485050078, 8.271145128434705, 8.941203624971452, 9.418444287392402, 9.645540695036612, 10.077931015722214, 9.081200861161756, 9.48193177100151, 10.14037024590277, 7.675925945082019, 8.168637416055127, 11.181609495993584, 10.675874775455846, 9.350377436607115, 10.497888403554118, 6.134411423437058, 4.008448301784454, 2.201207664705092, 1.2303206588952773, 1.6459030105221657, 0.10371964815403185, 0.19722380495119482, 1.2068891549302687, 8.183594884410981, 13.528439075716081, 17.2128527779733, 15.214543438726857, 5.804617558756183, 2.5159536013680124, 4.690451150940311, 6.448865878966547, 7.865610295726408, 8.389173169289867, 9.079613281834511, 7.686137345529373, 7.684621349457772, 5.830308593088581, 6.102230827654562, 5.716934934739144, 8.266833463022786, 10.649291892205516, 9.349325260808392, 13.199507151880573, 11.107563972473146, 8.963466998069517, 7.811726245187945, 7.0438129478885285, 7.487481553708354, 4.926867110113944, 5.285026575288465, 3.195309586101963, 2.0032674602923857, 1.373081940316385, 0.12860961498752718, 0.20881028725735604, 0.10234610613195166, 0.15099194621847523, 1.689835762785327, 7.663499876376122, 16.099210496871702, 34.13130814029325, 58.55430687627485, 80.68062843814974, 95.02288479958811, 72.51644242194392, 48.94383707354146, 32.05571536094912, 28.37997990269815, 37.14042502064859, 37.21102768375028, 47.683877637309415, 57.73433539175219, 68.97105124688917, 57.51191346876083, 42.993005321871856, 26.745694952626383, 3.54644212511278, 0.10530962533647976, 0.05851212941530732, 0.044137408821693355, 0.07594562841639405, 0.012726929628350323, 0.04591954766862816, 0.06653328065670307, 0.0377038330771029, 0.013127648196513615, 0.051442405749713226, 0.08061842767581825, 0.024731442174543778, 0.11869391681806696, 0.03834782190801155, 0.05260948707619983, 0.0336774664690658, 0.05972650134935976, 0.08574416875959405, 0.06367006534410101, 0.0407976983115077, 0.07378532175695704, 0.02589400741271675, 0.01606900256217247, 0.011858271149497841, 0.06346541261600872, 0.036961260221658215, 0.0669915467921284, 0.029973806738252604, 0.006258835877111603, 0.03637109289786989, 0.017563419852165446, 0.06058501778170467, 0.02761290953194182, 0.1269776715085872, 0.016339525445214203, 0.030709053877921357, 0.21546218273860795, 0.14085433535998867, 0.21306377595230458, 0.11224127314504116, 0.11885039027660124, 0.09653948908371311, 0.12359381518176488, 0.09842093207783277, 0.1767581184544871, 0.11738109492486525, 0.18684035647780667, 0.11388049445926182, 0.2192001249040327, 0.1682272084778355, 0.17524468111655406, 0.22807689293497996, 0.14169718529428207, 0.12650854224639554, 0.13632902334774696, 0.12315703781261561, 0.16119528742086503, 0.17136443045831498, 0.13599480982990036, 0.3131112888936074, 0.14317852354818775, 0.1782023933746161, 0.1944499078296846, 0.15507499567202984, 0.12266325584102063, 0.1502497602374323, 0.2606073917160111, 0.16513066576613536, 0.25019693098241286, 1.7892785105974445, 12.391335137428777, 38.36875838618125, 78.17589698299285, 96.20819368670064, 92.68727810152116, 90.63859278155913, 80.30113127923782, 76.59559757478776, 57.070015322777536, 48.907457090193226, 43.782645117852, 34.53527696671025, 40.831955863583474, 48.72334103430472, 67.99704044095932, 68.10043411870157, 58.42648859946959, 31.179816761324485, 10.25906705087231, 3.30887911781188, 0.48674091876995185, 0.17093902183396203, 0.13411409461930876, 0.356924623371132, 0.9296495347253738, 3.5241907642733667, 4.631068427716532, 6.837059422846764, 11.485088179188391, 11.114028038517123, 14.092310186355347, 14.71995315244121, 17.766962089846214, 15.152815138140033, 18.376457229737316, 12.831598635642761, 18.042732169551236, 17.146213669930738, 19.256680242476925, 33.57355886890043, 14.761455751234486, 15.027527770688458, 16.85838230194584, 19.91904697110576, 11.567357932367633, 8.569828714093855, 3.837405505680269, 2.6541850355363663, 2.423460925779035, 0.31974931818342983, 0.7901516652876331, 1.785666497965013, 8.568129347216699, 10.712088058071753, 15.48519874772718, 21.78642269103758, 11.388654747316915, 13.453977780957377, 18.218530839489354, 14.358626373352545, 21.38775887027864, 18.94500086384435, 20.111678492638376, 24.804925803215276, 21.252943085085963, 14.07674426032651, 14.505339687870396, 12.442572078397198, 11.596179508393812, 18.29093583168522, 17.220660255801295, 17.162442476518695, 19.193875251277802, 12.468347933984573, 14.173582676918278, 14.425284112653426, 11.532043853113729, 6.169919660014491, 7.561810958770014, 4.056559358873676, 4.26971125025903, 0.997155364001951, 0.7445454092756395, 0.32569029939270794, 0.2108016562077307, 0.4849933496406002, 1.939559956231425, 8.395824528509571, 22.154639113333918, 49.28336135802731, 75.94583342152258, 94.28195691877796, 100.65296080804642, 72.57949844483407, 51.857691349521765, 36.64549250756541, 31.58909843813989, 44.44224657550935, 43.83138841198337, 57.124873592007546, 67.8389375440536, 80.86170857952487, 68.63732030314785, 55.65948001800045, 34.59697977189095, 5.3663074008880125, 0.2901857400373105, 0.2758917344673988, 0.08957764208917657, 0.11704390132499319, 0.1363577210013905, 0.14260175127175548, 0.0968318205747393, 0.21488525724459082, 0.09834515066036294, 0.1616802057551761, 0.17813641788257709, 0.13845631161764746, 0.17995308814269884, 0.16134583901974464, 0.16230246833255216, 0.21137144176229355, 0.15245613942463554, 0.1738249669752775, 0.1861745494628145, 0.08187633638660755, 0.3961000615550626, 0.18679736362349603, 0.20248776361826928, 0.10977830046847945, 0.13662772102942392, 0.09262222105697279, 0.10684458208420586, 0.10639765405005987, 0.19721592956733322, 0.15640002134586536, 0.0930517588952376, 0.160193428277008, 0.11912713953924757, 0.1952829518385472, 0.1765100438628466, 0.13898305835262423], [0.09579735672882489, 0.08921605624979542, 0.021645925383293824, 0.05263951006195238, 0.014669228731955012, 0.032583860635396936, 0.01842057073278533, 0.06314816028480569, 0.02232360484589252, 0.016036750260560263, 0.010622103056389718, 0.01657040136295461, 0.021103140597622243, 0.02984545445219884, 0.04598347387546974, 0.04141880026567848, 0.003319996913271626, 0.028577107793441223, 0.08768608673445641, 0.06153554903463491, 0.038359589018528505, 0.0383792046998297, 0.05037297765093465, 0.08907954704256789, 0.072278541723086, 0.04326429458395128, 0.048229099747033856, 0.036780264288667715, 0.029640828537183906, 0.01675797033033544, 0.07653172398286481, 0.25311427040686535, 0.28192553488958266, 2.799828768737855, 12.732901015589315, 52.41642905819801, 73.62091910454535, 80.85586424796813, 75.78486719439107, 58.23346876328992, 42.269598668621434, 35.17011650146977, 34.95315451775828, 27.258499745399725, 18.485616791632868, 34.203471906723514, 39.524241570503484, 42.89840559805594, 55.0424127424917, 24.754038933784734, 15.57710478382726, 6.77629259324843, 2.087460155448606, 0.29931689522439436, 0.17208536516033834, 0.14726448413585463, 0.08764051216384096, 0.22821203084482303, 1.4065656210145643, 1.6989770916200455, 7.163970835747258, 7.160102888461083, 7.63675372446737, 6.739373284001505, 6.5812394984306835, 8.719472039130427, 4.9865748997657535, 8.429737341019417, 7.05087419479124, 8.690299410973827, 6.992521584033967, 10.620052583755987, 2.945289866578195, 5.473132171938497, 10.995987249958901, 11.72173849997982, 6.454355236022703, 9.847759469862908, 4.4694152955086, 6.03739453900245, 5.401050775281845, 0.7247477361271459, 0.508327836230878, 0.17562919596750892, 0.6662699159595274, 5.388974287817556, 26.950001408976895, 40.56325781729914, 41.093597565927816, 30.988650245051232, 15.414147953833304, 1.8364392509383543, 2.287011473409591, 4.661954151045892, 5.360663600506322, 5.979704318508025, 2.878232780964144, 4.853079482432335, 4.109574849567106, 2.95343172646338, 7.975004219239759, 5.3962978432255415, 9.460847070140224, 1.9541482314948115, 7.736269648998015, 8.743928017154817, 5.2793612018708265, 7.770492328751472, 6.153034346718942, 7.809049227545339, 4.243826058603102, 4.110392663748034, 4.742125926479217, 1.4392737755852363, 1.0356813741307105, 0.9774367511272432, 0.6821525120927442, 0.26810696348547935, 0.02308837126850361, 0.054038463220480955, 0.27544688253152755, 1.750548169497521, 11.348594600154508, 20.8455970979506, 37.59551409752139, 49.0721260347674, 44.021588064009144, 17.362746154108358, 23.65805418260636, 27.379928481194284, 24.22435422097483, 20.942556127425163, 36.25180421337005, 36.106280357606956, 52.91316978393063, 54.490425432882006, 57.64493673078476, 53.77929579827094, 36.43226462025797, 10.529612533507809, 0.5264330679370511, 0.17715746476765604, 0.06929239994215389, 0.021193012287239396, 0.09354759398246966, 0.11721726702225786, 0.04197494179430989, 0.1444173796523002, 0.020443083072501807, 0.1089991354233315, 0.02416669939374251, 0.12141585019567322, 0.09319346983947101, 0.18775102051515735, 0.0762865452035781, 0.03799879608014899, 0.018774733180180192, 0.06551954715001969, 0.0838172507862891, 0.06429236622587328, 0.09727275014043817, 0.11392635248240926, 0.06055624734970832, 0.058265410799292795, 0.03748266349336313, 0.03791546869662501, 0.03554215512028144, 0.026713334617295095, 0.021925357868894938, 0.062473573902201276, 0.040772459544842286, 0.04175672164907859, 0.036822088858893806, 0.08398874722901853, 0.06341889192680679, 0.0880138191484636, 0.05063650423600789, 0.05120583779869541, 0.03558144010903855, 0.018760591197097977, 0.06879196832737616, 0.029847268165359576, 0.016395951651277083, 0.024638619131198334, 0.03849640466092575, 0.053029946772561926, 0.025546611436913093, 0.03448998698243692, 0.04626146037011378, 0.006157732380914592, 0.08956609714415767, 0.03535246791978998, 0.05105059008083997, 0.016463796397851362, 0.05668912360805178, 0.09768436918215406, 0.03694037666484233, 0.04454268082495659, 0.0015114565218438305, 0.05622747519444074, 0.026371695792242408, 0.15611413265428237, 0.07504186683124112, 0.05983332464952142, 0.004819787591845999, 0.06860932530534845, 0.08576682197951502, 0.13728415112822287, 0.3774781495092377, 4.251320237113584, 17.755918656626058, 61.30866973630844, 82.60388420474145, 91.65346683994417, 83.22544651646768, 69.54114421721428, 55.84719680970716, 45.70837982239262, 46.813240897270944, 35.71801277898973, 24.261718719236313, 34.35055686581519, 41.65674009630757, 36.81104398542835, 46.1737141301555, 27.055719091046242, 17.484592622326268, 7.486245026511531, 2.143803532085111, 0.06648754520762352, 0.2202398134695907, 0.49203188969723644, 1.1830548725781904, 1.455107280804265, 3.876513497483346, 4.09538469487621, 7.119745621758123, 8.158837374179594, 9.639834627028435, 8.597430432996443, 10.50174311284096, 8.529797004115197, 9.948334924636349, 12.4994719413019, 8.515509770762536, 9.795875337816055, 9.201708820558364, 8.245688946016374, 5.686835646629334, 9.335251796630121, 6.940591364137589, 7.40490242358177, 8.240933072182441, 6.004651083100227, 5.177056472147665, 3.2991820381533716, 2.376658714586689, 1.1711139520329814, 0.5549244294243475, 0.1578865230323807, 0.6529171873004206, 5.080585287463281, 26.47704201359903, 37.06528025288736, 38.581703862836285, 28.29603333627024, 12.741331169682166, 2.521788617295604, 3.010494858026505, 4.818739621869979, 4.925185393902564, 4.894873317210905, 3.701866043190803, 4.8598813626074024, 5.860002406181828, 5.909649316341647, 9.067212708534734, 6.981295760600799, 11.087143132763526, 7.713872425017819, 10.918544953869237, 8.386388286467522, 11.848055489601629, 14.156339937640777, 10.377574601481038, 10.098743111856523, 8.240671253973439, 8.151969304007869, 10.803590090044084, 5.6864904780541705, 4.064103547603854, 4.627475046342419, 2.0041490129886137, 0.39783690545347433, 0.3520817832360345, 0.02762244158093968, 0.36830066132449335, 1.3351234481219323, 9.22811225537331, 24.07954619776818, 47.62735236075617, 62.691175783834154, 57.42976334787185, 27.088468920799997, 25.613377286541848, 29.941177368164066, 26.912550618571622, 27.7709593695979, 43.24275439785373, 43.775573084431315, 56.636381610747314, 63.07911780572707, 64.67922910567253, 61.66715475820727, 42.75756112990841, 12.688250714732757, 0.7535161150078621, 0.14534512745036235, 0.043326263436146324, 0.09502881732318672, 0.07674766118608176, 0.07090902166260828, 0.05491800493590775, 0.018667670477542187, 0.055572531306214874, 0.06875904186839057, 0.041530970859551625, 0.10577507737663486, 0.09800525277011818, 0.0842801823971733, 0.019450102887687185, 0.05061426087312641, 0.06771050498730714, 0.04853844605085831, 0.08722962090565313, 0.07133047727327194, 0.08316316491653843, 0.0352121206120618, 0.05615281609577998, 0.1128372589066144, 0.022641470047434973, 0.052149765373718356, 0.03462275385015434, 0.02435022916254257, 0.07319252292114882, 0.009188560070469975, 0.06079082730256262, 0.011158735198419423, 0.08076511819155947, 0.07136202477399381, 0.07023799758885177, 0.08464222788930902, 0.14040188383190863, 0.2184242616978384, 0.21553732064222136, 0.17903496240896566, 0.11401469008095803, 0.12458384592807102, 0.11760567359986807, 0.1904529053717852, 0.13194920675408456, 0.18032634150116675, 0.11784340600453078, 0.13029543743018182, 0.17364254611874783, 0.0800245333342783, 0.15569702842302863, 0.13139904837214178, 0.0628333670958396, 0.1452658526719578, 0.27981379820454505, 0.2520397401625111, 0.12103593953314329, 0.08265759285178878, 0.15729018487036228, 0.2792169544244966, 0.3267381544555387, 0.18689251174369167, 0.2111325908692614, 0.16475900587054992, 0.05988814207094331, 0.19090710358033258, 0.1891483955325619, 0.29800486240175467, 0.6686552073205672, 7.645129945970352, 25.614497123226045, 76.99971937364148, 94.70722029286047, 100.31356596177625, 93.37556777461883, 77.61766526006883, 59.14894996150848, 47.86214543927101, 45.95481057320872, 37.34045020995602, 26.826986074447635, 48.37325772931499, 53.4348960076609, 58.73348466811642, 72.45856392768123, 35.75629903424171, 21.28917597955273, 8.585405426640666, 3.086837664727242, 0.5791084155921014, 0.3762599164920469, 0.2756960449680206, 0.8335909956405241, 1.208315549358245, 3.9455143626659153, 6.106554260176997, 15.742404249406631, 15.363998489995158, 19.503783679777577, 18.5543288723115, 19.578383238084857, 23.04521914451353, 14.508679586072123, 20.540787750674834, 20.015874601179554, 18.478809518198815, 16.640971206849624, 23.807188580113074, 12.332234824857405, 22.003204245721143, 21.452656445964692, 22.062724251900953, 15.692689188065069, 23.528412003670972, 16.006980865232407, 21.00561999505566, 16.230664810826703, 5.927654466321392, 2.3955373273741816, 0.3135790008931391, 1.7910742206919579, 6.681349662042434, 23.37051699238439, 34.913009059044626, 37.460298230571134, 26.67678479225405, 14.92944694334461, 5.3397652122282215, 8.133533673901713, 11.910507467485244, 14.151857649126361, 14.305249779455124, 10.717165566259816, 14.14445907838883, 11.133106447035267, 11.112799356060645, 17.801259294632946, 14.729152091087835, 19.459386371797134, 10.889694940659309, 15.834590734974032, 17.268881874699748, 16.729540286525605, 17.64790246563573, 16.156073097259767, 17.512753278978412, 13.018311300585347, 13.58150286059226, 14.182269746257415, 6.591158682300199, 5.444827368182521, 3.594955715440935, 2.2542937580616247, 0.933682466706922, 0.6133401045395482, 0.12237645550480775, 0.5786422051249013, 2.4154029065562836, 12.504943647692281, 24.853649485495783, 43.86232022316226, 60.10146617889405, 53.289846758688654, 26.788758654748243, 35.13224993982623, 41.17681457150368, 38.01717281341553, 33.326877086393296, 52.542082186668154, 51.38044088117538, 67.80067090065249, 73.41319038021949, 78.34158574381183, 74.26082241919734, 52.887533172484375, 18.444153416541315, 1.42858850379144, 0.25287924995345457, 0.16611386300815692, 0.2308313467449719, 0.2434354083191964, 0.25893618623095177, 0.13415926316332433, 0.2578760124742985, 0.15359341226998838, 0.21139647751565904, 0.15863963342722387, 0.28782006052713244, 0.23944462649524215, 0.24646217574275311, 0.1189108575964647, 0.11033054260957627, 0.15649179867919416, 0.12191262757105213, 0.1866138396003554, 0.18712840553733612, 0.12132817143273932, 0.150079719361759, 0.2449905208402103, 0.18322155630636602, 0.18048170413221085, 0.17929189297701084, 0.09550420552371972, 0.14977953546950895, 0.14630413163573514, 0.09820780641729794, 0.14994612894952297, 0.12726327674763818, 0.2667459316792027, 0.1626647359901859, 0.20271057263016704, 0.15785845357083506], [0.13943046902216252, 0.09590712946749504, 0.05446826152864003, 0.09859131769307199, 0.0634239251244693, 0.0030396247729508868, 0.08950184534994826, 0.04482830138576608, 0.01870477211571509, 0.06149492339201032, 0.04204089047327157, 0.06285336199066331, 0.0270496433856146, 0.02895285476810269, 0.03980952915885756, 0.052366296295076616, 0.03781355985049759, 0.07575608294216857, 0.11092246044427158, 0.06095836307072352, 0.12299445097244556, 0.05359320142757028, 0.020259913365026156, 0.11482469782593752, 0.06227721407588932, 0.133501622645605, 0.10723151777300144, 0.06955204246145102, 0.08460107364601667, 0.022102998336777094, 0.12768601938601465, 0.3453513637425438, 1.509329022899751, 11.759798238354346, 45.88276055551345, 79.22967310874694, 74.94757452318746, 65.23399345336422, 59.89623208199779, 45.182001667637984, 38.91149674692462, 33.80746549175632, 26.445096269730602, 44.74509669888405, 70.82058998846239, 45.417563530706595, 50.7457229398912, 49.03791119975429, 31.759470508944606, 17.583387321041478, 4.590215961779318, 0.6647781895533685, 0.1183133932851976, 0.11891628149896862, 0.032504589687432014, 0.09116601814786274, 0.9358116395531163, 1.7633491922770779, 2.7568582229075895, 2.8795651610820525, 5.778097433428611, 4.226733840280964, 8.161067241622556, 7.348902254335343, 5.437268960860468, 4.462903180430013, 9.322694328523452, 7.229658278726763, 6.371917311222323, 8.87447234122984, 6.947664868447089, 4.434983259247196, 2.0489319389866245, 3.764705109980799, 8.015785101921328, 10.674086174657269, 9.32658531973439, 7.019850207913307, 3.6241852179650342, 3.1014237336574064, 2.085205528043932, 2.0544109998210787, 0.5914568949130274, 1.3117216070813518, 4.224667241496425, 20.382237703569476, 50.22911933160598, 60.06819271272229, 69.29663150541245, 50.452196290416104, 34.00232491954681, 8.351638047925888, 1.5776277838214752, 5.218862564333024, 6.595486037192806, 6.955682683375574, 5.6409645080566415, 5.694854932446634, 5.050349696989983, 4.638085057658534, 6.045259381494215, 3.5204255340560793, 5.432971023744153, 8.0846722183689, 7.199630083576326, 12.48227136750375, 11.440882086753847, 12.139421893704323, 5.927117591904056, 5.178848505020142, 6.360061457080226, 4.159775549365628, 5.260961853688763, 4.999788874580014, 0.8776384772312257, 4.105427678554289, 1.056610160777646, 0.321027826998503, 0.14070989714274484, 0.2345402694998249, 0.07871683656929002, 0.019962812976671324, 0.5607168508633491, 2.935632255769545, 11.643380330454919, 27.105717543632757, 40.615142929938536, 47.05248194356119, 41.690252827059844, 32.435657708875596, 21.078864374468406, 21.927561336948028, 19.133643334911717, 32.397408716140255, 47.335426038311375, 52.473778032487445, 59.563242466219016, 61.41604461977559, 54.99492068444529, 29.640486509569232, 2.9786211877099933, 0.20230941834949678, 0.12241483650981419, 0.07168397322417268, 0.07840537586279454, 0.21688286215066913, 0.09429642960669533, 0.10815616291497024, 0.08760775424419873, 0.11148946509966928, 0.04879680537288228, 0.10957036888407123, 0.0936709494600373, 0.16673336766900557, 0.12239161638482926, 0.055524455458526654, 0.027218395318355293, 0.10083034754760804, 0.18943636798329894, 0.03713606233378092, 0.014776879407074905, 0.0448144351943366, 0.06657548444045168, 0.008278717662418082, 0.05155354212488859, 0.03195515525857768, 0.039362593463832335, 0.04831362605815934, 0.06517824731887349, 0.03652385849085066, 0.02398014166242173, 0.012683448392987974, 0.06252912676803048, 0.08465292247673196, 0.09794046471436178, 0.09686398860667983, 0.054780116770416505, 0.06662997627450575, 0.041306181510369626, 0.018270737341334744, 0.009854055862242897, 0.021917469078494657, 0.04795968960670214, 0.017384434899976178, 0.016407186330686656, 0.04622758779254171, 0.07105454006382535, 0.017412814627131148, 0.07387926711911157, 0.043900948122984944, 0.091949358372198, 0.02011152596453265, 0.027561116242601026, 0.05963428734591412, 0.08321056277641366, 0.024206162497942007, 0.06050754330992218, 0.024532362736100634, 0.08210830014920042, 0.06680233073571036, 0.007827668075239467, 0.19386193534779936, 0.04130698590269012, 0.03400249459270028, 0.05484049982060829, 0.08455443421318647, 0.10924900266071481, 0.2600552568272237, 1.6752417265407502, 13.102442218411355, 48.708973392363525, 87.47691139098137, 87.14381587120795, 76.2203993335847, 72.30315962145406, 56.44528765832224, 50.665039785446666, 44.39999088164299, 29.843665284495202, 37.96640557627524, 46.43479885593538, 33.56819698887487, 38.83210797463694, 38.1193740906254, 32.905010484880016, 20.46163628178258, 5.865249556879844, 0.9199772150285783, 0.2319947431885427, 0.31216688634407136, 0.5763378739356995, 1.0996324328645584, 2.6037899332661785, 4.331991134151336, 5.439467449342051, 6.437361076954873, 9.127911386951324, 8.857690480447586, 9.258728315753322, 15.761332627265686, 12.604487519110403, 13.008296508942882, 9.954065507458104, 11.117768018476426, 11.52751841852742, 10.06949007511139, 7.869452747606463, 7.6638558314692595, 7.240246226710658, 4.324179243656897, 5.7688676061168795, 8.8328795279226, 5.57109042521446, 2.755961225878808, 3.1586094392884165, 2.9500006331551463, 3.0263826635576065, 3.1957932633738366, 1.2876220744463707, 1.4992430157238439, 4.158724844455719, 18.707148336595107, 49.66020699470274, 60.82295871550038, 67.56638773026006, 49.32050620355914, 32.060265310349, 7.165251979904791, 3.2878664905025117, 4.177055551159767, 5.66955074187248, 5.986288016842258, 4.0459365998545005, 5.135109174636103, 4.63088309572589, 5.155131893773233, 6.9885639125301, 5.748793405871238, 13.756759262854054, 9.304854408387216, 10.249329766919537, 11.694109324486027, 12.821954507981578, 16.039313943155353, 12.288836740678358, 8.935509324073792, 7.280886884658568, 9.559445650346818, 10.885900047517593, 7.694105150238161, 4.542795977284832, 6.1366903205071734, 5.763687135711794, 1.4632259741906197, 1.0729324913793996, 0.3134091438785676, 0.2301813671064954, 0.18684631664185755, 0.8122811875035687, 4.242720930807052, 12.103895025868571, 26.72921903671757, 32.29620764332433, 35.83169875606414, 37.04718635928246, 33.57462183121712, 30.362349710156842, 27.77049456873248, 27.996050465491514, 36.36891441960489, 55.800010696534194, 62.14981417502127, 69.85953869358187, 70.27997755235242, 62.874479909097, 36.26991379645563, 4.0662728634572805, 0.14739347802054498, 0.06463237136842744, 0.0502150601166631, 0.06454682999080227, 0.14342290559603324, 0.024930550341284084, 0.09267736406576249, 0.04380339065626745, 0.06609965190892259, 0.05010050315890582, 0.06670388843744032, 0.05499749804937071, 0.025006500298097253, 0.06448047911568035, 0.02872663283450229, 0.07267074043592138, 0.093945975024854, 0.13312156642636946, 0.020285481549499017, 0.011207161531333002, 0.022902866908078714, 0.09150000183933205, 0.024646952252594695, 0.031176470933602225, 0.09400763744187933, 0.04788234536986678, 0.06472598731277451, 0.06894117927238827, 0.038916017830131516, 0.02070932543926662, 0.033843378130827224, 0.012638843881206648, 0.14470035720977092, 0.11432820390309058, 0.09624769385423391, 0.23839879390453142, 0.21624806637485183, 0.3504520384294372, 0.16550647785827038, 0.25241374428714475, 0.1342717401923672, 0.15879766204424445, 0.12323059757510502, 0.11150448042298518, 0.2447194636108414, 0.17593419089192347, 0.13195447743900363, 0.14408595469449798, 0.11124469234698242, 0.2166736741820651, 0.13007537101305303, 0.2667044097137067, 0.16312061959216673, 0.341017788215991, 0.11597215964068329, 0.2627817943932549, 0.09300007860386565, 0.25638612467915783, 0.23476762907399287, 0.21841273973545722, 0.40593629342413723, 0.1863364851282489, 0.16519552276980493, 0.14357791582663215, 0.1493096171367553, 0.3035479988301954, 0.3836559438176694, 3.677126183625191, 21.243462716379476, 66.22437231002316, 101.60224499241, 96.53750804162796, 85.95772251006096, 79.24531552099413, 60.902759336656146, 52.888658892723825, 46.87855228301018, 35.99863483059791, 56.80267441657282, 84.15719770616101, 56.924766032926506, 65.35612429341963, 64.1437824310795, 43.046506451022246, 22.58627830013152, 5.979851897685759, 1.190767845799846, 0.2366670521516954, 0.19011253250702737, 0.7781182626082052, 1.2800276303483595, 3.282049370388831, 5.89412457519962, 9.27420206608311, 8.912172202141054, 16.705698159433183, 16.238454637988923, 21.008922630740752, 21.41636863831551, 18.763993286317397, 14.5517050450848, 19.934161824564782, 18.313638510242587, 16.700402959700554, 18.311761656115134, 16.47271917712304, 13.823918084944449, 13.424977737088359, 11.17399029193386, 16.920871542346095, 25.075041786316906, 19.245562284223496, 13.646352387243702, 12.760019302368166, 6.664636933034466, 4.745363843056464, 5.723829971205804, 2.4076824563164867, 2.526447657615908, 6.715389951582878, 22.112948240772372, 45.83594314513668, 57.15707232875209, 68.15012270404448, 45.43171544228831, 32.62816175337761, 13.342203959341973, 8.20264191396775, 13.434508116014543, 12.444265561719096, 12.595653360889806, 9.676755897460446, 9.591891496412217, 10.741697049910023, 10.022743267397727, 12.728910984531527, 10.107013429364851, 14.282427468607503, 16.722689867019653, 17.932133097802442, 26.699881669013735, 21.881608809194258, 22.62225820172218, 17.05682089251857, 15.035416637697528, 15.643590919433104, 10.911920070648195, 17.508911317394627, 12.131956642673863, 6.737713140826072, 11.19305104978623, 4.476773661951865, 1.2412467887324672, 0.7192423218680967, 0.39557348335942916, 0.39848314658288037, 0.18173111692791988, 0.9598542365335649, 4.934509848394702, 16.1120121325216, 36.58123231703235, 53.372781353612105, 63.63133261280676, 56.481546048195135, 47.29581794431133, 33.72963782279722, 34.44036345328055, 31.545275757389685, 43.16552292916083, 64.05814140073716, 69.72406787257042, 78.22524824450093, 78.27701568603516, 74.31582189375355, 45.58394262867589, 6.625626019893154, 0.3974620739538824, 0.2547379324753439, 0.20377770246517277, 0.1664924943038533, 0.3343997691427508, 0.20380635415354084, 0.26325906717008163, 0.16421865341403794, 0.31974248467914523, 0.1556670284199138, 0.20062676751084868, 0.15414750834386196, 0.25166196688528986, 0.23163391577620662, 0.15057706364220189, 0.1859984411707809, 0.2658711512002253, 0.31257144205512544, 0.13289405363461665, 0.13048441599934332, 0.2697909779606327, 0.20532913776415013, 0.10992414062662471, 0.1800901565941111, 0.1604174477078261, 0.16145879102330055, 0.1707922240659114, 0.08817869659152724, 0.1334057237592436, 0.16652224915883235, 0.14559183840549764, 0.16187955715483235, 0.29841597582544055, 0.29725093995371177, 0.16749985395900666], [0.08642767240563709, 0.12900667835868176, 0.11969430507310938, 0.023878219409755642, 0.07187454525621668, 0.02318920567631722, 0.04008571534687954, 0.04240989587419937, 0.03295063289002546, 0.00920982284080838, 0.025168330626442068, 0.04588775501977052, 0.11289356636904901, 0.0352063941048278, 0.0916131377039898, 0.058539111032000476, 0.059442485742751634, 0.07796304435619424, 0.11693209079244446, 0.07533343989522227, 0.039661685680790294, 0.217577182958203, 0.05599224789729042, 0.2536942908960966, 0.24183390151348808, 0.22326301092342024, 0.12588562849428386, 0.11667840843719822, 0.11212062195784624, 0.036607611053172624, 0.1595209716188331, 0.7245882672648276, 6.127379104014366, 41.40572017238986, 68.4518627966604, 73.92508322192778, 67.20110524085261, 59.52019837594802, 50.18027405585013, 33.923708854183076, 30.613838357310144, 26.654272348650043, 55.37016599409042, 88.3700115449967, 102.96391933195054, 92.71646838034354, 75.98152699009066, 46.51576442103232, 20.086389010952367, 4.458911188187138, 0.7071910233747575, 0.05731383766678553, 0.10493430354061628, 0.2485840554319082, 0.532568083895791, 1.3195571543708926, 1.3348465533025804, 4.067573129169403, 2.884905468071661, 4.185925991304459, 4.460669390616879, 5.818650818640187, 7.492591421450339, 4.050119807643275, 5.473578341545598, 6.706380267297068, 8.403826163661096, 9.92558910000709, 6.934917655683334, 6.717035385870165, 8.291859165314706, 5.071859975014964, 5.938731239688012, 7.304007295639285, 7.919097206284923, 8.71510349935101, 6.452708330846603, 4.4948871674076205, 7.1982474480905845, 4.741176712897516, 5.617216027552082, 4.59933449183741, 3.806711243044946, 7.604820728302003, 19.05463111016058, 36.877814492871686, 69.76618628348075, 62.435715736881384, 70.64087483190721, 65.96028697106146, 51.4614535147144, 14.949618712548288, 10.04078911196801, 9.58133541768597, 12.557981937162339, 13.86447931489637, 11.190809415232751, 15.721374461727759, 16.828631124188824, 15.701549822284331, 15.707608903608016, 8.663865577790046, 16.77492407060439, 5.863984592499272, 9.088306234728906, 4.602504747529184, 11.10625978439085, 14.360699345988614, 10.60537507457118, 6.899204965560668, 5.156540514961367, 8.96685004234314, 10.899127260331186, 6.497270378374285, 2.9065939687913467, 5.667026206370323, 5.722633648303248, 0.292104912861701, 0.6550860128575756, 0.5997943217235228, 0.3567642964903386, 0.11055934242904188, 0.29083023448624923, 0.9316833449467536, 6.5964911445494625, 19.830544571722708, 48.718728326982074, 55.65168234609789, 41.95143168972385, 27.758694118069066, 24.982046311901463, 18.241459054331628, 25.1415769515499, 26.986224497518233, 31.62616287508319, 42.993719193243216, 54.60244440263318, 61.75736534980036, 58.70058382711103, 41.497778200334125, 15.440485688947863, 0.7683223882509816, 0.06109270424912534, 0.08700644417155175, 0.1583109204206736, 0.1321535990122826, 0.1670180459416682, 0.18449632661236873, 0.34048940205285627, 0.1749272296024907, 0.09380991014862254, 0.337886480434287, 0.2637288629287674, 0.393079070434455, 0.2091526366289585, 0.06576772133309035, 0.040674982517356836, 0.21548671287394341, 0.06247023375885141, 0.030517466779377674, 0.05837377010574264, 0.06389473594965474, 0.07234474704150232, 0.046072470309633407, 0.08248224298680022, 0.049135872057729194, 0.0568921369079861, 0.03495997809354336, 0.061235820964699796, 0.06625581893228716, 0.017773887187603022, 0.06451018800538394, 0.1514191628103295, 0.04191018438207046, 0.07592689756664538, 0.1032509249184401, 0.03535686909491497, 0.04699193286679445, 0.047982135982883554, 0.05036078919205935, 0.0319272754037933, 0.031012890094350425, 0.030272885548671892, 0.038019583875974344, 0.039417717320423935, 0.05732209992504889, 0.04695105058471522, 0.05625763607601966, 0.2251145075405798, 0.06517519062805562, 0.020973838362542373, 0.032327213519883734, 0.06698616885489996, 0.019719468977963252, 0.05401154289082174, 0.04470773446824282, 0.08881808889489021, 0.017436643792015892, 0.030508365654837222, 0.09462847509571622, 0.050429702631288, 0.08783217204073746, 0.08939732797443868, 0.022095929260455796, 0.06984919264552093, 0.05665059321590009, 0.09150218518991625, 0.4629339091479779, 6.545922967695422, 45.05868627179054, 77.24373786680161, 83.26054388476958, 77.82124411675238, 69.91571487918978, 60.53481355790169, 44.639384900369954, 37.30826716269217, 29.156762169253444, 47.78739683089718, 76.00163305959394, 87.92691707611085, 76.35474835672687, 65.2978810187309, 46.273224661427165, 23.9394469799534, 6.9301902190331495, 0.6511028459475887, 0.09158239459558841, 0.11584005543902037, 0.4565238063373874, 1.8417793127798268, 3.1404508265756794, 5.738272138180272, 9.429342592916182, 8.501242149260737, 10.491518474394276, 11.138058439377817, 10.64687277040174, 9.61168867926444, 12.100345280862625, 9.837292625058083, 11.96959307116847, 10.277626725935168, 10.396216646317514, 10.55117380234503, 12.916804282895981, 11.579684961226679, 3.850928857441872, 6.3222919740984524, 8.429957974341608, 6.278466841866893, 8.843146331848638, 7.540266360006026, 6.152313611199779, 6.361501457229738, 6.7030629227238325, 6.473677321787804, 7.044078688467703, 4.35094157534261, 9.954441074402103, 18.33848672528421, 40.052345568133944, 74.91128475435319, 67.4466299241589, 75.34223556518555, 68.62533353990125, 52.318871867272165, 16.66797084193076, 10.861072424919376, 10.226359386597911, 13.743570293149642, 15.143334769433546, 14.611234857190041, 15.419804011621784, 16.746228010423724, 12.773123941113873, 10.249309174476132, 6.32026263783055, 8.585733925142597, 6.706609725952149, 10.019340611273243, 11.108492593611441, 14.060191858199335, 16.989216881413615, 14.500293558643712, 12.159040608713704, 12.113745077963799, 12.24195461119375, 12.358813785737562, 11.045703291893007, 7.885626150715736, 10.20603366436497, 7.827551047648154, 3.789353284143633, 3.3436521551301404, 1.222527277085089, 0.9994236584151945, 0.15908620140004545, 0.30952078801008964, 0.8484794547961605, 6.487138896219193, 17.976642193332797, 41.51153787489861, 52.55089575244535, 43.92075569398942, 32.116514059805105, 29.236637315442486, 26.88210125892393, 29.423820664805753, 33.86597548761676, 40.696210476659964, 51.85532616030786, 60.879852694849816, 68.9851168663271, 68.00290046199676, 47.20390896643362, 17.723174710427564, 1.000853178481902, 0.0799516936944377, 0.061337886858851685, 0.15781759044095395, 0.05071433493867517, 0.12331633813559048, 0.09561490522877825, 0.11449818349172992, 0.10074588635395612, 0.13470280254560132, 0.05880059216231589, 0.13434652569553546, 0.1098905629929035, 0.046232640142402345, 0.04681308581043155, 0.039290270933340636, 0.051127961130752686, 0.0911318659481983, 0.053182191425754186, 0.06979509151630825, 0.023873276227424224, 0.057309758248588735, 0.04137978723813449, 0.04134601808243221, 0.05108202649881283, 0.09134014993305169, 0.08876046376122583, 0.05585909415517123, 0.0312595455081112, 0.12717582015020232, 0.0817616223808258, 0.1213570912518809, 0.031136887170554652, 0.014752401940284238, 0.06249159612061997, 0.30562829526682056, 0.28702829333563007, 0.2430532989843238, 0.15587063926842906, 0.09963194088589761, 0.1455846065354924, 0.09006463652176243, 0.16995766320295874, 0.2729439200653184, 0.07058457576579626, 0.17536707132333712, 0.19291883514773464, 0.38779220573844453, 0.1721848799817024, 0.19861309008011896, 0.14654387119075946, 0.15796696226443016, 0.21074845906226866, 0.17550519697608488, 0.15646680889110412, 0.3733998344790551, 0.3025392142515029, 0.1396835691505863, 0.5952751997017092, 0.3916891417916744, 0.48677652653667236, 0.3650053800834764, 0.17647606020252551, 0.23329185261841745, 0.26933953766861274, 0.2867529000486097, 1.2552343284891498, 11.45502027003996, 58.429410765247965, 90.43657502820416, 95.55194193317045, 89.1287705206102, 79.65306158988707, 66.46295439812445, 47.51650225731635, 42.55958341783093, 36.72485382326188, 69.22126708492156, 100.73517368685816, 106.57453952297088, 96.12787139031195, 84.66154390765776, 54.12408782589821, 25.01145624345349, 6.725379738115496, 1.0363742853364637, 0.19105056120503336, 0.36640995632736917, 0.3348905863540788, 1.9449768720134615, 3.947404209644564, 5.319987641226861, 12.700047243025995, 14.055226137561185, 17.137068663873983, 18.853146799149055, 19.00162223846682, 16.50917564668963, 17.918767621440274, 18.029517704440703, 19.50436419056308, 17.031329408768688, 22.96431829852443, 13.806897940174228, 17.96877587995222, 20.90046125073587, 10.856091995393077, 13.724075132800689, 14.535307576579434, 16.39303622707244, 15.076566223175297, 14.44084905808972, 9.931142195578545, 12.324455784213159, 7.553417576897529, 8.247352030969436, 7.5622997841527395, 6.00430787571015, 11.461244090910881, 23.488839211002475, 42.258239484602406, 71.03524561851256, 62.33737799429125, 72.15860459112352, 68.81454867701378, 52.72223664868263, 20.420888739247477, 17.839837766462757, 18.324699594128518, 19.412965120807772, 17.70522790570413, 13.871548406539427, 20.625514868767034, 21.335095167160038, 22.216226208594538, 22.809690621591386, 17.102569457023375, 25.23636494913409, 13.799875916973239, 19.882490481099776, 12.98605961184348, 21.892299229098906, 25.898759134354133, 20.006578583871168, 21.10077669543605, 17.04227674391962, 20.49502153550425, 22.327331266095563, 15.91234289830731, 10.274414304764042, 16.256728960621743, 14.193946642260398, 4.878512130629632, 4.844944976991223, 1.2268219047015714, 1.3911221464795451, 0.26837242827300106, 0.8665791706692788, 1.2585297323042348, 8.983847633484872, 23.875871243015414, 57.06834439308413, 66.52699885829803, 57.36773106359667, 41.66869155822262, 36.67526329717329, 28.69152984311504, 38.09090552791473, 39.11762514422017, 44.88439967555385, 57.09708752170686, 71.43131871377268, 78.65451243615921, 78.06119118967365, 58.93954246274887, 27.546411521973152, 1.5716928700285575, 0.16577788748808447, 0.2811726236775998, 0.29073217523194134, 0.2536052561575367, 0.2821581804704282, 0.26200691177960367, 0.4222890836817603, 0.34381073028329884, 0.3323322204091857, 0.3942781206100218, 0.46904483930237834, 0.48503490224961315, 0.2861013269472507, 0.2244918312757246, 0.15723403062551253, 0.39435954043461435, 0.30880676342114327, 0.15027081233359155, 0.16859989493123947, 0.19847341692976414, 0.15833770285450643, 0.13042668361336957, 0.13547250640488442, 0.17121439979922387, 0.17634570268132996, 0.19025628124513935, 0.15023655288161772, 0.2207160750103574, 0.218334169757943, 0.20400878522665272, 0.22544064649170448, 0.27332389967576154, 0.2867860563339726, 0.27711753643328146], [0.19699485191414434, 0.19137219555916327, 0.10000599863668604, 0.041730575068222905, 0.051334973409651756, 0.11623415404990797, 0.07987055732237716, 0.11812902656534027, 0.04996304017221255, 0.05131303265150036, 0.04331022538545151, 0.06791360255691313, 0.05064365183634143, 0.03093885152690834, 0.014602639411966649, 0.07587219888885176, 0.09772992077013178, 0.041188935583998124, 0.11119665863413004, 0.12384912164341058, 0.1847320671884283, 0.16456149308191192, 0.06379576122027732, 0.2517476614804999, 0.2666545527115945, 0.20299643067823303, 0.1035558585558207, 0.12828910678264596, 0.08925871202541936, 0.14051834451815776, 0.2724365859983429, 4.560130892261382, 33.15274346259333, 62.65160691353583, 74.61058016746276, 72.31341269708449, 61.927737420605084, 40.10250876026769, 29.372225807559108, 29.021359989720008, 40.153358367181596, 59.81483113381171, 55.71680153569868, 66.13797818460773, 73.51158695836222, 73.4094484390751, 52.3724239872348, 20.403265530063262, 6.1617268093170665, 0.8721093448900408, 0.4768225316318774, 0.062460818538262006, 0.26928002795865463, 2.1103116389243834, 1.0986674072281009, 2.1002441404327272, 5.009293758100079, 4.486941916327323, 4.827525731055967, 5.276096318998645, 6.391103584920207, 5.703883247990762, 6.337822108499466, 17.916149439350253, 9.593805613056306, 15.62698164293843, 7.271712951121792, 9.199571128814451, 14.987615693000057, 11.522840011504389, 6.976382501663701, 10.617043145241277, 14.451857189978323, 12.455298208421278, 13.935931171140364, 17.979852653318837, 16.85330479375778, 14.195696019357252, 16.05870221891711, 17.738368011290028, 17.11114375822006, 14.974496345366202, 13.384508682835488, 22.371061771146714, 38.5929806770817, 51.08142683582922, 66.26917362213135, 60.24879824730658, 69.01078485673474, 65.32620837611537, 63.5149048989819, 26.529472335692375, 21.52585375693537, 24.23360120865607, 28.090171660146407, 30.39540352359895, 29.719392830325713, 37.1137725153277, 34.78484953603437, 36.51848223901565, 26.400147868740945, 18.088602327531387, 19.36178211242922, 9.811429496734373, 7.945099578749749, 10.133451184918805, 11.2649598621553, 15.361010624516396, 12.51092722339015, 7.994193925011543, 5.781787893464489, 10.093075286957527, 7.522157757512986, 8.088138613008685, 4.315044533821845, 5.1949419898371545, 6.965571959172526, 2.9883035584803554, 3.4004706288537676, 1.8018653964804066, 0.7108827091513142, 0.06090390571062604, 0.1585413443465387, 0.07242713213687943, 0.3856923893815087, 3.8768983800565047, 11.553531577510219, 27.825943154673425, 44.00370990076373, 40.01494969091108, 38.030512794371575, 24.921800667239776, 16.949777449330977, 21.960273904185144, 30.794169325982374, 40.19248008728027, 50.39775379242436, 60.562780057230306, 55.307459062145604, 63.32307354096444, 35.08251036367109, 5.249110902509382, 0.5337969502133708, 0.20298918348646935, 0.19550871794983266, 0.1241253882706646, 0.18313653586852938, 0.24177112826897254, 0.2188477857458976, 0.2631912837105413, 0.22459105498367743, 0.4065419931805903, 0.348200352802392, 0.3290806061798527, 0.1621621057030655, 0.0317809832537727, 0.12978870091178726, 0.13326065734990183, 0.13081317497116904, 0.03172770566907862, 0.051587001014981544, 0.15653600195242515, 0.07074383778437492, 0.04772625112485501, 0.06025480707326244, 0.030375541330525474, 0.04861059621156705, 0.06190253962432185, 0.04153534522159927, 0.026494005559793404, 0.053820438427670356, 0.017937215217839808, 0.08888382689967271, 0.05207205724511897, 0.12326539328862583, 0.1464866444228157, 0.04386655460562437, 0.08834980232941528, 0.06725475928115268, 0.0324682732893815, 0.02389323281785173, 0.04974057589988074, 0.032632687249250954, 0.032415512814036304, 0.031293600031565276, 0.02290832145409959, 0.05137978955322216, 0.10173034764105275, 0.06688430980448762, 0.03254914919154779, 0.024442839616489027, 0.019751190763687896, 0.04757564589982072, 0.04500318393712083, 0.031199474638748555, 0.07713273528122133, 0.09271117152586099, 0.17186977269668735, 0.01374807024765159, 0.02950460086726854, 0.07966922941587626, 0.11266040750929426, 0.10830998570928652, 0.05989451975291295, 0.0035243096898475122, 0.01796541299911276, 0.1432637584906432, 4.506621428074376, 35.4491303813073, 69.34393528969058, 84.5217663241971, 84.89909049003356, 74.40121973714521, 54.32801969589726, 44.02205874842983, 37.18291605672529, 39.671573638916016, 46.86753042282597, 57.648572767934496, 76.23032293012066, 86.69308846996677, 85.24014057651644, 61.79645961330783, 25.805614609872144, 7.216749268193399, 0.780148824616786, 0.26936717812092076, 0.12073600078902899, 0.6946178045003646, 3.855387366587116, 3.7225197736294042, 5.710992543928086, 7.496202943786499, 9.989767901359066, 9.549847610535162, 12.762596299571376, 12.93338708339199, 10.40978608592864, 13.672598927251755, 8.253515055102687, 12.093508589652277, 13.442767647004898, 12.180810743762601, 7.4972036384767105, 8.327712570467304, 15.68018957491844, 11.505768875921927, 8.273476977502147, 9.852799715534333, 13.58780316768154, 13.33925727875002, 16.479275418866067, 15.255926405229877, 15.378676979772507, 18.625986652989543, 18.02125523167272, 19.812742894695653, 18.569657494944913, 15.281653231190099, 26.192525048409742, 40.004677003429784, 57.10553630705803, 76.99560872970089, 67.35400707490983, 75.61952360214727, 70.64126706892445, 67.19026380969633, 30.219485221370576, 23.645569278347878, 24.89155330965596, 30.36315379604217, 32.88032897057072, 31.771582788036717, 37.015819165014456, 33.26377791743125, 32.82430575739953, 24.038502516285067, 17.298334952323668, 14.848752021789553, 6.027977418514991, 6.897894403626842, 8.228600159768137, 9.383135111101213, 17.169802804147047, 16.96771444812898, 12.608348111952505, 14.055939028340003, 18.473673174458167, 9.018754766833398, 9.380540463232226, 9.9714857339859, 10.391557851145345, 7.838070354154033, 8.012134355883445, 7.405669246950458, 4.249578704757075, 2.753109662763534, 0.4303766738983893, 0.21784385816464502, 0.07461868752274783, 0.6419935702316223, 4.1023542563761435, 13.452813817608742, 29.241187264842374, 46.11512176452145, 42.17579910832067, 36.15141899354997, 20.63564438973704, 22.45059763231585, 28.905400999130745, 38.27974411749071, 46.331840561282256, 57.60176712466825, 66.66641558370283, 64.12388032482517, 71.69624343995126, 42.60312957148398, 6.700792360690333, 0.82631689886893, 0.14349266556241821, 0.07549048025882052, 0.07912461751050527, 0.04294115486705015, 0.11334755773385687, 0.16598987933849135, 0.12403024015046897, 0.1280858559954551, 0.3817138802861014, 0.2212038125482298, 0.13000078469274506, 0.015969037664152922, 0.03209644676967254, 0.053508295902922276, 0.07761993655754675, 0.0777000004065133, 0.030032734221388257, 0.10298396625946607, 0.0549897107656204, 0.07942193623391852, 0.049438086082978595, 0.02596770315581272, 0.03045313263071641, 0.08148884911450648, 0.04202910804099614, 0.04069871975169067, 0.07967001848643826, 0.031026005519614108, 0.052385992415609865, 0.14914579689502716, 0.017855044627081484, 0.048221423546032566, 0.03717977914117998, 0.4596091182001176, 0.362841212340901, 0.14601772200436364, 0.11915702462917376, 0.12298362615007548, 0.14278317621398356, 0.16856790309952152, 0.19681584780975697, 0.08378882126341905, 0.12450473968900981, 0.10934179889098292, 0.19626731353421367, 0.12611376947813457, 0.08224370618981701, 0.19951420866193312, 0.2118174887953266, 0.1442956636028905, 0.12579558251966394, 0.2662287610432794, 0.2682892311244242, 0.3459480236614904, 0.42729056530421783, 0.2718350537601979, 0.3552972994023754, 0.39553196139393315, 0.32745512082211436, 0.36843451220662365, 0.30300760040840796, 0.1520108125142513, 0.35854208012742383, 0.45002070045278925, 7.294814240547919, 46.86086631590321, 85.27620284788071, 98.10367122773202, 96.72378140111124, 84.3568463479319, 61.34162549049624, 43.51343716344526, 42.69313619982812, 54.15563544919414, 73.60460988936886, 68.89389822559973, 73.5957924012215, 79.03801825738724, 79.28384104082662, 60.05884570460166, 24.63507344645839, 8.052225391710959, 1.473938702575622, 0.7277058773944456, 0.2768137059625118, 0.5351442843675613, 3.7704994313178526, 3.413058250181137, 8.270322411291062, 15.379751709199722, 15.628045585847671, 16.280339667874, 19.66100404339452, 18.72419103499382, 17.405135208560576, 20.11966051593904, 26.342765554305046, 18.12701802099905, 26.18351536412393, 18.994114821957005, 17.58377367450345, 23.15044260794117, 22.598920099196896, 16.150315057846807, 16.598274246338878, 21.295804785143947, 17.043302443719682, 20.147317148024037, 26.725592805493264, 22.719905607161984, 19.38286485210542, 21.319211529147243, 21.337976148051602, 22.512816229174216, 19.717458717284664, 19.60925425252607, 30.103739999955703, 47.61252187913465, 60.25236760416339, 76.64982042004986, 67.28553033644154, 77.61962644515499, 72.14524499831661, 70.049177446673, 35.783508516127064, 29.29614163214161, 31.433358769262995, 35.586699670360936, 35.45309197518134, 32.99359329285161, 45.240119426481186, 41.4517766429532, 40.42992076566143, 33.005560444247344, 24.530589349808235, 27.783218737571474, 16.68642363240642, 14.935002000101152, 17.735363475738033, 20.07187035775954, 25.32861517321679, 20.287669358714936, 20.068655975403328, 14.667871921293198, 17.886374727372203, 19.01967102481473, 18.483806617798344, 14.967906763476712, 12.089570529999273, 15.029868445088788, 8.969207386816702, 10.307504400130242, 5.519821614988389, 2.5343531946982107, 0.33039882899292056, 0.23029770521867662, 0.28148126518053396, 0.7799662505426715, 5.437358194781888, 14.601346561985633, 36.79527213496547, 58.09498556198613, 54.108978855994444, 50.60620423286192, 36.023349685053674, 28.32468625037901, 34.39065917845696, 45.839159488677986, 54.170995450788936, 65.52152279884585, 77.12538426922214, 72.4070788967994, 83.24870617158952, 53.35165939023418, 12.139068880388814, 1.3022557021148744, 0.33234493746872873, 0.30506518999895743, 0.3168675712039394, 0.35650799411439127, 0.31406647796111725, 0.3623643379297949, 0.4563823558630482, 0.3184515345961817, 0.7498842453764332, 0.7737636962725271, 0.5330494935474088, 0.38029517738088486, 0.14269322216991456, 0.17697246985570078, 0.2310954172524714, 0.25391921431066533, 0.23491764441132548, 0.2659391798079014, 0.25453616023784686, 0.26209017021521447, 0.15266682892557115, 0.13514180156973102, 0.10677431649979084, 0.16287041527609672, 0.17178648361755958, 0.13096029449614788, 0.13123957950982357, 0.15659488347028533, 0.17344150932565813, 0.2438503368607452, 0.10085646348494677, 0.4347358367616131, 0.22048442534381346], [0.2519580292245073, 0.13385583105827534, 0.05245491351571776, 0.041873301078955975, 0.014795237746570381, 0.08916490455909122, 0.047263051383197315, 0.02981147270709757, 0.043344419719951774, 0.034458090911709496, 0.03838001675302944, 0.052686402303797585, 0.047190460721932115, 0.027439593630392226, 0.051887138941956144, 0.0822667041493039, 0.07967188774097352, 0.032068088109935486, 0.2647508855067915, 0.20369309571481523, 0.24167686881076908, 0.18238144896684155, 0.1210817056257398, 0.23573636257600403, 0.2714326430953318, 0.1251638740781815, 0.09458336017785535, 0.1496826866341214, 0.14428052570550673, 0.11772094684983454, 0.33139455943338336, 14.30813076034669, 43.62655047447451, 58.393097462192664, 57.631498690574404, 50.42529667577436, 41.02324201214699, 34.26120135091966, 26.518993723777037, 26.933864778087987, 41.42706963323778, 66.00191900807043, 67.9878620947561, 37.30509004285259, 36.18939538155833, 32.22298287576245, 21.49173698117656, 7.0643362595189005, 1.3340504347316682, 0.34980956645261857, 0.032249229599631606, 0.19409467285919577, 0.8023268861636039, 2.598104947997678, 4.5187018379088375, 3.007844561530698, 5.5043360975480855, 10.077600556035197, 6.840570434447258, 10.561510228341627, 10.851951933676197, 9.245016690223448, 10.035256608839958, 5.191756044664691, 9.641744821302353, 7.56050726098399, 7.681052973193507, 5.465614949503253, 10.028547394660212, 21.923497761449507, 20.160013860271825, 15.05140814089006, 19.716115305500647, 32.086160798226636, 27.749829561479633, 32.9405471586412, 30.43146383377814, 32.39489055448963, 35.09962758710308, 34.393675481119466, 32.32831224318474, 30.423434742035408, 26.844999559463997, 42.548424274690696, 47.739234047551314, 43.247559301314816, 54.054316705273045, 49.22205863460418, 58.709687648280976, 56.591525385456706, 62.075336210189334, 43.11227675407164, 44.5258754299533, 45.419006962930005, 46.94069831602035, 50.14222314280849, 51.480076928292554, 51.948937446840354, 52.68767272272418, 49.88428415790681, 44.8051913322941, 33.44218300234887, 23.49791165321104, 12.063100414891398, 11.172274254983472, 13.146902284314557, 7.4764685188570335, 15.039086995586274, 16.589656799070298, 8.702779412269592, 14.645096678887645, 16.219865545149773, 8.364300439434668, 7.8470869025876455, 7.687463106647615, 10.997481672994553, 3.5267474141813095, 5.5180364462637135, 3.948282575415027, 2.5419356265375694, 2.1053138038804455, 0.6931993160997668, 0.4879554439215891, 0.16855296438499806, 0.08488490156108335, 0.47970084653746703, 4.693268393316577, 15.470907592004346, 36.59050480011971, 47.3067888136833, 49.19168772235994, 46.9004391085717, 37.75052616673131, 26.47301373943206, 21.474023557478382, 35.636654976875555, 41.3129835744058, 45.838273033019036, 58.04104904974661, 55.278661020340465, 52.01677876134073, 27.67851891056184, 1.063289834607032, 0.04421931128167818, 0.1771770919402761, 0.21743597763199962, 0.17676734215309545, 0.1895566897526864, 0.13829327278560208, 0.16845508899179198, 0.23842022904465277, 0.2082095057853768, 0.0859707392632, 0.11802890653451605, 0.05083107141657703, 0.0338919289530285, 0.061050335756473006, 0.050145836411825115, 0.27479353210618424, 0.034109758393418406, 0.12100356465746319, 0.06754152897384859, 0.05993513390421868, 0.049446846298392744, 0.033984096991198684, 0.017616325884216258, 0.04110081632050776, 0.025700505094362364, 0.035750102026448134, 0.09431302307113525, 0.07445967831318417, 0.08113909933355548, 0.08186774854097637, 0.062064042450079036, 0.14152818629818578, 0.08238926289543029, 0.08438088465481998, 0.003916333878277651, 0.054735978614659085, 0.05927743976034465, 0.049982115761527134, 0.08266542993125417, 0.037594929848226814, 0.04964734299949581, 0.027139670208036423, 0.03418251759402695, 0.0006223013605772248, 0.06381915371504522, 0.08038941335173384, 0.05572295267014735, 0.03467559476473159, 0.12742619300561567, 0.02899494363866266, 0.029066622655297962, 0.1401958061802772, 0.05013467068032873, 0.14379125599178577, 0.08380193668868273, 0.08349453624818595, 0.13743367616928395, 0.14891604712653547, 0.05254403635438892, 0.0599882927452845, 0.1541816452217679, 0.0486608247663225, 0.11878813031099497, 0.17279347555050928, 15.54056888626468, 49.8295396374118, 72.73415750072849, 72.71189412763043, 66.7773166779549, 55.87495542341664, 47.11710691452027, 30.5270774902836, 30.07311021128009, 49.57575052015243, 78.16220006635113, 66.26704769749796, 52.535892686536236, 50.88854820497575, 46.94244769311721, 29.89132404327393, 9.150351266707144, 1.6097435379220595, 0.41323882737948053, 0.5411350919354347, 0.8484135712346724, 2.7362709276137815, 5.974011978795452, 7.124312241231242, 9.466675712216286, 11.436102678698878, 10.690130629847127, 11.035373730044212, 9.779538666048358, 11.292774369639735, 11.876718209635827, 11.749871700040757, 14.703390944388605, 13.207631361099983, 8.601982343581415, 11.660591690771042, 11.304086485216695, 3.9565195527768906, 13.543162672750412, 14.973263740539553, 14.449199784186579, 20.653863799187448, 29.4998558105961, 27.006110914291877, 32.58570797981755, 30.25057000498618, 33.40484596067859, 35.43406063510526, 36.98101205210532, 35.24470429266653, 36.42788725514566, 31.330641700375466, 48.939353804434504, 52.70572739262735, 52.307281263412975, 64.0198943691869, 56.457176362314534, 65.70623505500056, 65.57977391827491, 66.02120922457787, 48.71171512911397, 46.599546247913, 46.436763963391705, 46.39899546100248, 52.33233736407373, 53.5437378575725, 54.15860860578476, 52.573614120483406, 52.48001067869125, 44.685735548696215, 32.79473500867044, 20.057139896577407, 13.3386012623387, 9.185838910841174, 8.583723710429284, 12.610677999834861, 15.059820644317137, 12.634829013578354, 16.13415293155178, 19.18879185953448, 15.087137991382232, 11.089168056364983, 13.872311307537942, 11.705577354277334, 10.995901938407652, 6.374426157243791, 10.919003871179397, 11.599893012354451, 4.503979221467049, 4.415849447250366, 3.3395569555221067, 1.066443787947778, 0.24963105247626383, 0.22810572848444988, 0.6168887463788832, 4.429811614174997, 14.693690922952468, 35.54521668341852, 41.60674164372106, 42.66700929211032, 38.63911951741865, 28.36509450789421, 29.792286157608036, 28.795851161403043, 40.29383413253292, 48.68372509556432, 55.59665933732064, 65.95207352792063, 65.34825209648379, 61.111405895602324, 31.731411833916944, 1.882918356887756, 0.02889200248905728, 0.0522043414774441, 0.1652719936664066, 0.15737181919957363, 0.2500634325007277, 0.15074437724486475, 0.1314270565466535, 0.15386056245094346, 0.05833921187947835, 0.05677482586414103, 0.13330654601656622, 0.010602927875644978, 0.09737824810849083, 0.07765382828731691, 0.022734745082655744, 0.11221277467425793, 0.04890827116586509, 0.07546055686449812, 0.15861812167831008, 0.07110255079404001, 0.07812784519046545, 0.03463787642577964, 0.06520987908926702, 0.03145481174391124, 0.059629273300449696, 0.01796007719672015, 0.07880844536327547, 0.04649282658412572, 0.04840019782404265, 0.0380588956778088, 0.06756725420634593, 0.1283820026043442, 0.05096299175713813, 0.4851992740746468, 0.36903748469006636, 0.18120015670935954, 0.250519928973048, 0.1324665306075927, 0.16543532361186322, 0.12505426987885468, 0.10758286101683494, 0.12025606202622575, 0.0863224042639617, 0.16876849556161513, 0.3118803388168735, 0.2339241356258431, 0.09748877161332677, 0.14877484180033207, 0.23397465146357016, 0.12189471643538245, 0.2628940109524035, 0.5185827504723303, 0.29232214475351, 0.3618252878227542, 0.30040973497013895, 0.2041614665499618, 0.4342742841089926, 0.49001085782243364, 0.2165461358644309, 0.22979354275570762, 0.27124685145193533, 0.2280728173472228, 0.16885780609182774, 0.7885355874896051, 22.205726023643248, 64.95379109536448, 89.84261051301034, 87.94393231791835, 76.24133694556453, 62.91683758458784, 53.086499321845274, 41.84409602995842, 41.91454179825322, 55.79884183022284, 75.53584375689107, 78.38869340958135, 49.27191980423466, 49.40742200420749, 44.50147044274115, 29.45259321120478, 9.266619143947478, 1.9873066006168245, 0.6900062616313658, 0.4823559540654383, 0.6261590844200504, 3.221009690915385, 6.547873856559877, 12.279691734621602, 11.985350212743207, 19.28845928561303, 19.425863835119433, 19.71617021868306, 24.583064779158562, 21.683195714027654, 22.033094667619277, 19.392160869413807, 12.802382861414264, 22.9461871424029, 19.13462784982497, 18.204369121982207, 19.592013474433653, 19.56765751684866, 32.570608815839215, 27.537495974571478, 20.4793163653343, 24.177748618587373, 36.748541016732496, 31.893994077559444, 40.37926727725614, 35.01705385023548, 39.392418553752286, 40.967893446645434, 40.981586440916985, 40.754222331508515, 39.41174014922112, 38.10238238303892, 55.401215476374475, 62.77087050099527, 55.09855754913823, 66.4348388487293, 59.68143132425124, 69.19358299624535, 71.95743406972578, 71.35451870579874, 55.9230201475082, 51.25217937654065, 51.25922395337013, 49.0019783666057, 55.13136033088931, 56.90267524411602, 57.58469696967833, 57.50328033201156, 57.44914377889326, 50.581430542853575, 38.750789396224484, 27.01202388732664, 17.575526891216157, 18.299504249326645, 22.2231884156504, 16.100742182423993, 23.726505425668535, 27.569953587747392, 15.96189812306435, 24.053933120542958, 24.200651338023526, 21.41755711647772, 17.966440108514604, 16.37604844185614, 22.832693361466934, 8.723529731073688, 14.948223329359486, 11.709081992026299, 9.164424730885415, 4.921246843953287, 3.1009584424957155, 1.0277836817887522, 0.5130516263025423, 0.38792749686587247, 0.7776913371297621, 5.830978828091776, 19.280147783217892, 45.9413254645563, 60.21596408659413, 64.32950665873867, 62.04961722896945, 51.897860342456454, 39.97620451834894, 34.60910381809358, 48.25031495863392, 53.72901493503202, 62.55770537161059, 76.83998477074408, 75.42691953720586, 73.77611944752356, 40.951027254904474, 2.855777456875771, 0.1369110509873398, 0.3541991583281948, 0.4495905880485812, 0.376666494675221, 0.45279274364152267, 0.37638558555514584, 0.36633478778023876, 0.33818507086365457, 0.4269178482072969, 0.5171917186629388, 0.356072825529883, 0.29226646548317325, 0.31014962362185605, 0.22049616181081344, 0.18956231283805064, 0.45051822859433394, 0.2502406439593723, 0.2671583934176353, 0.21476179451471378, 0.2722440527812127, 0.1477475945026644, 0.11072683989280656, 0.21897337820020416, 0.19780448427604091, 0.128405375946914, 0.12496371828620473, 0.1738633786238009, 0.1539629424411443, 0.3094007573541134, 0.167782693620651, 0.14574269643954693, 0.28103249087449045, 0.24506363627170366], [0.25263355023437933, 0.1629808391895025, 0.04859897848819533, 0.07552348332659853, 0.028139085531415, 0.1725453703153518, 0.08456252410166687, 0.04902954288427869, 0.07379715781538718, 0.06144116317192393, 0.042655304479863376, 0.020448945560342362, 0.061855555451925726, 0.025546458219328237, 0.08430465890635407, 0.04225950132334425, 0.06913129931255695, 0.10141393800656642, 0.10217368272283386, 0.10911805525181756, 0.1714084805139611, 0.23993245596366547, 0.18472216933244662, 0.14918342713386784, 0.19429238483069405, 0.12527669584679027, 0.02757290059009627, 0.07618115448783483, 0.023983165794502825, 0.08951249397209576, 3.274790043792417, 23.265195469702444, 43.89636639625796, 52.820594003123624, 49.11079275992609, 38.366428498298895, 29.733531013611827, 26.36353646555255, 33.119003234371064, 39.92853987601496, 35.33471484338084, 44.31746813558763, 44.69919320075743, 35.1619932728429, 33.50490562377438, 23.568196604328772, 11.950949065146908, 3.150028764240204, 0.1739144920101089, 0.16548245334096495, 0.6765967811788283, 0.815368521838419, 2.114330352314057, 8.130161416146064, 4.483416195838682, 6.697397549306193, 5.887923307957188, 7.76705535188798, 8.47130956188325, 8.600470269879988, 12.547615112796908, 7.118508604265029, 11.283370487151608, 10.775832456927146, 12.188942797722357, 10.033691583141204, 10.525018457443485, 9.064624924813549, 9.928152368914697, 30.375458271272723, 30.05825031188227, 33.648868376208895, 43.067122428647934, 48.39383448323896, 45.32859240808795, 47.21197728187808, 44.85353062229772, 48.664246605288604, 47.72592152318647, 50.286142749171105, 44.696969216869725, 51.62878574863557, 45.156149325832246, 52.649084444968935, 44.24228414412468, 35.627935547982496, 46.99652541068293, 44.855938957583525, 53.45591206704417, 51.16786410731655, 52.45656274980115, 54.631199298366425, 62.09256718235632, 58.509493797056145, 62.235898433193086, 60.95757838218444, 63.057682052735366, 65.44949239300144, 64.42825232782673, 64.18883085250854, 59.81432907042965, 55.152278331018266, 44.470158161655554, 32.84932851791382, 22.883552774306267, 13.18403732392096, 14.157176383080023, 16.681124510303622, 14.955440490476548, 15.356629337033919, 16.157020349656385, 20.82843476726163, 4.4900901086868785, 7.5233898720433645, 8.267534586691088, 9.774488614451501, 6.0079002764917195, 10.933834352800924, 10.66845267049728, 4.953619145577954, 6.642087717210093, 2.263156108317837, 0.5603395678823995, 0.27007020168727447, 0.18172603010410265, 0.12591709172533405, 0.6319027826670678, 4.312612664315009, 21.451513075059463, 38.67367167626658, 47.98385658571797, 33.05960678285168, 30.581847506184733, 27.950362697724376, 24.330048368823146, 27.357094403236147, 25.935423489539858, 36.77500917065528, 54.838928022692286, 55.9451227034292, 58.747448305929865, 39.50251163974885, 5.338502699329007, 0.222084645121809, 0.14912099096803896, 0.24581965780065906, 0.07614602935650656, 0.11201356117042804, 0.14695432577883044, 0.10827550409181465, 0.17955582558868394, 0.18249665326889486, 0.07350820477210707, 0.03597689852599175, 0.05238074471332854, 0.06058914316517692, 0.03590147716984634, 0.048164936052935745, 0.050038185736705224, 0.026843355059803977, 0.05767383387372379, 0.06595639346708214, 0.10589411211830956, 0.06300590924858566, 0.03539895796547494, 0.02577366074547172, 0.034862696418478605, 0.030526828373812383, 0.029755295479610085, 0.029696253083285787, 0.07538286788809685, 0.06542757063383056, 0.05438334451267316, 0.11608350285959822, 0.023138302964188402, 0.05170603575665624, 0.12869503379108446, 0.11166880628274334, 0.06472863797699252, 0.06190773370044847, 0.018675128343485056, 0.057097762567742225, 0.05783416841539645, 0.050770918192762526, 0.045948609214035735, 0.010296983959814234, 0.02980335792075963, 0.018597605991207303, 0.04919418667052542, 0.04234660552033494, 0.023738680324787577, 0.0971061489995449, 0.12215751523692762, 0.03290726848307156, 0.09252417712442337, 0.05680396784878066, 0.1352832060787947, 0.18772842092139108, 0.029946271623034152, 0.09830875382308038, 0.12561223469674587, 0.051544509948261326, 0.047440649716243635, 0.03067658132603092, 0.03591315234981237, 0.09535432808221349, 3.054468059732068, 26.946924309576712, 58.03716982564619, 68.56980846774194, 63.656839786037324, 52.44365422956405, 40.70094869982812, 35.046616754224225, 39.733099937438965, 44.42057155793713, 38.54869711783625, 50.69372015614664, 61.44055158861222, 37.697052494172134, 33.485548726973995, 25.860296372444402, 11.906814555968008, 3.3184048389234855, 0.2849569754494775, 0.16870584489116747, 0.7391099848093525, 2.3012815463927487, 6.038932598406269, 11.09748250053775, 12.433127011022261, 7.610856275404654, 12.311710042338218, 13.170052113071566, 15.422027014916944, 15.07861860336796, 15.92838833408971, 15.204080516292205, 14.511684121624118, 13.358619078513115, 11.38194259135954, 11.24832901262468, 7.171282624044727, 9.90344928156945, 8.583093189424085, 25.552047106527514, 26.548446801400956, 32.216897318440104, 39.1465251676498, 44.780582381832986, 44.86733736530427, 46.2713497684848, 44.22468839153167, 48.939122384594334, 49.2108485006517, 52.52124263394264, 50.53833546177034, 56.49539201490341, 51.146887271634995, 57.22257591062977, 50.17681452535814, 44.099250993421, 55.092979938753196, 52.29771852493287, 61.07080544194868, 59.196504777477635, 59.26941379424065, 61.63918041413831, 64.46588354725992, 60.38368855753253, 63.33987697478264, 62.64062427705335, 64.56531563112813, 65.89827429863715, 65.48435049672281, 63.99871357025639, 58.306538597229995, 55.1025152206421, 41.28179288679554, 30.731280003824544, 20.089464149167462, 12.560551089625205, 12.139435621999926, 10.590555379467627, 9.537628446855853, 14.443835942975937, 18.243173130096928, 17.787411366739583, 12.715574925945653, 16.514800325516735, 14.400427072278916, 13.956045085384002, 12.727384201941952, 13.306315252857825, 13.308038153956014, 8.464734688881906, 11.414374709129335, 5.8482995244764515, 3.0343416429335073, 0.9984460076497448, 0.5610112124873746, 0.06689272911077546, 0.947940159709223, 4.3321181208856645, 20.392888899772398, 37.80811440560126, 47.64644645875501, 39.22366249945856, 40.820435862387384, 28.005442580869122, 25.46416836400186, 33.280432301182906, 33.871474650598344, 42.4023473647333, 61.536214274744836, 63.509146859568936, 68.17709292134931, 45.43281762830673, 7.112371565834169, 0.20987378583560068, 0.06661313000105082, 0.04888242718973949, 0.05027904761053863, 0.046789436676209016, 0.11769510670414857, 0.04336482064137536, 0.047974444460123784, 0.17481804675152227, 0.041680522713690035, 0.105882452260102, 0.06829971853162974, 0.06141475229073436, 0.05029023249423312, 0.1448824256658554, 0.06917486673281079, 0.039504813856535384, 0.06391801736167362, 0.001657110544563752, 0.040888207769321824, 0.03992849112217946, 0.05972971125776249, 0.022194863770217187, 0.023907501205441453, 0.04727932309070903, 0.026134884608308637, 0.03353700041770935, 0.04756926821785108, 0.05771064056804585, 0.07055174889824084, 0.09066940165094792, 0.03756638541216812, 0.09402301282651963, 0.4807281398004102, 0.286825004244043, 0.21245326516368698, 0.34616467332647693, 0.15228182377834476, 0.26877033434087233, 0.2298658614557597, 0.10289123131623192, 0.2566873810945019, 0.2613708442978321, 0.19955888690967716, 0.08473403586615479, 0.09768174150057378, 0.11092448291639168, 0.22798905329358196, 0.16207582888103303, 0.2640089446738843, 0.22900341499236324, 0.29053633251497823, 0.2796185070708875, 0.4762008053160483, 0.43744677677750593, 0.37000480859029683, 0.21414840323550088, 0.2551655321111602, 0.2537027638285391, 0.3277070411751348, 0.2299971382824644, 0.11263398513678582, 0.2859692533891047, 5.482226187183011, 35.59503862934728, 72.64133068823045, 84.05828337515555, 76.59988864775627, 60.77123442003804, 48.917921973812966, 42.289135994449744, 50.4782094493989, 55.88315709944695, 51.602466644779334, 55.57174836435626, 57.98157807319396, 47.67336568524761, 44.684845170667096, 31.955985176947813, 16.141895690271934, 4.943236631731834, 0.5082257013888128, 0.3455111390400318, 0.7286155608392532, 1.8292783513184518, 5.132827335788358, 18.83284264995206, 18.68246093873055, 15.749061492181594, 15.23234413516137, 22.25106470046505, 19.60006021684216, 16.89717846532022, 22.6813369412576, 15.761907254495929, 24.22133203475706, 21.542241419515303, 23.97020816802979, 19.23866479627548, 20.5501720213121, 16.862618461731945, 17.748832894909768, 37.28774532195061, 34.716329651494185, 36.8432701787641, 46.759437745617284, 53.698640100417606, 49.75797991598807, 50.95351049976965, 48.10663069448164, 51.71811772931007, 53.15159497722503, 55.16524176443777, 51.81539643195368, 58.84444852029124, 54.66723803550967, 66.71771234081638, 59.53153794811618, 48.93765541814989, 59.212990499311886, 56.34752650414744, 66.4976046162267, 64.28261080095845, 64.50629180477512, 71.07117452929097, 69.83117211249568, 61.44029271218085, 64.7147540123232, 63.196122107967255, 66.67348369475334, 69.99442115906747, 69.75489770212482, 70.5385245046308, 64.90847987513389, 62.11925891137893, 47.701740111074145, 36.75010604243125, 27.18727538662572, 19.576716230761622, 24.570848557256884, 26.861442135226344, 24.523764425708404, 24.296245382678126, 29.06947570462381, 35.002646984592566, 12.92860375296685, 16.553833792286536, 17.14165783697559, 21.55678752929934, 16.550129113658784, 21.737251858557425, 21.18431337418095, 15.84999780501089, 17.356803763297297, 8.723407157005804, 3.3166211410876247, 0.6311225374379467, 0.6557974327475794, 0.29843065407006975, 1.1080402784770536, 5.906324617324337, 25.984509991061305, 48.86714296956217, 61.39604053189678, 45.64153086754584, 46.49212429600377, 39.386107460145034, 36.632391791189875, 39.86915126923592, 37.39255105295489, 50.35717295062158, 71.78642657495314, 74.50702175017327, 80.79440855210828, 57.831457199588904, 11.692882603214635, 0.7660069028216024, 0.34098398841677174, 0.36346275479562823, 0.21563029307271206, 0.4031899601461426, 0.2535725442031699, 0.24324498950473725, 0.33547030040814035, 0.43263497852510024, 0.299130919719896, 0.23191802714380527, 0.16356723353026376, 0.139125979715778, 0.1370454074875001, 0.25967065004571793, 0.22388499770914355, 0.2728915502948146, 0.15203938759382696, 0.20760728406809992, 0.1913966490857063, 0.2347755810666469, 0.07352197137210639, 0.14799592956419916, 0.08803981251173443, 0.10981826727548916, 0.14864687447346028, 0.1015388026773449, 0.15774073650039014, 0.1303358102637914, 0.1541146891371858, 0.23175773090652882, 0.17583250038085446, 0.24007291052370305], [0.09058021369480318, 0.11670521385366879, 0.04524629044857237, 0.14388188419322814, 0.10131043952799614, 0.06065453259995388, 0.05930713332828976, 0.05949852124397313, 0.11433373505790388, 0.01686568420770909, 0.009918181251944795, 0.032362702542976025, 0.05880417745380152, 0.03172614668015271, 0.1393678643169903, 0.015279190810096842, 0.05270664234675708, 0.059063915734089194, 0.1685955129083126, 0.09165092882129455, 0.09158019592324573, 0.19733137901752226, 0.09017807882158987, 0.3076633925159132, 0.08473519265892045, 0.10779260056874446, 0.16570570668385876, 0.0030196325115544064, 0.11221677365322268, 0.2765900389321389, 10.285806828929532, 26.86644707956622, 29.925040737275157, 53.45549629580591, 47.43099458755986, 37.93126506190146, 34.45749636619322, 31.512443557862316, 18.709405660629272, 20.793608042501635, 34.38359498977661, 25.600780594733457, 22.45582615175555, 54.57631749491538, 43.03059731760333, 21.169327958937615, 4.685505042153021, 0.4560292199734719, 0.04109106785167129, 0.35854879105764054, 1.4004314017872657, 3.484266429178177, 4.167651668671639, 5.039139563037503, 8.352996168598052, 8.645782470703125, 11.359481138567771, 7.637776482489802, 10.928794107129498, 11.795976219638703, 9.926751102170638, 14.381987029506316, 9.589378237724304, 22.556850717913722, 12.289493737682221, 8.50662854409987, 14.94499227693004, 32.42690690102116, 16.680230209904334, 40.02995667919036, 46.22077080511278, 49.490988100728686, 58.81768226623536, 58.32455012106127, 58.17097756170458, 61.134167409712276, 57.91871816881242, 62.241621171274495, 57.829193991999475, 62.374103146214644, 61.25054805509506, 68.23384177300238, 62.1239814450664, 58.83390518926806, 39.7462437998864, 31.86309756771211, 42.89665229858891, 44.156227342544064, 47.66627403997606, 50.70574222072479, 43.06219985408168, 52.99777923091766, 68.01468326199439, 68.41878152662709, 63.65006977511991, 66.333265150747, 66.40452677203764, 67.85900438985517, 67.36073001738518, 69.84818735430318, 64.5344622673527, 60.06791814681023, 52.679216092632664, 47.499071244270574, 37.812201515320815, 29.86914303994948, 35.55741133228425, 24.616581432281006, 8.438273399106919, 18.88146827297826, 18.227222811791208, 10.370504529245439, 11.487216065006873, 23.382115440983927, 12.874006321353297, 6.997555455853862, 6.561014286933407, 10.413751602172852, 15.826945054915646, 4.7086607544652885, 4.678821813675666, 6.391732635036592, 2.5242918249099486, 1.000091993520337, 0.6344553263437364, 0.03721801841992044, 0.286295821349467, 0.6587511613484353, 8.40436254778216, 17.688047924349387, 33.78167590787334, 39.503919770640714, 28.9535657436617, 41.58482736156833, 26.770043065471036, 22.849598776909616, 28.31006757674679, 45.02276912812264, 47.517306343201675, 53.79938225592337, 55.65918584023753, 51.86749335258238, 17.947438186214818, 2.802616593337828, 0.05808944423352519, 0.1850649017480112, 0.053161664099823085, 0.12429927490771779, 0.09493530863114903, 0.04757080805457888, 0.07858093257152265, 0.16645808163429462, 0.01754545317512126, 0.06468206749207552, 0.021123340420965708, 0.06854236155988709, 0.09424437393224049, 0.02579428957805278, 0.07582349101862601, 0.14884503077595465, 0.08101211259922675, 0.041941697408835736, 0.012824589559327693, 0.014196596532729606, 0.033481010881763314, 0.03606733137501344, 0.1177288145728169, 0.04116763067882388, 0.002493523305372125, 0.04908445606669111, 0.02094769369690649, 0.02689990575515455, 0.0514639136681874, 0.037640385675213994, 0.01349409007572479, 0.04102066820186954, 0.07817915009875452, 0.07654993389282497, 0.07777870061897463, 0.04644535211545806, 0.07132124591378436, 0.10092872855884415, 0.024595440500566078, 0.09199534663029256, 0.05590135156507454, 0.013837779143584833, 0.015678996776020335, 0.06034259308850574, 0.04898069328778694, 0.024945025572613366, 0.08328680384663806, 0.028880476696236484, 0.04125789881894185, 0.024321527678459406, 0.17041610553860667, 0.0912391412402353, 0.07569292665369089, 0.0535027532567901, 0.11030510082961091, 0.11799885290524653, 0.07508332750970319, 0.1715346705168486, 0.07281478028744459, 0.058288148288885434, 0.013334410539227388, 0.3337542021707181, 11.672380374323938, 34.555363424362675, 48.909026038262155, 66.70702780446699, 63.20421788000292, 49.38145591366676, 46.73462875427739, 37.681010000167355, 26.052902398570893, 34.259644169961255, 46.81113066211824, 38.3937164275877, 28.51131654554798, 50.39353332211895, 41.72351060375091, 20.527392856536373, 4.825783218106916, 0.6498665026118678, 0.09630126638277885, 1.1325636722387806, 3.141630969701275, 8.56224088899551, 8.18201760130544, 12.160750762108835, 11.937250187320094, 11.87677606459587, 15.398226072711331, 13.782811645538578, 15.359341656008075, 14.369930644189159, 14.702515275247636, 16.84341061499811, 14.41929171162267, 12.45592284587122, 8.856806966566271, 8.674562861842494, 11.644770810681006, 21.695276614158384, 23.769443611944876, 34.643055854305146, 43.256812172551314, 49.5347656742219, 59.50863522868003, 59.25619932913012, 58.675727767329064, 61.229284886390936, 60.31648658937024, 63.07836078828382, 61.4838388658339, 63.187940043787805, 63.55245767101165, 70.63356353390601, 67.7826201531195, 64.03320689355174, 44.04315325521654, 39.45641202311362, 50.321314642506266, 49.84731581903274, 54.54166335444297, 57.632851908283854, 50.600355978935, 58.119041458252944, 68.04299492989817, 68.85522365570068, 63.190595488394464, 68.62193676733202, 69.04615679094869, 70.31027393956339, 70.27414891027635, 72.50595400410315, 66.29340602505592, 61.11979976777108, 53.073088738226126, 47.398627188897905, 37.67225919231292, 30.155183845950713, 26.07203572027145, 14.596079799436755, 11.849042946292508, 17.889471438623247, 18.57832593302573, 15.40792021059221, 14.991576306281553, 22.353589573214133, 15.792773365974428, 16.863999136032596, 11.359024182442697, 9.153307753224528, 11.368478075150522, 8.928080354967426, 10.916177803470243, 8.265896016551602, 6.28139243971917, 2.236294246489002, 1.7555593651148582, 0.2178961819698734, 0.20556683952529586, 0.9764983240635166, 8.261566700473908, 18.588930060786588, 34.66460143366168, 35.60341288966518, 29.04155431255218, 38.114945734700854, 23.519906343952304, 23.29113998720723, 31.103261901486306, 49.3310103108806, 55.012041830247455, 62.07726601631411, 65.15832701037007, 62.1250718639743, 22.94185684573266, 4.21852235832522, 0.07773834310712353, 0.14973065905993985, 0.03909397622450225, 0.06829232578316043, 0.0878194932855906, 0.014721664577542294, 0.07390703014548748, 0.031527726077324444, 0.010622686240822079, 0.05152399794408872, 0.04700256999762309, 0.07122523977511352, 0.05806371134014861, 0.08714895950810564, 0.21045366842900554, 0.045814409761899905, 0.04945921478793026, 0.02380394718549665, 0.036944934887991804, 0.0067911204701710135, 0.0728573058281214, 0.0630658901026172, 0.011603769080172624, 0.0026294119813809955, 0.025214426136846026, 0.04063306601657983, 0.03020505803907591, 0.1997276867229131, 0.09242111531596992, 0.0337908091774631, 0.029593051463786154, 0.008318655741130634, 0.39412101129851035, 0.21764922586660232, 0.16833055373882094, 0.2530711703002453, 0.16874842405799897, 0.18687031051564604, 0.2513217932033924, 0.142405801302483, 0.22757603997184386, 0.107361875294197, 0.08979988419601033, 0.18074343041066201, 0.18767246585940162, 0.21080818327684558, 0.20806817788510554, 0.15975527194959505, 0.19625444325708574, 0.15222709445703417, 0.3905197238970188, 0.20653545045323912, 0.18094662757169816, 0.3546321818665151, 0.22105274000956168, 0.5472172171838823, 0.2232313408486305, 0.3116682243923987, 0.23659067318564464, 0.12372376667636058, 0.20487714588882464, 0.9296006889593218, 16.915046822640203, 47.444232586891424, 62.7013425673208, 84.07076435704386, 75.65517794701361, 61.0555003535363, 54.62806924696892, 53.498308966236735, 33.91375387868574, 34.08416517319218, 46.08974402950656, 39.1557192033337, 35.50197255226874, 70.45424845910841, 52.933016977002545, 25.846056207533806, 5.73398498758193, 0.8890031770833078, 0.10673297073451743, 1.2221192280131004, 3.3613270905710038, 11.678112918330777, 12.847364602550385, 16.68642559359151, 19.277355055655203, 19.139883825855872, 26.46870697698286, 18.743069402633175, 25.007169092855147, 25.373722430198427, 22.15887527312002, 25.96342529020002, 19.7102847022395, 34.50099545140421, 24.724685876600205, 16.717341715289702, 22.857974998412594, 39.380757347229995, 22.47219224129954, 43.23175999426073, 47.621653156895796, 51.71201452132195, 63.02710717724216, 62.40545465100197, 64.21288282640519, 63.66358234036354, 62.213454631067094, 64.51765098879414, 60.66991959848712, 64.88955051668229, 67.22220759237966, 73.80817305657172, 70.27640035075527, 70.85949205583142, 52.25284661016157, 44.692599696497766, 55.36340775028352, 54.19037195944018, 59.77767059879919, 62.739295421108125, 56.82451809606245, 66.3735165134553, 69.6708962225145, 70.2333091920422, 63.805450547126036, 71.87686074164607, 69.88173146401682, 73.68730129734163, 74.08710064426546, 77.20040352113786, 70.16021190151092, 64.14311955052038, 55.860748598652506, 51.70127507179014, 42.71205771353937, 35.007036116815385, 41.642274395112075, 29.545478859255393, 14.75247254294734, 30.992696169883978, 30.198453472506618, 18.652739178749826, 20.910310322238555, 36.71853096254411, 24.975611663633778, 17.562153570113644, 16.253125283025927, 20.49680229156248, 25.3193054276128, 11.294409998001592, 12.904292902638836, 13.68822466942572, 6.813454108853494, 2.105899707924935, 1.9042729658465234, 0.31866882777502464, 0.7439744592674318, 1.1765752396275921, 11.106218599504041, 22.57113402889621, 41.3065508873232, 49.2860128802638, 40.58795305990404, 56.298873424530036, 40.309143143315474, 33.19813313022737, 40.06259079902403, 59.45446729660035, 63.16884986815914, 71.87786486841017, 73.75788042622229, 72.5914224501579, 35.57686628833894, 6.767360866069795, 0.2961053014282258, 0.32439763327279403, 0.272804859785303, 0.25092476047575474, 0.2784011627156889, 0.17600808773309956, 0.29872057238413446, 0.3246770408605376, 0.14263348263357917, 0.17053129451890148, 0.23970485124136173, 0.12157574040634979, 0.19861790111228345, 0.18285651541044637, 0.3320013929999644, 0.29951206378398404, 0.19056291559771185, 0.17061040075796266, 0.11641178685691088, 0.15850697764225546, 0.16748516039261896, 0.12881874166909726, 0.1437842845916748, 0.12700849122578098, 0.07388580950998491, 0.1538393418154409, 0.173187168134797, 0.22018511479179706, 0.19044964183722773, 0.1222928676513895, 0.22101987483761004, 0.27426103971177535], [0.06916480799836498, 0.05699589968689027, 0.08364442135057143, 0.13725370679411197, 0.07298530379851019, 0.022203210298152223, 0.06385490320803178, 0.043755196064950964, 0.01461453963026044, 0.05204856898936053, 0.03324245110214238, 0.05070159106605476, 0.004481713469665979, 0.03065579161498576, 0.02273006811587801, 0.05926983633769616, 0.12089877915118011, 0.10065591698812862, 0.06752740231252487, 0.0837342604814518, 0.042610097631451585, 0.13206107091278801, 0.24020054077188815, 0.026048918051885504, 0.16691929720822843, 0.11521973106409274, 0.04155691059666776, 0.07812891771355945, 0.08889586214096316, 0.6309707294548712, 19.938137146734423, 34.64041609917918, 39.01425500069895, 53.8817245729508, 40.92058181762695, 39.21613154872772, 20.927135329092703, 20.706252936393987, 23.12219369796015, 27.285983793197143, 18.66840708640314, 18.25323793195909, 40.755524558405725, 38.14169237690587, 26.88913602982798, 7.846403919881391, 0.5691310090403403, 0.20928236595805616, 0.43566528527486714, 0.9337161132885564, 1.9870683166288563, 3.9520436381140067, 7.385017967993214, 10.637910154557998, 13.37401242025437, 4.389288627332257, 8.022762017865336, 11.92540757117733, 15.32602994672714, 14.846093635405264, 16.626678089941702, 22.191917319451612, 18.76841183631651, 11.724864629007156, 15.661516151120587, 30.25937572602303, 31.373185688449492, 38.048751815672844, 43.1630047675102, 53.54692282215242, 59.30096926227693, 65.22654487240699, 64.9808946732552, 64.69095699248776, 64.57230137240502, 67.88605305456346, 65.7235013284991, 65.4878649403972, 63.44519261390933, 67.16863586056617, 66.5535140806629, 70.33890724182129, 70.22002804663875, 58.531157047517844, 41.268205796518636, 28.39665585948575, 40.90812044758951, 45.16513939826719, 47.60162945716612, 49.04350449962001, 37.402262841501546, 52.01956756653325, 63.53530906861829, 65.85140981981831, 68.0629676388156, 66.97564740334788, 66.32865244342436, 64.49492085364558, 61.89993958319388, 67.40317006264964, 65.8947520102224, 67.08502661797309, 67.43363903414819, 58.414580283626435, 48.734362894488925, 45.05001391133955, 32.393054885248986, 28.225063931557443, 24.380231172807758, 19.49794915414626, 19.89811916505137, 19.448972478989635, 16.291383101094155, 16.777877615344142, 14.535476238496843, 15.326982102086468, 14.19798864472297, 8.054697465512062, 5.71045272773312, 8.268021941184998, 12.575572786792634, 5.317462615428433, 4.343534179272191, 3.3411960159578635, 0.8071745066873489, 0.27332095789813227, 0.21967163669966885, 0.07610254620592441, 2.2572811332441147, 12.986077262509255, 18.74686625695998, 41.47017648143154, 59.14487854126961, 40.37168141334288, 32.108502618728146, 24.85005463323286, 29.92358553794123, 37.27586838506883, 46.97361484650643, 45.609767513890425, 53.61796871308358, 57.3579369052764, 32.88262551830661, 9.653944373130798, 1.1925378153401038, 0.0940672850476638, 0.12229311279952527, 0.027034354185865774, 0.01355159072010147, 0.04711449161292084, 0.09253461124195207, 0.07051705277615017, 0.019360815340112296, 0.05923515936780361, 0.04554702592412791, 0.0494560546752426, 0.04527240638591109, 0.09046085719620028, 0.05117216823442329, 0.1037476639894228, 0.012194809744194632, 0.05459496097999716, 0.04963809248781012, 0.06129194456603258, 0.038157744002678705, 0.08677936804991576, 0.019291488213404533, 0.04754126004333939, 0.05427407356159342, 0.03271300773767214, 0.04062209180706451, 0.013687179664209967, 0.08235272050144211, 0.04743641325002236, 0.047831270287955, 0.05880071090594415, 0.0323442091804839, 0.024069821830057812, 0.033610805328334534, 0.04150228852766656, 0.07049338065928991, 0.03663455819590919, 0.048083389823835705, 0.06798635792708205, 0.023937876591639175, 0.09508675655290004, 0.03237466500591367, 0.033411331354610385, 0.05570253259652565, 0.05984972276154065, 0.06467428403876482, 0.05298672792231364, 0.02877624085803907, 0.10334145352845231, 0.03603262376160391, 0.053537391922286445, 0.08175364740553402, 0.039648742625309576, 0.08316045296528647, 0.0990313585967787, 0.15056653759412228, 0.015131056218618348, 0.03727516474863214, 0.0919007654151609, 0.11537124027287769, 0.9603266982782273, 22.526058150875954, 42.95816290763117, 49.02801505980953, 69.72633500253, 51.42895667783676, 49.98218651740782, 29.644228450713623, 33.566365242004395, 28.62034470804276, 26.620534081612867, 24.142904243161603, 20.75529629184354, 38.97858104398174, 37.77864171612648, 27.173329399478053, 8.177362238207172, 0.6463203122538905, 0.13554655646364536, 0.9306146216488654, 1.8916781126491486, 6.059693703728338, 8.754863585195235, 16.420779151301232, 12.302590531687583, 9.917223665022082, 12.72352360909985, 18.72457934964088, 15.551205373579457, 12.45200930103179, 14.955525802027795, 14.916109904166191, 16.729759939255253, 9.632516464879437, 8.083209664590898, 11.2653422932471, 21.50914053763113, 28.433322175856564, 37.47991792617306, 41.89430629053424, 55.448617319906916, 59.70376137764224, 65.69607611625426, 63.76297520053003, 65.79611616749918, 63.485612638535045, 66.46184828973585, 66.78924068327873, 65.31289977412071, 64.04033384015484, 67.15357395910448, 66.43999284313571, 71.28568895401494, 73.70342223874985, 64.38583189441313, 46.255146457302956, 36.42150948124547, 48.75369625706827, 52.003509383047785, 56.32090145541776, 56.04016957744476, 46.47847444780412, 55.54007522521481, 66.76522793308382, 64.90796604464131, 67.79988642661803, 70.89933549204181, 68.44371211144232, 66.68141472724177, 66.13752318966773, 69.40575184360628, 67.17455863952637, 66.10629327835576, 65.52501370829921, 58.14454078674317, 51.07116199308827, 42.66735053831532, 35.117125280441776, 28.82080920280949, 21.468628337306363, 16.932764168708555, 15.258605384057569, 16.459459604755526, 14.941597465545902, 20.106300923132128, 17.57616427636916, 14.414744704000412, 12.165199710476784, 10.890195042856279, 12.652650302456273, 10.813485249396294, 11.692339354945767, 9.241238467154965, 7.027958237355755, 6.631945448537027, 3.162842167000617, 1.0620796608348047, 0.4938341881478987, 0.101549344047183, 2.4705261809210626, 11.696968732341645, 19.98705694752355, 36.390569825326246, 47.78574159068447, 43.72103252718526, 35.81428735486923, 29.599187874024917, 29.363259269345193, 42.36893269323534, 53.48152122189922, 52.69478790221676, 59.322585444296564, 66.97574154023202, 39.91555683074459, 14.83075422625388, 1.6027549774416032, 0.10065954824488971, 0.12982974790277022, 0.03489052839276772, 0.05389221320529619, 0.03248210883729401, 0.004893925750718242, 0.04071321030477843, 0.05268515358048101, 0.0041260906671654555, 0.05158234320040192, 0.026909523989043893, 0.04155907096461423, 0.045379260329589735, 0.0014601763917110682, 0.06029098557548658, 0.0797342396371307, 0.046173417715415846, 0.04058965564435048, 0.08397218440809558, 0.030401517456818013, 0.0750783019729199, 0.0330564487845667, 0.06656485114006266, 0.053412496607991, 0.0606226250379076, 0.07355173388796468, 0.02759198575550991, 0.08778708776639355, 0.01581713200486716, 0.039704762804772586, 0.0940854489923485, 0.17476489557133568, 0.2200241903624227, 0.11399625800549985, 0.3300057339572138, 0.11804590602555584, 0.12358509710118656, 0.1431683652223118, 0.11607090837412304, 0.21188539482893484, 0.20185875946715956, 0.15608574143580853, 0.0838636220883458, 0.13173074912159674, 0.14687780891695332, 0.1928806226820715, 0.1842266483412635, 0.28099817013548267, 0.18627225631667724, 0.18576152081931793, 0.1878987222669586, 0.10051192310188087, 0.2097051085964326, 0.34751945385529154, 0.23875545379855942, 0.4099690109010666, 0.25795188582231926, 0.1397607601698368, 0.1951576198541349, 0.2225628984911788, 2.0889947827785247, 30.368143050901352, 59.366206122982895, 70.56716565162905, 80.66839848795246, 62.164868231742616, 59.57167163971932, 35.62407985810311, 37.46062770966561, 38.22605863694222, 44.28703446542063, 31.312945927343062, 32.33872025243698, 55.821493517967966, 50.29297944038145, 32.804521322250366, 9.520946606512993, 0.701674209727395, 0.49349775297507165, 1.0580838687958256, 1.3305836723696802, 6.262059077139824, 13.174736403649854, 23.131372044163367, 21.657404168959587, 23.823482105808875, 16.90950451358672, 25.492758520187873, 26.200057960325672, 29.6200744951925, 28.96656251722767, 28.23736252323274, 32.74947477925208, 32.79782191399605, 23.026346660429432, 22.2906727944651, 36.900368121362504, 38.831382336155066, 41.633417683262984, 46.413723960999526, 57.143485238475186, 61.079383665515536, 68.38337036871141, 65.61166671014601, 67.21002471062445, 63.876194415553925, 67.51069007381317, 65.72670590492987, 65.08015417283582, 63.636972981114546, 67.5026649044406, 66.0020366791756, 72.14143245450913, 74.78999722388484, 70.41251444047498, 53.32645423950688, 42.34091520309448, 54.009515393164854, 56.18071986782936, 62.05933293988628, 62.39065947071199, 52.903740406036384, 64.4853541927953, 68.8782871923139, 65.67996301958638, 67.72661655179917, 71.88453289770311, 69.79496079106485, 71.05734425206339, 67.18705531089537, 73.50070630350422, 69.29848286413377, 69.5271021319974, 67.4923098471857, 61.17463058040988, 49.432493794348936, 47.56866193586781, 36.296440785931004, 34.962054375679266, 30.164101354537475, 23.80471552571943, 27.15229961179918, 33.040846086317494, 31.626762997719553, 31.21317259726986, 25.782433402153757, 27.293000913435414, 23.118090898759906, 17.228026466984904, 15.700544714927675, 17.267397257589526, 20.848487884767597, 20.813580751419067, 13.660235616468615, 10.270169319645053, 5.106218957131909, 0.6286102593425782, 0.6785218682019942, 0.29714947926902, 2.792043354242079, 16.837619235438687, 25.615248257114043, 52.803457167840776, 71.85839422287481, 55.61201933891543, 46.824466720704116, 36.802061757733746, 40.45965233156758, 50.36109532079389, 60.874698700443396, 61.05539837191182, 69.09308402769028, 75.36273387170608, 49.8940626267464, 21.970299482345585, 2.922208679299201, 0.25934729965463765, 0.264396799668189, 0.11818510420139759, 0.19512725212881643, 0.24389083226842267, 0.2137576371070839, 0.1525229269698743, 0.1282903325233248, 0.16517218773163136, 0.1610636275501982, 0.1769414739382844, 0.25488411737305505, 0.21379640115605247, 0.15242030183153768, 0.21635164146221456, 0.11426598224188052, 0.14665685383783233, 0.16169321392813038, 0.20595100197580554, 0.14679715518028508, 0.22175495152271565, 0.1686441594915044, 0.09970812066908806, 0.17508959427716272, 0.22046311277775998, 0.18545528483246604, 0.10263242383277225, 0.18422949818834183, 0.13038441088170777, 0.16268394947532686, 0.21369726937865058], [0.05113153876135907, 0.07621681588071008, 0.04570451061872225, 0.08097274334079797, 0.10490275603989441, 0.04099398535946685, 0.09433696331876902, 0.019583963345916524, 0.04160882071441701, 0.01862121490581382, 0.09404173601538905, 0.06450543059937416, 0.06824453721844381, 0.07515406806863124, 0.03160999051385349, 0.07783482422030742, 0.022672167190560893, 0.06858864093139287, 0.08444427843055419, 0.09520050528789721, 0.06355648514844718, 0.07428764560890776, 0.11588838792616322, 0.04045940154502469, 0.1171137379001706, 0.13572238896402622, 0.02608094818799967, 0.022807730279201945, 0.014167479445947515, 5.077504755989199, 22.018562286130845, 40.08370099529144, 50.020821863605136, 50.59749657107938, 39.81736421585083, 30.781388282775882, 30.62648407874569, 16.51094267445226, 22.446124169134325, 24.49833962225145, 21.780727409547378, 47.73748467045446, 45.19656935045796, 26.009605315423784, 12.560990395084506, 1.9088509847079556, 0.4520081776765085, 0.031139327160593484, 0.8245953460854869, 2.9318925209583777, 7.553807852729675, 10.10169469541119, 9.86667117764873, 11.486157025060347, 6.664499650078436, 16.066080197211235, 20.981483690200314, 15.373344517523243, 10.360326959240822, 10.52260914156514, 11.399706025277416, 16.762158716878584, 12.245742640187665, 19.15826209129826, 29.373561374602783, 35.33879803073022, 43.23096767548592, 53.91649246215821, 60.86638327567809, 63.78630545831496, 69.48039454798545, 66.84904898366621, 70.59077047532605, 67.7094679494058, 66.57524401141752, 67.23691648052585, 66.19053794491676, 67.73060167989424, 66.72030894987046, 66.10377511670514, 64.90746790362944, 69.33327428756222, 71.13466985764043, 64.39358249787362, 46.261316345584014, 29.543186233889674, 35.342363465216856, 44.44198377670781, 46.57445484592069, 45.1460688344894, 36.581079344595636, 54.78698799687048, 62.06400840513168, 65.29158169223417, 64.83152297235304, 68.05325585026895, 63.3692398378926, 60.34971298709993, 61.84472045590801, 64.20939976169218, 66.42514274966332, 62.467184912773874, 62.20220527341289, 61.46381124373406, 59.73138663076586, 55.82701621517059, 52.42401492211127, 37.050747871398926, 38.494701770044145, 44.90993038300545, 34.62942561795635, 29.41311259423533, 16.471885673461422, 21.2852418422699, 14.286596948100676, 18.91999379281075, 9.541712614797778, 5.397791775964922, 9.16197423012026, 9.634983635717823, 12.197686741428992, 3.989702068990277, 6.561383970322148, 3.7035283926994573, 3.595783825843565, 1.3153580119532924, 0.2579399042071835, 0.12494464269689015, 0.08801448564495772, 2.7116296175987493, 10.204477463999103, 19.016484099049723, 27.16132498556568, 41.999621929660925, 26.8243129791752, 30.08905660721564, 66.75285677756032, 88.74016561815816, 56.19273408766716, 41.95713089358422, 47.10982699548045, 57.970179665473204, 42.47117319414693, 27.60720825964405, 2.0196368593362073, 0.02719145583649797, 0.024474523097817457, 0.046526331439494126, 0.0047526136510104185, 0.031836704658945246, 0.03508683459292497, 0.06945753019423255, 0.053769179484656746, 0.057381736039514505, 0.011800844241083871, 0.04893231866580825, 0.029783123623459574, 0.0363650637859058, 0.07347231355285452, 0.059511644330116055, 0.06648735368564244, 0.007735278829181147, 0.050803752721197186, 0.09990906553162683, 0.02437556943585796, 0.016030837019394725, 0.030846185531587373, 0.023911356542920394, 0.09198240740525146, 0.0692148871659752, 0.1025007639621054, 0.02257912964259665, 0.01546459366387177, 0.06453045103098116, 0.03655508423464433, 0.064034060530004, 0.02289560822499616, 0.031427357067924835, 0.03636246674784249, 0.08515264929061936, 0.05412870071708195, 0.02460128958186796, 0.00821740860344782, 0.09179284660926751, 0.08351243972297638, 0.08540410233000595, 0.07928126716926213, 0.04351193250547494, 0.0324374535721877, 0.08160050642947037, 0.05732432541046893, 0.0889394678656132, 0.0019696851907816206, 0.09855976253147088, 0.08140416575535651, 0.1129936634172355, 0.07548517126950526, 0.035323563422406876, 0.06602776987898736, 0.02119103386517494, 0.02626040428426237, 0.0912384441002242, 0.03800996947252462, 0.05434862157750515, 0.08321758780267932, 5.054353946639646, 31.00868767307651, 52.938688724271714, 62.42096762503348, 64.1522116045798, 51.469541442009714, 42.516656998665106, 32.577774986144036, 24.40199444370885, 30.750848708614228, 31.041686573336204, 27.45573809069972, 40.27488908460064, 40.945037795651345, 27.180905457465883, 12.985830153188399, 2.362462431192398, 0.4020033818819831, 0.40481054254116555, 2.595019758709016, 8.758724178037337, 9.08438092277896, 9.457895486585556, 13.70924072880899, 14.533909251613004, 18.83987545967102, 13.240559658696576, 17.955520229954875, 22.938358091538955, 13.548137218721452, 13.677326363901939, 12.437959371074555, 12.04805616409548, 9.917553144116557, 15.043737946018098, 25.29407282029429, 33.63347307328255, 41.58471753520351, 52.119858649469194, 61.404767805530184, 65.32087395268103, 68.72751912763043, 67.92890887106618, 70.64955895946872, 69.16542037840813, 68.11371526410504, 66.94357026007869, 67.1485690147646, 67.8375490250126, 65.90649558651832, 64.5159722143604, 64.87907386595204, 68.66753824295537, 70.9681809333063, 68.14498439911874, 52.58087050530219, 37.24315974020189, 44.70860296680082, 50.56565477002052, 52.32554774130545, 53.58239673799085, 44.44261135593538, 59.364605795952585, 63.59840039283999, 65.72462704873854, 65.56044055569556, 70.56314129983225, 66.7144646183137, 63.27971958344983, 65.44956299566454, 68.53287543019941, 69.20818205802672, 63.54330285902947, 62.63238729969148, 62.6685280184592, 59.80350725112423, 56.3083577156067, 48.48931281797348, 37.75597041653049, 38.14437135573357, 26.621304827351725, 19.927942906656575, 20.454589743768018, 12.778228905893142, 15.631789488177146, 17.8017044836475, 15.00501532708445, 11.915447692717276, 11.556656725945013, 11.579639853969699, 10.178277011840574, 12.301374596934165, 12.471488771900056, 9.88912086332998, 10.478673692672483, 6.999950553140333, 2.7990168381121854, 0.6208489306511418, 0.0795706951870553, 0.09928744646810717, 3.195637104011351, 9.71659246952303, 19.04200892294607, 29.02384481122417, 40.11480146838773, 32.47239070553934, 23.080357697702226, 53.52180396356891, 81.94516135800271, 60.946066225728686, 46.25104365810272, 55.320277367868734, 65.37107244614633, 50.99406388498122, 31.734063356153428, 4.519136730701693, 0.05356752599078802, 0.07367375637254409, 0.0186131575760702, 0.048599993554695, 0.06150203268794764, 0.09899386625376441, 0.09079900074509845, 0.04837709644268598, 0.05399291929338248, 0.049951246248618256, 0.04306332673877478, 0.02926336361035224, 0.02698520773030337, 0.033584344651429884, 0.0736823518790545, 0.028937975425393354, 0.018582092710740624, 0.010162880268668937, 0.028505597316149264, 0.03955033863143575, 0.010051470017060637, 0.06871019610233846, 0.019487298371630813, 0.11250732782026453, 0.03991824469619221, 0.026185540257081873, 0.05170679035326166, 0.040064475559178865, 0.012259941581907052, 0.05107764447588594, 0.0907367637621299, 0.21192158482247786, 0.22999890028469025, 0.10555950023474232, 0.20233957157019647, 0.2554060683976258, 0.1455976147084467, 0.2598910995068089, 0.14940870294888176, 0.2314339668279694, 0.15636009284325186, 0.2322024909118491, 0.13527366062325819, 0.2331687269672271, 0.1999619410883996, 0.17434923158537957, 0.18919135774335555, 0.11686946310463453, 0.2295448706154862, 0.14341746637177083, 0.25926827002436886, 0.2114516818114827, 0.2616645011209673, 0.33642309928132647, 0.37220522761344915, 0.16573812752481432, 0.29186521927195214, 0.1333024244635336, 0.23988264492682873, 0.27350264331025465, 9.68053706230656, 42.192896719901796, 68.4365027950656, 76.33296351278983, 77.69039384780392, 63.364081921116004, 49.61775910469794, 46.084797920719275, 31.97416340151141, 37.30019100250737, 40.426935841960294, 37.336496460822325, 64.89071938299364, 58.02061742351901, 32.48722118716086, 15.345117180578171, 2.380557060241699, 0.9582448390222366, 0.6056379791229003, 2.50877125128623, 8.51707773823892, 16.68176777901188, 17.499948701550885, 19.035517400310887, 24.116169368067098, 21.08743279210983, 25.464131101485222, 27.69075866668455, 24.230555488217263, 20.956792369965587, 27.678758175142352, 23.64906999372667, 28.813411612664503, 24.539473518248528, 26.846694023378436, 35.577839036141675, 39.2565986417955, 46.116643644148304, 57.88515052487774, 61.84022934206071, 66.35237493822652, 71.67372119042182, 69.40685010725453, 69.92756043711017, 68.39855778601863, 66.63121623377647, 65.66900783969511, 68.07888461697486, 69.58739680628624, 66.73109546784433, 66.03192513988864, 65.45014350645005, 71.22784968345397, 72.25388680734943, 72.23888766381049, 58.66345074868972, 43.36532062099826, 49.81463070838682, 54.52464419026529, 58.3142029085467, 58.97949180295391, 52.32695587219731, 64.26209680495724, 66.03948746958088, 65.60064877233198, 66.3840441549978, 72.38778083555161, 68.72041963761853, 65.63851533397552, 68.95174534090104, 70.9131500797887, 71.81594633287, 62.95234680175782, 63.62996762798679, 62.3551384864315, 61.177097751248276, 58.875345030138575, 53.94027379251296, 40.333603043710035, 49.31756050355973, 50.10962432430637, 42.17986268381919, 38.77775176878899, 25.006339511563702, 31.32981211908402, 22.349347529872773, 27.50264571559045, 18.76246356195019, 16.002582907676697, 15.166036467398367, 17.152130565335675, 18.92396911498039, 10.434458774905051, 16.60529528894732, 11.47132948521645, 7.401468388495907, 2.3228587498587947, 0.5851296215288101, 0.7907349339896633, 0.3063268142361795, 3.994678576146403, 13.410301208496096, 24.30132681323636, 35.84629389547533, 53.42794949008573, 39.833736188950084, 42.451278932632945, 74.90751143424743, 96.32661788694321, 70.0259413257722, 57.98121329276793, 63.90956201860982, 74.75453115278675, 62.10846847103488, 41.42291192085513, 8.720602662332597, 0.2645516413594446, 0.2332914848962138, 0.13328843569803622, 0.12776614452201512, 0.0958264067829136, 0.15683178849998983, 0.16810514002798066, 0.10358119308347664, 0.26263004769721343, 0.2311646103137924, 0.19457389149935017, 0.16525927660686357, 0.16788116656243804, 0.18629641872980904, 0.14544851867662323, 0.2465317212045193, 0.07111323005970448, 0.14948911153741423, 0.193675990486818, 0.22611206127030237, 0.1336781446251177, 0.16389262171522265, 0.1092147968348957, 0.17717543719035966, 0.1401538552055436, 0.20360381582811957, 0.11725819143917292, 0.20439519997565977, 0.18608464138402095, 0.3014403990199489, 0.2768045741944544], [0.0894823101078791, 0.027226893148655375, 0.021924095739039685, 0.049593651727322614, 0.03262737825993569, 0.044809520740302346, 0.046877084795625946, 0.09035568098507582, 0.019091838039457798, 0.009344057724510711, 0.024639758686985702, 0.04594760563885493, 0.04604500988798757, 0.03727802225658971, 0.04206776100721571, 0.01238742340055685, 0.07612541393046418, 0.02609667788830496, 0.05299815795414391, 0.06958648577452668, 0.07429631006333136, 0.08421041476990908, 0.08070861154626455, 0.04493088438926686, 0.08858483044370528, 0.0918900631668587, 0.07389638152333998, 0.14771653729821407, 0.5912768948943384, 14.605318942377645, 26.2439335930732, 40.51468710745535, 53.87265997548258, 46.733067650948804, 34.299542519354056, 36.976830805501635, 33.8449437387528, 22.327874514364428, 25.65662337887672, 22.791614378652266, 40.92179775238037, 47.73559016566123, 32.94450483014507, 13.28390577147084, 3.605800823819253, 0.18702705210495382, 0.12177477004907786, 0.4103177034806821, 2.2123104237741043, 6.9234344267076064, 4.6041864637405645, 6.127773792512956, 20.277916385281472, 10.674543130782343, 11.298019559152666, 13.182984167529693, 18.634376602788127, 20.901628155862134, 10.149521135514783, 16.313406229019165, 18.385302174475886, 22.113936678055797, 20.272485863777902, 26.279482033944902, 36.177396851201216, 51.444273533359656, 57.825479507446296, 63.932551030189764, 66.4414833438012, 68.97499715128254, 68.90843452945833, 68.2797727277202, 71.4736803116337, 69.667083678707, 67.17668456415977, 67.14313260970577, 69.065807865512, 68.41483562223374, 69.89888791115054, 67.27088420621811, 70.23653338032385, 68.1404266049785, 71.12564056150376, 57.912720864818944, 49.80451883808259, 31.779931552948494, 32.269790480213786, 42.9960451587554, 49.49998601790398, 41.02732519949637, 37.06353872053085, 52.732713299412886, 55.904663455101755, 60.2877160041563, 68.30481313890027, 67.34930023070305, 64.50126332621421, 57.701563988962484, 58.78103948408558, 64.36026196325979, 65.93112022646012, 64.31113427685153, 64.38125448842203, 61.54839715650005, 60.67589336825956, 60.608503126329, 59.53366387274958, 53.54674239312449, 49.22860507042178, 38.826271487820534, 34.883132365442094, 34.67206962646977, 21.637917833943522, 19.213424344216627, 21.56117666152216, 9.828003471897496, 8.908831323346785, 10.177767103718175, 12.5850913986083, 11.027318162302818, 9.142822277161384, 16.156766376187726, 5.122334995577413, 7.532397104847816, 5.22590910234759, 4.866689126337729, 1.0518034187055405, 0.09252135025998277, 0.2088645416041536, 0.06318407448669595, 3.075235538905667, 9.07942500806624, 31.19797733522231, 49.82939450971542, 58.263541575401064, 57.95558452606202, 79.60752287218648, 66.12348110445085, 34.626138671751946, 32.73494043657857, 47.77502175300352, 57.0773305431489, 59.692104093490116, 33.73745118418048, 10.272339370942886, 1.0311012715101242, 0.1318681240081787, 0.021658358990304896, 0.08392889277949449, 0.0494599387410187, 0.011165347494815868, 0.00421911432978607, 0.043570476944648454, 0.011192647037997602, 0.09890608789940035, 0.0076281103106485984, 0.014895933300947711, 0.05322320394278054, 0.12752215317901106, 0.05008488262612974, 0.10730145393960899, 0.014227463172808772, 0.019494275517401197, 0.04016102178983631, 0.07261965003225111, 0.025993880380185384, 0.08139910191417703, 0.03169924167225198, 0.08066768712934949, 0.038718639106880275, 0.055950201161566286, 0.03788677487342108, 0.010051441288763478, 0.04090729484995527, 0.02584490117677037, 0.026934073276577458, 0.05956450056645179, 0.0679355203324268, 0.02835527937408657, 0.004050140231547337, 0.047362401495657624, 0.09922026055714778, 0.060117968448227456, 0.06348748360910723, 0.08934953174884282, 0.015369464695874243, 0.034963126714912154, 0.09052651093131112, 0.04463595202973774, 0.029147264900647347, 0.09245070163160564, 0.03927699079917323, 0.08379816753609527, 0.027381215815342246, 0.025664483640162696, 0.08103264375559746, 0.024935623758562633, 0.018114083852138252, 0.07798395089564786, 0.014556429945983955, 0.09076410544014747, 0.08212245745404113, 0.06674125054550749, 0.08235444419927175, 0.6066206554251333, 16.82005290062197, 37.2214101975964, 54.36501156899237, 64.14171926436886, 57.825859977353005, 42.2404593806113, 40.850547898200254, 44.29142359764346, 24.133627837704076, 34.56218050372216, 25.08941335062827, 27.293704978881348, 46.802807392612586, 36.42182719322943, 14.937434850200532, 4.002400252126878, 0.356900139201072, 0.402490000931486, 1.3035641802895455, 6.313863290894417, 7.901807398565355, 10.254277836891914, 11.632061350730158, 14.93338304181253, 12.353234214167442, 16.971509341270693, 13.329973028552148, 16.30298939443404, 21.053541552635934, 16.142610542235836, 11.973821386214226, 15.570704456298584, 19.184885178842855, 20.878215528303578, 27.783624702884307, 38.34833852706417, 50.391238735568145, 59.176139831542976, 64.81913612734887, 66.87685074344759, 69.76101659959363, 68.95816233850294, 67.90999520209529, 69.96458761153683, 68.52139857507521, 66.59621300235872, 66.48953237841206, 67.79512466922884, 68.49524421076622, 70.28728100561327, 69.03704120266822, 71.11563067282401, 68.23154326408141, 69.92812525841498, 61.227625723808046, 56.274256629328576, 38.966272646381015, 40.275038134667184, 50.75240665866483, 53.56081977967293, 51.22069843353764, 44.94778517753848, 57.15737827362553, 57.875062188794544, 62.088938989946925, 69.98033985014885, 69.31697291712608, 67.24101143498575, 59.16677713394166, 61.813388562971554, 65.42149843708162, 67.63913985221618, 65.8600704131588, 62.697643772248306, 61.48947531177152, 60.30968127712127, 60.99262475967408, 59.07184008629092, 52.15375577249835, 47.08239786086544, 40.60520364392189, 29.321433075012703, 29.07481993398359, 19.15480059962119, 12.508735599056369, 11.294887546570072, 9.846345455415788, 12.68135420737728, 12.825131627821154, 19.046666737525694, 12.289112287182963, 15.704246451777799, 20.591323567974953, 12.551655154074393, 12.027031279379322, 8.973694578293832, 7.510447031067264, 2.6753650990224656, 0.7615721730455276, 0.25185347354460147, 0.28555624006736663, 3.4462885702809984, 10.10408341884613, 27.428512919333677, 45.48746408954744, 43.76601034595121, 50.60694556082449, 87.21264562299176, 79.94191277411677, 43.53249988248272, 38.22515256943242, 53.40619994748024, 64.62997982578894, 66.73584938049316, 42.41242393370598, 14.206101086831863, 1.431520720643382, 0.0473665498617676, 0.10283075633548922, 0.021552481808729713, 0.014500673109244917, 0.07548901703088515, 0.016197385491743203, 0.02521257986494851, 0.01722885393387368, 0.06652798698914629, 0.07699055702335413, 0.00980868334731748, 0.16400555839702008, 0.06917152658946092, 0.007944440463512776, 0.09010537707757565, 0.027113048652667674, 0.03040170514835946, 0.041356976970189044, 0.014739726057967112, 0.05838542230307095, 0.040164227867799426, 0.03792936553157145, 0.014414300526221915, 0.019849261509314663, 0.027466919986651312, 0.01662617447906204, 0.038722978994971326, 0.020911974847436916, 0.06102770551918976, 0.02728437464083395, 0.2225314888862833, 0.16498043592418396, 0.20999404631795424, 0.14011260903170034, 0.19149408014791627, 0.18004858866333964, 0.13028989095361004, 0.19799740053713324, 0.30816888797187036, 0.11518219275580299, 0.11508964167367067, 0.1928703264603692, 0.1605179584434917, 0.1536317319879609, 0.19397245119175605, 0.29922000042373137, 0.09632217292223247, 0.14110876848140072, 0.23481730221500322, 0.15384865744460016, 0.17313691276696422, 0.17488607535919837, 0.17884141795577543, 0.19811309513545808, 0.3357383086075706, 0.18818203690311602, 0.18769243011070838, 0.20302235509359068, 1.0260286049977427, 24.229039492145663, 50.22694241616034, 68.97687988896524, 79.39454601657006, 69.23172412380096, 51.07224064488565, 53.40983598462997, 50.25858417634041, 35.08675044582736, 39.812269056996996, 35.84754905393047, 57.786047920104004, 60.277011855956054, 44.04045074216781, 17.56761350939351, 4.705391949222935, 0.4297149577929128, 0.4763747685618939, 0.8921750875249986, 5.7593725285222455, 11.113593636020537, 19.128791363008563, 20.28840284193716, 28.266370411842104, 24.12360029835855, 20.960165608313776, 24.51959102384506, 30.36307534863872, 33.40039799290319, 22.834040695621123, 23.687832816954582, 30.775934227051277, 31.034759667611894, 25.72539233392285, 30.94054629725795, 41.302291193316066, 55.615737745838786, 61.921500852031095, 64.66271200487691, 67.20384305523288, 70.88765467366865, 69.58420399696597, 69.49463275171095, 70.87601307899722, 70.98606694129207, 66.89447003026163, 66.22068528206118, 70.4869218026438, 69.9186723462997, 72.16231515330654, 69.81642400064777, 72.73038418062272, 70.21145374544206, 69.50694899405204, 63.270870716341086, 60.836957654645374, 45.40859699249268, 46.018372581851104, 54.744481271313084, 58.69834023137247, 58.18050107648296, 52.74063648716096, 60.924320605493364, 60.49266769040016, 61.18014151050199, 70.58873084283644, 72.04541283269083, 69.85725587414157, 63.54253015210552, 64.64359437265705, 68.97911563996347, 72.05457548941337, 68.41281167922482, 63.40936568475539, 63.573077571007516, 61.57912108205981, 61.34786205907022, 61.71854565220495, 56.23101249817879, 50.11751613309307, 42.62567927760463, 40.620940193053215, 41.71424204303373, 30.309015281738777, 25.12523831859712, 34.56123521251064, 20.56653222730083, 19.40962914497622, 16.34630608943201, 26.467298846090994, 21.067046273139216, 21.585273742675785, 34.52650262463477, 11.572455052406559, 17.195761049947432, 12.621525314546401, 12.546222671385735, 3.250617211864841, 0.603940021847525, 0.6485584534464345, 0.4639454516431978, 3.7988361043314782, 12.593646087954122, 37.464444175843276, 59.666989157276774, 75.14344200011223, 71.72132307483305, 86.35337983408283, 71.76419458081646, 47.50375455425632, 46.58162101622551, 64.0268369643919, 72.25202760388775, 76.32930001904889, 49.9172124555034, 21.77447319030762, 2.810597881194084, 0.41020223870873457, 0.3284673374747077, 0.15642367814096714, 0.191577430514078, 0.20233505165144322, 0.13487676579144695, 0.1723668411854775, 0.1053564333086533, 0.20069150194045038, 0.20121294734699113, 0.10233423176912532, 0.2515945971132286, 0.24525040850764324, 0.13314733762414227, 0.2465296987323992, 0.19096940185033506, 0.13552008046498223, 0.12861784277183394, 0.15275782484921718, 0.19923863151381094, 0.17482699465847787, 0.11439064772979868, 0.1347922816151573, 0.23653073446644893, 0.18654525940937383, 0.10342976814436336, 0.09445841889828445, 0.09611057177666696, 0.12739044734306876, 0.10935241686961344], [0.037802252392735214, 0.04641319557483639, 0.06995061502581643, 0.051045373022075624, 0.07987964312515913, 0.060091002153292786, 0.04112079972401261, 0.017772743801376032, 0.02311797673633743, 0.026411695157988902, 0.01537178019662538, 0.046276977481020075, 0.06432065785291695, 0.08463566251579793, 0.04157083041425194, 0.05028091686507387, 0.04068946157912574, 0.04741158817083605, 0.01846905069185361, 0.03722826867634731, 0.033091983772934444, 0.08928385503109425, 0.05456208814716628, 0.06233103941344927, 0.05360096955912248, 0.07507965028766664, 0.053345337510108955, 0.07462082490805658, 4.869092068364544, 17.28039599234058, 30.479340284101426, 47.84633828747658, 51.85732656909574, 43.46253656571911, 39.68108146421371, 33.96245794911539, 25.33909574631722, 22.477779657610004, 27.120071457278346, 47.48449179434007, 72.60598228823754, 36.97309670909759, 16.2937286784572, 9.528733491897583, 0.8864596426006287, 0.3065657110944871, 0.512004230892466, 1.1107799314683484, 5.861292375672249, 12.800736446534435, 6.570641254225086, 7.87693270752507, 14.213534958900945, 11.16121611287517, 31.6962517076923, 9.762698950306062, 15.571284967084086, 35.57000606290756, 16.78608125255954, 15.119352417607463, 20.805761506480557, 29.693783675470662, 32.89042515139426, 41.41768340141543, 53.655929411611254, 58.421260080029896, 64.48491096496582, 67.13276970771052, 65.65824877831244, 64.30406616580102, 67.54095508206275, 68.67761088955787, 66.84780166995141, 71.91029502499488, 67.68771448443013, 69.01587609321841, 66.69733955014136, 68.82061266130017, 65.97057142565328, 65.33175460753903, 66.42363655951716, 71.55505380322857, 69.51986928139964, 59.39556506372268, 50.624129464549405, 35.67172096621606, 29.417841011478057, 42.83848747130364, 51.622003970607636, 40.669714866145966, 39.53598122442923, 53.6506812803207, 58.5101802118363, 60.93638581614341, 66.9581614771197, 65.45096328181606, 63.38222288316297, 58.08305371192194, 55.33298192485687, 61.18489934552101, 60.616869541906546, 65.56277044357793, 61.50390571163547, 57.888115836728005, 59.334278029780236, 57.68459973796722, 62.260393634919204, 59.80224424792875, 60.943661812813055, 52.74935199368385, 41.55382102535617, 42.76381338796308, 34.18163214960406, 26.79389107611872, 23.889754472240327, 8.626149046805597, 9.96917938032458, 10.326268038442059, 13.189555118160865, 4.873523856362989, 10.351863465001507, 15.629468425627678, 15.283091760450795, 14.73842163239756, 10.310744277892574, 3.689686348361354, 1.663954983795843, 0.3905504593445409, 0.06688617905902286, 0.05746977486377282, 0.23780849251535632, 1.8639916950656523, 10.877585603344826, 27.00947826908481, 40.79588966984903, 26.74034091734117, 22.70552423692519, 18.877261530968454, 23.553738747873616, 28.737264679324245, 45.00882902453023, 47.62647374983757, 58.47285493727654, 38.73358588064871, 18.294222777889622, 4.068061464255856, 0.07442398627679195, 0.0287463576833327, 0.027544995837454355, 0.014243108603442389, 0.04805776801320815, 0.09005291537652094, 0.04661371525857718, 0.032449343256772525, 0.05260793574815316, 0.010324758477509022, 0.03739401562920502, 0.02990987861619121, 0.05813024990681199, 0.08354665320967475, 0.012259968394984402, 0.04040761017090371, 0.042144821791519085, 0.056459419804835514, 0.050305584896235704, 0.03366476856172085, 0.03296162625173888, 0.02204267657361925, 0.0006861968042005996, 0.061478126914270466, 0.027555251839540662, 0.03093956973433735, 0.01931435976838393, 0.007110978936731455, 0.032058898885283744, 0.04205109093398337, 0.03184588813793755, 0.028847559813349962, 0.029447084901133375, 0.02458542007051649, 0.07739178025193753, 0.042618068776303725, 0.026713418886966767, 0.0162098056922156, 0.016870966383947, 0.02407568623311818, 0.02356636608319898, 0.06072741054419068, 0.04674727885773586, 0.03168411909662668, 0.03326236172729442, 0.04066264850177592, 0.05444572705234732, 0.02654359060069246, 0.1118002363270329, 0.05895601991083353, 0.03780302997197836, 0.04380249816383566, 0.04666159575384471, 0.07004687397350227, 0.02992389610998573, 0.026821397064674287, 0.05202130775057501, 0.13608324701987928, 4.135989316048161, 21.460310951355968, 41.120873728106105, 58.259936917212706, 63.956940327921224, 54.17314883201353, 45.2112429372726, 43.92368178213797, 34.4641016375634, 27.492688778908025, 31.731433406952892, 48.87445034519319, 68.33150879029306, 40.63323290117326, 17.508876016063077, 8.113674223423004, 1.3058617086179796, 0.10660107337659407, 1.2448465439581102, 3.8164877506994435, 8.775348163420155, 11.49243183674351, 11.311136945601433, 14.85428942788032, 14.640373164607634, 14.695811944623149, 20.03104436782099, 19.505587970056844, 20.462901246163156, 24.018535690922892, 18.081318486121393, 11.739988307799063, 23.315760704778857, 29.28450199865526, 32.039412029327885, 41.1759045816237, 52.51242514579527, 59.69545379761727, 65.87617566508632, 66.70125407557335, 66.5498427421816, 63.81617430717715, 66.10288081630584, 68.41177617349933, 66.61752716187509, 70.12480074359526, 67.60471713158393, 67.57455410495882, 67.86481734245055, 69.93270658677625, 67.67543746579078, 68.65590449302428, 68.37571390213506, 70.16257316835465, 68.37510201238817, 61.48713757914882, 59.44529679513747, 43.006231554092906, 37.60913256675967, 49.56154761775848, 54.46281979160925, 49.73806212025304, 47.91681543473275, 59.057425375907656, 61.675128936767585, 63.097870657520915, 68.19551237167852, 66.65851593017578, 64.98449933144354, 59.96069231340962, 58.60405037480017, 64.16431603893157, 63.744763635819965, 66.64882767585017, 64.72160639301424, 59.41649875333233, 61.26236615642425, 61.336200852547925, 61.27705935508975, 60.75494481671242, 60.842841209903845, 51.408634877973995, 44.73919745414488, 37.735154398026005, 32.82918910826407, 20.983580197057417, 18.82734937052573, 15.322865574590622, 14.512660791797025, 18.167902846490186, 18.287978364575295, 14.578187907895735, 20.465903820530063, 20.55903265553136, 19.745244787585353, 14.679602749886053, 12.280527199468306, 6.798245608806611, 4.469788410971242, 3.0326221739092185, 0.37775069294917973, 0.20516661987189325, 0.1335019290807747, 2.325226635702195, 12.807307397165607, 29.152300473182436, 45.51414012908936, 39.67216591681204, 36.90502397475704, 30.616283955112582, 29.190553388287945, 37.99219123778805, 49.663086014409224, 56.659554973725356, 66.17663706502607, 47.83296692755915, 23.389818976002356, 5.449083139819484, 0.08532435257708834, 0.09782624866573081, 0.047761969974324595, 0.03387372287350797, 0.039279580176357305, 0.014771301329376237, 0.03447095735839779, 0.07100286743333263, 0.05156926607953445, 0.021426410549470497, 0.03573543144269817, 0.030202918738547354, 0.07869036823150613, 0.03925867746734331, 0.03696402962950449, 0.015815896688089255, 0.0710103061470774, 0.04866763911840897, 0.03807538572037893, 0.045483149513001406, 0.029267820326851744, 0.0267850500231068, 0.03199663508923785, 0.05430071809959989, 0.06346792538440035, 0.04120878109167661, 0.05429190808847066, 0.05197092980867432, 0.08412799903101499, 0.084039339675538, 0.10297043714672328, 0.1454621856851924, 0.2911059648519562, 0.17681601937980423, 0.18014994209572194, 0.18829083671012234, 0.07477391225796554, 0.09216376339956638, 0.09858903475105764, 0.10603508761813564, 0.0828809381252335, 0.20390835109977953, 0.1358322000070926, 0.2785140534322108, 0.12791991369017672, 0.20938926586701026, 0.12098413666770344, 0.19897926478616654, 0.24975584819912913, 0.11550721321855822, 0.17501373625090047, 0.2085261605679989, 0.23870728218988066, 0.21689266807609991, 0.13392214362900104, 0.19533098555139958, 0.2647921623241517, 0.2797668216930282, 7.482537896402421, 29.94664711336936, 55.71041983942832, 74.18527756967853, 73.838453754302, 65.26587447812481, 58.89493334677912, 52.40497965966502, 40.62526264498311, 37.221198389607096, 39.85116327962568, 61.84293969984978, 88.29377635832756, 47.27336237507482, 21.850586783501413, 11.452496224834073, 1.5289260422991169, 0.582244411831902, 0.9252011992277639, 3.3622804716710126, 10.876397125182613, 21.123263643633937, 17.692480202644102, 20.172836088365127, 26.11205174076942, 23.040780982663556, 44.55235927335678, 18.2548382589894, 28.514656443749708, 48.89275604678739, 27.687622731731786, 23.361646552239698, 26.421479678923085, 34.4649096458189, 37.40511440461682, 45.595470474612334, 57.7740611568574, 60.98551742492184, 67.62704326260474, 69.88847009597286, 67.39260319740542, 64.43016252210064, 68.20352969631072, 68.03744869847452, 67.24442389703566, 71.6030087009553, 67.08384206218105, 68.77372464826031, 69.87187062540363, 72.91984250468593, 68.79478777608564, 70.67989457038142, 71.18262475536716, 74.0118303606587, 69.72614672876173, 65.03220711984943, 62.43963418468353, 48.60698784551313, 42.61759527267949, 52.848615415634654, 59.11389181690832, 57.864008949648955, 55.066703980968846, 62.60094165802003, 63.65972665048415, 63.97945081034015, 70.72213849713727, 67.79880385245046, 66.12711321923041, 62.86289714997815, 59.5345542507787, 67.07653076417985, 66.1761506911247, 71.55401829750308, 64.85545727514452, 59.838761514233006, 62.636639148958274, 66.89976522999426, 61.461712775691865, 62.75293742456744, 65.75329957469818, 55.73125154741349, 47.143453474967714, 46.63534179810555, 37.63005056688863, 33.381570616076075, 32.687069869810536, 17.40684928432588, 17.47926604363226, 21.882081454800023, 18.94977831071423, 12.794542043439805, 22.823738590363536, 28.645028183537146, 28.26632530458512, 24.791124943763982, 18.544420965256233, 10.86927115917206, 7.226632660435093, 1.8520908562406417, 0.4281288799979995, 0.38325760874056053, 0.413193597548431, 2.619687789870847, 14.449401786250455, 33.42178275508265, 49.95159203006376, 37.81722607151155, 33.47818643816056, 30.309689929408414, 35.01185278738699, 41.99573093844999, 59.64021505848054, 64.27209100415631, 73.79729240171372, 58.35967886832453, 31.84973405253503, 8.515903968964855, 0.27421789363987986, 0.22999399732197487, 0.11105754472795995, 0.10149254628847684, 0.14674268632886872, 0.2366020878957164, 0.25838104827750114, 0.2724078423794239, 0.11383941682476191, 0.09694731599020381, 0.19379825811953316, 0.07441595767534549, 0.15816193164115952, 0.2278818929147336, 0.1537429679545664, 0.12355163438065399, 0.1455328649570865, 0.13903202669274423, 0.13466564728127373, 0.16309969007007538, 0.1128716026282599, 0.1177959468576216, 0.17288039588639814, 0.11226594883708224, 0.1649576065040404, 0.11707340337095723, 0.15441478109888493, 0.13079005443761427, 0.14758558222843757, 0.13741718995715343], [0.0432485667988658, 0.037904957970303875, 0.05679557918600979, 0.0820094288416928, 0.003685022966237739, 0.034342580174486485, 0.048970956310269334, 0.057592119105280414, 0.015866656716342176, 0.010351908633545523, 0.06599229234721392, 0.06641796144146113, 0.018910323081898595, 0.049784250572443976, 0.07614763814114756, 0.050319255735244484, 0.04733954909287634, 0.034378869759459654, 0.016700923593053897, 0.03191875076041587, 0.060044282281230536, 0.05125384086803083, 0.08761979714636842, 0.038548900835937074, 0.07557376167706906, 0.018668097571559975, 0.026616227227233114, 0.38692061218523216, 8.694296306179417, 23.16053486639454, 48.35636015861265, 51.204597103980284, 51.80460599160964, 47.58340612534554, 34.15294001179357, 24.18782714874514, 18.420336784855014, 20.32945829053079, 39.386946847361905, 60.15520265025478, 42.14304731738183, 25.490428632305516, 16.427799213317133, 2.2979244878215175, 0.05026503586240354, 0.060353433232634306, 1.0150220665720202, 4.086779014718148, 10.591927228435393, 6.591193493335478, 8.126627850917078, 11.04841168849699, 11.46811019989752, 9.749545281933202, 12.566068883865112, 17.399410509294082, 14.833452816932434, 13.76108563715412, 27.310112253312145, 23.52391500626841, 37.22838417176278, 43.77977002051569, 46.14719498542048, 55.03417968750001, 63.08690763288929, 67.8761294580275, 64.77713146517354, 64.20582256009503, 64.63216066360474, 64.34449011279692, 65.53862041042697, 67.16166973114014, 65.909743309021, 66.72498441511586, 65.39420266305247, 67.13018878813713, 66.72830274028163, 65.07217214953515, 60.56083848399501, 60.67916462498327, 62.81142780857702, 67.5767820112167, 68.70319258782172, 58.156692289537006, 53.33531095135597, 46.11470207091301, 34.4122596709959, 31.76626209289797, 60.31156793717415, 44.12339710420178, 40.142450255732385, 53.113077302132886, 55.60208005289878, 59.660572159674864, 65.91923544483801, 65.10091920052805, 64.8511112889936, 58.78493439766669, 51.80841853541713, 54.03629733670143, 61.522344773815526, 65.17217689944853, 68.62635335614605, 60.58009732154108, 55.91771710303522, 58.962472638776234, 62.34556398084087, 59.22678547520792, 60.78874388048726, 59.56746293652443, 58.899593122543834, 57.701646358736106, 48.54621856443344, 32.95613858007616, 23.75202632719471, 24.807561635971073, 18.580997067113078, 16.804004523061938, 22.83632939861667, 17.426859255759947, 22.792667535043535, 16.447571881355778, 14.37824312717684, 12.115667039348233, 7.704818123771299, 7.184618192334329, 4.887742448237635, 3.62628907926621, 0.08429273091737302, 0.15420966871803807, 0.09065160542846688, 0.5259723120158719, 3.69489059813561, 15.713313010431106, 24.036961024807347, 37.53262281417847, 35.79226716872185, 29.313464780007642, 26.371312564419163, 22.586807820104784, 31.64415086469343, 39.70179550109371, 54.27891946608021, 52.64921780555479, 31.902136918037172, 13.233282681434387, 0.2048580090124761, 0.03977333533487493, 0.07070059212104929, 0.021584747516880595, 0.05827911611225817, 0.03733066781874626, 0.03229298088098726, 0.09310366901298685, 0.054120787028824134, 0.007771609112575291, 0.05091769297817542, 0.01842803051394801, 0.05453396888990557, 0.03245904576033354, 0.045844697047986334, 0.0519972525897526, 0.0485885213880289, 0.009093084447686712, 0.057165346844422246, 0.0296941616632525, 0.022476257440904458, 0.013015326300275423, 0.08275844066614106, 0.021460616375289617, 0.055625058124743165, 0.028636355118285266, 0.04657795427427177, 0.005672276348641684, 0.03773891990403495, 0.10854581821589701, 0.004220475093461573, 0.05386437357012784, 0.018288156265513073, 0.10713907394317851, 0.011068831907675393, 0.13898056090599106, 0.05670580134216336, 0.07880594025576308, 0.02115432484706323, 0.06776600039654201, 0.07016085253487672, 0.03559133796502025, 0.03934971552582518, 0.03579620902817096, 0.043236347696473526, 0.04866891848524252, 0.05969113106989573, 0.055256255737115303, 0.026741840748957572, 0.023803734596097664, 0.026097593363374475, 0.0660397514941231, 0.07269396822178557, 0.031682025761373585, 0.051814862376739906, 0.019764959278907028, 0.0248320467559801, 0.5177392570241806, 9.950962912651802, 28.875665510854414, 56.46975148108698, 63.53157104984407, 60.25712543918241, 55.653659220664736, 43.886536936606134, 32.476469970518544, 25.614342189604237, 27.35861236049283, 33.8600762428776, 54.669599302353404, 50.663333554421705, 25.998216713628462, 12.847792140899166, 2.9621447815049082, 0.02878738552211754, 0.37666054983292857, 3.916401060358171, 7.669063758465552, 10.333145914539214, 13.505488307245317, 15.006727441664665, 14.156202654684744, 12.706143586866318, 16.355506008671178, 15.333694258043844, 22.876319923708518, 19.583523504195675, 16.29177631870393, 18.37035402174919, 23.619442370630082, 33.4760840477482, 36.34066550962387, 44.2541689257468, 54.7205626580023, 64.35155822384742, 68.67184500540458, 66.73661816504695, 66.75088774773383, 66.11307897875386, 65.42820961244645, 64.26670166753954, 64.47870969772339, 66.43420342476138, 66.65146350860596, 67.43658081177743, 68.84825752627465, 68.90583007566391, 67.65720628922986, 63.19385105563749, 62.88146957274407, 65.74712576404696, 69.32791632990684, 68.7168816597231, 60.99936339163012, 57.37613670287594, 53.473331312979425, 41.307339283727835, 40.47518099507978, 64.41858760772213, 50.335847023994695, 50.51319306896579, 58.28658550016342, 58.83141056183846, 60.81636128887054, 68.17322546435942, 67.19955982700472, 66.82359280124788, 60.73129292457335, 55.278398221538914, 57.033078362864835, 62.44035197842506, 66.12583452655424, 71.08127071011451, 62.17835726276521, 59.24828790849256, 60.42886641717727, 62.511464549649155, 61.71206197431011, 61.13378693980556, 63.18333518120551, 60.24983375303207, 54.128626008187574, 46.839697284083215, 33.4622694600013, 24.331507490527247, 20.822096217063166, 12.118364649434245, 12.74572422427516, 16.046172207401646, 14.485717050490843, 20.56348454567694, 22.58308941318143, 17.08259282573577, 15.200565092025267, 11.517473228516119, 9.585324468151216, 7.722542333987452, 4.9973687721836955, 1.029934488957928, 0.2851477006991064, 0.21144141623329735, 0.5790966484815844, 3.9991880761038874, 15.457552902160154, 26.215774897606146, 36.0789571269866, 36.823246479034424, 28.077778931586977, 26.929530559047578, 27.428926729386855, 38.268620275682025, 46.524978068567094, 62.00374903217439, 60.43051773501981, 37.130811291356245, 15.380696019818707, 0.49786871359232937, 0.08229136451958649, 0.03129731172755842, 0.03436842798105171, 0.04652858756843113, 0.05717519490468887, 0.0097791382089077, 0.08122854775959447, 0.05308282982197501, 0.018470898878970937, 0.05406171781942249, 0.039618639200324976, 0.04996891606659178, 0.12895613187743774, 0.034415170835751685, 0.05616341109177279, 0.032090651314525355, 0.02280391707655884, 0.0219594277141075, 0.035976829578078566, 0.03894954949857728, 0.01824912600099079, 0.0864037474797618, 0.04632586921234766, 0.02107276329620471, 0.04841419041997964, 0.05220731772902993, 0.04302475421178726, 0.07188052074202607, 0.02771746712706743, 0.12033367439383462, 0.1812569697898242, 0.1026022782729518, 0.16073361219417664, 0.07568473717378033, 0.27285621831974677, 0.22227920081105926, 0.16676316848926007, 0.11249558369238531, 0.14549240019292603, 0.24383438691016168, 0.15187875427786382, 0.10380227839754474, 0.17400761765818443, 0.13951236382126808, 0.12292216291591046, 0.2134789802855061, 0.12184318936159536, 0.11290588506287146, 0.14533761978870438, 0.17260676460160365, 0.1888928898880559, 0.23695583665563216, 0.17238934884869284, 0.20592877010424293, 0.1430300557084622, 0.1653064063359653, 0.9567218562287669, 12.85872280597687, 38.48837890932637, 69.97600170873827, 74.66409698609384, 71.6806951645882, 67.35004548103579, 49.952384348838564, 38.134608576374674, 29.6395980927252, 34.88923557343022, 54.307960694836034, 76.21140926114975, 55.7958294499305, 33.88701115885089, 20.236874664983443, 3.1934214551602644, 0.2666452983694692, 0.3053362012630509, 4.0353040349098945, 8.97044881697624, 18.054852293383693, 18.889046292151175, 19.80601602985013, 24.921102485349103, 21.131192714937274, 21.06554988891848, 19.21764285333695, 26.22166825879005, 25.338246553174912, 20.55596536205661, 30.918416284745742, 30.20036562796562, 43.35248270342427, 47.86936652275824, 49.72658918749902, 59.999802266397786, 66.1852035214824, 71.44368202455583, 66.74597694027808, 65.71745695606356, 65.91801951008459, 64.63092511700046, 65.9360388786562, 65.31953642445227, 67.93298029130506, 68.32232259934949, 67.61275799043717, 70.10581647196125, 71.64560564102666, 69.97156943044355, 65.95201076999788, 63.823971979079715, 68.87627109404534, 71.59019823997252, 70.23625096967145, 63.104413170968336, 61.734819566049886, 58.10317939327609, 49.91395296589021, 45.77115735700054, 66.52360208572881, 57.95514914297289, 55.20020969452397, 62.50473768480363, 59.138277192269605, 62.04472995573475, 70.42873736350768, 69.59228407952094, 69.49380120923443, 62.71373333469514, 57.93664732287007, 58.778203610450994, 67.07150228561895, 71.75027801144508, 75.46311516915598, 62.851522276478434, 57.62714093731296, 62.4964810955909, 62.45471177562591, 62.234753101102775, 62.75459266478016, 64.47525016723141, 62.94745952852311, 62.60118876734088, 51.68709178124705, 37.510053496206964, 27.272133904118693, 30.425137050690193, 30.014786528002833, 27.315338811566754, 34.853412566646455, 23.786751070330222, 29.692169620144753, 27.563958244939005, 23.54908093329399, 26.38496437380391, 18.241798339351533, 14.574347907497039, 9.971385713546507, 8.01426322229447, 1.2572331438141486, 0.4892892029977614, 0.35277463315475377, 0.9334050815912985, 4.988976370903754, 18.534309094952, 31.830977278371012, 46.78586667583835, 50.419338595482614, 40.870175438542525, 37.91323392621933, 34.72690828384892, 44.16043604573896, 56.146626626291585, 70.21099090576172, 69.53409179564446, 45.55568587395453, 19.873184657865956, 0.8833207658702328, 0.1720560393145969, 0.15621851979484483, 0.1476179111388422, 0.1265251969978694, 0.14452144503593445, 0.08297640034147809, 0.16568560453672565, 0.1538620180179996, 0.18174775635763524, 0.21932315862467214, 0.09433629682227489, 0.1556171867395601, 0.2429332070413136, 0.1473822931368505, 0.1388520266740553, 0.17341858797496365, 0.06463124521917875, 0.15706408168039016, 0.12231843200542274, 0.06988900623494579, 0.14649827363750628, 0.16646292330997606, 0.10571528421414476, 0.1252511774580325, 0.1290480317848344, 0.1388628898008216, 0.10901495513896789, 0.32881771544775656, 0.18429046346535607], [0.051210901639874906, 0.03835473968196781, 0.07371346270965953, 0.1036236573371195, 0.07326944580962581, 0.03733167905480631, 0.08000445416978291, 0.012220464113558973, 0.04161144456555767, 0.0573796944151963, 0.012146810505298838, 0.04982169311974318, 0.07016531116659604, 0.041696955299665855, 0.013107624573392734, 0.07699375160999837, 0.04429396271945969, 0.05336651601077569, 0.08199472761442585, 0.03229916704097583, 0.019683721400196516, 0.020048714415620894, 0.0038663928458962833, 0.056768754617341106, 0.042302099642373865, 0.010121893607110027, 0.07063172847753571, 1.0790446472744788, 9.373370370557232, 37.778457364728375, 51.09623770559988, 48.19400541244015, 49.126333190548806, 39.321341283859745, 29.780234675253595, 27.11985964928904, 22.354389736729285, 29.89305380851992, 51.445563993146344, 49.52401053520941, 43.720824641566125, 26.013406092120757, 4.768718125358705, 0.6053278667311515, 0.056657710172716653, 0.41484148331707527, 3.2368582727447635, 7.93372372465749, 7.131514693460158, 9.95993043145826, 14.343329129680512, 13.681755700419027, 13.131629555456101, 20.280152136279693, 19.10562780595595, 37.82329790053829, 27.92648723048549, 25.415556469271262, 32.868295138882054, 30.19815537237352, 44.297601330664854, 45.33225982419906, 55.43129613322597, 62.76817583268689, 65.25362491607666, 64.21097263213127, 65.89398322566863, 64.71655830260246, 62.73428655439808, 61.3118350890375, 63.438634410981216, 65.1498233118365, 66.01061882511263, 67.14192451969271, 64.4863308629682, 62.95504539243637, 63.24289637227213, 61.22320129025368, 58.217614543053415, 56.91658396874705, 61.238059228466405, 65.61796995901292, 70.10616948527675, 65.2267998264682, 58.13211864040744, 54.10746482110793, 41.891011499589496, 26.485531983837006, 43.49049522030739, 36.05557195601925, 41.89828749625914, 53.24127212647469, 58.60843558465281, 61.348336665861076, 65.79078174406483, 68.79824730657762, 64.73926882590017, 57.77321000253001, 54.00695016307216, 50.00271620288972, 57.04542206179712, 61.553970844514915, 60.30768871307374, 62.91161690988849, 63.57964754104615, 60.46690948547856, 61.57323360443116, 60.57537086548344, 59.756340749802135, 60.09118172430224, 69.39698926864132, 60.23648200496551, 60.85963287661153, 46.32856930455854, 45.91836783193773, 43.97317424897225, 23.248513629359586, 20.301044641002534, 16.302993316804212, 19.797475068799912, 22.950256601456676, 19.99348375105089, 18.46381429703005, 11.437099941315191, 11.283420497371305, 8.127732488416857, 6.096025638041958, 6.543582293295092, 1.5413419373573796, 0.2064831879350447, 0.10161109839475925, 0.10443632340719623, 0.8603389861602938, 7.385633780110267, 24.484003359271636, 44.6081236100966, 50.64629870076334, 45.93344934525029, 22.32790393214072, 28.45925492625083, 32.87217240179739, 42.78037755720077, 53.84662328227874, 55.875583002644206, 42.402559172722604, 15.797268402191902, 1.401906948416464, 0.01832303433348575, 0.0075656363192284784, 0.032562735760884906, 0.0472966788126336, 0.06411299056884262, 0.024403751895372427, 0.06805909031461324, 0.06006930654327716, 0.03666337842362062, 0.09747246926229808, 0.03098427479515874, 0.12492378212271199, 0.061488790858176455, 0.07194196099355336, 0.047550184967657255, 0.029638038061919714, 0.011317440845643081, 0.009964141739352096, 0.03351826190708145, 0.013514057199861254, 0.059184444347216245, 0.011673864210024478, 0.04222523421049119, 0.028252774894598032, 0.0116558458220454, 0.02584421169763852, 0.022817266158639424, 0.06652252478224617, 0.036877618742085276, 0.007399753864569169, 0.017837790411806876, 0.026670152156223214, 0.11579592877458181, 0.04130940291009123, 0.04431186619425013, 0.0397006489126192, 0.013775919458918996, 0.01316685657647829, 0.04604576831503261, 0.0462195668519745, 0.06229597173871533, 0.007588751107123831, 0.014718901872965357, 0.008487853920087218, 0.030374260048472115, 0.05083084542063936, 0.12243319197647995, 0.03651177728428476, 0.18551153100786671, 0.023853484345900438, 0.07622060035505603, 0.04250846840741654, 0.056389410859875144, 0.04841208367818787, 0.013652577387890028, 0.09086425611448866, 1.5168642637229737, 11.741196397812137, 44.10374995200865, 63.522855543321185, 60.322366222258545, 59.36897923869472, 49.20926386310209, 33.90596405152352, 32.341173694979766, 20.620519730352587, 27.82876726119749, 45.927357904372684, 55.9410552055605, 45.118835818383005, 24.654559781474454, 5.747869197399386, 0.7002372739295806, 0.36028915896050395, 1.1958273355999303, 5.9303417801857, 11.252818165286895, 13.816310647995243, 12.838441210408366, 14.81212983208318, 15.837673717929473, 8.904845214659169, 12.756113602269082, 11.862168177481621, 13.772475219541981, 9.792926696039016, 22.200597524642948, 26.609119984411425, 28.226950591610326, 40.3784788808515, 43.918006112498624, 58.57909233339372, 62.50509069811914, 66.16160654252576, 66.04147218888806, 66.35234355926514, 64.45315153368058, 64.56584122873122, 62.2415780252026, 63.90617309078094, 65.59707941547518, 68.77861192149501, 68.0912636172387, 66.81802303560319, 65.23123602713308, 66.04495525360107, 63.6122424371781, 60.638317062008774, 60.39473395193777, 64.15220768220964, 66.75988566490912, 70.1680644865959, 65.92613881634128, 63.36261103230139, 59.23569710023942, 48.883601234805205, 33.99975184471377, 53.44432146318498, 43.21895345564812, 49.99055293298537, 59.30847275641657, 60.31861643637381, 62.80697591843144, 68.67590858090308, 69.51259720710017, 68.2360226108182, 61.595598959153705, 56.923593244244984, 53.02633408577212, 59.10362305179719, 64.48771545963903, 63.49088430404664, 64.65926031912527, 63.37396629395024, 59.01703673024332, 60.252049892179436, 60.42276320918914, 62.33075703344038, 61.26819087613014, 69.4034533346853, 63.360049724578865, 59.49476180538055, 46.69157681926605, 39.426154859604374, 32.605845428282215, 19.93420300945159, 11.56567523556371, 12.059128034499384, 13.145991313842035, 21.59297335532404, 17.246071330962643, 14.973008786478351, 15.775247235451976, 16.968983334879724, 12.550391170286364, 7.555435146054915, 7.327528278673849, 3.7985919367882515, 1.358880631385311, 0.16010275411029018, 0.1343271130275342, 1.2244792691161557, 7.830608535197474, 25.05441600276578, 43.691944229987364, 49.15584510372531, 40.505963756192116, 21.93731038801132, 28.70802340968963, 39.18388966591128, 48.26183495983001, 62.08566381085304, 62.80162972788658, 50.90193133200369, 20.7183083411186, 1.9936865808502322, 0.08181434455177478, 0.03653339245506833, 0.06318287172865483, 0.06211474214890792, 0.0746783504502908, 0.05360989448344035, 0.0710746115674415, 0.009485677695803104, 0.004314580376470281, 0.05538816841679716, 0.023672417549776937, 0.05638710110478344, 0.026617954755502365, 0.012819630097627882, 0.02256571927348212, 0.10292143050220706, 0.023185137749439286, 0.00958835167224489, 0.058156101543816834, 0.026808524872326565, 0.054308030408837145, 0.04745241682676058, 0.060307797374984914, 0.033014049648397395, 0.04626478136126553, 0.0598451147426761, 0.05304569370984551, 0.06028349706602674, 0.014555580545997909, 0.12249954285160189, 0.1120938242022549, 0.15517369844019413, 0.2453262665339055, 0.2783227459557595, 0.21854643740000265, 0.1248908709854849, 0.16640482320179864, 0.08899667931179847, 0.1932414654161661, 0.1372879662460858, 0.1156123204817695, 0.24242135305558485, 0.1176799534850063, 0.11992636842713242, 0.14868514822615733, 0.16623505811777808, 0.31074901081381306, 0.1909381761065414, 0.3574812628569142, 0.16214094635459686, 0.17799697455859956, 0.21452438386697925, 0.1246746886341322, 0.19689765067831164, 0.11040056304585551, 0.2158811868679139, 1.8897774791525257, 15.23149984498178, 53.999191714871316, 72.36659219188076, 69.34065618822652, 66.48270745431223, 56.45332067243515, 44.24115057914488, 41.591307117092995, 34.799515278108665, 43.50808312816005, 68.9036492378481, 64.62034648464572, 55.52976723640196, 31.500446988690285, 6.937165664088342, 1.1519563606669827, 0.5960182437012272, 1.6971322293243103, 9.137698681123796, 16.4181766586919, 18.791073329987068, 24.505605812995668, 26.845448670848725, 25.500209062330185, 25.55677160140007, 33.79514532704508, 30.447625960073164, 49.37454469742314, 35.30352023340041, 31.519186112188528, 38.33049174278013, 33.20158873834918, 48.31881915369342, 47.92121241169591, 58.40548822956701, 66.21048711961316, 67.50379454705023, 67.84296974059075, 67.91818511101508, 67.09636226777108, 63.52145917953984, 62.51335905444238, 63.78730958507907, 68.9406842570151, 71.37478167010893, 73.03232039174726, 69.45889995944115, 67.71073095260128, 68.62296442831718, 67.9899174167264, 62.65209720980737, 62.26260977406656, 66.83986279272264, 69.90896840249339, 73.47504615783691, 67.72747947323707, 65.5147567102986, 61.609080145435954, 56.95530560708816, 42.01298152246783, 55.99936123817198, 46.61693803725704, 55.58219363612514, 61.956994379720385, 62.07066074494393, 64.24449712999406, 69.96687827571746, 71.87329922952961, 70.50306627827307, 62.44019508361817, 59.10879665805448, 54.17498842362435, 62.71647899381576, 68.11141675518405, 64.92146292040425, 67.53304758379537, 65.34329422058599, 59.620760102425855, 61.20155372927266, 59.52354808007518, 63.35575865161035, 60.77341133548368, 75.00413510107225, 66.06199402962962, 69.58831464090656, 50.96846649723669, 49.62445459058208, 47.19544449160176, 30.737589136246715, 30.897684597199966, 23.739898358621907, 26.26042715964779, 37.5387534787578, 32.55481735352547, 30.166835246547578, 26.83889635147587, 22.9753166244876, 17.890805044481834, 16.5207132985515, 11.772818546141348, 3.77846674573037, 1.459443951326032, 0.22274141229929464, 0.3782052282364138, 1.3347920078423716, 9.606136564285526, 29.637430983204997, 56.54053065084643, 64.52590757800688, 58.46185268894319, 32.38140544583721, 40.08580730807397, 46.11442750500095, 57.42334635026994, 68.78717053321101, 71.61612510681152, 61.61583054450251, 25.481185566994455, 3.0450889372056533, 0.16872985408671443, 0.09807233908964742, 0.26128740200111944, 0.14291246121208515, 0.15431224789109924, 0.13105207182947667, 0.1913518329421359, 0.0921842409297824, 0.11306971296547882, 0.21050147231548064, 0.1528988769578357, 0.13371729171804844, 0.13638608157634735, 0.10496452570922914, 0.17702171398747354, 0.24204429990101248, 0.10261674967384148, 0.11379724368453027, 0.1677360541878208, 0.13033386440046374, 0.11241861483863286, 0.1328901772297198, 0.13440828770399094, 0.2272795639451473, 0.12379705830807648, 0.1470689325323028, 0.1811649626301181, 0.2813466482104794, 0.10122442317585792], [0.05454091730737879, 0.015626188420179873, 0.07405100870997676, 0.01097142382810313, 0.03260498167946935, 0.014325126934225762, 0.0788811854116859, 0.049297711962173064, 0.0637609846589546, 0.06330318583716309, 0.0620087155801875, 0.01550344868578137, 0.029951306735916488, 0.058571033915805246, 0.03573027567096776, 0.07702526080632403, 0.0601498147232398, 0.05251361500291575, 0.0790867880888043, 0.06436386521184637, 0.09563426427062481, 0.1162874048215247, 0.021855318280417594, 0.013291197434638538, 0.04049950624786077, 0.015937581136372062, 0.1102894190098009, 2.595411995726247, 25.6247050915995, 40.65780262793265, 45.6596443730016, 47.69019265328684, 40.13751591405561, 40.877255316703554, 32.07637840701688, 21.02344128393358, 30.000073717486476, 38.35201378791563, 36.84772599127985, 33.99497832021406, 20.045202162957963, 12.911996437657265, 1.0618301000325912, 0.35813436813412175, 0.1483750358344086, 0.7523528258166006, 5.269813172278866, 10.508282684510755, 10.44514331125444, 12.43478911538278, 12.39880431082941, 10.543544792359876, 4.919855383134657, 12.875750795487436, 14.216034489293254, 17.281776666641235, 21.079166396971672, 33.259161287738436, 33.543058518440496, 42.91831554905061, 55.034058094024665, 56.089363944145944, 63.79678995378556, 64.19401622587635, 66.11557360618346, 66.5973191107473, 65.70568200080626, 64.1161964016576, 65.5794209049594, 62.59423832739554, 65.5901054413088, 64.56148739783995, 62.94056007939001, 62.54899770982804, 62.575057937252915, 61.612924068204826, 59.03978647724275, 59.03592294262302, 55.3858672418902, 57.53143118273828, 58.27631281268213, 65.07594154727074, 67.50515168712985, 63.988762517129224, 58.31762321533696, 57.58391641801404, 48.90818272867511, 30.07125493018858, 39.10976471439485, 27.515007065188502, 48.69020485108899, 52.92785121548561, 59.11992049986317, 54.80786677329771, 63.71840138589183, 67.27468890528526, 67.21935995163457, 62.94821654596637, 57.91221487906672, 51.00131242505966, 49.957640324869466, 54.478548496000236, 62.77846813201905, 61.40039044041788, 62.280107467405266, 57.859070685602006, 56.466444923031716, 61.552346983263575, 59.20178428772957, 60.269559352628654, 62.84836869085989, 63.63296824116861, 63.798300066301906, 59.04465021625642, 54.59157943725587, 46.742783361865634, 31.781231818660615, 17.17590601213517, 12.599830685123322, 17.647298420629195, 18.321577387471354, 21.819845207275886, 13.164964798958072, 13.085901583394698, 11.56011135347428, 11.613579142478205, 7.400502504840975, 6.35620576720084, 2.0559880377784854, 1.545938097180859, 0.4062629226715334, 0.14118335480170865, 0.2295315560073622, 1.5885729126391874, 7.83088113992445, 23.94300456969969, 31.824711292020737, 29.231106773499523, 29.9396849063135, 23.80945767125776, 22.31116129506019, 37.30988710157333, 48.77293548276348, 58.84595863280758, 44.87304833627517, 23.728990247172696, 2.8629262216629523, 0.05910275256141059, 0.05929686391966478, 0.029398139543651097, 0.035769300189830606, 0.013105233421459073, 0.07027965745017414, 0.04367342383991327, 0.026019990571864673, 0.020929621682772716, 0.03788513544526312, 0.045640143911324205, 0.07877819255114564, 0.05500111398437331, 0.011758602152939045, 0.047976547371475935, 0.03201859499958735, 0.017878002366952358, 0.02431042897965639, 0.05093329818919302, 0.007513233989987884, 0.03446348034025681, 0.07166349569395666, 0.034249837570373094, 0.11594074237490855, 0.018628305049553033, 0.04408124308552473, 0.06313615568703221, 0.01227117530370672, 0.05298841331574706, 0.029148138240881027, 0.06187211061196943, 0.029183077595887646, 0.10170936449280671, 0.11047858910094346, 0.018887924586212444, 0.055545676094029224, 0.06144451480659266, 0.06818980023625397, 0.05664596221439781, 0.04226485244749535, 0.01839677412663737, 0.025926196512075204, 0.06540815030495006, 0.08968082647169791, 0.026857311266564557, 0.054029890696608254, 0.08077090981626704, 0.06557991487845298, 0.0698588300316084, 0.031504354649974455, 0.09971389697203714, 0.22632913994452647, 0.033040977638935855, 0.06917895764232644, 0.04865055152725789, 0.07158681795361542, 2.977464333657296, 27.525364083628503, 50.28258123705464, 58.317078005883005, 56.11987213934622, 47.934877949376265, 46.5877712926557, 36.81431524215206, 27.799569137634773, 35.69018748498733, 34.97166026023127, 42.33459234237671, 36.382870212677986, 26.197963414653657, 13.843958454747355, 1.9332147870332965, 0.23781771621396466, 0.1630216410323497, 1.67309986727853, 5.519394076639607, 13.022511178447356, 11.962888759951438, 14.825000109211093, 20.842812215128255, 15.012519801816634, 10.01746669892342, 7.258569088674362, 14.495584753251846, 9.945180358425265, 16.512025248619818, 27.804978086102395, 31.0849150150053, 39.46399396465671, 49.1819877009238, 55.74177526658582, 63.069472697473344, 65.42813116504301, 66.70712978609147, 66.78957016237321, 65.33492388263826, 65.92634277959024, 65.52725730403778, 64.16234308673491, 66.47842422608407, 65.0095279755131, 63.885317848574736, 65.2846626312502, 65.54288402680429, 62.94471386940249, 62.222236817882916, 60.37711074275356, 57.423958240016816, 59.49324384812386, 60.379985840089866, 66.77142527795607, 67.55435389857139, 65.26075186267977, 61.46772576916603, 61.78284506643973, 54.81149888807728, 36.4251612078759, 44.08071779435681, 35.91210734459662, 53.9895740632088, 59.318941562406486, 59.34473114628946, 57.87748229119086, 65.39362215226697, 70.47111465084937, 66.8717045937815, 64.78801604240172, 58.4207776284987, 53.43856342377202, 52.32604588231733, 58.41586682104296, 63.84318374818372, 65.3641063167203, 63.13024982329338, 59.027650663929606, 56.90584844158542, 61.20260884684902, 58.00131936227122, 63.13019491011097, 64.76199503867858, 66.05282352816674, 64.55766308692195, 60.887093390187914, 51.46090438289028, 41.69402222479544, 28.48716651239703, 21.042482429935088, 12.185836280545882, 14.842689018095694, 8.047046882490958, 14.608931445306348, 15.029001601280706, 13.96457035695353, 15.726717710494997, 12.777013951732268, 9.452951338983352, 8.436642673707778, 6.600522850790332, 1.4040147320878122, 1.2117294822969746, 0.125500324572767, 0.06186526178592636, 2.1894155490782956, 8.729918291491847, 24.945556502188406, 36.33283645875993, 35.419347824588904, 28.19110405060553, 27.399120638447425, 29.620413780212406, 45.119887013589185, 52.77509450912476, 63.93746576001568, 51.89359280370897, 28.34056792720672, 3.336370274905236, 0.17032025261752068, 0.10661085631938712, 0.051195572220510056, 0.012735268495406115, 0.056306692516250964, 0.013570647157217949, 0.06018804634110101, 0.0225101625772133, 0.04250290660908626, 0.06754254020990864, 0.11330491727999142, 0.06972022940434756, 0.044900911199229385, 0.03757681952969682, 0.03472716397335453, 0.039403862620313326, 0.006998372630351374, 0.03055074563880842, 0.03584566000368326, 0.07485461195990925, 0.04748677587016456, 0.022540932498692025, 0.042545884141638395, 0.06828377624192546, 0.05152604339884655, 0.03017671278587753, 0.04595147055243293, 0.046024459579418746, 0.037980524883154905, 0.21530643706360172, 0.10976503948651015, 0.14781810523521516, 0.2832063726119457, 0.16144124760983453, 0.16000852529560367, 0.1580210021066089, 0.22720513084242422, 0.18402627038378871, 0.18186901275429035, 0.1076806061750939, 0.11165592834473619, 0.13998277245029328, 0.12810975793869267, 0.28668594396402763, 0.1290889255582325, 0.13778383963771407, 0.35699568568698825, 0.1973955618638185, 0.24760153234726, 0.25105381564747903, 0.236273528106751, 0.2576012014141006, 0.1134194014593959, 0.16572884253917203, 0.13452716922808078, 0.2563969111971317, 4.643155701698796, 34.382818360482496, 60.04033211738833, 70.09106836011334, 67.51236884824692, 57.688828053012976, 56.26315632174092, 47.81042898854902, 30.57409690272424, 44.599176683733546, 53.66409970868019, 49.01658919549758, 45.50313003601567, 26.63651970125014, 16.00951667754881, 1.8116295241540479, 0.6191038436466648, 0.20560655352329055, 3.042482767374285, 9.907960987860157, 23.087769016142815, 26.509105428572624, 21.554653759925596, 25.859972776905185, 21.0093266348685, 13.699574047519317, 21.146929264068604, 24.21856088023032, 27.112081589237338, 27.949776303383615, 38.864494985149754, 37.94417750450873, 47.07572590920233, 58.80724091683665, 58.45864026777206, 67.48304520883869, 66.74196043322164, 69.22279680928877, 67.49006625144713, 67.24843255935177, 64.98800985274777, 68.57387204324046, 65.05725145339966, 69.12036018986856, 68.5580256677443, 68.5632973332559, 68.74818217369818, 67.66644739335584, 65.37843473495977, 64.6807078392275, 64.20670901575397, 60.14433768487746, 61.59457129816855, 63.871095334329915, 69.27567035921159, 70.07910513108777, 67.0104858952184, 64.85271946076425, 62.85468762920749, 59.3596871437565, 42.92992968713084, 52.07315498782743, 40.67448839064568, 60.18780539112707, 61.967847577987186, 61.98118363657306, 58.12097910911807, 66.31326106286818, 71.00218788270028, 69.4271287610454, 67.13921808427381, 61.146205163771114, 55.03390512158794, 55.19315335058398, 60.174485022021884, 67.10607405631774, 67.42055400725334, 66.50914422927364, 59.791877423563314, 56.76739269687284, 62.57153564883817, 59.99484046812981, 64.02616231672226, 66.07179211032006, 67.91610625482375, 68.24562457300001, 63.915786820073286, 59.27927071048368, 50.503861750325854, 34.95040101389731, 22.52699951971731, 19.388471880266746, 26.264069080352787, 26.866878540285175, 31.739944950226818, 21.585701281024566, 24.531756254934496, 20.826718730311242, 25.532884367050666, 18.801312677321896, 16.468308471864272, 7.4924198177553, 1.9979847631146832, 1.3658276392567543, 0.4861121444452194, 0.34746631799686345, 2.364018141261993, 11.096613695544582, 29.62862526216815, 44.56953140997118, 45.4605919314969, 42.80397061378726, 35.25806388547344, 33.96285018613262, 51.79533350852228, 62.30328083038331, 73.55396424570392, 61.17242620837305, 38.252970018694484, 5.5786135312049625, 0.3493519361701704, 0.21628539017852277, 0.2390019655708344, 0.11821308939327156, 0.11489810437084207, 0.14276226201365072, 0.12347812058344004, 0.11428110481750582, 0.11571529802055129, 0.09727049784194078, 0.20710787135026149, 0.3149354668153871, 0.09167522146937349, 0.1511619104853561, 0.12340525796096172, 0.12870404298507399, 0.14277882483457366, 0.1388413780519078, 0.12417237244306073, 0.18728830340889194, 0.11149628328219538, 0.16286561956569073, 0.16003670200945871, 0.2254868109500216, 0.13576460040865407, 0.09472471872164358, 0.11347460575521955, 0.19669178753129898, 0.22715505933569324], [0.08055911714872045, 0.028447730864788738, 0.04207317341840075, 0.09231153409928085, 0.050458423267569275, 0.01860169307028334, 0.09214042070051355, 0.05998189591111676, 0.05548845315652509, 0.011210390591933843, 0.04517900877662244, 0.034016770641169244, 0.019989288975334456, 0.06181971402838827, 0.10215738037180516, 0.0969629748273761, 0.04928366574008138, 0.03087638663278232, 0.042978137761594794, 0.14647939723105202, 0.047747467929917964, 0.0009843145932292476, 0.07513797256134211, 0.03809770186161322, 0.030985626940345092, 0.014440443276637986, 0.0813822556407221, 7.0078207888910855, 30.517202923374793, 45.30150844204811, 56.25212661681637, 48.21337799872122, 36.35000075063398, 30.453446757408884, 41.518939387413766, 28.457568307076734, 20.498618348952263, 43.441583264258604, 37.27573502448298, 35.197122020106164, 23.77021828005391, 5.264289004187431, 0.5020669367044203, 0.13753418690494953, 0.41639238235450565, 1.9988279501276633, 3.18813655164934, 8.20698005537833, 10.594917055099241, 12.271918577532615, 16.516998813998317, 14.129177524197488, 5.976779210952021, 4.131983105213412, 11.366059933939288, 7.7613733083971095, 16.0308131863994, 39.98386098492531, 44.007393006355535, 46.77101658236596, 54.68683027452039, 59.09174219254525, 64.3775047025373, 65.01432111186367, 64.16172727461785, 62.41879070958784, 64.53523497427663, 62.905666674337084, 60.827614568894916, 62.470993534211196, 62.95249192945419, 59.06554860453452, 60.88588137780467, 58.63162463711154, 58.65376641673427, 56.83461819925616, 54.89706147101618, 52.35765234116585, 55.07836910986132, 57.525273061567745, 59.459256510580744, 65.72001041904574, 64.27204001334407, 66.46781813713812, 62.87447598672683, 60.85189404026155, 58.63519007159818, 35.50470252190867, 46.93703089990924, 31.03731901414933, 47.024005536110174, 56.515333344859464, 54.339986847293, 59.001425696957504, 60.273693530790275, 63.852836701177786, 65.34771080940001, 65.48330714625698, 62.338303673651914, 54.894449172481416, 50.868591185539, 49.19855187016149, 54.08436598316316, 58.65268384256671, 62.206872893917954, 62.69470199461907, 58.52533232781195, 58.95192930775305, 57.10110010639314, 58.89812615609939, 65.06277415060228, 61.61370461986911, 58.68275665467786, 64.75054564014559, 59.01052559575727, 50.83101095691804, 41.59804967141921, 33.16351429108651, 24.397685720074563, 17.277948433353057, 10.54640910317821, 7.225863875881319, 11.861385664632245, 12.182440488569199, 20.426789945171727, 10.896510058833707, 3.4257858510940307, 5.0856431838004825, 7.239735337995715, 1.5113008719298149, 0.9851491727655934, 0.20916118617019347, 0.027726447592759808, 0.5148889809366196, 3.8948503328907877, 15.442342931224456, 37.69202793798139, 38.166269948405606, 30.189271203933227, 25.044341394978186, 22.619657670297933, 33.089514855415594, 55.25457374511227, 54.434574803998395, 52.24906936768563, 33.615065390063876, 6.95337240734408, 0.2859587426627836, 0.005429954598507574, 0.043515992771473624, 0.023962713162144347, 0.016529819770385663, 0.03511734404450944, 0.06160612871509887, 0.029633066151291135, 0.0077354823212860335, 0.006791791275909712, 0.0717691315578357, 0.07618957379412267, 0.03193141227858442, 0.02238990209485975, 0.017209745785822312, 0.013952827355223558, 0.04745582974846325, 0.0204924421174632, 0.07089173105815727, 0.02695679927485124, 0.00932840463299785, 0.04591606579901231, 0.003911281289014545, 0.044930826932672537, 0.06088215647445572, 0.061210662637266426, 0.06517421003551253, 0.053591470068861405, 0.04773520669268985, 0.040908949599871715, 0.05910050792379245, 0.019670531281360218, 0.014032337705664819, 0.0243602744904497, 0.046159222106178927, 0.053705483104192445, 0.03660381125706819, 0.027169723837305943, 0.036865809496732495, 0.12327099339135232, 0.012481635935874957, 0.03839554918569423, 0.02701359320311777, 0.0552722018572592, 0.08225342018469688, 0.010722205850235637, 0.02201793959454423, 0.02390642868234746, 0.10099484194670955, 0.0326186295358404, 0.047648033547785976, 0.07029690208934969, 0.11829956539816434, 0.007136082680400222, 0.05270929684141471, 0.053807414932957584, 8.275062595644306, 36.39809293131675, 53.22063261462797, 64.64031919356316, 56.70265397717876, 44.805128574371345, 41.918774035669145, 44.705100290236935, 25.322880668024865, 28.34771840803085, 45.27197691702074, 35.13685480240853, 32.747188037441624, 18.712453342253163, 6.0959334623429084, 0.4019468445931712, 0.22957395131309188, 1.430049341532492, 3.5950755928793265, 8.977504180323693, 10.30068241780804, 15.064316661127153, 12.925083425737197, 18.045485673412202, 20.24080684108119, 10.78047360143354, 11.412900878537087, 13.543657871984667, 14.335683449622124, 20.677158755640832, 35.295157740193034, 39.64888272746917, 46.56007543686898, 56.9149051943133, 61.236647175204375, 65.62948996020903, 65.76041083182058, 64.09391341670867, 63.27678172819076, 65.19664464458343, 63.5501552397205, 62.26228813971243, 65.85061750104352, 64.5022007726854, 60.334651085638235, 64.88975055756109, 61.972307312873106, 60.64520474403136, 58.556581850974794, 57.72925200000886, 55.280088763083185, 56.10306086078767, 58.90595128459316, 61.99720651872697, 67.55722507353752, 65.26148142353182, 65.58146445981919, 63.33637037584859, 63.54286747594034, 61.488129938802416, 41.920201778411865, 48.92950473293182, 39.27078585470877, 55.115302147403845, 60.227593914155044, 56.2452938479762, 60.238898184991655, 59.99637411486719, 62.48504346416843, 67.56572092733076, 66.68913395174089, 63.95555965362057, 58.051098162128085, 52.82041749646587, 51.316965164676795, 57.63911201107887, 62.76787773255379, 64.52800604604906, 64.41839933395386, 59.15438244419714, 58.352238132107644, 57.447935688880186, 59.36944600074523, 65.3941281380192, 63.9750224544156, 62.40173624407861, 64.55319942966585, 60.759992907124186, 51.30537848318777, 41.02096703744704, 32.27778623181005, 22.55767441564991, 21.519193572382775, 11.759795296576716, 9.362216130379709, 18.343701516428304, 17.38285026242656, 16.49951877132539, 16.89496820972812, 9.498419454020839, 10.03052132744943, 9.936594290118064, 4.734405721387556, 1.352623470367924, 0.6094858855489762, 0.11505268559220339, 0.5694105392021518, 4.455255539186539, 16.90361507477299, 34.110758842960486, 35.74663039176695, 37.01115938924974, 28.540185190016224, 23.99220678114122, 36.92319631576538, 59.57762187527072, 61.843288790795114, 59.69493604475453, 41.132801655800115, 8.944559212653868, 0.337935479417924, 0.052814798639907, 0.0660985793858286, 0.026348219027802832, 0.012324211570704657, 0.09382253527761468, 0.02614156489500836, 0.03856752826381595, 0.03890359954487893, 0.00824878756482635, 0.07736927258872217, 0.04948692035771186, 0.0412087083133238, 0.06216064230689119, 0.05635765651541372, 0.06660555339147968, 0.04814751138309798, 0.05319564776014417, 0.06026342556241059, 0.053033501420530586, 0.03491792369693999, 0.06028344727031166, 0.04679155490931965, 0.04321359488512239, 0.0231774079222833, 0.035687654369300416, 0.06257045338110578, 0.015329419364852291, 0.009529291081332393, 0.19243460629255543, 0.2831103358297579, 0.11555534652284077, 0.2034093673911787, 0.10596941856126632, 0.25830771834138905, 0.1881845190279907, 0.16651777520535455, 0.17616691308156138, 0.1282828325225461, 0.1945695094764233, 0.11526492259074604, 0.20552205402524243, 0.10770234008950573, 0.21114895450732402, 0.2393127521199565, 0.13432758800204725, 0.14793614406258832, 0.0793758637061523, 0.3310504940248305, 0.19358453491041738, 0.13332531517071108, 0.13419320085836997, 0.20207729370843983, 0.0962979645438252, 0.12003567385216875, 0.28042605567363005, 10.886173632837112, 43.40587792858001, 63.29641319090321, 78.27348555288008, 64.50851186629265, 49.34190273284913, 44.76600293190249, 55.23598563286566, 39.49095241485104, 30.478377342224125, 56.4795966302195, 49.39466645640712, 45.65562786594514, 28.500461386096095, 7.246146452042365, 0.8879419308035605, 0.29331370767566467, 1.6903103695761774, 4.3468735871776465, 12.995844944830864, 21.374667959828532, 21.56549519108188, 30.321051074612527, 33.651221798312285, 21.872004885827344, 12.4819742479632, 13.041074775880384, 15.659707938471149, 14.063861235495537, 19.61143312915679, 43.28750471914969, 48.403491358603205, 49.80588382290256, 57.009379402283706, 61.248700618743904, 65.79847351197274, 65.89025697400494, 65.3654085436175, 63.749611685352946, 64.68166489754954, 64.14374712974795, 62.734423837354115, 66.8948701120192, 68.04643877090948, 63.925486841509425, 68.73787418488534, 64.7124868823636, 62.71336463189895, 61.6244754483623, 61.33107431473271, 57.61683294850012, 59.1941866567058, 61.589962513216086, 65.15147462967904, 69.70547583795363, 68.05998663748464, 67.45603576783212, 65.7280473555288, 64.78798074107017, 64.70788594215148, 49.96945058145831, 52.46535278135731, 44.524267258182654, 58.89491765729843, 62.42255226258309, 59.5913972393159, 60.632398205418745, 59.23720721275576, 63.29604056573684, 69.91042752419749, 69.21574438771894, 65.54997174970566, 60.8299405344071, 55.88536147148379, 53.64558219909669, 58.599100343642704, 64.3983756342242, 67.18783978492984, 66.93003023824384, 60.101030795804924, 56.9762824427697, 58.7727907396132, 61.244707645908484, 69.12406290731123, 66.28514551347303, 63.73056465579618, 69.02336782024753, 65.7613875019935, 57.13952364460115, 42.35979749310402, 36.86712603415213, 29.788097066264, 20.82733846479847, 17.391363766885576, 16.54416514981178, 23.025754382533414, 22.85023420087753, 36.419916998955514, 21.556748305597615, 12.062829771349508, 15.667580135406988, 17.939122761449507, 5.837001627491367, 2.700534458121946, 0.8674484659587184, 0.2761152789237038, 0.8293976754911485, 5.054893272538339, 20.088869910086355, 45.8208224081224, 52.52001885444888, 42.78547663842478, 36.50542859108218, 34.63212028626473, 45.18429625418879, 69.80353509226154, 68.9140356740644, 69.89880161900675, 47.8241886631135, 11.773339240781723, 0.681123073783613, 0.10531746241594515, 0.29706324841226306, 0.17238568694841477, 0.08127936237161199, 0.23705835454165938, 0.10999497311610369, 0.08879593363212002, 0.12626088134223415, 0.09026539752319937, 0.19389026527923925, 0.2736324798916617, 0.15985385214369144, 0.1099387422624615, 0.10092420097921165, 0.18179631101027613, 0.1372333288553261, 0.1389260154457823, 0.17936557531356814, 0.11885781366858753, 0.09925289590272213, 0.19776749755105666, 0.24943030679658537, 0.21148281562472546, 0.12064951712325697, 0.1226888278559331, 0.2007807205401121, 0.21235287700208927, 0.13012165804543804], [0.013065566346349736, 0.060333779246936885, 0.10874772834922038, 0.0269369441910737, 0.09944436425763754, 0.041989711969490015, 0.045796659504694325, 0.0050498155460152174, 0.0506794587859223, 0.06483602052133891, 0.06666805084434248, 0.03663139425278191, 0.03576257776829504, 0.02598781296382508, 0.06958511447714222, 0.016639125195422, 0.020925274133802425, 0.0304900887121837, 0.03692485955393603, 0.07863602195415767, 0.09606989250788767, 0.03540068932418381, 0.01676258409485942, 0.040621252940787424, 0.06413239557596465, 0.04380810975788101, 0.32830462039959046, 8.841346944532088, 27.96681311822707, 52.376993548485544, 54.75415383615802, 52.324896627856845, 34.3778016490321, 31.084142308081354, 77.25639927771785, 83.23596631326984, 32.020021792381044, 35.676698453964725, 36.61065793806507, 27.703626002034834, 11.11461345226534, 1.431905235494337, 0.16422640622383164, 0.14525448392716148, 1.2801162513994402, 3.087564038653528, 4.013502275751484, 7.895960125230975, 8.235372131870639, 8.230043591991548, 18.613185997932188, 21.292353099392308, 15.664608940001457, 6.83571110810003, 21.123891222861506, 20.3123842131707, 32.211978666244015, 40.17912441684354, 44.79260444641114, 56.64270054909491, 61.45528793334962, 63.94066641407629, 61.11449672329811, 61.70496248429822, 62.35031004874938, 63.14514698520784, 59.56594497926774, 62.9981130169284, 65.1170519090468, 64.83843811096685, 62.36660357444518, 57.87877667334772, 55.02746851213517, 49.80092202463458, 53.65315629589943, 54.660919097162065, 54.896728069551536, 54.37725720867034, 55.29024377945931, 57.38937470220751, 62.10927255692021, 63.12647258081744, 63.8660393991778, 58.52805053034137, 61.10624797882573, 56.650823777721776, 67.07643662729572, 33.63188451336276, 41.038370593901604, 37.743744388703384, 52.410576881900916, 60.86947410337387, 55.38669093962639, 61.897072330597915, 59.36957151659074, 61.99908141166934, 56.945342786850475, 63.42057974107804, 60.057123784096014, 58.62107346134802, 51.76426441438737, 49.695708367132376, 49.487552104457734, 58.07363217876804, 58.292096430255526, 61.81514578480875, 58.62209327759282, 59.524022686866026, 57.32517334722704, 58.1110280559909, 61.46008499207036, 62.88328563013385, 57.63437378791071, 60.406979591615745, 63.6098615584835, 65.13744431157266, 51.19235538667249, 42.87043517635715, 30.39728822246675, 38.94567628060618, 15.254256456129013, 9.59101092430853, 14.48847153494435, 13.004999756813051, 12.87462115287781, 11.178180363870437, 10.654781249261672, 8.056622858970396, 6.353175245946454, 1.5079337622850173, 1.1783366289830979, 0.5915121145306096, 0.030946901195772716, 0.3059221053075406, 0.6705127560323285, 5.288798424505419, 24.632021842464326, 46.94332238166563, 34.89745686131139, 24.722038276733894, 20.065569070077714, 35.52129414773757, 45.79064761438678, 52.602090527934415, 56.93367765795801, 40.2636161927254, 10.0400468034129, 0.48125634210244306, 0.010771926871741251, 0.016852358108266227, 0.05601406608137393, 0.006994870172122554, 0.04283528534635421, 0.03754392371422822, 0.03965554165563757, 0.03301088570527012, 0.04976216808802659, 0.04952138282298561, 0.07419909350574017, 0.009966193897379263, 0.020787809231889345, 0.03417002653042155, 0.037886970225841775, 0.05104319733237067, 0.045033521018922336, 0.059372833028676054, 0.04775273478439739, 0.03254063029382979, 0.03245051537129668, 0.07787490594050578, 0.04032802129645021, 0.02401898615062237, 0.004744304469861692, 0.08144706667911622, 0.015773999339510358, 0.05193975386059573, 0.09315459853819302, 0.03043319136204739, 0.06530897256227271, 0.008531597540563634, 0.09579924896599785, 0.046758084527907834, 0.08550733267780274, 0.04492624572688534, 0.06426945253605805, 0.027324509987187003, 0.12164862601146584, 0.054921996253993244, 0.04179938508558177, 0.007577204725690067, 0.011910540370961592, 0.0769234017559117, 0.062409360412388086, 0.01896583572811177, 0.017078915205333504, 0.024307571471698826, 0.018834758084267378, 0.025483504944150488, 0.036525030605374806, 0.07525655531114148, 0.04161581126672607, 0.006395933535625979, 0.7207742525685219, 10.487483336079507, 34.543521788812455, 60.72569962470763, 64.42613817030384, 56.20467770484186, 38.350491908288774, 33.73365432985368, 79.6382507201164, 67.22714193405645, 26.967049990930867, 40.568756980280725, 38.740014645361136, 25.172528374579645, 11.177677319895837, 1.8949330670218316, 0.31275606924487703, 0.2824148505685791, 1.8869396443328552, 6.841956992303172, 10.794619629459998, 11.430311299139454, 17.46686939270266, 17.06166894205155, 12.056847176244183, 16.9189436974064, 19.67848800843762, 15.49870542941555, 19.318128093596428, 19.847999118989517, 30.84560924960721, 39.39692535708028, 46.677268012877434, 57.191906898252434, 60.859460292323945, 63.83164413513676, 63.93005248039, 61.490091123888575, 61.8557736950536, 64.23809582187285, 61.56283932347452, 63.93473186800557, 67.3998752717049, 66.03637310766405, 63.643660622258345, 59.63372745821553, 58.02209615707398, 53.19874186669627, 55.67702085741105, 56.60535566268429, 56.82596152828586, 55.406867611792784, 56.9762824427697, 60.28745712772493, 64.13107395172119, 64.72364210313367, 64.93767015395626, 59.94436740875245, 62.60061610129572, 59.4250455979378, 68.20960152533748, 40.64026963326239, 44.054512439235566, 43.22855934020012, 56.46588402409708, 61.250536287984545, 55.94765655456051, 63.153458487602975, 58.55375774445073, 61.071844870044345, 56.17417735438193, 65.45730183201452, 62.20955187274564, 62.27465145049557, 54.19552203147642, 51.08485106498965, 52.73336833523166, 59.80187946750272, 60.60857765136227, 63.19303912501182, 61.41909622376966, 58.84223238114388, 57.50675947435441, 59.500955227882635, 61.60868398604855, 64.47032759266516, 59.99434232711793, 63.857578846716116, 65.39701108009585, 62.98672637631817, 51.815365052992306, 43.29933458758939, 27.82425653549933, 27.464543811736572, 18.317880553583947, 13.402832035095463, 16.120147128258985, 11.348127838104002, 11.159762874726328, 15.359542677479407, 15.979902782747823, 16.6399258951987, 11.00148052938523, 8.410003896682493, 4.249527223648564, 0.9245485536033108, 0.13556698036770667, 0.2725421222707918, 0.7906219206990734, 6.345800699726229, 24.482879600217267, 48.860922090468875, 36.53137114740188, 29.66377950483753, 23.888683665183283, 39.27660272967431, 52.378793916394635, 58.51079994632352, 63.655212002415816, 46.43876829454976, 13.388837998913182, 0.6098560592339886, 0.06782687374300535, 0.016353851289398248, 0.04372156097463543, 0.030038495202578848, 0.017555036935054006, 0.027678883108761043, 0.010136252010030853, 0.025961631909012798, 0.019350406120441133, 0.024164770767393134, 0.026596054216966997, 0.05097918302541779, 0.037507392811558904, 0.045559344617950345, 0.025098993923635255, 0.04598454639856373, 0.0533788500263566, 0.057260652012642355, 0.018531293420481588, 0.03693683350819253, 0.03441779468689234, 0.01067420948416956, 0.050374624739971854, 0.014772438012333888, 0.05275489056422826, 0.04934329036322813, 0.02529703722816081, 0.024899661676177097, 0.3253033024168784, 0.13820357921142734, 0.18917994303328378, 0.05647984370889683, 0.19651253827877585, 0.1355627822058816, 0.1851914747948608, 0.10810234523828953, 0.19857665493844018, 0.16765081924536537, 0.19275112317935114, 0.2379032729133483, 0.19651710416280455, 0.1646605329287629, 0.15387291178828286, 0.1613130811001024, 0.23287857882678512, 0.10057826631612356, 0.1810646817208298, 0.18513433995746797, 0.11937367429416026, 0.1420018431400099, 0.11817787999227164, 0.20351127240686648, 0.17883544246996605, 0.15282144079044943, 1.10133204488985, 14.25373827257464, 41.653417848771625, 71.15856493673017, 71.33103939794725, 68.51217316042992, 49.58567019431822, 45.20672436683409, 86.809433814018, 93.32462403082079, 45.944671246313284, 46.03449744562949, 48.45220719614337, 33.75864767259167, 13.193113688499698, 2.4827374998600256, 0.4335496262196572, 0.3561925497506896, 3.7842711181409903, 10.915946383630077, 15.55597693689408, 18.159142232710316, 21.114020578322872, 18.229678215519076, 32.198366080560994, 37.17873873249177, 29.654250106503888, 10.762415009160197, 26.12579964822339, 24.46307163084707, 37.036733242773245, 44.8185666145817, 49.66375281733852, 57.655527130250015, 65.31052674016645, 66.49053650517618, 66.09905258301767, 62.36803523955807, 62.669763565063484, 62.6273980448323, 62.14919051816387, 64.95452065621653, 70.33471815047726, 67.92646915681901, 66.5670854814591, 61.70547631479079, 60.38644990613384, 55.72647802291378, 59.24081579331429, 59.06224596884943, 58.844538734805205, 59.99549158157841, 61.05804989414831, 62.0883192554597, 66.30422392199117, 68.39432162623253, 66.76111728914323, 62.60070239343951, 63.58234220935453, 59.085701742479884, 67.86844161248976, 46.942475149708415, 49.90773600916709, 48.3962232066739, 59.40468849674348, 62.983592402550485, 56.98632371041083, 61.391576874640684, 59.43073695705783, 61.033209523847034, 56.69544073843188, 67.29744649702504, 64.13101903853878, 62.49819124898603, 56.54874409398725, 53.64671968644666, 55.022310595358576, 61.40496000166863, 62.32497938217656, 65.141845210906, 64.47212796057424, 59.330018335773104, 56.72532919914492, 58.94593984849992, 63.03765835300569, 67.8181254479193, 61.47931245065505, 65.9094452088879, 67.55627585995582, 69.21865478638681, 56.280622636118245, 46.5334503881393, 33.14766007085001, 42.57857945657546, 21.784598788907452, 18.014651921487626, 25.798577877783007, 21.484074631044944, 21.90191884194651, 19.402243321941747, 23.109075330918838, 15.889659831600806, 16.36626801183147, 9.878452997053824, 3.5430544230245777, 1.7014461010694506, 0.2682627244822441, 0.6509482800479859, 1.2583627864237756, 7.694044843796761, 30.140690688164007, 60.061595286092455, 45.673717837179865, 36.15289380473476, 31.951003766828972, 47.92244011355985, 58.582630311289144, 67.50594400590467, 73.27308331766437, 57.033435298550515, 18.897481349206743, 1.2049801863970295, 0.1440155665360151, 0.13899825753704195, 0.18462139812688674, 0.21661129930327017, 0.2028482692736772, 0.11150682465203347, 0.09232594421313656, 0.1526016195214564, 0.11812893463478935, 0.1066414921754791, 0.18114365006406463, 0.15917154359481028, 0.1371010867578368, 0.10529637967626895, 0.11719969296527487, 0.13126034049257157, 0.1225018717588917, 0.16146288193281622, 0.10836133658285103, 0.18936250178563982, 0.12783021245512272, 0.14736862612828133, 0.12832895101558778, 0.09276074507544119, 0.1523366143866893, 0.13775598468078723, 0.16189627319334016, 0.15720571601583114], [0.048814080655574806, 0.037603824129027706, 0.09542926680296661, 0.030504809091648752, 0.03539448401199714, 0.05305406322041827, 0.05639224538519498, 0.005501476567118399, 0.04932509194458685, 0.05324981783727004, 0.0491681779854961, 0.059773064173397526, 0.07344798260037938, 0.06250601389535493, 0.0584300852290565, 0.03934862385053308, 0.04580638499089307, 0.05980538925336254, 0.005049762877470424, 0.034432246935583895, 0.0470912178617812, 0.03664110441722217, 0.09521663143870332, 0.024518165211643905, 0.031988300052621675, 0.025308702832027793, 0.7245288801289375, 10.835674097461085, 37.659774288054436, 59.90726963166268, 63.144652766566125, 56.38365937817482, 49.16632567682574, 30.571596391739387, 28.379426848503854, 34.48694944381714, 41.50925897782849, 40.799914021645826, 30.491789887028357, 18.982726220161684, 5.6188291022854475, 0.6043586122893518, 0.07310918787674558, 0.6199312798919216, 1.5730850662915938, 3.8454350877192716, 12.707502688131026, 5.66255372378134, 16.049327754205276, 10.74652744877723, 8.58965531472237, 17.244871085689915, 13.936160629795445, 27.07526230042981, 25.720469759356593, 33.61910543134136, 40.86289159713253, 48.18573313374674, 51.35742833537441, 62.52533012820829, 60.43533832796159, 61.74869298934937, 60.905097069278845, 60.916903403497514, 61.02079129988148, 60.2177252308015, 61.83289843220865, 60.5138014208886, 62.23150145622992, 59.94672475322601, 56.17993931616507, 53.64059686660767, 52.02083056972873, 50.44390047750166, 49.2299190644295, 53.58394999657908, 53.8146088969323, 53.3594923634683, 56.85856034678798, 60.15235500950968, 61.04780074088805, 61.21752954298451, 59.39882847570605, 62.37327160373811, 65.39211988449097, 59.75596027989542, 63.805325031280525, 42.89617769179806, 18.651248678084343, 51.53075002854871, 58.649589092500754, 55.52087914559149, 59.58976161095404, 64.23177296115507, 64.78489383574455, 62.73519654427806, 60.43444794993247, 58.50597543101157, 62.53066062927247, 61.49431159419399, 56.28370169670352, 47.48296599234305, 45.67936212785783, 50.38059342292048, 60.77696108048963, 60.23704682627032, 63.1521797949268, 57.626717321334354, 58.32764094875705, 59.008270232908195, 61.6508416206606, 60.734552414186545, 58.76964892110517, 60.771528597800966, 61.72502148535944, 61.17721934472362, 61.81463979905652, 56.61062340582571, 44.94027776102866, 40.371508829055294, 26.35826676122604, 15.535512951112564, 19.4645482109439, 16.26969729700396, 7.345161293783496, 17.31489912156136, 10.550759011699308, 14.065445873045153, 9.911426401907399, 7.797857234554907, 3.416250324056995, 0.816177694547561, 0.3674451249741739, 0.11944001750840295, 0.6491144494183603, 2.9411323993436755, 12.912273945346957, 27.180785825175626, 47.65858227206815, 29.620729531011275, 25.231059943476033, 27.383372322205577, 30.771164624921738, 50.32398577659361, 51.69335972878241, 48.973741223735196, 20.543743256599676, 4.417400254357246, 0.09308999434353844, 0.03678814350296894, 0.05915942774604886, 0.06041110816201376, 0.060024241421131365, 0.013031057915800523, 0.06158670455577874, 0.02894350466498685, 0.018174319430404616, 0.020302391025207697, 0.04694443541548906, 0.050942751714178634, 0.03155123923094042, 0.11240111739044228, 0.046940723719495925, 0.04411063404873975, 0.049731294744678085, 0.05243041785433889, 0.06827780841699532, 0.042852989638284336, 0.05224519311600635, 0.10940023607784703, 0.07346632274528665, 0.09438555627580612, 0.04218927404332546, 0.01385343893836703, 0.04369333829550494, 0.09095021117959293, 0.1141978080774988, 0.015564887979698759, 0.026679437141865495, 0.021904370890209274, 0.034342702748554374, 0.02438027513093285, 0.0335286500593347, 0.03685017747263755, 0.07610770197765482, 0.051595945091497515, 0.055087352502009565, 0.0676310157042838, 0.02986402059304378, 0.04629190087378506, 0.033257795843265714, 0.0350880565031642, 0.09588675152870918, 0.021447995076737097, 0.06647349515509221, 0.009229052605317726, 0.04170547802782348, 0.04890551324933768, 0.026832721759414962, 0.010386239906262246, 0.026875074930308808, 0.06726844927235957, 0.9816286003878041, 13.116054804094377, 43.44688630873158, 67.92849309982793, 71.9926255749118, 63.577462780860166, 52.583545561759706, 32.81084418296814, 43.56869159206268, 47.41130036692466, 32.52082217124201, 39.06360626220703, 27.804313244358188, 17.78171020169412, 6.023440216818164, 0.8457409049714766, 0.42335655059545274, 1.0882144132929465, 5.855973641718588, 8.553525382472623, 9.283551035388824, 15.328451029716001, 16.768346255825413, 13.253734900105385, 14.986842005483567, 21.581070923036147, 16.105942264679943, 18.513963760868197, 17.91162890772666, 27.469474231043172, 34.52132117363715, 45.66463755023095, 54.51173959239837, 61.71460367018177, 62.56858994883876, 63.67052493556854, 62.37914339188607, 60.90599921441848, 60.80276635385329, 61.535998544385365, 63.6080337339832, 61.90683510995681, 63.83061647415162, 62.749615177031494, 58.77970195585682, 57.45958512829196, 56.203195048916726, 53.37242049555625, 51.86745020651048, 56.15935079513058, 57.14762726137715, 54.71571460846932, 58.049529214059156, 61.72562553036598, 63.532677158232666, 63.13790628986975, 61.3534906602675, 60.488153042331824, 66.08753650419175, 61.353671089295425, 65.25297380262806, 47.20584661729875, 25.59798590598568, 54.13254053361955, 58.443762717708466, 54.53331262834611, 59.33230115521339, 65.57008958631947, 64.78123426437378, 63.261280521269775, 60.16592248793572, 58.4904859912011, 63.67469049269154, 63.592257961150146, 58.68953058796545, 49.100696579102554, 48.183881775025405, 52.02292903777092, 63.472507999789336, 61.50486669232769, 62.886105814287745, 58.73385729328279, 58.181454212434836, 58.37332087178385, 62.7563302747665, 62.46226233820762, 61.22736684737667, 61.32431607092581, 64.21693855716337, 64.33631981572798, 62.86325016329366, 52.79482010872134, 44.36510139896024, 40.22760883454354, 29.27694163014812, 18.58494297150643, 13.47665104173845, 16.21021161156316, 11.420827008062794, 15.96645199483441, 18.25926857609903, 14.33908022219135, 9.70209538936615, 9.062428397517051, 5.374906216898273, 2.2619661592668105, 0.6477565738943316, 0.24532286510352166, 0.6378353675526958, 2.9233961768688697, 13.877441767723331, 32.37979531288147, 48.12846652923092, 31.24225893328267, 25.230059739082094, 32.850730765250425, 37.82938149667556, 54.69942108277352, 59.616002267406834, 56.24144600283716, 25.39364414830362, 4.894828209953924, 0.15245492900571517, 0.09020604103082612, 0.05136056840720196, 0.03708789072510216, 0.03632034723376555, 0.015607103254766235, 0.08418534071214738, 0.017374378080750187, 0.005678416064549839, 0.019690146962661418, 0.05494551132282904, 0.07435774265397942, 0.049787142554358135, 0.048957461671483134, 0.06376589911298887, 0.02179603456639715, 0.0196957279131898, 0.0479916469644635, 0.050088793504983194, 0.05442824875635486, 0.1299171585349306, 0.011112880048101709, 0.005349078696341284, 0.05227870180181438, 0.06794545649280471, 0.0460019174422468, 0.02185738288737353, 0.06340950351929472, 0.15346067987622755, 0.142268487702935, 0.1502246478752744, 0.1351993347728445, 0.08064812890464261, 0.11967321467255393, 0.28868981546932654, 0.07421965530562787, 0.1309834763167366, 0.11680306626423714, 0.17582519190205684, 0.172086805405636, 0.14437178209904702, 0.1577093575390116, 0.12159091660812979, 0.13804918185116785, 0.1625788115685986, 0.10541846344788229, 0.1725625306848557, 0.09450157263105917, 0.17629941564894494, 0.13165369599817262, 0.15501065960814878, 0.11004326729885033, 0.1582155271523422, 0.11293731765040468, 1.532660016129094, 16.64602714200174, 54.05781545946675, 77.47417711442517, 79.21476025735178, 70.27031283224784, 64.2212139406512, 41.87936206017771, 38.0879480608048, 44.511323436614006, 54.47657946617373, 54.98609535155758, 40.06501090142035, 23.00466379811687, 7.83390675821612, 0.9776185897569504, 0.9470195671723736, 2.1164633862433897, 6.69081041889806, 10.992089394600162, 23.44139422139814, 24.149686021189538, 29.86362034274686, 18.950566707118867, 19.52965759461926, 29.766539719796953, 18.92316895146524, 31.794783607605968, 29.80703034708577, 39.3852759176685, 45.2947501982412, 50.77621544561079, 54.05437554082563, 64.57148944177936, 63.38163060526695, 63.86986763246598, 62.19150896995299, 61.1969017982483, 62.98347473144532, 61.75634945592573, 65.27967337639102, 64.31463303104525, 66.34449097418016, 65.07726338601881, 62.000885701948604, 59.97467556307393, 58.022362878245694, 54.83014975824664, 54.43918358895087, 57.200908737797896, 59.397353664521255, 58.39508218149985, 62.39817865433232, 65.79245267375823, 66.88784122467041, 64.92718958085584, 62.944886453690074, 61.97419005055582, 66.76437285638625, 61.847046421420195, 64.59238390768728, 52.0855143762404, 37.94014530797159, 56.50001648933657, 57.54691277780841, 55.00370679363128, 59.462072772364465, 68.88110345409763, 68.83270140617125, 65.11402383927377, 62.4063999422135, 58.405503919047696, 63.97176296480241, 66.78960938607493, 60.745374233491965, 51.94815689517606, 50.086878499677105, 54.757225052002944, 66.55184315096948, 66.93463510082614, 68.02474806385656, 60.38590077430972, 58.69129957691316, 60.51946140104725, 63.90308618545533, 63.901721200635365, 64.21524409324893, 66.375854246078, 66.56615195735809, 65.19762131475633, 66.15487575531006, 60.69302628117224, 46.752761871584006, 41.99760190902218, 30.55230813641702, 21.903846686886205, 27.031547484859345, 31.656590661694928, 18.886402614655037, 38.779971830306515, 20.08264510862289, 20.970022524556807, 21.379580728469357, 18.138369360277732, 6.944253386989717, 2.3141167673372456, 1.2481792102898321, 0.5084852826210761, 0.9463620185852052, 3.823042521553655, 16.38702715596845, 35.137180359132834, 61.044372589357444, 41.32875542486868, 38.17967268728441, 38.46329535207441, 44.705453303552446, 64.40284713622063, 67.84894743273335, 64.81490388993295, 35.16382501971337, 6.842899341737071, 0.3703226125048053, 0.14675721135591308, 0.2322911885717223, 0.13821200617859442, 0.17054050289575132, 0.12139646817118892, 0.18575788956255684, 0.08133434450193759, 0.05834585003134224, 0.14122020363086654, 0.10762447491288187, 0.13333205674444476, 0.15122500548679985, 0.16710170274299962, 0.11969895522680976, 0.15380940309936, 0.12496779387396191, 0.09469929226343671, 0.1892906427383423, 0.15177850401209247, 0.20313757471740249, 0.17425066671304165, 0.12907758745695316, 0.13691515721861394, 0.16628053309696336, 0.14815830956062964, 0.1817819851660921, 0.16603345441962444], [0.12063816370021914, 0.023992935330757213, 0.11058869125742106, 0.0548504704549428, 0.10072321781227667, 0.07566503339236783, 0.052793742713308146, 0.008192031940956029, 0.05139501555071724, 0.04199733454433661, 0.06699917702785424, 0.04335010026191031, 0.0711010262790707, 0.06975062777318301, 0.02128867943200373, 0.0528265580895447, 0.05824473791665608, 0.024987800091865565, 0.034738770205407374, 0.022130453012763493, 0.02381265952041553, 0.08282833086747317, 0.004877205881770821, 0.06353265215312281, 0.028228269657120112, 0.02928619686093542, 1.3193147028646162, 14.414853549772694, 44.021297808616396, 57.244945187722486, 56.1586683027206, 44.849863206186605, 31.754840150956188, 24.595518304455666, 17.457585142504787, 16.171031055911897, 27.04332244011664, 37.198201533286806, 31.091163350689797, 8.170853555202484, 1.2416949195246543, 0.19274199141129372, 0.32269618263648403, 1.16001058009363, 3.140304227990489, 8.26542042916821, 7.989282627259532, 14.273192248036786, 17.791265095433882, 22.649887377215972, 9.487011240374658, 15.944232748400783, 28.417415003622736, 34.413891376987586, 28.309028148651127, 26.04789157067576, 42.495017282424435, 49.30460883725075, 61.094826036883944, 61.53938354984407, 64.08877903415312, 62.90540779790571, 62.42780039387365, 59.207659998247706, 60.07753972084292, 62.789623352789114, 61.880633677205736, 59.137206385212565, 58.36644887924195, 57.46234647689327, 52.129782246005156, 50.80908883002497, 48.449791016117224, 47.74365063636534, 48.393167680309666, 53.91363697667276, 55.977058641372196, 52.89230669698408, 57.98853243550947, 60.20247113320136, 61.60627172839258, 62.57526190050187, 63.79606039293351, 56.53112088480304, 54.82334444599768, 59.242376896642874, 62.24929724970172, 47.48220897489979, 16.80947034589706, 55.7823129623167, 56.253770089918575, 56.85405354345999, 60.88038221482308, 61.31228616160732, 62.449691141805346, 62.345144287232436, 62.62488380555184, 58.196237625614295, 59.997609661471465, 62.23957761641472, 58.07261628489341, 49.92170356935071, 46.7579629344325, 49.31377149397328, 52.89909631975236, 58.74046648702314, 60.45290270159322, 59.01761724102882, 58.72169402337844, 58.4796327929343, 60.01431111366519, 61.633449831316554, 62.5887470091543, 58.49290217122724, 58.35943175900368, 60.5617759304662, 61.98390968384282, 59.15006783700759, 47.4868687506645, 41.74870790973787, 40.98371236555038, 30.994035659297822, 20.20443666365839, 8.576962524844754, 8.69159967668595, 15.26563721318399, 23.660707666027932, 24.165516707205004, 6.3531742653539105, 8.558934330940247, 8.705010260305098, 1.5607978740046102, 0.36898508427604554, 0.10021773001719868, 0.024430986321080598, 0.9426220386259018, 6.110673239154201, 26.08410877566184, 41.22935471996185, 39.82999424780569, 26.8124968390311, 23.588649803592315, 26.260021194334954, 37.83792441891086, 42.212790981415786, 47.696641029850134, 32.28518382195504, 7.160940314492873, 0.4210785421873293, 0.10844664047321967, 0.07734851926685342, 0.04258339180641117, 0.061827738799395106, 0.027603469413494872, 0.09377257868407235, 0.03462156258343208, 0.059061958379442656, 0.1156963833097008, 0.04625982477239544, 0.05914118336213212, 0.05265874269929144, 0.016761565197920127, 0.05992352384172621, 0.09179464691588957, 0.006620783693036966, 0.04101360104076805, 0.032542480396166924, 0.0703589552112164, 0.07908602966175926, 0.04469459222990178, 0.06619487663791065, 0.050856995831934676, 0.0458403954642915, 0.025799874359020786, 0.018180442388139425, 0.04354385155884009, 0.029306586291040146, 0.02570172508938178, 0.02277663285513559, 0.01639558775951305, 0.02158730242010807, 0.023298484288276206, 0.06486886271065281, 0.0026473092317070455, 0.03442515679184468, 0.04712304115415581, 0.03184906548760351, 0.049464680825269995, 0.043557644971916755, 0.04033958539366722, 0.04767035734989951, 0.010849432944650612, 0.05899053983270161, 0.05332718888718275, 0.041257013987389304, 0.02221912960521877, 0.021713532642611576, 0.08244517199214428, 0.025022591974946762, 0.02495143581331978, 0.06873009140573202, 0.04781305271711561, 1.7886405125741036, 17.390004665620868, 50.41425128136912, 67.52315536622079, 64.17927595876878, 51.51388775917792, 40.49449866817844, 26.607037205849927, 19.17509690407784, 23.75822759443714, 35.605154422021684, 33.89613851424187, 28.267603997261297, 8.77260740726225, 1.9926879699191742, 0.16565321433928706, 1.0143573474018805, 1.9469357281923296, 6.27317899657834, 8.787870330195274, 14.341186534973884, 14.759882880795388, 14.965639633517112, 11.525628816696907, 10.442566314051229, 14.21532650147715, 19.20012947051756, 21.87790216938142, 25.40722731621035, 32.25517376776665, 41.084815379112, 51.74781399388468, 58.49747173247799, 63.25560485163043, 64.87291182241133, 61.85336535976779, 61.36975672937209, 59.76638593981343, 61.44695289673344, 63.302320280382716, 63.21019164977535, 62.39644496671615, 61.55021321388983, 60.58565924244543, 54.472009904922984, 53.9574969199396, 51.64367898817986, 48.503633391472604, 50.86410399406187, 56.30702018737794, 55.7484079945472, 55.5792950045678, 59.77787063967798, 62.67754946985553, 63.875284425673954, 62.698643976642245, 63.24511643378966, 58.97608718564434, 56.76887535279798, 62.27289815102855, 60.882884686993016, 50.748233256801484, 21.890767543546616, 55.99126154376615, 55.353719495957904, 57.53082713773174, 62.49814418054397, 64.92160804810064, 62.71896185413484, 63.95569301420643, 63.958736773460146, 58.055879531368134, 60.85687937275056, 63.811083070693485, 60.04346216878584, 53.687378975652884, 47.41795662910708, 51.689217705880445, 55.54655498073947, 61.43645663415233, 62.4500951459331, 61.84107265164776, 57.62251254050963, 60.50029670038531, 58.6384887849131, 61.53424524491834, 62.04300803522911, 61.34193535773986, 61.44792564453618, 63.62665714756135, 64.30420737112722, 60.89014499418197, 47.52769277941796, 40.66840087213824, 36.69530268638365, 26.00758137241487, 17.70056224638416, 15.069145098809274, 11.649239370899817, 18.7717144720016, 15.620932367540176, 17.651234519097116, 13.219200391923229, 10.57824404008927, 5.820168285600602, 4.250383771234944, 2.434126340573834, 0.33583989186633023, 0.1641960231767547, 0.9132266933879546, 7.843084614123068, 24.8915474261007, 41.96415585856284, 37.03150472333355, 29.914922983415668, 27.522814543016498, 31.72240018844605, 43.797055905865086, 48.563355399716286, 54.271710149703495, 37.80502750027565, 8.580942749977112, 0.46713602398672416, 0.030574716529959155, 0.058967446112224174, 0.09200363570163328, 0.06720204477108295, 0.11650952435429059, 0.05022996052679035, 0.06056397334642469, 0.040235872410478137, 0.11864527023487514, 0.04375716874135598, 0.023504960305628278, 0.04511341249810592, 0.011966588321111858, 0.0363357647532417, 0.022650630543789557, 0.022417923675910122, 0.011002376653073777, 0.0167813724012024, 0.06592253238082894, 0.02503749813073345, 0.032872334873724374, 0.03511895665959005, 0.038138603295890555, 0.03530159968161776, 0.033932294125758836, 0.022851964195949898, 0.07588589654093789, 0.19519465254439464, 0.08938453430610319, 0.15487968921661377, 0.10596620865286359, 0.19877248233364475, 0.11457640106879896, 0.1485153524986198, 0.20776093066219362, 0.10658642577548182, 0.19119469298710748, 0.12436236990916154, 0.10150963771006755, 0.15367074118506524, 0.1235927273369124, 0.13500945221993232, 0.1819068728195083, 0.13215628032001758, 0.13456320600403895, 0.08643719487853589, 0.07674298804974364, 0.0903262555479042, 0.2919264756623776, 0.19477053094775448, 0.12009553596257203, 0.17448905795331926, 0.26387892423137543, 2.2578319811051895, 22.55494248482489, 59.7545325371527, 73.73523266084733, 70.93174211440548, 58.7002347361657, 45.681864600027765, 35.672097513752604, 27.149067578777192, 26.840722214791086, 39.02047587979225, 48.06164110860517, 36.46658143689556, 10.787131824801046, 2.0744874063999426, 0.6255776543290384, 1.212258144251762, 1.6787008893105293, 9.201173417029842, 15.661541646526707, 17.42366840762477, 22.827254995223015, 29.87649944520766, 37.14656745233844, 18.495758079713394, 22.349361258168376, 36.39263299203689, 40.76143164788523, 31.83579198775753, 32.99218123958957, 45.679817122797814, 52.346520654616825, 63.27504411820443, 63.83330722008983, 66.92507236234604, 62.96682427006384, 63.3996029053965, 60.24357757260723, 62.05008399101996, 65.9038205300608, 65.78746341889905, 64.04700186944777, 64.48481290571152, 62.02241166945427, 56.54869310317501, 55.81440971743677, 53.14239309680078, 52.422308691086315, 52.92770216541906, 58.75943506917646, 59.741545569512155, 58.36054571213261, 63.39201311911307, 64.1924786567688, 65.7457019436744, 65.10994849666473, 64.49574847375193, 63.198059758832386, 64.42233739360687, 63.40575318182669, 62.69545901206232, 53.77147459214734, 32.73751743378178, 54.65364702286259, 56.929480721873624, 57.555745955436464, 65.58972497140208, 68.02675631738478, 66.10942332975327, 66.5475050095589, 67.08500308375206, 59.3379532906317, 62.4340134282266, 65.77622582835536, 63.676075089362364, 54.72413201485911, 51.711073152480594, 54.5472841108999, 58.08296741977815, 64.80634135584678, 65.22835700742661, 63.84086954978205, 58.079123497009284, 59.94865063698062, 60.64911534709316, 63.966385395296165, 65.54241334238361, 63.364791870117195, 63.72521062051097, 66.5602134889172, 67.15441334632136, 63.56576235063615, 50.082422687161355, 47.75692393702846, 45.06420112425282, 36.348855418543664, 23.525409429304062, 15.400304928902658, 21.371255497778616, 23.665251731872562, 34.830949152669604, 39.710134460080056, 21.561504179431548, 17.841808757474347, 18.238217215384207, 5.937353016868715, 1.694184200417611, 0.3508386063960291, 0.23218966659999665, 1.3766586516172656, 8.335033674393932, 32.55149706717461, 53.04667549748575, 54.75175726798273, 39.16107323861892, 34.87836668568273, 38.51580412157121, 51.90311239611719, 57.42020453176191, 63.74525000972133, 47.03964794835737, 11.843620269529282, 0.9375458174655515, 0.22527498763895806, 0.23658520331786526, 0.20489741657530108, 0.21309575246226406, 0.3323642122409036, 0.19098565823608832, 0.13768522880010067, 0.1584843780484892, 0.25864262133836746, 0.30264646656090216, 0.09700848045007837, 0.15861306549800983, 0.07216237215024811, 0.16437395475804806, 0.1787344414380289, 0.12438377440576592, 0.12803858070964777, 0.09787441261353032, 0.10868117063035888, 0.17391539599385955, 0.18473693950762674, 0.20796780504526632, 0.1459666392615726, 0.12362566145677721, 0.13950842612933728, 0.1300716631474995, 0.15160104740531216], [0.035716260092393044, 0.06677940938501589, 0.06481902869117838, 0.05546964952842363, 0.0403343185391878, 0.03150823871575056, 0.013375791736067304, 0.021102732655802564, 0.055375347935384324, 0.008184677496882937, 0.07744935942032645, 0.04551589211088516, 0.08716914592491043, 0.03189911592691656, 0.045697619657843344, 0.06474579068561716, 0.045398301444947727, 0.0331654439439937, 0.042044395325525154, 0.0779893288328763, 0.07562148129387249, 0.00867607789264331, 0.07935363183458967, 0.03428297087309822, 0.011173640396596204, 0.19050777258892215, 1.5922318711396188, 20.13119032306056, 46.484985582290165, 60.333548899619814, 58.219858138791984, 52.05073864229264, 43.017021994436945, 31.760808037173366, 29.447780463003344, 36.09633322684996, 40.07428338450771, 35.1382040977478, 14.45926654723383, 4.201276186973819, 0.6838076297313936, 0.11909136323318367, 0.1974781921073314, 2.9999130387460036, 4.8884548487201815, 9.673141433346657, 9.156484873064104, 10.339046139870922, 6.576577271184614, 4.99188922105297, 14.736291785393993, 28.691210169945997, 16.667343262703188, 18.631089656583725, 26.00251759252241, 39.25636722195534, 46.92895473972444, 59.32849645614625, 61.66957093823341, 64.02109461445963, 60.26416609364172, 61.19443854978008, 60.03636660114412, 60.5249801758797, 60.82894425238333, 61.667307730643984, 59.56500361042639, 57.35886258463706, 57.155981909844186, 52.91571540217246, 50.907328513360795, 49.67651620987923, 47.10546924221901, 45.24173544299218, 50.07135768090525, 54.10023589288035, 53.76076259920674, 51.27386616122339, 59.458985867038855, 61.01967734675254, 65.66082577551565, 58.13941424892795, 58.09296161897721, 47.265572547912605, 47.99773393138763, 60.832627357975134, 58.640104801424094, 58.45397264726701, 28.328292869752456, 51.09351165833012, 56.93877673918202, 59.25019025802613, 58.77538734866727, 58.836909724820046, 54.910440675673954, 56.41670142450641, 57.19235797082224, 60.979210253684755, 61.170041407308275, 61.54421198752619, 58.332959682710715, 49.5772723997793, 41.968921538322206, 45.9621532501713, 50.98210457832583, 58.07854298622378, 57.72989526871712, 59.39811068196451, 58.61151464523808, 58.5280034618993, 56.98539803105017, 58.50080574712446, 60.61097814190773, 61.15728978187808, 59.48173169166812, 59.54983580497004, 61.21524672354422, 60.056888441885675, 57.537200989261756, 60.41871140080114, 53.353742168795684, 42.96397978259672, 24.911102402594782, 27.997121272548554, 10.767568022974077, 11.946587389515294, 18.460401834980136, 5.114288743465178, 8.121062007642562, 7.445981896692707, 2.5249730915792528, 4.463862199937144, 2.032273755438866, 0.2499597654828141, 0.14289268082188022, 0.45591758564114576, 3.0894737426311742, 16.126148354622625, 34.61674459518925, 43.02787127033357, 34.9680712915236, 32.91133334559779, 28.998151325410415, 36.58385638267764, 48.5208761307501, 55.674894932777654, 40.452090001875355, 14.981685069299514, 1.1400339488060245, 0.04708564457213206, 0.05901103268467611, 0.029357395157398238, 0.05526490486978043, 0.056547018128537366, 0.09168672044911692, 0.03344114366618376, 0.007787773088972656, 0.027935365515370524, 0.04140519454414326, 0.0026118989720294674, 0.006270628843095995, 0.03948849618374821, 0.03344454126612794, 0.07005910839765303, 0.019577597155265754, 0.01872072972717785, 0.012192798763393395, 0.015519557599609178, 0.10452315181253419, 0.09338359754051893, 0.01592943762173696, 0.0702522851286396, 0.08602076480465551, 0.05345084696948048, 0.0034581836136508616, 0.03488457205915644, 0.03928247981915071, 0.01899561165050874, 0.04108659006775387, 0.022109173005446795, 0.022347487636931965, 0.03206286722073152, 0.036917872832066594, 0.03611919552748723, 0.07151919537253919, 0.010757727432064714, 0.05326512427399716, 0.022924606568149986, 0.03682789963579947, 0.0330845833635859, 0.00825252320106712, 0.010010230546486715, 0.016444580997490597, 0.022650318362960414, 0.04174880413038116, 0.031078735351442333, 0.0443843457727663, 0.011443174068605708, 0.024783384851029804, 0.023702796766414277, 0.036741764540033, 0.19727830444612812, 2.232791324776988, 23.365008023477372, 53.0715197901572, 67.81305774565666, 64.66188830714073, 55.9587097937061, 45.41042481699298, 35.40744343111592, 31.49656580340478, 36.950907861032796, 37.4130807384368, 36.43117812372024, 17.768850711084184, 4.951627071826689, 0.5238754374365653, 0.28062916090411527, 0.781318916668815, 4.484053090695412, 12.61933369021262, 12.92468628575725, 12.282127526498611, 15.571164354201287, 14.817818249425581, 13.040903172185345, 10.173340708978715, 9.875827950816001, 15.469669103622438, 22.247040348668254, 29.27499809572774, 39.434227097419004, 47.9979222051559, 58.3018905885758, 62.31547547924904, 63.489589921889774, 62.348776402012, 61.66544460481214, 61.1613808139678, 60.06998523589104, 62.181361798317205, 64.8964225092242, 62.12301654200401, 58.90935590190273, 61.27443528944447, 55.118334139547045, 55.01370491520051, 53.498948312574825, 50.39529054395614, 47.489959578360285, 53.038289470057336, 55.518988563168435, 55.87997997960737, 54.90449044012255, 60.36844622704291, 62.775855833484286, 67.45212908714049, 60.40370441252186, 60.1186030141769, 53.59617602440619, 53.96017589876729, 60.388132602937766, 58.803549966504505, 56.50740623474122, 32.454194830309966, 52.54951115577452, 55.661951111209014, 58.84942208566974, 61.4292904638475, 61.381770949209894, 57.242199528601866, 59.79012020172612, 60.404520265517704, 63.310094418064246, 61.44854145665323, 63.740143083756976, 61.41762925732521, 52.487325899062625, 44.12692331498669, 48.489438333818995, 52.96601195489207, 59.44025654946605, 60.586329967744895, 62.23278799364644, 59.35507835880403, 58.13924950938071, 56.76114043881817, 59.40389225559851, 62.061125463055035, 61.34177454056279, 61.809803516634055, 63.944435811811886, 68.26232602519374, 61.72196988136538, 59.987823347891535, 53.896480529539055, 44.878888745461744, 33.579465958379934, 20.631776932747137, 15.347471583274105, 15.957922800894707, 18.908275711920954, 16.21280037587689, 13.747675053534971, 8.042164512218969, 9.304789689279373, 7.545953306459612, 5.389696984521804, 1.356648067312856, 0.7191752738529636, 0.2822412244014202, 0.664251733931803, 2.7354173218050315, 18.902186232228434, 36.84159532670052, 39.54226878381545, 30.152732364593017, 31.207061544541393, 32.76564475028746, 42.955228974742276, 53.811031695335146, 61.24391532713368, 47.472006890081595, 17.871540323380504, 1.5222741927831405, 0.07820454591344442, 0.010498294629336847, 0.09688561526878227, 0.06325362377890176, 0.03145670398108421, 0.03859801473276269, 0.025384202712185444, 0.043456881427236145, 0.031430049866978685, 0.08297358879879599, 0.07294045701142281, 0.03420498312240647, 0.02765543507261863, 0.0804958765905711, 0.06745550496083114, 0.05461468008316813, 0.04829831962143222, 0.030705370910225377, 0.023609425970202973, 0.10667176797024666, 0.016806498169898987, 0.0415945370050688, 0.027394520847367185, 0.020367144607007504, 0.03866171111322699, 0.0888245853204881, 0.052945780522760846, 0.07277351113096361, 0.14246485135968656, 0.1848238598435156, 0.17971253653447475, 0.13790477427744097, 0.12797986007025167, 0.09083550483469041, 0.1206736488928718, 0.18806022892315544, 0.13096041707021575, 0.21584400096006934, 0.17559083028426095, 0.1338406165520991, 0.18485064227734843, 0.22315326116738782, 0.14065771123334286, 0.21372063506034114, 0.06718034150018808, 0.1171934723313297, 0.10345396886189138, 0.11227731758187856, 0.07887458939465784, 0.1528730904383044, 0.17400168813765052, 0.11444372996207207, 0.26233921007763955, 3.731287741853345, 29.771426993031657, 62.87953192187894, 76.12560349126016, 72.75251419313493, 65.61804840641638, 56.30547085115987, 45.846545311712454, 42.15079399847215, 48.78432604574388, 51.82427667802381, 43.3309292793274, 18.67311393060992, 5.550066521090846, 0.8172819030381019, 0.5887548721605732, 1.11417057533418, 7.525244662838598, 18.155645439701697, 24.351621404770885, 22.450156365671468, 21.217157340818837, 20.746055187717563, 14.399952465488067, 23.00967266482692, 39.14137509561355, 23.39769901767854, 25.291660562638317, 28.989059271350985, 40.68709096600933, 48.04036225042036, 61.91933570369598, 62.19951452747468, 63.65447067445325, 62.74985836398218, 61.76661429866668, 58.974812415338334, 62.407094201734, 64.38000717470723, 65.57551422426778, 65.0185808058708, 62.059289793814386, 65.40682092789682, 58.070121657463815, 56.82954657462336, 55.9267463991719, 52.54532990917083, 49.2728925520374, 54.37404870986939, 57.83546586190501, 59.52039841682681, 57.22017542008431, 64.70570902670583, 66.19300119338497, 71.29368274442612, 61.9742920321803, 59.22148635310512, 56.40616986059374, 55.83287623620803, 61.73974998535649, 58.297752488044004, 61.961356055352, 40.11666067184941, 53.86867876975767, 58.05297305507045, 60.351536889230054, 63.25182368678432, 63.01719142544655, 59.281314265343454, 61.03248780773532, 62.95906582186299, 65.37523408089915, 62.957065413075114, 64.65641660075035, 63.324481671856304, 54.66539452152868, 45.23592249039681, 50.13015400978827, 56.60071942114062, 64.22616004943848, 64.329742000949, 64.5022282292766, 60.054056490621264, 58.474784743401315, 56.503154385474424, 58.8788555514428, 63.46326689566336, 65.24021433245751, 66.35412431532338, 67.18168950849964, 68.546478209957, 62.771827559317316, 64.18135873733029, 65.00822574861589, 62.48826765245008, 47.516325750658595, 26.488632617458222, 37.19932333115609, 17.556819146679295, 20.98169549818962, 27.997187952841482, 15.820400580283135, 15.664103934841773, 18.843644857406616, 10.241246742586936, 9.351519826919803, 4.069325202895749, 0.32994515172416167, 0.6261544266054708, 0.84601191623557, 4.41476147982382, 19.965281909511937, 42.3144470491717, 54.48758171450708, 48.87969063174341, 43.641400567946896, 40.17208376238423, 50.52514453088084, 64.0445896117918, 69.4265482502599, 57.13059240771879, 23.7466860202051, 2.4497417865260958, 0.15030206872090218, 0.2091311402018032, 0.25318070555165895, 0.24173714460865145, 0.14760580694963857, 0.18629419707482864, 0.08995434284330377, 0.15610860149946906, 0.15368736529302213, 0.2278067396893617, 0.09921344237462168, 0.182282485728783, 0.13236107094393623, 0.1660920601458319, 0.16108527719493837, 0.10459623660051054, 0.24968319242039036, 0.16594195287794838, 0.14313766041830664, 0.20307031219765065, 0.08600669943036572, 0.06950028556128664, 0.12040380974330249, 0.16157796366080163, 0.21867529338886663, 0.20307086378095612, 0.10453475804458703], [0.014696287915050505, 0.10301756687582501, 0.023655672782971978, 0.13441942662241, 0.04302947714384045, 0.020495115764318936, 0.0021936999532514282, 0.02401150338682196, 0.03441683707698699, 0.06531553027490455, 0.023373488126502886, 0.023055071341654947, 0.06520025702493806, 0.04386381201085545, 0.06282952516489933, 0.023573295348474098, 0.07316731862843999, 0.05163670096906924, 0.0428652968407879, 0.07039459362145394, 0.04642345732258213, 0.022326129105603023, 0.018627876040315437, 0.06292317941364262, 0.06904238714806496, 0.050446242469573216, 3.999300599098206, 30.696880817413334, 53.34806257678617, 59.88571620756581, 49.83285796257758, 40.26566759232552, 35.746351903484715, 29.384214531990793, 21.226867168180405, 33.96235596749091, 48.81636788768154, 22.520682542554795, 12.808449787478294, 1.210090421861218, 0.16902130457662767, 0.08392273343258327, 1.0526220909049435, 3.685306286619556, 9.373742995723601, 6.797132145973944, 11.024259694160955, 15.726319589922506, 12.779561531159187, 7.4546346452928365, 6.9664010501677, 9.355645179748535, 21.353948039393273, 35.999046679466005, 45.75830767231603, 52.15616410778415, 55.427922894877774, 59.50785075464557, 61.0794738800295, 61.182844023550714, 59.83467048214328, 61.096944116776996, 59.801804942469445, 62.31971556140531, 58.91901277726697, 63.57723528339017, 56.42580916804653, 53.44098352616834, 52.3968917323697, 52.466396131823146, 49.384378079445135, 51.74261685340635, 47.071109279509514, 45.335232980789684, 47.49690217356528, 50.520920138205256, 50.951666985788655, 51.84844632302561, 58.49456525618031, 59.95936262992121, 61.729328247808645, 62.458092858714444, 56.02706101632888, 63.30450111819852, 54.74516768609324, 55.852903858307876, 55.873088375214614, 56.0380946436236, 28.553544782823135, 48.301780377664876, 55.59654166621547, 58.842526558906805, 60.86486924079157, 56.375842094421394, 50.79290120832382, 51.71231262145504, 57.09823285379718, 60.39265117337627, 61.391341532430346, 60.9621165644738, 60.30617467818722, 48.30861706887522, 43.31644004391086, 47.342807938975675, 49.36096152951641, 54.06649958702826, 55.54142059818391, 58.98597548084875, 59.139308775624926, 57.52375118194088, 56.88635426182901, 58.8640211474511, 60.543152516888036, 62.99565369083036, 64.30829055847661, 63.00558513210666, 58.501864787070986, 56.25572343026438, 53.988118863874874, 49.3953214922259, 44.092112279707386, 42.14530660260109, 35.90381153168217, 23.672686584534187, 15.735224350806206, 28.966083988066647, 12.050726317590284, 18.65851094645839, 11.67943867944902, 7.409751453707296, 3.717067679089885, 2.0799774989005058, 3.5251769952235685, 1.2339776562106226, 0.17620365465840987, 0.14383999450552848, 0.6869042796954032, 6.4087027695871175, 21.91975582030512, 51.21058264086324, 47.52761825438469, 32.04783728045802, 29.140023454543087, 28.189319372177128, 47.78226244834162, 54.57916905803066, 50.48969414926345, 21.647994402916204, 2.317948187551191, 0.05459915531138259, 0.02829827477164086, 0.034012848270996925, 0.023643377071787274, 0.03893863274565628, 0.05015996690358847, 0.08250428333638177, 0.08523842049462181, 0.055594414607771946, 0.005037516483195848, 0.0686301322533719, 0.03720064354579776, 0.037382087640223965, 0.009559921191764936, 0.02056972506726461, 0.027585175233863057, 0.04208742265379237, 0.10556536846824231, 0.039278572770736875, 0.013177419971344213, 0.052737684229448925, 0.030340720719147115, 0.09649779857887376, 0.022996387091435255, 0.032764756976957285, 0.03015772912711386, 0.06772592633722291, 0.031444504030890046, 0.08556843585064335, 0.027019605078103564, 0.1430625378364517, 0.05486965329656678, 0.1126117532652232, 0.0222044590214688, 0.03738503324829283, 0.04302841994250494, 0.02788889079144405, 0.02951129264528713, 0.056949160662629915, 0.029404940489198894, 0.06453837238011823, 0.03523133409720275, 0.01019110486301924, 0.06395510367808804, 0.09058988938528685, 0.0676134952734555, 0.09338886822543799, 0.05669676916553609, 0.003738556950983982, 0.03110147475625479, 0.01534568245387486, 0.02668095208073576, 0.08291188807737443, 4.43955478168303, 35.84016715326617, 58.98336318231399, 67.8987144654797, 55.874531807438025, 46.025201428321104, 43.39459326959426, 31.81735096439239, 23.506103523315925, 31.903590156186013, 47.91086912155152, 25.48636897917717, 12.261116370078057, 1.3989963046004696, 0.2705010495358898, 0.3765021228501874, 2.800312936306, 5.883748435205029, 8.838288476390224, 9.662216651824213, 10.99273560508605, 19.252059690413937, 15.97189820581867, 16.88151840240725, 11.398620509332227, 9.391384836166136, 17.798870571198, 29.856401220444713, 41.30403664804275, 50.242039618953584, 57.54942701708887, 60.58967574950188, 62.556320774939756, 62.62660964842766, 59.796596034880615, 59.30000435921454, 60.29922031587171, 62.989621085505334, 61.62846842119771, 63.87763392540717, 59.843684088799264, 55.731035817054014, 53.718789315992794, 55.39373551645587, 52.24783774345152, 53.27256087333926, 48.59148271622197, 46.91866244039228, 48.661481334317116, 52.685990025920255, 53.34925889968873, 53.95285675602575, 60.15208828833796, 61.38253973376367, 62.91974013851535, 63.56848839790591, 58.08447753229449, 62.684076293822265, 57.48957164825932, 56.78755367955854, 56.07432557690529, 55.21933124911401, 34.15967079900926, 51.345457261608495, 54.107001981427594, 58.6667965304467, 61.51693190297773, 60.25292850309803, 52.54182331023678, 53.80512460585564, 58.438200796804125, 61.2558550219382, 61.183306863231046, 62.60560927852508, 61.7603777300927, 49.469917128163004, 44.15893770033314, 47.43636431232576, 51.579873792586795, 56.61643635842108, 59.23254743699105, 62.13033960711572, 61.007396405743016, 57.47119534400202, 56.96189518897765, 57.26641624204574, 60.45075324273879, 63.86378011395855, 65.12637146057622, 63.524867719219586, 60.58563178585422, 62.2406719576928, 58.482896204917665, 52.589201619548184, 47.25483702075097, 38.49884379294611, 30.534408400135657, 19.7402790669472, 14.500736786473183, 15.206970322516659, 11.316339969635012, 11.707335556707076, 12.347906654880894, 15.086703588885648, 7.303252729677386, 6.794542401067673, 4.031269632039532, 1.2107416578838903, 0.15143400959430203, 0.16172420984554678, 0.9316065522932238, 7.3004678468550415, 21.917706381890085, 50.105027306464414, 51.69745076087214, 34.574775234345466, 33.62740516662598, 34.00853010915941, 52.892600874747004, 61.88975711022655, 55.26976116241948, 25.207543373107914, 3.1012281054450623, 0.07465434125474385, 0.040370543006687395, 0.05251837240892553, 0.03755995410404379, 0.0399581004204529, 0.05904776277020574, 0.08871819102956403, 0.02449094802291403, 0.05666034551517618, 0.023693109584611752, 0.005380012847918777, 0.011467422666628996, 0.07905776867823255, 0.042373928046154405, 0.028973519989860155, 0.018225944180402066, 0.007723525604007827, 0.0402028272078643, 0.01944656739191663, 0.07719092731994968, 0.053017164595545306, 0.04934783326461912, 0.04056920109677219, 0.045743182737139926, 0.03225743823174027, 0.028707969017447005, 0.07789457141752205, 0.08865714914375737, 0.15666404588808938, 0.09452883003940506, 0.2937777118096429, 0.1032707742565582, 0.24323489246589525, 0.11749836000343485, 0.09238569907123044, 0.12553466829441248, 0.15064501564108557, 0.08327089220045075, 0.09447403177018128, 0.15541759019176807, 0.23436894159643884, 0.21439227966531632, 0.11851960117177618, 0.1771812441368257, 0.21717509405026514, 0.2785185273856886, 0.19297106702241207, 0.15051128733302319, 0.09091559166629469, 0.10937733004891104, 0.15694982732736296, 0.15703135440426488, 0.2639181479330986, 7.175691858414681, 41.831897458722516, 68.66124676119897, 74.86348675143334, 61.89739004258187, 53.621859704294515, 46.625367210757354, 41.004853940779164, 32.80536855420759, 45.21232158906999, 62.788054404720185, 29.038249715682003, 16.471569922662553, 1.6672851986462072, 0.3305480629205704, 0.5027535659891944, 4.291019035923866, 7.762130325840366, 15.96078024756524, 20.916288014381163, 25.448612243898456, 30.830221791421216, 17.770282376197077, 19.625310474826446, 13.581166517349983, 13.552828373447543, 27.76702327112998, 38.409374529315585, 46.49567011863955, 56.440341549534956, 58.28417716487762, 61.977677037639005, 62.18875154372185, 64.00962952644595, 59.71657576099519, 61.89096912260979, 63.22800705509802, 68.3390946542063, 62.38111242171257, 67.6846315014747, 62.01757930940198, 58.70522399102488, 56.54832047800864, 58.111820374765706, 53.68247993530766, 56.83107237662039, 50.48992164673344, 50.51679772715415, 50.82457434746527, 55.359246115530695, 56.08959144161594, 56.08949730473181, 63.139157525954715, 62.64804932378954, 65.66475206805815, 66.24779670469223, 58.466940003056685, 62.99280605008526, 56.435599403996626, 58.2557439034985, 56.99978136247205, 56.08177415786251, 40.39651393890381, 53.62671559856784, 55.17369447215911, 62.51452007601338, 65.95239516227477, 62.44352909826464, 55.033293231841064, 56.39310444554975, 61.7157333127914, 64.03734891645371, 64.26505427206716, 66.74122302762925, 64.77269134213849, 51.49446025971444, 45.775264078570956, 51.79860084287582, 55.33286817612187, 60.78278580019551, 60.04891818569553, 63.97011949170021, 63.0373877094638, 56.947837414280066, 55.9203411686805, 60.16463202814902, 61.74180138495661, 67.30673466959308, 67.4864419814079, 68.87676531268706, 65.11852672023159, 62.81307912641957, 60.40699135872626, 54.43757149481005, 51.50561940285468, 45.43133105001142, 41.364586276392785, 26.98442020723897, 20.928580722501202, 43.10493799947923, 22.631565986141084, 27.029492162889053, 25.78733244249898, 16.191623499316556, 16.604932469706384, 14.247999845012544, 6.021482954102178, 2.9003676964390666, 0.4608424584711752, 0.37774680122252435, 1.2318550410770601, 8.427030905600517, 28.96577608200812, 62.86586246182842, 59.06727836978052, 42.03135390435496, 39.99023875882549, 39.31296702354185, 62.30870154596145, 67.9592993951613, 66.00267994788386, 30.707751666345906, 5.214519519959727, 0.20395273823411236, 0.2533918393835906, 0.2409205561684024, 0.11990403696413963, 0.1887012146894009, 0.12832088410974513, 0.2362417048143764, 0.24182147556735625, 0.14158904432289063, 0.20973824956003698, 0.0919151372246204, 0.1043727457703602, 0.15746365781993638, 0.07395085037475632, 0.08392740656892139, 0.17837054967399568, 0.13724871190084567, 0.22832893586206823, 0.1061964410567476, 0.2281299675063741, 0.15321873398798128, 0.27021226503195306, 0.1639134439850046, 0.16721474667710645, 0.08889822935264918, 0.14588069951822683, 0.16414584441771432], [0.026473190950890704, 0.044338108536096356, 0.05150214911648824, 0.11501656454657355, 0.05034718347052413, 0.0283603853501019, 0.08487679635084446, 0.20146341213295538, 0.03152160311958963, 0.04749819058023634, 0.026340899057686332, 0.05724478633173051, 0.04807790846473748, 0.008540696749884275, 0.04218317598344819, 0.022645135778152657, 0.058497876349476084, 0.03145523692270921, 0.008754697665872594, 0.11916729020735911, 0.09281211893164343, 0.03474109911269719, 0.09617984910765964, 0.06268463495578017, 0.0514473585081437, 0.18052670413688307, 4.750048623931024, 29.360291996309837, 52.6738424454966, 60.80200933641004, 53.069366408932595, 35.75369065807712, 16.717800632599864, 22.35328951189595, 25.337009045385546, 41.44227666239585, 32.1897937405494, 19.78370951068017, 4.364988073225945, 0.40507392356953315, 0.24513829920080402, 0.30547296327929346, 1.5103771537542345, 4.836565323414342, 12.936876031660265, 8.715391793558675, 7.749582173362856, 12.79570600678844, 18.66854633054426, 22.664209911900183, 12.440879575667843, 10.063863435099202, 25.008151646583315, 38.62410468439902, 47.99589041740664, 56.325529852221095, 58.97826410108998, 59.770516195604884, 61.687041174980905, 61.56183911908058, 57.781141035018436, 56.19649956303259, 61.57034673998433, 58.11548779087683, 59.47552650205551, 54.73858202657392, 53.0762658580657, 50.26702119458107, 50.66396897838962, 49.03943700175132, 51.53069903773647, 51.16419276883526, 49.239575939793745, 45.78633300719723, 47.26499595949727, 48.014356936177904, 48.52100949133597, 46.90830346076719, 52.29933454144386, 57.79461829893051, 59.789912316106985, 59.926673596905125, 60.463920639407256, 57.47343893974059, 55.15573393914008, 58.49824836177211, 55.40032509834536, 55.10218574154762, 36.18926986571282, 54.25243562267673, 58.51396529905258, 60.69813320713659, 58.63754349370157, 56.87724651828889, 51.383731749749955, 45.182782219302275, 48.63920619410854, 55.909405600640085, 60.980135933045425, 58.2953872988301, 52.21104198886503, 41.979653143113666, 44.20914796090896, 44.672454403292754, 49.130290862052675, 49.98365740622244, 53.68513930228449, 55.8815489276763, 57.87687040144398, 57.44916339074412, 54.96054503225512, 52.89993178459906, 55.69337321865944, 54.87352332761211, 58.38181280320691, 58.96994475395449, 65.65468334382581, 65.62128043943837, 65.3849458694458, 63.594599616143014, 59.161846714635054, 45.04230253158077, 34.93375447488601, 23.62772249406384, 33.371415599699944, 16.73738306568515, 8.502059963441665, 11.618828254361308, 4.944153976055884, 11.58782191814915, 6.7477014564698745, 3.053279826717992, 1.1158519238233566, 2.325303367068691, 0.5023650368375163, 0.34111584747029894, 0.2786185171815657, 6.728013609686206, 26.816317227578935, 44.53677569666217, 29.99104638253489, 27.15285266599348, 25.03681044424734, 25.439877125524706, 35.07341438724149, 55.4088915548017, 56.08607699794155, 28.65923893067145, 5.560975122836329, 0.2606137655675411, 0.031265183915233904, 0.0071614071531521705, 0.008977157150154874, 0.011283070310920237, 0.08238347127072274, 0.036847335286438465, 0.03870510233325824, 0.06238300698779284, 0.0231761017423724, 0.0710174843909279, 0.028069256617116834, 0.14580476488317215, 0.05954697630518387, 0.038118056817761356, 0.0077224827668208994, 0.08108526633511629, 0.061706405793947566, 0.06016650394867024, 0.07472341174199697, 0.016987392596239527, 0.06424625156327121, 0.048595362553192724, 0.041506413911138816, 0.01141870138986457, 0.04629766185497565, 0.019860337225479946, 0.02520238898033577, 0.042599088947979674, 0.019466388001737576, 0.0743258810572086, 0.022997530477662242, 0.04862492588619071, 0.03456037131048018, 0.0547300222810478, 0.028704521621787743, 0.026632891554806023, 0.043836389893605825, 0.03644834903459396, 0.029260766572288932, 0.06109541620037729, 0.05492462010513391, 0.03710960165687627, 0.017374615568006714, 0.060483905667018514, 0.07138064837143307, 0.06271087346718678, 0.051534753818545616, 0.10025552879538267, 0.046567910861584454, 0.017468549438842365, 0.050950106158251726, 0.2312170107278132, 6.552688075650123, 35.886231468569854, 60.256191915081395, 68.66695773216986, 58.95710291401033, 43.139945153267156, 24.616697142201087, 27.979223497452278, 25.90591157636335, 44.116250545747825, 34.3464619113553, 18.210958703871697, 5.090280896232975, 0.6190084810218504, 0.26063037435373954, 1.5242905361998467, 2.5999062964993143, 6.3059077435924165, 9.63206539230962, 14.801325663443535, 12.477345851159866, 18.256175787218158, 22.724071164284986, 19.07303487100909, 14.683974231443099, 13.50863895108623, 30.75383951587062, 36.315087733730195, 47.023005331716234, 55.811687592537176, 59.955589309815444, 58.59760592060705, 62.50121147401872, 60.692838007403964, 59.62206625169324, 57.78920935046289, 62.608609891706905, 60.281416677659564, 61.43640172096991, 57.98323331340667, 55.6246336813896, 52.7810251328253, 53.84261461996264, 51.523219077817856, 53.39801396093061, 52.20735103853288, 51.88014691875827, 47.73102844915083, 49.58012004052439, 49.65175036461123, 51.05774748709894, 49.41139928756222, 54.50569914233301, 60.71238710034279, 61.66327161173667, 61.53638293666225, 61.43834329420521, 58.90732803652364, 58.10765874001288, 56.216009432269686, 54.33624490614861, 55.40402781578803, 40.4746122514048, 56.019279033907004, 57.97068957359561, 61.66348734209615, 61.17324990610923, 58.4379772217043, 53.969542518738784, 46.79128346904632, 52.24211500537012, 57.72313702491022, 62.93175435835316, 62.78269644706481, 55.75621743356028, 45.20056232329338, 45.831016648200254, 47.96639027134065, 52.1558463958002, 52.10920156971101, 57.24937746601721, 57.93685128611904, 60.011588988765595, 58.44818322889267, 55.784784055525265, 54.680185779448486, 56.16553245052215, 57.23958330769693, 59.85783207801081, 61.19086919292327, 66.32051744768697, 63.768776386014885, 66.41306969427293, 63.00467121985651, 56.55952668959095, 44.301770810158025, 32.59178373121446, 23.890599743012462, 17.183860578844627, 14.985943782714108, 14.305201730420514, 13.292281992973821, 13.388886047947793, 17.548195815855458, 9.694764479514092, 10.001434991436621, 5.540061535373812, 2.4303086486554917, 0.5634283118190304, 0.4576582293356619, 0.24844629750136407, 4.934736855568425, 25.26754386963383, 49.190832645662375, 39.132789027306345, 32.38637312766045, 31.557750855722738, 30.370147382059407, 42.237752945192405, 61.703013066322576, 62.36427368656282, 33.33533763885498, 7.405593251028369, 0.45803208024271075, 0.04304196437700622, 0.05593875963841716, 0.021862201580417254, 0.013051929981297544, 0.05573236022985751, 0.06191203911458293, 0.09575579645893267, 0.025437441992483316, 0.009488665438707798, 0.05365478340536357, 0.027671589951721892, 0.025622389023943294, 0.026209130019490278, 0.08322053724118779, 0.016752686238877715, 0.02122235920039877, 0.015010014326582033, 0.02916988556183154, 0.036307978744228045, 0.003815094880279034, 0.008082387522013198, 0.09235648047779837, 0.015189094082151931, 0.05904513508862546, 0.07397679011187247, 0.040361572117094076, 0.134308175334046, 0.2672613862781756, 0.13269453369561704, 0.26358238691764496, 0.19040484101541583, 0.11509375556582406, 0.18768660784248384, 0.3273508409338613, 0.11241096928114853, 0.12632733946966548, 0.08234228638391342, 0.12657791150793915, 0.14427645011774956, 0.1358804022592883, 0.13557687822368839, 0.14039183275834208, 0.09858090655818101, 0.11561667952205866, 0.11808705260796894, 0.16842741789596696, 0.12927254151192405, 0.18937691956037478, 0.18048896664573302, 0.10825578498864367, 0.2726347269790788, 0.4946224006914324, 9.754280563323729, 40.976503049173665, 69.51490356076148, 73.71966869600358, 65.85755225150817, 46.706446524589296, 27.60537062921832, 32.84307822104424, 36.67681263339135, 55.29904950049616, 41.141807417715754, 24.20387552630517, 5.1685674825022305, 0.5821881503347428, 0.5980306647477612, 1.6572836450030728, 4.374642006812557, 11.737029860096595, 25.76609673038606, 15.743284821510317, 16.72911470936191, 26.804850178380168, 34.10549109981906, 33.50506251858127, 17.44048753092366, 14.958618590908667, 31.39231901015005, 41.76644486765708, 48.82862137209985, 56.693824721920876, 60.35985231399537, 58.68275665467786, 62.97685769296462, 59.59792406328263, 58.27617160735592, 59.15867743953582, 64.9668368985576, 64.66677558037543, 64.60971686147874, 61.07414730133549, 59.71356338070285, 55.1511683002595, 56.345227995226466, 53.93651223951771, 56.4671705615136, 55.528806255709746, 53.127076241277884, 50.44146468562465, 52.14589534267303, 52.53513959146316, 52.817899334815245, 51.63791702639673, 56.24900833252938, 62.013205866659845, 65.20407753605997, 66.16781957687871, 64.7705065819525, 60.18128641190068, 58.624717343238096, 58.46284897096696, 56.04934792364798, 56.9608675279925, 44.657247374134684, 58.71246076399281, 57.3350263410999, 64.4241338391458, 64.80110891403692, 62.17634116449664, 56.793146979424264, 49.00227254436862, 54.26647378552345, 60.08771827144008, 66.35840754355154, 64.8289224409288, 57.25342535203504, 45.60969298885715, 49.02994878830449, 50.038550976784, 55.541361762631325, 55.14872074127198, 60.67287706559705, 60.227056549441436, 61.6825226045424, 61.647715491633264, 55.615631841844134, 53.4017990481469, 57.13048258135396, 57.73337441105997, 62.897229656096435, 61.58200010176628, 69.51390727873772, 67.01210975646973, 71.4354528919343, 67.4719762802124, 62.85434246063233, 51.76917914421328, 40.49866422530144, 32.42489080275259, 42.26844941416095, 22.036136465687907, 16.29197145662, 20.952799397130168, 13.45764421647595, 22.52092965187565, 16.419720111354707, 16.75269796002296, 6.042116092097375, 5.116405352469414, 0.8954498988966789, 0.7722108054064936, 0.422156397253275, 8.396940442823595, 31.09853740661375, 49.74278073157034, 42.20756246197609, 40.01056448105843, 36.714973372797814, 37.15012504208473, 48.064484826980106, 69.03774722929924, 71.16720199584961, 43.180082767240464, 9.891928299780815, 0.8649383941965719, 0.19803553639400392, 0.1516403017505523, 0.1540315226321259, 0.09184602843297106, 0.20871186028084449, 0.14043105646006523, 0.16883434847958628, 0.13470586689729847, 0.08516617074248292, 0.27190234692346665, 0.0793849571698135, 0.2688354211709192, 0.13771369662736693, 0.22120718333509662, 0.10885813694086768, 0.11202957240804551, 0.12320315630565729, 0.18997368673163076, 0.23969702182277558, 0.11094396453230612, 0.20713978657318702, 0.1667127599038424, 0.09915580191919882, 0.15787996531974885, 0.10829397447166905, 0.13961685821413994], [0.015110544214445739, 0.046672707859186396, 0.06442019565691871, 0.043729474662893245, 0.03934613406477917, 0.03398783550026917, 0.05550668604912297, 0.017085013265210777, 0.0855474527023973, 0.07882040399577349, 0.06155740169267501, 0.014642796783347525, 0.03178300189545318, 0.0322959226586165, 0.0772136954530593, 0.05165122982655322, 0.03102415158683735, 0.03554061911399326, 0.056384979041233185, 0.047633554486017075, 0.06051711557853607, 0.012463888551499094, 0.013808292419379278, 0.06862003521452989, 0.02969904355854998, 1.3307439992504737, 10.722881440193424, 40.658124262286776, 59.85849103619976, 56.916999739985314, 47.409445085833156, 30.979109079607074, 24.742685633320963, 16.20548221372789, 31.326431035995487, 30.99207643539675, 33.47136151406073, 11.150510984082377, 1.7071624652993296, 0.13883175598757883, 0.1147071646165944, 1.5469919890165331, 2.840970999771549, 4.861330188089802, 3.259583014634348, 9.34231794649555, 9.426326290253671, 18.078696381661203, 20.391667081463723, 22.340551614761356, 22.27973722642468, 19.284015240207797, 35.35430708239156, 40.073436152550485, 51.33745562645697, 57.214993969086684, 61.64016100668139, 58.625376301427046, 60.79758882522584, 56.78325868421986, 58.08746245599563, 59.90678325776131, 60.04010854228851, 57.25406469837312, 55.426048001935406, 52.96848304810063, 47.82718927629533, 44.93690452268047, 50.70920567358694, 51.54927538287256, 51.90218279438635, 51.90453229411956, 50.717462262799664, 44.296867847442634, 46.557663179213, 45.491708094073886, 46.693216369998076, 47.019812522395966, 46.234361817759854, 48.863385338937086, 55.993340399957475, 57.24531389051869, 61.29081902965423, 59.869697247782064, 57.42797866944344, 57.29880325255856, 59.67988591040335, 50.070118211930804, 25.824296859002885, 44.74479859875095, 56.4127359082622, 61.8726908776068, 58.664101862138324, 56.56491210383754, 50.69928207705098, 48.03226255601453, 44.57585034831878, 45.316389914481874, 48.23508047288465, 46.963906980329945, 43.99176628358903, 44.06510676107099, 47.89195545258061, 45.86703577349263, 47.19304007868613, 49.454796391148726, 51.59837953505978, 55.15956217242826, 56.89183381295974, 58.24021131761613, 54.116713769974254, 52.99102490948093, 54.81473092109927, 53.66223266047817, 54.55921203859391, 55.89643824485041, 61.39414994947372, 63.81030644139936, 63.756354239679155, 55.834186307845584, 51.77185812304097, 45.44592226705244, 31.666531908896665, 28.391488136783725, 21.35903927587694, 12.900242074843376, 11.61958723298965, 8.71709410221346, 12.034950544757228, 20.529899251076486, 5.294533910289888, 6.254363877158012, 7.597394210676994, 0.7613497623993505, 0.3854570778146867, 0.06581997619040551, 0.2751516016019929, 1.5035202378226866, 10.178936950622067, 23.26091616384445, 33.046655116542695, 29.07063476500973, 18.7595159007657, 16.288229515475614, 28.317639712364446, 44.95643008139826, 48.16995736091368, 38.34733440030006, 8.282751421774588, 0.8105152016205173, 0.22502798557041154, 0.028381860709839293, 0.09061730767209684, 0.01138296434580679, 0.08826512663114457, 0.01581419884572707, 0.09748072002924259, 0.024248575040649985, 0.04307919241968663, 0.06267531166574167, 0.06525682495726694, 0.09008529025220102, 0.025997130508204142, 0.013596855025107582, 0.02883277623163116, 0.019441135828533483, 0.018385319196949565, 0.03444708988911683, 0.054685508742207484, 0.03793260225305154, 0.06220878710249259, 0.08147946453743404, 0.042491112685491966, 0.013187220151115571, 0.02711511900528304, 0.0148226416692318, 0.04745888643928113, 0.05936458226173155, 0.05236467218867714, 0.05272437345176455, 0.04119095039523898, 0.02321741111846941, 0.016033952124416828, 0.025993221544570504, 0.032061986219618595, 0.019816488267913945, 0.004468423759399523, 0.021640095454190048, 0.008591214502831141, 0.04527174371985659, 0.05336084312969639, 0.008290747158049096, 0.1277717216421039, 0.03856780022502907, 0.030769638026193268, 0.026653796179039825, 0.004029566461535832, 0.0023136954170636715, 0.036212110501383586, 0.03311175650226013, 0.05510394213600986, 1.5197644887431976, 12.494746465836803, 46.10620621711978, 66.86462863799065, 62.91474303891582, 52.166581922961825, 33.99691597107918, 25.56003305219835, 19.128707032049856, 30.968004849649247, 32.77510550714309, 31.490019367587184, 12.448316389514554, 1.973527436775546, 0.0802941733009873, 0.23433544823238928, 2.059433594826729, 7.003905282866571, 8.993150514941062, 8.048070621105934, 17.612036312780074, 12.988780756150524, 10.941857560988396, 16.3187426136386, 22.948560176357148, 17.538350666722945, 19.823817706877186, 37.2511496082429, 40.202313469302275, 51.27842787773379, 57.50325287542036, 60.56444706455354, 58.09836272270449, 59.65547700082103, 57.912716942448775, 58.14228542389409, 61.048200822645626, 61.144047860176336, 59.46692082189745, 58.61948097905805, 55.153439352589274, 51.23257537041941, 48.34511080095845, 52.50891462449105, 52.8576486341415, 53.92862043073101, 54.00425941713395, 52.38236719562162, 46.55658844978579, 47.37515964815694, 46.16799923681444, 49.86766899785688, 48.2686794957807, 48.43849851239113, 50.49595817442864, 58.15319745771347, 59.96668177266275, 62.51398663366995, 60.09584934480729, 56.36148229722054, 56.66440694562851, 59.1124483846849, 52.50074040505194, 30.584144053920625, 47.19740959905809, 56.35746579016409, 63.22538298945274, 60.70523661951865, 57.72684366472306, 53.39906515613679, 50.694410493296964, 47.74722391559232, 47.049493097489886, 51.3072023853179, 49.5336046526509, 46.586182732735914, 45.56993192242038, 49.38215409555743, 48.164328759716405, 50.12576879993562, 50.91121950457173, 53.92809875549809, 58.43993840679046, 59.01800163330571, 60.08929114187918, 55.511104599122085, 54.06829995493735, 54.392962378840295, 56.842188373688735, 57.06424551625406, 58.97629899363364, 62.783504455320305, 66.80671876476657, 63.05063747590589, 58.20063460257746, 54.89530817154915, 49.167463164175714, 34.38480700215986, 29.821095966523696, 15.990896205748282, 13.131525612646534, 8.811978197866871, 9.20976144652213, 14.481138663907206, 12.885541031437537, 10.721178150946095, 10.145067284184119, 6.696828315334936, 2.463350940135218, 0.5256338850144417, 0.1650484185665846, 0.3970307358089955, 2.046235554641293, 12.280687036052829, 28.032097047375096, 34.917468793930546, 29.94691383454108, 19.179880234502978, 19.27883182802508, 32.61889907621568, 48.99911503637991, 56.95884358498358, 43.534767012442316, 10.335878825956776, 1.0799999895595735, 0.19606655253277672, 0.07718924192651626, 0.07903956642915165, 0.027808284935271068, 0.1361982368173138, 0.07141178218467582, 0.044852739590550625, 0.03671105973602783, 0.025763031275522326, 0.04519207440617104, 0.07249454787421612, 0.04494466248058504, 0.010166285529492364, 0.028938094169021617, 0.02742599556973625, 0.03376353261691909, 0.040140475311707106, 0.003656087346532713, 0.033866988960653543, 0.02651810860111108, 0.02043978697920759, 0.01531276940142796, 0.022566544733220534, 0.014395393476250672, 0.02128157779694565, 0.023700691939842318, 0.14741897342666505, 0.1434233805705463, 0.22061701984174792, 0.1542485246975576, 0.15074992372143656, 0.09949459664283261, 0.13464528466424636, 0.0878089136113563, 0.15881192660139454, 0.22961689820212705, 0.10184957390470852, 0.12926629023446193, 0.18465613255337363, 0.2793456265522588, 0.16593092121183872, 0.08422014408654745, 0.21349007323864969, 0.21539456781841096, 0.11932771667958268, 0.10494730405269131, 0.1399726294461758, 0.12372934379644933, 0.08648878323935694, 0.12611971432042698, 0.16061957234576826, 2.3050163782412008, 18.30035932602421, 56.04902628929385, 74.28962830574282, 70.38875272197109, 59.14245059413295, 42.20128274733021, 35.77941356166717, 26.71057797247364, 43.253635052711736, 41.222070878551854, 41.426002748550914, 13.488752534312587, 2.558249499528639, 0.250958085300461, 0.4464276255138459, 2.4594457303324053, 8.59352179111973, 14.9369220003005, 12.565826677506971, 26.687110431732673, 18.09111264444167, 30.31140204398863, 31.150297003407633, 34.000995236058394, 30.645503651711252, 22.2236277211097, 38.54527681104599, 42.59088393180601, 52.288669616945334, 59.406233910591375, 61.372800488625806, 59.10590587123748, 59.79635284792993, 58.22665952867078, 60.267225542376124, 63.09525835898615, 65.55491393612277, 62.01156239355765, 60.005434789965236, 58.59162822846444, 52.63194760968609, 49.41490980886644, 54.841355969828946, 57.104759677763916, 56.974917457949736, 58.44967372955815, 56.574161052703865, 49.205988684008204, 51.03947316446612, 49.09495422917028, 52.51408430837816, 51.99386035242389, 50.66603606747043, 52.70049495081748, 60.23563085063812, 61.64157305994342, 63.95781109409948, 61.004540920257575, 56.53272513420352, 58.436043493209354, 59.81634516869823, 53.11587395206575, 32.0399062479696, 49.997770094102435, 56.719371118853175, 65.5894386383795, 64.42988011144823, 61.4533777390757, 55.941957350700136, 53.09124538975378, 49.56539938526769, 49.90625335324196, 52.33282766034527, 52.226503972084295, 48.33632861414264, 48.86604862828409, 51.31818109943021, 50.36073838510821, 53.394887831903276, 54.493280918367454, 57.43977715892177, 60.170452825484745, 62.7002796050041, 61.33595374322707, 55.28448181767618, 53.35098866493472, 55.12958741957142, 56.17606793680499, 57.20179127108667, 61.76658291970531, 67.44948540964435, 69.65215513783117, 66.35595213982367, 60.6399134666689, 57.942170020072695, 53.73478866392567, 44.2469713764806, 40.14296408622496, 27.87353719434431, 23.214720449139996, 21.49494940234769, 17.161299105613463, 28.332611399312174, 34.106271651483354, 13.774617814248609, 13.613863395106408, 14.646390080451967, 3.362272381782532, 0.8242642122410959, 0.31526080903507053, 0.6208920154360034, 2.1354390776926473, 12.015362228116683, 32.86822845858912, 46.33018139869937, 39.877572597995886, 28.74848658038724, 25.988679470554477, 41.1173043712493, 58.0163969532136, 62.678106446419996, 53.011868384576616, 15.194007869689697, 1.5869716050163394, 0.36404761696054094, 0.1521635704463528, 0.21764326570255144, 0.12198588855925108, 0.2815063622209334, 0.19570831449762469, 0.15304264101770618, 0.11265965674312846, 0.09756243862812558, 0.19373694044207374, 0.12454831477014289, 0.1913850505145327, 0.2326276390663078, 0.09980814110848213, 0.15636764647018525, 0.13428943682341807, 0.14224135286865697, 0.1316149472709625, 0.170849067789893, 0.10723873432124816, 0.11428837499190724, 0.13388423759850765, 0.13676077518011295, 0.07799676754662106, 0.11359627583935378, 0.15419224787863994], [0.023194941759650266, 0.023160958099329186, 0.06700684556797629, 0.06676012695196175, 0.03385782654907915, 0.0748094510767729, 0.06800495088100433, 0.05912808708906655, 0.05218928401929237, 0.05189168184334713, 0.08895174825503942, 0.13063482970239657, 0.0674627291699571, 0.039410125389094317, 0.06513306345309942, 0.015449165610686667, 0.0676585948695579, 0.01831748594169415, 0.04005045231972491, 0.07041809719897087, 0.05899182302997478, 0.04505145513722974, 0.0971019814812368, 0.0570325225201105, 0.050997220565594976, 2.496317480840991, 16.641955721762873, 44.668885046435946, 58.05413799901163, 56.86589125664004, 49.26138431795182, 38.91848641057169, 26.662483830605787, 32.921162805249615, 61.312847060541955, 52.74084829515027, 18.19996233909361, 5.33836345518789, 0.4767010300870865, 0.09031272643516142, 0.3157037304293725, 2.444045034147078, 6.343366378738034, 5.644590739280948, 9.353485914968676, 16.773102129659346, 15.533039896718918, 7.959118129745607, 18.024340175813247, 22.524134228306433, 21.77607547852301, 26.649345851713612, 43.61623856329149, 44.11406578556184, 55.257233112089104, 60.45762131291052, 59.947956377460116, 60.09388815972113, 56.02892021979056, 55.66704234769268, 62.005612158006244, 56.72771400020969, 58.61342876188217, 54.61059116548108, 53.092649598275464, 46.81706520818895, 45.50109824826641, 46.17980164866294, 50.64117216294812, 53.174050546461544, 54.031013904079316, 53.24721059491558, 50.828386891272764, 46.068790728046054, 46.2345540138983, 43.96287802726992, 46.02249891527238, 51.82133490039457, 51.59368445796352, 53.50729511630151, 53.83249490491806, 56.103158920041984, 57.68754151559646, 56.749141908461056, 55.90252576335784, 57.31594793258175, 54.12979487449893, 45.155776700665875, 29.959210465031287, 38.401906336507494, 58.073098736424605, 56.90140831855036, 57.76275296365061, 56.228459035196614, 50.3298536423714, 49.174590110778816, 50.0985122496082, 44.25791871163153, 44.48998966524678, 43.47848100046958, 43.82044499920261, 43.04276058750768, 46.42600490200905, 44.25943666888822, 48.773688577836566, 47.71522129735639, 50.90005251669115, 55.4842677424031, 59.411740918313306, 59.83856147335422, 58.01949562564973, 52.986675000959835, 51.14798161291307, 52.08788348782448, 52.1546971413397, 55.71913926832138, 56.07032475932952, 57.20442318147229, 52.49735147722306, 41.962347645913404, 33.90114345858174, 26.806205357274703, 20.79802659250075, 24.602680552390314, 16.078736705164758, 19.528104336031024, 19.83287642079015, 7.360811060474766, 10.462779268141716, 10.098899026070873, 8.165455393252834, 8.020618932862437, 3.9263170573019215, 2.389378715907374, 0.8654364739214221, 0.24627759451827697, 0.07623886389117088, 0.43477867639833884, 6.162475491723707, 18.93907808488415, 28.108344001154748, 32.948121255443944, 26.02635579724466, 25.032968482663556, 36.453061026911584, 50.2259853578383, 51.04823966180125, 43.10680897005143, 16.318763206082007, 3.5755890127151244, 0.13096414025752776, 0.04302026493655097, 0.05379214297018705, 0.04575574657909813, 0.0132232167074577, 0.0485723416110681, 0.02892644197169331, 0.084831221780229, 0.07823919607025963, 0.029736359701341683, 0.08651345127051877, 0.14952608294064, 0.060302296863688584, 0.13800033608511572, 0.02236222716859512, 0.0558384710682496, 0.09109766012237919, 0.0530533162846921, 0.05823346110241068, 0.04969173779470786, 0.015869632967928007, 0.05553130428456972, 0.024283826576485753, 0.037056167024157705, 0.06569141131495276, 0.03302128917928184, 0.027297208528785456, 0.0734532303026607, 0.04377361664909028, 0.04339625705934821, 0.06620314272661364, 0.06174830314252646, 0.19480207844847636, 0.017180498464093093, 0.10654697224738137, 0.055614233302373084, 0.12881014616258685, 0.09703900905386095, 0.015243824361072434, 0.03421290064110391, 0.060491903624947996, 0.007606192056329982, 0.04106956376363674, 0.041369904703911276, 0.041674788545576796, 0.06248721792813271, 0.034484616706087705, 0.01709770351167648, 0.09108377860919123, 0.017285057974438515, 0.05965210272059326, 2.863533453595254, 20.391155212156235, 50.55146755710725, 64.36094837803995, 63.79533475445163, 53.718597119854344, 41.85212119933098, 28.287298217896495, 31.705887010020597, 49.72993104688583, 43.30888163658881, 20.4762412271192, 5.4927827562055285, 0.5698066373025218, 0.06521382444207707, 0.4957643007078479, 2.81402186520638, 7.7127172870020715, 9.972226081355926, 15.27722683645064, 12.791243330124887, 10.828557937375962, 10.445364925169176, 17.605523217108942, 24.185522756268902, 16.62340683321799, 26.9688444752847, 41.42297075640771, 43.9689733905177, 55.001541645296165, 59.7473624444777, 60.170166492462165, 58.86731593839584, 57.16838052195888, 56.0719015521388, 64.5133520710853, 60.03467213722968, 60.76324455199703, 57.62082592133553, 56.45616831318025, 51.875934293193204, 47.827624659384455, 47.5135330230959, 52.68590373377646, 55.498337284211196, 57.1657996023855, 55.44984502177085, 54.070453336161954, 48.68017535055838, 47.66310084250666, 46.2207825722233, 48.019597222728116, 52.90776475783318, 53.94394905336442, 54.45353554141138, 55.02779799122965, 58.08824300765992, 58.85018694785334, 58.0035472685291, 56.191071002714104, 57.793978952592425, 53.5951836647526, 47.095977106402, 34.370984569672615, 41.3218245967742, 58.811002469831905, 60.48272448201334, 57.62873734197309, 58.72343947810512, 51.296411944973855, 50.6307465030301, 51.074092003606985, 45.854723453521736, 45.65088964277699, 45.35338570994716, 46.312197331459295, 45.853068213309015, 49.21524547761487, 46.99172442959201, 50.5641132785428, 50.42392776858423, 54.63598458997665, 58.353356007606756, 62.32257496926093, 60.60891105282692, 59.293591283982806, 53.35479728637203, 51.860974373355994, 52.805026115909705, 55.780202727163996, 59.55897884984171, 59.99518955907514, 60.72005533402967, 56.932881416813025, 45.41273509302447, 35.90489410584973, 28.574529463245025, 24.546194499538792, 25.204105415651878, 19.524178043488536, 16.19891126309672, 15.869481198249327, 11.825285150158791, 14.658061092899693, 8.7075392084737, 11.2223982234155, 14.064836925075902, 7.066326862381351, 5.6771910286718805, 2.0757099601530262, 0.48565083694073463, 0.09034637301679581, 0.6465601897047413, 5.860763836291529, 21.65021054206356, 30.487538037761567, 35.47705373456402, 26.352883308164536, 25.82162572491554, 41.55042033041678, 56.912002640385786, 58.57064747041272, 51.73955740467195, 19.542746543884277, 4.078324100663585, 0.2502970893176333, 0.037549650221462214, 0.09767225733207119, 0.027527111514862028, 0.021867070069176056, 0.03881330076124399, 0.04734405752031073, 0.006762821661053046, 0.026759987456663966, 0.033794306368837436, 0.05619267948091992, 0.024703190767116124, 0.037831367564297495, 0.10374302915748089, 0.013143607723196189, 0.010329986069982332, 0.05457624545200698, 0.02228148341659577, 0.07408667776373125, 0.04042870823233839, 0.0806814001031941, 0.03748829040916697, 0.027496364576021032, 0.05638938021635818, 0.05268282850363082, 0.06594481787854625, 0.1313173527558965, 0.23765836992571432, 0.18203180643819994, 0.2122982242895711, 0.10141581492198092, 0.1752694257565083, 0.32942868588912877, 0.16384215184277104, 0.1861836965526304, 0.16041320358072558, 0.19028176132950092, 0.23165942650408516, 0.259863244549882, 0.15416327443334366, 0.12877800111328402, 0.09245608722971332, 0.08266750602952896, 0.12553500537309917, 0.16305600773663292, 0.1719938482969038, 0.10061729849586565, 0.11186389057266136, 0.25821088482776, 0.14297456029922734, 0.13904886530531993, 4.052434251193078, 25.521387900075606, 58.300160823329804, 70.95104802039363, 70.51751628998788, 61.99604941952614, 51.99235416227772, 39.5316352382783, 46.22202204119775, 72.32553282091695, 63.64852436127202, 22.65051691762863, 6.847222283963235, 0.7442838975018071, 0.2631428056666928, 0.852738781081092, 4.508586535530706, 9.03469822099132, 18.28557002928949, 22.61583532056501, 32.932804399921054, 30.139557123184208, 17.527432749348304, 27.227189425499212, 31.70785211747693, 24.853535736760787, 33.46685471073274, 49.610079103900546, 44.76823083816036, 56.34256078350929, 59.67965841293336, 61.222475651771795, 59.3620680224511, 58.99626385781073, 57.25502960143551, 66.47184248893493, 60.511275414497625, 63.556725209759136, 59.005210784173784, 59.302012612742764, 53.2477322701485, 49.700454435040875, 50.38989336259904, 54.89113476968581, 58.077750667448974, 59.86073070956815, 58.09192611325172, 56.6188290042262, 50.63681440968668, 50.797972832956624, 48.05028584695632, 51.90117474525206, 56.74004593203145, 55.027660708273615, 57.64414441200995, 58.97138034143756, 60.53961061662244, 62.509075826214215, 57.67270711160476, 56.731102928038574, 58.4103637356912, 53.472656665309785, 50.836874900325654, 36.18435121351673, 45.42494150900072, 59.68382004768618, 61.8029825149044, 60.6261145684027, 62.995339901216575, 53.18862999639204, 52.87103568353961, 54.634803956554784, 48.6963237485578, 48.67891234736289, 48.380580794426706, 49.57209487115183, 47.71551547511932, 51.49197739939536, 49.9207268991778, 53.375295592892556, 52.33624796713553, 56.683767764799065, 61.69887104342061, 64.38810294674289, 64.03135161246023, 60.89701698672388, 53.2957773823892, 51.77922041185441, 52.89843343919324, 55.325082271329826, 59.65297845102126, 59.97706428650887, 64.67311020820372, 60.99549201227004, 50.74004334788169, 38.04995990568592, 31.96725610763796, 26.620985154182684, 31.48582047031772, 23.294944686274377, 25.571480489546254, 25.15179080347861, 13.126034294405292, 22.25038220805507, 18.453794602424868, 16.580178391548895, 16.086039177833065, 10.620085923902451, 7.784554025819225, 1.5975273160203811, 0.9236098813914484, 0.2226378678554489, 0.7223633027845814, 8.042102734888754, 25.05477489963655, 38.36887605728642, 46.89711686103575, 39.349668641244214, 36.816911851206136, 49.43827536798293, 62.73876197876469, 67.5409080136207, 60.222741942251886, 28.222614411384832, 5.312734198185706, 0.3916190600683613, 0.1274560857564211, 0.17692190805269828, 0.24809009726009063, 0.13915352823753513, 0.13484911001738042, 0.12581543185778205, 0.12264069455165057, 0.19391206814156425, 0.13067285830695785, 0.13152568270602535, 0.26589686111096417, 0.2549446383190732, 0.329998011790937, 0.1533898167432316, 0.1210001479053209, 0.176698608744529, 0.09549639142689206, 0.2499938410736861, 0.17509273523765226, 0.13343285859352158, 0.14171405455037472, 0.08396356591894742, 0.14665374352085978, 0.1329853713151909, 0.15395532752717697], [0.017160279488551523, 0.12464794450469556, 0.04883857248651405, 0.023328989909421054, 0.04046365716344407, 0.10201230630158417, 0.0443655881099403, 0.012478946009650828, 0.022087113503667138, 0.019044082033477964, 0.055629340556239894, 0.07636268668237232, 0.04360285948120779, 0.05352588145122413, 0.013180151074794273, 0.010652566542698732, 0.018445236848727353, 0.04413621372453148, 0.03832914851485722, 0.036137922546796264, 0.008968992568101854, 0.048088897996011286, 0.017910191466310815, 0.010063239042797397, 0.07860446679255656, 5.952129565900372, 17.96599295831496, 46.52528401344053, 60.20829193053707, 51.1626708892084, 41.47371445932696, 26.078311512547156, 24.117187223126813, 30.472693827844438, 37.63784431642102, 32.19679517130698, 16.4477248537925, 2.0965632411741444, 0.17271784735062432, 0.08606061669847659, 0.08150898956603582, 1.4961374791399127, 6.673578466138532, 7.194248591699909, 6.446438422126155, 12.658696636076897, 6.7374929978001505, 10.351798745893664, 15.049192982335246, 35.74413968670753, 23.79220316486974, 31.29461080797257, 50.07199310487317, 58.413815421442834, 65.9928975566741, 61.68667639455488, 60.94174769616897, 56.95027712852725, 57.32534593151462, 62.73518477716754, 58.28509892186811, 59.212045208100356, 55.124358900131725, 51.17401438374674, 47.543852944527906, 47.92608007307976, 47.18420297868791, 50.123348697539306, 52.745802248677904, 57.99472193564139, 56.52074229332709, 57.2751788170107, 50.43032907670545, 44.514249524762555, 43.559105319361535, 48.711452330312426, 54.98329085688437, 58.31535608537736, 58.21685360323999, 57.43729037623252, 55.753334491483635, 55.98714697745539, 56.513419228215376, 55.574662685394294, 55.795480358985166, 56.80785586757045, 54.78453651551278, 45.51318307076731, 29.6671703938515, 42.30653955090431, 61.218055140587595, 55.94680932260329, 57.14283804739676, 51.911015972014404, 45.92638515656995, 45.81724520652525, 46.644743719408595, 44.357146832250784, 46.10209949554936, 43.273466556302964, 43.61909012640677, 41.3059978331289, 43.81177656112179, 42.917844864629934, 44.36059459563225, 44.8971159996525, 46.48626035259616, 49.16383104939615, 56.78015216704338, 57.96856364896221, 59.387532049609774, 61.03204457990585, 56.89860774624733, 54.94915839164488, 53.27104683845274, 52.675485918598795, 51.1243728668459, 47.574196400180945, 50.92172753426337, 50.22935075144614, 46.20005676823278, 45.48063132070726, 41.21123336976574, 32.063263962345744, 20.762438927927327, 12.55148551156444, 12.000403288872013, 13.317621484879526, 12.839371792731747, 7.595225630267975, 15.848278826282872, 16.3340800616049, 6.1011002044523925, 4.037443932987029, 1.4554811317113139, 0.36909975231655184, 0.11912352360424497, 0.23189026411742936, 1.8831245264699383, 11.90054072487739, 31.79099852038968, 36.55507795272335, 24.489884953345022, 17.050943220815352, 26.478789429510794, 34.398041079121256, 49.69627318843719, 43.808556295210316, 28.484158054474864, 6.426900606001578, 0.05345458547855097, 0.04371662736840306, 0.022296138678587252, 0.032114354074902596, 0.04841017611925641, 0.07367359549407998, 0.018483545075380997, 0.024888947936556032, 0.020439279445957755, 0.042262427779215, 0.014701759698049677, 0.08064528671844352, 0.11198399017655081, 0.07486246436113313, 0.0760171580458841, 0.07605779901026719, 0.1262604216894796, 0.037054749761497786, 0.0685182910773062, 0.054154111853530335, 0.0398034502511784, 0.10502017433604888, 0.002306187037198294, 0.06209342192197519, 0.009970302043873216, 0.03088152708275424, 0.008743110586017852, 0.024122373546443643, 0.06227279374856622, 0.057262126731896595, 0.053526555608597495, 0.0120567626154591, 0.019976995179369565, 0.016745561621181907, 0.034891060823875095, 0.017980282765723044, 0.07587612125902407, 0.06804983597248793, 0.02152959301677202, 0.04308830120510632, 0.01542084908578545, 0.1003333863111273, 0.02803688365665655, 0.009490576828078879, 0.023282697131376595, 0.04055519700951634, 0.016312308256484328, 0.023240943424283497, 0.026251182500873844, 0.022397183760580038, 0.15432108854574544, 6.373310242929767, 22.92357663954458, 52.43943375925864, 67.19904207414197, 57.86432273926274, 50.12843993402297, 32.65625769092191, 28.83153884641586, 33.56099943960867, 41.77578010866719, 37.61202335357666, 15.94826102256775, 2.515250271366489, 0.35582157933423597, 0.015926369439600217, 1.1632051054508457, 4.04321349436237, 8.786797561953145, 13.032628932306844, 11.833406417600571, 13.777618427430431, 11.943001362585253, 9.851602412039234, 15.144077077988657, 21.47190743877042, 22.516242419519735, 33.17710922610375, 47.78492966005879, 59.449536877293745, 63.88146215869535, 64.10083247769263, 60.81646327049502, 59.48313590018981, 58.48791291636806, 64.3741471536698, 60.08540799540859, 61.2442801075597, 57.553729857167895, 53.62355809057913, 49.43800864681121, 50.47177676231631, 49.345479934446274, 51.23275579944734, 53.94791064723846, 59.65886200627973, 59.498664563702, 58.491058657246256, 51.461053432956824, 47.46923377436977, 45.52136905731694, 49.194884454050374, 56.61021940169796, 61.223954385326756, 62.26399829310756, 59.78626058947656, 57.33861923217774, 58.54968240184169, 57.65214604716147, 56.952261847834436, 55.940443315813624, 56.68529748916627, 55.51769418101157, 48.49494534154093, 34.870243457055864, 44.98434558991463, 61.74048346857872, 60.237858756895996, 57.53332960990168, 54.39718284914571, 48.64740787013885, 48.452356246209916, 47.822560879491995, 46.91923902880761, 46.7320203781128, 45.1615974980016, 43.98662797866329, 43.20638225924584, 46.80777703562091, 45.77837844048777, 46.50446407256588, 46.70855283737183, 49.56381474771808, 52.339460388306655, 59.51770374851843, 62.35874314461986, 62.44623945605371, 60.72532699954126, 55.7624343902834, 54.51603851010723, 53.53588135011735, 53.54935861402943, 56.297163271134906, 54.07378735080842, 56.89065710190804, 56.3677933908278, 52.07175862404608, 47.352664855218705, 39.54190008101925, 33.42178667745283, 24.67669959991209, 18.833487879845407, 11.843856592332164, 7.173219784613579, 8.914519740689187, 8.42125129315161, 9.940775536721754, 13.460289855157177, 7.901728460865637, 7.246290108849926, 3.4981217115156116, 0.6354092590270505, 0.17968826686903355, 0.3949817876902319, 2.703759381847997, 12.840073896992592, 29.236582402260076, 42.406407017861646, 31.563489283284834, 21.67651983999437, 31.038703610820157, 41.06328156686599, 57.09960176098732, 50.72553057824412, 33.495048707531346, 8.476709685017987, 0.09353751992626537, 0.05576485767960549, 0.009158648167466445, 0.025098068872466687, 0.12108160603430965, 0.027743328340171326, 0.011599369820267444, 0.023351114528674274, 0.004723404154872462, 0.05303358185976263, 0.029687688220292333, 0.038146268005572984, 0.017286837213642655, 0.025902541632193233, 0.00877144530550727, 0.028990559700515964, 0.03865855100053934, 0.021096596291529077, 0.03489021812715838, 0.03219706667286735, 0.05727038899015996, 0.07105257121785995, 0.028113446483809142, 0.033295709534638354, 0.025693480068096713, 0.015837661246018066, 0.20491635426878932, 0.20656738099792313, 0.16499856156447243, 0.14394470340301915, 0.10166958920777806, 0.22534482421413546, 0.10171456622981256, 0.13545013663749542, 0.10854326714310916, 0.0948666288487373, 0.2300208870081171, 0.15920267740805305, 0.12569465809651922, 0.0973896781403211, 0.11651666429374488, 0.2072094392872626, 0.09489691996526334, 0.16188194734915612, 0.12364375645354872, 0.1275109070082826, 0.1121963037838859, 0.20384092004068438, 0.11061738125018536, 0.13785200614121654, 0.2968326559470546, 8.849444677752833, 28.838616763391805, 60.21717609897737, 74.54173472619827, 63.60393093478296, 54.38024997711182, 38.12501838130336, 35.0131981603561, 42.97753549391224, 47.96594704351118, 39.61145154891476, 18.1597678507528, 3.091561914451661, 0.37327756684633995, 0.30059221711370254, 0.8742351469493682, 4.241582953160809, 13.88311057321487, 18.99389320804227, 18.311592994197724, 19.394824158760812, 19.074323369610696, 23.578714439945838, 20.758810735517933, 40.67426873791603, 27.59158349806263, 33.679729584724676, 55.94871951687721, 61.97180132712088, 66.5169575906569, 63.00164707245366, 62.166095933606556, 61.07138595273418, 61.11128430212698, 66.20215600536716, 63.6369651363742, 64.82629445291334, 62.19620404704925, 54.66958753524288, 52.382731976047644, 52.548514873750754, 52.20163614519181, 53.13646639547041, 57.2764535873167, 62.129531598860225, 61.189402226478826, 61.018755589762044, 55.2744758513666, 48.45841630812615, 47.968912355361454, 50.77369336158999, 59.38948146758541, 62.67162669089533, 64.03627026465632, 61.03348801212927, 60.23988662227508, 60.741059626302416, 60.45402057709233, 56.40442440586706, 56.80839715465423, 56.30068163717947, 56.54401763792961, 50.11774363056306, 39.07174910268476, 48.09612266479, 62.68459404668501, 62.571402288252315, 60.205750234665416, 56.91550531694966, 50.48160622196813, 50.809222190610825, 50.024905050954516, 48.70116395335044, 49.69236650774556, 48.229596999383745, 47.3523118419032, 46.35175051227693, 49.02849751134073, 48.428131688025694, 47.672985215340894, 48.78766006039035, 51.46297147197109, 53.88579599318966, 59.937173781856416, 61.91082023805188, 62.5570934818637, 63.30372056653423, 58.02949766958914, 56.48944962409235, 53.03302172691592, 55.05758054794804, 57.14380295045915, 55.49067689526466, 60.784543022032715, 60.08059132483698, 56.57281960210493, 52.692477626185266, 45.801955807593565, 38.60187661263251, 24.996184495187578, 17.808205812208115, 15.929431684555547, 22.978081895459084, 21.136232960608698, 17.151289216933712, 28.484061956405643, 27.243781051328106, 15.822104850123006, 12.165116360110622, 4.621208079399602, 0.7494252054922043, 0.37890573903437585, 0.6141019023714528, 2.724059363526683, 14.639301376958048, 40.19208785026304, 47.20318725032192, 36.425408317196755, 30.39322464696823, 39.198127869636785, 47.4136890903596, 63.873821381599676, 58.814477689804576, 41.786860804403986, 11.272171139717104, 0.37276897639516865, 0.16527337262467032, 0.07558840927818129, 0.22490639209506974, 0.17942005948674294, 0.12564695380147428, 0.13829967728064907, 0.08274829766202359, 0.10690096615543289, 0.16890766309393992, 0.0725987051884013, 0.12412306702425405, 0.12192490796047835, 0.23661693467968897, 0.15859829532282968, 0.20688397449351129, 0.24690358028296502, 0.13865523400806612, 0.14111875826793333, 0.22993712295447627, 0.18965651100922018, 0.2186306304628811, 0.12328923394482945, 0.19553523991377125, 0.12805004904587425, 0.16468143180733727], [0.06459962877054369, 0.045943047415705464, 0.04433839581906796, 0.026724421824779243, 0.06983775495281143, 0.03171287803730417, 0.028765117261378516, 0.07575175454539639, 0.06386387026718547, 0.031369638088489735, 0.034383814857010885, 0.04748387239693154, 0.03676834396056591, 0.03295019621990862, 0.09169982821350137, 0.08030279945101469, 0.04361717383407297, 0.04011874139729527, 0.010296443867827616, 0.056863600132806655, 0.039926882337538466, 0.07601937970086452, 0.0716917643383626, 0.04499835758319786, 0.13698055048383054, 5.473378790963081, 25.550521304530484, 52.86647788939938, 56.49111270904542, 50.70060391579905, 30.19524693489075, 14.22447641049662, 22.248417100598736, 38.76811842764578, 29.88942561611053, 21.178929921119444, 6.2358645085365545, 0.534180055462545, 0.1633212273760188, 0.29450252291656315, 2.325873826780627, 4.71585242017623, 6.507672994367539, 8.524342948390592, 14.46163663941045, 9.154713922931302, 8.357582399922034, 6.717449686219616, 21.191222629239483, 29.92111248354758, 29.09001127366097, 46.10317422497658, 48.69222487172773, 59.849371525549124, 58.81390502375942, 63.02225128296883, 55.39348840713502, 56.58665380170269, 61.7147840992097, 59.06492102530695, 56.40483625473515, 54.19441592308783, 50.31672546940465, 47.95972224204771, 47.02208357472574, 45.56911606942454, 50.795246785686864, 53.70083270534393, 53.74005248469692, 58.119539599264826, 58.18920481589533, 55.66578718923754, 48.85875301976358, 43.23610205804148, 45.62717107034499, 55.42968011671498, 56.14813673880793, 57.78112142316757, 61.51074240284582, 60.084325421241026, 57.240701183196045, 59.48363404120169, 57.685282230377204, 58.27228846088533, 55.54825728939426, 57.45231305399249, 45.472488480229536, 48.40900621106548, 31.448657974120113, 43.71388204636113, 62.43588047642862, 53.64331114676691, 56.1239553266956, 47.8816709979888, 44.65712970302951, 41.67089593025946, 43.23481944299514, 46.62801481062367, 49.603917060359834, 49.09398540373772, 50.82546864786456, 44.82739194746941, 42.96487016062583, 40.640865833528586, 42.90290847901375, 42.17080200872114, 42.250677154910186, 45.23713842515023, 49.32511106614144, 52.90477983413204, 55.98600556773525, 57.768040318642896, 58.00287654322963, 58.269707541311945, 59.66368259922151, 53.550060718290275, 60.24316964610931, 50.79484278155912, 55.32728664336666, 54.50797803940312, 52.47268761357954, 51.234579701577466, 55.074336913324174, 41.73000212638609, 38.80796578622634, 32.78095964462527, 24.35161159884545, 11.284399128729298, 12.121128939813184, 5.0749993420416315, 7.9556885073261885, 13.237308013823725, 6.246008738394707, 7.205275354846832, 6.046825878081783, 0.6276093807912643, 0.06654603602064234, 0.19869849356191777, 0.6431751229589986, 8.73305912940733, 24.440610178055305, 34.878123498732045, 27.570718449930993, 19.007729368825114, 26.703141158626927, 36.70553222779305, 47.56306471363191, 44.97897194277856, 32.78137149349336, 8.920295430767922, 0.07988803944880925, 0.03789329045121709, 0.03257942498631535, 0.00793396229592843, 0.021065021977729855, 0.09807107504457237, 0.010788203367302495, 0.018609556962826082, 0.11275024664017463, 0.02539135031251898, 0.03400390802492057, 0.03712699185275743, 0.03236554089873549, 0.06957831161637461, 0.01711260775224336, 0.03830215923728482, 0.05203475259364613, 0.025922209024429325, 0.07507587347419993, 0.03090045328492359, 0.038343068332441395, 0.04138839040552417, 0.02801827346575597, 0.07336701476766218, 0.02278682565496814, 0.06605079082111198, 0.0851121002567872, 0.04022294850719552, 0.017000722526122006, 0.011212987629997154, 0.06320056069882647, 0.02761075299443497, 0.08463233769420656, 0.055882701154557936, 0.03731928375219146, 0.0037451055663217225, 0.038909092395296024, 0.08561845373121962, 0.0753531666592725, 0.011924652668136743, 0.05400147649549669, 0.029625847687824603, 0.03363586406433775, 0.04412916954606772, 0.039525984696322874, 0.020965459275870554, 0.022095787534189802, 0.10704099936711212, 0.04954103297824341, 0.05894144125763447, 0.2799176184400436, 7.202244833592446, 30.690216710490567, 60.75707466371598, 62.74583793455555, 56.72691775906471, 37.38535350368869, 23.623407886874293, 20.99253300697573, 37.13201545899914, 34.24795158447758, 20.43405613591594, 7.573976189859453, 0.5776519905174933, 0.08558895168525558, 0.5019829428244023, 1.8434437460476354, 4.791222724222369, 11.274116635322573, 11.045021780075567, 10.217730172218817, 16.991415369895197, 10.309602868172432, 10.279926215448688, 13.858415330609969, 17.928969706258467, 30.166111569250788, 42.430102056072606, 53.416849182498076, 59.911054718878965, 60.43675822596396, 62.90001846128895, 59.58099511361892, 58.60936126401348, 62.31955474422824, 61.94181088478335, 58.567384058429354, 57.03649082491475, 53.253619747777144, 50.35456457445699, 48.888323768492675, 48.69846928504206, 52.35422026726508, 55.03856489735266, 56.98620996167583, 58.82488373787173, 59.822432687205655, 58.92832448405605, 51.13790112157022, 44.7659872424218, 47.90723308440178, 57.66663136020784, 60.113084239344445, 60.61906606920304, 62.00902462005616, 60.867858086862874, 59.21682265497024, 62.62274611380793, 59.86584940264302, 59.01122377764795, 55.79249935765421, 57.11047849347515, 48.98412765995149, 50.37682794755506, 34.94697678473688, 45.31853152859596, 64.20667371442242, 56.34736176460021, 57.73328419654601, 49.138618053928504, 45.7871174812317, 43.234921424619614, 46.47197508042859, 48.638429564814416, 51.864112269493845, 50.93758567687004, 51.69660352891492, 45.754640256204915, 46.296880475936405, 42.7214753243231, 45.97739165829074, 44.026953866404874, 44.787250411125925, 47.11953486165693, 52.60238078332717, 55.64228042479485, 59.00037842412149, 59.85417250664004, 59.64820100415138, 56.65160432938607, 58.0637909520057, 53.76714037310693, 58.96615182199786, 50.022590852552845, 56.39441059481714, 56.24317969045332, 53.236114209698094, 57.5959227931115, 58.557613434330115, 45.815060446339274, 38.06233890594975, 32.57546667129763, 18.255118708456717, 9.903218842321827, 13.511987674620844, 12.041471485168705, 13.292691880656829, 10.739479930170122, 12.571165023311494, 7.210557316580127, 4.217108834174372, 2.8627921256326863, 0.03446656767459166, 0.10022929028397608, 1.0479537349554802, 7.596049818300433, 26.34132016089655, 35.523698560653195, 27.763575507748513, 24.340711332136586, 33.024246615748254, 40.85923594813193, 56.86870359605359, 50.704836153214984, 38.8156222528027, 10.896517903574052, 0.33857933035300625, 0.0470620452336246, 0.07034994601722687, 0.03818584793818094, 0.054287338374002334, 0.11673739720736781, 0.014557987019690055, 0.06279272996189614, 0.06078318557551792, 0.03216290681232368, 0.0804972019226801, 0.027922581423134096, 0.0592703266339677, 0.05999707211289675, 0.010562498543050983, 0.07286494372472649, 0.029032265527113795, 0.04094885128940787, 0.08363288406643175, 0.010746005329213316, 0.022559646111462387, 0.04610586791269241, 0.007716965976156175, 0.08296340749028229, 0.030740756511447892, 0.019101875706485683, 0.21074937836777782, 0.1542103888406869, 0.1335604888417067, 0.10283051118735345, 0.17392196902824988, 0.11809143463089583, 0.11236514956239732, 0.27811967136879123, 0.10400889997160244, 0.08846635494621531, 0.1394085589075281, 0.1844301366157109, 0.11515175608257133, 0.1330169494594297, 0.17519047273503197, 0.11499024176549529, 0.08811568585975517, 0.20682690094315237, 0.08772033852555099, 0.14939243124137003, 0.15246957660682742, 0.18329853282099773, 0.27547798570125337, 0.14843076107002076, 0.470556054985331, 8.45415997889734, 39.26934634485553, 67.26065466480871, 70.02004208103304, 63.557156670478086, 42.42985102438158, 24.987376812965643, 32.011559278734275, 50.01980204736033, 42.87326320525139, 26.942845044597505, 8.19482708169568, 0.6906002555643359, 0.45030559323007063, 0.4061668552458287, 4.201645380066288, 9.52015526833073, 16.289943591240917, 17.206357332967944, 26.782439716400642, 30.620233781876106, 19.86294138816095, 13.906137827903995, 31.318531382468443, 35.58878244892244, 31.649773582335445, 50.26946875356859, 54.076172151873195, 62.72846183469219, 65.26057535602202, 67.14255994366061, 63.45105263494677, 64.01581902657786, 63.30323811500304, 64.99725487924391, 60.411419714650805, 60.25992993385562, 54.72931346585674, 53.22668483180385, 51.53843395171627, 49.37200692392165, 55.45146888302219, 57.96116605881722, 58.009775992362734, 61.11683837829098, 62.476967303983635, 61.07577116258683, 54.512998673223684, 45.85006760012719, 50.231625726146085, 61.337197134571696, 61.217749195714156, 63.33067901672856, 63.42324695279522, 62.23087779937252, 61.39677009274883, 64.00709567531463, 61.17425795524352, 60.767017872102805, 56.231840118285156, 58.128188425494784, 49.35008871939875, 54.62045984883463, 40.59600568586781, 48.52653218853859, 65.70995346192392, 58.942880399765514, 60.61962696813769, 52.77044650047056, 49.037318921858265, 46.29393477593699, 48.5471167872029, 51.31954608425018, 55.62231556061776, 52.846046263171786, 56.053529170251664, 49.02286106540311, 49.28064707786807, 45.1932627924027, 48.65138907586375, 46.44889585433468, 46.89462223360616, 50.90222158739644, 53.87378177335186, 58.619869293705115, 61.86492458466561, 60.86249620683732, 61.199670991589954, 58.075754181031265, 58.584744468812026, 55.16366104925833, 60.94932179297171, 52.740758080636304, 59.20709125457272, 59.43073695705783, 55.682061103082475, 58.34063968350811, 60.9852114800484, 49.117864793346776, 45.088472750879106, 35.557070086079264, 27.837774984298218, 14.912352273541114, 22.29714470524942, 17.018813125548824, 17.702486168953683, 23.61379219639686, 15.932091051532378, 16.053348183631897, 12.439029197539053, 3.0421118582448656, 0.13156104532461013, 0.43157857392103444, 1.125841832930042, 10.846900901486798, 30.848388248874297, 46.26100255597023, 38.88971582535775, 32.715008912547944, 38.597232526348485, 48.7430234878294, 62.21937348765712, 61.463779864772675, 46.20344177369149, 16.638270654985984, 0.9477499247558656, 0.15469326938111938, 0.15520326943407137, 0.16991159067519251, 0.15421808036344667, 0.34825958672069735, 0.10736598918635039, 0.1951902092344338, 0.18285933461400772, 0.2475309603276753, 0.0949342820733305, 0.14193582168269542, 0.17162764294733926, 0.24035003516943226, 0.12883642297838965, 0.09502081936525722, 0.07724266889835558, 0.1272131133103563, 0.20016483181426603, 0.13089395128190517, 0.13853923297457157, 0.19211646529936022, 0.15582148706720722, 0.18476243491374678, 0.10677666838971839, 0.1624716205462333], [0.02238173559758692, 0.05068390975676237, 0.062499927326796524, 0.025025139217294996, 0.033385414600131974, 0.09748196875255916, 0.023434315507690755, 0.016931962304478212, 0.055608832382506905, 0.04935746298982732, 0.02777179616743759, 0.0265005192223696, 0.03317928715278545, 0.09007035153767756, 0.01604628135194822, 0.07363878445880068, 0.07725875674476547, 0.04417365627183069, 0.06918057408784667, 0.03663892872751721, 0.11255470269750203, 0.007238047067902141, 0.06060568683390176, 0.025378229141595866, 0.7654507842756088, 7.282571052351306, 34.05887373032109, 54.03155911353327, 59.98206923084875, 53.006004441169004, 31.219677848200647, 15.195695469456336, 33.70046323345554, 34.013029067747055, 31.804569921185895, 16.99134280604701, 2.5984609030908157, 0.24847281946530267, 0.09155519081339722, 0.7357042030461374, 1.7008212184713734, 4.484353642309866, 8.826712581419176, 16.702705390991703, 8.151104911681145, 9.566460809400006, 7.830721303339928, 9.37602581516389, 14.442087546471628, 20.49310741886016, 27.231066688414547, 30.220405017175985, 33.42995305215159, 50.3517012442312, 56.02661778849941, 61.55220970030754, 52.212257923618445, 56.050140242422785, 56.62822700315907, 56.674730623922045, 51.78148754181401, 52.46230902210359, 47.07376864648635, 46.27085947221326, 46.46345961478449, 50.78351889887164, 51.02063402052849, 53.661773743168006, 56.361615657806404, 59.83268576283609, 59.076197839552364, 53.83742140185449, 42.899586231477805, 41.14899712224161, 50.14920888408538, 59.18032892288701, 58.45327838774651, 61.89254199304889, 55.34985988370834, 54.74878018902194, 55.906675631000155, 55.9538068309907, 55.9970784187317, 58.09776260006813, 54.30093965222759, 55.91479493725685, 42.22483265784479, 46.835288540009536, 33.40219443844211, 56.074047088623054, 58.4283713371523, 55.67075290987569, 50.34653548271426, 43.92429367188485, 44.08296139009538, 44.486828234887895, 49.19987763127973, 52.88927078247071, 53.37658213030908, 56.36037226646178, 55.99374440408523, 55.04707251825641, 50.68473008371169, 48.942538769014426, 42.03332685655163, 39.29687353872484, 39.47846358822238, 42.81938552856446, 46.43505773236675, 49.9330117625575, 54.96130989443872, 58.281227542508034, 57.95198379024383, 57.83171607602028, 52.53069162368775, 56.69575845041583, 52.79080752403506, 58.246365516416496, 58.30774668724307, 54.25782888166366, 56.98550001267464, 58.9353298371838, 53.3101567914409, 48.669235860147786, 38.700739952825735, 34.660314283063336, 15.27316326095212, 9.245290275542967, 8.006112046780126, 5.266070740838205, 6.0330701258874715, 7.5078200236443555, 9.862561514300685, 4.966404111154618, 1.4604642578671057, 2.340219895685873, 0.122062619925747, 0.0430103364370523, 0.4331950807283002, 2.7706828617280532, 15.567708746079477, 38.572627498257546, 44.862748192202666, 20.195719195950417, 18.83675717538403, 31.124732955809566, 45.04388324676022, 49.03615397791709, 39.05248242039835, 14.067576700641265, 1.3244367054393216, 0.06930765275272631, 0.074679461277781, 0.030202229259415504, 0.018861429435351205, 0.013161069739820256, 0.056117311750929204, 0.023453682210416566, 0.040194982467519666, 0.09726289824973192, 0.09757103413463601, 0.05792279712735646, 0.10632121379697516, 0.06532116102114802, 0.05801205403141438, 0.00889984930249592, 0.022446318724823576, 0.025602060880872513, 0.021250964923491402, 0.09761419552828997, 0.03789601772422752, 0.00360229839814917, 0.045210766951523484, 0.0342947609662529, 0.06713697326279457, 0.06607371983268569, 0.018730303911011548, 0.045344349702880274, 0.015059847388446573, 0.02233521107794537, 0.08293058062272687, 0.12244721904637353, 0.01609720991954448, 0.0038111320510882166, 0.060335192679157185, 0.03297317502719741, 0.021360224383252285, 0.053737256600851976, 0.05014988901694456, 0.059203044962017774, 0.039449096281802466, 0.09436608232077091, 0.008761480416832192, 0.038243067045245445, 0.032489160676637006, 0.024532990928198543, 0.0396239596809591, 0.04285239592014302, 0.06943841630052175, 0.03730524136053939, 0.7537859618183106, 9.370993414232808, 39.302353089855565, 62.05528113149828, 65.60237853757798, 56.7086983496143, 33.744036843699796, 15.704127800080085, 29.653083201377626, 38.60919183300388, 34.08715009689331, 18.58342501424974, 2.854324954171335, 0.3440712614645881, 0.17510070255206478, 0.5737303557895845, 2.6539281202900797, 6.6323720062932665, 8.706565480078421, 11.99865096999753, 13.665570039902965, 13.163684145096811, 9.630683737416422, 9.498637145565404, 13.362654216827886, 18.764187443640925, 26.352308680934293, 30.050721322336507, 35.96645570570423, 52.001124581983014, 61.70443688669513, 63.854370347915165, 57.348527139233006, 58.53956268679712, 59.8983266276698, 58.18126986103674, 53.795146096137266, 53.68113063996839, 48.96255462400375, 48.66421130395705, 48.55298465298068, 51.3560555058141, 53.4136289165866, 56.06462163309897, 59.78515840345814, 60.32770064569289, 61.27705543271957, 57.03767930307696, 45.724845932376006, 43.46752974294847, 52.01250337785291, 60.694920785965465, 60.65103338610742, 63.87254661129367, 55.539808504043094, 55.08730819148403, 56.83129202935004, 56.693212832174, 55.69810359708725, 58.6778066235204, 53.53337495557724, 56.722144234565, 44.513355224363266, 48.869002173023844, 38.31205660297025, 56.87956463906073, 60.97434651467108, 55.8799760572372, 52.74505699834516, 46.34723978657877, 45.857222003321496, 46.57731817614648, 51.60287064890708, 55.025589696822635, 55.82299578574396, 56.671451522457986, 59.091499005594564, 56.99664738870437, 52.65547790834981, 50.181101675956484, 44.83530336810697, 41.10923605580484, 41.68565973158806, 45.13705130546324, 48.789919345609604, 52.34104502585627, 57.231181590787834, 59.85737316070065, 58.732774719115234, 59.546038950643236, 53.9825608653407, 56.181394515498994, 53.314538078923384, 57.15622509679487, 57.73438638256442, 54.64011876813827, 56.49448202502344, 56.73764151911582, 54.66033074163622, 49.21336273993216, 42.98437218512259, 32.664335812291796, 18.812340421061364, 6.171662663259815, 8.237565717389508, 13.785986804193067, 14.699161648750307, 12.823675447894683, 12.32610219909299, 8.788353762319012, 4.481366757423648, 1.9513127255824305, 0.36496355168281064, 0.11342607408521638, 0.5017124218565803, 3.516422510147095, 16.85479529442326, 37.343631252165764, 42.43645629575176, 25.49952460873512, 22.638173218696352, 37.029014018274125, 48.28894638246106, 56.57012493379655, 44.30977244530955, 18.9589782299534, 1.6044244362461952, 0.12208390950916276, 0.0468960301499934, 0.03576351239556267, 0.014227419122753125, 0.03483297986789577, 0.1336299270511635, 0.06125504594115962, 0.01743630671332921, 0.08844195504582698, 0.07248818168356534, 0.09016510895303181, 0.04423565193710308, 0.02693702271508594, 0.038212006010355494, 0.046536566374162515, 0.030406462554369244, 0.04932267493718574, 0.008927823003051023, 0.0436726960563852, 0.006484203622676433, 0.023195784456366976, 0.06145490678928553, 0.010304467681224548, 0.011452570136997008, 0.027032528981386174, 0.08302731454492578, 0.14576783944522181, 0.13594873730213414, 0.2455953012911543, 0.2691064017914957, 0.21729584482889022, 0.11625076283610637, 0.09136374544111953, 0.2042642449058833, 0.12226589369557558, 0.12364344235749976, 0.1627341588778842, 0.12600188999767267, 0.18522070871005136, 0.12523196397289155, 0.16482582405930565, 0.12139367195026529, 0.23086867054864285, 0.15867683465682692, 0.15447916312804147, 0.17735589686180317, 0.23040688806964507, 0.1964332788221298, 0.07537801855153616, 1.2583914687556605, 12.535333191194843, 48.6123771821299, 68.62493345814367, 72.87307216275123, 63.71183926059354, 43.05418252944947, 25.998365763695013, 47.20130843500937, 47.859697880283484, 42.21414027675506, 21.01021112934236, 3.9384082536543574, 0.5360982170508755, 0.338826592891447, 1.0413438057707203, 4.863840505000084, 10.34181631380512, 17.564783519314183, 23.471396430846184, 19.965166199591852, 22.257962188413067, 16.858545080307994, 17.126952871199578, 18.726899431597804, 23.57723962876105, 32.13821457278344, 34.24410373933854, 39.425507668525945, 57.256104330862726, 64.08603729740267, 68.25674057006836, 61.75246238708497, 61.74409597150741, 61.07686158149474, 61.632488850624334, 56.063727332699685, 57.145356209047385, 51.15106851823869, 52.600376452169115, 51.023567953417384, 54.7794609685098, 55.80162279067501, 57.52948960950298, 59.97061198757541, 61.16137296922746, 62.460528650591456, 59.3874575245765, 47.43948259661275, 46.89376323453842, 54.33387187219436, 63.788674569899044, 61.2707325720018, 63.8546056901255, 55.41657547796927, 56.13611075185961, 56.06106404335269, 56.431731947006725, 55.607857704162605, 58.397337544348936, 52.78925426544682, 56.55881281821959, 46.80297213215982, 52.903775707367934, 43.049134439037694, 58.981241180050766, 61.79829920491865, 59.188228576414055, 54.616133474534564, 49.3824286614695, 49.55817830178046, 48.896121440395234, 52.731987660931004, 57.22768283659413, 59.339483014998905, 60.985980264602176, 62.14991615664575, 61.405054138552764, 55.49705466916485, 55.025589696822635, 46.68385759476693, 43.490036302997225, 44.0851108489498, 47.56177817621539, 51.898715419154016, 54.443235397338874, 59.72669939840994, 63.99275941233482, 61.357111007936545, 61.195481900245916, 52.73801634388586, 56.39483813316592, 52.467592454725704, 57.89958484711186, 57.98433942179526, 57.44428003987959, 58.10196738089285, 61.29884027665662, 57.727643828238214, 55.16206072222803, 44.115093446546986, 38.33135466421805, 19.62394941237665, 13.588097345444465, 13.57963973476041, 10.909378374776534, 15.212507728607426, 16.664956500453336, 22.005938137731246, 12.327496601689248, 9.548113922918997, 3.60193679890325, 0.9800837994102509, 0.29519292135392466, 0.6020027999916385, 3.936974627356376, 19.84511225454269, 47.18455991437359, 57.31550078238211, 33.56649860259026, 28.688760649773386, 42.67110424657022, 57.16811772315734, 64.5244013878607, 52.447356947006725, 23.78168336806759, 3.4639284495384466, 0.3386740801074813, 0.2500789994073491, 0.17233408326583524, 0.12077225206960594, 0.1108544548192332, 0.22420133073483745, 0.2119867942265926, 0.07137992824878424, 0.21430790274133607, 0.13765185801011903, 0.22078054897006483, 0.21728950162087718, 0.172127254848038, 0.1899149890748724, 0.13240447748572598, 0.14197201167623844, 0.125882541159949, 0.15359106804094008, 0.31401545650536017, 0.10656259278015745, 0.12100947885623864, 0.1810924447472057, 0.16891455788525844, 0.11138955191258462, 0.1977436109295776], [0.03793650930146537, 0.02588406933711902, 0.05575393709624487, 0.0727546806897848, 0.06423508200133521, 0.030748926839160345, 0.08833169967176453, 0.06210603172920885, 0.07496724986741621, 0.013319159643874775, 0.02398566515635579, 0.03402418637227628, 0.03438301812556963, 0.05017296741566351, 0.05590361918533041, 0.09076544609401496, 0.05736445692638236, 0.05990444059153238, 0.0317543329701068, 0.06617472852550207, 0.05946233125043012, 0.05120781813597968, 0.05161001812666655, 0.020134732682978915, 0.35140373413601234, 14.652689406948706, 39.95717710064304, 54.539419758704405, 49.938656053235455, 39.93941268613262, 21.704862886859527, 27.977566296054473, 27.760892606550648, 32.7420771891071, 32.63926794452052, 8.79990122010631, 1.4339633766681918, 0.10336763841370422, 0.06123795835000854, 0.3185958042740822, 1.0861974570059008, 3.622025708037038, 7.790274802715548, 6.774598129333989, 8.135697351348016, 13.041378759568738, 6.832824243653206, 10.256351790120526, 15.844260358041334, 9.523724625187537, 20.49098345541185, 27.846763095548077, 43.58424771216608, 44.68366453724523, 49.77772120506533, 50.35020682119554, 55.275989886253114, 57.651247824392016, 58.92821073532105, 53.28074685988888, 55.56647669884467, 50.28121625223468, 48.37117887312367, 45.63494520802652, 50.306699891244214, 50.81913794240644, 52.450690961653194, 58.29739947472849, 58.03158829289099, 56.3544887112033, 56.742297372510365, 48.78446725107009, 41.30360518732379, 45.03031969070435, 56.18969032841345, 59.33417604815576, 60.989906557144664, 56.620370495703916, 57.44088326731036, 56.45778825206142, 57.91837692260743, 57.67473105461367, 56.41275944248323, 55.74809028256325, 57.531815575015166, 55.120267868042, 42.911192524817686, 50.218058247720045, 46.0617422288464, 56.235766410827644, 55.666422613205455, 56.18314389259585, 46.50196552276612, 42.41564027724728, 45.48704831830917, 48.218504536536436, 52.66859823657621, 54.331918531848544, 57.867346886665594, 55.00900199336391, 53.70224083623579, 56.16212391084241, 55.850428842729144, 53.795808976696385, 50.6550181296564, 45.19832657229516, 42.568467586271225, 43.029855989640765, 46.471261209057225, 46.148395230693204, 52.680655602485906, 54.30251252266669, 56.534705931140536, 57.174758295859064, 57.02163288670202, 52.73113650660361, 56.98893208657542, 55.045986021718676, 55.37884619928176, 53.293820119673214, 54.8440271039163, 56.8538535025812, 57.81790933301372, 55.8451924785491, 48.13593079966884, 38.74146592232489, 24.840107502475863, 11.27719569590784, 12.15209605232362, 22.540188489421723, 18.696022533601333, 11.261365990484915, 7.837502100775319, 5.144076203146289, 4.113794584428111, 2.7274826120945717, 0.1613845264599208, 0.08109182404774813, 0.17349516612387475, 1.433971711704808, 10.133225648633896, 28.118453910273892, 34.5063102629877, 33.2086843059909, 21.691664111229684, 34.60607574832055, 42.184016473831676, 47.145253842876805, 39.63308342041508, 15.974505601390717, 2.3314695781277073, 0.07540785767618688, 0.04166133221118681, 0.025797846141241254, 0.07483736732073369, 0.042183206626965154, 0.042852338463548696, 0.04812861965488523, 0.057233658904630336, 0.05022783463280048, 0.0777630877470778, 0.030988246961046132, 0.054713861656285105, 0.015797377470129683, 0.021181817827445847, 0.043935475705732266, 0.016045083381956624, 0.05261291148922136, 0.03025842946954072, 0.11807611287241021, 0.045245122164487846, 0.03454654342344692, 0.04447176406580595, 0.035911248621320536, 0.05505083309065911, 0.07501039593931168, 0.07095809725503768, 0.037952233256111224, 0.08574518765653334, 0.08456788671713683, 0.03406919786826738, 0.021949506875488068, 0.019145937253450675, 0.03183426658412622, 0.10848614762747481, 0.03602459132971783, 0.047790621662692684, 0.06289773763367726, 0.015727740077812587, 0.016015588996871825, 0.043480155178375786, 0.009836545965123561, 0.048649597747792164, 0.061561370028122786, 0.03608894271535739, 0.025266024073766127, 0.011306413967582968, 0.05618191594558378, 0.06695835220236933, 0.04431646655223543, 0.8249539365210842, 17.449097133451893, 45.415084592757694, 61.9708913372409, 56.73858681032735, 48.07111755494149, 29.298118506708455, 29.71893391301555, 36.65598484777635, 36.223629828422304, 33.93917868214269, 9.805542019105728, 1.9814813906146636, 0.08823831355379474, 0.06242548656319419, 0.7232439361753003, 3.5304986709548585, 7.569906240509403, 10.721031062064633, 8.723063949615725, 10.478021598631337, 13.988185967168501, 12.51390822472111, 13.37666198130577, 13.221088032568655, 14.59958737896335, 19.40523216801305, 30.53814445772479, 47.69900621906404, 52.50983638148154, 56.70767461099933, 56.140209628689675, 57.99136830914406, 59.39714970127229, 61.67834135793871, 57.330609752285866, 57.96323314789803, 54.226712719086684, 49.017667847294966, 48.24880484611758, 49.962382470407796, 52.6888455114057, 55.16893663714009, 59.551302771414484, 58.5385311034418, 56.80841676650509, 59.36856738982662, 51.17992539559641, 42.51057340252785, 47.59304731122909, 57.97952275122366, 62.14348739193332, 62.57455195150068, 57.51775780031758, 57.05764808962422, 55.144292385347434, 57.08746594767417, 57.944484218474365, 57.13133373568135, 58.03549497358261, 59.22499687440934, 56.42596998522359, 45.29912364098334, 51.361891992630504, 47.45084178063178, 58.85387789818549, 58.008775787968794, 57.70163851399576, 48.84631518394717, 44.66337019397367, 46.24268116489534, 51.24445622967136, 55.016552555945616, 56.15638548328031, 58.88235038326633, 57.374179440159956, 56.34676948670418, 57.20826710424116, 58.59515051687918, 56.52865763633483, 52.37886451905774, 46.39635178350633, 44.13576825972527, 45.21272167082756, 48.35375570481824, 47.7760454916185, 54.03993729622134, 57.98415899276734, 58.41146592170962, 58.15755521097491, 55.724579595750384, 53.05667361905498, 56.615812701563684, 54.02698562991235, 55.81990103567801, 54.2902551158782, 55.270122020475334, 57.67013403677172, 56.92503275409822, 56.01051645894205, 47.51178364599905, 37.03189696035078, 27.925581162975682, 11.285191447504106, 12.59043170559791, 21.32588348081035, 15.138108211178935, 11.866045440396956, 11.804635832386634, 9.45149515905688, 4.5149530326166465, 3.0280795789534047, 0.9776905407347988, 0.1343528689035485, 0.20446145125935156, 1.6673033396082542, 11.050499370021205, 30.77240997745145, 40.805173920046904, 32.99492297634002, 24.91622894041, 38.2312753892714, 47.87580705458119, 53.00577694369901, 47.03372516939717, 19.844684716193907, 3.1778234147256423, 0.08234151263510989, 0.02487951356376852, 0.04582016308221125, 0.04855626908641669, 0.008948534190083944, 0.09820101887828882, 0.08124661211284899, 0.0459784559995657, 0.03800238903251387, 0.04119461995639628, 0.023060338196134376, 0.050566579560719194, 0.07493918040587057, 0.014153739659025544, 0.04792918015511767, 0.03661970758149701, 0.02500665734612173, 0.04781962192106632, 0.0783160423499442, 0.05830378031298038, 0.03798198811109028, 0.09014879894112388, 0.006068496544274592, 0.12111794158455827, 0.035477336421008074, 0.10187531445896435, 0.1015678680531921, 0.19102233852590286, 0.23398090274103228, 0.14606756368471732, 0.15553274852854593, 0.13065658659944612, 0.17041535477244085, 0.2522739332409636, 0.11057937562826181, 0.15965070094793074, 0.12922162730847636, 0.09197351312445057, 0.16004152836338167, 0.20304216612731257, 0.1295370716721781, 0.2107817379216994, 0.17098350089884576, 0.0986820071815483, 0.15642364749745016, 0.20756150265374493, 0.2012660985271777, 0.1866596210147104, 0.1254501611354851, 1.1196432623171038, 21.96845204599442, 52.50344684047084, 70.38869780878868, 61.734497931695756, 52.51846559586064, 32.69458709224578, 39.44908895800191, 39.886794090270996, 44.4780852717738, 39.0586091626075, 11.39809589232168, 2.1417533582256687, 0.2329073530892211, 0.19800867735137864, 1.356114624969421, 4.931999041188148, 11.020655035972597, 19.877103105668102, 18.253298728696763, 21.408019873403735, 23.98587803686819, 15.822868731714065, 18.153901946160104, 22.399089067212998, 13.069306035195629, 24.08174272506468, 37.56876745531636, 55.78944383128997, 54.36847502185453, 59.751327960721916, 57.5499173133604, 58.42255446218676, 57.51873839286066, 62.739989680628625, 58.80333031377485, 60.5952690493676, 54.6195145576231, 51.69228892172537, 50.5466861878672, 54.87868124438871, 57.00908914689095, 58.05851144175376, 62.552825943116225, 59.41771861045592, 58.714892633499645, 62.050931222977184, 52.42051616791756, 45.769400135163345, 49.693213739702784, 60.86478294864778, 63.57964361867597, 66.93256408937516, 57.079017162323005, 58.12480342003607, 55.93044519424439, 58.48636358014999, 59.56728642986667, 57.655264331448464, 60.18941748526789, 60.21068065397201, 57.2101459195537, 49.46256268408991, 55.156004582681966, 51.553990071819676, 58.8167683539852, 60.54650614338537, 61.975300081314586, 50.628765706093084, 46.329349856222834, 49.47020738355575, 54.19683994785432, 58.51387900690879, 57.34873502485214, 62.07242581152148, 58.594624919276086, 56.35553990640948, 59.47284360085765, 61.79911898028467, 59.36197780793714, 55.05603121172998, 49.69473169695947, 46.17373766437654, 47.86294952515633, 50.95138457513625, 50.82919489952826, 56.943793450632405, 59.3803031213822, 59.632864536777625, 59.92659514950168, 57.61021591001942, 52.90506224478445, 58.01268246866042, 55.836880976153964, 56.20859223027384, 54.84539993347661, 56.444322755259854, 57.58772896182153, 58.66498047305692, 58.81388541190856, 50.83996572802144, 43.95600211235785, 31.747191529120173, 17.97914074313256, 22.45380024756155, 32.51650364168229, 31.209424772570213, 18.677102981075166, 21.030442714691162, 14.21043432527973, 9.965952250265307, 6.99652926575753, 1.2045503191409574, 0.43077975872062874, 0.536706552149788, 1.9549703357681154, 12.42633640766144, 34.85238490566131, 45.23412604485789, 45.33421316454488, 33.73324640335576, 45.97940383418914, 55.97765876400856, 61.51222505877095, 55.73557399934339, 26.60871990265385, 4.740792810916901, 0.1424837737314163, 0.10927250623823175, 0.19287492298791487, 0.18607114291479512, 0.2377649633994987, 0.22488029914036875, 0.1576162012474191, 0.20344420906997498, 0.08177744975734143, 0.15413751855732935, 0.12390601899354689, 0.19639572519208157, 0.13021265396908407, 0.12107904730064255, 0.13738021855392765, 0.17330468602238164, 0.08530536891832467, 0.1130186455444463, 0.18725773650071315, 0.13713841056150777, 0.15143571030949393, 0.20370382094575515, 0.16476980771028227, 0.2023953580928426, 0.15648266691113674], [0.014367454249652164, 0.0757443847795648, 0.06225754476843342, 0.04081026215346591, 0.010050984508838626, 0.026879462698895126, 0.05651374692998587, 0.08043436739113062, 0.04662793768089145, 0.06551655940711498, 0.05498170131637205, 0.035317794780337045, 0.017661933013568484, 0.046251524209735856, 0.038379936313797394, 0.07019828359085707, 0.008377661748278526, 0.01385212509757689, 0.02233417302880797, 0.0431942128606381, 0.0649621952024679, 0.019404126120911493, 0.029628260864786087, 0.0408560435678209, 1.9136616491502332, 22.660968072952766, 48.29146454411168, 55.97588977506084, 50.159881653324256, 33.33139957920198, 22.691778290656305, 19.324145009440763, 24.812433219725087, 31.498440696347146, 23.719092146042858, 5.561357063631858, 0.5734325620916583, 0.03559196232667854, 0.35252783026906753, 0.6683033584587036, 2.933832133008588, 5.906297651029402, 7.238542447167059, 5.248889778890918, 9.531275187769245, 8.279998898506165, 11.134972514644748, 12.012127253317065, 10.287730751499053, 18.58237578022865, 27.62569831263635, 40.181940678627264, 48.60457951022733, 52.19817661469983, 54.54035328280542, 59.44708147356587, 60.576186718479285, 57.72410977271296, 53.53390055318033, 53.37422086346535, 52.374726418525945, 49.94126835177022, 45.97584624444285, 43.00899290269421, 44.315675612418886, 52.36002145274993, 57.893356123278224, 57.92374664737333, 58.27043317979383, 56.65458533071703, 57.430237954662694, 48.07548315294328, 38.89958058634112, 48.67657069237002, 58.10625060912102, 59.09743747403545, 61.3895490092616, 54.240546918684444, 58.334316822790335, 58.7706648149798, 57.41777658462525, 55.93081781941076, 54.590139927402625, 54.08525636119228, 57.01506291666339, 56.76190530100177, 52.401484827841486, 46.026319303820216, 40.33222236940938, 59.858298840061316, 57.57556176954701, 52.11054302030995, 44.12039256864979, 43.59046859125937, 45.239958609304125, 48.44666488708989, 52.10079985280191, 55.23387539771296, 56.5647199076991, 54.44283923795147, 55.24779588945451, 52.691728453482355, 54.75605226332142, 56.47390919346964, 51.78323299654069, 51.224169731140144, 45.210827166034335, 40.495232151400664, 40.38689628724129, 44.07392424921836, 47.214620959374216, 52.80031142696258, 55.36887161193356, 54.77951195932204, 55.322069891037486, 53.85404440664477, 56.74836527916693, 55.81259366004698, 58.35648213663409, 53.519223043995524, 58.875043007635306, 57.02707713650119, 56.18217898953346, 53.21133659731958, 51.53984208260813, 36.7783784866333, 29.042391738583966, 8.336737944233803, 8.378598459305303, 21.912952469241237, 14.919545900437141, 11.62377534374114, 10.128617844273968, 9.243214361129269, 2.5196700471062816, 1.140184469761387, 0.3837493146138807, 0.1255033506200679, 0.1455347035681048, 0.47376574888344736, 4.776931568499535, 22.45272355694925, 37.85029949680452, 30.60687222788411, 18.829777317662394, 22.758368369071718, 36.91121347488896, 48.54706971876083, 42.254156297253026, 28.97200284465667, 5.614753759676411, 0.12543558248228606, 0.03462329394214096, 0.044184550042113954, 0.004414526601096675, 0.043578015249823375, 0.05908846119118314, 0.007574218898005183, 0.07368977527104079, 0.030744263278921286, 0.052318258751784606, 0.11217669959390357, 0.046998555696899855, 0.013101609825577228, 0.05320270726036641, 0.041080645225461454, 0.033241631388063395, 0.034085029075222636, 0.06186335805743452, 0.010146723474345861, 0.017427173030051975, 0.011343751177792589, 0.03552527054243031, 0.05997868600271403, 0.02188414808422808, 0.02722908990577825, 0.040009252111157106, 0.03390271547100237, 0.01846599208581592, 0.02642830585940711, 0.05089493250594505, 0.029665195878835458, 0.05783120365512948, 0.02964501329247029, 0.03491759044869292, 0.04483042727975596, 0.06028117198917655, 0.03165466493115791, 0.06775859232631422, 0.019476739764814417, 0.016920503544350787, 0.03697157559555866, 0.04174198594785506, 0.05931136596407141, 0.03412702218479207, 0.08050744451822774, 0.12403636885386322, 0.07298148101976804, 0.025194270363558206, 0.010543149077303467, 2.3518053514342157, 26.821594776645785, 55.09432923409247, 61.14712692076161, 55.96697422765917, 37.301250042453894, 21.895042927034442, 22.288107564372403, 27.863609675438177, 33.42844293963525, 28.00141626788724, 6.578565422565707, 0.5665098851726902, 0.09863822525667568, 0.18621676090744235, 0.32706383375390885, 4.148984618725316, 12.541272640228273, 10.76429872743545, 9.793364040313229, 9.394227573948523, 8.874550788633286, 10.71704593396956, 11.00268763880576, 13.146271763309358, 18.190703584301858, 30.201148140815, 45.76017472051805, 53.6556823022904, 55.132901822367025, 56.00488785774478, 60.435452076696585, 60.773148536682136, 60.76752385785503, 56.54607295989991, 56.077883166651574, 54.474437852059644, 52.430671184293686, 47.1813278813516, 45.158200725432366, 46.54955171769666, 55.127889033286806, 58.379012230903875, 59.87944826003044, 60.209354892853774, 58.135460499794256, 58.91714180669477, 50.75932179727862, 40.52396743528305, 49.72116062718053, 60.491643951785186, 60.68775853803081, 59.79792179599885, 53.16828466230824, 58.515981397321156, 58.59540547094038, 58.395074336759514, 58.172220953049205, 57.55532233945785, 55.618785427462676, 58.56787435470089, 58.82640169512842, 52.87869607248614, 49.818203987613806, 45.120812692949855, 61.85573447135187, 58.99476943477508, 54.88634947807559, 46.29596264131608, 45.77063960413779, 47.358156173459946, 51.990016429655014, 54.81482113561323, 56.868268212964466, 57.015412007608724, 56.34231367418843, 54.44602812490156, 54.01843878530688, 57.13753892529396, 59.258956755361254, 54.89098179724909, 52.83726799872614, 46.79762986398513, 43.04623188511018, 43.75395298004151, 45.79955923941828, 49.98667763125513, 55.26708610596196, 57.242234829933416, 58.44226044993247, 56.07067385027486, 54.24956052534042, 56.76311339101484, 56.914199167682284, 58.4816449688327, 55.619362015878, 58.67624944256198, 57.1193548171751, 56.88773101375949, 54.28785854770292, 51.60429446927963, 39.01718501121768, 28.44099433191361, 12.371129047486091, 13.588620001269927, 19.2095313918206, 16.456131473664318, 19.241433989617136, 10.877687584969307, 11.807159877592518, 5.60538076585339, 2.388038245900985, 1.0507019681315268, 0.30692669172440806, 0.2534555319336153, 0.7336136410313269, 6.286641061306001, 24.016641186129664, 38.8941284918016, 34.77649880993751, 22.362332536328225, 28.133247129378784, 42.86763460405412, 53.21325071396367, 49.57577797674364, 33.69528178245791, 6.690866802969287, 0.15724763634704775, 0.03472632510707744, 0.008062932719176095, 0.06618789757692045, 0.05129766875817891, 0.07202025517941484, 0.035292073378279325, 0.03400403442942808, 0.05581744961560734, 0.03320584742112025, 0.05382261411737531, 0.038855282379494566, 0.054658358586170984, 0.05428901993699613, 0.055356318311345194, 0.01890960295924977, 0.04353827443875132, 0.008878499389656128, 0.030824388414921782, 0.016313712112605572, 0.08244996770255028, 0.06293315004797713, 0.07627574336384574, 0.011108470254487569, 0.04242468137113799, 0.1923322109805961, 0.18147046317256268, 0.13160370110023406, 0.24942319750064806, 0.16945829645039576, 0.1508973190380681, 0.15031686953959927, 0.15113074602859636, 0.1998437643652001, 0.09287199636380519, 0.2557507007112426, 0.13534044816849694, 0.17064705040426026, 0.14350274727950174, 0.1215405922923838, 0.1787037825992992, 0.09809178240116566, 0.1665329437462553, 0.10178224243704351, 0.12606971942248846, 0.2770450951591615, 0.16324927639817038, 0.14159057649873918, 0.12623371586443918, 3.223928669767995, 31.590390859111665, 63.3727817381582, 68.49809185151132, 60.67614047758041, 44.17730223747992, 33.47209499728295, 28.721194728728268, 36.636541658832186, 43.57670891669489, 31.886180716176188, 7.61898881966068, 0.8248823532654393, 0.11049111463850546, 0.7570347874875992, 1.449229118804778, 9.426331193216386, 20.783757009813865, 14.779646723501145, 19.201714108067176, 22.65662208680184, 21.44300545415571, 18.92259628542008, 19.281491195001912, 15.396508074575856, 23.616418223227225, 36.23342790911275, 50.39306656006844, 58.575585734459665, 56.66278308437717, 58.58120256854642, 60.40404173635668, 61.25879287719727, 60.59167615828976, 58.591577237652196, 57.51149769752257, 57.67098126872894, 56.19125927648237, 51.31205043485088, 47.22866696696128, 47.7923664739055, 58.34878644635601, 61.755231580426624, 60.37483184568344, 59.9791862887721, 59.50196327701692, 62.97653605861049, 53.03968191146851, 42.74174221100346, 52.22758654625186, 62.419579105992476, 61.26241714723649, 59.039029459799494, 52.46479580479284, 58.30330264183783, 60.30962636393886, 59.7108647900243, 61.948882918204035, 60.34495907445108, 59.5265055471851, 61.399347089952045, 60.14381208727437, 54.250819606165734, 53.07155901385892, 47.58077813733009, 63.638667445028986, 62.49581037029144, 56.75406056065714, 48.0910784967484, 47.712914943695075, 49.59371105317147, 53.62359339191068, 56.77230742669875, 59.634574690172755, 60.39324345127229, 58.94316673278809, 57.57156487434142, 54.32852175927932, 57.21081272248299, 60.30901839656215, 56.01760025947325, 55.69552659988404, 49.94585360250166, 44.468448008260424, 45.14307606604792, 48.02128384190221, 52.06116822458083, 58.21674769924533, 59.214296648579264, 59.57101268153037, 57.05975832477693, 55.80278773461619, 58.188769432806204, 56.118436551863155, 59.65808145461544, 57.16180662955008, 61.55077411282448, 61.42094366012081, 60.513201298252234, 57.970905303955085, 55.034705285103094, 41.356062966008345, 33.22708806683941, 13.488563279951773, 13.697797213831256, 31.688769786588608, 25.366813175139892, 23.9428614031884, 18.77864726128117, 17.532143515925256, 10.386460731106421, 6.130049257509171, 1.5968040064457925, 0.5015005832237582, 0.4581725807680238, 0.8898081822741417, 6.9824386412097565, 28.224118640345914, 48.191797118033136, 42.036421606617594, 28.988104174214026, 34.60526381769488, 50.270457190852014, 61.39134937717069, 57.01757715594385, 42.83549862523233, 10.37672148596856, 0.4044411962311114, 0.10296656074182642, 0.17002667240317793, 0.1648086483680433, 0.16052632412362486, 0.20834567025303843, 0.15923715136464567, 0.12299612104412048, 0.2330600037690132, 0.23004998302748128, 0.24549241568292343, 0.1853559998374793, 0.09850115680526342, 0.1706818001525056, 0.1198464731175092, 0.15242756434505986, 0.15537026127980602, 0.11041907173010612, 0.13932015236106612, 0.08895694999204529, 0.12982410949564752, 0.09925709406454718, 0.2661018662395016, 0.10202312346307502, 0.11472204970496316], [0.07617645836885899, 0.059178786787895434, 0.043273499130361506, 0.0468290051174981, 0.09121998904212829, 0.029320892983026085, 0.08189966376390188, 0.036722003302026185, 0.015142656705011765, 0.06958176667291312, 0.05186140987901919, 0.04398822085931898, 0.036156630413907195, 0.021210364178724347, 0.0045020818323527854, 0.05218954448918662, 0.048188654135071465, 0.020718886216561642, 0.06436784120817339, 0.03845655276710468, 0.05796791970609658, 0.01423289665141173, 0.11061921220032439, 0.10325274054682064, 2.0412927553538354, 19.504066090429983, 51.26851604830835, 58.517354226881466, 51.49876309979347, 42.291540407365375, 32.51441497956553, 30.496161368585405, 35.21565129680019, 35.40994590328586, 18.151491649689213, 3.0129539389764113, 0.1597078051418066, 0.06376853445544839, 0.21194427634679505, 0.3062232391488168, 1.6654224405365607, 7.807486653327943, 10.707919559171124, 5.7608125286717575, 5.065357175565535, 10.828596180485142, 9.562908122616431, 9.765055314187082, 14.516088943327627, 29.381664991378788, 36.98789973412791, 53.29693448159003, 56.50077742915, 56.546488731138176, 57.05510247138239, 58.928100908956225, 54.23432211722098, 54.37613541080106, 52.342315873792096, 52.27720060656148, 49.59928081881616, 45.2024725175673, 44.49853650985226, 43.26608857800884, 47.869660700521166, 51.204361761769945, 56.38922129907916, 60.06525485746322, 57.1046616185096, 57.54506926382742, 55.50702925651304, 44.82359117077243, 39.78642848230178, 49.495675333084606, 59.0027436133354, 59.43489074707032, 52.25112076728575, 56.433159689749445, 60.06968321338777, 54.38115212225146, 52.58707177254462, 51.41489105839884, 51.19939211876162, 51.24088295044438, 52.77224686837966, 55.35586503244216, 56.04788880194388, 27.895861364180043, 39.25964632341939, 62.220707093515706, 52.007200333379934, 54.459195521570024, 46.54621378068001, 46.86607522349204, 44.251870416825824, 43.99747333218975, 47.69315404276694, 52.13614040805448, 53.68599437898206, 54.71650692724413, 54.55789412221601, 56.04148749382266, 54.24925458046698, 55.511536059841035, 57.97505517159739, 54.01213161406979, 49.23767751263034, 42.37389449150332, 40.27720720537248, 41.09076953703358, 43.93908492980465, 48.41945932757471, 53.34977665255147, 55.73871189548124, 55.02588779695573, 54.567837330602835, 56.42048258935252, 52.84817218780518, 57.53333745464202, 58.175539278214984, 57.70244652225126, 57.751323176968484, 59.93038808145831, 54.66650847465762, 53.94088175988967, 44.59743907374721, 37.07612560641381, 18.600322584952078, 20.16939813090909, 23.26853536790417, 6.130032587435938, 11.308355004556718, 8.911779965123824, 9.357627937870642, 4.471940321307029, 1.3114692270755768, 1.7282743776036849, 0.42619588694745497, 0.11875524981728486, 0.17283620793492566, 3.319174849217938, 15.100131823170571, 41.3537879913084, 32.703945867476925, 29.05195643824916, 27.426481131584417, 39.966610400907456, 47.68194783118464, 49.70595752039264, 34.16443647876863, 8.510133181848834, 0.6929441781774645, 0.16143306579080322, 0.03803864031309082, 0.025215866382143674, 0.06449219260004259, 0.07460705830805725, 0.031496182407042196, 0.016655931249260902, 0.05202244539114256, 0.05106057220649335, 0.043646116635852286, 0.04197943106954617, 0.08338284062882585, 0.01899566144622382, 0.06982191991541656, 0.030368556523875847, 0.0698209086793565, 0.02229049644102493, 0.05712727227458551, 0.06775008108947547, 0.1026741526420078, 0.052345152268366474, 0.043246743509606014, 0.11519930716003142, 0.05644855667806922, 0.0633174695465113, 0.02823703178775407, 0.05554666434745154, 0.03577819064019188, 0.02979284527921869, 0.0610194624131245, 0.033249686802587206, 0.009993622717898219, 0.062816831087994, 0.08082360134369905, 0.04898821627120337, 0.02649860974821833, 0.027135288185109536, 0.013373661054027899, 0.035394763634089506, 0.017250340784929933, 0.04700130595254803, 0.0408330264561359, 0.0417478809944324, 0.018294813569575068, 0.03333384922194866, 0.006025712927728291, 0.022424324340517485, 0.028698929179940495, 2.6850008916470314, 23.423086558618856, 57.41280694161692, 64.25464037925967, 57.22250923033684, 47.08015426512688, 37.3312287176809, 36.31996716222456, 37.09502750827421, 34.59470871956118, 19.938225400063303, 3.6597091440231573, 0.3264561728123696, 0.03559219215305583, 0.2796842680583077, 2.1514511733285846, 6.244252497150052, 8.351360540236197, 13.31440023837551, 10.381485204542837, 11.371961139863538, 9.640902492307848, 11.734075334764297, 7.1720568018574875, 14.291687203991799, 29.698423839384514, 39.828778313052275, 54.35128719575944, 59.30486025348787, 58.853399369024466, 59.863617574014974, 59.50936478953208, 57.92065581967754, 56.61342790049892, 55.454591089679354, 55.45617964959914, 53.060482240492306, 47.797814646074855, 46.65147842899446, 45.13121089627666, 50.443402336489775, 53.14735881743893, 58.1509970080468, 59.96117868731099, 58.237512726937574, 59.10629418588454, 57.59859784956902, 48.71907349555723, 42.39738556646532, 51.89207876882246, 60.93625637792773, 60.310293166868156, 54.69685193031065, 56.85491254252773, 62.07423402417091, 57.23353109052105, 55.82303108707551, 53.699714829844815, 54.02832708051128, 53.685237361538796, 55.59971878605505, 56.727235471048665, 56.526217922087646, 32.38603776501071, 40.00614789224441, 63.3327421834392, 54.48493019227059, 56.20332840950259, 47.671341742238695, 47.493670140543294, 47.56256265024985, 47.40441268490207, 51.035527260072776, 53.9059099074333, 56.05707499288744, 57.1588413176998, 56.73280915906353, 58.465598552457756, 55.17700495258455, 58.484822088672274, 59.99714289942096, 56.218919830937544, 50.8100341212365, 44.47925413808515, 43.202255925824566, 42.82006802097444, 47.06039728656892, 51.78323691891086, 53.98704021207748, 58.81725472788657, 57.05601638363254, 55.968398048031716, 54.76989430765952, 53.55123742934197, 56.234750516953014, 59.28171434710103, 59.5745938054977, 60.38596745460265, 60.59906198132423, 56.63881348025415, 53.764539841682684, 45.098439493486964, 31.75202585035755, 20.55583200147075, 15.91398637140951, 9.160638663076586, 11.572232457899279, 10.457616448402405, 12.08978626035875, 10.992418873694636, 9.304825971203467, 4.544639000969549, 1.5776554855608171, 0.16170859697364992, 0.07700472964995331, 0.14394482597708702, 3.423839129747883, 16.125293277925064, 40.12758447277931, 33.25856116510207, 30.62231459925252, 32.93169044679211, 46.924369488993, 54.40015208336615, 55.409323015520656, 38.72234044536468, 11.49471269499871, 0.8747311429150644, 0.08300498308193299, 0.0443105370317015, 0.03380620754474113, 0.02460629596645313, 0.08306246265889176, 0.04668371654265831, 0.026137470155053084, 0.01949871116648278, 0.05514981165047615, 0.014261838495581141, 0.04324240362151496, 0.05264258590496836, 0.00985522127349771, 0.031039902354560556, 0.042084297015061306, 0.05900116547221138, 0.023691014334138845, 0.03072523173966235, 0.013442947961119635, 0.032232647626510555, 0.042224035282889684, 0.07678511522469983, 0.023090841902059414, 0.03473088716066653, 0.25619768237154333, 0.059799455902388984, 0.13043609117307972, 0.20407451557055598, 0.1277423881354832, 0.17213725995632911, 0.1771126639458441, 0.14119794111578696, 0.1311685325157258, 0.15886907676054587, 0.19464510703279128, 0.15095149677607322, 0.10037190521196013, 0.16870343937508522, 0.1399262964485153, 0.20639974563833208, 0.1118310560442267, 0.11451394958121162, 0.14281725180485558, 0.15964150789283937, 0.124817043092222, 0.10135360858252934, 0.1559884482694249, 0.1472964912893311, 3.7668530979464134, 29.100552643499068, 64.45102168667701, 70.20238522560366, 64.83036195078205, 55.08620208309543, 44.46102296152423, 41.87798530824723, 48.25491589884604, 45.73339277698148, 22.800212214069983, 4.485358749666522, 0.35551689084499116, 0.15681769248218308, 0.4576029177875288, 2.820249363299339, 10.96872187429859, 17.07735057800047, 23.55559599015021, 18.213347427306637, 13.427810668945314, 20.48476649868873, 20.982240707643573, 15.599322069075802, 19.44574829070799, 35.988228782530754, 42.86189225412185, 58.30870766793528, 62.899355580729825, 60.989941858476215, 61.67574867125481, 63.48444769459387, 61.65326956779727, 59.639709072728316, 57.193134600116366, 58.24265103186331, 54.6377065104823, 50.849014636008974, 48.10046865094093, 47.06684566313221, 51.53543333853445, 55.98500144097113, 59.75253605073499, 61.29122695615215, 58.76667576451456, 61.137560259911325, 60.33396074848791, 50.356349252885394, 44.57505018480363, 53.321472829388036, 62.145150476886386, 61.7149684506078, 57.11886844327373, 58.361824404808786, 64.57993038239019, 60.43915087176908, 59.02140625061528, 57.0284499660615, 56.167450489536414, 58.58837266122141, 57.207380648582216, 58.628318079056285, 55.73496995433685, 34.8264580388223, 44.5731988260823, 64.55489781595045, 58.369221994953776, 58.811751642534816, 51.43820562670308, 50.107412107529186, 50.342515053287634, 48.01995808078397, 52.700820507541785, 55.71364795008014, 58.047156180104906, 60.53713167867353, 59.73448922557216, 60.7285943338948, 56.61615787013885, 58.603662060153106, 61.811729400388664, 57.57481259684409, 53.95703800262944, 47.57070549072758, 44.93920303160145, 45.315766257624475, 50.15987773095408, 53.92108948000016, 57.70645910693754, 59.39490218316356, 58.633170050959436, 56.776888755060014, 56.202461565694506, 54.895747477008456, 59.65979553038075, 61.44216368275305, 61.64583275395056, 61.260734450432565, 62.89290328179637, 58.33844707858179, 55.78367010239632, 50.031004336572465, 41.31578414670883, 22.344766201511508, 26.66243676216372, 33.63631286928731, 18.55391113988815, 23.625165108711492, 19.004373781142696, 21.256528131423458, 11.235351850909572, 7.218633967061197, 4.756462189459032, 0.8329890956801753, 0.4886880078383031, 0.31254603857955626, 4.418108242173349, 19.2381235091917, 51.277455129931056, 44.441422877773164, 41.568557370093565, 39.82262019188174, 52.015362785708525, 60.3306894917642, 64.13644759885727, 45.646296547305205, 15.035574513096964, 1.4498756970128706, 0.35441568541911345, 0.12874646893432065, 0.09226879405398523, 0.14997972956588193, 0.12076217801340165, 0.2712679954786455, 0.1262173062611011, 0.167072024496813, 0.14728594991949298, 0.17248547756143157, 0.21590495091532508, 0.1676814321188196, 0.1039297707499035, 0.19966692062875918, 0.12727656071224522, 0.15384438267398268, 0.14858305934936772, 0.15773189584574393, 0.19296717529575672, 0.15208570526972895, 0.20144962255031834, 0.14970850379716966, 0.17839239850159616, 0.12774683910632326], [0.05404404417100934, 0.014905201049611695, 0.03714949568553317, 0.03813058235532334, 0.04635416083939133, 0.017771462519322673, 0.017322596282728257, 0.01607489952396962, 0.05361039627103075, 0.05874336156393251, 0.019827004739894502, 0.015413071378134193, 0.05784340360532365, 0.07296871033407028, 0.04329819397460069, 0.05932315222678646, 0.09732849835868805, 0.10848519001756946, 0.016418308012127396, 0.06818118174710582, 0.06954903939678785, 0.06724357439745819, 0.04395212279632688, 0.055254003438617916, 1.8064276032870816, 22.210470130366666, 50.48275939879879, 58.16641584519417, 50.33377209017354, 35.97350028253371, 17.870512662395356, 22.40886361368241, 38.72967527758691, 32.260184595661784, 12.969411111647084, 1.633989669142231, 0.0763725079295616, 0.043395264975486264, 0.10632074648334135, 1.0205329353770902, 5.061812333522305, 7.428551864239478, 8.774775497374996, 7.049678362184956, 7.995071555337599, 2.2292621722144466, 9.059674893656085, 6.823854763661662, 21.207924081433205, 35.14747265846499, 46.49476797349992, 48.47054819906912, 53.82742720265543, 58.70791473696309, 59.402166412722686, 55.302642391574004, 54.01050383044828, 51.277796376136045, 50.754006985695135, 46.54813966443462, 46.03801188930389, 43.31524372100831, 41.20072141770394, 44.28611270843014, 46.04446026586717, 52.769528665850245, 56.25824159191501, 57.7287930826987, 56.85710122508388, 56.545013919953384, 54.395331490424375, 44.81565621591384, 40.04217486227713, 47.05470200507872, 60.50563896856001, 55.469817730688284, 46.239511889796105, 61.47450362482379, 56.972140419867735, 53.725116099080736, 49.125603629696755, 45.74548544422273, 43.41299310807259, 48.36399701333816, 48.571572765227295, 56.54277424658499, 49.99019599729969, 21.822345718260735, 37.35894810768866, 58.20507080324235, 55.08676690440024, 53.1932544708252, 54.196404564765196, 51.24048679105697, 48.22747107475035, 46.209419465834095, 42.004293472536155, 42.76508815826909, 45.09058690840199, 49.673339090039654, 52.504674542334776, 56.39488912397816, 56.06142882377871, 53.08740538935508, 54.89182118446597, 57.31403773830783, 51.68061202572238, 45.64147595436343, 39.97005031954858, 43.50010502722956, 41.52836876530802, 47.34989566187705, 52.438923851136245, 55.252294848042155, 54.43706158668765, 55.532497206041896, 54.54457375311083, 57.11035297762964, 58.16357997155959, 55.16733631010979, 54.93136259817309, 56.53785167201873, 58.09171822763259, 58.2812471543589, 53.47271942323255, 46.63639691568191, 31.80832951299606, 26.67129739638298, 22.7465541901127, 5.501617404722399, 15.992410240634797, 16.89404841392271, 10.591625205932125, 10.521846240566624, 5.692767250922419, 0.83788396850709, 1.0730837477791695, 0.1837327208129629, 0.09113497626517089, 0.14306016296388643, 1.3641726441921727, 9.687644397058795, 26.48533586532839, 33.39206295628702, 30.74102709370275, 28.6476130254807, 23.56489985219894, 37.47800773189914, 50.76395019408196, 39.35333213498516, 16.907719835158318, 1.3569113564106727, 0.06799718274945213, 0.0425015353117018, 0.04809164059078021, 0.035187640272441416, 0.05051196898303686, 0.058411702949313395, 0.06380057991332104, 0.025471946592592908, 0.019904153624309168, 0.023506572920708887, 0.011687991828958114, 0.03010539000012702, 0.05585715212228318, 0.005758491883640208, 0.0346781381766402, 0.035895122470514434, 0.0424040123189409, 0.04061940666888991, 0.03745073677911874, 0.13056571324986796, 0.06451136011990809, 0.009283072337688459, 0.017816535302347714, 0.0944742845791963, 0.05275089541570314, 0.07108539808541536, 0.059906589468159986, 0.11568771119439795, 0.03361119986361554, 0.025331384780245925, 0.03334341766012292, 0.06389098594926539, 0.07800764599514586, 0.047077248248481945, 0.026369746098475113, 0.0326626374566507, 0.03732541628602532, 0.0344147801309103, 0.06880025739871687, 0.06841659290535797, 0.09520880202011717, 0.021392875050585118, 0.027473575375493497, 0.07092627396266307, 0.02392800554873482, 0.0441116452847998, 0.010127518607694055, 0.09145337006738109, 2.4101410469701214, 26.034463336390836, 57.57142759138539, 64.56808090209961, 56.61248653165756, 40.74811127878005, 22.329641542127057, 22.346717580672234, 34.7784835292447, 34.609041060170824, 13.807861862644074, 1.9736250057335825, 0.053992750754039136, 0.07518961454831785, 0.3886427165519807, 3.0735655898048035, 8.19463243407588, 10.75860736831542, 14.69918224119371, 11.434844578466109, 7.903449891075012, 8.897383885998881, 6.423481770100133, 8.360877190866779, 24.47079085534619, 38.977969154234856, 46.44282794767811, 52.05444920447565, 56.88131793852776, 60.21934124731249, 60.6277580415049, 57.685333221189445, 57.74342744581161, 55.82280358960552, 53.62200483199089, 50.99437375222483, 47.595235993785245, 45.35620197173088, 43.920426214894945, 46.412213848483184, 48.56215515444356, 55.462718240676395, 58.32277720974338, 58.98785429616129, 57.00070704183271, 58.86978310923423, 56.069108824576105, 46.91632470776958, 41.816011859524636, 49.715551637834125, 62.04581252990231, 57.34954695547781, 50.297015559288766, 62.80053930897867, 58.1015633767651, 55.46775848634782, 52.69674516493275, 48.57591875137822, 46.13265868156187, 50.4900550073193, 52.064839563062115, 59.554091576607, 50.87679678393949, 26.46480029629123, 40.27902718513243, 59.67137828949959, 58.274481065811656, 54.512104372824396, 55.17735012115971, 53.23572981742121, 48.97178396101921, 47.96886920928956, 44.084749990893954, 46.30650204996909, 47.49161089620283, 51.086518072312884, 54.94692264064666, 57.45485867223432, 56.85857995863884, 54.28115521707843, 57.820737361907966, 58.38695110813264, 53.95095832886235, 47.68120650322207, 42.42579137125323, 45.87859892076062, 43.58069012241979, 48.61037285097184, 53.87967709572085, 57.70807120107836, 55.20276707987632, 55.46852334853142, 53.94436482460269, 56.816587063574026, 58.262808092178844, 57.159190408645145, 55.61282734717093, 56.52075798280778, 59.457059983284246, 59.36147966692525, 54.714330011798495, 49.97672265575778, 34.74037378065048, 25.417853017007154, 12.992523677887457, 12.238068522945529, 15.981294243566452, 16.19727759591995, 11.3186296532231, 11.463844622335127, 10.780143141746523, 5.014067282599788, 2.663426384810479, 0.6759919394408503, 0.17980327198822654, 0.1681797569918056, 1.7069403610883223, 11.740024589723157, 30.0114054449143, 36.54363247656053, 36.42594568191036, 35.86385826910696, 30.425629308146817, 43.04282334543044, 57.70438025074621, 46.87201369193293, 19.628167921496978, 1.6621351266099562, 0.05299355376571898, 0.02979608391591859, 0.04830605710946745, 0.03996545103408637, 0.042434870340530916, 0.014797783073698802, 0.047725324158466635, 0.04069995698368838, 0.04771127793637495, 0.04170701786455128, 0.03452516573991987, 0.020055021234457533, 0.01861506705022147, 0.015803178670936297, 0.029834583664553303, 0.051518210149820776, 0.026435185328967152, 0.06433114559660036, 0.030503460776902018, 0.011199683555582119, 0.03736292012035847, 0.01701591213444068, 0.048787133512838234, 0.05455704728862452, 0.1373728028228206, 0.1356788598481686, 0.07220674396282242, 0.17436151963568505, 0.19209720584894383, 0.16093153867029375, 0.10042730102976484, 0.19094048969207272, 0.19056516789620925, 0.1409538808248697, 0.11752323487833624, 0.1390012912452221, 0.074060607791668, 0.13628037676455515, 0.30961415880630094, 0.23057839983413297, 0.18082845084849866, 0.20847254973505774, 0.21696179985038697, 0.09830072522163393, 0.1631332293994004, 0.12415485201223243, 0.09244610510405996, 0.12598357283540312, 3.6802596670965997, 32.68372408805355, 62.70239376252698, 70.63576006120252, 62.7293247561301, 48.24934613320136, 26.89340356857546, 32.80097746079968, 49.95863268452306, 41.88490829160137, 16.79031937353073, 2.342511050162777, 0.31196641645604567, 0.20361503135533104, 0.6270105451826127, 3.3352599989983345, 8.877712218992173, 17.620947937811575, 18.065938872675744, 18.15864605288352, 21.61807848561195, 9.11892621747909, 16.819593983311808, 12.185994155945318, 29.4307142303836, 42.96163420523367, 51.8493837694968, 53.450248164515344, 59.277231077994074, 62.48632607921478, 65.55560035090294, 60.702196782635106, 59.466061822829715, 57.598958707624874, 55.63651846301172, 52.86973737901258, 49.948461978666245, 50.044501212335405, 46.49250084354032, 49.41634147397934, 49.18957356483706, 57.999271885041274, 61.32584971766318, 58.956177234649665, 57.57738174930696, 60.60395317692911, 58.71100164228871, 49.14541552143712, 43.73408225274856, 52.28436285449613, 65.87142959717782, 59.21579891635526, 52.389254877644206, 64.4343045450026, 60.54986761462305, 57.92522538092829, 55.46721719926404, 51.285566591447406, 46.845561227490826, 52.95234249484155, 54.378041682704804, 62.106836765043205, 52.27232510043729, 31.05803305102933, 43.50391757103705, 60.48593298081429, 61.74070704367853, 56.94799430908696, 58.73905443376111, 56.54875978346794, 51.29973419250981, 49.37575670980638, 46.22588557581748, 48.07616172298309, 51.3377772608111, 53.87205985284621, 57.072513872577304, 61.032746684166696, 58.45185064500379, 54.81221668181881, 59.62508255435575, 61.3190326383037, 57.07763256565217, 50.19567328114664, 43.616156193517874, 47.47691769753733, 44.71328627678656, 51.50648624666276, 56.70237548889653, 58.683141046954745, 57.22536471582229, 56.94032607540008, 54.84910265091927, 57.71371549175632, 60.844143436801055, 59.22223160343786, 58.67816355920608, 59.86767330477315, 63.0103547342362, 60.85391013853012, 57.650071113340324, 51.832074349926366, 37.687960440112704, 31.272916178549494, 28.354694343382313, 12.83695855448323, 23.905912676165183, 27.09834937126406, 18.317023515701294, 20.078783535188247, 16.368174283735215, 8.320329689210462, 3.303876134657091, 1.257973736332309, 0.2346436607260858, 0.527787450100145, 1.9640192437556483, 13.219460248947145, 34.64673895989695, 45.553234392596835, 42.48497993715348, 39.821345421575735, 34.64205172754104, 50.25352431881813, 66.2370180314587, 54.254165387922725, 24.852602212659775, 3.205279270487447, 0.2586035508542292, 0.17397409365061792, 0.13215467153537658, 0.11501590571095867, 0.18798371206127829, 0.1334299627811678, 0.09188067092890702, 0.11648372251300082, 0.13790996835356759, 0.13677769040148105, 0.09754422105728619, 0.07827130281516621, 0.2264807181012246, 0.11437962372456828, 0.12339248727526396, 0.19211672576925448, 0.12936919116445128, 0.23213162777885316, 0.09271896264005093, 0.1688375354053513, 0.189136567135011, 0.07766876700184039, 0.1019841219268499, 0.25744133418606174], [0.020505071076894962, 0.09802347034095757, 0.07733201773296441, 0.09383489993671257, 0.025204668091910503, 0.008650308610090326, 0.04491539792187753, 0.023698303660738374, 0.04082372997917476, 0.04835185767602056, 0.128097684393006, 0.004763495929974822, 0.05869927320389017, 0.03792041762461586, 0.00396299270270843, 0.07387644025467097, 0.037327365979792616, 0.04422367798284658, 0.04583983238966716, 0.020271414259989417, 0.06099141976465622, 0.016472711746070175, 0.027155171997184237, 0.027276064502075318, 2.5189841226223977, 27.086125304622037, 49.904209798382176, 53.49384530898064, 52.38814092451527, 33.00646258938697, 26.17190318722879, 42.13562227064564, 42.903669418827185, 25.297042054514733, 7.88050304497442, 0.6915736162374098, 0.0735866521755534, 0.06732167706133858, 0.9324854083599584, 3.102333478389248, 9.438918079099349, 6.755189261128826, 14.442005176698009, 9.733464544819249, 10.27381222094259, 14.265533820275339, 8.827168556951708, 9.025667944262105, 21.16006724296078, 34.98473744238577, 46.25951990004509, 54.701562696887606, 56.64039419543359, 59.376102262927645, 55.477070193136896, 53.112508558457904, 47.57774222281672, 46.20416348980319, 44.817668391812234, 42.51851620212678, 42.78399398249965, 41.29122618705996, 42.43738981985277, 46.03269315535023, 52.58686780929566, 52.28023259870468, 57.47182292322959, 55.94521684031333, 54.189826749986224, 55.07798471758443, 55.6154671022969, 44.4679420225082, 41.39843633097988, 42.57342938453921, 57.85576412754675, 57.27695957306893, 58.449665884817804, 56.00341696893015, 53.73323540533743, 48.8453895045865, 42.108569683567175, 38.42700166086997, 42.047565060277144, 48.05547514269429, 54.440619176433934, 53.68228773916922, 54.06125930047805, 18.543326623978157, 43.790835026771795, 61.77188988654845, 53.31509113311768, 56.38526362757529, 55.52826889099614, 58.727785464256044, 55.52545262921242, 55.79093040958528, 46.18826220112462, 41.481645491815385, 39.19847696058212, 44.07705822298604, 49.83554870851579, 53.16196964633081, 54.02945280075074, 53.524765353049006, 54.24465364025485, 55.636365490574995, 55.17531441104028, 52.73074426958638, 41.182184296269575, 44.30054703066426, 42.3528431307885, 43.374746076522335, 46.66825832859163, 52.806771570636386, 56.31555134250272, 56.00904164775726, 52.65502683577999, 55.32620406919911, 52.43228327843451, 54.64070712366412, 50.45808769041493, 54.48572643341557, 54.95904276447912, 60.95922970002698, 54.61765143179125, 53.28275903578728, 37.959462981070246, 39.65053012294155, 15.958605293304691, 10.680755184542749, 9.153099867605395, 9.300780046370722, 10.19375958750325, 6.575172572366654, 9.146944688212487, 5.329672463478581, 1.7601161786625463, 0.3395092385190149, 0.10982605072879985, 0.1612381423793493, 0.9250185025795814, 6.302677671755514, 23.77645092625772, 32.1430233986147, 28.542711196407197, 22.92953471983633, 28.518916137756843, 39.6190256457175, 47.653392976330174, 45.165559091875636, 22.246310787816203, 2.930404962070527, 0.10642516426742078, 0.04154851044257803, 0.018845268810588508, 0.0637596057006909, 0.04084026215658073, 0.04192754776487428, 0.030221638096977147, 0.08834745043948775, 0.024930222838696454, 0.0470467081533805, 0.014273185215349642, 0.062285472503713066, 0.018582799426850774, 0.02551074128507847, 0.005093849801097907, 0.0342840587179507, 0.04313004150566074, 0.06381389835188467, 0.003570461699235884, 0.03242407767702976, 0.04578216512116694, 0.0391629969160403, 0.0647778514652483, 0.01822404619756966, 0.01516619954453481, 0.04384050378575922, 0.02832674068368731, 0.04442735394883541, 0.05344174967537965, 0.012370578084711828, 0.03436405744944369, 0.04875622569553314, 0.03514365916470847, 0.07675791144250863, 0.06634203446728569, 0.029577589894254363, 0.03766129221466761, 0.04882817667338157, 0.014662355008054406, 0.011219194857403638, 0.03011836944478414, 0.08440771305392827, 0.07742458413685523, 0.0807813745773127, 0.01890538564522661, 0.021443812236670527, 0.02579920403208704, 0.05581548076964194, 3.820820498851038, 32.28746860258041, 57.77590859320856, 59.89159584045411, 58.613483675064586, 41.09376622784523, 29.219473023568433, 38.72740814762731, 46.45677589601087, 28.02619976382102, 9.271252443713527, 0.7784153821487582, 0.14206663885664556, 0.060747148799559766, 1.7612807548815206, 7.450135196408919, 10.876842314197171, 7.999546979704212, 10.258564006897712, 11.95883499037835, 11.136815048033192, 7.605327694646775, 9.114173285422787, 12.199490051115713, 24.811882126715876, 38.703042384116884, 49.07768403330157, 55.22485002394646, 56.66367346240629, 61.47741010112148, 57.90062035283735, 54.93909751215289, 50.80517822696317, 48.63453465123331, 48.058067829378196, 45.62193470616495, 43.4364410369627, 43.87599752795312, 44.62704904617802, 47.7970576286316, 53.03468481186898, 55.62888945302656, 60.413023964051284, 55.84110929119972, 54.922278388854004, 56.06903037717266, 57.231362019815755, 46.999808434517156, 42.37697747445876, 45.85593546590498, 59.960790372663936, 59.25199454830539, 59.5687416292006, 58.27459481454665, 55.976474208216516, 51.63538317526541, 44.4691305006704, 41.063399237971154, 43.71533724569505, 50.665416332983206, 55.69746817311933, 57.58117468126359, 54.99058646540488, 22.824397548552483, 44.425854990559245, 61.100689980291556, 55.75110266285559, 59.38741045613443, 58.265428235453946, 60.7807618571866, 56.37016642478205, 56.750110733893614, 49.14598426511211, 42.30037358499343, 41.98396382793304, 45.48619716398178, 53.282817871339866, 57.06458284008888, 55.89946631462344, 55.02446789895335, 54.99648571014405, 58.00829725880777, 57.00923427458733, 54.22222552760955, 43.02856945222424, 46.454610747675744, 44.15780805772351, 45.797888309724875, 49.90260162661153, 55.10679452650009, 59.07078496871456, 56.60704228185839, 55.193070980810354, 58.3952743776383, 56.907123211891424, 57.66456427112703, 55.14549263062016, 58.299729362610854, 58.80669962975287, 60.63369258757561, 55.82472947336013, 55.251047534327355, 38.57263926536807, 32.589850002719515, 14.570683433163552, 14.369056936233276, 15.403543826072449, 15.430080621473252, 15.022490466794661, 11.167047696728861, 11.219136772617217, 7.182841358646271, 2.859338233547826, 1.7161161332361161, 0.37172387924886524, 0.2230141396003385, 1.120597011139316, 7.490504720518667, 25.9047995844195, 36.68164107107347, 31.904621739541334, 25.837497595817815, 31.006522524741392, 43.043960832780414, 53.95218603072628, 50.02433238490936, 27.022457391985004, 3.7153474746211885, 0.10961755990020691, 0.01580480660777539, 0.022067909594625238, 0.003629731288510225, 0.004574022276492249, 0.11532445528334188, 0.06420596682977292, 0.0836054198143463, 0.0019791784565783136, 0.041677569444741935, 0.025215768705933325, 0.05198924314050425, 0.04380046036995707, 0.03638365673982809, 0.03554391712250729, 0.038141847678249886, 0.05576146391010093, 0.026493408011212468, 0.030559841017689438, 0.009245416243380357, 0.011849320369712528, 0.030426486177490126, 0.01708352130897824, 0.008213826184791904, 0.09562780614942314, 0.2703168513553758, 0.11188042275006733, 0.2643786587061421, 0.19795341176852105, 0.1455197648535813, 0.1306846100957163, 0.1301340533480529, 0.2105348431054623, 0.16774115633339653, 0.26058640090688584, 0.11701003257786075, 0.14203515264295763, 0.1592383004965321, 0.06881288252770901, 0.13619409994252268, 0.16434131941247374, 0.2035709812996849, 0.18450625511186738, 0.21026268270948242, 0.15943539959769096, 0.11905927947091481, 0.17210922113830046, 0.3108171619955571, 5.152382312282439, 37.55079515518681, 65.36255305813205, 66.90348363691761, 64.71267907850205, 43.9574690788023, 36.35016156781104, 55.869542552578835, 55.35021681939402, 32.06512316580742, 10.4087221430194, 1.2285930999825079, 0.24288662889551735, 0.27731576934456825, 2.203670668025171, 8.951113493211809, 18.955748158116496, 18.06236167107859, 25.219057490748746, 17.61832779453647, 21.996538177613292, 24.26761600279039, 13.4363349599223, 12.665582356914399, 25.349254685063517, 37.26184198933263, 49.186094422494214, 56.610337072803134, 57.29053881860549, 62.26115457473263, 62.02952684894685, 58.44410004154329, 53.18374272315733, 50.48279862250052, 50.040523928980676, 46.981126185386415, 45.794911230764086, 44.37559373917119, 46.41688539135841, 50.15451192855836, 57.30016039263818, 56.783945099000015, 62.2124622714135, 57.1533029310165, 55.556058883667, 57.63702923251737, 59.77580747296734, 48.21712386223578, 45.73849185820549, 47.14615598801644, 61.80403371011058, 61.69481923503261, 60.19037454358993, 60.66041961792977, 58.329951224788545, 55.39302556745468, 45.17690258641397, 42.56044633926884, 45.84109321717293, 53.63457602839316, 58.91137592254147, 59.99098477825042, 55.69510298390543, 26.586568317105694, 47.346106652290594, 61.064835594546416, 58.217591008832386, 61.07349226551672, 61.28402548451578, 62.854907281937145, 59.61178179710143, 59.382221160396455, 50.76564858036657, 46.067343373452466, 44.017214621267016, 48.36556203903691, 56.80232140325732, 58.84410727408625, 57.202242343656486, 54.825309553454005, 56.1839872021829, 59.09802975193147, 59.92489676321707, 58.67382541779549, 45.20235484646213, 48.19703740458335, 46.716840805545935, 49.082971388293856, 50.52413648174655, 56.58294716188985, 62.27683228831138, 58.78507168062272, 55.986170307282485, 60.47452280598303, 56.18529335145028, 59.82626092049384, 55.843439179082075, 61.50136401576381, 58.523724156041304, 62.702727163991625, 56.98908505901214, 59.61921861094814, 41.38939526773269, 40.92454733387117, 20.039587290056293, 17.81221055215405, 20.791948879918746, 16.791607872132335, 17.967556022828628, 18.12046374044111, 21.59740955598893, 12.27498979337754, 6.965851918343575, 1.4852076720806862, 0.475484605037397, 0.4843829614260505, 1.3087837518222871, 8.992637665041032, 30.97942875277612, 43.71889483544135, 40.01098809703704, 34.52429040785759, 39.26063083833264, 51.82828534033991, 61.62782123011928, 59.7650444892145, 33.16366726352323, 4.968482477049674, 0.3773390585857053, 0.11613240991268428, 0.11285271856092638, 0.10465415284758615, 0.135649150958465, 0.20388022035119996, 0.10691739874140871, 0.2550516608020952, 0.15824797863681472, 0.17219473187240864, 0.08032799608284429, 0.22628890500674326, 0.13789919715735222, 0.15108540894523745, 0.08711255500994383, 0.08452444953183014, 0.15820900008322733, 0.15101716583294256, 0.25164045513637606, 0.1297199981467378, 0.15210424459749652, 0.1612541995822422, 0.11586938894564107, 0.08188982719495412], [0.02338530120229529, 0.06221686549965413, 0.01795658766622505, 0.04615117052209474, 0.0715029466476652, 0.03674406280380584, 0.01965336325097709, 0.03338983109701545, 0.02757942191355171, 0.04359289650775252, 0.02819237652264776, 0.031923286000927614, 0.04221391909184956, 0.04423962027255086, 0.05610981941102974, 0.053858578114980654, 0.05068612375086354, 0.11206204687515575, 0.04287652002887861, 0.074818414305487, 0.043102642371048855, 0.03555745006568971, 0.050757779784861116, 0.1851138854098897, 2.7077793209783496, 29.953291608441262, 51.2518891211479, 50.81479195625552, 38.8223804966096, 17.631912923628285, 14.92318585995705, 25.840488403074204, 34.6716263986403, 21.720381744446296, 5.328983106920797, 0.4576540924608708, 0.020056151214145848, 0.07695612137115772, 0.27337338895567004, 6.036331576685752, 7.7653618685660835, 8.345264196395874, 11.851809197856534, 10.145732125928326, 1.751916218669184, 4.733038775382504, 5.562082702113736, 10.024085698589202, 23.88998785326558, 39.59916276316489, 49.00986625302223, 55.191321603713504, 55.0484767267781, 57.67096557924825, 56.629109536447835, 55.86107807774698, 49.43123079115345, 45.24987828346991, 44.13824719767417, 42.14240404867357, 41.01309876288138, 40.94554378140358, 43.318244334190126, 48.93627866621941, 53.52460845824211, 58.14530957129694, 57.542515800845244, 55.37153882365073, 55.76337183675459, 53.69187793424053, 56.859003574617454, 50.345311703220496, 40.67576708332185, 40.53782909147201, 50.118222159724084, 58.59608404098019, 55.22442248559768, 56.69880220966955, 51.97788061634187, 41.65023680656187, 42.411753208406516, 40.09538965840494, 45.1982638143724, 50.72099239595475, 54.92702837913267, 52.557414731671734, 56.95888280868531, 28.87885439780451, 30.685925637522054, 49.05547165101575, 55.55900458366641, 54.76482660539689, 53.61629778339017, 54.97753281747141, 55.61493365995346, 58.98526945421773, 54.9425531202747, 50.65922683285129, 40.97025863585934, 40.60910640224334, 44.00423549836682, 54.24986647021387, 55.394457232567575, 56.649396034979056, 52.26400575330181, 56.058698854138775, 56.3732337182568, 52.84787016530191, 46.76597241432437, 39.82954317523588, 40.12978492244598, 40.492929720109515, 42.65934890316379, 48.64427389637117, 53.07221012730753, 57.33165702512188, 57.27683405722342, 58.95876599896339, 52.75926774547946, 50.950454973405414, 54.34050460015574, 55.971912491706114, 56.91303030137093, 59.54143408806094, 59.31096346147599, 55.11685932836225, 44.81884510286393, 31.40946172898816, 18.22572446638538, 25.31538305744048, 18.610030451128562, 22.411093481125373, 15.4911538862413, 8.793274375700182, 7.324247706320978, 2.3291874941318267, 2.7056891879727765, 1.8467131641603287, 0.0958009190376728, 0.04658317899391536, 0.31982019663818423, 4.001160538004291, 18.913906274303315, 29.144153710334535, 28.10213685035706, 27.504663775044104, 25.92104211930306, 38.46341694554975, 52.27104640776112, 54.420324833162375, 31.101398775654456, 5.307199243576297, 0.12014557682578603, 0.04975701231629618, 0.04594423102154847, 0.08079667335316058, 0.04452842392868573, 0.0676890928298235, 0.0894282779265796, 0.050025782773211125, 0.0541567012307144, 0.04659664298918459, 0.053638021401580305, 0.017585734078179927, 0.037252549833107385, 0.1339915971602163, 0.0017569556216438934, 0.046340857722586205, 0.03038541428864964, 0.11456456501036884, 0.032604364978690306, 0.009357158785625812, 0.004665559249734807, 0.02801980755682434, 0.02134292611792203, 0.027215497590781703, 0.0675250810661143, 0.030012735496124918, 0.04695814455889406, 0.06591602063347256, 0.034401737483999426, 0.07791399174640257, 0.012281822968244314, 0.026353003246889963, 0.08451455167584843, 0.014464346177485442, 0.03786656930441818, 0.02462910240395896, 0.032539343266117, 0.023371149643114018, 0.04346886687281151, 0.004995102982877964, 0.033510570384321675, 0.10977881374738871, 0.048009305291118166, 0.032369750551879406, 0.03273307158040904, 0.05300724375692587, 0.07395388408293647, 0.23925079092864068, 3.6747592783743337, 37.44776625787058, 58.770303956923954, 58.678418513267275, 44.86070855971306, 24.356700874144032, 19.345266972818685, 29.494799875443984, 36.54413453994259, 24.72850822633313, 5.860896706581117, 0.5156453242225032, 0.06442952660783645, 0.16190253979256078, 1.484930899835402, 5.513362942203399, 9.829174299393932, 11.00966553534231, 9.311927422400444, 14.384614036929223, 8.189096989170197, 7.363489549006186, 10.03598911146964, 13.307254660514094, 22.262357204191147, 38.83388873069517, 49.5224258976598, 56.39499502797281, 57.24707111235588, 59.78771578881049, 58.08696039261357, 56.757704442547215, 52.40042186552479, 48.070925358803045, 45.94120779345113, 44.19391739752985, 43.73614149708902, 44.16890836531117, 46.17453782789169, 50.5676983248803, 56.02292683816726, 59.11844568867838, 58.08889804347869, 55.53614501030215, 56.16981175638015, 54.26554026142244, 57.846785822222316, 51.776451218512754, 42.78474315520256, 42.05049507079586, 52.46414076897406, 60.45792725778396, 57.76150564993582, 57.89176364098826, 54.82816111656928, 43.654575809355705, 43.33593422366727, 40.927387129875925, 47.71223637365526, 52.21754527861073, 58.1178569024609, 54.5491825380633, 57.73114650480209, 30.230099155056863, 36.01802310635967, 51.386332281174205, 57.23262110064107, 57.03463162145307, 55.15815011916622, 57.89885920862998, 56.290373648366625, 62.127931271829915, 56.34584380734352, 51.56208584385534, 41.14506298495878, 43.33147056641118, 45.5805693903277, 56.21728812494586, 55.95300274510538, 56.82738534865841, 52.704385942028416, 57.43872596371559, 59.0164444523473, 54.562506829538655, 50.07427984668363, 41.76538582771055, 41.46765439741073, 41.85354501970353, 44.85156551484139, 50.6704330444336, 56.068089008331306, 60.23867460989184, 58.769374355193115, 60.947760689643125, 55.002859561674065, 54.76010407170942, 56.80538477436189, 57.79468497922344, 58.23639877380864, 61.28477465721869, 61.948757402358524, 58.800215951858036, 46.488425500931285, 30.093916423859138, 20.328087422155566, 12.631424396268784, 12.839297267698473, 16.22084221532268, 15.488518053485503, 11.65483267076554, 11.980473726026474, 6.9845027885129385, 5.246039196368187, 4.09121913775321, 0.27839558559560007, 0.02049616338955539, 0.40464528205413974, 4.494823919188592, 21.478034180979577, 32.92668942482241, 32.77345026693037, 30.603204811772994, 29.715774443841752, 44.48154480226579, 56.97883198338171, 59.75841568362329, 35.874499659384455, 6.856160875289672, 0.10254341973772935, 0.13677442686692362, 0.049720558022419294, 0.05445259503058849, 0.043252293816617424, 0.03589846261386429, 0.04268321306294492, 0.019282321971390518, 0.02978660932351505, 0.04063529150199987, 0.046709686923291416, 0.03007570600828096, 0.039226241304629275, 0.032673454618141536, 0.023669843494351354, 0.038070547875137105, 0.03042617208144117, 0.03140051717749767, 0.06749711885687805, 0.056776036283061396, 0.02470073545531881, 0.049382429795279625, 0.0753424107848156, 0.02088467721947499, 0.14841087342750642, 0.11314724872429525, 0.25858488895239373, 0.12357462467926165, 0.20376388223901873, 0.1850451826448402, 0.22331230102046845, 0.14872599603427997, 0.35488391835843364, 0.11594088027073492, 0.10300279670064488, 0.12925761811915906, 0.15253850919825418, 0.13346728658483875, 0.13552231744172114, 0.14704449432751826, 0.11564127860530732, 0.2051910580766778, 0.1410641821642076, 0.17912249561519394, 0.13723319095949973, 0.18649953928205276, 0.17848342506875917, 0.322660053929975, 6.764683358130917, 45.0369288844447, 65.78911865911176, 63.68333147418115, 51.02558797405612, 28.168854405803067, 24.409354771337203, 36.29043955956736, 45.1379220716415, 27.815697923783336, 7.8277535400083, 0.64770074140641, 0.22731981420468902, 0.1990882484542747, 1.714925939036954, 10.848024660541165, 16.778258085250854, 20.457935525525002, 23.859832671380815, 20.600244998931885, 11.421578141950793, 12.765795973039443, 13.128604427460703, 15.406670935692327, 30.535614528963645, 44.885717591931744, 49.18266234859344, 57.753602074038604, 56.320148360344675, 60.602466598633804, 59.87160744205598, 61.144510699856674, 53.22650048040575, 51.731912705206106, 47.83096259640109, 45.99208485695624, 45.68024858351677, 46.290090853168124, 48.855485685410045, 53.72310784555251, 56.914163866350734, 62.5686134830598, 58.93838144117787, 54.78175947743078, 55.516599839733495, 55.943239965746486, 61.47919477954988, 53.82950998121693, 45.39781439688898, 44.83962189766669, 54.77906873149257, 64.10482152815788, 59.32038107225972, 61.11668932822443, 56.87093542468164, 44.59145353686425, 45.934739805036976, 43.76286460507301, 49.54928236622965, 55.665481244364095, 58.42862236884333, 57.71321342837427, 58.892921170880726, 33.43089049862277, 40.10794124295635, 57.21136185430712, 56.76698869274509, 58.96212354783089, 57.43052428768527, 59.22084700676703, 57.77393171864172, 64.3633371014749, 57.71027165074503, 55.400748714323974, 44.773023974510934, 45.20123304859285, 48.1705496388097, 59.695159619854344, 59.01221613730154, 58.8713599020435, 52.968028053160644, 59.02271239988266, 60.32819094196443, 57.91025369398056, 52.34104502585627, 44.95200957021406, 45.52609159100441, 43.81663637776529, 46.93295947967037, 52.378699779510505, 57.98895997385825, 62.255471060352946, 62.10693482429751, 62.99112727565151, 57.58003719391362, 57.13643281690536, 60.31652189070179, 60.67745839395831, 62.13872171217396, 63.8083884023851, 63.06729578202771, 61.495496149986025, 52.1988747965905, 37.1435825286373, 23.005607128143314, 32.1189086667953, 25.529652334028675, 36.168289107661096, 32.70674840096505, 18.795627201757124, 18.22516748982091, 9.150158089976157, 7.696453179082564, 4.167537429640371, 0.612218184096198, 0.16028689100377022, 0.8833488966188124, 5.088308924628842, 24.485233022320656, 40.45118785673573, 40.78005898383356, 37.72437572479248, 38.96817891828476, 52.58700116988152, 65.31056988623835, 67.7115781845585, 44.8334284751646, 9.274229522674315, 0.34571360075666063, 0.2282873219660213, 0.15836247813797769, 0.16383850526425148, 0.11448483824008897, 0.18537342067687743, 0.150220817435653, 0.1457529620177323, 0.10805009038097436, 0.11088876789736171, 0.12471486994576071, 0.11206606883675822, 0.1886200706564611, 0.24351659831741165, 0.1514005162302525, 0.12316444588284339, 0.09229409027724497, 0.2251413052961711, 0.123243659374214, 0.10487838678302304, 0.08611720761344319, 0.16142309132602908, 0.14489561769991152, 0.09614078628440058], [0.02696163903531288, 0.027105171353586262, 0.04928471911097727, 0.08920667933360224, 0.05049641356773434, 0.06284806449266692, 0.05961698525014424, 0.07056011457837398, 0.04121103339017399, 0.05671520890187352, 0.022130066138361732, 0.05944491041103198, 0.04828978923239535, 0.02909827357788961, 0.05303410279955115, 0.09125540528686778, 0.08621584143369429, 0.050862285669051835, 0.06588579080398045, 0.13970244555704056, 0.08565347161023848, 0.004085522481135183, 0.03812416636895749, 0.40625789713475013, 4.500374563278691, 30.97450225583969, 53.30408496241416, 42.804421686357074, 30.39494852865896, 19.970084851787938, 20.015982466359294, 37.88780127802203, 38.862153330156886, 15.855878418491734, 3.374561412680534, 0.17864706144938547, 0.1508533302694559, 0.3293270719868522, 2.63630687229095, 7.870048457576384, 9.370467816629718, 4.6358551902155725, 4.158787112082205, 13.804006172764687, 9.951190410121795, 4.521337180368362, 11.461284295205148, 17.56485019960711, 23.667526706572502, 37.549649823096495, 51.495888002457164, 58.64850651833319, 56.387872003739886, 57.292550994503884, 58.8482375298777, 55.66051160135577, 53.24524548745925, 52.09628128236341, 51.51331117076259, 45.70356707419119, 44.91261328420332, 38.24515273494106, 42.89676996969408, 47.979879302363244, 53.31668361540764, 55.07832204141925, 55.91515187294253, 56.61638536760884, 56.37637161439466, 54.155953161178104, 55.55429381708945, 54.35670398896741, 47.7367707990831, 39.184685907056256, 44.96371000043808, 47.55548277208882, 52.09959568515901, 49.210468030744984, 43.74908531865766, 39.78555379375335, 41.13029526126, 38.432496901481386, 46.022969599693056, 51.48854924786476, 55.78408587363459, 49.576542838927246, 56.001840176120886, 35.48260781072801, 26.587658736013598, 51.01704897419099, 54.71681679448774, 58.23125654651273, 53.138345210782944, 55.101789582160215, 56.50902225125221, 55.234930515289314, 54.28981973278908, 53.5048593244245, 47.81607720159715, 38.29382542640933, 42.25368169046218, 50.98047287233415, 54.25116085237073, 53.68235834183232, 56.604343691179835, 54.00549496373823, 55.616698726531006, 56.1657521032518, 49.83704705392161, 44.8002883695787, 38.603076857905236, 38.571042860707934, 37.55033231550647, 41.45060385427168, 44.01387668425038, 49.069749078442975, 50.764848416851414, 50.744879630304155, 45.54197719020229, 48.5716002218185, 50.68238058397847, 56.2083568880635, 56.71709614415323, 56.648780222862, 55.878242369621034, 58.0725888283022, 47.88655434885333, 36.764159894758656, 21.296565724957375, 10.011359568565123, 11.977422122032413, 13.519086184040194, 9.558355231438915, 10.043781880409488, 6.251603018852973, 10.048727989196777, 2.9857280321659583, 4.458991596775671, 0.6542460740573945, 0.010972176509488736, 0.21340820908306107, 2.400078941737452, 15.007614877916152, 33.0800344867091, 36.221343086611846, 26.945218078551758, 24.645891343393636, 39.040009283250384, 48.85636821869881, 50.079708407002116, 27.92735995784883, 5.6736711917384985, 0.3646858907755344, 0.04437134526069126, 0.01660576972719883, 0.049905855539104635, 0.04795809231338002, 0.0473968141652163, 0.05621871880946621, 0.0240525484625851, 0.06988982594902478, 0.06656606155898302, 0.04710314585076225, 0.02017656299886444, 0.03105154880622943, 0.03610355967295266, 0.06533099759009577, 0.04648705411161627, 0.04947161009054511, 0.009058620067193143, 0.04401172826727552, 0.0788592063491383, 0.06545099760255506, 0.029663305556882295, 0.04623152931491214, 0.026713547206694083, 0.022552818352837237, 0.03374927955108785, 0.03899960568354976, 0.024250379177711667, 0.015246520990565901, 0.08962029786480051, 0.0711827295561952, 0.07094516569087583, 0.049601845037672794, 0.050462506516205693, 0.010316642733561176, 0.02348745136611885, 0.023990543221213648, 0.03907930181031266, 0.060740066316699794, 0.04541759919976035, 0.05347499023041418, 0.06402519306228047, 0.05936143364036276, 0.05665973264483675, 0.01314728973328226, 0.05769583974934875, 0.07488260481266246, 0.40203469955632765, 7.486261206288492, 38.703752333118075, 59.811395137540764, 47.56552796210013, 35.4785010891576, 24.88831147070854, 22.632595608311316, 36.21052911204677, 42.058939933776855, 17.327911584608017, 3.641750817337344, 0.20332093020119976, 0.24640539330580544, 0.48623995855450636, 4.0667028532874205, 9.597095501038337, 9.139698109319134, 10.058723168988383, 6.759302846847042, 14.281907754559672, 10.046855057439497, 7.207952862785709, 13.188924597155664, 16.168177531611537, 22.49360053770004, 39.42377005853961, 52.52198396190521, 57.273935425666075, 56.58726569144957, 57.148976556716434, 59.74834695939095, 58.04359859035861, 56.037282712997936, 54.88948345184327, 52.02204650448215, 47.88025109998642, 45.65895795822144, 41.68517335768669, 45.31639775922222, 50.93767981375418, 55.33318588810583, 56.17633858034688, 58.71123306212887, 57.056408620649776, 59.16148193420903, 55.18590088813536, 57.572251289121574, 56.89656811375772, 47.78687123329409, 41.45079605041012, 46.513187423829116, 50.653135391973684, 55.60075036941036, 53.046063607738866, 43.74966582944317, 42.41562458776659, 42.14970357956425, 40.92150749698762, 47.013179794434585, 52.25280346408967, 56.400011739423206, 51.37816590647544, 56.60000554976925, 36.60648061383155, 33.155991185096006, 55.39066822298112, 53.92970300489857, 58.36723727564658, 53.359676714866396, 56.18889016489829, 56.67111419862317, 56.779544199666674, 57.711311078840694, 55.23990015829764, 49.295767814882346, 40.48921523555633, 43.01235437393189, 53.534712483806, 54.55924733992546, 55.763818986954234, 56.08253117530577, 55.607202668343824, 56.331680128651286, 58.08082972803424, 52.61097861874489, 46.81177785319667, 41.61937952041626, 42.23520732695057, 41.37056396853539, 44.94410991668702, 46.03643901886479, 53.35062388450869, 54.33429156580279, 53.90203068333288, 49.84606850531794, 49.952113705296675, 53.01842266513456, 58.748122953599506, 59.08624695193384, 58.7783016697053, 58.33747433077905, 57.979946367202274, 50.658269774529245, 39.03425908857776, 21.045675239255353, 11.781047678762867, 16.834869653947894, 14.56933609900936, 9.615711069876149, 14.54590876256266, 11.00471648477739, 9.248232053172204, 5.610354331231886, 3.999465338645443, 0.45516623724852845, 0.08336343562170383, 0.1905449738185252, 2.7615827177801444, 16.586677758924424, 35.394817321531235, 39.733150928251206, 33.197195683756185, 30.81163367917461, 45.303124458559104, 56.34773438976657, 56.51469399852138, 34.784308248950595, 8.564722768722042, 0.6189683380146181, 0.11520542054166717, 0.028213459262323957, 0.03628491183682796, 0.06440607665647423, 0.00872693655471648, 0.008592901811484368, 0.017352215157100753, 0.06927181515962848, 0.027276434139498783, 0.04092418708868566, 0.004810594536754633, 0.022492833668366078, 0.032899634416906104, 0.016170593481811307, 0.03326606959284794, 0.02923787203467181, 0.007689900089791346, 0.05351238681243793, 0.0038215163729018384, 0.03485009044168457, 0.05427969281651801, 0.03311352616536521, 0.02235482484402676, 0.05594666183535611, 0.12949254664201892, 0.10032472951758294, 0.19047453969476685, 0.2364567763382389, 0.1752063307550646, 0.24764382040068028, 0.16117258057478936, 0.14680613373075763, 0.11232574966045157, 0.1816209994496838, 0.11857917216876823, 0.1281238692782579, 0.05258930065939504, 0.2104195315510996, 0.21086832117890159, 0.17694553420428308, 0.10696728638703785, 0.1477402553803498, 0.2247271428425466, 0.15426354002087347, 0.10895918393808027, 0.2836429201547177, 0.5882510314545324, 11.124777293974354, 48.482130958187966, 64.71899801684965, 57.34171005987353, 40.093746185302734, 29.707808110021777, 31.58299719133685, 51.25151257361136, 48.622351769478094, 20.566983299870646, 4.161411668023756, 0.5130677754359861, 0.42237920626517267, 0.6872446678819195, 4.201274225788732, 13.640447258949282, 16.594746074368878, 15.403186890386767, 11.734811759764149, 21.01784013932751, 19.2680609995319, 10.18525588896967, 17.754157512418686, 22.707975718282885, 30.177802193549375, 42.88365748620803, 53.233113596516276, 59.36735537744338, 58.24397287061138, 58.854732974883056, 61.245523498904326, 60.564043060425796, 57.69618249708607, 57.41456416345412, 56.273311338117054, 49.561943777145885, 49.40501366892169, 43.248896829543575, 46.81205241910873, 51.93682124537807, 58.214849272081935, 59.66524370255009, 61.44392090459024, 59.18862865817163, 59.8133877015883, 56.30974231227752, 59.94444193378572, 59.69744243929463, 50.96414012293662, 43.30132322926676, 49.465551530161214, 51.68514236327141, 56.18995312721499, 55.26612512526974, 46.03695677172753, 43.51331164759975, 44.283492565155036, 42.460516114388746, 49.10587803010018, 56.2390729688829, 60.62219219823038, 54.087103797543435, 57.73162895633329, 42.680961162813254, 37.13370207817324, 55.275738854562086, 55.69870371972361, 58.893533060627604, 55.89704621222712, 56.93760002813032, 57.64329325768256, 56.60048407893027, 58.505767545392445, 57.363683177578835, 51.21898828014251, 42.67603466587682, 45.81652741278372, 56.33464544050155, 56.84246686197097, 55.34775357092581, 57.62852945635396, 56.45896888548329, 58.225796607232866, 59.854250954043486, 55.57561189897599, 50.0523655645309, 42.416801298818285, 43.74220940374559, 43.13773293648997, 47.27571579717821, 47.2363430453885, 54.779331530294115, 56.43699576777797, 56.40521280227169, 51.34302146973149, 53.57227702294627, 56.68650165680916, 62.59394414963261, 60.371250721716116, 61.55269607420891, 60.67660331726075, 63.033939946082334, 51.348450030049975, 45.36937721313969, 27.31105754452367, 15.720153624011626, 20.442395094902288, 22.563861954596735, 22.341455721086074, 20.282274138542917, 20.80738929010207, 20.4141697191423, 11.404205964457605, 7.618274948289318, 1.6716586413883394, 0.19108400860380745, 0.5974408996201331, 3.28758089292434, 19.81018158697313, 43.43415821752241, 50.210550831210234, 39.62579957900509, 37.85303338881462, 50.9813004924405, 61.673807098019516, 63.94854645575247, 41.79548609641291, 12.186285391930612, 0.994172033763701, 0.1876835741343037, 0.1608806091450876, 0.20779941891950948, 0.11934527541480719, 0.13949889599555923, 0.20482019491253362, 0.14505499463167884, 0.1882270062642713, 0.20927792264809533, 0.11243839522883778, 0.11675290282695525, 0.16602364849419365, 0.2494046275293635, 0.17671524817424436, 0.1211804466983003, 0.13354148986118455, 0.17898047823579083, 0.23646658226366968, 0.10047730358858263, 0.21194711087211487, 0.10888347146852363, 0.1821152180913956, 0.09372875079392426], [0.11698374810117869, 0.0006478879191901446, 0.0706781687275056, 0.03644756379447157, 0.07489391227042483, 0.033564464669794805, 0.019861426985552235, 0.05935141321031317, 0.020332025221338677, 0.050658567568227175, 0.07647167801135972, 0.04054500037924417, 0.05708843544726411, 0.006194383463627029, 0.024839349489118305, 0.0391399989565534, 0.07797783751401209, 0.05998612854689841, 0.011838858481496574, 0.04723404729438405, 0.03340491536824453, 0.017733914634933876, 0.022683177789252613, 0.26275859725090767, 7.416362118336463, 36.563377688007975, 51.69092001453523, 43.31229802100889, 28.745901738443685, 18.40076611888024, 23.995109335068737, 34.17959643948463, 30.66745519638062, 13.57108602600713, 1.7884622898793991, 0.04173437103388771, 0.08815036666008734, 0.2375949531673424, 4.117665963788187, 5.089821978922814, 4.607588139272505, 7.9187535085985745, 4.9663972470068165, 12.856590997788215, 5.671543796216288, 6.545405705128947, 9.94134428039674, 11.02031869273032, 18.844837257939, 45.67233324050904, 58.224066841986875, 57.5366989258797, 57.99836973990164, 53.1737720581793, 54.61945179970034, 55.16083302036409, 55.81187978867562, 54.550896613828606, 55.1462378809529, 54.60894377000871, 53.27949954617409, 45.8548842706988, 40.691660527260076, 40.26078424146099, 44.43109135473929, 47.84777387495964, 52.13988234919887, 53.31535000954905, 54.40913823343093, 52.68002017851799, 55.87406504538752, 55.79379373981107, 51.67040209616385, 43.442975705669774, 40.87529805398757, 38.300713108431914, 39.642406894314675, 39.155448559791814, 39.91730620784145, 37.510077030428, 38.89745466170773, 37.63711867793914, 45.363756456682765, 47.38832312245523, 52.59922327533845, 48.96855977273757, 58.349233596555656, 37.98826494524556, 45.354432982783166, 62.02382764508648, 53.09455194780904, 57.11436163994574, 52.38186905460974, 55.9362816810608, 53.93578660103583, 56.606053844574966, 54.47124112036921, 55.72025322145032, 52.58482033206571, 43.125863844348544, 39.127454603871996, 53.569088135996175, 54.96631876114876, 55.614666938781745, 53.41508019355036, 55.30354061434346, 54.90966404637983, 55.81493923741003, 51.93870006069061, 49.78328704833985, 41.31457213432559, 41.61626123612927, 40.70074473657916, 40.00996435842207, 37.902541545129594, 39.69262892200101, 40.54322235045895, 41.28485233552995, 44.85611938661145, 45.352671838575795, 48.54068017775013, 52.46430158615113, 50.03467175268358, 52.32755599483367, 54.433519686422045, 54.84155993307791, 52.367685764066636, 37.29628432181574, 28.897354256722238, 10.482245010714378, 16.535208417523293, 10.831415384046494, 6.912636631919492, 13.16164549319975, 11.186724266698285, 4.137227804430069, 4.417880254407083, 4.951856040185498, 0.27347187721921556, 0.04718832333662337, 0.06551619168491134, 1.242950568276067, 10.060419594087909, 29.68206559458087, 36.0852760653342, 30.058256195437526, 21.072559164416408, 33.289222332739065, 44.91606104758478, 51.9305964439146, 28.109716830715058, 6.292958038468515, 0.7248002591152346, 0.1320463926681588, 0.021143823696841157, 0.04383515266160812, 0.02594355989487902, 0.059815620357591304, 0.020255429835449305, 0.029044702964564486, 0.0905387300337034, 0.040814793563538024, 0.0049404062203041495, 0.04874187686871137, 0.015424530138261618, 0.0462090791082911, 0.029068275489994598, 0.04615070703890055, 0.007243988558559889, 0.0513597869975192, 0.035709882410423416, 0.018625686944071806, 0.03883974228595053, 0.022860293486906637, 0.06833747134453828, 0.09677343701402988, 0.07617412180068993, 0.1259572270716871, 0.012411603050666952, 0.023576279260939168, 0.114384442417612, 0.021048294447903192, 0.025703699681006616, 0.09945437702680789, 0.007726573197531604, 0.01468212677977018, 0.130723251570617, 0.06129306688484165, 0.059454406070853436, 0.03162077703182736, 0.01608592927485945, 0.004950421383499258, 0.018373029231424295, 0.03317836784727631, 0.03342065464464888, 0.061738688739076744, 0.03685810648265385, 0.012127450505842366, 0.017502567573120038, 0.22148027835834413, 9.867424272721815, 42.841237052794426, 58.16665118740451, 50.39768318976126, 35.00562014118318, 21.162073535303918, 26.121277155414706, 36.48545588216474, 34.626923145786414, 14.233234082498859, 2.1101454284883316, 0.03496633279287527, 0.05035788571882633, 0.7299311483098615, 4.399674573252279, 8.125066257292225, 13.10839637633293, 9.61472753555544, 11.314280725294545, 16.2082435623292, 12.002566476022045, 9.739860949977752, 11.821751094633534, 20.160366873587332, 23.598900918037664, 43.65365797473539, 58.20758896489298, 59.283451957087365, 57.59256524424399, 54.97119034490278, 55.01631721373528, 57.15390305365286, 55.52899452947802, 58.25194312680153, 57.8071306597802, 57.953635108086374, 54.26166103732202, 46.97666252813032, 41.07116160854217, 42.66640524710379, 47.250475345119355, 52.44172834580945, 54.36422709495791, 56.08162903016614, 57.582841688586825, 55.18814448387393, 55.87304915151289, 57.64480729256907, 54.53453640783987, 45.18356277096657, 41.94591683726157, 41.54738833827358, 42.22509937901651, 41.61861073586249, 42.52953806231099, 39.265376906241144, 41.04736066633656, 39.05376503544469, 47.92823345430436, 50.578025925544004, 55.39585359634892, 50.66092129676573, 59.20937015164284, 39.1258111307698, 46.49026117017193, 60.081524848937995, 55.06970851652084, 60.86131557341545, 54.474135829556374, 56.8656284578385, 56.167646608045025, 56.96531941813808, 56.223356031602435, 55.6950637602037, 54.00667951953027, 45.06514641546434, 40.67318616374847, 54.69962112365231, 57.335206770127826, 55.07651382876981, 53.928322330597915, 54.25307104664465, 54.47690502289803, 57.98143686786775, 53.386007585833156, 51.03931626965923, 42.51436633448447, 42.0623484734566, 40.81075937517228, 42.693316628856046, 40.68121917786137, 41.932859266957934, 42.61826207560878, 44.016791005288404, 46.479247154728064, 48.48934027456468, 52.03031093843522, 54.52045902129143, 51.819718883883574, 56.397893659530155, 56.662233952553045, 59.179564060703406, 53.54459685664023, 40.43163091905656, 27.222419823369673, 11.400616995749935, 12.17035468547575, 14.482574251390274, 13.657694901189497, 14.91949785140253, 12.297050183819188, 10.864005377215724, 7.258872091770173, 3.536436894247609, 0.7213423220861344, 0.19211974415567615, 0.08359941368501994, 1.7388891693084472, 11.885215044021608, 34.20479374547159, 40.38208353903986, 33.10234492824924, 29.161924008400213, 39.8739012595146, 47.97185805536086, 58.585352436188735, 34.66824531555176, 9.360798193562417, 1.1144511473755683, 0.13129185734977647, 0.0485842083130152, 0.03497077227239648, 0.04096165261862259, 0.017594203180182847, 0.023678339409431624, 0.012647514081289692, 0.017358315132197835, 0.0575952485744511, 0.053277052262978214, 0.028342403351299228, 0.017548368139673146, 0.03057429709682061, 0.03980127073103382, 0.021941035858265335, 0.018641259596352617, 0.012418864606579226, 0.03900573055650439, 0.03136096788840669, 0.060836018829215924, 0.01868236787436951, 0.029248572367754196, 0.03470492061047304, 0.28025071346952074, 0.22831166824025495, 0.22073174916928817, 0.11249334671564641, 0.2156572746894052, 0.09779230330980594, 0.09675829145576685, 0.13720358932210555, 0.18253201588747964, 0.15409975042266233, 0.18630017256063802, 0.25969829049802595, 0.21403448596116037, 0.08922602305369032, 0.1469909907468865, 0.13069444666466407, 0.21556004281005553, 0.10597529445564556, 0.10104217851955084, 0.17379562580777755, 0.1290409990976895, 0.14784695610644358, 0.09566850073996092, 0.629714529120153, 14.37805485340857, 50.8079787992662, 64.79687275425081, 56.13882895438902, 41.23317903087985, 26.703325510025028, 35.36383451954011, 46.86787559140114, 40.65375474191482, 17.034459460166193, 2.2803461407461474, 0.302391114133981, 0.11664390383708863, 0.7460443675518037, 6.3639857884376285, 10.891829690625592, 14.850417067927701, 17.50800132751465, 12.60592310659347, 23.789488884710497, 15.027743501047935, 16.678916215896606, 16.881355624045096, 16.184282783539064, 23.65510259905169, 47.8076127267653, 60.75440745199881, 59.00873307258853, 59.770924122102805, 54.3165232289222, 56.9630209092171, 57.532764788596864, 58.7268990085971, 59.93227474151119, 60.084878475435325, 59.50613275651009, 58.00308050647859, 49.97847595522481, 44.40134802172261, 44.18101672203311, 48.23009121802546, 53.75200002424179, 56.15279651457264, 58.826676261040475, 59.87403931156282, 56.11297661258329, 58.20041887221798, 60.39123912011424, 56.809491495932306, 48.69839083763861, 44.41154618417063, 42.653822283591, 43.98455696721231, 42.7122381425673, 44.212721240135934, 41.93190613100606, 42.54485491783389, 40.63192675190587, 50.096241197278424, 52.904544491921705, 55.91496752154443, 53.54751902241861, 61.080309344876206, 43.66750786381383, 48.09370256239369, 60.00061811939363, 57.06574778403006, 62.383889459794574, 57.47102275971444, 59.21491638306649, 59.698611305605986, 59.75783125046761, 56.71557818689654, 57.96905786760392, 58.473466827023415, 47.55208207714943, 43.89085938853603, 58.290888340242454, 60.02624688609954, 57.159817987872714, 54.26420273319368, 54.23462413972425, 56.054666657601636, 61.11469284180672, 56.55462764924573, 54.34402688857048, 45.88602788986699, 44.937520334797526, 44.58493063526769, 43.574261357707364, 42.95491126275832, 44.652826862950484, 45.40331355987057, 45.872272137672674, 51.24531915110927, 49.295759970142, 54.22025649778305, 57.84679758933283, 55.66608136700046, 57.11935089480493, 59.463320086079264, 60.86682650350756, 55.92380069917249, 41.001833715746486, 34.50879704567694, 15.050934514691754, 23.683061253639963, 23.641313506710915, 13.462215738911784, 26.865268407329438, 15.299916767304945, 15.1769131998862, 12.739354295115318, 7.303729787949593, 1.2686522665523714, 0.41892414972666775, 0.18387291490310625, 2.275110757158649, 13.035571690528625, 38.565673135942035, 47.89853718972976, 41.29490144791142, 30.950891548587432, 45.848431971765336, 58.01304724908645, 67.58850989803192, 43.28282533153411, 17.290005799262754, 1.9910440065207022, 0.4477916603847858, 0.1474481920200971, 0.1505210472931785, 0.14952208396167527, 0.22829047824826934, 0.1474644943711258, 0.11266419964451944, 0.15846053739228558, 0.14469870245985447, 0.11716185588269465, 0.13939403388048374, 0.08197265662132733, 0.09358920021763734, 0.11032977652165199, 0.14065797170323713, 0.10803935748915519, 0.11366966706249984, 0.0853783234713539, 0.19563879967937547, 0.20715133917908515, 0.10489890261763528, 0.10615088180789065, 0.13997851300143427], [0.027382363032008854, 0.055567770069765474, 0.04992699573537515, 0.022937392575606223, 0.08503584386480433, 0.019734859684362047, 0.004543213571812357, 0.0396371670367737, 0.031692385185329665, 0.07148682049685909, 0.09342492032315462, 0.03371484772933107, 0.06726229758632761, 0.08753939621871518, 0.027425085840326165, 0.03631947772397149, 0.1026184197455164, 0.009996884337235844, 0.015156079523055064, 0.06437554805269165, 0.025814453012219844, 0.12419081984027741, 0.051084884006770394, 0.3775464845520835, 12.968127516008193, 43.87966886643441, 50.676187161476385, 36.65319212021367, 23.182466799213042, 22.456936182514315, 48.586195361229684, 56.131615715642134, 40.738870174654075, 9.784401424469488, 1.3863026567043797, 0.028116484022428914, 0.2357467200847403, 1.3019246295575173, 7.404677867889405, 11.308965913711056, 10.955174988315953, 7.68344561899862, 8.107531301436886, 13.688057968693396, 10.000685818733709, 7.677278672495197, 16.56680703163147, 32.92679140644689, 35.11643886566162, 51.693563692031375, 54.57509763779179, 60.75922020020024, 57.76268236098751, 56.53919312261767, 52.89022391842258, 53.138035343539336, 52.642702748698575, 54.42253704993956, 54.09838061178885, 54.020403892763206, 53.27508687973023, 54.08722931338895, 49.41248578409995, 45.21112134379726, 40.15668061471755, 38.24545083507415, 40.03149424829791, 44.9010540593055, 49.93393744191816, 52.858833189933534, 55.31807691820207, 53.91822614977437, 53.8017160661759, 46.80055987450385, 38.64015502314414, 38.4066798610072, 40.272331699248284, 38.49493711225448, 38.88959815425258, 39.543174851325254, 39.47842044215049, 39.166913647805494, 43.042733130916474, 43.03073852292953, 48.65737853511688, 47.590097688859515, 58.258795507492565, 38.851637455724905, 34.948365303777884, 56.86464002055507, 50.56916136895457, 51.58007775583575, 47.862125827420144, 49.79389705965596, 50.15745370618759, 54.48858584127119, 53.9241450063644, 56.76466272723291, 53.74978780746461, 49.53984122122488, 36.37185619723412, 51.784974528897195, 52.105989148539884, 58.080480637088904, 53.68937546207059, 51.626624522670625, 53.410365504603234, 56.469025842605106, 55.019211922922445, 52.94715712147375, 47.382937708208644, 47.648305662216686, 48.1883454322815, 50.78580171831193, 52.76863436545096, 51.33633382858769, 46.978968881791644, 41.96772521541965, 41.90237460597869, 45.8227365247665, 47.45733330326696, 49.51736996250768, 51.2622598678835, 53.08943325473417, 54.46966824993011, 57.91690995616298, 53.78283769853654, 40.18194460099743, 24.080101213147564, 17.610532083818992, 18.752173223803123, 11.090477147409993, 11.825806825391709, 13.166906372193369, 12.893760358133624, 10.829236507415773, 4.851069758015295, 2.3763664980088515, 0.1309912597700473, 0.08838993767576833, 0.04159205871063375, 0.8724379046790062, 6.6201940275007685, 29.86604044514318, 49.993082861746515, 42.642239524472146, 21.905341109921856, 31.909818880019653, 46.455924741683475, 48.40792363689792, 40.299658852238814, 16.563941740220596, 1.0357871555512952, 0.06277034870318829, 0.018061892197076834, 0.006778925308026374, 0.05119762150570751, 0.012907028280859514, 0.07107614374329006, 0.04583351216429184, 0.016361165513855316, 0.058682695061208746, 0.019401896805051836, 0.0553590570756745, 0.06345049305368336, 0.0603901748094828, 0.019547553102095282, 0.015992638917880195, 0.02611066473858251, 0.05311163472792795, 0.06729331648638172, 0.039561278366994475, 0.004023082006061751, 0.07590301860604556, 0.009327816660515964, 0.07688954833053774, 0.06376410646724605, 0.02876995702184016, 0.03522054374878926, 0.034842483188596465, 0.059885468424087575, 0.01575810205747163, 0.03614679001451981, 0.02629705776099957, 0.02720809143577372, 0.07593458908940516, 0.0839431420148861, 0.054669734991846554, 0.03742013922742298, 0.02646828798817531, 0.036233848246235045, 0.04321393196380908, 0.014922642956427751, 0.02262610806933334, 0.052061427775169575, 0.024483446106915514, 0.008914985284659891, 0.0763428526660127, 0.033386506275424076, 0.7397139685288553, 17.3114788147711, 52.21850625930294, 56.452124349532596, 43.11358682570919, 27.347215913957168, 26.205929748473633, 41.818349592147335, 52.89226355091218, 42.48605074421052, 11.816430399494788, 1.4012848850219481, 0.04772770286147152, 0.2046405013290144, 0.9897825951057097, 3.671025427118425, 10.65103244396948, 11.642576244569595, 14.396557654103926, 14.513896338401304, 17.922150665713897, 14.138966779555044, 10.543121176381266, 12.38592815014624, 25.76131339996092, 33.18894301691363, 49.97182361541256, 56.08531998049829, 58.55274577294627, 58.182725060370664, 56.349154287768954, 54.10785705812516, 53.22833222727622, 52.37112568270776, 56.35984666885869, 56.23128314172068, 56.96057335022957, 56.54358225484049, 56.29859885861797, 49.941974378401234, 45.13871046804613, 41.357773119403475, 39.641477292583836, 43.379452920729115, 47.474697636019805, 53.860990924219934, 54.95876427619688, 57.39135549914453, 56.9233500572943, 56.67924919436055, 49.8197494014617, 40.10413262151903, 39.41118317265665, 41.70952343171643, 41.40592021326865, 41.03981794849519, 41.85249774686752, 42.23938857355426, 40.588345296921275, 45.06052586340135, 45.52370286756947, 50.57527634405321, 49.99651885801747, 60.04861224082209, 42.44127688869354, 37.55635707609115, 57.269154056426025, 54.346160657944225, 53.13628204407231, 50.21482621469806, 52.323563021998254, 52.044317722320564, 56.99107762305968, 54.779959109521684, 58.339702237036924, 56.101535058790645, 50.89563985024729, 38.855434310051706, 53.16522521357383, 55.14246848321731, 60.94266945315946, 54.646320035380704, 52.64114556774017, 53.07049605154222, 57.50347645052018, 56.99039120827952, 54.46170976085048, 48.65514670648883, 48.70558446453464, 50.16308622975504, 52.635301236183416, 53.24577892980268, 51.85219218654018, 47.62536764144898, 43.473993808992454, 43.347948443505075, 47.11726773169733, 49.872313084140906, 51.73339928350141, 53.59006497167773, 54.59838867187501, 56.01638432471983, 59.454047602991906, 54.78289304241058, 40.1227403456165, 30.023260808760124, 17.554428462059267, 10.579291312925278, 13.848894757609214, 10.910585484197064, 15.665586590766909, 13.152330844633042, 8.695830933509335, 6.99441755971601, 4.10878302108857, 1.056602561185437, 0.1700819686295525, 0.02074985149046106, 0.9218625880537495, 7.8053543548430175, 31.330702497113137, 43.4170017703887, 43.91485252688008, 23.94022753161769, 35.675231487520286, 54.67298430781211, 54.687281347090206, 45.59980469365274, 20.431414419604888, 1.3764798160522216, 0.05741815202899518, 0.056528294939667954, 0.031604869216079676, 0.05421741752915325, 0.03908826120858712, 0.014639344599638737, 0.08616631384938957, 0.00406946623585217, 0.01805284278347127, 0.007835987790097153, 0.04128079335655897, 0.042161813621679624, 0.04787936145740171, 0.03340363600141099, 0.043117305293919585, 0.06509105885221113, 0.0728609907110372, 0.07095736947150962, 0.06576576780888342, 0.036845037022665623, 0.03568628690235558, 0.035498813695965276, 0.037621673977663445, 0.13742645962103722, 0.10273973742920546, 0.23926168469892395, 0.13323871659175043, 0.15505771272845809, 0.16395309669596536, 0.09666206315159799, 0.18133135692727181, 0.09883125643095664, 0.10858861188734732, 0.2170683473588959, 0.09146466220338499, 0.16819788263209406, 0.17248124875608953, 0.1453085390910987, 0.08954037957253957, 0.21132501683408217, 0.15910297872558718, 0.14663629203794465, 0.11067085418730013, 0.11751053314055167, 0.2816381599874266, 0.1327104223591666, 1.1726864547498765, 22.517830979439523, 58.85672946130076, 64.45849380185528, 48.76378459315146, 33.16844471039311, 33.35707933672013, 61.50722795917142, 66.67073803563272, 48.188039487408055, 13.163552745696038, 2.1366474128538564, 0.19542976492835631, 0.33632366106875483, 1.4126609842623434, 14.977706805352243, 23.910584219040413, 19.517684559668265, 19.459921775325654, 19.85527511565916, 25.60777221956561, 21.65376420943968, 16.216843358932003, 22.92496123621541, 38.17738202310378, 38.19228702975858, 53.14409148308539, 57.97909913524505, 60.31101488297986, 58.48224901383924, 57.13957463541339, 53.545965763830374, 53.21587085723878, 52.60445179477815, 57.82528338893768, 56.48890049226823, 58.52131189838533, 57.177147019294004, 59.85294872714628, 53.79016076364825, 48.455301946209325, 44.395793945558616, 42.89038435105355, 45.52645244906026, 49.54932158993137, 54.27450287726618, 57.28636541674214, 58.833112870493245, 58.92554352360388, 58.051258979305146, 51.85605572115991, 41.83047756072014, 41.49882547317013, 42.81185457783361, 42.878636852387466, 43.42928271139822, 44.046240160542155, 42.14014084108415, 43.37068250102382, 47.74559220960064, 48.050191710072184, 53.18824952648532, 52.373726214132006, 61.78444147109986, 45.55486217621834, 40.38381330428585, 56.94584485023253, 55.8855301334012, 56.23679014944262, 53.26294714404691, 53.125950521038426, 54.211344872751546, 58.998150517863614, 57.401938053869436, 60.599485597302845, 58.424578405195675, 54.28918430882116, 39.810190200805664, 56.49929869559504, 57.40851194627824, 63.91684586001981, 56.494293751255164, 52.49391548095211, 53.470922977693625, 58.245302554099794, 61.336502875051195, 57.815206819965, 51.89899390743625, 50.44930942596928, 53.263421750837765, 54.82929860391925, 56.919796389918176, 54.87777125450873, 50.68744044150076, 45.888585275219334, 45.760323770584606, 49.37689811952653, 53.24820687693935, 54.17762425638015, 56.32751849389846, 57.05947199175435, 59.98799985454929, 63.536034707100164, 57.30927205854847, 43.418715846154, 28.3132113564399, 22.602426698130948, 26.941448680816162, 22.202227269449544, 21.522043174312962, 22.97111184366288, 24.469700436438284, 21.013362753775812, 10.406800181634965, 4.645474803063178, 1.8032551412620854, 0.427647071980661, 0.2468364250155226, 1.5320755829734187, 9.262467315120082, 36.84833395865656, 59.80905348254789, 56.75075400260187, 31.620004753912653, 43.457645370114236, 60.98048894636093, 62.71667511232438, 54.56300104818037, 26.696082853501846, 2.4157743059819747, 0.1505376867228939, 0.10921465893906933, 0.10777710261003626, 0.2606669320694862, 0.09669838338008813, 0.2680069430460853, 0.15563532770160707, 0.1866945546240576, 0.1683696701882347, 0.1587669112749638, 0.18254427329426814, 0.12589638436874076, 0.1155335896257912, 0.12128107234715454, 0.0780552430378814, 0.15309297299433142, 0.1987890604763262, 0.18507244005318613, 0.2056729580245672, 0.14335892193259733, 0.1188261129502808, 0.15676032781841295, 0.17509164739279978], [0.09651038540346969, 0.07828237278567207, 0.06900797447850628, 0.0688690061290418, 0.012330987618394918, 0.048613564802273634, 0.03605788551090706, 0.04170429059154084, 0.039091992056778366, 0.06276717709918177, 0.0340091021010472, 0.011113952571195702, 0.022881634781257282, 0.040756233802606026, 0.02012578477602332, 0.03172089514743177, 0.08774095395159337, 0.05799477491828223, 0.059787056769334504, 0.026967411507822336, 0.012793594599521209, 0.04346053949707458, 0.07522431833128776, 0.11883002765957387, 16.14230655854748, 39.93370955990207, 49.5973627798019, 39.951564188926454, 23.912449306057347, 19.450215870334258, 45.30281851368566, 54.94242760442919, 34.16005126891598, 8.32013160951676, 0.8933093879492053, 0.060349116327180985, 0.14250032123058073, 0.36604370501252914, 1.1146098807934792, 8.192895804682086, 14.3351980563133, 7.855247393731148, 16.318307230549475, 15.31115435784863, 14.62475428658147, 9.995252355452507, 15.917834216548552, 42.150503743079405, 39.11196908643169, 55.40571051259195, 57.93626685296336, 57.54450052015243, 57.775688940478915, 56.28989904157577, 52.79728335718955, 57.794335888278106, 55.35982270394602, 52.79409054786929, 54.18442172388877, 56.56718315616731, 55.79076174766787, 55.49765086943104, 52.142051419904156, 52.43979069494432, 47.51984411670316, 44.8826777550482, 39.405629096492646, 35.18053431664744, 39.67013412906278, 47.34759715295608, 51.6149672385185, 51.949631706360854, 50.69838777665169, 44.71906000568021, 40.719332848825765, 37.87404552582772, 36.486683584028675, 38.917368535072576, 43.473436832427986, 45.16335471983879, 45.94641277866979, 40.24513398447345, 41.59627283773115, 42.56726341862833, 46.26324615170879, 46.48943355006557, 56.55107005949944, 42.00818838611726, 37.43822313124134, 58.91826752693423, 50.454596780961566, 51.924654053103545, 44.992966959553385, 42.279133950510335, 43.349984153624504, 49.811430054326216, 52.55861105457429, 58.494180863903416, 53.32651307505947, 48.067073591293834, 37.68784276900753, 42.82785392576649, 54.750184397543634, 54.15759271191013, 57.52284511443108, 55.90957034018732, 52.36159040081886, 54.9767130421054, 54.96534209097586, 54.03925872618153, 53.42349759994015, 53.97456707492952, 53.81160828375048, 57.43210892523489, 56.560111122746626, 56.56933261502174, 54.47697954793131, 51.51488404120169, 48.651498902228575, 49.78406367763397, 53.24230370983001, 52.05698305560697, 54.17291741217337, 53.56790358020414, 57.1740875705596, 57.303047257085005, 46.78208551099224, 39.04230779217136, 32.67474774391421, 20.18180654894921, 11.568455215423338, 12.61045736651267, 17.80146521906699, 13.881425915225861, 11.700935229178398, 5.685504492252104, 8.279926334657977, 4.197797534927245, 1.5709510517697183, 0.24313459623484845, 0.07947645105061032, 0.4020373961858211, 5.4420817090619, 26.027148116019468, 61.15274375484836, 66.69066367610809, 47.38681300993889, 30.67473903779061, 40.219144359711684, 55.02267145341443, 39.23676713820427, 15.39702876921623, 1.554289558722127, 0.0886712604833226, 0.03269000594774562, 0.07170221377764979, 0.05951447502499627, 0.03966237515992215, 0.023948596076919668, 0.02517237748590208, 0.039118874082041365, 0.05052773124207893, 0.01227863316964959, 0.032824197739002206, 0.012519796690603179, 0.03811012780774505, 0.016437946676066326, 0.003680587317156155, 0.06368685033052199, 0.03888123743836919, 0.06329127316994053, 0.05613774714630939, 0.04931741191314594, 0.013693521914613104, 0.03186290103551601, 0.07581430562441388, 0.018538688084170706, 0.011015444197842192, 0.06426016371997614, 0.02202700432990828, 0.01596123410103422, 0.03031117653834724, 0.08435131366094274, 0.03262163643094321, 0.04131019964153248, 0.003073184451486375, 0.0017891952349248553, 0.05987958103838948, 0.054298913962538206, 0.016297963260102178, 0.022472444238261353, 0.07188988233646078, 0.09416733613057483, 0.04085564520210028, 0.0231026875365886, 0.03902972826073247, 0.014485472009607382, 0.03913560544230765, 0.033237915861630635, 0.6015988571509239, 20.645585636938772, 48.316238234120036, 55.24916871901482, 45.0458836555481, 29.680733949907367, 22.37973020922753, 46.28696472414079, 57.71983046685496, 36.48806033595916, 9.774289554165257, 0.8649806209629582, 0.08764096415571629, 0.14040890119729504, 1.6186815163781567, 4.805289814549108, 6.909112382319666, 13.07949733349585, 12.085068629633996, 17.033720093388713, 17.62919472109887, 16.65619392548838, 11.928883771742544, 16.292158749795732, 33.964768225146884, 42.150770464251124, 53.9792307730644, 57.86899428213797, 59.16986796163744, 58.40790440959316, 56.4019533126585, 53.57029622600925, 57.4962906683645, 55.60393141162012, 53.20444499292682, 55.750592754733184, 57.79914471410937, 57.9287515917132, 55.7089489506137, 54.11937313695108, 54.52700153473885, 49.08746250214116, 46.371727143564534, 41.26765274232434, 38.61007828866282, 43.82692867709745, 49.40667283150458, 54.17917751496839, 54.93651659257951, 53.416107854535504, 46.73671545520906, 41.71629736500402, 39.67978708205685, 38.955913666755926, 39.83845480026738, 45.481317735487416, 48.0375656004875, 47.057251545690725, 43.06383548244354, 43.41860601978917, 43.66522896674372, 49.383126843360166, 47.99124633112262, 57.610584612815614, 44.53023318321475, 39.68222679630403, 58.74148630326795, 54.271800364217455, 54.17110135478359, 49.246761721949426, 44.67714163564867, 46.108798903803674, 51.707739137834125, 55.10388805020241, 59.563764141451934, 55.65678927206225, 50.38615534382482, 40.02063712766094, 45.32551334750268, 57.26365489344443, 56.75570795612951, 58.72968781378962, 54.84978122095908, 51.186412995861424, 56.689706233239946, 56.426719157926506, 55.5812365778031, 53.15831791970038, 55.83489625684677, 56.03004594003001, 58.3568076933584, 57.967661503822576, 59.9590527626776, 56.234303366753366, 54.50243965271981, 50.71372032165528, 51.257780521146714, 52.81616172482891, 55.07220314395044, 55.39043288077078, 56.082248764653365, 60.09695937556606, 58.94733228991109, 49.93642422460741, 42.73531344629104, 30.723270523932676, 25.070028997236683, 9.876164294058277, 12.117321298968408, 10.124368936784807, 10.56267713346789, 12.160358525091603, 13.062885115223548, 10.495594797595855, 5.519296017385298, 1.3667289263779119, 0.3012903683608578, 0.09658413668794018, 0.5199682051616331, 6.019777703669764, 27.77279503883854, 63.979219390499985, 66.03254487437587, 39.54400639380179, 33.22327160066174, 45.87406073847125, 59.70696595407302, 45.65103477047336, 19.405665589917092, 2.009303865413512, 0.05006671868144505, 0.08367878805485465, 0.015460321766084001, 0.049799940053133235, 0.043626631189498215, 0.027874160835879947, 0.018668710441899397, 0.0254822543056141, 0.024012175628975518, 0.06324600503449479, 0.016838591508266908, 0.037794783035473484, 0.047650504181341785, 0.1486986926606586, 0.0429265417398945, 0.11506488937283717, 0.027426987653598193, 0.03395985413883482, 0.018178396933381597, 0.0689136613941481, 0.020085339164060932, 0.043188938345279426, 0.06406767263768182, 0.2291704987686488, 0.2259225157960769, 0.18705368132120181, 0.21471060451961335, 0.07752207648609916, 0.1061789206259193, 0.2074149193903131, 0.11367489944302267, 0.1783518877721602, 0.19370531633255944, 0.21179395457429273, 0.21506124296255652, 0.15523141550440944, 0.1383176343815942, 0.10088807227270258, 0.10399077433131396, 0.31899747949454094, 0.11987365391706267, 0.20570282013185565, 0.1916676143845243, 0.10619245739954133, 0.2153326372706121, 0.21385050228526517, 1.1261308625821145, 26.784326376453524, 56.70072024868381, 62.668728059337994, 52.64682515974968, 33.765649103349254, 30.50847172737122, 56.31000903344924, 62.636639148958274, 39.556350092734064, 10.575213028538613, 1.3417442863987339, 0.19181314044662062, 0.33998782896707136, 2.2428852992673076, 5.508303574977383, 15.824618108810919, 23.486934900283817, 15.912683163919757, 27.048798068877193, 23.55037139308068, 24.20098670067326, 19.46431875228882, 22.596837320635398, 41.154445294410955, 41.68073323465163, 58.16008906210623, 58.65790451726606, 61.38384588303105, 60.497813840066236, 56.54894805723622, 53.22379012261668, 58.97134111773584, 56.604449595174486, 52.68851210994106, 56.18794487368677, 58.36974367018669, 59.41615750712734, 60.02785113550002, 56.50298964592719, 56.51519998427361, 50.98978850149339, 50.19959172894878, 44.41295431506249, 41.09341321452972, 43.951824788124334, 50.58926351608769, 55.59694567034322, 55.06214618682862, 53.56370664411976, 48.730762158670736, 45.00722085275958, 42.109836609132834, 41.252892863365915, 43.220087020627915, 47.28472940383419, 50.32724918857698, 48.392649927446925, 45.44467103096747, 45.96764064604237, 47.43887462923604, 51.0510520012148, 51.81509440945041, 58.99667570667883, 48.61758216734856, 42.12031718223326, 58.276461862748675, 55.7164014539411, 55.74823541025962, 51.96810606987246, 47.032877937439956, 47.621139326403224, 53.34900394562752, 56.52126789093018, 62.80455189366495, 58.336042665666156, 52.72670030593873, 41.509419795005556, 47.27896744205106, 60.660870690499586, 57.42720988488967, 61.9569355441678, 57.1876746608365, 51.48465825665382, 56.65840571926486, 60.06481162963375, 58.33991012265606, 57.94196605682374, 58.743808346409956, 59.562407001372314, 61.858531121284734, 60.2878572094825, 61.45906909819573, 58.61023987493208, 55.98734701833418, 53.09479121238955, 54.9308644571612, 58.901389568082756, 58.24090557713663, 58.90138172334241, 59.30047112126505, 60.90284170642976, 60.29630599483367, 49.899020502644206, 44.1029497884935, 36.253737941865, 26.51880348882368, 16.12339092839149, 17.8926230630567, 26.76721699776188, 23.61012281910066, 23.130007059343402, 13.416275958861075, 16.444567345803787, 10.393131702176987, 2.469140358509556, 1.00329767311773, 0.3341646107935137, 0.7711628584131118, 7.273677568281851, 30.811492473848407, 66.28727928284677, 75.36682098142563, 59.59548827140563, 40.85121470112955, 55.61379225023332, 67.74793071131553, 52.52217615804365, 23.81445869322746, 3.548199837246249, 0.2751688539020477, 0.10255680329376653, 0.2065517528042678, 0.16458548695570038, 0.14335887596732186, 0.24234883517267244, 0.16860182547280866, 0.14801007154728138, 0.16989377147007376, 0.11719803055447918, 0.1499685753257044, 0.175788281785865, 0.29503933604686494, 0.23604808375239375, 0.12411593474567899, 0.19445317136424203, 0.11515116619486963, 0.13785646477293584, 0.09118658760862966, 0.19796980605010064, 0.08061747772679215, 0.1842578434415402, 0.20385040420918696], [0.0646620036493386, 0.05517497380834915, 0.059135694342154654, 0.020067242252069618, 0.022970033666840004, 0.1231831307673166, 0.04025321664108385, 0.045318329526532086, 0.0941635899606251, 0.04062389977456581, 0.025278467256876252, 0.035079694653470675, 0.12027546703334778, 0.022096754720194206, 0.025784167641353224, 0.0859218092274762, 0.050579273637624524, 0.05994460658140241, 0.03393544274712763, 0.041856385857587865, 0.0722768946340488, 0.035574135460680535, 0.08627866830436454, 0.6013279684608983, 21.993668963832242, 46.52786885538409, 43.61493241402411, 34.54761674327236, 14.618911916209807, 44.385615394961455, 55.639970148763354, 49.18256036696896, 30.763612101154944, 4.994603501212213, 0.6862682428571486, 0.1563522634246657, 0.3319342224107635, 2.409997880458832, 2.861862033605576, 5.132204169227231, 9.439970254898071, 14.018828503547178, 15.381764865690663, 18.59371143002664, 18.019090083337602, 13.018589788867583, 20.246425636353035, 32.033328433190626, 45.0159598935035, 53.49323341923376, 56.94755108125749, 57.85579550650812, 59.152142770828746, 57.47857332229615, 58.064916672245154, 56.485021268167806, 54.93444558112852, 54.01043322778518, 54.90098776355867, 54.4512370324904, 53.78332407243791, 58.090286562519694, 54.95514000615766, 52.974931424663914, 50.67382197226248, 51.3092851638794, 50.30413466115152, 40.152844536689024, 36.49033138828893, 35.707379233452585, 40.01440448145713, 43.83076475512597, 41.98239487986411, 39.58816835957189, 41.54196370032526, 38.00814743964903, 41.668805306957616, 45.55566626210367, 47.83479867442962, 52.768783415517504, 50.89695384425502, 42.70588390288815, 41.46543433589321, 38.37981162532684, 44.682848684249386, 45.52009820938111, 56.07360778316375, 42.65228471448345, 35.94137214845227, 56.75113839487876, 52.10649513429212, 51.72831589175809, 47.21382864059941, 44.833279425098056, 36.455818453142726, 41.6103070782077, 42.48603113235966, 50.74466782231485, 48.0121760983621, 45.27299673326554, 37.78174431093278, 38.473003218250895, 41.06322665368357, 50.970564965278875, 51.81275275445754, 54.82415245425317, 52.97333502000379, 53.88182263220511, 55.1367732017271, 57.06874055247153, 54.386474778575284, 53.841712474823005, 51.796773018375525, 53.88187362301735, 55.393386425510535, 55.93936858638641, 55.88896612967215, 54.423709838621086, 52.01316625841203, 55.11586696870866, 53.380218167458814, 54.14372713335099, 55.314852729920425, 55.73900999561433, 56.95727463691466, 52.844461625622166, 51.37367871499831, 42.75310139502249, 33.64180418752855, 25.603057530618486, 14.361015096787485, 10.53778479176183, 9.998751109646214, 11.921333209160837, 10.740035926142047, 9.403952110198237, 5.979726381840245, 4.358487234961602, 0.7498062882692583, 0.2841605504433955, 0.05457513079407716, 0.25938946513399, 3.429869528739683, 19.248953173237464, 34.474044845950225, 59.803193461510446, 57.14125340984714, 30.413132636777817, 37.93652496030254, 51.7394789572685, 46.8218897235009, 14.628582519869651, 1.8191078906097722, 0.04220570662930127, 0.07887600665731777, 0.07224848809381647, 0.03610493480077675, 0.042969921468606884, 0.06580897516781284, 0.013099348908590694, 0.03702596017730333, 0.019677778473123908, 0.07106354925781488, 0.008422137940332534, 0.11779762459017577, 0.03386878926727561, 0.0071822409142529775, 0.040382953631060745, 0.03017045767797578, 0.06530393170373094, 0.07545230609755363, 0.018410923770598827, 0.04441910318189091, 0.04062774170550608, 0.035860395704906796, 0.05176340042042637, 0.06892955771857692, 0.05519611400461966, 0.019925596425309777, 0.030645985689554966, 0.037019299042801705, 0.01502251496628648, 0.05754948248185458, 0.04335722871004574, 0.04043248504580509, 0.06320477418241001, 0.04560635943386344, 0.022107322903109655, 0.11029174025621145, 0.0011092931597358397, 0.03039582159310099, 0.07858017414447763, 0.07046864368021488, 0.012889049154886556, 0.01801766594120812, 0.07441971150617446, 0.06504234332110613, 0.010152814830953797, 0.04075519575346862, 1.2245604131490955, 26.522363039755053, 54.53353228107576, 50.80099305798931, 40.90986982468636, 18.664386656976518, 36.03354000276135, 55.053438525046076, 56.69640171912409, 35.61149297222015, 6.60588865318606, 0.6894286313364584, 0.042040626172937696, 0.30290479140896953, 3.745438672842518, 4.97050985213249, 6.8348261233299015, 9.404547329871885, 12.24434333462869, 13.281037538282334, 16.53513389249002, 14.903730903902362, 14.274877886618338, 19.899919532960464, 32.41048982066493, 45.817590375100416, 55.88688335111065, 59.4279795308267, 58.639712564406864, 61.22981048399403, 59.55278542733962, 58.57697817587084, 56.88459311762164, 55.806839543004195, 53.87259721755982, 54.67321180528211, 53.67509803464336, 55.39567316732099, 59.99922175561229, 57.36034131819203, 55.52917103613577, 52.998532325990745, 54.44928369214458, 50.573746619686005, 40.55730365937756, 38.29224863360005, 38.25627657674974, 41.94650519278742, 45.323575696637555, 44.29195311761672, 42.09637111233127, 42.389411387905, 39.91329362315517, 41.12955785566761, 46.319261520139634, 50.792791381959, 54.36126962784798, 51.486984222166, 44.46103865100492, 41.11367225646973, 39.549752666104226, 46.96719392653435, 47.39272794415874, 59.053910932233265, 45.653839265146566, 38.81282168049967, 56.687564619125865, 53.99990166387251, 54.05743106718987, 49.868943768162886, 46.12007179567891, 38.05353710728307, 43.5840319818066, 45.97546577453614, 53.75762470306889, 51.27186183006533, 47.481934408987726, 39.148992338488185, 41.437338398348906, 45.03486964010423, 53.81558948947538, 55.15871886284121, 56.36409851812548, 52.27880093359178, 55.51963575424687, 56.70328547877651, 60.455397329022816, 57.599209739315896, 56.52316631809358, 54.23001535477177, 55.66433591227378, 56.95184607659617, 57.48625724546371, 57.934129161219445, 57.812841630751095, 54.91586531362226, 57.489473589005016, 56.278194688981586, 56.49387405764673, 58.88075790097637, 57.762996150601296, 58.47390221011255, 52.50858906776675, 52.15576794839675, 43.91985354884979, 34.187213682359264, 27.24269259360529, 15.735490091385381, 10.065041126743441, 9.602030823307654, 14.960394444004184, 10.913175229103336, 16.465607920000632, 9.30943867852611, 5.608331859111787, 2.5754527699562813, 0.45496288686990743, 0.061741553907913554, 0.2678772903257801, 3.8523784183686782, 23.348861586663034, 44.51359841131395, 64.89801106914398, 59.91929169624083, 31.92244891197451, 43.8990806764172, 57.38810385427168, 54.34275996300482, 17.921687826033562, 2.644485014100229, 0.015109714924267706, 0.03744703274400484, 0.07159807944610234, 0.043393135251056765, 0.032042171355457075, 0.036259044878064625, 0.024590813329503424, 0.06187566142949847, 0.04120572440085873, 0.058674042098104, 0.11538578828255977, 0.04083758084884575, 0.03753633561333822, 0.02439650087316911, 0.05585369323530505, 0.02827104609159212, 0.03735254728986371, 0.09760385334131219, 0.0291142005458354, 0.05465394208928751, 0.03165099153956098, 0.01249706398906006, 0.07908442853799752, 0.14470913657738319, 0.12166068423539401, 0.1634716870443475, 0.23343664323610647, 0.1979757049271176, 0.2716212232987727, 0.2014980086636159, 0.17159251015513174, 0.20753697251840947, 0.19959634860917447, 0.12726321546060423, 0.11882944543275142, 0.20223032743219407, 0.15444340214373606, 0.10804262102371263, 0.273035911903266, 0.1674445730543906, 0.06656222345848238, 0.2160119580765886, 0.16748589583702628, 0.21536986914373216, 0.11368745562410164, 0.1576712523256579, 2.0187811697683027, 32.683588766282604, 61.75529826071955, 57.84747615937264, 46.926518947847434, 22.36597053466305, 55.567673021747225, 63.397520126835, 56.68236355627737, 36.994391256763095, 6.980661317225426, 0.9481162986447735, 0.37383837385043023, 1.0237835383703633, 5.726032872353831, 6.7477519569858435, 13.318516765871356, 18.78420525981534, 22.750706018940097, 25.41269902260073, 27.78679397798354, 27.349902737525206, 19.29157756990002, 24.033760370746737, 35.367023406490205, 50.66931124656431, 57.35709751805952, 61.2361333447118, 62.26218615808795, 63.58381702053932, 61.49138158367526, 60.59027979450842, 58.800255175559755, 55.33361342645461, 53.98478877159857, 55.440776501932454, 54.24197073905699, 54.72541462990546, 60.33859699003158, 58.640995179453206, 57.71793596206173, 54.244469288856756, 55.854566943260934, 55.42611075985817, 43.77169778270107, 41.00204944610596, 39.94739470943328, 43.72493136313654, 48.43210897138042, 45.31333438811764, 42.875000815237726, 44.44732996725267, 41.21127259346747, 45.49344962643039, 49.614821249438876, 53.23645937827326, 57.258010602766475, 54.85054216077251, 46.57309770584107, 44.34492472679385, 41.84818706204815, 48.41257164555211, 50.628102825533965, 60.87989976329189, 48.95132487820041, 43.61323795010967, 56.19630736689414, 55.23206718506352, 55.086633543814386, 52.53142510690997, 49.3818756072752, 40.65467649890531, 45.418669639095185, 46.71856272605158, 53.90708269611482, 53.00385890468475, 48.75253131312709, 42.604031716623616, 42.50636077696278, 45.75615036872126, 56.196954557972575, 57.257410480130105, 58.19417838127383, 52.7023345424283, 55.46697401231336, 57.80764841264295, 62.60313426294635, 59.79645090718424, 57.829048864303104, 54.30905111374394, 55.674949845960064, 58.565101238989065, 58.47997011676912, 61.10949177895824, 60.74067523402553, 56.851249048786784, 60.519367264163115, 59.72362033782467, 58.78621701271304, 61.016668888830374, 58.695763234169256, 59.998213706478, 53.01534360454929, 54.19478070351386, 44.82226148728402, 37.47793712923604, 29.00855148992231, 23.502453757870583, 18.00115700690977, 21.926878844538045, 24.48845132704704, 18.422429369341945, 23.590214829291067, 16.80840542239528, 9.974953109218228, 4.011207934348814, 0.5378911692288615, 0.18795818601164127, 0.6473183716016432, 4.260631453606391, 24.87612270539807, 44.310062700702304, 69.91982552313036, 66.30819336060556, 41.29347762753887, 51.71112414329283, 63.872181830867646, 64.06679414933728, 22.69826981329149, 3.5437425538416836, 0.2074639183739501, 0.16532367395777858, 0.1512736827135086, 0.1378690745801695, 0.26967434873504026, 0.19417816112118383, 0.17679335849900402, 0.2462687078983553, 0.1263878374330459, 0.15189228339060662, 0.1421297491798478, 0.2341262296202683, 0.1276247323520722, 0.1344297228441123, 0.17642821035077497, 0.16486281078428994, 0.09483855938719166, 0.21717441989289177, 0.1121171056142738, 0.13558173522112832, 0.13296508530695594, 0.15695502140348958, 0.17021964995130417], [0.029195086024100744, 0.06745555858698583, 0.05237472709268332, 0.009037890685572019, 0.11865948116587055, 0.029609499371520458, 0.10284862150588345, 0.03373756223628598, 0.04054664746828137, 0.04215619436675503, 0.03802610328420997, 0.027646088799942407, 0.03989153121027254, 0.010984255800834827, 0.06815881964059607, 0.07758550090535034, 0.07774014341374559, 0.03340451317208429, 0.03788166889740575, 0.032201379747881044, 0.0096906186644769, 0.05913528065467554, 0.08620097932796325, 1.3978447212326912, 20.05455505463385, 42.226950737737845, 43.260428597850186, 31.852583654465217, 29.170688544550252, 46.23957857008904, 38.49638838921824, 31.020964691715857, 18.158440128449474, 4.552227316364165, 0.312793362405031, 0.07436544183761844, 0.32783448756221806, 2.5173636934449597, 6.457278382393622, 3.8258009283773364, 9.175411289738072, 8.65283195049532, 12.775707802464886, 15.852569899251385, 11.892026239825833, 15.468884629587974, 23.34154440510658, 37.61911107647804, 50.36315456513436, 58.53683271715718, 55.591709306163175, 54.96039990455874, 53.84213609080161, 54.01668940821002, 55.27207143845097, 55.97628985681842, 57.18469758187571, 56.204403138929806, 55.19343576123638, 56.632137606220866, 54.15063050485427, 54.46476920958489, 53.153709134747906, 52.28137008605465, 53.03528101213517, 53.93314292353969, 51.96126937866212, 49.7963289291628, 37.00668004251296, 36.77402465574203, 36.22686186144429, 36.26132380577826, 36.90200374972436, 38.966453075408936, 39.83069635206654, 43.63875689045076, 47.44413060526694, 51.19650917668497, 58.836144862636445, 50.57690412767472, 50.15876377782514, 45.377539665468284, 41.35874978957638, 39.25434720131659, 43.06902085581134, 46.59621223326653, 55.113184067510794, 45.05974531173707, 39.43055968130789, 56.1559187212298, 49.56858042747744, 56.71658623603083, 51.91665634032219, 49.56441879272462, 41.595331468889796, 39.35738394337316, 37.50346391431747, 39.65196571042461, 38.74445084602603, 38.57953871450117, 36.798606149611935, 38.351488190312544, 37.88277672183129, 44.33531491987167, 52.015378475189216, 53.61044952946325, 52.8898669827369, 52.585777390387754, 53.52117638434134, 52.85003531363703, 52.91287168379753, 52.310846697899606, 51.560869909101925, 53.870435991594874, 53.88008502221877, 53.80927447349795, 53.51620281896284, 56.8151318642401, 57.786420545270374, 56.97637657965384, 56.99671799136747, 55.74510928123228, 54.394547016389915, 52.897111600445164, 52.67141057598976, 53.65001839976157, 52.183981557046216, 46.22642294053109, 34.9466904517143, 37.339599055628625, 14.169326905281315, 17.991809998789144, 2.1506603254425913, 6.596554883064763, 8.756733575174886, 16.5955364319586, 10.020125085307706, 3.4567742914922777, 1.7402175044821155, 0.2799458104756571, 0.10292951272980821, 0.1078862471566085, 2.7911546922499135, 10.847316672725063, 30.143875652743926, 34.584114397725756, 54.82431719380041, 40.500350844475534, 36.399308866070164, 53.16882202702185, 49.96540269544048, 14.809828381384573, 1.4301545100827373, 0.14607389157097186, 0.08582490676593396, 0.03067549348117844, 0.059460619043919354, 0.07686801359898622, 0.014421146479435267, 0.052951415099443934, 0.03307855042118219, 0.045436674789074934, 0.024280474941817023, 0.050643716953815, 0.06481588006980958, 0.02660972122553616, 0.03221491652150308, 0.11849409044389764, 0.031052636651081905, 0.05298617250856854, 0.01834605336039057, 0.05198995943271345, 0.08903513692559735, 0.03942963381808612, 0.04008243649056362, 0.06953641426779571, 0.05055203538147673, 0.09202802794114237, 0.048203872471687295, 0.010209945837907013, 0.01857242851157583, 0.025233461506544583, 0.03203571706469501, 0.05951692650635397, 0.015346155513168104, 0.02348510905229036, 0.025910556827101017, 0.013363199165811943, 0.09551697620941747, 0.019055829991796808, 0.05792248686174712, 0.01757591283099065, 0.01320095802281773, 0.04326443247977765, 0.06337445882719851, 0.022973320184035168, 0.028648537831501137, 0.06763798710439475, 0.06616834701309282, 2.3142484118861537, 25.259369650194724, 50.853235106314386, 49.200626803982644, 37.34836555296375, 24.75628645189347, 50.34754745421871, 49.2087657220902, 40.42886957045525, 22.950160503387455, 4.971375715348029, 0.43321325233386415, 0.04890220374950478, 0.20731987852242686, 1.7769280700914323, 6.226032597403373, 7.9262731825151755, 6.946304786589838, 11.389559834234177, 15.61381228508488, 19.851899916125884, 19.207748674577285, 16.32787977495501, 23.421105761681837, 38.95263848766204, 52.0736413617288, 60.14665972801947, 58.0710159578631, 58.35527404662102, 56.94076930322955, 56.83727364386282, 57.3725163552069, 57.47958921617078, 57.236778813023726, 56.14991749486616, 53.83529155485092, 55.77209518801782, 53.168739657248224, 55.53633720644059, 53.954049156558135, 53.663126960877456, 55.023561831443544, 56.26417613798573, 54.97022544184039, 51.87741694911834, 39.89874555218605, 37.57456471843105, 37.50113794880529, 38.284243076078354, 38.940761550780266, 39.68585891108359, 41.71075113358037, 44.66148353392079, 48.405432931838504, 53.39363659581831, 58.26032523185977, 53.55941949352142, 53.25195274045391, 47.123272880431145, 41.848747960982784, 40.62292883473058, 46.14836385173183, 48.29821102080807, 58.093244029629616, 47.25071460969987, 41.50607401324857, 56.71093410061252, 52.42832952930082, 56.52184055697534, 53.6611657757913, 51.11246062863258, 43.09496341213104, 41.036299582450624, 39.9965851537643, 42.38212754649501, 41.57517440857426, 41.13787328043292, 37.85658705619074, 39.93159148000902, 39.743219652483546, 46.71226339955484, 52.80175093681582, 55.39893657930436, 53.1175527264995, 51.99080874842983, 52.44198722224082, 54.50730339173348, 54.54017677614766, 52.95042053345711, 52.61699945695939, 53.56109042321482, 55.101146313451956, 53.55362223040674, 57.36584048117361, 57.14332049892795, 58.34238121586462, 59.249468541914425, 57.97702812379407, 57.84788408587056, 56.17518932588639, 54.29265560642366, 53.26746571448542, 55.13577299733316, 52.85027065584737, 47.24576065617223, 36.829051586889456, 30.883877854193415, 16.17354529519235, 11.03307325993815, 5.141239839215433, 12.331751392733667, 11.40301356392522, 16.25309194287946, 12.703525404776297, 10.28305724743874, 3.184704232600428, 0.4826557089484507, 0.22885637207617684, 0.19443498443691962, 3.0382044421088312, 14.193240615629382, 33.110962375517815, 41.16843638881561, 57.65372283997075, 42.821554599269746, 42.4149146387654, 58.51522830224807, 57.384452127641254, 18.323683700253888, 1.9360729691482361, 0.09146329856687978, 0.03651744633492443, 0.05251228967080674, 0.08272255710776776, 0.04379450403634579, 0.03792360071994124, 0.03468854931153117, 0.08985079839945802, 0.022984464848113638, 0.02199366035300397, 0.0629025946311172, 0.02975311978990513, 0.0648544142924009, 0.055913386806364984, 0.041697315360990264, 0.02480800691691618, 0.019052083821847074, 0.026690669906055255, 0.09150216220727853, 0.10233148917435639, 0.04088783238623892, 0.05887052449848383, 0.08241225319403796, 0.16239308121223606, 0.19111408521571469, 0.1394419603410267, 0.10659340483647202, 0.24163428964393757, 0.11306272624360938, 0.1392892943394761, 0.08240863725903534, 0.2399281352277725, 0.2144930202273592, 0.07811833803932514, 0.1810785172687423, 0.17594965054623543, 0.06555446543760839, 0.13421779228073938, 0.1759044513587029, 0.17024756619526496, 0.11120176077970576, 0.13545625001913117, 0.22019534972646546, 0.09692856215781744, 0.11697430223707231, 0.14794887644388985, 3.186323190889051, 32.36908528112596, 56.96444472958965, 56.10078588608773, 43.732576062602384, 39.39297945268693, 57.070819408662864, 48.07138427611321, 43.13678764527844, 25.438886727056197, 6.344057696480905, 0.65754723885367, 0.16903838833733914, 0.7295732320316377, 4.153198715179197, 12.085797209893505, 11.473420108518294, 17.78645234723245, 19.913485050201416, 27.435098578852994, 21.38731368126408, 16.895668352803877, 19.6814807768791, 27.285493496925604, 43.816295131560295, 54.48079601410897, 62.03937592044954, 60.522701278809585, 60.07812807636877, 59.69507332771056, 58.73141365666544, 60.21729769245271, 60.53548820557133, 60.00978077611616, 56.6597040237919, 54.366878617194395, 56.744529201138405, 54.41399412770426, 55.325498042568086, 53.93684956335253, 53.76742670612951, 55.702010277778875, 58.79076303974275, 57.721599455802675, 54.12431924573837, 41.20389461517334, 40.47350222064603, 39.792602292953, 40.35113996075046, 39.99816979131391, 43.1046163651251, 45.033543878985995, 49.085348344618275, 50.99227136181247, 57.357795699950195, 61.17762334885136, 55.6287560924407, 54.96724444050943, 50.5285922942623, 45.41408438836375, 43.83833492955854, 47.793805983758745, 51.513377851055516, 60.279173081920995, 50.228966359169256, 44.90228568353961, 57.55056058206866, 54.44384728708575, 60.34595927884502, 56.956305811482096, 53.890208659633515, 47.31393929450743, 43.26363317428097, 42.2863079655555, 43.519760024163034, 43.168327423834036, 42.300381429733775, 39.02240568591703, 41.25062181103615, 42.01000444350704, 48.756787084764056, 55.7643759635187, 58.08234768529093, 53.724119817056966, 52.31295693305231, 53.86077911623063, 53.57107677767354, 54.287682041045166, 53.26535547933271, 51.11895215126776, 53.77149812636837, 55.07341123396351, 54.31211448484852, 56.20552101442891, 58.18511770617578, 60.94747827899072, 61.33110961606426, 61.1220080621781, 59.458981944668686, 56.9118732021701, 54.22102135996665, 52.509754011707926, 55.291196915411184, 54.27489119191324, 49.720403609737275, 39.724878649557795, 43.27312923246815, 18.71546180017533, 26.250221152459424, 10.565755213460616, 14.54057433912831, 18.112832769270867, 24.295690367298743, 20.317098902117824, 11.883564706771605, 7.702360758858343, 0.9084491852310397, 0.46578798503164326, 0.26152611499832523, 3.696670128453163, 15.097030208956811, 40.376851097229995, 47.413853829906834, 65.70826292037964, 52.15326939859698, 50.89807171975413, 65.61174515754946, 65.94052607013334, 24.501869755406535, 3.1696590012119663, 0.46593804633425134, 0.21454218775033954, 0.1379704433343103, 0.2816599475279931, 0.13650260354963042, 0.12185501775914624, 0.1197798234680968, 0.1385054638188693, 0.20556901521500082, 0.1601011300038907, 0.142793380505135, 0.11783411335800925, 0.1351521284349503, 0.22240897610543237, 0.2100566816666434, 0.12747549076354311, 0.0923554845634968, 0.1651559313458781, 0.26711374581340824, 0.21688908278461427, 0.15860678357703073, 0.16814920540538528, 0.24229278818013208], [0.03685554391854713, 0.09820729313838868, 0.09015762427401158, 0.05418808402253255, 0.038817050761633345, 0.07757112909589084, 0.061438516338145545, 0.0328645016246986, 0.03035021254852895, 0.051837768405675895, 0.04840998076683572, 0.03629131250143532, 0.03290050009626054, 0.0577732912384935, 0.03242261444909438, 0.09067120195756997, 0.031539253785365054, 0.09927659866309936, 0.06547406450995515, 0.10252264343322286, 0.04891595502774562, 0.04305855018056689, 0.11072133172063098, 1.9057352744763898, 21.270860472033103, 43.388595965600786, 43.00125406634423, 28.506454767719394, 21.797666165136523, 31.588700317567397, 33.38307288385207, 38.638609609296246, 25.820829483770556, 4.241421645687473, 0.392241123462877, 0.6039224937558174, 11.273621436088316, 10.425142165153257, 4.337074525894658, 5.282582448374841, 3.8851711490461907, 11.882307587131379, 11.069835674378181, 21.14845702725072, 18.53358934002538, 18.79003586307649, 26.289868470161196, 38.04039324483564, 54.7145418197878, 55.01119067592006, 51.22683694285732, 51.398154304873565, 51.594406174075225, 48.56314751409715, 49.77136304301601, 50.338722121331, 53.4371356810293, 54.41171915300431, 54.893574483932994, 58.7107192316363, 54.96054895462529, 55.875175076146284, 53.92945589557771, 53.60628789471042, 55.27098494191324, 55.812346550726126, 54.64393523431594, 50.55312671969014, 42.10858145067769, 35.48456899581417, 37.05099105834961, 37.08057357418922, 44.1235226200473, 46.01484637106619, 49.51986458993728, 50.62527479663972, 54.69624396293394, 53.974712202625895, 50.32462904530187, 48.66853375588694, 52.09410044454759, 43.8109528633856, 40.24267073600523, 37.83415502117526, 44.65145403339017, 47.020793114939046, 55.18673635298207, 46.109187218450735, 40.5035867998677, 56.24276784158523, 49.58183019391952, 54.104126884091286, 51.67305361840033, 49.745020404938735, 44.70355879875922, 41.306684247909054, 39.87182240332327, 38.22126157822148, 37.845953510653594, 36.91675578394244, 40.225023992599986, 44.954814064887266, 36.69212556654407, 42.23013177994759, 47.95880832979756, 56.103931626965924, 52.87347147541662, 52.509542203718624, 53.0162771286503, 54.78871383974629, 54.288486126930486, 53.06505180174305, 53.883309210500414, 54.50096091916485, 53.46078757316836, 52.25851051269039, 53.653219053822184, 52.578658288525, 50.33661973091864, 54.63735349716679, 53.4857181579836, 50.9893766526253, 50.61708096534976, 51.608597309358665, 52.20518589019776, 54.74435575546757, 53.71391773223878, 54.2326472651574, 46.88698930125083, 35.77869969029581, 24.561987923037623, 8.762724995613098, 2.435251815665153, 12.229598164558412, 10.040099755410226, 18.312036222027196, 6.133967705311314, 7.727181027012487, 2.6143261549934267, 0.6785668528849079, 0.14346692500816238, 0.048925117439320015, 1.4149500549800935, 11.362454295158388, 31.757532858079482, 40.25553611017043, 34.68499775855772, 26.55965301298326, 37.13520826831941, 47.26968319185319, 46.276021311360026, 25.028018451506092, 2.5984569807206435, 0.0666011177423981, 0.08396885192562496, 0.05278192580707612, 0.02180032274355331, 0.07085598539561033, 0.047526995486189286, 0.04033705347307748, 0.05297038726688874, 0.0837526772351515, 0.05431400206420691, 0.016443050736861847, 0.10258583036521751, 0.047921327753893794, 0.049621035540176016, 0.19992526079858505, 0.011559690296229337, 0.040398183458995436, 0.01415386223309343, 0.006672309809214166, 0.006673391908407212, 0.07651775053912595, 0.021651751481957977, 0.04351286330230294, 0.02611012847703551, 0.0571227255427549, 0.05556405071289309, 0.07550069987173043, 0.03662226631516411, 0.09124533889154274, 0.06641036184925227, 0.012957779690623285, 0.023213701337696086, 0.021775995621517785, 0.07634630772255122, 0.008323814385690758, 0.11382924317712746, 0.07283025526351507, 0.032173892513157866, 0.021916565094744007, 0.17048218828295508, 0.045782471556336655, 0.07699525314232997, 0.05921077861961338, 0.09654334250597224, 0.05888307301868355, 0.09646184607258729, 2.541927291500953, 25.47215823204287, 49.29760348412299, 49.60566643745669, 33.36049572114022, 28.308386841127952, 33.33283908905522, 39.94997955137684, 40.947567724412494, 26.389224067811046, 4.642453597437951, 0.48984093952082824, 0.19361393736495128, 8.738539661130599, 5.754700985647017, 5.281350333844462, 11.036492586135866, 6.944994224656013, 10.867990505310798, 13.604681126533018, 20.92225786178343, 16.051153617520487, 13.69391602854575, 23.38874032420497, 40.68844810608895, 55.36292529875233, 57.59870375356367, 54.107959039749645, 53.43148354561099, 53.86128510198286, 53.28270412260487, 51.72147920054775, 54.84503515305058, 55.403831697279415, 55.82286242515811, 55.36616909888483, 58.861224497518236, 56.46374633235317, 55.969323727392386, 53.851467409441554, 53.1382236173076, 53.34698000261861, 56.69935918623402, 57.546614677675315, 53.11212808855119, 44.46299983609108, 38.11365527491416, 37.83358627750028, 37.537204142539736, 43.58156088859805, 46.062103086902255, 51.99118529596637, 52.701910926449685, 56.27251901934224, 55.760128036622085, 52.47569214913153, 52.97452742053617, 54.53479528427125, 45.95983120702928, 42.039508511943204, 40.03969200195805, 44.872573729484316, 49.366813705813506, 56.873661471951394, 49.38692762005714, 44.53852115138885, 58.172275866231615, 49.94376297919981, 57.346012899952555, 52.892973499913374, 51.143780754458525, 45.25079219572006, 43.33064686867499, 40.85345437449794, 40.047674025258715, 39.41020650248374, 38.409535346492646, 42.01364440302695, 46.61539262340915, 38.06142891606977, 44.53762292861939, 53.389431814993586, 58.28804462186752, 53.53772486409834, 52.53902666030392, 53.8910049007785, 53.809015597066576, 53.786163868442664, 53.73979753063571, 54.10172639354583, 55.54475461283038, 54.75544821831488, 53.51493589339718, 53.37675471459666, 53.00585931347263, 51.66977451693628, 55.115694384421076, 54.870989476480794, 53.085765838623054, 52.17639569313296, 50.729758893289876, 52.5800036614941, 54.323097121331, 54.02275339249642, 52.79196854560606, 44.31305546914378, 34.61558749598842, 24.032160043716434, 13.155957075857348, 8.738729896083955, 10.171895315570216, 14.671859010573357, 9.703765338467015, 9.965544323767386, 10.325960132383532, 2.938554176399785, 0.9397415480306073, 0.19653182837270922, 0.08229525624624184, 1.7925842106342318, 11.735844323712012, 31.48282574069116, 44.86021434107135, 45.03659940535023, 35.8116279878924, 43.25040301968975, 53.91808886681834, 52.24462924465057, 29.584888873561738, 3.1975534269886636, 0.055252597667276866, 0.09126551764746828, 0.03455806155538848, 0.0016025533536336415, 0.016631879918878118, 0.025938022994406285, 0.043585729755220876, 0.06221602663337704, 0.08575133168168607, 0.07176239764498127, 0.03355437912227165, 0.07672157589226, 0.027766029440587568, 0.05314276088029147, 0.0469938212735278, 0.04883034087176766, 0.07263037526319105, 0.036153914632215615, 0.030409626497496522, 0.025781691262137987, 0.04037385633695991, 0.04977611854912774, 0.02826931664810306, 0.09503869219653069, 0.1832264745908399, 0.22725458947881577, 0.21207126308112376, 0.15626431653095832, 0.20902450076274334, 0.28121255218021335, 0.12773079722518885, 0.2142938220452878, 0.15749220225599506, 0.19549394777465254, 0.10969400781417087, 0.22197553887963298, 0.22064616182638755, 0.20836781019405012, 0.19263515278937357, 0.27286856765708617, 0.23637365579845446, 0.15773879063706245, 0.22194671865192153, 0.12427367224928834, 0.18362027442743703, 0.19528066889653284, 3.311481365273076, 31.062734011680853, 57.39471304801203, 56.44934338908042, 40.386409913339925, 33.04955767047021, 39.68110892080492, 44.66130310489286, 49.85177555391866, 31.06076890422452, 5.682220487825333, 0.8723459128410587, 0.8964598479290163, 13.015377367696455, 18.157483070127427, 9.02365969073388, 16.146205394498764, 14.245057086790762, 17.74667755250008, 16.18110468310695, 32.80937525533861, 27.105188023659494, 23.652354978745986, 31.504765518250007, 43.65739991587978, 57.82911162222586, 60.253175612418886, 56.84297677009337, 56.28572563971243, 55.213910533535866, 53.20618260291315, 54.06735466372583, 57.355501113399384, 57.730585605867454, 58.82399335984261, 58.690597472652314, 62.13275186477169, 58.91632595369893, 58.21929331748717, 56.09592606944423, 54.84023809432984, 54.764752080363614, 57.447633666376916, 59.81573720132152, 55.15520834153699, 46.43595203276604, 40.168475181825706, 40.564367848057906, 41.56845931083926, 48.20463111323696, 49.62452911561536, 56.17031381976221, 55.49646239126883, 59.46488118940785, 57.999593519395404, 55.731851670049856, 54.32415616127753, 56.49623140212029, 48.26593383666008, 44.88591763281053, 41.68138434810024, 48.51876981796757, 51.227252714095584, 57.38984538662819, 53.85604481543265, 48.10587759940855, 61.17138285790721, 53.21219559638731, 58.27866623478552, 56.16934891669981, 53.51161364586123, 47.94242851195797, 44.858029580885365, 43.627797788189305, 41.9956015002343, 42.33770278192336, 40.675363079194106, 43.704652709345666, 50.88203314811953, 40.38220905488537, 45.66890116660826, 54.182535063835886, 60.420084230361454, 54.69855031659527, 53.765606726369555, 54.119902656924346, 56.24792183599165, 54.8677025302764, 54.40496875393776, 56.21459345663748, 55.964973818871286, 55.020208204946215, 53.73416500706827, 54.03874097331878, 52.5035095983936, 50.60070899225051, 54.42079551758305, 55.078843716652166, 52.3235708667386, 51.56753009365451, 52.279930576201416, 52.62632685322916, 53.44281919540898, 54.33730394609513, 54.992767303220695, 49.790111972439675, 39.797081639689786, 28.396455818606963, 16.417891306261865, 9.247917282965876, 25.89095557889631, 25.407837244772143, 29.758396879319225, 15.946611665910291, 17.876170681368922, 5.57440237652871, 2.2188093008533603, 0.48435682250607404, 0.3723255647045951, 1.9653966085564707, 15.622187525995317, 40.311351437722486, 52.52172116310366, 46.0663039453568, 38.57664792768417, 49.468595289414935, 59.27338323285503, 60.79419989739696, 35.79169450267669, 5.562873059703458, 0.2769629398901617, 0.18210902810096743, 0.19078010152424538, 0.1423056582890211, 0.19509434099158934, 0.11346613282277701, 0.1391602391677518, 0.11090893899240803, 0.16977109014987948, 0.09555993842021113, 0.1718988687160515, 0.17328211707213234, 0.11291619660633226, 0.129421652865506, 0.19647162918361927, 0.1093522483302701, 0.12706535793240034, 0.1234149183296869, 0.097494111246159, 0.13164824145215173, 0.16120893910767572, 0.15658189061908953, 0.18915411054847703], [0.06226479962107636, 0.06322573434801833, 0.0460910287895991, 0.02108653564186346, 0.05001776949352315, 0.048891007374491424, 0.0671544477283474, 0.0935816772342209, 0.02838753742135821, 0.054427551616343765, 0.04884233780866189, 0.0417995689466836, 0.07095337049254487, 0.0383303627642172, 0.08177711267865474, 0.04535715486253462, 0.027475567204096628, 0.03795610966100808, 0.03214720584031555, 0.010451888853323557, 0.028326143135106372, 0.03560551059161944, 0.07903760524406549, 1.8742497962328697, 22.163517398218957, 47.23477801968975, 44.755424299547755, 28.154520104008338, 20.58116855159883, 32.33426443992123, 33.304217553907826, 35.39892796547183, 18.2486742542636, 3.4276269135936617, 0.42508067743432143, 1.6817316557130508, 9.518200947392373, 11.144819624962347, 10.225851439660596, 7.378601950983848, 4.161201330923265, 8.631838444740541, 18.92888580599139, 20.93286983428463, 17.196249385033887, 16.90591750606414, 22.016893317622525, 52.541937058971776, 54.03938816439722, 53.519364249321725, 50.97488741720877, 47.68832168271465, 44.080023534836315, 41.9720672792004, 42.33607499830185, 44.10540126985119, 46.52008687296222, 47.765317809197214, 51.21858427601477, 49.98539501620878, 51.15721094992853, 53.800139273366625, 54.93813653146067, 55.425334130564046, 52.672155826322495, 52.18236554053522, 53.87042814685453, 50.39339211679275, 42.36580264183783, 36.42882077924667, 40.0714082871714, 46.60070334711383, 54.68284122405514, 50.86557880524666, 54.560094571882686, 51.69677219083233, 54.90103483200074, 48.992529376860595, 53.523270930013354, 56.26030868099582, 50.311920565943566, 43.63671725796115, 41.579183070890366, 37.65684035516555, 43.93607647188249, 44.63801599317982, 55.509147336406095, 45.80628218189363, 44.46525127656999, 56.6637989782518, 47.016980571131555, 50.123642875302224, 49.958601305561686, 48.72968350687335, 43.132476960459066, 40.741937468128825, 36.76994146839265, 39.62050045690229, 38.45443864022532, 38.541640773896255, 37.079236045960464, 39.41569782072498, 36.84712586864349, 40.30866461415445, 47.43869027783794, 55.08566471838183, 52.73878120606946, 50.699760606212, 55.90886823592648, 56.35627731200188, 52.62199655655892, 52.89670759631742, 50.92663834171911, 52.97848901441021, 54.28703092759656, 53.73088198323404, 50.357008211074344, 49.80739785778908, 50.77518778462564, 50.63599463432066, 49.633452507757376, 52.306994930390395, 52.122941632424634, 55.128391096668864, 55.28515646534582, 57.3662523300417, 55.829856011175345, 56.10373943082748, 46.089253733235026, 39.36209078757994, 24.523678133564612, 9.79011239544038, 6.677997016137646, 10.445178612585991, 10.980494868370796, 7.608736724622789, 14.22481079255381, 13.75376747500512, 2.5819739555158927, 0.6234654579912463, 0.11725374046833285, 0.09112815042176554, 1.209829461670691, 9.307396104258876, 27.975809074217274, 38.89506986064296, 22.246106824567242, 22.967832742198823, 39.12623866911858, 45.3093021915805, 48.57351826083276, 19.784850920400313, 3.6844075735538238, 0.12038949922087694, 0.07318051832337534, 0.0652337657107461, 0.0538903899160364, 0.05746102613967754, 0.04086235613231698, 0.06226304144929014, 0.024952178918606332, 0.07339242590411056, 0.10882828249445847, 0.0374578882098919, 0.06515578562093359, 0.039301919300229325, 0.041348550003021955, 0.009339604838450831, 0.02006299046408986, 0.016101852412365617, 0.03948924311947438, 0.08591343588646382, 0.05826524225994945, 0.0398205416727691, 0.07919672170593854, 0.017717047294061032, 0.04169050483934341, 0.030115713034906698, 0.0343590472344189, 0.024270598153253237, 0.06945708586323647, 0.03636628569614503, 0.039490357777404214, 0.01855913114043013, 0.025363133379047918, 0.03911815012895292, 0.030056837262705933, 0.029261894636757435, 0.055285742461320855, 0.027551789122122913, 0.14455336025885998, 0.026822406385514527, 0.005612417589873076, 0.0679018201246377, 0.054751997513155785, 0.05791254687092959, 0.015041764840603837, 0.03227956285099349, 0.05082821007817984, 2.673445098823117, 26.447706607080278, 54.405764995082734, 49.33808626667146, 34.5937006704269, 24.37749728079765, 39.31726594125071, 36.89853245212186, 40.47377678655809, 21.126560395763768, 3.892541772896244, 0.4977219617895542, 2.1656521145374548, 12.227800738426948, 17.51140986719439, 10.07533440666814, 5.991930346335135, 11.181634991399704, 12.911939563289767, 10.945586754429726, 13.725804898046679, 8.66110226800365, 15.004517186072567, 26.95021910052146, 50.087200134031235, 57.575408797110285, 55.03856097498248, 54.83330726623536, 52.536461430211226, 48.412246088827814, 44.62402489877517, 45.74024123530234, 46.666104947367025, 49.80447176964053, 52.02058738277805, 53.35402850181826, 52.762201678368356, 54.260982467282204, 56.13153334586851, 56.285400082988126, 56.18792133946573, 53.48100346903647, 53.8287058953316, 56.99020293451125, 53.113524452332534, 43.64714291787917, 37.40483983870476, 41.16698511185185, 46.90285528859785, 56.01023404828964, 53.31415760901667, 55.723402884698686, 52.47566469254033, 54.77526011005525, 50.40022096326275, 54.45453182343514, 55.84756943487353, 52.64511108398438, 45.09931025966522, 42.32870094237789, 39.2595600312756, 45.36667077772079, 48.03235277052849, 59.019931439430486, 47.56260187395158, 47.81018972396851, 58.74094893855434, 49.81787450851933, 51.80858719733454, 51.80398625712241, 50.54438767894622, 45.31000037347117, 41.994001173204, 37.843419659522276, 39.7782777970837, 39.90114996510167, 38.97270141109344, 38.941620549848004, 41.92446539478917, 37.84344711611348, 41.74598970720845, 50.045054266529704, 56.519840148187455, 54.72341422111758, 51.22684478759766, 56.432818443544456, 57.58713276155534, 54.9737947986972, 55.229317603572724, 53.45943827782908, 55.76177543209445, 54.896837895916356, 53.57244568486368, 51.99699040382139, 51.457095761452955, 49.96224910982194, 50.722788841493674, 50.212868951982074, 52.31932293984198, 52.951146171938994, 54.5744582914537, 55.410197704069084, 58.563728409428755, 57.958855782785726, 54.11737665053337, 48.398074565395234, 35.87700213155439, 24.2512930593183, 10.203299772354866, 10.965816378593447, 8.727493286132812, 11.684344583942044, 12.377759814262392, 12.84285976040748, 9.130742357623193, 4.017727894167747, 1.5937508089888481, 0.1135806936109739, 0.13333449290404398, 1.3350336013301727, 10.34769888847105, 32.33625700396876, 46.142939213783514, 27.87471978895126, 26.540439282694173, 44.733086401416415, 52.04735755920411, 54.69860915214785, 24.725060462951664, 5.541126949171867, 0.07606881535461835, 0.05818279970797801, 0.04627963197567771, 0.00883607056757976, 0.06243912292824638, 0.01625978718361547, 0.05667441855034521, 0.021863871652092186, 0.040369876510193275, 0.060584190406746445, 0.05169997217073556, 0.05979968189832665, 0.05467993928299797, 0.02313829530330916, 0.019087697334227063, 0.0088891968499088, 0.019542129199591377, 0.0412479396759262, 0.046671650657850894, 0.02983943874677343, 0.025638942268767187, 0.03982648268462189, 0.0315095353195624, 0.1118361735115609, 0.1742876534380259, 0.11291589017116255, 0.11340194231560154, 0.13506179134691917, 0.10524023309229844, 0.13327792497171512, 0.19017781851993454, 0.17566622865776862, 0.1219439605671552, 0.15325323858809087, 0.139601904177858, 0.15301533764408481, 0.11998474432696259, 0.2324803663237441, 0.07232655245330065, 0.281873011901494, 0.16354291789954709, 0.14749679263801346, 0.1270850617138128, 0.10758990136485909, 0.2196404722429091, 0.2196329339377342, 3.557121513351318, 32.95378908034294, 62.2234998210784, 58.296109014941806, 39.5099013851535, 31.2763717866713, 43.48681603708575, 42.72962600954118, 45.23203542155605, 23.286568464771396, 4.915604024164138, 0.7607055130985476, 2.456692961915847, 11.844457695561072, 14.589459819178428, 19.956093757383286, 19.405085079131588, 13.311169185946065, 15.801916410846097, 27.838229979238204, 33.715211345303445, 26.952129294795377, 22.77635439749687, 24.52155613130139, 57.53028977301813, 58.65589234136767, 59.89736564697758, 54.77244384827153, 55.23939417254541, 48.92334268939111, 46.45497552810177, 45.59365441722255, 48.80674239127867, 51.194857858842425, 53.6016869544983, 57.46273871391051, 55.993642422460745, 55.22928622461135, 59.35556081033523, 59.14930297482399, 57.95139151234781, 53.07753670600153, 54.555638759366936, 59.35980481486167, 55.23045116855253, 45.484702740946126, 39.92662968174104, 44.3560250343815, 53.09401066072526, 59.20597337907361, 55.88855035843388, 56.596145937519694, 54.38441553423482, 55.691459102015344, 50.67511243204917, 56.01084201566635, 60.31663171706661, 54.60967725323093, 47.5737492499813, 45.00898199696695, 42.48870226644701, 46.828534218572806, 49.185698263106815, 59.74429907337312, 50.64601629011093, 51.36252741659842, 60.11143684387208, 53.77814654381045, 55.15342366310858, 55.389036516989435, 53.25289410929526, 47.863514346461145, 42.968584645179014, 40.344832789513376, 42.80221731432023, 42.07898324535739, 41.52531323894378, 40.64934599784113, 43.22224040185252, 39.82355763835292, 44.06794655707575, 52.8162480169727, 60.25420719577421, 57.79885445871661, 54.73844082124772, 58.78464806464411, 59.49635821004068, 56.24844743359474, 58.225737771680286, 55.656008720397956, 58.094424663051484, 57.066846047678304, 55.53171273200743, 52.58803275323684, 50.6159552451103, 51.51978308154691, 51.478115743206395, 50.02503056680003, 54.168916594597604, 54.32030439376832, 54.72390843975929, 54.89615540350638, 59.21788561728693, 58.524077169356815, 57.485198205517186, 52.49666506244291, 46.24707029711816, 31.60699425205108, 18.069649434858754, 12.129646366642369, 18.361836594920007, 16.846370043293124, 19.36892278732792, 25.57942132796011, 19.844906330108643, 7.6028659170673745, 2.557715812037068, 0.748177707916306, 0.3504611701974946, 1.818016613683393, 11.30840599536896, 36.2239553851466, 50.153233235882176, 35.38838463444864, 34.56744432449341, 53.48061907675959, 58.805303265971524, 65.35313544734832, 31.455594685769853, 7.172540724277497, 0.35570078259033544, 0.20560433186831015, 0.21719128914898445, 0.1003622525041142, 0.20336098127788116, 0.09825230846481939, 0.16053942422713005, 0.13902799707026253, 0.23413199060145887, 0.18723194998118187, 0.2240912132566014, 0.17403084544404862, 0.16744468030669998, 0.1590918857724436, 0.1360802592769746, 0.10645472760041876, 0.13796454445729334, 0.28059266447540254, 0.26366022145075185, 0.15055702278210273, 0.27087526816514235, 0.1431317308977727, 0.1234027145490531], [0.02637209224274322, 0.01972688853950991, 0.07482596027154116, 0.10247977315298012, 0.07869388457507857, 0.03438725076135128, 0.1017176152597512, 0.0067758968667007025, 0.028758553803087245, 0.02180813492516116, 0.020587584491999402, 0.02092906243858799, 0.03389976603249389, 0.04885570604294058, 0.08217978381341504, 0.04327944397265392, 0.06332550963927662, 0.009492534182725415, 0.029642787807050253, 0.05177093106472204, 0.06606820399963087, 0.052286117532921415, 0.010694088508194734, 1.8586262603921277, 18.674237689664288, 43.37981377878497, 46.948570512956195, 32.43106265221873, 28.42694832432655, 18.885339652338338, 30.880541878361857, 31.206908572104673, 16.127873216905904, 3.251695618514092, 0.15477920912446516, 0.14290599543000423, 0.2633769527798699, 0.2132648740324282, 6.6164677758370685, 18.891319305666034, 10.640655813678618, 13.963713319070878, 8.540161867295543, 9.263819552236988, 10.289308524900868, 10.549767632638256, 30.661718730003606, 47.342380400626894, 52.67425429436469, 53.925113831796956, 49.512133598327644, 43.9120166532455, 39.93503139865014, 38.70302669463619, 36.87294290911767, 36.31199298366424, 35.763504428248254, 39.770272239562004, 42.069063571191606, 43.807132474837765, 47.037643617199315, 50.06541921246437, 53.8747113750827, 54.510664862971154, 54.05442653163787, 53.723551073381984, 54.530076672953946, 47.72556850987096, 39.80766027204452, 35.76078622571884, 45.90911103833107, 52.72135019302369, 55.94502072180472, 54.428797152734575, 54.66184085415256, 54.943384662751235, 54.63707500888456, 55.159942642334975, 57.038408863929014, 49.716285121056345, 46.572862363630726, 39.48891670473161, 37.85188021198396, 37.55321133521296, 42.01357772273403, 45.9790272866526, 53.7345572440855, 46.54071069532826, 42.41447141093593, 54.37921054901616, 45.69351403943954, 44.949573778337054, 44.55419102022725, 42.97490750589679, 39.43548617824432, 39.08014689722369, 37.85439445126442, 41.424127855608546, 42.95867673812374, 45.92527120344101, 43.1517985559279, 39.77375138190485, 36.337049084324995, 36.19781671031829, 44.00369028891287, 54.20486119485671, 53.505867373558786, 52.95373885862289, 54.516721002517215, 51.794050893475934, 49.42360962590864, 45.35939478105115, 44.58548368946199, 47.82663622210103, 52.69369748330886, 51.89270242567986, 51.13703427776214, 51.6832164795168, 51.80391173208914, 52.76840294561079, 51.593456960493526, 49.89616109478859, 51.5349587317436, 52.95999503904774, 52.39857050680345, 53.86593703300723, 53.31444001966908, 52.06680467051845, 46.2483960582364, 37.63307471429148, 30.787028651083673, 15.661897601619845, 18.433719911882957, 6.216563995807402, 10.086144458863044, 6.107753524857183, 6.590072676058739, 5.054842772022371, 0.6931274264089523, 1.078770816806824, 0.15285067470563998, 0.03971794717794946, 0.6085918915848578, 7.230959034735157, 22.16860471233245, 37.10692013463667, 34.34477921455137, 37.24333624685965, 48.58750151049707, 48.70074033737183, 42.79851459687756, 20.297687092135032, 6.194201582862485, 0.056789373873823115, 0.08998312476661899, 0.028834595690451326, 0.04106728848250162, 0.06364016493241634, 0.05957884556283394, 0.051014890383568504, 0.02831545620856266, 0.03334179738416307, 0.04413216494985166, 0.07106308194418108, 0.04593846620991827, 0.015132007125254362, 0.01998473649784442, 0.05385444507062916, 0.07831329975517527, 0.04409909676460009, 0.034959483966832204, 0.020712338080028855, 0.014939109058750254, 0.0310783178335236, 0.049230679268798525, 0.04968627941824737, 0.01718608132984129, 0.08011064161696742, 0.026025682605142077, 0.0531225974461244, 0.07268687424760673, 0.014131547049469045, 0.023032640287232016, 0.011518858767475092, 0.009351657316719574, 0.01391133986368415, 0.010921911565556882, 0.019072599656459306, 0.035597730968748374, 0.08027983213504476, 0.02707236555344876, 0.014192036394360326, 0.07318852394218407, 0.07546662428085843, 0.06724678430586092, 0.028563779778778556, 0.015472744839386115, 0.056461794677400784, 0.05685457944749825, 2.1164915782790032, 22.900122827099217, 49.75535977271296, 55.0481354805731, 37.878720991073116, 34.29328633892921, 26.34972187780565, 33.349003176535334, 32.82724165147351, 16.71381550450479, 4.2097833175813, 0.18972043338562214, 0.3232672245752427, 0.2825264236138713, 0.6513155732424029, 5.091368373363249, 6.21834671305072, 5.888260631792008, 11.856662150352232, 12.148528656651898, 14.744847455332357, 11.66055246706932, 16.91399366624894, 32.081271563806844, 50.68722863351145, 55.21518530384187, 56.19691141190068, 51.881437378544966, 46.34978932719077, 43.47398988662228, 41.78995163209977, 39.292472639391505, 38.04859099849578, 38.10819141326412, 42.059167431246856, 45.72819171413299, 47.12877204341274, 49.489474065842174, 53.1006080873551, 54.50565991863128, 55.988629633380526, 53.51694806929558, 55.78928693648308, 55.453041753461285, 51.13643415512578, 41.48998052843156, 38.211498798862586, 45.73651498363864, 55.41381412936796, 56.57050148133309, 54.23838177034932, 55.57667093892252, 54.96924877166749, 55.748698249939956, 55.83815182408979, 56.362098109337595, 52.93910449550998, 48.86642909819081, 41.77684699335406, 38.94322872161865, 38.93520747461627, 42.731202802350445, 48.55451045497772, 56.10683025852327, 49.69461794822447, 44.834369844005955, 56.36251388057586, 48.992529376860595, 47.81769714047832, 46.1808842228305, 45.3783868974255, 42.02731778544765, 41.33455661035354, 39.9459748114309, 43.35228658491566, 46.73562503630116, 47.88265551290205, 42.305076506830034, 40.050168652688306, 38.589030850318174, 38.14619133549352, 47.81769714047832, 55.773644524235884, 55.907707214355476, 55.94208678891582, 57.395732864256836, 54.400073635962706, 51.29429778745098, 49.508156314972915, 47.16882728761243, 50.740098261064105, 54.040054967326505, 54.63849490688693, 50.705338216597035, 52.511381795329434, 52.541183963898696, 52.19611344798919, 52.82756013254966, 50.898416888329294, 49.89543153393654, 53.03639496526411, 53.958952119273526, 54.483510294268214, 53.33592284110285, 53.408584748545, 49.400946171053, 41.27616820796844, 29.086726288641657, 16.688304408904045, 17.015955678878292, 13.416023946577504, 13.061738802540688, 8.961378335952759, 13.089725894312705, 8.169598887043616, 4.145588336452361, 0.7045405430178489, 0.2581983822728357, 0.054026060256986856, 1.0420622123825936, 7.873409928814058, 25.68111073586249, 40.8271352706417, 38.163026148273104, 41.18707941424462, 53.958810913947325, 52.6923599550801, 51.57988948206748, 23.061634263684674, 7.919119269617143, 0.08373758530304318, 0.12099466271578305, 0.008081658780875226, 0.005907388253798408, 0.04269895616978888, 0.07030024223269955, 0.03629086433999962, 0.0370033146182616, 0.01751071300297495, 0.053020205964604696, 0.03483032537323814, 0.015324863056922633, 0.019414023976893197, 0.02713445697971169, 0.16906103389638086, 0.020566227875890273, 0.019902508450491775, 0.04560277797281743, 0.010352081003328486, 0.041785392489644795, 0.02284284008877172, 0.0972136771005969, 0.025244205889682618, 0.06454054806982318, 0.0997319306817747, 0.1411146213931422, 0.1957408885561651, 0.21937892982555976, 0.14960829949667379, 0.17686249027329107, 0.07368582991823074, 0.20483245231932212, 0.09526944554020321, 0.16488112028568022, 0.12452338626908681, 0.13095436497561394, 0.24353237972865183, 0.17081784204609934, 0.18456787922449652, 0.11455691179200528, 0.18456401814135814, 0.17871950272350542, 0.10276381557266559, 0.16633771389963167, 0.14811585296786603, 0.18104494729590032, 2.8026364503368257, 28.705934747572872, 58.79630534879623, 61.82796801290205, 45.91586928213797, 38.965633300042924, 30.161447871115904, 42.76727291845506, 42.49580567882907, 19.925256083088538, 5.158244294504966, 0.31498648827114417, 0.40183787624682155, 0.2250043747405852, 0.46524583992938845, 12.840882885840632, 31.651385676476266, 18.88331178695925, 28.398646462348204, 19.86226477930623, 18.33801604086353, 18.985481685207738, 17.698200979540427, 32.421858810609386, 50.72229462285196, 56.835363449588904, 59.78293834194061, 53.691764185505534, 48.06562231433008, 44.54762497255879, 43.066051621590894, 41.65143312946443, 39.49343919754028, 39.58399888007872, 44.22002861576696, 47.24438782661192, 49.56633683173887, 51.49959071989983, 56.761873922040394, 57.45517246184811, 57.820686371095725, 54.910954506166526, 55.73382069987636, 58.59534663538779, 55.475003104056086, 45.27070214671474, 39.75745785620905, 49.96920739450763, 57.1980179509809, 59.72042752850441, 55.8405170133037, 55.88249421888783, 55.350813019660215, 57.833971438869355, 56.576836109161384, 60.3505955203887, 54.10580565852504, 50.57752778453212, 43.36279069223712, 41.0197118789919, 40.83292861138621, 45.33499371620917, 51.739706454738496, 58.84188721256872, 53.14724899107411, 48.989768028259284, 58.79870191697152, 51.47959055439119, 49.72985652185256, 49.06679161133305, 46.85715575372019, 45.12588431758266, 43.613179114557084, 42.09306847664618, 44.71427471406999, 48.849837472361905, 50.28150650762743, 46.59858526722078, 44.80846258901781, 41.65100951348582, 41.20260415538665, 49.666522010680175, 58.23277842613959, 58.67826554083056, 57.43817290952129, 58.81057100911295, 57.16862763127973, 54.341167480714866, 50.83531379699708, 47.62008813119704, 52.46982820572392, 57.3008664192692, 54.47290420532227, 51.4905261224316, 51.371768520724395, 52.21108121256675, 52.17919626543599, 53.42413694627824, 49.38872014322589, 51.35079952978319, 52.64077686494397, 54.63401948252032, 55.01815288297592, 55.75008676898096, 56.008119890766764, 52.81773851763818, 43.636944755431145, 34.54453376031692, 20.810191823590188, 27.060610286651123, 16.48742610408414, 19.535052814791282, 17.961864663708596, 18.323538572557514, 11.770419036188434, 8.047803899934216, 2.779775406083753, 0.37744260302955107, 0.2233204521959828, 1.4255682787587567, 9.562240339094593, 31.54110431671143, 48.15706060778711, 45.98546781847554, 48.21253861150434, 61.976943554416785, 60.81828717262515, 61.515033475814334, 31.96678738440237, 9.731499437362919, 0.2209075969914275, 0.31306440431264143, 0.12795630286658002, 0.14438800784128328, 0.19786155782639983, 0.10902405626350835, 0.15714671192390306, 0.20311548074166622, 0.13862626056276983, 0.1623102824293798, 0.19583836558365053, 0.07406652199044343, 0.09671457081792817, 0.1422045806482915, 0.3128449967311275, 0.15644166588542924, 0.11800013993295932, 0.11498150070227924, 0.1473757047807017, 0.15476957173837771, 0.13035960495471954, 0.1626779433460005, 0.10872895919507551], [0.024090680489016157, 0.030371586401616375, 0.029076687135403196, 0.034729236241189704, 0.09410960374460106, 0.07053172335990014, 0.05149407838020594, 0.04378852855053641, 0.01994744716813007, 0.02771342218282723, 0.023999791817679524, 0.04607387225053484, 0.029095881468346043, 0.02422714947662767, 0.0619837832486918, 0.018339936148315188, 0.11665517299045479, 0.03853180941434638, 0.014222094811679376, 0.04242739715282956, 0.056507158573837056, 0.05895068793888054, 0.03489562287746418, 1.950404206591268, 15.836304810739334, 40.43736934661865, 47.892163338199744, 41.56968701270319, 21.405682140781035, 18.73366944251522, 31.918805030084428, 26.220587645807576, 13.2197642326355, 2.7087716806319455, 0.04641948132625511, 0.18343284335588256, 2.602693875951152, 20.318093222956506, 23.690252919350904, 7.794963996256552, 11.135191186781853, 6.482198180690889, 8.706575286003853, 9.237626944818805, 4.878502815000473, 16.269916949733613, 37.25509551263625, 46.96098481455157, 55.68215131759644, 49.241270403708185, 48.805463698602495, 41.74752335394583, 41.42022509728709, 41.620316966887444, 44.447200529036984, 44.01373547892417, 43.172967587747884, 35.957736276811175, 36.89284109300183, 36.11133629275907, 39.40763735002087, 46.49279109893307, 50.49944123914165, 55.214345916625, 51.80984627815985, 50.91761296795261, 53.24974052367672, 46.06858676479709, 36.266595471289854, 37.35559448119133, 51.128612949002175, 55.51835313920052, 55.03483864568896, 51.915224675209295, 54.02864871486541, 53.28442996548068, 55.87851301316292, 53.03243729376024, 52.38603068936256, 47.735970635567945, 41.64521617274131, 36.71349071687268, 40.34944549683602, 38.9430522149609, 44.52997822915354, 45.64131905955654, 52.280934702965524, 49.418769421116004, 42.80579843828755, 55.755405502934615, 44.123295122577304, 42.439480443154615, 38.01549011661161, 40.985591180862926, 38.7949788185858, 38.75510400341403, 41.29424248972247, 46.771024427106305, 48.36267125221991, 51.381950993691724, 52.399025501743445, 50.44105675912673, 44.285889133330315, 39.14348140839608, 36.604095812766786, 39.97212525336973, 47.244325068689164, 49.547164286336596, 47.270122497312485, 43.77634579135526, 42.84984273295249, 39.32933507427093, 41.77391306046517, 48.94308397846837, 52.19299908607237, 53.7353221062691, 50.39875007444813, 52.73201511752222, 51.45526793695266, 53.1426166719006, 53.83792346523654, 53.461426919506444, 53.037202973519605, 53.54064310750654, 52.31826782226563, 53.24337059451688, 53.30767393112183, 56.44796271477976, 51.62613030402891, 38.60324551982265, 24.86888004887489, 12.802702534583307, 13.085900602802155, 9.038123430744294, 9.851434730714368, 7.559316821636693, 12.09435974397967, 8.64638847689475, 3.8693848348432973, 0.7369456332056754, 0.11923829889706067, 0.020817066129717617, 0.5147762127941655, 7.376037701483696, 21.068211217080396, 32.53812570725718, 22.140879438769435, 26.304340054911954, 54.20757939738613, 47.538220420960464, 43.05921493038055, 19.653855523755475, 3.105142140580762, 0.13192818530144232, 0.002343868508168887, 0.057067513586052006, 0.010274213911484807, 0.01975523953836772, 0.04059036427568044, 0.1251788740797389, 0.04679155873975927, 0.02839744676865878, 0.02392361203448907, 0.07265675167042403, 0.024477294420883543, 0.07927847094833851, 0.03930086975977306, 0.07411293159689634, 0.02214669407675824, 0.029063684708108346, 0.06015906523492548, 0.0353571065821715, 0.05146634599734699, 0.09554224945003949, 0.014797042841241967, 0.033555198836350636, 0.032346672153160456, 0.06111057324995918, 0.05637851325915225, 0.024930029401495576, 0.029215052190627304, 0.01741500563859459, 0.08840463890303528, 0.023660751945909955, 0.044806188257831725, 0.03961637158006911, 0.027805867927869963, 0.011227595011493372, 0.059755068768056176, 0.05019684637626333, 0.028589070256378864, 0.03819979839928208, 0.11027906150106462, 0.03287921434328441, 0.010070342593075288, 0.05034818321526532, 0.06654208300695305, 0.04353658904531791, 0.08458491685169359, 2.182465844577359, 19.919162681025846, 45.96177670263475, 53.330584495298325, 46.317959293242424, 26.3399669431871, 22.536905465587495, 37.959392378407145, 31.365670427199337, 16.891969557731382, 2.4045690749922106, 0.15896758034584985, 0.19499055139960783, 1.0670763927121316, 8.640825575397862, 23.81875761093632, 13.462381459051564, 11.806869622199766, 12.743862079035852, 12.833469606214955, 18.035299278074696, 11.0384782860356, 18.022757499448716, 38.219563191936864, 50.491839685747706, 56.365824361001295, 52.67062610195529, 48.86052200871129, 43.10652655939902, 42.81751848036244, 41.9402176334012, 45.47113134014992, 45.84902817203153, 43.924580004907426, 38.586446008374615, 38.62188070051132, 39.11339290680424, 42.728060983842425, 49.64685132426601, 53.80883516803865, 57.3387094466917, 54.28293205076649, 53.04467508869787, 54.599357497307565, 48.54985852395335, 39.209596880020634, 39.0632140251898, 53.19042251956079, 57.11678958708241, 53.92119930636499, 50.86774003121161, 55.63952299856371, 54.53433244459091, 57.60495601161834, 53.80189649520382, 54.47700700452251, 48.9926274361149, 44.254918098449714, 38.75111495294879, 41.64082311814831, 40.13926921352264, 45.88644758347542, 48.799062390481275, 55.364717821921076, 52.23506258380029, 45.60300534771335, 57.69806523476878, 47.39995687238632, 45.088813997084095, 39.914285982808764, 42.386689263005415, 41.48426171272032, 40.182685928960005, 43.008533985384055, 48.67735516640448, 51.355118059342914, 52.83516168594361, 54.72097058450022, 53.31986073524722, 45.15658470892137, 40.076020994494044, 37.53068908568352, 43.457323735760106, 50.673139479852495, 51.82357457376296, 49.5197194622409, 47.00805717898954, 46.48394223182432, 42.62242763273178, 44.051998199955115, 50.72170234495594, 54.87042465517598, 54.88518453413441, 50.066427261598655, 52.71664727118708, 51.69730171080559, 53.46301547942623, 54.47944279639952, 54.76816062004336, 51.24350309371949, 51.53675125491235, 52.47794751198062, 52.993876472596206, 53.45411954387542, 58.798580323496175, 53.23442366815383, 42.704409091703354, 30.794598825516243, 17.177296492361254, 15.700085797617513, 15.079244221410445, 14.338050600021118, 13.846392285439277, 9.094132915619882, 8.585101442952311, 4.331626844021582, 1.45066446113971, 0.15861194700964037, 0.10360333302448835, 0.7614405284966193, 7.566655576229096, 26.454211858011064, 38.35893677126977, 27.115244980781313, 32.08854952166158, 60.265636982456336, 53.1303043519297, 51.91378908772623, 24.678009671549646, 5.036286529033415, 0.14160415157675743, 0.026860078759191018, 0.023152952480520454, 0.015374800498266856, 0.026983526167309573, 0.027807130057725216, 0.07704917807132006, 0.056579385343338215, 0.06635172547952783, 0.01481750888013912, 0.06879799743934024, 0.026262658497979565, 0.12661066176670213, 0.002550312206186655, 0.017370001803482735, 0.07874718897285, 0.008601629468161733, 0.059318065402969244, 0.07886168847401297, 0.017955155081806645, 0.04183082916443387, 0.014907048279119116, 0.03463583480146143, 0.08171655342824037, 0.10259979614807714, 0.1585613545631209, 0.11916406497719789, 0.18505305802870184, 0.15341715076036994, 0.18102599428065363, 0.21355923565645374, 0.17713811338668872, 0.15915988373660273, 0.1382424964779808, 0.0768379599697167, 0.2189978317267472, 0.08051680611266245, 0.21479260657102833, 0.11622212646949677, 0.2035302254221132, 0.11980993072352103, 0.11037895170551155, 0.20988536908501582, 0.1741659986756502, 0.15531271275493408, 0.1762774136037596, 3.1725625357320233, 24.639831281477406, 52.82543028554609, 60.19144927301715, 53.055814619987245, 32.7312239908403, 30.833177297346055, 43.56911913041146, 36.180432765714585, 18.240019544478386, 3.397441823636332, 0.2687894865389793, 0.5296119651006115, 5.3695315891696564, 27.05243214484184, 30.557471936748875, 13.17247417665297, 20.430302427661037, 19.89484594714257, 22.63502943900324, 19.495795772921657, 12.235559186627789, 20.263993932354836, 40.98219833066387, 52.83268667036488, 61.65929432838195, 54.7040141782453, 53.54418108540197, 46.17203927809193, 45.53183786330685, 46.62835213445848, 49.96966238944761, 49.8395848274231, 48.35951766660137, 40.28060790031187, 41.36269177159956, 40.74019985814249, 43.986675047105365, 50.6978347224574, 55.25489930183657, 59.69396329695179, 54.84278371257167, 54.07505035400391, 57.217453295184725, 50.916420567420225, 40.89378810697987, 40.99901745396276, 56.09640852097542, 59.59859086621193, 53.81041588321809, 51.083878317186915, 56.487409991602746, 54.58292276628556, 60.49152628068001, 56.52560603234076, 57.799434969502116, 54.243669125341604, 44.763571062395656, 42.3810096709959, 44.15196764853693, 42.87831129566316, 48.00067178664669, 51.851140991334, 56.676672197157345, 55.289557364679155, 49.54406953627064, 61.26052264244326, 49.761870907199004, 46.38013278284381, 41.16666739986789, 44.78699545706473, 45.60250328433129, 42.0591752759872, 45.97590900236561, 51.93105143885459, 52.58353771701936, 55.60617500735868, 57.94500981607745, 55.68843103224232, 49.40174633456815, 43.918163007305516, 40.37704721573861, 43.85288300052766, 52.479861628624704, 53.77055675752702, 51.56906766276206, 47.31959142992574, 47.871335552584746, 43.53641440791469, 46.587892886131044, 53.12744102170391, 57.85292433154199, 53.67153260015673, 50.956569948504054, 53.024168937437, 52.579089749243956, 54.473825962312766, 56.61009388585245, 57.77288836817588, 54.54666437641267, 53.32070012246409, 53.5808591688833, 53.58635048712454, 53.679569536639804, 59.22197664937666, 56.06569636252619, 41.207966035412205, 29.628650757574267, 16.748746172074352, 18.819902750753588, 15.671353455512756, 18.971900478486095, 15.472557929254348, 22.280415796464492, 20.546657577637706, 6.81381888927952, 2.801720331753454, 1.124246899158724, 0.2173879745626642, 0.8860724924072143, 9.339835086176473, 28.632405996322635, 44.5817692049088, 34.37174550948605, 38.28006575184484, 65.86992340703165, 60.15630875864337, 61.194748417023696, 31.84911039567763, 5.957171282460613, 0.4774515817482626, 0.08460589999993963, 0.11038895681380265, 0.07072069426818241, 0.09655911625633318, 0.14943698691504617, 0.17400035514466225, 0.19622717052698138, 0.17651258727475522, 0.10053667540271437, 0.19560996412990556, 0.09226923838498131, 0.1801293190088003, 0.15356088417672342, 0.11795382991793657, 0.10371112159543461, 0.18753325236180138, 0.15439242665325442, 0.23014638753187275, 0.16070234048510754, 0.1858435075489744, 0.153846696259514, 0.11034921983317023], [0.035791838496562936, 0.02623521722853184, 0.06253739668717308, 0.041196178945322195, 0.0756215732244234, 0.09577071219081841, 0.09027851294846305, 0.035022418089811845, 0.049724614457978364, 0.03440487078360973, 0.05814113601621601, 0.02389855521370567, 0.04639729158952833, 0.030403449913607012, 0.14842306954726098, 0.046475892210559505, 0.03438563814627067, 0.0299287760900634, 0.045427152316176125, 0.022629913611097202, 0.02281727573473848, 0.11056121934445635, 0.05335237402769347, 1.0757129615353, 15.520902122220686, 38.17840576171875, 50.94877619897166, 41.135194301605225, 35.77807603343841, 20.13208266227476, 30.502127293617498, 25.83460092544556, 10.313481111680309, 2.551448109649843, 0.23609921246046023, 3.97839387578349, 21.718906933261504, 17.984822296327163, 5.984430284269395, 2.8837711676474544, 6.584939274095721, 10.149963382751713, 8.793867634188745, 24.340940790791667, 16.41682638276008, 21.451036507083526, 38.37177076647359, 52.7363101128609, 51.43424403282904, 50.99216153544765, 43.15525416404971, 41.924496773750555, 40.58298733926589, 49.493059112179665, 52.46750616258191, 53.361335877449285, 49.307629062283425, 44.06479689382738, 36.505879663651996, 37.223842067103234, 35.134187590691354, 42.75229730913716, 47.47663528688493, 52.735674688892985, 53.698895054478804, 53.08199644088746, 46.205744204982636, 40.335885863150324, 35.68699859803723, 44.71054454003611, 53.60063968166229, 55.36316064096267, 52.70261303071053, 53.856315458974535, 54.57478777054818, 49.698403035440755, 49.68472573064989, 48.28129383825487, 44.83176146784137, 41.616174943985484, 38.47595284062047, 37.834617860855595, 38.5329488015944, 37.30268955230713, 44.842336177825935, 48.69605310501591, 53.73343936858639, 47.04474702958138, 38.67241651781144, 56.32059943291449, 46.02405217386062, 44.30496754184846, 37.373029416607274, 38.41190053570656, 36.78756467757687, 40.501311825167754, 42.786217966387355, 48.28595361401958, 51.367806926850356, 54.74027649048836, 49.45296856664842, 53.83535431277368, 50.500327694800596, 50.36867333996681, 42.68899025455598, 33.485321229504, 34.43098898856871, 37.54696692189863, 38.50025584620815, 36.69096454497307, 35.572845858912316, 38.20259109620125, 44.37228718111592, 53.20553148946455, 52.71516853763212, 53.685825717064645, 51.020355532246256, 52.737051440823464, 53.17372498973724, 54.61387811168548, 51.982061862945564, 53.49142520658432, 53.540348929743615, 52.401610343687, 53.90869086788547, 56.16155124479725, 54.81647637582595, 58.97807974969188, 48.85330484759424, 42.38477514636132, 31.457746105809367, 21.24006594381025, 19.778679070934174, 22.11466427772276, 14.602124171872294, 9.245602103971667, 7.71507021880919, 6.587882522613772, 3.1943434572988942, 0.6710441146166094, 0.4779125828175776, 0.04674675791794735, 0.6329615161784234, 5.066899647635799, 21.090590300098544, 32.29797663227205, 35.42949891859485, 37.445459904209265, 59.90306877320813, 46.62439446295462, 48.89616066409696, 20.84616191925541, 3.2922926400938346, 0.09954377182669218, 0.0446877395734191, 0.013799717022676863, 0.07849988813001303, 0.019251672708759868, 0.04684320455717464, 0.051300901649219376, 0.0198963203752834, 0.021558597105585282, 0.0700656890929226, 0.006529241931744882, 0.057614603785858046, 0.04677045301744535, 0.017242971019098358, 0.013421837450756181, 0.053050048919695045, 0.06234014819886896, 0.033127928618341684, 0.024447579785520514, 0.057082176508922736, 0.015912401741520775, 0.04039786936294648, 0.05235211600759818, 0.07620894049684848, 0.030152875960113543, 0.08562671215904337, 0.04450233480442436, 0.019872621445345785, 0.014760375000356186, 0.1308756264587564, 0.04367530075532775, 0.09341299233417358, 0.023695486372396834, 0.0006915962876519189, 0.018410582861472524, 0.02501663564133548, 0.04346549608594468, 0.021680698114176913, 0.07557645064568327, 0.04558240769491081, 0.06049827747647801, 0.09548234137436075, 0.02776632821487804, 0.0713356253841231, 0.021875883910744902, 0.03857745676331463, 1.6721201327539261, 19.410692107292917, 43.51233497742684, 56.58376693725587, 48.418129644086285, 38.58599101343463, 26.101406428121752, 36.72309660142468, 32.00369492653878, 13.747364205698814, 3.206921517848969, 0.16399060436073812, 3.6311001114306913, 19.523266092423473, 23.98257932355327, 12.305748039676297, 6.774212756464559, 10.165311617235984, 13.627611302560377, 16.069194559128054, 10.125534861318528, 8.574480645118221, 19.566208201069987, 38.74126980381627, 53.640385058618364, 55.58275061268961, 52.13993334001111, 46.90183547235305, 43.93689232487833, 42.0281179489628, 50.13122089447514, 53.576501415621856, 54.94902503105902, 53.10805274594215, 45.19543970784834, 37.84537692223826, 39.647839377003336, 37.42742484615695, 44.529170220898045, 50.787507949336884, 53.888086657370295, 53.98618121300974, 54.74305745094053, 50.13999131418044, 42.217807692866174, 37.88613034832863, 44.710752425655244, 56.97048517965502, 57.050368170584406, 52.51455891516901, 54.98010196993428, 57.34147864003336, 54.773679394875806, 53.04618127884404, 50.334670312943004, 48.98127217446604, 43.13395177164386, 41.16048182210615, 39.01079939257714, 39.63615071388983, 40.10332069089336, 47.85562646004462, 48.804377202064764, 55.539631997385335, 49.66363122386318, 41.57727287661645, 57.617946901629054, 48.90017324878324, 45.844670418770086, 39.10359874848397, 40.687793070270175, 37.70092779590238, 42.10840494401994, 45.23676972235403, 50.642097842308786, 52.625142297437115, 56.70630570380919, 52.42430909987419, 54.70758353510211, 53.3052695182062, 51.125459363383634, 44.43784175380584, 36.646049484129875, 37.095176558340754, 40.9197541975206, 42.078767514997914, 40.88014610352055, 37.005621002566436, 40.780980740824056, 45.00400058684811, 54.49912132755403, 54.026252146690126, 54.54092987122075, 51.53518622921359, 52.27303897180865, 55.84695362275647, 56.49130490518386, 53.51986631270378, 56.47932990904778, 55.74807067071238, 53.45768890073223, 52.99508456260928, 54.9793488748612, 55.38890315640358, 57.435439017511186, 53.12567987749654, 44.88720809259723, 31.609630084806877, 18.578498517313314, 15.653346834644196, 16.432535475300206, 18.18915032571362, 11.595973583959765, 13.768577364183242, 7.934103213971662, 5.948497941417079, 2.3523302135928987, 0.20085314649247354, 0.10852516448545842, 0.7337410567748932, 5.73767593791408, 23.22539321837887, 38.239884991799634, 38.152400447476296, 38.52752808601626, 62.610877021666504, 51.080865936894575, 55.1434608428709, 24.994537099715203, 4.046952738877266, 0.15628634921966061, 0.1139588269495195, 0.032967096119518244, 0.06415253602749398, 0.06614434547842511, 0.0600689732950301, 0.08404921454888198, 0.02801830602449275, 0.06552862529192241, 0.02513804525557545, 0.01449319609110394, 0.03572932572194165, 0.03393705919264786, 0.020260133615304387, 0.009461839912429212, 0.06285042021303408, 0.06466427893047372, 0.033181730973263907, 0.04675282533430765, 0.05043895314297369, 0.024505404102045204, 0.057598538922085885, 0.0689574356581415, 0.17146077367567247, 0.1404022668758708, 0.2763875159284761, 0.18540950341811105, 0.15904080302965257, 0.12364207106011531, 0.2085683260473513, 0.137184483089274, 0.24631979064114634, 0.13538485062458824, 0.18568114287430243, 0.11104865044715906, 0.11935659053344881, 0.18279070845775067, 0.15722457710052692, 0.16763270892683538, 0.08270679101828607, 0.16772421046851144, 0.1531513182506446, 0.1716315193522361, 0.12496734188208658, 0.1866620878178266, 0.19191657763815698, 2.258280847341784, 22.165747265661917, 51.290901014881754, 64.87806973918792, 53.162048093734256, 46.66130004390594, 30.545424376764608, 40.89141115065544, 36.88730270631852, 15.103658033955483, 4.060690840405803, 0.3579049094790413, 5.400696781373793, 27.838208406202256, 21.365570022213845, 7.2834923190455285, 3.928052951251307, 9.959068490612893, 16.668170882809548, 20.53131130433852, 34.32072724065473, 23.86552206931576, 24.516429593486173, 44.03908575734785, 56.752511224439075, 56.77330370872252, 55.22232793992566, 46.724152103547134, 47.185705246463904, 44.10769193403183, 54.157098493268414, 56.56550045936339, 57.290797695036865, 54.09572124481202, 48.02132306560394, 40.83892591537968, 41.753167644623794, 39.11469513370145, 46.23577779339206, 51.789681373103974, 55.47622688354985, 57.18817280184839, 56.58001715137113, 51.50661176250827, 44.93868135636853, 40.50763468588553, 48.657970813012895, 58.5919733970396, 57.407182262789824, 51.707115480976725, 56.58218622207642, 60.88504983532814, 55.02889233250772, 54.80278730392457, 53.99686574935914, 50.303918930792044, 45.82175985459359, 42.96928674943986, 41.380063949092744, 41.022163360349595, 40.86428011617353, 48.84971980125674, 52.30925421560965, 55.92482836015763, 52.90218322507797, 46.31409968099287, 60.65987440847582, 51.66357717206402, 48.32001547659598, 40.750088153346894, 41.61770466835269, 39.64548595489995, 44.646853093178045, 46.96594661281955, 52.66516616267543, 55.65914661653581, 58.19126798260597, 53.568515469951016, 58.38402894235427, 55.51672535557901, 55.29304435176235, 48.55516549079649, 37.7230421189339, 38.631070813825055, 42.360660414541925, 44.003615763879594, 41.824676375235285, 39.56814465984222, 45.1112852558013, 47.95986344737392, 57.92464879251296, 55.79192669160905, 54.47471634034188, 51.07789278030396, 54.22681077834099, 57.573039685526204, 60.77355646318006, 55.091716935557706, 58.91404313425864, 57.52897970138058, 53.19469790304861, 53.32923127758888, 56.36543996872441, 56.40055694887715, 59.35444685720629, 54.66750475668139, 48.06986239648635, 34.99313915929487, 27.69728941302146, 26.927173214574015, 31.539449076498713, 22.40985401215092, 16.39364125267152, 19.611176213910504, 13.66957772162653, 10.754203527204453, 1.742919159512366, 1.7330949705454612, 0.21751882238013132, 1.1847533814368711, 6.72131076935799, 27.73329677120332, 43.69589405675089, 47.58419844412035, 47.556137807907604, 68.94051951746788, 58.37616459015877, 63.00171375274659, 31.24301006717067, 7.740464133601035, 0.339495295718793, 0.18798247099884097, 0.15133303920588187, 0.4213618108582112, 0.15393422946574228, 0.15619498557381092, 0.235996694574433, 0.13928258340925942, 0.20122620066808117, 0.1647730865665982, 0.1553164206204876, 0.16653271391987803, 0.10531164014772063, 0.10967299402240785, 0.07013908797694791, 0.21535857700772826, 0.14875846284051097, 0.14962192053996748, 0.15354980654533834, 0.2852561481056675, 0.145254468605403, 0.1317804069408486, 0.16244224873521637], [0.06309731885971082, 0.024745632038121263, 0.022022652950498368, 0.02253411240094612, 0.014362341570367497, 0.004290577884192669, 0.06942673345967647, 0.038889779318724914, 0.051028224143890605, 0.051123314807491924, 0.060902936609401825, 0.05863317513778325, 0.06823143711493862, 0.04070066561501834, 0.12738092487016994, 0.01940552040093368, 0.026170139974584023, 0.035381062151563746, 0.04279854376950572, 0.0018555457509430728, 0.021476723373897617, 0.09007790516461096, 0.017366721031947002, 0.44000915702312227, 12.652301211510936, 39.63767651588687, 48.551764795857096, 42.57869320531046, 27.061722278594974, 25.34010183426642, 25.08103712912529, 26.593499145200177, 13.554553235730818, 2.087778602876971, 0.5711001614409109, 1.946873460565844, 3.576633098625368, 0.8542984748078931, 4.239942421836238, 6.977371919539667, 8.181165466385504, 15.07188585496718, 12.659963561642556, 11.734214578905414, 10.211378874317294, 17.173760475650912, 38.62539514418572, 54.42645157537153, 51.93109850729666, 49.27302983499343, 44.54780540158672, 40.00464954683858, 44.976673433857584, 50.72119243683354, 53.396723501143924, 57.680328276849565, 53.34852933883668, 48.49074840545655, 42.43053743916173, 37.48932376984627, 36.417136038503344, 38.80818543895599, 41.56709824838946, 45.192678359247026, 46.66531262859222, 44.017214621267016, 40.277748492456254, 37.96293820104292, 36.5341442631137, 45.33470738318659, 56.75195032550443, 53.489161998994895, 53.4275572530685, 53.383583561066665, 49.198622472824596, 48.42744527324554, 47.069073569390085, 41.91352590437859, 40.999123357957416, 38.32772647180865, 40.25321014465825, 37.99741583485758, 42.41367516979095, 43.10189816259569, 49.89068546602803, 46.332377925995864, 55.55498807660995, 46.548006303848766, 38.01436047400198, 57.65708038883825, 47.75428418190249, 45.654729643175685, 38.50274655126756, 38.63673079398371, 34.86026494733749, 39.363185128858014, 42.00554078625095, 48.399604289762436, 49.932109617417865, 51.5365316021827, 53.46243496864073, 52.98410192612679, 53.54946844039425, 54.65471782991963, 50.31938091401131, 45.99315566401328, 40.75699152485017, 37.90925272049443, 37.740175031846576, 35.932868449918686, 36.45168035261093, 42.336204436517534, 49.38852402471727, 52.972181843173125, 53.63355621214836, 52.214697637865626, 53.076658095082934, 53.50758144932409, 53.09665041585123, 48.43585875726516, 49.33557202739101, 49.501633413376354, 52.337432522927564, 58.17725727635046, 52.1847071955281, 53.71801268669867, 55.87264906975531, 56.256229416016616, 54.662272314871515, 49.167588680021225, 36.47463406285932, 23.386830129931052, 17.455482752092426, 14.496874232445995, 20.73401939484381, 21.434427230588852, 8.057029314579504, 4.904634625680985, 3.585001475388004, 2.2428274443072658, 0.1708959370491005, 0.028093673754483465, 0.5728222045206255, 5.205804994029384, 18.26463241730967, 30.120714056876402, 28.747468725327526, 44.23572986356674, 57.935380397304414, 50.56337195058023, 42.60124683380128, 19.301556079618393, 4.849309594400467, 0.08843823185851497, 0.07370683604911452, 0.016242676609826666, 0.09187090330787244, 0.0237748549965721, 0.02784794339189126, 0.10297737790331726, 0.06778095443282398, 0.04004060425945828, 0.04055015232053496, 0.07110114885313858, 0.021121145579062646, 0.04763573783660128, 0.031177397899990602, 0.009021193799262327, 0.02904973041656758, 0.027515191186760223, 0.037099565905068195, 0.07103920298358125, 0.05984012751028903, 0.008734675957971524, 0.07915741373454371, 0.0560105535682411, 0.04640828878168137, 0.017106699299127344, 0.07549728311958813, 0.04985037928206786, 0.10184552129958907, 0.02634961330782502, 0.05301228844590726, 0.026241623638798634, 0.09177950901850578, 0.049162282938918764, 0.04397498285998741, 0.03982906440092672, 0.07150287003887278, 0.043507182760344404, 0.0710384598782947, 0.010112197806818352, 0.035697192163957704, 0.0668106044852926, 0.03708681820200817, 0.043127000136601354, 0.041404263747315255, 0.07863029927736329, 0.10351888715259491, 0.425091770387465, 15.412863377601871, 45.520039373828524, 54.37748078377017, 48.511850756983605, 32.837314298076016, 25.30332176916061, 32.30319338460123, 28.61462196996135, 12.595035587587665, 2.037483766194313, 0.5487648986520306, 2.9785165094560195, 7.178947425657704, 2.2922233227760564, 5.7646638058847, 9.296080066311745, 12.452049505326057, 16.101819853628836, 18.69713648673027, 15.281750309851864, 13.34901809692383, 23.35005202601033, 39.21921060931298, 56.23943774930893, 54.54914331436158, 52.486725776426255, 46.963620647307366, 42.730822332443736, 46.40130573703397, 53.525749867962254, 54.98320064237041, 59.58601574743948, 54.655106144566695, 50.78798255612774, 42.96664699431389, 40.145870562522646, 37.92287118973271, 41.17442192569856, 43.79571445526616, 47.922110634465376, 49.96463783325688, 48.263827523877545, 43.110068459664625, 39.28080358812886, 38.66313618998374, 47.24550962448121, 58.158688775954715, 54.33069082998461, 53.430687304466005, 55.96039641288019, 52.02773394123201, 50.46831330945415, 48.79312392204039, 45.000082139045965, 42.34708901374571, 40.50604220359556, 39.99633804444344, 38.86959798874394, 43.022438787644916, 43.23612951463269, 51.18723669359761, 49.46131537037511, 57.02914814795218, 50.4358321620572, 40.77953338623047, 59.567200137722885, 49.678810796430035, 46.75223235161074, 40.203650997531035, 41.09506061000209, 37.403192443232385, 41.93392222927463, 44.39828072824786, 49.98017041913925, 52.615979640714585, 54.76905492044265, 52.279718768212106, 53.31766813032089, 53.541972790994954, 56.844577097123675, 53.07543431558917, 46.91281418646536, 41.02367347286594, 38.25324850697672, 38.190871054126376, 38.84094507463517, 37.21389101397607, 45.47288856198711, 50.77380318795481, 55.23116111755372, 54.35829647125737, 52.52269783327657, 53.89265229625087, 54.539757082539225, 54.50443221676735, 50.040755348820845, 51.195893364567915, 51.759012360726636, 55.390982012594904, 57.84274578094483, 52.74857536438973, 54.80692540445636, 55.48207513747677, 57.537165687930205, 55.17052519705988, 49.72835817644673, 35.11304601546257, 24.543997972242295, 14.379216855572118, 12.765599854530828, 14.320859832148399, 13.446212468608735, 11.890438660498589, 8.975055640743626, 7.185689489687643, 2.8015622112058827, 0.3760804987001804, 0.0203744990510806, 0.6798334107283623, 5.898670111933063, 22.496869833238666, 39.130753317186915, 35.58589166210544, 49.70714599855485, 62.72126036305582, 57.69718270148001, 53.582188852371715, 25.34780340809976, 6.729949299366244, 0.0584217616837592, 0.05902596756875996, 0.029949006556923834, 0.04087173304851017, 0.044167929764596686, 0.01871195802044484, 0.043542832661900795, 0.06763519854435036, 0.029261442644882108, 0.041584321222598516, 0.046147029816864, 0.02122170419522351, 0.03674798134353854, 0.07739050854598323, 0.027867855932263118, 0.03650991952106838, 0.028983228239080602, 0.08642895943334988, 0.01043268207145194, 0.040000300373761885, 0.028133916353145917, 0.06663405952314216, 0.02391475222764477, 0.16083111986517906, 0.08048882092078848, 0.11639674089007801, 0.1722006307494256, 0.19797429532533695, 0.09617530620626866, 0.19729990812559284, 0.14335838567105033, 0.1734806257750719, 0.10209279915978832, 0.11085384194889378, 0.11001437046234647, 0.19822099095871373, 0.21345987405267455, 0.15827080805695828, 0.09859660369974953, 0.14305611801964624, 0.13930029536206878, 0.11837517061541158, 0.134161239670169, 0.09346800510801616, 0.22622322062811545, 0.2128521824676183, 1.0211840488256947, 18.684565290327996, 53.1185019400812, 60.23651338392689, 54.67793433896957, 39.261348632074174, 35.50420438089679, 36.73376937066355, 35.77769948590186, 16.88381887251331, 2.577929991868235, 0.8764978642425231, 2.996735428610156, 4.3992494863848535, 1.3451138475248892, 11.705288079477127, 16.185553631474896, 15.88591887104896, 24.437635060279604, 19.62100567356233, 20.23565088548968, 16.62603089886327, 21.473095916932632, 41.877287126356556, 59.50565422734907, 57.38490712258124, 54.27792710642661, 49.288068202234086, 44.36665857991865, 50.6124133448447, 55.923663416216456, 55.877583411432084, 61.42144964587305, 56.9976907391702, 52.934691829066125, 47.39679936439761, 42.452314438358435, 39.490764141082764, 43.78055449455015, 46.13449042843234, 50.12395274254584, 51.72690776086623, 49.11029854128438, 44.043494501421534, 41.337502310352946, 40.49747574713923, 49.44037383602512, 61.3758756268409, 54.600004688386, 53.92076784564603, 58.40420169215049, 54.72232380220967, 54.17418433773903, 51.56515705970026, 46.21351049792382, 43.977959540582475, 42.09515125520768, 43.19481518960769, 42.43934316019858, 46.27184006475633, 47.41896075587119, 53.08060399947628, 51.50152444839478, 59.87530623712848, 51.71953370494228, 43.608880196848226, 62.76981146104875, 53.238110696115804, 49.66313308285129, 43.25396060943604, 43.06969942585115, 39.245835658042665, 43.60834283213462, 47.36246293590915, 52.86576794039819, 54.998258621461936, 54.72429283203618, 52.78288433628698, 54.939783926933046, 55.439740996206964, 59.825017529149214, 57.623187188179266, 50.19655973680558, 44.717381231246456, 41.577080680478005, 41.286691927140765, 41.67224914796891, 40.164125273304606, 48.030419042033536, 53.83191831650273, 56.66709769156672, 55.15667138561126, 52.19963181403376, 54.77249091671359, 56.88890772481119, 56.22302655250796, 52.3419471709959, 53.06065482477988, 55.78949482210221, 56.62145306987148, 60.97889646407097, 51.305464775331565, 56.08795973562426, 56.99627084116782, 60.013067722320564, 57.693036756207874, 54.575521253770404, 40.556915344730506, 30.20175022463645, 25.497000563529234, 21.79923119083528, 28.107859588438465, 28.20059422523745, 12.940743488650169, 12.622529441310514, 12.139387572965315, 4.067331167959398, 0.7380358682524774, 0.16786579883867697, 1.140020588232625, 6.671235340256845, 23.690947178871404, 41.58124231523083, 41.01209071374709, 54.81635870472078, 68.20895825662922, 65.57227042413527, 59.85716919745169, 31.931597840401437, 8.747662113558862, 0.3663976682770637, 0.16913614115647732, 0.09565095732649488, 0.18386683216498745, 0.11253550453411956, 0.2008557665131746, 0.1430362303771319, 0.16452358705141854, 0.09717649885363157, 0.19614970371607812, 0.17066347532935683, 0.2749378937146356, 0.13395503944446965, 0.15128027106965744, 0.0949751758467286, 0.10456225294018946, 0.1587015639750227, 0.15365583311405875, 0.24723020953036126, 0.2519650619116522, 0.13644591304323367, 0.21698470587932298, 0.19227853886062102], [0.04858594733260332, 0.1051206008020428, 0.04161943869304754, 0.04624194044980311, 0.027547612027715773, 0.023289360181098024, 0.15658051166082584, 0.04030793447107558, 0.03692589377263381, 0.032981035089300524, 0.045399228411336104, 0.05152301735154564, 0.015971593524990304, 0.039088502526283264, 0.028565629881115693, 0.04729178351079745, 0.015354219546181061, 0.03646907171294574, 0.06728948604676031, 0.07299538551559372, 0.04547728510994104, 0.027211314750715133, 0.03224727607542469, 0.1569649958682637, 9.70105988364066, 33.76211897019417, 48.294025851834206, 44.263386495651744, 28.287308023821925, 16.74178984857375, 26.792449605080392, 29.136867907739457, 13.93102232486971, 2.3757401445219597, 0.11928140666455993, 0.04413345580800407, 0.6784674453158533, 3.2503982945795986, 2.8175105683265196, 8.448058732094305, 11.628348827362062, 15.74195121565173, 21.974941607444517, 8.457602839316092, 7.2244160309914625, 24.529989227171868, 34.62963742594565, 49.760654972445586, 50.03275371366932, 47.176295480420514, 43.43859834055747, 40.64707494551136, 46.03051623990459, 52.36470476273568, 53.56828797248102, 52.58177657281199, 53.29069399064588, 50.565188007970015, 47.298132142712994, 44.831302550531205, 40.44828138043804, 38.261152082873934, 36.197918691942775, 38.360007578326815, 39.509815093009706, 38.3966778170678, 36.85172288648544, 35.55328892123315, 39.94586890743625, 48.907331574347715, 55.166112530616026, 52.11790530912338, 54.63026577426542, 50.514503140603345, 48.25316652174919, 45.25257295177829, 39.26695762142059, 37.08337806886242, 37.84583191717825, 38.98272306688371, 38.56182136843282, 41.200690038742565, 44.88636870538035, 49.141540219706876, 49.31380287293465, 47.37907809595908, 56.741101049607806, 48.35576003597629, 38.29044042095062, 55.68051176686441, 49.83383071038031, 46.30753755569459, 40.295218729203754, 40.83173228848366, 38.934470069023874, 39.697104346367624, 40.08016301739601, 44.573826405309866, 52.00769455202165, 52.59653645177042, 54.062212436429924, 53.93541397586946, 49.4508897104571, 52.32822672013314, 53.38955340846893, 53.1936506302126, 50.05118100873886, 51.83575745551817, 50.92885055849629, 46.05113613990046, 37.77780625127977, 43.822049248603086, 51.206719106243504, 52.857228940533055, 50.703035785305886, 52.69091652285669, 53.1673550605774, 52.84932144226567, 50.685667530182876, 46.928570347447554, 43.287830275873986, 48.136499543343824, 48.417521676709576, 53.691387637968994, 53.40985559648084, 52.141894525097264, 52.95930077952724, 54.39915187897221, 52.04062284961824, 50.58799659052203, 36.4559635808391, 28.443887079915694, 17.25424162803158, 12.995807682314227, 13.801553710814446, 6.217758357524873, 20.101923558019823, 8.021178851204535, 4.291092090068325, 4.353310196630416, 0.19717552609020667, 0.15651171696522545, 0.2555572941538788, 5.0602551525638955, 16.570696061657323, 38.966378550375666, 40.0687724544156, 44.01526912566155, 56.31849312013196, 47.133988795741914, 38.209059084615404, 17.260660586818574, 5.05773110735801, 0.14955373871470654, 0.07116624334406468, 0.08761680940346372, 0.08277387733781531, 0.030634237731236125, 0.03716361468597766, 0.04358606300346794, 0.026508942359097065, 0.015044948893539129, 0.020922416625844858, 0.01700226044763, 0.02319123963975618, 0.015807617192847595, 0.04913060137281015, 0.058253406201519316, 0.0830775928953963, 0.0521694423420535, 0.05309564647294822, 0.08786188093044105, 0.03344234259378526, 0.03443059601610707, 0.03711905901230151, 0.034623699968740825, 0.06749868933712283, 0.03017179258618384, 0.02483083825227955, 0.02631928771734238, 0.02851315094308267, 0.025974046363825762, 0.12074795176064777, 0.06095870397984982, 0.02631723460170531, 0.031793504960895065, 0.03401395143760789, 0.034142937661418994, 0.047934833883998856, 0.08110942874824809, 0.04064922664134253, 0.10914057823679141, 0.0704054337655825, 0.04124089166702282, 0.03673887255811884, 0.02548052486212504, 0.01168205464754494, 0.05551470315925056, 0.051835654003004876, 0.40415274880586133, 12.6996854043776, 41.087176645955736, 52.73513732417938, 49.199999224755075, 33.351458580263206, 21.652001104047223, 26.47141537358684, 32.03081223272508, 16.00923230571132, 2.7255471675626697, 0.12317494894828528, 0.09915885094913746, 0.578516811853455, 2.9747206357217606, 7.438878974606914, 11.901602706601544, 10.682752651553, 10.714761153344186, 16.40951116238871, 9.68445158773853, 9.370101075018606, 25.599160655852288, 39.113502733169064, 51.23967878280148, 53.30422224537019, 50.202972812037316, 47.36868381500245, 42.779138088226325, 49.31611707133632, 54.72026455786921, 56.71595865680326, 53.60023567753454, 56.18781543547108, 51.618171814949285, 48.30284333998158, 46.407718812265706, 40.675178727796, 39.20372901424285, 37.93702310131442, 40.688950169471006, 41.557629646793494, 41.40874824216289, 40.95795023825861, 36.85628460299584, 40.911587822821836, 51.50134009699668, 55.93124143538937, 51.700059137036725, 54.53102588653565, 53.209030243658255, 50.59726515123921, 47.179021527690274, 42.185412837613015, 39.63728035649946, 38.79320982963809, 39.30754238559354, 40.39068529682775, 42.6184856507086, 47.0165922564845, 50.646718394371774, 52.16038065571939, 49.39561174761865, 57.90470746255691, 49.5022923715653, 41.99548382912913, 57.76651843901604, 52.937688519877774, 49.39804361712549, 41.74970419176164, 41.87499253980575, 40.84045171737671, 41.97813910822715, 42.476723347940755, 47.24729430290961, 52.972272057687086, 54.20833641482938, 56.68087305561189, 54.15945583774198, 50.802107011118245, 54.383866402410696, 55.588587099506015, 55.65922506393925, 52.91221664797876, 52.139752910983184, 52.27659263918477, 46.81526091790969, 38.834347648005334, 47.545225774088216, 54.92877775622953, 54.05546988210371, 50.580806885996175, 53.19535686123756, 55.02961012624926, 54.60036162407168, 52.57415932993735, 50.435581130366174, 45.381014885440955, 50.406818389892585, 51.44995312536917, 56.56787741568781, 54.58924170463316, 53.05325331226472, 52.015080375056115, 55.351028750019694, 52.87660937155447, 51.58928355863018, 35.63879659098964, 27.621405278482747, 13.511851372257357, 10.028490520292713, 15.037972061864792, 13.273849794941565, 11.254659718082799, 10.673059494264665, 9.619134318444038, 3.402580373710202, 0.5636084956988212, 0.11468670240813687, 0.48805659817111113, 5.483237178094926, 19.595855436017438, 39.224815676289225, 42.55698680877686, 46.73943365773847, 64.8192616431944, 51.610362375936205, 47.66754096554172, 20.74787908984769, 6.271534052587325, 0.05200738410255121, 0.04716002787914007, 0.11231328540992354, 0.029094062009525877, 0.11146749369800092, 0.04544681396275278, 0.05250375162089064, 0.046955880769077814, 0.011242496379230534, 0.015549707947479141, 0.05603269350925281, 0.03725201740200001, 0.028790271758372267, 0.0830658334457586, 0.015633936441924064, 0.04766965254900917, 0.06422585064184762, 0.05490801514937513, 0.0641643146293298, 0.027657225803141634, 0.00592836421997016, 0.04761162904962417, 0.019047182774351492, 0.1639596390868387, 0.18164563683732865, 0.17402338374766613, 0.09090878880552708, 0.10602319027267157, 0.12797422166312897, 0.31515346479512035, 0.1498514404820819, 0.14422705276839196, 0.09708053101935694, 0.14866040358620305, 0.2447275688210803, 0.13633297636143624, 0.13680594372412852, 0.15890235561997662, 0.20750709508936252, 0.1011395329729684, 0.13142209229690413, 0.14694763017037224, 0.28000433959307214, 0.15725506739991327, 0.14920587351004924, 0.10720853513527302, 0.6141471322025023, 15.410658024972486, 46.73705277904388, 61.218337551240005, 56.67346762072656, 42.101744759467344, 29.57646166124652, 38.20456012602776, 38.95771403466502, 18.18150758743286, 3.394864090988713, 0.2884735948135776, 0.1469253063682587, 1.3359157668967403, 7.809308594272983, 9.485720780587966, 16.5839889741713, 18.551545950674242, 21.50675181419619, 29.470073253877704, 14.500396520860734, 12.034541637666765, 28.75225990049301, 38.17472657849712, 54.31218900988179, 54.46269035339356, 52.67044959529754, 49.40116582378265, 44.71367459143362, 51.03391124356178, 58.452697876961004, 57.52100944519044, 54.087762755732385, 56.15094907822148, 54.87806935464182, 51.89700918812906, 49.725996909603, 43.94147365323959, 42.6859268834514, 39.88571936084379, 42.68331066254647, 43.45165198849094, 43.16981792449952, 42.51073029733474, 39.378725559480735, 44.03487313178278, 54.384705789627574, 57.38200456865373, 51.134598485885135, 57.54544973373414, 56.97662761134487, 53.521345046258745, 48.634668011819166, 43.11847017657372, 40.01589498212261, 41.63503369977398, 43.370254962675034, 42.50452118535196, 45.53965514706027, 49.02582245488321, 53.01842266513456, 54.45841496990573, 53.292910129793235, 59.529478703775716, 51.06845555766937, 45.330188812748084, 58.27793275156329, 54.82899658141598, 52.52523952914823, 43.57644219552317, 43.982736987452355, 44.21716528554117, 44.31937832986155, 43.52158392629316, 49.87709837575113, 57.10675224181145, 57.941456148701334, 57.58865856355237, 54.78627412549911, 51.16456539400163, 55.05144988336871, 57.02219378563666, 57.7948183398093, 55.66846616806523, 55.83315080212009, 55.5073901145689, 49.926029943650775, 42.13100564095282, 49.538040853315785, 57.447849396736395, 54.24492428379675, 52.186280065967196, 53.48077204919631, 57.401600730034616, 55.934559760555146, 54.778441152264996, 51.89095697095318, 48.09600107131466, 52.17427369086973, 53.139678816641535, 57.90686084378151, 57.09254149467715, 53.019234595760224, 54.25305927953413, 55.62414338511806, 55.2754956676114, 53.94167015629431, 40.14604314681023, 33.43495407412129, 22.881424888487786, 20.638578322625932, 27.233941785750854, 12.511334169295527, 29.294141223353726, 17.356642946120232, 13.370031214529469, 10.79220933298911, 0.9732235739788703, 0.37436725030983653, 0.6230656826688398, 6.88278494342681, 22.55122015553136, 49.97829944856706, 52.71648645401002, 53.76224525513188, 68.79830221976005, 60.544827368951616, 55.84683202928113, 27.74796251327761, 8.354938722425892, 0.30632034845409856, 0.17249263282264435, 0.1522998728098408, 0.18663827780513995, 0.244934443204153, 0.10897426820930936, 0.21293062987106465, 0.15516099670240957, 0.10830980184818469, 0.12735381301852966, 0.10339000818109322, 0.0962671448266314, 0.15340618038129422, 0.20059345800790096, 0.13175167864368809, 0.1938664552665526, 0.15959863761259666, 0.17297957362907548, 0.15937630357521196, 0.13977660286811092, 0.2719828167990331, 0.08128539148357608, 0.19697531667207518], [0.03909244021821407, 0.05504788365215064, 0.040411727893496716, 0.06987211399621542, 0.023068221240875222, 0.06985362829460252, 0.05638432403605792, 0.025102358964842655, 0.10535200532045096, 0.057864700849618644, 0.039814727065423806, 0.005688024722340127, 0.027565603602617502, 0.015662665696694486, 0.0034209991422211455, 0.020791415590792898, 0.04693413919378673, 0.05790529967916589, 0.04285886936310319, 0.04069632189648767, 0.030435445575764587, 0.018000360014998627, 0.014805565569399586, 0.09900268392577287, 3.8670233228514275, 29.81194703809677, 49.61588813412575, 49.42547667411066, 29.793500131176366, 24.107442094433694, 37.97494457614037, 28.107600712007095, 13.4422714671781, 2.0458765351964585, 0.2354314442603819, 0.06511266253167583, 1.2222985538744158, 1.540582591006833, 3.560987989748678, 7.153637351528292, 11.692775718627438, 10.9598651624495, 22.92119968322016, 15.371719675679362, 14.843011633042368, 31.26615009000225, 37.95417170370779, 52.34597936753304, 50.77552118609029, 49.21394325071766, 44.47034643542382, 42.435095233301965, 45.752267222250666, 52.608150589850645, 54.560471119419226, 51.78946172037433, 53.194894021557225, 52.3456028199965, 50.26244378858998, 49.34768038411295, 50.18539667129517, 46.864761229484316, 42.95661357141311, 39.406558698223485, 39.59670343706685, 38.19255767330047, 37.359975768673806, 38.466480316654334, 42.04701985082319, 49.3431108228622, 54.041357194223714, 53.00310188724149, 53.993323849093535, 48.48894019280711, 46.80634144813784, 42.340354304159845, 38.724740935910134, 37.30457228998984, 36.88936979539933, 38.5532941356782, 39.76744028829759, 46.071622679310465, 51.49282070898241, 51.85580468946888, 54.06733505187496, 51.681690677519775, 55.77475455499465, 46.91253177581295, 37.948892193455855, 56.825965450656035, 48.468084950600904, 46.64906617133848, 38.59301990078342, 38.972089521346554, 37.22975307895292, 38.91939640045166, 36.56618610505135, 39.66332881681381, 45.864874547527684, 51.76754351585142, 51.15404559719948, 52.38603461173273, 54.828306244265654, 51.97406807253438, 50.125337339216664, 51.70732336659586, 51.546070806441776, 53.36412860501198, 54.84831817688481, 52.753678367983916, 39.892693335010165, 46.61527887467415, 53.933582228998986, 51.787378941812825, 49.57330688353508, 55.73032586805282, 52.260554067550174, 49.45862070206673, 44.09144155440792, 41.706318855285645, 40.41715737312071, 43.720844253416985, 47.92174977640952, 51.4775352324209, 55.40955443536082, 56.8930575924535, 55.506558572092366, 56.591137070809644, 57.1328007021258, 54.26017053665654, 43.627048615486395, 30.91108145252351, 15.477757030917754, 7.991688511063976, 9.328705360812526, 13.599059389483545, 9.890074979874397, 6.568915411349266, 7.651113031371948, 2.206383477295599, 0.38952212420202076, 0.10242897386272108, 0.41723382268701836, 4.114537383279493, 23.519804362327825, 39.0215309973686, 35.27110968866656, 41.35545107626146, 51.10197221079181, 48.14641529513944, 41.027509550894464, 20.19732148416581, 4.839100155138201, 0.347165429303723, 0.06406325231035871, 0.03833513549198547, 0.053108443971723325, 0.028395656038135774, 0.045535124748224215, 0.022266176979868643, 0.07997430860996246, 0.10301692336196862, 0.041520609520375736, 0.07874087640835394, 0.060460915368410854, 0.051211330649112506, 0.04404329875063512, 0.011710928501411071, 0.015151797091558337, 0.06985871511841975, 0.046502724440107425, 0.03650417386163627, 0.0366056383767676, 0.03875446520865925, 0.06691833176920492, 0.05277237269066034, 0.03757470895746543, 0.025444491916606506, 0.03208650103319557, 0.035317637732312564, 0.04136254259895894, 0.02874698970587023, 0.11344750922533775, 0.011151680486246703, 0.07672454065252697, 0.026414085352312655, 0.013700527788680649, 0.09702462192264297, 0.04332920521377556, 0.012236100925703444, 0.020087254383871635, 0.0783988181501627, 0.04178614708625021, 0.015233141264968343, 0.04831575961302846, 0.12162072508926354, 0.02696540627268053, 0.0707613735369617, 0.06982773452276184, 0.08611007533486813, 6.051944080860385, 36.420752463802216, 55.50654680498185, 53.7958638898788, 35.36860412166965, 26.414307625063007, 36.69907992885959, 33.340636760957786, 15.532057342990754, 2.454228978003225, 0.22004344981283913, 0.03594543146450193, 1.320424365901178, 4.266257113026035, 7.243753315940981, 11.230084107768151, 14.52128412262086, 14.301020483816824, 12.201443391461527, 13.993738082147415, 12.30857999094071, 24.202208518981937, 40.270994171019524, 52.33963689496441, 51.95973180955457, 51.79414895273025, 46.33053441201487, 45.960611758693574, 48.42733936925089, 54.40052078616235, 55.70685048257151, 51.89667186429424, 52.97800656287901, 53.57197107807283, 52.507620242334184, 51.27414857187579, 51.46403835665796, 48.507269428622344, 43.106071564459036, 40.88159345811413, 40.435757252477835, 40.30884896555255, 39.826032653931655, 39.53460839486892, 43.193006976958245, 51.718007902945246, 53.615921235853634, 52.90335601375949, 55.0947214711097, 51.48763925798478, 47.73992438470164, 44.70448840049006, 40.043716353754846, 38.67860601794335, 39.02972875102874, 39.387299860677416, 40.11032996639129, 48.19838669992263, 52.223154267957135, 53.16403673541162, 55.64864643158452, 54.27600906741235, 55.46023538035732, 47.08833240693616, 40.78854307051628, 57.70474503117224, 51.29689831887522, 48.41476425047844, 41.28116530756797, 42.124419981433505, 39.78382402850736, 40.586121313033566, 39.99753828971617, 42.81886777570171, 49.176590519566695, 52.75144261698569, 52.85863314905475, 55.24803123166485, 55.245787635926284, 52.48304267083445, 51.25748242101362, 53.943568583457704, 52.967490688447036, 55.850562203315, 56.78182701910696, 54.66622606400521, 41.67195889257616, 49.83788251876832, 54.14877522376276, 52.33699713983844, 50.65948963165284, 56.082068335625436, 53.94291354763893, 51.11406880040323, 46.750769307536466, 44.7542279766452, 42.030130124861195, 45.10916717590825, 49.41221514055806, 52.93555082813386, 57.060923268718106, 57.83114340997512, 53.8949429604315, 58.41442731118972, 56.81798734972554, 54.31653891840289, 42.639846878667036, 30.841110291019564, 16.099884163948797, 10.003442264372303, 10.608786556028551, 16.066082158396323, 10.138046241575672, 11.809381900295136, 5.265703999227093, 2.259454861763985, 0.9748538090817391, 0.140503712238804, 0.5296961734852483, 4.713274442380475, 22.805009272790727, 40.19420985252627, 39.86889239280455, 45.66923456807291, 57.778273782422474, 55.15640074206937, 48.40820604755033, 26.6545194579709, 6.375469998005898, 0.3547095873903844, 0.04450304726619394, 0.028672315285450993, 0.05484650978037427, 0.03122628388565875, 0.025595562540054805, 0.02409022083626159, 0.04963531541908461, 0.03774488006808585, 0.020719010705849337, 0.04933229700151471, 0.05261254759745733, 0.059145768398358944, 0.028654204966921, 0.04971762007522968, 0.06083884569365652, 0.044319243620960944, 0.030519627147324146, 0.07589173413092092, 0.047545044517685334, 0.028830307513295166, 0.06463393418779297, 0.07066686893062246, 0.14837111346423626, 0.1341607800174144, 0.14982286540250625, 0.21980217808196623, 0.15122860610004396, 0.20530518985563712, 0.12432061811728824, 0.1636108545766723, 0.1815096255872519, 0.18030343547223077, 0.11332433760887194, 0.15438940826683276, 0.09573422342298493, 0.17489113153949862, 0.15134117505963773, 0.18713275691674602, 0.2676858296317439, 0.20969688081212584, 0.11051282557027955, 0.2757209887908351, 0.15862759052505418, 0.1252641703092283, 0.08979307367436348, 0.27877679094672203, 9.022633010341275, 42.059492987971154, 61.63199463198262, 60.414498775236076, 41.354745049630445, 34.1722184611905, 48.17192639074018, 37.81021287364345, 17.15819258843699, 3.260520706253667, 0.45096902537249756, 0.4973131159861242, 2.1586612251497086, 4.69543501254051, 10.503890610510304, 15.62441445166065, 20.621035522030247, 25.247908484551218, 35.07933716620169, 27.209648586088612, 22.125462562807147, 35.801398446483, 43.06447482878163, 54.713047396752145, 54.40265063316592, 53.36929436652891, 49.034228094162486, 47.34338060502083, 49.083010611995576, 57.201265673483576, 57.930704932059015, 51.864359378814704, 54.18508852681806, 55.90423983912314, 54.432472413586034, 53.519274034807765, 54.12211095133136, 51.34865007092876, 47.24165785697199, 43.974911858958585, 44.041215604351414, 41.8851593232924, 41.388316615935295, 41.50634465679046, 46.539326098657426, 53.500572173826164, 55.9707240135439, 52.65152023684595, 56.228455112826445, 53.61024164384412, 49.94959946601622, 46.970908411087535, 41.253998971754505, 40.00873273418796, 41.30714708758939, 41.83176017576649, 42.96438770909464, 50.91411421375891, 56.1877840565097, 57.338811428316184, 58.17299365997315, 57.11744070053101, 56.75777504521032, 49.42604934015582, 45.09891410027781, 60.41968807097405, 54.23990364997618, 51.166463821165024, 43.12961755260345, 42.7347094012845, 42.710857468266646, 42.23025337342293, 41.149008889352125, 44.12392662417504, 50.89565946209816, 55.48066308421474, 55.411307734827844, 58.44039340173045, 57.03220367431641, 52.76547685746224, 51.399829156937145, 53.52114500537996, 53.74852872663929, 56.237284368084325, 58.00358649223082, 58.00143703337639, 43.773188283366544, 53.52317679312922, 57.651765577254764, 52.760973976504424, 51.142141203726496, 57.91347395989203, 56.54271933340258, 53.3697925075408, 47.64742705129808, 46.42065871146418, 44.185390164775235, 47.254378103440814, 52.742789868385564, 56.2397672284034, 59.325378171859256, 61.56586739324755, 57.00279766513456, 59.662941271258944, 59.3663473283091, 58.08610139354583, 46.99487017047021, 35.88188548241892, 21.89281698196165, 15.048963523680165, 17.791449446831983, 26.071845485318093, 24.691877211293868, 20.124459535844867, 18.26667597216945, 4.1380823908313635, 1.8035411065624607, 0.2426035594074957, 0.6469966146734454, 5.797899519243549, 28.789998985105946, 48.23337031948952, 48.00786149117255, 51.14973099000993, 61.47153831297352, 61.80346496643559, 56.41910191505187, 33.52410170339769, 7.998518828422793, 0.5020036884853917, 0.21448335219775477, 0.15147309540019882, 0.16706692235123727, 0.10939848173650042, 0.1306018879216525, 0.07255265564327279, 0.17904041695498651, 0.23260744498862376, 0.11243522362483126, 0.23282211814676565, 0.3063010430384067, 0.3964033097990098, 0.20131100660129903, 0.10025264830478739, 0.1719261567679144, 0.17819427284261874, 0.17215871041820896, 0.27543094790270256, 0.10696298863378265, 0.08737285636485585, 0.1060175212220319, 0.22333741338262636], [0.062489309348165996, 0.027257301093589877, 0.02038157961872076, 0.05530506319877121, 0.037349548055640155, 0.03010351308471253, 0.01692933079245831, 0.08105567235860132, 0.045771190911651626, 0.0612990347097718, 0.05214663207410805, 0.029780725768256574, 0.0016847215503672018, 0.05823187146996779, 0.06426384860289193, 0.04272461628481265, 0.025893760349361167, 0.07360044175819044, 0.011009482118571478, 0.04592717407391437, 0.02098005516604791, 0.07685835323026104, 0.037683022298639825, 0.14955619019606423, 5.209355719627873, 28.469910044823926, 47.636879797904726, 54.36086170135006, 38.84433792483422, 22.75648759257409, 23.79199920162078, 29.875193295940278, 15.179048930445026, 2.950119039704723, 0.10338502094870615, 0.08870100767742242, 0.46045337773619166, 4.026473063615061, 10.215419896187322, 11.211536199815813, 8.568507855938327, 6.68409041820034, 5.094369476841343, 5.693096239720622, 8.233936544387571, 22.53737811119326, 37.87828953035417, 50.83987551350748, 52.113578934823316, 50.01842529542985, 44.95693214478032, 44.8505300091159, 48.729444242292836, 52.89325198819561, 54.66406483804026, 52.817114860780784, 52.53286853913338, 51.81300378614857, 52.372961351948405, 51.73610179655014, 54.08548778103244, 51.38171172911122, 52.48309366164669, 51.555649234402566, 49.45873445080173, 48.34279660255679, 46.20014306037657, 50.72209850434334, 49.523171147992535, 53.56915481628911, 53.3735187592045, 52.56676566216254, 53.2964284958378, 49.93691452087895, 45.661272156623106, 39.522707923766106, 36.729446918733665, 35.32850573139806, 36.24041757275982, 35.823046007464015, 38.906515336805775, 46.723010693826986, 52.183271608045025, 53.98784037559263, 54.93370817553613, 51.90987848466443, 53.40509776146182, 48.53255694912326, 35.98815817986765, 55.70613661120015, 51.103156766583844, 46.20351237635459, 39.12505803569671, 41.97810772926577, 36.749435317131784, 37.44193369342435, 36.28859996795654, 36.9390623031124, 39.46930485387003, 48.111592492749615, 49.17084032489408, 49.774512706264375, 51.646522706554784, 56.183759704712905, 54.8403283088438, 51.329461836045795, 51.110589658060384, 53.527495322688935, 55.063444491355654, 49.56325777115361, 41.44634023789437, 46.836202452259684, 52.13451654680314, 52.64575827506281, 53.168418022894095, 50.03796262125815, 45.5075034787578, 42.52157172849102, 39.66015954171458, 40.279046796983295, 38.84610691378194, 39.97304308799006, 44.94535330803164, 50.32248350881761, 51.670978684579175, 54.095301551203576, 56.67567983750374, 61.20665281049667, 59.195167249248875, 60.790355974628085, 43.95339765856343, 32.06892394250439, 17.34150848081035, 11.044398123218167, 12.50368848923714, 15.650281502354531, 6.234530902677967, 8.990705897731166, 7.139755102895922, 1.619230770776349, 0.991297304149597, 0.03295815970388151, 0.40147119592274394, 3.481944876332437, 16.576091281829342, 33.382821852161044, 39.239046035274384, 48.50061316643992, 54.01549308530746, 41.151840840616536, 48.07576164122551, 21.577815355793124, 4.824623177128454, 0.35419434729603033, 0.031972765704737074, 0.06840061231125748, 0.08001296540662166, 0.05347682501099283, 0.096771169393774, 0.02167718943148371, 0.034326737476212364, 0.017430591697414077, 0.05231318724972587, 0.03188378842277152, 0.0796963336066373, 0.015390854828330058, 0.1351630068834751, 0.018699114556394277, 0.05914866421071272, 0.02750562466380577, 0.042148315152453805, 0.021305135000617276, 0.0736800612761609, 0.06851973898348308, 0.012126154859640427, 0.032073489029801665, 0.03041738313772986, 0.051640217312641686, 0.010760964153544798, 0.029444876652691635, 0.026580560088698423, 0.0653707881968829, 0.08776952137028979, 0.027936976215231325, 0.03254777023328408, 0.015082466134410954, 0.018993935833174377, 0.028283292007061745, 0.027739193380600023, 0.04684127401560546, 0.03336426291254259, 0.014635464364302256, 0.043102887519184625, 0.014627315104007723, 0.08428557565616024, 0.019644403852702632, 0.011700885088723755, 0.02836158810814302, 0.022990492044857914, 0.17108588088904658, 6.37329210196772, 34.92849065411475, 54.16266433654293, 58.38653925926455, 42.28898302201302, 26.549078302998698, 30.45379584835422, 32.273928580745576, 16.778420863613007, 3.2574818499626654, 0.1719696705620135, 0.108791510274093, 1.0184822712213764, 2.8826160296317074, 6.472325084670898, 8.918227361094567, 15.321449598958417, 11.985702245466172, 10.159388838275786, 13.210963414561364, 12.844844479714672, 20.30048962562315, 40.84574691710934, 52.322900141439135, 54.020070491298554, 51.143906270304036, 47.62473221748106, 47.37942718690442, 51.10643979041807, 53.6095630738043, 55.38341576053251, 52.500536441802986, 53.083090782165534, 52.895503428674516, 54.41098174741192, 53.74404153516216, 56.80002289433634, 52.48327409067462, 53.80402634220739, 51.4910517200347, 50.25234368539626, 49.7485387709833, 49.523669289004424, 52.69834156959288, 51.33155638171781, 54.411625016120176, 53.85349135245047, 51.779530279098026, 55.8476008138349, 52.263993986191295, 48.45754161957772, 41.638281422276656, 38.86640910179385, 37.007586110022764, 37.76641961066954, 36.778943307938114, 40.679446266543486, 49.014902576323486, 53.337228990370235, 55.21051768333682, 55.98375412725634, 54.32138696793587, 52.87617006609517, 49.16611779120661, 39.017530179792836, 57.52064466476441, 54.04929214908231, 47.85462625565068, 41.98024149863951, 43.40035130900722, 38.49489004381242, 40.87193266037972, 37.5467864928707, 39.69426455036287, 41.615888610962905, 49.02199422159503, 51.576810421482215, 53.10893135686075, 54.71050962325066, 56.30758893105292, 54.62845756161598, 52.54601632395099, 51.282126672806285, 52.930318386324, 56.560734779604026, 52.33633033690914, 42.91335375078263, 48.700595209675456, 54.22319043067194, 53.300488148966146, 54.91150363799065, 53.609696434390166, 48.3180425243993, 46.264485620683246, 41.76901009774978, 41.39898154043382, 40.43888338150517, 41.72513054263207, 46.83368036823888, 52.33832682332685, 55.35256239675707, 55.97957288065265, 58.39085778882427, 60.615371196500725, 59.863260638329294, 57.898474816353094, 46.54090681383687, 34.64338533339962, 17.224745404335764, 12.889321215691107, 12.275786034522518, 13.960578364710654, 8.048750171738288, 9.758222545346907, 6.781240663220806, 3.7197437161399476, 0.9886114611741036, 0.03280893343711092, 0.32736502888221897, 4.298427412586828, 19.030526184266616, 36.93516346716112, 45.605382304037775, 50.770461328568004, 57.456568825629454, 47.819136650331565, 54.19383148993216, 26.007822598180464, 5.588002704804944, 0.44738667566449414, 0.0351400662123436, 0.018834928538830533, 0.06261025930965139, 0.050547844880530914, 0.16326047660362336, 0.022649366498714494, 0.044049684093484, 0.017589309793566505, 0.04095222973715394, 0.008554217244137921, 0.06147387512629071, 0.02083430502323374, 0.07759378997669106, 0.014667988627127584, 0.0494573263811969, 0.03534160096258406, 0.044120849831210035, 0.043063583378229416, 0.06934512211310287, 0.03540612854844621, 0.0247972184837225, 0.017873484363418915, 0.1797014282595727, 0.11200366331444633, 0.13824248115622229, 0.15451834086448918, 0.17192650916835955, 0.18050085633031784, 0.1949667567086797, 0.21122856636441525, 0.15290359605944928, 0.1403910513486593, 0.14629875369850667, 0.1413598614594629, 0.17688268435097512, 0.14905179790671796, 0.17736280697488016, 0.1318821893824685, 0.12393074831174267, 0.20441280467615974, 0.22941074394170316, 0.20105280432729952, 0.11057716163416063, 0.19988631288851463, 0.10053802371746111, 0.28985310466058795, 9.100597962256401, 41.479507800071474, 61.63486580694876, 65.79936389000186, 49.60492510949412, 34.70818681101645, 35.04172555861935, 40.56949046350295, 19.359344359367125, 3.9158629602001565, 0.39181821228515723, 0.2973685497718473, 1.1238921698062652, 8.59517801192499, 18.658038300852624, 19.83322551173549, 18.011937641328384, 15.025068444590415, 15.474959400392349, 11.388887147749625, 12.584477547676334, 26.46065435101909, 42.47188314314812, 55.19320826376639, 56.847879732808764, 54.77846468648603, 51.51842986383746, 50.657359784649266, 53.682417177384906, 57.75962291225311, 56.919294326536125, 54.41739874501383, 53.52729920418032, 51.9283018573638, 56.16918417715258, 56.81932880032448, 58.18635325278006, 55.31637853191745, 57.38005122830791, 55.5042875197626, 53.373153978778475, 53.37936309076125, 52.35476547671903, 56.085347437089496, 55.59789096155475, 57.0535139114626, 53.78529310226441, 52.29290577673143, 57.251346495843705, 55.71675054488644, 50.861170061172984, 43.265990518754535, 40.73989783563922, 39.433497536566954, 39.82336936458465, 37.878058110514, 42.58344319558913, 51.291187347904334, 56.03709443922966, 57.600296235853634, 57.95930293298537, 54.69078402365408, 53.90652571955035, 49.96720698571975, 42.35970727859005, 61.274498047367224, 57.20521157787692, 51.19913716470042, 44.12383248729091, 46.271137960495494, 40.49491836178688, 41.71846251333914, 39.84402848828224, 41.0167504895118, 43.893773709574056, 52.4867336211666, 54.77502476784491, 56.15318875158987, 56.44279695326283, 58.73758354494649, 57.451822757720954, 52.79482010872134, 51.45327145053495, 53.706343635436035, 58.25117041987758, 54.544267808237386, 46.42964093915878, 51.45722912203882, 57.476643516171364, 55.04680187471452, 56.08229583309543, 54.99804681347263, 49.07709567777572, 48.60104937707224, 43.91686078040831, 43.557642275287265, 42.44966683849212, 43.638188146775775, 48.51753034899312, 55.1001343419475, 58.28226304823353, 59.579163366748446, 61.08946807922856, 63.94967217599193, 60.892812205899155, 61.33794238490444, 47.23408768253942, 37.50385222896453, 22.507140559534875, 17.118651174729873, 20.03432543047013, 27.335370356036773, 17.527862248882172, 21.078854568542976, 12.019544455312914, 7.3692338601235425, 2.13368185585545, 0.15174660411092544, 0.823815897587807, 4.647943444790379, 22.877131854334188, 43.638705899638516, 52.26488436422041, 57.90997520569832, 64.33441746619441, 54.73382811392508, 61.90473271954445, 33.38433196467738, 9.078538552407297, 0.5411067773257533, 0.20785397970147673, 0.15083612393467657, 0.15985055796561704, 0.17781286830863646, 0.20197756438245698, 0.08068384392367256, 0.24802482656894193, 0.10410240100276086, 0.15285782996685277, 0.12894830245885158, 0.2253832205409004, 0.06404475511742697, 0.2522385706223788, 0.0997803780821062, 0.15028112387705236, 0.06892234883120946, 0.1214056459045218, 0.15148041920075495, 0.16502359731783792, 0.20509975571786204, 0.11697231040846919, 0.15564940839765534], [0.023292698409228076, 0.06470779272457285, 0.01527456746947381, 0.031003488280299692, 0.05089932985063042, 0.01788154935404178, 0.029878972714105924, 0.03615195344712946, 0.06427135243411027, 0.06194112747306786, 0.041059914886230425, 0.02853159450985972, 0.017627614189780528, 0.040712283338390054, 0.0559186689826029, 0.04288035046850001, 0.047344517173065294, 0.02399691515752385, 0.008071086767520155, 0.06969618956528364, 0.02884856530375058, 0.03357166972672267, 0.10247791155932412, 0.04340512452707176, 2.197020289398009, 25.11025486453887, 47.78358036471952, 50.00418316933417, 32.61309789073083, 23.511979233834055, 24.887197517579605, 29.553496183887606, 14.482778214639234, 3.397575919666598, 0.21675849543704143, 0.10946460278524507, 1.7877018403622413, 3.6599917998237, 2.810426277499045, 7.390936824583239, 23.155631903679144, 14.379642432735814, 7.782921339234999, 19.863894524112826, 12.785926557356312, 16.336343269194327, 37.81919117896788, 51.733144329440215, 51.04993804808586, 50.06927097997358, 45.40058751260081, 44.374028713472434, 47.08049551133187, 52.07313537597657, 54.57552517614057, 51.10167803302888, 51.21943150797198, 51.78667683755198, 50.80211093348842, 49.69541026699928, 54.62209547719648, 52.665734906350416, 52.47197766457835, 50.86269586317001, 53.39203234641783, 50.16998175651797, 54.32476020628407, 51.497598155852295, 53.66765729842648, 52.47794751198062, 54.24770132187874, 54.67704003857028, 51.85718536376954, 51.159646741805545, 46.08898308969314, 38.121845183833955, 35.79036481918828, 35.61315213480304, 36.757154541630904, 36.46761302025088, 37.943440098916334, 41.282965675477065, 47.00695107060094, 47.513030959713845, 51.39566359981414, 53.51047615851126, 55.46042757649576, 48.410210378708385, 35.77596972065587, 55.58243290070565, 51.562619286198775, 48.44134615313623, 44.335624787115286, 42.8855598357416, 42.51042043009112, 40.253092473553075, 37.704626590974875, 37.886067590405865, 36.70931339263916, 40.39676497059484, 44.031762692236136, 47.97479198824975, 47.23655877574798, 48.6944253213944, 52.45553116644583, 56.20653298593337, 52.254886242651175, 52.15691720285724, 55.27329129557456, 49.62306607154108, 41.78751584022276, 48.59488733353154, 54.19588681190245, 53.229979622748594, 51.1499624098501, 46.91197479924848, 42.34895213957756, 39.213017186810895, 38.89694475358532, 40.98102161961217, 39.49941296731272, 40.02759148997646, 37.86592621957102, 45.48846429394138, 48.33816428338328, 53.398931795550936, 52.51473934419694, 55.6761500912328, 57.27055434257754, 59.78864146817116, 50.51802150664791, 39.596319044789965, 18.23054898169733, 16.674430985604566, 6.785366506345811, 9.730647302442982, 3.1264464941716965, 10.984488821798756, 4.191897309595539, 1.4712144939168808, 0.5797766894102097, 0.34680337615070805, 0.23849555080936802, 4.4927842866989876, 17.791425912610947, 35.924937417430264, 26.79979032085788, 39.041774349827925, 46.440666721713164, 46.56447241383214, 43.67436024450487, 27.300847614965132, 9.679806520861964, 0.22338811308145526, 0.04449609118784147, 0.07880203320734924, 0.01819659535202288, 0.0658668837540092, 0.04980737493643838, 0.04659732097699758, 0.045945188631453825, 0.08609397216669976, 0.01716448339603601, 0.020322489341901197, 0.06590105127543211, 0.02722445124339673, 0.03147138988659267, 0.01792200454210322, 0.038487184792757034, 0.025392200670114932, 0.06717626591243091, 0.03225488332851279, 0.021997699551584742, 0.03499758534974629, 0.07289156528009523, 0.08103682659566402, 0.05173686696516891, 0.05648973390399929, 0.05859275633889822, 0.026036593612403642, 0.040485195725435213, 0.013068942878876003, 0.013091575988988965, 0.06376970656997254, 0.06738374550496379, 0.06879366904256806, 0.03209068770370176, 0.05029331982856797, 0.024131545534117088, 0.07253575574366317, 0.02424916301313187, 0.07011837295947537, 0.01240012705356123, 0.018956679062196807, 0.016676280459749605, 0.01831478548176106, 0.09433464207235845, 0.029343121024149082, 0.09755305405105315, 0.08546085412343664, 3.781490157688818, 31.032757297638927, 53.99688536121, 56.39537549787953, 39.564336038404896, 27.158102758469123, 31.379367343841064, 34.07772464136924, 16.100443101698353, 3.1206379542427682, 0.19002552024058758, 0.07276539825984547, 0.7099377856619897, 3.283477603427826, 7.8479061876573875, 11.045601310268527, 14.149453236210732, 15.123824900196446, 9.641115280889696, 15.983323089538084, 17.006818517561882, 22.56526420193334, 41.579343888067434, 54.88003838446833, 53.22082873313658, 51.71455621719361, 47.96608432646721, 45.56206757022489, 49.31645831754131, 55.57068147966939, 55.34083058757167, 52.31066234650151, 51.383555243092204, 50.98111221867224, 51.88487337481592, 52.05204479156002, 54.06496201792071, 52.942093341581284, 51.795117778162805, 53.17166966776694, 52.49509219200381, 52.77302742004395, 55.36338813843266, 52.81100773042249, 56.14255128368255, 53.592618434659904, 54.18706540138491, 54.1222325448067, 53.93883036028955, 53.45860281298238, 47.245980308901885, 40.20956985412106, 38.64402248013405, 36.942725796853345, 38.63522852620771, 38.6953466938388, 39.60118278380364, 44.36885118484498, 50.42031134328535, 51.63208053958032, 53.02176844689154, 55.46882537103469, 55.454536176496944, 48.36037666566911, 39.30877400982765, 57.58085304690946, 55.156914572561945, 50.96192398378926, 46.012787126725726, 45.2716003694842, 43.26826549345448, 40.83661171697801, 38.4384589041433, 39.8029024370255, 39.72556898670812, 42.42348109522174, 48.02769691713395, 51.38267270980343, 49.638284867809666, 53.11887456524757, 54.3392925877725, 57.17442489439442, 52.768140146809245, 52.07825014668127, 56.268659407092684, 51.863057151917495, 45.56214209525816, 50.55975552528135, 55.18929766070459, 54.15949113907353, 52.876746654510505, 49.97869560795446, 44.80583852337253, 41.68094112027077, 39.337277873869866, 42.866893276091545, 40.73710510807653, 40.61729238879296, 40.90993650497929, 48.1994535846095, 49.861118639669115, 55.54420155863608, 54.56993187627485, 56.603080687984345, 57.87061422101913, 60.10148971311508, 49.07695055007935, 39.59446376369846, 22.490617575183993, 15.352090174152007, 11.70476052068895, 15.285307899598154, 13.141447247997409, 5.7461355097832225, 2.7455139929248444, 4.857758870047908, 1.107101851413327, 0.034178549258579174, 0.33080482494927227, 5.051537684855923, 20.33217453187512, 43.105361615457845, 32.35102668885262, 44.61011617414413, 53.33364002166256, 52.18639773707236, 50.401703619187884, 32.30934758340159, 10.345613168131921, 0.2540429834757121, 0.018410774383453593, 0.07281534719250857, 0.036993734688768466, 0.019388543892531626, 0.061165482601931984, 0.01584257282722261, 0.10740290696342146, 0.024961383465016564, 0.04014419849901911, 0.01450726338061354, 0.02307042182843772, 0.01930494646301433, 0.03190566214822954, 0.03700488509850637, 0.030395951828048117, 0.04808036760697442, 0.04439926916553129, 0.03376922081975687, 0.028697209312550487, 0.04608563170017255, 0.05518448095948947, 0.039604098851522135, 0.21570022157844038, 0.23699294595468431, 0.16052586447087028, 0.07467662675246116, 0.1155915058728668, 0.10569305234258214, 0.17760101435405595, 0.20506906623561538, 0.14083317601152007, 0.2120842252888026, 0.15019423418468045, 0.10584847626066017, 0.1424923845596852, 0.1972565169055616, 0.15960597673491125, 0.14259165423291345, 0.10244064904268711, 0.08429979424803488, 0.12130838338165514, 0.17515183126013126, 0.1692806559825136, 0.15811539946063874, 0.1733547575291126, 0.24752176727258393, 5.71603867315477, 38.79366874694824, 62.93400579883207, 60.62786002312938, 45.65461589444069, 34.5324646272967, 36.85207982217112, 40.70855417559224, 19.270004533952285, 3.920228313053808, 0.37363459446257163, 0.24418355446429024, 3.220181090216483, 6.071462285134101, 8.570757335232152, 16.09740032303718, 29.667160587926066, 27.633911755777177, 14.55656780350593, 27.57715309819868, 19.50850425227996, 20.46829842752026, 43.49399397450109, 58.756893373304806, 54.959733101629446, 54.80365807010282, 49.59335019511562, 48.707373065333215, 51.813996145802165, 56.651074809412805, 56.4087390130566, 51.989298635913485, 52.387901659934755, 52.68279329422982, 53.03880330054991, 53.21973831422868, 54.5541561034418, 52.15552083907589, 51.84022503514444, 53.645605733317716, 54.07681934295162, 52.95726899177798, 57.5586602764745, 53.49118986437398, 56.82609881124189, 54.540396428877315, 53.41381719035488, 55.55900850603658, 55.360846442561, 56.3006777148093, 50.25108852694112, 41.960688483330514, 40.423613594424346, 39.1920756524609, 41.22329858041579, 40.05902144216722, 41.34617859317411, 45.446643983164144, 50.76936306491975, 53.40185396132931, 56.05228970127722, 58.509493797056145, 58.23865413665772, 49.41390568210233, 44.47275084833945, 60.58711051940919, 57.30501628691151, 53.56514223160283, 48.61658588532479, 47.13991549707229, 48.095546076374674, 44.10464425240794, 41.394427668663766, 42.06939697265625, 41.18176852503131, 44.42850259042556, 48.563535828744214, 54.01925463830271, 52.96835360988494, 56.441698689614576, 57.45356429007746, 59.4097012858237, 52.67949065854473, 52.77431395746047, 58.13717457555956, 55.81821441650391, 46.487515511051306, 52.87384802295316, 56.91337154757593, 54.53345383367231, 55.02324804182976, 51.72700189775037, 46.90933896649269, 43.81540083116101, 42.35611046514204, 45.495100944272934, 44.574112738332445, 44.61234800277218, 42.046192230716834, 49.273308323275664, 52.90404635090982, 58.65300155455067, 57.97929917612384, 58.87268566316175, 60.45794686963482, 65.83019764192643, 53.542361105642016, 42.92818031003399, 24.796333851352816, 24.7722073524229, 13.43821377523484, 18.28875107149924, 14.389378736096045, 19.334788360903342, 8.786704405661553, 6.698595343097565, 2.3105309855553413, 0.47220780183711364, 0.5049089390423991, 5.783268588204538, 22.4338294998292, 46.9813262262652, 39.2819881439209, 49.45231353082965, 59.88826182580764, 61.58614212466825, 58.45634175885109, 37.58507274812268, 13.302791983850542, 0.5385107198549856, 0.2554043830041924, 0.15572105294033406, 0.1892610564227066, 0.0945938402606595, 0.14307419769465923, 0.10811117057117725, 0.18441763406078662, 0.25367893849409395, 0.12916775600564095, 0.109976809171419, 0.14832038312189041, 0.1207902321531888, 0.07595194864176935, 0.09365930492358823, 0.10283440291400879, 0.0607364695338953, 0.14711561793040845, 0.18944081129325976, 0.15908397974506502, 0.1649451345926331, 0.08353907660010361, 0.19596412657730042], [0.028213007270448634, 0.007756886339085478, 0.05293466841741916, 0.0056349597270450285, 0.11275206992943441, 0.029162427695888667, 0.06089317664924649, 0.060600638314480745, 0.08449626515709585, 0.020938173139227495, 0.1149938960048941, 0.05416051634857732, 0.023466029632536155, 0.036874715268852255, 0.0422773894763762, 0.0301039555004888, 0.03167253776243137, 0.11912127130574758, 0.08275960511978596, 0.05069246312843696, 0.12293304902531448, 0.04152231406600725, 0.025393056773370313, 0.039708233183069576, 4.377776470876509, 23.569847922171316, 44.75025461566064, 45.297205601969075, 36.41154666100779, 21.795873641967777, 22.47542231313644, 25.000777590659357, 19.065798098041167, 4.510277567371245, 0.2352712246318979, 0.17775813898732587, 0.6350000455014168, 1.5030634042716797, 6.898556303593421, 7.389138417859232, 11.980944410447153, 12.248270607763722, 7.415972823096861, 14.87185380151195, 19.476540857745757, 20.59847600998417, 43.51855193414996, 49.58002982601043, 52.21690593227264, 46.402247105875325, 45.705308606547696, 45.93138225616948, 46.93447743692706, 51.24215379838021, 53.904007557899725, 52.175066009644546, 50.74365192844022, 54.22739913386684, 53.88286598267094, 53.93264870489798, 54.60396235988986, 52.83497341217534, 53.360676919260335, 52.7882658281634, 52.98187009749874, 52.99032280522009, 53.56485982095042, 53.37274997465072, 53.44191312789918, 52.42113590240479, 54.2190876314717, 52.46081459906794, 53.22763012301538, 49.43810278369535, 44.865070235344675, 36.83864178196077, 35.31818205310453, 34.53968571078393, 35.38692943511471, 37.666316801501864, 37.5926782238868, 37.632941353705625, 40.77905877943962, 45.41122105813796, 47.33716364829771, 48.168121691673036, 52.454260318509995, 51.650048917339696, 33.44191628117716, 53.96460817706201, 51.90029613433346, 52.033013451483946, 46.44055297297817, 46.80463913948306, 46.4352773850964, 40.92044061230075, 37.51059870566092, 38.5849045168969, 37.00880204477618, 36.635741495317035, 37.07125794502997, 39.85317937789425, 44.49589675472629, 48.99245877419749, 48.62171242314, 52.34644612958355, 50.49694661171206, 50.696936499687936, 54.51361056297056, 49.86522536123953, 44.77010180873256, 48.416721513194425, 51.8224213969323, 50.608134038986705, 45.11492129295103, 41.205161540739, 42.031714762410815, 45.038893991901034, 45.87728492675289, 51.77622764341293, 49.41254069728237, 42.237933374220326, 37.109865834636075, 40.29230440816572, 43.66447194930046, 50.19975254612584, 51.41007438782723, 52.42857663862167, 54.152976082217315, 59.68234131413122, 53.42039108276368, 42.30768096062445, 23.8968284668461, 12.460602233486792, 17.97918781157463, 14.88854152541007, 10.840943801787592, 2.1650046783108867, 3.3266700083209626, 5.415650817655749, 0.559049598391979, 0.1385502799624397, 0.2896928084233115, 4.27527807412609, 16.83449310641135, 32.14508068177008, 43.64084359138243, 39.64789036781558, 54.89892067447786, 49.27034301142539, 49.689824811873905, 20.877705620181178, 7.087477753239294, 0.21114284112568826, 0.03749623857138138, 0.02922091659368767, 0.026239823332176577, 0.09413185859880141, 0.03284695821123258, 0.041685540589594075, 0.04307465334873527, 0.023399349339606784, 0.059049988255625775, 0.0631604751481885, 0.0265660408073135, 0.05653326301985691, 0.067355040190441, 0.03161626668917316, 0.1260464609931073, 0.0067937725708038825, 0.06248786527242872, 0.07473720898551327, 0.029751811694774418, 0.04923804520419048, 0.03988297017771871, 0.015617000153138032, 0.026624726972753004, 0.013950410347822455, 0.0037008204174438313, 0.05604661332683698, 0.11777382223836838, 0.10458297561854125, 0.02777381863955769, 0.026476988831775326, 0.030887736225380536, 0.051761489031055284, 0.025100303933985775, 0.08426369618504279, 0.02770293635436364, 0.04239580751727185, 0.04119897899668544, 0.017893128773017276, 0.10587614735648518, 0.09458923607223457, 0.07049532652261757, 0.0446642589785399, 0.0821733333530926, 0.047596042990804686, 0.03444116802946214, 0.2623755839322844, 5.21407138916754, 27.903047146335727, 51.88375157694663, 50.89318444651943, 41.27615251848775, 29.512481920180786, 28.24216546550874, 30.22372530352685, 21.827056484837687, 5.002258987196031, 0.25681603790050556, 0.09293389626808705, 0.3131496239333384, 2.73598704607256, 6.597225118067957, 7.8991558763288685, 12.724958215990375, 15.441933043541448, 14.986039880783329, 15.878504610830738, 14.936221857224742, 27.382893793044556, 43.05372753450948, 53.60614276701405, 52.05893247358261, 50.712147451216175, 47.91160260477374, 48.38506798590384, 49.25794832168087, 53.95580245602516, 54.369247728778475, 52.049558008870775, 52.06086620207756, 53.53879959352555, 53.1580747327497, 54.90030134877851, 55.27850412553357, 54.59704722127607, 53.46052085199664, 53.812992880421305, 52.731183575045684, 53.911495362558675, 53.826936906383885, 55.461639588879, 53.94327048332461, 52.75731048276348, 54.793220643074285, 53.727438142222745, 54.564734735796534, 52.46719237296812, 48.28101927234281, 38.55944441210839, 37.89492037988479, 36.480764727438654, 37.036517512413766, 39.303208166553134, 37.92647977029124, 38.9241660025812, 42.335329747969105, 47.78172116125784, 49.56837254185831, 51.83401200079149, 54.83234628554314, 51.458072431625865, 36.52554250532581, 55.83876371383668, 54.627167101829286, 53.957759718741144, 49.23136249665291, 48.96526105942265, 47.45434837956583, 42.9839446467738, 38.07363533204602, 39.356697528593, 38.87361449580039, 38.62952539997716, 39.04328446234427, 43.04557684929141, 47.597181489390714, 51.40948995467156, 49.66731432945498, 54.82872593787409, 50.74467174468502, 50.523936440867764, 55.99118701873287, 51.389148542957926, 45.82924373688237, 49.66199951787149, 52.43237349294847, 53.69077182585194, 47.83093121743972, 43.674046454891084, 44.03467701327416, 46.509139537811286, 48.542496235139915, 52.90325403213502, 51.142713869771654, 45.15691811038602, 38.34866800615865, 44.15945545319588, 47.79778718948365, 52.39688388762936, 52.75181916452224, 55.48199669007332, 57.24706326761554, 63.61764354090538, 55.64051535821731, 45.03472843477803, 26.008338389858125, 13.854247812301884, 9.885602497285413, 17.60518785445921, 10.534032064099467, 6.953572448222869, 6.717352607557851, 1.9750946688075222, 0.5598036740576068, 0.115548444070643, 0.36397539019103975, 5.364390832762565, 19.795951227987967, 38.008206275201616, 46.160836988879794, 42.20614648634388, 57.38913151525683, 56.219633702308904, 55.809545978423095, 26.929128516104917, 8.885158838764314, 0.21136503726724656, 0.056835381284115784, 0.043037176327479464, 0.027152682211430326, 0.044163501776394345, 0.017808828457829454, 0.04546602361745412, 0.05760045414189658, 0.07394542647225243, 0.037253806217303204, 0.12358543417987325, 0.037909435754221295, 0.04224831260921013, 0.06871903675698465, 0.07633459423818896, 0.018318129455550544, 0.05462043340347948, 0.06517666151687022, 0.023038700042713075, 0.04273470949321505, 0.02766942000767637, 0.05630750073901108, 0.02964985113771212, 0.12750832529197778, 0.1307069492195883, 0.13558201101278106, 0.17647432884381664, 0.21116524153659422, 0.19754096535184693, 0.1258965146036879, 0.12853573346810956, 0.17190767872718074, 0.1534943571013789, 0.20260606291553668, 0.2055787138881222, 0.12895525853720405, 0.09301576808455492, 0.17936706152414122, 0.1547382693857916, 0.14455149100432474, 0.25943757545563484, 0.22544040134356869, 0.17350576878074678, 0.2619708137166116, 0.10731651522820035, 0.20079556732408463, 0.35661579800709603, 6.215533883340898, 33.60165088407455, 59.47447138447916, 56.94264419617192, 47.65644458032424, 32.07612149177059, 32.88368455825314, 35.27824055763983, 24.946095828087103, 6.472084839497843, 0.42584606055771157, 0.5170683478636127, 1.300392944005228, 6.001471511779293, 15.87049218916124, 13.797576427459719, 24.459170833710704, 22.749554803294522, 14.146638935612096, 24.341895887928626, 24.655089301447717, 24.46650762711802, 47.969163387052475, 54.38034411399595, 57.13124352116739, 52.38951767644575, 50.34775141746768, 50.303185447569824, 51.98281888038882, 55.598055701101984, 55.90349066642023, 53.09394398043233, 51.12736171291721, 54.78090440073321, 56.21569956502607, 56.68288915388046, 59.02239076552853, 57.49385487648749, 56.675405271591686, 56.40976275167158, 55.19240025551089, 54.88138767980761, 55.14393152729158, 57.46990488421533, 55.09126194061772, 54.32793340375347, 55.99767854136806, 55.62864234370571, 57.65066339123634, 53.57531293745964, 50.40249986033286, 40.48295905513149, 39.50977586930798, 37.62807369232178, 37.985013300372714, 41.50737624014578, 40.79218303003619, 42.040489104486284, 44.38137531280518, 49.68593382066297, 52.52383139825637, 54.15933032189646, 54.96616186634187, 52.39282423450101, 40.628890837392504, 57.67762576380084, 57.4774044559848, 57.06694410693262, 50.61290364111624, 51.784562680029104, 51.43112574854205, 44.745959620321955, 40.88563349939162, 42.377420702288234, 41.191723500528646, 41.682957218539336, 40.617798374545195, 44.07857618024273, 49.02728549895748, 55.160052468699796, 52.50548255059027, 57.10871342689761, 52.38543841146654, 50.897699094587765, 58.345134719725586, 54.740731485428356, 48.07275318330335, 52.299864061417125, 54.57763148892311, 55.03032791999079, 51.25172438160066, 45.863905722095126, 46.90141970111478, 51.00998870788082, 51.09393135193856, 57.11030983155774, 53.21996581169867, 47.15583639760172, 41.20235704606579, 45.92119586083197, 49.81889432476413, 55.96999445269185, 55.65024675861482, 57.061033095082934, 60.18925274572065, 67.60522703970632, 57.33348484962218, 48.11126301365514, 30.61398936856178, 16.66958489725667, 23.88189796478518, 24.351415480336836, 22.00232171243237, 12.572619242052879, 12.392067640058457, 9.150609162545974, 1.8502049316321652, 0.33130066769738353, 0.7490792401855992, 5.992827588512052, 22.28850176257472, 42.462638116651966, 56.149246769566695, 50.07452695600448, 63.85060095017957, 61.1496215481912, 66.59120805801885, 33.65622674265216, 10.96947398877913, 0.45166717661965283, 0.16821066097867104, 0.14360239999669214, 0.13308631106009408, 0.19135839065476773, 0.1699888889467524, 0.1465033604613235, 0.1321980014683739, 0.27635233717099317, 0.14830682336563064, 0.22734639745566154, 0.1233565730733737, 0.15122842223894212, 0.1814283743020027, 0.1193854567264357, 0.29659293171378875, 0.11116818314598453, 0.14740870784847968, 0.16177817307893308, 0.11351490964091594, 0.13796178654076593, 0.1916829514647684, 0.1262190452806892], [0.08377297856514493, 0.03916761642622371, 0.019521682312892332, 0.0820915075019002, 0.033763134251198465, 0.009039257194906955, 0.0628239174012936, 0.03267196074668919, 0.01569858085619466, 0.135118389922765, 0.022766846081902905, 0.06542032344206687, 0.04581450552289044, 0.021807713576802806, 0.05165366981659205, 0.02481628258171822, 0.008264193592983629, 0.01319262681664118, 0.08308988860658101, 0.0611856728491764, 0.08676605344179177, 0.016034610002421807, 0.02820442517047688, 0.009391166386194527, 2.422212631471696, 20.380080399974702, 43.05551613530805, 50.487670206254535, 33.35874242167319, 19.50913183150753, 26.837700028573316, 33.96479960410826, 19.654585084607525, 5.595012470599144, 0.6158666012267913, 0.09023554307679016, 0.19632651680900207, 2.7927062348012, 6.592328529204092, 7.721267563681449, 6.344581823195181, 12.70529047135384, 15.96760222988744, 14.671666814434914, 16.5116173221219, 39.39288531580279, 41.40584961060555, 53.09779574794155, 49.67682607712285, 49.923966776940134, 44.56631506642988, 45.666712484052105, 46.45857234154978, 53.52014087861585, 54.07364614548222, 52.72614332937425, 54.04385182165331, 51.2323086492477, 49.494145608717396, 46.86951514213316, 47.787334072974424, 47.78914620799404, 47.98439002806141, 50.30086340442781, 49.12306585619527, 50.07978685440556, 49.16859280678534, 49.637516083255896, 49.521994436940844, 51.671692555950536, 51.82695173448133, 53.308497628858014, 49.405072504474276, 46.9273308784731, 38.1065087164602, 39.26299602754655, 36.35472328432145, 35.102792939832135, 36.14810066838419, 35.932456601050596, 35.84876498868389, 36.68747755788988, 36.61968331183157, 35.94656928893059, 44.2087871028531, 47.58024469498665, 50.56507425923502, 50.29314417992869, 29.881892704194595, 50.058084380242136, 50.702533721923835, 51.52145008887015, 53.00559651467108, 52.24797110403738, 49.3098295119501, 46.11425884308354, 37.054901661411414, 37.29717077747468, 37.898658398659, 39.98189979983915, 37.52792773708221, 41.39756164243145, 39.79318672610868, 47.38660904668993, 48.17740594187091, 51.98290517253261, 52.312117545835434, 49.479150387548636, 51.843088365370235, 53.88554496149863, 52.01797116187311, 48.40776281972086, 48.62557203538957, 45.671791953425256, 46.34547472000123, 44.194074292336744, 45.987668268142215, 49.14721588934622, 53.26550060702909, 55.52505646982501, 53.57294382587556, 49.24038394804924, 39.141932072178015, 42.10439628170383, 41.44255122830791, 44.14248335746027, 46.842960696066584, 52.489773458050145, 54.087994175572554, 55.44222385652604, 56.31004433478079, 46.982852028262236, 23.173260996418616, 17.74785818592195, 10.976507779090635, 15.11827866877279, 13.236059719516387, 4.781078494364216, 2.9272952579682876, 2.9775572448007526, 0.49562714032588473, 0.0964930794772602, 0.3075757827008924, 4.797060681927589, 19.847850068922966, 46.227297629079516, 29.36919381541591, 37.82794983156266, 53.61230873292493, 52.62320072420182, 49.77396357444025, 28.70167897593591, 7.02642459061838, 0.11995286740843328, 0.11195625013281262, 0.07899864201223658, 0.060353027206034436, 0.01165908158591558, 0.052469963312990246, 0.05586797311421364, 0.07403619256952117, 0.05905015679496912, 0.0637114417528914, 0.01567330953079246, 0.023252729686998555, 0.025627355188912442, 0.14550099569943645, 0.031076291530963876, 0.09037078057806339, 0.05252234840525254, 0.05389525457435558, 0.020400793103861715, 0.0023433923366434515, 0.0412018173524449, 0.0247158216417677, 0.03320791585851581, 0.05751657900550673, 0.010784740649884748, 0.042440125703691475, 0.05420119561735661, 0.03746681696464939, 0.0690060975630918, 0.04396930614846849, 0.0074660089787005664, 0.004912514395395955, 0.06491266761816318, 0.038776727723738844, 0.046874334539977774, 0.08146607332051763, 0.029641021974384788, 0.04806332981153842, 0.017142747566404364, 0.027540807251728354, 0.06989688927968664, 0.02176724306698288, 0.015295209708593547, 0.04691998954982527, 0.019228732205867287, 0.029154385687903534, 0.0807687724309583, 3.4553531677492204, 24.362360854302686, 47.66282627659459, 55.66805824156731, 39.81070795366841, 20.851802287563203, 28.569551975496356, 37.62604582694269, 22.21783438036519, 5.837729717454603, 0.5109674687827788, 0.06520148276561691, 0.11776384777359425, 2.4900161931591653, 4.811646505709618, 7.7913519836241205, 7.883799797104252, 10.122858824268466, 9.099656593415046, 15.842097170891302, 18.767950957821263, 33.419158689437374, 41.80729635300175, 55.005475782579, 52.15651319872949, 51.990247849495184, 46.47547775699247, 48.5505174821423, 50.16826768075266, 55.51397969645839, 55.587881072875, 54.16443332549065, 53.743645375774754, 52.576414692786436, 52.59262584870862, 50.29830994144563, 50.19283348514188, 50.75857654694588, 51.415251916454686, 51.32109149809807, 52.35042341293828, 53.128092135152514, 52.074821995150664, 52.84277500644807, 51.3215974838503, 53.38575263177195, 53.502447066768525, 55.87965834525324, 53.00385890468475, 48.418290461263354, 40.83217551631313, 39.81779175419962, 37.73771178337836, 37.58917162495275, 37.76612935527679, 38.33166845383183, 37.469547179437455, 39.728961836907175, 37.977058733663256, 39.62063381748815, 46.10750059927664, 49.42977559181952, 52.92043793585993, 50.60944803299443, 32.48017072677612, 51.76948508908672, 50.97645636527769, 52.79416115053239, 52.42055931398946, 54.135062617640344, 51.093719543949256, 47.19471100837954, 39.80409483755789, 38.93169303094187, 39.43077933403754, 41.77662341825424, 39.55289840698242, 41.79923980466781, 42.90643861216884, 48.820635426429014, 50.01957062752017, 53.9463613110204, 51.92809004937449, 49.79841563009447, 54.44524757323727, 56.058287005270685, 53.671897380582756, 50.949293951834406, 49.31145337320144, 47.55549846156951, 46.14205275812457, 44.694611872396166, 48.82199648887881, 51.56223881629206, 54.894711971282966, 58.71942689341884, 53.91120510716593, 51.867979726483746, 41.16994650133195, 42.791140540953606, 44.587946937930205, 47.17866851437477, 49.06466960906983, 54.388004502942486, 57.401153579834975, 58.691935000881074, 56.41576397803522, 46.418415115725615, 23.967293846991755, 14.481273005085608, 10.900877618020582, 18.91795219913606, 13.19105346356669, 6.351502845364233, 3.1913227419699393, 2.2421964330057946, 0.9348580745920059, 0.024162755956152276, 0.3395713529279155, 5.666255460631463, 21.61214001717106, 44.87604110471664, 40.62647857973653, 44.255863389661236, 60.65016654229934, 56.97541559896162, 59.63866964463265, 31.832946308197517, 8.00398269007283, 0.09898805164641912, 0.05200230877005285, 0.07160124338922963, 0.027696775092232614, 0.004990463362886541, 0.05259544851498739, 0.034834278386927424, 0.11521994556871154, 0.11067040985630405, 0.07486103943759397, 0.020616488989382502, 0.04852893889971799, 0.023709337242067825, 0.13354331315044435, 0.026990378823792262, 0.020265921409572327, 0.014047917061214967, 0.026371781977133888, 0.02231138957393987, 0.10539975558077136, 0.040625435780854, 0.01468096902939461, 0.12049102119260258, 0.15324877995637157, 0.13502069839066075, 0.1885446109959195, 0.22434085066760742, 0.13727497339489, 0.16012826483816872, 0.15465039910087663, 0.10315371602172814, 0.09032943481278997, 0.15822000110582, 0.14707850863135633, 0.19504757898469127, 0.1348622407644026, 0.12260117207563694, 0.18440810392700857, 0.11534686335512709, 0.15559354526621683, 0.14703985183469712, 0.17452083528041842, 0.1230700561896928, 0.33804414132910393, 0.2009093313808403, 0.15860641585482707, 0.15036838129162788, 3.932680367462097, 28.51144402257858, 57.030666105208866, 62.77936243241834, 47.807193033156864, 29.778938331911643, 37.826451486156834, 44.62471131355532, 25.951254175555324, 7.145918127029174, 0.8956204607121406, 0.19088387579446842, 0.6926397041928384, 4.054018153298286, 13.821926501489456, 21.52588905826692, 14.698148696653305, 24.952975665369344, 22.49897026246594, 25.44340725867979, 21.99157245697514, 43.270481632601836, 44.72037792205811, 57.50930509259624, 54.33218917539043, 55.147057656318914, 47.99725147985643, 51.68456577485608, 51.57610831722137, 58.37916128097042, 54.96253367393248, 54.31052592492873, 54.84456054625973, 54.609571349236276, 55.129814917041415, 53.71699287045387, 52.72806529075869, 52.292803795106956, 54.50607176749937, 55.22435188293458, 55.06138132464502, 56.31786946327456, 54.74646991299045, 54.23043504838021, 54.38597271519323, 56.061636709397845, 55.427989575170706, 58.2819139572882, 54.448440382557536, 51.992718942703746, 41.31700400383242, 43.420759401013775, 40.50122945539413, 38.90458160831083, 39.073188612538004, 39.44155016253072, 40.32053762866605, 42.038488695698405, 41.646804732661096, 40.79108476638794, 47.38704442977906, 53.32562269703035, 54.77429128462269, 53.75664018815564, 36.71574215735159, 53.5758856035048, 52.0701269180544, 55.45395958808161, 56.64370467585903, 57.57627956328854, 52.86881169965191, 51.60848356062367, 41.0113807647459, 41.07628030161704, 40.79255957757273, 43.18382863075503, 41.127561369249904, 45.91229992528116, 44.36519945821455, 51.462904791678156, 53.411789324975786, 56.22108105690249, 53.850231862837276, 49.48675978568293, 53.65886334450015, 57.519675839331846, 57.37950601885396, 52.95808876714399, 52.03466084695632, 49.69890902119298, 48.699296905148415, 48.76636159035468, 51.49251476410897, 53.72137023556618, 58.099786543077045, 62.52320812594507, 57.39584661299183, 54.59014777214297, 43.38790955082063, 44.77999010393697, 46.41216285767094, 49.34776667625674, 50.747142837893584, 57.16117512795233, 61.813423864303104, 61.876750530735144, 60.20694655756797, 52.06834616199617, 29.249553680419925, 24.600017263043313, 16.369001903841575, 25.585675547199866, 25.471711081843225, 14.228891038125562, 10.297894593208067, 8.617712028564947, 2.239406647220735, 0.5230140481745044, 0.7227152129334788, 6.727063905808234, 25.641767401849073, 55.00109057272635, 44.777248367186516, 49.822181270968535, 66.37954911878033, 66.30749517871489, 66.63835494749009, 39.66551357699979, 10.743351309530198, 0.4274606368234081, 0.2315416328248478, 0.16183824969395516, 0.30050430086351215, 0.14827864665177562, 0.18718046887267023, 0.12993399714750628, 0.23468484561289513, 0.18392837966882414, 0.21154445505911307, 0.1982664812596575, 0.08007275090823252, 0.12291493104590524, 0.35820402084819736, 0.1568208640861896, 0.20455486802083833, 0.14467889142613258, 0.12474917536300999, 0.06850535951314435, 0.23334345630099698, 0.16807941479548333, 0.13257195962773216, 0.20813398483780124], [0.02020332819571899, 0.042784348160268805, 0.027832359248291583, 0.052175881311057076, 0.03220816345645055, 0.026442836632110903, 0.03429136336630872, 0.06896161083732882, 0.06381928394999235, 0.051192507868812936, 0.06907451687560928, 0.018926770989632895, 0.01814076669454094, 0.031735648085633596, 0.06894287232670092, 0.10713854534251076, 0.07197572248837641, 0.09286448870214725, 0.06416914481369239, 0.021481835095572378, 0.03686245786206376, 0.11699887067680398, 0.05863687917289715, 0.15869397970457233, 1.7340112117029007, 14.302829677058806, 42.726707766132975, 47.69176944609612, 39.033023541973485, 33.89690729879564, 25.128968492630992, 30.068030741906938, 23.45765636813256, 7.3193339570876095, 0.7582453902690642, 0.035434404853731394, 0.06895023443165325, 1.634251487351233, 1.9948156105895198, 3.6762620364466025, 7.150504358353154, 8.26931534274932, 16.54676568123602, 15.201653549748084, 19.660250948321437, 34.11016656506446, 43.40267335214923, 51.12556918974846, 49.64226999590474, 46.737182217259566, 45.16095422929333, 46.737876476780066, 48.90659024638515, 55.02736260814052, 52.28042087247295, 52.317228394169966, 52.45846902170489, 48.26849122201243, 45.269180267087876, 43.12688366059334, 43.77712634301955, 43.04671825901155, 42.743326848553075, 43.443560138825454, 43.788250184828236, 43.87943352422407, 45.408793111001295, 44.28544590550084, 47.10035054914413, 47.96411921901088, 47.70214411520189, 47.821882309452185, 45.28409311848302, 39.82902542237313, 37.3862595711985, 37.278198272951194, 36.585648905846384, 35.66667287580429, 36.21210198248587, 34.79226673803022, 36.39343315555204, 37.46127882311421, 38.01083818558724, 40.720619386242284, 43.54363156903175, 47.07472962717856, 50.594915651506, 51.62238836288453, 28.77868098597373, 49.225031791194795, 46.50816679000855, 49.556256340396025, 50.836208097396366, 51.73845521865353, 50.650903563345636, 46.87106447835123, 38.12262965786842, 40.66137590715962, 40.38768076127575, 38.62854480743408, 38.135361671447754, 37.41004090155325, 37.87401022449617, 41.385555267333984, 48.477318209986535, 50.17462192043182, 53.17285030118881, 53.35312243430845, 51.487325468371, 52.96967544863301, 54.37904973183909, 52.92839250256939, 51.98885148571384, 50.08321500593617, 50.60319185256959, 51.43222008982013, 50.351764002153956, 53.18990476669804, 53.113736260321836, 50.25520309325188, 55.09918120599563, 50.70432624509258, 43.33799346800774, 37.97974555723129, 44.11992972896945, 46.7300082022144, 48.64223034151139, 50.449470243146344, 50.88355895011656, 56.11172929886849, 55.062122652607584, 43.88721942901612, 28.19833690120328, 13.184672747888873, 7.807397419406523, 17.88265435926376, 4.877423182610543, 4.379889157510573, 3.6022339184438033, 0.9569510084486778, 0.7079684494003173, 0.06345988146119541, 0.2510974213721291, 4.859579830400405, 16.900349701604537, 38.93710982414984, 40.40889686153781, 40.450430839292466, 54.68444939582579, 54.777546851865715, 44.271211624145515, 27.885747532690726, 5.781095104832803, 0.1437774817309072, 0.10103255645522188, 0.037899629828790506, 0.04177843641129233, 0.060762849771567894, 0.051297262731579044, 0.07323482629632758, 0.03341473278499419, 0.07615656306546542, 0.023872098367240642, 0.03579410994725843, 0.025124694258275054, 0.011810419382527472, 0.01897430483011469, 0.06868023440361985, 0.03940463253867723, 0.042749376246525396, 0.05273046385076258, 0.02247484017824454, 0.0418059581199721, 0.05051529763506786, 0.10173956367878184, 0.006273733414409142, 0.05930824032534034, 0.05074486354245775, 0.05904880081934314, 0.060093304247505246, 0.0526469411148179, 0.02576826557126497, 0.030201888350289197, 0.0271691071365269, 0.018712860088975682, 0.033677895478303396, 0.04139587891498401, 0.03950256538847762, 0.05921162131633009, 0.020507095464234872, 0.06270920339551184, 0.06910900615396039, 0.04003108944743872, 0.06833281352995865, 0.08804928135847853, 0.039320964246026935, 0.028398442682960344, 0.012861200901229056, 0.07037587043258452, 0.05663115756526109, 1.8772310427119656, 18.68037816016905, 48.94302906528596, 53.51462602615357, 43.261052254707586, 35.959807288262155, 33.11543779988443, 37.21991577456075, 27.316633193723618, 8.289132137452404, 0.7934795512307076, 0.1076443855380339, 0.2889603670806654, 1.3937750170307777, 6.002429550693882, 7.12142929915459, 8.957921747238405, 7.238162467556616, 7.657809988144906, 15.36610774455532, 20.004858624550607, 33.184985345409764, 44.81597785026797, 52.96809473345357, 52.16933542682279, 50.24132574758222, 46.629932849637925, 49.437271241218816, 51.30360164949971, 56.779956048534764, 53.93460988998414, 53.15541536577287, 54.756632774106926, 50.25015892521028, 45.51721918967463, 45.34957708850984, 46.70040607452393, 46.713094942031375, 46.30552145742601, 46.43505773236675, 47.15794271038425, 47.69422092745381, 48.39635264488959, 46.750659481171645, 48.58267307281495, 50.69958017718408, 51.748280755935184, 51.93201241954681, 47.28650231515208, 43.685295812545284, 38.40196909443025, 38.41775271200365, 38.23874750444966, 37.77931636379611, 38.45512897737565, 37.183331827963556, 37.67087459564209, 39.14961599534558, 38.567351910375784, 41.366245438975675, 44.7062809236588, 49.15240910745437, 53.60252634171517, 53.68025202904978, 32.53879054900139, 50.05766860900387, 48.50838730412145, 52.9603402076229, 52.70195015015141, 53.03018585328133, 53.20687686243365, 49.98660702859202, 40.377866991104625, 41.99984550476074, 41.32775522047474, 41.49673877223846, 39.77457900201121, 39.353414504758774, 40.29975691149312, 43.6655152997663, 49.83956913794241, 53.15265401717156, 54.63842430422383, 52.94418788725331, 52.29673793238979, 54.46014473515173, 54.664570823792495, 55.22561488613006, 55.36101510447841, 51.72462101905577, 53.32728185961324, 53.599698312820934, 52.96403115795505, 54.30197123558291, 54.047789881306315, 51.501379320698405, 56.17649939752395, 53.49575550325456, 45.38734951326924, 42.71270882698798, 46.37666540761148, 47.6352677037639, 50.327327635980424, 52.99837935355402, 54.8049210732983, 61.0564927131899, 56.36220009096208, 47.457851056129705, 23.430968561480125, 17.970199700324766, 9.657345068070198, 17.372624643387333, 11.76722328509054, 7.4561295586247605, 5.3809903033318065, 2.011582517335492, 0.2959282125436491, 0.055655628863361575, 0.4972755470343175, 5.22730399524012, 21.304371241600286, 48.31824648764826, 43.681334218671246, 44.328513529992875, 58.941240849033484, 59.76933163981284, 50.30774324171005, 34.313502234797326, 7.640712376563781, 0.185222179598866, 0.019290394622892625, 0.1152684925604732, 0.09425148322817781, 0.021236248374465975, 0.017458109575654232, 0.028771772650220705, 0.030179618174330364, 0.07045815593653149, 0.03555285736858364, 0.057680211555693424, 0.05246305703035286, 0.033250759325681195, 0.056503603925868395, 0.014306761891460948, 0.05547405836442786, 0.005699070752598346, 0.02645504424318431, 0.07183905240268477, 0.04871356225902996, 0.10932951084067745, 0.07217069186510579, 0.048854974428972894, 0.12995396139881304, 0.1275953988454515, 0.0923836536164726, 0.14235105665941394, 0.11576671018114976, 0.10046758959370275, 0.07253633797048561, 0.12540172139603284, 0.135356888415352, 0.20410181894417734, 0.11839721862587238, 0.11793503778115397, 0.08836179160543027, 0.06730682261648678, 0.194734325632453, 0.2246815759328104, 0.0978663916729631, 0.15085642526467002, 0.24198862063067578, 0.13770317057928733, 0.23491962091817012, 0.15990887257841327, 0.09652451972567266, 0.3261350900415452, 2.3974967964233893, 22.72518119504375, 55.37599071379631, 59.920178151899776, 51.310163774798, 44.887714078349454, 35.720236762877434, 39.97842457986648, 31.54095918901505, 9.261726967750057, 1.2496230102354482, 0.23057122925116172, 0.5920523597348122, 3.8424290812784627, 7.769870142782889, 11.462311956190295, 15.743947702069438, 22.451097734512825, 33.744197660876864, 22.007269782404748, 23.29102231610206, 37.41887407918131, 46.66967822659401, 55.59446281002414, 53.17186970864573, 52.78076625639393, 49.565991663163715, 51.93547195003879, 52.87508356955744, 59.51991596529561, 53.73255683529762, 53.63458387313351, 56.7174413127284, 53.879955584003085, 48.37442267325617, 48.232519165162124, 48.4051779777773, 48.03514942046135, 46.4528888271701, 48.74081127105221, 48.77264522737073, 50.00646206640428, 49.75380651412472, 48.06204119036275, 51.08139937923801, 52.546232054310465, 53.30061758718183, 54.43953660226638, 48.96426477739888, 44.23592990444553, 39.99639295762585, 41.359538185981016, 39.80778971026021, 39.264627733538234, 40.647110246842914, 39.83839596471479, 41.043179419732866, 42.14294925812752, 40.73526551646572, 43.95193461448916, 46.65338077852803, 52.02227400195215, 55.99366987905195, 54.88108957967451, 35.34978851195305, 50.688687755215554, 50.14495311244842, 53.39349146812193, 54.96605203997705, 55.54244825916906, 54.93331986088907, 53.43293874494491, 43.14003144541095, 43.541399740403705, 43.42285786905597, 42.37266286726921, 42.03628824603173, 40.978197513088105, 42.16847996557913, 44.70146817545737, 53.46027766504596, 56.2689692743363, 56.93446605436264, 56.32501994409869, 53.23112495483891, 54.510272625953924, 57.5617197252089, 56.53585518560102, 56.741175574641076, 54.84521165970833, 56.06414702630813, 57.30052517306421, 55.38311373802924, 56.90154952387656, 54.31280089962868, 50.96081787540067, 58.60905924151021, 55.47675640352311, 47.55881286436512, 44.74722262351744, 49.0082698483621, 51.24169880344022, 54.45424549041256, 55.209933250181145, 56.74558039634459, 62.19684731575751, 59.221533421547186, 49.131875499602295, 33.711822417474565, 19.11383144317135, 14.425979352766468, 24.511465834033107, 12.247074284861165, 12.347283978616039, 15.539624575645695, 4.252149328108757, 1.6340203126592021, 0.25339107329566635, 0.7269668783391676, 6.900430215943245, 22.232268702599313, 49.66974619896182, 52.41527588136735, 52.86136704106485, 65.2098669544343, 69.26092224736368, 58.77064912549911, 40.48031145526517, 9.502363397229104, 0.2713560343029038, 0.3103312477469444, 0.2259595638080951, 0.12389779887011937, 0.1491744945486707, 0.15155682881032267, 0.15383719676925292, 0.12748389474807248, 0.16522998140463907, 0.12517340421195955, 0.15253778907560533, 0.1546870640689327, 0.10479376471090703, 0.2536020232664962, 0.14682517867655526, 0.07508220136045449, 0.07653170100022709, 0.13231714346235798, 0.1152662938881305, 0.09542725965260498, 0.15205323846349794, 0.20558571593175012, 0.15406305481108928], [0.03082111147382567, 0.059057197142993255, 0.04378874688559482, 0.018903198464202787, 0.056821028626854383, 0.01582020880549305, 0.03443656001059759, 0.050709929933110555, 0.03815434640273452, 0.023380972805523106, 0.043168112245057864, 0.061298942779220884, 0.07087041083122454, 0.09235518578920635, 0.03414188812096273, 0.016332870056372017, 0.04960599723422239, 0.06583640877638133, 0.002049274424338834, 0.045722440906590035, 0.03058667133201755, 0.022978246129388293, 0.03918520963540481, 0.049488716833894296, 0.9013121875543749, 13.872633922484614, 36.98226328819029, 49.28014501448601, 35.245806478684955, 20.64831364539362, 20.973272208244573, 26.022417737591653, 26.57410498588316, 9.528369692064102, 1.2937538421923116, 0.017394918813219955, 0.10575486031631309, 1.6897438322344136, 4.42387608751174, 4.166802965825604, 7.603363567782988, 4.2925389543656385, 2.564679244833608, 12.933080157926007, 20.48930075860793, 31.341665521744762, 43.09078608789752, 51.43469118302869, 50.340522489240094, 46.084444907403764, 46.82418038768154, 47.068434223051995, 50.63469240742345, 53.917112196645434, 50.962080878596154, 55.54324450031404, 51.6838401363742, 43.48777701777797, 43.135485418381236, 39.02484932253438, 39.02163297899308, 38.13596963882446, 37.97707442314395, 35.00474153026458, 38.16131991724814, 37.36745180622224, 37.55338784187071, 36.4642946950851, 36.96920964025682, 38.503185856726866, 37.78441544502012, 37.36343922153596, 36.66937974191482, 35.47050729874642, 36.415335670594246, 36.14297805293914, 36.739327369197724, 35.66423708392728, 37.02498966647733, 39.91018710597869, 41.676438239312944, 42.39907218563942, 43.692438448629076, 43.80801108575637, 46.1763499629113, 47.17181221131356, 51.80748501131612, 49.894262667625185, 27.04989044897018, 45.40962073110765, 49.492204035482104, 52.145044188345636, 52.35737385288362, 50.433619945280014, 49.201603474155554, 43.24661008773312, 37.778296547551314, 37.30945956322455, 35.958505061364946, 37.866757762047556, 38.49922034048265, 35.75251394702543, 36.31374236076109, 37.59676141123618, 43.62418920763078, 50.18745983800581, 51.03938294995216, 52.603373142980764, 52.300632845970895, 52.89893942494547, 53.436551247873616, 52.32080951813729, 50.80876719567084, 53.13877274913173, 53.04756979788504, 53.99412009023852, 53.65079110668552, 52.71999697531424, 50.9981196157394, 50.29062994064824, 54.61928313778293, 51.019806400422134, 46.71580137745027, 42.837330372102805, 41.78321300014373, 45.07643499682027, 47.98986957919214, 53.21997365643902, 53.49508870032526, 58.448434260583696, 53.786003051265595, 45.93036243992467, 19.631450945331206, 17.257720770374423, 10.47101918728121, 21.10821939283802, 18.141924988838937, 2.987251872977903, 2.998422783228659, 1.253313347697258, 0.4262289513022669, 0.10505772030521786, 0.35584496033768503, 5.193847648559078, 19.531136328174224, 33.335294492783085, 25.490561992891376, 41.75370893170757, 56.67128286054058, 52.89087110950101, 43.41027882791335, 22.06403040116833, 6.336627256485724, 0.06850896012638846, 0.08261888242897489, 0.022877277656187935, 0.03045886105317022, 0.01969665679479799, 0.07005843424027966, 0.022359105360303676, 0.0226537695890593, 0.029818057232806762, 0.022973879428219893, 0.03313134154004436, 0.04456540682323037, 0.11971672846665306, 0.05019203534409885, 0.00911536611496441, 0.024071832810859048, 0.011231297131387458, 0.027522919098696405, 0.0065314228883043175, 0.04944848572655071, 0.04563827465678896, 0.06745014234536117, 0.03868887659102198, 0.038165040990157474, 0.057755740164148237, 0.034957354242402705, 0.04434876864956272, 0.015679895014111555, 0.04187129009815474, 0.04808093451203839, 0.05003075851427932, 0.03373168251146713, 0.02095383197639979, 0.026052547393426783, 0.05054571898654104, 0.04120161050870534, 0.020033442452850363, 0.008083990560994755, 0.02957154546053179, 0.007656899894843059, 0.03208377950584456, 0.060249647471092405, 0.1251132969534205, 0.08162266935311979, 0.05539509385163265, 0.09195569391933181, 0.032430742641970996, 1.2032920963341192, 17.44471976833959, 43.18495435099448, 56.26478018299226, 44.31898609284432, 28.40934668817828, 22.050170706164455, 31.436461364069295, 29.950851894194084, 10.009480753252584, 1.5312148678687312, 0.04916297624849024, 0.1232794893064326, 1.1659342170723024, 5.55634182307028, 5.505699121182965, 6.838913233049455, 9.656622371365948, 8.613876931128964, 16.044697396216854, 22.92583396357875, 33.162482707731186, 44.191218806851296, 55.06962222437705, 51.384551525115974, 49.10259500626595, 48.48740262369956, 50.612950709558305, 53.13102999041158, 54.04629938064083, 50.63643393977996, 55.73863737044796, 54.045099135368105, 46.82130136797505, 44.77028223776048, 41.854768799197295, 40.66635339490829, 39.93045791502922, 40.72624014269921, 38.306243650374874, 39.83661128628639, 40.25867792867845, 39.271476191859094, 39.96905795989498, 38.87571296384258, 40.99334178432342, 40.085238564398985, 40.66442751115368, 38.64308111129269, 37.02747644916658, 37.97101436122772, 38.37306907100063, 38.03400762619511, 37.30042242234753, 38.150349047876176, 41.628459807365175, 42.42885866472798, 44.383532616399954, 44.75720113323581, 45.653070480592795, 48.20685117475448, 49.923303896381015, 53.41325236905006, 51.744946741288715, 28.996686320151056, 46.88394161962694, 50.2459619891259, 51.85238438267862, 53.28949374537314, 52.76086022776943, 53.16429168947282, 46.932241685928844, 39.03625949736565, 39.89692165005592, 38.02381338611726, 38.043076146033506, 39.12081795354044, 37.33436661381876, 37.61863254731701, 39.559507600722775, 46.10777124281853, 52.40641916951826, 53.312953441373764, 54.4410349476722, 54.42022677390806, 53.81592289094002, 54.43266460972448, 54.091061469047304, 51.25886701768445, 54.20229204239384, 54.40290558722712, 54.90270968406431, 53.38182633922946, 52.78921896411527, 51.716031028378396, 51.24801774178782, 55.16343355178834, 52.44184209454445, 49.558256749183904, 42.11647718183456, 43.484992134955625, 47.685603480185236, 50.513095009711485, 54.51473236083985, 56.14415161071285, 60.430635406124985, 56.36494967245287, 45.141907199736565, 25.90443676517856, 18.920025171772128, 11.703459274384285, 16.212764093952796, 12.337219176753877, 5.419234883400702, 5.934805437441796, 2.9740827602724877, 0.8786408266713543, 0.11412362778379072, 0.3357889010540901, 6.000737538260799, 20.681998960433468, 37.5954278053776, 37.97076725190686, 47.87783884233045, 61.75661225472728, 60.33636908377371, 51.16079599626603, 27.912092131953088, 7.333521170000877, 0.12708868530969467, 0.06347925965524008, 0.02324097406780047, 0.002402656419660836, 0.02071390856027363, 0.05984717934963204, 0.012383964513578724, 0.053882725206353975, 0.07702237265484949, 0.024937525571834658, 0.028483903621353453, 0.04383339065938227, 0.06699995077665775, 0.05930684221487853, 0.05241847454359936, 0.018841375168713353, 0.025193291686234937, 0.04186112411139954, 0.027355270332566677, 0.030382679354759957, 0.013996587255068365, 0.049510814640070164, 0.006652837290593814, 0.13370681163524428, 0.15747677324520004, 0.1938835083837471, 0.059341266375756076, 0.14957348846139448, 0.1938911539412314, 0.19963099110511043, 0.14134922815907386, 0.14341024982352413, 0.05947720867791965, 0.18556927871559897, 0.2496022322485524, 0.18602398254217642, 0.26060831102152027, 0.09956746692619017, 0.12156175164085244, 0.08503130862429258, 0.16756713180051697, 0.15343544494000175, 0.21613212662839124, 0.20565440337504112, 0.2200015294816225, 0.15151958161544415, 0.18440759830897857, 1.4656291613655708, 20.05237617800313, 49.85343079413138, 62.9711231877727, 48.453281925570586, 29.932518736008678, 31.381556026397217, 37.26704305218112, 34.75544744922269, 12.261663540717095, 2.0308381679557987, 0.2464358836051918, 0.8498258696448419, 3.973934631193838, 11.053021454042005, 13.330232885576065, 18.939540924564486, 14.47661420991344, 7.4586903760510115, 18.973812633945098, 22.577023467709942, 33.03914377766271, 46.28082621482111, 56.08173885653096, 54.41978354607859, 50.843217372894294, 51.267009858162176, 52.85091000218546, 56.76159935612833, 54.447298972837395, 50.647145932720555, 57.47348993055282, 57.49383134226645, 49.46644190819033, 47.87223769772438, 43.11052345460461, 43.0939906643283, 41.93509501795615, 42.59188413619996, 38.97637274957473, 42.358487421466464, 40.653723362953436, 40.858055314710064, 40.22722836463682, 39.795622517985684, 42.36384537912185, 41.61718691548994, 42.072738832043065, 39.691581649165, 38.35501047872728, 40.55635052342569, 40.593448300515455, 39.08726992145662, 39.29164501928514, 39.80932727936776, 42.72961424243066, 46.16587723455122, 47.573145204974765, 47.69617426779963, 48.902338397118356, 49.614574140118016, 52.1047261453444, 55.05988297923919, 53.236125976808616, 33.13147637151903, 50.77141446451987, 51.9052069417892, 55.326047174392215, 55.14741851437477, 54.35451922878143, 55.139405112112726, 47.1620023635126, 41.24781731636294, 41.4969741144488, 39.594805009903446, 40.73240610861009, 40.76751132165232, 38.94725307341545, 40.184435306056855, 42.10963656825405, 46.995513439178474, 55.183975004380756, 54.86269758593652, 56.100876100601695, 57.26076410662744, 56.94830417633057, 56.09470621232064, 55.13335681730702, 50.95322416674707, 54.28030798512121, 54.76870975186748, 55.645885082983206, 54.99928628244708, 53.48419627835674, 53.35209085095314, 52.08809137344361, 55.73393444861136, 55.91461450822892, 52.46615294487246, 45.74762313596664, 46.36251741839994, 51.12010140572825, 54.000113471861816, 59.03812731465986, 58.140755699526885, 62.99210394582441, 58.14356019420009, 49.54841944479173, 25.088891675395352, 21.382679400905488, 16.181550852714047, 29.706472542978105, 28.04256389217992, 13.427544928366139, 6.31471787729571, 4.904804758487209, 1.8257534888482865, 0.42512088172858764, 0.8713966992593581, 7.568980070852465, 24.355275092586396, 43.36988625987884, 40.166553220441266, 54.5689473613616, 67.31148858224192, 66.99523571998843, 60.38290408349807, 33.940343626083866, 10.363525652116346, 0.2556290306271084, 0.1517857205603392, 0.1910258012433206, 0.12734115724602055, 0.11848471352770445, 0.2399082475852582, 0.12280982378269396, 0.11036863250117149, 0.18590024402064664, 0.06743027768548458, 0.1654135207495382, 0.16452230002370574, 0.23196679630106498, 0.11600579090055921, 0.09251126088202001, 0.18469699568325476, 0.07607545733692185, 0.12549490833114232, 0.1426302344207802, 0.18924377347913482, 0.22378960444081217, 0.21085963374184025, 0.24103465730384474], [0.01800955307008999, 0.10406610375690846, 0.018280730958306984, 0.12087879957811487, 0.022369234957882476, 0.08396869104716086, 0.0029948007290987603, 0.06032342939907986, 0.03898811053424593, 0.07071756862945135, 0.02677059968963506, 0.037768004432080254, 0.038699567348005316, 0.054921869849485744, 0.0651175425117535, 0.0018695589354930206, 0.01460664509420073, 0.06803937121144227, 0.05643807659526506, 0.006584514696676765, 0.09686793395948988, 0.02386663041468109, 0.041114065811158194, 0.04794868475366985, 0.6370544481662013, 8.45265967230643, 32.89048398694685, 49.381149968793316, 36.05318323258431, 25.0299443352607, 27.714079118544056, 33.14093712837466, 35.57931384732647, 13.771171031459687, 1.3572800592068703, 0.26539727985378236, 0.13638335430333692, 0.5676077198117011, 4.422995025111783, 4.83829754014169, 3.0921161943866364, 5.460925265665978, 7.365209998623018, 13.498462361674155, 20.569468121374808, 31.23166657263233, 41.09710808723204, 48.291672429730816, 47.665834734516764, 48.43146570267216, 47.01743948844172, 52.253799746113444, 55.8060315347487, 51.025313408144065, 53.26977991288709, 53.03722650774064, 46.76422303722751, 44.80575223122874, 40.96022129058838, 38.723795644698605, 35.97993689198648, 35.44290950221401, 35.02443575089978, 35.66934008752146, 34.905631080750496, 35.83115354661019, 33.300314795586374, 34.24465679353283, 33.10103877898186, 34.53565351424679, 34.48368603183378, 36.78165366572719, 35.507703135090495, 48.69192284922446, 44.66835944883285, 36.84353689993582, 37.180182164715184, 39.56747785691292, 45.857386742868734, 47.84795822635774, 48.84328319180397, 47.482205052529615, 48.4179296032075, 52.28994830962151, 47.35177839955976, 51.27963596774686, 51.77891838935114, 49.83927888254966, 29.357552220744473, 47.962550270941954, 53.87814737135365, 54.814758377690474, 51.138038404526256, 49.05460480720767, 46.549739991464925, 41.68464383771343, 38.059875657481534, 36.85117375466132, 38.47242662983556, 40.65585713232718, 38.83786209167973, 38.77423340274442, 35.52219237050703, 36.86268591111706, 37.83032678788708, 43.78939551691855, 46.10088748316611, 48.72822046279908, 47.49781608581544, 49.12459950293265, 50.38471975634175, 52.0924844280366, 52.11387703495642, 52.21076742295296, 51.60435722720239, 52.81201970192694, 52.00346623697589, 53.28747764710457, 50.10759645892728, 51.51781797409058, 51.42209645240538, 55.32701599982477, 47.891288649651315, 45.3381629913084, 42.83114087197089, 45.77240467071534, 47.300732674137244, 52.82653639393469, 55.00884902092719, 57.51235277422013, 52.45473100293068, 39.80321622663929, 23.725948449104067, 21.843956016725112, 12.58954328875388, 15.770370748735244, 10.706887975815805, 2.6934209946663152, 4.027587261892134, 1.6723541266495183, 0.3533446332139354, 0.14631738495682517, 0.32017854192564565, 5.277097013688857, 21.038609089389926, 42.93632315051171, 32.04315593165736, 40.393556471793886, 50.26172207247827, 52.72230725134573, 43.86932165391984, 20.82004873983322, 5.060040402796961, 0.24464886094773972, 0.11527984598351103, 0.03165380308224309, 0.007301414509363954, 0.012586735538206996, 0.022337304413198464, 0.01382532734198556, 0.03938584806277387, 0.04611973410412189, 0.04222415785695757, 0.04620928595203065, 0.04651079517638972, 0.07357627934505863, 0.049990998551009164, 0.09364547703655497, 0.01883942355972625, 0.13626894673272488, 0.0312498813089464, 0.027505655307322744, 0.034658059012144804, 0.02098729469693236, 0.03804098454213912, 0.040437288417090336, 0.04430009142285393, 0.06521206243985123, 0.02005867355863654, 0.04312058031979588, 0.021647892314039414, 0.07754771744892483, 0.05323636533331968, 0.09621830672145852, 0.041417693268627896, 0.056625787288911884, 0.036895457099402146, 0.019056586503622033, 0.04504772811947812, 0.17234018132571252, 0.05425936850388685, 0.0681366490560674, 0.06155721017069394, 0.018839061583182024, 0.03280165177139063, 0.005608691529731357, 0.10983867585779199, 0.04562622792417965, 0.02847321286437012, 0.023629372984531428, 0.9814400814713972, 10.47844913698012, 38.93583113147367, 54.200040601914935, 40.504183000133885, 26.50822093409877, 30.448634009207453, 39.903338647657826, 37.935822856041696, 15.070972923309574, 1.757155524626855, 0.07906859350060264, 0.27594775081642214, 1.0007559159590353, 3.8324660158926442, 4.0672630167776544, 6.479116178327992, 9.951301217079163, 12.883237619553844, 16.482842814537786, 20.550630938622263, 32.91676582828645, 42.91222018580283, 52.05990914375552, 49.95154103925152, 53.18119318254533, 49.915780790390514, 53.71811466832315, 55.25746845429944, 52.12692283814954, 52.985698330786924, 54.29179268498575, 49.646149220005164, 47.727376722520404, 43.61821151548817, 40.02339847626225, 37.89878391450451, 37.76302283810031, 36.823634793681485, 36.7225278577497, 35.53803090126284, 36.61223865324451, 34.74140928637597, 35.930142402648926, 35.686163133190526, 37.03643906501032, 36.01637178851713, 37.87297864114085, 36.60068727308704, 49.684870858346265, 45.70639510308543, 37.09667882611675, 38.74161105002127, 40.239132758109804, 46.65703250515846, 49.60520359777635, 51.919696177205736, 50.192276508577415, 49.62617651108773, 54.73716212857155, 51.12605556364983, 53.51400236929617, 53.286869679727864, 50.52786273341025, 32.46184149096089, 48.72631026852516, 55.224465631669574, 56.2049836497153, 52.77208997357277, 50.866273064767164, 48.604359857497684, 43.58087839618806, 39.700826675661155, 38.14571672870267, 39.05458088844053, 42.242585305244695, 40.846539235884144, 39.75991718230709, 37.36309797533097, 38.14803877184468, 39.558079857980054, 46.869381781547304, 47.92216162527762, 50.795313465979795, 49.68929529190064, 52.000885317402506, 53.4020540022081, 52.89791176396032, 53.63873374077582, 54.558227523680664, 54.01768961260396, 53.515226148789935, 53.61410910083402, 53.12856281957319, 51.925473828469556, 51.40652464282129, 53.048930860334835, 57.021487759005645, 50.32573515369047, 48.159586614178075, 44.75766789528632, 47.730408714663604, 50.12469799287858, 55.400803627506384, 57.421534215250325, 60.03976337371334, 57.693519207739065, 44.11243407957016, 26.612638350455995, 23.424741798831572, 10.209122530875668, 7.594795150141563, 7.522663743265214, 8.465506415213309, 3.9063561154950053, 3.345342696674409, 0.7007087550816998, 0.2123735000890109, 0.44189989266376345, 6.485248313796136, 23.29851600431627, 43.16640154007943, 32.85032087756742, 46.211074706046816, 56.716033181836536, 60.48894143873646, 51.24202043779435, 26.894166469573978, 7.199260890483857, 0.22679988565223835, 0.03855846161323209, 0.048148131914316654, 0.022375928651120876, 0.025983994015522545, 0.020749165841768828, 0.08938523910699353, 0.035970792805235234, 0.02437846333299193, 0.007796310660083809, 0.00956919468608835, 0.03210295277136949, 0.03619977648580267, 0.12010941747576, 0.05655396654601059, 0.08163814432919025, 0.04470875336518211, 0.045494185009550665, 0.03643789959530677, 0.03410551043587827, 0.023915560450404886, 0.03237103374915258, 0.06386444866356832, 0.07547214011391325, 0.2770989664619969, 0.1546210732551352, 0.21001404121277795, 0.10244038857279286, 0.2046405932595653, 0.13298944690294806, 0.30332874446626634, 0.166030727146614, 0.1150655405475728, 0.15174203822689672, 0.10034188222620757, 0.05394704594847657, 0.29010321704610703, 0.23985122000017475, 0.2075586681284251, 0.2040884277272609, 0.3002477226959121, 0.07739983183602173, 0.2304030269865067, 0.23764479484769607, 0.07760492123423085, 0.15322886167034028, 0.23472143397215875, 0.9361481666564943, 12.820351239173645, 44.57105328959804, 61.474762501255164, 47.75862232331307, 36.28850583107241, 39.32390259158227, 44.58408732568064, 45.06460905075074, 18.377661397380216, 2.1544986098043384, 0.5525711911820597, 0.3084110943300109, 2.2965646511124027, 9.638866782188416, 15.615254736715748, 15.311351456949788, 14.471938744668039, 15.332478323290426, 13.695252576181966, 23.282744153853386, 34.496029730766054, 44.45897548429428, 52.176748706448464, 55.34039520448255, 54.90798527194608, 52.86428136210288, 55.61895016700991, 57.13362047749182, 52.081238992752574, 53.779103602132494, 56.649733358813876, 50.971525945971095, 51.03193829136511, 45.75512270773611, 42.32674760203208, 41.20582049892795, 40.03613441221176, 38.80993089368267, 38.19375007383285, 37.79096580320789, 38.763286067593484, 36.672023419410955, 38.187238939346805, 38.21532310978059, 38.0907250988868, 39.27371194285732, 39.825020682427194, 39.961491707832586, 51.894271373748786, 48.20034788500879, 38.1598098047318, 39.94327622075235, 43.13168856405443, 50.98393240282613, 53.51806594479469, 54.43459441584926, 52.28182508099464, 51.8766010961225, 56.756563032827074, 55.00592293277864, 56.48855532369306, 55.6493289239945, 50.759066843217425, 36.150638441885675, 50.854466730548495, 57.067230439955196, 59.20863666842061, 55.25435801475279, 55.00055713038291, 50.677756109545314, 45.587625734267704, 43.12813489667831, 41.08394853530392, 40.43725952025383, 44.9505308366591, 42.222973454383116, 41.1151078439528, 39.50810101724441, 40.33962388192454, 41.71721912199452, 48.170922263976074, 50.611522966815585, 52.92970257420694, 51.951753708624075, 53.39093800513975, 54.142817143471014, 55.22077075896725, 56.93538781135314, 55.1452886673712, 56.49749440531577, 56.169035127086026, 56.622190475463874, 56.31123673531317, 53.13943170732068, 53.90895366668702, 52.694776135106245, 61.185840714362364, 53.02989952025875, 50.203541555712306, 47.9035460564398, 50.66745988784298, 52.54042694645544, 58.007720670392445, 59.04747040041032, 62.261087894439704, 58.511239251782825, 42.35436893278553, 27.515487555534612, 26.343112684065296, 17.453243078724032, 27.44659700701314, 19.458890191970333, 11.152450596132587, 13.403360574476181, 6.827206919270178, 0.9590275970197494, 0.45511457227891494, 0.8837829926802266, 7.4017007889286175, 27.906849884217788, 52.52095630092006, 45.38267797039401, 52.65774111593924, 61.35562835201141, 67.84372283566383, 60.4127101744375, 32.76265786540124, 9.263740124240998, 0.5481615890899013, 0.20743914309047884, 0.2133633776177322, 0.08778398511030021, 0.08780941922938632, 0.10555893332967836, 0.16233799949048028, 0.11675603612656556, 0.1562544186749766, 0.2039347198461333, 0.091261028372232, 0.14364461144132, 0.11799965729756702, 0.23252407930070357, 0.25703389798441245, 0.1627920904467183, 0.22916835372246083, 0.20180790655074582, 0.23883190937340262, 0.11606652635119616, 0.16402408240302918, 0.15498919382451043, 0.14864381012176314], [0.020207037976492318, 0.03404415062358303, 0.025708679252514438, 0.07852278649806976, 0.034790975267007467, 0.010346439723376065, 0.021286892531920346, 0.02596825090867858, 0.05543136428440771, 0.051579742331898985, 0.07487767886730932, 0.10736598918635039, 0.0498050881639844, 0.035989994799057325, 0.016146095905212626, 0.07263712449780396, 0.0513818733123762, 0.08463259050322157, 0.03442931664927352, 0.058550085241515795, 0.037120035774404966, 0.07952240866518791, 0.050640679415195226, 0.006732738345876457, 0.2851706526933178, 6.8915538922432935, 28.686156195978967, 51.1064358680479, 43.99344113565261, 31.958138558172415, 18.409775803166053, 32.30601945231038, 33.56255662056708, 14.936210090114226, 4.224508875800717, 0.08771440900501706, 0.10805823389560947, 0.4008115329329045, 2.40866917756296, 2.138846391631711, 3.6054137349128728, 11.572829638758014, 14.149406167768664, 18.710029317486672, 20.526172999412786, 29.82207852025186, 36.48419680133943, 49.031878594429266, 48.044268931111986, 52.265457030265566, 53.006024053019864, 54.77566803655317, 50.418726705735736, 50.09707666212513, 52.57727761422434, 53.206767036068825, 47.67631138524702, 42.61769725430397, 40.45969155526931, 35.66855953585717, 35.72658315781624, 36.70371617040327, 36.5605261248927, 37.49357169674289, 39.746930214666556, 38.953524943320986, 41.38031498078377, 39.019542355691236, 35.80319489202192, 36.83603732816635, 35.61013583214053, 36.45178625660558, 36.41218600734588, 42.485242735955026, 39.38163988051876, 35.39631174456689, 37.417312975852724, 42.5574065023853, 52.51126804659444, 53.183377942731305, 50.53025145684519, 52.21484668793217, 52.03703780328074, 39.62838442094865, 48.902695332804036, 55.12748895152923, 51.55897148193852, 44.885733281412435, 23.5940783639108, 49.84650781077724, 51.71994555381037, 49.450344501003144, 47.629125272074056, 45.28648576428814, 41.65943084224578, 38.47443880573396, 38.092105773187455, 37.90955082062752, 40.071655396492254, 38.164575484491166, 36.90693024666079, 35.67366253945136, 35.73315312785488, 34.90643516663582, 36.31922583426199, 35.88673745432208, 38.70191274150726, 41.92326907188662, 44.49349234181066, 45.03924700521654, 48.14896483575144, 50.06090064202586, 50.027172180914114, 49.07081204075968, 49.23644981076641, 49.09661731412334, 50.53129088494086, 53.39612730087773, 53.00727136673466, 51.99346419303648, 53.3779392703887, 55.61380009497366, 53.05063316898962, 48.08197075320829, 44.63023008838777, 42.70318923457977, 48.81689348528462, 54.5324928529801, 57.94713181834067, 57.30525162912185, 52.7047428777141, 37.45614444055865, 26.61638225278547, 20.732142540716357, 11.571562713192357, 2.8958287787052894, 2.2471641148290327, 5.345531586677798, 2.292172822260088, 2.656209223693417, 0.967853420203732, 0.09031170753822212, 0.4457914048144895, 6.838929903122687, 20.83853683164043, 40.61378186748874, 30.017906773474913, 44.389361258476015, 48.40856298323601, 50.25671712813839, 48.63712733791721, 20.858946884832076, 3.242176026105881, 0.20396378522198047, 0.05537265513633048, 0.071336253576221, 0.006877445651503701, 0.07221391454579369, 0.028007663148004684, 0.0740726353720792, 0.030163488193084637, 0.04634908550689298, 0.03765165099814054, 0.030647109923583847, 0.011922929927917018, 0.04558294778689743, 0.01527612454317991, 0.05558829356525695, 0.029921549965717623, 0.02553317425472121, 0.024102529953984965, 0.0759670252521192, 0.04376294504430506, 0.026434924859072895, 0.012437197090607258, 0.05016423018288709, 0.015625240386373574, 0.016030517177686335, 0.1029051511338161, 0.08491540718222819, 0.002767888598159076, 0.02011426281364214, 0.021787117302958525, 0.03125837722402667, 0.04785960788027414, 0.03444853013441448, 0.040009083571813764, 0.034925986772343036, 0.02195662000186501, 0.013709731377480973, 0.019976880266180923, 0.01568001184252001, 0.02938143691168197, 0.059581048065616246, 0.014018411184811305, 0.05544225422425136, 0.06157355848699809, 0.008814130767038273, 0.06537916153789529, 0.016086270183985753, 0.3524576259716865, 9.326278394268407, 33.15181778323266, 58.829347395127826, 48.71149547638432, 35.11476793596822, 24.408642861150927, 34.04323916281424, 40.42810470827165, 16.391380986859723, 3.9992243580279814, 0.1425631864056472, 0.18017172963628847, 0.3405074204408354, 3.9962965538424835, 4.589946789126243, 4.666583038145497, 10.174000647760208, 12.33126796060993, 15.989441006414353, 24.83330415141198, 31.109316079847275, 40.82961028622043, 51.72961027391496, 50.460307751932454, 53.45369592789681, 53.68422931240451, 56.483950461110766, 52.19030049539382, 49.71542612198861, 52.997908669133345, 55.75316190719605, 49.821592915442686, 45.52985706636983, 41.679074072068744, 38.614859657902876, 38.24394072255781, 39.4087669926305, 37.50320896025627, 40.17066386438186, 41.533777713775635, 41.697489600027765, 42.07777515534432, 39.675260666877996, 37.280335964695105, 38.188254833221436, 37.13012879894626, 37.596981063965835, 39.13396181598787, 45.78349713356265, 41.32250708918418, 37.17623233795166, 39.27444150370937, 44.610716296780495, 54.57711373606036, 55.36802830234651, 53.452985978895626, 54.44183511118735, 53.78366924101307, 44.13339914814119, 51.75064594514909, 56.082978325505415, 52.511668128352014, 46.17125088168729, 27.48763676612608, 51.157226639409224, 53.78037052769815, 51.24952393193399, 50.52308920891055, 47.54425302628548, 44.85416604626564, 39.15676255379954, 39.02917961920462, 38.98345262773576, 42.92387354758478, 40.521347292007945, 38.36292582173502, 36.13776130060996, 38.24758068207772, 38.426993816129624, 37.63218041389219, 38.70674510155955, 42.16926051724342, 44.26581836515858, 46.57610224139306, 48.56965472621303, 50.41836584767988, 52.062356702743045, 52.31063881228047, 49.32280863485029, 50.98823524290516, 50.851807363571666, 53.53499097208823, 55.7675491609881, 53.89548816988545, 50.7491667809025, 52.439641644877774, 56.649003797961825, 56.04073439874957, 49.18454900864632, 46.37977584715813, 45.37675911380399, 52.0968617931489, 55.391746874778505, 60.60824424989762, 58.77929795172907, 54.44271372210596, 36.954065369021514, 29.902149784949522, 21.479330524321526, 9.406773274944676, 6.044616112785955, 11.623192871770552, 10.860596837535983, 8.893321291092905, 2.9355410606630388, 0.09781582220908135, 0.06272946642110906, 0.6566736534718545, 6.937619188139516, 24.442432119000344, 45.896943846056544, 36.28008057994228, 47.202665575089, 53.253333414754565, 58.186431700183505, 56.294476447566865, 25.079931020736698, 5.860866798508552, 0.33144852266676966, 0.06543513192164321, 0.009654770537670101, 0.03725741449142656, 0.02655798347756988, 0.033064400777220726, 0.02397705241286707, 0.0505522996818106, 0.04305507597183028, 0.03164538186073544, 0.0617575804672895, 0.0403511073560484, 0.03431418129513341, 0.019540859408856883, 0.0730482685650068, 0.030077774445676518, 0.012858235183352185, 0.03976682741795817, 0.04883477652084924, 0.061282958354680776, 0.017275357386097312, 0.01597846150323148, 0.03084060458105899, 0.16852618195116523, 0.08642653859550915, 0.19312269114438566, 0.250617298748224, 0.15580195182513806, 0.07132331435117992, 0.13279555004931268, 0.09151560705034964, 0.2166121113564699, 0.1287297069305374, 0.13300208735369867, 0.274260365554402, 0.10457382852872533, 0.1813879248596007, 0.1258292597448153, 0.07767226802365435, 0.1401667254826715, 0.16616634003097014, 0.09717787015101603, 0.15461089960750074, 0.11050433731607853, 0.1531040506257165, 0.12375500008103349, 0.11878420794082266, 0.5672680670695921, 10.603638445177387, 40.30946085529943, 64.64629688570577, 57.3755052012782, 42.96466619737687, 28.450574721059493, 41.654523957160215, 45.461168519912235, 19.12010919663214, 5.538157714951423, 0.42855405879597513, 0.47083472712866725, 1.3935015542853264, 8.146876106339118, 6.5046081523741455, 13.36014291932506, 20.83629715827204, 22.612050233348725, 27.65535339232414, 23.803919284574448, 33.98591764511601, 39.51831094680294, 54.59793759930519, 52.837471961975105, 56.949194554359686, 54.9950187436996, 57.340235248688735, 51.387085376247285, 50.5108827929343, 53.584950200973026, 56.949229855691236, 53.84401098374398, 47.57775398992723, 43.353098515541326, 41.177069525564875, 38.98112666222357, 42.02045756001627, 40.231429223091375, 41.90814441250217, 44.35906094889487, 44.20375470192202, 45.43637521805302, 42.37097624809512, 40.12874549435031, 40.927473422019716, 40.047211185578384, 39.770840983236994, 40.977891568214666, 47.08379814701696, 42.446611312127885, 39.37115930741833, 40.19348029167422, 46.33352718045635, 55.79782985871839, 58.569255029001546, 55.28250494310933, 57.35873314642138, 55.80130507869106, 46.73246752831244, 53.475735725895056, 56.64325360328921, 52.34109993903868, 49.19210741596837, 33.4510907050102, 52.67055549929219, 56.3243531411694, 55.87813254325621, 52.71210124415737, 50.870371941597234, 47.15656203608359, 40.718669968266646, 42.260130067025464, 41.2680685135626, 45.08373845008112, 41.88818347069525, 42.59946215537287, 38.657009447774584, 40.03662863085347, 38.82813853602256, 39.75956809136176, 40.08615639901931, 44.90538435597574, 46.751357663062315, 49.34243617519256, 49.926351578004905, 51.675308981249415, 54.50849971463604, 55.06678242837229, 52.05982285161173, 53.64702955369027, 54.0075110620068, 56.33834423557405, 60.33528258723598, 56.406683691086315, 53.228999030205514, 53.621714576598144, 56.62894087453043, 58.28769945329236, 51.93427954950641, 50.39384711173273, 47.554278604445926, 53.71193301293158, 60.09506487077283, 62.580588479195875, 62.48896191197058, 55.83084052608859, 40.09970426559448, 30.441169738769535, 23.97507190704346, 16.775594795903853, 12.722185100278548, 14.33859580947507, 13.828303294797099, 12.017376365200167, 10.499540701989206, 1.410882311963266, 0.4261718317866326, 0.9038543124352733, 8.612371721575338, 26.675231533665812, 51.79594147589899, 39.882993313574026, 56.30079538591447, 59.30449155069167, 67.06261419480848, 65.26545478451636, 31.528435061054846, 8.595676152936875, 0.582578671315024, 0.23079177064280357, 0.14297837541709024, 0.14280415170135038, 0.1283144949364566, 0.14314077073527923, 0.16293225389334465, 0.16821781623988383, 0.1051671712869598, 0.11658453968383613, 0.1891656478326167, 0.2242600743568713, 0.14589453506613934, 0.11151939615487091, 0.19861548027444273, 0.11352329064280757, 0.13425304764701476, 0.13545110190828002, 0.18911654159667032, 0.114205039947504, 0.11325105363803525, 0.09168929450454251, 0.30588312675395324], [0.02393791489603539, 0.03046924920542346, 0.02198370887086757, 0.03492481465781889, 0.04459125079935597, 0.04018986883062509, 0.01819165408491127, 0.015087406443912658, 0.026905454146946152, 0.05072811686043298, 0.04597821468186956, 0.005683508155221541, 0.05623269225320509, 0.06936541578221707, 0.09754843454086974, 0.02130967790200826, 0.040084638993345925, 0.08073939295906214, 0.04134730894058462, 0.051093360769652554, 0.01918105089346007, 0.03873765340916092, 0.040740440900046984, 0.05809567252834959, 0.19832307983550335, 4.634123463784495, 29.562307788479714, 47.080268013861875, 48.337595539708296, 26.268562155385172, 27.35288962241142, 36.977223042518865, 35.11626235900387, 21.59389707349962, 4.645392433289559, 0.35787472561482464, 0.14773340655430672, 0.5497248987517049, 2.9370982416214484, 3.7649992877437226, 2.4764472438443095, 5.453837052468331, 9.548856231474108, 14.207909299481301, 20.670123984736783, 26.16421141932088, 35.91383318747244, 46.3624232815158, 49.897698663896136, 54.154364601258315, 53.5744264818007, 51.804586379758774, 47.77577092570644, 52.21906323586741, 49.45255671778033, 50.706330576250636, 45.98471864577263, 46.16103702975858, 42.38561061120803, 38.18913344414004, 36.26039812641759, 37.84639281611289, 37.19790735552388, 41.29335211169335, 45.04182008004958, 50.776380185158025, 47.65952756327968, 49.90622197428058, 44.81475407077421, 41.12589436192667, 37.89570877628942, 37.24608190598027, 33.782119135702814, 35.90705925418485, 34.032656608089326, 37.2990809717486, 36.749878544961255, 44.948577496313284, 52.29489834077897, 52.29806369350803, 53.50800114293253, 53.599215861289736, 52.13195523908062, 43.04538073078279, 48.14937668461954, 51.814764930355935, 48.31948203425254, 43.6811145659416, 28.562829033021007, 48.87669786330193, 53.61998873372232, 44.714262946959465, 42.58174480930452, 39.72001098817395, 38.6025865616337, 35.271964765364125, 36.515760114116055, 35.598082388601, 37.090571695758456, 35.91457451543501, 36.64819894298431, 35.44464318983017, 34.95506863440237, 37.93491286616172, 35.6817465443765, 35.544377296201645, 35.091955431046024, 36.15386263016732, 35.65398793066702, 38.94548800683791, 41.479272457861136, 41.25842732767905, 43.89196941929479, 43.44572920953074, 44.13940037450483, 46.0062014672064, 45.1102222934846, 47.92211847920572, 49.497318806186804, 52.76661434481221, 53.78521073249079, 53.4165903060667, 56.75765737410515, 50.974538326263435, 48.21683360684303, 43.91083209745346, 48.4875673632468, 52.363226029180716, 56.63943713711154, 56.83299433800482, 48.27046809657928, 33.86351616151872, 26.923709761711862, 24.940871231017578, 4.018733001524403, 3.577045192641597, 8.983805468005519, 13.050489444886486, 5.702754585973679, 2.879849042623274, 0.1612881679208048, 0.02897948015391106, 0.5479101283896355, 6.078141100945012, 23.005885616425548, 43.597634761564194, 48.074526094621234, 51.971702883320475, 55.947644787449995, 54.910993729868245, 50.73263791299636, 19.91702695046702, 5.245179216707907, 0.05246335963508295, 0.06467774675618257, 0.010512648244208146, 0.01028439809282821, 0.050664451123485645, 0.03966737005318846, 0.08928886524611905, 0.05500804708008805, 0.03724893006766516, 0.02774371521457309, 0.04479986803245641, 0.019636936410660707, 0.009498302824795246, 0.019773445617888245, 0.08384989379274269, 0.00309018059089149, 0.05698186112567783, 0.01905968915971537, 0.028458883189746452, 0.07555926729354166, 0.006561356816335672, 0.09253997385742203, 0.05655468666865941, 0.04002390354270897, 0.026694825933044477, 0.024642673651537588, 0.04293489209826916, 0.13257445707436533, 0.06367404134042802, 0.015108883718869861, 0.012763769839019065, 0.06851005563212019, 0.07040454510359034, 0.060842526746132684, 0.03263071074240631, 0.06837936869311718, 0.028247594225010084, 0.14001332403671357, 0.03469095482761341, 0.01017589418728265, 0.013395846960315061, 0.05257370693969631, 0.09630193287927298, 0.02553606049097594, 0.03857852928640862, 0.09750904229980323, 0.0019646886216979774, 0.18648409494949927, 6.361836819879471, 33.499916368915194, 54.579388710760306, 51.67776046260711, 34.67345814551077, 28.00564262174791, 40.88506867808681, 40.329927782858576, 24.299887303383123, 5.552520944226173, 0.3681555029846007, 0.14570906517967103, 0.26873754577771314, 2.572665435652579, 3.556383372314515, 8.485098654224027, 11.477537616606682, 10.346547672825476, 14.439047709588083, 21.61499354147142, 28.44880573211178, 40.17555113761656, 48.428535692153446, 53.829255027155725, 55.53239914678759, 56.013877930179724, 52.57974478506273, 50.849065626821215, 53.01545735328428, 51.624894757424634, 53.507079385942035, 48.985704452760764, 47.1724868589832, 43.758938312530525, 38.92809229512369, 37.45739175427345, 39.4737998900875, 39.06367294249996, 43.375581541369044, 47.62166884637649, 51.95468764151297, 49.40487638596566, 50.41172135260798, 45.70769340761247, 41.37936968957224, 38.349852561950684, 38.958573033732755, 36.231027418567294, 38.818748381830034, 36.492692655132664, 40.21685761790122, 39.20945175232426, 46.58749672674364, 53.59360687194332, 53.59758415529805, 54.100153523106734, 54.285207025466434, 51.955483882657944, 42.86081752469463, 49.31223000249555, 52.04303118490404, 48.160614275163226, 46.99732165182791, 31.45796968090919, 51.11749695193384, 55.34087765601374, 45.525534614439934, 46.949233393515314, 41.85633382489605, 39.91256013993294, 37.6740752497027, 37.14148798296529, 36.82810629567793, 38.12096265054519, 37.93162591995732, 38.30500025903025, 36.42624770441363, 36.613921350048436, 39.33409290928995, 37.03929455049577, 36.7178092464324, 37.16235891465218, 38.05068946653797, 36.71490669250488, 41.17899148694931, 44.74034670860537, 44.896570790198545, 46.27093399724653, 47.07190944302467, 46.56436258746732, 48.949442140517704, 48.09101181645548, 49.72918187418292, 52.37049810348019, 55.1656771475269, 54.88532573946061, 53.93404114630915, 58.55476971595519, 55.13240368135514, 50.63080533858269, 44.95709296195738, 50.60785947307464, 54.216926405506754, 59.32477412685272, 57.10293577563379, 50.429940762058386, 39.213695756850704, 29.49896151019681, 20.01120109711924, 6.205981931378765, 9.017515297858946, 11.464315306755806, 11.528154823087878, 7.548044420057728, 4.4088450747151535, 0.5443772986050576, 0.026348716984953613, 0.7667614074964678, 7.054560732456946, 25.131304264068607, 46.76684318050262, 44.669865638979026, 55.4042866922194, 59.73142585446758, 58.562265365354484, 56.691918450017134, 24.316137683007028, 6.617149287654508, 0.06815660564649491, 0.05541046157539372, 0.06295438217479857, 0.0125138049254254, 0.03204001864838985, 0.045273149491197644, 0.02532393840562192, 0.060369463622449875, 0.06571683011228038, 0.007400486436146762, 0.10873624469123541, 0.008334780934326833, 0.01777683471089169, 0.03245060347140797, 0.045482843077831694, 0.047042015864844286, 0.03690869892917333, 0.04227489202974304, 0.028582619796056422, 0.02873371723258207, 0.043994498949858456, 0.07844498260847985, 0.05441668082869822, 0.0944582503589411, 0.15554848397451063, 0.17833484997672422, 0.16067505243324465, 0.36810616692227704, 0.17732899185390244, 0.12350217574426245, 0.11670588035016291, 0.18254860935191955, 0.1433537431782292, 0.1237520659642835, 0.08648876025671921, 0.22500201518977844, 0.15897429127606655, 0.3720445023669351, 0.16579077308697088, 0.18949779291306773, 0.1517900719397491, 0.1568715637850185, 0.13350658689535436, 0.09305059444159271, 0.08164434198049769, 0.1515189993886217, 0.1489957355924191, 0.31730797982984976, 7.103112811042417, 39.63676260363671, 60.9850702747222, 58.985096869930146, 38.366781511614406, 39.91937329692226, 47.49894180605489, 45.41781848476779, 26.460040500087125, 6.159733754973258, 0.6434339381033375, 0.5052340667574636, 1.208970217454818, 6.670188067420837, 10.639510481588303, 9.019368617765366, 17.754681148836692, 16.267656683921814, 22.352271656836233, 27.49690728802835, 31.507058143615726, 41.953930239523615, 53.173909341135335, 53.66045974916028, 58.063434016320016, 55.446444326831454, 55.019690452083466, 54.15499610285605, 55.327816163339925, 52.558873853375836, 56.469743636346635, 51.069600889759684, 51.22531898560063, 46.595023755104314, 41.00703870096515, 40.39979304036787, 42.12956220872941, 40.77470887091852, 44.612979504369925, 49.85929081516881, 54.597502216216064, 51.913279179603826, 54.202468549051595, 49.081210244086485, 45.02991960894677, 41.93131385311004, 42.02319145202637, 37.254397330745576, 41.01421271601031, 37.38717348344865, 41.46671302856938, 40.86570785891625, 48.311535312283425, 55.76121061078964, 55.548437718422186, 57.496271056513635, 55.736134898278024, 53.23494534338675, 45.40390191539642, 49.27226889518, 51.924163756832, 48.18367388940627, 48.242913446118756, 35.80874896818592, 53.62076144064627, 57.24436075456681, 48.407629459134995, 49.077201581770375, 45.30914921914378, 41.56329354932232, 39.54878776304184, 39.62547402228079, 38.127014867721066, 40.90089936410227, 40.56122210717971, 40.43400787538098, 39.79953312104748, 37.77117744568856, 41.86894816737021, 39.85406975592337, 39.777669829706994, 39.424205441628736, 41.07266387631817, 39.48903829820695, 42.766912060399214, 46.123680376237445, 45.953441666018584, 48.53435731703236, 48.48140924207626, 48.63740190382927, 50.85362734333162, 50.200493874088416, 54.572861886793575, 54.731427623379616, 57.5809040377217, 55.55852213213521, 53.96069757400021, 59.797258915439734, 56.00331498730568, 53.39466817917363, 48.144359973169145, 53.16945745098976, 57.4781693181684, 63.224449465351725, 57.884938716888435, 51.58979346675258, 38.571501778018096, 29.144832280374345, 33.173230002003336, 8.165760357533733, 7.129033794326167, 13.830082089670244, 22.08019448864845, 11.615449132457858, 5.061260259920552, 1.0610566576642375, 0.1939264093075068, 1.1698701929661537, 8.263601430000799, 29.502640693418442, 54.98170621933476, 58.94333147233533, 63.779245192004794, 67.15341706429759, 67.81228111636254, 65.18953338746103, 28.651050982936738, 7.866331521541842, 0.16917184085374878, 0.1978293361683046, 0.23807164371734668, 0.10227928028231668, 0.10442733719584443, 0.21107772365212443, 0.15232187485502613, 0.18967934042936374, 0.14943465800775638, 0.1173023564080077, 0.1464722879351147, 0.045705169454337134, 0.13784350256525701, 0.07137606716564587, 0.12833014611274968, 0.147224708850826, 0.19494861574663272, 0.15431906607362533, 0.06835923590246709, 0.1532556594259316, 0.10553511565611248, 0.24525973945856097, 0.1438983550836002], [0.03100837400603679, 0.010316727960842752, 0.025748351115673303, 0.07771778896811508, 0.034370243609432256, 0.04917260980413807, 0.03271618317211828, 0.05442224645746812, 0.029179808315670783, 0.04522372532876269, 0.056460488497489886, 0.037962797608587055, 0.07524300321576095, 0.009503464342185087, 0.018474909349254543, 0.09523340876424506, 0.02513607257917043, 0.04034842604831342, 0.06181079676494964, 0.009418959098477519, 0.11482339547646624, 0.07026355428200576, 0.015422098766711932, 0.048824330912001675, 0.10856135447900142, 4.386226727116493, 23.275156328755042, 50.667008815273164, 44.54083927216069, 36.675000498371745, 24.062550567811538, 25.38943152273855, 36.89785388208205, 20.694060248713342, 7.42761932073101, 0.9653908458928909, 0.028661869676603426, 0.15374499042668652, 2.386086621592122, 4.331241471152152, 8.368697416397834, 10.349957193097762, 8.86303569039991, 9.89395518456736, 18.371342459032615, 24.08518852726106, 34.93927717208862, 41.301671458828835, 46.567316132207075, 49.03103136247205, 53.09175922024635, 50.54059082461942, 49.810378859120036, 49.59073005184051, 52.5591484192879, 52.613869405561886, 49.39036361632809, 46.22582281789472, 43.42871396772323, 39.854399235017844, 37.20549321943714, 38.066735882912916, 39.861941952859205, 45.890864172289454, 50.014102843499955, 53.30475568771363, 51.83339618867444, 51.08019913396528, 51.26988495549848, 49.79266543542185, 43.91829636789138, 39.780289972982104, 35.86831800399288, 39.098629105475645, 35.72195476101291, 36.313428571147305, 35.244241452986195, 44.686182698895855, 49.13001237377044, 52.653540257484686, 55.329777348426084, 53.37326772751347, 54.36593724835304, 61.52505905397477, 49.62565091348464, 54.597627732061575, 51.11176636911208, 53.30768177586218, 34.171983118980165, 43.84877235658708, 54.36195996499831, 45.8375709287582, 41.38102885215513, 37.15331392903482, 36.63917749158798, 35.2912236029102, 38.214926950393185, 35.52447518994732, 38.19235763242168, 37.354876687449796, 38.72697668690836, 35.49049569714454, 38.08095055241739, 35.920156048190215, 36.62500204578523, 39.35340666001843, 36.868596922966745, 37.17462416618101, 37.67040783359159, 34.33738946914673, 36.543534417306226, 36.82119900180448, 36.27886464518886, 38.845502868775405, 38.774923739894746, 40.73807393350909, 45.117745399475105, 45.79035343662385, 46.05489769289571, 49.08610143969136, 54.183566647191206, 52.29834610416044, 56.732871916986284, 52.943140614417295, 52.16595042136408, 45.824332929426625, 48.60704668106572, 53.47038561298002, 57.617735093639745, 54.90566715117424, 44.227873356111594, 31.142648381571618, 24.516258970383678, 11.738342873511776, 5.670398464125972, 10.32464417719072, 14.196626601680634, 10.565083507568607, 9.195011373489134, 3.404067687449917, 0.07218795182603983, 0.1331002078950405, 0.8532878516181823, 7.681753606565538, 24.921118174829793, 46.47019824674053, 41.85697709360431, 53.27121157799998, 49.40731610021284, 55.97074362539477, 52.472550330623505, 22.957091331481937, 4.586501967522406, 0.012891943052020526, 0.053957418778971325, 0.0898893096394116, 0.017019554882520632, 0.04653617566932113, 0.040916652613950354, 0.05372702549662321, 0.018521129348946196, 0.08524080302806632, 0.07016144242257842, 0.04756837189497967, 0.013067445176984034, 0.022692876462374004, 0.024994380787135135, 0.052239926261526924, 0.035536999348551035, 0.025648531774359367, 0.016568093523082715, 0.0914736484147368, 0.01512498209898871, 0.01905551206530823, 0.028742036947439757, 0.08130987565363608, 0.07870634116472737, 0.03880061434521791, 0.059379252845481525, 0.048664295144619486, 0.01004670782300133, 0.03518115533816238, 0.019617161766115217, 0.05734011065214873, 0.05323003744706512, 0.07129781894505986, 0.06121586437427229, 0.025740632779836178, 0.09679091914046196, 0.06013152820448722, 0.05674821580009115, 0.0366914019198908, 0.07738369802433638, 0.11964738984862644, 0.026374595435035807, 0.06952143724887602, 0.06322568455230325, 0.10673978125616428, 0.047716429877665736, 0.07995352464457674, 0.16786610527384668, 5.479013766011884, 27.397779187848492, 57.29773636787169, 50.45499686271914, 39.18892598921253, 29.641655375880582, 28.676662098976877, 39.371916324861594, 25.199176957530362, 6.911188296733364, 1.1126673269656397, 0.09298495602824035, 0.6583140009353239, 1.4070678069706888, 5.099335197479495, 6.584331306719012, 7.653151192972738, 10.770179340916297, 8.232629414527647, 24.35608506202698, 27.725036259620424, 36.32539964491321, 45.62799869045135, 50.13290359127907, 50.401401596684615, 53.02581633290937, 52.36235526300246, 52.86799976902624, 51.54838108247327, 53.65339948285011, 53.28608912806357, 50.624427564682506, 49.461515411253906, 45.259958774812766, 41.8451903712365, 38.37543426021453, 39.79719146605461, 41.64971905369913, 46.19279253867365, 50.2424200888603, 55.17844446243779, 53.43437041005781, 54.7097957518793, 52.85456565118606, 49.637484704294515, 43.925580209301366, 41.44881133110293, 38.80415716478902, 41.50092786358249, 38.0883873662641, 38.58224122754989, 37.35071505269697, 46.87301389632687, 52.465741096004365, 54.71911922577889, 57.539213165160156, 54.49581476949877, 54.39904989734773, 61.78732049080634, 50.41779318163472, 53.83573478268039, 50.05588785294564, 52.6390157207366, 36.913288408710116, 45.250796118090236, 57.876560534200365, 47.93424252540835, 42.99476646607922, 38.8380072193761, 38.12405740061114, 38.106210616327104, 40.27155506995417, 37.789134056337424, 39.424687893159934, 39.38009446667087, 39.542139345599765, 37.0538269319842, 39.2098989025239, 38.43032783077609, 38.7628310726535, 40.57598983087848, 38.2405557170991, 38.26804760963687, 40.681607492508434, 36.49955680293422, 38.79289996239447, 39.649714269945704, 38.58247656976023, 41.0917854309082, 41.497837035886704, 43.09124500520768, 47.18723104846093, 49.09255373862482, 50.92730906701858, 50.59646498772406, 55.572058231599875, 52.84452438354493, 57.23832422687162, 55.55591375597062, 54.24252379325129, 47.21418165391492, 50.88523380218014, 55.339830383177734, 60.68286342005576, 58.005512375985425, 45.7371307957557, 33.46170856106666, 29.03685727427083, 15.878826245184868, 7.94153904722583, 8.91011982194839, 12.048513120220555, 6.602671329052218, 5.905794116758532, 6.008874495183268, 0.647904091785031, 0.13278128549216256, 0.9373662464561002, 9.142749713313195, 26.344883634198098, 49.836999985479544, 50.30303639750327, 58.44843818295387, 55.97048082659322, 62.12474630725, 58.44482960239534, 27.90329621684167, 5.768485665321351, 0.07407183864063795, 0.0477620427526774, 0.009047348998607168, 0.02632073945395889, 0.02477774069824767, 0.032503555468734235, 0.04115353466101712, 0.035155522036215955, 0.04977216553543845, 0.030571851361122344, 0.04482096992433072, 0.053856387103517214, 0.04241650721298591, 0.011955718491076222, 0.03503256109392932, 0.06597183779963563, 0.023837099640419888, 0.054918928071856506, 0.05593664140530652, 0.01796592627802203, 0.025448730298047586, 0.03422862076531014, 0.0574440879356717, 0.15883808084312948, 0.09393117420615689, 0.19769082747159467, 0.14011766521200059, 0.10690093551191593, 0.14504828370146214, 0.14956483166785012, 0.15187778900707924, 0.20393242158236044, 0.154255005801397, 0.15959748848071023, 0.15476728879636334, 0.2666797110390279, 0.11129519286295099, 0.16987921579951243, 0.1600250881165266, 0.174803966055474, 0.2380540390168467, 0.13405855324479843, 0.13398507009110144, 0.256127784509332, 0.2587084129693047, 0.0982195582060564, 0.16267046632785953, 0.28116808843708807, 7.116698920726777, 31.9232157353432, 63.87988928825625, 55.92446357973161, 48.90232663000784, 34.77470236439859, 34.57621082182854, 45.2066380746903, 28.307771029010897, 9.010200077487577, 1.5956084189876434, 0.24185994850291362, 0.9723452694954412, 5.0939213460491555, 12.396486190057571, 15.255007590017012, 18.302859837009063, 14.346622940032715, 13.142674949861343, 26.707910760756462, 28.32119141855548, 40.626913962825654, 46.970610310954434, 51.374161166529504, 50.45099212277321, 54.287368251431374, 53.50510643374536, 55.18582636310209, 51.67266530375327, 55.26065341887936, 55.65734232625654, 54.378053449815326, 51.170543086144235, 48.91727478273454, 43.82307298721806, 40.150793137088904, 42.22746064586025, 44.51616364140665, 49.5804024511768, 53.809247016906745, 56.039267432305124, 55.93328499024915, 55.79174234021095, 56.992501443432225, 53.224951144187685, 47.18979627855363, 44.03359443910661, 40.70046232592675, 43.24282500051683, 39.10090015780541, 39.76533789788523, 38.895371883146225, 48.242858532936346, 54.82416029899351, 56.968123912811286, 58.57950025989164, 55.14230766604024, 57.82572269439698, 60.1447573784859, 51.888356439528934, 54.697483431908395, 53.78475965992097, 52.93979875503048, 38.92174590018488, 48.13146322004257, 58.92593183825093, 50.6105855203444, 44.472335077101185, 41.088498484703806, 40.02728946747319, 41.01117680149694, 42.44328121985159, 39.305616501838934, 41.93709542674404, 41.657144100435325, 41.694477219735425, 40.07997082125756, 42.34032684756864, 40.869198768369614, 41.03043563904301, 44.38650969536074, 40.65423327107584, 41.87225864779565, 42.945317145316835, 38.84507925279679, 41.22906838693927, 41.70575403398083, 39.24955014259585, 43.273246903573316, 43.718769319595836, 44.85611546424128, 49.9578482104886, 52.12009006930936, 52.95426053385581, 51.59867763519288, 58.00323740128548, 52.677215683844786, 59.37650626705539, 57.32173735095609, 57.0028486559468, 51.19032359892323, 54.84311319166615, 59.83429785697692, 63.84713749731741, 57.7191165954836, 46.51771776137814, 35.08944903650592, 29.808860132771155, 16.108010334353295, 11.579351559762033, 20.143639925987493, 24.460473060607914, 19.87816999035497, 16.05652334228639, 7.080818549279244, 0.8318067462213579, 0.36230783128449995, 1.6406264420478576, 9.783608125102136, 31.523110443545928, 57.75397862157514, 55.245877850440245, 65.44392654972692, 59.87499244751469, 70.35715410786291, 65.16343001396426, 31.516297286556615, 6.481854973300812, 0.3090904611012628, 0.110663024768714, 0.16174037430074908, 0.21899416982646913, 0.10403814920855146, 0.11996714728734187, 0.13752386003973024, 0.14704737481811356, 0.15880884692793892, 0.16395055328405675, 0.13660461581762762, 0.1137942252981086, 0.10125631541614571, 0.08376782279341452, 0.2485006744222295, 0.15828511857938382, 0.19894733424148253, 0.10375806746343452, 0.2730655135406602, 0.09674688440657432, 0.10458310585348837, 0.13598589256646174, 0.23542310922376572], [0.05222892523893426, 0.03684792900457978, 0.04262217117713825, 0.008940223093715408, 0.052032799069439216, 0.07891207407679289, 0.010914597341099815, 0.07881071298353134, 0.010096934462536969, 0.014518380274004756, 0.029537577121969194, 0.03437084498845282, 0.008069615878705538, 0.04081251828240291, 0.041392381723609664, 0.031259539762451764, 0.019543259179279692, 0.0728915959236122, 0.020803533186535203, 0.030787654498952533, 0.03964419206303935, 0.0284650482823171, 0.022850451172299446, 0.06403486875276412, 0.091924337940591, 3.9367397754423084, 22.4857852151317, 42.74935553150792, 50.62989142633254, 46.66092741873957, 34.97407644025741, 35.871114653925744, 32.20733850233017, 30.437070861939464, 10.661879758681021, 1.6262519359588625, 0.09563938173795901, 0.21230613031694967, 0.6901427478559556, 1.8715347806292197, 5.791389365350047, 7.7167676245012595, 10.780561854762416, 5.560095531325187, 15.688959994623739, 21.728108813685758, 31.061200364943478, 42.554417656313994, 49.91363525390626, 51.26540168639153, 52.30276269297446, 48.21152663999989, 52.956668869141616, 50.17426106237596, 50.434278903468964, 51.21622300917103, 51.39754241512668, 46.61052888439548, 44.197851534812685, 38.88911962509155, 35.73730691786736, 36.84362319207961, 39.19017330292733, 44.763504382102724, 49.54708976130332, 54.151975877823375, 53.34986686706544, 50.682710063072946, 49.7489349303707, 48.060068238166075, 47.566426184869584, 43.81155690839214, 38.046037535513605, 38.71114992326306, 37.01619963492117, 36.92604787888066, 36.8928175587808, 39.526881325629454, 46.717499763734885, 50.792481514715384, 49.86476644392937, 53.19666693287512, 51.3042841419097, 51.31058739077661, 53.29832300063103, 55.37335488104052, 52.110692070376494, 53.552421985134, 33.69767442826302, 42.69234388105331, 50.678415067734264, 43.75856176499398, 42.73495258823518, 36.624421534999726, 39.776991259667184, 37.98152239091935, 38.9926701976407, 37.419823292763006, 39.02819510429136, 35.83777058509089, 36.009405659091094, 34.93130691589848, 35.17258367230816, 36.51594838788433, 36.62056192275017, 37.09559232957902, 37.96018077481178, 35.781257075648156, 36.8289888289667, 36.98104735343687, 36.92594981962635, 34.90634495212186, 36.107441379177956, 36.85038143588651, 35.29557743380147, 38.2223637642399, 40.90040514546056, 41.12865571052798, 44.979391636387, 47.87381841290382, 50.45252576951058, 53.57225348872524, 53.52416523041264, 59.42394733428956, 53.82734875525198, 49.88125216576361, 45.818841611185384, 52.06771466039842, 54.63287807280018, 53.54764453826412, 39.89672945391747, 33.60161950511317, 27.292083078815093, 12.540457767824973, 5.253429922365374, 10.419844023643002, 7.540580149619811, 5.3641662770702, 2.2384593948241207, 7.533113917996807, 0.7269554176638204, 0.018841530301518018, 0.9925040458479236, 7.001325834182001, 25.19936719248372, 41.91671871369885, 36.69717365695585, 50.23954106915382, 47.051783761670514, 54.59992231861238, 45.96265139118318, 20.901873303997903, 2.4682144340007537, 0.21432774441857494, 0.019093218912941315, 0.0840501491761496, 0.0491937883048048, 0.057478217152698394, 0.006826158458997886, 0.023403461316540357, 0.05705262083680399, 0.07006154455725225, 0.0379701980179356, 0.04443311109958638, 0.05211513436910126, 0.034519266862902916, 0.03445449795934462, 0.07162262490319629, 0.05443544232196385, 0.046308973143177654, 0.011141333511219391, 0.012446735842874455, 0.07588767386492222, 0.11102370662434448, 0.05887504058679747, 0.06347826374093853, 0.013194940402172508, 0.06510101033434754, 0.04717473293684664, 0.042813555262381994, 0.030361569802006407, 0.08160714075089463, 0.031804502153048114, 0.02507096085126602, 0.021810745369763147, 0.08482694700961152, 0.024988700245176593, 0.13331363999074505, 0.06149038815149858, 0.047492502377398556, 0.01319068478375313, 0.02830031256551945, 0.022451124011328625, 0.05211549826086529, 0.035090462019246434, 0.038031013907804605, 0.012682664110475491, 0.06655300742075329, 0.039044276270414555, 0.03325383133825756, 0.10101429291910703, 4.800064727183312, 26.14285215254753, 50.7964470309596, 55.565656923478656, 51.91275358200074, 35.3120788451164, 34.20451133481918, 34.79883670806885, 30.464672580842052, 11.775456340082231, 1.2833180086266611, 0.1563651337017936, 0.21341847466124644, 1.1370834684179676, 3.302445204988603, 8.725380109202478, 10.362888266963344, 8.828751233316238, 10.511614737972137, 19.536274633099957, 28.54267981744582, 32.99980632720455, 44.038450333379934, 50.42799918882309, 52.62424799703783, 54.35449569456039, 52.018124134309836, 52.711928659869784, 52.63879214563678, 51.08497265846499, 53.66556667512464, 53.148096223031324, 48.30695790629233, 45.25668751808905, 41.725820879782404, 37.56848504466396, 39.017385052096465, 41.524560143870694, 47.93799231129308, 50.08150093017086, 54.60906928585422, 53.52711093041205, 52.54477685497653, 52.185570116966005, 50.994950340640166, 48.530140769097116, 44.895499983141505, 39.109345020786414, 39.18150486484651, 37.47066505493657, 38.4308377388985, 37.59969926649524, 42.17516368435275, 48.24022662255072, 53.755530157396876, 52.341280368066606, 55.40281188103461, 54.128088643473966, 52.448788612119614, 53.541239307772734, 57.252523206895404, 54.272051395908484, 54.2065909601027, 35.264865275352236, 46.00271448012322, 52.453401319442264, 45.51053154853083, 44.617384326073434, 38.02220521434661, 40.34083197193761, 39.12735654461769, 40.698006922198886, 39.69913221174671, 40.34984950096377, 39.05820515847976, 36.96184735144339, 37.269855391594675, 35.95123690943564, 37.54138146677325, 39.369884537112334, 39.17294625313052, 39.351308191976244, 37.712777276192945, 37.77721789575393, 39.808884051538286, 38.06688101060929, 37.34443926042126, 38.276480705507346, 39.08866628523796, 37.81658280280329, 39.90599016989432, 42.98805529071439, 44.21343903387747, 48.00896759956114, 50.47395367776194, 53.381657677312056, 54.840304774622766, 52.88545823866322, 60.1845851252156, 56.30918925808322, 50.397051688163515, 49.27630109171714, 54.24558324198569, 58.72205095906412, 57.3296134702621, 44.16955947875977, 31.87169736431491, 22.09370509270699, 11.704762481874036, 8.261919713789418, 11.607815219509988, 16.607678128827004, 4.6235713074284215, 5.86567513404354, 3.686599688183877, 0.5727500083946413, 0.20808516971526608, 0.7827048003673555, 8.950885015149272, 28.209356800202404, 50.382413402680434, 38.45690188869354, 58.04233166479296, 50.51686440744708, 59.61068353345318, 53.66538232372653, 25.3359813844004, 3.3905747340571497, 0.2008261648757804, 0.012077295687049629, 0.05929385319412236, 0.01991598393707987, 0.07236625879041611, 0.03593995776628295, 0.05650696705185598, 0.053048696774508686, 0.08149610396714942, 0.018583567429994865, 0.032202548031965574, 0.05694986929395988, 0.027895898580731406, 0.050478881645587184, 0.034235998192020965, 0.055336288942564885, 0.027417107034594785, 0.045714385492066224, 0.02186822686194172, 0.05026907697620411, 0.02439809625127143, 0.05086836840717062, 0.026291143562224124, 0.16882556911197402, 0.18972412592941718, 0.2528286268634181, 0.26067018028228517, 0.10576215347335224, 0.16096661017546732, 0.12671672663981878, 0.1675013248478213, 0.14276385547653322, 0.1849929201266458, 0.1738280160052161, 0.22548376192008296, 0.14838963747024536, 0.1915272823985546, 0.1603466458618641, 0.1171862404613245, 0.09951642248779537, 0.21425429190839493, 0.1017841729786127, 0.11908708846256619, 0.07636603448660144, 0.1678952319367278, 0.08546815494135504, 0.1782839664167935, 0.22433580980906564, 5.915468642788549, 29.58906423661017, 55.474344145867136, 62.75949562749555, 57.81653650345341, 46.21183564586025, 47.219578835272024, 44.06329854842156, 38.036466952293154, 13.566920468884131, 2.108350944134497, 0.3485937542732685, 0.419619144691575, 2.238676105776141, 6.758604174660099, 12.901174618351845, 14.332749516733232, 21.82090032485224, 11.444111177998206, 18.607680951395345, 25.725113845640614, 33.23596439053936, 44.98384744890275, 49.74009783037248, 53.76962715579618, 55.2622341340588, 53.0381521871013, 53.69083066140452, 51.45732325892295, 50.48755253514936, 53.52791501629738, 55.802438643670854, 50.90523004531861, 47.857132650190785, 43.67268147007112, 39.6566568651507, 41.45845643935665, 44.268540490058164, 49.150526369771654, 53.03794430148218, 58.360027959269864, 55.50393058407692, 54.435123935822524, 53.25388254657869, 53.26985443792036, 51.66690726434031, 47.464252364250925, 41.49569934414279, 42.54294472355997, 40.63666105270386, 40.58954161982383, 40.58104968840077, 44.416778625980506, 50.302969717210345, 54.586766689054436, 56.074525617784076, 57.596103222139426, 56.22131639911283, 56.20529351695892, 57.496498553983635, 58.71179788343368, 58.25393176847889, 54.3920406218498, 38.5581264957305, 48.709726487436605, 56.25364065170289, 47.44984157623784, 47.99562369623492, 40.23379048993511, 43.379790244563935, 41.840667878427816, 44.198836049725934, 42.72748439542709, 42.83892285439276, 41.08718449069608, 39.73769303291075, 38.55555734326763, 38.89344992176179, 41.47582077210949, 41.00559134637156, 40.124552480636105, 42.43520898203696, 39.57283189219814, 40.207165441205426, 41.96261436708512, 41.309743696643466, 39.23969322635282, 39.7183596703314, 41.501202429494555, 39.05521631240845, 42.624804589056204, 45.22162545111872, 44.727524480512066, 49.23815996416154, 53.65744736886794, 55.02964542758081, 55.75786875140283, 53.26747748159593, 61.304786589837846, 59.212209947647594, 54.580777229801306, 51.307386736716, 57.42731578888432, 61.131908124493016, 60.41431834620815, 44.21732610271823, 37.09809087937878, 30.2693405074458, 17.22244297304461, 10.489442559980578, 23.075882273335612, 19.83920124269301, 9.2747914022015, 12.164288740004263, 11.586687372576806, 1.7704023492913095, 0.3415580334201936, 1.5711790395359841, 9.6043126621554, 32.282330297654674, 51.50115966796876, 48.66261489929692, 60.75782775878907, 56.951351857954464, 69.08737305671939, 59.913655250303215, 30.05372193551833, 4.2208272410977274, 0.4004050160367643, 0.12487083778626497, 0.21982440995352887, 0.13264662255683254, 0.10841936774311528, 0.11938714978074837, 0.12935268963056226, 0.18245367573634272, 0.18272715380355237, 0.10036998999214942, 0.14672380992241446, 0.1540164919870515, 0.15783006235236124, 0.08824254235913677, 0.15715284062729729, 0.15795718698251635, 0.11736088552542272, 0.16033516986475838, 0.06473982286068701, 0.20306157879531386, 0.2563633718678067, 0.17174894530926982, 0.16206069098364922], [0.07537891487440757, 0.0021239883461666685, 0.08727695747849443, 0.028592000542689237, 0.03121653541682228, 0.010686183438426065, 0.05572588295645772, 0.013017002117609786, 0.03792121435605711, 0.05171184653356191, 0.07720113927198034, 0.040920463901373653, 0.0351069750444543, 0.04001710451238098, 0.027919243195004044, 0.035630588479820764, 0.037297572820417346, 0.011079269855643713, 0.04506274344279401, 0.025582596501936356, 0.08760460562282994, 0.012134869109779116, 0.016469369687500502, 0.016903827725459012, 0.10967681680115, 2.0262031521528, 18.049678687126406, 43.02168569257183, 52.91556242973574, 49.264271182398645, 29.123237671390658, 21.19886144515007, 37.74423468497492, 29.805231940361764, 13.614195815978514, 3.031417025673774, 0.13830246584069344, 0.36008292809128767, 0.48333743527050943, 1.8143684417009356, 4.537892033976894, 5.003989733034565, 4.134543922639662, 7.291513566047915, 21.065108622274092, 24.41828404703448, 26.48042701905774, 38.91420710471369, 46.573878257505356, 49.68113676194222, 51.22409520610687, 56.297932055688676, 54.48882118348153, 53.59455216315485, 55.36151324549029, 53.453276234288374, 51.21438733993038, 47.63883706062071, 43.872043778819425, 41.26364015763806, 36.60586872408467, 36.54476211917016, 35.64256598872524, 39.71825768870693, 44.78563439461493, 50.58191299438477, 51.338950049492624, 51.98510169982911, 50.42404936205957, 53.71428643503497, 49.30372630396197, 48.641065397570216, 42.32146416940997, 38.76918923470282, 36.048111607951505, 35.37971227399765, 36.042063313145796, 37.691737682588645, 37.98540161501977, 45.2755384291372, 45.708964255548295, 48.80658941884195, 47.95430544883975, 52.15088459753221, 48.126775987686656, 51.57986987021662, 46.72164570900702, 57.27009542526738, 38.902039912439164, 42.91844890963647, 54.82044581444033, 45.19142712316206, 45.78258714368267, 41.347237633120635, 42.91004719272737, 43.509275528692434, 46.32343492200298, 44.50012899214222, 45.27619346495598, 39.23692011064099, 35.36029261927451, 34.8494823517338, 35.659977389920144, 36.61271718240554, 37.25271463394165, 41.51509938701507, 45.86031675338746, 44.46996988788728, 43.00403502679641, 38.63029810690111, 37.07403890548214, 36.753173335906, 35.942909717559814, 38.55374520824802, 37.45637978276899, 37.20981959373721, 39.17457011438186, 41.88827760757939, 45.90240770770658, 45.4122644086038, 48.642748094374134, 53.84433261809811, 54.28355962999406, 52.54587119625461, 56.41304577550581, 52.52980909039898, 52.53434727268835, 47.434171707399436, 53.56312613333426, 47.58117821908767, 42.33631426288236, 25.067273532190633, 19.020541790992983, 12.01547891862931, 6.75157577760758, 4.2211174964904785, 13.37665217538034, 2.7866692168097345, 3.311866738142506, 2.878361728883559, 0.2250216423623985, 0.28779481026914816, 0.8276481145331938, 8.443429354698427, 26.35180465636715, 37.78992637511223, 45.87448827682003, 46.08316621472759, 39.954682473213445, 49.06000198856477, 39.95278012367987, 22.793416707746445, 2.041457249752937, 0.070561692719498, 0.08093132862761136, 0.057767392361476544, 0.04058730758486256, 0.03743810015880773, 0.05704233993686015, 0.051552887119713335, 0.10280162967260807, 0.0473598197793528, 0.026671301288109635, 0.019726978554841013, 0.09554359010390698, 0.06358865701082735, 0.024934179682825363, 0.017875388091910752, 0.027513413862775893, 0.0390730811763675, 0.07474408079419406, 0.056191706549256086, 0.03085210164558263, 0.028485412814564286, 0.03306206037861205, 0.0430850223487904, 0.060274878576878584, 0.005346563533924881, 0.08040047566136045, 0.014795727085232016, 0.04717659070006302, 0.014725846459998962, 0.02986076471936559, 0.035671972549490394, 0.06474523144143243, 0.035182622396537376, 0.06311020828903684, 0.01938275609826369, 0.017746913231789105, 0.05944865275054209, 0.019512156009553902, 0.05886396295541237, 0.05675119971255622, 0.006807764687935912, 0.0175671162264001, 0.0346435071720231, 0.03098794627153585, 0.054252795469496524, 0.030002929570694125, 0.04748644645235712, 0.010625909555763488, 2.8247500379239363, 23.495162071720248, 48.042523476385306, 59.460986275826734, 53.13453266697546, 36.13896939062303, 29.887144757855324, 39.15531127683578, 37.49039457690331, 15.461852800461555, 3.045340704341089, 0.22540381298430506, 0.08482045824489287, 0.3359671237487947, 2.6938664288290086, 7.164356208616688, 8.983169063445061, 6.3312290945360745, 8.514688034211437, 17.320674811640096, 24.772919262609175, 32.144700211863366, 40.11168710647091, 47.74911842038555, 50.79487416052049, 52.99331557366156, 54.90706743732576, 54.617133678928504, 52.20310311163626, 55.64736773890834, 54.38109328669887, 54.83637063733993, 49.536024755047215, 46.613294155366965, 43.357432734581735, 38.47269335100728, 37.93694465391098, 38.372272829855646, 42.19938039779663, 48.161010434550626, 51.999798820864775, 53.82770961330783, 52.492570107983006, 52.54622028719995, 54.405423748877745, 51.26284822340935, 49.71616744995118, 44.211419013238725, 40.18127387569797, 38.68714894017866, 37.95789011063115, 37.911684590001265, 38.87347721284436, 41.580983438799464, 47.14462234127907, 49.594232728404386, 52.1203685575916, 51.0141150413021, 54.01779551659861, 50.811516777161636, 54.08832365466703, 49.24555363193635, 58.98577936234013, 41.29498774005521, 44.76894470953172, 55.17944466683173, 47.44793138196392, 47.865597125022646, 43.106659919984885, 45.65798913278888, 44.35471496274395, 46.73553482178719, 45.466287212987105, 47.81990935725551, 41.057209737839244, 37.854563113181825, 37.841246666446814, 38.253150447722405, 38.01503904404179, 40.00678331621232, 43.251426758304724, 45.93717951928416, 45.55879239113101, 45.39211911539878, 39.94537861116471, 38.38687973637735, 38.06942270648095, 38.3368577495698, 39.95006192115046, 38.92221658460556, 39.65821012373894, 42.88954496383668, 45.02937047712265, 48.38335391013853, 49.43465109794371, 50.834858802057084, 55.19604413740097, 54.65523558278238, 53.57941181428971, 58.499746707177934, 54.87844590217837, 53.63314436328027, 51.593119636658706, 57.0163219974887, 53.03851304515716, 45.85120116510699, 30.24400003494755, 15.571086887390384, 8.736413736497203, 12.459839332488276, 9.843597835110081, 17.036444179473385, 7.071436239827064, 4.0272344937247615, 1.8972498394789237, 0.16496885267476882, 0.3201200740952646, 1.280637191187951, 8.958558151798865, 30.7344885026255, 42.65711315216557, 49.341004510079664, 52.30311570628997, 47.830405619836625, 55.52007505970617, 47.501691387545684, 26.43459216240914, 2.568801901032848, 0.06404337998960288, 0.028795565425929044, 0.04940443184046496, 0.020231776870787144, 0.01916575594805181, 0.0309274617146941, 0.056139375083148486, 0.05223837110304064, 0.027302751174917626, 0.03057787664264681, 0.03346353258577085, 0.020378210747073737, 0.09082143179952137, 0.015040914483007886, 0.08755778998977716, 0.003965679277297891, 0.0789388488497465, 0.016435644581853863, 0.013349064843608968, 0.037944016963123314, 0.023431457999733188, 0.019966369539859797, 0.0945757988900427, 0.14556830418446373, 0.12694247742934575, 0.15385654815022023, 0.07238197891462235, 0.13106275109514115, 0.16019846913554978, 0.18882130663241112, 0.1409573741858044, 0.1250411161491948, 0.1600913547219769, 0.22559133598641043, 0.152890557242978, 0.13456106095785095, 0.08309532016996415, 0.11887390151499741, 0.14903486736359137, 0.1163529972696016, 0.09837733401406197, 0.15793383662258426, 0.1416991464793682, 0.16563032363210956, 0.13846709813562133, 0.10475783518725827, 0.10444357059895994, 0.23961500444960213, 3.1656089088609143, 26.25893665898231, 54.18098964998799, 65.3723354493418, 60.93224379324145, 41.21732088827318, 32.12544725787255, 47.91470127720987, 40.3031026932501, 18.0728736231404, 4.061310574893029, 0.3602160435290106, 0.8291410053929975, 1.198966334904394, 6.303858795473653, 13.874830449781111, 12.409335874742078, 11.784699405393294, 13.01216494652533, 27.27915494672714, 32.90166078075286, 32.13077383656656, 40.19634754427018, 48.16639977116739, 53.654693865006976, 54.83036941097629, 57.85126909132927, 58.084524600736565, 55.250549393315474, 57.24830665896016, 55.65907209150253, 56.30143473225256, 52.0380497747852, 50.22877416303081, 45.58318953360281, 41.08075572598366, 40.107203837363954, 39.693111373532204, 44.0952423311049, 49.906457316490915, 55.600801360222604, 54.736114855735536, 52.42659584168465, 52.009840088505904, 56.64516379756313, 54.73552257783952, 52.513766596394206, 47.84091364952826, 42.81703210646107, 39.3854171229947, 38.642512367617705, 39.76636555887038, 40.44316660973334, 41.770320169387325, 48.77291194854244, 51.05513518856418, 54.09663123469199, 53.74619883875693, 56.31195452905471, 53.946023987185576, 55.516293894860056, 52.43652728296096, 59.13750448534566, 44.79214552910098, 50.0903223406884, 58.2824081759299, 51.41766809648084, 49.460424992346, 45.989186225398896, 48.250150219086684, 48.15484839100992, 49.95346300063595, 48.179892724560155, 50.956264003630615, 43.58837404558736, 39.04819919217018, 38.41150829868932, 40.321820243712395, 40.427269243424945, 41.74243211746216, 46.589065674812566, 50.477601482022195, 50.28560146208733, 48.49028556577621, 42.631398093315866, 41.77422685007895, 39.803106400274466, 40.437255597883656, 41.64315692840084, 41.26352248653289, 41.62409813173356, 44.11877655213879, 47.934093475341804, 51.84497894779329, 51.140642858320675, 54.84212867675289, 58.35646252478323, 55.05663525673651, 52.55520251489455, 61.89702526215584, 58.467257715040645, 58.71382574881277, 53.29827200981879, 59.592966187384825, 54.803791430688676, 47.42731540433822, 30.42440160628288, 23.966156359641786, 20.42122410189721, 13.40276143243236, 14.348242878913881, 24.24914360046387, 11.296620253593693, 8.922926360561002, 6.740827502742891, 0.4676329086144125, 0.6174605544055662, 1.6570763722542794, 11.156248431051932, 34.10859369462536, 48.61184373978646, 56.973211226924775, 57.34618940661031, 54.75236131298927, 62.36656435074345, 56.603559217145374, 31.192313432693485, 3.778426786584239, 0.17281619771834345, 0.15064378990040672, 0.14424038269827444, 0.09215656217307815, 0.18055705654044307, 0.1458506841933535, 0.16807547710355253, 0.24708649143576625, 0.1646606708245893, 0.2850173431779108, 0.12551514837410183, 0.16628670776563306, 0.16443302013701008, 0.10084905541471897, 0.160043305687366, 0.19217778297681964, 0.18269841018463337, 0.15703135440426488, 0.09634011470141912, 0.08498870647482334, 0.10236887426506128, 0.13386808846506382, 0.23899943748068428], [0.014777695290714264, 0.007531183430053775, 0.06691955750988376, 0.0529257090191447, 0.016946125354978348, 0.024913861115853635, 0.042179383848223, 0.029419222283327294, 0.009179164002078676, 0.05521676007417902, 0.04399232709059312, 0.0641781501772423, 0.03729490300400123, 0.033998947605610855, 0.0859132367036035, 0.10778497033301862, 0.08395336162779601, 0.06151539709178671, 0.03590079152115411, 0.05466960475689942, 0.028929981297903487, 0.046256641677070054, 0.016629851701098586, 0.03503288285085752, 0.02899940035516216, 0.6417033148388709, 12.087043543015758, 42.63120981954759, 48.29095463598929, 52.557712831804835, 29.17146517384437, 29.805114269256595, 34.51764199041551, 32.404417991638184, 18.322281452917284, 4.719918937452378, 0.5350621597420785, 0.03624957603132052, 0.42635796050871577, 1.6116390233078313, 7.943840007628165, 9.522625380946744, 3.6540241587546567, 6.261900221147846, 10.33274289100401, 15.358858223884338, 24.22327753036253, 32.29226762248624, 42.252661874217374, 50.64307059011152, 56.30038745941655, 54.177757616966005, 51.68203976846511, 53.66518620521792, 53.33300067532448, 52.24391537327921, 52.690979280779445, 50.553546413298584, 45.762128060863866, 43.42365803257112, 37.1881994893474, 36.612050379476244, 35.821175036891816, 36.78365799688524, 41.68447517579602, 47.55001498806862, 49.15950467509609, 50.36871648603871, 51.258792492651175, 52.044176516994355, 49.42923038236557, 48.05219604123024, 46.833829418305434, 41.43532230008034, 36.29196928393456, 36.60013421889275, 35.82963951172368, 37.85355898641771, 37.358563715411776, 39.006618145973455, 40.11917098875969, 44.28667360736478, 41.911372523153986, 45.14243279733966, 43.674430847167976, 47.74183850134573, 45.68456711307649, 54.08150657530754, 40.65482162660168, 38.810028952936975, 54.561651752841094, 46.53962419879052, 49.5461013240199, 44.678671360015876, 48.80347505692513, 46.79096183469219, 48.000040285048954, 47.37891335641184, 49.67577095954649, 47.338846345101636, 40.54630533341439, 35.674576451701505, 36.692380520605276, 35.362367553095666, 42.74753947411814, 48.39342655674104, 50.66368264536704, 50.07646068449944, 48.903197396186094, 48.52344528321297, 41.259862915162124, 38.35956042812717, 38.32525537860009, 36.288576433735514, 37.089167487236764, 39.35020208358765, 39.27231557907597, 40.78334593003796, 43.7197656016196, 46.365592556615034, 46.32373694450625, 54.72254345493933, 54.63450193405152, 55.24426575629942, 58.342447896157545, 54.129033934685495, 52.3079716005633, 50.64045436920659, 51.487792230421505, 49.887222013165875, 46.423302388960316, 31.87015587283719, 12.485489672230138, 5.144793506591551, 9.179515069530858, 11.534385508106602, 21.80480487885014, 3.2359068528298414, 3.5744203915519104, 1.2884563135523952, 0.1406390340097489, 0.16864739238254486, 1.2490089141553449, 10.967337277627761, 27.8988855115829, 43.60067459844774, 43.30856000223468, 38.66782342233966, 41.61374699684882, 46.49268519493842, 44.23724389845326, 18.025842443589244, 1.4709014397475029, 0.039622848853468895, 0.022436587492965405, 0.03555201084142731, 0.023290635717491952, 0.03064498402959397, 0.025357987183416565, 0.04102515747710582, 0.06883375842364566, 0.055391301716407465, 0.02206275573811464, 0.02636419196102408, 0.062049256953140425, 0.06349347058623549, 0.028725416669922493, 0.019397112585964705, 0.005314016767266777, 0.07682348090794779, 0.038529871211897944, 0.02668803073315611, 0.004680306921082159, 0.024220518985643022, 0.021945084632945158, 0.021055692942031932, 0.02827093117840348, 0.03986831874616685, 0.04597462939038392, 0.032074691787842786, 0.04578019627520154, 0.028531793692720034, 0.016291070384003462, 0.05194745687467437, 0.021128829440943176, 0.0478241648224573, 0.021605479771331437, 0.04228661700542416, 0.03569633414548251, 0.04709317138598812, 0.02752547400192388, 0.023080576323874058, 0.027897861681037375, 0.04452785319318214, 0.04444105926180079, 0.08215359126728389, 0.05202072552375255, 0.01480758325347016, 0.03524604681578856, 0.022267977286490704, 0.046872449963684046, 0.8894418083852338, 15.89288401988245, 48.39465425860498, 54.503867395462535, 59.57680602227489, 34.22473115305747, 28.715228803696174, 42.52184629440308, 35.89611191903391, 19.845922223983273, 4.831860440392648, 0.29089418750616813, 0.07054605686496343, 0.8021881936057922, 1.6626113268636888, 6.150637778543658, 9.165040543002467, 8.981651106188375, 8.585442689157302, 9.51816172369065, 17.898487006464315, 24.67057481888802, 35.19930285792197, 43.9790617266009, 52.18644088314426, 56.370633186832556, 56.449723858987134, 53.804885341275124, 55.26902767919726, 54.76611314281341, 53.3374604102104, 53.1611341814841, 52.79777757583126, 48.51150558840845, 46.02172620834843, 39.48587294547789, 38.33623017034223, 37.26439545231481, 39.55323965318742, 43.53083287515948, 49.70484748963387, 51.655304893370605, 52.99839504303471, 52.5267457192944, 54.184766892463934, 52.19989069046513, 51.58288225050896, 47.351919604885964, 42.8816492326798, 38.77526890846991, 38.751605249220326, 37.698425323732444, 38.70784728757797, 37.83109949481103, 40.387712140237134, 41.94736811422533, 47.03932239163307, 44.12408351898194, 47.098044195482814, 46.30214821907782, 50.294505242378484, 48.685980458413404, 55.63550256913709, 42.47543288815407, 42.45501695140716, 55.85106034432688, 48.321976661682136, 51.00763136340726, 46.08837512231643, 50.9166088411885, 49.174303777756236, 50.51665652182795, 51.89077261955508, 52.08008581592191, 49.63288768645256, 41.54305804160334, 37.595376814565356, 37.68625028671757, 38.40021579496322, 44.22810085358159, 50.30453082053892, 52.465717561783336, 51.56430590537287, 52.67840023963682, 48.440804866052446, 42.27265419498567, 39.06170391267346, 39.90733946523359, 38.85679929487167, 39.731919304017104, 41.849316704657774, 41.87453754486577, 43.02547862452846, 47.00952022306381, 48.6350877054276, 49.639869505359286, 57.31850924030427, 54.179291263703384, 54.428169573507006, 59.890658393982925, 56.594074926068714, 55.183300356711115, 52.07177823589694, 54.601746220742505, 52.70633536000406, 44.00561617266747, 31.432805715068696, 13.526878952980043, 11.069608176908186, 15.521050191694691, 9.610550211321923, 11.008760448425047, 7.996538521782045, 5.323991400580253, 2.1094207705989962, 0.19815962731597886, 0.31509205518711003, 1.6087736093228864, 11.1499834252942, 34.19725102763022, 44.89981459033105, 47.60589307354343, 46.23424414665469, 44.82685850512597, 54.456285122902166, 51.5466199382659, 22.08077499943395, 1.6918380101842267, 0.050376873208029624, 0.002130302586480074, 0.005325943798637919, 0.02494276944367636, 0.05670319281278118, 0.015800871788674307, 0.05501943114664286, 0.03263757105976824, 0.08407020535800727, 0.05258206495895021, 0.04857136101852502, 0.0744500715706137, 0.027150173273478306, 0.015948105269231867, 0.05379777371643051, 0.027809581539082914, 0.01555546701344992, 0.0353600062249649, 0.03209371566622248, 0.008433216529327535, 0.06411886263278223, 0.09721916995101398, 0.04306117020126793, 0.0908584108636264, 0.10958886990744261, 0.1430407043306097, 0.1856247128377999, 0.11968157269180783, 0.17956270505824398, 0.1450405462134269, 0.19955462746081815, 0.0761441371193336, 0.1165385207822246, 0.13150800139673297, 0.1500704650196337, 0.09285674355323277, 0.1797460298985243, 0.0984179136914111, 0.20408640525514082, 0.23235169419598198, 0.13437657166392575, 0.11271855358274714, 0.23784448332603902, 0.13923899300636786, 0.07072333727152118, 0.14086823219493513, 0.1383371083366294, 0.08542720754180225, 1.3184293503722837, 19.078967455894716, 54.836060770096324, 60.905454004964525, 64.55307783619051, 40.19003645066292, 39.816336554865686, 46.974246348104174, 42.6541478403153, 23.526390021847142, 6.488866209983827, 1.0254797796087882, 0.3888266695843589, 1.8532968624945612, 4.509679896216239, 15.590048605395904, 22.226475361854803, 9.635558262948068, 10.215933726679895, 13.195565169857396, 19.42969991314796, 25.34024303959262, 34.22025965106103, 44.817668391812234, 52.632590878394346, 57.842416301850356, 59.42725781471499, 55.887761962029245, 57.130847361779985, 56.616181404359885, 53.961231016343646, 54.62180522180373, 55.6645594873736, 50.4875054667073, 49.04377906553207, 42.40779553690265, 41.06022211813158, 39.414654470259144, 40.878839954253166, 46.55421933820171, 51.82470029400241, 53.63343069630285, 54.63430973791308, 53.56096490736931, 55.11771832742999, 54.69492604655605, 54.17085424546273, 50.001747377457164, 45.19041122928743, 39.54808565878099, 39.686710065410985, 40.05135320848034, 41.026866282186205, 41.2687353164919, 43.046937911741196, 43.96911067347373, 49.16345842422978, 45.21648714619298, 48.55722473513696, 47.72877308630174, 51.984309381054295, 50.67594789689588, 56.07907948955413, 46.51628609626524, 45.65277630282987, 57.456329561048946, 52.09258248729091, 53.12916686457973, 49.31459519170946, 53.464560893274125, 52.19794127248949, 53.06475370160995, 52.94680410815824, 54.14542159726543, 52.721514932570926, 44.24783429791851, 40.31308904770882, 40.67093864563973, 40.05722107425813, 47.47410143575361, 53.08008624661354, 57.07727955233667, 54.59116758838777, 54.162978126156716, 52.16051401630525, 45.83365640332622, 42.504144637815415, 41.83840074846822, 39.49520426411783, 42.00930626161637, 43.36981173484556, 43.99030323951475, 44.889816468761815, 50.41531424368582, 52.15867442469443, 51.61750108964982, 60.83319610165012, 54.580000600507184, 55.280802634454545, 58.74296503682291, 57.310182048428445, 57.54368074478642, 56.21283231243011, 58.26922116741058, 55.42937809421171, 49.0024882747281, 35.370694744971495, 18.487987864402033, 10.450731708157448, 18.123919348562918, 18.25714265146563, 29.45027312924785, 8.473741431390087, 7.132652671106401, 2.6513072415705654, 0.48417856916785246, 0.6070925042994562, 2.102083241747272, 13.780922043708063, 37.4235652339074, 55.81786532555857, 53.35186335348314, 49.454035451335294, 54.58380137720416, 62.993288501616455, 60.04786699048935, 25.992315507704213, 2.3253038573649625, 0.15468118051367422, 0.13256495758410425, 0.07915005929047063, 0.1471984167132647, 0.14394586785666405, 0.11758310464961876, 0.10295225021940085, 0.18397610694650682, 0.1286487927239749, 0.10347397141759435, 0.22139990041332863, 0.19499392218647466, 0.10806594840100697, 0.17470434398180054, 0.18579152082243275, 0.155906384930976, 0.11787477730503006, 0.16331253993895747, 0.16707219303615634, 0.14268631205683754, 0.15274932127325766, 0.1082384637406757, 0.11325080848989949], [0.030222007734400612, 0.058681825551414685, 0.05198601407990341, 0.010444014427071859, 0.08466766200839512, 0.05659308299542435, 0.04310801264739806, 0.05272740332950508, 0.018178711029430552, 0.013970562290670651, 0.04495835247179193, 0.04320524452674774, 0.04215778016875829, 0.02648167537465211, 0.05013812956730685, 0.013258393549720847, 0.05212970536142107, 0.05288640104774987, 0.04047789490751682, 0.016353167555925828, 0.022240965026280573, 0.05276856523367667, 0.05562596976937306, 0.0654186993356674, 0.02670245233833069, 0.18548879351827408, 8.244723062361441, 35.077866277387066, 54.267823080862726, 46.218793930545935, 36.20481421870571, 25.812274794424734, 28.558216325698364, 38.219920127622544, 23.264383539076775, 6.672699364923663, 0.882610326572772, 0.09950528356937632, 0.3793257697215004, 1.7463364019509287, 3.10559370344685, 6.665215972931155, 8.002533864590431, 4.327481879341987, 5.361730485193191, 9.81843779163976, 16.693154419622115, 25.484621563265403, 38.63289079358501, 47.32031706840762, 51.557037753443566, 51.30995196680869, 50.87048569033223, 51.529141856778054, 52.845426528684555, 53.00885208191411, 51.75838085912889, 50.07517022471274, 46.30055181441769, 46.5268058930674, 38.51035987177203, 36.52163582463419, 35.443235058938306, 35.310521664157996, 36.864874593673214, 43.56118417555287, 47.95608620489798, 49.34869627798758, 51.1113388307633, 50.526642876286665, 51.426144338423214, 50.511008308779815, 49.125889962719334, 49.15701004766649, 42.23663899206346, 38.94376216396209, 36.38190138724543, 37.896583464837846, 36.50369098109584, 37.532050148133315, 36.80442302457748, 37.633211997247514, 35.50868765000374, 39.99683618545532, 39.38912768517771, 47.232126497453265, 45.73217291985789, 55.318045539240686, 40.90990512601791, 38.15398116265574, 56.5141095653657, 47.580974255838704, 52.478932026893865, 48.365609107478974, 51.00155168964017, 51.41760141618791, 54.797123401395744, 50.77073589448006, 53.921654301304976, 52.6663467960973, 46.68625808531239, 36.17405891418457, 38.0323092399105, 36.79664888689595, 45.71507530827677, 51.14566741451141, 54.41681823422832, 52.076606673579064, 54.291051357023186, 50.052608751481586, 49.496142095135106, 41.63408448619228, 37.913343752584154, 37.29272280969928, 38.50250336431688, 37.515258481425626, 39.39415224136845, 40.46102908349807, 42.41979014488959, 42.9756841351909, 47.24104596722511, 53.02486711932767, 52.71648645401002, 50.18131740631596, 47.82849934793288, 58.195166818557254, 56.20111227035523, 54.213321747318396, 55.95257128438642, 50.10996164814119, 38.64918824165098, 27.32039866908904, 7.89021973648379, 9.180117153352308, 21.844785598016557, 8.45297150073513, 8.059446965494464, 8.8103376665423, 3.9022922948483503, 1.5047141092438854, 0.4868154131597089, 0.5407385648258272, 1.9080797486728238, 9.954917642378039, 32.04429538019242, 44.725598596757465, 33.72833951827019, 38.22172834027199, 54.26148453066426, 52.04056009169548, 45.251443309168664, 15.028717229443213, 1.137300301944056, 0.08183687519762786, 0.05360003876229448, 0.04672946731349634, 0.03877945116630966, 0.0427372414138048, 0.09003146491464108, 0.022101425941312508, 0.039792548820015886, 0.022219301975001732, 0.05612525991314361, 0.07327403467629226, 0.04264666300807749, 0.0417686419771804, 0.06339572159753692, 0.025396042601055196, 0.05189938102698615, 0.03263382872025813, 0.02741231132418879, 0.047596969957193064, 0.03162991071510459, 0.031106950369693583, 0.02612450986259407, 0.021870592158407937, 0.04440786850248133, 0.003374879930972032, 0.05490951668170672, 0.0028099688502298973, 0.024041784927248958, 0.03201000523873635, 0.1138733315371698, 0.015674807232684426, 0.01923496050069169, 0.006175598508918719, 0.02270133215783825, 0.024389435627287435, 0.06836080638271186, 0.08936334431411759, 0.0367618820089246, 0.03231830774776397, 0.062074511041564334, 0.012088181796453655, 0.007586883767808398, 0.027959324915202397, 0.027361544592666532, 0.0055045878417008835, 0.04478005699873452, 0.0316509589808242, 0.0315796381102935, 0.25439058821047505, 10.556157173648959, 40.451266304139175, 59.40574753669001, 52.90564275556996, 40.187216266509026, 30.777207036172193, 33.209637441942775, 40.62103040756718, 24.87779167390639, 7.908976020351534, 0.9776100095721983, 0.14055583686117204, 0.16038217701979224, 1.6832282850819251, 3.776111852738165, 5.043301197790331, 8.8977280739815, 7.054878444440904, 5.722873403180031, 12.375100447285561, 19.468741224658107, 29.27853999599334, 38.981373771544426, 49.63005573518815, 54.31929242226386, 54.72919579475157, 53.89437029438635, 53.44028926664784, 54.68521033563922, 56.06719470793202, 52.1216433278976, 53.43892820419804, 49.04855259003178, 50.04344217238888, 39.96586907294489, 39.08177075847503, 36.80087327957153, 38.0874381526824, 39.07007032825101, 45.2601666604319, 49.85226977256037, 52.61578744457614, 53.26930138372606, 51.4855251004619, 52.4896244079836, 51.45139655759258, 50.74434226559055, 48.58126886429326, 42.131519471445394, 39.76883665207894, 38.07394127691946, 39.27297845963509, 38.183618591677764, 40.032557210614605, 38.787455712595296, 39.29461817587576, 37.82423142463931, 43.49771630379462, 41.553420943598596, 48.99322363638109, 48.89663919325798, 57.51167812655049, 43.005525527461884, 39.954972728606194, 57.12336347949121, 51.827916637543716, 52.942140410023356, 51.70928062931184, 52.01329177425754, 52.33275313531199, 56.77839494520619, 53.14512698881088, 54.87541783240534, 54.320527968868134, 48.527430411308046, 37.57896954013456, 40.033890816473196, 37.74924355168497, 46.67637371247815, 52.230442031737304, 55.68011952984718, 53.89802986575712, 55.911221658029866, 54.06532287597657, 51.457448774768466, 44.06616972338769, 39.356885802361276, 39.9402795299407, 40.141806987024125, 40.133930867718114, 41.596618006306315, 42.75788276426254, 44.322665276065955, 46.08973618476622, 49.998060349495184, 56.27442921361616, 53.24075829598212, 52.66030242366176, 50.097202177970644, 59.26616607173797, 58.82075348208028, 58.22191346076227, 55.92541671568348, 52.02468625960812, 38.49250132037748, 25.77820900947817, 12.816978000825452, 8.158244605987303, 14.214610668920702, 13.978760511644426, 9.991961486877935, 6.089611091921407, 5.473055685720136, 1.4868896334402024, 0.9445208335115064, 0.5136391238099145, 2.1112613428023557, 12.375148496320172, 35.10946489149524, 45.057901797756074, 44.077509295555856, 43.46148537051293, 56.9274018656823, 57.45332894786712, 51.68669562185965, 18.623374354454782, 1.329047329002811, 0.07240857748735337, 0.03624936535714134, 0.01926765904851979, 0.03218888102339641, 0.08149601203659851, 0.02654930178616797, 0.03457923239517597, 0.03716860574880435, 0.02697348850028169, 0.020833148230468074, 0.04182734729481801, 0.02709262666382617, 0.03622614140171678, 0.04257487290869317, 0.029151122153346098, 0.024126881973878033, 0.007234462734026414, 0.058497198361663096, 0.04004291018411037, 0.037912005979207256, 0.043496457529404474, 0.06056486966929609, 0.05934739890958994, 0.17246631004156607, 0.126836787939312, 0.10320212511766343, 0.1172126934773499, 0.12639244928235008, 0.12932737808554404, 0.2805943805123529, 0.14954882043023265, 0.14812754346959053, 0.1367430632273036, 0.10549408398688802, 0.20404545019470877, 0.25115823343155846, 0.17866851191126532, 0.15108896359320612, 0.14784668031479084, 0.2360502441203402, 0.08798000402748586, 0.16108539976900624, 0.1507369768355162, 0.10641828479786074, 0.13929300220502963, 0.14982695631202192, 0.12126451718711084, 0.14071319132081925, 0.44962533779682656, 12.63009471278037, 45.013881037312174, 67.1539975750831, 58.72269030540221, 47.825663474298295, 36.529931637548636, 38.26868303360478, 48.648768932588645, 29.039967713817475, 9.327513940872686, 1.3999592464777733, 0.34960422424539445, 0.8097207377995215, 5.376945359091605, 10.497142172628834, 13.331573355582453, 13.685085792695324, 7.479226435384444, 7.6689598156559855, 11.308104953458233, 19.35703016096546, 28.470649411601407, 39.9618447211481, 50.92484581855036, 55.86050541170182, 55.900274322878936, 57.28000333232265, 55.491798693133944, 56.537737923283736, 57.32175304043678, 52.76302929847471, 54.434249247274096, 51.42902728049986, 53.06509102544477, 43.93503704378682, 40.843915170238866, 39.11105125181137, 40.94044470017956, 40.930772135334635, 47.3961913970209, 52.92913383053195, 53.505455524690696, 54.44985243581957, 51.76429971571892, 55.45446165146367, 53.04182352558259, 54.01173545468239, 52.08143118889102, 45.299492343779534, 42.84258634813371, 40.29508536861789, 41.15573967656782, 40.64587077786846, 41.39831081513436, 41.47594628795501, 40.40900276553246, 39.216598310778224, 43.98791059370964, 43.74493545101535, 51.067926037696104, 50.16804410565285, 58.088662701268355, 45.72119028337541, 42.87949977382537, 56.40518142331032, 54.07620353083457, 56.180661032276774, 53.63896516061599, 55.85109172328826, 56.91373240563178, 59.26473832899525, 55.187705178414625, 57.43763946717786, 57.64681946846747, 50.22289845251268, 40.62379567853866, 41.889352337006606, 41.47707593056464, 50.379561839565156, 55.24139458133329, 57.13468736217868, 55.069716361261186, 59.05052200440438, 56.14945465518583, 53.5078207139046, 48.69320546427081, 41.95229853353193, 41.9166402662954, 42.66674649330878, 41.0816421816426, 44.67674155389109, 45.26895276961788, 47.348314946697606, 49.441534857596125, 52.63479917280136, 59.152181994530466, 54.88812631176364, 57.20515666469451, 54.458693458187966, 59.71823884594826, 62.00022282138948, 60.28285226514263, 61.876817211028076, 55.6658499471603, 43.811768716381444, 30.57664252096607, 13.631576818804588, 16.40269898599194, 34.03018943725094, 14.837698782643965, 18.290414156452304, 23.327596456773822, 9.09033017773782, 4.305901979246448, 1.3274712716379475, 1.1588571581148333, 3.175636938502712, 14.469321543170562, 40.440605302010816, 56.9309869120198, 46.169360299264234, 50.823338800860995, 65.56286065809189, 65.60142147925593, 60.311603238505704, 22.09165761547704, 1.7516572196637432, 0.13328606082547095, 0.10942152566126279, 0.11764580128534187, 0.08957257824799708, 0.2454585086313948, 0.1325727870026904, 0.18745204704182764, 0.1504322730245129, 0.13990956508824903, 0.22877545786961434, 0.18601918683177043, 0.1073933385252472, 0.1369772716275146, 0.2239009323379686, 0.1122962782580045, 0.1791505344332226, 0.11566759372550635, 0.20918050690764384, 0.15564995998096082, 0.13851594390167346, 0.2432206585522621, 0.18523612239908788, 0.18324046335633726], [0.025859274901449684, 0.07497407571082154, 0.07667698957506688, 0.029431713346932686, 0.03711747704073787, 0.060040643363590204, 0.024584295836487607, 0.059826050644680384, 0.039735394830424944, 0.012225996225982184, 0.032188325609651305, 0.06265128714843624, 0.046037042573575056, 0.05798635944243401, 0.08814852038818984, 0.020537250600154364, 0.044263303880729986, 0.03854061559503598, 0.04034156573095149, 0.031561495233026725, 0.049700505671001254, 0.045179610155643, 0.012981162609292135, 0.028052816370261774, 0.06772090080043963, 0.09715002285496843, 6.365644951020518, 28.498643367521225, 49.09546413729268, 46.020584798628285, 33.77357621346751, 28.454575538635257, 36.59534108254218, 38.1037748244501, 22.518125157202444, 10.476585030555725, 1.5782107460883357, 0.09888042395393695, 0.17172796982190303, 0.4722115403461841, 3.4814334973212215, 3.6002119366199743, 9.929083931830622, 11.429732749539038, 2.0845784391126325, 7.467378916278963, 10.937374291881438, 17.651054090069188, 32.856190704530285, 45.65654177819529, 52.408529404670965, 50.32410344769878, 48.09541271578882, 49.51135696903352, 49.68836961253997, 51.79746335552585, 51.87010957348732, 52.99591610508581, 48.22194445517756, 48.05652633790047, 42.037512025525494, 36.57371313341203, 35.6514266229445, 35.288434797717684, 35.50548307357296, 41.13391560892905, 44.51389651144705, 49.11251468043174, 49.903441013828406, 51.4210452571992, 50.2622555148217, 51.646785505356334, 49.874027159906205, 48.32517731574274, 47.453379554133264, 44.676910215808505, 37.69266336194931, 37.56028336863364, 35.679601007892245, 36.76325382724885, 35.50426713881954, 37.39673229955858, 36.60506856056952, 37.92192982089135, 39.96227618186705, 48.956380813352524, 46.80798884361021, 56.30603567246468, 44.72728129356138, 35.67342719724102, 47.36600483617475, 47.816944045405236, 52.9464981632848, 48.357407431448664, 50.142638914046756, 47.572858871952185, 52.97160133238762, 51.99096956560689, 53.82601907176357, 52.47016945192891, 46.79857907756683, 36.290929855838904, 36.694220112216094, 36.78065738370342, 45.354668324993504, 52.30606140628938, 54.432413578033454, 53.1824012725584, 55.020561218261726, 52.11055478742046, 52.23417612814134, 47.45117125972625, 40.26611866489534, 38.38030584396855, 38.98473916515228, 41.58470184572282, 38.67883351541335, 38.73713170328448, 43.00221504703645, 45.08598989056003, 48.96241341867755, 53.461462220837994, 52.09503396864861, 42.78762217490904, 51.048702501481586, 57.50521798287669, 57.82326729066911, 55.77037326751217, 49.60603906262306, 47.33592810169343, 29.261210964572047, 23.30235600471497, 12.474807097065835, 8.46528382070603, 10.749558460327888, 12.518073781844109, 4.08398506141478, 7.057824634736584, 5.069598238314352, 1.0930351288087907, 0.4204859272126229, 0.4790650242038312, 2.1875367337657563, 13.753100672075826, 37.06362893504482, 48.871108485806374, 38.52179358082433, 38.43712922065489, 51.97289136148269, 54.370600946487926, 40.43259582211895, 11.922588367615978, 0.17298366453859115, 0.13751958526911276, 0.042646754938628406, 0.08131637207923398, 0.02197562281282679, 0.007825464136042303, 0.045616276442043246, 0.0033449282871574285, 0.056691429532703855, 0.08613967697226232, 0.003608695711121865, 0.04878723693470802, 0.06788390898896803, 0.08337224563283306, 0.014561165326965914, 0.013901213138935067, 0.059939875988469976, 0.01658151538351611, 0.04160819635275872, 0.08915873755130077, 0.03977788206670554, 0.09720757904071962, 0.04393685849443559, 0.09630086801705823, 0.032060904120425546, 0.06471271866992598, 0.016658974533540108, 0.06824534927164355, 0.03937809142254053, 0.0294835104667131, 0.0595165204797541, 0.047542547071052176, 0.06460887545178975, 0.0478487370926286, 0.02577412997432534, 0.0391622269976764, 0.13011816468450332, 0.07606590422050608, 0.02492286264896393, 0.025349899210155975, 0.07985296794363568, 0.025694780502348177, 0.04542905221422834, 0.08651679907474788, 0.06255113647409505, 0.01254234744626428, 0.08122980414379029, 0.09179765764143198, 0.04138863555365994, 0.11435629634727394, 7.8390254512909925, 33.68123577487084, 55.1526705680355, 53.45159353748445, 37.02634288418678, 31.277885821557817, 37.607587152911776, 44.313251587652395, 27.72591094816885, 10.157164854388084, 1.6836315537652664, 0.12680490335990346, 0.4177114018990148, 0.9606640834000804, 4.130627436022605, 4.4860177078554715, 7.099518939372032, 6.964258945757344, 5.429117785346124, 8.762175863788976, 15.039357639128163, 21.473141024189612, 35.55291237369661, 50.20023892002721, 53.16926133248114, 53.35501693910169, 50.809520290743926, 52.0520055678583, 52.49785354060512, 54.43659090226697, 51.94104171568348, 53.77460072117468, 50.60056386455413, 49.56115145837107, 44.83788036531018, 37.937784041127856, 37.583131174887384, 37.26747843527025, 38.26090889592325, 42.808293065717145, 49.23532016815678, 52.14599732429751, 52.703260221788966, 51.167511094001036, 51.912459404237815, 54.42891482383975, 51.623266973803126, 51.785609952865116, 49.484072962114894, 45.5337009891387, 39.18470159653695, 39.01707126248268, 37.37328437066848, 38.59170982914586, 37.69679754011093, 38.51000293608635, 37.633725827740086, 39.99241175190095, 41.75209291519658, 50.63307246854229, 49.99878206560689, 57.71938723902549, 45.945079172811205, 37.8783836672383, 51.44187696518437, 50.205181106444336, 54.22119786662441, 50.46864278854863, 53.953048952164195, 50.34640996686874, 53.99887400288736, 52.391004254741055, 53.865140791862245, 54.60603729371102, 49.52273184253324, 38.54074255112679, 38.54768514633179, 39.312904265619096, 46.92419690470542, 52.921496975806456, 55.66967033570813, 53.73445134009085, 56.35009173424014, 55.7947390310226, 54.31445221747122, 50.139755971970104, 42.75409767704625, 39.73711644449542, 41.47653464348086, 43.03002465155817, 40.31346559524536, 40.44107206406132, 44.814616787818174, 46.07676490660637, 51.36497105321577, 56.6793982444271, 52.44237161451771, 48.50901096097885, 54.523428255511874, 56.875708949181345, 60.1511194629054, 58.22460812907065, 56.157589650923214, 51.4846190329521, 36.684625994774606, 23.10784370668473, 10.003892356349576, 11.046669175547938, 16.233996864288084, 13.30483259693269, 7.583387917087925, 13.335673213005068, 2.8895490640594117, 1.4826434225805345, 0.25163664001851316, 0.5022661808517672, 2.2614113890355636, 15.092406715116194, 36.343234662086736, 50.02277128158077, 38.18057483242404, 40.98498321348622, 58.641673749493016, 61.23819651142244, 47.18704669706283, 16.121555259150846, 0.7465417118322465, 0.10942127285224777, 0.03842385230405677, 0.027046866316889084, 0.050573516486873554, 0.008141140720146078, 0.038884661851390716, 0.039974785815443725, 0.0871298915796703, 0.05514808029176728, 0.01718785673860581, 0.03427992567359921, 0.04437664275868766, 0.057796457737323746, 0.06655833173182703, 0.061627211454775066, 0.05406851301931086, 0.05298775064969256, 0.024047741260860237, 0.08166494974566084, 0.027899859255299937, 0.029448159339447177, 0.029819022503591357, 0.03331375473569478, 0.13648124501830147, 0.23291665339662185, 0.14155067863964266, 0.14901563855669192, 0.1177985592174434, 0.11675699373647092, 0.09807872060205668, 0.13335263386609095, 0.2081181727830441, 0.10625651767176968, 0.0851337192580104, 0.09517255073954022, 0.1648285360105576, 0.17038445078557538, 0.12135602638966615, 0.0888423738820899, 0.1469882175086006, 0.1073502077751102, 0.1994524619752361, 0.21681605928367187, 0.21823830151509857, 0.1101191636295088, 0.16437017028370213, 0.231216122065821, 0.16627161583352476, 0.2659500582564262, 9.542904034737619, 38.885746386743364, 60.715925078238214, 59.5814226519677, 44.5214549187691, 41.105113644753736, 48.28719308299404, 49.24830713579732, 30.991921501774943, 13.160495258146717, 2.4780823819098936, 0.3786174754702276, 0.5354959493683231, 4.001530221393032, 7.245766472431922, 9.719832347285363, 17.994785116564845, 17.72569679444836, 5.9406791867748385, 9.90310803536446, 14.157826515936083, 21.996744102047337, 35.288258291059925, 50.53091825977449, 55.98177725268949, 55.47314390059441, 53.01617514702582, 54.734259574644035, 53.94986398758427, 57.452768048932484, 54.71183930673907, 56.06748888569494, 51.9433480693448, 52.597011058561264, 47.66012376354587, 40.44343725327523, 39.20011651131415, 38.57757360704484, 39.25813621090305, 46.05935350541146, 51.2895203405811, 54.45462596031928, 54.69601254309378, 52.2329641157581, 52.62694266534621, 54.69923280900525, 54.59731394244779, 54.7815868931432, 53.26519858452582, 49.65163269350606, 41.63925809244956, 41.21345735365345, 38.961059816422, 40.512561182821955, 39.81872135593046, 41.09014980254635, 39.83818415672549, 41.75889822744554, 43.441689168253255, 53.6095356172131, 53.70516300201417, 59.6905900586036, 48.96022081375123, 41.058723772725756, 53.388290405273445, 50.13648079287622, 53.88068122248496, 52.740793381967855, 54.674431662405695, 52.603424133793006, 55.6158632616843, 53.705417956075365, 55.1983779476535, 56.769448018843136, 52.30214688085741, 42.22411878647343, 40.57268327282321, 41.5119497237667, 50.61202895256781, 55.510449563303304, 58.50461436856178, 54.94908386661161, 56.02504491806031, 56.762854514583466, 56.66907064376339, 53.43385265719507, 43.054978770594445, 42.2127321458632, 42.79382736452165, 46.20177476636825, 42.494978058722715, 43.318248256560295, 46.80754169341057, 49.831238023696415, 54.05845872817501, 60.672990814332046, 53.52969184998543, 51.43223970167099, 58.828598222424915, 58.24551043971893, 61.255294123003566, 60.79561195065899, 57.36668771313083, 52.24141290110927, 33.595798707777455, 27.28401868574081, 18.491341490899366, 17.604976046469904, 18.988898069627826, 18.29807650658392, 17.12784521041378, 15.216558556402884, 10.233926619252852, 5.154831342158779, 0.9163161727689928, 0.9763888041338614, 3.049195658776068, 18.045081669284453, 44.25790694452102, 59.55546440616731, 49.73961145647111, 52.06914240314115, 66.02735950100806, 70.1295546562441, 53.227732104639855, 20.689225927475963, 1.4488997622843713, 0.47048955855350344, 0.15298359096050262, 0.17504592726547874, 0.1655156096263278, 0.10327799846568417, 0.20125753366418425, 0.16084861731336964, 0.2806613059534181, 0.17043476744044214, 0.06418646223122074, 0.23134097907572027, 0.22803131070348526, 0.20114537839206958, 0.2579760942007265, 0.1470082583686998, 0.15539600183406185, 0.16789265788130223, 0.0980939734126291, 0.2455549437793032, 0.1541475696308959, 0.16334929683756444, 0.10680679862778034, 0.11701078334402655], [0.062095720185748035, 0.02333895288287632, 0.033373015467077494, 0.07280794678316002, 0.053418437619843794, 0.027626222224846005, 0.025031911434545636, 0.10426301133608627, 0.018262249087133718, 0.07513603435889368, 0.07825336869685881, 0.047832151289067926, 0.04088236251845956, 0.0427944949948259, 0.037223752588033676, 0.019381331174724528, 0.03771177740887769, 0.007832407765466, 0.04078444882085727, 0.0380665565570516, 0.014052982817614272, 0.04433749183531731, 0.03201852413645435, 0.06145008426580218, 0.04833127289349514, 0.05752199141669178, 2.470675721283882, 20.913542355260542, 43.33232564310874, 47.66748212998914, 45.465110501935406, 32.97210654904766, 25.382414402500277, 35.88852605512066, 34.03217023418796, 13.12983605169481, 3.11412412312723, 0.2619691896102121, 0.01972418233391739, 1.2226258266356684, 2.788072935035152, 3.529170458355258, 4.573163457455174, 4.177593896465917, 4.887442877215724, 4.989276432221936, 8.217008085020128, 16.128972461146695, 25.694144771945094, 42.32704570216518, 48.590647251375266, 51.935813196243785, 46.70474421593451, 46.16794432363203, 45.878814651120095, 49.35499952685449, 52.79414153868153, 53.36125350767567, 50.57238555723622, 47.86033722662157, 43.644714970742505, 36.71963314856253, 35.972354950443396, 36.76885497185492, 37.18828185912102, 43.53885804453204, 47.95569004551057, 49.97111366641138, 51.83460035631734, 51.606067380597516, 48.91789059485159, 51.286672699836, 52.23340734358757, 50.297199910686864, 49.09567594528199, 51.928968660293094, 45.70671281506939, 40.389296777786754, 37.8222623948128, 37.04586844290457, 38.375395036512806, 38.19640551843951, 37.89343772395965, 39.13939429867653, 43.2561061459203, 49.40333881685811, 49.09742140000867, 58.090604274503654, 43.63639562360702, 27.551120327365016, 41.80630399334816, 46.09954211019701, 52.465580278827304, 46.787227738288145, 51.97966921714045, 53.21350959039504, 52.16371074799569, 51.39225113776423, 55.38858152204945, 51.41837412311185, 46.011331927391794, 37.9992122803965, 37.42632266013853, 36.26929013959823, 42.84557911657518, 47.72622746805991, 51.29625505016696, 53.23597300437189, 53.141247764710464, 54.1233661097865, 51.02059871919694, 49.734328023849, 44.65587846694454, 37.596306416296194, 38.55664383980536, 39.192146255124, 40.06446176959623, 35.32610131848243, 40.406378699887185, 44.65465468745078, 48.19715507568852, 51.79648276298277, 57.2410894978431, 45.36830640608265, 45.27276923579555, 52.40405790267452, 55.628595275263635, 52.07949746039606, 48.241701433735514, 39.12989431811918, 27.006342334132043, 13.969993033716756, 6.024795395712699, 6.701766579381882, 13.156188495697515, 15.455087692506853, 6.450729004798397, 9.590269596345964, 2.7261794046048196, 1.2425059921318486, 0.03993880649607989, 0.4031432594262785, 3.405743520106039, 16.066702873476093, 36.07863941500264, 40.170416755061, 37.24732529732489, 36.98536196062642, 50.85583563773863, 52.030463910871944, 36.71918207599271, 10.115638721373774, 0.23003231703994736, 0.06751588801102293, 0.03632548768373747, 0.04632496905903663, 0.07201367448414527, 0.037977314974752166, 0.027678551775733792, 0.038235919444911906, 0.025101529674664624, 0.03321045160954518, 0.057145459201907924, 0.01859477912676671, 0.0663811968819749, 0.0560424994346836, 0.0354360519427686, 0.006637198563229534, 0.05475465966869266, 0.05279450114035318, 0.0628708977432501, 0.08149251101478454, 0.027336539482818018, 0.03685971526729484, 0.024786479846243898, 0.03967010498707814, 0.03585228283378867, 0.06898568898078895, 0.03262459353033093, 0.02981348943355824, 0.011634539959261255, 0.03161946893669665, 0.013839905037574712, 0.10596531999087143, 0.020339253260904265, 0.05993854299548173, 0.05182649159143048, 0.06931817880080593, 0.055042563171516505, 0.05525552029270799, 0.048465280823649905, 0.05455212517371101, 0.019915669841030915, 0.017089401033797094, 0.03941770199866545, 0.02882182691997338, 0.03138402330448791, 0.02764423486716565, 0.04188524055925589, 0.09036167945352294, 0.015231684740302304, 0.08969293832178078, 3.5190441243110167, 25.772384289772283, 49.65783003837832, 53.115273829429384, 48.85228503134943, 38.416972160339355, 34.21579991617511, 40.172774099534564, 35.92714963420745, 15.752219000170308, 3.1301197938380705, 0.36374139629544755, 0.18057170414155532, 0.7869727681240728, 3.2436160262553924, 6.200928938004279, 8.126056165464464, 7.2749631251058275, 6.3063431266815435, 6.685671623676055, 10.782512253330601, 19.36397863972572, 27.782799043963035, 45.040890478318744, 51.43091394055275, 54.5009530744245, 49.3737994470904, 49.6567278523599, 49.18922447389173, 52.81740119380336, 54.78907077543197, 54.99900779416485, 51.070059807069846, 50.78745695852464, 44.496508644473174, 39.30284730849728, 36.997176139585434, 37.680598151299264, 38.62463812674246, 44.37182826380576, 49.44878732004474, 51.45347149141374, 53.734125783366544, 52.150712013244636, 49.242502027942294, 53.69896957951208, 53.63919658045615, 53.984388689841, 51.00642327339419, 52.8098153298901, 46.82723983641594, 40.75126486439859, 39.632616658364576, 39.025904440110736, 38.801540943884085, 39.8376154130505, 39.80966852557275, 42.223346079549486, 44.61453276295816, 53.117964575367594, 53.27783253885085, 59.68725212158696, 45.556607630945024, 33.3160944907896, 42.96566640177081, 46.92846836582307, 51.5017480234946, 47.94254618306314, 51.910788474544404, 53.85049466163882, 51.98240703152072, 50.189617141600586, 55.96483653591525, 53.39767271472562, 47.94797082101145, 38.060624830184445, 38.268639887532885, 38.0642294883728, 45.12055773888865, 50.2444322647587, 53.23540818306708, 56.9634327580852, 53.411699110461825, 57.66646269829043, 52.05320581313103, 53.21439996842415, 46.25036116569273, 40.22245876250729, 41.36033834949617, 41.51640553628245, 41.305648742183564, 39.646772492316465, 41.88792067189371, 47.675440619068766, 51.17682672316029, 56.83983102921517, 55.71662110667075, 48.34180424290319, 51.86049584419497, 55.37470025400962, 56.934897515081595, 55.43373976984332, 50.683423934444306, 42.77196799555133, 29.803664953477924, 15.660947407445601, 8.220098912715912, 9.665829154752917, 11.339357418398704, 14.554586025976366, 9.887736266659154, 9.499540271297578, 4.033128590353074, 0.938238483523169, 0.08648054779417093, 0.31645645778025355, 3.642000132991422, 18.008101563299856, 40.147478734293294, 46.2411985089702, 45.98890381474649, 42.85591848434941, 58.21586124358639, 59.263377266545454, 42.14493397743472, 12.327173006150032, 0.32682230155314174, 0.06070157805938394, 0.043650805093948884, 0.07598835313993116, 0.047200055973183726, 0.04642330793543689, 0.0871148379519582, 0.03299128151528778, 0.059591999292493834, 0.03655076349875139, 0.02019896532499021, 0.03464754828582368, 0.029030080261309783, 0.04028616991314677, 0.0267137291525761, 0.03973339917138219, 0.04927276047847925, 0.061944555716529015, 0.05860506354140178, 0.004239744598781991, 0.020985061550633084, 0.021285929176355564, 0.02016833712977748, 0.04670666087599051, 0.14895536275880952, 0.18523295079508137, 0.16164472056252344, 0.1927504337002193, 0.10238706885326294, 0.15680885182753687, 0.13435833877132786, 0.25114461238826474, 0.15934647211144048, 0.2424716390669346, 0.19454877913719226, 0.16485269842368944, 0.1693937305601374, 0.09429864360079651, 0.19905705335399798, 0.1517785806208849, 0.1751299517890138, 0.0670672516008058, 0.11361065530969251, 0.11753564550270958, 0.13931322692623063, 0.17016418518558626, 0.16735900103324847, 0.18129728133639983, 0.16194976145221343, 0.17927555998246517, 4.511625391821708, 28.304837096122007, 55.50108294333182, 58.80006690179148, 57.527681396853545, 45.20586144539618, 38.510708962717366, 47.60519489165276, 43.93589604285456, 16.745757326003044, 4.3988533269974495, 0.6092857833831542, 0.4886763020148201, 2.0789334129902626, 6.606135272210644, 9.9508923099887, 14.297978685748193, 13.780810256158153, 9.02266929226537, 9.542042093892253, 12.534105489330909, 19.277288375362275, 29.422334086510446, 47.78829897603681, 54.68806582112467, 58.34092601653069, 51.14183525885306, 51.56797332148398, 51.32665341900241, 55.50481703973586, 56.86999013347011, 56.631784592905355, 53.06960175114294, 52.26097376115861, 47.724505547554266, 40.56925512129261, 39.01657312147079, 40.21968956916563, 40.575491689866595, 46.58129153713104, 52.18229493787212, 53.20274660664221, 54.668371600489465, 51.73098702584544, 51.685130596160896, 53.97361393897764, 57.361969101813536, 56.700849686899495, 53.980776186912294, 54.1606011698323, 50.237360231338016, 44.51831702263125, 41.90582236936016, 41.26955116948774, 41.74276551892681, 40.95670292454381, 41.4080382931617, 43.564577025751916, 47.31279396241712, 55.38972293176959, 55.21722885870165, 60.84231168993058, 46.61682428852205, 38.16734467783282, 48.637323456425825, 50.30557809337493, 52.07209987025107, 49.25609696295954, 51.51055374453145, 52.42868254261633, 52.56651070810134, 52.619203828996234, 56.504131055647335, 55.50422868421001, 49.62938108751851, 42.030894987044796, 42.0391554986277, 39.84884515885384, 46.90338873094129, 53.31281223604756, 56.09054457756781, 59.44863865452429, 54.719946845885254, 60.19918026462678, 54.082981386492335, 54.52273399599137, 48.26586715636715, 42.27787094731485, 43.25880865896902, 43.48243867197345, 43.94947921076129, 41.67414365276214, 44.45029135673277, 49.539445061837476, 54.31559362719136, 58.00620271313576, 56.532246605042495, 50.012690790237926, 51.80183287589781, 55.4386584220394, 56.31692024969286, 56.54572386895457, 50.829759720833074, 43.61857237354402, 31.665945514555904, 17.59013968129312, 12.352495827982503, 13.644331386012416, 21.123622540504705, 27.02302613565999, 14.286889164678513, 22.068592117678737, 7.822615235082566, 1.5775196734936008, 0.5911131359396443, 0.5877910109777605, 3.985399474059382, 20.455336955285844, 45.604990067020545, 52.01483326573526, 49.40364083936138, 50.84150329712899, 62.69719269967849, 66.3691234588623, 49.23023285404329, 15.980541148493367, 0.5840717460359297, 0.1778174035491482, 0.14264923340130237, 0.19048304327072638, 0.15813804501968046, 0.1485256946855976, 0.2095264875360074, 0.1550819517503823, 0.20326315184995053, 0.18021786345108864, 0.1494527223610109, 0.13937144960847594, 0.1976185087715426, 0.18665241978822217, 0.06723148553001304, 0.15479387204733588, 0.15441540929098285, 0.23914543851729364, 0.18888398794637573, 0.15599958718784396, 0.1533943979490188, 0.19966517394829184, 0.07982425496823366, 0.22304412428169484], [0.052515491918330236, 0.05453002353709552, 0.057695491179343195, 0.037743003152671366, 0.035150465855915705, 0.016323724881775917, 0.019771011373508843, 0.0083342561640987, 0.027958512862002658, 0.09589891700494675, 0.04853648103533253, 0.004957336284625795, 0.014109537343404466, 0.04403345069036849, 0.024234750984056343, 0.0417768391179702, 0.025508492817020705, 0.030211803443249197, 0.025337561364135435, 0.030128328587799787, 0.04240867396396014, 0.04793257392462223, 0.058753987203442284, 0.13753001938664144, 0.03554432697954678, 0.017193510467487, 1.287210838448617, 12.055328238394953, 36.09937698610368, 53.10072968083044, 41.82712393422281, 33.163161277770996, 33.99798677813622, 37.33466863632202, 33.37627541634345, 15.991574775788093, 5.284600507828498, 0.3752439306868661, 0.1619146746252814, 0.28312954931489887, 2.611468218026623, 3.0402296108584252, 6.145698043607897, 4.519003860412106, 5.547644457509441, 3.0103558590335235, 5.022980378520105, 12.082540662057939, 20.13613054829259, 40.61762971262778, 49.976879550564675, 51.92318316428892, 46.60400598279892, 45.03286138657601, 43.86504627043202, 44.74477114215974, 49.37642743510585, 51.57758312840616, 50.870673964100504, 48.99927585355697, 43.723923314002256, 37.48922178822179, 38.791417306469334, 39.327722980130105, 37.878171859248994, 46.78256796252343, 46.55323482328846, 49.15185605326007, 53.30199826148249, 50.78324041058941, 49.851987361907966, 50.934322264886674, 49.17049907868909, 50.59041277054818, 52.4963120491274, 52.31490635102796, 49.7410588110647, 44.9920726591541, 37.93429705404466, 37.176899140880955, 39.572984864634854, 37.99410927680231, 35.45133475334414, 40.7332847195287, 44.363563829852694, 49.37172451326924, 49.54692109938591, 55.542373734135786, 41.93997444645051, 29.549658144673995, 49.2244081343374, 49.24451028147052, 53.44125416971023, 51.76390747870169, 51.13370026311567, 53.631430287514966, 56.80110939087407, 50.568592625279585, 53.6498026694021, 49.7680486402204, 43.39370681393532, 37.357943980924546, 34.61161413500386, 36.54736657296458, 41.04934146327358, 45.74831739548714, 47.503491755454775, 51.988710280387636, 54.30781556713966, 52.52279981490105, 53.50959754759266, 49.72249031066895, 47.81876010279502, 39.98109571395382, 37.50340900113506, 37.80936564168623, 39.78090578509916, 38.34262363372311, 40.640854066418065, 45.555289714567124, 48.58742698546379, 53.20716319545623, 56.425067840083955, 53.31276908997567, 53.55972543839486, 54.678189293030776, 52.32263734263759, 48.61817444524458, 40.112946187296224, 31.035334294842137, 24.026313750974595, 12.326116907981135, 5.827067244437433, 10.64712772446294, 14.848140132042671, 10.431936690884253, 8.602393211856965, 11.844541045927233, 2.4259879127625497, 0.991103453261237, 0.04391068510050255, 0.4266649166182165, 4.445257417617306, 18.53889826805361, 31.518052547208725, 40.74874278037779, 29.01174822161275, 37.63553011801935, 54.683574707277366, 59.119802828758, 33.17042158495995, 7.322310545752126, 0.17351894549304442, 0.04496850696722827, 0.011140441018787604, 0.0826074140927484, 0.01308809794981273, 0.009471177566616286, 0.03766924037688202, 0.051526254073025725, 0.04050784511491656, 0.02612972692135842, 0.03623609671429281, 0.042091099875828916, 0.06339775173053627, 0.03728322399359557, 0.04975101001740945, 0.054761014368024566, 0.05117550837777315, 0.048622286713291565, 0.043302384475546504, 0.03717981744557619, 0.07476695617961307, 0.06803183290626734, 0.042236786816389336, 0.05715607718053845, 0.060954383243956876, 0.020705054499088757, 0.05700012083135306, 0.061588841941087484, 0.11045834139710474, 0.041078542314109304, 0.05677240502630031, 0.025606801049904, 0.057389753149642106, 0.03294185735285282, 0.08256832828685161, 0.01513413493446405, 0.031319005422354225, 0.03546360812540497, 0.012693494678505007, 0.07269614391149053, 0.054581680845829754, 0.03671462204487574, 0.058476766796722535, 0.04033298937663917, 0.005202748720729423, 0.018158197110038132, 0.06556496850305027, 0.08060438528416619, 0.02263337632851495, 0.011351451319041512, 1.8246396582934166, 15.892953641953008, 41.24458920571112, 58.807582163041644, 48.65538597106934, 36.58148334872338, 37.223751852589274, 39.83171616831134, 39.707263285113925, 18.133864518134825, 5.453634560108186, 0.5162148033418964, 0.07623524795616828, 0.34692438739922743, 2.927341836114084, 6.418102239408801, 5.677994624260934, 8.652539733917482, 5.605235147860743, 5.589370631402539, 7.036762487503791, 13.072814595314766, 26.09223592665888, 42.9751467704773, 52.85622481376895, 53.33995111526982, 48.45505483688847, 47.04993240294918, 46.7260975991526, 47.669937533717004, 51.25937692580685, 53.645511596433586, 52.2450214816678, 51.07286430174305, 46.18542632749004, 38.977596529068485, 40.61232274578464, 40.88424498035062, 39.88123609173683, 49.332069350827126, 51.0763277546052, 52.1664995531882, 54.20420223666776, 50.720588391827, 50.828453571565696, 50.693531882378366, 50.850332552386874, 51.314949066408225, 54.22359443479969, 53.30819952872492, 51.44809392190749, 45.75955106366066, 39.17228729494157, 39.290621280670166, 40.75513624375866, 39.348652747369584, 37.56337419632943, 41.85016393661499, 45.469374118312714, 51.01641747259325, 52.24935570070821, 56.196613311767585, 42.37220002758888, 34.266422025619015, 52.37935089295911, 48.86828437928231, 52.607220988119806, 51.916522979736335, 51.29308185269756, 53.59943943638956, 59.0165150550104, 51.81987577869047, 54.60572742646741, 52.31602030415689, 46.86345115784676, 39.23397048827141, 37.4520141847672, 39.213636921298125, 43.30588886814733, 48.51014452595865, 50.0765508990134, 53.76521056698215, 56.15719349153581, 54.34337577512188, 56.165771715102665, 52.82381034666493, 50.360236321726155, 41.24431071742889, 39.50736753402218, 39.045324094833866, 42.601894024879705, 40.032251265741166, 42.49744915193127, 48.54017026962773, 51.312670169338105, 53.74627728616038, 58.38308365114274, 53.72677133929346, 55.35564930208268, 55.75022405193698, 55.81659839999292, 50.32014969856509, 46.170980238145404, 34.057959818070934, 23.12669461773288, 10.577086940888437, 8.086242637326642, 8.862535588202938, 8.1750240152882, 8.618931885688536, 9.0880238240765, 5.048841055362455, 3.1077416914124645, 0.08656648753751671, 0.12669015104972547, 0.5851720321562983, 5.025164158113542, 19.746678413883334, 34.92251688434232, 47.405185391826016, 34.52768718042682, 43.32239027946226, 63.163837079078924, 62.90678062746602, 40.92795979592108, 9.351746343797254, 0.43214799175339363, 0.007262131914631614, 0.06424516371841874, 0.027551082406012763, 0.05121266364210075, 0.01629971568622897, 0.039109401404857635, 0.0324484967296162, 0.06188095892749487, 0.04987968214517159, 0.05323432370900147, 0.02423957733797931, 0.09850377682596446, 0.05508768191981701, 0.01691086615826334, 0.08741361224242757, 0.07799777878268112, 0.043448247616329504, 0.0412961725716389, 0.044821479372800364, 0.04299959971479351, 0.04016104860291366, 0.06207905777339494, 0.0162879983714271, 0.14877176212687648, 0.09716313061935287, 0.23461505500299318, 0.1256799415474938, 0.227035534297747, 0.08506703130420178, 0.1932710517318018, 0.14224826298173399, 0.27366680063066945, 0.15323155829983373, 0.1677272288549331, 0.13075185729370964, 0.15500735010831587, 0.13221718430999788, 0.10658591249657255, 0.09008633979265729, 0.17522332258522513, 0.14292459604480576, 0.1764852226140999, 0.14794443313392902, 0.19503421841129182, 0.1200179465776009, 0.1944386156936807, 0.21189719258296877, 0.06880480796098709, 0.1296613311334964, 2.2701170896330187, 18.803585690836755, 47.2464745275436, 66.28119176433933, 53.522396241464925, 44.23986404172836, 45.76246146232852, 48.05363947345365, 45.073461840229655, 20.681041902111424, 7.184558376189202, 1.0220359998845285, 0.3804677616684668, 1.2438794345624986, 7.378005750717656, 11.359631169226862, 13.982945680618288, 14.141300589807573, 11.707720929576505, 5.805724157441047, 7.5498707736692126, 15.28024608089078, 26.10180062632407, 46.226011091663, 55.09246218589045, 56.93515639151297, 52.47404475365916, 49.56252821030156, 48.77792081525249, 49.30178865309685, 53.634266161149554, 54.9806942478303, 55.723332282035585, 53.41160105120752, 48.383985411736276, 41.17351978055893, 42.94419142507738, 42.885038160508685, 40.98455175276726, 52.41101226499004, 52.83932332069644, 53.770435164051676, 55.3819723283091, 52.41079653463056, 50.238093714560236, 50.60737309917327, 50.12544716558149, 52.717329763597064, 55.96399714869838, 55.613207817077644, 53.494296381550456, 48.65851210009668, 41.58507839325936, 40.82467594454366, 43.73652981173608, 41.54734519220168, 39.195633242207194, 44.362995086177705, 47.5914312947181, 54.11028500526182, 54.95287679856824, 58.012160793427505, 44.51480257895685, 38.67818240196475, 52.247414127472915, 49.63870456141811, 53.404642766521825, 54.09468181671635, 52.181773262639204, 54.561432100111446, 57.03873442065332, 51.15368473914362, 56.15942139779368, 54.945149729328776, 48.24880484611758, 40.51861339999784, 39.14711352317564, 40.63655907107938, 44.65519205216439, 51.36879928650395, 51.4911929253609, 57.310123212875865, 57.05145466712214, 55.00142005182082, 59.26448729730422, 53.988989630053126, 52.70906140727382, 43.62259672534081, 40.369759451958444, 41.36106791034822, 43.00734550722184, 44.031692089573035, 44.60114963593022, 51.45719774307744, 54.32205377086517, 56.570438723410334, 60.39061154088667, 55.8386185861403, 55.665567536507886, 58.67899117931243, 58.8825386570346, 51.20674264046454, 46.24034735464281, 35.77697776979016, 28.408256269270375, 18.21838375060789, 10.861536245192251, 17.16248562259059, 26.680871901973603, 17.076240547241703, 17.868239648880497, 22.09258721720788, 6.026758541983943, 2.3675495001577564, 0.38748871234636156, 1.0971720035999053, 5.763946012143166, 24.062311303231027, 43.01891649923017, 50.77066136944679, 41.59435087634672, 51.07026769268898, 69.59914822732249, 71.88410143698417, 46.868769891800426, 10.335454229385624, 0.44802148676206993, 0.15452966364401002, 0.14438520395948043, 0.2404041669421619, 0.13791824210314982, 0.15410788627641817, 0.11047422239977507, 0.12946277646528137, 0.1593370798734888, 0.1470045505031463, 0.16530453708143006, 0.2028156645716198, 0.2305188748024164, 0.19646821243147697, 0.12785264350954564, 0.1584023606753157, 0.1317846663897076, 0.12944074377657908, 0.12497859571369425, 0.13040272038309805, 0.19965749774729052, 0.18385576985536084, 0.09644189714303902, 0.16893668250451166], [0.0751259986070856, 0.03195913891578394, 0.03320529583781477, 0.08515779740147053, 0.05790070698205983, 0.009873299990900824, 0.033492889075029286, 0.056321700178687616, 0.0422694604663599, 0.033686705489432624, 0.013531085419198199, 0.027547832277994004, 0.012264136870902394, 0.018417632785595713, 0.033780095437842036, 0.021955641324541742, 0.03911123235499667, 0.06618962127475009, 0.05671548086308664, 0.03575411632717137, 0.05146202143101443, 0.12906969675133306, 0.015313678173228137, 0.028437687452101422, 0.06644036951324632, 0.029998018947099487, 0.4688297218132404, 9.049301205142852, 32.16258033629387, 50.17572802882041, 49.638127973002774, 47.17240841157975, 28.72612907040504, 33.77489412984541, 34.846846518978, 24.045335285125244, 7.814109085067627, 0.9971203078185359, 0.0067807236994286224, 0.2003173445982318, 2.156679692768282, 5.901259366543063, 3.534846618290871, 5.567599515761099, 4.7471240066712905, 4.550720145625453, 3.145723717827951, 6.3925254441076715, 19.972471614037794, 35.52347498555338, 47.162598563778786, 49.838812120499156, 49.309515722336315, 44.016539973597375, 43.982238846440474, 44.2468576277456, 45.207422548724765, 45.88686335471369, 48.56650506296466, 45.99885486787366, 41.825284342611994, 37.69146311667658, 35.628135588861284, 38.798814896614324, 44.10567583576326, 47.56788922894386, 48.87091236729776, 54.09539961045789, 50.260933676073634, 51.680784610009965, 52.10693443975141, 53.37318143536968, 52.644236395435954, 51.21014725777411, 51.749033851008264, 53.19884384832075, 49.72231380401119, 50.112958338952836, 42.07812816865983, 36.93104105611002, 35.245806478684955, 37.785254832237, 35.99177460516653, 40.7581211674598, 42.48625470745949, 51.26958685536539, 47.84626768481347, 56.835488965434415, 44.700228706482925, 33.49446819674584, 56.18568558846751, 48.45584323329311, 55.13703992289882, 52.6863665734568, 55.10928915392969, 51.485187776627086, 54.71796212657806, 51.911015972014404, 50.69507729622626, 48.73922271113242, 41.052185181648504, 34.84600713176113, 36.773212725116366, 35.42604723284322, 37.68825069550545, 42.2767726836666, 49.727373661533484, 49.668220396964784, 51.537931888334214, 52.492036665639574, 52.966153160218276, 52.275459074204974, 48.557797401182114, 43.30141344378072, 36.95495182468046, 37.09865962305377, 38.43235177378501, 39.491485857194476, 39.72449817965108, 44.54726019213277, 48.85464629819317, 51.393074835500414, 52.88637999565371, 56.73303665653352, 54.4705625503294, 58.06386939940914, 53.512504023890344, 48.5947225939843, 37.0264527105516, 25.3148280420611, 11.76097200762841, 7.694292443413889, 5.199176678734442, 4.625610449621755, 5.536608378733359, 10.764812557928025, 9.47071575349377, 2.1133590754001372, 3.556680491855068, 0.2829687014943169, 0.17676453827129257, 0.3786506930426244, 5.970614225633684, 25.539489638420847, 39.15476606738183, 38.648576351904104, 45.91672435883553, 35.19393705552624, 46.66762290462371, 55.31828872619137, 27.081789124396543, 4.195097473359877, 0.14491167490280446, 0.03494403963427871, 0.04672718437148198, 0.08068849407737294, 0.017297920590687185, 0.026061625535329504, 0.027439402108411157, 0.029800691934783134, 0.03168167719136804, 0.02569696959859181, 0.023797732297210925, 0.07473246690126197, 0.02700781881538851, 0.01786795512382542, 0.027076513919558738, 0.018348127543445558, 0.06271615564342468, 0.06733896000491035, 0.0917074584492272, 0.059935919144341064, 0.07779258979304184, 0.004258745494523957, 0.05304293962375772, 0.03946303908202437, 0.04678914939323741, 0.042130074598976684, 0.052605603010423725, 0.020144921652371847, 0.04085691690805458, 0.033131310896527384, 0.07377440500403605, 0.01675900837947284, 0.033731644207070914, 0.043799422320819674, 0.07173552328059751, 0.05573664649179386, 0.0633675831880781, 0.0445889831791001, 0.03931797267268262, 0.024424664180485472, 0.08623084909613095, 0.055779428671925306, 0.016671714575720892, 0.005922251317139355, 0.057714605073053996, 0.019864267256531506, 0.011875338630840905, 0.0194660336860726, 0.047494938536997766, 0.02615251420666614, 0.45706625787481187, 10.424038998542294, 37.35445699384136, 56.77159747769756, 52.71138345041583, 51.38295904282601, 33.584902363438765, 38.08688902085827, 42.01571933684811, 25.34539115044379, 9.364782341064947, 0.8967956395879869, 0.0237247068810487, 0.03329647945300226, 2.7323988128092984, 5.745518226777354, 6.0325518827284546, 8.40246412061876, 6.002912492521348, 6.207421931528277, 6.790059622256988, 11.14376646857108, 20.951279478688395, 38.84032534014794, 50.081708815789995, 52.83239641497212, 51.316678831654215, 47.09629089601579, 47.1146515107924, 46.89734435850575, 47.68117904663087, 49.544030312568914, 49.624580106427594, 49.17499803727674, 44.144044460788855, 39.60449718659924, 38.6165423547068, 40.78579741139566, 44.864301450790904, 51.3898035787767, 49.98708163538287, 56.192161421622004, 52.27499231215447, 54.10004761911208, 53.1372469471347, 54.4770658400751, 52.69466630874142, 51.554774545854144, 51.35507883564119, 56.31371959563225, 52.55540255577334, 51.261644055766446, 43.27092093806113, 38.41669367205712, 38.35806208272135, 38.545688659914084, 36.96245139644992, 42.1408978585274, 44.48813438415528, 52.651080931386645, 49.99864086028069, 60.022300981706195, 46.30092443958406, 35.912425056580574, 54.97543434942923, 49.06388905740554, 54.28014716794414, 54.36372895394602, 55.235146245648785, 51.357918631645944, 55.22446955403974, 52.55142527241861, 53.25523184191797, 50.443316044345984, 43.63186920842817, 36.83906539793938, 37.445675634568744, 36.835758839884114, 39.94788500570482, 44.95422178699125, 50.736552438428326, 52.80262954773442, 54.659369760944, 52.74609250407065, 54.00839359529557, 54.460493826097064, 51.60886795290055, 45.895072875484345, 39.77197062584662, 39.514827882089925, 40.33341084757159, 41.604517659833355, 40.80811962004631, 46.87242161843085, 51.428211427504024, 53.87739427628056, 56.08270768196353, 57.40474254854264, 55.68597955088462, 59.18138011809319, 54.94854257952783, 49.3232322508289, 39.88719809439875, 28.534438917713782, 15.25151668056365, 10.904580335463248, 8.280605885290331, 7.161520825278375, 7.3079821275126555, 7.987290063211995, 6.069486881456068, 4.585325746766983, 2.7902976543672624, 0.7179620357290392, 0.016973654724537365, 0.7453711907709799, 6.881018405960453, 23.876663561790224, 40.102049842957534, 43.71567849190005, 45.592634600977746, 41.099445819854736, 53.71919332012054, 61.44395620592179, 31.772616332577122, 5.685704533130893, 0.14988874896399437, 0.02820085137031011, 0.03156287610651024, 0.12861814920700368, 0.021807613985372648, 0.022747695799015706, 0.015946578839042738, 0.01042083930975247, 0.07223942527367223, 0.022263742735489242, 0.02958184168223412, 0.012910154877200484, 0.027903622662227963, 0.07308444323679132, 0.015390555096429684, 0.05356644197637516, 0.07288025016145361, 0.05084466564679339, 0.015007991854461932, 0.04442413254911381, 0.03866784364706086, 0.020108624406519438, 0.026567894740090258, 0.053947210657380285, 0.12236631250069027, 0.16699432785953247, 0.18079917096803266, 0.15281730391565831, 0.16608518067627184, 0.13419359922409058, 0.12270123081942721, 0.11680084460925673, 0.07897649441034564, 0.10732851216509458, 0.08764972820157006, 0.2398689779182596, 0.19862813604695184, 0.12385366454480157, 0.11486675605298051, 0.10728813167060576, 0.23412497323607248, 0.13361607618149252, 0.1068488874983403, 0.08383919920531974, 0.16445073208981947, 0.19211231310281063, 0.15422247770813205, 0.19326781884076136, 0.18779425851760373, 0.14551034197211266, 0.8371617620991123, 12.691958335138137, 41.72773891879667, 63.47676769379647, 61.50139147235502, 58.04089215493972, 38.51043831917548, 45.510570772232555, 46.691545440304665, 30.828021341754546, 10.50264427738805, 1.4956211971659816, 0.09218002744619885, 1.380636057546062, 6.097659795515, 11.219683943256255, 10.160346877190376, 14.406139023842352, 10.982897320101339, 9.21604214176055, 6.393067221487723, 8.544927547054908, 23.675277310033, 40.43529833516767, 52.71754549395654, 54.95803079297466, 54.56577416389219, 49.28693463725429, 50.057852960401966, 49.43539634827645, 49.996722821266424, 51.25596838612711, 52.41294207111482, 50.71780350900466, 46.490139576696585, 41.01480107153616, 39.79436735953055, 42.52468609040783, 48.964492274868874, 52.977975183917636, 51.604729852368756, 57.86897467028711, 54.15684746157739, 56.82414547089608, 54.09923176611624, 55.53106946329917, 54.4882014489943, 52.877389923218765, 53.077101322912405, 57.50308421350295, 54.042757480375236, 53.667461179917865, 45.29967277280746, 41.10317599388861, 39.10113157764558, 40.46857180133943, 38.201622270768695, 43.84404197815926, 45.96000771368704, 54.60328378985005, 51.491538093936065, 61.27782029490317, 48.30177645529471, 37.878826895067775, 53.45772027969361, 50.999198267536784, 56.43980418482135, 56.218005918687396, 58.167070881012954, 55.11723979826897, 57.948657620337706, 54.242939564489554, 54.243296500175234, 53.021352675653276, 46.53147351357245, 38.7622348723873, 40.29773689085438, 39.05267853890696, 42.18649541178058, 46.064527111668745, 54.881399446918124, 55.73065142477713, 56.10945824653872, 52.98205052652667, 55.90291015563473, 58.10137510299683, 54.12064006251674, 48.882334309239546, 41.157351770708644, 40.198657820301676, 41.9918752485706, 43.6653740944401, 43.1857035236974, 49.75475965007659, 55.050551660599254, 57.11302803408716, 57.977035968534416, 59.67429261053763, 56.9910462440983, 62.767724760117076, 57.7782698600523, 52.974515653425655, 41.90885436150336, 29.312984289661532, 15.82239902788593, 13.00698055375007, 8.60316493818837, 10.611019365249142, 10.429041981697083, 22.961613824290616, 16.886084041287823, 9.282946009789745, 7.752037086794454, 0.8761580276393122, 0.4330912298492847, 0.9872506438724458, 8.570599459832716, 31.261398138538485, 48.85833724852532, 51.33742816986577, 56.713879800611934, 48.1093567417514, 62.322810311471265, 68.67652831539031, 37.85863845579086, 6.934463151039616, 0.38276737375605496, 0.09256012196983061, 0.2072706650341711, 0.22587409903926237, 0.11794725688354624, 0.12226528082523616, 0.10841789685430066, 0.13142259791493416, 0.2168622390637475, 0.1199439041797192, 0.18872769068806403, 0.17687186718948428, 0.07726472456969562, 0.29925055201015166, 0.10211268680230265, 0.14385007622261203, 0.2039278863418487, 0.1771608202327644, 0.12081778067494593, 0.14860093984152042, 0.1939703521108435, 0.14052539252706114, 0.12326910115417936, 0.15856308592182977], [0.07308292638270125, 0.029587449445839853, 0.0813784635054969, 0.08408708227497917, 0.03745244898562951, 0.025698787142192165, 0.04610176551185789, 0.062245969179897546, 0.025521815086023945, 0.01287490717180434, 0.07030182037382357, 0.03933175842488005, 0.058954085538824724, 0.04034685939850827, 0.09956427233954591, 0.10371975540634125, 0.011912372278710528, 0.09392607206058118, 0.030262855542523247, 0.06772605657217003, 0.039834901990909735, 0.09211375317986935, 0.02530921994137668, 0.0371819471700057, 0.039298019912694736, 0.06586634749246222, 0.20894965397254114, 4.495821672101175, 23.88261575852671, 45.527829200990745, 54.951868749433956, 39.49143094401206, 30.785312614133282, 24.385873502300633, 35.76532833037838, 32.07832390262235, 10.439233279997303, 2.0711683457897556, 0.22534598866778038, 0.023272100220163985, 1.9371834902032732, 4.784807687805546, 3.6401791726389243, 8.551528896054915, 2.9450775682926182, 5.754411220550538, 7.263630417085464, 6.381334431709782, 14.299436826859752, 34.62924126655825, 48.04262938037996, 52.777373406194876, 49.23499461143248, 46.78649033269575, 41.18599291770689, 40.96213932960264, 40.69413554283881, 43.818664243144376, 42.58072891542989, 40.8849274727606, 38.05643966121059, 37.5823074771512, 37.874425995734434, 40.856325549464074, 45.7120237042827, 47.663222435982, 52.15148864253875, 48.756081058133034, 50.059355228177964, 53.01281759815832, 50.83534909832863, 52.841986610043435, 52.40045716685634, 55.02150650947325, 50.29037106421686, 53.208045728745006, 52.73483530167611, 51.6112135302636, 46.05747469009892, 40.151059858260616, 36.943137645721436, 36.863552754925145, 36.65639277427427, 40.42372734315934, 45.126535431031265, 48.53368659173289, 49.82759414180633, 54.3735937149294, 45.13379573822022, 35.473629505403586, 55.1683835829458, 51.03530368497295, 53.60234199031707, 51.89944890237624, 52.812521765309, 52.03491580101752, 54.58408771022674, 54.58150679065336, 53.12308719081264, 47.843329829554406, 40.207392938675426, 34.541329183886134, 36.30578387168146, 36.32572127926734, 40.45392174874583, 42.08169360314646, 48.33317110615392, 47.49232476757419, 53.95579068891464, 51.15990561823691, 53.54422815384404, 51.77395266871299, 49.59868069617979, 44.30120991122338, 38.491010819711995, 37.30845935883061, 38.115357583568944, 37.32015586668445, 38.19851967596239, 39.43088131566202, 44.42714545034593, 46.95967082054385, 51.19983142422092, 49.4923177842171, 52.38016674595495, 54.892272257035785, 55.8765047596347, 46.36186238258116, 34.29213708446872, 20.987090718361642, 10.335957273360222, 4.084307921509589, 6.963032224485952, 5.352476633364155, 3.7746451314418548, 2.674745854831511, 3.404160108297102, 1.813358553955632, 1.4912655276636926, 0.5306224044292204, 0.1400986968749954, 0.903546896673018, 7.176673921846575, 21.34729373839594, 38.8347634192436, 43.69044980695171, 31.978285812562515, 37.346016053230535, 48.660288933784734, 51.58405503919048, 26.53426939441312, 2.5304205283041927, 0.06175312566600981, 0.0957403214828622, 0.03840986353855941, 0.019714232767000794, 0.006979932894013943, 0.02358590132526813, 0.03692761364002382, 0.004186824681387554, 0.04604123690496049, 0.05047474860123569, 0.06179328399500059, 0.024403763386691292, 0.04736820078124443, 0.040249098918490836, 0.023215721894596374, 0.014923417662841179, 0.0401708813414218, 0.06876967516877959, 0.03540729300209111, 0.030400542609934366, 0.02177322621367151, 0.045733587485888315, 0.09478715488747244, 0.03440041598233004, 0.019691263535811056, 0.039515550578794176, 0.03519921586097729, 0.024769558879216353, 0.029865301875097137, 0.022305764573355837, 0.029054054982900143, 0.04209111136714778, 0.06023776927782644, 0.03046760020116645, 0.016398466334888534, 0.06669306361507024, 0.010188847776472328, 0.07852794993067942, 0.023208681546572237, 0.089224498538721, 0.03630576091968725, 0.05387216085387815, 0.06678315555496563, 0.042693317762666175, 0.007370686573502158, 0.05862670935570233, 0.06789893197316317, 0.045981612281813744, 0.049155085542870146, 0.06907388868351137, 0.2136479792816024, 6.079814482119776, 30.2978188760819, 51.36457097145819, 59.92561455695861, 45.66264106381325, 32.81603347870612, 34.66078496748401, 40.45801670320573, 33.33961694471298, 11.397624227308459, 2.1462638387756963, 0.1838115206168544, 0.12641664233899888, 1.0903861806277306, 4.082283733352538, 5.180081600143064, 8.532379884873668, 7.942926585674287, 7.172270080735607, 5.755587441305961, 9.006594438706676, 17.836425304412842, 37.4294017207238, 50.280969142913825, 54.00830730315178, 50.71728967851209, 48.43278361905006, 44.69658874696301, 43.407866570257376, 43.404410962135564, 44.43897139641547, 46.02585254176971, 43.305312279732, 40.6134759226153, 40.023304339378114, 38.50722589800435, 42.618348367752574, 48.160171047333755, 50.226095184203125, 54.90640847913681, 50.089408428438254, 52.1665426992601, 54.80318738568214, 51.64840936660767, 54.475128189209975, 53.70781844662082, 53.65219139283704, 51.5291497015184, 54.86371740218132, 54.33564870588241, 53.7109955664604, 48.06419064921718, 42.54123849253501, 38.810401578103345, 38.3428511311931, 39.210608851525095, 42.16630697250366, 47.27393504111998, 49.84566842356036, 52.6236008059594, 55.594400052101385, 46.577761403975956, 37.77016155181393, 54.665731845363496, 51.900892334599654, 54.41768115566623, 52.35151383184618, 54.27977846514795, 54.22285310683712, 56.001793107678814, 55.77311892663279, 55.45148065013271, 50.77896110473141, 41.6898762795233, 36.96994312347905, 37.538204346933675, 37.80121495646816, 42.3722392512906, 45.280484537924494, 49.48495157303349, 50.44820723995086, 56.53147782048872, 51.96714116681007, 55.138655939409816, 54.63769474337178, 52.31250193811233, 46.49338337682909, 41.32570774324479, 39.37821565135833, 39.766436161533484, 39.51466314254269, 40.5548051095778, 43.50287029820104, 47.942973721411924, 51.06875758017264, 54.24516747074743, 53.418547568782685, 54.679883756945216, 58.428430172704886, 56.304513792837824, 49.332567491839015, 36.19071329793623, 24.697850981066306, 12.873094370288234, 5.587927199179127, 5.905586721435671, 7.2574188536213295, 8.112145969944617, 5.830930288760893, 6.329102679606407, 5.165474693621359, 1.9983603300586825, 0.9533366669089565, 0.1459355514136053, 0.869510223067576, 7.663781306435985, 24.877619089618808, 46.1628766213694, 45.526778005784564, 39.475945426571755, 41.02074346234722, 54.78931788475283, 59.35802405880344, 30.134181514863048, 3.338539345610527, 0.14165963166423384, 0.01763794105499983, 0.07348070987650464, 0.047044758459613215, 0.05146192567002389, 0.006079484639133537, 0.03278389385330581, 0.024038956147588553, 0.08564357375425678, 0.008090704364041168, 0.052637192645981434, 0.00704827847056872, 0.039222142734234376, 0.027030671218169794, 0.09992503846484808, 0.03739574698791389, 0.024262286099274794, 0.04000189000620477, 0.015184414242544483, 0.0167550994158392, 0.08182395895522449, 0.024934924703331727, 0.09001075755804779, 0.025544757504136335, 0.15598924500086617, 0.1312033435510051, 0.18063106063392856, 0.2393979410971365, 0.07146923877899686, 0.115773375146091, 0.13134010556724765, 0.15013130772258007, 0.2607732957168933, 0.12899573862312302, 0.15738242185644566, 0.1435716798709285, 0.08785031300278441, 0.16659519605098233, 0.1408368532335566, 0.26068029264288567, 0.14741906535721597, 0.1567760172991022, 0.20380391799394162, 0.1405216846615076, 0.1438012304565599, 0.2490464661030039, 0.17598528895647297, 0.09081102832550965, 0.16600713163854616, 0.16641970062928815, 0.30525046070256545, 7.003789572946488, 32.63168992534761, 58.188800811767585, 65.04757104381439, 50.70950377372004, 42.95866497101323, 35.85647244607249, 46.04323256400324, 40.741027478248846, 13.771441675001576, 3.0559448321019453, 0.45544775923894304, 0.46405055890640906, 4.220558558740924, 12.298572063446047, 11.202052889331695, 15.695169106606516, 11.203885616794711, 12.814885416338521, 13.320632884579322, 8.904566726376935, 18.38318213339775, 40.04693661966632, 52.58549497973535, 55.890503698779696, 53.696753440364716, 51.12949155992078, 46.08719448889456, 45.90132513353902, 45.50455385638822, 46.74247349462202, 46.65819352672946, 44.21017954426427, 42.71428954216742, 42.2392552129684, 40.90134651430192, 45.678263864209576, 49.857447301187825, 51.21294390770697, 57.4053583606597, 51.2138891989185, 52.21401906782582, 56.749467465185354, 54.00210211353918, 57.359419561201534, 56.56967386122673, 55.51046917515417, 52.49304079240369, 54.56722151848578, 55.35327626812843, 55.551308893388324, 50.46345349281065, 45.22197454206405, 40.80291855719782, 39.57025097262475, 42.262071640260764, 44.05512432898245, 50.28756656954366, 52.22360926289713, 55.80041470066194, 57.065610501074026, 48.56477529771867, 41.035707304554606, 55.730388625975586, 53.55281422215124, 57.069909418782885, 55.741959617983916, 56.516435530877885, 55.509790605114354, 59.3221265269864, 57.89709414205244, 56.87077852987475, 52.88981599192466, 44.635407617015225, 38.1072735786438, 41.3829468911694, 39.50509648169241, 44.31456558166012, 47.50362511604063, 53.96136829929968, 54.25890361109088, 58.51418102941206, 51.99307195601925, 54.80821586424305, 56.5551414797383, 54.52078065564556, 49.921970290522424, 43.081595974583784, 40.95804045277257, 42.19734861004738, 41.443025835098766, 42.43385968669769, 45.24768960091376, 48.79473209381104, 52.53797546509774, 56.26126966168804, 54.13056758142287, 58.59666847413587, 60.17302982268795, 60.039633935497655, 50.746538792887044, 40.777187808867424, 27.08544477339714, 14.425305685689374, 8.740373369186155, 11.82378190179025, 10.78881157982734, 10.506988302353891, 8.786433762119664, 8.370808632143083, 9.653190297465171, 4.988547851962428, 2.4900708611934417, 0.5786056780526715, 1.1784343205152021, 9.352233698291164, 28.698031171675655, 50.59747303685835, 56.1845402563772, 44.013759013145204, 50.57904966415898, 63.61275626767067, 65.08686142583048, 34.713583992373565, 4.587626216873046, 0.21359268305522783, 0.1703239758048327, 0.16607370467916613, 0.14083584199749655, 0.16397085461405017, 0.08584880870917151, 0.11819293361998374, 0.12892564157805136, 0.13455280253002722, 0.15945151808761782, 0.18040765407344989, 0.08883421504569632, 0.10603794512609321, 0.1773773779672, 0.26151263185085794, 0.1065816453868343, 0.1464206229655012, 0.14356095463998858, 0.08967586988282782, 0.113229243114831, 0.18320978919584907, 0.09914233409348996, 0.2774532055181842, 0.1547178148382133], [0.04951449952298596, 0.041621733126380754, 0.09250749172943254, 0.05742419263227813, 0.033941655720193545, 0.10170446919097055, 0.03652054899101777, 0.02071442950006214, 0.06142593717442886, 0.028747976044072743, 0.02629328286275268, 0.03780133308722608, 0.029703682220931497, 0.049803318500879316, 0.007404407369904221, 0.012634964603480073, 0.026575536467134956, 0.054169487238170645, 0.022029699044181936, 0.01255215145647526, 0.042590294258608934, 0.06684904677733298, 0.03987519438528726, 0.057539921704559564, 0.0331006367360392, 0.02625529639302723, 0.09662071738632456, 2.119911885069263, 17.47377472539102, 44.13675669700869, 56.92464051708099, 51.1071732736403, 42.09615930434197, 31.588496354318437, 36.537031127560525, 30.985610408167688, 16.60170239786948, 3.3517364052034195, 0.29416817150289015, 0.10781292488137562, 0.776409641388924, 2.8723943329626516, 4.927297099944084, 6.754114531701611, 6.152849505024572, 4.36090047321012, 2.5553060058624517, 8.370616436004639, 12.784940081257975, 29.984095942589548, 44.718597165999874, 53.30983515708677, 51.289206550967315, 49.63009888126005, 46.17644802216561, 42.998139704427416, 40.52183366590931, 39.36315767226681, 38.05281931354154, 38.63507163140082, 36.826364763321415, 39.44463314548616, 39.447241521650746, 45.43739503429782, 47.39297113110943, 51.4666388880822, 49.262309997312485, 50.29176350562803, 52.92362682281002, 49.36443282711891, 48.52804230105493, 50.49020797975602, 50.86973259525915, 51.92751738332933, 52.95550000283026, 52.06087012444773, 54.76461479740759, 51.16336907109907, 49.93759309091876, 43.93988901568998, 37.19380455632364, 38.189164823101414, 34.9563394823382, 40.47550655180409, 41.945889380670366, 49.45917375626103, 48.08662660660283, 54.77739780179916, 45.200075949392016, 35.30752497334635, 56.8473502128355, 50.76587215546639, 50.29403063558763, 48.97164667806318, 51.331548536977465, 49.773708620379054, 52.67907488730646, 50.13732802483344, 51.2631384788021, 42.65721905616022, 36.67387870050246, 34.84113162563693, 34.824065393017186, 38.19869226024997, 40.53383611863659, 43.21203439466415, 47.48775912869362, 46.46845279201385, 52.80826991604221, 51.65845455661897, 52.169237367568485, 53.8235911246269, 49.77590907004572, 46.82467852869342, 40.99093344903762, 38.74754951846215, 39.637041091918945, 40.81830993775399, 38.98950092254147, 38.42336562372024, 39.545916588075706, 43.740095246222715, 45.01096279390397, 49.261882458963704, 50.72828800447526, 52.64372256494338, 52.452601155927105, 46.49161438788138, 29.178211650540753, 20.852343574646984, 7.663704329921354, 4.515322225709116, 5.649681485468342, 5.069113335301799, 9.577253210929133, 5.059000484405026, 5.957850342796696, 3.78749555157077, 1.2214526702319424, 0.7185248958487666, 0.28340638284721686, 0.9967815130949021, 8.6788764884395, 23.05847675569596, 34.06292161633892, 36.25200425424884, 31.914211934612645, 46.486699658055464, 50.77008478103146, 44.101420064126295, 17.61867492429672, 1.3658145238314907, 0.035337375987681656, 0.03585732752277005, 0.027564914123485648, 0.044480551094297445, 0.0748714812160019, 0.013829659569197366, 0.06801416691873344, 0.04879584776297693, 0.05165746961269648, 0.11470282089806373, 0.047251966090932976, 0.05791841127398995, 0.065878015011549, 0.03987919336425201, 0.1087706573607941, 0.03966974492575373, 0.06785475934344916, 0.07498768909323601, 0.00845773325812432, 0.056914050853060144, 0.043562551765071775, 0.04786959383636714, 0.02050458078062342, 0.048052780780821085, 0.03284431903833344, 0.048981363614720684, 0.04720167624914358, 0.040268492434294, 0.007951652702514925, 0.0520016729170757, 0.002298346606098236, 0.01315290228493752, 0.0760444690803847, 0.010244884235303729, 0.017764990991582314, 0.07737691048532724, 0.019886487636775262, 0.04100852570826969, 0.049008954271313646, 0.03147646904953065, 0.06381975126362617, 0.06471917679112765, 0.016334224116778182, 0.10601374440856519, 0.03903185415472235, 0.04847743863900823, 0.019544553867871725, 0.11017075199032984, 0.024844162436502597, 0.02619353821501136, 0.052398429853060556, 3.0080249905586247, 22.553903056729226, 49.783604760323804, 61.57872100030223, 53.97895228478217, 43.58051361576204, 32.911160761310214, 42.41393404622232, 37.418415161871145, 18.057933315154045, 4.214186668395996, 0.17383940007177093, 0.13876443218079307, 0.23994586250234037, 2.4233550217843827, 4.972340128114147, 9.127720171405423, 8.727870814261898, 5.594561398029328, 6.395782482239508, 8.200494906594678, 14.010442476118765, 32.15154082544389, 47.83394752010223, 56.34493773983371, 54.74255538755848, 52.06367069675077, 47.22978092009022, 45.471135262520086, 41.357439717938824, 41.5952883228179, 40.734559489834695, 40.85186189220798, 38.3923279085467, 40.030772532186205, 40.01805228571738, 45.92678131595735, 49.609384844380045, 54.1279709723688, 50.51442077082973, 51.14792277736049, 54.787035065312544, 49.817262618772446, 51.80679467416579, 51.283393598371944, 51.827653838742165, 54.556497758434666, 54.23180003320017, 52.382171077113, 55.543232733203524, 52.75685548782349, 51.79986776844148, 46.76461135187457, 38.51867529653734, 40.36919463065363, 37.33648469371181, 41.661674437984345, 44.97268830576251, 50.62115238558862, 51.25653320743192, 56.04986175414055, 47.25334652008549, 38.70600769596715, 58.0396762201863, 51.82772836377544, 52.287332088716575, 49.92325290556877, 53.28184512353713, 52.763417613121774, 53.791670876164595, 54.80952593588061, 52.07140953310075, 45.99302622579759, 38.67179286095404, 36.73880961633498, 37.076384482845185, 40.01391418518559, 42.44385388589675, 45.67853843012164, 49.49636174786476, 49.50226883734427, 55.16319428720782, 51.23732143832792, 53.451628838816, 55.505954527085834, 51.82265673914264, 48.885009365697066, 42.40672472984561, 41.31862786508376, 41.57787692162299, 41.76790006699101, 40.613844625411495, 39.88498587762156, 43.09563805980068, 44.086887682637865, 48.63101628518874, 51.05733563823085, 53.765642027701105, 55.72035128070463, 56.02493509169548, 47.59502418579594, 34.829788131098596, 22.54307339268346, 12.069800803738257, 6.7719676898371794, 4.738978714712204, 8.184117049940172, 9.66709411913349, 7.464104717777622, 6.98895271747343, 3.856116927439167, 2.0541185380951053, 0.6819775988978725, 0.20651557813248328, 1.4280364301896866, 8.512062987973614, 25.897027407923055, 42.79866756931428, 40.64848699877339, 35.344348184524044, 50.214755612034956, 57.99895809542749, 52.73826737557688, 21.896041170243297, 1.7518261267292885, 0.06080480457674112, 0.021037586453941562, 0.06107899510572034, 0.008761494780980773, 0.04482810603334539, 0.023639307229689533, 0.05509078840634996, 0.011278641365107991, 0.04111995702729591, 0.03090530645192391, 0.03591081578164332, 0.03345330148154209, 0.017931668741268017, 0.04023616352388936, 0.034150119735709125, 0.044280368489243334, 0.051651007661055175, 0.09500846236703858, 0.01807294493060439, 0.034235507895749424, 0.07330330689587901, 0.03065901492992717, 0.05413145863360936, 0.02025413131641765, 0.11192185278501242, 0.11516590572653279, 0.23850042312856645, 0.14065277762711048, 0.11068390066465063, 0.13174568783612023, 0.11919826314213777, 0.07676417804172925, 0.2193496193015768, 0.08987614824887245, 0.12714403516222395, 0.13781140348122967, 0.0922223614648946, 0.1048136446925421, 0.1830463060328076, 0.19479875362688498, 0.1611598635152463, 0.21244534381454994, 0.1296257386885343, 0.14579878939736277, 0.10258868787317507, 0.18333513650201982, 0.12538475254851003, 0.2605545010057188, 0.11284337994912941, 0.12321759706302998, 0.1690048949732896, 3.264254067213305, 25.53331582776962, 55.14117410106044, 69.63161760760893, 63.46449459752729, 53.973429587579545, 42.413722238233014, 48.45964008761991, 41.12845566964919, 22.120694921862697, 4.725972625517077, 0.6115285823902776, 0.4100136278617767, 2.9523265986673297, 6.412254966074421, 14.832470263204268, 16.909145616715957, 15.221735104437798, 11.771495726800735, 7.264589436592595, 12.87493690367668, 16.21307788356658, 33.67568954344719, 49.59855518033428, 60.46907071144351, 55.938446829395915, 56.081177957596324, 50.397871463529526, 49.14946340745496, 43.53451598075129, 43.75433344994822, 42.34895998431791, 41.40652818064536, 40.17126790938839, 44.17755719154112, 43.930647911564, 49.584603309631355, 53.58884511455413, 55.82201911557106, 51.52720420591293, 52.462458072170136, 55.354503969992365, 52.09843858595818, 52.86459907408684, 54.85430763613794, 54.3609558382342, 54.61241114524103, 54.227461891789595, 52.416887975508175, 57.53733827221779, 55.19011351370043, 53.7489523426179, 47.651674978194706, 39.48001684681062, 42.28906539178664, 39.24428239945443, 45.71920164169804, 46.91300246023363, 53.404281908465975, 53.8507103919983, 58.25737953186036, 49.471713573701926, 42.23632520244968, 56.94906119377383, 54.16404893321376, 55.2061991537771, 52.748602820980935, 56.35911318563647, 55.428597542547415, 56.78096017529888, 56.77410779460784, 55.20493615058161, 46.10462157957016, 40.08717621526411, 38.81210388675813, 38.821243009259625, 41.39267829156692, 45.11146176245905, 47.98621000782136, 52.877782160235995, 51.834247343001834, 57.34518135747602, 53.63675686620898, 55.34987557318903, 58.20558071136475, 55.18107245045324, 51.014848524524325, 45.677820636380105, 43.29548674245035, 43.42388945241129, 44.51584200705252, 42.90460294292819, 42.591338926746005, 44.107746847214244, 47.762281894683845, 50.71665425454417, 53.53022921469904, 56.1018527707746, 59.01476960028372, 58.213888291389715, 52.790121109254905, 34.924815393263295, 26.17794755966433, 11.419158039554475, 7.8919710747657295, 11.481498229888178, 12.63374840059588, 16.026114186932965, 13.200817223518127, 17.419769571673488, 9.824045800393629, 4.037482421244345, 1.6991268771310009, 0.42523873669485895, 1.7860468452976597, 11.211956874016794, 29.188107790485507, 46.515168220766135, 46.994944695503484, 42.93091420204409, 61.29653784536547, 66.74951491817352, 59.55092230150777, 25.325743998250655, 2.4338787409567066, 0.10813031510840501, 0.17299644288516816, 0.1422623130342653, 0.20218638462885735, 0.15328020488302554, 0.09835560776052937, 0.21573104895651343, 0.15063485731520962, 0.30972052245370807, 0.2065158998894115, 0.16979283172517054, 0.11032556303806844, 0.2180376630877295, 0.12160242324875248, 0.2539565994013702, 0.263929455390861, 0.1509129778752404, 0.16413675861493235, 0.11213762910976527, 0.13668732266993294, 0.15042976025612126, 0.10352821810351265, 0.2461867364904573, 0.17151424661278727], [0.03803866712616817, 0.04517727358747394, 0.0261716032025194, 0.038122132405518525, 0.02558448682388952, 0.048046372455334475, 0.022439703555597414, 0.02154747542414454, 0.043965751500499826, 0.020876121932580587, 0.03183753586434309, 0.0134495276987793, 0.034906122112466444, 0.05102402981250517, 0.07364715013893382, 0.05507161322560522, 0.130320274000687, 0.06947133509862809, 0.0112778733619639, 0.12480617996545569, 0.037677242165251125, 0.021005855092117866, 0.02126718300484842, 0.03732998600049365, 0.03926358426049833, 0.006506086445428552, 0.019760090790148226, 0.7789805098887413, 9.052875464962376, 33.62872700537405, 54.97948223544706, 46.95385786794847, 36.52746054434007, 38.39665820521694, 33.421237545628706, 35.47611628809283, 16.678137625417403, 6.296906884639494, 0.8310769402211713, 0.29802070510002876, 0.37540732191935666, 1.1284096370781622, 1.7967859271072575, 6.2529013233800095, 7.306111156940461, 3.1640362835699514, 4.393708157923914, 3.357857018709183, 7.442561099606176, 21.77401231181237, 39.78713058656262, 51.22419718773135, 53.544483107905236, 51.46663496571203, 46.998972969670454, 45.867883005449855, 43.40595245361329, 41.54574878754155, 41.02491294184039, 39.582163210838075, 40.89081495038925, 41.64218418059811, 43.57344550471152, 47.50319365532168, 48.12785463948404, 51.274709470810436, 51.072056293487556, 52.412573368318625, 49.72529088297198, 47.88471475724251, 47.45155172963297, 47.80859724167855, 49.76483621904927, 50.88789316915697, 54.65240363151797, 51.80401371371362, 52.88234779911657, 53.416817803536695, 51.38102531433106, 50.23045293746456, 42.767053265725416, 40.925782880475445, 37.479121685028076, 39.316756033128314, 41.659144509223204, 46.809942183956025, 50.924143714289514, 54.93639107673399, 48.62292835789342, 36.440634958205685, 55.28093207267023, 48.9517524165492, 50.381217079777876, 44.34947075382356, 44.87875930724606, 45.43359817997102, 48.239293098449714, 46.34594148205173, 43.59717976662421, 37.994015139918176, 37.258441294393236, 35.45203685760498, 37.2479764107735, 37.17968794607347, 40.540708111178496, 46.56213860357962, 50.50062187256352, 51.37039961353425, 55.57941659804314, 50.47817807043753, 52.574010279870805, 52.31874242905648, 48.395077874583585, 47.621959101769235, 42.607903095983694, 38.92889638100901, 38.5797897461922, 38.812880516052246, 38.76513350394465, 38.7640352402964, 40.050070593434, 41.54455246463899, 43.49739074707032, 45.162872268307595, 48.860588689004224, 50.74876669914492, 51.570460104173236, 43.846709189876435, 30.500485781700384, 17.94419046371214, 8.656595464675657, 3.112334541736111, 2.77580768350632, 7.163795799978319, 9.054583657172419, 5.225865956275694, 4.995965053958278, 2.5447111937307545, 0.969767720708924, 0.05449373012168273, 0.03231795534731881, 1.4894477542369597, 8.846985351654792, 27.683147307365175, 37.52036148501981, 39.8665193588503, 44.911883723351266, 56.605842036585656, 55.973304933117284, 44.58342836749169, 14.815315777255645, 0.6462586574977445, 0.06720442730452746, 0.048199666648983, 0.09192872762439713, 0.021159630005938873, 0.03950643796293486, 0.017331279889349977, 0.028735525200083375, 0.05523846717551351, 0.028399737371552377, 0.030612691508365736, 0.0517976445506417, 0.03631521444467287, 0.04439350052346145, 0.02282364192538925, 0.05785084231906842, 0.021511702948520263, 0.03986389458840413, 0.04050719394018093, 0.009767461113721855, 0.036884632277032064, 0.07057424890057695, 0.011489968634240571, 0.048900449408158186, 0.06374883833491514, 0.0017082113622417375, 0.03613026549799308, 0.04002679552462313, 0.032711352987755696, 0.03280887981095622, 0.06705870205957083, 0.01746376330453542, 0.06794583953676686, 0.04600699660518477, 0.07904806234423192, 0.022568597848857605, 0.09297056889702236, 0.04549536478495406, 0.03452252273658111, 0.055286454923090436, 0.047428966875398354, 0.09116411824981052, 0.07016810738751966, 0.022939828735205437, 0.059429703565735015, 0.06975962930629331, 0.03422062663782028, 0.015049989752080894, 0.02692946142727329, 0.04287014617734859, 0.07010385559331025, 0.04501919900517791, 0.9992311558415814, 12.097680030330537, 41.197838475627286, 61.551350701239805, 54.16302519459879, 43.557661887138124, 45.37006362791985, 38.591596080410866, 37.69611897007112, 20.27793795831742, 6.232349084269616, 0.8200480933150938, 0.07623624387046984, 0.19618661383226996, 1.6679819096480648, 4.353409726773539, 5.644693211201699, 7.00313110505381, 7.383259765563473, 6.7817750861567845, 7.744603705021643, 11.763577442015372, 26.636551080211518, 43.851682755254934, 52.60046274431291, 52.897425390058956, 52.62354981514716, 49.739764428907826, 47.194530579351614, 45.003878993372766, 42.00264999943395, 40.90054242841659, 42.05799072019516, 41.204118190273164, 43.18677433075444, 44.87805720298521, 49.30414599757041, 50.29160268845097, 54.16600227355958, 50.99982584676435, 52.13535593402002, 51.30187972899407, 50.60748684790827, 49.406343352410104, 50.19681861323696, 52.44207351438461, 51.264534842583444, 56.029206552813136, 52.16530323028565, 52.237608202042125, 55.40282364814512, 54.354452548488496, 50.96250841694494, 45.17959725472235, 41.992098823670425, 37.97635662940241, 41.30561736322219, 42.86640297982001, 50.129130271173295, 52.95989697979343, 56.76949116491503, 50.026921149223085, 39.6745938639487, 55.258998178666644, 50.35516469709335, 52.40937663662819, 47.37128434642669, 47.49356423654864, 46.93869790723247, 50.610150137255275, 48.81996470112955, 45.92464362421344, 39.90653537934826, 38.59504776616251, 38.52017364194317, 37.84660854647237, 39.416329322322724, 41.005493287117254, 48.76402385773198, 52.27963639843849, 52.07541035067651, 57.355144177713704, 51.563937202576675, 54.877473154375636, 55.91576376268941, 51.05928897857667, 49.166090334615404, 44.330564929592995, 40.870920688875266, 40.26798179072719, 41.14850682597007, 41.93331033952775, 40.97355734917426, 42.48730198029549, 43.859829518102835, 46.24740369858281, 48.16260291684059, 52.389188197351274, 54.83180499845936, 56.07764390207107, 46.13030918182866, 32.9575780899294, 19.831970353280347, 11.576609823011584, 5.457472599321797, 5.415446854406788, 7.861920325986802, 8.83940831307442, 9.05567309548778, 8.955028999236323, 4.030502073226437, 1.4807977022663241, 0.15246455107004414, 0.11201663318300441, 1.9093045087591296, 10.275222313019539, 29.634104813298872, 41.66203921841037, 46.11232119221842, 45.82292872090494, 60.999798774719245, 62.42982825925274, 49.59598995024159, 17.240889879965014, 0.8722249935230902, 0.11958719065953648, 0.025173097608550906, 0.055937227462568594, 0.06974261449349504, 0.018500965914779136, 0.0540436611270472, 0.030993170991179445, 0.030969380130690914, 0.001434003835686693, 0.030337872787288604, 0.07270387373864651, 0.02737318338345616, 0.03625411893271151, 0.00934612999234589, 0.08333759547601785, 0.004408192969182687, 0.03724464380572881, 0.02256809223082758, 0.042765096370731635, 0.041551241546028087, 0.07321361332170426, 0.038396472321642984, 0.05506437752516039, 0.015815137303434312, 0.08029274071656889, 0.20222096583775936, 0.09973277337849142, 0.16404009364064664, 0.10001480864781527, 0.06793828590983345, 0.17651139217759335, 0.21837831174414005, 0.2595651137732691, 0.12949355787807895, 0.1539560323280673, 0.16638403157553366, 0.17030379704890714, 0.14545005085247179, 0.1623942916311564, 0.20015308002550758, 0.19528909586369994, 0.18804188877824815, 0.10831715629225779, 0.20348151755188743, 0.16251363280800082, 0.16464514988324336, 0.155543289898384, 0.23434520819254462, 0.23238638265719339, 0.11842715734195326, 0.11062753957606132, 1.3538190578260731, 14.874884813062607, 46.405949823318, 66.77052313281645, 59.070012261790616, 46.66557542739376, 48.90910056329543, 44.714635572125836, 45.83638637296615, 22.99137676915815, 8.54466082588319, 1.2498002523376097, 0.4814359131118944, 0.874796536180281, 5.852884775207889, 6.731169156489834, 12.956853643540414, 15.888749841720829, 10.496291998893986, 10.936365262154611, 7.647993276196142, 10.241524250276628, 26.162044309800674, 44.50658521344585, 54.82756099393291, 56.3449534293144, 55.632407819071126, 50.53315401077271, 50.35866345128706, 47.1960916826802, 45.41870886279691, 44.69268991101173, 44.73480832192206, 44.90323489712131, 47.055576693627145, 47.420000183966856, 52.47361721531038, 52.30313924051101, 55.30129309623472, 51.93058467680409, 54.05591310993318, 53.42941253416, 52.42105353263117, 50.720455031241144, 51.425665809262185, 54.24645400816395, 54.62268383272233, 58.89651406195856, 51.79920488788236, 52.69346998583887, 58.036212767324145, 57.50265667515417, 54.618039746438306, 47.80700868175876, 44.34189273465065, 39.955678755237216, 43.18742544420304, 45.208634561108006, 51.63663441135038, 55.5679318981786, 59.475259780883796, 53.049287796020515, 43.93111467361451, 57.26107397387105, 54.41982669215049, 56.08359413762247, 50.57705710011144, 48.25069542854063, 49.9133175419223, 51.403018043887236, 50.2719045454456, 47.28145422474031, 42.38592832319198, 41.836922014913256, 40.57504061729678, 40.71654012126308, 42.07897147824688, 44.67076386174848, 50.73248886292981, 56.01035171939481, 55.883321838994185, 60.874059354105306, 51.50468587875367, 54.57817669837706, 57.31526936254194, 52.90253623839348, 53.50426704652848, 47.259583088659475, 42.53969700105729, 41.66517319217805, 42.81131329074983, 43.43279715507261, 42.89157675158593, 43.8540675563197, 45.92103896602508, 47.49491353188792, 49.94865025243452, 55.61101913452149, 56.17615422894878, 59.06413655127249, 47.91223018400131, 34.26438239312942, 21.88050073962058, 12.083026055366764, 7.006957377156904, 6.968986382407527, 14.804506705653283, 19.098418489579235, 13.77021691491527, 12.834129544996447, 8.368980807642783, 4.342205476376319, 1.0097600231247565, 0.4564594855952648, 2.5634206543045663, 11.393644982768643, 34.02475303219211, 48.771178260926284, 51.83558094886042, 57.4932586762213, 69.55550009204497, 69.30315832937919, 56.620315582521506, 20.474493811207434, 1.3682797334847914, 0.15193732936055432, 0.14337700160761035, 0.18185620376419637, 0.12041412894764256, 0.1140440159266995, 0.13404445722699165, 0.1009400130339688, 0.1514770637356466, 0.11183342325591272, 0.13904961607148572, 0.10365189533800849, 0.15487870862407072, 0.10949876264578874, 0.1012244538193749, 0.21274048684825822, 0.07260683338127791, 0.20078004638273872, 0.1746706667566492, 0.21629436872899535, 0.08651596403891042, 0.13244722519190083, 0.1983452657417905, 0.15446468406627256, 0.08744737373725062], [0.027929928206327944, 0.0987079928839399, 0.015959838863402125, 0.04870153850905838, 0.025029528901101123, 0.07397487489206177, 0.06400300332555367, 0.018040434074317737, 0.05880196729013997, 0.040510645166279814, 0.045998259372408354, 0.08808126552931725, 0.04613268482048185, 0.08289177060848282, 0.010267982743830692, 0.0644760664492365, 0.04336536073336198, 0.07067206300674908, 0.06024474450837701, 0.06480482542106221, 0.03256594566928764, 0.017989085115973028, 0.025434789413045493, 0.05058267506800833, 0.0624017569897396, 0.06369510109746648, 0.03598724454340916, 0.4621162788281518, 6.383968793576764, 27.241317802859893, 49.24141553140456, 50.15360586104855, 37.324713660824685, 27.091712720932502, 37.25850797468616, 31.61668838993196, 23.674104521351477, 8.616450986554547, 0.9249456322962238, 0.2314929709198975, 0.12115070716507974, 0.8742381500140314, 4.174963947265379, 3.290280709343572, 4.8398606046553585, 5.093297198895486, 6.6398862869508815, 5.976711550066549, 6.754921559364566, 17.429959889381163, 29.203014758325395, 47.175687513043805, 55.55174819884762, 54.11128520965577, 50.09295032870386, 50.0377861146004, 47.82641656937138, 46.43792498496271, 47.515992349193944, 46.075062597951586, 47.10559083569435, 47.18687019040508, 46.8340608381456, 47.36101558131557, 52.08626354894331, 52.19275982149186, 51.61941520629391, 51.58253708193379, 49.28827216548305, 49.334936603423095, 42.915652259703606, 42.8853323382716, 48.1835130722292, 50.434329894281205, 51.89358495896863, 55.38370993829543, 52.97816738005608, 52.000418555352, 54.10791197130757, 51.712304776714696, 48.75218222218175, 42.3472459085526, 36.53500326218144, 38.2274785349446, 41.18950343901112, 48.93732986142559, 50.94746612733411, 53.44968334321053, 50.00133552858907, 33.43141609622587, 53.147131319968935, 48.81456359740227, 48.394344391361365, 42.82222140219904, 38.34969958951397, 37.391013483847345, 38.643532183862504, 37.490100399140395, 36.14638267024871, 37.19480868308775, 35.79604833356796, 34.62680939705142, 36.32876503852106, 40.30192990456858, 41.97729187626993, 46.12310378782211, 47.495129262247396, 52.0216150437632, 52.016594409942634, 47.51643949939359, 52.20899843400525, 52.767390974106334, 50.55497023367113, 48.826213036814046, 47.59842488073534, 45.78049259801065, 44.62673917893441, 42.94911007727347, 41.400146484375, 41.39739690288421, 40.30340471575337, 41.222529795862016, 43.9227129567054, 47.413085045353064, 48.42587240280644, 52.24185612893874, 50.75649769075456, 45.41896381685811, 32.40244503944151, 17.12239899942952, 9.832195505019158, 8.012741342667612, 4.270097603721004, 5.066611843724405, 4.360788195363937, 6.650316849831612, 6.492731215492372, 1.524998156293746, 1.3603176897571934, 0.5436241422449389, 0.1760457486154572, 2.4087986157786463, 10.51828767022779, 28.396251855358003, 35.34950610130064, 29.8381543544031, 37.84463167190552, 53.876692172019716, 56.43088863741968, 37.33181315083658, 11.746115050008221, 0.6781619294516502, 0.03570799017325044, 0.02429007785394788, 0.04687805389685016, 0.12390497711396987, 0.026198111759919315, 0.056543180028036724, 0.027151481368609016, 0.05128566799084506, 0.01441405633569605, 0.04419369713192986, 0.026796424513562556, 0.05826498945093444, 0.09219461376027716, 0.10677030219906762, 0.07052105941599415, 0.023897427149237167, 0.10396388464517171, 0.053326246599035884, 0.010213230439882365, 0.09180146509841566, 0.05061416511213587, 0.010477760600136414, 0.021215947044472543, 0.016861706296162262, 0.05051535509166218, 0.018362428489772063, 0.06502191941704481, 0.0589545643437774, 0.03720578399576968, 0.01243209686025136, 0.027115141987920772, 0.04719454397056853, 0.07987057264413565, 0.0547364114543363, 0.04637880588791544, 0.06594568355790069, 0.043778714964226376, 0.05880318536993958, 0.007334450614683691, 0.06127210671923334, 0.03050071052125385, 0.08809905409091905, 0.006556721505588822, 0.03384791337133896, 0.09039017792430618, 0.0728277041907272, 0.029175725067034367, 0.049656168332383524, 0.029938716080880938, 0.05341393685328865, 0.02447125381760059, 0.46332853635953325, 7.24166710530558, 31.445204327183387, 55.26194780103622, 54.73964106652045, 41.22708759000225, 30.60714875498126, 39.2372731239565, 38.9505753209514, 27.217250139482562, 10.861953977615604, 1.2102663156486329, 0.14477293637971725, 0.08822470017138027, 0.9506057779635153, 2.446805892452117, 4.77522631806712, 8.310082497135285, 6.313839756673382, 9.577684671648088, 9.709443949883985, 11.745273701606258, 21.47515908364327, 32.83402735187162, 50.20326306743007, 57.981103466403106, 56.31331166913433, 53.34666621300482, 50.65116636214718, 50.36415084715813, 49.70773827645087, 48.10688957091301, 46.640413422738355, 47.29125230543075, 48.72395684642177, 49.154695849264826, 49.784350010656546, 53.6894029186618, 53.6227265481026, 51.47314610019807, 54.48086661677207, 51.97374643818025, 51.144710356189364, 45.732141540896514, 45.45125276811662, 50.368273258209236, 52.59072349917505, 55.29890829516996, 55.60136618152742, 52.17414425265405, 54.52994723473826, 55.99655674349878, 53.41589996891638, 50.30331880815568, 43.824371291745095, 39.111518013861875, 41.59343304172639, 43.49803793814875, 49.656115962613015, 53.95373536694435, 55.6879093570094, 50.48718775472334, 36.13070103429979, 55.80570597802439, 51.55164057208646, 50.65392378837832, 45.40998943390385, 41.430121237231845, 41.14417260692966, 41.9348047625634, 41.22423994925715, 38.787098776909616, 39.47762812337568, 37.757900222655266, 36.619020431272446, 38.29806158619542, 41.568984908442346, 44.315977634922156, 49.506320645732266, 50.545219221422755, 54.37261312238632, 54.669634603684955, 48.77206079421505, 52.86587776676301, 54.431076049804695, 52.32406116301014, 50.71363795188166, 49.18453724153581, 45.88043066763109, 45.66387268804735, 44.244594420156176, 43.797291248075425, 43.67438770109608, 43.061999813202895, 43.28470414684665, 45.53878830325219, 50.208217020957704, 51.34796365614861, 55.02441298577094, 53.47177413202102, 46.56761030997, 32.5155818846918, 18.03190250550547, 7.6124443450281705, 5.123393545227667, 7.100819695380427, 7.873762451833295, 8.522945604016705, 10.322213288276426, 8.80986305975145, 2.7286328471476033, 1.1515719683900958, 0.2578279634396876, 0.1560707720777681, 2.3744582649200194, 12.116742749367992, 31.690134771408577, 37.031226235051314, 35.41189924363167, 47.97783574750347, 62.49059754033243, 63.625637331316554, 44.7793899813006, 14.687663220590162, 0.7717806317152516, 0.03866806198211928, 0.04025038977664325, 0.10186907084238145, 0.03895632554626754, 0.05133261002840535, 0.06403974490240216, 0.08848264963636476, 0.031999643899560455, 0.04645042744795642, 0.04685891319006201, 0.038015190361728596, 0.0322598245956244, 0.06790041818373627, 0.11490048690428657, 0.048050873221889626, 0.031562244083972714, 0.0338707925871976, 0.006490000514238472, 0.025989984823090416, 0.048913748694523695, 0.03981494540048223, 0.06225746815964099, 0.05401405182877376, 0.07894990349849386, 0.22969303202004204, 0.20453511827415038, 0.1547715942104978, 0.1709923721970089, 0.15151875424048594, 0.16592565052691968, 0.14673125629703845, 0.1032974417772024, 0.19020133741920997, 0.14032895226151715, 0.19104418735350334, 0.1970991318023974, 0.10623641552463656, 0.21585334723274555, 0.09050974126664862, 0.11914476722238526, 0.09489413140521896, 0.15340339182124985, 0.11761668228333998, 0.24392354422278945, 0.1954050662536775, 0.2728749415086162, 0.16290481262389692, 0.13000847621550485, 0.12420011248679892, 0.11304931204405524, 0.16765425131926615, 0.7121870198076772, 8.594307245746736, 36.0068678855896, 62.967585209877264, 62.37794706898352, 46.75188326066541, 37.88806799919375, 50.027011363737046, 43.87630739519673, 33.003709085526005, 12.010155281712933, 1.8036680932967895, 0.46714178496791475, 0.9439337037263379, 3.5912902605149055, 11.07635465360457, 10.290581334021784, 13.116178358754805, 13.481586364007766, 15.783045887947084, 12.451705317343436, 8.907757574512113, 20.586834415312737, 33.05350749723373, 52.0202971273853, 60.303985995631066, 60.38989374714514, 55.98524070555165, 54.134133015909505, 53.73016811186268, 50.561822614362164, 50.86884221723003, 49.860298864303104, 50.221478554510306, 50.64223904763499, 52.436484136889064, 52.41644867004887, 56.941902868209354, 53.4339467940792, 52.749563801673155, 56.10040149381084, 54.89817934651529, 53.3507494003542, 47.75008332344794, 46.33732795715333, 52.942481656228345, 55.328937961209206, 56.41650138362762, 58.19466083280502, 55.05010843276978, 55.64467699297013, 57.75442577177479, 56.03556471486246, 53.2521096352608, 45.8101692507344, 40.59418178373768, 43.653183367944536, 45.89142507122409, 53.47901482735911, 56.9496887730014, 56.96546062346428, 52.24524897913779, 40.689915072533395, 57.12033933208835, 53.97604188611431, 53.24380205523584, 48.11447543482627, 41.6010973530431, 41.54502707142984, 42.553401762439364, 42.016437130589644, 40.20047387769146, 41.5724915073764, 39.96727328146658, 37.69431860216203, 39.8346971696423, 43.0033564567566, 47.2956375152834, 52.87567584745346, 52.9105104169538, 56.5798367223432, 57.41983190659554, 51.958190318076845, 53.62103208418816, 57.2736059465716, 56.315774917602546, 53.154317102124615, 52.389843233170055, 49.29703081807783, 48.485680703193914, 47.271134468816946, 46.26117906262798, 46.96365202626875, 46.69539328544371, 46.377179238104056, 48.31381028698337, 52.01235825015653, 53.664358585111565, 58.66295260767783, 55.94838611541256, 48.634209094509, 36.7781235325721, 19.48817853004702, 13.47945357522657, 12.373511887365773, 10.186141364036068, 12.421929624772842, 16.878227533832675, 14.987082250656622, 15.53783989721729, 8.722793306073836, 3.7155967902752662, 1.2379516300655182, 0.45490889299300413, 2.924858975795008, 13.58243344291564, 36.012669071074455, 47.329185547367224, 41.98801171395087, 51.16411039906164, 66.59102762899091, 71.41151858914283, 51.454954147338874, 17.079472580263694, 1.0283586767412003, 0.1297862187869126, 0.17962382355284306, 0.14634261989305097, 0.2945285392624717, 0.10258954589165027, 0.18074897688723382, 0.1535918954158983, 0.14413679228915324, 0.15686278441740623, 0.14763265067050535, 0.10250767407518241, 0.10290631558746101, 0.16132593605547182, 0.2404122721524008, 0.13656415105346711, 0.09007507830017036, 0.19137081660089955, 0.1368706934754887, 0.1389144015528502, 0.16230323442047642, 0.1542411702534845, 0.2884462607964393, 0.1592996181739915, 0.12459176727720808], [0.04402898439776994, 0.042755183192991444, 0.024414341145705794, 0.031125374784272526, 0.03936130643611954, 0.0722965830937028, 0.07550833010745626, 0.05859315087417922, 0.05947511342744674, 0.04493799368520418, 0.03190041827638784, 0.02025236165331256, 0.1129782344064405, 0.10697021284290861, 0.03727144156132014, 0.05233654144009756, 0.12801873137152966, 0.016627750704966245, 0.01919243112957526, 0.041639717040403236, 0.0574688593887033, 0.02301536883497911, 0.02182418829761446, 0.09509045675757433, 0.06329046494718041, 0.058345781083429055, 0.0302875274041247, 0.020547431908668052, 3.103588881992525, 20.71289154791063, 42.39518511679865, 52.158223352124615, 46.68819573617751, 42.39158438098046, 28.990881212296028, 27.61481373540817, 27.359861635392715, 12.969650376227595, 3.169041718206098, 0.16402737658110358, 0.10656765662133695, 0.46525549263723437, 1.0728588243646007, 3.711710211730773, 6.020495497411297, 5.314032993009014, 6.75291967968787, 7.722090771121364, 11.009760652818988, 15.04390758852805, 23.693426116820305, 39.080072372190415, 51.00685473411314, 52.26355468073199, 53.177918003451445, 51.353258855881236, 51.53203264359505, 50.66661657825593, 47.399215544423754, 48.07747963936099, 49.019240717734064, 48.2730019477106, 49.695924097491854, 50.75823530074089, 50.64886785322621, 48.89629794705299, 52.23781216529108, 49.99226700875067, 49.873207384540194, 45.627720202169115, 40.37336018777663, 41.28399333646221, 43.82951744141118, 48.16727445971582, 51.978849441774436, 55.00545617072813, 50.993561821599165, 51.09581408962127, 53.20005978307417, 53.497238159179695, 47.10368848616078, 42.18426358315253, 40.31902751614971, 37.594576651050204, 40.91940902894543, 48.44067542783676, 49.86188350185272, 55.492975404185636, 49.74635401079732, 33.87838586684197, 52.595583315818544, 48.13308315892374, 49.15063619613648, 41.532989317371005, 37.16747368535688, 38.076879132178526, 38.54573965072632, 37.204336120236306, 38.374559571666104, 36.283979415893555, 36.339371127467004, 37.55829080458611, 37.256997862169825, 40.933804127477835, 43.07204892558437, 46.13374125572943, 48.683015146563136, 51.74253056126257, 51.34938355415098, 51.33225064123831, 51.616712693245184, 54.090771213654556, 50.63124464404199, 49.41447834814749, 47.4556976749051, 48.7627883111277, 47.267000290655325, 48.02012282033121, 49.61744923745432, 48.45052842170962, 45.151642522504254, 46.422055075245524, 45.692188278321304, 49.47609093881423, 50.45570288935016, 53.100133480564246, 52.11901926225232, 44.49581438495267, 25.158988352744814, 14.579157713920841, 6.069622693523285, 1.5009257125277675, 5.036266917182553, 6.148066664895704, 5.28409501237254, 8.873251503513707, 7.650765901611698, 3.0483479365225765, 0.5540405478208297, 0.09358963688775417, 0.34438235444887993, 2.3529310716736704, 11.708564239163554, 30.126307356742124, 46.053740593694876, 41.4915337870198, 33.06947154383506, 42.193896924295736, 57.37597980806905, 29.65687221096408, 7.073337118471823, 0.4694444001201661, 0.032000542137651675, 0.134226678900661, 0.06087605458413882, 0.0306171769531624, 0.020942739023256208, 0.026644963185272874, 0.07667668313989717, 0.07093869224791566, 0.05770051671612648, 0.058405244828111706, 0.041169633998745875, 0.021859066365587137, 0.014567280623821482, 0.05365766006551924, 0.026462362298081, 0.01756845113460816, 0.06811574251661379, 0.024871904395460605, 0.028925078335188092, 0.002818399647836604, 0.013741669583044226, 0.050754117884583054, 0.05556399708673839, 0.097835089320377, 0.061147445061754804, 0.0236046340902366, 0.06866197852838425, 0.04967958764022878, 0.026247265876360962, 0.05513792962677056, 0.07585920603765596, 0.0730295300543789, 0.06988565076983745, 0.07506743118527436, 0.06570848741478498, 0.04900967439396247, 0.03020728352449594, 0.03438291087326023, 0.036514607979164976, 0.029823659250753063, 0.012552346808895951, 0.01980244204582226, 0.01862555862434449, 0.07767762297824507, 0.01536394120194018, 0.046324926924200795, 0.052290235255514426, 0.07346298260193679, 0.05632335492860406, 0.14281907509411537, 0.02329937678070799, 0.1020836673917309, 4.495107310433542, 25.679237804105206, 48.24167005477413, 57.313457227522335, 49.34531127252887, 45.435163205669774, 36.34506640895721, 32.59957748074686, 30.964968935135875, 14.261503584923284, 3.52445773059322, 0.3268068265770713, 0.20068165004974414, 0.8315304642723453, 2.589862822524963, 5.462427533441975, 8.770583464253335, 7.422818829936366, 9.558519970986152, 12.386926393355093, 13.444286584854128, 17.513282798951675, 26.842283318119666, 42.45080824821226, 52.47047147443218, 55.92061181222239, 55.47319881377682, 54.453398258455344, 53.930714976403024, 52.575383109431115, 50.522473396793494, 50.38388821386522, 51.79978147629769, 50.58499989971038, 52.019128261073945, 52.29677323372134, 52.29055627699822, 49.61180494677637, 52.925886108029275, 52.25021862214612, 50.909340689259196, 46.32534903864707, 42.05835550062118, 44.4991405548588, 46.10358607384467, 51.17515579346688, 53.20650423726728, 57.64843940734864, 52.163549930818625, 51.94951403525568, 54.15159540791666, 55.46500106011668, 49.86604513660554, 44.18533132922265, 41.470164714321015, 39.855234699864546, 42.49615476977441, 52.03368417678341, 53.045008490162516, 56.88403614105717, 50.259686362358835, 38.27205627195297, 54.718126866125296, 51.61290799417804, 51.346986985975704, 44.69980116813414, 39.89312871809929, 39.94720251329484, 39.57481661150533, 38.95507427953905, 39.17841403715072, 38.32343539884014, 38.305188532798525, 38.511850372437515, 38.32426694131667, 41.29542312314434, 44.92797720816828, 49.97911137919272, 51.66632675355481, 53.80718777256628, 53.75826797177715, 51.5621760583693, 52.49869685019217, 55.39505343283377, 50.81933798328523, 51.927772337390536, 49.70164291320309, 51.69419911599929, 50.53064369386243, 49.86408395151938, 50.104007490219615, 49.5476310483871, 47.39599135614211, 47.808691378562685, 49.82971222169938, 51.46472084906794, 52.04370191020351, 56.335018065667924, 54.94958592999367, 45.696036123460345, 28.647236477944162, 15.994109607511952, 6.881587149635439, 5.847699892136359, 6.501301594318883, 10.283269055428045, 7.585314781435075, 9.698021027349657, 7.513646704535331, 2.1663436774284612, 0.8518755532080128, 0.1954102756515626, 0.21207342344907024, 2.376179449981259, 13.147656359980184, 31.997046509096702, 44.20614342535696, 38.93674112135364, 36.73889983084894, 49.205682739134765, 62.78275136024722, 35.94803233300486, 8.687746928584192, 0.5750351567422191, 0.0684005280415858, 0.02036522172631756, 0.02592608351410637, 0.06137322266435912, 0.045933953952044256, 0.08319666594146721, 0.03470272576856998, 0.06353201246970604, 0.07622184907837261, 0.05804941613948154, 0.035668762641087655, 0.06424935038892493, 0.026322694893385616, 0.051200233865529306, 0.07666598855247421, 0.08570096906154387, 0.07601009471522224, 0.0410648140185062, 0.010916854427646725, 0.03642905127978133, 0.047669545296699777, 0.08791176857607019, 0.017530158229713, 0.02826121526830379, 0.11026764679099284, 0.13702064752578735, 0.2078237805155016, 0.09730612859129907, 0.11636427408384702, 0.14954889703902507, 0.2269099418434405, 0.29445922362708277, 0.19058695543677578, 0.14139320160592758, 0.17434253597692137, 0.13070414533778546, 0.1990009144309067, 0.14295689431169342, 0.09362548214173125, 0.17450071781152682, 0.16962291342356514, 0.15544443391263485, 0.08506880096730687, 0.102698705759981, 0.10589490118887156, 0.15812025645807867, 0.14097487163399497, 0.24674458639515987, 0.21549878641963008, 0.35729626794495895, 0.0832583360193718, 0.2673879133597497, 4.80362182663333, 27.337625718885853, 54.628182995703916, 63.78330484513314, 57.253091950570386, 53.20899886469687, 39.9351373026448, 40.196273019236905, 37.3596933580214, 17.844003323585756, 4.527612482347797, 0.4918962614911218, 0.6395747548630161, 1.479202768495006, 4.313756035220239, 9.936846302401635, 13.06822051925044, 13.608958471205927, 12.171215645728573, 15.965693016206066, 17.84725889082878, 18.801814740703954, 29.292640916762817, 42.11820694708055, 53.75085861452165, 54.642307450694425, 58.50640689173053, 56.297147581654215, 57.6254778523599, 55.40643222870366, 53.20274268427203, 53.313467271866344, 54.28988249071183, 52.70374267332016, 53.66771613397906, 55.38409433057232, 52.831788447595414, 49.08407749668245, 53.67773386739916, 53.427302299007295, 52.831200092069565, 48.392685228778475, 42.110232768520234, 46.45046480240361, 47.54004824546076, 53.80368901837257, 55.98015339143815, 58.931415311751834, 53.803312470836026, 52.364830278581195, 55.08570394208355, 57.034090334369296, 51.30545693059122, 46.45381842890094, 44.80282614308019, 42.73296394655782, 44.71500819729221, 53.22539044964699, 56.15517347089706, 58.72649108209918, 53.168233671496, 41.85926775778494, 55.475858180753654, 53.475119913778, 53.15346594779722, 46.786051027236454, 41.183541436349195, 42.000692736717966, 41.504610969174294, 41.6020465666248, 41.11180520826771, 40.99308683026222, 40.48183333489203, 41.12300749747984, 41.20505563674435, 44.31607569417646, 46.73691941845802, 52.61926266454881, 54.23957809325188, 56.3700173747155, 54.647618339907744, 52.93450355529786, 52.91955540257116, 58.4310071699081, 53.83340881716821, 54.715738142690356, 52.09538698196412, 53.78167275459536, 51.36122518970121, 51.68869603064753, 53.08291819787795, 53.541988480475645, 48.32462426154844, 51.94854913219329, 50.03067485747799, 54.69822083750079, 55.01747039056594, 59.0708791055987, 57.66174408697314, 48.005264882118475, 28.847375415986587, 16.701240385732344, 9.978582282220165, 6.81569476281443, 11.375523632572545, 16.698771253708873, 12.513081585207294, 19.673977282739457, 16.27657615369366, 6.838505796847805, 1.872488529451432, 0.4889732376942712, 0.5769286809429046, 3.1140971568322953, 16.024674677079727, 40.22150562655541, 57.100700024635564, 52.407136963259795, 45.81035752450266, 57.85016298294068, 71.17368959611463, 43.23346622528569, 11.375177483404837, 0.69023608800865, 0.29049916192889214, 0.1879971492434702, 0.15413551140696774, 0.24540296725688443, 0.12053116419983488, 0.209162748989559, 0.17506184657254528, 0.19740231875931064, 0.1357939568979125, 0.15330082796994718, 0.15932053237432436, 0.14768954035976242, 0.11997408804393585, 0.16532260143468458, 0.1440188607140895, 0.2426319812694865, 0.18047859381523826, 0.16193984827447325, 0.11593519589833676, 0.14754769151970265, 0.09670282669004895, 0.21979022711034746, 0.14817329424042858, 0.13299873188859032], [0.018204093437581774, 0.0174109089834195, 0.06438874008674776, 0.05027187319712774, 0.07582636384834206, 0.05079801855308395, 0.017906263350479065, 0.0360955846976609, 0.016452716851246454, 0.02679283922207692, 0.02589747204535431, 0.0039107536459566964, 0.026606233610260873, 0.07456955064328448, 0.052856642362331195, 0.0533557792885169, 0.01612242378835236, 0.04729517728030201, 0.04430018718384447, 0.023652807614135168, 0.026461831782193437, 0.07984375190590659, 0.02677750980271207, 0.057575766958536646, 0.016672137839299057, 0.06200455955319828, 0.023001663522013736, 0.006942159013687483, 1.3413218961608027, 12.402114791254844, 37.216118920233946, 52.12684831311626, 46.36696146380517, 24.907087856723418, 25.524412047478464, 34.80887013096964, 28.703598976135257, 18.1568633356402, 4.567205867459697, 0.8382124670090214, 0.034177626122630415, 0.8197968777629637, 1.0542106508247315, 3.950157468357394, 7.437461528085894, 4.0584381741862146, 10.696158332209434, 10.489783806185569, 7.998727204338198, 12.992698223360124, 21.54946642537271, 33.704711160352154, 45.642821327332534, 52.38300261958953, 53.09131599241688, 52.365583373654275, 54.656153417402706, 54.752247564254276, 53.80129637256746, 52.66990830821376, 52.179792465702185, 51.91706818919028, 52.89506804558539, 54.26319076168922, 47.574678851712136, 50.08898873482981, 50.91856218153431, 51.28634322074152, 50.59891646908176, 45.750717886032604, 40.37302286394181, 39.02200168178928, 40.81052403296194, 47.168066347799, 49.519036969830914, 52.43105949894075, 53.31754261447538, 55.488394075824374, 52.3182717446358, 52.32583015195785, 47.15525196444604, 39.309876195846066, 38.011901147903934, 40.542975241138095, 40.92295485158121, 48.069548606872566, 50.07613512777513, 52.87222416170182, 51.3415741151379, 32.35464115296641, 50.88346481323243, 50.01662492752076, 46.68270834030644, 40.46875615273753, 38.728176932181086, 35.72762650828208, 38.11236481512747, 39.45042648623067, 37.0083745064274, 38.501138379496915, 38.60794059691891, 37.92900185431204, 41.94708962594309, 45.32141054830244, 45.66119370921966, 48.93726318113266, 49.14609016910676, 50.87832650830669, 53.8696672070411, 52.32694018271662, 51.33790669902679, 51.899409678674516, 51.34368042792044, 53.4189280386894, 50.94708173505722, 49.9378990357922, 52.00087747266216, 50.869340358241914, 51.86233935817596, 49.79045321864467, 51.66170227912165, 50.265997455966094, 51.833604074293575, 53.138074567241055, 53.48216056823731, 54.1008948510693, 51.36766572152415, 37.359744348833644, 23.20976845679745, 11.751736787057693, 3.230083849160902, 5.78042192805198, 3.7111449001296877, 5.807550020756261, 6.420643935280462, 9.906786237993549, 5.2857149512537065, 0.6996562728478063, 0.9175335171241915, 0.30933312711215794, 0.28785300230787647, 3.3949670532057366, 14.219190036096881, 32.90446527542607, 37.35984633045812, 31.71054090223005, 47.25825340517106, 53.85379729732391, 52.80371996664232, 35.195462857523275, 7.088012666471544, 0.11828290298581125, 0.019938633326561223, 0.12456092457737654, 0.07413991321358951, 0.009306866071006704, 0.041254010922726125, 0.0687133906889827, 0.04180143820121885, 0.03345122538326729, 0.003200062497090849, 0.06471910784321447, 0.04085719269970733, 0.07789829460483405, 0.014855891800365381, 0.038837371243824886, 0.06572022388178496, 0.0034257553512185455, 0.038099211054824056, 0.023145548240732283, 0.04804104048338148, 0.07007017836815889, 0.0471996039813084, 0.02418489589716398, 0.055367349977454836, 0.04720853273606589, 0.024701252564667694, 0.024009224275247227, 0.049788559817018053, 0.0303639485050113, 0.014079830368920682, 0.0778758941939281, 0.032009468977189356, 0.06413144179649892, 0.018383266081312494, 0.04820676828404108, 0.039132058455218235, 0.045968619430617946, 0.07188886343952149, 0.04797102004710225, 0.044144311273891124, 0.08343074410673111, 0.015850803484359098, 0.004772290619345563, 0.021310930455764456, 0.016463495708341082, 0.038888473138814016, 0.007368538654484456, 0.046707250763692205, 0.04594813423952268, 0.04573444550436351, 0.008007025058876963, 0.04156251452983387, 0.09626468568439446, 1.8610592330655746, 15.773582189313828, 43.03746146540488, 60.05343675613404, 52.921430295513524, 32.168922808862504, 29.358648523207638, 38.304811985261985, 30.53613816538165, 21.178423935367217, 5.302602716030614, 0.7713620412734248, 0.04213631821555957, 0.7417855928501775, 2.364348355800875, 4.989022458753278, 6.6621442667899595, 7.273639325172671, 10.33987375997728, 8.750950040355805, 9.020486493264476, 13.31118977838947, 26.137111763800345, 37.53231686930503, 50.241376738394464, 54.73692678636121, 56.271028518676765, 53.81414997962214, 57.00138561187252, 56.1459166772904, 56.19350287222094, 55.11463534447455, 53.65488213877524, 53.54254937941029, 55.93000196641492, 55.26517983405821, 49.14217564367479, 49.35151646214147, 52.791101701797984, 53.48337258062055, 53.70981493303853, 47.15352219920005, 42.29677677154541, 41.018860724664506, 43.640243468746064, 49.83627434699766, 52.59705420463316, 54.330918327454604, 54.331385089505105, 55.49783522082914, 54.19276460524529, 52.84922730538153, 49.041307972323516, 42.19737606663858, 40.54306937802223, 42.54896948414464, 43.52645158767701, 50.297141075134284, 53.53937225957071, 55.27610755735829, 52.72252690407538, 36.179005022971864, 54.5222201654988, 52.31146251001666, 50.26695451428814, 43.53932872895272, 40.53137287016838, 38.305274824942316, 40.03673061247795, 41.153660820376494, 38.288624363560835, 39.68053233238959, 39.22589825045678, 39.98100942181003, 43.31832670396374, 45.936344054437455, 47.21497005031955, 50.333811313875266, 51.54128551483155, 52.81351804733277, 54.5544385140942, 54.10972018395701, 53.02428660854217, 53.89138929305538, 55.278629641379084, 56.1900786430605, 52.53493170584402, 52.46382305699011, 53.48852657502698, 54.19188991669686, 54.76424609461139, 50.35087362412484, 53.48849911843577, 52.673438441368845, 54.2024254029797, 54.24254732747232, 56.779077437616166, 55.823807716369636, 54.103613053598714, 40.00708533871559, 26.84195972258045, 12.832297798125976, 4.667578829872993, 6.890085945206304, 9.003641874559465, 9.34144914150238, 8.969648653461087, 7.693424619013264, 5.46985307047444, 2.4950189311658186, 0.5417626098759714, 0.12875785300087544, 0.49041670056120046, 3.5171780567015376, 14.69580900284552, 38.328612927467596, 44.19915768408006, 38.409339227984034, 49.929791496646025, 58.91917359444403, 58.8781181458504, 39.3313511725395, 8.455375913650759, 0.3333761531018442, 0.041049752729914846, 0.10850608889614383, 0.06513041278888142, 0.02819598288155131, 0.043731466491496375, 0.04467550514926834, 0.04550382239563812, 0.06596989193630796, 0.05813866921309983, 0.04883594863537339, 0.03053733910013351, 0.049094415209706754, 0.035416233248167464, 0.0879664825756223, 0.035967789740572055, 0.021222160017538457, 0.01767980776006176, 0.05849345602215298, 0.04632811001952618, 0.05675139123453729, 0.06482295872222993, 0.02447185328140134, 0.11119700337369597, 0.018382714498007012, 0.16965302067898935, 0.12753064143321208, 0.18093455402601152, 0.1328635480134718, 0.13909973354349214, 0.2718944102525711, 0.1257122627970192, 0.22073145805587693, 0.12886444647465983, 0.1386232268545897, 0.19044028024279303, 0.12824033762538625, 0.16535830113195604, 0.1549388771696437, 0.2900142895598566, 0.21160724362538708, 0.14849454555059635, 0.15041367240971135, 0.16042133943448145, 0.139231929675706, 0.16595238699547707, 0.18273824675669595, 0.08497311658556424, 0.13032605030363606, 0.20533656881701565, 0.14419982600356304, 0.14765318182687606, 0.15646627262955712, 2.0837290008221907, 17.24730883875201, 48.319321217075476, 65.62416730388519, 59.250539348971465, 36.37230726980394, 36.91540648860317, 46.74446213629938, 40.27336720497378, 24.335427899514478, 6.537525663452764, 1.3630574653225562, 0.3160272953250716, 2.262398600578308, 4.5951772697510265, 11.922740359460155, 15.526994543690837, 12.54920465330924, 21.081831647503762, 17.950791812712147, 14.55044008070423, 16.510838731642693, 26.964523984539895, 40.36688043225197, 52.89869231562461, 57.26507871381698, 56.69691162724649, 54.85254649193057, 57.96662207572692, 59.077268646609404, 57.35404591406546, 57.56948209577992, 56.41279474381478, 55.991998949358546, 57.76509069627332, 57.06385327923683, 49.496389204455966, 48.949442140517704, 53.90745139891102, 55.661966800689704, 55.752499026636926, 49.52924297701929, 44.505298676029334, 43.31123898106237, 45.760700318121145, 51.81236443981048, 53.51444559712564, 56.646383654686716, 58.04513223709599, 57.980675928054325, 55.98256564909413, 57.78621658202141, 51.38119397624847, 42.80213494454661, 40.9654184310667, 44.69864799130348, 44.049040732845185, 52.94509003239294, 56.01041447731757, 56.61186287480017, 54.29190251135058, 39.03683216341081, 56.5058490537828, 55.392048897281775, 51.64910362612817, 44.340512060349994, 43.05435903610722, 40.1790734260313, 41.64777355809366, 42.45295378469652, 40.786526972247714, 41.54740402775426, 41.98169669797344, 42.01196170622303, 45.87279773527577, 48.62255573272706, 49.78855479148127, 53.1697633958632, 52.89771956782187, 55.24527380543371, 56.653761632980846, 52.93492717127646, 53.30190804696853, 54.798213820303644, 55.96953161301152, 59.03694275886782, 56.42016879973873, 56.103609992611794, 57.187466775217366, 55.74944742264287, 55.925004866815385, 52.63743500555716, 56.4356739290299, 55.817037705452215, 57.694927338630926, 58.79918044613254, 59.670891915598226, 58.8645742016454, 54.66258218211513, 42.208786241469845, 26.62406421476795, 17.321971154982045, 7.7015826586754095, 10.90029122367982, 14.719215746848816, 13.375865740160789, 17.829623914534046, 17.245928164451353, 14.17463779449463, 4.251206488378586, 2.054224196941622, 0.8671308152617947, 0.8981034436052846, 5.12305376991149, 18.81865151466862, 43.83184340692336, 52.20793154931838, 44.06630308397355, 58.58201449917209, 68.53586427627071, 66.99548675167945, 45.822618853661325, 10.964212129192969, 0.5149690830899823, 0.19400289552586694, 0.23303080049733962, 0.25443702846044497, 0.11452655172756604, 0.13482755230319116, 0.12098597527872171, 0.15744870378365441, 0.21577670779680053, 0.09904000772944382, 0.2646705688488099, 0.12725160156767215, 0.18561766482889655, 0.1035417931815309, 0.18030881340945923, 0.14293208838470522, 0.14027367135690105, 0.10631065710537857, 0.1702022750771815, 0.14491575049056163, 0.1165277649077677, 0.17122743861569514, 0.06939248932946114, 0.16872703488315308, 0.08484681933036736], [0.1106722254846846, 0.06327233164601269, 0.11218504995227822, 0.08140889251784933, 0.0063287773105736465, 0.01254096944561048, 0.07097567131202068, 0.020289407750110955, 0.04110630534048523, 0.06647705746394011, 0.04324609616530999, 0.03928226914497153, 0.05356737660364278, 0.049596084056482206, 0.11259941924964229, 0.06674469794116675, 0.03317583975712619, 0.024900096431074124, 0.06595695271126686, 0.019773769290036252, 0.04699618465477421, 0.055573465933482495, 0.0641373981301102, 0.03133963233971548, 0.1009266447996901, 0.0810091708215975, 0.09403874827248436, 0.00437829973957231, 0.6339161843061447, 7.521689034277394, 27.567841391409598, 47.24622349585257, 49.61621761322022, 39.68994994317332, 31.963435719090125, 32.22425176251319, 33.278726070157944, 22.029476281135313, 8.466896895439394, 1.3032610546196661, 0.14280623546050442, 0.5555330709584299, 2.529619139048361, 3.914190559617935, 5.329285619720336, 9.228933991924409, 9.127044543143242, 9.068846375711503, 6.3922126350864295, 9.858162576152433, 16.184285725316695, 22.580626164713216, 38.38935082958591, 52.37947640880462, 52.28720265050089, 54.38398015114569, 53.21203477921025, 54.34854545900899, 53.19395657508604, 56.57267447440856, 53.31373007066789, 49.8163487065223, 49.93043084298411, 46.965617133725075, 49.392756262133204, 51.245527036728404, 50.59774760277041, 50.79972221005348, 49.07877445220948, 48.271938985393895, 43.20388763181625, 40.05769568104898, 38.826604889285186, 44.15976139806932, 46.629948539118615, 51.933518609692975, 54.27706810735888, 51.44889016305247, 50.535021058974735, 45.62893613692253, 40.7088718875762, 38.755990459072976, 37.50286379168111, 37.359120691976244, 39.86071817336544, 46.82536494347357, 49.620312567680116, 50.383821533572295, 50.10689043229627, 38.699382812746116, 51.0482749631328, 49.44222127237628, 47.421894688760084, 42.58345496269965, 38.97464690669891, 41.82391543542185, 45.14078932423746, 45.855743269766535, 46.82611803854666, 43.58307884585473, 41.410544687701815, 44.70276647998441, 48.19652749646095, 48.8754976180292, 48.63533481474846, 49.93816575696392, 49.118759093746064, 50.25224562614195, 51.33531793471306, 51.754380041553134, 53.5032589973942, 51.97656662233415, 50.089549633764456, 56.30668286354312, 56.789114782887125, 51.43656607597105, 54.6100498783973, 52.245880480735536, 54.72120592671057, 56.23030254917761, 57.3325042570791, 56.36894656765846, 54.699550520989206, 53.4947003856782, 57.318968157614435, 56.24858471655077, 45.71219628857028, 30.222601544472482, 19.894806723440848, 8.847891419164597, 4.447796171711338, 6.484356464878206, 6.83464422341316, 9.654981840041376, 5.860096543065964, 2.515394418470321, 3.9113122753558622, 1.5388258594659068, 0.6019843525944218, 0.09073759113708812, 0.5439697398293404, 3.6441824416960444, 15.855169450083087, 24.6202370812816, 30.078405411012714, 35.961235031004875, 44.63956532939788, 58.42631601518201, 54.90449044012255, 26.519780158996586, 2.8668130453555816, 0.10850126254222087, 0.15802463336337, 0.023154423369335073, 0.026943997945636514, 0.03645658447977997, 0.1232017620256351, 0.02101431270280192, 0.08248716127127409, 0.046547429500928814, 0.02415705626199563, 0.04993642244728343, 0.07342354439559483, 0.04724426307685433, 0.02627162555713327, 0.05704767573925276, 0.044139783694258625, 0.02273763323413028, 0.07371147854193565, 0.06516325497819532, 0.05183423674034496, 0.04432644101700956, 0.02145056913216268, 0.057859579551844835, 0.04415959855842014, 0.019641552090404496, 0.05250097455216512, 0.1148890185680601, 0.023452263032536835, 0.042856816247466116, 0.015245170760599357, 0.014866729071664234, 0.05272310174581024, 0.04443196579813958, 0.023592660135980097, 0.017964273443325393, 0.006506345957712901, 0.03255852610774098, 0.058150639336916714, 0.0461277895186457, 0.07272612859284686, 0.07800246724077771, 0.04689102759584785, 0.025760997312083363, 0.03826990310523299, 0.08002018961574763, 0.03672870657136364, 0.09132774696955759, 0.0238471775270638, 0.004483840800070715, 0.12090391194027279, 0.05524590205881865, 0.034788592733562954, 0.037186084044796806, 0.7716995489693458, 9.024699118829544, 34.157470349342596, 53.51646954013456, 52.92082625050699, 39.84665647629769, 32.59616109632677, 37.2138164889428, 39.872548041805146, 25.176293849945072, 9.378255682606852, 1.5821614308703331, 0.17261198932124724, 0.26449302031147864, 0.9106645276469569, 2.9400706627676567, 5.495129314161116, 9.096600086458269, 8.364640705047115, 8.883292771154835, 8.798688227130521, 10.947904875201564, 17.773532059884843, 26.802804662335305, 42.614657417420425, 53.64518603970928, 54.724900799412886, 54.81712356690438, 54.592901276003936, 54.62223668252268, 53.77317297843195, 55.40125862244637, 54.09210481951314, 50.57451540423978, 51.467882279426824, 48.65779038398497, 49.937836277869444, 52.315110314276914, 52.268183077535326, 53.778083785887695, 50.93254543119862, 50.462480745007916, 44.413397542891964, 42.090938629642615, 42.459053070314475, 45.22965846523162, 49.206004373488895, 52.590484234594534, 57.232966269216234, 54.556019229273645, 53.02835018404069, 48.69559418770575, 43.552900129748934, 38.73597852645382, 38.428131303479596, 38.8300879539982, 42.35131732879147, 48.70723578237718, 52.82423004027336, 53.18876727934807, 53.36271655174994, 40.456114353672156, 53.423932983029275, 51.529514481944425, 51.016593979251006, 44.08576980713875, 40.46593204621346, 42.65018624644126, 45.19739304819415, 45.85671601756927, 47.70969860015377, 45.49357906464608, 43.1324730380889, 46.20641100791193, 48.431928542352495, 51.48605462043516, 49.82860611331079, 52.882528228144494, 51.99791216081189, 52.53080145005257, 52.99535128378099, 53.63338362786078, 53.7913727760315, 51.91909997693954, 51.581713384197606, 57.23211511488884, 57.84039628121161, 52.34128821280695, 55.77217363542127, 52.88207715557468, 56.6591235130064, 58.303879230253166, 59.73599541571833, 58.43199168482135, 58.310625706949544, 55.46325168301983, 59.793622878289995, 57.89274031116117, 52.250179398444395, 34.91792378887054, 22.77222610289051, 9.517717515268634, 4.656218665261423, 7.887825619789862, 10.764560545644454, 9.277784170642976, 6.558848648302018, 8.185624220678884, 5.218290388584137, 2.674194271526029, 0.7439431415930872, 0.10864511087176301, 0.32505610116547157, 4.646721136185431, 16.168266765532955, 29.373969301100704, 37.173455299869666, 38.199413976361676, 50.01489516227476, 66.61700940901234, 59.53769999165689, 32.38108773385325, 4.869970188986871, 0.12556111364955866, 0.027347264713757945, 0.0511189442758839, 0.038564793329926274, 0.08429619363479077, 0.06356632937827418, 0.10017731121831364, 0.06661336748830735, 0.0550276359483119, 0.04697848802372333, 0.01890504090566068, 0.0343523018302456, 0.0835704479006029, 0.049050200445156907, 0.045673491718668136, 0.0981416700467948, 0.05346571673609076, 0.03994521099112688, 0.00935338388737892, 0.06836546419729149, 0.022283931067513845, 0.040388660986096635, 0.026661696460758968, 0.03422929875312313, 0.020689401407575896, 0.14045062234565137, 0.21819517076496156, 0.1969931971642279, 0.27228431836251293, 0.14104738951690737, 0.036523651647111105, 0.16001784092476293, 0.10543786845500432, 0.1531046941395729, 0.17226239275788108, 0.12548386900415345, 0.13768058630727953, 0.20431247780159598, 0.10646841759162565, 0.2683206407293197, 0.2429902805916725, 0.09836907558623822, 0.20592797337280166, 0.1770030214421211, 0.20086479102892263, 0.11230195496952343, 0.14470875353342103, 0.19651279874867011, 0.19961335576109349, 0.2412637022714461, 0.1730367391099853, 0.1736049924886996, 0.13166748558080968, 0.981417956852144, 10.637686579458176, 36.44198033117479, 59.840758000650716, 60.92395582506734, 51.47813927742743, 42.73268545827558, 44.30458707194175, 44.298401494180005, 29.78138000734391, 11.84577267016134, 1.7718278857008105, 0.393878651722785, 1.256576759680625, 5.261293784264596, 9.748169510595261, 15.320324859311505, 16.534851481837613, 17.055657909762477, 20.782023322197702, 13.032944683105717, 14.196003925415779, 21.526706872447846, 26.46865990854079, 42.99391531175183, 57.12074725858627, 59.50244965091829, 57.5195267892653, 57.23585705603323, 53.4842864928707, 54.03206117691533, 55.998796416867165, 53.870486982407115, 50.9838657225332, 51.01104382545718, 48.111270858395486, 50.23546180417461, 52.21703144811815, 52.556053669221946, 54.910550502038774, 53.580996451839326, 52.38641115926927, 46.960769084192094, 43.69569793824227, 43.19290107296359, 47.427115363459436, 51.29914191461379, 54.94604795209823, 59.39454524747787, 56.47998102249638, 56.02567249728788, 49.725483079110425, 44.66906939783404, 41.52996516996815, 40.7540693590718, 40.593161967492875, 44.07785838650119, 50.57113824352142, 55.5214165103051, 54.72266504841467, 54.41869312717069, 44.10745266945132, 54.44497692969538, 53.07819566419048, 53.400736085830204, 46.71752722032609, 42.38318266407136, 46.70733298024824, 48.39762349282542, 48.91354460870066, 51.48465825665382, 47.50273866038169, 45.39616700141661, 50.33181090508738, 51.2034478495198, 54.63010495708835, 53.215039314762244, 54.66079750368672, 53.66044798204976, 55.57791040789697, 55.94198480729134, 55.00880979722547, 55.83287623620803, 53.21728683287098, 51.19939996350197, 58.62605879383703, 60.63479477359403, 55.110913015181026, 57.313900455351806, 55.625202425064586, 59.586223633058616, 61.42803922776253, 63.79133393687587, 62.853942378874756, 60.7362586452115, 58.17766520284838, 62.091774863581506, 61.42499939087899, 52.42376389042024, 35.39246782179802, 24.890458968377885, 13.031810137533373, 8.53796632059159, 13.795703495702437, 14.048082520884853, 17.93538474267529, 13.55990727101603, 12.175823450088503, 12.687049488867483, 5.2794337657190145, 2.5314704977696945, 0.4406156841545336, 1.312498604097674, 5.154609237947772, 21.442993687045192, 35.943243119024466, 43.07171160174955, 48.941475806697724, 57.23511180570049, 71.32063727225028, 69.14737747561547, 35.855323191612, 5.736901269805047, 0.267304562993588, 0.2860334515571594, 0.14715940751616033, 0.1745312847197056, 0.20281629276371774, 0.1824977717572643, 0.13701033598232654, 0.19564498966980368, 0.18247267471686487, 0.11603576026015705, 0.1915741363360036, 0.09362725180483635, 0.11089548648845766, 0.0838438110546239, 0.2764512544437763, 0.19569936659066908, 0.11198061172880473, 0.135915351190394, 0.20888920963531543, 0.14536680773861949, 0.19486690480862895, 0.12151187931698178, 0.193199529763191, 0.0911407755507577, 0.1799691913108672], [0.07877153524708363, 0.03492520153222065, 0.03752710808429026, 0.043790734883758335, 0.034818776597779606, 0.13291023341157746, 0.057442440846634496, 0.04731934352387344, 0.07383117978010448, 0.030497895148132118, 0.02542379605133207, 0.09946977539408593, 0.02525893393002691, 0.07322920321096336, 0.04487162365788414, 0.027252951629399776, 0.020186547039737626, 0.03645726629803258, 0.06098271317539677, 0.0817047633350857, 0.07745570262833949, 0.04015742117659219, 0.055798573209153074, 0.1252911442650422, 0.008398189074209621, 0.04068578818752881, 0.061589715281321164, 0.013989213658797165, 0.07243264030905501, 3.8941585248516457, 20.96983621197362, 44.76586172657628, 54.30183787499705, 42.43886070866739, 30.523629726902133, 26.281292207779426, 30.911942412776334, 26.55740745605961, 10.101601539119597, 3.060534740647962, 0.1510264814621018, 0.2238305441794857, 0.335122496490517, 0.7446475134741876, 2.843214595510114, 3.4221780059799074, 5.97842219375795, 3.0161474837410838, 4.720847558590674, 3.4995396483329038, 8.186021850955102, 19.105259103159753, 32.98729396635486, 45.99190442792831, 52.99333126314225, 54.32005336207729, 52.787414673836004, 52.85513047249087, 53.31193754749914, 51.33223102938745, 50.56352100064678, 51.97936327226701, 51.3355101308515, 50.34218949656333, 50.88794023759904, 50.80099305798931, 52.130696158255304, 53.771125501202, 49.549129393792924, 49.10921204474665, 44.88851816423478, 39.03133300042922, 38.58536735657723, 38.85355941710934, 40.7386112982227, 46.184959565439534, 45.11844750373594, 44.862752114572835, 42.79361555653234, 38.42652705407912, 35.95175858466856, 37.7505143996208, 37.03379538751418, 37.52906914680235, 39.168388458990286, 43.24140118014428, 49.499366283416755, 47.91269302368165, 52.26951668339392, 38.56635955072219, 51.5642313803396, 52.17608974825952, 46.62840312527072, 42.39757776260376, 41.10184238803002, 47.92568783606253, 50.50736050451956, 52.6255698357859, 49.356172315536014, 50.18347863228091, 50.10279940020654, 49.86363680131974, 50.24291038513184, 51.277796376136045, 52.00771024150234, 48.238845948250066, 50.20870731722925, 49.93747541981359, 50.06862378889515, 49.37792970288185, 51.27006538452641, 53.273745429131296, 47.03842024649344, 46.79748473628875, 50.55430343074184, 52.365881473787375, 52.527494891997314, 53.16158525405392, 55.4517787502658, 57.452195382887325, 57.556440214956964, 57.46274263628068, 59.346543281309074, 55.88434949997933, 55.550449894320586, 48.622132116748446, 40.62400748652797, 26.295655927350445, 18.989623708109704, 7.130813569791856, 2.500998584493514, 6.94134347861813, 8.287200370142537, 8.10785391638356, 6.889258815396217, 7.068984758469367, 2.578776243232912, 0.584585760389605, 0.35612004718953566, 0.23829125048172092, 0.3938261287346963, 6.560492611700489, 14.770040838949143, 32.59409792961613, 39.72853037618822, 39.971940901971635, 47.80876590359596, 55.282477486518125, 46.96159670429845, 15.296583733251019, 2.4125537949223674, 0.02804127525568249, 0.08512158442528979, 0.03975106132847648, 0.018835979994506608, 0.04842744757150931, 0.039550403748909314, 0.0300346743390565, 0.007512566535883854, 0.025465046055614952, 0.029306528834445827, 0.0396769882870778, 0.0044379171806447695, 0.08520494245233075, 0.04693585906117674, 0.06672089558935936, 0.03594808595915956, 0.052755610686877084, 0.04720023600384594, 0.03921889452143543, 0.0012802972712726785, 0.018961365605073593, 0.014127827692596663, 0.09350799489766361, 0.011229627059712526, 0.03442008528978594, 0.011512077931735304, 0.04530363979058401, 0.02275328824086295, 0.036834112608865384, 0.0181067543059227, 0.029424558085719907, 0.04529802436609903, 0.06122192796019297, 0.04853606734785342, 0.015206142411296888, 0.052604484522054275, 0.00640986867496864, 0.011657778278834397, 0.02874185500155774, 0.024963078434549035, 0.057011543202304074, 0.04050960711714241, 0.03435967159607718, 0.06799204229948021, 0.02387608585488652, 0.04027546766484457, 0.015816445398565023, 0.019739517498941674, 0.02668401451721307, 0.020886483271756483, 0.10717183952369999, 0.059795828476067514, 0.08383797346464089, 0.12240550555889645, 5.1201345459107435, 26.42671015954787, 50.12186211924399, 59.85428233300487, 47.826675445802756, 34.64471109451787, 33.234901428222656, 34.5212858723056, 31.202990124302527, 12.808385068370452, 2.6899401362865203, 0.047974777708370844, 0.3479888512482566, 1.0867484274410433, 1.5093548860280745, 4.07823462159403, 10.523365178415853, 9.081639186028513, 7.272813666251398, 7.947774635207269, 5.713796058008748, 11.588679936624343, 24.15424773769994, 37.59807540524391, 50.87804409765428, 56.897403578604425, 56.378105302010816, 53.10975113222676, 53.77620889294533, 53.25853447760306, 51.745252686162154, 50.48268879613569, 50.19387683560772, 49.87449784432688, 50.571248069886245, 51.64434186873898, 51.607655940517304, 53.13690177855953, 55.816661157915675, 53.14969262769146, 51.23972977361372, 45.93066446242794, 39.88848463181527, 40.578131444992565, 40.852654210982784, 43.96413318572506, 49.73652455114549, 48.00958733404837, 48.38380498270835, 47.51045396251064, 41.1472830464763, 38.43937281639346, 40.2650753144295, 38.08066814176498, 40.93803636489376, 41.39733022259128, 45.56484853067706, 52.38873712478146, 50.92912512440836, 54.71569499661846, 42.431600401478434, 52.869996255443944, 53.60342064211446, 47.884942254712506, 44.03089192605788, 42.072056339633086, 47.693663950889345, 51.001567379120864, 53.22850088919363, 50.49325958375008, 52.308332458619155, 50.6333117331228, 52.37105900241483, 52.48816920864967, 53.54309851123441, 52.83039208381407, 49.988948683584894, 50.55997125564083, 52.22528411496071, 51.94345005096928, 51.349826781980454, 54.209952431340376, 53.078121139157204, 50.029184356812515, 50.033977493163086, 52.034260765198745, 53.307030662413574, 52.21049677941107, 53.138913954457934, 56.14750523721018, 59.04608972610966, 58.02831703616727, 59.26156120915567, 61.22497812394173, 57.32130981260731, 59.12356045938308, 51.951824311287176, 44.214380402718824, 28.293677952981767, 18.168887361403435, 8.423871436426717, 5.051047878880655, 9.238687945950417, 11.486969936278559, 10.2696878487064, 7.287747110089949, 8.137108914313778, 5.09349625918173, 1.983723270316278, 0.5561595470193894, 0.19389516824195463, 0.6441722630012421, 6.624998440665584, 20.394991290184763, 35.27791107854536, 39.46389198303223, 47.3380148026251, 51.11477090466408, 61.91078101435016, 53.483133316040046, 19.135543723260206, 2.489853414797014, 0.04375737175465592, 0.07304677469355446, 0.03143138669040655, 0.0439538273419584, 0.055089256230501406, 0.08557533830284111, 0.02983750245954481, 0.05698497910352965, 0.03152052485083621, 0.0273028718337657, 0.042970695217410405, 0.00846075068693608, 0.024378101356447707, 0.07841039373869858, 0.1100929634224984, 0.021525850677261912, 0.02072232020568223, 0.03130676908298366, 0.02510291629380757, 0.01855689607891104, 0.019088109106486364, 0.0405400131468571, 0.06399405158815846, 0.008377102504093802, 0.08905714663166193, 0.17811801645063585, 0.13791287948767986, 0.1725493080072826, 0.20450763103942718, 0.130997940056747, 0.21385071678988396, 0.16049149776658705, 0.21286260126338852, 0.11836267572136656, 0.10684959996010988, 0.12099943544355132, 0.14950996445071313, 0.13421331832726158, 0.11930956805665648, 0.10873188565094626, 0.17544685171977167, 0.13612342067062855, 0.16267360728834906, 0.24261448382129594, 0.16222651837573898, 0.13576450847810315, 0.10050941799436847, 0.1307527612774603, 0.21215490456069672, 0.13102728122424695, 0.17722815936130865, 0.12177680784295644, 0.11276884725497616, 0.25103303934297255, 5.715843044942425, 29.445193659874704, 57.148407813041445, 67.99916636559271, 54.33964167871783, 41.89317664792461, 39.001856388584265, 41.99473073405605, 37.95485811848795, 13.90415212800426, 4.267696622879275, 0.3519639282697632, 0.8168004933864841, 2.6114880750256204, 5.415592472399435, 9.5693378679214, 14.907763100439503, 16.035860296218626, 9.436712726469963, 9.46488711141771, 6.179354431167726, 13.042020067091912, 23.841342618388516, 39.08826228111021, 50.12764369287799, 55.35402936320151, 54.76800372523647, 53.798072184285815, 54.13966748022265, 54.672419486507295, 52.183271608045025, 51.80843030252765, 51.48055153508341, 51.40243361073156, 50.14298800499209, 52.65397171820364, 51.92090426721881, 52.52032087695215, 57.81504600278793, 55.64981529789587, 52.975876715875444, 49.63271117979481, 42.291634544249504, 43.048918708678215, 42.15486541871102, 45.42665950713619, 51.25085361542241, 49.66298795515492, 47.716307793894124, 47.44600549820931, 41.98587402220696, 39.88833950411889, 42.280718588059955, 40.53746823341616, 40.6734371954395, 42.308190868746856, 47.800238670841345, 55.66391229629517, 52.215627239596465, 57.15832356483706, 44.6637624309909, 54.29978255302676, 56.26687472866428, 49.520958931215354, 46.66522633644843, 43.945902009164136, 51.75155593502907, 54.44360410013507, 57.69054605114845, 52.90517207114927, 54.92698523306078, 55.592956619877974, 54.602228672273704, 57.44424866091821, 55.81926953408026, 56.06795957011562, 51.572762535464385, 53.38761967997397, 54.21704015424175, 55.20042934725362, 52.97695144530266, 57.573443689653956, 55.52906513214112, 50.955051991247366, 53.97211951594199, 52.82348478994062, 53.77861330586096, 53.52325524053266, 54.35990464302802, 56.63024310142764, 58.68231342684839, 58.3554191743174, 58.31420683091687, 61.19051225723759, 58.20171717674502, 57.81175121184319, 50.739600120052216, 45.5489315525178, 30.416992249027377, 22.649279409839263, 9.095745009760703, 7.238572355239623, 16.151523147859884, 19.18379083756478, 18.30210478075089, 15.259296701800439, 17.586682111986224, 9.440708641083011, 4.494715073416311, 1.0973132089261086, 0.8544873614465037, 0.9941766915782806, 8.844161245130724, 19.95131042695815, 44.42607856565907, 52.29804408165717, 51.36979949089789, 60.13013086011333, 68.37283488242858, 61.67605461612825, 21.897802314450665, 4.172124151260623, 0.22547087632119658, 0.22154211697559203, 0.18067963060832795, 0.11424027233114166, 0.1711991699712892, 0.17318949704208683, 0.19973969898156582, 0.15117867248913935, 0.09477390922726163, 0.09051212380009313, 0.1871185076813544, 0.1324634049688616, 0.1584287600651864, 0.12189628691562723, 0.2535125901622157, 0.09623133021617129, 0.1132444729427657, 0.1153184108496193, 0.1284778402036717, 0.10328085597364173, 0.09709827361568328, 0.20016990331632478, 0.25886389817441663, 0.10034831736477152, 0.20405012333104688], [0.022815356684488156, 0.05631526887056328, 0.0639422985184337, 0.04488386574291414, 0.02935713277228417, 0.049632105510681875, 0.04464473139734999, 0.031185432247096495, 0.04311953844021886, 0.06805920522780189, 0.028783821298049826, 0.014703074496449723, 0.04295240486821821, 0.04176093896310176, 0.02879464803563972, 0.025815282302397876, 0.022139998468300028, 0.07507707623224105, 0.01755611328858762, 0.019020070922711206, 0.05391172163428799, 0.0488335163062138, 0.038363810162991285, 0.026978222923653743, 0.06868568128876149, 0.014285490502633396, 0.04725330291436084, 0.04799658057069586, 0.04807260713630146, 1.351632213880939, 16.135226680386452, 41.19369253035515, 48.32789159590199, 41.82170321864467, 30.81485394508608, 26.38588416960932, 36.1553531308328, 34.16263218848936, 17.43791641727571, 4.377754897840561, 0.30927233037448704, 0.14520637360551666, 0.5776956268856602, 0.6523611300414609, 1.3079828528627273, 9.395434683369054, 5.186158822428796, 7.205002750119856, 8.751209897379722, 5.585696351143622, 12.730993763093027, 22.489933121588923, 33.493871996479655, 45.78641929934102, 51.39636570407499, 54.41088761052778, 52.930663554899155, 54.44638113821707, 54.278233051300056, 53.68320557378954, 51.67818800095589, 50.8126974105835, 50.5638583244816, 49.93672624711068, 50.5485414689587, 51.51939476689985, 51.559124454375244, 52.97431169017669, 51.50311693068474, 50.54358751543107, 50.0605829300419, 43.920108502910985, 38.21103203681208, 36.575219323558194, 35.85259714434224, 37.693789082188765, 38.71773558278238, 37.28316791595952, 37.36025425695604, 36.96314173360025, 37.64974478752383, 37.09714951053743, 39.4967379108552, 39.434960580641224, 40.38928108830606, 45.23640886429818, 48.01629458704303, 48.77105666745094, 49.64529806567777, 38.62076674738238, 50.30911607127036, 50.93276508392827, 47.978875175599136, 40.77073550993397, 41.31727856974448, 45.32715289823471, 48.76043881139448, 53.66709639949184, 51.380754670789166, 51.638050386982584, 50.82525683987526, 50.50546599972633, 50.461253043143984, 51.598508973275464, 50.665632063342684, 47.97566667679818, 45.20959161943005, 47.090803500144716, 47.69001614662909, 49.71889349722093, 48.51489451623733, 52.408458802007864, 51.43583259274883, 48.34522062732328, 54.71343571139921, 52.83491457662275, 55.43752485705961, 53.80456762929117, 54.31796666114561, 52.808109098865145, 56.829264163970954, 56.328612835176536, 56.44580541118499, 52.39058063876245, 52.95706110615885, 48.940012762623454, 40.79751353110037, 25.418315856687485, 11.60100696548339, 5.715608683324629, 3.996042580373826, 2.8877754172971173, 11.082092100574124, 7.118386520493416, 4.274098911593038, 5.318258366277141, 3.2917275736408853, 2.987391607415292, 0.22782425245931073, 0.121380410968296, 0.8216976951206885, 7.007925712293194, 15.895958177505003, 38.685885936983176, 35.2129291719006, 40.37168141334288, 42.894561675287065, 57.00018928896997, 40.70695777093211, 14.083487795245263, 1.9545919496205546, 0.0924983906048921, 0.03342285331699156, 0.08778067561046732, 0.05499275979555904, 0.010410974012507547, 0.02863432498528592, 0.07488853433319638, 0.033566150063228224, 0.032689324129493005, 0.03880444861527893, 0.01813669493722339, 0.0064166361041697526, 0.08778013168804108, 0.05750367042398261, 0.043438502977932655, 0.012670219012145555, 0.08257364493704612, 0.006524197721568447, 0.022323177751874732, 0.025719000372074308, 0.029975670247128414, 0.09691550035870845, 0.026242834057719, 0.016881827595493486, 0.014479331814894273, 0.025197114464977098, 0.0374295391262539, 0.1032354269597319, 0.06554656707110905, 0.08118422957317484, 0.02017341629271546, 0.02128909120426303, 0.03464599695777701, 0.02953554315853023, 0.11156631137935386, 0.024920192832547813, 0.04474527660697218, 0.018997337263558182, 0.010660376809086772, 0.028460493889607252, 0.036983733410916986, 0.030051650847458554, 0.057090431106306856, 0.018379782296476826, 0.02227167366072536, 0.036055993273734085, 0.011495958484198538, 0.020001768547620986, 0.009847159155704563, 0.07011844190738856, 0.07657206617295742, 0.01158831038347055, 0.11466089290596786, 0.05329651855713418, 2.2132282583944263, 20.465503738772487, 47.307024155893636, 55.35658282618369, 47.497070835482695, 35.91753198254493, 28.962551893726474, 38.52493539933236, 37.35211926121866, 16.693311314429007, 4.9644502805125335, 0.2982709094160988, 0.19013119440886284, 0.5633689859701742, 2.0032047023696284, 4.5083310911732335, 4.753395386280553, 6.566223684818515, 8.214498748702388, 6.782174677618089, 7.821677788611382, 14.990772220396227, 24.544474540218232, 35.320578621279815, 47.73514693783176, 53.49799517662295, 55.61548279177759, 55.12997181184831, 56.22814524558283, 55.891397999178984, 53.4266786421499, 53.537242412567146, 51.29211694963517, 51.245491735396854, 52.149092074363466, 51.3217386891765, 51.1692879276891, 51.86957220877371, 55.17600867056078, 52.625675739780554, 52.76285279181696, 50.93118436874882, 45.11535275366999, 39.17669211664508, 38.47062626192647, 38.242520824555434, 39.45172086838753, 41.02001782386534, 38.928068760902654, 38.90661731843026, 40.26534988034157, 39.85609762130245, 39.21613939346806, 39.81144535926081, 40.881036481549664, 42.00001024430798, 47.56952093493554, 49.362342203817065, 50.864896312836684, 52.51657109106741, 41.194022009449625, 54.227034353440814, 52.62895091887444, 50.313881751029726, 41.40020139755742, 42.49178132703228, 47.089520885098366, 51.03966928297474, 54.61613739690473, 52.49903417402699, 53.90549413619503, 52.89215764691753, 50.88421398593534, 53.95493953458725, 54.21124681349724, 52.94408198325865, 49.76564422730477, 48.14784696025234, 49.219732669092, 51.69054738936886, 50.77596441391976, 50.91257272228118, 53.93252711142264, 51.92488939531388, 49.682431144099084, 54.21563594572006, 53.92959710090391, 57.52184098766696, 55.635067186047955, 56.87329669152537, 54.76248102803385, 57.45918896890456, 56.11598507050545, 55.84489437841601, 54.675039629782404, 53.97983481807094, 50.34086765781526, 42.22034546636766, 26.877143383026127, 16.13299975472112, 6.7221075007992415, 6.865238710757225, 9.30686560369307, 9.891931241558446, 8.347298925922763, 8.294422434222314, 9.038020468527272, 3.716911274579264, 1.4288178398724527, 0.3496160832864623, 0.27908377769973974, 0.9701102539416283, 8.19611950266746, 18.64651437728636, 41.92333575217955, 38.73491164176695, 42.35234498977661, 50.427179413457075, 65.31904612818073, 47.61476547487321, 15.931060448769601, 2.4672757617888914, 0.07296042126272956, 0.0335731789199335, 0.07190006364497446, 0.142738007669968, 0.01793637060590329, 0.05199264074044843, 0.059386350650099985, 0.024301751118694103, 0.04689164812706652, 0.02216187985463729, 0.04386973004007051, 0.0553759531448445, 0.02483802607222911, 0.05865539168758739, 0.05675917468784798, 0.019721445484807896, 0.051331702214215076, 0.034054389388691035, 0.0544710117842882, 0.015384770174991461, 0.06915008378846031, 0.006434681784031132, 0.04627648718474854, 0.028279214504084764, 0.012726972720796063, 0.17614674964739432, 0.18883606148583276, 0.23573783346481864, 0.17377658086197992, 0.1320514028831836, 0.19488290072448794, 0.14903762528011877, 0.1871043503765137, 0.10598397423182765, 0.20859927599949224, 0.12818254395237855, 0.12151032415849548, 0.14711986205750896, 0.0838598835792753, 0.1172955918516363, 0.17868369577392457, 0.12679685943669852, 0.21799309209229487, 0.0958730998418985, 0.1344648862798368, 0.0916482168700426, 0.129827848004718, 0.3081593884816093, 0.19938314633984722, 0.2047046994970691, 0.1932685236416517, 0.11346801739907074, 0.1618239544932881, 0.17929039144467923, 2.7602250874042515, 22.056156243047408, 51.70022779895414, 63.358104228973396, 53.96160364151002, 43.15073951598137, 38.42393436739522, 48.82309867489723, 44.293655426271506, 23.232522126167055, 5.938253200823262, 0.7196777049572237, 0.5522382800136844, 1.3313403220907336, 5.43050826557221, 11.52123183973374, 16.901285186890636, 15.42077087586926, 16.333164188169665, 16.203516125679016, 11.034268602248162, 14.936365023736032, 27.48679934009429, 36.990041348241995, 50.71197878929877, 54.83140099433161, 57.09519301691363, 55.01264195288382, 57.6308475771258, 56.41327719534598, 54.89782633319978, 54.042282873584384, 51.6883037936303, 51.319012641906745, 51.0741037707175, 51.22992384818293, 51.877252209571104, 52.73741229887932, 55.05949466459213, 54.93385722560268, 53.91908122647194, 53.49609674945955, 47.933112882798724, 41.60969911083099, 39.87043388428227, 39.26254495497673, 40.86844175092636, 42.23712536596483, 40.444814005205714, 40.592856022619436, 41.10185023277037, 42.01132235988494, 40.79248897490963, 42.54955783967049, 44.44766336871732, 42.86515174373504, 49.01494964476555, 50.97958249430503, 52.647460583717596, 53.480446492472005, 43.02097574357064, 56.42893137470369, 55.23982563326436, 52.59110396908176, 43.74294680933799, 44.610696684929636, 48.856521191135535, 51.38058208650159, 57.07108612983458, 53.744857388158, 55.52015742947979, 56.511548257643184, 53.072822017054406, 55.376214288896136, 56.638111375993304, 55.105143208657545, 52.34387305475051, 50.945924635856386, 51.16238455618582, 53.391663643621634, 53.83699778587588, 52.72792408543249, 55.38808730340774, 53.24447670290547, 51.42266519608037, 55.66250808777348, 55.321003006350615, 60.152500137206054, 58.17845359925301, 58.78242408075641, 56.51956950464557, 59.10468209174372, 59.22252578120078, 56.67534251366892, 54.446388982957416, 55.00389898976972, 50.61129546934559, 45.20650079173427, 28.043789632858772, 15.469627918735629, 9.270779798107764, 10.223859856205603, 10.084214652738265, 23.174429862729966, 17.289376258850098, 12.518451309973194, 14.45932440219387, 9.115622601201459, 8.034851743328957, 0.9580748900771142, 0.5347198103704761, 1.4087192473873016, 9.29270584737101, 21.6445093770181, 51.2281430921247, 46.11717708649174, 50.61333117946502, 56.08608484268189, 73.34911454108455, 53.58071796355709, 19.624259279620265, 3.010554183875361, 0.19194020378974178, 0.15548016425342331, 0.17698799079704672, 0.3591847053218273, 0.20531611426943736, 0.09653563566145398, 0.21817402673825143, 0.12837808023417188, 0.16897523204886145, 0.2164232400396178, 0.1284833560367265, 0.14401899860991588, 0.18944030567522974, 0.12205675935312627, 0.15840487344370735, 0.10015247464780846, 0.1459101019727607, 0.14449440213220735, 0.11975140926698524, 0.10888494235733825, 0.1721641036771959, 0.144148206999225, 0.13596759838682992, 0.08307508012700467, 0.13910399299235116], [0.010599316728691901, 0.031166651601632758, 0.020827054001030423, 0.05417450511407468, 0.050183014658790444, 0.04927315118332063, 0.018311437677531954, 0.020417821323198658, 0.04896819073286268, 0.0911236688074085, 0.08186273066507233, 0.015719945133183033, 0.08903001179738392, 0.029831841069784377, 0.06786959080566322, 0.10026721929710719, 0.08148012337304893, 0.05033805553290633, 0.02710940398936791, 0.04850494885636915, 0.11373488412749384, 0.013257852500124324, 0.03585171975916432, 0.055789947059125676, 0.054385972194253444, 0.04048945900473384, 0.05140893153786179, 0.09052114831584115, 0.029505215652827776, 0.32795418113950764, 8.443839242381435, 30.049368104627057, 47.17790365219117, 44.714882681446696, 36.352973907224595, 29.36449677713456, 33.12911902704547, 38.19411485425888, 20.702210933931415, 6.722129073835189, 1.0491064214898695, 0.09849263790754542, 0.4132916874462559, 0.674734881087657, 2.304675132036209, 3.9055444300174718, 3.3212485572984143, 5.973891365912653, 4.808504687201593, 5.351674018367644, 9.175915314305215, 18.14444315048956, 30.6873220013034, 42.02694516028128, 53.489538546531435, 57.3767368255123, 54.72145303603142, 55.52345222042453, 54.70383767158755, 54.863995890463556, 51.80637890292753, 51.998214183315156, 51.20105912608486, 50.41176842105005, 49.39437620101437, 51.00494061746905, 50.77635272856682, 53.33072177825436, 52.76746942150978, 51.27095576255552, 49.318450881588845, 44.475241553398874, 38.31482187394173, 40.993318250102384, 39.95015213566442, 38.99755747087541, 38.2310204352102, 36.28298705623996, 37.470457169317434, 38.128544592088275, 42.88659534146709, 45.75237704861549, 46.593274378007465, 47.60645397247807, 47.47528206917548, 48.64624684856784, 49.12597233249296, 51.40381820740239, 49.58798831509006, 36.52664861371441, 51.37491818397276, 48.35747018937142, 46.56715531503001, 41.895471234475416, 40.276834580206106, 42.43200048323601, 48.050293691696666, 52.1197723573254, 51.85955447535361, 54.67757740328389, 52.01485287758612, 53.30012336854012, 52.72599820167788, 51.142855075097856, 48.647537308354536, 45.93410438106906, 43.64921392933015, 41.67430839230938, 44.24353538020965, 47.72340728390602, 48.86558971097393, 52.75004233083418, 52.68488783990183, 54.34360327259187, 54.65638483724287, 53.27276875895839, 50.16561615851618, 49.70707931826192, 50.629867892111506, 51.17055093088458, 54.98719361520583, 55.76579586152108, 58.18430577555011, 58.95237645795269, 57.057055811728205, 48.47167784167875, 38.56665372848511, 21.388827716150594, 12.209538182904645, 7.173754697845829, 4.112849293216582, 10.226089723648565, 5.966305992295665, 6.638498748502424, 8.221144224366835, 8.05127666842553, 2.581657959568885, 0.8350580846590381, 0.5404125178052533, 0.43744077064817954, 1.526528125809085, 10.54342221829199, 26.58109464953023, 43.60463226995161, 47.5804643477163, 32.00132973732487, 47.527539806981245, 52.1421024107164, 36.26240637994582, 11.070725071814753, 0.789993238304892, 0.07054726728388379, 0.04767768498089525, 0.09309429209679367, 0.031150805072919018, 0.025128819641747305, 0.06494650572177864, 0.023645257817641385, 0.01907577892134507, 0.05462722477292823, 0.007382887960111182, 0.015541436113116723, 0.03925616086851205, 0.044828837647313075, 0.028795979113408157, 0.018701973979571657, 0.042120758969817436, 0.017261740173243226, 0.028219099584666472, 0.04780625368678763, 0.039136819691667636, 0.0664139854451341, 0.07065555381198084, 0.082607843101986, 0.06533850525175372, 0.023261723559229605, 0.018159930383966818, 0.05786443271884515, 0.07955982439940976, 0.07053680252283812, 0.048613442228205746, 0.03915157454508928, 0.042156880015447255, 0.027533056357154445, 0.00991900192363368, 0.069658275873911, 0.0362806408966501, 0.011075990999327793, 0.06478034891188145, 0.03845932600539058, 0.032417493151320566, 0.0675792741258779, 0.029534813459782355, 0.12391386373389153, 0.060028190604381026, 0.03678981357464387, 0.03225279190847951, 0.037095042155875314, 0.011609184364187381, 0.04468618441493281, 0.052078538348958384, 0.12366741324865049, 0.039444155014690854, 0.08914171507762325, 0.015410840147054725, 0.6256617401396075, 11.450605642411018, 35.321755332331506, 53.416492246812396, 51.635092919872655, 39.064006343964614, 32.11404296659654, 40.59240102767944, 42.32989726528045, 22.81384833397404, 7.569253656171984, 1.0249008009991338, 0.05949409708621041, 0.35081586890643646, 1.336261793490379, 2.25534642415662, 6.537752180330216, 5.65424467286756, 8.910763090656651, 6.212280767579233, 6.489689417423741, 10.075960024710625, 20.173036129243915, 34.244331236808534, 43.85628369546706, 56.10417481391661, 58.50969383793493, 57.88206361955213, 57.958051696900405, 57.60419114943474, 55.89236290224137, 52.97404889137515, 52.64714287173364, 53.24296659038913, 49.73997231452696, 50.70320836959347, 50.72529131366361, 51.93416972314158, 54.26386540935886, 54.60112648625528, 53.148127601992705, 51.57922267913819, 46.706697556280325, 40.76427144388999, 42.19447351271107, 41.80746501491916, 40.8968004872722, 39.71568853624406, 36.95030773839643, 39.336175687851444, 39.649698580465014, 42.62158432314473, 46.549379133409076, 47.70163420707949, 48.248102741856734, 49.667965442903586, 51.09995219015306, 51.39739728743031, 54.737079758797925, 52.41958656618672, 39.687812251429406, 53.20187584046395, 51.20298500983946, 48.076326462530325, 43.25674549225838, 42.168652549866714, 45.68088008511452, 49.72973885074739, 53.18556662528746, 54.813083525626894, 53.80037461557696, 54.66730863817277, 55.1254963874817, 55.122080003061605, 53.341437693565126, 52.34176674196797, 49.41691806239467, 45.59010859458677, 43.50540807170253, 48.83423036144626, 49.202689970693285, 51.714477769790165, 53.957151751364435, 51.774027193746264, 52.746104271181174, 54.87852434958182, 55.884306353907434, 52.50062273394678, 51.60386300856068, 51.87130589638987, 55.416795130698915, 57.03624763796407, 57.13166321477583, 57.50784204852197, 58.65832813324467, 56.53135230464321, 50.561108742990804, 40.95465936968404, 24.179074379705614, 13.141426655554003, 6.743741823780922, 5.877122081095173, 7.345900170264706, 9.671751933713114, 9.09710705280304, 8.523883050487887, 6.832448676709206, 3.6304847896099095, 1.1932866203208123, 0.4027256495769947, 0.3691307635557267, 1.8586678130011407, 10.678364499922722, 26.002401882602324, 49.57736261429326, 49.76029019201956, 38.943291479541415, 54.028464363467315, 57.437470805260446, 43.25180722821144, 13.886716211995772, 1.16356878271026, 0.004674322816783622, 0.046484169790581356, 0.0641166371473622, 0.021778431781116995, 0.03034354375314809, 0.013242934853018773, 0.024001050117095152, 0.040866960320741906, 0.03571683082789664, 0.018921730131091132, 0.027329211851822275, 0.05602123666434519, 0.03864259338907657, 0.044567597834693815, 0.06913103118178344, 0.014075885016110637, 0.04326073610554299, 0.028894961503664815, 0.02780727944487045, 0.02891781199122629, 0.08816205716181187, 0.08825250150215241, 0.06817905968355556, 0.02448018448757789, 0.034819799325158524, 0.07258939722012128, 0.12146746153913199, 0.10449080758037106, 0.1466696934714433, 0.10697569803244646, 0.09708647586164937, 0.15003657328986353, 0.14624521947435795, 0.18430678113814325, 0.24320286999066032, 0.16353033873583042, 0.07073456812049113, 0.15609179353041036, 0.165894455426643, 0.35676751405962054, 0.2471007866364333, 0.11645479503298, 0.3027215738209986, 0.19837410129126043, 0.2509357768201059, 0.18017673985131327, 0.08262754688339849, 0.13661926341873987, 0.2040567116871957, 0.09790741568130833, 0.2326043193498927, 0.15736121654270158, 0.22308325605286708, 0.14306448369977937, 0.9574070452682434, 11.566867636096093, 38.88687602935299, 58.98659913770614, 57.55265512774068, 47.03134036833241, 40.19665348914362, 45.29119260849492, 49.39923994002804, 24.90983351584404, 9.78413470329777, 1.5946712176645956, 0.4520487190494615, 1.366060039689464, 1.8535183538352291, 7.658451785964351, 12.462602642274673, 13.245976451904545, 14.96517973561441, 10.751922668949252, 9.836220837408497, 12.797583841508436, 21.56397919501028, 36.56727652395926, 43.97000105150285, 56.127603130955855, 60.27681181507727, 59.19564970078007, 59.93181190183086, 58.78195339633573, 58.28139228205527, 54.19999353347286, 53.43810842883203, 54.74061381432318, 51.02514866859683, 51.353188253218136, 52.813831836946555, 51.50876906610305, 54.37293083437028, 55.99134783590994, 55.25848434817407, 55.08015771065989, 48.60713297320951, 41.224714556048, 43.71785540734568, 44.32732112946049, 41.95824092434299, 42.72165575335103, 39.90894763700424, 41.11835556645548, 41.87756169226862, 45.985585489580714, 50.508741178820216, 50.846425871695246, 51.89345159838277, 52.51602195924329, 52.359821411871145, 52.82040572935536, 57.03723999761767, 53.693525329712905, 42.42941564129245, 56.66955701766476, 51.37041922538511, 50.2548030114943, 45.116427483097205, 45.763355762727805, 47.0053272093496, 51.2346032357985, 56.251400978334495, 56.74993814960603, 55.79204828508439, 55.2147420760124, 56.73191485866424, 56.43238306045533, 55.80201895006242, 54.87040112095495, 50.58185023646201, 47.912896986930605, 46.1231626233747, 50.43562427643807, 50.35152081520327, 54.167257432014715, 56.31180547898816, 51.73823556592388, 53.25001116721861, 56.3442591697939, 55.839767840600786, 56.49169714220109, 53.78089220293107, 55.48854312589092, 56.59267463991719, 58.85401910351169, 58.39130886139409, 59.16939335484659, 61.08017990666052, 59.237434710225756, 51.11663403049592, 42.46017094581358, 26.530356830166234, 16.952674119703232, 12.574130335161763, 9.1542608891764, 16.167214589734233, 13.942575666212267, 14.494543363971097, 18.285728885281472, 20.777104670001616, 10.186245306845635, 2.4779536791386145, 1.3934109720491594, 0.9201876747031367, 2.515947717812754, 13.277952594141807, 33.0830664788523, 54.645657154821585, 60.82370788820329, 44.20426461004442, 60.487548997325284, 66.01178769142398, 48.25026789019185, 15.464705344169372, 1.3460178312755402, 0.14139674093213775, 0.12313172626759737, 0.14422205787512565, 0.09704685379420558, 0.1391649582693654, 0.20599384161253131, 0.09946605220677392, 0.1128206118160198, 0.10700353000673557, 0.1514322169485592, 0.059799111162823056, 0.12302713228329537, 0.11071622957505527, 0.16338421512515316, 0.15193602701108302, 0.12129244109195088, 0.1986958735412167, 0.1374543605432395, 0.15733064963452278, 0.09085831127219623, 0.18992451920865044, 0.2027341068512009, 0.3729402123680038, 0.23104287894262424, 0.12118501258232903], [0.042546830260224884, 0.012680043132164547, 0.03433235290069734, 0.028145133795577194, 0.05614152779021571, 0.025961597435056202, 0.03206239033099865, 0.06292776828030906, 0.023228337447489464, 0.01706416226713167, 0.1225186950497089, 0.0354293410125519, 0.021153158478198514, 0.010447866891721084, 0.03161635478928445, 0.05341674456553114, 0.06463153633258997, 0.055305377294820164, 0.03305376364639209, 0.017935468537372448, 0.0320303640253241, 0.06878194023644732, 0.02933494686599701, 0.030176477213840813, 0.12020046702556073, 0.09384497399291686, 0.016832660072513165, 0.062498084885338624, 0.15812157412930844, 0.28527888559526016, 4.2501087150266095, 24.293615433477587, 40.34738625249555, 51.63588131627729, 31.24036050611927, 27.462058990232407, 25.298071676684966, 34.52946401411487, 30.32353197374652, 10.168941770830463, 1.7935802475098641, 0.1197869097813964, 0.27579747500919527, 1.337379914137625, 1.4454882808269993, 3.746392789386934, 3.201220597951643, 5.56570157889397, 3.9874018440323495, 4.807654513466743, 10.234220797015775, 15.183741065763659, 28.797692714198945, 40.92532396316528, 47.26117949331961, 56.95066544317431, 55.495615159311605, 52.935276262221805, 52.17901191403789, 50.66332570968136, 51.02490940401631, 51.101226960459066, 50.121269841347974, 50.7895318923458, 53.98096053831039, 51.4201666462806, 51.87765229132868, 51.60098006648403, 56.28813005262806, 51.523375972624756, 48.9572908032325, 43.704476202687914, 39.9375024918587, 38.217311751457956, 38.273397722551906, 34.127625034701445, 38.58479861290225, 39.37529740795013, 42.67440295988514, 44.86361503601075, 49.42648472324495, 51.86415933793592, 52.21401906782582, 51.67792520215435, 51.61420629870508, 50.27627406581756, 51.39889563283613, 51.162647354987364, 50.25468534038913, 36.07393649316604, 51.77080300546462, 49.92865008692588, 47.38729938384026, 41.89458870118664, 39.50654775865617, 40.63286027600689, 42.883312317632864, 46.38626344742314, 49.70290983876875, 51.2310613355329, 52.5425293368678, 52.188743314435406, 50.08480356585596, 50.2636165772715, 47.223018753913145, 42.82488076917587, 40.225353471694454, 39.64268538259691, 41.41885226772678, 48.49564744580177, 51.16348674220424, 51.80291545006537, 50.86152307448849, 49.15428007802656, 54.18391966050672, 51.038825973387695, 48.87054366450156, 45.865674711042836, 47.41956087850755, 49.78125918296076, 53.628009980724705, 53.256184977869836, 50.21654029046336, 57.80868784073861, 63.20400999438379, 47.142115946738954, 29.281560221026023, 18.53264993236911, 10.171030432947221, 4.510441816622212, 8.433166473142563, 10.157802239541086, 6.375974512869313, 5.6137295307651645, 6.3102762833718336, 4.36581471273976, 1.1872700721986833, 0.5125734342202064, 0.1241335317852997, 0.23359666368173015, 2.0197439890715385, 12.71630644798279, 20.34638527900942, 25.311174354245587, 49.30407147253714, 38.90249098500898, 45.374903832712484, 50.09441337277813, 31.19755764161387, 6.081353522116139, 0.5960013897668931, 0.03365404716122054, 0.05239293700264347, 0.054128068694544416, 0.08874547908142691, 0.04096763576531122, 0.02174960389252632, 0.09643574545700705, 0.040540970756762454, 0.04920114657931751, 0.04313576418245512, 0.02703961337946596, 0.05332875936742752, 0.03567452745271787, 0.0138425518713531, 0.056150816606297616, 0.06001920822346884, 0.015772960332763052, 0.07384210419390472, 0.027858182156999266, 0.1308323118475176, 0.016717848390521064, 0.030187897669572025, 0.08262435229675424, 0.01890392624773085, 0.015858752604183412, 0.01830068371829487, 0.03861947668596141, 0.0076762086621695955, 0.04736372299732701, 0.02959475792463749, 0.04935449056868111, 0.03996903249513238, 0.04585195956150851, 0.038785384517283215, 0.0180187001599059, 0.09479234130271981, 0.003992601522176917, 0.03937832124891781, 0.02741128093593063, 0.03116605596827163, 0.06760893705030603, 0.05822873817035749, 0.029054185217847268, 0.018828357419660015, 0.008365250166295277, 0.010745748689758682, 0.04829765312493809, 0.07104737714173333, 0.022345355997282653, 0.0403240989262779, 0.10370529166633084, 0.06821056121900197, 0.005849780357112327, 0.06893974668796986, 0.27178041636943817, 6.054805449901089, 29.091142877455685, 48.14447764427432, 56.68867464988463, 37.127104651543405, 31.17755355373506, 34.754639440967196, 35.66596684917327, 30.647368738728186, 11.071429137260685, 2.0515799065751414, 0.09250856425252654, 0.13696539726468826, 0.7109291647230426, 2.51568540930748, 5.292991928515896, 6.433137664871832, 7.9474770253704445, 5.603511756466282, 6.397576966593343, 10.508603338272342, 18.038884324412194, 30.217165139413652, 44.533147504252774, 49.686545710409845, 58.108058821770456, 56.64377135615195, 53.28231973032798, 53.08904101771694, 54.07372851525584, 53.9423644158148, 52.442936435822524, 50.884115926681034, 50.93988810816119, 53.03455537365329, 51.96306582420103, 52.986074878323464, 54.178110630281516, 57.35813302378501, 53.25899731728339, 50.80603330366073, 46.790134214585834, 41.3307793678776, 41.468489862257435, 40.2650047117664, 36.32579580430062, 39.44352311472739, 39.68071276141752, 43.60607570217502, 45.29846076042422, 50.80454672536543, 53.68686906753048, 53.59043367447392, 52.95755924717073, 52.38603461173273, 51.4545109195094, 52.93018894810831, 54.598325913952245, 51.44376362523725, 39.34881356454665, 53.242244874277425, 52.28991300828996, 49.398549602877715, 43.14338114953811, 41.15057391505088, 43.616313088324766, 45.34957708850984, 48.264270751707016, 50.85134060152116, 52.54842073686662, 54.53468153553625, 54.48181975272394, 53.19704348041166, 52.418743256599676, 48.23976770524056, 45.67213319963025, 44.10490312883931, 41.911356833673295, 43.91883765497516, 50.675453678254165, 52.42489745540004, 55.68814469921974, 51.324221549495576, 49.47512603575184, 56.18333608873429, 53.937484987320445, 51.2139323449904, 48.24277616316273, 48.28570650469873, 51.88965866642614, 56.64893711766889, 56.942632429061405, 55.72481886033089, 59.89552997773694, 61.54353341748638, 47.96562148678688, 33.307979106903076, 21.23404118322557, 11.962167043839733, 6.462951110255334, 4.598660824760314, 7.671309315389203, 7.067887965709933, 6.246412742522455, 8.0726114203853, 5.830402729972716, 2.713517993688584, 0.9937305219711797, 0.14598108767982454, 0.4185312079085458, 2.022982763667261, 14.02965130344514, 24.13396712272398, 33.620521406973566, 54.51630130890877, 41.103619221718084, 51.69199474396245, 58.53916260503954, 36.80952995054184, 7.982968101578375, 0.7510210585690315, 0.041217165924007856, 0.040164721994510585, 0.09142010652970883, 0.051752579428495905, 0.03070936414353069, 0.045790013691951195, 0.02159445768132085, 0.051442673880486726, 0.03096190694298956, 0.04717888896383586, 0.039748261277113235, 0.08248482470310504, 0.03997370563147049, 0.047747195968704845, 0.03886185158344527, 0.056626166502434405, 0.04086388064728629, 0.033124914062359644, 0.041662151925265796, 0.023283300425616965, 0.08581333883827733, 0.025114177786294493, 0.08857846425305452, 0.04728945460350764, 0.03638392487060159, 0.07126770402875639, 0.10289819505546363, 0.1726014019861337, 0.11517738938451776, 0.14956509213774435, 0.2559853994077252, 0.1305519389889894, 0.14851645566523075, 0.14163248150819732, 0.10136500030996339, 0.18102820061387556, 0.12285048772971477, 0.21228756034566512, 0.06578768558439708, 0.11037124486099328, 0.153242988331664, 0.1978397549640748, 0.15897943938691772, 0.16589877616253593, 0.1184840240485726, 0.06933314049796713, 0.15297902507647393, 0.19981385629263618, 0.1939001937787379, 0.23836284905912417, 0.1804717603109537, 0.1799638593389142, 0.12152669545743736, 0.2218451813584374, 0.4083759463842838, 7.260703348344372, 31.45433560494454, 53.17406623594223, 64.05731770300096, 42.050824549890336, 39.75669691639562, 36.05892166014641, 45.39617876852713, 39.3722693381771, 13.515263834307271, 2.543949518472918, 0.4036689183164028, 0.6822735539847805, 4.757025049578759, 5.568473223716983, 11.650768114674477, 12.9579891697053, 12.095535474438822, 11.697076597521383, 9.470862842375233, 15.902907636857803, 19.917642762584073, 33.692940127465036, 46.53161079652848, 51.89673854458717, 58.65512355681389, 59.65785395714545, 56.128744540675996, 55.9261501989057, 57.5512077731471, 56.3149316080155, 54.112720797138834, 52.57626564271989, 51.17173940904679, 53.30877219477008, 50.87015228886759, 53.23906775443785, 54.39132282810827, 60.199513666091434, 53.80212399267382, 52.87813125118133, 47.52163663987191, 42.33651822613132, 42.45429915766562, 42.029949695833274, 38.1264578911566, 41.92775626336375, 42.077798689565356, 45.46826408755395, 47.57777752414827, 53.1900655838751, 56.98850062585647, 56.59197645802652, 56.07630245147213, 54.41139359628001, 54.025236252815496, 55.505487765035326, 55.04145176179948, 51.43215733189737, 43.375436413672666, 53.56011767541209, 53.39472309235604, 51.66426750921434, 44.99454375236265, 43.03844598031814, 44.75157253203854, 46.01419133524741, 50.09496642697243, 54.68166059063327, 53.641448020935066, 57.04810104062481, 56.814500362642356, 53.55829377328196, 55.5126892366717, 51.24609970277356, 46.80748678022816, 45.46109399487896, 44.46232911079161, 46.535870490535615, 54.49441056097708, 56.15946846623575, 58.5098821117032, 51.447270224171305, 49.90673580477315, 55.85350398094424, 55.09079517856721, 53.95855203751595, 50.66109780342349, 51.01193028111612, 54.20850115437662, 59.12703960172592, 57.596067920807876, 54.582758026738325, 59.876180925676906, 64.32006159136373, 51.665487366337935, 36.503867487753595, 24.057682906427694, 14.951274933353549, 6.139567379028567, 16.102103244873785, 19.135314264605125, 13.432844050468939, 15.48672749150184, 14.730512172945085, 9.089849687391713, 5.378667769893523, 2.4801948233958218, 0.6870478139288965, 0.5900654953814323, 2.8638425853944596, 16.42086152107485, 28.546153076233406, 35.72274315741755, 56.81928957662275, 52.9780928550228, 59.51750370763964, 65.58977596221432, 43.55004072189332, 9.798162079626515, 0.8925741886900318, 0.1260108991916622, 0.0977924565273908, 0.11693893961848752, 0.12847558024429506, 0.18064573887855778, 0.09036953951562605, 0.15934870908817939, 0.16196797902305282, 0.16049436293542385, 0.192013441795303, 0.1123344524192714, 0.1910678747921221, 0.08450940356499727, 0.2044906085657497, 0.15046503094415511, 0.14049836494509252, 0.15729513379835314, 0.1100279608621232, 0.16971893488399445, 0.1505588460713625, 0.09686426439833257, 0.17232936416422168, 0.2498134733327935, 0.20399337153761618, 0.18374134696299033], [0.025339139505259456, 0.030103827180761485, 0.050492215405909285, 0.024087773185343515, 0.0241634224526464, 0.07662658098964922, 0.007631828231106122, 0.06743135786945782, 0.011319756346394219, 0.07122002271634918, 0.04901349334226501, 0.01711086298699581, 0.03279285708201989, 0.02283921457767006, 0.01044104200592565, 0.009108049975287531, 0.05471598371983536, 0.054279179537608746, 0.030023797805751526, 0.04957017496288304, 0.023058311893574657, 0.03904130384926835, 0.023537612888180924, 0.048369477698279005, 0.061286922859688925, 0.033798918218141606, 0.04139941824119418, 0.009134780698185487, 0.03182299743076006, 0.045889168451990814, 2.2518481602591853, 15.080697459559287, 43.091743146219564, 47.43603875560146, 49.70183118697136, 31.78791161506407, 21.929108711981005, 41.89280010038807, 31.20428450645939, 15.78550619463767, 3.5583259261423543, 0.27447799581193155, 0.04154178802104246, 0.12962112683923016, 1.5241168487456538, 3.824445994630937, 3.1598091942648736, 7.3824100821248955, 2.789294998491964, 3.577507296877523, 4.6367936172793, 14.397247010661712, 25.144730537168442, 41.985442561488, 58.64519211553759, 61.05821855606572, 54.88296055024671, 50.863954943995324, 49.260792040055804, 49.76555401279081, 49.01528696860037, 54.42516503795501, 54.90070143053609, 52.45883380213092, 52.50500009905908, 53.02487104169784, 53.09155525699739, 56.08664574161653, 54.21983288180444, 47.564853314430486, 46.724936577581595, 42.08450986493019, 39.75648118603615, 37.772232563264915, 37.824309872042754, 40.537393708382886, 38.981463986058394, 41.00190039603941, 47.474556430693596, 51.324452969335745, 52.5423449854697, 55.197526793326105, 54.29354598445278, 54.49728958068356, 54.738664396347545, 54.66130348943896, 53.92718092087777, 51.43895872177617, 50.843558619099284, 34.51153486005722, 49.41336047264838, 50.90671662361392, 46.897226687400575, 43.59685420989991, 39.46958726452243, 38.8651970894106, 39.00161320163358, 39.47977365985994, 41.027278131054295, 46.495634817308, 48.49269390106202, 46.81398222523351, 46.07717283310429, 44.71425510221913, 43.39138869316348, 39.341376750699936, 37.82155244581161, 41.18059181397961, 46.24689771283058, 50.21514392668202, 49.531921955846975, 56.57066229851016, 51.57589650923207, 52.09291196638539, 53.295102734719556, 51.973683680257494, 47.347259829121256, 43.752717433437226, 46.464397061255674, 51.315894357619754, 54.78091224547356, 55.79521756018362, 52.263762566351126, 49.57873544385357, 52.2807111278657, 50.08047326918572, 35.39074590129238, 19.010404425282633, 9.76039259664474, 6.039421423788994, 2.560012850069231, 4.618126567332975, 7.527771649822113, 5.5757683419412185, 3.770053016562616, 2.6898141301447347, 2.008697368925618, 0.35920784117714055, 0.30151268707648404, 0.645690587980132, 3.6858389935185834, 14.33845264296378, 29.51184649621287, 36.596843350318174, 36.04147495761995, 52.73530598609678, 44.591818317290276, 42.742644356143096, 25.71096585642907, 5.253251944818805, 0.3236773880499025, 0.017050945335218025, 0.11138358408765447, 0.025445867044430588, 0.08997680454124367, 0.06420921504257188, 0.03752111344628277, 0.03207859883625661, 0.07858191316406574, 0.022320804794529275, 0.05030950726640802, 0.06414656820256384, 0.060832671024986816, 0.10117766116895985, 0.07991638470200763, 0.031006167672814864, 0.025749103797058907, 0.09001692456583824, 0.009307571829506948, 0.021481586116996985, 0.05507373528915548, 0.03488921072153795, 0.047893120396521785, 0.018839314392197038, 0.04701130723039951, 0.06506797662305255, 0.04435633376781498, 0.05403831383333572, 0.0473505309632709, 0.03514018495597186, 0.016237946016894236, 0.06374964655767526, 0.07793564905202197, 0.03995262672223392, 0.01560942737400652, 0.009236862871705765, 0.047799366556348345, 0.02210643232589768, 0.07634978576172745, 0.008443038734126716, 0.033687034907240065, 0.03720984809220799, 0.021669059323387283, 0.02531165227053627, 0.024620233021015604, 0.1013990605790769, 0.06740561731520199, 0.05472435706084775, 0.043667743297954725, 0.008645107830694367, 0.07227711679954683, 0.018965031335791274, 0.0717181790499918, 0.0041788530577304625, 0.030490889274064573, 0.05656724668017799, 2.83232462502295, 19.153021804748043, 48.01533360635081, 54.429487489884906, 50.13611209008002, 36.46984092650875, 23.77248541001351, 44.468875546609205, 37.94285958813083, 16.8812556036057, 3.554132422131877, 0.4091354459524155, 0.04536416073660216, 0.5889365882162125, 1.9470752174815826, 5.375552917680433, 5.0531036911472205, 7.247704613593317, 7.172808426041757, 7.027524815451715, 6.993272227625694, 15.953058081288493, 28.360968174472934, 43.079081735303326, 56.84224720924132, 59.221447129403394, 56.651965187441924, 53.17747869799214, 52.94951838831748, 54.127198265444854, 51.843484524757635, 56.089611053466804, 55.36655741353189, 51.633002296570815, 53.3603984309781, 53.497630396196925, 53.4247370689146, 55.367996923385135, 56.700845764529326, 50.315968451961396, 48.880573165032175, 43.932177635931204, 40.820400561055834, 37.77334651639385, 40.05791141140846, 41.549729993266446, 40.25377496596306, 41.44099012497933, 48.52463768374536, 52.0650121473497, 54.64817531647221, 55.484028477822584, 54.95128039390811, 54.52354200424687, 55.09920866258683, 56.19379704998386, 54.655266961743756, 52.82034689380277, 51.09264481452204, 38.340842877664876, 51.285182199170514, 52.69088514389531, 49.69321766207295, 45.76685843929168, 40.941362534799886, 39.66508996102118, 41.1071022864311, 42.117328336161954, 45.35909275854788, 49.21082496643067, 51.364053218595444, 51.01800995488321, 49.85914960984261, 47.9954707237982, 44.2300541939274, 41.89478481969526, 40.549784475757235, 42.89356931563347, 47.64929802187028, 52.3035079433072, 52.929518222808845, 57.01174459149761, 51.82568873128584, 51.86846610038511, 55.49815293281309, 53.79891549387286, 50.506983956983014, 45.67453369017571, 48.43104208669355, 51.92894904844223, 57.34793093896682, 56.84814253161031, 53.347105518464126, 54.36036748270835, 56.04235826000091, 51.82864619839577, 38.0363335917073, 19.404220196508593, 10.939352147040829, 6.373566667879782, 6.287466229931002, 7.955631142662418, 10.768393681895349, 6.177378537193422, 7.99046375097767, 6.666410824944896, 1.6576918166491295, 0.4007088771510509, 0.1729213356250717, 0.43703600043250673, 4.210883052118363, 14.535959670620581, 28.27724322195976, 38.00221289357832, 41.72608367858395, 56.811276174360714, 48.63431892087383, 51.32728884297033, 29.705639039316488, 7.1333140807767075, 0.3428546219102798, 0.05251905805761776, 0.06705994312200816, 0.0207877651818337, 0.05567137963108479, 0.018933411056716597, 0.06520100013022462, 0.026290295119847984, 0.0317414646081987, 0.03974846429041317, 0.04624860924518397, 0.02418773425292344, 0.061117084997315566, 0.052463102995628313, 0.0519608136176342, 0.04995976897677587, 0.04446162872256772, 0.0876400371893279, 0.021254498504042145, 0.04430065449747828, 0.03213923469546341, 0.05361532987726312, 0.027343662185294014, 0.05634968537056158, 0.02508376601092037, 0.04708184477602763, 0.14353532133804214, 0.15731384166546408, 0.13945706759489354, 0.09905192805754562, 0.16461397010472514, 0.15276347857809838, 0.15575800902180134, 0.21100632425758148, 0.15646164545849447, 0.1461311336606741, 0.18655105103408137, 0.15489035316051977, 0.14695132271416728, 0.09337638099227222, 0.16977436900619539, 0.19837995420300192, 0.1080909918152517, 0.2002458839166549, 0.0831470157830946, 0.11934916714146254, 0.19353913654002453, 0.15381589952495792, 0.07806446673648973, 0.1356424400282483, 0.11397021867695356, 0.2663726936424932, 0.21909763766152246, 0.04743891069665552, 0.19682058223312904, 0.20231847350876178, 3.8031512018172973, 22.06639559038224, 54.784485524700536, 58.9730042026889, 61.14248675684775, 42.76281318356914, 32.400079850227606, 53.46660052576373, 40.776171914992794, 21.759166140710157, 4.329098876445524, 0.7948127893670913, 0.2954373646888041, 1.3463274533710172, 7.147497371319802, 10.629434893208167, 12.910238235227524, 15.719829047879866, 9.546837191427908, 7.918493651574659, 6.538491547107697, 17.42171898964913, 30.198053390749042, 45.174996314510224, 61.20580165616928, 63.305568002885394, 60.06383103709067, 56.19311847994405, 56.1960014220207, 57.29276672486336, 54.480564594268806, 58.31350472665603, 55.42193343562465, 53.28485750382947, 54.56367177347983, 53.07803484701341, 54.43478268961753, 58.19027954532255, 58.15450360698085, 52.541403616628344, 50.78005936837966, 45.98224755256407, 42.84072714467203, 40.43563565900249, 41.621081829071045, 44.02421997439477, 43.08425534156061, 43.57355925344652, 51.793419391878196, 54.12788075785483, 56.579385649773386, 57.41720391858009, 56.124924152128166, 56.52685726842573, 57.26907953139275, 58.53472640437465, 56.56971308492846, 53.17290129200105, 52.60196108971873, 42.32629652946226, 53.32802710994598, 55.3737118167262, 51.303809535118845, 46.871378267965014, 43.727527972190614, 42.75424672711281, 42.78073057051628, 43.31432196401781, 46.75483680540516, 51.886481546586566, 53.25102313872307, 52.357824925453436, 50.89840904358895, 49.63640605249713, 46.26339127940517, 43.648084286720525, 42.43730745007915, 45.240260631807395, 49.791982943011874, 53.962803886782744, 54.68098202059346, 57.6321223474318, 52.05164863217262, 52.58369461182625, 55.389389530304946, 55.39522993949152, 51.5378063724887, 47.82298449547061, 49.07834691386069, 55.98805696733537, 59.27908635908558, 56.98858691800026, 54.79488765039752, 55.171156698657626, 59.15069541623516, 56.71372290580504, 40.697959853756814, 21.83718796699278, 13.813347297330058, 10.14987414883029, 10.000044511210534, 13.393676242520733, 17.445062975729666, 14.176329316631442, 13.230180086628085, 11.373689924516986, 5.949439310258435, 1.9266114768482026, 0.8433092193257424, 1.236089729974347, 5.304407006309879, 19.580424831759547, 38.291781871549546, 47.41164945787, 47.09931504341864, 63.47817190231816, 57.76669494567379, 59.188283489596465, 35.351188798104566, 8.288717346806681, 0.6407951635699118, 0.22884244459771344, 0.26087429674883045, 0.15784054243516538, 0.1946948108173186, 0.17294465534148679, 0.15350871358907994, 0.12873700008757655, 0.1468900663237418, 0.1689788173403471, 0.12653487268835306, 0.12998469684633518, 0.14099247633449494, 0.17271289842263346, 0.11027769020368015, 0.24278720600470421, 0.18387611715062974, 0.20506610913622766, 0.0985303983813332, 0.1172880229029444, 0.12848738565920823, 0.20206594028540198, 0.1379040081895167, 0.139506081900289, 0.13153037116412195, 0.16480973621289577], [0.010714604342806964, 0.011649834904669514, 0.022313797005241918, 0.04179411057022311, 0.05737381085993783, 0.03584786633690519, 0.059601065943077694, 0.026945692915168983, 0.09235189161113194, 0.09819160365769941, 0.018837008467544953, 0.07297441768910616, 0.059778813663269245, 0.0345155245233928, 0.0926036817292052, 0.026582220584274303, 0.03144158140545891, 0.008527628247505956, 0.026121248243256446, 0.014490867183814126, 0.08019045265691896, 0.044951990111580784, 0.007017682834092769, 0.07028371771617282, 0.06972126362304534, 0.02854426560412732, 0.04758357490983702, 0.023215691251079404, 0.02793529656745734, 0.04045224245337229, 0.7039178667529937, 11.926979461023885, 35.88054795419016, 53.6458489202684, 48.95581599204771, 31.611379461903727, 39.15968471957792, 21.702648708897254, 30.747669627589566, 21.883503313987486, 5.459742671059025, 0.8069648437442318, 0.17014497170044532, 0.2896454948331079, 1.0208554890367294, 4.300503817296797, 4.70233348108107, 5.762484929253978, 5.909420347982838, 6.194616863804479, 6.627258706477381, 12.403921042719196, 27.864335313920055, 49.16776910904915, 49.37664316546533, 51.15413188934327, 52.221781438396825, 50.57270326922017, 49.30777811234998, 50.10710616265574, 52.18423651110742, 51.802264336616766, 53.90713760929724, 50.977374199898016, 53.12805683382096, 54.29158872173679, 53.8476783998551, 54.90612999085457, 53.284551558956025, 48.56634032341742, 44.892824926683986, 39.894427022626324, 39.79141773716096, 39.56404578301215, 38.88842144320088, 42.51698647775958, 41.32989683458882, 42.83956612310102, 49.00651654889507, 51.51208739126883, 53.94780866561398, 54.30719583265243, 53.26455531581756, 53.251423220480646, 51.92379113166563, 52.76525720473259, 52.23487823240219, 50.68252178930467, 50.4782525954708, 34.335773452635735, 48.650502620204804, 51.52600788301038, 48.21747687555129, 48.2584931004432, 44.58538955257785, 41.56810237515358, 38.591807888400176, 36.320524138789025, 34.85593857303743, 38.8095582685163, 39.285722240324944, 41.202102092004594, 39.48096213802215, 40.63496266641925, 38.481149981098795, 38.887774252122455, 37.8788229726976, 43.793494393748624, 49.25028008799399, 51.01399737019693, 53.21987951955488, 51.786523865115264, 52.43167138868763, 51.553099693790564, 53.136560532354544, 51.20665242595058, 48.213013218295195, 43.882555730881236, 45.990202119273526, 49.73674028150497, 52.59940370436638, 55.13580045392437, 56.53739275470857, 53.35112594789075, 44.09819979821482, 35.388984757085005, 33.47232249475295, 18.201633268787017, 8.614262303998395, 5.380427443212079, 2.556755811937394, 5.032019970878478, 5.984914206689404, 1.8843891231283065, 5.892306556624751, 6.0967988352621765, 1.7610457803933852, 0.5473054092257255, 0.14797460167638718, 0.9891267625554916, 4.948124395262811, 20.038883224610363, 33.01364837154266, 35.78351636086741, 33.201298482956425, 38.93669013054141, 51.9218691702812, 44.84646251124721, 22.419442246037146, 3.087519911989089, 0.09475974426154168, 0.1427221343281769, 0.09813112101607746, 0.10008803133161799, 0.00577896127417203, 0.01635121403171891, 0.0320865240158333, 0.09057278264193766, 0.05028266354554123, 0.08596094865952769, 0.06122428368056013, 0.05220302763665396, 0.06018941380804586, 0.004425481179608934, 0.04428836644717282, 0.03429975968995883, 0.0695380766785914, 0.013923506297531628, 0.06056704918944067, 0.003675549810249058, 0.033429882173696836, 0.018183472265879956, 0.03027936090685187, 0.03061124743262847, 0.03405206814228046, 0.06392048799522942, 0.0628787731271117, 0.0126100207806655, 0.013814096493015607, 0.007996534442363848, 0.07041765286797477, 0.06275653230747388, 0.032529893571570996, 0.019248179347825148, 0.021701099035600503, 0.015297002354336363, 0.007016346010664899, 0.02587076430509408, 0.1074420923607484, 0.05269543831086448, 0.0053335539245557406, 0.01002203117335035, 0.09592324029654266, 0.06111910746943566, 0.08254256474995807, 0.009359893719515493, 0.027546740602701906, 0.06860763225103579, 0.06105215138485355, 0.014900046235491193, 0.048348061710355744, 0.04072943221657507, 0.025986397616384972, 0.022920034938461842, 0.02709323187328635, 0.03581456832527634, 1.0696905298579125, 14.447523951530458, 42.99917128778274, 57.39886291565434, 58.77905868714856, 34.78421411206646, 36.97264563652777, 31.494859572379823, 33.36553988918182, 23.559738013052172, 5.7414997585358165, 0.7073279998956189, 0.06901955006704216, 0.3256950184943215, 1.6077572251519852, 4.349620717187082, 6.126617673904666, 6.011535823345185, 6.955082070442939, 6.353689566735299, 9.19475838061302, 14.33357713683959, 26.550584493144868, 48.97663593292237, 53.023584504281324, 55.73804117018177, 57.405468187024525, 53.33524034869287, 51.47655856224799, 52.007019904352006, 52.859472536271625, 55.29440933658231, 54.53017473220826, 51.452373227765484, 54.5104883563134, 53.90980482101441, 56.308381249827725, 56.844259385139715, 54.379304685900294, 50.92486150803105, 46.868648298325084, 41.0619754175986, 41.5798734080407, 41.041308449160674, 40.56044940025576, 45.00708356980355, 43.02001084050825, 45.0245185052195, 50.10585492657077, 53.275333989051084, 56.02589999475787, 54.3336247628735, 55.09169340133668, 56.22387770683535, 55.74641150812949, 54.835256684211, 53.13747052223452, 52.63124942779542, 50.327025613477154, 36.88248995811709, 51.26621361701719, 54.62582172886018, 50.63923451208299, 50.56004970304428, 45.4187245522776, 42.85646369380336, 39.68509012652982, 38.63226713672761, 39.54390048980713, 40.886041425889545, 42.80512771298809, 43.3292701167445, 41.58086576769429, 43.25156011889058, 41.165549524368785, 40.6097928170235, 39.40575068996799, 45.779135457931034, 51.300746164014264, 52.38411657271847, 55.293569949365434, 53.19258374552573, 53.04840526273174, 52.9802893823193, 55.17120376709969, 52.415287648477864, 51.08832628496232, 45.852052319434385, 47.95355235376666, 53.577964459696126, 55.21457733646516, 57.026033786035356, 57.24861260383361, 54.14209542735931, 49.64465479696951, 42.094719794488725, 35.08429896446967, 20.681185068622714, 10.613882695474933, 4.742802535333942, 4.583208157170204, 7.154522826594691, 7.831307697680689, 8.972098173633698, 5.49264939561967, 4.320623615095693, 1.3445321109987076, 0.8537080355228917, 0.16878139648226, 1.0471785765501762, 5.196373164653778, 22.063177285655854, 35.71307059257261, 40.377282557948945, 39.22979708640806, 45.92893077481178, 59.380150148945475, 49.0325257855077, 26.609527910909346, 4.539117284359471, 0.1554948424980525, 0.041247993302080906, 0.06352476144750273, 0.047706811643776395, 0.04941485063623517, 0.010833807623825006, 0.07925325899475044, 0.030423008138313893, 0.012466205967470043, 0.06966969058398279, 0.05110057348745966, 0.08420489893685426, 0.028776549208428592, 0.10918915587207002, 0.004708403674510098, 0.032198238787391496, 0.0853946258223826, 0.04236763846429606, 0.0600869610394922, 0.03794339643190465, 0.1028414202793952, 0.027018069071815382, 0.027963051932954022, 0.11228779766468272, 0.03240444284353045, 0.06822692485706461, 0.11662847482629361, 0.29858105245136446, 0.11909514004665038, 0.14685732372585805, 0.21614986922471754, 0.1085445465099427, 0.20095921902646943, 0.11818707304736299, 0.25693838214201314, 0.14524601099471893, 0.07875394586834215, 0.15679411229587373, 0.17974491141015486, 0.12018961155967367, 0.16582665664534416, 0.06721734354693083, 0.3268776437447917, 0.11879574522496232, 0.11771975941355191, 0.08759256272066025, 0.11440788470809499, 0.11332799184827075, 0.0828895642752609, 0.25665218701526044, 0.09077401861788766, 0.15014688995095993, 0.10962728921684528, 0.08304520269795772, 0.07863175484441942, 0.14932405023324877, 1.2070535267553022, 16.746228010423724, 46.29343663492511, 65.75351922742783, 63.65602001067131, 43.214576090535815, 50.717403427247085, 32.76198910128686, 40.917063451582386, 27.95409287175825, 7.581602258066978, 1.2086675820812103, 0.5781468220295445, 1.5276458787341274, 2.5403404476181155, 11.762256583859845, 10.549145936965942, 12.154264142436366, 13.471047935947297, 11.952090474867052, 13.085572104300223, 15.751411972507356, 31.127217777313728, 51.936170131929465, 54.2061516546434, 56.994831331314586, 58.54034716083158, 55.21341631489416, 54.74133160806472, 54.273549741314305, 54.3145541990957, 54.1828880771514, 56.23310312148064, 52.133747762249364, 52.69833372485254, 55.931355184124364, 57.39350495799896, 58.96311198511432, 59.10288172383463, 54.00500466746669, 50.18372181923159, 43.16299692276986, 43.697557141703946, 42.861472560513405, 42.917809563298384, 45.60860649231942, 44.62564483765633, 46.792060098340436, 53.620753595905924, 54.877959528277, 58.0534045157894, 56.27522937713131, 57.02222516459804, 57.939032123934844, 56.2487926021699, 55.46053348049041, 53.23613382154896, 52.35232184010168, 52.70571954788701, 41.91270612901257, 51.5837412495767, 55.671098078450854, 51.51349944453086, 52.622628058156664, 48.15579760459162, 47.06729673570203, 42.969208302036414, 41.61101310483871, 39.93115217454972, 43.025937541838616, 43.483725209389966, 43.69161867326306, 42.82912085133214, 45.172019235549435, 43.437602058533706, 42.77243083523166, 41.454082996614524, 48.29244905902494, 55.22901558106946, 55.36792239835186, 56.6266345208691, 53.53429671256773, 53.90008911009758, 53.40635684228713, 57.13808805711808, 55.482722328555205, 52.42012000853016, 48.71880677438552, 49.46635953841671, 55.05576449055826, 57.19356213846515, 57.73830875273674, 58.33498362571963, 55.583276210292695, 54.173548913771114, 45.50787610392417, 41.317231501302416, 22.860604947613133, 12.889789938926699, 8.926163296545706, 6.481466658653752, 11.183396135607074, 14.683480012801386, 11.638508746700904, 14.403209993916175, 11.560784039958833, 5.604005975107993, 1.3262678394394538, 0.6176628016175763, 1.448138822470942, 6.877827067529002, 25.12876060701186, 42.696882063342684, 46.893520047587735, 46.33970883584792, 51.27334840836064, 66.75488856530959, 55.93712106827767, 29.99419212341309, 5.44486855306933, 0.29915482166313356, 0.2432015063541551, 0.1687779184430838, 0.20585426039272742, 0.09309495093240854, 0.08891914355298204, 0.08022225296665585, 0.19502278837946155, 0.2072639541039544, 0.1455096524929808, 0.17259986981028513, 0.12161101109438366, 0.1394942381809796, 0.21796070189485628, 0.19992896866413856, 0.12133842168916618, 0.1603977745699306, 0.13727633703139522, 0.13130647430737175, 0.08176608867342434, 0.13632444214195977, 0.14142594420381133, 0.16828307160927405, 0.24837921884271408, 0.11399453430767022, 0.14831557208972593], [0.013892555387780793, 0.010896096317728442, 0.023545457628525557, 0.03645711691088734, 0.024569814859498895, 0.02023777150879464, 0.02516920013623613, 0.04563590744510294, 0.033330463113323335, 0.04033883845794105, 0.054561322059242, 0.02512031989622741, 0.0981517441029991, 0.06843041313151199, 0.017627497361372077, 0.044408600116449023, 0.08508422997810187, 0.04005260119635252, 0.038310747082916, 0.015446041887175414, 0.022386602171125914, 0.04884338351867853, 0.02628916705537948, 0.055305174281520236, 0.023713414745044806, 0.03353686252188298, 0.1392866436752581, 0.03406327983905231, 0.006275896655185329, 0.05254659891849565, 0.4287561834339173, 5.229845200815509, 29.40625236880395, 52.84419882682062, 47.378301466664965, 40.884064551322695, 29.57180973022215, 44.52217663488081, 64.0891791159107, 31.8069213821042, 11.91527412783715, 0.9878238615009093, 0.12504048029621764, 0.18751060680275966, 1.660689488053322, 2.3768219832451116, 2.8469043201015842, 4.005764910290319, 4.64858377172101, 5.226172391445407, 5.93323992144677, 15.543961736463732, 27.855578622510357, 31.95522619831947, 33.65726224837765, 53.87192649226035, 55.087869090418664, 52.29851868844802, 51.332223184647106, 50.16354906943537, 51.191064926885794, 53.129943493873846, 53.89280134631742, 51.72901407364876, 52.99467663611136, 50.58991070716612, 54.34199117845105, 52.382516245688166, 50.34979889469762, 44.86153225744925, 42.22147510897729, 37.810958123976185, 36.58770422781668, 38.822651140151486, 40.19070325359222, 39.294935887859715, 39.828707710389175, 43.70603338364632, 50.75267337983655, 49.39581963323778, 50.31898867699408, 49.70360017591908, 49.334995438975675, 48.26800092574089, 50.49085909320463, 49.22427085138137, 55.78934577203567, 49.442868463454715, 56.74812209221625, 33.768335926917295, 46.31365253079323, 52.93882208485758, 50.834874491537775, 51.975052587447635, 49.35536430728052, 48.26094458180089, 43.822872946339274, 42.39592252239105, 37.486609489687034, 34.73785169662968, 35.512625709656746, 37.585559122024044, 37.53969484759916, 37.68169641494751, 36.41976794888897, 40.14583133882092, 42.61607339305263, 46.73280877451743, 48.86660952721873, 53.84307745964297, 49.401942453076764, 49.88562560850575, 51.83078389013968, 54.0322494506836, 53.6713247145376, 50.83477643228347, 46.95041794930735, 42.440390433034594, 45.42853832244874, 48.265145440255445, 50.96729763092534, 52.89055339751705, 56.11656165892079, 56.826428290336366, 52.95341330189859, 37.041118452625895, 25.274788487342096, 16.881539975443197, 9.103018064652721, 2.90009974952667, 4.499961733818054, 6.983519744488501, 9.972031924032397, 7.185575740952646, 5.168918044336381, 3.9277018991208847, 0.389081072062254, 0.5304778283161502, 0.39402908074759674, 1.1108768875560453, 7.329714019452372, 18.115294056553996, 28.37496319124776, 37.59188198274182, 33.38140979889901, 50.25235545250678, 54.62855169850012, 38.671879153097834, 15.588635571541326, 1.8358130200255303, 0.08380741421734134, 0.013885633783384919, 0.08274593045033755, 0.05214783866258879, 0.06799378897994757, 0.11188380885869266, 0.04569308441733161, 0.03371349558414471, 0.04635893739759923, 0.055475835688412196, 0.0314791637638043, 0.07339124612870716, 0.0670130049148875, 0.02552233028015302, 0.02256361061647054, 0.03339660331426609, 0.01855834206986812, 0.07465188977338615, 0.08125215858942078, 0.030492503804364995, 0.05533013342609329, 0.020775785481917764, 0.04714887746940217, 0.06131105079886414, 0.042237506939038154, 0.035239048602600256, 0.004742411275078813, 0.0445702446684722, 0.07506362372829069, 0.05591369707197432, 0.022036199300219456, 0.06486517782773703, 0.062442872928635734, 0.04264750187435458, 0.05522947713372208, 0.0362896807341566, 0.05514112421341481, 0.03009924980541391, 0.03474790580390442, 0.007354999008032704, 0.021468667959373806, 0.027379827280979485, 0.0735232967042154, 0.07155897065756783, 0.09535735412951439, 0.0616027694195509, 0.034566814109923384, 0.017227335164563793, 0.0650727110464246, 0.04446485778316856, 0.052068586866821975, 0.020018396486017494, 0.0769390452713255, 0.02757926103508761, 0.03178790294294877, 0.07482152462245957, 0.48280028506152095, 7.72776153779799, 34.852628092611994, 61.99139748850177, 52.55709701968778, 42.259290679808586, 34.49733195766326, 37.7870395106654, 57.1488392737604, 31.63375854492188, 10.92431083802254, 1.1789466801189608, 0.12565698955328236, 0.17363007420734053, 1.297169981464263, 5.604052062957518, 6.973081336867425, 5.544473711521396, 6.566715451978869, 5.169859903474008, 5.799807262036109, 13.602492443976866, 30.804673433303837, 38.49347799055038, 41.867426287743356, 53.41089894694667, 57.193762179343935, 55.542875797517844, 52.80398276544387, 53.636894149165, 53.39291095733643, 55.63853063891011, 53.92178766189083, 51.848363953252, 53.774094735422445, 53.09633270386727, 55.95906280702161, 54.86207000670895, 52.35025867339104, 47.55710271096999, 44.060592113002656, 40.47265106631864, 38.32977787140877, 39.835485566046934, 40.83533302430184, 41.798094472577496, 42.717529419929754, 45.52226335771623, 51.2949881246013, 52.838597682214555, 53.366701679845015, 50.77902778502434, 51.860029082144464, 50.98664668298537, 52.76615150513188, 51.91633862833823, 57.120770792807306, 49.96078998811784, 57.18533300584363, 37.55313681017968, 48.93455282334359, 55.44516563415528, 51.05080489189395, 52.780832936686856, 50.317411884184814, 49.266067627937566, 45.36396826467207, 43.68217752825829, 39.53829934520107, 36.59068130677746, 37.68683864224342, 39.70422344823038, 39.71835574796123, 39.82312617763397, 39.98129183246244, 41.157139962719334, 42.90924702921222, 47.98150316361458, 52.14721325905093, 54.70477119568856, 52.93681775369952, 50.46930566910775, 52.812729650928134, 53.8494630782835, 55.246889821944706, 54.01249639449581, 48.87543093773627, 45.74676805926908, 47.82871900066253, 51.98951044390279, 52.92003000936201, 55.90070578359789, 56.05034812804192, 56.91636039364723, 51.70733513370637, 41.16167814500871, 28.89018612523233, 18.665100528347878, 9.458999633789062, 4.63741482265534, 5.251713395118713, 5.323020123666333, 4.9415176530038165, 4.958881495460387, 4.935420818867223, 3.093677542863354, 0.6712148602931731, 0.7289452237948295, 0.31580151389202765, 1.2170996973591468, 7.8279020997785755, 19.7682475274609, 32.14879124395309, 37.72405409043835, 38.77888925613896, 53.81325567922285, 61.69758842837427, 45.858508540738015, 18.95727199892844, 2.313824550759408, 0.07033185102045536, 0.05197815784823991, 0.0796813872312346, 0.08986948328393121, 0.07757682879004749, 0.058913084513117234, 0.035627378571418025, 0.05319182498140201, 0.04308910942786644, 0.009371431003655157, 0.028761706254895658, 0.03821227414112899, 0.012101844016973291, 0.027718512837084073, 0.015245647650332221, 0.007928959262977925, 0.07727035531593908, 0.06303518529861205, 0.036278875063984625, 0.01245136492915692, 0.009292660885670734, 0.06261243882979597, 0.0038005978633244074, 0.07166944819712831, 0.04916509065116125, 0.005843896801853854, 0.12182839620377749, 0.09641138386101493, 0.1538544643910662, 0.08179411983057376, 0.13678852288473037, 0.0930181276353617, 0.18612346672002347, 0.1091056599492027, 0.1406908981622227, 0.13411496795954245, 0.16822236680215405, 0.16595869955997314, 0.18621473843532224, 0.15825540968968024, 0.16228610469448954, 0.2642931939373093, 0.19733157820038258, 0.24735817685723308, 0.2527606748645344, 0.09707181293877865, 0.10195088137181536, 0.08778827520267618, 0.11432502463820482, 0.12815242137519584, 0.08414841527419706, 0.09876726510664148, 0.2621145318112066, 0.11862257104967872, 0.10470725806249727, 0.1412842639030949, 0.6215612698466547, 8.5090329570155, 39.81069226418772, 65.35663420154204, 60.282075635848514, 51.72591932358281, 40.83321494440879, 55.985621175458355, 73.68523813063099, 37.318987000373106, 14.90581270187132, 1.2154368575542205, 0.39334478037011245, 0.6502219674087341, 5.291223920160725, 7.082514974378771, 11.029448009306385, 13.463295371301713, 11.666165378785903, 11.392117219586527, 10.038746537700778, 16.839405875052176, 31.737730772264545, 43.83088242623114, 43.88321076670001, 57.88760200623543, 59.986093582645545, 58.224051152506185, 55.0957138307633, 55.20566178906349, 54.83544495797927, 56.64416359316919, 55.018886366198146, 53.4980736240264, 54.6979933400308, 52.9121107439841, 55.447581814181426, 58.567293843915394, 55.1037036988043, 47.96024391728063, 46.005962202625895, 42.978692593113074, 39.5448261691678, 42.21063367782101, 42.657572069475734, 44.03379055761522, 43.73029716553227, 47.423746047481416, 53.339496120329834, 54.157129872229795, 54.499929335809526, 53.64920254676573, 53.65467033078594, 54.12170302483344, 54.93245301708099, 53.04384746859151, 59.835941330079116, 52.4330363735076, 55.4519631016639, 40.85718847090199, 49.55009821922549, 55.573995882465, 53.972786318871286, 56.2359703740766, 53.18115788121378, 52.15359887769146, 48.66823957812402, 46.752408858268495, 41.51862952017015, 37.94312238693237, 39.54542236943399, 42.307390705231704, 41.62526307567474, 41.60292125517323, 40.72242759889172, 44.49036621278332, 45.83492725126205, 49.717693251948205, 53.49314712708997, 58.19448432614727, 52.89866878140358, 51.590821127737726, 52.30270777979205, 54.97322605502222, 57.10166885006813, 56.89011581482426, 50.21227275171588, 46.11554145812989, 49.11022009388093, 53.116556444475734, 55.59686722293977, 58.98542634902462, 59.66623606220369, 59.58425460323211, 53.928447846443426, 43.74605332651446, 32.33353291788409, 20.517806583835235, 11.285785686585212, 6.379799314083592, 12.505871288238033, 14.547151173314742, 19.52032235360915, 16.57700127170932, 13.633369341973337, 12.562058260363917, 3.5380509495735173, 1.4116156726114213, 0.7150529853759274, 1.9689412054515656, 9.835846251057042, 25.157011478177964, 37.77742970374323, 49.31382248478551, 47.98317801567816, 65.16160218946396, 67.57131422719648, 50.96743099151119, 22.87618656312266, 2.949965576971731, 0.18731127072486187, 0.1389121798978698, 0.2408912916096949, 0.16396121722796272, 0.1886338142738227, 0.1819200495318059, 0.10156851922792774, 0.1681590572960915, 0.15504358606713434, 0.21865923618597372, 0.1022723242039642, 0.12262418535688233, 0.1061428225629272, 0.10482781731914129, 0.18477092316794783, 0.226333889689657, 0.09344018845548553, 0.15681847389186584, 0.0970718435822956, 0.16942521677382533, 0.1186823259077726, 0.22200146329499063, 0.18931380923717253, 0.16003950589126156, 0.1698459062965647, 0.1458268588589084], [0.05603937379595253, 0.05362908115550395, 0.06877527527150608, 0.04556384155406587, 0.05673835624850566, 0.05340668200064571, 0.021386792312466332, 0.07667671378341413, 0.05531476570233222, 0.03243884019133064, 0.07438949699844084, 0.02978571683108326, 0.07584791390165206, 0.035418424259630904, 0.01731992838153195, 0.05921771554576774, 0.05664844433927248, 0.030242247777360103, 0.010228569435346271, 0.06937044131900034, 0.0016701874260287434, 0.0302969770986707, 0.040354784578084946, 0.04051459051908986, 0.047288788107013514, 0.03711565375147808, 0.08020575909364609, 0.011869661919321987, 0.042447514621721166, 0.06040952619045012, 0.10912996791904012, 3.0137585151580075, 22.480848912269842, 46.15371396464687, 56.207815600979714, 42.24309129099692, 49.521974825089984, 71.53442998086253, 64.5089158704204, 44.39837094276182, 15.800924051192501, 2.799042823814577, 0.0579826171029239, 0.10420109611004592, 0.7198487570689571, 5.233581748700911, 6.833004672681132, 3.943321022295183, 4.656879584635458, 3.5006442858326823, 6.93726372334265, 7.503951095765637, 15.851298070723011, 22.359202484930716, 44.628292437522646, 55.596098438386, 55.77275806857694, 51.54082267515121, 50.917205041454686, 51.088247837558875, 51.37086637558476, 53.26362571408672, 54.03177484389275, 51.759941962457475, 51.5670358750128, 54.4766971372789, 53.60509157180787, 50.576382452441806, 47.54373919579291, 42.31214461788055, 38.91348146623181, 39.96189178959016, 41.35054811354607, 42.70839029742826, 45.82934964087702, 43.37669941686815, 42.15691289594097, 44.41737482624669, 45.896516307707756, 45.68595170974732, 47.869641088670306, 45.28195150436894, 46.294174040517504, 45.82718841491207, 48.89907106276482, 49.71038979868735, 52.790227013249556, 49.32644467200003, 51.15208833448349, 35.57536794293311, 47.89392056003694, 54.59611369717506, 52.21325028327204, 53.433664383426795, 48.21043229872181, 49.89202691662697, 51.65509700775147, 49.21926590704149, 45.08664884874898, 36.315354454901914, 37.21766433408184, 38.74632573896839, 37.02912776700912, 40.222976515370036, 38.821576410724276, 41.352356326195505, 42.076002244026434, 49.061723909070416, 50.791089073304214, 51.1963483595079, 50.669821154686716, 50.779482779964326, 49.1202848957431, 52.21542719871768, 52.30757151880572, 51.49482504014046, 46.36042679509809, 43.34890157945695, 42.785919866254254, 46.22063352215675, 49.660854185781176, 52.76094651991322, 54.140495100329005, 56.934164031859375, 53.41865739514751, 44.01739112792477, 27.663896314559448, 16.641447774825558, 6.523475733495529, 3.0116982902249987, 3.7218071279987215, 3.271321442819411, 2.1024872458750203, 5.01712526044538, 2.5263652878422893, 1.0498754511917792, 0.5055636071389722, 0.434571924589334, 0.3072131166775381, 1.7889540570397533, 8.625142958856399, 25.377356506163075, 25.89437980805674, 25.620519922625636, 40.630961848843484, 40.12404649488388, 46.91127269498764, 27.793571833641302, 10.981267575294742, 1.0521824177234405, 0.02829185878527501, 0.05974252024785646, 0.025411841249273672, 0.02679300010054102, 0.04663966265657256, 0.040039604514717095, 0.049217479573863174, 0.03550816379908112, 0.02883473933193713, 0.03229085115655776, 0.052827902573851816, 0.053856030872632424, 0.037916250106307774, 0.03226583072495076, 0.02003300003707409, 0.0633913510659289, 0.038115007787822716, 0.1308261218570894, 0.09338078599783683, 0.05489182771153508, 0.060720492770234426, 0.044884367530504544, 0.05539911964367475, 0.009827156600001599, 0.03267615890851425, 0.025141542446949793, 0.020720347529277205, 0.055471139569436355, 0.007476478048990811, 0.07736159638772089, 0.05719035578471038, 0.029764149540794954, 0.05163730617852942, 0.04840820727329101, 0.007458112048616092, 0.04358116004075255, 0.022505064262077216, 0.04236762314253757, 0.09373955263365662, 0.06323054154974318, 0.023375162028617436, 0.022435250669537533, 0.08672997070055816, 0.04030697686117023, 0.06363045093753646, 0.06292028743172846, 0.014875563023041093, 0.012990304911058518, 0.013560166116803886, 0.010815509613753568, 0.019042059561357867, 0.06733411066834966, 0.04511274983205142, 0.052789893121488636, 0.07110451964000541, 0.04162144584340915, 0.11103063205917997, 4.072967123600745, 26.77274557851976, 53.80741919240644, 62.7201150309655, 47.04966175940729, 44.56032560717675, 67.35621929168701, 66.8827578329271, 46.08763771672403, 16.43467022526649, 2.568325578205047, 0.21853634036116062, 0.06435793569131244, 0.2693748696436805, 2.1122480640488286, 4.4730920272488754, 5.34886020806528, 7.822043059333679, 3.927097118669941, 7.153452509833921, 11.322569674061192, 18.540553508266328, 30.897070746268, 47.09730678989042, 57.000965918264086, 58.41569815912555, 54.26143353985202, 52.22223643333682, 52.89285975117838, 53.94071309797226, 54.6585774421692, 55.62118984037831, 52.688021813669515, 51.7830761017338, 54.91607712161157, 55.15346680918048, 52.296655562616166, 49.58374431056362, 44.245202387532885, 40.97064302813622, 40.85798863441714, 42.9485099546371, 44.139965195809644, 45.68368065741755, 45.84578437189902, 44.43280543050459, 45.02899000721593, 47.888633205044655, 48.00606112326346, 50.23009207940871, 48.32051361760786, 49.78712704873855, 48.040350483309844, 52.499916707315755, 52.745174669450336, 55.167363766700994, 52.897782325744636, 52.74265258542953, 39.45386248250162, 47.65234962586434, 55.163884624358154, 56.16100211297312, 55.60704185116676, 52.04657700753982, 52.37219256739463, 53.230493453241166, 50.933608393515314, 45.98891165948684, 37.302999419550744, 38.762340776381954, 40.680234662948116, 38.23030264146867, 41.60309776183098, 40.07247909422844, 42.50448588402041, 44.12557009727725, 50.244644072748, 51.89883309025919, 52.9022499053709, 51.704354132375414, 51.61987804597425, 49.44186825906077, 54.123558305924945, 54.27619341881045, 53.72829714129048, 48.421373444218794, 45.282371197977376, 45.78965917710335, 48.911093127342966, 52.13133158222322, 54.966416820403076, 56.74747882350799, 59.46871726743637, 54.080306330034816, 44.42218757444813, 29.67544463373, 16.372196674346924, 6.713264026949483, 5.286817137272128, 3.781307767475805, 6.63267255790772, 7.607818890002466, 5.023504995530652, 7.400740298532671, 3.449724566551947, 1.2482935718951689, 0.5437069410277952, 0.12565943337376081, 1.9820283161055658, 9.648580531920157, 28.82124458589862, 30.007614474142756, 34.11351626919162, 44.2206326607735, 47.00891617805728, 54.6681833267212, 32.474585271650746, 13.377835750579836, 1.1709031246362196, 0.02919895476811836, 0.052452090481716784, 0.04311449375123747, 0.09005804050473437, 0.030262384398449815, 0.022969932160190037, 0.02214313368313015, 0.062274375720129865, 0.020656337052763953, 0.06566547157783663, 0.06281083261954688, 0.09038422542113451, 0.05135344761994578, 0.01694383475208475, 0.02006435984625451, 0.07802293711011449, 0.03484576587535201, 0.031917530765396454, 0.03356004051203209, 0.04464537491120639, 0.06712640124943949, 0.05269516634965136, 0.039679803660199534, 0.05295347587596025, 0.052769327491161325, 0.057663012881793325, 0.18703679674335066, 0.20897468972590663, 0.16801895513649912, 0.1259750692594436, 0.16761171811771008, 0.17191181560197186, 0.17668953826350553, 0.23096882888386328, 0.08528470752700683, 0.172665492901879, 0.1366735024437789, 0.1104967070803527, 0.22274023252389125, 0.18780011142934525, 0.0657214113180676, 0.1624508595634853, 0.19163436616861051, 0.1692453086856873, 0.14445574533554817, 0.17710506435363524, 0.11895506086969569, 0.15600571589123818, 0.13534237871006613, 0.07193606977741565, 0.1254346631767769, 0.20831786126138704, 0.1514626766044286, 0.1508571913525943, 0.14615246154848607, 0.23634270584631353, 0.2352220111436421, 4.986527831323686, 30.431512863405292, 59.90901116401919, 68.42724600145894, 55.075972541686035, 59.31296779263405, 79.08773822169151, 68.90532801228186, 49.9790446988998, 19.563764564452633, 3.3739259887126187, 0.4795568832947362, 0.49127352393923274, 1.765462614355549, 9.094027992217772, 14.888727837993255, 11.903342277772966, 12.17410349076794, 7.9064907085511, 10.606655728432441, 12.826807460477276, 27.33914367614254, 39.40414251819734, 50.32727664516818, 58.5546834238114, 62.39512705033826, 57.13708785272414, 54.648720525926166, 55.646849986045595, 56.45300688282136, 56.45440324660271, 55.17185880291847, 54.53175936975787, 54.13504692815966, 58.54581886722196, 57.099393875368186, 54.24161380337131, 51.79894601145099, 45.81195785153297, 42.81924040086808, 44.053461244029386, 45.02622865861462, 48.35077862585745, 48.58190428826117, 48.24508251682405, 46.25057689605221, 48.355034397494414, 49.427237818318034, 49.13797086285007, 52.349925271926395, 50.14065027236939, 50.027556573191, 49.56181041656002, 53.57926276422317, 54.83903000431677, 56.29296633505053, 55.008386181246856, 51.62073704504198, 43.61011966582268, 48.340909942503906, 55.56545688259987, 57.04308432917441, 56.416866164053644, 52.440457497873616, 54.91367270869594, 57.27991704017886, 53.22413136882167, 48.210699019893525, 39.015427789380475, 41.58397620724094, 42.48218328722062, 41.17856394860053, 44.72473175294938, 42.87684825158889, 44.5698255877341, 46.76436032018354, 52.388117390294234, 54.52089832675073, 54.498450602254565, 52.38470885061449, 50.92755225396926, 49.891481707173014, 54.7344909944842, 56.79623388474988, 56.67033364695888, 50.775113259592366, 47.613545617749615, 46.21732304173131, 51.90205727854083, 54.06396573589694, 58.639139898361705, 57.84740163433937, 63.23654997733332, 57.83438721010762, 50.682710063072946, 32.94455582095731, 20.423455930525257, 7.820916848797952, 7.064497076695965, 9.398423529440358, 10.997068843533917, 10.417367046879185, 13.928537503365549, 10.39000557314965, 5.618013249289605, 3.2833562551006197, 1.4805523089824186, 0.6029678256280961, 2.5097957253456116, 11.764024592215016, 33.592056766633064, 38.17553850912279, 37.667571959957, 54.4591994439402, 52.83465962256155, 61.569770151569, 37.68789375981977, 16.03252333979453, 1.6465695683033237, 0.12012870756969338, 0.21162239684452935, 0.10610441857528304, 0.20101382577371216, 0.1633794807017811, 0.12731978339293312, 0.11608530316622027, 0.17671388453773915, 0.07693513056203242, 0.08694402332748137, 0.1719443436952368, 0.1822156215747518, 0.14697583752774424, 0.1678996139596547, 0.09214068883128705, 0.20165879519716387, 0.1717824080298024, 0.1675466619311802, 0.15793057308802683, 0.18483559631051558, 0.112088653108766, 0.07925260015913556, 0.12074764532547806, 0.15270920890954234, 0.17092225983017878, 0.11537612025295535], [0.037569897925300945, 0.02219334883134692, 0.04163898542643555, 0.01285154627816331, 0.03263641043656296, 0.03613719859370782, 0.052588626502021674, 0.05025111221437974, 0.03538190484828046, 0.008445949868238982, 0.08880203935287653, 0.020277179071619626, 0.06618392924147268, 0.023303084646261508, 0.047530649725588105, 0.04807029355077013, 0.027180711453359936, 0.06905734118434691, 0.07343326605135396, 0.10042638938513496, 0.038104389809192195, 0.06703505292534828, 0.034311446361243725, 0.04399165293321975, 0.02460845250395998, 0.039449456343126875, 0.06421294972120274, 0.05158464146417476, 0.10626649979742304, 0.06588690163147065, 0.038371559142345385, 2.6695141484660487, 17.991849222490867, 39.54823078647737, 50.400067990826024, 51.85351010291807, 52.26900285290134, 70.02749458436044, 67.78767216590144, 43.15268893395701, 20.38913715270258, 4.96096182254053, 0.40538477140568924, 0.08205369340195771, 0.2374345037124811, 2.152518548311726, 2.864293903112412, 3.7329814703233786, 3.584317266941071, 1.9758661499907895, 4.765709177140267, 13.881891696683823, 19.452202550826534, 35.52675016464726, 46.76888673536239, 55.69734657964399, 57.06565364714592, 52.92657252280943, 52.75331750992806, 51.606314489918375, 53.04984085021481, 54.660828882648104, 54.00609508637459, 50.61582972926479, 54.89529248206846, 54.19567892628332, 53.833993250323886, 48.244121536131836, 44.213466490468676, 38.827977718845496, 41.44758755160917, 43.6567723366522, 48.032988194496404, 48.85553667622228, 48.915439113493896, 46.09148948423324, 44.60979061741983, 43.812066816514545, 43.18293825272591, 41.07013002518685, 40.27759552001953, 40.16993038115963, 40.59735498120708, 41.616551491522024, 47.57545548100626, 49.230091648717085, 52.359158531312026, 50.986521167139855, 46.89195502188898, 32.14211536991981, 46.623190295311716, 51.52301119219873, 49.74047045553885, 51.17822308694163, 52.821747179954286, 54.144558675827525, 54.978172163809504, 53.00149371547084, 48.368033132245465, 40.42825768070836, 35.03924269830027, 37.28744722181751, 40.982916124405406, 42.33958551960607, 39.85978072689426, 39.73536706739856, 41.791230324775945, 48.17091049686555, 51.459982625899784, 50.90007605091218, 50.62723598172588, 54.25378884038618, 52.70969290887156, 53.66513521440568, 50.756717343484205, 50.31033985076412, 44.59827846096408, 44.25507107088643, 43.98166225802514, 44.31256909524241, 45.6682578979, 49.96017809837095, 51.47129474147674, 54.08571527850244, 53.6230952508988, 40.744306579712905, 29.202616637752904, 16.42185191954336, 8.299466602263912, 3.9963124884713084, 2.5730539954477742, 4.203145196360927, 3.884788472806254, 1.4876473863278667, 4.503463920085661, 1.720195030493121, 0.6638059320469057, 0.5134232708763692, 0.4630695986411264, 3.2724920251677116, 10.887880844454612, 19.47747830421694, 37.46135727051766, 25.769777874792776, 34.65381883805798, 42.01438180861935, 40.33038670016874, 19.416354048636652, 4.872097094212809, 0.3894734010100365, 0.02920233704630406, 0.04756590509186349, 0.06940077073992261, 0.038454066811790394, 0.04601787122326993, 0.017280800440799327, 0.027069787667583556, 0.04442360394844606, 0.04690555645333183, 0.03448555133335533, 0.09972146592072903, 0.03870834671561757, 0.018894350148677345, 0.05196311571184666, 0.017260667650149237, 0.030674769528089996, 0.04014127204314836, 0.11295730488434916, 0.055857335983385006, 0.053231684536102324, 0.055919044365685795, 0.09099079085694206, 0.00175529416845811, 0.12165544419399194, 0.023086193663578843, 0.019477722272577307, 0.05456401868873546, 0.022081953901497108, 0.016418373129600962, 0.02314502347050415, 0.07851639732478127, 0.0379871285610622, 0.029352942271338358, 0.03368038909449693, 0.030800497963003097, 0.07997862934585541, 0.004061259040158362, 0.046466974947120876, 0.010062762153064533, 0.02375338538249414, 0.004930136811679169, 0.04241800491487788, 0.06107557835357805, 0.08856544075834175, 0.07587416007393792, 0.007850815900676555, 0.10617647680544084, 0.07759652491058074, 0.09279916438484385, 0.020846730969365568, 0.029687615441939527, 0.010130824277087325, 0.05011565254760846, 0.07423228809549924, 0.03171162548354797, 0.05813828999957731, 0.0909662607216066, 3.830672266983217, 21.236784881161107, 48.10844675187142, 56.77749672243672, 55.85350790331441, 60.49372280797651, 73.59631015408424, 71.25377655029297, 48.92793186249272, 21.794953846162368, 5.291968189900921, 0.581726904117292, 0.029871924705202543, 0.6284815565712991, 3.6777468987049597, 6.851221140353911, 10.317631959915161, 3.3657738326057314, 3.113892948435199, 4.490322018823316, 15.083142076769184, 25.34663454178841, 38.526527881622314, 49.198963719029585, 56.45440324660271, 58.5254382318066, 55.17815812941521, 54.26166888206236, 53.266775377335094, 54.95125685968707, 55.98506027652372, 54.343913139835486, 50.746228925643436, 56.93426209111368, 56.337061620527706, 55.785572451929895, 51.43147876185756, 45.564071901382945, 41.2444362332744, 42.42815263809697, 45.16594740652269, 48.272523418549575, 50.07371502537882, 49.64722787180255, 48.53710297615298, 47.33209594603508, 46.1774403818192, 45.05341460627895, 42.49573899853615, 42.4340558052063, 43.49530404613864, 42.72862972751741, 43.37196903844034, 50.05033769915181, 50.52005721676735, 53.216604340461, 53.01382172492243, 48.95279184464486, 36.057329177856445, 48.487394778959214, 52.339480000157515, 50.50463837961997, 52.45299339294434, 54.17274090551562, 54.84851037302325, 54.77322439993582, 54.34709025967506, 51.605298596043745, 41.043108817069765, 38.09865613137522, 38.17733103229154, 41.061065427718624, 43.11437129974366, 40.84889658035771, 42.39657363583965, 44.143099169577326, 51.581591790722264, 53.86901609359249, 53.084855848743075, 52.2562002366589, 52.71685123443604, 52.674438645762784, 53.880991089728575, 51.47122806118381, 52.18443655198621, 47.8143278245003, 45.5005608835528, 45.75410681386148, 46.34067373891031, 47.97089315229847, 53.7821630508669, 54.4362888797637, 56.05643564654935, 55.01228109482796, 44.82221834121212, 31.3800988658782, 17.773667381655788, 6.117830093829863, 2.3442998961094887, 2.9660485204189055, 5.505386802457995, 7.083635301359239, 6.42232172912167, 7.176315024975808, 3.3877726908653014, 1.1922349348183603, 0.28162225600211854, 0.6476702204635066, 3.482064263474557, 12.840492610008488, 24.672792919220466, 38.89678785877843, 27.193986561990556, 42.17095498115786, 46.792593540683875, 48.69696309489589, 24.552793887353715, 6.713069379329682, 0.5118733830749989, 0.09133540784880038, 0.09352611287707284, 0.034616295728952653, 0.044786358071911725, 0.05388627219344339, 0.04070375294935319, 0.04077576138379593, 0.060059152047840826, 0.04644897954177953, 0.04441173724649895, 0.07058180252751035, 0.0103974171290775, 0.049153990037138426, 0.04478338565076551, 0.072689785381719, 0.040509584134504686, 0.039290121546195406, 0.060714057631670475, 0.020514534177979635, 0.03940614556232768, 0.04069424962865249, 0.07507690003201847, 0.03024551514235716, 0.0691377497728794, 0.006477720603617209, 0.043167215922186454, 0.17375975757116274, 0.1839799680296452, 0.12942460996489372, 0.11052997061802496, 0.26279184546682144, 0.15039502582963438, 0.15388593528299563, 0.08928449854495064, 0.19363505074814444, 0.15163170624404185, 0.1781525823377794, 0.0649015746650196, 0.21252428151426778, 0.051225882489234216, 0.16917351092542374, 0.13434081067962034, 0.13693942688405514, 0.2904085796927252, 0.1841534256574608, 0.22740034536728937, 0.17278913949285785, 0.19750305932135354, 0.17327879225054096, 0.07844844532589759, 0.17370481374523333, 0.1575453994014571, 0.24588600101490177, 0.1689561258160299, 0.13054034041781581, 0.1297174240913122, 0.2308611475652264, 4.470903834988994, 24.68297343100271, 55.252651783727835, 63.99840762538295, 64.98045536779588, 64.98466407099079, 76.92531201147264, 73.26421876107493, 50.99223213811075, 25.252964419703332, 6.901151932054951, 0.7254629558132542, 0.3777646357494016, 1.5910502571252085, 6.2426256941210845, 8.737283522082913, 10.942492984956312, 9.79570177293593, 6.395268161450663, 8.216258422020944, 17.667884980478597, 29.55727734873372, 42.95147918885754, 51.17927035977764, 59.1454472849446, 59.71754066405758, 57.65059278857324, 57.373987244021514, 56.10551626451554, 57.99784806466872, 57.686227521588734, 56.29258978751398, 51.740883165790194, 57.310393856417754, 57.97383923684397, 58.14344252309492, 54.4125428507405, 47.87212002661921, 42.33448643838206, 44.80459120965774, 47.832453097066576, 51.19096686763149, 52.90082216262818, 54.05925889169016, 52.249163504569765, 47.97351721794375, 48.265518065421816, 46.68653265122445, 44.41395059708626, 44.08569528210548, 44.578486181074574, 44.34659957885743, 46.219241080745576, 51.862468796391646, 53.8877179545741, 56.25576657633628, 54.944333876332934, 50.36441364595967, 40.74293375015259, 50.370650214533654, 50.940829477002545, 50.80870051537791, 52.689343652417584, 55.96569161261282, 56.97599218737695, 56.967025649163034, 57.04547697497953, 53.10157691278766, 43.49499025652486, 39.57758580484698, 40.562018348324685, 44.591351555239775, 44.70286453923872, 42.65291229371102, 44.059435013801824, 45.07874919522194, 54.810726181153335, 56.93208125329787, 54.586358762556515, 52.71372118303853, 52.67401895215435, 53.618043238116854, 55.80369772449617, 52.90906698473039, 54.863195726948405, 49.26813079464821, 47.95692559211485, 48.66828664656609, 48.86287543081468, 50.60464705190351, 56.20018659099456, 56.98925764329972, 59.24924888918477, 57.12450096684118, 47.07636133317025, 35.87759048708024, 19.384121971745646, 10.677294673458224, 6.560826993757679, 7.790036028431309, 11.857918289399917, 11.936482383358864, 10.400295911296721, 12.687885934306731, 6.267669537375051, 1.8697917773838968, 1.350423633571594, 0.9712148914414068, 4.7339639644468985, 14.34349386922775, 27.869720728166644, 47.62665810123567, 36.5929994275493, 47.402333828710745, 54.503887007313395, 54.91888553865495, 30.051264570605372, 7.870403922373249, 0.6911099185386013, 0.1843666738920635, 0.14326339076843955, 0.16543357693139585, 0.1324454172243995, 0.2457443513577023, 0.12252174407964754, 0.19559687934815886, 0.1318242731353929, 0.1634593223852496, 0.13918682241872435, 0.19937904010857307, 0.13384352768621138, 0.11841429472570458, 0.16246906181256618, 0.20671811645790455, 0.157005675137043, 0.1645447157563702, 0.22101785236548996, 0.16423420499890082, 0.0915406734472321, 0.12366269414703693, 0.10938639286905529, 0.11160977920817752, 0.20473773320836408, 0.12463855992762313, 0.17476731640917642], [0.015149408812454392, 0.06468245053603765, 0.008937038083170212, 0.021682615249207424, 0.0237594987641299, 0.03823295085420532, 0.0557243584414884, 0.04390526119799864, 0.05759591507094522, 0.051461289817046736, 0.008092022992880836, 0.029557246429425095, 0.0197838356853613, 0.01288259965217402, 0.005099159748023076, 0.02948012244286797, 0.03125289778014825, 0.042502776374139135, 0.020971833127400568, 0.07619533477531326, 0.08079174740780747, 0.032992311903545936, 0.047242769205401984, 0.028025329135538592, 0.08346579262926694, 0.043247003979500265, 0.010848497359773085, 0.07593757683230985, 0.01016851676057183, 0.05033720517531038, 0.07928836114344098, 0.9358755619295183, 10.890828505639108, 29.66895114990973, 51.27112050210276, 41.352960371202045, 40.28343985157628, 58.26986443611884, 38.325529944512155, 43.332737491976836, 22.783881425857547, 6.348799351722964, 1.0507463399441013, 0.15824410223191784, 0.12188307955981263, 2.3067787481892497, 3.6636347011212385, 5.549294794759443, 0.8164495638301297, 0.4971966399781166, 5.569750935800615, 13.536249495321705, 19.867573707334458, 29.83671484454986, 44.864713299658995, 54.82206967569167, 58.673374345225675, 53.25647915563276, 53.05126467058736, 53.82318319812898, 54.491421714905776, 52.3099837764617, 53.46944816650883, 51.733893502143125, 55.6937183872346, 52.20606057874618, 51.452082972372736, 45.551826261704974, 41.81000278842065, 42.066357135772705, 43.85262412409629, 46.03599579103532, 49.245514408234634, 52.14020790592317, 52.592943560692575, 49.956961754829656, 49.0666151046753, 44.87068314706126, 42.64862514311268, 38.315457297909646, 39.25622601662913, 37.76755317564934, 40.7288642083445, 41.23516375018705, 48.137213414715184, 48.66027716667422, 50.479237110384055, 48.99061918258668, 39.672515007757376, 32.266813401252996, 48.03216449676022, 50.258619477671964, 52.26505694850799, 53.79345947696317, 54.86679254039642, 51.97189900182909, 53.05688934941446, 51.68467952359108, 50.08996540500272, 41.05422481413811, 35.31766430024178, 39.61524840324156, 44.24849717847763, 47.44063577344341, 44.2460496194901, 41.07282469349523, 41.420405526315015, 47.24952220916749, 52.75552580433508, 53.41905747690509, 51.74181276752103, 50.4096071950851, 48.7299737622661, 54.96480080389208, 51.76571176898096, 48.25683001549014, 44.98611457886235, 43.851592540740974, 45.94580088892291, 46.4052830203887, 45.79782947417229, 50.188958183411636, 51.95121634391047, 57.9287515917132, 51.65554023558094, 42.208982359978464, 27.412878351826823, 13.367717996720346, 3.392126276608437, 2.099014477383706, 1.5460088224180284, 4.650897970122676, 6.5641977806245135, 3.47152681600663, 5.505430438826162, 2.5603388970898044, 0.718238011242882, 0.41641033945545075, 0.5419852043832503, 4.661527102993381, 14.104826469575206, 30.51200774408156, 34.494743193349535, 35.79598165327503, 41.76845704355548, 47.309303052963756, 28.222159416444843, 14.461775883551567, 2.2755870799864493, 0.08491877796909503, 0.04428344433225932, 0.02143182679109516, 0.013411869689251387, 0.07097213964668975, 0.04779976492206897, 0.02995473497937764, 0.016602644088467764, 0.10365643057852023, 0.07068481070980911, 0.02220886594225322, 0.030196416567290024, 0.11527038479764616, 0.06009038545251374, 0.02308772009376797, 0.1036152073873147, 0.019842445242008375, 0.01887044054456055, 0.09441900367458021, 0.02637326435726737, 0.018747803274421923, 0.041682526033612034, 0.08179758254799151, 0.04673676430097511, 0.045858965435576056, 0.03113324825291432, 0.00964492151979357, 0.14466730817671747, 0.061687023769463264, 0.03912218741231388, 0.025002135512148662, 0.051070772667205146, 0.0069981906844693575, 0.07286647590057505, 0.06508774935237824, 0.04229962517837844, 0.034983803427988486, 0.01245275920917911, 0.04652826964194256, 0.02863199990843573, 0.03768244007181737, 0.039807207912447, 0.07995710993606238, 0.011284602486768798, 0.030563985553359797, 0.0709043715089079, 0.04390372136127084, 0.058537490756040624, 0.04900088736547097, 0.00587583931666168, 0.055171262112356005, 0.043339646992183505, 0.07621840934359259, 0.023274971134660226, 0.04392462023984521, 0.03979725643031059, 0.05593009518399354, 0.04915850612545206, 1.212916244422236, 13.211206601512048, 35.64281702041626, 57.76366295353059, 48.73460608143961, 45.79134187390728, 66.63934338477351, 53.19877716802782, 48.41044179854855, 25.07069383898089, 6.504944495616421, 1.0736630328239933, 0.10501826677711741, 0.17555422660323883, 1.179690582136954, 3.123899405041049, 8.182956028369166, 3.7160988536573227, 3.376133792823361, 8.368980807642783, 17.60522903934602, 22.499927320787986, 34.23310933574554, 48.248204723481216, 57.30420043391567, 59.84752801156814, 56.20107696902368, 56.14382213161838, 56.431680956194484, 57.570042994714555, 54.71758165667134, 54.02466358677034, 51.06803586406093, 56.58971717280727, 54.91203315796391, 52.02145422658613, 48.22217195264755, 42.84231178222164, 43.2715916633606, 44.797805509259625, 48.34551872745637, 51.055676475647964, 53.43046765173636, 54.454751476164795, 51.532703368894516, 50.22006650124827, 47.804235566046934, 44.15035947676628, 40.0170716931743, 40.563120534343106, 39.746934137036725, 42.62536548799084, 43.97675537293957, 50.40396682677731, 50.95665231827767, 53.80125714886574, 51.94900412713328, 41.83849880772252, 35.8722835202371, 48.120700236289736, 49.86489195977488, 51.51107934213454, 54.883341020153416, 56.055647250144716, 54.17430593121437, 55.51327759219755, 53.033084484838675, 51.37609097265428, 44.886066682877086, 37.30187762168146, 41.07358955567883, 45.43616341006371, 48.79742676211942, 46.66349264883226, 42.73871414123043, 45.15594928495346, 48.75007983176939, 55.457638771303245, 54.11169705852386, 51.00679982093073, 52.22560574931484, 51.236199640458636, 56.32988760548254, 53.21464707774501, 51.07873608989101, 46.72171631167012, 46.25364418952696, 48.63401297600039, 47.51249751737041, 48.52749709160098, 52.2262764746143, 54.033277111668745, 58.74926044094948, 53.787234675499704, 43.7735491414224, 29.727998510483776, 16.515392603412753, 5.223480664914654, 2.7299809167462015, 3.9133832868068454, 6.860807413055051, 7.3542553090280105, 7.528812548806591, 6.0347994008371915, 3.2649309212161652, 1.0840717775206412, 0.30386739620758646, 0.5055104099935102, 5.404926567308364, 12.812666335413534, 25.97929519991721, 38.57802467961466, 39.367621329522905, 47.224662227015344, 54.016034372391246, 35.996104901836766, 17.08966289797137, 3.004523539735425, 0.07640247728915946, 0.10282064397488871, 0.03415318791784587, 0.04951381770473334, 0.0809635656074651, 0.11414873248506939, 0.039185106213535034, 0.022108611846042257, 0.040295811129673835, 0.021166254751264088, 0.06518740206956863, 0.02794764590479674, 0.04736097657211846, 0.03873645831199904, 0.07056212938961483, 0.017660659392394366, 0.022037624223758618, 0.005465525497246775, 0.053309542051846945, 0.0049219502045983275, 0.0600500739059381, 0.10900960018437718, 0.04476826690557984, 0.055897980778207706, 0.09099420760908435, 0.05318944627839712, 0.026977972029858542, 0.22216991070778142, 0.11793283144793204, 0.18022189307357037, 0.1622713345193094, 0.11941767838453093, 0.12511623873104974, 0.24678646076110103, 0.1133947027847171, 0.195020719942066, 0.2020170332323159, 0.2043439793370424, 0.1572876414584537, 0.13349178607665724, 0.10798587689116117, 0.1010628782152649, 0.2120450475523549, 0.11553719023903532, 0.13078630060678528, 0.12863465074089267, 0.15900407677456257, 0.20818096134931813, 0.18422151555217084, 0.12072967290277443, 0.1270630979730237, 0.11232556579934974, 0.13372103022711893, 0.12114769643953732, 0.19704887643456462, 0.11467167176306249, 0.14127865613948914, 0.2461853728539521, 1.7126503514666713, 15.912264450903862, 41.14388235153691, 66.48629250064974, 54.132438551995065, 49.66027759736585, 68.24701309204102, 49.900573761232444, 54.18889322588521, 27.91234120245903, 9.060560368722486, 1.4361405372619631, 0.5343792996098918, 0.5008080090966918, 3.3655076017302856, 9.213292560269757, 11.933162097008, 7.093205394283419, 4.59680897574271, 12.700397314563876, 16.43932607866103, 23.5575238350899, 32.62754398007547, 49.58356780390586, 58.76196499793761, 62.727751885691, 56.35342574888661, 57.37889412910708, 57.62905505395705, 60.044980126042525, 56.15601678048411, 54.27721323505525, 50.862613493396395, 58.39425848376367, 57.58133549844065, 55.41019378169891, 48.97148978325629, 45.22369254019953, 46.069822311401374, 47.13003504660822, 51.741079284298806, 53.17134803341281, 55.671200060075336, 56.884408766223544, 54.39726129654915, 52.617952592911266, 50.92099797341132, 45.88499630651167, 41.72709172771823, 42.707386170664144, 41.771567483102125, 44.75301204189178, 47.235444822619044, 52.191273243196555, 53.73250976685555, 54.93782666421706, 53.90924392207977, 42.596740030473285, 40.1829840290931, 49.759894032632154, 49.75776418562859, 52.378060433172415, 56.10921113721786, 58.69240960767193, 56.101915528697354, 55.849840487203295, 53.7665637846916, 52.570942986396055, 44.9960813214702, 38.505111740481475, 43.37860961114207, 46.714934533642186, 52.390729688829, 47.439490441353094, 44.16896327849358, 46.692420128853094, 51.14438087709489, 57.41043783003285, 55.85374324552475, 51.069757784566576, 53.272964877467004, 51.761612892150886, 58.980550842900435, 56.111340984221435, 50.81312102656211, 49.72628716499575, 48.43524686751827, 50.58401146242696, 48.96222906727945, 50.76130259421564, 55.254256033128314, 55.982734311011534, 62.16236575957268, 56.75145610686272, 47.16959999453637, 33.183310493346184, 15.781772098233624, 5.009865933848966, 3.9105113763963026, 6.91348631535807, 12.291365688846959, 14.10010785825791, 13.238901476706229, 14.818925338406718, 7.722986542409467, 2.479667264607645, 1.0519326117730912, 1.2616570870722494, 6.166402764858739, 19.58713992949455, 40.718779794631466, 47.614133973275464, 47.997494666807114, 55.170105503451445, 61.075335779497706, 41.60691815037882, 19.655173440133375, 3.5122138069521998, 0.23494352286140766, 0.23461408973220857, 0.09942842196793326, 0.14470362074432835, 0.20439438792246006, 0.3275318215450933, 0.18743598983893472, 0.1378631297378771, 0.15642908672171255, 0.1736030619471304, 0.16331866864235173, 0.052646075435463464, 0.28830680215070326, 0.09341279315131326, 0.13463368609307275, 0.22839317999539838, 0.07863788354781368, 0.1462281357136465, 0.2441251632427016, 0.1644767944010035, 0.1641452162256164, 0.2192708194976853, 0.1745306412058492, 0.18823544855319685, 0.15551396405264256, 0.06955553582238574, 0.08743087986424085], [0.002025381099590431, 0.036797980071916696, 0.0728374564900033, 0.04349919629373378, 0.034192905746280186, 0.006672350507635143, 0.029250259676407424, 0.01192892073548489, 0.03997618392590554, 0.06415021861152304, 0.02857275641403131, 0.06540179177517853, 0.038493049195817405, 0.009718781014183357, 0.09083383476301547, 0.0618103600948328, 0.007203748832727152, 0.046077430728943124, 0.024064840343330177, 0.06958279323073165, 0.02230470737202033, 0.0422348294617428, 0.024457579148152185, 0.027929037629115968, 0.03474022194202389, 0.06884040806682841, 0.012153126900234531, 0.03580155249144282, 0.09085315550046583, 0.08415429882945553, 0.03811698429466736, 0.3866270166491309, 6.763211488723756, 25.8423593736464, 52.52894616896107, 53.039517171921275, 44.59483461995279, 31.008418990719704, 32.999802404834384, 52.73201119515204, 27.789725949687345, 8.200463527633298, 2.2327469529644137, 0.04123250300425195, 0.24505706323731333, 2.042291611433029, 5.879150927066804, 14.905318483229607, 4.125977956479596, 11.411606496380223, 4.111629436092993, 3.615146851347339, 11.94231887017527, 22.53212017397727, 36.801830337893584, 51.119379689616544, 57.07569099241688, 58.00432389782321, 55.509818061705566, 56.2015280415935, 54.237267817220385, 52.53353534206268, 55.15692633967246, 52.01519412379111, 54.88228198020689, 52.34244531200778, 51.529188925220126, 45.679460187112134, 41.881958669231786, 41.133888152337846, 44.19257594693092, 47.302529119676166, 50.79710598914854, 51.96333646774293, 53.71945611892208, 51.05497437138712, 50.27377943838797, 47.12200987723566, 45.88815773687055, 39.802357227571555, 39.77148425194525, 39.25101318667012, 43.11045285194151, 45.72529308257565, 49.07832337963966, 47.53225449592837, 55.905106682931226, 44.657710213815015, 43.0620978724572, 34.17834520339966, 45.82358767909389, 58.9553496145433, 50.18358845864573, 52.27778503971716, 51.59888552081201, 52.1678174695661, 51.204306848587535, 53.62056924450783, 45.54603684333063, 36.604994035536244, 34.9147976598432, 42.63952132194273, 47.94174994191816, 49.56236347075432, 47.35651270035775, 41.9537615776062, 40.51609916071738, 48.02124854057066, 48.52276671317316, 53.05668146379533, 49.876717905844416, 47.505876556519546, 51.01267553144886, 53.00727136673466, 53.66237386580437, 50.92154710523544, 47.308361684122396, 46.214212602184666, 45.845223472964385, 46.64990555855536, 47.29467653459119, 51.344013829385084, 52.51217411410425, 54.159342089006984, 49.001091910946755, 38.89060620338687, 23.428430787978634, 12.193467251716122, 4.157726110950593, 2.056789917330588, 1.757126964869038, 4.653795130791203, 6.881770030144723, 5.540803353632651, 5.013225934197826, 2.112693007915251, 0.7818667614652265, 0.21180365324741413, 1.3895517275218041, 6.530746336906187, 16.48107970914533, 25.37442453445927, 32.24363219353461, 32.76065745661336, 40.66264675509545, 34.526443789082194, 19.199872555271273, 8.834167045931663, 0.48157586205390196, 0.09739455045951952, 0.07336425685113476, 0.05217052252602674, 0.015905617075341365, 0.05906235291472366, 0.08790930177295402, 0.01764291296562841, 0.029104333333370667, 0.01658851359670441, 0.015571029132021772, 0.04634043637422785, 0.0646431195820051, 0.053152237387914816, 0.05080236610205424, 0.037270537577569485, 0.05494429707346905, 0.018408418663086432, 0.07225359790027142, 0.008149585881901365, 0.02233297793164609, 0.016932136589480985, 0.023646112005676956, 0.024911938235163692, 0.043607467500072335, 0.02094435738399625, 0.020689391831476844, 0.026067417160037066, 0.029892881040371237, 0.06370459292684832, 0.09256476446265176, 0.020774345236620115, 0.06943154449184095, 0.03264447351196601, 0.03611854818319121, 0.01747784974624313, 0.03936653881664238, 0.05817958213869603, 0.02551440127013672, 0.02609944538093142, 0.018936373901763753, 0.023426895946144097, 0.02380547553090559, 0.052100410159196586, 0.04048641763567444, 0.02562046805847316, 0.014109513403156833, 0.09347704494552267, 0.021867506739292896, 0.04974121558329752, 0.03684446245672242, 0.05439305467711342, 0.025402874190119967, 0.040081796807146845, 0.02134808380487225, 0.038418922528264024, 0.06819841872540212, 0.06319774532570474, 0.020173676762609713, 0.5598261051120297, 8.240797750411495, 32.32624123173375, 57.68148145368023, 54.72538717331425, 47.965276318211714, 39.541319570233746, 34.73808703884002, 55.69065501613002, 29.587661989273567, 9.63769595469198, 2.128752907437663, 0.14874900931552534, 0.25100460215922327, 1.1499944401364173, 2.6723429128046963, 5.152150892442273, 3.1696477243977212, 10.01711662738554, 9.63784598535107, 5.960559719993222, 16.478239913140577, 26.069029223534372, 41.38520617638865, 52.66458565188993, 58.70325496119838, 58.65244850035637, 59.07996723728796, 57.17360904139858, 55.46709168341852, 54.192501806443744, 53.95361377346901, 52.846246304050574, 56.23234218166721, 55.56648454358501, 53.75327871691797, 47.39810943603516, 44.66941064403903, 44.344630549030924, 48.171043857451416, 50.50602689866097, 51.78918715446226, 54.414904117584236, 54.91428067607265, 55.60637504823747, 52.480355847266416, 48.75140951525781, 47.26726308945687, 42.96978489045174, 40.68657321314658, 41.195469364043205, 45.60932820843112, 47.98005973139117, 51.18455379239975, 50.91918976076188, 56.68542300501178, 47.09657330666819, 43.520932812844556, 36.9145514119056, 46.72070826253584, 56.986939522527884, 52.59419479677754, 53.83786855205413, 52.758640166251894, 53.1541641296879, 53.10968445193384, 55.0701399772398, 50.107416029899355, 39.897400179216945, 36.98576988712434, 44.262103880605395, 50.453620110788655, 52.27341159697502, 49.62019489657495, 43.68154210429038, 43.101619674313454, 51.183683026221495, 51.55634741629324, 55.18956045950613, 51.637477720937426, 49.52715627608761, 52.44628221757951, 54.59319937613703, 54.292816423600726, 52.64782144177345, 48.67508019170454, 47.58144886262956, 48.59631507627426, 48.85204968913909, 50.06619976412866, 53.849788635007805, 54.145327460381296, 56.224050291122936, 52.86768205704228, 41.59548836369669, 25.999854303175404, 14.872996191824637, 4.893996667477393, 2.1346457783252966, 3.6431937592644847, 6.3700997829437265, 6.927471035911191, 7.164685197414891, 4.764566296531308, 1.6812112062208115, 0.9137703706660579, 0.31382773432039446, 1.2697991921055702, 6.559361988498319, 18.49984715061803, 32.782006917461274, 38.229843724158506, 37.97366196109403, 47.17814291677168, 42.94982002627465, 25.899706386750747, 10.988122897763407, 0.9359764403873875, 0.11945923865442315, 0.020249318369033358, 0.04156307760445822, 0.028101677458072384, 0.04933597422355125, 0.06435290249364992, 0.020732361703149734, 0.057510507758706815, 0.0757373674141784, 0.03253833586049657, 0.03657697136664102, 0.020136458296028358, 0.009301869262520586, 0.01957108349268956, 0.042001019427252394, 0.031147319372863542, 0.006765959269907927, 0.026340904803345763, 0.04034017528136892, 0.04642311641345582, 0.029064328221964742, 0.0704684674799923, 0.09330920274219207, 0.04934927350991676, 0.0236590780437954, 0.07019639135368409, 0.04172902374017624, 0.14511257380006776, 0.14409249708537133, 0.22768994192442588, 0.21942559990190694, 0.08544031530618669, 0.0662943761375162, 0.08904036164524094, 0.12975324636265156, 0.14672816130182437, 0.21733889897023478, 0.11640752740805188, 0.16736028806096123, 0.18708942698374872, 0.13432588728685535, 0.22820582553263635, 0.18009043238576383, 0.18595026956210214, 0.14221555102736722, 0.11552119432317635, 0.2355156526450188, 0.10292445654950796, 0.12118660604521153, 0.10973691639880981, 0.17371642763816542, 0.1797111116109356, 0.1594807213592914, 0.0926779386317057, 0.11417028253837941, 0.23190057566089017, 0.21816432806513003, 0.10068089911533941, 0.6370332428524572, 9.454649725267965, 37.81810076005998, 66.13825275051978, 64.38652615393362, 55.50632322988203, 43.66646059097783, 44.60022395656955, 64.06682160592848, 34.06284709130564, 11.896599723446755, 3.0971917413896133, 0.3178474283026111, 0.8451123451513629, 4.82429075625635, 12.518214987170312, 26.751098017538748, 10.709494390795308, 17.977224665303385, 8.011001281199917, 4.409334880690421, 16.713056525876446, 25.058136370874223, 43.26923039651687, 54.00472617918446, 61.332098053347686, 60.6338220257913, 60.968635543700195, 59.7832795881456, 57.927657250435125, 55.710211953809186, 53.79738184713549, 52.38131600041544, 58.14839647662256, 57.51106231443344, 55.94149058864963, 49.9243119455153, 46.37022879815871, 45.5821854068387, 49.778254647408765, 52.8465404818135, 54.13454878714777, 55.72022184248894, 56.30542770508797, 57.54547326795517, 53.77559308082827, 51.806967258453376, 48.93620806355631, 45.600695071681855, 43.42580749142555, 43.237235623021284, 46.810687434288766, 49.80698208655081, 52.5575480922576, 53.75630678669099, 58.4302423077245, 50.080798825910016, 45.36631384203511, 39.85628197270055, 49.15146381624284, 58.56045323033487, 55.06455452211442, 54.36281896406605, 55.42977817596928, 55.69301628297376, 55.315727418468846, 58.31579539083666, 50.17320594479961, 41.40731265467983, 39.05442007126347, 47.80162326751217, 52.42471310400194, 54.29393429909983, 52.602769097974225, 46.737413637099735, 45.00403196580949, 53.39185976213025, 51.89214544911539, 56.797477276094504, 53.48532592096637, 51.28672761301841, 53.916629745114236, 56.22563100630238, 57.27160553778372, 55.78774152263519, 52.582937594383, 49.58644682361234, 51.1613529728305, 51.60974264144898, 51.647711184717, 55.96092985522363, 57.9165255638861, 57.83599538187827, 53.32062951980099, 42.25641558247228, 28.16583810314056, 16.013465523719788, 6.309902677612921, 5.126577529215044, 6.3016681517324145, 13.403582188390917, 15.825223134409999, 12.408355282198999, 10.180857931413959, 5.005206158084254, 2.467215210199356, 0.5704234300121185, 1.958933523105037, 9.026108230313948, 23.644508277216268, 34.866191648667865, 43.66447194930046, 46.70959618783767, 54.42862456844699, 50.10934583602413, 31.487128580770186, 12.071886524077385, 1.12084828797848, 0.27848083585981404, 0.12494357017379616, 0.1432609086435649, 0.09715091151696059, 0.1074663773479481, 0.19369923359444066, 0.09024046902214328, 0.1787124087493266, 0.20177980644568322, 0.1161640723265948, 0.05612318381486882, 0.21078775937278427, 0.1333751568510648, 0.12377497965409873, 0.16056603812161954, 0.13870634739437412, 0.07871767926600673, 0.15154492380397935, 0.12733705867562564, 0.10673333845672109, 0.16389305072446025, 0.13910852823286288, 0.1604258593532347, 0.12266388403311854, 0.18797684791347674, 0.1582593933468865, 0.18463566268403686], [0.024770049175487894, 0.06948137085043615, 0.07880587130784988, 0.04987191401361939, 0.02822859524448793, 0.05731944159995164, 0.03811812959611416, 0.044255727271158854, 0.008629969933310585, 0.03914767898799431, 0.07991715845081114, 0.06425328808085573, 0.054812372902468334, 0.04601823128459435, 0.053978884562609665, 0.07742341968321031, 0.06064025655148491, 0.04987923781417551, 0.06057477135571742, 0.09339693513128067, 0.020219820153508938, 0.031875826854018435, 0.05083523510444549, 0.07288996415633349, 0.011133571125326619, 0.07073978517925547, 0.04463694411359968, 0.08159651511138485, 0.056450694063377965, 0.04822235434286056, 0.04425612563687948, 0.18200252655773394, 2.5104093311294435, 23.082762110617853, 43.73282709429341, 45.093430626776914, 45.305532793844904, 34.4426227384998, 40.5305060263603, 50.4364283623234, 29.55797160825422, 9.797327595372355, 3.1966164708137517, 0.09816525023310416, 0.22525105505220352, 0.40154078734978554, 0.5664363407319593, 1.184547947299096, 10.054682147118355, 11.520376763036175, 1.7541888644618375, 4.076904447809342, 6.014908081100834, 17.510925454478112, 31.252241365371216, 45.38443126986104, 53.21006967175392, 58.51102352142335, 56.703916980374245, 57.606481813615375, 57.38478160673573, 52.75309785719841, 54.30183003025671, 53.498807107248616, 56.2677925632846, 50.02936086347027, 50.716764080908995, 44.468091072574744, 43.8150478178455, 42.78956767051451, 44.07969405574184, 48.896564668224705, 50.120712864783506, 52.7510307681176, 56.12916423428444, 55.612101708689046, 51.787269115448005, 47.44725281192411, 46.35401371986636, 42.79717314627863, 42.884951868364894, 46.02712338970554, 49.265318455234656, 51.56921279045844, 52.89329905663767, 51.410811793419626, 49.94723035443214, 42.21806264692738, 54.403780275775546, 38.15891158196234, 44.12495820753036, 56.61051750183106, 48.95438824930499, 50.59976370103898, 46.93497165556877, 47.94207157627229, 45.63138369591006, 43.28140935590191, 37.2136321375447, 36.05943941300915, 35.91576691596739, 47.1216215625886, 50.447395309325195, 53.56189450910015, 48.84460895292221, 44.50603608162173, 40.00956819903466, 42.78883810966246, 48.62150453752088, 50.5074114953318, 51.46476399513983, 53.57740748313166, 52.08098403869137, 53.36870601100307, 52.363837918927594, 49.026775590835086, 48.03073283164732, 46.73040043923163, 48.8730461366715, 50.27276354451334, 51.344704166535415, 52.131139386084776, 55.74887475659771, 55.96178885429136, 46.937199561826645, 31.9645869347357, 20.226821630231797, 8.822916707684918, 2.850027507351291, 1.9891817387073272, 2.4388052378931353, 4.289362324822334, 4.35826022778788, 7.006732331168267, 2.399620024427291, 1.525080280919229, 0.5413301685644735, 0.626666295912958, 1.6060289307948084, 8.95946421930867, 15.37905646908668, 19.089196997304118, 24.705589817416286, 38.853065198467625, 41.622023197912405, 24.14324745055168, 14.608124417643394, 5.216295863351514, 0.5330064087625473, 0.055180658180747306, 0.054761309311875415, 0.04688741549128487, 0.14118237420916557, 0.019541918525412198, 0.11035746293923548, 0.0419922860249156, 0.010327887946679708, 0.034965831005284866, 0.02865223803617541, 0.02285800288401304, 0.10485833826204462, 0.045066665812966325, 0.026131511906221993, 0.049817284283738945, 0.01831945287243974, 0.039341851633282444, 0.013860937981535832, 0.07728360097614989, 0.10340238816194958, 0.03357858750067892, 0.031529828988676595, 0.02784046828897009, 0.024509722922718333, 0.0072430199361406275, 0.03763134583770748, 0.06378105233213113, 0.01565070897941628, 0.01928093343702776, 0.07534235715866089, 0.01647841335544663, 0.0644896338663755, 0.008364141254024881, 0.022741279812649857, 0.045136525370781465, 0.03833996184590844, 0.024494795699513728, 0.017045153710510463, 0.029862371588786765, 0.053239310941388535, 0.022649766779654933, 0.035840454436237776, 0.10790199792433171, 0.055107967928051955, 0.010353233008044622, 0.0354678560829451, 0.05250308895483614, 0.03782839514315128, 0.038170710040797154, 0.04998758945974612, 0.0271773406664931, 0.04202506692719556, 0.041329493565905484, 0.043583944770357305, 0.02545264883778028, 0.022956682669539607, 0.011243160002894942, 0.007863517638461125, 0.08560453391363544, 3.8656007282195555, 24.943730638873195, 51.55840273826353, 54.793648181423066, 50.022535939370435, 39.75562218696841, 46.39994859695435, 57.29173906387822, 33.714230752760365, 10.713268691493619, 3.877349207478185, 0.165184797538865, 0.1937331559677278, 0.17012629447685135, 1.7490536238878005, 2.400362332982402, 12.439790137352484, 17.56652112930052, 3.001790628317864, 6.683566781782336, 8.162142951642315, 20.58901329194346, 32.97597792840774, 47.14597555898851, 56.05611401219522, 61.13386146483883, 58.67240551979312, 59.32956334083312, 59.02412837551486, 54.06187903496527, 53.71809505647229, 54.156416000858435, 56.71708437704272, 53.19320348001296, 51.92654855789677, 47.71994775341403, 46.31560587113904, 45.9415372725456, 46.4410158126585, 50.606423885591575, 51.11322941318635, 55.42491051458544, 57.212142405971406, 56.48713150332051, 52.8738284111023, 50.60681220023863, 48.168784572232155, 43.753325400813935, 44.14566047729985, 47.22035154219597, 51.540191173553474, 53.04674217777868, 55.97443457572691, 51.26805320862801, 51.507498218167214, 45.11037918829149, 55.11399599813647, 41.25500309851862, 45.787658768315474, 58.433050724767874, 52.88670163000784, 52.48862028121949, 50.74111023256856, 49.62630987167359, 48.618907928466804, 47.43885893975535, 39.36281250369164, 38.285611983268495, 37.96347164338635, 47.90469923327046, 53.2344981931871, 54.354950689500384, 51.24741369678129, 44.906412016960886, 41.348324129658366, 45.6785580419725, 49.95010545176845, 52.692297197157345, 53.49799909899312, 53.88681188706429, 53.15669798081922, 54.599337885456706, 53.729097304805634, 51.240267138327326, 49.95290210170131, 48.58247303193616, 51.103403875904704, 52.550727090527936, 53.88493699412192, 54.071928147346746, 57.877988276943086, 56.728161150409335, 50.23696799432078, 34.20562921031829, 21.80864291806375, 8.331329976358722, 3.845704260372347, 2.7197212221161013, 5.547547378847677, 5.874807392397235, 6.926581638474619, 7.657556014676248, 4.581995654490687, 2.341327229815145, 0.4968727686472478, 0.5226092473153146, 2.132586288836695, 10.380347717192866, 17.72066047114711, 22.38478614437965, 28.256764527290102, 42.678658731522106, 47.091678188693145, 31.433792191167033, 18.47513621853244, 6.563952142192472, 0.4681752682212861, 0.04178328574785302, 0.07548407576377354, 0.041145103863410415, 0.07572898641228676, 0.01466448185965419, 0.0984248391262466, 0.0467517413198948, 0.049815254150739605, 0.05337153771711935, 0.03403222263460198, 0.032528675491771394, 0.02233881743684892, 0.08613318054666443, 0.009900943316038578, 0.04044728203406257, 0.06206635220517075, 0.007399184565480439, 0.06982211143739762, 0.110322582956043, 0.031003363791011998, 0.02887033369211901, 0.031240117518351446, 0.017208362997118986, 0.03495584887963149, 0.002605154286063607, 0.04346058546235004, 0.04616419018636789, 0.09532286485116329, 0.15348795260633194, 0.1858647128627185, 0.1279352124660246, 0.1701739451457416, 0.13871336475976054, 0.21686219309847202, 0.15301192089194252, 0.108753458686894, 0.20017567961927385, 0.14605446358121213, 0.1711835111341169, 0.10804733246444695, 0.11549365346229847, 0.12811623138165282, 0.2023528555348035, 0.1355556729099443, 0.1203480615250526, 0.1761818058308094, 0.27303824081055583, 0.07634527350385344, 0.14345298220794048, 0.22954226591654364, 0.22527834310406641, 0.09844723187627331, 0.11927360788949075, 0.11219025168928409, 0.3134177547068365, 0.11228857907436549, 0.10148209684918966, 0.13714833906100643, 0.32819289413671343, 4.604096249226601, 29.231979500862863, 56.998808614669315, 61.33017609196325, 56.684842494226274, 48.845769974493216, 53.434609674638324, 61.01790835780483, 39.35372437200239, 15.383495611529197, 4.598127382416879, 0.4561853793359572, 0.4371610872687832, 1.1602221429347992, 2.8337079959530986, 4.3642894010390005, 22.171434702411776, 18.624908001192157, 3.782044682771929, 6.604177519198387, 7.956510243877289, 20.572839398537916, 34.57615198627595, 48.38488755687591, 58.02037031419816, 63.17659654924947, 60.6577798628038, 61.01183260640791, 61.82335922794958, 55.67042735315139, 54.25843684904037, 52.37189838963171, 58.88027937181535, 55.44675419407507, 54.36548225341305, 48.99079176687425, 48.64093203698435, 46.76538405879852, 47.45718033083024, 53.01595941666634, 52.21618421616093, 56.987986795363895, 59.942755314611624, 57.984904243100075, 55.87286087774462, 51.663545793102635, 50.98597595768591, 45.563114843060895, 46.17441623441635, 49.28437725190194, 54.38969504448676, 54.3715109363679, 56.91451687966624, 55.75311483875398, 52.86737611216884, 48.03147415960989, 54.58694711808236, 44.22039731856316, 47.74123445633919, 58.53075696576027, 55.13132110718758, 54.57214801542221, 52.14109043921194, 51.249680826740885, 50.13741039460706, 47.71075371773013, 40.49802095659318, 40.162630850268954, 39.58567765451247, 51.12935035459457, 54.42733018629013, 57.68106176007179, 52.52228598440848, 48.31365731454665, 42.675258036582704, 48.15076520366054, 55.0299866737858, 54.083306943216634, 55.39633212550994, 53.43520979727469, 54.18551998753702, 55.53891028127363, 54.91775981841549, 52.56758543752855, 52.28671627659952, 50.74469920127623, 53.98625181567285, 54.54609563273769, 55.87841495390862, 56.09762053335867, 59.302777474926366, 59.9334357630822, 51.91913920064127, 35.49655575906077, 22.424651153625984, 10.56316742973943, 4.859354784411769, 4.581076839277822, 9.271774118946446, 11.918742483662022, 13.424931649238834, 19.8392306604693, 9.194039606278944, 3.8330597646774787, 1.851806361829081, 1.2423332852701987, 3.022306830652299, 13.112904160253464, 22.92594575112866, 30.13752925780512, 36.49527357470605, 52.66546426280853, 54.660275828453806, 37.93866657441662, 21.755133944173014, 8.066928396301886, 0.774664493097413, 0.26093239685700786, 0.18210717416819067, 0.10425434688166266, 0.24167214970915551, 0.161320450865934, 0.25539718177770415, 0.12370466044352901, 0.1277206082557959, 0.09195420004787946, 0.1338474500563837, 0.1004156794759535, 0.1997384579191285, 0.2034587953840533, 0.1321465816468962, 0.15080132822115577, 0.10292994173904581, 0.09083422546785686, 0.11455108952378074, 0.15958181432177945, 0.1960049130983891, 0.09056384239586131, 0.18503749112208046, 0.07195129960535035, 0.17904605536210924, 0.16965515040341886, 0.134300162054358, 0.2840466178472965], [0.0808538388340704, 0.020205174467616507, 0.025221332419483412, 0.030003982941590013, 0.024436787521887212, 0.047263763844966895, 0.01925349025236022, 0.06040410994882546, 0.04250242780413359, 0.06459682488874083, 0.027703014878375877, 0.019938070251936876, 0.05280681600373599, 0.03646386231506064, 0.07302525528376141, 0.021328186586258874, 0.0192462200779588, 0.05034750139701271, 0.04540953995479692, 0.003036392360715376, 0.048343603078636437, 0.044871390001067234, 0.05588553951031739, 0.023812556098545754, 0.039896204346610654, 0.05050304405871899, 0.05885571601890749, 0.0893631834356535, 0.012322282944355282, 0.009972832049243152, 0.16307436320329868, 0.07222267093076822, 1.555359507760694, 11.545644671686235, 30.08382808777594, 38.001950094776774, 47.11972705779537, 38.64491678053333, 29.83969976825099, 51.144514237680745, 32.55921040811847, 12.753200261823594, 6.590598763958101, 0.5722720921039581, 0.2337778434758225, 1.0048911360002335, 1.1273621190940182, 5.555175408240288, 9.04530038756709, 10.023101183675951, 1.742517974588179, 1.8131043353388387, 6.082285085032064, 14.487410533812739, 23.49798421705923, 38.74618061127202, 50.34471942532448, 57.15176536190895, 57.34846438131025, 56.7758571717047, 53.67738477645382, 52.87120042308685, 53.97100948518323, 53.90619231808571, 55.615345508821555, 52.979351935848115, 51.11783819813883, 48.12453239194809, 44.772431696614916, 45.20799521476992, 45.69148617406046, 46.45433225939351, 49.96788163338938, 49.926390801706624, 51.805492447268584, 51.53686500364735, 51.078567427973596, 48.91675702987179, 44.56046681250296, 39.84629169587166, 42.76810838330177, 45.723830038501376, 49.694264934908965, 51.02951426659861, 51.2070603524485, 50.96108851894256, 53.126880122769265, 52.99096999629852, 54.48151773022067, 37.35611223405407, 44.33134155888712, 55.99146550701511, 47.487410037748276, 49.38663344229422, 40.01558903724917, 41.20690699546568, 38.61671101662421, 37.043562089243245, 34.8181269245763, 37.80522361878426, 43.01838305688674, 48.91472131975236, 50.720239300881666, 54.3454546313132, 51.06117563862955, 48.36302818790559, 40.48951333568942, 40.94936416995141, 45.67670668325117, 50.19724615158574, 50.5193276559153, 54.34490549948908, 52.78623011804397, 54.538458778012185, 54.02832708051128, 51.44418331884569, 51.37164692724905, 46.92227102095082, 47.849535019167014, 50.696563874521566, 51.78370760333154, 56.69452290381155, 56.60993306867538, 52.50143466457244, 40.91835783373925, 28.31456065177918, 17.25673821664626, 4.905908905690716, 2.1611526656535367, 1.5971469686877344, 3.970503537885605, 2.1671345253144545, 4.63294037888127, 2.9491889476776127, 2.8333682206369217, 1.4586777408276836, 0.445864336384881, 0.33085048378955934, 3.6852621599551174, 7.03677180313295, 25.12200040201987, 35.54695037103469, 35.98693832274407, 41.092279649549916, 43.443332641355454, 20.53846766871791, 9.161740849095008, 2.6863256721727313, 0.06927355417921659, 0.05050500141336553, 0.015419086125949699, 0.031070254758120548, 0.04564709232879743, 0.056683309000706485, 0.027319658735406496, 0.043843939690099615, 0.04591748689211184, 0.0369617045526543, 0.04774842937026293, 0.03931524156923256, 0.019798812704280983, 0.050482570358942595, 0.0205919511931678, 0.11168232007372765, 0.0687022211270467, 0.08508862732278724, 0.016185290878638625, 0.0450319045734021, 0.034735981645363, 0.04687715374353913, 0.0039458912262137266, 0.04804141203602476, 0.03792672252823268, 0.04693115528132166, 0.011079372319903587, 0.014078684109863977, 0.07051442509456989, 0.041661389667781136, 0.043345955726239956, 0.031408202954598015, 0.030357519112106775, 0.08291225579957809, 0.01868409731785857, 0.09545781123902529, 0.06525865590740597, 0.05072925067056091, 0.06708511677120002, 0.045770677632742354, 0.044142304123529506, 0.03355015797780887, 0.06844037993540687, 0.061894143300671736, 0.0446148080030276, 0.028985591620327007, 0.05738069799037711, 0.0268130773498166, 0.037554480405824806, 0.00923752745298008, 0.0897623995138753, 0.022160225104720845, 0.06958389639734261, 0.06228514691634525, 0.043452576013101686, 0.0554209646408356, 0.02515041566033277, 0.03617705431796851, 0.053582686870809526, 0.027439229738628192, 1.8185892797285512, 15.396119759928796, 35.751341158343905, 43.94794164165374, 53.52001144040016, 42.98305034637452, 38.329577830529985, 55.38607120513917, 38.11493788996051, 14.673979051651495, 5.287136810441171, 0.5905344637651598, 0.117248791540342, 0.4482043059843202, 0.8871576406301991, 5.155346643540168, 13.20587610044787, 7.191593147093251, 6.08797840533718, 5.850157747345587, 7.567246383236301, 14.80896055698395, 26.011580228805546, 41.43366313749745, 51.72223229562083, 57.125709056854255, 57.86285969518847, 58.699046258003484, 54.67276073271229, 54.449828901598536, 52.85028634532806, 54.43859131105485, 57.26552586401663, 56.47626261557303, 51.624839844242224, 50.83783980338804, 47.7076118992221, 46.99957701467699, 48.4763886082557, 48.480169773101814, 52.29060334544028, 51.57426480324038, 54.23780910430416, 54.65575333564512, 54.27230634996968, 51.640756822401485, 47.03749456713277, 42.69548177719117, 45.58030659152616, 47.689886708413404, 51.592770545713364, 52.573265029538064, 53.20233475777411, 53.96379624643634, 54.40104638376544, 52.413197025176025, 53.34961975774458, 39.70227795262491, 47.054525498420965, 56.96727668085406, 50.0098313823823, 52.17388929859285, 43.352439557352376, 42.62631470157255, 42.36803447046588, 39.63521326741865, 36.40693003131498, 38.43472088536909, 43.989436395706676, 52.16986886916622, 53.48885213175128, 56.70073201579433, 52.74980698862384, 49.54495206955941, 41.89044667828468, 43.87028263461205, 48.681414819532826, 51.0558412151952, 51.461249551465436, 54.4593837953383, 53.130069009719364, 54.753930261058194, 54.827004017368445, 53.62763735555834, 52.8850071660934, 48.48591996777443, 51.157383534216116, 53.51686177715179, 54.33462496726744, 57.086116652334894, 58.26468298512121, 53.73471413889239, 44.535748035677024, 29.473577891626668, 19.616734212444676, 8.163279458399742, 4.172057470967693, 3.146943820099677, 6.42936973802505, 7.7263347756478105, 7.391493801147708, 7.593295333846924, 2.6659310633136384, 1.3015083680229804, 0.19383417232142341, 0.620897653843126, 3.437447547912598, 10.266751954632422, 27.517868434229207, 33.89202394793111, 36.2793549414604, 46.68764660435338, 46.67550294629989, 27.72121979344276, 11.678413960241503, 3.625273430539716, 0.07804994937032461, 0.08825486871383845, 0.03478906387763639, 0.026915972534146522, 0.053388506564642155, 0.10013329180618448, 0.04126504258883577, 0.02868526600181095, 0.04133563376061859, 0.03406878801122789, 0.05255607925655861, 0.06627567593128451, 0.05262020847670013, 0.09111616114575057, 0.0076667814714563715, 0.07354198924956784, 0.05114304157154215, 0.07382215526435645, 0.10421669366018427, 0.011816158338690238, 0.06286090795671748, 0.018936634371658007, 0.035560395673758564, 0.05476736906735648, 0.05201639329654075, 0.047218285035341985, 0.06593446036980999, 0.07227325571640845, 0.21726549242533025, 0.1020841500271232, 0.10375952303049066, 0.12677556985328275, 0.10219316433874831, 0.20966634454746402, 0.11953162630238842, 0.19878550582835752, 0.15431448486783814, 0.17642657092261702, 0.22068046724363682, 0.08211965357223827, 0.14417183315080984, 0.16231042032520618, 0.25220084845298724, 0.11203442940548544, 0.0898630021800918, 0.19830849352142504, 0.16203994532265972, 0.1321087828687122, 0.12802823086179074, 0.19432080669268487, 0.19815058747847236, 0.14191322208892915, 0.2480921503757277, 0.2348663165203987, 0.10342142544686796, 0.19008510655933814, 0.06327367996075942, 0.18343459003634993, 0.1827210251001581, 0.24386372807766163, 2.101539012885863, 16.082083467514284, 40.047356313274754, 51.185338266434215, 60.99674717072518, 48.78349058089718, 42.64811915736045, 62.15000244878954, 43.99362548705071, 18.739015633060088, 7.762186709911593, 0.9940082135219729, 0.5726610809083909, 1.2496638274000538, 4.317936791527656, 11.9719337455688, 18.04797833965671, 13.13302101627473, 6.043706122905978, 3.791549566291994, 9.034143205611937, 16.343515323054408, 26.16507434075879, 43.35403596201251, 53.340351197027395, 60.72018084987518, 60.78189934453657, 58.66541585614605, 55.8837023089009, 55.11714958375501, 54.393174186829604, 54.837755234010764, 59.30442094802857, 59.136206180818625, 54.59781208345967, 53.60336180656187, 49.666255289508456, 48.56084900517618, 50.82081671684019, 50.22751115983533, 53.60075343039728, 53.294961529393355, 55.582774146910644, 56.26254050962387, 54.50674641516901, 54.42040328056582, 48.51054460771623, 43.90898858347247, 47.9665667779984, 49.957640324869466, 54.2163105933897, 54.13965571311213, 55.09083832463911, 55.10504514940324, 56.242034358363, 55.99922003284578, 54.44252937070785, 42.86524980298935, 48.94569627700314, 59.467187543069166, 52.776090791148526, 53.58376564518098, 44.09401070687079, 44.00691839956468, 42.75456836146694, 40.812038067848455, 39.02930121267996, 41.741486826250636, 47.85366135258829, 53.24735180024178, 55.08211497337588, 58.19179358020906, 56.4642797746966, 52.176548665569676, 44.26100953932732, 45.55868256476618, 49.84569588015157, 54.00971935641382, 53.559588155438824, 55.974320826991914, 54.441682138750636, 56.20560338420253, 56.6799081525495, 55.591011124272505, 56.11798155692316, 50.71662679795296, 53.5342731783467, 56.44682914979997, 56.17913130790957, 59.40639865013861, 61.018394731706195, 54.687944227649325, 44.862646210578184, 29.097359834178803, 20.689106295185706, 7.276805658494273, 3.9489731577134903, 6.120796386272677, 8.86542441383485, 13.35169707575152, 12.069249710729046, 11.082824603203806, 8.234435665991999, 3.307586451691966, 0.969178936173839, 0.8782636049774386, 5.29115233690508, 11.305673083951397, 35.297401335931596, 46.84975816357521, 47.80338441171954, 54.74514807424238, 54.02122759049939, 33.755376415867964, 13.815797798095213, 4.01321618787704, 0.26269804566137256, 0.20784500115100416, 0.19097988193313922, 0.1408023639552055, 0.16303490967519824, 0.19734760475975854, 0.15890840771457843, 0.14236861539463844, 0.1255165273323655, 0.11914646793757716, 0.16410239191064913, 0.12449131016769718, 0.1064171509877328, 0.27498566695759374, 0.13097086650950293, 0.2750877098691079, 0.20006534763641898, 0.21745554351758575, 0.17203772981320659, 0.16687039015514238, 0.17173521701366673, 0.10351953066645131, 0.11850021914729189, 0.12184970876983098, 0.12276278598414314, 0.1337082978458174, 0.13925282855428037, 0.1956277067262319], [0.045361954403380235, 0.05412563636538483, 0.02841807368602003, 0.0761080926824962, 0.060110280755907304, 0.05913956308617227, 0.04621250735175225, 0.035794776443752556, 0.07149737718845568, 0.021873869099504045, 0.0728972343307349, 0.011938096553597961, 0.04694665707046947, 0.0062821819277990975, 0.03516524752241469, 0.13284159193356193, 0.024287827470670306, 0.05700142318082433, 0.07628279137274913, 0.03867879104349883, 0.06075757908664885, 0.04047204199577532, 0.04834702749165797, 0.0745649541157388, 0.05405232175103119, 0.0675322593099648, 0.07108969583867059, 0.04486294005126242, 0.03407146931896287, 0.03482243849805767, 0.005274274998584823, 0.06296312706845422, 0.2618885358735438, 4.30031652412107, 17.48645967052829, 34.3365579266702, 45.610857932798325, 43.50371360778809, 34.686327442046135, 51.31791830062867, 38.61979792194982, 18.01118846862547, 7.727791445870554, 1.323725040401182, 0.15852079786840947, 0.08557447262348668, 0.3446136517149787, 1.0399177790649476, 14.461562114377177, 5.081258954540377, 5.293771499587644, 10.038174852248162, 1.9257546841136872, 7.62144422338855, 20.041346473078576, 31.988919358099665, 42.32638674397623, 53.591386810425796, 55.82954222156156, 58.69459436785791, 54.092163655065725, 52.238749611762266, 56.61761699184295, 54.85489599166378, 56.38148246272918, 51.883720197985255, 52.46965562143634, 51.3733257016828, 46.00798614563481, 45.11891426578645, 44.7435591297765, 45.49079810419391, 48.16331678821195, 49.5805868025749, 50.91702069005659, 50.192613832412235, 48.66589792313115, 45.81497807656565, 41.54920439566336, 39.46615126825149, 41.944014487728, 45.03908618803948, 49.11240093169674, 49.69079363730646, 52.64858630395705, 49.971117588781546, 53.410718517918745, 51.693618605213786, 58.039421266125096, 41.84643376258112, 44.707485091301706, 55.038211884037146, 49.73365337617936, 48.13846857317033, 39.09703270081551, 40.14976939847393, 37.997639409957394, 39.7792270106654, 38.585088868294996, 45.71565581906227, 49.27762685283538, 50.88478272961032, 53.00150548258136, 53.44262699927054, 52.09355131272347, 48.07838178450062, 43.69437217712403, 39.885617379219305, 40.60786301089872, 47.15247100399387, 49.74173345873433, 52.56295311835505, 51.1091854495387, 52.520434625687145, 53.45379006478095, 51.95895125789028, 50.90756777794131, 47.018675035045995, 50.474459663514175, 51.885877501580026, 55.9486214576229, 54.16142094519831, 53.941838818211714, 45.3440857702686, 35.006588966615745, 21.499205173984652, 12.853556063867385, 3.06109931680464, 1.8442843590051898, 1.4755713891598488, 5.371508463736504, 5.3045374251181086, 4.8291667526768105, 5.524722616518698, 2.129191722600691, 2.0414354315688534, 0.27993349178183463, 1.2379054196419255, 5.098080039024353, 16.221834574976278, 24.588846352792558, 30.543678922037927, 29.959165357774307, 49.87241114339521, 41.57514695198306, 15.329818956313597, 5.742957409351103, 0.8381904649638361, 0.09671409584341512, 0.07356697903765787, 0.09412269618722702, 0.12244223947486571, 0.04376375326706518, 0.015290542317914869, 0.08215057288086222, 0.05936124977926093, 0.04466654575099388, 0.024918283358396544, 0.03300777155785792, 0.011897407708719615, 0.025144537850733728, 0.042253127471814235, 0.03554667120859508, 0.06651384500606407, 0.0205673961599748, 0.02325673058118311, 0.01032090314003008, 0.04800247178683358, 0.03738689484194883, 0.06901904444901213, 0.04134897518181994, 0.026547591494877013, 0.05912984526085277, 0.021564365747655113, 0.04368460489316814, 0.05452780571255473, 0.01778707730643932, 0.024034112556687286, 0.04023577281904798, 0.023925155701656497, 0.030614989772138577, 0.04708023982182626, 0.031191622237524683, 0.071325084014285, 0.020261933921926448, 0.018874970039412863, 0.012077701713649497, 0.0586575060902584, 0.0428702189557014, 0.04907718206185007, 0.02887872427010969, 0.03575207853329278, 0.03472368976461791, 0.045535998088457895, 0.056334260190206195, 0.07997776366650097, 0.0812501744216969, 0.012950023050389945, 0.07044464980642642, 0.024300797339228374, 0.08264483748784951, 0.052497653561013366, 0.017738965069574696, 0.029774300205791672, 0.04272797558036062, 0.051003188390525124, 0.04628738861591105, 0.03785205193825307, 0.44311389687561226, 5.735929992891127, 23.120432553752778, 40.429104912665586, 52.07840704148816, 47.03353297325873, 39.026963480057255, 57.38130246439288, 43.466254972642474, 20.71868684984023, 8.546365095723061, 1.53851795340738, 0.17728028398367668, 0.2391843711056056, 1.0292906073793289, 3.299939791041036, 13.66877559692629, 10.028103186238198, 4.962346419211357, 5.915997182169269, 4.7677527320000435, 11.508290959942727, 20.912810833223407, 33.26077730424943, 44.237145839198945, 55.280943839780754, 58.08135532563733, 60.23559554930657, 56.18270458713655, 54.18460999765704, 57.10555591890889, 55.583005566750806, 58.228722695381414, 55.13577691970333, 55.32203066733576, 52.29413740096554, 48.29408468738679, 46.54666093087966, 46.833884331487845, 47.951940259625836, 50.001108031119074, 52.04410983670143, 53.42749057277557, 53.032492206942656, 50.90450440683673, 48.28173314371417, 44.711764397159705, 41.501920223236084, 43.773270653140166, 46.560918746456025, 50.62968354071341, 52.89708022148379, 54.91824619231686, 52.326630315473004, 54.649438319667695, 52.800766421902566, 57.79642651157995, 43.55803058993432, 47.15174536551199, 57.07583219774308, 51.98890247652608, 50.21386131163567, 41.19586944580078, 41.894616157777854, 39.502362589682306, 39.929438098784416, 40.069992311539195, 46.77650790060721, 51.25222252261255, 53.29960561567738, 54.16336251843361, 54.93323356874528, 53.70895593397079, 50.06463081605973, 44.61746669584706, 42.547161271495206, 43.941858045516476, 50.03458153816962, 52.01533532911732, 54.22296293320195, 51.68063163757325, 52.39276539894843, 55.91076666308988, 53.74668129028813, 52.71123832271945, 49.25757961888468, 52.201404725351644, 52.34209229869228, 57.840639468162294, 57.024001998286096, 57.14739976390716, 47.371864857212195, 38.988041800837365, 22.82643129748683, 13.616607093041944, 5.026520807896891, 5.3355589605146845, 7.172792246264796, 7.627027717328842, 5.973315267793595, 7.07655591349448, 4.5365471513040605, 2.394903619443217, 1.9398128265334715, 0.1689843638169189, 0.780683370126832, 5.995241317056841, 14.450492205158358, 26.366662594579882, 36.74487752299155, 35.91102084805889, 53.583491079268924, 46.39283733983194, 19.48834523077934, 7.469667619274509, 1.2955363142874934, 0.11045956713778358, 0.05862026272581951, 0.05673311620710358, 0.07446046738374619, 0.09338383502777546, 0.02205423492517683, 0.0228777009197661, 0.017831663623632445, 0.0661539368992371, 0.030764252428085576, 0.07545763806950662, 0.03189381842892016, 0.027001914192712115, 0.03278750978830842, 0.0102453620826465, 0.061893331247472, 0.07149566881238453, 0.05127543305617668, 0.061912414497665824, 0.03489769131485974, 0.07410323292377495, 0.04779779607610357, 0.03438415193569756, 0.013100792984327963, 0.05857910465208754, 0.01368828283082093, 0.03637899126436922, 0.05946525004542163, 0.15472760544188563, 0.17114122308069663, 0.096425426252667, 0.27972303210727634, 0.21394171271353, 0.09592094969364906, 0.152388570469714, 0.13588915098338358, 0.26081138560848854, 0.0736391828245213, 0.18246964100868474, 0.07802149686481684, 0.23844178675884203, 0.15984003191753743, 0.08792267000723271, 0.1882226395631029, 0.14348354911611927, 0.1733641497670643, 0.13740707759655293, 0.17570336860033775, 0.20618364755665103, 0.09172075773559271, 0.12195193554244696, 0.17328872075003965, 0.10217349120085278, 0.17867995726485408, 0.14046137822010826, 0.09943458131484448, 0.1218518767986567, 0.12757590190777857, 0.19045391660784522, 0.15390951546930498, 0.4178526685122521, 6.474330396421495, 25.665609528941495, 49.06765061040079, 58.969689799893295, 54.35580184382778, 46.60278220330515, 61.82373969785629, 51.529510559574256, 26.468212758341146, 10.198589986370457, 1.8859629741599484, 0.7058792357002536, 0.6830817461013795, 1.5788747298140682, 4.545369052117871, 21.3115668296814, 12.902150307932208, 13.778771604261092, 16.202337453442237, 4.534523208295146, 10.331292594632796, 21.829666822187363, 34.65096335257254, 45.23456927268736, 56.19028260630947, 59.665455510539395, 60.95325593025454, 56.0661199785048, 55.69463622185492, 57.43202655546127, 54.88472953919442, 59.60003037606517, 58.11792358275383, 57.3159126312502, 54.53754486576204, 51.206366092928, 48.65068304923273, 48.276073163555516, 51.11779505206693, 52.0588344143283, 54.60783373924994, 55.20206889798565, 52.84846244319793, 52.30316669710221, 49.075503195485766, 46.11971485999323, 43.66128698472054, 46.06675109555645, 49.09717429068781, 51.85443185990857, 55.28467401381462, 55.30291303511589, 54.23372591695478, 56.71369152684366, 56.33344127285866, 60.348555887899096, 47.50227582070136, 51.26588021555255, 58.238885556497884, 55.58881459697601, 50.74322439009144, 42.42248481319797, 44.307462169278054, 41.869387472829516, 42.38763063184677, 41.57479393866755, 49.59324036875079, 53.79560109107725, 55.20600695763865, 56.00976336386896, 55.63072119989703, 57.11883314194218, 50.70839374296127, 46.826090581955455, 44.80228485599641, 45.3588064255253, 51.870207632741625, 54.43840695965675, 54.96957825076196, 51.618509138784106, 53.02371786486719, 56.36442407484978, 57.727663440089074, 54.8771946660934, 50.720796277446134, 55.98323637439359, 54.66420996573664, 59.80153822129773, 59.02031583170737, 58.33837647591868, 50.01208282286122, 41.11032647471274, 25.007482882468935, 14.869607263995757, 4.607547934978239, 4.6704029363970605, 8.170524566404282, 14.372775343156631, 13.266130570442447, 11.394492214725865, 11.063420637961357, 6.271908638938782, 4.401630855375721, 1.1940588369484872, 1.921234275064161, 7.137941496987497, 21.83003160261339, 34.61297519745366, 43.219584957245864, 43.28773613898985, 62.543055319016986, 51.99994002619098, 24.853961313924483, 8.993772210613374, 1.4794692445185877, 0.1574000572004626, 0.12402389694245593, 0.3088292251190832, 0.21054555301464375, 0.11706015771074642, 0.11943958849916536, 0.1370588293479335, 0.14876416253466762, 0.16326453686962206, 0.1331590128041083, 0.15595038902134667, 0.096318940031192, 0.1770937262523559, 0.17916479899037271, 0.24515573536196064, 0.21004301465807423, 0.14340401386782048, 0.14011026480265204, 0.13990688378051405, 0.23023770521244696, 0.20171640500906976, 0.21443311215168048, 0.15525937771364567, 0.10882996022701265, 0.1819314489201192, 0.13147873683802544, 0.08830243511305702, 0.13783060164461214], [0.025030844657111074, 0.055592039735206676, 0.04679529724882976, 0.03143129859029526, 0.07988626978570416, 0.08573599460144198, 0.05738208843995968, 0.02186756802632684, 0.04303221590816975, 0.07680382309181076, 0.030442761715441465, 0.07362674155663099, 0.033457415373695475, 0.04882049281150103, 0.06425110856071115, 0.024162129679274176, 0.030390259794770714, 0.05354980254665979, 0.037596760798365846, 0.04740578505480963, 0.12602114178720983, 0.0796988923403044, 0.01860499490923699, 0.06852727728865801, 0.031137095929514018, 0.01777656466489838, 0.030688670193476063, 0.049233938972916336, 0.04588074148482373, 0.0708421268650601, 0.033708945021874485, 0.04442630823881877, 0.05621511053534285, 1.3907909513481203, 9.387429125847357, 23.699352818150675, 44.06855060208229, 41.5903147574394, 36.24406929939024, 41.071651904813706, 39.82123167284074, 18.929317266710346, 8.464883738948453, 2.2729029530479066, 0.3756647581054319, 0.2531781927832673, 1.0455249298003413, 1.552949088715738, 2.181763004872107, 6.563438311699898, 1.4217141823422526, 2.930459384956668, 3.739317814188619, 7.624708615964459, 13.066927117686118, 25.767557813275246, 37.615753527610536, 47.15112170865459, 54.77317733149375, 53.917414219148704, 56.198397990195986, 53.4871066770246, 53.10503644327964, 52.227751285799094, 55.213039767357614, 56.309220637044604, 51.530828475952156, 52.5778228236783, 48.769232765320815, 46.16686959420481, 45.14554715925648, 43.14719761571577, 44.18830448581327, 45.1143878506076, 46.00577392885762, 44.62714710543233, 47.20309703580795, 44.37767651773269, 41.57713559366042, 39.236582786806174, 40.09599762578165, 43.12292991145965, 46.51742750598539, 47.12678340173537, 48.98475131680889, 48.16800794293804, 50.55915540264499, 49.64910276474492, 55.949252959220644, 45.13716897656841, 45.22592044645741, 55.04406798270441, 49.892481911566954, 48.34473425342191, 40.608365074280776, 39.52954069260628, 41.2925519481782, 44.18889676370929, 47.53451378114762, 51.95725679397584, 51.14707554540327, 52.57637546908472, 50.884472862366714, 53.185943172824004, 53.52698149219636, 50.623858821007516, 46.98742551188315, 42.70118882579189, 41.27866675776821, 46.461400370444025, 50.74193000793458, 51.21676429625481, 53.449247960121404, 53.270270209158625, 53.76634805433212, 52.2106497518478, 51.491926408583126, 49.04624231400029, 51.08619251558858, 52.13763483109013, 56.79825390538862, 56.29603755089545, 51.37005444495909, 41.43580475161153, 29.295947474818078, 16.73457464864177, 8.478945436016206, 6.124655508225964, 7.439563428201984, 3.7805218225525277, 7.1479018657438225, 3.4408654032215, 7.0533516618513294, 5.209476822806943, 1.28323404539016, 0.6609557172463787, 0.18212696988015406, 1.6515569845514915, 8.687800861174061, 12.419127091284722, 19.091152298835016, 31.440938749620994, 39.84003551544682, 47.72171674236175, 25.759799365074407, 12.31517839816309, 2.3881529752285253, 0.07411742087213263, 0.032816644112068805, 0.06632783885804877, 0.10079692313147169, 0.03899967846190257, 0.014986472444668894, 0.014201269669067717, 0.11054503190661631, 0.05265202027775588, 0.034826471950979, 0.08119357584585106, 0.04733914306627647, 0.03113854575091072, 0.045033191601114894, 0.09505936890960702, 0.03631218073649272, 0.06653807636710905, 0.05538456780355304, 0.05028123862200207, 0.020838112480217413, 0.02323037907180767, 0.055430211322081674, 0.055318940881519556, 0.08732237883152501, 0.043322793057849335, 0.015289669935291093, 0.03864591821066795, 0.07309909849878281, 0.011713087911747638, 0.013799878858750867, 0.041569719586761734, 0.05315622104512108, 0.032079035506373456, 0.05505349907663561, 0.020536459614372542, 0.06822930739050911, 0.05626514373767761, 0.019465529983262383, 0.09636778579724413, 0.045911174327615774, 0.10704236300361734, 0.05155722700780438, 0.036767620007477464, 0.04790273096953188, 0.018248474826255155, 0.0459237611522117, 0.03772772735946121, 0.08075832299167111, 0.018632351909013047, 0.0742888713495866, 0.018527572148389394, 0.02640828032106642, 0.034575685408086546, 0.011635964882800416, 0.0436030050379134, 0.036360459597480875, 0.060434749635357055, 0.019885644940058553, 0.030061077559366826, 0.05497592501342297, 0.10866003426452799, 0.0432775785485583, 1.9905240473247345, 12.226993710763994, 32.51444635852691, 49.42722605120752, 49.00964660029258, 40.963559227605025, 47.87907046656455, 45.632215238386586, 23.668081721951886, 9.365469736437644, 2.5035133140702404, 0.2535230089579859, 0.06769171285052454, 0.6108441287952086, 1.021910974335286, 7.171731735429457, 8.670944475358533, 9.277819471974528, 7.125545826650436, 6.902668908719094, 8.012510903419988, 16.31057231656967, 26.459585505147135, 39.819474451003536, 50.0292000462932, 57.19708834925006, 54.96981751534247, 56.60106066734561, 56.19357347488404, 54.2939107648788, 53.47862259034188, 57.0660811854947, 58.76196892030778, 54.96314556367936, 54.717969971318404, 52.128982082490005, 47.94049478346302, 45.470319409524244, 45.91879537028652, 45.77495813369752, 47.024087905883796, 48.30565567939512, 46.211129619229226, 47.319877762948316, 46.468656755262806, 44.78205327064761, 41.410207363866995, 42.2816050437189, 45.78926694008612, 49.92564947374406, 50.16634179699806, 51.076163015057965, 49.53641699206445, 53.26903466255435, 52.37224355820687, 57.586599319211906, 46.76044579475157, 47.02399376899966, 55.9528301608178, 52.652504751759196, 50.2107391049785, 41.91827589465726, 41.89576933460851, 42.75397608357091, 44.238730476748565, 49.337882303422504, 54.66657515495054, 52.828415209247225, 57.34480873230965, 53.323767415938846, 55.080451888422814, 55.33681408051522, 52.11195507357198, 47.64208086075322, 45.14599430945612, 44.066707088101296, 49.9533845532325, 53.282053009156265, 52.87832344731977, 53.28440250888948, 52.99957567645658, 53.01943071426884, 53.996387220198116, 53.454594150666274, 50.02260261966337, 50.966477855559326, 55.64457893371583, 57.78434561144922, 57.335461724189024, 52.19650176263625, 43.94827896548856, 30.502925495947565, 20.150329528316377, 8.300268726964152, 4.163582209617862, 8.940565259225908, 6.104119939188804, 10.271347991881832, 7.937200415518976, 5.0405628931137825, 6.009427549377565, 2.1533248405302725, 0.5431198112426266, 0.346380771408158, 1.3998421882429433, 9.393665694421339, 17.964157289074315, 27.98395387588009, 35.97581055856521, 44.221883896858465, 52.8468660385378, 34.26583759246334, 15.054922584564457, 4.057932188433986, 0.1459516392600152, 0.04717332716550558, 0.056391218827376445, 0.11228181451799409, 0.0338423898774049, 0.04441138101561416, 0.018070849680131482, 0.03118500898351833, 0.030158763345811638, 0.02375551127648402, 0.09066406201811568, 0.045896312221884734, 0.07275773738060268, 0.013325668518401444, 0.05785628920421005, 0.0674818430636679, 0.02090065398313586, 0.031890957090522976, 0.04855388272253256, 0.05175979597674263, 0.03682577757224922, 0.05139142259835236, 0.05475620716629971, 0.06696523933280861, 0.05619993050312323, 0.03751634454895412, 0.03283200800539025, 0.061454853163130825, 0.04945233531837021, 0.12060728269599139, 0.1262628425273203, 0.18229788409606104, 0.14174350297018407, 0.10937388265325178, 0.08940978456408748, 0.1418282016510925, 0.14531981590534412, 0.1283954551082946, 0.2459784831491209, 0.12902699501043366, 0.19743858536164607, 0.13559650539630844, 0.09558750992460598, 0.14719029618126733, 0.10212377975544623, 0.1390308928826163, 0.20162668079137805, 0.11245271341214258, 0.09374084732224865, 0.1199408091845051, 0.1455434369704416, 0.287519171833992, 0.17102652439667335, 0.12102385066569814, 0.11821976201909205, 0.13749171499042742, 0.1499181207750113, 0.11407997609386522, 0.25625383661639306, 0.10688428076044207, 0.202517349933905, 0.16535160552349784, 2.01887579694871, 13.33883660454904, 34.38068459110875, 56.541781886931396, 55.32999700115573, 49.017832586842204, 55.191819744725386, 51.311242426595385, 27.524889476837654, 12.145829085380802, 3.181111831818858, 0.7533359311280713, 0.5221666323561822, 2.86380140050765, 5.905358243373133, 7.0836102962493905, 11.492458312742173, 10.354843485739924, 7.768548304034819, 5.8831424290134064, 9.461290297969695, 15.132784574262558, 28.524987966783588, 40.28073733852756, 50.97000014397406, 58.24213720137074, 55.761948016382036, 56.406507184428555, 58.096397615248165, 54.47467711664016, 52.337091276722575, 58.17209935957386, 62.3329653278474, 56.153973225624334, 56.47495254393547, 52.836797314305464, 50.405873098681056, 48.52396695844589, 46.545193964435214, 48.25121710377355, 48.59781342168009, 50.80951244600358, 48.109556782630186, 50.326770659415956, 47.84148239320325, 46.18200209832961, 44.60995927933724, 43.76872070374028, 47.604433951839326, 51.14059971224878, 52.27834201628163, 51.95940625283026, 52.60879778092908, 54.28605033505348, 55.060624307201756, 59.32437012272497, 50.03341659422844, 49.65856744397072, 57.009818707743, 55.28740790582473, 51.86726193274222, 44.32566588924777, 44.17128924400576, 45.53778417648808, 46.86054468154908, 52.799252387016054, 57.36024718130789, 56.090752463186945, 58.25421810150147, 53.297028618474165, 54.37851628949566, 57.10120993275797, 54.46565566524383, 50.32781008751162, 47.15527549866707, 44.97652046142086, 50.555040836334236, 56.93789812826342, 55.4510570341541, 53.660742159812685, 53.673113315336174, 55.27014947706654, 56.203265651579834, 55.91377904338222, 53.086299280966486, 54.13127360805389, 56.75860266531668, 59.831163883209236, 58.29967837179861, 53.002811631848736, 45.086405661798295, 32.19274728528915, 20.357565995185606, 9.659070910946015, 9.7852143356877, 13.914342445711936, 9.381737766727325, 10.588682447710346, 12.73808442777203, 18.535791750877134, 12.740263304402752, 5.102482899542778, 1.3276735188499575, 0.6410286058821987, 2.569412810187186, 11.570600751907596, 21.213570333296254, 30.978471694454072, 43.605471657168486, 52.74440588489656, 60.339695253679835, 39.42909663723361, 17.23055443456096, 3.859258991095328, 0.2548829988846856, 0.14700975990103138, 0.1504868797717556, 0.2812559127567276, 0.14800645561227876, 0.1116847638942061, 0.12045879187362811, 0.19503555140428006, 0.14445514778696722, 0.12149661118465087, 0.16691753520600258, 0.20884180411456094, 0.18742958534388773, 0.08287079512111603, 0.16196696778699277, 0.13038556001359417, 0.14236683807065412, 0.0837586910253571, 0.1690509828228143, 0.1629646594125417, 0.1360819599921665, 0.08472750879703991, 0.1782469184047753, 0.20060530172721033, 0.1501081718672668, 0.1845979405146453, 0.06517104609238525, 0.24631297245862024, 0.17546221944353274], [0.05242231647453962, 0.03966574977722861, 0.0679253543456716, 0.012442548214758356, 0.10127876179232713, 0.03775987240876402, 0.004323171094931182, 0.0046914946776063695, 0.029845375928186604, 0.061301363617061615, 0.046347082186970985, 0.09340541572460244, 0.019125398436200716, 0.07046403183091073, 0.09256267304261846, 0.00586194200291028, 0.13267821602282986, 0.02021322222126107, 0.02198150062242583, 0.019445703627782005, 0.03279845335430676, 0.01670379450755014, 0.024225465998414065, 0.022209557336604884, 0.017466477171007185, 0.02389713603582594, 0.013017751926165676, 0.008848121130628692, 0.0672273256725842, 0.06115794429675706, 0.041255202189448385, 0.100028935309139, 0.026018621189700022, 0.25157051130888924, 4.29227811674918, 13.636769056320192, 30.915709849326845, 43.22565286390243, 43.27295664818057, 39.257300746056345, 34.75085435375091, 23.651215530210926, 13.891470124644618, 4.913962021950753, 0.6311881758512989, 0.041471491793110486, 0.07055562530313769, 1.6716755566097077, 3.124794931181016, 7.012786509529238, 7.625813253464238, 4.90689096912261, 4.919121899912435, 4.53267430105517, 11.133108408220354, 18.504444168459987, 28.883776972370764, 40.302863428669596, 50.5267801592427, 56.99676898217971, 60.15660685877646, 50.82366827995547, 54.72518321006529, 52.93242077673636, 54.112183432425226, 56.14006842336347, 54.182891999521566, 51.93442075483261, 50.06418758823026, 52.224150549980905, 46.908405442391675, 45.4140490870322, 44.05155104975547, 43.90608210717478, 44.53690121250768, 43.700247887642156, 42.99517047020697, 41.210715616903, 42.402202237036924, 39.26560048134097, 40.216135901789514, 39.52568892509707, 42.72051826600106, 42.319993280595355, 42.98587053052841, 39.57060398594026, 48.04401789942096, 47.753240831436656, 55.8903193473816, 44.05639909928845, 43.26507268413421, 58.455510216374556, 49.582359713892785, 50.672531512475786, 41.180599658719956, 43.496582738814816, 43.56226282735025, 48.09682084668068, 51.21939620664043, 53.29815041634345, 53.04880926685949, 54.45834436724263, 53.7997038902775, 55.25110244750977, 51.06075986739128, 52.79089381617885, 48.78810721059, 45.2536908272774, 43.23852608280797, 45.416457422318004, 49.17954406430645, 50.87848732548376, 52.11171188662129, 50.319977114277506, 53.29106661581224, 54.035756049617646, 51.29821231288295, 50.48987457829137, 51.24375804778069, 55.698837080309474, 56.835363449588904, 53.0069968008226, 46.33465290069581, 35.10697418643583, 23.04562314864128, 9.73083753739634, 4.323410949399395, 1.6198861743173294, 7.357702091816933, 9.15328323841095, 10.951509533389922, 5.677392540439483, 4.733525149283871, 2.7908514440059666, 1.7305339079710746, 0.6878518998142212, 0.42604043238586, 2.4245393324282865, 8.340115104952167, 18.785836965807025, 11.136878786548492, 30.845346450805668, 31.942451038668235, 41.80391526991322, 18.479641060675345, 4.286566165185744, 0.5828938705305899, 0.04406430488151889, 0.06815685845550991, 0.01661164179113844, 0.09156862033470985, 0.016409827418805614, 0.013318581247491943, 0.029043176534375357, 0.11068222293209647, 0.014886867607973758, 0.06343816286854206, 0.02772044146343345, 0.045978019329448866, 0.06909507867549697, 0.02953365666701669, 0.06272164083296253, 0.021523064032437342, 0.0158132019738156, 0.03215761697520653, 0.05875525890939659, 0.021119833653492313, 0.02487886047381307, 0.055523087991581815, 0.032476811339297605, 0.055149807820036534, 0.04369515009344586, 0.03593220495648923, 0.023778848229877414, 0.09875472424732101, 0.013197629370786732, 0.12014505588599753, 0.047700882123242465, 0.020105720933286414, 0.022300480481898113, 0.04220139355428758, 0.050031578228358305, 0.026373496098864465, 0.018958036953042594, 0.012838635781419375, 0.1201401682450406, 0.03403961155263167, 0.01968293616007413, 0.04695896044253342, 0.07035956042067659, 0.032971880338605375, 0.041272105919497634, 0.01748697385342131, 0.021386206255204255, 0.01861149133483489, 0.024204936757263158, 0.01839421922340989, 0.018283825953521075, 0.029881931728713458, 0.026219820776473612, 0.03325005452479086, 0.02004859184155301, 0.023815405945624077, 0.033542516250764175, 0.049575974248469844, 0.023556473972876708, 0.020042574220907786, 0.0686473845534267, 0.13958808395170397, 0.3282399932222982, 6.613631411906212, 19.079138078997214, 39.13784104008829, 47.29576695349909, 47.06153477391889, 47.00225991587485, 41.30147141795005, 28.172912097746327, 15.923603042479485, 5.79508129627474, 0.6645076685855467, 0.03715601126332918, 0.3052318294442469, 2.862136109221366, 4.118504860708791, 7.39843100309372, 5.41274041898789, 4.9606686253701495, 6.479977138580815, 5.4148236878456615, 11.852362252050831, 21.946014127423688, 33.880672608652425, 42.50208539347495, 52.826006873961425, 56.86501264572144, 60.347473313731534, 52.72076183749784, 56.32823236526982, 52.82452421803629, 54.07678404162007, 56.4895280714958, 57.1876746608365, 54.44243523382372, 53.446914149868874, 52.77961307956327, 49.59311485290528, 46.600797483997965, 46.28876116967971, 45.94131369744578, 47.05132484436036, 45.32531330662389, 45.8245486597861, 42.434436275113015, 43.559638761704974, 41.962096614222375, 42.22012581363801, 40.845790063181234, 45.59363088300152, 44.29143928712414, 45.98931958598476, 42.92746643866263, 50.78469560992334, 50.269221644247736, 56.79949729673324, 46.56008328160932, 46.37362949309811, 58.498958310773304, 52.202440231077134, 51.10026205739668, 44.07210426945841, 44.51026439666749, 46.00559742219987, 49.537985940133375, 53.23225459744854, 55.157981457248816, 54.99296342172931, 55.75780599348007, 53.65550187326247, 56.462397037013886, 52.46754930865381, 53.77110981172132, 51.635124298834036, 46.272550013757524, 44.618525735793575, 47.63092956235332, 51.05883790600685, 53.09788596245551, 53.490801549726925, 51.51567243760633, 53.55084126995456, 55.00204370867822, 52.917951153170684, 52.58920946428853, 52.76638684734222, 57.397486163723855, 56.26344657713368, 55.22634444698211, 46.335535433984575, 37.78258762051983, 23.830277612132413, 13.353575891064061, 6.137985683256581, 3.9372545865274247, 6.588004606385385, 8.773076130497842, 12.893355373413334, 9.903785624811727, 5.437746509428948, 3.5753311168762947, 1.0074634753888654, 0.16352767274985391, 0.4636368101402637, 2.31639689014804, 9.24358404451801, 17.74552437566942, 15.225855554303816, 36.26603457235521, 41.60527467727661, 48.110235352669996, 24.343009841057565, 5.524772136442123, 1.1993564881624714, 0.12145770157897666, 0.002735156773386764, 0.029241825048361095, 0.05588915544532, 0.022798885794116125, 0.018300067017515822, 0.017494201892986894, 0.03434499718188759, 0.0019794711261056364, 0.07177346761548711, 0.03618571111151288, 0.0679522899970893, 0.05044543041637348, 0.07606069482262097, 0.048297254759217464, 0.050794440922477556, 0.05171294970017287, 0.06602966211616032, 0.06399432354937158, 0.05243378098032648, 0.01627346759872331, 0.019921574463707306, 0.005215740614315315, 0.02858162579697467, 0.04629010822804225, 0.12230446622256311, 0.008436901412243325, 0.012164613431049211, 0.009462069738806497, 0.18077960508244653, 0.10821555005086046, 0.22835374178905643, 0.12481635361309014, 0.15589804989435982, 0.13936496850463653, 0.13889835967171577, 0.18820109717067213, 0.11681256575449822, 0.2662746037446684, 0.11123358407208037, 0.16076563466941157, 0.15338397915324858, 0.15631792736389946, 0.178145028710846, 0.14197224150261573, 0.22234355219669882, 0.16081005244726138, 0.07967178814954336, 0.17456074846127342, 0.3009448933505243, 0.18794891634775748, 0.1443772213233094, 0.10552450533836119, 0.15213677269076148, 0.13098534557127184, 0.11565443233496721, 0.09843233146614606, 0.0997770302778771, 0.14826842703886572, 0.16874678462984102, 0.25463083338352943, 0.20741255983950632, 0.44869031216348376, 6.988203544770518, 22.355242852241766, 43.423112823117165, 57.672479614134765, 55.15221165072534, 52.191418370892926, 47.53313702921714, 34.545180951395345, 19.49180672245641, 6.755638862809827, 1.2645385582600872, 0.13850521867073354, 0.9265692483994269, 5.027627406581756, 7.64160079340781, 15.912403695044981, 14.620872120703421, 12.264449404131982, 9.074551463127136, 6.405046630290247, 12.981964657383582, 22.889334347940263, 33.45259689515637, 44.378468836507494, 53.05760714315599, 58.29871739110639, 61.665287710005245, 53.87110671689434, 58.84875136037027, 52.70093817864695, 54.82365823561146, 58.15855933773903, 59.107647403593994, 56.42527180333292, 54.60617849903723, 56.442236054328184, 50.75914921299104, 49.07590719961351, 47.629662636787664, 48.373787249288256, 49.19372735484954, 46.36962475315217, 47.257174753373675, 44.80841552057574, 46.22506187808129, 43.7291596781823, 42.86775227515928, 43.487255342545055, 46.50913561544111, 46.02656641314107, 46.49312842276789, 44.8631404292199, 51.87007034978559, 52.84360262655443, 58.217645922014796, 48.32423594690139, 49.26984487041351, 59.52527784532117, 55.15880123261483, 52.81651866051459, 46.958215621209916, 47.09263524701519, 47.581272355971805, 52.126256035220244, 55.228635111162745, 57.73523361452165, 57.11102762529927, 56.633122121134114, 55.361207300616854, 57.533847362764426, 53.64486832772532, 56.65150234776159, 55.65817386873307, 48.89426223693356, 46.60130739212037, 49.8935801752152, 54.7164833930231, 54.8687498031124, 55.13032482516382, 51.059528243157175, 54.623982137249364, 57.635644635846546, 55.68115503557267, 55.08628837523922, 56.14124513441517, 59.812536547260905, 58.19276240564162, 56.932865727332334, 47.39166890421222, 38.49314066671556, 27.61619637089391, 11.455740024966579, 6.111972524273781, 3.874479748549, 14.158127557846809, 17.042359113693237, 24.07472364364132, 16.911324493346676, 7.522817696294478, 7.965352246838232, 3.9135286596513565, 1.7879870702182095, 0.8369264811758073, 3.629916291083059, 11.72470675360772, 27.5318536450786, 19.157104992097427, 42.94755681868523, 48.58142968147032, 55.15205083354827, 29.562690219571515, 6.510350502306416, 1.3714311127701115, 0.16056902586452423, 0.1182896598813034, 0.11729471851140262, 0.1673878978697523, 0.21702722375912054, 0.1141053336041589, 0.12919810840920096, 0.21628966494914026, 0.05144665370725336, 0.20231652764543412, 0.17684666289677545, 0.2200011924029358, 0.15480203854460872, 0.17137636610817525, 0.2526946534072199, 0.11465335460079294, 0.11548796142902105, 0.11717436609849816, 0.09967611351561162, 0.14538462694373824, 0.20443538894816754, 0.09254706017072163, 0.08928372479614713, 0.1330887472196933, 0.1936899332870399, 0.2047068138997401, 0.10179750290849518, 0.1699397214237721, 0.09695805654290224], [0.0425186995116453, 0.04037581369160645, 0.025678552844892108, 0.04604014522966839, 0.003457243001321331, 0.01481621131871737, 0.04884146829886783, 0.03490265556460908, 0.04476208074559127, 0.04224156720503684, 0.03190935469202457, 0.057513572110403935, 0.09023597208602775, 0.049675542695988575, 0.009762933534089356, 0.04897115932356927, 0.036202174341005665, 0.07362229824667016, 0.043074484809391925, 0.006961682285632819, 0.04359011177814776, 0.0511722946389308, 0.04673959882629495, 0.018956217494222428, 0.08432826973618039, 0.038651028017122904, 0.07412094487658433, 0.070796720833788, 0.04639310108858251, 0.04836491947512954, 0.05709705393641226, 0.014500486375313374, 0.035204015401822907, 0.031536028555203835, 1.0180095030415444, 7.65831450300832, 20.97048144186697, 47.90557392181889, 37.55543139673049, 33.483532628705426, 35.12159678243822, 30.01746354564544, 15.982481741136121, 6.7169750794287655, 1.0608882408949638, 0.39754312605627123, 0.21318380660828085, 0.7994018398946332, 3.4778131496521736, 5.698867517132913, 5.714345680129144, 3.5227603249011503, 7.956684789349956, 2.266441583633423, 7.3851493673939865, 15.126576442872326, 26.07706419883236, 35.045687152493386, 44.511488176161244, 46.37872072958177, 55.00729576233895, 53.749344579635135, 50.300314272603686, 56.46736668002222, 53.960874080657966, 52.05586125773769, 57.38542095307381, 52.61432832287204, 51.928450907430346, 52.950432300567634, 51.09162499827724, 48.81416743801486, 45.025044102822584, 43.38865872352354, 42.13801491645075, 43.79239613010038, 44.706116184111565, 44.80421466212119, 44.96558881575062, 42.87858193920505, 43.67401115355953, 39.40995154842254, 39.67780628511983, 38.82515361232143, 43.06755388936689, 41.473498728967485, 49.99102753977622, 47.87667782075944, 56.54325669811618, 41.41583204269409, 42.79883230886152, 59.21412014192151, 48.53846403860277, 49.18023440145677, 39.94093848812965, 40.413223235837876, 43.661365432123986, 48.7392972361657, 50.55036537108883, 53.93067183033113, 53.55796429418749, 53.903615320882494, 52.81669124480217, 52.55583793886247, 51.40103332458004, 51.264515230732584, 46.93456765144102, 45.36818481260731, 44.336585767807506, 46.45397532370783, 48.381149538101695, 50.95512259391047, 52.757926294880534, 50.32590381560787, 50.15076606504379, 52.2279905503796, 51.556202288596864, 50.48912148321829, 52.46543122876076, 54.86664349032987, 56.23193817753946, 51.46208109394197, 43.84364581877186, 33.60345909672399, 17.767456308487926, 11.382515257404698, 1.8460310394725494, 3.198227829510166, 6.355222723176403, 2.49512606090115, 6.975568119556674, 7.1403929783451945, 2.9304478629942867, 3.6763515155161586, 0.532646899021441, 0.06539295878141158, 0.6206216783292833, 2.911002467716894, 10.85271385408217, 25.32347490710597, 29.343102209029663, 33.24432296137656, 39.782231546217396, 32.29263044172718, 11.461324499499414, 1.5631156270542454, 0.4543220696430053, 0.014006372113081237, 0.051311113601250034, 0.0579000749595223, 0.08962258846769411, 0.03809305170791284, 0.06857170272738704, 0.028378729325448795, 0.009588028957706787, 0.03783971026179291, 0.04889430921344508, 0.07977167835399028, 0.05849436383634325, 0.03712584655131063, 0.02416989398038676, 0.02302650200773872, 0.024508849582484653, 0.09468433056627551, 0.020481375977396965, 0.035798541765900395, 0.027007669428243276, 0.04869780383042751, 0.048617314802662986, 0.08146377505674478, 0.045677896724232746, 0.033874638348577485, 0.03801620542822826, 0.06513438878520843, 0.024964746591004155, 0.07279247180708955, 0.09634095739813582, 0.050723807615858894, 0.11573656462132932, 0.04564202082673869, 0.0755723367535299, 0.03566119752283539, 0.031462857582335996, 0.06908458327093432, 0.04060976545236284, 0.01265529370416076, 0.03324306780292142, 0.01520425113173382, 0.019866312711289334, 0.023542536918314236, 0.022553243531635212, 0.0770760830792208, 0.051417680261957074, 0.02405967691072053, 0.0652159771491443, 0.024391507895122615, 0.05598897287141412, 0.03114365555736567, 0.024406965634214784, 0.02427265509932993, 0.035219823626140435, 0.0759867290335317, 0.07894944384573929, 0.015382207610884742, 0.08487938572802851, 0.06298384974680601, 0.07658769436661275, 0.0448290023562168, 0.06446222324044475, 0.029004954492613196, 1.9338142967993215, 11.345986223989918, 27.5012356235135, 53.81172203248548, 44.84967885478851, 38.156448333494126, 39.149364963654556, 34.92828276849563, 18.89079566924803, 8.751016720648735, 1.377483329945995, 0.18756322172139922, 0.07516387399406203, 0.8295006989952057, 3.618883889529013, 3.6307551880036635, 9.09179812477481, 7.949064114401418, 7.09712972564082, 5.9010779569225935, 10.909436229736576, 15.919593399570836, 26.822247851279478, 37.798296713059955, 45.553018662237356, 50.20773456942651, 55.731282926374874, 55.56578243932417, 51.592358696845274, 56.33424143637381, 55.1182556921436, 51.745342900676114, 58.3600514934909, 55.32040288371425, 53.7576090135882, 54.617023852563676, 51.25021034671415, 50.42865422464187, 46.90723265371015, 44.546087403451246, 43.84160226391208, 45.26321434205579, 45.96632272966447, 46.692094572128795, 47.053831238900464, 46.19829562402541, 45.64167599524222, 41.101658036631925, 42.5591911808137, 41.84525705152943, 44.04386320421773, 43.54303144639538, 52.844300808445105, 49.85855340957642, 57.81513229493172, 44.524020148861794, 45.95521849970664, 60.83451794039819, 51.79393714474094, 51.74987716059531, 42.75261502112112, 42.73319144402781, 45.55725874439363, 51.01538196686776, 52.35967628417477, 57.053772787893976, 54.504832298524924, 55.69740149282641, 55.018247019860056, 53.76458298775458, 53.94922856361636, 54.98086683211788, 48.46424887257238, 49.47567124520579, 45.0855976535428, 49.27285332833567, 50.65899149064095, 53.5608393915238, 53.321045291039255, 51.23209684125839, 51.4924402390757, 54.027142524719245, 52.533735382941465, 52.105502774638516, 54.9242474186805, 56.46372672050231, 55.947554572936035, 52.6808830999559, 45.01240622612738, 35.94563968719975, 19.883414199275357, 12.14919840135882, 4.283288534610502, 5.400268262432468, 7.52358942262588, 8.446683941348907, 9.991782038442551, 8.065569295037179, 3.7924796583191043, 2.393215774528442, 0.9908387545616397, 0.23176088718877685, 0.9841283146412143, 2.790374630881894, 11.209725045388746, 23.57715137543217, 24.334645386665102, 37.35043264204456, 42.92252032987533, 40.14362696678408, 14.76531340229896, 2.6931743756417306, 0.5026045159226464, 0.08329825686110605, 0.04638124204751465, 0.06211528607133416, 0.01739930466658646, 0.012227726627081152, 0.027632092373565804, 0.07125566112658671, 0.053049393914519787, 0.045092226336559946, 0.05078628974696321, 0.04610728134491271, 0.039776529921519185, 0.01922267436560604, 0.028900230273364053, 0.032595363445580006, 0.0245452425893276, 0.0496698200191942, 0.02821174514059338, 0.004749248130998064, 0.0851839593040847, 0.02889945843978034, 0.012171312869947043, 0.045609167146105925, 0.01864533901454941, 0.07780678540227876, 0.018687659626706474, 0.02899052522655937, 0.028310061034355915, 0.026873092677804734, 0.24090040805599383, 0.2167506353749383, 0.2052835861761724, 0.09283220575701806, 0.17827515640566427, 0.07717894570481393, 0.11832794895575893, 0.16246163075970066, 0.20030174704809345, 0.206345506613293, 0.09773773486695944, 0.18841380914372785, 0.12194795954611995, 0.1347109537211157, 0.15814189078106036, 0.2044810018231792, 0.15479912741049645, 0.13270680642416402, 0.15569378021022967, 0.17352084539109663, 0.1793765763361608, 0.10841336161378892, 0.20179123647751349, 0.09275153669859133, 0.23795771112124767, 0.19051203203778114, 0.15876314212237636, 0.09938858539587068, 0.17257091168674732, 0.11279639577673328, 0.13250414552467485, 0.10436747508544116, 0.15872745774686337, 0.11073482252897755, 2.2405426636818917, 11.804541695502497, 34.04150547519807, 60.1554262253546, 48.688777108346265, 45.5665861406634, 48.324247714011904, 42.83532996331492, 22.65073068680302, 9.192027430380545, 2.099384896216854, 0.7883083351677465, 0.2994259861448119, 3.3766574292413654, 7.565084176678812, 12.24193205756526, 16.314398588672763, 12.551906185765421, 16.939216467642016, 4.502325942439418, 10.022047046692142, 17.295744226824855, 27.406569219404652, 37.78214047032018, 47.95564297706851, 51.05162466725996, 55.54529589991416, 57.634632664342085, 55.29009472939276, 58.500797902384114, 55.368032224716686, 50.49174947123374, 60.36446894368818, 56.42965309081539, 56.35559874196207, 56.329059985376176, 54.819178888874674, 51.94156731328657, 48.517487202921224, 46.48738999520579, 44.562863380678245, 48.223427111102694, 47.92855508865849, 48.69829277838431, 48.49036009080949, 47.69575457419119, 48.028622596494614, 42.853537605654815, 43.94585494072207, 43.24697486815914, 45.301237798506214, 45.82599993674986, 54.90643985809819, 52.235827445983894, 59.6347237402393, 46.83305278901131, 48.837482006319114, 62.349498118123705, 53.691819098687944, 52.30037396953952, 44.52929965911373, 44.1328735505381, 47.947766857762495, 52.60592268359277, 54.726563884365945, 57.54611261429326, 56.35418276632986, 56.96517821281188, 57.80628735019315, 56.04578248916134, 54.68878753723637, 55.40984861312374, 49.718728757673695, 50.48989026777206, 46.54312295298423, 50.8460924702306, 52.77133687849968, 55.83874017961564, 55.154470935944595, 50.55055756722727, 52.178705969164454, 54.71849164655132, 54.303320530922186, 54.42378828602453, 55.51098692801691, 58.45103086963777, 60.04723941126178, 55.747956921977384, 46.60560238745905, 37.19931940878592, 19.33250358027797, 15.800300394335101, 4.224852083190795, 7.685642636591389, 12.244875796379583, 12.400591931035443, 18.01264955151466, 13.481783463108926, 8.686428031613751, 6.383476536120138, 3.641981011436832, 0.7176049774692905, 1.5297342957027498, 4.1321189172806285, 15.821145830615876, 33.25390138933736, 42.471216340218824, 45.99332824830086, 54.36699236592939, 46.432410132500436, 18.840277502613684, 3.423290978516302, 0.7435215480865971, 0.23457365561156507, 0.209285706101406, 0.1939321243234219, 0.2560464719370488, 0.11401384738424133, 0.186094171517799, 0.1409301167774585, 0.12520976274484588, 0.16048933739864057, 0.12085805391712535, 0.1512518798511836, 0.1331897635733889, 0.1864467864675868, 0.1350249271960028, 0.1661043022308619, 0.18546878330169186, 0.22840693893451847, 0.09783820729822883, 0.15742803473145733, 0.17638687224638078, 0.19394320195480702, 0.15527512848136887, 0.21581829104933048, 0.08413621915444251, 0.12087424901584465, 0.13486810899790258, 0.14228505052385793, 0.1550049905575091, 0.18856457524722625], [0.035014002613963625, 0.04754809737806359, 0.09355924617979797, 0.04105167561060479, 0.023093655359961336, 0.07840667821226582, 0.027897300521632837, 0.039168692779757326, 0.033862718020475684, 0.059570238565004645, 0.04046834562154066, 0.03473314328960354, 0.029053120355632518, 0.022741473249850735, 0.011263718929952912, 0.022166022475087838, 0.03348126369077833, 0.008369850524280582, 0.07628626175104611, 0.0504138982374101, 0.033659528520318775, 0.06294242354230055, 0.03986777482374061, 0.019525158436848752, 0.09790494887819214, 0.028690647769479022, 0.0389798712586203, 0.07697725773698862, 0.07147680772768875, 0.01677669926486429, 0.05476409404148018, 0.06820074763269195, 0.019750857515440836, 0.0969128803380074, 0.2591745315059539, 4.55345796000573, 18.775729017872965, 39.59493444811913, 46.645759613283225, 41.110161735165505, 38.10147239315895, 32.034424735653786, 21.760450716941588, 9.483568379955909, 4.655858787798113, 0.3135372644230243, 0.16153386763988004, 0.32044388413909947, 3.3852716895841786, 2.7483140749316064, 4.254656212945139, 4.669314478674243, 1.3474590571657306, 4.410799885949781, 5.657663508769005, 8.227737238330226, 18.238801648539884, 23.826516059137163, 31.617625836403143, 37.972924555501635, 54.592583564019975, 46.409715298683416, 49.6954220341098, 56.542515370153616, 56.007602137904016, 54.3155465587493, 52.4556056914791, 54.881932889261556, 55.94442059916835, 54.296115136915645, 52.66990830821376, 50.46308086764429, 51.36390809089907, 45.794789637288744, 45.4978544481339, 43.260891437530525, 45.69015649057204, 46.28241869711107, 47.65646811454527, 45.11293265127367, 48.342996643435576, 42.723197244828754, 44.29744443585796, 40.451340829172445, 46.87413177182598, 47.2705461132911, 53.22041296189832, 47.86525195644748, 59.518747098984264, 46.64454367852981, 38.37242972466254, 60.817883168497396, 47.21893164419359, 51.71686257085493, 42.5768026228874, 41.15100929814, 42.45510324355095, 48.30731876434819, 49.38090678184263, 50.88182918487057, 50.05957488090762, 49.96488494257773, 49.32944136281168, 49.84253052742251, 48.21658649752217, 48.73426875760479, 46.319383113614975, 45.411217135767785, 43.7087280519547, 46.044930950287856, 48.76275693216632, 49.43640831978091, 53.5229100719575, 50.73084146745744, 50.701204038435414, 50.77998876571656, 52.35614222864951, 51.67417541626961, 51.5992699130889, 55.94387931208457, 56.54318609545308, 48.897113800048835, 36.22051546650548, 28.53049497450552, 12.647406093535885, 20.268002594670943, 15.804877800326194, 5.469549577082358, 2.341907740600648, 10.029438753281871, 8.536672919027268, 6.950482601119626, 3.628377005938561, 0.8515091793191049, 0.326712291327215, 0.3118923510755262, 1.187554689184312, 5.065752844656668, 14.165072114236894, 19.196218867455762, 27.899218913047548, 32.620620996721335, 34.75129758158038, 24.839766256270874, 9.6451102149102, 0.41410364871544225, 0.1938962714085656, 0.08632833378449564, 0.048210660010696425, 0.09264219296915878, 0.01571972967095433, 0.046446010951072945, 0.02129621390673903, 0.02573488137474464, 0.0653771773701714, 0.03800693193390485, 0.0052417516933694, 0.011040982696407986, 0.06933134019134507, 0.03412622928379044, 0.030273634399617874, 0.0403483685917191, 0.09314847749567802, 0.03256029577084607, 0.04555559844800061, 0.08324967922582742, 0.06720749165622458, 0.02528562251808903, 0.07121183323643862, 0.07767749274329794, 0.04070995060066062, 0.0658564113320843, 0.07207332208992974, 0.013116249765810228, 0.09027260641056685, 0.05188810038230112, 0.05885713711200703, 0.02488446440697918, 0.12270061794908778, 0.02330595173031813, 0.014281849669773253, 0.002222006902053592, 0.01751835473001965, 0.09947359051194885, 0.023505498482395085, 0.04605231836678521, 0.02879756874585104, 0.06729663364709386, 0.041507869478194945, 0.022794576549542048, 0.037799766437420924, 0.033903803315854845, 0.03904871958037538, 0.006801064770233127, 0.011289696013855358, 0.04098661559363527, 0.012941738767098757, 0.0038955918083252807, 0.09956174424939579, 0.0187018743881415, 0.0601982812757694, 0.017799378763283455, 0.04574328998944933, 0.08161577456180127, 0.011555850280508881, 0.04051749016188326, 0.1170904718099102, 0.044565713258400086, 0.022639727197407235, 0.08453797864457292, 0.572524594683801, 5.788758435556966, 23.3876734395181, 46.76772963616156, 50.87440806050455, 44.1627541665108, 43.20679018574376, 35.72619876553936, 23.345415784466653, 9.84830467931686, 4.368739329999493, 0.5264230781505185, 0.07506445110324891, 0.6595762686864023, 1.6365073404965864, 4.062356376840222, 5.712692891397785, 5.893638691594524, 5.258162261978273, 6.3952642390804915, 7.456055033591486, 10.871163702780201, 19.218994109861313, 29.24458795978177, 36.645963191986084, 43.13956468336044, 55.36615733177432, 51.5446077623675, 54.154756838275546, 58.33039837498819, 56.39453218829248, 54.62899884869976, 55.60506497659991, 56.8666051280114, 57.29213130089545, 56.48535466963246, 55.00576211560158, 52.64592301461005, 51.68403625488282, 47.72215604782105, 47.00773554463541, 44.183036742671845, 47.56533968833185, 49.31392446640999, 50.13035405066706, 47.987378874132716, 50.5206730288844, 45.06134956113754, 45.19720085205571, 42.372678556749904, 45.915288771352465, 51.23061418533326, 53.318566353090354, 52.01651596253919, 59.87009340716947, 46.64632835695821, 42.28029104971117, 60.63233544749599, 49.86549600478142, 53.99440642326109, 42.71311283111573, 42.36076631853658, 43.853086963776626, 49.837890363508656, 50.48828994074176, 54.77578570765834, 53.17863971956315, 52.2263902233493, 51.24079273593042, 52.83124323814146, 50.598739962424006, 51.039877168593875, 49.22819322155368, 49.41665526359312, 45.6282889458441, 48.54767768613754, 50.96156312573341, 54.19480816010506, 53.82124946963403, 51.58406288393083, 50.47372225792178, 53.231991798646995, 55.40746381205898, 54.95092345822243, 53.449624507657944, 57.78161956417946, 56.423012518113666, 50.37455297285511, 41.2421691033148, 30.01191339185161, 17.10083184703704, 19.399593760890347, 12.827319329784764, 5.378171590066725, 5.200362705415295, 4.628482605180433, 4.886220568610776, 4.233193493658497, 4.248143607570279, 1.2120600645580601, 0.3174168256021315, 0.21292047154518867, 1.400031932900029, 4.947083986574604, 17.19504129502081, 22.162385794424242, 31.520525601602372, 37.37990140914917, 43.453138566786244, 30.15651941299439, 11.248376081066748, 0.659931120612929, 0.21789411353247784, 0.09672397837763834, 0.016292382309573795, 0.033901505052082004, 0.04558922204699728, 0.07163446096162643, 0.02987018951605405, 0.04120693481977909, 0.05678748163665014, 0.035829874762003465, 0.04972148115836805, 0.02424604695049986, 0.04149942335882976, 0.014300923343868026, 0.06312845650339319, 0.05779624323270494, 0.11718384260612151, 0.021088291898429878, 0.019041647789098563, 0.03781300826719211, 0.03833190643138463, 0.0194071521682124, 0.08280357856663965, 0.01164549214374875, 0.020951526051747705, 0.06808227979608121, 0.08496447511377835, 0.02214208031223426, 0.06736112292855978, 0.02171873821005706, 0.24512680788193983, 0.11312651072418499, 0.21340047159502584, 0.19527322252190885, 0.13629441149532795, 0.18963349772797478, 0.12553218616953782, 0.18713306335191573, 0.14090515763288544, 0.14789741065713669, 0.11028853800868797, 0.12099490020303957, 0.17779129527268872, 0.12113808969696685, 0.13066947219833253, 0.19917913712561133, 0.13004422187805176, 0.13542329291662863, 0.13133167860008058, 0.07518818196389945, 0.16897458853500505, 0.10336167824965331, 0.2190983424624128, 0.13005154567860788, 0.15068079194714948, 0.09677864641191498, 0.132674339617933, 0.22147640195344725, 0.2533055932050751, 0.12759755155251873, 0.1409075478272092, 0.143978932211476, 0.10023793175576196, 0.1535154551628136, 0.7030288983256586, 7.217342526681962, 26.489987796352757, 52.25740832667197, 58.48610862608879, 54.4176576214452, 50.28178891827984, 46.065723434571304, 30.847244877969068, 14.261562420475869, 5.934075876589745, 1.0625076894798586, 0.45394423507875015, 0.8745092225651588, 6.889310296504729, 10.107107566248986, 13.200916263364977, 10.7114153715872, 5.3449030268576845, 7.9545725930121645, 8.867701349719878, 11.375421650948065, 24.81425319948504, 33.054158610682336, 39.1606221660491, 45.75949222810807, 59.34143243297454, 53.11833327816379, 57.21071074085852, 58.21426876129643, 56.961314678192146, 55.0114260181304, 52.96876938112321, 58.92959140962171, 59.796172418902, 58.7233571083315, 57.00016183237876, 53.7914433786946, 55.44420465346306, 49.69623788710564, 48.80730721258348, 45.84901248255084, 49.34489942366078, 51.66901357712285, 52.37168265927223, 48.8060716659792, 51.48979656157955, 46.914022276478434, 47.80352953941592, 43.097175628908225, 48.92051858286704, 53.810941480821185, 55.414728041618105, 54.3198964672704, 60.59340200116558, 49.13898283435453, 45.43195862923899, 62.05826997756959, 51.9523734431113, 54.98380076500678, 45.01213166021532, 44.24744598327145, 46.34096007193289, 51.39786404948081, 51.943587333925315, 55.88418476043209, 55.35468832139046, 54.63659255735336, 52.89791176396032, 54.573544379203554, 52.443917028365604, 52.68594687984836, 51.080583526242165, 51.70117309016567, 47.36695797212663, 50.897542199780865, 53.129300225165586, 55.58722211468605, 55.2117100838692, 52.25940873545986, 50.95555013225925, 52.70831615694108, 55.23162787960422, 56.59271386361892, 54.478877975094704, 60.24662133186095, 57.453693728293146, 52.35559309682539, 41.87581231517177, 34.15656820420296, 23.457960351820915, 28.749673097364365, 20.985317807043753, 9.598588943481445, 9.904097453240427, 21.881365622243575, 16.5876308948763, 17.619645710914366, 10.610925228365007, 4.6225171704446115, 1.8291214565115592, 0.5590291285226422, 2.4367187821095992, 7.034909167597371, 21.279962332017963, 29.78752636140393, 40.8069311418841, 48.17622923081922, 51.697917522922644, 34.2884147551752, 12.615385824634183, 1.0125944871575603, 0.32864436507225037, 0.2170822748373593, 0.1167317204958489, 0.16556900595465016, 0.20776621666887116, 0.2153298946758432, 0.1326062037579475, 0.2622969526677363, 0.1210158986730441, 0.21555184566926575, 0.08637728680285715, 0.10558538634570376, 0.19264132745804327, 0.09720911121656818, 0.19367729283628926, 0.13275490142405033, 0.13063895125542918, 0.16218888813689833, 0.08271512605490224, 0.1989179777522241, 0.17371704050850484, 0.12832921914636128, 0.15522137975260136, 0.21234746842134386, 0.12050081179627489, 0.18959453449614588, 0.19173527526999676, 0.08674327764780292, 0.1040437416503987, 0.17047232107049035], [0.01964839325556832, 0.03186302744002352, 0.0074417373980395505, 0.07188087314247124, 0.02445076479606571, 0.02431389744273357, 0.04842507269894404, 0.05864164423978618, 0.07055286738661028, 0.058714533675341844, 0.02428983462103192, 0.04215193108745641, 0.06681020611957197, 0.0841912166065266, 0.07669712236571698, 0.03288775622364014, 0.10514851704600359, 0.049861606300598195, 0.026846383022324696, 0.047120735229503725, 0.06498211348849921, 0.03408734649119358, 0.09222924859533388, 0.04487574904135639, 0.031365577822491046, 0.03324266943720079, 0.03571991433179186, 0.07237011221267524, 0.042097217087904294, 0.05100581607210541, 0.05440658378985621, 0.07437611344240366, 0.05442049211612152, 0.05759037625525267, 0.0697289168414089, 1.2622333077653762, 13.09423073645561, 33.42845470674577, 50.04156335707634, 44.76578720154301, 37.50706857250583, 40.5140712953383, 23.69003915017651, 20.448576750293856, 7.98313872468087, 0.9380109247661407, 0.12223685130236611, 0.4694503449624585, 1.3257799946492719, 1.0299788607705025, 6.081272132935063, 6.103836057647583, 4.772661087974425, 4.899618894823136, 3.89012314138874, 2.9378542784721624, 7.740072386880075, 16.62126325791882, 25.10082352545954, 31.09657818271268, 40.00336693179223, 50.26175737380982, 47.022734688174346, 54.755314857729026, 57.026728045555856, 53.275867431394516, 54.61687088012696, 53.24888152460898, 55.32503912525793, 55.048284530639656, 55.16897586084182, 51.70989251905873, 51.011392916402514, 50.99866874756352, 48.666760844569055, 46.18923887129753, 46.69662883204799, 47.40337325680641, 49.95249809757356, 47.68903555408601, 48.407221532637074, 44.23643981256793, 41.92500275950278, 40.27241014665173, 53.010691673524924, 50.4200210878926, 57.373842116325136, 49.84409947549143, 65.81895612901258, 58.987932743564734, 36.68082129570746, 60.20584437154955, 47.05197988017913, 51.71038673770044, 42.457044816786244, 41.12236815114176, 39.69303292612876, 42.76671986426077, 44.21301934026903, 48.69785739529518, 47.52721425025694, 47.91481894831504, 46.02370700528545, 46.60781852660641, 45.273102637260195, 46.456603311723285, 45.117157043949256, 45.13769065180133, 48.80464000086631, 48.50122897855697, 50.58795736682031, 52.29774598152407, 53.089864715453125, 52.050075761733524, 54.21534569032731, 55.36649857797931, 53.89144812860797, 53.11279096911031, 51.22238897508191, 52.85527167781707, 48.14099850193147, 40.67686926934027, 28.985940987063994, 19.8466125611336, 11.511477885707734, 13.822092221629235, 38.23400143654116, 19.785360828522716, 10.724057170652575, 2.270274474736183, 4.525133054102621, 2.577461268632643, 1.5029510038514293, 1.2653849321988322, 0.15075651207758536, 0.3998073142382407, 2.209754264162433, 9.18125169892465, 17.893742899740896, 22.001578423284716, 34.20679807662964, 42.65736810622677, 31.007644322610673, 17.06423809451442, 4.126564350820357, 0.238918783744016, 0.08292029972278303, 0.02503607320719429, 0.04976757666877201, 0.04963481746193382, 0.01995977160761193, 0.05930074032456164, 0.044877771513476494, 0.07733311323869614, 0.06035245647053085, 0.03726492215308451, 0.007803443896268765, 0.047200891009021195, 0.02183673298737455, 0.019965572808418545, 0.04459979651015132, 0.0437955076115266, 0.059987473031205524, 0.05924180135010712, 0.09981055428544361, 0.023121870378212585, 0.027275872980094245, 0.03956205977667724, 0.027123427228821863, 0.0738178881546182, 0.04341310716324276, 0.03938144305720925, 0.00791941907429587, 0.027031443051753506, 0.042254157860072396, 0.03841424173104667, 0.05656018717995575, 0.043540752733186375, 0.03579046719917848, 0.09148959836532032, 0.04388870986839456, 0.04897858271555555, 0.04477654065516207, 0.012022274294717899, 0.1288132564795594, 0.03681812052344603, 0.02381934555277469, 0.043668865616763794, 0.043149729965314756, 0.05481517295383158, 0.11069002170716563, 0.0521162873314273, 0.09301499433575139, 0.015721894826950328, 0.003586866275121969, 0.015507770379284217, 0.08630972550881487, 0.02981431297807684, 0.007487819501904832, 0.04176080106727539, 0.060943286460373676, 0.03064020555616627, 0.04149602192844595, 0.004271818306146851, 0.05648840474145067, 0.09942675955713758, 0.08447793267306783, 0.12205816895490694, 0.013280920365134315, 0.039666791656805624, 0.06799730532352002, 2.48239184098859, 16.677619872554658, 40.04741907119751, 53.34545812299175, 49.809880718108154, 43.77476899854599, 43.8977196139674, 28.043003197639223, 19.36928168419869, 9.919211326106902, 0.7985249450129848, 0.22332645832530915, 0.19795981626356804, 2.1751096844673157, 2.3519024300959805, 5.315003289330391, 7.522905949623355, 6.8109339860177815, 7.795329266978849, 5.561505133105863, 5.744996551544436, 11.335678235177072, 19.017331331006943, 29.289610885804702, 36.10919075627481, 45.56559770337997, 53.137321472167976, 51.157277630221465, 55.620734845438314, 56.34901308244275, 54.312090950627486, 54.63104632592971, 53.61419539297781, 55.649152417336744, 58.65079718251383, 56.17104730298443, 54.290039385518725, 54.21175672161964, 52.448659173903934, 51.05967729322372, 48.98244888551774, 49.2275538752156, 49.72663625594109, 51.142553052594586, 50.044783622987815, 50.6832552725269, 45.98654254790276, 44.06476943723617, 40.74800537478539, 52.432491164053644, 53.478591211380504, 58.31465790348669, 53.10938635180074, 63.77273013514858, 59.05094169801282, 39.720313010677216, 61.31495337332449, 50.46040581118677, 54.47561848548151, 44.75062331845684, 42.94345401948498, 41.98431684124855, 45.54604468807098, 46.14242538329094, 52.81973108168572, 50.519672824490456, 49.25552037454421, 48.07229034362301, 49.24580858599756, 48.387801877913944, 49.03067834915654, 46.358763710145034, 47.06740263969668, 50.32147153731316, 51.11052297776746, 52.715352889030214, 54.424392331031065, 54.64586504044072, 52.405411120383974, 54.30412069443734, 55.91381826708394, 53.97641451128068, 55.11782815379482, 54.32848253557759, 55.31169522193171, 52.184640515235166, 43.83203952543197, 31.705241780127253, 24.95382485851165, 15.201806522184803, 21.789162466602942, 35.397774788641165, 16.913426883759037, 6.979634636832822, 2.472374107568495, 1.7255896377948023, 2.0170723646879196, 1.6014609630069427, 0.7253249986998497, 0.06660495584289874, 0.2685316826307005, 2.394058838967354, 9.589722425706926, 18.648216685941144, 24.571383960785408, 35.47563775893181, 49.535934540533255, 38.408503763137325, 20.554821991151382, 5.166334182985368, 0.24084560212589082, 0.046178810974402774, 0.057096460218270945, 0.017294316147003445, 0.010685806140123356, 0.036740381751329675, 0.03529038032396667, 0.07126112333348683, 0.08343960774401504, 0.08528178873201532, 0.03437967798221977, 0.005671109979776967, 0.04833839751119095, 0.0035298968648402804, 0.007428827858905519, 0.04664933068617698, 0.014167012132313705, 0.07155959118878649, 0.049722327685524384, 0.10210706371693842, 0.07019069932040668, 0.04718969463400784, 0.03823179023100003, 0.040106621886333155, 0.031060358817358653, 0.009613130786155742, 0.022491194240208116, 0.024483421209057974, 0.039196091914369215, 0.0397150551960353, 0.058302696298567526, 0.10960652057321803, 0.10792908679333427, 0.14032124541699886, 0.25736800424994966, 0.2717107636553626, 0.12788105771065722, 0.21988935888774935, 0.14364433564966725, 0.39552950991257546, 0.1754677965636215, 0.15024205339291405, 0.1418570678440794, 0.21745321461029593, 0.1598588163934408, 0.22835836896011907, 0.20975113515892338, 0.34750449981900955, 0.1364020315269309, 0.16698390906376226, 0.15209877472971717, 0.2674010594285304, 0.15559665558318939, 0.23458209790049062, 0.13390590256500629, 0.13674525423876702, 0.15010834040661014, 0.13186371134173486, 0.15247196680115116, 0.20818189597658573, 0.2602225397863696, 0.2513953070006063, 0.27222943582361747, 0.12924123915933794, 0.23039124455423127, 0.2083313137653374, 2.7111385858828023, 19.03472900390625, 46.320591203628055, 59.91760115469656, 58.19159353933027, 50.888234415361964, 51.84103696577011, 34.79906028316867, 26.45542387039431, 10.740258520649327, 1.6959031791456285, 0.39144892726213704, 1.1501539089987356, 3.1001950512009286, 5.385327954446116, 15.150433278852894, 17.205845463660456, 11.045938634103345, 11.136407121535271, 6.626450207925613, 4.85608745005823, 10.033428784339659, 20.243795687152495, 30.6044227077115, 38.65391469770862, 46.75231079901419, 53.562984928008056, 52.25357224864345, 58.10913747356784, 56.017725775318766, 53.3157540136768, 54.09204990633073, 52.77883645026915, 55.999702484376975, 59.8465552637654, 59.470270526024606, 56.63970385828326, 54.87653570790445, 55.933222232326386, 53.50594974333241, 51.65622272799092, 50.77323052190965, 52.20937498154179, 52.94124610962407, 53.031119377382346, 52.79745201910696, 48.004821654289, 45.597306143852975, 44.28465750909621, 55.847432151917495, 55.05818459295458, 59.92276299384333, 54.76174362244145, 63.523942039858916, 60.46565432702342, 44.071002083439986, 61.457166748662154, 52.13525003002536, 54.67316081446987, 46.020937811943796, 45.16558654846684, 43.85746432888893, 46.54889668187788, 47.62057450509841, 54.092842225105535, 51.67239466021138, 51.592390075806655, 50.09775523216494, 51.53977540231521, 49.225082782007036, 50.44834844527706, 48.8110883774296, 49.61356216861356, 53.4249920229758, 52.0978972988744, 54.876355278876524, 57.40027889128655, 54.300414054624504, 52.204115083140714, 54.14234253668017, 56.67407558810327, 54.67916204083351, 57.22635707547588, 56.65240449290122, 58.478224662042436, 54.99491676207512, 45.88440402861565, 32.11866744102971, 25.657356862098943, 15.770075590379777, 20.346995207571215, 44.298334813887074, 29.789289466796387, 20.54156045759878, 12.195134259039357, 12.33946277249244, 10.691344603415459, 5.4339800534709815, 4.83197566001646, 0.8496169421461321, 0.8328177984203062, 2.9986865626227472, 12.524631984772222, 26.39225802113933, 33.720734042506066, 46.07003411939068, 58.753222034823516, 48.97961301188315, 25.241154163114487, 5.585203113094454, 0.4626457681578975, 0.19897287561287805, 0.13390498325949715, 0.16816733104567375, 0.12025733373218006, 0.1742007024586201, 0.10361696938954054, 0.1372216230318431, 0.22801566718807145, 0.1472472778010753, 0.09386147552680585, 0.12368389946078101, 0.13407983516733493, 0.10712338446248924, 0.15477940830732548, 0.1520927839221493, 0.1012063435008449, 0.14545008149598876, 0.10392789383448901, 0.25213640513679675, 0.1740147882411557, 0.1174700913590289, 0.13260381356362375, 0.1720039913010213, 0.0981616419589808, 0.09832892491812668, 0.09490667226453943, 0.11532665395568456, 0.08222722763856573, 0.14955894811259163, 0.15067083280413382], [0.03520413414545117, 0.07746253613262408, 0.09125041805448071, 0.027015841671175538, 0.049334196899566925, 0.08265619857176658, 0.04265112930067605, 0.041171664131745216, 0.09716343705452259, 0.05703344182561963, 0.07937472223514512, 0.01082295886120729, 0.027372582004435604, 0.05613652140563054, 0.022595184930269758, 0.020341526626819567, 0.03558489516557705, 0.05956278835994102, 0.03746310526865625, 0.06269081345488949, 0.0473193358629942, 0.05796603512980285, 0.05395544227212668, 0.05572886303848317, 0.018340589238270637, 0.10093164735383565, 0.032852765157698624, 0.02988404421616466, 0.04919835801927313, 0.036218917192590815, 0.016164361356547283, 0.09340801276266576, 0.03398698514267322, 0.010634195754274486, 0.07522516868888371, 0.34872444887315074, 6.103875281349306, 24.555992580229237, 45.51008047596101, 45.72555588137719, 41.78036535939863, 30.453323202748454, 29.11489086766397, 20.6137026509931, 9.382049595156024, 3.3200135009904064, 0.30512659960696775, 0.07956632082500766, 1.2261269097366643, 3.422293225603719, 1.8079747331719247, 2.4043577572991772, 5.634053291813021, 8.379713393026783, 3.9648852329100337, 3.5417480286090606, 4.755887071932516, 10.305714818739123, 16.721407251973307, 24.137136397823213, 36.21338851990239, 47.34429451727098, 40.99853500243157, 51.20414995378064, 55.65895049802719, 52.02115220408286, 53.42427815160444, 53.808411552060036, 54.12843381204913, 53.790564767776004, 56.05707107051727, 55.55658055889992, 53.17598819732667, 52.85057267835064, 52.28079349763932, 50.2618868120255, 49.281223666283395, 48.177786411777625, 48.42096944009104, 46.28838854451334, 48.297485382326194, 45.9495859761392, 41.65468869670745, 45.82707858854725, 53.50880522881785, 53.64981835888278, 55.667846433578006, 51.71937288776521, 53.28574003711824, 39.24796942741641, 37.60244492561587, 60.11997584373721, 50.02197896280597, 51.93315382926695, 46.04250300315119, 41.282953908366544, 39.11764475607103, 41.97293020063832, 40.077036888368674, 44.91761822854319, 42.01741380076255, 42.425340298683416, 41.51103188914638, 44.56005496363486, 42.157348279030096, 46.56184050344652, 47.53011288181428, 48.7491580747789, 48.67332296986734, 50.934302653035815, 49.495463525095296, 53.42764746758246, 49.38191483097692, 54.01118240048809, 51.33695748544509, 51.282110983325595, 54.64073458025533, 55.50378937875071, 51.541026638400176, 53.15450537589289, 39.96832839904293, 32.318704397447654, 23.860772079037083, 13.25766315383296, 6.595443381417183, 3.466543199554567, 9.747141849610115, 10.902683869484934, 6.859615012522667, 2.3686619823978794, 1.3385017120069074, 0.6940953938230392, 1.504449349257254, 0.19020374293529219, 0.12899279684549378, 0.8154439661772022, 4.528940694947397, 13.816624437609027, 24.40472049097861, 29.356442189985707, 37.97985146122594, 34.49629645193777, 26.410822599164902, 11.477742560448187, 1.677986650216964, 0.07301578643701731, 0.14127632723219935, 0.05028424551710487, 0.06039923762962703, 0.05061604968842961, 0.03682973441637812, 0.0183044298882446, 0.06723795897297322, 0.017149964114651084, 0.027842465863232652, 0.028066435498335672, 0.05996627537834068, 0.01616279470674213, 0.019948284119187344, 0.07541884337702105, 0.08188716120897763, 0.059251833271475575, 0.083831982657073, 0.04640783295936642, 0.13018556510008153, 0.04214112924772405, 0.03608202877184076, 0.0807394236025791, 0.06176584272555286, 0.023983797817040357, 0.08712728688072774, 0.05784300523960303, 0.06196009581007304, 0.10759081300948897, 0.0795085194911207, 0.05760236170082804, 0.04950670074791678, 0.08121669637940584, 0.06503722585377193, 0.014243925444691653, 0.029310704013633154, 0.03371440339833498, 0.07424631516539282, 0.04480730291576155, 0.04028417808454364, 0.05413704341457737, 0.011633555536278555, 0.020701147450674928, 0.031303626207274296, 0.02287363107766836, 0.004146300066607975, 0.0739062104314085, 0.050466210551319585, 0.06970167475482149, 0.03641509698824056, 0.053191579833266237, 0.05693867291894652, 0.03853852417500269, 0.01703768818368835, 0.03930885622638368, 0.028197942151417656, 0.03676993742344841, 0.03675455437792886, 0.06781523686743553, 0.055596540501761826, 0.043993920553475625, 0.029307549646604928, 0.023733924833997607, 0.014460214090743854, 0.05849270908642681, 0.05103766234711774, 0.46507025257714335, 9.028812704547759, 31.292622166295207, 52.48621979067403, 51.97747268984395, 44.411071577379786, 39.36668388305172, 34.248449725489465, 32.22779170159371, 12.528899523519701, 3.4274996817111973, 0.3452709245104944, 0.13295815987212042, 0.9586270862529356, 1.4275761645647789, 3.1696898898770733, 4.194959209811303, 6.056162099684439, 10.365129901516823, 6.412144159117053, 4.442223954585291, 7.829649025394072, 13.283276231058183, 23.906395127696378, 29.175897452139086, 40.134479999542236, 50.704569432043264, 47.70380327778478, 56.2551546865894, 57.041582061398415, 51.91903329664662, 54.024859705278956, 54.30778418817828, 54.82644704080398, 55.578047690853, 57.70444300866897, 56.54059340876918, 55.2669527453761, 54.398288957534305, 54.78021798595306, 51.9260347274042, 50.867838090465916, 51.21813320344495, 51.356596792897875, 49.48768154267342, 49.89984027801022, 48.0820962690538, 42.758816288363555, 47.25253458945982, 55.697119082174, 54.678832561739036, 58.04825836612333, 52.500203040338334, 53.852502915167044, 45.01953317273048, 39.693821322533395, 60.28538611627395, 51.29074412007486, 53.4446587870198, 47.18585037416028, 42.262126553443174, 40.796799659729004, 42.39535770108623, 42.88173552482359, 47.48836709607033, 44.641165656428186, 43.99323325003348, 43.98909514950168, 45.65527485262963, 45.20450430531656, 47.313280336318485, 50.043481396090606, 49.609973199905895, 50.4172440498106, 53.04884849056121, 52.98114838138704, 55.869844575082105, 53.061447143554695, 54.832016806448664, 53.81084734393705, 52.20181657421974, 55.01259880681192, 56.64109237732426, 55.058270885098366, 54.63509421194754, 46.07819657171927, 36.92331790924072, 26.505849861329605, 17.610339887680546, 8.320433632020029, 4.554397857958271, 12.093929263853259, 17.422730961153587, 8.738655371050681, 4.064398215663049, 0.13082129550316643, 0.4733329398497459, 0.7476427333970225, 0.229181484469483, 0.16211292285832668, 0.655648811690269, 4.281828432313858, 15.225757495049509, 25.92458990312392, 29.22710987829393, 43.96089330796273, 43.46412904800908, 33.34571230796076, 13.59394952174156, 2.0945861214591615, 0.0598897317033862, 0.04306628000772288, 0.08900210321430238, 0.053448920258350914, 0.04233796404854905, 0.03611756759064813, 0.014272148123822145, 0.07945291682957642, 0.05821236304097599, 0.06665233072013625, 0.01248430670990098, 0.05619806124858799, 0.018159514781267896, 0.02320404671463034, 0.049533176746579914, 0.07859162715894562, 0.034301740027243094, 0.033072915844499104, 0.05761087676810642, 0.08883286673094958, 0.0217816359438603, 0.03801421743006476, 0.0428925006229791, 0.02254787708572563, 0.05048255120674449, 0.02424148489691077, 0.03693867211921081, 0.030870401570873878, 0.07042568146942124, 0.11545330361132661, 0.020757698146025502, 0.18145884927963057, 0.2251435575946685, 0.1405440697506551, 0.09858778602774106, 0.0998297754314638, 0.11032183218987719, 0.19025769084692004, 0.15663236049154114, 0.20744635963872557, 0.16693241263349212, 0.18800739949989706, 0.11797010162544828, 0.06733923579656309, 0.16087213621264504, 0.06619502219461626, 0.1660756505424938, 0.19044388085603717, 0.17414456353552882, 0.11039922239198802, 0.2402097644704965, 0.19928982150891136, 0.19629225735702824, 0.10268872363432761, 0.26415566583314254, 0.1269586648671858, 0.14723636870903356, 0.1616236837881227, 0.191807410108947, 0.16167202393614477, 0.11203567812880201, 0.1449689016707482, 0.224828404344378, 0.1674038937856113, 0.16567101822264735, 0.16531323984024987, 0.7307443046762098, 10.636355915377218, 35.0896922234566, 58.65599824536232, 58.606254746837, 53.97762652366392, 43.51566506970314, 40.01070568638463, 29.2726231005884, 13.092346037587813, 4.88004969973718, 0.6225346305197286, 0.989352114979298, 2.715348024522105, 6.096637037492568, 8.831306657483502, 8.19669658137906, 14.270727038383486, 12.159176911077193, 7.856656995511825, 6.36300225411692, 6.264658137675255, 13.172428088803446, 22.73175116508238, 30.068515154623217, 40.697026329655806, 49.71579482478481, 49.30063939863636, 59.31109289969168, 57.77874446684315, 52.9975752676687, 53.99287277652372, 55.2899770582876, 53.54087452734671, 56.446993889347205, 58.11589571737475, 59.200089823815134, 58.26711485462805, 56.438274460454146, 56.43671727949574, 54.114984004728264, 53.7194404294414, 54.126664823101414, 52.56737362953925, 51.50266978048509, 52.657690125127, 50.509078502655036, 44.77005081792032, 50.45178836391818, 57.0568871498108, 57.28218417013846, 59.3505205646638, 51.96163415908814, 54.43951699041552, 50.28043962294056, 43.76890113276821, 63.12187948534566, 53.38639590048021, 54.97873698511432, 50.423147216919936, 44.881002902984626, 42.7790282618615, 44.66934396374611, 44.00523178039059, 48.450736307328754, 45.81999478801605, 45.25942141009916, 44.46431775246897, 47.23029082821262, 45.94895055217128, 50.760298467451534, 51.831254574560354, 52.590750955766254, 52.50674555378576, 55.40371402617424, 53.65236789949479, 57.07376903103244, 51.98012421208044, 54.17217216184063, 54.69381993816745, 54.617274884254705, 56.82066632855324, 57.25680643512357, 55.69045105288106, 56.8724141582366, 47.88684068187591, 41.393039149622766, 28.75108907299657, 22.21215674954076, 10.300948158387216, 5.335489338444126, 14.500908390168222, 16.13485405522008, 13.651420089506335, 10.975595828025572, 4.841230002141768, 4.031837395121975, 4.509490151559153, 0.5211924136646333, 0.34184681792413035, 1.4753019713586377, 5.419911001959155, 19.486213422590687, 35.04191383238762, 39.7884798819019, 49.21455906283472, 51.99248360049341, 40.10394827012093, 15.757551462419572, 2.5840356513377163, 0.21275171769722817, 0.3965539533284403, 0.20386010288230835, 0.21134996065689673, 0.10115356004286198, 0.17301041632890704, 0.16499856156447243, 0.2232896861049437, 0.18309012626207646, 0.16822463442240992, 0.10600518720645098, 0.30150894856741356, 0.07576102420928017, 0.19105174098043673, 0.20712598166879148, 0.20687156386913794, 0.15815244747265694, 0.2480774414875815, 0.10099282713546869, 0.2378646314384476, 0.13423588727751087, 0.11559678421866511, 0.2179259827901279, 0.1545590814203024, 0.19873298284026886, 0.24875470917792092, 0.13911101035773754, 0.14829258945199753, 0.22496035532845607, 0.24000733339738464, 0.15754608888058894], [0.031162438118049217, 0.037695670410269694, 0.006256710461926677, 0.0386154662156778, 0.03788887012389399, 0.024568717438547362, 0.020387625967663144, 0.05114835056085741, 0.04429528422112908, 0.031210211361007347, 0.018776657976089947, 0.029289527428186232, 0.06326102801868994, 0.041660297992489034, 0.02307711743689593, 0.06685198089408298, 0.026563497395404888, 0.07925336624705985, 0.02502088934453505, 0.05416508606304565, 0.06455432999158098, 0.03493347528180288, 0.021366236258238074, 0.1333524653267476, 0.06047832854692975, 0.033757266017698476, 0.029911533366107655, 0.04309077949954137, 0.03736182078418713, 0.10257512811691531, 0.06141959779685544, 0.011669880552818219, 0.09805978290856847, 0.033190330310213956, 0.06320518786988913, 0.0758344613977017, 1.768415055928692, 17.389179006699596, 35.859237717043975, 41.85978943301786, 35.229034423828125, 24.067304480460383, 20.337001008372155, 18.389289263756044, 18.68734428959508, 4.461599482643989, 0.9398262467115157, 0.16759356183390464, 1.2217926906962548, 1.3479243483274215, 2.6110056234944254, 5.5713390054241305, 5.960068933425411, 10.760531290884941, 6.289934871658203, 1.4961409112138133, 2.686401422946684, 5.3971122253325685, 12.605689725568219, 20.825247841496623, 23.807771052083663, 32.097284640035326, 37.77837499495476, 37.727309657681374, 53.50170181643579, 53.632944322401485, 53.29755029370708, 54.19489445224885, 56.70802370194466, 55.68165709895473, 54.682260713269635, 55.837539934342914, 56.80483564253777, 54.38253671892228, 53.024188549287864, 53.66299752266177, 52.00290926041142, 50.63317837253694, 48.39331673037622, 46.06538611073648, 47.39479111086938, 44.74142143803258, 42.34155454943257, 45.48002335333055, 54.0391214432255, 52.66460526374079, 55.74889436844857, 52.08333746079476, 51.350466128318544, 36.512249592811834, 40.68796565455776, 57.89717651182606, 49.082567384166104, 51.71981611559468, 47.27220919824416, 42.15216682803246, 39.48091506958008, 43.802727653134255, 41.85007372210103, 41.3328190003672, 39.84963747762865, 42.375212407881214, 46.569277317293235, 47.341803812211566, 48.55316508200861, 48.88423665877312, 49.249134755903675, 52.48212483621413, 49.42133857357887, 51.095037460327156, 52.55546139132593, 49.82104770598873, 51.030487014401345, 55.5926271407835, 50.60089334364861, 51.60847571588332, 56.039671436432876, 54.07133586945073, 54.904164883398245, 50.92196287647371, 39.431179415795114, 29.14850361885563, 14.32512442911825, 6.203089183376682, 4.26457098414821, 0.4451723751281539, 0.5337373179293449, 3.5391607351841468, 1.194389051487369, 0.5304593196318996, 0.3099613804971018, 0.16427217231642816, 0.14945662940942472, 0.1420683089283205, 0.24296539805589185, 0.9160223627282728, 6.200346956329962, 20.551229100073538, 21.589735438746793, 34.657800043782885, 33.39509887080039, 33.83135272610572, 20.452824677190474, 7.109439594130363, 0.4231115556772678, 0.05819318786023125, 0.009523091514805153, 0.048215631921325004, 0.05220125797354887, 0.014213398756128887, 0.10785251630530243, 0.06948774470196617, 0.022738661707168626, 0.005940580449532718, 0.05322669347327563, 0.03322599936396845, 0.030550601997322617, 0.06013250496659068, 0.05593516668605228, 0.0178804615091893, 0.03788480602745568, 0.02837649809436933, 0.04244072325227242, 0.07443558484796556, 0.04285799602286951, 0.025333564300390504, 0.0501205631712031, 0.07919398677204886, 0.03463839353512853, 0.08133390783182076, 0.021257583923157186, 0.06165463357202469, 0.06287371311637183, 0.042074521733147484, 0.0376236351627496, 0.021093275300377322, 0.007376755426277317, 0.014500576390644476, 0.058127633716550574, 0.047633937529979214, 0.012984829297619722, 0.02460941202908514, 0.019145939168670488, 0.0031380601285491143, 0.07528525296478503, 0.06628886030446138, 0.0019313253728943248, 0.03197687002079141, 0.0374936300419992, 0.05157758579439214, 0.1088074372420388, 0.03005071430497112, 0.032940018741834554, 0.020244507336868875, 0.01469481798384579, 0.04954535754457597, 0.045923772643530564, 0.017353318323711717, 0.03332033160052473, 0.12768344533058906, 0.028540747345335064, 0.06230094364934391, 0.037629438278776024, 0.042098408354626554, 0.054721043730575236, 0.02862671964741763, 0.02481721337854622, 0.052984333897550265, 0.03947883964546266, 0.0494105069177045, 0.025265401627327648, 0.05756212293260521, 2.755853605847205, 21.42975764889871, 43.06494159083213, 48.98330003984513, 41.41100752738215, 27.818655390893262, 25.155354276780162, 21.0419705606276, 18.06361879071882, 4.8158787431255465, 0.921009349967203, 0.056466000500105085, 1.0465832343024593, 1.3604184456409947, 1.4810613590863444, 2.9018915372510112, 4.458084548673322, 11.57058604301945, 7.784063239251414, 3.960474527651264, 7.061752888464159, 8.350888875222976, 13.689500420324265, 23.536870594947572, 29.078518729056086, 37.93255552168816, 41.123995934763265, 45.90297252901139, 57.512419454513065, 56.10762649966825, 54.66741061979725, 54.6520310063516, 59.83974995151643, 55.95737226547734, 55.3918331669223, 57.41640767743511, 58.289440985648866, 56.63672677932247, 54.85457043493948, 55.696962187367106, 54.69489858996484, 53.49147227502639, 50.96794874437394, 50.182505884478175, 49.74012136459351, 46.600762182666415, 45.306815408891254, 47.67892760615195, 55.3621918155301, 55.34725542991392, 58.79951776996736, 51.57671628459808, 51.35171736440351, 38.19751947156845, 43.35478513471542, 58.945947693240264, 53.676361037838845, 54.70443387185374, 48.78387497317407, 42.80610046079082, 40.486069494678134, 45.83054596377958, 43.365453981584125, 42.83025049394177, 42.47309123316119, 44.540866728751894, 47.61533029617802, 49.91138773579752, 48.46155028189383, 50.23746221296249, 50.92561460310414, 53.81782916284377, 52.46933398708221, 54.046809288763235, 55.85345691250217, 52.06765582484584, 52.11904279647335, 55.548653448781664, 52.85995891017299, 54.20740289072837, 56.58552415909306, 58.19532371336415, 57.18802767415201, 54.66390794323337, 43.09284925460816, 33.50583914787539, 19.067049334126136, 12.823405784945335, 6.661202407652333, 1.2384467067257052, 0.40596571120042957, 2.0368550838001314, 0.7194725159675844, 0.7027628513113146, 0.44010982097637275, 0.11711501726700414, 0.08776330073634464, 0.03395380204423301, 0.13346524879096017, 1.6955831382543811, 8.018899954134419, 22.260935345003684, 24.966262694328066, 36.42576917525261, 39.1393550749748, 41.85123866604221, 23.998939529542003, 8.38467715247985, 0.6551619474926303, 0.025568443027535276, 0.020291405324373516, 0.055404168163095756, 0.009739294933575776, 0.028744226043683388, 0.03421560493147662, 0.0127021734970772, 0.054687561857844555, 0.041965231629869634, 0.021884105949392243, 0.019501120513004642, 0.10012426729043646, 0.014780856361011825, 0.07675824852119531, 0.06253285378578209, 0.05663841241790403, 0.08549093073534389, 0.07548218352660056, 0.08351307557595354, 0.005515388723823332, 0.0314368182537897, 0.030227253521462123, 0.01303693859822928, 0.03790147993112764, 0.02084662563227598, 0.05055118119344116, 0.05346433011694782, 0.03021148551676062, 0.037056044450089816, 0.013893259231061226, 0.04269440560751865, 0.12813130033112344, 0.10379483968379999, 0.1861546464985417, 0.08966732034159285, 0.07144377401639378, 0.12157175674914353, 0.14012863559107627, 0.11179928637800679, 0.16769623293751673, 0.11480245829349565, 0.08527354562595006, 0.10408567730337383, 0.1313061831939605, 0.18867005023264116, 0.17017751511546875, 0.18861498383264388, 0.13102835374734095, 0.1488754444665486, 0.11672178433547098, 0.09109533121508938, 0.1734009679527052, 0.159183019591916, 0.20438015400882692, 0.21637632481513486, 0.17363084029526482, 0.2238915554217754, 0.12691574096078836, 0.14887823302659298, 0.14600857491454772, 0.15065066936996677, 0.17677414501386304, 0.10274297798112517, 0.27980711791784535, 0.20131181865449876, 0.12797953065244422, 0.12229308981688754, 3.5744051923674927, 25.492444730574086, 47.09350209082327, 56.4123240593941, 47.016141183914684, 35.277703192926225, 29.116061695160408, 26.637788588000884, 24.83505548969392, 5.7960015823764195, 1.4161612093448641, 0.31431554846705934, 2.7477870064397014, 4.060942117244967, 7.270846597609982, 14.505238686838458, 13.624531261382566, 19.452179016605502, 12.540068472585371, 4.3450771416387255, 5.327302371301959, 7.98610060445724, 16.485555133511944, 22.35155582427979, 28.546029521572976, 38.57060747761881, 43.10218449561827, 48.23309575357745, 60.194861735067065, 54.37767690227878, 53.86296387641661, 54.57371696349114, 58.082386908992646, 55.14831281477406, 55.832935071760616, 58.63437814097251, 61.195446598914366, 58.862864048250266, 57.082802249539284, 57.430959670774406, 56.75983428955079, 56.673965761738444, 53.07436350853213, 52.70236592138968, 51.488541403124415, 48.71079729449365, 46.3757279611403, 50.07207155227662, 57.35124141939225, 57.27595544630482, 59.27718793192218, 52.343116037307254, 51.2520303264741, 40.81254797597086, 46.261810564225726, 57.928065176933046, 55.423588675837365, 55.79699047150151, 51.941057405164166, 44.133987503667036, 42.667432908088934, 46.511834206119666, 46.66988611221314, 44.735169179977916, 44.382728530514626, 46.6799077680034, 50.18741669193391, 51.65029210429038, 51.38313162711359, 52.4597437920109, 53.5316804916628, 55.741198678170484, 54.74802317157869, 54.96842899630147, 57.46276224813154, 52.91086735263948, 51.94836085842502, 56.3603408875004, 54.15330163894161, 52.99508848497945, 57.315830261476584, 58.48712844233359, 57.48565712282735, 55.54625688060638, 43.58710319765153, 35.759189821058705, 21.87981040247025, 13.027280780576891, 7.958451817112585, 3.4635825455188756, 2.46064622075327, 9.35194932645367, 5.781778087539058, 1.4305223548604598, 1.4138082775377458, 0.7379014657870416, 0.6417308327171111, 0.4351278286307089, 0.8299921597203901, 2.032287974030741, 11.49981765977798, 27.144976546687467, 31.816646898946455, 45.4701272133858, 45.80419155859178, 53.11407358415666, 31.571530142138084, 9.56534783686361, 0.7497133158387677, 0.12006262482534494, 0.08799501935080176, 0.11469594142850369, 0.10441297304726417, 0.08845266495500842, 0.1525078963247999, 0.1530216348868224, 0.09336013992827746, 0.1823461782788077, 0.14683637888200823, 0.20852236077189448, 0.15476025610921845, 0.1224339350817665, 0.17357030402748816, 0.13066974798998526, 0.22596055972239665, 0.2165250378029962, 0.1672862226804418, 0.26219775960330044, 0.1799026489137642, 0.116374401766206, 0.15802038923626946, 0.18615135232046728, 0.09790487993027895, 0.20486392321125155, 0.13986888581946974, 0.13595325722088739, 0.17847755683525918, 0.18054677564049923, 0.11579541549567254, 0.07413369257964435], [0.043835010935342124, 0.03828510995052996, 0.057582719206449494, 0.05921164812940744, 0.03489525898570015, 0.04581149862778764, 0.028475409621492993, 0.029252527296663295, 0.002605844962207841, 0.05380955997914557, 0.04616846495698537, 0.023781378235247348, 0.043667004023107796, 0.0599709676668769, 0.0857482213647135, 0.05603276628760561, 0.1012918389131946, 0.03082986977402001, 0.055316163812794035, 0.039010078105474674, 0.07488491839819378, 0.009794196624669337, 0.05062260357062182, 0.07881707917418211, 0.03507974061874613, 0.043529069892341093, 0.04370840724497553, 0.04630489755542048, 0.01605972236457972, 0.02979268057031497, 0.046047859735065894, 0.019308148710537824, 0.05234225645601269, 0.025673602001681447, 0.05782242045707761, 0.061591883310146874, 0.15428283011480687, 10.067755406902684, 31.273455504448187, 42.8829671490577, 38.36529885568927, 34.02526294031451, 36.528547040877804, 42.800212983162176, 18.295917241804062, 5.424096170933017, 2.32480154883477, 0.2023302712627957, 0.4484456236804686, 0.38367469765005574, 1.0550018664329284, 1.13806908649783, 2.045677842632417, 8.40487539768219, 5.335348623414194, 3.9545032093601846, 5.864136584343449, 4.810909590413494, 7.120468318462373, 10.44449317839838, 15.829326914202785, 20.497931934172108, 29.848976173708518, 30.694674484191406, 46.12048364454701, 51.60649099657613, 54.24179815476941, 55.49308915292063, 55.15895420505155, 59.28142409170828, 54.431115273506414, 54.27152972067557, 55.6777229616719, 56.358669957806995, 53.93657107507029, 55.396096783299605, 52.90505047767393, 52.97112672559677, 52.015692264803, 46.7434815437563, 49.205470931145456, 45.83254637256746, 43.977955618212306, 45.82109305166429, 51.42290838303105, 51.81125833142189, 54.54943356975433, 54.465887085084, 52.811764747865745, 46.83880298368393, 35.943902077213416, 59.93575780622421, 54.026809123254594, 52.74882247371059, 51.537500427615264, 45.16198581264865, 42.34519058658231, 42.051522731781006, 39.745169070459184, 42.79094050007482, 43.35700911860312, 50.31991827872492, 50.593107438856556, 51.688860770194765, 50.4460342468754, 51.37277656985868, 50.426810710660874, 52.942320839051284, 53.79754266431255, 55.353519455079116, 52.07463764375257, 52.335090867934696, 52.254560685926876, 52.27309388499106, 54.19657322668261, 54.93770507074172, 50.45239240892472, 51.30302113871421, 49.9878857212682, 40.05893122765326, 30.250807308381606, 17.871142202808013, 8.238879711397233, 3.71888300103526, 1.3613136040587581, 0.44237759444982777, 0.8243472561720879, 0.8200363874916108, 0.8866843208670617, 0.11140518010623994, 0.06541582650595135, 0.05567882217526917, 0.012494154770167605, 0.08952888059279612, 0.45624157954608247, 2.6120604959226426, 10.53854278979763, 20.488233873921057, 28.031157639718828, 31.942205890532467, 40.71838363524407, 28.817010387297604, 16.71254857893913, 3.0547212977563185, 0.33071825701382856, 0.031099009868358413, 0.08249261581729497, 0.05007118497404361, 0.02414487354877976, 0.05257895464197763, 0.022425107665420062, 0.04845604946416232, 0.022655326662765398, 0.05326452672541623, 0.10184938238272745, 0.031691253290421544, 0.04071728206209598, 0.06762807392665456, 0.023500421234676917, 0.030926144043464335, 0.08193247530969881, 0.03311156881071868, 0.04334346594048604, 0.014970806904227264, 0.05801362834209877, 0.05306958033132458, 0.039605443335829243, 0.0829504146390865, 0.03503290200305562, 0.029050519487129587, 0.08130502631707538, 0.04371279692878166, 0.024053253263475436, 0.048332483312415506, 0.008129369779189509, 0.04712838844786729, 0.019320764263430913, 0.046884492865853736, 0.01747184553213658, 0.026140044210478667, 0.08512984285311354, 0.012774030629154897, 0.02718402669885226, 0.02545977154025628, 0.0295390633325423, 0.030001860878039754, 0.06025232494838777, 0.03695874362282696, 0.04938524133796173, 0.03069355017355373, 0.07077630459060592, 0.04752348680349608, 0.028278452246600104, 0.07736436962600678, 0.06966244339221908, 0.018679274794375225, 0.09591603907005442, 0.023874260650406924, 0.03768282311577951, 0.007322283702031259, 0.030670829920939384, 0.02879822949668573, 0.053840456305131804, 0.04840572514841634, 0.06145822778043728, 0.02051965356053364, 0.03626833369414653, 0.08161172961756107, 0.05271950113256613, 0.04529392579570413, 0.017098530886634704, 0.05140567183374398, 0.5513654300762761, 13.046150322883362, 36.19958569926601, 47.71501341173726, 41.85662015791863, 36.04348321114817, 30.13130053397148, 28.928584168034217, 22.145468611871046, 6.767052960011267, 2.2307624788053575, 0.15787136981323843, 0.11200015463175313, 0.9579976071273127, 0.8716615818200574, 1.1398765637028603, 4.121300039752837, 7.709701964932104, 9.303106011882905, 3.837286363686285, 7.326021598231408, 8.2395573008445, 7.698747275337097, 13.084811164486794, 19.35478852641198, 25.33917811609084, 33.31587483805995, 36.46072141585812, 49.30348703938146, 54.91885808206374, 56.82844046623477, 55.90846423179873, 56.96889661973523, 58.838800307243105, 56.52666114991712, 56.64820363444667, 58.06925873602591, 58.7395094287011, 55.05543108909361, 56.76460389168032, 57.03713409362301, 54.44122714381064, 54.64167594909669, 49.39920463869649, 51.723354093490116, 47.0035856769931, 45.40614158876481, 46.98893954676967, 52.91316193919028, 55.637934438643924, 56.15237289859403, 56.19884514039563, 52.38211616393059, 48.362612416667325, 40.14634909168367, 59.37236424415343, 55.368106749749955, 55.99544671274001, 52.80357091657577, 45.339041602227, 44.263884636663626, 44.102702679172644, 42.02153228944348, 44.17605492376512, 45.22476334725657, 51.72629587111935, 52.45129500665973, 53.1795104857414, 52.454793760853434, 54.77260074307842, 53.135187702794234, 56.49208937921832, 57.770664384288175, 58.33899228803573, 53.968279515543294, 54.63671022845853, 52.5575049461857, 53.540309706041896, 55.31325632526029, 56.42010996418615, 54.28676812879501, 54.76998059980331, 53.16689614326724, 44.32891361175045, 34.045490603293146, 22.04165327933527, 11.483160334248698, 5.23620875612382, 1.6760548829070985, 0.6127768766976173, 0.7806755253864873, 0.7373072879929697, 0.39771356529766516, 0.05078416002253371, 0.1269136725233928, 0.08507261608516978, 0.09261212401813076, 0.05436364839213991, 0.6799984567107693, 1.6257825998529312, 10.060624537929412, 25.44794740215425, 29.33772267833833, 35.01319423798592, 48.637951035653394, 38.045037331119666, 20.006825693192024, 4.396379782307533, 0.22587026859964096, 0.027216359439696518, 0.011924944739157875, 0.02708373046780546, 0.05056005249160433, 0.017184296344977715, 0.05689320177020085, 0.012505734189143105, 0.04199115604522728, 0.051313101599413546, 0.041770446114242084, 0.06529510637084324, 0.021808856963029793, 0.05198556974890733, 0.04606094068637298, 0.05167575996188868, 0.05432196554817981, 0.03307809842930686, 0.10264714038179767, 0.01835605463824205, 0.0470676108623945, 0.05180850001652876, 0.0053534760410266545, 0.11242803005922226, 0.10937706191813755, 0.014644334704855518, 0.058301960854160215, 0.03924849232839, 0.013642389376107003, 0.019245614868498618, 0.060462527983491464, 0.025995006529434074, 0.20617191108965105, 0.08447505984335177, 0.21999953765301938, 0.2666370552634039, 0.22398665757669559, 0.13401943679538467, 0.18430486591833253, 0.13240555000881996, 0.0819165253591153, 0.15879750882665958, 0.18465685267602244, 0.07280261481120702, 0.11100585677570875, 0.15711985288127778, 0.0947696267957649, 0.16843920032824242, 0.14073151614396803, 0.15768979165342548, 0.14080838540629034, 0.12890209203525899, 0.18239350719076974, 0.13514272087524015, 0.11171555296788294, 0.15305935705621398, 0.09365272422831866, 0.12664785533542597, 0.2815327462890456, 0.13190469704568386, 0.10727141563209797, 0.17089141713034722, 0.20120709443524962, 0.13773562206375983, 0.16837644240548535, 0.09154632717611329, 0.16265756540721463, 0.2469531308499075, 0.8627538178716937, 14.636960702557719, 42.1430237831608, 56.48918290292063, 50.347920079385084, 44.181769817106186, 46.07524694934968, 54.535101229144686, 24.799071665733095, 7.873715383391227, 3.5525127283988462, 0.4730095588151486, 0.9725337271248141, 1.4516376992387157, 3.7162023061706178, 4.358651484212568, 6.926140862126505, 18.29997689493241, 13.925256440716407, 8.7356488743136, 9.975407123565674, 7.434318728985326, 9.387588962431877, 16.22336429934348, 20.807142180781213, 24.259588872232747, 33.13745406366164, 39.161528233558904, 53.09820759680964, 56.532909485601614, 56.13288264120779, 54.26706606341947, 54.95195896394792, 57.78304730692218, 55.74893751452046, 54.28819587153774, 58.466990993868926, 60.755340976099816, 57.16362660931003, 59.80437801730249, 58.2897900765942, 56.62685417359876, 57.02700261146792, 51.343492154152166, 53.41759835520099, 50.37923628284086, 47.37720712538689, 49.47579283868113, 55.728827522647, 56.72428977104926, 57.37408138090565, 58.035483206472094, 51.64055678152269, 49.73314346805696, 44.648833890115064, 58.348190246089814, 56.97359169683149, 57.59589925889046, 54.87798698486821, 48.52777557988321, 45.920117209034586, 45.04994330867645, 42.90761924559071, 46.970539708291334, 47.31559845709032, 54.4710724584518, 55.077368905467374, 55.40850324015464, 54.60451541408416, 55.52680192455169, 54.78386971258349, 59.3116851775877, 58.524508630075765, 59.129040010513805, 51.33894220475228, 52.56978196482505, 51.91505993566206, 52.524804146059104, 52.751972136958955, 55.53429757395099, 53.94972278225807, 55.1239941197057, 53.86314038307437, 47.11927206285539, 35.14460540586902, 21.13356378770644, 11.19566530950608, 6.835070290873128, 3.3930730387087795, 2.0513638084934604, 1.5051344157226625, 5.768860251672807, 3.1191724586871366, 0.40208231958170093, 0.2784508358566992, 0.2928967413402373, 0.18168470732146697, 0.155396890496054, 1.0456993526989415, 3.929711133241654, 15.824971122126426, 30.264604245462728, 38.31029545876288, 43.403763771057136, 56.92363639031687, 46.07054794988325, 22.97142759446175, 5.0990204272731665, 0.4010919824002251, 0.09136271888330098, 0.20573275884793651, 0.18458390578387246, 0.1176468431649189, 0.14598283436029189, 0.195304969205491, 0.14226735389280704, 0.08551749866455795, 0.1703630309672125, 0.18883095934025704, 0.1519191424332319, 0.20936070610919308, 0.1167934825043044, 0.16650265262972924, 0.1853587577540067, 0.14168486660045965, 0.11081526942190625, 0.17878048332227817, 0.09902061804408029, 0.1414600197946833, 0.1313752843247306, 0.18841629126860251, 0.26777861820113275, 0.17165840903837837, 0.08135803960143559, 0.14283775231770932, 0.10684049117469019, 0.10724304739626185, 0.2019568800085014, 0.2044762061127732, 0.14330969312258307], [0.048843961915061365, 0.037532451547562115, 0.07903351433454983, 0.06207286012208751, 0.02893292307553272, 0.06513563750852501, 0.061915980636953354, 0.07274340387553939, 0.0519876956428972, 0.021244937726747126, 0.056651225238437616, 0.041799810264379754, 0.05069341307746307, 0.10004887657780802, 0.09981990821899907, 0.06755047688080419, 0.02223879699745486, 0.041084762948054465, 0.07479251287276707, 0.014791359426453711, 0.0519510957923147, 0.04010709686084621, 0.08419418136679357, 0.040803007300822966, 0.08178216885895499, 0.1419145704036759, 0.02724376240474803, 0.04444388229580176, 0.04911042644732422, 0.025755025656713594, 0.054091212204507286, 0.037294952799716306, 0.04585208979645564, 0.057791121934931126, 0.08055755432935492, 0.06194953528803684, 0.039457845005897746, 4.712139406511861, 23.875359373707926, 36.27497365397792, 45.6345372815286, 33.41157282552412, 38.04405281620641, 28.38004069943582, 18.62881664306887, 11.224137794586921, 3.0800710858837252, 0.5142398286731013, 0.27764010032819164, 0.9000691639319544, 0.5614316415402197, 0.8007519932523851, 2.463457334426142, 6.7037429636524575, 6.411495006853535, 3.0818126182402334, 6.594373554952684, 3.804482601342663, 1.397901227877986, 3.6597402778364, 7.461502715464562, 11.017759346192884, 18.981221991200602, 23.19966050886339, 27.08163811314491, 42.100748477443574, 48.837627134015484, 53.281660772139034, 51.66378505768315, 57.538609120153616, 54.219189613096184, 56.76056385040284, 54.97300247992239, 57.657613831181685, 57.988571659211196, 56.58212346415366, 56.25231489058464, 54.78016307277065, 54.22046830577236, 50.86086019392937, 46.799418464783706, 45.31740973072667, 45.76011980733564, 46.02813536121, 47.86230625644807, 52.09399061818277, 53.886086248582416, 54.609147733257664, 55.82497658268098, 49.495996967438735, 37.227301597595215, 53.42515284015287, 54.061286757069254, 53.60339710789343, 49.75823879241944, 47.1635320878798, 39.920165615697066, 42.448411680036976, 42.34416292559716, 42.50914173741495, 49.61123620310138, 52.61865861954228, 51.82601821038031, 52.22731590270997, 52.34346120588241, 52.43426407537153, 54.711066599815126, 55.54600584891535, 53.83630352635538, 54.59286205230221, 53.54203162654754, 52.06227433296942, 52.99925404210245, 54.16894405118881, 53.33425975614979, 52.940842105496316, 54.71147844868322, 45.814181835420676, 43.64704485862486, 29.633230124750447, 21.579070514248265, 9.896332140891783, 3.9089676785853604, 0.47491696452902216, 0.8521613959343204, 0.4096246084138271, 0.3992582130576334, 0.5910473136651901, 0.028374437317853014, 0.021240484840687246, 0.026007782960791263, 0.08378286876024739, 0.05249961474609952, 0.2178826528571306, 0.9576361362011203, 4.978843417859847, 17.748430851967104, 21.435105800628666, 28.430313717934396, 34.09769735028667, 40.91876968260735, 18.32356602914872, 10.070818778007261, 1.0607635830679247, 0.06174238894375102, 0.029640573812949083, 0.04812171337224784, 0.029177852876244054, 0.1499821044384472, 0.04953351765570622, 0.05500333563935372, 0.04864913426459797, 0.027148399779933597, 0.01466180629757864, 0.01591739759239699, 0.10632878274566705, 0.003262386143755829, 0.02136319488917868, 0.02321776160369477, 0.015711244289583016, 0.0347234905817576, 0.026412306113108516, 0.030615765436161912, 0.0175852820863046, 0.05305272256655078, 0.0005379081572285824, 0.026691545161508748, 0.040994874021459016, 0.020668971757855148, 0.05929769895550224, 0.045457378315228614, 0.011423276849992333, 0.040988132447725346, 0.03099610319270963, 0.06265186937525868, 0.04538870236325649, 0.01632394513205415, 0.01874503769701527, 0.058938216027473254, 0.04607281887963895, 0.02596784105163909, 0.0635545737590761, 0.032841335125868364, 0.055860005799801125, 0.027366085578837705, 0.020721264919566534, 0.04956526816972802, 0.02118609259806333, 0.015089375289878058, 0.00872708689947162, 0.06622037970490995, 0.030995844638035185, 0.036329777776113445, 0.07471722941244803, 0.034014863082237785, 0.03677742976334788, 0.054230356754194346, 0.028674561838288943, 0.05181280543066321, 0.06883756588062934, 0.03166587662792975, 0.04395266671875312, 0.05816963831743887, 0.031745676176562425, 0.07743933132939762, 0.022548955354479053, 0.04358619323841507, 0.0292867120550645, 0.04188416803616189, 0.02691831676319482, 0.03580762756868236, 0.05913759807064649, 0.06406165118659697, 6.420527735064107, 30.184662418980754, 43.21918879785846, 50.952627966480875, 33.73759631187686, 38.273970388597064, 37.015073914681714, 17.70816379977811, 12.015193566199272, 3.6457334939510595, 0.12302766854484236, 0.12163814592866168, 0.36675907791622225, 0.6638835214318768, 0.4791937269751103, 1.75029149939937, 6.768684666002951, 11.894646383100941, 3.8594940881575313, 1.3194947641703392, 4.109093133480319, 2.800186194719807, 5.262356256285022, 11.043186110834922, 13.173316505647476, 21.753176681457028, 27.57072433348625, 35.40348968198223, 45.49252394706973, 51.06768285074542, 55.66950167379072, 55.273942409023164, 61.31338834762574, 55.98186746720345, 57.37875684615105, 54.943208156093476, 58.01071343883392, 60.136316437875074, 58.96666957486061, 58.675582639632694, 57.242058323275664, 55.69622870414488, 52.72713176665768, 49.120057398273104, 47.53746732588738, 47.2600616178205, 47.62277887713525, 52.022509344162486, 54.80890227902321, 55.306097999695815, 56.79498264866491, 55.8843259657583, 50.75216347171415, 41.56578033201156, 55.16281381730111, 56.712918819919715, 55.41728542697046, 52.46249729587186, 48.642583354826904, 42.479378792547415, 43.478469233359064, 45.501172773299686, 44.63255213152978, 51.386155774516446, 54.14139332309846, 54.642323140175115, 54.186496657709924, 53.44991868542087, 54.423160706796956, 57.362557457339385, 57.379407959599654, 55.26596430809268, 55.41080959381596, 54.35745708404049, 53.6488103097485, 54.180785686739036, 54.952225685119636, 53.76837591971121, 56.00837484482796, 56.68062202392086, 49.50082540512086, 46.86085062642252, 34.190167227099025, 24.903634209786695, 10.67200339609577, 6.06976782121966, 1.5141686148220495, 0.7557584850057479, 0.5104984391120173, 0.4097416053616232, 0.1440725175123061, 0.06455733305624416, 0.09246745597450964, 0.06894942237845353, 0.06463377330932887, 0.20909467441660745, 0.16425568610429764, 0.4053631983697415, 3.1916429054352546, 18.762185073667958, 26.93668103987171, 31.684306129332516, 39.56062547622189, 49.29892532287106, 23.862582252871608, 11.15229272073315, 1.5358384842834167, 0.06700358203341884, 0.041123749162521095, 0.007819474286084335, 0.07015365130838848, 0.019795623863296165, 0.08745678129696077, 0.047360344549580935, 0.05286744037162393, 0.06717454221460127, 0.042924921463934645, 0.023178026538282152, 0.13542903857606073, 0.0379215169607872, 0.031020589277989445, 0.04209775334945129, 0.031863759053991206, 0.012172279098341543, 0.014419499390398063, 0.041050024691127965, 0.0964768460741447, 0.059251431075315324, 0.03794063468493762, 0.04203709067716714, 0.04058411299821831, 0.037731404581497756, 0.030332709354678952, 0.05698565709134264, 0.0083779432855907, 0.018551941405260758, 0.06468115584744562, 0.025253410436092846, 0.09532959876401771, 0.1603762474992583, 0.16214177372955507, 0.17874703592350408, 0.20947989406845263, 0.11349125284581416, 0.13763960060333053, 0.22065019144886927, 0.19098977978912093, 0.13083713820144055, 0.07566456607873402, 0.11981368455435, 0.15116757953599577, 0.18236251127335334, 0.14465549510092507, 0.19110366641994447, 0.1568546179201334, 0.1518383201572203, 0.15478729901294555, 0.1579752973010463, 0.11232488398109713, 0.18478195483405746, 0.13552740426553836, 0.19647774256525502, 0.08541985309772915, 0.188905009399018, 0.21114239679469218, 0.10761044784298829, 0.10067236489586293, 0.17540684660836575, 0.18750832386074529, 0.20708429116395213, 0.13605195998905167, 0.16836236170943708, 0.11082428627677503, 0.24077360518276694, 0.20099291157337928, 0.3231920560281123, 7.4359126821641, 32.719129362413966, 49.76850755753056, 60.52842009452082, 43.18067504513649, 50.5484002636325, 39.26237237068915, 25.888307979029996, 14.33940185654548, 4.418032736547532, 0.7666212440498414, 0.8462217630397889, 2.345482981012714, 1.5260405261670391, 3.0883617506873224, 7.78125286102295, 11.750588513189747, 15.486325448559178, 9.384016663797441, 11.965408882787152, 9.576187306834806, 1.845053879003371, 7.226223263048357, 10.890708873348853, 13.296062177227391, 21.361537825676706, 29.35153138252997, 36.0631735094132, 46.481063212117846, 50.23890172281573, 56.39133153423187, 53.26271572420674, 59.91138027560327, 55.90407902194608, 57.35186507624965, 55.127096714512, 58.95079966514342, 61.07806967150781, 62.57555215589462, 62.08296914254466, 59.39098373536141, 57.41765106877973, 55.01249290281727, 50.13689264174431, 49.98970570102815, 48.926209941987075, 51.02640774942214, 53.64850044250489, 57.04646148989278, 55.87712449412192, 57.870767193455855, 55.441772783956225, 51.30089913645099, 44.53544993554392, 55.26673701501662, 56.671286782910755, 56.7209400669221, 54.20791672122095, 50.19208431243897, 44.633995563753196, 45.47254731578212, 47.29268397054365, 46.54214628281132, 54.61772595682452, 56.01558416120468, 55.58287612853512, 56.52031867734848, 54.09568986585064, 56.707286296352265, 58.07970008542461, 58.926904586053666, 53.82606614020563, 54.73041957424533, 53.23980908240042, 54.42525525246897, 54.942474672871256, 55.07617650493499, 54.58693535097184, 55.41477511006018, 57.713111446749785, 50.67680297359344, 48.89124985664122, 34.932640521757065, 25.823953651612808, 11.18021999636004, 6.796200583058019, 3.055903402067, 2.4038179411042124, 1.285825506333382, 1.9007158663965042, 1.7059038747702877, 0.23344111718958427, 0.20919336186301327, 0.3167756712965427, 0.23258551955223086, 0.6544274836778641, 0.5974481927771723, 3.0296982920938924, 6.547565460205079, 22.564987674836193, 32.29674696922302, 41.049137500024614, 48.27196644198511, 58.20247419418828, 31.722749279391383, 13.077843073875675, 2.0750235453728707, 0.2034602662728679, 0.15087237521525354, 0.19691223699238994, 0.15967281024542548, 0.2253956924523077, 0.19299919777099164, 0.1587955936068489, 0.1426203672083155, 0.1991734067879377, 0.16890455277696734, 0.1187029260120565, 0.2967624210061566, 0.10175721434455726, 0.12758370834372698, 0.17360516102804294, 0.2132220803609779, 0.0772477710439313, 0.156210353297572, 0.1798005600369746, 0.23417161266890266, 0.15321980651107528, 0.11445236377297871, 0.16611236147582534, 0.10867558584939088, 0.07243085532419144, 0.19468430009099746, 0.11913988724230759, 0.09314270119272894, 0.15276458174470933, 0.14536377403043932, 0.16490254010404312, 0.17874928822200145], [0.0503537641657937, 0.021124914731650103, 0.04423933298957925, 0.0743383223250989, 0.019172451556510022, 0.023493721795779084, 0.0663875860552634, 0.05911536236864425, 0.019620955816560218, 0.11855579882619843, 0.009819296537898481, 0.04550763368306141, 0.08051277649018072, 0.026112319488498955, 0.04740557055019083, 0.04864753697127585, 0.05367285158905772, 0.08228098402821249, 0.03286395004139312, 0.05450115734410863, 0.017745494053909378, 0.04476829754909681, 0.04140562355338086, 0.12742889729598839, 0.01833691201623409, 0.06179285498576299, 0.07556620805013566, 0.022836332171854955, 0.06284855478893846, 0.03987832385445795, 0.008274812529224062, 0.06731976184152788, 0.06426302122793372, 0.122031478451625, 0.017945144227856112, 0.04712675285014895, 0.0682538758302408, 1.2407346742768441, 13.607565049202213, 38.12251590913342, 46.72216346186977, 40.87760440764889, 28.695303163220807, 23.15656738896524, 29.713597528396118, 15.188788175582888, 4.527902737740548, 1.1362400362568519, 0.10235503871714878, 0.546161302876088, 0.08868580083212546, 0.6983742093847645, 2.0199111801001335, 5.340231483982456, 10.663585009113437, 2.5024177470514855, 0.16531420511103448, 2.131270088495747, 1.8141991669131865, 0.7521891281489403, 2.419660394230197, 4.62171063307793, 6.9043006147107775, 13.345343816664911, 12.865045666694643, 21.065928397640107, 35.57761938341203, 43.88673305511475, 47.93685482394311, 50.498939175759595, 55.51019068687193, 56.70217152564757, 57.247141715018984, 56.379372227576475, 57.790625326095096, 57.48164453814107, 58.89330948552778, 55.53510950457666, 54.8286396457303, 49.00823062466037, 48.532137255514826, 49.79383037936304, 47.739018317191835, 46.799798934690415, 47.94488783805601, 51.269433882928666, 52.81227073361797, 54.317833300559755, 57.46799076757124, 49.95364735203405, 37.61742445730394, 54.092093052402625, 53.74360222970286, 55.811636601724935, 49.920668063625214, 47.050171667529696, 40.484590761123165, 41.52904341297765, 40.338721736784905, 46.20578342868436, 49.310853250565074, 54.79030239966608, 53.60525238898493, 57.66793750947522, 54.739735203404585, 55.484330500325854, 54.512994750853515, 54.465039853126775, 53.422983769447576, 54.06684083323325, 54.02074906133837, 53.67693762625418, 51.63073124424104, 54.455786981890284, 53.075038156201764, 50.364103778716064, 49.21735963513775, 42.05263668490995, 30.002703666687015, 19.78470383151885, 10.280728340148926, 2.8603889384577355, 0.703616211971929, 0.7147960701296407, 0.1951101530463465, 0.10825540194468153, 0.3442320479981361, 0.32482287335780363, 0.12248510975510844, 0.0630529508775761, 0.03872648767766453, 0.058356900849649986, 0.09763736202712021, 0.4283313723581453, 1.7609355863063567, 11.297332163779966, 22.53980213595975, 29.406511245235322, 35.94120740890503, 35.886443276559156, 35.37029074084374, 18.202696231103715, 4.281809801055539, 0.2524950721811864, 0.02339614517686348, 0.06885717773149092, 0.03847400041958017, 0.023148643235946377, 0.039775032219627214, 0.009773658765029284, 0.0447948731391901, 0.045256579009395455, 0.05475588540937151, 0.04427325919330601, 0.014405379432343669, 0.09152888335407743, 0.08520637503674916, 0.04619538911708421, 0.04685487973714068, 0.0025350294703046883, 0.029371150266078692, 0.02056447736498329, 0.038456008844678445, 0.06976700673300414, 0.019732124750472365, 0.018419438837877205, 0.03369925784007196, 0.061767068466231714, 0.025350692111157605, 0.04215148675646033, 0.077745299185476, 0.03160855792943509, 0.05147979467085773, 0.006473102529848656, 0.03855335946765639, 0.03243989739266615, 0.032253117495847326, 0.02050866785969946, 0.034886376196218115, 0.0912895038603775, 0.039660613157696305, 0.05020789336413146, 0.042407317988334164, 0.01886527519673109, 0.02874374149307128, 0.05613154949500196, 0.035943883966894886, 0.013198817764679271, 0.013521881830397875, 0.03303544648412255, 0.03500700440077532, 0.025346107074930787, 0.020786855452423616, 0.16337113034340645, 0.0442442282914154, 0.0853744930317325, 0.03905158091877257, 0.04910713609968943, 0.08309699790251833, 0.040876118901876674, 0.03756788311406009, 0.03623680534562276, 0.0534178477321421, 0.049348515082871726, 0.051138479517953056, 0.002497306103900736, 0.030861216176661755, 0.047377727084582856, 0.07795120829776411, 0.09374470840538703, 0.03464968567113242, 0.02751125157960961, 0.02155291464840693, 2.2417578629909025, 17.27301016930611, 43.10533808123681, 51.3066218745324, 43.74010309096306, 33.326410324342795, 24.882841725503248, 29.23443490459073, 16.90519382876735, 5.157523558985803, 1.2531030105967678, 0.021709673474693013, 0.07062015288899984, 0.1558881673601366, 0.6680365759999521, 0.9860819614221974, 3.4423583553683375, 4.572447134602455, 5.113810214304156, 0.9723468629583236, 1.1130933944256076, 1.6593888546189957, 1.8774911448840175, 4.693512070563532, 5.33759565122666, 9.419458220081946, 15.391345254836546, 17.2161397241777, 24.46454251966169, 37.62933277314709, 46.22174355291551, 50.27554058259534, 52.23419573999221, 56.88090608965967, 57.1870510039791, 58.05529117584229, 55.88425536309519, 58.09392259966943, 58.992282652085834, 60.97385229602937, 59.03534635420769, 57.45109711923907, 52.807720784218084, 50.970545353428015, 51.77436059521091, 49.25227265204153, 49.66573361427554, 50.19285309699274, 54.794236536948915, 55.0825660459457, 55.96963751700617, 58.24358455596432, 51.53550001882738, 42.7420913019488, 52.741950481168686, 54.53859213859805, 56.62925858651438, 52.55655965497417, 48.456639474438084, 42.923010626146876, 44.428294704806426, 42.97274235756167, 48.87400319499355, 51.791266010653594, 56.72212854508431, 56.64321830195766, 57.78580865552349, 57.6191157679404, 57.63860602532664, 56.75551575999106, 54.59193245057137, 53.37402082258656, 55.890488009299006, 54.91106825490152, 55.522071546123875, 53.890067454307314, 54.01211984695927, 55.4878096426687, 51.66500491480674, 52.44196368801979, 44.42335251838931, 35.78341437924293, 22.220560427634947, 14.378639286564244, 4.387181824253452, 1.349462407731241, 0.43541857431973185, 0.3798133080765125, 0.4893968536728813, 0.47826038673520094, 0.32653085106322843, 0.06459544593047711, 0.1343663980162913, 0.11702929202827717, 0.2694615601531921, 0.22545353209059085, 0.22052125885121285, 1.829760435127443, 10.6882429892017, 26.284855681080973, 33.33318033526021, 38.110721342025265, 42.12328249408353, 42.37484762745519, 20.920867381557343, 5.440632393283229, 0.3111155992073398, 0.03546850342724112, 0.05261788339984994, 0.04111205866079658, 0.04015044594604162, 0.04186255669581794, 0.02050189372722901, 0.027676077311738368, 0.04021832899701211, 0.01594205508984986, 0.017112902696094206, 0.04109077290782044, 0.08545159978131134, 0.002833052755205802, 0.04715249340440478, 0.031562169390400095, 0.025607639916181087, 0.04767784585935935, 0.025195720184954907, 0.04359562761120258, 0.021057066154636202, 0.04081049581028281, 0.014186467892760712, 0.024464460532932032, 0.03993344388060993, 0.009826049602951014, 0.04236665021087374, 0.09521210385907082, 0.05907904980103335, 0.042211670623791796, 0.019807603563212102, 0.030295623038264535, 0.03388036485581148, 0.17792379784007228, 0.13464042766680642, 0.16661270882093138, 0.176014538193422, 0.19846105227066627, 0.14016410546197047, 0.14426583213911903, 0.0742047548955006, 0.11576182254019285, 0.2218308095489779, 0.11376999393706361, 0.19795918807147012, 0.18410951349764101, 0.15547322349682932, 0.14008850790560246, 0.18960673061590042, 0.07876650971030036, 0.18816510635998943, 0.20939367853345411, 0.15468329491634525, 0.10905857618537643, 0.12382064615526508, 0.14271381461331922, 0.15287594028538273, 0.19512296203644047, 0.19939442315409261, 0.18438374233101645, 0.16812654452458506, 0.19446840119217673, 0.1376426343115107, 0.157204796710322, 0.14698783446463848, 0.18676327271086557, 0.1776497069025232, 0.07607792414003804, 0.1419416899161954, 0.22703414001772482, 2.5948028026088594, 19.732808912954024, 50.306590064879394, 60.22690357700471, 51.67471278098322, 39.37214382233159, 34.745814108079486, 41.156794794144176, 21.82625828250762, 6.212843627698961, 1.7845363650591144, 0.22581149433409015, 1.6804149650758313, 0.8255072358635165, 2.4360823775491407, 6.0926038603628845, 13.87853120603869, 17.69749887527958, 6.358943581581117, 1.850445667101491, 6.455087248356112, 3.524903164755914, 1.4584509788020965, 5.655724387015066, 7.3640847686798345, 10.086683784761737, 16.51426492198821, 18.479111540702082, 29.54329998262467, 39.16645473049533, 45.21371795285133, 50.65348448291902, 54.0162814817121, 54.29782529031077, 55.88196077654439, 57.01363517392067, 55.46159252043694, 57.51754991469845, 58.73992912230953, 63.097654927161436, 60.777824001927534, 59.80730018308086, 55.67394179682578, 53.854675908242505, 54.777652755860366, 51.31634543018957, 51.265762544447384, 51.7610716050671, 57.91018309131746, 56.08969342324042, 58.73572041911464, 58.768001525632805, 53.061486367256414, 47.93597229065434, 54.15832227276218, 56.763799805794996, 58.3516497765818, 54.15053244559996, 50.77628212590372, 45.94399659864364, 46.6469951598875, 44.98036046181956, 50.19278249432964, 54.20525735424411, 59.34095390381352, 55.70341448630057, 58.78409108807964, 57.8093546436679, 57.82904101956276, 57.948606629525464, 55.78496840692336, 53.20762603513656, 54.35122051546651, 54.551669320752545, 54.192376290598226, 51.7438288657896, 56.23391897447648, 56.240261447045114, 52.3700862546121, 53.576132712825654, 45.93895243060204, 35.358962935786096, 24.37951534025131, 12.89934189088883, 3.8894075539804276, 1.6918916976259601, 1.4334347147134043, 1.063336780475032, 1.1717143198174815, 1.96518455541903, 1.0185549576436321, 0.185097583058861, 0.29483187943696976, 0.3753831441844664, 0.6520380860855503, 0.3555885660311868, 1.1753628595221428, 3.5666366930930846, 14.315625429153444, 28.645604771952478, 41.92526555830433, 47.05624741892661, 50.333069985912694, 50.36338206260435, 25.970079591197354, 6.444680709992686, 0.4884477013782148, 0.07711377460509539, 0.2300499677057228, 0.08468012625892317, 0.14662233391596427, 0.23915685322736543, 0.140794396640793, 0.2285102841955039, 0.1936097392031262, 0.1367559335044315, 0.20706939841470412, 0.09794676195709937, 0.1417508114489817, 0.18794551491737368, 0.14646346260222698, 0.16515608456346298, 0.1372412195609462, 0.10353450002449174, 0.09277952955134454, 0.23656965173300237, 0.14717341160341618, 0.16568879146249066, 0.15391529177225408, 0.11334477683469174, 0.15243684933070215, 0.11346335958449111, 0.08390145917092601, 0.20604624202655208, 0.12504198182854923, 0.1880553719257155, 0.12489646342733216, 0.07454517372553388, 0.11572593898181954], [0.08040446697944596, 0.030319584353316217, 0.06686472859714301, 0.050523150036291736, 0.04597975068815774, 0.03524498961445305, 0.05299060049677088, 0.04029986373479328, 0.01854667838122095, 0.03795782186751885, 0.03024751463183953, 0.0958895324278743, 0.06057114775983557, 0.02226168387419274, 0.022110979057728283, 0.023007121898474234, 0.02343784717302169, 0.07555631019415394, 0.033060872942329414, 0.03694876915805283, 0.007733740907673154, 0.016572783896399122, 0.031365453333203355, 0.04414814554395215, 0.05686857587387485, 0.07151707330898893, 0.01652137556624028, 0.02113307356804369, 0.07640829955738399, 0.05640885034095376, 0.06830619963546915, 0.00933813011919659, 0.0021727931743953377, 0.033325269037196716, 0.023834994813847928, 0.0925208906072282, 0.07306761228509488, 0.12921280197558865, 6.290655607177365, 26.076160092507642, 41.357882945768296, 40.756897387966035, 29.451143895426107, 30.855929005530577, 21.600561180422385, 20.89995918735381, 10.277514938385258, 2.0339841539821317, 0.4269221076561559, 0.05873627525063292, 0.14943041388065587, 0.2437937842501748, 0.1404594323567806, 3.430969753573018, 7.9344792712119325, 5.324672422101421, 0.5209719642035423, 0.3195400842495503, 0.7202437520027162, 0.7215842220091051, 1.6427768814948298, 0.8583738174169295, 1.8091459283905647, 4.521108702305825, 8.987112026060782, 12.327378930584079, 25.813979064264608, 33.9660979086353, 41.066086061539195, 44.08655820354339, 50.29001805090135, 55.341254203550285, 58.0113253285808, 58.852599205509314, 58.69980719781692, 57.533812061432876, 57.21031065910094, 56.514031117962254, 53.754427971378455, 49.04247683863486, 47.80948761970767, 49.085630755270685, 50.73732514535227, 48.376109292430264, 50.467422931425034, 51.366845946158136, 54.26929004730717, 54.29733499403923, 57.535420233203524, 51.0677848323699, 36.76113182498563, 56.876991564227694, 55.539843805374645, 55.01046111506801, 51.92352441049392, 48.394360080842056, 42.91778602907735, 41.8647708431367, 41.09032238683393, 44.83637809753419, 50.84370766916583, 53.35913542778262, 54.81358558900895, 53.53000171722905, 50.616214121541674, 56.65790757825298, 57.562304158364576, 54.283296831192516, 53.31744455522107, 54.554022742855935, 53.544318368358, 53.31860557679207, 52.01577071220645, 53.11726247110675, 49.14741985259518, 45.417936155872965, 36.06688799396638, 27.57150684633563, 17.773004501096665, 9.927443400506052, 4.218956270525533, 1.0350488919404246, 0.7100063045659374, 0.15812614001333714, 0.1299845436287503, 0.18996657743569345, 0.12003921317837893, 0.18445911006100718, 0.05168507942148755, 0.11597555341018785, 0.028573581873769724, 0.07069535207964721, 0.15803097657138304, 1.2518404976975535, 5.166944111547163, 15.83628421829593, 21.47483744928914, 29.43531713178081, 38.64904703632478, 40.07242418104603, 25.761754666605306, 11.35529302781628, 1.6333655219885612, 0.07384884576763838, 0.02141598792326066, 0.038283995292600126, 0.024931128737666917, 0.02648153747882574, 0.03930393028103056, 0.039394405264888084, 0.05027546614949262, 0.0459384010924447, 0.045478928368538625, 0.016307543189595305, 0.04766669544962145, 0.015846862919598578, 0.02129239112799687, 0.04393186360116928, 0.11955204254557049, 0.018999401870514118, 0.020361123155922662, 0.023232374730850422, 0.04302587270015671, 0.056054461897621234, 0.07530519423345405, 0.06902937131423144, 0.013496333755733026, 0.026722920292447654, 0.04379587533373026, 0.037861984268191366, 0.010661010746844115, 0.01292022510296515, 0.009143306299172824, 0.08092182913735028, 0.03343282778176569, 0.022066873460707646, 0.029791385881722938, 0.03330574911688605, 0.029239030742657282, 0.02401833114544711, 0.030218305614506526, 0.03808093602739034, 0.03897982146290522, 0.010342676316448038, 0.021778211530838764, 0.0464018153387212, 0.03426973670420628, 0.035951380137233965, 0.05747227231040598, 0.018810360099098856, 0.02315602257787701, 0.051612894786822225, 0.08270403310175865, 0.033065258795695926, 0.03918635493685161, 0.07894032739944036, 0.007788617700909175, 0.05936101995288365, 0.04977324954985131, 0.057871377305878755, 0.04514896663867178, 0.018080762857871673, 0.07349999230955878, 0.03659004848750849, 0.07525683110279423, 0.06877656229921887, 0.05242536933491788, 0.01554835101424326, 0.029041496886601372, 0.07841673694671163, 0.06294642252126528, 0.06786650347132837, 0.11761828340710172, 0.21745689183233247, 8.361781297191497, 32.93367124372913, 47.69957104036885, 47.174702998130556, 31.532008340281827, 32.19418287277222, 23.686069711562126, 20.450679140706217, 9.746325016021729, 2.4068097289531463, 0.2614161354159155, 0.10562382863774415, 0.057650598426980365, 0.042094669845556064, 0.06877261694640883, 0.3831795903463518, 1.7838673557965987, 4.588772529555905, 1.1189619956477996, 0.2623220190646187, 0.9869915835799711, 1.0231827415766255, 2.007716408660335, 1.622984601605323, 2.811278657567117, 6.018202872045579, 9.993653009014746, 14.810905071996874, 28.81028744482225, 34.04302735482493, 41.60622389085832, 46.387361711071385, 52.8518670605075, 56.66590136866416, 56.97339557832288, 56.42986882117487, 58.8445818808771, 57.002503487371634, 59.23077060330299, 56.72021835081039, 56.79144074839931, 52.286673130527625, 50.63854809730284, 50.85240356383785, 53.16589986124347, 50.705016582242905, 50.43743641145768, 53.97798345934961, 56.27686892786334, 55.9111039869247, 57.83494026430192, 50.89583204638574, 41.14452169787499, 57.88575456988428, 57.46449201337753, 58.34705668111002, 53.75059189334993, 51.08083848030337, 44.089868683968824, 43.773023543819306, 42.96134787221109, 46.37562205714565, 54.12171479194395, 55.93823502140661, 57.39940420273812, 55.16207641170871, 51.218497983870975, 56.70359926839029, 57.29914057639338, 53.68187196793095, 55.138608870967744, 56.84114894559307, 55.15631837229575, 54.774895329629224, 53.91610022514097, 53.80578748641476, 52.856142443995324, 46.41390439002745, 38.5329919476663, 29.514427415786255, 21.293390566302886, 11.901752737260635, 4.665945162696223, 2.6265494861910423, 1.378718508828071, 0.6750313877578705, 0.24199405985493816, 0.2641303236446073, 0.14612031649918328, 0.12722229104368918, 0.020624931278308074, 0.0770602633635844, 0.04643160849809647, 0.18034238338230119, 0.1074372583459462, 1.0835677529534986, 6.3076429020973945, 16.182476532074713, 26.71133891228707, 34.48459602171375, 43.78865811132616, 47.885922847255586, 32.27632907129104, 13.561096729770785, 2.1381678215919004, 0.08912712110266571, 0.1168006607481549, 0.12984459468674275, 0.01783517613676527, 0.018617520446798975, 0.044199741565652435, 0.03527845616542524, 0.017180917897231637, 0.03835975372743222, 0.08114043232654372, 0.05085267126560212, 0.13217675018935435, 0.011220484757946144, 0.05084628975319286, 0.07142413918289446, 0.015175279601657344, 0.04094311712129463, 0.020987884584634055, 0.05977723935258485, 0.0771094998344779, 0.02958746668281815, 0.03043360313430669, 0.04889093459613862, 0.024360038918412985, 0.02735940720735779, 0.02033135489440493, 0.02419552153667375, 0.06863783909789017, 0.08594804773888282, 0.07287985945661223, 0.03827980862209394, 0.062291854016122326, 0.0407703872770071, 0.2627746544538006, 0.13153870620073813, 0.1653794451586662, 0.16226108426288252, 0.12298806179915706, 0.14570800797833552, 0.12310279878757655, 0.07490576365061345, 0.16649828592856086, 0.2372606170754279, 0.10637458714265978, 0.1590698530837413, 0.12647408361156143, 0.09201258360858887, 0.10153615967400613, 0.17257777583454886, 0.1959950458859244, 0.1686769633764221, 0.1001354981394064, 0.19628127165619405, 0.12971627495942578, 0.1415873589294572, 0.13711135233602217, 0.11445949605155377, 0.11008767741582087, 0.16518931745761828, 0.10073382813002794, 0.13794684782624245, 0.16552224394775208, 0.1880046875486451, 0.15489999054660722, 0.1519665019887109, 0.14958104208832787, 0.19332991792790352, 0.20309792200644172, 0.29709346291999666, 0.2496961239845522, 0.35795924043463123, 10.323238007483944, 37.46398918090328, 53.09187689135152, 56.454768027028734, 40.38375839110344, 39.377427254953695, 32.31861810530386, 29.481006860733036, 13.41517867580537, 3.994768055215959, 0.9046552113948331, 0.45950352064063477, 0.6394682992850581, 1.0302939986990345, 1.485327059222806, 7.523472732113254, 15.748108356229721, 13.870665873250655, 2.358088007857723, 1.2017943637986337, 3.5759768370659124, 1.6222773492336275, 3.6153272803752654, 2.172981308352563, 3.7785795138728235, 7.2950010434273755, 12.500817314271005, 18.401672186390048, 30.996948019150768, 36.38228970189249, 44.184287978756814, 46.82963640459123, 54.68458667878182, 55.93980789184571, 57.30753444856214, 59.172150781077725, 58.54524227880663, 58.0485172425547, 61.707931718518665, 59.55772369138656, 58.03574992764381, 53.61632131761121, 51.7875240695092, 54.1242447207051, 55.87283342115341, 53.124471787483465, 53.28188434723885, 55.35736730021816, 58.077750667448974, 57.51933067075668, 58.956800891507065, 52.700538096889375, 44.94776556568761, 57.68627066766062, 59.140203076024214, 60.05994789062008, 54.983318313475586, 52.999336411876065, 46.15423171750961, 45.75384793743011, 45.343524871333955, 48.812237631890085, 55.04651946406211, 57.029367800681825, 57.59495396767893, 57.00006769549463, 52.96541575462588, 57.202924836066465, 57.66876905195175, 52.493499709713845, 53.45372730685819, 54.95574797353437, 55.76816497310516, 55.27576238878312, 54.22937208606351, 55.33946560275171, 54.54941788027364, 48.20938110351563, 40.87116779819612, 30.975749569554484, 20.767198724131433, 12.647651241671655, 7.122891362636321, 2.1941640684681554, 2.1290112935727645, 0.739608861265644, 1.3367933972227959, 1.2252740393723212, 0.509073086563618, 0.3154650480756837, 0.21275248378515246, 0.27834428834819025, 0.2859536251954494, 0.5194679191035609, 0.2981613281994097, 1.529915950471355, 7.144425665178607, 20.413685306426018, 31.48303754868046, 41.697721019867934, 50.64186642246862, 56.42379699214813, 40.931435015893754, 15.474612270632099, 2.6665441788011983, 0.29571202253141715, 0.3284992067323577, 0.15105015357896207, 0.15343936731017407, 0.1260759553781921, 0.12374565380835727, 0.17326765333212193, 0.1224916521459818, 0.13806741474376572, 0.18440300178143287, 0.14455763502947747, 0.33095356858065056, 0.14382885558710945, 0.19842072540233213, 0.14944221163468976, 0.1969527630435844, 0.10157304680756024, 0.09125198087384624, 0.11040206457818709, 0.4066501954390157, 0.12362241324397827, 0.1790563056185361, 0.17402866975434367, 0.1370268988032495, 0.20057121081457985, 0.16520952685706078, 0.11010536638599251, 0.158168351457965, 0.1682485363656475, 0.17400634595223013, 0.15473017949731122, 0.16935121268033984, 0.09304355409356857], [0.02396550746784816, 0.040039677293069904, 0.015951378379888352, 0.010693816546981615, 0.06325660769136683, 0.045289509298820654, 0.024482444446954518, 0.026111478707002058, 0.04667376123008229, 0.043759060978528955, 0.10304468638834455, 0.07707729349814116, 0.06851289015744003, 0.03550854301260364, 0.08340292745420048, 0.0037925426882030747, 0.02724706424370168, 0.04388074255398205, 0.011945225959343296, 0.03427591903375522, 0.08243411734339692, 0.045753639837306355, 0.009085943550622512, 0.11382604859048322, 0.05738106188214114, 0.01909716235053155, 0.03881160004605209, 0.08815891620132231, 0.04837794680028193, 0.102406443216868, 0.04069601546131796, 0.0562254986875961, 0.02857067648531689, 0.017344088879443945, 0.03939047523383652, 0.03340292737008103, 0.01723612985393453, 0.036531707061634916, 0.8152702174359753, 14.981902760844077, 38.0254372473686, 48.88546043826688, 40.30884504318237, 30.75923473604264, 34.06799716334189, 26.353279467551943, 17.790508077990626, 4.722127722155664, 0.925846183972974, 0.22100251528524587, 0.14396385560112615, 0.08080162994203069, 0.0217234879551876, 0.08770525425432191, 0.5749142987112845, 4.395276125400297, 1.040406236725469, 0.06233025417332688, 0.15407684439372632, 0.8985643221005317, 0.921183834152837, 0.3212883888233093, 0.9091426480200984, 1.578180715441704, 3.2232638280237875, 4.783586850089412, 13.707480565194162, 19.85688917098507, 29.82508501698894, 35.02342770176549, 44.06767983590403, 50.535483898655066, 54.71669127864223, 58.419675442480276, 59.87236445949924, 59.30774319556452, 58.259293648504446, 55.614419829460886, 51.64087841587683, 51.43245935440064, 53.22834791675691, 53.34123373031617, 52.1377525021953, 52.94379565023607, 52.499810803321104, 50.801801066244806, 52.906682183665616, 53.69943241919241, 56.5013579399355, 49.92888150676605, 35.58400500205256, 53.96327457120342, 56.22798050603559, 54.90185460736675, 51.15973303394934, 48.70613359635877, 43.05439825980894, 41.32111464777301, 43.52301166903588, 44.48188997084095, 49.67646914143717, 52.59453996535271, 55.10930484341037, 54.0376191754495, 52.381378758338194, 55.092250377901145, 55.238390045781294, 57.49096801204067, 55.83925793247839, 53.80374393155498, 51.96944359810122, 49.758944819050456, 49.35236761646886, 43.51165248501686, 38.87201024639992, 33.89524421384258, 26.94940128634053, 16.53136645593951, 10.152435456552814, 3.0266864020978255, 1.931903612229132, 1.6561810912624484, 1.2493576373784774, 1.0918581726089602, 0.26009086459394426, 0.31298142166868337, 0.09665053352833756, 0.15998606359766376, 0.02532533268564411, 0.11600762185069824, 0.03985041910181603, 0.1810375315647933, 0.48356104101384845, 2.330116360418258, 8.67095918424668, 21.91591581990642, 16.617856679424165, 27.617143623290527, 33.478774793686405, 36.938928942526545, 21.80701513444224, 5.805617272853852, 0.26411463416391806, 0.11455394703173831, 0.05783701443203515, 0.03985412696736955, 0.01004472844332697, 0.07101581431925297, 0.05590272669289863, 0.030720627551237424, 0.054714983975094174, 0.015442655778550094, 0.05292344905976808, 0.03718966933628244, 0.13700275171187618, 0.03904434138788812, 0.019094785562746467, 0.04392815190517614, 0.08716052743576228, 0.007076283293445745, 0.08627847678238347, 0.02433081074888187, 0.07320641975609526, 0.018865914880147865, 0.023130203499608946, 0.010919877602117918, 0.05551810075919475, 0.09444162625098422, 0.04424650740299014, 0.013845466835904988, 0.0572299127346806, 0.04485837799767333, 0.03499225720823292, 0.02191275380732071, 0.03236080264492381, 0.00806350824272921, 0.018551939490040945, 0.062275475056301204, 0.026462917711826104, 0.018234189201687134, 0.037149070506735195, 0.058185611250660116, 0.026777032912979205, 0.016499455875506806, 0.0846468244168547, 0.05097570115580194, 0.06624259625471408, 0.019679178498805534, 0.021852368841909116, 0.02181450111581193, 0.02116855684547655, 0.05200603578780448, 0.029012985009279464, 0.015332302728277302, 0.021662892315596826, 0.04406297954940989, 0.09076553802456587, 0.04982268903404475, 0.03605416615403468, 0.02608665937347518, 0.06815744068233237, 0.015252254201069236, 0.010743280929032593, 0.05727596994068834, 0.02217524042803674, 0.04509038006466243, 0.039941794238984585, 0.04331964060604092, 0.0333334278735903, 0.02819901275929184, 0.06044521439640273, 0.047805740407878355, 0.08130301916671377, 0.0319701571753549, 1.5270778705035488, 18.680099671886815, 44.87918292322467, 53.05879954368838, 43.69409368884179, 31.623958503046346, 34.32019772068147, 26.08807429190605, 17.322449684143066, 5.64556299678741, 0.9793328493833543, 0.1136224300810887, 0.1719976940582837, 0.09145378375486021, 0.052103141262646646, 0.22542639725631286, 0.26300965958545286, 0.99143244205944, 0.5898180183383727, 0.2011915734939037, 0.246634254412305, 0.5279197075193929, 1.8577831959532154, 0.2806268013533085, 1.2372028250848095, 2.496815376704739, 4.982414245605469, 8.605650740285075, 17.35719600031453, 22.776770168735137, 29.998047813292477, 35.464204049879505, 46.58415486735683, 50.89676557048675, 55.177436413303504, 59.43223922483383, 61.781601675095104, 60.59222529011389, 58.67167203657089, 57.547720786063906, 54.623605589712824, 52.809038700595984, 54.36105781985868, 54.67079954762613, 53.82658781543855, 55.28102620955437, 53.82153580265661, 53.751807828103345, 55.56956752654045, 56.69291080967073, 57.50198202748453, 51.45139655759258, 39.14040234781081, 54.54996308972759, 57.054808293619466, 56.65595816027734, 53.22878722221621, 50.1042506771703, 45.29396964657692, 43.777765689357636, 44.62024373392905, 47.74485480400824, 51.23808630051152, 54.65177997466057, 57.18834930850614, 56.04919887358143, 55.58278983639133, 56.91659181348739, 57.06749323875674, 58.9699290644738, 55.518917960505334, 54.90164279937745, 53.912440653770204, 52.56163127960698, 50.78060065546344, 46.10830076279179, 40.256140155176965, 35.2884034187563, 27.894855276230846, 20.722444480465306, 12.440980576699781, 4.846929696298415, 1.647792734926747, 2.3344858807902185, 0.9584941546763144, 0.8384720175977677, 0.44392754353823205, 0.0589274141877409, 0.16705783654845532, 0.16310624778270721, 0.04739786370567257, 0.11445015743975678, 0.1417484672199334, 0.08277021543753725, 0.4010020436779146, 3.022042560961939, 10.803045861182675, 22.950486060111757, 25.08714818185376, 33.00261082187776, 39.268867815694506, 42.03100481340962, 26.87099506778102, 6.960316963734166, 0.47247397142552566, 0.07184565608059207, 0.05438796402285657, 0.0643389213890318, 0.07337647595352705, 0.024580243231368162, 0.08408214100786755, 0.04771579402468858, 0.05887478011690321, 0.013202431784462065, 0.06517581115927427, 0.08265216894928487, 0.03582792506823617, 0.011967861942285973, 0.026388383102453044, 0.0352004339407769, 0.03478968823929468, 0.057575498827763145, 0.04342507728705964, 0.02019415046238611, 0.040306019251264875, 0.06002860429186014, 0.03187262077605532, 0.031945588735623226, 0.016722919892579798, 0.036089095932942246, 0.023741355886863127, 0.03336507113530271, 0.013050669766662103, 0.07580453034250006, 0.013574637517693543, 0.020491465355359742, 0.01902133879822589, 0.04776613749263268, 0.2077955578363711, 0.11184861477945121, 0.12894292452162312, 0.1385242023294972, 0.1682063708862951, 0.1003526074571475, 0.106321397658077, 0.13654240947817603, 0.22784092253254307, 0.12586009478376758, 0.1898664344222315, 0.15557960246599492, 0.1196212892330462, 0.13585823167475963, 0.2559019264674956, 0.10351296529294023, 0.1400152392565243, 0.11305285903114466, 0.12916147408466186, 0.0616704571181007, 0.19026245591380905, 0.2892833191060251, 0.11643677664500092, 0.14248498415033664, 0.2462656435466582, 0.08466217681885728, 0.12753031201540463, 0.11686882725165737, 0.15098681342938255, 0.21282339288342386, 0.09990134336535009, 0.114808211613807, 0.1658597516436731, 0.15985254979422017, 0.1673553238112119, 0.22716840458733423, 0.1412295192600258, 0.23085842029221598, 3.0171775962075884, 22.98235139539165, 51.78503728681996, 59.77468175272788, 52.339785945030954, 43.90328545724192, 45.04746044835737, 36.81877889940816, 23.386165288186845, 6.920324477457232, 1.2986163554653045, 0.4483321200936072, 0.5472286165721956, 0.6841149229195811, 0.17569786808904142, 0.42342323088838213, 1.302374353812587, 10.02560071406826, 2.6375507539318455, 0.7365269201897806, 0.6149892773359054, 3.4931498621740653, 4.089988739259781, 0.8179938132243773, 2.110964713558074, 3.119665206440034, 5.52661516012684, 9.619076463483996, 18.03936089238813, 22.513418312995665, 31.27260631130588, 37.116992781239176, 45.813883735287575, 51.08961282237884, 55.16626942542292, 59.18671061915737, 63.33238917012369, 63.08030236151911, 62.54958998772406, 59.54990248526297, 57.760391696806884, 57.46318194173998, 56.922381231861735, 57.19454273100823, 55.64896414356848, 57.5341062391958, 57.52596339871807, 55.78806315698932, 57.5158005376016, 57.506520209773896, 60.57266050769437, 52.439351389485026, 42.816416294344016, 56.67274590461486, 58.71748139781337, 59.19688524738435, 56.296543536647675, 52.58002327334497, 47.97771415402813, 45.04589542265862, 47.18861956750193, 48.74097993296962, 52.53524157308763, 56.942671652763124, 58.536789571085286, 57.3675427898284, 55.54928887274958, 58.555899358564815, 57.672071687636844, 58.4125602629877, 55.92244748146304, 54.932994304164765, 53.65201880854946, 51.87283562075708, 51.981477429789884, 47.25056163726315, 40.702078342437744, 36.69150190968668, 31.275542205379857, 19.99961441563022, 12.231161229072079, 5.539343251336006, 4.201876309610182, 4.774655122910777, 3.741925700056938, 1.925282161081991, 1.1719402238245935, 0.6792875271170371, 0.641158105384919, 0.3717016933425781, 0.2564221154898405, 0.2405471802358666, 0.39454416762436595, 0.3852724812684521, 0.9241305147447895, 3.370326968931383, 12.551350189793496, 26.619033775021954, 27.379369543444728, 40.876702262509255, 47.19044346963206, 50.12964410166587, 30.591775025090865, 8.107926970528018, 0.660556187072108, 0.11717286456616656, 0.20506958717540388, 0.12335214508517135, 0.17222080950535115, 0.14696437685239702, 0.4404732530876514, 0.22210991070155175, 0.11082178883014188, 0.07966411960942131, 0.1124069549804253, 0.12600375925220791, 0.27060511491952405, 0.12902906344782922, 0.2918703367392863, 0.15251215577365893, 0.188716015508098, 0.12250960158604769, 0.17098279609795541, 0.11754201169336036, 0.09630246147994073, 0.20375473514920284, 0.18954066319331048, 0.08814216951929754, 0.16063241197937922, 0.168539174802361, 0.06975035964240951, 0.10346375946556369, 0.21283134487607788, 0.17503100387271375, 0.11564186083212977, 0.13437071875218423, 0.11141628838114201, 0.27783146909167694], [0.03595849709405053, 0.0866761606847567, 0.044818120077252395, 0.012868622377995523, 0.009874459656496203, 0.019795566406701843, 0.0653028515197577, 0.014255093091407852, 0.028237376527319995, 0.024173586524181792, 0.10456429073406805, 0.04470593799206038, 0.035452990146774443, 0.028833996226650574, 0.02287780625685569, 0.08789869911608197, 0.07672831746599368, 0.029173507242493575, 0.006077144719329813, 0.13343802202613125, 0.1312374344636356, 0.012728967422228909, 0.06217706723198776, 0.05355913349757752, 0.028782760266274698, 0.04602660462560673, 0.05925886212818085, 0.008109050254607874, 0.06693963667437916, 0.0647502722999742, 0.05847524611219283, 0.06988424116805678, 0.02330513393145896, 0.05771119598179095, 0.01039444279271148, 0.04896520298995799, 0.038533582907891085, 0.05768010430338402, 0.5137776018631074, 7.529321966632721, 29.039969675002563, 50.149616810583304, 42.93687620470601, 37.2961195822685, 26.373167845510668, 38.047535880919426, 25.021705396713752, 11.230881329505674, 2.6216666256227805, 0.6936962313709721, 0.21717901642043747, 0.052407507994963284, 0.17402938987699249, 0.23530006018136781, 0.06669809681273277, 0.4114118915411734, 0.3694219688975042, 0.3941557916902727, 0.10005451498493072, 0.06943778044754459, 1.916568493170123, 0.6784083033280989, 0.5901004289907794, 0.34591882038981686, 1.2915829328760025, 1.8723609298467638, 5.032761789137318, 9.769322852934561, 18.516450543557447, 24.28255238840657, 30.801876783370975, 37.439756777978715, 50.16068181683941, 52.535445536336596, 57.38103966559134, 59.1269297753611, 57.001487593497004, 55.866510560435636, 55.613262730260054, 56.99430181134132, 54.994532369798236, 56.27979501601189, 54.49528132715533, 56.324160945030954, 53.51495550524805, 54.59046548412692, 55.3153234143411, 54.56974752487675, 53.92339975603166, 52.742095608865064, 36.022796630859375, 54.67662034496185, 58.620187005689075, 54.681134993030184, 52.29898152812835, 47.48542531844109, 44.2611821236149, 45.99967856560984, 42.85937801484139, 43.54474159979051, 47.64402243398851, 52.42720380906136, 52.56625967641031, 58.00404148717081, 51.53104420631163, 51.14944465698735, 52.03033055028608, 52.11263756598196, 56.262242409490774, 53.049683955407914, 51.70758224302723, 45.57179112588206, 41.117555402940326, 34.365814885785504, 29.19727436957821, 23.290728138339137, 13.582565822908956, 8.235860466957092, 3.093434846208942, 1.4374323453634017, 1.3086680419022039, 1.5337816914243083, 0.9487837144444067, 0.6976132695713352, 0.10360144844819462, 0.11520571165507841, 0.06088757654652, 0.08188278684692998, 0.056966171644988566, 0.004636501534766848, 0.141992190432164, 0.18820621463800633, 1.279018845769667, 8.072538856537111, 19.065921652701594, 21.81636214256287, 18.190123073516354, 26.049399722007017, 37.56244067222842, 30.503154954602643, 15.028151427545856, 2.4692739642435506, 0.05637695427022635, 0.005266525061620821, 0.02637506274866962, 0.024300571343290712, 0.04010046636986156, 0.07087123054530352, 0.07916364969024736, 0.06343003850610507, 0.03130310335226598, 0.0526451867734713, 0.09687006368391937, 0.026626333842174183, 0.1386590950912045, 0.059356178277202194, 0.048871518097697735, 0.03499303478747606, 0.04580415184459379, 0.04378055357524464, 0.06262767248817029, 0.06323498102926439, 0.010360365286619674, 0.07091328877234651, 0.0149673413139798, 0.03857417407655909, 0.03902472953702654, 0.04422871884138835, 0.07005926161523789, 0.0347914464110809, 0.03555388009596256, 0.013137223337957216, 0.049507206365946806, 0.07392900154715584, 0.04092418325824603, 0.013599504731715688, 0.0637823163772062, 0.06301919704363232, 0.06219465661072924, 0.03361408418465046, 0.029560716807722088, 0.06153975102689959, 0.015614089019025768, 0.027529857940070575, 0.05257220923780434, 0.03593709259744614, 0.00253290620974205, 0.02436440561958138, 0.08538665084709084, 0.02147050848561189, 0.09121345431213418, 0.002406082508499704, 0.010266786689058909, 0.14885069982659432, 0.044186403974890716, 0.10234640490624214, 0.1187613248945244, 0.06474704706981298, 0.0198186103314642, 0.030628658695927555, 0.034656086335739786, 0.04221947705974022, 0.06928478502818654, 0.031883409209249, 0.019202530083637086, 0.0226342266861109, 0.02170188236050308, 0.08275873944043152, 0.018960524823576696, 0.032605288114639065, 0.017667513964096868, 0.06730492271843456, 0.04074636275970167, 0.037177400438175086, 0.6026031064891046, 9.671580330018076, 33.48966721565493, 57.22201501169513, 49.10581527217742, 39.61541706515897, 31.900546396932295, 38.88258495638448, 27.938836812973026, 11.674870098790816, 3.0820148654522437, 0.6957828710156103, 0.09511679486041108, 0.11483667944107326, 0.1950802449737826, 0.11237882423184573, 0.03838502696805424, 0.23874652121336232, 0.2841276393061684, 0.3689968513865625, 0.1706700023984717, 0.44908717635177803, 0.993780164468673, 0.975465085958281, 0.40912499651312834, 0.7490575445755836, 1.724838503906804, 4.3927177594554045, 7.962029509006008, 12.942464428563273, 20.386199297443515, 26.386739246306885, 32.10671401792957, 41.37043060794954, 50.55358955937047, 54.69549479023103, 57.95773790728662, 58.949011064344845, 57.097934753664084, 57.072211850074034, 56.650662960544715, 58.99621286699849, 57.0368673724513, 57.67506445607832, 56.24659607487341, 57.32336121220743, 55.02843341519756, 56.99805159722605, 57.14652507535873, 58.05385558835922, 55.94326349996752, 53.08051770733249, 39.05579682319395, 56.30505115755143, 60.33347045221637, 56.95873375861876, 55.40883664161929, 48.81960384307369, 46.290824336390344, 46.95856471215525, 45.815487984688055, 45.38157186200542, 49.06982752584642, 54.81039670205886, 54.47493207070136, 59.54267747940556, 54.52437746909357, 54.129998837747884, 53.48972682029971, 54.03234750993791, 54.81162048155262, 54.22686176915323, 53.33750355628229, 46.604472744849424, 43.1140535877597, 37.58668091989333, 29.99619841575623, 26.357637220813384, 16.70546477840793, 13.148481038308914, 6.763842500025227, 1.5698954438970936, 1.4291138562463945, 3.2155759824860484, 1.5122054685508053, 0.21167560931174986, 0.44742032224612854, 0.1696179491738158, 0.18611787427817622, 0.24932959687805947, 0.04580090746223446, 0.09260041819464776, 0.08666230981508571, 0.23345309880472, 1.6358190871054128, 7.424155377572583, 17.036626569686398, 26.266279335944887, 21.06617158459079, 30.038946367079216, 42.66518931235037, 38.3012818521069, 17.785867914076775, 3.131637751094757, 0.07869108069327571, 0.07227080423505076, 0.04000555956736207, 0.020257438901030732, 0.07157208608283151, 0.09137684554462472, 0.008310596496167203, 0.07937771763892905, 0.02166855945101669, 0.07849061080525, 0.041827737999659394, 0.08392732229924972, 0.09394291833403612, 0.04125809800180216, 0.05413790526349218, 0.017952366521762266, 0.06172776049483688, 0.006267481179337108, 0.02223407406540167, 0.023435573807106386, 0.02375559554615569, 0.05453327558033409, 0.03058052730686482, 0.05969409199972307, 0.044052476483968, 0.03660140191054633, 0.059195418556731556, 0.06013617069730836, 0.07773762298447472, 0.030184051908192136, 0.02380659401927504, 0.013609163185221054, 0.04065109972631739, 0.04613023333912415, 0.11762469556302795, 0.19510420820405408, 0.24468670569119916, 0.13634039209254328, 0.09805633551290921, 0.13039380311965942, 0.1734147115700668, 0.07319222414685835, 0.11299331101679033, 0.08071414270107785, 0.23288311406729684, 0.0922102802583287, 0.17635812862746178, 0.08988762424597818, 0.16599959333337125, 0.13750438608469503, 0.16157966437599353, 0.28314104063376305, 0.1060834201052785, 0.21567051268873677, 0.16768599800284834, 0.1467605974645384, 0.1069900775027852, 0.19052554582876546, 0.16082955704581353, 0.11114225106974764, 0.12710966079706146, 0.19667180795823375, 0.1845028230379666, 0.09952176212062759, 0.13276908937240803, 0.11102274135355988, 0.0883418579976405, 0.16728279060654103, 0.09380183558190062, 0.1403454691171646, 0.19994505651054845, 0.15467745732636223, 1.0370304243218516, 11.92864058479186, 38.19941005399151, 66.30432590361565, 55.321344252555605, 48.78077630073794, 36.53620350745417, 49.296144362418886, 33.85493401558169, 14.336422816399606, 3.9629887669317188, 1.2667709997584744, 0.9316715778362368, 0.2828762806471317, 0.7376576046789847, 0.7324754182369478, 0.18824477950411458, 2.161254402129881, 1.419979146411342, 0.8695146357340198, 0.3572857572186378, 0.8799115520331168, 3.187600902972683, 2.4933475111761405, 1.705151882863814, 0.6003034331144825, 2.776434772437619, 5.342073036778358, 8.000264283149473, 13.16164549319975, 20.29815777655571, 26.225969137683993, 35.97757562514275, 41.31293650596373, 52.10951928169497, 56.09627516038957, 60.6834674650623, 62.30033905275407, 59.32948881579984, 58.7342103065983, 60.59985822246921, 61.97203666933122, 59.898040294647224, 61.72168747071297, 57.25597097027687, 61.0051175086729, 58.035855831638465, 59.41367856917843, 59.296321253622736, 59.40000126438757, 56.58552023672289, 53.37373448956398, 43.94802793379753, 57.33747782245759, 63.09504655099685, 59.6221564662072, 57.138527362577385, 52.97700635848507, 48.29641065289898, 50.55569194978284, 47.59625973240022, 47.09492198882565, 51.43930389035133, 58.39202665513562, 56.68764306652931, 60.64995081193986, 55.982804913674634, 57.20404663393575, 54.69713826333323, 54.275185369676166, 56.93880419577322, 55.53408184359151, 55.0016789282522, 49.43100329368345, 43.378040867467085, 37.10047960281372, 31.798925630507934, 26.039664399239328, 16.383575470216815, 11.285748424068576, 4.580266379540967, 2.972352995026496, 2.7270558091901966, 5.519037140953926, 2.789651689029509, 1.7026826282662733, 0.5888287843235078, 0.46443985414601147, 0.5163406256225802, 0.4743807029820258, 0.2991826459765434, 0.29297782408614315, 0.7314649176213049, 0.5009764565094825, 1.818588421710076, 8.628794685486826, 21.420634215877904, 30.220879623966834, 30.015767120545913, 39.501974275035245, 49.687420398958274, 46.06189520128312, 21.34670734405518, 4.467856643661376, 0.235552700657037, 0.19464132255844532, 0.25326765653106476, 0.17697453829309634, 0.12683981398661293, 0.18683663329049466, 0.2063450929258139, 0.18236601995604654, 0.14496226734932394, 0.25392066987772144, 0.18937013202136566, 0.20015876439790573, 0.26980424660348123, 0.13917245060926484, 0.22450301615941912, 0.12247036256256605, 0.1904064498000568, 0.21876138634979728, 0.1265284681933061, 0.1701311361525328, 0.14462187916280764, 0.12766983960905384, 0.09667257387791911, 0.15090638951909158, 0.12438671618339517, 0.1898073383997525, 0.15338456138007103, 0.17567640230540307, 0.08914182232993265, 0.13831996328888402, 0.0866585483233775, 0.12488972951447773, 0.24881369794809052, 0.08204072353339965], [0.03971084554289137, 0.029039449516623735, 0.045212180383743784, 0.054526173945276014, 0.06057237733095404, 0.018843627467210737, 0.05986304886098351, 0.09440660837196535, 0.04586404076807442, 0.06470282081394427, 0.03803186426540056, 0.047524942370552214, 0.0581037279428734, 0.029857346052003485, 0.019914959294481144, 0.03331704508332956, 0.04803499604965891, 0.01531824405725685, 0.08873468490257379, 0.05686969819268393, 0.09949630501890376, 0.03835500398230168, 0.04766495259959371, 0.057657033565544316, 0.029888336223760442, 0.03725046224351372, 0.043463868149105585, 0.007891736008347043, 0.042938220750300155, 0.02936245516813811, 0.058888845491193, 0.08175025363602946, 0.037001054658884966, 0.08782605099822245, 0.04720364126466936, 0.014688873141553375, 0.03998385629646721, 0.06696640378645352, 0.036529535202369574, 1.7154249380673132, 16.805757822528964, 45.395704161736276, 49.288248631262014, 35.809729560729, 28.63690103254011, 33.74882998005037, 25.173544268454275, 12.41566461901511, 6.589714269484244, 1.9480665965426354, 0.27852330777433615, 0.09826089631045058, 0.18691796118453627, 0.08601620658150605, 0.027953992943249406, 0.19910801352272112, 0.027080187311155662, 0.06924721607637983, 0.2959268029418684, 0.6425404344354907, 1.3791296222517568, 0.5994093778633303, 0.40175225826040395, 0.8132798597216607, 1.7175219352206879, 1.512364324542784, 2.3790756300572427, 2.8934481451588296, 7.355687464437178, 14.81049616490641, 21.256692870970696, 26.511751067253854, 36.390267802822976, 46.59833423552975, 49.49065862163421, 53.30466155082949, 56.42899021025627, 56.95739623039, 57.43053213242562, 57.735931796412316, 58.40451548176428, 58.02246093750001, 58.90701424690985, 57.77716375166371, 53.43914393455752, 56.03955768769788, 56.04794371512629, 56.39045292331327, 55.12319787856072, 52.92674118472684, 36.096729386237364, 53.94969140329669, 59.08221083302652, 54.82961631590321, 54.34229712332449, 49.66462750588694, 47.614455607629594, 46.85262541617117, 45.656871257289765, 45.284634405566806, 47.94686079025269, 50.71834087371827, 53.343736202486106, 55.136557471367624, 50.50177504939418, 54.53385391542989, 56.76998930592691, 51.937597874672186, 53.62135371854229, 45.59228943240258, 41.91865636456398, 36.49046474887479, 29.99420192933852, 24.28802017242678, 15.434253042744054, 10.340174801888006, 5.4046877930241255, 5.61549557793525, 3.5124359111632075, 1.3598723781685675, 1.808755775132487, 1.818111363437868, 1.0163135069512552, 0.1615887501787755, 0.5319045291792962, 0.16083764693429395, 0.08335908424229392, 0.19209228756446994, 0.053767176164734753, 0.05571526880826681, 0.09649769132656437, 0.9142778885941353, 4.40082480830531, 13.510343220926101, 31.771488651152584, 42.661886676665276, 27.45722466899503, 27.780961413537305, 37.00544449590868, 22.83943787697823, 8.235921263694763, 0.43863773706459236, 0.04790981728283148, 0.06608187866907927, 0.02059591569817595, 0.04726198652098256, 0.02376780507244891, 0.06427111494685374, 0.05396123772727386, 0.017123011226255088, 0.08998620444007459, 0.04192298954172481, 0.04944927479711272, 0.0786682972384076, 0.01593448805637778, 0.09676700187546593, 0.05009626669268455, 0.027141868880379106, 0.044498033220729524, 0.014992609766552286, 0.03539197890448474, 0.06018896947704977, 0.03040620591491461, 0.060397414340367245, 0.0493483848479246, 0.04751515559731953, 0.021725958588743405, 0.051208687645773736, 0.008983662194241921, 0.07871187231954067, 0.07130837563665644, 0.011278088824192603, 0.014295446772819326, 0.06806875068333841, 0.018559422253841357, 0.015999433160158658, 0.13165205657001466, 0.012696105123106993, 0.033128123970762376, 0.008227942312406677, 0.07485995159274147, 0.044159456832154144, 0.07587170093170098, 0.08706709535251703, 0.023046791846413287, 0.0350275815224215, 0.014259518206780477, 0.08521664827581375, 0.07776210715453472, 0.06625744303868664, 0.03885882170570474, 0.05395007199577747, 0.09521750477893699, 0.06717240482929253, 0.11311183247955577, 0.08226204633472428, 0.10108361621537518, 0.06086716796421717, 0.034126635310390306, 0.08979217735149207, 0.015313625504683345, 0.022392774924575802, 0.033163095884505785, 0.052709836933401324, 0.009507280417657908, 0.03878201373041638, 0.06521402362493739, 0.04403164655330681, 0.03177488136345581, 0.07811663732413324, 0.0048925113608880395, 0.03440390934326476, 0.026497654053532792, 0.03848436175875607, 0.07237257901579142, 2.3295412428917426, 21.350525771417928, 52.80861508461737, 54.489107516504106, 38.90749985171903, 27.506481793618974, 41.521135914710264, 30.452501466197354, 17.719491604835756, 7.914355060746593, 1.886053924118319, 0.2868897539954032, 0.11079329035935864, 0.3213008607347166, 0.12011283422790228, 0.054463745440326394, 0.1810669953063611, 0.1501489277448385, 0.06656218515408617, 0.13035427298276656, 0.2796352077876368, 0.8689968828712741, 0.5368962968068739, 0.09922753839242844, 0.46824216301883426, 1.8567574961531548, 2.442322868493296, 2.8441424812040026, 5.970969200134278, 11.103092470476705, 18.929780106390677, 24.11131935734903, 29.542684170507616, 38.32136438738915, 48.0144706849129, 51.82701841477425, 55.68193166486679, 56.15820546304026, 57.89947502074703, 58.18086193453882, 59.186894970555464, 60.148558155182876, 60.1161946788911, 60.56403913805562, 59.31471324736073, 55.35510017025856, 57.993231434975904, 57.82172972156156, 59.606921980457926, 56.667313421926195, 53.02862082758258, 39.49035229221467, 54.83908491749918, 60.08001081405148, 57.09926051478232, 56.96233841680712, 51.625263460220836, 48.670573388376546, 49.15235027190178, 46.45923522210891, 48.41616061425979, 50.01790362019693, 53.25257639731131, 55.177471714635054, 57.3555285699906, 55.09214055153632, 56.29959906301191, 56.889970687127885, 51.625961642111506, 53.43228763149631, 48.28213714784192, 44.197902525624926, 39.33275538106119, 32.30694317048596, 26.611238064304477, 18.715285293517574, 15.921908578565045, 11.056124048848307, 9.125461866778712, 5.318827109952127, 3.352565496198593, 2.8518624411475275, 3.0333110401707315, 1.7239706795061789, 0.6268876646795581, 0.5138285620318306, 0.3933656486051698, 0.7433685143628429, 0.2558348478088456, 0.11348949084358831, 0.06919047194382838, 0.2381158163470607, 0.6725748195763558, 4.05294464961175, 16.221346239889822, 31.212374394939793, 45.6576321971032, 31.579117967236428, 32.3578300399165, 43.82952920852169, 27.86227018602433, 9.626817261019061, 0.7818004488945008, 0.07112437663900276, 0.00494543893916172, 0.015034684272963676, 0.06853856942466191, 0.04837517739243565, 0.07208718062047997, 0.03671599717269983, 0.00940127491635541, 0.06106294173326704, 0.02692192312209837, 0.0321736128910655, 0.01822549027330693, 0.02887866298307575, 0.10665599421988572, 0.03799879224970937, 0.036495743064029564, 0.022244370287104, 0.025080686337464762, 0.12623034507757233, 0.0298538584367282, 0.029478687943229755, 0.06763512193555794, 0.04944486596110848, 0.09635863104654897, 0.03138061229800505, 0.06133480718539608, 0.028742284010795337, 0.055161460017364834, 0.017564980756311167, 0.03841037681746868, 0.035918396221654075, 0.05577659414660546, 0.11704183288759763, 0.02116931527252159, 0.1921340853216187, 0.08558247058141617, 0.10059150431545512, 0.2069723197529393, 0.2782431953857022, 0.23615735853391312, 0.19356815595059626, 0.20261038365142964, 0.1434537176523478, 0.21702570690503045, 0.1354862653440045, 0.17034328122052456, 0.20608738094808596, 0.11904432543463285, 0.1782049674300417, 0.13431871670388407, 0.1573658743572812, 0.17570526849838997, 0.19398363607545055, 0.1774304831821111, 0.21267533873117742, 0.15545135934747037, 0.10804214604919958, 0.16863876623251747, 0.09139836495441776, 0.24337338584084667, 0.09332509906662088, 0.2059078099386346, 0.14229176145407463, 0.2420246727283924, 0.15221105257589973, 0.1886897386922952, 0.15006090424233867, 0.1841016687572964, 0.07036483110559565, 0.17351136122259403, 0.08961969265534032, 0.07178551817853605, 0.12637099882047023, 3.231905790105943, 26.668090858767112, 59.32249130741243, 60.038508215258204, 48.08430848583099, 38.07947181886242, 44.820319914048724, 37.64140190616731, 18.64670853460989, 8.404772435465167, 2.560336445608447, 0.4241992166686443, 0.3565607009635818, 0.7494913342018282, 0.43495288479232025, 0.17047858766971097, 0.4213735779687282, 0.48173836462440034, 0.371041631987018, 0.6994294495351854, 2.2155731003130636, 1.5467160747897242, 1.8961309833872704, 0.7425161342947715, 2.5518906020349075, 3.701029107455285, 4.4855377078056335, 5.383493265798015, 4.2009011103260905, 9.024342183143862, 18.160720986704675, 22.260821596268688, 30.33636989132051, 40.72791891713297, 49.80544059507309, 54.14259356837119, 59.126415944868526, 60.79861256384081, 59.99673889529321, 61.02536086113223, 61.22800227134459, 62.8021788597107, 62.01113093283869, 62.403014936754786, 60.369862202675115, 57.16024944859167, 58.69038958703318, 60.23911391535113, 59.98512083484281, 58.13079680165937, 53.194411570026034, 45.2308940118359, 56.23105564425069, 61.56407094770863, 58.26126660070112, 59.820808825954316, 55.76647835393106, 50.95221611761278, 50.518174479084635, 49.960903736852835, 49.45309800486411, 52.35794651892878, 56.02264050514468, 57.94885766121649, 59.846013976681625, 57.521852754777484, 56.366499008670935, 57.19357782794584, 53.149767152724735, 55.57146595370386, 49.81663111717471, 45.69278055621732, 38.90806859539401, 31.44243709502682, 27.2962760925293, 17.81232233970396, 11.953600587383395, 8.231115379641134, 8.40420663356781, 5.6971397130720085, 3.5377937891790947, 3.822310018923975, 3.863915089638003, 2.022528994467951, 0.3760088541575017, 1.2556250946175669, 0.6381560213142826, 0.8717231752891695, 0.8949792757630349, 0.2897180586812958, 0.37469001847409433, 0.431862271601154, 1.3301246324854514, 5.652285448966488, 16.820958968131773, 36.75030216093987, 49.07750752664382, 37.83707718695364, 40.763283006606564, 49.951203715416696, 35.78068048723283, 11.186540895892728, 1.0986145778048424, 0.18886751705600371, 0.1764807639823806, 0.16357696284690212, 0.2159339856476553, 0.22331294453432485, 0.17754870587058608, 0.0770598496761053, 0.14340298731000195, 0.17055462955707507, 0.07278898610703408, 0.07957405065216365, 0.2336753102680368, 0.135738599384504, 0.23418603044363762, 0.12323911647282301, 0.1602093169405576, 0.19258169517401727, 0.15282355519312044, 0.1567055678535854, 0.23269870138216406, 0.24021943250010092, 0.15953689092589965, 0.14603270668416254, 0.21697212671560628, 0.17425656559005862, 0.20025550598098388, 0.11171998095608528, 0.2530313643716997, 0.14522525001197092, 0.14548628681129025, 0.09450720337730262, 0.13666136761105832, 0.20323056246965163, 0.15573286601612646], [0.036710182565354535, 0.01865653922000239, 0.05079491589699061, 0.03800947917625308, 0.09167986396219462, 0.0463786909747268, 0.003777104340711489, 0.018519731238484383, 0.07656674186188368, 0.030989735086839047, 0.031257369818406246, 0.036502335250618, 0.02513547120014987, 0.029990149308897318, 0.04372570167986616, 0.03797182978521432, 0.03672365805194263, 0.015956854950937054, 0.003997162857558578, 0.04847314471619264, 0.023978322203601563, 0.025789633678692966, 0.08926447300660996, 0.039130828884099765, 0.08194576693518509, 0.08578663301323691, 0.07999719931713997, 0.0346634982364072, 0.058236307119049376, 0.08949745566614213, 0.030004546016214356, 0.06409437846272223, 0.037088702778301896, 0.03626030892313969, 0.05100159875808224, 0.04093513448512362, 0.030165836252572558, 0.0196586626641933, 0.03243699774987275, 0.13153401774264153, 6.12067969576005, 27.894361057589133, 43.683275791906546, 44.72079761566655, 29.410986669601936, 24.033144558629683, 28.815810142024873, 20.182120338563, 12.876212654575227, 4.30504935403024, 1.015415161607727, 0.051417814327343825, 0.11972093428935736, 0.01292508784606452, 0.059253001555560104, 0.025259962403065255, 0.06199731236143459, 0.11847385040093815, 0.20555205402835725, 0.15531275872020953, 1.6955046908509348, 0.3460727121320463, 0.12961567229320928, 0.26832407280322046, 0.2885761586648803, 0.721491678587852, 1.333012600098887, 1.7219311695906425, 4.165732649064833, 8.323847074662487, 13.255300906396682, 18.285936770900605, 21.01413546069976, 31.779945281244096, 37.0893753728559, 42.45420894315166, 49.15378585938485, 55.55629814824751, 59.98939621833063, 57.70761620613837, 57.84757814099712, 57.01691427538472, 58.93314115462765, 59.55521337447628, 57.00133854343046, 58.082708543346776, 57.353214371588926, 57.1355777402078, 53.56078447834138, 52.136152175164995, 36.363776114679155, 53.79860562662925, 58.82931993853662, 57.24256430902789, 55.35520999662338, 53.520399755047215, 50.621666216081195, 48.24217604052637, 48.2204931782138, 49.50088031830327, 46.98689206953972, 51.63755616834087, 53.81380481104697, 53.53503411816013, 52.601517861889256, 57.46364870379048, 52.69514091553227, 52.372388685903246, 46.32481559630364, 40.83164207396969, 31.01484187187687, 26.14445640194801, 19.751220518542876, 16.305275155651955, 8.613602365216902, 7.748960967986815, 4.270608002139676, 3.2173697313954754, 3.4527001746239203, 2.021365153693384, 1.011375794487615, 2.7304969535719965, 0.8847043206614833, 0.7598824282327007, 0.2674891901833396, 0.014176041436111255, 0.4072217276740459, 0.04141684291103194, 0.09226271897674569, 0.060183905635870276, 0.4127342818725494, 1.954658752487552, 7.716636715396759, 11.61682882616597, 31.680379836790024, 27.67212348599588, 27.59413499985972, 36.06238119063839, 30.68521372733578, 15.860596049216488, 3.0217160236450935, 0.03396160464974181, 0.015104545745998623, 0.035848559646476666, 0.03971831106971349, 0.003942453167251041, 0.00927313617731054, 0.08804622466766066, 0.051823044195771224, 0.02342422038406855, 0.029974582402275938, 0.04304671795257638, 0.05223369030582328, 0.01829774194066563, 0.05101413578696309, 0.03338366025878537, 0.08614710802512784, 0.12922533517402987, 0.02282536370799907, 0.036561381477381916, 0.01905458318370004, 0.08414338973741378, 0.07887589174412912, 0.041532828622768005, 0.12243372823802695, 0.048605693248851646, 0.03871838629786526, 0.019772872967164845, 0.0214071357772956, 0.048938550791072274, 0.043667892685099956, 0.0302510348058516, 0.039969752617781205, 0.04221538231978494, 0.08102119074112947, 0.04612050785292541, 0.05281996973339589, 0.007095104637330459, 0.02348239710103841, 0.05548888216576269, 0.04578897564281379, 0.016629390133124207, 0.05110929539847759, 0.023373920966180104, 0.03934456358453439, 0.10581575664541415, 0.0562575173323914, 0.0349400827901498, 0.023662343493572647, 0.025197899705099485, 0.02551027014100504, 0.09761330686629781, 0.04630121650294431, 0.04413199258006869, 0.07797403771790766, 0.04352893965739397, 0.03840230608118638, 0.018800385634324724, 0.014739296091119609, 0.009484377261551638, 0.03751691145401809, 0.04657939068912979, 0.030513073265131925, 0.06302842074224065, 0.04343837657342515, 0.02828815858060074, 0.05526114337807221, 0.04537962805179339, 0.029288826457735513, 0.040347993208636204, 0.04110274686207695, 0.07738690027185986, 0.04593029971264544, 0.09626539814616404, 0.02650015916104519, 0.2627505686494612, 8.179042483529738, 33.59317071976201, 49.74660112011818, 47.741407040626775, 32.14177216252973, 27.25146889686585, 34.100615593694876, 20.318495265899166, 14.360275730010002, 5.215185342296477, 1.5030732101971105, 0.08198319799116544, 0.12358646839857103, 0.04112247745656679, 0.12829721199288485, 0.019493427075025056, 0.16736263229000956, 0.015782438755606212, 0.1741192366687521, 0.5570325808178994, 2.5979681553379184, 0.19905259472227868, 0.3701770251556751, 0.8110897062766937, 1.5970026990098338, 2.936976893294242, 2.1639495607345336, 4.258734497331804, 5.281938199074038, 12.843793284508491, 13.736809107565112, 22.685657432002408, 24.558036135089015, 35.543326100995465, 40.02362989610241, 46.64457113512101, 52.90710579964423, 57.94494313578452, 61.1824910102352, 59.081061578566036, 58.91261539151592, 58.84084386210288, 59.866912364959724, 60.462206563641956, 58.15280914306641, 59.522967569289676, 59.4101131346918, 58.32436576966317, 55.4975998786188, 53.144401350329005, 40.47684015766267, 55.24341460197203, 60.11441392283286, 60.00800786479827, 58.96567329283684, 54.43572405845889, 51.1838516881389, 50.78790803109446, 50.03705655374835, 52.04569839662122, 50.33905160042548, 54.09204598396055, 54.92726372134302, 57.23149145803144, 53.57408915796588, 57.170655496658824, 53.46511002509825, 52.867905632142104, 48.206223595526914, 40.94016228952716, 33.9231675670993, 27.51780175393628, 23.94549527475911, 16.405335799340282, 11.626021881257335, 10.169479135544071, 6.464295992928167, 4.622475985557803, 5.00525224593378, 4.705863614236155, 4.014050672131201, 3.26971278075249, 2.440278333040976, 1.2446612119674683, 1.0503534900565301, 1.2220426192206721, 0.6449184326394912, 0.13065264890751532, 0.15083434661069225, 0.10259304691346423, 0.4332926803298535, 1.715877971822216, 10.552544670720255, 14.626113387846178, 36.200025004725305, 38.136514848278416, 29.787312592229537, 41.42083698703397, 37.13143102584347, 20.094153342708466, 3.6350180689365637, 0.1260510805032907, 0.043336693723235405, 0.03112112299629277, 0.037082171878747405, 0.020721806926772963, 0.03282143599203518, 0.0474184867925942, 0.054637268185615546, 0.021829332578026002, 0.0034322173028598513, 0.0635504560364831, 0.020545727363036528, 0.1142865976679229, 0.09478998941279228, 0.08304481965399559, 0.08329360670740567, 0.04085864443632384, 0.03691231869461556, 0.07793400962386401, 0.018550849729968656, 0.09798251528052554, 0.04481376486740286, 0.046456885569158106, 0.08449123195943334, 0.05308789749359412, 0.10666404580396992, 0.004275149352202613, 0.040787321650573326, 0.051196951178773764, 0.0422956989777665, 0.008148950986534117, 0.07007686631573785, 0.019461609528309876, 0.05660481563198471, 0.024296325300970388, 0.1996926458612565, 0.08862744791493302, 0.20218194131889652, 0.13373298119873772, 0.18440706204743157, 0.17374296492386251, 0.14444285973666177, 0.22149780645005165, 0.12217079154065541, 0.20974247836537901, 0.1747508148752874, 0.10568598135104103, 0.11028872953066904, 0.17603545239375484, 0.13469831327036505, 0.09694580679699298, 0.11532362024750441, 0.13750536667723812, 0.12012541339161897, 0.1297946304323212, 0.1770449417733377, 0.10827178856538189, 0.19282931011290322, 0.08373573137026641, 0.22495189771777202, 0.18419456457899464, 0.1214892797232155, 0.17980291958778136, 0.18248955929471602, 0.14501748696690606, 0.11936341637685416, 0.2729604675644829, 0.1410151831805706, 0.11488744808781533, 0.161574914630863, 0.11450232802740029, 0.15144364698038948, 0.17058643752769118, 0.13093744975424584, 0.5554554815734587, 10.806087659251306, 39.490454273839156, 56.68844323004446, 56.23438573652699, 40.268370105374245, 34.658051075473914, 41.75549753250615, 30.790496026316, 17.450511147899014, 6.171900456951511, 1.7381847361403129, 0.2747156362860434, 0.3768760350442702, 0.11650521894015613, 0.31393005302356136, 0.11061522854311813, 0.2679429593826494, 0.2432996728607724, 0.4248321585116848, 0.7480576466168127, 1.830149975515181, 1.0632178836291837, 0.5011757619438634, 3.1079802205485687, 1.0258560207101608, 2.4431703455986518, 3.9703059484881744, 3.2829154787525057, 7.750589241904597, 10.715433839828739, 16.953644906320882, 21.86014952198152, 24.879972511722197, 37.031026194172526, 39.62640362401163, 47.60245707727248, 54.61671790769024, 59.06477981998075, 64.13669078580796, 60.12293723321731, 60.649515428850734, 57.41464653322774, 60.19142966116629, 61.93817092526344, 60.17415554292741, 60.83035630564536, 60.64820535721318, 58.165556846126435, 56.248098342649406, 53.63750603891189, 44.39735112651702, 56.26384273652108, 61.63115916713592, 62.526816706503595, 61.62407928897489, 58.14196771191013, 52.83976262615573, 52.45559000199842, 51.98964772685882, 54.320614261011926, 51.48862769526821, 55.8151275111783, 57.57270628406156, 58.305683520532426, 57.454819448532604, 58.20238005730414, 53.83888444592876, 53.47923448008876, 48.32777784716699, 42.602537293587964, 35.04332196327948, 28.11629072312386, 22.769711863610056, 18.39208395250382, 11.233043536063164, 10.997723879352694, 5.917514158833412, 5.454031700088132, 6.899124556972135, 4.995336494138164, 4.384209648255379, 4.903526065811034, 4.649259399983191, 2.2732380705495037, 0.5460623243162709, 1.849710100120114, 1.3858344237650595, 0.3149120551684211, 0.3436181357791347, 0.31532479269850644, 0.7679168519473846, 2.775393138008733, 10.070764845417393, 17.031611819421094, 43.88009640478319, 38.4008002281189, 37.713789247697406, 48.09440074428436, 46.48558178255635, 24.556163203331735, 4.824984035184307, 0.30298057282643936, 0.1629778820901148, 0.10261510258480426, 0.08846715933853581, 0.17556751056784586, 0.11135220512627594, 0.1428716134039625, 0.17145300554412027, 0.16415819375505372, 0.16248985343883116, 0.12664737270003365, 0.1325424192773719, 0.1292706569356303, 0.16783610527073184, 0.16318938364425015, 0.24863981131103732, 0.2271648346176071, 0.1114867837919343, 0.30666419935803263, 0.09895393009027166, 0.2696829595633092, 0.23131859398657278, 0.11357619667485838, 0.3125552929216816, 0.1381838141429809, 0.154161328570016, 0.13320376766064476, 0.10886202866752302, 0.12316734169519718, 0.18197120888338936, 0.07560465034217605, 0.1954208323431592, 0.17411365954866334, 0.15183125682655843, 0.14951684392027317], [0.05376670502066132, 0.030739277961754033, 0.015971823351367587, 0.016059805676641486, 0.01711843002046789, 0.027774264885773583, 0.06595605638839545, 0.05819703745205076, 0.0675102649256587, 0.058315394205912474, 0.03259388106544653, 0.04643627397355534, 0.032990565223078576, 0.05113167282674582, 0.05785733874466631, 0.0678049942718879, 0.05229660910704444, 0.10402594542791767, 0.0186681205541977, 0.07470158589703423, 0.0611464070126174, 0.05173104469694438, 0.07210752791574887, 0.0454990228547925, 0.008481610303504333, 0.04446006207276256, 0.022678232691701383, 0.10201428280842882, 0.04248520614759576, 0.04596073255543748, 0.05342422541411174, 0.034084577083347306, 0.03735981363382551, 0.04778529735161893, 0.012697140299414676, 0.0410371276009227, 0.08644397475666578, 0.027764125712095734, 0.03188634715643862, 0.04504326182687956, 1.5524690886659007, 17.398396576604537, 39.989466051901545, 44.828607882222826, 33.42073940461682, 22.809982838169223, 27.620450181345788, 35.974088638059555, 25.900849757655976, 12.413939756731834, 4.572167665727677, 1.431100046442401, 0.28389909995659707, 0.06481897506502367, 0.03614688194507072, 0.09038724380755618, 0.12362104960747304, 0.133150830985077, 0.32022251537249935, 0.3251999111906175, 1.948415074617632, 0.7627662283278281, 0.14412445827357231, 0.2792489462562146, 2.3545108062605706, 4.586352427159587, 0.4796969241672947, 3.619492102053858, 2.2925447119820506, 4.897684676031913, 5.584071999596012, 12.248756981665089, 13.525280587134825, 19.78028920388991, 27.638832369158347, 34.5933319676307, 39.76063497604863, 47.01879270615117, 51.622823745973655, 55.32432525388656, 57.907225624207534, 58.40767298975299, 57.11310255912043, 58.659395017931544, 57.42965352150702, 58.15058908154888, 55.33003622485746, 56.75883016278667, 56.626681589311175, 57.453356404458326, 38.35129991654427, 53.031852860604566, 56.06328410487021, 56.95388963145595, 54.57340709624752, 54.836402016301314, 52.98692995502103, 51.5783715248108, 51.40856819768106, 53.50382774106918, 53.509930949057306, 52.57723839052262, 56.20799210763747, 55.32487830808086, 56.05063053869433, 53.41484485134002, 50.7065619960908, 47.67942574716384, 37.514760340413744, 31.662442837992025, 23.200280243350615, 15.533625310467137, 11.770430803298952, 7.089555628838078, 2.955868253784795, 3.397453835894985, 3.522613971464096, 4.288250823174754, 3.1895971442422564, 7.005105037843028, 4.025578763215773, 4.782920047160118, 2.150418119084451, 2.2136143667082635, 2.2944416682566366, 1.370013421100955, 0.7228966225539485, 0.24351468309760096, 0.10987245267437351, 0.34174241546180945, 0.8630331641724034, 6.2667360132740395, 8.0595445344525, 26.171695301609656, 24.699774903635827, 18.104201593706687, 37.34718884191206, 40.286232579138975, 27.460962687769246, 8.786900524170168, 0.3177877040880342, 0.030716668791888706, 0.05115964652730092, 0.06533114314680138, 0.04505628915203195, 0.0658835461663623, 0.06972303328615043, 0.04816449555237928, 0.05595385923140472, 0.028808732562127615, 0.014180438780796625, 0.02084764261399546, 0.03723287286477224, 0.0027801828729289197, 0.07588401962552341, 0.02898751641623676, 0.06511821666912687, 0.06487579580636756, 0.06566046136281183, 0.03271814052676482, 0.05730606187435408, 0.05101600121105871, 0.016982933964520212, 0.05803669524949886, 0.047778601743160724, 0.05505499294808796, 0.06435782843900305, 0.04517289539498668, 0.015620143028847394, 0.012437579176959493, 0.06014410353776428, 0.007916520867917326, 0.06929294386458013, 0.08735957240024883, 0.03361298867891874, 0.08240339721763328, 0.04434723264327453, 0.026264351552292228, 0.05798600704198884, 0.03322029200893256, 0.013774900561979702, 0.058657873812462055, 0.03216376483079887, 0.03192764504121677, 0.08546941132555086, 0.00943893962915266, 0.04966667139782541, 0.013449396506222266, 0.06317507295358567, 0.015368175752941641, 0.07038308698083125, 0.05607402778320736, 0.020905388406507915, 0.04014879885700442, 0.02734211085724735, 0.05847205918642783, 0.03410491671773695, 0.008677332361619319, 0.05088038449626296, 0.020605836536795385, 0.030490755208677826, 0.02544770182500924, 0.01981541191438033, 0.06477422786936646, 0.02772394248524741, 0.01953512332552383, 0.05116400173715046, 0.022731301517436103, 0.029123715357854966, 0.0033092106347002333, 0.03804731625883329, 0.01784659850771629, 0.06538735867868509, 0.022463101796024752, 0.03108389112317274, 0.02919584062070616, 1.8984768058984511, 20.004890003511985, 45.55419145091888, 51.13714802649714, 35.58362453214584, 25.371539631197532, 31.738795695766328, 43.59641098207043, 25.507926325644217, 14.230410956567335, 4.614620458695197, 1.3270170121423661, 0.0797508484233291, 0.23576602550043216, 0.03736684249053079, 0.03617697387873646, 0.2599284845975138, 0.4671400382874474, 0.23301652061843106, 2.4125731616250934, 1.647739292633149, 0.7736277616312428, 0.9264524353127327, 1.6250629675003792, 5.86245830020597, 8.903604765092174, 2.6002465621117623, 7.471871010718807, 2.945031970739365, 5.835348348463736, 9.071667540457941, 14.66386227838455, 17.103740284519812, 24.433865662544008, 31.250550823826945, 37.2766960051752, 42.390631245028594, 49.79112002157396, 53.63433284144248, 56.08474731445313, 58.291370791773645, 59.837726008507516, 57.68690609162854, 60.172865083140714, 59.57060083266228, 59.138920460977864, 57.37294389355568, 57.33496358317714, 55.73636239574802, 56.95419165395922, 43.40769398596979, 54.17959720857682, 59.06912580613167, 60.48065739293253, 56.617805265611224, 56.29309577326621, 53.716043656872166, 53.00613780175486, 52.62413424830283, 53.794934288147964, 55.23483637840518, 54.31509548617948, 57.438769109787486, 57.05422386046379, 58.46383348588021, 55.826431782014915, 51.6431769247978, 48.118688060391335, 39.36784490462273, 34.22842210338962, 25.757320427125503, 21.167843341827393, 16.812843584245254, 8.78748986028856, 5.323498652827356, 5.329648438961276, 4.876796583975516, 5.825487019554262, 5.958367605363169, 7.767864340736021, 5.7175286835239785, 3.151375117801851, 4.490870170054897, 3.448690041418999, 2.7096404856251133, 1.4093201054680733, 0.5336698409049742, 0.4311632010484896, 0.031739350205527685, 0.2886248512133476, 1.0334029673568665, 6.4719181387655205, 10.389866329008534, 24.553915685222997, 32.53028096691255, 21.55151782497283, 38.81954070060484, 45.981984753762525, 33.321295553638095, 10.234703248546971, 0.7154212591628875, 0.02058831993640671, 0.030844909995193445, 0.0026099681910578044, 0.10196418065818087, 0.0979144636902117, 0.10381134121768898, 0.059516026353042935, 0.03654815113892959, 0.05696343288065926, 0.019128133370090398, 0.01165567057943272, 0.03435121398539313, 0.04002579577988194, 0.006453212014504619, 0.04326874555479135, 0.03009056619879219, 0.12625983946265715, 0.045975560187211925, 0.0514652926264511, 0.09284704488011138, 0.05039715538582495, 0.09066125047543357, 0.026810166215704336, 0.029280215629466602, 0.008407699098179658, 0.018776602434715437, 0.011639816389839736, 0.11406076260872426, 0.0394655863243726, 0.034772658104737925, 0.0280942885400427, 0.06455640608985579, 0.05444352454956501, 0.021005657824477362, 0.03772061423308427, 0.11750680229236042, 0.1212761234191637, 0.2465780388804213, 0.14959109316189445, 0.10924399244569002, 0.16615397537187224, 0.10497183418802677, 0.1342967606239742, 0.27026037535359787, 0.15238884626136673, 0.10410090713130851, 0.14253042848600497, 0.12759850916242407, 0.13121730167298548, 0.16913932808224233, 0.19247974419305403, 0.20486095079010536, 0.21832266311732032, 0.13056650998130923, 0.1642738270663446, 0.301953494068115, 0.21372650329384113, 0.24982406066790705, 0.12289914963466507, 0.12291526046371269, 0.14899231884027683, 0.1409105355701139, 0.24713244138946458, 0.13342525900131272, 0.12369932081069678, 0.16165225886769835, 0.056089755568292834, 0.14550822756944165, 0.1951715779761153, 0.17638751576023717, 0.15566624701023102, 0.13667236863365098, 0.09231318118831805, 0.16761441474720357, 0.13647657188196338, 2.6387583536486474, 23.378391150505315, 53.09364195792906, 59.29002584949617, 46.22341448260892, 31.79085143150822, 37.09251326899375, 46.13168201138897, 31.088203922394786, 16.722721245981035, 5.874593132926572, 2.095296560756622, 0.4293205450859762, 0.4379318636511603, 0.1388868377093346, 0.24105223136082773, 0.33266767498946964, 0.29698936689284544, 0.9366128449478458, 4.461719114934245, 6.701822473156837, 0.9822645146519908, 0.7352367668382583, 1.7971020456283324, 7.124856470092651, 6.484050029708493, 2.2908708405110145, 7.515926091901719, 5.244068205356598, 6.212824015848099, 7.489985006470834, 15.971824661377939, 16.980889689537786, 25.216327521108813, 32.30472310896843, 38.736680630714666, 44.30177865489837, 49.30357333152525, 53.36798037252119, 55.67415752718526, 58.33872948923419, 59.849744150715495, 57.68468210774084, 61.250912835521085, 60.39061546325684, 62.63459951646867, 58.05615801965037, 60.001688926450676, 57.690687256474654, 57.69567258896367, 47.96143631781302, 55.70439115647347, 58.648875221129394, 62.04418866865097, 58.12975345119354, 58.875611751310295, 57.49941287502166, 55.43297490765972, 54.09335605559811, 58.200709127610736, 58.222964655968454, 56.91880010789441, 59.305734942036295, 61.816848093463534, 59.3251585191296, 55.85382953766854, 54.93149988112911, 49.011627397229596, 41.136186661258826, 34.35617369990195, 25.205401758993826, 18.52120053383612, 14.829494164836023, 11.099629998207094, 4.925918386828515, 5.70788896852924, 6.178859722229743, 9.528966872922837, 9.801467657089233, 8.887997654176528, 10.469680678459907, 11.046506397185787, 8.29450382340339, 5.213290347206978, 8.021926553018632, 6.616161340667356, 2.161313973126873, 1.1193347433882377, 0.3495860526398305, 0.622561841962799, 1.6377336940457745, 7.6846238009391294, 12.108202768910317, 33.57883445678219, 31.57655665951391, 25.8778509401506, 48.70696906120547, 53.94500417094077, 40.7637183896957, 13.652636024259753, 0.9676030013830432, 0.21019224858572408, 0.1633393376945488, 0.15156687988388926, 0.25701344343683413, 0.20968376538686215, 0.3159209623211815, 0.24849177248054938, 0.13025336388138034, 0.13851044339037713, 0.12694680582611792, 0.12012919786596492, 0.1553446279778596, 0.11507759111062174, 0.15434140519749734, 0.1146782064930566, 0.10449252361732145, 0.21115614041205377, 0.23996492276989648, 0.18453378831186604, 0.18383330815742094, 0.119318324441631, 0.18282597914578455, 0.2665723974425947, 0.13992517796014586, 0.10111344001826741, 0.14733252806528924, 0.09184490228372236, 0.1901678440551604, 0.11795409804871006, 0.21108376042496776, 0.15168260512573106, 0.14509429494219442, 0.244321143855491, 0.09411289792267546, 0.10106763562127467], [0.028584077278332367, 0.03253823626906641, 0.07426021966121851, 0.07357769660771855, 0.027004202880385905, 0.02797107478874105, 0.032422534009862336, 0.06283681832193848, 0.00924191234873668, 0.03459875614592626, 0.0313527017997037, 0.02984932894187589, 0.025805246550589803, 0.037766736556565574, 0.05708809070769818, 0.07026808186163826, 0.042898721256924253, 0.08450971000016698, 0.03405968688668744, 0.04298538878379811, 0.03285392578090391, 0.07239949934545063, 0.023081246650807803, 0.040821163584628416, 0.023032751369981036, 0.02635124699032355, 0.09018784644262445, 0.08965805067770904, 0.03682939350725182, 0.067925714406996, 0.009849345379118479, 0.04838098050846208, 0.03905667923390865, 0.00394703557005062, 0.048199823697007475, 0.04646909318023151, 0.03066390448610389, 0.03593466792916579, 0.06689711113370235, 0.02595047766883527, 0.16581685071991337, 5.79511022375476, 24.97669423780134, 48.00977168544647, 36.18450026358328, 26.47020140001851, 18.73896856461802, 19.570265893013246, 36.84642768675281, 19.249669005793912, 11.295221928627262, 3.6200824187647913, 0.6762717147507976, 0.014427587363658654, 0.26596819921847314, 0.008261760306214134, 0.45490809626156287, 0.73062694000621, 0.34117403950902725, 2.352664105353817, 1.9554003255982555, 0.41308643716958265, 0.45519243745553883, 0.8787081198346232, 5.446452210026403, 12.467937065709023, 2.327875461309187, 4.941023924658376, 1.9285833258782665, 3.265461666930107, 1.1130159276147042, 4.670859892522135, 8.538005544293313, 11.396220018786769, 16.29761182492779, 24.6224336085781, 30.162910915190178, 36.49742303356048, 42.418821319457024, 50.73062573709796, 54.98115316514046, 59.70467921226256, 57.357242645755896, 58.731809816052845, 58.73920740619783, 57.144430529686716, 56.78592197356686, 57.926515840714984, 56.88536190217542, 55.09995783528974, 43.61031186196112, 52.7630881340273, 56.963154269802956, 59.57080087354107, 56.08983070619645, 55.28095952926144, 53.151767561512614, 54.040462893824426, 54.50281227788618, 54.86635715730729, 53.31071376800538, 55.369765912332845, 55.69606396459765, 53.10647203076271, 55.913700595978774, 50.94430077460505, 45.30105344710812, 37.40551448637439, 30.10544623098066, 22.674657144854148, 13.941286187018118, 11.519478540266714, 9.637580244771897, 2.1113258167620628, 1.524177155187053, 1.9482052278134132, 2.3154028144574936, 1.8393246444963642, 3.964859002059506, 10.357789185739334, 3.977555714307293, 2.2969237931313056, 3.4374985387248382, 1.8910137612012126, 2.0152059293562368, 0.264691774162554, 0.07585356763053326, 0.1080317349143086, 0.26799490014391564, 0.9388001791892514, 3.5268153202149177, 8.542178946156657, 20.1081895443701, 32.78894362911102, 18.919174017444735, 35.656659064754365, 36.59148147029262, 32.24295558467988, 13.100828163085446, 1.7046548450185408, 0.07678152993321419, 0.03380597388792423, 0.04392158653166506, 0.04448994333224912, 0.022487834944660147, 0.04992384328356674, 0.0029349800353238903, 0.07818263579880999, 0.021234660657242905, 0.09651774750842203, 0.017893394988570965, 0.06266062576023322, 0.02279184927653161, 0.06809783904182334, 0.04407038761963768, 0.025659145922550274, 0.09557024996367194, 0.025723146822964473, 0.05391295120540646, 0.09215871488014538, 0.021112548157332406, 0.03599172232732658, 0.02156829386348686, 0.03706000129421873, 0.05304251827539937, 0.02815550854129176, 0.017138836687550913, 0.028475128084180817, 0.01517990006945066, 0.016963050152445515, 0.023213065484718933, 0.053531290031969554, 0.04136821164959862, 0.049908364477056655, 0.025494609388612935, 0.04305380043543635, 0.04316662220404514, 0.04751592934612305, 0.026538281611377196, 0.056324488738732, 0.014193445996141002, 0.06653721068775462, 0.06105279106827033, 0.028305671350549788, 0.03476562541759303, 0.045838372992171396, 0.03298278560020751, 0.028239561793124004, 0.0720760723455779, 0.004444689397895408, 0.05081245548001701, 0.028565966959802375, 0.019715153987729744, 0.04632923233833525, 0.014337320181150592, 0.04417780463794067, 0.07416162414536362, 0.01838694330334904, 0.01898581147073738, 0.027878110019129612, 0.059062054140433196, 0.015146366485785094, 0.048762978760585676, 0.06322493761657708, 0.06730203456696003, 0.08566155383783965, 0.030305833075075384, 0.07734923938950224, 0.009368497844515069, 0.04543979276692675, 0.05891793768011755, 0.042794238355371265, 0.03757513030582378, 0.02849703819881524, 0.03384391439237422, 0.0117745942383584, 0.3690774744797138, 6.969096208772352, 30.778838742163877, 52.918821919348936, 41.878769782281694, 24.62170404772605, 21.305999025221794, 23.80319952964783, 47.51635712961997, 24.392410132192797, 14.073930940320416, 5.012932246731174, 0.5863736257437737, 0.0479714758694172, 0.1962519458104526, 0.01837842249041123, 0.4130423105051441, 0.6158683172637417, 1.2727084876068178, 2.3274003642220653, 2.520592539541183, 1.4011643947132173, 1.3551815911646814, 4.070246714738108, 10.08247115919667, 12.26096437823388, 4.672647512728169, 7.150291079475034, 4.1829052759755045, 3.5153220401656244, 3.185893446207047, 6.765773286742549, 11.640350299496806, 14.384108051176995, 20.73921653532213, 29.137758285768573, 34.062627438575994, 41.15868537656723, 45.09563107644358, 52.4682867142462, 55.94789974151119, 60.61180183964392, 59.572891496842914, 60.80675540431854, 60.278474900030325, 60.047353159996774, 58.81966306317238, 60.27040658458587, 58.22471795543548, 56.66812143018169, 45.73166301173549, 53.298009211017245, 58.9093872808641, 60.38909358362998, 59.35253666293237, 57.68215610134987, 54.52098854126469, 53.877868883071415, 54.74502255839687, 55.566692429204146, 56.08142114454701, 55.29865726347893, 58.20532575730355, 55.16277459359939, 56.96498601667343, 52.76501401778191, 47.80785983608615, 41.21281016257502, 32.51887079208128, 25.431204765073716, 17.593414860387004, 14.815077493267676, 10.811299508617772, 3.4524028099352315, 4.865196664487162, 4.740943822168536, 4.572709443107728, 5.951408830381209, 6.799382115564039, 7.413678236546056, 6.767585421762159, 2.302075336056371, 3.713885411139458, 2.1809454358393148, 2.2265314671301075, 1.1664486604352151, 0.2321556216526416, 0.11900495617620407, 0.13272761337218747, 0.7608609983036596, 3.318047412941533, 12.4294517501708, 19.881127457464896, 35.82405013422812, 24.133674906146144, 32.18673233062991, 44.689191156818026, 37.96254204165551, 17.11174191967134, 2.3504474759101868, 0.030439741413799987, 0.014151722932564876, 0.027839863079509912, 0.05913543770270002, 0.08623427350915248, 0.04679185368361012, 0.07006742045163147, 0.08937920999502943, 0.06432548420683992, 0.04272766148431167, 0.04524334484050351, 0.021361210721454794, 0.08587523874255919, 0.006061424595123578, 0.07343905001518226, 0.04390713811341313, 0.0717019839512725, 0.062070921919639074, 0.04118289115027555, 0.03250842395749304, 0.028089397068646167, 0.02849665323963329, 0.052937196507569284, 0.023611191802868442, 0.08005293987451062, 0.09293860004794213, 0.02663034814289741, 0.039085901657780336, 0.054389404268154216, 0.03338523456946977, 0.015726215562843267, 0.03109981426067891, 0.012790437359663268, 0.03670289706919463, 0.03531705933592973, 0.07592711973214343, 0.16816314820560718, 0.1554497352410709, 0.1308486754855802, 0.18582156679082304, 0.11310840806653423, 0.1991776815585552, 0.21087207500973057, 0.08578232759910245, 0.09286271903904215, 0.12644553151462348, 0.13967287456316335, 0.15053515863274375, 0.15553717651674825, 0.09327815319862097, 0.1574363697680735, 0.24235543885057975, 0.11875594695729595, 0.20412746756788225, 0.14953254872272093, 0.14958764576623518, 0.15672090493382948, 0.11329028500063766, 0.08296506224019874, 0.15343495464373022, 0.16628373534448687, 0.17037986957978818, 0.21655949643783032, 0.2044610988589064, 0.17141441003449503, 0.19506951974284267, 0.19218818645083136, 0.15678756990500037, 0.12062086543488888, 0.06257768525111099, 0.12213205047432454, 0.1042386420792149, 0.2166992155534606, 0.1341913469255932, 0.2577779532199906, 0.148272380052555, 0.573951356833981, 9.397906757170155, 36.089739722590295, 60.51283259545604, 48.91409766289496, 34.698447565878595, 29.20936311444929, 32.25267914033706, 49.772461306664255, 26.678302749510735, 15.518252561169287, 5.4423366631231005, 1.052801539340327, 0.18326942147987504, 0.3676727450182361, 0.14107029554584335, 1.3342780547757305, 1.4444595166752416, 3.094889064950328, 6.096741960894677, 8.28064707017714, 4.727368989298421, 1.7659764448481223, 5.310171909870641, 15.666094537704224, 24.681732000843173, 7.897267255090899, 9.793970046504851, 4.038714045478452, 6.117971299156067, 2.253876270786409, 7.166840049528307, 12.776360877098577, 15.287462261415298, 19.158656289500577, 28.73700776407796, 32.7362681588819, 40.41084627951346, 44.82366569580571, 52.09164504081973, 56.314319718268614, 61.86891755750103, 60.68702897717876, 62.85855900856757, 61.247825930195475, 60.21533258499638, 59.201270457237, 60.91423226941017, 60.095429651198856, 57.79483795166016, 49.471254656391764, 55.1672068718941, 59.04236347444596, 62.341739669922866, 61.509436253578436, 59.214794789591146, 55.960945544704316, 58.17312309818884, 57.951940644171934, 59.849548032206876, 58.15461343334567, 58.595887922471576, 60.66522452139086, 58.643493729252974, 58.337560622922844, 55.57359580070742, 48.00744571993428, 41.89149395112069, 32.88850319000983, 25.8379525907578, 15.708665001776913, 16.598972428229548, 12.35289296796245, 3.34473007148312, 4.024718048111085, 4.59838233647808, 7.811878237032122, 6.8457543369262455, 12.306090266473833, 20.81291590967486, 12.690799274752218, 6.793666241630432, 8.502755203554708, 9.372938909838277, 6.113442922792127, 1.484578621964301, 0.9527208547919028, 0.5782073123320457, 0.5962753428086158, 1.3091355393971167, 5.105222184811869, 12.3829157698539, 27.32457991569273, 40.83550953095959, 27.37973236268567, 45.23927219452397, 50.382130992028024, 46.672074794769294, 21.768728879190263, 3.284375826197286, 0.11825107203255739, 0.09446416455771654, 0.1081404964169187, 0.13084063156237527, 0.1691549256323807, 0.11946896797106152, 0.10655947480230563, 0.2254923421048349, 0.21287436837390547, 0.13469576985845644, 0.16141297896542858, 0.1495137182815421, 0.16482646757316205, 0.17800552409983453, 0.22002209128151018, 0.1426090597505531, 0.21231042040932566, 0.15157276343914772, 0.13749605104807885, 0.18458909985999908, 0.07961294493607937, 0.17624485486697766, 0.16283468493530828, 0.26205195774955137, 0.19686182840697228, 0.20764742707533224, 0.12089876382942162, 0.11458478973156984, 0.1145872718564445, 0.1124127159616159, 0.20125973999740618, 0.10895513899384007, 0.10958145417633558, 0.12424237755758148, 0.12130013261471065, 0.3249081849090515], [0.021765590232286244, 0.049199729316657594, 0.077979001967657, 0.025043584699291858, 0.01375593605541414, 0.030721441519656972, 0.045700706992178194, 0.059142719368420305, 0.036162337768943086, 0.015355268129027419, 0.025178245719402068, 0.03710169179905807, 0.014999317823939267, 0.053212700877338655, 0.029154552312027064, 0.02904440802071364, 0.08849060928989803, 0.0384780683464581, 0.04700497934414495, 0.14100111780628083, 0.06043727389506756, 0.04327888089802958, 0.025463711147406892, 0.07788305711602012, 0.09239700652899281, 0.03277600314768572, 0.029520688713678432, 0.03792132543880613, 0.02608671108441007, 0.017500895586225296, 0.10666626745895033, 0.07120553599370104, 0.07451288311952546, 0.06502800981604284, 0.06538426368347099, 0.016120518144640713, 0.046328791837778785, 0.06663244307762192, 0.03501576844662909, 0.038738430988404064, 0.04187040143616257, 0.9917726463848545, 12.822457551956179, 34.05860700914937, 45.98885282393425, 45.01597950535436, 30.32739943073642, 30.49453554614898, 20.099764293239964, 19.09270359623817, 12.699435353279116, 9.495940516071936, 3.7349723183339645, 1.041239985535222, 0.11663603611410626, 0.30546968442297756, 0.5159200739956672, 0.7582597927220407, 0.446101731710857, 1.6541825210855854, 0.2700577604193842, 1.4056108915998091, 0.9688433896630042, 3.6483487342634513, 7.408718889759434, 13.477134473862188, 2.665322360492522, 8.710289770557035, 2.575745967126662, 1.3735294582382327, 3.2365099172438345, 2.5199875139421035, 5.004939927208809, 5.577748158285695, 8.392270861133452, 13.524034254012571, 19.651490334541567, 25.213105294012255, 30.48657705706935, 37.422466970259144, 45.722712163002264, 52.182718553850734, 55.422215846277055, 57.380474844286525, 58.98790528697353, 57.99596140461584, 59.5599712094953, 55.70484222904329, 56.883192831470126, 57.517271426416215, 47.47303062869657, 54.968770242506466, 53.33442057332685, 60.9412613222676, 57.324031937506895, 56.36498105141425, 55.87431999944872, 56.307773282451016, 55.67815442239085, 56.49554498734013, 55.37969343123898, 60.020641819123306, 54.29571505515806, 53.74858756219187, 53.199240007708156, 44.268148253040934, 41.78199314302014, 29.88673487017232, 23.088269118339788, 13.572853053769759, 11.109312368977456, 6.942727094696415, 5.148492301664045, 0.8566700378733297, 2.4113184934662235, 3.4597572540083243, 5.44448612197753, 7.179954003903174, 6.466754338433666, 5.680723613308323, 5.979781295022657, 1.7611627160541474, 2.477406018203305, 0.8594547368345723, 1.4608289157190633, 0.6999889388680459, 0.10315566188505582, 0.21340773410854802, 0.612482269925456, 3.3181089451236114, 9.38895590843693, 12.227786029538802, 29.27880475597997, 25.28901884632726, 29.66125742081673, 40.168247684355705, 34.41069856766732, 22.617423880484797, 5.874604409740818, 0.30526299390100664, 0.02599212029317935, 0.030720309624748848, 0.029304263129409765, 0.037644874950450276, 0.0363263878370485, 0.0414517535377414, 0.18585723584457753, 0.029244000738066052, 0.04096180583620745, 0.05102751934300027, 0.02044677561629684, 0.04828741819026971, 0.014408755964869934, 0.0943770680216051, 0.0149134527741661, 0.06945268085767185, 0.05242408230720509, 0.06844850812828349, 0.14829504093335522, 0.012513420923853354, 0.008351089988624858, 0.03947950614195678, 0.10589420404886046, 0.01953176594519567, 0.06334420218462906, 0.04810106347224886, 0.03223037617581506, 0.08375898213876833, 0.04256056238626761, 0.025970459157120318, 0.04149918970201285, 0.04014176616985952, 0.00910418027366001, 0.03169712152392153, 0.0463363646169103, 0.05419400971262686, 0.02559905015533009, 0.02848789302421914, 0.04296728995658698, 0.07156052581605411, 0.08585395682002268, 0.01640146365389228, 0.026013716311764815, 0.017504025055395982, 0.10622136955780369, 0.04418991648802354, 0.0804880548328642, 0.10850556795635533, 0.04145436972800282, 0.07663110856928172, 0.06665793082286274, 0.05724600058109049, 0.07015723659987412, 0.04660845223453738, 0.03646751655445945, 0.06456826513092365, 0.09287590341221902, 0.01652814778349092, 0.02984255097896582, 0.05113756787332316, 0.0725765499256311, 0.02021862505634706, 0.07832517411800162, 0.011745877432516746, 0.06233078660443426, 0.05258874524564994, 0.036836767103523016, 0.07982921921798299, 0.025099045634570143, 0.02637635169160222, 0.04581106961855004, 0.02249967674874971, 0.05444939661350462, 0.052956888797662915, 0.02356377287557529, 0.020248090713134697, 0.013563583826556081, 1.4018638023445684, 15.829467138936444, 39.572310216965214, 50.09426432271158, 45.81301296910932, 29.597654227287542, 31.516848379565825, 27.736648436515566, 27.84257596538913, 17.484180773458174, 10.185105858310576, 4.773665214738538, 1.0852130646667173, 0.3535193931912223, 0.007262614071218958, 0.26737234645312835, 0.15249861133915765, 0.8171321788141805, 1.34592859735412, 1.0286311588941082, 3.03187104002122, 2.776097203454664, 4.583055675029755, 5.794985198205517, 8.77525108475839, 8.25553801751906, 8.318946073132178, 5.139847888100532, 5.305454769442159, 5.354686888956255, 3.420579394986553, 6.8245058771102665, 8.269092748242041, 11.203410029411318, 17.92957571245009, 23.60930500491973, 29.320077896118168, 33.80408833103795, 40.36090274010935, 48.391990969257975, 54.81266383201846, 57.34614233816824, 59.7375447519364, 59.28210658411826, 59.6513859687313, 61.63869404023694, 57.80645208974039, 58.04182175667056, 58.007136237236764, 48.04675963617141, 54.30029246114916, 55.29985358638149, 61.52337243480068, 60.06265824840915, 59.109502684685495, 57.81952534952472, 56.68317156453287, 57.79458299759896, 58.33138681227162, 56.22206164944557, 59.98774097811792, 56.84141566676479, 55.31027532392933, 55.39877968449747, 46.48729978069183, 44.129410097675944, 31.765050080514726, 25.29775396470101, 17.184258699417114, 12.637076531687091, 9.682183477186388, 9.27946980922453, 2.89182722568512, 5.483443592825244, 6.480533134552741, 7.603008102986121, 6.8288827519263, 4.0096514888348125, 4.224624095424529, 4.983700292725717, 2.971013995908922, 2.3718631267547607, 1.9524761986347938, 0.9839701328066088, 0.6532676265605035, 0.04792035865266958, 0.2136075145174419, 0.855781804890402, 2.9535099287186903, 10.896353164026815, 15.315467984445634, 27.74815078704588, 31.72982131281207, 28.784197799621094, 44.34392452239991, 37.96228316522414, 28.030522215750914, 6.619661565749876, 0.478022899478674, 0.03001372374954724, 0.07883430849159918, 0.03907251044086391, 0.009869171734598857, 0.033193704927520405, 0.04279704223717413, 0.05702727098738956, 0.07136276021840111, 0.09050316823225829, 0.04549767070960614, 0.015147896746413843, 0.016123484820127487, 0.04119948461471547, 0.04817243605371445, 0.05484446432561644, 0.09197304581081675, 0.03240803962633495, 0.029934450886362506, 0.013407041420108609, 0.03559352897648369, 0.06272670467414203, 0.0278720042983731, 0.06793100807455278, 0.038566356149291804, 0.028912259768995068, 0.06293655913924018, 0.06928773446669502, 0.021865298490851157, 0.01743510970094752, 0.025763663298059857, 0.028934459081820907, 0.015955628252648298, 0.030523595482771917, 0.012377311997566254, 0.05869447749348418, 0.01962303383005483, 0.14074227201842493, 0.17060707593637128, 0.16041346405061985, 0.2562440000474453, 0.2243963307550838, 0.12730104488230523, 0.11706676904953296, 0.15643028181887444, 0.14331432029364571, 0.1148752366463023, 0.15925556811834538, 0.15304978095716046, 0.09511609772039999, 0.1985269358321544, 0.2105078002017352, 0.2196462179023412, 0.19523746153760344, 0.1996582791569733, 0.12734742384524117, 0.20397080258736688, 0.23055979921933145, 0.1482796119225602, 0.10888270538059935, 0.2174092718069592, 0.19894304414910657, 0.11958819423471728, 0.1319522711057817, 0.12440314110849174, 0.16095052232905743, 0.12094843697043196, 0.17716961492213512, 0.14544657281329557, 0.16991434859171992, 0.1216054492960534, 0.17724158122174202, 0.1285515608446252, 0.13118543241533542, 0.16894147821491765, 0.12322196376419838, 0.10346743668760024, 0.1771901001132304, 1.9035757645483942, 19.112693955821378, 47.97019889277797, 57.987916623392415, 57.779395580291755, 41.40337459502682, 40.62688258386428, 31.60404855205167, 28.16106850101102, 20.202893210995583, 12.947280118542334, 5.689107189255377, 1.3970832911229905, 0.7751998966259341, 0.6697901819021471, 1.6388904255244041, 2.5105632841587067, 2.1083249584321053, 5.191671713705986, 2.8252042974195173, 7.400511330173862, 7.977117886466365, 11.294088363647463, 18.18184098889751, 25.311078256176366, 11.670648647892861, 18.716128603104625, 8.53391549279613, 4.773949586576031, 8.062307353942625, 4.666107941058375, 9.019549046793292, 8.069980490592219, 11.016891521792259, 16.981870282080866, 24.831178226778587, 29.435148469863403, 33.99269550077377, 40.181972057588645, 48.13706436464864, 55.40057613003639, 56.44932377722956, 60.9551896587495, 60.56623174298195, 60.98882006060693, 62.517281424614694, 57.6806773677949, 59.065215203069876, 57.27800684590494, 55.34274470421576, 55.648811171131754, 57.17160471024052, 64.0004825592041, 61.96304267452609, 62.02132125054637, 61.13469692968554, 58.164325221892334, 60.914083219343624, 60.1309859368109, 59.92848573192474, 62.33976671772619, 58.68297630740751, 57.37019823443506, 56.32981700281943, 48.85745079286637, 46.85149185119137, 32.96909024638514, 25.903913128760557, 16.715980652839907, 13.706383282138457, 9.901285113826875, 7.852679712157096, 2.662624014962104, 5.665313111197564, 7.757410243634255, 13.760431581927886, 15.502601323589204, 13.510222608043303, 15.365132054974957, 13.559802347613921, 5.08078238656444, 7.607143752036556, 5.373713326069617, 4.252579317938897, 2.427077841374182, 0.8522260537551296, 0.744549086497676, 1.2005427599914613, 4.600855390871725, 11.757373232995311, 18.708423106901108, 37.79527648802727, 33.18686023835213, 39.48532773602394, 51.5181552979254, 47.49523124387188, 33.79068559215915, 9.403531435997257, 0.6474072378008597, 0.14320849290778562, 0.23821222085145213, 0.18820851290177917, 0.09330197087218685, 0.13017650994081653, 0.17270182079124838, 0.30296246250790937, 0.14467532145640544, 0.13343880343581402, 0.22324136127868008, 0.16430019581269834, 0.1369411735645225, 0.1411208113835704, 0.18588791000506572, 0.10971242456787056, 0.27472651473456816, 0.16215295861324958, 0.143245326415185, 0.19053161324512577, 0.09809549026671918, 0.13422367583599784, 0.1398567969520246, 0.13670979968963132, 0.0871306270240776, 0.09649621277687051, 0.1459633450834982, 0.10088290884009293, 0.16322825494552815, 0.11069664070683141, 0.13794879368957014, 0.12290560775586676, 0.12824768440858011, 0.13370267476045317, 0.19900385620853595, 0.0922165085531531, 0.17634430840130777], [0.05510761552760678, 0.043769073747699304, 0.01779538169953852, 0.039277159338516575, 0.08674369133528202, 0.05465469668589292, 0.03011575325452272, 0.10171184661768137, 0.02336096067372109, 0.0077854920621781105, 0.005957374533247804, 0.05537350549392643, 0.02393726755173937, 0.023813469658395457, 0.02149107028549958, 0.031171422414181214, 0.010593445622362198, 0.033832809947911775, 0.04934445481687304, 0.01672335464747683, 0.08256170162630659, 0.01870417265191434, 0.03977045101384002, 0.025406279450943394, 0.053750004303912004, 0.017688836106249405, 0.04100893173486956, 0.06435816551768972, 0.030610812677731438, 0.011888935733886977, 0.11392457515842493, 0.028762600662547256, 0.05078521722386922, 0.02791355882260588, 0.012705247424873374, 0.03796826364592679, 0.036237946816629944, 0.05026756778299328, 0.03882632808639638, 0.03772932082234371, 0.022447190149837447, 0.07576084034817834, 3.256280378949258, 22.933733617105794, 42.65928614524103, 42.40372019429361, 29.173249852272775, 30.704449030660815, 28.89111964933334, 31.06463832239951, 22.557937214451453, 12.890761706136889, 8.806762426130234, 3.083502914636366, 1.284384770739463, 0.13445265951656526, 0.0597779288317167, 0.1666428313981141, 0.7933642703198618, 0.6150517288234927, 1.1027080613759257, 1.2226249686171933, 0.3556398326350797, 4.5443850275008915, 5.079169802127346, 4.826196047567553, 7.052193091761682, 4.255734374446254, 5.132093362269863, 4.766968257965581, 4.555041126666531, 0.8944799090104719, 1.4713981098705724, 2.797355959492345, 3.3758447631712887, 6.569663603459635, 10.199340139665912, 15.645500133114478, 20.991375907774895, 28.799867668459495, 34.34089606808078, 45.00618926940426, 51.74708051066245, 57.90496633898828, 59.20329832261609, 59.8390753038468, 59.32679806986163, 57.29867381434287, 53.208692919823434, 59.206859834732555, 53.780456819841945, 55.18342587255663, 55.08395848735687, 56.64932150994578, 58.80476197888775, 54.36980862771311, 54.73758574455015, 56.66940796759821, 56.17725249259703, 57.65138510734805, 58.87676885051113, 58.181705244125865, 51.791779841146166, 56.67912760088521, 42.03978700022544, 39.19312292529691, 28.939233403052057, 22.26872713335099, 15.47998493717563, 8.681476039271201, 5.342172076625209, 3.944925761991932, 5.29257272520373, 2.900738850716622, 6.232844283503871, 8.235187780472542, 3.895478647562766, 5.129251114783749, 3.451845588222627, 1.2853377841172682, 4.4613102078437805, 2.2284745112542184, 0.5384132734710171, 0.5757526440485832, 0.3561742862145747, 0.7116245274101535, 0.22391109066384457, 0.5032521360103162, 1.4052859477458464, 5.960946073455196, 7.5821920844816395, 32.096176570461644, 31.30674466010063, 17.6329739247599, 34.86068071857576, 37.10605721319876, 30.587713410777432, 10.218208701379838, 1.5452013044588029, 0.03710704292320917, 0.019542719087293072, 0.018541934381749843, 0.018615505635558117, 0.03953217851719068, 0.025499454894734007, 0.03310298096508749, 0.04613874840640253, 0.07737683387653482, 0.05068913064596634, 0.03574719089233587, 0.10346944383796185, 0.020791308338483496, 0.05213172017266193, 0.06678359222508247, 0.0117558021015758, 0.06363651452345714, 0.03170124307695416, 0.08244210764044717, 0.03333098405311185, 0.03856541386114494, 0.048455179954368266, 0.04061051621852864, 0.048571495083911766, 0.19314784947181904, 0.03217098520948522, 0.0378925243632928, 0.032727222499107166, 0.05646844049014392, 0.07327202752593064, 0.027431103460971388, 0.026943597664696076, 0.0465190421128946, 0.01893325592391193, 0.0069815498183391275, 0.0515300615300094, 0.016250981002925866, 0.045243524871165716, 0.014226945105849976, 0.0063150949802459975, 0.060773437106681455, 0.012184091216524043, 0.04221953834677416, 0.02200026786135089, 0.04504391683205482, 0.06419260625637348, 0.008212786220434693, 0.09703018372097323, 0.12243722925984091, 0.07088129694062857, 0.05207369667327693, 0.032082705067530755, 0.06479112010809683, 0.06909996631645388, 0.02202110545289132, 0.019605444451313347, 0.07108644762587163, 0.01292023946711373, 0.025723422614617214, 0.07810605764989892, 0.05609586128904935, 0.04080547027349953, 0.03286886449542738, 0.0469311974161575, 0.033053035862864025, 0.0789458125889782, 0.06330308624573293, 0.14070574494619525, 0.07640187207969927, 0.04001334302067276, 0.03576500243657539, 0.029560651690248522, 0.02226758849686913, 0.014994159179379143, 0.06756389108035835, 0.09760465007275344, 0.01802571752529231, 0.036815918020663724, 0.17729670890877325, 4.00791534973729, 25.767416607949045, 49.82946511237852, 48.85808229446412, 33.75460763131419, 28.954966029813214, 29.234776150795724, 29.926193914105816, 25.480230469857496, 17.088676421873032, 10.443113484690267, 3.5339405507810655, 0.8503541025903918, 0.10101280670853392, 0.010855858507115516, 0.21749078356210264, 0.35152569533355776, 0.7653788332977604, 2.1383271678801505, 1.2620251769981077, 1.5723851683639711, 3.4551849961280827, 7.620546490915361, 7.46283337954552, 6.428592128138389, 7.75097216329267, 6.24064342629525, 9.25577575160611, 6.545244887951882, 3.5926809858891273, 4.146195813532799, 4.673737931636072, 6.346085561859993, 9.218304368757433, 14.549692869186403, 20.79995051507027, 24.375500794379946, 30.892163861182432, 38.051744584114324, 47.50391144906321, 55.32632566267445, 58.87851038286763, 59.75048465113486, 61.207962882134225, 60.33281149402742, 60.536358971749586, 56.94275402253675, 59.27969432646229, 50.63680264257616, 52.85942939019973, 56.29751236208024, 58.74474579288114, 61.10886027736049, 58.78044328381939, 57.4864572863425, 59.00717981400029, 57.59231813492314, 60.01803736532889, 60.9976375487543, 60.74686865652762, 54.4224742920168, 57.60126506128619, 45.60115006662185, 40.601151835533884, 33.79424710427561, 24.687888160828624, 18.444700587180353, 9.485051035881042, 8.04450273513794, 6.2836223071621315, 6.4190450791389715, 3.609861457540143, 5.467509944592753, 8.250541898512072, 5.911246211298051, 5.3806667077925905, 3.206450588280155, 3.5012902511704356, 1.8017450287457437, 2.5894612698785724, 1.4844777435064318, 0.897580297483552, 0.36426414405145957, 0.2719117238396599, 0.07870766649683637, 0.26990199942261944, 1.486735557836871, 8.306935775664545, 13.10417002247226, 27.8473691017397, 36.75591115028628, 24.178380120185114, 35.64975569325109, 44.70638682765346, 35.10256936473232, 13.629282232253784, 2.035209526938777, 0.10110607791331508, 0.04141638325827737, 0.005471865832430101, 0.031241946553270665, 0.06936727737587306, 0.07875419101647793, 0.035125974024976456, 0.050008584099311026, 0.0764287770876, 0.01646351869097881, 0.07067606964659306, 0.08132813918975093, 0.018550466686006517, 0.10266059288574804, 0.021004684892813527, 0.043533743028679205, 0.07833927779668763, 0.03491051562671219, 0.05867417616349074, 0.04349205635427948, 0.024715122586536794, 0.04158093128353358, 0.03452936007130531, 0.0006193033233660484, 0.1137409438829749, 0.05752766046733145, 0.009904785246978845, 0.04628427829893847, 0.023910151869659464, 0.07284650398838906, 0.037754973276488246, 0.02746121454683523, 0.04335078208016292, 0.08999011148848841, 0.035509355065803376, 0.03943506921190889, 0.027419782596670335, 0.21161439888659986, 0.14206993303471996, 0.16599458311834644, 0.1144881017746464, 0.17503953809219022, 0.1437966492507727, 0.11376597197546114, 0.29059985652565956, 0.18159487585146583, 0.1775805291629607, 0.12704023790936317, 0.13147078484537142, 0.12120375875383617, 0.1075520872649166, 0.1914905408217061, 0.21359184035851111, 0.14770262514150914, 0.1380494423210621, 0.14372128152078198, 0.16426310183540468, 0.22701357821783713, 0.2198122291555328, 0.14086256314429546, 0.15544352992888422, 0.11302516495268192, 0.13215139267906068, 0.12587492624598165, 0.12472180304147544, 0.1380647640795477, 0.1371414289479294, 0.23921921278440186, 0.16321158487229578, 0.2265671941061174, 0.08531934236206355, 0.12533450484155648, 0.14351868190832678, 0.11017415342071366, 0.1614278563929181, 0.2623612121228249, 0.19555076085511716, 0.11130626283345685, 0.29271818156684604, 4.662451801761504, 31.922446950789425, 56.964793820534986, 55.557529772481615, 42.81933453775222, 39.71783015035814, 39.70312126221196, 40.23568499472834, 32.64296085603776, 17.34692527401832, 12.659854715870274, 4.143624699884846, 1.779331257266383, 0.4006486626402025, 0.3411673898658445, 0.5674467800605683, 2.00588429406766, 2.7547501940881056, 4.986053224532835, 6.171002724478322, 7.211082914183217, 12.751250843847952, 15.31978161104264, 16.10720624846797, 18.67966821116786, 13.54212030287712, 12.526911862434881, 10.007233235143847, 9.362408326518151, 5.165453610881682, 4.182535592586764, 4.666049595802061, 6.560629404360249, 9.43968294128295, 13.260149936522208, 20.471503003951042, 24.262514960381296, 31.400683464542514, 38.05688681141023, 48.84345577609155, 55.32520386480517, 59.83696506869409, 60.689845238962484, 61.50211318846672, 61.995217877049605, 60.33640046273509, 57.66131654862435, 62.27204307433098, 57.30175679729831, 56.98319758138349, 58.92775181801089, 60.92177106488136, 61.99422943976618, 57.67021248417517, 59.41210569873933, 60.08383512496949, 59.47648748274773, 61.420704395540305, 60.802534934013124, 63.04610321598669, 57.668827887504335, 57.36121208437028, 47.061244518526145, 42.58511020291237, 32.77876311732877, 24.95251870924427, 17.102798915678456, 11.034775568592934, 6.87603356376771, 6.508711441870659, 9.091980514987823, 5.9409468885390995, 12.529413354012275, 18.335138982342137, 9.646509520469174, 12.501036967000655, 10.235239632668035, 8.875777509904678, 11.066196695450815, 6.681810540537681, 5.213145219510602, 4.975012733090309, 1.8674089375042149, 1.8620795396066483, 0.608258490120211, 0.9178337623034755, 2.329045798509352, 8.672901738074518, 13.991076753985498, 41.322495322073664, 40.714982940304665, 26.293881054847475, 45.83964586257935, 50.12648659367716, 42.883131888604936, 16.80291214296895, 2.69557535648346, 0.18416611207348688, 0.11767763989947497, 0.09406469567047973, 0.05629857581469321, 0.14373974423975716, 0.10121382817986513, 0.16700479262057813, 0.11017698028515424, 0.14977098592827398, 0.1936428648449721, 0.21083867357623196, 0.29471957094727025, 0.18734294079965164, 0.2686575049113843, 0.19893493893886768, 0.162760971955234, 0.19594618479811376, 0.09840975485501752, 0.21535624810043844, 0.11601565811302393, 0.13732210312399173, 0.22890057534940783, 0.16923014014478654, 0.11285622724361959, 0.2716554214637126, 0.13369299140909027, 0.12877011040766395, 0.11722546416304766, 0.15955362228616593, 0.2158797159790993, 0.08988154150785939, 0.11384989690756607, 0.11364358942955734, 0.215715007075379, 0.14257260928711585, 0.13663803257288473, 0.11561736900119052], [0.03740200592625526, 0.012797029546251702, 0.006118079669953835, 0.011820142953506401, 0.026908516583423463, 0.043765170529725096, 0.02719866089342583, 0.01227701863934917, 0.01320781450974004, 0.02002004932071413, 0.009205869827119094, 0.042276523797021764, 0.006664902696596279, 0.012599149035410056, 0.009631920050108626, 0.022646608582187085, 0.06088227521808398, 0.0357256484999051, 0.06669118669965575, 0.07312545192337806, 0.07269599069390567, 0.06253041762618289, 0.04282310071791853, 0.058609487699164506, 0.029504305923417695, 0.04025211347447288, 0.009326207875874976, 0.03903309138672006, 0.027145036653946006, 0.05549281985769349, 0.025417514130352967, 0.04213776612173646, 0.02379784912561938, 0.031199300353745782, 0.025823693947806477, 0.05505919877079226, 0.034460737745487885, 0.05915904470208672, 0.009139750693594257, 0.039334152449643424, 0.06435513180950958, 0.0163641513415402, 0.15225130283544142, 6.533702333127299, 25.19040261545489, 38.58265307641799, 42.61978787760581, 45.44863262484151, 20.319597451917588, 25.12441069849076, 22.077772425067042, 19.103168479857906, 18.35539214072689, 10.092049587157465, 3.0574946586162817, 1.4413646440352164, 0.24752181323785938, 0.16455495069103857, 0.4252167652931906, 0.695840787262686, 0.44985289655385485, 1.2247942844706199, 1.821214080818238, 1.1334623853045127, 3.1323609380952777, 2.2545026242733, 4.571743559452796, 6.580228507518769, 3.2351890590883072, 9.693659351718042, 5.380834879413729, 2.914436993099028, 3.883704672898016, 2.2246041124866855, 2.7661927284732943, 3.963090503408063, 4.299840446441404, 8.348747261108892, 13.123106245071659, 18.111591339111328, 25.586844413511216, 30.30041548513597, 41.7287116665994, 52.47128340505785, 55.01725466020646, 58.05742494521603, 58.15033804985785, 54.07197913815899, 49.343412845365464, 63.94314142965502, 54.094807332561864, 46.3863536619371, 55.14158594992853, 52.723127026711744, 57.02632404142811, 58.50734826057189, 58.84128708993235, 55.839034357378566, 59.80532723088419, 57.87153597800963, 59.10971057030463, 46.54923008334252, 53.72043671146516, 46.41633625953428, 33.38630883924423, 30.483868660465365, 21.183544589627175, 16.169316980146593, 8.909098044518503, 5.037184751802876, 3.476519257791581, 4.152125946937069, 7.307743353228416, 2.83336773034065, 4.105312949226749, 5.214204259457127, 6.493639244187263, 2.707549126878862, 0.8180836600161369, 1.3934787555086998, 0.632071934880749, 2.0877911054318954, 1.2021459062253277, 0.46174901627725173, 0.21741913901942395, 0.13598052995099177, 0.3061034536409763, 1.8831320034880794, 4.6431414831069215, 11.833159308279715, 19.244354194210423, 32.97369510896745, 16.75941894131322, 25.905342832688365, 41.7165405519547, 33.036441264613984, 15.728109171313626, 2.715027615908654, 0.29497755871665093, 0.014762733593553066, 0.06294672129555576, 0.06438716960650298, 0.027711056886361014, 0.03670134574114796, 0.049821585867433786, 0.07368231357465829, 0.04652777934567102, 0.07121673619915402, 0.03802943959712021, 0.04635289296387665, 0.10209653000797957, 0.03334417608716796, 0.06599649050903898, 0.07961188773474387, 0.007650282810397087, 0.025492450935886275, 0.1528066552935108, 0.03601689214607881, 0.018211474694732218, 0.027243509595733018, 0.021843443917591247, 0.01631664814457538, 0.1351970671525886, 0.04977482003009608, 0.028822742395042896, 0.051852396854590026, 0.0391590055979548, 0.03706247192777453, 0.06440593876064786, 0.08653174545015059, 0.13503241953590225, 0.049431256409133636, 0.020176955618925636, 0.022633655950607314, 0.04280934177879845, 0.05092627316292736, 0.011761795781973389, 0.04954104063912265, 0.06387052757124748, 0.05669750844038302, 0.014471466007131725, 0.022551858827712077, 0.12980797568396216, 0.04877536640232129, 0.06241857261967756, 0.03856287044923633, 0.043082023114566846, 0.014508730438988537, 0.05823752136840936, 0.052048741359143495, 0.09352512462365051, 0.054627898930301594, 0.04904877169117813, 0.009558197493935305, 0.10162462750750204, 0.039172726232678666, 0.025809517490767667, 0.015886184297532083, 0.055688647252898064, 0.07334397850377906, 0.03668703904916202, 0.03614026294540494, 0.06850378903289957, 0.07101743076477321, 0.03940824081280059, 0.06041343706930357, 0.0793834173330857, 0.00913928242235054, 0.062410505713834885, 0.01759234924740609, 0.01108888904714296, 0.05436607306042025, 0.036067932754034, 0.10476447716956178, 0.037155317953757705, 0.037648284041713324, 0.0838037216735463, 0.04736386089315338, 0.2950484371714054, 8.269272196677424, 30.823063465856738, 44.9229448072372, 46.285772323608406, 49.395505843623994, 25.496780910799583, 26.414805766074892, 25.15839803603388, 22.35729621302697, 16.921010786487212, 9.011229699657811, 4.797716208042638, 1.0610717342745875, 0.24511090389663176, 0.02299348553342204, 0.30835624243463244, 0.2552847966792122, 0.8975061401724816, 1.4642147791962472, 1.959021899007982, 4.148851748435728, 5.2474826285916, 7.116104681645671, 5.953547012421393, 7.589281278271829, 7.43576902535654, 7.937557841500929, 9.565507673448133, 6.5688663817221125, 5.919401799478839, 4.725441144358728, 5.584853041556574, 5.1795005990612895, 9.153106731753196, 13.615024416677414, 16.178727726782522, 21.542714065121068, 29.617113105712402, 34.874628666908514, 45.07744304595455, 53.23565137001776, 55.723544090024895, 59.153374395062855, 59.52046509711974, 56.98535880734844, 52.5900645409861, 63.59537624543714, 53.45721037157121, 46.709819762937485, 56.70010835893693, 53.916951379468365, 58.84112235038512, 59.77536816750804, 61.405477754531375, 58.99180804529498, 60.50027316616428, 60.4654307519236, 59.4639672771577, 51.15108813008955, 54.976583603889715, 49.01084684556531, 37.088916455545736, 32.67492817294213, 25.010954180071433, 17.006879314299553, 11.6793425813798, 7.362781070893811, 5.8301193387277666, 7.322616980921838, 4.035259172801049, 2.957896609460154, 7.273252971710698, 7.853349947160291, 7.675008110461697, 5.880792438983918, 3.272252025142793, 2.2051155711373975, 1.8462232356109929, 2.191463761752652, 0.9576061668415224, 0.6544332446590547, 0.11228834158710896, 0.20831907168030742, 0.3092948227159439, 1.9208273291587832, 4.820629713996764, 12.71725566156449, 20.00157560071638, 34.283390198984456, 23.789271193165934, 25.837946707202544, 45.92127430823542, 37.55851437968593, 20.088330584187663, 3.8754887782758285, 0.45683094630798987, 0.027291439886715625, 0.06777520111251263, 0.06627654161063895, 0.06492380653658221, 0.03918733552939469, 0.03725968977256167, 0.0603021398156641, 0.018494222425825654, 0.03282608614573556, 0.002780398095755147, 0.04657776658273032, 0.019740532565441345, 0.05163940908988157, 0.024929740203304157, 0.041222815822449424, 0.07832430077776795, 0.08656323932471775, 0.04838056682098297, 0.03117492918165461, 0.04495595844702856, 0.031242436849542206, 0.04556405988912429, 0.08413154601810441, 0.028299988893371437, 0.041129345434807965, 0.0339348835029429, 0.08749036659156123, 0.07098180001541492, 0.05822234133618975, 0.057224726319433226, 0.11173014694284047, 0.1277608202109414, 0.051645101123158975, 0.09819492847929079, 0.0792141119018197, 0.052325567230582244, 0.015591109254127069, 0.13518998850016825, 0.11368884990412383, 0.17038766835485736, 0.10523069529764115, 0.12132313823507679, 0.09695290843205107, 0.24787890214112498, 0.1549323654222873, 0.15466676273893926, 0.11543284906374833, 0.13911113293180544, 0.11027025915081463, 0.1589432493933747, 0.17081802590720116, 0.36270487933389606, 0.24042391668884988, 0.18059272559419756, 0.09074880666429959, 0.251935429630741, 0.14760580694963857, 0.17351716816906007, 0.16293256032851436, 0.16391241742718607, 0.12509120297768425, 0.20624340241474493, 0.11551282098216396, 0.08412033815177218, 0.1222328753060391, 0.14755143002877313, 0.17582398148313647, 0.2276996099540303, 0.2995423395787516, 0.11719929459955424, 0.12852002100478258, 0.05431258480154699, 0.30604351492178056, 0.1062132643475648, 0.22903750590499372, 0.09735840643125196, 0.14091747632670787, 0.20775533822034636, 0.1257613077459316, 0.7957620029487918, 11.344896785674557, 35.84313246511644, 52.77101524414555, 56.05221517624394, 58.55862540583457, 32.33724151888202, 38.168301736154866, 32.65615570929743, 29.104873134243874, 23.974893439200617, 13.835197840967487, 4.423007282518572, 1.8284909355063594, 0.925394804967988, 0.5544622026143536, 1.207206008895751, 2.2098785542672683, 2.5263191999927646, 4.147021962750343, 6.881913196656012, 8.349993594231146, 9.673146336309372, 11.674792631979912, 15.518994869724398, 16.048903157634122, 11.200811459172158, 18.240343140017604, 11.751628921877954, 10.563510637129507, 9.023142918463677, 6.714793751316686, 5.606470204168751, 6.347722661110663, 8.353703175821613, 13.526439647520743, 16.35484803107477, 21.373251984196326, 30.156633161729385, 33.55831261604063, 43.43169104668402, 54.34502709296442, 56.667886087971354, 60.75411719660605, 59.79537617775702, 56.77871265719014, 54.15594923880793, 64.85067982827464, 57.953635108086374, 50.22301612361785, 58.081994671975416, 57.24805954963931, 60.3435823225206, 63.70959566485498, 61.29418834563225, 60.53723758266818, 63.18942269971294, 61.68614687458162, 60.875683215356645, 54.411213167252086, 52.36363395567864, 48.73852845161192, 39.00976780922183, 32.721527891774336, 24.520526509131155, 18.408130368878766, 12.352130066963936, 7.279489049988409, 7.682193402321109, 7.9523324293475, 13.492425833978961, 7.196032289535769, 12.836876184709611, 13.93668132443582, 15.153701593798978, 11.421823290086563, 7.7595822561171754, 9.399836563294935, 5.031612534676829, 6.433001852804615, 4.24270720251145, 1.8917548440156446, 0.6163122192505868, 0.5664726839430871, 0.6475086065550005, 2.7709687044543605, 6.302363391845457, 16.5901667071927, 25.78580075694669, 42.665840425798976, 25.068646361750943, 35.11722726206626, 52.91211858872445, 45.085742781239176, 24.6428926913969, 5.565670199932591, 0.4380913938005125, 0.09374072474818076, 0.2557443115379541, 0.1258275743513819, 0.1967480949937336, 0.15726084370286236, 0.17151734160800136, 0.23047248051772196, 0.19191869204082798, 0.18380658701062205, 0.14653035739977516, 0.21465019082590459, 0.18287634176592674, 0.14911207370460033, 0.23557502445915054, 0.2282185579139379, 0.19722550566638672, 0.1811509125775868, 0.25417968420492065, 0.10710644625848341, 0.1526399392394289, 0.11092468976013123, 0.10056328163632464, 0.20652115525257206, 0.2600796184232158, 0.1719096245905084, 0.16581200904423193, 0.18264631620578228, 0.1294857591030098, 0.13317929881234325, 0.14110083181050517, 0.23099263889654992, 0.2913481099230628, 0.16841537499379727, 0.21339440417866554, 0.15481818767805255, 0.16543175364213605, 0.08785602801869954], [0.011009113438757918, 0.019399251886493257, 0.09844032942407555, 0.05355999917693196, 0.06565254001367478, 0.06753839567423829, 0.008878465873309442, 0.01886169565090489, 0.04775261987120875, 0.008628204100645118, 0.08098962025776987, 0.0085037789728132, 0.02271001384924016, 0.0705718970106494, 0.05900156766837163, 0.011963888818788673, 0.05831344451214518, 0.042653657390826175, 0.006713747505038496, 0.03272587418436043, 0.040434633922432704, 0.06473039231833912, 0.024338354799716223, 0.07974625189578341, 0.06616184292661567, 0.020634273720544674, 0.018584438855008736, 0.05449483711873332, 0.05158961337480334, 0.07523137400107038, 0.04508333205575905, 0.0658069067304173, 0.010318610621916672, 0.1328056164446377, 0.06345705076631519, 0.0240831536751601, 0.03285171178680274, 0.0692621011647486, 0.030454163018974568, 0.03151081660161576, 0.10845686008612956, 0.02707575932295332, 0.047952415601861094, 1.6520594156557515, 11.090583051404646, 32.35364290975755, 45.37558240275229, 34.10274544069844, 26.450114942366078, 19.200811962927542, 22.52722505600222, 22.086417328926828, 20.45211865055946, 15.642886853987171, 10.229568865991409, 3.7080604462854327, 1.4653224810477228, 0.5124100429877159, 0.34427335545901333, 0.27875488083208766, 1.003907662966559, 0.995521022667808, 1.07696934573112, 3.1124159309171864, 6.736015735134003, 7.049645512334763, 1.816416531801224, 4.755624273130971, 6.445837809193519, 9.130928670206378, 7.822181322882253, 4.748679226444614, 3.6749855501036492, 2.972020329006257, 2.8188907523309035, 2.0222883815726926, 3.7079886178816523, 5.659594295486327, 6.0272002989246, 12.1453123131106, 16.729381430533625, 24.904718745139338, 32.647653971948934, 42.73577628597137, 50.846108159711285, 55.123413608920195, 58.492651139536214, 50.63777931274907, 52.60114915909306, 50.961417998037035, 44.783830104335664, 42.610009408766224, 55.75902585060366, 52.786112446938795, 53.847239094395796, 55.1037036988043, 58.324495207878854, 56.9330265445094, 56.72135976053054, 54.3950020113299, 51.711861548885224, 45.951833494247936, 46.91033917088663, 29.07327844250587, 27.984287277344738, 20.411867287851152, 14.176760777350395, 6.262719015921316, 5.564807278494682, 1.5374772995710375, 3.67546824678298, 4.091084796574808, 1.0084035572025085, 2.7257273514424605, 5.432029654902797, 5.053389533873528, 4.997586463728259, 4.185717125092784, 1.8311069112631584, 1.3167844063812688, 0.5985101745013268, 1.0521938171117537, 0.3466518439592854, 0.13832664357558375, 0.10437923453507886, 0.3797228790579304, 1.1340801586066525, 3.1139140311748754, 10.92256832507349, 16.77887978092317, 22.884074449539188, 26.21945800319795, 20.83347893530323, 36.650595511159594, 35.28152358147406, 22.67704586828909, 4.839276661795955, 0.7562748895537469, 0.038887783659682165, 0.022880251992553956, 0.08994921005421108, 0.04118922286696973, 0.005162764676741415, 0.004051297503117953, 0.03947648775553511, 0.03480862593278289, 0.02959158632063097, 0.05362736128811395, 0.0316009717437649, 0.0862047101761545, 0.008394900641794647, 0.01915851258672774, 0.10234806731703783, 0.025361616524957845, 0.04013171892673258, 0.08281926804732892, 0.07262869753063687, 0.03153212342200981, 0.058408087014310786, 0.027522210467366442, 0.052284650474546425, 0.011452708032823378, 0.03578969345037495, 0.0902782524785688, 0.07066136075844688, 0.01717229174720424, 0.06472973348272425, 0.028081351230221412, 0.029513405132738334, 0.031079671893929763, 0.047704647445390304, 0.039477935661712, 0.028811762439868147, 0.051923401713851965, 0.020954061802777074, 0.02231499401762361, 0.039719870058639396, 0.021864639655236277, 0.024466002284879648, 0.05247261397720826, 0.03507222146576932, 0.032405955867180904, 0.03850423024907228, 0.11281409240778416, 0.034823679560495, 0.048083868628788384, 0.047515580776117505, 0.06589104616714102, 0.0246254941298356, 0.011428737141672644, 0.014481330346766741, 0.08320680894558469, 0.040929430960527355, 0.021467051513853575, 0.08505409974003993, 0.04386017309321512, 0.0370157367339538, 0.004784919578777326, 0.015244842300401821, 0.04739877151986284, 0.013766072356262276, 0.01995935792013282, 0.05131090675751048, 0.04299723250310748, 0.07366961183687372, 0.05037812959222544, 0.035976450364556045, 0.04556922332173394, 0.06678209835363012, 0.07724071537414867, 0.10922554504847336, 0.05047130886645568, 0.05773366917104972, 0.07196443801325175, 0.014944107782456183, 0.029838297275766253, 0.04056032979860902, 0.04010212878065725, 0.050844964421083855, 2.142220610572446, 14.150508353787085, 38.52440980172927, 51.66056086940151, 41.21664231823337, 28.47819801299803, 24.0705188628166, 26.75531064310382, 26.708212783259732, 27.887877379694295, 17.729962372010757, 9.659378817004542, 4.917987844636364, 1.3203717816260554, 0.4249318725159092, 0.025040250301601428, 0.06082357373088599, 0.4311561223960692, 0.4136634239506337, 1.2362048270240908, 1.9620535234289787, 3.7708379808933508, 4.99109935375952, 3.7972406802638887, 6.968037168825827, 6.468712091445924, 6.489026536864619, 8.904800107402187, 7.892676611100474, 8.041321692928191, 6.685729478636096, 4.208831652518242, 5.312444923385497, 6.794644382692153, 7.364328936223061, 9.153033187312465, 14.416815715451396, 20.189055089027654, 27.348018038657408, 35.607005780743016, 45.051496567264685, 51.83155267469345, 55.77941433075936, 60.80719863214801, 55.820712966303674, 57.337850447623964, 54.40006186885219, 46.9563760295991, 42.05739844229914, 56.833135543331025, 54.67261560501591, 56.344431754081484, 56.98278181014523, 59.4111329509366, 59.205561530205514, 59.123835025295136, 55.32621191393945, 54.247069820281006, 49.85150883274694, 48.96292724917012, 35.311737598911414, 29.69116549338064, 24.983889825882454, 18.45997429663135, 11.074757268351894, 9.260873852237578, 5.005764115241266, 4.649937970023002, 9.248842962326544, 5.462528534473912, 3.2160954513857445, 7.768521828036155, 5.366939392782027, 6.022387060426897, 3.599029587161157, 2.4945663877071875, 3.1807203302460336, 0.6372498312304098, 0.8061274177124425, 0.2594881066151204, 0.30847716175260087, 0.11520879898941326, 0.16565421025358862, 0.9282754794243844, 3.599925603597395, 11.883284257304284, 22.98334179386016, 24.601686231551636, 33.35949943911645, 23.38373145749492, 36.767795931908395, 41.34895955362628, 27.09844546933328, 7.207990615598618, 1.00173270870601, 0.031468049743242806, 0.03978923165930375, 0.06404611875393218, 0.09653486957352969, 0.02733963064759249, 0.026779453750819932, 0.01567210294231172, 0.021518930988085848, 0.02856942776200031, 0.018342381884013454, 0.03615959517417416, 0.022675723753749363, 0.018290699677421682, 0.006499150476884098, 0.05381698720157147, 0.018446508554681655, 0.06997070951207031, 0.05329915389959371, 0.011948857216104385, 0.03637483523738, 0.0709414195209261, 0.041373202712425304, 0.040084232966746056, 0.02789217347819959, 0.04349443505728438, 0.023084609776795394, 0.048799310480394674, 0.06214819337812163, 0.03753571125167993, 0.0722425892167995, 0.040755337479734616, 0.04122224125650622, 0.02487658902311758, 0.028729469275041938, 0.025402682668138898, 0.01850379277921973, 0.027535266520815994, 0.054893061113093174, 0.1902322873713509, 0.08129676788925164, 0.1772339509860162, 0.14235666442301967, 0.16170096673792408, 0.1721744458641737, 0.08352564707879098, 0.2005707511618253, 0.21716531876835132, 0.2260093748449318, 0.13598296611059096, 0.1300531391414904, 0.15734610928883477, 0.13237564193625606, 0.15747208478710345, 0.20743273859543188, 0.1256439890412073, 0.1226604059939423, 0.15776157409193056, 0.14859877947357394, 0.1590348122220847, 0.10426825137748834, 0.07870192083740428, 0.12161186911285886, 0.23127730184745407, 0.19187712411005653, 0.1156316105757029, 0.23721901850113947, 0.18761756799874768, 0.16895051805242417, 0.1353404941337724, 0.10056199460861184, 0.14380863086590845, 0.28521076505703313, 0.16452312739866395, 0.13971542308647789, 0.10567752374035698, 0.15756455159956412, 0.10076008962407228, 0.12662452795813162, 0.19421540831606235, 0.12859752612008205, 0.1729384653510586, 2.79461054551986, 17.94369036151517, 45.279841269216234, 57.548952410298014, 49.40890073776246, 38.11400436585949, 30.274253276086625, 35.96749905617007, 33.87476551917292, 29.066271128193026, 22.425894544970607, 13.543001855573348, 5.806398805110685, 2.154598875391868, 1.0419341224816538, 0.68750397332253, 0.5892036771101337, 3.180891198496665, 2.797428278192397, 4.653767183903725, 8.461434014381902, 12.978773809248402, 18.265018770771643, 9.759054087823438, 11.716862993855631, 15.531864166259767, 18.608840011781265, 15.310432641736924, 11.634840349997244, 11.073432487826194, 8.138946054443236, 6.688203023326013, 6.094005617403216, 9.40913454178841, 8.814205123532204, 8.999193906784058, 14.848874595857437, 21.302490465102657, 26.831849813461307, 36.950448943722634, 46.46966088202692, 53.697985064598825, 56.526237533938506, 61.79496126790201, 57.16042987761959, 59.17633202768142, 58.40651589055216, 53.572473141454886, 46.318951652896025, 59.00628159123083, 54.13470960432484, 57.600810066346206, 55.4970468244245, 62.074179110988496, 59.55930048419584, 60.94589756381128, 55.12961487616263, 55.756150753267356, 49.33919237506006, 48.773978833229314, 35.97679115110828, 31.402583852891002, 22.969823345061272, 17.007112695324807, 8.109232139202858, 9.182541178118798, 3.1959871755492304, 9.065183862563103, 9.902789342787958, 6.047753518627537, 12.029347438966076, 11.741281709363385, 13.611423680859229, 14.63490047762471, 10.297249363314721, 7.352665278219408, 5.221053698370534, 4.563298696471799, 2.89880512222167, 1.821615510890561, 0.9915936882457427, 0.55932974142413, 0.5505368906644084, 1.8753679168801156, 5.085825574013495, 15.29235737939035, 24.47154983397453, 32.05709995761995, 34.53717147150348, 28.825969080771173, 47.21335403380856, 47.800348497206166, 33.504336880099395, 9.147338886414806, 1.2760655461780488, 0.17454029391369513, 0.11201545340760101, 0.196010903905957, 0.16061810145695365, 0.13066228629360277, 0.13603951872116135, 0.1462037587958959, 0.11638152638390181, 0.1466024769169669, 0.20251367271186846, 0.13784166395423875, 0.14989302373461186, 0.14421695572954996, 0.07583998489163576, 0.14743729824981383, 0.12757361896576422, 0.1919815725376529, 0.1844287423356887, 0.12042319176778679, 0.10219203818949962, 0.28011355308755753, 0.16683934827245053, 0.12100374085768578, 0.18647625020915465, 0.13639139822654187, 0.18400138784800807, 0.19087353360749063, 0.17012440990055763, 0.1291351206600666, 0.14604355448917036, 0.12038590626851206, 0.15418187504814518, 0.12033583476178109, 0.2021129780839528, 0.14111777767539024, 0.13347562162145493, 0.10205751314999596, 0.16571529810467076], [0.05683936877176166, 0.02134218492785529, 0.029060924876361128, 0.07014933823337478, 0.08925291273983256, 0.04181610112408957, 0.037731703355788224, 0.025635389536018335, 0.024489429253604145, 0.04388047059276893, 0.025224505938709747, 0.01797332477215077, 0.025869687951560465, 0.10330763074659532, 0.07220509687378522, 0.06333903109114017, 0.040105074388726104, 0.08632444971871954, 0.03837039468870048, 0.08575600481802419, 0.04863937047400302, 0.08691162546916355, 0.023016468171150457, 0.03461643745521865, 0.026687412117157253, 0.02569937511467405, 0.04169562996755685, 0.01863812629674231, 0.058723745882631316, 0.04419525612085577, 0.023842942976062338, 0.03594190746005024, 0.010074819419382802, 0.026938551060494878, 0.0465864425284728, 0.05332637683398301, 0.08745563216507436, 0.010111994793518417, 0.09577291852404034, 0.04380011563039115, 0.09119404164413292, 0.043296543055123864, 0.044126672099434563, 0.032771582820362626, 3.6840261230545663, 18.586543298536732, 31.87591391225015, 44.10322435440556, 37.31425269957512, 24.288845831348052, 20.701971669350904, 24.700490736192275, 19.59191933754952, 17.591100661985337, 19.00571523174163, 14.18541548713561, 5.534859491932777, 2.561427599960758, 0.8206868880698759, 0.3921639018001095, 0.04314237169080204, 0.47924811921773425, 0.8103593486932017, 1.5364766048808254, 3.3981056847879967, 4.82165051083411, 4.3917469728377565, 7.882557386352171, 5.899466353078043, 2.9858140791616137, 9.27536112646903, 6.610096375788412, 6.084851786013573, 5.43041265779926, 4.221841664083542, 3.124488986307575, 4.025589794881882, 2.887420197648387, 3.23983486140928, 4.426153023396769, 9.545674208671818, 14.90052926924921, 23.049098368613954, 31.2134079394802, 37.004609031061975, 44.579568755242136, 49.63435857526718, 54.08251070207166, 47.52207594533121, 40.065285467332416, 35.083286992965206, 43.87483258401194, 59.03438537351547, 55.65276492026545, 52.270148184991655, 55.02726454888621, 57.43263060046781, 58.3194588845776, 51.831591898395175, 51.63390051934027, 43.61252407873831, 42.160274367178644, 27.51948641192529, 20.769075578258885, 18.991149510106734, 10.52159030591288, 7.3868109814582334, 4.216134125186551, 2.231715369609095, 6.511539470764899, 2.956835118032271, 12.023645293328071, 6.860948128084983, 2.1909668464814467, 6.298441511969413, 4.427355229854584, 6.09035732284669, 3.4549881421750595, 1.0189263570693232, 1.1287864297628403, 0.6591018457566539, 0.5071636890211414, 0.037206994414690046, 0.16619407241382908, 0.3561290257400082, 1.1849303783908969, 3.105697155960145, 9.291510505060996, 13.13326322263287, 13.549740487529387, 42.062203345760224, 22.707848241252286, 24.261314715108565, 36.511394516114265, 27.44393175648105, 10.680479638038143, 1.1468031017049667, 0.0906657474115491, 0.03333788650530962, 0.09878347552711926, 0.10452417837035273, 0.02739737644010494, 0.026337158633396033, 0.008312461920262826, 0.043977204514967824, 0.06364177754749695, 0.13736848208692767, 0.04103501319825169, 0.0565510324292606, 0.04160953700662621, 0.08693893650366415, 0.0476652360521257, 0.06493388825366575, 0.05840426423556863, 0.05706648319779385, 0.034387212456955064, 0.08256517200460357, 0.04886225226425356, 0.059342139715989756, 0.1101270926395251, 0.04033270592410718, 0.02786086729517387, 0.015343009764629026, 0.028082402685897487, 0.010717683058652666, 0.04839655890640232, 0.011834488907498459, 0.07102432555609173, 0.08376506487688712, 0.047220659907907254, 0.03808290487335574, 0.04383501859622137, 0.049713705365936604, 0.10693041457524223, 0.016539934046205976, 0.014483049256546844, 0.06422138817968868, 0.09777927215421393, 0.030506341267497312, 0.024298148590230176, 0.08491130861183328, 0.07101514782275885, 0.054232716305001136, 0.03546188825801496, 0.015878102069930927, 0.03757012775167823, 0.043823519616477916, 0.04450771657209243, 0.0609543334482418, 0.03010927789634274, 0.10710673737189463, 0.024291813043096376, 0.03157429464702164, 0.023589591953843355, 0.03968381796092276, 0.05661459857477777, 0.059084975491127664, 0.08517848943630535, 0.013537036964759953, 0.047487066983575785, 0.013591559442330994, 0.023503290233953346, 0.029823783740040757, 0.029152725192327655, 0.0326369735111873, 0.04503533664730288, 0.04044046002109686, 0.01664729169269483, 0.030670364522525383, 0.056389656008010915, 0.050073402798584396, 0.03173371945928422, 0.033573749655437087, 0.028959412480734532, 0.07939322325851648, 0.004266869856960951, 0.059823085884413416, 0.013263436323482425, 0.01359575568893624, 0.17237995661074118, 4.715656791963886, 21.762125569005168, 38.209467011113325, 51.81283120186099, 41.604729467822665, 29.85522843176319, 26.80428339589027, 24.590884024097075, 24.29909106223814, 26.106797725923602, 23.3599030586981, 13.92225092457187, 6.055327125134007, 2.4324914476563855, 0.6015185711364592, 0.09549557171281307, 0.08343321857072654, 0.0963029211326953, 0.5254193803956432, 0.9245522921123813, 3.3408729107149187, 3.470738174453859, 3.4005174521476995, 5.003829406153772, 4.3787825588257085, 4.447312739587599, 8.809108984085823, 7.43457172186144, 8.28284457806618, 7.793039093094488, 7.181983340171076, 5.339719614674968, 5.051885304912444, 5.769243173060879, 7.501211810496546, 7.516983660959429, 12.135980013878116, 18.01970785663974, 26.610263355316658, 34.55715594753143, 40.45369817364601, 46.12017377730339, 54.53046498760101, 57.336865932710715, 54.306850664077274, 45.809780936087336, 40.70279613617928, 41.67228444930046, 55.969747343371, 57.027940057939105, 54.77214182576826, 56.79364119806598, 59.50914121443226, 58.685867094224506, 53.62104777366885, 52.4249170672509, 45.1400754528661, 42.45844118056759, 32.82147184495003, 24.09826570941556, 22.347243178275324, 15.060979704703055, 10.88627855623922, 7.0536252471708485, 6.638995908921765, 6.692781900205921, 3.3548926874514553, 9.035284615332081, 10.685354163569789, 5.6997779973091625, 5.435364159845538, 4.711801592380771, 3.7373973236929987, 3.502785654798631, 2.5293391798773124, 1.0225365923777705, 1.0492965338691589, 0.2357346771825706, 0.19244078096122513, 0.08168689050381223, 0.2156326985887943, 1.173883758244976, 4.2269196625678775, 10.724770061431393, 20.469598693232385, 15.769043026431916, 37.30050479212115, 27.98859796216411, 26.336885921416748, 41.02299490282613, 31.012129552902717, 13.499080134976296, 1.4744660162156629, 0.13773677119564626, 0.029490615932210803, 0.06023067147320798, 0.0503017008304596, 0.046407936381236206, 0.03773234686964462, 0.051567726242806644, 0.04613528185854516, 0.026617772809620348, 0.032290736243369124, 0.03981809402185102, 0.0902505507392268, 0.024056524458912112, 0.08184196202144509, 0.022874751481257623, 0.02776184851574081, 0.10893276156557184, 0.07814685949274609, 0.062105093271501606, 0.01856388854643991, 0.0223758616184275, 0.017174660874110077, 0.1474862972334508, 0.09260047182080247, 0.06252977411232649, 0.01167888687397804, 0.02977696810698798, 0.05917643489796789, 0.09523319425962626, 0.07080507119216266, 0.03965230493415748, 0.03668032045806608, 0.03285740765051977, 0.07895793209994033, 0.03564588725566864, 0.0762885140495435, 0.06811238705150544, 0.0769458634538516, 0.020918557457926295, 0.11900427435795147, 0.1770885015327123, 0.1452366800438012, 0.14844577639333664, 0.2716059015402871, 0.10083281435072423, 0.17753836368360829, 0.1949296780531445, 0.1555750365819662, 0.17402600376836716, 0.08387283812607489, 0.10750178593180834, 0.18335373711682137, 0.13266228139400482, 0.18167926809720455, 0.21186051229315422, 0.11334379624214866, 0.12072825564011452, 0.10862268747821932, 0.11120390582589373, 0.21037635483568717, 0.25783072135621504, 0.16921906251340144, 0.2028183612011133, 0.17723765885156972, 0.12070423878368833, 0.14186966232955456, 0.1151817637465654, 0.23322872697345673, 0.1948137536284424, 0.09184456520503567, 0.08288241667492736, 0.10874457206697234, 0.09671192015371016, 0.16760981821965787, 0.10561671934180683, 0.22349033985407124, 0.11470934030629935, 0.25381855035741485, 0.1325287982340782, 0.2121555787180701, 0.1373218120105805, 0.13987699102970863, 0.35774185532523745, 5.781696698357982, 25.116520850889145, 44.840076892606675, 59.44847391497705, 50.75798819142004, 35.810176710928644, 32.33286415376971, 36.20823452549596, 31.905104191072528, 27.25967057289616, 25.755592623064597, 17.65475876869694, 8.057301919306479, 3.19098370209817, 1.4197468685527004, 0.7667346863496689, 0.40346391318786534, 0.9032452418919533, 1.9055447943748969, 4.797183746291745, 9.533427588401302, 10.750019338823135, 12.187390519726662, 17.764989137649536, 15.594075898970328, 9.092370790819968, 21.825142368193596, 16.66382685784371, 13.186247579513058, 13.059397147547815, 10.285642089382296, 7.04567950579428, 7.4788900921421675, 7.106294833844708, 6.718649441196073, 6.976476148251565, 11.221288192656733, 17.295214706851592, 26.031160700705748, 33.776498379245886, 41.20365535059283, 46.34952260601906, 56.57341580237112, 60.83502392615042, 56.28784371960548, 49.434011751605624, 45.309612058824115, 45.63029719937233, 56.84273750551286, 60.71949051272485, 57.911575532728634, 59.07139685846145, 62.55593638266287, 59.07747260985836, 54.950570444906916, 54.95605391840781, 46.844082493935865, 41.88052700411889, 33.364029776665475, 24.60563998068533, 22.56388548881777, 14.276651778528768, 10.89040881203067, 6.681207476123688, 5.360490035626197, 12.16652351040994, 8.643483961782149, 18.64864226310484, 12.327956499591952, 8.526224705480761, 14.485037499858489, 12.53705216992286, 13.071932062025994, 7.721404846637481, 7.218964917044486, 3.704684756455883, 1.959288987901903, 1.3500047979816314, 0.8511281578290848, 0.3180297265850729, 0.8312777165443668, 1.9080302287493984, 5.169713795185089, 13.205255385368103, 19.845314256606564, 21.172963996087354, 51.68702117858395, 30.243621526225922, 32.826135543084916, 48.496941827958636, 37.38243133791032, 16.294944613210617, 2.2039957344532013, 0.29222521930933, 0.13198210256955317, 0.14930180303992766, 0.24320835518019818, 0.12742139729520968, 0.09353826303155192, 0.1469645147482234, 0.14788752812291348, 0.16530619183134648, 0.2267517140435596, 0.168762244284153, 0.21132618128772707, 0.16123651827294982, 0.2120496134363836, 0.16723322471784008, 0.1497817111592139, 0.31281297425589255, 0.19444935624637913, 0.18603810920350014, 0.19153616901847625, 0.14464685362913918, 0.1778478632050176, 0.2854985996119438, 0.14058018313540568, 0.11959402416382106, 0.12714391258815605, 0.10225885637825537, 0.18196512614527058, 0.16484532865785784, 0.24829557736314115, 0.23535080584547213, 0.1727456410205172, 0.1896416795470061, 0.21262742759239292, 0.17908788376277496, 0.18885700632968258, 0.24756474480513604, 0.18447317543529695, 0.11019819325977757], [0.059005984165255106, 0.043809373802956075, 0.05063962987473896, 0.0514716281735849, 0.043887710123653376, 0.051813697923095, 0.09314082427731446, 0.10540214577509512, 0.05413617007434369, 0.07362527832869561, 0.06001016455552271, 0.040199058055276835, 0.050500799421100855, 0.003469517645088115, 0.04442053576630931, 0.05360835081627292, 0.02385122630174362, 0.05691374441789043, 0.036620860543823054, 0.028589953172711596, 0.05010111219880562, 0.05364059545700589, 0.07994315181408199, 0.03621180023577425, 0.0319580223426343, 0.021817892970096682, 0.060822646764497605, 0.03864640467649987, 0.004630421669477778, 0.04788901416524764, 0.0945498131876511, 0.03523655881684634, 0.03674222419278757, 0.054813395629847245, 0.0070257329817620985, 0.05075065516716531, 0.022066025018331506, 0.040748473331933065, 0.06768742275814857, 0.14056017291882347, 0.04426696961144767, 0.08147093031795756, 0.08098087153367459, 0.0495948851288807, 0.4078783875992222, 6.378710856360774, 18.28297930379068, 29.977404379075576, 40.74984496639621, 29.467862998285604, 25.909508389811364, 34.820931419249504, 27.466265732242217, 21.655725394525838, 17.650954069629794, 16.90857098948571, 14.94413818082502, 7.926384970065087, 3.6320211329767784, 1.044961947106546, 0.5184608505618188, 0.12581694105099286, 0.29989173695925747, 0.20950935781002047, 1.3241815062299853, 1.679827590142527, 1.142760118649852, 3.897262590546762, 3.565796325283666, 4.0143178835991895, 3.8507587246356474, 5.8069744129334735, 8.341769364572341, 7.100533362357848, 3.944850991810522, 4.85203024841124, 2.8071712005522946, 2.588172280980695, 2.3190876360862487, 3.3355691307975404, 4.153413955242404, 10.338705874258473, 13.661595698325867, 21.48605346679688, 27.79009073011337, 41.22974695697908, 40.951741126275834, 44.92920098766204, 37.03747064836564, 47.579279791924264, 29.09662635095658, 43.497814363048924, 61.53172708326771, 47.23365229945029, 45.84478416750508, 47.88133367415398, 54.35568809509278, 55.84057977122646, 47.468955286087535, 39.74082700667843, 34.58726406097412, 27.29120642908158, 17.264063242943056, 16.3583860089702, 9.1409993556238, 7.626817380228351, 3.635698109865189, 6.050438871306758, 8.210671986303023, 5.610652921661254, 2.0703792139407127, 10.603956157161344, 11.538449083605121, 4.6430125351875065, 4.179073610613424, 2.9821682360864457, 1.6643185384811896, 2.337666677851831, 1.5572722760900375, 1.4348855013808897, 0.06587269070047526, 0.3863516540056275, 0.1064652230049814, 0.8742195187557129, 1.2645479964633144, 3.3574711555434815, 5.7670544905047265, 12.818831320731872, 11.011437466067653, 27.098733763540945, 36.48002732184626, 28.279749616499874, 34.115144052813136, 30.735882905221757, 19.9680785594448, 3.1617875397205357, 0.10993035359969063, 0.06074056044341095, 0.03805425318498765, 0.0633515834417795, 0.06454155164500398, 0.06241091940131399, 0.09082607429234252, 0.05246456622356369, 0.009726157483284273, 0.04592731196974074, 0.04310179967433215, 0.025853736085757136, 0.08268869602151456, 0.024936064259119095, 0.051498759177423296, 0.037216949727266066, 0.03117110065725302, 0.0971829646357125, 0.05688500845985067, 0.04611820575871295, 0.01769849839019439, 0.010358175232766137, 0.02781617947133078, 0.023121378166721235, 0.03828608288219379, 0.027462767790101712, 0.0393720010235425, 0.04897148491093709, 0.0708921141021194, 0.027075140706954465, 0.04900197137988383, 0.05308300219175797, 0.05935108762294535, 0.059084864408378644, 0.06544400321980638, 0.06278747076829595, 0.06032062168683737, 0.035925620430780035, 0.04792328510854033, 0.030507390807953574, 0.02167274229108326, 0.05615554719923004, 0.006977624575337096, 0.0343426721050374, 0.04482929730006764, 0.009431359189141904, 0.03720208379109541, 0.08831232530815948, 0.04409432403683182, 0.04568752644944095, 0.016404125809429154, 0.02747743071297244, 0.02299744429277076, 0.05462807513052418, 0.05183255900779078, 0.08863223596445977, 0.004606598250252465, 0.025240854255013892, 0.06351312840237253, 0.09643173881716306, 0.020512283794702064, 0.031120207521223256, 0.021665770890972307, 0.03024597862555135, 0.047766574162749514, 0.020338852979963826, 0.06853180486829051, 0.020609285847674456, 0.05192429037584413, 0.0090224779541454, 0.07579991083231664, 0.06915826560749162, 0.01985490183165718, 0.028264400278848988, 0.10139557487902143, 0.04761702996949035, 0.021806677442885215, 0.023514484693746895, 0.06811985640876717, 0.07669262542960144, 0.03278851336348922, 0.07863314912444161, 0.06908472882763994, 0.058821376127701615, 0.5867531150579453, 8.028662733493313, 23.28573888347995, 35.367274438181234, 46.30336807620141, 33.09227228164673, 30.168623847346154, 35.49100168289677, 29.66487188493052, 24.472416677782615, 21.767561974063998, 24.903292963581702, 14.753659059924466, 8.276810992148615, 3.1681488886956246, 1.0775211741847377, 0.15558065966733042, 0.10690609128364634, 0.06353460567732973, 0.4653039093940489, 1.1359552966971551, 1.4050291550736274, 2.459575903992499, 2.876991350804606, 4.864850025023184, 3.757345762944991, 4.625428059408742, 7.32439136312854, 7.115176550803646, 7.178732185594498, 4.200472591384765, 6.670140998978769, 4.3163310712383645, 6.26617560463567, 5.688010886792214, 6.056750945506558, 6.494061389277059, 11.614756834122444, 17.333451932476414, 23.628552075355287, 30.89180104194149, 43.18377371757261, 46.24946686529344, 50.60338404870803, 44.97013484278033, 48.69025584190123, 35.25200382355721, 44.447251519849225, 57.90380531741727, 51.59557504038657, 52.234282032136, 52.58328276295816, 57.92339363405782, 59.44527718328661, 49.421232669584214, 40.8527522702371, 36.30278325849964, 32.224118401927335, 22.60755127476108, 19.761120580857803, 14.350367822954732, 11.019347906112673, 5.486191703427223, 6.322589093639005, 7.401740502926612, 5.9046370175576985, 3.5597624942179653, 9.89783440866778, 10.502550140503915, 3.834888569770321, 3.2958946016526993, 4.284621650172818, 2.8744548030437964, 1.890014659973883, 1.3558518261678758, 0.3314727616886939, 0.4274583385596353, 0.36250177410341083, 0.1194863811495804, 0.26531224409418724, 1.3084436087839066, 3.847536007242818, 7.437596849856838, 17.71777949025554, 15.10473374397524, 22.487261987501576, 43.903438429678644, 29.946096020360148, 34.5213564749687, 37.9832011653531, 24.32847353719896, 5.130956365216163, 0.091209125915362, 0.04970934632564745, 0.031793910987494935, 0.0429927968540259, 0.029604431699901342, 0.0575889858056701, 0.04453537234615895, 0.0206587080948896, 0.018961612668429172, 0.012443394741914686, 0.0422770140932933, 0.06978171562115032, 0.08604687308111499, 0.011835628463285825, 0.03877534110459589, 0.05200751433749834, 0.011186893717686256, 0.06735430474603368, 0.04630778570689502, 0.04617999841068541, 0.010367534911981034, 0.0831960377493693, 0.02107849171865852, 0.02485992469554467, 0.006783291051584867, 0.010303777244482792, 0.013998166353802287, 0.0070206341878210595, 0.009517373626060303, 0.027016937176907257, 0.029781520584478017, 0.03670106994949522, 0.0787343723218768, 0.029832678020841656, 0.03739762007288876, 0.03132488514717308, 0.07534840159238347, 0.05370011665828286, 0.06187692930501315, 0.04341914393608609, 0.14822485195773263, 0.3005141067889429, 0.10738445956620479, 0.1721654673137011, 0.15236739579948688, 0.2760904883184741, 0.13191035077456506, 0.17134160103817142, 0.18165034061718374, 0.1564641582268861, 0.1799304425836571, 0.12390241071942354, 0.19505418266259855, 0.1443580691252024, 0.17967030976808843, 0.24136920790037802, 0.1682623565918015, 0.19707522985915985, 0.16113256014162497, 0.22939205139635072, 0.09444950163484582, 0.12541765602485788, 0.10769362200892742, 0.14341435605479827, 0.20649452603632407, 0.16891900119521927, 0.15626215616301184, 0.18889452931621384, 0.12365701743551802, 0.12086047475496609, 0.15039042930208868, 0.12461646595188688, 0.12558837871878378, 0.11165178380906583, 0.19043485634028914, 0.20761336680621872, 0.1613065846745045, 0.12229764804003701, 0.21254675853396618, 0.2169015240525046, 0.15569267704361872, 0.17469446144757733, 0.23524425833696322, 0.15170540390235765, 1.0187251517368903, 9.315864501460906, 26.363512931331513, 41.993934492911066, 56.6768055577432, 41.40087604522705, 38.80550646012829, 49.232139125947036, 41.258011556440785, 32.539500498002575, 26.38175783618804, 24.1948599584641, 18.7996829325153, 10.908416413491773, 4.989404399548808, 1.6403089752120357, 0.9921248629689218, 0.6035343016828261, 1.100349246013549, 1.6337279735072967, 4.881103346424719, 4.093260486279765, 6.264377197911663, 11.5625383200184, 11.004647843299374, 11.791698874965792, 9.881659534669692, 17.646833619763775, 19.964654330284368, 16.934399797070412, 11.830392076123147, 12.131699727427575, 7.961762297538019, 7.2393940917907225, 6.061879444506861, 7.41792812462776, 6.75782754536598, 13.10850424151267, 16.330568559708134, 24.21144570073774, 32.24246724959343, 46.73768428064162, 49.45763618715348, 53.4654434265629, 47.05543156593077, 54.18379022229103, 37.38204302326326, 48.54583809452672, 59.2521357536316, 54.449083651265795, 56.96816705888318, 56.09923262749949, 59.63817934836111, 58.85906327155329, 51.61594390869141, 41.76061622558102, 37.47406967224614, 33.58556916636805, 25.17772355387288, 20.227129536290324, 13.58973297380632, 12.119588428928006, 6.026997316268183, 9.33898393184908, 13.307796928190417, 11.39106994675052, 7.414151372448091, 22.22848557656811, 22.39639439890462, 12.551410005938623, 10.653448623995628, 8.219525756374482, 9.30035250802194, 8.776799440383911, 5.464541690964853, 4.342681063759712, 1.476367630304829, 1.278588610791391, 0.43084432461088706, 1.202410666211959, 1.9156015063485794, 5.211142359241363, 9.237512215491265, 18.080388884390555, 19.59201151324857, 37.1515606295678, 45.633603757427586, 37.53544692070254, 45.59800824811382, 43.561133184740626, 28.673694825941517, 5.926724374294282, 0.2908899280573091, 0.2375976038315604, 0.18825671515397488, 0.17187729568010376, 0.24103605158386693, 0.1846055860721296, 0.2331601008171997, 0.2468374056080657, 0.1295911574796323, 0.12981010540839166, 0.12245489524737482, 0.17731103475295729, 0.17232789327540707, 0.12141670055326917, 0.17653871087297318, 0.114756025704405, 0.07479917783770831, 0.24205315587741716, 0.2843796515897397, 0.2061073451993927, 0.17545806724698315, 0.324092086765074, 0.1640157626881715, 0.08179535323213186, 0.13811823701666248, 0.08541977648893673, 0.0778947399568654, 0.22074808216383382, 0.1183938401781263, 0.1494197192932329, 0.09430343165032326, 0.27286593231462664, 0.1504771810986342, 0.14465433064728014, 0.14926294706040813, 0.13770006026231474, 0.20286739082826724, 0.21102644172647309, 0.12282137638859211, 0.17334367989772753], [0.0775681336921069, 0.039567318970277425, 0.05136143025611678, 0.049049599066136346, 0.05119080715362103, 0.02205207838766998, 0.013925352569429145, 0.0607442376654475, 0.08598510341178026, 0.06236642501467179, 0.08386241933030468, 0.025862113257209142, 0.07069703747308062, 0.044939759517869646, 0.00912842599885358, 0.02067246894922949, 0.022962845846890442, 0.02435346971446228, 0.021829683063251358, 0.06885795914117368, 0.022034856731132157, 0.03215998801733217, 0.012340859618909177, 0.030529191755058787, 0.13157298097447043, 0.039334949181084676, 0.06315791258408178, 0.04454612822061585, 0.03403028443215355, 0.11241215671743117, 0.03445784959401335, 0.038783764241323355, 0.04741554884540458, 0.047455266673838904, 0.016464131561318235, 0.03951502963900566, 0.010716221745937102, 0.07038008391616807, 0.07181196353368222, 0.04856504462358933, 0.03999042550041791, 0.04294770874924237, 0.01911292652479343, 0.08637274390146618, 0.04317559692407808, 0.597542145800206, 4.323950765594359, 26.751268640641246, 35.95898359052597, 40.57499354885471, 37.989865272275864, 26.8950980324899, 14.401790095913796, 24.390574462952156, 22.28644447941934, 19.148269853284283, 23.248095896936235, 15.737596404167915, 9.03296257219007, 4.159369093756522, 1.3946694400041335, 0.38667445281340235, 0.28273041750634875, 0.3709579138986526, 0.9017739240680972, 0.9023603184088584, 0.9102309831688482, 0.7073303288029087, 2.5608054139921745, 2.8031578804216077, 6.387300356741875, 4.270173109346821, 6.105737426588613, 4.404951632022858, 4.922236261829253, 4.954829687072385, 4.5961255027401835, 6.68147910025812, 5.011670714424503, 1.802953118758817, 4.040772799522647, 3.776405540204818, 6.998644894169224, 11.577396258231133, 24.10040536234456, 31.34738237627091, 32.2074895135818, 29.726390338713127, 37.57027364546253, 39.71909315355363, 18.806005793233073, 30.451640505944532, 47.27481757440875, 38.58894848054455, 44.79340460992629, 40.156908112187544, 51.06564714062599, 43.88155552648729, 40.35785113611529, 32.06240692446309, 25.656223297119144, 12.466500497633412, 14.028269648551943, 7.777783524605536, 5.665215051943257, 4.861095826472006, 4.066348859379369, 3.2953697394940162, 6.041870943961605, 3.4162005589854334, 3.0602229122192632, 5.11941381039158, 9.172973536675977, 3.6474188873844766, 1.9413798134173117, 3.2947649590430723, 2.001850136345433, 1.4003576121983992, 1.0084061925449679, 0.2646158395274993, 0.5380033245009761, 0.4726590889115488, 0.3997816962580527, 1.903815519425177, 3.85341564013112, 6.586345934098767, 16.19150680880393, 15.56159769335101, 19.47738220614772, 32.78590183104239, 19.422718094241237, 29.129956691495835, 37.13458068909184, 23.873743357196933, 7.426433784346427, 0.3627506607482511, 0.07272558467042062, 0.05596011433930648, 0.05021549295634032, 0.029987868282102773, 0.03948125282242414, 0.05592812633802814, 0.04400824639765967, 0.1170145678183725, 0.039493088880854274, 0.10818578753500216, 0.0738422803941273, 0.051922233429767435, 0.04897843715884993, 0.07107053597968432, 0.02070783731347371, 0.012258982056781892, 0.09362653934306676, 0.06749714950039502, 0.02830181984351047, 0.025418167220308416, 0.033562763954602906, 0.03656723821956304, 0.050339660487107696, 0.05757902283221484, 0.015566595398159999, 0.10819464351140684, 0.08212170668787534, 0.0527304485290041, 0.10054881023543497, 0.06170590017591754, 0.02714231321137519, 0.08749369141315261, 0.0408567943339867, 0.022354234956325065, 0.054368221937047864, 0.07271674401577442, 0.07134497931767857, 0.018473857893578468, 0.02288777497597039, 0.009857016792070242, 0.017486010497856527, 0.07825663223141625, 0.025209341228248614, 0.05228789485690575, 0.07121074539158614, 0.05261589540168644, 0.020880187944238706, 0.04463371888343846, 0.039185680779478246, 0.052339238069591024, 0.058826420816683, 0.04479998294564505, 0.058512956790265545, 0.045087208460655906, 0.06745106165087031, 0.04005092346379834, 0.04231208559846686, 0.027205157319023728, 0.02595584794518448, 0.046600385328694705, 0.03038167194913953, 0.03696839250023327, 0.049726460729875875, 0.01980862054493158, 0.042499872900906115, 0.04043923044997839, 0.06375465294226043, 0.030456193151973912, 0.03987533228111364, 0.05740610912682549, 0.0444107260104389, 0.0038961132269187443, 0.016481429826648488, 0.04302449757233263, 0.03358597258826898, 0.11793172828132108, 0.06629233068275837, 0.050402855079981594, 0.10067560544778263, 0.047428399970334385, 0.1343402897398318, 0.0402170572910578, 0.0303180062121922, 0.04089142916904342, 0.03079110955549104, 1.3114993802962767, 7.294344536719784, 30.375411202830655, 43.94190119158837, 43.0896839018791, 41.51861775305964, 33.0999562048143, 21.148284442963142, 28.47927470361033, 27.517031008197417, 20.647254605447095, 27.81247373550169, 18.498246823587728, 11.032569235371007, 3.6308414801474544, 1.1734720319509506, 0.09035436331384605, 0.06253250521577655, 0.12464661151170732, 0.2230589557439089, 0.3945012667006062, 1.6047013310655471, 0.5065413498349729, 3.475630595799416, 5.143278000816222, 3.4782031803361835, 5.136572709006648, 5.079466431371627, 6.76039424634749, 3.7795081350111195, 5.316029479426723, 7.284448887071303, 7.386693310353064, 4.75713340505477, 3.0566623806953435, 5.925874200559432, 5.5917564130598505, 9.071907785630996, 15.761745456726322, 25.618341045994914, 34.94156783626926, 35.80738790573613, 36.49208861012613, 43.57904664931759, 46.21775450245027, 22.552898929965114, 34.89469159033991, 46.66388096347932, 43.787461788423606, 50.45209430879163, 46.03094770062355, 54.44773435592652, 48.0043117461666, 43.396279888768355, 34.4529934852354, 28.03217157240837, 18.00180027561803, 16.882500956135413, 12.440574611386946, 7.656652888944072, 6.289322981911321, 6.401857253043882, 4.979744582406936, 6.8802182424453004, 6.357658024757139, 5.924514118702182, 7.803731474184222, 5.260551966005757, 5.733129420588094, 4.3459096647078, 4.044603974588456, 1.540944429655229, 1.5357383412699548, 0.5185709833618134, 0.2360125679162241, 0.14320879934295533, 0.20916768259579138, 0.2291070360450014, 1.4874133924322746, 3.7408431258893784, 9.144217660350185, 19.320028481944917, 19.06832214324705, 18.756976166079124, 35.498540478367964, 26.376845067547215, 32.66435738532774, 42.64260822726835, 26.972609950650124, 10.713269672086163, 0.6603066875569282, 0.05106490826414478, 0.02906691759914881, 0.042808227120868625, 0.05502220821536838, 0.01937568319150277, 0.043300542034088604, 0.0542659989948715, 0.012763901031576099, 0.009447062076369842, 0.10448679327964784, 0.03396807043182273, 0.08302988093947211, 0.008496638075749, 0.06436107665180199, 0.011351204255685933, 0.0158665714890606, 0.03926967465949636, 0.03335178334025606, 0.06311013934112365, 0.029715416772711663, 0.05870005844401256, 0.03373166335926902, 0.0587945094241971, 0.07304601626650942, 0.0744300996584277, 0.08173235782211827, 0.06958188158610175, 0.045867721820550586, 0.03901828673758334, 0.022115148491256183, 0.003360467662494029, 0.015308674661472682, 0.02348071170760499, 0.014394462679422673, 0.015829741812100815, 0.051431393235801696, 0.08467538417467187, 0.02011098204210641, 0.03303288008957621, 0.006975793625198065, 0.1479024208721615, 0.22595554950737187, 0.11753130178417891, 0.192937052718574, 0.1786666120132131, 0.09474873557806977, 0.12788458171510889, 0.11823605670924149, 0.11426389082184724, 0.16334160531480468, 0.1304525160981763, 0.07875701022003928, 0.21502534408242474, 0.07926485756592405, 0.11268626297673873, 0.09812746677667865, 0.18797364566595326, 0.21373071677742467, 0.09513273715011536, 0.18886152624843583, 0.1937170987648349, 0.13794847193264193, 0.09851142238344877, 0.09255498151985869, 0.18650566798544702, 0.10240645853862648, 0.2957271910723179, 0.11223178897653857, 0.13839412059995437, 0.29591770181732796, 0.19090180225189657, 0.1412322924983117, 0.24805507172019253, 0.15526066474135847, 0.15070467856862854, 0.16336984331569365, 0.19672358018015662, 0.17601109079776273, 0.25979405148856105, 0.12936997257413405, 0.26075788202785677, 0.1389595547751073, 0.22535092227401274, 0.22289438473601497, 0.17220591675610314, 1.5224948261053333, 9.055164167957923, 35.46999346825385, 49.873760438734486, 52.817648303124216, 50.4369382704458, 40.81827071405227, 26.199826540485507, 37.87067228747953, 32.95416562787948, 30.22355664160944, 31.119216142162202, 20.050650335127308, 11.916543995180438, 5.3908923268318185, 2.004029503272426, 0.5422692084985395, 0.5714051870088424, 0.9192885326281671, 2.384881473356678, 3.7230524805284317, 4.820257579126666, 4.133719244310933, 8.093803496130052, 10.202331927514846, 14.920557871941599, 10.658422189374125, 16.17267158723647, 14.040679047184607, 11.89957288003737, 13.837888586905695, 10.286459903563223, 13.500894231180991, 10.618860183223601, 3.159695935826148, 6.072837566175769, 5.977320498035801, 8.374302483374073, 15.046925852375647, 27.14328012158794, 37.244234469629106, 40.561375079616425, 41.231464955114554, 47.816108580558534, 50.65271177599507, 29.240396907252652, 41.11932831425821, 49.98753663032286, 45.578251269555864, 57.60868226328204, 52.064055089027654, 55.88739718160322, 49.34209885135774, 45.19418847176337, 37.34209760542839, 29.242063914575887, 20.67831193247149, 17.31296343188132, 11.797033298400141, 9.45835538448826, 8.07755409709869, 8.331769281818021, 7.057143122919145, 13.455693817907765, 9.771581157561272, 9.327345278955276, 15.2498447702777, 20.64778216423527, 13.183733340232605, 10.855765458076231, 11.537288062034115, 6.4876551781931235, 4.924433769718294, 2.0823446492994986, 1.0239099122343525, 1.0981067534415954, 1.0948189492187193, 0.8362310572016625, 2.4495035025381275, 5.270755031416494, 10.127684320172957, 22.17713586745724, 22.823220837500788, 29.337995283065307, 43.699110400292184, 27.965773690131407, 41.1798426412767, 49.01410241280833, 32.609104917895415, 12.903630022079716, 1.2490458089497782, 0.16805191223900165, 0.08249358108807957, 0.1483772421676305, 0.1708124487871124, 0.10259746724078733, 0.1115360202628278, 0.11655597992601896, 0.15621732469768296, 0.17463836848976153, 0.24098262461202763, 0.1597693832891603, 0.143680801434863, 0.1973873494012702, 0.19649153214789208, 0.11785847495400137, 0.11303937588367732, 0.22248373096508367, 0.20838685513984775, 0.269014501884099, 0.15078484200902526, 0.2173377038730729, 0.14114751720861082, 0.20012424447603766, 0.14111383998345944, 0.1149646161244281, 0.22227598324177728, 0.21758107468485835, 0.12388274524240725, 0.33187943180241897, 0.1559242654231287, 0.12355337340024211, 0.22568913477082408, 0.19495264536911444, 0.23993213420673726, 0.11793392695366375, 0.1832739720421453, 0.30283308557925687, 0.1198933806811129, 0.08508148738333295, 0.18886909519712772], [0.006849917239554588, 0.08282096876252083, 0.042526816213203054, 0.04557042607977506, 0.022949895130530484, 0.06583951143247467, 0.06558042049648301, 0.05465449750303261, 0.045849036936077385, 0.018928159523995656, 0.048522174343346595, 0.023053223154537623, 0.041530147315033024, 0.028356629604053114, 0.04980111216765739, 0.019867346929987113, 0.06581305075557002, 0.03814945493133799, 0.0349152768631616, 0.07673468365664445, 0.030148672052629055, 0.04299868423972399, 0.06601792564916034, 0.02863611571580893, 0.03147287418194596, 0.033508835195173184, 0.06751997892053858, 0.06351149663509381, 0.05426601048619036, 0.010586835241185562, 0.0619776277322202, 0.041278920271584106, 0.08666273116344407, 0.036406011185458595, 0.03818021336149785, 0.0946612943023924, 0.06881249182286762, 0.03663389552985469, 0.034567553384770314, 0.010509090723409768, 0.015710382440668202, 0.057888426592633616, 0.0385083326499068, 0.0640620687045157, 0.05550908390432597, 0.041408741531232675, 1.815041863629895, 9.312436349930303, 26.17234837624335, 42.08323117225401, 42.01655480169481, 34.79878179488644, 27.263302687675726, 20.95049500465393, 22.24333174767033, 27.588120045200473, 22.674341394055276, 18.679046515495546, 13.065716085895417, 9.671980411775651, 6.511366396181046, 2.1674534630390907, 0.7208799114150386, 0.16760488461342551, 0.15889095623166333, 0.4918941470884508, 0.883646383881569, 0.10408547045963426, 1.9206547448712012, 3.337652399655312, 1.0329103421780372, 4.40636956884015, 2.876001197484232, 3.2609303487885386, 1.3176834871692042, 5.038049634425871, 4.549497837020505, 5.281613622942279, 2.870014189712463, 3.0878324758621956, 1.777187069096873, 1.4149808210711328, 3.3645556915190915, 5.8341172145259, 11.248215263889684, 21.435509804756414, 21.391308615284583, 26.486079154476045, 30.002703666687015, 31.910240534813177, 20.878007642684445, 13.472057946266668, 26.275687140803186, 39.26133686496366, 44.165848916576756, 40.340965332523474, 36.68571641368251, 31.501064761992428, 25.765394626125214, 18.891748805199903, 13.165148169763627, 9.812413031055081, 6.772274615303163, 3.240897333429706, 2.798485847250108, 2.778036080060467, 5.182323234696542, 4.7928563913991376, 7.457117015315641, 5.683736483896933, 3.7734956318332307, 6.460818811770409, 3.6527371310418655, 2.7852167141052986, 2.857548652156707, 2.2477939003898255, 1.1000358241219674, 0.31110355630517006, 0.36787413421177095, 0.15931543022874864, 0.06003159586520446, 0.41467199402470745, 1.428140372999253, 3.612009200357622, 8.585127918950974, 11.673716921960155, 12.944659975267227, 13.902851862292136, 29.36707965789303, 29.056686816676972, 24.78277029529695, 41.4367304309722, 28.67710336562126, 12.718440217356529, 2.3192116810429484, 0.1518175744962308, 0.1000578398065221, 0.04266257082382518, 0.04102375170576476, 0.05557473380899718, 0.05761394878068279, 0.06414987004151748, 0.04715224059538976, 0.00966310653189618, 0.029090647172603398, 0.08387743465362058, 0.11844323752748391, 0.0171505578327924, 0.042869058332496116, 0.08684371177467608, 0.02825189389348511, 0.014465706941160946, 0.03243126358175951, 0.03196733031091431, 0.011305831740760516, 0.030903961967616796, 0.037674422961689776, 0.015772467163661798, 0.010271916605321871, 0.00729628459310099, 0.056862975771148364, 0.0163601964126311, 0.04708333098660073, 0.039277504078082504, 0.06510997356306161, 0.09620787260392982, 0.04690546069234129, 0.09037271111963258, 0.08713043550209654, 0.08389769001833855, 0.02935505092834994, 0.0614201455497213, 0.039355373085145993, 0.055628574468315616, 0.06960459609305666, 0.035793102541638, 0.05141025303953117, 0.04302758490666748, 0.020261412982137936, 0.0573552102451363, 0.08236903051335005, 0.089564940351392, 0.06350800327415909, 0.014744697968595693, 0.01961535762905354, 0.02650928326822337, 0.051460933586161946, 0.02394771890624637, 0.08529650528104075, 0.034454915477263356, 0.07745332775577422, 0.011386945130183332, 0.04565017583269266, 0.09322323235532931, 0.018515364537315986, 0.06450225133448839, 0.025181944008856535, 0.04969945996098461, 0.09414876615929027, 0.04468166449617955, 0.003957280559623013, 0.06916231055173182, 0.017675092488887812, 0.06302933621731016, 0.044565357027515295, 0.07354941264155411, 0.03155243815854192, 0.04020814002761918, 0.10349349899878425, 0.020599617818070036, 0.03693767237446962, 0.08374444178996548, 0.0697816236905994, 0.07038788269123725, 0.04748993981329184, 0.06003390562029616, 0.02105169779350681, 0.07382914964710513, 0.022360265983508962, 0.039177269134069645, 0.0894915797717629, 0.02690588124096394, 2.5473568324119817, 12.433055427766616, 30.377480253096554, 47.99215239863242, 46.68340652219711, 39.73629666912941, 28.877095214782226, 23.532448122578284, 22.366374538790797, 26.003964947115993, 22.881571977369248, 21.81546784216358, 17.302557383814168, 10.328951920232466, 5.538100840583925, 1.6705122061314124, 0.5332915160444476, 0.21934889917892797, 0.13390214873417733, 0.2653789550306336, 0.21893781639875906, 0.9989325654122138, 3.1300430624715747, 2.6521140240853835, 3.7678231491196543, 3.750774322017547, 5.9084637799570645, 3.6404632993282813, 4.70233004900717, 6.046525816763602, 7.009290206816889, 7.769293064071287, 4.237080562499262, 4.355872484945483, 4.038578968855643, 2.583177387714386, 5.31359859051243, 8.345357352687467, 14.964777692671746, 26.518279852405673, 24.935785878089167, 31.526095367247063, 35.372655930057654, 39.1512280894864, 24.57940128541762, 18.10981450542327, 27.353742737923902, 44.170947997800766, 48.53544381357009, 46.398826799085064, 43.20628812236171, 36.71716205535397, 29.773082233244377, 21.732137087852728, 17.853893579975253, 12.149937768136303, 11.002475830816454, 7.026343201437305, 5.328944863811617, 3.9649798600904407, 7.45096379710782, 6.648186022235501, 6.064357401863222, 7.095359265804292, 5.770646400990025, 6.008092472630163, 2.723612458475175, 3.393610158274251, 2.0318882599953683, 2.2138862359908322, 1.0414439487841822, 0.2309746817956048, 0.44548509221884514, 0.058217947821944, 0.24368590374867766, 0.34332411123379586, 1.4674818684016506, 4.469774682675639, 10.384619178310519, 11.089425952203813, 18.186969487897812, 12.793398672534575, 27.757964557217015, 33.811642815989835, 25.76588100002658, 41.68951542146745, 33.153869182832786, 16.739289337588897, 2.750090418323394, 0.15665713577501236, 0.034775772252150124, 0.027151117476844983, 0.028479084928309726, 0.04749710273538386, 0.04907953778221723, 0.071958324631616, 0.038231135225824775, 0.028109097019619042, 0.027559252733725215, 0.03641687814266451, 0.04859288042831806, 0.029623426849983876, 0.03739847809136395, 0.02607900807033143, 0.01452880290021459, 0.06973528303205967, 0.045334264155357115, 0.06492871716017685, 0.028262241826122327, 0.039237054635680495, 0.05794309845734989, 0.02993870267434226, 0.030120028025140206, 0.11391211856877613, 0.053279277748398246, 0.01519484069919394, 0.04393446446967222, 0.07778728846460581, 0.023702752716358633, 0.07870517671108246, 0.05417272779009035, 0.06712730523319015, 0.045031061876685395, 0.027194753845011996, 0.013986457657489567, 0.03282294518524601, 0.09394317880393037, 0.032093428383250876, 0.023115998314272974, 0.06699092626090973, 0.12376082234925802, 0.12464135614854675, 0.09891495919756352, 0.1740109424797758, 0.12600873116283648, 0.15431043992359794, 0.14101495335419334, 0.11326813739874672, 0.12371035247680642, 0.09397603631500276, 0.14920221160977118, 0.22394081487530665, 0.09671832464875714, 0.12287851122598495, 0.13077272552876704, 0.13209640288785582, 0.1724619280186392, 0.2134107678167282, 0.17749071301471803, 0.2056974115511102, 0.130480524272688, 0.10936048377545611, 0.17231074822766168, 0.20874248847605723, 0.0899974276281653, 0.13655120416754676, 0.1689460134554294, 0.16586692222664434, 0.15246787589163552, 0.1493650052936808, 0.23401670969061314, 0.14301608226472332, 0.172366320245689, 0.11984564574255098, 0.0937001757143486, 0.17809150980845576, 0.15295069514503404, 0.22945099420124487, 0.14882889696426932, 0.12671383848834422, 0.12350695613290995, 0.15976991955070727, 0.09704457085219123, 0.0878573610116878, 0.20168695658926042, 0.21827321980268727, 2.913139424016399, 14.996810709276508, 35.902042542734456, 55.200005731275006, 54.26111975023824, 47.48440942456646, 39.49290183282668, 32.378330307622115, 33.75642368870397, 38.59417699998425, 34.036939836317494, 26.147256974251043, 18.84856547078779, 13.76345867110837, 8.562289918622664, 2.941494973436479, 1.1843588155123497, 0.7148256104800009, 0.8480677897891692, 1.1865034939781314, 3.642315638642158, 2.8609998476120735, 6.135688645224418, 8.42697403123302, 5.754047911013327, 11.457058921937021, 10.979484858051425, 12.147705939508255, 7.906704477725491, 12.833624539836762, 11.275339434223792, 12.184936096591334, 8.339180600258613, 7.909003967239012, 4.171800065425135, 2.276431615314176, 5.975186238365789, 8.647797588379152, 13.567817711061048, 27.176390809397546, 25.857391857331802, 34.185782017246375, 38.360737139178866, 44.885090012704175, 30.057683529392367, 22.50641295986791, 35.040466477794034, 46.85743424200243, 50.2859740872537, 46.297276635323804, 45.42142706532633, 37.573686107512444, 33.439731520991174, 22.02428306302717, 18.080869374736665, 13.279514678062933, 11.550643732470851, 6.497970521450044, 7.599258317101387, 6.07298759683486, 9.610596299171448, 12.616851810486088, 15.224822990355955, 11.899522869817673, 10.357898031511615, 13.301290696667088, 12.007824413238033, 9.204770230477857, 9.716059027179595, 8.467191073202319, 4.061906039714813, 2.572344046446585, 1.449920068825445, 0.7627691701054574, 0.7695924394553708, 0.9500470240750621, 2.0795815846612378, 5.9562764917650535, 13.116513721404537, 17.871191232435166, 19.58940705945415, 21.692925153240083, 39.818403643946496, 38.52761437816005, 32.83738293955403, 51.65949006234446, 37.18860741584532, 19.674834320622107, 3.6594608089616223, 0.35221471481265565, 0.1788530624922245, 0.1078435454157091, 0.18330004967508778, 0.08769541768537414, 0.1513225591230777, 0.1209996652699286, 0.12156234918943337, 0.0785858431951173, 0.15420223766517255, 0.13976748642181197, 0.23621879878544041, 0.08445622940217296, 0.12598683636996055, 0.2581337244520264, 0.10294940037232253, 0.16658779564163378, 0.10207030681833144, 0.132435841125346, 0.11235176600636014, 0.22037159591432542, 0.13244655103452746, 0.14516912641063814, 0.1380270878754316, 0.13182822614908218, 0.19427238993587034, 0.11867234378211922, 0.12802455363975418, 0.12901447713375092, 0.21657641165919844, 0.2308644877085763, 0.17094963981259256, 0.21605839832655846, 0.15255441318356222, 0.12671987526118755, 0.0932914218414695, 0.17908417589722142, 0.15819950059296625, 0.1453732735207004, 0.1417706071609451, 0.09379487184266891], [0.04877510593242703, 0.04669573263175065, 0.026866174903848482, 0.06639664887540764, 0.07537080966416868, 0.01907837595940838, 0.06239453278061363, 0.10408537852908335, 0.09247051266532752, 0.046669743098919435, 0.0074099696470394496, 0.07544672131658563, 0.006648301571277121, 0.0789035551790749, 0.019094226318561745, 0.03234653425733409, 0.08620898494677198, 0.07145252274048906, 0.01667599700721762, 0.004354219202087411, 0.026633531238222798, 0.0795369413531115, 0.04891333500704458, 0.04577073125889705, 0.06832729003602458, 0.00616551008856585, 0.07024078614889614, 0.024043330509636193, 0.014021722599864008, 0.01103527055332257, 0.12268497443367397, 0.035013600417803374, 0.029399512756255367, 0.009724277695040069, 0.09772358522299798, 0.041609785985201604, 0.04053196922365216, 0.010189532467554654, 0.036821920319550464, 0.035362484519399946, 0.056827961722569126, 0.024842802630437, 0.07853921142316635, 0.042992298896875114, 0.017598409002887148, 0.026362845561497157, 0.03892355996574606, 1.9305497816493435, 13.92825117034297, 28.65222573280335, 42.38779929376418, 49.7110213002851, 38.03966760635376, 29.6020100193639, 28.72536224703635, 17.597080315313033, 20.20294027943765, 28.07781227173344, 17.047695498312674, 12.982602042536582, 10.7099631140309, 5.2898496197116, 2.671682238578797, 0.8798442588698481, 0.24047309953358867, 0.22201441018091095, 0.2239318210030756, 0.40032800887861564, 3.1400036763760353, 1.2772710621356964, 2.226300782734348, 1.7035055905580523, 3.3471548316940187, 3.379942169112544, 3.5331229817482734, 2.8361239308311097, 6.394492022452816, 3.921439099696375, 2.493336969806302, 2.6414863621034934, 4.778827053885307, 1.1569331129712443, 1.5800725236054391, 2.9515752196311955, 3.878033661073254, 6.931449790154734, 12.696445526615268, 16.797834634780884, 20.443709088910012, 25.244621538346816, 23.256550565842662, 14.462663319803054, 14.585868889285674, 27.000033201709872, 32.73243600322355, 23.37794400030567, 22.117172633447957, 20.712236512091852, 14.48326753031823, 11.420718162290513, 7.752198884564062, 3.443236475990665, 3.869174497742807, 5.511433626374891, 1.4431024991696881, 2.2206753684628397, 5.134010910987854, 4.482701834171049, 3.333731745519946, 7.420667900193123, 7.654799078741382, 4.6798695768079455, 2.2777865490605755, 3.9719533439605472, 1.304492065983434, 1.5334683921067946, 0.31458147290733557, 0.4458683506856042, 0.4345651523720834, 0.18535901822390097, 0.8957534535757957, 1.8145301168964756, 3.5488254552887337, 7.597288796978613, 10.984479015873326, 18.606920011581916, 16.550378184164725, 27.537648947008197, 41.62149367793914, 23.895400724103375, 32.429436829782304, 37.88926039972613, 18.42574377213755, 4.416172552493311, 0.2829305809592047, 0.08426197248721316, 0.025411603762017145, 0.057277073107299306, 0.03754631773899159, 0.08410370638293606, 0.03967548292430659, 0.0426342255706268, 0.025699543654017394, 0.03773996944449121, 0.06307202263645108, 0.017188523235099933, 0.04639473285586123, 0.07694666784617209, 0.04608539421291602, 0.07123312281985437, 0.011441884168063202, 0.06875148824145717, 0.021135214783792055, 0.028362402076562567, 0.04403631968964492, 0.08311841006000197, 0.02925106406872792, 0.09007837247824477, 0.02918620323461871, 0.07709397123225274, 0.10140983177529228, 0.03475487720401537, 0.083102130691611, 0.07726389719473739, 0.022833348259389884, 0.02653127190687003, 0.051444447374031435, 0.048841813038433754, 0.055665568854179115, 0.054919510298678954, 0.03877759340309328, 0.051240572225182295, 0.07857589937386014, 0.007413644475051232, 0.0781904039303622, 0.08326715369138026, 0.04627160337423125, 0.0723583297803998, 0.1051427943692092, 0.09836155260282178, 0.0453243816211339, 0.038249080835451046, 0.041302454492618004, 0.03327057035940309, 0.041706872307845665, 0.022152696375644976, 0.003993187579438992, 0.024170213822095145, 0.02874606273948185, 0.047528002891809716, 0.06517427898342572, 0.02834872357667454, 0.017494410651946263, 0.047233702554818124, 0.012332487235506697, 0.03339739621526772, 0.05734826565810269, 0.056257019375240615, 0.04275011169093271, 0.05198599109726568, 0.043921651649138624, 0.05292649425926709, 0.050068480683670896, 0.03469587311208729, 0.06766418731140514, 0.021599167206835364, 0.04545108873337027, 0.01940775546245277, 0.0555992026572987, 0.03598925935465001, 0.06481603328739444, 0.008921923168424157, 0.03320898455117018, 0.018168357351133903, 0.007368377776020357, 0.058990658576329874, 0.041475613346143116, 0.08576767233711097, 0.1141175756891889, 0.035494163542264895, 0.05830105303996994, 0.06238429784594525, 0.03678610187865073, 2.851010061079456, 17.2081204383604, 34.25594929725894, 48.672624787976666, 53.1039224901507, 41.9007585894677, 30.168510098611158, 29.26070890118999, 22.918581501130138, 26.282604240602065, 27.733594871336415, 26.038915226536414, 17.25608906438274, 13.208462903576514, 5.943047317766375, 2.3293860641218003, 0.8519877084801275, 0.2848735025092479, 0.09607420558290136, 0.3802273326343106, 0.6704560042388978, 0.7150503500334678, 0.7700041044623621, 1.3433876369268665, 2.9007817516403818, 2.8067995559784675, 4.8109370470047, 4.789575819046267, 4.206677780997369, 5.469684898853303, 6.735522497084833, 4.031432900697955, 4.733338346404414, 4.173514631486708, 3.9166849418993923, 3.121782796036813, 4.620740336756553, 8.51943410211994, 10.306065870869546, 16.8438793382337, 20.45718243045192, 26.549284227432747, 29.396436637447728, 29.179635470913304, 17.97030560431942, 16.932673954194595, 30.994220010695923, 39.05332180761522, 31.513545743880737, 28.127696975584957, 24.7523719264615, 19.133772773127404, 16.309252439006684, 9.504145133879877, 5.874704920476483, 5.411548018455506, 5.4931289053732355, 3.835589203142351, 6.781088181080357, 9.022693807078946, 5.156728298433366, 6.975725994956109, 6.386904687650743, 1.2730247287019607, 5.138115671373183, 2.965001737879169, 2.1222277995078795, 1.8075714644885834, 0.9048734545227021, 0.6731375571220153, 0.3895934010224958, 0.2177962074957548, 0.35648341801378036, 0.4760346561670304, 1.4333900977526943, 4.038465220120646, 7.843884777638221, 12.524746714099763, 23.166687104009814, 15.811242826523321, 24.051628728066724, 44.55290448281073, 30.65896522614264, 33.86458304620559, 44.513802374562914, 21.986090944659328, 5.474355461135988, 0.34466121045331805, 0.1037110296648837, 0.025485138626649015, 0.07509372332283566, 0.03605031656221517, 0.10366803681057307, 0.03941276456199346, 0.037716101975210255, 0.027390403124774178, 0.07344887126237154, 0.07105702218870003, 0.02205817070188782, 0.05549145622118827, 0.02989756183758859, 0.04421841878924639, 0.05356586741043195, 0.012638288467461544, 0.02983495521719658, 0.0686353952774117, 0.06571571928479018, 0.03613219220912264, 0.040080544253390644, 0.018880311587464907, 0.07829318994716292, 0.04071622486076048, 0.01682040266572468, 0.1333790792212371, 0.051492691761063, 0.0489962563639687, 0.029087985017066522, 0.048585039518413045, 0.03036984929724807, 0.059106931571037545, 0.024369685880599484, 0.04641039169303352, 0.07851589170675125, 0.05078459286221093, 0.038603078573942184, 0.11190415615396154, 0.04031566046779195, 0.06607806355121636, 0.044255160366094885, 0.22632668846316878, 0.297451930781526, 0.15665362709231917, 0.2995058431500389, 0.1227051838331165, 0.11743673589080574, 0.23494611223859174, 0.24407268621988837, 0.1955288967057582, 0.17276030394338793, 0.11990286484961549, 0.23479367606341842, 0.10483236788141151, 0.09155518315251797, 0.14259120990191737, 0.10016944349533129, 0.16437225404285616, 0.17611598355635522, 0.11050839758207721, 0.07321005101285635, 0.13717144427280273, 0.16067313721343396, 0.08607959269636101, 0.10771942385021718, 0.14293290043790496, 0.11632950135296392, 0.12237516847709495, 0.2059375494718552, 0.13205655099403474, 0.12229129717114473, 0.14849316659233264, 0.20300793731885575, 0.1379716077879552, 0.15399847359907243, 0.17445639196422794, 0.13381686782644642, 0.13596177611860538, 0.1414338502311899, 0.09500899862858558, 0.08732121437788011, 0.11133572657502468, 0.14336964716353726, 0.21406410292031305, 0.15376147663881704, 0.2677239808103731, 0.19167184318986633, 0.16692257606454436, 3.1664764881134038, 18.949690057385354, 37.836041681228146, 55.8435490054469, 62.208763476341005, 49.57828044891358, 41.09325239735265, 40.159406661987305, 30.388347179658954, 33.73609012173068, 38.72940071167485, 24.126140033045125, 19.547939761992424, 14.47423529240393, 7.559810059685861, 4.01782448253324, 1.4958647518388688, 0.5690019998338915, 0.6961650569592753, 0.6583963094219085, 1.412953200840181, 5.828454292589619, 4.331115955306638, 7.006784792869323, 6.591358232882715, 8.201072965898822, 8.88450478353808, 11.640349318904262, 8.411975868286627, 15.252995414118613, 10.44181518016323, 7.298836631159629, 8.39314260790425, 11.028191870258702, 3.7677152839399155, 3.152024515213505, 5.601718743001261, 7.143605399516321, 9.635218977928162, 17.631575599793468, 21.630035831082253, 26.489150370320967, 30.516375303268436, 34.33887604744204, 25.518687348211966, 22.855003803007065, 34.57904277309295, 40.54659558880714, 32.8418367908847, 31.38388787546466, 27.844364566187707, 20.59831911517728, 16.026950632372213, 12.175542020028638, 6.110533995013084, 6.5822495087500545, 9.349129142299775, 4.645890574301443, 6.953007136621784, 11.580435114522135, 10.077367175009943, 9.953478132524799, 16.57599518376012, 15.276356070272385, 12.598085230396642, 6.9658372094554295, 7.727528156772737, 5.284625512938346, 4.8254066705703735, 1.9706120125709043, 1.68917263707807, 1.019486704420659, 0.6000536884511671, 1.0369695050101126, 2.4853216063591743, 4.9795175752332135, 10.844167009476694, 15.550181634964483, 26.876174557593565, 26.34088477780742, 41.10009693330334, 51.08962851185953, 34.42736471852949, 42.309638223340436, 47.59121164198845, 26.291729634807957, 6.9984762322518135, 0.6397431716322899, 0.2250645279643997, 0.11089548648845766, 0.23854006051776871, 0.15083214027747033, 0.2007610167586996, 0.1426405919295165, 0.26776498183608055, 0.15874189084335683, 0.23905039764940741, 0.2576801391138185, 0.12676495187465223, 0.13496786896740237, 0.14449026525741623, 0.1538510476389239, 0.15558861165998444, 0.19287397303888876, 0.17874703592350408, 0.19510960146304102, 0.09693021690773387, 0.1264096326344917, 0.1508734783818645, 0.152138871771674, 0.2849228385715716, 0.2273660552717986, 0.2796779248502947, 0.18953428934178046, 0.11660426644788635, 0.15960105845043737, 0.09371644742186032, 0.14320365123210416, 0.09058740726041217, 0.09948411656002845, 0.08918814000583465, 0.16056312698750727, 0.25527512864960783, 0.1883024965683299, 0.18785867119027724, 0.21232083920509587, 0.1839706983657614, 0.16369722332925568, 0.23273342048689244], [0.0679045780411651, 0.11075706206141941, 0.0314457661607453, 0.037121698185200655, 0.030667547234183842, 0.008926642270037725, 0.07388521196140398, 0.0023389475902677666, 0.046862682342649474, 0.03585845750245837, 0.10722417098980759, 0.04813560637675467, 0.043273598721791665, 0.011520542245688698, 0.015814718827905676, 0.039849051634871194, 0.07295839112973021, 0.022177762772527435, 0.01293829424426921, 0.06951333969951638, 0.04935763919004991, 0.05249144824882669, 0.009634761278697801, 0.02080948568970686, 0.009890232449247232, 0.05940957077508492, 0.04815896439756598, 0.01986121248093344, 0.03647750634099207, 0.01715393436531867, 0.038191608919371525, 0.09602223417811817, 0.016662542588047443, 0.008172313795394955, 0.042889823145683736, 0.03995273397454331, 0.07045432549691008, 0.021629925636995225, 0.04489981186305804, 0.06946232590463854, 0.04725363233216828, 0.053904263768345125, 0.04197717877104879, 0.0585833564400673, 0.02712947932342368, 0.06609186079473266, 0.04740063694395846, 0.10282502599781561, 3.2944190550235013, 14.254268773140447, 29.836550105002623, 40.733198427384906, 43.602443587395456, 32.838494931497884, 25.33803474518561, 21.34038644452249, 12.298906445503237, 32.39043081960371, 22.577282344141317, 23.452765172527684, 14.672942565333459, 12.273027627698838, 6.94284035313514, 3.9396857205898534, 1.228172425781527, 0.6304053565667522, 0.24876944870958406, 0.9244133544064338, 1.6522436444797826, 0.2536684737330483, 1.1159639565214035, 1.4409516920005123, 2.1374689042568207, 3.0615138623022267, 2.4142967981676904, 3.4719107179872455, 2.336407351878382, 7.907052097782013, 3.5110709263432414, 2.085815211457591, 1.5388039187077553, 4.145074996256059, 1.6714556587319223, 0.35172619586510045, 4.403683725864657, 4.3097944413462, 6.95185003742095, 9.813510314110788, 14.428575961820542, 15.311985900325162, 17.95672243641269, 11.576090108963752, 8.733267995619006, 14.390532893519248, 22.717940499705655, 19.325872813501668, 16.904123021710305, 9.834515586976083, 6.077028128408617, 6.372222765799492, 3.8393051585843487, 2.1798572232646327, 2.6555296730610634, 2.866250185235854, 4.368834447476172, 8.517693550355974, 5.526072892450518, 4.1614332410597035, 4.7730528346953855, 3.638046629005863, 1.3687701523303988, 3.0320289154206557, 2.763485557609989, 1.4579372708835912, 0.2766328479253477, 0.4382287074000605, 0.3962205825073104, 0.1879738142052966, 0.3172355385557298, 0.874173676054324, 2.012800290699928, 5.345699758298936, 6.818302158386477, 14.971078980353573, 19.736431221808157, 17.582846033957697, 11.59491160223561, 20.057400734193866, 30.567366115508545, 25.20437409800868, 32.49890200553402, 24.320758235070016, 10.565963099079749, 1.2818250564798233, 0.045757945251440814, 0.08205418369822925, 0.04204768567315994, 0.03605461048503076, 0.01941392247024323, 0.04341042585550778, 0.04768495515529667, 0.013803738984279336, 0.02464177158300675, 0.01797813963475487, 0.07278332471727364, 0.004225916711748728, 0.04199608582102003, 0.036610832452894225, 0.03087968847173597, 0.06496699857375314, 0.04895722418422661, 0.04451541192529183, 0.06541693733344156, 0.03974119794645137, 0.018799596563762715, 0.031239742135268547, 0.008057165034716169, 0.032770958458704334, 0.06641712640562365, 0.006225263510244869, 0.015739469841543226, 0.04144924076934976, 0.03221531105678409, 0.08486648480738364, 0.047381691589591005, 0.01900819655988486, 0.02040697543341066, 0.013213472069060851, 0.08208081291447725, 0.031274767675166654, 0.010759030739145895, 0.040553561411798, 0.03325479660904215, 0.028807231029796026, 0.0341308756070512, 0.025277772032084967, 0.027828080647234476, 0.05903309218645577, 0.01927317488157461, 0.055926460096792835, 0.05006251285874075, 0.03071559243835509, 0.04745536626526906, 0.0424423128847153, 0.03951083530762023, 0.03480767598375678, 0.11549960596547013, 0.020634873184345422, 0.011738545013471477, 0.013157878026005723, 0.03773395565428561, 0.007417186195286172, 0.14021483580431632, 0.05320631170405015, 0.028529857405491417, 0.040433477129667036, 0.03665323158906352, 0.06876265014251394, 0.03223621376579808, 0.017461233299165484, 0.0182073378199411, 0.0569123080030324, 0.05499049217530316, 0.05565005174327282, 0.025801094354040204, 0.004548336784805982, 0.017976209093185685, 0.050925514735882325, 0.033944474923754894, 0.00692536540877735, 0.03148014627156719, 0.05579291564983226, 0.0169363807165815, 0.029076194923911846, 0.05840965749455556, 0.060184127801368316, 0.032056056699084665, 0.017691712766405077, 0.049051261476932034, 0.030698947262980288, 0.03507522069999287, 0.0432928811548458, 0.04116814778817277, 0.36136704466996655, 4.327469621935199, 18.253690965713993, 36.295118947182935, 48.761850864656516, 47.54708889992007, 37.79137765207599, 29.687178404100482, 24.608324843068278, 17.953837533150953, 36.976187536793375, 22.526748488026282, 26.774332177254465, 19.508488562799272, 13.041789627844288, 8.541856331209983, 3.3870541616793606, 1.050861682141981, 0.39780917307061536, 0.06895551277745156, 0.2220951558481301, 0.9764077418273496, 0.31739442519122557, 1.4926154358733086, 1.366904329869055, 1.4953053237930423, 2.700370454019116, 2.854760337260462, 3.8930200569091307, 5.8208983367489235, 4.911784616208846, 4.402439353927489, 5.143856550416639, 4.110192868017381, 5.3381197779409355, 3.148872890780049, 1.976156405383541, 4.673578095051551, 5.065898952945586, 10.52364464729063, 13.61720133212305, 18.61757513015501, 20.681820492590628, 20.97706121783103, 15.349080735637298, 10.203847923586446, 20.056049477669504, 27.887836194807484, 22.380059688322007, 20.823269005744688, 13.222120596516518, 9.382679135568681, 8.296704273070059, 5.003081704339674, 3.0723295529042525, 4.646448041162183, 4.78029009795958, 4.083622977618249, 8.710849688899133, 8.673817611509754, 5.384773919659277, 5.86849678908625, 6.358523887972678, 4.424988079455591, 1.7383025298195502, 1.1743424304070011, 2.0012274600805777, 1.3893129532375645, 0.3278284201458577, 0.19550960661182482, 0.21662801534177797, 0.17543280166724037, 0.6422084425726245, 2.8147957978710054, 4.815916495938455, 8.153075902692734, 15.94859246284731, 22.85790047337932, 21.39524667493759, 15.599479944475236, 28.44602281047452, 37.297006037927446, 29.30211344072896, 37.108332187898704, 29.068875581987445, 12.89291802913912, 1.5638195699261082, 0.09464049501524818, 0.08478205425724869, 0.041775624868610216, 0.025413919262768283, 0.06579805841489185, 0.018026803454924977, 0.04811140182878702, 0.05973748705019394, 0.02239894001714645, 0.14696817664850145, 0.05634342643222021, 0.06599523412484316, 0.06012179122696962, 0.024921705856198267, 0.06192023242493311, 0.09142655699003129, 0.0636948521188911, 0.06652173571168415, 0.042075379751622684, 0.04584975705872621, 0.009293421227935581, 0.034297013264750285, 0.024723409742657698, 0.04361554206679425, 0.10828720991529765, 0.020925201355449615, 0.05788551928896097, 0.00809479431594692, 0.07198388898564924, 0.08978195007770293, 0.038197821892437436, 0.0538734402207117, 0.03471143618826905, 0.034770922915589426, 0.05922379445344691, 0.03792901313112628, 0.04384484367385026, 0.03385483880617446, 0.09460841891385856, 0.012634732861882977, 0.06793225679786936, 0.038448271356643214, 0.19205862566107706, 0.1364018936311045, 0.07477770439319073, 0.11289483041412408, 0.11018701603696232, 0.08571334904240024, 0.17315870030753075, 0.11536464425584964, 0.14311921302108996, 0.14031828831761115, 0.3111145879712797, 0.17944031485146095, 0.08794484059176139, 0.0599198542805689, 0.12194720111907491, 0.0744578397021659, 0.2691501607337306, 0.12386276566934203, 0.1750977301309186, 0.1515555264608514, 0.1273213538731779, 0.19214404446463432, 0.12293900152848614, 0.07161191499401486, 0.2022700107866718, 0.19272358997935252, 0.23272039699217967, 0.25621939330331744, 0.15315838158130646, 0.13821163845639076, 0.19099577059668882, 0.23199052970495918, 0.06988637089248627, 0.1627339443732654, 0.1678987559411795, 0.13154975318860623, 0.21596775480335761, 0.08874977683468212, 0.202191548061467, 0.16675501731374573, 0.12521027602375517, 0.1086005628589661, 0.14295735396444798, 0.18806286426561494, 0.12715122872783294, 0.2751754729017135, 0.16981749975633237, 0.4585573714106314, 4.7722046221456225, 20.223787676903513, 40.0356323488297, 53.5083737680989, 56.06674755773237, 46.80664739301128, 37.73251464290004, 32.25881568847164, 21.078485865746778, 45.328262928993475, 31.23270403954291, 33.663153648376465, 21.50147230394425, 17.496412684840543, 9.941636496974576, 5.466587697305988, 1.77726490362998, 1.0040464168114047, 0.7634945634392001, 1.5940802880833227, 3.1760112797060325, 1.6565757797610376, 4.890576360687133, 6.554745849101774, 6.456647861388422, 9.261140573409296, 8.01378910579989, 10.012440181547596, 10.560653190458975, 17.474170884778424, 8.566431941524629, 8.992122853955916, 7.801410901931025, 9.714844073018721, 4.739259164179526, 2.276946916695564, 6.9680685477872055, 7.112700554632372, 10.963915990244958, 14.467314270234878, 18.84039321253377, 21.630300591068885, 23.0853626420421, 19.611115417172833, 14.352696730244546, 19.22484628615841, 29.016115780799623, 22.76568751181326, 21.328132960104174, 13.037340679476339, 10.847942290767547, 9.597643652269918, 5.516747457365836, 4.89340340898883, 6.662269292339203, 5.447790228551434, 11.21234126629368, 17.815979949889645, 15.828410060175004, 12.72277835876711, 11.895437721283207, 11.897958824711463, 8.20114209767311, 7.99955286325947, 6.172282397747041, 6.301270521456196, 3.292024693181438, 1.2310230083042577, 1.2371083204784703, 0.6842112048499046, 0.5303106372875552, 1.456457311587949, 3.027965094774, 7.308003210252331, 10.606423327999732, 21.237485024236864, 28.08336046434218, 26.10215756200975, 20.718202437123946, 33.259879081479966, 41.91893093047604, 35.25801681703137, 43.055155277252204, 32.46187679229244, 14.677725895758599, 1.896119583998957, 0.17757558023496983, 0.1743119384252256, 0.14521210394319028, 0.16530548703045617, 0.2521546686729116, 0.21383303548059157, 0.1017139993247486, 0.24209028049822778, 0.09590585776154073, 0.31887395547763, 0.13794709297437824, 0.10728398713493541, 0.14285390145115315, 0.14575737468417616, 0.20148438762032217, 0.13877011655319121, 0.11715614852765877, 0.09983107778093508, 0.14525425410078419, 0.14041624031960964, 0.17771929832956485, 0.1497145558917715, 0.10818528957785138, 0.09541301807809262, 0.1429342334308932, 0.13142966124559605, 0.20065610867834863, 0.1574772482197131, 0.2854497232023747, 0.32530078964848674, 0.12608452790206479, 0.1437812968487701, 0.13347073398049802, 0.09271035181178201, 0.2233760242140101, 0.31342958310438745, 0.21987592170555748, 0.1900498818365797, 0.25016775835425625, 0.11269446011752852, 0.10545465344142531, 0.16532825516356578], [0.10306709446012975, 0.04686928985099639, 0.021601191594175274, 0.0599218231265343, 0.028373924038943746, 0.011186846794800894, 0.06688798702652417, 0.09275237939530805, 0.06915297193993485, 0.03252757615560005, 0.05491945284208464, 0.04185318361006437, 0.06456345409875916, 0.030295919897335193, 0.12794542441805526, 0.03238353630407684, 0.048345794090099876, 0.019239708330602418, 0.027681234998688586, 0.03535088211778672, 0.1076479631686403, 0.0521452799289217, 0.026484670778436047, 0.07043122794599303, 0.06576632705306815, 0.012765880411250458, 0.020854363120311213, 0.03248401256578584, 0.08499606857977568, 0.010588871119844337, 0.015471803508849155, 0.03210828474332248, 0.05514957799365925, 0.07384493871922455, 0.01824242847731277, 0.03804687192783721, 0.0785369667855482, 0.06752710353823439, 0.06338108931818316, 0.06736151363340116, 0.024039452189519524, 0.05667139633348393, 0.11177388290243764, 0.12869226055279856, 0.05014257287726768, 0.04103304052184667, 0.02676322417814405, 0.024868137158092954, 0.4583730812995665, 4.583454776194788, 12.66932527865133, 26.509442752407445, 41.0528519845778, 38.42134560308149, 35.01675967247256, 22.724069203099898, 27.82346617790961, 29.776569220327563, 31.873754647470292, 25.40279699910072, 20.723909485724665, 18.545546685495687, 12.745250598076852, 9.867834160404822, 4.221951000152096, 1.958664105303826, 0.6831991720584132, 0.45343622685440127, 0.3873451474693514, 0.2839565259074011, 0.49939574133003917, 0.5486673909810282, 0.8698230933758521, 2.1572910922188915, 2.211625234734628, 3.7017863700466775, 3.911221325397492, 4.118008190585721, 2.862975496438242, 3.6622672648199144, 3.2924917003800793, 4.213788547823507, 2.1596437788778737, 1.971235056557963, 3.004932691974025, 1.3302821401626834, 4.589333918786818, 4.470813620475031, 7.66094837457903, 8.688236244263189, 9.206883407408192, 8.2423343389265, 8.09214678502852, 12.712489981805126, 12.161444041036791, 12.041091995854533, 9.052317507805364, 4.7154670473068, 5.784734574056441, 4.151359613864653, 1.6004815962045424, 0.8401056847745373, 2.073813984470983, 3.5240794670197273, 2.3778079690471774, 6.553649056342341, 11.973340895868118, 3.5511327895425984, 5.862107738371819, 3.6026533669041054, 0.841308136380488, 1.7762514612367077, 1.0429707313737562, 1.240517840750756, 1.0273981863452544, 0.24477298251323162, 0.11545246091460991, 0.413438469892548, 0.8322225174596234, 2.789164089387463, 3.6202314688313395, 12.45693579796822, 16.809121254951723, 15.46722742819017, 8.815392621101873, 18.41315100269933, 19.46312831294152, 21.75690881667599, 31.574919069966963, 34.807948373979144, 28.623217844193984, 15.202384091192677, 3.1847902795960827, 0.09802292641853133, 0.04976975618891659, 0.008191591440399569, 0.057825687822074666, 0.06811064803191731, 0.02989187746519043, 0.061128059206830884, 0.024622774517704404, 0.043800356948087295, 0.044189656018129284, 0.01738908122323694, 0.047976095379600604, 0.030364948249752485, 0.01460590773457361, 0.0330628034838986, 0.04720329652510343, 0.021984942272425662, 0.03286113083783177, 0.028553669333397865, 0.05415047676632962, 0.03841754740043994, 0.03609779486132245, 0.04157559165070134, 0.043846881467728846, 0.0474489656006617, 0.09737097027321016, 0.05928338460263707, 0.0341229121230783, 0.04189141522792559, 0.027855579373276526, 0.05709886190391356, 0.037884009296014425, 0.04309143450471663, 0.04319225167555194, 0.1161184364689454, 0.01883765198140135, 0.07238336553376529, 0.08345353522247846, 0.01445383449355441, 0.06052021440418978, 0.01809796344699158, 0.013525257405314236, 0.08165633125651268, 0.0694193100676902, 0.03968242751134019, 0.0629221375340656, 0.042428868041644176, 0.009779561472485864, 0.03675872955711619, 0.020700017470986615, 0.039879530442938696, 0.07876577426589305, 0.008956008335395206, 0.0360034319812492, 0.03355921696751349, 0.06827888094008931, 0.036453520128082846, 0.016417298691287156, 0.018392813452068838, 0.05815313295311025, 0.03726902455391903, 0.06648858708720054, 0.04092270087811255, 0.0907457652952402, 0.03232229906584948, 0.08157749314822497, 0.06639235878303167, 0.041845917266102574, 0.030540047220945842, 0.06515612269962026, 0.020191865605151942, 0.06105462584884898, 0.01694277180508981, 0.024312524230129296, 0.09444806905042741, 0.08717728943954553, 0.04619646547061782, 0.07591926733091955, 0.04724267344441145, 0.02962071489873192, 0.0872430197834488, 0.04667287639852974, 0.032349008721329515, 0.009790482055846482, 0.030752646196032726, 0.0738097446399831, 0.10629250848245238, 0.017892584850591038, 0.036652771936308955, 0.01896381325599167, 0.02851604675543645, 0.5682537464364883, 5.613741788171954, 17.62012031770522, 32.15795193949054, 48.74731063842774, 42.302150418681485, 38.49217968602335, 25.309893700384325, 26.122769617265273, 35.25984464153167, 27.678363976940034, 29.003450447513213, 22.578235480093188, 22.376013763489265, 15.839353472955766, 10.321409202391102, 4.836313311130771, 1.9670543002505458, 0.4690797422682086, 0.2742127761725457, 0.22360076376747703, 0.13141060097803994, 0.33670069890156873, 0.6452550823169371, 1.3342992600894745, 1.1638139308460298, 2.1628191826804994, 3.027618210161886, 4.045561032910501, 3.7874148978341013, 4.214190100469898, 5.061852537816571, 4.817860030358838, 4.883022856327796, 3.587050423506768, 3.83241355419159, 4.625754596725587, 4.113150335127308, 6.293428232592921, 7.930074449508422, 10.226766332503288, 12.039244559503372, 13.955705800364095, 12.090812940751354, 9.811182387413519, 16.482277993232973, 18.03751345603697, 16.846883873785696, 13.465809610582168, 6.701174791782134, 6.335421127657737, 5.31901587401667, 1.8822176009416582, 1.9669607762367496, 3.643992451890823, 5.977258230409315, 5.184466319699442, 9.113815369144563, 3.4718283482136267, 4.036856312905589, 4.701953011174356, 4.585082069520028, 1.880485506788377, 3.2266319182611283, 1.1138674496643006, 0.7011521054852394, 0.5783829609713247, 0.3906164961236139, 0.16626427671121013, 0.4792784869430527, 0.5237106366022941, 2.950405372727302, 5.1983897532186205, 13.877271144620835, 15.937008723135918, 19.864194585431008, 15.272202280259902, 20.435228924597464, 18.02863124878176, 26.762865128055697, 36.007852400502856, 37.43982345827165, 32.81597072078336, 18.48283975355087, 4.4813427329063416, 0.17518196915907247, 0.05061555939215807, 0.06356717973587013, 0.07120554365458028, 0.023497770570458907, 0.011714219806655761, 0.05873743587383821, 0.051803524275460554, 0.0894526701660887, 0.03643340265919124, 0.07430899647935744, 0.03873019937365767, 0.028572022884843812, 0.0109684475765173, 0.002714340488666729, 0.023198437035804795, 0.03366766437407463, 0.02000884528482153, 0.015125863100101632, 0.03875292920237107, 0.059309580979207834, 0.045851277743255904, 0.0359651850416295, 0.02055382108195655, 0.015236517797494608, 0.05328410793276084, 0.06979113084173973, 0.07372219611199633, 0.024505162784349055, 0.05783620237883541, 0.06344079821100158, 0.0553870844023843, 0.025525448258004846, 0.019250485272477233, 0.017556486756450707, 0.04914389299829641, 0.010419759125779233, 0.03290407006598769, 0.02387307129890448, 0.05736808435270383, 0.0977553012630632, 0.03991896481884103, 0.025167627740771543, 0.15875024120173148, 0.11397321408073749, 0.15663660461864165, 0.15286806490152113, 0.2166621522196839, 0.11034441646188499, 0.09372746376621147, 0.2718408760284224, 0.12022967795811354, 0.13152421181721072, 0.10510290417099193, 0.22038797487414655, 0.16503792316202195, 0.11889901387715533, 0.19099183290475802, 0.17250369513227096, 0.22833935465783844, 0.11579579087875544, 0.14883212985530977, 0.11345724620285536, 0.1945322163162693, 0.0963789860026971, 0.1477803830658236, 0.20603567001319703, 0.24230922842698716, 0.10177059790059444, 0.21015034357626594, 0.21570932270298082, 0.23950649575600702, 0.13342346635556993, 0.12459034235366892, 0.17960171425534835, 0.19905388174999147, 0.18269186779376, 0.2210441904683267, 0.17049980830521355, 0.14614415715538687, 0.2704825408516392, 0.15960139552912406, 0.14576929501227795, 0.11996212941143783, 0.10035724994996864, 0.26044577780750494, 0.4120360693383602, 0.14904945367766967, 0.16626891920403128, 0.08794119401324181, 0.17563725521247234, 0.7153921478217649, 6.113722881963176, 18.976513185808738, 36.86343900619015, 55.54926926089872, 49.96610087733115, 47.60487325729863, 34.500862090818345, 39.40072221140708, 43.797589348208525, 43.78262942837131, 35.24766568214663, 28.847773536559078, 27.006146215623428, 18.417961789715676, 12.373556014030212, 6.527233854416878, 3.1046891068258597, 0.9252949071026618, 0.7565282501520649, 0.7445381774056343, 0.9367183199332607, 1.4198517919548097, 2.0339835411117924, 3.7521451903927714, 5.394598966644657, 5.265412272945528, 8.205786183957132, 9.137517271503325, 11.781913541978406, 11.396536750178184, 8.445244431495667, 11.255167665020114, 10.919805995879635, 7.3929141894463575, 5.062395295789165, 6.250717543786572, 4.498442305672554, 8.939315984326026, 8.048657015446695, 9.989190332351193, 12.355541548421307, 13.474267221266224, 12.692185832608132, 10.814043206553306, 16.84126703969894, 17.904550990750714, 16.48718683950363, 14.67685709076543, 6.623984998272312, 10.404966473579407, 8.277619980996656, 3.0998025690355613, 3.7268765462983042, 5.513884127140046, 11.536325120156812, 6.607343362223718, 16.62726252309738, 19.914265601865708, 13.122691454425937, 13.390733484298954, 11.53502191266706, 3.472237010155955, 6.080663675262082, 4.517036301474418, 3.058342380869773, 2.4079852142641625, 0.9954509103009779, 0.5984453328194157, 0.7232319239166476, 1.6161700963012635, 3.8552483675941347, 5.664416849613191, 16.704966637396044, 22.009574174880985, 22.718069937921342, 16.00489906726345, 28.301524654511486, 28.749271054421705, 34.37714661321333, 42.89198467808385, 46.101181660929036, 37.805113792419434, 20.693615059698782, 5.537808133709816, 0.1881764138177518, 0.1441577830982785, 0.14850096536740182, 0.17561511527146065, 0.1670687303187386, 0.15644653820462767, 0.36955162161780947, 0.18722660268747038, 0.218831958369382, 0.10553603496162162, 0.17714177528696676, 0.16553197326439043, 0.1274773983224746, 0.1474057967143674, 0.15243038354862123, 0.14281924363345871, 0.12980342512169193, 0.08717069342251747, 0.09070534649635516, 0.1491351023076042, 0.13835797657168683, 0.119968602854398, 0.14120102078924257, 0.1474510725106924, 0.09665921330451967, 0.09293522160019606, 0.1644025604811407, 0.15846810634097747, 0.10030242103722789, 0.21710809200040757, 0.18751270588367216, 0.20687433710742384, 0.09299526757170117, 0.1348707596621206, 0.20420861160082204, 0.2184072545459194, 0.1047461906508092, 0.1587469163801401, 0.11244921239032862, 0.15077943342827982, 0.2256456975855174, 0.1639585972072617, 0.1680544403291518], [0.019405395911645987, 0.04856794426638273, 0.04054149169655096, 0.04721007257279369, 0.05108416388412157, 0.010509334913935634, 0.10188289106853547, 0.045876792301574064, 0.07171339866134428, 0.02556181828221006, 0.021301009617145025, 0.040057699511488604, 0.024602907942608002, 0.03053853994295482, 0.03201793041831303, 0.04770654734344252, 0.11377880394819284, 0.025530427829512668, 0.12866791427856492, 0.008969210903160274, 0.07473001541990427, 0.04258091351197612, 0.04651221243904964, 0.009062122046617011, 0.04521377384662629, 0.035847490953822295, 0.13062807280690442, 0.011342793567887238, 0.022416125284507874, 0.021965387878158403, 0.017498269819864826, 0.03500230828179948, 0.0873582087637436, 0.0037143784978862612, 0.010138179678770324, 0.04872823667321955, 0.039357587079247164, 0.022392638943969242, 0.023043790696969917, 0.06728727205265915, 0.06391722063023238, 0.061332846000309915, 0.09343276506349926, 0.07967896639339386, 0.09039109722981531, 0.037420123905664494, 0.04099298944516529, 0.07649514328448043, 0.05218354985117913, 0.3966881719327742, 4.640451227464984, 15.888105592420025, 23.902945403129827, 33.3845986858491, 42.968996494047104, 36.33552720469814, 28.7063838589576, 19.78175420914927, 14.461722931554242, 23.827014200149044, 22.753794885450795, 26.68378818419672, 24.90978644740197, 11.629906008320471, 7.53812131381804, 5.16595910633764, 2.5232563191844575, 1.173040448657928, 0.8690152076944229, 0.19872348335000778, 0.1739506820036519, 0.2476448469584988, 0.5532720084151914, 0.24825678267065557, 1.9872841695624015, 0.9689540740463042, 4.8364182345328794, 1.8656162917613985, 2.4864936595962894, 6.342500515522496, 1.755426494825271, 3.457266303800768, 1.755402102585762, 1.5465547673163877, 1.817090321452387, 1.8925472853645202, 2.465015986273366, 4.041648958959888, 4.005694552775353, 5.16542713488302, 6.8333086563694865, 5.43932036046059, 5.127075179930657, 6.5439701176458795, 8.246797015590053, 6.611221605731595, 5.569695532321931, 3.6360187636267756, 2.1280520289174976, 1.541209557364064, 1.966123472779028, 1.840499026640769, 3.3248522348942298, 3.7714697276392295, 2.9146564006805424, 5.954825705097568, 3.213250752418272, 1.0614780673096258, 4.134185025768896, 4.481130924917037, 3.787185194030885, 1.3456622439046062, 0.30720502678905764, 0.5966877432600145, 0.3923302960972632, 0.370197372450944, 0.4134110133013418, 1.6349513852788558, 2.380292300255068, 6.097425924193475, 8.130013346672058, 19.742053939450173, 37.07861631147323, 14.349996178380906, 16.885523142353183, 19.025015254174512, 26.647025769756688, 24.832594202410792, 26.717330332725282, 30.550847053527836, 16.003315410306378, 5.084596891557017, 0.2171156303055825, 0.09847357763998932, 0.054466537830810395, 0.03869415110638065, 0.034684849106856895, 0.05122690138617351, 0.037552649455685774, 0.04851884952175522, 0.02850255786230968, 0.035197752633041916, 0.019863606505696813, 0.04767153329486328, 0.03328302694905189, 0.021217483050760724, 0.01877630366042497, 0.07065242817324978, 0.11027356098976829, 0.07139445327582859, 0.04640296447060762, 0.04402413123076962, 0.020049559027557413, 0.11848634529498317, 0.04431689939191265, 0.09940948427444506, 0.1106722791108393, 0.04158091979221471, 0.04524812905959064, 0.02568235455621635, 0.07153280875495366, 0.03161011883358081, 0.042470412989777905, 0.0849884460049291, 0.09884650158064981, 0.08935094901150273, 0.07556291387206124, 0.03409101605235088, 0.044252406280007095, 0.016531219796067285, 0.05396920121124676, 0.005848101188143295, 0.023695955601250453, 0.0695995016083602, 0.06200334147339868, 0.02312991238619772, 0.03327988981900196, 0.07283164954353726, 0.05772430757661501, 0.0610515691580311, 0.03595694193556424, 0.048146174559670116, 0.05807233365973639, 0.004795310125055333, 0.04449682280180916, 0.03300154709347314, 0.036684645024398645, 0.03645838861684165, 0.031542536472120596, 0.024388441628205682, 0.046376557419857675, 0.05082791130388937, 0.07969074116479005, 0.05868880461240488, 0.04093361763103355, 0.08276292994137734, 0.03104043861610755, 0.04730748065236596, 0.06511485354313928, 0.008280885691243795, 0.014527725589071071, 0.054321475251908266, 0.024985174325505094, 0.02655531366115376, 0.050874952932879816, 0.05812487580002316, 0.07054254052139099, 0.032692212280967546, 0.03408713964745402, 0.00966104671298977, 0.03734969361234577, 0.06050671593496396, 0.024242249069615238, 0.05961245384007212, 0.05151265601236975, 0.07371154748984883, 0.024932653252636234, 0.03925465550574084, 0.03252373422465978, 0.040114049108759056, 0.028504340931953445, 0.00894424697053769, 0.031693934598156524, 0.08862488918126592, 0.03055705820330449, 0.5671191395771119, 5.9030803268955605, 19.21681719441568, 30.909451707716915, 41.249880483073575, 46.89258260111655, 38.03761228438347, 36.52926483461934, 24.23402874700485, 16.681726594125074, 25.2372415988676, 25.556820631027225, 27.094105366737615, 24.69697040896262, 18.137969278520156, 10.664432241070656, 7.093214709912577, 2.5515275376458324, 0.8902538615849711, 0.4783532672351407, 0.18391786894250303, 0.1282042778667904, 0.09028819629982596, 0.34504823807266455, 0.3742195792015522, 0.37416616755147136, 1.8571291407269819, 2.0863525761711985, 1.9136344377071628, 1.7377514368103397, 5.476985900632797, 4.597696902290467, 2.288746141618298, 3.3904244582499232, 3.0993870429454313, 2.9551918900782064, 1.4883910431977243, 3.7920494233408286, 6.207051267546992, 5.432538092136384, 7.240748780388986, 7.716201822603903, 8.549726566960736, 7.173585545632148, 10.758920177336663, 10.400237075744137, 9.946506119543507, 7.707075938101738, 4.504655830321774, 3.240007200548726, 2.262922727292584, 3.8505854049036583, 2.547492399331062, 3.882721874021715, 5.816305731573413, 6.252475255920041, 5.535387541017225, 4.121632460624942, 2.401518696738828, 2.3245161964047343, 0.8941903277750939, 1.0755357194331385, 1.2030949972329603, 1.1301311898616053, 0.5173687156169645, 0.1624044039917569, 0.5179674899385822, 0.2208545837070673, 1.223964703179175, 2.288271534827448, 6.997466221932442, 9.779835785588912, 25.82477734934899, 35.8303729949459, 18.763210773468018, 15.007933570492654, 18.406771267614058, 32.30750799179077, 29.52704764181568, 34.0779717506901, 35.504082787421446, 20.467733606215447, 6.139308502597194, 0.5879727270333999, 0.03661010466936616, 0.008952053406486108, 0.029113691097365755, 0.08104870861936962, 0.10386230904729137, 0.014740610889519655, 0.026988358266891974, 0.022633136926038612, 0.07836970680904004, 0.05462725924688482, 0.049346952263506196, 0.035874629618539926, 0.03315361554644281, 0.030131789389997724, 0.03611439598664161, 0.019432103651906216, 0.02044448884384286, 0.04901827373091252, 0.030237496117009755, 0.029984493664796316, 0.09790320219772478, 0.03185294380772018, 0.10531723258956786, 0.02603331858652734, 0.027430387168762185, 0.04144330358793659, 0.0655399174279263, 0.05265072941960347, 0.04331384898133336, 0.011380763758244294, 0.12425966816203249, 0.06105377932169265, 0.08545170703362073, 0.07594435671043974, 0.010989749608861824, 0.01014860613541978, 0.04690443030408314, 0.01304137903536039, 0.03153760286588823, 0.044756898160783515, 0.051660453525161555, 0.04615506990962932, 0.0029087587608955805, 0.17422313351304303, 0.18214094332389294, 0.16397690670865198, 0.12894601951683723, 0.1643666769227674, 0.19560017352623327, 0.22679508994183234, 0.2310217349159141, 0.1663966720262843, 0.3089616663994328, 0.12141368982772674, 0.17698878752848796, 0.12778352705701707, 0.09656054117987234, 0.1888807244118183, 0.16652448613557125, 0.307781707134939, 0.2282685681336349, 0.19660823798227697, 0.11596010907763436, 0.15158616997782262, 0.12605698704118692, 0.19484533177268124, 0.057842507282452243, 0.14337053582552942, 0.22317560029125985, 0.2112188217260184, 0.1455704492306517, 0.11648700903019599, 0.13235295041193887, 0.12512753086705364, 0.133952021058048, 0.11219480225155432, 0.16720794381633883, 0.12832295254714068, 0.16613039518556288, 0.25433587421092296, 0.19593118479655636, 0.10166857031083877, 0.15506203346435102, 0.17349259206844916, 0.12839672681424888, 0.20524849934924036, 0.21361466977865468, 0.19320683824198862, 0.07289264546406847, 0.12657221947466174, 0.14995363661118094, 0.15060136395116008, 0.6597251348918485, 6.509365987393164, 21.281682291338523, 36.68342574950188, 47.64852531494633, 55.497038979684156, 48.74541613363451, 42.78579827277891, 32.11676116912596, 24.189733420648885, 36.13957735799974, 33.64622469871275, 39.00635926954208, 33.874985171902566, 17.63199725458699, 11.532855783739398, 7.741961008118046, 4.018579783939546, 2.307648288626825, 1.5043496965400636, 0.44693842229823916, 0.6372421703511669, 0.8128849873619696, 1.7509797527905435, 2.251135269480367, 6.519876958862429, 6.583272757068758, 10.05943900154483, 7.430822916569249, 7.3941472845692795, 14.636540028356738, 8.102653834127612, 10.228003840292654, 8.950445709689971, 7.498232280054401, 5.322542575097853, 4.668378503091874, 4.90085885409386, 7.234395521302377, 6.274565554434254, 7.131793672038663, 9.143001725596767, 7.811191822251967, 7.804125672386539, 9.997738157549213, 9.913291488924335, 10.355865263169813, 9.667352014972318, 5.969149220374323, 4.180539106169055, 4.354725681966351, 6.038114784225342, 6.584633819518551, 9.465589215678554, 10.43657881598319, 11.496617986309914, 13.881284709899658, 13.304543322132481, 7.1838891217785505, 11.642276183251413, 9.160246426059354, 7.457974543494563, 3.7829460924671547, 2.1017630782819565, 1.6706377219769264, 0.877623278046808, 1.0293066645822218, 1.1673843908694483, 2.1716785911590826, 3.3824166943950043, 9.012046533246195, 11.80453287016961, 25.88140460752672, 43.252462264030214, 23.030045455501927, 25.616905458511848, 28.32191509585227, 39.064363279650294, 37.01974153518677, 39.46278979701381, 40.349896569405836, 21.331378721421768, 7.846896177338016, 0.7329617308512811, 0.224675094828971, 0.1809779146025258, 0.10877323141621967, 0.14224055613721573, 0.24271353898990541, 0.1425892487168312, 0.12593944617096456, 0.11608462134796767, 0.11256602547702291, 0.15535449519032435, 0.12445884336146618, 0.08730378587760272, 0.12243802599128216, 0.10648750850269872, 0.15168346314420625, 0.24296049509317647, 0.266117402502606, 0.1686288530547773, 0.08073323361215093, 0.08319711027246329, 0.21278683516767719, 0.18575928384257903, 0.19464011213952498, 0.2240362541089135, 0.12223806938216572, 0.21164813739878519, 0.1076671306885058, 0.14070170000195503, 0.13851718496411078, 0.1536703734628616, 0.18529624497938543, 0.28398186809593634, 0.19673784473730674, 0.26831598291474007, 0.17214125893529386, 0.14896821771417895, 0.08666830062265359, 0.11279537687979399, 0.07077717793083961, 0.13953646494736596, 0.14522014786639523, 0.13681211839279822, 0.14982214527985743], [0.02671584355524711, 0.060017660725861795, 0.018059021282580592, 0.05389652244987027, 0.03685168283540876, 0.0361448020163563, 0.0481583247141492, 0.012805265949047621, 0.023909889484545397, 0.02504187057756128, 0.05029988137163943, 0.011098355021057351, 0.025113959451236074, 0.01909539077220665, 0.08652695740062384, 0.03270909685881869, 0.03266572096054593, 0.01591071156003783, 0.0708871192088531, 0.08970566304220308, 0.06529031832131647, 0.03475532153501146, 0.04444997652523941, 0.013902094140047989, 0.05984223808252043, 0.0554578326221916, 0.03853572795407907, 0.03627040213154208, 0.10019467843155708, 0.030724099844754226, 0.038490712627648346, 0.10635091502579952, 0.007008312621168913, 0.009134338282409215, 0.06798494066442214, 0.021441793594990047, 0.04804868987130542, 0.02358654292390472, 0.05734755319633311, 0.08113025101803004, 0.056905217859293186, 0.02792464794530984, 0.003668907349140594, 0.05004528354132368, 0.04771538033720948, 0.061313778071874575, 0.05767281114634487, 0.04805757649122708, 0.04748655370466652, 0.03514696483410174, 0.34488677738174317, 3.511183204189424, 10.95359819550668, 24.835839963728382, 40.967944437457675, 41.474138075305575, 36.24856825797789, 35.362226347769464, 24.18320659668215, 25.202707090685447, 18.351763948317497, 24.946390005850024, 28.206181641547914, 17.39344850663216, 11.509303912039726, 8.52823393960153, 6.0119113902891845, 4.566582700898571, 1.2329251126896952, 0.8343760212582927, 0.2363999939012912, 0.653845318142445, 0.3292024448033302, 0.4959946786684375, 0.15492475050831997, 0.6895114914063485, 0.8909261190602857, 0.7302729460981585, 0.9176764384873453, 2.1806446390767253, 3.734705352014111, 1.9249292703405505, 2.565527702531507, 2.8111886882012893, 2.783702434070649, 1.4756716547473785, 1.5132951520143019, 3.95816425161977, 3.580895244113861, 3.147875628163738, 3.3582061096545193, 4.750381044803127, 3.383306827275984, 3.9442873962463874, 5.206920908343408, 3.813595492993632, 2.2050332013637792, 0.9020664470811045, 0.200813279276894, 2.0699791321831364, 2.3369307431482502, 0.7477654300389752, 2.7415509281619905, 4.364938553302519, 6.130852362801952, 5.26782404030523, 1.0738736150726196, 1.9876206353787456, 1.3352533766338903, 1.1599202430055988, 1.2425230299272847, 2.0916619944957, 1.4574803147585162, 0.20399913251880678, 0.765710273577321, 1.102694823376594, 1.909366776385615, 4.551846846457451, 7.651351805656188, 10.009506248658704, 14.873233495220063, 15.054205771415466, 53.83112992009809, 29.046957377464544, 19.846208557005852, 29.04732019670548, 27.267838908780007, 27.69692659378052, 21.512068586964762, 17.50585186866022, 7.0200090639052855, 1.11715795051667, 0.06692822962518662, 0.047823161247276494, 0.0484643500268219, 0.015265750755075247, 0.07829122876207675, 0.06768880937729152, 0.05880892336849244, 0.06813094936191075, 0.010493864725914695, 0.06677223114116539, 0.02197071218923215, 0.0555480701187926, 0.04565327465834637, 0.04097279153704163, 0.05927189711421248, 0.02221696732205249, 0.0764805876139191, 0.0639286813055796, 0.030960518408626802, 0.02558164655291025, 0.012305144599879221, 0.08993157471019415, 0.03459846503251503, 0.03613847029966212, 0.08432488362755507, 0.05627625201257968, 0.0448443777408571, 0.0644135000484605, 0.057298305234120744, 0.034392314602530775, 0.015587405219013173, 0.037198238029715516, 0.1091762472905459, 0.040985489444386576, 0.048077215155166005, 0.01159947324213722, 0.03545845235367456, 0.04250466478087249, 0.035556346899078745, 0.027263799434407588, 0.011477344462858334, 0.046844277080268636, 0.021110688478896217, 0.024560079797201102, 0.03648947263436933, 0.035957554805903666, 0.028198237095268506, 0.10634713055145358, 0.021917103271510814, 0.059504496729782516, 0.08380009041678521, 0.061366515564582044, 0.044546082255340395, 0.01918143010698259, 0.0287221244070679, 0.036925476254715074, 0.015203245641333202, 0.003441247324864831, 0.0762329267097577, 0.05951564713952042, 0.04485705266556433, 0.02734638371264502, 0.06109109929492397, 0.03445863866457536, 0.03756181186726017, 0.04536732084928982, 0.06988466251641512, 0.01653544477096969, 0.04837715772971992, 0.03794003713635668, 0.018802873504858826, 0.043226813732255856, 0.07377741572957847, 0.03969755774784473, 0.01141505959939452, 0.045767908224896084, 0.02112052696306379, 0.05258622098593943, 0.0632079764299335, 0.02013763998665156, 0.08194615764002647, 0.020774017734032486, 0.04052901978514368, 0.06558611252976042, 0.020613003289327025, 0.0217069691843203, 0.07472593983214709, 0.06430919717756972, 0.07904666040333048, 0.03930211082221039, 0.041569018616311015, 0.033994875848293304, 0.07342922110711375, 0.06872819916855905, 0.7328095551460021, 5.095437342120755, 14.292305957886482, 30.27375513507474, 46.44341630320395, 47.764474499610166, 39.29164109691497, 36.166716237222, 23.805923615732503, 26.753688743037564, 22.445782922929336, 31.546644664579826, 35.286081375614295, 21.49264697105654, 15.388993793918242, 8.60194213928715, 5.803512430960133, 4.933636140438819, 1.8802159664130982, 0.6569201499223709, 0.355221058332151, 0.27078379726698326, 0.34848650196386927, 0.437158114847637, 0.3625664012807031, 0.4590826012915181, 1.673397967411626, 0.9099666521914545, 1.8271714256655787, 3.554595752108482, 3.1154672897631124, 3.106369597296561, 3.5253753200654065, 2.9759103396246513, 4.1969238269713625, 2.4632756796575364, 2.395960698204656, 4.3386008181879605, 5.188512244532186, 4.6251784986065285, 6.088952133732458, 5.748895877791989, 3.4073092812492005, 6.277617158428316, 6.008052268335897, 7.24531981252855, 4.281826471128772, 2.64921318619482, 1.580325026185282, 2.9402518272399907, 4.4030875255984645, 2.2529277926491154, 2.811806461503429, 1.1746307246146666, 5.628474700835444, 4.6525576230018375, 1.7355435101255294, 0.9884593467558584, 0.881564831060748, 0.5631955436641171, 0.5139611258862481, 0.39850701788260096, 0.13256396166980267, 0.14588736448316805, 0.2662032043501254, 0.6456986778686125, 1.4157900550673086, 4.801918047089731, 7.269416403385901, 15.668422464401493, 16.947416182487242, 22.387706348972937, 60.75712173215805, 26.524494847943707, 22.098072651893865, 30.262605797859933, 32.33486260137251, 35.364105163082, 27.94465368793857, 21.859747479038855, 8.694341413436398, 1.1720574046334913, 0.027306154520521243, 0.09007383723773303, 0.03354960639450339, 0.04451229394744, 0.0539105418588846, 0.05363322952161393, 0.07680996711696349, 0.0988388560231655, 0.04669780873002545, 0.053924710655044165, 0.055469304788857705, 0.057797986082732684, 0.03048227461535604, 0.02954056869531351, 0.04604576831503261, 0.05234604859123788, 0.010803051108884956, 0.07949945667097646, 0.03330650754393109, 0.04063762040928968, 0.015693266121219965, 0.07274397078060335, 0.02020122911480646, 0.024375475590087237, 0.00843074206533211, 0.04698687285605458, 0.015382523622153508, 0.03394900633382701, 0.062348816483732195, 0.044824899955382275, 0.04210981923425871, 0.01674741938439829, 0.12346603937687413, 0.06836043099962896, 0.051665069204905344, 0.0244642575196321, 0.006814918033928881, 0.032670194914023724, 0.007659244123891357, 0.05824825042978891, 0.01912899138856559, 0.04029579963835497, 0.03640569708940964, 0.020972313847573056, 0.11211663063976074, 0.13964615341636444, 0.1570406240681487, 0.1531149903612752, 0.13845505523345164, 0.15072306467881127, 0.11863682794594958, 0.20641768741751873, 0.1375543503391166, 0.07444224215202755, 0.09068504516636172, 0.20962823933411032, 0.11918828867736364, 0.09711569445508142, 0.29136272688065806, 0.19700262004569655, 0.1766272859587785, 0.13336147452073713, 0.152459908577223, 0.15632198762989816, 0.1579697814679915, 0.16857519625656067, 0.20510726337952, 0.07503876417514778, 0.20089319756915494, 0.12820244691665136, 0.1696202780811056, 0.10799320069171729, 0.1468856076920225, 0.08926014460983778, 0.1283857947395694, 0.1432807962860792, 0.12706512810602305, 0.09373896274595492, 0.08908655674707505, 0.09641268621048621, 0.1186963223341492, 0.13454903337743976, 0.14059717496556623, 0.18980039764315854, 0.09000308901792572, 0.13180323636099217, 0.1526149188078219, 0.19849250784083722, 0.13608482516100331, 0.22111843970994796, 0.12209022207365883, 0.11837183813294096, 0.15465579235986357, 0.1552602204103624, 0.8995716357904097, 5.139289440647249, 15.93020635266458, 34.29598100723759, 53.2478028728116, 56.16594822176042, 48.33663848138625, 50.19248439419655, 36.597678815164876, 37.829907094278646, 28.819253983036166, 35.5777645111084, 38.953791664492705, 24.34121143433356, 19.288625986345355, 13.06460605513665, 9.280386663252308, 6.265352397195755, 2.5552699690864933, 1.2525210289224502, 0.9331997700275915, 0.8199509533662951, 1.3173187067431789, 1.1639021841749069, 1.3479028978655416, 2.4408206007172986, 3.4819049171863066, 3.616482173242877, 5.97595404232702, 7.228955193873375, 6.576586096517502, 6.861739466267248, 8.012351066835466, 8.999495929287328, 9.802737524432521, 7.339024255352636, 5.265826082998707, 8.908125296715768, 8.075529663793503, 5.284540201387098, 5.796490407759144, 11.210239856473862, 4.763690627390339, 6.808206467859208, 8.930501437956288, 7.206361851384563, 4.5218260057510875, 2.451444830625288, 2.8643041993341143, 4.044028121617533, 4.548738858392162, 5.65264581672607, 9.504100026622895, 9.388544059568837, 13.413432240486147, 14.008726439168377, 5.7067122574775455, 5.460434969394438, 4.5039243082846365, 2.434011366098158, 2.8783335368479452, 4.081428411506837, 2.4868260804683935, 0.8047414114398341, 1.2509118765592575, 1.6760429932225136, 2.616706543391751, 6.310158612266664, 10.07491079068953, 15.720502714956961, 21.4959535291118, 20.696529380736813, 61.48482338074715, 36.861073816976244, 29.16586010686813, 39.501346695807676, 38.657758620477495, 43.269575565092026, 33.09412756273824, 25.43165191527336, 9.423751254235546, 1.8144378186233583, 0.2303564794842274, 0.14223412099865176, 0.14404090872455028, 0.18997783892818038, 0.12299937691779868, 0.15927953134861686, 0.2022098575628573, 0.3253153453190481, 0.06361069736040889, 0.22127617721355733, 0.10946959001763214, 0.1459319354786027, 0.10855112720521227, 0.08542311663228659, 0.24807210951562852, 0.12671559282969083, 0.18611094884334073, 0.19967024545035056, 0.15488856051477695, 0.09116460854608206, 0.09151909275040512, 0.14649576086911464, 0.0739657354631251, 0.0680429028767732, 0.1618595929035256, 0.10908774881353302, 0.11533162586631314, 0.1349287678397471, 0.16096210557847254, 0.1135679842123101, 0.14567319694305622, 0.1265968032361519, 0.2994053630578903, 0.18828283875219284, 0.17213272471581736, 0.14005385008790802, 0.1184279004472398, 0.1646664930928138, 0.17246496172681933, 0.13460544809218378, 0.0794733866989132, 0.1843221641836628, 0.0863067607485479, 0.17237480849989], [0.06010081573960282, 0.018870032602740873, 0.0022929286886562384, 0.04529234765458011, 0.044997258247026516, 0.030690970372468717, 0.03847456732464414, 0.11814751226695315, 0.057008678033467264, 0.042562339710251945, 0.10793656381147523, 0.0389911480728657, 0.026301631305907524, 0.06124689476564527, 0.01615243336756624, 0.024123530339209304, 0.03347915694898656, 0.016291844132806987, 0.027863931646870992, 0.04292831906387883, 0.04624628033789416, 0.04964510602275691, 0.05211917548290184, 0.028184139162241936, 0.040368191116759856, 0.047176448973797025, 0.06318037428202168, 0.022523237782860958, 0.07592635364421914, 0.014222035439865244, 0.04577418631543556, 0.0335761858150363, 0.011810461517363306, 0.063936912920326, 0.06318276447634544, 0.03973427251161587, 0.04099703821984511, 0.059833332310400666, 0.016377439136586843, 0.04757040585841864, 0.07642847065243029, 0.052715283818542964, 0.11287826759320115, 0.060249042261632225, 0.05373748259678964, 0.022172572526840434, 0.05800442762612816, 0.07365361592101474, 0.008653646838220378, 0.09039223103994325, 0.08971107928382774, 0.14510348799728578, 3.2556760887945853, 10.127809836018471, 25.100397948295843, 38.194299205656975, 43.00774166660924, 41.94076676522532, 30.538621025700724, 26.13615666666339, 25.86819406478636, 28.196765991949267, 23.81742596626282, 30.882528558854137, 25.879863116049, 24.767431866738107, 11.629293137981046, 7.313675938114044, 5.506869948679402, 2.12803854577003, 1.1266006889843172, 0.6418720380433145, 0.143250152769108, 0.28705804819060915, 0.1135792074004008, 0.37648067238830757, 0.7695291299493082, 0.790338223018954, 0.4864200198602292, 3.2096706090434908, 4.555600064416086, 1.7271833458254415, 2.7432260253737053, 1.4988559268174635, 1.7873277443070568, 1.2246731812915495, 1.3280876966253405, 2.5725820852864176, 2.2824686333056423, 3.323374236783674, 2.6449677107795595, 1.6915076730712768, 1.847500825120557, 2.743200775115721, 2.5719174886903455, 3.407782662299372, 2.141961979289209, 1.856408160059683, 2.651179519391829, 1.7423046957100592, 4.257286162145676, 1.9069899426352594, 1.5151690643641258, 3.2523528606660905, 5.147362659054418, 2.5771965086460114, 1.888072596442315, 0.6974719416710639, 0.5352112098086266, 0.3372596979381577, 0.13514547879176755, 0.10421871613230436, 0.28322662797666365, 0.49439245174008034, 0.5722720308169242, 1.876188305116469, 3.893969515638967, 6.838278789674082, 8.245180999079059, 9.122913306759251, 15.905386574806707, 18.005130367894328, 36.76134755534511, 49.79572096178609, 23.639638654647335, 32.008070330466, 33.99282101661929, 26.41259551048279, 15.290572700961945, 7.429668268849773, 1.3830440251096603, 0.12351412671588122, 0.12088125105947257, 0.012718594591734151, 0.022736794367853193, 0.02725588191571015, 0.023649745177657857, 0.05180339787095305, 0.04352589828833457, 0.040577356102726156, 0.05288807494986442, 0.0312529418302039, 0.028770138967722177, 0.013841778122549577, 0.04104829716285871, 0.02209410597119601, 0.06699151614861143, 0.011663071946391176, 0.02084091827724009, 0.07280991562912542, 0.11007558088749649, 0.03559149501304473, 0.04049767146728212, 0.07590399919858865, 0.07636800333256684, 0.07239307952864517, 0.00930845474583968, 0.04904149768633708, 0.08874480492405354, 0.026212144575472322, 0.026129127457557667, 0.05401941444424372, 0.03350187528638109, 0.03318049374126619, 0.022545676498163133, 0.08050893838968008, 0.023334348694451397, 0.06518220033256278, 0.013076806771418741, 0.06867530079738748, 0.06871757352904928, 0.03869845652051511, 0.04309580120588503, 0.05021936936123718, 0.03167869519412277, 0.041278380179597486, 0.02173332260891555, 0.06493114565889682, 0.01896479767897437, 0.03546366175155967, 0.09076005283502803, 0.02073494150423475, 0.061619389697068164, 0.0648654229758728, 0.05480832029734889, 0.06267909997052724, 0.10023182603500544, 0.0535992726743702, 0.05856406634613391, 0.029464536384048483, 0.012053173493533846, 0.06855416697480025, 0.03753543546002719, 0.0108363835944704, 0.012303037858087451, 0.04617592282292824, 0.05459774954004153, 0.04885507402040305, 0.03749958254517086, 0.07139358759647416, 0.0440148385842481, 0.10149309021090308, 0.03400596497099727, 0.02652420091532892, 0.04341592636680411, 0.04087197436620632, 0.01136980104004784, 0.06486889335416979, 0.01566850998994684, 0.08759896721570723, 0.039709401467154105, 0.04571821976212725, 0.09346695556755989, 0.02621511316617891, 0.06501061962016168, 0.033822981039843256, 0.0014286947266701911, 0.08313537890752477, 0.019042000189543735, 0.03151818445222753, 0.027604405955982306, 0.05105507935607626, 0.030168398816679275, 0.019859509850521723, 0.01079259592393834, 0.08750352032122113, 0.056852825106151646, 0.4820770980610002, 4.645588551798175, 14.396818491720385, 31.511937572110085, 44.64527630036877, 48.30793457646524, 48.07291007811024, 33.92858043793709, 28.67908024018811, 25.74127401075056, 31.73402217126662, 25.848839129171065, 24.7934744434972, 24.884304769577522, 25.454032959476596, 14.010419922490275, 9.435082001070823, 5.903011685417545, 3.088763793629985, 1.1288989527571587, 0.5224037518905056, 0.03427216903336587, 0.09388511700014915, 0.18808875803745564, 0.2694124998825212, 0.5164901046983658, 0.19156143459821903, 0.579247230723981, 0.24594633809981808, 0.2843173226762203, 1.8460497933049358, 3.477593251774388, 2.6971021390730336, 2.3906865812117055, 1.2738304080501681, 2.8616901847624012, 4.053498929546726, 4.717604739050712, 4.102609945881752, 3.9956226416172522, 3.1892357958901316, 2.028819127909599, 5.68474502332749, 3.1118971974618974, 4.286851027319509, 1.9583340133390121, 3.851775108806549, 4.005600415891217, 1.7726387131598689, 3.4988806901439546, 2.469304362612386, 1.998919758104509, 2.0737828506577403, 3.769931913383546, 2.1365665139690524, 1.2815007254961999, 0.7033652415679348, 0.2690899155793652, 0.5198741908515654, 0.2141140058877007, 0.271626279479073, 0.26139940405564926, 0.4175902680764276, 0.8567134903803949, 2.153936485129018, 4.094088106386123, 8.30625524443965, 13.65939328747411, 11.778673664216074, 18.002514146989395, 17.898090847076908, 44.40769833903159, 48.941511108029275, 23.946136582282282, 38.5652377528529, 38.323941384592366, 32.09703164715921, 19.54560006818464, 9.704981273220433, 1.8317348582129327, 0.11275579311674643, 0.10211676239005982, 0.015402241767714582, 0.015014857917483297, 0.04598520906461824, 0.03878038579357728, 0.0709518000123001, 0.04570636838193863, 0.03508165583855683, 0.05272058131653936, 0.01931494199520638, 0.018194770147543282, 0.025847942545829762, 0.051841510745186004, 0.02592872268700552, 0.06408043566250032, 0.014163135727416846, 0.012241676130572395, 0.05594142179395403, 0.030972247214747534, 0.011725280201062562, 0.049859170140998985, 0.036898372063954035, 0.11246099482260405, 0.07780788856888972, 0.0327622901738411, 0.019828512017885526, 0.018785791659367182, 0.030693670832401806, 0.02562846984684227, 0.09974847818093915, 0.0015152593104792158, 0.051408295684884635, 0.009229182840264853, 0.04293350547912621, 0.011180506459617568, 0.004402683839397205, 0.05107410131923614, 0.03984114560749262, 0.05496395105916647, 0.07472101388679397, 0.035864628340688445, 0.03403989883560327, 0.03473296325894133, 0.021829457067313696, 0.1600613240753451, 0.13569755239352105, 0.09684815356928496, 0.15859641074653597, 0.15460728367249812, 0.12534081740605255, 0.13099682156837758, 0.13370635198248973, 0.11979588833186897, 0.15166812606396216, 0.2156048129883505, 0.13860545361474638, 0.11359351026194711, 0.12893480398962576, 0.11061517491696343, 0.15361178305841264, 0.12227441259329358, 0.08420530496345413, 0.14486422341677452, 0.13402285354752697, 0.12844717370406275, 0.1872749121919755, 0.1696111463130482, 0.2088107622318691, 0.11455160280269001, 0.2629841028922989, 0.11601897527373607, 0.08706534101117043, 0.10457274834475211, 0.17861111660397824, 0.20844818813906563, 0.13393852258882216, 0.08250147179369965, 0.1827289464492952, 0.14239970324260576, 0.12266743868108719, 0.2183081840555514, 0.13142481956991459, 0.2956810419357592, 0.10935440869821657, 0.13003489092713402, 0.2118895776690014, 0.2270664076410955, 0.12556741855317546, 0.13675054024544456, 0.14247335493564606, 0.135236581967723, 0.12131677204442602, 0.085870910345787, 0.27190544191868077, 0.19257584226227578, 0.4107687454069815, 4.848923731234766, 15.795169934149712, 33.46160657944218, 51.75603920413602, 55.07048514581496, 55.94307914856942, 44.12933949501284, 38.4115828237226, 37.80333695873138, 38.05930691380655, 35.40003015149024, 43.47528819114932, 36.412911645827755, 34.07055454869425, 20.415760240247174, 11.6266288680415, 8.465117119973707, 3.8295220319301855, 1.6688608882888671, 1.2126643547127325, 0.38757316587913426, 0.6491845617851904, 0.575726106762886, 0.862705584975981, 2.7101271046746165, 3.523533767269504, 2.8898452030074213, 7.474319060002604, 9.130246177796396, 6.153491302844017, 8.975583199531801, 8.626695236852093, 6.254932130536726, 3.690936113557508, 5.1799859923701135, 5.017976414772773, 5.260608840373255, 6.6253426286482044, 5.956318166948134, 3.747795281871673, 4.958315693563031, 7.668360673612164, 5.649229922602254, 7.1913803585114024, 5.731539389779491, 6.123980860556326, 7.917996981451589, 6.335484375876765, 9.646834096600934, 6.656656380622618, 5.688644349575044, 8.314951139111674, 10.91052664864448, 6.292226516431378, 5.755109892737481, 2.6214695265216212, 3.3924417822591724, 1.8343466664514236, 0.9081292669138602, 0.4913548518332743, 0.6342581046685096, 1.1064307583916573, 1.4787300003151742, 2.903070454635928, 5.733915365511372, 10.642239470635692, 14.743671724873206, 15.47948875734883, 23.32607653833205, 26.59528382362858, 44.33091402053834, 57.01464714542512, 34.61327721995693, 46.38518871799592, 45.13296811811386, 36.88071312442903, 22.256550135151034, 10.59162030296941, 1.9033524345967079, 0.2695146960116202, 0.20720280496583832, 0.13122479401288495, 0.09218548199221974, 0.12780415780481794, 0.10744560870432085, 0.10919752921308241, 0.14756760980573394, 0.28065110166226664, 0.15265780440982313, 0.12706254638971823, 0.09393069923164384, 0.1389970317963631, 0.12198951215513291, 0.1379695853158351, 0.2634677495206556, 0.11016763401247802, 0.11293141111250847, 0.35804568579600704, 0.175732939594215, 0.07985355017045814, 0.2125999863229452, 0.14118519341272695, 0.23452107133644245, 0.18868083675061503, 0.13277270530741062, 0.1316201719906061, 0.23266150015256098, 0.20713217165921965, 0.13511239911519712, 0.17508476792323976, 0.17306811807136382, 0.11323256793642238, 0.17800345566243897, 0.21258412830291257, 0.10565584345209984, 0.11425714158723432, 0.10857599441923442, 0.2823120415691407, 0.17578184664730104, 0.22360151453364283, 0.2023472171276808, 0.11769037994165575, 0.12816021248938578, 0.11715702186789244], [0.02490168797873682, 0.044635293194122856, 0.04284615230356013, 0.017761059045310945, 0.0653690338555363, 0.045015613713692275, 0.046675944580666484, 0.04162321167607461, 0.0290584140231893, 0.01563787317624496, 0.01532294400667231, 0.07343947902441987, 0.03857119399453363, 0.029197545166337685, 0.03147891670044872, 0.025206612040018363, 0.013503596269255205, 0.07699872352062695, 0.04064685176877726, 0.029621816150123076, 0.014968313288033731, 0.06059210409500426, 0.0631709284179153, 0.03544795694911192, 0.030626419803968845, 0.027689698355032072, 0.015065391949798553, 0.037104978316253236, 0.08502156398589573, 0.0640047270233833, 0.026904096256100365, 0.06550779536126122, 0.048805128918179584, 0.01737294358111197, 0.037218179298384536, 0.01579977532533268, 0.02701694675300631, 0.09293115367331813, 0.04750917628107052, 0.032003863128803434, 0.02128242432410198, 0.06331822797355634, 0.0633724325246388, 0.02868160027109327, 0.02439395554604069, 0.03542471767192887, 0.10205695390581124, 0.014246327130334272, 0.01991554726696303, 0.03591125628219978, 0.08259168630766292, 0.08710447278234267, 0.1561817935397548, 1.7945704008302383, 10.521677578649214, 23.360616930069465, 35.383552274396344, 40.71655581074376, 44.99750121947258, 47.107242153536895, 30.10780945900948, 30.809605813795525, 35.55986281364195, 46.831919224031516, 35.29638936442714, 22.762457439976355, 21.38796675589777, 13.756667087155005, 10.743567039889674, 8.004134681917007, 5.536391667781338, 2.4540848308993928, 1.5134954380412258, 0.5338730074224934, 0.27506763836549175, 0.429188808606517, 0.31498670277576296, 0.13297482994535278, 0.9259074097198825, 0.4915292134448406, 0.3075224936248795, 2.299283834234361, 2.9056300463215, 1.5745005516275283, 2.20074997313561, 0.9839488662058308, 1.2124491146495266, 1.4214176756720391, 2.898140770773734, 2.212522722059681, 3.2281957182192036, 1.329459668167176, 0.27102260219473995, 2.3925955497449447, 1.0042748335869083, 2.508554050037938, 1.0265108113808017, 3.659698112357048, 2.8436409081182177, 2.4697341072943906, 4.257218991556476, 0.7713683538379208, 0.8741723277395772, 0.29229952983798524, 2.9199256147107775, 2.220832753566004, 0.63487526510031, 0.1861498507881357, 0.2257925106753265, 0.0354066456577951, 0.040793473336605296, 0.48999201205949633, 0.6727412138735095, 1.6017977965454904, 3.0180628261258526, 3.522831172712388, 8.1688359860451, 16.09997437846276, 16.05862573269875, 25.76009942639259, 22.765234478058357, 20.24173055925677, 32.45740921266618, 42.45069842184744, 36.173599996874415, 36.97822716928298, 26.000436775145996, 14.939056750266785, 6.628470228564355, 1.7333500471807297, 0.02878989254484975, 0.06930986674682749, 0.058814940989137664, 0.051626672878140406, 0.049755625697153236, 0.0011108608868521368, 0.015343333436777035, 0.03736313462497727, 0.04458855033942288, 0.018132468047101172, 0.018159158550383105, 0.015647595789613986, 0.05672771145679778, 0.028756320656787966, 0.08155474799775309, 0.014980165625832256, 0.036167485879794244, 0.09171210094204835, 0.05288929302966403, 0.0658201370688696, 0.046268044895822966, 0.03466500359917841, 0.033258079295797695, 0.04647924767566785, 0.10474229892415386, 0.04149819378771129, 0.015167886853188038, 0.06756104123328002, 0.08640928629545436, 0.03979069871767875, 0.04173354748936911, 0.05149299819623271, 0.026044116595820076, 0.04124097593669449, 0.04411059574434354, 0.05913771681427475, 0.06025266585751407, 0.02060484445293344, 0.04377914397346397, 0.03659220119457572, 0.07800948460616412, 0.010676640855719247, 0.055631504754625985, 0.07165461673491424, 0.03163074958138168, 0.05423342876677072, 0.056557525024418874, 0.05396573083294977, 0.0578425532477277, 0.04959588104318227, 0.021190528247144916, 0.03144765648269846, 0.04813253819461792, 0.019924537308754462, 0.05760947099676537, 0.018031332949777285, 0.056485275272279985, 0.03168891097659306, 0.04457502505711971, 0.0849921002443279, 0.043791596732673146, 0.08351803982570287, 0.05081292279365082, 0.05821369986440386, 0.04074951138107046, 0.041413307415261384, 0.01666361702636125, 0.06683957026970964, 0.04663188686414112, 0.04382500965749064, 0.07663941296238093, 0.06149152579206613, 0.006364681457559909, 0.07218487215258422, 0.015337249741048343, 0.053235216201433254, 0.07719398401076756, 0.07425824315437386, 0.05798204636742031, 0.008257848469750776, 0.01639712376580123, 0.029696934901538397, 0.04844990926944921, 0.08047070294137924, 0.048191262664453643, 0.049960672960526524, 0.054206309254251184, 0.05497684431893211, 0.06168475997964702, 0.03226526765032642, 0.07620515602250254, 0.02977656591082773, 0.04874884060794308, 0.0850927182323029, 0.029800770458795374, 0.07682281441145367, 0.06906745354494742, 0.0942185337865545, 0.3390766439899322, 2.9168985255302924, 14.62699886291258, 29.421700623727617, 40.36399356780514, 46.97436401920934, 48.93256418166622, 49.95742067213982, 33.22195368428385, 34.58090982129497, 34.75624369036767, 42.31272905103622, 34.65656057480843, 29.261854233280307, 28.732777487847116, 18.081191009090794, 13.786702636749515, 8.817648964543498, 6.687489151954652, 2.3425127661997274, 1.6215524461961563, 0.44926172182444607, 0.36568716769256904, 0.157056252261804, 0.059074529882280104, 0.14779438715307944, 0.2685446448383793, 0.37081637149376256, 0.4883435747075466, 1.503789042753558, 1.3648404277140096, 1.1481408750818622, 1.8773123093189734, 1.2717758215242818, 1.4224134673995357, 2.829931734069701, 2.7140507005876113, 2.8607473450322307, 2.9143931115827257, 2.381131197175672, 1.917642854875134, 3.062958029970046, 2.589907929781945, 2.6444129405483126, 0.984222267664248, 2.45743747680418, 2.654438763856888, 1.8282916300719785, 1.730085409456684, 1.8391898130216908, 1.719159402193562, 0.5850604897545231, 2.417013284660155, 0.9129393184857985, 0.7620657788169, 0.5909975485936289, 0.3630034084762297, 0.10503634645213043, 0.15782672220901137, 0.18842853335363252, 0.4850942280984694, 1.2648328585970787, 2.8027705463670918, 3.6061111813591378, 11.514567732810976, 15.637697558249197, 17.91999532330421, 20.81145678797076, 19.540500986960627, 21.754673065677768, 34.77254898317399, 47.24226190197853, 37.34223096601425, 40.42702997884443, 32.460619672652214, 20.390196192649103, 9.36463427159094, 2.3162247961567295, 0.08850585443959122, 0.00642213182741656, 0.008202666198954949, 0.06180996172911218, 0.030592685122223153, 0.04242337519122709, 0.01358026347588748, 0.09721495646743045, 0.05497835734258256, 0.0730748977812548, 0.05782427822029399, 0.015799504321729465, 0.03450663790347115, 0.09249543350550438, 0.0334962560314565, 0.017642240723474853, 0.02980732051054797, 0.04014440534275867, 0.008499365348759438, 0.09209365869361548, 0.03912393792322086, 0.06796765005997113, 0.07838341212200542, 0.05377134368304284, 0.02466237168729065, 0.031616825933357885, 0.08516374990464219, 0.05857472262916066, 0.0444668687639698, 0.028509557990717794, 0.1503958532045926, 0.024545531787519014, 0.019662985315306053, 0.03488210908647987, 0.03895396216502113, 0.017023902431490923, 0.09105835215098436, 0.020845024508514234, 0.0941738248952935, 0.049936744204211625, 0.0625645506736492, 0.007938016816267685, 0.042482674227006016, 0.0514049057458197, 0.024749698049779383, 0.030713248209306793, 0.11635433026258984, 0.1486138254404068, 0.22553277622547843, 0.10021717077301395, 0.18165173489720593, 0.09687141199866611, 0.13194762861296055, 0.09844962973147632, 0.14371709868071542, 0.06567543838173151, 0.12624713006399332, 0.13331771557850222, 0.19669725739907837, 0.15007815654239348, 0.11056676582102815, 0.22200927739181828, 0.12331210933024846, 0.29418242073828177, 0.08405164304760196, 0.12947527902020564, 0.14656037272464845, 0.19569348303541062, 0.19450940221788424, 0.19610101116761086, 0.21563096723008543, 0.17799017169783193, 0.15492453600370115, 0.14758429520072477, 0.39377198164020816, 0.12400027079087113, 0.14769496426226633, 0.12674233695912746, 0.13773019816125595, 0.09192023937019611, 0.10825646680689628, 0.1239839990833594, 0.20595258011692957, 0.22840758244837486, 0.15383515897537434, 0.10696490385359335, 0.11629124292202535, 0.1766297221183777, 0.19541019904277018, 0.09297015520954326, 0.26953743350121284, 0.13401936018659225, 0.22116199946932255, 0.20113788605217012, 0.12289927220873295, 0.16008681948146514, 0.17422054413585894, 0.18892998386534954, 0.41076561976825043, 3.361829644249332, 15.39853201758477, 32.537041171904534, 48.549682017295595, 54.84535678740471, 58.87382707288189, 60.36269995474047, 40.32422073425786, 41.61106801802113, 45.62459799551195, 60.727139134560865, 46.63630277879777, 33.73782380934685, 31.27976267568527, 21.493188258140318, 17.067934928401826, 12.327985917368244, 8.010259462941079, 3.74600128781411, 2.6837062643420313, 1.1659283335170438, 0.8076179183779225, 0.9281011178128181, 0.7791477622043702, 0.5545537654430636, 2.3071746624285177, 3.1214364017209704, 3.9071761360091553, 5.728643699999779, 6.764887811676149, 6.427762056550672, 6.9876710830196265, 4.745754118888609, 5.769119618400451, 7.088605924960106, 7.366027322507675, 4.839225180687444, 7.709564681976073, 3.9616715859982277, 3.101399463991965, 6.353743009028896, 4.994910426678197, 7.506122127656014, 4.344669215140804, 8.214165837534013, 5.9972093662908, 7.076747619336651, 11.658008810012571, 3.338351316990391, 5.242469839511379, 4.315107291744602, 5.4435864283192545, 5.912139040808524, 2.3547635539885494, 2.1904726278397346, 0.7819563631088503, 0.8809710822759137, 0.5752115408259054, 0.7892828602944651, 1.2996692667084357, 2.305236521267122, 4.667001751161391, 6.381995841380089, 13.508223179847965, 22.569565080827285, 24.7128560081605, 36.124240890625984, 31.619216357508016, 29.421473126257624, 41.28057302967195, 51.143533645137666, 46.942902688057195, 48.07694227464738, 35.646049053438254, 22.562791147539695, 9.888135367824185, 2.5050844684723885, 0.2379230839470702, 0.25897816784920236, 0.13546288434055545, 0.17372332242948396, 0.21063300961207962, 0.143204876972783, 0.16673358217362436, 0.17639768940787162, 0.14437643991362664, 0.1893006631683919, 0.2143492102022133, 0.15559282514356798, 0.15294773804564632, 0.13664100499403092, 0.17343711198097275, 0.1706058961609679, 0.14444540314857038, 0.24777664472499203, 0.11475542049494483, 0.2227069536644605, 0.1308741249264248, 0.2655004259319075, 0.33928023951668895, 0.19067831908262547, 0.2472707049380387, 0.1389972616227404, 0.14571528581361617, 0.15239957149230665, 0.15655383647930238, 0.08962435046991996, 0.22649173444557577, 0.16838136068995924, 0.1280889892950654, 0.2666122340146573, 0.09092964937970524, 0.1770742216538037, 0.22256787806268663, 0.09224250191642393, 0.14678597029659057, 0.1583578969321905, 0.1607785968770904, 0.1564680193100245, 0.14598828890631277, 0.09129702684379394, 0.10262888450656207, 0.1542542856787482], [0.026572920276873538, 0.06557125042402936, 0.018504692932530757, 0.03467565222132591, 0.038398659502666806, 0.11187570364845377, 0.05208948191495673, 0.04983643265140634, 0.04526970975641762, 0.012363337596217472, 0.046306881723144365, 0.06805043352106888, 0.06113814092391442, 0.028975818253632997, 0.010170212687714206, 0.054891571072080446, 0.04616248181029674, 0.01849814288077816, 0.086818247012073, 0.01453481285998057, 0.025463557929822037, 0.08087631585376878, 0.031421475427886175, 0.0477485481138912, 0.036397143717735045, 0.04173774565119417, 0.05169516496901071, 0.08402276153285658, 0.015597512791564148, 0.03484401536444503, 0.022357550201817386, 0.07002077335792203, 0.037706617806707664, 0.07663485473923146, 0.027458818606852044, 0.03689310137903498, 0.06722318113691385, 0.0629374937665078, 0.024407934735438997, 0.046196668483917756, 0.04329908263659285, 0.05458254652518419, 0.03432628931477666, 0.03376964982899447, 0.03363044399227347, 0.13200182167272415, 0.05298774298881331, 0.08060018712234113, 0.026957212962330352, 0.04978173780405233, 0.022485982927103198, 0.02899611766840662, 0.016479901481239546, 0.09608239506281192, 1.6936989296828548, 9.438461122974273, 21.789215418600268, 31.293516466694495, 41.339251687449796, 40.818494289152085, 29.091903817269113, 23.648422802648238, 17.21972869288537, 23.852574325376942, 30.56488129400438, 33.66313795889578, 19.94669968082059, 23.558675050735477, 23.91472428075729, 15.027893531707027, 9.781976419110453, 7.2452908850485285, 4.029138804443421, 2.9057263895388576, 1.1903542808948027, 0.6904022984447018, 0.27442213268049304, 0.126092043224602, 0.11508608702570201, 0.22694361906859184, 0.20270173197552083, 0.3568341637090329, 1.0103282152164368, 0.7166634247668329, 0.8332875635354751, 0.5411502298328185, 1.6005946094951324, 1.5663502341316593, 1.870657272877232, 2.414404663347429, 1.0530721828822167, 2.8618377639401347, 1.1967563244604296, 2.976650686994676, 2.048056392419723, 1.2105707896332587, 0.8778570880812984, 2.051158987226025, 1.8449843795068803, 1.1181286145602505, 1.1457820597194857, 2.064026935446647, 1.2730140647580548, 0.4548929890076961, 2.9126657978180917, 0.42000182093151156, 0.29397045953139184, 0.3628037353196452, 0.12904142810692712, 0.6293333850560651, 0.38152876280007825, 0.9138073267475252, 2.3308010591614634, 5.2467162955191835, 5.582855574546322, 10.224226597816715, 10.907229896514647, 15.390379371181613, 20.813486614534934, 26.23078973062577, 23.348114375145208, 21.965596560508978, 31.10321483304424, 40.38277779856036, 37.30844759172009, 30.142202761865434, 13.993689052520262, 6.072218321984814, 1.5392172384646632, 0.08433945461987488, 0.012542081230710591, 0.034155348285792336, 0.03527028583771279, 0.04428375842830828, 0.009837426008626578, 0.03278867424195332, 0.002447364832116892, 0.02195421640100258, 0.021189434656633005, 0.025287286844104532, 0.04466107588321452, 0.06834111026217861, 0.019485884939410517, 0.00725372840890721, 0.05481209711081559, 0.05125986614955529, 0.014605908692183514, 0.058543255567670836, 0.07853779416050642, 0.035957248370733955, 0.0832672686045689, 0.027713031477985844, 0.08858963381499053, 0.05540758491523805, 0.04117132705305854, 0.11409014208062042, 0.026543992796852708, 0.008794967077612396, 0.05142220401114995, 0.016189104081281734, 0.08193937010101734, 0.01834255999945585, 0.03136543992666468, 0.0442855166000945, 0.030181316974302454, 0.07561094758491363, 0.03665898107893525, 0.0608162920651657, 0.048763783152906165, 0.01554796797028112, 0.029149319931504228, 0.02138145842529353, 0.0306934199386066, 0.05384627091247709, 0.01916943508530817, 0.016244746962442033, 0.045193238859815944, 0.01925749689220421, 0.03371313935325992, 0.03181972815054319, 0.014133084970977039, 0.036575109772985025, 0.052590924765794515, 0.03814779635098192, 0.05434501713382141, 0.06057780123345795, 0.07560093481574329, 0.0292541571487222, 0.03979003605162425, 0.05678093924577679, 0.008036636751175167, 0.038702796408606153, 0.02269693672837269, 0.038890112566971974, 0.10404231672685954, 0.01164488214623904, 0.027653876083692717, 0.041023364831363006, 0.012905590908391582, 0.08997888063951846, 0.019797157954364535, 0.05204916653794147, 0.023431685910890662, 0.01954342388818341, 0.052309245727355444, 0.051544988753214005, 0.018035284048246763, 0.013171734641336147, 0.031367288113782005, 0.0447908281949499, 0.07878120327668806, 0.03275548731307349, 0.04135790393657742, 0.03246477992844678, 0.08888420994363486, 0.059404522255663915, 0.042463744194397045, 0.024904382693010475, 0.019850969885385806, 0.03774461193731235, 0.008594016469414196, 0.06327282194228423, 0.11737072975524973, 0.09057508090571051, 0.028060103781641494, 0.10312319507882481, 0.047927946753559575, 0.04421768717527871, 0.007886540495805562, 0.2815481906215991, 2.6872903300869853, 12.58178484055304, 27.539317915516516, 40.24563212548533, 50.073005076377626, 48.340003874994096, 34.05523769317135, 29.234872248864946, 23.327180685535556, 31.848929966649703, 33.09718308910247, 28.03321884524438, 26.115546572592955, 26.497067674513787, 27.365439245777747, 22.300402233677527, 13.207084190460945, 8.780183465250078, 5.322958346336119, 2.3681113796849407, 1.2417466457813018, 0.4790770671060009, 0.065630208550682, 0.026511734749581066, 0.16004664583071587, 0.1866088447070891, 0.19422481587577253, 0.20197879012313583, 0.1414380024277395, 0.4457436622150483, 1.4352137547346855, 0.8078559572177549, 1.3730174663566774, 0.8637103858974673, 0.8178845384428579, 1.144306022794016, 1.7020306567991934, 1.5297197093886714, 1.5694656992150893, 2.9840176336226927, 1.051136248054043, 1.8631237480909595, 2.1079265927114794, 1.448468791861688, 1.5853061911559876, 1.8928408502571046, 0.6852328597057251, 0.30121988827182405, 0.5471096584393133, 0.9992785920058528, 0.7350877167717104, 0.3967583455866383, 0.3837874351489929, 0.32689121882280997, 0.033815197586532564, 0.27172538061295787, 0.45706227421760565, 1.3128491659318249, 2.3575952601048256, 6.024106039154915, 7.689686109942775, 12.147230352124861, 13.856297250716919, 21.355012962895056, 22.93782464919552, 30.333747786860314, 27.20524572557019, 23.455236265736243, 35.423074076252604, 44.626099832596324, 41.873098035012525, 36.30939245223999, 18.734310750038393, 8.769214557063195, 2.112485122296118, 0.15939303493547827, 0.027905941993418722, 0.019895818587692998, 0.027466006426801606, 0.03192000331417207, 0.004181233197150211, 0.05586089829223291, 0.02409840840095234, 0.040780675837830196, 0.018794682109728456, 0.07391581717397898, 0.06891087283410373, 0.06464923296364085, 0.017708718003104293, 0.013103247338515377, 0.07093987968419829, 0.07699482413309236, 0.017551457389227806, 0.0346132964947291, 0.06529587245876751, 0.0285597424954176, 0.0676398946633262, 0.05510345950061756, 0.07924942855512904, 0.022628055847880822, 0.021876324411301364, 0.04248855012138525, 0.011966349876245425, 0.00909661707062755, 0.021606107963429346, 0.036357111793251774, 0.07680936956838255, 0.004471847693616104, 0.029615084152488463, 0.06336035897895213, 0.016716184064505563, 0.06645202937145388, 0.0378813203274002, 0.02346030695574178, 0.09567967796277616, 0.08238028434495773, 0.02967330683473378, 0.042437329482767856, 0.04534581676125527, 0.06671313511868639, 0.024716687321122137, 0.02654181902236756, 0.15056722707325412, 0.14409027543039093, 0.10844130084038743, 0.11863472886503705, 0.12163200190350895, 0.2359724095872333, 0.16496252478851428, 0.2049870641842004, 0.16722063023236491, 0.19614306939465387, 0.18417835415851685, 0.21651825026398708, 0.15156573075200283, 0.1853127771567914, 0.1401534108745475, 0.10345544741158524, 0.18126558061809311, 0.20977802484506564, 0.15398307523179441, 0.12956256707829814, 0.21869706560767468, 0.2069569979944537, 0.15072818214614547, 0.14573877406937463, 0.09974766612773943, 0.17158124866264482, 0.12239749227920849, 0.12753980384478647, 0.13232069811032665, 0.11436787193580983, 0.06783307139431277, 0.15009458146749005, 0.1178590878243408, 0.14733355462310777, 0.19564203257041593, 0.132367153682055, 0.15568912239565005, 0.11478037197863865, 0.17973300640381154, 0.22464042168951806, 0.1319011577194737, 0.08486457724845217, 0.23728200625027382, 0.12056459627685048, 0.12885657109079823, 0.23190927841970999, 0.19781044444009183, 0.19970796761974213, 0.18161051936687964, 0.24170328352239825, 0.10146607795069296, 0.13932314010397082, 0.13800263434888857, 0.5739481086211821, 2.785903128885454, 13.079870939254763, 29.302980284537043, 45.0672488058767, 56.11123508022678, 53.733137346083126, 42.02340326001568, 36.05539937173167, 28.963481495457312, 35.24952488560831, 40.2295700196297, 44.18630799939556, 30.477826249214914, 34.522913655927105, 35.36549760449317, 22.224845617048203, 15.096447736986223, 10.463027358055115, 5.806450286219198, 3.6853121701748144, 2.1159331308257197, 1.041266584107953, 0.6910171912562463, 0.5099576729680262, 0.5781815717777898, 0.5312032216498929, 1.164811193462341, 1.4830457106713326, 3.417757004499436, 2.2814534748754194, 5.410814535233283, 3.343086353232784, 5.121999142631408, 6.583865034964777, 5.577386809933571, 6.441539381780933, 4.023966914223087, 7.822474029756362, 4.966680638251766, 8.288428072006472, 6.065607657355647, 5.011287302740159, 4.969311568044848, 6.4928988968172385, 6.638030025266833, 3.7819694222942477, 4.013258108208257, 5.456181649238833, 2.8497078341822473, 2.8225128160369013, 5.935711995247872, 1.749359691335309, 0.9666711320319484, 0.9796970169390402, 0.4783221947089319, 0.8500586990867892, 1.1650330525252128, 1.980791053464336, 3.4316600907233457, 7.804002608022383, 8.715470240962121, 16.509750273919877, 17.790058966605894, 23.868999250473518, 30.303059162632113, 37.220080514107984, 32.81927924002371, 30.615150390132783, 42.181400252926736, 51.66547952159759, 48.70833012365526, 41.44927417078326, 21.942456537677398, 9.250938488591103, 2.5084125995635986, 0.2759767395834769, 0.07731962243034955, 0.1844719650163766, 0.08266479407827701, 0.10850494742513665, 0.09674337572388111, 0.09875800310363693, 0.09190402128883908, 0.1217262766834709, 0.12325027837387978, 0.14366460633614372, 0.23061089728388096, 0.12744994939214763, 0.16051443443904, 0.10962761097377348, 0.1901206836825417, 0.1948802807037869, 0.13144095338159992, 0.09634727762351114, 0.22454587111790336, 0.12778872113314368, 0.29631799807952297, 0.1451987586915493, 0.15387536326964057, 0.12855493163149204, 0.1896408368502894, 0.2916185389603338, 0.16930696344183338, 0.15071719644531129, 0.10778858626802122, 0.173646085444958, 0.24207330398982574, 0.06662729496677076, 0.1902331300680676, 0.11718654689649421, 0.10617737312831226, 0.19791717580970258, 0.11487463143684211, 0.1575539182991751, 0.2438331918129998, 0.1860323175787926, 0.16663403670874335, 0.2151701653436307, 0.10418491633308512, 0.15717756994549306, 0.1582949398265731, 0.12784539631778194], [0.04606638757151462, 0.025833597549447612, 0.030233698236125133, 0.03159099919421058, 0.04817162017007509, 0.016515440300046917, 0.034520944595457084, 0.06856523694530611, 0.05022982263096398, 0.13148560098582698, 0.01304518553473416, 0.03790888417091581, 0.022974432926745187, 0.03391773845519751, 0.06339427752179966, 0.03928778880846597, 0.016269388180526517, 0.03378108752170398, 0.028068109400450226, 0.029856991736338507, 0.03290902665485779, 0.02077671244830614, 0.028170847536755667, 0.04685033683574969, 0.020799666357737397, 0.03825843476900651, 0.01077469532197762, 0.03207690195150433, 0.05384615982972807, 0.022044296849579103, 0.0558456837860567, 0.04969236215636615, 0.054139042904059735, 0.03814857393022507, 0.02513042268072886, 0.011034469991441696, 0.05546640131562468, 0.1133682344469332, 0.049399544199508046, 0.010251642088405788, 0.024165713055539998, 0.041039973617561405, 0.008721388162924879, 0.05459756567893971, 0.06781175116738004, 0.06275296616818636, 0.028071683200616992, 0.020824252034447367, 0.06957726207591834, 0.028435994397788763, 0.07442563336582915, 0.011997413783965093, 0.019321365642451474, 0.029188122284869035, 0.26886725978505227, 1.2606560246598337, 7.739686523714374, 16.72268790583457, 28.638822993924542, 40.334207088716575, 43.833424122102805, 47.57008575624036, 36.08271083524151, 31.415572781716627, 15.06592679408289, 20.338440518225394, 29.50180522857174, 27.856412126171975, 15.003211036805185, 15.500873519528298, 22.817362777648434, 13.830309587140238, 12.395541879438586, 9.570278256170212, 5.589632939907813, 3.1251579955700906, 1.5871099911389814, 0.6858575584427004, 0.5185923112496253, 0.3365670625240572, 0.113055961687238, 0.5037169675192525, 0.13558334400576932, 0.38772659796860914, 0.5419239786363418, 0.4016555473208428, 0.4671416317503299, 0.731909984061795, 0.40506181938032954, 0.687608345141334, 1.5041849569928263, 0.21134816801115391, 1.287183136709275, 2.099541791023747, 1.3783189173667663, 1.4353565535237713, 1.386496078583502, 0.4650746652435872, 0.9228510253371732, 1.0996592765854252, 0.33771018828115157, 0.7144426278048946, 0.5973020844882535, 0.23137770533081026, 0.18565374757013015, 0.13381553483345818, 0.35560529739145313, 0.16514270866830505, 0.6696568826033223, 0.7975839438938326, 2.2360741034630807, 3.11886455262861, 4.723356894908413, 7.599861381515381, 6.742568054506856, 11.211887251946235, 19.87849554707927, 20.360294003640455, 17.62393286151271, 22.79460910827883, 24.2692300581163, 32.27832555770874, 37.71679770561957, 36.45146069988128, 31.416665161809615, 15.421576922939671, 5.9496942643196356, 1.0450188214740446, 0.1305286192725743, 0.11839869717556624, 0.007508250588040439, 0.0405314406229844, 0.040636674290703195, 0.04829424786411467, 0.00788213884187562, 0.07930200516937241, 0.03270070819604782, 0.03634945474444859, 0.028154183209182757, 0.046176348001726215, 0.07341072774462162, 0.07085079131948371, 0.06428405417189484, 0.06981121766711436, 0.023987622511002327, 0.08752192175316234, 0.012565648968091175, 0.05440211366681803, 0.0648289495297978, 0.028974665291306954, 0.03905379491287374, 0.008256625601901643, 0.027421291789881168, 0.06448628606214639, 0.0430107309723333, 0.022467889845551505, 0.037899212310871774, 0.06885775995831336, 0.030539095356699922, 0.013113916070470888, 0.027118543418304577, 0.06474851029774835, 0.06801709337460418, 0.0616537410795929, 0.013537177733416039, 0.022838019480508183, 0.022906038512085235, 0.04288598121474347, 0.018054034050193526, 0.022376399795194308, 0.024959885763124596, 0.05534570799359391, 0.07039242559262822, 0.08595920963993958, 0.0609343423838577, 0.033252617088897575, 0.02341005158790898, 0.048829693527471636, 0.08707781292257771, 0.0632076163686091, 0.06172362362004577, 0.06126836054928361, 0.0331168701391547, 0.08268341767571627, 0.04299501850900631, 0.04673615526107531, 0.015630613535552496, 0.04889956840704526, 0.025690346768486406, 0.02871363423764706, 0.05254585198276947, 0.0990147881149765, 0.07405900666790624, 0.023596450355985475, 0.03683570607174789, 0.03793247201810441, 0.04168196678942731, 0.03269876233272014, 0.03464354164597969, 0.06405803908203399, 0.04538193014600585, 0.008946930193492483, 0.04442607841244148, 0.024799060925180395, 0.038166255239517465, 0.09350869969855394, 0.02198854288566978, 0.020574509286351746, 0.012359449700001749, 0.09839391981762263, 0.04832163933784731, 0.016727715602985794, 0.07093549766127141, 0.025824812436175924, 0.05733818011057954, 0.02158445831868918, 0.10018183879794614, 0.009677788606965014, 0.020900881894293333, 0.022975695056600437, 0.023192034455977624, 0.0244150402009367, 0.05838154972861371, 0.10689750343801514, 0.11805222625093115, 0.07896586877083586, 0.057498353773788105, 0.029781133710076253, 0.05983424778547018, 0.07267540591138025, 0.25500135946898694, 2.2532173125974597, 10.484534694302468, 21.037522592852195, 35.00150165250225, 45.188881504920225, 46.246246599381976, 47.70377974356375, 36.17015615586312, 31.9147002696991, 22.584146491942867, 30.178015962723766, 26.093059624395064, 29.188862846743678, 25.459010447225264, 22.864988196280695, 24.667056452843454, 19.35845790370818, 15.79327052639377, 11.038718531208655, 6.184545197794515, 3.270232985096593, 1.5195680025123781, 0.42525087152757957, 0.15516239098243176, 0.16012038945430712, 0.09769451984715077, 0.07354349844277867, 0.18427604569062112, 0.15240404544578445, 0.10338649949840001, 0.27140206086539453, 0.4475570536188541, 0.3675343588955941, 0.44743809548597185, 1.0997825860977173, 0.7335160107862565, 0.6421777377686193, 1.8012199214389248, 1.3188419346847844, 1.5207144377693054, 0.8485776979115702, 1.0456809665887588, 0.4703307332050416, 0.699775843851028, 0.7150136391001364, 0.8955287140223288, 0.8216130577268139, 0.5975163439589163, 0.32592665283910693, 0.23083736819605674, 0.17934299104156035, 0.10625072604706211, 0.1611497511546458, 0.5831583240820516, 0.8274692176811157, 2.007651566978424, 4.09935609467568, 6.141875693874975, 10.301019741642861, 10.365911433773658, 15.957239327892182, 21.498034346488215, 19.868014973978845, 20.628964593333585, 26.773224107680786, 26.86087731392153, 35.92795372009277, 40.78130629754836, 42.18135710685484, 36.07015140594975, 20.43355799490406, 8.078586661046552, 1.6916570908600286, 0.12692064392350375, 0.0849440282270793, 0.014232628520638233, 0.0391865502892723, 0.09497040311896032, 0.0830688594930595, 0.026389945921818578, 0.06618565293930231, 0.06716801514548641, 0.028021743844052958, 0.060853937625764846, 0.0459261245334581, 0.05754365638319043, 0.010382594285352577, 0.06986881215726176, 0.029909374913380995, 0.07070466770880646, 0.08608798902001112, 0.02921497749705469, 0.01091843544160046, 0.03392355306254279, 0.12934458442032337, 0.0720856637663899, 0.03611566003171667, 0.03604999097484735, 0.06538778002704344, 0.058570359758431875, 0.022800299226336425, 0.02428108972737626, 0.0024674880466679294, 0.09321989221197945, 0.030693215010086858, 0.03721331464006536, 0.018271503429259026, 0.08434098679572345, 0.05194417035747921, 0.02917521944900434, 0.040921325750288465, 0.02185954134010019, 0.060375125012210304, 0.03145276820437322, 0.025911983665859988, 0.06409732790123071, 0.03204923468611894, 0.07341546216799368, 0.03901721804492897, 0.029907953820281455, 0.01475077879149467, 0.11744747644350415, 0.24112243565820882, 0.2203569176696962, 0.12785085086380282, 0.3272153965888485, 0.11486409772788325, 0.09065994046508305, 0.2258717088449386, 0.14445338578474137, 0.20864133422653522, 0.10686655348587422, 0.10334467875861353, 0.08270800143720643, 0.10421546791950542, 0.24720281422618898, 0.19937755389799997, 0.16726897038038702, 0.13874302768418867, 0.10284476042274507, 0.16083608411492842, 0.08743661020191447, 0.08379610675957896, 0.12541312078434613, 0.19375927956594577, 0.1462995657517064, 0.080685245864574, 0.13927755787247612, 0.20450536341917133, 0.19827953539788726, 0.24045684314783544, 0.09571586795631917, 0.10309738557665579, 0.17517603963853853, 0.14457320193609885, 0.15315444388937566, 0.09645136598978313, 0.13391550930757679, 0.15106215051585628, 0.11683587781003407, 0.0913759109173571, 0.18010863463484472, 0.17424982401632494, 0.111518767962773, 0.1278223677147781, 0.2131536227440642, 0.11923354915193013, 0.13678501420203718, 0.18185582072023423, 0.23847733323852863, 0.1811604886766403, 0.11048911514902308, 0.1431534877948223, 0.13545727657694973, 0.13370895668143226, 0.3750784250517046, 2.1517046565009705, 11.398949988426702, 23.637271504248343, 39.18712169893327, 53.031692043427505, 56.86740136915638, 59.607796669006355, 49.08478744568364, 42.966976473408366, 27.314446472352554, 31.086770296096805, 41.56989097595215, 39.650890980997396, 25.71549423279301, 26.033863213754472, 32.29932004405607, 21.573014374702208, 17.60396799733562, 12.661242254318731, 7.76523046916531, 4.394962826082784, 2.67835860290835, 1.203536999321753, 0.8498604355319854, 0.6377047648833645, 0.3976299697833677, 0.8356569815547237, 0.8843470785406329, 1.3760245759640972, 1.9304514772469, 0.7993696029147794, 2.096554415841257, 2.1482853303032536, 2.215680720344667, 3.2162763707099424, 4.252759746966824, 3.2549166198699706, 5.982920171753054, 4.806537128263905, 3.0648373355788574, 4.291407840867197, 3.075375273343056, 3.2047835809569207, 4.564956878462146, 3.283106694298406, 1.923515991337838, 2.9148647765959463, 1.8688060367299666, 1.1325582789797937, 0.7262726801057017, 0.5814708468894805, 0.7044660179845749, 0.4506613031750726, 1.1327302503970362, 1.5553694362601929, 2.7333698445750825, 4.785293571410641, 7.932044459927467, 11.8700913652297, 13.02258570348063, 19.5837608075911, 28.831623177374567, 30.613920727083762, 27.27081794892588, 33.74956738564276, 34.19893764680432, 44.06218851766279, 50.49992761304302, 46.95145345503285, 41.11327609708233, 22.559835641614853, 8.717382396421126, 1.6581677717547265, 0.2771139817853128, 0.24578519916582495, 0.09250293350628308, 0.1483432891508264, 0.2363634055420276, 0.23619664352267022, 0.11179566278212494, 0.15804257514255662, 0.13450893633548291, 0.09900345001369716, 0.07709622353075013, 0.09120882714107152, 0.19776821767370548, 0.2726918464947132, 0.20224597094760788, 0.13698243506012425, 0.15959195732589693, 0.16383269831778544, 0.11434161044176548, 0.2649604871628746, 0.13545457994745624, 0.22143163177515232, 0.16425087507213318, 0.1244952325378695, 0.18238895662849952, 0.14246057658906908, 0.16476144203014914, 0.1363331295790211, 0.11461514213512983, 0.16091716686083427, 0.22384848595867235, 0.16629108978855997, 0.1025789738782952, 0.07982678305838378, 0.1706353905460527, 0.15518040937041083, 0.13676469755028525, 0.1064434048208979, 0.1417531403562715, 0.138886408700097, 0.2390148511697208, 0.2027555266695638, 0.10746794016731363, 0.14548533686226414, 0.21458389357693736, 0.128295702799674, 0.17949898186470234, 0.15251341215785474], [0.04068245953549782, 0.0434829322471013, 0.022342312713003448, 0.025054723617710897, 0.020696022322461493, 0.061715721423106815, 0.014566989510410256, 0.004486913770256985, 0.04937925053039386, 0.04642926426904817, 0.08193740125505194, 0.060197316004984805, 0.08271444423664963, 0.024448430143116463, 0.02618630251456653, 0.021245558257965792, 0.016922581557845397, 0.07807954334683957, 0.06518881167134931, 0.010194701645823737, 0.05010262522245607, 0.0497047383067829, 0.049463056718870524, 0.019884470910314592, 0.03260833331413808, 0.07466755627143769, 0.023947086883708838, 0.05492926642839467, 0.06556810180266058, 0.03383859774217971, 0.06310920471385603, 0.05181642136566582, 0.0654383494909252, 0.03866161918267608, 0.06140118870403498, 0.11501490213577786, 0.01275916948103376, 0.10046362125825498, 0.05049738649939818, 0.04789232366508053, 0.06749506574124098, 0.021180938741552736, 0.05232664358411586, 0.056095179470796744, 0.04028079580635794, 0.0804338081469459, 0.08180626998505286, 0.025421403941788503, 0.04850591795759336, 0.06092154871552222, 0.02600295852208811, 0.024977450244008534, 0.031012941805285313, 0.049197932840475155, 0.05307203564312189, 0.04270641403573175, 1.0168319952584084, 5.836248532418282, 16.262297745673887, 27.08935537645894, 41.351999390509825, 48.955058974604455, 43.51326065678751, 43.35694636068037, 28.153837611598355, 22.903215615980088, 33.69231254823747, 18.986142604581772, 22.55398346531776, 26.959266047323904, 25.333021956105387, 22.107503990973196, 19.200555047681256, 14.682639644991967, 11.898616802307869, 8.934866055365532, 5.242417377810325, 5.1209827584605065, 2.267473412136878, 1.277572839490829, 0.4755593139317728, 0.5131065701284717, 0.12452304152952087, 0.09597917237589437, 0.06280950728743788, 0.26196456243914945, 0.3341755811725894, 0.30082740610645664, 0.30102162471702026, 0.3252777150802074, 0.31137490464795026, 0.6583885872556318, 0.6405165527136095, 0.669577454607333, 0.8070397364997095, 0.9097202783150058, 0.4531342962816839, 0.4739898449230579, 0.3067290716834607, 0.2526501436988192, 0.18822234844969166, 0.1185026016807364, 0.2977789890381598, 0.4047499909516304, 0.35061546030544466, 0.3309935890138149, 0.6332024355088511, 1.7227606283080195, 2.399922292078695, 4.544717938669266, 4.549698858491836, 7.852311009360899, 7.5756039734809635, 12.31498129906193, 12.469230467273343, 16.40821187726913, 15.961969706319994, 25.171155545019335, 27.889056051931075, 25.141043509206465, 31.970372430739868, 38.59720506975728, 33.22002387815906, 23.560047880295787, 17.259695683756185, 5.138200002331888, 0.9953543832225185, 0.1290810501743709, 0.11543024436480577, 0.020463834479150754, 0.020301481295797615, 0.040321800662505056, 0.06076088858648174, 0.06715446305010589, 0.05646358349270398, 0.07061374073307361, 0.042726236560772506, 0.02725529202800845, 0.0035241593450923724, 0.01948163889709019, 0.022051542126122984, 0.040785758831207795, 0.037316250044011304, 0.053919861318483475, 0.06455439893949418, 0.013669602734397256, 0.09310202192394965, 0.03432167363503287, 0.09088488686228953, 0.014627234664775673, 0.0527831745303927, 0.02485217188575095, 0.04048242631758894, 0.06618788225516196, 0.040841169970771, 0.03229412618243406, 0.04724832334285302, 0.050897468256974415, 0.06213107514345358, 0.05386659905554787, 0.018676945887085412, 0.030016659781517043, 0.0694470347896699, 0.05814577084815791, 0.09913573041558267, 0.05110459544906213, 0.03463884935744348, 0.09825292899603806, 0.019740976896437428, 0.018418427601817156, 0.03177120797185889, 0.054444983947060765, 0.05291622485064211, 0.025185755296279828, 0.019930602809894952, 0.07622559524832234, 0.011165829172598259, 0.04204734859447326, 0.07238957850683121, 0.04887526426764746, 0.07260176954009841, 0.008549018379961772, 0.0748118642537344, 0.11734473639197888, 0.035115995729762706, 0.020370837150802536, 0.03981917420582425, 0.038791651116503824, 0.03248080648782273, 0.06548511915870252, 0.021020682723892313, 0.04314149835056836, 0.04706859911581682, 0.06602131175778567, 0.043646254531678655, 0.02084619853825819, 0.029378899245432792, 0.02326202999439932, 0.031119115845931154, 0.008535456708482197, 0.07355063838223297, 0.030044635397291956, 0.05882663532130181, 0.01278103075756301, 0.03944490578085665, 0.017730584067683068, 0.05213227558640703, 0.037245107288922996, 0.09807885849788305, 0.020802935637954264, 0.06623280565104177, 0.06651842621185126, 0.06852245093473504, 0.05434856029047121, 0.03881057731867318, 0.01594503134143569, 0.0577212279031594, 0.052658068541918075, 0.0704345680893429, 0.032213974233356216, 0.0466739067867879, 0.06266943194092282, 0.04790755732345486, 0.04605106198258939, 0.07648246452933358, 0.01604904884457468, 0.14164001981337226, 0.021130352040692683, 0.0516184029589978, 0.0834466327702807, 0.07632827401281365, 0.12263551579728244, 1.6925075097430138, 8.152941561514332, 20.77432567073453, 34.45507234142673, 47.9067349433899, 56.2661490901824, 48.74967190527147, 49.326503507552616, 29.224001399932373, 27.200540842548495, 38.56563783461048, 19.52202073989376, 21.272596120834354, 26.209954100270426, 31.07934524936061, 28.07421349710034, 23.937870187144128, 21.221646493481053, 13.894212841987612, 10.816743758416946, 4.746924456088774, 5.072854786149917, 2.4592086720851163, 1.0854609094319807, 0.5847087634667274, 0.16468775969359184, 0.20335407116480414, 0.07040629944493694, 0.15062862135950597, 0.1576836935935482, 0.2292146867201213, 0.2153092256236461, 0.17022171838869973, 0.09982822027297751, 0.32686379287512074, 0.32980409961554313, 0.2249602174326297, 0.3741045127953253, 0.3306702999097686, 0.3979129320190799, 0.4130735056054208, 0.33378132168323765, 0.41738210666564207, 0.27559850665350116, 0.17409597823937095, 0.10219298047764648, 0.02653547772957433, 0.1799558000939508, 0.19415389145574263, 0.3533529069635176, 0.5050106448752265, 1.1597290274596985, 2.2188119974828537, 5.6944523992077, 8.080335057550862, 8.28768184108119, 8.980406734251208, 12.2140783263791, 11.653141148628729, 17.25431223069468, 18.496364085905014, 28.081705224129465, 30.982299927742254, 29.307375300315123, 35.412107129250806, 42.29381145969514, 39.90498996550038, 30.169461273377944, 21.96521609060226, 7.124204866347775, 1.8630951883331424, 0.11854623804890341, 0.15355253381834877, 0.037474952818405245, 0.026060664094984535, 0.08178170920620043, 0.02425055920837387, 0.048017218979375983, 0.029130910838683768, 0.040623279243347146, 0.029156404329584013, 0.015473943766987613, 0.03589580428876704, 0.00889906885042306, 0.023011302823320996, 0.056232734388040925, 0.06824377113051953, 0.03653127039151807, 0.042889861450079954, 0.04822593197346695, 0.030037968517130906, 0.04682484526006926, 0.05642327960700758, 0.02549433168174038, 0.012381063913175417, 0.04167820529771909, 0.03825933875275716, 0.035098134389808106, 0.07579316159770375, 0.04258623016217063, 0.038576357427143285, 0.028299841421446013, 0.01160885303116013, 0.05688006336229944, 0.038035043530286326, 0.08076160184798703, 0.046987485726394, 0.029368147201415513, 0.10689386452037482, 0.027134872582410614, 0.04519741403900328, 0.03593608136138609, 0.02862294857961036, 0.05446461111968083, 0.0287240223899003, 0.06392403115187922, 0.06835882987586722, 0.012408454429298159, 0.018302286757276427, 0.02049242296526509, 0.1330711578409518, 0.17181652958594984, 0.09203290026034079, 0.14677875374834384, 0.15114341712286397, 0.1814551107705601, 0.18168735798568497, 0.22768444141312955, 0.13904524937031731, 0.12989180102463693, 0.12166975471641749, 0.14079007590490003, 0.18811800727440467, 0.12521861106037133, 0.1477494177919242, 0.11731456784952073, 0.07291927468031645, 0.13774029520009795, 0.15678634416432152, 0.28924124555722364, 0.16020868874845967, 0.14515178218003244, 0.16916778058775012, 0.16215265217807986, 0.09293094682957857, 0.1258111264436476, 0.2725279649659511, 0.15373829481822832, 0.10676454887875628, 0.10816404595971109, 0.16231426608658608, 0.23829538735651204, 0.3913934012093852, 0.17361260740266693, 0.2104751188908854, 0.27152068191959017, 0.10690240640073054, 0.19794901442383567, 0.15346351440154737, 0.2180522494018078, 0.1641681222545524, 0.1840893960287494, 0.2887921648160104, 0.09823602143554919, 0.13951524431186338, 0.14677979562792087, 0.16869007880168577, 0.13853112776433268, 0.1963098620575282, 0.10992856095394782, 0.19880251298027657, 0.15284008737052643, 0.2448973798703763, 0.13085727099209063, 0.1574596741627301, 0.24143362057305154, 1.7954059882510094, 8.326085767438336, 22.29694466437063, 37.47597594414988, 53.14775105445616, 62.24475514504218, 57.329786054549686, 54.94150192506852, 38.838050365448, 33.941571327947806, 48.666458822065785, 29.229896722301362, 33.15498705833189, 39.21105992409491, 37.001847682460664, 32.699943088716076, 27.17231938915868, 22.491213775450184, 17.290613766639463, 12.286427424800012, 7.2146208920786465, 6.890059959503913, 3.401307809737421, 2.2673640760683247, 0.9414534787497214, 0.9666624905601625, 0.3198605847935523, 0.26297521627237724, 0.5732909277562173, 0.7905442700270684, 1.1173771129500483, 0.7247177054805141, 1.1922055170420678, 1.224313916698579, 1.3159157239621686, 1.770683901925241, 1.855346423483664, 3.2313899984282837, 2.518150128664509, 2.4217345926069447, 1.2185553869893475, 1.9108859593829803, 0.9152570102483997, 0.8865835649832603, 0.8558660132750389, 0.7638735011700661, 0.37595577958610754, 0.9516938066770955, 0.9973467021219193, 0.9500123969008847, 1.197120124293912, 2.5236286992026917, 3.4318466484546666, 6.203890327484378, 8.115311322673675, 12.098221317414316, 12.52055173920047, 21.275365314176007, 22.8850079736402, 26.15140291952318, 26.636909977082286, 35.44015992072321, 39.16193223768665, 37.04467212000201, 43.77647130720077, 50.1335782389487, 45.12130691159157, 32.79023801126788, 23.122195659145234, 8.3052775936742, 1.9019615866484183, 0.206985404534686, 0.2169011103650255, 0.13066717393455968, 0.07680695639142106, 0.19638667003281657, 0.1899567408667457, 0.22620115729589618, 0.12572645074537686, 0.17742104497888397, 0.10283867002374704, 0.10544605793491488, 0.23172802201682524, 0.15233802398846996, 0.19890523004916408, 0.18204510572456545, 0.17713921655329967, 0.18268563183805636, 0.21485868931537677, 0.12665576136280454, 0.17499616219391748, 0.10146114434446059, 0.15417818250435014, 0.1818660862984196, 0.1527874111648529, 0.12055178728675651, 0.10667254171905019, 0.17836123404483642, 0.213035645203725, 0.11911829122372213, 0.12248271956078469, 0.1399291922608691, 0.12800015373936585, 0.19309863598356325, 0.09269792586565019, 0.09763252035143877, 0.21223705982969654, 0.14748334013406308, 0.21880463967400215, 0.22438562084590236, 0.14534439200595503, 0.15642125730312642, 0.08194104017269227, 0.26410464437738546, 0.15532360652521734, 0.24328229798664971, 0.196598079656401, 0.07756619548965847, 0.15482404058979404, 0.17486578935096342], [0.032543192857936505, 0.0757080185857992, 0.02663072352598031, 0.03240017956423183, 0.023202504962682727, 0.04802838471087237, 0.012580492879234016, 0.09910599088236209, 0.04084540643699227, 0.043192393401817936, 0.048150445499847976, 0.05276148658125632, 0.04600971238687635, 0.033374153107645056, 0.005408858931097653, 0.026175134867850332, 0.06113162534611841, 0.016682997135625734, 0.050163946730355104, 0.0392048406384645, 0.07033432548445079, 0.03359883137407803, 0.06106719735168642, 0.06071245650790873, 0.030141635535044536, 0.06555294858351832, 0.01604351481693166, 0.03640352139970468, 0.09231881959544075, 0.02728560612717223, 0.015288124352903857, 0.058770925407448125, 0.05886244227088267, 0.03628030381796341, 0.028161708107819, 0.03775295080436814, 0.035726736344757586, 0.028704123256067117, 0.03738252814078043, 0.025769148487597707, 0.061882824351590496, 0.08070608345611442, 0.01859865744688338, 0.02589141995075249, 0.049810286070550644, 0.03334814442261573, 0.06584125811294203, 0.035572745011097966, 0.07582330715752418, 0.01049854935357167, 0.04301399833733036, 0.027022640701503526, 0.03798332493451815, 0.03356709235137509, 0.028891443244872556, 0.05970453760857063, 0.06015018244544345, 0.20684793771755314, 3.2049061550248057, 8.832308823062528, 22.06295567174112, 35.101777045957505, 46.87953287555326, 43.858401775360115, 39.61429918965986, 35.02827967366865, 38.559934708379934, 37.19022343235631, 29.37527152799791, 23.622825414903705, 28.670243140189882, 31.07476588218443, 32.16761862078021, 30.489081490424375, 23.22515199261327, 21.204168411993212, 19.47666049003601, 10.414188946447066, 8.219764530658722, 5.513979244616724, 3.242797721778193, 2.268629775893304, 1.391369378374469, 0.9305916390111371, 0.35699249876122324, 0.22537471696494088, 0.15064333024765217, 0.22880185725948504, 0.27183051851968615, 0.36390920019438194, 0.2361813217641846, 0.2608237655893449, 0.34203101610464437, 0.16549668725459807, 0.3059129735394832, 0.2334285073823506, 0.5924257816326234, 0.26424995593486295, 0.4328308518855803, 0.2011946684891178, 0.34398490803376325, 0.5060701138309894, 0.49317188981559973, 0.7456950314583317, 1.3587054730423036, 2.4503968223448727, 3.0239576581985723, 4.819877109219951, 9.527301826784688, 6.048118299053562, 6.387077271938325, 16.73876766235598, 16.53155080733761, 19.660366658241518, 23.506064299614202, 14.668069020394357, 26.770686334179295, 24.750801017207486, 28.269208246661773, 33.05546868231989, 42.968565033328154, 31.273026004914318, 19.30602954279992, 12.293959356123402, 4.279168084744485, 1.3782761390170744, 0.04171008604668802, 0.020922443438922207, 0.05816658545706061, 0.010701068526794835, 0.034212184348894704, 0.04048220798253052, 0.06234521204004846, 0.053510575014497005, 0.033734130162385204, 0.03518681289748319, 0.050072629049780874, 0.025962827006174673, 0.04874966415246168, 0.024057401629585414, 0.05077192559838296, 0.019284173988947467, 0.02573515525117757, 0.04816322384642498, 0.05761116405107802, 0.049212978807308023, 0.07043272947832462, 0.011140512839530506, 0.041965377186575246, 0.06454589536353465, 0.06354845654700073, 0.06904422575908323, 0.011069492658510083, 0.01995326752113479, 0.0650717074712438, 0.03497983509254071, 0.06587659774888908, 0.03938605873695305, 0.05685618823213924, 0.08465340511212427, 0.1043445384129882, 0.08149294768490138, 0.03468587949511505, 0.03312219828066807, 0.024661977152009646, 0.020815208366501237, 0.03229764635644613, 0.021567627366992737, 0.04296302284684874, 0.08759247845098858, 0.03250461650050936, 0.037953374727118405, 0.0745846962015475, 0.01795240674137829, 0.05748184457901986, 0.03095672052774218, 0.03612458878647416, 0.0284981586024045, 0.04877424408351222, 0.0663672387599945, 0.07362386106603569, 0.025042994811590162, 0.03056555603360457, 0.07230016072430918, 0.06903405977232803, 0.05502875060624173, 0.020846399636338317, 0.050585371697501796, 0.09283450402079091, 0.04568509795072098, 0.023684866478546493, 0.025866047118700324, 0.04229344284882949, 0.029713373233173645, 0.05836633139199788, 0.05644004927167008, 0.019048105910300248, 0.1005426049232483, 0.029749132302259246, 0.037691487570203124, 0.0034422295932252443, 0.03824616587089916, 0.053913023983759266, 0.003828056130347954, 0.04582111686167698, 0.08161490888244684, 0.014896866012995523, 0.017624021237415653, 0.031705337816909436, 0.060574989690775835, 0.05794398711934205, 0.025898366453005903, 0.015441396521524558, 0.0792807232468359, 0.03807415231882084, 0.007615438737576047, 0.016050708382540656, 0.03138742856531134, 0.0452266632759523, 0.039586766112235286, 0.02446447585469052, 0.05733346866984522, 0.043516077041145296, 0.07190798499411152, 0.0692175378301932, 0.07920739331072377, 0.025569628548598098, 0.015851588724481485, 0.11630981289330991, 0.032711464070504716, 0.022834882350458253, 0.06734049984163816, 0.01414712927784891, 0.5194419946882033, 4.951497633611003, 13.063066524844016, 28.458213536970078, 40.6604580725393, 50.986481943438136, 48.50478656830327, 43.15216725872409, 37.765497853679044, 44.526530465772076, 32.86981309613874, 27.085064303490427, 22.200036625708304, 30.60031206377091, 33.007090168614546, 37.07495281773229, 31.46027211220034, 29.31006604625333, 22.90562002889572, 21.869808358530847, 14.196932546554075, 9.13375081554536, 7.253266534497661, 3.094810372398746, 2.8649425650796587, 1.079441787254426, 1.0916376618608352, 0.5327443454054095, 0.34015998424541566, 0.07125414427249663, 0.13372335913440875, 0.13443074940193084, 0.14444198639642808, 0.04931618617246709, 0.30852815256484095, 0.14761093973873124, 0.3150851603957915, 0.1962883503086144, 0.2624358290866498, 0.047619753412061164, 0.1588920287547573, 0.2523302866686737, 0.13236528442751977, 0.24320575048125562, 0.30643820342036987, 0.1367610356500072, 0.5750164641968666, 1.109801790406627, 1.8960862438524924, 2.78781111682615, 5.416512758501115, 9.652655874529193, 8.440266943746998, 8.859802676785378, 19.26131452283552, 17.962272590206517, 24.554468739417292, 21.82916279762022, 18.47597952811949, 26.139451457608132, 25.919863447066277, 33.914240252587106, 37.02600556035196, 45.41139756479571, 39.018757881656775, 23.939658787942705, 15.423013491015281, 6.095287742153292, 1.605371198346538, 0.11730820165886996, 0.044598831239366726, 0.00020961753145984992, 0.025378736674845703, 0.021217128735095746, 0.052844894404012355, 0.0578618280199026, 0.05112093610448703, 0.03500261854740881, 0.07008427438596565, 0.08718232263720806, 0.04053781830495404, 0.04484889765961036, 0.028346574700046933, 0.019329480428789413, 0.017548199600329804, 0.0023269860849400325, 0.008463730768961533, 0.05643716112019555, 0.01685159968122119, 0.049837125960977814, 0.03516984021952076, 0.01879160052105304, 0.05344366106475073, 0.08705389565758168, 0.07757572562343652, 0.022101249741089922, 0.044124002283018444, 0.034322577618783524, 0.10386761037572738, 0.04149384623874099, 0.034081673610114285, 0.04213102837844242, 0.007141975811757749, 0.06297350755982822, 0.03518627280549657, 0.05343352189107288, 0.036610269378269875, 0.016996867188643065, 0.028991727984600493, 0.046270481055422176, 0.037568986280671055, 0.042268786308986527, 0.030855692682727694, 0.03090971337270833, 0.044341555931755615, 0.03341895392945698, 0.05868542233421918, 0.05488750314520252, 0.041101237668866114, 0.17050229043008822, 0.11040331330150367, 0.18875281837198044, 0.12762239578390314, 0.1885914342898515, 0.12994852217455066, 0.13892143423999512, 0.14364015280960069, 0.16190555817898244, 0.1253843695045479, 0.09432589334826316, 0.15301509249594905, 0.2719698239478373, 0.1798463108078126, 0.1322019391603047, 0.1298647734426683, 0.19025994314541742, 0.1307020615786314, 0.11605580112025624, 0.2266737416146263, 0.18539536143502883, 0.12684788855333484, 0.1801687265716253, 0.18385687302197182, 0.05476076155900956, 0.1778139867970059, 0.2548757516929219, 0.1134687988087535, 0.25223648686322475, 0.20076656323527137, 0.08406431414186956, 0.14905596542502605, 0.1601454098859141, 0.2713578116268881, 0.14409451955749145, 0.1158450196887697, 0.12243089371270711, 0.18514532565830216, 0.16685260159354057, 0.10844347653009238, 0.17753343007737593, 0.23906916680355228, 0.08407313181387802, 0.16971107482189135, 0.1498543209726772, 0.1397954486310482, 0.08512590516118274, 0.10399265890760769, 0.18600671492036314, 0.17001990018592728, 0.16267086469358014, 0.17025032411179236, 0.23605439631688982, 0.17666755154007868, 0.18434444202050088, 0.16593173326503846, 0.1125171490674538, 0.5587684134802511, 5.191983051838414, 14.367890031107011, 30.167741314057384, 44.96404340190273, 59.08057912703484, 56.08959928635628, 53.67465480681389, 47.627018959291526, 49.82835508161976, 51.03489575847503, 43.14860574660763, 33.41020391833398, 42.38322973251343, 43.42459940141247, 44.702401699558386, 42.705068049892304, 34.09417506187193, 29.87658573735145, 26.261792144467755, 15.062583954103532, 12.529041709438449, 8.285069542546427, 4.371833099472908, 3.036236147726736, 1.9608089063436756, 1.4407316715486589, 0.6307605149284486, 0.6307977774450857, 0.4777589975105178, 0.8414110373104773, 0.7516547664999963, 0.8581492004375305, 0.6898458121765045, 0.803889889390238, 0.9400223039330976, 0.65918262206739, 1.1453530504818887, 0.8984201749966991, 1.2989040368026303, 0.58418849783559, 1.4394268705960245, 0.7998057214483139, 0.6642955541610719, 0.5875991825615207, 0.9538582808548405, 1.2210780838804862, 1.8020756110068292, 3.1105780553433204, 3.911538792233314, 6.130633690664846, 11.803390479856922, 9.817990641440115, 11.624687294806204, 24.98128733327312, 26.06270440163151, 32.51009448882073, 34.14757028702767, 24.478190406676262, 36.49194740479992, 33.33059157094648, 40.60071253007458, 46.334519540109945, 53.11111611704673, 44.435962938493304, 28.197656369978382, 17.52205517984206, 6.738065663845309, 2.0434434399489434, 0.18604704178869727, 0.24029582678791017, 0.16673954233767527, 0.24696080705090878, 0.14556145535842066, 0.13228470729964395, 0.20907782048227327, 0.22165977275900303, 0.29732604721380823, 0.1320345795923664, 0.22358623874043265, 0.16130450091535048, 0.1624385102261459, 0.1509335396751281, 0.10139968111029557, 0.10250297029532733, 0.10862683201388967, 0.10674515153251349, 0.20276674219677526, 0.2360953054120464, 0.14011135264750452, 0.18667953930074171, 0.20695949544108685, 0.24039149584789432, 0.15188992383979982, 0.20718723805921696, 0.25205849399489744, 0.09664910094391915, 0.12686792175255476, 0.25580052706983786, 0.19301477999937153, 0.10565937511743077, 0.11049119890817713, 0.14652272716404932, 0.2945903778797196, 0.31444170782642983, 0.22848101963679637, 0.11482687351564247, 0.16084133947808898, 0.10154969644762817, 0.18823152618302455, 0.09420400875951014, 0.09226480273589974, 0.22340343483994085, 0.11534224384494367, 0.0889693912599356, 0.18171433960237812, 0.16949568154110065, 0.10693442887596546, 0.11987631224215993], [0.11029927090050713, 0.03047779491621881, 0.02344525141280986, 0.01608445647082502, 0.03718357127640517, 0.022735712268660148, 0.01685045821021401, 0.03595722538809623, 0.17106634564697745, 0.04943266218047469, 0.028389261119187843, 0.06138252680219951, 0.0582384943000732, 0.027497795245219624, 0.04074798686610114, 0.03928924054508248, 0.0010697194515922738, 0.0312935502358502, 0.043700416947925286, 0.025101811211976795, 0.039230274757550615, 0.07236396818752251, 0.0223517183574938, 0.04911093972623349, 0.01753791486994634, 0.01226019534853197, 0.021138212102795803, 0.07120291597299999, 0.03378169656160378, 0.07221337828424669, 0.04316542327644364, 0.052683629065511696, 0.0913780406417866, 0.022824777650736996, 0.04678784321332651, 0.016737822217926863, 0.013147814503510394, 0.02406686090023047, 0.08560117078764785, 0.06494356394414941, 0.005872058672755356, 0.08412288922456004, 0.058663002771115115, 0.04339912605862464, 0.049175789069023826, 0.017418839908655614, 0.017503653502752705, 0.009813739527617733, 0.0029891223417625075, 0.032899607603828755, 0.04809879968243261, 0.03074946693114696, 0.019747011754060947, 0.044263081715231946, 0.05854578365782096, 0.022812047184655265, 0.038381495302723306, 0.03622549022698114, 0.13872899295341584, 1.4020509729462287, 5.719062330261354, 18.777301888312063, 28.2171074036629, 36.76898441007061, 46.394849515730336, 38.71579793191726, 43.98585919410952, 48.73499831845684, 29.330099551908432, 26.110318053153257, 26.76084706860204, 26.058317230593776, 19.03777668553014, 33.3628922893155, 29.191751672375588, 30.034151269543557, 19.737960946175363, 18.529421821717296, 12.039578941560562, 9.593108411758177, 10.0849393106276, 6.400790368357013, 6.075753848398886, 3.6687774187134163, 2.921671804881865, 2.1854331176127157, 2.067324423020886, 1.2507533882894826, 1.201808214668305, 1.0187697074105664, 1.1439156243878028, 1.1673086400954955, 0.9552076987681851, 0.925095601668281, 0.9211713928849468, 0.9684993855414853, 0.7503479430752417, 1.0304944073000262, 0.9757674761837529, 1.0558065651885926, 1.3292990961382467, 1.4163515668722892, 2.6240158802078617, 4.020867751490686, 5.479021120455958, 7.945380518513342, 10.342732187240355, 12.476881050294446, 14.15799713903858, 22.82040261453198, 23.20601082617237, 20.959088917701475, 18.702449337128673, 12.120202279859974, 25.095959786445867, 21.67674929864945, 30.52194703009821, 41.86522976044686, 34.736012105018865, 36.96655811802034, 22.852589584166004, 12.908066222744605, 9.018843020162276, 4.347495282849958, 0.698422564854545, 0.0604337920254517, 0.024474839109086224, 0.03464475589533968, 0.007945299439597875, 0.04090486252079568, 0.07354258679814878, 0.02397624227488714, 0.029997383094122334, 0.0659045369754876, 0.04120397772039137, 0.009523396034755055, 0.02898062928579748, 0.0192896208740891, 0.10964569064878649, 0.007815418329330222, 0.05934029727453186, 0.0475776836936993, 0.03192134013759994, 0.03404650251351057, 0.09382690963966232, 0.008269116665507037, 0.009856569588244444, 0.05137389450664482, 0.0408361942297028, 0.03686832226512413, 0.02090841445380882, 0.07482450470448503, 0.0900433699209844, 0.023209570208564404, 0.06569947055991619, 0.05810820189635119, 0.00869970212900831, 0.028793249925177906, 0.012816260268370952, 0.03431113226519477, 0.06337492614083233, 0.02191961029424302, 0.04077969141484749, 0.03409310364194455, 0.046816234431800344, 0.07394603934259185, 0.008542475989088416, 0.08577318050928655, 0.030647351241279996, 0.028627552768035282, 0.06004149755162578, 0.1074413032901864, 0.0403890670126965, 0.10127370561202688, 0.06961820181459188, 0.08456828508285746, 0.005552037412511005, 0.02391476180374382, 0.018958781973548958, 0.0758221120603623, 0.08956255015706824, 0.06288271464948213, 0.04648341519397594, 0.08154501868111473, 0.04023155167458519, 0.07180110806779516, 0.07837809547181092, 0.07771568222632332, 0.06224403863832836, 0.029709077395138242, 0.013229578110058943, 0.020853777063049136, 0.029318713462881507, 0.07764380785726732, 0.03960513690065953, 0.037173095024040634, 0.02416555409229571, 0.05256044595772701, 0.05762871895586291, 0.0442053723118959, 0.02176364436895857, 0.051331962684109333, 0.04590170548087166, 0.004693417079491361, 0.030695229821327715, 0.08742031551176503, 0.03195473199499951, 0.0185582309871191, 0.038243450089207584, 0.06491975393146276, 0.029043088434264067, 0.020187853219648524, 0.020967970129042383, 0.01906573550865775, 0.020507740893311078, 0.05957087824842142, 0.019580736200535492, 0.10134526588503392, 0.12606488540768623, 0.06320388552041785, 0.039454374627600756, 0.0332594582540614, 0.10126002328169924, 0.03284241914028122, 0.07267513778060675, 0.031159701268939726, 0.04901510978778524, 0.0787337824341751, 0.02644599674479856, 0.006281055778550405, 0.09041237915235181, 0.03393151654651569, 0.0076355423211240244, 0.05095951371796189, 0.3518796892416093, 2.0775762729106413, 8.589747490421418, 24.310713045058716, 37.048963192970525, 43.80450056445214, 50.506819217435776, 43.068440345025834, 48.67534691287626, 53.9520134464387, 29.51856355513296, 28.47973362092049, 32.35441169431133, 28.5148133385566, 24.856251978105117, 39.32987636135471, 33.75016358590896, 35.451636775847405, 32.179020950871134, 22.929179745335734, 18.008970368293024, 12.264624930197193, 11.893267669985372, 7.176224810461845, 7.18363416771735, 4.035059622218532, 2.4488636659037684, 2.442381213749609, 2.0542290999043376, 1.1742056377472416, 1.6457759012137692, 0.9789120526083055, 1.3908811658620837, 0.855689138895081, 1.1160307593884007, 1.0601699568571583, 0.8422571661010866, 0.7192121073603631, 1.0677558207704176, 0.7198672044661738, 0.7179552941553055, 1.2024023311753427, 1.4126172253201086, 1.7256750719201182, 2.2634323902668494, 3.5071488013190613, 5.393952756158767, 8.487794303124952, 12.9512946644137, 14.848924606077134, 16.904134788820823, 20.1707709604694, 19.153974940699918, 25.450847994896677, 22.416180795238866, 17.49276880295046, 26.406719799964662, 23.666432365294426, 35.50550268542382, 43.70737483424526, 37.88279633368216, 41.90102531063942, 32.590206938405196, 17.77722889377225, 11.764438402268196, 5.479755093974452, 1.045735144326764, 0.14091099522286846, 0.050165555514996095, 0.0761620176114863, 0.051984933895930174, 0.056203619216478644, 0.04792136605829001, 0.05035440384921047, 0.03518576718746655, 0.04364681377586338, 0.010346305657989316, 0.03275971611841552, 0.007690034633983048, 0.05100425325273987, 0.03237884401554062, 0.030561658561289794, 0.04569025755289101, 0.02354003564124146, 0.06587150326419262, 0.0017706300516898235, 0.023780248255559036, 0.028163692275542888, 0.03065945734570344, 0.03791036272060968, 0.03097461059599394, 0.041465585255214286, 0.044101303097822016, 0.09601023724122394, 0.11611986905336381, 0.04818851240880547, 0.07237866941478945, 0.05725191861030556, 0.09868438971499283, 0.012207053744444444, 0.0614956358537799, 0.015345957287917695, 0.1421001475424536, 0.04544307545368229, 0.04030039616590066, 0.015257565105604309, 0.048965049772373134, 0.01911070678503283, 0.02423003762810221, 0.0187965513642637, 0.01630602633550523, 0.038519548177118265, 0.023263288293814948, 0.03036387189621887, 0.03982678528935198, 0.06497095158744244, 0.03311631855584922, 0.04255670896400848, 0.2643371060971291, 0.08326305512098536, 0.11032393127078972, 0.13503819583885132, 0.20432016932435576, 0.1730678422797111, 0.14799588359892368, 0.17956229137076488, 0.3168630972504616, 0.18821680197311988, 0.21851594710061628, 0.20977044057461525, 0.17368072794089395, 0.10847409706442587, 0.13460535616163286, 0.10958631117377551, 0.20015084304876868, 0.2177124894073894, 0.1670687149969801, 0.16324316301653463, 0.17619892023503783, 0.19463301816534614, 0.10861447501567104, 0.12544332763120053, 0.18493535628001537, 0.10482355020940305, 0.24736280402829572, 0.11395858180138374, 0.17263106491056182, 0.27388320514752024, 0.12696792687019035, 0.14125928943676336, 0.10958166868095437, 0.10506531989742672, 0.16602991509341425, 0.08382776917348947, 0.15830876005272712, 0.15160170624092703, 0.19691542391815495, 0.2487467418635084, 0.07241904990927828, 0.2599309054353545, 0.2599140821445373, 0.14229409036136445, 0.14341810988562723, 0.14800337593882315, 0.2788542577576253, 0.11457745827013448, 0.1159892357405155, 0.09867561800825982, 0.23685992244751225, 0.15513203857887178, 0.13052855798554036, 0.15066160910552548, 0.19799712474548048, 0.19612118992353642, 0.11125305036623633, 0.11032845885042222, 0.5319819347031656, 2.422958372100707, 8.993973232084706, 26.01877973925683, 40.70565946640507, 48.44352699095204, 58.18947153706705, 53.57808605317147, 56.44762146857477, 62.364454115590746, 43.277953747780096, 38.407766357544936, 38.59556159665508, 38.57135665032172, 30.08108635102549, 44.93830873120216, 41.549855509111964, 42.67030408305507, 30.17189314288478, 28.5300301736401, 20.01877127155181, 16.24050407640396, 15.368973035966198, 8.988457399029887, 8.347841193599086, 5.085828025494853, 3.9804460108280186, 3.0867761325451637, 2.996200760526042, 2.123204469680786, 2.074926711859242, 1.5929413298445365, 2.3131680440518165, 1.8776547812646436, 1.5300982181103, 1.4850181725717362, 1.6743665476960523, 1.7581632060389367, 1.466603012334916, 1.5122475114560898, 1.5265087591063593, 1.6874699607010812, 2.3686396739175244, 2.5373739100271657, 3.347063881735648, 5.201038333677477, 7.923207850225511, 10.542314148718312, 14.176129275752654, 17.471387963141165, 21.17292085001546, 30.8727716630505, 31.72765616447695, 32.27829221756228, 28.336847559098278, 21.87181857324416, 35.89869676097747, 31.347664786923318, 42.08565911939068, 52.99306454197053, 45.81488393968152, 48.98942678205429, 38.94322872161865, 22.144937130712695, 12.9439058996016, 5.972437147171267, 1.040708626950941, 0.24975028640079885, 0.11174366839470402, 0.16428369427880934, 0.1867275576918356, 0.13312585651874542, 0.18003443135849892, 0.11458190924097454, 0.07542981375609675, 0.23901192471385005, 0.11901279325566946, 0.11439229481883588, 0.10776389525422167, 0.1530424265130874, 0.1640582192809351, 0.16846149348683898, 0.20008871331810954, 0.19177511184205934, 0.2067574627336956, 0.08710739157733419, 0.16433178927869568, 0.13230217410431755, 0.22872616777256613, 0.18069528944550023, 0.09372987694317296, 0.06419229216032452, 0.12488581480518465, 0.2386624200810348, 0.19158599537707147, 0.22399316932405197, 0.16447520093812099, 0.15973555284642404, 0.1218840754741142, 0.10467922690534785, 0.14405362578409334, 0.20804700321487843, 0.3430366137575719, 0.12977848129887737, 0.20520536859910335, 0.09524430253452833, 0.11220067814593354, 0.17907060081920317, 0.08367830541946235, 0.19719414202676666, 0.1277308431904643, 0.19710228808464544, 0.1128481220333807, 0.21511963418414518, 0.19555837576908452, 0.22323789856126233, 0.17051899114683752, 0.25078919355667406], [0.028167557189120885, 0.07321321495598362, 0.04681343054999748, 0.04547059333192245, 0.03309119087193282, 0.07234704530527515, 0.03540437037665998, 0.04534885429987504, 0.041722737988757516, 0.05044540360329613, 0.06736230270396318, 0.05881564962046762, 0.02731496836209009, 0.06149484678321789, 0.04297002489047666, 0.014097556685878625, 0.018127063296795375, 0.004626776048568108, 0.07121492057077347, 0.022007698914216414, 0.1161086458652731, 0.03148697594541215, 0.038587304823581255, 0.0294892197369688, 0.04379390265732523, 0.03174541187622855, 0.05230903888361589, 0.04280539259554879, 0.07707609074010004, 0.06738557645510282, 0.03638368355290544, 0.019926986874892347, 0.018336582598426653, 0.08191042729923803, 0.003884104798705648, 0.01639706630920691, 0.03985891118645668, 0.04703394129812237, 0.0856517938776843, 0.023844406203997713, 0.01017572756315912, 0.07582097825023436, 0.03269746764412811, 0.04588819552032698, 0.06429441934151035, 0.016421412583440542, 0.018993338284593438, 0.02971206896848256, 0.024243271796994155, 0.020298261811295827, 0.016850331805706505, 0.05003403354015562, 0.03224269103919787, 0.030495552834303632, 0.02643606249964045, 0.00969634900215052, 0.031683944811623906, 0.05012684126174258, 0.02847453245081969, 0.02886189906407268, 0.7271067353506243, 3.839539275054009, 8.920962233697216, 20.51200539835038, 33.89677393820978, 46.57088941143405, 48.039495406612275, 47.48134997583205, 37.00832351561516, 26.032290343315374, 23.753932599098455, 31.170987506066602, 28.709072643710723, 23.44318086101163, 39.67797886940741, 29.96923015963647, 32.082377672195435, 28.302924940663, 26.348554972679388, 23.32293668100911, 13.445875144773915, 18.396728038787842, 12.66351919020376, 13.358104267427999, 9.655089705221116, 8.695686786405503, 7.40485143276953, 6.871630703249286, 6.4428038558652325, 5.960194449270926, 5.878338506144862, 5.029731758179204, 3.5239811626172837, 4.465268859940191, 5.202570019229766, 4.602863154103679, 3.2551718190793073, 3.3041413849399937, 4.277881547327965, 5.299040223321607, 5.713583759723171, 6.821807776727985, 9.626944738049662, 12.562752519884418, 15.533249743523138, 18.601997437015658, 16.002896697290485, 17.94023867576353, 20.242550334622784, 18.170428852881155, 20.83583627977679, 21.889773222707934, 17.217045791687504, 18.17773230614201, 31.169387179036296, 35.93989733726748, 38.079538499155355, 38.19125544640326, 34.49059332570722, 23.701453247377952, 9.347166976621075, 6.435866163622949, 3.0872728026682332, 0.6823673844337464, 0.0719969814282752, 0.04170530565804051, 0.039721582265150164, 0.051365103647713704, 0.021156573315120993, 0.036279476443005186, 0.10148261778897817, 0.019884453673336296, 0.03071876021192199, 0.02167301616751619, 0.09626753553147278, 0.037832179617497234, 0.020475201308727264, 0.09409566094437916, 0.09382912363376349, 0.049382602165062586, 0.010394683152797722, 0.046231276505897125, 0.03935968616015969, 0.08945122225991181, 0.009324039847049262, 0.04652830028545953, 0.043169847434206356, 0.04953962720690235, 0.03726218721919483, 0.04209978348245064, 0.05583249558244021, 0.05511423452727257, 0.07342353673471559, 0.05640661336421486, 0.06849423591648379, 0.057109058534185735, 0.044950143839683265, 0.012783676633731493, 0.060487521602021116, 0.007446574764476428, 0.039655028376728296, 0.05098151959358685, 0.02379367203121224, 0.13907501954705487, 0.033813780323872646, 0.057429723787091436, 0.05250452536969416, 0.011299689630827597, 0.03661237995050127, 0.02840045366376158, 0.013828693340802866, 0.026219008723273877, 0.07577200224923511, 0.0757007330896393, 0.0825123962074999, 0.056139018852263696, 0.029241813557042234, 0.020777327233865377, 0.12893034535790646, 0.003470360820609776, 0.00756213769143928, 0.07034046950960351, 0.03666287280559059, 0.04157694762632732, 0.04332485766480527, 0.06652367391413258, 0.08499213854872412, 0.04516498553716848, 0.08927413337533513, 0.04424962155040234, 0.02266316757267041, 0.014189854001386032, 0.037814019503252166, 0.06835357451270666, 0.025301704618839488, 0.01536575970315044, 0.06497136527492155, 0.09673733895103778, 0.0855412244075729, 0.013414168910634135, 0.030133214313536886, 0.05653211388797049, 0.006761648588918991, 0.02022657704900109, 0.06707876590230773, 0.082163596375575, 0.06710626079791016, 0.02487427352236644, 0.04899804517927189, 0.026157532082570177, 0.016853020774320732, 0.05214656312619487, 0.04851526039982996, 0.028132489514386946, 0.047920071369697975, 0.027106456466079242, 0.05251214028366151, 0.031039410143069206, 0.017462487768141494, 0.04391816594908315, 0.02535841044699473, 0.022382972829584635, 0.08892273650534692, 0.06613767285260462, 0.04972428887061054, 0.13490803750051608, 0.0781865045428276, 0.08042056248673508, 0.029977326912264672, 0.067149291956617, 0.020879766595880353, 0.009483054802272349, 0.03928849360935631, 0.042670829251648924, 0.029068706414452004, 0.009445734829041026, 1.2442532854695476, 5.5152196941837195, 12.636083191440953, 25.28359813074912, 42.90025303440709, 52.246755169283965, 52.328673870332786, 53.672956420529275, 42.955177983930035, 30.302333524150235, 27.162842942822365, 31.00295512906967, 27.182133159329815, 25.862041827171083, 38.319767982729026, 37.09110121573172, 31.822095071115804, 34.252407396993334, 29.092764777521936, 25.906701933953073, 19.81961488723755, 20.180716130041308, 16.670618441797075, 15.613230793706833, 13.013263210173577, 12.46112390871971, 8.256238160594817, 7.2502781787226285, 6.349078820597741, 5.776779517050713, 5.243552413678938, 6.0312908407180545, 4.151984741610866, 4.286601956813566, 4.392405440730434, 3.88696710428884, 3.687510903804533, 4.518623390505391, 4.1986869323638185, 4.934388745215632, 5.444553782863002, 8.035854399204254, 9.26865779584454, 11.87882452241836, 17.196294492290868, 19.16252766886065, 21.037573583664436, 20.905507379962554, 26.659722482004476, 23.860464172978556, 26.31662884066182, 25.9834195721534, 19.5132875827051, 19.074435157160607, 35.067530831983014, 37.82372936125725, 40.39587067019555, 44.48622811225153, 37.37247636241298, 29.58392789286952, 11.625253096703561, 8.802502732123099, 4.2403130858175215, 1.1733658828081623, 0.05271980373729622, 0.07916450770872255, 0.0801742269146827, 0.02713179482417482, 0.03515531902291602, 0.010007393148337162, 0.04242750823557858, 0.06256890588349874, 0.07361120529352658, 0.05067939366844874, 0.04886042897499377, 0.05113331991578302, 0.06113512253749275, 0.0947867718435103, 0.05103730611623295, 0.024156357206764723, 0.029382813954725865, 0.026724822105719682, 0.02939924271026206, 0.03875637659803033, 0.027126152586612492, 0.10994931427581657, 0.08596407429825875, 0.03778008946908578, 0.06473209303353103, 0.01599889498339185, 0.05978052586978001, 0.038020947512479565, 0.10173095285051292, 0.026314993794526786, 0.05526038112058755, 0.046831621307759516, 0.03856780022502907, 0.018819150958029975, 0.027954979281451915, 0.042625361933342876, 0.07272487986953029, 0.0030113793505851423, 0.035672623724226034, 0.0779773012524651, 0.04179756945720123, 0.0653650961636055, 0.0545074699086047, 0.057706216410283125, 0.06750602845943744, 0.03392322364473536, 0.08864310675210531, 0.07724336603836668, 0.025334027783584692, 0.039404345255705624, 0.015555735144223419, 0.0480870938589496, 0.13915432496897637, 0.16471074233132024, 0.19179374310037783, 0.15869814722288042, 0.13028008502817925, 0.20152304441698138, 0.1431364193558693, 0.12057405746271535, 0.11693924605365723, 0.24452633284513028, 0.1345238597282479, 0.17751486010609135, 0.2143148894632055, 0.11853361291991127, 0.14698689983737084, 0.25055169097838864, 0.16101783081408472, 0.17232495149777782, 0.18321885967687254, 0.1810924600689642, 0.18159757248095929, 0.14409694039533216, 0.17847666817326702, 0.128672081796873, 0.09129066831402241, 0.11904420286056497, 0.08846780285239221, 0.1894813373444542, 0.21417218260467055, 0.1444209802655443, 0.14603192527447978, 0.10476407880384116, 0.1261919793943244, 0.16155401575228862, 0.10923011093250207, 0.1232996067753242, 0.14146533644487783, 0.23514013166629502, 0.2155383778435569, 0.10985922999680044, 0.09491125347032663, 0.13526135725119423, 0.1340220721378442, 0.15399603743947324, 0.20536466892207825, 0.16480071169714774, 0.16986128934208425, 0.1752578425070932, 0.12702117764180706, 0.1900313578305706, 0.16440951655949318, 0.26266599254262063, 0.17904372645481942, 0.1488580849141844, 0.13450201090064742, 0.09345953983645286, 0.14389228766723988, 0.08582400278218331, 0.18008891553167375, 0.1602458133692703, 1.1831182433712868, 5.5458176136016855, 14.772562922969943, 30.407988448296827, 47.82178425019788, 60.34446877817954, 61.17424226576283, 60.53198160663728, 52.64226736560945, 39.20175606204618, 37.75148714742353, 45.35315821247716, 42.30435479071833, 37.02442092280234, 51.9663292361844, 42.43280849149151, 44.977885446240826, 40.53786831517374, 37.54204826970255, 34.25363902122744, 23.534146508862896, 27.900034766043387, 19.610128941074496, 17.758050464814712, 13.456654798599983, 12.332923200822647, 10.126137925732522, 9.354785200088255, 8.641312929891772, 8.295318695806689, 7.398272637398013, 7.6213476350230565, 5.846138788807777, 5.986689569488649, 6.570711856888187, 5.5076436361958905, 4.548629522323608, 5.256657542720919, 5.708599407826701, 7.253879404837086, 7.506511913191888, 10.052535630041554, 13.46537030512287, 17.423650756958995, 20.699737879537768, 25.923368084815245, 22.503106401812648, 27.89104861597861, 30.702472156093968, 29.028794842381632, 31.643370313029138, 31.552055574232536, 27.729921571670044, 27.801904909072388, 44.547017005182084, 46.46979032024261, 48.083547546017556, 51.175924578020656, 44.2700231459833, 34.613869497852946, 15.875285325511811, 9.707308219325158, 4.432561685962062, 1.069026668706248, 0.2203645019401466, 0.1538377483525584, 0.09723023226064059, 0.1305122096692362, 0.1243764659269683, 0.08059276373035486, 0.19635262508546153, 0.19540436145278717, 0.22961050902883853, 0.2432687995174239, 0.16046266221711714, 0.10403988822813957, 0.12683741613140992, 0.16621892430609272, 0.10948237602508838, 0.1442583244774611, 0.23847062230831195, 0.09975292149089998, 0.1043922197253954, 0.2054178354240233, 0.11413263697778026, 0.17398751551105132, 0.12678956627965937, 0.1652846954041912, 0.15367212014332896, 0.0841781318247799, 0.14812443315261795, 0.18135815468286315, 0.19581055659199917, 0.17376403234178023, 0.20436310089163243, 0.19215437132985363, 0.1415808931473763, 0.0703066237451088, 0.14152712909685028, 0.13115668879641643, 0.17815817477962664, 0.16942892463937884, 0.13759328292742853, 0.18409575455852095, 0.1801299625226567, 0.20645844329509044, 0.15662563423956596, 0.13205940084111306, 0.16073466939551218, 0.12091388640504692, 0.1641769629091986, 0.14960995424659024, 0.17171773488723463, 0.16101980732092935, 0.2040119874741762, 0.1189224714893968], [0.03149873347983005, 0.049394694862947355, 0.0887312145242768, 0.0700987611086138, 0.06504368397497362, 0.04462681260080107, 0.054729938011376135, 0.060269883683612274, 0.02951060316615528, 0.039121605185491425, 0.04355181504281298, 0.005351560342411001, 0.027056453907261455, 0.10675737829578501, 0.015784950566387946, 0.07222751260644968, 0.00897102653154082, 0.06716037724888133, 0.03368952469299397, 0.06395819867330213, 0.009253170010783981, 0.09266894475947465, 0.06171893133150955, 0.0688314218554766, 0.058225126065794504, 0.010011711969010292, 0.030015330618968415, 0.06565113807277334, 0.00917768640999472, 0.02280031646331472, 0.05784722638406581, 0.05990596127606208, 0.10653212546340882, 0.09080123772183735, 0.04736232105642558, 0.025139774699064515, 0.024296405740202438, 0.048153804795395945, 0.026980331580665325, 0.11751298462190937, 0.031991103934424545, 0.06476062214783122, 0.039117594715207815, 0.041941256908279274, 0.014046227837341928, 0.075185738143421, 0.036457419515617435, 0.09534235412795698, 0.055833081639702284, 0.0149338019846548, 0.012744357171017798, 0.03364831682354693, 0.026277656584317167, 0.052057290900378465, 0.04220732307482151, 0.025759786893162998, 0.06850074000296093, 0.013867697749857702, 0.03462539685349311, 0.018263287136271115, 0.013125955142200956, 0.22427824596243523, 1.8675965984021465, 8.62602549214517, 16.18680290637478, 31.58535061344024, 41.62631819325109, 45.593972129206506, 44.91930877008746, 43.332792405159246, 40.111996973714525, 41.01179653598417, 36.72867421180972, 20.652630213768255, 25.222985744476322, 19.102285946569136, 31.70115859277787, 20.992948778213997, 31.299802064895633, 29.825357621715916, 14.528970006973514, 20.215425183696134, 15.937156792609924, 17.10543082606408, 13.36540085654105, 13.742605390087252, 17.967057881816743, 14.632789261879461, 18.127535773861794, 13.349615277782565, 15.16105603787207, 11.182041937305081, 10.68449712568714, 8.978474966941342, 11.481028526060044, 17.872411089558756, 14.584703945344495, 10.846798919862318, 11.430348561656091, 14.751108538719917, 15.788187134650448, 13.152126881384081, 10.60381102946497, 18.328800432143673, 29.74691414063977, 25.65940630051398, 22.260337183552405, 26.54251421651533, 18.88717139920881, 20.420741650366015, 16.663091413436398, 20.23963209121458, 26.111102527187718, 37.50098497636857, 41.967121170413115, 39.35692110369283, 37.21172194327078, 26.552873196140414, 17.535146090292162, 10.649052627625005, 4.771958983713581, 1.2709016232721269, 0.23817220041828774, 0.03416619226036053, 0.07698936958707149, 0.044463969121176394, 0.03940586594023532, 0.06468079578612121, 0.014340334737132636, 0.06478736627726786, 0.045905524429174206, 0.03587929892443842, 0.021935598549222755, 0.0572390215201003, 0.058222996341365005, 0.05471802534415357, 0.020158956383144664, 0.0314626794668936, 0.09404762723152676, 0.055426595387079065, 0.025952503971394994, 0.07401445865510933, 0.09656015047503096, 0.09771315876634852, 0.0635646861196766, 0.07823735745924135, 0.059159423915609244, 0.029963834188698284, 0.08377132381522849, 0.04145074230168135, 0.005904052898498072, 0.05538006320655827, 0.028130348298638582, 0.034383753569976944, 0.04308238700633088, 0.05321317585185171, 0.08409539432895762, 0.024207487830051014, 0.03339849555143907, 0.06235317552402135, 0.020423928959174983, 0.03748241834522736, 0.02784390419331049, 0.021824910335483092, 0.02970960982624562, 0.05593648052684242, 0.04126007833908643, 0.03085926648289446, 0.01765512249192163, 0.049572002082582445, 0.08428908433885345, 0.1209244967227982, 0.014539717737915776, 0.047356077439842686, 0.032646645371231346, 0.07444529118196619, 0.05571811482490552, 0.08873319869200069, 0.13222136715006444, 0.041124534402643485, 0.020176721962108728, 0.026139023398319562, 0.03729641219721206, 0.022017669548550924, 0.0551861510311644, 0.017144122694228447, 0.05483435196501594, 0.05524336630778928, 0.038541320395926316, 0.034916981408793124, 0.048561026492426475, 0.015174336355900573, 0.0598798529996026, 0.09442943013122967, 0.08247512602998365, 0.06374452909034106, 0.02863295560312127, 0.05553890004633896, 0.0690002446513503, 0.06741193754057731, 0.04285539515436657, 0.019725840914273457, 0.07538986227084553, 0.04869357119464586, 0.08285035589529623, 0.06956370231965858, 0.10392473755224098, 0.022919425898562037, 0.010782397378446355, 0.04771558718094903, 0.0663966412145284, 0.010387975095410742, 0.04291250317868206, 0.03885812073525402, 0.031503184450670116, 0.08481926314773099, 0.04379668355649037, 0.015902842879445565, 0.05758469188285451, 0.011229844437161041, 0.052574787123669545, 0.02954127732664347, 0.027023236334864652, 0.026084612003497543, 0.04334238192607318, 0.018034720973622416, 0.05532705758307731, 0.021595212277926264, 0.04415909294039012, 0.04998225748779313, 0.012399929785920728, 0.03713867086316309, 0.05259256036351285, 0.03483795943940359, 0.06976902154424498, 0.014301564942504612, 0.05004581980287068, 0.29149044905939414, 3.1988760011811412, 11.900391674810841, 21.127750835111065, 37.09637288124331, 48.955914051302024, 53.716259387231645, 48.128690104330744, 47.309659988649436, 44.050994073191, 45.1886579298204, 40.17409201591246, 24.044954815218528, 32.31188927927325, 23.660201680275705, 34.211312724697976, 26.44755167345847, 33.43922161286877, 31.633356501979215, 21.082194466744703, 32.291041881807395, 25.995894670486454, 23.796168681113954, 19.36139968133742, 21.368407857033517, 22.308990263169814, 16.94303293381968, 20.61814473521325, 17.379173040390015, 18.238101505464126, 14.008656817097819, 12.08298388988741, 13.268102542046579, 14.343278138868271, 18.149055857812208, 14.292436376694711, 13.763788150202844, 15.574936693714513, 16.85659173996218, 17.55738789035428, 17.921909439948298, 14.601104355627491, 23.068765132657944, 31.893140962046964, 31.79422074748624, 24.355781078338627, 31.08190263471296, 23.27991024140389, 22.663509768824426, 18.506370052214592, 22.80102610588074, 26.61610180331815, 37.6450026419855, 44.377488243964414, 44.28093517980268, 43.30112711075814, 32.25319100964454, 21.923995902461392, 13.264092899137928, 7.150960824181957, 2.193286192993964, 0.5388140293859667, 0.08880685804592026, 0.050986368930147546, 0.05594445550213418, 0.02620572475866685, 0.0650630276950617, 0.009455187396416742, 0.0825712624036016, 0.02854890235128903, 0.044044149108231075, 0.05682769742223525, 0.013911136850384215, 0.05882680769108477, 0.04170131817039463, 0.011173565703023587, 0.051805588882416494, 0.10119536546088996, 0.013347199419513346, 0.031401754409495386, 0.03482006745593202, 0.056966355506090395, 0.05729218419160574, 0.054990499836182406, 0.023087928852727337, 0.0573052957864298, 0.025192161706546624, 0.09554270910279405, 0.03652781533497957, 0.035586672489561384, 0.08144217903815931, 0.04480434198593421, 0.023910485117906527, 0.014309432665486971, 0.07470438211795784, 0.06077562045726565, 0.02465093016414152, 0.02416841926113252, 0.013402882520289672, 0.04889456585289971, 0.07931632335267721, 0.037685385679886226, 0.02495272092581276, 0.04675891573330568, 0.029109464207243536, 0.07938126462601847, 0.009400746315687655, 0.04409965217834519, 0.036903577631399516, 0.10339495710908406, 0.06936880955172163, 0.07251409077716452, 0.005750051509934448, 0.05950008023289904, 0.04240418085828424, 0.22158062055466637, 0.12917615232929108, 0.21305931732058528, 0.1687227447907771, 0.1474391368608321, 0.12231710667331373, 0.14452964217672426, 0.11784886055055166, 0.1944769507334117, 0.11955656246432375, 0.24391501000331295, 0.14943850376913625, 0.09399353376319332, 0.2637657883667177, 0.20675841268272172, 0.11489197566744783, 0.21084290238157397, 0.15053662952155838, 0.14039434552673372, 0.17649435438215735, 0.0881840745287557, 0.27915419650173956, 0.12422241330627473, 0.21776277541873917, 0.12376761754914639, 0.12041261209355247, 0.1041918953940753, 0.20741507260789796, 0.16260963894667166, 0.23718370184783014, 0.18862299711233188, 0.09533164421877555, 0.20395286080818023, 0.1677593892259944, 0.21659216242692164, 0.12212184618317312, 0.2263769131874846, 0.15254555720715754, 0.08456017987261857, 0.2079037294512795, 0.13077963564184406, 0.1363539978140785, 0.1796550033313613, 0.08950784381839538, 0.1740768720065394, 0.1749880263401616, 0.14546086801396263, 0.20361778927185845, 0.11648323221672928, 0.07539442815487424, 0.13671464136531278, 0.08768442432366072, 0.08416792753362849, 0.1944414042537251, 0.21181641627223263, 0.12736641516488406, 0.11249071903406613, 0.1154421340493906, 0.14766007661819458, 0.11622042575430487, 0.16985820966862863, 0.3614641539752484, 3.213725849505394, 12.795734443972188, 23.930815804389216, 41.419032696754705, 55.43754839128064, 59.15666134126725, 59.20123123353528, 58.12603112190001, 55.544032896718676, 55.8235998307505, 50.86105239006781, 33.63891732308173, 38.726537381449056, 31.138596573183616, 44.98331400655931, 33.295784458037346, 44.40076751093711, 39.88987315085627, 25.656084052978027, 33.68445996315249, 27.517701733496885, 28.13964059275966, 22.422327149298884, 22.683000026210664, 25.56369458475421, 21.826876055809763, 25.469277251151304, 19.542697514257124, 21.970124936872914, 17.91630437297206, 16.366170933169705, 14.678835926517365, 16.585728545342725, 22.952033435144735, 18.867894910996963, 15.607359986151419, 16.835542340432447, 19.9540796202998, 21.321215860305294, 19.08037558678658, 16.741432912888065, 27.308188330742624, 39.488532312454716, 36.99630145103701, 32.111022741563865, 37.367875422200854, 28.641707897186283, 31.666563287858043, 26.159086842690748, 31.430118891500662, 35.69338813904793, 48.85194770751461, 52.14184353428503, 52.359393873522365, 50.07784135880009, 37.81139742943549, 23.845747440092026, 14.427966033258746, 7.005698786627862, 2.1901120149320175, 0.682850142400111, 0.132977266104952, 0.19052916176376805, 0.26179945516970854, 0.1432139474538065, 0.11335606130981639, 0.10301964297409981, 0.2083003331696795, 0.12823796275282098, 0.12689837374754492, 0.11852145510455293, 0.20518856063004465, 0.154947058988675, 0.1694768664216803, 0.10780928596373528, 0.10075657328049983, 0.18001287364430968, 0.10495335614729313, 0.18688157200813296, 0.10383813897328031, 0.1799107541240031, 0.20767764158306584, 0.20556291715512354, 0.14889029125052114, 0.2191367694326947, 0.11128068315766512, 0.2048514053345688, 0.2959853627028004, 0.1884824199782264, 0.12025119736790658, 0.14499888635210453, 0.21410784654078946, 0.1095391661229153, 0.15473319788373288, 0.1884456017925855, 0.10665130576178913, 0.11671400854303954, 0.25387266680838605, 0.1924315419408583, 0.1681205383952587, 0.13136797584593296, 0.19270575545247526, 0.1357304022437142, 0.12648218882180032, 0.15552209990639843, 0.122128909513835, 0.19044313008987135, 0.13576214892729638, 0.22734226058087043, 0.21174083403762312, 0.1618481015846614, 0.17342269420623782, 0.15959295324019848, 0.16543645742199115], [0.07390306947091896, 0.027077484936002764, 0.03127943698106514, 0.04162237280979753, 0.03928700356834358, 0.06641633733506165, 0.020978494261902188, 0.041963140209836346, 0.08436298884090879, 0.08368686262157657, 0.08589825202380458, 0.009657206697269313, 0.024096495096361446, 0.008878582701717895, 0.06260640588739226, 0.02714192633697343, 0.019109659159796375, 0.01253666881952555, 0.0673390212919443, 0.04969677099237039, 0.012940372257763821, 0.06875162613728354, 0.017301712725912372, 0.09062895986942515, 0.05314143171774284, 0.02555190318925006, 0.021517345186082587, 0.05935677582578314, 0.054254726011065714, 0.10059002576576126, 0.0621961543126212, 0.007237495005791707, 0.06297857140100772, 0.006595027817022657, 0.015385461569343124, 0.0476401083682093, 0.021016243244371107, 0.03823894166177319, 0.015830588339257146, 0.04479236037079846, 0.03965722704907099, 0.029270448008432027, 0.03589293145905099, 0.035177298085463625, 0.03240979013724193, 0.040958155427248254, 0.048174041007915815, 0.026163174320132505, 0.07064128925483074, 0.05091232270182622, 0.015863626838601645, 0.012731454335153105, 0.022953375084926526, 0.024393086036246632, 0.0341566123308674, 0.03789795209623633, 0.05372347084865455, 0.01306303442575999, 0.012055929494841446, 0.04525435352397542, 0.018001068646328586, 0.02177573898206315, 0.08470194444300667, 0.6074771417244789, 4.70104988544218, 14.973382392237264, 25.242360291942475, 29.66443257947122, 37.49724303522418, 43.68665295262491, 41.216348140470444, 44.51297475445656, 43.13910576605028, 32.06458187872364, 28.44343600734588, 19.541540415056293, 23.65270014732115, 22.896322050402244, 32.85735957084164, 21.67561181129948, 24.775517832848337, 25.662432409101918, 21.027375421216412, 25.592365149528753, 19.89938412943194, 22.63545697735202, 18.302834341602942, 26.573253831555768, 23.304419171425607, 17.935394548600723, 18.69358870290941, 18.820740176785378, 21.01047000577373, 17.85685104708518, 12.181286331145996, 23.86865996545361, 44.322233815347, 22.726275536321825, 18.500810092495335, 20.436317382320283, 20.0929158349191, 17.881881652339814, 16.70367225523918, 20.927394205524077, 37.153164878968276, 24.565155236951767, 28.592136982948553, 16.73019139997421, 17.562449709061656, 26.2862402777518, 28.153129623782252, 27.64560434126085, 36.06615843311433, 39.45787114481772, 39.236421969629106, 29.838044528038274, 19.24675076238571, 11.545828042491792, 6.510959450275668, 1.8375288118277828, 0.8009598788715179, 0.15594902538484143, 0.11140987622521578, 0.05995948017845231, 0.1104791330233697, 0.0336603214213204, 0.04075720673426986, 0.04034677129839698, 0.08601584652018163, 0.024814239042180202, 0.011282193140246937, 0.029670098841550852, 0.004684360962616461, 0.0671639165750915, 0.01590783011183263, 0.04584814827408522, 0.04495459864096296, 0.07507959666151194, 0.016963515550859513, 0.006629346162005658, 0.031268690682707295, 0.013413767672083793, 0.06191580060629114, 0.02384510525922862, 0.061468765319835764, 0.03562126135934265, 0.0459027856648449, 0.04860923257506183, 0.10394433408134407, 0.01943679211000281, 0.03438047854410064, 0.013677683046778605, 0.03946377069599206, 0.0334632184897219, 0.08351935749693264, 0.028264455820223498, 0.08770788193590219, 0.06350707630777071, 0.036302248406554424, 0.03651104950075669, 0.029324060756592985, 0.047679289935096625, 0.026834280748340874, 0.049823926266042456, 0.05182318209159759, 0.04183096322982062, 0.05062379100690446, 0.0030836039654640185, 0.06598417181521654, 0.04686211160714588, 0.023351713992475022, 0.138819866302994, 0.05485558409183737, 0.04492955905715785, 0.0869338803233639, 0.11076401813977188, 0.04189955874256069, 0.02789336666014166, 0.05778135048345693, 0.022070382143400853, 0.051594355459054636, 0.07432673141480454, 0.04355849915995233, 0.01809684495862213, 0.020262158002644297, 0.04587593428309887, 0.09590851608663799, 0.04911292006351775, 0.025717251776387135, 0.017168407681428136, 0.03287085249359089, 0.06077148741291416, 0.02251234784301731, 0.018489039841017896, 0.05660727860466127, 0.09353511441018313, 0.04388227856027023, 0.11935622281124515, 0.03791841047425424, 0.07902258225987036, 0.03400408422514316, 0.025406909558261116, 0.016308987265332572, 0.0251890973548495, 0.034887299332166874, 0.08229332570467265, 0.04243916809378613, 0.025108391907246366, 0.043752032121823686, 0.056957737016942234, 0.11220241716552166, 0.03793449065978489, 0.02079035838945739, 0.03634939345741465, 0.03396741925708709, 0.02842995762494543, 0.054362955082568436, 0.032723778933887525, 0.07101493331814004, 0.04671609907921764, 0.043663721336352254, 0.046480209116012826, 0.08533587453946953, 0.044964768458157785, 0.014644169995951799, 0.04130780178632948, 0.0334927665009614, 0.04271425494563676, 0.0188873078854334, 0.016217432097501813, 0.039414764051475835, 0.03866256147082295, 0.024221920926544457, 0.029126337293775815, 0.005686259368479613, 0.0549786139820372, 0.04098117636937288, 0.04208842622897318, 0.11323778499518672, 1.033430178799937, 7.0064871830324975, 19.291683473894675, 30.465104041561005, 38.02450764563776, 46.066931524584376, 50.13227993442167, 47.57973870923443, 50.04197912831461, 46.42416531039823, 35.60380512668241, 32.46332218570094, 23.557596398938088, 26.155380202877907, 23.627598939403413, 33.58438068820585, 28.648230798782844, 23.269412017637684, 30.704299980594268, 29.599884094730502, 31.666790785328036, 26.367186230997888, 24.761489475927046, 26.94950326796501, 32.27873740657684, 31.34220288645837, 21.670306805641424, 25.894046406592093, 26.315187369623494, 28.226858415911277, 21.274208214975175, 19.512687460068737, 31.650055992987852, 43.70255424130348, 22.84832008423344, 24.891266976633382, 25.786916671260713, 29.080570128656205, 19.529659555804347, 19.799224445896765, 30.259813070297245, 43.31190186162149, 30.625119093925726, 28.457797765731815, 22.32537204219449, 19.429621465744514, 27.387718308356504, 28.486046675712835, 29.92824335252085, 35.5847071063134, 43.915076101979906, 44.77397318809263, 36.43739115807318, 24.54846359068348, 15.631288405387634, 9.130694308588582, 3.305880220667009, 1.2069403908906446, 0.2916462406996758, 0.18538190893107848, 0.03511961932564455, 0.01293462181028219, 0.061934393560213435, 0.048808756344501054, 0.03922244916940409, 0.060701880664114034, 0.02668316799005674, 0.03453982483235098, 0.03763051080187002, 0.02376141206872079, 0.06082286509955603, 0.06222803506159014, 0.03602048126800406, 0.028637739822208404, 0.08526176319367464, 0.019820994780128522, 0.05458761802724293, 0.026920241559104576, 0.045848692196511456, 0.042424305988055085, 0.030883744907295032, 0.03956662183026633, 0.03124971851526249, 0.046200495093099536, 0.021690427430815274, 0.10257649941429978, 0.021862331815364382, 0.09354151890523012, 0.08977055835026888, 0.02958634436400908, 0.018168684853721532, 0.04420122394578592, 0.032280168060453675, 0.036317983852519144, 0.03906833143123696, 0.0501499503039785, 0.029702805050258196, 0.021610394225365693, 0.032767193136556495, 0.01107432571570239, 0.040061993434304194, 0.06865367413528504, 0.01434112668052436, 0.013366390879626476, 0.018765373500965295, 0.05672959220265189, 0.012570411162150484, 0.02783114691415141, 0.06589512175489819, 0.05379411181615246, 0.05877487076025817, 0.0329891556212979, 0.08613940884148882, 0.18614946774417357, 0.13243931916452226, 0.1124280913462562, 0.14521242570011847, 0.10495632856843934, 0.18309346640542631, 0.1865105862699209, 0.06097734672948719, 0.12960151498836855, 0.22914823625356923, 0.23948067859295877, 0.1303483894275081, 0.12140518625176723, 0.1694182147301974, 0.10625823370872006, 0.094596506246636, 0.12754225532614416, 0.16529226435288308, 0.19856288067756162, 0.16571358206772036, 0.25152047044567527, 0.26137470538097046, 0.16253546631384283, 0.1823808820617776, 0.17672303162755507, 0.12646726542903533, 0.2221707687262566, 0.10679545286562174, 0.17410160132473515, 0.21181928144106943, 0.1760164687349912, 0.11500969273789276, 0.13476042767926572, 0.2173492105136956, 0.2898023896400006, 0.12930510024870598, 0.13382776159672968, 0.11041889552988353, 0.1235365654311834, 0.1367873277875685, 0.13637728688697662, 0.16349327540205372, 0.13044343029539432, 0.1329749065541452, 0.15386174222634685, 0.18558623990224254, 0.11707913370863085, 0.14659804892876457, 0.11735949124540053, 0.06898514505836272, 0.19811910126478444, 0.10458672178849097, 0.13544619894556462, 0.11162361475609003, 0.18075190334310456, 0.1259395074579985, 0.1221083630357058, 0.10716792481440691, 0.13914649555039021, 0.18490653605230395, 0.07037931782824379, 0.10293367258723705, 0.1713392721308816, 1.1969621263204084, 7.4660541357532635, 19.818873559274984, 33.69684288578649, 43.26655534005935, 52.4472471206419, 55.967880295168975, 57.823008414237734, 56.63963325562016, 57.29440235322522, 45.16879112489762, 43.48801235998831, 31.818976786828813, 36.43051916553129, 33.403057359880016, 45.96810740809287, 35.27667553194108, 36.832695468779534, 39.644062134527395, 33.27069305604504, 42.56596119173112, 32.310724335332075, 34.73207796773603, 30.05686571521144, 39.94497852940714, 34.281660433738466, 28.541491339283606, 28.689378423075524, 28.580905275960124, 32.36093851827806, 28.168095427174723, 20.289246151524207, 33.3848967859822, 52.28646524490849, 31.136688340094786, 27.146110111667266, 29.905556363444177, 30.915021473361602, 28.26424840957888, 25.795139920326974, 33.047278773400095, 49.99622468025454, 36.16387644121724, 40.68890310102894, 26.612501067499963, 27.604480251189205, 38.39506572292697, 39.334830314882346, 37.4897591529354, 47.16452836990357, 50.626890813150716, 51.9148559724131, 40.09608784029561, 27.227764052729455, 17.03402603826215, 9.075128051542467, 3.350176527615517, 1.1252225887390876, 0.4257986550369571, 0.4054586529251068, 0.2193336387074763, 0.1469328753169506, 0.16066359175789743, 0.19184985137995214, 0.1562199293966255, 0.21450466476380828, 0.11235686815193585, 0.19466664942522205, 0.1910198564010282, 0.10405113439886801, 0.22206892499760275, 0.15501016931187722, 0.23361425306047165, 0.10264969145458552, 0.2780992627864884, 0.046549360042498, 0.09677376643183733, 0.12131789053279547, 0.16280880648522608, 0.15705441365078573, 0.10921769264724948, 0.14769375384334596, 0.14109416684556392, 0.17110403717285202, 0.14642091407891245, 0.2028241221823039, 0.1835396053690103, 0.09305476195990078, 0.1920717870516162, 0.12783813380425976, 0.17804246485954334, 0.13509793537518672, 0.0888200577408556, 0.16672091107935677, 0.2097879533445643, 0.16629790797108607, 0.24162328862134488, 0.12087236443955092, 0.1278027022377618, 0.10739074148718389, 0.11866964715262575, 0.14517698647274127, 0.09756871288822544, 0.19660762511193755, 0.09390236930020394, 0.20290100676638467, 0.09649778325711528, 0.06781918222024556, 0.2207369432454148, 0.17567119290751798, 0.1950093205537527, 0.14641567403751035, 0.24365156768791138], [0.053781605430788575, 0.03660663429106917, 0.06984815076594392, 0.04070506679014333, 0.0844475572868701, 0.03290300903421256, 0.03398775889147674, 0.02193452219568914, 0.07859182634180592, 0.04831788167657872, 0.08392766703881564, 0.024141165683226242, 0.01677820079719588, 0.09986788830569676, 0.05723921304208137, 0.08891839278681625, 0.05890220606459245, 0.012455407000567405, 0.0373074438633217, 0.09842002809408212, 0.0378035738944046, 0.024659159863668106, 0.018125801166940122, 0.029275657406317133, 0.04183303166721617, 0.03688222676094982, 0.05511937497724449, 0.05018635097170069, 0.01771119438231953, 0.05719891298682459, 0.030556045052024628, 0.016688706405881434, 0.049582554943739414, 0.018026770896188194, 0.04333865873876118, 0.03130341936353474, 0.039059590368020924, 0.049919583834707744, 0.045319413540944944, 0.015666307487164535, 0.04069422664601476, 0.016976652043541113, 0.019225801919556914, 0.028039072752900185, 0.05985498961602008, 0.03572279865282678, 0.014249422125548366, 0.0668530917215732, 0.03202160764034958, 0.09943719367466627, 0.015756605313189568, 0.011046899768013147, 0.010765758906340888, 0.043880167988038836, 0.01609193923462543, 0.020704328630780502, 0.014356458015109022, 0.03909854593897059, 0.04468590862328007, 0.06855364603501174, 0.07333410363043509, 0.048101607394675096, 0.03710569843890206, 0.008563248463155282, 0.2552258691960766, 2.3957645796960403, 8.612802201701749, 13.7656718684781, 23.00222408386969, 31.426843712406775, 37.448119271186094, 45.46962515000374, 48.41045356565907, 51.07110315753568, 40.346150705891276, 34.620949376013975, 40.64246223818871, 33.934550285339355, 31.941225297989387, 20.378005466153546, 36.36122265169698, 27.798767012934533, 25.969251971090994, 22.96416532608771, 17.300706025092833, 32.96833715131206, 26.318754765295214, 19.79494514003877, 22.04897830563207, 32.072230500559655, 21.951340706117694, 23.561734499469882, 18.664402346457205, 25.771429192635324, 20.08075256501475, 23.05685877799988, 62.314604713070786, 41.8718546436679, 16.548313056269002, 18.721106090853294, 15.833674861538796, 37.040565398431596, 31.171813164987874, 31.708277694640625, 36.116141196220156, 38.92162038433937, 31.349831896443522, 24.719643669743693, 28.48225570494129, 29.942993425553848, 35.55569333414878, 36.019623433389974, 39.66591365875737, 33.27426241290185, 27.379416611886796, 13.75490398176255, 8.773036906796118, 3.3480984068685964, 1.1783032888366332, 0.3115769986423754, 0.09114916421352856, 0.04032131419667313, 0.08144798598462537, 0.06539406194802254, 0.06024945211867171, 0.023023433825601975, 0.021714195308666077, 0.017525923678711537, 0.06921953731967558, 0.07850904288070817, 0.04580992431710324, 0.05254133589445584, 0.08917209046382098, 0.0408536801865745, 0.021102027854912227, 0.003604957202051376, 0.04144546395588306, 0.1241061824464029, 0.02416595820367577, 0.06589174330715211, 0.04713294284057714, 0.025131861010806698, 0.028478016235655355, 0.036168715450912714, 0.017807895745781642, 0.09188689156285218, 0.04584116921309502, 0.08547636740390332, 0.062192373668714884, 0.037373549590307864, 0.05887217541796066, 0.01438713504842693, 0.040522431428994865, 0.07210086295080763, 0.013938524493677242, 0.029439326345680222, 0.03356877391436889, 0.01045954590212674, 0.03470188307185327, 0.03163040292659595, 0.003668251625757905, 0.037794882626903635, 0.05979522709704696, 0.03979265607232529, 0.03771278864493774, 0.05209047016837905, 0.06460650057922449, 0.031835588085795605, 0.03406919403782776, 0.0614916445356944, 0.052477283283106746, 0.07327841669921914, 0.04630446088530364, 0.019168213175068942, 0.09558695068042125, 0.03147997773222385, 0.021645147804050677, 0.02033872082979689, 0.03437475586730627, 0.04364285310129485, 0.06449386267171753, 0.06040342430013323, 0.02949806996771405, 0.005461761611513794, 0.08742108159968931, 0.05536381448168428, 0.05352372108327766, 0.05717514893941342, 0.0378802631260647, 0.033269900032469345, 0.03175944469178156, 0.021602237304191918, 0.0683352573504371, 0.03303666456392215, 0.022451440022597392, 0.02377832345964928, 0.08586197009971065, 0.09227808670050676, 0.033895452957480185, 0.02727872282717257, 0.020088125808885502, 0.019677516088009845, 0.012467433623368702, 0.04076951776721305, 0.024986444116239587, 0.02695344380974289, 0.02425713798842363, 0.050126680383278485, 0.03531360427939123, 0.0023338277289088097, 0.06844751987486117, 0.03391302318402356, 0.06555065031974547, 0.06595704464181777, 0.028522851531423872, 0.026877991810080507, 0.05317921134372873, 0.01383599798916088, 0.017396544834839243, 0.020966003198296796, 0.04386246369610872, 0.034149652422075315, 0.006778034252009445, 0.03509469465502808, 0.017807934050177856, 0.05876730181156628, 0.06996179224863168, 0.03566556805444341, 0.012247912086276038, 0.03375504819315768, 0.033992681006390246, 0.021090389064122594, 0.024769687198943673, 0.05821716641226123, 0.018121172080657656, 0.08082278162962006, 0.022827118049345674, 0.03289735913577099, 0.03515911498858083, 0.022888357202792843, 0.46436796445519696, 3.748322350363578, 11.231560880138028, 18.689403533935547, 27.690097747310517, 38.201606581288004, 44.132493080631384, 53.72885411785495, 55.145790730753255, 53.140427989344445, 46.391350761536636, 37.362133072268584, 43.169308016377116, 33.65293195170741, 37.88718546590498, 22.788776543832597, 36.83426049447829, 28.85667927803532, 21.821947597688247, 28.495560384565785, 22.001721589796006, 32.35669843612179, 27.596266808048373, 28.71328526927579, 26.84499171472365, 33.340515167482444, 24.77654549383348, 29.877717341146163, 25.770736894299908, 28.76817099509701, 24.20119654747748, 37.92768393793414, 72.70768934680571, 43.448121855335856, 22.47815816633163, 26.482345058072, 22.389294908892726, 31.156586523978945, 31.11964760288116, 33.26370731476815, 47.01600782332882, 40.59898668719877, 33.850489970176454, 25.802817959939283, 28.052077601032874, 33.27489783686976, 37.2359896475269, 39.329805758691606, 44.46329793622417, 38.345832132524066, 32.442345350019394, 17.942686234751058, 11.358670188534646, 4.473835806692801, 1.6703969865076005, 0.390153196790526, 0.21686580903347463, 0.03767796994877919, 0.09163481799224693, 0.13376624473640997, 0.14342148067249408, 0.06889534423187857, 0.04124338911365598, 0.03403991798780138, 0.07502816151827574, 0.01885486406184012, 0.03047446051852838, 0.018931921015703873, 0.14461953493375934, 0.01972139568909282, 0.010337214109547918, 0.049882704362032876, 0.060360079045377435, 0.06687803554438776, 0.05852184724062682, 0.021874380463193503, 0.019224304217664946, 0.06580012685228741, 0.0309298423329188, 0.05435819767655865, 0.018773015228009993, 0.044402042403817184, 0.037000947406575564, 0.09586526276243311, 0.06766127617729288, 0.015917325771654087, 0.08511696491510638, 0.041438684077753175, 0.03709003960172977, 0.017877090722322464, 0.032868113729261586, 0.009851247192390505, 0.02244051369357734, 0.03617835283700017, 0.01570723764973903, 0.09542961920341177, 0.017345592326995347, 0.02396075772271762, 0.04241983203457729, 0.02165875927124533, 0.018181963072669123, 0.01345444406803337, 0.015694600071818117, 0.034462350360568494, 0.061759748496115215, 0.07917966858874406, 0.04143781839839874, 0.12018812534910057, 0.04544299118401063, 0.021676484630593372, 0.0408584950491786, 0.040829073442446615, 0.17641929308733634, 0.12047581434730562, 0.16198432733935697, 0.09318652142199779, 0.12241734927820584, 0.12810413485332844, 0.1418164958276095, 0.11850891424523247, 0.24230112321674827, 0.17133534976070927, 0.17397371060665578, 0.14814562314460356, 0.16734913382078373, 0.19983732922663613, 0.2928857709611616, 0.21374999154959956, 0.1506665886770333, 0.1644014879580467, 0.20551318272707925, 0.18079307290815538, 0.15117848862803754, 0.17295939487314996, 0.11734352597305853, 0.13300168898797807, 0.08283645906034978, 0.1766370612406923, 0.13766491214834875, 0.08703947788284672, 0.1665523257707396, 0.10717906373282594, 0.1813292578463593, 0.12041707838615102, 0.20270021512143074, 0.2047052204368576, 0.20626309087439892, 0.20896310647649152, 0.15136834053743273, 0.15685964345691666, 0.21307088524824191, 0.21474028276579998, 0.2033807157028106, 0.23304449814942577, 0.12287517108263508, 0.10211158363569169, 0.07955446944481905, 0.15816530242802637, 0.12492330714819894, 0.10950148991879918, 0.10488188780483701, 0.2523956033250978, 0.15028645584900535, 0.12881841991216908, 0.061257520405155044, 0.114601643665904, 0.13319684222580927, 0.09726082981233636, 0.10041695884278706, 0.10028304667362284, 0.09749301574042729, 0.21443112032307735, 0.1717658145653625, 0.1504436570910677, 0.11482306605865879, 0.10806974053623215, 0.5710567702208796, 4.04142685474888, 11.558095255205709, 19.658046576284594, 31.102098918730217, 43.04674571560275, 52.65319116653935, 62.69175629461966, 63.55085342161117, 64.85550826595676, 56.71099685853528, 46.78106569474744, 57.81552453194895, 45.873429236873505, 48.4666689749687, 31.950970426682506, 52.743056589557284, 39.70911072146508, 38.359281939844934, 32.498396019781794, 29.05803611201625, 47.14050385259813, 39.05843657831992, 32.884835773898715, 33.56683984879525, 47.138421074036636, 34.646052545116795, 37.66834466688095, 30.03072507919804, 39.85648201357934, 33.03630398165795, 35.428494791830744, 75.00022057564028, 55.13913446857084, 26.282139439736646, 29.341042964689194, 28.188538820512836, 47.11327083649174, 37.99777277054326, 43.62291835969494, 51.73439164315501, 51.75231295247232, 42.65383012833134, 36.1622525799659, 39.04335114263719, 42.27924769924533, 47.102605911993216, 49.13168722583402, 51.07187194208945, 44.443180099610366, 36.65081124151907, 20.77543766267838, 12.099361746541916, 4.726548233339864, 1.7674616748286833, 0.46702573796914476, 0.24847750792339926, 0.0944314755859875, 0.3123539650151807, 0.2227534092361889, 0.24022303311334503, 0.21379001198276398, 0.19899202781098507, 0.1318415254354477, 0.12441161404093429, 0.16453176887044985, 0.09587460903510933, 0.09517401396747559, 0.18029698501190833, 0.2074434485046133, 0.10317418589106492, 0.13199710257111058, 0.12291184371157039, 0.20949323932009362, 0.18397872696720785, 0.16854806142228265, 0.15308656849928443, 0.20898379085044708, 0.2752843186739953, 0.12663300089057417, 0.11564071170024334, 0.16007335165575629, 0.1112577005199367, 0.2402607552827366, 0.12439988523481355, 0.07264343706230003, 0.19412629696871006, 0.17900735260017459, 0.14387207826779735, 0.13223705663075372, 0.13667037680504784, 0.17142939471429394, 0.13406160227473707, 0.13041186747291397, 0.1493527478868923, 0.1901784926773079, 0.120058556898467, 0.10011580967975241, 0.09413351334871785, 0.10995458496073562, 0.1306324395080728, 0.11793327577892812, 0.13640920210990215, 0.1144478515151047, 0.2422431610043972, 0.1429661639755772, 0.2087579787738862, 0.19064289517700675, 0.13369282286974693, 0.08168479908377894, 0.1557000314876918, 0.11568725154164339], [0.03335665948989411, 0.02109423291028267, 0.02356295507671612, 0.04792137754960887, 0.014081045575890572, 0.10069295733926759, 0.014347735146481185, 0.02792944940137527, 0.011666512638781101, 0.02498525284951733, 0.08870515987397203, 0.032719255184694644, 0.08913241477022249, 0.03981330980276389, 0.026368493544718912, 0.013694790747737693, 0.022040255735778523, 0.06917714967482513, 0.023462281547366612, 0.06379980616451753, 0.02954477451801781, 0.04165919482587807, 0.08690131392570273, 0.054114240807511156, 0.023262506884132183, 0.015996375511730873, 0.0715099257086554, 0.10086007941994937, 0.016678659162754496, 0.07941022274955627, 0.04389116134975226, 0.0325083818226572, 0.0449808256610507, 0.03643087839948074, 0.040004690057568015, 0.03514758153488079, 0.07021870749491839, 0.06167584654664802, 0.05381010390157181, 0.03300387600076295, 0.027968477750677737, 0.06596493534743786, 0.022370958655712106, 0.06338728313905097, 0.0392955262965012, 0.03168768906635383, 0.013996570975699974, 0.02179958538392619, 0.15882297358926267, 0.029318408942931605, 0.044912007982812585, 0.06843030587920258, 0.02817432174549228, 0.06579220550315035, 0.11768547697894036, 0.08747754994058803, 0.013321723165591399, 0.04321613063615176, 0.05507599524853211, 0.0537191309605635, 0.036186021377122214, 0.023154955800442446, 0.03614862096465884, 0.05339807883325604, 0.02086612831560835, 0.22823150479985824, 0.6996769878652789, 5.3675958994896185, 9.702712182075748, 16.79156472606044, 22.128574963538878, 31.350400640118508, 40.539625537010934, 46.6620139152773, 48.61953550769437, 43.77852662917107, 44.40336804236136, 45.78647421252343, 40.387355204551454, 40.44745768270185, 35.40481544310047, 27.01034119052272, 29.33671659038913, 23.437624823662546, 31.860748067978893, 25.467127792296875, 23.791808966667425, 19.556576821111864, 25.283447119497485, 31.77913531180351, 23.41276680269549, 28.432984852021743, 26.01845418253253, 28.46049047285511, 29.94300911503454, 17.064218482663556, 67.84986526735368, 61.165534603980284, 22.236030255594564, 26.15984189894892, 19.700480737993797, 45.56479753986482, 30.923176080949847, 17.560825847810317, 39.22802809746035, 48.14665455971995, 38.4491708970839, 38.071678069330034, 44.469283473107126, 39.01053267140543, 38.44958666832217, 35.996693257362615, 25.771493911743168, 17.665139321357973, 8.499285867137294, 3.9440241071485707, 0.9196840178581976, 0.14510213968253907, 0.04478487569177824, 0.02878147898422134, 0.07887429828124662, 0.0598663583608164, 0.07290998203379494, 0.016003635152423337, 0.0412850757880557, 0.062249121631705956, 0.026960524377383055, 0.009581133208778358, 0.03202586708920858, 0.0058985317985887735, 0.04803248711170689, 0.0751434654117592, 0.006579492511528154, 0.03855454690393902, 0.03907792668248858, 0.07758174707452137, 0.038231920465947165, 0.05541725294484247, 0.04118705483814401, 0.04945569844435781, 0.01533868998634599, 0.13770899284751187, 0.04770843575017587, 0.009531587429885423, 0.0312654348090291, 0.02896118214383962, 0.027540939401895292, 0.013996846767352715, 0.09497611047399622, 0.03441611695433817, 0.015143585586619955, 0.024114185981752894, 0.052456001360570235, 0.058965584518568176, 0.01734879457451884, 0.006958660068771532, 0.03558753816891582, 0.09570446090712663, 0.06654019076978007, 0.02041654387158492, 0.09594013253527303, 0.013999433271707067, 0.06427582638758807, 0.05656339325791886, 0.031170798052522927, 0.02906367130156967, 0.04795112857414831, 0.06187298012176349, 0.027993523080142278, 0.003988802204877439, 0.04050720926193942, 0.035955884734228734, 0.07726512293541625, 0.00747037663747887, 0.026460404943434462, 0.027370837239188053, 0.0616910380701865, 0.027374031825832305, 0.08278029715462078, 0.09422453991588085, 0.056452383287251, 0.0527828527734645, 0.08200177562332923, 0.00982750038195762, 0.011932061695974442, 0.026276005664840344, 0.024239726725124547, 0.04103036304455131, 0.08940222327627483, 0.034040733871440736, 0.07282549785750528, 0.07375863891455435, 0.037696267958850636, 0.02674552754709317, 0.0639009565835999, 0.04986145308301334, 0.09419348271143052, 0.03365321212538308, 0.0536553081755917, 0.06349611742001388, 0.04045705348553677, 0.05672301533782194, 0.03874675070326175, 0.0536097067918989, 0.07919459964238829, 0.023702515229102106, 0.053652289789170034, 0.04886170068094808, 0.024967692199073015, 0.006550833162280821, 0.03662266085044511, 0.05141189246768913, 0.0762559399910031, 0.047079151976973786, 0.037965444442365444, 0.04253194900229574, 0.04096342994260692, 0.04021840177536492, 0.04188311466526601, 0.0640034744696271, 0.014154593847061117, 0.007849575795849125, 0.047958318309317675, 0.01901885475813141, 0.01445037177613666, 0.020631081049120235, 0.07846558271276374, 0.03512189843721929, 0.037167127199110486, 0.008086076235368608, 0.029438092944122134, 0.031604721744154254, 0.038933055625567516, 0.05341954461689438, 0.055533276960974744, 0.04277508232682463, 0.021042837986662503, 0.03286990254456478, 0.051492722404579964, 0.04536698760104276, 0.024647302737820054, 0.33343606117752295, 1.283700439718462, 6.577573553208382, 13.750348148807404, 20.91546431664498, 29.66011012754133, 38.87691320911531, 46.70285755588163, 53.82452072635774, 55.15199592036586, 48.96156226435016, 50.055283807939105, 50.69858781753048, 44.07851342231997, 42.557786972292014, 41.215791163905976, 27.1081199953633, 25.76621244030614, 24.073854838648153, 26.762070848095803, 27.966211034405617, 25.35487348033536, 22.055189378799934, 23.984318894724694, 37.36843632113549, 24.30537077688402, 26.99117256749061, 26.53331429727616, 32.02435208905128, 26.328882325080137, 19.43446167053715, 72.18103270376884, 63.55497191029211, 18.97980797675348, 23.866069239954797, 19.21359496731912, 47.31101320635888, 30.446794417596635, 20.12703064949282, 44.02255296707154, 54.10661366678054, 42.28837505463631, 41.1690325890818, 47.60199815996232, 42.94671743146835, 43.708649604551255, 41.23555990957445, 31.120255570257868, 22.099490588711156, 11.768673581461753, 5.759386256817849, 1.69554612088588, 0.24432022454998187, 0.10404463797327011, 0.03831288829866437, 0.020276832416833892, 0.07270768885650943, 0.044069947119081215, 0.028687476165472504, 0.032973604036435004, 0.00793602067841998, 0.07241550292218886, 0.08305883906300991, 0.044297256897534096, 0.022191414459338112, 0.03361902545176206, 0.023134206309013312, 0.03157755435113946, 0.0902734567681628, 0.03418018102585789, 0.0822190611412929, 0.057633464870553826, 0.01580760187108911, 0.027836871506165595, 0.02987117202381694, 0.0412456299208345, 0.031879701343695485, 0.01777454219277828, 0.045663984567527814, 0.027859490252129977, 0.021007251287359866, 0.03416766697961477, 0.040934513953904954, 0.09046675607321725, 0.026472560843572985, 0.11015640316350807, 0.03687224080485683, 0.08357435494901673, 0.08171466119106739, 0.030963513812410737, 0.06222392116943675, 0.011403876630919836, 0.036987904759664694, 0.03130832232625014, 0.024975732291838335, 0.06162867851315006, 0.03499157155954069, 0.04130487916089835, 0.060017894382678696, 0.020104688629808447, 0.007819303831521181, 0.05153854978421042, 0.07190618468748947, 0.027758393459202304, 0.030245329366035523, 0.046525963717290474, 0.053775430762118874, 0.10019974227273658, 0.023262123840170044, 0.033796547176015955, 0.027041019150807012, 0.1813474600954402, 0.11369289484836402, 0.18070751620877176, 0.15557378019777038, 0.15975205438031306, 0.16583227973070838, 0.14256727731516286, 0.15380736530548142, 0.09325408271604008, 0.09464850829493615, 0.21223401079975793, 0.14124716992580122, 0.2235108250451665, 0.1369092430198385, 0.11533271371116562, 0.21856796447067492, 0.16300990456534972, 0.11432166917309647, 0.21230389334021077, 0.1236941880216041, 0.19315929482540778, 0.2829936146736145, 0.18696656180245264, 0.14031796656068296, 0.13387456956890323, 0.10971578003297891, 0.2702203855639504, 0.26126592089572265, 0.18885990214203635, 0.14274678703758026, 0.12495090163523152, 0.13752318588235687, 0.10390008484283764, 0.13370503431125996, 0.13286656639989347, 0.21666540043248286, 0.1378778079825063, 0.1844027413115386, 0.14244081152062263, 0.1581201185622523, 0.15946884699646505, 0.270369864639736, 0.09157590583086976, 0.26599397041624595, 0.17815209204150786, 0.10297812100860382, 0.15624395391393095, 0.1353071846308247, 0.3354872769165424, 0.08664401563545389, 0.2381254690549066, 0.1595005323930133, 0.07493298275456314, 0.18253702610250444, 0.2182242054972918, 0.15171957652895682, 0.061016064813180323, 0.13963597976873, 0.10898055779116769, 0.09226160814925548, 0.16586106931490285, 0.08777961074825257, 0.1574838518976204, 0.1386025578023926, 0.15786577737139118, 0.4229353860982003, 1.5393897001781773, 6.4928150561548055, 13.942814930792778, 21.996836277746386, 31.382195372735303, 41.9809083015688, 53.229085322349306, 61.55957591149115, 64.55854562021071, 57.185399686136556, 61.38905479061989, 59.64348239283408, 53.951766337117846, 52.6159639512339, 49.56165352175313, 37.74738434822329, 41.9591469918528, 34.609574502514256, 44.03085662472633, 38.91188506157168, 34.085447788238525, 30.27449450185222, 36.99017863119803, 47.782556626104544, 35.32010401448896, 40.922409642127256, 40.20375297915551, 42.00854924417312, 41.63007582387617, 25.316751964630622, 77.01342413502356, 72.25271009629773, 33.60924459272815, 37.236032793598795, 29.798738456541496, 56.85399863027758, 42.16659722789642, 27.03704664784093, 51.65922726354292, 62.37162028589557, 50.34442524756155, 49.44477081298829, 54.67108588064871, 52.566910789858916, 52.0813762757086, 46.491798739279474, 35.75458103610624, 24.313133147455034, 12.341425918763685, 6.070844021535689, 1.749254400210996, 0.26977580941973195, 0.18922137306822887, 0.10925910736043608, 0.14451896291105978, 0.23508967711560189, 0.20203911188629367, 0.07928968647554999, 0.13429193427005123, 0.13525611720979214, 0.1686526783892224, 0.2730010395809528, 0.1036363437531456, 0.10154228071652113, 0.0831088952479824, 0.22788442100488374, 0.16861000729183998, 0.21214391885986253, 0.1528870792038018, 0.21749890409410003, 0.24601804392953075, 0.14490573006051202, 0.12169674399398989, 0.06883141419459736, 0.20745913798530258, 0.2690995682872111, 0.10198408362245369, 0.12792927528461143, 0.16647092126790555, 0.18231538154425161, 0.17446696397758302, 0.10454009767741927, 0.2055129069354265, 0.117846631234692, 0.21299084438191307, 0.11078265705896963, 0.1771773064448949, 0.15873364773729157, 0.13789086212073604, 0.15636796822711346, 0.10127880775760259, 0.1835193959695678, 0.13321346633376616, 0.09854175180437104, 0.22753454864986483, 0.14095052535976135, 0.14445075044228187, 0.20327049097226513, 0.1552129068201588, 0.11071016981957421, 0.0959481611367195, 0.21185896479554717, 0.12816246478788315, 0.17819736783783283, 0.08771342075159473, 0.1860335892847469, 0.2180075405105468, 0.126162308809017, 0.10112271734303045, 0.1386581604639369], [0.036578285207431165, 0.021900142084867246, 0.03416270272986543, 0.02608234629846148, 0.049786763340835614, 0.006088518730980615, 0.10553341494092058, 0.1065637112685269, 0.044106581443620306, 0.11526595680944382, 0.035411039172040845, 0.08905129371992043, 0.06746247636094209, 0.028743117131412994, 0.08019361660004624, 0.08767007549683895, 0.07477152972452103, 0.014157833441370919, 0.01866978296499339, 0.04536749704951241, 0.026763955792111736, 0.019004774062083136, 0.05099386893092625, 0.018313456319212433, 0.02197646933998312, 0.07582661665735707, 0.04915588610475102, 0.012921677797191567, 0.054432278378836574, 0.0259914672032239, 0.03910979594013864, 0.07453650927111026, 0.005472471520695235, 0.019385291849293055, 0.034450529623896844, 0.03773902715634435, 0.09105019331459077, 0.03893641875155511, 0.052663553731455925, 0.020441196580988266, 0.026882463848338495, 0.05474345563280006, 0.009717650076885138, 0.016241006538151734, 0.03796288187825873, 0.049033423119615165, 0.05782872536069444, 0.028618918957128644, 0.06280378078020389, 0.014669024761045172, 0.005916486505509144, 0.025568385570940953, 0.034223189201927, 0.032993790453239795, 0.04818189340913969, 0.04042226160245557, 0.022074180024285472, 0.060315335680159836, 0.02397392102847657, 0.04727917370356379, 0.010910603150184597, 0.07622029391988631, 0.08333021038842779, 0.02883113488825339, 0.042753076451199676, 0.013758811757959908, 0.04671253677036974, 0.19476169029310827, 1.169029702582667, 3.952490543165515, 7.8169797697374905, 12.519269124154123, 20.800734989104733, 28.137975546621508, 34.82640704801006, 40.57743326310189, 46.20908998673963, 54.36678055794009, 54.91059364811067, 51.44641122510357, 48.587528967088275, 40.8361174983363, 45.94283557707264, 48.74661637890724, 50.67118221713651, 38.100272147886216, 30.70586696747811, 21.173238561999415, 38.01037926827708, 31.577311715772076, 28.94848039073329, 30.951293591530096, 33.999869515818936, 32.577414128088186, 30.721293649365826, 36.76158681992562, 57.21400553180326, 77.26641701113793, 37.12970518296765, 30.74848940295558, 29.134416426381758, 47.077773386432284, 38.463769958865264, 29.733156427260372, 39.445139131238385, 52.109770313386, 50.50648973834131, 44.078407518325314, 39.78346709282168, 38.32221946408672, 27.926326413308423, 18.61537075811817, 9.792949249667506, 3.897954888882176, 0.9707945236755956, 0.11802442492015901, 0.037214525058985724, 0.0772492955589006, 0.031231426250850482, 0.06296415362627276, 0.05394426504931143, 0.020595923359055194, 0.03511725594439814, 0.04340597488466771, 0.060315435271589994, 0.07216574293711493, 0.07216945846354769, 0.06736666174425233, 0.05058235714151975, 0.029969022519165472, 0.07484622329713837, 0.05557104892608139, 0.05166351021597943, 0.050974486906441956, 0.01325066755300448, 0.0861842556285762, 0.07370112869407862, 0.11828952198547703, 0.05027692554698837, 0.03760393138133711, 0.05026603943758434, 0.06858540037947317, 0.036009541532445344, 0.13583875771972442, 0.02231896426829119, 0.04426421552535988, 0.04431880312040449, 0.0825652103089998, 0.06453725389174877, 0.022126067159396988, 0.06265741202139086, 0.0406735614242573, 0.032424541160223946, 0.06238493752936202, 0.03841246440706234, 0.030554158560511087, 0.02403963030496192, 0.042545217645144275, 0.09574545427195488, 0.039575397367438966, 0.018021789409460563, 0.04050120696305268, 0.04676577605066761, 0.08566870909905241, 0.04094387937877928, 0.02652422389796665, 0.013144084612929053, 0.055333446756365805, 0.05343621469012672, 0.02445354569523085, 0.06762605145453446, 0.021223826258773767, 0.015212729809835795, 0.03647562176469834, 0.05012896332529284, 0.04018557873824912, 0.03586966153835097, 0.08564888274357205, 0.03207141676196649, 0.03111210997186361, 0.004748557694256306, 0.07701006162190631, 0.030260654954960754, 0.025810197393800464, 0.03408976349859469, 0.024106900485592987, 0.09513389394288102, 0.024777340417307232, 0.05127550200408986, 0.0210509623490995, 0.03470187158053441, 0.12678238803580885, 0.08188718419161536, 0.06541920495369742, 0.021227156826024576, 0.0553949597862459, 0.021126092591833685, 0.03935446527095572, 0.034855889727271376, 0.023992452695364916, 0.0257686467000073, 0.011695715910454672, 0.04001233944549196, 0.019264345718247276, 0.04935497703451303, 0.07963146128120922, 0.056815746450616475, 0.018836389851546096, 0.045140846106674404, 0.005183921631185278, 0.022892739225719726, 0.011377418826844905, 0.03997896482507068, 0.056245711917478236, 0.08149677812452279, 0.04841539317802076, 0.01715475982505708, 0.025266477980861263, 0.10014830712950039, 0.006029520863516918, 0.03221638357987808, 0.05472236523224462, 0.03440732609540705, 0.07587354720359848, 0.012043862652424122, 0.03282928456281943, 0.06314192815954167, 0.027045016214551947, 0.008142433493518302, 0.015707490458754043, 0.045726206228737874, 0.043474068609817375, 0.046381701700269215, 0.07149245124310255, 0.06139291495445275, 0.0357014324606186, 0.025859556438761856, 0.04906855974226229, 0.05441537847922695, 0.012131686972063637, 0.022105424920277252, 0.06967648578387114, 0.024963605119996977, 0.5219336190531331, 1.9983005139135548, 6.382781786303367, 11.05339211802329, 18.1831314486842, 27.24492246104825, 35.10057680068478, 43.34705414310579, 47.98113446081839, 52.96625514184275, 59.700682317056966, 59.1119816226344, 54.7521024365579, 51.72338547245149, 43.6351522322624, 46.91912528007261, 47.41198678170481, 52.19856885171706, 40.48374745153612, 31.240225184348326, 24.807287070059008, 36.82247377211048, 35.367094009153305, 30.525518348140103, 33.109177697089414, 36.0963842176622, 37.30000665110927, 30.616995865298858, 29.752674141237815, 65.59671463504915, 79.07499836337182, 31.944074899919574, 30.645399708901685, 24.065604132990686, 48.669451590507265, 39.543214075026974, 26.810733733638642, 42.712748050689704, 57.798685796799205, 54.695165311136556, 48.785490989685066, 45.13017931292134, 42.76485281605875, 32.46036079622085, 23.10445477885585, 12.365975053079667, 5.613347589969636, 1.379815179013437, 0.2500636010400711, 0.04225720689001103, 0.06520316815905033, 0.03741347426248174, 0.10062515855796876, 0.02814381420912762, 0.01887461763896769, 0.019526282670877634, 0.02935332723052031, 0.06517810176216787, 0.05350792051983937, 0.042212731655566924, 0.04116166668433336, 0.07039614111906098, 0.08138266166732197, 0.07235320465218636, 0.06525736121881394, 0.015112356969996568, 0.0050510293165702495, 0.01941616519264156, 0.03550793397270384, 0.08539476371820896, 0.06545053794980049, 0.08897944233350216, 0.059205492612935846, 0.05403282481335825, 0.041509478262835936, 0.054654995460183396, 0.04129209315344211, 0.012400954428519453, 0.04955247450139254, 0.05172086338843069, 0.016899244604452003, 0.07219132261290666, 0.019518625622074452, 0.03542171077682607, 0.016646510283012065, 0.05864180128781065, 0.060910172309846654, 0.01351650293555952, 0.0238820057993214, 0.02235567520162271, 0.02061759981687271, 0.07444308484874426, 0.031113050344790665, 0.06415202657902433, 0.09645802329384512, 0.033093837705711206, 0.020840550555036436, 0.07598615446758848, 0.02415255166500086, 0.04561312015979521, 0.01584359459699162, 0.04410759267968036, 0.01550453844585366, 0.05724584736350564, 0.04156997239577674, 0.01001118528356235, 0.09597325051623969, 0.048540418727263335, 0.030755800563060952, 0.1272066705109131, 0.2647068814164208, 0.20163478600161694, 0.15800696737583608, 0.17612842482424554, 0.1376961685356594, 0.1638104817679813, 0.15941849969808133, 0.13802992240075143, 0.15473917336954227, 0.17370519678919547, 0.13427872691423665, 0.2572885456104433, 0.10342252095259967, 0.08507214877153597, 0.18762591835712233, 0.1779392268508673, 0.15110244674067344, 0.13537665348379843, 0.1514013589269692, 0.15344099141657352, 0.17836986019486384, 0.12689580735299857, 0.15029529650365153, 0.172192219104017, 0.1996381463663232, 0.25651277433479985, 0.13436652059035917, 0.11267384469148614, 0.1648512275348748, 0.164253709597453, 0.16760834733084326, 0.12783930591878392, 0.07642423418620903, 0.09767275528922197, 0.161530711357632, 0.15139693093876685, 0.21034918935789218, 0.15319504654936253, 0.1420531710309367, 0.09975282956034907, 0.13496226120379665, 0.16774776001130381, 0.10172238032664023, 0.15396323355455555, 0.10844908429369812, 0.11546157736090884, 0.12807229623919533, 0.17736559553492456, 0.28794355390052645, 0.1573193728202774, 0.1776934964882751, 0.11510654157328029, 0.11360371455309853, 0.26441166177392006, 0.11344151075689063, 0.10263555713238255, 0.13524102527768384, 0.10272961740772571, 0.09696451466410391, 0.12194794422436146, 0.18711395711908418, 0.16612579865801722, 0.09055967487755323, 0.25148215072770275, 0.13650021335530665, 0.13050865502126757, 0.5342713118560853, 1.9571345035106906, 5.899094708504216, 11.393321387229427, 19.06806718918585, 28.352725313555812, 38.34616945635888, 48.790288048405806, 53.43788485373221, 62.56283583179597, 68.3174196366341, 70.06997385332662, 64.32803969229421, 62.58854304590533, 54.03809770461052, 59.20786396149666, 60.60014455549179, 64.67891139368858, 50.57355834591774, 42.533240779753655, 32.6624079673521, 52.34228449483072, 44.21849104665941, 42.399778212270434, 43.81594996298514, 46.2249049832744, 45.354935046165224, 42.24853161842593, 49.22076425244732, 65.52746518965691, 87.02906300944667, 49.87362707814863, 42.48368555499662, 40.17435089234383, 59.0882355936112, 48.46549226391701, 40.47504371212375, 51.33695748544509, 66.06251178249236, 63.00695011692663, 57.24094044777655, 52.15630923548053, 49.0678467289094, 36.58184028440906, 26.120031802884995, 14.162394116001746, 6.445710822459191, 1.646404215885747, 0.3324341713901489, 0.15270566958333218, 0.13698416641883313, 0.1925731609545408, 0.196539519895469, 0.15336609866109588, 0.12290290346549404, 0.10291869556831737, 0.14471056150092235, 0.11617670511646618, 0.131055457938102, 0.20177062871235035, 0.12707804434842643, 0.2169593330472708, 0.16023865810805754, 0.23495953409902512, 0.19032798707485202, 0.10940100982665055, 0.20952751409382592, 0.2130269118013882, 0.11340404905739332, 0.1330016430227026, 0.15733123186134523, 0.1669484851581435, 0.1676072288424738, 0.1656055636703968, 0.14678068428991303, 0.10697908414107178, 0.17411839397203538, 0.08945510632568791, 0.1178933625980731, 0.07841681355550405, 0.22565078440933461, 0.12057301558313832, 0.0714304287647528, 0.21143128855093835, 0.1607148123965148, 0.16791956288920296, 0.16907606454145524, 0.11541970299496768, 0.09387284427160218, 0.2158081633669715, 0.1473427783217161, 0.22220881265257636, 0.07703548808011317, 0.14095895232692843, 0.17957134653002987, 0.15355055731150413, 0.12320415988083809, 0.18252872170940523, 0.17013058456922733, 0.2643471571706957, 0.1564806750825336, 0.20630467412692888, 0.12523957122597965, 0.14867117478241845, 0.08593398236459301, 0.2399245346145284, 0.2222343233804549, 0.16124698303399548, 0.061188507374496236], [0.08364369356704336, 0.053640078347657, 0.022838385287492026, 0.029883810559347756, 0.036230933281683156, 0.035765967707359986, 0.024814413327182976, 0.05511107824502453, 0.03175516226028483, 0.024143019616003, 0.03800025547764475, 0.015335527000828617, 0.0415469667754106, 0.01266075399584107, 0.035057600677734425, 0.030789125387767152, 0.039995477850278544, 0.011609160423939748, 0.014598460402339699, 0.041289182019329844, 0.057065054443815065, 0.040373151536069574, 0.07501123097514914, 0.06213568316231813, 0.08337253674624429, 0.1068948451129179, 0.08042011049485977, 0.03656040088483884, 0.03907416136034074, 0.03046266659493408, 0.049967521786569595, 0.022274067685488733, 0.05224302125674102, 0.05739474038202917, 0.05146582505755848, 0.03516428991250935, 0.03893866338917325, 0.042770696473458124, 0.05886483246520643, 0.01747094154838593, 0.03814357520651914, 0.0657508903813939, 0.04061121718897935, 0.0868938981945957, 0.029972399051691738, 0.03968263818551937, 0.003968917435192834, 0.020373022416606545, 0.02445598377004987, 0.06111942922636386, 0.03310195057682934, 0.059310833532964034, 0.009672095616077705, 0.012278282684424232, 0.005626285217717411, 0.07370006383186387, 0.06117931431940487, 0.017766798959083615, 0.04727425158865029, 0.04475993569940329, 0.060607762932176554, 0.034855004895718834, 0.024328834242037228, 0.07011554609503477, 0.03906729338209956, 0.0769358966499567, 0.023404388282928738, 0.06800413882780461, 0.06872781612459691, 0.0788136930655568, 0.7318154794554557, 2.0973732106147276, 4.384029219227453, 11.241571749410323, 16.44530769317381, 24.722836479063957, 34.413856075656035, 45.06953554768717, 46.21697395078598, 51.288990820607836, 54.30754884596794, 59.0184134821738, 56.37335138936197, 54.83405251656809, 46.73999847904329, 50.25643079511581, 46.531140112107806, 32.10625117824924, 45.36820834682834, 41.78462897577594, 49.044932242362734, 38.637625094383, 39.10724655274422, 46.59512181435862, 40.554636447660386, 41.26269094405636, 33.72341694370393, 72.16994808566186, 47.74938514155727, 30.07237868924295, 44.6877202680034, 45.908656043391076, 36.221723556518555, 48.31963108431909, 44.61792169078704, 49.46878748555338, 38.23438975118822, 29.404293144902876, 25.230522578762425, 15.338465821358467, 9.220041978743769, 4.780667135792394, 1.3082520255158026, 0.35148196703483986, 0.0850987856486632, 0.0756529292031642, 0.06538954202926929, 0.031918651168985714, 0.013093788067870324, 0.017055700826007995, 0.03473950948025431, 0.0462474333002202, 0.03710379471041022, 0.031113645978151794, 0.06995459102214345, 0.024224150242404114, 0.05525835481802783, 0.027779949258171746, 0.05721878913802005, 0.05951896813067217, 0.057494170933721535, 0.06518174067980821, 0.017931059701368213, 0.08427190098671183, 0.01989129292328031, 0.011613587454532184, 0.032978100972550536, 0.043781312002289685, 0.028875675240171053, 0.07451472939142297, 0.023622761645744887, 0.061786258968734936, 0.036793686149101106, 0.0682340111703642, 0.023206434993734284, 0.028253812943735433, 0.03842670215113509, 0.032855592022139224, 0.018279758026643146, 0.014272489990558357, 0.023454486602737058, 0.023428918418264198, 0.03070422752399839, 0.055141468952980735, 0.04671806026430381, 0.013343246405824058, 0.07704095028701329, 0.059700822082137874, 0.03551368346257556, 0.05162553140713323, 0.04568725065778821, 0.0013675016581997156, 0.06778957292197213, 0.015923791553735012, 0.028270180412237684, 0.05403234217796595, 0.053109171755251386, 0.04736283433533484, 0.052337721215500954, 0.059128684637647484, 0.011761243241058003, 0.034541732391282436, 0.06273233158994587, 0.01854102848277938, 0.05311556475897951, 0.0028461325095005094, 0.09517039037159375, 0.059581212774519964, 0.07250022458573503, 0.02429996421861072, 0.020921211952583927, 0.04761051822213396, 0.024652772605599418, 0.027190243502357797, 0.11491639855047388, 0.039841498007937785, 0.05316035408947257, 0.05124675072429161, 0.07861785034859374, 0.018236096760618593, 0.072661294571815, 0.06804556120187044, 0.11056350228647072, 0.04526230168618983, 0.009478149924337143, 0.011867497720935894, 0.04068160534746224, 0.013403351749143293, 0.03756563464600233, 0.033223681947997505, 0.04323794498979565, 0.042106969387180386, 0.09540962430858806, 0.022076317409594214, 0.010446335673482429, 0.05188753347723715, 0.07214855958497332, 0.014903440004995754, 0.018160658167494882, 0.02341657099614461, 0.07260766075623613, 0.022991740768174493, 0.049365418812920975, 0.06293855479828293, 0.03040289833030153, 0.07048748944315218, 0.022717404682489655, 0.01858584845678941, 0.05962730828492392, 0.06875243052960404, 0.0036801513652467443, 0.010915148924405297, 0.07236324040399444, 0.030871477924407493, 0.04959526817284284, 0.03429165447971994, 0.03616025400978904, 0.01395479811640877, 0.05080288704184275, 0.029427909720388633, 0.03559933209251012, 0.05781112832107371, 0.032974523341944145, 0.019017780319817604, 0.014821402522014275, 0.012614038911828352, 0.04731296967234343, 0.059756168104227514, 0.054603514351671746, 0.06128662025495883, 0.02406400147705309, 0.007053472546695342, 0.04072361760922978, 0.05274523402594271, 0.10098404010697719, 0.22060370523362394, 1.2876544340002922, 3.5211867190176442, 7.244014643853711, 14.647645238907108, 21.733621704962946, 30.916280554186915, 41.87248614526565, 52.1190780978049, 53.22643380011282, 57.86957479292347, 61.331152762136156, 62.62345214043895, 62.180487109768784, 59.741435743147335, 52.84861149326448, 55.94410288718439, 51.09089935979536, 34.636552564559445, 50.005312811943796, 47.62604621148879, 51.57568470124276, 41.4757070233745, 39.91191687122468, 49.41407042164957, 43.098352339959916, 43.23373294645741, 35.7851049207872, 80.24249968990203, 52.04157990794028, 32.127934040561804, 44.8877925257529, 50.80695506065123, 41.182451017441295, 48.872171448123076, 49.22487881875808, 55.78746695672312, 45.28355575376942, 37.1932005113171, 31.397773065874656, 20.314494448323405, 11.924682913287995, 6.825834089709867, 1.735430006538668, 0.5694353604508985, 0.18339976367931213, 0.044311268645669186, 0.044426289086620656, 0.05948042624720162, 0.012641454325808633, 0.022898664915814035, 0.05072485715631516, 0.07443140200789898, 0.01780218072986651, 0.06320259466226544, 0.011067205886056107, 0.04443203474605276, 0.05277371334452784, 0.047797979937205394, 0.031730137998238206, 0.040302418638020754, 0.026563263738587983, 0.048202114299901073, 0.061277928987457875, 0.029591779757831848, 0.00748668808580166, 0.02855947053420448, 0.03377744860406365, 0.07815797542852741, 0.03492457717056236, 0.04804163803196242, 0.05751984254006417, 0.11957846491807893, 0.006698652700100455, 0.059966562661312284, 0.03509596253054277, 0.03586878819811729, 0.07501741330469809, 0.02364697385459177, 0.02266492191401701, 0.039987173457179344, 0.024092662741520235, 0.03591776036867692, 0.040802528495870294, 0.02456688457318852, 0.049308437193112994, 0.04066878103560979, 0.07403942546056164, 0.027153251031714103, 0.030618935124948624, 0.044580801360068784, 0.1070617756716186, 0.006447759383703552, 0.045974219533344435, 0.034001992805109876, 0.013423559233366002, 0.019262911218609062, 0.036645835010154594, 0.0778701868388922, 0.07125525509998684, 0.04528930628552072, 0.03126416884873423, 0.08867587233262678, 0.02239049964344069, 0.046514840120629924, 0.09178929196129884, 0.030066597222861265, 0.1235037615462657, 0.17647923180653205, 0.1867115924194936, 0.08637455186896748, 0.07351339884823369, 0.1458848823582934, 0.12975765902909542, 0.20158689018459092, 0.18129383394074056, 0.11385248628475013, 0.150867625470123, 0.22336278621467853, 0.2116570699839823, 0.10789178597230105, 0.12889119826497572, 0.15533652276762072, 0.2790066173240062, 0.1695971728693093, 0.10079316163976347, 0.2012207308003018, 0.1683995016520062, 0.10068470657232309, 0.10231091205271022, 0.13834360476222732, 0.39955946947297744, 0.19480422349466434, 0.1703492107410585, 0.14742926964836736, 0.15715097137276204, 0.17271626920950028, 0.14291384017034886, 0.1165743660362017, 0.14325868698858446, 0.10716853768474634, 0.16307787188599188, 0.153254694155147, 0.14192783904652442, 0.11583253245560393, 0.15892107880884604, 0.15078982158053308, 0.11320300460342439, 0.16333737650946265, 0.24618927990236592, 0.1350052234145903, 0.10982212835862754, 0.1106114287470137, 0.1522257614640459, 0.1492004955728208, 0.15703503162630145, 0.1261331898070151, 0.20297343271874613, 0.12058384806638765, 0.13372325188209935, 0.16015518516782792, 0.09488975704317132, 0.16873524734570136, 0.13727417666344874, 0.16086024652806022, 0.15465433679280743, 0.14711613887019698, 0.13226140290498734, 0.14122306879970337, 0.2044541581023124, 0.1720838483062483, 0.20870438326270352, 0.1820609331010811, 0.09677300800479229, 0.2805887421052302, 0.14865576109338194, 0.3070101646646377, 1.2014134035956476, 3.374500370794727, 7.357413307312997, 14.255528834558303, 23.32613733506972, 34.090476266799435, 45.623209476470954, 57.01634553170974, 60.55848113952145, 65.61768362599035, 70.75936179007255, 73.90463982858967, 71.31455759848319, 69.84890122567454, 60.430015671637754, 65.07037178162606, 61.158795972024244, 45.77422465047529, 60.870136983932994, 58.074024415785274, 61.44147334560272, 51.8766716987856, 52.65332452712521, 60.73952205719487, 53.627864853028335, 53.14443272929038, 43.14626801398493, 82.32736495233353, 62.16489176596365, 42.954158167685236, 55.89475947041666, 57.13427551331059, 49.33019053551459, 58.96684215914819, 56.08218600673061, 62.57396751834501, 51.31626306041595, 42.09635542285058, 34.49725351025982, 22.215983021643854, 12.533398482107348, 7.178714044632451, 1.9985365915683009, 0.6413708326797332, 0.28451166386085175, 0.16908835259176072, 0.1668783421477964, 0.11864206032647241, 0.23206661755759872, 0.08987408747235615, 0.17290388414215657, 0.11998054616513754, 0.1249133863095795, 0.14443308445474795, 0.12607448448937747, 0.13693441666903036, 0.1879652799858201, 0.21887295939508947, 0.24254339086192273, 0.12279093971536045, 0.24168160323414112, 0.21512072202899765, 0.07155798240414551, 0.1557508077953131, 0.10820226608625344, 0.221102443794089, 0.13858441684034564, 0.18330092301532147, 0.07258378945651554, 0.10433885404059004, 0.14205482578085316, 0.2890286714799943, 0.08368710776971233, 0.16739669255912307, 0.12401891737094811, 0.12006262482534494, 0.14526764531770062, 0.17385702009402937, 0.13411576469098369, 0.20326028668111373, 0.15038515861716964, 0.12544304417866853, 0.19986774291723006, 0.14263001991616142, 0.24088539273267795, 0.1645959210732291, 0.11030930665231521, 0.17528896099857746, 0.12637245438752637, 0.14508450433852213, 0.13973077548848045, 0.15472461769898094, 0.16298454705505602, 0.07415187184608753, 0.1887067458442142, 0.09317876861220406, 0.13465012633992782, 0.1842391202526708, 0.16028707486487206, 0.15876000116188682, 0.04291361017573265, 0.18316734792484393, 0.13987987152030393, 0.1661854462638017, 0.2005417011077366, 0.08864506793719146], [0.037564841745000695, 0.09913668036460878, 0.1056362392621175, 0.03609943811992004, 0.07327608013105008, 0.025752283061944672, 0.026002906811153217, 0.01851122766252487, 0.04511436627757165, 0.03213477223330448, 0.02369648994757764, 0.03278948629515306, 0.052059803668770104, 0.025915053763216542, 0.01426311594719488, 0.06049561532094114, 0.03766477408428346, 0.02343652184091268, 0.09393009402218366, 0.06855631202098823, 0.040214544522666165, 0.022148074950241757, 0.06784650857650465, 0.039877266653122447, 0.024050083574688724, 0.021980830295492085, 0.027825537235325867, 0.07407249747625283, 0.04306462142736681, 0.09064071165818362, 0.03284328481963566, 0.10268146112080544, 0.024384770151828567, 0.0036074297508269914, 0.05192516754651743, 0.08030902008495985, 0.14033918719618552, 0.027432432623520017, 0.0335446153316767, 0.0498108146712184, 0.04838347795509523, 0.06872819916855905, 0.07393417264064474, 0.09436891684609075, 0.06814742791316203, 0.08848172266997638, 0.01400943454955855, 0.053171221046678485, 0.028274093206310948, 0.05168228320056393, 0.016581881190499952, 0.04391562636761416, 0.08045912735284337, 0.08548422746600644, 0.055625330085956284, 0.1049488745329361, 0.01168231224460948, 0.08481714874505998, 0.08788064242370668, 0.06523149042961097, 0.052045493146344546, 0.021027627310925917, 0.0589060633172912, 0.02543628136927803, 0.048054699831071405, 0.06418301100512186, 0.07108647060850937, 0.06727396510541439, 0.0731309371129159, 0.01553566364060727, 0.03458725716618281, 0.0774545381746946, 0.6793423177253816, 1.0586333683421536, 3.3704843540345473, 7.232694683536407, 12.824672710510994, 18.430427082123295, 29.452120565599014, 33.60918967954574, 46.970928022938395, 41.36610815601964, 42.51832008361817, 51.24342464631604, 50.829504766771876, 56.68596821446573, 53.63456033891248, 52.018716412205855, 57.16187330984301, 50.71522258943128, 54.94402400908932, 54.426373127968084, 56.36187453423777, 56.70732944242416, 52.04331751792662, 51.13918765898674, 47.117208896144746, 43.63436775822794, 52.91125174491636, 46.137036046674176, 44.00849519237396, 45.29294590796194, 49.725059463131814, 46.37971701160554, 37.39865426094302, 29.2075333287639, 20.501324784371164, 12.890169428240869, 6.436180443533006, 4.1715083391435686, 1.4254979212437908, 0.16367292302029748, 0.0825717603607524, 0.08363191113476792, 0.03602301701903343, 0.011510885707403143, 0.031148280813208515, 0.035848008063171184, 0.03252633126272309, 0.04656245248512395, 0.08401228911093167, 0.08307766184330949, 0.04097756043437027, 0.03572492837725628, 0.028541461722324454, 0.04743403071657785, 0.03470181795437971, 0.04731357105136399, 0.021433866500193556, 0.0369321565414148, 0.06561538474934717, 0.03151465661733622, 0.06666518567550568, 0.04603675529060345, 0.028694951268393668, 0.08138217137105043, 0.04200120328835422, 0.08137678577294273, 0.030677253568184473, 0.059799973011737874, 0.009212630553050868, 0.04110984083625578, 0.06323907576921968, 0.004845850860639926, 0.03757127305312503, 0.04378326935693622, 0.037991682953772046, 0.06525071157563118, 0.044554658609652714, 0.006413544939395281, 0.041151623271646044, 0.06963140917040649, 0.07307827622900087, 0.030584658435996503, 0.026773233116874774, 0.05540496106409738, 0.024768940263217496, 0.06660682509743399, 0.07223697379231453, 0.03847809898997507, 0.06778948099142121, 0.058530699386591875, 0.03887129361711202, 0.011325827593194141, 0.06889529060572386, 0.040012193888786345, 0.057798587461753245, 0.017299368496864073, 0.05999128431862882, 0.03245697732293799, 0.12409466814490096, 0.04743151411774659, 0.015354841035009633, 0.024697391481529322, 0.021755460634707444, 0.05633949257072903, 0.02925497303236156, 0.04071757700594683, 0.02032293175767747, 0.03506055011624291, 0.015120704455541508, 0.059673411456207116, 0.07862169610997362, 0.02861118529953303, 0.015440205254802301, 0.053074061945681615, 0.030063563514681115, 0.01412474514631134, 0.023969129148510196, 0.037363598108171456, 0.059105211703647534, 0.02817549386001643, 0.01990079815920082, 0.050498708001067566, 0.027053374233805848, 0.060099796842663526, 0.04918243871220658, 0.03299459484556029, 0.03300401772702894, 0.0796760399375231, 0.01521003701078195, 0.02639824839969797, 0.018526564742768967, 0.06543606654891083, 0.08173095588121684, 0.10511388221094686, 0.04607179998269966, 0.05845756863334006, 0.031369157368317246, 0.035985206749530575, 0.0508392455747291, 0.015583573821781865, 0.08386374466241368, 0.03573966024804019, 0.012965042204145464, 0.013854246203517242, 0.030112755935518976, 0.041600129446916045, 0.06719757081760515, 0.09640488743541703, 0.0666811356260892, 0.029721972570123694, 0.044112560759869315, 0.03499914816911182, 0.03272059966900176, 0.0359946794267143, 0.06272935533836003, 0.03242816092566617, 0.06329341055524927, 0.047617328743780815, 0.03993844260431586, 0.055845833173201936, 0.02369228795531296, 0.023734545365216273, 0.05061797639955917, 0.07693420359564405, 0.03843619398051693, 0.06404246834497299, 0.06539932497206234, 0.02376802149228752, 0.057888637266812794, 0.017377810154650963, 0.037581990623185714, 0.0246217709425236, 0.031730754699017254, 0.0678210514747808, 0.06222790482664301, 0.2963392033932671, 0.9048382757652191, 2.1909604726299166, 5.6871151155041115, 10.644810584283645, 16.88320109921117, 24.74676685948526, 36.33011433386034, 40.995275512818374, 52.78991322363577, 50.71213568410566, 49.632315020407404, 57.457353299663914, 55.85562206083729, 61.88677218652541, 58.6039170142143, 56.494007418232584, 61.61632476314422, 57.030418995888006, 60.010765291029415, 58.87245032095141, 62.535516523545795, 61.11943890971523, 57.16987494499453, 52.83371825372019, 47.599405473278416, 49.66294873145319, 58.24868363718833, 48.967504655161214, 50.74511889488467, 51.16067440279069, 54.07618391898371, 51.92475603472803, 45.17958156524166, 34.58263174180062, 24.44897267126268, 15.800093489308512, 9.058474648383356, 5.299975708607705, 1.9318092301968608, 0.5151348032297627, 0.08966113035116466, 0.05781349170232012, 0.06454711344333426, 0.03536286373292247, 0.086628464050591, 0.06554708801089756, 0.06847013479038593, 0.058923196873717734, 0.01789999483603864, 0.06436294590633723, 0.04931484168815998, 0.025634075695228194, 0.040410693674798936, 0.044787491882039655, 0.07100304363355522, 0.01244838867757109, 0.018903135261949033, 0.07163064584376351, 0.00619119988949669, 0.021637607583655946, 0.060334836448272394, 0.02910753175045454, 0.02212323263407715, 0.07149019128372593, 0.07486329939697059, 0.06657178423577739, 0.04862445091167766, 0.05124326119379652, 0.09574707071747511, 0.031136730122530175, 0.07085321981820368, 0.043255603316450314, 0.06659397014206456, 0.03414068153248199, 0.02181365075821598, 0.028804331387002623, 0.04753348425090794, 0.052532579509481314, 0.036323369450626836, 0.042911116559539116, 0.02535528863870329, 0.06346042921406127, 0.03493687671218668, 0.06574951908400943, 0.046943133066017786, 0.048024577253888694, 0.02998758291435098, 0.01483072964249239, 0.0044071573140700504, 0.020863282298969648, 0.015867458235832955, 0.02710001175141623, 0.03787848963251999, 0.05596204105043604, 0.0630009220161986, 0.09539493074220035, 0.04956839380845909, 0.051728049293160445, 0.026020655153138984, 0.011684314606921568, 0.060448160004471584, 0.03703190118915612, 0.03529712572813996, 0.021461782744154338, 0.161647830879496, 0.25303632862144904, 0.14466107222101382, 0.1093092937803557, 0.11218301215839964, 0.14104964181540475, 0.15892277952403794, 0.13743111743561684, 0.10420278916435857, 0.12999517692913934, 0.12368970640724707, 0.19246589332338304, 0.29066243058731484, 0.06357859827638154, 0.18524340023436855, 0.12611353965175728, 0.1005921095249153, 0.14577825824099203, 0.1133635459888366, 0.21693353120598102, 0.15911523613237566, 0.24635791117625855, 0.1197735951732724, 0.13513676071118924, 0.09911978812587839, 0.08579551963315857, 0.11098342572128582, 0.24384619998595408, 0.2268633943411612, 0.22160980850458148, 0.23223330296816366, 0.16184450097141728, 0.094248618059341, 0.13339017217438068, 0.16951129441299748, 0.15892546083177292, 0.26160670744795955, 0.08793674304240173, 0.15495488840726115, 0.08608362997972197, 0.21444730010003815, 0.14932405023324877, 0.14325623550722677, 0.2291380472841763, 0.13129377256958716, 0.1656695932991082, 0.09676243599143722, 0.1709658808765873, 0.10571575152777857, 0.10826149234367956, 0.13363680652072354, 0.11022857630685454, 0.21587389371087476, 0.1416262455524937, 0.14149170519123155, 0.24498581706035524, 0.15079996458465053, 0.1172198870429589, 0.2429186207272353, 0.2715857074626031, 0.2538479987772242, 0.24157458075111915, 0.1834270670529335, 0.10645008510759763, 0.29605290101420495, 0.13491401298632547, 0.09819711182987499, 0.13872963646727224, 0.2072845159038421, 0.14748369253450824, 0.18292978405952456, 0.29905167558500845, 0.9626390580688754, 2.0011797787681704, 5.79392223588882, 10.344685527586169, 18.86051889388792, 26.62669808633866, 38.35913288977839, 43.46720810859434, 56.26971844703921, 55.33372325281943, 56.66275170541579, 64.27873942159837, 64.9840953273158, 70.15810166635822, 67.10845101264216, 68.00556767371394, 71.89672362419867, 66.19688433985557, 69.98589392631285, 69.20008628599106, 70.9009671980335, 71.1328734121015, 67.19214654737904, 65.19467561475693, 59.99059254123319, 57.495788604982444, 66.98337447258734, 58.818458895529474, 60.020932074516054, 58.54528150250835, 62.9128053880507, 59.86857937228296, 52.34266888710761, 40.63084810010849, 28.80406656572896, 17.48602624862425, 10.079587236527475, 6.0900376496776465, 1.914976868898638, 0.6830146367992125, 0.2165939244291475, 0.1781942115555848, 0.1464930489178627, 0.12502350378781557, 0.22286387911487013, 0.18146730689031465, 0.15260681359758302, 0.18027775620500888, 0.17206765320752898, 0.21081873996844216, 0.09249754024729614, 0.0954259573031337, 0.1819323069385944, 0.11351184528921882, 0.21740403176555712, 0.17885010539283677, 0.0760864200551183, 0.1601621565679389, 0.1646725911526911, 0.23948786449768852, 0.1469851531569035, 0.1656574431446291, 0.06608972340942391, 0.16714167721088857, 0.20180632840962182, 0.27671157112044675, 0.0876415387216595, 0.2561350929881296, 0.14514940730746717, 0.07565768660917398, 0.1421498666487394, 0.19519256878524058, 0.1277707716930778, 0.1463318486968356, 0.07355881254038504, 0.17166723437126608, 0.19357417740168112, 0.10152531952987756, 0.13425024376521189, 0.12175814594112097, 0.1342131804314352, 0.1482162717729807, 0.13166624451837233, 0.14299273190479125, 0.1412739217161171, 0.15033957638567494, 0.2014722068223261, 0.12929745469122164, 0.1253007893120089, 0.19945932612303766, 0.25079889222979546, 0.05890048236676282, 0.17951965091689942, 0.14027886543302767, 0.1730271783326903, 0.1344437116096097, 0.14659593452609357, 0.21802177442417991, 0.27636217373994093, 0.13816933508121199, 0.15320669108581159, 0.09285625325696123, 0.17150600350672202, 0.13956640366344683], [0.04901351632490274, 0.04940146708019799, 0.011870242230924628, 0.04077315668485338, 0.09064030563158375, 0.024574066647478653, 0.012199886034302896, 0.09887486981648592, 0.0559600645435914, 0.08076485006078597, 0.047771909965142134, 0.03815490947735887, 0.050062087679942774, 0.043656144726781115, 0.10859780494243869, 0.06682293083999427, 0.05845838451697942, 0.03953338510567143, 0.05014779376647165, 0.04828874735281833, 0.02749800017373937, 0.07412002557107518, 0.01569643868283639, 0.05148326504915472, 0.022766168094089916, 0.038008498583710006, 0.04388322850929634, 0.019403911616292693, 0.019307219828929634, 0.06686918722886233, 0.03467971631776422, 0.01277928024665603, 0.00876841159732712, 0.013053989800203954, 0.032730359629157095, 0.03543208743776045, 0.009339424807788625, 0.04035966455816262, 0.07814168073837796, 0.032447941315871094, 0.032983996019127874, 0.0315652126746793, 0.07030401904616626, 0.009496423994160948, 0.022990536094913562, 0.0163821735599589, 0.08241152541050989, 0.05093705202002199, 0.04976483407400308, 0.03288251618223806, 0.03355691870374065, 0.02003469117616694, 0.040664563721586625, 0.05139056457987717, 0.028580131925522324, 0.09896932079667047, 0.02374139419125934, 0.010972156399680723, 0.02863901535860233, 0.0016388857916500722, 0.033696974898057605, 0.030998550843627706, 0.01097840193148342, 0.049394353953821045, 0.025224528921347474, 0.0969592133356679, 0.03553436783653113, 0.06560966973343203, 0.012905607187759974, 0.07578030664233432, 0.01614965821406053, 0.0491764096002425, 0.07927203580977456, 0.09465149603784086, 0.1498190962499188, 0.24171843674154053, 1.424021884318321, 3.5973292396914576, 5.437657275507528, 10.468466704891576, 16.79560672852301, 17.726506763888946, 22.560612270908972, 33.12433373543524, 36.19144678115845, 34.87953555199408, 38.86835459739932, 39.042398006685325, 34.521525136886105, 40.641387508761504, 46.532140316501746, 41.68496939443773, 45.570084894857104, 38.362733625596576, 39.321643306363015, 47.06052280241444, 46.78750230420021, 46.11033255054105, 43.39715849968695, 42.841005632954264, 41.9787549203442, 42.598775740592714, 39.07006248351067, 29.57477504207242, 21.792167002154937, 11.280222785088325, 5.748590913511092, 2.1226548475603906, 0.42136775570050367, 0.14040131692684468, 0.10096203040091262, 0.038929301794738545, 0.05661231946320303, 0.021734917987017863, 0.037332471955807946, 0.05831206555388147, 0.01847175689744613, 0.027995085899507808, 0.03457284705232709, 0.02205144253469283, 0.05331868531122323, 0.06275532954943276, 0.059851710759704156, 0.030146138216819496, 0.09547295679728832, 0.045435724840048826, 0.04019286806484865, 0.027279010110144174, 0.015500994331593958, 0.02876897834451689, 0.02966143438712724, 0.04385570680061656, 0.009754399314612873, 0.012470596608886076, 0.00842525496057445, 0.09272682270215404, 0.03582493349489185, 0.05998258539024861, 0.06635548697123606, 0.019977883841361732, 0.015248579851862405, 0.07741243398237614, 0.048317107927775195, 0.017966353372039816, 0.08739159487548374, 0.005675084060884171, 0.022822621113230145, 0.04024646357603131, 0.017254523624996507, 0.03842969372447941, 0.0461790829356159, 0.06978159304708242, 0.012234937429668443, 0.07242220619152631, 0.037966379069633065, 0.0866686989883742, 0.027246075990279357, 0.02052997851053313, 0.023823537968940312, 0.030758022218041366, 0.022286361481453625, 0.06483578303408238, 0.04674029596630604, 0.13219069298957625, 0.0678523691491254, 0.062107268961206566, 0.012814488690046054, 0.040589820353254195, 0.11071458248601806, 0.05358843636068125, 0.05191915758675145, 0.038310184008291656, 0.04754662648924897, 0.041351710115709615, 0.04595853771353441, 0.03427923236402773, 0.021618252372249, 0.07098743842253763, 0.03853035001685062, 0.01822294877661813, 0.04886080052763705, 0.05148993767497521, 0.04061663343060402, 0.019979776078534704, 0.04775133667393558, 0.04835864521502968, 0.03350931783056548, 0.055671544339988506, 0.04769082338879666, 0.030577202485273444, 0.06438459555107741, 0.031274091602573474, 0.037739609383166804, 0.052269164007157094, 0.032935946984517, 0.017193629211115263, 0.05205878860227043, 0.047697545810332226, 0.11638737163476406, 0.057229725043139154, 0.0422805036237884, 0.03928858937034684, 0.05922676687459311, 0.03136735706169519, 0.04041188111108157, 0.09929794187266981, 0.028869908513321035, 0.06347878468072703, 0.029414118222531774, 0.015937968010773823, 0.022450306212469455, 0.05774291585229578, 0.029660317813977603, 0.02400574432085118, 0.033361374761068055, 0.03600293785453804, 0.06928630954315586, 0.03561366942801303, 0.019678749489567934, 0.048279462367176056, 0.08680303250589678, 0.02622147935682968, 0.053579810210653854, 0.021331072822513602, 0.04232055087003016, 0.06473750927515569, 0.03226139124542956, 0.016598361656971036, 0.03148404565910178, 0.023175904474731897, 0.07321834008419707, 0.042310020991510926, 0.05688764380231019, 0.029775514455151655, 0.006293368726713404, 0.027016245782555594, 0.10862296326987206, 0.022225047634433837, 0.03269210885909777, 0.028541003984789697, 0.03775619901716709, 0.08845279518995555, 0.04033490842688949, 0.0315370608586818, 0.01826384446523603, 0.07202711932721638, 0.04639196727845458, 0.052414483225513855, 0.087493545856447, 0.04730670307312281, 0.19875867742924921, 0.6620686284957394, 2.4970384615082897, 5.731474180375376, 8.552278068757827, 14.706836746584985, 23.011839774347123, 23.280594694998957, 28.528423963054536, 39.87559180105887, 41.95148268053609, 42.44199468243507, 45.58695893133841, 45.03139049776139, 44.1197532223117, 48.106183544282, 53.35744488623835, 48.47713385858844, 52.83052544439993, 45.689638737709295, 46.14640658901584, 54.34905536713139, 52.92086939657889, 51.5415757702243, 50.67090765122445, 49.87442724166378, 49.05681310161468, 47.935893843250895, 46.351130777789706, 37.081424728516616, 24.2701223973305, 14.558088702540244, 8.09564063625951, 3.304637564766792, 0.641246542574898, 0.2252509784434111, 0.06626324998515268, 0.0420661483921351, 0.02631339075554523, 0.038112127297227426, 0.02222425664865202, 0.0755474618786285, 0.09709733898841566, 0.019211483736252113, 0.0369909844331203, 0.0497846489381646, 0.05023785889328969, 0.06765771386844498, 0.07221206061301694, 0.030467889399357864, 0.07634584806979665, 0.02308940165676177, 0.046818988517888134, 0.0729123032802055, 0.03867409109408337, 0.09598864888351771, 0.050546098200063554, 0.0497401200775658, 0.03687104953813457, 0.03187162869219338, 0.007544017318005284, 0.031157297668077295, 0.03562976110486254, 0.0527367496021813, 0.025172942475746238, 0.0883882292996972, 0.030318157514557246, 0.05802527670898746, 0.060794447068004846, 0.07009646284484095, 0.05418765118285533, 0.062002621350749854, 0.015727185621677388, 0.04411105539709811, 0.05945709503946766, 0.026582366140979915, 0.10577814172833197, 0.011577322767416557, 0.12365160119389335, 0.01042940513035583, 0.03442253294070402, 0.04545815972491138, 0.023853712257057912, 0.021653057661868876, 0.024728052235478838, 0.017859064673464146, 0.10804901785788038, 0.037450889996703596, 0.07293803617358208, 0.1195845093518015, 0.04913638916707808, 0.057757908192973946, 0.041994484697258284, 0.11794391674019637, 0.012905031664206857, 0.057342504676912105, 0.03256606824335552, 0.035628052728791396, 0.04497493827535261, 0.08190691861654482, 0.03465412515065363, 0.02971395162955648, 0.19299060226448123, 0.18666009598922345, 0.11468208289795345, 0.18418164833659129, 0.17788722480256713, 0.11917961656206078, 0.11368846686016168, 0.20214037338812507, 0.13095061114478496, 0.13973975403895303, 0.1287845128606404, 0.20190633352725737, 0.07122567644523037, 0.27304470659263674, 0.1962488814587555, 0.16563844416410695, 0.11345080340341215, 0.2268693698269706, 0.19939304419582893, 0.13304930901335132, 0.1368649631378151, 0.14108377869331068, 0.12628808512442535, 0.24283107219924852, 0.14670144015502545, 0.14332763490176972, 0.20071332012453388, 0.10023552623967971, 0.12642422660944924, 0.18522987112162576, 0.09617837821884502, 0.09499106451027817, 0.06474314002139915, 0.11701220826756571, 0.1358940386243405, 0.11726082678163245, 0.11621861012592433, 0.17913309827206597, 0.2162038018145869, 0.08168524341477502, 0.1912030739889991, 0.10955691638012087, 0.14761610317134088, 0.10082411925278364, 0.13003755691311053, 0.11764993816013299, 0.18807190410312147, 0.22358240830081128, 0.1836813929220361, 0.17235132024413155, 0.13617355346439347, 0.09593548238157265, 0.2184638684435237, 0.13823039228877715, 0.15107941813766956, 0.1387019040844133, 0.19085641920326218, 0.13266321602127246, 0.1470381664412637, 0.1406629972400204, 0.19748481110699717, 0.10147695639921774, 0.11260793048648104, 0.08178151002334011, 0.1698569839279498, 0.1820113212471047, 0.21311023152403294, 0.13687588755161534, 0.13952135769349916, 0.2795897328084515, 0.2473729623541717, 0.14765379469721548, 0.14283750716957355, 0.13117443139274276, 0.28553405416107946, 0.7200909021400637, 2.1353684750295456, 6.068015502345178, 8.48030944024363, 15.713194358733395, 23.353017337860603, 25.006517979406542, 31.494659531501036, 41.71782316700105, 43.89653505817537, 45.08732349641862, 49.290919765349365, 50.24607181549073, 47.470700740814216, 53.195211733541186, 58.682160454411665, 53.77957428655317, 60.04627450819939, 51.34007969210225, 53.91560600649927, 59.86138182301676, 62.04412198835804, 59.881138801574714, 58.17886937049128, 55.691741512667754, 56.61244730795584, 53.058827000279585, 53.5772741225458, 41.900554626218735, 28.634641747320856, 17.004888711437104, 8.701831179280436, 3.6162970864003707, 0.7903144436497843, 0.3159490317827271, 0.15223749793104588, 0.09104474642944914, 0.12432705325585221, 0.11503604616248801, 0.09827744380961503, 0.1562794544283421, 0.3276390738544926, 0.11394879119771142, 0.09584176684579543, 0.12748708933471672, 0.2922109087869045, 0.1884974353015423, 0.15476279952112706, 0.11502222593633399, 0.20267464310651828, 0.10762416847771215, 0.1751472347325856, 0.1817451363369342, 0.1543765992767388, 0.1923739321289524, 0.16693022162202867, 0.19745038311568, 0.1408251627318321, 0.15291608329261505, 0.07728041405038488, 0.1765470918748648, 0.09854872320448199, 0.13161480937513614, 0.11410919468729727, 0.1625316665177384, 0.14243621499307696, 0.18060121384839858, 0.13888558132513878, 0.18143194427172984, 0.1426923181861639, 0.1588174117909324, 0.08237238597845839, 0.10458055478070052, 0.16596363316620552, 0.10278933396142337, 0.2528315073540134, 0.14638800294168536, 0.24918738031579604, 0.1604268246240193, 0.13375591787119068, 0.19000129654042183, 0.1609772741193733, 0.1429763989102456, 0.23040396161377433, 0.2198041545888109, 0.26607943518507865, 0.13024476837486992, 0.16320885759928536, 0.3724795177338585, 0.1181920832623878, 0.15868382137869635, 0.10929432442231525, 0.1947813634310038, 0.26743525759347025, 0.16221205463572858, 0.18742212364750524, 0.13106711779630956, 0.1902877368153103, 0.17215671858960585, 0.18550840536913565, 0.12917203077625844], [0.11326998367064423, 0.07344336309019597, 0.028740847595937313, 0.02147408803143809, 0.11789521653084986, 0.03771696382412507, 0.011296073695824993, 0.010350814085423706, 0.020907608146268516, 0.08605646450192699, 0.0615738112960131, 0.023620490195049394, 0.07461883307945344, 0.06617691953696551, 0.03512766707928912, 0.041190521386001384, 0.02386690429111402, 0.031189389091225404, 0.014186875834580392, 0.030511378295599457, 0.05869938811707882, 0.043180461582397266, 0.03023761486063802, 0.029693537301594214, 0.037720001362744844, 0.05322381298268034, 0.08071050378343753, 0.052744441124941074, 0.06069168403384186, 0.062380578489072865, 0.06508934281526074, 0.027785380821554895, 0.03166302486563162, 0.02372483903121564, 0.01313995156857756, 0.032787735784246076, 0.0321052625264612, 0.03517960017967609, 0.018979866628444964, 0.010069001939207798, 0.05802063804660594, 0.020840548639816624, 0.03126396966587392, 0.08200258767652897, 0.028705630534058137, 0.08299514651298523, 0.020730042371958978, 0.02706125153288726, 0.04214093772574298, 0.017061685887916435, 0.06229404119714614, 0.015219130474443157, 0.016494752095651724, 0.03674119763496903, 0.012445083965787725, 0.03162769097534399, 0.03179824704514637, 0.04001788592206375, 0.043505152627345056, 0.031278837517264395, 0.040417190100396835, 0.06179655902087689, 0.1147196212062432, 0.008125843859518008, 0.0456896293607931, 0.027846685092475627, 0.0181543973139337, 0.03692838355838772, 0.043188176087794766, 0.022264547127809738, 0.06233308869864672, 0.009613971567652639, 0.03755601641211299, 0.03682605719434158, 0.06041565106340474, 0.03830996950367286, 0.008408068735603123, 0.07291818683546397, 0.30127630298656805, 0.6864215217290387, 1.4748850969537612, 3.0819734354172987, 5.9134059663741825, 5.749230750145451, 9.425026024541548, 8.062653012814062, 12.46487565578953, 14.301434293870004, 13.461928425296662, 17.762692589913648, 14.817800598759806, 18.658942407177342, 16.84559145281392, 19.329483355245284, 16.984498270096317, 16.23927245216985, 23.350834538859708, 23.937879993069558, 24.609899674692464, 21.04243536149302, 21.500899637899092, 17.323051767964518, 13.200400471687319, 8.037061508624785, 3.8960969111611767, 1.6030961010725269, 0.22770198482659557, 0.02390410360549727, 0.04912659090252654, 0.015739398020800325, 0.017868351574326237, 0.04232125950136012, 0.012900207225503701, 0.04092707140972057, 0.039165387110364054, 0.01836077757029524, 0.04133621215700142, 0.06446707257700544, 0.04063207010227827, 0.018563438469784397, 0.022989115001814022, 0.034252863617674, 0.0823434125331621, 0.040487359923821305, 0.03975962236103031, 0.038208324957879326, 0.04738641069120458, 0.03333263114214905, 0.05621881457045675, 0.06439047910633587, 0.07299970625148666, 0.03351951063039803, 0.036282502490306096, 0.09212348249650772, 0.05813388116357308, 0.02170830409252836, 0.043252661538821076, 0.0475643499333772, 0.07001352616615834, 0.03520500365524523, 0.02694104084624879, 0.048187179415817225, 0.027127190635749893, 0.04656987204667061, 0.05136519940870424, 0.03494190224896997, 0.05138224486501948, 0.05784886964266339, 0.014511395467355128, 0.04517286092103009, 0.017340289083339514, 0.01021743338975695, 0.02366586366758472, 0.0406666896155765, 0.01161697643598722, 0.06563741743804948, 0.048845543886625, 0.042000031173830076, 0.06641879647729859, 0.026611954371835438, 0.011271707311783348, 0.07552176728964814, 0.07405317673880248, 0.06714924599134153, 0.07142592416775805, 0.071398819976997, 0.0987262487591755, 0.03993869541333087, 0.02620735461072576, 0.04463764891449002, 0.025904001029688987, 0.040163354527565746, 0.02440678560355258, 0.03935504366733855, 0.0501111671028118, 0.008734759270033289, 0.0254961779536379, 0.04975823039609579, 0.08044077188617761, 0.04680948136674781, 0.021362905690987265, 0.04085199862358071, 0.06779226189058635, 0.03837038702782124, 0.07045721364838463, 0.030493262231410034, 0.07267549784193117, 0.0173405725358715, 0.037205803147967786, 0.04370233982861523, 0.005399222981425063, 0.020626735415369756, 0.014665622373051463, 0.03345666460752968, 0.05772121641184053, 0.052992098198662844, 0.03739521838724613, 0.027224759593786254, 0.029047650487853155, 0.04901402577337238, 0.07377973697598904, 0.022760690565431313, 0.010168328111420476, 0.0825403890602531, 0.03306289541444952, 0.007204872109146128, 0.06077033445058812, 0.0494723417045128, 0.009906844108275348, 0.026586236800217343, 0.042552867033068216, 0.028760141520310315, 0.00727508694023615, 0.0630978359690597, 0.027229739165294076, 0.0574014934470817, 0.0747008121482307, 0.02817644763948216, 0.0016059794424725096, 0.022802375324611223, 0.069496983722333, 0.06872159549065175, 0.037267729865327, 0.038917791323676225, 0.08778557857318271, 0.022231580449208137, 0.009941834216606955, 0.013313301944083745, 0.023657693339872266, 0.0022981512536775443, 0.00539209405448468, 0.027458684541465297, 0.11189659486614889, 0.09975305172584711, 0.026668265664709673, 0.0060268318949026935, 0.02959437296545554, 0.025815634702843045, 0.06554946288346283, 0.006420535012899388, 0.05933360166607365, 0.037584422952345306, 0.06564522387399789, 0.04328368043887519, 0.01268939132006058, 0.033066932697810476, 0.06839838299539781, 0.030836542399840492, 0.027126194721448327, 0.025749417893107862, 0.023635264200669144, 0.054219282953248876, 0.034811801367229035, 0.0884678718003054, 0.37361804696340717, 1.085185853223647, 2.3276315389140962, 4.923128601043455, 7.587589265838747, 9.032766453681454, 13.26380950789298, 11.980221713742903, 16.638974720431914, 18.92480261864201, 17.86696683975958, 22.519093982635006, 20.596263793206987, 23.583789986948815, 23.143094047423332, 24.346232068154123, 21.663587785536244, 22.477373692297167, 29.542280166379868, 29.768910792566118, 28.884120179760842, 25.119162567200203, 26.072533861283336, 21.57920583601921, 15.975472465638193, 9.620416933490384, 5.219624975035268, 2.093721974280573, 0.4557181576326971, 0.06013574934895, 0.024845771221143585, 0.05082812580850817, 0.11945209871496885, 0.03092861084658052, 0.018372437428502787, 0.04008730497932242, 0.03705014940351248, 0.05473531594860458, 0.07591709164121459, 0.05325285154545019, 0.02679447673501507, 0.07641225257107327, 0.07475392502402106, 0.01627218823188976, 0.03393487584206366, 0.06779201674245058, 0.03450815475756123, 0.027099161393820282, 0.07076753288387291, 0.05793665565790669, 0.042843126256259224, 0.034494200466020454, 0.050666711082862276, 0.012441740949608147, 0.04216233839190776, 0.021501676772811243, 0.07988720441297179, 0.04183505030889665, 0.06509105885221113, 0.06290521082137862, 0.02067927372521691, 0.016096780910306883, 0.03346017712066251, 0.037190504372119904, 0.0279411954444743, 0.030168992534820593, 0.025265171800950365, 0.011363971110944067, 0.06004866430415742, 0.06291577900429407, 0.07784213269910506, 0.041641046202951865, 0.026389279425324454, 0.050166455668307124, 0.014974612445991128, 0.08018830761073098, 0.011541049461811783, 0.06246656802813373, 0.06491789233780677, 0.026710245367740432, 0.05212716194951246, 0.01576064834220996, 0.011271712099832874, 0.031874804126639525, 0.02407367525231694, 0.017912349919037476, 0.04918595888621865, 0.053841502015148444, 0.06321557985258199, 0.030391655990012714, 0.048246126051150987, 0.05617595578153288, 0.034414274512880275, 0.01988285254957455, 0.04706744615349078, 0.029122792221906207, 0.03480599442076299, 0.03161492795052548, 0.1862832573392699, 0.21146427629695785, 0.14192673587991347, 0.1595690972622364, 0.14797996429185714, 0.18937114325742568, 0.10610153808468774, 0.15763273342482506, 0.26374970052030783, 0.16558049727351437, 0.19831977033567047, 0.14069083687518874, 0.1434304898664836, 0.15160929051137742, 0.11350386265304782, 0.1233466215912373, 0.11217325219824431, 0.1302060349694183, 0.27353077405883425, 0.2118508442635498, 0.1069346510414635, 0.15251169612090434, 0.10905959508231572, 0.19419913660855065, 0.2721529189617403, 0.172034113878204, 0.13229811383831885, 0.15712080283030389, 0.1909866235068729, 0.1791497836670568, 0.1946040906853253, 0.1280747094161568, 0.09313102601276291, 0.1578831062802384, 0.1500151075062252, 0.13566301714989448, 0.16457276989615735, 0.16076724345405258, 0.08855794075756304, 0.14812020434727594, 0.13660029508173466, 0.14299893721697793, 0.07772423942843754, 0.1808089156064295, 0.1568801592915289, 0.19700067418236888, 0.09777878951882163, 0.10569211005443528, 0.1498181309791342, 0.07255668526575451, 0.0988263841117582, 0.11301225637115779, 0.15655284056500082, 0.15061011267525537, 0.10157706876916271, 0.11865295409675568, 0.21074053771313161, 0.16866168758321196, 0.13951748128860228, 0.14761450970845838, 0.12626959942281246, 0.1325571281655181, 0.2190131381634743, 0.07500004609145465, 0.17039364384066674, 0.11811719816778937, 0.09215920517641692, 0.1417306633365731, 0.13572307844315806, 0.17262979320460753, 0.15263938765612342, 0.10301694634460634, 0.12953373152882824, 0.13987024945597495, 0.09641527558767027, 0.1410343660221946, 0.1838974603602002, 0.3398898616433144, 0.5515836119171112, 1.1592744002419135, 2.4992560715444627, 4.929642187010858, 7.601946611558238, 9.088661209229501, 14.404684805100965, 12.52410932894676, 15.61040178422005, 19.344111834802938, 19.969700459511053, 24.42289871554221, 22.322961745723603, 25.61920200624774, 24.35414348879168, 24.857330629902503, 24.411545415078443, 26.768515302288918, 32.03629766741107, 32.65290406442458, 33.428548843629905, 29.16069042298102, 28.971438023351855, 25.07313355322807, 18.346507972286595, 11.724861687229527, 6.076747678941296, 2.3396121734573, 0.690622502757657, 0.1772097732511259, 0.17390165237649796, 0.15530063920924742, 0.22423208150411808, 0.11404887292413943, 0.08387551943380987, 0.10234308774553, 0.15902993990288627, 0.07347025277633822, 0.12314681053882646, 0.1203126606020716, 0.11808391930835864, 0.16702127883270865, 0.1568309764467901, 0.15176541923034578, 0.1296893239862496, 0.2780142576704102, 0.10183275827477056, 0.12674298047298385, 0.14968170604157835, 0.15893998585881727, 0.17817394086910834, 0.14039442213552614, 0.12548710955607315, 0.12509476528653216, 0.21701360271582681, 0.1790001973389618, 0.1677450327382934, 0.13211701065301895, 0.1863026546855127, 0.1355616483957537, 0.15244345300860945, 0.18120046314452926, 0.11598668466772764, 0.17398324074043384, 0.17068509433058002, 0.12226050043658865, 0.08791019043494618, 0.17053576847237928, 0.21738011450056108, 0.1325658462460964, 0.22877982457078275, 0.08466436783032072, 0.09192055346624506, 0.11411946026548264, 0.11088448546586499, 0.24439085785660053, 0.10350757203395329, 0.18397558600671832, 0.22360954313508927, 0.09631696352434736, 0.13993161309870983, 0.200187768486719, 0.10137125924830476, 0.18738801741311628, 0.18583776188954232, 0.17275391477009944, 0.29267298237931344, 0.18704948315937675, 0.299116057614165, 0.11228506273079304, 0.08605444202980689, 0.1683457222797217, 0.15211124664112446, 0.1330459382264845, 0.14029349771238145, 0.2119040567307703, 0.17012604932871558, 0.15809869874388943], [0.019887933627732342, 0.014891642250961836, 0.09953113137594155, 0.014589388963706313, 0.03962009476738111, 0.038792953465975104, 0.02169341517371997, 0.13800303271460918, 0.09434830142004837, 0.039951362677158854, 0.04826367712549625, 0.057167143320604685, 0.031693392590950095, 0.02774368648627593, 0.03220962668438593, 0.07068491796211851, 0.02295316249552754, 0.05348100402061978, 0.01814150213894825, 0.08363665321901922, 0.07714423426096478, 0.03645475736008056, 0.07810847848773965, 0.06389989938226438, 0.06228849472057435, 0.05022773504137032, 0.054575762816614685, 0.036726902434301954, 0.025761227138460647, 0.07420114662137724, 0.012243508995931235, 0.024844511006508144, 0.05695464968260738, 0.035128804719856674, 0.03688792645510647, 0.0725377322505078, 0.019389196982487075, 0.0803373959816752, 0.042041721678669416, 0.02885399686713373, 0.05823894629194852, 0.009703403714323237, 0.05602419376373292, 0.029338080165607315, 0.03198387589485895, 0.03614746034145355, 0.06474795105356364, 0.014009043844717165, 0.036462613591744054, 0.02674416391058795, 0.039255088345418056, 0.05460183278867795, 0.04356240620836616, 0.06797361788490126, 0.031316370079894705, 0.01921368815425423, 0.05757318907267144, 0.09051060694600306, 0.02309304823528134, 0.04284481931057188, 0.06678188384901132, 0.030659836559225957, 0.048733419258027315, 0.06718119185778403, 0.036970411141913746, 0.02980060383467184, 0.07424983150896526, 0.09325513225649634, 0.03556259434610125, 0.026839396300455256, 0.05597640136857668, 0.011704485701967873, 0.008001070161680541, 0.012004314320943048, 0.03812827260023163, 0.024247148201891014, 0.05511502359783458, 0.028343820613959146, 0.10109120048582555, 0.03641405127822392, 0.08748295852133343, 0.057641014667047616, 0.07930238821333455, 0.46961192822744774, 0.8200873783038509, 0.6715046253896529, 0.7388333964251703, 1.0791852397303427, 1.8868991948904532, 1.9240537237736488, 2.4256596594087543, 1.6526844208278966, 2.531184164747115, 3.074030390670223, 3.0611351084324623, 3.013976942146978, 5.119067170927602, 6.913240676926029, 5.988076127344563, 5.719459470241301, 2.9884160814746736, 2.257449304865253, 1.4649426240113474, 0.6632713865368598, 0.12356060527024731, 0.11740035437528165, 0.021653846732430884, 0.018960141779614553, 0.09277530840688175, 0.05997688569609196, 0.022615478599383947, 0.04720962441135799, 0.029093338056437434, 0.0720760723455779, 0.023661269055258845, 0.07335038299882606, 0.04407100815085634, 0.0512344894870635, 0.01958122458158722, 0.1044521737663496, 0.009158351308395787, 0.014054746735059928, 0.01725958363573638, 0.040804087484796206, 0.033400223079708316, 0.053384323724575584, 0.028528972573938872, 0.04404909037534268, 0.011774543485033416, 0.049548801109795614, 0.033782068114247055, 0.08087738837686279, 0.03538539437877555, 0.05371608959150411, 0.022394914225104357, 0.020670615016452728, 0.029253454263051672, 0.015019067570627218, 0.03728854830466932, 0.0492527426010178, 0.0530282422269304, 0.0777214049031177, 0.04223445790909952, 0.021108983933264693, 0.02245682370548527, 0.10227342737057518, 0.039900348882281014, 0.04828790848654124, 0.06043490668338153, 0.02435131892261486, 0.022782840082542073, 0.04229266526958635, 0.07388054648594511, 0.04143885644753614, 0.02966228091428357, 0.08692946765692004, 0.04352314420224678, 0.034153919531813556, 0.03255423601536501, 0.0522585345372077, 0.052449765404866594, 0.01903456339101878, 0.009109674081687004, 0.03387396802164374, 0.04346146263302334, 0.05590998154554156, 0.03889112380303202, 0.03290720719603762, 0.007237122016733573, 0.023043758138233138, 0.04092803668050517, 0.023385915987854524, 0.04148879005844074, 0.02942481089473492, 0.03151778034084747, 0.026791341520184954, 0.026316713661916798, 0.03650733397432393, 0.08126888228880783, 0.06517419471375405, 0.027710409542064995, 0.03093986276296839, 0.030560674138307094, 0.036262277769105095, 0.06675872501106032, 0.06466854604021197, 0.04821879203401266, 0.05646129288981038, 0.05918525256997636, 0.018740801230794, 0.040782353570384365, 0.0990381231531501, 0.004520625469364947, 0.06148106103102046, 0.05055756270585041, 0.0471573120974485, 0.06604183525327714, 0.01265985192731023, 0.026430290027130997, 0.023105589094601815, 0.017138386610895395, 0.031778853529343204, 0.03966366218763494, 0.006219655746639136, 0.020206122501422803, 0.10156351667378219, 0.04612020524819532, 0.013879718626999568, 0.02773617690939817, 0.08669404883778865, 0.0250463483614787, 0.0346803751533791, 0.0488266981236877, 0.009640499277250662, 0.0696448003873229, 0.025745279103096937, 0.06905771656742982, 0.008262193145891352, 0.06391806332694908, 0.02529815763175007, 0.03617154614579293, 0.06398134985037389, 0.0214757542726734, 0.06421646223433557, 0.056958874657509796, 0.0344794073082026, 0.010474732637615695, 0.0234813935258576, 0.03423144379931112, 0.013907691369944764, 0.07218419033433161, 0.04418841878613157, 0.07202925671252512, 0.0951841799542308, 0.050240555522783156, 0.03180821001860163, 0.06084539957584874, 0.03106586698953423, 0.07322315111636155, 0.04345367534927303, 0.022992374705931833, 0.03007242140630561, 0.028133782287759167, 0.05196528374067238, 0.02055575736918517, 0.042176560814222025, 0.009984291766980484, 0.023103323389565753, 0.100424466504445, 0.03286637470967347, 0.04810061531081315, 0.03688134959027652, 0.07658325871753116, 0.054769858853110386, 0.039441753329048236, 0.05084269297038836, 0.035305813165201295, 0.037212176999497804, 0.248755153508917, 0.7905900514414235, 1.1374065736609122, 1.235918126279308, 1.6380679535288967, 1.9445466370351854, 2.96887164635043, 3.1146484949896416, 3.830017966608848, 3.26011547638524, 4.084701139119364, 4.881390169743569, 4.855783956666147, 4.961236388452591, 6.6006081623415795, 8.647574993871874, 7.322025683618362, 7.693010318663813, 4.073122547518823, 3.3444361388683324, 2.0334929996921174, 0.8093827398073289, 0.08679545589632566, 0.12368461192255059, 0.02870121020673504, 0.032577103739904786, 0.01414853792201968, 0.09244308671763829, 0.022020735815467856, 0.04301316330149289, 0.029467464755139047, 0.024152404193075436, 0.06541866103127118, 0.07203905497707667, 0.0014167005429044368, 0.06150530771382394, 0.09076330870870622, 0.04392556635843169, 0.014125016149914554, 0.04411871627634091, 0.07374269662485008, 0.018041922200110652, 0.05876539425263482, 0.06792734617427473, 0.03935076889672107, 0.0122371849401163, 0.032800579248296644, 0.09025091080055123, 0.052072015110283136, 0.019144462534196435, 0.006924351778692536, 0.04706671070908347, 0.016969010316496416, 0.004342673778263552, 0.03745174418473917, 0.08983033619100049, 0.04578055633652595, 0.047807448783949505, 0.017284586830365083, 0.09152516782764467, 0.03167945745160743, 0.034606842203967036, 0.062289509787074024, 0.040360231463226585, 0.04866200454172589, 0.04736726615397681, 0.006981286954420109, 0.0562975186133577, 0.07092563044880668, 0.04976222937506053, 0.03503845614050666, 0.021730273578976913, 0.05768572738874824, 0.04933092187369063, 0.03848133188101553, 0.06636058145593252, 0.10341502861270022, 0.039246171081979433, 0.01586275254075806, 0.03389687405057973, 0.015940411831252277, 0.07055197106373888, 0.046083015509911125, 0.035609134187501286, 0.05869224817762452, 0.03281657899459524, 0.05656981690516395, 0.030758213740022435, 0.08112722497072913, 0.04492587417424206, 0.03772799549023471, 0.018679924053891052, 0.022386598340686292, 0.025576691879259966, 0.17216232635321158, 0.10614256209303295, 0.13580040735823495, 0.08533612734848454, 0.1662863553651879, 0.1636268045272558, 0.1303066376356348, 0.1982963893322214, 0.16292253989846478, 0.1110270391068151, 0.30053696685260345, 0.18469710293556416, 0.11507168457272554, 0.14570534199235902, 0.18927234855871047, 0.2710304162915676, 0.11047032301224048, 0.15381726316146313, 0.11062786133298952, 0.21807412887292527, 0.184275632003142, 0.09986722947008188, 0.26196146744393534, 0.12290638150467027, 0.15699639015140074, 0.1648321825890772, 0.15275310574760362, 0.08985746336439926, 0.12561683122429157, 0.2415802804452758, 0.09727631244928607, 0.11969430507310938, 0.1896612760761092, 0.20087766130605053, 0.24095385034959163, 0.21238707516702915, 0.15272730390631384, 0.06669702428963876, 0.25973852543580916, 0.13812001434064683, 0.10939272075530984, 0.08072009520424951, 0.0899627238451954, 0.11519560695535715, 0.1314337521551117, 0.22393595787786671, 0.10487349914206613, 0.1697512637943991, 0.12699709183746768, 0.16275400055512307, 0.11326943208733875, 0.12152494877697, 0.16664494580078512, 0.11648834968406348, 0.15856201339873577, 0.16019436290427563, 0.2742207434869582, 0.2480954292320436, 0.11247391872588666, 0.14054987669712113, 0.16022489916893745, 0.09778751526027919, 0.15627836658348962, 0.11350566295966988, 0.12227191514666043, 0.11958470853466181, 0.1465689682311589, 0.15085308512132015, 0.10729193912758943, 0.11518514985519072, 0.13929553029517974, 0.1560856648270161, 0.21006854070771128, 0.14079381441397054, 0.12817675232767098, 0.15285254396017522, 0.166975665957697, 0.2380556478014877, 0.24043612813036289, 0.2303678788725407, 0.18663916646713213, 0.16578470567061057, 0.2654928569832156, 0.7056379486476222, 1.2040093997793815, 1.117292169121004, 1.7832436989392004, 1.814752466255619, 2.7808462131407956, 3.0740904519634866, 3.43921898834167, 3.1567463134565665, 4.191879658929763, 4.729554239780673, 5.637813864215728, 5.850344059928771, 7.141243152080044, 8.856995240334543, 8.01771245656475, 8.305262884786053, 5.3142546069237495, 4.244412943240135, 2.3670770997001283, 1.121985407606248, 0.30869905145898946, 0.3043399192392826, 0.09526782143380373, 0.107875851343476, 0.1431112150631605, 0.23036360410192322, 0.11373584939827842, 0.11740079870627773, 0.08899657205948908, 0.15713906636641872, 0.13460114267804932, 0.15595020516024483, 0.06657732305146995, 0.1785909378480527, 0.16137066026849134, 0.1709108297983485, 0.09764363628722007, 0.14181919245710298, 0.2578229072593874, 0.1360442837880504, 0.14247427424115522, 0.14774189480850775, 0.14384600063485486, 0.19765964769307645, 0.17090128434281196, 0.16253598725363133, 0.1573271409518296, 0.2220135981277112, 0.10318229876218304, 0.16243631921468243, 0.09147927916098027, 0.13398454915131294, 0.1637478617410506, 0.16196398004408807, 0.10596490630339231, 0.14485634803291292, 0.16543955241720523, 0.15187241106985078, 0.20844936791446902, 0.16055004220576058, 0.1909486408675871, 0.20991478686130818, 0.1566846842967695, 0.1250201942879827, 0.1364409947587598, 0.14611801823541043, 0.18638379871845248, 0.14396714977920055, 0.19569375882706336, 0.08541663552844718, 0.12454837605717684, 0.17939393588852498, 0.11522100277004704, 0.10250572821185475, 0.12556417800125577, 0.11533026989068716, 0.10703962040884842, 0.2020518595893537, 0.09180431494549399, 0.12983383881228586, 0.16097456216812134, 0.15357361655802498, 0.10429643575222262, 0.08877425334386288, 0.1527611037055331, 0.11881402408283566, 0.17456617236377733, 0.06232656162953185, 0.15074647632577728, 0.22899736289776143, 0.09371617929108682, 0.17893466617791884], [0.04986274394116575, 0.03279183052420136, 0.01844589185390261, 0.06831078084125634, 0.018623819604756373, 0.024770077903785055, 0.06156278346034308, 0.049137097798408046, 0.04097586354961799, 0.011587269461503433, 0.05661328090354801, 0.04826251650229097, 0.044519426226015055, 0.03684708247742346, 0.05375283882923184, 0.0680414013444416, 0.03169154440383277, 0.033222268515777205, 0.012876001719926155, 0.012394173592779667, 0.02454964184923278, 0.01750113115826201, 0.0246666043230723, 0.02096057546535327, 0.03847230353482789, 0.07543315389944662, 0.007739209817842611, 0.08716562192045874, 0.007458692360218735, 0.03741897094333845, 0.018362217815592885, 0.05530356166643962, 0.0477117873848446, 0.025946197152558356, 0.05271544852744668, 0.027343505137269537, 0.019047665409743786, 0.0331775059983615, 0.026174410914761886, 0.004998204681361395, 0.009808438199181712, 0.04035011144174684, 0.01576635090919632, 0.05553860893292774, 0.03992223984471733, 0.05661563279347555, 0.07264781908522691, 0.04396686232799003, 0.06893064556342941, 0.08133042979264453, 0.02688651836867775, 0.011123837978248636, 0.044819832283763156, 0.0066394499041170126, 0.05373979618232097, 0.0469884509971786, 0.015607796564337709, 0.008406472399890905, 0.03238177047141137, 0.054698264106146754, 0.022746929711091424, 0.10289658627082264, 0.09379323241451094, 0.04583145138777552, 0.023408214892110518, 0.06942202967982139, 0.03483386086900869, 0.06272878460285645, 0.04491317243645749, 0.02368329408308191, 0.03630695984728875, 0.025266587148390474, 0.05995240535647158, 0.028973437635408297, 0.0449623552811963, 0.062106472229765314, 0.04962524902375956, 0.03037292705548387, 0.052560580023113763, 0.036724906775259206, 0.045236415575228395, 0.013996070145719476, 0.040102193898130814, 0.05930208097842913, 0.023573132554790186, 0.050106777419005676, 0.02252981847813053, 0.0398432715014825, 0.0254963752212784, 0.08248788139392292, 0.07831118535250425, 0.037539867278669155, 0.012594991093201023, 0.06507771360057016, 0.08436208485715813, 0.022255585814315467, 0.24767803388737866, 0.18520498858584514, 0.20769091022591438, 0.15748728397152117, 0.10370716092086608, 0.07287009183557765, 0.06704482820726211, 0.018640932093764988, 0.017802548452070164, 0.01378748547135582, 0.020773964107877785, 0.017480975384974194, 0.022701466223225, 0.02725583211999507, 0.05883426172658802, 0.0628606245041855, 0.01071938185862476, 0.05975819823722686, 0.07171323778288019, 0.05265258718281985, 0.024892127201441797, 0.08963543576218429, 0.033261178121451414, 0.04416277016242666, 0.01167918756348832, 0.015313895550676653, 0.06382358936412681, 0.013674060408506664, 0.03848724224935136, 0.011449709756209726, 0.0389249082804928, 0.04411794252753739, 0.024132353756877205, 0.02932771116555218, 0.04523946077472741, 0.018695699719471798, 0.032206470402137886, 0.12398909356805587, 0.05651583068913991, 0.023658426869059765, 0.09109706257379825, 0.05339212249964476, 0.08010262833727945, 0.03346983365894806, 0.03896836844843723, 0.06531422026455402, 0.01779210092800279, 0.010858898918565002, 0.04352866769618085, 0.03449669791265361, 0.04478602482366466, 0.05604439550229619, 0.08526538678955647, 0.04254490737953494, 0.025826266088012247, 0.024173818265778885, 0.10098470660347132, 0.019566684232784376, 0.06017267095646071, 0.08953710071622364, 0.0235400069129443, 0.05663100817811586, 0.055389899775506034, 0.03864678005958277, 0.0410855750012542, 0.05984362470166338, 0.023440187571630366, 0.05311988166443283, 0.020380826937335155, 0.03554236962490025, 0.025183104632061817, 0.09660354935594144, 0.06603456507887571, 0.03442216138806074, 0.03394217665998205, 0.007199911689836413, 0.010219200180032322, 0.02492111788371638, 0.05256195132049823, 0.03599410486077109, 0.08389173751516689, 0.058726771929932226, 0.02584339389877935, 0.022350308755713127, 0.012248709775327195, 0.01946530207210491, 0.029608264054742553, 0.05449278400309625, 0.03771327511076966, 0.029278348290151166, 0.028868950903415683, 0.012677598354076187, 0.03319768092384742, 0.01343533879281172, 0.0025612241710581247, 0.012559534628845513, 0.028022381612249923, 0.09987646082956946, 0.03135046673818462, 0.061332202486453526, 0.009791475097318331, 0.027405232671768438, 0.01155094636018358, 0.034454486468025756, 0.11279130129203682, 0.0459523783666232, 0.04103761789719424, 0.009133281081073709, 0.030794786777527585, 0.038939463951054125, 0.0136304690480052, 0.030491772190397306, 0.054574395349669846, 0.02606194346181808, 0.1007199312950815, 0.06422468618820272, 0.03667458245951322, 0.03619676959069987, 0.028657684921317046, 0.01506504433740291, 0.09992798790335657, 0.0067363269889967586, 0.023543686050200657, 0.03227208966329213, 0.05800397563425284, 0.03566405120035333, 0.1032857895798741, 0.05730652152710865, 0.009339949578016756, 0.04524951950917321, 0.03452286364570741, 0.03607017739165214, 0.01441469697672273, 0.03341688932250104, 0.018017100951363964, 0.03767667909062678, 0.00807871700324599, 0.023974286835460414, 0.02465628128829262, 0.09208057391186876, 0.040622482511905894, 0.04345033520592317, 0.06760230272888176, 0.055573611490188114, 0.07123725969464549, 0.05275763698943681, 0.04104691820459501, 0.03475034962438288, 0.059269805694179195, 0.05634552168269312, 0.0751712973860483, 0.08600727399630893, 0.09421797454236977, 0.05008747583375343, 0.023581668689486482, 0.036547124581111055, 0.0375757776501198, 0.10937303229565583, 0.07796852188485284, 0.051499816378758806, 0.0027056482635558613, 0.038292862760323676, 0.030651340644145687, 0.06927158533325119, 0.03829630249510369, 0.0443578582827843, 0.10722705148040287, 0.010672637088704976, 0.012790132839713367, 0.08606309882335125, 0.17276244898957593, 0.08593959012819875, 0.055497527467988195, 0.11930324783128117, 0.10591090476560978, 0.1842855451808822, 0.2337943450097115, 0.38346527985507445, 0.4293745696063965, 0.33467752198057793, 0.1691616365625974, 0.0739547650840494, 0.13277747037429966, 0.026782908807358435, 0.017632856146402417, 0.0204427594003538, 0.018192324411845016, 0.03588590643278534, 0.036744813569971634, 0.0415560947130284, 0.05222000031461639, 0.05256612266924593, 0.04404937382787467, 0.07126834754261278, 0.03571674272778534, 0.07848073593190602, 0.04506934329026169, 0.04004610860119424, 0.014957300774122198, 0.026986310896914334, 0.019981528504661495, 0.04457301407631847, 0.06745511425598975, 0.042861382131494825, 0.01645999468652712, 0.034157267336042664, 0.07932393826664456, 0.03144337596642154, 0.03496998703227409, 0.013406609538041297, 0.06968921050429344, 0.059144243883389624, 0.06867015268653631, 0.060569439383764426, 0.09399732589841851, 0.05146784369923896, 0.04577263881782851, 0.0585316876400142, 0.12431988267288094, 0.03134073550632644, 0.013606838108370862, 0.058565154190986395, 0.02953248646771235, 0.023694120820671804, 0.034400124868918816, 0.004668131868745531, 0.03595646696105119, 0.10936577744301289, 0.0833765127425713, 0.01165048895223487, 0.021877247547250123, 0.02881878938135361, 0.02058091569661854, 0.030777036520322005, 0.06977971613166795, 0.05643698108953334, 0.016492901993314588, 0.046519306413228476, 0.03452169536162288, 0.03517376258969307, 0.03606688321357773, 0.04663209753832029, 0.0738906205421494, 0.07652740324697188, 0.03255265787424099, 0.008871342213223539, 0.043913075294826305, 0.012352020562356038, 0.013089408917773156, 0.0006857108171736342, 0.06924158533013637, 0.023399334017848297, 0.036544171312162956, 0.04269300749705684, 0.10144518673299782, 0.05599377241225974, 0.19742341682074532, 0.16314813747040688, 0.07110708603455175, 0.10871205163458664, 0.1154296238335871, 0.17278518647916857, 0.1579324116990451, 0.17791863440746264, 0.09196913110152369, 0.10056553393482201, 0.21425147270483358, 0.06770056116604997, 0.17324540613880082, 0.13913505019680147, 0.23595555565289913, 0.16528448089957237, 0.15081190023451083, 0.1266573165212908, 0.1667279897317771, 0.2598365846901171, 0.09769701729378394, 0.19362106198264709, 0.09684511220022556, 0.06820743558027091, 0.1751507280935203, 0.1068313287631158, 0.15405603744570287, 0.20591254436200668, 0.11793227986462655, 0.11002537148493914, 0.13879098478824864, 0.17712136670466394, 0.0735525765846814, 0.10045222186994168, 0.14684287530760612, 0.14374429480202738, 0.11104127302044824, 0.09361653423477566, 0.14715142487998933, 0.10940680911223735, 0.1597983107691811, 0.12754195655185369, 0.23028310358283982, 0.13269286362394211, 0.23206670948814964, 0.12063403448630726, 0.26589119206032447, 0.18720719001946912, 0.10100762029328655, 0.1873162349746112, 0.07902795253621955, 0.09317522162511464, 0.11258792026989883, 0.16432149305699334, 0.1748046861781228, 0.17093540589895942, 0.10998972541382236, 0.12481661408298439, 0.0972697317540165, 0.13260347648493706, 0.0906963679458826, 0.17201022725672493, 0.2363682931829845, 0.16240743769993707, 0.19887418816647223, 0.17388548792129563, 0.2086771411761161, 0.15413335103902126, 0.20616478647195524, 0.08930921254138793, 0.2452258324070323, 0.20628820323655683, 0.1544443214492452, 0.1135149556061914, 0.08543675299733879, 0.12905753127509548, 0.13776514709236162, 0.20082965823671511, 0.123929591518977, 0.16680816849393232, 0.10790678597385846, 0.10735506477255015, 0.16024498599431208, 0.1439308218898312, 0.08914788974629295, 0.19034085735197992, 0.09644755087192021, 0.10177838901478438, 0.13886966201807224, 0.2290218930330969, 0.29162166459906486, 0.15013996451612444, 0.13120614743280795, 0.18557442682645015, 0.18231129063473595, 0.3209354674383518, 0.4422582379512249, 0.6880987639869414, 0.6343841108102953, 0.5084529230671545, 0.34790599117836646, 0.1114071949174808, 0.19929870812883302, 0.08631147985016147, 0.16982476226985457, 0.12296295709787838, 0.09817156279760023, 0.09624839865512426, 0.24234319676554975, 0.13109800646141653, 0.14096403915074565, 0.13489466160535812, 0.10163380524083492, 0.2768139511106476, 0.1299331391290311, 0.15341747251729812, 0.0778394743740078, 0.14018278268556442, 0.09063575506931351, 0.13253351733569177, 0.13100555497071437, 0.12557837361049268, 0.1214223083168749, 0.0948634802273685, 0.1930426655998153, 0.08423480700941817, 0.18814304302777016, 0.08373909449625401, 0.14685994374655909, 0.15980583375259755, 0.1885920778037079, 0.16832940460693452, 0.17582211222860122, 0.23651646990929884, 0.19301315589297205, 0.14453423870426996, 0.1925091619693464, 0.11562931231193005, 0.35851842333232203, 0.11331607918104819, 0.09909823807256837, 0.12797612156118118, 0.059300832255112554, 0.09068761922178731, 0.13162637730279278, 0.06517141381458891, 0.15052110858021245, 0.16383174836875933, 0.2741648190684857, 0.12416241330004509, 0.13346258280498366, 0.1433688657538545, 0.14571381492480157, 0.1148890721942148, 0.29664447410933437, 0.22960522302216102, 0.09188096204231824, 0.24301165444475992, 0.14670830430282703, 0.127347324253811, 0.12293219866771853, 0.21296873508441835, 0.07342749740928411, 0.17856498278917807, 0.11299917158941108, 0.08361439070393963, 0.10608626995235683, 0.18205174004598973, 0.12379882797118157, 0.17163541107889146, 0.16907794911774898, 0.10132753861046608, 0.13042527401158888, 0.13907649043586948, 0.1374595852628831, 0.20124791159985528], [0.04181590577166888, 0.05156496449583962, 0.0361597637135175, 0.08949135760626487, 0.011614543149217723, 0.008422155177310832, 0.012351294694047783, 0.06106741568674484, 0.043393357416554805, 0.01508685390299727, 0.052723220489438505, 0.01432707183994353, 0.053563530842262896, 0.039597579443286506, 0.03663325201599829, 0.02353560956825893, 0.03892098591032048, 0.0381082394010117, 0.07329285745659182, 0.010050531559353395, 0.01484749068866574, 0.041048255028022874, 0.03794542273446437, 0.015116499590447113, 0.07639830210997213, 0.0032936027902554003, 0.004797010361442282, 0.08186542729456579, 0.017698320274751995, 0.02863715568016614, 0.09294446828144212, 0.058471932781920324, 0.02471380300008722, 0.05291967990718061, 0.0638159629588406, 0.020906164070531245, 0.020338278414020618, 0.019228510040369247, 0.05217080597855872, 0.03074652898395735, 0.03899159240386179, 0.09690778585331095, 0.049830537604829, 0.02245228080409429, 0.027475337377719344, 0.0337527422685056, 0.05067062962259497, 0.06641991496566804, 0.038836291059851646, 0.012027154274795566, 0.04211633864249434, 0.01701515945305507, 0.024819544201055845, 0.03832785382626518, 0.04106474124015339, 0.01355315641229672, 0.08718128075763103, 0.02161633332199868, 0.017238048904184854, 0.04031195643267805, 0.011964658737152576, 0.05733164155014581, 0.051307827084054874, 0.02390486969342155, 0.038896019104868174, 0.03325036862083981, 0.028149852897190762, 0.018691128089783654, 0.03324161223586529, 0.004557944484986365, 0.11803330387920143, 0.032554163237012206, 0.02203314452462139, 0.03827161531174376, 0.08229783030166742, 0.03827326623122058, 0.05220241093587491, 0.0018230692489117745, 0.01953359114967527, 0.04376446955927438, 0.020727656008074843, 0.019992020078784516, 0.029812079831777565, 0.03183822917391456, 0.03576237092455549, 0.05633367796338374, 0.010884574355347263, 0.022111247188501784, 0.04899312306435839, 0.008943556533795933, 0.0297404793391545, 0.05999909458501686, 0.025307396652116895, 0.03526349829870366, 0.056748755892077764, 0.020593077342416492, 0.060005410979952545, 0.04724897834802828, 0.02932167439270885, 0.01634290389296028, 0.004963758495456029, 0.054415240583400575, 0.02004806898654469, 0.04649365395908395, 0.07910383354511955, 0.04665737843982155, 0.052100892794588884, 0.04757864513404427, 0.049119075579989346, 0.030041580621693886, 0.018664661667219574, 0.007639207573036754, 0.03077210482930945, 0.02186735543692785, 0.0480037817971841, 0.0194175862857411, 0.04272027256628198, 0.07029644243659512, 0.02419598310464813, 0.011119827507965026, 0.03105409221813804, 0.028769062614188563, 0.045062096098498, 0.0594504262440868, 0.027762712279875434, 0.10912848936934626, 0.030222333321768432, 0.01956289018233938, 0.0326492500701739, 0.09896798780368221, 0.07428962977663164, 0.05235791146274536, 0.06691366629374605, 0.055239957216526234, 0.040207052182766705, 0.051935862133940386, 0.05244521867303599, 0.03364396161369739, 0.01169422108139242, 0.039452321511963685, 0.019210449517554334, 0.03741348958424023, 0.02987341283099546, 0.012232016719457124, 0.046979108554941994, 0.10087333274103942, 0.03412771166392392, 0.023981219931175152, 0.09656158305944935, 0.00197339030320666, 0.07459556698919305, 0.0250348761948126, 0.08742642889340078, 0.024550176195559964, 0.019536230322574417, 0.0664371442830851, 0.03637725990566035, 0.025215556116534338, 0.00938152708488727, 0.013037992926735072, 0.025922563340094303, 0.017863404561555194, 0.0513838421583416, 0.06303383698386532, 0.06270930681738161, 0.06545511149470845, 0.06643092364913995, 0.03945894434206909, 0.01845473825420824, 0.047109060049537695, 0.047529320563039476, 0.03142717895248244, 0.07780156068263516, 0.04447810727381899, 0.035630021574756796, 0.02429316518828273, 0.01969301213149823, 0.040331717670684865, 0.04385248157045534, 0.050866847722640926, 0.04966472553449774, 0.02861934413592662, 0.02805963072234825, 0.04478956414987484, 0.05850727241786738, 0.024884993007646936, 0.06281153358999761, 0.01755430915152594, 0.03942617110066837, 0.0353660200151705, 0.0275589999247102, 0.04627184086148778, 0.036277990232432084, 0.03205408593789945, 0.08944156189118663, 0.015900088793357775, 0.07800798307383254, 0.09468053077017108, 0.045006864989596995, 0.03853634465485811, 0.07115452985970244, 0.005715277342636499, 0.028532343360805706, 0.042589110652765924, 0.010712759028519354, 0.06469087750320474, 0.04365409544158367, 0.04996915355384831, 0.04309879660966896, 0.03352423356245122, 0.03137527458039263, 0.03707207100946577, 0.029881416534584378, 0.04077192328329529, 0.035475011344157883, 0.02390379717032756, 0.08227120874629867, 0.0855614491287739, 0.0700277830624292, 0.02307345362139806, 0.06910519869697672, 0.017488389200861418, 0.024315845221281055, 0.02862967483158554, 0.006617173503693795, 0.01895532500179064, 0.05078046747873868, 0.024141564048946868, 0.07170736188850096, 0.008095836195523941, 0.047128668069959655, 0.014547600782656623, 0.02741750540031541, 0.016917870117111072, 0.002652036951809761, 0.017897736791881825, 0.013543632024178102, 0.05327939266158689, 0.0220527621211424, 0.015977131383072947, 0.015327315495890236, 0.01965147675946355, 0.011190920467338255, 0.030686400658000382, 0.012704624978434897, 0.043551370711816896, 0.019830318070167018, 0.03781531036140458, 0.05234142142017523, 0.032976948010224494, 0.09040546903927481, 0.022992928204457128, 0.04051679302187216, 0.04481700924976219, 0.004426928606980871, 0.052449110399691336, 0.02837666663371267, 0.04708802710557657, 0.04733193800934861, 0.08423224827575107, 0.032476983709080566, 0.09395883764110266, 0.05625557529950335, 0.018311523862423438, 0.030487669789562785, 0.03318764517203935, 0.05022896461248879, 0.023916652125696984, 0.09886052865054339, 0.032258974238028454, 0.05985010963594241, 0.0502181742640753, 0.024810146217444734, 0.029587022351822066, 0.007262401003015018, 0.016069257286407294, 0.0453491875481221, 0.048826740258523536, 0.04930449567074257, 0.03127966680744242, 0.05290291790339736, 0.03266547581241016, 0.06616728215087807, 0.012111420116026797, 0.0214622060077325, 0.021017248734771725, 0.0210467029002405, 0.024228932546271433, 0.00720056813142653, 0.035703818824502735, 0.0342653738334775, 0.04219351433998635, 0.011873055688826548, 0.047280138974348386, 0.050918493540056294, 0.019935938612287565, 0.02811881867537816, 0.012393253329660625, 0.03466200053451523, 0.057349200285370314, 0.06720673322917954, 0.04334833825968447, 0.046473988482067664, 0.05267871844191706, 0.03952182100845441, 0.11357768288543148, 0.08807440904239494, 0.04358278414715202, 0.034512774267744635, 0.04722071353406195, 0.030492398467275406, 0.054868530977757714, 0.07785127978892097, 0.03349720215004298, 0.021927897450363925, 0.004321188842427106, 0.02614994398168018, 0.03995368392356942, 0.02273181479634537, 0.028074335780054815, 0.027598330878742763, 0.03557685890325135, 0.03486106465119989, 0.02305316761316311, 0.017624563244622082, 0.08140954369258496, 0.01676419479472022, 0.03085073992429722, 0.020509610147846323, 0.04469449263847163, 0.04605008905092555, 0.053654047960956255, 0.028211923256035776, 0.0859995901344284, 0.03367551294485888, 0.03635063451985198, 0.025628402814148896, 0.03534736960465389, 0.022654656335831653, 0.04201994562942175, 0.03585577619472339, 0.03838829050261167, 0.025873313462662122, 0.015386289901911251, 0.05482053173886192, 0.035749152077422026, 0.0386348482401621, 0.03677385213274149, 0.08434652561141599, 0.029324857488034234, 0.07485406037660376, 0.03458275256918804, 0.10310064145033399, 0.15525740120680104, 0.10239344270479295, 0.14921431579897482, 0.13411167378146804, 0.180590657156802, 0.1122605555780953, 0.12616600901369127, 0.1083367758039986, 0.120580009965887, 0.1297015660712796, 0.10775958984008721, 0.1605494599789381, 0.14102077562241785, 0.17611829714188654, 0.0735182864891906, 0.1290727304595132, 0.13340534071528143, 0.156948187899205, 0.05928803475633745, 0.1030892803664169, 0.2134613449414892, 0.09343153166194117, 0.09863072525589697, 0.24408293647631524, 0.09976077389212386, 0.1314632465401965, 0.2030270282299288, 0.11630756059481252, 0.1823288187264435, 0.14139128638611687, 0.11996861817615649, 0.12495068713061272, 0.18084934972707303, 0.13253900252522963, 0.14595533180381023, 0.13771774157160713, 0.11876897045200872, 0.08596164579953879, 0.07893925487634637, 0.1970682584590489, 0.17199988506974714, 0.13024588686323937, 0.10915147966795391, 0.12282061030066783, 0.11377528760462038, 0.09661992831576256, 0.17539287316462687, 0.12257490292071335, 0.18617672515251946, 0.11952808697617824, 0.15610927565684243, 0.13467412021371628, 0.16089288187363457, 0.22368587613586458, 0.2526895206181273, 0.14051324237258206, 0.15339404554857364, 0.09395006593436965, 0.16471843385408003, 0.08133274337817585, 0.13853912572226218, 0.16351192198213071, 0.1044060169689117, 0.08656329295087246, 0.1058927254991666, 0.19055632724156304, 0.11229204179178323, 0.08457510326538356, 0.14489192515611649, 0.23436132668247148, 0.10394368290660844, 0.0823843599327149, 0.10032759468641975, 0.22667501332058063, 0.20827517484224614, 0.15893502160906792, 0.11796023441298355, 0.10916036628787557, 0.10826576711429704, 0.19979746201105658, 0.11935095978720535, 0.19873094504639027, 0.1243574056594122, 0.1455627883514089, 0.2152661101952676, 0.15450326425413932, 0.13558709783659828, 0.21392632966801045, 0.08838109702112214, 0.17253459911913643, 0.20015557747214072, 0.15665502137234136, 0.17655686715677862, 0.17875834338126645, 0.21054141613985264, 0.12213258673587155, 0.095787926186477, 0.1295143801478609, 0.12129295437086014, 0.09762005610091072, 0.12945813397246023, 0.19315549502930335, 0.11583437872750145, 0.2609124479274596, 0.20190101687706288, 0.11945617430272604, 0.10379025081713354, 0.13701634211165292, 0.10842697499620338, 0.0981539274535833, 0.08885258583412056, 0.11303116342112904, 0.10283819504923399, 0.13290271042816101, 0.08777581861302738, 0.16904436382314852, 0.12984419632102215, 0.11877896023854134, 0.08770208265031539, 0.10608797066754873, 0.15878281526027188, 0.10960480453626764, 0.11839305110756429, 0.1326766072381889, 0.11448196541037291, 0.14420088320489854, 0.1779171788404065, 0.09537836026039817, 0.28671462629591266, 0.1851114492502905, 0.15861793781720823, 0.16343168193294158, 0.1389241155477301, 0.1056746662323994, 0.18876593379724413, 0.18437689350497338, 0.14222547952686587, 0.12493286792549396, 0.16142220266403692, 0.08152744462413174, 0.13102889000888795, 0.07112918001028799, 0.12950265900261942, 0.20911702886223796, 0.21358457784498894, 0.1331137523295418, 0.0903827928367161, 0.11816084985771488, 0.1692078010209145, 0.15465743178802152, 0.17074425164009296, 0.133302531715843, 0.13051818515504562, 0.09283083445963361, 0.161921477486049, 0.09941562829959778, 0.22546336865953862, 0.14516037768654286, 0.10572341240702138, 0.12498921369232478, 0.12953788372537783, 0.11574680721687695, 0.12153533692922323, 0.14194372771007402, 0.1470003676630797, 0.14992398900851128, 0.14494093946151196, 0.10013214267429807, 0.14080797171881124, 0.15296037849639693, 0.09899002815326376, 0.1546424317864641, 0.06442590301195461, 0.11104026944526743, 0.1380236558015308], [0.04899093205289495, 0.03635951347889439, 0.08298693405043694, 0.03719906157423412, 0.019201306258178046, 0.027538729238233743, 0.0324516645031831, 0.06625932761498037, 0.06679715198134223, 0.005419330874217614, 0.030821067423770027, 0.02624313666244909, 0.02752981772045455, 0.003313330511915528, 0.029623396206466906, 0.047489441856141054, 0.04029685300925086, 0.07449828914456791, 0.032527112672405864, 0.04789487090742877, 0.06954252764943146, 0.07082295934519461, 0.07852791162628321, 0.05614294122243601, 0.01494132401046133, 0.03834635868007618, 0.04472049366262171, 0.023518196389740034, 0.027385390994529572, 0.06550386533020966, 0.055597601533536954, 0.04319516664010383, 0.025700392096393535, 0.07490781676625052, 0.032074448554926825, 0.02144565276290861, 0.02670376234868121, 0.0760724772548964, 0.002485071440347501, 0.029015637588717287, 0.04437896017465861, 0.04133880919506473, 0.08419158432873027, 0.006848939519841225, 0.038186430165003386, 0.1427253365757004, 0.01709193295438684, 0.0465706228128364, 0.03304935481038786, 0.07598115957432217, 0.03770147735673574, 0.049100084260346434, 0.004733489223590662, 0.06678979753726913, 0.012118520793474972, 0.05988977000778241, 0.05822905226640644, 0.007567698532159651, 0.04233197324098118, 0.005671327357225481, 0.040455620901118365, 0.015972868103774327, 0.055575691418902534, 0.014467149101678404, 0.01464480010326952, 0.0432225274703195, 0.013030359818179522, 0.030239880565674077, 0.040888464408776456, 0.019636055409547784, 0.0628614135747475, 0.039203752793612025, 0.07757790897402071, 0.022122257787193504, 0.03969547398869069, 0.08916310425246916, 0.06872593920918242, 0.02144033228227448, 0.007536422992650901, 0.05892149998896545, 0.07940468393386373, 0.021623310467769063, 0.03353487452371948, 0.019323865004304438, 0.017129007779482393, 0.051668842187932426, 0.031809667500877575, 0.025140098371212522, 0.022039271312795823, 0.024495197895673976, 0.00949728680068567, 0.006810965020239594, 0.12009511461421368, 0.017263431312336076, 0.028639084306515517, 0.03070447267213416, 0.02914370067657963, 0.049611746724094116, 0.08755039724130785, 0.02490807906724513, 0.04770072507521799, 0.04188582661651796, 0.03653513913553569, 0.024187303328466032, 0.016765702072711244, 0.023103342541763862, 0.03239447987007518, 0.020495600314931046, 0.020537691100710825, 0.052080112659642776, 0.04634423617033228, 0.010679462932110315, 0.03615717050589381, 0.039359479316420136, 0.038330531303560546, 0.008590150598226296, 0.02892450185402507, 0.04942388664330206, 0.03677780131599115, 0.04317441331823507, 0.02255487146847431, 0.020516985659337333, 0.1020728578911193, 0.04181344279899232, 0.07829954847693443, 0.02212456754228521, 0.06081318940907236, 0.0695729413400254, 0.02755572106839428, 0.04648284062803273, 0.026287483577165874, 0.04508882873661576, 0.009418305050912163, 0.006565253809845496, 0.0514378015612883, 0.009366650615007648, 0.031476599284477776, 0.03973546377833813, 0.034594577136299307, 0.043000603289974314, 0.0722276428413968, 0.0062707150279874765, 0.004512374223615494, 0.012693849951779891, 0.03492798243138579, 0.06640749668041546, 0.07324748206883669, 0.07143402937799692, 0.08610362487454569, 0.056976395088338086, 0.04399472877623574, 0.06289812833851864, 0.07731113417614853, 0.03450828882294797, 0.03273346611569005, 0.020750912522236188, 0.025776579540463227, 0.05263151593446251, 0.019894736488499952, 0.035480013898303436, 0.10572725816840127, 0.005588594649452717, 0.03338474044275861, 0.052147984219294403, 0.056203826060218204, 0.08972534384097784, 0.020222823218172117, 0.01590740589064456, 0.022762726444090088, 0.03869122848094952, 0.02844794919984716, 0.05332474889714391, 0.05766911477211022, 0.04818293145827709, 0.05668121375023358, 0.008365730886467764, 0.0586720732521386, 0.039038235667131604, 0.02222401150051625, 0.04874699050560594, 0.07551783725859658, 0.014925912236644617, 0.0816203787502262, 0.05739987317112185, 0.06740571690663215, 0.0032624809471364586, 0.038947756852834456, 0.014862215856180317, 0.013311420240619732, 0.08270814699391205, 0.04350734746924812, 0.02621084988688029, 0.03774482261149153, 0.03557946743263352, 0.009058546331230431, 0.17762819515360942, 0.009549412380663619, 0.03132078274633856, 0.03320387091427561, 0.042127094516951236, 0.01707950317781539, 0.029665270572408076, 0.07096422595843192, 0.002067330159104219, 0.05009134840821067, 0.10269630024389875, 0.10645246764104213, 0.13398229685281554, 0.013210548486019815, 0.05632427806455282, 0.023855204213290446, 0.09292646521522153, 0.06377716826635503, 0.08441207975509667, 0.023068447236812884, 0.02500846722884284, 0.02848649108331771, 0.013420969856181934, 0.038161076485149326, 0.015304320409233052, 0.01265321569066615, 0.05099786407945137, 0.05300140233650323, 0.031419797695332, 0.04755013134150256, 0.0449827945070161, 0.08816756533398744, 0.08164978120476007, 0.03185167018654606, 0.05134076120391969, 0.04567507369023177, 0.11667506829384836, 0.02207865206254346, 0.04508999319026067, 0.050840237658591046, 0.03138012391695332, 0.05616707682249047, 0.07543896850679191, 0.03998571405968359, 0.01811156533808718, 0.026922285098642595, 0.027941948125859904, 0.09034227444640092, 0.035933564762554826, 0.03502875746738526, 0.03363563806840009, 0.08893870177768892, 0.027576493542461146, 0.012980194465677827, 0.020347936867525982, 0.027781674871221188, 0.04401391927873896, 0.04012782336963762, 0.025402979527209556, 0.05852509928386539, 0.019115709339178378, 0.06588377599273959, 0.019164662357539903, 0.057994269300252206, 0.027540644458044442, 0.030921932475100604, 0.02569587217764028, 0.03642310643748891, 0.04473377379678911, 0.01196131093292347, 0.02956624030165615, 0.055816534140537825, 0.03360521671692691, 0.021100013043671366, 0.049751358587414994, 0.036997071001678705, 0.012496410899104611, 0.03493406133906495, 0.03174888033930573, 0.04887445604488735, 0.008679903544215186, 0.03891394173185672, 0.0635285880566845, 0.006811548204671953, 0.033104493988737944, 0.030631479814708717, 0.013083104971766233, 0.025890305292822664, 0.018713086084913344, 0.03041221012902116, 0.0797778913270562, 0.018476489405598373, 0.0414657844380746, 0.04073103334033682, 0.03468435114970611, 0.06125169430649089, 0.04860175938736047, 0.08976038470263444, 0.03371349175370509, 0.10880818034732535, 0.026383169874128316, 0.053543271647105296, 0.05248782082250523, 0.07603188991666802, 0.0658333444246842, 0.0768877173803987, 0.02165555127806241, 0.010381253631485086, 0.011044191647200816, 0.023734055068944732, 0.04813127797998248, 0.03766051846586409, 0.02483672180753802, 0.03237032894826224, 0.03513998960355117, 0.049520432873959505, 0.037998301953437834, 0.05714826308371079, 0.034796425982588725, 0.013981531712136442, 0.027653676900832404, 0.07186997937218798, 0.06494530296373753, 0.03555196104571223, 0.09534976219818478, 0.029845069493016893, 0.05306928538747373, 0.03536843319213198, 0.039020064061567675, 0.01650455419064289, 0.024735939110659307, 0.14945267639573545, 0.07707847327354454, 0.034816723482142535, 0.058377297940633954, 0.04287153662693116, 0.06620347214442107, 0.06760416432253777, 0.003795986014020239, 0.03290859381518057, 0.04686340629573792, 0.04348049608750209, 0.033208413815666596, 0.05153826250123882, 0.05126615573141364, 0.016335656701196587, 0.11351931464648056, 0.028585080853513176, 0.07738852437825934, 0.04303724910583227, 0.03406283933849585, 0.06946725184999167, 0.01420886926127658, 0.026658735530931624, 0.02592127056672208, 0.01784107692900204, 0.03218525359707494, 0.1179590622984594, 0.13293214352621188, 0.19535657288807054, 0.18047675520422, 0.1342707749215826, 0.11999233625829221, 0.18900329847970318, 0.15947451604710472, 0.15419045523289712, 0.09064148540698713, 0.13963253237307072, 0.1338725930620586, 0.12047933835175731, 0.12506007682532072, 0.15137244676870687, 0.11519332401334278, 0.12074097269965757, 0.21328561969341772, 0.15148754381845075, 0.3275943649632316, 0.1335046257102682, 0.20735180906711087, 0.16797191733794828, 0.11395046126938636, 0.08895645969577375, 0.12716136407107115, 0.1525424009249095, 0.1284754806528649, 0.1690458806772386, 0.12186611837316906, 0.18022681135804425, 0.23075208728832586, 0.10488516666115293, 0.2535257362309964, 0.10047738019737507, 0.2697024181965859, 0.16442830103539652, 0.23547207756388575, 0.12339071761215888, 0.1448686054397014, 0.16590810711345366, 0.2295792679632864, 0.23660962620089132, 0.1414699329724235, 0.17271821507282797, 0.21680659043692777, 0.1606037756127696, 0.162385129219582, 0.10475821057034117, 0.18109420674943155, 0.23221284842058537, 0.1197029542057745, 0.09826767618858046, 0.3538458998645506, 0.2076738417869614, 0.1634878514995498, 0.13446277187716577, 0.09617879956720338, 0.13427094346092594, 0.1321604171948087, 0.15970002168849592, 0.14142940692122907, 0.13938712376740672, 0.11461448329951494, 0.11532132198373157, 0.21183281055381223, 0.1438210261685233, 0.16639426651020206, 0.15414910180674446, 0.15602410200142092, 0.16104642121541887, 0.0881642634950338, 0.08515713090497641, 0.12144915203774169, 0.15237081255162918, 0.2723434297067504, 0.1660494503354834, 0.1179186128560574, 0.14487464221254473, 0.16065358664960633, 0.16954722393664623, 0.1398852188140154, 0.1558415126055479, 0.12160242324875248, 0.11397118394773816, 0.12525076377055339, 0.13514570861814484, 0.13893723097299376, 0.14207411587478655, 0.098019823762438, 0.10263921903266061, 0.12726467102766037, 0.14941265596257103, 0.13396049399049054, 0.10141187723005012, 0.1576241838835901, 0.16025771837561362, 0.07258824042735562, 0.2845138089070397, 0.0810252586680074, 0.1472954953750295, 0.23062551424147623, 0.11724232575826107, 0.11694299988448621, 0.1249267009177035, 0.10216897128209954, 0.1377522768152337, 0.08315040955259916, 0.0991048647331134, 0.14479997928344435, 0.13453627035262125, 0.20875664578089792, 0.11633550748229028, 0.19439896298271997, 0.2739519385560867, 0.14948198691971842, 0.22097409342325505, 0.11051531535603347, 0.19685235956022817, 0.1327273682240517, 0.13174954891925858, 0.09132706515130498, 0.11991571980498492, 0.13546391089837398, 0.18040460504351125, 0.10980306809107143, 0.18396190367639068, 0.19515201209052918, 0.07220701209359592, 0.12471070242745262, 0.12758920119414408, 0.18258427840567407, 0.07521402977046467, 0.13486985567836993, 0.2046072684348591, 0.16190371956796418, 0.11165123222576034, 0.15179854487219166, 0.09434564309495111, 0.19858638425507855, 0.20730576718286162, 0.19047679199326426, 0.07695709430282155, 0.16291733050057966, 0.14105538747483684, 0.16052244771872798, 0.17272610577844805, 0.18622849737444233, 0.2167671675523443, 0.1253634629650943, 0.2318154632925026, 0.08900526715742965, 0.18882941184265, 0.11756713171639752, 0.16698318894111341, 0.1695819583631331, 0.13253488097219698, 0.12822383609149726, 0.10060529389809217, 0.19957241602241996, 0.1699985876198738, 0.1260445840776928, 0.210080016704817, 0.18123542739739343, 0.12218875630247979, 0.3045229529661517, 0.17912781226538843, 0.14317743570333527, 0.0743737385698384, 0.16606019088818183, 0.13224811894038033, 0.12652347330003977, 0.1745892928973321, 0.16605790794616745, 0.17620414495468142, 0.1130326955969776], [0.054598052144771626, 0.026190776468044328, 0.019686278218643802, 0.005317711705086573, 0.02799541340209544, 0.03147328212376564, 0.05431123265636064, 0.03118544948407479, 0.04857243737205864, 0.023845882838471763, 0.021592858472778913, 0.06365040369752435, 0.022373276071683056, 0.03605323152676706, 0.022636197447296114, 0.09390756337633056, 0.04940776432293558, 0.0304898914445432, 0.04688988229440105, 0.06814290799440877, 0.0231185264044231, 0.04530358999486893, 0.031560397812075196, 0.042890884177458864, 0.007024579540631104, 0.01403385934780442, 0.03592859285192625, 0.03968266882903634, 0.0820047940097509, 0.01746231348313872, 0.0067267839274849865, 0.020747302332893014, 0.03994179040854497, 0.02601585944273299, 0.027139375264185573, 0.033580295876750064, 0.028588009224603736, 0.028231985183552872, 0.003662548819369066, 0.04330878897059349, 0.07220603916193209, 0.0462353520936543, 0.03816378077552204, 0.05618007733456551, 0.028951533266433307, 0.018308066890665123, 0.017710344024723577, 0.03166010990107973, 0.009967693514491041, 0.03769786908261238, 0.024975544600296887, 0.06173651687981141, 0.048434035927658124, 0.05186759220856813, 0.08239949783009869, 0.029439192280293475, 0.01851845570209046, 0.016104658209388296, 0.01909052994432709, 0.05818340108699857, 0.07013365641356477, 0.010539594429334807, 0.008335868779179311, 0.01752259119624092, 0.012319420648348189, 0.11134555548309319, 0.04412354263026388, 0.047578392325029265, 0.030682371035518668, 0.10747910972924964, 0.0551340532218737, 0.05425860241596257, 0.07787081503099011, 0.00694877322530374, 0.022035726240926215, 0.022518078180690928, 0.041220735893735004, 0.011608025656201908, 0.04577758391537974, 0.05869917361246002, 0.055664818088013324, 0.034273517348112605, 0.04267385912938945, 0.018179785467744358, 0.020327436354672237, 0.05888189324328016, 0.031076994416634404, 0.01012477409770532, 0.05893748441350557, 0.02254871978244234, 0.011573391778755092, 0.05195845789726704, 0.01389024084463956, 0.03577834768821636, 0.026364184300144835, 0.011403814386275989, 0.018987079346252066, 0.12463276064203632, 0.04455919385016446, 0.034913733195994175, 0.031266970815317284, 0.018491795842325496, 0.04100508214305005, 0.04332990618422628, 0.015638527223810313, 0.04944927096667309, 0.015943366057810285, 0.013220998882916907, 0.023807994044956662, 0.05496292833178755, 0.02802526401806503, 0.020567769627837885, 0.015975059115237767, 0.0210243312176317, 0.05560228233075431, 0.0038371091349906623, 0.05356009876836212, 0.0506629572520333, 0.028455993123052102, 0.020181636416142987, 0.023583400048195355, 0.08801089269259284, 0.039073552320440935, 0.0431846559137827, 0.06066688959817253, 0.026678791712789286, 0.055620335192689975, 0.060602139846812335, 0.008913453108811331, 0.033798787983194474, 0.0644030123047771, 0.02368870266382733, 0.046368180248405666, 0.025880510858710737, 0.011394855945611434, 0.00729478114554959, 0.03685192032266529, 0.05340258343025081, 0.03080952439397093, 0.015801179181453923, 0.03218694282094798, 0.05653612818869372, 0.07859651479990253, 0.03669804007175469, 0.0022393707636623617, 0.014363149793127613, 0.06690078069485965, 0.03044321370731679, 0.01320263671298181, 0.045737153625175844, 0.03813010738081029, 0.0665524022112931, 0.039421900160490506, 0.06506764720524512, 0.03155626285250389, 0.054886503400461334, 0.07889494435080598, 0.004887827212036017, 0.019820039085442984, 0.08634766218282523, 0.026566134653084224, 0.04470129549923924, 0.08825450099163479, 0.04245420256930013, 0.01863477274685377, 0.0555337519354878, 0.03486302966672567, 0.03287195566020185, 0.011312571399274373, 0.07096774996288362, 0.03863146213153678, 0.027661684434860948, 0.03293487446142301, 0.02283099253902272, 0.006205522382046066, 0.04765832593904869, 0.07966636424703945, 0.047439975558870265, 0.016692209342915206, 0.04027017399728779, 0.05295529150434079, 0.030927837097776995, 0.05133476273547258, 0.03767094109207392, 0.021030511631960833, 0.020661063815256762, 0.0466207517761617, 0.03628790724061189, 0.03382178594268138, 0.06193997451074182, 0.06615530053574233, 0.0348805386062351, 0.11781087791126583, 0.02679012727082497, 0.012732923308747911, 0.06662601559993721, 0.03738049417734146, 0.0460014884330092, 0.03694717569517032, 0.061751493898731094, 0.05272941047986669, 0.03365434210507139, 0.0455068254603013, 0.0363930374864609, 0.06506463647970269, 0.10526181378912543, 0.01776101882569492, 0.10219406832249896, 0.07843139986958235, 0.04521345592013771, 0.029859527487367876, 0.05246958026902811, 0.05168441292499343, 0.013918075691758385, 0.04138307375532966, 0.012008966389863242, 0.06753517044407707, 0.024070245093635978, 0.024674406928581097, 0.018282996663343043, 0.018129997413545366, 0.022739630808392843, 0.05102834288751887, 0.01944637395471575, 0.027441993400815035, 0.04916109933307575, 0.03286960760071393, 0.11372628096010416, 0.03393114116343279, 0.038905254294795376, 0.026059767772113124, 0.03784345260130302, 0.018197455285717885, 0.0779624468076133, 0.018445196629111326, 0.04794191253641921, 0.04164481918597895, 0.04525752895842156, 0.02560259331197989, 0.040486804510076205, 0.05000309507933356, 0.1458815728584605, 0.06724039513257242, 0.06525227439499671, 0.07817633089519317, 0.09648143494081113, 0.051282979022230835, 0.02956496285004241, 0.06810294118739905, 0.018404004081422766, 0.028390103815904552, 0.005450744788357688, 0.030904674429386377, 0.026606995867745533, 0.0633447269548572, 0.02377457345925993, 0.03765554272479588, 0.09279730279118785, 0.039740362910613905, 0.05328474761617761, 0.04206832408184006, 0.05249655422484202, 0.06411990068191964, 0.024098845071069176, 0.04697112591877099, 0.0752203883002362, 0.035763129351600524, 0.05905630848100109, 0.015487971794491094, 0.02734946147088082, 0.03359507754324906, 0.038907506593292764, 0.038970233872532845, 0.056806534243326996, 0.029735576376439105, 0.014999716189659893, 0.06304737375748735, 0.06449260628752171, 0.030767701738964648, 0.007612979595339107, 0.009983215413446869, 0.050890420248071035, 0.07651185932298822, 0.029718800966117172, 0.02138304997295622, 0.035815296108804406, 0.02571538635229151, 0.056911112905870524, 0.0336354082420228, 0.03477219845198336, 0.03334517966234877, 0.01905797503798479, 0.022384826762361393, 0.03320259154744206, 0.04017494160742049, 0.03332917225517092, 0.06627897777023815, 0.030070690047596733, 0.027170235200995402, 0.03370423741157978, 0.014667962771660138, 0.045052443390652064, 0.020192466984172503, 0.012437465221380756, 0.0809521662191518, 0.040475769013526945, 0.03942810547267718, 0.037179809784696954, 0.03400905996621136, 0.047982135982883554, 0.047286340456095435, 0.03602371032860491, 0.018194321986107577, 0.07986314925214938, 0.05321487656704361, 0.0437703799276102, 0.028879235633799148, 0.01975748226076605, 0.049991649725744804, 0.04655225585485178, 0.020524523964512254, 0.05409030822075663, 0.04561447613542119, 0.02068156815855013, 0.019851435283799807, 0.05346123895217335, 0.01169722606127541, 0.05146389451598929, 0.007984140097358896, 0.05477361651437898, 0.12915537602478458, 0.06091600606939005, 0.07676770970706018, 0.030921239165529132, 0.05881013761785242, 0.08347667873867097, 0.04205273802302057, 0.009456387281628146, 0.08246907393538183, 0.042599870357662446, 0.020347726193346807, 0.05146684395449777, 0.04406077321618796, 0.07085788529366255, 0.015426536331013327, 0.07423137645086936, 0.06915638869207713, 0.0595175049027368, 0.02909622237747235, 0.07556523511847181, 0.0445721062621282, 0.046508293899316946, 0.1567250264868621, 0.1112833644654001, 0.1510188052611005, 0.10541669378477721, 0.1328079759954445, 0.08066655331922155, 0.1688800073198734, 0.09813978547050108, 0.13345034071995368, 0.1693998899070486, 0.17656694887386215, 0.18449966675571858, 0.12251507145382705, 0.14451952981612376, 0.23837666928527818, 0.19263078608820516, 0.24512185895394897, 0.13537129086832847, 0.14573541860426628, 0.23451475877194639, 0.1003024057154694, 0.18651391109151227, 0.077697119915918, 0.1541370435828163, 0.20469285577775972, 0.16859837807714942, 0.14001499410838852, 0.12301410112770335, 0.1796474497044279, 0.23876800231875914, 0.07295577110902918, 0.30408680378910036, 0.20612956174919683, 0.08482938316921074, 0.13407693935498116, 0.09576979288530928, 0.14739637383289877, 0.059765885929547014, 0.10555396141904978, 0.11426091840070103, 0.25918393906566406, 0.09619953756731364, 0.2256108865502381, 0.2115189749747515, 0.10708965361118318, 0.16714586005095514, 0.1286870205113965, 0.10451318500863929, 0.11508629386944157, 0.20804272844426094, 0.20389590983188924, 0.21042961326818313, 0.07494534741366103, 0.13614470259316508, 0.1434097288837356, 0.196105653660432, 0.13991980002291743, 0.11936263496717138, 0.0995124388305891, 0.1656987659272648, 0.15518361161793434, 0.08137698495580305, 0.09224388853556688, 0.17859723509079029, 0.15828917884538252, 0.17179022212663006, 0.24743823304532037, 0.2608402824449924, 0.09449496129227263, 0.2673206508399979, 0.2779917959724703, 0.21100604846592874, 0.1739502529944143, 0.10857502914844983, 0.12096083227304683, 0.08010998278135255, 0.14677185895702533, 0.11881968547259608, 0.18520868112964017, 0.09972676724916506, 0.22269388420447228, 0.16533240736011537, 0.07880759500567952, 0.1177351501199507, 0.19432287513008042, 0.21077669706315766, 0.0827269850959701, 0.11227047641671474, 0.15892159974863454, 0.1119692583057669, 0.10507760028685294, 0.19428579647454525, 0.11150520820651325, 0.1157525069110336, 0.09278069400498945, 0.09530414932317312, 0.1705793895187878, 0.23165728145789719, 0.11764919505484643, 0.10088092467236905, 0.11964152161512645, 0.13556080569903697, 0.19188319152641684, 0.20645055258947037, 0.07961996996234502, 0.17749567726446738, 0.1731287156261744, 0.05570889112629718, 0.08429239383868634, 0.10413641530659892, 0.1612397358422318, 0.11762410567532625, 0.11252163834269009, 0.2355288600008334, 0.1418881710138052, 0.0953789731307376, 0.24133694027700733, 0.13447061661751042, 0.10691806523790283, 0.24454551568675428, 0.10323241623418947, 0.2399019656642791, 0.12804609603218495, 0.1327791098024576, 0.18181108118545625, 0.13320166857973223, 0.15560011830060713, 0.1392309644049214, 0.11806469816233843, 0.12859879782603634, 0.20182862156821837, 0.09511979026419502, 0.1291710195401984, 0.14871992861791966, 0.23584108679525315, 0.19583608264163618, 0.16837651901427778, 0.18133938552871828, 0.1511191168139058, 0.06196792139821957, 0.0865548353401884, 0.1466019559771784, 0.23543084671180095, 0.11488977699510514, 0.2019831721460627, 0.10153795231974895, 0.14669860562970563, 0.10347043209138418, 0.14976131789866956, 0.13198657652303097, 0.20861056813549614, 0.19318007112991428, 0.15907276421785355, 0.2653776680029208, 0.1727796093590798, 0.11545338788099828, 0.2035079629070336, 0.17399134595067273, 0.15173020982934585, 0.25652262622550615, 0.08799776194557067, 0.25005594016082827, 0.29862775317122864, 0.1347259384009146, 0.08030636942074185, 0.18387182705825378, 0.1632508698610529, 0.2021579934103835, 0.06280921617402666, 0.20312078207010226, 0.21038159487708924, 0.12996847110409893, 0.1348482519989052, 0.15582859636314456, 0.11774428188800813, 0.22566681096871055], [0.006839776150656925, 0.013806659694490655, 0.03666353164120548, 0.030679911893281727, 0.025079544866457585, 0.055328428880461765, 0.011120495919678963, 0.005182485695132205, 0.04442884398984813, 0.0338379695500818, 0.09134114584735326, 0.03136784735796673, 0.03996979475261704, 0.005177114461173094, 0.02518529181308564, 0.05974860681641487, 0.05972766580300466, 0.045759308887946035, 0.04415973262380689, 0.06010599066353133, 0.039530251806061116, 0.045046552174514344, 0.02680166072452501, 0.07773717099259939, 0.07645857024697528, 0.036393784422187075, 0.10681341762744612, 0.0093600737501777, 0.07404271963863604, 0.026348625054402698, 0.01733680721372366, 0.06207613897840343, 0.022082486332604484, 0.018948238688491045, 0.03803077259010846, 0.03873816285763056, 0.04694927709117051, 0.04494165941592186, 0.05033023377519943, 0.04336044627932772, 0.006386232468479824, 0.01564040605444461, 0.04442771401015982, 0.02017170408620469, 0.047649247797145966, 0.02176569173893621, 0.023317286001157858, 0.10283469402742001, 0.025833842697583383, 0.033755346967448155, 0.01759604370642093, 0.04426453728228808, 0.014463771611542232, 0.04609928338698322, 0.023443587086794358, 0.0337551937498633, 0.0356781127442035, 0.06787245597450003, 0.04580306399974131, 0.04395730538113464, 0.02629045216787246, 0.09062332912318169, 0.05521530450712289, 0.03017578198904953, 0.03878399023726102, 0.04881181303531893, 0.029594880498705373, 0.10257194885202955, 0.040454709256488475, 0.022313214778419466, 0.013709194158324072, 0.018963267418345617, 0.058335052022049506, 0.05268209305922351, 0.04894271830938036, 0.06055725475532874, 0.07434099597195465, 0.04690349184637589, 0.038829537994799115, 0.026363387568703583, 0.03253290429711342, 0.029341167499942165, 0.09238276495448045, 0.03671222802011236, 0.031744716651437264, 0.09711949425118585, 0.02399986076559271, 0.09602857738613121, 0.01236332323206889, 0.04817230964920694, 0.025194708948894858, 0.056336091140345226, 0.022076344222671563, 0.05860598667735054, 0.04167745070111367, 0.019988189639163115, 0.0509458773529097, 0.03203578218216858, 0.05277262933011498, 0.013802689443823072, 0.029569996047704935, 0.09145396761596204, 0.03815019420618492, 0.024093411592466217, 0.049582099121424465, 0.04007787826741415, 0.02256986572437229, 0.03989944489853036, 0.008958840945495233, 0.047219851685147134, 0.004011823147002067, 0.02070035838011292, 0.008549879271266683, 0.07883509756216119, 0.02922935313695381, 0.01646395344587584, 0.04300129659954579, 0.030372046054370945, 0.034386335286281766, 0.007403917073632681, 0.05011390969758073, 0.024244941868669084, 0.04390767054452051, 0.00969234044708672, 0.05444363563231403, 0.01580447527474814, 0.01257661551672725, 0.055559664859526584, 0.07514320494186494, 0.06044550934025358, 0.030815327509997353, 0.03388537507083628, 0.03219198367948974, 0.02959653524862182, 0.020110035923519926, 0.03560529225656102, 0.027593661572844274, 0.04345126600275117, 0.05404515116805992, 0.007375576129678878, 0.05225456620175993, 0.049648898157982096, 0.0027709766507013553, 0.02331472343705114, 0.07080255842377102, 0.0799874700005016, 0.11990590621867489, 0.05240457387821329, 0.03749707743765847, 0.052652790196119785, 0.055930531854110385, 0.029569973065067204, 0.031072673680741462, 0.06567177648145346, 0.0660630712105382, 0.026784603776890906, 0.08772780788281272, 0.024596227655908274, 0.038691833690409703, 0.05171157074190917, 0.020287473378102147, 0.026143076003439007, 0.02770719771844245, 0.06309440006471931, 0.03929415499911674, 0.031175436714904445, 0.023469938596169797, 0.04623343304340397, 0.04984904245864, 0.06551155685296943, 0.08978511402083021, 0.07117431024990736, 0.03407936002458296, 0.005108522778872642, 0.13619308870646263, 0.10049807223220987, 0.060543963129842476, 0.05769308183282133, 0.048612078591700525, 0.04861605458802754, 0.009106638458287044, 0.04242265889901788, 0.030202131583205158, 0.053048608674397396, 0.08185574394320289, 0.02943910034974256, 0.03632334646798911, 0.0994468617042707, 0.07232750240232676, 0.02303057376505627, 0.05526728357278532, 0.02146140736107144, 0.010848392980293402, 0.04679777171282519, 0.06631087001052595, 0.013399364261497414, 0.052950147223929246, 0.043251543050451625, 0.013972711167298259, 0.07690180573732623, 0.07921379780577076, 0.027290072419770786, 0.06706031084421181, 0.0582702792880516, 0.057237324635348016, 0.016435219403055888, 0.015367867402552117, 0.019780187191621914, 0.04468768211682478, 0.06260664720508842, 0.047902171725347165, 0.01962443002529683, 0.09139147782397848, 0.022276773891081254, 0.04253714307842236, 0.04599658930073342, 0.03790783846089917, 0.034080800269880605, 0.0492319279921151, 0.0739270403620697, 0.03261163515309173, 0.025207874169873617, 0.01492883198924603, 0.04875213861645711, 0.03320403562317933, 0.015065504947767384, 0.016827778177215688, 0.04134797926751837, 0.031013035651056037, 0.036369572213340196, 0.010189296895517938, 0.010830315220500193, 0.013940983635914183, 0.0447453149113684, 0.03089143643005481, 0.027829252761758627, 0.09382979013025762, 0.02651606506157306, 0.015012881410638652, 0.02052639896470693, 0.06465329322963953, 0.03209849988530961, 0.032480760522547274, 0.09894496686155758, 0.021030412040530674, 0.032384279409363385, 0.01384545821741584, 0.04164177398647993, 0.04798983133608296, 0.01873553054587495, 0.05529856677317331, 0.05105423665935955, 0.06086535999671586, 0.05773706294055428, 0.03654143254783365, 0.048447197318197265, 0.027901010302406166, 0.056136176666064616, 0.05104319733237067, 0.047007066933738614, 0.0252371157459434, 0.028855919747823672, 0.02308099958745222, 0.04582950935488747, 0.01639263640578476, 0.03920591316155849, 0.03622207347483885, 0.05002517373331132, 0.04241474138032045, 0.02812212625999124, 0.07384550562428852, 0.03435499079885983, 0.050101070063969785, 0.08661540225148202, 0.03975996710059624, 0.06151780643830858, 0.06284506525844336, 0.025198547049395503, 0.01636412644368266, 0.06800822207644101, 0.04963238130233461, 0.043277919457684604, 0.0648174582109336, 0.027586619309600324, 0.030778921096615737, 0.0666048409297101, 0.022744589312482747, 0.03015987991896128, 0.015628536479667793, 0.05297407214980453, 0.06799198867332551, 0.028118184737620816, 0.026483596340122244, 0.0384624976093971, 0.01422067467618974, 0.01671507898267479, 0.04008722070965075, 0.021433205749358863, 0.03988818340604344, 0.02169194045446573, 0.04797868475678468, 0.040030882603699164, 0.045618651314608516, 0.028168080044129205, 0.02824214159420902, 0.06893026251946727, 0.008431118406024913, 0.04482927431742992, 0.03468574159928868, 0.08627956462723595, 0.06044732496863412, 0.047045719899958184, 0.05048757291308815, 0.025685671716928486, 0.042842318033499104, 0.01214885979049629, 0.03376291591614004, 0.020050440028670336, 0.061851713520985466, 0.08934053787661177, 0.009181251591672341, 0.016181996700564222, 0.05603803314208504, 0.022343425455713467, 0.09307896267742881, 0.02115972768214922, 0.012631968242086232, 0.010727964916206416, 0.027754520884745067, 0.022289946772939256, 0.09354480542242528, 0.010069041201213916, 0.05684709093803841, 0.06895087028463041, 0.02283990405680191, 0.0125485077507854, 0.009074003112712696, 0.03406352498718808, 0.07656731642782688, 0.021214809403904987, 0.013818158674234105, 0.025599394894896016, 0.04023236372778493, 0.010565148249659087, 0.04751897454562207, 0.10770005714749137, 0.09751494117682019, 0.024408687416824604, 0.057907433234035015, 0.0626999069185507, 0.021330641898056193, 0.0816326208352562, 0.11793028037514418, 0.1413820933310255, 0.09564745630468093, 0.10346028142638745, 0.12651208157260574, 0.11340963383836132, 0.09627837567560135, 0.18430281280269548, 0.13977015240778848, 0.15214939781975362, 0.15888190107239833, 0.1646399864506337, 0.1298407182818459, 0.10404262316202927, 0.15470221728807496, 0.08569404362670838, 0.1586624781691259, 0.22264900677386792, 0.10697415053483941, 0.09579710391980988, 0.22645384373684085, 0.11414458028851979, 0.12262818433584706, 0.20084136406019812, 0.2717521017597568, 0.17133602391808264, 0.24309057682271928, 0.1710351045814253, 0.16732161594254358, 0.15963640574726368, 0.11731323485653247, 0.13005572851867447, 0.13775894178017495, 0.10744992177933456, 0.13448247565857827, 0.1397140134846972, 0.15804073653153836, 0.09102968514085778, 0.15313628760557021, 0.09158408764990107, 0.16629127364966179, 0.1212746372085906, 0.14992400433026976, 0.09538252777870625, 0.16203023132777986, 0.1271517266849837, 0.09254305353087765, 0.1866296056898371, 0.1058088771758541, 0.10738771543988299, 0.07537963499705638, 0.13125942118706244, 0.1067623348846551, 0.14985042924602188, 0.13075142828447203, 0.08902578299204189, 0.1482255414368645, 0.14351305882296256, 0.15638580275399072, 0.1283394770636674, 0.18103367048165492, 0.08115373927378848, 0.1118361735115609, 0.13704811943875206, 0.11939705529760931, 0.13349765431015723, 0.10555904058198776, 0.23758499402432676, 0.13207548868752297, 0.08009836888842045, 0.09995696900953209, 0.13840476922210188, 0.12239698666117846, 0.18046792987133228, 0.15195562354018613, 0.16612863318333704, 0.22342517641523194, 0.1509502403918774, 0.1170440468816988, 0.08279638500103066, 0.17966981947181687, 0.1048751385702241, 0.16998977760874456, 0.14897846797060582, 0.11529499154177406, 0.13512470248726108, 0.07065927699929284, 0.19279178712637196, 0.11030395169772449, 0.1373131858605531, 0.15493498544298834, 0.11566270608454944, 0.1681833576050497, 0.13814630647820814, 0.19666235443324814, 0.09528307424437615, 0.21430159017684, 0.18323696999540254, 0.1064742781642464, 0.12317837336130681, 0.1808529043750417, 0.19133920781314376, 0.1946728700591672, 0.124521846432359, 0.20351003134442916, 0.12239640443435601, 0.1199391084693132, 0.10857928859730882, 0.16944809215924433, 0.1578532901382254, 0.10541127754315253, 0.15602459229769247, 0.09431305371465222, 0.18941902375269323, 0.17247804650856605, 0.1637270088277517, 0.07520540362043728, 0.1594037448446597, 0.1615239084968644, 0.13442489649018935, 0.14546004063900442, 0.16134505761006188, 0.10017863655042264, 0.08929087239648066, 0.13681824709619247, 0.08779910002504626, 0.14958087354898453, 0.16042567549213288, 0.15699399995707697, 0.11600163104313037, 0.11171143907572954, 0.0780410857330407, 0.12117152177398244, 0.2751453196810138, 0.1370387118790419, 0.09972875907776818, 0.12136543394937632, 0.12943127492983497, 0.15240470428139935, 0.09944680041723675, 0.17392301090782689, 0.14200041821647075, 0.1350226748975054, 0.1195837585856357, 0.20138792182889678, 0.21461438387632373, 0.15409100169856704, 0.12248501782455753, 0.11109459273997815, 0.1196777728957034, 0.15367565946953912, 0.1461458425488203, 0.15263756436686363, 0.1863880275237945, 0.1740168107132758, 0.24323757377363023, 0.09181098757131446, 0.18293203635802194, 0.10107067699033408, 0.11616738182642769, 0.17171995654221506, 0.10951031525168689, 0.121754392110292, 0.11977676677727893, 0.11919709102761362, 0.1751835166566795, 0.17855359872262325, 0.17862452314265315, 0.13964590826822867, 0.20531485788524154, 0.190789018787684, 0.1692867080771154, 0.09505101089035312, 0.13963625556038273, 0.23652017777485235, 0.2915761896198796], [0.013028087409874125, 0.050398595631122596, 0.012275561157073225, 0.014789737235274047, 0.026922622177329276, 0.02434706138897567, 0.02129405928445199, 0.052556274608979305, 0.00970066590760384, 0.030624753562733534, 0.08770741462226837, 0.04183407354679319, 0.010329196999420323, 0.00444039068703029, 0.04492370997585597, 0.02396908126801493, 0.042919175804502545, 0.0903015032470707, 0.045786102813097744, 0.06972920029394089, 0.0033723109029984524, 0.07567957374117068, 0.02513020434567044, 0.041032826017227866, 0.05761253151802286, 0.05919015553269175, 0.03981495306136147, 0.026091811314765966, 0.011392160273727872, 0.06707567090709364, 0.027459611507853674, 0.05262225010101834, 0.03051687497645617, 0.0947639883886422, 0.027420487397560672, 0.03597098049677668, 0.058170752975368695, 0.04369948615109728, 0.017460471041680827, 0.06161550180085244, 0.05305250040105274, 0.006568357423548737, 0.06377663583524766, 0.06065715262065492, 0.054891176536799445, 0.05035553765933841, 0.04337001088706236, 0.0315499828467446, 0.07090913657579692, 0.04989279373999565, 0.061126569165818156, 0.03134558484288714, 0.08875220533340208, 0.09431997914948771, 0.05854260056249558, 0.015489644738995742, 0.036140063762544625, 0.06641444509788867, 0.037507538368264516, 0.01079969947421623, 0.03190741265913652, 0.04943123725693553, 0.021866514655430953, 0.026358861904290896, 0.040077947215327335, 0.01207217917732534, 0.09209519853034327, 0.04464462031460097, 0.029934290007898406, 0.07193249214680926, 0.02151830854164737, 0.02575025101372552, 0.02391967051211865, 0.04525151133777634, 0.027042105080439683, 0.02672550775441191, 0.029588814997564883, 0.09409022172011676, 0.057586396428486036, 0.06274267377692365, 0.04244616247653481, 0.04565002644554742, 0.0669760488334202, 0.023013183569175102, 0.03427694942201338, 0.04812420315800175, 0.06237846408640185, 0.055400808867547786, 0.043243866849450335, 0.07664820765175166, 0.013989204082698112, 0.055864632970863776, 0.04563507623970509, 0.04417029697628271, 0.015483154059057275, 0.0757530109295922, 0.012039546704580708, 0.05768347509025086, 0.06030264926413375, 0.06637938125359436, 0.01841844292357564, 0.028259822903501413, 0.022225421102296923, 0.09502152416614756, 0.015486651250431615, 0.02890472337903996, 0.027933565208748467, 0.07350360824456138, 0.03840275041218247, 0.015939532745359166, 0.024563613377751845, 0.031854677081648866, 0.030609485430402622, 0.08506621925100204, 0.03321848787187088, 0.03986513565084146, 0.050416031792279214, 0.03524739896097491, 0.05483390380358023, 0.0706608628012961, 0.03448024617447969, 0.04831352263628956, 0.04647957709347529, 0.0528266117156994, 0.014954248871353847, 0.033821372255202264, 0.06537990464318184, 0.03354975961208825, 0.03554787013619658, 0.04157698210028391, 0.0347785071860398, 0.016365673941289707, 0.09939078406821336, 0.03851479460154811, 0.06793696823860369, 0.006928585850889044, 0.01975269804167892, 0.11965624582503112, 0.04981485578501898, 0.012447388932829904, 0.022028657164604917, 0.016138381399815122, 0.004735866490180695, 0.1321656419144523, 0.0486714925406681, 0.06753275726711558, 0.08929319364289123, 0.039771684415398106, 0.021727711014870196, 0.060203023360020695, 0.09311802550068787, 0.014650988178477894, 0.08211166327518803, 0.02105905415279971, 0.053805124330063986, 0.047152412965172724, 0.048449461108013514, 0.02961139352391324, 0.02553980283048605, 0.05400474003005413, 0.05105651960137391, 0.04814673380385484, 0.014900265528159517, 0.06630086490223486, 0.022760454993394595, 0.014817464830083473, 0.015761046707930586, 0.031833017860809644, 0.05359953314426446, 0.03139693188601204, 0.10920970235019924, 0.026593296300439585, 0.00969681631578433, 0.03714181182365264, 0.025970913064215454, 0.007903836845916005, 0.05186485344423883, 0.027717338807340113, 0.06417860216911762, 0.026661646665043892, 0.027234333777619947, 0.02048081290277262, 0.10065112127772263, 0.06759321692609979, 0.025914000392320658, 0.10652917602490033, 0.08007491893705823, 0.026064871832908645, 0.012490393278459388, 0.035215407129256956, 0.024149148319397244, 0.030539214100328185, 0.06791747896181, 0.04096624148528903, 0.03505269771501903, 0.03907529517046867, 0.09060842871305444, 0.016386969270364895, 0.019868967205946966, 0.06493951133902996, 0.07954867782011148, 0.03258633892983198, 0.04740787647484292, 0.0310595793228957, 0.01931826681679776, 0.05740951821808854, 0.04767009304956563, 0.053825448642695145, 0.06865742796611402, 0.06927777532367937, 0.011357137606659485, 0.03475331438464984, 0.004484315295778816, 0.034432308222617836, 0.012440308365189742, 0.06357382937905288, 0.04203880288367791, 0.004767119047051717, 0.0657884746549591, 0.018431299794164878, 0.04119985616735874, 0.05252787956006585, 0.030267955772879145, 0.03346202339256003, 0.07821713273804035, 0.08657008048988159, 0.0515384195492633, 0.001651677425064507, 0.030969715294157787, 0.04399412356677555, 0.05047449579222068, 0.026330177657186028, 0.04763823145279481, 0.019022170003623735, 0.07164337822506506, 0.02384402124481576, 0.014561793519063823, 0.06384218997892833, 0.11935145774435614, 0.02882690991335098, 0.05172750154029458, 0.0042085959425856995, 0.02754197553581288, 0.04385157375626507, 0.06842141925928093, 0.07029834233464734, 0.02338898416999127, 0.07889244690417282, 0.01680737917101191, 0.06471581366514007, 0.028644845287706104, 0.019363220856194536, 0.1170687455563776, 0.037633153805208784, 0.05433543720432828, 0.017207240678309914, 0.014921987951252491, 0.04624144249265233, 0.04271359611002188, 0.01982669830472479, 0.04340818504832926, 0.03587605454207909, 0.0311224885480178, 0.0634913791662022, 0.012347281350934458, 0.0581113160437634, 0.04371162864469713, 0.04607001882827571, 0.019316206040281444, 0.012012848540419533, 0.05367826783068238, 0.06084087199621624, 0.017643368787943356, 0.04794617964615745, 0.010995805533903261, 0.008428147900098515, 0.019076531602730675, 0.031107691559760325, 0.043539649566575404, 0.09539943533919512, 0.04444714583035919, 0.024522972413368767, 0.07963983462222161, 0.08406049136312739, 0.04717738743150427, 0.03280545922837431, 0.02297616620067387, 0.026812864760417613, 0.03776431954916447, 0.01095119814929222, 0.03910928266122937, 0.033439148007141005, 0.052282631832865946, 0.05069034106488671, 0.01799026297615661, 0.0761980620483237, 0.013730121765195603, 0.013192130774710209, 0.04759696612675344, 0.03682185903251652, 0.05389097597329848, 0.005851983817504539, 0.018810216457613053, 0.12224182321299469, 0.04141243790546733, 0.04249943240034965, 0.02238511213011319, 0.016190214908771938, 0.035818325986544934, 0.028817672808203968, 0.01123197416159054, 0.07363394278311923, 0.04857154871006647, 0.08142711008868872, 0.04304067734929343, 0.019071193885118253, 0.020352401244904728, 0.03184727858752012, 0.022553412070978555, 0.0715438787254595, 0.04355130559434334, 0.03697041880279299, 0.011670639937473162, 0.05332710461751108, 0.022149107253719724, 0.022290163192777865, 0.09679746153133531, 0.020920053244598454, 0.11251820626878932, 0.03941195633923335, 0.02705904136922571, 0.01966340857888422, 0.02135410334073728, 0.02658520066629975, 0.04826202620601943, 0.0668626524988682, 0.04370880178025654, 0.0321209941419863, 0.003404251502586469, 0.012913435648736215, 0.01095002028910864, 0.02668838121838147, 0.035251183435320854, 0.08030890517177121, 0.039388414457320206, 0.1026695714362206, 0.03913442566690426, 0.0322960299109259, 0.02824334818268976, 0.06087595499270867, 0.043061986084907286, 0.03186387779761947, 0.15957458245177425, 0.11687330886601441, 0.16412119170831097, 0.20449998548194287, 0.09117570916010488, 0.13301348674201197, 0.1997652709964783, 0.1551162418458731, 0.08366562666431551, 0.18846415644211156, 0.19445910088477597, 0.10607747526298608, 0.121579249089043, 0.08692626540939655, 0.15137512807644185, 0.15043590428127399, 0.15920905125958307, 0.18449372191342617, 0.11703624044575038, 0.20821649250724625, 0.15301424979923234, 0.13465329794393432, 0.06108733397277613, 0.18486885984818782, 0.11734788501334768, 0.13976154157951956, 0.13667855862407916, 0.11862059454283408, 0.16547532872326914, 0.14417318146555655, 0.09682391454736072, 0.13352599956335562, 0.11671063009529345, 0.16497300487131844, 0.14494513762333702, 0.13624541251169098, 0.1316261474764155, 0.1811403712077487, 0.18257139280678766, 0.22494439005611405, 0.17415697415990217, 0.11745676142914642, 0.1899072209433202, 0.17296435912289929, 0.132886239537789, 0.2140264573597139, 0.0847072993975974, 0.17239671861452444, 0.15062117498488198, 0.18458997320023277, 0.22147922115700863, 0.11904251746713154, 0.1483270021215562, 0.16761908788354168, 0.11882887086680821, 0.10665201056267946, 0.10482057778825683, 0.11903711654726537, 0.2011693263005826, 0.08367363994400348, 0.11603924596021253, 0.14193686356227245, 0.3038077945670774, 0.06882475689053535, 0.15829587445384072, 0.09307792845873103, 0.15810407668111787, 0.18398811920515953, 0.14053023420274258, 0.17826334332987187, 0.13040720965833436, 0.10320884370875937, 0.07903113180110533, 0.1589008694094035, 0.1282649520303934, 0.10263068481318413, 0.22079223947178936, 0.15101207900912533, 0.12996238836598012, 0.11644095948506748, 0.0854411963072996, 0.11863472886503705, 0.268054134062221, 0.08524043530586266, 0.11987631224215993, 0.11910794903674435, 0.13292140297351346, 0.17977193899212346, 0.17455887920673818, 0.1934077831045274, 0.11199964901372311, 0.14943638936646525, 0.08931762418679653, 0.06958310732678061, 0.16127885229164557, 0.3031298373976062, 0.09520375350069615, 0.09962352157960977, 0.1380841614257905, 0.07308316386995778, 0.13305713843193748, 0.09244671797439938, 0.05991371791629542, 0.1654388629380734, 0.10058551350788725, 0.1563438671010156, 0.18450279239444964, 0.17143936917906807, 0.18021262340968658, 0.10478235000083524, 0.24282604666246524, 0.1108893731068219, 0.23080508525092758, 0.29500522981247596, 0.140544697942753, 0.09059472340008906, 0.15226044992525734, 0.16863773967469894, 0.09523798997003226, 0.20417208452859234, 0.07117840882030226, 0.09336480540373633, 0.09992791895544338, 0.14453831429202713, 0.0808459481284503, 0.09045794606208803, 0.1418784723406838, 0.3526643471371743, 0.10042967590233011, 0.15418740620295848, 0.17356779125909652, 0.14720451477314198, 0.17809607569248448, 0.14851990306089002, 0.1562751030489322, 0.13884559153549134, 0.1261722985955496, 0.28515612766627346, 0.1318553609833602, 0.14843267628983145, 0.1280476971559467, 0.18966162847655435, 0.10227466843301251, 0.16883509924575207, 0.15524797832533238, 0.1145410231284557, 0.17299806699156764, 0.16071020054721064, 0.12164212192498869, 0.16830361808740324, 0.14136064286914565, 0.11254484314591655, 0.20575076191415712, 0.13981820144239934, 0.15775740657362247, 0.18446556052132962, 0.16212254492265565, 0.07864990346734563, 0.11598891398358731, 0.14760956078046752, 0.0686062379710136, 0.12849989587501173, 0.09685743855492723, 0.12009707579929983, 0.10070330718712461, 0.10373306235358601, 0.1123904687682948, 0.12403164975224965, 0.10015170855988419, 0.17127721900901488, 0.1504229880388706, 0.10649220462167457, 0.14480584751694434, 0.1632729025497552, 0.1331638851233067, 0.12103458355751731], [0.02699328612746491, 0.029293334885169903, 0.0236286700988609, 0.029862618652142348, 0.058060528244823224, 0.04258705370668923, 0.03672622827692859, 0.043391568601251616, 0.044961324892938144, 0.03413716135846992, 0.03202860393831807, 0.037168751305509964, 0.038403347960763404, 0.07560968353983856, 0.01529444074783955, 0.03642320602891907, 0.03771455447760321, 0.0672004436473212, 0.018178172852663745, 0.08128928321023142, 0.04541453484806322, 0.046277984886640505, 0.02703603383363976, 0.031563584737840204, 0.011498980701059825, 0.0560295065834878, 0.0423364510248986, 0.04780659842635355, 0.01669172670752291, 0.02711601149771483, 0.00914638405740862, 0.02235378104922993, 0.08343588455670303, 0.038474046384855624, 0.009941228049536868, 0.03974654524016284, 0.06691491501706262, 0.048511498908121745, 0.040969937859523686, 0.08005792710689769, 0.032073105985839526, 0.034886533244242596, 0.03856366718067758, 0.005649449801327842, 0.06115954542051881, 0.1016716882886906, 0.03725637261184954, 0.011419229032922418, 0.1145694449904465, 0.056568840143060496, 0.02575686235251206, 0.10490966615297141, 0.020542588317766786, 0.08662337722677378, 0.011614480904573876, 0.040589498596326004, 0.036088004257650144, 0.01798494249552248, 0.014679037530215518, 0.016022445483794136, 0.025698919292359103, 0.03796965409550936, 0.0555269337529617, 0.07983705629744837, 0.08758372206601404, 0.04796771437770898, 0.07578205332280168, 0.06150565245338987, 0.0381673545756888, 0.04004657208438843, 0.04835306809494092, 0.051844414218419024, 0.11164504223533216, 0.035784951366123655, 0.012127913989036555, 0.017228871170851975, 0.04303953204784663, 0.10927956190801437, 0.04200337514761956, 0.06992518856760956, 0.02958836683612918, 0.04686208096362891, 0.013836948895796895, 0.04935960420557568, 0.01873676011699342, 0.05448494692363086, 0.023333709011034622, 0.06420124772815936, 0.02220929303627101, 0.11381872478992709, 0.013258077538452082, 0.02130178911160798, 0.08098716111553293, 0.038264571133279995, 0.05204791781462489, 0.06955804859077738, 0.091265287821091, 0.03443577477047521, 0.024475333235797384, 0.0642253450238176, 0.05023781292801423, 0.015286978093847154, 0.07976191073295572, 0.06256755373831238, 0.029684859440631928, 0.0034295158853168573, 0.0410602864388737, 0.01835746998568216, 0.04813455300585878, 0.03191827770112263, 0.008404480571287775, 0.1039967957823988, 0.024802883703922553, 0.023377420072774255, 0.030650723943366643, 0.02947165142564524, 0.009593452860210693, 0.04386136435993737, 0.00454002664604735, 0.06918558430287146, 0.030638359284268755, 0.06262749245750808, 0.06348841823637486, 0.03421494226542211, 0.023959164259835117, 0.018704425460929354, 0.02910580805262491, 0.013655350626175924, 0.055028045805351394, 0.05267554300747091, 0.021495647660847154, 0.034106582958972266, 0.03750094235123646, 0.028100915200587724, 0.032212790627513206, 0.03355074403507095, 0.019782071767915643, 0.041719382523649165, 0.059462871342416734, 0.03302434970053934, 0.05111843865785388, 0.021934935883168253, 0.0250915034989556, 0.06746361017107003, 0.029098932413504492, 0.053266656449845726, 0.047182328698615876, 0.07912749800110057, 0.05223282845690847, 0.02552477410063148, 0.020690217291215257, 0.01995217010018326, 0.01621018682095793, 0.01843321501397558, 0.015078575365365514, 0.025676605066344626, 0.0186791273224498, 0.022582251450888092, 0.07500137142356365, 0.020041670237157135, 0.05501790663167354, 0.06258222049162274, 0.05332068097026599, 0.021798834617760394, 0.07587802881795554, 0.05630507607073073, 0.01015478942257863, 0.05638924615097143, 0.020715965506350322, 0.03912871831186837, 0.04860367077673155, 0.019323842021666707, 0.06571840059252516, 0.05572966360036404, 0.07417263282883553, 0.053649102863405025, 0.047878913295966004, 0.026563755950079333, 0.017881405712555976, 0.028302852146988435, 0.05359500939507158, 0.034449097039478446, 0.024799993637228207, 0.08364567773476725, 0.03276624318753039, 0.026073091956336173, 0.03066505361799031, 0.0244693041238333, 0.021267001058966405, 0.09630299774148772, 0.03885781046964469, 0.015321964371739136, 0.06075098306962079, 0.01536938904469172, 0.11631006570232492, 0.005748998617843515, 0.03843794066098429, 0.042374594542648525, 0.04134700633585453, 0.02500871237697861, 0.008493844727655093, 0.03544053738756526, 0.05553072205774727, 0.032757440837280404, 0.04367023308370863, 0.010145632756663667, 0.0228742286262493, 0.08782271851575182, 0.031527245357151956, 0.04940155518030928, 0.015742603141153534, 0.021876822368452148, 0.08257730683732419, 0.02663042475168984, 0.017572180067579594, 0.09303628391916714, 0.04172505540472846, 0.0343789501986917, 0.05859109775854215, 0.009110600090465479, 0.0294453535424245, 0.0990424209064053, 0.05836389523239867, 0.037488803688076236, 0.06616791034297598, 0.04029971817808767, 0.035838133189827204, 0.11286922009481538, 0.028127199677269787, 0.043181200857244195, 0.02844773278000855, 0.0989501609376842, 0.020003892526391055, 0.002116315496800047, 0.04580527416340286, 0.018467788561998356, 0.03384329769159517, 0.0771819640912356, 0.025653407923997413, 0.022717981163652676, 0.013030997586376485, 0.030307219694218332, 0.11522854107522196, 0.06599760133652918, 0.008745615693530249, 0.06392743641270265, 0.04512796050778801, 0.0460095783214896, 0.07797453567505845, 0.03874186689274446, 0.028904836377008792, 0.01985488650989869, 0.024244311761351365, 0.04689582713669346, 0.021945613233612913, 0.007304667031407477, 0.06032896055389316, 0.030469616927627115, 0.029961401859538692, 0.01791345691608806, 0.023654108048386635, 0.016423356531548406, 0.03161149204618508, 0.06064319832911415, 0.05077737248352459, 0.02480790541026621, 0.09216626084619954, 0.09214906983317868, 0.016776875465086872, 0.04269650085799156, 0.01019572054276303, 0.07800145600471767, 0.04108808393920622, 0.0272529382228611, 0.029438399379291845, 0.03297879811256163, 0.008033714125744038, 0.07584257426881984, 0.10597695686644125, 0.028636937345107718, 0.037766403308318514, 0.025036444759837566, 0.009073690931883552, 0.05171695634001686, 0.020996941659118862, 0.044203763527254906, 0.024465303229648742, 0.11452523405633627, 0.12268752550646184, 0.03321655349986207, 0.010145159697370424, 0.0773531694205538, 0.0293923594102624, 0.018487396582420317, 0.019749687316136497, 0.06458845920860767, 0.046540243596199064, 0.05653054340772572, 0.08216437012437852, 0.044415391485897765, 0.013294738676068524, 0.014486975457158782, 0.09657938694280964, 0.04120355254159339, 0.05216504116692851, 0.05643799232559339, 0.016190195756573832, 0.05024639694320579, 0.08903418697657124, 0.0025244586539619994, 0.025711347153710745, 0.05533441585759002, 0.020275752232860655, 0.02448006765916944, 0.045602919699083415, 0.02742787823081017, 0.0668495677171215, 0.04413231050655727, 0.02447482570254755, 0.08432463081854005, 0.027034991954062736, 0.02471858338873473, 0.026591840733383453, 0.016942789042068106, 0.06824554079362462, 0.022624212001720746, 0.02739202531595384, 0.062844785636351, 0.05845413655943929, 0.04172440806043245, 0.07650842724908745, 0.0404122794768022, 0.04371177803184237, 0.016043641221439166, 0.015981344866656488, 0.08030322846025229, 0.015461706470007138, 0.04009330344776954, 0.030025123137860533, 0.050037557544607314, 0.046069804323656906, 0.03432598671004657, 0.019955887541835828, 0.022449446278774453, 0.04112410156296627, 0.06225028608535087, 0.08162519744326992, 0.047574002641223134, 0.06062486967552574, 0.0724737485870719, 0.04416766163382319, 0.03015245461175519, 0.13841558638359272, 0.1596326672381932, 0.13143215869222918, 0.08867362769500864, 0.10082723723063547, 0.17070489004254344, 0.17538899675973002, 0.16123968987695633, 0.1771299162458989, 0.16040165097482745, 0.1727372293751086, 0.14103386040416457, 0.12315772729174745, 0.1472515372499343, 0.16680587023015947, 0.11373397248286395, 0.17784354246912465, 0.21245743268199507, 0.1322039769541833, 0.11738066591562764, 0.18015875210685117, 0.1546272326020464, 0.14011824743882303, 0.16440887304563678, 0.06829974151426746, 0.11792386821921795, 0.1877786609674654, 0.07397074567814989, 0.16926665189525775, 0.08806913835747589, 0.16035683483125704, 0.2386776499089695, 0.12587347067892551, 0.16855625856307246, 0.09884419565599772, 0.14420809975314525, 0.2534986320402353, 0.14207445295347323, 0.12027547469422703, 0.20017384100825558, 0.07117676173126505, 0.12650489566787598, 0.1725931742018269, 0.1499659246614864, 0.1532238208117985, 0.26412318370515303, 0.16579251976743822, 0.0912835973224813, 0.14732525023000856, 0.2023356032347487, 0.08212294775031267, 0.2392698511961968, 0.09655903964754074, 0.1975104290871851, 0.11177485583410149, 0.15076365201703965, 0.08285744986947506, 0.11326714914532439, 0.12689564647453447, 0.07474066404205176, 0.10512521265134697, 0.19778167017765586, 0.17444827143223057, 0.17060002792746792, 0.1844088393714159, 0.26181704454845, 0.21383017031175477, 0.1771978682447826, 0.11240114803395926, 0.13842139333005876, 0.139913349562595, 0.17349608542938388, 0.23418028478420552, 0.14902579688256787, 0.07537014316767454, 0.08111019483617238, 0.23594760366024511, 0.20467204882973627, 0.11121323677681147, 0.13438345113348577, 0.22705989589373912, 0.275368741563251, 0.14935611867375914, 0.17706893564712617, 0.10015152469878236, 0.0950052447977566, 0.18451077503062066, 0.17160015571261608, 0.16434006302827792, 0.25964135484349343, 0.1282044617278922, 0.1322490842111649, 0.1902417408963365, 0.255449045930178, 0.14254087792529216, 0.2531479169884997, 0.17759865480324916, 0.1685749511084249, 0.14065015760640945, 0.17716010011011557, 0.11852694029409079, 0.22640911952382137, 0.25797888276077086, 0.13195251625391746, 0.08227949015676014, 0.12033958093173082, 0.12617036039310117, 0.1076192195497213, 0.09759103669033897, 0.09921145820689779, 0.09203877615472002, 0.1729226226527845, 0.17046136601317316, 0.19453002530480587, 0.10370550617094963, 0.11647991505601715, 0.07091808448275251, 0.09895942294068875, 0.09675511985176033, 0.15425186484090744, 0.1115148838969969, 0.17790061601948354, 0.20294435202114045, 0.14388750727859237, 0.07881455874491124, 0.0885917405567823, 0.2146341029794947, 0.10778504694181104, 0.12519839400004956, 0.22822146904805016, 0.12358377176907756, 0.12047414427563069, 0.16910793379910533, 0.15834996026129494, 0.11562900587676034, 0.16057915354688324, 0.08969439388883692, 0.07246521436759541, 0.1588535098539245, 0.1502904395062116, 0.10239090695376359, 0.09115036697156968, 0.09452049500278889, 0.17063154478467282, 0.0956349231062397, 0.140018732617459, 0.07077622032093425, 0.21317541028463075, 0.20723407667490745, 0.10804187025754683, 0.10683229403390039, 0.1221285341307521, 0.12133519645900497, 0.11006367588115316, 0.1937245298177004, 0.11928630196639609, 0.1324212548112677, 0.20862287150756006, 0.19842084797640003, 0.1901909492669567, 0.1272338359887081, 0.20718336165432008, 0.14055399825015377, 0.12787386414504823, 0.12642574346353933, 0.10221921132817384, 0.11223143657609341, 0.1342986605220264, 0.09943694086565126, 0.16394493019869252, 0.12383601387902615, 0.19173274717984662, 0.2604317124332151, 0.17300270948438876, 0.14500218053017894, 0.1614855581353749], [0.022489037702701265, 0.0373098072445681, 0.05010803763364112, 0.028106544031611377, 0.08723971794449514, 0.038856331919950825, 0.019024966224547357, 0.042613751870850404, 0.098898472985433, 0.04730766068302816, 0.05022996435722998, 0.050269099958841844, 0.05152900815911351, 0.013890893934595009, 0.007886459098963608, 0.028708106913273374, 0.009352925192234258, 0.055061654082589576, 0.05840878032388226, 0.08668661778492313, 0.040914852307328296, 0.02754481772201196, 0.03991746711694906, 0.04244995078132038, 0.018858537453437046, 0.03370881861736698, 0.05704411726084448, 0.0607459383806394, 0.04749409967072068, 0.025922186041791594, 0.011279256150667227, 0.020114716720737277, 0.03529495769931424, 0.03295535199163902, 0.033690639350923805, 0.021494481291982438, 0.0527616436292808, 0.03251214714480504, 0.06005016966692864, 0.04257172428732438, 0.030098989335519653, 0.06874066341908709, 0.0752071962661801, 0.07137384551066546, 0.06740115102260344, 0.030883792787790302, 0.04170254008063386, 0.07246226492908693, 0.02616389444278133, 0.071982019731114, 0.06779950908235005, 0.08661819847240564, 0.04194615604055505, 0.03644702370248495, 0.05989469978357515, 0.03568054124292347, 0.05282191176628394, 0.0400655021169974, 0.03734000260010362, 0.024509747820575873, 0.03949404266032, 0.07579774280349094, 0.05764905859025256, 0.062204493179677, 0.03398374842119313, 0.058144426363850796, 0.005490424312395795, 0.03610149123555711, 0.008875109450591188, 0.03263847504351889, 0.06071995650868743, 0.04660770912925082, 0.00930443278423721, 0.04786624603213803, 0.01665071036005693, 0.0445219045204501, 0.01668276922446826, 0.0953563352325751, 0.0037412550168923076, 0.031234708937606027, 0.022639667825593103, 0.013137292285870402, 0.028137758284086184, 0.026125653248821056, 0.06751669240334342, 0.04998579298356368, 0.04344203847370321, 0.04226398293770129, 0.026356010141992764, 0.052202414766314535, 0.05807379688767176, 0.0852319393907824, 0.04529567630661111, 0.010115614558960642, 0.09798624612871679, 0.0035637756668767265, 0.0797897044028486, 0.020180992902286594, 0.023328503443589135, 0.017129095879593687, 0.016027880877616908, 0.0037017232041821006, 0.08486478409219174, 0.07727675981098607, 0.014843872838443326, 0.07600415753380907, 0.03708036008080648, 0.04001259608494659, 0.022700387954471574, 0.024753838755010117, 0.024934708283493118, 0.06320694604167534, 0.019337430506223635, 0.04108837888305707, 0.020267465076739752, 0.06445112262642191, 0.09145880163076425, 0.04822700832700057, 0.05602639626651522, 0.02613685536949385, 0.02064190970192994, 0.025074636158082756, 0.04097347718573386, 0.05407887052804713, 0.03378780994323954, 0.021434554064105597, 0.03538134177365611, 0.020152048185287465, 0.04205042443748924, 0.02746259925075837, 0.0739861210627902, 0.012139705039801137, 0.017336129225910674, 0.03295948503599052, 0.05586471341009583, 0.06222573296737768, 0.00881154234746411, 0.01917774139362718, 0.04230540148132751, 0.04949923139065505, 0.028941851830290213, 0.04791499603719962, 0.05164068845671512, 0.03767284482056576, 0.05726050645593674, 0.09911368240512188, 0.029066327711447116, 0.01556079323974348, 0.030440656888869502, 0.09680624855982681, 0.060527430952436505, 0.039781340953683665, 0.05233619287009201, 0.022448463771011562, 0.06912517827004194, 0.006985866723792448, 0.10524607068228145, 0.018064876109541907, 0.055971666945204626, 0.03475912516155551, 0.06285818834458629, 0.008027057300486994, 0.030839373094720707, 0.035662473059229316, 0.0029569883049736104, 0.03382555892570846, 0.021121193459557912, 0.05827416718426732, 0.02916947378957224, 0.07279275525962153, 0.021783039799981543, 0.16243192186999708, 0.06846291058125996, 0.04808003818916698, 0.024436243599460974, 0.05395107174051866, 0.03460919026345496, 0.015798432756245376, 0.024740058748472123, 0.0051352448832814495, 0.03225978246078857, 0.05291341713839962, 0.019949567316460515, 0.018935305209109382, 0.05585734364426425, 0.01563063747580013, 0.028950987428787257, 0.05823084108170964, 0.028697103975460898, 0.042513321574416854, 0.023927725926642458, 0.024421821994286393, 0.020111299968594988, 0.018457817927663846, 0.07826845296808789, 0.03601047999015258, 0.029531050052854325, 0.04088151216086361, 0.013366035606351592, 0.04056406830767951, 0.012499255000523502, 0.049991695691020265, 0.08209844825849419, 0.0705043510383656, 0.1120782343129958, 0.015319436281589011, 0.06926411597598946, 0.042045192056966406, 0.033323817300580205, 0.07280204790614306, 0.01225232954076942, 0.03213768336741674, 0.050452198803184495, 0.04856614395976067, 0.01685525966627944, 0.008802387596768959, 0.02022003848856736, 0.048488175361267025, 0.03559760073380124, 0.03334426418727925, 0.018248718059171113, 0.03960366218140529, 0.059266990321057464, 0.04259376846734555, 0.04826649249861798, 0.0632633492651005, 0.017804911833316568, 0.03297187650816576, 0.020032249270908294, 0.03001157487291963, 0.035888786923380635, 0.14117636807983922, 0.05298971949565796, 0.025524299126118425, 0.04146039883996691, 0.020825548638259212, 0.015959625316393233, 0.039196704784708644, 0.05201175846459885, 0.04893043408951452, 0.022608660416857853, 0.06763044113834059, 0.016699360773688363, 0.0076688216593597215, 0.041384349291723584, 0.025278128262969757, 0.011561506882219786, 0.0533318160582454, 0.02529136051664189, 0.06925294641405344, 0.018046735147494945, 0.04407409931563082, 0.1114212449700121, 0.01741341600615171, 0.017517368391817136, 0.07053003796646673, 0.033875557654086626, 0.015268236710389536, 0.04725394642821724, 0.03217522550614611, 0.009053767857802732, 0.053642905212097594, 0.021771600192052223, 0.050162039171423645, 0.07244317401801387, 0.009198098822737174, 0.055993649838191856, 0.05716226717096664, 0.08467696231579588, 0.03029642934580484, 0.05719144746000248, 0.027359495307469082, 0.129043159465636, 0.03129352916843228, 0.009257778029648528, 0.04264780447908467, 0.05093042152903734, 0.03572878179951541, 0.06319248613210456, 0.08096177296172227, 0.05115135362552059, 0.02432558794445809, 0.023017201700337955, 0.015134634806834643, 0.021487760785666686, 0.05027679531204124, 0.001570713183384449, 0.040390936267231746, 0.034002379679511634, 0.054803038121110974, 0.018903941569489338, 0.06595648539763305, 0.017074651926034884, 0.044575668570976106, 0.03168778674256417, 0.03677192925205154, 0.04074460458791545, 0.009063974064173958, 0.042998140317297755, 0.0625158159903461, 0.02001677621005764, 0.03410261462352449, 0.012151837957301929, 0.06392656690290859, 0.03686264555360522, 0.04802535100269222, 0.041045703955235026, 0.053497080375710805, 0.03136057909878512, 0.04189628754712401, 0.056430457850858096, 0.04322667200598986, 0.025600258659030643, 0.05042586836122698, 0.08182465609523558, 0.05253177511716082, 0.042184397893687414, 0.11405102563120666, 0.030088821433544643, 0.08206302435287545, 0.02103028755124298, 0.13098499317082668, 0.07079987711603604, 0.048681938149515665, 0.0375990437403802, 0.08886466704068646, 0.06508355885143242, 0.01202519500492922, 0.05764407518830511, 0.020267474652838804, 0.019941460191001816, 0.05668659934834127, 0.03331722128355215, 0.06081334262665722, 0.05010936679618974, 0.05592288629662606, 0.042474484747095455, 0.07575214525023777, 0.0245473014506241, 0.030428721239009214, 0.05403571296483279, 0.0168384651037594, 0.014834773629122685, 0.026095536417297782, 0.01614108185974821, 0.047369277134778044, 0.10442560583713556, 0.04901094226947716, 0.00976934664762549, 0.026965115159269304, 0.01763949429826631, 0.04599551677763943, 0.10747101217989, 0.1265851893432198, 0.16978826584114184, 0.0845347151100155, 0.13354159711349395, 0.23459944213109635, 0.06900534679692599, 0.14584225722618643, 0.26385134506610136, 0.10209352694331639, 0.1391140287441592, 0.16149939368328742, 0.09127165401174177, 0.11625401104890531, 0.1321193089167918, 0.15300707921626108, 0.11199697536686737, 0.15663801422042234, 0.1899551167603462, 0.15444370857890577, 0.11956420036092882, 0.1447351988885672, 0.15710754950921382, 0.12915796540196867, 0.08618315246196524, 0.15716088455050223, 0.25115247245036787, 0.14195806887601653, 0.32649999304163846, 0.10896494491927086, 0.11742199635914258, 0.08702598707450014, 0.11973888372942326, 0.11332672780319569, 0.11172659995575106, 0.13081107589025653, 0.1519205213914956, 0.16172592588249715, 0.12518029900327807, 0.09687619238731363, 0.11313656179775154, 0.12481097567586169, 0.17834148429814847, 0.1278260219541769, 0.12316097550454641, 0.11402455729342277, 0.1930285542602501, 0.15146394831038293, 0.08760922513301335, 0.1928018688434555, 0.09534107476112344, 0.17105558977252053, 0.08904220791713846, 0.14184732320568255, 0.13394717938236653, 0.3224828731148474, 0.10279817461606958, 0.16958235672885374, 0.1998174569058803, 0.12001348028500235, 0.10898691632093922, 0.20639180896743653, 0.15210073591480333, 0.11731114343649919, 0.0726175892557348, 0.09782269401776214, 0.04809619115305044, 0.14602840127002809, 0.16531792829834646, 0.09920621050461646, 0.20287687499676982, 0.109818703945606, 0.06841891415176854, 0.1341489516198635, 0.11099976637671072, 0.10879187033541741, 0.17458688738124986, 0.13877972329576171, 0.051501256624056455, 0.1663984799937856, 0.1056927765509294, 0.1284123396861457, 0.11059429136014755, 0.10251957908152573, 0.1169482246041298, 0.25692039439755104, 0.11214789468795062, 0.12323068184477669, 0.1690423873163039, 0.09025351549949377, 0.1781620511845235, 0.1809603405455428, 0.19193130184806165, 0.13685151063386472, 0.17233198418492274, 0.11379801743333379, 0.28204289955958245, 0.11593878885070164, 0.0715532556416527, 0.08131202836070331, 0.15029410140648966, 0.110801158082341, 0.23776128617746217, 0.2669267284293329, 0.09082559165695021, 0.19225606184092262, 0.13684012656730993, 0.0703769046512823, 0.09390250719603031, 0.09902988004708484, 0.10101234705577936, 0.17253651433894712, 0.17437717847285733, 0.1503653935487232, 0.0789538641730624, 0.12180079405586566, 0.18867014216319208, 0.22516969651464494, 0.11427407213036092, 0.22305333265854468, 0.12400741839120466, 0.09052531583414924, 0.09614085523231376, 0.13496557070362952, 0.12850856032943533, 0.12928531985850106, 0.1098061401036478, 0.11375114051324707, 0.15502109372567746, 0.07672758202158636, 0.1435076808857341, 0.07149873316408166, 0.15976995019422424, 0.12056679494919316, 0.17248800565158168, 0.19325802823708904, 0.12818579982605674, 0.111921239914673, 0.10919420439149104, 0.1347797024514406, 0.18762833919496308, 0.13884721564189081, 0.12009476221376851, 0.1331143958433982, 0.1684052319896798, 0.337273211729142, 0.17450319993640148, 0.15328363695692632, 0.08378284577760967, 0.22198756646004417, 0.10165289615190799, 0.05564798330587726, 0.11657330117398694, 0.12960802673572494, 0.14208133242303325, 0.086199646334975, 0.15481366775929928, 0.13248438045622843, 0.24057650608160805, 0.16398757065255798, 0.10511285565312832, 0.13284571348659455, 0.18036564181168235, 0.15394690056000987, 0.0998464914699716, 0.07711310044772203, 0.2041343470374423, 0.14660682829637683, 0.1644133010338391, 0.11614701154852107, 0.2676677806002479, 0.177489165517111, 0.20643812664333852, 0.30855591559121687, 0.12783290142373693, 0.15328734482247985], [0.06178954165549048, 0.06177862107212986, 0.0739987385309031, 0.005019791123847808, 0.029647604584874167, 0.0410085103865112, 0.07549775043322195, 0.06013044802051398, 0.05296584053505814, 0.03682737486557134, 0.03567322127280697, 0.06670709068496382, 0.032637827699222875, 0.021607527141309073, 0.08741743502116973, 0.05756950418975565, 0.010564208834341938, 0.029374009689256072, 0.04881830946091683, 0.027031485186589342, 0.04190278014228229, 0.10314696678711523, 0.10221580223691079, 0.012332772603258492, 0.04209414124488831, 0.00842836719276684, 0.027738948232464256, 0.06477795105667845, 0.043305778245051066, 0.0671591208646855, 0.04772052844806064, 0.014878392760311405, 0.0355526352030856, 0.02420595373898264, 0.0232121825683862, 0.028376620668437214, 0.08178845077993409, 0.07787631554228645, 0.02985025782348408, 0.024726583261884028, 0.008448215573275042, 0.0196622422100195, 0.010190967924802775, 0.02861461928865362, 0.024275893736029827, 0.039293247184926466, 0.036785136607866135, 0.018734477174979065, 0.021544303820138017, 0.01081889093432936, 0.027462009363056674, 0.035235876998593735, 0.022056303362572388, 0.04487120997040503, 0.009207532237914783, 0.07662416781268774, 0.004191097536785228, 0.05507884509561043, 0.04282015127941005, 0.01017224665115317, 0.11669695542584504, 0.02645485272120324, 0.031431235388041504, 0.05527224399209504, 0.02568434830003929, 0.1113645084983399, 0.02851787962079529, 0.020575003413062905, 0.11784136821065219, 0.006841743081402515, 0.023137705415607463, 0.03137207616330876, 0.09365574261474033, 0.04991922377338333, 0.014324825287105577, 0.04154497494680747, 0.0718753343267787, 0.005885321091139509, 0.04066237271012318, 0.08914029781496333, 0.013104248998476373, 0.05776925395513254, 0.028809328195488745, 0.042684274094720046, 0.020713969847307574, 0.03179402398546377, 0.026184521360142578, 0.05337357551099793, 0.0639833570007355, 0.016203443332004453, 0.034412661897799665, 0.07399128449539985, 0.014265101072528671, 0.04167767669705134, 0.07990535303589799, 0.025435239489701007, 0.030034015503441615, 0.038015856858222716, 0.05570530583481154, 0.03439786107910257, 0.03183588686008607, 0.045223415063153354, 0.04526713953143166, 0.04314952695201482, 0.048446224386533426, 0.04024705346373301, 0.018627738144489068, 0.027878397302101218, 0.02316059037712553, 0.030994661032192172, 0.027805212922694705, 0.005400862409583023, 0.01691904031641541, 0.04798008669768611, 0.06554786942058033, 0.13450093837755342, 0.04306081397038314, 0.014243887140295439, 0.055462061427533633, 0.04904791750314255, 0.02277026666448482, 0.04390760542704694, 0.03017952432855964, 0.07571449202875938, 0.04703573777430481, 0.028196950067555713, 0.041691872306288257, 0.02544895437876544, 0.05905864121873052, 0.04485188157207543, 0.11242607653501535, 0.021095834034044417, 0.008319833601314214, 0.037253863673897526, 0.09004721568236429, 0.03997596942128674, 0.05858082068903793, 0.06006723427544198, 0.033152454923237526, 0.02293377855582343, 0.0037346283563472814, 0.03532807184984127, 0.06417228194374232, 0.09602378167572523, 0.052967874498497096, 0.05596750708777578, 0.03179151696273156, 0.016720916572657805, 0.019157022545715014, 0.03651859163637123, 0.022829479515372265, 0.01048533050643821, 0.039092953497123335, 0.005021101134198328, 0.01965003459894609, 0.134827199902746, 0.01921501923202267, 0.03218312770308506, 0.04759400902736572, 0.025650299522244645, 0.040265351473804445, 0.08098490881703554, 0.03310560098578853, 0.029826555063106844, 0.036508605680278236, 0.06592909775434003, 0.07804632577444277, 0.05673064174310816, 0.009112563190771448, 0.013334736126595208, 0.010091756665778738, 0.08271318785245381, 0.050568253462833744, 0.02171811193317896, 0.05657894484278175, 0.016955245631716905, 0.09977116970525635, 0.03188495862207586, 0.04521077461240273, 0.04948291754830749, 0.04986143776125485, 0.03274296943639075, 0.019217307919696457, 0.025091174081148162, 0.022251860711783655, 0.013947822885858196, 0.06337788324022005, 0.04598112581598182, 0.039091252781931436, 0.006700309365236711, 0.07753556729444573, 0.017228907560028376, 0.0072247329385830995, 0.031019118389174826, 0.016123279891607743, 0.0484184077340028, 0.050469998856105154, 0.018547264438483025, 0.05625935211297005, 0.020134700124242136, 0.038324823948524656, 0.0268400302382126, 0.10859227378762538, 0.03607271697312113, 0.05574281349958432, 0.03838536404674092, 0.05868385951485365, 0.056390885579129385, 0.046697471651338765, 0.010462090271645257, 0.02989490925815077, 0.010154343176362737, 0.028990262841445305, 0.08046266667905354, 0.00630257087909887, 0.03312209868923791, 0.07480077896147005, 0.060784238946413806, 0.07964843012873205, 0.052531227364294955, 0.021551087528707522, 0.04425103498262264, 0.004557006984889027, 0.037850385697017756, 0.03444984780564424, 0.02273957718223814, 0.03887386384209798, 0.03649516466764673, 0.042299456639035095, 0.030635762246205445, 0.030756223826639117, 0.05352887302456845, 0.0619160610761854, 0.060665085461110844, 0.01721777055682915, 0.015189644707847508, 0.05771802182519629, 0.05455107946369437, 0.05021970260948424, 0.052064354231040326, 0.05269387166105932, 0.08332651018375352, 0.03709257152231951, 0.01002067807055409, 0.009607725078240037, 0.06850824000373965, 0.09566604925860321, 0.03793851262138736, 0.04388478749822225, 0.0537604728953973, 0.023305480586244695, 0.031512999952199965, 0.06384203293090386, 0.019083669626965158, 0.04493002254035204, 0.04069379763677716, 0.047636197489355846, 0.05026053509584839, 0.01802398999702306, 0.04321077185112142, 0.006187786967794021, 0.033637928671293685, 0.06612005283034618, 0.028462064369852026, 0.016455388582882383, 0.043813472373350974, 0.02036303263007393, 0.02536742347142389, 0.010693780157805212, 0.030079216606193976, 0.015976478293117498, 0.01069004643678425, 0.05923474184988488, 0.05988245003766591, 0.011878782196060545, 0.01720664887538841, 0.026331912846334522, 0.05444471581628727, 0.013429961813193177, 0.029778866089820385, 0.06579671010014511, 0.01685569825161609, 0.0421205559565175, 0.11669015256507743, 0.01425731187355855, 0.052488146409873045, 0.01273357256826374, 0.1319360913288209, 0.02850772321013914, 0.012929001597747689, 0.1399635742869108, 0.03252236675771494, 0.08122639505252724, 0.02547610261958213, 0.028105136345050512, 0.03712177479399308, 0.009443375278234242, 0.04399695043121615, 0.030288025361275485, 0.06950843673680099, 0.013316169028140366, 0.0194253716542716, 0.045823625799629, 0.06406563484380323, 0.05676514634321775, 0.03364309976478258, 0.028857605141257087, 0.037153402733947, 0.04323338293620656, 0.09772916234308675, 0.08392937541488679, 0.043989396804282745, 0.01736643949463483, 0.011358971429628231, 0.06244291506347157, 0.07871625434246757, 0.03484541730534646, 0.05360314141838782, 0.02535542844974947, 0.015274902632940682, 0.05092351524639995, 0.06995717273844827, 0.020827276166528467, 0.0540646557666121, 0.0566736831059379, 0.03519110682029878, 0.04079502849509159, 0.0759989021706485, 0.016035182653145207, 0.031192888197819554, 0.09306190189935508, 0.0923676347179759, 0.020965317549604564, 0.046139491511689085, 0.03275616530088648, 0.06187291883472955, 0.05399173951797909, 0.046816368497187094, 0.05766720338273914, 0.02091949400041373, 0.028214158317554864, 0.05061196643979319, 0.06313520956844573, 0.038016695724499804, 0.04956969615793036, 0.030692016082485358, 0.02375142611262779, 0.05724754424825792, 0.03911900048654887, 0.07491569215011212, 0.010718516179270322, 0.020922121681994008, 0.13654207239948934, 0.1992617673691242, 0.1993717622732924, 0.15807815226576022, 0.19281820183800114, 0.1341995747099, 0.18441041751253992, 0.1477023340280979, 0.19200070941400146, 0.08596550688267716, 0.16632655965945414, 0.15891092048297006, 0.17105408824018895, 0.16859419523708283, 0.3066651799505757, 0.15926307578000332, 0.15974741188749192, 0.088812465809526, 0.12628443088502656, 0.15404698228643787, 0.08170061879941533, 0.19276540305825973, 0.2383750605006372, 0.0954762662971212, 0.1555634533325511, 0.18234046326289255, 0.27548043718261106, 0.16246930696070194, 0.17302336321482736, 0.11472311456717792, 0.15481104773859825, 0.09961000778862547, 0.12216983393075005, 0.0955552269794768, 0.12312322269163786, 0.16919370500310776, 0.13579345127988246, 0.18560338494998796, 0.06704662085300492, 0.08264384923442718, 0.14861423912788593, 0.14676246671907364, 0.1795090329382689, 0.13519204161580534, 0.11463367380201818, 0.21234126310915719, 0.11697738957140716, 0.10532185209975128, 0.18458445736717793, 0.16687671804139692, 0.18169681151067058, 0.10798928598242422, 0.1074190944012615, 0.10776862967759372, 0.1168306224468735, 0.13866284892203348, 0.09452663136706238, 0.10894635962622781, 0.12498863146550233, 0.09029147515614187, 0.1983620890326077, 0.10802392847836019, 0.14878044956393782, 0.15216858066137762, 0.09493810485207266, 0.20518079249849244, 0.13071110141613793, 0.07874957150629452, 0.15489874948416987, 0.136255509550533, 0.21197245306065007, 0.12582733686412537, 0.23547557092482047, 0.10842156641545797, 0.16585176900750206, 0.17314357773190545, 0.17543632567169207, 0.07193990787791629, 0.17432945119517465, 0.17753638717676365, 0.10813850458831557, 0.12133646816495927, 0.09464249450473056, 0.11276801988001793, 0.18677617363151044, 0.1799841913124246, 0.18260929883728105, 0.15906997565780917, 0.16477803549458905, 0.16225109447634992, 0.15123681856259225, 0.15836022583948028, 0.1926079566680616, 0.1373518426572123, 0.25053210977104406, 0.1822186093176565, 0.14739044431236484, 0.25165663491333684, 0.11928726723718068, 0.08862840552483836, 0.0721366009524753, 0.26836335779197756, 0.19809659360156906, 0.12731323334118053, 0.10971260076809315, 0.1299122862157322, 0.0719158373953354, 0.17175430792473978, 0.05961400899855841, 0.1457559344388785, 0.28002122417092323, 0.24473901417466903, 0.1104109971633842, 0.0755085522729543, 0.27597949750000433, 0.2428959138811596, 0.11326007049290404, 0.17805083053967646, 0.1779968366627732, 0.11196456218679106, 0.0662780737864875, 0.15276134885366888, 0.15547339203617266, 0.08938202153771155, 0.1994019001722336, 0.11154707491157517, 0.09688104938475356, 0.2255595586593113, 0.18511589256025132, 0.16155067560893877, 0.18397334902997942, 0.12550448443019582, 0.10344824618509701, 0.17083098811487998, 0.22414955851291457, 0.16501777504961337, 0.22492771998288172, 0.1101953893779747, 0.18309818550703988, 0.187089120548579, 0.08188392831793717, 0.08679414588597514, 0.12896230654610744, 0.12085612337555617, 0.20982549165285405, 0.18299546843815237, 0.18357521313573086, 0.18323172995400044, 0.0997383734812179, 0.15227328955886826, 0.07886925742270486, 0.1548063133152262, 0.23567489168095976, 0.05713047069166938, 0.11617669745558694, 0.2507714203168308, 0.19700925436712083, 0.15687576194684352, 0.1514819513766035, 0.12245585285728017, 0.14041688383346604, 0.1299175722224097, 0.12270156789811389, 0.15970092567224659, 0.11255687072632775, 0.20039216074491703, 0.24740481629006325, 0.09159682769208186, 0.11359405418437336, 0.12529777858646649, 0.07291263269801294, 0.22151700461343413, 0.15468920911512068, 0.13874249142264167, 0.14653532164952449, 0.09986169831526857], [0.07086132502844257, 0.05904720352602102, 0.03833779381708272, 0.016748137591827302, 0.022197866834880366, 0.022876377502876907, 0.018311138903241486, 0.04328678309496853, 0.010525893904418956, 0.024872588128933025, 0.047626713320853255, 0.05674966753670766, 0.016344796130133253, 0.061572493624783335, 0.025802682071263273, 0.04260415661959879, 0.04930340782589009, 0.03460934731147943, 0.1108927898589642, 0.026212510382456165, 0.09944368243938494, 0.054199529376121304, 0.07048112325250142, 0.07871920378097604, 0.03689628064392075, 0.046074105907351746, 0.05340607679118553, 0.050178444944322116, 0.04068510253883658, 0.0993713714002121, 0.03831080836994994, 0.02930323657159123, 0.00504321186810792, 0.028488050072243618, 0.02089063163786646, 0.05729934711369777, 0.04565855683458429, 0.015856356664200225, 0.04760553482018652, 0.027482253236455784, 0.04810078768059612, 0.02386151677778652, 0.03497260705297513, 0.03244544386923794, 0.07468240305541024, 0.028934240746762485, 0.04748360426615804, 0.0460482542703469, 0.031161587760453264, 0.02085668053628216, 0.029415313319693652, 0.07058919527597966, 0.051648372318595655, 0.021931913666306965, 0.053451896509936744, 0.01981177682717962, 0.04194249030983737, 0.07168178221270924, 0.0021152642805264484, 0.03908284879740208, 0.0397305914591397, 0.021266518423574108, 0.12879600417950463, 0.11525228980087465, 0.04728124980183859, 0.034816846056210424, 0.05772917989581343, 0.05151701122221928, 0.012843112607726888, 0.026265046777083512, 0.02653736039064825, 0.04788563571750157, 0.009929254095280364, 0.07949150467832243, 0.08230480936265762, 0.0363281958045498, 0.05418300102915495, 0.07509281167820578, 0.057815307330700665, 0.003073343414730663, 0.048835251495362296, 0.03927635494619608, 0.026280571548869053, 0.05510206905103499, 0.003581330092856661, 0.042704498815921046, 0.008671359748639649, 0.09637020663508485, 0.0490746118368641, 0.026441997765833815, 0.019188930107761296, 0.021795994346781124, 0.1416108931504911, 0.07188569183551496, 0.043147362753628724, 0.05082608418418996, 0.05908037130270274, 0.034475622833856655, 0.022146519791755467, 0.028277599973784342, 0.029358802843959104, 0.020449257741171508, 0.03259974929894651, 0.06257569342250786, 0.04645311641657064, 0.03788711195210776, 0.006172049127804537, 0.030618703383351528, 0.029842614181219574, 0.03989424699196412, 0.03196411848729176, 0.06902538765702518, 0.02796621204564168, 0.037118718103175206, 0.0174287166972194, 0.05406848237579388, 0.0325199612416327, 0.04050480757629679, 0.040631644923480294, 0.05928495508288184, 0.033278399777989236, 0.0394084744696175, 0.014898981373276443, 0.05089120931863304, 0.07873536823617835, 0.03436323007448547, 0.035040363699438117, 0.054527870830028295, 0.06101834775519468, 0.05143705079512251, 0.021916145661605463, 0.03247220715087268, 0.015930742844037952, 0.050180206946547956, 0.00565191756205393, 0.035728509838302294, 0.034580370035743525, 0.045415059618291356, 0.06142812052501306, 0.013713395192978844, 0.11945351597762878, 0.03613192790878877, 0.08583359420299531, 0.07992891790044886, 0.05689191857292768, 0.02897568418824625, 0.05228959940253727, 0.014249644291046408, 0.07165671581582678, 0.03344231195026829, 0.019686693821342725, 0.004909388277859938, 0.03528344722825193, 0.0060658305582980965, 0.07149445839346417, 0.009607577606314614, 0.04690416983418888, 0.04166548440773641, 0.06278401571175744, 0.06405934526194489, 0.054279983929929235, 0.02991686725328046, 0.02474979381076992, 0.048155061179591764, 0.07990372892949851, 0.007528327358511067, 0.0343165063719836, 0.013851182809430025, 0.11245677367814126, 0.02314930781722069, 0.05333209951077739, 0.013442015249071824, 0.030758619766622305, 0.06674980008674246, 0.019887858934159723, 0.03945256282965984, 0.022038099198271672, 0.016548813005248388, 0.007737195485406706, 0.025116158123578758, 0.028155625369700215, 0.05684596861922934, 0.048273253224549756, 0.0586749192687773, 0.038649254523578196, 0.01919104642565212, 0.007285410453820782, 0.10431755679629504, 0.0372601953905917, 0.09363307407306087, 0.03402566109153052, 0.006098521445246955, 0.03199967837351705, 0.024099664785148158, 0.09184526234504678, 0.05588728619078475, 0.009740700704916831, 0.05187524925737132, 0.11633891657355333, 0.04170371985603725, 0.01754790848691858, 0.03908282581476435, 0.0219062190773266, 0.059999014145784804, 0.036188568619470445, 0.03731063461952633, 0.015604833719290554, 0.06706881442017133, 0.038937633000915094, 0.030624615666907162, 0.016375447307983716, 0.04873387891078188, 0.03705239787157025, 0.04644522954139017, 0.03265462800740235, 0.010077578293520116, 0.08762034106879465, 0.04838997821113275, 0.07151376380915604, 0.047290312621982834, 0.026499280075152076, 0.03783601388755826, 0.028156686401475343, 0.05349555203030187, 0.02998931044262023, 0.06265234818021137, 0.08943277486269513, 0.039589374641617464, 0.03819824707123541, 0.02437215076849586, 0.0629462463210427, 0.026480480277490233, 0.026618197988418323, 0.06530867378798223, 0.016503138843202786, 0.05945409197480448, 0.04391353494758087, 0.018421055283397436, 0.05007381648606351, 0.037806653567860206, 0.0444190304035381, 0.04594160333996819, 0.04733608637545859, 0.04792627668188465, 0.08755081858966621, 0.040804225380622575, 0.02829868654390016, 0.008566225672351017, 0.042299307251889864, 0.029377296206451235, 0.02003280851509302, 0.016653016284709016, 0.022800506070075978, 0.0435790762815985, 0.06753212141413843, 0.019496292243861867, 0.033488365325836406, 0.009250296223458023, 0.031752871657391234, 0.05700818773719573, 0.014179091423659796, 0.10138698703339023, 0.03551588979579749, 0.016146436814338933, 0.010087720340027685, 0.03370181657373905, 0.05086652213527311, 0.041310797190113414, 0.055712733057237444, 0.04884533704288545, 0.044355674932200106, 0.04487889000184594, 0.057049748007087946, 0.02968568298515053, 0.10177425213999326, 0.021333039753259193, 0.05976248066872359, 0.023622723341348673, 0.0302523409857625, 0.030145996490553505, 0.06515855119834024, 0.0052972801401460125, 0.03694710674725714, 0.033227864788064075, 0.0319038829090254, 0.06780700908312876, 0.04757058971952047, 0.016336800087423577, 0.03589251011069264, 0.019433003805217244, 0.11567730005950698, 0.033879273180519386, 0.03270366529543554, 0.004851343711057017, 0.07184649111642953, 0.010641013936800583, 0.04722465122599275, 0.057029377729181326, 0.08378069307054244, 0.02222418770073883, 0.10428253125639693, 0.02312710084351561, 0.055776567333528114, 0.04171201658825721, 0.03412229159185964, 0.02452505617252281, 0.025555814068103512, 0.024383096249714017, 0.05657486542458496, 0.03381139012954889, 0.028499300073411678, 0.04434369714750398, 0.03712522985053159, 0.012442619077891353, 0.10711911735275101, 0.04639629184478714, 0.02710934461755378, 0.06641898033840042, 0.041789724716856595, 0.07346656789342243, 0.04824607242499629, 0.037925305265572765, 0.030317485272403688, 0.0707416161293945, 0.07516444856000525, 0.025808672878831148, 0.05421876201346036, 0.019679130618310264, 0.011860682411239514, 0.06440434529776536, 0.07668660397851661, 0.07661307485954416, 0.027927656755632455, 0.03376832066644584, 0.053657962670249325, 0.07168773471588089, 0.057698367839498874, 0.019646975992908402, 0.06474956749908387, 0.08349475841368399, 0.025198359357854052, 0.07251313316725916, 0.042045314631034295, 0.06869607710189397, 0.09324777015154401, 0.02123259988072659, 0.03351333596172833, 0.04915264172239169, 0.021723725442444126, 0.0792745485781662, 0.023214086296878034, 0.032595363445580006, 0.12393592706611081, 0.15336116505486352, 0.31190923565337736, 0.08333414808035859, 0.07191425159333215, 0.1956110979400335, 0.10048472698056891, 0.21840092665966482, 0.15684156378190364, 0.1573257313500489, 0.13657073940961592, 0.13922972334248407, 0.11714449633033046, 0.20853562941474302, 0.17257861853126558, 0.1323322660379833, 0.1318603558766265, 0.1381232012664118, 0.1874115209906332, 0.12844040914769136, 0.1756032409086343, 0.17392841948857232, 0.30396331041570634, 0.1548431468226256, 0.10111835064186205, 0.14628442785432264, 0.15314255420479084, 0.11344301995010146, 0.11982803338117178, 0.28076874212391917, 0.1507160166699079, 0.15946981226724966, 0.11299865064962257, 0.07924067983103376, 0.1373932726921574, 0.13367419161142843, 0.15984321884330244, 0.0936717002262031, 0.13005022800737812, 0.06591100275756852, 0.14201967766688717, 0.16867677951532026, 0.1626408953339823, 0.1367892430073792, 0.1519819463212644, 0.10745631095262305, 0.12047775254975404, 0.1607160074936767, 0.10930824423989943, 0.18978979498628648, 0.3140921878718561, 0.15078197684018843, 0.1408692434309952, 0.06712494568238336, 0.20270838161870358, 0.0842538366334573, 0.10524201041628277, 0.27530019201578637, 0.088276372801873, 0.21435166168357098, 0.17165169810816167, 0.12330069462017668, 0.2316950342708057, 0.20152590958581817, 0.15956808602617634, 0.1346559945734278, 0.08934939385301645, 0.13457256759847366, 0.1575910735635027, 0.08509063447314887, 0.164082826025063, 0.17273960424767387, 0.12232568685806568, 0.09853788306035342, 0.15646349939127124, 0.1870246159453546, 0.1453791570759589, 0.1959344330093553, 0.14821572018967522, 0.06284375524809284, 0.16595091610666246, 0.14352370744511006, 0.18101975832495, 0.12090237210354499, 0.13595747070447092, 0.1791076181877044, 0.16000120149504754, 0.08352403829414999, 0.09094425101554202, 0.08545841030295818, 0.1794911218025992, 0.18886140367436796, 0.28603323705254063, 0.15278359604699, 0.20453164023497414, 0.1487028601789667, 0.16402114062539994, 0.1108205401068253, 0.11809361798148002, 0.10446904302244225, 0.19134484622026646, 0.07200612085721186, 0.11264729208403057, 0.19598474966422205, 0.18909602576205808, 0.08366518233331942, 0.12268233909121445, 0.14287469307741812, 0.09427983614225542, 0.16758496632739422, 0.12280616954329515, 0.11775100047910407, 0.23059965111315253, 0.10543551656507677, 0.1269451893805977, 0.09336492797780423, 0.09212017299667483, 0.15778126255158456, 0.13980199102192156, 0.14529286493216792, 0.12868040151173069, 0.24693943319782136, 0.16050418418261314, 0.08841460570693017, 0.23174630087469858, 0.09293443252963406, 0.12042956561931681, 0.1721233171561072, 0.28123584125311146, 0.2458768079598104, 0.12994769479959242, 0.08077879286100788, 0.13645838495464097, 0.09409998934115134, 0.07018684589814755, 0.14390468296985473, 0.06684867905512934, 0.21631471602426422, 0.21890596246286748, 0.18357887503600892, 0.36746139668168565, 0.1966417313463265, 0.15479008757298993, 0.17790824625520937, 0.15084971433445332, 0.11180952897355442, 0.16677300505820783, 0.1297851462638186, 0.1515933252390354, 0.10925514668586755, 0.12564915247381697, 0.11833414660706637, 0.17234738255220075, 0.22767641281168308, 0.23190940099377788, 0.14092636294662952, 0.18237542751575672, 0.10494512836298636, 0.14473748183058155, 0.21587576296541, 0.08692645693137761, 0.07451880497918015, 0.25527053212206213, 0.1603883670102204, 0.17673527371258507, 0.12604748755092585, 0.15549580776883712, 0.14544880979003447, 0.2306026694995742, 0.14986984191402314, 0.2082584128384629, 0.07110938429832458, 0.0787648702821424, 0.2176374587560854, 0.18536277205472995, 0.10854309094288658], [0.03183041316186709, 0.06201165735781674, 0.061791931849814234, 0.027887270515484196, 0.06346770704934193, 0.056177430500787114, 0.044328222171433514, 0.02281337251676427, 0.04597001754107975, 0.05255280806112194, 0.11752070678818612, 0.0411966998851107, 0.06193864534819319, 0.018525084277855295, 0.009465979660050044, 0.03890818841154537, 0.08986605121003044, 0.0888652109631127, 0.04491483101681356, 0.028820336878960653, 0.012082717674333724, 0.10880467166463215, 0.023910762824779077, 0.10622121634021883, 0.02685407262986466, 0.08464241175041085, 0.06295257037685764, 0.026398822965641177, 0.019133289141820806, 0.026648931520720644, 0.044580219133246335, 0.0591991302527247, 0.06575331888011386, 0.021067732013762, 0.014818758561065602, 0.032609068758545384, 0.05397398926077351, 0.04777448785100733, 0.007289127895473353, 0.08940616096820563, 0.022960093676022465, 0.042771703879078554, 0.07347279618824683, 0.013279662065718685, 0.015018492047074101, 0.0799395205573209, 0.026024294070779316, 0.028871578584995963, 0.09881660882984439, 0.09752601880820529, 0.03952485088619494, 0.03794615051799244, 0.013070676152804687, 0.04223118671366284, 0.015753265169839707, 0.0733714197732268, 0.045504642109717094, 0.0879049886979403, 0.027276382428563894, 0.08900018033361243, 0.007963648202994299, 0.05191150819882751, 0.0075594803239519325, 0.04897724589212768, 0.010679985787118635, 0.03672311795995601, 0.019081681628801653, 0.007095990905297861, 0.010912328763234039, 0.04078121209937719, 0.013921292303430458, 0.03050276172167111, 0.08054034799457559, 0.03960862260071501, 0.027679134002556244, 0.021429928808262753, 0.0645326420424446, 0.054692778916608904, 0.0016623598029611693, 0.03210108926249368, 0.015838322954462664, 0.022118772087138028, 0.043389469520339084, 0.029066486674691402, 0.09485408798941682, 0.025644898602378466, 0.07749464287753068, 0.03713154624546728, 0.012913877106902581, 0.08617647217526551, 0.0856741636450733, 0.07580646088406925, 0.016309774420674772, 0.012367215916334141, 0.019689384705176758, 0.023361715270326506, 0.07157109016852994, 0.05032929148705256, 0.022502055451754602, 0.01865956718252311, 0.023246754201189167, 0.042845650515969724, 0.046010474644361005, 0.0275797781444365, 0.041181244061238347, 0.05946216271108678, 0.031244244817043507, 0.10841932943871907, 0.03474062030774451, 0.02508647030129308, 0.05117910899101727, 0.050089348918728294, 0.05998007645229659, 0.04717752915777026, 0.02291820015788319, 0.07300280124670075, 0.040216425268520276, 0.04142273412716966, 0.05272488290023419, 0.041852398369941986, 0.007044767393850752, 0.10743409440281892, 0.016273479090042172, 0.045713412560402386, 0.02365308723622753, 0.044382468857351816, 0.023996608722354137, 0.14157286454592982, 0.018835351802408695, 0.03794795848549374, 0.0123566668856168, 0.027325339277365038, 0.11173828279659634, 0.06063199812366117, 0.02923001005734888, 0.06239771970637864, 0.03665658705417187, 0.057926489671151486, 0.02721256730447133, 0.04924128958654981, 0.013049931449425078, 0.01749451215859623, 0.000703170559474177, 0.02519687889294038, 0.05990417246075888, 0.03287485147255563, 0.06702318622340118, 0.04241299086941346, 0.056661977282454895, 0.031094013059872295, 0.05886552194433828, 0.021010313723837177, 0.07648959680790864, 0.009646554244682193, 0.045379210533874656, 0.020970423525619893, 0.06300859438676028, 0.029212684978941278, 0.015907678809467585, 0.039289435897503174, 0.031309594032204444, 0.03361489240741057, 0.013573451039020815, 0.01596259582231963, 0.06545579331296106, 0.04357065314487104, 0.05988259559437152, 0.0058207422731474286, 0.023574829439542467, 0.018641479846630848, 0.03768157822290256, 0.04564685101110128, 0.028452775553770127, 0.023854032098766298, 0.04334094551121516, 0.06849378392460846, 0.05387508347930928, 0.04420594687783911, 0.07069497669656431, 0.029304843441012408, 0.021266064516478972, 0.01666960783392912, 0.013908074413906905, 0.04689604164131227, 0.040741425323029684, 0.013218630713620975, 0.0747132151117248, 0.06969631980023078, 0.0553521852669937, 0.021169085446144306, 0.045790641884049105, 0.03631021189052732, 0.04957110575971104, 0.046821581725511825, 0.0574464513169181, 0.03953725384968904, 0.041542140421487635, 0.09485829381212112, 0.04817975985427057, 0.01874502812091622, 0.03613031146326854, 0.006828070327173919, 0.038975313035470825, 0.027616594414857608, 0.019794982264659578, 0.05972617959243156, 0.016066233154326197, 0.04859072006037159, 0.03360887861720497, 0.015343895553791476, 0.020987603047321883, 0.055525217716011314, 0.01546018387025763, 0.05209308635864047, 0.03314233490175778, 0.03762570743058478, 0.007417308290549104, 0.01909178632852291, 0.06306336967334633, 0.07198628684085223, 0.015988646642184787, 0.04119411050792664, 0.032509312619485205, 0.022317020320183328, 0.11553697573441653, 0.05895156510955384, 0.07413452761548181, 0.03165500775550402, 0.059720698233333334, 0.04037849882978105, 0.015373699246875703, 0.04244034020831028, 0.013115840866380643, 0.0031001490706037134, 0.01500398425700804, 0.04354468659467755, 0.016199496063974597, 0.010902949931821036, 0.020431490246987632, 0.09448322482527265, 0.017173427472551985, 0.036011399295661724, 0.10060740063988394, 0.05418903780199828, 0.03150197403174976, 0.04493404833239414, 0.10629644617438318, 0.06044903717514488, 0.034000878147180044, 0.015551204691761205, 0.07829970935539854, 0.02159331621031367, 0.07663622603661592, 0.027467318352371938, 0.026961721389764742, 0.02914371982877774, 0.03966733557923187, 0.046947675967408765, 0.015064158548240461, 0.0485225880308257, 0.025889799674792636, 0.02772103901201439, 0.03164292654893812, 0.07443707105853865, 0.017909270245581865, 0.03509736830188382, 0.08711309127149083, 0.05492355907335878, 0.06272079430580621, 0.025016915263427843, 0.03076524642716733, 0.04348180609785261, 0.03091093336772775, 0.018430796091354663, 0.0654835946437332, 0.06302374377546292, 0.014852166697833569, 0.0450666428303286, 0.029720252702733683, 0.03997857028978967, 0.059981397953965974, 0.07970408641643102, 0.04107066309980808, 0.009174416172167948, 0.04158208041542, 0.11220923534804776, 0.013980123067965672, 0.04035030296372791, 0.05358154539980235, 0.04791099705823487, 0.016259773777076797, 0.06849713172883758, 0.12107579142696435, 0.006118840491023636, 0.04268971714942206, 0.02625009848646099, 0.027737887200689124, 0.05183542417662759, 0.019477538411475478, 0.07619951761537984, 0.07183041093089888, 0.01747266716143537, 0.031922966159219225, 0.0760062566147216, 0.01009924326001877, 0.04666184090198048, 0.02123366857338096, 0.01147106541470895, 0.057159149193114815, 0.023925852841667594, 0.03525618215902679, 0.03537384943375665, 0.01747510140581477, 0.015226501197884641, 0.04783650266847784, 0.05501265892939222, 0.05711000848321184, 0.02926114578581145, 0.050627678903120185, 0.11706244831364002, 0.0119212263398954, 0.06090796597662473, 0.09520166974154212, 0.048976682817503336, 0.030952056967503125, 0.011709889494663766, 0.05183149031513641, 0.040300495757330815, 0.02852289749669933, 0.062029855776458025, 0.037303234210177776, 0.025061957402935913, 0.04583187273613388, 0.08301969197007918, 0.11155079809888718, 0.04440515655122938, 0.008288489113892279, 0.00754115310677838, 0.004238978989662663, 0.03826452516800454, 0.11944564825464642, 0.046307977228876085, 0.022767146771413185, 0.030786457486570846, 0.015372113444872442, 0.0155971105954039, 0.06014250624444216, 0.008185140022467221, 0.013919806092857354, 0.06300251164864148, 0.023562966568034985, 0.04657503164884064, 0.13210352750555163, 0.1268291117383107, 0.17809866506966854, 0.10047612381317925, 0.17921295527729297, 0.2259650796411499, 0.19815775806144362, 0.15780301944863412, 0.08506283314237673, 0.09786199432827773, 0.19939426993650777, 0.16803947097111135, 0.12596923166946059, 0.10230843758871479, 0.07397181820124388, 0.1988262310624123, 0.23850603089217218, 0.15017515859536587, 0.12695580735922823, 0.2505475234600806, 0.1556617117697193, 0.19982920869463877, 0.1009452760580086, 0.1205359445884824, 0.16656367919377743, 0.1409331045203632, 0.11260458268225194, 0.0902045701420115, 0.11006234288816491, 0.25379708457377653, 0.1631596287892711, 0.15952003699156547, 0.22554828184506587, 0.08978435559378517, 0.12734475019838543, 0.14815254857943905, 0.23732999399785074, 0.19670545453986815, 0.12067848290767401, 0.14436583725675461, 0.102237137785602, 0.13176280224034864, 0.18272332336393096, 0.16130791766749275, 0.09336364095009143, 0.104662824962889, 0.1757540070121327, 0.054943350954882564, 0.33007826716188465, 0.1478989887982607, 0.2296429451915526, 0.10869358125473223, 0.1654998435368461, 0.13389165332961467, 0.08851864044704745, 0.25915734049293304, 0.09919844237306427, 0.19813076112299197, 0.15212114449710618, 0.1516267726378095, 0.13563090274410863, 0.09724134053554266, 0.11692883491876627, 0.2593435917890841, 0.17761098881883008, 0.15301789637775193, 0.15431374942343082, 0.13695458010319742, 0.0941411818888399, 0.12474696136890881, 0.10571678574647635, 0.1406633343187071, 0.10982083367003549, 0.1313720973989656, 0.17987577454938045, 0.13394333362098665, 0.12314137131456407, 0.2571744597967594, 0.07247495134511302, 0.11072012896258986, 0.13927913601360015, 0.0923575223573754, 0.09603315859191841, 0.1537521303661408, 0.18935701659610196, 0.12271236207696701, 0.1394841564638961, 0.15137163471550713, 0.15805621150760882, 0.17869710231259947, 0.18461614276372618, 0.15470497520460239, 0.2105807624156437, 0.10321285800948259, 0.12083392214751053, 0.13458949814160026, 0.11510189908045916, 0.09357475946026464, 0.1970993616287747, 0.14085994312359443, 0.11765254285907555, 0.15736052706356973, 0.10699863470489941, 0.12329288818422826, 0.14071910551959468, 0.13784616855123352, 0.14921240057916413, 0.24035599533348317, 0.11236364036918649, 0.30174787606923814, 0.16222071142927294, 0.08756650807035547, 0.1692342310543022, 0.0838457952223478, 0.09528921060864964, 0.18129803210256562, 0.20311590975090382, 0.08402749595622863, 0.23553223078770025, 0.13596016733396438, 0.12459924429534905, 0.23286253694565068, 0.09196718523819601, 0.20676570583976087, 0.16897301039388105, 0.12859907361768907, 0.07646529649895045, 0.2341709538332878, 0.09495673611039117, 0.11295289987878454, 0.07817391005735244, 0.09887863130819413, 0.22719783768538507, 0.09948925701000037, 0.07224786756259781, 0.18978066321822906, 0.1186008601179046, 0.1230347471972627, 0.16728456793052537, 0.10928677845626109, 0.11356521863490344, 0.07999546029755185, 0.14045439149823882, 0.19322479534293377, 0.1328411782460828, 0.24519370267948798, 0.23712747099418796, 0.12880947200521348, 0.15561139511485256, 0.08823961590326602, 0.1065559431369747, 0.12615628735793213, 0.19461057178916472, 0.10601449517473098, 0.11911540307224759, 0.10916867834185401, 0.15151947436313476, 0.22643438510356412, 0.11732648817762253, 0.1435179158204025, 0.08372659960220899, 0.11046145171407731, 0.09732639927777553, 0.20403564426927798, 0.2199538022039398, 0.1128242813771771, 0.1695817438585143, 0.15462153290788974, 0.1285334811696122, 0.11006402828159834, 0.14475887100542748, 0.1437964500679124, 0.08140980416247923, 0.10991471008427682, 0.092958977986728, 0.18716618899376164], [0.09560289297012553, 0.023385914072634715, 0.1052932004113832, 0.009001328181775828, 0.018883835591916597, 0.04045263315821367, 0.027476015365532333, 0.05461330112490443, 0.05431251585363381, 0.0355297981220628, 0.05924274746869361, 0.029426461814211744, 0.030350955653815504, 0.062335390792859185, 0.025503607091283607, 0.03805751288910547, 0.035235041962756265, 0.03080197842791677, 0.053914831951260574, 0.10114740069595077, 0.12180242582314438, 0.039038431019552296, 0.047397434696434974, 0.04384784290807382, 0.033587550729393, 0.03180979390538508, 0.05725880574074484, 0.07134380720315442, 0.021775390412057602, 0.032213985724675084, 0.01636191819524092, 0.05437553807672474, 0.0565200709858008, 0.05971049394218191, 0.037105874639124646, 0.05806246261683203, 0.017980974160074707, 0.0437166158770842, 0.06342839524750749, 0.0470123797534935, 0.06733516786968516, 0.005009514054343586, 0.016666761817290418, 0.05844301679321836, 0.03978069360938765, 0.02360701662368111, 0.045395145162699685, 0.05300445136644187, 0.04245049853418623, 0.0410453055895144, 0.04920213483273984, 0.016453846830934767, 0.05782022178473492, 0.022497340180580656, 0.02733583085148806, 0.04788109281611058, 0.04365079743306964, 0.04123591975639424, 0.06358668816486193, 0.021464561728099664, 0.04259882081720618, 0.07358808475997179, 0.04146913607274333, 0.015985294049906156, 0.0313485132139777, 0.06240857900270532, 0.04737334123121635, 0.03243355418465311, 0.043004747825644674, 0.029626678893222447, 0.013541884386100838, 0.018832827542698192, 0.02534325531263265, 0.017169598948150393, 0.014901532446064297, 0.015901448599423374, 0.029988563506894057, 0.04502286473589559, 0.030347688288818446, 0.028414065130956234, 0.014605498835144025, 0.04838600604524536, 0.023756001572755557, 0.03714769920935074, 0.03337700295472338, 0.024820614808930025, 0.02080035775208906, 0.02567072151108615, 0.023420391859666958, 0.0253750498767101, 0.04959487363756184, 0.04399605793878437, 0.05243132566852916, 0.04734133024730029, 0.02300497685228625, 0.04180013968218719, 0.014242693000743467, 0.04459887337420256, 0.03184474475171057, 0.09159700389230445, 0.06352941926208235, 0.11914200930585785, 0.023225591022280917, 0.07766688242554665, 0.038938050518833825, 0.03569549910964505, 0.05951513386061115, 0.07300706069555975, 0.03572767863290445, 0.04051899552465447, 0.061922143814304186, 0.08337750099599363, 0.009315412739411959, 0.04002269695422823, 0.0959816468398898, 0.06127579543258875, 0.11369979730056179, 0.06643473876700287, 0.033771549727046685, 0.030478572495461955, 0.05309800219331538, 0.11230378591966246, 0.033518943725334066, 0.03419990778990811, 0.015751796196244897, 0.06722520360903395, 0.03857486738613056, 0.016429914244180246, 0.024798645322481473, 0.05426158632842764, 0.01414752860117944, 0.10235875424358154, 0.08829547903470455, 0.031660536995097514, 0.052221865738712014, 0.04483164535955556, 0.05122790879179394, 0.00921924380705722, 0.1074235300503431, 0.012102796838829115, 0.028035112078331655, 0.05394901479444197, 0.05441857689631082, 0.032231567442537315, 0.03832888038408372, 0.03761225492663441, 0.04215705621566984, 0.02123419334360909, 0.01763180469072634, 0.038726116125021255, 0.029743557097390298, 0.043400098990288474, 0.037636915296917005, 0.06940273958588801, 0.027248491082460653, 0.08766613780490815, 0.08187726335299593, 0.021395248007930575, 0.02693620683144658, 0.05415215066844418, 0.01574272571522142, 0.0024777569764879563, 0.028515702015870524, 0.07276280122178216, 0.05911112207198336, 0.06419021989248934, 0.023283413423585798, 0.04359093915310599, 0.0553864753624845, 0.04773817528339644, 0.027453973100730972, 0.03248114739694903, 0.023866408249183048, 0.03472124594413946, 0.030835625009551167, 0.06831502496835686, 0.018602380634195382, 0.035173984755191116, 0.05452974774544278, 0.024786033600028005, 0.06713881953469208, 0.020079991870349454, 0.09115064276322242, 0.007914998746972771, 0.049794083310952114, 0.034571613650768995, 0.0522451471507309, 0.03152115878859355, 0.03419834497054258, 0.0420567523237438, 0.08929862520627438, 0.02162215559022321, 0.04962099340534018, 0.0910453133345131, 0.061619056448821104, 0.03288245489520412, 0.10872005725339537, 0.05528195415653529, 0.03191261822658201, 0.0083787486355211, 0.023522982524046977, 0.07145927963598121, 0.042542620607080965, 0.06540374529938545, 0.022853821959166278, 0.02448034536604199, 0.06496230245477731, 0.03086986147888726, 0.039195325826444936, 0.017148181045007323, 0.0681859391531156, 0.03154875136040632, 0.03930390729839283, 0.05175937462838427, 0.03522004196119886, 0.026921174271152388, 0.03955915630344422, 0.05728541580479472, 0.012123041669838132, 0.03129863514444761, 0.09559107223345388, 0.027562782483836337, 0.038822451681499524, 0.0794416017109348, 0.04119753875138779, 0.03302439949625442, 0.02729360983076115, 0.006601280052094691, 0.03384066617957527, 0.04952689865604044, 0.008880349491993266, 0.024773747464942358, 0.02739552250732818, 0.07902134885831226, 0.07239654224606291, 0.026591358097991156, 0.038194022096333005, 0.03219188791849921, 0.04993643393860229, 0.08202796816946038, 0.14009141903971473, 0.031603208720503796, 0.03792554275282929, 0.05627372009198993, 0.021276284129388874, 0.03292714463426702, 0.02274517536974482, 0.005939390140420367, 0.09601188433026114, 0.03142173972822005, 0.06662605390433343, 0.031299196303852146, 0.04858700070349921, 0.04243644465121531, 0.0624778027075433, 0.026105520458170967, 0.05930248317458938, 0.024029780329475482, 0.052137879519573146, 0.0232512166633481, 0.022518455478993636, 0.0454310670254692, 0.03650301706887061, 0.045405219218903975, 0.03418597265056545, 0.011623212391690863, 0.007625262378790086, 0.03319126110704195, 0.07685017907210896, 0.042946881374284145, 0.028635937600366534, 0.03046347864813382, 0.05399917057084461, 0.05592558292611953, 0.011329247218166149, 0.06041432190085612, 0.03161487432437078, 0.03547223427543237, 0.05559375577215707, 0.030832181444331527, 0.03287978124834838, 0.030169115108888478, 0.036192862542286035, 0.10976335409307673, 0.02047734060925582, 0.12720313118470292, 0.06193771838180481, 0.018171584496514934, 0.0022357016813100107, 0.034710696913422115, 0.04897678623937311, 0.06836184826228889, 0.043323716193798094, 0.013574498664257268, 0.07532567176367007, 0.10600189302837658, 0.06962344185599396, 0.045109513110571334, 0.07448014818252095, 0.0205053104793713, 0.050162491163298975, 0.04188080874061392, 0.0624398775248518, 0.03176043294520388, 0.006557643683927675, 0.06484660019557323, 0.034720265351596384, 0.042564875461281314, 0.0415895804161987, 0.029614613008415027, 0.024526188067430933, 0.014400712999274895, 0.04343821569496105, 0.008919692894954596, 0.009197268574949234, 0.05838801934113426, 0.012034295171859765, 0.02684399282800094, 0.017372596926326235, 0.06734380934147105, 0.03260245358931922, 0.04015866989990877, 0.05241357158088396, 0.07070563297959105, 0.03273586397089305, 0.057730256249347044, 0.012818462771153259, 0.03045387190556334, 0.038695116377165245, 0.09091165397436389, 0.04791328383068885, 0.0289571161321815, 0.14021148033920797, 0.007739610098783048, 0.03565463597976393, 0.04657811898317549, 0.016279741858823166, 0.03353757881409219, 0.03256220716021715, 0.06405525818286885, 0.02932052526082243, 0.05288368526605829, 0.0057187065437075595, 0.054322019174334504, 0.06456127074817497, 0.01685615790437066, 0.015410259835452083, 0.05035056957914945, 0.03860953669514387, 0.03971975514545076, 0.030192116898815, 0.04787961809685634, 0.1554344900913777, 0.1726605746174051, 0.1517355724448158, 0.08279348918867689, 0.15460235006626577, 0.1908568328907413, 0.10710578742286853, 0.15062653760035194, 0.15845505220274772, 0.10248056222354213, 0.28111777178222136, 0.15030072040615544, 0.14103845693171024, 0.1473416138680712, 0.18724901842013483, 0.12935376215365627, 0.11127971022600129, 0.12650767656704112, 0.22773342507500804, 0.1411310309964803, 0.36850064091624757, 0.14660215516003872, 0.11599076791636406, 0.1688196242696816, 0.1301685273046455, 0.14238108730604573, 0.11026539449249545, 0.19881403494265773, 0.16617184054226647, 0.1366464595400518, 0.14403079636394978, 0.06925859248205539, 0.15079155293924196, 0.1525393365732124, 0.21522494063021677, 0.15263727325345242, 0.0496754392741188, 0.1757564584934904, 0.19215594947097764, 0.15959742719367628, 0.17134854179476539, 0.10804204645776942, 0.12848651231897454, 0.15096243651163194, 0.31428907246839616, 0.10281415521017007, 0.14291574006840108, 0.15781437287167197, 0.1839074654684913, 0.08701587471389964, 0.13782076507566438, 0.08013326419337143, 0.1246235752478242, 0.10701873685203253, 0.14222074510349383, 0.07374729315239577, 0.1308021433050594, 0.18988946302523538, 0.352388953850154, 0.20303508747489224, 0.2898752905668751, 0.1131800449483337, 0.08765386507636116, 0.26386721840789246, 0.16920369478964037, 0.1530199341716305, 0.12360612621470807, 0.18928837511808644, 0.11262758830261808, 0.09317733602778566, 0.1287378734278102, 0.06708120206190694, 0.16816408283287482, 0.07691155037572307, 0.16170426091599852, 0.1799674905956753, 0.1431984111907021, 0.1924553979188204, 0.23325851247195276, 0.08053112429596725, 0.16600714696030464, 0.11642035171990434, 0.10169869288802148, 0.13581479448945294, 0.09206953458487989, 0.10862449544572061, 0.14573425415062136, 0.22595118280620347, 0.12629037572731897, 0.12683414493597325, 0.07586908857187918, 0.12601902738453882, 0.1247327657596719, 0.1791977101275998, 0.11992074534176819, 0.14435296697962668, 0.10442137703179352, 0.11565288483736016, 0.17903687762877635, 0.10963853538757372, 0.12398805168847885, 0.14660914188190816, 0.12922142812561604, 0.13204689828618882, 0.10367709196983807, 0.09524526780531292, 0.12697951011960545, 0.26013119146227837, 0.06886595709910316, 0.1627957217034794, 0.09659415711798976, 0.2524271048605442, 0.08149272551940334, 0.17260103426393003, 0.1249406437179254, 0.2876025834871877, 0.21488184049244852, 0.14825403990764774, 0.20577340747319883, 0.2958610113109312, 0.15039206873024666, 0.13285839990262063, 0.15157443351082264, 0.09433887087770047, 0.07968006189912558, 0.0697906252237097, 0.1289341451540109, 0.18614076498535373, 0.08119297829727012, 0.15895762120283422, 0.14538740018202415, 0.25084281971137373, 0.16199413326478776, 0.30816358664343435, 0.15187677777101918, 0.12791518692768392, 0.13639077003444397, 0.13927087758577641, 0.23657343620734833, 0.17048241810933237, 0.11814116905894011, 0.13924536685789787, 0.14801546480626832, 0.1359897689713586, 0.14164069397074563, 0.09915294441124124, 0.17680319506795178, 0.11933148583217014, 0.1765602073001285, 0.19994833536686438, 0.13533882406209746, 0.10878260067153363, 0.12479680304926251, 0.21520675370289435, 0.21617366391564571, 0.16601906728840646, 0.21862074792865785, 0.12729831760929478, 0.2379486559619827, 0.15891793784835648, 0.15602975573030212, 0.11014498845343629, 0.1713712179973241, 0.19988053658556557, 0.09846744893659508, 0.12215405251950988, 0.09380715989297438, 0.18815232801341242, 0.14558411623922088, 0.07652870559644315, 0.1454033194890907, 0.1465887792648808, 0.14647933594401807, 0.125670924692625, 0.1303541350869402, 0.15353946435836055], [0.055220923762047486, 0.06850899076990544, 0.055763720039037935, 0.06709689154259621, 0.016369008338980136, 0.056537227524865064, 0.029201996137177753, 0.041300573746763894, 0.042111313105711055, 0.002998089161513734, 0.061663968353382045, 0.04670136337799411, 0.0385754649347115, 0.03175748159147559, 0.11227075220836748, 0.02168298297141108, 0.05240446662590389, 0.051211874571538744, 0.0785471480940619, 0.018396132528000785, 0.03323895774120766, 0.016656915672243606, 0.03880845525512292, 0.008174979781371453, 0.1368666485312485, 0.05078353949131505, 0.013748604593978775, 0.06293796108014162, 0.013989123643466063, 0.033715587004177996, 0.08078795527258227, 0.05392052015409835, 0.025733410485930024, 0.017442379875348944, 0.015660748561663974, 0.06412718617807954, 0.004665235098781846, 0.08024682140638752, 0.07252417249424804, 0.01692641582790642, 0.11404798426214727, 0.022132303115100633, 0.049275200468518084, 0.06279300958398851, 0.05414919356905645, 0.01885832486403806, 0.03968851791033822, 0.05913174898934461, 0.06426977429298625, 0.10326993922072072, 0.015684313426214843, 0.016879389520674463, 0.05233805063330839, 0.048678839323861946, 0.06346517129831257, 0.027677105784776713, 0.017290981749313015, 0.026194742888272293, 0.005109157195434936, 0.005657892569058365, 0.03706273239766879, 0.03348392201587558, 0.022769525474418077, 0.03057603803162854, 0.08284715364777273, 0.03311783157949967, 0.01584224723985479, 0.11174581344089202, 0.03978228707227015, 0.039765754894864176, 0.0483489848463045, 0.058419980529335246, 0.021258880526969032, 0.07092147825225707, 0.062435974306877584, 0.043907134282973506, 0.04538789031005675, 0.027227142127230767, 0.021075703158614137, 0.06041277440324907, 0.030385508134420362, 0.059724942360433846, 0.008585906471125782, 0.03716268005871004, 0.023434102918291767, 0.030385052312105417, 0.02345837066851316, 0.05673502759647466, 0.059473657860390605, 0.08342946473989757, 0.04235113693040706, 0.044703593763012084, 0.029283170813634515, 0.020646592414367105, 0.08096913506667461, 0.016449663990868196, 0.07814469912479963, 0.00676783905815213, 0.04021975009011165, 0.023925010144950885, 0.04971269796031618, 0.039673150186577154, 0.07221972915313898, 0.04414323492035751, 0.04720083355242687, 0.008878865196639973, 0.06343419070265467, 0.04106790518328067, 0.03449468310141275, 0.03537451593025077, 0.01006749561882668, 0.04333095572468254, 0.021575470192117557, 0.008830454185484879, 0.039158618723553036, 0.03297967145279531, 0.03664000508105082, 0.056026400096954844, 0.05211616092691979, 0.05931166473836188, 0.09137992521808033, 0.016173219248171777, 0.009714037972322155, 0.03766129987554685, 0.03454100843819399, 0.06749976186021682, 0.036513171564306945, 0.06675021377422156, 0.008985465373693696, 0.011752621879080131, 0.05662844944444876, 0.02224650192675331, 0.03395604285141153, 0.027564552146941427, 0.04122065162406333, 0.02327307123660801, 0.01346563182455758, 0.035851811689715234, 0.04822628820435174, 0.043915423354314226, 0.028690891002394983, 0.016201857530001192, 0.053232481267543576, 0.09365427172592572, 0.05494014487691945, 0.039765977060362216, 0.04724385705025447, 0.06710403914292974, 0.07975644086517635, 0.06969314819622426, 0.0696109929272244, 0.022572393814522414, 0.04626932809309614, 0.02391311662992643, 0.006340492231350753, 0.02863972015949267, 0.028174743093850634, 0.05970158817006215, 0.06981475699332453, 0.06511331370641148, 0.06936738462818247, 0.04348307780380692, 0.06330970141495909, 0.06572061458662634, 0.019324924120859756, 0.045737892900022774, 0.06201216297584677, 0.0571277012838231, 0.030852032697669445, 0.03927261260668597, 0.05062914596149518, 0.07173429753991865, 0.021802067508800857, 0.1269740785562223, 0.07624536797764801, 0.010234310306728849, 0.01446604785028725, 0.08472494240249358, 0.01911515967109271, 0.07083666465815998, 0.04929031155282452, 0.12338661138088473, 0.046881160383383115, 0.032192286284219836, 0.05624001988420083, 0.013401189465977013, 0.04700960268476798, 0.019045085608658772, 0.046778968084723725, 0.03415928214728352, 0.0934211052052917, 0.008700203916598714, 0.027100703145767895, 0.0497207380530815, 0.034879485235339215, 0.026825894000789812, 0.024166138234337973, 0.07057814828811154, 0.04005900186095988, 0.03824505121296933, 0.1114428103450806, 0.026455272154341784, 0.029621369903907183, 0.03470484400168061, 0.023249789824589126, 0.08072423973991986, 0.04810188701676746, 0.025130144973856308, 0.045310657155970414, 0.07258463215323226, 0.028933614469884388, 0.01230305222223603, 0.0403106234396898, 0.12752943867517094, 0.07757258466294698, 0.022008003434166316, 0.05827940339522977, 0.00407339291526906, 0.04034987778492993, 0.02680594890168117, 0.02313720554323687, 0.055030052955713005, 0.01851042901586381, 0.06750196053255951, 0.034084431526641694, 0.022176730469049468, 0.09111105900017485, 0.035034821053305944, 0.0235771257880955, 0.0240916725728781, 0.04029237905577306, 0.06751114592677163, 0.017541816172700737, 0.007051961438264699, 0.03978717854366668, 0.07003295415591809, 0.05785336657877892, 0.022239524780982928, 0.021811992177859913, 0.09417899598878238, 0.044421232906320406, 0.0755287769941553, 0.04755766964667747, 0.07978341482099026, 0.02906855128164734, 0.06678793594361314, 0.02355953832457383, 0.06733522149583987, 0.07791117254284122, 0.03286977997049689, 0.009708262626982985, 0.026729347770132368, 0.04176576914746435, 0.02080497534705266, 0.0014979587708254375, 0.02715895264109056, 0.013204349877102482, 0.08676286651602677, 0.09630827608728602, 0.033028823654017145, 0.03660858015439684, 0.029575042651906133, 0.028503151580450997, 0.04333526879969624, 0.024290014651694128, 0.01015961290367188, 0.04787859919991705, 0.13353781263914802, 0.04156249154719614, 0.030110766022135655, 0.03566013649106026, 0.07409452250407589, 0.02028420601310509, 0.0625549592528372, 0.058248756047818935, 0.018643215035779342, 0.04020671510408002, 0.03213546171243633, 0.03208861543586658, 0.028261060135499127, 0.05985684737923646, 0.03642372696870758, 0.031167975018521955, 0.04710284707647178, 0.04894151172089962, 0.04902687689830219, 0.03107594487617814, 0.013831547975930718, 0.018376206581090248, 0.02962483262132493, 0.0013090295185740558, 0.05300794855781621, 0.05038719241236968, 0.021745924755269964, 0.011144480217368373, 0.06444333151223199, 0.05412437998118901, 0.012386131584794532, 0.035239630829422705, 0.008588189413140138, 0.04236999418466322, 0.07981727590724345, 0.006643184103942927, 0.022360355998840065, 0.04075716842987365, 0.045900154152825, 0.04739538541123752, 0.00697956900224991, 0.06065191257925284, 0.025630932819518833, 0.033265173269976536, 0.05440798190031802, 0.026146519568658648, 0.03984793314650174, 0.07321929003322318, 0.012539954379110808, 0.014933010998872981, 0.026541822852807182, 0.01162429832132353, 0.03577630989433777, 0.02281362341055947, 0.03841445623566547, 0.022567389345157052, 0.019740691528685635, 0.04315914901634378, 0.06982142195826577, 0.019589025271876205, 0.06759521641558217, 0.05514833693122191, 0.04103067714060026, 0.054998693146532586, 0.05917894000548029, 0.021190254370711988, 0.07081841644380363, 0.03886563605779121, 0.022985972126104662, 0.025029400581373804, 0.012896020554997509, 0.043698781350206946, 0.07061063041610104, 0.03947994281207362, 0.013205316105496981, 0.06799535179931311, 0.0750116523235075, 0.06550778770038197, 0.013660544702302546, 0.016730274336652893, 0.025650219083012595, 0.05689900871666689, 0.08080104771520823, 0.007888910101516353, 0.021224801105657415, 0.07770036812871695, 0.21025211069612734, 0.14546586290722893, 0.23886016269605007, 0.13964645985153415, 0.17732356795139853, 0.16051480216124367, 0.1176172951536794, 0.14466654208879318, 0.14082808918770284, 0.1559343777837292, 0.134377904656914, 0.2381294373903544, 0.13340039178729057, 0.2340631959058585, 0.1012498343123063, 0.13315499850338505, 0.1292781186320128, 0.19342826829562265, 0.15888796848875864, 0.11995046955323029, 0.17063562037243, 0.1665613656082461, 0.0924903926469626, 0.1861760509951461, 0.15422679844402498, 0.09364127887472992, 0.15670743710812063, 0.12662398403570538, 0.3336896975674937, 0.21143701888861197, 0.13272762869394597, 0.11539734088845792, 0.1391343760394281, 0.09309423080975972, 0.13989850277862242, 0.10623394106064113, 0.32668492666655974, 0.2030322682713309, 0.1066404196523851, 0.17965737820392658, 0.10769723028305078, 0.1275661879128987, 0.1271763870552663, 0.1953649538899622, 0.1552969160219354, 0.18670429926245444, 0.13015326683319386, 0.2042105574641497, 0.17507935934249433, 0.19486848294975298, 0.15357269725251585, 0.17177506890748778, 0.12835240862782926, 0.14894148124562157, 0.2001548726712504, 0.099496312679783, 0.11087022090871489, 0.15980008809316545, 0.20637250355174466, 0.15147746210136723, 0.17699894585436393, 0.09320332173017726, 0.15259558274861307, 0.18722736877539467, 0.14331042856699036, 0.12134909329395141, 0.2753532665871805, 0.10022230356210664, 0.11174535378813745, 0.11548097470715163, 0.13696004997097677, 0.13326793518518248, 0.22767972231151598, 0.20594159441609539, 0.12337518134905447, 0.18658622979156433, 0.09759512759985463, 0.07311481862298905, 0.11905440715171638, 0.08546768762772122, 0.18305605067120445, 0.18560957494041613, 0.1298115456536893, 0.0780632256740524, 0.09300509647976968, 0.12621758971363306, 0.23281602008688837, 0.12884868038517813, 0.1476355771263761, 0.1371592481530482, 0.27219986482974023, 0.10725505965491457, 0.08292369349228759, 0.23910529551006135, 0.12792686210764995, 0.12388835300601299, 0.13470053492534545, 0.11494141898208088, 0.08774502953935055, 0.17273413437989452, 0.09638767343975845, 0.2092699553336828, 0.11435942964688425, 0.18774798680697719, 0.06769604124729672, 0.09499032906587086, 0.16588904684589756, 0.29150785457703376, 0.1499208786915387, 0.07726733692951741, 0.08352564707879098, 0.04707746658354037, 0.12037267593005974, 0.08432044031759424, 0.2684675763931967, 0.15406029689456188, 0.13270061643373582, 0.1385421900739593, 0.15799372937650452, 0.12922939544002857, 0.09255605404295268, 0.21597604387469832, 0.14502332455688907, 0.11284524920366465, 0.3128235156257307, 0.11586325258136758, 0.1369338497639664, 0.18518792014689217, 0.14808949954327078, 0.21977390943756028, 0.11733142944473414, 0.1742144460759817, 0.14348207822730466, 0.14033673571482783, 0.17536445130263606, 0.15360611400777294, 0.1748725156029386, 0.0956177244323396, 0.1750183634219631, 0.12369500007480384, 0.06003353789809251, 0.08963353586413207, 0.21135961336474265, 0.11644558665613014, 0.13770899284751187, 0.17071944571310477, 0.22333998743805195, 0.18001426792433187, 0.19417970861879089, 0.10173033231929426, 0.10311985493547494, 0.11999754565617732, 0.13996748133532463, 0.1853814492783239, 0.105051982306665, 0.11008876526067335, 0.20141591468165, 0.21427332153243406, 0.11804914657747555, 0.16471543078941686, 0.10098257687904182, 0.3335143247198674, 0.16255915375246158, 0.09996216308565871, 0.1587406191374025, 0.1708528062989635, 0.10189562344983702, 0.1508901944203723, 0.09998974991181206, 0.16006015962170017, 0.09505085001188902, 0.11227239163652544, 0.20815408698493437, 0.15011575613771716, 0.12026652678727143], [0.02863087567440685, 0.030655707345314087, 0.006415101534296429, 0.035490582081218885, 0.02936900521989071, 0.04957494386021168, 0.014339066861617952, 0.029261848671481978, 0.03293332313337634, 0.010720303079353706, 0.02386597923994545, 0.02018841820949268, 0.025131529677779447, 0.03927835443567845, 0.046221949385419014, 0.014891727478243412, 0.04307176902770035, 0.036212386293036324, 0.02153032654595952, 0.05144133322661923, 0.04670792109062595, 0.04271040152337763, 0.03340992175282971, 0.011924677565994283, 0.03837899785609015, 0.06855006074352611, 0.05061807599098933, 0.02865578502326483, 0.03862401575691277, 0.08261487578913089, 0.01830637192113265, 0.07630204316228628, 0.02995374672595532, 0.052850195732448375, 0.03974267266570561, 0.006931678452078374, 0.07108352117000089, 0.021459721967638023, 0.030318021533950686, 0.04404280462392396, 0.017841921540938558, 0.03568062168215552, 0.06492847201204108, 0.017836256320738507, 0.02607508186971949, 0.06480227434827436, 0.012940471849193978, 0.06505834689784436, 0.08958837498099574, 0.04460603246585496, 0.011795250841626718, 0.03330746515383644, 0.0945274587420206, 0.03799161400585886, 0.06888627375085508, 0.015108040064543247, 0.04293805604139644, 0.01948974985298851, 0.018173143485440843, 0.023077653698442925, 0.08845641878583739, 0.026765610542028185, 0.04817034463368116, 0.07362671857399326, 0.009355781742581918, 0.0420580048775, 0.03858175451656984, 0.011689740424645285, 0.06451990200026382, 0.032620801395105745, 0.05287722714485661, 0.024929535274784413, 0.02281154539706486, 0.1217385723946556, 0.03225270380836821, 0.035273522559192874, 0.0125712193849106, 0.028836321303500768, 0.08947044340593201, 0.04272561219911422, 0.009309138479312102, 0.054350360597093264, 0.04896704543141588, 0.0033953421394295634, 0.08594983272374639, 0.026280847340521794, 0.010864542113737235, 0.017309798783953154, 0.027241952522026918, 0.008736090347801727, 0.059037232891686504, 0.06739880679355514, 0.08391996019429739, 0.00412067394673584, 0.028069199160522515, 0.08785964395370215, 0.07239892477950743, 0.08949711858745545, 0.07065293379127979, 0.029266134933418328, 0.02197606522860306, 0.0984967517996988, 0.013694284172097762, 0.042602934709359566, 0.0734437461341581, 0.05508043472805331, 0.08631298138249306, 0.07895453833043575, 0.05460491629257318, 0.04527895643766369, 0.04131450505566694, 0.04416700279820831, 0.007434405457799233, 0.033217901814608805, 0.01814324881941561, 0.00719109689065766, 0.03063122317525408, 0.012522932863043202, 0.02089988597999177, 0.07986350931347379, 0.020985187955140587, 0.05641725432548312, 0.015074124394525445, 0.017419753468505318, 0.007361292899135621, 0.023550427623934323, 0.03695349209010601, 0.045696263682217374, 0.016809882363304496, 0.06907829368907599, 0.04075613038073625, 0.009372811877138672, 0.08664007028264385, 0.047428656609789024, 0.04461554344743491, 0.050295300165852236, 0.07909113946821421, 0.05288375038353186, 0.02380918531167892, 0.048881496392911485, 0.032506175489435275, 0.030401550015554796, 0.07240418014266799, 0.04488126487441121, 0.0460432785292787, 0.044130115664654204, 0.04078634488846987, 0.04252311217808916, 0.038364189376513806, 0.00760402450630922, 0.07287356987475388, 0.01845051136408602, 0.030170886687213377, 0.06657196809687922, 0.01257693248560592, 0.07028687399842086, 0.06277841177859134, 0.041942999758307016, 0.046402539291809645, 0.058801419537274115, 0.05265418447614197, 0.035341723536651944, 0.05394823721519882, 0.04487883254525162, 0.08069916568215817, 0.045727661795794, 0.057596746276343064, 0.0593480002886105, 0.03237050514848482, 0.11897039794993979, 0.10373040402848875, 0.01829937370794435, 0.027704480021531065, 0.009485014072138696, 0.05911724694493798, 0.0230464720047049, 0.04048145721636472, 0.05195768031802389, 0.03968109068791232, 0.06150182201376846, 0.09258069909147679, 0.06949924368170962, 0.04201434552669526, 0.05478379782289267, 0.026291448082174027, 0.008559200646085365, 0.076550439510855, 0.029923737146741444, 0.04202540783632187, 0.09074477704181787, 0.026718819806832942, 0.035410280744995803, 0.08533723051509551, 0.07218177715737013, 0.04284090460127881, 0.02320853024420719, 0.035745064998345996, 0.010438662345310854, 0.014341308626406377, 0.02935126070834456, 0.02697043372468362, 0.02722805377186066, 0.04237629908828005, 0.07377320224599493, 0.08922736370755781, 0.004547613789327443, 0.029569266348957058, 0.039848101685845086, 0.0199062354682434, 0.03904182095861724, 0.08212880832293341, 0.06153625000508563, 0.03376226857184403, 0.05264469647719976, 0.026726599429704012, 0.021107070628673803, 0.04369671291281139, 0.049673868793874025, 0.04700367699467367, 0.06867289528130524, 0.0657833571876249, 0.02198221308419541, 0.05212767905886135, 0.05957819055765868, 0.031517196198805206, 0.06333137021189736, 0.09508026778818139, 0.03325877260536917, 0.01523082863704692, 0.030421428081970063, 0.007519965508817545, 0.04972545715469507, 0.008582613250661281, 0.025135568876360214, 0.032007747194579536, 0.005353039849714767, 0.03036427792281874, 0.015370803434521923, 0.012521845975800628, 0.10433380552116903, 0.02454276812533217, 0.018736997604249947, 0.02788276783370924, 0.05552761940165393, 0.08336819302771362, 0.08589923261634766, 0.03533602767293492, 0.02647828352036736, 0.0108053857618342, 0.04844948026021162, 0.018322651289523612, 0.1080232313383491, 0.03533487471060888, 0.0246385769963625, 0.09762299787853995, 0.023386004087965817, 0.035064342251468095, 0.05962589485270362, 0.03175402078927765, 0.029734065268008463, 0.1160210743546486, 0.051780579942128355, 0.07190469081603712, 0.01817953074350953, 0.06852295655276507, 0.03442213840542301, 0.03740941399648305, 0.0451516019811313, 0.058611973654478795, 0.008552394912488038, 0.015403614980318855, 0.050141848924179236, 0.014855627500031506, 0.03996498372045256, 0.05304358313761411, 0.049210826100240794, 0.04080671899681611, 0.03909938097480805, 0.029728041901703806, 0.03605931043444622, 0.03103977978049267, 0.0951592667749332, 0.03953833020322266, 0.08654265454219234, 0.012906616508600213, 0.098208281391811, 0.04290270874457013, 0.042297177527460365, 0.03500734530990163, 0.028152708489928516, 0.04869899892758939, 0.04818208876156038, 0.05676914532218249, 0.06226537801745919, 0.0528125616631681, 0.04729642600361859, 0.043258663837707816, 0.058280495070521875, 0.011845355864704378, 0.041099636545104366, 0.010657638044757469, 0.051136081662750056, 0.08104178318453413, 0.05109776960565679, 0.040483950832558256, 0.02170275953117638, 0.03413051937616641, 0.05955976614307973, 0.03788571384164595, 0.0726736439091544, 0.08345770274078654, 0.04590847386768268, 0.026290157224021615, 0.061149965491025686, 0.09188899830464395, 0.025429051414492632, 0.05281462243968441, 0.02362677594646812, 0.05266812727636388, 0.03160179145784388, 0.025756013910135916, 0.09342805362276493, 0.02158582961607364, 0.015473499435991531, 0.04228693876235236, 0.01553934852352306, 0.1663333931637387, 0.054871300385603984, 0.1137085690072948, 0.08557351501358133, 0.05161152348943776, 0.03668931433029714, 0.030647927722443017, 0.04565996260592534, 0.06975265790618236, 0.03538902180509702, 0.06877721347395452, 0.044711059289834196, 0.05896849182224082, 0.01864852594031442, 0.027448214034760193, 0.04829079280757616, 0.014839578915627734, 0.0501863164977441, 0.009019997744490544, 0.05830583342861745, 0.03568331831164899, 0.035959573447584145, 0.04027827537708706, 0.025389168877154592, 0.020370279821837624, 0.023174039050636273, 0.09832918538802093, 0.1273829396814108, 0.1398066335147427, 0.1354350600271456, 0.2057425800951258, 0.20514711527334106, 0.10493916819893545, 0.20946892368937695, 0.12057833989421207, 0.09348138866405334, 0.18083747536424669, 0.14980608807696452, 0.07722227563781124, 0.2796436347548039, 0.10829375230617101, 0.0988079290536623, 0.18564674552650223, 0.23337679644746168, 0.1841226289229047, 0.22124706587243467, 0.12865893572809237, 0.15607110915645478, 0.11107693441332349, 0.05800574529735793, 0.0999415246769786, 0.30759643643133106, 0.13141440077414437, 0.13989476426955194, 0.1352416841132987, 0.1618002057676354, 0.058802821478175546, 0.13154209230936345, 0.1516870331139334, 0.24596907558941075, 0.174000630936315, 0.20449161980180972, 0.13495158193813217, 0.1389822462994245, 0.15294640505265805, 0.11754601833320434, 0.16981627401565352, 0.08588627040866884, 0.12141654733568431, 0.18635366081951127, 0.1763634299558978, 0.13424655122141685, 0.181544620483633, 0.18486646965386408, 0.17789188261714675, 0.11893607721093202, 0.12950474276177346, 0.1966911593392011, 0.11909861042494736, 0.11104400795433791, 0.16248708020054525, 0.08050445677532304, 0.15022469384054984, 0.11100289201544178, 0.13156138240329682, 0.12249075582311039, 0.19067004533304324, 0.08274089725267503, 0.09266935078607452, 0.15829199804894387, 0.10180399933409306, 0.08394844334332213, 0.14842395820925314, 0.11349044845349367, 0.15732432174826824, 0.14033232304838397, 0.20217936726347094, 0.13336144387722015, 0.12158626645442941, 0.22344345527310527, 0.16233358682403642, 0.2392298307630324, 0.13431791997244283, 0.1531867727997803, 0.18246512108993146, 0.1562439998792064, 0.1429361486507039, 0.21892453243415202, 0.11401272889587188, 0.13829224622778355, 0.22918756720760178, 0.13477466159289883, 0.10364399697150915, 0.12260975992126812, 0.1908702700729332, 0.1129483263338766, 0.11366015991135953, 0.1614618553749977, 0.2087290972591408, 0.06834062762678632, 0.11414470286258768, 0.13706763935906274, 0.14518378933350887, 0.22246540614193488, 0.154108606399067, 0.08458844085614528, 0.2063977078444535, 0.23118074412547776, 0.1078264003679637, 0.1264376944351581, 0.1855156985261748, 0.15120128740466413, 0.2522116043274441, 0.2061158794188692, 0.10878795562612434, 0.2210597573749481, 0.20949296352844085, 0.20546901009736523, 0.1353727617571431, 0.22294798024719764, 0.1932204899287993, 0.08529753949973853, 0.17337029379221702, 0.1570527282573523, 0.07655737260656972, 0.10976739137643769, 0.11035598438954163, 0.21845818407112555, 0.14698489268700923, 0.15071882055171076, 0.18157786869954678, 0.1332836706311472, 0.20951468978197346, 0.1879381145080251, 0.10481204356878035, 0.17030951206482228, 0.13068126995236645, 0.10491268453939308, 0.10535428826246532, 0.16796004297512193, 0.1856901980335674, 0.16969043641321122, 0.1487103065535907, 0.19997447428684081, 0.10037341440517096, 0.1439409342504317, 0.11723343147746018, 0.08505241434660651, 0.1868623738447505, 0.11389098220294523, 0.13470226628405435, 0.19343988218855476, 0.2162379693360098, 0.15759890298208884, 0.15440089958569697, 0.05052395825905185, 0.23077867053929838, 0.17480531437022073, 0.18975541296024478, 0.178413848963476, 0.18504804781367704, 0.17265401690477328, 0.125189131997045, 0.12864130038407542, 0.21854072238408753, 0.1682493637406057, 0.21402035929983665, 0.1325273120235051, 0.17222439479683677, 0.10329341215472068, 0.2062506649282671, 0.134421541025081, 0.19400462688457584, 0.16756054344436816, 0.2269712595208999, 0.2272416732364124, 0.1629579638040835, 0.1353332316202502, 0.11980237709658763, 0.130575243383646, 0.19419883017338094, 0.14152504533769625], [0.05130898004638092, 0.11064091547121925, 0.018633453160404198, 0.024381778578484253, 0.023051706300447547, 0.03747107258306877, 0.029958626706032988, 0.05396366239555421, 0.0090377977974112, 0.021150954060196396, 0.02382005418410465, 0.05366533626652053, 0.07205217040234035, 0.05465322196663869, 0.026935021310383757, 0.0038579790458653966, 0.012364879348165086, 0.027397357287906834, 0.041317584729122545, 0.025782306047697223, 0.044586014588393515, 0.10239200245949531, 0.01605250102828347, 0.07695920870549257, 0.0327005971132988, 0.013122128533019174, 0.04917278600436065, 0.03803052744197269, 0.03356149607908822, 0.042286096065635645, 0.056267648845190005, 0.031039021353447632, 0.009028108700388863, 0.0022092357375508836, 0.0595109012248295, 0.07312276295476383, 0.007914680341679243, 0.013191808060172104, 0.009743497883450362, 0.0645277544014877, 0.04073373380026991, 0.05782576826130671, 0.029431349455168652, 0.05420990220661606, 0.06859457811280605, 0.06927278809129231, 0.029764999898390907, 0.030097054963510846, 0.017519580470698497, 0.00856860629057572, 0.027920907521019542, 0.04924186415249302, 0.04964591424551703, 0.04491208459160501, 0.08927846177210731, 0.08638733021554448, 0.050819511149799636, 0.10346361390885808, 0.09802058985036227, 0.02843380721676494, 0.03868357526258596, 0.015401366512261093, 0.03990565787159628, 0.047994175054613626, 0.049293345261004665, 0.061963378496828585, 0.029001890140916073, 0.03669626274777036, 0.029248405743630666, 0.03937446016577944, 0.02908879323982664, 0.04387537993851208, 0.08410204397214037, 0.06383679288950178, 0.026587724926010258, 0.025217277899144158, 0.03258023703951509, 0.07489636375178253, 0.04469104907325199, 0.03382201576905866, 0.0418565352447331, 0.07840949741582717, 0.02014771595807566, 0.05554334718673941, 0.03555560762423181, 0.052701482744587046, 0.08192990125427324, 0.0527074160955606, 0.08296431147403295, 0.028191920700332815, 0.03333051673947804, 0.0363192287453961, 0.005467925267669583, 0.01931253839434395, 0.09948679786776343, 0.05354494171878023, 0.041407374064287836, 0.009579890231121211, 0.025440893218582197, 0.040107284552387656, 0.05603965341804489, 0.06027732622779666, 0.01728435891920761, 0.009411034876510743, 0.08810795603259917, 0.025399164409346642, 0.0174177099289673, 0.032922613224194895, 0.06564032857216175, 0.03488905367351348, 0.05824522821292762, 0.10718112450934227, 0.06899400869564665, 0.0868014773474105, 0.05494073476462115, 0.05706545280953569, 0.04945681310228763, 0.04342242662284163, 0.012973043992514572, 0.01947521716506491, 0.04447269869307357, 0.045409965133594896, 0.04264670897335295, 0.029741484829555118, 0.036400142951958606, 0.05382079082811552, 0.03523883409798145, 0.06533042302415257, 0.04070756423677649, 0.04212006182980634, 0.024619275411110253, 0.03559254455350099, 0.016229925076327017, 0.06120566774400012, 0.028424118119742603, 0.02671583397914806, 0.028952092510618033, 0.017974527530191887, 0.0744736440960438, 0.01329532664855041, 0.06329827521356844, 0.043025485825754946, 0.013577729640077921, 0.0475417273569732, 0.026869949802095373, 0.11206246822351411, 0.0963796295165535, 0.04061689773093789, 0.07520659105671991, 0.06286523252305004, 0.028879427155780218, 0.02085995747737827, 0.03944209423817454, 0.04500118827807807, 0.02311983066911419, 0.06612065037892711, 0.06920377889107313, 0.055769986638258544, 0.023337813327088956, 0.029863480501057162, 0.03429921959797221, 0.050341862989890004, 0.027049298646048676, 0.005724417250378118, 0.0633353691908621, 0.03433225713970681, 0.04509769620433931, 0.017167225990804936, 0.043422733058011344, 0.04651530360382411, 0.04632431788430099, 0.032895290698375435, 0.019427777170353842, 0.04874440112842187, 0.03874416898695692, 0.026263531838213245, 0.029575734046257796, 0.022991231319704847, 0.051268595721452474, 0.03530429631111122, 0.05424202427328114, 0.020070015490355513, 0.060191704410939455, 0.03294045541195139, 0.01205908194664986, 0.036354441976835655, 0.02601137974359576, 0.037756034308263374, 0.07759241101842734, 0.023381087718711748, 0.029573328530175552, 0.06761525727568135, 0.02906680460117998, 0.03754269414310975, 0.029549020560338136, 0.08747162808093333, 0.05588116131783013, 0.020625973157885096, 0.04939555288142255, 0.013604279374703767, 0.04497099292254256, 0.01908238259925237, 0.0629441855445264, 0.06947438412856671, 0.02620276574405932, 0.05741923987384766, 0.056752295218287944, 0.03001332155338699, 0.07304317408031033, 0.023789688374005982, 0.022153646324671084, 0.026371684300923542, 0.03148637648161141, 0.0055717431091433095, 0.020773908566503275, 0.04261583946044407, 0.027575980263551878, 0.03230482460029664, 0.04636875481434888, 0.04007001437487141, 0.06074506504040572, 0.026210890106496312, 0.02051879745727826, 0.03554830680631342, 0.052035534003328894, 0.041364404192614945, 0.03181989668988653, 0.020556077210893555, 0.04378303953055893, 0.08434415073885072, 0.05394599257758068, 0.039791280944501205, 0.06551911047990285, 0.03476691244530582, 0.061016103117576534, 0.02521523052916652, 0.06299146466077336, 0.07726901466207159, 0.015084943471236095, 0.08242875472792695, 0.0096006311040612, 0.03648464628044636, 0.06953292856774024, 0.011103896709579614, 0.0009788940423600106, 0.010200460711794515, 0.026288625048173052, 0.05513615996366548, 0.03589528334897853, 0.023310073283350757, 0.035803843094336416, 0.022025020162184394, 0.0783208916865049, 0.039249208620599205, 0.04096533750153838, 0.03178469111932622, 0.03881675964822212, 0.0020342069112830948, 0.042877362725595315, 0.007675792580665721, 0.01839596015821782, 0.06567331631818125, 0.029200722516003638, 0.00798299383830219, 0.04465422322673183, 0.03803628076228403, 0.010287896241812457, 0.016149445624661543, 0.016858829636006586, 0.07057794910525123, 0.00816030536718186, 0.01437614647476303, 0.08402774876524365, 0.13933918198510525, 0.012042813111967858, 0.014607809547845636, 0.03272723399042603, 0.05189250155742611, 0.02881371596407506, 0.011110561674520856, 0.032817896665825, 0.009405138872323499, 0.027964356197645108, 0.02652446904610242, 0.02055819161356457, 0.054673301131134076, 0.05279655425599026, 0.06114170323276232, 0.05139738659284288, 0.02699637920745919, 0.07116525509064237, 0.0320051635630549, 0.03352625986501094, 0.03279213695937107, 0.05357941567537285, 0.02619026127391525, 0.07082937916200008, 0.03931356383667838, 0.013433436021929788, 0.046524462184958884, 0.012858362545469596, 0.06388288456946611, 0.03244675004914884, 0.06389912180302125, 0.05779382239486422, 0.06262308362150384, 0.027136157694903594, 0.06629352577992025, 0.023212385581686132, 0.023211724830851443, 0.028046861951870304, 0.08912754245102407, 0.05086379869270229, 0.055073501632338574, 0.03099845508263717, 0.060172084899198626, 0.01466807576962897, 0.009888341169684164, 0.01145096135235602, 0.02538009839613111, 0.07850502857998495, 0.08085983730251751, 0.03541174397293118, 0.021394725152922255, 0.02513224980042827, 0.08990808645443571, 0.0495655324700619, 0.0519605454868607, 0.021747623555242054, 0.027497582655820637, 0.13290131614813883, 0.022163724211314996, 0.07329788299337511, 0.02933939592161727, 0.03386239243310786, 0.06840471088165237, 0.038174019540630044, 0.007898145770248508, 0.02766242945536731, 0.05002112878907112, 0.033650906200730996, 0.06302233800412187, 0.030758543157829877, 0.05166824463935149, 0.027571102198694023, 0.012431980031842907, 0.1278991144030325, 0.016514566959813237, 0.02252796646057358, 0.059519404800789016, 0.021012851390086358, 0.02417880166772633, 0.09837170326781851, 0.21423319384696024, 0.14908164469224794, 0.2133656145944711, 0.2407025122233937, 0.10996604563608287, 0.10275113681751875, 0.15712743715172814, 0.05301988803811612, 0.10496932141963514, 0.1084767324068854, 0.14885102158352254, 0.21445180469703293, 0.1762383431196213, 0.16279756031449766, 0.1333622712521784, 0.1396153107165329, 0.08237022561051192, 0.1031889484053658, 0.20058271745520256, 0.14806565888706716, 0.18451031537786608, 0.12624521484418263, 0.1588156038234311, 0.15587030218974238, 0.09912656034312903, 0.14174906476851434, 0.17443884855076192, 0.1695892974854477, 0.14211209851407236, 0.11854369463699481, 0.18921081637663228, 0.1606403026849993, 0.0790365863471262, 0.14191153669549575, 0.12267457095966225, 0.12491779897602336, 0.16101899526772961, 0.0848536451737727, 0.08626878577014131, 0.2129274582670581, 0.09483685867199976, 0.10824322114668547, 0.12848468902971477, 0.1189876349282361, 0.1253502785919174, 0.08960139847570851, 0.13578641859273757, 0.13137054990135855, 0.14338607208863383, 0.15809543520933197, 0.08514896440770357, 0.11583190426350602, 0.2350007496293514, 0.12436907317849899, 0.1303792627708566, 0.1299918061422725, 0.22578097339118683, 0.1629085664547259, 0.17044443547004656, 0.17451770964168734, 0.11985952725573895, 0.2585500472735974, 0.18658875788171447, 0.09815842438969882, 0.12811666039089042, 0.1436332273747652, 0.20108591464738693, 0.13786530542758205, 0.15486459728450547, 0.172059103666294, 0.12865623909859888, 0.20525897943204452, 0.12195423380621981, 0.09760395293274234, 0.12355383305299668, 0.16907293890272418, 0.12809072065377428, 0.1250625589501954, 0.0923055662743507, 0.3239154575332519, 0.12977154054228338, 0.12861764358897365, 0.1281775950243877, 0.17991953349161535, 0.1029069591013174, 0.2143965697576923, 0.09560470859850607, 0.2741940836271932, 0.11809867416178027, 0.10055928265735989, 0.06796584209246982, 0.07072201193941217, 0.15639179356155858, 0.12941860383556736, 0.07852002858154236, 0.3013492652004765, 0.1693439042015422, 0.11128305036935116, 0.19914144559973673, 0.13501984037218556, 0.1102212678280569, 0.13359191376836071, 0.08386789685896329, 0.17860578463202526, 0.1210713251343658, 0.11765689423848545, 0.06060153080691254, 0.143793125246321, 0.16416015494013989, 0.17245206080617445, 0.2732225922086547, 0.2198787562308773, 0.13667537169831415, 0.18582930427885827, 0.1733330465973385, 0.12837048830284228, 0.1113415488432492, 0.158316865262966, 0.15541538385854614, 0.15227702806793875, 0.32197146346011474, 0.09919086576349313, 0.2996513692121352, 0.09360066855386381, 0.11715666180656803, 0.16086801465961242, 0.21875680514401008, 0.1282674035117511, 0.14143000446981, 0.16071554784092212, 0.16416845933323906, 0.12921804201699075, 0.15960185518187864, 0.12819099390218336, 0.15198047543244977, 0.11064719739219836, 0.2606366869182356, 0.1318945540415664, 0.13317174518540983, 0.1357214390150001, 0.14586039818823338, 0.10227700500118156, 0.12254359290724802, 0.17330862371431244, 0.201002273167814, 0.1713418155427902, 0.15412736023145338, 0.19590728285331882, 0.24128930492987558, 0.07993128511213488, 0.13281100970362464, 0.1362513573539834, 0.15644034821419947, 0.26841778067811844, 0.11470486635282157, 0.14072917191491974, 0.13917261914860818, 0.14235718536280817, 0.171496978990974, 0.17509852686235983, 0.11222249633001705, 0.15925403594249682, 0.13899018297032004, 0.13818350770781118, 0.23506703155656017, 0.07671891756716274, 0.13876285403966904, 0.16672880178497684, 0.21270308643579486, 0.23827882453558907, 0.06129870912240398, 0.13857602051669551, 0.20300502618474348, 0.12392630500178184, 0.13648757290455604], [0.046622762756962935, 0.03555078510074847, 0.020036610226417263, 0.02935742580091521, 0.027383945003572493, 0.03522449676247855, 0.026912285736010923, 0.03714282305971269, 0.03695332738120229, 0.024099501991464246, 0.009501232153495714, 0.07068791336590244, 0.07388158836552212, 0.02056177307461058, 0.059160959921897426, 0.031875849836656166, 0.0027783854391365765, 0.026499082807511575, 0.007504877885953794, 0.033001095101597815, 0.03169468727954213, 0.019736027968446576, 0.05258086220090909, 0.04023908231888087, 0.014731489655171192, 0.05625648311369362, 0.0267670450416664, 0.07097364883990058, 0.0898866436534351, 0.01607795429956769, 0.025454399348687262, 0.02766729794412611, 0.05694232332790571, 0.07616543436362859, 0.0507028857546468, 0.11733358215180137, 0.02753478580064351, 0.06802843913676278, 0.04822081833657238, 0.003209350116160368, 0.10826776660377942, 0.031391115363446936, 0.06470956238767793, 0.0393587208893751, 0.0387296324685937, 0.0532495420456173, 0.01923610388691868, 0.06020797611845117, 0.05005286781177406, 0.06308415746917168, 0.025385238846103032, 0.01813494634153622, 0.03813468092571824, 0.03865842076559221, 0.02887623639957559, 0.009056582273314557, 0.0293050924195878, 0.04192172549664975, 0.01773405827641968, 0.01772193876545756, 0.02652903876057075, 0.07830019199079083, 0.013916825053221999, 0.029448697516213984, 0.03166741454943774, 0.03300836910643885, 0.027299162052992373, 0.029286754189900337, 0.019540706191272027, 0.036962612366844574, 0.02845442072758752, 0.04361285692861965, 0.024209657774096536, 0.05041295211882361, 0.005634838589392002, 0.03542335786586327, 0.03438955285556374, 0.048212038968960126, 0.04496598270751777, 0.0677411561651576, 0.062190420144507964, 0.10472613446895154, 0.012658318793851764, 0.08077687764119718, 0.009298508051752804, 0.04444295149897376, 0.08539841795760779, 0.029630388673995773, 0.05039283081949238, 0.010474232765245102, 0.009116655057897011, 0.02933314847459476, 0.05681129164933678, 0.030191166949788892, 0.05873133015308169, 0.0440431340417314, 0.033331987628292654, 0.042653213059830095, 0.011282395195936965, 0.01917109558088405, 0.09234664390885061, 0.05061062195548608, 0.08128875460956367, 0.029708529642272382, 0.029004023695785194, 0.04618984647095204, 0.028682703437704234, 0.047464812129375436, 0.024375584757616444, 0.08676445997890928, 0.05151444099723332, 0.018901124281147798, 0.07379767875517569, 0.029077968417456555, 0.044256910877001863, 0.09119291549488422, 0.007106957453933935, 0.01949160187054546, 0.021985497686170766, 0.008498151099399455, 0.015304923703473423, 0.03397555511084295, 0.01747984349006607, 0.01892148115251574, 0.051315231323843045, 0.029696829564448808, 0.04400839195436528, 0.0632218809257592, 0.04039835965921802, 0.02499497259005664, 0.029879706243293423, 0.07894875436660745, 0.10470961761330405, 0.035403918384784655, 0.0689628059344907, 0.02824515040453163, 0.03950297141507749, 0.0278358698462046, 0.030542701715603474, 0.016828640026130506, 0.011921645773033942, 0.06089281658792208, 0.05255858819451063, 0.03439085520503502, 0.03138389115432098, 0.05854018738553409, 0.03737480214406406, 0.03651538938884774, 0.023985058031675797, 0.062061828455977866, 0.05208821020900242, 0.0011221818708544297, 0.0831498273257767, 0.009986396593552445, 0.05569509771322051, 0.04955569973155376, 0.06445267012402897, 0.045650080071702126, 0.016734114352373347, 0.03108394666454725, 0.021612640778203646, 0.04288657493288479, 0.09438816863562792, 0.06402441548303732, 0.08189925007642278, 0.020252748527714325, 0.024608921732813604, 0.03481416857891506, 0.1414686459447107, 0.0968130284379567, 0.02905935056567673, 0.07736063877781553, 0.06176872704658778, 0.02289635707594214, 0.020436465988055836, 0.0852958694280636, 0.0716478981438183, 0.027798406231487473, 0.03916051096072601, 0.02058329439962343, 0.07754117505805147, 0.05787196336314083, 0.011879365380492904, 0.017180854694977883, 0.03081088420003653, 0.02157342665257954, 0.044024380209345015, 0.09737277824071147, 0.08082350941314813, 0.010858824224992385, 0.05164002962110024, 0.008150129804327604, 0.03900771472422827, 0.0900579562350627, 0.015833597149579756, 0.013802708596021179, 0.018938243156298995, 0.08233645645480964, 0.026275383218401865, 0.06211273882898593, 0.030985305183416897, 0.04412584089403672, 0.055683625546554406, 0.004843991182203735, 0.06319097693889372, 0.061690049816764174, 0.04469839968688546, 0.031345330118652315, 0.04969386751913736, 0.0167286291628355, 0.02128329957955547, 0.06868011182955197, 0.035172981180010304, 0.01673434034831101, 0.02035571265995743, 0.05239165763580992, 0.09646317906557553, 0.04489063412972516, 0.05598156480118633, 0.07152446605745824, 0.008768573433401124, 0.06958437137185566, 0.04008176616362987, 0.004074021586171922, 0.05923154343280101, 0.09087244559439922, 0.03808501927602676, 0.0792608049608046, 0.04803976111654793, 0.02657830587498123, 0.08357777936203827, 0.015957712969412247, 0.026557240372283325, 0.03517681545007133, 0.028337375899296136, 0.05008521204393718, 0.049086106986167936, 0.060819364077742064, 0.03033683090771158, 0.04622660336955901, 0.05384643945182043, 0.045810717218104875, 0.0195684424045706, 0.013234326897579576, 0.02508254601590095, 0.017425968356791045, 0.018944569127333742, 0.02902851552672444, 0.01748741052353815, 0.026257456760973703, 0.02158672785416486, 0.021088318711507226, 0.035260947225915815, 0.03421886463559443, 0.044869394342024485, 0.060402677364407055, 0.04959122322860265, 0.03612373076799897, 0.017640658751911214, 0.045348973043503306, 0.07562352674863032, 0.03114565313162823, 0.04552339211166386, 0.03821746055637637, 0.025739435767454487, 0.012316347678161919, 0.0518857523228132, 0.00770393769339388, 0.015295745012530637, 0.053828830920880845, 0.11957352365096731, 0.10367957409471275, 0.021179048419599573, 0.02050649025477469, 0.014417571721658593, 0.04729464101875502, 0.027741432272558732, 0.006167964921558217, 0.05392533118626284, 0.036534710126298095, 0.06914496632112611, 0.06687756823075396, 0.05634332301035043, 0.05688172577309513, 0.05863526655781654, 0.08267862196531027, 0.05192057867985099, 0.005442319736410414, 0.023943084074304472, 0.08328088964786261, 0.06137890320631766, 0.019013130166117224, 0.06252756777910456, 0.04262833435448908, 0.02497188653045845, 0.03878342333219705, 0.04760226362474984, 0.05379841339984729, 0.061779701256103096, 0.002937879199312339, 0.055063205410636244, 0.08165227099051399, 0.02908149816756768, 0.08404153068700145, 0.10021858037479463, 0.020983778353359912, 0.039407149137508486, 0.06020979557727134, 0.03902489041549064, 0.018140609646516464, 0.042852587442124085, 0.06605966211927515, 0.03454482355605691, 0.03187342899881544, 0.02666583142033027, 0.0326931698908729, 0.017722245200627276, 0.06638587001831302, 0.030600177462122617, 0.006504693123016266, 0.05809186507136591, 0.09506792611172123, 0.03682413814409125, 0.03677558349145036, 0.05539989722291789, 0.06595537457014285, 0.01426871604992137, 0.04671991036664094, 0.06729864845833472, 0.0776099774145311, 0.04798723046758002, 0.037982321359337344, 0.030617351238165173, 0.006409593840925805, 0.004617692639810904, 0.031773944820968375, 0.024673146713945656, 0.026070447037777594, 0.06366933373013331, 0.03869918047360355, 0.027630460606287086, 0.04085880531478794, 0.04716949672588418, 0.010764867371519007, 0.0523822232630224, 0.05608824637508201, 0.05698164662105903, 0.029610502946701263, 0.012029851861898939, 0.046546701717400746, 0.04646354670365972, 0.014386414925778105, 0.1626604765413269, 0.10035123615976303, 0.17587267403160373, 0.13229023845445725, 0.18207368080414113, 0.13868843625870445, 0.09032502214634612, 0.11195352285980217, 0.15360995976915284, 0.09850276558990441, 0.10555976836551582, 0.20017287573747097, 0.16552025211914895, 0.12867275595424638, 0.12852168341557826, 0.13111522811795437, 0.10600662745174863, 0.141090382371218, 0.1265998446052113, 0.11506130408135154, 0.11029524127802542, 0.2238391856512716, 0.11607491501396704, 0.13262811387258192, 0.12519563608352216, 0.08946918702173619, 0.13606614793740934, 0.21667327581634446, 0.17998446710407737, 0.10935434741118263, 0.051461105955944914, 0.15746469969951338, 0.17417359826785905, 0.1375650142830226, 0.13133670413686385, 0.21611040037485862, 0.18050851720956065, 0.12942151496967963, 0.10959675295218345, 0.15620112959896365, 0.22795543735546453, 0.1610440463428536, 0.13540643898229446, 0.3035334431596341, 0.06639994305348204, 0.15465885671156068, 0.09763731606184475, 0.15962627806490468, 0.16250666140788989, 0.18513809378829696, 0.13643739414551567, 0.11396341581618595, 0.1788765967132584, 0.11683331907636697, 0.16428272900802476, 0.2698883017705333, 0.12143684866567775, 0.1444337892556383, 0.10343704597964402, 0.16148957243609816, 0.24590060265073854, 0.2101005478611877, 0.12148982364564173, 0.1179701782342407, 0.10007050323991046, 0.12464072795644884, 0.10462855018915669, 0.11328196528577998, 0.11282420476838467, 0.13098755190449377, 0.10446437754698339, 0.13125445693731308, 0.15863594088342883, 0.2252933584273823, 0.14326112314818368, 0.19271473400294784, 0.21553955761896026, 0.17300692296797232, 0.0998208964724214, 0.1703218307586447, 0.13436855838423775, 0.12007006353908971, 0.1704235365914722, 0.18711898265586746, 0.12154391711397518, 0.17174856226530769, 0.1552005728045779, 0.11349773394965357, 0.1264459452021026, 0.12213100859474753, 0.11658752742674082, 0.09102336491548246, 0.17223412411347513, 0.14492532658961513, 0.1778201614656756, 0.16190136001715738, 0.08894435550657012, 0.12277211693506088, 0.13466975351254787, 0.18545557594587728, 0.17709772523132064, 0.21013659995890435, 0.1937120732280516, 0.1383672768790876, 0.20914436287937627, 0.22981156114368673, 0.20078497998897107, 0.24300626118577298, 0.11616068621796947, 0.2309327001773542, 0.24618425436558264, 0.2028365481284357, 0.21232620182056583, 0.18540700597147788, 0.3510194950767102, 0.1513045713786156, 0.10213384615077127, 0.1644143888786916, 0.0913465774107364, 0.14440340620856132, 0.07455034481902277, 0.10722902798724752, 0.14008470810949802, 0.09159062237989518, 0.10913837190356948, 0.1374015617634981, 0.12351044183296543, 0.20051809027791026, 0.16734370991827982, 0.13484501910786476, 0.12877116760899945, 0.16753475692483688, 0.17932201555419355, 0.13196848152625945, 0.19684235445193707, 0.11742136050616542, 0.08029019730466028, 0.15403124684047315, 0.11692494319211091, 0.12879151490426835, 0.10520239600971823, 0.14889021464172872, 0.1387119091927044, 0.0937622594797323, 0.13486050940569372, 0.16912832705964967, 0.12003284698772816, 0.17093353664442418, 0.1474268028452512, 0.223756248972589, 0.2241067495197058, 0.061315769900477705, 0.20660622165568415, 0.18520264435679684, 0.15078438235627067, 0.12855932897617742, 0.15363180859675332, 0.1248192800689609, 0.06214524777005277, 0.07930125440320662, 0.08235223020517057, 0.11361271608620883, 0.2354331449755738, 0.11310701378651204, 0.1495272320725264, 0.14145925370675905, 0.08148314175947059, 0.12310061543699234, 0.2466423289790269, 0.19923870812260336, 0.11426916150676628, 0.16742384271515956, 0.12987833319892808, 0.18741754244171804, 0.1786780114015264, 0.1577361859381199], [0.039666764843728275, 0.05542261556031243, 0.01576025667975867, 0.016072564871020375, 0.014245972814669293, 0.07981284025816188, 0.06979198886021491, 0.0074524808235676785, 0.0260998705597294, 0.0286323523088809, 0.0366202783170006, 0.09775612097714217, 0.04432127375396029, 0.0483747560440773, 0.04543967019285887, 0.01754378884910576, 0.02019221800559711, 0.027265222442726937, 0.03608913423733846, 0.08572616569337346, 0.05663824004812106, 0.030642701087579615, 0.052883187308907516, 0.025824272344189308, 0.051926243900051045, 0.09708662141835499, 0.03490766577963387, 0.024861443464854555, 0.008703253904147255, 0.05851007246923062, 0.015465673847845005, 0.026956268758963675, 0.013177741728272411, 0.026768695961143223, 0.05490001336100602, 0.025255373536398815, 0.04165784651113134, 0.02213022701682583, 0.07778294474607514, 0.075415434285758, 0.006500028126362351, 0.0739350076764822, 0.026282264603181716, 0.04217497884265838, 0.04463888997692735, 0.03990094643086195, 0.014165040413518588, 0.03750768009453051, 0.03931526455187029, 0.056632341171104106, 0.1149164368548701, 0.014697782744112757, 0.044271669560863126, 0.06091490290277909, 0.03209247651900495, 0.030586682823336417, 0.019986441043475946, 0.08503104049351909, 0.048908681022904577, 0.018614465671200908, 0.031650371008342316, 0.03900814756390549, 0.007533281553356398, 0.004388933997571228, 0.025741310767649163, 0.07534729076489326, 0.048287054298505674, 0.041460161352710384, 0.03750031415913855, 0.04332915541806048, 0.04741333102086379, 0.01899728363740348, 0.013609500263907738, 0.02979399632632492, 0.03356210894942765, 0.018859655941806493, 0.017421856379857468, 0.007534120898438438, 0.0461913786468006, 0.024450079147373478, 0.06269262908327003, 0.013759215869339965, 0.010371698599849499, 0.05302811199198327, 0.037079107527050285, 0.007058668059236821, 0.03028223182134811, 0.043905349298109936, 0.03865123486086246, 0.03572900396501345, 0.021173258710111824, 0.027204667022752187, 0.04923072523407398, 0.016057027650306064, 0.03509671329670856, 0.1570196332590234, 0.033217763918782436, 0.047867667125237566, 0.02015823051483641, 0.10068161157710899, 0.011787206918421772, 0.04618166848236034, 0.04630670169248216, 0.023213130602192496, 0.03555035992195049, 0.05826483240290996, 0.09839369765212459, 0.11643758103732141, 0.008267892840047999, 0.05272210583150868, 0.028705042561576254, 0.029254090116028825, 0.013244349242848976, 0.04588710384503488, 0.043282098467311556, 0.04738360680940171, 0.05620188785776977, 0.03132258113774081, 0.032815391558312604, 0.07156614124053909, 0.04738917626861123, 0.02915200315445902, 0.06273880120246642, 0.02420502677259426, 0.04912056562100207, 0.044088865660371325, 0.021979817144212224, 0.04328521644516338, 0.06326023128724868, 0.039781586101819436, 0.04794622178099329, 0.00864824400313439, 0.006184408998852897, 0.0438368495463604, 0.06736886807747426, 0.02594156615105608, 0.050396063710532846, 0.034358832729800094, 0.034091797462033654, 0.03611760589504435, 0.03379827853472483, 0.09082733833741757, 0.0178484256274157, 0.0375036696242469, 0.108019347272573, 0.022155145941782865, 0.03948935803266303, 0.07946998526852939, 0.051701320485482295, 0.06053174402745021, 0.04809311147959483, 0.07040870496101918, 0.18014493188069713, 0.047502358098544424, 0.08283062147036677, 0.03438173109785684, 0.031272316193808956, 0.045566948040598826, 0.03275782388124255, 0.026076696400019913, 0.0578795284813931, 0.05243593368739371, 0.005786267837749855, 0.00695889947124787, 0.04377460490251261, 0.08729574961527702, 0.015295195344444967, 0.03762978684878157, 0.0875764825351296, 0.10113161928471058, 0.03114553247278016, 0.031049252457676396, 0.00563276392753206, 0.0331251209060992, 0.02539083894882952, 0.013619801273659594, 0.018257602763872956, 0.03981286547176781, 0.017563354734691883, 0.013673502121931844, 0.04266240611492146, 0.006937821040816245, 0.024268347769975666, 0.010921097597137336, 0.02192984139847179, 0.06784067098652163, 0.038671509377778544, 0.131426504963348, 0.01650312926710373, 0.08168027916502568, 0.0402976114362959, 0.028916816076924725, 0.04189956640343993, 0.056767023258632233, 0.005156229946747302, 0.04376928059143886, 0.04903491699106751, 0.09775429002700314, 0.04557812526341408, 0.08007850422854386, 0.043493722595514796, 0.10898013644280935, 0.04848245268447265, 0.03375613986844978, 0.05484891146601689, 0.036323936355690804, 0.04360825657063434, 0.022548386534195275, 0.042102001306991425, 0.029807797400280837, 0.010058007619884467, 0.03253969566656217, 0.01913712341188183, 0.05373531073752431, 0.0773568389817111, 0.0850151518299695, 0.06904024976275622, 0.05712916451175848, 0.03071050752975768, 0.03355501114480919, 0.03849538193354684, 0.09893509198821361, 0.005319569947107906, 0.036852291875308564, 0.009143128183730429, 0.05545440437873045, 0.04973851895380405, 0.006264848230902347, 0.019548236835567702, 0.0292723766347814, 0.043335954448388475, 0.02460658899508417, 0.022613618920947758, 0.05433534527377737, 0.03698652963184061, 0.04710551306244828, 0.09343940704580277, 0.090015055311303, 0.047145989317927635, 0.02795397953671073, 0.009083411630032765, 0.07809468124422335, 0.013267405616540103, 0.028286842824590784, 0.07937011804672019, 0.012171712193277576, 0.038590074231427525, 0.03690018769233458, 0.02733140286328572, 0.052714398986990416, 0.06009337319541843, 0.029941188629656553, 0.029315878937561667, 0.024547747696839997, 0.04058825370344905, 0.03820626418136301, 0.02051427370808538, 0.01980129099871603, 0.024352914300717177, 0.029546718466125672, 0.047518200796818545, 0.029863221946382718, 0.03996859965545516, 0.027559258479384646, 0.06971798476672943, 0.042973748077788664, 0.019761174804561084, 0.033030926565369295, 0.054411620817958355, 0.0031387871938697515, 0.04511198757456676, 0.057324555236846216, 0.01636803157687668, 0.0323028136194954, 0.0675128236593258, 0.05448788487082047, 0.052433784810766104, 0.09010067329772058, 0.06167960420791661, 0.09190259636529992, 0.04384785822983231, 0.07109980053839184, 0.057117569771024494, 0.07094718050211668, 0.015421365237524434, 0.059128412676434365, 0.03934532584201905, 0.015522826879826045, 0.0624495608762147, 0.08216659177935894, 0.12522475508552405, 0.04060944369543464, 0.026192107545812766, 0.020139840574214057, 0.01923185784459835, 0.07509236734720968, 0.0288460276375014, 0.05839429360123412, 0.02057966505808215, 0.07657000539644111, 0.006431623656798395, 0.030033452428817272, 0.03944725384034457, 0.022659524824590455, 0.04860193558758305, 0.06618603598326445, 0.010062488276631603, 0.01945338748966254, 0.07989022279939345, 0.03434124335105862, 0.014338632106720922, 0.06454592600705163, 0.033567858439299374, 0.03359028566328268, 0.03917213634497697, 0.0744617927158552, 0.018440385596946846, 0.013930950756935824, 0.02202329454913495, 0.04437923213587173, 0.04312861275168196, 0.013198333214067165, 0.041410204759168054, 0.06598221063013039, 0.017245610191997503, 0.031061266631548925, 0.058522065575685234, 0.07856161949495155, 0.05011935275228274, 0.06928455520180926, 0.04150161053985357, 0.014741212268540216, 0.04308919369753811, 0.013945015173615708, 0.03637611077377393, 0.05004572021144052, 0.10801312663862783, 0.051519562295007135, 0.020823081835143028, 0.035665820863458424, 0.06658922805781327, 0.04287332544223436, 0.030023006819969708, 0.05741121893328044, 0.04706786367140951, 0.03932896220395642, 0.050281916609815056, 0.024941130015518398, 0.0204105798770944, 0.025544410849350597, 0.0160868696477865, 0.022296389572382457, 0.06839868176968829, 0.08528845369695656, 0.11517023412330497, 0.1619915132440867, 0.15599758003748235, 0.23407006005366005, 0.18676380897241254, 0.11802708324525626, 0.11696209079555928, 0.15356557263482004, 0.13416321617701363, 0.2201944457427148, 0.15475323874383204, 0.15377302924471517, 0.16612233594059947, 0.11439751187760024, 0.11859231057666964, 0.14871778357173168, 0.15850657927653483, 0.18833951393683113, 0.15397354509801636, 0.21617619200579583, 0.1159734696510338, 0.14250908527643452, 0.15700241160248557, 0.1893839216040027, 0.1354120314241417, 0.08412457461799346, 0.15031423419713974, 0.11089730211683821, 0.14288224670435154, 0.13107624956436698, 0.07153752019568797, 0.12277411642454325, 0.19602487734969587, 0.1338006114406932, 0.1591932545265844, 0.15073887673356842, 0.2167870398731001, 0.2023883100839392, 0.15056007181204137, 0.20328880047365544, 0.10843999849091615, 0.142264197610559, 0.20009505652612258, 0.14186436100111854, 0.09760697898004325, 0.1347009026475491, 0.20085686967978555, 0.16754522168588254, 0.1580164055790632, 0.1342247943243673, 0.15026609323197795, 0.1276695255130049, 0.161141584657373, 0.14463090367855566, 0.13130590740230777, 0.15788048625953738, 0.09974557470770613, 0.1455946116437835, 0.09582430770200107, 0.1359441867398639, 0.16793969567985306, 0.10806424768581506, 0.09318030844893187, 0.09696528075202819, 0.08375812412029313, 0.12194903973009318, 0.17550043190919584, 0.16220986362426512, 0.16360938368785768, 0.20759735556860126, 0.13212765927516645, 0.1674538273965159, 0.1851834002281389, 0.09107000434831267, 0.12996520756954147, 0.083061144987662, 0.13232423743653682, 0.11095066780164359, 0.12665139466163614, 0.19026930473985212, 0.08936312214861955, 0.1646352060619862, 0.15871949043245087, 0.08048163501605873, 0.12157105960913243, 0.10173044723248291, 0.23676998372520172, 0.12922341995421918, 0.06614537969712289, 0.09672738746890137, 0.22231650929297173, 0.09287350555701603, 0.19920038840463086, 0.20892504722841326, 0.07990020492504682, 0.11435257315996195, 0.14526609782009356, 0.2138585768519871, 0.08199778430524372, 0.1795063516305339, 0.2246592061654214, 0.16037120664071652, 0.1081458283888717, 0.22007919547538604, 0.15589014386698125, 0.256319965326017, 0.11091889813542367, 0.11215072155239121, 0.10929083872225978, 0.15125757954534025, 0.1611552976312176, 0.19924472957368822, 0.15434681377824278, 0.13739419199766653, 0.07230022967222237, 0.12178736453455304, 0.12575249007392314, 0.13583903351137716, 0.23378951865578854, 0.1460207403907853, 0.22481357288216391, 0.25590463841874755, 0.20023753355828025, 0.10573107328626419, 0.0969943997540301, 0.14941432603424595, 0.13825368136167526, 0.16391902110509335, 0.14383075548516167, 0.09872110830920358, 0.18303620899396558, 0.17998082052555778, 0.15364185967031987, 0.11781001989279064, 0.12682314391338056, 0.19371253288080617, 0.11613614842175476, 0.16836610021850756, 0.08633947270291467, 0.12823577174135756, 0.13106252126876386, 0.10203374910258478, 0.1620674325573829, 0.08161206669624775, 0.09391003784032599, 0.2012898625745889, 0.18252242446666767, 0.09860555160670512, 0.19026722098069807, 0.23175843570741916, 0.3175670707658414, 0.15492265142740744, 0.1310681137106111, 0.13597190380096436, 0.12032167745694039, 0.15336387700611545, 0.1540479169137055, 0.19280762982464608, 0.22946987060769913, 0.11541948082946962, 0.09709968321746397, 0.10116213256673467, 0.1706463609251284, 0.18268252152108377, 0.13841183255276374, 0.21226428659452548, 0.17875750068454974, 0.13623235837346123, 0.09863933608416589, 0.1596528766376357, 0.07632942314470008, 0.11127899776423171, 0.08725343857921901, 0.06498320133335168], [0.03348225194420065, 0.0759793745894586, 0.027403562600093506, 0.006466253703805588, 0.00665254665598754, 0.04590580788170619, 0.04338632472940991, 0.02810866417994182, 0.02406067090980228, 0.019696168413746263, 0.013139472763624885, 0.02892245065360781, 0.027875160580621134, 0.005261840433963845, 0.0127277847739958, 0.04526293370872737, 0.02769075555636758, 0.014941137276529787, 0.025798807581586224, 0.020061636403683695, 0.04310329737622411, 0.0451761206251479, 0.06056255991420439, 0.03321866790253309, 0.0338583896237035, 0.013713935284965463, 0.0354351747720953, 0.01636697246032136, 0.012660751123011354, 0.022274366459779205, 0.010397191133139836, 0.004449629707397112, 0.08842955974321212, 0.025933051083777702, 0.022213081341056574, 0.03927695249477702, 0.05721219695143162, 0.06658276993661158, 0.013729606571066526, 0.010174278699372326, 0.02021078414644205, 0.01262482542980222, 0.0463966787191889, 0.07995371616655782, 0.005529994668904693, 0.03735582997661926, 0.025528447492228403, 0.02985956962220371, 0.015266055275025147, 0.12876954350259998, 0.0029057738908206026, 0.014152176839660012, 0.01052410508911576, 0.029195442254985535, 0.00035618889958113285, 0.00794912844280442, 0.028677482548500263, 0.02968134118183967, 0.018854278004578045, 0.08495406397888738, 0.07581699459302811, 0.021909731590459426, 0.010763333280450635, 0.027930539161447557, 0.04594504690518783, 0.08746902338199078, 0.018492799417506305, 0.046242618437616095, 0.04350793735694982, 0.05013092067993937, 0.04699509680992173, 0.007790427104825335, 0.04531993831117307, 0.024702581727216323, 0.035738710299014084, 0.07350200712079964, 0.023178103147074584, 0.012314737935911023, 0.09731893758139304, 0.07431546226143837, 0.034915579467891686, 0.03983851409547272, 0.037136138942573345, 0.056765483421904434, 0.17838312883771237, 0.0372106563149681, 0.027804741778621272, 0.005037458068991621, 0.03820497715365022, 0.04635125736615831, 0.0625334628256819, 0.034562868757113334, 0.04591832958882855, 0.027253135490501602, 0.047245768439625545, 0.05210775694239044, 0.02606748227751063, 0.04812951214731701, 0.009513845791168993, 0.040996601549728263, 0.025882175184726238, 0.06851744838058949, 0.04250227075610911, 0.036508054096972754, 0.033332405146211386, 0.08599124743693298, 0.043712164906244126, 0.1429531711243814, 0.055484251164260416, 0.02935444763410957, 0.014862483986953815, 0.012844121928567128, 0.029071736292192535, 0.015062842792230509, 0.041713230837617195, 0.04758020795340981, 0.036508804863138546, 0.03898657452795775, 0.05736549114508014, 0.024704498862246835, 0.017420310797470234, 0.006758180125841812, 0.06221465533599258, 0.07327508421674853, 0.009569387165679327, 0.09820019150333059, 0.05991143114384144, 0.024175202969702023, 0.058615984124762405, 0.02974192724533139, 0.04852673639693568, 0.03323604277665577, 0.026187591457499132, 0.0318837845923319, 0.04859809748708241, 0.02449736400927988, 0.00821740285778839, 0.0077608393527747645, 0.0428657450022236, 0.02776534379189534, 0.02321854875903697, 0.026138454578035784, 0.021437853987839435, 0.023447363900261062, 0.0033378314401488756, 0.07587710185156715, 0.01228968973361677, 0.0044853193497645764, 0.05378900584013713, 0.023955975418850303, 0.03055796218705514, 0.007559087703890739, 0.014247710876647505, 0.0343360148009754, 0.06509500420502116, 0.011332196656674629, 0.05598227726295591, 0.03597561532871858, 0.029373555782160936, 0.06625876837079564, 0.016860997664832303, 0.053616800766077735, 0.02425274447417788, 0.07943070027977228, 0.017773241758526816, 0.04560569293736931, 0.04452617163018835, 0.0659388117492199, 0.037382428549350276, 0.06480051234604851, 0.029218742819202524, 0.08226635174885874, 0.06976044135949305, 0.026686852872972528, 0.04166880922932779, 0.07235253049481301, 0.086317302118386, 0.05944242445571769, 0.03163811551677364, 0.024381600463041858, 0.050921381691530834, 0.06738755296194746, 0.013249537573316166, 0.06232344748211965, 0.0891033876987715, 0.02282564141487162, 0.026332680849478613, 0.051446144258783716, 0.09146630163154296, 0.03152569785954491, 0.042320834322562145, 0.018166463198741118, 0.05843110795643541, 0.023062782016612833, 0.0030316201117520612, 0.05399766903851302, 0.09512280098973744, 0.022269748864815603, 0.0497667339720553, 0.06750334715170246, 0.058513240242797526, 0.020812525143546444, 0.042859106850359714, 0.03277810988947749, 0.02390383164428415, 0.07811686715051051, 0.03449958989456777, 0.0562887124326681, 0.0487296232923625, 0.024141202072402643, 0.05207427506965976, 0.020462959223697265, 0.0611253242729412, 0.027118568316162116, 0.013560563524914606, 0.04632055639259277, 0.020522447866237453, 0.028714032603367686, 0.02582493501024381, 0.02667243701345738, 0.04414499309214373, 0.00860342019868474, 0.024217439312187415, 0.04866417640099122, 0.04964453911769295, 0.09257120726209495, 0.015337140573519132, 0.06722171790897846, 0.07348593459614823, 0.055102463586316, 0.04337625067320563, 0.012747540266343184, 0.05885230692764444, 0.019426836797426787, 0.031531931900028745, 0.0748761160479438, 0.08399081566641409, 0.0773229778954579, 0.021893203243493073, 0.029551650157138228, 0.05511529938948732, 0.0830845719563865, 0.07072214983523854, 0.0672599533572793, 0.021530765131296172, 0.026760661614037333, 0.0415430827096345, 0.039577661157255216, 0.15474928573014277, 0.013195253540611556, 0.036011188621482546, 0.14016209831160886, 0.005140255577111196, 0.027007721139178164, 0.04007083025851077, 0.09574856458892746, 0.04761837828423708, 0.03748231492335758, 0.03293976976325916, 0.043870277792936375, 0.1086254760382637, 0.017119282293283654, 0.034573260739806204, 0.008466790332609128, 0.01970961900247682, 0.05609108856128109, 0.03601103540389769, 0.03949598086276843, 0.08132396401056359, 0.04474934453385011, 0.029589747709612695, 0.01210875221483049, 0.05185749516972611, 0.017721513586659587, 0.013973361384423991, 0.03823035381614201, 0.016742568132617784, 0.04233309172935063, 0.029870455731607737, 0.02090756218099306, 0.0394379880069004, 0.028563528884983355, 0.026552211005060423, 0.12764697188451407, 0.03994314255373132, 0.042725930125602794, 0.02544720961351789, 0.047203277372905326, 0.06291992737040406, 0.01594289778656657, 0.07767224504101662, 0.030834420336290237, 0.023793379002581203, 0.045603337217002146, 0.0634903947432195, 0.02748127838957214, 0.03960090809531751, 0.015106549065920617, 0.0463078355026101, 0.01278163596702319, 0.00970906510408367, 0.032077828917892716, 0.05349096316363543, 0.031275370969407024, 0.018817233822999463, 0.04212386928679001, 0.07606219635495255, 0.03726540095803719, 0.045567269797527024, 0.04308837015301951, 0.018577042276099808, 0.012726701717192848, 0.01889021135866642, 0.01512330532404444, 0.0185946335700611, 0.06552543070527815, 0.029200054104289705, 0.0683166414138771, 0.013570198995782243, 0.07119420555330093, 0.030115130808084246, 0.014536102760523079, 0.025727517354572495, 0.013075327264114976, 0.06218481238090223, 0.010812510379530009, 0.07405714507425025, 0.03184213430710858, 0.05028301977642602, 0.04179751200060691, 0.003397829770561188, 0.013894901532048901, 0.04327866256297116, 0.009095747560833492, 0.047720145404098496, 0.014448310042010441, 0.007923408477161562, 0.008962403254343138, 0.06055445853440512, 0.061937768177519885, 0.011966948382436268, 0.015854022968860886, 0.036712940481881944, 0.034192695072101015, 0.06603025200386202, 0.0076102863174803085, 0.024431219977897503, 0.04768377537989328, 0.05812391435967819, 0.05089785513137618, 0.03967691933916461, 0.06521749400323437, 0.10826093309949483, 0.16717265780654647, 0.11565809423524527, 0.1175409468311456, 0.10813656638586715, 0.12911832801276638, 0.22532432370128172, 0.10505088680093327, 0.19145603622159652, 0.14086449368586465, 0.11060657174957376, 0.14616050547169102, 0.13953485616272496, 0.1668231991390067, 0.1435631609732105, 0.13942524430251893, 0.1629797666664085, 0.07804445651990753, 0.0868985177047791, 0.09691752283082855, 0.2822485482019763, 0.15888539443333305, 0.1668280867799636, 0.11651599013637151, 0.13585817038772569, 0.18865206248817906, 0.1525739177821144, 0.09084966980041036, 0.1168083216273977, 0.12191626648869246, 0.18449628064709325, 0.10483746236610798, 0.22877617799226316, 0.0895901752876178, 0.19087095955206504, 0.1602538113271998, 0.11620003249376051, 0.17800370081057473, 0.0801118367141293, 0.07931894337337825, 0.09665677714492045, 0.09970714007654499, 0.14188751217819032, 0.12231882271026412, 0.12976505943844396, 0.12772596321038662, 0.08891234069221443, 0.15685288656142451, 0.07994229379560679, 0.2428980742491061, 0.048857184592634446, 0.173210074163733, 0.19445550027153186, 0.15449103749086782, 0.17385983929759072, 0.08214445183834723, 0.17176576860008702, 0.09297934826463462, 0.14094703199882663, 0.15932183472379563, 0.2287265354947698, 0.2645620907987318, 0.36150218257980965, 0.17606502338763208, 0.12933447205972287, 0.2057009508773204, 0.26181379633565105, 0.1495333301324037, 0.10513999814828558, 0.09097094917970319, 0.16951210646619722, 0.1065636040162175, 0.21721781111292301, 0.07203944568191806, 0.16361036428040074, 0.28614674063940204, 0.0709704848967733, 0.17801845566399638, 0.1464260775115221, 0.254475838474689, 0.14862707876149686, 0.09057842870993961, 0.11942556909015102, 0.10803139017474268, 0.2980387541315248, 0.19460372296312164, 0.15963196243730285, 0.09433455014180753, 0.07332894019782543, 0.21678998165072935, 0.15929466924600064, 0.11668459842762641, 0.150621144341365, 0.08904863539482318, 0.22032538549073283, 0.09832455055607904, 0.16604937372669099, 0.12737367767840624, 0.0706918970231087, 0.12751396369910048, 0.12372944338787949, 0.20568247283658675, 0.17390739803593006, 0.11953549504640604, 0.07560724738023936, 0.2020568698043785, 0.1834135379401907, 0.4275259075145568, 0.12807814915093685, 0.152785710449661, 0.10223549835744405, 0.1516119718191124, 0.12317015323787929, 0.13678055557031787, 0.10376521506376805, 0.21287346439015484, 0.17836583057238212, 0.13473021317153208, 0.15439109366026618, 0.14283416702622367, 0.15640089468609902, 0.1469466036125537, 0.1071339717976028, 0.12805400205956352, 0.08557228927290247, 0.15381087398817464, 0.18719404395068848, 0.16603311734093776, 0.1611552976312176, 0.21683893466909088, 0.18195234779869357, 0.11452446030753274, 0.12723286305704426, 0.07763498252437961, 0.12850814664195623, 0.19965565913627226, 0.09038124533910906, 0.14963485210412933, 0.1839967913204624, 0.11850981822898311, 0.09828793921417768, 0.1036273422200353, 0.0792305215051578, 0.2167497926782216, 0.10866890556269115, 0.14475597519307368, 0.13178958467418148, 0.0886483850979036, 0.13943670497786614, 0.08084412483919053, 0.1161556606811862, 0.10704818527184187, 0.08420536625048808, 0.14917811048367333, 0.19530280883754456, 0.07735121589634689, 0.15159876446329779, 0.13169665820896626, 0.12493780153172633, 0.19347184337675574, 0.08705689106136562, 0.15267160931421866, 0.2123003540140006, 0.2545505780125818, 0.09618139660526669, 0.08726573429040371, 0.15096884100667893, 0.2216098697916154, 0.13236678595985138, 0.17246931310622923, 0.11753493304094, 0.10904159967697437, 0.16152896467716465, 0.1035532998221536, 0.16781981824146164, 0.21946372043701912], [0.007701326291181989, 0.05191716958858794, 0.03217059450464384, 0.06472154400281369, 0.025843242596414302, 0.028596256161108616, 0.05652664018975151, 0.06037903972150338, 0.025181614591049093, 0.07917275847566706, 0.072993217486768, 0.02641139255325881, 0.06617809931236891, 0.052780937553653796, 0.06605279797147359, 0.062048801130825476, 0.03224924875182971, 0.0641816780121336, 0.03768059379991986, 0.05171103064992255, 0.06117941391083503, 0.017004141193484108, 0.03360942253963121, 0.06452436829286237, 0.020985475238112193, 0.11818793106583819, 0.08048611663041577, 0.027854238719409032, 0.06643772650990756, 0.030127116253659613, 0.013797047206260746, 0.08137603500677694, 0.018174562663320574, 0.0031198418395022953, 0.06280055938048229, 0.011453647448140527, 0.009959748225106348, 0.07666922144351468, 0.020700777813251463, 0.037191190020812136, 0.01857227337877116, 0.09848829418901475, 0.06377672393535895, 0.02354388714828078, 0.04009389333547123, 0.03530629963103322, 0.001974619036416463, 0.025446455016912475, 0.08430021559639324, 0.03205292531469416, 0.07477744392329648, 0.0114656692828923, 0.03159096280503417, 0.042536089707526474, 0.06142496807320465, 0.00466120547630013, 0.017557158998604265, 0.011051637064214918, 0.015411987363721336, 0.008437606213133662, 0.04357282883457599, 0.053655944028568846, 0.04790482238956517, 0.017250208634762995, 0.08747244013413306, 0.03875047772101337, 0.02067905539015849, 0.04335159796380228, 0.05209964407127231, 0.01731779865710245, 0.026193413725723664, 0.06679882205301715, 0.06387328165733526, 0.08596996551439648, 0.1427735694714131, 0.03562231089979891, 0.019420581689525037, 0.04596798740808041, 0.010505059185708243, 0.024247153947550445, 0.02105834169103013, 0.046667391208991896, 0.05180082381552747, 0.033011513897368026, 0.027198783467493715, 0.018128679742315607, 0.04165993793116462, 0.07270799529167914, 0.020990075596097498, 0.057138468649598866, 0.12053851864390797, 0.03114108533237971, 0.0066920279547752395, 0.02889724444567917, 0.018320893117737387, 0.004385524427503227, 0.05630474665292329, 0.025093336364314444, 0.03753037544928732, 0.054487176239490516, 0.0628703078555484, 0.020285567734390497, 0.038789567357349786, 0.033791268830217665, 0.01773654231651416, 0.034704541396950526, 0.027255328417184855, 0.047796612470260555, 0.04045282084975512, 0.05159176991231019, 0.02901999088334701, 0.023580316544300126, 0.022799456529619715, 0.015227115983443876, 0.02319396499754681, 0.028405023378229914, 0.030948651706679698, 0.022550596697856824, 0.014214206021279098, 0.01476293852207281, 0.028758220554840182, 0.06012814975674114, 0.0779922093234716, 0.03831000014718983, 0.07226946358118327, 0.09094046654119607, 0.006447858975133709, 0.01941960109698196, 0.057523841519028916, 0.032293861882100185, 0.06355383831466879, 0.061321921586509676, 0.07809665009018876, 0.04031942195950016, 0.014243742541199731, 0.02376980456193128, 0.03254843672977821, 0.04744318929771262, 0.0023585414859436213, 0.06203720639009149, 0.031648319807925054, 0.031123721949575894, 0.049256488770967534, 0.08296552189295331, 0.08774521340045237, 0.031151207269079266, 0.07531538320284697, 0.05737737699922535, 0.021892852758267717, 0.01288557590375985, 0.03636281531784804, 0.052148474515565944, 0.06275145697497553, 0.04373973641063898, 0.030398761455510414, 0.01833835609197136, 0.016692121242803913, 0.0347918409463619, 0.02685964400429399, 0.04865908574673438, 0.006662131852335147, 0.05849142205871402, 0.04414634906776971, 0.014488898337848726, 0.04410948874729295, 0.03596784336672675, 0.049806260278508555, 0.03346799121749017, 0.03431452220425971, 0.025973590541510813, 0.0486232060188007, 0.04321816843003035, 0.08321606328771, 0.05986315994373253, 0.08042995472468677, 0.038416375285915794, 0.0358712779838712, 0.05046031550474225, 0.08578586692531263, 0.027321154522078655, 0.06046605198794316, 0.09655025261904925, 0.06548672028246426, 0.0547912671801544, 0.01530331970688196, 0.048610527263653856, 0.05843322618954605, 0.07693178275780332, 0.03249975950306943, 0.05399139477841316, 0.0037796558923042954, 0.07425350873100181, 0.04523580270488897, 0.10851383404505831, 0.03789606368950298, 0.03432916597493234, 0.05537390002920743, 0.06293878462466021, 0.016611821821800644, 0.010063104977410649, 0.056278592411188356, 0.03591555403545499, 0.08137832560967054, 0.03573666867469588, 0.07346315880215938, 0.05839624712544103, 0.03526988364155254, 0.03750208765268326, 0.0009116582159842966, 0.04143391134998491, 0.01706765179762677, 0.03969489176186823, 0.045836480754998424, 0.002921989817555333, 0.026502995601584835, 0.017891571699311177, 0.024756479843129075, 0.025130570152654283, 0.027863994849124746, 0.053766264520104856, 0.024292828109596046, 0.01665141516094727, 0.00754693754941165, 0.0044312000259636875, 0.057312983478749954, 0.026530614986474958, 0.06312615823962035, 0.06309500527417948, 0.05143076121326416, 0.025935872202558864, 0.04267311985454252, 0.012317516919856351, 0.03976165632446928, 0.038114211056381464, 0.006114156342171614, 0.01506153661231961, 0.03624024124996316, 0.021022548147987936, 0.07520400167953584, 0.023803091082241268, 0.042264898412770806, 0.04448741907253862, 0.04037910786968085, 0.011641455817997698, 0.02438433539693154, 0.010581130758979389, 0.03504443545675567, 0.02579098773909913, 0.020296155069504055, 0.004626034379696413, 0.05564933545106361, 0.07569389192447548, 0.03168586960753366, 0.03391556276549255, 0.015845645797408877, 0.048404487916418625, 0.06353527600426348, 0.05482961371120426, 0.05594800631966322, 0.07260919293208469, 0.01586664139458369, 0.05952541476055499, 0.024116645123989835, 0.055176697506178776, 0.03950029393778213, 0.045262654086635004, 0.009354374056021053, 0.04742607106304458, 0.036273190691586465, 0.05929505595216348, 0.04395086641213106, 0.0523170942981397, 0.04511326694140031, 0.09023429435347358, 0.0331482797440502, 0.013123365765016888, 0.02936469214487701, 0.00754373578069311, 0.02975307382462967, 0.03873333267326798, 0.07872336363840489, 0.058087678400859724, 0.011699142238696017, 0.05059141996166399, 0.017920545144607464, 0.06451831619826055, 0.04552067632997229, 0.06608927907842783, 0.0135464770832069, 0.06829312251460168, 0.03598697258219604, 0.016317381673762878, 0.03743998856554109, 0.025662419033206763, 0.06382295351114965, 0.02305682376778174, 0.031016201509403128, 0.04905006637977016, 0.006273782731319268, 0.061707033986045476, 0.018341696235321222, 0.13252504440324922, 0.014158474082397598, 0.052030179048738176, 0.01585068761356055, 0.015463902269520107, 0.036815496672305374, 0.04758703379681514, 0.08385612208756708, 0.038635710089076916, 0.06656548699303981, 0.020364620347297, 0.025504309976954135, 0.06601410287041819, 0.040081306510875304, 0.0344212765565082, 0.02449780642505615, 0.01490964435957252, 0.04081820648524069, 0.05748189054429532, 0.051859188224038774, 0.07113266571034348, 0.027924488982065555, 0.024135088690766887, 0.04056127208675589, 0.013644325663335623, 0.046454709879453146, 0.05072735077250869, 0.020050168067457217, 0.0108161062047246, 0.08430828250223592, 0.027341233686574047, 0.016782075286872925, 0.0398523458129456, 0.043653513214761214, 0.01805434240058305, 0.012749587636320822, 0.02264842804100725, 0.011036610249580156, 0.014581450377590956, 0.028493512279143738, 0.0827261960254081, 0.023420820868904554, 0.08584922239665063, 0.02453940499934458, 0.03780803635656353, 0.033695649565948595, 0.012372286460782972, 0.028619886143133048, 0.019910625152049527, 0.12559687463386407, 0.041218112042594346, 0.10895245768610509, 0.14650602644730001, 0.17914982963233225, 0.18182516188150455, 0.13402034077913533, 0.08758944474280843, 0.20314082293020141, 0.18081357342100915, 0.11940178206010212, 0.11414335454784094, 0.16423428160769327, 0.13045053959133165, 0.2159021623552807, 0.16770749443000363, 0.10420412981822606, 0.2021347043374854, 0.10916190612460337, 0.16909573767935077, 0.0979923518494733, 0.10588799873667379, 0.17517096813647978, 0.07737262805383052, 0.1202500558968994, 0.1551743725975675, 0.11971731835435476, 0.23458833385619426, 0.2333021488401198, 0.15077059277363364, 0.18480070866644385, 0.12567128475394942, 0.1880454587479753, 0.183757649314019, 0.08371274107165876, 0.14229127115780307, 0.18631930943698655, 0.13840810936545173, 0.09176873782229039, 0.16469211107300175, 0.14013566827822116, 0.19213195559718918, 0.07809693354272074, 0.1364603614614856, 0.08089387458899329, 0.16361537449542554, 0.09568140166060579, 0.3086838829180887, 0.17459971169310232, 0.10830962564796211, 0.24346839606521592, 0.09077070145717553, 0.15882490413083186, 0.1381260817570071, 0.24322361565164982, 0.143535505199144, 0.20548230938373074, 0.08002867786994866, 0.08528563449339521, 0.13748563225230864, 0.08143572091695764, 0.10549690319044937, 0.12664758720465247, 0.07236562293743895, 0.22526311327613172, 0.0711089935934832, 0.22498817964186593, 0.15466708449586747, 0.10566762588437527, 0.09724266586765166, 0.08165790173675745, 0.10393812110827816, 0.0841706318240012, 0.08854185291115316, 0.1183369275062315, 0.14551008150221842, 0.2473965885057565, 0.12031174129656247, 0.15245443870944364, 0.07501638674687955, 0.11786548465850855, 0.12318967315818995, 0.12566996708271966, 0.14665055659509477, 0.20129381558827816, 0.25513508777704935, 0.17177019658828938, 0.12997152013403754, 0.13544708760755678, 0.15513038382895533, 0.07333136103566616, 0.15773446990116952, 0.2509903376020732, 0.1473959141801442, 0.1528967472334062, 0.09598307176342896, 0.14341478506403585, 0.18576083134018606, 0.1187372161075473, 0.1032717395273428, 0.15721109395305957, 0.1420927011678296, 0.22312577393266464, 0.14189607704118376, 0.2652009468405478, 0.11055673773009932, 0.18343826725838647, 0.13661212347928556, 0.16996268873974202, 0.15358831012441268, 0.12615228071808815, 0.18629939115095526, 0.10149299061947292, 0.14693900402034485, 0.14540739507684786, 0.18446795071565336, 0.131261489624458, 0.15179520472884178, 0.09590778064223067, 0.149277456765694, 0.1746594512294377, 0.23916840583326357, 0.10270177777255736, 0.15981015448849048, 0.13009216366035323, 0.106932268508019, 0.09755099327453683, 0.26024506277134346, 0.12607289868737423, 0.16979503805839247, 0.16541197325193113, 0.08778419195403976, 0.18378498333115734, 0.2099166867593604, 0.1513349084604171, 0.11086767749680627, 0.23043904844070637, 0.14862913187713395, 0.14438472898496738, 0.10684004684369411, 0.0905121161392139, 0.14223382988524053, 0.14834641478955746, 0.13719940648203896, 0.15969465907302596, 0.11208886761338481, 0.2543537087378002, 0.16843097254393563, 0.15021615962107338, 0.21209620690393835, 0.11790913634843404, 0.24551276297819233, 0.1869651062353965, 0.15226221192748318, 0.1198425354255784, 0.13075720458742113, 0.15861525650947325, 0.09306921037815272, 0.1663234033772061, 0.11383229986794534, 0.0913287352229799, 0.08763365567691865, 0.07870956639488859, 0.14745041367507752, 0.14127344674160405, 0.10344747243629349, 0.11389450620739691, 0.1832304122827707, 0.20290564925920582, 0.18068525369369215, 0.09602139914228071, 0.17840048839007655, 0.10940382136933266, 0.17786067219511156, 0.2556367374716267, 0.08520773101237514, 0.15369064414933806, 0.09937288059342293], [0.004231266878289922, 0.04507913006349437, 0.0368995480089178, 0.07035195316758848, 0.05690439048433497, 0.039638270203384667, 0.04682304878388682, 0.06525108695871408, 0.051672852658216036, 0.02779582834562227, 0.038860537742655125, 0.053447246356236364, 0.041693243603672714, 0.04245121482639544, 0.09423567117342065, 0.1152975962407166, 0.021854450685843345, 0.049383797262224464, 0.0818137240205561, 0.01674835592688572, 0.050589520063611775, 0.08500359922407136, 0.022031064595906966, 0.010907692016072331, 0.04483751359305555, 0.003093325381820661, 0.026780683321938403, 0.033793816072565895, 0.025303420655789877, 0.014485290063725365, 0.11491952418920495, 0.04429548723442901, 0.16113651315531424, 0.034902341468560125, 0.06195647987507044, 0.027783117031738646, 0.04097618530654619, 0.027233498741782484, 0.05791451571689499, 0.026698867046845057, 0.09791651680584877, 0.014843721536078281, 0.045079516937896136, 0.06313466181557986, 0.011958643989337069, 0.07610018665511763, 0.004083190222210702, 0.02797687407432785, 0.04885158065946833, 0.01994472564077906, 0.060333197020114436, 0.017760250822550828, 0.02339473365986299, 0.011434147637637873, 0.06978995872721558, 0.053009848455868425, 0.04721101103050094, 0.05799849044471499, 0.008151128591458884, 0.057665027693034186, 0.02506981554981922, 0.08077062636373505, 0.049838550884516976, 0.01082290331983278, 0.053553234620560566, 0.06617429185538523, 0.03705678372493675, 0.11185562448395837, 0.03318698250598485, 0.06673450897177381, 0.06820320677492889, 0.014420032779115343, 0.01716803229834524, 0.030995469254952286, 0.051787298533224294, 0.02591990693021686, 0.06684664892212999, 0.050222008534136324, 0.02394395932975796, 0.036519713955180305, 0.05694554089718769, 0.04241679832639714, 0.06719065304364889, 0.019900897750630975, 0.0061418456325848265, 0.0662683904351246, 0.09521335258238739, 0.03486314074947469, 0.017147610309503732, 0.04041184280668536, 0.033416544582935116, 0.020810947002422427, 0.02936534715005227, 0.018029241529744, 0.02486937822053029, 0.03837427492403696, 0.05709400873691325, 0.06203447911708106, 0.019404677704216975, 0.012533035647544651, 0.04707318798248326, 0.0622292991066652, 0.038378633964326114, 0.012259268382143591, 0.05693321454248602, 0.048023477917717355, 0.02624117356214312, 0.09217549220568712, 0.030321074394328944, 0.011515737916793556, 0.048345215693717046, 0.07010383261067253, 0.042755926298278, 0.03306294137972497, 0.052350319531415744, 0.0020706861030175203, 0.061182359518903884, 0.07514967838482511, 0.03494675541597028, 0.04716305392644098, 0.011806196322844876, 0.08151697986308606, 0.03298333718351299, 0.03411124460399151, 0.04456413894771569, 0.016957677960876497, 0.08303157399378477, 0.04243304705127113, 0.065488068597211, 0.018721333021418225, 0.04176238303883903, 0.04596561636595477, 0.020705814841353608, 0.059315433890949336, 0.005422492902125082, 0.009217379340571503, 0.02966033888139552, 0.017440694481915524, 0.009438744276731966, 0.030909862759853565, 0.040887663846895586, 0.023142221503921097, 0.07646887412955684, 0.040472298635229956, 0.049312175702183485, 0.01813645170430743, 0.03391793763805782, 0.022230580704466953, 0.05403028523188926, 0.05099066285296314, 0.011415429236817987, 0.038764906987067194, 0.04919643513858319, 0.05621155588737419, 0.06944807666924692, 0.013091756019651169, 0.031942463096892165, 0.01212784504112337, 0.022425611368230274, 0.05028182467926414, 0.061103467784461483, 0.02309093383261033, 0.036917983914815614, 0.031056488158121228, 0.04163529671308014, 0.04661247419613985, 0.05364698846073401, 0.012583597450547162, 0.04053737397395796, 0.05297083159788482, 0.08437571356133108, 0.05552875321178187, 0.05926324415110773, 0.05563873279419157, 0.06676500693203942, 0.031653102111792376, 0.05551171924678549, 0.050878350532823996, 0.03805928638265018, 0.053343973873603734, 0.03459553474620466, 0.04476616782466731, 0.046771625131969495, 0.07288765057080215, 0.05811441103897749, 0.0220747220314919, 0.060003825177949284, 0.043629779810867006, 0.06477359967726855, 0.10507603746748741, 0.023648385371592258, 0.032641654308404655, 0.03615381121034584, 0.056769654770652135, 0.005781652158006065, 0.05650474539687557, 0.06043614774581887, 0.0270917552388123, 0.012228145102609791, 0.015194954654772677, 0.010464112743765358, 0.009861859425361599, 0.03676329161070528, 0.007795953950394066, 0.06618693996701511, 0.03986416654961725, 0.099083460236509, 0.03143217193052894, 0.09477867429415066, 0.036382771908275546, 0.027265915752298413, 0.01956671679152116, 0.03469119231486994, 0.030531022705197818, 0.10353133608136447, 0.046660753057128, 0.04393071446928286, 0.036691961164075526, 0.09486060739765245, 0.06702616630542664, 0.05369708295010271, 0.04891789323019405, 0.013081765275508648, 0.028180812425430746, 0.05295457521213159, 0.03906159368794292, 0.021250865332061247, 0.008084258691768252, 0.08599311669146822, 0.04514342782297923, 0.08629706973630576, 0.04952459273138835, 0.015520932727433262, 0.024890390097073493, 0.05221777865963598, 0.014222160886762845, 0.018299578636464094, 0.06102371803154388, 0.01902699444232689, 0.02679731317555472, 0.03378396035142003, 0.017320675317258123, 0.010316996091616251, 0.029069173728085818, 0.0478288532805539, 0.0470816953888824, 0.02077780220837843, 0.004199332503166291, 0.015284224007759365, 0.03836295597495572, 0.054208423656922196, 0.016459448848881068, 0.0435475594243936, 0.04497792984869692, 0.01575754855894634, 0.02298400711057888, 0.049950349925746845, 0.08283720216563634, 0.04443501482807821, 0.02855385319449969, 0.01689942655033402, 0.039287612608243386, 0.021618530079121553, 0.024704010481195107, 0.06966828864308135, 0.02683440140718895, 0.03619422234835164, 0.03216597882490004, 0.06650707278881343, 0.05455639228344925, 0.018571493884308204, 0.07860996730385289, 0.03339541970842308, 0.018374314343917276, 0.02411890125292684, 0.013994879836607126, 0.042284433654839956, 0.04263702945242967, 0.03388634417206049, 0.026151263568129753, 0.06271338623557841, 0.04460471096418558, 0.039160055138411066, 0.05476095691143025, 0.049363266105853745, 0.030866320237457275, 0.04529842656225928, 0.053253874272829106, 0.024159335373570363, 0.024954337371332992, 0.014759612742871528, 0.00861132909889303, 0.026359888462109432, 0.045879691944367466, 0.0366318041098214, 0.049244307972971475, 0.04463080008844695, 0.07388950205377995, 0.0062072714565381895, 0.03287711143193226, 0.002595579384022483, 0.03941125536878263, 0.0949488683874088, 0.03613333751056944, 0.0293564758518891, 0.004950117342354309, 0.03380193660456327, 0.026001263552555637, 0.07502644548132535, 0.07556178006193331, 0.04797085916863815, 0.056634271712673295, 0.057524963837837985, 0.045946490980925105, 0.02218465947906577, 0.03611182193121603, 0.022242964515762947, 0.06485472838844984, 0.11351512414553475, 0.027086620534499808, 0.03846056323738829, 0.023918841221940615, 0.05629328980801567, 0.02411914257062299, 0.021472209200803793, 0.04756126642948197, 0.04930134321893415, 0.04614209238019201, 0.015968141341281515, 0.07984764363256194, 0.040801099741891514, 0.020617283805603945, 0.02029072925178034, 0.02757652418597812, 0.055078419916812456, 0.006950754999002863, 0.05811671313318995, 0.02052888300480141, 0.01382821453585019, 0.020663496144416354, 0.022683507207060055, 0.017228522600846428, 0.039485964263158466, 0.044492620809544484, 0.04317747000905295, 0.0026786666468627033, 0.016735311364755034, 0.052517794012542696, 0.09112219025771465, 0.1026809708245339, 0.016840223275545626, 0.04032605628092443, 0.16103951110234185, 0.14569296201150264, 0.12282721397857513, 0.18735165888022992, 0.08094079747435548, 0.11778122264771693, 0.30602951083452473, 0.15798090506465207, 0.13338756747543812, 0.10660127255945437, 0.12344411394048123, 0.12506204567128612, 0.12782590704098826, 0.1921466338418184, 0.12471659364359033, 0.1806469799409951, 0.15265987284721869, 0.10229484718893805, 0.14958914729856676, 0.14244910059196336, 0.11283574205252433, 0.25443011834736795, 0.08994506551854073, 0.0783192445974677, 0.10307344532902203, 0.11884942500581665, 0.1415528543293476, 0.12668695646308123, 0.17894229641364467, 0.11907367426301203, 0.2572115384522946, 0.245505653682255, 0.2763611012168469, 0.09288877368934693, 0.11134465916022179, 0.13383890051514874, 0.09408193264877605, 0.11015860949673, 0.2126073254452598, 0.2011586930001936, 0.13908260381750523, 0.08945407210699013, 0.14558443799614906, 0.1580591379634796, 0.11173897993660743, 0.20703912261993657, 0.08193994466696056, 0.12189407292152606, 0.1088995363322958, 0.11568031844592865, 0.15174000043301814, 0.12353924673891838, 0.28179897716449154, 0.11945259667211965, 0.09160728479224829, 0.1239243284949372, 0.1660085718838438, 0.11880470079279716, 0.10891988362756469, 0.12073543388396503, 0.16004891345097175, 0.2975433097491342, 0.1743413408797595, 0.10819088201969863, 0.1381342942195554, 0.1149375195945463, 0.17329443576595477, 0.335365223788446, 0.1645867433398962, 0.20708491935605006, 0.13244773080993083, 0.09249015515970607, 0.14087909532170143, 0.08750656935115976, 0.17144358266265164, 0.0939966440801659, 0.14400111811776317, 0.14246137332051031, 0.12980952318156921, 0.2080268244589529, 0.13727725633690435, 0.20273871870050508, 0.12010405486029004, 0.13336827738150475, 0.060168331068369656, 0.12670068475868435, 0.2774507233933095, 0.1039890812770013, 0.21213886267956228, 0.21047689621486973, 0.18887781327770603, 0.08811970782135764, 0.11929050012822114, 0.17669169863145198, 0.10224191051337028, 0.15578279962703107, 0.1995421249058939, 0.18525194977560352, 0.09037010642069002, 0.0940904975117695, 0.12911857316090217, 0.13035726072567125, 0.15025288587616337, 0.09334768333862867, 0.1244229981074891, 0.11882432030453799, 0.11810805107797347, 0.23418034607123947, 0.10294041416097073, 0.13851913082743847, 0.11704793860835415, 0.1266768364416015, 0.20664074157755222, 0.10986436278589311, 0.10682416584102378, 0.09936741072564356, 0.1151925579254185, 0.14751311031080064, 0.1871621746930384, 0.14512869228999462, 0.16177858676641219, 0.19957166525625414, 0.13510247061569847, 0.1351678179156396, 0.08304247542494729, 0.23380978934226498, 0.17260463487717415, 0.09540603135622318, 0.101933705680553, 0.09700895542459143, 0.14149021898065844, 0.10116458404809238, 0.13910218502484983, 0.16083442936501197, 0.1305276846453067, 0.11360526971158483, 0.0748539224807774, 0.13596507029667979, 0.09792246930902043, 0.14847145566055853, 0.11275223080789852, 0.12771804186124958, 0.1927601323733407, 0.1235602988350776, 0.16464036949459585, 0.1079882441028472, 0.16184819351521232, 0.14191512198698136, 0.08992525448481883, 0.17181970118995638, 0.08565598437863012, 0.14610648095127077, 0.08916298933928052, 0.2192528317532232, 0.17803022277451333, 0.1678112533784682, 0.1870620929666104, 0.1471804136470441, 0.10750818276597608, 0.1260858685559323, 0.15317001079599704, 0.08912671507606584, 0.11052692158808632, 0.09815575074284308, 0.10337896885410433, 0.16777831159772413, 0.20435179343387005, 0.1135027135211614, 0.12726892281564015, 0.11916271666245115, 0.13686320113558925, 0.12740886409676846, 0.17428593740107554, 0.13850327280740585, 0.12483593482043474, 0.19167630182158565], [0.03371902673895802, 0.02836707712812049, 0.08280028438856525, 0.03175651632069099, 0.06049761481042351, 0.028618989820261637, 0.022818637456023888, 0.07685760246409525, 0.013390748645178975, 0.024758628719756683, 0.01824709969843107, 0.04593629052021331, 0.040511212071343776, 0.02321882646590952, 0.02863649684455126, 0.04113936586485755, 0.08001316458948197, 0.03892988785200062, 0.04335896389919423, 0.044999816980693615, 0.052111384368711905, 0.05324097335218422, 0.03139191784054762, 0.06237821127738684, 0.01981816983090774, 0.02694931268061121, 0.01959102476135858, 0.056197934844080484, 0.020509322864874717, 0.06576936842212755, 0.01153025528295867, 0.10533835363364029, 0.033791697839455265, 0.049924050127306295, 0.06203518774841101, 0.1055035298509944, 0.060014006486462976, 0.05298899937300913, 0.08097419890785411, 0.02153431786404502, 0.042051332251679514, 0.06320231120973345, 0.007648992909854579, 0.06132550687799531, 0.020744011985258232, 0.031413073358576626, 0.045541372195246725, 0.056594044435769326, 0.038563747619909626, 0.0504508926232736, 0.05204217981607203, 0.04964316782030848, 0.08609464632407313, 0.032922302958585566, 0.09433683308382189, 0.025302152780275193, 0.02555782313368494, 0.04823099964508607, 0.02170311576206117, 0.043776098773964954, 0.10533891287782501, 0.03305188290053799, 0.015381926073572569, 0.03927572292365855, 0.03483115657863598, 0.05355527241443915, 0.06324127444156236, 0.024932992246542728, 0.08596301709692325, 0.02195545937865973, 0.037345208167549104, 0.03461942136768372, 0.01397402883852802, 0.08963368142083769, 0.033859986917025624, 0.0505223571352901, 0.046473053854800044, 0.0482379135886027, 0.0518597474682235, 0.056078792850096384, 0.04970577252548068, 0.01340494233919608, 0.05330162836358913, 0.017230110318069498, 0.060698789499339566, 0.06522205988726308, 0.03892960056902901, 0.04133811205505364, 0.06173824057764104, 0.019746624879659187, 0.05261926235811365, 0.05921986442239535, 0.03694665475538181, 0.012497975633689954, 0.052663147704856056, 0.0972285162236902, 0.044266540602210074, 0.02440318115986884, 0.015254304443876592, 0.01129995680399119, 0.06106803238752389, 0.017807989591552366, 0.022159583506084258, 0.08504579534694072, 0.011765892437148479, 0.032665923973845865, 0.038887749185725566, 0.05256874268994697, 0.017912106686121514, 0.017130220113622568, 0.011641548706158515, 0.023912840838273688, 0.08631212336401786, 0.08747797894982562, 0.06987009918497455, 0.03181048721495656, 0.015961902512748156, 0.05361440291087474, 0.027668200012656952, 0.01414311497712568, 0.03197470007674589, 0.0017376915028791936, 0.0502508900488817, 0.022543878106760885, 0.06733024192433204, 0.04128607936323651, 0.10083340423842592, 0.09352920021140769, 0.06345002190960992, 0.08675480727106334, 0.04833717943139134, 0.02288857170741164, 0.05326863295669037, 0.07866756945487954, 0.016628476573274504, 0.0668069349241353, 0.020218638462885734, 0.03125818378682579, 0.011093070929599626, 0.05214008585279507, 0.07185721634736947, 0.07523109820941765, 0.08625156411360349, 0.014853431700518536, 0.003352923611659677, 0.04686207330274967, 0.05926855697086262, 0.01733516970078551, 0.026517963044405467, 0.02080847445364681, 0.022195890328035723, 0.08273338959101709, 0.013037095646253757, 0.0643084081070077, 0.02369580621410522, 0.050444901815705726, 0.0924609135836363, 0.023249697894038215, 0.004711660505798195, 0.12937934949032723, 0.030324391555041078, 0.027627905703059612, 0.038162011112416946, 0.05209349238524034, 0.04384891926160744, 0.028875269213571187, 0.0420897553915218, 0.02855595802107165, 0.026234041283568068, 0.03417933066826194, 0.07131016828239926, 0.02619883188256814, 0.07493485966997762, 0.07557638169777009, 0.019043206778024475, 0.024671423016116027, 0.03191098645930329, 0.019375773206833872, 0.06149335291176554, 0.02931320529070593, 0.04923651302834192, 0.020265021256261298, 0.02587468092960696, 0.036495578355125846, 0.045651753973816676, 0.019205343541539004, 0.016444828060846177, 0.04676153958444634, 0.04104706376130062, 0.009925712853850377, 0.008052210361065884, 0.07935217626753353, 0.025703921846504656, 0.08499348686347086, 0.09473342914134265, 0.07604742617977243, 0.049390638427388285, 0.036783822767075994, 0.03794756011977311, 0.048009531287055825, 0.02176399485418393, 0.09975367225706579, 0.015237940805813959, 0.024243336914467718, 0.01751432319231812, 0.02238479037318499, 0.048159561946146914, 0.051931702276511546, 0.06848243816244988, 0.02820401914387701, 0.05333664624260799, 0.04426083324717418, 0.022838253137325088, 0.05109495423253506, 0.015610772815923539, 0.01785309301809438, 0.021483277256089835, 0.0052492761132006925, 0.02146501755041461, 0.0599404888588094, 0.030557265047044046, 0.03930759984218786, 0.023657905929271254, 0.06495481777575708, 0.02027147746224317, 0.03644554515279109, 0.03840120674501504, 0.0430601972696041, 0.010087477107111727, 0.023415745536406195, 0.036182144972225355, 0.0928980739967477, 0.06383540243991921, 0.07871496731475477, 0.02777854731727031, 0.033081595620681206, 0.1417352598641188, 0.03269036600907003, 0.013058837221544838, 0.03071630106968505, 0.03532098553654167, 0.07005673352508776, 0.020973123985552983, 0.032779860400384477, 0.06076938450156201, 0.11767426911260813, 0.01857120851655641, 0.03340984131359766, 0.012291104123446972, 0.10031523002732186, 0.06157238637247394, 0.017788952306633996, 0.038373466701276844, 0.02528241835534573, 0.02076971040467822, 0.037481093013118354, 0.030594200061093417, 0.03171470515700358, 0.031225671015319326, 0.03924649666934725, 0.007797435372917643, 0.03390352369376248, 0.052527845086109255, 0.015862686465674593, 0.0027252488625010536, 0.013659264377859092, 0.02812824730250624, 0.0032130311686365356, 0.021701480164342833, 0.03640702625195827, 0.019422295811255614, 0.04540195185390692, 0.0635374976592439, 0.01101988080453368, 0.040934782084678455, 0.013347934863920654, 0.04431290041294791, 0.06302378591029875, 0.02893985425602765, 0.06898736671334313, 0.017394583649753083, 0.02019125465003233, 0.03177369009673355, 0.028544708019903595, 0.0020873521064077656, 0.030511680900329546, 0.07171214227714846, 0.041538068664170084, 0.03625509186437534, 0.026629128147877996, 0.05662251992391483, 0.09417456800058004, 0.03206675703216705, 0.0038401761201150237, 0.0280141806410205, 0.10839577223504744, 0.026053842082018816, 0.02525521457315453, 0.02146570511432665, 0.01926323489075707, 0.04503263618736979, 0.04994304910782845, 0.004549864651409969, 0.04388752626255155, 0.04827900271442148, 0.05180868004719096, 0.16472670760366226, 0.013567804013408962, 0.047703452348228426, 0.027413609843220443, 0.07405061034425613, 0.03448964224287099, 0.016528165020469218, 0.01003377721644938, 0.11947357215948644, 0.07707875672607653, 0.03272726846438262, 0.016883024607875177, 0.02791986947188214, 0.054147504345183416, 0.015793175477865004, 0.012027071920343706, 0.00817183690566209, 0.03970660524623048, 0.04904852271260274, 0.06314273255186216, 0.036734402435080665, 0.0686298641225984, 0.030963479338454145, 0.011849171940177199, 0.009624938116288714, 0.03848224735608505, 0.019060560584729238, 0.03197598135879925, 0.028952460232821685, 0.03992037059018209, 0.045868928409031326, 0.05823267586228829, 0.017295635733453017, 0.07460218598885883, 0.024139654574795597, 0.021618012969772664, 0.05648633247361549, 0.03246294131742851, 0.037931713591059374, 0.028090649622402368, 0.03877095142078977, 0.09392290811745391, 0.018970217751038652, 0.01877259962531107, 0.060359071639757005, 0.03250087799143887, 0.1435911844694807, 0.059107314614999684, 0.13984354363093454, 0.07978792707886427, 0.20196536826270245, 0.13871756292158557, 0.10495044501318086, 0.15694264142263323, 0.0719421295328967, 0.1927194377828029, 0.09366135037834607, 0.1302614997351362, 0.2168796905466626, 0.1567831878820735, 0.10209499783213101, 0.1370139978826046, 0.19478087313473227, 0.08729967964632858, 0.21591095704465144, 0.2526952356340424, 0.09108808402332569, 0.15400349913585573, 0.16349385762887617, 0.18754020844015384, 0.0806683153214474, 0.14942635361465717, 0.16677994581480182, 0.15945222288850816, 0.062448875227522474, 0.12226410104983276, 0.1392293556202804, 0.18404663300081608, 0.10996164063051825, 0.1379234668227934, 0.19139295654191127, 0.25237311098364096, 0.15797319822013378, 0.15677399482698212, 0.11559496092940531, 0.15718239629941602, 0.07461137138307095, 0.09761966539606934, 0.10039379234395682, 0.10162612137895438, 0.15318338669115497, 0.1262290657107388, 0.3947756793950835, 0.12970096852269866, 0.16749701943368683, 0.10227609335655168, 0.2650195985071121, 0.12173052847145066, 0.13318908941601554, 0.18097368579718376, 0.2751744003786195, 0.11267842589727334, 0.09519767842345661, 0.2169124637880633, 0.1803474855278769, 0.22808775606174625, 0.2566998530059092, 0.1458189834750468, 0.25265693123782834, 0.08934480498635, 0.0895166538295246, 0.15421614982187748, 0.15617998557225352, 0.14023501456024187, 0.16591238188407115, 0.24703177743621413, 0.16728490500921206, 0.1406179359483142, 0.07456559762959519, 0.1633633162465788, 0.20276591482181705, 0.16402051243330204, 0.16829172840281842, 0.09108911058114422, 0.1604833772345897, 0.09139313257389492, 0.13249124460402997, 0.07075110795877634, 0.09187775213391551, 0.12700161175622096, 0.11364177380117679, 0.14359221102729922, 0.1036323524350601, 0.277901642745541, 0.09037877853599288, 0.08868468234375601, 0.12392638161057427, 0.1183319709173614, 0.0762390477522727, 0.10226658620541135, 0.10428748018438778, 0.1795068878920809, 0.1004181462790697, 0.07659841959755267, 0.08044867791355619, 0.12448158085105882, 0.14594604681816795, 0.16268353578784775, 0.1627771976974703, 0.16530220817414024, 0.12680285790514562, 0.1750363818099422, 0.21377075253234756, 0.11088683735579254, 0.16651241258988458, 0.10168807490939095, 0.13391979939995274, 0.17960191343820867, 0.17994315964320015, 0.1888098306353054, 0.1932139935032014, 0.14312560219437848, 0.08200146152728027, 0.1320872711197984, 0.09637580673781135, 0.171143475379194, 0.16487995583203532, 0.08822731253120207, 0.1655861050371201, 0.17193973184593264, 0.1865813881158829, 0.10917511348041797, 0.16338491992604348, 0.25489059847689444, 0.20850469478436057, 0.20192064404968293, 0.238023380178117, 0.1564585351415219, 0.22617382327875785, 0.17052761729686491, 0.12067466012893185, 0.19122930483952646, 0.16070431699195217, 0.10559594303730035, 0.2520244796910594, 0.20481040430886133, 0.13057829241358465, 0.12677953818873053, 0.1805764998519613, 0.12956799098080204, 0.1352144420267113, 0.05341595932540875, 0.183982833198482, 0.1727214786073854, 0.08953530040960159, 0.1398303975621539, 0.12392115689093068, 0.2227297217975701, 0.06507386017831103, 0.15102412191129502, 0.12035085774597623, 0.09055636537772033, 0.1375087987511389, 0.12012133014298255, 0.06570785922268707, 0.254230966130572, 0.08606957226631143, 0.19133373794536437, 0.15077891248849132, 0.20458895893346882, 0.12130324293168322, 0.1179265418660737, 0.1076093753198943, 0.13317214355113047, 0.14867773249505029, 0.1780712238002208, 0.13190515669843844, 0.15202610362921992, 0.13494531533891155, 0.10602353501223749, 0.21934869999606765, 0.10798679619667031], [0.00791464395250284, 0.1288575823268583, 0.03739620664066846, 0.01576072207817267, 0.013948563118315032, 0.053397592367424127, 0.03832708007746166, 0.05030594878799973, 0.023876790655776862, 0.05140357658327107, 0.006220868559584263, 0.012985278416665332, 0.06859071702966768, 0.04153907223935089, 0.06082523231124205, 0.06549366869993749, 0.03375381096115997, 0.016718239095362446, 0.0053102026070137665, 0.026324985496279214, 0.02570893397674926, 0.044045554879572124, 0.0464620030364923, 0.04241504781549016, 0.05920555006953017, 0.05450458941800941, 0.05298539875976501, 0.05737203353595349, 0.014860230730846526, 0.04592794399227827, 0.04647624078056505, 0.04022719646473566, 0.009301315763995293, 0.05729682668442688, 0.04504758639321212, 0.03181415486089405, 0.03222204113919889, 0.02969653270537815, 0.11971617688334758, 0.027791739351326422, 0.05038842198348815, 0.06085897465386699, 0.07241115154277894, 0.11312968232819151, 0.021437888461796027, 0.04667552706274775, 0.028707373384085876, 0.06690238947950064, 0.02375002034128674, 0.034465594742927826, 0.028654915513470772, 0.040334238099955746, 0.06307480353561622, 0.019109699379412398, 0.06418899798225011, 0.02195988928208188, 0.033796263723483974, 0.06528783619644181, 0.08479490155173887, 0.01036169061872868, 0.009287517562869095, 0.05440692086854289, 0.02574705834230108, 0.07703597071550547, 0.03627839625903195, 0.030977602169338255, 0.031218347214763204, 0.031347113188296076, 0.060498878855498574, 0.01124442883601953, 0.07253190232140404, 0.0554907092854621, 0.0056195091700271494, 0.026360503247668667, 0.04600869348993705, 0.03057145299540172, 0.0447843853955067, 0.05162018028298213, 0.07129752017076939, 0.007167142278875315, 0.0726813737363104, 0.07299311789533786, 0.03321582571633401, 0.059533791932007, 0.051577233393946965, 0.014357203035615386, 0.04796682571571681, 0.04048485864674853, 0.0389050436206162, 0.01720520288443133, 0.041129173065025004, 0.03506974317133427, 0.011897146281215453, 0.028347666375339035, 0.05754202844635133, 0.03799387396523549, 0.03320661350904453, 0.019971737900989193, 0.025896049037034956, 0.022827912865567113, 0.010095455912843106, 0.03846024914133934, 0.016768299110774553, 0.023071827599778775, 0.01883956337077243, 0.034458274772811326, 0.02093351149420825, 0.07349610824378268, 0.012498099165367744, 0.028967205510144273, 0.024506310001015667, 0.038848594431915594, 0.01802825327632168, 0.03702865297635717, 0.015432844107459872, 0.028463433752016678, 0.023400691908694083, 0.033254336956287586, 0.04904552347837918, 0.037541341997923396, 0.040103362182215344, 0.02333839938435103, 0.03438602119023281, 0.03892075991438281, 0.03583246413918753, 0.03470425794441854, 0.02210517594170186, 0.10031382808642042, 0.07299206835488159, 0.05338601677888825, 0.031475714452925234, 0.030638169677507494, 0.026720712044005914, 0.06437773140327585, 0.04330954739763852, 0.03924536668965894, 0.10767755714515526, 0.06882101072058563, 0.02351217110821557, 0.09521484645383974, 0.026365082538236054, 0.056196850829667626, 0.05544098251829705, 0.05914845736697317, 0.05058942430262124, 0.06637556613573144, 0.052506781498631167, 0.10420291173842647, 0.019623987609520555, 0.04863143380310747, 0.0660219629325213, 0.09542133013207106, 0.04491368954580638, 0.004366034671904579, 0.06336819988885714, 0.03069527004094374, 0.08989695519689592, 0.04979185782553208, 0.018359120905158982, 0.022320266617762468, 0.029872928280383352, 0.060191187301590565, 0.052516231193177165, 0.021778897179530996, 0.0711170451775674, 0.024152651256431016, 0.08711416379458482, 0.03598255991575218, 0.10526746751800661, 0.005529560871617568, 0.07137865654282993, 0.06878400867384288, 0.03314977744594216, 0.014550778132322577, 0.022553038603115468, 0.025607938690471555, 0.010039998808004444, 0.034834672922208425, 0.03741951103532507, 0.019497429884429422, 0.05080274914601638, 0.04825852135376585, 0.05661124310966942, 0.03393806276782867, 0.05251246204058971, 0.0289319520590887, 0.042047099615897865, 0.031182339167102214, 0.06231323553008899, 0.021221589282034867, 0.08493445978890504, 0.003518219769654435, 0.027866139895312732, 0.033603347462391665, 0.036439630954015645, 0.04309772791701459, 0.018786904402077198, 0.03467464481570548, 0.047025705852936354, 0.08724822152045467, 0.11062481230305088, 0.06700130675228373, 0.052027658619467294, 0.023714876057760372, 0.013099244529111011, 0.056853564380998575, 0.0388872167546182, 0.034617249508418386, 0.024460616686771956, 0.07302348562065633, 0.04502565712637959, 0.029687759083425327, 0.025794176580083948, 0.015486966304090476, 0.11427513699257567, 0.005517229250061416, 0.061377240795521974, 0.051729278864278916, 0.07784825374162005, 0.014771863446390678, 0.024038090468234113, 0.09605911365079303, 0.08197037367931298, 0.04704174390363117, 0.10668283794075252, 0.01684875941024192, 0.018837037195842114, 0.08278043505044715, 0.07750960457469187, 0.02678387982380246, 0.03885082757821487, 0.010386608586075806, 0.016695141544445388, 0.02666177881521083, 0.034896477065499754, 0.01587259006731573, 0.013826912186378914, 0.035901496322044445, 0.03900025302784578, 0.03494295945030547, 0.03345425909144744, 0.018161973923504836, 0.013363525710789668, 0.0735080668762807, 0.04440721349730607, 0.0202072678028696, 0.07655330467969179, 0.03465970993162163, 0.058141905934579914, 0.054893294769910075, 0.024704632927633585, 0.061378826597525235, 0.05108052113604161, 0.04597109389461337, 0.012017280359061496, 0.016842464082724145, 0.01802014423564317, 0.09429446842160918, 0.04817508671793246, 0.011419585263807208, 0.10009391488687647, 0.043944063551363446, 0.05383134368927248, 0.0706176401206082, 0.021156280286489956, 0.039386924416307485, 0.0959790881062227, 0.05682331539930836, 0.0286926664111595, 0.03041210287671176, 0.029734400431475336, 0.04695741294492637, 0.055253095624427644, 0.04218391525829512, 0.010080132239137687, 0.052752653587489366, 0.040065057786001314, 0.06670772653794096, 0.030058026614208377, 0.06801558418139335, 0.015799914178768956, 0.026087159245845773, 0.04483761318448571, 0.008584459522558797, 0.046138851828272306, 0.032426655562894965, 0.07258382010003252, 0.035340172208605275, 0.016721123416397362, 0.11709569652955379, 0.03657322136625167, 0.08261105301038874, 0.010649847888177442, 0.020809723176963387, 0.06400790245782945, 0.04661952986592247, 0.013420527440405661, 0.026034958014685302, 0.06860880436555994, 0.01790376015818648, 0.03352677697435983, 0.03330301418299637, 0.08899522374474234, 0.03729386495486383, 0.04901261234115209, 0.040714780785023205, 0.03258096099260353, 0.028900507980236606, 0.040926466200260386, 0.08285099174827337, 0.029159326955015143, 0.07820681353370029, 0.04560219574599497, 0.03483173497501881, 0.01974729712181274, 0.05611668738927092, 0.005459241661047864, 0.04774371792952861, 0.0646018121211279, 0.02341832916793083, 0.09969424681677934, 0.007531213594765793, 0.03426198389441256, 0.026086421886218653, 0.017490298675012686, 0.03194127566060953, 0.004837222795392717, 0.03784845132500895, 0.009394255635749188, 0.04640005716693498, 0.031180674841086713, 0.07363012000437706, 0.018314415844337597, 0.02684847444235798, 0.03181604518284721, 0.04481152022978471, 0.08978742760636153, 0.03301356318256548, 0.036668357995128444, 0.046096153917812535, 0.048888632501926155, 0.10027216056421881, 0.06974903431030051, 0.01962941151202446, 0.02534289908174786, 0.04024615331042198, 0.07230245898808203, 0.030153396899902055, 0.049540672916919, 0.027906930246841044, 0.05104090672947707, 0.03056462523677657, 0.08243474553549483, 0.17954727604744897, 0.099379193157919, 0.16210222827090373, 0.12952401753394835, 0.12023012228910962, 0.12588526843295944, 0.12843483968848182, 0.1707145887156648, 0.14291152658481754, 0.1404169451205, 0.06051080301404, 0.17481262284901836, 0.15021327913047808, 0.1442837432747887, 0.08493888011622815, 0.12369401182138151, 0.08289322617553896, 0.17399496188567531, 0.18859639853960086, 0.07090060235632044, 0.1189183192928472, 0.12337363385144742, 0.18401362993303808, 0.1762070407670352, 0.1423778237714883, 0.1468687844012053, 0.2064515791472889, 0.16545038490045458, 0.2411853621203092, 0.16499330620131186, 0.14200032628591985, 0.07584388427917035, 0.13665773635429723, 0.1562740152040797, 0.13891224118490375, 0.09237701163416909, 0.16915581429437285, 0.2356821848379989, 0.1780883841697247, 0.17341549297974956, 0.16717926148445378, 0.21094370423065079, 0.18216630083418664, 0.10912160223890698, 0.10226463268120443, 0.15565215099242427, 0.12006073258817197, 0.15818450059140884, 0.16039017497772173, 0.07557841183076944, 0.20028513826189503, 0.19203424874332645, 0.07099216518503043, 0.11724395752553979, 0.10119819232533056, 0.114149950564869, 0.15712972009374251, 0.22046561022439312, 0.08456139029153893, 0.12982882859726108, 0.13025524845767406, 0.1402127060798868, 0.15069039868971995, 0.1293569031141458, 0.1628990822862233, 0.1633777799865892, 0.1780969183892012, 0.0944982324877093, 0.10010855482710947, 0.2765232054216247, 0.12916296029523497, 0.20584780993240498, 0.22524117251798031, 0.16504382203903892, 0.12877698987722397, 0.16159529256964886, 0.16454413352954775, 0.09839578141127864, 0.12920730146429232, 0.18590841051791945, 0.1406741514801979, 0.20540033797583274, 0.09393272936464318, 0.19510331954206192, 0.1626841333364287, 0.18956716983549057, 0.10552360901548978, 0.14744549539060364, 0.1334594724880111, 0.16363452669353257, 0.14030839046162946, 0.20385926018559164, 0.1419657450770178, 0.12917989083836157, 0.16144221288061913, 0.12635551618352053, 0.1219348134773393, 0.09215594164185947, 0.11508090061045463, 0.12919479890936805, 0.0945174536337295, 0.10063814374828532, 0.2118491282265994, 0.08490354048028108, 0.09373716243933286, 0.1706003496843961, 0.1722044458672885, 0.10569410954391766, 0.12194589110872439, 0.126044116764059, 0.13544554010994975, 0.19290647048863674, 0.21323099762441652, 0.1520113334540398, 0.19855514318952638, 0.21217627841378414, 0.15564672708992036, 0.22039788805188673, 0.15036822807404304, 0.08465473810511251, 0.10350146631319677, 0.16272902608879153, 0.15784014406944477, 0.16419153390151842, 0.15593036348300596, 0.1749755850722713, 0.10234740848142294, 0.10939488878413554, 0.1490630593992049, 0.13846334430479235, 0.1630238780090886, 0.18536200596680566, 0.15612839721143246, 0.1181211741641164, 0.2118701190357247, 0.23847722598621923, 0.19355824277285608, 0.11952245622993478, 0.19290388111145268, 0.10970178360660231, 0.1353869037402253, 0.2038868699943827, 0.1013857995971076, 0.13338563693386893, 0.14288998419238677, 0.16755228501654443, 0.16493482304917229, 0.08689531545725562, 0.10885042243547018, 0.11283109955970319, 0.17927934445681112, 0.1751269946896261, 0.1080626235794156, 0.19631703264049946, 0.11341835957981887, 0.17034138132247234, 0.13254015165711605, 0.1619882343877708, 0.07304836815643696, 0.21249471052039057, 0.06233099344817381, 0.13701928388928214, 0.1558516402879069, 0.25791600226394595, 0.20529694674957186, 0.1415009135680814, 0.22635523289922746, 0.18398005996019612, 0.1128455096735589, 0.13531155133199307, 0.19999541913069066, 0.1489219613253109, 0.1394804179548256, 0.12330762771589142, 0.13928028514548657], [0.03565366304810009, 0.06812081401867252, 0.08394821351694484, 0.027400666787739725, 0.0669378899939118, 0.02921550035206301, 0.02342940871453574, 0.08023504663499133, 0.03183165422430442, 0.054816188020331245, 0.06947700414926776, 0.0323131404847147, 0.05772000216248055, 0.1251223904170817, 0.06501894699589861, 0.02028847120762352, 0.04027508462088243, 0.048033433230293375, 0.02428032938511141, 0.08720993244599912, 0.11567138586073153, 0.05499999166556424, 0.0033223598157130787, 0.044975386436788306, 0.05150131408065077, 0.01737472473553592, 0.04003311574999844, 0.04017795233296291, 0.06299293554958797, 0.021477726949078423, 0.005616634425091287, 0.00911730623263265, 0.06709430982629139, 0.046293004040396026, 0.0414333367840417, 0.08883807612883468, 0.010200613929379371, 0.03681234039005734, 0.02579322280061822, 0.004262549599872962, 0.0455559355266873, 0.05505890765738103, 0.008448526796494282, 0.04409724283182333, 0.09145821174306255, 0.0315654999576509, 0.032661212533111536, 0.04425511440081943, 0.06632055336188886, 0.04846017101719495, 0.03225309834364922, 0.07334397084289983, 0.027331921887854417, 0.018497221660049214, 0.05567715593403386, 0.1422817869893005, 0.0378513777808797, 0.01653172732931712, 0.06600727702701284, 0.013414107623600192, 0.05529890002142038, 0.05786729788768196, 0.04929265961231244, 0.027148857517468355, 0.004650534829124808, 0.021641652527896148, 0.022203721661841678, 0.03797864796774041, 0.04558979661294049, 0.037826288401359515, 0.0397254356874093, 0.060705753238571275, 0.04284046793116197, 0.04369655203434729, 0.0646411507360397, 0.07242717044127565, 0.056107773956271915, 0.006108037693681376, 0.07469300571228228, 0.05736469824407851, 0.03573447383279282, 0.0627066370009655, 0.05825140671203694, 0.013405736197807617, 0.03323490896652783, 0.023640967725265413, 0.02616611035210231, 0.03915212229795514, 0.08778446774569251, 0.043286898008157174, 0.01833802667416392, 0.058979450709997654, 0.0922886893573788, 0.032165381276319106, 0.02097771093699961, 0.07402664711398464, 0.022707702178928642, 0.03799401186106186, 0.022482637038093903, 0.011656975801733714, 0.044962864729665944, 0.09078529543213307, 0.04994202638044954, 0.016076360836685184, 0.02535450531380071, 0.031880710664535725, 0.006161227657069122, 0.015257390820601536, 0.03510325951802154, 0.027661211375567703, 0.04761135708841105, 0.011841128016972255, 0.025911093088648012, 0.056072886312200185, 0.035489440610211705, 0.038526462120634895, 0.022594784649329323, 0.016329995311436155, 0.033190556306151614, 0.028125385964109052, 0.07570301603165365, 0.0274697813250485, 0.02998573089679403, 0.0135681152366282, 0.033801136042682395, 0.006225768170664989, 0.05154089784369834, 0.11094699057960704, 0.054522251575103695, 0.03682575842005111, 0.05530146641596671, 0.04208584068222873, 0.03172817489793224, 0.03994402355484424, 0.04211894717187651, 0.041273802804249915, 0.0533508763258015, 0.02867935563347513, 0.01649626511930218, 0.03572649502706143, 0.02293361384691971, 0.0794009760683102, 0.024857492366385077, 0.029487842693924907, 0.031579184203198364, 0.041052211872151786, 0.023516585689879233, 0.04686170175010639, 0.03512061907038574, 0.04609385948447932, 0.07918424213365202, 0.018968258481172305, 0.0008206156687059951, 0.030163400092973348, 0.03646878059953451, 0.06673465452847943, 0.06250830449824853, 0.029837127076461915, 0.0403835894840379, 0.04958145943800769, 0.014477033551121432, 0.03620160360550208, 0.04891702755083961, 0.045954783882705436, 0.05051449707318699, 0.03452901533173938, 0.02404976181776053, 0.04698686519517534, 0.02555255819442532, 0.025608373445368586, 0.03863813858779688, 0.022820876347982598, 0.03961902990516636, 0.019442104929757696, 0.0496279226706153, 0.04150787330863457, 0.06892714454161544, 0.04462879676852496, 0.033105034080724564, 0.024263515670393265, 0.023282279613457864, 0.006877049201002886, 0.08698729197344474, 0.03761079552913866, 0.08609032558818018, 0.011252480420103718, 0.09478570698129554, 0.0641101598739624, 0.05596037480920073, 0.05287733439716601, 0.01895529818871329, 0.05962245128748398, 0.008567317347643117, 0.03991494285723856, 0.03923382557507965, 0.07106792361986253, 0.016211640472794255, 0.0118653153279616, 0.027849217013065374, 0.017773705241721005, 0.015604719763711817, 0.04887077499241118, 0.0858265768376089, 0.04192091727388963, 0.01452587835956365, 0.0861391177280776, 0.015222637241916552, 0.02685226849280298, 0.0518180109981087, 0.024943474244566697, 0.046930756915601037, 0.08458643370578367, 0.012607671763567675, 0.04981380624456271, 0.03648116824127013, 0.01992980033279427, 0.02326517861576811, 0.05934911494654033, 0.0275028016298048, 0.06781092379242182, 0.057153664003576965, 0.004760343956971361, 0.015768856974318624, 0.05035167657620004, 0.025538046573919636, 0.03212884845842998, 0.07584016109185834, 0.016419369043902527, 0.030348232211244684, 0.02146225771866739, 0.016908881990539453, 0.038727395491854805, 0.034083864621577725, 0.028758471448635383, 0.015346122954431322, 0.04628149739977333, 0.0271269416571745, 0.08363652298407209, 0.09149495331991105, 0.043970229284417246, 0.06927908533402989, 0.06295261251169347, 0.07507284742689903, 0.03469944308181444, 0.04299427157328014, 0.060292330059793696, 0.044214760719407956, 0.0266175314919242, 0.06436247859270343, 0.029834369159934503, 0.06502047917174716, 0.06189288691647592, 0.1300736856196196, 0.063700812282942, 0.09367894741796678, 0.07080894759705952, 0.032279716068578344, 0.05049084410852483, 0.03743667523526857, 0.015348501657436212, 0.023851373773669044, 0.017421492488093434, 0.0181535737694151, 0.03105155263666905, 0.09004864826678269, 0.06943076308215819, 0.04924716165048942, 0.020858660873566425, 0.022137443565072554, 0.029075999571491155, 0.051250979529633645, 0.020651713712140918, 0.009476788203051735, 0.04817752287753167, 0.08229098147562436, 0.05985564079075571, 0.14084794618670018, 0.09019270344006439, 0.036693501000803326, 0.01702100087347771, 0.018865529920965917, 0.047594495493197636, 0.03724202378502777, 0.06777904687389251, 0.030539840377206286, 0.07031553334766819, 0.022842238709751158, 0.03906786411760315, 0.05148516494720694, 0.008970650190848016, 0.02110010497422228, 0.03630158574049992, 0.046278773957202514, 0.0749857891951838, 0.0816087112311394, 0.04523119468602442, 0.07434348575770855, 0.08573985568458035, 0.025872920842600927, 0.09333882736222399, 0.08613361721678127, 0.03533947123815456, 0.024055710490492564, 0.01107733261080519, 0.019165158399470875, 0.05542558415101902, 0.04340772156513507, 0.07958307516791167, 0.03432858374810988, 0.0693092079112126, 0.04206665401016513, 0.04580871006774326, 0.04676407916591533, 0.03355221492388556, 0.009589812984960455, 0.02450763341790486, 0.04071201520761655, 0.10926507518536623, 0.028639712498613426, 0.05993888390460803, 0.005556234137921204, 0.08953969009340772, 0.03614436151579984, 0.07689974496080991, 0.037507415794196634, 0.023498293425467227, 0.07689081237561281, 0.008726991138481086, 0.018942550485653263, 0.04107290773742622, 0.03650541492407361, 0.02338907418532237, 0.09329919763390096, 0.051858866467110576, 0.05825279716161951, 0.014089261868878478, 0.07527848074753439, 0.052358757989901694, 0.030921896085924203, 0.10963000116809722, 0.03666561923079914, 0.03713354956538927, 0.020545200677588582, 0.06236965790571225, 0.03548685506346726, 0.031200062611230442, 0.056572850613344106, 0.03577947383746505, 0.052989857391484325, 0.04373319785020525, 0.04993950595117865, 0.03324183057092371, 0.10083446910064067, 0.13756156688736332, 0.20984979196181222, 0.09942259969970874, 0.10313098619301474, 0.12457325859295747, 0.1680923157161282, 0.11336676355811859, 0.1793642116770629, 0.16525290275533355, 0.16843443526135338, 0.1971246884955514, 0.134497138581449, 0.24353555133265836, 0.11275505001145987, 0.17162050300788495, 0.1212226658038074, 0.11733014241702135, 0.12278557709989049, 0.2475666293814298, 0.14088340073583588, 0.16330169213394966, 0.17275089638367777, 0.10779993203017982, 0.12481402470580033, 0.07259796974399398, 0.1949559855124643, 0.17796458436116097, 0.14421137860946118, 0.21272891892060158, 0.08465617835041016, 0.15656751880963005, 0.1169023895636201, 0.11753808932318804, 0.10645057540386917, 0.18826497358179864, 0.06461716452313047, 0.18888251705756112, 0.13145688801042496, 0.09420619211009434, 0.15551474546232533, 0.1507680646834835, 0.055200871410629446, 0.145203355219095, 0.19193197600543502, 0.12810799593646682, 0.12769626964244152, 0.10934819572515066, 0.171046044316984, 0.1164994502980863, 0.1892588041242092, 0.13971906966499745, 0.12966205125614522, 0.1750710855929121, 0.13521375254757945, 0.15627878027096873, 0.19235263488465743, 0.14940585310180343, 0.12497781430401149, 0.1345401467575181, 0.12358997708126424, 0.13511756254780677, 0.26375144720077515, 0.13915867634838627, 0.31589362830404316, 0.10239360358325705, 0.08343498823383162, 0.10899783307386023, 0.19013735375577406, 0.15154705352840886, 0.16869461404219752, 0.14745174666806576, 0.1122616281011893, 0.07188450439923233, 0.2000487082067036, 0.17943643844656407, 0.214683301145992, 0.12990552932024002, 0.1674699918517182, 0.14617175164241947, 0.12847793979510186, 0.10900246024492288, 0.22301527341046642, 0.14326116911345912, 0.06967605677463355, 0.1422578084372705, 0.08512172232111616, 0.14262220581933377, 0.2075005067332137, 0.15994979699532832, 0.11162333130355805, 0.11862985654583863, 0.1713844253531387, 0.13080689305018994, 0.1446818638472788, 0.12261137636678836, 0.12282516086293806, 0.17878766922700792, 0.12231999482478827, 0.19422208860276208, 0.21043515974475493, 0.19991001564889185, 0.12982835362274803, 0.12388228558965268, 0.11370520588130721, 0.2531837239380806, 0.1494545456502707, 0.236120218591344, 0.14981155794474388, 0.19712442802565713, 0.11982653950971943, 0.07487125138962462, 0.2650731020877438, 0.10938950318602786, 0.1780836957116281, 0.14155228742428366, 0.1134473943121491, 0.10693527157268218, 0.13699041769629525, 0.11223423279701703, 0.3265073781292285, 0.17824869572875962, 0.22162900666796395, 0.14300223139505233, 0.13263723031888086, 0.1479401890068285, 0.18562436043735475, 0.20772530757371457, 0.1358900090018588, 0.10523082553258828, 0.18546361986908222, 0.23184958484865006, 0.18701516242036897, 0.15974663047780915, 0.17313070745477754, 0.1527882385398111, 0.1290496252477169, 0.07860413737474911, 0.11874062519881035, 0.14578259429864346, 0.14688384568979665, 0.15441180867773874, 0.12621325365598166, 0.1895044119127335, 0.08172249060965354, 0.15575345845953112, 0.11443454456785995, 0.16036657946965388, 0.1036560475345581, 0.1727409678841791, 0.2059851082101945, 0.10522563145646166, 0.14244646524950383, 0.06674938639926334, 0.06261108285417, 0.09312676656390391, 0.15433737557501565, 0.17342468603484093, 0.14151579099557093, 0.06483042807949167, 0.11095402326675192, 0.15126787576704256, 0.18644772109485444, 0.13899632699547276, 0.1441504439759639, 0.10287140496075155, 0.12294116955731185, 0.09283471086453046, 0.15770514405542807, 0.12975119324701448, 0.15216554695319745, 0.09741442278027536, 0.10328335342027488, 0.15192504131024884, 0.13324985551016946, 0.13454552469474657], [0.057992392384837714, 0.02728344575922576, 0.027408919469904036, 0.02678423030902782, 0.02291984724692039, 0.04702273726222977, 0.0838132058420489, 0.05727542984870173, 0.09693947891073842, 0.007556972822414772, 0.06474199855039198, 0.029846249268420284, 0.02458343207235298, 0.032572430603566675, 0.06799322973576284, 0.05501018829583641, 0.03572130861181406, 0.025225628257518815, 0.06272991075210514, 0.0713159752288653, 0.0062905581416411996, 0.07539643530523585, 0.06557773152786879, 0.03297253917422026, 0.08811271343860896, 0.00822400557808578, 0.11424988673459138, 0.09483679738496581, 0.044986249563554605, 0.04755702613282108, 0.021723939947062926, 0.04188484602397488, 0.049829105020410595, 0.025208333822628184, 0.050454163818710276, 0.056362773982747916, 0.015475019162911323, 0.0047613427441026415, 0.0396658378773399, 0.028353335425978708, 0.025474784948352366, 0.002599109134133605, 0.07592821523787514, 0.0256390341993181, 0.05216859198445755, 0.042328782484776555, 0.05602679080179623, 0.07041490261232661, 0.06109292258418376, 0.02356530122098423, 0.04905066775879072, 0.019553948021043214, 0.02820611247913011, 0.041223306118720965, 0.04827822896561796, 0.10170890484005214, 0.02465975166658961, 0.06361890599251756, 0.09524490008310926, 0.019845971161679878, 0.04704626765282405, 0.038795742026019486, 0.05580399328121736, 0.007270800678299801, 0.05169329188403584, 0.05417000051707991, 0.07284562298727613, 0.06422717980439625, 0.03198356562924962, 0.021981755346660654, 0.019349113347068913, 0.021226226029196577, 0.017754407486908378, 0.050462211572354844, 0.02087653753527951, 0.06350125403954618, 0.042655561119318015, 0.05172992620857493, 0.01882377812909263, 0.01445457568362115, 0.055655540763250286, 0.032829441610843904, 0.002473191810666674, 0.01927060274136884, 0.05962882130857437, 0.07113671065458367, 0.008947770017379475, 0.03381623180523034, 0.08410779729245171, 0.028229753952473405, 0.05769514643977727, 0.03512025134818208, 0.022343119020543756, 0.023720874526207487, 0.020885535237950184, 0.017832433541996345, 0.05739624191436076, 0.020495847378286625, 0.027681918732161005, 0.023482121309385668, 0.09449806394836596, 0.0607423760717915, 0.014399499707524816, 0.011168036463430092, 0.02005662427343909, 0.03389031250750826, 0.0945315573124155, 0.06015095619424697, 0.07382054647971546, 0.030793787032786398, 0.022244768652824626, 0.019776102027765686, 0.05150898262077282, 0.03899994659267607, 0.047792291734367616, 0.06062380864375061, 0.10212034768154545, 0.0505648443715707, 0.017558589667802858, 0.04930782815321319, 0.07972795005527236, 0.037550423970265735, 0.05390708680234609, 0.057219133877585975, 0.024495483263425773, 0.05096460820265836, 0.08098509267813737, 0.013214762927213264, 0.028626516634117694, 0.034776346818093336, 0.036191973880293875, 0.021507261553779248, 0.05884278445474564, 0.02533109175161489, 0.03881521215061507, 0.10633327202090334, 0.04119190800514433, 0.029384650650524327, 0.044443928261077216, 0.0160477991636482, 0.009299645692320361, 0.03529613747471764, 0.03011861842335953, 0.039149134555050445, 0.04819824172544384, 0.047834637244382215, 0.057831916116899064, 0.03828233671224406, 0.03783137522517674, 0.011991384672001006, 0.049628290392818956, 0.04292294495709, 0.03251878146622931, 0.042543221986101526, 0.09892419821793035, 0.04035285020607614, 0.06410934782076268, 0.036044145723985094, 0.010229363293957808, 0.012808673125090859, 0.015999662028926036, 0.027808315578788042, 0.02460156920396032, 0.01203481323881856, 0.008204073885515814, 0.029721913198309562, 0.03650641083837517, 0.03722446504980326, 0.04775071997315653, 0.04133122109417473, 0.01441477741595478, 0.04956713742426327, 0.04750659839520532, 0.06393407456456654, 0.06397610597853219, 0.038412326511235974, 0.03952345277573313, 0.02285854297599966, 0.06468304042373935, 0.026196091203019026, 0.06265991712890326, 0.018201195710008184, 0.015171189649751591, 0.021160014965120825, 0.08556655127434962, 0.029496127934826, 0.013303612847061408, 0.0899318888062431, 0.02352613497585539, 0.059056251024406765, 0.03607997565620369, 0.00925218750302109, 0.052584428340196616, 0.09218744317730589, 0.04800935125639362, 0.04956863895659486, 0.02185110288161424, 0.04159366749527474, 0.01665001705048546, 0.06070415977568877, 0.05314425858218343, 0.030292120101230762, 0.06088110693399945, 0.05338278005740816, 0.05832256095844412, 0.03669786387153211, 0.00883803558310554, 0.0509810101451172, 0.028458592076335224, 0.04020126055805914, 0.008214048350289946, 0.05241168700459023, 0.025966234182217912, 0.03930070122042972, 0.04468310091103758, 0.008942297276770397, 0.05936959630719597, 0.028874263723170566, 0.008272219321600372, 0.013916276342746232, 0.021162334296311584, 0.03514531774506454, 0.05349329207092524, 0.05176193336205137, 0.0546810730931259, 0.03146417333834595, 0.0419808138582495, 0.06902836007817138, 0.0572020462864349, 0.031260275206859076, 0.08884457255443258, 0.03792961834058647, 0.01691895413152393, 0.042097619284064546, 0.03879501807293104, 0.044456714268533454, 0.04883254337454996, 0.014596864066627479, 0.022928356568539338, 0.035461428605260394, 0.08205417603735002, 0.039357020174183195, 0.04226532359156878, 0.06186806183728961, 0.04078767022057887, 0.017043339997349728, 0.02398669937505357, 0.04243259888983542, 0.022893447857049685, 0.0355805016513313, 0.01036128650734862, 0.06557311201768537, 0.0445515061578443, 0.019723429652531783, 0.021771477617984338, 0.022324083650845195, 0.02630847438629116, 0.02567255054600537, 0.04403693255998435, 0.025255997898057107, 0.01180106066092248, 0.029552732256331274, 0.010393403785964175, 0.022687333816241835, 0.03752623474405658, 0.07904165784918493, 0.012677368527698903, 0.03450513637113956, 0.03538458615601544, 0.021867096882253405, 0.041624782156319394, 0.02903146688045273, 0.01971085814969434, 0.0260670475226136, 0.07686075108546404, 0.0321502931746504, 0.050197872934081865, 0.03899534623469076, 0.0342877819052627, 0.02322822061908101, 0.01956806127582827, 0.06554711865441454, 0.08167352993041277, 0.07455361601445945, 0.014390089274984936, 0.02853595546536869, 0.08872598980463321, 0.005637702800618906, 0.022126252935718627, 0.016977138509373033, 0.028040714096277956, 0.014427768351930766, 0.07402968082216478, 0.05834396162460889, 0.01238264109668953, 0.042202944882334247, 0.04905956970047086, 0.04898512893686852, 0.01196601088233893, 0.035424867059074105, 0.036649619484500545, 0.015742819560992143, 0.03385664294323614, 0.029668756272463553, 0.01972344497429027, 0.0403517508699048, 0.04530083590878114, 0.028748964297495065, 0.055348159474951614, 0.008800322032203118, 0.03345838830535931, 0.024766201498888196, 0.0031466247521400935, 0.07796135130188159, 0.03094966677317937, 0.022267305044337146, 0.021785753666453307, 0.0210506042029949, 0.05533664134301006, 0.024890200490312233, 0.04997090023431567, 0.024778692562493588, 0.028174737348191203, 0.03225607459523505, 0.03267441988892613, 0.03348120240374439, 0.04670884805701433, 0.03542469085885152, 0.02602490311067912, 0.05431197193120757, 0.039709313367042816, 0.0481032008575576, 0.027045278599666014, 0.07519042660151759, 0.048340308900562026, 0.06494684280046532, 0.028593655292605682, 0.009501700424739431, 0.08881806591225248, 0.011940097958300144, 0.018412992207994385, 0.01697593192089229, 0.062037520486140446, 0.03276607847862667, 0.05875830793933523, 0.04832273867401866, 0.0650710639573874, 0.07453814103838897, 0.03589725602538355, 0.050906224641948945, 0.005337260832499352, 0.034374625632359136, 0.12062470353538952, 0.11749789268980104, 0.20861026170032643, 0.10216031448855516, 0.174352525763454, 0.1999585396580158, 0.15966240677141375, 0.16759045151693208, 0.16581029300728153, 0.15867704916144573, 0.14362965740503805, 0.09328229007341209, 0.09306542590380677, 0.10569367287380081, 0.12848023039799544, 0.11675048198911453, 0.14738391724324998, 0.13768354340666725, 0.1441362100623308, 0.1424886460506147, 0.08674429654474221, 0.16427909775126368, 0.18161018228819295, 0.23645587235448823, 0.11780869456068163, 0.21418056360656218, 0.3903766186727632, 0.24936010249920432, 0.13222731199235688, 0.15104486757228452, 0.0883798176542886, 0.13986004516482353, 0.15007596553093003, 0.1301489614190594, 0.1985008275556949, 0.15525243695705168, 0.10911361194185673, 0.09937717834667814, 0.09193490229306683, 0.0858873199491251, 0.15459694148552033, 0.09603342672269191, 0.1458221550790533, 0.10768720985300119, 0.1066106035103721, 0.1463274819956672, 0.16527297425894968, 0.12472881274598262, 0.08218188289432757, 0.09889370025766474, 0.1533454296088988, 0.13595576998927902, 0.12736453058859035, 0.09406509403620036, 0.1638782805492801, 0.16547819389210594, 0.09753244628589, 0.2208211516300517, 0.17443814374987157, 0.061388287783390096, 0.17513356772401642, 0.16022359681946619, 0.12989114218902204, 0.11954161608892104, 0.1821338493497141, 0.1508009911424691, 0.16173115060214074, 0.22884687258591577, 0.14121006062674907, 0.10380623907211328, 0.1627232804293594, 0.12911098889045178, 0.08721151058712313, 0.2729047270071122, 0.11416179428417837, 0.1227381332747398, 0.13486634699567673, 0.13170186760685137, 0.06329956990216049, 0.10700562142676885, 0.14811776818767672, 0.15188163476845912, 0.1521116450068451, 0.09232248915659805, 0.11282701631106677, 0.14630462193200666, 0.11408964412346964, 0.10901998067575117, 0.19619994376215244, 0.1340211068670596, 0.222262438807276, 0.16461862791930476, 0.07174552072800937, 0.12153897584686357, 0.13768619407088528, 0.07096257886939472, 0.07105279338335799, 0.13088756210861668, 0.14793856490042903, 0.07144779597799625, 0.302002523695269, 0.20138945400474534, 0.07263671081032484, 0.1418321393430233, 0.1659064523635372, 0.10787313173134482, 0.20053342735815435, 0.10167967858574084, 0.14992988788552825, 0.10212541152272495, 0.22171523752472094, 0.09757686406373979, 0.11558738431983417, 0.18827306347027903, 0.07249832468768282, 0.1151161712984885, 0.1823622354817006, 0.16423228977909013, 0.12953509516533346, 0.1551147709570585, 0.2063336169287082, 0.13475572389941062, 0.09994580710847532, 0.1512477123328755, 0.10332423187191449, 0.1567399192361101, 0.2112983416525587, 0.10505572081573548, 0.09322439680897421, 0.1249507177741297, 0.1960271909352272, 0.17270447145546639, 0.17782757719678266, 0.082058182677194, 0.15634610407775448, 0.2465025485763627, 0.12171580426154599, 0.19899178266284928, 0.15374304456335885, 0.14286625078849255, 0.07700063107955842, 0.09514425911249653, 0.13660790999570202, 0.09998316921654249, 0.16820833207138125, 0.18251473294390788, 0.23472175572908696, 0.11560545633396796, 0.14760818182220384, 0.13327277686086395, 0.16138851011712707, 0.14653218068903492, 0.17313409356340287, 0.17793982439944822, 0.16031984810627278, 0.152290603145957, 0.19306584742040406, 0.14464855434433108, 0.23146686264343802, 0.13756529007467533, 0.09099209320641334, 0.1390880583635261, 0.15791951077840022, 0.2511288156552661, 0.03655959266207872, 0.07128700944444827, 0.17312493115182848, 0.14781782944356242, 0.17653172415110374, 0.14974804925582103, 0.11030215905198168, 0.18433619891443562, 0.16182645193992123, 0.1525838462816131, 0.15745342288526798, 0.1748711213229164], [0.0375586326023744, 0.039627916525088014, 0.030538164559871923, 0.009347801979240632, 0.03604996799220962, 0.014247281867409907, 0.03261986676783812, 0.05306506424301094, 0.056165728507743734, 0.06164010471454071, 0.018726657332491972, 0.04079677517555895, 0.023937305856135585, 0.024724168169702736, 0.048194055054937644, 0.028813294615716706, 0.017292002561472116, 0.032041432080610145, 0.05792473532980489, 0.09651102125644685, 0.038086321625498035, 0.1036224392573199, 0.06110089755947552, 0.003611634855323862, 0.02189420298823426, 0.015646295355362518, 0.019831149275564862, 0.029681389062334935, 0.09596869229309021, 0.04937989404425026, 0.04062061325737065, 0.030554064714740363, 0.0360275560899848, 0.06018590512535265, 0.0034886391996781555, 0.08130097371195594, 0.051511897585324706, 0.04365647414458856, 0.03911334292722806, 0.10463224273295173, 0.010682498555510275, 0.014627170504912015, 0.04558588956452666, 0.02505905009926327, 0.01627398662329201, 0.04538135558006264, 0.09976537808054879, 0.01118693202208247, 0.057157341225613514, 0.037197548550583666, 0.05058997971636634, 0.0282841787538341, 0.07044128668043884, 0.05577510410559274, 0.06667077045647368, 0.04423693130393663, 0.00664048029237517, 0.046321161602052956, 0.05164099872232445, 0.030832267629223007, 0.04625913529326359, 0.05285566176978811, 0.04678260700236406, 0.030199176399037245, 0.0893082932358788, 0.06884165679014499, 0.033572374527613004, 0.026121968365905267, 0.008050558483979155, 0.03157605090358805, 0.03765074701438989, 0.01876396964484405, 0.04509029962543038, 0.0439180510358945, 0.04716303477424288, 0.0597768180042265, 0.06427580340495033, 0.06184966806622763, 0.03010843328440622, 0.055449279250517014, 0.046238508375902335, 0.05873155614901936, 0.03565251774665329, 0.03141804143876559, 0.03162174421783177, 0.06348368764344244, 0.04886695987454826, 0.04597539164786858, 0.057472214853811654, 0.054887277149264856, 0.015078002714642115, 0.11344236111448658, 0.050485730471630255, 0.02536630498305444, 0.039012514265073885, 0.003480966350311534, 0.06974727230807466, 0.0131850061570144, 0.06143538686897486, 0.08887866346706307, 0.026719968938719363, 0.03473801560880196, 0.07922240863403968, 0.033301922507704265, 0.059951899738441554, 0.04315160688072924, 0.03860693582664094, 0.016462990090311054, 0.0636994333246783, 0.029104245233259378, 0.022874058171686147, 0.024219682034585747, 0.027500304183171644, 0.09244378385764938, 0.03937042288241848, 0.10171295744517159, 0.04716072501915117, 0.05257689769590094, 0.04262060835777272, 0.01044110999622893, 0.007542547386800571, 0.026494108981663184, 0.04507200544579856, 0.011422176556211087, 0.013817705724748873, 0.015736368143059794, 0.041137155701196006, 0.06658139097834788, 0.0184596890974189, 0.060922437377514384, 0.03720956080923638, 0.056764127446278456, 0.024888595536110864, 0.01742800806588944, 0.06599696548355204, 0.027040777833110867, 0.02454500701729088, 0.04859689472904129, 0.03207208900412004, 0.031208148669271223, 0.05219543953576396, 0.027161670338001945, 0.020111491490576058, 0.023843827807614883, 0.029686613781978528, 0.015862943105129226, 0.010468376980673884, 0.10525329489140742, 0.033481907204634724, 0.029957613554753126, 0.07344525532736894, 0.0871514416329803, 0.012429997779338831, 0.02156594388877913, 0.09892454295749627, 0.020077594015146458, 0.01198683219451097, 0.02331549335541504, 0.06644757073973456, 0.08250925524701035, 0.053949692782254956, 0.019093331910910148, 0.05104316285841408, 0.03487011598002526, 0.034875440291099014, 0.008106213814068225, 0.026454103870257258, 0.01793517167830179, 0.0043403745568808055, 0.004513460632053114, 0.08999897512577235, 0.04067225907478602, 0.042945452620305365, 0.07906061086443164, 0.09187821944754931, 0.0343688378380912, 0.11461146491309328, 0.04814034463056634, 0.014078599840192305, 0.04782926696803301, 0.04980172120755719, 0.03575581704236327, 0.028153217938398162, 0.028018089604654142, 0.03899546880875865, 0.0632415157592585, 0.021856086283561685, 0.021818934849673705, 0.011796815576212061, 0.0574389704683375, 0.018999495716284842, 0.04556871004282467, 0.039850415271376415, 0.03629073027461287, 0.030755406027779948, 0.07470442042235406, 0.03141681952852636, 0.11593011673539878, 0.06916465478078013, 0.05964294413945848, 0.04312607317021297, 0.05280420747435382, 0.029854040382610216, 0.047393190569334456, 0.06524195519065665, 0.011134683868036637, 0.02671140982138534, 0.011542871793461664, 0.05035919955961647, 0.03244291194864819, 0.026888563823435577, 0.07693322300310097, 0.04207099389825617, 0.007139315571440685, 0.028877808795040174, 0.03796321129606616, 0.02878017280431044, 0.020594944681731925, 0.034285904989848216, 0.04051068730111565, 0.02292768241116597, 0.033072532800536965, 0.013709304283463187, 0.05151315779996015, 0.01818184624426067, 0.013577022923967771, 0.006789351764675831, 0.01624512426074474, 0.021751026900845672, 0.03263989996705805, 0.024318126248075597, 0.009930210747575809, 0.034846221697666956, 0.10064556714027159, 0.03126684058037016, 0.029103883256715153, 0.024346031000717513, 0.04040217477708094, 0.01951190320053889, 0.07191291860034389, 0.04804822638811124, 0.02081567376491524, 0.030145067608945315, 0.0303263106052914, 0.03687840015176804, 0.04446730926452626, 0.04349628132918189, 0.06362431074282335, 0.032118525423650304, 0.03288200290332879, 0.04773623325050839, 0.013174225384699962, 0.014398530606300601, 0.026243726550150785, 0.018444296475800297, 0.060307992727405606, 0.04027808002466637, 0.006099523105207952, 0.09213821436729162, 0.022146383811148907, 0.032357730632347446, 0.05608365750841557, 0.02868873063444851, 0.022153638663791844, 0.022198247963622696, 0.018949242263671853, 0.050146797852170084, 0.10357615222493488, 0.019424645785963344, 0.041798630488976356, 0.040972745571766174, 0.06080630227863308, 0.10143824597640384, 0.04619054744140275, 0.05032116712461557, 0.040730045086914496, 0.11719565568191391, 0.04801936785600359, 0.05554344677816957, 0.040081835111543056, 0.008549563259997917, 0.05554393324400148, 0.030094388977534352, 0.0741919382445274, 0.023827196038778753, 0.04960832231107259, 0.02141396736636037, 0.043688657498287584, 0.02677139833629612, 0.06261220900341868, 0.007112981299043543, 0.06218698807060719, 0.04498058434335455, 0.005068313217751923, 0.04763907797995114, 0.062126103232825, 0.011808537679063457, 0.045949972850540956, 0.026939179252592788, 0.06434893415820214, 0.014631699999764323, 0.051716523500339645, 0.06028614389980513, 0.005247058288659901, 0.0337839373687823, 0.06972320948637302, 0.028696337887536616, 0.041729751523704305, 0.03386151909287419, 0.015846273989506787, 0.0720358220860362, 0.025677103023495407, 0.03306432799886792, 0.04168081382710127, 0.030141675754660563, 0.02577467581197139, 0.021126280283375133, 0.10216050601053624, 0.04933295966756921, 0.07152498699724674, 0.003213992369579031, 0.0050051210189027895, 0.018165856074061126, 0.0476125292029352, 0.030947640470619646, 0.06739905194169091, 0.09891472937118623, 0.07629051353902587, 0.07499512780698077, 0.022632999030212243, 0.04537871640716349, 0.10310869303441818, 0.03484963461936962, 0.06331177368279427, 0.09374726713905412, 0.040432247558548566, 0.02527805356939714, 0.017743337516402526, 0.09306755562823626, 0.047335473505119165, 0.009013749339858131, 0.048199088252600164, 0.025192571563586116, 0.05021659229251166, 0.029120945950008692, 0.07444852407300666, 0.07697092218985481, 0.016725495863225193, 0.06824304334699147, 0.026281247621462233, 0.04496204118514734, 0.045442370652791955, 0.17635664241688867, 0.1198929516718753, 0.17564545235326215, 0.16182516491220844, 0.15446201808029605, 0.12196789315390973, 0.13211682679191714, 0.21077482780862242, 0.13680540746258152, 0.12886620847688568, 0.13128168370214202, 0.12703679051370392, 0.132599814584659, 0.14315839075753767, 0.08678218725347712, 0.13405196488864962, 0.14668751267656205, 0.08663679908720717, 0.17647451270491848, 0.18832652108563533, 0.21093714651801895, 0.20837767740651486, 0.10833037130895162, 0.12557367749151685, 0.09536572747052678, 0.16412036433335275, 0.17683301120996478, 0.13028177042161265, 0.16464249921902535, 0.117323852835163, 0.10710073124256828, 0.0987521272092577, 0.13725359954180258, 0.16244724362848267, 0.09389369718490109, 0.22390575869189155, 0.1846318935314494, 0.10429184688555618, 0.16185870424153345, 0.20018625163262893, 0.10174023783615521, 0.13079504933088057, 0.14707283958071662, 0.1751949160449928, 0.07630839403117858, 0.1036198958454113, 0.1547407361889078, 0.13099896661456556, 0.15114781446754932, 0.15438821316967088, 0.14929731376469135, 0.10860094590292824, 0.10867208482757693, 0.14904102671050257, 0.1399711432356027, 0.14067959070446032, 0.23490023889368583, 0.26170081368857817, 0.16369221311423088, 0.12348021200347332, 0.10381210730561327, 0.1558381264969226, 0.07230527053076415, 0.2150782041492001, 0.14903200219475454, 0.09252251471362768, 0.15854854557302692, 0.10153138694623787, 0.13796390094343694, 0.16865238727581117, 0.16997214226472765, 0.18567309895109746, 0.139248967471142, 0.12339758175996043, 0.08557061154034831, 0.11967228770616556, 0.11498042051830601, 0.11927948378386999, 0.11238130635672039, 0.291680101785929, 0.10145865455870667, 0.11382605625136245, 0.3273286856710911, 0.13006564169641466, 0.16889224940490338, 0.2015270740394631, 0.10373314662325768, 0.09030659773176716, 0.12524916264679165, 0.14673740032219118, 0.09457732340501201, 0.29993071551284484, 0.25066827423870564, 0.1959718181000602, 0.129457337241019, 0.179079303578023, 0.24360860547711774, 0.136295958992935, 0.11528526222513569, 0.28184359412520166, 0.20787366816113073, 0.11772191212061914, 0.13033571833324048, 0.1798600544251742, 0.11497700376616371, 0.2093500421652871, 0.1108652106936901, 0.16002977657462322, 0.13398145415609883, 0.18155739883021002, 0.10417161704671961, 0.09007045878998696, 0.14795938717021098, 0.18074753664193616, 0.1773268161641975, 0.19376238988291836, 0.19122593405265964, 0.12710767662933758, 0.12065766829877131, 0.16015357638318695, 0.10925535352960711, 0.10886452611415617, 0.10917111450145323, 0.08964827539579523, 0.11654075009808426, 0.1730364020312986, 0.2670718254821916, 0.18526354834677713, 0.13494160747335804, 0.16772188156122164, 0.1445026605600311, 0.1154209976835597, 0.13864861500840034, 0.16995331182354884, 0.21286057879126843, 0.08985764722550109, 0.1371540234334046, 0.13184124964379496, 0.09873629983274207, 0.10627576946130685, 0.10843930135090506, 0.2078397457878436, 0.2207027297587164, 0.19573653717675518, 0.10725776394528728, 0.10360527122693677, 0.06969914666467136, 0.15780232996950228, 0.1100719496307354, 0.09084753241510161, 0.2046596688488799, 0.17872661201944276, 0.1393358265199969, 0.09865622066201703, 0.16916479284484542, 0.19792869777208377, 0.2823130834487177, 0.14582001003286532, 0.16860164161170685, 0.22521114187134852, 0.13593131646273598, 0.12065424388574979, 0.29238315599579967, 0.10729365516453983, 0.16177395959534954, 0.09448631982048673, 0.1120054482993099, 0.10628170664272002, 0.12912916049601572, 0.1589991431683302, 0.19354679741926734, 0.10898442653518532, 0.143011118014974, 0.14890679278441016, 0.2181475354178298, 0.16468369942759314], [0.020007366735127666, 0.029309047348496896, 0.0457663377446513, 0.010158570066484953, 0.051983064641394926, 0.03112448420706055, 0.04690982739350969, 0.033635592103124626, 0.0251533382857639, 0.06219085681462481, 0.06731482823529551, 0.03385650121697015, 0.012604260757084818, 0.17889951806395285, 0.07970514361776652, 0.018102238217609066, 0.05845572619188217, 0.013696272170261271, 0.03823623737140048, 0.012616593815055827, 0.062264979651738564, 0.00869909021627879, 0.028438049428645643, 0.0385975857235251, 0.017888074507936835, 0.02424617718544699, 0.08964190920514446, 0.05622851707401776, 0.01449445247529976, 0.028141692145577366, 0.0758029981666515, 0.021045674427202152, 0.0641669652935478, 0.003339341351567137, 0.028796913740675778, 0.06266807213485723, 0.027886180755411907, 0.09849971655996577, 0.01753240669777076, 0.02569686234628241, 0.04784081957393116, 0.03713177607184456, 0.05362590572105781, 0.038866026762632594, 0.08644808864881916, 0.02073658093239271, 0.11470744040824714, 0.046744007662299185, 0.10069087358011354, 0.03773775161995042, 0.08435614767574495, 0.02804487969936623, 0.03500302840444831, 0.06555698586687927, 0.01715369496284233, 0.08027846849853955, 0.06565584951350767, 0.05092841437867573, 0.06083865800211507, 0.04683871145149873, 0.0278483800620081, 0.03534708998256153, 0.06419603449983463, 0.0648739954997455, 0.01957834792143155, 0.042209552390681165, 0.09568543894396675, 0.034661797521215294, 0.07195769643951809, 0.046163347489651174, 0.06041793017497948, 0.033053487854739355, 0.054352551608556704, 0.024151197604594693, 0.0410049480776633, 0.04405713429854762, 0.02711043820806569, 0.0431523691382139, 0.03764247709524728, 0.025525235668605855, 0.02571070172463454, 0.038200024395219745, 0.08014946695296996, 0.04587090491587597, 0.009082669482356118, 0.04776221129202074, 0.031956183731616024, 0.010819920364977613, 0.038932228250609296, 0.03720280008330461, 0.04154977065721347, 0.03025616951016409, 0.053883449159442424, 0.0013771385654822114, 0.02354106985993924, 0.030511899235387965, 0.015425323039263248, 0.029181374965475935, 0.02651174241046031, 0.011692591229333513, 0.03700651303534547, 0.029688084670793147, 0.03328257495717656, 0.003912981525401495, 0.08056538374794107, 0.05157170223913366, 0.02096050460222027, 0.033397342589113026, 0.05655334984523155, 0.06889664658134984, 0.03910091315065661, 0.044778559296842546, 0.016356896488897262, 0.04347316462606673, 0.04250541171659866, 0.10210066688277068, 0.07181643748716002, 0.020223713795384093, 0.014213872773032037, 0.022091863248797677, 0.04009268674699049, 0.029209162889709397, 0.04696937157742439, 0.04557375856224568, 0.05389267668849038, 0.056470010970388694, 0.05836070447619404, 0.024874507179183346, 0.0033069645606672335, 0.07205979297718695, 0.03498399494996956, 0.0761978475437049, 0.044938618046862465, 0.0037843697270633836, 0.036880349845535336, 0.06331673793254361, 0.045780678910593835, 0.02880746085617331, 0.036644440730132406, 0.08272219704644335, 0.020304198992709, 0.03232772296835338, 0.05497920386973889, 0.017335633183979703, 0.025028391260533564, 0.03479230059911648, 0.05407750306110229, 0.033034147965090896, 0.042356733202693925, 0.05524625828970344, 0.0036216911957449014, 0.060988432021751526, 0.0857414568083421, 0.042359219158008214, 0.023374805797732646, 0.03881813860648582, 0.01808143701524504, 0.006730246644902735, 0.041345129420440045, 0.018043703354534604, 0.10560020248615935, 0.0443115750808389, 0.048665666442003944, 0.04954236980167128, 0.0327978328230881, 0.09551973412594489, 0.036425841371378595, 0.03490960015164268, 0.04238045128482965, 0.030334298987121835, 0.07712615458595176, 0.12074644256743694, 0.013247806214607291, 0.014824094363458216, 0.04531952079325434, 0.04531231190588686, 0.027377557745503805, 0.041206341101637775, 0.011223961839512473, 0.00605121982516721, 0.0215015618596226, 0.031191963146650986, 0.0879438216948221, 0.00461725166044949, 0.04333309310999128, 0.04053632443350169, 0.13265031510062758, 0.006220489824866697, 0.027499520858269066, 0.05327088142474813, 0.042016505894641724, 0.03936636644685942, 0.10781721497375159, 0.05348037199808225, 0.02582561874371623, 0.06873701684056752, 0.08017752875363635, 0.03689468718103824, 0.04128040265171759, 0.040794802499153925, 0.02876135768489011, 0.027027275533445423, 0.03519632387906313, 0.07281350092061105, 0.08562087456906035, 0.02365592367676718, 0.05098572541629115, 0.04343333188444377, 0.007061131989523288, 0.012579050718716556, 0.039694995183738015, 0.04951368746978622, 0.039462740307733904, 0.02449159536721005, 0.058665128665104996, 0.015213052524373898, 0.03811915998437232, 0.03204623162145576, 0.03925588124641969, 0.03808503842822487, 0.10133934402537924, 0.042322040911042885, 0.12069404981429539, 0.004427498384874555, 0.06045091792099899, 0.03331868451148753, 0.029222015929859013, 0.032029906287789345, 0.015140582521956776, 0.03644855970877313, 0.01775441514778762, 0.03173873158952883, 0.06087432322542995, 0.11185163316587288, 0.06397354341442547, 0.005375032318801049, 0.021369296779495575, 0.02376027251293342, 0.06090751781518902, 0.10320255412690102, 0.016123258824189825, 0.05203792419765265, 0.05171706359232626, 0.052217659916007714, 0.023558132553232775, 0.028108445844883402, 0.057076430849490635, 0.06875776250155703, 0.04280913110461928, 0.05325371339436501, 0.03065522854036141, 0.033161322390961076, 0.027658457289479917, 0.02688319546230618, 0.025548670298209595, 0.04623363988714353, 0.02370355710867913, 0.06838348258527056, 0.05347789753408683, 0.025122215963840008, 0.018761763311622125, 0.04198982688267866, 0.0756449465669932, 0.019232938028571588, 0.09405945562907765, 0.04370651500780256, 0.013389329467299245, 0.03556121155739792, 0.005821075042589538, 0.02683200355198595, 0.050663110469618154, 0.08127845072698209, 0.023159479549635324, 0.014951446904770791, 0.049565084308626196, 0.03343855811943931, 0.09280119451784319, 0.05680082305785149, 0.05793730683264233, 0.041303611285383665, 0.026731655610004262, 0.04524871894729234, 0.04945856361319462, 0.08748353308727665, 0.0188284799937279, 0.02177719454911928, 0.03635771700271195, 0.04857997950767318, 0.05815921569122903, 0.059184394551501165, 0.043153732774719115, 0.03996441298494897, 0.07125533936965851, 0.026244465824997714, 0.011176367669606642, 0.037299725527484576, 0.03357856451804119, 0.026427417197414947, 0.031343449372798204, 0.009225250893993484, 0.03910398133279335, 0.07989310328998873, 0.08277719449852744, 0.012998447468083714, 0.05991009048997395, 0.005298193221190764, 0.013799041907693592, 0.011032662023940395, 0.01941465599943073, 0.024561761360194896, 0.06117646064188692, 0.05874994225920208, 0.02662414283071074, 0.023001661606793924, 0.04499786728692632, 0.007143382540708709, 0.047956717185555935, 0.06126077627883323, 0.06220130242347237, 0.018234085779817357, 0.03631663553777241, 0.059600878251536246, 0.0484337448142469, 0.012761712892942373, 0.03686236210107323, 0.05613146139489067, 0.05918053729880241, 0.06618392158059344, 0.09911873858542213, 0.009636914943374935, 0.0224376427790811, 0.02917404158882076, 0.042157580985897974, 0.054033935640848456, 0.03822291510239725, 0.07284961430536163, 0.022211991580984285, 0.07833466594738346, 0.07949115993875651, 0.08178904066763579, 0.04966615428847652, 0.06621198338125983, 0.017779117652906046, 0.04551189313192041, 0.029323819438896837, 0.024722226136814685, 0.020597844324525327, 0.050475790480812716, 0.03522484916292372, 0.06760730528302732, 0.06830259902222503, 0.045852629888442256, 0.11023463606233559, 0.18942899821746736, 0.21963373066917544, 0.12420555171106132, 0.12782658885924086, 0.131460044292673, 0.14789083762274635, 0.1522001281620995, 0.18260050414791032, 0.10176099881890321, 0.28730408498837107, 0.07655821530328644, 0.16239885751518512, 0.21026328025806337, 0.15590362701444857, 0.08914826512937585, 0.17439230104848263, 0.1297608765983774, 0.14332377381863134, 0.09016416666488494, 0.16706646269848272, 0.18700010113177762, 0.08997228462249042, 0.14806994897944314, 0.11763638606475246, 0.09965550575044849, 0.16841284690364716, 0.2038503582439115, 0.13294205670395207, 0.10631062646186161, 0.1785486651163909, 0.20734106851441247, 0.18562468219428294, 0.15058699214170057, 0.13234777165757072, 0.10334801124108416, 0.12275529364424369, 0.17290431315139418, 0.2595386684181229, 0.13083252635213638, 0.13577348702857572, 0.17815549347189166, 0.16238200358085095, 0.11746594682335855, 0.29716057222216363, 0.20570573126596792, 0.28949714956745026, 0.09626368977009289, 0.15464332044845627, 0.11574691446918635, 0.151798713411535, 0.0956866646846456, 0.16085172763034222, 0.17669704592516347, 0.12460508188533208, 0.19720751792192462, 0.15023643030754982, 0.14726609292049564, 0.15023325870354332, 0.06071786891909377, 0.1091712907016758, 0.10586136185954656, 0.13550759323181646, 0.16107897995220077, 0.11704934821013482, 0.09417597760236072, 0.1932255154655826, 0.13189818529832747, 0.17559519698542936, 0.16662104385754756, 0.23085632121130345, 0.09439741531687398, 0.19144547952999993, 0.12753199740883805, 0.19668192031883425, 0.09861369512134022, 0.11837138614106564, 0.1797771024247331, 0.1768507691280496, 0.20113321291583203, 0.10095618515005035, 0.09783705050546317, 0.16458378624050848, 0.06941606185489124, 0.18330458491559953, 0.12179243603661177, 0.19784736987804213, 0.12619862903750714, 0.1416192128653488, 0.08214920158347777, 0.07597267898100038, 0.09919433614179012, 0.10220352184748459, 0.09732885842001247, 0.08001488828731161, 0.12297166751757746, 0.0975571985867235, 0.08899113283522668, 0.16236260623460816, 0.08259243707382873, 0.23723457008600238, 0.1260841678407404, 0.17775950262383108, 0.11194629865067621, 0.19679255873685886, 0.1417738094084686, 0.1317196102031777, 0.18994166425639586, 0.19286418243521647, 0.11788149589612601, 0.11218812196485459, 0.1550308536858328, 0.08865744791804783, 0.18921072444608136, 0.16075608921387505, 0.1395674915082993, 0.1909858574189486, 0.10012014573740383, 0.09698650138753076, 0.1259515350384097, 0.1552022735197698, 0.1677052880967817, 0.12907279174654715, 0.14834849854871152, 0.23747412577992488, 0.2450894381129934, 0.17748236265634337, 0.10469505428186349, 0.1254946708438858, 0.12070069945747815, 0.06588303288745304, 0.12901596334432403, 0.1374735433848635, 0.12503056711847746, 0.14407536735938442, 0.10502754410188045, 0.09363645252080695, 0.16737381717370403, 0.18522049420543257, 0.22019272970576442, 0.1381515465196102, 0.1345340946629163, 0.23796437608618892, 0.10531950787070299, 0.12890166302602138, 0.10240839674107491, 0.24695426466003542, 0.0987685214908373, 0.1312868931000271, 0.1173703850156838, 0.1429682017694558, 0.22188411394674934, 0.1777662135540478, 0.09288945550759954, 0.20274484740389934, 0.09768577878393474, 0.11123404372483493, 0.25206477591587656, 0.16503173317159378, 0.10836497550049137, 0.24918065406382087, 0.13532138790094084, 0.17571777105331424, 0.14376410583574928, 0.16632210102773484, 0.2997109095656103, 0.16787764255798635, 0.09374720585202018, 0.13978078570817748, 0.11760151374243921, 0.239841919692774, 0.23350977398935827, 0.1656914880919841, 0.12579930570697592, 0.19678820735744892, 0.14684324302980978], [0.018875914242779537, 0.06694888335562522, 0.027728131070973414, 0.05660162104534046, 0.01407891393624126, 0.03321933439902721, 0.02648093609980518, 0.035367762865198236, 0.02773172210811848, 0.019697493745855266, 0.04602763118342527, 0.06337198053276347, 0.04484623550407348, 0.02558979389798497, 0.10451686989155509, 0.01453579153730384, 0.013289763892610228, 0.08680412035074928, 0.01825771576184179, 0.049840274582346605, 0.02204874207475974, 0.023598424947610306, 0.03417694047393818, 0.035587767995293104, 0.025115008991692337, 0.008952315791600175, 0.06788144218585185, 0.07406019410418888, 0.03284505831318037, 0.026332805338766307, 0.03439648212083886, 0.021733249830562743, 0.09039040775068345, 0.0618894127077393, 0.05022902206908311, 0.014166010472352707, 0.02982706834201611, 0.04765055014661724, 0.041439090104353045, 0.07600436437754862, 0.06506259102494487, 0.040745263423530326, 0.1007270176083811, 0.05017009841638708, 0.09292299483692454, 0.027024190114330382, 0.02398760718924384, 0.005454762919520539, 0.05986586806454486, 0.04634597902036002, 0.03921324462299386, 0.03655565497014792, 0.020786462832362424, 0.09948957110604933, 0.030043354115238594, 0.06818101320776247, 0.019147762457930276, 0.038402758073061705, 0.03937793820495567, 0.09832867210911167, 0.046054880930891925, 0.051880765090426134, 0.011010704028810705, 0.07290259694620486, 0.02284401603373549, 0.02929449359315538, 0.042370116758731105, 0.05910973162240079, 0.006567677999320891, 0.0018415490851639922, 0.059566584325605826, 0.10189767656547409, 0.03368615773656676, 0.05905300664204744, 0.05246412955344685, 0.09158684556642849, 0.051125563275549686, 0.02267756811042707, 0.038241703408740224, 0.004763893338085543, 0.05617873668069801, 0.012771838660081549, 0.0650158136962883, 0.012087199288690764, 0.043162266994195606, 0.03643703391595233, 0.10291619046080498, 0.049855086892362566, 0.021442193875930483, 0.009183592947890923, 0.01315806380232736, 0.03040920514913817, 0.035292073378279325, 0.022594593127348253, 0.010188511655395551, 0.019071341357043674, 0.02429597481574503, 0.04078829841267678, 0.038723595695750374, 0.14528145022209615, 0.021661522933432174, 0.0318839282338177, 0.02271468890079808, 0.02676685735012495, 0.05719529322138237, 0.048592493553916295, 0.02861893810932675, 0.03141373410941132, 0.035097977341783625, 0.05589826423073969, 0.011680451608563383, 0.01434491211248021, 0.044886248276358655, 0.01062163957319553, 0.017921661717757102, 0.04899710289112503, 0.013217748754898147, 0.03314958209352147, 0.05313977313738677, 0.08102814681948194, 0.03542254581266353, 0.048075564235689185, 0.019451790196340413, 0.02673894302138398, 0.12803442851309815, 0.05781965487967095, 0.021031229839389844, 0.02855964290398744, 0.03889634086179637, 0.036004167425656514, 0.045433867076832446, 0.07937766401277435, 0.03959841830956359, 0.02197190728639403, 0.10866912006730996, 0.07255503817671731, 0.018885254769796328, 0.04382893585810258, 0.02581201493740082, 0.03639474586253205, 0.03866392893776779, 0.012303174796303915, 0.03167768778850234, 0.059988361693197684, 0.04960898880756671, 0.017598571796571056, 0.022173880621971145, 0.04082622742580791, 0.010977811086171818, 0.0945969199341151, 0.046831471920614286, 0.02887552968346544, 0.07308826601553349, 0.004198962865742825, 0.02506544693343101, 0.012969544885920422, 0.048948038790014484, 0.03279583333360572, 0.030591917119079062, 0.11630001462875836, 0.04405280207133582, 0.04488577713228522, 0.006769367882366022, 0.006814095925825138, 0.041182393193124764, 0.028632178023878126, 0.07027989493743067, 0.051015487932149446, 0.01690445591755692, 0.022158610574420423, 0.0027498599158735167, 0.06394911670095979, 0.01567473253911181, 0.04156015880946671, 0.05422012948040521, 0.03995995435322966, 0.07910103732419592, 0.04555288649674866, 0.06801483341522756, 0.024293996393680576, 0.009983465349632166, 0.052474073374704014, 0.005831781121331358, 0.02961436977549907, 0.08279558060871017, 0.0482509064397985, 0.05751699652342547, 0.011020688069683891, 0.03610069067367623, 0.058120118394013376, 0.027150305423645243, 0.039254352901010744, 0.0464765012504593, 0.02827784129148049, 0.012831926766422488, 0.014486131802832168, 0.03922496576823535, 0.037923692650492155, 0.028762112281495528, 0.023097805641291123, 0.03626020550126991, 0.012130392283471602, 0.00686091921975716, 0.012579408864821158, 0.027724030585358703, 0.030974591443795833, 0.008122999758099117, 0.019360112454441768, 0.1147118377529325, 0.07870842492388141, 0.04267648298053011, 0.016114619267623753, 0.007103566557259089, 0.030790033201957424, 0.051780173915528485, 0.04579857855494465, 0.08360308324617725, 0.05955358381353079, 0.042680535585649555, 0.05232145333842886, 0.041690734665720694, 0.018467480211608836, 0.0973208834447207, 0.04713017343273086, 0.09891830700179262, 0.05386803930084552, 0.06148952630258376, 0.08503004457921752, 0.00442385180635498, 0.045387553231370066, 0.04354405457214002, 0.08487213087538559, 0.042334221709038944, 0.025431303712990017, 0.019000731033062743, 0.08110734498909405, 0.020717583867090366, 0.07273838599963535, 0.03958141115764457, 0.04036931726600855, 0.056535316135493986, 0.08153857588167153, 0.05505046153801584, 0.017407716311995062, 0.010735715810780325, 0.007977148108634978, 0.04969688590555903, 0.02086249705884726, 0.004394047155660848, 0.034795797790490815, 0.0201411544150042, 0.014407944869280103, 0.08115281996827933, 0.06855759138782179, 0.04752121152236097, 0.0628481870667348, 0.08213919647518667, 0.027663023173508626, 0.03872681709547197, 0.051497311271246404, 0.016357287193738645, 0.049934874949676376, 0.020741263644829876, 0.07104840369955187, 0.04593339853829915, 0.026926992708937298, 0.039588363405557415, 0.026641063797738285, 0.037168984962326866, 0.023700688109402696, 0.006260604582606785, 0.039695378227700154, 0.034845371340071006, 0.0048875068915226775, 0.05569372258539643, 0.04151384113356472, 0.06621839553718606, 0.0623015680110022, 0.008571233014546095, 0.03598729816956386, 0.0908389752129874, 0.0242462691159979, 0.025557252398181348, 0.04785340256808747, 0.05910899234755386, 0.11640521382252056, 0.02410691006169204, 0.044365507670708244, 0.0701938172982585, 0.04880075455613194, 0.021399112921508572, 0.026722085256610188, 0.019511939589715293, 0.058972697644945116, 0.04570896542000194, 0.07541288321297016, 0.040868051996034, 0.05481205880641938, 0.02027780917893735, 0.0398803539874573, 0.020893345504338225, 0.04188730899665145, 0.04487387978682115, 0.04659139145646365, 0.010221124975942075, 0.047180482426718365, 0.03644505102607993, 0.03072485252613983, 0.02240481208108606, 0.0023794415615303742, 0.020797383415723042, 0.03936527860200694, 0.02686127577157271, 0.026831199159665454, 0.029117506215228673, 0.035740813210366235, 0.031870083109806144, 0.08752541511409706, 0.04644291595585885, 0.06861132479483081, 0.01703956892954246, 0.058926644269377, 0.014059935065527118, 0.022445770971957716, 0.011776153227284312, 0.020144287714614503, 0.04428465092074006, 0.02459350229811765, 0.006096178173808562, 0.06062427595738442, 0.014465231009037986, 0.031092542171057676, 0.02812990971330193, 0.023696696791317196, 0.05402700254513372, 0.022405283225159493, 0.0056781345272376655, 0.024392681924866575, 0.024626528348533377, 0.02449501403457215, 0.06027221259090209, 0.050076490132919246, 0.03622093966471092, 0.03753411778879743, 0.03489762236694655, 0.025045178162174362, 0.02745913461812081, 0.08414932691882696, 0.08493619114761392, 0.041078454213998014, 0.006899057949457559, 0.016780424367396102, 0.1803406826671093, 0.1807875111098251, 0.1369353359745395, 0.15034244155451176, 0.12649095286765408, 0.18920032097206962, 0.10388717626131351, 0.20390367796344144, 0.15023223214572476, 0.1995572321597607, 0.1964937231593555, 0.1153893199478907, 0.11648145489274495, 0.13903666918556537, 0.1895574558406107, 0.11560672803992227, 0.10721426547294664, 0.20942418415459896, 0.10988665594448967, 0.09887013539311387, 0.06464931723331252, 0.124186453139109, 0.1214886362093591, 0.07764784514062828, 0.16565502230678836, 0.10802625738565, 0.1359594318895571, 0.18473808863951316, 0.1601025242839129, 0.12008889398026852, 0.14760893258836963, 0.1381769959604548, 0.2863753106324904, 0.22524506424463567, 0.1095560430398872, 0.12463183367564795, 0.15459851962664437, 0.16342063494507345, 0.09191423324086974, 0.1971098876768543, 0.15055657845110665, 0.1280321991972385, 0.19092653157009234, 0.16357599757611752, 0.17587636657539876, 0.0931814958852145, 0.15903965389776617, 0.12887103483080864, 0.21237399038528243, 0.1853688701146072, 0.11051678624484809, 0.16457566570851112, 0.11324248877504181, 0.1718537461373114, 0.10552691851532268, 0.12819156080724733, 0.19138572467190607, 0.1665228313856548, 0.12168136094847035, 0.23578658730031984, 0.10848781769914974, 0.1621373917066282, 0.06883191215174814, 0.15143600142290517, 0.14691340136191539, 0.12630807235836983, 0.14223713938507343, 0.1062939104233538, 0.1423879361320888, 0.07179301051843552, 0.15627822868766325, 0.13328019259197096, 0.14317339075909508, 0.13924368146446445, 0.2124699812021948, 0.1320851413953689, 0.1914003875947768, 0.14210102088268728, 0.10517061868261908, 0.18211866548705488, 0.1448959547785982, 0.13054548852866696, 0.28609430958186427, 0.10819208477773976, 0.11761408524527667, 0.07920362415813631, 0.13345337442813382, 0.19993474496708763, 0.11021500888971553, 0.13603887520730495, 0.10670920668710625, 0.09595498698012483, 0.11220219500002362, 0.17497795994483656, 0.11026065240824416, 0.10518558037978028, 0.15567386192419838, 0.12435811812118178, 0.12156489260134198, 0.26097894435928715, 0.14033128116880694, 0.17273485450254333, 0.1678312482732919, 0.13951878363807357, 0.1953750662505627, 0.17507191296787034, 0.11132539970980537, 0.23626666395894944, 0.13778158733921667, 0.1784827662331443, 0.08365022063615822, 0.12728968379838815, 0.18910832913412204, 0.1293909633832593, 0.18024435477151027, 0.08043524839224354, 0.18928224641469218, 0.2898483855589744, 0.1347239465723115, 0.20439533787148617, 0.15130492377906077, 0.12953754664669115, 0.15038272245757042, 0.093038298730408, 0.20752506751206615, 0.27077435906375613, 0.14894472945842052, 0.22938544771844344, 0.16684869454512674, 0.2085021054071765, 0.14698910617059277, 0.1273685678719513, 0.15113661426209635, 0.126573016206103, 0.13232532528138932, 0.1734093029893214, 0.1398935385288731, 0.10773980178900304, 0.07807427266192052, 0.12573821019501458, 0.10225675729734283, 0.17999140786067133, 0.10498359363766448, 0.14278875333407234, 0.1840842172743813, 0.11987852623626111, 0.09496222129992901, 0.14504688942143995, 0.13114292985729634, 0.15866591024302668, 0.1646785359949835, 0.1850282980669891, 0.13071773573756218, 0.10148459429582281, 0.21207489433788487, 0.12534771985825033, 0.1471762614504945, 0.06952605675905943, 0.1760294156209115, 0.24454366175397751, 0.10611099927055259, 0.10585927043951328, 0.11003354564309122, 0.10582976839354924, 0.19437726737270433, 0.14845708385109901, 0.1708351249896711, 0.1258139762907259, 0.10805143869572109, 0.120116863850384, 0.0971992899693789, 0.2520417166693557, 0.11600582154407618, 0.18661109700558648, 0.17882543736167494, 0.13241523336018288], [0.042224012300251954, 0.04018551745121518, 0.043129547378949584, 0.042310637692289974, 0.044651702797460946, 0.06971796178409169, 0.018239138129677986, 0.019886443586719614, 0.022226878584572868, 0.030041220560369473, 0.02733990452402542, 0.06136330182573969, 0.036532691484617616, 0.06314786917139446, 0.04545060609797797, 0.029241302193352775, 0.03398545679726428, 0.026665055756306937, 0.03203408146697668, 0.05635533526900315, 0.026314677783258023, 0.04979939996114662, 0.034759247735623396, 0.06983359509538259, 0.10814769764340694, 0.04963788564407057, 0.019241158151999116, 0.034667033732177756, 0.026461448738231298, 0.022446567703398968, 0.03707529240918737, 0.04687629189462431, 0.03338668630608628, 0.04829397590290155, 0.02560879479372694, 0.07592652984444173, 0.09193734611354529, 0.07531215031180652, 0.02431859547692922, 0.03217042213486087, 0.05830024481720983, 0.02930034267445726, 0.017913774842576637, 0.044984476070009896, 0.03288596740833694, 0.0564243751127393, 0.024378641448434324, 0.013691588500214201, 0.007086222326653379, 0.06172659987163159, 0.02950500114820898, 0.030626207214569857, 0.05035322407380708, 0.06571487658807347, 0.046670478543326746, 0.04070919983449482, 0.0049030857682678735, 0.09085223619495669, 0.00835313257055297, 0.013555060140788557, 0.07364579416330784, 0.018129600963044553, 0.010018384594830775, 0.041074064530191884, 0.07532076114007542, 0.059904919396485054, 0.06055510970914076, 0.07108987969977242, 0.031836289056246324, 0.06841001987096763, 0.01660738425749925, 0.007522055971240926, 0.015678409761148357, 0.03751724470226515, 0.030771859681173682, 0.020568416972133904, 0.015211946484933217, 0.07129161363287319, 0.10128404779900467, 0.014923932856970258, 0.03719767495509117, 0.06202363514251286, 0.04838081196911874, 0.03033024063634296, 0.04837291360261941, 0.018110649863017664, 0.04759420437978641, 0.029135212422378605, 0.10877631875055452, 0.07897923700511456, 0.013046998290284988, 0.03852926217199814, 0.028514658221073692, 0.056862052635199604, 0.053025852032606645, 0.0259455249104048, 0.06481286934426715, 0.03323831039691164, 0.03255153555543192, 0.013997619558546334, 0.05620623157630044, 0.007831021625128004, 0.028493223080952323, 0.0482216993376853, 0.02199236949485156, 0.051578807704631364, 0.019698217698943712, 0.03169582492010969, 0.029229182682390657, 0.015167387938427349, 0.1135073330313448, 0.036487745106100075, 0.05219771098645945, 0.05737369211630956, 0.024777476397913792, 0.05072914724869113, 0.02851055773545898, 0.0166408967737469, 0.04085598228078696, 0.027154153100244945, 0.09447806905354224, 0.03138614919847779, 0.023321014934129292, 0.040306291212477995, 0.04031014846517675, 0.009394593672045778, 0.061165455788854635, 0.07454971662692486, 0.021303166154651873, 0.028456341693057653, 0.058287818871078, 0.03154820169232065, 0.06757532877306785, 0.031458320426604444, 0.05308676368346619, 0.045477354057854226, 0.055463536146787874, 0.04474756720986578, 0.03510338209208942, 0.08996961863651391, 0.05965677968737099, 0.04414049232558858, 0.06453274163387476, 0.030201467001930844, 0.01596534990840742, 0.03507692907606402, 0.08337275891174233, 0.026957448534367066, 0.038948208844709786, 0.0764578577852057, 0.01001792015402668, 0.0722459523427871, 0.026022589525147796, 0.011748266669230597, 0.05434482944227996, 0.03134562123206354, 0.03567741177375278, 0.046119894982585986, 0.07154530364899866, 0.03153666057774136, 0.008756674172717237, 0.008951404146970281, 0.07470883308879792, 0.11062867338618926, 0.008452159968475181, 0.0683568916734188, 0.07941095819396359, 0.028279641598102548, 0.054320157580678506, 0.01757793721833056, 0.014262091304596155, 0.01802151553302763, 0.035353655356072614, 0.024911982285219337, 0.09097599003824497, 0.07159649364409909, 0.047963336185221715, 0.02746480749920011, 0.01120149343830323, 0.03341290183485516, 0.06339695499909502, 0.08030864470187696, 0.004215419391966275, 0.015130611887622266, 0.055864728731854316, 0.030230478751623345, 0.03274687648480458, 0.04938244128659849, 0.03784168293819793, 0.05495602971002941, 0.058136294340534564, 0.02640510680184009, 0.07281564596679903, 0.015149289111216224, 0.043895769368616805, 0.038762187374936, 0.02230986505897055, 0.04645088710071099, 0.06572077546509043, 0.04734085144234761, 0.08069463810252567, 0.03992007181589161, 0.04649107607321874, 0.04972037799175709, 0.029450243098601222, 0.04959561291240877, 0.016490908249491648, 0.024416643239918257, 0.05927609910647716, 0.016508938128789587, 0.04373629284541934, 0.020736958230695417, 0.06702544618277781, 0.04070784768930847, 0.0827419314713728, 0.0364249297267487, 0.01181531947241315, 0.0384458888231987, 0.08828024920676986, 0.10068001811422649, 0.1021722577992947, 0.020100777750954996, 0.04904456203803421, 0.016607698353548205, 0.03782846792150409, 0.0551319771235989, 0.011128363642661322, 0.030162367789495378, 0.008038842126787191, 0.008349285851563177, 0.022877201047395507, 0.07311591412872076, 0.04113935437353869, 0.05744303456477581, 0.005952192906049952, 0.033506816553492705, 0.0419178873961491, 0.0165167790386946, 0.02018185666642122, 0.03466678092316274, 0.031169729359868555, 0.05929631616679892, 0.043500858704529466, 0.05160203932093517, 0.047122753871184204, 0.05338360360192676, 0.027406571410416115, 0.021271023020568876, 0.10354287336550413, 0.03694728677791934, 0.02489696504668363, 0.04624117053143921, 0.04201241498512607, 0.01635874850645421, 0.012728490532496044, 0.018831680326031584, 0.06644729494808183, 0.04110045242874373, 0.03819329814324456, 0.03073394982024066, 0.024432100979010427, 0.08806366082881728, 0.04266812113083659, 0.03361509159027088, 0.06995226211485363, 0.07709706622746683, 0.09145350030232823, 0.09758827877381156, 0.028152344598164483, 0.06443455980549898, 0.07131527808885421, 0.03440010954716033, 0.040003793734696605, 0.040709364543398546, 0.04411863200666924, 0.052896647473737124, 0.02779139844220012, 0.03227726458722065, 0.05620441977835952, 0.012835829984396698, 0.02284798628440307, 0.06634820147507614, 0.05933973803034714, 0.054562356277939775, 0.04608887991297149, 0.033102092303095326, 0.08255346618112057, 0.0496484499965464, 0.05432558148318241, 0.04453161851532998, 0.03774541249919323, 0.02155848410761645, 0.02169874523045315, 0.03029495271133079, 0.06043936914554047, 0.08171096098639312, 0.05887756101606835, 0.04614932425019722, 0.04884294684856169, 0.03790529887943018, 0.0635800576738773, 0.03217832050136021, 0.05895054621261455, 0.014134823032955249, 0.055251800935835614, 0.04435976967215539, 0.026074867365100694, 0.046445558959197615, 0.05451358329024046, 0.03731785499821267, 0.02051550136398404, 0.010847810753470948, 0.03413089858968893, 0.016835165180025563, 0.04230886802918488, 0.06346452778445617, 0.0406562018718931, 0.02387801639645571, 0.01385105832014233, 0.020628874715898308, 0.05261073962995603, 0.10131804678108423, 0.03064909983696717, 0.04215186596998284, 0.056329154214190866, 0.09667567653401245, 0.033028601488519105, 0.0239542210775037, 0.03145962277607572, 0.011870389702850053, 0.005491535618690955, 0.00601551486104126, 0.0180734294812165, 0.0345069864734767, 0.08054020243786997, 0.011664553368914754, 0.03470128169283271, 0.021896131614583637, 0.030258912104933016, 0.04780616175623671, 0.0027140927071037193, 0.03814102030329166, 0.060061921455687096, 0.04373226322293763, 0.0336658870500903, 0.03577326852527838, 0.031046709045767788, 0.01854460036772634, 0.0354879352474405, 0.007169200182561913, 0.006838250678077701, 0.06362663581967354, 0.10099912437820628, 0.07201919031720008, 0.1212956126959574, 0.15470476069998357, 0.1246041932233399, 0.2289218879154613, 0.06152791879890908, 0.08782494017073224, 0.17110451214736508, 0.1268320075506645, 0.12205705812741673, 0.18151754693638894, 0.16585795899793027, 0.13390358897947496, 0.1878177008080867, 0.1295174904648335, 0.14268747651048247, 0.08697920208496433, 0.13891406447416352, 0.17222094740117752, 0.1198167795495641, 0.11309084167043049, 0.19783407059167663, 0.2215157635509968, 0.2188444149590308, 0.1125085382391849, 0.07001975446098274, 0.1413632782116052, 0.09736889417493537, 0.18290767476202982, 0.14413392712031642, 0.16826018090209655, 0.10630224545996998, 0.1281924877736357, 0.14246779313731578, 0.13783253218618133, 0.25411453608783985, 0.10757176040281212, 0.14033616880976385, 0.13292079010317404, 0.1044151793804861, 0.13836220537702884, 0.20812655378493572, 0.16805146790800557, 0.14237849792886165, 0.16761534937447117, 0.10820179111174039, 0.11031843842037263, 0.1436882631312455, 0.20759833616114434, 0.14332627126526448, 0.08450096893695094, 0.1520364611379562, 0.13365381367264256, 0.09751297999173404, 0.12619142015013965, 0.14055888589111068, 0.16879083468548714, 0.06385730872411402, 0.17278848065724298, 0.10289598106136245, 0.10995215646201566, 0.10845473036170007, 0.26410835224293894, 0.17405208140130968, 0.11400141377723026, 0.1758406515563688, 0.17686541672916184, 0.19823884080734946, 0.13969129131686303, 0.0930225326409263, 0.1395329102993973, 0.1480318590878479, 0.17773443622694862, 0.122622660841913, 0.09355296425881887, 0.08501774886803282, 0.11632630676631966, 0.15851552718349043, 0.2944318589664275, 0.13614900800729954, 0.2071551083316726, 0.1718172190650817, 0.11233308878276618, 0.11171096410121649, 0.15956658449384475, 0.1353001213001628, 0.12119831952957377, 0.17465364428297167, 0.22054163678999872, 0.17160819963582102, 0.2110763600156192, 0.09493441996915687, 0.22962719442382937, 0.09392224928183902, 0.11277270833811454, 0.13435078514439447, 0.08409200822033229, 0.09539506863802673, 0.1456087995921412, 0.16025915862091128, 0.04468367930742041, 0.1682089142982037, 0.07033307676113422, 0.09866646325756466, 0.16639386814448143, 0.18362718454051405, 0.17246603424991333, 0.15981913303896306, 0.1146354511260025, 0.19381316619053965, 0.2525528811759526, 0.20885980718078154, 0.10548444660080057, 0.15042954575150244, 0.12248584519951575, 0.2353689468075191, 0.10465945417602217, 0.18819522893717214, 0.18481083634880283, 0.18830415131824632, 0.16183619657831808, 0.12285397342977025, 0.09225424604430314, 0.167297713999306, 0.07408332229862291, 0.18765201131182332, 0.1732880159491493, 0.1537767371102687, 0.07780937477946281, 0.10233620827596995, 0.1751183685395987, 0.10374595561335165, 0.05147545478276668, 0.11121718212962152, 0.22062350094558733, 0.12325134323609453, 0.19194493821311384, 0.16636754536340315, 0.18027395640890445, 0.10484785051836122, 0.1437858780545573, 0.12579746709595765, 0.18509442677661297, 0.16711817363337164, 0.3017797146833712, 0.11414196026781875, 0.10774005459801805, 0.12702651727463932, 0.15346713033655, 0.08321433192900113, 0.11430764210320289, 0.13943716463062072, 0.08587321627043909, 0.08521630353624783, 0.07727552640942797, 0.18264948780978882, 0.146571496321309, 0.20944895943807018, 0.08692292526604668, 0.2081973709526562, 0.101930518754788, 0.14652102644885742, 0.1252142903244784, 0.12823008736895938, 0.13335389025028677, 0.214385170369379, 0.20620063938681157, 0.10100796503285248, 0.12244570219228346, 0.17143990544061508, 0.09050189652630398, 0.11743836765808445, 0.2011471710378124, 0.19146593407757823, 0.1874871185470012], [0.043542154674087806, 0.02543939743191004, 0.05768083974779133, 0.010449600165649768, 0.033024652305269436, 0.0399846606887877, 0.0037916066245205944, 0.020550975065317847, 0.02864317138559155, 0.02466638598801388, 0.015867203511598132, 0.02226616357332997, 0.03477613614391416, 0.06019731217454519, 0.053107991979847995, 0.009418576054515378, 0.0312154648089481, 0.043750266289158214, 0.10476642303288945, 0.03121620408379503, 0.03381431275498002, 0.03914296371682037, 0.043101830317849116, 0.04100810435991134, 0.014257151952704356, 0.024192342271787987, 0.07516085560764037, 0.08393334375033457, 0.029128867299145753, 0.018760487775228197, 0.047371663498662175, 0.027542199616530733, 0.047691999333760435, 0.007697323960582576, 0.10520801909508244, 0.029155785713585156, 0.04816114008727093, 0.07394056181393324, 0.02182783487613403, 0.0031174250715036668, 0.030188386050623753, 0.04532517069169591, 0.0625427324895657, 0.08470095618958436, 0.020277828331135457, 0.07766807752270853, 0.03768423654799981, 0.06559324480833546, 0.0030226453917191155, 0.08162173472585217, 0.03146342065696034, 0.0649838678298458, 0.03446307814409656, 0.023393936928421743, 0.035770656165456584, 0.026889617194331465, 0.025894850109433456, 0.08181051411215337, 0.020846552853923173, 0.04218291168311431, 0.031134506552329952, 0.04068799069031112, 0.08048065442351565, 0.013609981941690129, 0.028742000558263356, 0.04596838577380104, 0.015010380133565877, 0.06222841044467303, 0.02284418457307883, 0.031250775716598, 0.02897585272758959, 0.024774345013523297, 0.016581032748123812, 0.05623298719705594, 0.01700783948293857, 0.09974447154109517, 0.0733452731923711, 0.07183962696862799, 0.005717254807091048, 0.05908397574638648, 0.020267196945966254, 0.07938305727176129, 0.022984102871569417, 0.05929042878110082, 0.04621863988558612, 0.030977912434947588, 0.008006752618858892, 0.045750230746043306, 0.015961735888624626, 0.06374808756874935, 0.024965451391894492, 0.07094276783567283, 0.08868520328354451, 0.03318199144315816, 0.02313144456204628, 0.041817798008841854, 0.028308877428512902, 0.012418145441540308, 0.014497825177386405, 0.04393581278441895, 0.04201857433203728, 0.0297782072542055, 0.013126912752106307, 0.007222088020024522, 0.04754972531490269, 0.08936122991144659, 0.010678715038774236, 0.032093112371982105, 0.04853216029943959, 0.010181812216497717, 0.029893206627739054, 0.019775786016496922, 0.04258349522828095, 0.03871929794249516, 0.03780072021688666, 0.05552629789998455, 0.07473235198807332, 0.030420376626293988, 0.03648941517777501, 0.010114905927630683, 0.029133708974827203, 0.048449522395047455, 0.019964509861423604, 0.043908279584420305, 0.03191890206278092, 0.04927961696540156, 0.04165586617384707, 0.02576164657159919, 0.029461228799435402, 0.1199419353337538, 0.042534454109808134, 0.06521365590273373, 0.054941638748371796, 0.06601982554721256, 0.02847963842683502, 0.040309110416039344, 0.06385226403513262, 0.057893015459300055, 0.01684548246914581, 0.07702602689424831, 0.02866485933472793, 0.059402013317711895, 0.02262802137392423, 0.032652590213523756, 0.025981452518833742, 0.016989133531047453, 0.02507538500902874, 0.010420339437381876, 0.10700403562476558, 0.0405169424090174, 0.11868479271088878, 0.056524307452022075, 0.004575968139819922, 0.060502851021385966, 0.09271865620488122, 0.004339454293761764, 0.061420566898079655, 0.050328268759673646, 0.061870452031613364, 0.0496283516798529, 0.058104681722339124, 0.10381053682536849, 0.040412493981420994, 0.047882847157457185, 0.02411680408723412, 0.026231030558025645, 0.012921150154133719, 0.030546168263460842, 0.03531719723175611, 0.008140284616890694, 0.05491979758165056, 0.014270830452592384, 0.015566744785305234, 0.0441101782264248, 0.032960561389524135, 0.006241552454734883, 0.04408618052219672, 0.004257364621040442, 0.03436448262824166, 0.033873738195266456, 0.04445894358439311, 0.0910561228351247, 0.04672667875345196, 0.038507639340335326, 0.03556558974988518, 0.0007449618527560585, 0.03340424887175041, 0.009616740975498913, 0.03783753840252757, 0.03676174028265861, 0.06919948113781792, 0.030158443504103252, 0.064416166034437, 0.018433898747448, 0.031701214348657, 0.05036725497414028, 0.016598671922580372, 0.09012019321803125, 0.026869871278083133, 0.05830605176367587, 0.04356793353273984, 0.04631058958869788, 0.04184281077956961, 0.031318005677613045, 0.0197300371608787, 0.025896893648971474, 0.043167522357356165, 0.051242023961798805, 0.11287508832831537, 0.025678878432259928, 0.09343437384814025, 0.02255616041140691, 0.006253190766719561, 0.029260230310741934, 0.02784557426498542, 0.026636930753386794, 0.022060942024953907, 0.028762979876069773, 0.028476022491832415, 0.08144387209247198, 0.08735941918266397, 0.014285315260020717, 0.026770921446563258, 0.01908564230337018, 0.021111228570882833, 0.023129102248217792, 0.005507842278964217, 0.03402251247016173, 0.0358692018855964, 0.04327627619908702, 0.045217052702942205, 0.03133747388698882, 0.0177214982649011, 0.10460254916500662, 0.010364733903007883, 0.06751494572287606, 0.04220810448450427, 0.01628234847298553, 0.05887346627611307, 0.01935801528874905, 0.02094438036663398, 0.02304477895039224, 0.01432946299187719, 0.08435025645960724, 0.041973241079117984, 0.031138974760148316, 0.025734042508467555, 0.04868100735268766, 0.047899662787395145, 0.013505724078464895, 0.06167513408487844, 0.061480685647937565, 0.07289074556601625, 0.051275597765080394, 0.0050317387438319145, 0.058963998716564915, 0.008699501030928185, 0.050974843137326746, 0.030080585988358628, 0.03401048872019014, 0.03732341296610333, 0.013239151336282734, 0.046662894272876364, 0.03425386719285481, 0.034168486693693746, 0.042747924509908886, 0.027819816473751303, 0.053901115146976326, 0.03357245496684506, 0.013229507246925948, 0.0404335230949425, 0.014169598636668057, 0.030152305224609953, 0.03441988610692563, 0.029203564702202717, 0.026049239808813702, 0.013710191030235542, 0.015899136929111858, 0.038080388274524486, 0.03177077321696185, 0.03879466567248587, 0.05865864373082596, 0.010019005126049443, 0.09739799019429954, 0.052395809832359516, 0.045086951821201274, 0.05552691077032397, 0.08168797068778547, 0.01525908291730429, 0.08285451575272507, 0.027850852610783714, 0.07140501762830442, 0.050044421692408865, 0.037809595345489444, 0.032609631833169735, 0.023726579966023568, 0.026509555229436488, 0.0035373678979193496, 0.009248110957654014, 0.019142091492070787, 0.03268799113650476, 0.028920454994565057, 0.08475606089397784, 0.026794645274358413, 0.051400002783104304, 0.047295001080079425, 0.08216197226917551, 0.044977048847583995, 0.008945735096330605, 0.05195946147244784, 0.06023107749980785, 0.08883511136856773, 0.04352713168989267, 0.029989375560093793, 0.050877906201827916, 0.046009042059942606, 0.010189665575331498, 0.015316877547921914, 0.05059572537579844, 0.028754510774066853, 0.02586252119902882, 0.03133766157853027, 0.057909306319009875, 0.023779327034830086, 0.08525254715594553, 0.07124402425101689, 0.09669112852744519, 0.03186165614263906, 0.05806910076869592, 0.05585376601365786, 0.059647172944800514, 0.012816533187193977, 0.08789717460111265, 0.02793048745051267, 0.04577823509011538, 0.0471291775184293, 0.048469157228546764, 0.04826955685031511, 0.04574097257347838, 0.021889029979525555, 0.01918345066388288, 0.013991603853120921, 0.03488079141525011, 0.04926548647363821, 0.05895742568217459, 0.025914609432220462, 0.026198872102184162, 0.01061888357188793, 0.024426037393089746, 0.04061698583104918, 0.05699961904376265, 0.03704544945409702, 0.1808256316449373, 0.10510816719503173, 0.1377480020446162, 0.11372208279827911, 0.13115815968523103, 0.22215210682442113, 0.07605795988873129, 0.1138733315371698, 0.12056975204858089, 0.08256080530343518, 0.14746645555621193, 0.13043192365477163, 0.1687883219170955, 0.10295144582708037, 0.15505849413814085, 0.047952526684610114, 0.1114486785785806, 0.16938685109057736, 0.14660433084974367, 0.164999526835257, 0.1594584435224533, 0.12110444311533244, 0.17125586047768596, 0.16276789739006953, 0.0812899420458463, 0.18134877776666997, 0.15008776328496395, 0.16134157957088563, 0.11439686070286459, 0.09496750730660655, 0.153172722747249, 0.1338938749845951, 0.18513990175579825, 0.09674139155615723, 0.24101196577952755, 0.09219587780535222, 0.1085805909467801, 0.14962579694486436, 0.1530367727842062, 0.15813865789001988, 0.1711538175661718, 0.16078873988120787, 0.23076644377602687, 0.1772967701958072, 0.19828583264062483, 0.17552462496584462, 0.10974011098545407, 0.25753556300074826, 0.0749618259649123, 0.15817660988578874, 0.10532474025122582, 0.2085806753846907, 0.10506433930488364, 0.09077659267331324, 0.10904203634709121, 0.11459769831309397, 0.09561051554497212, 0.2335229507016559, 0.14560270153226393, 0.18066044776670395, 0.17734449747348988, 0.09075726427498365, 0.25452699782627247, 0.17349383313088648, 0.15556588949215028, 0.18200500868260863, 0.11417084944344337, 0.14396385560112615, 0.2049980498850346, 0.12039952731180577, 0.09645783177186405, 0.20929197270062663, 0.16466834702559058, 0.10696379302610313, 0.23846686847748297, 0.26607735142592465, 0.15925474074338714, 0.15088958155003288, 0.057142345054495725, 0.15652478642521367, 0.15970460289428312, 0.21809225451321373, 0.14966184904258098, 0.16345521615397546, 0.18298671971405708, 0.12952648433706454, 0.08084515139700905, 0.1930704745914667, 0.05972059098102393, 0.186929942799672, 0.23078682171481274, 0.14639595493433938, 0.15972718716629092, 0.07797974507294356, 0.07281566128855751, 0.14067212900807782, 0.10305202551065915, 0.1018902684952463, 0.1076593472351951, 0.14051069896067345, 0.15057479602194604, 0.10053086079536908, 0.11069189096170087, 0.10789154082416527, 0.16173479718066033, 0.1993127888248813, 0.15292236521359415, 0.21988053355486165, 0.1295676232585984, 0.09869683098288314, 0.17853593273508936, 0.18665341570252375, 0.10483704101774963, 0.16733059449301613, 0.2083267325595502, 0.19434904469357384, 0.11790363583713771, 0.2125895215618995, 0.2142380355226417, 0.08826970783693176, 0.20535293245507827, 0.11115227916067648, 0.20712705419188548, 0.2430346677260053, 0.08778253720412332, 0.1644936789788546, 0.1376175985581452, 0.17037407795508064, 0.10335415526623688, 0.21322106912491784, 0.18463098954769874, 0.16714886311561833, 0.15008331997500313, 0.1735243693955483, 0.15590335122279583, 0.21453558407243223, 0.13298218438942588, 0.1817565357252475, 0.1424257195885143, 0.20619012866049044, 0.16002102785052794, 0.15648107344825424, 0.1084968651975355, 0.2348232777008126, 0.12048671577846813, 0.12278613634407522, 0.14906840669291635, 0.10822267466855627, 0.37638184704607536, 0.18589288957657354, 0.2534550722808607, 0.14526502529699958, 0.11730386560121853, 0.1137340184481394, 0.1825424959702838, 0.0806564332977418, 0.11971521927344224, 0.13638047381274163, 0.14600681291232187, 0.11189101774606014, 0.15207623642298485, 0.16690363837105615, 0.1179181302206651, 0.1998872015505068, 0.0796676972400277, 0.12295073033460688, 0.08176084863202226, 0.10016017383144749, 0.12767890242919808, 0.10058880002508241, 0.1261321555883173, 0.32197697929316954, 0.1240574132891432, 0.07994793986360874, 0.1163237173891356, 0.08771622463339761], [0.015805044095031917, 0.05882617566854723, 0.01990107586607337, 0.044511822803366574, 0.03974412440232212, 0.024414126641086997, 0.04022105627002255, 0.08454947762431637, 0.028845541171669483, 0.030629974451937506, 0.03675639681938676, 0.02484151560272421, 0.07286849837269514, 0.08275993453759341, 0.07155874849206979, 0.04383128008715088, 0.05777473531423077, 0.02728451253666032, 0.04106751447843929, 0.07581466568573829, 0.029200452470010328, 0.00751800480253634, 0.07260314083748287, 0.017340358031252702, 0.06272662040447036, 0.03194723965510005, 0.04123585463892068, 0.027748953340755358, 0.023562713759019974, 0.04646519762313655, 0.02802193536603403, 0.010912762560521164, 0.047949795581160054, 0.013482515444798816, 0.026614346481379003, 0.03612007652860015, 0.029635969624524156, 0.05762898708663641, 0.04656624078990952, 0.010607809770942457, 0.019995046126085426, 0.013534326928727811, 0.04175259243516673, 0.07260132520910233, 0.02625321646431281, 0.02752924506973115, 0.039000004049270384, 0.06178692929566868, 0.015573491147088428, 0.045028641038844665, 0.005859721305539772, 0.04157971320373397, 0.060503417926449934, 0.031835992197175665, 0.017678811845760194, 0.10830404852787334, 0.030190772414507887, 0.030530993976900657, 0.018452625766757037, 0.06268859946078832, 0.029905600015134103, 0.04676806665356121, 0.05151869278521307, 0.04219691193993053, 0.021835392333507057, 0.047717831818567175, 0.08567203392064379, 0.030108536706276, 0.04789410098906487, 0.09691760710050022, 0.007786582779860305, 0.06438029779782219, 0.02309304248962191, 0.018423428240742896, 0.06133743486697636, 0.020961862493066058, 0.06366291774376746, 0.09220104123796187, 0.05939256745360552, 0.038444701386916066, 0.07625980107414146, 0.03263397427696375, 0.054269710690864635, 0.029518694969855493, 0.026955238370705518, 0.020551543885601625, 0.01679443228509157, 0.023769124658898483, 0.013969984851897726, 0.0341873247957518, 0.013904652873715086, 0.03780363518143854, 0.033165187304539066, 0.05170447293729071, 0.042406088417215694, 0.029323792625819484, 0.009043692843988538, 0.016973101226012074, 0.01703427143154606, 0.031642401778709986, 0.051434913409813765, 0.009264280200905858, 0.04384966619733361, 0.04901801709145789, 0.05139309267002729, 0.05926688689918769, 0.022424278375242027, 0.03558281140642301, 0.03654276171038228, 0.03530655627048785, 0.009115571043484155, 0.04323186225167686, 0.0413462134348529, 0.031643481962683226, 0.035832238143249866, 0.023899631567239284, 0.05282688367691252, 0.03153645373400181, 0.013390876007296387, 0.07647229088169914, 0.006070563545255292, 0.029860810684641043, 0.019900122086607644, 0.019198381717527108, 0.04349849915372268, 0.03878944095284228, 0.05725809327897526, 0.025433314693791252, 0.05384956892099112, 0.03298953866526004, 0.03518413542018783, 0.15148473993664788, 0.013898084627374286, 0.018799389720023162, 0.02356994179858556, 0.013944575630669153, 0.03473513128776704, 0.020925147729294918, 0.07238541864940236, 0.05721686242689049, 0.0013999561352031908, 0.01945213685112615, 0.033286803762518594, 0.03865129997833602, 0.007109623918715384, 0.045417235307996316, 0.02593681257548592, 0.005841387385096882, 0.12202729561155844, 0.04825351496918067, 0.03728143134785276, 0.003730971483521224, 0.024175473015695333, 0.018907128495254347, 0.023976558286155907, 0.03987601026892662, 0.029495710416907267, 0.023296515442310803, 0.05765518346320718, 0.025696492708858945, 0.042168516891017076, 0.030209765649370612, 0.01737965834176829, 0.02909166032388326, 0.030167326293585282, 0.033376619910761234, 0.036078271110572165, 0.045074426283639286, 0.026512108217444152, 0.06941435347882009, 0.050636906432168144, 0.06529846949683082, 0.009642848294348487, 0.02309746664738463, 0.028939969169216293, 0.060993492032491395, 0.03247388105298723, 0.08441063184891978, 0.01632788282398495, 0.06352530536992897, 0.07940333561911699, 0.027844974801184672, 0.007610137409140026, 0.044134788800992315, 0.07042051803681158, 0.046498258147508874, 0.07446640456515936, 0.05811572487976763, 0.021778458594194344, 0.026443780835477576, 0.07209661116282787, 0.03137573040270757, 0.027008006506929957, 0.06472865329875101, 0.039405662926935384, 0.049516606264777725, 0.03484090887791207, 0.04114552904220839, 0.0540642267573745, 0.03247154065437856, 0.047161835846641374, 0.02554532057876068, 0.02714786543360641, 0.029886884487143932, 0.033847177926931656, 0.11642870973915824, 0.030552681926037037, 0.007140950211549119, 0.03767751795690387, 0.04598920804358298, 0.059059744385341485, 0.031560472505647814, 0.017592151979765585, 0.061831297277803385, 0.02124312401358639, 0.05982361831552079, 0.02313713084966425, 0.04975718468607915, 0.015825863491984147, 0.04173059805086063, 0.028942951166461554, 0.04736814332465011, 0.061957115728047595, 0.012852610182768155, 0.014726728418721788, 0.03191044828253648, 0.0364586299345378, 0.029852965944296414, 0.03750443188173156, 0.013774032967405455, 0.015039703106477618, 0.029878570517945676, 0.04786402054671799, 0.025269735769759265, 0.08753971031476414, 0.031050604602862752, 0.06861268843133604, 0.05116960183987695, 0.019842609950912096, 0.025432912497631004, 0.041017856659187425, 0.044532499516442905, 0.027881946204410448, 0.03590985817173797, 0.06304169704596843, 0.05314911941006299, 0.026633506340365258, 0.0474975394055007, 0.11878793112813466, 0.03375087301397035, 0.03461637233774509, 0.07704655805061902, 0.048648280076562404, 0.07505888164403939, 0.027843477099292704, 0.07466175698585088, 0.04689077478683284, 0.06176107382822422, 0.06140513788728465, 0.04222894590648432, 0.040192140281320586, 0.04794235303697567, 0.049910344814340916, 0.05670885420254162, 0.021400798314941988, 0.039039304359785976, 0.025307643715472474, 0.009558931980732708, 0.030198440954629934, 0.06173645942321709, 0.041596773981807694, 0.011643293471406064, 0.08065295525856557, 0.041362791577534336, 0.022573215443821206, 0.026595688409983154, 0.008259037821253222, 0.024127791703288114, 0.022621074871670817, 0.043743792846198046, 0.030564037264294686, 0.03660907811154762, 0.07866127221214195, 0.08168428580486968, 0.0626333989954043, 0.05513779173094419, 0.01706712894261845, 0.07476235965206739, 0.009810395553828248, 0.04868804387027218, 0.030738952374386213, 0.034475645816494385, 0.03178238710989395, 0.0468750546626266, 0.06520653128503792, 0.007285447800607091, 0.02739484068907557, 0.014656062553366347, 0.022985658030055707, 0.05031587728749841, 0.02073726849630475, 0.023965978611921592, 0.07501290104682408, 0.016638914521242824, 0.06243477920971571, 0.08853583912094755, 0.0350723440398372, 0.05368343126329203, 0.013791282394630535, 0.03763761626736772, 0.10098649158833489, 0.01467490735869374, 0.08282393352278779, 0.07862284524186004, 0.04836345624719416, 0.024453122431652683, 0.05244992628333069, 0.042266399945102395, 0.03891969122172844, 0.0223243173076621, 0.020713594464224674, 0.09466346999209735, 0.02889606275505597, 0.004993341938262025, 0.062307072352738156, 0.019062931626854886, 0.044116483130041635, 0.04568932675606301, 0.013753311246663574, 0.044867264617594986, 0.06457969516275391, 0.020614031762365374, 0.03480457332766345, 0.02166574407789496, 0.046151499939902176, 0.024750307089679187, 0.10016909109488611, 0.025225871490434777, 0.021608831406000163, 0.03277080524111948, 0.03587251904630854, 0.05038296360702765, 0.08016399198001431, 0.02743970662836106, 0.04143869939951166, 0.05725420155231992, 0.0593868907420866, 0.029771063484311588, 0.08333546575158836, 0.07534241844569484, 0.05905556537571454, 0.019521253303654736, 0.11548357940609418, 0.22381709167553535, 0.12564637157465183, 0.15056912697130634, 0.11955148330138576, 0.0869637500915316, 0.16480446552797673, 0.17721754138267812, 0.10618219948223523, 0.26068605362407626, 0.1572961450344132, 0.08944241224878258, 0.12460676727876549, 0.19214018338149597, 0.22920940071344378, 0.07484892758751109, 0.12976493686437607, 0.12893586119096126, 0.1573199090818244, 0.1641708035622874, 0.1284493110893715, 0.09639637619857827, 0.13337817523748646, 0.16705029824328038, 0.1542182948680655, 0.10030169325369982, 0.1131775015364251, 0.10017326627407344, 0.10110741856718257, 0.14611518371009058, 0.07044410588400019, 0.10319937486201526, 0.1367029048983128, 0.12105608764555185, 0.1507440095226611, 0.10277671649331048, 0.1460490703222252, 0.22151110573641716, 0.11905657518054209, 0.16212318843651205, 0.09011172794646795, 0.10812691367802121, 0.11700025729594693, 0.14201998410205688, 0.1033307666019086, 0.18483076995659262, 0.17577035532843682, 0.1832184613111519, 0.1424078390963616, 0.14388690973001142, 0.1668742972035562, 0.11879915431622537, 0.18870991744822074, 0.11708088804997745, 0.1123175218761448, 0.22549932882670434, 0.13498620911230966, 0.1046977432504777, 0.15968272342316567, 0.11837848777612371, 0.20512814693633588, 0.18186771040481908, 0.1728371272404348, 0.1606566969665789, 0.08760741716551204, 0.20413416317634045, 0.17329275037252134, 0.1522382333754532, 0.21785672844177295, 0.14635668526734077, 0.10856960524594593, 0.1282921941169808, 0.1557486933926421, 0.10442477080129808, 0.230720509144087, 0.13388161757780662, 0.15215756431702646, 0.154120342866067, 0.13447409465668664, 0.155861645396198, 0.1387921032766181, 0.11285012152286307, 0.214088648377407, 0.15492180873069072, 0.13285977886088435, 0.1067532797253901, 0.13167441101564517, 0.1456965166594713, 0.10237802135487718, 0.1582278764896816, 0.12495361358648348, 0.17679807760061758, 0.12453157574899736, 0.19056781856042726, 0.14361952972267905, 0.08403310371983437, 0.11122411522533625, 0.06610596447341865, 0.1540815481735814, 0.1080241812873752, 0.13711740443062398, 0.09812586565291691, 0.07199177203039009, 0.1370249682616803, 0.20926440885711103, 0.20757443421790678, 0.27648024321083103, 0.12567630262985346, 0.1607684998382484, 0.10586333070551196, 0.1408608011420696, 0.15618007750280444, 0.13056592775448678, 0.07710818982412738, 0.12380868752276707, 0.07077326322154653, 0.16051598193664707, 0.11879014512223583, 0.13582412544037067, 0.12245298002756412, 0.10488708188096363, 0.0687169683195891, 0.09414872019401482, 0.1109572944621886, 0.08418709505349399, 0.12562406309429677, 0.13969052522893877, 0.10900057566862915, 0.20422538892636377, 0.1803470565186393, 0.21278069114252446, 0.2469368284988788, 0.13048738842048954, 0.10949527694573326, 0.19445079649167676, 0.13313186264807178, 0.10595825666020955, 0.15492548595272726, 0.09568506356088385, 0.15223227321140229, 0.3103937911650827, 0.17466455337501344, 0.11242643659633976, 0.11547943487042382, 0.11775143714922091, 0.1906193149906974, 0.1634830711109023, 0.10954698021974295, 0.1724847880822997, 0.08466999857656418, 0.1279269463773216, 0.16215548670339971, 0.1207142592137379, 0.16794482846894573, 0.15377356550626217, 0.06563458291272964, 0.10459126468988196, 0.10984525655306156, 0.09458399603083249, 0.10169170616615204, 0.11775211896747352, 0.090849784713599, 0.1703669686591433, 0.1583269010147741, 0.3219889609083053, 0.10858992189769784, 0.09330805361030564, 0.1513874161267473, 0.06824394733074211, 0.2227807585750857, 0.20776591023370145, 0.12434452006052579, 0.1502044078323149, 0.15787475592186376, 0.1108877643221809, 0.14925478056313532], [0.05391665524052036, 0.025382239611879475, 0.07673912696660527, 0.012357364025627895, 0.07394240042495151, 0.048047873987666065, 0.054265612120469736, 0.07159437924142807, 0.03264751105058578, 0.036053396235670776, 0.033313938596796606, 0.09397322477232065, 0.04197437488924592, 0.01511833532863567, 0.09910892499911209, 0.035595038169694525, 0.01503832893626344, 0.07573319989587031, 0.037408153781847614, 0.10241662452538168, 0.04358561101159261, 0.05638057403566857, 0.05673587412363099, 0.00904248146745827, 0.06731197072733795, 0.07084771164602811, 0.009897683611920765, 0.04278946179716338, 0.013873985416496233, 0.08997911046589575, 0.006342004297391302, 0.011924685226873526, 0.05281456498309009, 0.01858893196068464, 0.043523519585329684, 0.023524918811275594, 0.010430808028867169, 0.0293259070284905, 0.08300631607492125, 0.03798666124742839, 0.050505116326554175, 0.06204511624790969, 0.05412834065575754, 0.01912260030005728, 0.0511372346250761, 0.013568177481272049, 0.02275692332806366, 0.08318782528682102, 0.028356464895149393, 0.06168842187992508, 0.017368201496860674, 0.0489512984941323, 0.03209729521204868, 0.08562229949259952, 0.017879984619456436, 0.040252446722719944, 0.05911887488177708, 0.049690477580072424, 0.040905283869154034, 0.027735376347517295, 0.022527384233751127, 0.03723519794162243, 0.00697961209469565, 0.017741878118906772, 0.009207076415599836, 0.0650156528178242, 0.027900755578171343, 0.06642342364836125, 0.020107523155128284, 0.0283793919915033, 0.02386116820778097, 0.038096345885987246, 0.020960567804474025, 0.03233858609511968, 0.029303004829994136, 0.03377160718364101, 0.04280284535320055, 0.06483490969384871, 0.0390478270879436, 0.054696850673926455, 0.08894781056310862, 0.01280053152567557, 0.04685271170831496, 0.007504749566226477, 0.05156519815265652, 0.01962833898893047, 0.034824694626994675, 0.073020099512031, 0.06152834780814667, 0.05044880886411956, 0.010922125112565776, 0.01961274909967136, 0.026327385266702023, 0.055038602496947975, 0.08818851017783727, 0.020422465731239608, 0.03738065505580556, 0.017347607138236205, 0.025700183337434165, 0.024964773404081503, 0.05234584940837757, 0.01750069065770555, 0.05189344001513335, 0.12817818491208938, 0.029410891077150742, 0.04027778891125514, 0.05345796775673667, 0.018843280812425, 0.022843700022466724, 0.019372729922554666, 0.041405738466569496, 0.04212049849992318, 0.01573947079915313, 0.06505017273969228, 0.09119608709889074, 0.07887923954835824, 0.04931696758214985, 0.033510666145312215, 0.03049954032194951, 0.019695957739567085, 0.05479505931537959, 0.03285076183777663, 0.024119060216171127, 0.038687413363086606, 0.03094202504613467, 0.01402595236281594, 0.04608100069867027, 0.04605513757034656, 0.08150163512196272, 0.0464960977795624, 0.03381668762754529, 0.08740864033179899, 0.02875873191852964, 0.051747795209408774, 0.015713314642198384, 0.07371326352679923, 0.05164506664920238, 0.05956904729828239, 0.050700258073066516, 0.06173502683879868, 0.04044651977657791, 0.017900870091492133, 0.027478765621180498, 0.018186607480710073, 0.03814260610529492, 0.04802115667130678, 0.029653124248368606, 0.0038608619304854545, 0.04356945804770916, 0.07623944611799333, 0.024739991715778748, 0.02808949091441689, 0.03987884862468608, 0.030919436943687262, 0.01633244296235423, 0.074158544471908, 0.031844704532094543, 0.029435744884634213, 0.030397102875154347, 0.06241563467248794, 0.05504912088414835, 0.016375535408095006, 0.037238821537504276, 0.04066655171975013, 0.046203187892153386, 0.024254529459041455, 0.02061153623095203, 0.04254143317079833, 0.04749355191785482, 0.047564985786354354, 0.010161786678157026, 0.02343932380749574, 0.029135183694081444, 0.01595360769574801, 0.0072491395422407704, 0.033277319594016, 0.01646057499812976, 0.021714107208554784, 0.01626049198450581, 0.02738028118807462, 0.015762712949165897, 0.05130871957648666, 0.03382193149938699, 0.05525630170239076, 0.05092970140638852, 0.06528224375459456, 0.06872232327417982, 0.11657105653636879, 0.06538630147734958, 0.050912475919411074, 0.10258286560495054, 0.04066917174045117, 0.008461491877002823, 0.10730701573793927, 0.09957806192218296, 0.05740775621586269, 0.020723534455042214, 0.03447956435622708, 0.03519640048785556, 0.032545824369956414, 0.020982853302191344, 0.0652409439545966, 0.04430540807304844, 0.04941359425203935, 0.02154498946883025, 0.010087619790987623, 0.02310527882899248, 0.0035778068066123995, 0.020008506290915034, 0.020921374746267835, 0.02022892127804939, 0.011544368537743727, 0.03503776283093518, 0.01658622490903062, 0.08118970710183344, 0.059208162429351965, 0.03896399025594996, 0.024933570642925562, 0.02632346481174952, 0.04253822326239559, 0.07199613107067925, 0.024535974840663617, 0.03673357122968282, 0.07638895583729591, 0.010486571568875544, 0.05180120685948961, 0.07490210175033539, 0.04512386193739311, 0.035677151303858526, 0.05970551437067409, 0.04685335522217136, 0.06347755127916895, 0.07996021259215572, 0.013142223976882956, 0.0056473172040686255, 0.048517156467442556, 0.02330846258348996, 0.04506915559872024, 0.07418205571030417, 0.040788382682348454, 0.0240168794088306, 0.09596525255831019, 0.023576327141434438, 0.013356188503694872, 0.04077500678719052, 0.04834141206717299, 0.0271752818051966, 0.0544006580997619, 0.04016722327158336, 0.03469250615566008, 0.01956202258776513, 0.014855562382557941, 0.04018267909545572, 0.0556733331552917, 0.020222566578717485, 0.049549624654314214, 0.03758096406536718, 0.05114158983492563, 0.029686115824827747, 0.03900939628722207, 0.09347337538436537, 0.042115346558632395, 0.026588236289699713, 0.037581128774270896, 0.0381151648358472, 0.01919137009780013, 0.021066301344563405, 0.03801738520363166, 0.05853091389121068, 0.02975490094432908, 0.06947085246323578, 0.02649238528383355, 0.026768383780314077, 0.03444700561944516, 0.01569526082265281, 0.026155775826003765, 0.07203043648792852, 0.01148491436916013, 0.040363629063170765, 0.11297026709202798, 0.037212789869837226, 0.006977736615696021, 0.019541979812446143, 0.033967480544121034, 0.028293639939698963, 0.018646246828739683, 0.009822906727241653, 0.0372483286886446, 0.0240944285741857, 0.04565790949028827, 0.02916786883537087, 0.001100711897672755, 0.03932361874068457, 0.037795372923175176, 0.061585187701688665, 0.019987724240749113, 0.11492824226978327, 0.03577046464347551, 0.019526393753626657, 0.05276052131047172, 0.021840293381002643, 0.05362225531209862, 0.06795147794388956, 0.03756130624923014, 0.05014629606457968, 0.05149052373223728, 0.022794944271745703, 0.03198687512908251, 0.03473922985816195, 0.0519473726050027, 0.025524159315072244, 0.04703829267753228, 0.044797071811532786, 0.05829212428521245, 0.022541497488536184, 0.029369847916607416, 0.02525966745921441, 0.027783090218661294, 0.0520206795584771, 0.0328374050948168, 0.0055964753001688, 0.01818282300636413, 0.03689605081754346, 0.03737986215480393, 0.03366851856211021, 0.044102632260370644, 0.0725714324582969, 0.013677634208673432, 0.024677457873739546, 0.0500442301704278, 0.08452594340328248, 0.11605613053806367, 0.041922702258753206, 0.028130281265945207, 0.03238359759111078, 0.06161946247542097, 0.06849365368966134, 0.02856139533011423, 0.014628324424847962, 0.00932047083493202, 0.028538383964088657, 0.05967320844290718, 0.041445919778198004, 0.022970278814975775, 0.06437567062675953, 0.035034031982743935, 0.08759091563162305, 0.009578730565525833, 0.026112064764264132, 0.042327503117943005, 0.02716493195733957, 0.025608059349319628, 0.216821207394523, 0.19582385587836468, 0.1818221128515659, 0.2466855669814733, 0.16371695775418513, 0.10813630591597288, 0.14151831908572104, 0.19595219092744012, 0.1456373287064414, 0.12825935958854615, 0.15347863697717268, 0.24484144013014533, 0.1197387841379931, 0.08745382419757305, 0.19360099047903093, 0.10244423433417275, 0.1947494328863198, 0.16117516995197342, 0.10621020765674692, 0.183230105847601, 0.10001543683991318, 0.1471755260060872, 0.13747219507011676, 0.06363229337899436, 0.17977414532534539, 0.1777768162109198, 0.10550563659278617, 0.11149816019760986, 0.18960810957416413, 0.16803766300361003, 0.09824514554272737, 0.09504282141044255, 0.15070519950841704, 0.13009855283364175, 0.07152438178778657, 0.1074022174842896, 0.10699082060807175, 0.09734407292618867, 0.21671694282802845, 0.15602152794599533, 0.19264733358736963, 0.15798335654600976, 0.14928614420275535, 0.14254959600587047, 0.1586578969633387, 0.1284538233472455, 0.1587607366062941, 0.19729267625558763, 0.11254775428002882, 0.2012744029202769, 0.11091000385462277, 0.09902123857529894, 0.1448489016582889, 0.30975435289644426, 0.12595059275026285, 0.09271070421222719, 0.13667379355719014, 0.14830319210886955, 0.19831062324585455, 0.14344303838668332, 0.1045639766380191, 0.1553572990721272, 0.09878883048170999, 0.15851304505861577, 0.10215482163813808, 0.1563121510609504, 0.09676327868815392, 0.17071305653981625, 0.20322918351138794, 0.0938975812506772, 0.12057438688052279, 0.0711955768506854, 0.0765441958942721, 0.13766756281256676, 0.21854257631686427, 0.198972936899912, 0.12801998775572548, 0.15198124152037407, 0.09689306930428553, 0.12528340677700697, 0.25186052155350486, 0.12954395114173814, 0.08915846175964802, 0.10782781763062363, 0.1252236519189131, 0.12438959667399047, 0.09670457337051631, 0.09977311556858402, 0.15934552216241438, 0.1961462256769019, 0.1682449051088864, 0.1497894946125246, 0.16134124249219894, 0.17725515629976027, 0.14957152727630832, 0.09994531681220378, 0.11965591640722369, 0.11803805362433197, 0.1322864846236283, 0.09855076865923983, 0.2076222227826234, 0.0803646533900211, 0.1875186354042061, 0.2790220923000767, 0.15025184399658634, 0.10719254688029328, 0.17868740363947808, 0.10991908444632446, 0.1543036830281058, 0.13671880888362087, 0.13117505958484066, 0.1040700491097185, 0.12930364468164984, 0.1645758036043375, 0.12484449202254896, 0.11138370666172236, 0.16939641186787238, 0.16839605425634693, 0.1297561728185223, 0.1650189395032583, 0.19933377963400659, 0.10351818235170457, 0.128602352474005, 0.12816807255148888, 0.0826666173675368, 0.142243972889358, 0.17229096783745676, 0.13500750635660466, 0.15975628318565507, 0.18344359923033945, 0.11276509342414719, 0.16694353623015268, 0.09684327358920729, 0.16479004775324177, 0.08416150005594378, 0.16079304529534233, 0.13897781831122216, 0.1824577206805829, 0.21721313797658492, 0.13345006492830094, 0.18896413606501397, 0.10424035045528605, 0.17788114206444833, 0.07892847601925174, 0.09756692790336187, 0.10584895123517322, 0.19930764071403012, 0.08199010810424244, 0.10898579783256977, 0.1309504885707171, 0.20611663018503498, 0.21221513439330364, 0.12813085600012733, 0.14445404462035627, 0.21394516010918926, 0.16960130974410043, 0.1503393005940222, 0.14360089846436055, 0.10213844267831695, 0.14115602078457035, 0.17124752544106978, 0.2139072081134204, 0.06326426857060964, 0.13770038201924295, 0.1083382237101755, 0.15358447968479128, 0.09375571708885894, 0.13223509544566756, 0.17688656075587197, 0.11479365594324567, 0.17088708107269582, 0.11564592109812845, 0.08953049703831635, 0.14604116429484662, 0.13254747545767215, 0.13855823195509373], [0.034936650716249025, 0.04495105165387354, 0.036768983643982685, 0.039395156031053875, 0.048126321391112385, 0.03501155113260593, 0.025056420502463178, 0.042096600387125246, 0.05447536316369811, 0.04090017406269908, 0.04693030875416533, 0.033267352790121114, 0.04293756957556452, 0.01572302289141883, 0.03478812925036877, 0.03272571713633595, 0.04351416948221384, 0.03588910101942959, 0.06540115592220137, 0.047547430881569465, 0.04025805065588605, 0.056276600582585226, 0.07634456870296309, 0.03782813084281741, 0.03801079301704322, 0.07520128206740465, 0.032306961985605384, 0.08239193654228603, 0.014641365156539026, 0.012877027320134784, 0.020116775582033782, 0.011095871938572777, 0.03448865398944866, 0.014947996636281812, 0.03753317167021094, 0.02144603006121132, 0.05021620924854952, 0.049115141718498165, 0.024856795226373983, 0.034151559981006774, 0.03982221940532327, 0.04587644373156852, 0.020757458743549163, 0.0360278969991111, 0.01801276489371254, 0.04878022339976123, 0.0443439154825624, 0.06979457057651973, 0.0949679286549649, 0.04218007332735485, 0.03165478559000598, 0.050932145226866975, 0.029221111946108363, 0.05241828302161829, 0.032771215098158966, 0.01881387069701187, 0.03526566632752938, 0.042166980884728894, 0.06639899310445593, 0.07314091923856929, 0.034796943091937614, 0.03778001669073298, 0.02618458073195671, 0.03975049059297289, 0.08901237645336697, 0.06784162859642698, 0.040851228705216805, 0.038819280077493, 0.042993061154359774, 0.017092335150547085, 0.06310407192476335, 0.028238201987058408, 0.029491876146846244, 0.010378852903452373, 0.06093260719470921, 0.036815079154386636, 0.011204522358433855, 0.05323967866359219, 0.025793872060134046, 0.014978440970392718, 0.026287677014366757, 0.05140528495934221, 0.05755825801902721, 0.04606734135098035, 0.06318779767400796, 0.031280182001571503, 0.04273121230184071, 0.05540819778557747, 0.01879695739086357, 0.027553240858739423, 0.06008927462502353, 0.01565152007500611, 0.0454369735633654, 0.08549707476049663, 0.01897340467680366, 0.010291319697224086, 0.03786725495311041, 0.009169380101675709, 0.017030676563961372, 0.08456441633883985, 0.04517435862292205, 0.04924140833017807, 0.07979843014430615, 0.0681802471198382, 0.06931313028138492, 0.07535407830390238, 0.15336655831385046, 0.0524687375723114, 0.028799198597909945, 0.036730418777874405, 0.018138928083522667, 0.03343815975371869, 0.03534452358801519, 0.008787271724413, 0.08144466882391323, 0.04399014374000892, 0.023420815123245124, 0.03173233092492146, 0.08368491675824889, 0.03206898251758709, 0.03306844572146093, 0.03291234764600954, 0.0069014591562952254, 0.020965955317801526, 0.010002687453262268, 0.08487556294928636, 0.05208951638891332, 0.03759104578245071, 0.02682940268348302, 0.03355665823384639, 0.033444434013818546, 0.05055692685287326, 0.008145891422886522, 0.04813157675427295, 0.03235639380891958, 0.029548128067906347, 0.08157501102335031, 0.0315347338666118, 0.0451216594346108, 0.04235353861604968, 0.005218811190476822, 0.010689151071522747, 0.03856628720137862, 0.05305303283216012, 0.020509428201964306, 0.048278087239351966, 0.03253280087524364, 0.0067252814375434915, 0.029472766083575068, 0.0516973483195949, 0.02677090037914534, 0.025462661606950626, 0.018128666335776932, 0.012059373060061086, 0.09218159026556438, 0.022627672803918683, 0.03291273068997168, 0.04751933077650686, 0.016531920766518, 0.015984782686216698, 0.05313277492419847, 0.1213241418102576, 0.011028948412727444, 0.031258363817488, 0.005066310376634882, 0.07469600111606621, 0.08464461042275352, 0.005824997412761854, 0.01461283029657939, 0.06135278343853932, 0.029802440530470306, 0.15960727908438252, 0.04347432141883239, 0.043244839781114174, 0.07860006178699194, 0.022436654525658777, 0.05881322112174765, 0.011413267911261609, 0.029821569745939587, 0.03845115567767813, 0.03906403750842137, 0.029516413943060947, 0.03782430040319601, 0.037978644137300795, 0.0695007988401959, 0.033404333141422084, 0.0644877186465648, 0.03909532070880936, 0.011087218975468029, 0.04629767334629451, 0.03820992608164107, 0.008812174370001641, 0.01594555036600439, 0.014667473432998505, 0.023469743243749105, 0.03755204424622559, 0.007136410182987851, 0.051580826346311844, 0.04459707689802012, 0.045072089715470234, 0.029738692439071117, 0.04016446152461633, 0.05650768334406519, 0.020175944382865584, 0.06725819135505347, 0.04356759262361354, 0.043939524480412086, 0.0467581496453814, 0.05770389899431218, 0.08814539474945876, 0.041335511186550704, 0.06846566849778737, 0.05934042750947899, 0.015301815301720655, 0.0232909842874975, 0.013369671651162209, 0.006519505911837182, 0.05445124671584176, 0.023595544457015012, 0.025039700633515755, 0.031167817970497474, 0.03086685458378446, 0.01567500450032493, 0.02995183916702386, 0.059463457399678815, 0.02465892237641158, 0.031219258859393098, 0.030563192652358167, 0.01680363300106218, 0.026380494312052766, 0.06228369901016836, 0.037979961808530555, 0.04249530318643778, 0.13615044825259717, 0.05064544065164463, 0.06252099474471423, 0.04016514717330856, 0.011841063857108597, 0.06999961400945341, 0.06297113651770257, 0.013278458350067659, 0.028517125024189873, 0.03737056950828241, 0.05827020267925917, 0.08066001858922743, 0.024870764839673237, 0.052373202577714, 0.015284301574161697, 0.04547495237221161, 0.0037554305163212125, 0.05430963153259889, 0.008101867222707839, 0.026420558795272827, 0.020507428712481936, 0.10100031181448892, 0.017348118501925663, 0.03767066530042118, 0.048839101087181806, 0.022128736975813107, 0.04191389224762398, 0.07053892458638839, 0.02433329095853673, 0.05161017900513065, 0.06943769617787293, 0.008266556974230035, 0.05683879803625807, 0.017235783199148796, 0.012347001728842096, 0.045205795040894906, 0.04532658029347659, 0.04282572839949881, 0.021912004956374728, 0.11360740709689357, 0.03508771942447751, 0.015027575934636257, 0.029374858131632212, 0.08420626257335947, 0.02768058573917276, 0.04034019060312741, 0.032936318537160274, 0.007143965246336114, 0.0459119672286174, 0.010989763973010405, 0.018654717845962416, 0.04322631577510507, 0.03929037435521041, 0.027662245594265483, 0.06608839807731491, 0.005606145723797982, 0.0506946349877023, 0.01034332078791434, 0.04651806535079114, 0.011144420845554242, 0.10131857538175199, 0.030984349488731355, 0.03554106727542897, 0.02777594070310795, 0.10720389264245188, 0.030096719800043973, 0.04742404093004523, 0.042672169905516415, 0.019283787114545703, 0.02849058965371261, 0.03005669936687956, 0.029402253435804483, 0.03013434812366482, 0.057908256778553616, 0.07406500513635336, 0.014322379551407312, 0.014291587604900763, 0.14309978503133022, 0.0411369220443791, 0.10040047263065655, 0.04514903941702458, 0.0532309644134535, 0.043999593434554916, 0.03137928696589605, 0.00148194920902531, 0.027554039505400488, 0.01611739633634927, 0.05837736305810752, 0.04456337669023103, 0.007279028941411526, 0.017142368352881843, 0.04343889368277404, 0.07532395572671968, 0.07322776296566572, 0.02575216431831641, 0.004602472866780215, 0.0207096797549316, 0.08951498375784966, 0.013353234277136866, 0.024711144674989968, 0.08355910979932354, 0.03267044772303874, 0.10011971672816623, 0.022930480547309406, 0.06915675641428079, 0.023546106888041384, 0.0075762600435184384, 0.019272885683383194, 0.014316994910909524, 0.012461085627306134, 0.0035678134290426373, 0.035907782073463165, 0.016785758254568905, 0.021269220798727007, 0.06602197825427979, 0.042354235756060774, 0.050485106109971964, 0.03149056698255722, 0.024083249436150637, 0.12412702003794333, 0.1288542421835084, 0.18850857421996134, 0.1320760862361039, 0.14203506071240674, 0.13377499346050525, 0.14474964730681913, 0.0972902782321457, 0.17231031921842407, 0.1504911392206146, 0.10663687266529569, 0.1644323613013952, 0.2058049702956792, 0.11257177879733425, 0.14197564293299952, 0.11806514249333452, 0.11944133517963272, 0.09186060708617011, 0.13077422706109862, 0.14025868667710212, 0.13131635684159496, 0.17010593185982398, 0.2044596892571257, 0.15028359068016853, 0.09859142494538138, 0.19159471345764978, 0.07553484441051561, 0.18403045322385528, 0.1125359412042364, 0.11913807161392705, 0.1393860818878297, 0.11508222594256363, 0.16180075735094088, 0.14570711931634336, 0.1702772444414516, 0.08410563692450525, 0.14534267596900463, 0.12443523253163985, 0.16028699825607962, 0.10307170630943391, 0.07388791625177668, 0.1221380566036509, 0.11653331904521874, 0.12303535240672289, 0.07707167807365618, 0.10769271802517677, 0.1501809808635904, 0.17201724462211135, 0.17302843471688611, 0.13266097904453356, 0.1485813586341758, 0.25791906661564307, 0.08272327723041659, 0.13175485024769462, 0.125278611066601, 0.10827475332564886, 0.08764535383952242, 0.14877821258719892, 0.13123700545439798, 0.1412046980112791, 0.22729537599990446, 0.14963730358548705, 0.11834127122476218, 0.11566133478716498, 0.08546898231631325, 0.1678862993515307, 0.150468371087505, 0.1531712212149174, 0.1851604175904105, 0.09405007871288447, 0.10839831564695605, 0.09719163675101535, 0.13961590826511383, 0.05468213412490103, 0.18339020290201713, 0.08157504932774652, 0.16366852567561213, 0.08534559619522865, 0.31387268835979126, 0.11343758838671832, 0.12100525771177585, 0.127150883988267, 0.10828493463416254, 0.11096170712863246, 0.10065157326959795, 0.20728149751742042, 0.200724397755919, 0.14540865146104368, 0.0895989623161093, 0.15539578732944306, 0.13210148971167304, 0.14781781412180395, 0.09040561459598043, 0.24911544465970611, 0.15945810644376665, 0.11000411254504036, 0.1704057173863534, 0.11086172499363461, 0.12412472943504974, 0.18043302690550206, 0.15241394330176616, 0.19173081663827743, 0.28713364574697714, 0.13674681705813255, 0.23226900266543513, 0.16023170202970505, 0.22642229623611898, 0.1429969453883748, 0.09233688394869528, 0.1271204932803108, 0.18525158205339987, 0.125821583543814, 0.08735876800792833, 0.1746561723731218, 0.18542105602400918, 0.11892047199991443, 0.09305594173530418, 0.1577305475309972, 0.12702537580363213, 0.13642052488942302, 0.08190275109823673, 0.18042682159331538, 0.15541028171297044, 0.08615974081499923, 0.12283086821797395, 0.19266457056566594, 0.09238096464785839, 0.1492122933268547, 0.09868207612946149, 0.19880285005896323, 0.12661923429057484, 0.18082204635345167, 0.10286238044500352, 0.13556840529124584, 0.2622541130310105, 0.11121847681821355, 0.19165321193154783, 0.09855022473681359, 0.1464335085643876, 0.14428746646210072, 0.18973051510270567, 0.0781679805368185, 0.08635750641265223, 0.09640945331944574, 0.15017636901428624, 0.11527156457304956, 0.10623636189848186, 0.1696774742055324, 0.11673062499011717, 0.17168462456714723, 0.187271204326422, 0.13544638280666646, 0.07322529616254954, 0.12264290854575173, 0.3200157022764606, 0.12036609523479017, 0.12922556500040716, 0.1746133480581545, 0.1326214029423652, 0.1680277038605944, 0.1453090753526457, 0.28774167441072007, 0.10144507948068843, 0.12723699227095614, 0.1765677762488204, 0.1269572322827674, 0.14554058712336326, 0.052389746246438836, 0.1285921328610951, 0.14063443748220322, 0.10109617239645413, 0.23222496793154748, 0.10473823099727593, 0.20017354989484434, 0.1419524457906523, 0.10860647705774154], [0.015172033304078205, 0.03638625760833102, 0.060398800959510196, 0.05504647788080958, 0.03943551354290497, 0.04770850469808906, 0.04333498151672464, 0.032678422698330496, 0.059953508523082545, 0.08114841496271473, 0.03537821613492505, 0.08666280011135725, 0.028017185620903492, 0.021466950007203608, 0.06186938333895899, 0.0491507992809338, 0.05219216450988766, 0.07083123309477683, 0.03822592965837929, 0.031529537875265364, 0.06489959049729571, 0.03608936406371575, 0.060430988143648834, 0.02955228601011538, 0.026656331930069194, 0.05540839696843779, 0.04521901005758874, 0.049981077712389736, 0.09348970837891103, 0.023425716170740706, 0.013733678328384076, 0.07974869571626186, 0.005537322778705387, 0.05280663980351341, 0.02243388128737288, 0.07981856293495625, 0.04753484788741316, 0.04568825806340864, 0.009018752851613588, 0.056135418239019574, 0.021611922570774635, 0.022499333924403595, 0.06890366394673625, 0.026355843517869234, 0.04447427300375797, 0.048295592348421776, 0.03401597390972799, 0.03718026177657228, 0.03796038060118595, 0.06928134529340653, 0.009293836830634504, 0.023794597082380808, 0.04826656910741041, 0.025345699133111105, 0.06024315487593413, 0.0540666246125775, 0.025282223002925038, 0.06965600825365513, 0.07483854709613709, 0.023352242593142777, 0.0625372013347524, 0.029395521438169866, 0.0656521876132296, 0.05148092082010643, 0.0471099027462544, 0.01789329731236062, 0.02599146911844371, 0.021216550338712913, 0.03536853661400176, 0.014639258414747254, 0.07248324041645374, 0.02282288541356402, 0.003793844080064446, 0.08168501358839773, 0.02115689124160957, 0.04059377719738311, 0.09844264300960688, 0.01512554230078334, 0.05030948428377029, 0.05403977323083147, 0.05252798298193563, 0.017202538813674645, 0.0019240520862607107, 0.01653704972517106, 0.024695187063527205, 0.020960992983272, 0.07861130029684113, 0.0816145641428809, 0.044590320002527974, 0.10619369846197868, 0.04915026684982642, 0.025766223946946765, 0.012089243785838687, 0.027193240821361545, 0.019271405218469522, 0.05804777671132357, 0.01882768326228665, 0.045517163816839463, 0.06834482578861137, 0.02747869092760788, 0.012180882265731212, 0.02079727041775421, 0.014034231858057602, 0.06462237392101558, 0.030132944267543576, 0.023805511920081995, 0.022165777326952067, 0.025642715251794266, 0.004495690265039523, 0.03825210305231233, 0.030717950073942065, 0.025447272815771645, 0.04492728760646236, 0.035210312644560496, 0.04808253563580014, 0.1252757152542472, 0.011579021567388648, 0.013842439830994174, 0.008884920164071506, 0.00877991249229038, 0.12017684087397591, 0.018951299209748546, 0.049132018635470065, 0.05413181486449415, 0.046728900408432375, 0.07401542392589393, 0.035055041944067326, 0.03082837015690823, 0.008619459206989456, 0.0469407198890563, 0.04012525314465165, 0.024667324445721124, 0.03068380170471726, 0.07311697899093551, 0.03040224332512627, 0.021784223405824556, 0.05346044988161134, 0.027758629031239018, 0.004213910677560395, 0.007069005936970033, 0.05207052123883078, 0.04598557295638227, 0.041895578915794054, 0.026037424817801486, 0.08485839491890323, 0.03558461171304507, 0.046974910393116937, 0.03401665189754098, 0.036125891135945436, 0.05070067176054563, 0.02446248402608739, 0.02164126948393401, 0.06511755783351199, 0.04574654586312752, 0.018647606634805282, 0.030168027264036, 0.010037024471638425, 0.03592172870412469, 0.036011338008627776, 0.11069734550772176, 0.04515656240044102, 0.0600115588355449, 0.02776731263786074, 0.0434888196327994, 0.08230159179337564, 0.04287543218402613, 0.04305829354111226, 0.04554315334967068, 0.037392985240946856, 0.03003675426777092, 0.035622460286944144, 0.010387101755177063, 0.024242183952141675, 0.05684988715896203, 0.028210113373314662, 0.027871152025557337, 0.06309902340534233, 0.018336316382872964, 0.06360400175195068, 0.03267428582353938, 0.09376068899948752, 0.026568750843345642, 0.048845363855962796, 0.05168733938086418, 0.05021064745021924, 0.05549789135975223, 0.04934700588966089, 0.004357883017585283, 0.03226546300274711, 0.012125238426961006, 0.08773147744397003, 0.014570101742602646, 0.03150777906299599, 0.06957877126912917, 0.03874525300136978, 0.006681707792825276, 0.012357994132945615, 0.04843459900228247, 0.012580002582962475, 0.02230279023698982, 0.022490045108321696, 0.04710051433874234, 0.047695848925579945, 0.05718888489589576, 0.04472284938298887, 0.038295042280468254, 0.03050281726304562, 0.05062600883144525, 0.01920585107478884, 0.059169597563243685, 0.14051707281220344, 0.03204687513531216, 0.011515111639915455, 0.04678385572568063, 0.042283782480104316, 0.09771136612060571, 0.047727783300703576, 0.023945142935600974, 0.046315653429877375, 0.042660100190269376, 0.048980831183613315, 0.03414017591445196, 0.04320244064494487, 0.05066465030634596, 0.00930869797875564, 0.019134403799750635, 0.03007005419461958, 0.0280073796954727, 0.022658869819415194, 0.00704676975616284, 0.1359682419006863, 0.04772312931656357, 0.03585166613300962, 0.07261358261589082, 0.05696320305428198, 0.050707876817473484, 0.04102421901939858, 0.05680641933013836, 0.0483136911756329, 0.011043012829407329, 0.04038418703261883, 0.05068969755103031, 0.037543644092135856, 0.04820808595527084, 0.010438007340135594, 0.06076268123222455, 0.08638486341242829, 0.0211571651180425, 0.03294846486119974, 0.024686668165809205, 0.029736857658492464, 0.04299471590427622, 0.09751342432273012, 0.037816616541315476, 0.10627311113620959, 0.024504833366541613, 0.030510744357842113, 0.07346093714717897, 0.008003481902227166, 0.09449480041380852, 0.05689014124894335, 0.0169074225930437, 0.013995311718674438, 0.01160576569682528, 0.03828318323940039, 0.045198341005391655, 0.031912976372686606, 0.009712733707631068, 0.010738636520991643, 0.039727423685572805, 0.0826039590362099, 0.04744579016621556, 0.06117835670949952, 0.04554283925362172, 0.02862128616881467, 0.030784415862252636, 0.02910095105518497, 0.04706210652065854, 0.0405274301527008, 0.03352516435927922, 0.0919488910585642, 0.05889241929135977, 0.06679586495362944, 0.01642754703249422, 0.10774042232022171, 0.04814521311932514, 0.031764707715821364, 0.07293016845059973, 0.01322193351018453, 0.026971261099641843, 0.015595082377624369, 0.02485798649309624, 0.07988390257401813, 0.033409312712929906, 0.011523910159725818, 0.04950201228982018, 0.03283146791340363, 0.018877603466652574, 0.04509713312971496, 0.07398376917286266, 0.02022709224313017, 0.04984122836181233, 0.03214187003792294, 0.007549122815215661, 0.023982252234653122, 0.029016227476418983, 0.0503750805622868, 0.05425598622570115, 0.018942906716538054, 0.07376189478823254, 0.04613853773222335, 0.08073288121170576, 0.03485207077896884, 0.03203427873461718, 0.02388275273504757, 0.13596834915299572, 0.04710605315443489, 0.05985526540767282, 0.022484305194549026, 0.04902193563119058, 0.009098842556047584, 0.013842816171686978, 0.030528174773339304, 0.03883940137682423, 0.004471005954509301, 0.03525179247522066, 0.04887959266441965, 0.027899493448316093, 0.05906119229151838, 0.02348177082416031, 0.022347656176275304, 0.03584037782744535, 0.05470342370831678, 0.019254989869472, 0.010748343812602182, 0.08066997007136384, 0.08288776396863884, 0.1047888387655539, 0.039098733630512035, 0.04469203732667431, 0.022866046807217984, 0.07777733698246941, 0.04593209235838825, 0.047567222763093255, 0.036448781874271176, 0.015704495054970107, 0.045288402301770066, 0.014664674339245164, 0.06359598464182308, 0.04348246110302787, 0.06674153399803946, 0.015768245061589106, 0.24711845262396723, 0.13072530468625407, 0.15502599668839287, 0.1503620074400979, 0.21750843422787808, 0.14452506097093706, 0.20650572624177704, 0.13671975883264698, 0.12513490829376445, 0.163353510321148, 0.09806603418603059, 0.17616228591049873, 0.15456838172770318, 0.16653363322538717, 0.1399299430270349, 0.08701752946381608, 0.1475315730297758, 0.17902973768932207, 0.18177918128428922, 0.09837863636353324, 0.11896312011465912, 0.1313381443821615, 0.1321843651033217, 0.0893395419623102, 0.10992430916596806, 0.12674196923692382, 0.09496192252563854, 0.11413632186069606, 0.21273110993206504, 0.12323121044544444, 0.10108468873846917, 0.14741866699149533, 0.12537469381406424, 0.2372669143181655, 0.2692768103893726, 0.15967437306479101, 0.1366979100050465, 0.10389903530238137, 0.07702430319641868, 0.1315066684037447, 0.18402613248796235, 0.173226575697622, 0.1878334975410854, 0.1022172348213292, 0.15228136412559018, 0.09333590090635324, 0.13166857342566216, 0.10803972521135885, 0.09931153227244655, 0.14990880514585203, 0.07708749778929257, 0.1284416195666117, 0.08839295606219, 0.1201249001127097, 0.1976387181709851, 0.18340488114664633, 0.09482763497339142, 0.2250531592196034, 0.1791841656930985, 0.15469667081150318, 0.10719551164056025, 0.21352048692924364, 0.20920301457085919, 0.12202438447744617, 0.17902402267340692, 0.21517545135030824, 0.18671652602572597, 0.07914577685897389, 0.14122827819758846, 0.1547869312907419, 0.1196823541014906, 0.05435600283465559, 0.06642137819360341, 0.10508448741729222, 0.10222376189044408, 0.13345239383559074, 0.25623531261038396, 0.23287281784559452, 0.18318803229879949, 0.0698975251326638, 0.1270462746822065, 0.16177771342617853, 0.06160312948087531, 0.1789010655615599, 0.12910846080030167, 0.10372127992131057, 0.2856701113764317, 0.22713036066101444, 0.09778251270613364, 0.14233256329692182, 0.18172717923598905, 0.1314529196749772, 0.12482938476868215, 0.10527941848962538, 0.13971894709092958, 0.10976653335796249, 0.16157514445724028, 0.2841401112175757, 0.15177620574831963, 0.18311621921677745, 0.08741194217075264, 0.10852833608946494, 0.21635228497607095, 0.16190797901682316, 0.264722662827661, 0.14062374289478027, 0.14853641991653752, 0.13688489674560486, 0.19668279365906793, 0.16406183521593773, 0.15913277954584168, 0.2388726039639404, 0.14920875400064454, 0.07577021726437154, 0.2169763555209483, 0.24338585775225396, 0.1836778995611014, 0.11970347514556301, 0.09665751258932775, 0.09829849590577426, 0.2287474190515857, 0.09954477540187298, 0.2188117949352149, 0.21106545092357745, 0.17536777612422744, 0.1140277135756708, 0.19679444331315257, 0.0735292415465078, 0.06813518582813202, 0.21043220264536722, 0.09058321675946636, 0.14537609272426175, 0.11948947614479451, 0.18951279291462517, 0.094795597176398, 0.1274991092542487, 0.1640193786231741, 0.08061638222106042, 0.19442401405784393, 0.15856648735221357, 0.15402470444959981, 0.22057162147135506, 0.13221559084711537, 0.2672523157971521, 0.22490222457676168, 0.10013611100974584, 0.1826839770881399, 0.13907558645211882, 0.11962709617951225, 0.21759748428819642, 0.1260030774339553, 0.07155962949318272, 0.14932519936513516, 0.17438188225271242, 0.08641467189356204, 0.09068923566730754, 0.1371307956475404, 0.07696152229102389, 0.07216001259944133, 0.21764389389464933, 0.31475877629653104, 0.21948342421843162, 0.17970296043542125, 0.12517558756254374, 0.15452358090589124, 0.14221996369381107, 0.08738974860358624, 0.18281284839876238, 0.08117679085943007, 0.058012540497246294, 0.07348222673059472, 0.12533553906025427, 0.11056907174568023, 0.13429322129776403, 0.11130604066795881, 0.12962304205904085], [0.059149127693906914, 0.062017318747577176, 0.03151788567793706, 0.036241884508560744, 0.028987907121078144, 0.0418363296757302, 0.029652666510833852, 0.02634272809260555, 0.03879510234260271, 0.01458520612363974, 0.10089344254905179, 0.018723029906170505, 0.07984653280507173, 0.02077339911803363, 0.027485308012053854, 0.06876113328842387, 0.015750811773262197, 0.026846076587154984, 0.0057079631181794314, 0.017622086865406845, 0.058889240026474006, 0.036362700404659394, 0.06094518635842589, 0.038849575024458675, 0.05827356197480714, 0.04279872380016793, 0.03620183726231899, 0.014370097252990932, 0.02915953954441413, 0.006082810897139773, 0.0175365837921779, 0.06168231615916856, 0.0549412633652889, 0.04665460137109603, 0.03567727770836603, 0.015721334625155698, 0.05131101400981988, 0.027949760307467757, 0.05411068232910288, 0.030424111304924856, 0.025669534074803515, 0.0632446107544726, 0.046422040059922204, 0.048827847255574125, 0.05223203938634646, 0.03520226489091593, 0.054598768436980825, 0.025475688932103016, 0.08291794017197625, 0.036527072229693015, 0.03736052992603472, 0.05331299327794583, 0.028833247375704592, 0.03947040884785595, 0.04065872996204323, 0.014889684896315298, 0.05086634976549014, 0.03978365070877537, 0.019212853118416764, 0.05892995376920989, 0.034113362837102146, 0.06688994055073108, 0.04526855296365196, 0.03991632181550226, 0.021649464709503997, 0.03455946732672953, 0.032765457947408004, 0.02908139857613752, 0.010668473400836511, 0.04009030421354598, 0.015772683583500407, 0.10554666060113138, 0.019078634514082825, 0.10245175731758918, 0.012196390758148365, 0.03916689247313527, 0.041561009167062665, 0.03469076330563234, 0.026370742012776678, 0.06552086482124944, 0.032586285303677284, 0.02272501002035795, 0.020437923470331777, 0.05405535928965096, 0.038811075275823954, 0.027952945318012953, 0.045820852561343106, 0.06507941431576206, 0.15770088460656906, 0.03308425011533884, 0.06861913889165848, 0.053119651838055545, 0.023396030263674837, 0.029605157568209597, 0.021066220905331355, 0.07044671824382198, 0.0523813460923491, 0.03536294800259414, 0.06924378400247905, 0.06511630144931617, 0.04223220944104176, 0.0354860928059826, 0.04058361504106753, 0.02836563305238322, 0.03318598659168328, 0.01622842545921524, 0.019929507304163232, 0.023499023124215104, 0.02012408789127104, 0.011617433215912071, 0.005915672537089596, 0.06645969025069667, 0.0707454082646197, 0.07315957347952551, 0.010697315653575765, 0.02076479403542415, 0.07825984213981899, 0.076366494139356, 0.06459611242697125, 0.036772231856781634, 0.022188781032098398, 0.035363101220178994, 0.050548974860219226, 0.0096402196551583, 0.036575282142767986, 0.030221046294055642, 0.041595073266615795, 0.030669368608223817, 0.022224339003103877, 0.021109286537994782, 0.025900683868976853, 0.08300070831131551, 0.03715634451157624, 0.07198575057930524, 0.053804350581260464, 0.03907161794843213, 0.035525902564967834, 0.008851038968010295, 0.04722447885620979, 0.04102247233893122, 0.03699218719116142, 0.008356336733296273, 0.06467749394716756, 0.034448966804531314, 0.02537394862531895, 0.037009064108133316, 0.04032644698576581, 0.01536273652867925, 0.08232794521797089, 0.07038075807354144, 0.05674291830209475, 0.03302807288785135, 0.04989865048217678, 0.04982788311017137, 0.014195217574465901, 0.05057634335131415, 0.020090697949091275, 0.030245495990159053, 0.02621678132263403, 0.04238970562695496, 0.03785264565639439, 0.023762189647963932, 0.039976865744158145, 0.039837338150508946, 0.08540703644675594, 0.01823390000349572, 0.0564847236889745, 0.050983113056469354, 0.011262247083528389, 0.020789527184059544, 0.02428698860439322, 0.07868718130574112, 0.06379792541866341, 0.05549948865307435, 0.05230239690131238, 0.012887819583768086, 0.029263237205844735, 0.04268004911981764, 0.029608242987324635, 0.007020406755468538, 0.05051949579689292, 0.05064877313411525, 0.08067717129785208, 0.039325120273016156, 0.06395317313651885, 0.008799743635820286, 0.046229192746743086, 0.014948347121507171, 0.04996306315485028, 0.0153552288670213, 0.023676263311156825, 0.05930082076379369, 0.05943996148304113, 0.011057476569417746, 0.038602189911950024, 0.030345223400922074, 0.06661818618135107, 0.03664367464220813, 0.04443266676859029, 0.076073695334696, 0.048726432536157875, 0.02647017064924923, 0.015962930028176597, 0.06473370947905126, 0.045396129585682385, 0.010633275491155444, 0.06292654637006984, 0.09435079120580228, 0.04893513020849036, 0.009593130145672589, 0.028308101764489568, 0.02253058839649443, 0.04628014525458698, 0.01173860821572523, 0.021108752191667596, 0.0339017195567008, 0.03860466054550583, 0.06555185307778659, 0.007689621425308889, 0.012248112226746256, 0.10672842783312644, 0.04115903900275308, 0.04772466915329138, 0.04260081264580931, 0.04859821240027105, 0.08208026133117177, 0.031765370381875865, 0.04900751019557638, 0.01636461865517401, 0.050286287141423074, 0.02803010569374648, 0.017399450223292076, 0.033118034592799606, 0.027433907342774254, 0.06421489941497004, 0.02581685086742284, 0.07739873633029, 0.03890662559217984, 0.0598336234238119, 0.06092612992130941, 0.01312200978939091, 0.04920039964359134, 0.03734015581768848, 0.05212527354277911, 0.027306566292780544, 0.020213386930164792, 0.035999701133057956, 0.053669978759341666, 0.027399950495530522, 0.006428337139603232, 0.03945749260545258, 0.033296261117943836, 0.06200530648892445, 0.053333382708050554, 0.021633587537273284, 0.057919242479387796, 0.012277848887137108, 0.009301186486658071, 0.02484613702812743, 0.03625518379492625, 0.03564495262840102, 0.016701524972074454, 0.03066159664623199, 0.055426189360479196, 0.04678332712501288, 0.01621386212777467, 0.05496097097714102, 0.05569203336152339, 0.05979429246977933, 0.030724421601682424, 0.037043729586707014, 0.02321453445831374, 0.017520716196046244, 0.036725718828458945, 0.014148828077821002, 0.008180793431106835, 0.03813059767708182, 0.04053688367768642, 0.04741149240984552, 0.05736261448492447, 0.008474412907455719, 0.046248149592429406, 0.07170395279723792, 0.005556568343778171, 0.03525444696987829, 0.04475993186896367, 0.030252467390270005, 0.020951667778013695, 0.029229477626241507, 0.023747934666912884, 0.040395341272796356, 0.04850453133845041, 0.05740999702304121, 0.028812095688115207, 0.02368255672345479, 0.020114264728861953, 0.0410244028805004, 0.023392941014120178, 0.07536140976533776, 0.029663148508857817, 0.018331940105605512, 0.01745386353333391, 0.0898358137196591, 0.04041198453295135, 0.043151124245336944, 0.033887749943401546, 0.03984041782396455, 0.10071944865968921, 0.019128853492739222, 0.0808051233029654, 0.021137723721744075, 0.04587657396651564, 0.06784404943426771, 0.041993232143502084, 0.01739053295985345, 0.004411495765746241, 0.005870147762189229, 0.09664494874736956, 0.01947967388156441, 0.047697400253626614, 0.01946396141823742, 0.022930244975272688, 0.007482132735481907, 0.02820568538511232, 0.0710812152453488, 0.02435719098655447, 0.03271365891240778, 0.12000240265361725, 0.02330594789987851, 0.02540050314799432, 0.021539408518301866, 0.00895875093016413, 0.009183295131210358, 0.07086781379316123, 0.00869444580823784, 0.05515144724819449, 0.03846499122559063, 0.03716828782231577, 0.10730566742319254, 0.016481690296542742, 0.06590410030537075, 0.011216755824974708, 0.039133709374695055, 0.025149913872742367, 0.062222182149848634, 0.03934881920295377, 0.01655002150894894, 0.08373740910282058, 0.020413330132742564, 0.06870192235275623, 0.02981048636889506, 0.03810565002382763, 0.20118106276758257, 0.14218303825586073, 0.15922746801328275, 0.13185529969632626, 0.14468198642134666, 0.1643795471998953, 0.16640801012756365, 0.1684681584517802, 0.154402983344851, 0.14710072518116044, 0.14117295132769694, 0.08211972252015146, 0.13725818074758978, 0.12932190821776468, 0.1299280216616969, 0.17658335847720025, 0.1518952558117528, 0.1272790964632746, 0.1535534684456164, 0.08451753941875312, 0.1463913584067937, 0.18269022836560206, 0.12846082539087342, 0.17812167835091391, 0.13858323706494224, 0.13385956956734582, 0.07942000569234933, 0.1824284714436339, 0.1399518531416693, 0.09267953209458821, 0.19803965794703654, 0.21647674362024955, 0.24919257439192266, 0.11411542298212168, 0.15763193669338382, 0.10915539437724699, 0.12268316646617268, 0.08616463611683539, 0.1512409094721079, 0.10012297260184443, 0.10559146908382255, 0.1715654212861292, 0.12259403979706189, 0.14856853432232334, 0.18402984035351586, 0.13805220023758952, 0.17492297015363173, 0.10878722784259628, 0.14952073564692853, 0.2526580956914733, 0.1268870739506618, 0.2094820544363991, 0.09792174152549236, 0.211234679746051, 0.16605344931444815, 0.10237480378559521, 0.18717050972965457, 0.12061815348363693, 0.18233261852254792, 0.16291418954009013, 0.13269153063095387, 0.3147121368637008, 0.23101925279103944, 0.11236193199311534, 0.12768431100994349, 0.12496565648865317, 0.0949262994371595, 0.10493398944456732, 0.14979825865837837, 0.08077817232978922, 0.15362302922914106, 0.1657782705320466, 0.12480649406150465, 0.21428729497617294, 0.13783962616036016, 0.12167067402192663, 0.10270343252247381, 0.1909741515954656, 0.21208736624929214, 0.19340822743552347, 0.14558911113248718, 0.08315306787769641, 0.09531769375767439, 0.2342648455692876, 0.1054456672300735, 0.11164477410455866, 0.09491721363437754, 0.21242893421121184, 0.27628633103543715, 0.11456688625677941, 0.11104881132562315, 0.29325324801668046, 0.1345282111076578, 0.07281867967497918, 0.24944936706414148, 0.19173657761946802, 0.12249611843858035, 0.16261248879374998, 0.17524520205634256, 0.13578689356725063, 0.17201385851348602, 0.1321421230151769, 0.2864373943978741, 0.1312810708318026, 0.17520999265534265, 0.19480123575175964, 0.14301975948675988, 0.08283153311499665, 0.12731892537445794, 0.056720471925913334, 0.15732491929684916, 0.1539337851347462, 0.15397130812127746, 0.1582876007042585, 0.07934698985228616, 0.1283999520444101, 0.12391250775826555, 0.16332490459805535, 0.11094528986441513, 0.1847804226582089, 0.1496774006274439, 0.11260160260022649, 0.12884993676937398, 0.09173705242574216, 0.09685977512309629, 0.10805056535548742, 0.15168920880363834, 0.19041147533684008, 0.128050861099074, 0.29326455547444286, 0.14557668518635536, 0.2048100059431407, 0.11817290042076381, 0.18568895697113008, 0.12334575591188286, 0.11095259068233353, 0.16111092581864328, 0.13844770078937854, 0.13582582615556257, 0.11029272084875454, 0.12297727528118318, 0.13858525953706236, 0.12560143285701353, 0.15516669639656622, 0.054005161378412485, 0.08644736086529109, 0.10951874221885398, 0.12254218330546734, 0.17882349149834725, 0.1934294940363015, 0.11870396789163352, 0.24478880988974727, 0.10760726857810252, 0.1028948242685968, 0.08016705633171144, 0.20779082341299904, 0.10122822297196235, 0.13377597405304834, 0.06708150849707666, 0.18691903370763027, 0.09478816612353248, 0.17221092697112791, 0.2379683290998782, 0.09398816348684412, 0.14181897795248416, 0.06493028764042162, 0.1784142626509551, 0.09022002979632347, 0.21038833645082292, 0.16040284607198932, 0.13446090262263052, 0.23529100502210282, 0.19100287989262613, 0.17831162219086003, 0.09579138890389474, 0.13659945238501797], [0.041530365650091446, 0.029193471493800322, 0.011651690752666083, 0.01065873163526938, 0.03568671591159317, 0.022660681617356116, 0.10718453360060531, 0.13558544308668183, 0.05946080290502118, 0.08656179907942012, 0.043604970053439183, 0.03058465460555688, 0.03295643600605188, 0.0913261918110713, 0.007611998045186122, 0.051959384863655415, 0.04313156985106968, 0.029011814809975126, 0.02244272768767851, 0.026826326840467034, 0.06710240737565103, 0.021927070075405702, 0.046830491328071204, 0.031211544353995594, 0.020265312369672522, 0.01838446309369418, 0.047768615787067724, 0.051225614358460715, 0.013709354079178265, 0.008206351081870737, 0.014719791492567429, 0.0677484952874722, 0.05395274947307283, 0.029696216694109386, 0.03213220583875814, 0.06925214968261219, 0.037857399231964545, 0.06483569876441071, 0.05311798176638061, 0.049925279698424765, 0.026720058954050465, 0.07107598286482596, 0.03155024906229829, 0.03405170042007681, 0.06257494265634207, 0.03549605577943787, 0.05826457959389495, 0.06953518852711686, 0.0008084990904242131, 0.034841709439792944, 0.009298534864830154, 0.03647364142741408, 0.0208447678690596, 0.08557734545320274, 0.04964439356098733, 0.023941316326419194, 0.030752828141914743, 0.043339302252617576, 0.04754524753098527, 0.018797731139667092, 0.010203508784123247, 0.03194831026297423, 0.07291912912361084, 0.04635819046187305, 0.018906144072271643, 0.10675142579261335, 0.04513684712770966, 0.006335603153978985, 0.006485809534487705, 0.0392359821125865, 0.03693012640841546, 0.03340872282522821, 0.06396138559906714, 0.0324764168040166, 0.04218516398161169, 0.07142791599636117, 0.016275401970732118, 0.047630957447953766, 0.016661450912755345, 0.029969658372142625, 0.055317531279738874, 0.014318294387551085, 0.07074897823434684, 0.02894749981351197, 0.015363992912875069, 0.04515092782375794, 0.009314762522286225, 0.07392043668416239, 0.04320209207493932, 0.02186303853147453, 0.016970287768110152, 0.06048678998805343, 0.03383759033655928, 0.04263474651041531, 0.011432106013319666, 0.05851931532003707, 0.041805126914574255, 0.013168188611856632, 0.019453678603073763, 0.05962941502671569, 0.031179824483490763, 0.009236584207223309, 0.00924608082465467, 0.04030480883234451, 0.016251850512719924, 0.038863023697969415, 0.11482612274947668, 0.01806871229482274, 0.09322601325449445, 0.022838505946340102, 0.08662320868743044, 0.019992479731539087, 0.09045548691985109, 0.019500358255519983, 0.0877567430237128, 0.04810829151181444, 0.02563273121092108, 0.011450484462623155, 0.03474373062471709, 0.02315167885934634, 0.012985178825235175, 0.0289235940398348, 0.014472958920974166, 0.026594903169860764, 0.031020047270783016, 0.04518682670388972, 0.015910185832199792, 0.07801064905980903, 0.023613961210714716, 0.011579588472452617, 0.07727131292584442, 0.040827748110337604, 0.08060456914526802, 0.04308351698601919, 0.01959624565056255, 0.0129883331922634, 0.0500827988669757, 0.05914946477259359, 0.038976653689338316, 0.06093681301741351, 0.02006784363109018, 0.032537198219929016, 0.039495034744181944, 0.020267555092070854, 0.07428246685453961, 0.007644759795267977, 0.04548031881812119, 0.039660735731764186, 0.06198739535325478, 0.06532863037840975, 0.054866305492337675, 0.05174761517874656, 0.01511894532614538, 0.03649935516859255, 0.1131301113374291, 0.07422118748147642, 0.016736535190214074, 0.019071448609353076, 0.012899543601839293, 0.03062198607010707, 0.05406023160884938, 0.009048342040079016, 0.011845846160975917, 0.02956917250318633, 0.05652933681924498, 0.05193188230717375, 0.03996102304588403, 0.06219027458780235, 0.026104091704192183, 0.03924233681191841, 0.06702259633569949, 0.01636672156652616, 0.13936133724787544, 0.06211709020839584, 0.04458269359724176, 0.025734207217371272, 0.013838314447521925, 0.03708428628141842, 0.05703181771922016, 0.012817503246028098, 0.017268753708190015, 0.04216675105835161, 0.09949755374222033, 0.03738526307467011, 0.05336312224127112, 0.03358275118854738, 0.07288231093796992, 0.016682280843416532, 0.026272573590939565, 0.06852013734920372, 0.011455627785424792, 0.007021986333007414, 0.04475274596423392, 0.033506077278645775, 0.06802852340643445, 0.016863521924542806, 0.02764956683911864, 0.021914071478550474, 0.053073878084579786, 0.06049209514692907, 0.03305607723192342, 0.03135164651358801, 0.061021921555361444, 0.03393136332893083, 0.024534936791526216, 0.026195652617682374, 0.012723327099886394, 0.06095873462336679, 0.039970763853841254, 0.07045991793875733, 0.08551719222938822, 0.031520270126601385, 0.08033967892368955, 0.03666897469590749, 0.061102092656637394, 0.027353215301709793, 0.03261670282471084, 0.0429628543075054, 0.020886550304449854, 0.018090733492206183, 0.05639231816354779, 0.028610972710134044, 0.08012183416154116, 0.02113626240902851, 0.03129359620112566, 0.04452830901549709, 0.01606694753131559, 0.030060889867825374, 0.0753989480736275, 0.01406231951419144, 0.038206988134451454, 0.02750111049071195, 0.04805035228210111, 0.09702150394479114, 0.03703534858481538, 0.03718899517890908, 0.043521995070360364, 0.012937055097051687, 0.03452258785405467, 0.04729044285692996, 0.04741824164445843, 0.013133280857976888, 0.014855221473431636, 0.06529260892421007, 0.046921644299741716, 0.07134061261651016, 0.031557237699387536, 0.025187662855211287, 0.02418088351166056, 0.015557003977348008, 0.06844987176478871, 0.013034723646518205, 0.008956050470231042, 0.07999438011357862, 0.027071193438924612, 0.03991836727026009, 0.03253185858709678, 0.026715249837105794, 0.025668076592527574, 0.020700046199283773, 0.085735963957925, 0.008622039008074471, 0.04915017874971513, 0.04687586671582634, 0.06330905024022346, 0.04368630177792042, 0.027343418952378056, 0.00863838636676871, 0.08675869899771868, 0.050210088206034516, 0.0450465445136351, 0.051576099583819035, 0.03262741273389228, 0.025947263929992918, 0.05059583645854747, 0.04231108585372568, 0.037059671876411286, 0.05453089304688958, 0.030364597764527126, 0.061039055111787976, 0.08215707696733937, 0.06166874491158993, 0.03555265818572333, 0.06235756520782748, 0.08014296286649282, 0.008376609334992546, 0.048215976660890926, 0.020919921094431512, 0.05931506999918531, 0.04278666557623975, 0.051744696383755055, 0.043851213694940654, 0.03672172751037344, 0.015091894761539035, 0.03177051657750722, 0.06671219283053953, 0.04276809177451557, 0.024971606908366088, 0.030114037217572335, 0.06938492804164849, 0.03421919022296225, 0.048993647834586526, 0.04328726956080045, 0.07930774316792527, 0.04633907656816225, 0.012911336567823686, 0.12338233661026725, 0.0183169937302028, 0.04324986531789746, 0.09983372078427385, 0.055398338233991984, 0.008317832196612031, 0.05548217889642524, 0.01597893743535444, 0.013532015258416295, 0.05463142293475328, 0.04662508400337351, 0.06257418039885741, 0.04591465236679201, 0.01339523983563507, 0.052712096892777956, 0.010242853144694482, 0.06726246612567095, 0.04782172866285809, 0.03795195746445849, 0.054354654519908854, 0.010721201317444926, 0.04462459477626028, 0.1094515256643776, 0.011984724495109293, 0.013772383963148442, 0.042217266896078666, 0.03498572247823881, 0.07522665489945682, 0.051519761477867444, 0.03852237504155886, 0.03293340740304801, 0.03360396033273109, 0.01565876822437971, 0.020905932328934153, 0.0386251840409973, 0.05243332132757191, 0.0028852389040102643, 0.0178245504972555, 0.01942543102608573, 0.04540641814650548, 0.04892639297571394, 0.01764971582639602, 0.08650345382310691, 0.08727962346447092, 0.036825892485437856, 0.05990520667945666, 0.1738018464417227, 0.12984122389987593, 0.30507383147074335, 0.1353618679868598, 0.09646805138477395, 0.13202020778290688, 0.23908038233076376, 0.3226216269596931, 0.16819961399080294, 0.18861415645768567, 0.16682517564585134, 0.10821881358541789, 0.16955903701243863, 0.21878959370716927, 0.09830603421094919, 0.19193168489202378, 0.15385464825216802, 0.08603469994399818, 0.12466921876635283, 0.08942329835507179, 0.1291856211760352, 0.1296352228570369, 0.18405571880359806, 0.12964936484011913, 0.10814051173867718, 0.12375003583128415, 0.2763606109205754, 0.14716100097904283, 0.11171919188552326, 0.13004017693381156, 0.11223918938588713, 0.1707653956668031, 0.10082247982462568, 0.1688645783090784, 0.2442314962465917, 0.16985379700218478, 0.19013833434831715, 0.14471903443336487, 0.13169785330612815, 0.13645156677211487, 0.13307253679921552, 0.19276744085213832, 0.11081120915590756, 0.1647136534654325, 0.2202404416616886, 0.10016289344357868, 0.18556451364870996, 0.10272322823443722, 0.1344889414406592, 0.1943835952589589, 0.14167985638543484, 0.06023247177983004, 0.1179633753734731, 0.1468894228098854, 0.12006712176146046, 0.1689298490002271, 0.14804451486035702, 0.2248083941277958, 0.11854663641462404, 0.08720083132145867, 0.10497034031657443, 0.14936816157592883, 0.1250743720259878, 0.10454130809633963, 0.1109830120338067, 0.184321949679044, 0.09307451936746798, 0.1524164560701578, 0.1691083781301014, 0.1722778217686761, 0.12687794218260434, 0.12051200434084862, 0.14242438659552606, 0.10183177768222748, 0.15217533755686977, 0.117288988173729, 0.15471510288696136, 0.28505368638903866, 0.1722503651774699, 0.10060466570599426, 0.11138136243267406, 0.1762670867385403, 0.11229852289562264, 0.13031268973023663, 0.13920159259390447, 0.11471208290106828, 0.12905063648377696, 0.15538546046422375, 0.17330632545053962, 0.11216133953102174, 0.09542537507631126, 0.12131536244264535, 0.19554735942473336, 0.1783502789875192, 0.14055202174330914, 0.15025837106570122, 0.1486272473008402, 0.11785361795656144, 0.15161152748811632, 0.10230334310401833, 0.20845923512693376, 0.1386123637278234, 0.07391616957442415, 0.22512340948225992, 0.2516108534989819, 0.12063087820405922, 0.16559459329132112, 0.16865310739846, 0.1447528955196181, 0.1345789108064867, 0.17169715776558847, 0.17513664739747203, 0.21027884716468476, 0.21592454744442818, 0.13711873742361225, 0.15963885722862137, 0.10151047274590501, 0.09969553384449213, 0.1485522013277777, 0.10768258268193853, 0.1478387436438953, 0.10518136689619673, 0.09406685603842621, 0.13857997353038481, 0.1185074510172971, 0.15120968372831423, 0.12917652005149474, 0.16328172788264292, 0.1339250547631133, 0.1558745616386014, 0.32768559071325487, 0.11223856885466846, 0.17697067720995796, 0.16152482780237354, 0.19737538310789293, 0.17301911908772685, 0.11396878609253515, 0.15618712551170782, 0.13506266468715283, 0.1460203113815477, 0.1793200390473489, 0.2164316516850264, 0.15256080235685074, 0.08422914561965773, 0.16897809721769827, 0.12583128987781464, 0.13809237388833878, 0.24435547991625725, 0.16511180468143957, 0.21971508920673402, 0.13362084124838153, 0.17948747522407965, 0.21010571129379735, 0.0962512331804441, 0.18996038744526525, 0.19464377403980304, 0.09011923560812589, 0.21038128844191953, 0.11873661089808711, 0.21429736137149796, 0.1357698710935731, 0.11264037431007433, 0.14221031098596512, 0.10718419652191863, 0.09942766354088822, 0.1361441356881011, 0.11381769823210855, 0.12509172391747275, 0.24061381456352052, 0.13529521833744743, 0.14655003053767068, 0.11049087715124893, 0.2195550840828688, 0.14506869228376498, 0.17717920634294712, 0.1637966462200688], [0.06931559708450111, 0.05608951042015707, 0.028557082255100532, 0.0501241063278529, 0.06697190429774985, 0.03299431522346793, 0.021764318526331938, 0.023504328283090747, 0.04098899046620054, 0.047351404303504575, 0.031590798096130454, 0.05806089213658726, 0.05483317218961255, 0.07544382550423184, 0.07412523496896029, 0.01394206765032704, 0.056150475697171305, 0.021747592911725084, 0.03665949435784452, 0.05048845008376145, 0.04871736205513439, 0.02160131416824316, 0.01845200906597799, 0.023493476647643313, 0.07179834249038851, 0.056481847028818824, 0.06791713422224407, 0.00883369186457487, 0.03751450593793585, 0.07973563391715288, 0.033631788476580576, 0.02946042057667529, 0.05613912227413347, 0.03931939376578216, 0.028071690861496235, 0.05674571069257875, 0.017839627107605338, 0.03364354792621828, 0.03723537414184502, 0.06794908008868657, 0.13281975842771993, 0.07016589339341849, 0.021138982021159703, 0.034875329208349994, 0.01715170121901939, 0.11931178205075765, 0.08260329253971577, 0.03164820489473641, 0.05556003258173024, 0.01350401953283337, 0.033482926101574016, 0.01249393547749928, 0.0731559728662814, 0.010318609664306767, 0.007705823706102468, 0.04719817522732962, 0.028529606511696216, 0.06092606863427547, 0.013198685614512333, 0.03221861672617736, 0.1121398890691419, 0.014825233919245583, 0.030310241911079616, 0.01419793431376738, 0.02175872033882526, 0.04931014173874452, 0.027293479595814022, 0.045463847927749164, 0.037022880503847715, 0.05478781595405552, 0.14045875819940723, 0.04236720179417922, 0.0478414707486668, 0.01515581043467166, 0.03598563575876817, 0.04465886954999259, 0.04498439946121747, 0.051635187945418784, 0.033351411787612785, 0.06038003946624457, 0.04317581908957612, 0.047539804476283254, 0.052593119607697573, 0.03494972400667687, 0.03219253909323485, 0.035443023342879555, 0.007981829863462237, 0.0222619807332634, 0.08268668887115295, 0.06955706033735506, 0.049051813060237516, 0.05023188723791992, 0.016028427672872863, 0.03382682297078352, 0.011879324203266973, 0.05474111523419138, 0.06064837325304266, 0.07067331173006566, 0.03674413175171903, 0.07359674155351616, 0.05830989369461614, 0.07164634298533201, 0.05629502499716417, 0.07933527636792391, 0.005700372144459717, 0.024098722497001294, 0.08448911755676232, 0.04235808151744066, 0.09686634049660738, 0.09017559669671521, 0.032150162939703276, 0.03026785618144899, 0.008415836867155328, 0.0938693585715467, 0.038267758059045004, 0.001884733820559397, 0.04936302861859722, 0.034350233392850045, 0.04077432879937753, 0.05759637089326017, 0.021441736138395725, 0.05391400840674197, 0.019168253394684965, 0.008087343153273387, 0.034865251321706085, 0.07089576068063898, 0.048203807354213736, 0.07821393049051685, 0.07431540863528367, 0.05389194507452269, 0.09005889852320956, 0.020122716593886578, 0.025015440544173605, 0.05561308417048666, 0.06410630262126366, 0.017138434491390665, 0.013510224845020041, 0.10501329486648883, 0.10111129497207942, 0.04821342558810308, 0.06979117680701517, 0.05755427436182096, 0.06646403396922736, 0.07340776298435465, 0.027252275556806597, 0.008385136851199694, 0.05140347316140129, 0.024869171376790733, 0.06588815801566647, 0.02381344667575773, 0.035590928107980764, 0.04576990388393883, 0.055972187884993134, 0.03793935914854369, 0.05206931465035004, 0.034274773732308424, 0.10793944430207053, 0.07850606279868273, 0.029443478542229826, 0.020695279217174938, 0.035228691093863986, 0.040149419388223084, 0.041220402645487944, 0.05164757941759402, 0.01754731668399707, 0.07968040663869151, 0.04294838290661574, 0.014284514698139844, 0.018659852550274903, 0.016624061991610838, 0.02558914080802952, 0.05963066758047189, 0.05072035255932039, 0.0744964275509119, 0.005724117997282696, 0.05690501484599325, 0.03657350481878366, 0.04258292066233774, 0.042037749512782024, 0.047747038920680364, 0.04217947194833429, 0.08194254170502387, 0.028837430215771162, 0.013751804926282456, 0.05946357231286745, 0.025460167990757093, 0.04840179128692516, 0.03415958858245323, 0.022938589587987914, 0.0727971526043069, 0.026931660099615975, 0.030795786522268772, 0.10103668566913375, 0.03720880238219135, 0.006448205629919446, 0.05666309194038472, 0.031520827455566294, 0.014592025263775742, 0.04242014996106586, 0.07584363913103458, 0.06702909276129738, 0.04160242388024927, 0.08203693139817446, 0.03421288914978504, 0.028887676007504907, 0.010081458528856597, 0.022582243790008852, 0.06421622091663942, 0.0776330826263274, 0.04678135061816824, 0.02327727897453212, 0.03396528187177835, 0.0564498781797386, 0.08257346873682353, 0.032424908882427605, 0.03814504609533376, 0.018733603834745385, 0.07754806984936999, 0.036201458048796466, 0.012526473146863283, 0.040735039980180805, 0.06280672638827274, 0.05690483098489143, 0.07166086035149713, 0.03303868703604226, 0.059459707399289456, 0.08236522305636637, 0.004304973155094852, 0.05607587405510488, 0.03846525552592451, 0.042488642051936164, 0.024779518022232, 0.046892241845207835, 0.023179692779517463, 0.05044490564614535, 0.09895743877296487, 0.045398167379560976, 0.08423661497691948, 0.034715086597228245, 0.04346612810848221, 0.02760334683942699, 0.017301314360191746, 0.0604762256355776, 0.07843532990063391, 0.1080180602448602, 0.045636761633138505, 0.007656948254143279, 0.028633327155764547, 0.022279347946506836, 0.031423934570123116, 0.03648717054015687, 0.015288367585819817, 0.05347905432685249, 0.007547288992246914, 0.008239913393833466, 0.019818487757396315, 0.0140987690200188, 0.04545098148106087, 0.07888967366588694, 0.031175808267547723, 0.009852909603186194, 0.04066817199570998, 0.03019463732808588, 0.005856403187217732, 0.03280967271195785, 0.022443974495775277, 0.045451261103153236, 0.06344426475885896, 0.04782684613019229, 0.08181383893374475, 0.02505033010346515, 0.02576754161817653, 0.06784011174233691, 0.02599988650951174, 0.047942253445545514, 0.016109593730840473, 0.032176305690119346, 0.015280570725970452, 0.04453238077281464, 0.023208103150189407, 0.044324813080170465, 0.04020198068070797, 0.03714832357100902, 0.09038130662614301, 0.021823692255683487, 0.07587506405768857, 0.042854740149191314, 0.03318623940069829, 0.04158133731013344, 0.07249145287900202, 0.020004995693002018, 0.06188619513845733, 0.02655291006029133, 0.04295500573672114, 0.011076445864032836, 0.02898877280043258, 0.005356230127114442, 0.07208470615648455, 0.01361443865818963, 0.05523122764462906, 0.034083814825862646, 0.1805811883100579, 0.037653416830806, 0.028507177372493094, 0.0754240757575439, 0.04837133163105577, 0.03745750133549014, 0.12198661634277914, 0.035164454621413065, 0.018927563890634526, 0.04639326962792585, 0.009604009551807277, 0.057934755759854475, 0.05452209835751884, 0.04920958886824308, 0.05014805423636591, 0.03553823658054875, 0.08038737555785526, 0.07717130780820886, 0.00850882270418468, 0.017665261665599483, 0.04157819251920428, 0.05336631682791537, 0.011256058050710107, 0.05114703672006727, 0.028780484985139583, 0.032991783302878185, 0.060491681459449956, 0.06509911809717456, 0.06456893162741777, 0.06405033606795535, 0.03378812786972812, 0.0163075604265736, 0.10507440570020869, 0.025181239207966194, 0.007626402892187359, 0.010763560233998203, 0.030534240274479797, 0.05532521514161941, 0.021119668944588593, 0.05897785724711515, 0.05624255946566982, 0.03034022084677652, 0.034671266367959405, 0.028476999253935875, 0.06955182795683224, 0.10479278411836394, 0.033439626812093684, 0.048939830157905824, 0.03623771699025266, 0.030524694818943262, 0.03496467038207958, 0.14326346737723197, 0.229203823593355, 0.1935802601397999, 0.11426503229285441, 0.13627216430200687, 0.12302641982152579, 0.18750332896747898, 0.15607136962634904, 0.1305726999717374, 0.11038122698664667, 0.1507098113577212, 0.16251438357416662, 0.1025397425156928, 0.11917245363996876, 0.12665800600042268, 0.17158676449569965, 0.20935198802861477, 0.15379064926697364, 0.04395352090678869, 0.17431212228632745, 0.17676625430824297, 0.09422080140681037, 0.1273554141422914, 0.13928958545288733, 0.19092639367426598, 0.13183282267662788, 0.19803009716974151, 0.11127454679339163, 0.1454308833326063, 0.11269609954568649, 0.09010175348169382, 0.13990752729437045, 0.12054279341452545, 0.10916097915821499, 0.16354008337422726, 0.18291757261801153, 0.14020561210570798, 0.18062033540298864, 0.18350470240318006, 0.10910941378003168, 0.2066985812158354, 0.2610319576436474, 0.07639086339622736, 0.19180756332653184, 0.07209799778197082, 0.20667303984443988, 0.29397769140139707, 0.10003428260285048, 0.10769664805622832, 0.14472186895868472, 0.19446663918995089, 0.08881106386862456, 0.14051675105527525, 0.19203506079652619, 0.06651158504668744, 0.13868892655497597, 0.10609760805363617, 0.18803531574385782, 0.14649652695703894, 0.14206293099109205, 0.21300558391357624, 0.15892167635742696, 0.2153425657701108, 0.20470466885355212, 0.10524593278645508, 0.1639093990407644, 0.13809634222378656, 0.1641274429857731, 0.3520466044785515, 0.12043419279037945, 0.3366971136100831, 0.11888785197609857, 0.11378779015954464, 0.11667329096986402, 0.09169706263609471, 0.1256800334780447, 0.14446420294623222, 0.15870170187084906, 0.146971853870538, 0.12614030676383164, 0.23714558131271796, 0.1865537936288503, 0.15258675741572536, 0.23044356835945962, 0.1609769523624451, 0.10836002657250052, 0.0943722723111991, 0.08757825219823469, 0.138532399470287, 0.11797288252461342, 0.1583511553584568, 0.13262543256484693, 0.1556506341383342, 0.1379189162605232, 0.16805954247472749, 0.11919884536896022, 0.1939124511855264, 0.23245200574878724, 0.14663128182291985, 0.1752567699839992, 0.08924951130944876, 0.1712469738577643, 0.12784597088372515, 0.21999222917422173, 0.12977984493538258, 0.15247092492157413, 0.10446785558615962, 0.07673834555692251, 0.23067454386863018, 0.22404414481453358, 0.2941731663961565, 0.15060819745544465, 0.13012133628850983, 0.2970304904926208, 0.083868203294133, 0.15617675268121306, 0.17327664720435298, 0.10895392091404046, 0.12251588350702679, 0.12823079216984973, 0.13647341559971535, 0.12971117281385008, 0.118466557243899, 0.1824147431480308, 0.08325107350584962, 0.19513788542920546, 0.12640139718930568, 0.3062920951314511, 0.18345256245905356, 0.08804542027534017, 0.11315493258617579, 0.19955357025948264, 0.12401024525564526, 0.11687876341203529, 0.21951570716356078, 0.09118024440061662, 0.11155139564746812, 0.20287335099231815, 0.18989116374042728, 0.1513637593316455, 0.18790282849823275, 0.25540517973563365, 0.22299259720790773, 0.15202544479360505, 0.11242504997719681, 0.15619193654387228, 0.19078754789886937, 0.1101418934582222, 0.13700967714671167, 0.08879021861620488, 0.14759431563077435, 0.16501489455901808, 0.24524608777175028, 0.17791949242593783, 0.2576500165366358, 0.10354935446934355, 0.18635217460893816, 0.2385709645046342, 0.12533530923387698, 0.1113714722375716, 0.178324431180954, 0.07180670817052165, 0.12699795751682214, 0.09654469082071897, 0.14104069390844914, 0.1564974830515923, 0.16973652426273594, 0.08891979472771769, 0.32485805211528657, 0.18502486599308832, 0.1392347948445428, 0.12626115713388691, 0.08234118321730245, 0.14135691968183364, 0.1558805064808938, 0.17246080953026974], [0.03245328477914295, 0.0351402998691605, 0.056325059474235585, 0.05296883976928169, 0.04552371386859206, 0.03683958630708437, 0.06879274207617968, 0.015831187803057895, 0.014887847242906932, 0.07979672176823502, 0.014334796879049993, 0.027193608543565197, 0.03615574558235465, 0.047016884350488265, 0.04177606153872706, 0.031486859117003704, 0.017385610844939947, 0.00803241704312724, 0.08567009571819537, 0.028397990691085017, 0.01596151085029687, 0.05271650955922181, 0.03260493571419389, 0.05422600537478443, 0.04908843206301813, 0.05727274854096675, 0.05248860989306724, 0.012877548259923296, 0.019146720578353253, 0.0241306702786636, 0.009338461452223843, 0.07268642991661065, 0.0782409274289685, 0.11050211566109812, 0.015989272919062887, 0.02510887071219904, 0.019083114213220054, 0.04569746260981887, 0.06674541806381556, 0.07560166259927135, 0.025092604750346754, 0.013162746514764526, 0.01785377866678661, 0.0366580770951846, 0.03505658561123475, 0.038725487932923346, 0.0563770538616565, 0.03904612637275169, 0.07691136651462124, 0.051661706078917756, 0.05053403231525614, 0.0660508674299044, 0.015006399349189334, 0.027619827305898074, 0.06826075529980083, 0.045179717407952395, 0.008634571248905794, 0.01485379559228257, 0.05122473335734779, 0.05284063112471373, 0.016937125737087864, 0.060847939157317725, 0.04978238897878797, 0.029926686585249922, 0.09051861256481179, 0.028378263927034797, 0.02267369553596983, 0.04362918609272569, 0.044543017903643276, 0.07583682094850848, 0.018792772635577187, 0.011180938341684881, 0.10118352174158059, 0.04259464563801885, 0.06200571634596395, 0.023288565364876584, 0.016713657889575247, 0.027654000572980415, 0.022621477067831065, 0.026579273060985634, 0.045580948297415054, 0.04920398493507697, 0.012118132961463305, 0.061485852910986835, 0.014271100498585692, 0.037470298834265246, 0.058232725658003366, 0.016403610615300077, 0.08518214367570416, 0.0631532432781833, 0.04403037484735251, 0.01093552015992182, 0.07450546738841841, 0.09239092379087403, 0.040974863804876804, 0.04633392462687147, 0.028077126255319006, 0.07377362359435329, 0.038255692174237584, 0.09547751502043779, 0.07024041076581325, 0.08015340464490076, 0.05805762860202982, 0.06753695542894064, 0.0595213353423582, 0.04919455439272908, 0.07452150926955285, 0.05810575807587274, 0.00540920558588339, 0.013557156348871368, 0.03626475606354014, 0.06613863812338922, 0.07248868730159537, 0.016953133144265702, 0.04216827557332093, 0.04088430455134761, 0.024696445362942836, 0.02250245764791485, 0.021351402880804195, 0.019513548374356284, 0.04817669167213383, 0.05160654008749032, 0.03431680131583445, 0.036478617168482275, 0.013755674627909978, 0.11714226701447081, 0.09201858973791523, 0.045695830842540155, 0.11084153857682982, 0.03334851597525901, 0.07643819996906866, 0.04950699186132801, 0.0454406775984793, 0.013052364736194573, 0.02575517695907864, 0.11536072188567732, 0.07875568488793028, 0.10462268961653595, 0.053471883743881225, 0.116325149973554, 0.014038563127659503, 0.0679880126769985, 0.029359655116774866, 0.006896556672384783, 0.024274028311934204, 0.126719132155901, 0.04443340604343722, 0.04524302691401494, 0.009871345509084003, 0.01751699875439367, 0.03728926842731815, 0.035758168932290814, 0.05755172711947272, 0.06183400922905534, 0.02612077135352358, 0.05105663068412293, 0.04338892176747323, 0.05736154196183047, 0.044303504344556606, 0.056465345494929826, 0.11898531368182552, 0.023224679377651023, 0.0989401558293931, 0.11856159811178524, 0.0721982020824667, 0.079830008288545, 0.03400761206003447, 0.02989313193416644, 0.015349810710176827, 0.028869127103638266, 0.018403793407243588, 0.04915323161009339, 0.017728088536269723, 0.019427821220409487, 0.013386829147836374, 0.04304284154767952, 0.010383112352311371, 0.025303807530191638, 0.03979556337599793, 0.08721737115974389, 0.012136352447522505, 0.021616620604970285, 0.04687965502061191, 0.04097325885067544, 0.047273841731610804, 0.050656319100169406, 0.024380773088083636, 0.10668378788977863, 0.04642791595430144, 0.055116889021930196, 0.060506589530456456, 0.03737228937567242, 0.023470884714756283, 0.01614413855056609, 0.021206788463337768, 0.028870521383660457, 0.013044245161807105, 0.07333058728686265, 0.019493396431508086, 0.037093636384534265, 0.03984761905045279, 0.04048742504129487, 0.012840894783186096, 0.026639177306224743, 0.029320383534556436, 0.004943239788014081, 0.009060396433567569, 0.02693260047254303, 0.02718088956880233, 0.08727167147181689, 0.025967438855478843, 0.016027230660491172, 0.008500158249761068, 0.08447358129365791, 0.04111352188873195, 0.053809100326391, 0.03857469118590798, 0.042260642794351426, 0.03359469449928692, 0.046139614085756966, 0.014173932779099674, 0.036296870469325976, 0.05773284179609149, 0.03523966913381892, 0.013548845252502831, 0.07049261457136563, 0.027259811946761706, 0.021279398276801073, 0.05006053252145649, 0.07173040581326331, 0.009565429363940513, 0.05808371006541195, 0.02484331782456608, 0.016276405545912923, 0.025815994764167457, 0.010610988078218316, 0.027502815036343473, 0.04976866068318487, 0.052350219939985586, 0.031560016683332866, 0.043268431458742394, 0.06334573436047762, 0.024229828869142843, 0.050870946293035825, 0.05116612763114033, 0.03877610336208055, 0.006743444903423229, 0.07717640995378457, 0.03855895573994325, 0.03880290877855113, 0.028223313068250017, 0.05170780925020095, 0.03328103129000914, 0.0346258067105326, 0.038655456005325245, 0.054448170872825774, 0.055792321931690946, 0.03963232919153187, 0.024469849961479346, 0.07555937454585107, 0.011936213892524042, 0.059880412243787325, 0.013267610545059847, 0.048181433756385124, 0.03535683462095838, 0.03412451324684005, 0.07286479816802087, 0.01533900120956523, 0.048731400616346836, 0.019843425834551454, 0.02936955680319619, 0.01434324204080528, 0.056483861840059685, 0.05139078674537521, 0.03699267748743296, 0.10021844247896826, 0.09332739733039372, 0.06357286793870792, 0.07820745704755669, 0.02489895879050657, 0.05718552943078741, 0.018008252635838527, 0.017016367956755624, 0.05149844125093472, 0.03452626124565159, 0.04130046649445449, 0.021703891426084504, 0.007571154067503109, 0.03890956736980908, 0.06414508582243035, 0.04111126575979494, 0.017674544736021952, 0.0629701903991161, 0.005629188212145481, 0.03444197242178264, 0.03309108745006304, 0.04722495000028322, 0.013412359985522928, 0.041289844685384346, 0.08106260545431607, 0.02383556937979114, 0.09240864340456263, 0.01709281395549976, 0.04063200881524433, 0.02567366137349558, 0.020473916196234284, 0.027065957227962154, 0.0717998287009616, 0.030935787175211216, 0.07010457571595907, 0.0174448064588491, 0.09109933785493336, 0.04015686576284709, 0.10040724484790718, 0.09017818607389928, 0.11367871456088559, 0.0653406502979417, 0.09095157481609814, 0.04545486171639735, 0.040985895470986446, 0.009032615212603443, 0.012220675745348056, 0.0703009470335899, 0.11579679445393624, 0.03657722417565604, 0.017564764336472558, 0.02865220739265844, 0.026621042089837215, 0.08168327456880962, 0.042484248537690415, 0.030268312003763936, 0.037871951072086255, 0.05492078200463326, 0.005147875279128071, 0.02570300637143514, 0.035357516439210986, 0.0699592718193608, 0.04677043003480762, 0.07650481131408485, 0.03972695254149937, 0.014436795740508506, 0.07921850924650509, 0.037241430066886454, 0.04004355369796676, 0.02754107155206223, 0.04677463585751192, 0.01084490440740821, 0.014980044966984182, 0.037303686202053106, 0.07938678811995253, 0.04837199429711027, 0.013161026647374516, 0.1280815275986829, 0.10944558848296443, 0.12033072495532614, 0.14532939200439762, 0.1470231511179478, 0.09565361565159214, 0.20256789641514902, 0.15871483261787123, 0.15123013827589252, 0.12401921614523857, 0.11080703397672023, 0.1713233068585396, 0.10833114505775514, 0.1362834870815277, 0.16505218771917207, 0.1713373569110709, 0.12351567421348826, 0.1187656762739343, 0.1435416492242967, 0.1329029249327798, 0.11575126584859625, 0.10482922692092196, 0.16319117628999297, 0.11725105149971864, 0.09654970869662301, 0.11760805613331257, 0.1551096381679658, 0.14450385565719298, 0.12301315883955649, 0.16969176940619948, 0.2007936061389985, 0.12220872821466577, 0.20045013827902658, 0.23359453395730068, 0.1631156553424174, 0.15221742642742975, 0.06595463146485629, 0.17973843030631545, 0.12251036001309273, 0.1797137775969121, 0.13767128599987877, 0.16403918965689598, 0.1347969547514954, 0.12508141237401194, 0.15970126275093327, 0.07443405267211699, 0.2203364784438764, 0.18055630577427728, 0.14576805394984063, 0.1331409024855783, 0.15546027661090897, 0.16651653414291723, 0.10786355563229132, 0.17932157122319747, 0.20779168143147425, 0.23661811445509237, 0.07410435907302365, 0.20237721713079562, 0.1624276470993796, 0.1393775629901117, 0.11703971848492661, 0.17814668346076243, 0.17472991599671303, 0.12748790138791646, 0.22698789895061525, 0.16434041542872307, 0.1437160568011384, 0.11091585676636427, 0.22618614197258027, 0.23645668440768797, 0.1192871293413543, 0.1267070509493351, 0.14069440684491588, 0.11612104116788796, 0.12449640465239364, 0.11562685316969311, 0.1985273495196335, 0.11100891346652662, 0.13282460010340139, 0.14287487693851994, 0.14382546947848412, 0.1667358804373972, 0.09564204006305627, 0.15811337698851863, 0.16042844873041878, 0.1907481403360444, 0.1519641730814211, 0.14106006061117496, 0.29811478069713043, 0.19164475432086378, 0.11322339786396873, 0.05060045213829126, 0.17207313839706684, 0.1312034508033145, 0.16981687156423447, 0.14380067887325443, 0.16395004766602672, 0.11659606930709655, 0.0970696755534699, 0.20802055785973228, 0.19096881962351261, 0.17221492595009266, 0.25408801412390125, 0.18600918172347933, 0.23951942732016887, 0.1387986763110084, 0.16383265235250996, 0.1412349278407712, 0.12542782967249233, 0.1647195216989325, 0.16995357229344307, 0.1446014859022633, 0.13905615846235908, 0.11257839779700003, 0.13075561112453862, 0.11708244320846374, 0.12645306215891916, 0.06458671252814031, 0.09232992020946357, 0.13698243506012425, 0.1202557632519353, 0.13696789471132143, 0.1239127682281598, 0.18405743484054843, 0.09631504830453666, 0.15992627809605292, 0.1397000860062338, 0.12622092985698294, 0.13324441628590708, 0.0832197328488673, 0.20264154810818935, 0.20584825426340106, 0.1168566081492651, 0.1902024712293379, 0.19141820679989555, 0.2321103918215921, 0.14719228800987044, 0.1803520514119056, 0.18230575947992264, 0.2654819785346908, 0.14031044357726652, 0.16805327587550686, 0.1351930528518654, 0.09497837043337284, 0.1526910373039784, 0.2529382080801072, 0.24781462736427787, 0.1745369231268283, 0.12443046746475082, 0.1382101062805422, 0.12561521477877133, 0.09436808947113254, 0.1318414335048968, 0.10103001304331327, 0.07736932621487687, 0.15135634360053848, 0.16655459339099546, 0.09502210639297001, 0.15417350936801205, 0.1740307688352562, 0.3140628926696316, 0.2220024438875337, 0.22565872108023013, 0.12455998995010892, 0.17256587082820554, 0.18351570342577275, 0.2447312766866338, 0.08958539489897029, 0.16296522631760568, 0.08679586192292553, 0.15261082789830624, 0.0881348227361037, 0.10286141517421893, 0.1953744227367063, 0.1643093888677897, 0.09551722901843249], [0.03127996366651308, 0.049185801838194175, 0.019819906935276046, 0.022117509957282774, 0.015209621408083027, 0.05168535138270067, 0.05633099282520914, 0.0059905303398057105, 0.001991407374472117, 0.012601353453412172, 0.05937092163930497, 0.022218962981095238, 0.04056072050345041, 0.07108154466315623, 0.03472442903946485, 0.029922105379462726, 0.02870342420083621, 0.05813956170553162, 0.07832230128828557, 0.047024560551489555, 0.014303820113831711, 0.07292617713251422, 0.019007788618065177, 0.022315890340495016, 0.05329147003771317, 0.03967205085040581, 0.09280346213809906, 0.038801353620064837, 0.043859246126826734, 0.06878883502776585, 0.08107925254491069, 0.047595690590359514, 0.12367859047146575, 0.03212399720664948, 0.04057084052493015, 0.0398175003037097, 0.024534770167402686, 0.028182139672759562, 0.017132052978981408, 0.043842258127105814, 0.06659822193004432, 0.0684947568562723, 0.07230102640366362, 0.0330538900508996, 0.05503111781792776, 0.023036457320314743, 0.04447319665022435, 0.060696479744247855, 0.007215703155980596, 0.02712377005316798, 0.013409988943397278, 0.018851579459864768, 0.03447967926941572, 0.031487462411244074, 0.03492766067445759, 0.07893862668424845, 0.022550880150388808, 0.031010683761128498, 0.03604747820645571, 0.04238055853713905, 0.01721732622583307, 0.05876111565157772, 0.07708152996436243, 0.018808295492142923, 0.08078044761092433, 0.051638336566787575, 0.010376887887926593, 0.04337522794582671, 0.0591479977142186, 0.05480053301359858, 0.006448538399361555, 0.034177909575162396, 0.02557877755363382, 0.015423581146845415, 0.028908839186413154, 0.06649474643411175, 0.03579876010095881, 0.0623963522394338, 0.019054295900728435, 0.05932666857035891, 0.011428853970081096, 0.03062862613719077, 0.05866780997283998, 0.06991097763661416, 0.0463502882649341, 0.03405734648807876, 0.028448179026224443, 0.01372873227322294, 0.023783768429571105, 0.020936066397435723, 0.03569385202060785, 0.009042537966442686, 0.022561907986058824, 0.008691112368157314, 0.04536971104361358, 0.017638860360508966, 0.036614743331747676, 0.06355199970365052, 0.034323267097915375, 0.017370524658491055, 0.02081718678856569, 0.035528951594906474, 0.02014626039101953, 0.018327148225639137, 0.06562087759976426, 0.052644746272914836, 0.03776823425845754, 0.04062219905937391, 0.09769366948955482, 0.041676707595827124, 0.0315226526600459, 0.025257250451813304, 0.027831326944813616, 0.050182336670977455, 0.04561709998656185, 0.0658472489205099, 0.020901431562379006, 0.0036887090461659097, 0.056022301526559945, 0.06333321648379488, 0.012409185085655942, 0.02225617187157754, 0.0655000425514675, 0.03890023641889134, 0.050769910787142096, 0.022840754414397865, 0.05261847711799126, 0.06930912364154093, 0.09538100326373693, 0.01794325390590295, 0.026200310432262, 0.04117950504165023, 0.04607689829783575, 0.049321529635738943, 0.029976480385108344, 0.05680405594889195, 0.04470151766473728, 0.06718938133769459, 0.04650298491000168, 0.051877739043125225, 0.022901669895697026, 0.017796188007078825, 0.049756253889251145, 0.007319138911102088, 0.017256674416843924, 0.033311690128738844, 0.057479753158986575, 0.07964781725839262, 0.015379712079471398, 0.04696988868677328, 0.04942775538731967, 0.049671198977457906, 0.03893895450258448, 0.027080811672813954, 0.08818014449770413, 0.05622780461224818, 0.01424601686472494, 0.06366887024693912, 0.04061628486059847, 0.022827378519239928, 0.050343425809255535, 0.038335403622758966, 0.04679571859718812, 0.13899189900727044, 0.04001118265272629, 0.054572947443492954, 0.08563034341580446, 0.01814630934067311, 0.025574638763622894, 0.05266764464097158, 0.03023112226547974, 0.016389847845740376, 0.03667834778166106, 0.058362929961614074, 0.05211084044628567, 0.018732671122697574, 0.026521015904783726, 0.03190254800081734, 0.05175357534279747, 0.06936566093035283, 0.030442784698079192, 0.019192812258317586, 0.07184783177029702, 0.06336480228891296, 0.06705942984309889, 0.043256783091853705, 0.08321041721970805, 0.04583908162350136, 0.031029416526096965, 0.034314851622067155, 0.05588178950992804, 0.08091446703239795, 0.015655305506961963, 0.05257215178121002, 0.08259900244733981, 0.019670770683836554, 0.022991373045970837, 0.029898969524149454, 0.09328491775499237, 0.03058306880355362, 0.04567365642757185, 0.03381220218274863, 0.07383345506123959, 0.02703027476766898, 0.01369371247898427, 0.03946413458775609, 0.030236873670571277, 0.001179196528204146, 0.0410494041599093, 0.026862530240548715, 0.01051201909450033, 0.013739775430651443, 0.0387359680157275, 0.03177672763535332, 0.031407367918760545, 0.02517516413072665, 0.022534342227323402, 0.04783816890971315, 0.061841175981586984, 0.04949268899978169, 0.08114246245954307, 0.06747555348180956, 0.021019188852439967, 0.028415767761367946, 0.01660737851183982, 0.04970841935925907, 0.04877801323609968, 0.04708719206973911, 0.04624673232976948, 0.04385502115192433, 0.007859244304258496, 0.08688783077823539, 0.028995943383403847, 0.019274090356644125, 0.018452637258075902, 0.07415672884352746, 0.013798422334084829, 0.039616302632155924, 0.06556362018830354, 0.04505423603639488, 0.005074497462520677, 0.046873717839198734, 0.04819017481960116, 0.01870520687061212, 0.05201151331646308, 0.02531531225559452, 0.05092793174328343, 0.03886412303414076, 0.07078557425448972, 0.022561710718418324, 0.049519793190542734, 0.016840160073291872, 0.04006464026808258, 0.09364557662798513, 0.01463487256138075, 0.027930744089967305, 0.02676152920861158, 0.03515601999336674, 0.0704213071073736, 0.07693670870315644, 0.0645117891291457, 0.0732277782874242, 0.03143020116934373, 0.03561724705861942, 0.06842004030101723, 0.1327944468827017, 0.01399376230584758, 0.02121550654391608, 0.11464124275071007, 0.04376388733245192, 0.02746082575721366, 0.09508943019975578, 0.06616039502043879, 0.046164872004620494, 0.034288490536592664, 0.010080764261675219, 0.08694685785280121, 0.0750368336335786, 0.08940763185702025, 0.05412842875586883, 0.058533365372568376, 0.05993871536526469, 0.07051454766863777, 0.07307801575910661, 0.03150108536975759, 0.04513249957873937, 0.0790308406876941, 0.05715333458576953, 0.12984416567750517, 0.05000668803169843, 0.033641617384649096, 0.035483472785281564, 0.00784919179427708, 0.049208497192950985, 0.024599223059692213, 0.055160716912078286, 0.05627717131808881, 0.06300846798225276, 0.01728332853094945, 0.028479845270574577, 0.03487233380456606, 0.03720550437367732, 0.021740655985570723, 0.012830464496097017, 0.04034517400507485, 0.08656756772148995, 0.05393656586567241, 0.006249194660584533, 0.01765056618399197, 0.03279389130071767, 0.05365141261849673, 0.02838113867197066, 0.011178935979372792, 0.018818168450267087, 0.04368359365710809, 0.007154336161611061, 0.05472629526329618, 0.027557586492489905, 0.07510699962656345, 0.0473654581864755, 0.01940783398646501, 0.016286322554092736, 0.05249923170213738, 0.0210783633989312, 0.0442856966307567, 0.014007817146428412, 0.02411075390785212, 0.06574069375112172, 0.003602647686362147, 0.013102544452844849, 0.016666953339271488, 0.06874035698391738, 0.015877298635220336, 0.009729752350868958, 0.03342761072300134, 0.005094078191060333, 0.09150285168641037, 0.08035112427727831, 0.012820919998170388, 0.043238205459689906, 0.03640255612892009, 0.015129491484033005, 0.05202231515619544, 0.027985316363253424, 0.00614011571029081, 0.005475553588175606, 0.015679315660118816, 0.044668334566297076, 0.008801719185055025, 0.07242314081879393, 0.03368592024931023, 0.027625852587422537, 0.15884129841241146, 0.12256724970234979, 0.24545970372855666, 0.1914913069096304, 0.07302376141230907, 0.16747682535600278, 0.13788104087354677, 0.10410002613019559, 0.19368691490061823, 0.19501307438458168, 0.16247900563382334, 0.11052597929993946, 0.09067445783124817, 0.14712914704315125, 0.1340306982878716, 0.1369383083956857, 0.22611160161754779, 0.2283964588517143, 0.22739378765465754, 0.2170030000589548, 0.08088435977697372, 0.09771522720374408, 0.25959226392930557, 0.12424457622992417, 0.21785787757365935, 0.2341705095022917, 0.2123702059109365, 0.10004588883490333, 0.11217509080926258, 0.1648429384635341, 0.20982598194912558, 0.19443913663346923, 0.17327998734770284, 0.10676817247463811, 0.20216960730331562, 0.16142566538145467, 0.10620799366264574, 0.12397138927612575, 0.13681795598278124, 0.16158847438712276, 0.13205921698001125, 0.2155365392325386, 0.12445820750848902, 0.15320888209727504, 0.3300752334537045, 0.15414015389978886, 0.23921400338651674, 0.18364993735186516, 0.11051238890016273, 0.092865017302815, 0.1483360726025797, 0.049338908340301246, 0.14186394731363944, 0.16020562439676256, 0.1884198152730542, 0.13250403827236545, 0.1907018073383839, 0.07953275085216568, 0.13670744013882455, 0.14726757913106872, 0.12137121025232539, 0.1287401104045491, 0.138846495519242, 0.06408127452877742, 0.183092730961019, 0.13843184276934595, 0.10380127482236394, 0.10893972530480354, 0.2237755237447639, 0.13529952375158188, 0.0923430432956065, 0.1536393009366528, 0.09735497435735119, 0.12869362418930377, 0.14950270193719095, 0.12682006423992495, 0.10691746002844266, 0.1489177171982104, 0.1311578838935783, 0.15433086382765926, 0.1227172114135277, 0.10654711780408699, 0.10597564685609072, 0.21557704996197455, 0.15888412272737873, 0.14139387576330092, 0.13402435507985855, 0.13674061174594587, 0.15023062336108378, 0.18835376317222274, 0.1374030326523127, 0.08731732265122476, 0.2018526460855238, 0.1465654289049487, 0.1325972864945089, 0.1521417522622693, 0.16026634452564104, 0.13994744047522545, 0.18043552435213522, 0.0717826989749747, 0.1598786887141966, 0.19316729278333727, 0.09164316068974235, 0.16259347449146933, 0.14189261432376601, 0.14657785485108055, 0.14231071446932134, 0.1695711258798838, 0.13247212304943992, 0.13872896230989887, 0.18014972759110315, 0.08930735094773193, 0.26119639075571494, 0.1444599588191317, 0.11046381892576335, 0.12841455368024687, 0.09352841114084567, 0.06304199965069852, 0.10383843008669154, 0.19279529580906515, 0.15990816777752292, 0.1155882653209471, 0.11731552545942607, 0.13780648519675578, 0.17047215253114703, 0.12902802156825222, 0.13078781746087537, 0.14424646543639322, 0.17069934356597163, 0.17772804705366013, 0.10734593300449272, 0.14598482618889502, 0.13966254769794403, 0.12243363630747604, 0.14239771141400262, 0.124671432760454, 0.11091607893186231, 0.14065837006895773, 0.16243270327967985, 0.10561773057786689, 0.1113135023643413, 0.09763335538727623, 0.26693604405849214, 0.08825034113420595, 0.09449398069972954, 0.13559809885919094, 0.1100644343081982, 0.1512414457336549, 0.2172261461495392, 0.12017065088354772, 0.0983143232822899, 0.154807600342939, 0.15963018511331853, 0.1360409436447005, 0.21651094178518943, 0.12008442768766997, 0.097419586212885, 0.20696485805655682, 0.11860709607360825, 0.1559333205823937, 0.22712066198789307, 0.15908831580271646, 0.12329563843987643, 0.18218566753691245, 0.1082026874346118, 0.20561095086797593, 0.1986287948825667, 0.06805713679040633, 0.07528411149377785, 0.20994133946876373, 0.08667737110367707, 0.09312800762634124, 0.16214126811152504, 0.14176637835560307, 0.10632205649369186, 0.12971969171156808], [0.06189924544624745, 0.03274903302231143, 0.016640823995394093, 0.007146625965458131, 0.07662640478942664, 0.06438988155775494, 0.045944878365844495, 0.04361880177091207, 0.017193202117097475, 0.018902625813479387, 0.03899575226129063, 0.05479277254292562, 0.02843522447942486, 0.023704001439675212, 0.04244085348721954, 0.04524584611757629, 0.044814848881815715, 0.03137477470802204, 0.05061721797251413, 0.017128025271719503, 0.019879246190671, 0.057856948039824926, 0.029525350358697678, 0.04880992079814596, 0.07209592934457526, 0.006356025621625445, 0.055090983758770654, 0.01102511222744661, 0.015466196702853327, 0.04460928450909354, 0.016340687983639298, 0.04202563766269915, 0.02924573784243436, 0.030948228443101532, 0.017054997940337466, 0.02137309849081982, 0.04043250036756358, 0.03251316987218396, 0.06339947925880551, 0.046717213737147475, 0.018265217677840305, 0.03176687382942727, 0.02090884920870585, 0.026637673858673345, 0.0298912282056746, 0.07430422375158918, 0.053043418428710395, 0.020668065858884685, 0.018478900667340047, 0.02611560409047431, 0.026847061010137684, 0.030009981410037127, 0.010200848543806183, 0.008417107615499728, 0.06011045695612988, 0.03990730113019386, 0.020068680582147454, 0.060467139832795634, 0.03881160004605209, 0.05151241852511322, 0.03289010811356768, 0.022958883257102103, 0.07234058718407348, 0.0423929883137105, 0.03615213347779166, 0.04284201542876902, 0.021445239075429497, 0.044263330693807335, 0.11732210615469564, 0.016419972338142897, 0.03195041891998582, 0.025031672032069296, 0.03287984636582194, 0.0021750859319112237, 0.04718067011825981, 0.02718621579509589, 0.03309306012646806, 0.0027277233264964796, 0.05699800642868204, 0.04144585849116406, 0.06176816014152381, 0.06469691427604807, 0.06619858450346416, 0.0413976141041325, 0.012385993688968162, 0.03328698762362042, 0.010159476923065321, 0.029790093108350714, 0.031166159390141408, 0.012936553309461283, 0.04245773040419144, 0.03899584802228116, 0.012466684772422718, 0.028383553764151952, 0.03375953363795434, 0.02000063282227324, 0.04220953706892268, 0.051296929483331984, 0.005791593106433509, 0.041029210082225265, 0.06891060470333023, 0.01250185874185615, 0.04369010540446447, 0.07203176182003752, 0.03019291554547606, 0.047928126784221786, 0.07636625665209948, 0.05521436987985527, 0.05131093357058783, 0.04909035494370807, 0.038896555366415175, 0.10570871117975443, 0.025671885964731057, 0.043265428394079215, 0.04418161975580358, 0.08593297112853297, 0.046936173157225695, 0.0282475252770969, 0.024436965637329607, 0.03665640319307004, 0.10278413988529675, 0.031320932133483796, 0.05667840986843071, 0.05437070023148291, 0.007740956019505018, 0.027987834877304496, 0.05834942383150901, 0.024219942504480004, 0.024883619795042663, 0.03757782693531725, 0.05606703340045868, 0.060269722805148175, 0.07067452214898602, 0.04732313565909863, 0.03747070486086511, 0.05369710593274044, 0.04330779305629192, 0.02419701923856572, 0.0302447528848725, 0.05147470401660089, 0.0329895310043808, 0.025991231631187182, 0.03789675699907445, 0.03277773067595498, 0.0574626655678355, 0.05630778036110344, 0.01818343587670355, 0.035833161279198625, 0.022241541507443594, 0.024507286763119123, 0.04565772179874682, 0.037560747005045414, 0.025774082093830072, 0.089651707469696, 0.01280817037989055, 0.03666309497108863, 0.029258947113468766, 0.01567900156406986, 0.010980992266277393, 0.04686514531532603, 0.024617496171906113, 0.034782192068955595, 0.05109567435518388, 0.03628168660666674, 0.018415255997810635, 0.043312581105818676, 0.012445263038840026, 0.04472696710558188, 0.060296872961184675, 0.03260839843161164, 0.025410780217498544, 0.09971544446964418, 0.0761349747077592, 0.03569926443179289, 0.044862135658941926, 0.0950935134483922, 0.06298473457835856, 0.037839070578376134, 0.030979931076628067, 0.04827468197852854, 0.07175106720458116, 0.11687986657864625, 0.07072106199038607, 0.024544656532065525, 0.03641443049174644, 0.054289835820635485, 0.03476225846116582, 0.05538743680282947, 0.052287936991741585, 0.005992348841015971, 0.02089895709838358, 0.09529530100764767, 0.006706738758141236, 0.048075108413374236, 0.04586919653980483, 0.011711306757323686, 0.027464711738209573, 0.08740790488739168, 0.06445638565046173, 0.030578753813320113, 0.01920872390450489, 0.07871710470006352, 0.03336840744821295, 0.05113138937421384, 0.04479364356807163, 0.05378057504253042, 0.022558470166498618, 0.04093948586453353, 0.017092545824726264, 0.04313073481523222, 0.05943108635443834, 0.04342285180163961, 0.06607883730001989, 0.031338343396782875, 0.06523817837718995, 0.05572849531627952, 0.004019205122359939, 0.01670382898150673, 0.008042995280946695, 0.04265055090429322, 0.056663808232593926, 0.024481232112814343, 0.0645030021006542, 0.030291221863139543, 0.05864942386265724, 0.026184268551127567, 0.016438517411569917, 0.027339693849846244, 0.015564949266732702, 0.030007267543565364, 0.02726127517469708, 0.05772531881267506, 0.020443004548489567, 0.015112867376076118, 0.02522121559107496, 0.03060941456726963, 0.06692875822585437, 0.03483347016416731, 0.017915278290128036, 0.03167879095511331, 0.032803999830878554, 0.016698650227138595, 0.052505701314657933, 0.014917732332833113, 0.07446522478975597, 0.03379152930011192, 0.05312568861089888, 0.018213209883880713, 0.05827936126039394, 0.03055979122197436, 0.06918690197410123, 0.013315240146532176, 0.028569155800787192, 0.02830020722842986, 0.039662298551129724, 0.06310165874780187, 0.10651944670826198, 0.0622769421146762, 0.05949086036473032, 0.0548938540140948, 0.04129930587124921, 0.0069928242385597725, 0.02677557160026364, 0.09474704252375711, 0.06378476019768466, 0.06950173346746354, 0.05312832012291878, 0.036929597807747704, 0.03159378200859553, 0.03162596344707474, 0.09047226424539283, 0.0281254300141647, 0.043529288227399515, 0.02440867975594536, 0.04354203210001992, 0.018011196328687574, 0.00466808686107998, 0.03103177416168394, 0.01449228348886414, 0.023884296402214997, 0.019327687783046596, 0.025681419928948727, 0.06363444225562197, 0.009743092814460397, 0.01198368261553227, 0.10463748277435381, 0.05492369696918515, 0.04434134142713682, 0.03209632419560465, 0.027570148419228294, 0.012078757957375098, 0.019545706830197768, 0.06408831487680156, 0.01404829340190777, 0.046848237754837166, 0.06363376426780898, 0.0592192285694182, 0.026064002323114586, 0.06182983404986801, 0.06231166888028384, 0.062238925001433784, 0.04624338835598, 0.07602529389963997, 0.008228838635278086, 0.010934450509657544, 0.005456805022643699, 0.062931016493108, 0.025886356109572996, 0.0640671861718499, 0.047426457937446334, 0.03546635838105314, 0.01398089968959891, 0.08677323168564229, 0.06983791583127553, 0.07084310745760318, 0.0516540183865976, 0.008851975510497729, 0.04970221787751202, 0.012810021439837593, 0.03589517992710875, 0.05889030871912838, 0.030665670318769354, 0.029092273194222685, 0.09891852150641142, 0.021373636667586623, 0.03548538800509226, 0.049451297269232815, 0.024893511905364936, 0.06821043864493409, 0.053504745085393234, 0.05835193276946103, 0.023308255739750403, 0.023472886119458466, 0.025595807688190572, 0.049981866782951745, 0.02979595751141108, 0.05493051132127162, 0.03783759968956152, 0.010425873465024897, 0.03003803746504409, 0.020744050289654446, 0.053955449933005925, 0.02083786541686183, 0.0344175725213943, 0.009055549969836589, 0.01822983782227722, 0.06170708761220017, 0.048647383753690994, 0.008025870821814263, 0.02349223558520598, 0.02203945517389765, 0.011815036019881167, 0.15477029186102653, 0.11972310997906233, 0.23740356908209864, 0.09735934105851958, 0.11460417175605414, 0.26954147844545306, 0.19250537749500046, 0.1741601151203917, 0.09474302822303388, 0.19983248755095467, 0.11639644977666679, 0.1135879944288923, 0.08832586974266075, 0.12097263768795999, 0.12918295519005868, 0.14128288494483118, 0.1324173171193369, 0.1593172841615254, 0.20458114483664114, 0.08764669449338991, 0.17883259262288773, 0.13265511081103357, 0.1718127451116039, 0.27521935441801626, 0.1760519232841269, 0.1539533663420908, 0.15407174224815062, 0.11300501684027334, 0.1363340642062887, 0.18960766524316805, 0.06231711576542547, 0.15542978631152263, 0.11764479004928183, 0.1565488262642776, 0.13258392592110943, 0.24186872787052588, 0.2110285714509026, 0.07880517416783879, 0.11009850223819095, 0.15082297786589594, 0.0687346496288815, 0.1151194654765629, 0.14567059224411366, 0.16206145707157352, 0.07327394274574134, 0.10712502389064721, 0.1478293514059436, 0.06634612537680135, 0.15912996034228033, 0.06581318865139639, 0.06801127876725889, 0.09295694019284942, 0.0936388963412854, 0.11406172021862962, 0.11909863340758509, 0.10178983436837312, 0.11164333385926102, 0.12651251058184332, 0.12158900904919832, 0.12151503559922981, 0.18024006467913428, 0.11999898590147497, 0.11378363796299505, 0.18951610241445804, 0.10613891551451338, 0.12496852165748998, 0.1767515300983383, 0.11737279053176604, 0.21890579392352413, 0.09365598010199686, 0.132033399816963, 0.11511686077762036, 0.2695710187958133, 0.15790624213555168, 0.1751900130822774, 0.12052283682409795, 0.07167975207970989, 0.15781397450595133, 0.22368881791349382, 0.13207303720616526, 0.16044698805818636, 0.19405030104662144, 0.15464111411523435, 0.1370331654024701, 0.08352338711941436, 0.10191662958072079, 0.17829980911506763, 0.1661799763960223, 0.10285610618490366, 0.09765157295811562, 0.11934069420901999, 0.20334843275768144, 0.15874552210011791, 0.06933553069229088, 0.14588757898778687, 0.10973235817566034, 0.15432493430712532, 0.12243270934108766, 0.18853413091311533, 0.1414504743391468, 0.11174909229720793, 0.14444904972708997, 0.09144950898424273, 0.1422551577730525, 0.14297996887997275, 0.1507654140192655, 0.14366023963497532, 0.12632485734479082, 0.12713891769488975, 0.21444995076425616, 0.1597686018794775, 0.21437911827477718, 0.10707507495798411, 0.18095919141365638, 0.10354225283428546, 0.26201138573308147, 0.18820348736499587, 0.0812609839223085, 0.12727173435832226, 0.13980784393366308, 0.18744578044260704, 0.17995100438354478, 0.17836238317672284, 0.20781299399752773, 0.08681555804345878, 0.1136487758448047, 0.2024734990611192, 0.14620654735594027, 0.10521017180214967, 0.08017555224679171, 0.10345766906656566, 0.1482661134533344, 0.14283093413518322, 0.18769851284882716, 0.17675031967941793, 0.15697179872903133, 0.2576903434049699, 0.25227502108581606, 0.18621613271534446, 0.10827872932197587, 0.08183611677058282, 0.13462749610264457, 0.12632815152286522, 0.10693144113306077, 0.1861659539563041, 0.13859177128441874, 0.13911439646636287, 0.1495221452487092, 0.08287352239412647, 0.1763296914437125, 0.180071096326555, 0.10906078251859835, 0.11105737618861661, 0.12741018942887747, 0.10463238828965735, 0.13261533552600493, 0.11201744523620415, 0.060919254282189, 0.06981902410306277, 0.1645983572328283, 0.12941702569444336, 0.118516598107113, 0.09919283460945853, 0.16124811684412343, 0.12438050321032926, 0.1595357724375302, 0.10748575171155315, 0.15448786588686128, 0.1504683557657465, 0.10825526404885516, 0.24652957615833132, 0.1229823774267589, 0.17687030437011875, 0.1507411443538243, 0.0793156951605793, 0.1562403533006868], [0.010497518007703608, 0.009472500025895576, 0.05763628407411518, 0.03435406383247145, 0.01836285175335023, 0.03264416707679629, 0.024811245553616076, 0.025400212034583095, 0.08133212284695718, 0.046544380470990174, 0.07789210461440586, 0.04871643891918564, 0.03447310240458577, 0.03502471252314506, 0.010078248620453862, 0.04875962712591694, 0.03684455055683371, 0.0057818762387239165, 0.0459338735128122, 0.07743997484325402, 0.052797040721822175, 0.032976369613841656, 0.021158643667736364, 0.009491463574851233, 0.04932788050463123, 0.026687389134519526, 0.0546776371887855, 0.10863325183069515, 0.03806943321720727, 0.07722813621043198, 0.023497965922879598, 0.0016027779131564464, 0.08873939634330812, 0.029902081756341844, 0.018635682476263855, 0.038664143442386584, 0.03347084106456849, 0.013002495285153631, 0.03580699171570521, 0.0059853008321125905, 0.06576759875902245, 0.015090672851299808, 0.014660616946076194, 0.01482485949377259, 0.05816674633552471, 0.04651235799575525, 0.006634086809842097, 0.04327583186809094, 0.012288879595636841, 0.03777927358544642, 0.03330898966880576, 0.02593986352064437, 0.06969684074001928, 0.020411129545180068, 0.07850548057186027, 0.021348616235979626, 0.01237851762843709, 0.08006967889565615, 0.018199889530097286, 0.019748882923816, 0.012225023294318349, 0.035973952917922894, 0.08569281788602953, 0.0569954936602904, 0.04597860921715056, 0.03992093366480643, 0.0205537942688792, 0.010253853209677243, 0.032998130341330846, 0.04780913800782254, 0.05713550771977152, 0.0256549630824837, 0.06365904133887061, 0.044497565907095714, 0.01789622568345118, 0.02073592401199764, 0.057082115221888795, 0.019594981605487487, 0.06660965962275382, 0.043849244848975254, 0.033232009323734435, 0.0378519676685814, 0.0323191887488769, 0.043228610208438295, 0.041026122747890414, 0.08264256220671438, 0.021118473847426718, 0.026419654811522173, 0.024225105937089653, 0.021344548309101694, 0.021968237725236726, 0.035944757307128566, 0.04463579498171326, 0.010683323057638782, 0.1359188598730872, 0.04476360526056059, 0.0400015912319143, 0.034671021219823635, 0.027463359593023217, 0.06706341350030515, 0.06070268505643453, 0.05338786688122538, 0.0396512707154597, 0.05717220716178418, 0.053399859987679994, 0.029197627520789544, 0.02317621857078085, 0.019720466807484627, 0.023087708602449106, 0.07224772200589219, 0.05035153868037367, 0.011997648398391904, 0.06554529536515474, 0.01930726579420509, 0.031204804695481737, 0.028987910951517766, 0.016606307903965636, 0.03967076765313264, 0.029562145561700868, 0.06562086993888502, 0.07935958433776133, 0.046263934834109205, 0.06864495605470673, 0.0737792466797175, 0.05523483974919204, 0.027938588830311934, 0.045289352250796173, 0.0192866139789863, 0.06282403231448223, 0.04065075498675147, 0.061505951227680336, 0.07909398931529253, 0.0313865973599135, 0.039946111144437906, 0.04595934976673415, 0.06539737144785543, 0.07201481595515244, 0.07444600364373577, 0.01184349331343847, 0.013619029440075881, 0.03809717709138509, 0.043470264983273325, 0.021201904652820482, 0.04803068297464521, 0.08515515439813176, 0.07307069961942973, 0.04125598742957077, 0.09251260919676674, 0.025191037472517743, 0.01336469112204448, 0.12946878259460773, 0.02678161028832678, 0.06315612759921821, 0.012652408425515939, 0.05427670890405294, 0.037158087361603975, 0.011214950730303123, 0.04956633686238239, 0.0599723274729425, 0.018690365832298994, 0.05984073271974922, 0.12099219591266687, 0.046904568199909506, 0.03358743581620436, 0.04405787740383418, 0.03341859769857219, 0.09948112115624452, 0.05090935411111963, 0.016904743200528528, 0.0643010153585384, 0.03801804020880692, 0.03892582758600193, 0.020612348284151767, 0.0345240242689127, 0.07019020902413516, 0.04413577705441464, 0.006148675785234739, 0.03648247059074141, 0.0570970960712481, 0.03992843749602476, 0.0413193850357446, 0.09336315831469913, 0.020933950079544898, 0.033817875063827926, 0.036792613626007116, 0.026710164928508383, 0.05289740973122178, 0.043671841868349624, 0.03496124979949767, 0.029074325669376604, 0.014949527854520469, 0.037322401730043274, 0.037331954846459056, 0.04236953070146903, 0.06780500193276713, 0.03159747838283018, 0.008207125788284166, 0.025006923561675415, 0.0420125107461166, 0.012675961798747942, 0.034117840621019566, 0.01878354510652923, 0.043709261433011105, 0.0991861160183626, 0.054166871047909224, 0.04292339311852571, 0.030999544842709458, 0.05142111616629747, 0.06192018262921803, 0.012182158759735044, 0.005555317226436831, 0.03774736602340014, 0.09518755074109762, 0.04299659665013033, 0.030313319669315414, 0.02370017866093305, 0.029468441517242504, 0.036047098992933194, 0.0662546621395215, 0.059436567713536566, 0.04167602194713489, 0.020598484007942102, 0.03575999605199022, 0.041477275756938804, 0.06777088037661969, 0.0336464858734079, 0.026925542887540597, 0.009762093710202363, 0.03617362607450735, 0.0046168025414038815, 0.08591707480410415, 0.0881444524613119, 0.042090820253736554, 0.03517088975997702, 0.01131613945378171, 0.017491599109264153, 0.02588947791786444, 0.017536476539868503, 0.052485013110262733, 0.05434683276220195, 0.05433685829742782, 0.0876679917376849, 0.04668684601182899, 0.02133784503976424, 0.008684238644256707, 0.018901198974720413, 0.049258158842642466, 0.05744658538230485, 0.017681100533433983, 0.0054934374319629805, 0.03477223675637957, 0.038674608203432256, 0.033472522627562284, 0.045397926061864824, 0.031237960980844595, 0.010899409648000954, 0.057300852476468975, 0.05343492383197431, 0.041357884784379316, 0.06058266972221675, 0.07976125189734083, 0.0486917708880238, 0.037048257166339506, 0.019493045946282726, 0.018401931813587586, 0.0112524593526858, 0.03345648457686747, 0.04942632663334089, 0.04883943050498924, 0.01974399336763928, 0.05623893970022759, 0.027488720933756525, 0.022152650410369523, 0.04404648567640013, 0.05714946201131229, 0.06951697095627747, 0.027435768936430256, 0.049703738562041716, 0.026202595289496165, 0.02423017743914839, 0.05517342248030248, 0.06580216464616599, 0.02994262695973439, 0.030372720211744312, 0.01564285370536269, 0.058239750684269016, 0.05209315530655365, 0.01517082767320737, 0.046483618207275874, 0.04624502395369834, 0.022148316267937906, 0.035172104009337006, 0.037369106280347036, 0.0415682640197056, 0.03492074290050134, 0.036963596789827274, 0.03369501371297144, 0.016908655994601788, 0.08875045099205549, 0.06305070623995797, 0.017078367452467644, 0.007161794027553932, 0.022383576123825005, 0.010352644077952831, 0.033994837543897094, 0.010732939699664714, 0.03766671994761114, 0.04378825658932329, 0.048756022682233204, 0.018263472912592754, 0.004985579552369253, 0.02356265247198603, 0.04410394227072116, 0.009954735137251838, 0.04693976994003019, 0.03508769644183978, 0.08547632909950711, 0.05876753929882281, 0.038421783866661216, 0.03501625108202139, 0.1187123412326459, 0.022563838527628013, 0.08360561899720662, 0.04376579106094376, 0.07125841904311411, 0.041650936398054325, 0.07089166977112332, 0.060929347490591396, 0.06283118757569502, 0.04819587451375781, 0.026539560978210745, 0.06704351053603234, 0.012832722540253834, 0.021646346731652177, 0.020602312532343695, 0.022231262522719564, 0.032951667108723236, 0.04159102066149635, 0.030159211507247343, 0.01490308281650106, 0.054373067443168936, 0.03887875914393414, 0.14343622020415722, 0.042340825386946244, 0.04736579143472257, 0.02670231252728451, 0.014618809612828397, 0.06596848233452728, 0.05780136453047876, 0.0026576870896538062, 0.09305176655611685, 0.01542725645366215, 0.07375890704532785, 0.18759947300197619, 0.1917961179729431, 0.13295567774724576, 0.1158212862848755, 0.19627347288112487, 0.13826506542823008, 0.13124224549580005, 0.232354314216683, 0.14787669563966413, 0.18548433488655477, 0.14413798738631511, 0.11901688416518512, 0.13558202633453956, 0.08629602785672873, 0.20006867245801035, 0.1277052711755518, 0.1105077310855831, 0.16272337235991033, 0.3077049144814092, 0.09949406804216486, 0.1803004170858091, 0.10244049582510226, 0.10010006657290844, 0.15058550593112746, 0.1763478783710349, 0.13857021357022947, 0.22401170865181955, 0.12335164712802058, 0.25905471535459645, 0.11942122537162035, 0.10621481950605109, 0.12347478044009018, 0.10981557064599569, 0.08517199301070745, 0.11665347993614213, 0.16739008888121576, 0.13236658677699106, 0.11347731004559225, 0.1514297961107185, 0.1189781507597335, 0.1638788168108271, 0.17541991606835397, 0.14394629686590166, 0.15259950511878537, 0.1127969167165218, 0.13692562197965963, 0.17438353700262887, 0.17994996250396778, 0.22106018638418568, 0.08655182461464599, 0.1397447642539778, 0.07258346769958735, 0.11848713436554517, 0.20339672694042807, 0.21361523668371865, 0.11492110233032897, 0.2093356703558276, 0.20760788161668087, 0.16393074225033485, 0.1348684920418647, 0.09734168273186493, 0.17988804727792743, 0.150344847070594, 0.23319805281296854, 0.17818736272954172, 0.10053460696531881, 0.13305631105697927, 0.12948647922565862, 0.10398393316615014, 0.16460637051251628, 0.1285265557347767, 0.1592119777154538, 0.14259750714465497, 0.09412556901694306, 0.11605171787161982, 0.10569795530529753, 0.08781210053712131, 0.17364176470906506, 0.16472891393688419, 0.14796177736453472, 0.1186188631841252, 0.20008114436941765, 0.13744270068503198, 0.1644120599714018, 0.23730250676312756, 0.14857752819455441, 0.1657636995397268, 0.1239488126649972, 0.13962413604942062, 0.10199874654532441, 0.16102952131580922, 0.1726126788003791, 0.12446694091082582, 0.19777252308783994, 0.15931690111756325, 0.09830657813337543, 0.12934053947608318, 0.1680043535006623, 0.09836716036642752, 0.15411704868799256, 0.14106059687272196, 0.11380565532993887, 0.1127076291689469, 0.10219863420652767, 0.2222703295128961, 0.13336326716647995, 0.09590028064145197, 0.12082105187038261, 0.18705329827723965, 0.14608449422784392, 0.1435689066326426, 0.20031112396428663, 0.1570480857645312, 0.19564351878098904, 0.1483874617805404, 0.23137493209252435, 0.1400583546849028, 0.15926249355318087, 0.1529103835984584, 0.1303966070014623, 0.14405636837886227, 0.2876278643886889, 0.19431285470003085, 0.1948270529148079, 0.13757707250695075, 0.08215735275899211, 0.08241861172380947, 0.23745520340819515, 0.08818921497872761, 0.15940386741872759, 0.12655196410994377, 0.10412867781856369, 0.09429173348771949, 0.12839062109349236, 0.11923049246111225, 0.26883128429612807, 0.10629986292652546, 0.12249008166573702, 0.1730079954910663, 0.17815537089782377, 0.19557656269640694, 0.13998045886476196, 0.18890631174848926, 0.24940827410788308, 0.1232223085037643, 0.15329679834746546, 0.1553907311491428, 0.25080551122946126, 0.15390888727720708, 0.2837471387559368, 0.1461007046483217, 0.14986794201597092, 0.10995931172322844, 0.09785849330646378, 0.10183437472029079, 0.122213025967921, 0.13086205138073814, 0.125596683111883, 0.08839316290592955, 0.16199018025109846, 0.21584726449462677, 0.16199687585955666, 0.09066464424493814, 0.15999203908347315, 0.1415406275660761, 0.2323171589523554, 0.21332564012658214, 0.16496839302201427, 0.1449095911436504, 0.17424032452606386, 0.1523435244997663, 0.12494864933673414, 0.12342499238589119, 0.18792006547652906, 0.13649572408007038], [0.04860796469954714, 0.021421159016749552, 0.06611323464782008, 0.016030906924917813, 0.022006113112213153, 0.043110919951070706, 0.017317532441548763, 0.08728477157532208, 0.0359512422414076, 0.014445110667316664, 0.013981537457795875, 0.026030332758842457, 0.03439212691098933, 0.003934838253283693, 0.054643396889009786, 0.03490470101936691, 0.020571533034765915, 0.04106017152568506, 0.010124603643142169, 0.05017608922395495, 0.056296273720480745, 0.006013727482152923, 0.09338087792838774, 0.016028324251003083, 0.1009242622662456, 0.03304850828323153, 0.07453413439854499, 0.028166712577184363, 0.052426085627127084, 0.047663408932426286, 0.04249261038738393, 0.007359360442346623, 0.05324719398612938, 0.05651732839103188, 0.03137414460070431, 0.03225547321621449, 0.008216556330632058, 0.03547181292707401, 0.011543926121967455, 0.05901250740393035, 0.031176108957058003, 0.040042469683553905, 0.02493674224693208, 0.027608586880829067, 0.05147758450719619, 0.03904126554487213, 0.051680479063502247, 0.04763444697844887, 0.07698984456158454, 0.059904080530207966, 0.041369387594562386, 0.0666735130512426, 0.03563389031877441, 0.018233177965627085, 0.02274380981801979, 0.05110259212914014, 0.034779989566173286, 0.03877242614004401, 0.04671377400236745, 0.03257395128809637, 0.022842024205132358, 0.06482281316552432, 0.04741760579148128, 0.012907382596524493, 0.016835726339430097, 0.030252191598617265, 0.03789404121738288, 0.05938856081376153, 0.14207037736571607, 0.008109869011076949, 0.029403954150996385, 0.008594649449561634, 0.008055157884354553, 0.036288749937328606, 0.07370342695785147, 0.045815800211482474, 0.015426677099669413, 0.11276208269860476, 0.016870956807847948, 0.028322722552524462, 0.01809528405447641, 0.051561325578199285, 0.017884598383980415, 0.026197834053046765, 0.021670850053910288, 0.022127850229040753, 0.06249336578372506, 0.018830249656832988, 0.03174423210082516, 0.0072913490716488135, 0.04170754263477941, 0.050471852788881916, 0.002123493740650555, 0.06736204989494816, 0.02410357949444123, 0.06154166624671029, 0.026761113605912656, 0.03883071777020251, 0.07057789547909653, 0.01590234492229478, 0.028040461287262942, 0.016181705587152994, 0.04616050913389172, 0.013076227417426005, 0.03686456460385554, 0.03860748740994642, 0.035850639575191086, 0.03872424304004639, 0.032319977819438905, 0.022300070624858625, 0.03444845735606167, 0.03145173207045563, 0.04828715772037545, 0.04129356787269635, 0.04013953685399987, 0.002526088984825859, 0.14910994398017086, 0.04087713396837635, 0.021904842034282706, 0.03820485074914271, 0.06950344950441392, 0.028912579610703454, 0.007867703830162364, 0.04365229513496161, 0.042629299625273676, 0.021151386899873618, 0.026595138741897482, 0.059951846112286857, 0.00395009417608831, 0.06784611021078403, 0.040478389034227985, 0.04972484045391602, 0.009697334382743126, 0.0355070146671947, 0.02677447417931211, 0.018448665092188506, 0.030371777923597448, 0.035737932719770944, 0.09661328633345904, 0.05171386517524239, 0.02957446808596292, 0.02193798491310689, 0.06930648829908141, 0.0443265023040435, 0.018420972928945577, 0.042219687733919396, 0.023910699622525323, 0.041792011489310575, 0.04213523420114671, 0.034250232105654095, 0.035159126479899695, 0.02088379430314226, 0.028050320838848432, 0.010467622384068467, 0.051122142692967776, 0.02484018452495577, 0.09793841159872471, 0.10930815997022776, 0.0360937767301596, 0.0069274965696217074, 0.07570785004645586, 0.04567244217821187, 0.027831870867239854, 0.027830392317545992, 0.0145988367430325, 0.05956689076077554, 0.015418824698445539, 0.05165264708921314, 0.0013548992724428256, 0.08635854063135001, 0.07417855468849022, 0.015151902428647925, 0.018577178256706368, 0.06921307919847389, 0.03937012410812801, 0.0588985633165125, 0.0672399967668518, 0.050432368617264495, 0.03069259256364838, 0.025529782400436463, 0.033932355412792777, 0.017880884772767464, 0.0576870795339346, 0.005870430257111307, 0.012017385696151085, 0.07402523751220397, 0.06448316042341533, 0.0394347129810241, 0.023735347842316956, 0.04170594534145729, 0.038868397804758245, 0.06712174343485987, 0.03118282371771432, 0.10683348913106228, 0.03806850242037927, 0.02274401474653954, 0.0765984425801904, 0.06588402114087535, 0.08600904365941402, 0.08948326771778446, 0.030550473677595297, 0.015056323383994883, 0.013944823651634639, 0.08127861926632543, 0.051859667028991446, 0.01050537902741663, 0.04829661507580069, 0.09093895734798524, 0.036244454733546705, 0.022091480204835538, 0.018766786933185595, 0.0794777380783231, 0.018061129939592174, 0.013626569660470612, 0.04629386971975046, 0.05088537938952927, 0.039363271451645324, 0.03370951575737807, 0.005315523087647894, 0.05605297568704813, 0.03927973722438178, 0.05297686070984891, 0.05306955734868685, 0.053420314535258286, 0.037864937537139466, 0.02618214265713769, 0.046760317674207116, 0.09698591916070831, 0.013881493078154183, 0.048299307874854536, 0.03872019043492694, 0.07420112363873951, 0.059530945915368304, 0.016409515237976468, 0.07873111644819861, 0.044789556488995595, 0.01215497029930233, 0.01418396374285822, 0.046890610077929114, 0.019580334004375245, 0.016838258260019848, 0.014678505099108143, 0.08051180355851689, 0.05610505434414072, 0.06259273504838347, 0.013002334406689532, 0.059026691521848404, 0.02236255084074313, 0.06949651640869918, 0.017801514233372385, 0.06985826312654442, 0.038159846914030855, 0.06050977262578184, 0.06724790279423037, 0.03360879051709368, 0.02660603442740056, 0.0010512696603508366, 0.046175463170173674, 0.0443525952587445, 0.03899426605071753, 0.04857721776070614, 0.06255548402306534, 0.03497245766582989, 0.021133029517988046, 0.03343062910942301, 0.004124794542158564, 0.019851381657645106, 0.03776227792484626, 0.040893892141719984, 0.05534720569548588, 0.01761204728315915, 0.011169689298126728, 0.048689196832598224, 0.05115070245078495, 0.03495258917551368, 0.032909681660033045, 0.07357403470744049, 0.06214951871023063, 0.08037776115440554, 0.07634973213557275, 0.0184516528350932, 0.03406486564105557, 0.01388255410992931, 0.016982497294403372, 0.0161326682991198, 0.030667983904300682, 0.02978925998773306, 0.01961749692958209, 0.037783762860682704, 0.055239240924317035, 0.034705123623772975, 0.025964556449663737, 0.040532367589372786, 0.026376384250339002, 0.0648274250148285, 0.04847024890383886, 0.043144160506105235, 0.02200474181482869, 0.03686022854620411, 0.02563662868323586, 0.01614722396968113, 0.036108336231160554, 0.05797197231121602, 0.0432303300758283, 0.021170385880395774, 0.04346333188755859, 0.022596705614799456, 0.08160160959608133, 0.025491635052246914, 0.06067365415454392, 0.03519960656581867, 0.05765051032686907, 0.030746253192304607, 0.020857117206399, 0.08380564455423625, 0.031015611621701432, 0.03344795035739099, 0.026064251301689975, 0.08700187062664379, 0.01677119300790852, 0.03351116410246299, 0.051700830189210754, 0.0238030968279007, 0.09587515295753557, 0.030579033435412475, 0.014654985242222827, 0.07187597017975585, 0.06435004498569236, 0.05486134890346758, 0.03488020535798804, 0.02848796771779176, 0.03052423133574907, 0.03579586428860503, 0.022697269976619753, 0.021247098094693596, 0.03845736482030442, 0.02603233033310502, 0.05351842741572088, 0.010732376625040367, 0.041499810233231516, 0.041487150630282785, 0.0582460824009632, 0.01587584402577411, 0.04318210867143447, 0.054680103991901687, 0.012571955786927814, 0.08260973533915897, 0.04798556039590509, 0.02256300732223017, 0.09217505553557027, 0.051417902427455114, 0.07038484132217784, 0.19947182867796193, 0.14331928454339504, 0.17973735778322145, 0.10782715113412951, 0.1387678029676599, 0.14085281850589862, 0.12050917747640803, 0.14305971863289035, 0.09983843222500817, 0.15307536829383145, 0.13611438083312205, 0.15382227337648793, 0.14864462217496288, 0.17385590160565992, 0.1407748767204823, 0.1457712561973641, 0.15669721749521073, 0.18717564251874724, 0.07078608753339899, 0.07790029409431642, 0.2720494664484455, 0.2283405803985173, 0.19861010233721427, 0.1616838370119372, 0.2055721102102149, 0.10323852195494598, 0.1236418029293418, 0.20421872396142254, 0.09050031072430073, 0.11059277450605748, 0.13054484501481056, 0.23596002960637694, 0.17281086574639046, 0.15663044527173042, 0.16200026196818199, 0.16717559958417572, 0.13027113712122365, 0.09467085507968742, 0.08811131915858678, 0.10895379067909335, 0.1167974201962352, 0.13573715913920634, 0.10458157367763982, 0.09451753024252192, 0.13382040715265658, 0.13102334353231615, 0.12747018177422786, 0.13586319592450896, 0.17553522762271667, 0.15890486838836826, 0.23830389093247153, 0.24600132789102294, 0.10506348894728769, 0.13587431952116952, 0.11320487385795963, 0.18578908466283353, 0.10917596383801392, 0.1002945839577625, 0.11883815585245049, 0.1317901975445209, 0.07707013823692838, 0.11724876855770427, 0.15880700831692066, 0.12531903752636525, 0.08927121458034362, 0.09571933067373692, 0.17502625412758321, 0.11542863558016478, 0.23997993809321236, 0.0855498658793588, 0.18495188845742136, 0.12095521684856185, 0.12412161145719791, 0.19809561300902598, 0.20573688040096916, 0.15887848432025603, 0.12836051383806815, 0.17338268909483187, 0.10774642844954807, 0.068700842168783, 0.13498309879533707, 0.1382424505127053, 0.07818249024210439, 0.1281005112574466, 0.23540456989599814, 0.13348388004927866, 0.23897634759064645, 0.12226023230581515, 0.2021301078099397, 0.16230415372598558, 0.11170475112815058, 0.20728574164452093, 0.1066082209769276, 0.12628484457250566, 0.19218918236513294, 0.08925709557989914, 0.07021183568623758, 0.14659870776437944, 0.17965694919468897, 0.062252530722969004, 0.19233244080697337, 0.21651458836370902, 0.11952981067400788, 0.1539897861620111, 0.07299918531169815, 0.07515583773173633, 0.11876131723364515, 0.09938408079887591, 0.14864137396216393, 0.18264069312041809, 0.12577222449885261, 0.09366265272781735, 0.16430339806022184, 0.12126601871944244, 0.1811173885700203, 0.08703004734049882, 0.2486507050813206, 0.11608153401363282, 0.20731980191363444, 0.12815822832166188, 0.14152066331476937, 0.097410814506152, 0.13987786436994232, 0.13914159258767483, 0.09962474732028861, 0.08802303518619269, 0.20236195665934395, 0.18901567846055956, 0.07722393038772768, 0.16986334245772133, 0.13225672976864924, 0.12015097008477296, 0.08655575464569754, 0.16124215668007252, 0.10775552191320928, 0.2112317226466633, 0.12404095005965042, 0.18270171968446625, 0.253727906834214, 0.18096679100586524, 0.14157151623118308, 0.08918899802430984, 0.14680372821467538, 0.16718931255802033, 0.12315992596409014, 0.10549055232155709, 0.1379992022749878, 0.27411499270989054, 0.12402156803516612, 0.10565635673100911, 0.23039124455423127, 0.159575394504974, 0.1552565738318428, 0.13252052448449597, 0.14770454036131983, 0.09939937191384454, 0.2333596360779578, 0.22412810805103472, 0.07686782973788439, 0.09205129403140276, 0.12524914732503314, 0.14962634852816983, 0.10613110141768571, 0.12812213791954902, 0.1887816998867258, 0.17332350114180198, 0.10008715799138432, 0.1174962226181261, 0.08848353829835692, 0.13110203608389825, 0.1774831747095431, 0.1754128527376921, 0.10851670687477435, 0.1764107282243429, 0.31513274977764777, 0.12290940755197119], [0.04216555596118973, 0.007723269443358145, 0.040083876735861265, 0.017474636007400773, 0.021429450003310077, 0.08992798941870851, 0.018507734301590154, 0.08311904591297911, 0.08728551468060863, 0.0864162730173238, 0.03529383155006555, 0.053214018548568415, 0.015776080225834686, 0.011892896408455507, 0.05426784909720864, 0.08937139589820178, 0.03652914832796782, 0.04091366870148529, 0.039554525301941944, 0.03338809973830658, 0.05303129891774828, 0.02791603328660131, 0.08292281249117467, 0.029559259325446143, 0.05491556111542929, 0.031534220587702534, 0.07493911911883662, 0.050858098998545646, 0.02671419838142972, 0.023027779459352457, 0.04533404965073832, 0.07980488826550784, 0.018022170538202893, 0.00984078530417455, 0.03506019388535812, 0.015131946795830324, 0.026745102368295196, 0.06074109287451833, 0.02542803826321277, 0.032762259530324134, 0.048146251168462544, 0.042771347648193764, 0.051389277552164374, 0.06942764510430637, 0.06697576538088822, 0.0737981460688095, 0.030880634590322455, 0.06889208835820038, 0.039431384328993103, 0.014775848061206841, 0.05636019609688271, 0.041386207054939964, 0.02503030839556408, 0.05925088332244947, 0.022589071548634, 0.023180493341398337, 0.00463180733101082, 0.0614345709853355, 0.016564431622804656, 0.06616352065916985, 0.06794996875067873, 0.029909376828600804, 0.06636178421397364, 0.04318216995846841, 0.03566220875889544, 0.09229507086978805, 0.02362790592615643, 0.037285361378904314, 0.02645897427423587, 0.022110902448935855, 0.07460936423270934, 0.018608746824846156, 0.11023518764564108, 0.011206577389290737, 0.01616569434953553, 0.024383282026035652, 0.017384952009325067, 0.048606972615685196, 0.05874862841841194, 0.008382569499043448, 0.02188278061728324, 0.038038513908583316, 0.01581698357533183, 0.0037722566799681277, 0.027408779658857855, 0.09928284994056148, 0.01734043464004513, 0.033990616399434306, 0.009564297469032389, 0.028062762106738748, 0.043159194981619235, 0.06146999106051461, 0.01933477409634619, 0.03406017335251935, 0.05384230640746894, 0.03237843032806151, 0.024390722655000228, 0.07442078402926845, 0.206298147057814, 0.0409155149733828, 0.04161240217546302, 0.024873988154614647, 0.018467374874519247, 0.016755737184036164, 0.03552312549624232, 0.03643965393665337, 0.015670681849212175, 0.05136092846852638, 0.06530336479866697, 0.03690922752984109, 0.019002933535845052, 0.03521238874283529, 0.061976739070228035, 0.03605845624641065, 0.02624846863440208, 0.06516422024897991, 0.055455308362481096, 0.08422996533373672, 0.04586910460925391, 0.04951371045242395, 0.06494764719278583, 0.013864263760737114, 0.05199317317155581, 0.01785014549480571, 0.05964852125954725, 0.03370447489883631, 0.04946032944586008, 0.029010642695450978, 0.10978337197053818, 0.036035335712855866, 0.018243797859477422, 0.0575959112405056, 0.01832706587118728, 0.05354860361905829, 0.0689751016456754, 0.07423426460234389, 0.03510928862998563, 0.03249990505977504, 0.035685796606084036, 0.021976542118335926, 0.058479720065670635, 0.08032672437688998, 0.008242114939005866, 0.061911242383141676, 0.04968111981607733, 0.07988168857991695, 0.07417581209372129, 0.047549028174891594, 0.020455426664181778, 0.0351132033392787, 0.00541059076861148, 0.015172768748485515, 0.06966039793746126, 0.040154352994455446, 0.03216166191944673, 0.04185721706298571, 0.025396477355952227, 0.038268619907959815, 0.015131769637997835, 0.02787955217964707, 0.017575700241591663, 0.08921324470711332, 0.01220238156571624, 0.05172466318453512, 0.019595902826216434, 0.040992610231642766, 0.042080263562139966, 0.04852480202492687, 0.009052422415885714, 0.011224196453939283, 0.01513784663045719, 0.06678358456420322, 0.05922036237954613, 0.005461202846134021, 0.046149033136786, 0.06322234057851377, 0.04463142445010524, 0.029671249888657086, 0.012642612076184202, 0.06350116593943489, 0.04828439597340842, 0.06459729220237463, 0.008209559075053661, 0.03943457508519773, 0.038039793275416865, 0.060584841581482085, 0.03938617365014169, 0.08818189117817149, 0.028985124306693196, 0.057095586878037265, 0.05861770016171279, 0.058988073029585426, 0.04089673815835868, 0.03855553515736134, 0.020502207823277965, 0.022042894908677668, 0.01659462889355998, 0.02722830083521624, 0.03659836437192656, 0.020072059029893532, 0.017709708171746424, 0.04236119949529248, 0.07590636641027466, 0.028810347092428037, 0.1108064364281393, 0.048010833636527105, 0.0102361450873075, 0.019192674362491217, 0.05013340280481404, 0.032440510263005574, 0.013833938170254472, 0.03159714896502274, 0.03810918168915856, 0.020018507568766514, 0.023529365951676044, 0.04347775349273317, 0.035039383106895035, 0.052666445713370084, 0.014403239174205211, 0.051627289578919454, 0.027677979125010393, 0.06897241267706118, 0.00880678494145433, 0.022492575113691633, 0.07691288336871133, 0.016517372756835916, 0.06918637337343347, 0.05239635758522538, 0.07193885833746003, 0.08118465858241243, 0.05119975123013701, 0.03444425536379699, 0.019393025506888668, 0.03786911271632679, 0.060145191382616765, 0.03690370403590702, 0.06944408535116142, 0.05628317361697555, 0.013362319122308926, 0.06127967183748561, 0.06361731636007467, 0.06453240455518808, 0.020985661014433832, 0.03126198741336984, 0.026602878145152525, 0.013383202679124812, 0.009807197136744376, 0.06317206605848286, 0.05775790436253433, 0.010885473551048387, 0.03304406114283108, 0.04755422608145783, 0.07299662657803105, 0.05779594062797486, 0.05901684346158178, 0.03712081335364811, 0.018861869935907664, 0.027071595635084857, 0.026350132332393722, 0.025707070467873447, 0.06736549729060742, 0.0645249811632018, 0.038627926635766224, 0.039679642781735434, 0.013457425107668727, 0.09102438381242176, 0.06290397358938091, 0.09385726970410156, 0.03337252900124558, 0.07685435425129629, 0.024029021902430444, 0.0467199754841145, 0.05505666301976289, 0.026234447310167937, 0.09949894036136328, 0.04486594694636522, 0.012214939662015006, 0.06509835967012952, 0.035889993511861375, 0.039650401205665646, 0.03843877952726137, 0.04758242960839022, 0.1105500421216411, 0.025975971159735517, 0.048436778522427046, 0.1108377234589669, 0.05184882305442326, 0.08401402046964054, 0.03076120722858656, 0.0024386079683374135, 0.07713263568979117, 0.035612026169415445, 0.04958940376978248, 0.054213380245792295, 0.06844683805660856, 0.03411030614628427, 0.010942571999264822, 0.007448172057798554, 0.024321839859288548, 0.07316169554307576, 0.04408893460828451, 0.06669870202219294, 0.09727906270493424, 0.05081885614462438, 0.018030066989482414, 0.032440215319154725, 0.058221720804971074, 0.03388284698068615, 0.005176776903681457, 0.013234147824527276, 0.08921845410499843, 0.06891160827851103, 0.027660265256981217, 0.04113900580353314, 0.04965367471618999, 0.022750122382515864, 0.06456602049330551, 0.07735647892038669, 0.017505164611183347, 0.08670836702109345, 0.03115853681529482, 0.06623349513017363, 0.06828658778460757, 0.030147383109696453, 0.027101473064131798, 0.007821930555491559, 0.022815525223831498, 0.036655709883498575, 0.06752108208714955, 0.018673419967413913, 0.04244305599000185, 0.0869074273073385, 0.04280418217662842, 0.04885977396981851, 0.03033732503442274, 0.049075458364020434, 0.022564181351974126, 0.1343758668630354, 0.026572364863128434, 0.04126909519395521, 0.024890269438225417, 0.040703461835941965, 0.04693645660975768, 0.023682627586587787, 0.02461611912886222, 0.01513159726821487, 0.05171383453172542, 0.04602051805704833, 0.049859124175723524, 0.059857601975841876, 0.0297187166964455, 0.06146211567665301, 0.14708263018438894, 0.11852836521762995, 0.12213728285484737, 0.19885635363959497, 0.1936212458437489, 0.16815914922664243, 0.10871227380008468, 0.1973468999588682, 0.2098786887983161, 0.17364936430127392, 0.0955714603825923, 0.1089589387899445, 0.08428873193840827, 0.10703753664969437, 0.2086890768259764, 0.13530724591785862, 0.17569363928369938, 0.14902663957928458, 0.17101045187202193, 0.10631752125318013, 0.11259925071029894, 0.07362222163787774, 0.17356969115714874, 0.10465053691258354, 0.1119200754610281, 0.16044590021333388, 0.18497649520154924, 0.13643307340962274, 0.19444258402912848, 0.1382810307005721, 0.13998438123493426, 0.14896130760110196, 0.08895799953250155, 0.18610613781117624, 0.06569118148857547, 0.07302512504881428, 0.13225853773615054, 0.14831748730953664, 0.1372284412143692, 0.1895435130403888, 0.14614080169027852, 0.10259593506493878, 0.21654975179943348, 0.20713211037218573, 0.14362984126613987, 0.09711378689614997, 0.08617476379919438, 0.12442207114110071, 0.197672916335925, 0.09151707027828501, 0.14087080625036072, 0.12723944375231383, 0.23268647461889252, 0.13231125990709952, 0.195005260287754, 0.06990656497017031, 0.17145188705575082, 0.0870823558239687, 0.1072101592416725, 0.1533295562671077, 0.21365758602417287, 0.21044896464915047, 0.1681684495340432, 0.17478107534829648, 0.18222354292388887, 0.19646182325818848, 0.11512632196348523, 0.08465424780884097, 0.24852214020586785, 0.10245425476422233, 0.14827650160558764, 0.1727635215126699, 0.19982784505813353, 0.16013042520611517, 0.12221532423169383, 0.13027610137097298, 0.15699324919091118, 0.1317258155153644, 0.1660191132536819, 0.2369673892615303, 0.13372374217837088, 0.18625914089141354, 0.13982480512030665, 0.11553489963614172, 0.14846791633434836, 0.289923278314452, 0.1433648054878558, 0.0885205097015827, 0.09617673879068706, 0.1659884544149522, 0.19691517877001918, 0.11049589502715296, 0.15059787059022536, 0.17264050311378895, 0.14199894732765614, 0.12886994698595616, 0.23883676637084256, 0.23750930453740784, 0.3145193584984349, 0.13535330312386637, 0.18300227129891997, 0.11219080327258957, 0.1619217839212187, 0.13189866027284053, 0.11423159255495957, 0.18267650006999894, 0.3020107974448512, 0.2081812064974539, 0.14093999931168172, 0.2899459851605277, 0.17195152959996657, 0.16815432287271947, 0.17590883338162977, 0.07905801382636832, 0.15921078261829194, 0.1858799426906532, 0.10773215623151873, 0.14343845718089612, 0.24536752802950723, 0.13767283349748582, 0.1475227170533711, 0.14394790565054263, 0.09143614074996403, 0.1349302693720787, 0.1258777224669053, 0.13018528930842876, 0.3071683158557261, 0.14760455056544275, 0.17775430854770446, 0.12106768621672546, 0.13559992214845074, 0.1385637018228731, 0.08252486811890718, 0.16432742257752728, 0.17297972684666035, 0.10635910450571007, 0.1256992929284611, 0.1028776255946967, 0.15991313202727228, 0.06989991532698756, 0.2278434353009347, 0.21718709098715938, 0.08688567807116816, 0.15400552160797581, 0.15263534271188323, 0.1853369395699232, 0.14353607210420793, 0.13823753222823143, 0.10516847363643109, 0.08707671741684599, 0.16394136022896538, 0.1300071279007581, 0.13333493723504006, 0.08549689856027404, 0.11086522601544858, 0.15221027116621696, 0.13449559108384196, 0.12032280360618908, 0.1160736050036165, 0.1116237526519164, 0.1250450768237633, 0.19103422821048768, 0.131295534571813, 0.1263578757343273, 0.07394834526724393, 0.2719048596918583, 0.07826738810587315, 0.14835444339100393, 0.1233229264917393, 0.1009939379629589, 0.1215996346887081, 0.10761758778244258, 0.21223957259808818, 0.21130549691377148, 0.13405386478670184, 0.15009615960861408], [0.07558283215809254, 0.01291723448723074, 0.014411286927849777, 0.04752652051167623, 0.015791603082400418, 0.058457377111358996, 0.07424284478709584, 0.026926347279861092, 0.03674095248683326, 0.06006390562341098, 0.014862432276018927, 0.057353268212248246, 0.07540005124023846, 0.08939491479747719, 0.024269627136809212, 0.027846656364178466, 0.03422439195996812, 0.02261116169393063, 0.08649001664091503, 0.04258151489099668, 0.048138904385268695, 0.023123835393738364, 0.02150891438847588, 0.09140384248307637, 0.01286767338657932, 0.06871570427451404, 0.03322974170347856, 0.037664126739987445, 0.046639137886344426, 0.07555238016310238, 0.029169006475938425, 0.0447424880469278, 0.025136338794724118, 0.04312283644873289, 0.04149277754608662, 0.012035607097430095, 0.040252186252825686, 0.04748141708513422, 0.02996585091515895, 0.02334892160199102, 0.0068064982488360865, 0.0315253569504186, 0.057154119825891914, 0.07924988054700437, 0.04726368340573484, 0.10650091504137363, 0.04903502424337691, 0.007851271244186548, 0.034316219089011994, 0.06840408268955446, 0.022610581382327986, 0.04390582427262299, 0.036119494301777695, 0.03864734313420711, 0.01903592319708438, 0.1075390407875661, 0.05173061568770678, 0.06876975943845126, 0.06083949686839216, 0.06729964437263627, 0.04523191863911287, 0.04360898435416241, 0.0667566106083893, 0.030417536355314717, 0.013444819130874692, 0.04427965985791338, 0.04152350533272951, 0.03321506345884935, 0.021029705324420528, 0.04337806247114655, 0.038432095410122026, 0.0474233016551983, 0.031233262946648948, 0.02489810843291062, 0.04967455444256625, 0.02304764411922905, 0.026159133206331925, 0.016520982946179086, 0.033680408246695034, 0.045189140289421045, 0.003555726476817302, 0.04385337406288713, 0.05280300088587308, 0.04459363716324011, 0.07081600326684213, 0.07047904715422662, 0.04859290341095579, 0.035307326188851754, 0.04119133343920112, 0.08154517189869959, 0.06158450205299643, 0.031071151080991954, 0.025354809833750613, 0.08979417684097445, 0.04081838268546328, 0.03360170803423371, 0.01609702605844265, 0.051250684585782795, 0.06748744316639439, 0.08056271010108533, 0.039209498453044125, 0.046162680993157054, 0.025797777193328066, 0.12334898880292332, 0.004813995488333486, 0.05205856643677239, 0.05212914611723635, 0.02414666044886314, 0.03589383544280164, 0.03904163326707579, 0.027624251463660793, 0.0119879832416172, 0.03881643789129392, 0.026822025256772197, 0.025457239619666533, 0.026060729212458097, 0.02308730449106905, 0.05546915157127285, 0.023364088227671963, 0.01663848934244485, 0.02248874658929004, 0.03529182056926432, 0.03574155631565279, 0.004633884386895526, 0.033099388012722615, 0.03720617853105068, 0.019390646803883776, 0.026662188672250318, 0.03441049386897395, 0.0231883438274024, 0.051021873274998325, 0.037099297774294694, 0.01465676639664678, 0.05926270022868149, 0.01956054786851089, 0.020844206709655064, 0.05915677325139123, 0.020056833032398455, 0.005415114517804356, 0.04579434208872338, 0.05042083516356446, 0.03954067443227095, 0.03327443527298109, 0.016589651237271966, 0.013052761186695388, 0.044554041908873666, 0.015006125472756404, 0.012107868340887852, 0.1249614047006734, 0.044905377491827936, 0.0642116895065673, 0.05289501953689803, 0.0320727612462736, 0.028527562972158197, 0.049944799618735436, 0.037670401000087304, 0.046117592888373526, 0.01216725834960779, 0.04599002009678272, 0.04699051560413453, 0.04365735514570148, 0.031688579643565806, 0.05017427359557441, 0.04579920291660294, 0.05601645627569768, 0.04606479027819249, 0.09836106996742949, 0.015053488858675045, 0.06134759702329194, 0.016152979205212286, 0.010350731730971847, 0.023345033705775297, 0.018206407023113103, 0.02995752162420221, 0.018028688031218706, 0.036721267857618874, 0.03909756151598789, 0.026712131859253974, 0.006964140470259853, 0.01968050766135416, 0.11902682798644228, 0.07056300272984851, 0.02872115147540406, 0.039386656285533984, 0.028853525723060294, 0.04988104961211643, 0.059260405795348275, 0.006131666239290949, 0.0633421337472335, 0.034886448974570924, 0.04041867248053032, 0.049291571767459956, 0.031115176238780542, 0.09983542149946575, 0.08334706432276195, 0.024338709115381205, 0.030814456084983486, 0.02394179130093225, 0.02530160311218952, 0.05870649358257652, 0.05407457277479191, 0.09431810223407323, 0.04359461637514253, 0.033142514932419986, 0.06901760420371449, 0.042068048290187315, 0.09801485951268867, 0.062380145649395646, 0.03839263422114234, 0.025398273832134666, 0.07330351373961858, 0.03408887866704214, 0.10612184707556041, 0.025242539648447308, 0.04045858183094571, 0.025450155221586748, 0.07001034690127259, 0.008140703092419333, 0.020912403856674512, 0.11353001689478276, 0.035560368860681216, 0.015983217951631355, 0.028998567234544508, 0.02981513269215582, 0.017777928301403602, 0.025266405202508457, 0.06313138295926395, 0.09593497676354262, 0.042673127515421766, 0.1030937160154985, 0.04042034255220525, 0.035924697294831276, 0.023739304686445865, 0.013372879644345134, 0.06125620273392528, 0.07486712217571274, 0.02761518098263731, 0.005367812418919658, 0.0268293816160651, 0.06103197645936763, 0.06873769865882012, 0.011450599375811797, 0.015170851613455003, 0.02837706882987292, 0.030621783056807135, 0.02066780155855081, 0.02175642590549204, 0.03041587011407941, 0.020974960681351445, 0.05124194735300638, 0.05452290658027895, 0.009732541868523245, 0.011876628531383411, 0.06792477211884915, 0.037965061398403305, 0.037887414556837855, 0.05071264571480213, 0.039566418816966396, 0.028429633952797424, 0.057815552478836435, 0.024840602042874502, 0.041195516279267694, 0.00994671419668462, 0.05481672428187825, 0.02779129885076996, 0.02677511386272888, 0.03904017386958003, 0.010414288300389965, 0.01805287151176843, 0.050097385181054, 0.019833539469888615, 0.04323157113826564, 0.049292410633737044, 0.016779114357045582, 0.03532216531194506, 0.0556843571605221, 0.01340131970092414, 0.027344514458109776, 0.06292886378604078, 0.04191767672196992, 0.02561215408927491, 0.022486658999696377, 0.06996050522091889, 0.03143201488250446, 0.048872257372544664, 0.016742298086624474, 0.01516311221019996, 0.02760102559301642, 0.010272896240255045, 0.05811107089562763, 0.026857500873325814, 0.025285473130943797, 0.028876956522224412, 0.018454837845638394, 0.025693093193694953, 0.023914689025391015, 0.007296856286214485, 0.014960919581954519, 0.020993452128623764, 0.022608283118555145, 0.010973102518267209, 0.02578704621672871, 0.04255957413284529, 0.08159112185239792, 0.005233150441199542, 0.06138406280848769, 0.026650406239974885, 0.056267671827827735, 0.003355398554460056, 0.04366608088715904, 0.022278139442806284, 0.04520111807411717, 0.05213714790560546, 0.04668907149724903, 0.018661708398271474, 0.008988920430232201, 0.05268258718593467, 0.05217063360877576, 0.05192317188747468, 0.02177421638231364, 0.03872275299903366, 0.036586735157235976, 0.016359137296075785, 0.016797556008602825, 0.09794398105793423, 0.04422628268178913, 0.014460536805281957, 0.0676066770909294, 0.02395996482171599, 0.038801648563915686, 0.06363341569780342, 0.011688435202344291, 0.02244173943425619, 0.07513082496100858, 0.09362949644245448, 0.08273042483075012, 0.05575727340915511, 0.01587327188556834, 0.0915042153229156, 0.004765804248651671, 0.017870073356936057, 0.0842628917927223, 0.03059508680786577, 0.013496259062160409, 0.04588570190413345, 0.014558688947750677, 0.039045616924282045, 0.0788817752993876, 0.07105980308786516, 0.06722223884876698, 0.012790497689087306, 0.11192921488996475, 0.12336238001983975, 0.0933085285848187, 0.19502885579582185, 0.15213134878825757, 0.1718865347004706, 0.23774369679872068, 0.27075802606921046, 0.09596687666470967, 0.20750933206610142, 0.12670556473876202, 0.08262167098901926, 0.1959226046118044, 0.20813044551159107, 0.1143830634593483, 0.20452587925378354, 0.1882059388463536, 0.09063484342468363, 0.1270567087997352, 0.20753570081245518, 0.12245438196846556, 0.11238485334380982, 0.15488047062629653, 0.1502851075342586, 0.20684992954615625, 0.23804645474639632, 0.11408962880171115, 0.11537021371505915, 0.10753013118500672, 0.14753459141619746, 0.13931439137987553, 0.20129764602789957, 0.12186290846476633, 0.13751914093811668, 0.10804070580390193, 0.16639526242450361, 0.12965486535141546, 0.13950773665020544, 0.10538031993013237, 0.11845696582308701, 0.10141265863973288, 0.15052694617019546, 0.16159532321316583, 0.19468463716968415, 0.21300837247362062, 0.1741026278825537, 0.1672605740567369, 0.10788807044586829, 0.08962790511788861, 0.19581472411030726, 0.10830573392130675, 0.07962219927820467, 0.26143357157707214, 0.1906810616773944, 0.2080012830875574, 0.1524994846793913, 0.19337516308071154, 0.16201340803696265, 0.17210038048365425, 0.13297294536905904, 0.28086140811924015, 0.1779774393165304, 0.0996636875694798, 0.12327312311578183, 0.09305877626062402, 0.13856881929020728, 0.10379438003104541, 0.2512415684759617, 0.07250772458651374, 0.17794572327646518, 0.18164651017756234, 0.07468189743738021, 0.09649959888549582, 0.10552340217175023, 0.18813999399783152, 0.153977099745985, 0.15779898982615242, 0.07335379209008909, 0.1465346781356681, 0.14767916752926766, 0.12284891724947, 0.1489286569337691, 0.22310128976260463, 0.12803876457074959, 0.12432606500242988, 0.15355866252174302, 0.2117588524256022, 0.10387019209203222, 0.1234924157841071, 0.12999292463064194, 0.12770691060370978, 0.11919427182405226, 0.1182794938945482, 0.09918823808191285, 0.1711959830455242, 0.13161867045827452, 0.09616341652168382, 0.18429525917576206, 0.09741215516001948, 0.10932091533416703, 0.18700402350194995, 0.17163582476637057, 0.1464219253149725, 0.14044317597102735, 0.19926587360039835, 0.12285508425726045, 0.17954177553615264, 0.1205771984232049, 0.09383414150966753, 0.14153632215194165, 0.08367259040354721, 0.08207679095287478, 0.11299684268212128, 0.1601918348141255, 0.12294125382698352, 0.22287737758409595, 0.1096753842167316, 0.13628557084068177, 0.15141655811138693, 0.08701636501017117, 0.16446116620734816, 0.08345564962514947, 0.12116475721761105, 0.13648944215909128, 0.11145454681208057, 0.10293030180037023, 0.1914447900508681, 0.15460288632781277, 0.17595539620566755, 0.11576638842422156, 0.13829373243835666, 0.11905365638555059, 0.0872718706546772, 0.08785098716015778, 0.16226318334379505, 0.19569149120680748, 0.17571591712053747, 0.21931375106496198, 0.16188271343708038, 0.10387195409425806, 0.14174785434959397, 0.12615711473289037, 0.14088404424969228, 0.15821416351583698, 0.1623136225727297, 0.18104503922645124, 0.14405557164742103, 0.08098811106455904, 0.14825701232879393, 0.32823901262975513, 0.11841918236666149, 0.1461542541942289, 0.150401292428855, 0.0712738097495129, 0.12230188450625828, 0.20382880052972227, 0.0773786035396399, 0.14420958596371836, 0.13665123992869932, 0.16336124780918324, 0.14768022473060316, 0.1277070944648116, 0.0741621221025144, 0.16790744337824084, 0.10003810538159263, 0.15798099699520296, 0.20520716124484617, 0.1557052408855769, 0.07823467615150637, 0.14366790051421813, 0.09383403425735813, 0.19642189475557498, 0.24841940781522184, 0.1824910608270476, 0.2638890978790099, 0.11514669224139183, 0.2093600472735782], [0.03340659310079871, 0.011521647327519473, 0.04443390783102763, 0.07801461739525681, 0.02598275678352483, 0.017587264338808677, 0.05757965868519199, 0.01638062797757166, 0.024463338214122964, 0.01609950626809751, 0.09434146025488455, 0.017980005058850494, 0.04489266043228488, 0.007826969498813513, 0.06145045581844546, 0.044231748719128876, 0.04759043905763857, 0.06440588513449316, 0.10248373382754865, 0.027667602464076013, 0.03915614042911799, 0.02288094530212543, 0.04665712563080653, 0.024428718700824727, 0.022585539883303068, 0.027984881608356393, 0.023371228167126258, 0.027720700018107895, 0.01540902451867418, 0.0380159602800925, 0.04740156007990722, 0.09040117894689884, 0.016354609716443286, 0.018932530055603674, 0.03306841507794396, 0.01578235448593454, 0.035570285868861025, 0.017640697056307428, 0.021906906641238642, 0.018434484804710074, 0.02805621780064558, 0.022871426659666245, 0.020911457738088026, 0.05522235634646589, 0.029060220075470787, 0.033260032820004615, 0.06717016785255364, 0.009716775779041552, 0.07362635851266884, 0.035027401491759286, 0.03346407267775747, 0.12368698679511586, 0.06866373286973085, 0.12290921602999011, 0.03702957611230593, 0.0923368686269368, 0.04284943115987605, 0.0266597869866077, 0.02833613292163899, 0.06060331196133649, 0.014675398612575186, 0.037368370835939725, 0.04740196610650709, 0.029845220795381936, 0.03369617433617673, 0.0593954632659593, 0.017912030077329087, 0.05354718252595875, 0.07718315918839748, 0.019760368497020776, 0.06244846154004336, 0.03606440108870307, 0.013214063871982358, 0.021373448976045175, 0.0513393132977428, 0.038501008849350676, 0.030872391484257196, 0.028757734089008266, 0.04176013457078127, 0.04377302676138859, 0.09509583469480277, 0.06531422026455402, 0.01797589691235654, 0.03296528815201694, 0.010599645188889437, 0.019977454832124136, 0.05606308804764863, 0.03347483621309361, 0.0627012322506597, 0.016743232713892095, 0.018556013162578308, 0.05055724860980146, 0.013930042942745552, 0.05011599345673477, 0.03147478557131704, 0.034860149176130374, 0.024448985556861567, 0.031122279789058432, 0.04177921399053547, 0.06374908348305092, 0.072297977373725, 0.06793946568523684, 0.04637223285352511, 0.007243331638164819, 0.08595853548256621, 0.008325862713278303, 0.006292476234281617, 0.025770243993329427, 0.02719503346710436, 0.03875376423820853, 0.005500827307602572, 0.04050955732142733, 0.01722326149202643, 0.0581570629841618, 0.040782759596984235, 0.009969771527985652, 0.06213742984278549, 0.04335105404137604, 0.10660513364259275, 0.04743248704941042, 0.042808066242404526, 0.025883328147052277, 0.06045328513268502, 0.10556107837586634, 0.024647593851231282, 0.030305256593912363, 0.09464184332999492, 0.053932287264615304, 0.035464416348165086, 0.0071671245630920664, 0.02112722065630219, 0.03540050163264236, 0.030420640926627867, 0.10452689798248392, 0.021811344833563895, 0.015138665386926264, 0.031505804471371156, 0.045427619629809936, 0.027443795622656905, 0.014194911139296188, 0.05442180978735128, 0.091828515663022, 0.03551140818144045, 0.06038606857820865, 0.035480473551058, 0.013123707631753098, 0.07371611337387755, 0.03800929148471163, 0.12065392212882159, 0.0970128701338845, 0.043305782075490684, 0.05203068083632858, 0.08292850452445208, 0.016371670494517012, 0.0842519214136466, 0.11264409749738633, 0.027245601015766303, 0.10405553940443263, 0.049482002073237975, 0.03611891973583448, 0.06765440436861209, 0.03096696120807, 0.04356584594314618, 0.016552850288609346, 0.028553123495751814, 0.040433944443300854, 0.06867601325915706, 0.02138927060690138, 0.018325453256106666, 0.06453826512780882, 0.09686403457195529, 0.012413343985474879, 0.046720745402478406, 0.0305076282952101, 0.00716815255732546, 0.023635482535727566, 0.06029171335901465, 0.006563056573917669, 0.041922445619298566, 0.03394927829504013, 0.07165614124988356, 0.03675037919874153, 0.03324229022367828, 0.04031923426795871, 0.05572486788995805, 0.02334963597898041, 0.016491067212735935, 0.03183849347424844, 0.027969536867233056, 0.035303043757355025, 0.059492553419042984, 0.04049464925042084, 0.005020604613462403, 0.03309411732780357, 0.015278092431535405, 0.03628586944673331, 0.037366980386357156, 0.10275855254862579, 0.06387005642717404, 0.006877661592537358, 0.044525650690399834, 0.01868054266988991, 0.05308819243744497, 0.029904245954727935, 0.10173764845897114, 0.04589506349856815, 0.013129302946430062, 0.03555714363051999, 0.022338371190633026, 0.04081727185797307, 0.03596643376494608, 0.021996314847661604, 0.024766804793128566, 0.014562336483880159, 0.04542338316358867, 0.008713265715707696, 0.03896290241109748, 0.01992857650733523, 0.03317614236185628, 0.046819727792735064, 0.0666016003777904, 0.07331850608029673, 0.05649073364874048, 0.0692057247544008, 0.04254829348816026, 0.015364765704068688, 0.0618401762368458, 0.07266183849424124, 0.06104362099581669, 0.025559897316739928, 0.020838690876600244, 0.05305107547751358, 0.005183922109990231, 0.07900940554757273, 0.056175890664059314, 0.05870783423644401, 0.0345808488406962, 0.06051963600780695, 0.03504080036955495, 0.06792735383515397, 0.04613261970300828, 0.052077025325307925, 0.004228084740574442, 0.006801359235279023, 0.0400695470612376, 0.023688961218501774, 0.03873461204010152, 0.039052875607364604, 0.025034805331679604, 0.06065870777914121, 0.03257480164569232, 0.06469902867871909, 0.024695930168813756, 0.06839212405705644, 0.0616212397994053, 0.036853165215542244, 0.10688851722666334, 0.045836369672249404, 0.0615441560324642, 0.029538389175168933, 0.006960126169536624, 0.08378899746364163, 0.054712321819557305, 0.01846976315362319, 0.10506397924355923, 0.04397758372849034, 0.06198968595614838, 0.017601626572169123, 0.0022317381339117645, 0.053872329393221494, 0.04660370248940684, 0.06508063239556167, 0.055930642936859405, 0.030866571131252477, 0.049279383308584654, 0.023930868802351818, 0.042211142023124044, 0.10650902791249175, 0.015153527492657306, 0.033062320848506306, 0.05489152893724461, 0.008717733923526061, 0.06364947290069635, 0.030388386709795847, 0.03599241180645843, 0.024490580300710375, 0.0109768592219259, 0.0640405914295585, 0.0299349871479095, 0.04319904687544031, 0.011006944452322299, 0.026009790111152876, 0.06845325021253479, 0.03137463872741548, 0.12198290081634638, 0.04935454036439619, 0.025028226551629847, 0.1143609771444913, 0.10109966575738885, 0.04671763125506621, 0.031708597521027254, 0.04874622824812128, 0.07063149865115843, 0.04979804015508102, 0.06342047389837042, 0.02922156393798369, 0.018850068351434126, 0.03551288290069469, 0.03285810479053086, 0.028095045051867926, 0.037827138758955464, 0.02760952150809669, 0.08126672192086136, 0.04592206426745942, 0.035515001133805325, 0.05978216529793798, 0.04796829277409181, 0.057815774644334475, 0.08519193427937646, 0.03694156793156459, 0.1085599908424962, 0.00910533323598605, 0.04038433641976407, 0.05981832847840363, 0.058516400355485186, 0.06505205731598601, 0.014320026703869865, 0.039320558219427065, 0.05085918684339812, 0.05003330575662756, 0.07892589430294691, 0.045362260838549946, 0.03513959506827016, 0.04664721245306634, 0.06334882552525209, 0.07303967305849637, 0.035513909458513224, 0.035560556552222664, 0.08149680876803976, 0.05809910077181074, 0.019082671797443784, 0.05976696228308063, 0.04012273271538077, 0.015284411699300813, 0.008136594945925378, 0.08551234289282754, 0.07425355469627727, 0.054519382575827266, 0.01185715074590858, 0.05353978594704982, 0.026165196792252605, 0.042808866804285396, 0.1348229557756455, 0.0638667545882204, 0.22384948187297393, 0.17083389924899225, 0.16068988389545874, 0.0650563857127582, 0.1260726995045139, 0.15199441823267168, 0.11103373471527331, 0.10477199249209897, 0.1615844600863995, 0.07515428257325003, 0.14066068365448905, 0.14424162376071178, 0.19529376900003803, 0.17535093751165176, 0.11961389648457689, 0.10845594078062043, 0.17693808782965909, 0.07967440050936515, 0.11413179428106356, 0.30354594571455834, 0.2259840479781551, 0.13948961100991697, 0.23643983047335382, 0.11917141942127098, 0.09879762517108072, 0.12258554388198162, 0.1612063190869747, 0.13094095843693904, 0.13098721482580708, 0.22337476782981427, 0.154068126313148, 0.14120144979848018, 0.15534027659844968, 0.1386631553572032, 0.08526802979289524, 0.08423243979773215, 0.23027158162045866, 0.1225318334576103, 0.16424909774814883, 0.10807664298842992, 0.1453998108063975, 0.2605781578008206, 0.10955123966860195, 0.22687070281995883, 0.11826639379104299, 0.10344820788070079, 0.11338296631771712, 0.1275238615550822, 0.12723546009510756, 0.21625378139076695, 0.17847656092095762, 0.27374114180284165, 0.08611487870615336, 0.19795423914347926, 0.11272926349192859, 0.18206985036451973, 0.15650826956956618, 0.1531254398005624, 0.13524385980300366, 0.12528345274228242, 0.2039458740863108, 0.17540906826334615, 0.13439209260527166, 0.10304471703186151, 0.1014051816215919, 0.1162605764224164, 0.1308300748707787, 0.07296625119183334, 0.13684968734460493, 0.16434056864630792, 0.20303069013020686, 0.18379370141173565, 0.2401311025624314, 0.15262932126079837, 0.18758418188700754, 0.13217452853437395, 0.13071802685097342, 0.15821198782613202, 0.3236388078620357, 0.19684672115310548, 0.09122012693795467, 0.1580117324427251, 0.11639191453615505, 0.17100649885833266, 0.16039213616280787, 0.11547716725016795, 0.241105719619701, 0.16878936379667253, 0.09007902365298041, 0.08875715426139294, 0.10666750852138766, 0.24118956028213426, 0.143623314197025, 0.10700803460373033, 0.17701647394607145, 0.12877429324773051, 0.1513852864023178, 0.20658031256208498, 0.22051471646033952, 0.17268159607004735, 0.15713234011444355, 0.09585836797111458, 0.24470584256754768, 0.1345811477832256, 0.1840514133894636, 0.16535692217369236, 0.09346993564958535, 0.1881213780612715, 0.17489437975229757, 0.12114198908450143, 0.1037791118987145, 0.16414702419311772, 0.1273203502979971, 0.13678535128072386, 0.19489321226794876, 0.12253436154776043, 0.30066303428142305, 0.16162815774160047, 0.09454665690540306, 0.16477636542291413, 0.1884918888249705, 0.2066598324886253, 0.1743746657044657, 0.13813239432150318, 0.19236535194420046, 0.11737723384172687, 0.19557401928449833, 0.13236277165912813, 0.09757864138772411, 0.15451006711490695, 0.11994547465996397, 0.21363143178243793, 0.16987153959851112, 0.0994663892854606, 0.14341288516598363, 0.15888614519949884, 0.10026305943967835, 0.20447735524465963, 0.10957021566648638, 0.22230308743253832, 0.17357876163817224, 0.1614486173756661, 0.12373115942482987, 0.12636543702213995, 0.16152508827226777, 0.14937643532551106, 0.15559311625697922, 0.22762770494145734, 0.12903719930158508, 0.0889085945222647, 0.13559780774577973, 0.10127765096483693, 0.25316922955455323, 0.13904406959491392, 0.12525781177945677, 0.1889575017435897, 0.14808165480292615, 0.10206073838015718, 0.147319994866848, 0.12915995723057178, 0.135193451217586, 0.18443004468515997, 0.12384003584062862, 0.1949675687618794, 0.1203852167893802, 0.1131137170558495, 0.0934979361632178, 0.12082610038980363, 0.2228742366236064, 0.11588262694497263, 0.07280494371849684, 0.10921266711046619, 0.096789815973851, 0.09506961150515465], [0.07256847535890919, 0.05353888579373879, 0.06239062190176018, 0.04005137928611329, 0.021335600402146097, 0.05011635351805918, 0.025053827294839487, 0.006652993381008387, 0.08798300709214904, 0.03333814697520387, 0.02005758762900387, 0.0604242159263982, 0.009947869074230474, 0.018912177014675353, 0.04576758263752826, 0.07743280426028275, 0.03312583336786878, 0.03054091864595971, 0.0035851741784192143, 0.052329075913275444, 0.039083630207084843, 0.048246604856103666, 0.02947165142564524, 0.05300766510528423, 0.014496264273240684, 0.0961542847536264, 0.012724614127599185, 0.028834490353361737, 0.06504220542527976, 0.07358734931556449, 0.02354716025893727, 0.015795931479172604, 0.009290656608138836, 0.012712420880674355, 0.02753179422729919, 0.005811807293925555, 0.08318881354024334, 0.07035000730426082, 0.04948241193027747, 0.03100779560965396, 0.09307532375978847, 0.05469990736474434, 0.05324362401640224, 0.02576080579010229, 0.03607964623839625, 0.02179822366264078, 0.053557405969308275, 0.07395049031343191, 0.03563088342367161, 0.010931478088511335, 0.07998949247262171, 0.03403295424856967, 0.022740910175226392, 0.056776396344385804, 0.018039964845464114, 0.0189035949147036, 0.06250637012623972, 0.08969543576841393, 0.017030925542536764, 0.02475911710080841, 0.07516709922422325, 0.04225796914749569, 0.04036717605026018, 0.01034727284399372, 0.036680680519390496, 0.03973900693498793, 0.06545666665319474, 0.026183994674694636, 0.13099895129280706, 0.026048981254139257, 0.038544446034657384, 0.037778434719169335, 0.01820817668621819, 0.02137113539051385, 0.046334548988529754, 0.04210604625123163, 0.030124180221689806, 0.0393841358562631, 0.10190040383848453, 0.05363421394459663, 0.013052359948145046, 0.046694874613275456, 0.013512176454007147, 0.007945258262371946, 0.026300999283369993, 0.0040851763051543985, 0.01091403809691509, 0.03795207620808675, 0.02635919515253796, 0.03415777678451231, 0.015251650906828864, 0.03167236539264841, 0.04744052331173613, 0.032670156609627514, 0.0019307467371090167, 0.046378928461983326, 0.013612422889338867, 0.07914750055680353, 0.02551489156640826, 0.050550978180141225, 0.10391111650894727, 0.06799495343359248, 0.034512134584327864, 0.041652843956985784, 0.03528646561467359, 0.055830323723174875, 0.013892145530741303, 0.06315104843628022, 0.0597261336271561, 0.04177149948513797, 0.024145107205596664, 0.04149049460407227, 0.05267318345666413, 0.019309686632045818, 0.07099450941407873, 0.030737977527502566, 0.17710475791846553, 0.04297850165335883, 0.06134940882123286, 0.04324441843275582, 0.04005414869395956, 0.034120671315899784, 0.066692519692644, 0.023393567290998275, 0.037572111919402115, 0.02983388652454221, 0.05918686135461735, 0.051176393209325696, 0.040851132944226265, 0.020862027829993638, 0.07298046212282873, 0.04096924454995221, 0.06696988182562975, 0.02370844666485585, 0.03658376656652939, 0.02105724618529841, 0.06044966919768242, 0.02087074591057195, 0.06390654902544714, 0.04147015496968262, 0.08054824636107491, 0.033921476964268, 0.058938867202208894, 0.028966491133154883, 0.04454181897604177, 0.058970384059413794, 0.05097075605825071, 0.02396233586384164, 0.02169857477589, 0.04074836607962366, 0.028767819636531418, 0.053870643999788075, 0.038864191982053944, 0.05958500490974515, 0.023460954300037796, 0.04257051386840401, 0.02797418893615325, 0.03323486300125238, 0.01670432119299808, 0.03496911752248003, 0.027232315135939468, 0.02642728887768763, 0.05413784014601862, 0.04973545843254655, 0.05159795607229875, 0.07490732646997898, 0.033268953913882855, 0.07344506380538787, 0.0995651456797796, 0.008105896845189555, 0.04202297933760189, 0.15075729348726813, 0.004599612964797886, 0.02654234187737588, 0.07294061788988691, 0.017594655172058174, 0.016820557798529347, 0.04880775659975987, 0.01665665520234935, 0.077698728700559, 0.030929959161327254, 0.060693197057492314, 0.07014986683404253, 0.07552902980317032, 0.05842096112187832, 0.01376316313736982, 0.079899737611413, 0.05828070957514067, 0.024287628287809993, 0.01843501340537783, 0.008282242624479677, 0.11065692670883671, 0.01097692912744899, 0.020166239964084762, 0.018983331261082523, 0.07578954566270113, 0.06181783711297378, 0.04395889501357752, 0.014661205876167985, 0.049586285791930654, 0.08072849152789963, 0.0848058412872976, 0.029275446732137955, 0.020949015198575876, 0.01786339115501652, 0.08523845879901802, 0.030736935647925546, 0.03275772812025201, 0.022613913864798607, 0.01533570990432054, 0.039954373402701276, 0.0686561179557635, 0.06714638082250472, 0.025586038151936188, 0.003126548221071942, 0.017752101562256296, 0.03279379553972714, 0.046380556398822416, 0.08517531783229883, 0.020611375352487932, 0.04940812821469961, 0.03386069171791596, 0.0615577387713617, 0.014392481384528501, 0.14591661372011708, 0.08712021588918664, 0.016950976606758855, 0.01003463810775429, 0.0309604283932957, 0.03634323028006381, 0.04925174285627661, 0.042920455171336094, 0.031206469021497235, 0.029035565450847633, 0.0330102919871288, 0.07541640721742185, 0.10743476089931304, 0.06507792810518896, 0.012436249056800961, 0.024869717214436784, 0.026856075949786652, 0.029528081462147738, 0.08984651596796128, 0.018917229364535982, 0.11674514235628229, 0.04194057125958704, 0.055635231772377614, 0.051023535685794014, 0.03965552633387908, 0.06218059506687907, 0.03457978397848145, 0.02074324015167452, 0.008407723038427291, 0.017079962830569957, 0.024108840603261225, 0.0046737539964998446, 0.011798265397608762, 0.033854202953197306, 0.0048409905115653195, 0.051066160817900975, 0.030712755997815443, 0.042475982448987426, 0.06570445779230326, 0.042109516629528616, 0.05124324970247765, 0.045937190673524336, 0.04431089709302591, 0.03430361694265758, 0.03716749109087452, 0.049866022797481674, 0.049224749748264594, 0.046096720822876504, 0.050494946509359345, 0.07349425431100592, 0.06372046626863942, 0.07307796979383116, 0.020791239390570312, 0.017925890523099133, 0.046833873606256904, 0.06300393657218065, 0.031193880281681498, 0.037867423492453756, 0.036495961399087985, 0.026908855577329957, 0.05419891650578188, 0.03579910867096436, 0.025507893353219957, 0.05537690309387061, 0.054606456129300984, 0.023283867330680934, 0.06612424333129199, 0.003272552369913507, 0.0706697034559423, 0.0412032844108199, 0.05104696648495813, 0.0362459026397236, 0.02065014897755558, 0.05304133466955635, 0.06479475902573717, 0.013369735811025867, 0.006339497274659094, 0.09940291890093397, 0.026227399301264557, 0.061937630281693516, 0.007594024664872597, 0.023067732859823494, 0.003360465747274218, 0.04566596107437246, 0.0555456722635896, 0.020807589622094266, 0.046985773519883235, 0.02179475136912398, 0.036710109787001725, 0.02191312344474418, 0.03570525906980038, 0.02955770033652023, 0.03760009328083646, 0.06064534720574176, 0.06532602567946719, 0.06882647292748575, 0.02473059181694783, 0.020799991945105217, 0.036891542390109076, 0.02989724008066039, 0.025077091469880075, 0.036736126132910295, 0.03439366291727751, 0.06317400809137091, 0.05912226865128164, 0.03917636131987937, 0.06195940633094119, 0.02695043691464009, 0.05592852853418839, 0.02949402885391347, 0.07510378971816072, 0.057676312168158834, 0.011997100645526042, 0.045630717199415936, 0.01998631463896844, 0.02346450511756684, 0.09270131963515475, 0.01514725897821688, 0.03540592170470665, 0.052646125231178544, 0.017972273316474694, 0.07489471666274533, 0.03340940464348082, 0.03262830139588445, 0.04450605033085712, 0.014628451786965374, 0.01972519931563687, 0.011501498257500992, 0.14265166956090158, 0.14339587801406461, 0.12576777352801255, 0.1664251092100336, 0.0843991635126933, 0.11341950105082606, 0.1685135108568976, 0.17673463019872868, 0.16504964430726346, 0.1579073759456796, 0.11835819410700953, 0.12840296276995253, 0.07766282982042721, 0.09781926960474062, 0.1418900709118574, 0.2315983846182785, 0.14925113398461573, 0.10561098134325397, 0.08066822339089648, 0.1573026414600111, 0.16330317834452276, 0.16313967985972283, 0.12800108070575422, 0.16278043058851074, 0.11396073450845097, 0.26628373551272577, 0.08147836903170233, 0.16371574733526478, 0.09094787461142387, 0.1774708253722037, 0.11221650552244918, 0.18027628531619427, 0.17738863945968691, 0.10958336939614628, 0.16807610529565042, 0.09289199125862892, 0.1577386220977191, 0.16461810697951626, 0.13723394172566553, 0.23127328754673082, 0.18558276186306633, 0.1565468957227084, 0.16627694780547775, 0.08354915831718715, 0.18105623943190421, 0.14935182858138316, 0.10788249332577952, 0.1662054564803839, 0.167995129802054, 0.22789471722658605, 0.23985875830534967, 0.12973933420594663, 0.10031148385737212, 0.1691509572969329, 0.09602722907138449, 0.09020181222548408, 0.1797946764817161, 0.21289082394251901, 0.10294976043364695, 0.16913537506855306, 0.2227767136308455, 0.11360575234697712, 0.09448522431475502, 0.20737695207278575, 0.17491091192970354, 0.16786566094285058, 0.2591785764501941, 0.10017903491614327, 0.204374193844776, 0.16864207573235038, 0.2124582753787118, 0.15878178870245335, 0.12952533520517812, 0.12597037314046777, 0.19375592410083742, 0.15407981681487254, 0.12113433586613787, 0.09996560282043873, 0.21077875017879472, 0.15389060841933375, 0.12968504921563212, 0.15749580286923917, 0.10005276064358412, 0.19375597006611286, 0.10769827982350703, 0.09983684642300492, 0.14749150663133592, 0.16607166688528754, 0.13060450794235354, 0.1153211840879052, 0.11154568063155298, 0.11212809131510797, 0.12043151914352372, 0.1370219958405341, 0.13060930365275952, 0.20647525126414917, 0.10450783771492782, 0.12972644860706023, 0.1944450355104862, 0.16837178459090574, 0.2038432336262157, 0.08048607832601956, 0.17996834861415048, 0.15717634420481422, 0.1829689158306968, 0.09741773228010825, 0.16219716188648056, 0.1295791298992211, 0.17347342454858367, 0.12052970863277875, 0.16464027756404492, 0.14430502519732522, 0.2636726014316082, 0.10892563694787603, 0.23980545390757824, 0.0708245528080771, 0.1538385144404827, 0.0955866365843723, 0.14472142462768864, 0.1535375951038253, 0.10811998058230647, 0.11920000982260513, 0.1931571497792198, 0.12304719612603227, 0.1325653253063079, 0.12197395290939078, 0.12356751538332432, 0.13258611693257286, 0.1459768588744825, 0.12466979333229604, 0.10758397950520439, 0.12300104698947362, 0.161578101556628, 0.06077784594268568, 0.09928887905252558, 0.126026006445529, 0.12099956567849844, 0.12086484145613448, 0.13268783808715884, 0.1413544222352005, 0.17709407865280108, 0.18483872194924664, 0.15128578690271224, 0.13192230174618383, 0.05951346761937584, 0.08749582879846135, 0.11043706713544746, 0.14890000524540103, 0.07618539861493534, 0.1880315006259949, 0.10531133371255091, 0.16721398058918216, 0.19672590908744644, 0.20387312637702112, 0.12034723415009438, 0.10353086876773065, 0.14229787483571038, 0.09433081163273704, 0.18728747603393373, 0.10366291934323889, 0.12454230864081653, 0.21177170738097162, 0.12348329933780818, 0.11969769884261394, 0.1379032574233509, 0.13956528517507738, 0.1425798871223965, 0.14067219029511177, 0.147277400378258, 0.11937738982059302, 0.1233898442719252, 0.29077942753511093, 0.1684182248408756, 0.1314117041446509, 0.18586189365915715, 0.11478493786266736], [0.015856337512002116, 0.026463333314525026, 0.037911588461288524, 0.005465859224298789, 0.0482805272293908, 0.07484538826130091, 0.021851192896945343, 0.039374142239290866, 0.04749681162197263, 0.0657494577969755, 0.018941108325135805, 0.018701106384997408, 0.07051169782155944, 0.019128704105593988, 0.035013328456590255, 0.0832262829006199, 0.03241711010735843, 0.05100742485674639, 0.03588839238809963, 0.0631353819382287, 0.017556892783050577, 0.04501078352932969, 0.059973878800989165, 0.03147191848726042, 0.05935288792956741, 0.07762762041942728, 0.06692614586603257, 0.02115459106261692, 0.025608679880538297, 0.021131723338077148, 0.0353571257343696, 0.020033752718459696, 0.04124194503791871, 0.04949041371864658, 0.022624459065076326, 0.005843904462733096, 0.05523627233361045, 0.01443448981585642, 0.06991800266287981, 0.013927124147754044, 0.009879406669267244, 0.020596857986322815, 0.03277473527217104, 0.0427772426947711, 0.011652971077109537, 0.03651989781628213, 0.03746349597349763, 0.050188534322284886, 0.05478128888494065, 0.04989507668201001, 0.012002875990865212, 0.0437338873293371, 0.03146051335328769, 0.008104735264374364, 0.02206321922130883, 0.046481097778004986, 0.04680467416502295, 0.08036546544322083, 0.03901918306045475, 0.031221151096566074, 0.07636442570196045, 0.07882511543650782, 0.047606856321855906, 0.018978587261611418, 0.07291061788677208, 0.03580374350290626, 0.04620534059922061, 0.10373020484562843, 0.03414220221701168, 0.04994040227405006, 0.02054560287374883, 0.03766302357337648, 0.03789251287197394, 0.03982616475813332, 0.04433009525640838, 0.01571567802344479, 0.06814510666675146, 0.03764196381633801, 0.07069925912806103, 0.047443909420361446, 0.042983059876508294, 0.01189806367150478, 0.02899756557458351, 0.04445743056074266, 0.015246638776584259, 0.045237300406780936, 0.02849919473632209, 0.02453835928932794, 0.027567474772372556, 0.03876749636425126, 0.06098402701618691, 0.05066342456566711, 0.03799273632466793, 0.033763628377909624, 0.04067986249743451, 0.002847878711162916, 0.05806707063569658, 0.032954888508444836, 0.050407788686213956, 0.045283618082682935, 0.0105740990294444, 0.060466745297514626, 0.04492731441953971, 0.09036112787021745, 0.07964492910691807, 0.03263270640144906, 0.01724338853701709, 0.028333474596541737, 0.013262708539954357, 0.047270593518811854, 0.027273655155553456, 0.019743257923231974, 0.05307066051529781, 0.0492784065464812, 0.1166870499089841, 0.014497011208966857, 0.08817375532441563, 0.015816113107927864, 0.04252704603958034, 0.04960413181012677, 0.05033661145716906, 0.026808467415732243, 0.049993603249951724, 0.008722350560879756, 0.06329800325235532, 0.03424048363681763, 0.022415479855431665, 0.04394184189638303, 0.07221914692631654, 0.041627007641739426, 0.08850136516435493, 0.0357283681120363, 0.009654229488073578, 0.057049602450382327, 0.017336950855209463, 0.011544849257916214, 0.016843898582362363, 0.04868812047906461, 0.0830569927911124, 0.05865004056343629, 0.0591504147216197, 0.09271032116826504, 0.019767956597910776, 0.01292380081835173, 0.07137896297799964, 0.03010883739578628, 0.04575224172684454, 0.09655638898332274, 0.044409373865252545, 0.009045819695588321, 0.05656475306398446, 0.022172128195844354, 0.007047618198538981, 0.04502014895420402, 0.02733952339528309, 0.013426866817979083, 0.12188778333966771, 0.050032941864863525, 0.0127303798968393, 0.05781818016041672, 0.056793828675102805, 0.05579043735539722, 0.053115311949964494, 0.02021995996455512, 0.022894392060416362, 0.01586328209903572, 0.03893472569724245, 0.030643572512593482, 0.04400240497723703, 0.03110950718814087, 0.008080076809311587, 0.013445510525226355, 0.02416533958767691, 0.0499412679534045, 0.04358570294214353, 0.021385390371564898, 0.07061223153986278, 0.014407827083261745, 0.002053796976519328, 0.020962567293956395, 0.030274371759244995, 0.10101225512522845, 0.02542201872734774, 0.04115514344565811, 0.03182814362639141, 0.07320828134975127, 0.07018945825796935, 0.017996221224987702, 0.021532525218302206, 0.03456688688827619, 0.030620390692004756, 0.07689482667633603, 0.020456633252662518, 0.053323549969542416, 0.023642911673373273, 0.044694343251326395, 0.047763115275771394, 0.08887926867652325, 0.015476005501113834, 0.029603567935766715, 0.06722805345611227, 0.013871377844723963, 0.06360563734966902, 0.035378430639543844, 0.021589587277342236, 0.034445668796017286, 0.08900532078358436, 0.03844021977255902, 0.062291034302043344, 0.024529013016651717, 0.030374420926936214, 0.018678175458203883, 0.044174966282181205, 0.048789822481452465, 0.06984500980545437, 0.02405340073540086, 0.021014266737526464, 0.02053349676932539, 0.03804698301058623, 0.017141334134184064, 0.041216453462238276, 0.010227765043025777, 0.039964646641765876, 0.04061890871173913, 0.02705245492829671, 0.04181017160355564, 0.08443221254574676, 0.024997816691475532, 0.05014851388912048, 0.05069991716394021, 0.029834432362188256, 0.04957046990673389, 0.06190639304658098, 0.053398553807769096, 0.01648253299325945, 0.04005167806040376, 0.024016649582453316, 0.060522436059170195, 0.03864127188740719, 0.02027657769259907, 0.05839656888236923, 0.026721480047150005, 0.012836026294427294, 0.04115394451805661, 0.05065985076550034, 0.018761303658867558, 0.03543934229040339, 0.032257262031517686, 0.014518883019205064, 0.04571417098744743, 0.03638881634199812, 0.016712857327694376, 0.020698540836512562, 0.0642837094323289, 0.032822106318968924, 0.09809688454674137, 0.0692677395718713, 0.00769901222684571, 0.04960139687623709, 0.028773607430799354, 0.029913224505200505, 0.017008745381909034, 0.05916991165929264, 0.022461039104288625, 0.01332381362801478, 0.04931134832722526, 0.0846912804991007, 0.05654290423638398, 0.08380290195946732, 0.036707796201470404, 0.02088808631073804, 0.026668346103941722, 0.0499135623836229, 0.027087976510125785, 0.04788848939501951, 0.042206465056346315, 0.028441718989802946, 0.013635412230336619, 0.026487940058652914, 0.10308270733202658, 0.03221714200692312, 0.07494926978383334, 0.02874419348494661, 0.03388580408007388, 0.041584665962164445, 0.02547227792562016, 0.01871097359746214, 0.04195101303799499, 0.020883089502251918, 0.059671331527492696, 0.07005763750883841, 0.04042313494268925, 0.08402754958238333, 0.06286455836567668, 0.10236020981063766, 0.016158334159803008, 0.07560238272192017, 0.06989498938163442, 0.1072453992861894, 0.025405605293570027, 0.04501969313188907, 0.013944668518829972, 0.01292242473291774, 0.02653698117712573, 0.053818224433569185, 0.03542425035829506, 0.04279312752788106, 0.020841370269115415, 0.061823617246362476, 0.039276852903346864, 0.04587783035071147, 0.015339389999186801, 0.034464610319945126, 0.04112167689468592, 0.024924276081184228, 0.05526909154028662, 0.017335976008325815, 0.1323849575654153, 0.01917811869192989, 0.005772818685434158, 0.0879016945198659, 0.0060709485044372425, 0.03134514242711087, 0.02160238094567772, 0.05053464901603518, 0.05114869530042333, 0.03334259794604394, 0.042917785354919975, 0.018277381238858068, 0.05896288788907471, 0.035787705452211445, 0.0340525392863539, 0.033308281037475795, 0.02751632116644854, 0.06450967472647468, 0.10475029688208334, 0.023220766583577763, 0.07190589357407824, 0.0363106562215234, 0.01286671769189378, 0.04559153180208899, 0.018890674841860612, 0.04251315303507351, 0.03951694868925599, 0.048603601828818364, 0.057011317206366416, 0.014565244745162707, 0.012450501165022294, 0.043605203710256085, 0.11678156217620259, 0.06638390883322685, 0.013208235858098395, 0.14214407502403184, 0.12698663473730126, 0.20411455132547887, 0.11534363046408662, 0.094160242156396, 0.20200342751078068, 0.13238316491967247, 0.1388886456768359, 0.1824570158796926, 0.19455454011838283, 0.08162987824048727, 0.09258770879598395, 0.1777842012985099, 0.1022715887595569, 0.14526398341742255, 0.15836068549223487, 0.07409538052255109, 0.13384576466295028, 0.12145927972010068, 0.11295340549681457, 0.1111834589391947, 0.1605599094182253, 0.20195407612669855, 0.15956756508638784, 0.15305131313300904, 0.0914125452418962, 0.1819011118383177, 0.07294443300774983, 0.15414038372616615, 0.22592320527520873, 0.21422639098619262, 0.09865881770008034, 0.21600305613490844, 0.13952953951253047, 0.06443348728240499, 0.09807420834418266, 0.18350905378259, 0.08236699271947145, 0.2160192818771447, 0.07229427716905071, 0.09942965536949136, 0.1348056728320737, 0.08746392123641507, 0.08251512348051034, 0.1219507787496813, 0.1584011042911199, 0.13609582618359597, 0.12682875167698632, 0.11176993754962761, 0.10206033235355731, 0.19143351323662267, 0.17913121369577226, 0.16761380187686414, 0.14959461716634614, 0.1090548146936682, 0.169771044184604, 0.22069370524296839, 0.2361983595596206, 0.14208695550839748, 0.15764998572487987, 0.1318310759961605, 0.15707025634905986, 0.1992001279347366, 0.1059545411337768, 0.15391703845272142, 0.11396398272124991, 0.15924421469530753, 0.23513103054175455, 0.15136408108857372, 0.09858575589474171, 0.1827426594231398, 0.1700408756732941, 0.13532647472475806, 0.15229014349320244, 0.17222053371369841, 0.11385479987028146, 0.10646231953174838, 0.18552205705594632, 0.10418948221711383, 0.1905952445081165, 0.2130719577713359, 0.16962505846975312, 0.33940419254283755, 0.11188043807182582, 0.12783489325234007, 0.11450403640347143, 0.11672124807392398, 0.07887645098831385, 0.09587028063833715, 0.08034119577777964, 0.2558460173707816, 0.16080945489868043, 0.14551237976599127, 0.2670236232299959, 0.10819482737250867, 0.07444375134523838, 0.1667547262003345, 0.0860655426438297, 0.12149444315582515, 0.07812415264667043, 0.09513495114421654, 0.1685458857325777, 0.09559478775988664, 0.1958962052219337, 0.2886619911559167, 0.1459498159707554, 0.10268171392982045, 0.09936476006142556, 0.10182339668033585, 0.1263083481500226, 0.1477015832619321, 0.1477151123746749, 0.13155350701943522, 0.09831288303699225, 0.2587819574100356, 0.0792799724806701, 0.1971623953431845, 0.18168885951801655, 0.1981048673511513, 0.34741679807343795, 0.1772918672330918, 0.145034586049376, 0.1370624452829361, 0.10095879750987215, 0.11779171039140034, 0.114475752437307, 0.10910305525026015, 0.13779716956759655, 0.18868688884521687, 0.16045009837515894, 0.2198845325338264, 0.17126903718998357, 0.10734012605802667, 0.14739242081920947, 0.09895252814937024, 0.17051440994105033, 0.18718471299977074, 0.17834436478874377, 0.1517058635551122, 0.10986469220370056, 0.1709954825139815, 0.4184465398711543, 0.05856208983928927, 0.18680545351197644, 0.22285690771475916, 0.14714753315333398, 0.12655214031016634, 0.18181172469931264, 0.13372305269923904, 0.13219400248940916, 0.12376890457685917, 0.09066544863725863, 0.09124888587863215, 0.1312790177161655, 0.12554311058333806, 0.1357304022437142, 0.22831370603413353, 0.08013250576632638, 0.11626021636109199, 0.2630335002416565, 0.12855808791374007, 0.1741451304405928, 0.18455782815092997, 0.1066197122957918, 0.09447996129071522, 0.2299485836298235, 0.12426446387243849, 0.108697013328633, 0.17501779651689917, 0.14102492781896747, 0.07326443559460102, 0.10156853454968623, 0.09376383762085631, 0.22091470628736481, 0.128031141995903, 0.11844169002987685], [0.017792721459221457, 0.10207354737025115, 0.1560869518547289, 0.004454496280936104, 0.06536852823750627, 0.0704106048590714, 0.04251865737680947, 0.030120985635045557, 0.004877079477263314, 0.02895853531006123, 0.019227527532606356, 0.05608073105254481, 0.03029014167916631, 0.1291432258703055, 0.017027129576871955, 0.029802419463052388, 0.03647939474772542, 0.05186491473127277, 0.023172039561153903, 0.024746807983085036, 0.03474743849027061, 0.10297405308172589, 0.03600826599605141, 0.02279990852149504, 0.05567210741461285, 0.05936352889083567, 0.1123387118681304, 0.026481376600361643, 0.03600927723211146, 0.04340153157470688, 0.0384018081240356, 0.05427762820956208, 0.008312482987680744, 0.0061791660846211025, 0.012526619661178802, 0.044235000762367443, 0.033532626055661714, 0.03437875101583139, 0.06535647767445733, 0.024511232115929166, 0.04070971694384371, 0.03541913289096087, 0.0741531205694041, 0.01391281458293839, 0.018014716502699642, 0.04425036848612851, 0.06253062063948282, 0.06632537971581183, 0.013528119701321327, 0.02877842612384308, 0.015384190820998725, 0.07475390970226257, 0.043692913116706956, 0.02367971645247552, 0.09481893221457159, 0.04647644379386499, 0.058510175891100406, 0.07856204084330991, 0.04690725716852373, 0.05944519769400359, 0.05003915100748982, 0.020195916295051575, 0.060286132408486265, 0.017083894776841326, 0.03664598056686021, 0.09721238241200486, 0.02238604867260062, 0.06024430017738093, 0.03821962858520208, 0.054672626973760706, 0.040360231463226585, 0.053911338590325854, 0.037632131077829874, 0.03803707366328567, 0.06648628882342769, 0.06285227031537122, 0.09687556419521572, 0.03467054624531058, 0.05532185201563182, 0.050352787403690244, 0.07000434843282546, 0.015743178664706647, 0.04058352694095623, 0.07943224777737934, 0.051362590879322066, 0.03869859058590185, 0.04305186606342754, 0.05279803663612374, 0.030032996606502323, 0.046707189476658265, 0.012285959843035427, 0.01628986571074253, 0.010140882053923224, 0.05135884470937233, 0.09227784155237098, 0.07252451723381396, 0.05908837692151147, 0.05004382414382793, 0.02284426692753069, 0.06841185848198592, 0.04115438501861307, 0.03741034862375067, 0.034017299241836996, 0.043231000402762045, 0.007319555950215868, 0.006645589620025168, 0.13181492686271667, 0.04218008481867371, 0.015022987067969817, 0.06573029027711, 0.06619246346094916, 0.034010707055248564, 0.020931986979238933, 0.047286179577631336, 0.05370012814960173, 0.02873133852957718, 0.047638078235209956, 0.005047745672204802, 0.037269308006451014, 0.011812301085991486, 0.06504994291331499, 0.033419968995956645, 0.051645273492941936, 0.028919652517464374, 0.05319124275457956, 0.04449267443569918, 0.028072206055625316, 0.02117153501228219, 0.01692553674201331, 0.021819216386985876, 0.015279163997019491, 0.017887082424074892, 0.04599298868748931, 0.09131182766249103, 0.05605510541147763, 0.04677380082167445, 0.020479748040557872, 0.030580104043286656, 0.054586809804482814, 0.05949665581987751, 0.030064662850852457, 0.06571039497371643, 0.008076706980054658, 0.03420241672786013, 0.03582248584397378, 0.041764777063602404, 0.037214034762714183, 0.050596863016366005, 0.024842059525150447, 0.030003301123337402, 0.008960745631596975, 0.027364963260028633, 0.018779155422723102, 0.03870532449875628, 0.04442486799352112, 0.0277390995348293, 0.04364388348955301, 0.043985248438172767, 0.04148400966979323, 0.046552818929476124, 0.030912781554845073, 0.02205273339284524, 0.0751269638778702, 0.020641551555825338, 0.013679880761511385, 0.09965592709880683, 0.039364623596831676, 0.03712307714346436, 0.05743384917056369, 0.014383798735516687, 0.038816422569535436, 0.046535110807106386, 0.017014372297712875, 0.04662028829296751, 0.05409717236855819, 0.04690120890436154, 0.026075386389669393, 0.022375763942217155, 0.04327527645434584, 0.04009929425533741, 0.07689285016949139, 0.0829883742957346, 0.05556670520755072, 0.022006961554589293, 0.039593235724755836, 0.039741818477670034, 0.06987994341480155, 0.08319426808626422, 0.05597096214431429, 0.06527829074090527, 0.01780976883075651, 0.025423564309734973, 0.053425435833032095, 0.044017638635611346, 0.01877349786340229, 0.016458619558703036, 0.01945762587110362, 0.025474286991201585, 0.029669440005935972, 0.04188713279642886, 0.05907240398829022, 0.018010139127352068, 0.046944301350102316, 0.03345913141064587, 0.03353852493267867, 0.02525913119766741, 0.03456828116829838, 0.048075889823057, 0.028425897358946746, 0.053066006531157804, 0.0357035085588934, 0.03701510854185589, 0.05420667314601522, 0.04751406392202743, 0.04239210731259758, 0.05900539427755341, 0.02086938035884692, 0.01182539927427687, 0.016209271345888416, 0.09359203474295717, 0.0333180716411481, 0.06289607139244195, 0.0334180805892233, 0.02566394546339589, 0.08741715156863775, 0.08024166563465711, 0.04270438390273241, 0.02496800629512197, 0.024812138046047864, 0.04479245230134937, 0.05934067265761476, 0.017178481737632426, 0.05514257978047094, 0.03732145944189641, 0.06774070417328228, 0.03380557169176398, 0.035148941340946385, 0.05415164121997453, 0.029901290770560026, 0.021558091487555255, 0.027705868555893822, 0.04320229508823926, 0.013199778247414338, 0.03211808109265422, 0.1381725373287355, 0.07558202776577204, 0.09836820224600454, 0.05489104630185231, 0.025750375503013213, 0.05546446311317625, 0.038405719002889055, 0.06041457087943151, 0.039994983723567384, 0.028747445528185176, 0.023215361833271962, 0.026400182771706776, 0.016655230278810187, 0.005497770616784693, 0.03522294160399226, 0.07537075603801398, 0.029458922874783317, 0.022226168038023096, 0.056326894254814235, 0.02195025572643405, 0.053494617403034246, 0.0663642663388483, 0.09217139363529221, 0.07140455797554986, 0.009981571197239383, 0.03884865954938916, 0.035096878005612286, 0.0729884370981205, 0.04773286246364156, 0.022716586883630485, 0.054056117716695995, 0.050265196740867636, 0.025044530817878344, 0.05087555431190038, 0.011633213669542345, 0.12413132545207778, 0.05186823955286415, 0.03329798098533385, 0.04677812921844664, 0.0707937484126418, 0.010561200981629233, 0.03238187772372077, 0.06688800234828265, 0.02160156314681855, 0.026755423487855062, 0.08414498320029629, 0.027570359093407472, 0.04647778444773248, 0.047250108327716596, 0.02772792231201405, 0.042661038647976615, 0.017872183929167448, 0.02911086614814497, 0.11199545851277729, 0.09100690934686892, 0.046160501473012476, 0.018589985331580527, 0.04039884995548956, 0.04532323248924748, 0.01987450219119989, 0.012506840228583786, 0.007384844357147814, 0.042081408863586765, 0.005464867140436846, 0.04940314098231254, 0.029482629465600176, 0.03918096167786468, 0.06741110250473985, 0.054935203609807845, 0.036934025795950044, 0.0031730318028900415, 0.012382679401085743, 0.007121051077715933, 0.10666892578404759, 0.10979182958122223, 0.05235139971538898, 0.008087799933198239, 0.03367675400729622, 0.01531345313490038, 0.03145126667204163, 0.013442161763387342, 0.044252023236044956, 0.06288173405693905, 0.03463564710991998, 0.07236331701278687, 0.038443448833159866, 0.10887783306140093, 0.06570688629102323, 0.026375729245163744, 0.046776926460405516, 0.05490919492477852, 0.024727366586786606, 0.02944940231710432, 0.0724037894378266, 0.023579360849614588, 0.052764750115813754, 0.04137129132305423, 0.034853602954817396, 0.020790398609073415, 0.07679000286565674, 0.07250310507633033, 0.04690243464504038, 0.007087122001159456, 0.07245133285440745, 0.038109652833232, 0.05162610980351606, 0.011622827432508911, 0.04694566498660753, 0.16992530364903713, 0.14645128180423092, 0.2842497843648157, 0.15315277381770073, 0.16849961402195116, 0.2623850527790285, 0.1017420074992603, 0.15017020966737502, 0.10199420364393343, 0.17286302101227546, 0.1445653725175127, 0.15464813148062076, 0.2656433472950613, 0.20373340726139086, 0.15609358617615315, 0.17047964487104647, 0.2562889694086006, 0.1485573954039043, 0.08859361747219678, 0.08888304548998995, 0.04993247326403376, 0.18019173985287068, 0.11383055318747798, 0.12633136143126797, 0.19466516321464894, 0.22188230597924805, 0.3070576621159431, 0.09971741331560958, 0.19746593470054288, 0.11965255328123608, 0.14207431505764687, 0.19234203222778537, 0.17384790364773045, 0.1284397196685595, 0.0907688705070365, 0.175494977363175, 0.09361312514351261, 0.16524960857725915, 0.18242065734680624, 0.16917184085374878, 0.1465362715985506, 0.1995759859921471, 0.14454805893042397, 0.1699223465496494, 0.1615500933821163, 0.09894970128492964, 0.11929099042449268, 0.19368619477796942, 0.14292796683167258, 0.2907738197715052, 0.15927082858979702, 0.17098192275772173, 0.23731818092205834, 0.14753950970067134, 0.18291636219909116, 0.18662585185900812, 0.1581512064102196, 0.1987562565914085, 0.12053814326082507, 0.14534678220027877, 0.09654915711331753, 0.16710363328456881, 0.16354222842041524, 0.0953106074443748, 0.16892667739622055, 0.29343882515545816, 0.16743105926340626, 0.20971620154957618, 0.20639533297188822, 0.2395037684829966, 0.18249389535236746, 0.12796484474693576, 0.10441193116768714, 0.22462817960448805, 0.11500875811062514, 0.17757352711933275, 0.16797007872693, 0.17000056412671843, 0.11578554062232857, 0.15934576731055014, 0.08855381154365118, 0.10105357790786414, 0.146051935491062, 0.12326650411611605, 0.10341444638587775, 0.10110786289817865, 0.13434047360093365, 0.20457147680703672, 0.11060856357817689, 0.09689469341068499, 0.19805459666156, 0.1731273673114277, 0.13435118351011507, 0.16015855595469475, 0.178489446519844, 0.1572510990644655, 0.1751368925456078, 0.10687347125983047, 0.15968721269840197, 0.16191078289862604, 0.13813532077737395, 0.1227132047736837, 0.14506791087408222, 0.25036016899731856, 0.06419277096527719, 0.09893620281570381, 0.26457701419149676, 0.10803201070596134, 0.07668601409081491, 0.14133370721772795, 0.09747586303180265, 0.128615130820582, 0.2039015635607704, 0.1454842336956532, 0.1113280350522649, 0.06873721602342783, 0.11658077053124867, 0.14011823211706456, 0.17440123363367974, 0.08976262167937334, 0.12053026787696347, 0.1764929294586182, 0.19981710450543513, 0.12734777624568633, 0.11150250391614054, 0.11913277028549103, 0.11466647002605662, 0.16870354662739462, 0.15221656840895453, 0.15614653817347943, 0.2385589216024645, 0.04717635321280649, 0.17596082010817143, 0.17915116262532052, 0.1530280240601109, 0.22285647870552158, 0.11336946018761206, 0.1512792138683219, 0.21489978227163517, 0.11426045108706721, 0.10451182903301333, 0.21962038541753448, 0.26396503251406456, 0.22904305238156553, 0.1287187212297032, 0.09666321994436365, 0.15533266168448234, 0.12442980862913594, 0.11298935034222181, 0.23518117865727795, 0.14916550067643966, 0.11648130933603934, 0.1310736601871829, 0.156948187899205, 0.2135413704860595, 0.11117262645594536, 0.07077166975866403, 0.1307332720006666, 0.12763020221985158, 0.10077263048339276, 0.16427589550374017, 0.08066888222651136, 0.16639094168861068, 0.14785786519848532, 0.2013206133438695, 0.1983934067069523, 0.14879180298697564, 0.14616468831175758, 0.1779786037701753, 0.12539412946470324, 0.11138156927641361, 0.18591977926271577, 0.16031771838184328, 0.10354612923918233, 0.09559297979238535, 0.14923129230737686], [0.033910112049911297, 0.04067475269097955, 0.034225077608660344, 0.07942601948255494, 0.01371944345714104, 0.05146110212550529, 0.03861976396893302, 0.0481756842665134, 0.05117517512952609, 0.022754448864068237, 0.010865642407518483, 0.0712632837014333, 0.017168455561923406, 0.02154633395313736, 0.026295835850760344, 0.028011166085038456, 0.018257405496232452, 0.020088941692524863, 0.0259090323121317, 0.03033092628503519, 0.04845270549037284, 0.042003658600151546, 0.05308906577767865, 0.02507138986050362, 0.09568543128308751, 0.0324462061267226, 0.016703160569792794, 0.06569520345017796, 0.02132494794955898, 0.025633970358138605, 0.014197055227874268, 0.05286986120946465, 0.0320815310377868, 0.06336112506687641, 0.041642248960992986, 0.01589321315423736, 0.016244203040015795, 0.021063688984741608, 0.042412408642591014, 0.04186686977083164, 0.027230223715906183, 0.06869956280194944, 0.07430207104452195, 0.033550452921659715, 0.0166427219782265, 0.09027525707478486, 0.010016224226884304, 0.03608311661669324, 0.027566789123680324, 0.05216097324005058, 0.031457435595051896, 0.06959087545833281, 0.06054431169984802, 0.013887117121128306, 0.06578848231583834, 0.10243360869466298, 0.05715190966223037, 0.022550525834723827, 0.07427985449471781, 0.09925736985619991, 0.028688311201309966, 0.013834146929213838, 0.03551362983642086, 0.008151206157861218, 0.017900188273239522, 0.05345207654059895, 0.06838391925538741, 0.05363598360770172, 0.015947165853914716, 0.027538932251533674, 0.024757768786061677, 0.03937525306678107, 0.03508838975141126, 0.049015634558013374, 0.03934101276700536, 0.02630068710254085, 0.05976286371268573, 0.0733042185405089, 0.036497079887457436, 0.022961122149060813, 0.05531776493655578, 0.0937528289373844, 0.0019394927080758218, 0.04201989200326704, 0.04515817118508201, 0.04193111007372218, 0.022224582236019835, 0.03185831408406938, 0.05396301505125819, 0.030711064858722593, 0.04142752983757565, 0.024957432366547086, 0.05336300732808248, 0.03731085295458475, 0.061727381281314365, 0.06067854179550083, 0.049816644600322174, 0.10349169103128296, 0.03592894525237141, 0.05920885956936306, 0.05577889624081793, 0.037355320528149605, 0.04157630794291054, 0.0448844479697366, 0.06445860730544214, 0.017838217505824663, 0.059457259748371384, 0.02576099156642393, 0.07063091642433597, 0.051147166955014395, 0.04105214675467822, 0.030698207988133355, 0.022355985467232043, 0.04316402133554221, 0.02537736346224143, 0.05840103517496779, 0.027784880949184302, 0.03745452891434393, 0.0544321941091649, 0.05932024492311382, 0.054933839973302624, 0.031116041918134982, 0.04625815087028089, 0.005050140654578084, 0.030702086308250026, 0.04188142161095335, 0.03701729572287971, 0.017610551496486992, 0.021626014758141774, 0.03405241671228602, 0.018056135046325864, 0.07004803076626794, 0.030575270028484446, 0.012449106885000102, 0.021740307415565176, 0.012048540576811761, 0.04003645972378793, 0.008234039414674044, 0.04305631703426761, 0.06466251692824787, 0.04293879914668299, 0.017152990161951993, 0.02891122555029729, 0.03244130316400721, 0.09852717315117199, 0.03724904881129342, 0.019384435746037675, 0.03626425427594974, 0.06197781542376165, 0.08409555520742171, 0.05925088332244947, 0.0226627902743677, 0.05186774159571336, 0.05237628225116961, 0.029393334257146044, 0.04162329977618591, 0.04290078203344057, 0.04394157759604916, 0.04924224719645516, 0.012845268187623833, 0.052709993981425805, 0.047541451565320456, 0.06122280130042665, 0.016367882189731446, 0.029836123501281106, 0.043026803496984706, 0.06023289695862801, 0.05078951497712443, 0.013709584863165454, 0.017020907027706984, 0.046276150106061856, 0.04784924654109825, 0.030492865780909217, 0.03694607635899898, 0.06217998985741889, 0.06885972114339953, 0.016503686596068646, 0.06730878380157294, 0.034617950478869106, 0.045087771535280256, 0.0333673425859982, 0.09208641150185178, 0.03246188794653262, 0.03883109698372503, 0.06188144156288716, 0.1005609144246386, 0.02945021053986444, 0.057560207712794506, 0.06667140630945083, 0.020826128949861855, 0.014649440680870847, 0.06201495153589114, 0.03312225573726239, 0.07893087387445473, 0.051777381525044484, 0.043669700652601263, 0.035017266148521055, 0.03103428309963596, 0.03164539909771374, 0.07808214038490288, 0.02718490003908594, 0.028160560891152393, 0.0559119389001881, 0.049609720421534394, 0.00889575073210102, 0.02271715187347464, 0.04283208692927034, 0.054113367467277476, 0.07967106802689453, 0.017449159753478823, 0.030946843739178394, 0.024768051601225333, 0.05902055898801454, 0.027256941032265464, 0.07500062065739786, 0.027412539235346263, 0.05337767025095321, 0.037690120103258284, 0.01945612242355222, 0.01743908952771416, 0.030822124625105533, 0.037202792422425364, 0.0014471902437846087, 0.044666614698907064, 0.044798106030230565, 0.014265486989320527, 0.014215906736471001, 0.045378030758471265, 0.04444024337816142, 0.033591132190439014, 0.0327788989600395, 0.023054726602089022, 0.04439939557003879, 0.05141943077286405, 0.04186413100650234, 0.06215511115207788, 0.017888398180084846, 0.03254060348075244, 0.05767698249509258, 0.07109125865803612, 0.021712695691554297, 0.07662468875247626, 0.033760541043574774, 0.0439986779594854, 0.012413915678588374, 0.03600435894763759, 0.019173499181746476, 0.07573490061106221, 0.08749149274080993, 0.054226200727205125, 0.023630372729272615, 0.03502095869231609, 0.027108454040341803, 0.08643569334620431, 0.039807801630588315, 0.035522504965023655, 0.007708696057013567, 0.04573733365583805, 0.01738555721878525, 0.0514866971230555, 0.05088062198351949, 0.029565332487465876, 0.027650208437755227, 0.05023714260108048, 0.015696378353412355, 0.08235434460784159, 0.07622209422650837, 0.05079521467128108, 0.05596045524843278, 0.03689284473958035, 0.05783297331823457, 0.05413891649955223, 0.05440218261473122, 0.03812779379527896, 0.040210806013595675, 0.06650000179727232, 0.0542101243721141, 0.10097087871643806, 0.008576698094275931, 0.016252128219592477, 0.03525218318006204, 0.02677663263203877, 0.04472160832055154, 0.028585546251927173, 0.041733011227822116, 0.021852144761191263, 0.04119441694309635, 0.08635006003802823, 0.05702985270369438, 0.05469153785417157, 0.0034653149346160076, 0.01839844994397173, 0.06367907836853016, 0.06263597305082987, 0.03726296096799835, 0.02935442656669165, 0.06988296946210247, 0.04907347036585693, 0.032083358157486204, 0.04109003746341314, 0.04770511858946374, 0.041163099268751766, 0.04041894061130382, 0.028341055036552494, 0.006308010103361261, 0.06239052614076965, 0.03870127572407646, 0.05579355916368866, 0.004570270360883085, 0.034707582766009916, 0.007830291926380127, 0.019339123560536294, 0.05630596090228327, 0.03856687708908031, 0.0056452923379237616, 0.10279127982475104, 0.016751673087597858, 0.03802848198721486, 0.04476463564881875, 0.012882690625115028, 0.06984191481024027, 0.061840348606628764, 0.032329427513984904, 0.020045196156828635, 0.03543016072663088, 0.05156063226862781, 0.03788566404593088, 0.04282227334296031, 0.0019439658236449526, 0.03602201727429225, 0.036582196086284616, 0.020141815165838888, 0.02325323722024839, 0.02979336047334777, 0.06939744591833123, 0.008683785694771478, 0.010040155856028922, 0.04029069749277927, 0.07543877698481083, 0.0032106991491145306, 0.013514634638634181, 0.06424360472949282, 0.006048788453617524, 0.02119753412121246, 0.021741588697618535, 0.05749080397729432, 0.05144640855911759, 0.03175839898176491, 0.1165133394721535, 0.026352315682977922, 0.05148902603034532, 0.043552761161399466, 0.07230340893710814, 0.2516688769983669, 0.12437871056458644, 0.14721280384448268, 0.20290312116905568, 0.13737179158676055, 0.13341203632373966, 0.18580442174307762, 0.12701180072561388, 0.17467235215008262, 0.11288242745062999, 0.1859870417824676, 0.13833085705916728, 0.12441222691127371, 0.1715793640863511, 0.09330479773662745, 0.12937496746740035, 0.10545026375761918, 0.08709269801094648, 0.17045991044611702, 0.18520719491906706, 0.12754820782931584, 0.20303646643315593, 0.16249746835279852, 0.12263132529633662, 0.0656746110067733, 0.18456115297252135, 0.12342696123185659, 0.15311324368080786, 0.17722204597967287, 0.12825978093690452, 0.1648418812621986, 0.23621420225789472, 0.1808186142795509, 0.1356058210254677, 0.1064570258641916, 0.17670801630423916, 0.1706817235437132, 0.15091173681280307, 0.09633547220859798, 0.17917055997156328, 0.1272554549899313, 0.16466664631039868, 0.15457109367895513, 0.13411941126950327, 0.13024787869184248, 0.08073127242706477, 0.1494086263400893, 0.11785377883502554, 0.14921404000732208, 0.11653530321294263, 0.14258696577481686, 0.1713151097177498, 0.09303442232551114, 0.1941424461021539, 0.1998771964422157, 0.19644420323593004, 0.15784749851351784, 0.19059945799170003, 0.1391038550965248, 0.12400720388658586, 0.1481186415279104, 0.17915502370845887, 0.1031141016151636, 0.1600809972132406, 0.10750377009953223, 0.1639698893432656, 0.16111245799449184, 0.07208839103940033, 0.10577657890896644, 0.11577129904781619, 0.15699957707716575, 0.18337671975454978, 0.1262864993224221, 0.14086493801686073, 0.09662278582372012, 0.1551756596252803, 0.23926425875434953, 0.21671879676080522, 0.1325685275538314, 0.13294965629616093, 0.12443304918105565, 0.10291330230933043, 0.19283661859170084, 0.11496501449014872, 0.11784144481944463, 0.12804150716551851, 0.13347589741310767, 0.10526558294171288, 0.15393157880152428, 0.17493913460883403, 0.06983524218441979, 0.1686549153659613, 0.1172218022627696, 0.19338907523741647, 0.15688509289776126, 0.18825666918869943, 0.10825626762403597, 0.1480385546963061, 0.2039691938027259, 0.1409756990089532, 0.159920317932002, 0.0749987820463796, 0.11508878365519548, 0.13632105603333444, 0.13180829254129242, 0.1424477675989751, 0.08382700308556519, 0.20316631833632148, 0.10577179852031893, 0.10846814456125421, 0.20455997016641403, 0.16259696785240405, 0.13477164320647717, 0.10612763870026796, 0.1392371390735911, 0.169267448626699, 0.29602740560808494, 0.08814870424929165, 0.11352391117402624, 0.2265920919636565, 0.19593469347924958, 0.1842396258707008, 0.09656205037308317, 0.15915527188729856, 0.13360240917292335, 0.11508380408368765, 0.10394551385674747, 0.19360881989761708, 0.17559404785354293, 0.10027108804112482, 0.25701597152698424, 0.12348748983875399, 0.07319783957134332, 0.10190533744471689, 0.13707122465054836, 0.10346799593178496, 0.14934856504682573, 0.16322880652883362, 0.1418638860266055, 0.20675936263174782, 0.13732961078564968, 0.1304921075221031, 0.20219758483431033, 0.21195109452932112, 0.10122627710863467, 0.11312947548445194, 0.17224852656645162, 0.18031393087679343, 0.19724262007061513, 0.15169887683324276, 0.13320845611874135, 0.1240030210465193, 0.09563182811102561, 0.08723420977231958, 0.14836475493446474, 0.2204683987844375, 0.12290467312859914, 0.1589697560355548, 0.1149557218436272, 0.182391622614476, 0.138997659988461, 0.13696242484354204, 0.1084820107526837, 0.11791606178326954, 0.19252255318626282, 0.14283539276690255, 0.2527784481043777, 0.09591518871245847, 0.06558568352052281, 0.08889675846383457, 0.14507373314230673, 0.18865247617565817, 0.08861614811804988, 0.14287850819528103, 0.16427142155026236], [0.051177132484172626, 0.06158049924359207, 0.08464454147484034, 0.04861357246315287, 0.060463769045928796, 0.06606775966863479, 0.05057376929588857, 0.020675594587960554, 0.05386106790073457, 0.028904240743647662, 0.04519094442648273, 0.03012110246345401, 0.03523593062474843, 0.018786651593062188, 0.06237069212441003, 0.07311163169722404, 0.03842486354011682, 0.05785410968406547, 0.06801479511083135, 0.04672166087754792, 0.03332172588054692, 0.017727129011144562, 0.03185158400165458, 0.06702812749051279, 0.04161430973439448, 0.02178163785908011, 0.062190692105721083, 0.031005211978129325, 0.019703823547329635, 0.0674813604282756, 0.053121203166102214, 0.023249640437443892, 0.00689250071563067, 0.005731203352972385, 0.04480395511153244, 0.04362285437603151, 0.029611272865065166, 0.050526402079530304, 0.059529494178751786, 0.024668827893272526, 0.08080659419178002, 0.05853801169582914, 0.057885588236874154, 0.031597574143820716, 0.01574078080950365, 0.04530527538830235, 0.04911523364904908, 0.03446393999301138, 0.05949033176406257, 0.1283937084278272, 0.02366513205361703, 0.09961226008712284, 0.05811998815906625, 0.06330778236470877, 0.010320770989863143, 0.06560621467689354, 0.03848322794862813, 0.02601211135756345, 0.037485275853184924, 0.06249467196363596, 0.000531340150290259, 0.016263322679386023, 0.05602748794180732, 0.04584536354448046, 0.04488251742816741, 0.04723109402543595, 0.03450508274498486, 0.022380291521849654, 0.010862972591102365, 0.029068714075331247, 0.015713638314346395, 0.041031918203037594, 0.04122671904042363, 0.06788320418807768, 0.07930869311695138, 0.007297217305148802, 0.1281228120769224, 0.05499689283991053, 0.03334856194053446, 0.010309325636274392, 0.025821395684033636, 0.05315278514078068, 0.06342504744327838, 0.013909055006449983, 0.032841335125868364, 0.06752311988102813, 0.037165024287758336, 0.014406452913047567, 0.03205542276132732, 0.06735757594147036, 0.026784548235516396, 0.0867701749948244, 0.030999887667055574, 0.044886593015924584, 0.07468652460844287, 0.038426694490255854, 0.08450693676188108, 0.044321231619124456, 0.02243026152193066, 0.016058554080495193, 0.10002139700396408, 0.0670342332112693, 0.038833881713329785, 0.04832799403717922, 0.07937289128500609, 0.027956480813783505, 0.030318814434952317, 0.032816238085468935, 0.030986172777991143, 0.01759164253129594, 0.05474178939156475, 0.02368077939947046, 0.06097740801652113, 0.07617333273012793, 0.07575043687416662, 0.051100948870542555, 0.08536768251008565, 0.038716287216952736, 0.04786025522457016, 0.04481260041375795, 0.003865835995736322, 0.0348269545863713, 0.008433420500237375, 0.09932892246832771, 0.0028415086900725243, 0.04537046947065861, 0.053399542061191414, 0.06615373771637678, 0.041077458299696445, 0.03537120643041788, 0.055372011622474085, 0.026031305690506296, 0.015119207711259445, 0.03065298581796308, 0.031855014160335544, 0.03169568319384369, 0.006851566243811601, 0.01379003750175358, 0.014403393349399971, 0.03877595780537494, 0.047611510305995905, 0.028240055919835166, 0.01717576021028142, 0.024294389013741768, 0.02625654511634381, 0.030125840717265685, 0.01785344924897917, 0.07148725716697593, 0.08775250655749152, 0.03334471234871495, 0.028424587348596226, 0.03680769023635695, 0.003042639568335407, 0.019086586506736856, 0.026686536861703764, 0.0556882948524529, 0.07245664950460196, 0.04295649194729425, 0.034113730559305805, 0.009731035548142128, 0.07206454272231749, 0.051013499933985934, 0.07933411957515825, 0.041462942251875516, 0.03746818443159423, 0.05258476924932292, 0.037520592506494255, 0.009164719414266368, 0.07770163217379202, 0.03350342278398814, 0.031973587334035866, 0.0821249932050705, 0.029480819582879066, 0.03402369224556512, 0.07498424169757674, 0.05081154766582674, 0.07562669835263684, 0.023859540270941875, 0.03562717172767847, 0.09462619215370187, 0.041868980343063036, 0.009964000013086104, 0.030066673831653692, 0.06388389197508655, 0.024513020931232362, 0.012660582583668012, 0.046078403660606955, 0.03662824563141312, 0.0192589984245358, 0.02546507478391211, 0.04957823037740685, 0.037104511002619425, 0.03832745929098418, 0.048622830635717804, 0.03583704534497473, 0.02085334613859173, 0.03625510335569421, 0.05052714518481686, 0.010021841566589092, 0.02595450729131699, 0.023016701827967362, 0.00039447845284162366, 0.039330570988597414, 0.059273119024451704, 0.012250123207547493, 0.08414939586674014, 0.012203269270098498, 0.0342964080552901, 0.033147031020733624, 0.05353565290269833, 0.04256834200913868, 0.03410462560432573, 0.08602329289480563, 0.10969234540337518, 0.03542210531210707, 0.011634448028710342, 0.04576944040074464, 0.13421549401696653, 0.018233258404859135, 0.04278060199031907, 0.04752430651757506, 0.01955055233631884, 0.04736640813550161, 0.04930490935822168, 0.05705879933591332, 0.09784524764625296, 0.053772944806804585, 0.021221876565006473, 0.02435071945881411, 0.04207582025217914, 0.028313223062263384, 0.030223852091078317, 0.04082822308485066, 0.06468619670598738, 0.04721065096917653, 0.05140710058772276, 0.037069439497445865, 0.03449703116090067, 0.042153861629025596, 0.017638910156224045, 0.03849729715335754, 0.06284390463523808, 0.029332855445963722, 0.054257418810119556, 0.05336511023943463, 0.014058617394297354, 0.03937903754112702, 0.03594149760301075, 0.03170999180104944, 0.028447342075167165, 0.07577276833715939, 0.02428261424234558, 0.03866193710916466, 0.014917175961478103, 0.05385138837981129, 0.07322675939048491, 0.027198293171222174, 0.049065847791010336, 0.03049243102601219, 0.05042919701325798, 0.010711857917598419, 0.028295170200327714, 0.06634353599961727, 0.03988389331366747, 0.07502600881120852, 0.023088407657680013, 0.05829365263062139, 0.032850646924587994, 0.022838111411059098, 0.028338115174143065, 0.023338146575336016, 0.037905927071528095, 0.08143219691250594, 0.01008265649884819, 0.034429393258065946, 0.014542704523210565, 0.06458245307928132, 0.006427626593053462, 0.05554047818746298, 0.024317438684163556, 0.0506182138868157, 0.0049745627292131465, 0.04979048269770799, 0.004607408867037345, 0.020051826647813284, 0.06622340575221085, 0.020248310963412928, 0.028980648437995585, 0.027617320283165867, 0.06405759092059828, 0.03162478367167135, 0.10509184952224455, 0.020813461686033877, 0.05505894213133762, 0.028969666567601027, 0.04195172549976457, 0.03411438939492068, 0.046209293612909895, 0.023582704823404074, 0.07399555926601734, 0.021861113735564777, 0.009087977514061476, 0.01144648165321879, 0.06264523888427405, 0.052561131606419245, 0.03870193072925172, 0.10988286380926449, 0.04831930660011788, 0.020292874297968323, 0.04826090771764998, 0.02334992517717183, 0.0449606545660044, 0.008480104940733122, 0.05011214003447564, 0.04366934442171647, 0.046467074538551034, 0.02912903583848909, 0.062071829733829346, 0.03454218055271814, 0.028711732424375032, 0.01753265376112634, 0.04538583336398006, 0.06304201114201738, 0.05065607778247326, 0.013620911143539895, 0.011961948701120433, 0.06058756885449253, 0.033359490184774326, 0.044215277828756845, 0.07749260508365209, 0.04140918203178914, 0.02255771173945358, 0.05799618835050253, 0.07327774254184577, 0.040985010639433904, 0.0442271904959794, 0.02502391922227558, 0.029290385446661425, 0.0511065413123898, 0.019511569952291828, 0.057848544055295575, 0.07947317985517365, 0.020097223102986332, 0.06913535191767639, 0.03318088061566795, 0.030228439042524948, 0.017033622172030232, 0.09129793848842384, 0.008179067818057394, 0.03982470536063756, 0.08647304013251297, 0.030591710275339506, 0.2361115924413166, 0.12618617244785832, 0.16885043632599617, 0.237416515968019, 0.16950695835534604, 0.16363731525357694, 0.10130327660590412, 0.13048030976806918, 0.1080612829255481, 0.09312534930124398, 0.16341668193138417, 0.1373977313238767, 0.15778595100968115, 0.2019018595737796, 0.11043467694112372, 0.22862075407418514, 0.2032873602283578, 0.23992576035520724, 0.10261435181863847, 0.09135847475620047, 0.1066819033134849, 0.1412983139556262, 0.16233006281958473, 0.19206250206597392, 0.127078473357664, 0.14706824305317096, 0.1149971365568138, 0.13358080549345863, 0.09898740047168347, 0.14838628200513704, 0.1451108271196004, 0.16320983819182844, 0.21061471543244778, 0.10112828680223997, 0.09094748390658249, 0.10135039101324736, 0.12338315632434622, 0.17160392486520354, 0.14648169549482484, 0.09410849291711085, 0.21240061960153042, 0.34457081207825296, 0.1430903315063446, 0.08065060336863802, 0.1460224411059772, 0.11361681465660373, 0.09205915409350589, 0.2048377689695166, 0.1854815310047519, 0.19577645035761018, 0.1530097298804791, 0.13485698540124202, 0.1074330908276381, 0.1249563408594939, 0.063220233836722, 0.14844828916172828, 0.17297805677498543, 0.1457098312675953, 0.12661371079664077, 0.15647008774742005, 0.1704610902215204, 0.10899207975354888, 0.1466152705853024, 0.07079191746250277, 0.21538031858301934, 0.15560905088580426, 0.14098300748775083, 0.08875115579294582, 0.18111853770190672, 0.1848567403372257, 0.10907543778058984, 0.08638968976635127, 0.12749858065358094, 0.1395121493166493, 0.2088669777637528, 0.1286411012012151, 0.147765597568885, 0.15759760063261757, 0.23438689869738397, 0.19419898339096578, 0.14044444767698167, 0.16916355178240808, 0.12266998975387505, 0.15876591536066226, 0.13867798681941726, 0.14343232847750187, 0.14735972418660118, 0.10608145892019234, 0.16791369465570297, 0.13868809918001776, 0.15526642572254906, 0.09281886816625634, 0.13646607647740072, 0.09426063031799371, 0.16387642661650337, 0.11691954227224474, 0.15653402544558048, 0.12871625442658702, 0.10055204312647543, 0.09338668487485378, 0.26604912874679415, 0.06314140721975316, 0.22686184684355415, 0.14229352345630047, 0.1379149938903509, 0.11468345419533792, 0.1504253475896774, 0.14389886070163022, 0.08108265397529449, 0.22874021782509743, 0.10334650204787332, 0.10589244970751387, 0.2319301313330089, 0.16070607899417802, 0.14737104696612205, 0.1919467002153397, 0.11245089012288279, 0.12905203076379915, 0.15906151804712512, 0.1645075451702841, 0.1210116928503398, 0.19385412125097168, 0.08633445482701065, 0.17520145843586615, 0.11814767314541726, 0.16732193769947176, 0.09343363840373294, 0.15291427532511373, 0.13578643391449607, 0.19277514769665657, 0.20153945402031948, 0.06230395437488633, 0.19831175705598247, 0.1797823424661352, 0.18222588715293717, 0.13651741969008602, 0.08234775625169277, 0.10651509532885206, 0.14164231807714509, 0.1488602146386139, 0.17718207151178392, 0.12132041096206635, 0.08246930376175912, 0.13779554546119707, 0.11052365805352889, 0.1181091312619467, 0.1724213560021693, 0.12606047274124238, 0.18025328735670737, 0.24265752264088203, 0.09257867661935669, 0.1282237518218256, 0.10866476868790005, 0.13516037154101557, 0.2076995363759418, 0.1452844839302763, 0.14363868192078608, 0.12548484959669653, 0.1293260297707973, 0.18288803226765127, 0.2563475291695326, 0.0963891136850561, 0.1263588410051119, 0.07134244356664919, 0.1534840302361596, 0.19831575603494722, 0.13948406453334516, 0.10049688479592724, 0.14132883489852952, 0.1329577768281583, 0.09207130424798497, 0.15579933180443703, 0.08603902067989112, 0.14981123618781567, 0.3027685503325155, 0.09044069376203323], [0.07240846257416472, 0.005229628830772615, 0.06227499625134853, 0.05901037001862161, 0.028185920316665888, 0.008336912573976143, 0.04949995917418311, 0.1049875160078368, 0.07819810311400122, 0.006830546706389155, 0.022324880382286447, 0.016726756077860633, 0.11819509398793021, 0.04536810991985183, 0.024714362244271947, 0.022757720059504914, 0.056771263555293126, 0.03486341654112743, 0.019588797360718734, 0.0602423083487778, 0.010021974674365934, 0.0345613595639025, 0.014970422902655219, 0.1268168313488845, 0.015777905430314283, 0.041573534704624646, 0.03098231361007258, 0.011433409320400848, 0.04765270285368447, 0.009840094867432791, 0.09773141464158412, 0.01982306896318351, 0.02630811432496675, 0.016086406164592313, 0.024424420947569515, 0.04514502128586174, 0.025335791701030348, 0.029761303524156252, 0.08403046837737484, 0.04246901104887647, 0.020583173740775357, 0.03523305779503238, 0.014577154539555553, 0.0418429869797922, 0.007590333557492423, 0.0715339808694778, 0.04826050169105011, 0.02451253063496082, 0.030954292029022213, 0.008020659508709347, 0.059893734512790564, 0.06890931767561743, 0.022545151727935, 0.053192958791529944, 0.024260573892764026, 0.03422988097994559, 0.03868998358807257, 0.020586919910725088, 0.02487473509034082, 0.07806490340660657, 0.07409548011398123, 0.04679332074198512, 0.04084357165641362, 0.029364236322562062, 0.0181370722355261, 0.06520708286834341, 0.04398495349432192, 0.040885097452349244, 0.06203717957701414, 0.11714949888447601, 0.053696217270748275, 0.03915539349339182, 0.023509679407241846, 0.10488901242253282, 0.029794957766669895, 0.030199011690133525, 0.04028163084219541, 0.06097415980372218, 0.018113434592622425, 0.11065708758730082, 0.07751738802800257, 0.0005571742510637118, 0.0404333085903237, 0.0386632509499548, 0.02788364308916273, 0.04262501336333733, 0.07998451290111389, 0.023583585824516994, 0.06081811152398587, 0.05874036616014858, 0.020870510338535233, 0.028685965057041858, 0.04367961766078107, 0.05479556493340962, 0.04344901370425378, 0.03579277312383056, 0.04286510531880683, 0.07045017330036049, 0.0078107997767567165, 0.045260945710563855, 0.044918186481921904, 0.044079086548017885, 0.05266514719433842, 0.06352491083464797, 0.02054603762864586, 0.0729699667182661, 0.029739259344135082, 0.01149124991629393, 0.054190884073895794, 0.05828362070925294, 0.03835376675030397, 0.04953642878981848, 0.03246688283979893, 0.029952750811653755, 0.02188557109254743, 0.11944085254424042, 0.05221229730053775, 0.011602980967220521, 0.043102175057415044, 0.02683055181536944, 0.030990211976571914, 0.04821941256523133, 0.10061847827126903, 0.09561416978437094, 0.030820684379807887, 0.02538626923436119, 0.030451014397605777, 0.017562138570112087, 0.028814110499356064, 0.02498511112325134, 0.09785761996623009, 0.05922436135851088, 0.06854969302132245, 0.05720915941281184, 0.030330401514807058, 0.010397986906971182, 0.03800028995160134, 0.05132758832206169, 0.008753357969615008, 0.023141311774511012, 0.0616473519063044, 0.020059933773271983, 0.05820505073173873, 0.04680706052890709, 0.048671569149460525, 0.04337731936586, 0.06174108659427974, 0.06477990458088537, 0.04040482161085933, 0.02557678572503069, 0.02707971425186242, 0.036807835793062564, 0.06755808413389229, 0.035985490202062556, 0.04088330480660643, 0.03343374708727483, 0.05028504607898574, 0.08471587192147009, 0.02336020033145624, 0.01653803606337357, 0.00843886930059882, 0.015638014902510954, 0.05144368894698639, 0.03001179703841767, 0.042441320800853354, 0.01900159671241718, 0.009805827754579726, 0.03895323821193269, 0.04378092512788792, 0.023401097935293953, 0.03611526932687529, 0.019514368088435263, 0.02195110225359038, 0.019833154510706663, 0.04041815154074181, 0.04746614512236369, 0.0353692414148921, 0.004338595317676663, 0.04523139003844512, 0.045238717669440855, 0.013480716095786664, 0.021154342084041527, 0.051900840424481905, 0.04601502903707085, 0.026786178087575302, 0.026128160271553263, 0.03826527976460996, 0.06979236424329781, 0.029854819877073172, 0.013562807204922842, 0.024274871008650913, 0.05187616856288045, 0.1334152998582971, 0.01213401779457326, 0.05030607519250724, 0.038576652370994134, 0.026314681613697644, 0.027281840805024393, 0.031495309066808516, 0.04852386356721963, 0.029273117824848142, 0.03961719512458771, 0.005789393476480919, 0.03145456468055566, 0.020432417213376013, 0.04894122826836763, 0.0919129002478815, 0.01329997488703098, 0.05792521796519718, 0.04628923871824819, 0.06187014559644365, 0.04364836510391005, 0.016687024842887636, 0.07537745164647218, 0.038734129404709224, 0.08603496807477168, 0.02311683143489063, 0.02120388882054437, 0.04290782621190433, 0.04721656133751235, 0.02242953182318278, 0.02311792694062235, 0.020571123177726424, 0.04181944509787906, 0.05100255253754797, 0.005206259318642439, 0.032870293249406164, 0.014123658259068767, 0.026387645742825927, 0.018731039355418855, 0.06919110013592629, 0.03267975952175837, 0.06554928668324025, 0.034822836863778295, 0.02250619807220515, 0.058925901164090445, 0.042938243732937885, 0.03454756615082583, 0.06921790555239686, 0.054868347116655884, 0.02313526351034882, 0.0594010480469273, 0.04780790460626445, 0.05983913159598747, 0.04956033456349566, 0.049824098635825424, 0.03160892373641893, 0.05493378634714792, 0.056433338341453386, 0.07505564109211968, 0.025594484271301378, 0.036591274228187344, 0.0506349299253235, 0.0070436771549735105, 0.005533625925665782, 0.02461465398570703, 0.06484931980770442, 0.03626882782085769, 0.046803609302808205, 0.05959909326667267, 0.019105388219618512, 0.04333063396775434, 0.041171809688450835, 0.0630428729909322, 0.036240896255138426, 0.023817662074561083, 0.028458883189746452, 0.03078570288996543, 0.06580145218439641, 0.056950390233748385, 0.061601229582823096, 0.03331832828060274, 0.033779965202894904, 0.014508717032449861, 0.04404592260177578, 0.04367359620969623, 0.007707543094687525, 0.02028117805058437, 0.08572072646911107, 0.011448082776980536, 0.027492062992326198, 0.04012552510586478, 0.05085778873293631, 0.05576847361460809, 0.0247514906955222, 0.028388891481764378, 0.022244573300403934, 0.021370365472149946, 0.03406017718295898, 0.0976251735682449, 0.039091854160952, 0.015992880235576344, 0.05946307052527705, 0.016930033678128835, 0.03864866080543688, 0.01608844587369071, 0.06604647008521904, 0.007254963725685112, 0.015057856517453349, 0.06325805559754372, 0.05625573234752782, 0.08301336408382462, 0.02289859022224142, 0.032298672914264664, 0.034044476210950844, 0.05930808327731587, 0.04047906319160135, 0.06306212095002975, 0.05883626504651001, 0.017185771064231956, 0.0724517695245243, 0.0021147091061838215, 0.08066329744554336, 0.040882178657357736, 0.009889412735168253, 0.052136649948454676, 0.05464341221076827, 0.022480064897888133, 0.04580982472567309, 0.04223834580531524, 0.02485548330080365, 0.0037690728664353133, 0.023062736051337376, 0.004055280202714306, 0.02354082279658366, 0.07787513576688306, 0.027141125775092555, 0.05854207962270706, 0.06057730710674679, 0.024457510200238997, 0.03034501464196271, 0.04138214678894128, 0.04504962801753033, 0.055843201661182035, 0.017953724412608053, 0.0029703570180572574, 0.028267181178014127, 0.001073698560151482, 0.013656906742272119, 0.06828003007197572, 0.017985340861243107, 0.023512188345193866, 0.04538786732741902, 0.0748847421979712, 0.066764930323247, 0.038150619384982896, 0.08952354095996388, 0.012293111273808586, 0.05898130081233479, 0.05479970946907998, 0.02634761764878227, 0.08090542719489144, 0.20959139050495243, 0.06662103602842939, 0.14438368710539035, 0.2293136039929044, 0.18131186765047813, 0.17727400206269758, 0.1568865484648174, 0.18984509121266105, 0.10092013305233372, 0.14482791084916363, 0.13641784358168804, 0.1256833966040323, 0.18273047862514374, 0.12324506897599467, 0.14719743612072161, 0.15121159894812494, 0.2203984396351922, 0.138703283042677, 0.11186553000081932, 0.22303286278920792, 0.1395099123399104, 0.1753573879719742, 0.06370368894309768, 0.29797250284783305, 0.15635609386428712, 0.07273852389546172, 0.21959456825448623, 0.10225980632728147, 0.1621683723022861, 0.12490731889321921, 0.24102209346188655, 0.09060118152129074, 0.1908618584275246, 0.12566452019757804, 0.21707544133307474, 0.09225616126411385, 0.10495639751635252, 0.15303266655293205, 0.20642498057455788, 0.18774587240430618, 0.07879614965209077, 0.15940642615239467, 0.18194427323197165, 0.16232220275748163, 0.1772835475182341, 0.18333607112928746, 0.1470886363137153, 0.11360916909911942, 0.08996869933100478, 0.16049899010648652, 0.14376124066691245, 0.15910022080905978, 0.09082502475188625, 0.18523200084605526, 0.18174846115852558, 0.17983740886613248, 0.10185385633620525, 0.1452525227420753, 0.16265221811350317, 0.19352550017497233, 0.1493137693333049, 0.13326027430593967, 0.15449347365046703, 0.1159604921215965, 0.12576572041237546, 0.14677385078562846, 0.09730552338183888, 0.14666109796493285, 0.14754585290868438, 0.28831893698342387, 0.11521308142090998, 0.19267966249777427, 0.14019943743703828, 0.24927243139714966, 0.13651792530811604, 0.1470372011704791, 0.12041616674152114, 0.12455509464827277, 0.16874500730585668, 0.25732059872919516, 0.1775073677661919, 0.1433830996674876, 0.1486936977673923, 0.10545089194971709, 0.1926194633086843, 0.10242613167652201, 0.1679795782171911, 0.13362700059529276, 0.15360056753120116, 0.11558759116357374, 0.11341022372606302, 0.1363943246824126, 0.17121439979922387, 0.15763639532510312, 0.1281468136115901, 0.09766219093674615, 0.18190596883575763, 0.2126095624219987, 0.22458089665780145, 0.11387508587851641, 0.2102996541127082, 0.1665140213745256, 0.23903381950672598, 0.2189319175217421, 0.11822946069221343, 0.11589889099160511, 0.1284938054760137, 0.10672448248031641, 0.12414165231729708, 0.12436702006286192, 0.11008957731387309, 0.1184030945202516, 0.09028007576782858, 0.15320260017629594, 0.12202161890003951, 0.2436344992489584, 0.2579444700912122, 0.0751698111754752, 0.20165096577857772, 0.0941111129378119, 0.12779910928539692, 0.14235461130738258, 0.17440325610579985, 0.1513984631146154, 0.17022625362921148, 0.1914291005701788, 0.09538252777870625, 0.1472569764741967, 0.08104618819009873, 0.1447064552696482, 0.22589299076747513, 0.130029053337151, 0.13236755204777564, 0.19525730321484228, 0.17537082515416608, 0.15390350933997862, 0.1275578835197995, 0.11763802549291043, 0.07408063333000868, 0.08932939129731349, 0.19755156800871898, 0.16012723828035016, 0.3239248038059281, 0.19071072460182253, 0.1538373193433208, 0.1224453344700798, 0.1364149018040588, 0.22265634589618255, 0.18136840493929002, 0.19517323272603174, 0.11230344118009652, 0.15995188075448238, 0.15271207407837914, 0.05334639854188408, 0.12605930062671825, 0.07155517852234264, 0.0907282984905666, 0.23868331895960918, 0.12099536751667339, 0.18731169973409947, 0.09165026232480042, 0.10711434462498273, 0.10158036294723712, 0.09994627442210914, 0.11233914853824724, 0.07765477823634302, 0.21764930247539477, 0.25753623715812163, 0.1222910060577335, 0.16975584500018628, 0.15490230413213854, 0.15007287053571594, 0.19804168041915665, 0.17780795002416258, 0.07441588106655306, 0.17686825125448166]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.027096349851138173, 0.015304435322421695, 0.09690323529104072, 0.02770837940906565, 0.033085154099089485, 0.036344095959418246, 0.043871641429441596, 0.09194839310141341, 0.03812447663456683, 0.027290650816153617, 0.027578010396551222, 0.08955620694905521, 0.0400541372026407, 0.01522231835781807, 0.04476327584275315, 0.03438568794198575, 0.03764294823932071, 0.026571819025482384, 0.05316619550989521, 0.09254095444996512, 0.040306915574136286, 0.004491798538384178, 0.008762787554352995, 0.01110594695238697, 0.0719440064483112, 0.03508129960767204, 0.016324640356845433, 0.013330708419333303, 0.027098127175122503, 0.06917794640626639, 0.016340892912159045, 0.05743070437963452, 0.026583394614018263, 0.08120506716471526, 0.05249688364264946, 0.0358489963165935, 0.03807980604770203, 0.04303516917711785, 0.0191791586562871, 0.004432571323348149, 0.06930519361048937, 0.012522130385942519, 0.09948836068712896, 0.007416633654370785, 0.08384890553932037, 0.14428191998552892, 0.00820257331079413, 0.03817994140028473, 0.03710020175804535, 0.059686921416751804, 0.04013406315578088, 0.026390313644022233, 0.019945953296677723, 0.13149033540919905, 0.05319043453181944, 0.08058312634426741, 0.061444334775930455, 0.04720001000790827, 0.13159040181386855, 0.06564131682558406, 0.036583747414331284, 0.06147472548388666, 0.02356297997457366, 0.044580935425455534, 0.03258260425120112, 0.038728468014948794, 0.04625322492492776, 0.05491113695766657, 0.03673201607119653, 0.012325479446219341, 0.040720733288194866, 0.006961518055534051, 0.06851665164914823, 0.06358371191327611, 0.042858984276291825, 0.04721502150078455, 0.03315403689480117, 0.035312826700148084, 0.035209355034655145, 0.04674867313775805, 0.0793811267301921, 0.08937698834004904, 0.03183583897959081, 0.0607731230106325, 0.021899439199196718, 0.05065669065281268, 0.056421835531270316, 0.04912408579501414, 0.036583521418393626, 0.011461542941810144, 0.12284594482832378, 0.03395557553777772, 0.052504655604641286, 0.03851006017817605, 0.042342338410596696, 0.008891403183130728, 0.02367073981722276, 0.05447995586080417, 0.04274553048514551, 0.04046716201569765, 0.03723324058697589, 0.031234203319576, 0.055239953386086615, 0.028182589749415076, 0.07262734921589013, 0.03121873791960459, 0.061747238280311714, 0.05491161576261925, 0.02423416301157446, 0.0238420772967079, 0.018807969904775103, 0.011094699824048627, 0.02071548861661746, 0.06230325723487524, 0.05232061830259139, 0.0457709534243951, 0.0810575262913781, 0.0069471127297278615, 0.020417269739893176, 0.02556692425822539, 0.04839020803751004, 0.06608308908799965, 0.05246091581460449, 0.054346572292307695, 0.018788155040613586, 0.01916984685756747, 0.008489433976431048, 0.07944213031160255, 0.10871594336124198, 0.008990782981498108, 0.03313031498222582, 0.032751557282021934, 0.05885451709130599, 0.024682027588207877, 0.021737112828920928, 0.03673366316023373, 0.0448382030721874, 0.07268970877292656, 0.035428915833753925, 0.11420698581083168, 0.025731759566453197, 0.011979764075799575, 0.08997423048581808, 0.01329226612729291, 0.08123748034479157, 0.03659912662941121, 0.013777150945257277, 0.01554915636417366, 0.09152149826648737, 0.060328657949163075, 0.09631092675150403, 0.026594054727484624, 0.015541133508386632, 0.041193352080881596, 0.07671590684162033, 0.02512394349210926, 0.06397552375170974, 0.004477240473798086, 0.09476932802147443, 0.04886932325579467, 0.03122023945193618, 0.06207128198096349, 0.023555458906377037, 0.04960135474140125, 0.060563486880592765, 0.012307836441323163, 0.05695975948906234, 0.05751851337751555, 0.049137074815770315, 0.06007749985362734, 0.05525522917929677, 0.014408159373898902, 0.03773512393837014, 0.04373337788086745, 0.04173823594746571, 0.0625513624700327, 0.0816262699663639, 0.04618146163862079, 0.042973966412847085, 0.04267282874113129, 0.00321130579498957, 0.036292982573110255, 0.027468819884703528, 0.018804013060646194, 0.03137633752738757, 0.04464470841471226, 0.044100207592090296, 0.04361998537675508, 0.056758496700034994, 0.03127557589792677, 0.08354914299542866, 0.022918271021016186, 0.02771290507347834, 0.01034149366821493, 0.029804878605289326, 0.04960486342409446, 0.025061003623470187, 0.009300691402337004, 0.05486841606456907, 0.024221746641541683, 0.006663292475540432, 0.012499520258467286, 0.014288280977897588, 0.03003707985513874, 0.01802206137067368, 0.04359098894882106, 0.022451995436342496, 0.01939931508874701, 0.052073148920411066, 0.0104394581191422, 0.031617764391065124, 0.05632102985175387, 0.01653101486754754, 0.03501186522865488, 0.07363756637900107, 0.03227211647636948, 0.015652689316700545, 0.040638375005895094, 0.04195056104611966, 0.011693065246236662, 0.050929329853745244, 0.05665015271534363, 0.016881703106205792, 0.037524687246449535, 0.09145750694217221, 0.06218208127745217, 0.022251887524861003, 0.042682615514363975, 0.026377115864306692, 0.08890695509410675, 0.005162956198722485, 0.029489229313067855, 0.04159938251118987, 0.016260430697471868, 0.029445525912207463, 0.09934838110160443, 0.029219976220760616, 0.029109125213337042, 0.06488087496930553, 0.08981971055149071, 0.03491712313505911, 0.05643349538947787, 0.004981006486266251, 0.03777366582184069, 0.06827745601655015, 0.0671600325093154, 0.030914909364054763, 0.04875103928028576, 0.022322036280867555, 0.06311515721702768, 0.07292614648899726, 0.02225875741832199, 0.038712510403486035, 0.011016911256217189, 0.0251422778913571, 0.02400361268120187, 0.06952401896518084, 0.04821195852972808, 0.033608809669291785, 0.14040603602845825, 0.04862112225964666, 0.018057113723649133, 0.047523502125254566, 0.021722685478086916, 0.04703820074698137, 0.031122689646097924, 0.0730599897102483, 0.07285823279450979, 0.049885998540107286, 0.020422120991673683, 0.03018564345585483, 0.013334665263462211, 0.05719076181131025, 0.01832207097792097, 0.0763107076167099, 0.03199012334188146, 0.05026554148043356, 0.00924827853938745, 0.045924791540469856, 0.0495626328272685, 0.0592914629997986, 0.03012579858242985, 0.07792969654885032, 0.05178065655092078, 0.025050381814400037, 0.030357821716836868, 0.032902583855414586, 0.02839122038905419, 0.06391214529773401, 0.031034771480687687, 0.05540807521150959, 0.034004589843173186, 0.02746929102877696, 0.03390714345920471, 0.034682424438576546, 0.05501837394530735, 0.07138552835151073, 0.052061266896705476, 0.06405643412783261, 0.035086018709285606, 0.018823134615236235, 0.04787925803553193, 0.015889040847879746, 0.0774458047723578, 0.0481357021377452, 0.06669562234873734, 0.046196388861825394, 0.04024243778398922, 0.020865739525986776, 0.06472036422741029, 0.09173830880993798, 0.033974367674560316, 0.09598421323443614, 0.02611556004041866, 0.03305458719091069, 0.04998308103231173, 0.058635580653865496, 0.020423817876425963, 0.04260048705844149, 0.03423898976536528, 0.07092114883444964, 0.03309039031005195, 0.016443156073951436, 0.06477074216931097, 0.02215791918006876, 0.024127268848279794, 0.023835498516658143, 0.03286139513816565, 0.05646216623004406, 0.041997338374776226, 0.028827218263740503, 0.049849168863147504, 0.10259788858914569, 0.023402279625917156, 0.011436056154179237, 0.02773136587723369, 0.035374753417507294, 0.11100775667376096, 0.032978434220797596, 0.059886966125979546, 0.07425892497262648, 0.01986252823694339, 0.016614223507443265, 0.03199332558940495, 0.03633586051423223, 0.017753432640024734, 0.037488213800374544, 0.011050988762308995, 0.033113372947780356, 0.04406671422804075, 0.015557819860987367, 0.048548562241898435, 0.15381245212929864, 0.11257428390484665, 0.15654577723433896, 0.14144849783230212, 0.10717092021819084, 0.09559962177468885, 0.17273068698423524, 0.14063151102633248, 0.22476158615562225, 0.18415514169441116, 0.18039075417384026, 0.15810888771328235, 0.15830224830537074, 0.10673946716011533, 0.1756594411187595, 0.13630593345770914, 0.14238628138217235, 0.08740594370230552, 0.20352918354253616, 0.1871229969565907, 0.18401939091422867, 0.07770634361452634, 0.10294452039224487, 0.11697712910151291, 0.20398211004512928, 0.09305524459529309, 0.12845550107979967, 0.20527482213031864, 0.1080692655617191, 0.23522993249277915, 0.11753601322491324, 0.15358714567076776, 0.13333634683682075, 0.1942778598036497, 0.15626970978994525, 0.15070667039723168, 0.17889196443701946, 0.12641097328835918, 0.17239693311914323, 0.09556281891080642, 0.1250489915330564, 0.11012416618365435, 0.26319689147414704, 0.08747667660035434, 0.23522752697669694, 0.17977033020748248, 0.08876139072761421, 0.18059275623771454, 0.1434839474818399, 0.20341172694198548, 0.14733753828031404, 0.06328500274028029, 0.08269603514382917, 0.3406319863373234, 0.09406639638567164, 0.13765830847044147, 0.15274326917865585, 0.17700740346504798, 0.2782916427860337, 0.23226134178619232, 0.17583485993166126, 0.19181937640232427, 0.14341870743420818, 0.1368939059395944, 0.11446742506157007, 0.1311504221971958, 0.14099201668174038, 0.11836344947017009, 0.22836256712194414, 0.0991668948723424, 0.10474929330690254, 0.14198508113622665, 0.15099127206110186, 0.20352930611660405, 0.13437133162252365, 0.12466250017525689, 0.11964468555825374, 0.13743315522949542, 0.17490582510588631, 0.2115573100144825, 0.11939849554290695, 0.15361110890103927, 0.1987772320787753, 0.20886564477076455, 0.09213517299823223, 0.12630755907946056, 0.13769583145697273, 0.09663623832767049, 0.20681062923564067, 0.09808655002064283, 0.21887012486976964, 0.1453171805628846, 0.15441367793227398, 0.11909723146668366, 0.10019200478470135, 0.11503297414991165, 0.14079502483289089, 0.17753428809585112, 0.22764714825297558, 0.14620999475159954, 0.07233756113677256, 0.09099234601542835, 0.15363611401088778, 0.1075139667298044, 0.19613124099710297, 0.09134080110778732, 0.1741952632343577, 0.09966567939808292, 0.08838412306842305, 0.0937274867488492, 0.13570046352763332, 0.056958016639034596, 0.09154750695151669, 0.13392919163790443, 0.091005239275194, 0.11467927135527135, 0.20898304008428129, 0.119949956274321, 0.12982331276420625, 0.1451993102748548, 0.13265503420224115, 0.21245384739050943, 0.14079548448564547, 0.1415667358425356, 0.12136413159990504, 0.14477633781010105, 0.09223818884141023, 0.1906552904796216, 0.16247211084250482, 0.12297102400372106, 0.13400583107384945, 0.11938124324285215, 0.11703303053734765, 0.15935278467593655, 0.14528422346038206, 0.16047203913331032, 0.22564847082380327, 0.1068620412280002, 0.2097356755046114, 0.2502221199533632, 0.11517811716804582, 0.12284836566616451, 0.14102740994384214, 0.11858520894161156, 0.122405995855168, 0.15346791174623275, 0.0828271740747075, 0.1279114254359757, 0.13895276723609817, 0.14953202778293243, 0.16321725392293546, 0.13629350751157732, 0.15021041396164125, 0.10838725333732945, 0.14061536189288865, 0.08196970718281885, 0.14532880977757517, 0.11857935602987006, 0.1860177312647143, 0.09254499173332607, 0.13185352237234194, 0.1444251477838524, 0.0960720988411096, 0.13547797627266378, 0.20685913792300611, 0.09544627395488563, 0.13376483513462928, 0.09126862030356162, 0.11967008903382287, 0.12172188699966478, 0.17120888396616907, 0.07445195614690743, 0.14788904497700353, 0.17797929324930717, 0.11782068383669662, 0.1766204524544939], [0.064569475549844, 0.05408624795475795, 0.08563542257874243, 0.014275959411245442, 0.06535122997217602, 0.052475241658788536, 0.037490822329756715, 0.04211242393320126, 0.049320028103407354, 0.029674563218929598, 0.02844424133429364, 0.034307175421065865, 0.05208631797182945, 0.011420518933464924, 0.027923489237324368, 0.01952805041876291, 0.06259812830737041, 0.03346377007302738, 0.043322965427632296, 0.031147466844788967, 0.0578744110140589, 0.07157805390776166, 0.032195224231409456, 0.07967667579050026, 0.01660299265847331, 0.09639463717899016, 0.063496389381227, 0.040557797878019275, 0.0836910378007639, 0.028787534909262776, 0.0693206072995259, 0.008101903611884244, 0.05457796148895737, 0.015296058150969688, 0.048393502215584444, 0.030888042660550247, 0.020388966621530634, 0.13041275613490613, 0.02543522225272271, 0.006156962462550691, 0.04083239060315875, 0.05841117817908526, 0.013926068861638347, 0.023130360547633424, 0.007835864737224316, 0.08519268504554227, 0.05831770396100418, 0.0269487208776897, 0.05816762350619801, 0.009712539312820281, 0.02240967290896562, 0.052406117545380715, 0.041203671285221656, 0.016514042189585108, 0.03704546094541589, 0.042778568026880105, 0.04346119067181022, 0.044335733663531086, 0.032933583603270596, 0.02325774756290259, 0.023121839734695615, 0.07301354179939917, 0.02959949043278973, 0.030752868361530766, 0.07547744910322851, 0.008517059106980602, 0.038162466934731895, 0.05043428766751482, 0.04246769720808633, 0.04108758981249506, 0.03881586332535071, 0.016814685734589736, 0.033739381695106145, 0.0221333890447333, 0.06414672908102793, 0.082510695492308, 0.0412427494302392, 0.04370717767385706, 0.041463961148814815, 0.11362958534230148, 0.010986841347579275, 0.07153068669140339, 0.01723839364375078, 0.03920415882021189, 0.051233650620786414, 0.08369103013988465, 0.056119989228224566, 0.05424756308897369, 0.09601438943777355, 0.03525137112686231, 0.06766087015069301, 0.006887218539392757, 0.03897573055338956, 0.06709268571989191, 0.12549919076263905, 0.09216492019233205, 0.031212180206972747, 0.047069694621548544, 0.07839078954871624, 0.09365881462731669, 0.04924049285510856, 0.0858060839856344, 0.015524991078212138, 0.01917664780311527, 0.013289922855854517, 0.0670081555783268, 0.062432683959242806, 0.04876591670777529, 0.006671313416107648, 0.07440560016660921, 0.029446246034856287, 0.06525391382315467, 0.05398513200963217, 0.05092051218173677, 0.011106149008077, 0.037563363195306836, 0.047823329786619836, 0.025145233075525013, 0.03415490012435663, 0.021334083548056024, 0.035457502404648455, 0.018831163216682694, 0.024327725329766833, 0.021443695408262072, 0.03941102937284497, 0.04708945585955535, 0.0502708274871111, 0.040853040503157724, 0.0636405518068181, 0.06520915130573897, 0.0681891414006391, 0.003138853508355697, 0.042624404323437524, 0.04060159512465039, 0.06076579537963676, 0.025026769069353902, 0.018748787697404623, 0.03232321837135861, 0.06014513009558282, 0.014695244120253671, 0.015737422471565586, 0.046332235402998426, 0.08329148464385541, 0.07251877157438187, 0.028305179139058438, 0.06790177415936224, 0.03743308994378294, 0.01820490166034189, 0.04866729054840342, 0.08272159949786241, 0.09252345700177456, 0.09042627598729827, 0.08890229727952711, 0.03421858884394169, 0.055697135507099094, 0.06151277324064605, 0.06395600000095945, 0.02508180865627383, 0.009193589437692877, 0.023804039116047566, 0.037445305215735594, 0.015091559598072162, 0.05141383450057718, 0.04158602193779042, 0.044115295693759, 0.023656676358152783, 0.014937820115817652, 0.003298140903596857, 0.009500401905707775, 0.05512437753139004, 0.036080324226209236, 0.07686299572308218, 0.021744088059471502, 0.06488832900480879, 0.02086077527623744, 0.005352184225264336, 0.011358024353431839, 0.07587904005401558, 0.03655147979096059, 0.04466366909083821, 0.0396909310872997, 0.060571385247092095, 0.07144026533370057, 0.01857543540667863, 0.03240115249589567, 0.0358634753783624, 0.02086241661961521, 0.03817642505671229, 0.08717771078790389, 0.032453698466622063, 0.043245414347057386, 0.01674985171355788, 0.011707271389182539, 0.00595371023894498, 0.019560371668288307, 0.033395461843258915, 0.02533041567902171, 0.038837597239762545, 0.04370730790880419, 0.033160709520621647, 0.034567652976200465, 0.051195759912051504, 0.016182113528972673, 0.049330163446645585, 0.06381400560419406, 0.046107951671846455, 0.029471417768828334, 0.05493391275165543, 0.036672245891344164, 0.07877928805687735, 0.006397662021505136, 0.03046675175879031, 0.011940807547240008, 0.05398125560473531, 0.03331831295884425, 0.007776389022417848, 0.0254921693985741, 0.0017522733880116815, 0.009582885634905149, 0.011741654372834151, 0.015524017188938396, 0.08582019532519965, 0.021162523903072845, 0.023791090314907413, 0.08657988641531238, 0.04923809499990556, 0.027576051126684875, 0.005141455462322601, 0.09699017860956731, 0.01663451526133764, 0.10534475812868727, 0.01709190422608968, 0.042471002877479604, 0.018499472043326786, 0.04066186326165353, 0.027154020950078007, 0.039069507376200734, 0.045481686285066034, 0.016948249333748416, 0.07510729840085392, 0.08242063419592958, 0.05086783597606325, 0.010762826704810704, 0.04265360376467148, 0.04103031324883623, 0.027361150057385528, 0.015258105197590927, 0.12871931877828416, 0.030886623482670517, 0.025327226838036895, 0.05881058960972775, 0.024807072289648558, 0.03711903219922416, 0.08309448513412669, 0.024517749608944983, 0.016356969267250072, 0.02294953506920607, 0.051043143706215974, 0.021663713944895614, 0.04739958357306258, 0.043795201176356886, 0.032940141315902435, 0.08913384735464089, 0.04257936218392946, 0.11726456529070294, 0.0151388329686597, 0.012451172449565943, 0.04844984798241527, 0.07418200974502871, 0.015532093670880123, 0.03418720605212354, 0.03836250398308039, 0.023563227037929242, 0.025022561331429792, 0.05153900177608575, 0.08977919982205476, 0.02633059900554438, 0.034368389676655495, 0.05970665584168127, 0.02641057858483926, 0.03561527821265402, 0.1118219625805655, 0.029705449968816775, 0.04336381323575493, 0.007380047689131912, 0.010804791086082979, 0.022177894922694372, 0.06814681504282259, 0.009272619067961651, 0.031509359119339816, 0.006956331161481719, 0.027875520641945546, 0.059741022545964494, 0.01675269581497677, 0.03245750592360574, 0.04587770777664358, 0.07828169096741946, 0.04915467568583066, 0.009195093842854184, 0.03907829823513185, 0.026678759154052507, 0.08980496335894832, 0.07020869472574803, 0.006230874625485271, 0.0430435003832944, 0.05627899843778822, 0.04000136140553702, 0.04170323722064496, 0.01608177899352966, 0.006606488971174845, 0.06212178249693206, 0.01588010538985292, 0.032873874710452174, 0.04802378052244744, 0.047289749547358484, 0.029475389934715726, 0.019057923327049902, 0.05637812255431087, 0.06580381939608244, 0.031275763589468215, 0.09009914878275126, 0.041694423379076105, 0.009375061302806341, 0.053948195080362984, 0.01772023996548547, 0.06098170960021596, 0.04346825400247209, 0.02497811291006304, 0.01904220511806348, 0.05175584679349296, 0.034962525335891594, 0.04111082908967811, 0.04195818745140587, 0.05464297171021181, 0.03198640015456946, 0.00513687712936512, 0.03496588463143956, 0.0586631789713377, 0.04079508978212553, 0.012650043129049724, 0.08172339459340419, 0.028754865089731834, 0.0771021070860086, 0.04103800094115638, 0.04225890377476331, 0.037122100381360906, 0.06420802377584962, 0.0629601508168684, 0.006093860757837613, 0.07980665026773369, 0.03205906359418746, 0.022588188632301266, 0.1867256577937834, 0.2192496295056997, 0.2364366435475888, 0.14790239022864451, 0.18692678651742398, 0.12202603922736262, 0.1438976962479853, 0.14859822789026847, 0.1483952299120926, 0.1881921799072335, 0.10481076420194681, 0.11916891431375859, 0.18198954902829664, 0.12082557178913586, 0.1266140938406029, 0.08445888772727021, 0.16264720789847836, 0.10765747031978062, 0.1198338173450001, 0.14126619954984035, 0.18447881384241968, 0.18016333331263837, 0.10192520976547273, 0.2031048627630357, 0.10462429074029769, 0.12451964776001631, 0.12446514060420376, 0.13645458515853653, 0.14150342633647306, 0.18022678071452727, 0.12460168045494827, 0.14642177209738763, 0.16920925658797065, 0.17038377662820203, 0.12019400890435904, 0.14928007678639504, 0.07738031957659029, 0.21882463456882587, 0.1036183560086835, 0.16762665683223357, 0.1192167565046299, 0.1771412083819028, 0.11495030560200253, 0.1261222730540941, 0.13781618386987718, 0.25680741175047817, 0.1360133951229434, 0.09146997885357949, 0.19141848259154828, 0.15689859136698708, 0.06319873740956669, 0.0970957148820162, 0.2501243518124665, 0.1385322922179776, 0.20911359678833716, 0.11422826007248894, 0.18654179669195609, 0.11192729200927481, 0.10473571822888429, 0.1144974250646849, 0.13810335958917297, 0.10816841266087948, 0.1347996360592304, 0.11819321707251573, 0.23258870647799587, 0.10143793954123413, 0.2026955879503681, 0.17106643757752835, 0.09995391231871421, 0.11430026467649207, 0.14451785974444883, 0.17368042150572424, 0.1790978429057906, 0.11984455023681927, 0.16693111028402083, 0.15634127772383152, 0.2164651910143514, 0.16613679968060988, 0.1286785935442294, 0.16781151384836243, 0.1262218568233713, 0.1520254907588805, 0.1286698448201341, 0.11037714373801025, 0.15264046017921742, 0.14416627135247956, 0.1846475370468632, 0.1940100814305967, 0.24925681852525283, 0.15765551687969317, 0.11833249951802916, 0.11696876342137975, 0.16233816802982362, 0.12254284980196146, 0.24152763488311924, 0.15023983173793362, 0.12040615397235079, 0.15780020024507277, 0.13034000842561647, 0.27868945692335406, 0.08561905127980056, 0.1577746129084018, 0.13161352234742335, 0.1518480954391341, 0.11379436319393497, 0.16731352605406316, 0.14371181267403788, 0.11869512723698733, 0.15797925031473561, 0.14156780836562957, 0.13740513173322524, 0.19126860515004207, 0.1681529285926973, 0.24572283960878852, 0.0872875294918495, 0.1106763240550795, 0.14128738954182596, 0.08676333382966057, 0.15922173767560915, 0.2740118159882484, 0.17238629981875422, 0.10103444869239485, 0.07484207110058877, 0.10901248067497246, 0.17597742889436985, 0.18740560679185778, 0.17442323567886509, 0.1369572767326909, 0.18104568274030763, 0.19245846227051752, 0.1808627103004725, 0.1425722568866707, 0.08046024584121282, 0.12037551811625881, 0.12465663960263615, 0.08473009051334474, 0.08404750617281084, 0.11960628923148879, 0.2108486327192476, 0.06445000413805246, 0.13404719982176058, 0.10089327400970845, 0.1405475631115898, 0.11489102571842172, 0.17306188211566018, 0.12216680788344915, 0.061131897307331526, 0.09584863099359697, 0.10911647711069354, 0.23943503507443015, 0.1912986817619493, 0.15484136949864127, 0.26808851608826273, 0.12418021718340537, 0.10661710759684925, 0.1235003064897272, 0.19549586299446323, 0.09917126157351079, 0.09057919479786389, 0.20171907099504627, 0.1633229280912107, 0.13595336447319678, 0.14600290586390804, 0.1631417329753599, 0.14765852912058755, 0.0951157606417133, 0.13290424260400957, 0.1103860303579319, 0.11571569638627192, 0.23774394194685647, 0.19236751231214694, 0.18298469724193697, 0.11478999404296761, 0.19107372770386358, 0.09410201181327144, 0.13381289949099864], [0.03660477652785279, 0.09473350575013507, 0.025898615431581295, 0.017950805617616545, 0.04329329867276453, 0.044067422859370715, 0.08685373220472567, 0.07872994433367446, 0.02024508573325171, 0.033052587701428326, 0.027743295781434547, 0.0539334861922168, 0.029767681206125888, 0.07858980386968582, 0.019032793727913694, 0.02347148417855703, 0.01152453164855439, 0.05891586158184275, 0.06029645927370556, 0.0536073089366959, 0.01773108202483385, 0.04961259325125045, 0.03262174751369223, 0.03313087039597092, 0.0698398616946032, 0.020014234713368842, 0.08676286651602677, 0.03880269427393233, 0.0496019178160256, 0.13410657163589232, 0.03487545944329712, 0.03391949662698373, 0.0797744898966724, 0.02048422390925548, 0.09234076035359214, 0.11411932236965626, 0.030608022202467246, 0.05795880709023726, 0.05393871857273964, 0.05970516580066854, 0.040079766674147504, 0.032859322870330464, 0.015217856853269042, 0.026076728958756696, 0.022855673976723227, 0.029024999183151993, 0.022700206008589557, 0.013403677336511113, 0.05605574892533403, 0.06480743012000477, 0.032985692903880155, 0.057756146190748106, 0.044243167259640274, 0.045800777227287336, 0.10535827191967158, 0.02285333166289474, 0.0655135563424518, 0.05145499640474877, 0.030147475040247364, 0.04100163857783041, 0.017861734489880262, 0.06022376902101021, 0.025256442229053187, 0.04106416284377056, 0.06546246593878155, 0.08111303702237145, 0.1019826203945183, 0.08170477099596493, 0.028084392599280805, 0.09154393698178953, 0.03023669172468926, 0.024859108811905308, 0.04931076993084243, 0.043656079609307556, 0.031491327324822065, 0.03522583358590642, 0.0689686052200775, 0.05058491204474723, 0.022946897811526736, 0.03287505831629519, 0.01864535816674752, 0.050757917680687485, 0.05333439777455023, 0.04461525233402368, 0.03482069181759031, 0.03244550132583226, 0.03253208458303444, 0.02130069552109607, 0.010144866668739387, 0.018836299836214994, 0.035950847706126596, 0.06578214676870454, 0.03182679531164467, 0.016384565669502464, 0.05809466895316878, 0.06669850283933264, 0.07141323775173196, 0.04064766765241662, 0.07516901444403395, 0.06958473909405932, 0.041486622029615026, 0.01867380109615624, 0.10794663786767952, 0.0740699004381895, 0.02639759914018214, 0.05829821085377086, 0.06508409511297941, 0.02435210033229763, 0.05613761691136226, 0.014509000484981846, 0.011670750062612277, 0.09934216046765929, 0.018695504367051106, 0.05983099957267123, 0.059402970927617246, 0.027042256382804726, 0.04561630708556022, 0.05953968697858434, 0.010883933714320584, 0.11650433027816397, 0.019881151834382646, 0.030540277047323126, 0.02043967589645857, 0.03409570068000786, 0.014507806345429874, 0.005854869096149361, 0.040767725121470234, 0.017671055205526854, 0.041306170019050764, 0.023788326652720574, 0.04178354238730766, 0.031588605169447205, 0.009560015995145566, 0.051343745116384766, 0.03619740544367702, 0.035521290715663664, 0.04770149116314227, 0.008636406029484445, 0.09516223153520016, 0.012140007644531228, 0.03260367549955845, 0.02513279755329413, 0.04492649853590035, 0.028113867832167495, 0.033372483035970124, 0.048261516757549784, 0.060779320661939924, 0.052770763906019355, 0.017121122819521738, 0.05298429942359367, 0.007232029447256918, 0.022126875382157105, 0.0811349701196436, 0.016160207244777874, 0.09123302019772031, 0.026857307436124935, 0.0361749054413409, 0.030398353513690735, 0.061605669062344305, 0.020998502563264583, 0.01134081610343269, 0.03403891441262057, 0.03377635309833192, 0.029348790074788758, 0.02001878910607869, 0.07940730395456476, 0.10590915808514242, 0.08236182928686181, 0.042833140300166224, 0.03567701723847178, 0.0036799756438291122, 0.02024847375709684, 0.05505196307034743, 0.06112260466081001, 0.049350828668403054, 0.02326160481560134, 0.01692720489846843, 0.06556178923816451, 0.06612621217725739, 0.03876642001071765, 0.03750933101400733, 0.041287691978317116, 0.09752300042178362, 0.02466695480829766, 0.004106673211114661, 0.04508132107495781, 0.025823364529999036, 0.03443693539368049, 0.04908102399279033, 0.023615753856457533, 0.057734006249736396, 0.04085228973699193, 0.0054587973300517815, 0.07945393572651571, 0.049366219374801845, 0.026607361674729376, 0.08247993706214814, 0.011276746255105302, 0.05203535014222707, 0.014371039541137796, 0.06606527754376013, 0.047664358881452394, 0.014312441475809583, 0.07812445908184014, 0.03198685214644478, 0.076856805732654, 0.023448710299787984, 0.05993228405714036, 0.03222133250786893, 0.05025403867025049, 0.062471202860075625, 0.042527517183653774, 0.06383973849757064, 0.03587788549221812, 0.018688898773924, 0.06888967518123888, 0.016241169331835646, 0.08143803450248896, 0.022965996383479046, 0.041827171094595425, 0.026922700701341517, 0.04098683775913331, 0.0332349932361995, 0.07730341967075102, 0.021970208486421935, 0.04433602477694231, 0.03268335247412324, 0.031431551399310274, 0.04753003302480906, 0.027428766892802332, 0.07543074072248514, 0.009443062139795193, 0.005810464246033301, 0.024176859634838278, 0.04128692589039284, 0.029777768668868852, 0.015638404649742428, 0.06673666167884104, 0.02380790211440575, 0.01404311560514954, 0.024742184642462, 0.032440437484652765, 0.03900037177147404, 0.05982678225864807, 0.01666307693437463, 0.043525706766353506, 0.016920495883471543, 0.03643272467137825, 0.015072393993426476, 0.018818679813956542, 0.10779110669729211, 0.06743551772688666, 0.05085130379865727, 0.022113024512486115, 0.06183824186483699, 0.01664136791782033, 0.0530969143484629, 0.05481351054303589, 0.030407508264385888, 0.05349258343959528, 0.10794211028804702, 0.008373883977201919, 0.036795681808143854, 0.06753218270117237, 0.005568273688456225, 0.054162722681799245, 0.04772102640521142, 0.058717169017801364, 0.06300449581636537, 0.03366737326066341, 0.018833495954412128, 0.051960193086415536, 0.02553308423939011, 0.02539929847473339, 0.05461348881644588, 0.053972169801953344, 0.028767432762129654, 0.06709159787503943, 0.060915780073452386, 0.02318885902153148, 0.04150607683245213, 0.05112431838267273, 0.014861621180429094, 0.04578283544810069, 0.04644011207405598, 0.03301452845335007, 0.030026251202329036, 0.01613269511219715, 0.041168297175318, 0.06498668703340715, 0.04912730336429612, 0.032254829702358094, 0.03055345759006037, 0.04074247869392557, 0.0913700580056156, 0.13713649534169706, 0.023791440800132773, 0.01798742270517734, 0.0346728406786438, 0.023085381610379107, 0.08118356307668072, 0.03302840230565879, 0.053720774219161084, 0.032674228366945064, 0.04071000422681532, 0.01625009042571389, 0.02014091501252786, 0.0818436474148785, 0.04874504081183865, 0.1136610868777479, 0.0800054730667222, 0.07647284246500462, 0.02857083736378099, 0.02116499645184846, 0.05695360780303037, 0.025207247892995516, 0.043733630689882466, 0.03736705699514958, 0.030661332345898115, 0.04042752462649538, 0.0296872170762189, 0.050878817846457806, 0.0416208636165867, 0.02285503046286683, 0.010493947080366555, 0.06390586720719453, 0.043816915938570615, 0.037923470484994115, 0.05247908742016843, 0.026800151531314178, 0.039579472955196135, 0.011327137603544661, 0.019658758425183838, 0.036450260423965035, 0.02287117385065123, 0.03507401411151213, 0.013442896250184747, 0.010123374072023699, 0.03283843548307496, 0.03110593721841372, 0.03618377290906445, 0.072162747533331, 0.05063407190684831, 0.06775833951729922, 0.042490905841752406, 0.030087430983962073, 0.046531916220462134, 0.009555122608529225, 0.08675847683222064, 0.018625190902140834, 0.05471294235077597, 0.01281245472660709, 0.1727106001588606, 0.21429337771429172, 0.1087674014871159, 0.11213785127526331, 0.07307103669811642, 0.13137428841042903, 0.2350646413622364, 0.13158925268198216, 0.08908576767651305, 0.2377245139570967, 0.06915795151144266, 0.16245096681579468, 0.1640498382790435, 0.1486601584380673, 0.20054896362125876, 0.09143486904400973, 0.1293952381538768, 0.11482276728436833, 0.14227446318874437, 0.13982662840956642, 0.16281043059162556, 0.15292909146556932, 0.10744942382218377, 0.16254116600799948, 0.1797811780124903, 0.14584521432557415, 0.15156859592083963, 0.14678548000031902, 0.16387961354226838, 0.1963801276419432, 0.16327881674853065, 0.11756708575112206, 0.3087941076486342, 0.10096695634626573, 0.18275456442948312, 0.18092430376958463, 0.20636568536921857, 0.10541595067949065, 0.20482184966245007, 0.16841263239902837, 0.11657325520871148, 0.21321086483376644, 0.11930396029305075, 0.07906837899598383, 0.09171367908317236, 0.11352562721097663, 0.15200840699816906, 0.23879910548848493, 0.1221771270877892, 0.3045965280503996, 0.11229567304854432, 0.14610805909239477, 0.08955756292468117, 0.1572105423697541, 0.1461303828945083, 0.08618866063414082, 0.09537343431504504, 0.18077960508244653, 0.11840874058825356, 0.10472176776778315, 0.08347082582692947, 0.2337747638023669, 0.10369816704863503, 0.08729882162785338, 0.15176140492962253, 0.19177534166843663, 0.14744810008954617, 0.2225769638654686, 0.14523600588642782, 0.16012258046577055, 0.21259552769122586, 0.16015195227678747, 0.15371088419229756, 0.09623440988962689, 0.20811405123001148, 0.13485130102884385, 0.11811219561364382, 0.16794809200350316, 0.15036545483575714, 0.122071675085012, 0.12283328139493543, 0.19528031649608768, 0.20976382157494947, 0.17307832236251525, 0.18231679114603228, 0.08485284078145221, 0.09570558705637533, 0.10800977883439873, 0.17550764845744257, 0.13573320612551706, 0.24068021906479714, 0.11207728436396969, 0.09558462177313144, 0.12696100143535485, 0.16514545126307398, 0.1459791111729799, 0.1571756240821654, 0.17047604425780236, 0.23446366070739685, 0.19620642486599185, 0.14473426426129957, 0.09661451973501714, 0.2005796990687809, 0.20618154847573852, 0.10447324884514655, 0.12837493927368235, 0.18126671442822104, 0.1620343222372955, 0.18860802775429142, 0.11552101812295376, 0.21141020581126216, 0.22584740853598043, 0.14302450923189042, 0.13006904312679846, 0.16365761658357036, 0.07068608241576342, 0.16012431182447942, 0.18126570319216098, 0.19963016373015222, 0.24138505059865215, 0.14008764988712727, 0.13722528493212116, 0.09420812265166352, 0.17543059533401845, 0.16305755523423995, 0.1304902995546018, 0.13038329239333832, 0.09543197875421855, 0.16206013940034375, 0.2503195356938147, 0.13174596362777297, 0.0956352831675641, 0.1410287276150719, 0.21218210068200866, 0.23041148459719074, 0.2104699861017927, 0.10773810873469038, 0.12173114900266933, 0.1798244006931782, 0.10170695897672447, 0.07636637156528812, 0.18846392661573427, 0.0803496380667052, 0.1342476697097863, 0.11775816340119609, 0.12775745708495378, 0.15383917327609756, 0.08984867633590776, 0.10826472523472003, 0.1650813143820532, 0.09545885311860232, 0.11761480536792548, 0.21122162560782126, 0.15446093023544358, 0.1662895576127114, 0.08173430368544594, 0.12080889405502428, 0.11702105658309114, 0.2139412837042924, 0.19164458578152044, 0.13752689374791038, 0.11442660023608517, 0.1330664540610967, 0.08880734068131255, 0.10913063441553425, 0.17152716285519062, 0.12818298828337463, 0.2842774554606407, 0.1084364974691022, 0.08652424544937189, 0.15591462803704126, 0.12261375890023286, 0.16609068118756817, 0.14021454469090508, 0.12342681567515097, 0.1257298751583984], [0.07492691533820284, 0.03959541907534003, 0.02587383248723082, 0.026882933077192115, 0.01672071355935787, 0.0726285060086558, 0.07062347771059121, 0.014760077183675623, 0.034865400708851316, 0.04883704797154473, 0.033159468458184314, 0.03569543399217148, 0.03937440653962474, 0.06886083197088973, 0.06914927939613981, 0.03685337972016104, 0.014581631365863067, 0.07303018122911453, 0.0479018921032548, 0.01789832093392409, 0.07125391444611935, 0.08676581595453524, 0.06993003024329102, 0.014436915441746674, 0.03208522358158183, 0.03400864627873225, 0.021653632227812084, 0.004719831791120552, 0.005151344699815157, 0.05079681196460321, 0.04940510982827795, 0.08180833842244842, 0.015442348385770476, 0.07415449952766781, 0.044258224717792005, 0.0588773196983722, 0.029789330850866054, 0.04042692707791444, 0.004433270857384008, 0.029382344725872242, 0.02707892709652022, 0.025770297619484128, 0.016802229144940936, 0.041466014264451886, 0.044876109102680806, 0.06560854358418335, 0.012052203434699727, 0.04592921569823258, 0.019896766621499293, 0.05487693496228707, 0.04212938128940521, 0.13124042220654028, 0.025718963982897903, 0.02879628937901749, 0.06179753578298035, 0.019125999815221277, 0.02717014710088411, 0.015287798765536039, 0.04293779174106256, 0.022861515397145864, 0.02919281457340525, 0.03460965757708877, 0.052089746215290604, 0.025981184388060245, 0.0404793045092975, 0.022911117675023216, 0.02989702366082178, 0.05573033392729779, 0.06871180488697945, 0.021874663915725488, 0.06750061987869202, 0.04179455107077957, 0.016282955597665523, 0.016956195580743013, 0.05692881719780065, 0.04537004429186064, 0.024049955254961407, 0.008178384084584973, 0.025308909675767346, 0.05364492385377807, 0.07457109814089152, 0.06373586846635708, 0.06803933290704604, 0.016096292529255152, 0.05966924393789903, 0.03356721109500335, 0.06571530559731108, 0.034705725002793536, 0.01616347844021455, 0.07262986964516102, 0.0877950091155306, 0.04296805221407164, 0.07927176001812182, 0.037671764636592525, 0.02610848138799831, 0.03151437508002405, 0.01239314320452151, 0.03424589604800267, 0.03785831853747368, 0.09171168725456923, 0.017838550754071727, 0.03820621821608755, 0.02583195237563022, 0.0643116103545312, 0.12174461682837819, 0.03942319484908254, 0.03663658066802929, 0.10967863242953055, 0.022298214776862054, 0.04714094845938587, 0.05111084672652426, 0.05148868129077939, 0.04182324106354387, 0.03986056210593351, 0.02365361009123585, 0.011909064694097447, 0.1314727153869406, 0.058439592380196824, 0.06948144745922859, 0.03973815657739197, 0.019990131672051166, 0.028179843324206533, 0.024798137789231636, 0.04891860186152401, 0.00769183733462987, 0.031736952350324685, 0.041768933090591626, 0.005961870032948472, 0.04881182835707742, 0.02502848510630429, 0.055365764175451575, 0.042677670416812745, 0.028777428294321703, 0.044764869305635654, 0.06536096694969362, 0.08140410446832258, 0.03157238517287037, 0.0490505566760417, 0.0645559770806182, 0.06526610228202998, 0.030448551424929214, 0.059005566647336374, 0.0231614081759847, 0.028516671117094737, 0.036557581681277485, 0.029085924240550207, 0.029387715002221447, 0.012507892641869765, 0.017264444463615938, 0.0010153643163521924, 0.030076832157529654, 0.019652124103759567, 0.003671823510704863, 0.051122123540769664, 0.07033076317560288, 0.0492715347378004, 0.06474460324933452, 0.012719880661837036, 0.034640979081872976, 0.09495757880710787, 0.05239396739090162, 0.023805351041617896, 0.028525235980088194, 0.04710798369600408, 0.03339625857470017, 0.04843723817518161, 0.05638369584396001, 0.05847512353812495, 0.021725205907357797, 0.056001931248653325, 0.04480411215955692, 0.048214881155159206, 0.051748768141072606, 0.0826057133775565, 0.07331521956310158, 0.022182125643256213, 0.057810373724468296, 0.01638690223767152, 0.021450810449858828, 0.0073093425617703515, 0.03738383049025171, 0.06216329680154882, 0.11384994287284152, 0.0361928204074502, 0.0854106447208793, 0.07887481922103513, 0.0208260657476081, 0.05684244844521727, 0.04175731536721991, 0.04050281957813329, 0.029636124757328824, 0.0338339246058416, 0.0052753350727500455, 0.012567236685314247, 0.062172409417408134, 0.07748324348921738, 0.06404108938670929, 0.024729737628912254, 0.037926151792729096, 0.02984714176085207, 0.03536888518400731, 0.07525296235877661, 0.021289516383061008, 0.05258415254854387, 0.10399858842814162, 0.03003246417539495, 0.02323736962411673, 0.025925537676460324, 0.02259600847478836, 0.06003728023760262, 0.0009707234153944639, 0.017680514476171905, 0.02446125253974911, 0.07860074360524455, 0.027463457269233563, 0.017865315950926275, 0.024778437838258765, 0.04063750932654066, 0.037276145341175224, 0.025086759499484496, 0.0324013555091956, 0.07318968839582897, 0.021315787453204397, 0.036564629690180865, 0.02207414555032888, 0.03156422059081736, 0.06844263223390426, 0.04884688071005287, 0.030591164437693455, 0.038106151811418035, 0.06726428941493073, 0.02866027046806149, 0.04124181480297158, 0.05524687882092211, 0.02319334255110833, 0.04504962035665109, 0.059197130763242324, 0.012320386876742686, 0.01218848281554998, 0.039510065389256326, 0.021030163061955286, 0.04489912621436581, 0.016572847098652876, 0.06699240481060359, 0.008284337874952584, 0.04818463983434824, 0.04969508559893697, 0.026058465422641848, 0.06209749750973237, 0.013843935617666333, 0.016846662244549202, 0.033313904122840014, 0.005404469247291526, 0.02652793942439941, 0.04780129326747791, 0.038968667222727696, 0.02542508690948448, 0.02964452491141856, 0.02005665491695606, 0.0044979401695121445, 0.06593693483380542, 0.09964640462590803, 0.0299958375117351, 0.061553375900632916, 0.032160440009207494, 0.07047333213831149, 0.027882968931789362, 0.04198202427716986, 0.03984247860048087, 0.04058116739014945, 0.0014326038100050704, 0.016134418810026783, 0.0350874857676606, 0.03117135346626803, 0.019453845227197297, 0.026662581292311513, 0.012841951984521604, 0.031253227197955695, 0.01918000901388305, 0.00846742618558628, 0.07925191834088295, 0.05893144381022262, 0.06341700735051306, 0.04116890621521781, 0.018358753182955326, 0.029599099727948348, 0.022705873144009424, 0.025631944055578885, 0.039471500523148045, 0.035992281571511305, 0.011920744662113007, 0.057838830060415694, 0.10028473206705625, 0.04183768565135618, 0.04404753521685639, 0.014927600502907751, 0.02687502704981354, 0.044209103160087145, 0.009785384698320302, 0.00901123465624668, 0.012803100793051624, 0.0447505587832101, 0.04786840256964488, 0.012554654648767845, 0.004033623854704803, 0.04389988326077019, 0.045534458251730095, 0.006468527548525844, 0.03307143346436563, 0.041635446100225376, 0.05450541679296763, 0.05387429440874727, 0.015678715238708164, 0.024672688976410898, 0.03396993202547874, 0.07547101396466456, 0.011838948496827676, 0.03049371805372498, 0.03226741652695402, 0.05912290450425879, 0.052461467397909974, 0.02869962440473178, 0.003749167986942696, 0.050053894369592594, 0.06174290605309991, 0.026498751474484324, 0.040766284876172586, 0.06278196642656, 0.04236363565489169, 0.05783311504450056, 0.04381726833901579, 0.01676640304316196, 0.024932053788835486, 0.04866540980254931, 0.057685524375448306, 0.039494418043402896, 0.016721941215256532, 0.03526160606153069, 0.023506446516201384, 0.02809364311096649, 0.026838262490327322, 0.0826689079704304, 0.06881350305892768, 0.021165743387574633, 0.03226209221588027, 0.043242710056684674, 0.0654789061856366, 0.07742400957091201, 0.02098906436003745, 0.06245216557515725, 0.036204510909174724, 0.056125413130728476, 0.25837317289363954, 0.13785094893988104, 0.12153886093367493, 0.11158485836800068, 0.08183419388989288, 0.23222890562347828, 0.261099434668018, 0.08579135977572973, 0.2196978675501962, 0.1554177740528699, 0.09347841624290713, 0.14688692536325226, 0.1216171014933817, 0.13028049871565836, 0.09904710170362266, 0.13562855851506034, 0.07373643768650871, 0.16436396497151545, 0.20760235046186756, 0.19296313035151652, 0.13162807801798468, 0.10898804247018792, 0.19210013230481457, 0.13998347725118362, 0.10371177277017025, 0.11973736687533318, 0.1271982052393498, 0.08554112481614275, 0.21142021091955326, 0.16338855118280457, 0.12284808987451178, 0.10726040694862606, 0.09957416253464837, 0.20180879521273798, 0.10767084621493855, 0.1581429939476713, 0.1752695483305762, 0.14475101094332435, 0.09409719312022771, 0.10831321093944773, 0.145467410404836, 0.1362425013775787, 0.0998239225197223, 0.09436522430229573, 0.09556201451848592, 0.11796927425049006, 0.08656286394163486, 0.11522309419008032, 0.1331551823644869, 0.12339669309796826, 0.13523299667623737, 0.19053700650411268, 0.1871540694827995, 0.12208404740498913, 0.11032344097451818, 0.1305409686099137, 0.08614425817804952, 0.1420326551963245, 0.11597156209210235, 0.14742235953529037, 0.1541166962875474, 0.13620896204825372, 0.13872908488396676, 0.15209436206327331, 0.1363025779926008, 0.13099297580699767, 0.1451971652286668, 0.2004261444052381, 0.15378442863302846, 0.15998483785698492, 0.18386715392191566, 0.11430322943675904, 0.13041217390808368, 0.10089232406068234, 0.09403286471722588, 0.1341480016708374, 0.08134361416582139, 0.11213783595350482, 0.10566858349428063, 0.155008805675372, 0.209651988059763, 0.1712463303439079, 0.4062054354336954, 0.1027331950383321, 0.19621848308992004, 0.1981049439599437, 0.16791410834318207, 0.14839236474325582, 0.12667441560376075, 0.1930785798017056, 0.1503202556482246, 0.10455976315443555, 0.09139143951958226, 0.09880518645889337, 0.08258512859503109, 0.09559828112082136, 0.09024115850127513, 0.1865674299939025, 0.17462719892782552, 0.21296398533928781, 0.12211194066631219, 0.10856854804461041, 0.15208135389031904, 0.14153431500158004, 0.19327209361137884, 0.2301534508625346, 0.1848582418695573, 0.25277970448857356, 0.12088897322574932, 0.1318310759961605, 0.16181506787336644, 0.18057535072007488, 0.14987131280283775, 0.14833377433880685, 0.11528138582023884, 0.11547091597270583, 0.2774213669040511, 0.14514430516189145, 0.15112542937840187, 0.10255439011680503, 0.13897389594104984, 0.09548664678849521, 0.05772243449164014, 0.11690644216873955, 0.1557654247529084, 0.16719565576603337, 0.12331388665423279, 0.08232555502364713, 0.094284018982322, 0.12222326856346862, 0.1284180470411816, 0.2001572015785402, 0.1079933615701814, 0.1677636486748534, 0.1341336451831364, 0.09866784221582836, 0.07896809042581628, 0.14170168989127682, 0.15823225851260847, 0.1493134475763767, 0.1520320944367878, 0.09059214934466348, 0.12413608285808757, 0.14777445354528967, 0.15055994923797347, 0.14504229289389428, 0.09352510164101278, 0.07590861870877205, 0.2044709047843372, 0.18083856320909916, 0.1513875233790567, 0.09483344958073671, 0.12855491630973356, 0.23543553516989757, 0.1361500805303935, 0.2166779183091656, 0.2084400522853098, 0.10851392597560922, 0.13638738392581864, 0.16753978246162016, 0.16854686632512078, 0.12328359553770674, 0.14438551039465014, 0.13958580100968962, 0.1857264339923859, 0.1346390640303012, 0.1829658208354827, 0.1592658796618062, 0.12881596843081136, 0.10914497558147677, 0.11032842820690525, 0.2438836770072099, 0.13540849209793154, 0.16060947530692624, 0.15292385142416726, 0.12944051395020179], [0.05587970958121362, 0.03435011464922178, 0.09288804590581887, 0.024036054589575338, 0.1456174104204101, 0.027378329579087517, 0.048679735646733356, 0.028480986741581754, 0.07072349814998527, 0.01330731783978521, 0.00515784734987744, 0.021273307877803044, 0.04506263619048461, 0.06676245585925157, 0.07113600585369334, 0.06425226535347682, 0.010585336581683688, 0.06944957820157852, 0.04999930294410837, 0.034348988499973095, 0.02401424023593145, 0.02920295949274254, 0.06222527714506273, 0.03349984898382137, 0.04652977883515339, 0.054706185455283815, 0.05468900593358183, 0.04282713800127949, 0.10283774305735865, 0.048312247099895636, 0.0329967973483426, 0.052962377817640384, 0.0015667471222602012, 0.051201689432585434, 0.005012269098041279, 0.02747415185665652, 0.02687171946520046, 0.04235971328471938, 0.031006508581941167, 0.060479983296846195, 0.025005012172304338, 0.032417297798899875, 0.024555282171575293, 0.03126479895605195, 0.0299138143929022, 0.014036952427798703, 0.066829863935709, 0.017703416674668272, 0.027584891781331073, 0.011538876644936542, 0.008681252816571824, 0.02201982608605777, 0.055605434782562725, 0.012923481934253248, 0.010104770584392452, 0.10506828465769369, 0.03898205843964412, 0.019563244498004357, 0.14000944763181672, 0.055445847176616235, 0.05467571047765594, 0.018157653187611894, 0.019644453648417708, 0.03311198632863741, 0.03167281929974354, 0.07278225985505889, 0.00899597514240492, 0.07647746197518802, 0.06716206264231475, 0.033506031313370314, 0.06396461082922836, 0.05265254887842363, 0.025146667575163227, 0.03833836455258631, 0.01677225020924403, 0.07257351621745095, 0.062038627483191035, 0.038112870402513974, 0.05778674757288349, 0.05378737790329803, 0.026634054093231118, 0.04965067548196643, 0.011440291662790604, 0.03331263241688571, 0.06336143533248575, 0.1363915820876437, 0.07790163474818391, 0.034653933628672556, 0.04596577341397924, 0.06705868673781235, 0.034411259956898234, 0.020746448144857443, 0.020319605020866282, 0.06275069088705125, 0.016344780808374766, 0.06714140125099691, 0.044890676264560996, 0.03708749235938153, 0.023826022009034793, 0.026067036031294736, 0.03527613108857505, 0.02920441697501848, 0.05113484443075234, 0.05898310111895685, 0.022193419694479917, 0.09536627905383226, 0.07542970650378736, 0.01622188115312207, 0.02496135090627978, 0.011633642678779942, 0.07064486688543713, 0.03101500641224125, 0.06015799654227111, 0.047752313436039036, 0.029876322049887914, 0.03774196893397359, 0.012599105942964315, 0.030566710911150423, 0.00964965690077553, 0.10893095359807053, 0.014170661583662996, 0.03178869775917021, 0.03399076195613992, 0.013332728976233593, 0.03600917764068131, 0.05855164040000208, 0.024508190746869774, 0.012659245760240143, 0.05438835472769795, 0.02427937752086549, 0.04216924850498477, 0.04600663271342074, 0.0682169733749282, 0.03245796174592069, 0.03295009662847846, 0.04591427698370911, 0.050935787974946925, 0.016220628599365874, 0.01668295883122952, 0.017602279662124572, 0.03379181658308353, 0.039567502831379255, 0.03098722614888703, 0.03158045782437248, 0.03528079656403392, 0.005787668821041383, 0.07041638116202048, 0.03427629441683812, 0.051948843493817315, 0.02865903898172321, 0.03442240270575689, 0.04019200238549421, 0.08356636465196648, 0.04209031080526691, 0.014053238499459001, 0.03726023369498792, 0.05609142947040739, 0.03976637542608284, 0.0675307577776332, 0.030717053751070655, 0.057563923239227266, 0.046119205503454136, 0.03582777568109093, 0.11265652344351816, 0.049035870770533244, 0.07200467295103496, 0.012248037533173639, 0.051674698930113554, 0.02806200367969371, 0.05698563027826529, 0.04434793361372525, 0.029375229684275486, 0.06925358992790984, 0.043973699662714236, 0.035067490872836886, 0.0694646088466529, 0.07448165737573179, 0.03118180482077503, 0.019648192157488198, 0.012538669266617827, 0.06895847753771851, 0.02453320160237772, 0.024822598976653912, 0.025554241672638926, 0.07452859558285245, 0.05144085059122694, 0.050887072443841934, 0.010521820231881595, 0.053862205541302124, 0.05505456010841074, 0.05216643927739032, 0.0221440740560572, 0.012285840141797259, 0.05794679483158454, 0.03254779704636143, 0.03032369058459036, 0.05750305755364318, 0.03703231487663523, 0.03274563159192762, 0.02384076728635738, 0.05108995933926875, 0.06319653490678438, 0.06452162569809346, 0.01271125834224926, 0.1288446814062134, 0.020887998210626747, 0.06814290799440877, 0.039419992601559053, 0.06167406156178444, 0.03166965918705589, 0.017954473263554035, 0.032787069287751956, 0.021768053204962806, 0.03763618368294932, 0.02175388440880324, 0.0438621917348956, 0.019763938466747923, 0.03309733872752517, 0.024233439058486014, 0.017637019834270882, 0.025851397602368268, 0.01603167205523219, 0.02403447644845132, 0.07647321018720828, 0.06925114610743138, 0.031195376068353656, 0.02655727676145973, 0.028997115497927994, 0.05104106377750155, 0.035413831562524846, 0.06523866101258224, 0.2010860525432133, 0.03483633533300411, 0.021135534625500444, 0.04838560001864549, 0.021329645983754628, 0.028294375384106275, 0.06359134980988118, 0.007939539894822144, 0.01975554405831762, 0.02940465703666691, 0.07953334073986738, 0.03635703135401972, 0.027603191706622322, 0.034162790829976725, 0.008968340435756311, 0.027784503650881594, 0.10748040441784168, 0.07471386628646044, 0.030163993811114665, 0.019844324072642673, 0.05984488874673844, 0.10812492184941808, 0.042856165072730476, 0.010062514132099047, 0.025061403904410622, 0.028532329954267032, 0.02399874802288269, 0.05025002436952726, 0.0228038921787013, 0.03162894927475962, 0.04541281881111284, 0.016192890470847487, 0.06193353171129862, 0.03636395678885522, 0.03157359559179074, 0.025535095220191345, 0.015658590108937314, 0.07124886592669834, 0.03213873290787301, 0.037413761545453346, 0.04321263727521704, 0.031406603746056076, 0.051407066113766164, 0.05106026194088402, 0.05339365467549332, 0.09918888159576925, 0.02140850324424044, 0.06431023905714674, 0.036944728044252244, 0.03233322347964972, 0.03699756512838987, 0.07952512061643986, 0.03732845382464509, 0.1295062902593805, 0.028978648948513215, 0.02848163600109758, 0.021976327613717126, 0.02375953898374592, 0.02689295925290114, 0.026388406085090774, 0.024192095208432407, 0.015758546388467715, 0.04959322654852464, 0.01994922257689459, 0.08071518458065488, 0.014362742808917838, 0.04839313832382041, 0.05868933321307263, 0.03513297606860438, 0.027280676351379485, 0.048391655943686926, 0.07914999034255743, 0.037890413791061416, 0.05750945821825055, 0.05018748478182862, 0.027718980150717883, 0.021076352418129964, 0.06643735112682467, 0.06760043347434652, 0.0015078884673364941, 0.019596921723155726, 0.04324058799313442, 0.03291694417355522, 0.03717740426861471, 0.041443640666623274, 0.030299457308325558, 0.011185371117936748, 0.03977694743943792, 0.015188397899750742, 0.018153340112598195, 0.04267267169310682, 0.0958700048466844, 0.009742840005445385, 0.0405910920592085, 0.08011322333327225, 0.0755106283712291, 0.06321812709493023, 0.056505193558311274, 0.013588580317915449, 0.0539166973753562, 0.04730453121385748, 0.038467684024644476, 0.0719609369914378, 0.04575965745795158, 0.022074591796544772, 0.015004940909303486, 0.06551222334946356, 0.0502518936240625, 0.07854427526434583, 0.029154479533674258, 0.02976850858108411, 0.04272851184190762, 0.030778760218151638, 0.05972693035859735, 0.05302926878474894, 0.025807060263750535, 0.01144743734790433, 0.025459656627067638, 0.04745453505987122, 0.07004247662881691, 0.021443538360237595, 0.12317038306425657, 0.15869266203334256, 0.13983824230249853, 0.1433565164165151, 0.22877456920762218, 0.11135883178682097, 0.17740189278077695, 0.07494769164270933, 0.09176325263275255, 0.11268944990250374, 0.12850197963416576, 0.17972960497342771, 0.09547938427497303, 0.31949307709451646, 0.24187389130313552, 0.22960385938565578, 0.13786656181177787, 0.15800826972530735, 0.137709375891474, 0.13606873731459343, 0.16941268357538408, 0.1805254937179627, 0.09743477773642349, 0.2261880418706325, 0.12474353695588729, 0.10884391834899303, 0.12694791665360813, 0.11560806869378976, 0.3406348055408847, 0.12027699920919635, 0.2172065496204361, 0.1848595288972701, 0.09314888352227789, 0.1886463934375394, 0.15887908186883698, 0.13426784846571185, 0.1343360609344898, 0.15868875498492874, 0.20807138013262905, 0.10251897387206556, 0.15143856015657225, 0.09538893993463247, 0.12227531657704424, 0.21840664167557994, 0.135594850646392, 0.07600345273291872, 0.15454513862008049, 0.09962575855634867, 0.19364718558086505, 0.174289170292116, 0.10868818033486606, 0.0992602656685537, 0.13671431960838457, 0.14929625656335585, 0.20927357126868543, 0.2958851584023045, 0.17805983973366601, 0.13152005962066113, 0.31942324051933907, 0.12347962977665088, 0.26315089555517324, 0.19067461121707194, 0.09958007673342383, 0.22708817985990357, 0.10537895629362715, 0.15172884619284063, 0.15254534270253875, 0.11795864095010104, 0.13107689307822337, 0.22656776101118137, 0.15424800375776906, 0.13747217974835826, 0.16117333134095516, 0.14541868721285175, 0.20032647636628922, 0.20917188075761642, 0.22680881823743546, 0.12181291356682779, 0.08035585103977112, 0.1553332592330633, 0.12490688222310237, 0.12215635078328273, 0.15998224847980086, 0.19629469351662746, 0.15573513363638233, 0.24684353431145994, 0.25671794800268066, 0.12021154465694582, 0.08557547619866748, 0.1815697788110664, 0.05534630171173523, 0.13578413565072323, 0.13098456416158907, 0.1920450659048173, 0.15195127216077622, 0.17714819510377225, 0.10663879554598563, 0.14671665466120168, 0.16946083986230437, 0.17724106028195352, 0.2082398581889368, 0.12546375919614108, 0.19323833977743504, 0.12994256201049975, 0.09196973631098386, 0.16189258064954512, 0.18947266522915135, 0.09146119948596725, 0.2585332239827802, 0.09324145758704794, 0.17320503330519124, 0.1477253166658263, 0.19828883570528802, 0.09472576826209984, 0.14733239016946287, 0.07852444124798622, 0.14602162905277746, 0.14309993824891507, 0.12563809016419034, 0.13790468234689007, 0.1584527539389749, 0.10276917052725631, 0.1388546773382733, 0.09958299552841533, 0.1402452035296348, 0.16145042534316742, 0.21052385740462812, 0.06353717207187606, 0.08512165337320297, 0.15348416813198598, 0.0703556074069873, 0.12484430816144713, 0.1912218278213855, 0.13690481503163615, 0.10833794025764351, 0.1239798622085683, 0.18755294082145538, 0.061870317966226614, 0.11643990228373198, 0.15377655324916686, 0.08065876220503161, 0.08709049167772455, 0.08164777405439846, 0.07728671895400172, 0.23847757838666442, 0.11965878157606048, 0.1600366100789078, 0.22100813837061006, 0.09299305357759999, 0.3040019212470901, 0.19122930483952646, 0.11037361207267932, 0.1823126083059657, 0.08031960742007341, 0.17788503379110368, 0.12673848353686834, 0.09736207599240927, 0.1951732786913072, 0.09126255288720132, 0.12318804905179048, 0.11653793089452291, 0.1737343387738351, 0.14965368254530817, 0.13635661783477954, 0.1549799701259021, 0.158642667135404, 0.11474395215871835, 0.1242180772486233, 0.1289656160459403, 0.12147385071242049, 0.20666470480782373, 0.14632394266945703, 0.10045200736532289, 0.10393494950427164, 0.09198374805911895, 0.11836591627328627], [0.011797611350043407, 0.05450934682401919, 0.052247621614726326, 0.017135134567656828, 0.05032591303930648, 0.0245658599305898, 0.03280606443783449, 0.08327216390640506, 0.08777784874602672, 0.0333905014239492, 0.04459923343552698, 0.039978773303089604, 0.0128818622925469, 0.040637030521587986, 0.03621818557862313, 0.04770911756842848, 0.014217815253012364, 0.0835320745564757, 0.025578821603689465, 0.05654881077428019, 0.025936247585641763, 0.042643889769791596, 0.0324806226267209, 0.03279003404801892, 0.07492103178294436, 0.03799001671253674, 0.05261582262333363, 0.05824647310580458, 0.035791263930619724, 0.0251169357028219, 0.016296283612328193, 0.0780544922717156, 0.03871645575629608, 0.05551262323053614, 0.05550707675396435, 0.024710920594272115, 0.03265719823238831, 0.01084228247148736, 0.02863598739608161, 0.024781006148024916, 0.12011252779273257, 0.023280186278204766, 0.01899350682393678, 0.03828510995052996, 0.05536677541151162, 0.014700471712726981, 0.06910090860460075, 0.031040430955228307, 0.05288486887190131, 0.05491976310769397, 0.011726526051549422, 0.0054664582092945856, 0.09811887893104747, 0.0818640330145436, 0.008528903783899883, 0.046236049233665394, 0.07031945571784051, 0.03659904619017917, 0.05478008229645991, 0.015949409533922952, 0.06123488250699255, 0.03429966775940792, 0.009056078570504344, 0.048612618683687145, 0.05181159501174285, 0.048819991023910624, 0.03986700490537671, 0.11204957496374847, 0.06151900153547045, 0.031959430029195164, 0.06653539505937407, 0.037609470197029655, 0.04448185344376872, 0.03345232471943863, 0.027795207814403602, 0.016166870294499303, 0.0543192076316524, 0.017864637963113286, 0.0639589800829849, 0.06874457046750092, 0.021522476059955456, 0.0499277733146183, 0.016694139884484392, 0.03612203388324669, 0.015100576452940944, 0.040713562705223603, 0.022571089549831325, 0.06272771591020208, 0.03503141962292214, 0.08209082568364759, 0.055881130674313155, 0.03206630887073134, 0.043761003011417006, 0.032977947754965674, 0.03995381798895617, 0.01305096279529314, 0.0255517672086435, 0.010344091663888146, 0.05424932892163915, 0.02124470406993022, 0.02136679358720299, 0.0897295956289576, 0.021848837176578182, 0.07234994111762894, 0.0335259840733582, 0.011301020708596034, 0.02110671631300882, 0.05128042028856374, 0.010775385758719377, 0.03823019676811753, 0.011483473166252577, 0.05627652780423242, 0.02049787751128597, 0.015333705626788641, 0.05275130910318225, 0.015441589001115533, 0.02550227984395479, 0.051504631241362904, 0.06408196017746964, 0.006413259092838534, 0.0360866712646619, 0.05263793958170761, 0.04155999410056299, 0.020356865622283473, 0.0720147010419638, 0.05355304309857949, 0.018452823034397537, 0.019565450831226284, 0.02134694233386507, 0.02572922573064364, 0.03922480872021087, 0.07314280381486302, 0.05035350752633907, 0.11195827260493271, 0.036213389868217136, 0.07709905805606997, 0.01854643323308518, 0.03323495493180329, 0.007872886893775074, 0.013012471665147574, 0.022802570677031914, 0.03428482480587498, 0.05365912329345461, 0.03289118446710129, 0.020723953888180758, 0.008564948220737278, 0.027132189359455824, 0.012329814546260864, 0.046540354678948084, 0.01952304020373812, 0.02748760053016726, 0.05047716943907642, 0.02114263051489909, 0.07083071215498833, 0.019679622829801614, 0.03740285628385121, 0.016580984867628545, 0.03389149611335128, 0.004212516876343157, 0.03585338600039963, 0.09986836328020982, 0.031152000170080896, 0.024018311993249004, 0.07982018704135573, 0.03961204318329692, 0.023277188959201018, 0.07247475982313195, 0.030431904334334597, 0.062343105298256686, 0.009914105664187623, 0.03109277199743496, 0.06257063341176798, 0.047052139716763655, 0.05711570817736849, 0.0738084193078741, 0.056544474716628754, 0.041987877188911366, 0.02284221381189362, 0.038032193683208, 0.05739644109722107, 0.06621707786595629, 0.023689206366637544, 0.04044563494502537, 0.045199497798157316, 0.04325383748378485, 0.07652720406411156, 0.03149599088506112, 0.08602399769569598, 0.008066064103566592, 0.013786831423790466, 0.05698905852172644, 0.014544053795567204, 0.027463507064948642, 0.09591534193004332, 0.01297873315296226, 0.05266917298638052, 0.038575656456692566, 0.050930107432988383, 0.06314349480934682, 0.025390655087727695, 0.033556688877363364, 0.06899436875697106, 0.025397145767666163, 0.020368414397742, 0.009609037961420274, 0.08667130368731676, 0.031972049412527875, 0.03136835297599676, 0.03123829997475109, 0.07994215589978042, 0.03407367182174518, 0.015364632596291844, 0.040151583586609176, 0.025465174375342268, 0.08838750151616913, 0.03201457303798488, 0.016314939768504233, 0.04846922234602032, 0.01721566381503738, 0.045646529254173084, 0.05451318875495946, 0.029741061565976952, 0.10098001814537472, 0.014474277549813834, 0.034085029075222636, 0.015016074082063091, 0.02503416947870245, 0.032720101711850975, 0.09171276743854247, 0.02155302764637576, 0.006847054464742542, 0.027590899825877244, 0.037027331474687786, 0.03306878663058723, 0.03734477915831151, 0.01360123034476513, 0.0778098727366136, 0.008544322260985933, 0.03729109937745718, 0.003356573541813921, 0.03678675688382599, 0.032685041697996284, 0.020999044570471012, 0.02553927806025792, 0.004184013138705444, 0.07207697632932855, 0.08289416846368583, 0.01899364855020277, 0.034220373828805266, 0.0549234020253343, 0.06495418192277994, 0.05845411357680156, 0.03039170195528817, 0.030694904233959895, 0.016821867808879867, 0.02820783426173993, 0.017930841366309794, 0.02593197856068371, 0.0651519934857084, 0.035041413239894376, 0.030363387345606764, 0.013928312541646583, 0.04850824686488317, 0.050537027719040076, 0.08428026666684497, 0.007185723262673785, 0.038244078281305494, 0.051596818431731195, 0.01393035225074498, 0.026212719141415534, 0.028685714163246657, 0.05425650333505004, 0.04195727580677598, 0.07207087826945129, 0.009547207005051597, 0.02851378679605982, 0.012484924368289931, 0.007103924224558737, 0.019874207247349045, 0.06073504077991652, 0.047297069517474984, 0.06692940940059001, 0.08506504713647789, 0.05714317625989357, 0.036686797731465874, 0.03315097254310404, 0.07050955277537146, 0.08601246041155632, 0.01729804507997488, 0.0234507710763043, 0.07149343949652488, 0.022146818566045934, 0.05697237695717523, 0.0719784037961114, 0.12867845564840302, 0.03595694576600387, 0.03646511486881683, 0.009880822016707352, 0.06800480532429873, 0.03267782898018918, 0.018005046557875413, 0.00986580765100136, 0.020563512094198697, 0.013659730733882998, 0.003890821474581777, 0.026083830593814774, 0.02306488492796498, 0.016057245027754578, 0.027184398251495538, 0.012602677827911272, 0.04292170389465267, 0.04987771712964581, 0.05541434564116982, 0.05630078214791514, 0.022827872645951087, 0.010402974139358248, 0.04337375322657247, 0.04750695079565049, 0.00957701548618535, 0.06156900409428824, 0.05229438745206403, 0.016037777775988703, 0.025905058231024493, 0.026254970805659413, 0.023799478977678284, 0.06622599512939492, 0.016610216867599278, 0.026858904729447058, 0.0619780222675012, 0.012867278851298316, 0.012331165733837314, 0.03735862236710326, 0.010943241368588662, 0.024849193718945308, 0.023695494033276074, 0.05294143680423018, 0.10795891825710574, 0.010874003299602098, 0.039705896614900524, 0.019904061693758256, 0.06217140584222733, 0.06248514566029753, 0.07312938195442961, 0.02381699557806696, 0.025910162291820013, 0.011277387853741888, 0.03482660601636575, 0.008286508776608014, 0.021150638048927632, 0.059921474556528756, 0.09096072190591405, 0.022546907984501412, 0.11983261458695897, 0.15201481149321602, 0.11942664927412426, 0.1656285003428498, 0.1685971063711951, 0.18262089740845466, 0.24581844738173872, 0.141302787909104, 0.1939444736607613, 0.17217660623212017, 0.08381512872273884, 0.18008914535805104, 0.10539338172924136, 0.16355425600082646, 0.0785166348120378, 0.1268691245105959, 0.10929375751725129, 0.1840053102181804, 0.13336499852518882, 0.1260222985799755, 0.14034372243669727, 0.17410154003770123, 0.24693243115419344, 0.12417839389414558, 0.18575508568075397, 0.23358072905290514, 0.1550192704364177, 0.1823977972831457, 0.06111371804088835, 0.20342763092729355, 0.07729932876123537, 0.1535866860180132, 0.07021919779118992, 0.22052190236506924, 0.165660185739398, 0.0904947565868497, 0.13003591748495258, 0.2298376694201462, 0.21698493570570024, 0.10922891583534018, 0.16198521600134913, 0.1372108671573862, 0.13789807866898277, 0.1959358272893775, 0.12561170609607814, 0.1413974457330281, 0.17305605984743566, 0.06529423303060955, 0.13858892143734042, 0.25172736015050645, 0.11104158711649718, 0.09684996153678625, 0.2279925160109997, 0.17380469628880102, 0.12501544454285216, 0.1410486459011032, 0.1403336560413722, 0.15295244182550138, 0.09698814081568873, 0.10407042449280139, 0.2084806855888136, 0.10738498816687254, 0.13699288449941144, 0.11200112756341697, 0.1467409090048844, 0.240570699135142, 0.1063776668161154, 0.19471915709155221, 0.15378816714209897, 0.10608663001368124, 0.17878929333340737, 0.09733650397749678, 0.18188143870042217, 0.15287592496362426, 0.14317714458992406, 0.13328175541133652, 0.14206409544473694, 0.20798421464860442, 0.25115397398269945, 0.21868393486065252, 0.1104950982957117, 0.114464299422839, 0.1601494548301543, 0.13468104564855177, 0.10325900714604125, 0.12177740539153739, 0.1517960474255585, 0.16264969002335303, 0.27228269425611346, 0.11781984880085915, 0.152180424380687, 0.13902243527193225, 0.1182150812218747, 0.139405969530344, 0.13305939073043485, 0.14592323271978289, 0.13355598424471196, 0.1256193439926832, 0.12950183162766118, 0.17334651442304735, 0.07291689214687194, 0.20983509839542452, 0.10790523847625141, 0.22235790868439984, 0.1534199393204143, 0.13803068848867572, 0.1514090351279705, 0.1029583942445536, 0.10392379526409412, 0.15300403018632244, 0.10598332305709202, 0.25284474535334495, 0.08782619655492806, 0.10063372342096222, 0.12349224724476376, 0.15851402565115885, 0.15240476556843327, 0.1529614050542155, 0.2449916086850628, 0.16388529791466652, 0.15354042962914513, 0.1901398665241657, 0.2353467149359565, 0.17560439004052072, 0.1624164468939266, 0.11568203448287903, 0.18122202085871852, 0.09753827621499378, 0.16330320898803974, 0.12422075855635828, 0.09709569956025771, 0.1111043910045297, 0.1987463587354268, 0.16773190199127122, 0.12229037020475635, 0.1497112310701801, 0.11187845390410193, 0.17540793445321823, 0.08157611418996127, 0.12364227790385486, 0.10140170358241567, 0.12209361584316339, 0.09456802309761125, 0.1405871851790336, 0.1307108103027267, 0.09834910367405224, 0.1177964831191686, 0.1307859635280986, 0.08446906137490466, 0.1850899375013767, 0.16909854156115364, 0.11415646231222538, 0.11701934054614076, 0.11576196809689845, 0.10699431396900647, 0.17767483458643962, 0.11236102800936469, 0.1489823443755027, 0.11604087772749125, 0.06631961873462124, 0.21564161585223293, 0.1775452584749268, 0.12665056728667792, 0.1407004895830347, 0.1656253900258772, 0.17151436918685514, 0.17912217385826573, 0.10628257998295369, 0.17959308810532096, 0.11989100580854763, 0.1135874734891038, 0.1669714831176304, 0.15183542434486652, 0.16246697805341215, 0.23103273593850676, 0.08859555567464522], [0.07876784270328861, 0.07704351668155963, 0.03740135475151962, 0.047021408099681146, 0.05896520913548528, 0.069744253921653, 0.042093769692245035, 0.04944445993450861, 0.06313601779120584, 0.04742377662971135, 0.05013622200837539, 0.04187189530761492, 0.04236419489907642, 0.050042724807656584, 0.09313405206006381, 0.04083852696743223, 0.1104326161646074, 0.041530480563280084, 0.05203800080644508, 0.06985670796805812, 0.06417548036082618, 0.05223510373804358, 0.010290111193523533, 0.030772962847784645, 0.07218102639120433, 0.004116552393703211, 0.04125700632651006, 0.030408247539232817, 0.025435116915633122, 0.04394075022109094, 0.022056684491314718, 0.010995462709557145, 0.02930097278177498, 0.04727009173122145, 0.021356095169340412, 0.042156975776437795, 0.021257773529918447, 0.039255444576302846, 0.046023107434232394, 0.04898983271672361, 0.03960175845291346, 0.006076427948315658, 0.058791019893702, 0.025650203761254108, 0.04646904721495606, 0.09954124373654205, 0.06153138917720607, 0.020547958594115994, 0.022840888479784615, 0.07700292934333125, 0.02561041123924717, 0.008799890150135804, 0.029600831086657224, 0.10123923165543426, 0.07455635860922837, 0.045308121404941046, 0.034632996445701975, 0.022560329844934807, 0.04713200821330951, 0.05700852098544279, 0.06974696587290495, 0.033129514420344945, 0.048722314813564864, 0.026284149179475445, 0.015740324029578798, 0.01305661843939414, 0.085571737689597, 0.03446336159662854, 0.021618210237413164, 0.08013655837144583, 0.020389839961764314, 0.02026968098606073, 0.04667695964716616, 0.043675668477531404, 0.044887722995612896, 0.039779877725748286, 0.01946951172524883, 0.03608094858786753, 0.03290447609258756, 0.05041759844208437, 0.050616275684367266, 0.05021952640926165, 0.0440013439454619, 0.01745562170512013, 0.02220656767848038, 0.040062997009485, 0.06441973600416415, 0.07950069007253455, 0.032391315926947904, 0.06492493268583091, 0.03787272099045016, 0.045862692453327684, 0.0571598080287297, 0.04657201326241897, 0.03809175318888119, 0.08283471237988242, 0.013922451011415933, 0.003611393298225237, 0.04344472361187782, 0.033995967523585406, 0.045394857879728086, 0.0858250753052773, 0.013658245480919798, 0.04568169652033718, 0.09795717309199034, 0.025317032122984532, 0.03824274145787762, 0.017446219891069398, 0.0068580339411123395, 0.03897791390397376, 0.041441622024942795, 0.023310444835994034, 0.030980488405592983, 0.028509125151040576, 0.012702867764258578, 0.04694220993006903, 0.053688973909424204, 0.02394360309887317, 0.022202411651491158, 0.022656037209315166, 0.0962966928378709, 0.04326560842474142, 0.012295180668814049, 0.014030180210548063, 0.0452507529107313, 0.024623203526942, 0.05129006533553043, 0.01597212595609768, 0.04272517169855776, 0.02564015268768755, 0.06196676843589353, 0.04123842103346702, 0.11093912285662468, 0.04748872173349223, 0.016690012585792332, 0.059276413202526114, 0.03280747787005479, 0.03545096767465434, 0.0005457460746026388, 0.053541130431356936, 0.07525683876367346, 0.011901625980352683, 0.04126205867637069, 0.04355373792350293, 0.02819246079231943, 0.036290990744507125, 0.03483106464808507, 0.07794868786849322, 0.05657450153282093, 0.09869575845978915, 0.04868803620939294, 0.00911186222032073, 0.04305352081334399, 0.07860832787569492, 0.05801330658517057, 0.043294386517617016, 0.017796538492304184, 0.12374746943673781, 0.016027211508293067, 0.032184843740035454, 0.05389806228659807, 0.014469621650454019, 0.040405354041966705, 0.07525420342121394, 0.03451734781265259, 0.023383380236825155, 0.038081621676082575, 0.041089290527686964, 0.050949416679119876, 0.03451101226551879, 0.02125453872365817, 0.013779897370465822, 0.06775570417483968, 0.10541231942272956, 0.08503487093314048, 0.07907190300043553, 0.07171557435104925, 0.03753202636876414, 0.03693454673573856, 0.03083115297129318, 0.008613456908102718, 0.058979795449563575, 0.07181566373835649, 0.052062707142003124, 0.006018151639915642, 0.02639385680067203, 0.0586594749362238, 0.05292312347240025, 0.03481777685303842, 0.07531212732916878, 0.0247713572706186, 0.08613718718650841, 0.07431926971842205, 0.007724291213127154, 0.009023132001710756, 0.06549969781190157, 0.04791565104237488, 0.06417965554001351, 0.031188169096205986, 0.04826521696222406, 0.05765899475063047, 0.0673015825750847, 0.024644627175744505, 0.08485628051623222, 0.03765274267343264, 0.0245678287765552, 0.04761983002085359, 0.026178492248178493, 0.019040035174017953, 0.017866007345277938, 0.10336541675872381, 0.008809016172533796, 0.02851768809881422, 0.013435277505777778, 0.02914361640690796, 0.08970139593246484, 0.04900240421956105, 0.028055679623878775, 0.056773826119399844, 0.08678517499638182, 0.016206099741881894, 0.05264183130836295, 0.06637014223322754, 0.04324347997504858, 0.024934524422391288, 0.06420347321357939, 0.011382754629237518, 0.03616424532787454, 0.05025170976296068, 0.03254313540134219, 0.10106488536562651, 0.03780804018700316, 0.03764053506235923, 0.01650517280664175, 0.04598262734831341, 0.029267661363607454, 0.11375064255609629, 0.030365932672735185, 0.01936317297569927, 0.02604074772417305, 0.055567831356799414, 0.04229533125556285, 0.0682868252718641, 0.04664300279992242, 0.0613928345152207, 0.0529504613199782, 0.018075932673509085, 0.03315098786486253, 0.024811329823287747, 0.009669016900232003, 0.012026937854956957, 0.022872198493249958, 0.049473659375742565, 0.06816447336947726, 0.022714062623919982, 0.0315237098613814, 0.007286679286945372, 0.05493753634753728, 0.037499126722855915, 0.06195812696410764, 0.03692299412984041, 0.07182841144141651, 0.058013536411547856, 0.022641452810456677, 0.03249208713250776, 0.1067362572517126, 0.027151670975370273, 0.018430903343664064, 0.02164649037313798, 0.09378796939047114, 0.024367063944678635, 0.12310786262875605, 0.02098068335814582, 0.053970890435119795, 0.040592402069559025, 0.02784491542937054, 0.022961246638348507, 0.0209658250828544, 0.012874253124238984, 0.04874546982107624, 0.055438147992977214, 0.04085263830699748, 0.03512055012247255, 0.03478874212070819, 0.014399898073245442, 0.03248999571247447, 0.02781705855722389, 0.04125240213808514, 0.012101151665011722, 0.06221079425285421, 0.04553833082618733, 0.007912922648697971, 0.01772744885285295, 0.031091096180100596, 0.06676685320393694, 0.059641503894160834, 0.06692950133114092, 0.04378968534330207, 0.019279707696348913, 0.020228272018533562, 0.029206316873070695, 0.014428964406702549, 0.037178212491374825, 0.07206754578698067, 0.03649229183793068, 0.033540302256663004, 0.021930933073763887, 0.03441130592217369, 0.05172580082510268, 0.015254612794266114, 0.11123808100819589, 0.009705630157353177, 0.02179977690590726, 0.05517462906878322, 0.05159773007636109, 0.0336176886283342, 0.11973969578262299, 0.02003891615106935, 0.007769403736963268, 0.11328424822779433, 0.005916251891082334, 0.05052076750284722, 0.024934754248768575, 0.06929432282284384, 0.012361386944840272, 0.066671222448349, 0.09013769832710106, 0.025519610668021827, 0.05689841116808596, 0.04767157542969912, 0.05944123701943506, 0.06247384203297477, 0.05063301087507317, 0.07703553404538863, 0.03334244855889871, 0.06241910888122455, 0.06303114418481147, 0.030448139652669914, 0.03290287496882581, 0.05294483823461398, 0.055241370648746534, 0.03611769016471601, 0.01436433052614091, 0.03965259987800833, 0.045552308100365826, 0.04396138862977105, 0.034261597020010796, 0.03552362728383272, 0.02875154984423951, 0.06193415990339653, 0.10362296019710841, 0.059465671393779986, 0.19046430476009849, 0.13779712360232108, 0.13623321639193645, 0.1717783477638037, 0.1382657855508789, 0.15622726851894012, 0.15527908149505817, 0.21322384236320374, 0.1667237456046766, 0.12790649949062255, 0.11232687580970027, 0.1318439615950469, 0.0732336311991657, 0.15479541954494294, 0.23420593340791043, 0.17389630508278647, 0.19017256315677397, 0.11568154418660749, 0.11293943971395494, 0.288516802172507, 0.15619346871972084, 0.22972877768258895, 0.11630533127895287, 0.12188268885497125, 0.1526588922546756, 0.08962574474994214, 0.16135987375051747, 0.23051536611972318, 0.15270485753013244, 0.08214230679215924, 0.17162923641022176, 0.09884915224486783, 0.09462798479944469, 0.13810484579974605, 0.1686814373298999, 0.09025890109760147, 0.07018136070860971, 0.06501330092789666, 0.10881465379028551, 0.17449596806639628, 0.13224032016531115, 0.06635980770712899, 0.1344679506315339, 0.14240247648089163, 0.21221260630315353, 0.19930790118392439, 0.1743904317939474, 0.12183084768513519, 0.07844014093279839, 0.1328579096063491, 0.11503092103427458, 0.10694012090924288, 0.13385210787096333, 0.1472106434765362, 0.2314068473154499, 0.16762497143880015, 0.1611794447225909, 0.2137499762278411, 0.09232536964719334, 0.14559369233827438, 0.2836841969720779, 0.12433985458506693, 0.14452581173710286, 0.14115002997700246, 0.16543334710501856, 0.07825242640871195, 0.1285829857712792, 0.22781545776994, 0.17012595739816466, 0.11820496886127418, 0.08760527211932406, 0.08331097392064911, 0.11724083954768798, 0.1207448261219167, 0.1641308290943984, 0.12379302868559477, 0.13803652607865874, 0.22942418112389504, 0.10318725535105314, 0.12489359825849534, 0.0741794663331201, 0.18137091770768168, 0.11837950667306302, 0.14471491288033225, 0.11279520067957141, 0.16874440975727575, 0.25351540936577704, 0.12259806175866436, 0.11232824710708474, 0.18768455472684678, 0.15385924477971372, 0.1170660412660049, 0.20009877971343457, 0.1028339202786165, 0.12385354963161292, 0.19725772732448196, 0.12651870823315076, 0.11629435323899794, 0.15615566994153685, 0.12674694880843163, 0.12868403276849177, 0.1640526881261218, 0.08121494203805923, 0.15502506206112524, 0.14093305855508775, 0.12003757375022096, 0.15536437772454756, 0.09387949391478494, 0.10212172663980916, 0.14948186434565053, 0.13032768973179404, 0.09340432787974996, 0.08906608687773829, 0.19074029559569974, 0.1417124917310092, 0.11058109932609143, 0.1232057533437206, 0.11094884451238379, 0.13765705208624565, 0.11307501429391485, 0.16809462930165953, 0.17921935977233996, 0.1270988896008461, 0.12903960481766732, 0.10480950015687174, 0.18634187838723584, 0.2080769572527178, 0.1492468132487228, 0.15481659421517005, 0.12663120824483134, 0.14090520359816092, 0.1805941811612537, 0.1486089377994499, 0.12450876165061228, 0.23625121962639595, 0.16627561481248948, 0.10893183459918346, 0.22876202068742246, 0.10821315219565746, 0.09943103432775506, 0.1906618941575289, 0.06623371729567167, 0.10812153574079277, 0.25001412708192106, 0.0887562885820385, 0.101194798555826, 0.10213268169712636, 0.1807198195808357, 0.15108288085508734, 0.19242829372805936, 0.1880116129834806, 0.1239205899858667, 0.14161349784943367, 0.1794511166911933, 0.3184907276543879, 0.16114026698614323, 0.1584064209413144, 0.25181486271321774, 0.07232033181935549, 0.13474429386758036, 0.2398985642338953, 0.12378539844986894, 0.14454136332196577, 0.19228809963791602, 0.16490704470103787, 0.16967876123324518, 0.08740082623497133, 0.23728229736368503, 0.2001557000462086, 0.09541583728165397, 0.13203361432158178, 0.17556257696161348, 0.148748304514635, 0.1770630674136262, 0.22442280675374696, 0.10111020712722694], [0.02432288365408538, 0.056624423652406664, 0.031108269956143155, 0.005035308234754109, 0.052197358586014285, 0.04992391989235917, 0.02436011169676579, 0.029915011405283888, 0.041163520617110115, 0.056679570491635994, 0.03705559245821449, 0.03642113759152351, 0.03331864237665169, 0.0200335209768626, 0.049689887692370725, 0.03865575477961571, 0.0823301132467966, 0.03109236022517566, 0.047540785068826336, 0.016216508961553057, 0.027988704387098554, 0.033012597911780885, 0.0458027039384169, 0.005328618881908516, 0.031106852693483237, 0.017054124600103786, 0.03954987897868118, 0.04648339987221745, 0.050233262365744005, 0.0335274511317332, 0.07720712241866896, 0.10040024280427925, 0.028704422030357585, 0.047789970487957044, 0.04608564702193103, 0.05315918580538804, 0.0476838136842895, 0.010656816415458677, 0.027059897472481095, 0.02436412982792864, 0.05287302132215231, 0.03978190402830801, 0.06998634536660488, 0.04257527510485342, 0.0950891467472238, 0.01736337897337733, 0.03735013794334185, 0.017772965966874076, 0.057897730730474, 0.012704771492750415, 0.04869681940744481, 0.023849247879679167, 0.07392808224164671, 0.04200029930460357, 0.0270985561843601, 0.030927794962941162, 0.0636445431249036, 0.09790792129933835, 0.0922078134552125, 0.03096575461958926, 0.04403266545024611, 0.04918676710897877, 0.02402914830693795, 0.015641320571904222, 0.07507838624259157, 0.020210261291433728, 0.04153960850089789, 0.04476277788560237, 0.04444266038556253, 0.004785481216986814, 0.07239058974289125, 0.030180932015120506, 0.09012134234991767, 0.01730714428929552, 0.04989368240198782, 0.018507519796971354, 0.02847818860543832, 0.036369476452349656, 0.01742797933759228, 0.017031825695847793, 0.05322030046954752, 0.003771694802356163, 0.03240379166879481, 0.08874164098092625, 0.06143408068906396, 0.05574727596174325, 0.012289280834187184, 0.036540283415947235, 0.046149737937676336, 0.11518374791428929, 0.03143809762062325, 0.028255751146183863, 0.04809885330858731, 0.064399664500548, 0.07477283973487155, 0.02783286869676123, 0.03210300256708457, 0.05232124266424968, 0.04044514464875383, 0.0037340336805960586, 0.02781779208641139, 0.04041720925259494, 0.02638154576772884, 0.019666030514805068, 0.061912169349530054, 0.06822247388622454, 0.002428920786534887, 0.028418052618602113, 0.06335140724155693, 0.01108902311252971, 0.04104547029841812, 0.03254002508436961, 0.010489903093736258, 0.02483600743054863, 0.013291416727306863, 0.022395042544831673, 0.040076150739144896, 0.01666801820148624, 0.04823525909394507, 0.022314825478280266, 0.0550755279348983, 0.027105314995072065, 0.04298988955035325, 0.020443513996959217, 0.01376947187142627, 0.03126309632564024, 0.03800462983969239, 0.07304609287530184, 0.06008295439964822, 0.02897940546033844, 0.0690632094178469, 0.08232300395085927, 0.01580583891125336, 0.04643767974489639, 0.03766765074443914, 0.04264866632799949, 0.026685420288554123, 0.05727611549739396, 0.03176457748087424, 0.0267008435536897, 0.0826868420887378, 0.03393338580105094, 0.04223749544771929, 0.01854303946358062, 0.021188555570739894, 0.0874699043831037, 0.10403180600053842, 0.06322350120171905, 0.03346370495555382, 0.05505423452104292, 0.060183388526521386, 0.022001815358957937, 0.039601256665323055, 0.006676116308587934, 0.013134661731460403, 0.0685277062978956, 0.03203557916886864, 0.03401326195847604, 0.04777690102796882, 0.047151650707688064, 0.010585060790030947, 0.0300315965808207, 0.015665015671402216, 0.12515912433305096, 0.03007890059492521, 0.03009515506545863, 0.019706108404563803, 0.0734212844362182, 0.0029451517677385242, 0.050559221286206484, 0.01196409566252823, 0.02416697135495563, 0.08128044255558523, 0.019514733895419106, 0.03391894887411787, 0.05075106885464442, 0.057208688268738414, 0.026046763429598465, 0.1304531442902742, 0.01161290659388948, 0.0645069934187397, 0.043326707767142404, 0.02610164979893354, 0.06982611807724161, 0.05865565598792127, 0.039327790089432275, 0.09143879907506128, 0.035093227596653086, 0.09349500970734705, 0.007575190393254162, 0.0428196954570951, 0.017552359457758647, 0.05367394326434982, 0.02681775048615471, 0.05760552564395532, 0.026365605393244375, 0.02053104145752807, 0.01437307350457676, 0.05113943712785841, 0.046052532871404005, 0.07093829388219504, 0.06175223700401764, 0.039986016664413676, 0.055264291999441, 0.014013985111828775, 0.020045259359082388, 0.022507159512550123, 0.05178063739872268, 0.026395534533226205, 0.04775316762407461, 0.07226680525608602, 0.13622970770924323, 0.02982507268297336, 0.02365720878926016, 0.021913554369201584, 0.052976190382915164, 0.03765078148834648, 0.014650969983889692, 0.04110406836374633, 0.03220201943129782, 0.011247535322552488, 0.057560992952916896, 0.057325689046974146, 0.043142647482454784, 0.04360701550819701, 0.0053644267890992905, 0.029292187668503295, 0.008435637367168262, 0.025948192811601108, 0.02947594917890045, 0.09334412869066001, 0.09468646029070502, 0.04777480960793553, 0.025823697778246096, 0.03948593745008111, 0.03194493181522816, 0.04771125495373722, 0.06532286939721915, 0.029626556319154562, 0.06111582478268012, 0.022927919898422498, 0.016059596917682117, 0.0166986693793367, 0.054792113707310734, 0.02525147606408404, 0.038838949384948904, 0.03152799229287813, 0.008406628490305476, 0.06524870442526956, 0.0261038982669913, 0.029241846115779013, 0.02342973430190356, 0.02545788313352293, 0.05135393791621731, 0.08509801189985969, 0.11697320673134058, 0.028866122123755278, 0.08033043224244349, 0.03448850077186381, 0.09717397842436068, 0.03723848445881759, 0.05804596491338265, 0.007044170324074766, 0.014386177438521578, 0.03997030420108669, 0.09487689442692265, 0.04813635714292046, 0.004935770430752347, 0.013507029300765886, 0.09672674395504499, 0.007172557562890073, 0.04484674112210351, 0.0784113283659662, 0.049384624637182684, 0.09942331216147832, 0.04836232243706623, 0.0017404521725350812, 0.029494773874419834, 0.04896749359285159, 0.04214420509074004, 0.04788935890481357, 0.011046081011544072, 0.03508934353087698, 0.02738144564171953, 0.0724430361221875, 0.017851331015868534, 0.03875094886508681, 0.021436231796659773, 0.037295657600606644, 0.03347534566156326, 0.014373480488786535, 0.044096246917521766, 0.013383953445290607, 0.062368179356018384, 0.033652825250981316, 0.02134639649621902, 0.02301639730801746, 0.024455516456416058, 0.09207102845633224, 0.025044724255079226, 0.054582688251450184, 0.04900480207476405, 0.06637486899572034, 0.025737627799953186, 0.016334172405843294, 0.020601460259527932, 0.05556810714845216, 0.04268359227646743, 0.03529835529925843, 0.027491762302815918, 0.04185581129164465, 0.01575505206992309, 0.03459414812706171, 0.05945022706122649, 0.032994292240830204, 0.07198051053790316, 0.022173369258281686, 0.026692684717296113, 0.020851526679771564, 0.03398816108763699, 0.056821346553342963, 0.04283461884986009, 0.08073000072111046, 0.04077931986220422, 0.012293658069064541, 0.08404438819495902, 0.08568273616894599, 0.027852493954161485, 0.04285849398002029, 0.05103680432864255, 0.03744872962875712, 0.09249446823471978, 0.04141446420802705, 0.07707376949368946, 0.01779696367110216, 0.019442681410920717, 0.017354274018397255, 0.04707646683879918, 0.030473052831967513, 0.0435807042184376, 0.02344738688289879, 0.025029806607973673, 0.03182275228262429, 0.09700202998975593, 0.058474763476800536, 0.05088879997211118, 0.03205809449296325, 0.10233944116701042, 0.07097721114874848, 0.037512376213506345, 0.05882839349308803, 0.047691620120237914, 0.11173098197867794, 0.10480407625436784, 0.20279062881825433, 0.09512033418662126, 0.12721800861219246, 0.11106706720085875, 0.13140438034409477, 0.15818776412596627, 0.13213979410788707, 0.20065862144674027, 0.16594063520671862, 0.1037473422324946, 0.18768461601388073, 0.11277622468168698, 0.12864107055769813, 0.21944942523635205, 0.15572666070393978, 0.14470150634165735, 0.30089843777879594, 0.08239991917845704, 0.11441016765010935, 0.18561361988465633, 0.12201748968612765, 0.127290626086535, 0.13673095903809995, 0.1686832452974012, 0.14091808919704732, 0.12264980333707026, 0.09750515057314789, 0.14041967239351044, 0.11711911583739905, 0.1423081863791712, 0.09803296983121865, 0.298675281266051, 0.12452687963002151, 0.20297118042024875, 0.23844079084454045, 0.09220194522171252, 0.11422586987816519, 0.088952460716809, 0.11607160551413415, 0.10308260007971719, 0.21117195246681092, 0.08672587213016326, 0.21210045103103886, 0.17051146816342108, 0.0812513005709456, 0.10356502862827432, 0.15924208497087802, 0.11517468509414505, 0.08139182407889636, 0.20559967405373053, 0.21455602329825202, 0.2568994495537012, 0.1790387468833116, 0.19912685928565843, 0.1451832377502034, 0.15470010288540395, 0.25912384712888353, 0.12275893256188401, 0.09473541330906654, 0.18173952857332845, 0.11008997567959371, 0.10089468361148912, 0.15109457135681184, 0.14375756344487592, 0.15021657330855248, 0.14647339110172566, 0.07989194649722307, 0.08579025660911876, 0.15698759546203, 0.09463179225642836, 0.24184116402701025, 0.12445361098094333, 0.11339567571638093, 0.12120441758945105, 0.08311234264364166, 0.18283598425407566, 0.15353350419430964, 0.1353529354016627, 0.13449523868339677, 0.10852583864283179, 0.13810656183669645, 0.20737146688324792, 0.10864316500843534, 0.1560524472546193, 0.0969439835077332, 0.11383837494518488, 0.11496317587913045, 0.28064886468552774, 0.24356386594233975, 0.1278068544343114, 0.1982236875882072, 0.1545675083874695, 0.16688427166833034, 0.13476209775094064, 0.21016905144337686, 0.1982438050570988, 0.18016639766433548, 0.13968153135670772, 0.13791608173520337, 0.12696087120040772, 0.08908677125169386, 0.19101524455172403, 0.13383309356868267, 0.13338822631105302, 0.13154455911247961, 0.12212212963570511, 0.2963290910326666, 0.13615046357435567, 0.15796426563493668, 0.12840137696794926, 0.10492595318224161, 0.07435113131519287, 0.0940573871916821, 0.09646271941282096, 0.1001460012048483, 0.15755661492866857, 0.14552463717277975, 0.18258622426900173, 0.1512023599277581, 0.16712414911918103, 0.19658208374054204, 0.10402638975891376, 0.09613397576275373, 0.1452662816811954, 0.15688755970087745, 0.24519500502895927, 0.2091974680942874, 0.10159412188635719, 0.1796522300930754, 0.18115530992227216, 0.1503328194901828, 0.17600356781434628, 0.1619989902622277, 0.14299100054608238, 0.17697185698536136, 0.12906238827253544, 0.15450825914740562, 0.20170126711168598, 0.1287273627014891, 0.12049145786271942, 0.2758793544865424, 0.1109077898605216, 0.13046653550719062, 0.13798185804438207, 0.18413272596174673, 0.1382957242669598, 0.1753589814348567, 0.14521780363734693, 0.16135281041985558, 0.06646922804535398, 0.08891192700473532, 0.10427567476947462, 0.24589546986164587, 0.14201659799343155, 0.11370480751558659, 0.25653278455138206, 0.12797579214337373, 0.12334339636107608, 0.10192475011271816, 0.1816988033392737, 0.08087275354492088, 0.27569117264882215, 0.14695441770938136, 0.10730231961896343, 0.1235300153794308, 0.24711479072368916, 0.11365237645804883, 0.15423470447140356, 0.13398998837557533, 0.1625987451763884, 0.1472122522611772, 0.14298254293539833, 0.10717806015764514, 0.2164734954074506], [0.03968241602002133, 0.029607306444837205, 0.011390221113669536, 0.05795876495540143, 0.03403241415658305, 0.08936231775629906, 0.021129647239802346, 0.03982749009024232, 0.019219357204893907, 0.017503316424066023, 0.08286577724521199, 0.009762131056988673, 0.046838964260513746, 0.04151040905966394, 0.04367726960129315, 0.02456452885282136, 0.034244118724018335, 0.07692541656715256, 0.03123086892188557, 0.045323596381011515, 0.0368172012179369, 0.0466832492290245, 0.029154341637847886, 0.040552829797830314, 0.03253494592143163, 0.06008564719870206, 0.051150744585620786, 0.028619116224769144, 0.10446908132683848, 0.03602215517011862, 0.01078965031586948, 0.06976254810128482, 0.046261965988143805, 0.05906984908506275, 0.048361690414528695, 0.02875250553892505, 0.018119425400190296, 0.012102092995548682, 0.04240877738582992, 0.05705751996907977, 0.05751226593049304, 0.02836074158098669, 0.04348077954003408, 0.024462336554161968, 0.07672686189893754, 0.009521513373681135, 0.06104363631757517, 0.025942805298273603, 0.0444525697328631, 0.032045381263859814, 0.026700175141975768, 0.050914456256695335, 0.017437951887146603, 0.029637158976026604, 0.04937560012143466, 0.0682300734784334, 0.015804371852878363, 0.027323205722495917, 0.020201288486620592, 0.0376401711705952, 0.02725204189998969, 0.018133791463990367, 0.017087275139807213, 0.051622624103460586, 0.04755746663337754, 0.11032473566311021, 0.021561397156948527, 0.021709706033429792, 0.037751284563132835, 0.02100302631245746, 0.029892842735975023, 0.04204706514194127, 0.037910910473475536, 0.026508785311072588, 0.010749224813715106, 0.061170979282788696, 0.07005151646632342, 0.029776403117143822, 0.0727008476913456, 0.07859045504442147, 0.02878842357125494, 0.03226084732300332, 0.06641572446472223, 0.02089653051488342, 0.06349386895195612, 0.041957566920187206, 0.01799890444794249, 0.01521647502217562, 0.0710263250455741, 0.03879456608105571, 0.039591726531545, 0.029421028335608786, 0.017430222059990612, 0.01824478036724031, 0.02880890684713039, 0.08745704942773427, 0.12880429325084533, 0.031722226225200205, 0.034860972720648975, 0.053012196515356345, 0.031537097247858206, 0.0818844186142087, 0.03390121393867078, 0.04850132143004768, 0.046493217288967104, 0.07386165475773235, 0.15162822820486563, 0.020783459767699245, 0.06561675604673163, 0.07862419355660677, 0.011210315898361226, 0.04958515964268197, 0.03675452373441189, 0.06812695804382525, 0.02704453740959927, 0.07288431808833154, 0.012624534316390995, 0.02871448459524301, 0.023908740352658976, 0.09004414366978793, 0.03247706797875224, 0.04623990265592452, 0.016465583297934745, 0.03505717932937607, 0.056075517824220086, 0.038970379429238464, 0.0077182190087173265, 0.026684271156667706, 0.04374634008854628, 0.06651547677334278, 0.0075795906107692474, 0.022146155899991433, 0.027423530681839874, 0.0352668690855705, 0.02678619149411398, 0.03688756639378206, 0.04829551957006897, 0.012864396445483211, 0.0527985843889896, 0.025179632338545015, 0.021737917221241423, 0.09432080652444594, 0.09627164942362616, 0.09996141231949292, 0.017836740871350613, 0.004155010486307044, 0.04563503410486926, 0.016213992362721794, 0.09226085738308969, 0.05133927882378621, 0.06783820418340546, 0.0647489852722614, 0.03804149782104838, 0.024306502779044455, 0.05910089479819421, 0.005683493312268008, 0.018458419306684407, 0.0619619842168064, 0.11176626798847031, 0.08047817995952022, 0.11104314227498348, 0.00909388596717749, 0.024216175267112353, 0.057374845078635606, 0.013587060590995657, 0.028766019329909357, 0.010621783214681333, 0.04054390104307283, 0.03225928450363778, 0.0595128700707949, 0.03529874600409981, 0.012843348179763604, 0.018115407269027446, 0.05103093226470294, 0.034046257365374796, 0.04172430080812305, 0.03824762526839491, 0.06812858981110397, 0.05191211340828769, 0.01951957748632037, 0.05679737566219223, 0.025513439829791748, 0.02011385104138284, 0.05556719933426189, 0.03685683477669954, 0.031526126868782506, 0.06714887060825864, 0.04757562674762261, 0.048966662387453744, 0.06449264459191792, 0.0337474447705092, 0.03815268016149921, 0.02101976533360299, 0.06493751184954759, 0.061678190775696314, 0.05812136328689033, 0.01831991252519431, 0.06095964626799669, 0.02744369603122675, 0.02101553269782134, 0.04162024691580765, 0.06105132784033495, 0.04097320522452074, 0.1115063266948827, 0.10232116997001633, 0.01645934159657167, 0.01725344344102327, 0.009898314676848392, 0.011697292136358879, 0.04027048809333675, 0.01546965654744136, 0.007469732644817522, 0.06547801752364443, 0.052821597670234983, 0.02163169146966069, 0.03598454791391569, 0.09840148876631453, 0.017558469008954785, 0.04856981352091797, 0.05490660554759445, 0.02874594974151302, 0.05377355384670439, 0.0386039940490117, 0.03527866683960442, 0.036408474158135154, 0.05409910291012737, 0.01896371366456151, 0.0785794540218288, 0.05318807115057304, 0.07141802580125871, 0.05244661295305818, 0.050221334376762954, 0.0019149583831970251, 0.021384517031331218, 0.04655539681534133, 0.07599513301806105, 0.033708726686816064, 0.059570288360719724, 0.022347853443915808, 0.04797891841360158, 0.08437933715721292, 0.06922173599201827, 0.03486322884958598, 0.05728830778670888, 0.06531538471819893, 0.06961304604286148, 0.04982791758412796, 0.09099912589355823, 0.05589341106373937, 0.03432849947843821, 0.023541152214391098, 0.07778361124256927, 0.009982133314253823, 0.014372949015289066, 0.07210457081636114, 0.04595687913317834, 0.0833658104942691, 0.03259193520211885, 0.05940916474848505, 0.03707171094814136, 0.08427954654419616, 0.019818459029099154, 0.08644508558415598, 0.023253771566575574, 0.03767094875295316, 0.01866165094167715, 0.03857290237060478, 0.06072562555932711, 0.032268335832463156, 0.02947441700305189, 0.013605841236459392, 0.05958947120234371, 0.047610476087298126, 0.03077311798058931, 0.03858621314828915, 0.06941581670675548, 0.043828820944913936, 0.028309490298852328, 0.02273456696721335, 0.10629869081200131, 0.049048932569642226, 0.04179229111140294, 0.1314911474623988, 0.005753362446182198, 0.029503874998960285, 0.022025085279657956, 0.03840605991201536, 0.07693558255390776, 0.038078446241636435, 0.00764217424852353, 0.0061740821336335955, 0.03597302212109489, 0.016660635029115987, 0.11235916641570869, 0.025204568500480345, 0.0538560270421928, 0.027679810075149424, 0.054496909386568496, 0.06068290849666923, 0.014176976063378878, 0.020961822273450035, 0.04648199793131602, 0.012178369497339572, 0.0507014723224265, 0.06895850052035625, 0.06982370490028013, 0.03662141978800778, 0.04804050039139487, 0.05409827170472953, 0.052638904852492195, 0.03986583662129218, 0.06859543613128125, 0.0349265345252089, 0.051271633260072245, 0.05678319154427417, 0.030158613958666404, 0.08725854072479472, 0.026655376235383655, 0.12558151457098224, 0.044932428056434284, 0.041455043885376186, 0.0056256914995760935, 0.023871307381458824, 0.026434030451421297, 0.02924132134555088, 0.0673410437640644, 0.06424847704869124, 0.11276877064618374, 0.05315457012564425, 0.05574649455206049, 0.01607238484035817, 0.03666756509412681, 0.09221967249628037, 0.05040052617269178, 0.11873834991767523, 0.014861442107376794, 0.01867378002873832, 0.0569933639358609, 0.034355385334140835, 0.030585951209368727, 0.04609018992332201, 0.04062581882481614, 0.049709828961039745, 0.018998871354626554, 0.04177389350990134, 0.06697268570743262, 0.06190778349616355, 0.0333822698092028, 0.03826496949900062, 0.023240250114712025, 0.05452381822490885, 0.023492743118455815, 0.11253574202137609, 0.15725992439735323, 0.07732316175655973, 0.14084748653394563, 0.12550550332713512, 0.14627759435003804, 0.08676376283889817, 0.15728237077353463, 0.1432006328456825, 0.18222017213702205, 0.336163793840716, 0.11772776503236064, 0.2885727265909795, 0.14395754303663008, 0.08923271100126928, 0.10492864215085584, 0.12178464492242183, 0.2488502250203202, 0.1587024219934979, 0.10366458175403458, 0.182788762594423, 0.2303990892945759, 0.130940452818909, 0.13325583099597885, 0.07634945634392, 0.207030144069464, 0.19879187967988754, 0.21553656987605557, 0.2203068921282407, 0.10089737258010334, 0.1319046664021669, 0.10706534564134576, 0.15795377023037405, 0.1081351261405695, 0.10210860355366623, 0.08573082350795308, 0.1523586470753916, 0.06202083126071, 0.18563361477948007, 0.13894605630588147, 0.20828994501742626, 0.1280922604905021, 0.1397982218693341, 0.11686085227636561, 0.15443233983410945, 0.09510885818951553, 0.1443186002753435, 0.12067698903622166, 0.11953226215536557, 0.11568121476880006, 0.11568373519807093, 0.19451458097225238, 0.1531369311194266, 0.18800465690512813, 0.1667927241613788, 0.2000392087164425, 0.1221013686529571, 0.0860940334537337, 0.15361221206765022, 0.1870794525189746, 0.09050948079675437, 0.13317589738195942, 0.11143460554341156, 0.17461711721074197, 0.21406624796650103, 0.20658857098990874, 0.19133752241971033, 0.09328169252483115, 0.25657689589406213, 0.16453656458085583, 0.12419262014689947, 0.15550909173344413, 0.1363949835180275, 0.11034140573634256, 0.06886099284935383, 0.14988737000573069, 0.11591593644792035, 0.11588271887552355, 0.2246155697972544, 0.23398853297675812, 0.15768686519755473, 0.09988266614175613, 0.10320873645644996, 0.21373980258020664, 0.21768659563554874, 0.1414099789314693, 0.22137972165740308, 0.11733656989470606, 0.1292505394667387, 0.101364609605122, 0.16597633490399008, 0.17380471161055952, 0.10011492101776023, 0.10262914497645632, 0.10126402992154322, 0.19357797719778555, 0.19994545487626908, 0.20760598171862865, 0.1968936516993469, 0.14609065357475512, 0.11228972054537266, 0.1933987432670209, 0.10921419162543551, 0.1841123173794439, 0.11185713367716921, 0.30189873410328744, 0.41653533436117635, 0.07287581451237202, 0.1355111632015436, 0.17297450212701676, 0.24513803873090978, 0.12234109288622295, 0.20911790220247162, 0.12851711753154957, 0.12672488547621236, 0.14859759969817055, 0.16998446095855008, 0.13753170478007487, 0.20813815235610933, 0.17402441030548466, 0.06789135536359203, 0.18294300673709762, 0.11928398838086475, 0.10191818473920708, 0.20593011841898967, 0.2362544678391949, 0.09173370462151305, 0.22505440028204074, 0.22170780647185542, 0.171152530538459, 0.056683171104880116, 0.1013716959184216, 0.15635479151481585, 0.11181497585869606, 0.17754544233602865, 0.14440276269470492, 0.09507030864516575, 0.11672418985155322, 0.12084801816531729, 0.14725912152038467, 0.20257722736606676, 0.13708231760369194, 0.28334141859123785, 0.19447574031449136, 0.1414932526888386, 0.08101522291619932, 0.1301645130039223, 0.17010608507740885, 0.11903701695583521, 0.16473648288557607, 0.2287381340659434, 0.15735537895271856, 0.1087405194618529, 0.19062840079347934, 0.15148411174454998, 0.11355456235187669, 0.1491069102719907, 0.193801598262883, 0.2593067582816847, 0.15202202804146275, 0.17629693352407025, 0.2634965850701255, 0.16272948574154608, 0.11332711850803708, 0.07717561322234331, 0.0968276683781897, 0.11109046352606629, 0.10608838435502783, 0.14379689439890847, 0.13714841566979885, 0.11314536414800153, 0.1121232802829435, 0.17159719861322836, 0.1676148131129242, 0.18368582091023847, 0.23989922306951017], [0.004462591436270986, 0.055970146260674924, 0.018930896373105147, 0.02086399476073923, 0.025799508552036943, 0.05526119317378729, 0.04812548635527492, 0.02952491177336103, 0.01444451216112582, 0.014902395252589018, 0.06045150780870069, 0.06530228461469374, 0.013889411554461526, 0.027347379626946586, 0.09353299234663287, 0.017505260372173884, 0.032050952638289144, 0.016817217655179482, 0.018619870421506705, 0.002387339209822277, 0.04097564138411995, 0.021783298354655988, 0.009150394527692228, 0.019400527422887184, 0.044672927263403134, 0.07336051834206428, 0.023982708056968068, 0.009570992119880694, 0.016303622734642798, 0.04521023835085573, 0.05500473758025516, 0.031891043275414456, 0.04060901468619704, 0.011523259942600084, 0.04421383375301958, 0.023640485089873115, 0.016635970828393777, 0.04305088547088447, 0.03570562296156441, 0.05730206289538934, 0.04452355160948731, 0.031132317456086318, 0.037074629743132866, 0.07904415529581808, 0.0076931253199525665, 0.042066684653682095, 0.030003065551300685, 0.05610202446640019, 0.05039301851103383, 0.024551758167123603, 0.03071821437427594, 0.029589711320436293, 0.008471617644142, 0.026686954379622495, 0.10798352500123364, 0.016689660185347163, 0.03524091402669588, 0.03874681199029569, 0.023806461869108102, 0.058078810933136174, 0.05600965341493007, 0.06877208068486183, 0.07000440971985941, 0.02104948379940564, 0.004776382965276078, 0.05835818787736278, 0.10777296573524514, 0.026084598596958865, 0.03900170859490191, 0.021649164019993717, 0.03146049994674902, 0.05182297524785803, 0.02027052176755763, 0.016039218978896257, 0.01406107557892439, 0.06690192982674607, 0.04567075295433883, 0.04712377659856312, 0.020231068239457185, 0.054382789098928054, 0.0856188980622157, 0.07441148372186769, 0.02283304182422017, 0.03374615391235679, 0.01745463536691762, 0.023701998119753216, 0.021058198049544327, 0.0025687387753878872, 0.02862483890156352, 0.010639131275726663, 0.006841699031346868, 0.0437121955497611, 0.021580840468466766, 0.027326588000681613, 0.07440682590728806, 0.045771206233410106, 0.03659756764048531, 0.043634357186214584, 0.05286768168932008, 0.0195808089788883, 0.04763647328100858, 0.012264778469538978, 0.020277188647718682, 0.07146544664377166, 0.057464021543461474, 0.03060195861654657, 0.02444590396818615, 0.041591311774907574, 0.0654118275269866, 0.056194793883590936, 0.07835644582707076, 0.05694392828210708, 0.00810783217480827, 0.018449187947196827, 0.04002363158149585, 0.15892615031090476, 0.062080612931881225, 0.03413331176665041, 0.03010028785455131, 0.01348570715861335, 0.02982034400526074, 0.02362011864240612, 0.03143401437198683, 0.019704392367613413, 0.055098116037345705, 0.07776283493806278, 0.021641596986521638, 0.02593392059357176, 0.05651276250700316, 0.028168652694852605, 0.013924321223561083, 0.055128587184533964, 0.04957376791524792, 0.023727208158121477, 0.06422689635186427, 0.0318481327755557, 0.07649779394869843, 0.06252591302918811, 0.03171119838953018, 0.0912632653489709, 0.059662452568450285, 0.12473802878371171, 0.011982900248239598, 0.0075869608554057786, 0.045807089791783405, 0.05455098370270384, 0.10103444103151561, 0.02468585036695004, 0.027093844743625774, 0.02417800685150489, 0.0028276585386089624, 0.03720509451663783, 0.031831110301878185, 0.06115384955680179, 0.014650633862812915, 0.04380010413907228, 0.012694933966192748, 0.03271336396855693, 0.0077502137132649945, 0.0720482939974435, 0.02922875941881249, 0.05103134212174243, 0.045397294039327296, 0.030662263142726118, 0.028592615328248472, 0.01264556821796202, 0.019102668607487314, 0.04191814786604336, 0.01139084451771792, 0.029970889858480905, 0.09269555865396416, 0.017825519598479715, 0.07476014565796622, 0.042564664787102136, 0.022544069628741954, 0.04120699610681303, 0.06499015741170415, 0.06566980763548805, 0.02595697409443317, 0.0520489750159604, 0.04926095889400571, 0.13931656706958048, 0.02883483126248804, 0.07922005674411213, 0.03776451490158516, 0.02241988677621609, 0.06529065540000316, 0.04531473274372759, 0.022513322689900958, 0.04764077869514304, 0.038240826238066926, 0.0653880251751792, 0.061357521692350994, 0.03250596864569572, 0.029388232111570337, 0.06337655024723181, 0.04500777280378727, 0.028433855097260208, 0.058396350547310814, 0.0888258723482009, 0.042599517957217274, 0.03142801973397934, 0.031464372521206256, 0.033039357362976, 0.03425771678467432, 0.03450066241766176, 0.03924988277797257, 0.024587729825608196, 0.04159988046834066, 0.06392142645293666, 0.107127636250469, 0.0167022489251629, 0.04935842059973267, 0.04263568879856218, 0.07043165695523063, 0.00539193652765525, 0.033578277235069585, 0.06098034596371074, 0.08077535312622786, 0.0839507645897327, 0.01752133672726491, 0.06327252316799375, 0.035985321662719214, 0.010873107934340594, 0.02007367164497414, 0.012733894325191937, 0.06037207981271129, 0.02798290510151175, 0.03257856313740054, 0.05624154822960977, 0.011791330386674213, 0.0440828480397261, 0.032231540629459966, 0.024286055892345407, 0.0364561248270254, 0.04494242550384614, 0.09849303627326604, 0.04488445946105546, 0.07462447914745539, 0.05024789847553738, 0.04165466724624557, 0.06279161913440594, 0.06929669769540911, 0.06801407498818252, 0.04216184043475697, 0.01447159432685904, 0.02210167108944828, 0.06048917635193756, 0.07730897380820206, 0.04307059308273658, 0.04934893260079046, 0.02068028496127696, 0.03583069447608244, 0.05965869490718169, 0.01229689191771491, 0.004564268061996348, 0.07456859303337914, 0.06127696371667328, 0.032682410185976375, 0.025939936298997174, 0.051999834306057424, 0.005659165232622576, 0.03209793489546545, 0.07093283933617416, 0.010899293777202407, 0.015509698048023688, 0.014408190017415872, 0.061366894778104565, 0.03504943801090121, 0.02152557297038936, 0.028141378049528407, 0.051680616959328615, 0.034184157022184906, 0.04182886031846847, 0.041802909090033466, 0.05541840590716851, 0.02162576003390695, 0.0610668717643186, 0.03552892478182912, 0.021514577693456126, 0.04929457866256276, 0.06909959859425022, 0.05986027179225799, 0.010039440521429624, 0.027791718283908504, 0.03253489229527693, 0.01340302903460519, 0.06677029293871696, 0.08126984755959242, 0.05223210833425965, 0.014000580488373677, 0.0903109720938148, 0.04972621941217973, 0.008434408753659696, 0.022934094567092198, 0.09539351347954043, 0.05090996315101943, 0.06071945472109703, 0.10786068280257526, 0.022993713444579515, 0.005348315960051673, 0.06942107206991605, 0.06511735865065167, 0.08541868864408425, 0.030032559936385483, 0.03193041061862342, 0.04374927420529627, 0.08682420717612391, 0.008969367951184751, 0.02467630108097388, 0.022305235972688086, 0.05325596952330201, 0.054779553695792155, 0.027979813936737277, 0.032227124132576494, 0.00933600901325624, 0.027363976921826124, 0.06150525408766924, 0.047816726108712536, 0.040153786089391484, 0.04929348698727066, 0.018527162291349906, 0.04766068165941585, 0.017823996998730208, 0.019994770334432685, 0.01913551462724084, 0.018158346497183366, 0.03455412386345767, 0.010989707474025988, 0.015482094942501958, 0.09477470595870288, 0.01259758047038509, 0.055722707522011576, 0.0944298668013465, 0.05070507293567062, 0.0819612495721348, 0.03999928530726222, 0.03676131127342101, 0.0717700278807071, 0.0280373394789715, 0.0059843633320152525, 0.02096336594061746, 0.050608921240294175, 0.04800020033613809, 0.0265131366904825, 0.030992646220951315, 0.06751218780634866, 0.03565221897236282, 0.07051544399150918, 0.059547455110136545, 0.021618237050490516, 0.06268736988966984, 0.19999371841549876, 0.14001465702970184, 0.1482773902675798, 0.21103969504756315, 0.09034438118819269, 0.16898814829126482, 0.2344420263844152, 0.17468295480695464, 0.2636332245123002, 0.05846262481364031, 0.23296427342199513, 0.16513812746251785, 0.06376930820425192, 0.2138918710331763, 0.1537299751033706, 0.1528539229184389, 0.28221695473597896, 0.10208668577815257, 0.09285027777115185, 0.1511480749374436, 0.16187508320135457, 0.1292371329280638, 0.14572483126915273, 0.1721744611859322, 0.12341943058756091, 0.18738259351061237, 0.10895831825872583, 0.09552906507686262, 0.08954128355629022, 0.1114982214846438, 0.0779361929744482, 0.10198668832139623, 0.13472350224131538, 0.15339871868491173, 0.15356518959085788, 0.08890043568587111, 0.18324994752483983, 0.1604091739582439, 0.16829157518523355, 0.13836013693963328, 0.11657271894716448, 0.14483034700876282, 0.14878549042247957, 0.16977171834197738, 0.06988785710305938, 0.17933159165324705, 0.12455648892829496, 0.11628500696632171, 0.20175576660661929, 0.13153236299272508, 0.1667713349865329, 0.08726921999045918, 0.09906261498408933, 0.1771746404589184, 0.21367866876384906, 0.1915042844390677, 0.10193698453686892, 0.15914701345947482, 0.12295749489097826, 0.11967732090382807, 0.31086165638219926, 0.18287510070348942, 0.14342149599425255, 0.0985546144206197, 0.13666173533326195, 0.1426460005102619, 0.19614665468613948, 0.14672777825786223, 0.09302994837203334, 0.0975241955189455, 0.12429206602035031, 0.13505477398153276, 0.21261245823435246, 0.10960901801985119, 0.10816553983116343, 0.1094746308761739, 0.1658541132365504, 0.12445754867287413, 0.12948035052226436, 0.17353958390172453, 0.2459558222683207, 0.13852179681341495, 0.09660231595438334, 0.12129635580124394, 0.10564143333824412, 0.11359616858704437, 0.1528048779695265, 0.2404731761423811, 0.08839028241533427, 0.07765023533495204, 0.15049947425723076, 0.09107968003879632, 0.17512903248350467, 0.11996606710336863, 0.09144518824834978, 0.09490492558407207, 0.11977806146587096, 0.23329065752125558, 0.11193490692324216, 0.10647441606007277, 0.09585725714362438, 0.15953503699312288, 0.13412298123923042, 0.09736715515534725, 0.12219210410670889, 0.24648001026963037, 0.23944105652551498, 0.16249425078351654, 0.16175230995060938, 0.1573789591390279, 0.13384078509144245, 0.16405913858644425, 0.17822448735035237, 0.1263522373272046, 0.2545983818990569, 0.20847285617022746, 0.1501346785094469, 0.09579525764791236, 0.06793063269146989, 0.14840273757375058, 0.11623140379425981, 0.1102915334124719, 0.14934150171616387, 0.09190391403652969, 0.1728908759692023, 0.13703679665923119, 0.159379996119007, 0.13778045352908874, 0.14397225192477628, 0.09566837050501378, 0.09081313506730142, 0.12648164489937405, 0.13566053502501982, 0.07294411891170087, 0.2143747362518503, 0.12166329659521581, 0.23957460097247557, 0.12711481656879187, 0.140525515101129, 0.2083516610606063, 0.17301397097687568, 0.14782922883187571, 0.12185258159954702, 0.13129280729880258, 0.22353204568066906, 0.1970236721418558, 0.20604965877869438, 0.1586673811318413, 0.17871597871905376, 0.13561421734911783, 0.34001510169717575, 0.06225730728117689, 0.12350450465155226, 0.12815473496072716, 0.16131910255118725, 0.1546691682550215, 0.09818767362664785, 0.21049964902622087, 0.145402982410404, 0.23224128560433466, 0.0934027957039014, 0.18048720464350718, 0.16020735575547143, 0.21055224862310196, 0.06971869722849901, 0.13432170444678876, 0.12844664510339499, 0.22170903221253427, 0.12218422872284729, 0.09033621469091985, 0.1822171077853249, 0.1371068630607859, 0.1142412452628055, 0.18865333419413338, 0.14684859032352127, 0.13319106592286017], [0.013424377989835076, 0.010173154465343443, 0.03060911962341878, 0.036077505022647886, 0.014858666953871088, 0.054613147907319574, 0.04801050421871966, 0.07714788083948436, 0.019029553175993988, 0.03287088696754748, 0.01867589826184896, 0.07430557206633591, 0.02777807617319688, 0.05920379955862319, 0.054129520431160934, 0.06882494841251643, 0.04586594832700588, 0.0980290934263218, 0.04445931130659677, 0.014843189104970907, 0.07439900414958116, 0.011855971928115093, 0.08169383892128546, 0.05903471246241562, 0.009221964376798321, 0.03791813851304112, 0.06354971293119654, 0.026748193533069668, 0.049336387911030365, 0.07945248015945958, 0.0500545034094924, 0.02850613740813588, 0.011290277283067906, 0.03345063166512597, 0.013908224758662045, 0.022253178383013415, 0.04063494676243394, 0.04652820452446899, 0.04907217567726489, 0.008154545343601176, 0.06748084714936634, 0.015611245875216782, 0.02728708276164628, 0.014918015785365096, 0.018258089229704875, 0.012219513206922961, 0.0229444214323115, 0.05456825515495674, 0.04691069690330375, 0.04130142793479947, 0.06502594137864728, 0.07850502857998495, 0.04626434469114869, 0.0787295229853161, 0.026812069944196174, 0.05094963118373867, 0.05432643950165761, 0.01782775082955918, 0.017256977021574013, 0.07943080753208169, 0.03737044693421453, 0.07803863425168299, 0.07179402175449556, 0.0333607925342456, 0.08922413081651734, 0.027090594615607012, 0.02081465103753632, 0.04867742206120203, 0.026067175842340917, 0.01455424563778985, 0.030091146510394833, 0.037461680345117085, 0.03976452149330609, 0.04028366097519475, 0.047964726634804285, 0.016688823234289885, 0.05481407361766023, 0.05418518054929953, 0.06405288331030358, 0.011474799135729912, 0.04082524683326483, 0.03931457507273844, 0.1170627853923267, 0.07756549068876813, 0.02197384548884246, 0.0341375520633113, 0.16193365828404505, 0.008016175979132494, 0.023988951673550953, 0.04246190558337877, 0.06325514063299184, 0.04977060654651254, 0.058479942231168675, 0.007306630610518399, 0.022026199937587785, 0.034952006948691224, 0.043039658452354135, 0.008105683298180661, 0.013424658569537345, 0.018985798064198707, 0.0692218509052069, 0.05409964683255362, 0.04489583586673102, 0.023311180280401342, 0.04502199139566191, 0.03666203776975313, 0.024729798915946198, 0.036724845488225265, 0.011188495799057908, 0.09161490736709488, 0.025566826582015045, 0.05953446225894075, 0.09134316831947335, 0.032251520202525204, 0.009647614318847416, 0.03736200081484933, 0.07145881998322665, 0.033387234058952144, 0.08014463293816775, 0.01604493974047082, 0.07726865460074718, 0.042610047835736506, 0.024101242926272175, 0.03770552613141556, 0.020520731829287066, 0.0619020838020069, 0.019251498423757094, 0.027913350063646515, 0.04592379179572867, 0.03737905776248344, 0.04229339688355404, 0.027534801122401992, 0.0199598022511289, 0.018857386406330813, 0.09130638843822865, 0.02673397685641483, 0.031196387304413705, 0.014548409005416738, 0.06851583193506926, 0.0092807530064977, 0.03578059615627412, 0.020888402322006804, 0.03425197495568184, 0.03892118126274117, 0.04481545792171552, 0.016455997622782187, 0.044504702016110384, 0.012113551755676107, 0.00848144176416099, 0.028781408121088342, 0.058481439933060646, 0.007650926803058435, 0.028896457290336974, 0.02675694991804419, 0.025621885321133082, 0.012456664342373129, 0.013174301035882486, 0.05159887920824751, 0.04124473359796309, 0.030611536630819884, 0.054607007712606466, 0.0188357463376897, 0.0025757532679445802, 0.05843787251280681, 0.06190967573333652, 0.05279194623712571, 0.0905682244187882, 0.02245780812846797, 0.04737151794195656, 0.05016025801699969, 0.015798117702586517, 0.018837037195842114, 0.044977205895608476, 0.051405871016604286, 0.03271911345842866, 0.07301151932727906, 0.038416080342064944, 0.023893311341863968, 0.045567047632028984, 0.032338812091057344, 0.022548365466777357, 0.007331541395791236, 0.04300188648724749, 0.07925230904572433, 0.030447390801723928, 0.06330574074039055, 0.018005377890902664, 0.03811422254770033, 0.04726690863589606, 0.0983794867211292, 0.045450743993804346, 0.01710630284862653, 0.04839092432971924, 0.010334192850296537, 0.06056337962828337, 0.02835494995627913, 0.04380694147379648, 0.01797881953778767, 0.011254925198192078, 0.051254266046828804, 0.04225998395873655, 0.053971530118536566, 0.05113433115184308, 0.08840488405117104, 0.007631756410363221, 0.02203489120508875, 0.04385694786305389, 0.02691244852969483, 0.024961479226007097, 0.02509529563418079, 0.021163454699900844, 0.01577399646668064, 0.011150941211399774, 0.03174210620683528, 0.04647809088290219, 0.04964409478669686, 0.05360527497325694, 0.04703477633395984, 0.012298413559854513, 0.05863123693533483, 0.07175723421237162, 0.03817647485242736, 0.015060429615269025, 0.015705330090807573, 0.05485639231459749, 0.10966739391968136, 0.03624992077088645, 0.05451172169658446, 0.09407953479357305, 0.023934756698567542, 0.04829013397196128, 0.059519726557717215, 0.023454524907133272, 0.043916116663885695, 0.08590848695847296, 0.04142065802889486, 0.033352507293344505, 0.011965468875132503, 0.06169294179867833, 0.00755450266766392, 0.023085760823901624, 0.06239804912418608, 0.02226845800666319, 0.05126692948021716, 0.031147348101160703, 0.0373378690452345, 0.016213766366784132, 0.01569816333827593, 0.034263343700478156, 0.04005451641616322, 0.033124481222682425, 0.04977558228758074, 0.07330738248363619, 0.05204870305474728, 0.08711273887104566, 0.028007362458494403, 0.031901638271407254, 0.029027017824832472, 0.06345331608768433, 0.03221933301838656, 0.03642704029898009, 0.01786712583364739, 0.07334095245647816, 0.04557580401700351, 0.0145611270225697, 0.03811626034157892, 0.03840400679637829, 0.03983166526942965, 0.03372469578959769, 0.038053759058276494, 0.023442734813978596, 0.06104428749231081, 0.039827264094304655, 0.007582580747698704, 0.03121592637692248, 0.10607960498741559, 0.030274402402761965, 0.023086253035392974, 0.018446566011275978, 0.03427598798166841, 0.020441213817966562, 0.020244227714776512, 0.003316164797832889, 0.07349216289097264, 0.041837072781016754, 0.05742303583951247, 0.024168221993492018, 0.05908790577743804, 0.04139736895599673, 0.04975281798491075, 0.011927631792552289, 0.0445006417501117, 0.026908079913306623, 0.04811015310547045, 0.05075104970244631, 0.027912333081927032, 0.019601083495804382, 0.04089910537004471, 0.05412540270856792, 0.017456598467223586, 0.07934415532696633, 0.018612276574957277, 0.04228915658689315, 0.05870641314334447, 0.008326958219010023, 0.008390571287412558, 0.10511919886114136, 0.022293221798815557, 0.01338102411659014, 0.048668566084797346, 0.05549039901985277, 0.024725058746914712, 0.06526371974858546, 0.010324972982127822, 0.04339225424994384, 0.030588948528372475, 0.03367384287318395, 0.08739154124932905, 0.06422674696471903, 0.012976896457163798, 0.02492660498847404, 0.04052290640350792, 0.07136184857377122, 0.0573905039158079, 0.032559851439849984, 0.026935777822208982, 0.04813047358766199, 0.03350446466356516, 0.054251588881015785, 0.027160682084579623, 0.012735573015356017, 0.02148310105586725, 0.07973288366150472, 0.040735177876007174, 0.004147812132648523, 0.05412238432214626, 0.025532789295539263, 0.016848248046552463, 0.04876891977243847, 0.026947006755959124, 0.13373124984002885, 0.0891427416354418, 0.04936980083584786, 0.04060105120222415, 0.04514260810890025, 0.01396232205743511, 0.0030705933984849724, 0.040734434770720626, 0.10412007465117401, 0.05486270870953318, 0.04156496218075195, 0.028279187691007412, 0.11446924835082986, 0.15010245685135165, 0.1525514560841745, 0.11651165407872009, 0.11365771609088106, 0.09789648360662884, 0.1630417585012413, 0.1272651536630527, 0.0862698046670806, 0.11048300942826657, 0.07156099312968793, 0.344095898852233, 0.09071175099140213, 0.15087271229394023, 0.19411993843893852, 0.20076561328624526, 0.0946788530376169, 0.15538049621447442, 0.21251458284114638, 0.11017024637229982, 0.11239062198587965, 0.05728812392560705, 0.1543639435042297, 0.14338571968818867, 0.11141452637891616, 0.1613532087855762, 0.16202371958042347, 0.262915829136487, 0.16678992027957595, 0.13186789418180145, 0.15238026607661478, 0.09856340910999045, 0.08298073639912952, 0.15489783017866074, 0.0963753700676945, 0.09912492857585031, 0.22299589138598214, 0.08384655364939282, 0.17766539638321246, 0.10750163271422349, 0.13035886951031225, 0.18926874794546636, 0.18937099003984084, 0.110735941017347, 0.13503379849416597, 0.1554121203239887, 0.09299987176012608, 0.10556330003084675, 0.10258311841396556, 0.16068176336346135, 0.22526505913945938, 0.152926777880038, 0.14548106209164666, 0.22758412986032425, 0.13643698045803657, 0.15238509243053777, 0.10767086919757629, 0.1401263832925789, 0.223247857704278, 0.1290537008354741, 0.12334696633080322, 0.17889740366128185, 0.11669836502762572, 0.10647093802089654, 0.17300251030152844, 0.15268504649641054, 0.10364274058731333, 0.10381943110616938, 0.10614413257327773, 0.09674048757240658, 0.11623833688997454, 0.12191964493643855, 0.09549648335744297, 0.2058267731580042, 0.12710723995922074, 0.11011147210674901, 0.2075282084725557, 0.18740136266475727, 0.2554492451130383, 0.09149302277834186, 0.1873791767584701, 0.1060362597326598, 0.3320677362142071, 0.19289997406303885, 0.12057860036410632, 0.13092248039620538, 0.3224764992633174, 0.19250249700440517, 0.09743513013686865, 0.1456989834625875, 0.16960213711905867, 0.143600944429636, 0.1438230486406434, 0.11340578807698143, 0.058071280288840496, 0.11479104358342387, 0.19841271212264416, 0.13038931384442315, 0.1899188348362523, 0.18103105046095389, 0.2954400306747806, 0.2143501601512394, 0.10731384924222385, 0.0832161169138647, 0.13957237914925621, 0.1431967717625441, 0.0967599462056833, 0.14253926914065115, 0.12422922382792159, 0.21992173376342944, 0.13641729199838254, 0.23622842084976936, 0.2058824830718579, 0.22428668825136078, 0.19604781402214883, 0.18972277761467043, 0.19436098034343413, 0.20942663563595665, 0.11561332405695032, 0.13548525410794443, 0.1346008209211211, 0.12316421605646612, 0.16506645227632216, 0.0903972872202435, 0.13410070340239233, 0.11989403185584854, 0.07485579939619189, 0.13052305747424403, 0.15972775407135487, 0.11875923347449112, 0.1512865836341535, 0.14307664917601695, 0.13113738338072456, 0.1482168999650786, 0.1837891814929824, 0.12613138950039304, 0.14127225164444218, 0.06895601839548157, 0.1357743603688094, 0.11165240434028449, 0.07835125175094412, 0.1280009504708071, 0.1569372328418878, 0.16479599259553418, 0.13341713846931536, 0.07668769182336908, 0.20270409152632762, 0.1108918782143343, 0.09657073781014451, 0.1243550078042092, 0.10664758257447712, 0.10228950755610582, 0.18919128113456313, 0.21282305580473718, 0.17947319534517106, 0.18416180665935242, 0.16252745303415483, 0.1293606263014578, 0.12159859280913107, 0.1912290596913907, 0.18657941160903824, 0.0744806384787925, 0.103828095560593, 0.11783701683124227, 0.17236071248208323, 0.19521840127004733, 0.26712925143299565, 0.12289050050199994, 0.21379546652878487, 0.1458855105503913, 0.12439020954432989, 0.09068686845562152, 0.1922383958533887, 0.1787471125322965, 0.09457261962515694, 0.19646602142001354], [0.11779917974866207, 0.019748679910516067, 0.08159591756280392, 0.01465624928729789, 0.04059375038430576, 0.013305519448382961, 0.05512035173934795, 0.015165010193032364, 0.03817894931642279, 0.051111122518176996, 0.04861465264712611, 0.06933486419579676, 0.04491246763556715, 0.027547405183976217, 0.040472658696554364, 0.0535312095927375, 0.056322979545521165, 0.019052631574712934, 0.015615837614712937, 0.02674375213832865, 0.03486450055554029, 0.017494473854200016, 0.04565586020509082, 0.04251775339305882, 0.05866496395620127, 0.011421890230849387, 0.026708339724028786, 0.030141689161199237, 0.05711616783012306, 0.04800119625043966, 0.012532859447322065, 0.03739222681390182, 0.09337263482232248, 0.04550852234505358, 0.04520985913733321, 0.0481910404989556, 0.07081856966138848, 0.003007275992140715, 0.0839974423269591, 0.049068678485890554, 0.0345637574191055, 0.06417400181113232, 0.007991731549883562, 0.02212574923290841, 0.028365179145288084, 0.07762905300384568, 0.07482310276358359, 0.007551258764109545, 0.03822956857601962, 0.02315343511591275, 0.028090571098390128, 0.02505604320416047, 0.010163805319837505, 0.042954963601885304, 0.03426815856308226, 0.04958897476054488, 0.06295172384970131, 0.04571361557370232, 0.01861957930809548, 0.04300056881601772, 0.034273482874156005, 0.023560095653538744, 0.055196788161993034, 0.06506177897174513, 0.06885923850800722, 0.0377385713340294, 0.017024919413210406, 0.05234735094070916, 0.05581160819518471, 0.05412017415848471, 0.057143758486716024, 0.05270709816907203, 0.05008951362763202, 0.009740761991950774, 0.0257924854409911, 0.01929013798343799, 0.03813414466417125, 0.02206526467606666, 0.05514270618497845, 0.035443689839373675, 0.011432010252329131, 0.03835111608608596, 0.04069490080338813, 0.016965976608316266, 0.08242839466660254, 0.02292852127744306, 0.046265987949746276, 0.045662567304867896, 0.037010760992885604, 0.06450127074194532, 0.01601573455357744, 0.02850779215805233, 0.02041167921326574, 0.008877206616283906, 0.016738590221070958, 0.06368880768516852, 0.01117778493226656, 0.07252969598818211, 0.022765867404579636, 0.041833985446681904, 0.049049583744377866, 0.055407899011287, 0.0693078289529489, 0.017721287590721925, 0.06242030397838643, 0.041730896825151104, 0.01183247026581798, 0.053678788770470894, 0.06496477691877274, 0.051120127881726915, 0.04444981564677531, 0.06773794625675486, 0.0393359910606617, 0.0165717056276457, 0.036832706837524334, 0.04821100091982273, 0.05444436724628172, 0.0370997459357304, 0.027278676861897114, 0.04117040391710978, 0.02215097650825497, 0.029333324674817345, 0.03808483541492493, 0.03977657588679464, 0.11636139359325172, 0.021438484095157157, 0.052572906377815434, 0.05065775168458781, 0.04652713583181462, 0.1099851671906729, 0.012252299854862354, 0.022258307341666474, 0.040205500854720036, 0.051743072277355584, 0.024006713422075398, 0.046000323979364294, 0.0679776321856245, 0.03424018869296678, 0.06778472358541143, 0.02311401797698871, 0.024001821950678865, 0.06026549399980615, 0.028292582738363457, 0.09159663617010079, 0.05333129128801727, 0.00923138342782735, 0.07049063040364174, 0.025448075292872328, 0.04661818155117574, 0.04215490733904224, 0.03688216547391588, 0.03404600455635979, 0.08417260833084585, 0.026451118042572375, 0.08292189318566554, 0.04039367886200067, 0.07395321758644235, 0.0630498328997243, 0.06047003564514941, 0.027650501466386264, 0.028694667815861684, 0.046150255047025225, 0.011923792734441739, 0.030651302339749473, 0.0460208896096916, 0.023333557708669576, 0.014376421308805867, 0.027330075615956902, 0.03500615404317937, 0.01164269496521522, 0.02981734668625699, 0.039845041164587584, 0.07416514048893606, 0.10909603788487374, 0.04108029282501629, 0.04837373714713801, 0.05416186849376368, 0.042441182905026985, 0.06697029551310886, 0.01998956859742682, 0.03607066768792368, 0.021591718916991548, 0.03308401645852193, 0.02002409234973452, 0.08899823447028476, 0.05711073243630029, 0.04548299629541655, 0.04077599887105246, 0.100311889883972, 0.05780009665496408, 0.05568320036775643, 0.08158641807254284, 0.049004120256511435, 0.03310288520409696, 0.026429345823764324, 0.08966155169952301, 0.09792347288420124, 0.04129665137659158, 0.018651846931466175, 0.0556255828949713, 0.0352320580502912, 0.04063235355481025, 0.027391615458914352, 0.04206546274344287, 0.016684617411585587, 0.05927521044448499, 0.05157205847001845, 0.07218357746399219, 0.016994107356895844, 0.05312494933605195, 0.039085028317546656, 0.02288382004706129, 0.07848658118276827, 0.03129984173292835, 0.043363280804647554, 0.024370691371000102, 0.027627444135085232, 0.027541586746191307, 0.016348877463549856, 0.020020780934681816, 0.018360599454852845, 0.08599018257471823, 0.07628135112745148, 0.015354861144817647, 0.014657053679618386, 0.06732137062616887, 0.03531830805924631, 0.03370163271263723, 0.01910238515495533, 0.025234585740573467, 0.08897746582665751, 0.012611937915696012, 0.034239464739878336, 0.03914566034631383, 0.02944633605018739, 0.07003643219509433, 0.017356727414974765, 0.009738560446778373, 0.04430605541734446, 0.017402719503508943, 0.05721467524586667, 0.02991078259994186, 0.02257508086791683, 0.025283829872346213, 0.036327762964872584, 0.022698147147293055, 0.037466070028923215, 0.004679946380952794, 0.011145716491756181, 0.039279040084370685, 0.06741946052399374, 0.03161766096919535, 0.018350624990078713, 0.031331293472659685, 0.06250398376235558, 0.011106724531630115, 0.025478441102970994, 0.013495848247511013, 0.02516027521191826, 0.05976261473411034, 0.07458262010327271, 0.02086124450509106, 0.031990270813806884, 0.015718717477284372, 0.05410351174613161, 0.0364128485201828, 0.05307805326376712, 0.024570197903461034, 0.03510344720956299, 0.010906298693660046, 0.02128176357326729, 0.1027029115826853, 0.03435266955244926, 0.08169088182189772, 0.0831312113892167, 0.04946261621831406, 0.01888955060783173, 0.02943276288738895, 0.07001636835235743, 0.02155138630299799, 0.07170897833402119, 0.014853195170871915, 0.019764679656814665, 0.03704117468347953, 0.03706878449227061, 0.02801493906806554, 0.05240664231560884, 0.025144011165285786, 0.040296891313647075, 0.026680042351325674, 0.041264464192452936, 0.03845033596359915, 0.040278846112590645, 0.044727534010645845, 0.010558004479765171, 0.03521374854890089, 0.013263552194280971, 0.028578661036707705, 0.0501330006086538, 0.03984969897916721, 0.036775384308590044, 0.0409362759561308, 0.03977236623365072, 0.04554085125545821, 0.033858435588978955, 0.05023982390881546, 0.01440245680691254, 0.049494205853871764, 0.021603373029539664, 0.04724589484413305, 0.024289271546407573, 0.054333384088691206, 0.05204262414706811, 0.0693845373368071, 0.004861584391384836, 0.07726135378282878, 0.027181724604639797, 0.0423206466310207, 0.04923814862606026, 0.03042425494641066, 0.01004431667106767, 0.006103083498836045, 0.033335159232299176, 0.04433919638094883, 0.028462974099262107, 0.039691501822803295, 0.0045587081788858825, 0.04941137259705894, 0.043662173838745204, 0.04535934204355844, 0.04101234848701185, 0.03357714725538127, 0.025482160459843375, 0.0570430638899486, 0.09295899330848649, 0.04957600106154719, 0.016411579844932404, 0.037101829694884444, 0.04926094740268685, 0.047915298641929706, 0.03993561190943565, 0.005521042931509475, 0.026299718001316634, 0.015258441318667706, 0.022136715781544487, 0.03340495750308037, 0.013552125066428656, 0.024177307796273983, 0.059990464604549834, 0.01720422995276749, 0.047237935190599774, 0.040693077514128345, 0.22556810820054626, 0.10394943622691978, 0.1979533504814871, 0.09341237946383416, 0.17958340475395804, 0.17010651408664643, 0.15410702825794298, 0.177245871314118, 0.18899577549628674, 0.1589120696148565, 0.09390337287538475, 0.17672070272026524, 0.13372317527330693, 0.11937329125019813, 0.16122764697478664, 0.15051652737442525, 0.14097882464768427, 0.1507219768339588, 0.16031431695145948, 0.1524379678190716, 0.17571988545598524, 0.1037911394791257, 0.140575019702796, 0.14216958575191038, 0.18224024364063818, 0.0944132580151481, 0.18419435007437585, 0.07888133096839152, 0.22640872115810073, 0.08326811896216485, 0.13156921182188297, 0.10952672485502497, 0.16320772378915743, 0.15637046567374663, 0.1560419058847812, 0.1366301878325401, 0.14065619437925278, 0.10241416538314474, 0.13888507570710876, 0.2963068744828624, 0.08678587979727215, 0.11779758628577956, 0.07681075618752549, 0.12318489276954245, 0.13941349251376045, 0.10141543187801877, 0.22714346076451966, 0.09228386300345583, 0.11477726166166606, 0.16525319386874476, 0.12915001340931462, 0.08236102489454132, 0.12795480133424844, 0.12196603922113297, 0.25402286600682045, 0.16201648771041827, 0.1847773429847533, 0.12806637437954066, 0.10792527933635059, 0.16006242724195605, 0.08363810878607535, 0.0771648726696449, 0.18167844072224634, 0.1542535042690654, 0.09002198840701774, 0.16733525230759577, 0.09956827897938991, 0.12403941022292261, 0.18120130584124597, 0.19529674142118425, 0.10615504166531949, 0.1484887232823718, 0.14512340628331707, 0.07498653996134959, 0.21788332701450397, 0.1365157342966526, 0.1320075213668808, 0.11189205196475792, 0.19109591361015074, 0.11830736417323352, 0.11990357731138507, 0.14662159847155695, 0.13293459500756957, 0.16616352082740876, 0.20575911227253177, 0.20551123686375158, 0.11701316587747106, 0.08264961021561777, 0.13986404414378828, 0.18650347697398356, 0.1743005543586708, 0.07200838081658849, 0.10673511578070541, 0.06383130386952432, 0.08805647492408754, 0.147720858034107, 0.10785746523329329, 0.10505386688295873, 0.15568167602102603, 0.1837442274535856, 0.11149498859360335, 0.15339540918507885, 0.1810562853971797, 0.10792500354469785, 0.14789656796041997, 0.16168961331488627, 0.09908006646700444, 0.17725063638100702, 0.14185651626077392, 0.16854211657999024, 0.1355853817996479, 0.17194746933396787, 0.21014913315734557, 0.13938626574893154, 0.17223061543078194, 0.09985207625093961, 0.21457698346386034, 0.11750451935034607, 0.12078047219303348, 0.13304227632620644, 0.12733356531469092, 0.1571150418491133, 0.15340760530483338, 0.08651977915677332, 0.20797142098026894, 0.11634132208963556, 0.17965728627337565, 0.0947404541676083, 0.19257703735943765, 0.13038445684698322, 0.119014892336582, 0.10680092273340111, 0.10253768173917648, 0.10190739056035396, 0.1338126236993459, 0.07404351637007729, 0.19932745174775202, 0.1615272946054897, 0.19357384032299443, 0.1739092672904653, 0.08549090009182693, 0.12566778373213547, 0.17128388397395614, 0.14489601606563215, 0.1414127828132722, 0.07488620542590657, 0.15182342740797228, 0.10483358596121112, 0.09503971109346998, 0.14664245138485588, 0.08407136215077293, 0.17076951721983571, 0.16777665684780768, 0.16694801018363045, 0.2412722364909226, 0.10360062107323639, 0.1009810523640725, 0.18573411019338718, 0.1554030651647237, 0.13111794006920632, 0.09866985702706922, 0.21393429698242297, 0.17063801056675373, 0.1380622206676391, 0.17140759185196894, 0.12091099059269314, 0.11581952428264965, 0.08176818775433688, 0.12364668290941946, 0.08216575674352147, 0.1229116292069516, 0.1187094071158959, 0.15437109876544247, 0.16571431751212767, 0.09014552008480796, 0.12275098823010923], [0.07358190243042285, 0.04505435861046276, 0.012930645813955175, 0.015461023694144623, 0.06179640197285241, 0.011284401388688674, 0.06208755751891483, 0.041896268394925905, 0.005983908467310211, 0.07780594270556204, 0.047987950590228846, 0.03530302843559654, 0.055939180986775514, 0.05064611480901799, 0.011706243873754097, 0.06845103621843361, 0.04034291787613784, 0.06748234102081868, 0.05809473024020272, 0.07415098318409535, 0.07392180032066761, 0.05204973727344506, 0.01606631550877806, 0.02406268380582333, 0.013608216109024662, 0.025699626008469253, 0.028998565319324696, 0.07432658585809893, 0.03483203374930928, 0.05896309090237464, 0.014966977422215767, 0.034571548533295436, 0.019142761819004532, 0.03130551844444727, 0.001361584347192078, 0.008148096798498544, 0.011829803322231578, 0.09359410318035273, 0.03665303623664283, 0.009059499153086256, 0.04374877624814549, 0.026033370297462232, 0.006317417184266472, 0.047339261809904734, 0.04435768208256172, 0.05754707696577234, 0.09310067360920292, 0.03936833529282482, 0.03660946115550976, 0.024066657886930534, 0.11581736391470318, 0.03458240782962211, 0.013756676287870976, 0.047346286836170384, 0.0370013112983396, 0.08077960491420762, 0.03910806841186939, 0.04421982456058745, 0.06666551509331312, 0.038320752191207105, 0.04082399044906901, 0.06115568050694081, 0.04314595315184805, 0.04373287609327705, 0.022083194963934443, 0.024203776134057872, 0.020037021998676564, 0.1002169639292744, 0.025392210246213985, 0.026439994445911823, 0.08996694498965818, 0.05477946942612048, 0.06712679961516012, 0.03438345479568647, 0.033585509105074796, 0.03105655136037498, 0.03606143249799648, 0.01160009760379551, 0.015896023739309564, 0.059988518741222165, 0.032264398140532356, 0.02556288314442481, 0.05480940431176175, 0.025659170820407813, 0.03513169670177083, 0.057687458747457114, 0.05099975248618473, 0.028407903868825208, 0.05971282284947173, 0.04324896516458642, 0.037034096031059185, 0.032600308543131236, 0.013634530271613791, 0.10833062411796664, 0.04924430414253185, 0.026475245981747587, 0.03387543891045836, 0.03028656404855992, 0.034503473960343874, 0.018499550567339026, 0.06724568880012921, 0.015388216613040817, 0.010319212000937232, 0.08951197303230725, 0.04006406187169975, 0.05098676729586817, 0.09280750708233926, 0.017594614952442147, 0.10966914060014872, 0.023191814205699393, 0.04948628833517433, 0.029534930288190805, 0.0414745369926095, 0.03891268917810052, 0.045540721020511085, 0.028141663417280204, 0.06721334456796609, 0.06943208075338794, 0.04146702167007231, 0.10307644839368521, 0.03519113363337613, 0.013923192201482673, 0.03271927050645313, 0.057735664830092466, 0.1319006214579267, 0.0346425763751951, 0.047168389728833596, 0.05553120086269994, 0.0657157422674279, 0.022559450759041696, 0.045107211016358874, 0.020807955429078113, 0.05408694892520866, 0.039746085587408275, 0.0371835061589316, 0.07630446400012701, 0.06325183496359857, 0.012660742504522206, 0.023621114556707686, 0.03288401388413003, 0.056404272965606184, 0.042196685943992875, 0.022157928756167813, 0.0477938468928539, 0.02662791772895763, 0.03571640947953828, 0.04678827605300373, 0.011177426786161961, 0.04127488681866277, 0.02887582845775591, 0.04474806899745618, 0.053753225703633604, 0.030276237183340618, 0.022715962521972197, 0.06558183009826368, 0.0333451145448752, 0.031656746775092136, 0.051518256115096236, 0.028487249510362748, 0.009710873071584972, 0.02099070761863503, 0.10674217911136728, 0.05329877085563156, 0.062481204137927106, 0.034054902667600306, 0.03426272699969911, 0.03074798072057386, 0.016142589137739232, 0.016813867935730566, 0.04842620650907198, 0.12855687749481973, 0.03604673510116916, 0.02187202857326596, 0.014625719725905408, 0.048666918995760144, 0.05017850240091643, 0.024869416524926503, 0.08583574691006253, 0.027555814914165006, 0.05019293549740988, 0.035655425050325935, 0.0048838334999257525, 0.042679133644748124, 0.024628052863502697, 0.04367392945794329, 0.024916557745347102, 0.04578833595939702, 0.027492051501007333, 0.026666245107809385, 0.05491806239250207, 0.025887882539762125, 0.06416300461897928, 0.05268703815677474, 0.05265226159545203, 0.04868439346131298, 0.05304521873533245, 0.015912442918746703, 0.04021755524820859, 0.024174890788872878, 0.05841246903723767, 0.01707611706919007, 0.04000239945467442, 0.04506176285025093, 0.04692945456612976, 0.07845600661371024, 0.06019999348228017, 0.043955528057150306, 0.031446386691963965, 0.02880402686705272, 0.05197539227083326, 0.037561038118456645, 0.05795101214560771, 0.05814864750831358, 0.05659286082992631, 0.09387374825535283, 0.02666838632355775, 0.061613295467630516, 0.02504596914795618, 0.10548083066579797, 0.012859237800923087, 0.05362307885661722, 0.03149644479215626, 0.12103042370008847, 0.052466469952055526, 0.08830877832107006, 0.08011714570344457, 0.0680003620143379, 0.014131003127042806, 0.00692102887232097, 0.038923337800248016, 0.027329234834460002, 0.043283734065029895, 0.040055301656285604, 0.05317282600087985, 0.07903857051485008, 0.026734235411089276, 0.028548781692440954, 0.036271321437051224, 0.020313991511601116, 0.027173004608841676, 0.02923937165178359, 0.021915954139624393, 0.050557880632338986, 0.011505054820689463, 0.0846902079760067, 0.01359277943735041, 0.04353886432645302, 0.1097618985260206, 0.11927736172031973, 0.04773054887811023, 0.05646115882442363, 0.008615213164669133, 0.014370251428185692, 0.02087202910784512, 0.09124705492849312, 0.01593968883577374, 0.02347234602747185, 0.03947070379170679, 0.03105611469025814, 0.07332684111691291, 0.01678574293281042, 0.040333686516650265, 0.062086274321641655, 0.053471255551783316, 0.07086624331291645, 0.028951343659672047, 0.0610421194634851, 0.08874786161487142, 0.09959254864483111, 0.028801249798327207, 0.0348506688380674, 0.09660835272722668, 0.029956112022421537, 0.09150573983788492, 0.03924550075504569, 0.021007975240448312, 0.02420621995453633, 0.00535643553443914, 0.012994428379310956, 0.029694554283313697, 0.08058253645656571, 0.018932834575553576, 0.041744870268889976, 0.03466912898265066, 0.021859192770094644, 0.038680047427694646, 0.010626921749433443, 0.043718305100957235, 0.050921799209449566, 0.03473161111375497, 0.051930070509232824, 0.08551012123784713, 0.09448747661325241, 0.023482762908022252, 0.04512648961897339, 0.07071677955888933, 0.014979186948508987, 0.02226744677060314, 0.007848957179850269, 0.03949522626616302, 0.14362149090776521, 0.056666298018347834, 0.006233464481474291, 0.014015822765237142, 0.024466843066376545, 0.030657712580455892, 0.04854897209893792, 0.04634028315664299, 0.014992126173550084, 0.05479596712956986, 0.04797462449078599, 0.029842518420229038, 0.03565664696056516, 0.04912631511087379, 0.10926368090534404, 0.04844897081174197, 0.030259383249006448, 0.047887930150834784, 0.020855336051975048, 0.031564519365107825, 0.05916290195478548, 0.03832249121079522, 0.023587330079246915, 0.056177338570236206, 0.05297881806449545, 0.03724184375436556, 0.019472798242443995, 0.030272333965366407, 0.0011315365226173234, 0.055037150760331464, 0.02181480180532221, 0.0563318087088485, 0.033730993032335274, 0.06961064052677925, 0.004399336992778004, 0.06899534168863489, 0.05593407118032056, 0.08321666083629094, 0.07049335001577293, 0.030349469443242398, 0.022869601455186645, 0.038418953171781, 0.0553586089142388, 0.012748018113685953, 0.0016763726284074027, 0.044009449155700785, 0.047413993686918295, 0.044866586629782, 0.06755553306110444, 0.0447733422380782, 0.012975430356398707, 0.02083171947648929, 0.10675959995076542, 0.18603789469888135, 0.0677541490163534, 0.1056431110707983, 0.0955532581335114, 0.12134074293557676, 0.11251596929205042, 0.13547981488368205, 0.11818010930813129, 0.12210598050226128, 0.11674284409250944, 0.12347015326902752, 0.17429315394932227, 0.21189205979387607, 0.1092101620029538, 0.19481850337357293, 0.14395665437463792, 0.187907884678533, 0.2290134813876883, 0.14872215027290006, 0.14313200668942544, 0.24437345233896088, 0.10449115998081623, 0.10109934400046065, 0.12255748974219446, 0.1449797647975145, 0.13002790420526458, 0.1812943242370121, 0.1728426430734896, 0.15833777946329888, 0.14004427398885452, 0.1787359429703605, 0.06517107673590222, 0.1438610619234462, 0.10460842505938585, 0.22865994713239132, 0.18607975374306404, 0.11453848737742632, 0.17841915029191202, 0.1649171570616384, 0.11142527459249382, 0.11824099031547386, 0.23051273077726367, 0.10142941298263689, 0.11524922544917754, 0.08670003964535652, 0.21170743260412447, 0.13862754759048262, 0.14935409620163903, 0.13055743950028575, 0.17464655030879284, 0.14667761482058034, 0.1468046781637015, 0.1405861279776981, 0.09853632024098789, 0.1696432760405925, 0.09279736407822178, 0.2748562900289413, 0.1903377930002828, 0.17073508922851857, 0.11978688679875867, 0.11767090598662054, 0.1527529065647433, 0.18782689386317808, 0.1733015450618921, 0.06756383745420365, 0.1856258160044109, 0.12751987023699668, 0.1776516374440924, 0.08359752144784698, 0.160196615202773, 0.1498655058563717, 0.16480719280098716, 0.1917906940704392, 0.16396310180425644, 0.09425225697698132, 0.09988623611148327, 0.18758062723903887, 0.12563560803931567, 0.10449671411826726, 0.09303858218293998, 0.16394615593937137, 0.11016018763785401, 0.14390926417564193, 0.14607170055950844, 0.1046296227122507, 0.2162800122412943, 0.11652799473414499, 0.26337033378020414, 0.1373913421505882, 0.16495661058973882, 0.22911455902841785, 0.23543574967451636, 0.1473010418516013, 0.13615398757880734, 0.14287912106562045, 0.10850879318651654, 0.1408636050238725, 0.07926314152897367, 0.1079560454273897, 0.10867994488968004, 0.10704891305536994, 0.16163488399357567, 0.16592223377477738, 0.19986766630843764, 0.12143121791943429, 0.15201891772449017, 0.13710560667659008, 0.21715486932906414, 0.2181520093713076, 0.10287508218278808, 0.11198919191355668, 0.1285478529790717, 0.13488323157352788, 0.21458254526219062, 0.19846777852264144, 0.14026193488990107, 0.14899199708334862, 0.0841118039322957, 0.2181980052902814, 0.11536069124216035, 0.10890439332973574, 0.1046765685802506, 0.14290510676801205, 0.21790347512691252, 0.1553654808911585, 0.1756133532692348, 0.14040700129924283, 0.1474395658700697, 0.11045693179532406, 0.10623752635212676, 0.14680400400632812, 0.0970104186525268, 0.10640857080298086, 0.1187735669795544, 0.17313611603552298, 0.13124675009279482, 0.14254158272618248, 0.18654553520102657, 0.1772660041047681, 0.15904181426571262, 0.12038187664603034, 0.09590070965068956, 0.14563005087116074, 0.16824122788684984, 0.08561479183094156, 0.18090766433986927, 0.1444373898688824, 0.09805743867952017, 0.15427930611035517, 0.14040052019540342, 0.0897543479297911, 0.12100087568884897, 0.09980338370247234, 0.15373811095712647, 0.14482956559908006, 0.08609692160520824, 0.13732832375793688, 0.11467637554291757, 0.13385400776901554, 0.10221683645560857, 0.21417613561835983, 0.1455960059238057, 0.16343180450700945, 0.1025898906312162, 0.14084422299938817, 0.18013831288103135, 0.13710739932233287, 0.09857427223675674, 0.11326689633630938, 0.1622457778261554, 0.12549582763665146, 0.12485370039939882, 0.10150701002848726, 0.14642941765487194, 0.13251726094993854], [0.013498767042502522, 0.0384634284062251, 0.09957637652874955, 0.009617488868834992, 0.04052379123506047, 0.05497133997719615, 0.003371646082321663, 0.006561738423882954, 0.03106469295979027, 0.02341226175157053, 0.07887768438987194, 0.02362725475142079, 0.019245038387335597, 0.07483617988445106, 0.06731039258621394, 0.04150558270574097, 0.01664775900632864, 0.009835100931776388, 0.0849212983983659, 0.07259783950904686, 0.05836641183122993, 0.025664939462477644, 0.05267973733885635, 0.01821276363766482, 0.04416347879375662, 0.04826992457251876, 0.04696951330369038, 0.0396771491655419, 0.03566408184387031, 0.01625546644772253, 0.06557033111852023, 0.04765412011634439, 0.027232089140001806, 0.0393682242100758, 0.05105122976425675, 0.02355500308406209, 0.03810794062672123, 0.07628551098488032, 0.04990230855201522, 0.03871250274260679, 0.01143337388883435, 0.053058180943011284, 0.015538909938186409, 0.02569364286178062, 0.022579635260626677, 0.06605429950380518, 0.027777321576591463, 0.053801546699457595, 0.04108143429602346, 0.058598651385475556, 0.039863714557741924, 0.03380223920929336, 0.021378279160407763, 0.01567545744981016, 0.04886502933297907, 0.10327035290819984, 0.04759771689291924, 0.04528502385402399, 0.02909299523209132, 0.07638020711320062, 0.02498434503532706, 0.019207456028990207, 0.026425996104315407, 0.038667069898257335, 0.007138323966383695, 0.012690220610238613, 0.04617292358870468, 0.003241895207001137, 0.03702885215921748, 0.009404439817092592, 0.037448526615457195, 0.022426222323349888, 0.034662054160669926, 0.034232110295805245, 0.026971073408100395, 0.033313103560959144, 0.05899769892435401, 0.006951421016692034, 0.0605698109364077, 0.032524936982700904, 0.03164662483839258, 0.007810592454212208, 0.02314485110072119, 0.03723792904507249, 0.015466785632945118, 0.025332078089817398, 0.08385436774622049, 0.04243297427291832, 0.0355205093059809, 0.06924785959023623, 0.009022273025625657, 0.04190253882458614, 0.05850439958815133, 0.06682961112669399, 0.019540369112585342, 0.04013413210369406, 0.030709132401933594, 0.009026159964231475, 0.059444255405856725, 0.11515409265074039, 0.0437921598072975, 0.052750282545363715, 0.06828549227887584, 0.014991892516733179, 0.0782666986267413, 0.037071163195275494, 0.034654366468349775, 0.03510615916081494, 0.029715208013752298, 0.03950083019932912, 0.013619624115827103, 0.047522739867769906, 0.02499918032798075, 0.043051601763093666, 0.06516143168893553, 0.019484783688019362, 0.04876159597188235, 0.028204735436086214, 0.06632080617090387, 0.028445177876781073, 0.05420473877400641, 0.016158881912668868, 0.058705015032882654, 0.06632591597735882, 0.013843959557913966, 0.060743594151591106, 0.01760860371793951, 0.03453488356523937, 0.04280321307540421, 0.10456986019327756, 0.010367793466655478, 0.06866201683278046, 0.0921467102823719, 0.09064169225072669, 0.08937161040282057, 0.023096030232526606, 0.06464423807037455, 0.017404280407654665, 0.005106899151278119, 0.021429735371061874, 0.04525813033744212, 0.02915349894113118, 0.011279250405007794, 0.01825766788134652, 0.05624947340918645, 0.03682183604987879, 0.02041839588914187, 0.12172183337351009, 0.03808751672265991, 0.024151034810910785, 0.023204108001664284, 0.03326732597704376, 0.05691431515339402, 0.08281185231622189, 0.03302196333665521, 0.01630157344944535, 0.011668295708424863, 0.04159480896628192, 0.06041768502684371, 0.05878085007650718, 0.03130056951645642, 0.022987647943439025, 0.017305727026635603, 0.03010503759968185, 0.06295740439165985, 0.029309407409821308, 0.03599987733328054, 0.02656825480141467, 0.036535070187622504, 0.02582531613898614, 0.02129826319193648, 0.044511884090400515, 0.016520069386329383, 0.06999580655246973, 0.031919679642024065, 0.04988713618067484, 0.03431893870114319, 0.038075642359833566, 0.04946125258180884, 0.07983396896311352, 0.12181180273933757, 0.048948559729803, 0.0469773542135954, 0.052884849719703204, 0.03582936914397344, 0.056119594692943565, 0.028146453382026766, 0.013004273566747866, 0.015098446728511444, 0.03550852769084516, 0.02016792727273799, 0.049458973470234105, 0.032525155317759326, 0.02523975683406236, 0.02499079358042969, 0.018528585299669255, 0.0016079484081391487, 0.027257973335743434, 0.05570834720387094, 0.0632172805677739, 0.06716191708560913, 0.04925047498076193, 0.020205260652507988, 0.01899011880009165, 0.036256804070886106, 0.06377189758143599, 0.021742845081814358, 0.04578993325271914, 0.046062656723323374, 0.019083658135646296, 0.05397051888247652, 0.06263065640063536, 0.029307651153254895, 0.016459843384162072, 0.04289417069465403, 0.04129634877186149, 0.03217137208388698, 0.05442819129976054, 0.057406427053314064, 0.013590050249120161, 0.08910210833193795, 0.057117926001909285, 0.032738840222478874, 0.06858130946995751, 0.02781737839893228, 0.08466897201874564, 0.04396981942737776, 0.025926462727628892, 0.03372277673934737, 0.02046202459642964, 0.08858281563246444, 0.06445565786693366, 0.0430518047763936, 0.05619433806127599, 0.04347296161276679, 0.06611704210480375, 0.023022661992018262, 0.03583615668298256, 0.006139415218645046, 0.031359454864756234, 0.009263323548610413, 0.06538260893355455, 0.006003993856269987, 0.04913469611276542, 0.02768053594345768, 0.07786518428474665, 0.09250170776560422, 0.039522587096378695, 0.0604660251748658, 0.03472906770184636, 0.017028824546404423, 0.05693666193814528, 0.032357952797845486, 0.05672099669614146, 0.045657001676098, 0.02031717269170669, 0.030382487832778887, 0.02360362859983598, 0.06631473109366433, 0.0047449891609440175, 0.055671509866031914, 0.019839139572615107, 0.01723402502736257, 0.0820499855364042, 0.01682543777860701, 0.05231601411416646, 0.05631551401869905, 0.023655282078130592, 0.029812087492656805, 0.04147186717619339, 0.02022432666572352, 0.08968870185555951, 0.023133664301806883, 0.026325481538210186, 0.03130379283139783, 0.03791154632645269, 0.047343417836893956, 0.059177702773482575, 0.04198285548256771, 0.05386570656311609, 0.10332053166724021, 0.06980088314101582, 0.03660049792679568, 0.05499403533195296, 0.006549276567379674, 0.08444350468175066, 0.057922958005820556, 0.036993661910415664, 0.06726830371565397, 0.011172051721763228, 0.06842760158882988, 0.02320445274123021, 0.03564203383340951, 0.05180330977084176, 0.11039938327045211, 0.03146808996285883, 0.0378213816082045, 0.020492654706862186, 0.041169116889396985, 0.04774407799085302, 0.04763786373059115, 0.040021701039926666, 0.08890456489978299, 0.0285618013567141, 0.05274380910240355, 0.053939484660663915, 0.035790409742584156, 0.019028568753011284, 0.04102775068472951, 0.02965116497850226, 0.02802163467652375, 0.04328107957037226, 0.033737769080025536, 0.07117520657277877, 0.08881121708620941, 0.00746289722531313, 0.04952171607123268, 0.07233998197461329, 0.024700854198947072, 0.05186567315831781, 0.013916932305531397, 0.02707455273447258, 0.06189385218726051, 0.18341807318070244, 0.022375085954404166, 0.027278902857834776, 0.04097151217020808, 0.09709348556615653, 0.029862419469282035, 0.020516608361034624, 0.022292691282927993, 0.032059695616725, 0.034160220604990764, 0.0547067370385893, 0.08444280754173956, 0.08066583319657272, 0.0897329051287905, 0.019319348915990804, 0.022878143335542372, 0.021816314828972665, 0.037032437450703115, 0.05525601441941916, 0.026843994743220752, 0.026554237307620146, 0.023790789625397133, 0.06912068133392642, 0.01116585790089542, 0.020724683586928635, 0.038362542287476604, 0.025920944979354262, 0.030156836634682074, 0.08777866846010571, 0.19548775778422434, 0.08630332101376788, 0.19089478488651015, 0.07458576106376226, 0.25159810579592184, 0.1474525587212655, 0.14625387626790232, 0.0996651201538982, 0.15509712029128306, 0.11132559123178644, 0.1409338706082875, 0.12869302664072285, 0.1528829116854937, 0.18947850281913436, 0.12277583246149364, 0.1269326791647942, 0.1434368943615306, 0.11811002758481812, 0.18824709308964593, 0.2266557538701642, 0.2196990320038411, 0.11246123997073983, 0.17735909910932665, 0.11681028281248386, 0.2127733213766929, 0.1698841340839863, 0.1436667513823317, 0.11843373803722283, 0.21930547731537975, 0.1388211380089483, 0.1459810263927906, 0.11767726451639207, 0.17558056470607558, 0.1471946628824357, 0.11974790058429204, 0.146513472821924, 0.0841012089363029, 0.12430056959630982, 0.21912117188255634, 0.10158511269236765, 0.11601968007462642, 0.17818670389392685, 0.1541701385811452, 0.10967748329764414, 0.17958083069853245, 0.15716302959669023, 0.1413336612524525, 0.18968654165585197, 0.10836495251785364, 0.16173613017364857, 0.18198623952846374, 0.14476119991271727, 0.07386596783274606, 0.1666486689880971, 0.18035059584484947, 0.1514891985683672, 0.11300027475602205, 0.10508922950154352, 0.15230180335141, 0.23991820672827385, 0.11929646029227203, 0.1438567258657948, 0.10568840984976101, 0.2047435554765886, 0.05688130059429715, 0.13174130581319332, 0.10816926301847543, 0.1278861215518367, 0.08473786630577619, 0.20112624151572106, 0.19304963699992628, 0.11914906497564047, 0.106804768494781, 0.12628681341847106, 0.14097009124534746, 0.13927663856696698, 0.19685524005082347, 0.14505831945327022, 0.19394147059609815, 0.1352230528549802, 0.14419663907779803, 0.1329412599725108, 0.19643940752552402, 0.19758936678690298, 0.12619229349037334, 0.12766844532903165, 0.13188067252837843, 0.19797280911476384, 0.11021947518231408, 0.29041406488226307, 0.08872497090769392, 0.16403028771521586, 0.10899311397224666, 0.20562795801989495, 0.1070232414490273, 0.17860802160876413, 0.1383224147702417, 0.07872993667279521, 0.15939164065545605, 0.24185853890113293, 0.14765194076443874, 0.19550959129006634, 0.14115002997700246, 0.18700909500400867, 0.17565683641981694, 0.12544372599692116, 0.1053917806054796, 0.1471266342747596, 0.13048493693913185, 0.11188070620259932, 0.17546448706378862, 0.12734292690912563, 0.15460991901495766, 0.08891149799549773, 0.19981796252391032, 0.12654241865440724, 0.13364891070992718, 0.10709755963856175, 0.2654928569832156, 0.13745702652921601, 0.14612184867503183, 0.07554031427829497, 0.14448027547088363, 0.13809168440920694, 0.10423478099607653, 0.24721873353325555, 0.1300045844888495, 0.09031833419876714, 0.14488313046674575, 0.173719001693591, 0.08832275176480894, 0.1853079661246269, 0.16302170231938362, 0.20088002085685733, 0.16039484811405982, 0.2173994812032869, 0.1859579917283789, 0.19256265022821967, 0.20769539950115068, 0.09020686840578433, 0.13101597376648458, 0.2036839486249993, 0.06165463357202469, 0.14066718008008697, 0.1352335022942674, 0.18005252635527044, 0.15527937260846938, 0.2849358927098013, 0.13857758333606107, 0.1480744535764379, 0.11038774639488229, 0.2015153528942216, 0.09963609308244721, 0.14497999462389177, 0.08669202636566856, 0.1346789006023638, 0.1842579660156081, 0.1558415126055479, 0.11240634977096513, 0.15246335597288224, 0.0875518911127602, 0.05365984724654306, 0.08684416376655141, 0.10302144328072187, 0.1278149060183956, 0.08197546050313019, 0.13741529005910122, 0.09121251202398732, 0.1484616803786447, 0.18439799156640807, 0.10536324383030016, 0.09342798467485175, 0.22423031950189223, 0.14261463687064188, 0.14677139930427074, 0.13968401348158238], [0.046535788794919375, 0.06148064734354135, 0.041378638106248075, 0.0677881556593122, 0.03505876513137933, 0.045025687769896565, 0.051505615664345604, 0.031325448221797426, 0.0212924677367893, 0.028745202805786848, 0.025086575638382666, 0.043206209797532334, 0.024628652327303446, 0.029887709946882342, 0.012371515584809166, 0.019854547515992197, 0.009786820155568421, 0.054190527843011004, 0.02070831420320657, 0.05381959573095364, 0.0665762045631005, 0.06420387157930002, 0.006054476656455306, 0.03351040567541796, 0.03650519658901519, 0.024141345713888446, 0.050590343608130375, 0.00023094748411817674, 0.01828129211771152, 0.050444484297786994, 0.035580536125287894, 0.0532135320827365, 0.06188861214585843, 0.019687618872511293, 0.03001157487291963, 0.006779523335412266, 0.005465991374465727, 0.048175898771132195, 0.01148056873540965, 0.02859105059366313, 0.0218577889139734, 0.04785031523375262, 0.007594902793155804, 0.008497177210125712, 0.016777474928887624, 0.043040776940723585, 0.028625970796471643, 0.043856220079525825, 0.036929065376640334, 0.06286269677202068, 0.06755352591074283, 0.02478437885011156, 0.0168009344563489, 0.031022071658122926, 0.011917336528459865, 0.03444668386251696, 0.04865510208952812, 0.028950771008948648, 0.08791441157940896, 0.03634433727711439, 0.014117529555674524, 0.029127844571766835, 0.027480180968620607, 0.01723278971058467, 0.05099703287405353, 0.029558659861645395, 0.0345970094654589, 0.06926760933692418, 0.09310818893174011, 0.05845053211575555, 0.04009338388700159, 0.05398278778058387, 0.06021158056213491, 0.04627012099409777, 0.0564205791470745, 0.03140064549722499, 0.08409082078404966, 0.029593842449567975, 0.02295259942090319, 0.037758332572036216, 0.09145356158936217, 0.03156856430934803, 0.013499406725919295, 0.07719891761699993, 0.019150912994518876, 0.0358334255795325, 0.060756180976187034, 0.05280633336834369, 0.02811130335284097, 0.08379284322502152, 0.061012571452245604, 0.03353264520785982, 0.03109045075102439, 0.01961673275687762, 0.021885283809575825, 0.03438134039301546, 0.013235155230147705, 0.01232106390694577, 0.02054322417074394, 0.027471033878804698, 0.03527832210003849, 0.004329697206436146, 0.08413307819395296, 0.04792155374983146, 0.014544805519342905, 0.026901443676662543, 0.05889952092641785, 0.06100286894868459, 0.04161392669043234, 0.05946355316066935, 0.0497398519467923, 0.055175061908460436, 0.057518272059819395, 0.03965685549642771, 0.0402008238879423, 0.043833804346861384, 0.03213207560381101, 0.035607349202637716, 0.018885559289746227, 0.02685478126119462, 0.023115213074150587, 0.0484679468096264, 0.03447716650102408, 0.026782956687853705, 0.03709432203322649, 0.03869468353748803, 0.035816261379589, 0.04677118463141303, 0.045634076494963906, 0.05781117045590955, 0.044765026353660135, 0.033763383229773854, 0.013605014819111074, 0.053525816333750566, 0.02799246204836715, 0.0573387814896001, 0.06564753745952923, 0.06816894732295506, 0.04842834772482034, 0.011616334837350634, 0.051092054589741656, 0.044699250044481414, 0.07316868992582445, 0.024606592825523788, 0.008021298234516215, 0.06980905729916788, 0.029158122281754212, 0.027369368265593247, 0.043210565007381865, 0.10052408857811844, 0.0397458749132291, 0.06796150603481839, 0.07060653950658537, 0.048712646783960444, 0.06773551009715566, 0.020473040940780795, 0.04703514788660312, 0.06797451420777267, 0.06688370459502743, 0.01901087978283965, 0.029627600113951394, 0.059475071292610905, 0.04935302734074574, 0.042410232952886054, 0.02688796819007445, 0.024515347923302365, 0.017956917084032492, 0.04120231530959568, 0.023740616612016194, 0.029081729909164772, 0.061568900672418464, 0.034311423378606, 0.032547582541742635, 0.041084322447498, 0.009498976024558708, 0.03665819200837324, 0.02610777467188816, 0.01397386604484411, 0.050648259855205977, 0.05592305866640903, 0.018023536089927922, 0.0910042203782547, 0.024267346110014666, 0.014237615753025299, 0.020641356203404647, 0.03399336282464285, 0.05095472949887476, 0.02772084940525313, 0.02030095269512986, 0.07743996718237478, 0.01783121737741655, 0.016459377985748074, 0.01512305826068886, 0.02426573732537368, 0.022645363689310128, 0.02825923684623934, 0.07431845000434308, 0.015405546479497947, 0.03326673608934207, 0.01582467797092132, 0.029519365296789238, 0.0465179504376025, 0.03862914471556583, 0.03413641442274375, 0.0025639049999881536, 0.02465775409232705, 0.029997346704945933, 0.08902258840539763, 0.06768159282904479, 0.016538683407669588, 0.022535717355147488, 0.026629068776063865, 0.03245878145999966, 0.06979277793077693, 0.013980701464348504, 0.018740157716937603, 0.028308228168997075, 0.10315528650197292, 0.02566689298668456, 0.03190246564636548, 0.08227933693917529, 0.05840580407229643, 0.029600888543251543, 0.07292456834787324, 0.032889422464875445, 0.04957784733344471, 0.052054670879677425, 0.01672232617443848, 0.01829634766064344, 0.02104924248170949, 0.044817913233512835, 0.09545279336312125, 0.026504280714077816, 0.0420799647878495, 0.03886830587420733, 0.032710322599497535, 0.07084185873428661, 0.06370631279423833, 0.026510003390872193, 0.01239440341915695, 0.029574537033876105, 0.09292149330459296, 0.08221245746338561, 0.046554883536432064, 0.07360781918490127, 0.012526018282158241, 0.035487827995131095, 0.025915023119699572, 0.017198386617125045, 0.034210016320068995, 0.014636150970604393, 0.04961993620400468, 0.07369924411778489, 0.016235101915475343, 0.0069949668907229945, 0.010799954198451053, 0.015866795569778453, 0.027244901960535396, 0.02077272113022064, 0.0026476901210468985, 0.04878247569825861, 0.03862937071150349, 0.010380402316279229, 0.05516509127412593, 0.05506968268403604, 0.02801980755682434, 0.054488310049618446, 0.04486215098070041, 0.00956320962417991, 0.09212928178209452, 0.06903655721896118, 0.017900446827913967, 0.03145178378139052, 0.0365604660023124, 0.0036080182021138293, 0.011217296874571231, 0.05888631740104287, 0.01860797307604263, 0.06325720140950815, 0.0296147509042414, 0.017246483532231183, 0.07575448181840681, 0.06727019595282693, 0.024980010892895442, 0.0486475637843532, 0.045156539417803294, 0.015088535465991065, 0.029675729587794315, 0.059721318764552, 0.03365233112427016, 0.021784079764338753, 0.027466845293078693, 0.029016099156691667, 0.023759069754892302, 0.020625823770739862, 0.06385765346367994, 0.03412690344116381, 0.003761882891863465, 0.05751828738157788, 0.01807996421121061, 0.058512343919926116, 0.15305736522761085, 0.03652478928767866, 0.054419113157857815, 0.038814476706207766, 0.05690429855378405, 0.06523340564942168, 0.03453098417770478, 0.060795814534949685, 0.01380454337659983, 0.04204731412051667, 0.034634252829897794, 0.003552940071395208, 0.056204515539350054, 0.07481066149569328, 0.04763167757060259, 0.03555096513141067, 0.018178552066186265, 0.0096481840967411, 0.041009061969816685, 0.05668933811267057, 0.05281548811903885, 0.035958366859103405, 0.049061959894794616, 0.03901592718677656, 0.03551419291104521, 0.04586140542561489, 0.015882497499396485, 0.010022380700965804, 0.06435608175853569, 0.051936440530323216, 0.08787374763238816, 0.031610714466941935, 0.07197894771853763, 0.023374518514761043, 0.02440212204331352, 0.04600934849511232, 0.043550842111149145, 0.029802662695968346, 0.027214900042200764, 0.020655519253904783, 0.02831876187795593, 0.02992047744262363, 0.05652988840255046, 0.06317904511947306, 0.031581790817360726, 0.07171118466724312, 0.057127103735242164, 0.06734173324319624, 0.0858306217818491, 0.05830810870975257, 0.026601326817105857, 0.1866917967075302, 0.19316913139435554, 0.11583848495877559, 0.28512128598747716, 0.08252774094862324, 0.27125500262744967, 0.17298104451789012, 0.19640257401812464, 0.09208540792667097, 0.10692990895721222, 0.13065306259499443, 0.20217852456675423, 0.12716275835109334, 0.11391335963121346, 0.16574477716799707, 0.08781880380645876, 0.09282219298784772, 0.18165942641996569, 0.12186707598307442, 0.10988856350342113, 0.12698174709634436, 0.14194408011051918, 0.1175926501051553, 0.08894781056310862, 0.1497697908311121, 0.08878779777836415, 0.1524249749678758, 0.15156197692117385, 0.12592665250262908, 0.16084628840607984, 0.1258299032586717, 0.12676329712473577, 0.14795655264489113, 0.10380752609982606, 0.11893788517843332, 0.0614936325338579, 0.13221218941673157, 0.1454887995796819, 0.08756889826467923, 0.14670142483326698, 0.1106721718585299, 0.20508135428592084, 0.09295848769045646, 0.10007752826617611, 0.18406105077555104, 0.09171239205545957, 0.09337340857112601, 0.18556045338271127, 0.06852486411169653, 0.176642163386268, 0.15677201832013746, 0.09773323793084392, 0.12032545427040708, 0.11819731564291062, 0.23565212354785015, 0.13277912512421608, 0.12412466814801579, 0.14381966253201808, 0.17873246493118425, 0.14656844729137036, 0.17879762837002355, 0.17687603470779237, 0.1719208247959614, 0.08471373453616135, 0.08431100977524635, 0.12488534749155084, 0.1703176938838536, 0.1452045349944984, 0.19475381490924668, 0.10270400708841701, 0.13043540169394788, 0.14179130685665917, 0.12021630972383485, 0.21066936814496595, 0.1805795948471754, 0.16814388875519076, 0.20983273884461773, 0.13407942147985583, 0.10050082248785805, 0.15778949033589135, 0.19272522940751047, 0.10709140029165054, 0.11731896519420609, 0.13289797600478898, 0.09191073987993503, 0.08228414797133977, 0.21212061446520591, 0.16870420546300952, 0.09047086230449139, 0.15717692643163667, 0.1286890123399996, 0.12404517120411321, 0.08420024112227463, 0.15335220182614942, 0.1166519707429313, 0.18193771551933982, 0.10030051347829642, 0.22098121804095086, 0.09926699958140812, 0.1459054135146641, 0.13062801151987047, 0.18772068343335585, 0.2072917477738473, 0.1724630771505256, 0.11869511191522884, 0.2584307827055454, 0.18270692908235137, 0.2199902526673771, 0.16094230986650915, 0.16618166178945573, 0.11515698080221493, 0.08937170999425073, 0.21002191659663955, 0.10178765101778893, 0.2136423255527212, 0.1659129794326521, 0.21008505756335877, 0.14115851823120348, 0.09018157984340384, 0.24160833458506295, 0.22726632594581575, 0.11466606399945675, 0.15250204341305842, 0.1020178757607937, 0.2755342165548956, 0.25222836633122736, 0.07946475288800656, 0.2693300994653856, 0.17050446611979317, 0.15450758499003228, 0.2329292632038555, 0.20430199771879182, 0.19146003520056126, 0.11692944778910569, 0.18051063161223166, 0.10639344822735557, 0.19189304341712307, 0.13753628598586207, 0.1058543521550394, 0.17040263771289782, 0.1682369071509569, 0.13629514693973527, 0.12619879757685046, 0.08606967951862082, 0.18349138779505608, 0.23702443216837224, 0.1398097285099568, 0.14343910069475252, 0.13380779734542295, 0.14911677748445543, 0.17890252112861604, 0.18920421269872498, 0.09548751246784964, 0.19396756355079914, 0.13409570850912603, 0.14885282955102383, 0.10315593767670855, 0.14838355473212658, 0.13411976366994843, 0.12528687715530396, 0.12978989600894913, 0.1371633697060808, 0.29881575114784703, 0.1798830677064196, 0.06970526770718637, 0.09428612572411377, 0.1881087988975548, 0.2297232005625002, 0.1379153003255206, 0.22352501299352417, 0.1850989926606417, 0.1966441828276842, 0.14414615388358795, 0.09952744649302575, 0.15974059370496582, 0.13384867579706256], [0.045095202588145776, 0.046540910092693184, 0.05053440386789942, 0.022451415124739853, 0.0507516204379499, 0.028846837775481325, 0.10079484703319688, 0.04565958722284244, 0.028815127481075547, 0.073980750786441, 0.005655510514418805, 0.020064457522464857, 0.10033811307362012, 0.04732073397345601, 0.012203272142928216, 0.08463106598825225, 0.01739132394563527, 0.06615279542822992, 0.037774339979214054, 0.03891583013859007, 0.022935368188266313, 0.02985036507579348, 0.0554112812894727, 0.015048026651774925, 0.04508156622309358, 0.0412292892654096, 0.03866674048044989, 0.04094051242235207, 0.04831124735515445, 0.039679412955358144, 0.09365784935653211, 0.030887759208018263, 0.04447292851945085, 0.05922861697693026, 0.031151013831878384, 0.05154921372811641, 0.04590380839222381, 0.08011926776699482, 0.07402840911621049, 0.020956011496544368, 0.03493746276944876, 0.05284810814285471, 0.03213485267253653, 0.015382161645609287, 0.04372862047485767, 0.01632773918249915, 0.05566515516670001, 0.03135632539558555, 0.05784886198178415, 0.0235958106725687, 0.03692900792004601, 0.06908673597800155, 0.047452868818635904, 0.05386418970902601, 0.022125864146097053, 0.04447852862217734, 0.04241139740653096, 0.010157091516791093, 0.03985043442357452, 0.014625060890290528, 0.04798828000803629, 0.03377547975809824, 0.03815125523796005, 0.08069719683619277, 0.0052806512441396, 0.06070795191091396, 0.08892911801775617, 0.033879334467553326, 0.05899399488924011, 0.03962523521735303, 0.034519760989614075, 0.03744099214072189, 0.06490476925166384, 0.02500917969061242, 0.06973215739332861, 0.030661912657500758, 0.018035092526265693, 0.025434641941120068, 0.04656866928862949, 0.06483515484198447, 0.033849169755534786, 0.06459972836197385, 0.02849856462900437, 0.027688959080185142, 0.06174628450084598, 0.17233602912916293, 0.02183058704700201, 0.022783805353326664, 0.012048407469034917, 0.04986284353259591, 0.07070250734085999, 0.016485583938417897, 0.021114771727532632, 0.025590136722331087, 0.023940613440748666, 0.05597943890719645, 0.10661735274498502, 0.05962510578214161, 0.03262911344908419, 0.03165722941048443, 0.02517717894196751, 0.02899925862889617, 0.03466156769483801, 0.07192853913311997, 0.045604176083279234, 0.015398622959882263, 0.026544979135055217, 0.035316205147894165, 0.034723808508246176, 0.04329177798823484, 0.02058566735696889, 0.026143219644924807, 0.13875419724612467, 0.008144209859892726, 0.027810071835354454, 0.04284489974980393, 0.06718512188883559, 0.03151236792966243, 0.08517321109050706, 0.03316283541461153, 0.03642595628456723, 0.05313773917394781, 0.028892054199992172, 0.04215195023965451, 0.09562025252248972, 0.02958363432797694, 0.041741583751694816, 0.04967306440155353, 0.044363217067814646, 0.06544897513043496, 0.026545408144292813, 0.05426362795274585, 0.05269407850479888, 0.07021670034455677, 0.011572642927809108, 0.014157029049050425, 0.044393531166978424, 0.025303223388149373, 0.03074155898854858, 0.022734204990669124, 0.02167481455891844, 0.06656110497011293, 0.0068491856255869, 0.041460984897228985, 0.061932784775572444, 0.045182276141619494, 0.03510779475853328, 0.05448326919107668, 0.03916545222783762, 0.04518390790889821, 0.00310202143737115, 0.154758601359302, 0.03492625490311654, 0.022519713778409268, 0.025263187633226478, 0.0156389006916734, 0.061605669062344305, 0.011494989382974323, 0.009457605361427751, 0.01214233655182104, 0.0027191780945060836, 0.020769064975602013, 0.025373550259598324, 0.0035795410381509896, 0.017742132843141595, 0.03048189540183352, 0.090470755052182, 0.027736215213794383, 0.017937397163721825, 0.07300126140997296, 0.0723736668606439, 0.011957738090366607, 0.01705984153123873, 0.017169089499680747, 0.019824285127763307, 0.029771461850032214, 0.03746490940571793, 0.0517929905665017, 0.026264374534929955, 0.022067825324953567, 0.02371320407086563, 0.027878533282707778, 0.11211993247871438, 0.031855234410613775, 0.020221032487649112, 0.031098609587417978, 0.008560577689129259, 0.029036082560196522, 0.020569190720937425, 0.022611347470252265, 0.029889109972563964, 0.06516882443740483, 0.05672496503158923, 0.0020136774307297125, 0.013262599372425148, 0.013266602181829514, 0.025700750242498134, 0.04816270673707609, 0.057353869591268807, 0.04444874695412094, 0.03768626285055953, 0.03179607710110084, 0.035350495243384954, 0.021145748492750912, 0.0788385526186997, 0.028728515495576208, 0.041923525803271806, 0.0341087011920829, 0.05036894802845294, 0.12508436181252042, 0.04782203126758818, 0.021193205724440275, 0.026197073710781914, 0.032510676255990426, 0.053152804292978785, 0.05046202005037377, 0.04520697098585867, 0.0526714597588345, 0.039517657320585944, 0.034423540346324444, 0.05137422775489189, 0.09827175943721687, 0.049115804384552667, 0.037107330206180775, 0.01716137116384362, 0.023875319766962243, 0.005591950114561065, 0.0367126991641858, 0.04996577893654185, 0.10375881822960031, 0.03875940647577086, 0.015967321627202536, 0.02077896474680353, 0.027155518651969975, 0.045573938592907884, 0.04551495365317791, 0.057938498099364584, 0.022075472797657696, 0.037801513117888284, 0.10666324141164941, 0.025263202954984965, 0.06577384237560534, 0.07000978765708786, 0.09804426196722255, 0.06249408207593426, 0.03838316920483786, 0.030471920937059388, 0.027453597717648073, 0.097419586212885, 0.054692591225067456, 0.05616866262449373, 0.023862878499071927, 0.06237385223709768, 0.04518054861335024, 0.05386539246706713, 0.01931811168399309, 0.004941640579472146, 0.01294679877783863, 0.030506297217441664, 0.04468165300486069, 0.03468593312126975, 0.050378681175530925, 0.037071986739794095, 0.052321618047332576, 0.03477116040284595, 0.0360690972076789, 0.0646866640196212, 0.06587854361221676, 0.02877747425959716, 0.06858271907173819, 0.052818495014141646, 0.04876167258067478, 0.05782499068206357, 0.019866695755251476, 0.032781829246349876, 0.042598483738519495, 0.04160426632170716, 0.07154402428216512, 0.06656103602219975, 0.01700650074429089, 0.06228564104305641, 0.03863879359297214, 0.05563412094488741, 0.017540335707787066, 0.09521349047821376, 0.027865220589803594, 0.022222044569770658, 0.042039545988964463, 0.026239302392388066, 0.03886907196213161, 0.06813176141511049, 0.03471635830318255, 0.04677264402890879, 0.03031234865287139, 0.007088990776889748, 0.04691572244008703, 0.03824376418525654, 0.06392253344998726, 0.05902146680220481, 0.03215609246023721, 0.04145956380412944, 0.03433878420882168, 0.05924070967481502, 0.10152844516860862, 0.049564865973567775, 0.03690484933735382, 0.06608940931337495, 0.044227902957748984, 0.015671981325853738, 0.004633152772927838, 0.0680546623264109, 0.02539443764685383, 0.0576596612471246, 0.03642984801122258, 0.03294590612753265, 0.039487385356258, 0.024374171325396148, 0.028062013255792762, 0.01646690479960413, 0.007845736737738574, 0.04992708383548645, 0.017763393698260188, 0.04566141051210223, 0.036936496429505854, 0.04905006254933054, 0.07670325106911122, 0.006786113606780888, 0.03143022032154184, 0.029082917345447407, 0.01058315323109949, 0.06582870193186306, 0.05414579213867265, 0.037049337350312746, 0.033118379332365534, 0.047454232455141125, 0.008517988946198696, 0.025162776488991036, 0.05053981627908446, 0.054662564408875285, 0.06688514484032508, 0.07901430084940889, 0.015910617714267106, 0.006017942402151324, 0.07190479806834651, 0.06943539025322085, 0.05985748323221361, 0.020459565454192703, 0.023485227795918624, 0.022232390587188067, 0.04299449373877818, 0.009793512891196917, 0.0626606410819917, 0.08251962041662586, 0.11199180427337847, 0.15466325405624606, 0.09751436661087698, 0.18440108656162219, 0.09123805339538282, 0.2565637191817645, 0.13318830800633277, 0.15712244225846184, 0.18310386987943805, 0.13506237357374162, 0.1197032759627027, 0.1649972898585181, 0.08934225391356215, 0.08108336643706407, 0.21692444540319905, 0.15475354517900175, 0.14833230344999224, 0.10390356288201387, 0.17398575350882547, 0.11794106689311805, 0.2746761980797014, 0.09596057942197209, 0.2048540559987868, 0.14241808935278846, 0.16892053337106783, 0.10718955913738859, 0.11829120737891044, 0.1602807469786175, 0.21858572238875976, 0.26879821994131614, 0.12914996744403917, 0.11506180969938157, 0.27850565710856073, 0.15353644597193888, 0.14523012233116936, 0.09932732134456597, 0.21873936898285345, 0.1726207686888595, 0.111741301183018, 0.09494318401501065, 0.2666890573117041, 0.11084158454210528, 0.1324942170251762, 0.10540883372267408, 0.23482525420765724, 0.1020313359256233, 0.1350380119777495, 0.13669594881996033, 0.08569244250294664, 0.10549173975783972, 0.1748908251043289, 0.11454881424264562, 0.4007522377275652, 0.11150617347729784, 0.09658613617742255, 0.11071714121968516, 0.1608368348810942, 0.1117745723815695, 0.06550105378752755, 0.16964480821644107, 0.13919233825177918, 0.16156667152479773, 0.18600254740205505, 0.11462700883707694, 0.15302564918754563, 0.15041361112267743, 0.1488213433373359, 0.1441081712443021, 0.17215189223568286, 0.1555419262618788, 0.1618737655301248, 0.22521203053334068, 0.3111297565121805, 0.1436317258424336, 0.08354338967511732, 0.13798587234510531, 0.12773592235340228, 0.16148474608217517, 0.13447415594372059, 0.13175151010434474, 0.1346405502408743, 0.22172626919083058, 0.15663450553772912, 0.1293829041382959, 0.24332633272053736, 0.136912445267362, 0.15178084824114077, 0.06106452370483068, 0.2575090257150512, 0.15308238565921783, 0.21187172782036567, 0.13818533099707098, 0.1476502706927638, 0.1804967500990437, 0.10670598911782427, 0.13881298683343396, 0.26404323476937513, 0.09565405998258822, 0.17392201499352533, 0.16375420494906365, 0.11416955475485134, 0.18696228703183515, 0.1375883186776792, 0.2218372140440249, 0.21026033848043413, 0.1883970471399446, 0.14536524491925396, 0.11857333457878522, 0.09921549549025875, 0.09420981570597618, 0.17462130005080856, 0.2537859916206329, 0.267183214666382, 0.09727989007989246, 0.09214364593067477, 0.07566285004178364, 0.16934439449781374, 0.12845006951641652, 0.16577992528196306, 0.11339582127308655, 0.15149917303314134, 0.12425841943871592, 0.1680753851730016, 0.19896734445806474, 0.14657829918207663, 0.20066076649292824, 0.16517883737481412, 0.1736463918801277, 0.1680612125464024, 0.22427159631925248, 0.2219237513359516, 0.0770984375248513, 0.1515084733405421, 0.186616949917328, 0.11808641675499179, 0.0780267522279774, 0.1437333091011932, 0.08584853291751877, 0.11656823733280744, 0.07299034465705195, 0.09382308686092015, 0.11739294630505386, 0.12761381559915122, 0.21878174896682465, 0.11259951884107244, 0.1413845601341417, 0.09895677227647075, 0.08549568048047443, 0.20576337172139078, 0.10562778931231269, 0.23926078071517332, 0.1333169035253025, 0.13461879334382473, 0.08751550193635688, 0.16108132418124907, 0.13197358367183518, 0.08171817753463984, 0.13216024865546536, 0.13649498863566306, 0.21874468563304794, 0.18877154156084985, 0.1576192809208747, 0.16659940953456587, 0.1707997776928448, 0.14786325845747225, 0.26548161081248717, 0.11230817560346858, 0.11038648234980722, 0.2599072486402527, 0.15776065478642143, 0.1342931446889716, 0.0992110828238149, 0.11995547976825507, 0.11721617151652614, 0.14551204268730458], [0.027679645366245703, 0.07366595759747491, 0.04561235024143131, 0.022789485895285205, 0.013140623810731117, 0.05245309405689759, 0.02570346985462933, 0.05790052695139762, 0.027822176024558085, 0.03587968196840056, 0.061727109320101246, 0.06034266586685854, 0.03225970202155652, 0.07517027082822977, 0.038905844182497075, 0.029850918574318774, 0.06332403492002238, 0.015322528403973388, 0.031495556130164096, 0.021069306324446396, 0.01396341564794702, 0.017280145435624065, 0.0711346039127919, 0.06512035405443561, 0.010978361711867396, 0.04741549138881026, 0.008449404924777488, 0.03176878138835872, 0.03487949289621846, 0.03426567260776797, 0.03451593821087191, 0.09314171293930662, 0.03550030756741762, 0.0400377429210611, 0.058104551487392, 0.06253351262139697, 0.04090868912997746, 0.05203039355335697, 0.02846124848621267, 0.09626142981071627, 0.023945524064343304, 0.00404579172496714, 0.04563368962056214, 0.07031937910904808, 0.09289949125940762, 0.04085639979870569, 0.037378839427425016, 0.008557552599438257, 0.021169991345114766, 0.0627270034484325, 0.021818934849673705, 0.06979340612287484, 0.04795906524504385, 0.006607800896745176, 0.02774406953023807, 0.030584200698461746, 0.06750305603829122, 0.04815953130262995, 0.004447366396385816, 0.0816276795681446, 0.0480478624963472, 0.09559061258069931, 0.030960914859127615, 0.05372368535327335, 0.08175668877459343, 0.04096705353848877, 0.0609126506042817, 0.029131192375995943, 0.039641250285410115, 0.0675680356160287, 0.05612604898370563, 0.018738282716742927, 0.06997941993176937, 0.031900946877055594, 0.05162882175476802, 0.02766828236710881, 0.05545792072230289, 0.022670770995318893, 0.028985658653020382, 0.057973876039707856, 0.025561180514013095, 0.03049265319151023, 0.113776758493435, 0.030814373730531627, 0.05582989471393728, 0.008454619110712122, 0.020370423463323427, 0.056349007382748596, 0.02394805598493305, 0.02930703062203623, 0.06342322798445821, 0.04225212772707305, 0.04036133846027717, 0.007301906720855304, 0.03453747294242344, 0.0787451281963337, 0.01655051372044029, 0.01829413366654227, 0.02338639862324682, 0.03762471917716246, 0.03550409204176357, 0.07560137914673937, 0.02317074104212225, 0.024255488984166615, 0.040705702643120484, 0.04680061772946389, 0.03177726198168051, 0.02092797459373551, 0.010680871576281085, 0.03746682845596825, 0.033513496840192426, 0.05340438373687287, 0.03899021344559808, 0.08256283543643453, 0.02624493696907115, 0.028461533853964462, 0.03210673533049563, 0.05477058663663845, 0.048308324729723316, 0.053901459886542255, 0.05146323951081403, 0.01659372874024895, 0.03126672566718152, 0.055475544575000965, 0.02254534324991607, 0.02540519926697016, 0.02272847848343513, 0.048940925663637544, 0.03170531674949152, 0.03872962863815408, 0.015829504324844288, 0.051539787016208136, 0.020027298427697633, 0.03351841512466631, 0.0409913998127224, 0.008738331154980248, 0.022944446330169038, 0.04871206072669837, 0.07009471616437359, 0.030941335567002817, 0.05338709696286148, 0.053837552831898776, 0.03867337097143454, 0.07676820000333172, 0.019091857191655907, 0.03975386904071897, 0.0667121162217471, 0.0281999186582623, 0.02452967951314584, 0.05136538326980607, 0.026855897834344257, 0.05404440040189413, 0.034520806699630716, 0.043749967514867746, 0.033320592070418986, 0.05234689511839421, 0.054051157297386285, 0.0245041151591126, 0.019251057923200632, 0.011582901802725129, 0.05250633333719546, 0.01152340262647598, 0.04078678921946595, 0.0037427129779732038, 0.022831626476780064, 0.03764324701361118, 0.03811867734898002, 0.06104194326326252, 0.076918552419351, 0.08057239345244824, 0.04828680531993028, 0.04285950521608034, 0.1338093295212715, 0.028133336041543274, 0.016131534488991867, 0.04770814846720427, 0.05796127389335345, 0.011329881155923491, 0.04019815407152619, 0.007979111687745899, 0.027063699183805336, 0.04579891563363133, 0.06264636120308312, 0.05229398142546416, 0.02123314763359245, 0.006066549244532061, 0.05820116666596263, 0.03002328261162245, 0.050455002684987364, 0.05035844113257143, 0.027038860698080352, 0.08792045601313153, 0.05408417568692277, 0.027115124750942476, 0.03689191394275235, 0.024925798680933735, 0.04457598266702506, 0.040425605576245055, 0.02231904279230343, 0.04032637037697338, 0.012784656268664667, 0.050488955701791474, 0.0617415807209909, 0.011246661982318808, 0.03790807977859532, 0.020017467604409304, 0.03190932213328779, 0.040998700630640796, 0.02293388389291302, 0.024492962834154888, 0.025626709759836237, 0.0866239364709585, 0.012593474239110948, 0.02809566558308659, 0.016697506840911605, 0.03869427368044853, 0.04996746049953565, 0.025900747071230606, 0.02374638525408603, 0.008231916393513882, 0.03124846021584686, 0.06289285382315998, 0.036436719819903374, 0.03897018024637815, 0.059600253889877955, 0.06627470299962067, 0.00957009292417957, 0.03528712061984885, 0.06657757586048496, 0.02737437848061804, 0.019351919144091588, 0.003011517007009036, 0.02698522879772129, 0.015611110852220127, 0.038771005046944466, 0.0364612614465577, 0.033197799667475686, 0.023864450894536513, 0.052812259058438005, 0.040729137272724224, 0.050052821846498605, 0.013977724255152769, 0.05571701931917379, 0.029480656789195155, 0.06435065785603178, 0.04461593415227629, 0.064980719208477, 0.028420324069297606, 0.041311138099239725, 0.04747616172197366, 0.04965603809743639, 0.033643291286763646, 0.05497903916083517, 0.02968277185103826, 0.031102608566382722, 0.026688415692338062, 0.01854212015807148, 0.03369429359032262, 0.06807828081711646, 0.04459912235277795, 0.0310550517432632, 0.021425090963020924, 0.09113305338448094, 0.07481798529624939, 0.054902851716765476, 0.01480917958918238, 0.027074183097049117, 0.01293859301855968, 0.008904085768717191, 0.02121201318298136, 0.05580538373079993, 0.05490279426017115, 0.02618277851011484, 0.056003344680873625, 0.03375658802988549, 0.07460263031985491, 0.0049838079740443545, 0.019326310740002704, 0.0543963105507916, 0.03834667660656475, 0.014555823778913868, 0.09046792052686216, 0.016623066077309272, 0.061105631982847575, 0.01886482703529539, 0.04215496862607618, 0.0179977782986938, 0.049155246421334245, 0.033399644683325486, 0.03392029718886461, 0.054778431376983086, 0.022251339771995143, 0.01860198801413419, 0.03645536256954074, 0.050898180718743996, 0.0283355794231137, 0.022930241144833066, 0.02027166323856481, 0.03067893130073865, 0.055914712138473995, 0.03813663828036478, 0.03715502684034648, 0.02838280682842578, 0.04328439290064477, 0.043494818101246516, 0.042512360134071885, 0.025894082106289365, 0.03981364688145057, 0.02341378435132004, 0.006766563521758203, 0.12512021472737675, 0.013842540380034237, 0.06589238682100851, 0.06638089044680519, 0.041333109500908086, 0.04657395912574665, 0.09597273723733041, 0.017969193643019084, 0.019342180251354174, 0.03482572501525283, 0.021601570807697795, 0.03186163507522114, 0.03221678960647795, 0.016603145876058167, 0.04297906855842279, 0.02197554237359474, 0.06957831927725384, 0.030563135195763844, 0.026440888853563417, 0.029859715178909323, 0.029742917413973523, 0.016503110114905625, 0.02733813677614014, 0.05852139524875149, 0.08589060646632025, 0.06693871736887001, 0.053153850002995426, 0.015945654745484074, 0.12786266393959522, 0.020306638982747833, 0.003768930900766845, 0.05415125434557277, 0.0465729478896866, 0.03663786386530246, 0.03862221161985109, 0.029417182574228897, 0.027176314108674566, 0.0209604739587033, 0.09245810970183342, 0.03068624935563534, 0.007951523903982655, 0.006817344138624087, 0.13879381931356846, 0.14061563768454138, 0.16850922076452166, 0.20291628255959482, 0.19692530645237816, 0.15689595602452755, 0.21442526741133583, 0.18442904877085842, 0.17147842434144792, 0.17015309223244268, 0.15284002608349248, 0.12596657334436334, 0.1302905651109834, 0.14959803391848842, 0.11458390106957768, 0.1391814444814959, 0.1695446039159452, 0.11622649317066516, 0.11819224414085189, 0.08265154075718696, 0.14181943760523874, 0.22044800552389315, 0.1688695885241032, 0.12769119047950353, 0.05958227380629509, 0.08623942928088289, 0.1400638858397161, 0.19370854922359992, 0.12255386614631261, 0.18085072868533675, 0.14938929028088047, 0.24505907038767494, 0.18228777173546054, 0.08837760366018742, 0.09542768100096334, 0.2945263022857328, 0.10093857278867115, 0.11441950626190632, 0.13745825226989486, 0.17323347048894053, 0.12115079143475141, 0.11590480519038056, 0.1444665471752805, 0.15204459699171205, 0.16215875023795714, 0.20468214586857827, 0.2318493243787558, 0.07695507183070145, 0.09853693311132732, 0.20739786627311863, 0.13391103535409898, 0.12419920084216904, 0.15499896910642424, 0.14622560762349637, 0.1461952398981779, 0.1681765547442821, 0.1627553488698698, 0.17072080934960998, 0.21298011915097315, 0.1539821252827683, 0.18505123473944204, 0.1158289471641183, 0.13749350763617024, 0.25000796773500983, 0.15797525133577087, 0.16341933259560218, 0.2438451121411016, 0.11689130427135576, 0.17111295443629065, 0.17322207110062723, 0.12729611893695209, 0.15095059279232256, 0.22390641752750645, 0.12717493148821016, 0.13855893675598407, 0.12655348096403385, 0.17801533002526532, 0.13940941692600328, 0.07168008149751733, 0.12402270184529406, 0.1812397021680109, 0.13596415099117065, 0.19163496371719146, 0.11478603336839907, 0.12606112391597804, 0.1336297125465447, 0.22182192292905625, 0.20466287109640338, 0.15068566426634789, 0.07920159402513698, 0.1957161592379693, 0.15521266167202305, 0.09663108255594008, 0.14552529600839462, 0.16744515528121304, 0.19917867747285675, 0.0656798204046584, 0.15187924457413537, 0.1338807595593314, 0.12999140777655188, 0.1257993363504929, 0.1370949120891671, 0.12098466526837119, 0.15734624718466114, 0.15150905556736455, 0.1759953706735565, 0.1531008636999515, 0.12920085100396989, 0.14823456595261253, 0.20937639558988236, 0.09184681750353306, 0.192627783023542, 0.23860595940101534, 0.21226957260120302, 0.12049235418559083, 0.10979124735439978, 0.08506518503230426, 0.21632674360467544, 0.13738358934079448, 0.13004232197999954, 0.13907725652379377, 0.15441933166115515, 0.11281230742292059, 0.10803888251464214, 0.0917072439446084, 0.11527315037505281, 0.1417085540390784, 0.13840668444191256, 0.1181153212523749, 0.08780550452009325, 0.13626214387195726, 0.21883756613298772, 0.10980181936775485, 0.08638372960230035, 0.20484547581403487, 0.097830829871518, 0.16081526184514647, 0.1880328949060171, 0.11784454747553795, 0.11355741985983427, 0.2694764529024401, 0.13069329753277764, 0.1064934993102666, 0.12604289102338015, 0.16289512927253402, 0.10406464052897307, 0.11904398835594616, 0.19401475456693482, 0.09662067142104912, 0.1367893349379301, 0.14089430982787765, 0.12117109276474484, 0.103330337592671, 0.11940359768848266, 0.09483736429002979, 0.2044291529924639, 0.16175597185088744, 0.2604251547205833, 0.11885709354593871, 0.20672384679557818, 0.16823071716052873, 0.09064425864527303, 0.1982738357037306, 0.0651398586529878, 0.13029556000424972, 0.17092975217007822, 0.079513514384387, 0.1553312061174262, 0.12471915237725743, 0.13941018301392757, 0.15929404105390274, 0.08394024620253233, 0.24197478508276327, 0.07689049061868461, 0.15418965850145588, 0.15853092555076848], [0.013394233387624545, 0.023102155105481227, 0.03564906269011479, 0.09886489535171179, 0.03807502948949414, 0.054748442865187125, 0.02590122779140309, 0.04289219418780939, 0.03985899162568873, 0.029698344503319072, 0.050569394933840925, 0.038632978985626856, 0.039699423171940355, 0.03086039071692334, 0.08519251650619893, 0.04095300731639709, 0.04899503062328985, 0.03396939193349212, 0.012858911255945363, 0.014388141496437452, 0.11150808103622929, 0.010890568993354758, 0.058448793096167434, 0.04370535438459727, 0.06219793163660554, 0.06250656547866042, 0.026823747039382017, 0.01659514408768906, 0.05159988661386794, 0.07543259465526189, 0.12849814919454436, 0.049143900659175656, 0.04202253500660581, 0.033348519805698626, 0.05539023685419271, 0.004366206084077637, 0.02238252083770931, 0.08165357333998527, 0.016294220920592066, 0.03955235727311623, 0.06366654133964932, 0.06243363007782929, 0.024450483258753538, 0.03894793688349667, 0.045260635444954525, 0.046490731333652814, 0.010594238523363827, 0.03456940348710745, 0.015835396498591912, 0.025937276058680108, 0.03030188963748515, 0.06755831396026958, 0.023411941909862143, 0.04582031629979611, 0.0191981652976885, 0.052931657691876736, 0.025082316189523668, 0.0708296166492566, 0.04030040765721952, 0.071037080920031, 0.02845104227984144, 0.019814726265688098, 0.016107877693890084, 0.03672942669401246, 0.030968428266444997, 0.043608007592058955, 0.013673849734327486, 0.04668022318172359, 0.05361397773207677, 0.024007303309777094, 0.04225099008650549, 0.025866953017670783, 0.04942019026906741, 0.07213795692810128, 0.019860963502358046, 0.036170274439838626, 0.03525923118896542, 0.06807608980565302, 0.060701915138070626, 0.05236890099401917, 0.02699812971836617, 0.0287102232311642, 0.030432239497801473, 0.0011711101110596512, 0.04607715110685076, 0.05197826127010969, 0.08461622686515893, 0.034106004562589436, 0.052796094603235685, 0.036777261224004536, 0.016143631017316255, 0.02068304479302418, 0.02740996134948106, 0.07385246936352023, 0.03473620381086104, 0.015555948691232311, 0.027366221559444265, 0.048066240945650686, 0.08506529228461367, 0.05981454017361807, 0.019030485888041796, 0.03170738327166727, 0.006405842404121594, 0.024815911029074943, 0.028449033214260015, 0.041201346208371466, 0.05066658467835477, 0.032245222959787614, 0.04903711949384982, 0.06437142649965902, 0.0878428666281604, 0.009218725740098426, 0.008741264314120336, 0.03362392075359821, 0.057847624749786435, 0.056596495917127024, 0.053327487661473216, 0.023105207965859485, 0.01223413686778757, 0.0675632935317774, 0.06193440122109267, 0.033657586487430724, 0.03407796957500039, 0.04473347885293826, 0.047911789959236506, 0.04009538720692358, 0.07578946905390871, 0.07447560528112997, 0.037633349157629475, 0.07022258389981524, 0.018114233239283486, 0.032696713047522696, 0.002976151994399486, 0.03055378317742819, 0.04661713584115909, 0.06015981217065166, 0.023719748376958796, 0.09300999178160584, 0.023929487928868304, 0.04513438798547272, 0.008901090364933254, 0.03126159479330865, 0.024259097258289977, 0.07781199480016386, 0.0697717258346177, 0.04085998509019133, 0.020593634671381405, 0.01959174871444702, 0.059884123939780466, 0.039214432059276494, 0.0411313027894545, 0.05702423344876978, 0.04461279319178674, 0.032319227053273114, 0.03147997198656442, 0.017301168803486134, 0.011812323111019308, 0.05583223894298558, 0.08109882609137604, 0.09697435889393093, 0.018733257179959648, 0.03199162870465267, 0.12812697193435124, 0.006253209918917668, 0.02267216527534108, 0.08998544601302955, 0.11419287447126643, 0.07395527070207943, 0.05698992037064126, 0.03770529247459866, 0.0767790248257018, 0.03198774463887657, 0.09522378669991609, 0.005560383940446041, 0.02835893361348539, 0.06687818876197262, 0.02416175621141109, 0.03207304278358577, 0.03533762879669666, 0.0075874123684761515, 0.0778396352524719, 0.06473257566892332, 0.04091332396191936, 0.017760752610141234, 0.07227543906699266, 0.02994167892592809, 0.07843837893057255, 0.006037099388307862, 0.045223005206113866, 0.09230288496661572, 0.027586839559878555, 0.027891930245283632, 0.049269267117544535, 0.11709545904229726, 0.033485071147762, 0.022513261402867014, 0.036463054092300516, 0.054063043151531494, 0.02306307696046368, 0.025922521205258467, 0.04595150502638952, 0.04280503253422437, 0.05842541592315801, 0.01891378196887672, 0.02054535006473382, 0.07040183315233839, 0.0857678561982128, 0.06574354359820005, 0.046722346526240154, 0.02457382341456269, 0.09654128939033517, 0.03984450490304059, 0.07389512513914416, 0.05807566231176738, 0.024240902670088316, 0.06559512172374996, 0.023031395394355062, 0.03379011586789162, 0.0712534394716063, 0.044593234967079856, 0.03827797384151528, 0.06267532315706054, 0.09194028023029528, 0.0293488513618227, 0.05413174208614135, 0.04222826025779209, 0.07113448133872402, 0.08641752174064037, 0.025870339126296105, 0.026686780094619722, 0.09496960638751907, 0.0241636197202869, 0.06487382696040216, 0.025593222141446128, 0.03084355210434766, 0.026138439256277297, 0.025043073335602403, 0.06670811724278235, 0.023062375990012964, 0.0057665224003064786, 0.022174248344174797, 0.006909569633388592, 0.012105012748150096, 0.01075107778888196, 0.05355452164827336, 0.060090734022519285, 0.04499312903311464, 0.04709511724931579, 0.09726613880165162, 0.02626127953971586, 0.003939644257996171, 0.016446988428792646, 0.076050819949277, 0.022920295408356096, 0.06732520872666951, 0.05883730309564741, 0.05880362970093566, 0.04147252218136865, 0.054030518888706164, 0.02582127885562518, 0.0804269899644198, 0.11357125540774678, 0.057443942378966086, 0.03510687928346377, 0.03327327848021542, 0.03701346145281869, 0.03255991655732355, 0.03391752395057871, 0.01881629728051203, 0.048853744857854424, 0.060581949599567926, 0.031191606915766196, 0.017756707665901032, 0.025318376607291644, 0.12475729589500736, 0.09346139376922961, 0.01729750307276845, 0.016080771587909232, 0.014008417567839066, 0.024738919192684755, 0.017840793476470055, 0.060525573189220125, 0.03406647825613618, 0.034789354991047614, 0.010299026541742346, 0.01515915345085124, 0.1222319636614092, 0.020195648164278077, 0.030833186934732144, 0.005534168890482116, 0.04995060656520148, 0.08313183192043536, 0.04707272832972869, 0.0531987848901941, 0.06598208805606251, 0.030671557704467448, 0.030523279471503153, 0.08526786891443115, 0.03401007120227141, 0.022205246176810998, 0.10714048354495918, 0.07355983909820357, 0.04424078855663539, 0.03636130995507683, 0.024632716423741752, 0.046694702243492495, 0.048964827606875094, 0.13538580057361435, 0.017645770473585978, 0.01526151333124407, 0.018474669946778207, 0.10960714876531594, 0.07249200446230751, 0.023165878299022877, 0.049269772735574556, 0.04227561215239187, 0.02454442479046843, 0.022567613425874905, 0.014684086049636526, 0.013278497612073779, 0.04188269331690766, 0.019350480814013752, 0.05162083911859701, 0.008493489454380207, 0.05726762341275331, 0.010146887225639677, 0.036124144455478076, 0.03423758016358461, 0.055459774655079654, 0.056867844259907166, 0.028609400314669457, 0.07889667570951485, 0.02084223020281042, 0.08772111227435452, 0.03433415703775902, 0.06774065054712758, 0.018784824473362778, 0.048200942185376926, 0.027714084848881732, 0.02768419592851593, 0.0401870955923392, 0.0061119121833584245, 0.10564551658688054, 0.04230494948945219, 0.04659981076275149, 0.023741884487530878, 0.01766927596632271, 0.02880139727025263, 0.04174583553967457, 0.05242790125550763, 0.015539384912699463, 0.04818065234670236, 0.07724092221788822, 0.08147559579341643, 0.12235806173374578, 0.13762265473844545, 0.19066010151178608, 0.10218328180452509, 0.09831306689809408, 0.06269429532450534, 0.0925777496529683, 0.1601743833312104, 0.18144021802131208, 0.14072288999394064, 0.13838282846395047, 0.29090589332965117, 0.2992441168715877, 0.10809624717841226, 0.10424795770837415, 0.17759459453725046, 0.10730155353103915, 0.12725947695153375, 0.15403811098827472, 0.12653900956314418, 0.13553483531840388, 0.13638396717367635, 0.2690214886059684, 0.14007998900788446, 0.1413064957746575, 0.10289273284856351, 0.13404427336588984, 0.19009538745928198, 0.26201984334376555, 0.09314413377714735, 0.14521542876478166, 0.11274551221680258, 0.13598819083023456, 0.16556442474886296, 0.1801212597638369, 0.14053023420274258, 0.11647184048929524, 0.12626408358975766, 0.11341144180586261, 0.17647678032517436, 0.156201298138307, 0.193623835220933, 0.16024751408446222, 0.15854895926050602, 0.22963332312722362, 0.14859683361024628, 0.2386829818809225, 0.11858029065713768, 0.15843594596991617, 0.17987107076952535, 0.18477225616093607, 0.14412592916238692, 0.15063692575260518, 0.1416619912150406, 0.08225096870333919, 0.18183908935996795, 0.1404250196872219, 0.17425206099306384, 0.09305969556613315, 0.11972170037728165, 0.1290930930765406, 0.11890878149818991, 0.13239159188683958, 0.11871489230543376, 0.06417327785804387, 0.10821254698619728, 0.1531699648307216, 0.15223305462108505, 0.13904650575451313, 0.14128123019491473, 0.21420037464028407, 0.1199491288993628, 0.11028593330974541, 0.14020023416847954, 0.19380601092932687, 0.19023826285716028, 0.11865773448540319, 0.16450694762170315, 0.15377803945973997, 0.15226400457322598, 0.12308599081851783, 0.08623763663514007, 0.1442801426615446, 0.1489599746081137, 0.3869960258804983, 0.11857283662163443, 0.20703325438643658, 0.14579702739513692, 0.18793039234174838, 0.08394296581466353, 0.09042436076748757, 0.25807666622342607, 0.11065805285808542, 0.10212646872406045, 0.1472671960871066, 0.25890532820936174, 0.20274962779254685, 0.2084536426850865, 0.08483695977878186, 0.0943531047913336, 0.107267125539722, 0.22031338855383858, 0.08404852506975014, 0.2124344194007497, 0.18167148464389388, 0.13220943150020417, 0.14605219596095625, 0.09883795203941484, 0.23922007080287705, 0.15602128279785957, 0.20249257465043377, 0.14959881532817118, 0.21017439873708835, 0.14730638914531277, 0.13873358948096154, 0.17748838410742823, 0.14181461125131578, 0.19413378930860953, 0.16901013501469167, 0.20767451594433478, 0.16121537424623966, 0.058790472140836145, 0.21445324494233056, 0.1455625738467901, 0.16011654369292722, 0.1672858856017551, 0.10509391029876088, 0.28387332875882426, 0.12080749211412285, 0.12256742590257239, 0.10718792737010988, 0.13120967143725965, 0.16324638058581661, 0.17161445091328315, 0.16969175408444098, 0.16429000684330541, 0.1503103731140014, 0.12951186737946926, 0.09374991780327213, 0.11212157956775158, 0.10392859863537936, 0.17106272971197484, 0.17666557503323402, 0.10988368352334346, 0.1515664968399271, 0.08098404313768111, 0.2225203346461058, 0.10987881886502428, 0.20321384643114385, 0.11394820131000974, 0.16423662583674156, 0.1407437122637226, 0.14515100077034968, 0.18210447753869718, 0.06712591095316796, 0.18841848228006594, 0.13787281308924, 0.1661788119423774, 0.1173719784785663, 0.1973584985300418, 0.2264647528288826, 0.11814790297179453, 0.1834448402927768, 0.13766875790972866, 0.3193698901562922, 0.12520440012937592, 0.15589054223270188, 0.11883919007114827, 0.163292805514028, 0.13981507580366828, 0.1965331307221805, 0.1078182032271739, 0.10581885930150749, 0.1473819867016808], [0.019340966001994187, 0.053637197857061704, 0.050080772564415975, 0.041627474955373236, 0.008707695298888271, 0.022501729864386782, 0.07205254578542325, 0.07806264344722995, 0.06043612476318114, 0.11575330364247484, 0.0387582152090486, 0.024616237872490482, 0.058996588096863804, 0.02244163026672698, 0.01979729968063053, 0.03832101266110136, 0.04781486068461691, 0.018354369244808634, 0.008309218495513403, 0.05541324630499848, 0.029962196675760132, 0.04637950685836616, 0.0734332200860785, 0.03485390938998711, 0.01273916022206146, 0.03999439000542607, 0.0434846674362498, 0.034822810050700946, 0.030916257678801497, 0.06916791831533756, 0.0169564254071203, 0.02150965749376243, 0.11191747076208554, 0.027586849135977608, 0.1304915712605561, 0.018225072755388195, 0.037008240563614715, 0.11752352599174747, 0.01433922582486224, 0.07273741306797152, 0.04328512834505208, 0.02338355069138831, 0.07264562041288422, 0.0398451330951385, 0.07132598033715641, 0.08221290945526093, 0.05697372144148235, 0.07017594446698505, 0.07242531650849889, 0.07387419561705283, 0.029034669127976222, 0.05249547021042916, 0.025231437119204673, 0.04759361449208471, 0.05261073962995603, 0.020100863935846477, 0.04438822217766316, 0.03484283175860201, 0.07331575582464857, 0.01068694856874044, 0.007254879456013442, 0.024817517898496122, 0.049996801667035594, 0.028730419224068045, 0.00841469922658777, 0.052206992141662106, 0.04028955219133247, 0.04319797818278594, 0.05579998664137337, 0.05338041667616176, 0.04206288485757766, 0.01813068114701779, 0.01963732711550209, 0.020807530250280135, 0.025826130107405688, 0.03528942271406132, 0.04086415260849942, 0.062385140542661956, 0.07361174921595282, 0.002357534319725669, 0.02948239006312384, 0.08468787906871689, 0.032992112720685626, 0.02427587649905153, 0.03178741647711685, 0.05435907867767158, 0.026633523577343554, 0.010702034755189334, 0.03876155152195885, 0.020762919035229473, 0.05746854912309397, 0.01604399840993386, 0.024040463425579573, 0.06632974641698022, 0.06632885775498806, 0.02762249520709438, 0.08721966942351672, 0.04761030754795478, 0.02173973668006159, 0.05779414415179242, 0.01800600416778076, 0.04358358087859327, 0.03621306428084931, 0.039787703313894814, 0.06866800764034833, 0.034666110596229, 0.05530029047100295, 0.02151822235675589, 0.035216514126307545, 0.040016292459181244, 0.024933827282380194, 0.10648880319129075, 0.02964961173523578, 0.04719775004853164, 0.016680467130255797, 0.05330570778178592, 0.019867015596959862, 0.01596527329961499, 0.049427000790714264, 0.03607023484824646, 0.03509317397049839, 0.018344896567624905, 0.08890515478748469, 0.029427155123783216, 0.05243848092974194, 0.01863345124518439, 0.05142697290847859, 0.02598141804487715, 0.04972814995374891, 0.057658140562594905, 0.032052490559797135, 0.04172142031752775, 0.09803676962732308, 0.04359111535332857, 0.036499431777384975, 0.019796920467108008, 0.05124767769067999, 0.0641421593665596, 0.021687728886101997, 0.043730026246198726, 0.09236888344129247, 0.04502444287701961, 0.09410148321260368, 0.02617987503688182, 0.01735054317020601, 0.027083065886531147, 0.04060962372609685, 0.03387945321118159, 0.018994226946585605, 0.030996641369476437, 0.060900806884972326, 0.020524824654022535, 0.014998230936696694, 0.010066415434853445, 0.09565376120829776, 0.057265275353265394, 0.046058757335788784, 0.027273333398625258, 0.025926345899220438, 0.019970171251184037, 0.05202215427773134, 0.02650142703655987, 0.01796507592042608, 0.03374931402504444, 0.02985844921861445, 0.04214555340548677, 0.0469285850563357, 0.019595581069288236, 0.062325600189186876, 0.004080288664197489, 0.046678576092686386, 0.01922502050987415, 0.04188887181601698, 0.02278212570555268, 0.05638662229983076, 0.03850726778769205, 0.0234286502874907, 0.053033172002723145, 0.06643184295464909, 0.02305742706202211, 0.022856361540635268, 0.04381101706155366, 0.026123594387524554, 0.05180299950523242, 0.02817598607150778, 0.06368578546830723, 0.04305120339737304, 0.01214050560168201, 0.060494680693673517, 0.031296763974692554, 0.030799948294917424, 0.02054384853240223, 0.06786572972252485, 0.014950502701404115, 0.04411394354857264, 0.03543319060437141, 0.06294403615738116, 0.024345046577734814, 0.030258412232562423, 0.05117559264744482, 0.012078099121760217, 0.03930067440735237, 0.034535875649101315, 0.035239948755911285, 0.04017149804220085, 0.07664636137985414, 0.026478517177184264, 0.054989699274301536, 0.017775461498287418, 0.043929235919589, 0.039959590461465626, 0.03529393497193533, 0.061803641503736864, 0.07125869483476685, 0.09710469343248876, 0.034636194862785845, 0.0733589478618195, 0.04569963829952382, 0.05651198875819964, 0.046851880502917116, 0.07161991295194434, 0.05825377009328335, 0.05429294230716844, 0.038552493788301945, 0.06712868419145385, 0.01927359048427353, 0.03083664773693008, 0.02494585869323102, 0.021928035346190297, 0.02288742449074503, 0.07233145541601604, 0.028632852181251493, 0.0373590781894182, 0.040925508590355035, 0.02889551691740992, 0.048994191757012764, 0.03385792997094893, 0.052620350202966126, 0.009444528240560284, 0.028853194390033043, 0.018054966762241338, 0.05153864937564058, 0.05997142348919184, 0.03645830051673036, 0.03730862746916471, 0.0479708859817155, 0.0379945021573334, 0.04992736345757881, 0.035302576443721215, 0.07509351647909611, 0.04961015326121161, 0.03763081723703973, 0.0463554785106211, 0.058367825263450225, 0.0674359160926073, 0.05443212899169134, 0.06892930490956192, 0.05418709576911023, 0.05979375620823234, 0.009933825724968507, 0.04174233068742099, 0.06613657734687291, 0.06669925360549843, 0.04299713674211695, 0.03013590902781054, 0.0668608598531254, 0.029560358661617485, 0.04255154553139883, 0.030096152894980008, 0.03674936413224186, 0.051496100852326046, 0.012025696792519622, 0.07908639738396292, 0.06009940996826176, 0.05819969194670839, 0.01542703428816411, 0.02042820372979247, 0.05813611430987235, 0.04970983279147937, 0.06544299964462558, 0.021626125840890794, 0.06488991480681204, 0.04074612910288476, 0.042766057811076605, 0.011288528687380736, 0.031093712370362014, 0.039443526822592945, 0.06909340094294279, 0.09054821420220599, 0.030363337549891685, 0.043404327795630505, 0.07025852108434325, 0.0300713642049701, 0.054134415732997085, 0.037874992441145644, 0.06059790338059107, 0.03985616476124814, 0.03525823527466386, 0.03174540996100874, 0.027422320262919513, 0.07281052849946484, 0.031801954910699884, 0.06020822126658694, 0.029546848701072798, 0.011017835349775853, 0.0768380519002676, 0.03532316505668625, 0.04871606736654236, 0.0862228204946845, 0.013792491855940992, 0.01882904881401168, 0.08089991136183662, 0.03317990768400412, 0.07936284787231877, 0.029113036092190497, 0.04690088331699372, 0.036644639912992716, 0.0209074798265412, 0.0590312191014809, 0.043444777238032514, 0.008765510039313907, 0.021808554358299703, 0.02580029570737914, 0.06817245600564827, 0.031135125168328805, 0.06163338229300515, 0.05666707176715136, 0.09554704516044549, 0.059070714764417186, 0.031908243864534364, 0.031731024745010564, 0.06417763689833303, 0.0639435510721899, 0.06129990421956586, 0.05098575989024774, 0.021789566869096413, 0.04399965855202848, 0.0681027879698142, 0.09907454297307039, 0.05234578046046438, 0.0032003392463534953, 0.039119463969743064, 0.06843727727931354, 0.0338527703687789, 0.07190740276728907, 0.05216166654962206, 0.06983672073411365, 0.004033364821225405, 0.05818339342611933, 0.021177600513422684, 0.04728078248820478, 0.034832121849420576, 0.11118524392405826, 0.13526933988736523, 0.1915861485946563, 0.10516930101138931, 0.12863678046532218, 0.18063625471005518, 0.20444688026703176, 0.1667133114871479, 0.1907622976408851, 0.19415205284472437, 0.12229403210503441, 0.10602458455269376, 0.2432159700941655, 0.08379079010938445, 0.12217099072351573, 0.08797939881802568, 0.11960151650372053, 0.12747025072214105, 0.09761077877614768, 0.1264153553112861, 0.19185118437294038, 0.1480110214963075, 0.20636775380661412, 0.14991334038636378, 0.18673017771253664, 0.09869896070731264, 0.18473830314413195, 0.1338847125730207, 0.18187849692279295, 0.19278898324456908, 0.11236441411799002, 0.22789779690004167, 0.20668853014226884, 0.16200700354191566, 0.15446687507773602, 0.11972035972341416, 0.1550927076248392, 0.20836264676144048, 0.17910052421352557, 0.1007846120985285, 0.2592565335573689, 0.15406544500541303, 0.13120432414354818, 0.12885698477827734, 0.15309790660056377, 0.1372731501056302, 0.12107360807638015, 0.18562446768966415, 0.175510911992, 0.1579166609313219, 0.14051662848120736, 0.1129427798573048, 0.1105272050406183, 0.12410509460155042, 0.16877572743162034, 0.18612244016220494, 0.1566402971624367, 0.10300818229875258, 0.1422913784101125, 0.12212401421199884, 0.1371479560170443, 0.16384291793069533, 0.10234714035064944, 0.09105639862677745, 0.11614137314139836, 0.25117583813205846, 0.18573504482065478, 0.08172456670792834, 0.1688798847458055, 0.10204544726518855, 0.13785781308768258, 0.19778211450865193, 0.14000518818295773, 0.12994210235774517, 0.12424149655646856, 0.10502485513326623, 0.17559337369616956, 0.241457078185293, 0.13710352291743602, 0.18298524882524245, 0.0856150676225943, 0.210708714420757, 0.10003542407385765, 0.16412738169873917, 0.08352538660889672, 0.1689057478741292, 0.19625197645396958, 0.10880598933586191, 0.0672155125967918, 0.21868568154111986, 0.134215509338725, 0.12328984681516887, 0.15971232506055988, 0.21741265791558453, 0.145409386905451, 0.18057305245630204, 0.2335864287470618, 0.13230390546302642, 0.0736023493171219, 0.1447832326014196, 0.0925793584376093, 0.17636752086541346, 0.1420955663366664, 0.1239696272738999, 0.13292575435292336, 0.0732062818602689, 0.12621077153110696, 0.1506046274857175, 0.08730003204677375, 0.18780587241053584, 0.08849503727810037, 0.20008187981382494, 0.2093573812876017, 0.10224011020674821, 0.07294968071003115, 0.11609606670155642, 0.18385670448262847, 0.04348726447431311, 0.19854739037973268, 0.12229356479140059, 0.20856624228819726, 0.08204012598481872, 0.2671827856571444, 0.09197479249128411, 0.12477562837903539, 0.1830013826369278, 0.1501917367380473, 0.12100842165490314, 0.12523778624111606, 0.16259122219297195, 0.10426740101989239, 0.16064192679139877, 0.15042942317743457, 0.30365990895417433, 0.1138620010967697, 0.10993383163886686, 0.11324641880609336, 0.18266894644306553, 0.08335072622304002, 0.16636051267625826, 0.2415157605202929, 0.228280212670084, 0.2193549359517713, 0.07200273474858654, 0.08363302196225814, 0.19521244110599642, 0.11162618881151562, 0.20072467354757173, 0.1411659646058275, 0.13289425281747697, 0.18304170950526194, 0.1301654629529484, 0.16243379112453232, 0.10471419881909125, 0.19808344753278842, 0.12540500025234877, 0.14417223151653044, 0.13431404356754598, 0.0878867328227047, 0.15475536846826154, 0.12444473202190093, 0.20668833095940853, 0.16924662635691706, 0.15621522561677043, 0.09537207833941906, 0.15150709438227838, 0.12579485473613586, 0.09361477989342906, 0.1682334903988146, 0.2505361087500088, 0.19051403918814278, 0.1047872989288261, 0.12137101106946507, 0.10305355768650772, 0.16810579886359556, 0.11167184765180273], [0.030151376343001763, 0.042222801881331595, 0.04043620440267748, 0.013566557205312196, 0.02515366961879115, 0.04660622674911734, 0.017535423168972615, 0.03813809001698129, 0.04182393820355496, 0.03586496541937513, 0.03638359162235453, 0.026162571025892135, 0.10745947489575033, 0.06227038057160474, 0.051993104223642624, 0.06675855647171698, 0.05646315065302676, 0.02314122750483934, 0.06132756382407201, 0.017981993057014003, 0.01926514053446872, 0.021037649656195315, 0.024044188528111386, 0.1331007441565875, 0.07270054891705513, 0.0383495839102374, 0.039604887922084143, 0.08781219246767222, 0.027243174432266145, 0.01320117444265634, 0.02873324800372845, 0.07019238471384011, 0.08590456458830065, 0.07731015358360545, 0.07373171858489513, 0.04746838592954221, 0.019425764274332794, 0.056873000031637574, 0.056968496721838756, 0.004278184017992669, 0.03739210423983393, 0.04376911588253514, 0.07831118535250425, 0.054311094760534265, 0.034492522733466285, 0.024225465998414065, 0.017499179549274907, 0.005667287201034807, 0.03719821121663817, 0.016940138377850095, 0.0851010762515568, 0.007984782174800434, 0.05223060297148843, 0.03116963168365821, 0.03977854473276004, 0.045867070645814946, 0.030333912112720074, 0.08515706195706323, 0.023972699118237344, 0.019371496520996578, 0.06067253183573485, 0.03154807720303295, 0.02617283085841806, 0.05191119410277856, 0.07208299011953416, 0.04511623170166727, 0.10878229423636392, 0.015319940942009131, 0.047930578265579483, 0.012448458583094181, 0.03595200449889226, 0.04928350869205691, 0.030019885011678262, 0.014313394297665406, 0.05039268526278677, 0.03081736721909575, 0.030821827766034874, 0.048590084207394434, 0.06847686870324035, 0.06666196044534445, 0.0980492645213681, 0.03166644927865315, 0.10334843258944251, 0.033456921246984316, 0.04800292760914853, 0.08596325458417978, 0.012630185172442469, 0.04057236887033909, 0.048374227443409544, 0.03947881666282493, 0.010759295997089677, 0.0425118085507664, 0.012697118274386854, 0.008103349602841323, 0.015389158901187684, 0.0326055447540937, 0.06658160548296667, 0.061869613165336276, 0.09016928413221914, 0.08247881091289944, 0.011282581929868508, 0.05376484725744494, 0.00802868906776571, 0.055021775375691154, 0.015279415848424599, 0.07090067130423362, 0.036444196838044354, 0.020948187823617653, 0.016951227500554056, 0.04101510640353926, 0.026499036842236118, 0.07988344292126356, 0.038505413854915294, 0.08752694728994563, 0.001577395864108938, 0.050351408445426536, 0.03281472123137886, 0.03507813949498438, 0.06318253848040778, 0.05260859458376804, 0.03629712710878061, 0.06974165688358969, 0.008974313048735983, 0.06267574067497927, 0.005575856522491743, 0.02913520476149936, 0.05824255073563226, 0.019715213359543876, 0.036420467264589765, 0.013876872610360866, 0.032100482137813684, 0.03229380442550586, 0.024430716275087288, 0.07971817477335853, 0.02008287619138437, 0.0338016378302728, 0.04160696295120063, 0.035286683949732014, 0.022862365754741817, 0.07669258712520523, 0.018207952605500337, 0.06273955579907184, 0.07871211746767645, 0.018873501065818053, 0.058950124864256194, 0.009018920433347025, 0.03774808997648858, 0.04373560719672711, 0.041966633570771066, 0.040572817031774795, 0.03326764007309272, 0.01619581501149843, 0.03162241071432589, 0.02743378859914599, 0.020463924494481856, 0.03585236710346034, 0.0169944214529448, 0.06007291481740052, 0.02880251575862208, 0.07081591133629123, 0.07045343683491792, 0.04780792758890218, 0.015133369804149675, 0.04779208106018844, 0.0263993285836712, 0.08694129605447093, 0.010046797838332433, 0.06526485355871339, 0.034808422919482954, 0.06590019325695692, 0.023572035133838657, 0.03157434252751691, 0.03884568329780333, 0.04190659526014521, 0.06446734836865818, 0.004887595470438922, 0.028258934241509246, 0.01362989448206199, 0.04327727211338859, 0.01350740947189831, 0.017227540093083537, 0.014348549114900732, 0.023623956742906765, 0.059105269160241856, 0.06762325523361083, 0.05444674594928661, 0.03400230690115883, 0.09028402112063863, 0.002459823097583027, 0.09658258919033313, 0.05568361788567516, 0.03882811690169958, 0.07251850344360837, 0.013769040946968862, 0.023096022571647362, 0.04725758534585757, 0.07083225965259538, 0.028730963146494284, 0.02515948805657606, 0.01104125178479139, 0.030682062685129144, 0.08649459784670223, 0.010261349380016327, 0.061958544482026374, 0.06983090612676836, 0.02218711287564328, 0.033946773187527736, 0.06998908796137379, 0.10033391491179505, 0.04692835139951879, 0.047003324594228506, 0.018315835022217324, 0.04381226961530986, 0.035747282822886785, 0.04878648616854222, 0.06245173656591966, 0.056795682607879566, 0.03423424768111399, 0.05113358038567728, 0.009886659606690369, 0.02444937051604352, 0.0340415152811235, 0.05695190325739884, 0.029486314348515966, 0.039717089159474264, 0.01306128774529263, 0.021877561643299077, 0.04406135161257079, 0.06688667701617365, 0.07078276271180761, 0.01997430046509591, 0.060436446520109335, 0.0464663697376607, 0.019452115783708233, 0.02744227685334702, 0.015183336931400964, 0.06083336816499792, 0.018840070904022264, 0.08034592254027244, 0.025588872677256024, 0.024525427725166086, 0.055998093148152676, 0.04198448724984642, 0.013984811526062268, 0.033946194791144906, 0.03987378478350659, 0.08809227421278916, 0.07522679279528319, 0.028266348057396473, 0.020978967321195433, 0.02253526536327216, 0.023595211208767952, 0.016110174042443116, 0.07917118033454304, 0.02410865865737921, 0.07290864137992745, 0.03564690998304756, 0.03452955925416562, 0.07669393543995197, 0.02109600257338776, 0.03774766479769061, 0.04740981850773097, 0.00889613377606316, 0.07695043699875956, 0.01922797186360244, 0.03171099920666987, 0.028535752452068755, 0.03984955725290122, 0.0390806156511028, 0.055049193662501154, 0.03957616728580287, 0.012384142629021119, 0.05292914109304548, 0.030380978639568054, 0.027947663141775037, 0.016963588329212322, 0.028260317030212576, 0.04152948464897852, 0.06283257036439835, 0.01904994260609871, 0.029175435868842952, 0.0409138870365437, 0.08084730410407628, 0.027793030209478833, 0.05999260198985858, 0.008373499018019967, 0.045191488348908966, 0.03249295664230182, 0.05165639325916287, 0.016130634335680835, 0.02769364945350155, 0.041016699866421764, 0.07371015320982664, 0.047924587458011605, 0.024034411330977758, 0.06340898640994584, 0.04731152559660616, 0.04077490719576036, 0.02561431254200157, 0.011802641674876215, 0.0332141786272968, 0.03409113862641877, 0.03784283590052397, 0.05214591195145923, 0.08423385706039206, 0.014716828647520275, 0.04547512091155495, 0.06180606617201721, 0.042692467405070225, 0.08176054219685255, 0.053637439174757856, 0.09567502014819654, 0.04266249804547237, 0.03589165592265706, 0.08098683935860473, 0.053795774226948145, 0.004288575521880581, 0.046094345950311234, 0.06830011689735037, 0.0446840163861071, 0.03494666348541937, 0.04757994365307593, 0.03496127661257502, 0.012195268439339295, 0.055340299412848494, 0.029597856750291203, 0.03629268379881978, 0.02350742327830484, 0.02312273414234721, 0.00809198277326481, 0.0062665604374131136, 0.04519997277267037, 0.04976501793510491, 0.023354291878340226, 0.007725404434642124, 0.08964567835773192, 0.134617445029078, 0.0931189984323517, 0.045028641038844665, 0.06824324252985178, 0.04191291548552052, 0.01703036055269261, 0.06874982583066148, 0.03551564464766172, 0.04856235182453548, 0.017047067015101353, 0.023400416117041342, 0.03833062706455108, 0.01260897890108848, 0.03306309842774945, 0.04442380696174599, 0.0224479868812787, 0.126315334871892, 0.12026300278281975, 0.0813137443976537, 0.10407816964171587, 0.17528152994571194, 0.07925782487877915, 0.07138015041428228, 0.11102428885116694, 0.1563049191909452, 0.07928138208245078, 0.08697705703877634, 0.21875447623672026, 0.19209429471483155, 0.15566272300577935, 0.17128072769170807, 0.1283630495890975, 0.23958538749044944, 0.052362362433585434, 0.1556583103393355, 0.1849914339160727, 0.14090410043154994, 0.16653099788292763, 0.2129730404985528, 0.2723025206115938, 0.11107835933686265, 0.2027037850911579, 0.11690454227068733, 0.21171467979588818, 0.1933479516376411, 0.07996461759772032, 0.0823364487939304, 0.2162772696465254, 0.16263550207499536, 0.23682665890983998, 0.15778576714857934, 0.18070042223459293, 0.11910355935293822, 0.19484678733973734, 0.10816121143439125, 0.15874870902588292, 0.12952023305960242, 0.11953893478118605, 0.12190731858173687, 0.12949030966528002, 0.1327906317648388, 0.10495209210221806, 0.11269670475514666, 0.11348238920853024, 0.11494717996327147, 0.1342559741028855, 0.1356732214410459, 0.08057801653781245, 0.08250206934228059, 0.16172350504465643, 0.15245289121183658, 0.15002822293148887, 0.0843353407277215, 0.16785668239237803, 0.10318268946702443, 0.24587648620288222, 0.15464509777244062, 0.08046720958044452, 0.1283001384487556, 0.12496417027808006, 0.11792888609512199, 0.12426634844873222, 0.24940508718211807, 0.13576944208433553, 0.09993307472717378, 0.15899433213616573, 0.19323061761115828, 0.14428074021012555, 0.15808262621923802, 0.11888255064766254, 0.11091294563225201, 0.11228099480391511, 0.1779020562647812, 0.1569186015835693, 0.16780000720773974, 0.1608756908606137, 0.16385384234449557, 0.11968227749269818, 0.1727051762563567, 0.08460411501507606, 0.16878084489895454, 0.2572140818642032, 0.10837603014923873, 0.13555970253242602, 0.21754954250589495, 0.14674752800455018, 0.1035714484450798, 0.2617115389195181, 0.11607679959026077, 0.1918958932642014, 0.17619386405473755, 0.14624607749283314, 0.20006730882150514, 0.1110307086679724, 0.23335412024490296, 0.12722036816299925, 0.07116782914606795, 0.1608983977066894, 0.1411083854374386, 0.10714557802965564, 0.07902552403749959, 0.113173081209102, 0.17226669817201554, 0.19429436133753872, 0.18723737388368578, 0.10829069561535314, 0.10363962260946151, 0.10534310337877083, 0.15126395339687027, 0.11649842374026777, 0.10847482484795394, 0.14450207833320866, 0.20950045586834032, 0.18907161820079052, 0.1202460645788139, 0.139199968487505, 0.15928040468885055, 0.12745061588864173, 0.16225196781658358, 0.16748506846206804, 0.16645797438198523, 0.08856595403725102, 0.14197107704897083, 0.09300011690826186, 0.15599661476669774, 0.08586653598373936, 0.1910884212702513, 0.26182966967744215, 0.0862728613578985, 0.17796383359499518, 0.10070781178411939, 0.11866960884822954, 0.146722155172498, 0.12410461962703737, 0.13125111679396323, 0.14527761978247475, 0.10550303189384361, 0.14938014319106457, 0.1549242908555654, 0.10234552390512922, 0.09064069633642513, 0.10340984219745283, 0.11766455511772826, 0.10881017983680773, 0.12718677520751953, 0.10136433381346927, 0.10992887504999677, 0.09141142675352674, 0.08787737888914925, 0.11497780815848421, 0.1867109489056372, 0.14657472921234949, 0.19500587315809345, 0.14881970390917795, 0.13205331810299428, 0.3243438539005095, 0.21530749426493723, 0.1303180523457066, 0.1910351934812723, 0.1903685590913219, 0.09012115848881584, 0.14980434139649715, 0.1317888032644987, 0.1970742339448583, 0.1316718063167026, 0.19250890149945216, 0.16298984838349206, 0.11950471363360844, 0.1516925795905052, 0.11234654894759578, 0.13609167398704639, 0.10759448257064629], [0.03276739231941681, 0.06345594759970423, 0.0075598164450287105, 0.006091882814578111, 0.023872040910646323, 0.049768346587135914, 0.030658710409977266, 0.04516632619103597, 0.03407243842018708, 0.07234814081100688, 0.043653237423108476, 0.06617825252995377, 0.06467113541739603, 0.048053179146541704, 0.01352522963462698, 0.0635565617572396, 0.06490752716819126, 0.04737645537862855, 0.021691729780286554, 0.03756596789424939, 0.011638878889742398, 0.04491345588898948, 0.040821508324194344, 0.08633939609412225, 0.031488916063080394, 0.021024861733519265, 0.04458843159579462, 0.06156088356229086, 0.03248754423111677, 0.012028093690112715, 0.07435594234735736, 0.03993784505573492, 0.015411355341183803, 0.05789989492886009, 0.014265439108825259, 0.03799810277057752, 0.033092225090630596, 0.09236270111174354, 0.030954929797219175, 0.049945688280727596, 0.06400229086378409, 0.007275132905511607, 0.015903604179320317, 0.021114817692808086, 0.08472740920560975, 0.05403474003316895, 0.018193498441588976, 0.028148960404758974, 0.04459785064682365, 0.07418678247279699, 0.07515770698627157, 0.0402077493227778, 0.005083313698114287, 0.03832513804457361, 0.07670275311196044, 0.038459379631545276, 0.04437456282997324, 0.046917066924394145, 0.0012257163794974107, 0.11336095661165253, 0.02867513065857272, 0.01618357484168824, 0.039354461440516096, 0.047757281516227996, 0.14283324772071454, 0.03503437289187024, 0.006882533911735781, 0.051500226235798294, 0.0706124690271193, 0.023709281700693315, 0.04368068252299582, 0.05598292077681231, 0.035710487619883595, 0.03096021197345709, 0.05707181516974684, 0.06906623546514781, 0.14114858973170483, 0.055296172748409936, 0.12808559552556084, 0.008347943282475876, 0.08890398267296054, 0.0669755815197864, 0.02277994043974867, 0.14306705775520495, 0.05441034911200405, 0.031901856606465676, 0.032800839718190894, 0.011956974875272043, 0.028527595530894977, 0.02963122370983324, 0.01720192977377484, 0.08149395126008219, 0.047873546850056424, 0.023415282053212007, 0.04232528146296259, 0.01974372332164597, 0.013039911976985395, 0.041091925870146484, 0.021141104084709962, 0.07861034268693579, 0.029146033414309064, 0.011041248911961673, 0.049652058270669756, 0.0548226040066971, 0.04238731926307083, 0.025831634449141643, 0.037969776669577245, 0.018465633939711318, 0.03592518759110282, 0.04070440795452845, 0.033400360975534685, 0.016079388799205903, 0.05615733984497286, 0.08258632369219296, 0.11875295155351201, 0.056944816944099245, 0.07282919040130031, 0.010930734983224784, 0.016432585975816174, 0.0166992056408837, 0.059970990649514624, 0.05742430754546678, 0.05985470616348809, 0.07072494605616217, 0.06294104841447647, 0.029912130914688594, 0.06304258953840022, 0.024291069937809825, 0.05978430268324672, 0.0422679053078736, 0.01592938208036245, 0.022126408068523295, 0.06435763691702197, 0.05999198145863991, 0.05279490716695305, 0.03553932442540123, 0.03170358922122227, 0.03871323052613485, 0.09296327573998321, 0.013637325534927509, 0.026391474267227516, 0.03753286140460161, 0.015115972904999171, 0.026698723405359254, 0.011289080270686218, 0.05821821978315712, 0.0358448785940005, 0.020784773608489383, 0.007588332631595193, 0.006922698943995901, 0.1050493699468432, 0.02882567268135327, 0.13008312382284673, 0.03567874476674103, 0.06965462929539143, 0.060573649036908345, 0.03348694423273687, 0.06399774796239312, 0.026296693869235537, 0.03007425618688426, 0.013501835224639266, 0.04893209650031021, 0.04680675026329775, 0.08421924010279679, 0.059565864202957, 0.047463272292647636, 0.04684516191182118, 0.0570127651125433, 0.06307797897006236, 0.04998342577187766, 0.04307941458518467, 0.025548699026506756, 0.013574480469669066, 0.08477620900638642, 0.028440295981483597, 0.08746601265644835, 0.04062113419715916, 0.07144841650921492, 0.004773763902184944, 0.00601397933355803, 0.09673869492666376, 0.055752504511826464, 0.023507459667481245, 0.038354532838228254, 0.054214514055920225, 0.05508148043806996, 0.05185402479142912, 0.017700974769409628, 0.08109330259744199, 0.0919036305839977, 0.03704671349917208, 0.027074073929519906, 0.040243870368407625, 0.01988541702890108, 0.03668548389067573, 0.017693264094451745, 0.02665196905934042, 0.05841786612666423, 0.0560389026518791, 0.02115290375396369, 0.07433757921981235, 0.04812358262678308, 0.10982665593826002, 0.04339066461750096, 0.04947559757819099, 0.01695352959476652, 0.018929120964340625, 0.013662217646807194, 0.05238425722646137, 0.08777980993111288, 0.025525070959702138, 0.03322002387815907, 0.0599663864610897, 0.003147716427432193, 0.05521811988024462, 0.05434144716409426, 0.0820908103618891, 0.08782051984340915, 0.06791618427321797, 0.0212772379088546, 0.0787856848910451, 0.05071378718580931, 0.034527460173253095, 0.01824788685377327, 0.0068642095673919455, 0.047239409909854015, 0.009449511642507728, 0.07754363420028841, 0.044592104987391544, 0.04617625224073568, 0.0436416809867707, 0.04659877271361409, 0.029017819024081674, 0.02925696869140431, 0.026686125089444464, 0.10521743431567185, 0.049555220926601085, 0.04494121508492578, 0.04705991167875548, 0.012796659908828237, 0.03658996421783682, 0.05145340677230589, 0.022046598943791563, 0.047809612982335596, 0.012760745706937969, 0.05764174245057568, 0.03901570885171814, 0.010204805387935091, 0.01608716459163735, 0.0019653877966301215, 0.10624784555646682, 0.052128866495143984, 0.08609352783570368, 0.01936369966114721, 0.026467845572399038, 0.020029629250207258, 0.043238048411665425, 0.04284505679782841, 0.014236618881113829, 0.016699770630727855, 0.043736656737183376, 0.022487892401254466, 0.02734867814597824, 0.05675724797671842, 0.006795137643723959, 0.04616330535481534, 0.01872826037147353, 0.09673951464074274, 0.1457283705953629, 0.07328327369665907, 0.013436330876673662, 0.020479169644175038, 0.021706208842055454, 0.07595482147148541, 0.09878910627336272, 0.053594419507369886, 0.058400950905296116, 0.019463455800207394, 0.008895270011928535, 0.03732309503961475, 0.015776147258528057, 0.029776623367422053, 0.04210250692502145, 0.029635230349677227, 0.04520720081223596, 0.03219775232155958, 0.013805872539148457, 0.0029384710022338457, 0.05767905476292776, 0.03516217550983833, 0.1261179216746842, 0.034699933378085975, 0.04233202303669626, 0.0442511537262509, 0.03300379939197052, 0.016168163067871527, 0.04551684972079051, 0.02261349251644025, 0.03365560998058608, 0.027702984234858907, 0.06497215434548355, 0.022794003898818648, 0.05129418305812344, 0.01713173505249283, 0.06283070494030273, 0.012970868302809616, 0.05997200954645392, 0.047567284050127195, 0.034674909116039355, 0.05831049890407632, 0.057461474301113244, 0.06991631726944639, 0.03096479700968391, 0.013746836846093497, 0.04580978642127687, 0.040200103765293475, 0.043778423850815144, 0.04622190725058318, 0.04745252024863036, 0.05115727165473565, 0.032178286027403614, 0.06206036139760287, 0.08476937550210184, 0.03723788307979703, 0.029203976474462018, 0.06460198066047122, 0.14327544899236772, 0.08400828247108767, 0.02732149926164458, 0.10250623382988477, 0.0495077426274938, 0.07585136895819057, 0.025491960639614734, 0.03894564628060307, 0.04071597971262471, 0.016489410547599677, 0.04522841378685929, 0.053416380673767104, 0.016013892112119545, 0.08855386516980587, 0.03308619980910613, 0.05761426670717136, 0.030376253792295055, 0.032844656117020116, 0.0299089459041434, 0.009264114534392232, 0.0405349110012814, 0.0599292848229168, 0.02168787061236799, 0.030689512890192772, 0.009756847923140853, 0.029282699669561083, 0.16960435877403907, 0.1766109836077498, 0.1490857049582466, 0.10378315684295471, 0.22222882286915857, 0.19340324786401566, 0.14429978515592315, 0.07353280385535571, 0.15643270265671516, 0.18241900259688978, 0.22858030463178314, 0.14249371755267345, 0.13569151562067772, 0.14818510731622098, 0.16885206043239565, 0.11241853056896119, 0.10056448439436574, 0.17275189229797933, 0.07456025799676295, 0.18001446710719218, 0.1364277720811867, 0.21292102312849415, 0.14491466264570915, 0.12736865214162296, 0.13386696997669437, 0.11188553255652228, 0.1791268929598793, 0.11732127111885818, 0.19071354380538388, 0.12723942843055533, 0.140471245432573, 0.180822245536312, 0.10508811101317407, 0.1462058731985669, 0.1758364227510268, 0.14638844727268144, 0.17194716289879816, 0.14871099603272256, 0.1587282851218216, 0.21895508402057234, 0.23790469783688747, 0.204180434886967, 0.12336536010186519, 0.1654406555838162, 0.1516394130885601, 0.1728392416431058, 0.07751505912071274, 0.16041349469413682, 0.11057998849860123, 0.21731669774218915, 0.13008557530420442, 0.1807184253008135, 0.1391820726735938, 0.12602622095014782, 0.18526894160576407, 0.08811977676927082, 0.10296548821873243, 0.09525099814298654, 0.09602529086893606, 0.17824581523816432, 0.13503857888281345, 0.1638402825882358, 0.18575159231981925, 0.12028607735109907, 0.2974676509057322, 0.1897468940625268, 0.07980117273907508, 0.21418713664095249, 0.23689087239965317, 0.0943130843581692, 0.1939269455690538, 0.0700329005297634, 0.11317128856335917, 0.15050456108104798, 0.14021652119774974, 0.23150202607916248, 0.17246954293260652, 0.20203852965947122, 0.20894930157209599, 0.07506909359607004, 0.11687938394325396, 0.176677311500234, 0.13380471767196733, 0.24444023988419966, 0.11253139830284542, 0.10117178527458061, 0.15976290218532085, 0.17324558999990264, 0.19881097059096062, 0.12445590924471618, 0.19834992355637013, 0.21769623302163618, 0.2433098005431314, 0.17963860904978168, 0.1046615532569347, 0.11805836261520464, 0.12692472717214015, 0.15019368260137497, 0.08804956481101052, 0.12502643024368634, 0.19651750252852518, 0.06478974881071238, 0.08093951810752192, 0.15613441866251732, 0.10812184217596248, 0.12321411902385375, 0.09637005341749999, 0.09716490028245796, 0.14114704223409777, 0.090331265762929, 0.16465215192687127, 0.09801390956366256, 0.1686401451907812, 0.17837790411806878, 0.2719881181274691, 0.11417899295807847, 0.1574801287103084, 0.09911442551040843, 0.216207969332895, 0.10789687279611827, 0.11610948856198981, 0.13783539735501812, 0.18926067337874444, 0.1643616667077426, 0.11794617669957301, 0.07128924642118716, 0.2893749125782521, 0.0812648679880846, 0.14516730312137835, 0.10097363663296546, 0.14720227779640307, 0.11970624838384891, 0.1708530208035823, 0.22117509957282777, 0.11942942251241016, 0.23592261387215507, 0.11087438842702298, 0.1140365006041623, 0.23324976374785747, 0.196087543341902, 0.10517292460727115, 0.09575152934919443, 0.11270693968981506, 0.12173422867612493, 0.09148992778312776, 0.11330196784148294, 0.09888040097129923, 0.11784667719996746, 0.15549327967868698, 0.13387620899706118, 0.23512418171571148, 0.15450188529587564, 0.29496551581448127, 0.14219066849158657, 0.12361578658343324, 0.22649846069755095, 0.10761472261360577, 0.15094719136193877, 0.08675280778158097, 0.09660230063262487, 0.06928296173892676, 0.21671516550404413, 0.14637579150017233, 0.23424840532243255, 0.16585872508585453, 0.1354643092640946, 0.09957407060409747, 0.11777176146185207, 0.11584993797324358, 0.09459827590974108, 0.10951976111579327, 0.07022269115212464, 0.1316050647367393, 0.23973247637191128, 0.10571460239589216, 0.13416827235731388], [0.01290297376052026, 0.02896735872772913, 0.020167869816143668, 0.047499649977732095, 0.024805904005564032, 0.045907899301739476, 0.04554428332935899, 0.0481474615873829, 0.031940607248895594, 0.06162920711381782, 0.007033389072955376, 0.013423060318605315, 0.018579719753395167, 0.016868137604286595, 0.03665840268255242, 0.06600414372740254, 0.04877280766865419, 0.019513464104684613, 0.04834726880935412, 0.0613492364514499, 0.02657631213115829, 0.03873102291817627, 0.05172929035559778, 0.04449034169796975, 0.061086073758140694, 0.06406751942009696, 0.016003339250962582, 0.04822715005326656, 0.05495509125232216, 0.03513001513877704, 0.04264862802360327, 0.0693659750264018, 0.03588303743350891, 0.0722952424398353, 0.08924895972614327, 0.07594991084789077, 0.04645618842914701, 0.02936073338552829, 0.03383706939677077, 0.030241700024494243, 0.05787854022797077, 0.017159038426114187, 0.06748905195103538, 0.02955741879920806, 0.03487629447913459, 0.05458904678122171, 0.03599529229705373, 0.04446381590359154, 0.03490290071274485, 0.02804187280426343, 0.01956664209794854, 0.06331642383649465, 0.023170298626345974, 0.02911473872260221, 0.007753609876794321, 0.011084276240228886, 0.04888530384989516, 0.0033490998753076123, 0.0575895756933718, 0.0643638881944841, 0.05549125703832796, 0.05087849991996923, 0.013572433099691427, 0.042336470177096706, 0.08423943418048083, 0.022442045869425904, 0.016039104065707615, 0.016701086386737805, 0.06471287954839007, 0.05399660800673789, 0.023375286517905134, 0.004943376726230546, 0.07836671140525611, 0.028439194730092442, 0.020636085518485597, 0.04455601458527869, 0.029767233044690186, 0.012262132593370494, 0.08968790512411826, 0.02529398245256274, 0.05805818401577492, 0.04209856157221141, 0.07330480076733135, 0.05696836648689163, 0.04016749523279648, 0.07641109577830761, 0.01344396685805893, 0.02702369407239941, 0.03493420689577057, 0.026851822246587085, 0.02759401014284982, 0.02700902540386925, 0.028313284349297325, 0.026120503222750082, 0.04680170940475599, 0.03564594471226296, 0.03146040227053867, 0.049880969172884385, 0.025646013260308295, 0.04077285408012329, 0.017739664124805602, 0.0162023420806133, 0.008871300078387703, 0.04916674923151732, 0.030527129063322663, 0.026214057880063212, 0.07762704585348407, 0.06068114266400376, 0.00932183447143724, 0.04935624491002771, 0.004932099433180186, 0.037388936466267036, 0.02141661420013876, 0.033156664576381445, 0.0748000894823382, 0.04787725854604956, 0.047694856841718, 0.016573143957723534, 0.016819927691211625, 0.0437884021460289, 0.05875706687689789, 0.02236640809344188, 0.010941057060394558, 0.06344303518774048, 0.057709054766042586, 0.0231328445877279, 0.061708267387603565, 0.0187220090940114, 0.0456445450864492, 0.029460721266185565, 0.05807846236313063, 0.059006206330753146, 0.044323039586625756, 0.04455589201121081, 0.02009704115710432, 0.02303376835170052, 0.06967277025743839, 0.05633227219204268, 0.01994191026765733, 0.06066068045554623, 0.03056542005299801, 0.036858661896398956, 0.050869199612568465, 0.046510829650346315, 0.04118106403057614, 0.09836012767928262, 0.044922036073741414, 0.016831859510632294, 0.058019672775821346, 0.010976703131511327, 0.03093333569385352, 0.030353502896163734, 0.046738905516723474, 0.05222643545318035, 0.04563660841555365, 0.029094762979976596, 0.02654927880353024, 0.004123180969468048, 0.056126845715146874, 0.031067703685332692, 0.06506575496807214, 0.05073367482832363, 0.03559529097870954, 0.038699188134482795, 0.04280267298341759, 0.050568682472071344, 0.027492361766616666, 0.018117023714547677, 0.048747086266596476, 0.04345514240764803, 0.04441516548996011, 0.015465637458668602, 0.044870823096003265, 0.031961645938516144, 0.026074551353831927, 0.006023633477818822, 0.06400825868871424, 0.03557625369379117, 0.05699551664292813, 0.03612559236165497, 0.01456365415510992, 0.03155557911903147, 0.0667644476878547, 0.029444106734327735, 0.048815888623076106, 0.015838101746574525, 0.03541616430025428, 0.06782753257862023, 0.03713495150629071, 0.048295442961276545, 0.034914951275793776, 0.04156572826867623, 0.033976259911733295, 0.010406907043239523, 0.04976137901746458, 0.02910602255724371, 0.03140060910804859, 0.02412190431759002, 0.04606853261770261, 0.019434777298761953, 0.040038482195908026, 0.02878041412200659, 0.04323182394728065, 0.017892027521626126, 0.048299985862667524, 0.04408869712102798, 0.01796988120693113, 0.018704957892036727, 0.0316708964190536, 0.08115432150061093, 0.05232351028450555, 0.08690394926816226, 0.015332563198171558, 0.032129413448274136, 0.02022965289201708, 0.017058820719079628, 0.10133425720156201, 0.0028161270001287302, 0.006715339531506142, 0.03469432944491987, 0.01789947389625013, 0.014318725312008493, 0.04780511604622007, 0.05234032591444351, 0.018777923936384822, 0.0312088783680191, 0.05265420362834008, 0.005369762591491904, 0.03036998719307444, 0.015082978455710317, 0.029088128658552325, 0.041682476237896955, 0.017995880315861395, 0.05247940151621738, 0.06081374865325709, 0.04213413486497537, 0.019427840372607596, 0.059871862702552354, 0.052116957658361045, 0.0007555351828247489, 0.02874808521160195, 0.06167664710852889, 0.04178123646265557, 0.011320518603878877, 0.036705210654725956, 0.03400019249848781, 0.07138314581806622, 0.05878480692063609, 0.036357199893363064, 0.022151047371387966, 0.028862940943649704, 0.04789479429863634, 0.02290156647382725, 0.025338241267168236, 0.05352128109323883, 0.039583502577677857, 0.030253455643692327, 0.03799887651938104, 0.05821936125416429, 0.04721775643467423, 0.0771353246584054, 0.12135227255883718, 0.02310019583561488, 0.02033678645778808, 0.026137429935437058, 0.02977306105857415, 0.042828145406899915, 0.04148974000746685, 0.0550256134761918, 0.04024572430118438, 0.055996875068353075, 0.04910359677347926, 0.03055285238060019, 0.03652502677493519, 0.02596161658725431, 0.05738304604986503, 0.009006148790039362, 0.011017034787894979, 0.045275007254414024, 0.06582825760086698, 0.012958835934348887, 0.03652485440515223, 0.06567520855535423, 0.04941695737802694, 0.08881156182577533, 0.024830332634249525, 0.029368614515049324, 0.00636226732298852, 0.04597880073913163, 0.017274918800760663, 0.03592759310718506, 0.021995912651501356, 0.023944277256246538, 0.008572233716897186, 0.043543299975534605, 0.061912954589652444, 0.04382225557140285, 0.017174802600376068, 0.02420756635406325, 0.033832001725151654, 0.024083929339183435, 0.04443181641099434, 0.02076995938325361, 0.03410408551233911, 0.020478198627731013, 0.0711246524306555, 0.030372944292462165, 0.10191361119429912, 0.004041832965618421, 0.0817892934766508, 0.010277377854612087, 0.03890508575545203, 0.05734443904892091, 0.05133280921126566, 0.07187395536851499, 0.029461653978233377, 0.031774728145870956, 0.030884591434451363, 0.019901112255249775, 0.0703749894314716, 0.026198843373887004, 0.03189278229500257, 0.05040138036072735, 0.007723834912007255, 0.18011050388938, 0.07666522246454993, 0.025601993848179138, 0.015561013490021711, 0.05269314770797088, 0.024340505591563644, 0.0020949215339046093, 0.04376778288954689, 0.026534679082913265, 0.0230914298745413, 0.06016946104805797, 0.008126268080706078, 0.043175761632981806, 0.03974644947917231, 0.042779491162828864, 0.024124566473126895, 0.04450430748082938, 0.03959430058697059, 0.05438136417538889, 0.0466172622456666, 0.012785692402582257, 0.01769049085616585, 0.04322694396720298, 0.04724508279093331, 0.08485307060782948, 0.04239109607653753, 0.05299771362314782, 0.01691827231327132, 0.13986451911830133, 0.1324573681960183, 0.1142700425078792, 0.08970668193914237, 0.06431144181518786, 0.16653377112121354, 0.11246592076795717, 0.09617462438801605, 0.20046504635003307, 0.10681392324547614, 0.11955500730583746, 0.12911123403858754, 0.16043813208178168, 0.11340512924136655, 0.08166491144126461, 0.12654914490638242, 0.19936791651191252, 0.13411345110545236, 0.19890572034543563, 0.1492067774937999, 0.17283176462496483, 0.20591887224826122, 0.07764996720417854, 0.06846318637291271, 0.10535534546380082, 0.18484923267556777, 0.10174976030905401, 0.12075624083198848, 0.13512801198709395, 0.24129512719810012, 0.20306223763092873, 0.07711821791505621, 0.09420899599189721, 0.13713053517764615, 0.16425678927090862, 0.1675054617226124, 0.12031069941698544, 0.1354186504238075, 0.11388424062921156, 0.09541513248076362, 0.18315317529824474, 0.13034488074481487, 0.15061895332990155, 0.18037987572531547, 0.1366149580046054, 0.1362362347783581, 0.12996873157399316, 0.09331582174185785, 0.12335527072390243, 0.10044745680305267, 0.1444843663803993, 0.15270884118733868, 0.14617821742450038, 0.14636353409338385, 0.1371600755280064, 0.0660695676361361, 0.11802994841409307, 0.2517786420761578, 0.21345049713648137, 0.15423228363356284, 0.13311626509793345, 0.13828669975121177, 0.12111117702818687, 0.19660028598962292, 0.18533363007009032, 0.17481663714974158, 0.2085221309455172, 0.1648154818723279, 0.18404163810754978, 0.11562762691849664, 0.1798444109097604, 0.18105455403847082, 0.12457985460998551, 0.11231228183474272, 0.10522043738033503, 0.16233154903015784, 0.15128184921078144, 0.13817330341665976, 0.20980181953599378, 0.12721147388219833, 0.18272321611162157, 0.19419254825240184, 0.1924267615522108, 0.12105928223219611, 0.14987252322175812, 0.25800456202799277, 0.11078525409703294, 0.18572598966138978, 0.0618645531545964, 0.1795699216064907, 0.0877232956249387, 0.1318177920315535, 0.10347086110062177, 0.11438498634003824, 0.12322403220159393, 0.09628245892423777, 0.1645234185120752, 0.117513099535098, 0.06949204245522138, 0.18472914073255756, 0.189130193283481, 0.15182986254653624, 0.14842188977185758, 0.1885677008859573, 0.13778330337616707, 0.11536593894444166, 0.24741577134738046, 0.1335624193832759, 0.09404195052000786, 0.2076855935757199, 0.057386447480248834, 0.14960502064035786, 0.1576957058522009, 0.11306595147377062, 0.15768718695448292, 0.17134935384796512, 0.1984731411381114, 0.10610795024061397, 0.1463165116165915, 0.13634287421741795, 0.17099935891887835, 0.11430598735328644, 0.18125657142410356, 0.17456338380373296, 0.10716488344534751, 0.08553763911608728, 0.12622324344251426, 0.1492128295884017, 0.19679317160719828, 0.14861540358153083, 0.17662230638727067, 0.164665236708618, 0.11834370738436138, 0.12840974264808241, 0.09987963243357598, 0.15007512283421334, 0.11030009061458612, 0.14207080637495365, 0.17899316465181692, 0.11839163384490436, 0.13931774684498388, 0.1649927086527309, 0.2383474813353631, 0.2452678140252829, 0.12245122568621752, 0.18820630656855722, 0.142541031142877, 0.11858935347728192, 0.35105810590809394, 0.1998998573230159, 0.3009134837456288, 0.07767078181308124, 0.10326130540981408, 0.09438697353846605, 0.1270080239121472, 0.12933278666628947, 0.14098340585347147, 0.07107108756298981, 0.18946549464618007, 0.07982211758292491, 0.10864212312885832, 0.130604017646082, 0.12558125410108797, 0.0904912479041565, 0.17633316948288874, 0.1067014308946748, 0.08585412535936603, 0.09924211704562749, 0.07827041415317405, 0.06549543070216333, 0.14974377448520354, 0.23710995822423891, 0.19157320170873599, 0.14407061761425388, 0.1409315110574807, 0.07450955063705483], [0.09258341870360798, 0.03329739875851139, 0.02989121862957555, 0.05900799131561672, 0.11806228498537695, 0.02526950594338198, 0.01583356746367269, 0.0422864101616846, 0.06365431074593818, 0.06219798909319986, 0.03680349590497152, 0.03231633890179857, 0.04563961531065645, 0.051652888406909285, 0.047171626450313676, 0.033563836477696896, 0.020215577941628236, 0.016075104452489365, 0.05782916969169052, 0.04006908740848303, 0.04159264476789583, 0.01023755373147827, 0.0339409853932598, 0.026049714783326756, 0.022914471224911755, 0.022584392666636456, 0.05794060867159598, 0.01618447307977946, 0.02459361338086667, 0.037555801907494184, 0.042671135686818636, 0.04986915226665236, 0.032912497033154776, 0.00988478939454522, 0.040469249605291316, 0.02246449607604694, 0.025020774431346406, 0.08569294046009741, 0.01443288773448477, 0.04171665525063873, 0.06861610518347833, 0.018055284688729915, 0.09273084466375651, 0.03760576233147614, 0.05708718289350791, 0.05868826452041826, 0.031652527545849164, 0.057951965925073436, 0.08956331624499253, 0.02494043096028749, 0.09939465281223098, 0.02304190995111581, 0.06190871429299155, 0.03228251611994159, 0.0967660825699568, 0.04204015119842464, 0.06817381964215348, 0.04017819748109868, 0.033495240964956825, 0.023735183133413235, 0.02598683045606219, 0.0312664900951448, 0.044789200258110805, 0.06918317878678923, 0.03520419160204549, 0.07569505637812038, 0.027747447977984147, 0.04136649944308785, 0.03167210109231453, 0.09876040095883994, 0.10027533216822533, 0.030234213430254214, 0.047700908936319814, 0.01790570027585472, 0.07291977263746724, 0.05137205206518693, 0.020939789584747726, 0.04588767075009885, 0.035127291696206216, 0.04486437263568083, 0.028761014860543995, 0.010017693200479112, 0.04448785191221584, 0.04716126128069816, 0.06833106684949129, 0.002930441443177481, 0.04609180253840262, 0.051438506362178636, 0.09593712180973062, 0.06384987001036925, 0.007632583306516491, 0.09594645276064835, 0.011637773807911624, 0.0354052513777729, 0.050701280800445434, 0.041574553601563945, 0.05015545081527484, 0.057283125201901125, 0.04486331543434532, 0.0365950970069295, 0.06338187838874518, 0.031498019102840655, 0.003812392983931087, 0.05353904667220289, 0.07549981120973825, 0.06869357199438157, 0.04986434123448787, 0.045742405157896786, 0.025143363820989768, 0.02442471397620055, 0.003127328912547279, 0.02077700356171737, 0.04675396680531483, 0.05800281118060793, 0.023763809923923785, 0.048559279811959115, 0.06943658535038272, 0.07845544736952552, 0.1267833226630765, 0.02592044510698367, 0.03703323035170475, 0.007887478953512807, 0.016693155461501692, 0.06904045660649577, 0.03491635704713483, 0.024827032710515687, 0.053883315094055674, 0.010117920483612727, 0.05606700658738133, 0.04332108851221781, 0.04056829711302154, 0.013090971737138688, 0.007703946311883028, 0.03778961960286383, 0.022965343293523597, 0.056864806721287395, 0.05030475752127748, 0.050065040948890874, 0.025922050061185035, 0.04086172794021907, 0.02080509217546111, 0.03297615127878324, 0.036103329846575376, 0.05386538480618789, 0.06742921282326983, 0.014541945138555622, 0.05553487808473649, 0.052994580323537516, 0.09658930778142907, 0.057192163752211686, 0.050217569054615115, 0.02194317132835427, 0.06528477950562393, 0.026234939521659287, 0.07153538281037923, 0.0690867436388808, 0.017853435842440497, 0.009004301560531941, 0.032967597907108646, 0.04471543748232146, 0.053894680008412375, 0.07052044654565473, 0.04301122126860484, 0.04843957857379029, 0.058812861060423244, 0.011190860137914219, 0.08054716617710168, 0.018471659221235785, 0.0279945113335646, 0.07976550368532058, 0.029173859642938744, 0.013836929743598788, 0.02412618674908675, 0.026900851873741038, 0.021835760055710713, 0.03160044697353677, 0.1329899065557026, 0.025069135646786422, 0.05826562147347197, 0.0036750889604821083, 0.09073365344515733, 0.042794805260435234, 0.00775729475971011, 0.07445400160166525, 0.011479817969243855, 0.016819581036425887, 0.01859376022982742, 0.07495093985550827, 0.04507606954223687, 0.09067369940420313, 0.0020790237730609314, 0.020414123033744194, 0.030518297984775518, 0.0308272018728237, 0.08400462823168886, 0.0361069304598195, 0.00931525377616767, 0.016314422659155343, 0.02859774428690153, 0.020023896997313828, 0.02119772372797372, 0.013111064308172753, 0.08700710300716662, 0.016391529408734173, 0.03226546300274711, 0.02872855188475261, 0.07412338869706278, 0.012374259137187996, 0.03213676406190761, 0.030558193928652236, 0.04749365150928498, 0.07923125694956511, 0.04482243315226609, 0.025368833073204564, 0.027730821954807448, 0.06228534226876594, 0.09011437094980672, 0.031853755860919916, 0.019360434211369966, 0.029904328309179797, 0.04125604488616509, 0.057650169417742765, 0.08499770800793365, 0.030522199287529916, 0.18143525377156275, 0.05988786244885095, 0.004853791361975094, 0.16008798393511003, 0.03337706424175732, 0.0890189494877573, 0.047143568480086905, 0.04206770738106101, 0.01864118107234038, 0.0472168562813632, 0.036805077876535156, 0.04694307943986309, 0.03974874008206591, 0.044344781161916834, 0.10596129802926894, 0.01654759492544878, 0.0069141977620611516, 0.03600168530078184, 0.05533111401863637, 0.1155066539743735, 0.0678484850833493, 0.017349700473489302, 0.052304162733977845, 0.034608703797623035, 0.0518455020632715, 0.028512151198341485, 0.013683995611274676, 0.03262240634930711, 0.10406851693386994, 0.03480403706611645, 0.01800777191566604, 0.022424739943216407, 0.03305757876425501, 0.012605097708142093, 0.014697712838589666, 0.07168069436785675, 0.1138746568692788, 0.005676420884312041, 0.016180883957854202, 0.040326121398397995, 0.10141481900767935, 0.11525284904505938, 0.042133786294969826, 0.057215552416539965, 0.026486543863410913, 0.10068715039280154, 0.01568494353353256, 0.011988362455139718, 0.03270350824741106, 0.035779967964176214, 0.04252642550836167, 0.056195559971515215, 0.0640580965386283, 0.00673814932064664, 0.07640863663607067, 0.03824169574786098, 0.03862958138568267, 0.09471052311240666, 0.03676976505366545, 0.08293723792678888, 0.05249017271243277, 0.036641181026014595, 0.03356402416923835, 0.028895518832629728, 0.04587115006401174, 0.014398397498523757, 0.03396391823527313, 0.029890827924734163, 0.05847862839037853, 0.1259897091996766, 0.027743111920332717, 0.024412441247653578, 0.020265429198080977, 0.04528905730694533, 0.029597096408026356, 0.021514464695487293, 0.018306381497231704, 0.05796526904187857, 0.020715400516506166, 0.05059535765359479, 0.03207708006694673, 0.06225677485006952, 0.03653245782780071, 0.03387853007523283, 0.0296054620881595, 0.03066516661595914, 0.04335957293909404, 0.013660963177831184, 0.07054634797837465, 0.032024760092157996, 0.02351613752844353, 0.048807649347450466, 0.04976877942681313, 0.02267201780341566, 0.023133670047466314, 0.023908951026838154, 0.04711664815042769, 0.0362800510089484, 0.010964604687967129, 0.05084952264423332, 0.050262787394345775, 0.044224344479340705, 0.030379099808933756, 0.020798542123708515, 0.04494198117285006, 0.026091910906196124, 0.06676734350020848, 0.041300301785550775, 0.03283097378669247, 0.028848990482548555, 0.009240045009421246, 0.0137878934131755, 0.03595671593962658, 0.13282536619132565, 0.1122167430097057, 0.034076571464538574, 0.06003439974700732, 0.023055845090458472, 0.10195029914499291, 0.026554781230046388, 0.0544475848155637, 0.06587007067977421, 0.02811092605453826, 0.02917658500072937, 0.055108622933227214, 0.006837169057689608, 0.0323411678114245, 0.04045311962404559, 0.1915388043609358, 0.18064970721400556, 0.20063815157740347, 0.14590423373926073, 0.3073066713348512, 0.15756493464352625, 0.14231017820777433, 0.17270804142519353, 0.2344046259719518, 0.199556389463044, 0.10442419623535487, 0.14485138378316356, 0.11230416130274536, 0.14813563335807095, 0.15230741111501572, 0.16375330096531301, 0.07478389438361892, 0.09218316074580916, 0.18301802206664317, 0.13119655601199598, 0.2380471289037697, 0.06546205991218168, 0.17658738809968197, 0.16980758657859218, 0.076667275580187, 0.1297545946773983, 0.2629450324081606, 0.07770982165370258, 0.10400096330070689, 0.16570540024868904, 0.15398659923624608, 0.11653102844232514, 0.15227181867005365, 0.09211314797040918, 0.1432206430622647, 0.13813810933741832, 0.13016868052223038, 0.14527123060918626, 0.1236149209040788, 0.16586221844678925, 0.15146909642123407, 0.11071366318050893, 0.33019480445692617, 0.15378433670247757, 0.1421462507137368, 0.12792633350698218, 0.15595058820420699, 0.14208295652943273, 0.29281651661280667, 0.1110830937602347, 0.15174265109723614, 0.18128287888342337, 0.13156665308821586, 0.13943515748025911, 0.19891269174554657, 0.15209175736433075, 0.15078589921036076, 0.17120365924652547, 0.11490260896783684, 0.15111733948992145, 0.1537478862390403, 0.08358497292764726, 0.2365365260911565, 0.11076723570905386, 0.07947363184704896, 0.12865714308234955, 0.1854722460191096, 0.22389311824114094, 0.24003059182676578, 0.18655521855238946, 0.3034726464219632, 0.1964099437839562, 0.12828094794625236, 0.11933070442248737, 0.14527686901630896, 0.22351640216525526, 0.1352412551040611, 0.23185638770941766, 0.11063983528724602, 0.13036971731532004, 0.16298482284670876, 0.11746358727255177, 0.10712742940672945, 0.11625605650366315, 0.216549736477675, 0.14429146544106547, 0.1457364298403263, 0.10871411241110294, 0.1734112028873736, 0.1785712340666402, 0.09499176165028926, 0.18069219445028614, 0.1320791659095595, 0.18515195997972644, 0.1864514749256834, 0.14045393184548424, 0.18137113221230047, 0.15569042474512132, 0.1626627135180658, 0.13012259267270565, 0.18871638323030165, 0.12112335016530369, 0.17047700952858696, 0.11902486680135613, 0.24239362067272588, 0.1939356636496321, 0.19394174638775089, 0.12630803405397362, 0.1632208392144211, 0.21538119192325303, 0.08853878855945603, 0.13883802258679945, 0.20756698784328279, 0.16580706011624108, 0.3175956305236586, 0.15277939788516492, 0.13010739348828793, 0.27625835350444244, 0.13340747043971093, 0.17027790327706646, 0.16885491027947397, 0.13437476369642443, 0.13606723578226182, 0.1642228362541045, 0.10169545999698101, 0.1488900307806269, 0.1812017042069666, 0.1347811120532213, 0.1198471166313656, 0.12102674647805192, 0.10977876012123401, 0.20463444923441257, 0.10543828980336267, 0.17131471135202916, 0.11603572961664009, 0.14896072537427948, 0.17880660692049613, 0.14785729829342137, 0.13421583109565322, 0.14110052537533546, 0.08694649013059755, 0.16329806087718857, 0.0946621906252638, 0.13333579525351524, 0.21805943530653754, 0.09918696637595854, 0.20247634890819752, 0.1196968867894142, 0.22207451743945, 0.17808492145230695, 0.22218984431557118, 0.07084290061386363, 0.1845821591034051, 0.08782693199933538, 0.19286804351835482, 0.2553742451052512, 0.1595394803030837, 0.18267418648446762, 0.06472809405456628, 0.0895394372843927, 0.07967590970257599, 0.22084065622860388, 0.17266224468908004, 0.1147740823967803, 0.25527152803636366, 0.06459374521528521, 0.24872090937870167, 0.13773137793665932, 0.16148178898278745, 0.15525545534347335, 0.16794416963333086, 0.1577380858361721, 0.2039654706154139, 0.15138807496236217, 0.10011688986372563, 0.18505428376938068], [0.037771470979937626, 0.03967496198451808, 0.053704203737358895, 0.038007969983042254, 0.11154599472760193, 0.07235734918785673, 0.03253145256049691, 0.06591439652707308, 0.07336787278613738, 0.01775672490287933, 0.011782916826045802, 0.044795646887993625, 0.02781834366971687, 0.06394507175671958, 0.036343360515010935, 0.004193316318935925, 0.04625948003282951, 0.028638586349364732, 0.042037787817178235, 0.020199629906264525, 0.028767001837672248, 0.028682044602089354, 0.03087125192846983, 0.0270434687169449, 0.01600989983642414, 0.04764556291423017, 0.05340370191862026, 0.0383327606194202, 0.054206738263488784, 0.01567610670932599, 0.020646510059915243, 0.051955067958202095, 0.04779999091800663, 0.0444199612003661, 0.032713003907232516, 0.022435890352954308, 0.026787905615844557, 0.02645806454482579, 0.07563294963009896, 0.06608472085527836, 0.048997363361019286, 0.05044191024236141, 0.029094594440633254, 0.049438848340463255, 0.03019766146016698, 0.06254981114198604, 0.02975530888614876, 0.04342226957481715, 0.03986087620198246, 0.048009937313655694, 0.02371214112387069, 0.056984994425288135, 0.059760534805395914, 0.029631601008135947, 0.03331760815795391, 0.03680997317837131, 0.02277371406014408, 0.07641426738231413, 0.056764127446278456, 0.07783342227940598, 0.04340485639629826, 0.04929445225805525, 0.04609448767657723, 0.01631541857345691, 0.08460327231835935, 0.018124711406867833, 0.0059155513994365696, 0.0903982907954243, 0.012055253422248268, 0.02080620300295132, 0.021193498753071315, 0.040797728955024676, 0.01939084024108466, 0.041857209402106466, 0.058602167729048006, 0.04233532870608953, 0.060562084939691334, 0.15816006238662428, 0.00573976630074603, 0.01478376557990428, 0.054226606753804994, 0.042044625151902444, 0.03427886464182408, 0.01114150683861226, 0.06280163956445552, 0.08126151252297625, 0.05076755889721456, 0.0531382562832967, 0.006660209450450156, 0.038948113083719246, 0.06840422824626008, 0.04005476922517823, 0.014844976962664196, 0.04403123669626732, 0.022552023536615798, 0.02837409640872671, 0.03789657696841225, 0.04234706900352913, 0.07478017885718616, 0.04164503752103737, 0.01971902656218698, 0.04054334945976734, 0.03988471685818607, 0.050418356869129405, 0.02156752586034277, 0.06044566638827805, 0.04529409050460785, 0.07302310257669418, 0.04207589303053195, 0.009895899584667097, 0.05013833641104641, 0.023186899751665133, 0.07410016091119859, 0.05581351192367654, 0.040946924578278296, 0.04524933947851101, 0.05206584810249267, 0.04074749656982961, 0.03372628542204057, 0.0404059439296684, 0.028239395169000474, 0.0637570814409804, 0.00993215278046386, 0.019713932077490517, 0.05124666645461994, 0.03703777708353535, 0.016540665660173665, 0.04307946821133937, 0.009398876103542505, 0.051773543424543836, 0.028580982283118273, 0.00143284177606655, 0.014540383276799995, 0.02608203794807196, 0.09021184797729216, 0.08237395645870317, 0.06655510650166581, 0.07735899934965758, 0.07894817213978499, 0.02736339661022348, 0.048976326586618546, 0.005291434889283753, 0.02816066239780236, 0.016115793297367714, 0.05283685431124703, 0.022776190439359318, 0.03221444920786927, 0.005936101229200441, 0.03482793134847476, 0.016452393179098447, 0.01487655031885351, 0.03758296355484955, 0.02127433443562158, 0.0172281778612805, 0.03632667895045973, 0.02755937722301291, 0.10083822293146964, 0.018090543885444923, 0.022648441447545926, 0.06772139109671116, 0.035224634658304915, 0.020014060428366065, 0.03920785519444654, 0.04440029955378944, 0.019919433247958942, 0.008498945915620894, 0.010366051574237645, 0.059862206164266796, 0.0076912756964203815, 0.005122192181466569, 0.058154082902136355, 0.05392945273929546, 0.039231397076359684, 0.02032126360122235, 0.1112571795801482, 0.06363110594271172, 0.016689667846226407, 0.02283445717166028, 0.07314788297780099, 0.052538892073977383, 0.06729641914247506, 0.03245999187892003, 0.06625233323223169, 0.12316361850788518, 0.0075150726010061565, 0.0939405358005916, 0.014020025715111725, 0.04778440102874752, 0.01863465591844532, 0.018488662542715188, 0.06315047003989739, 0.028932028667881127, 0.0339762790639314, 0.02913837445028607, 0.022567352955980648, 0.04266713670785389, 0.015671280355403022, 0.01115082246777151, 0.015114376569286951, 0.04617085515130912, 0.022753615743450584, 0.02255354039070587, 0.07132569688462442, 0.08169704116880894, 0.022738991124976068, 0.013225628926809277, 0.05985331571390552, 0.1296492729095682, 0.051812096799333254, 0.004226969125034709, 0.033804073989872015, 0.05495347097636231, 0.017748849519017725, 0.01624688626297059, 0.030120051007777936, 0.03484498829610887, 0.005928975653894727, 0.01801285682426345, 0.05060398763406181, 0.03474117189105, 0.03544005858261259, 0.04628856839131444, 0.012000518355278239, 0.04414544891445868, 0.04479337160685851, 0.031006956743376873, 0.02380898804403842, 0.08182349930246992, 0.07521970648198359, 0.05130067565328172, 0.04456957434153846, 0.042010059264758905, 0.007310327942362957, 0.06640133733350424, 0.009037582335182497, 0.040621609171672214, 0.054288690519188686, 0.07391515067748486, 0.02372328195750954, 0.046973286286717465, 0.078644456582204, 0.046978330975698854, 0.021764803076944044, 0.08272692380893616, 0.02117237387855928, 0.07492518397949396, 0.10317812358299572, 0.006579918169131082, 0.022422443594663374, 0.03837450475041424, 0.015085192449811487, 0.022081321878959576, 0.0054093056561184995, 0.04922709014687327, 0.018372265058719826, 0.045048804473011725, 0.12724860616388822, 0.10465133364402479, 0.0465831330286399, 0.055929903662012476, 0.027740306123310042, 0.07540930558236376, 0.05496690432811457, 0.04069999911852422, 0.013169642263692955, 0.013411824681585836, 0.017541258843735825, 0.03582978666189217, 0.021286632062026092, 0.03308056140198343, 0.0062985656756697405, 0.047429813402554685, 0.004651423491116974, 0.04660037000693622, 0.061235169789964156, 0.046810722429185145, 0.016311724114442067, 0.04946456591208135, 0.05958623448086362, 0.06359200481505645, 0.0354240243623574, 0.10181910658795988, 0.08468765690321885, 0.027392839284373388, 0.03394392334044941, 0.045419230967039065, 0.053187213132097844, 0.0012535308774057475, 0.05892556408540376, 0.03754111600198573, 0.054485245697921326, 0.054364100384015235, 0.03303294137661015, 0.027677933159734935, 0.019769754989313024, 0.03812250778860143, 0.037291241103723165, 0.05426516395903403, 0.018649860848522475, 0.028088730572152044, 0.14513039300518651, 0.008793043239312548, 0.0461505193473591, 0.08209223528542826, 0.05333336355585245, 0.04407823235998231, 0.031129113293343016, 0.06347409239219082, 0.015608559779432273, 0.027426284767927665, 0.05004371689151853, 0.009702954595277627, 0.00709292320196607, 0.0086762550504758, 0.027304063100487958, 0.0544780291496746, 0.048559957799772104, 0.010785769122923094, 0.0394830186550896, 0.08442262878581401, 0.05650561490666963, 0.07023561505540725, 0.00834033602938777, 0.04231460219729812, 0.03248150745827345, 0.026178572687410542, 0.03181363583632535, 0.026838570840716846, 0.03192144738990934, 0.013764842785143805, 0.07045379689624233, 0.06610871472906682, 0.026562499565883513, 0.03754352534850759, 0.04386709086717137, 0.08113509269371148, 0.053641832689003605, 0.027794298084993518, 0.03723164712409339, 0.03747011114272379, 0.012118305331246268, 0.011538362408417368, 0.06533157981691823, 0.08885892138125435, 0.01389894264584948, 0.04252138848025953, 0.0127392033145072, 0.08150614737983673, 0.0450055779618842, 0.05622002498937711, 0.02321690933087901, 0.06242244519413479, 0.10275108319136406, 0.1206149972013889, 0.229379502876151, 0.17653776092394707, 0.21229408741477998, 0.14353325290064659, 0.11043106866700035, 0.17668215317591546, 0.13442265951345045, 0.12678801112117308, 0.08867584934998905, 0.09825198670789119, 0.13235629055528872, 0.11972996646598463, 0.13676402339291188, 0.08203863977424561, 0.12855600415458604, 0.1350752744943865, 0.10778353774860021, 0.11891068905712136, 0.13749859445998747, 0.1149811712844718, 0.13976292053778328, 0.14182073995471, 0.21451598754332912, 0.07326144785169633, 0.19786940256674446, 0.12340069207693301, 0.2584511300008143, 0.15090468880389968, 0.14696966285907453, 0.25620512874616735, 0.15442294759615777, 0.1667299355951048, 0.23000980937673202, 0.09210474398587981, 0.22043151931176264, 0.09843331205868915, 0.1271692088114158, 0.14737853930602152, 0.11160136756276894, 0.13662678640215628, 0.08976353332400323, 0.21758553331657765, 0.1307405038706718, 0.15846075189690437, 0.04512617552292444, 0.1723049566029541, 0.19000077560063333, 0.20627942386894457, 0.08170243442779587, 0.24911412698847635, 0.14617008157074451, 0.14138734869418607, 0.12897444137882802, 0.12105785730865695, 0.09905153735270424, 0.12055428473338967, 0.11801038252850694, 0.22202675951825035, 0.16410311203329794, 0.18403135720760594, 0.1781731288159086, 0.11741916183382274, 0.17340179532766345, 0.11631804067761668, 0.09287019605718314, 0.21616319915460003, 0.14781139430499848, 0.1797731800545608, 0.1770728580172985, 0.10146665251663617, 0.16722784678061164, 0.16380228462719149, 0.0873511913983572, 0.07925807768779417, 0.13757995299754605, 0.21669897040532482, 0.07963089437614526, 0.07960982695822755, 0.203551170265963, 0.18209790450430688, 0.16292862263658356, 0.09820196882731493, 0.11001248588605274, 0.1567066250549209, 0.17235429266527777, 0.1524020842606983, 0.20337863194365657, 0.09248231808024068, 0.17332163188726674, 0.13111202587043086, 0.1166251959699777, 0.13079423727768083, 0.11808542850156946, 0.1919185541450016, 0.07171634043897353, 0.16704013991740443, 0.20250120080046116, 0.15128759487021357, 0.12176863368480437, 0.23659387543316812, 0.1458908425223443, 0.10056295221851719, 0.12315735190866456, 0.1604241739598013, 0.14274337028543796, 0.1233909014732607, 0.19928303396990224, 0.14851596536895922, 0.19426862078328289, 0.11609544617033775, 0.23864510649394607, 0.13049632100568664, 0.2131797003770067, 0.11010868354670464, 0.15022765093993756, 0.11494254513132958, 0.17290167780893465, 0.12495915240217602, 0.14103856418401967, 0.09239672307646082, 0.13560739916659173, 0.10690728638080821, 0.16344896487651334, 0.11951075040645177, 0.1291124444575079, 0.17333555936573014, 0.18009135169127297, 0.19504842168140799, 0.1356091305253006, 0.11199849222095744, 0.11349840810702694, 0.10311603215673279, 0.17057848553503716, 0.10784097902116277, 0.1301610043212291, 0.150283636645444, 0.16631925118065652, 0.13176631092304184, 0.1502368746385459, 0.15468237561083611, 0.09724707853409553, 0.1570192195715443, 0.14869101645965732, 0.16037915863337057, 0.1202570349578896, 0.11770408525462113, 0.100937400674147, 0.08957911297799119, 0.08889786163044554, 0.15002397880438836, 0.13156433950268454, 0.11992893482167875, 0.2668651656037377, 0.17163925684027134, 0.18153034060472445, 0.13609380371147586, 0.1033768697731918, 0.1729595634124933, 0.12766788608484692, 0.13280734780334658, 0.1720694611750303, 0.11201660253948743, 0.08191489359183658, 0.15540338692165193, 0.1208337919125634, 0.1751162541369277, 0.07860886413724193, 0.1274611495976006, 0.0786101664867132, 0.20116771751594162, 0.08744995545355544, 0.10084032201238217, 0.17450909881341845, 0.17360087093566695], [0.05383428546690172, 0.04060907597323099, 0.0250520040055797, 0.05956505214975727, 0.018282489130093206, 0.005534938808846018, 0.07484121308211358, 0.027756248413014318, 0.05616244965142781, 0.04965377813805977, 0.0487996360677625, 0.05426153653271256, 0.039172791350152225, 0.06399460700190356, 0.011757810209547321, 0.02274350338285008, 0.11270287942381636, 0.06326702265669742, 0.008222618958942832, 0.04306385150900291, 0.04389652396522222, 0.011103860320403211, 0.09858047754894342, 0.054822274588889656, 0.028279566904529933, 0.01828831522875736, 0.10432517937114162, 0.03572833363807971, 0.01623345674165795, 0.05505266787123777, 0.0445433626432092, 0.01233784793575685, 0.04295596334662649, 0.024801523897856958, 0.03539553738289303, 0.026329978474325715, 0.031708279594538674, 0.025656177331843687, 0.041614413156264254, 0.024871165120613672, 0.01969821195328428, 0.025607798879425374, 0.025721026674634027, 0.02275950887480811, 0.012821642993648928, 0.014428312274357005, 0.013305970482648382, 0.009735795826981626, 0.109365654868945, 0.040956665386235526, 0.006695485884143461, 0.045492871168760524, 0.02461478230543435, 0.007171368211387627, 0.05834702597630601, 0.058109760885277105, 0.009694052653597489, 0.041743690493486585, 0.010678772495368557, 0.009511622220968768, 0.0732960750258738, 0.00604031695758984, 0.07595559522028893, 0.02970033058626277, 0.030599129836886164, 0.08135272295124109, 0.01197369761704918, 0.033668032096278284, 0.02648122912843622, 0.003907773803333722, 0.1444539986550808, 0.017961841114165805, 0.042872501897715756, 0.0322930421680212, 0.05088815262781517, 0.01428009149798703, 0.04202249287176998, 0.019074698737371835, 0.021884676684895833, 0.04592029077391471, 0.03288796306737969, 0.02074884983050006, 0.07977532493250986, 0.04856954539014448, 0.04253224777658621, 0.03076235444525317, 0.07134476481305976, 0.02402085157471799, 0.050825578566159935, 0.007728575559843693, 0.024852867110542236, 0.031147212120554144, 0.053173791271664446, 0.028948173970885338, 0.03324802439179152, 0.0328723578563621, 0.08553986077106769, 0.06037407164131442, 0.023968039388437907, 0.04316181117188066, 0.0320293604501433, 0.07096363607073022, 0.008284119539894164, 0.04139279158064916, 0.035325854025300474, 0.029463362354304523, 0.04406217515708939, 0.010888122300046587, 0.03201074068314366, 0.024656750517146244, 0.008326252460509779, 0.03499116553294082, 0.03201287423801278, 0.03982013947660885, 0.03350675526645876, 0.023489787934287906, 0.012038615907752707, 0.029452654360342893, 0.06908983863409489, 0.03655456329485582, 0.02075078228728906, 0.08625487361343638, 0.013759292478132394, 0.03508536753454997, 0.024961004251494043, 0.01566016920767124, 0.020786600728188793, 0.003708093225272493, 0.05472503887910036, 0.06546817329381743, 0.028467794707525643, 0.06907066345335015, 0.06508539746245069, 0.022048726753001253, 0.05516347865904531, 0.0783558482784898, 0.025581387998235804, 0.06263437958794736, 0.06527640616461154, 0.02723059718376927, 0.050301084129680554, 0.07078210387619273, 0.005314155620703053, 0.03403513376871425, 0.09354790807851861, 0.02196027998692326, 0.02563496052678074, 0.03411729669859333, 0.05727768214719911, 0.05060651189377231, 0.018816423685019536, 0.028689701650892536, 0.020972103173393878, 0.04227327941466243, 0.02949250242372434, 0.10471360127051031, 0.048576601059927095, 0.021735743446756276, 0.026613128401579398, 0.025445535711403337, 0.0642661890015006, 0.05147916647875982, 0.05329914240827484, 0.03895066798694673, 0.02437436859303665, 0.05691879676775106, 0.008200617871367404, 0.01629392980718084, 0.02438521639804446, 0.05994825315992198, 0.051744290357155186, 0.058596816604896906, 0.02473327503990262, 0.0562271457766333, 0.06210832233210245, 0.04330420010392705, 0.035361343048392765, 0.043961323512297486, 0.050488005752765366, 0.01926667845597671, 0.050248323654335354, 0.04226603988377799, 0.02996325004665602, 0.029275603780162432, 0.07288431808833154, 0.049242599596900326, 0.12999626477399182, 0.04269250187902682, 0.01915233600283823, 0.06680794616019534, 0.02378444450216428, 0.050168937793181795, 0.06447668698045515, 0.011819621056107985, 0.04572876113196535, 0.02563793677836657, 0.011497989574807787, 0.0314378199137507, 0.040128509018329844, 0.03849959158669076, 0.08586183986476353, 0.03459589097708945, 0.044382679531530994, 0.0506130964194815, 0.021096150045313185, 0.006071406241972, 0.06689781593459268, 0.019731408458263166, 0.01923353940759215, 0.05135263556674604, 0.027639818370282173, 0.03913618766913011, 0.016593596590082013, 0.03811465538737755, 0.024146279320120815, 0.031737800792700825, 0.01799108843589502, 0.011910529837252633, 0.025173834968178023, 0.030241592772184845, 0.06568053286642798, 0.03800589005432783, 0.015553939625650886, 0.06300050066784024, 0.025350282254118114, 0.03292224550199124, 0.06620051504503335, 0.04911833630514242, 0.049359328413922945, 0.01740563638328064, 0.04341470828700451, 0.06283627056907262, 0.04943060140395838, 0.03128330189464314, 0.029264591266250903, 0.04536194291206137, 0.02597390655277958, 0.006774083632344921, 0.05758092656070667, 0.012445812706925697, 0.07132836287060092, 0.024454643116182378, 0.049087363370363755, 0.009163038808882478, 0.006636637403824998, 0.07532846032371444, 0.04031995056016792, 0.02348849133047606, 0.07406926458521236, 0.07324395806438501, 0.033485465683043, 0.09410187391744507, 0.014989431459276427, 0.03763543674722314, 0.005196461532895844, 0.02558404440811325, 0.03164165675820362, 0.014267151315336027, 0.06772441714401208, 0.11872528811856625, 0.03291442757472396, 0.08343248312631923, 0.02652720589521191, 0.019499463847868388, 0.028812358073229273, 0.05605895117285752, 0.010335710661996518, 0.05465985245762333, 0.011957416333438409, 0.03822526316188517, 0.03416039680521335, 0.02588398315222754, 0.06429929166070877, 0.06410138816722939, 0.02255359593208038, 0.01816057389782321, 0.0165757869610623, 0.0033435919425345117, 0.049785644852466164, 0.0817163082801046, 0.031260683148678754, 0.017665730894453103, 0.09045483574511544, 0.05810493836179376, 0.03742265199581462, 0.04620100837200881, 0.013763893793727604, 0.05759697227228073, 0.03648407171450315, 0.05246018803107643, 0.010164012163577062, 0.02177732478406641, 0.025220673583868532, 0.04060156831157304, 0.0215849811736975, 0.026253890621686177, 0.03695244254964975, 0.03128685845783161, 0.04045025062476916, 0.057025577933076894, 0.02338174463910682, 0.02066299052638633, 0.06812655967810462, 0.0016204114616548103, 0.0704126273311915, 0.10021675708553485, 0.05848216005570947, 0.057137327178591685, 0.03752471788996651, 0.07563344758724974, 0.08674843341953332, 0.019054046922153043, 0.05793873558662111, 0.09623458608984949, 0.06526019574413378, 0.03182930808003632, 0.012117991235197313, 0.01658143685950387, 0.02188677768102817, 0.05005864411472313, 0.01528130233993814, 0.03945578039894181, 0.029802084299585516, 0.033760135016974904, 0.07342182835864444, 0.033335837220112165, 0.0722398849264268, 0.049410246447810245, 0.034826085076577244, 0.028158053868420185, 0.030685716924527963, 0.08849340551082166, 0.02622046812076963, 0.031122603461206443, 0.07015936632430361, 0.02694363405387248, 0.025875830061493382, 0.04799226366524254, 0.08608497063358946, 0.11043818562381691, 0.03982052635101061, 0.08653675566517538, 0.022926634785929517, 0.018742097834605845, 0.036178222602053035, 0.02539550059384877, 0.04612713451347044, 0.016614118170353676, 0.024760061304175088, 0.05433028909347711, 0.04834736073990503, 0.020792210407014337, 0.1153093173859581, 0.11662816073024466, 0.12403433105998463, 0.14915341180899452, 0.20552927057348913, 0.19540154224922582, 0.22083230587022923, 0.10830936517806784, 0.23629030543229274, 0.1402173026074325, 0.21952571227185189, 0.25758860692862545, 0.10533990113124733, 0.1515045203268528, 0.11092928628767691, 0.102786798210394, 0.16851305120414303, 0.24288748691399253, 0.11930651902671784, 0.15631653308387727, 0.09972034743235958, 0.24533187429751122, 0.12291866955497574, 0.1623171159336644, 0.14681601626498086, 0.1368324810098256, 0.2128380251627776, 0.26024114040117113, 0.07702537571951266, 0.17330748990418451, 0.15375694139830529, 0.14205801270661816, 0.20691947500792243, 0.15114462754178434, 0.14974780410768526, 0.160376017672881, 0.08865429929667905, 0.13743024409538315, 0.18542097941521676, 0.1435373897754377, 0.09562465752805434, 0.05165219509733781, 0.14299912107807977, 0.06114778214044148, 0.14135863571878404, 0.12096863870899524, 0.1771222706884146, 0.16751136059962934, 0.1721736797762494, 0.15595239617170828, 0.168552489410485, 0.10653682158238466, 0.1300821891955791, 0.09169474905056339, 0.1433654490017122, 0.28741706763544395, 0.11085861467666204, 0.16537838795733067, 0.1123083211601742, 0.11749624560076384, 0.22857780718514997, 0.07250597790604638, 0.15311819260879872, 0.13724843610919293, 0.22341921625118102, 0.1531077738130285, 0.14039475921421282, 0.19485541348976476, 0.1639296084402069, 0.14045708812773228, 0.2753113768994808, 0.09226991254235468, 0.22951056519823693, 0.12011353902879263, 0.17625410920910298, 0.20707621659723022, 0.07791878745680855, 0.1957707046981781, 0.08286003158577988, 0.2061615689026733, 0.13097492677550163, 0.055534184775165016, 0.17493084553749333, 0.17011299519048584, 0.11469064776094691, 0.20668376507537983, 0.11516060439809678, 0.10740869092724978, 0.07789952034551291, 0.22392282713084455, 0.15424762071380693, 0.09037229743215347, 0.11573101048387828, 0.16618049733581083, 0.1103640359736258, 0.12278577628275081, 0.15786848932264314, 0.22036891460659044, 0.19132906480902628, 0.09867919563886621, 0.13060437004652717, 0.19349980558599197, 0.1011778680126994, 0.11323664352417954, 0.08100206152566018, 0.13867584177322928, 0.13910186326792165, 0.13137140791983376, 0.0980751276496918, 0.09507012478406392, 0.13438473816119856, 0.1311146458911319, 0.10406380549313561, 0.11959452212097184, 0.17754694386836023, 0.1418421444513144, 0.13641560660494914, 0.16047177866341608, 0.13335159198651392, 0.1304552893364622, 0.09499134796281015, 0.1742392213594529, 0.13654821642464207, 0.1703781535428378, 0.15961500125065928, 0.11453496337297464, 0.12599140225398925, 0.09190329350531103, 0.151664050476205, 0.19534270669664108, 0.18838731782330623, 0.17165882272585747, 0.21185845917751714, 0.24703337089909663, 0.18497913054400877, 0.18437825714147862, 0.16939040573854602, 0.14074705240707244, 0.17392437454433213, 0.18237567266389249, 0.15873200830913362, 0.20062420877718157, 0.07372997956530702, 0.10880274112306296, 0.12301135087205518, 0.12399205066744359, 0.11104074441978048, 0.23430003964852905, 0.1727882355091072, 0.12173675676627506, 0.17572921640690298, 0.13694558623096637, 0.1896383700471732, 0.131109727606658, 0.09709908566888302, 0.15447747773460804, 0.1516274008299074, 0.15536777915493136, 0.12707363168198255, 0.10776381864542924, 0.12377883307635786, 0.125674678523454, 0.1694547571241856, 0.21845692768692973, 0.20023572559077896, 0.13648260865480671, 0.087998213937446, 0.07523179534942874, 0.1702935927577557, 0.1359553869453169, 0.13821185296100957, 0.11714524709649625, 0.0833155168220401, 0.1699236335773622, 0.14074682258069515, 0.19543633796274665], [0.06190887517145565, 0.018946020863950253, 0.029180727621179917, 0.011372325299758346, 0.01903217894235446, 0.03393754182804016, 0.03497589357017029, 0.03545588595912822, 0.07367625381917724, 0.012406667529214776, 0.026124059785938552, 0.0759425410820592, 0.0034122511363332913, 0.06681268824444664, 0.05638726581368716, 0.07735051109545654, 0.05988804247951316, 0.05253229222650971, 0.030474230692151095, 0.059034168539989385, 0.019886581482545986, 0.0751528959541071, 0.059104889946719336, 0.021037952260925405, 0.030584202613681558, 0.029105003660304413, 0.047786366044273304, 0.15066620563307118, 0.03584546465126257, 0.02460006384118911, 0.021080740186716282, 0.06042016332127875, 0.04533974168401572, 0.04475711266540232, 0.014955050390844625, 0.05550725295418694, 0.0021471452688978567, 0.022849516545031822, 0.0868193731613217, 0.07672146863995061, 0.03393944555653199, 0.08633173521487944, 0.03328415309830058, 0.07291285486351098, 0.03268485017601521, 0.010383083624014211, 0.037560992153181184, 0.00856651965859196, 0.019931294204246615, 0.07325378697245352, 0.017839856933982625, 0.016529005801966114, 0.026836473675024126, 0.08508020035562017, 0.03789802870502876, 0.05531470441529828, 0.028190940107789733, 0.052525297843761025, 0.030500911619333975, 0.00649687088650441, 0.054450741097811735, 0.036846128697957725, 0.059504351173076904, 0.06577685310114777, 0.03332367557431421, 0.06407892646928949, 0.059266691546766996, 0.05781584359224766, 0.03152026055050233, 0.04461270509167545, 0.020277175241180008, 0.057047706382769736, 0.021150831486128514, 0.07811722721183494, 0.034690755644753095, 0.059930269245899496, 0.033015440097979964, 0.041725695088145234, 0.02366671594040048, 0.02854582267783342, 0.06021611963308627, 0.011041859867081288, 0.03781244519256777, 0.048583292837945685, 0.0016504278638392628, 0.03900393408032195, 0.050394343843142834, 0.05045961836473115, 0.0245332341611145, 0.05244935171738748, 0.02872636853416841, 0.055136497042352156, 0.014912106374639177, 0.0435421355218897, 0.034358139420228626, 0.04095566947193396, 0.021573007219440995, 0.008277198893108196, 0.09106094152816842, 0.03598012375615297, 0.058195907472362446, 0.005320948426566658, 0.05276587243462282, 0.03969732409102782, 0.04093901855089972, 0.03275721101090312, 0.0800539204670537, 0.07302487223979927, 0.018741245561790083, 0.03820277082042829, 0.018174532019803603, 0.11607047936488545, 0.04070264212186298, 0.030885878462164156, 0.021345088401088314, 0.028953082679260164, 0.02420969416327294, 0.05400277118408873, 0.03470771300095705, 0.038539872489749424, 0.044826696431564714, 0.03147614346216283, 0.024439357746873173, 0.03388324151596716, 0.03984846940804874, 0.015441041248249672, 0.04254972990301829, 0.020927788817413875, 0.011787910761702205, 0.026380155318146272, 0.008640180927731337, 0.019497433714869044, 0.006939195689835376, 0.02675633704770477, 0.0631476968016115, 0.006833105918861205, 0.022606406203140656, 0.02288591912797382, 0.026332977708549272, 0.09591269892670455, 0.03928249131046957, 0.010317444253051955, 0.06429108685903973, 0.03584205939043914, 0.04587364368020527, 0.031717187281878244, 0.07464812828167793, 0.07180534453401644, 0.020179954853149194, 0.04984141222291416, 0.053686426667075966, 0.036837602139360485, 0.05045415615783103, 0.03581858645643919, 0.014652076980940279, 0.07821763835607037, 0.110019120207477, 0.03886639448483625, 0.08779022106600386, 0.0257644945034577, 0.029199326320761637, 0.05000696382335117, 0.09166699368506671, 0.06833589320341427, 0.03413061513715694, 0.05083819220383322, 0.02311096511661045, 0.019838045982103196, 0.07355164195741377, 0.05157284754058046, 0.009675436717037474, 0.043075296862591664, 0.07983351697123821, 0.03502681926493684, 0.013877014336626858, 0.037991954914985165, 0.025591285854217508, 0.20667446476797904, 0.006300782063795675, 0.10931004454652149, 0.049399900430392836, 0.028501820502682563, 0.044088976743120345, 0.07932693367042849, 0.06282582496022505, 0.09327456024625609, 0.03064647981626613, 0.012646753739024843, 0.06450822682029779, 0.05170586338687328, 0.020436036978818236, 0.039536564370557185, 0.06834529310224519, 0.06841776501988212, 0.020544264135101152, 0.0631868745380592, 0.00945549670441617, 0.08110202833889954, 0.10385358330583382, 0.012080270981025553, 0.0575862815152974, 0.014640247625779482, 0.018939103089994, 0.07064862837714535, 0.07015290820310194, 0.0497135253352744, 0.04166318997440319, 0.04268010274597234, 0.017888867408938466, 0.01695039246471659, 0.06881613074050796, 0.04157939527724539, 0.041256837787166725, 0.09991273509278413, 0.010391995141793405, 0.010665432989387023, 0.014807712530807383, 0.020725723551285845, 0.03576289569478362, 0.09112442723445355, 0.058386433539131, 0.02913650519575083, 0.005860904432577832, 0.02599616523741955, 0.05067284744713576, 0.01917235579551949, 0.0774106719801503, 0.05640638353783758, 0.07661121326588816, 0.09422909813903033, 0.07062798230758599, 0.05501737037012654, 0.01998440708003698, 0.015992810330053252, 0.04475330137797902, 0.07853692082027275, 0.010194874973216606, 0.015134332202104552, 0.023045148587815707, 0.09266710614845639, 0.04994937699408301, 0.051019720567931096, 0.008370424132613886, 0.033814603868391246, 0.0445456187721462, 0.051879286540732275, 0.042900452615633126, 0.01737402568030502, 0.03930966827958342, 0.03465184986951851, 0.04571610152901662, 0.03824739544201763, 0.027551034525517496, 0.020408329493816824, 0.03226638613869587, 0.0382912578061223, 0.03417559215919145, 0.030255338304766247, 0.05394121984981241, 0.07769580990556749, 0.017427069608182195, 0.0477031612348172, 0.04122446674192625, 0.0177580444893289, 0.004298178434011437, 0.036584433063023516, 0.07170437414559626, 0.04957666755804131, 0.05498783385020591, 0.050263710530294534, 0.011262686626474944, 0.047374984489813934, 0.060496392900184284, 0.019553852260052677, 0.04028639207864481, 0.01857806308825891, 0.09368855416053727, 0.05334259108490041, 0.0887864801071344, 0.08047243430008812, 0.033170726120231614, 0.009543388056749058, 0.03888956481410612, 0.020081635128947038, 0.027522806100727572, 0.023709643677237536, 0.06301389954563591, 0.06083626780779131, 0.018607329562186234, 0.012144800482107507, 0.022095548131713466, 0.01098881306637439, 0.010299815612304355, 0.05418012436899928, 0.03915876044981903, 0.060377384971586935, 0.05440508608796424, 0.01692695208945342, 0.03504311395508628, 0.11414661808239837, 0.04103674072652094, 0.03549795567749008, 0.049251026564067414, 0.0568324126934092, 0.07157882765656517, 0.06783374555168614, 0.08715792273681972, 0.04338594168544777, 0.04734889153511294, 0.028939861916906895, 0.018923306356995337, 0.0341747418015955, 0.047364416306898485, 0.028922249555527687, 0.015563876743638709, 0.019506146049787922, 0.10884360425294408, 0.03294301797605811, 0.035813108927780585, 0.028824874034692204, 0.06997384281168062, 0.007880778078200116, 0.12829300617018055, 0.0772479166006369, 0.03825032189788838, 0.028838025849132292, 0.047440331789755055, 0.039318405512359836, 0.03703676967791492, 0.05610361026840345, 0.01821543919974037, 0.05819245241582394, 0.11641574753147942, 0.054551688503594174, 0.02654359251591227, 0.05779301034166448, 0.009128861711360514, 0.1120847307385937, 0.02811876504922346, 0.06471140099869621, 0.05180581870879378, 0.020389546933133277, 0.014664233838688704, 0.013024481050970574, 0.014495388060177286, 0.05778359895151469, 0.01328712280449127, 0.018344262629867564, 0.019217677557119922, 0.054342883578952283, 0.046069926897724794, 0.01806480141596929, 0.14322065838402318, 0.31061010375138254, 0.11560767798894837, 0.15950993995272345, 0.13307475845419592, 0.13701695498199234, 0.13371203635488788, 0.23529693454263673, 0.1776471481688561, 0.20783550166074308, 0.13013002372557117, 0.14777224721206775, 0.14133075011834023, 0.11655889872101047, 0.09088560698493835, 0.22826464576346261, 0.18583656679238045, 0.09466410584507451, 0.197866169675704, 0.12712237785660452, 0.073728684876715, 0.18201688304543498, 0.2058808896089754, 0.10074547266647702, 0.10138160909616178, 0.14824561294048064, 0.10207021488778054, 0.2818388137365541, 0.15294997502238522, 0.21054256527173906, 0.12501542922109365, 0.13460195473124906, 0.09508923867777472, 0.1082620898922605, 0.16201114041670678, 0.12340236214860795, 0.1336364081550029, 0.12950143326194058, 0.1316281699485356, 0.12556394817487848, 0.1730821068368612, 0.16096742222866706, 0.09614820201550761, 0.19087963166736788, 0.14918434643937697, 0.08924294593593768, 0.10610682409136526, 0.14997871832982188, 0.193147910758853, 0.12038109523634757, 0.23020654075568725, 0.17406072287309557, 0.17458757686038173, 0.18520707234499917, 0.20123427523480308, 0.2944108375137852, 0.12541303651467448, 0.1759191449250906, 0.13941966718243015, 0.14207805356671735, 0.14231100558273255, 0.13049661211909788, 0.11801102604236334, 0.22396270966818257, 0.06829440954231447, 0.20597280483813057, 0.21602965470763946, 0.16590806114817822, 0.12697340439884894, 0.13541270558151508, 0.09609196350098619, 0.1651077290936824, 0.17998017701170138, 0.170929997318214, 0.13957876832254473, 0.21727848527652605, 0.12533941546515112, 0.19148283397718785, 0.15575116019575827, 0.1432532171208051, 0.18002122400268433, 0.14187304843817988, 0.20001965815261488, 0.10010103184369304, 0.14839538312967748, 0.1456833246254152, 0.16766051791848677, 0.07042822488132985, 0.0620389262574815, 0.09450846742237769, 0.18042688288034933, 0.11296038455780476, 0.14868200726566777, 0.12493439244046328, 0.17880512070992302, 0.14163873278565947, 0.1645541692813558, 0.1881571390455769, 0.2392506836763313, 0.09122685318992985, 0.15566731953332502, 0.13708453925867237, 0.15118029659553883, 0.12559047779969632, 0.21405777503405848, 0.15260204853069398, 0.2151072695250473, 0.14168670521147791, 0.11445339033079725, 0.15205480128286347, 0.14467309980142504, 0.2261729039732487, 0.15036812082173365, 0.10473643835153311, 0.08512009055383744, 0.06926027021460957, 0.16718447088233887, 0.14392829379968106, 0.13823408483257218, 0.12512877192949096, 0.12767989834349963, 0.14266896782623184, 0.1601555375682731, 0.207510327980403, 0.20197983200271286, 0.1856806372562724, 0.10036701757100322, 0.1236077809646245, 0.1547336881800044, 0.17552813364853784, 0.13332032027744478, 0.12401359305987436, 0.17026564587027798, 0.15781890811218371, 0.11834251228719951, 0.15938111460737645, 0.13250166339980018, 0.14164458569740096, 0.11236316539467343, 0.18939368156415803, 0.1608165029075838, 0.16027345382157834, 0.12201937426242138, 0.12433267634121642, 0.11356947042288319, 0.13316291985252213, 0.21807232090542394, 0.21087539983132195, 0.15750421451464777, 0.23187855829394635, 0.17298986985077783, 0.1177660234632992, 0.31339924602258595, 0.10000501804414297, 0.1455923133800107, 0.16159993506247, 0.16491611518206137, 0.12998059061506104, 0.17151599329325462, 0.17841493680832848, 0.08873637795688645, 0.24653913693562632, 0.21274577285493576, 0.22205473704924508, 0.1341124551911508, 0.159131936849125, 0.1623454458651043, 0.2211075612614232, 0.2793132363548202, 0.10252096570066868, 0.17509253605479197, 0.11960542355213435, 0.2064495719969273, 0.13878297150856064, 0.11617321175553146, 0.12103440735729472], [0.01894554397421739, 0.042936520035108255, 0.04900610442423532, 0.04007773271070854, 0.030929771469785806, 0.03750694081968358, 0.028473668686685064, 0.0366474820991918, 0.03282378788196272, 0.0619521246652209, 0.014885269357041727, 0.08121553192576093, 0.012455592776889042, 0.044790085089663347, 0.036999625904906186, 0.07329047492314732, 0.03856589649653724, 0.029829335962271983, 0.028264141724174543, 0.04542993704578088, 0.018411444710387338, 0.07925319770771651, 0.06698670511644694, 0.0013503318322980176, 0.028768551250499104, 0.02510544821439732, 0.045220411998490175, 0.013779248110949995, 0.05490609226868518, 0.12608179296817512, 0.042944778462932, 0.025445501237446745, 0.010635083458656746, 0.008087485837149284, 0.07619461465266443, 0.009720933721250585, 0.039794395091913404, 0.03262513745275717, 0.04246716094653934, 0.02502171288905365, 0.01560573866065111, 0.024123480543494228, 0.02994273995770322, 0.025741306937209545, 0.027774259140114152, 0.03855585308384992, 0.07179389918042768, 0.023890756438636494, 0.027661536962935523, 0.020323025603448192, 0.031608496642401146, 0.03215845201104399, 0.036624809727072716, 0.022785069398401726, 0.03243815071219879, 0.04839998714986348, 0.08159218671461267, 0.013243268101265835, 0.08279691360169843, 0.07727413212940579, 0.027196029381405924, 0.036456684071210124, 0.08677968980684396, 0.030490372164715684, 0.043280022369036754, 0.013323330035012577, 0.054429447683956356, 0.0704107121113808, 0.0312216931037725, 0.12270312305660018, 0.015486031676822854, 0.01806753251941935, 0.04838151677000908, 0.039661218367156484, 0.04159606918091736, 0.02748155992688431, 0.04763591403682386, 0.02343856346523089, 0.015065724240435709, 0.016879826190791303, 0.06228519671206033, 0.08183165047798427, 0.024855412437670657, 0.0440342397609305, 0.09882567931086787, 0.059290670098796974, 0.0193624088029948, 0.04315679329597662, 0.02791437853668486, 0.014597424268422109, 0.036885949948261824, 0.02636588884577636, 0.019786685532439622, 0.02370413358984215, 0.11612057385425414, 0.03540309867070567, 0.026651930754944205, 0.10339850409617347, 0.03486354677607456, 0.11728076805030146, 0.0029572415927935753, 0.06333607782219207, 0.05057479968414672, 0.08040075911389244, 0.04541560737115722, 0.014746172687849932, 0.019044905577996568, 0.0459151158499862, 0.010655304349418129, 0.04819222410479861, 0.03028459520259452, 0.05493299344614629, 0.03288496383315614, 0.051502624091001294, 0.024130461519704233, 0.009595694624999119, 0.020873681942541755, 0.02471704738244655, 0.0464514616666542, 0.0745407380764523, 0.03899120169902041, 0.05876433705129932, 0.06468493266091233, 0.045863538980484016, 0.045163564444068945, 0.025882232641320557, 0.09317810211570994, 0.02961649949992857, 0.033885673845126744, 0.028344243877537312, 0.047734563178833456, 0.057998172518226414, 0.05881872546348361, 0.06783196056682257, 0.10061422648328928, 0.038618549719573035, 0.06563785410816632, 0.04122894835628329, 0.016825853381305933, 0.09627957843364247, 0.07305202239583578, 0.017371172002787073, 0.03308254940014693, 0.07766961735943634, 0.039683959687188755, 0.025832151558490533, 0.02616821709389408, 0.0562254986875961, 0.05647983604801759, 0.03377093685670726, 0.0782963385685317, 0.0525507970803207, 0.07558201244401355, 0.044186737223137776, 0.007297381056442617, 0.039597073825256485, 0.04336692355272751, 0.03718308864101287, 0.08275431911310843, 0.05664365628974573, 0.060398337476316004, 0.0301148186272551, 0.047381653285194794, 0.03145861920089491, 0.041034181992853844, 0.02711068527142127, 0.05151428011876922, 0.06501248121381768, 0.018470898878970937, 0.046796867729074536, 0.07642044205098383, 0.04908346015238955, 0.14057670509622944, 0.036624250482888, 0.0373971987245304, 0.046324325545180234, 0.04858587838469013, 0.017244830697534547, 0.014232077894942656, 0.07585823310599213, 0.013237302191555502, 0.05391678164502787, 0.07426796481013298, 0.020704690607324727, 0.03750827381267183, 0.03494089101290992, 0.024164343673375346, 0.04118357679896778, 0.04128887941459975, 0.04956652838436346, 0.040343810368569634, 0.0412617024454859, 0.046465484906108155, 0.11961529842547833, 0.012856283574365081, 0.024293948513185306, 0.02927638135940558, 0.05840878032388226, 0.049245537544089946, 0.01559953717890406, 0.02528406161394331, 0.0832209662504254, 0.058828301562537114, 0.04800524502511948, 0.10417226822145524, 0.017139085666126302, 0.025862831464638154, 0.022213052612759417, 0.02127815912958355, 0.04376192231692615, 0.061084227486243176, 0.05239468368311083, 0.059962487073555115, 0.02129148905946603, 0.039548005893706314, 0.06056956195783231, 0.06602805333151933, 0.07876192084363393, 0.03402146292970546, 0.038302446520256425, 0.04528079504868196, 0.029819459173708197, 0.09248313013344042, 0.023346207735519257, 0.060592395208415493, 0.04361638093307134, 0.04622966772125614, 0.06881944024034085, 0.05881354670911547, 0.04084139213626904, 0.04030874269383569, 0.058386521639242295, 0.06478053277298328, 0.051652137640743494, 0.08872117111158949, 0.03031256890314962, 0.008300296444025251, 0.044582471431743716, 0.07067695830858524, 0.021287407726049427, 0.11126843341175588, 0.06749814541469659, 0.04733642345414527, 0.04634212176766127, 0.0185677343078198, 0.017655601296874306, 0.0370144841801976, 0.03510956825207799, 0.04255666299873302, 0.06263209664593301, 0.015855897969055562, 0.026338759757157777, 0.02735902033295603, 0.01782840008907501, 0.04957172246049008, 0.029332118086336605, 0.03427981076041057, 0.06946189689540094, 0.02709936057668059, 0.030382204380246903, 0.04137340572572524, 0.015586721485540753, 0.024386717930376053, 0.05584113322378648, 0.03475341014564037, 0.0071974558992341404, 0.049890786589634036, 0.08046621366614297, 0.061006948366881385, 0.04195410803320908, 0.06014459766447545, 0.013663119715338033, 0.047825436528411605, 0.05705512211387677, 0.02155042677787283, 0.09502162375757772, 0.007131463649021763, 0.009869215784654503, 0.014640071425556898, 0.0836972124694336, 0.027006054897942854, 0.07827334060904481, 0.028689213269840808, 0.014588922607682407, 0.05693182792334307, 0.021032731371721434, 0.006561642184087466, 0.02746208405662929, 0.04734679245420041, 0.06472997863086001, 0.04396377882409481, 0.013649500587264137, 0.041112602583222815, 0.03872554155907804, 0.02032566094590772, 0.05690159043297172, 0.016178627828917196, 0.07402484680736258, 0.048017908458507834, 0.06448513693025996, 0.025042106149597995, 0.003260730675631954, 0.06319868761385161, 0.05765506855001854, 0.05690308430442407, 0.060810833688705206, 0.01763830111632424, 0.0384758313697192, 0.06466145206603312, 0.1146589853470364, 0.07354558220193272, 0.05671854521478376, 0.025029519325002067, 0.03342420929261754, 0.03735181950633565, 0.06473144185879538, 0.04585530736573762, 0.04235346200725725, 0.05575495599318416, 0.04436544255323468, 0.0348193128593266, 0.013629680935053096, 0.03172857134843306, 0.0229589541202351, 0.07688025568401621, 0.04867397083510314, 0.07028236940142608, 0.037338305715351336, 0.024711772867087877, 0.016036185270716107, 0.007036849875153313, 0.017434847315833453, 0.026732561508974722, 0.03197808043971177, 0.01844340781380813, 0.0055250107881522955, 0.02917860555762966, 0.013197378476991529, 0.031150770598962426, 0.024414538413346298, 0.03297656496626235, 0.05126742360692832, 0.050032401772876905, 0.02101862003215619, 0.10767606327370291, 0.07886550359187589, 0.05032076492845532, 0.12877541173609997, 0.034548002820942676, 0.011704429202983457, 0.08796670474112035, 0.0317558019437016, 0.12376533460713203, 0.12993637202007155, 0.08850996067086536, 0.18070645900743623, 0.1817899524805046, 0.10049668561306693, 0.1140939495376041, 0.11135847172549657, 0.19068354380226907, 0.10741551677065511, 0.1126703819740684, 0.17747232690453532, 0.12447624121822658, 0.1696820707330781, 0.12271161897168045, 0.09261421543816406, 0.13674871695618476, 0.25646020538143577, 0.07375789580926781, 0.12499463759482869, 0.11150129349722017, 0.12028816877113235, 0.25643095614448674, 0.1794394108677103, 0.12474437965260399, 0.1287312850716614, 0.14705056174387857, 0.1852099988008699, 0.1926686461534231, 0.13971258856115804, 0.22698866503853954, 0.08806754489459338, 0.12409033974812878, 0.1014872066556446, 0.15856483260229712, 0.14602130729584925, 0.1836638495085701, 0.09177254527927407, 0.11819877120996676, 0.16804157005202386, 0.2418420986542779, 0.12527333272080268, 0.21328704461695688, 0.08553550173077853, 0.22885042723388443, 0.1725601711340489, 0.25500272310549216, 0.12858027382002724, 0.11924730043017095, 0.15237231408396076, 0.0827557440366476, 0.19185323748857747, 0.1165276576554583, 0.16685954235013456, 0.15296661445210058, 0.08163365505395398, 0.25373670152358474, 0.13978751196015266, 0.17418646854498696, 0.12703279153473918, 0.11955477747946017, 0.13924601037175427, 0.18687573441814992, 0.14217599024695737, 0.20101730381288838, 0.15124935176103346, 0.21871784191218116, 0.29401280887184605, 0.13303243975725867, 0.19435791599173702, 0.13305799645041266, 0.08090097622405137, 0.3394064601630934, 0.13834121456790355, 0.16911672848847606, 0.06316554665024723, 0.16656887326990405, 0.12599484198876928, 0.2561630551973658, 0.0760390451778808, 0.16446490471641864, 0.24632766602500794, 0.10677232467118772, 0.10679729913751926, 0.30816076743987303, 0.13860413594351662, 0.1954642542067074, 0.24302769632589435, 0.16060244261978135, 0.21627590601002017, 0.11079841548757208, 0.11429340052869051, 0.10522766925034024, 0.09546865138315386, 0.20702113487547447, 0.08803789729192373, 0.11567432763836077, 0.1681976221621998, 0.11233207754670613, 0.1610108134486983, 0.07179651920112871, 0.15787133916972146, 0.2266044719445129, 0.24390675157548922, 0.15749171195972353, 0.21205382691996716, 0.11228222054459396, 0.1569933257997036, 0.14271327835177222, 0.19738308995241122, 0.12709823076523122, 0.10486858085759225, 0.12327036519925441, 0.17328879735883207, 0.099966652360895, 0.14171393197630683, 0.19082732318389803, 0.10755846877732586, 0.1623181731349999, 0.15814713082246243, 0.21081146213316151, 0.1600918450182484, 0.1322467399821166, 0.09460911605386965, 0.12913931882189167, 0.15701935746737067, 0.16998181029433207, 0.09318646013496384, 0.14100062751000927, 0.11962824531139866, 0.14494768103524563, 0.23533903873495518, 0.16876443529561644, 0.27228600375594636, 0.16610155963609297, 0.15757331564541788, 0.1409654487525263, 0.26016315265047935, 0.18616673536598685, 0.16667362813267017, 0.2462043258691988, 0.19576751777241308, 0.1374271184566521, 0.13706531045177292, 0.15857802463635323, 0.119685648279565, 0.14219921803282154, 0.23066772568610408, 0.24804753341501762, 0.13193920164579345, 0.2443374462065197, 0.15845583361243049, 0.11690860253668602, 0.07353951478557241, 0.14408155734981262, 0.049221784987997626, 0.12570744410397547, 0.12374661141826261, 0.16834900113603762, 0.15628080274308884, 0.20256034278821564, 0.08212508513562142, 0.1960128191257677, 0.1625889392509576, 0.09592032150155115, 0.09288702700887957, 0.14693321239563728, 0.10461960994308034, 0.1692772392303713, 0.1580122840260306, 0.1450769813551057, 0.18216608632956782, 0.1797644619739825, 0.1382840950522692, 0.2316700444827157, 0.19966351919837538], [0.04164344022771524, 0.03742151818568668, 0.053172883457474174, 0.014476702218094181, 0.02479524772253729, 0.022945338822600823, 0.023633617111631942, 0.04972516221084422, 0.015946573093383303, 0.022706047429012197, 0.02571108668381649, 0.1062840125673721, 0.09166005292847272, 0.012103838718406135, 0.024044215341188738, 0.021484780703641234, 0.04324531092518761, 0.06182510345693558, 0.019187022548829837, 0.07496678255378239, 0.0621595889359953, 0.050737681468167616, 0.05509415153233756, 0.05605004923117738, 0.006595765176649776, 0.01993789213649448, 0.01828148747013221, 0.0107343512166652, 0.03579676827235568, 0.029968516901135448, 0.02705871195141827, 0.03912982530891895, 0.026702389136076938, 0.015018025691050195, 0.05345143685718218, 0.05096283853955327, 0.07313826857435127, 0.051413964735524315, 0.02476064161577773, 0.0628831934544348, 0.015485195683375483, 0.07873572829750278, 0.03513208357617259, 0.03949852044423742, 0.018396925429002415, 0.10280082528028758, 0.05202852429882173, 0.04480324264976286, 0.11981142459497338, 0.04106451524421573, 0.022985905093411287, 0.05664451430822092, 0.04011288082467453, 0.022232419315485225, 0.018408979822490967, 0.08078077702873177, 0.10471396899271397, 0.057358718927829504, 0.03246433176701108, 0.028473749125917113, 0.09076118664515596, 0.09080102321721854, 0.08499166357421106, 0.016260652862969908, 0.007998752745709593, 0.02007342266639875, 0.054191485452916355, 0.03386053083945186, 0.05334971187215659, 0.033962225180960474, 0.04255122760491025, 0.013516557519324126, 0.08386156131182948, 0.015379307010481435, 0.05143236233702591, 0.010561074577121726, 0.08246687526303915, 0.06675261162942456, 0.04791308847826816, 0.013738635874864076, 0.04203355135095697, 0.03756927356364266, 0.0380090884714117, 0.08786297643617277, 0.027013302089706547, 0.02114514136807092, 0.08082356303930283, 0.05991216658824875, 0.051114615879111716, 0.025984545598828027, 0.0465495209209621, 0.04334286456146548, 0.0389183237547836, 0.03561771437225323, 0.05684649338945747, 0.03798160889756776, 0.0368670812026868, 0.04657246908473392, 0.03628959263404531, 0.031452626478107225, 0.05267027615299148, 0.06549585971140093, 0.028051418259799964, 0.05106829820320972, 0.015065379500869783, 0.041533357223435756, 0.061885758468340483, 0.025152294490967068, 0.07592073821973416, 0.025538893101075967, 0.06229686806158674, 0.048158244274917154, 0.06623237664180417, 0.04130259238844437, 0.01964789721363735, 0.04796263138433138, 0.02607336008710967, 0.06284955070324003, 0.04753949804111354, 0.01405998390363229, 0.022956351336512356, 0.05304488548708539, 0.04499115252627, 0.015919386548170402, 0.04805143629651397, 0.04397224409565811, 0.09211968270040329, 0.042670323633618897, 0.06592248641555348, 0.009590002591721714, 0.02513973830988811, 0.05174636262499037, 0.036875515830733126, 0.03136604705134467, 0.0404571300943292, 0.01833409281267274, 0.06509508847469284, 0.07620618258032107, 0.014515536172585863, 0.014808830061566927, 0.0357685838976214, 0.029376187294180837, 0.041338521912093126, 0.013863249651847348, 0.007548350024022043, 0.022099089373143452, 0.052550751115045244, 0.05253504631259749, 0.02558110454570382, 0.03466214609122084, 0.038876974159070564, 0.04465317368627556, 0.03431093308233446, 0.06819798971616453, 0.04208651867004172, 0.07543635614697011, 0.06717988184743351, 0.0396778654577511, 0.06725476694203193, 0.07223492833755671, 0.030318180497194973, 0.07433095255926733, 0.04230220689468327, 0.006779614308353274, 0.06345156940721697, 0.01949611029797985, 0.03899218612200311, 0.05394941316016259, 0.0569912150592333, 0.08797534621290623, 0.03496566629638115, 0.014774591677011022, 0.08981591841626553, 0.016076625137019063, 0.08336761080089115, 0.05764809714990759, 0.07496190257370472, 0.041361048727506594, 0.07559962480539277, 0.0319205989475332, 0.03184774973159356, 0.06333229717828574, 0.053663359759675885, 0.01441685542944939, 0.055617784119902126, 0.02518367919800503, 0.05350875938611646, 0.059981060875279296, 0.06307930430217136, 0.06501850266490253, 0.025740303362028736, 0.011810642505635419, 0.01086238653384029, 0.012199005033189972, 0.04202230901066815, 0.04569177057654147, 0.04962347936065448, 0.007925777125262446, 0.05667060343248229, 0.0639637757933909, 0.08159653809402259, 0.034311446361243725, 0.01985295022267007, 0.05456175489891922, 0.06500046129428572, 0.03013871865527284, 0.035874974358105854, 0.0481761324279491, 0.0457456648620146, 0.0620000894301601, 0.017574372994262847, 0.06918121760170307, 0.031220936591947274, 0.03787056828338293, 0.02171174382730838, 0.08213626235843667, 0.09141980009453912, 0.09144018569420423, 0.05686713945901683, 0.08466878049676457, 0.011448713841908162, 0.03182991520471631, 0.05823467535177066, 0.040923907466593294, 0.05250293573725128, 0.01923415227793157, 0.030931707757014423, 0.026258908497590213, 0.012036709306431154, 0.0394166371364507, 0.02617619589962546, 0.04427248544450249, 0.057499759545129155, 0.02463546093373049, 0.01922974344192734, 0.05476951794398408, 0.02521577828203238, 0.06663947576476682, 0.04669033937276371, 0.036964887647979686, 0.05546428308251405, 0.04733775644713352, 0.033267475364188996, 0.07772276087874368, 0.08999712885387483, 0.046387910842895515, 0.012197049593763247, 0.09439560734937269, 0.061297494873044, 0.06051470623201421, 0.02065023899288668, 0.06782499682759086, 0.06755010915860053, 0.014611648605956186, 0.05748190969649342, 0.03658892616869942, 0.07018843936103006, 0.0450777204617137, 0.01942903163932985, 0.04661051684149331, 0.011725715913569495, 0.032042133051060864, 0.05607612686411989, 0.012811826534509178, 0.027567662463914004, 0.023553675836733273, 0.04847515569699388, 0.011528876324694966, 0.03492136726215963, 0.05912589990804273, 0.013862938428628109, 0.02255523727545815, 0.054027381758656234, 0.06111105205491186, 0.017357162169871793, 0.026843458481673754, 0.0037286942871663, 0.02072943141683936, 0.0394795635985511, 0.021186314763561375, 0.03519553480850112, 0.0543566310267535, 0.009018534516555168, 0.008243100319598472, 0.0151445422389154, 0.038952257619389606, 0.06317904128903343, 0.06650167186894725, 0.016426049330602252, 0.06984006853834276, 0.04234743672573278, 0.021991141838952902, 0.03005729500024069, 0.017102951213957805, 0.031128939008340243, 0.02689845593375785, 0.019726695102309028, 0.02910616236828989, 0.06025330937137047, 0.049639253111015406, 0.0454781009935804, 0.10378758483115705, 0.040790324715236505, 0.04964493365297395, 0.05038602029784553, 0.0519413588147971, 0.029286214097913717, 0.050814052773339134, 0.0482777884650615, 0.02005227480924899, 0.06993892452409191, 0.034260344466254596, 0.10687655859416532, 0.07508904252561831, 0.05009941914449296, 0.027021434113022783, 0.05546248277589198, 0.03505362085096779, 0.05695514380931855, 0.015722240524126158, 0.03575773226217397, 0.0471937510695669, 0.037480771256190155, 0.04984525032341481, 0.03573115667208068, 0.028235811792734652, 0.02961576980118069, 0.047679416339604125, 0.06598961870035817, 0.013265761400332615, 0.04850469221691451, 0.032805964846404335, 0.0378566752788761, 0.023428636880952026, 0.07157111315116768, 0.056389851360431606, 0.059243333525955684, 0.026035383193483277, 0.09514589087977525, 0.06444084172647807, 0.034324358773207476, 0.04001040507348315, 0.0032284879501187995, 0.049229802098125226, 0.0442562367196285, 0.03266094823277766, 0.04912471781755167, 0.07794399174951738, 0.1411125223122297, 0.023367579673386873, 0.010883957654568217, 0.03871719503114301, 0.36795058978661416, 0.10473564928097111, 0.13071844053845252, 0.1365529048827387, 0.16486443489068942, 0.1254824287588558, 0.11919002769695175, 0.1688326017991189, 0.16440162585387308, 0.13471182706134935, 0.13720498360212774, 0.20840675810412054, 0.24187484125216163, 0.21059007804480293, 0.04829131374736467, 0.09758396569879786, 0.07557108036933408, 0.09285386306263747, 0.0812005625677205, 0.13264660723507404, 0.1906902240889688, 0.16746565579406678, 0.2771941452257095, 0.20780375497716091, 0.15081838133835024, 0.17506317956553352, 0.10212138956112247, 0.22316838374301312, 0.1262694615269861, 0.12315925180671677, 0.12715008725682575, 0.1184449535644343, 0.11181244776854593, 0.11163198043622317, 0.30052804958916485, 0.16188096675661304, 0.15643654841809504, 0.1286287518638757, 0.14097687878435658, 0.1763959120838873, 0.1755373113818707, 0.311522054816446, 0.1361599017775828, 0.13928233826112363, 0.08340082071240872, 0.20025438749261443, 0.2616872079670429, 0.20545342786898538, 0.2098888011589166, 0.2051927434701112, 0.14097283384011638, 0.14190281861491744, 0.10758640800392437, 0.17021177456744258, 0.20171654290489613, 0.16445542054791606, 0.20427927555095768, 0.11481577290161965, 0.13917320137543066, 0.07625578677341824, 0.16759567623657567, 0.25507278950704687, 0.17767253632266677, 0.15672277418836472, 0.15880751393495068, 0.17402559008088805, 0.08677075722164686, 0.17363462476961075, 0.16891009925353914, 0.0947408831768459, 0.13574837466641781, 0.13314837950371927, 0.13437571364545053, 0.1695241340466084, 0.08489512883487248, 0.1278450975434915, 0.1327966685376821, 0.16396679434805148, 0.14879797765564534, 0.05683738077359815, 0.20311545009814924, 0.09324160314375356, 0.12349626920636624, 0.15793850975892237, 0.18312587192462337, 0.11250138297797212, 0.1273960244631575, 0.1297143597396151, 0.10686318269900738, 0.0939495373337019, 0.198752012464308, 0.2037170742668452, 0.21337594145969038, 0.07817749534883807, 0.14087149572949256, 0.15921980713403996, 0.1846187781061857, 0.10714222256454731, 0.138215116495567, 0.08493618348673468, 0.3714439507213331, 0.19209665426563835, 0.1547994951327001, 0.15571475569759646, 0.1506378450581143, 0.1851510406742173, 0.25193743678110264, 0.09904229833233742, 0.07054051038839164, 0.12686940796312787, 0.19165523440366794, 0.12384477026400068, 0.15791235551718744, 0.2168848846227892, 0.13353350722501356, 0.19833449454557514, 0.07818180076297253, 0.18785442706317673, 0.20940349978064338, 0.08670939357891198, 0.13485038172333472, 0.08089166059489213, 0.14406969830874475, 0.12005897824682536, 0.10365861392910443, 0.1859470213493032, 0.183329115050935, 0.14242046422535373, 0.1982229521437999, 0.1387855915292617, 0.08089798848114668, 0.11822654955810118, 0.1513180851695999, 0.14652206832843442, 0.18275507004751315, 0.09139250438179701, 0.18157929362308595, 0.30389825422917643, 0.12539023007716865, 0.2202236336926299, 0.1412371035304762, 0.14023712896291288, 0.19209486161989553, 0.07667495944206754, 0.09963588623870766, 0.11992572491327602, 0.2331364593438564, 0.13662543808740957, 0.11259586460167363, 0.11111523114865827, 0.09581513762954744, 0.08894149033773331, 0.19478448906973486, 0.16389962375885056, 0.11268201118875897, 0.19000362544771165, 0.07073115902922808, 0.14626377412388403, 0.15171920880675316, 0.1910944733648531, 0.18329583619150425, 0.15792041476215088, 0.16544281595176266, 0.13522931945420083, 0.20428728883064565, 0.14384342657942928, 0.19653395809713872, 0.11118944208588331, 0.24942877462073682, 0.1510755570545312, 0.13012711259145893, 0.19761081724878282, 0.22207284736777508, 0.1164970524428833, 0.12485252828487467, 0.14167671542494528], [0.08230038137445528, 0.01973492097139599, 0.058614766044962796, 0.007405601509456193, 0.050006469696640014, 0.07363831714516686, 0.019017452817229975, 0.06351548795317931, 0.027712893582159476, 0.04423513865819381, 0.02684899346692668, 0.0024741295501664886, 0.06261255374298462, 0.07041106451182597, 0.03169295975127288, 0.018968394461778865, 0.03783927359167607, 0.04280837267757424, 0.013860126885946, 0.04503471994652383, 0.05535727209081093, 0.03652681175979876, 0.0030045520707649453, 0.021599082937163692, 0.04757335912736674, 0.016074210044837767, 0.033952174107393915, 0.0362922930939784, 0.013999063634283602, 0.03231269615371862, 0.006357705748204383, 0.05037673148176363, 0.06702534659134765, 0.020475695435438427, 0.018637647491789634, 0.040311209496951876, 0.024905441809565793, 0.07953665790057952, 0.06548172538919796, 0.03598852391024271, 0.028419205580928156, 0.015178037518184754, 0.0649641257440371, 0.03886390469908234, 0.031431281353316964, 0.11892512215361481, 0.024733478053202553, 0.02966559232933627, 0.01976545915127762, 0.027034518894769495, 0.02668188670800338, 0.06842720322310925, 0.08261751113159042, 0.02272722592967893, 0.06281348711420452, 0.03470667878225927, 0.059815899979683666, 0.11748182782602888, 0.045818577280207995, 0.050757017527376457, 0.031690575302608555, 0.05558087400371029, 0.014752958311639247, 0.044765359601907195, 0.033467895456499634, 0.03317532647821692, 0.04703492572110507, 0.026314248774020423, 0.024558836819543958, 0.045199758268051574, 0.01935531099837634, 0.02048553775004562, 0.046125701929052035, 0.01448378757378387, 0.05051635483640337, 0.043428233569307674, 0.07174951204609487, 0.061174629691747896, 0.0399999096689205, 0.0081541201648032, 0.06062089367919873, 0.048255047145029234, 0.01490308281650106, 0.03672109548783591, 0.026334239838404522, 0.027746679974840056, 0.023491892760859865, 0.08868167161821358, 0.03198617607385161, 0.06323794961997098, 0.06440910270377513, 0.07841188761015093, 0.04980899904283786, 0.041797446883133346, 0.015106053023989645, 0.01278889656532556, 0.04567444932857349, 0.03416655998256418, 0.05823003668938914, 0.06856810211414291, 0.05858132630706795, 0.10524515137677232, 0.05131488658427712, 0.019826878335387, 0.016355431345742077, 0.0710135620207556, 0.059920723790362965, 0.03609522463633649, 0.044198167254968036, 0.04218894845595764, 0.06995726466899918, 0.017076436910898458, 0.030345629427521944, 0.029051163000985984, 0.033455507814764016, 0.045329774880120834, 0.02846767021823795, 0.03993580726185634, 0.018651078928322084, 0.02569169699845295, 0.060181607372097434, 0.05508916813039011, 0.04053520211469262, 0.05527402514651899, 0.055017205661222826, 0.0811697811549229, 0.06066557192694276, 0.02739816551066695, 0.027237737123223565, 0.04467797578282414, 0.03851931835074098, 0.020258030703952237, 0.031472146398417895, 0.036474717780947685, 0.040913856393026735, 0.07217425417395369, 0.03377327725531594, 0.05391025074547338, 0.00875290023208025, 0.012273501338166817, 0.04159780053962623, 0.02633098587994614, 0.086996860411619, 0.01986856309456691, 0.04471184069951696, 0.042513727601016724, 0.069408071557841, 0.02465882278498142, 0.009530498627423039, 0.03255491017273838, 0.04137957656395532, 0.0520545061707737, 0.01651197566740936, 0.02372841666182203, 0.048645809443006595, 0.06059415721064133, 0.05421445659932591, 0.026285849894667347, 0.04221324876491581, 0.08137646401601453, 0.04627732605102562, 0.020312181628880002, 0.008512811149440466, 0.01464537466921273, 0.06267937193174036, 0.006846751381207499, 0.025318211898387923, 0.01544824630517753, 0.06305215797657449, 0.043397835200472225, 0.009646819502625976, 0.07128848033326288, 0.014807063271291556, 0.054634674977991855, 0.007786073331390658, 0.0150614810709451, 0.048620896263708996, 0.05591968787954219, 0.04931464250529966, 0.014398050843738021, 0.013042281103891232, 0.05133197034498857, 0.018401880102652698, 0.030592409330570412, 0.07069899865816678, 0.00914770843190772, 0.04065064390400245, 0.04364595575738819, 0.021077246825781562, 0.01638228847314754, 0.032379284516097076, 0.0326086052753512, 0.03782873988271721, 0.05730567499995232, 0.06268975242311436, 0.0666674456348823, 0.0948627447829612, 0.08058874176875239, 0.019714246173539472, 0.037565355023909966, 0.10139328427612783, 0.04053571922404151, 0.013437512567296866, 0.021652347115319104, 0.05853477880478867, 0.052825987354041114, 0.04798755222450822, 0.021618943766600663, 0.06181104191308541, 0.07468277077761389, 0.013640805489323555, 0.03936918181998115, 0.06961870743262191, 0.03997640609140358, 0.07183274749906794, 0.07704190023603939, 0.029034969817486503, 0.034891723489929596, 0.014688672043473251, 0.03747975235925086, 0.06075196366216387, 0.10856196734934084, 0.0507244166557587, 0.02246233570810047, 0.036200722604389154, 0.05990633665914497, 0.0423666617021926, 0.05845171572159856, 0.03495388003366609, 0.07519719881876823, 0.021438346199330785, 0.027869945437076594, 0.02210645722375522, 0.018499820613332333, 0.08460013901874905, 0.051717557719037424, 0.04185263968763813, 0.09989360587731486, 0.007604294552302529, 0.05241119670831869, 0.02707545863344304, 0.015593351018915494, 0.03889417666341028, 0.028412077132792726, 0.03413225073487528, 0.06089272082693154, 0.05283008592443601, 0.05973899624340477, 0.028979522288746895, 0.0568496305195074, 0.045216386206448085, 0.028075410218368617, 0.021204697043304483, 0.05109269810359805, 0.04845164062815809, 0.00834086750288524, 0.06829468533396721, 0.00696402890870588, 0.021958349445354075, 0.03688739402399909, 0.05882547852853614, 0.05882611438151329, 0.027800781104052742, 0.023296741438248468, 0.028903972612874165, 0.021101683115346298, 0.08743073430753524, 0.021837851475743998, 0.006013824200753364, 0.01836238827015604, 0.03293345719876309, 0.02915776605086942, 0.01579863672715522, 0.0030433398205786948, 0.02112598916996391, 0.0885469627176081, 0.06366728061449624, 0.012157245580437443, 0.03602183341319042, 0.025629678350542823, 0.004326462878980824, 0.03383327343110596, 0.029134423351816596, 0.03421537127465971, 0.027800867288944223, 0.04170026096905913, 0.014589939589401888, 0.10842231718162376, 0.010877736063013154, 0.0607916470166416, 0.014754262576330335, 0.010832040833549635, 0.03551806165506283, 0.03733796863666466, 0.013646262908174146, 0.023189699803028378, 0.04167733961836465, 0.018101531501498916, 0.007880683274819486, 0.03447145914598819, 0.08083487049706521, 0.036079696034111326, 0.05729646662310247, 0.03842212860622714, 0.05576348255178141, 0.06517388827858434, 0.08396247041321571, 0.03753756518445669, 0.06333715034528606, 0.04963461827907351, 0.044510076122899214, 0.057138491632236596, 0.04831342687529903, 0.06905230032580514, 0.145423207131605, 0.0160137408097545, 0.01371248354834895, 0.030910404767059994, 0.05975787264985904, 0.050780394700385874, 0.024168980420537056, 0.03450559602389413, 0.03258196073734472, 0.03409265548050885, 0.03000351945839582, 0.02511233917527622, 0.02914640688217215, 0.021067182345676328, 0.018547952002395066, 0.032389013832735444, 0.036673142214215575, 0.008966139848193815, 0.06139712460759667, 0.0446372160748128, 0.09637125617554111, 0.017145149252046982, 0.046481258656469085, 0.01719871220449286, 0.023793112787027514, 0.032183001298577554, 0.06403154393117275, 0.02643996763283447, 0.0493125012895513, 0.008329638569135099, 0.10054209930521828, 0.012953130494532807, 0.03702546988103179, 0.01461436247242795, 0.016047000516987136, 0.030823064998032588, 0.02909158371509083, 0.03769691530314665, 0.16042532309168772, 0.1421500658315997, 0.14190933036227382, 0.15563065456526895, 0.15318191580234036, 0.20932422500223885, 0.09770743608955415, 0.17395969119764146, 0.17429125405127005, 0.12764560824800886, 0.12904513597248063, 0.09512456299196329, 0.18106014648031804, 0.20546559334522296, 0.20628486309320698, 0.09951454557238087, 0.1407159185938297, 0.13662202133526727, 0.14832669568638648, 0.12578402991376578, 0.1796800237629683, 0.2249914278546649, 0.12344935398188331, 0.11478188883272872, 0.23595537179179732, 0.17349536530673507, 0.11295032582335895, 0.05905002656002199, 0.1312289155659176, 0.2800456776974663, 0.1101670747682933, 0.08496875754527508, 0.1604648532285806, 0.2209254008747878, 0.07016651392463716, 0.10737858367182555, 0.2081196436718587, 0.189983033004307, 0.13578749111583158, 0.31195498642421543, 0.12180767352542571, 0.12564501559902586, 0.29587109302801473, 0.19019297173907682, 0.19594996927245972, 0.22303333776372097, 0.14074673065014426, 0.12349144285244328, 0.11191079813626506, 0.15755348928993748, 0.10488174990901064, 0.10256336100639836, 0.18916060697407494, 0.14463153187065356, 0.16550244823578866, 0.216179225713976, 0.16306553787041098, 0.3100135970500208, 0.20724740660478994, 0.1338316073581096, 0.1926743918128552, 0.13669250142430106, 0.10268008982342097, 0.13261830794715113, 0.1428456736668464, 0.19854477035903162, 0.13901051494383043, 0.09680544416750632, 0.09859382280058439, 0.15616440334387366, 0.12538556460170977, 0.11637725927416356, 0.10857483762646876, 0.10082524540203233, 0.13661365565513411, 0.14793969871055695, 0.16987160088554507, 0.08904832129877421, 0.17795281725064402, 0.0728707276885548, 0.20843836689187636, 0.1219830846774482, 0.29240310492534793, 0.11196032572056978, 0.14864773249193547, 0.16145324454672877, 0.12267929772215506, 0.2355595341613216, 0.12541707379803543, 0.134286847446234, 0.22224484942853454, 0.16333490970634645, 0.14640994369983673, 0.12301438458023534, 0.08233827974406943, 0.18365686278670065, 0.10632618570760374, 0.20308425499787255, 0.1501275385699926, 0.11497701142704296, 0.1720088636202197, 0.14572499980849607, 0.13253342540514085, 0.07033396542312638, 0.055765688885003335, 0.14133298709507913, 0.11828071197434781, 0.1346222254177255, 0.1215109370288349, 0.16737223903258003, 0.10873596123870342, 0.2559066915343846, 0.13398104046861972, 0.13852734328998675, 0.06870396780751406, 0.09834331971022392, 0.08665776691369473, 0.18890338529261852, 0.12553321272735635, 0.24682543931468842, 0.07820920372802405, 0.1253446555065532, 0.19743820231768394, 0.1709593691292309, 0.13468118354437814, 0.18175134164912088, 0.19291958591390043, 0.1626127952289197, 0.12440847308044473, 0.11371064510556961, 0.11154785632125794, 0.10947987857845523, 0.10692885941675595, 0.12221800553942881, 0.24571798261134858, 0.18592164851725104, 0.21389663610006535, 0.16034071634133018, 0.30148360637887833, 0.06900804342641946, 0.1701860799784622, 0.08949350265245284, 0.11853881465691714, 0.16750543107909543, 0.19626899892764707, 0.10133778886689294, 0.15711249843720468, 0.10674733488309769, 0.13644951365647778, 0.08511294295350391, 0.23384126023419444, 0.16425309672711358, 0.11863275235819241, 0.12236330177514784, 0.1415105203106519, 0.14523534705081295, 0.1413947950688101, 0.13174853768319855, 0.21966503302176155, 0.09852169562251338, 0.18193390040147692, 0.09026151345742327, 0.07443166247779325, 0.11294460314656458, 0.17926377755018974, 0.22889743438891827, 0.14519754827262896, 0.08409039177481206, 0.10635720460765785, 0.1703313149271473, 0.08354622420043716, 0.1356567045853984, 0.1083309228922571, 0.1551487392956211, 0.2741054319325955, 0.1125582573454707], [0.06376971423085179, 0.020167484856961716, 0.03129790353047992, 0.04623856583249666, 0.04181190679270414, 0.031311649063061324, 0.013378827359467266, 0.02087787435870738, 0.01628972015403692, 0.04940692928709811, 0.10608151254634704, 0.04496143214524754, 0.04066721438580463, 0.017393501550560037, 0.0214083174679188, 0.050163475586281675, 0.043115267500040994, 0.10245872871770013, 0.05465372375422909, 0.02807096499318798, 0.0405258558420164, 0.009298257157957603, 0.03704403985231634, 0.04471235780886585, 0.07538028617179202, 0.04173907098330317, 0.044175311021747134, 0.010197641508233164, 0.07410138665187745, 0.03756899011111067, 0.044531959424456286, 0.016525489458393668, 0.04470899468287826, 0.02420466862648966, 0.020975619516966325, 0.07856579467413888, 0.026323572064058918, 0.051097834723130356, 0.010993846264036914, 0.040691491712125084, 0.01558006322386885, 0.027620595309042165, 0.03647333499224436, 0.013512168793127903, 0.012212111839964505, 0.017728825895896843, 0.007812767665112212, 0.04093999148256356, 0.0965446754989605, 0.030079356417240157, 0.0420172528303679, 0.012569708276479956, 0.007600924244240648, 0.017621975782657825, 0.059773485521755876, 0.020419558427566965, 0.04228511547309257, 0.0361468244884764, 0.08277978387571151, 0.06757126084618992, 0.020707209121375796, 0.006399851117748768, 0.03681067031838241, 0.04306650600366054, 0.0641532178457466, 0.037430098370438626, 0.07124790065591374, 0.04130007195917349, 0.06960238975983474, 0.09102828319995634, 0.027857575032319275, 0.07154075308672844, 0.022436476410216382, 0.024437339105192694, 0.023700548298356515, 0.007103873471233754, 0.07004856702781494, 0.05453497246508637, 0.02081661222262248, 0.007509912041226223, 0.024515269399290125, 0.025253942867200223, 0.0041105117904202595, 0.02338431486409278, 0.03492373830428527, 0.010098761582236377, 0.01828517043782819, 0.02381361329988126, 0.0783150770791596, 0.06878596219804979, 0.03928139580473785, 0.03383095984557464, 0.00700237735497555, 0.005358347402615172, 0.01945911208167672, 0.02041588312075023, 0.04794917888038101, 0.017813687370489203, 0.04769577997766676, 0.05429452427873208, 0.01327420273164828, 0.023404415096006086, 0.0399080595572389, 0.011778265714735515, 0.047894238884891235, 0.03592093197268344, 0.005014326522922925, 0.09412889383853444, 0.03080823353581852, 0.04241248908182306, 0.008698091429147509, 0.02932743920433906, 0.025055591212285143, 0.03232697220218759, 0.03968608175073901, 0.03487957716589013, 0.03303333208145153, 0.0330459265669267, 0.04613836919288001, 0.012611521355387185, 0.027948247283817302, 0.06501889336974391, 0.05812812401282211, 0.012526075738752562, 0.021675980927783157, 0.08579971013410438, 0.02157886204640231, 0.05115326118445204, 0.06129798516931553, 0.006824998793402507, 0.032979958735766916, 0.028650500931807106, 0.050006419900924935, 0.029983304313293872, 0.024712772611829064, 0.060586243522383516, 0.056842735728188876, 0.03454180900007486, 0.09647104678855789, 0.06670802531223144, 0.024290769248299544, 0.023409124621520602, 0.05180370813656238, 0.05329279536982218, 0.09010151599443729, 0.029011127246063084, 0.06134827884154455, 0.03347108238226464, 0.044040337820807775, 0.12276839374774888, 0.027993976987237414, 0.040538618866834915, 0.027652010659597097, 0.02733089149959626, 0.04758398476687651, 0.032297355243034905, 0.049826289647288864, 0.01743808978297297, 0.024655681824491873, 0.04783069572201179, 0.014175020623952152, 0.06078394783300258, 0.010169201451654156, 0.07121105182675586, 0.0515202900785352, 0.05945023089166611, 0.05171778754541471, 0.03634962711423155, 0.04900223184977809, 0.05237749650052959, 0.017840550243554097, 0.03282569544089418, 0.03770890074872202, 0.021775338701122714, 0.06554582396582251, 0.06602167181911008, 0.060082318546671065, 0.032869998305555315, 0.02597122716026441, 0.03966388052269336, 0.06725862036429106, 0.029213828365168268, 0.0581032453074811, 0.02942562486315447, 0.05891492312413551, 0.013159211018993972, 0.04754588338396242, 0.022018705682468512, 0.06291582496956953, 0.05889807685068058, 0.05161136261097366, 0.044741630028452606, 0.03664322648077242, 0.028892337652524153, 0.020466046558032115, 0.01774295830288001, 0.02060484445293344, 0.025212922689294624, 0.027952165823549997, 0.036925300054492495, 0.024562000762671236, 0.07770379254173848, 0.013489978098791214, 0.022897705390688874, 0.0742886032188131, 0.03938117875687538, 0.0160185547147487, 0.03317571335261868, 0.038920005317777395, 0.01761895739623616, 0.019957729983293725, 0.0650360384174893, 0.0647423969161126, 0.04429696961456249, 0.006986668243283227, 0.04296311094696003, 0.02231598801670536, 0.07097993076087968, 0.050875791799156904, 0.0289859842403882, 0.032668092002671574, 0.03966111494528671, 0.01314586864018272, 0.0238227833723349, 0.026053972316965945, 0.019072038497054772, 0.08950883973269694, 0.02493790478535718, 0.03374887352448798, 0.03635403211979616, 0.08722542274382808, 0.03039298323734153, 0.08437104042499297, 0.03285669135831056, 0.04039720286645236, 0.04457816984804888, 0.04172727322926925, 0.04621901526866902, 0.03855691411562505, 0.025777339882728074, 0.05310991486053794, 0.046119722612803025, 0.02421185453121941, 0.016482291675563303, 0.0813793215239721, 0.046314607719860734, 0.03955120814122981, 0.05405360111786474, 0.03466740145438141, 0.010924315166419313, 0.10294203060649096, 0.05571332677537876, 0.04475316348215265, 0.062355508261750785, 0.00761480575742861, 0.00904559369965066, 0.05835226218726847, 0.03477257766550587, 0.04538856829786974, 0.013741447417546186, 0.03761781289452507, 0.07697679808423405, 0.030839999371598807, 0.014661212579437323, 0.06411547652415692, 0.033055567783453775, 0.023729741993931033, 0.04806974962834389, 0.023795514472670132, 0.04837253055865726, 0.025716022205268665, 0.042207043452729145, 0.02790128800927872, 0.06577148282479856, 0.05305240464006221, 0.037769996260683385, 0.02748808891121899, 0.03166026694910421, 0.03333104150970617, 0.025104492519711776, 0.01917604833931452, 0.02580242926224826, 0.034083263242557164, 0.05370624919211673, 0.017537083664548495, 0.005874701676094124, 0.020894607634193475, 0.08620566778605984, 0.02723827721521018, 0.019852791259425785, 0.017199372955327554, 0.038057669937129945, 0.04421272292552937, 0.08462250112525879, 0.03718152582164734, 0.02375156209323435, 0.030889597819036538, 0.09081897265728443, 0.06741400597797287, 0.032000812183644985, 0.030278177301008857, 0.05605280714770479, 0.04703424773329208, 0.05545003767756205, 0.12008101093552767, 0.011517407030858582, 0.04717200183339658, 0.02741034822388282, 0.035273595337545684, 0.03552107238060525, 0.015978078459269338, 0.035416267722124056, 0.043360323705259836, 0.014873199641794689, 0.05665946451406326, 0.06489471817809729, 0.014452312851414807, 0.04669436516480581, 0.07360163685535231, 0.015962901299879435, 0.0929971521479949, 0.04514784815030233, 0.03726775667840435, 0.10842532024628694, 0.0371147267850897, 0.01888064675093178, 0.012959349213258154, 0.017976301023736596, 0.042356484224118536, 0.0234211158127554, 0.03398909571490461, 0.07874878243573251, 0.07368936924444092, 0.07069188170135021, 0.03677965907920753, 0.06047002415383055, 0.021474040150942824, 0.08452985045169631, 0.037595485261971914, 0.054416784250568, 0.04864629207839889, 0.09865520176507774, 0.03004217050939558, 0.04702623062316449, 0.02553217834041965, 0.02510203912313427, 0.023971013724803928, 0.04281737038024491, 0.05689176918578245, 0.07526163447407946, 0.04791251774276457, 0.05401172675192357, 0.12474447924403415, 0.15559999572653926, 0.07080836537023706, 0.1596159358779269, 0.2109294243517422, 0.07759255657513296, 0.1240979853056131, 0.0944036972378531, 0.085490019090714, 0.15553538387100543, 0.103759944378849, 0.1239073979518106, 0.20637769762787128, 0.14951397875143638, 0.15226495452225208, 0.14368904454092826, 0.11419529530910716, 0.22723180602394769, 0.11369605113061206, 0.10286238044500352, 0.12861946687823342, 0.10576232967357482, 0.18526109686541944, 0.23013342532419392, 0.20996718727532895, 0.11735167714857286, 0.14251982582913292, 0.14948181838037508, 0.26288714680460196, 0.1265852429693745, 0.09168193239959017, 0.12674769957459744, 0.1051024904835128, 0.10876420690047164, 0.08645787159161222, 0.25944511376080975, 0.11131656671603841, 0.26132178402716116, 0.16335922533706312, 0.14508021424614614, 0.10606418363749982, 0.14758689989966733, 0.12396783462815708, 0.08910684275531, 0.11852922323610514, 0.09489768605318763, 0.09757088857793039, 0.11921014516584336, 0.15149394831349774, 0.2260391756651863, 0.21150474106111836, 0.09454239745654407, 0.10168874906676431, 0.14531819179894465, 0.19150944787167734, 0.08984824732667016, 0.17427582504047504, 0.10019474737947026, 0.1985106028376087, 0.17957031997221132, 0.1434949331826741, 0.12627955090494888, 0.1074429657009821, 0.16576938391212495, 0.09864780901660843, 0.17134947642203302, 0.11550799462824099, 0.1213297419129841, 0.12955769475909973, 0.20027689515582978, 0.08281315466569317, 0.1012233812962809, 0.14389935099790174, 0.06722153404787665, 0.13717075479367088, 0.1784929858460542, 0.10439785813251812, 0.11105464891560617, 0.120343909328503, 0.12724675223111145, 0.14652260458998143, 0.11060168410861686, 0.13023195938477594, 0.10221725780396693, 0.10906092807530396, 0.2116391588483126, 0.11555707788154965, 0.1048782182436797, 0.21802609516007287, 0.15058535271354262, 0.1027949034206329, 0.11945579125876389, 0.11949487706466068, 0.18764093368043824, 0.12871009507967582, 0.19541436656107827, 0.0899351446799213, 0.1528983713398057, 0.13142731701654772, 0.12642768166598775, 0.10545195681193184, 0.12933251087463674, 0.1901332628462584, 0.12215668020109016, 0.11779984624515619, 0.1205474359073466, 0.13070097373377892, 0.20654223799224825, 0.12004027037971443, 0.09954466814956359, 0.09358778295497741, 0.17430760236757417, 0.0827260734513402, 0.22208545717500874, 0.056784294710885135, 0.1447246728404876, 0.2905324101448059, 0.15251538866469938, 0.1786576947497745, 0.15988166113534283, 0.12816451790352024, 0.2165741287171841, 0.1315294365368543, 0.11128828274987398, 0.1169532731235508, 0.23404982001070054, 0.08678504476143468, 0.15644552696856762, 0.20992759585140214, 0.12835282231530837, 0.17348120800189434, 0.15615864236268306, 0.16012472551195853, 0.09727535483938071, 0.1929734725384943, 0.1299517703873496, 0.11088555798895898, 0.1460789937165476, 0.19899205845450202, 0.14034819639017507, 0.09888641476150482, 0.21394845428726367, 0.14253530080520338, 0.15392070035299948, 0.20185114455319222, 0.15256365220392906, 0.12320220635663118, 0.19998083281661236, 0.09333426913907451, 0.1952592950434454, 0.12474868506673845, 0.14902262527856136, 0.08021695929909907, 0.10427339182746026, 0.11033943689037716, 0.1284859300921521, 0.16354552259848965, 0.14916000016514333, 0.09920274012631948, 0.1471754187537778, 0.05107148129853511, 0.12869809814278158, 0.07228803355246782, 0.14373890154304045, 0.12738042691301915, 0.2697466061480584, 0.15438035310756776, 0.2046721101167702, 0.09863822525667568, 0.19509719083866767, 0.1272563666345612, 0.12540310035429655, 0.1766535627745813, 0.23797407475931032, 0.12071281896844027, 0.16423570653123243], [0.04138962763752188, 0.0408175629713843, 0.10682699270546438, 0.03564406396640885, 0.02076626492423877, 0.02884198460848101, 0.008474071040719507, 0.034650846294337706, 0.016708385289436387, 0.03321993577804777, 0.021462929960820946, 0.03225109502372723, 0.035646323925785484, 0.028733136920979428, 0.061384955300919475, 0.019931483811007875, 0.09122128373072033, 0.047072241863896774, 0.05134397877320167, 0.025775476373852264, 0.028264681816161163, 0.057496005714300184, 0.026716178718713984, 0.03639145168445764, 0.038002572893615694, 0.047439569532270395, 0.07520101393663114, 0.04902980718461256, 0.0454267539504555, 0.013462387442198253, 0.06462733050988567, 0.04143750813278941, 0.012435797064925634, 0.06609946804782076, 0.022367997725884763, 0.02135316679824985, 0.011053369380533697, 0.06099912660917448, 0.059248412688893665, 0.014182606809622338, 0.04847027954735583, 0.037195384352197575, 0.02357351559875233, 0.03946036160472901, 0.0411900234288506, 0.0821914283498641, 0.03185690639750852, 0.04027039999322545, 0.031671901909454216, 0.03353728003980171, 0.049821677797984694, 0.005913296228109469, 0.02595918425809472, 0.01416841790365476, 0.017245991320739833, 0.022087716797907508, 0.022692527892368457, 0.04439550384338345, 0.037348808780793226, 0.03261811242649152, 0.03430001249897384, 0.059697635156372865, 0.02944821871126131, 0.027381495437434605, 0.04446930492356901, 0.03476184860412632, 0.04771259560760471, 0.025729543657132217, 0.04201670890794166, 0.026349760779750445, 0.0815289614782218, 0.059083336062969706, 0.02772339473238155, 0.0761747959580633, 0.052460073117887786, 0.0413207448418102, 0.04423127757505544, 0.0022817251315685894, 0.08612615552039878, 0.058419972868456, 0.02285622939046833, 0.08402967930681284, 0.015176655687091332, 0.017110165846984715, 0.019749244900360223, 0.11501427394367995, 0.08524709260992466, 0.02180604158990806, 0.05072433238608703, 0.02466886811288855, 0.027552687360214132, 0.03488522323389207, 0.03205998481491641, 0.02925385645921192, 0.04253839946261818, 0.025903016606706287, 0.05386129772711185, 0.059362218880485144, 0.03658565497326274, 0.02105519306966134, 0.05854703621157716, 0.05055023507485467, 0.011135971853359333, 0.0555052419733857, 0.013913918707159259, 0.059184731630187844, 0.01028107422884674, 0.057376764128885926, 0.04920023876512724, 0.016144745675246083, 0.03340758135422103, 0.09334750713840609, 0.03408624715502224, 0.05060591434519138, 0.0245157118150664, 0.006986358935283798, 0.032751273829489946, 0.03850406554016856, 0.011390945066757982, 0.009800740930762504, 0.034894875941738006, 0.04147399307018326, 0.018636689881884286, 0.13358855830325236, 0.22728143319968255, 0.06662541039047704, 0.028245736461793704, 0.07329674152236793, 0.07417845509706006, 0.05689946836942146, 0.04382724280378992, 0.05686555365701357, 0.011180187575519087, 0.008731484244156991, 0.055196064208904584, 0.06699848754872238, 0.028068919538430152, 0.05858309213973342, 0.0212828035376245, 0.06435305571123477, 0.034953811085752906, 0.02976869435740575, 0.09643084249429165, 0.027707676523395126, 0.06022935763241784, 0.022231896460476904, 0.0068731311400751435, 0.05956159709321876, 0.009405862825411943, 0.05834841642588858, 0.08496668144700029, 0.03359020522405063, 0.06487493012701312, 0.07239259689325288, 0.024690464131474018, 0.029281807177129294, 0.015812593891525704, 0.028426314876865477, 0.058832001767211387, 0.0616611683020188, 0.007016704635574453, 0.05005732261305375, 0.033275741452891985, 0.026316690679279067, 0.025240321823906516, 0.039274068173742106, 0.05823758265544331, 0.08624241702378758, 0.05712908024208681, 0.044653303921222694, 0.029185146033283205, 0.020335955252390236, 0.03765906289880795, 0.03502560501557685, 0.033684254008074926, 0.020917772217803908, 0.06383795351270707, 0.020301557904590043, 0.03404408550610946, 0.021587149202523213, 0.009830221909308627, 0.029959367896099726, 0.031197009750852184, 0.019307836529708678, 0.01768607435928237, 0.026431925624849337, 0.040003916308764494, 0.056835231896970546, 0.013419398418327254, 0.05999585403309715, 0.07743751570101708, 0.04255655574642363, 0.07169782409384366, 0.05488492142889769, 0.03872824201901113, 0.02077482404157279, 0.052952794057707635, 0.05944930775571735, 0.012202945597950491, 0.027318113153019262, 0.03849670726565584, 0.03186928254792527, 0.036518794649671164, 0.05502164131030441, 0.04321962016664686, 0.06588292563514364, 0.0029477476087894534, 0.021762091125692093, 0.035862031302625136, 0.04044859970529233, 0.05293291024563294, 0.04890939731511378, 0.05202983430917225, 0.0934087558679523, 0.024723938343325452, 0.05557407114294268, 0.030115023555774844, 0.019005159021265084, 0.012856883995775736, 0.017832489083370855, 0.06121052091100043, 0.011962351854890587, 0.10731030991601367, 0.04165813379410294, 0.00703307832854109, 0.037706223271426656, 0.027948526905909665, 0.02318414183513772, 0.031644885818804466, 0.030568300543593305, 0.020184746733115568, 0.02469940437755037, 0.10191307493275213, 0.03290732210922626, 0.024090670912917105, 0.060813580113913746, 0.024595618616008473, 0.04562010688166465, 0.021679079753436872, 0.01906138221402803, 0.04059846182504008, 0.03374338067407089, 0.00859722446259712, 0.02588847051224401, 0.08078306763162536, 0.12484665239049543, 0.03907289348482605, 0.06464878097176552, 0.007702191491731473, 0.02633101077780368, 0.06676770356153289, 0.03601326471975735, 0.04433243565501706, 0.009450094826940087, 0.03258242805097853, 0.012160467937768949, 0.06796516027421722, 0.010214160279100461, 0.05099920856375849, 0.02952815998615998, 0.0065382563925889, 0.037962617577924844, 0.037161936953423486, 0.020985316274867907, 0.013625002053055554, 0.022781752237689593, 0.0440741491113459, 0.029839369798860246, 0.02202200560620235, 0.022740655450991566, 0.009970195749173722, 0.02087960380219644, 0.026426156982779506, 0.08595717950694023, 0.062493997806262594, 0.024141200157182834, 0.03534657670365226, 0.06379259344671043, 0.07084987201397458, 0.06542409259465433, 0.046062174087931076, 0.028024333221237027, 0.019748203020783204, 0.04538098785785898, 0.034711727301680276, 0.09296746624092903, 0.09118459578002654, 0.061060704756528146, 0.04970621685647676, 0.044462038579607205, 0.06382428267369829, 0.022101071625647527, 0.0687462482000551, 0.052085425479397665, 0.015866720876205834, 0.05488151616807427, 0.03265419516772513, 0.018003307538287296, 0.03105925565074769, 0.06903097243799318, 0.09994350884470249, 0.07412864406022333, 0.017927939808296583, 0.06243236220231461, 0.06631661566995806, 0.009938707620265984, 0.02190161297368186, 0.02626209542335522, 0.03554661375200076, 0.007465778194713377, 0.01803876974830224, 0.03763376284510859, 0.009238460165027891, 0.06128597674110244, 0.024559342437573982, 0.0763895993511523, 0.049657769456145265, 0.041494091386876764, 0.04916762640219062, 0.08757034617085611, 0.048936241035980564, 0.061692129745478594, 0.010746435296060819, 0.07792719910221715, 0.08406560883046159, 0.009513132371789506, 0.0701544786833467, 0.01479776104867098, 0.037601793996028365, 0.04316641152986596, 0.01131476336834772, 0.03898306584526454, 0.049831418605941924, 0.044062811010066545, 0.01512812305947826, 0.029247055513664123, 0.04274364590885178, 0.04765118599959439, 0.035670888535077536, 0.057879436550842184, 0.09035648537739631, 0.09829351633426645, 0.08586570860878115, 0.05099540876765406, 0.02616327774200228, 0.03125094425594134, 0.017182957606330033, 0.024557126528253, 0.03638964371695634, 0.017188316391360377, 0.08609882916413969, 0.06607346702367067, 0.15926073155095502, 0.12451759464437924, 0.17980016167125396, 0.19517634304300432, 0.11661436348672836, 0.11423083412791453, 0.0861413547048165, 0.12194718579731642, 0.14683677724772884, 0.16185956226000864, 0.19622786000611322, 0.1512473905759473, 0.0843823938480308, 0.11496702930138958, 0.19963073063521616, 0.17697087639281828, 0.12966033521919482, 0.0962236923195662, 0.1293076436606146, 0.16395003234426822, 0.1594629174759311, 0.2021432079134449, 0.14185265517763554, 0.13578546864371147, 0.11089727147332124, 0.15929796342407504, 0.15636640540774793, 0.07924213539808989, 0.12610623117295966, 0.11633645743131639, 0.1664227649809853, 0.1495369460674063, 0.1892870268033397, 0.2172192053929452, 0.1432960261140139, 0.1722279800883224, 0.14306494335253395, 0.2512967268065099, 0.1894598255955404, 0.1749303399194633, 0.16847825549062223, 0.17560894060279095, 0.05196837873588647, 0.12738162201018105, 0.19037787472048115, 0.16800482847517537, 0.19508839614929693, 0.12344674162206151, 0.11124157436913061, 0.1385991716937673, 0.1632630046937735, 0.10391589689759478, 0.12105691502051008, 0.08551012123784713, 0.06704152636830846, 0.1000407100805352, 0.1401299072970306, 0.19582846772766885, 0.1226235035386297, 0.12685341204726888, 0.19444560241555015, 0.14221754285597032, 0.24194650111659882, 0.07923425235334905, 0.13080529958730744, 0.19363023971597995, 0.10697056524335377, 0.10895120896278851, 0.16362069114562006, 0.2844201316756587, 0.17819554454857306, 0.18589373227329026, 0.0844121563638891, 0.11368144949477528, 0.15707161998556507, 0.12471124634987886, 0.09869025794849282, 0.07160901152078183, 0.14192941718764845, 0.20038246207179564, 0.10924244494808298, 0.11438903894515769, 0.13253599946056643, 0.12245877931315093, 0.08474015690866979, 0.20001907592579243, 0.12286508936555156, 0.09224103868848856, 0.09682234406711594, 0.13418736326838696, 0.12827542445231832, 0.11966225195435748, 0.11061657685786487, 0.12761331764200043, 0.12322477530688049, 0.17266150924467272, 0.11444271106513278, 0.2013879065071383, 0.11977218557149173, 0.17385852162636098, 0.1791445895909302, 0.20231258995350332, 0.14223677166286977, 0.15610166074287507, 0.18792395720318442, 0.19214212924482363, 0.08746135484186873, 0.1349222867359077, 0.16676296930639975, 0.2550613441534581, 0.19585813065209698, 0.19022954477658197, 0.10716957190344412, 0.16183035898833506, 0.08913121201218137, 0.11975157014544933, 0.13658527975841878, 0.21196684529704435, 0.1931246676512303, 0.16982416472127362, 0.1517967062611734, 0.0761491856387546, 0.13074650999999818, 0.12799590961226534, 0.29171295163612215, 0.16261867878417816, 0.07605354722228742, 0.16869466000747296, 0.20641810110499784, 0.10535352217454104, 0.08180107590892623, 0.15469662484622773, 0.09571756867151107, 0.05204438231885434, 0.10324928549028213, 0.14501995377002225, 0.14522416216711845, 0.14672646058663247, 0.11098158711026754, 0.13177130581630817, 0.18811966202432112, 0.16079292272127446, 0.14467495373420178, 0.20271895363205866, 0.1800879042956137, 0.11310035648245005, 0.04561775882217673, 0.17217191777402358, 0.16981552324948773, 0.1349798812260551, 0.13362479426207083, 0.12170784460801272, 0.109593236608611, 0.19064318629041796, 0.08945840050376232, 0.15145541409090643, 0.12135906775872554, 0.1442134776903737, 0.17960168361183138, 0.13639090793027034, 0.21379856152399895, 0.11991038783303193, 0.09535206812283686, 0.168861789749034, 0.14351131214249518, 0.1683399766202896, 0.29434385078568615, 0.1325401976223915, 0.14573972401840074, 0.1412597644112764, 0.09283846469535943, 0.14180947846222308, 0.10968634693492806, 0.0769754114650911, 0.17895875198225822, 0.1622116103047325], [0.02948329213165468, 0.07139632253036385, 0.055371804778734525, 0.026984037530999032, 0.01720749157210512, 0.03892319990442165, 0.029182987580556544, 0.030656848816321264, 0.0755227632039497, 0.030710308346897367, 0.015052389522503703, 0.059974323131985245, 0.05535766279565231, 0.044685766897014076, 0.017493489431217313, 0.03568201213173809, 0.03323009410392373, 0.03741290352697815, 0.031688966517967564, 0.01022420943744721, 0.01806802281569089, 0.022537563627045003, 0.042170137166976936, 0.039489744907064785, 0.029412446235637033, 0.10252290390311711, 0.03432085009051427, 0.029612504351403446, 0.02096942569609852, 0.023257981219719497, 0.051027469547285195, 0.028045191880195375, 0.03227198241098273, 0.021314950502147118, 0.049262012264901595, 0.015427681632460126, 0.038533199863928946, 0.027072189353226174, 0.05285115334235373, 0.00319943358678551, 0.01891468403740756, 0.018941644586682804, 0.11922478510607636, 0.030755367723383734, 0.015006476915591668, 0.07318626398280745, 0.050107984007486416, 0.021845399357017972, 0.020612610669265834, 0.088199986174943, 0.03685477400018323, 0.05261397252099649, 0.00420152303582478, 0.03728453783438571, 0.05175559781491757, 0.026190609843920798, 0.05920042111087711, 0.034833217355152296, 0.07295993096645802, 0.05592584722645341, 0.036864127933738694, 0.014618327935046006, 0.058194838779708075, 0.032119952262409275, 0.0556386829984765, 0.05448218134622421, 0.0345616813208307, 0.02394297682199507, 0.0894990414681454, 0.028254385594458833, 0.07486152207298626, 0.014327301666320813, 0.027677747383413297, 0.039696174959141406, 0.08785418174680203, 0.04131918202244467, 0.01575925406218777, 0.01734991880854772, 0.046601454021349076, 0.0455245987001446, 0.03655067156820047, 0.02249579651341323, 0.051096559186736425, 0.06407811824652938, 0.026093291779679638, 0.04660336158028053, 0.0366905783753722, 0.008865873303054082, 0.054122177478406704, 0.08857384474287111, 0.02992796403686366, 0.06866464451436075, 0.022430941424963456, 0.05289459435810005, 0.07598400176052125, 0.056305145018643914, 0.056245099047138813, 0.037200578428324194, 0.04470026128054146, 0.07680860348045826, 0.07738064133351849, 0.0472532416273269, 0.0241087103683141, 0.04250073091938131, 0.007831213147109075, 0.07535598586283385, 0.04361536586657167, 0.08965770593814312, 0.03674228164938189, 0.07875258989271619, 0.06801739214889466, 0.021146334550012986, 0.023381145175306067, 0.03923394814914754, 0.043204145190576394, 0.07446616707790284, 0.03692846399761977, 0.020928221657091094, 0.004134747460709825, 0.041355670790278146, 0.0591004274845604, 0.020902161261126883, 0.0052888785496414195, 0.07673854473978281, 0.06923113589084919, 0.08322171701659119, 0.02410139614385703, 0.016563857056861444, 0.030364076824738618, 0.007858123421864285, 0.011617622822673332, 0.0509909961012102, 0.04244866758404721, 0.012459071773675182, 0.0622692276092787, 0.028625921000756567, 0.038583026222524144, 0.028465096162812367, 0.015503532955453042, 0.030274616907380765, 0.06585971317103793, 0.040875808636267344, 0.03081010087513395, 0.01329380021836128, 0.05459923192017502, 0.0689600863223595, 0.01508213958943323, 0.03859061049297452, 0.03589618733272918, 0.03653021319018256, 0.02220545110533074, 0.0070650826091878125, 0.039731227312116854, 0.016528812364765232, 0.009686228023060869, 0.00977920619921098, 0.06087875121363229, 0.02865835141781117, 0.06326066795736551, 0.037813751372478666, 0.03847097437227926, 0.03920153496907123, 0.08497739135618172, 0.028081931541824055, 0.03858740824545103, 0.0328510606120671, 0.03263920282704696, 0.01572603840501078, 0.02409581902376827, 0.03731687823610921, 0.02806449538066743, 0.014556192458727428, 0.050135984521118865, 0.05061092839065579, 0.028180456194545955, 0.007912080430786216, 0.05979601999804859, 0.04293738954490231, 0.020154482429666866, 0.013996672482349941, 0.09489048482669939, 0.024489186020688187, 0.007269200033343007, 0.008998113485323566, 0.02092173672281206, 0.057441839467613935, 0.03909516366078489, 0.01675176884858839, 0.038426817064323736, 0.039627154267603354, 0.024908144184718692, 0.01690543459488019, 0.011533681611200015, 0.009904676079449636, 0.010875695396304853, 0.07431052865520602, 0.04744852126966562, 0.06149924412790326, 0.052408415809153557, 0.043248727677329894, 0.05391751708943517, 0.07370273747871961, 0.05011894289524325, 0.011250577649221787, 0.06702577560058526, 0.009380475629211195, 0.03975443211534331, 0.023707783998801343, 0.03221378654181477, 0.028986729260894562, 0.027631167322397236, 0.07447113132765217, 0.0047000729471385, 0.05515281088469971, 0.05957591144608394, 0.03464387872466638, 0.028748230768307566, 0.01623345865687776, 0.0063041155038762, 0.03159278226385434, 0.0725461055915202, 0.022029321745879227, 0.05903247548567672, 0.04773749346514383, 0.09104922804380618, 0.02283416605824905, 0.01572655072631014, 0.043019238378732436, 0.054049927726267814, 0.04279998784524299, 0.05177426354719266, 0.04719627532927741, 0.07549306197512536, 0.005190903086200236, 0.018892708805299575, 0.1174648283349891, 0.04451358480559242, 0.037556514369263765, 0.06994170542325705, 0.047527918622138045, 0.040439257263055736, 0.07299799787541551, 0.05941780622027094, 0.06698369439090453, 0.03183614924520014, 0.004392814232907709, 0.04794038036057065, 0.01823878955967244, 0.0404992074735703, 0.03798461962311018, 0.06595438631672053, 0.012000963643884227, 0.08334154848970714, 0.008433002024708737, 0.03349666588849599, 0.027271274537328753, 0.11983661356592372, 0.0348873759409593, 0.03647734546252797, 0.03672295325105229, 0.05712418110981103, 0.05739636831886827, 0.072485898741551, 0.023450564232564742, 0.01972577005114046, 0.04834531145470758, 0.009873925310169018, 0.03803657570613488, 0.08611087206630938, 0.01719239580955717, 0.02148940787470389, 0.06318326243349622, 0.01827597546751701, 0.030820820360414447, 0.016251166779247504, 0.016245758198502085, 0.041499120754099665, 0.02392519017561309, 0.01947516545413002, 0.04342880047437164, 0.03463606845827834, 0.020807901802923412, 0.04190016395202087, 0.06969114870674188, 0.034857724507850026, 0.029590339512534203, 0.007701533134921544, 0.03989413207877548, 0.01576045682022889, 0.028256850482355204, 0.023295720626089363, 0.046886128463572076, 0.02090600893772658, 0.03961711085491604, 0.02350581066322423, 0.018026261447718548, 0.03212760931121246, 0.012518633194568177, 0.03314059205173004, 0.035682759067464265, 0.019720869003644875, 0.04039272891297456, 0.03157486155208561, 0.031104968117189505, 0.035254266939216086, 0.028909630172194976, 0.07888493158163563, 0.0192189799065912, 0.10705959232103442, 0.03991950491082765, 0.10624287364583825, 0.021115855741945487, 0.02556864795605502, 0.0409266462309226, 0.04762403967399751, 0.030856094878887942, 0.04439870609090694, 0.0590259560774411, 0.007119399200629204, 0.029858849499554887, 0.034686978831286394, 0.06883667721863716, 0.05184280543377803, 0.01087324487255706, 0.03666160109963629, 0.10220481653607662, 0.013986599383755557, 0.03469769640134708, 0.017706739581039837, 0.010085967913900894, 0.06798983596625828, 0.02567418805894352, 0.04925846144737256, 0.03202201558216926, 0.026076725128317074, 0.029388306805142955, 0.04434299234661364, 0.05174877580195185, 0.056466379713627605, 0.03626166872920529, 0.043296627324795535, 0.026195960968071898, 0.016519910423085093, 0.048714696069157896, 0.0468471001142696, 0.04283082288419528, 0.03282177690116148, 0.024413994490920056, 0.018666059777681387, 0.0657278387957523, 0.026753085004466198, 0.059373066685492956, 0.16385655429574753, 0.13160351723913224, 0.27940976343327956, 0.1387440695637657, 0.16860484385923033, 0.15988311670239896, 0.1779100389009522, 0.13533183734022802, 0.2063074167216978, 0.10390292702903671, 0.18374758291869395, 0.18351519780774272, 0.20345012326875042, 0.10868976613686931, 0.10026259212604455, 0.21587744835884343, 0.12273284726806226, 0.10838080287700701, 0.05974400262798994, 0.261199516394446, 0.1450896524493733, 0.1569287139441698, 0.0910802469438603, 0.08304606071643292, 0.1336610302208893, 0.22116449691595572, 0.19779820235506182, 0.13713891617953777, 0.17341538572744017, 0.13830333918092713, 0.23324870654652197, 0.17417411920764755, 0.12205627671773396, 0.2067500010373131, 0.15480891801416874, 0.20541792735457423, 0.08424737851225561, 0.09636004064832965, 0.15095462241480428, 0.13182603513761876, 0.12964424737278493, 0.0922239549277771, 0.1926727064194218, 0.17445355743890809, 0.14653454023984172, 0.21351270347593293, 0.21555042074572658, 0.10272069248340784, 0.20873406150889015, 0.2137282499743085, 0.11914666712043748, 0.2103650167344078, 0.11496188885141766, 0.22949029451176045, 0.12607729603205958, 0.15957352525043875, 0.1251695507897004, 0.10562417337731009, 0.14759829928798063, 0.1648677443905223, 0.16584784663732977, 0.13427573917133195, 0.10139339918931646, 0.130923981928537, 0.1502036723879076, 0.1582912319610196, 0.2328481344926742, 0.18520411524561145, 0.20849858140272481, 0.18525997837705, 0.20557921950615224, 0.13921882957220078, 0.13663161275607927, 0.13327774111061327, 0.19751229834172035, 0.16893967024741635, 0.15114602182180653, 0.15372452055734975, 0.1706592465240148, 0.1493794690336912, 0.20141491876734843, 0.09768494374809727, 0.1829417503529018, 0.07450345257717757, 0.1101668602636745, 0.11457813242750783, 0.14403261965320957, 0.13754451377016885, 0.1106275165934236, 0.15115863162904017, 0.13243631609985906, 0.2205555949119791, 0.20289291687790426, 0.11028066262482636, 0.20077541921167605, 0.1637118709303679, 0.12390001286422053, 0.08258679866670601, 0.07742417811025536, 0.22421061572047973, 0.10305710467359713, 0.13902497868384087, 0.09651662902005258, 0.1819265612791623, 0.0784396582974061, 0.143471077204712, 0.16696927678440848, 0.2182047162204981, 0.10296862151834274, 0.08286596110631382, 0.1985005977293176, 0.06414841447446136, 0.1005493005317065, 0.13078815453956205, 0.10651277408244149, 0.16137873483521326, 0.15641489877335488, 0.17480441038647007, 0.08618535879518717, 0.17348110074958495, 0.15239607813137193, 0.11327822677670948, 0.1288609837572421, 0.3375208726333034, 0.12677907853597595, 0.21071291258258207, 0.11323288969335057, 0.1169496571885482, 0.21251257569078477, 0.07502275293753033, 0.17870882345784098, 0.1397051881518095, 0.18566765972683508, 0.17950365500104043, 0.1856843451218259, 0.16586598759937674, 0.14909661405028837, 0.11865456288139667, 0.1471069304933471, 0.15947479183875746, 0.11469794857886531, 0.12647831241690344, 0.054609516650558486, 0.0834959764934836, 0.19674029621866443, 0.2069216200541104, 0.15121356013321108, 0.09254438652386589, 0.1181297313662306, 0.14789921862463798, 0.1716503804369319, 0.1907364191908029, 0.09546211665315975, 0.0837109943911914, 0.11557380924181593, 0.10071028624811482, 0.18264643877985018, 0.11758334979775453, 0.14132734868795643, 0.09538106455077087, 0.11482967739744533, 0.1708704722864974, 0.20184472473638676, 0.12723858573383864, 0.14881446386777586, 0.1187913019150015, 0.07759654023233922, 0.21059243759560972, 0.1654768608991177, 0.19218267061777655, 0.12210146824438727, 0.11776476707910338, 0.12713275068709928, 0.15771076714079227, 0.08980857929395092, 0.1415361536125983], [0.04706055136217226, 0.07171992573045916, 0.0543691948687117, 0.04956259452287228, 0.04377006200112162, 0.12300907559092007, 0.024641413436902147, 0.013774505069088793, 0.03854832626999386, 0.02746451255534926, 0.01071025966666639, 0.04184716981985877, 0.02736615452675089, 0.03484639789788954, 0.028107229680303606, 0.10079428012813292, 0.04375082170290332, 0.013589081147895947, 0.04217941066130035, 0.020961282181463415, 0.07669349110895589, 0.042563312641915776, 0.032689373925208084, 0.05863584495419937, 0.05735843930573714, 0.02941677463240922, 0.007500752981286497, 0.03441377272528987, 0.01720258094851048, 0.08985819114792733, 0.023547886127245524, 0.052429395126959974, 0.03137404692449397, 0.011024733013924091, 0.06862733603244828, 0.02611754995380198, 0.02078227807707604, 0.054024451472345865, 0.04747931800422169, 0.10682834868109035, 0.048822951953737974, 0.009639337696435471, 0.015154912196580442, 0.0187917365016596, 0.03374602750784928, 0.10206955605216565, 0.03760616835807601, 0.07133927196264267, 0.01713662652388936, 0.024811889067472472, 0.02521611153027944, 0.07860225279845538, 0.030401630454786846, 0.0405219717762403, 0.022167405263791164, 0.026600905468747504, 0.0637714187764833, 0.02768543124529383, 0.022050728157703436, 0.036985617987210714, 0.058942801063700076, 0.03760937443603912, 0.038935813542094924, 0.029969053162682443, 0.038089860951708215, 0.028086631491239515, 0.018475259834479903, 0.05617690573055899, 0.04475966373819017, 0.007566298027673076, 0.0395490056384475, 0.0395815950187464, 0.060801855138232636, 0.022366093997392925, 0.018232909834853584, 0.03799995670335428, 0.013332965505880215, 0.030114119572024194, 0.036324449634600076, 0.061054311752800024, 0.06822426653196735, 0.032548394594942374, 0.07580614678802029, 0.032357964289164355, 0.01609598226364582, 0.06660461876421206, 0.0330881265202357, 0.04195489327333147, 0.04513639896627396, 0.06869122776533328, 0.043767304084594214, 0.014458841835749487, 0.02315807569351408, 0.03926385239127182, 0.050154301683388414, 0.0387716906956367, 0.004993232770732815, 0.028619370949003967, 0.0659472233946285, 0.017818257084957535, 0.026955964239013773, 0.0548560897098674, 0.01803746356839134, 0.02518046162872305, 0.053824441237074715, 0.04979508688613292, 0.0772988154823261, 0.03483405239098976, 0.04477273702861802, 0.009689874601580445, 0.056433361324091116, 0.047175303672350226, 0.012412933170825485, 0.05011053891071389, 0.03085631321394636, 0.007898122308805825, 0.01216050049650573, 0.025236014494552247, 0.052865781791267864, 0.022167790222973115, 0.03886265980620538, 0.03774137521583227, 0.03673167899250984, 0.01576903700498083, 0.030104432390221668, 0.05997105959742781, 0.14413175143061147, 0.01750926318157825, 0.051018111783290104, 0.01312786365874232, 0.038429348984913486, 0.02001548726712504, 0.01883445547953729, 0.06909781360938665, 0.03153086703781399, 0.04408899206487883, 0.022304891233122157, 0.027045778472036607, 0.04575195444387294, 0.04413617158969564, 0.0164831860832149, 0.022090932451969674, 0.07829741875250494, 0.014959532005201667, 0.02935872048950724, 0.010812467287084269, 0.02550765203552381, 0.048972848547442306, 0.044418168554623286, 0.012321655709867277, 0.025684589617735436, 0.007143955670237061, 0.04885953265212236, 0.025794557708826278, 0.04598348919722823, 0.06450129372458305, 0.022905496504878806, 0.017375599990989414, 0.04652967158284399, 0.03372787122404383, 0.01887231937519485, 0.04160381049939221, 0.04057999144518568, 0.04391821574479823, 0.048964103653786645, 0.04731637493316685, 0.0624657751271321, 0.04091117125485213, 0.06957431263740986, 0.036743775520834236, 0.05368393688132206, 0.05048954558949317, 0.06723127868627349, 0.04132074101137058, 0.05354603722451195, 0.046635732625521, 0.03326343425038842, 0.03953833020322266, 0.019471836802099022, 0.05871537637205855, 0.06175730467563676, 0.04340799735678781, 0.014599685185408641, 0.030593870643285975, 0.014636924719407916, 0.029909428539535696, 0.01642203502987902, 0.09266810972363719, 0.04262821944130044, 0.015513381015719667, 0.06112164705090466, 0.0465588633631987, 0.02286182757797501, 0.006888032507812305, 0.024664097300340092, 0.04355565697375325, 0.05534901366298718, 0.1032045919207796, 0.013273145530312775, 0.06443535653694023, 0.08275326191177292, 0.01964609307657567, 0.04560927439841532, 0.07106855181196044, 0.057604506747016025, 0.05801384284671757, 0.014045865860797707, 0.014996665244501446, 0.006736492176705431, 0.0716606764903953, 0.0482691086888794, 0.05378645093690965, 0.05928233123174118, 0.029683572412919135, 0.01575083858633955, 0.028821298319305626, 0.0030930057795147503, 0.012004086409785576, 0.01210063072522321, 0.03388769631724685, 0.012854949623766928, 0.08669849214774948, 0.034299698402924884, 0.07032400628011073, 0.024532579155939243, 0.03191467708787851, 0.020059177261446754, 0.022450093623070468, 0.008847062014073374, 0.15204122620484523, 0.025488118708674467, 0.020846978032721147, 0.02462489466603485, 0.031185947441225572, 0.024416719848710685, 0.043720358216594306, 0.024924302894261577, 0.02266737531059452, 0.050639354083086216, 0.019440976865289193, 0.0033455181748591246, 0.02033648193783818, 0.035352693915727644, 0.053357035672712716, 0.016685517564896616, 0.024689659739153522, 0.05297507572498533, 0.04632244479932612, 0.04599630967864106, 0.028431955199207992, 0.026127139459394162, 0.015971634702216235, 0.009996411277942601, 0.016607206142056855, 0.07285593453073695, 0.06910619461127827, 0.026397087776492682, 0.011939740769805448, 0.03139436740668551, 0.020278559945103143, 0.016650532244614536, 0.036494547966867685, 0.024553456967095696, 0.08226094316811332, 0.009584340244351376, 0.08173643340987545, 0.021534166561679977, 0.02311587957064471, 0.025330846603479118, 0.04639732606348492, 0.02322362600675514, 0.04708749084402958, 0.049817161709671064, 0.03537940357120768, 0.017101876775644, 0.025134862160250068, 0.09621531131767458, 0.020693760447865053, 0.03885435158266656, 0.08445671203756526, 0.033435260110925284, 0.013381016455710897, 0.023093601733806635, 0.06988449397707178, 0.016149520318234162, 0.038072359673078024, 0.0681379743881764, 0.04712771812093355, 0.06089157935592437, 0.03498214867807204, 0.027502487533755844, 0.05450128374861614, 0.0300531983450656, 0.028910742914904992, 0.017196676325834086, 0.0753185011806988, 0.023749581755950086, 0.047450873159593156, 0.03492070459610513, 0.03234624697436248, 0.029203198895218874, 0.018148314575814915, 0.07645273265699226, 0.012633475520077252, 0.007753346534070349, 0.04569716766596802, 0.034081746388467095, 0.021854393229249026, 0.011918191674105343, 0.026585729266967506, 0.02143819872740536, 0.0064304874526456965, 0.03629675555613734, 0.03135357897037701, 0.029296525641374534, 0.09298779055356018, 0.046951268919773644, 0.01708079595118761, 0.01920884839379259, 0.004518794040420964, 0.046644787784786, 0.019603935258102514, 0.049422978829111786, 0.022012954277376977, 0.0627393872597285, 0.04395213045720612, 0.04615516184018024, 0.018430683093385834, 0.012567823700186227, 0.014247296231558487, 0.007551131880797086, 0.034711263818486084, 0.05091938603248808, 0.041723098050081925, 0.04915170709512407, 0.05287176876839611, 0.029619245925137115, 0.03410543765752547, 0.021438336623231732, 0.077074543242493, 0.08129030210717071, 0.008964413277534469, 0.06035569319201093, 0.05090173536671266, 0.05602618176189642, 0.06545548687779135, 0.04225881950509164, 0.07394041625722762, 0.05643371372453629, 0.04179611772058472, 0.05321684158256939, 0.05545977848551928, 0.15265576661594454, 0.12975920652670245, 0.15029069997610586, 0.23805851297032452, 0.15789861189982585, 0.21829820959077728, 0.17385652979775784, 0.1301864384403152, 0.12671511019429854, 0.0974364631298569, 0.11719255302582057, 0.16972212180975946, 0.08838102807320895, 0.11587790018247983, 0.14908705327299335, 0.16849477234626972, 0.13157668884002394, 0.10333750051476302, 0.13192162758881046, 0.17910551910679187, 0.18566015206517714, 0.199520199469501, 0.09684958615370336, 0.12716262811614623, 0.1475591368732914, 0.12695520981064728, 0.1709417950722479, 0.2118978820621006, 0.13168889007741405, 0.14286038255499256, 0.28755548440160295, 0.11870013745201212, 0.10514474789341612, 0.09536667741955289, 0.24894551103634222, 0.12538679034238862, 0.10514654053915894, 0.10933055272025448, 0.06269956600942439, 0.1668112481673879, 0.09820642745903424, 0.12090849314605999, 0.11620391655953662, 0.15001832507550716, 0.2251780468730196, 0.17052214742908556, 0.0717805156243905, 0.1434868279724352, 0.09341024207852541, 0.17191915472428645, 0.10113302122561202, 0.19126607705989193, 0.11670162090130391, 0.27621309302987596, 0.06942664152912556, 0.10713436250244418, 0.13036438534336706, 0.1535642243200733, 0.15753522575382264, 0.15644705914441617, 0.13361365534365177, 0.14427979026109944, 0.17986198496674338, 0.11408354606359236, 0.13213642332102024, 0.11105843338995211, 0.1141127953005414, 0.18672876811075598, 0.12197702492196714, 0.11290550967978855, 0.187943032792499, 0.16843222892813145, 0.23382635216318795, 0.1621428309308906, 0.09597072242608956, 0.09162129654038338, 0.16706272418941223, 0.09759200196112357, 0.19629984162747863, 0.23267812426051787, 0.14863539847635454, 0.1372730734968378, 0.14001058144194467, 0.08431896176790038, 0.1262374237299927, 0.1259285370789228, 0.11683381703351775, 0.18733757818418165, 0.14112672558234585, 0.21692957819229175, 0.09255103616704864, 0.10459912475198509, 0.04734099316861361, 0.17211979315165551, 0.09998077902221873, 0.19144719556695033, 0.1626653641822838, 0.16900261203127523, 0.09076804313207827, 0.10289354490176325, 0.12375624114347082, 0.18193765423230587, 0.18199914044910864, 0.18870810948071942, 0.15105563876849992, 0.13238524867882653, 0.14079220562932954, 0.10660867296880293, 0.08907719515264036, 0.13258559599278436, 0.21309546134885282, 0.18486107639487714, 0.12759164501462253, 0.18520668930103704, 0.12902213801299373, 0.12980748538769063, 0.146221746540358, 0.09603276022619779, 0.11264338503561674, 0.14373147049017493, 0.12196708110070999, 0.17346159615103277, 0.250004091330113, 0.15225563889309285, 0.07613607021349092, 0.11889951949518536, 0.20152215575498922, 0.12011902421833047, 0.11953737196182052, 0.09774882015922377, 0.16967182047665122, 0.11559824744660048, 0.07817053160960637, 0.14217249688602265, 0.09614065604945345, 0.24917343751557414, 0.08719150037054094, 0.10392757973844007, 0.12513818715008038, 0.18352167891158214, 0.15281495968661002, 0.04646509803170639, 0.1467030949049419, 0.0795973627076995, 0.18667160262984617, 0.14711361078004684, 0.15975004722995145, 0.10050793944467461, 0.16432731532521788, 0.17992940070408006, 0.09444633769171853, 0.07888246477851946, 0.1306829093805244, 0.19071316076142175, 0.10296974000671219, 0.19609846775570225, 0.1125247716423004, 0.15294237543017636, 0.11104090529824458, 0.17009634043901198, 0.14543394768430343, 0.11899002512255985, 0.1369205351558424, 0.14353570438200428, 0.13646045339203652, 0.18984510653441955, 0.2244318925565289, 0.20039841202237915, 0.13258335901604545, 0.22254210686491382, 0.09997795215777813, 0.14953625658827444, 0.19611083241480012, 0.23466426849124894, 0.17314146332923444, 0.14254267057103498], [0.030526102505504128, 0.02048696075836497, 0.003115560844420426, 0.014535302198642205, 0.010188121908164073, 0.12148525010073379, 0.042361800874313044, 0.01931613709236826, 0.035874763683926676, 0.033252797119559786, 0.08484284333404034, 0.02430097353945096, 0.03846474224701524, 0.07282288549768348, 0.05858897952543152, 0.057263589959831974, 0.03248973907301984, 0.03666028342840653, 0.045331778200042826, 0.07792791922486599, 0.03870907449914563, 0.013663148443635195, 0.01756521058268845, 0.09174695028172386, 0.028353136243118394, 0.013628821001358092, 0.034613920856387384, 0.023763124275231556, 0.08532800681648717, 0.043642994827560844, 0.028931444525838863, 0.04104889088100003, 0.05131786666630257, 0.032557767680695945, 0.09339463686750782, 0.033119562938208544, 0.019887261385578784, 0.04303578970833652, 0.009781536064110696, 0.0518702007379503, 0.0298148243417663, 0.037485187753073634, 0.030245254672462904, 0.06671448343343313, 0.050196382893069144, 0.044341601897031076, 0.011088238830017227, 0.07267123073219292, 0.05660887589798339, 0.04875786895413072, 0.053558880688562516, 0.014026400524251645, 0.05806148202428895, 0.0379875039441451, 0.04774870516191568, 0.026347058404597546, 0.02467433415022829, 0.00501539952482187, 0.01106900715028807, 0.04987907310527179, 0.03426054747955453, 0.11174134714829345, 0.026992784339874506, 0.059676820547470165, 0.028357637009673545, 0.029864744546132225, 0.047318470183639764, 0.024238307547244816, 0.03349648202739416, 0.03188126990872045, 0.03219672193330142, 0.07000561247790052, 0.012187575958969613, 0.08595458246887692, 0.06318790109587774, 0.07928070792507741, 0.04558363343558965, 0.0767898343263134, 0.05402663865336969, 0.06061057064441904, 0.04861680535419334, 0.046912615953554074, 0.022489252207320065, 0.014538089801076681, 0.08261122154973208, 0.06230827511077928, 0.04294827565430634, 0.025059490599819732, 0.07376273748494926, 0.05409768947790708, 0.002226782981456528, 0.004899360665736059, 0.024550097671547727, 0.016244555440460964, 0.03631595754995942, 0.019507356468708287, 0.07243687677527628, 0.06989822227267489, 0.04826874479711537, 0.07608854211866856, 0.035509895157789996, 0.06833095193630265, 0.09486380964517595, 0.06615737663401712, 0.013290713841636336, 0.013388732876328212, 0.027540989197610367, 0.011772922251463659, 0.034135368712727106, 0.044350584277943264, 0.043290180694912715, 0.01478099138400848, 0.02497090976835499, 0.06604856150525232, 0.048269181467232206, 0.041014129641435804, 0.037665812133420865, 0.046295539791425394, 0.05931584374798883, 0.0615605503140438, 0.04631367309259311, 0.0252298666389599, 0.02984279229666197, 0.05307005913627725, 0.03388640162865481, 0.06628084702477341, 0.02883621596641118, 0.04319472613954737, 0.018014831415888284, 0.0026689375696268176, 0.057997988657124584, 0.05308811965909216, 0.03248455265777246, 0.05158812333379061, 0.024396295944649368, 0.08669196507863461, 0.032266983687276804, 0.06468661039346649, 0.02503831592959262, 0.03353283289940127, 0.005774928778860598, 0.09122532101408129, 0.017462784627212152, 0.0925557705904207, 0.03363327085671406, 0.07017051290360189, 0.023766600399187977, 0.012773279862989102, 0.02859381042541035, 0.036036887040902535, 0.0380032891858249, 0.02279283369951431, 0.05255212241242971, 0.030665704792725946, 0.09696428483772664, 0.050536453153096864, 0.007834730448291428, 0.06284211581993489, 0.04864016720544427, 0.0269135344593275, 0.03629934876376102, 0.0803911600322012, 0.03936260112471158, 0.038641505544224096, 0.038339264705897345, 0.03772121561210483, 0.06794724913854754, 0.05819487708410429, 0.05898131613409328, 0.04827341793345348, 0.08542233522260383, 0.043361423041431174, 0.02826632124431912, 0.014161141025984, 0.03998716962673972, 0.02023634467003567, 0.06992830654546138, 0.0417353707786289, 0.04320465080860642, 0.017905543227830244, 0.1133176726439307, 0.05611300250635513, 0.05840005841286433, 0.02828993973502469, 0.04805455810480541, 0.03131532053943844, 0.0714208679874578, 0.01753543466029148, 0.029384198658649, 0.0323844594400256, 0.03773231622612765, 0.041156468777767116, 0.014361702844560629, 0.040449653076188224, 0.036241968778232415, 0.11154728175531473, 0.02539233282028187, 0.03721296223962019, 0.04853777955436418, 0.0505923890628882, 0.02092769880208277, 0.027668046795072097, 0.038643206259416, 0.10297362407248828, 0.08607649004026767, 0.09086983323457742, 0.06494224627291964, 0.03512676692597809, 0.04990286779619994, 0.059390177259281765, 0.04055964414991679, 0.02268292306501779, 0.02912206060793852, 0.07807109339703476, 0.052690899239913117, 0.04720497425765761, 0.05535320799437262, 0.03331805631938962, 0.0344644456110414, 0.02800068791745411, 0.06664244052503379, 0.056699128716342875, 0.04197206130371459, 0.05745217016327286, 0.059286743898185036, 0.03064713865188101, 0.032494289635290066, 0.04036575112672102, 0.03488827226383071, 0.007907218166491798, 0.01551747096762542, 0.05411840066494, 0.04837554894507893, 0.04730005342994006, 0.07903083302681485, 0.018763804935940334, 0.01753725603433146, 0.07345079414306149, 0.05228828939218676, 0.022649826151469064, 0.07868340449227441, 0.018395808855852774, 0.035118680867937305, 0.05300958032509493, 0.08064628263274509, 0.08145913256392365, 0.055654560170707204, 0.08966576518310655, 0.09101458554787022, 0.11236983802049391, 0.05953008023601386, 0.048578432010066126, 0.023594288072819193, 0.07121649105101824, 0.03591665720206595, 0.0369666075153697, 0.06278635994080575, 0.025434557671448397, 0.014042493158711061, 0.028834270103083506, 0.07606788072735071, 0.02963559615666107, 0.03711574951246862, 0.08601249871595253, 0.046336356956031055, 0.1024139432176467, 0.07708963517460131, 0.05090360079080828, 0.02116246070081909, 0.037403921146065965, 0.030832200596529632, 0.040246256732291756, 0.0627480517141521, 0.022072745524647257, 0.036169278525537064, 0.04078599631846432, 0.10474895622821585, 0.04372555229272093, 0.078425110287724, 0.08804491465731014, 0.04063210840667448, 0.048243578808802756, 0.073563102632761, 0.010831448073018222, 0.0625513969439893, 0.012880626018159093, 0.054976625983873685, 0.020165998646388614, 0.027581637822872693, 0.05034420338849868, 0.030630106602104443, 0.04414140397021848, 0.05315645087149836, 0.018132864497601986, 0.021337412200087023, 0.023430063719710997, 0.026896374089823618, 0.05778660201617788, 0.055525918686462034, 0.01861208888341583, 0.03737439611746419, 0.09453160327769096, 0.026732674506943555, 0.025993123868360155, 0.06760227974624404, 0.1052652458630262, 0.010155481774540199, 0.030170080379673073, 0.02995072067865441, 0.05828552060730516, 0.028897118041171666, 0.05302182624056455, 0.031126669472864563, 0.0649235001014125, 0.048383650324878194, 0.043733075276137366, 0.0361809192315465, 0.07671288845519866, 0.0492024144548322, 0.016654019859889825, 0.029093261447645007, 0.03310761196658977, 0.030504052579823523, 0.021165046247563536, 0.06649999413639307, 0.017922757223488826, 0.07282557446629771, 0.031724873058978593, 0.08271013882251517, 0.09724184615357269, 0.07785088908407958, 0.09897408586355949, 0.04242219158538407, 0.03931709933244894, 0.022107292259592685, 0.0819922301677927, 0.034596044194674304, 0.02343878563072893, 0.059619283513917085, 0.05162185801553631, 0.018883165264982852, 0.023364722165429307, 0.03647423131511577, 0.11800632992338751, 0.017010748701831026, 0.08980697817018918, 0.0399636124230681, 0.06228694722296731, 0.04978373346309509, 0.021363750302923784, 0.0556225415259119, 0.031066096815911513, 0.16602266790165057, 0.19448871784392865, 0.07879889990773895, 0.14625507136506422, 0.12506288836800283, 0.17445711208687675, 0.15074092984920548, 0.0913056836373383, 0.07847070018009794, 0.15288453579189318, 0.25760543021944265, 0.08304096623173646, 0.12595290633579417, 0.18839323202208166, 0.15450300378424509, 0.11710979254736055, 0.15357534791673386, 0.16500597729557948, 0.15403444908799666, 0.2606084948826221, 0.11178719751056164, 0.11627168469731847, 0.08153497526842741, 0.2345477465179659, 0.1347987473972382, 0.10914011092315759, 0.18514059123493012, 0.2237492316072026, 0.21915235166107455, 0.17659760771259186, 0.1463748568729047, 0.13895840564322087, 0.13607265968476573, 0.14122366634828432, 0.1384775782184255, 0.12288102399437659, 0.05194482536265447, 0.2033256952680888, 0.18120758776222506, 0.17518883330687401, 0.10485417074373654, 0.06807630431027183, 0.11704748661647882, 0.18955531079442273, 0.2135421365739838, 0.11511710592575612, 0.14052317087208072, 0.2486096121250622, 0.24294102113814126, 0.08417590250892025, 0.1184880536710543, 0.12643709688657714, 0.18135729666438796, 0.12845071303027292, 0.1427913580330149, 0.16056540992952165, 0.1757902123274342, 0.12820163486345162, 0.16300624266507166, 0.13355255217081116, 0.11368765480696194, 0.22471122353548006, 0.12109014791466537, 0.12161677207557425, 0.15683560361785276, 0.12838191833467255, 0.19249442243768325, 0.12132866172901086, 0.14231981559386178, 0.15919077240170973, 0.13920413600581308, 0.1958295708942798, 0.23900029549915947, 0.24111886568848165, 0.14675862095769376, 0.23242551442836565, 0.13511100483517494, 0.18151731711001168, 0.21202637032876093, 0.12201100092140899, 0.16749046172105497, 0.16261406693487399, 0.09724776801322738, 0.12397109816271452, 0.1886272259176739, 0.09803634061808549, 0.2063544851637656, 0.20877533832625036, 0.23124661236520738, 0.18526635222858, 0.10084622855027837, 0.13612787930234788, 0.15089043956850806, 0.2444046474392376, 0.19122775734191944, 0.1643609465850938, 0.19964490326181536, 0.15304924469561348, 0.1403139522599597, 0.10452554966773718, 0.1982284832986132, 0.21418270865275016, 0.2503198727725014, 0.19701487745248503, 0.07167292623630456, 0.12418939491673825, 0.18478655136160313, 0.10778087176262371, 0.2274526998160347, 0.16566150341062777, 0.1626646593813935, 0.11558765245060768, 0.12387162930662594, 0.13060021784997758, 0.15758312157084867, 0.12331544181271908, 0.13545554521824085, 0.11139944210768708, 0.12343823804610199, 0.15330373910405945, 0.1336875368630694, 0.11933050523962706, 0.1976152145934682, 0.1545700364776196, 0.1514484426907955, 0.19414068409992805, 0.1042221405453259, 0.09840852911433867, 0.15900547105458476, 0.16445912841346957, 0.2292292883559581, 0.17390606504294182, 0.11317027732729913, 0.16207968996417138, 0.09331366137391137, 0.1696199716459359, 0.12098808968139273, 0.1618716358056953, 0.10036551603867162, 0.17912539142754771, 0.09585748697000165, 0.2098634436486229, 0.20565003667387272, 0.25679573657051213, 0.13901031576097012, 0.18158016696331963, 0.14923023510604136, 0.09308241773396732, 0.11478486125387492, 0.19061166943321306, 0.1791974803012225, 0.05319268299987721, 0.15008799311134124, 0.12625985478441562, 0.1520745816730684, 0.16779053836099564, 0.17188316391360375, 0.15345677282781373, 0.15766107867802345, 0.19933206359705619, 0.09017280047579158, 0.12466562581398796, 0.12892977845284248, 0.13571581592963589, 0.1276926307248012, 0.06301861864724947, 0.10876154091449515, 0.22052657550140736, 0.22160660625705797, 0.20465171685622585, 0.20832287147641185, 0.18301230705072805, 0.12483865443256595, 0.13973152625464624, 0.11832658531925372, 0.10639647427465647], [0.029763283861440518, 0.03958114685731069, 0.06608192463435474, 0.017353804789543632, 0.053125386006168784, 0.07106942515219412, 0.03696293412377277, 0.0557143724853954, 0.06906239736464716, 0.05032132800307967, 0.02075914030654296, 0.053791507117209904, 0.03424033041923277, 0.04485711395259827, 0.016031378068991246, 0.06864391417512972, 0.031650962811263825, 0.041725580174956596, 0.06953517320535837, 0.012850957348071521, 0.06570466463604281, 0.026808369739521897, 0.06913905212235066, 0.046222294124984936, 0.03825788318570103, 0.02250682817952287, 0.01595123473840255, 0.07755441305738303, 0.04804908440658643, 0.029518426839081995, 0.07755516382354884, 0.028314215146125327, 0.015538027021853675, 0.012926321247622613, 0.0273625232699898, 0.03430631740259067, 0.06087200963989862, 0.03777535504571373, 0.03503020920400177, 0.04645338454734414, 0.053798949661394285, 0.03581748328982823, 0.04508177689727276, 0.027163572151273973, 0.038280574710018216, 0.0506261965229867, 0.03702327503912872, 0.043876835505568215, 0.041556041086873705, 0.005170254622616115, 0.030736816904297283, 0.010846250806935133, 0.008572927984078566, 0.04984675568618602, 0.07963221204737503, 0.038973872790173184, 0.02730035715015425, 0.06776346464551265, 0.0410721339886227, 0.012274146767243022, 0.024827352552224072, 0.04368009263529413, 0.057076580236635865, 0.05774391942747659, 0.014351317565137101, 0.055910590585441365, 0.0203851304362498, 0.08246855299559333, 0.07398432841704738, 0.03681781408827632, 0.020386204874563604, 0.01966679660272935, 0.0036098563343271496, 0.019517863364589792, 0.02942666482751168, 0.017644778389724034, 0.06504968244342074, 0.05217817957482992, 0.018980818492690885, 0.01952741648100557, 0.035671187309368003, 0.007580122084266717, 0.06927199135985106, 0.04613623563801089, 0.043531858452385476, 0.05635562638241438, 0.02763307488132869, 0.040226882368686705, 0.03068245913562996, 0.059386094010645346, 0.02821925663269095, 0.031393789010302674, 0.08100908655192583, 0.02673547647352661, 0.022171205059895595, 0.04085649555969623, 0.020518399091557633, 0.12772315932858375, 0.0076547112774043805, 0.07184376384341909, 0.004924425147398706, 0.03903553903763814, 0.010456823417165828, 0.06208990557840275, 0.020695047475577846, 0.00496652024242306, 0.03352887222483274, 0.03177879607274888, 0.006935604652690311, 0.02936799589905047, 0.04823916231191928, 0.053561320678601344, 0.014534476738903793, 0.036500389387290326, 0.0448277689546587, 0.036519127897918224, 0.04950043797913579, 0.013032080643179436, 0.10125739560011895, 0.042340112925176664, 0.08580413046142749, 0.14656507650450354, 0.017878396902233362, 0.0330060861644245, 0.03544936655089259, 0.05027885991899718, 0.019881364423781633, 0.05598911076724049, 0.03530739130632531, 0.07147945839190675, 0.02317762817256153, 0.032586664517199805, 0.02168978391695888, 0.07001592402136134, 0.03061061924053056, 0.03914073823140033, 0.019687682074765046, 0.02329781587656227, 0.02303794927654728, 0.0281299403568189, 0.06048670571838176, 0.043565999160731034, 0.06844310720841731, 0.12402169827011325, 0.009982362183021202, 0.05278107161904055, 0.027261211972443328, 0.07708904528689962, 0.0637966690344676, 0.028298177095430515, 0.04125129897147417, 0.009714059039740073, 0.029121233232980295, 0.031306148551764994, 0.004496609091743707, 0.03823343348959762, 0.06594634239351557, 0.0173561432729325, 0.018325807571771647, 0.009093154353209803, 0.021893069178106326, 0.027786972369217587, 0.018251498958336252, 0.03613046085041377, 0.0875356423878862, 0.03589706450340248, 0.07386052094760441, 0.02758789101555463, 0.04685605951254407, 0.046703879976825374, 0.0466041429899633, 0.07783739061485376, 0.03887207502679479, 0.028512980488519517, 0.05036765717030053, 0.017659638580235264, 0.024837813482830123, 0.017435592336339817, 0.023859620710173925, 0.05434939149586905, 0.04398571575180658, 0.02482551202598599, 0.04838735819043172, 0.06048646823112523, 0.08931909507561116, 0.09547147824759446, 0.01876748407319669, 0.0493877234628364, 0.06776590080511186, 0.0376967812377599, 0.023616663585867614, 0.026175607927143577, 0.008938596114486216, 0.03621525912275238, 0.05615984878292488, 0.10367025080467425, 0.02183542297702403, 0.0281711214131886, 0.01893022796139121, 0.042005543176445274, 0.04249267167441788, 0.06635442976990054, 0.023479131651261163, 0.0932756327693501, 0.060016220480564146, 0.028923837272750757, 0.07662509477907613, 0.038527825757140116, 0.019847568455002, 0.03391817895575397, 0.029279575946049827, 0.02639476078442268, 0.038335947545185205, 0.08240605554273052, 0.014646053614635623, 0.03019381378356728, 0.04342656732807237, 0.01869527262545401, 0.0012445166559642061, 0.017695483834212346, 0.013459506951602957, 0.022420089789516023, 0.012546611683172806, 0.03895054158243922, 0.05291766892637938, 0.050779222585861726, 0.026752939447760585, 0.020208430341294697, 0.04614274738536728, 0.020915807202278126, 0.041370463948096, 0.03881695500064281, 0.03514886090171433, 0.027875032260893818, 0.04687667110814683, 0.028478834034514525, 0.05173226277674398, 0.038473762932323644, 0.06295770699638994, 0.11006110182572758, 0.0689579719196885, 0.07892065426154483, 0.03458492825889299, 0.07797925477667202, 0.02907415713003326, 0.020622016313756188, 0.0826336142997588, 0.05547036199019321, 0.002255860806232499, 0.05630899844090304, 0.05018222941866806, 0.02160846559901632, 0.07369488507749573, 0.025324154825460528, 0.010148277675222245, 0.041118593390790686, 0.018092916842790383, 0.0063119913665427565, 0.0904610563790606, 0.01998615184528453, 0.08844227680275518, 0.016674070296088056, 0.01949898121247609, 0.020141192719400413, 0.07608473466168489, 0.020679729547531858, 0.003411577457764877, 0.06212979194618041, 0.10991821876697003, 0.06255421614755066, 0.05489705243117868, 0.018782717731571006, 0.022545061712603898, 0.022004810762741876, 0.03685249871904812, 0.031347212779726234, 0.05479553812033227, 0.015819325889160317, 0.05293822306538782, 0.06495351542628582, 0.05915998699023359, 0.054964249833456935, 0.025606814456442674, 0.03361947744363739, 0.03883871189769238, 0.057154265382597526, 0.06615152372227562, 0.04662469329853212, 0.06580142154087944, 0.02184700431121934, 0.03492152814062373, 0.005749841314560224, 0.06570376065229216, 0.03430638252006423, 0.11224791512734468, 0.06808614087921959, 0.05630240242387499, 0.028434858672441016, 0.06912805876063724, 0.023241747816603993, 0.06113393510121012, 0.028069308328051722, 0.014721308346657504, 0.03495287262804566, 0.0015455110452979083, 0.082631001939937, 0.005026763481568666, 0.08289022311087578, 0.010676676287285743, 0.0381900652522041, 0.02096549566504696, 0.09386997910276537, 0.04528204377199854, 0.062158937761259664, 0.06386590040018482, 0.03281948246782826, 0.018120055507508018, 0.005331287740714728, 0.08962665639457204, 0.10759829768850919, 0.06676706004767649, 0.03215772805795555, 0.023361449054772818, 0.09354656742465112, 0.02604896401716096, 0.034387503570366296, 0.014900192749806711, 0.006511474437561007, 0.011353544654294608, 0.07578324841996355, 0.05978758153956264, 0.07380556179991654, 0.004299016821483571, 0.03846158979520683, 0.03089649069513525, 0.03335697358594306, 0.030140564927170356, 0.03740112492514234, 0.04393893842315001, 0.04311142556910073, 0.07202249215615374, 0.03249010296478387, 0.044953981940183914, 0.0162253936662549, 0.08058789141115644, 0.043492554311430266, 0.016782366400284153, 0.03208936428681257, 0.006994905603689052, 0.06843582937313665, 0.033124615288069176, 0.027048861975931836, 0.1575788161567142, 0.1112509512853238, 0.13272165320813656, 0.08157016934766885, 0.1679846650410083, 0.1457012051175679, 0.10884040966629983, 0.15650701318537036, 0.12513770451468806, 0.2581899246621517, 0.0896722003216705, 0.11932639134747368, 0.16052143648266792, 0.15383739595211324, 0.12470851907686842, 0.11513287201523782, 0.13473804259011823, 0.13621587216133071, 0.192296112917604, 0.20537012346809913, 0.12078666218346167, 0.1130762400345937, 0.14615535736083984, 0.13924432497832084, 0.16068931699039476, 0.10646380574232149, 0.10229699223512605, 0.15862995007586095, 0.08495410994416283, 0.08332777422882857, 0.2255097169789576, 0.13327918135591094, 0.10300800609852999, 0.10736130072825378, 0.11126275670023696, 0.13317320075246597, 0.15301645613245426, 0.14736795197090796, 0.09767010462500396, 0.212899342840237, 0.18118299633985568, 0.08471391839726318, 0.1660948333841178, 0.14033852836057065, 0.09758122310402895, 0.1630809515594475, 0.12161228280033796, 0.17497857281517598, 0.12063178218780987, 0.10818490653388924, 0.0979775510307762, 0.1206551938347759, 0.11976866156704004, 0.1142348024633623, 0.2144459517852914, 0.15995591037696408, 0.21892673876737395, 0.14275988714108545, 0.10494977085580749, 0.10037886895119183, 0.1213965371191021, 0.1316775519761347, 0.16018359170806024, 0.3122554767516352, 0.13251214348260434, 0.18558723581654413, 0.09674916734858867, 0.17356777593733805, 0.11907640919690171, 0.15426488833562021, 0.14456765545952704, 0.085912179502268, 0.07993162219082156, 0.15432917843422583, 0.164155236655666, 0.09907636626233017, 0.20113411689958266, 0.232879773923947, 0.0909114777741413, 0.08127307278975364, 0.12066742825892665, 0.07819276348116898, 0.2922011641485076, 0.1740581028523945, 0.10456475804770186, 0.1556836525278707, 0.07032215234733398, 0.11611776231157205, 0.11073146706386922, 0.12600664740368245, 0.07819505408406258, 0.23017344575735832, 0.19899253342901507, 0.18164274102497488, 0.1739169281697081, 0.133688502133854, 0.13657651571256502, 0.18548571384481846, 0.1521540096690578, 0.1704700534502345, 0.14519411619872818, 0.1526732640641351, 0.11354767522143741, 0.1695892974854477, 0.18474191907913456, 0.15859996539450463, 0.16911479794690687, 0.15048968365355847, 0.12077918516532068, 0.09999419322177287, 0.23066538145705578, 0.11912222125477369, 0.18464246554480446, 0.12697474505271644, 0.1438258065571708, 0.10224958671437157, 0.08416092549000057, 0.087298178113997, 0.3191168972801778, 0.10425016404159608, 0.1584127028622935, 0.20511958207334244, 0.13452447259858732, 0.1409502495681086, 0.18971629651083102, 0.15991546093456208, 0.06206521839504281, 0.12263020680796717, 0.13022941597286733, 0.23600309906948, 0.1327322405432501, 0.16330731521931388, 0.17715928805691583, 0.14518550537045927, 0.13102165813888275, 0.15775265682849193, 0.12801633351632666, 0.1573268038731429, 0.07597568204566356, 0.22532066180100366, 0.12814077683874678, 0.15256886160181415, 0.1390131349645315, 0.29725090931019477, 0.1330772252573121, 0.22930070307225953, 0.10340997243239995, 0.20903735571811277, 0.1099302233647435, 0.11153562955798642, 0.20043141509015716, 0.0985046961314736, 0.11356149544759143, 0.18099852236768893, 0.09314744327698024, 0.14262735393018494, 0.09908477024685952, 0.11878385554037749, 0.1470083656210092, 0.0916308573176784, 0.16363909257756126, 0.09320830130168507, 0.13335960526620189, 0.09843616190576747, 0.1495217009177131, 0.10989209516875206, 0.21082646213471892, 0.12869180090004398, 0.1297599266493513, 0.11263914090851623, 0.08613150281411025, 0.1360079712204395, 0.0971939733191844, 0.13297217928113478, 0.16108616585693053, 0.1159618174537055], [0.07841864450564308, 0.028498532070267587, 0.07642198188771164, 0.037570192869151794, 0.02579975370017271, 0.0488658758601354, 0.02682547456765127, 0.046339394494650826, 0.027285791903493867, 0.03608499353210773, 0.05561866895145467, 0.037698079756791555, 0.04117608828950794, 0.04430333197477364, 0.031693369608312365, 0.04506505702832534, 0.059096945614944545, 0.07060460130413694, 0.035658045071026975, 0.010602319793355082, 0.031661764650996176, 0.04537081421022454, 0.02101324975580698, 0.014336238081957546, 0.042883453124593345, 0.01044681735126482, 0.08842618129546605, 0.041237834976204944, 0.06075635717640962, 0.11528417438028321, 0.06880218794028606, 0.046506133531370474, 0.044795436213814446, 0.02224852631409322, 0.04106268046363708, 0.02276021942135788, 0.06176856616812368, 0.018617926473398844, 0.04408168741652081, 0.027209267380737492, 0.01543946406473556, 0.022529345418837284, 0.07226547992397701, 0.1039887058939184, 0.02863070905028332, 0.09973904763859126, 0.04341351318984263, 0.014762143705851369, 0.06064221007569183, 0.027189475499213706, 0.010281128812611345, 0.08969643934359474, 0.015886882395153085, 0.03450309857726097, 0.03423163532129219, 0.04989475109464219, 0.0318588905652324, 0.059370764591280496, 0.044261568691581495, 0.08913509607795747, 0.037009676978472746, 0.03172800444336909, 0.015133433006403428, 0.05885157914411637, 0.03743187952486258, 0.09253189162982088, 0.021995575572814674, 0.030111396129453377, 0.04756568292636545, 0.0096222864944608, 0.044201154997872735, 0.05241359456352169, 0.04327359106091242, 0.049151787534356124, 0.033462678397735285, 0.053209479477617054, 0.007149958926733704, 0.04763016454695214, 0.013810174122843293, 0.018214483505054828, 0.027804094434325254, 0.03167989029128465, 0.007765442104784833, 0.052560442127287395, 0.018908340829394518, 0.0604916354941745, 0.026380714562330997, 0.034984236267665704, 0.06664814021919044, 0.023490573174410292, 0.055785162840038545, 0.02335683337502903, 0.017363991843716755, 0.0869038649984906, 0.0396513779677691, 0.12950892560184002, 0.010162007886045163, 0.03011812812708799, 0.02639874061118932, 0.05757255705013391, 0.042368504143650496, 0.013508677347412994, 0.0626631998156588, 0.02145417740628604, 0.0924840187954326, 0.04515738594495962, 0.03826952772215009, 0.027344887925972863, 0.05063612502248538, 0.08139825155658108, 0.01172407169736201, 0.01680915074933681, 0.09107439403211878, 0.023582082376965595, 0.060671999404627475, 0.07718692068010569, 0.03531108385012035, 0.050117763119839856, 0.0147017280969228, 0.03974858686448105, 0.0764891065116371, 0.06675574492903487, 0.03634552088295741, 0.021410948979938706, 0.05962285348364423, 0.08216232466962069, 0.026012212864213416, 0.02489494257456353, 0.05074951752659775, 0.045693003978099556, 0.041627980573403264, 0.08131031232375292, 0.03716168031396885, 0.01789622568345118, 0.031318781341636376, 0.06438379881963616, 0.007785626606369812, 0.01960771781722865, 0.03676426454236911, 0.034585108289555196, 0.018268316503494017, 0.030946380255984205, 0.06127974461583842, 0.06176546734246997, 0.15326019466644333, 0.046915515596347476, 0.04622461537139551, 0.045560834658963066, 0.04200155185835977, 0.015234535544990532, 0.0391891626490941, 0.02092884218830976, 0.022956537112833995, 0.0044336251730489875, 0.014630931039010326, 0.023810818994177446, 0.03953138944662867, 0.046615124860357855, 0.011277639705146994, 0.04851730968502741, 0.07158863358199596, 0.04125499151526921, 0.04700300283730031, 0.01614340310615878, 0.050925457279288, 0.03230273701070297, 0.035959914356710455, 0.02047900685049113, 0.01784610055056551, 0.014972180116831537, 0.022138429903275064, 0.09591289810956487, 0.04090368657583191, 0.017012713717356805, 0.00534115303795965, 0.0648535945783219, 0.01632269449351776, 0.014846168229386452, 0.06516575242482847, 0.04160388327774502, 0.0645320521547429, 0.020697887746557113, 0.06813396774833241, 0.008434450888495532, 0.04122948461783029, 0.07581294198790867, 0.008242492237308574, 0.018548601261910894, 0.0254803754749798, 0.03264374955887756, 0.08603942670649098, 0.05459322579084866, 0.05129551988155131, 0.05784796182847312, 0.015018347447978394, 0.0315169089158336, 0.024244032139259002, 0.0296036905098346, 0.038321663835836996, 0.07518660382277544, 0.038644987413839954, 0.012603870052243433, 0.035441253679774465, 0.06582672542501843, 0.022697704731516784, 0.05529293985736947, 0.016639814674553853, 0.07127516572513888, 0.015867289696489612, 0.01381126196769577, 0.055317083118303176, 0.04972371430466733, 0.02438532173513405, 0.027124199062405575, 0.0758980849998132, 0.04641425660661152, 0.03673352143396774, 0.03493490020534204, 0.060418941411039526, 0.10689822356066397, 0.00522137566980335, 0.0249303205149068, 0.02008970395000952, 0.06009216660693769, 0.04030296639088662, 0.04565690591510746, 0.027409405935735955, 0.030019584322167985, 0.029620450598398046, 0.02261113679607309, 0.02070049627593929, 0.05703643722940357, 0.01276355246157055, 0.011687934372363793, 0.0436019478365779, 0.06404816803912963, 0.04040161170245659, 0.02632054984719763, 0.039059563554943576, 0.046939000021666295, 0.03896008703797575, 0.04520695566410019, 0.0515028232738616, 0.04328406348283734, 0.0304899450706979, 0.0639119997410284, 0.04218687235768284, 0.029287924389204675, 0.03255571073461925, 0.05332618914244156, 0.026899210530363267, 0.04470211521331822, 0.05871302831257063, 0.041081384500308384, 0.05525655451140577, 0.0425882832778077, 0.01848945544371682, 0.06559090057928717, 0.011172232710035339, 0.01936314999306154, 0.0703180767595768, 0.03211384462643295, 0.060274227402142944, 0.03824379099833389, 0.03770473706085355, 0.03470025513501417, 0.07732382825305385, 0.038802655969536116, 0.025966536786948, 0.05906854673559147, 0.08005474784201191, 0.021107758192585844, 0.0949547366209088, 0.013454694004218667, 0.0355253050163869, 0.05311484846677031, 0.06226959916192198, 0.018457783453707254, 0.04547710507927884, 0.016163763807966344, 0.07583950225624346, 0.0187821795548042, 0.04356784160218893, 0.053798003542807796, 0.05612859622605386, 0.05651681128168299, 0.025808992720539534, 0.020093835079141205, 0.06764092888202398, 0.018365760972242684, 0.01839751148626449, 0.054600515117448185, 0.07241610813164905, 0.03404875098156833, 0.0627304048788163, 0.016558538491447127, 0.023160197757064335, 0.00483533869790394, 0.042693425014975576, 0.05131343867810023, 0.06662929445625314, 0.037109850635451656, 0.02923222405145005, 0.03532932440359746, 0.02536173909902573, 0.03167595259935385, 0.04035326006311563, 0.0803957412379884, 0.05068956348564356, 0.044116276286302075, 0.032576873913527496, 0.02337393437271878, 0.05391828317735946, 0.036766390436358994, 0.03586236072043258, 0.04733624342348307, 0.051706809505459764, 0.03558578765800884, 0.0004647574138699941, 0.036698557181103576, 0.08183201053930868, 0.03940668948475392, 0.029916283111238194, 0.05987130345836763, 0.03814781550318003, 0.09720581703849378, 0.01039535731017109, 0.008524551446880064, 0.045016621119312705, 0.031115620569776625, 0.06912383761617445, 0.05773578740416035, 0.07493118244794107, 0.04725804116817252, 0.025682680143584168, 0.06695330368294831, 0.11855805878557506, 0.029224229923960184, 0.027104889816274087, 0.011325927184624298, 0.13710916132455872, 0.07468779631439718, 0.03398554489737557, 0.04215349773726156, 0.0075089055932156985, 0.045883407470800226, 0.018407422748784867, 0.013027088622742844, 0.09527950427464901, 0.004549228319627864, 0.01230183510004633, 0.03148905778934639, 0.08252008773025968, 0.146164795564067, 0.14504451454887468, 0.17579600395214173, 0.13698032065745325, 0.14553847272069226, 0.173784502211117, 0.1251831488503564, 0.11921662626968277, 0.1372619805436942, 0.12776999794427427, 0.12385745668002676, 0.10421648681644471, 0.17482733173716455, 0.1714472292411712, 0.24578357505942547, 0.10697759793049867, 0.17216246424903794, 0.12608072044508112, 0.07169420049796182, 0.0859442862471746, 0.13059788894268776, 0.159050471059257, 0.10480841997289851, 0.10413983205874121, 0.09985889443346571, 0.22542524812442644, 0.1417841362736879, 0.11244782577118567, 0.1776338488824906, 0.11215436047003155, 0.10037948182153125, 0.10060964527750209, 0.12373037035426787, 0.2921024920238603, 0.133751290700128, 0.13969407987690743, 0.13218600453147966, 0.17005569181374966, 0.09269444782647396, 0.09142890121907958, 0.10072283476831452, 0.14720932580530643, 0.17795658640323148, 0.08674792014062406, 0.1958791980700147, 0.07690799572775442, 0.258238525280068, 0.16051952126285723, 0.1631667380852084, 0.12667097586898074, 0.16761421556434325, 0.18241115785654516, 0.08760934770708123, 0.1138251139632156, 0.09163666426414445, 0.1272351459990586, 0.21958888388208805, 0.12330598828773345, 0.1573574780336311, 0.16152966947805497, 0.2430699077705222, 0.1274488232428989, 0.18404952881316985, 0.11630906212714412, 0.18811336478158353, 0.2607218758954156, 0.17813206650316718, 0.13942073970552415, 0.20533066993999868, 0.1883219705233651, 0.11654071179368805, 0.08680687060639744, 0.21174267264864138, 0.12230157041020932, 0.1377927569011527, 0.14982660391157673, 0.17863439035511788, 0.11688149068504573, 0.11182436043576849, 0.12917860381064877, 0.1840800497560732, 0.08387885191628049, 0.151915296671852, 0.15587489871728807, 0.12118928735294651, 0.14826361600670124, 0.06327220141106556, 0.13992513199487042, 0.13102101462502636, 0.12353972171343143, 0.10277576654428437, 0.13103149470783051, 0.13360122939751995, 0.13653582112202722, 0.22217697403844328, 0.21250929683446887, 0.07069336025104409, 0.1675707017702441, 0.13166017710201203, 0.13107571330281997, 0.11193863011055416, 0.14139948352690668, 0.1507357051295619, 0.16536370971270148, 0.10510462786882155, 0.18498191910405315, 0.18779556086707502, 0.1483690450268407, 0.22380561567842963, 0.07195262493745935, 0.12261399638748939, 0.24069891161014959, 0.12363827892489011, 0.16820675393025722, 0.09848578908150235, 0.10802981203361865, 0.07802306734506162, 0.2169619071026964, 0.1309384303467889, 0.19167363583560915, 0.09514180763113884, 0.14331675645324493, 0.13150458464459067, 0.2575583924208918, 0.10698361172070427, 0.11212814494126266, 0.1531262212102452, 0.10114769180936199, 0.1016701331302043, 0.17582611120756597, 0.14801592445902287, 0.14096348756744018, 0.20840475095375893, 0.08678629348475127, 0.1504961341138809, 0.11659067604810962, 0.12816841729105483, 0.16315849497914314, 0.09693435378252499, 0.09875418032489477, 0.11687746106256401, 0.2188533475442279, 0.17826144343181966, 0.1892885130139128, 0.09645663667470218, 0.16994718312015458, 0.1286051257122909, 0.1041615583122738, 0.1902230023857086, 0.10546808296273794, 0.09667110298910449, 0.05592174482561889, 0.20864640572859397, 0.1316238032473672, 0.10251842994963932, 0.2110666766642563, 0.19386164423438812, 0.17959435981127525, 0.1410784467213577, 0.26644507362957925, 0.14294201688420388, 0.1722986900037335, 0.08584327755435821, 0.38596085723369356, 0.14012880413041962, 0.10267654283633156, 0.08735703664921945, 0.08401988104226128, 0.10145455598831178, 0.10587131334168297, 0.17420297007887595, 0.15625481704069724, 0.08639892112583884, 0.08319540189639216, 0.10777319556162243], [0.028474509468181964, 0.010968872755315277, 0.021258970542300134, 0.046084789003455834, 0.061870808262498155, 0.05213436700644032, 0.021385656587118586, 0.04631580664746223, 0.05490275595577494, 0.04592369986517776, 0.050526019035568165, 0.04467812516996938, 0.043013182453691, 0.035177393846454165, 0.027095566526235595, 0.03736352149937903, 0.03870185412045929, 0.01152507940142025, 0.025671299907468983, 0.051547915209084756, 0.04793936529407098, 0.025374013742792512, 0.026088398393063296, 0.025720168656158834, 0.015214307950959812, 0.03677995402305838, 0.03535669672513201, 0.03210310407373453, 0.08080383627525262, 0.0407573752736132, 0.011334127198243815, 0.04891091416920385, 0.06406675333217268, 0.03681013788727503, 0.04588996901387169, 0.051112650863585934, 0.027641352461350542, 0.03161405844073142, 0.0962064017151152, 0.07017349298562735, 0.06077277061018733, 0.023729435558761322, 0.05362476041961101, 0.03894686436040267, 0.024488205428145105, 0.08039689803075406, 0.007352702180674721, 0.07485663443202935, 0.024098462027107036, 0.020519033029314973, 0.03498563054768789, 0.030787685142469504, 0.04258519594347285, 0.06844495348031483, 0.05697112440341904, 0.07775331246516398, 0.044250487229756774, 0.053249289236602285, 0.06209029628324413, 0.03432536234838828, 0.062457758017004504, 0.04164421014607914, 0.015323299279947196, 0.01951501734795109, 0.05247912189412502, 0.008394456310798565, 0.04649956815785939, 0.06762507852287063, 0.029208980943827383, 0.08350692388992156, 0.027550170761382872, 0.02993784657108688, 0.0821492245661155, 0.006028150523742361, 0.050658739938010136, 0.043321586469368595, 0.041263016286276044, 0.015759397703673572, 0.023017485152869936, 0.04678890424510164, 0.03179699257617036, 0.01768798000299402, 0.03839887783772523, 0.07258860814955927, 0.05647414784517981, 0.014466708601121942, 0.048223246835292354, 0.02078058310754357, 0.022326657706270778, 0.057806512641329924, 0.03263348015025258, 0.017727410548456737, 0.04425504162246662, 0.055512102290747635, 0.01970567364966677, 0.04760427077511146, 0.060647480760610877, 0.03819497204535911, 0.007269505032097862, 0.026866153836430564, 0.04717088717546675, 0.0501185943252377, 0.008115735329357127, 0.04378937507769273, 0.031610136070559104, 0.012211130289811523, 0.048120947284323555, 0.03497390940244641, 0.06893164913861022, 0.03656451477699223, 0.09628861827114898, 0.07334091415208194, 0.024898554679126512, 0.06285514314508726, 0.021490869187419454, 0.04157205615493079, 0.02806419277593734, 0.09896851640434996, 0.01894497132349399, 0.03326122025628725, 0.02985582153703417, 0.029589810911866448, 0.028585601793301683, 0.06734138084275108, 0.036607212687452, 0.06018474833258699, 0.02776852114156129, 0.08631743235333313, 0.03475067138131108, 0.0959310697151288, 0.06212129220066052, 0.034217401407659054, 0.03633468839970808, 0.06385680310608399, 0.032979100717291716, 0.00911269055288886, 0.027180213496209155, 0.05050269931915307, 0.04759459891506741, 0.013117439117312673, 0.03719168797796292, 0.03966325233059545, 0.022764467378898014, 0.03709552479126761, 0.04953728297785406, 0.0501359730298, 0.05324529791851679, 0.03779841046179495, 0.0504568527873245, 0.031290279040413524, 0.013268753931286835, 0.04473298855666672, 0.012662859780022935, 0.012079598738871997, 0.018603093095964963, 0.049224232638915705, 0.04493594056956711, 0.02193454709354668, 0.0029967712508814953, 0.038407503987752625, 0.0407402838520225, 0.015942348118480897, 0.03155827766374475, 0.004792897905703755, 0.03995160016441538, 0.02234376444961996, 0.05413307124868997, 0.045012020761327404, 0.10757844068951185, 0.011667441520389291, 0.008941534061675832, 0.024187414411215052, 0.04844205303778572, 0.011432830924018016, 0.037060311559828064, 0.03878903492624241, 0.06062791487502475, 0.059522201021712635, 0.026045813480572357, 0.018409709521238844, 0.07051404971148699, 0.024628535498894995, 0.0467352053120492, 0.04096580098473257, 0.011899102678252085, 0.006438347035943861, 0.05223250669998027, 0.011704285561497654, 0.06614858194464637, 0.028755340064244888, 0.020683592545890042, 0.018777987138638576, 0.05073979204039901, 0.0432981595006441, 0.03359977366222489, 0.031695855563626654, 0.058751252269552606, 0.02420179771199342, 0.039998710741319006, 0.006138454257105027, 0.022094209393065785, 0.02809825304505085, 0.12067290578758526, 0.014028664314067893, 0.0774272807663487, 0.03746914970237882, 0.024322431662210056, 0.05536785176504524, 0.04912334268972759, 0.06956457565989226, 0.06163406028081814, 0.043633142936854594, 0.023523304280975176, 0.01642362083188228, 0.019614865417562185, 0.011263550390609571, 0.0407129536653238, 0.04449038383280558, 0.04866596904673404, 0.0915275197175722, 0.027081127684082718, 0.062336735277166294, 0.02984678552996728, 0.035478121661130464, 0.05282117632187663, 0.005871570291703628, 0.09621642980604403, 0.04119288859768741, 0.055225229176181945, 0.043309961085117636, 0.012710927966831913, 0.051465081952271924, 0.03725562184568375, 0.05115747849847521, 0.10860921199163122, 0.016406908623814102, 0.025270277776965694, 0.0745886338934783, 0.038391033097380595, 0.03719373343272075, 0.029290986825681986, 0.03560291738399575, 0.05683742673887361, 0.038816851578773036, 0.06838145245227122, 0.019407740140694286, 0.0319093776746623, 0.01717404800377065, 0.05055913701653481, 0.09299377370024882, 0.04679292237626449, 0.02245318861828456, 0.023011080657822952, 0.019200578474649982, 0.04178750689231581, 0.022088174535442266, 0.04943496810512678, 0.018970928297588424, 0.022370491342078296, 0.028094282794383266, 0.10146391758274648, 0.01394712191540748, 0.049074902950275334, 0.012797046783229998, 0.05565002109975584, 0.0070857152722084964, 0.06612416672249956, 0.03845099862965365, 0.006797663339849322, 0.08090368817530333, 0.03773286397899351, 0.025923926976599523, 0.03549121793419604, 0.07247950956826249, 0.05090643531612812, 0.017508654141678445, 0.05999919417644701, 0.02552912356482158, 0.05484838669578876, 0.020080667942942634, 0.025645911753658327, 0.07016201698852163, 0.06896762462753443, 0.016835471615195274, 0.027995311895445473, 0.02262233700152607, 0.034698236493333694, 0.006282738299154106, 0.04397509777317605, 0.028668224375935334, 0.01334804690427958, 0.02463057903843301, 0.01932591811994151, 0.03664571626652633, 0.0383576737987178, 0.014584421841127258, 0.025362616269699028, 0.040125640019053416, 0.04377494964207854, 0.02099325103054364, 0.033777318369116516, 0.08138689813354323, 0.02284062992511017, 0.011345688422631112, 0.04300615359698573, 0.03655126528634179, 0.013879845031507075, 0.026754063681789467, 0.04227056363297086, 0.11650800750020052, 0.038636096963478674, 0.05254805065511216, 0.049329301597730774, 0.033698043590711976, 0.030033216856780554, 0.03193483860682576, 0.02035240890578397, 0.07405765835315951, 0.0814755345063825, 0.02274426947077436, 0.053783252519825776, 0.05904770531361142, 0.011100122768942629, 0.0889243069855917, 0.04213849390526453, 0.009068269902209361, 0.03708845379972651, 0.009324063787296897, 0.06667588026292863, 0.02613880506326114, 0.062073653023089134, 0.0379462501094226, 0.03626835284634464, 0.0272649294140959, 0.02234725972577449, 0.0457393484670789, 0.006651469344844021, 0.07796503618479737, 0.03695473698298297, 0.019636802345273957, 0.038451668956587394, 0.06170828270936205, 0.08787002444507615, 0.013784423992488415, 0.03806245032577746, 0.023344461055051897, 0.06714468776819206, 0.07176876383563204, 0.05189266243589021, 0.040847352300319946, 0.046404086789416696, 0.0594777372785874, 0.14056466219405975, 0.13502189348782265, 0.1249066217532081, 0.15225832020082783, 0.1204471933024545, 0.10685848658003154, 0.19453394767497817, 0.16946483884126912, 0.13396700573784692, 0.12000148334810812, 0.1851038803015986, 0.19401938173799746, 0.19699123597914175, 0.16191675838443542, 0.1312196152585168, 0.15896609413527674, 0.16971184090981561, 0.15501899464476496, 0.05793098660726702, 0.1845495850448647, 0.1765555035202734, 0.18000597885299116, 0.10926260838225003, 0.08612584908522906, 0.15170731912216834, 0.14526762999594212, 0.19696639940863658, 0.08315817768415136, 0.19758564359959097, 0.12645707645964238, 0.12492296240863301, 0.11821165680885316, 0.26167207006965915, 0.09863503067003143, 0.21226103838172652, 0.1921205562088759, 0.14908673151606514, 0.09342317364268726, 0.18912176631631392, 0.10292709955284673, 0.23742751699061165, 0.10225122614252953, 0.16558103353506134, 0.17523947171866897, 0.06135221270303573, 0.17236760727340178, 0.09443692247112913, 0.16666638094090647, 0.1516930852085352, 0.0808732208585547, 0.1870620010360595, 0.14507574029266834, 0.18984787977270542, 0.19768650673570173, 0.09946389183882745, 0.15978153344363938, 0.0891508851500769, 0.21282353077925023, 0.18679779263273363, 0.1446204235957515, 0.1307203710800217, 0.26855270408334275, 0.13652117352091497, 0.15757783556417113, 0.14643902439744244, 0.11532060952196199, 0.1141599556731601, 0.1936673490150321, 0.13907621464421674, 0.19345829894225444, 0.1802913772483026, 0.14281864608487777, 0.27041273491997875, 0.12806082790296885, 0.12035292618337179, 0.09567065344702813, 0.0666861305193555, 0.1458503777581838, 0.16621334718600397, 0.14474037764293535, 0.10867187032295812, 0.1634388831594298, 0.07435590404296115, 0.21269128868176093, 0.2544707210073548, 0.1873437222093344, 0.1136347257922734, 0.08891749646394484, 0.09330515779795186, 0.10044342718057095, 0.19132207808715684, 0.125341683085407, 0.10637096354677793, 0.19682599081387445, 0.12751153520038053, 0.13309198011073375, 0.14303350310412147, 0.17280438464255105, 0.18675463123907968, 0.10069826632858285, 0.12020456559595563, 0.11581762438459743, 0.09827450969286504, 0.12323570738155996, 0.07802363425012558, 0.1324618268277376, 0.09446891430284708, 0.0739930464976257, 0.19572666996429045, 0.13378571869144518, 0.22408894563634552, 0.2158391439626294, 0.09666751003673962, 0.20770811656069374, 0.20343837147999197, 0.10334175230274278, 0.10211175983591426, 0.19234408534342246, 0.17327943576439736, 0.08170883892284286, 0.1148676830193689, 0.10022204309221237, 0.13475327241805293, 0.16097819342488245, 0.10160570513577231, 0.1481145812619117, 0.04929457866256276, 0.2531330395610102, 0.17945350688551703, 0.1486107304451927, 0.09309410823569184, 0.15453714066215102, 0.14298592904402366, 0.22628593258559707, 0.12707046773885528, 0.17889772541821006, 0.09508651906564351, 0.3165983066203133, 0.10741528694427784, 0.10254374915553678, 0.13207440084267047, 0.17357885356872313, 0.13541046860477618, 0.10592002887278797, 0.15655650246527889, 0.16368144191801548, 0.16001333632776815, 0.17012683073839835, 0.1405599277706877, 0.11682397280369075, 0.08510476879535184, 0.1230332226822934, 0.1471606179350807, 0.09716820212141161, 0.08863700869222803, 0.15708188556375044, 0.08927889078134492, 0.08338946728937088, 0.10034221930489426, 0.090163852568836, 0.19448805900831379, 0.23389856361093062, 0.2170097875979639, 0.2030577943209679, 0.15216396881207345, 0.1407122720153101, 0.18036872148513797, 0.224317868029879, 0.2694575152089519, 0.09180790023697961, 0.1890323485337919, 0.1853767608202273, 0.11016547364453155, 0.15867619114297052, 0.21884007890137935, 0.12679905810904119], [0.011435436580570476, 0.011269308498970444, 0.07778911941474484, 0.02799298107293585, 0.042530060595562386, 0.03300382237460825, 0.07211588593500276, 0.01996066984570315, 0.019704779242015174, 0.022812819018238978, 0.016728952834983508, 0.01823578841022907, 0.04774807313937814, 0.04616125606961789, 0.03005090199651257, 0.041008146494747176, 0.0641484757614953, 0.04371493814453002, 0.028556754752512903, 0.0504546502845422, 0.040417167117759105, 0.03673990677681662, 0.028248109419139165, 0.03345609004158647, 0.0553817141260351, 0.058586497400556846, 0.08267111430365233, 0.02241816690882608, 0.06589873002902155, 0.05374050098321131, 0.06399736491843097, 0.04197831641161635, 0.06870838047395791, 0.042419357060064236, 0.02200342414359893, 0.05379046523763288, 0.013065844053222288, 0.022830375838243676, 0.03009465710830785, 0.042089981387459466, 0.01421523736714716, 0.043580573983490474, 0.0232810691945375, 0.05437948725997441, 0.08796929411830441, 0.007073108816609508, 0.042350983712822206, 0.02600973648499818, 0.013379135709856788, 0.013882400892344455, 0.008199014832385847, 0.03764138541995518, 0.031056566682133465, 0.05957950822888844, 0.02523380624611051, 0.05500144340218075, 0.003170514246448875, 0.05950722400279296, 0.05093190390917082, 0.022401550461748437, 0.10566387971442555, 0.04199239710766462, 0.025191137063947898, 0.024035307653849165, 0.02512818570398996, 0.03794646844448101, 0.025574826455164342, 0.05246937725572817, 0.09476358236204233, 0.07367995402385151, 0.0909988884063017, 0.08958199346858649, 0.025734053999786417, 0.010750212109527521, 0.06100912022614672, 0.021038513420329943, 0.02676032645057046, 0.04110627852740788, 0.012434843285459907, 0.05353934927693298, 0.051518677463454586, 0.08260903819914787, 0.030147358211838914, 0.07907987031484805, 0.02073384216806341, 0.07397098316540641, 0.02305428610153256, 0.0066709993200586935, 0.008126359053647086, 0.026350747117952957, 0.023074108626573317, 0.029256761847664754, 0.06727376592255409, 0.05474450900369594, 0.026837222525970112, 0.013255768740970283, 0.037718584100084926, 0.025192975674966173, 0.029378803484442256, 0.02988969219938642, 0.05638049742687614, 0.017346925319983594, 0.026185657085490324, 0.0310861568282088, 0.032010221658574964, 0.03535314207716334, 0.03706029240762995, 0.00269399774204489, 0.02833588777350322, 0.012402833259153753, 0.028675724376714038, 0.0616864032382446, 0.05006686423815066, 0.01458837198198683, 0.03286021153232263, 0.027903492427280838, 0.05038664465950382, 0.09384316602541555, 0.04429407380220871, 0.04759475979353151, 0.01569660626456983, 0.03169236986357118, 0.038099544303071116, 0.03901155665516853, 0.013986417437873542, 0.04030128865833244, 0.006053683755453677, 0.03878263426163504, 0.05306437476387909, 0.06893314301006256, 0.012437070686099751, 0.07172230826390368, 0.036513332442771045, 0.05684720202078743, 0.016731419638099692, 0.031092890741063223, 0.017035297989364595, 0.06487103073947853, 0.016129561812586842, 0.08503891587738069, 0.03609231350222423, 0.006844399012475005, 0.11128958509934526, 0.04327492788434029, 0.06410146094558221, 0.03215731820091605, 0.03773314360108587, 0.016362963905257565, 0.02335875242527935, 0.021472414129323537, 0.04325684054844803, 0.02126234132916697, 0.032335736248041355, 0.047963853294570605, 0.053955982364113295, 0.04630606200906538, 0.04791795696702696, 0.014414157842346018, 0.03304036476859643, 0.04429263738735069, 0.03522756877505491, 0.07545734695609539, 0.02551827767503358, 0.03951876431763653, 0.003976823223168932, 0.03684743870830825, 0.0142480680651422, 0.03901898770803406, 0.049446980363779494, 0.04418295657923145, 0.027943533927863164, 0.04000966962907584, 0.019025920004013087, 0.06489281828004508, 0.027677404559067184, 0.02242038090292725, 0.020385360262627085, 0.02855425539065994, 0.02248768172707529, 0.05689948369117995, 0.030178396264091138, 0.009008020917404323, 0.007118733661744985, 0.09397793621305497, 0.009822876083724683, 0.02629326371055457, 0.09144173319181127, 0.03827713880567782, 0.09643717038054621, 0.05398896244925357, 0.022921199392106746, 0.033990616399434306, 0.0287240223899003, 0.03583612986990521, 0.04981295588696676, 0.00867971106462421, 0.036972441274913094, 0.049764608078065424, 0.03602259567067508, 0.05683864481867321, 0.06697452431845088, 0.06299699581558667, 0.05084117994673791, 0.034712493389604554, 0.021513057008926428, 0.02783439704217017, 0.007618713284647393, 0.03170360837342038, 0.03994638693609065, 0.017124537656444217, 0.019692879981331287, 0.024603840654655814, 0.01549045870741529, 0.0626345826012473, 0.040626466169112155, 0.035963645204901695, 0.050156588455842394, 0.026444301775266087, 0.02751626945551365, 0.0738493130812722, 0.05167897370073104, 0.02205719202456455, 0.05880845605485863, 0.02915877537170966, 0.08328105052632671, 0.016998131233718128, 0.05997328508284785, 0.013689504741060158, 0.06299873100473516, 0.03504448142203112, 0.009801436155553787, 0.10014322030568316, 0.06098336818057203, 0.0159448723781914, 0.05014767502284339, 0.0604339337517177, 0.07173168518009686, 0.012366065826837816, 0.016446593893511642, 0.022269903997620268, 0.040430106342800205, 0.02850372997683383, 0.014538815669384936, 0.03862998741228254, 0.06343218738273268, 0.03486993211892343, 0.051580971903017456, 0.053627035700746124, 0.057357918365948626, 0.06262977539952244, 0.025445903433606993, 0.028109332591655756, 0.048459416420589534, 0.02466902707613284, 0.05392850279026935, 0.029975367642398325, 0.007461364570659616, 0.02803534765036837, 0.004383370284021142, 0.06113940496898948, 0.03367093173907169, 0.047157292945250395, 0.009479539416309808, 0.027542699488901326, 0.0013953232184811045, 0.06911577071033179, 0.10138487263071923, 0.01652222592383623, 0.017038450441173008, 0.0189503243628649, 0.04803825958421634, 0.03457344077046841, 0.05523781983121749, 0.032215598339755694, 0.05161684780051151, 0.0024188244659002992, 0.02372784975675806, 0.05745988849910998, 0.0080044811681634, 0.030285353629639557, 0.06263226901571597, 0.046020709579029394, 0.02990889036276889, 0.062285966630424225, 0.02609586008944579, 0.024781825862103896, 0.06617754006818419, 0.022684248397126797, 0.027258653238776232, 0.033268226130354794, 0.027843919515068975, 0.035641746550437906, 0.041576683325993444, 0.042378934430739576, 0.04110609083586643, 0.09790873335253808, 0.021508178944068573, 0.05302653768129888, 0.00734078424659768, 0.0405505545166952, 0.03207075218069217, 0.07839704848705761, 0.02854781259121674, 0.03656142744265738, 0.05880836412430771, 0.016094432850818963, 0.015741887806554236, 0.02008446007816782, 0.045568794312496344, 0.012228053172058877, 0.03870822031111006, 0.02320172355299996, 0.05480796789690372, 0.02804976925554295, 0.04571281501182145, 0.03529360172368827, 0.07520861352884001, 0.08963032595572934, 0.01581723734195675, 0.03892190138538999, 0.05415206639877251, 0.06920931770676567, 0.05604879667742118, 0.01788847287365746, 0.01154674915596843, 0.07047626625506148, 0.036909602912923986, 0.04480325414108173, 0.024500116180147857, 0.008705917017294035, 0.11188017760193157, 0.05554373789158079, 0.025082519202823603, 0.0110493790200581, 0.024938354862012693, 0.02507421097928478, 0.0674185412184846, 0.08814643662903579, 0.03402804745541465, 0.03477040197580092, 0.02285847019764685, 0.03719112107289895, 0.011894150877431517, 0.04149580742382715, 0.0645118810596966, 0.012562310739961124, 0.03549307569741242, 0.05537828205213432, 0.046909946137137955, 0.0363913903974237, 0.024063947850898392, 0.025336900613300746, 0.08278316998433682, 0.13535238381835724, 0.1362508210924364, 0.17063378176141172, 0.16086278993996883, 0.18156982477634184, 0.1585779327058023, 0.23059047337981964, 0.12259288300429622, 0.07075380458826981, 0.11379686064056813, 0.1384297743319504, 0.17943732710855623, 0.1189569760895064, 0.08197272556924051, 0.09924408589159289, 0.1143927621324697, 0.10211556729289795, 0.1740572754774363, 0.13554893133621063, 0.1289145333031493, 0.1289074086854535, 0.12205518121200225, 0.14440040314389815, 0.14576986191734193, 0.19916367747129934, 0.2515594949645381, 0.10228367762700205, 0.15722324410753866, 0.1851784053348726, 0.24951975522262437, 0.11965128157528178, 0.17309802614392775, 0.16595174348162067, 0.09387890402708324, 0.15800166604740007, 0.17064833743197305, 0.13301020788569606, 0.12448155020754184, 0.1793714588688266, 0.13081602481824736, 0.11864332437154748, 0.13133431394254008, 0.1449998975881646, 0.2250244309224429, 0.0919963731881111, 0.2143990059172915, 0.11158292016555225, 0.22655703578024144, 0.15499723774771537, 0.15313406595058981, 0.09494607982736442, 0.14423023969415696, 0.11470955481091816, 0.13198522820828423, 0.18624904385257154, 0.07569488783877704, 0.2254490274935961, 0.08590378317861788, 0.15848943422878944, 0.12863751590972947, 0.07464399140688681, 0.12349505878744588, 0.14030774694777307, 0.15755165067891921, 0.11986321213865474, 0.3943048724003377, 0.14641814084062654, 0.2055306035664774, 0.16011038434601602, 0.19746801845969694, 0.08279172718645104, 0.1632447105141417, 0.14455719069848139, 0.1732431844838204, 0.09926551337083502, 0.14164876853746755, 0.10300584573058352, 0.11722927928091058, 0.13559397730615833, 0.124617921518943, 0.15505328474025573, 0.08721600752323867, 0.19898242106841457, 0.156884863071384, 0.17262037032313887, 0.13792090808912633, 0.13437067278690878, 0.19795839134002888, 0.19266371254719075, 0.2594623354173476, 0.10994554512322911, 0.136485994763432, 0.20305330504573163, 0.13368683206217905, 0.11402498630266036, 0.13581580572551297, 0.13537683734490027, 0.14875798786599792, 0.09730784462824946, 0.12762714552903368, 0.13117775621433414, 0.09495428462903346, 0.11933415181814663, 0.09420849803474643, 0.2040271100498015, 0.17560298043874004, 0.265031396261146, 0.1176368380566278, 0.08263110153136716, 0.14477823770815326, 0.11707843656861976, 0.1385874199050088, 0.13257508526646322, 0.13625941659894683, 0.14054837516478955, 0.1614011199243607, 0.20370339193651754, 0.11996035974833275, 0.1102442657875438, 0.0980688457287127, 0.14190952954513414, 0.20715302457251858, 0.15802995001356449, 0.09834033196731921, 0.18419355334293458, 0.20985884712107722, 0.1910199483315791, 0.20492781494413653, 0.12583630775371868, 0.16238977171240315, 0.14623521436606685, 0.15495726327982642, 0.1686896497924482, 0.1480251481576312, 0.23668819617840553, 0.1378916588521773, 0.2525926258174643, 0.0724486745293102, 0.1885852596211818, 0.28189813958541043, 0.1347868423908949, 0.11124530521732186, 0.13695012147147811, 0.08644659477736681, 0.15961814221114884, 0.19326772691021044, 0.15073012800947314, 0.10893789435466451, 0.15365014874166058, 0.15982566010807792, 0.15938836179914015, 0.1347690691510516, 0.10877824929212371, 0.24306996905755615, 0.09749282421844621, 0.11164883437055735, 0.1217511515583723, 0.1971766599003346, 0.13499193944998328, 0.13076282767278533, 0.18255599443950962, 0.16634381195950895, 0.13057956411953897, 0.10538267948093916, 0.09643013003252207, 0.0639598572536582, 0.1759601459507981, 0.12400961706354735, 0.09403713182696412, 0.07244776288468031, 0.109293527690874, 0.09808428240038695, 0.13048818515193078, 0.09720401673187172, 0.1876854893541144], [0.019323420673308354, 0.08153814687243394, 0.010876503619064969, 0.054308930562148174, 0.07115524998235126, 0.04527555117684026, 0.013627432466995333, 0.03170267374615275, 0.04273608462103913, 0.0449282796903243, 0.04859995908073841, 0.08426135961687373, 0.023010705274740056, 0.02704524412570942, 0.05646036209298238, 0.028528512921184305, 0.04158336744313279, 0.021978129835558996, 0.036475736677886984, 0.04577849556000964, 0.038549440927923694, 0.025281952956931728, 0.020648224181645823, 0.006168573003848114, 0.03890823437682083, 0.04331262324065451, 0.02987376714666044, 0.034403461181829055, 0.030687084391472802, 0.056436253306005275, 0.04723076460762851, 0.028134180653479793, 0.07772882829510397, 0.061230358757799676, 0.03257725312705002, 0.027659108464215553, 0.027306347957722125, 0.0467970400988575, 0.06867645759015314, 0.02423118867520844, 0.046238841624149395, 0.004618054137550174, 0.038909598013326045, 0.07552025043555806, 0.02963679891470219, 0.09731824810226118, 0.04397940318731051, 0.08136261314634355, 0.03290357593927653, 0.05364867002372781, 0.05196160651863583, 0.02551136947717638, 0.0471795937647262, 0.0600570184929717, 0.08177346610013517, 0.044064952225814906, 0.06082297618230505, 0.03129847809642313, 0.04874913938223355, 0.02914697378723612, 0.019037359611942403, 0.042199995443825765, 0.02293355639032539, 0.02166874522733833, 0.04436226711878854, 0.019825872844986377, 0.07337064602442327, 0.03158792335119459, 0.03829297001263307, 0.052842347161664124, 0.02266287262881956, 0.029093202075830875, 0.01859008492301068, 0.020920227529601227, 0.019136859111547954, 0.038062320090830326, 0.020038427770017617, 0.04402774716577223, 0.049673278906172326, 0.0025701622625121908, 0.030972411923651254, 0.007884198181977076, 0.01799567155690203, 0.015421107640459895, 0.05224834173737515, 0.03350172206879624, 0.032540473245805314, 0.03903280793418808, 0.019796117990007325, 0.07193822248448288, 0.0636645878154424, 0.06703550491722361, 0.0479110200408726, 0.04319762961278039, 0.015812704974274724, 0.019682735061994003, 0.0337810913521436, 0.09082670248444043, 0.011050645937962879, 0.07232209382158133, 0.057235110641246846, 0.06469479221249781, 0.030128826544950568, 0.06563132703905145, 0.01604694210278291, 0.07164350846001218, 0.07360439477187973, 0.017358470265002503, 0.06599546395122044, 0.060423848204194545, 0.012859186089988197, 0.018635828032969468, 0.0880150372282632, 0.08930224880215623, 0.006839138861264914, 0.0702066645927487, 0.028420741587216337, 0.02910005281709375, 0.04160253496299829, 0.012136729745825213, 0.04680007763747727, 0.03716366065125312, 0.016764154575104197, 0.03355616410713523, 0.04124184927692817, 0.03980356133392742, 0.019568225984731992, 0.03564498710235761, 0.05110623487722009, 0.05007046102095516, 0.006356535548900044, 0.017614106144455653, 0.09481599043694236, 0.0339976490865792, 0.03546711680809817, 0.04537262600816546, 0.02163417167931555, 0.019291551415658286, 0.02672810287725541, 0.014461377586778856, 0.02963324043629391, 0.03136173206111116, 0.049844419118016965, 0.019359223792449604, 0.0678306428955928, 0.046176263732054544, 0.02644905343561644, 0.012292788559270483, 0.017818387319904663, 0.029608733283596176, 0.03223311110970474, 0.042083894818901055, 0.06590150326730744, 0.013529590590135946, 0.07105030359760409, 0.027813900359756047, 0.02500720509898759, 0.02745304038868316, 0.0663793352883189, 0.029546256898151293, 0.04413123032258403, 0.031485102860437285, 0.00046403274257412005, 0.06268282315783924, 0.0928109314953608, 0.03315345466797871, 0.06623298185126436, 0.09847592186903763, 0.07455179272519966, 0.024052140520765417, 0.00973494642699558, 0.007704086122929209, 0.03479048880117555, 0.13091670409325631, 0.06928215734660625, 0.018638580203837445, 0.040199782008365284, 0.026535173209624428, 0.01577568760577349, 0.01672089933567951, 0.029682559261639273, 0.01628286749755423, 0.0345894213645689, 0.022376141240519863, 0.0748117416796665, 0.042774680130664385, 0.05848028314029498, 0.04368958829511558, 0.019876580204694502, 0.10012095012972433, 0.043636548197678024, 0.038796914140543634, 0.03632236587544603, 0.03918075483412512, 0.04133115214626155, 0.02866624786909069, 0.06416847831719825, 0.024538977905326796, 0.03599187937535105, 0.0381922677549864, 0.048123812453160365, 0.02388570025833624, 0.04224745842117456, 0.03371479410317636, 0.046446861308668895, 0.050226279474314184, 0.040215617045760155, 0.026867440864143353, 0.010979560639468894, 0.021696303325194507, 0.021416196682220025, 0.09643532410864869, 0.028945465850073005, 0.024592820479865038, 0.03319247152596232, 0.04000281697259315, 0.0606803076281663, 0.025478111685163556, 0.04190882457600486, 0.03891983677843406, 0.012102928031386148, 0.08436082847296231, 0.06772725166933191, 0.02735998943418024, 0.06285190642360719, 0.058833759938997615, 0.09134178936120965, 0.009569551874583047, 0.09144691960705865, 0.08843206485072452, 0.01966787104104315, 0.02815282723355678, 0.0298260820038136, 0.028532508069709427, 0.001487947557771188, 0.015009821846991058, 0.03138048397827774, 0.07441117728669798, 0.028818534657118783, 0.01799693177153747, 0.02807301810882505, 0.04088175347855976, 0.015960487165308047, 0.01565161487838674, 0.01855552669674639, 0.07963507721621184, 0.043224109441883145, 0.022500542428104148, 0.033368805813933575, 0.02605374057536885, 0.027224633189278747, 0.0021980685696396376, 0.04035363161575891, 0.047987533072310115, 0.03450723162161247, 0.02098163522239174, 0.07942192091216004, 0.07902611392520129, 0.0625801558846668, 0.02029425517145184, 0.06542655939777052, 0.11522438887867237, 0.06387147752027358, 0.033571091330339836, 0.0213289967242388, 0.051744696383755055, 0.049704301636666066, 0.04384097109939303, 0.10427770490247397, 0.09120403143066554, 0.08724161784254736, 0.03687006894559149, 0.02518226193534511, 0.09867209400380812, 0.03364842790629595, 0.029479342948405013, 0.05154426863056518, 0.017372564367589452, 0.013785787628993634, 0.024616032943970734, 0.028447319092529438, 0.08285254690675967, 0.022530092354563457, 0.025244914521012577, 0.00415158607328551, 0.030770754599342906, 0.05517539898714712, 0.06781415668346229, 0.048327764210801934, 0.06845428443123257, 0.012062553282556756, 0.007122215531360839, 0.03578821490068109, 0.05161032073139664, 0.052426280979547775, 0.042912644904948054, 0.018068557162018075, 0.03357370369016163, 0.008242742173493871, 0.026463551649583444, 0.03848843351607362, 0.03366765671319539, 0.0023372066554598393, 0.020410076174284184, 0.04383981430662736, 0.03690581460813842, 0.03419667872930727, 0.04483140404185942, 0.03333465744470877, 0.07846835595104965, 0.030129345569519267, 0.05378894072266356, 0.026415060199196302, 0.00897001529548077, 0.06117443816976682, 0.041933504098485556, 0.03893905409401463, 0.008010510280127487, 0.034316931550781575, 0.10805192899199263, 0.009257255174640206, 0.06462750671010825, 0.04353480406045433, 0.029058517445059075, 0.03437886209858041, 0.03466876892132625, 0.06682993288362218, 0.015631546247600308, 0.028279143640951767, 0.02425710734490666, 0.010949627669047444, 0.01374423501998066, 0.0443957643132777, 0.04143375813240006, 0.02704764772657185, 0.01505176611845532, 0.04501539920907348, 0.04996179910977522, 0.05161142772844723, 0.05128480614193025, 0.0872073507296943, 0.04405528036577087, 0.1298583076605874, 0.029837680574987206, 0.042729641821595936, 0.027281394558808496, 0.04295192606326553, 0.04253088030964137, 0.08568925557718163, 0.06784435586943742, 0.10213635125828367, 0.011641417513601484, 0.07661227812810291, 0.11704757854702974, 0.09313736155989671, 0.12994715853804542, 0.2095237142977215, 0.09368684578446612, 0.11921182289839753, 0.12462364419573739, 0.10627234504828531, 0.1961089478385064, 0.129228935787274, 0.18544114284938384, 0.07564048027439464, 0.19267319671569333, 0.17054100851378134, 0.10962188063609986, 0.22864810341308195, 0.13656007546570995, 0.15115941303872293, 0.13374497813563194, 0.14446328364072308, 0.207819092057405, 0.08751800704386928, 0.13152594317591962, 0.2065195005026556, 0.11401214666904942, 0.08666536650590359, 0.06367226401644369, 0.1659276729990398, 0.21441547680766354, 0.19165031611919406, 0.13758015218040637, 0.18841713396531923, 0.14540134298224605, 0.15311370333356245, 0.17476472703199233, 0.14054307383635353, 0.12209982881622931, 0.23145077479702814, 0.1460178445784315, 0.14782735957734047, 0.11601918977835488, 0.11345088001220457, 0.13294948775681759, 0.0983833707869053, 0.13281218947902804, 0.1315657797479822, 0.22800111151751012, 0.11772733602312305, 0.12370875901392392, 0.19857305432519606, 0.11023539448938063, 0.18100183186752183, 0.203625189681207, 0.13326074928045273, 0.098704430575092, 0.1437046574128251, 0.20351419886273725, 0.1611172996701733, 0.10388262569904329, 0.11035563964997569, 0.17132531400890122, 0.11068239913231905, 0.092773454474105, 0.23828599511856036, 0.09616459629708722, 0.2032266554212378, 0.1482423647276817, 0.12282600355965477, 0.1779382769018412, 0.08607404621978922, 0.1880098969465302, 0.09129656719103937, 0.18812082647796602, 0.1148956758721221, 0.10252560053261058, 0.0786652711911067, 0.12310122830733178, 0.1319896561964866, 0.09269596468056403, 0.14703260464293344, 0.20852665086427044, 0.190084187253829, 0.13082924749582045, 0.11829591881964477, 0.24658683356979202, 0.12500572288709302, 0.15500836134437593, 0.1278585270648041, 0.21446485883526265, 0.1483575537079765, 0.1280210679396987, 0.20734983256026623, 0.18473085676950796, 0.13896096437688799, 0.11520233320733232, 0.10505372132625311, 0.27819566729087986, 0.13171639263389573, 0.11389823705558816, 0.17526122861571852, 0.11567158504359185, 0.12435208134833844, 0.12541163457377305, 0.15147871848556305, 0.18254339995403446, 0.1813922762390106, 0.12104435117855189, 0.17676037075298448, 0.15532282511553458, 0.07772574096076912, 0.14107544365669453, 0.19754628200204144, 0.21172862259611008, 0.13700793046624432, 0.12645456369125074, 0.167263669051951, 0.13946046902527734, 0.1508589073895447, 0.09324114349099899, 0.138508987823321, 0.17408033472395715, 0.14689357500643502, 0.11174345389008523, 0.10581118310050619, 0.10305215574560628, 0.07271007138995395, 0.19597082218575865, 0.10608679855302458, 0.11259289984140666, 0.09717063062013158, 0.1320031393439539, 0.16808482337622874, 0.1706629543895683, 0.12319618490554633, 0.20317606297471832, 0.2107496235159136, 0.08777690645787986, 0.09876417777230663, 0.11429949858856779, 0.10818947241791796, 0.06509528765755315, 0.09806266339916377, 0.11270325480689926, 0.16353306600884085, 0.13107603505974816, 0.11046731228669805, 0.09532197618917113, 0.12054515296533225, 0.08028105021484437, 0.09419490763496968, 0.13235172467126002, 0.09691636603806289, 0.11055708246966524, 0.2005445509548149, 0.11682297688938918, 0.13606882924514432, 0.08830916136503221, 0.11715643198019075, 0.1486731512892631, 0.133344589942886, 0.11268709801257619, 0.1593503791598543, 0.12068292621763484, 0.18177130590042762, 0.17383449710905555, 0.21353640623631018, 0.08749402083096006, 0.10993345625578396, 0.13658330325157414, 0.13429363498524313, 0.08625353295956889, 0.15540491909750048, 0.1868495648546565, 0.2622877596126449, 0.13458978925501147], [0.020474958075811307, 0.030228875712641788, 0.06949996380435844, 0.03308395517148799, 0.053853050790606975, 0.024331781765325897, 0.09329505309823061, 0.020944204166411393, 0.02373085282142124, 0.03077726443147948, 0.052840615802955244, 0.05704202967125082, 0.027531966597082156, 0.0424115123197196, 0.017953190066280867, 0.05247321918666844, 0.043217911790575714, 0.015384781666310325, 0.01677728149168674, 0.05757921052375629, 0.04833714495743475, 0.009313726388368635, 0.059812460244903644, 0.08518119372667805, 0.07277961685172013, 0.013080294386694028, 0.018200898850937525, 0.027737176654139356, 0.029801023267810384, 0.032782346355698766, 0.03479700820941118, 0.05841867051898472, 0.023157955034666007, 0.06204932207061399, 0.014566122873445914, 0.020223962773959485, 0.08120574132208863, 0.03125187696798915, 0.10096070506880361, 0.048008163820110986, 0.01612395404898111, 0.03009086114264304, 0.010601139060341784, 0.016384402875818552, 0.03496481210834557, 0.03435977501794696, 0.06559483061033873, 0.06343325607538705, 0.04505689436149213, 0.011020884379714487, 0.034397393765468756, 0.021577561612150842, 0.10131386394101767, 0.034479005112042355, 0.04761017348256804, 0.06087641847590285, 0.047569831292475426, 0.046473739503492276, 0.05012132542868776, 0.029258104416752057, 0.01822208309726369, 0.02321807761496354, 0.014701145870100348, 0.04329069014338236, 0.07414771198865867, 0.04628246650099755, 0.03061553560978463, 0.02751233942446209, 0.08945603329207628, 0.08824035134767333, 0.006095901903350868, 0.040998589547891776, 0.021094976015569224, 0.014850562701242105, 0.055995902136689236, 0.06384821909089243, 0.06845027779138858, 0.0033377543525514946, 0.041264824253777345, 0.051797322793713504, 0.009650664306395959, 0.035649227399018504, 0.13137672457002825, 0.047093696156216246, 0.08260691613559762, 0.021048325091420163, 0.010541866837640204, 0.09473233363561093, 0.06582227445417835, 0.013756029901184864, 0.056822465041712414, 0.035341007244442744, 0.058697300527485154, 0.020068368401318308, 0.038356291010014476, 0.0320093521487809, 0.05770947994484056, 0.0025744604945723572, 0.017015312670639927, 0.061708918562339204, 0.015040334171405243, 0.05563415924928362, 0.059151709410211736, 0.01261725839633014, 0.02689317950317937, 0.04742848040956644, 0.021908494358461712, 0.03347460255627671, 0.05911599439118178, 0.08447564207017423, 0.054571940037872524, 0.028661316178078135, 0.045534228425352805, 0.040191136706139774, 0.013208902354592518, 0.050248859915882356, 0.04916930030430517, 0.009288482833653688, 0.06561428924361545, 0.014232376669233125, 0.04035119545615969, 0.030135269344393766, 0.030728939605215867, 0.020188230517951232, 0.03314061503436777, 0.05456573089524623, 0.034520189998851675, 0.0834067425720634, 0.0667780687311484, 0.009042267920449376, 0.04464356694370509, 0.04164443231157718, 0.07218380729036947, 0.08024744959848543, 0.03228827710113218, 0.027162375138892282, 0.060932595703390345, 0.018465157049978455, 0.020515846103549968, 0.05759534433544163, 0.031572479018641096, 0.023202457082187457, 0.023112131485475168, 0.046269768593652595, 0.05425565680789371, 0.06595936588822834, 0.03835758952904613, 0.08816443969525638, 0.005981510612107213, 0.023123756869726127, 0.0345928227949527, 0.031699149741701065, 0.09357820685592391, 0.07153614123742427, 0.052117313889245835, 0.037621647164586096, 0.05207843109664898, 0.009088519521267905, 0.06608341084492785, 0.045825487393285, 0.042705360664835865, 0.012348558802548195, 0.06473167168517267, 0.0355595261639645, 0.0028348901692116938, 0.015195447823873933, 0.0644449632795107, 0.04763605959352948, 0.03723809758441583, 0.048282614818984465, 0.06285757930468648, 0.007043683858242848, 0.053871827605631084, 0.05796277542568504, 0.03504116043087936, 0.04284386170066653, 0.033653464934398095, 0.01870067546054, 0.055624368645611315, 0.02860113039552685, 0.033537226413647016, 0.02152453683647177, 0.022647041421864304, 0.0423855610912846, 0.03898701119807459, 0.04677539428455695, 0.040027695677934155, 0.02718104661682681, 0.04961835040200142, 0.02687446972084863, 0.054107549029492566, 0.05379748260301929, 0.028364305805054404, 0.037927028963402394, 0.05380827295143278, 0.03705656538987833, 0.06467101284332814, 0.03461774746556917, 0.03649657043898779, 0.09657620001704463, 0.02915511730187122, 0.035949679422042066, 0.03241948114948408, 0.051234788261353977, 0.08137959731562484, 0.028636841584117185, 0.04050334434836142, 0.019123638349194682, 0.033240091551335595, 0.07306011994519541, 0.01614144000585281, 0.024543723820017713, 0.037041048278972026, 0.043989151656146974, 0.07218057439932901, 0.04089982549269353, 0.04325176904638929, 0.06968076821536788, 0.06648454214296033, 0.0561410604765819, 0.015688172594133406, 0.036107045373008136, 0.05783915181734389, 0.017519477048828717, 0.0051882964720378726, 0.05703409683079489, 0.011209819856430254, 0.0404375680391827, 0.0740856665276712, 0.051940811061931234, 0.06622587255532704, 0.01337862051572771, 0.04523137854712625, 0.06270750268031994, 0.0039785323174475066, 0.03725582102854406, 0.015678987199921283, 0.04098830098706869, 0.016014786519771142, 0.033852961890759974, 0.06480809661649889, 0.035439395916558085, 0.052014742377063924, 0.06537574478575299, 0.043624260147372564, 0.04242207667219543, 0.0515478347698527, 0.05657385418852491, 0.04297969292008108, 0.04579999964804419, 0.03835866205214012, 0.054487842735984636, 0.04460096479423585, 0.02294464742824916, 0.006800650603949063, 0.05205695382169178, 0.04521226082297583, 0.08112255183439102, 0.04503628659632899, 0.018318698275834322, 0.08042233214984018, 0.022993389772431507, 0.019317106193592472, 0.07505056959006094, 0.09975957879496199, 0.046072658001174854, 0.02209017977058407, 0.03398228136281814, 0.06022332852045375, 0.023758165771141652, 0.03039708180773643, 0.023171005342456124, 0.032282864689947136, 0.05264548937820139, 0.011919113852444195, 0.0671127648843873, 0.03900428648076711, 0.05530739976694027, 0.03748606492374693, 0.03725097935286261, 0.047914226118835716, 0.0273120706345165, 0.0546080878965797, 0.023594127194355094, 0.006989361042337072, 0.05995438952419547, 0.06932541067081113, 0.018797238928175742, 0.03221644486691202, 0.048652439933991244, 0.04916800561571314, 0.13944228209795492, 0.014690399571742504, 0.02135565275356414, 0.011515995513858094, 0.007409225584142992, 0.16165759083965134, 0.02876846315038781, 0.0624047102586877, 0.027443060178249597, 0.026041444864184148, 0.04366282884392046, 0.009352941471602648, 0.07184812288370825, 0.04087250296687407, 0.028686505149028478, 0.08719393653014014, 0.01812868931841466, 0.059069056184061115, 0.010546754478597114, 0.023866404418743426, 0.017408348334532593, 0.0630287884644443, 0.021582269222445546, 0.09515863858283528, 0.011519292564762217, 0.04537353765279536, 0.049966108354349295, 0.012740984468931153, 0.02223572881531812, 0.04065195774479259, 0.01763430405257931, 0.02967596707505084, 0.060463868637358954, 0.028688362912244858, 0.00709528754082238, 0.07630251813679934, 0.0205771139852943, 0.039079765293506846, 0.08778003975749017, 0.024303495883941654, 0.12391675954624531, 0.023257157675200896, 0.027826029446817217, 0.056946119293570525, 0.1015858711194127, 0.080474418467812, 0.027487717358575716, 0.0477652833045971, 0.050953982563148585, 0.05400680080657044, 0.01960347943578757, 0.03783731240658991, 0.0703609393789403, 0.05835351091058505, 0.0278152525049424, 0.05897693794160601, 0.02553518523552245, 0.029395825958119768, 0.04183526864395507, 0.05882065217461317, 0.05541260279114208, 0.12246627931392963, 0.06725677409239354, 0.15655898459015355, 0.18104738345549953, 0.08316445960513047, 0.16403834696017927, 0.17814291430817497, 0.14369143473525203, 0.08539238118476446, 0.23559146470600562, 0.18208371655594918, 0.15942721777865965, 0.10672076695388365, 0.10713029457556625, 0.1407140186957775, 0.16718537486608953, 0.12693269448655267, 0.14230139884016207, 0.1116478231344973, 0.20973616580088295, 0.1594662116540055, 0.1476400510798539, 0.21047168681698464, 0.1490774158869059, 0.11972301038763217, 0.16260030799575392, 0.13440462580371287, 0.11444250422139322, 0.16105996564992014, 0.07166901918789072, 0.12908779174810456, 0.13310143363571939, 0.15466592004222257, 0.1611166561563169, 0.11097932715089091, 0.16398438372679297, 0.26531460364499404, 0.0906864011419877, 0.12869788363816279, 0.13288597906789473, 0.16005124235826154, 0.15133572051361685, 0.14083679194652265, 0.16847617173146817, 0.0895613627207856, 0.16653263731108559, 0.1456517005159009, 0.13094789919353303, 0.12265028597246255, 0.18539108666441134, 0.07234380475335545, 0.09547917743123348, 0.20021795235093565, 0.1238594868130261, 0.13136825163758573, 0.17305330193090826, 0.12436913446553292, 0.15110722712932095, 0.10588927810350734, 0.10557793231020052, 0.14007257327677744, 0.08894171250323135, 0.09445299499578054, 0.09009402365453782, 0.2037227126739679, 0.1791944159495254, 0.09072354108455682, 0.16187253978944596, 0.17053641198623568, 0.20456888742985266, 0.14234806891650925, 0.10787386717575212, 0.11140403863523277, 0.09283982833186466, 0.09406688668194318, 0.1983581666624354, 0.11937467020846183, 0.07413292649172007, 0.11843057409409555, 0.2242546351326089, 0.09628246658511701, 0.11683874297887088, 0.2264837058441293, 0.0851089516354184, 0.16759622781988115, 0.1600632086516388, 0.09680825571018843, 0.13983173055514214, 0.19262739997957984, 0.14378022432567614, 0.15691844836598443, 0.13387899755710556, 0.1168793379779785, 0.1661278211301373, 0.11216808110475542, 0.1557673093292021, 0.09477727235324922, 0.1589101390732873, 0.1087837957686955, 0.20050883593578495, 0.19293214975585862, 0.1923524203800386, 0.09954701237861188, 0.09015311967701682, 0.14187321697752323, 0.14940510233563764, 0.11042988889159695, 0.0740728345549395, 0.15180684926529087, 0.227909671262868, 0.12717480125326303, 0.08483184231144768, 0.1339297432212099, 0.20157429569911575, 0.16874526777575094, 0.26988496162718345, 0.13422833365057746, 0.12646293703226313, 0.11884182541360779, 0.1383791665636724, 0.2495354753468306, 0.14433462683471943, 0.16848884282573579, 0.17116797487101248, 0.11314980745796235, 0.11567659525861664, 0.12751823846971796, 0.1855899171242791, 0.12497931583634309, 0.11056387766955361, 0.22921370612757824, 0.11103980213163361, 0.28273532046906413, 0.21427345942826043, 0.2520777840888308, 0.07728608310102456, 0.2706675970506284, 0.14446126116860297, 0.119765505284792, 0.1403263475625746, 0.19179757353999924, 0.14340828863843796, 0.0935223284027269, 0.09952298786130645, 0.17749455877609793, 0.1253663434556896, 0.09803905256933744, 0.24933912701183752, 0.1398599685560311, 0.07621352170263568, 0.08743603563597126, 0.14974487765181452, 0.19961937721217834, 0.14462370245206743, 0.26637554348957154, 0.22473100392568499, 0.12697630021120274, 0.12382580958787473, 0.16562606418325057, 0.18282058588679762, 0.201551113878527, 0.20966447529292878, 0.14600399370876052, 0.11117081082756482, 0.12401071256927906, 0.06501618141849196, 0.15169847846752213, 0.18973350284561036, 0.1472792083457593, 0.13128119340587047, 0.16056819848956602, 0.1417604948003446, 0.10535576681215918, 0.238860254626601, 0.16535018059995868, 0.16127745801162335], [0.049751799087971456, 0.037556119833982764, 0.04101573459563717, 0.08279112963787011, 0.03480393364424667, 0.11181332876965885, 0.035345569298031836, 0.029391882520529534, 0.030993088636727586, 0.1249564098074071, 0.030716730078922647, 0.052713154094113465, 0.03951861876093092, 0.029973394965993303, 0.022777253386354255, 0.09086160545027064, 0.05420668080689446, 0.046154231043352235, 0.05272892401403478, 0.01106400651136233, 0.00314013191757934, 0.03741474213799642, 0.06415376942905207, 0.03835991460589632, 0.07794557755152065, 0.02978099006859045, 0.04633067641407252, 0.017908059826661504, 0.023059382501448837, 0.02058785453799271, 0.0229618710000068, 0.022215379604829416, 0.03295806011245136, 0.017710359346482064, 0.033240918926293814, 0.0216045968549987, 0.023280896824754538, 0.03122642178148512, 0.04106445778762141, 0.01717557060352016, 0.06713351054537682, 0.13808961597181138, 0.03783435530720219, 0.04401805615353008, 0.04370235898081334, 0.016204542668175795, 0.01883307460605377, 0.0949395450973703, 0.025187764361861254, 0.029007038251767238, 0.03321643475623381, 0.08255782522140973, 0.019135179463773966, 0.02479478232412329, 0.017734602198845918, 0.03895952013291178, 0.054148289585305806, 0.05011829938138685, 0.034176936643498565, 0.00892143670259224, 0.0348801095969975, 0.05651608349815492, 0.028203919552446857, 0.03675283834097847, 0.026589027275481535, 0.04087585843198242, 0.07443982897506607, 0.036532201188346075, 0.03248639892966997, 0.03295392323766024, 0.03804851135599517, 0.019175728497606133, 0.09775064344848357, 0.015210218956663966, 0.054419630267206705, 0.06177741448364912, 0.025791788300980004, 0.07463368752430524, 0.045596668421621286, 0.017980740503257802, 0.07950057515934592, 0.007212757547911738, 0.014218719236763015, 0.03557335405099777, 0.05655592007021751, 0.04066304686749655, 0.034454651176929474, 0.01788502356277839, 0.004315138663045101, 0.059146484690568144, 0.03723875642003071, 0.03615432831969473, 0.015624040501162171, 0.055765443736867565, 0.09577461923923224, 0.024320324920418284, 0.05150206484681657, 0.028861245974117232, 0.06046402951582305, 0.019943419460868164, 0.012385490943767853, 0.05427550997645144, 0.03913303904776131, 0.06580031071338924, 0.04414881970132551, 0.089244470450907, 0.08756514443385024, 0.045609573172705795, 0.0062298969057719075, 0.07033993324805653, 0.01091922834260209, 0.040019575145936785, 0.030040199748210372, 0.039620485472222494, 0.04208388715802182, 0.06552078055157777, 0.03542496282006464, 0.05296806985091779, 0.06854514245905223, 0.008149157830273673, 0.043458471059679024, 0.024031446570710793, 0.031199493790946664, 0.0523968095771007, 0.05473638847169857, 0.023221542247601097, 0.039131813307082465, 0.023342222163093188, 0.05349131939452022, 0.03355841640563261, 0.0384103998001064, 0.04624160337111643, 0.02099384857912458, 0.054279784747068925, 0.06551890363616329, 0.11972155482057603, 0.0484883860354462, 0.06472569619936329, 0.025950050574817488, 0.051221569414220514, 0.08740489416184925, 0.044210248461533944, 0.08567505230706546, 0.024375854803609754, 0.020316565567026698, 0.02579177680966114, 0.04398701427083823, 0.04940402964430471, 0.0392682688881553, 0.006197508144748187, 0.04951547245464979, 0.018727069104751273, 0.059337405292617704, 0.07972406598949626, 0.0278255793701617, 0.020067947052959955, 0.04255346841208878, 0.00561446400224081, 0.0539849060136945, 0.025339311875042417, 0.0600890179855689, 0.03387135566182194, 0.04054449476121415, 0.07792843250377525, 0.019830048024173708, 0.0009706445322785107, 0.034347034975766175, 0.013188193082779407, 0.024845520327348384, 0.01964754289797237, 0.03521688567895082, 0.046642581451564066, 0.01501022883120083, 0.04262159278075542, 0.026382873015057658, 0.04245262825861574, 0.0799041579387361, 0.01061996279825126, 0.04577855684704358, 0.042290439784166314, 0.042410612166408575, 0.0533981784246862, 0.11302692695490776, 0.026991602649251302, 0.028160541738954284, 0.04144048821481486, 0.05365520858416154, 0.03669519405511599, 0.09816147341963746, 0.035945190146805785, 0.0722214145465724, 0.0732261848245417, 0.01020960875922033, 0.04329236404549691, 0.04195190169998715, 0.0023396557427927734, 0.01837528344514149, 0.052064921136104295, 0.11191576238601439, 0.08413045051237268, 0.05136187458711286, 0.028824738054085645, 0.002714813787362448, 0.06926951689585563, 0.04473193901621046, 0.025476749963878144, 0.03349227237425024, 0.019277342399882696, 0.03198653421995621, 0.005999315453077397, 0.0019501499487124686, 0.018661110849690535, 0.02714608236396265, 0.07319277573016382, 0.040078931638310035, 0.023771886405865514, 0.061471446627570744, 0.03556440997448179, 0.018948698341245615, 0.008248732023451838, 0.017135048382765344, 0.030284788639795397, 0.07095479541608403, 0.04208965580009165, 0.07391018642773552, 0.033543623247814756, 0.024867620048744064, 0.03610734797773823, 0.07306883802577373, 0.018118293505282174, 0.026145699854579665, 0.02538097748202422, 0.05067974606889391, 0.020703302072961966, 0.04629498820811991, 0.05537124170411018, 0.018347281016289227, 0.07148113612446093, 0.06237678252340806, 0.02520802355701885, 0.01796133741135559, 0.024639310525549997, 0.060878222612964536, 0.04581393095694723, 0.021738710122243054, 0.03239083329155561, 0.02429655704256748, 0.03345945316757406, 0.01608104163390254, 0.059251266366411606, 0.01201782523909764, 0.04009623373407991, 0.021138072291749622, 0.024216541074096196, 0.04520589846276468, 0.05227893928907091, 0.07652967086722774, 0.023652763564079523, 0.03687712461537412, 0.059370078942588264, 0.03550265945734517, 0.032961561134265314, 0.01061656424069717, 0.03613936662253353, 0.06700285424989078, 0.03394336026582507, 0.03573753052361069, 0.025986788321226358, 0.04155299971781431, 0.021474342755672914, 0.04714467547713749, 0.0037195074565393193, 0.01974559449140103, 0.0675850044635515, 0.06106024510377358, 0.04406212153093469, 0.05059215923651092, 0.02873571097640501, 0.03764762137565882, 0.004180521214185584, 0.030789224979197307, 0.055227025652364384, 0.08101920657340558, 0.06936527022551145, 0.03594772972827477, 0.047246013587761315, 0.0544459377265265, 0.06104472033198803, 0.026327544229946313, 0.08271596875161895, 0.058919504329922705, 0.08206846357713785, 0.024522443812701012, 0.04487741145215208, 0.025324154825460528, 0.041882930804164185, 0.046599328127359195, 0.027729833701385126, 0.015618151200244264, 0.03097236787359561, 0.02273501512864905, 0.021100267767906192, 0.02861909707257104, 0.029466284979735653, 0.01942929977010335, 0.04404436744328949, 0.04288270235842755, 0.04807970494091992, 0.016851333465667504, 0.07128502527672438, 0.07608032199524103, 0.09247751470895545, 0.039198895796172084, 0.017848280070710088, 0.05077274914290156, 0.05288904788152826, 0.05359968253140969, 0.03205801596895101, 0.060652575245307344, 0.015655602366032622, 0.07727015613307876, 0.057156038876142234, 0.10552249052712034, 0.062051853991203734, 0.06259679531438217, 0.021647658657222506, 0.013412620455417181, 0.03334648201182004, 0.041123933023622924, 0.03633370014628576, 0.006721516594200606, 0.015766298240651528, 0.048884694809995355, 0.028465094247592554, 0.030156160562088898, 0.038064128058331634, 0.03606014930072331, 0.010872648281586027, 0.005981553225748001, 0.06629716469756057, 0.05351269707804727, 0.07469017118696245, 0.01662808395321331, 0.012274613123266928, 0.03481707588258771, 0.042937615540839975, 0.027123618750802936, 0.060755418718702374, 0.04868159724038936, 0.02773544146499086, 0.05997281776921404, 0.024446758156221722, 0.17501969641495138, 0.09469228255892954, 0.16236686568346717, 0.16408887811966483, 0.10846288919809366, 0.2568728816244872, 0.3102021159664277, 0.07843354491577034, 0.1267429345077084, 0.18823653639804935, 0.10945441381585215, 0.13164266433206298, 0.19662176709501974, 0.1642768301310078, 0.12851749291463246, 0.24612638408378248, 0.17003421070835284, 0.19630347288423972, 0.13682903361416635, 0.11284337228825016, 0.08637939354464894, 0.11927576825743723, 0.21042846413629673, 0.14139716994137536, 0.16971761721276468, 0.19330362579034222, 0.13393654608197753, 0.10924786885058689, 0.11052515958586048, 0.14501002527052356, 0.15177142535967214, 0.11302436056036143, 0.1368908109443803, 0.14020161312674323, 0.19815910637619036, 0.09083420248521913, 0.1126993400976062, 0.1877477876241169, 0.15180516387185744, 0.13402671463066532, 0.2140148741102988, 0.26351604370340226, 0.1787848193799296, 0.1734154776579911, 0.10508038884689731, 0.1402622566468293, 0.19085154688406378, 0.1280430470022463, 0.1645010793882032, 0.10877464101800036, 0.08727998352579533, 0.2348647996663086, 0.18001581542193892, 0.07272472665194543, 0.08901577022287155, 0.13870616353327228, 0.22338226016971374, 0.21936987466629476, 0.16222026709827686, 0.17756534530030144, 0.20189681871523782, 0.16542956263067263, 0.12509877958725538, 0.11115974085705896, 0.10087203039156814, 0.08225757238124648, 0.16077864284236587, 0.13203698510844863, 0.11485026984084999, 0.10664025111304176, 0.14668697641501505, 0.11790747393763835, 0.13559881898183979, 0.1094897534517992, 0.17299619773703237, 0.1320920515084459, 0.07527139443423479, 0.19084013217399198, 0.1310582311763879, 0.14937047516146015, 0.24964531703341394, 0.07750162959940012, 0.22971242936628483, 0.21269750931570608, 0.18299818038940432, 0.12457184899117678, 0.09169668725301182, 0.12428528614222042, 0.09821159089164389, 0.13739903367334796, 0.11204610458545147, 0.20385542974597026, 0.1550915431711943, 0.1932113428389834, 0.193008390826083, 0.10777860414236785, 0.16111042020061325, 0.1563784636316761, 0.20417280465124116, 0.10157933638941857, 0.09863631003686497, 0.17170092691817593, 0.09675421586800968, 0.13784952401634187, 0.11409741225502185, 0.19192201686241936, 0.20026826900580239, 0.2581035405878098, 0.10463347613450982, 0.23051185743702998, 0.13999075508646427, 0.14485227244515575, 0.06637316828052844, 0.19878110848367217, 0.20921810650296752, 0.1563522634246657, 0.12311537029041399, 0.0989039658358501, 0.12792326915528507, 0.11724860767924017, 0.1197156789261968, 0.160821084113371, 0.08732079302952175, 0.10068920350843862, 0.2160123564423092, 0.15946294811944808, 0.08662117855443109, 0.07661544973210943, 0.1312900034169997, 0.12007628417303486, 0.09949530910460219, 0.08242052694362018, 0.0687915623007763, 0.17861759770781765, 0.11911823759756743, 0.2600470443646754, 0.18082157137893862, 0.22643916549221163, 0.07544616973328014, 0.18462907432788805, 0.1912847542834859, 0.09774015570480017, 0.15054398396563146, 0.0976417440500471, 0.13414818553193925, 0.24826409114945322, 0.22235819979781107, 0.14428529077239577, 0.22045580429896233, 0.11117145434142121, 0.1419718584586536, 0.15391032752250472, 0.26609392956860606, 0.1670771419641472, 0.11051772853299496, 0.0801618392729471, 0.16258273393877093, 0.09437899856317429, 0.07312991821597661, 0.17401877189836196, 0.1681144709788984, 0.10208429558382881, 0.08057438528105136, 0.25216081269806434, 0.15709146166280394, 0.23285912019350838, 0.11400295361395806, 0.10884528198549825, 0.0918659390581231, 0.10554062382828806, 0.09892889433690617, 0.14010985111517293, 0.0788905623278791, 0.09526459620364251, 0.13353375237314932, 0.16688879158708358], [0.02832143552481167, 0.06363500533024631, 0.05722343163084119, 0.030439919529242382, 0.06716755549273185, 0.043677878641192956, 0.0153468708477674, 0.04409664911368201, 0.014883133886952796, 0.0776033201104691, 0.024287486561544003, 0.011898983934623821, 0.010660001426003875, 0.047125423687600324, 0.028992141672079603, 0.012371163184363997, 0.050118513886005654, 0.0718322035766417, 0.05990920565842141, 0.02519076359608481, 0.0843562089627789, 0.028911918859868765, 0.011459736889528652, 0.017705686210143953, 0.037933276410424904, 0.018729664227594773, 0.01282132123672073, 0.006375875438548505, 0.07643931845743811, 0.0841033922868871, 0.020352395499245297, 0.08699587981907592, 0.029967879132938482, 0.0281945847710895, 0.021407781206371806, 0.04258349905872057, 0.034481786011207494, 0.030871569854958408, 0.044784098112535094, 0.037829843049328175, 0.04601304103890735, 0.06689036955996867, 0.018641862890592987, 0.048737173088856285, 0.052781443171683824, 0.04678739505189081, 0.08986377592889533, 0.0195449426574933, 0.04544344317588595, 0.03700580057357589, 0.01132572895937389, 0.03571916739606569, 0.0692619402862845, 0.01938145757923203, 0.02984124671427473, 0.04906778599345877, 0.027733317486220793, 0.0869357419170199, 0.06772682266009432, 0.03719476765141853, 0.0404292636460835, 0.07259865922312583, 0.007687575491746107, 0.04654556024639357, 0.024268481835362413, 0.03950980108892245, 0.04858760208251977, 0.017453796500640533, 0.061741814377807805, 0.012937443886673259, 0.070494077799301, 0.050435750895450195, 0.04794712193430432, 0.038469503483464645, 0.03349348662361022, 0.05894344074711685, 0.015813516069864555, 0.05540275856131508, 0.024807907325486024, 0.08340666596327098, 0.07428795204407747, 0.033476061953772465, 0.02388689535549812, 0.07349470630288124, 0.03911584037386122, 0.023211485428375103, 0.052050392278620315, 0.02548329043953169, 0.05497422429823107, 0.06325807474974184, 0.02092507112050249, 0.06954758382973171, 0.04370887072816972, 0.05786050268779359, 0.031322795642359604, 0.016083617604547934, 0.04455768848739324, 0.016991439455699538, 0.07048247156724816, 0.02229823775949978, 0.027663532621978272, 0.06267485584342672, 0.017748347731427323, 0.03099492916296567, 0.036130713659428784, 0.04431335623526285, 0.05294739313784146, 0.044214603671383475, 0.08266130837822154, 0.0433878262617415, 0.021341384365974415, 0.01057792563862618, 0.01592771200868752, 0.04887134189747515, 0.008516452939910515, 0.02504331656851836, 0.027052937563689008, 0.09897823039922984, 0.055652798168481364, 0.07137252783943569, 0.042957001395763895, 0.046278463691593184, 0.0561283357561596, 0.09879730341415252, 0.007443867601274003, 0.026566634525454817, 0.027356417549233285, 0.06238083129808788, 0.054565623642936836, 0.05626599409527356, 0.004910962588544334, 0.043123077766429034, 0.03668983143964603, 0.028092719975017735, 0.019097780966530406, 0.010307119303052465, 0.017753168339690855, 0.03376160590578953, 0.02392319068613072, 0.06048998074425806, 0.03112931247620333, 0.029898237910181768, 0.02506456210187847, 0.09649102636162313, 0.04741703888641731, 0.09270377111651244, 0.07636849362883838, 0.02278477062411126, 0.049119186662738366, 0.025762429896501765, 0.03269028556983798, 0.02034538770995794, 0.029801779779635613, 0.08961537191944738, 0.03995264587443202, 0.027343472578532757, 0.013733853570996754, 0.0270781533477167, 0.04469285704075329, 0.027199792788333954, 0.06249028994070907, 0.03531930014310825, 0.032719462028434204, 0.03368015543768003, 0.00346192475614859, 0.04436822728283944, 0.020292228868892117, 0.061636178513928774, 0.026062171372975555, 0.015614717211123678, 0.06639272650523532, 0.0454160517021533, 0.027348526843613195, 0.02889484276003655, 0.021960992448692842, 0.06298448176934354, 0.0584451541785271, 0.045494169687792185, 0.0615318603212795, 0.03194186937875085, 0.02895485234236525, 0.043424134998912775, 0.025951029252140753, 0.09399246890097858, 0.05837925912572011, 0.07489899143336282, 0.11029029235003457, 0.021478021892929272, 0.055294303493874694, 0.014463812788768161, 0.02493632855945297, 0.019810746438921462, 0.11525395221167034, 0.002104995350706421, 0.05454549085228674, 0.06121682964505688, 0.039015896543259584, 0.09376104906081192, 0.010924899308461576, 0.013526420901349236, 0.028241124612489538, 0.017798911449649645, 0.03221929854442997, 0.018504918928468422, 0.036271283132655006, 0.08694620667806557, 0.013654754035204891, 0.050390072902964975, 0.12236284978327253, 0.05051879099600258, 0.05587141284899366, 0.01930567616176221, 0.04770819443247972, 0.018873481913619948, 0.040826947548456734, 0.13737447289449556, 0.033829638343905254, 0.01910006007810514, 0.020121272518149307, 0.095283510914493, 0.08347176811507634, 0.05456987543091659, 0.04961364662214633, 0.005880427704523168, 0.014837521969551041, 0.047109726546031815, 0.030894621440600005, 0.018298678483153065, 0.042810134679800084, 0.02160965112007914, 0.03003394272508881, 0.047914191644879124, 0.006033669229626897, 0.0896827570132671, 0.03477916985209431, 0.00848877418320626, 0.026070071654694698, 0.05922666728316296, 0.11886180498667302, 0.08970973862996025, 0.07054169782467427, 0.06741171537507927, 0.04858657935514085, 0.0704287534819976, 0.06152514556062318, 0.055793616620282975, 0.030797085041300427, 0.061403996416277466, 0.012687256807581553, 0.09513656758973676, 0.016393084567220464, 0.07302132525270985, 0.013960755407629956, 0.01988169958724851, 0.030400079126740177, 0.0811222453992213, 0.039780283752348156, 0.008849127578639216, 0.032456019713032636, 0.010463276750317985, 0.034947306999275764, 0.01948904313687836, 0.01296491101158843, 0.036433739737877925, 0.042328127479601296, 0.03073716547430283, 0.016394059414104108, 0.054058427471787705, 0.022571899687811252, 0.018587101010545608, 0.09232836505097729, 0.033065074934594096, 0.005971914882050647, 0.047978025921169794, 0.05418364071257172, 0.025469190591285308, 0.06941069923942128, 0.02174662572572068, 0.031360644216258685, 0.06970584227312958, 0.07406795457486184, 0.050830573459426244, 0.02028886765812434, 0.013648422318510713, 0.009713658758799636, 0.00861314376966367, 0.05525867274451641, 0.007912674627732486, 0.04199738050961206, 0.028065730697445335, 0.05516042196822744, 0.08038154562875148, 0.09343834218358801, 0.018103142201359716, 0.027658263852279034, 0.0398433251276372, 0.04733214868352779, 0.026109862261481827, 0.042105789611776995, 0.019158849665414424, 0.027560352069896557, 0.03142310527994508, 0.008372573966851399, 0.059041760471319, 0.02694964209841865, 0.03029227140359581, 0.03462379189929174, 0.014102515189968532, 0.03131752495744056, 0.0055824094470740574, 0.02258104677762716, 0.019281529070388888, 0.03144078467401766, 0.04471507359055742, 0.055852681999245, 0.060052820331146645, 0.07289325067352864, 0.03618946877278147, 0.03625669681857671, 0.06040370392222559, 0.052162164506772836, 0.048238710320043954, 0.047534660195871714, 0.02992001204420963, 0.03162413632737533, 0.006054363179681522, 0.0208563300510568, 0.03232951944453582, 0.04786863239602216, 0.051227127382111166, 0.011106140389587852, 0.06909028296509097, 0.04490831160857793, 0.016882128285003767, 0.03944124388057859, 0.047085391763117046, 0.03619578133727755, 0.0636937259696424, 0.021609227856500976, 0.02621003400324093, 0.06173108914686788, 0.03220198495734123, 0.01189947231567555, 0.055909372505641756, 0.005019438244597686, 0.03990836982284823, 0.01617128679138278, 0.05364983064693309, 0.018788833028426575, 0.049782641787802985, 0.013223388119630758, 0.019634235950727618, 0.14587588848606234, 0.16409371979534626, 0.23910026997327807, 0.08642378067898174, 0.14131901365134025, 0.23206802715937938, 0.08931891887538856, 0.27420447177944646, 0.16448226426878285, 0.14754543922120525, 0.14011611771439353, 0.15484590473915302, 0.13124987573152588, 0.16353337244401056, 0.09395434836586637, 0.13236317002484876, 0.1366318732259735, 0.19457166984436974, 0.12639303150917255, 0.10596890528235706, 0.17728221452524587, 0.27744483983805107, 0.06595390368132822, 0.13626986603823402, 0.1822423427215507, 0.08907827533661358, 0.06347057604861837, 0.14238361539619585, 0.10431767937036292, 0.3745419490000894, 0.17232191778959768, 0.12951333826828387, 0.20255032235816603, 0.15161016385161108, 0.12877630039809213, 0.1333054122064383, 0.14036460599351314, 0.13587997325005072, 0.09166861779146618, 0.14865139439221353, 0.11615716987439703, 0.20771842810415453, 0.13871059152147464, 0.15441271266148937, 0.18584168425971465, 0.10550601963674831, 0.15961032811432116, 0.13039145889061113, 0.1515535193104898, 0.13517638277863303, 0.18900502983841205, 0.14380283924120088, 0.17810107058575078, 0.1096548913647571, 0.2288303404085098, 0.20168216087885443, 0.13203033546526588, 0.2306053048420337, 0.1203320962527106, 0.11462090311632042, 0.14917645573375687, 0.18303126006597475, 0.23557491720684115, 0.12675553665406283, 0.1551771458358534, 0.17355712731519055, 0.0811906493899803, 0.12839376205398192, 0.17457113661352666, 0.09559149358181224, 0.2729552888101147, 0.16862079380981385, 0.13964547925899107, 0.1382016946351336, 0.09670088848760051, 0.13045286849862145, 0.07794412964534375, 0.10002898127441445, 0.1296622810825225, 0.20693364763452163, 0.09066626069045837, 0.09081610748844762, 0.11072440373320734, 0.13930872232923586, 0.17096295442071655, 0.06433139074473612, 0.12860837392508984, 0.07803498001228418, 0.1442426503185303, 0.1984708122308216, 0.1229174284925384, 0.2716673417918144, 0.12182969089236953, 0.15842125240352847, 0.12573631029696236, 0.1744443030967828, 0.15760723801870502, 0.1884308929044393, 0.2066546077689817, 0.0898552340485396, 0.21961539052426818, 0.14100369186170642, 0.07826558013837184, 0.09440794902583284, 0.17114775014981148, 0.1441333295717355, 0.1847188598326137, 0.20843144145704087, 0.11954949147278264, 0.17118769397418346, 0.18890226680424907, 0.13852395718136143, 0.11843334733238144, 0.11101646709346003, 0.18744803274110441, 0.18507931952274617, 0.27088308226197, 0.16156209031901053, 0.10622006720833241, 0.15257912717999952, 0.17032273474239534, 0.09025356912564847, 0.1570221919926905, 0.19222100565750755, 0.22325400172943072, 0.14901133314255746, 0.12245366950669598, 0.1255781591058739, 0.13015911974493535, 0.0685963784194281, 0.1630363345987374, 0.10523692359246554, 0.119503847954254, 0.08747590285155081, 0.17465229596822493, 0.12294321501206969, 0.08739747843074222, 0.10347453832265832, 0.10214565156568443, 0.11290819864840278, 0.24209761962054238, 0.12065395277233855, 0.10955703895418875, 0.23656289483751022, 0.13194644883755716, 0.15580549115134826, 0.12460033980108078, 0.11262863784307435, 0.14561304371924172, 0.12197449683181702, 0.2134861508684774, 0.1263618976959298, 0.13674137783387016, 0.16675996624173658, 0.11228804281281848, 0.1425348564742073, 0.12203742329391742, 0.10363387695002942, 0.1318402537294934, 0.10786908678710462, 0.1922861997398638, 0.11517667692274818, 0.1208687102001521, 0.19160899333655837, 0.1585412217724708, 0.3284039360380942, 0.07090283167218009, 0.3443296782432064, 0.2157773819541739, 0.14821757412245198, 0.10738933954628245, 0.1487271451661664, 0.07776134106661044, 0.1102654557795294, 0.18595690388352643, 0.12322983914805997], [0.013701719055402906, 0.04159976172471239, 0.09012769321880995, 0.0443183587894084, 0.019211453092735142, 0.051445336036023595, 0.04470459733819289, 0.06223558485808392, 0.015057847898964201, 0.0164276868435404, 0.017771165660252015, 0.01642400196062461, 0.034278462445663835, 0.038713261169651826, 0.026143801871747262, 0.03663753827793464, 0.06650309679248641, 0.016880883392126813, 0.025198960736874613, 0.05947765683935535, 0.030810637136680946, 0.047267850924042926, 0.01832870721456505, 0.04193266523220847, 0.06120199052196357, 0.02737371964500316, 0.039294810004292, 0.07721538084649271, 0.025643220869824294, 0.016516083813903314, 0.057739514421911976, 0.046405331682293646, 0.027291991470021107, 0.03578153461398136, 0.04831833366845404, 0.05791658032385092, 0.06637152885237048, 0.03537637752390677, 0.0839276593779364, 0.045711738658287836, 0.036500661348503445, 0.03463364378999799, 0.0052963981814231845, 0.05581762964626955, 0.07563225249008787, 0.08325622161670078, 0.012280842375701234, 0.03721251790862411, 0.031664137608341636, 0.0434096597675835, 0.0907098281107122, 0.03604375884958333, 0.03385050274852303, 0.0579113326215696, 0.01789914064800307, 0.040941780297866756, 0.08151600693142222, 0.02735678718665675, 0.028932434694480993, 0.0466554019329769, 0.07228929759754289, 0.05083418556398923, 0.0795700516731989, 0.06190863768419912, 0.07261921336213428, 0.021929253425989902, 0.029046085753267812, 0.0037925029473920026, 0.02485802288227264, 0.035295873174383756, 0.0800951743017762, 0.03172517374848887, 0.05397984217251501, 0.07008132494745717, 0.0405612376127993, 0.01652642217044148, 0.015058625478207346, 0.041450504814424825, 0.04973052865675381, 0.03727272092815369, 0.05941672220585808, 0.029704019299618183, 0.03488439968937347, 0.024915944875007676, 0.03817870416828702, 0.040408713337514675, 0.020582589598733093, 0.03200151506931551, 0.013195177889429035, 0.018975869564700033, 0.06044969984119939, 0.01746370776316091, 0.0728361158361358, 0.03822617480651506, 0.04807864773958441, 0.03264440456405282, 0.04616764141246677, 0.0391525627985116, 0.020011011398427432, 0.041755350351694136, 0.008489035610710422, 0.07256802336703386, 0.020309869958568486, 0.06023474706096515, 0.12030772699583923, 0.043935345470785134, 0.04066300473266071, 0.022107186922503096, 0.08540584901047331, 0.05129218739908069, 0.01910174930197818, 0.014291435344925812, 0.03869217076909639, 0.057825335421629494, 0.06238071638489924, 0.07632027605488416, 0.07324602650178057, 0.03813486095638045, 0.03497667881029268, 0.019867833395819032, 0.05044597816923934, 0.07378118488216594, 0.01089139636831298, 0.009782707221024941, 0.012109795052017416, 0.011950807867481584, 0.07703842219686316, 0.020437831539780866, 0.07340978545647475, 0.046934993381822304, 0.04056168960467462, 0.025887761880914052, 0.04530581548028896, 0.004806519906607367, 0.025200937243719256, 0.06243607389830774, 0.021090670601434765, 0.024877738155004, 0.03319159052484939, 0.008578808666507324, 0.039597947165490165, 0.04428829366882001, 0.05687514890826518, 0.02571933745076099, 0.07171941245154989, 0.08053125453091438, 0.03947209807172899, 0.007611188864816101, 0.03577816382711453, 0.02576696896745313, 0.030385169140513868, 0.0469277078856624, 0.04209255544288505, 0.09113854623489803, 0.04242727457876167, 0.02941484409084003, 0.004842785551332899, 0.07679039357049812, 0.029384717683217702, 0.013512734740581966, 0.014839061806278845, 0.023866316318632137, 0.01152493097188492, 0.026660152793591543, 0.021946530623902238, 0.009077112472075368, 0.07324086306917091, 0.041458724937852354, 0.08388723291817211, 0.08759004229138936, 0.058963948920849836, 0.06358425583570235, 0.048464062743850296, 0.0436127228632329, 0.022521048686617327, 0.028436116971856648, 0.02320308718950518, 0.07025895775446007, 0.07603122342017389, 0.05472900721454813, 0.04916338993596935, 0.09560774996756546, 0.05373897646824199, 0.05380472596434336, 0.02759043251224343, 0.0422097554039811, 0.04210855135874402, 0.06119657811077853, 0.04727812416310753, 0.018698610853584065, 0.05016491966201894, 0.0321753136062574, 0.08663738131402962, 0.03742715659280939, 0.03301254428562618, 0.04842764675436963, 0.0638483225127622, 0.07015817122714174, 0.03215252632094968, 0.030963316544770237, 0.09726775524717185, 0.030676163808112184, 0.01084253145006275, 0.11148436295409357, 0.04790242070392255, 0.050408834396230603, 0.0198368834436781, 0.08228986298725491, 0.02421919939919345, 0.05387108066990491, 0.056193740512695045, 0.011755777203718261, 0.14905063345307304, 0.03823116969978137, 0.0586520477137979, 0.06976800264730569, 0.01122107464564784, 0.028512863660111066, 0.024938494673058875, 0.004484419675258499, 0.1258008378828245, 0.07000830910739399, 0.03236916832505696, 0.05298132700244746, 0.026768979413675207, 0.026011657450468312, 0.054686022021116755, 0.04580699020035325, 0.005553849210451928, 0.04329071312602009, 0.018112260562878464, 0.030997993514662793, 0.02376240606780254, 0.06427709809354236, 0.008517288933357885, 0.0491163827809355, 0.05686276126652957, 0.007129469905198822, 0.04844345114824753, 0.04648269124088749, 0.027569495329272845, 0.04629503034295575, 0.11019591031776321, 0.03993833152156684, 0.06020309996881312, 0.09344614095865719, 0.03487418007646357, 0.013061783787223601, 0.03534571102429782, 0.03103134706766615, 0.04447102096051939, 0.06570694757805717, 0.008315939959439059, 0.06352342845451447, 0.03380492051702834, 0.08275473280058754, 0.020031431472049128, 0.06512086733334488, 0.021603409418716066, 0.044599853966745644, 0.02995976051616092, 0.04642189833365622, 0.014819358982476256, 0.017881373153819193, 0.015585973592204674, 0.010957127669826152, 0.0632700793475153, 0.03782615816641239, 0.0922067026277223, 0.09296802548511375, 0.02832807176145575, 0.05193132689342864, 0.09548398080251871, 0.029474424663931135, 0.0009435389051026095, 0.0566888056815632, 0.08208828993261823, 0.03456303346601706, 0.039038971111538916, 0.031313518317596566, 0.05568496236998228, 0.028387843856527924, 0.049291349601961916, 0.0718144303367984, 0.08365596629559033, 0.08337559343706216, 0.05306381168925474, 0.012954463487521056, 0.042084151458355694, 0.037412780952910264, 0.03978445893153548, 0.05857740010645601, 0.03589953130651866, 0.0696795194920513, 0.04971548268992094, 0.004612514364247721, 0.055673635760021795, 0.15345059815914402, 0.041618324035117706, 0.07181564075571877, 0.030130889236686692, 0.014836484878023547, 0.05248150059712991, 0.049454579955988356, 0.08237363470177497, 0.12645334561145113, 0.016750330518510555, 0.03260634914641419, 0.019694680287953348, 0.0017799580100766055, 0.021184836213867513, 0.02637061369304936, 0.01434131820250543, 0.01959947279594358, 0.0248697919080094, 0.05461069259552225, 0.08816386512931317, 0.0059534325320724285, 0.0911044629831468, 0.027140250519639062, 0.0977762078025168, 0.03217123035762099, 0.049024762495631174, 0.04161142158291994, 0.016436098488949, 0.02547877818165768, 0.06838406481209301, 0.04031556087636179, 0.046183825019867196, 0.06374660518861587, 0.04847401805642632, 0.03637860055952784, 0.016210552627941775, 0.008748242417500626, 0.02582212155234189, 0.033570673812421105, 0.04505342015275552, 0.0332525136670278, 0.01237115648109466, 0.012569959170275159, 0.0072441480006091305, 0.1008600487764324, 0.03869808113743221, 0.008099937638748557, 0.018814661682793693, 0.051856319224762346, 0.056101710370351235, 0.05065351138792692, 0.035235421176278786, 0.09892867983228738, 0.04628868330450309, 0.03009703198087312, 0.1310398144226882, 0.16035213105140195, 0.16987714736211687, 0.11168672507929225, 0.09708779353287914, 0.1924498514422486, 0.14396364109650736, 0.14414302824485686, 0.0901539393910958, 0.13433819065891928, 0.1370169856255093, 0.25537678851715984, 0.16638640644809893, 0.12004010950125034, 0.1292934557122569, 0.0840390332403683, 0.21556037988874222, 0.1091095440149788, 0.10350174976572876, 0.10642653556480523, 0.1623007063303263, 0.16770193263167338, 0.09837374106169709, 0.2210981690234715, 0.15925877036586886, 0.09230557393522994, 0.1444988301204097, 0.21224205472296287, 0.13351400262646138, 0.1527493059514992, 0.19897161922868223, 0.1521531516505826, 0.14991580718947997, 0.18452609678910625, 0.10981550935896174, 0.14069721072671876, 0.23686111754467412, 0.13385350215098551, 0.19888151196702836, 0.15832169161688897, 0.12427869012519238, 0.13207936509241983, 0.1594303587391492, 0.13518048900990717, 0.22616306740430095, 0.14642538803239025, 0.14416139903328112, 0.13864817067740426, 0.1461121653236689, 0.1439504030971758, 0.11632361779770545, 0.0741653626544341, 0.08414202610090857, 0.20868621165713958, 0.0757229802829604, 0.13248343050720232, 0.24560619506143758, 0.16320766250212349, 0.0834615255195287, 0.13011654057810385, 0.24027253771501206, 0.13072384911919796, 0.17928556509075627, 0.15052391246201532, 0.11538966468745664, 0.09030857423861181, 0.20482621636361847, 0.10654228378928478, 0.21993737727884324, 0.16346299960728616, 0.18264731212008387, 0.11293651325808418, 0.20812630863679996, 0.17791601438676158, 0.12054634806249412, 0.134872445055554, 0.07910814662013324, 0.12451951752506918, 0.19987445384744676, 0.1823092375190989, 0.17973721988739508, 0.1836240129365075, 0.1585696283127031, 0.13543409475636098, 0.16315901591893167, 0.19582396313067407, 0.12098861828206048, 0.11056028471718873, 0.05187780416059879, 0.10824382635614566, 0.15139500039719767, 0.12979884391590474, 0.15979274897085083, 0.17921787356176686, 0.12791490347515191, 0.11589129906027548, 0.182359692069792, 0.12890370081989996, 0.10817457966866995, 0.10032574841452223, 0.18943670506198562, 0.1561984329694702, 0.15189234467764057, 0.14476837049568855, 0.16474690168134629, 0.0813880013001542, 0.23365470250287365, 0.1538883101555609, 0.2457331664740078, 0.17215684116367372, 0.14345429987917024, 0.11667237932523412, 0.21056884208754187, 0.13997734854778937, 0.14201888093544593, 0.2633604972112564, 0.12839503375993622, 0.14698389677270768, 0.27834110142242524, 0.09360086773672412, 0.17364539596582615, 0.28050909960462206, 0.13747896728736742, 0.1758730111102904, 0.12292815372347833, 0.11003960539857227, 0.21559561993325912, 0.1471786056795428, 0.11697171285988824, 0.2911747595475566, 0.18847632191834912, 0.15194027113818354, 0.16322692195253988, 0.17837365999096827, 0.14012195530437654, 0.14608029606601886, 0.09716936657505651, 0.15670403567773683, 0.13443594347805748, 0.150639254659895, 0.20700120126768468, 0.0624990463256836, 0.30068279934986947, 0.1340825317968284, 0.19567394779334146, 0.09577137868731253, 0.22462624906291886, 0.21511989465403944, 0.11082446247699762, 0.12993369071233657, 0.1863503359979199, 0.14818340660102908, 0.1948770784562634, 0.16672866388915047, 0.10611047833076409, 0.09680351362593713, 0.11702079611319689, 0.12881869570382182, 0.12716194629789362, 0.11016745015137619, 0.1342157391651023, 0.11841991781106881, 0.07881173954134987, 0.12866331775101925, 0.11869741783988093, 0.16377508850587955, 0.19830018912832584, 0.09490097257038278, 0.17583763316994713, 0.18385374738324076, 0.13827764459194677, 0.16684610516794268, 0.07269880989746702, 0.14649274248269298, 0.0935175709967171, 0.1516723395475457], [0.062258398956468994, 0.04934009577658388, 0.09058682503358972, 0.05021769928956225, 0.018878122491221276, 0.059671986532667955, 0.0024896562371718427, 0.0033069269744784484, 0.048168406431232734, 0.05025866967175276, 0.015119517019258873, 0.037168724492432616, 0.044745284267851425, 0.04408518460789516, 0.017726324618824067, 0.012593308572597321, 0.04261901106445059, 0.055203495261770104, 0.027159079045598066, 0.009009087694838883, 0.04587344832778458, 0.07478852921556081, 0.07622380260257952, 0.009463054161789197, 0.048220232279310306, 0.11119064484392444, 0.021776250345752608, 0.06346876808111707, 0.05039741968615882, 0.04873272594845584, 0.035106366004554496, 0.00452365774113024, 0.08776361483239359, 0.01538027611170565, 0.045908431732846845, 0.057623670436441905, 0.05615182401191804, 0.0291733329574908, 0.04877243994645054, 0.032334725011981306, 0.028695102570758715, 0.015179989127171858, 0.02814337370857116, 0.03190157889959312, 0.004661929908193528, 0.013721566478301202, 0.0249938023907523, 0.07847524308148893, 0.04088036685941681, 0.0672290263877761, 0.021749203611585884, 0.05840828236673148, 0.008575966480308244, 0.0974895836665265, 0.030572483383659876, 0.005225435456997085, 0.027313543438550927, 0.0411972361466577, 0.03153819849924936, 0.021079633189665697, 0.08712146461250321, 0.015090739883993183, 0.023752381807313334, 0.049191620275979085, 0.09839553626314287, 0.046434745628146396, 0.05223060680192806, 0.08785309390194955, 0.08812057350071208, 0.0357001799068624, 0.009053054438423245, 0.035173199515068726, 0.06527137296694903, 0.019726222043015787, 0.0050307155376480475, 0.02715097192013937, 0.0671592434387534, 0.05934578246406971, 0.03335791970452955, 0.009042582016498333, 0.04673237461716898, 0.09306743305416838, 0.0756616089793463, 0.006987631598848009, 0.03498983637039219, 0.09134607179270637, 0.05737032132944273, 0.014992903752793229, 0.058082323446269, 0.04351927162778955, 0.0031181478275797304, 0.0923580049927677, 0.0526301178240007, 0.012869281213610403, 0.023846095427870754, 0.048135154384879336, 0.08402477634409744, 0.017064629580765482, 0.027449479995055065, 0.023356781664094137, 0.033998821201103355, 0.011137324956155593, 0.06584514983959737, 0.059916085127981446, 0.0513767711668005, 0.01910994261232836, 0.042777928343463334, 0.06629782353317545, 0.05102614804561581, 0.08372162769158041, 0.05585565825083083, 0.04506857720233741, 0.03430688813809426, 0.07432139944285154, 0.011781220898903426, 0.041468500219766176, 0.01885269794823422, 0.04580221364214536, 0.06328650427261187, 0.04184601302709311, 0.013024401569348431, 0.031231703957723036, 0.02554739476181567, 0.1537127381250743, 0.052060845548347126, 0.025941137141818484, 0.05897964223197872, 0.04645139271874101, 0.0818505039018008, 0.037419744692141974, 0.053199294338663744, 0.004716811968284029, 0.052648683964845636, 0.020219214944048755, 0.022225932465986382, 0.032596838164834246, 0.028793617647381562, 0.007574910771161799, 0.028454821008527954, 0.05219533611389418, 0.02093564887951699, 0.029425584643538442, 0.009906060783372772, 0.05731134022015238, 0.044163474963317, 0.03122991131198022, 0.05474185067859869, 0.007994685297636616, 0.02682452270340535, 0.014520080031586752, 0.0758588383154523, 0.006194891475681817, 0.021242721817426143, 0.03225419384938094, 0.005705190358698489, 0.043158034358413956, 0.05762161349036521, 0.0865322127637844, 0.046443283678062504, 0.017782195411141843, 0.06049499478972247, 0.05891169789397429, 0.011478925476812068, 0.034062276263871503, 0.013338330036569989, 0.051977790126036254, 0.06035386990275114, 0.04617825939109729, 0.03596115158870816, 0.017511249264521946, 0.02087713891430007, 0.04028838773768756, 0.0177664025085828, 0.014121763149066078, 0.09154379142508393, 0.03923449973245302, 0.13309185753666586, 0.0334607133822095, 0.04072214288997554, 0.012784796079710848, 0.00902283226981038, 0.024088520121069688, 0.021341815290431825, 0.02808554939204647, 0.054490022256129214, 0.04683137999006337, 0.012874833435841627, 0.0671028670284056, 0.11006238119256113, 0.04361956402839672, 0.016081853687102278, 0.015231660800054671, 0.026240621978837638, 0.030133752490303693, 0.032840607342340296, 0.03242724928103628, 0.008867396860413494, 0.01115550613781858, 0.07660257945498151, 0.016735692493497364, 0.07367689733303363, 0.036846952242476326, 0.04461902148661114, 0.028585243647197084, 0.035385873183728225, 0.025163843266425595, 0.022178243492699923, 0.03703659347769234, 0.08554134698164079, 0.025788348566199985, 0.035982245819703225, 0.053825866160613876, 0.06082941515130862, 0.03443087180775981, 0.024561238505186576, 0.017730417443559538, 0.08616978422768655, 0.02131610537969297, 0.07544440007017506, 0.03670084012311794, 0.03428669022997061, 0.08254255708907882, 0.02625960180716169, 0.05516960353199994, 0.047796834635758595, 0.03470461417530333, 0.020958608534607678, 0.09640213717976887, 0.0436441324681284, 0.05864708729448819, 0.022013092173203345, 0.062122575397933685, 0.005343929627880214, 0.020144755028248317, 0.025064531458361496, 0.05614894352132275, 0.09447696588693127, 0.036302822972497636, 0.039235170059386766, 0.06589450888455876, 0.09061376068500743, 0.08802377829147924, 0.030517030109260834, 0.11522890879742562, 0.01131377894536502, 0.006423754976206129, 0.05575265006853208, 0.07464320233632481, 0.02983146185626186, 0.05842518992722035, 0.06613975661175867, 0.02439633424904558, 0.029855848350111517, 0.03683176454937747, 0.015483900994783448, 0.08894155162476725, 0.040261080533626585, 0.018074873556953766, 0.08402421709991272, 0.04267806878253337, 0.01849745531686612, 0.021590537226368344, 0.02390123460622084, 0.06292140592009791, 0.024556756890829534, 0.05040917147491729, 0.03337742430308173, 0.06216961702692413, 0.08764074965109749, 0.0474349347003285, 0.04432491267160062, 0.027374194619516214, 0.015035223407340387, 0.07604823057209292, 0.06811938143425411, 0.024945362651300047, 0.017765582794503822, 0.020893803241872982, 0.0777345433110191, 0.06349677625562876, 0.04248467371648839, 0.056461484411791454, 0.014230092769608864, 0.021851246523100044, 0.049126556428569945, 0.05491082669205724, 0.05997919545118367, 0.01395795152582709, 0.0025616881330572674, 0.08507486072278793, 0.015270241945531341, 0.021952609531581405, 0.05230090686029965, 0.0208327230516701, 0.03936219126767209, 0.03322277030336761, 0.056344816881802776, 0.05021616711371368, 0.01214484932021268, 0.01922726323227248, 0.0400679727505532, 0.029394075447212786, 0.025648882259584727, 0.05710571456039625, 0.05053972051809392, 0.0632293273003832, 0.06043696745989784, 0.05524731549103895, 0.052207520742329865, 0.018523894926352848, 0.03617473690199756, 0.052550417866798184, 0.0237076326964363, 0.01770885206849104, 0.02517043736823384, 0.021329743659964973, 0.04901783706079568, 0.034978808534722176, 0.046644760971708644, 0.057003100913378506, 0.014628111835448973, 0.05191319742270055, 0.026886514538238128, 0.02814364375456447, 0.0030039238786670353, 0.037097907324712125, 0.04567822231160057, 0.053804254820269924, 0.01048826558079811, 0.013226767524986738, 0.04618484008636686, 0.031136155556586963, 0.01837225548262077, 0.021095378211729472, 0.01326506617554133, 0.008857626366549203, 0.04270444902020597, 0.03155279055898709, 0.009403842268511653, 0.011903662816621365, 0.06659530313505281, 0.06115848821918331, 0.09295860260364511, 0.04110586867036839, 0.04209370457477147, 0.05290844905821066, 0.02045447288471605, 0.02281438949848375, 0.0549382028440314, 0.02343621732096278, 0.05531310329153653, 0.044305362107772986, 0.1907679513697663, 0.1239036747644986, 0.1651738578033063, 0.17784441580935834, 0.2951150255337838, 0.10473520494997503, 0.113156832484228, 0.15328138465842894, 0.23811598488640404, 0.11918857212989561, 0.09202902385544393, 0.21765676417177726, 0.1625850015590268, 0.24873678272049277, 0.19786289081938807, 0.09142669488585765, 0.11225719245210772, 0.17530445129640643, 0.2261418314470399, 0.15385595060163929, 0.08489889798745995, 0.14266807916423968, 0.26334836237853576, 0.060504513432181654, 0.18538567808366593, 0.26942114135430706, 0.1012205008056856, 0.13225147440548868, 0.17411868508544662, 0.12193361838017741, 0.12819023547513833, 0.16307897505260285, 0.27842788386248774, 0.08744810918165792, 0.15362019470382124, 0.15761028704864366, 0.13774619407711491, 0.1495897295253892, 0.18194756741004606, 0.10929940358525324, 0.16962090627320353, 0.09969082240375782, 0.18707830338708817, 0.10358439533100014, 0.14130974398745647, 0.16024527710772332, 0.16157168173982253, 0.137066291044316, 0.1341038443628819, 0.16035360194021658, 0.06793417201768007, 0.3673446448820253, 0.17165165214288622, 0.24383601101656116, 0.10369891015392158, 0.16015173777216868, 0.09934664208201632, 0.12688608569723944, 0.20941489916895667, 0.14298176152571557, 0.15181754385271382, 0.10550769736930247, 0.10441802922756442, 0.13724028493367857, 0.23120072369854297, 0.1982170839102999, 0.15389250831738596, 0.23108257761886045, 0.17344445110328738, 0.12271780896210864, 0.10303049077910763, 0.13881715435174205, 0.1569408334551319, 0.20390896397011898, 0.10608952582603502, 0.20357496495689117, 0.18475085166433167, 0.22270669319456626, 0.14737711438248235, 0.19992601156475084, 0.2572557264037671, 0.12461912427698413, 0.14896141485341136, 0.11699601316884642, 0.20023074601927113, 0.13159646923022886, 0.14112119442753254, 0.12463143530992732, 0.09550779081520536, 0.15778791219476732, 0.08786493762125892, 0.11896001745856578, 0.18624285386214334, 0.15516749312800748, 0.22653622883221797, 0.12940933417168357, 0.1337088187856059, 0.1104439466050075, 0.11878523449864119, 0.10065734191166778, 0.1405245651521029, 0.12118448398166126, 0.23805364065112608, 0.14282313536011404, 0.12880093778573698, 0.2232203551477963, 0.08938912317276963, 0.17328433872711274, 0.1480526507141129, 0.16601578843209053, 0.10278312864923671, 0.12929109616145013, 0.14583036754160159, 0.21722481315655096, 0.06623197827608356, 0.14836271714058616, 0.167768873394497, 0.15642971491381047, 0.16807351591846637, 0.1667673819728436, 0.1921548309826082, 0.08865015476100868, 0.14550916219670929, 0.36991318447455285, 0.1637463755304775, 0.11597398292994308, 0.13314732230238377, 0.18802903382287872, 0.15444139499337445, 0.12449374632729639, 0.14424550016560864, 0.11277675328235473, 0.17310112113914183, 0.14668932064406334, 0.08835015472986045, 0.1430000403835889, 0.1320358359765622, 0.12803242902361578, 0.11287751682703534, 0.1335592477792694, 0.1219454620994868, 0.14265168488266008, 0.20817699301387035, 0.1963800357113923, 0.12044003804124172, 0.1216344993501421, 0.11646629401272345, 0.15636533288465393, 0.1439950200578859, 0.1648616616524035, 0.1700956662816386, 0.17430286794420213, 0.10956473813782777, 0.1190545910128182, 0.10389282232931546, 0.13766596934968425, 0.16049813208801134, 0.18966421785373844, 0.13109264384594657, 0.1001494562613868, 0.15219390752815432, 0.13721069861804286, 0.16902283675247626, 0.1306149880251577, 0.15965034854748558, 0.19374536740924084, 0.23014326189314166, 0.14584682311021513, 0.18241029983806997, 0.1023879575152551, 0.13847812980173096, 0.20212751843275564, 0.10381013079876862, 0.19111566335683872, 0.27844581031991594, 0.10790564450285128], [0.027185840412012996, 0.041932703536604686, 0.08760587732878425, 0.040210832826673024, 0.010614679664403442, 0.07729536808666683, 0.03531655754833933, 0.06306456094006858, 0.011685434052900923, 0.03194363904185593, 0.07312437940028406, 0.0017982375861573666, 0.03551955935695479, 0.02039018278611043, 0.007145602759274264, 0.03691394280101504, 0.0669090774270796, 0.028691708801254153, 0.07830142539234893, 0.04646588327182878, 0.04182412589509641, 0.016201480231698484, 0.06384264963168292, 0.024287417613630815, 0.04598233240446256, 0.018077654456118905, 0.028050158045164524, 0.03505559352737281, 0.0732145173054549, 0.02933148031813964, 0.03848690134022505, 0.07187652942394057, 0.053537219552503484, 0.014312638743450085, 0.058679385561375856, 0.11152308103778671, 0.03805894547352388, 0.02196910148937135, 0.053907933329502424, 0.07896654292820923, 0.04664455795840872, 0.014112902384611868, 0.012110756492362389, 0.015597069418177971, 0.0657921442161164, 0.028373945106361664, 0.032460558783983996, 0.0668686816108323, 0.029445828516937556, 0.045929774942417304, 0.01628455863664708, 0.03320059971883893, 0.04626794913483243, 0.04719296199900489, 0.055977661583212115, 0.09316927678282223, 0.05695162363530648, 0.014462555446962436, 0.041168810454227274, 0.03547361323369607, 0.03053356228666681, 0.041974482141555323, 0.0311357322930088, 0.009695332978040943, 0.06830986153574721, 0.02622732652291175, 0.026757710260309042, 0.05813440593380121, 0.02051664858065065, 0.01329242221770748, 0.03611877417912887, 0.028069036366838603, 0.04424283018095359, 0.008773481184166045, 0.0383260841631601, 0.05725695180796808, 0.029322093825847394, 0.021372520094436985, 0.043157593857857494, 0.018633133318695812, 0.047743300411609874, 0.033670452934119015, 0.04398831662030951, 0.019472034069739526, 0.017277280266787258, 0.028578854473908583, 0.0167211483142549, 0.03953852938608297, 0.05458184172429385, 0.019361491412705472, 0.05519998274863728, 0.034695896094725016, 0.024594335418735302, 0.03146732387493455, 0.05691255315116817, 0.03460621401186913, 0.04809166357341794, 0.023446107516065243, 0.010646782578870414, 0.04860492333048775, 0.056327790577685645, 0.06488552512300592, 0.04609529972977696, 0.030950769939790332, 0.030426041846494042, 0.0046224342452572485, 0.03151960746054688, 0.02992198855105427, 0.018154406890032754, 0.019528548375913696, 0.021625440192198562, 0.09397680240292704, 0.05533090334445719, 0.04375454872065494, 0.06561546901901884, 0.023202257899327144, 0.025657265176696163, 0.033044398221517765, 0.025653122556245616, 0.05296456116822459, 0.06400404903557032, 0.008271083596252627, 0.023364101634210637, 0.07271525780520133, 0.040420545565505187, 0.020354146010152275, 0.03222126355995575, 0.02290093445128972, 0.07874759499944987, 0.05772999194901317, 0.010945666994478916, 0.05076243376900112, 0.07132731333014465, 0.0374598570558573, 0.01637860359023175, 0.042102786547113816, 0.05421097856014968, 0.10627384658061689, 0.1083431649772871, 0.034248975721458276, 0.021181484579198787, 0.0139068927232837, 0.02121430761631458, 0.0446026386963504, 0.017555843242594314, 0.02080604212448722, 0.037538909668763804, 0.06930468799245935, 0.029849920744797396, 0.10384979883148786, 0.043023566775504625, 0.016046726640554208, 0.04103282218678825, 0.052980457492653406, 0.02155681786638114, 0.05018373478143927, 0.033403716440643036, 0.025087613687520067, 0.04668382762540733, 0.03243650745360121, 0.09964300319552423, 0.06308192049243277, 0.021257208540074287, 0.05752213314295777, 0.04457920406674666, 0.05571092892017576, 0.005543525218062344, 0.03332445315355736, 0.03679303114392585, 0.03385110795798321, 0.025789348310941172, 0.02399500568337258, 0.04861774381190058, 0.025038760260588704, 0.017217450715120763, 0.04621022824017752, 0.01549439448412628, 0.03456468438549388, 0.08160116526508525, 0.026435576033808535, 0.027718673715548172, 0.0330128507207959, 0.012866461052439146, 0.033976325029206854, 0.023798823972503026, 0.037396440297485366, 0.036055909004062414, 0.01539798902212492, 0.02407216605910611, 0.0576952958269225, 0.021923095994298498, 0.07543249506383173, 0.018515264945885828, 0.022070631121976242, 0.022040761353808547, 0.020184689276521246, 0.0227212791721667, 0.03081234168231247, 0.01925231430739645, 0.013269435749539446, 0.07210285477941075, 0.01273761751250394, 0.07019708083281595, 0.025059747239274364, 0.040568427347968665, 0.07844760262918088, 0.01919121304977565, 0.008425552777255015, 0.050704329830384066, 0.031027344258261785, 0.0747347115388801, 0.04266849651391949, 0.02883813310144169, 0.033192348951894435, 0.012627764334601742, 0.029758725638291048, 0.05372533244231055, 0.06176296223495757, 0.021576163501689033, 0.033913030844902804, 0.10142221175614866, 0.05309751189704384, 0.03078526047418916, 0.06014627156659, 0.07739732672850932, 0.044226045194532604, 0.028280118487835414, 0.015892900973408213, 0.013215870881873756, 0.013849249395031123, 0.05790775116052359, 0.04454269231627545, 0.00599592264118274, 0.006956379999586892, 0.07432106236416487, 0.01469278114757711, 0.04770885709853423, 0.06280292659216831, 0.04897590523826019, 0.08415403835956128, 0.01737255670671021, 0.06389727553112373, 0.025701422484651692, 0.03811942811514582, 0.02787476796055994, 0.05477599138694425, 0.0450035899637207, 0.016485116624784087, 0.037063781938125054, 0.08054657628939998, 0.036894120275974274, 0.03450523979300934, 0.024515619884515484, 0.01322265650566307, 0.041946198175390886, 0.036064037196939035, 0.0212148477083012, 0.01967892952023014, 0.041155277511044856, 0.06884286720906535, 0.07138991803531686, 0.08580421473109916, 0.03632395550788891, 0.015215819059390456, 0.013755000470536611, 0.040736924556474534, 0.06352168177404711, 0.015139082904844997, 0.03330627005667456, 0.015753223992613776, 0.052420474033081726, 0.004019710261585011, 0.06540274172420464, 0.03809676340390598, 0.011275846101794273, 0.11702612808514988, 0.05432869180015499, 0.0163790958017231, 0.03614598179175969, 0.03803492478665806, 0.023400479319295096, 0.07630851660524646, 0.09470568909760445, 0.03943044204084624, 0.08252604023343132, 0.07308328644402566, 0.02461180988428814, 0.041151412597466866, 0.09527416464181677, 0.09242421031118402, 0.16118735074996948, 0.008089845387956068, 0.04642752907989968, 0.06354137406414075, 0.0088742705843141, 0.008066516095441918, 0.03446139275066314, 0.05875921192308588, 0.014556585078788622, 0.044648324349714864, 0.06720049727347589, 0.04783967427248436, 0.04118638451121027, 0.014529118911483356, 0.06735850290785875, 0.031004895966860558, 0.04799536249089626, 0.06178769155315334, 0.038765753514223525, 0.04315164901556508, 0.030480820963519718, 0.08080207427302677, 0.036755466022558754, 0.04762303226837709, 0.017096297740335428, 0.016577606419882467, 0.028785001073453217, 0.023478865435707475, 0.0015805240165660038, 0.02625039917597127, 0.04246569388816434, 0.014696238119335426, 0.04272837011564163, 0.0735752527872401, 0.03896876298371823, 0.014575729616016391, 0.024440669672443502, 0.056167023196335764, 0.04226012185456292, 0.040848781054298726, 0.024079374946473588, 0.027613943750639598, 0.02008061048634831, 0.07132414172613813, 0.07063891438226547, 0.11038698030695801, 0.07799020983398923, 0.026658854274559888, 0.05509685199227064, 0.05469816834515622, 0.11199883696052337, 0.024968029277759696, 0.04926445225494043, 0.015179057372733952, 0.017997565709294814, 0.02675972890198952, 0.0169578579915387, 0.03970922526693152, 0.028609436703845862, 0.018373033061863917, 0.07010243833065033, 0.059797460243346236, 0.09338286209611163, 0.08336651529515944, 0.1876090337792712, 0.12427086070660623, 0.10688144623512223, 0.12409400164840684, 0.12276405769009745, 0.14037044358349618, 0.08008604253371877, 0.1158222362339016, 0.11853034172447459, 0.06832799483691493, 0.19584303871998865, 0.06836852854898862, 0.14066325770991464, 0.1363936045597638, 0.16987120251982443, 0.16786337800083623, 0.1871442022703348, 0.12873166811562356, 0.09853534730932406, 0.1063211678316997, 0.21275554813684958, 0.18032551412620854, 0.1265177353014869, 0.1000207381683492, 0.2174151400404592, 0.11705052032465897, 0.23353206714795482, 0.15219327933605642, 0.09697677973177164, 0.19905507684715334, 0.12396981879588097, 0.1345214082468902, 0.11449082138677759, 0.15959128316852356, 0.10331301634470302, 0.15356465332931088, 0.15081953047023666, 0.2453264657167658, 0.10812329774301861, 0.08155045024449788, 0.09044589549903909, 0.06889829367038704, 0.14718749229946446, 0.18954240987377782, 0.17570965052131685, 0.17123808723784265, 0.1555499242198083, 0.14717302855945405, 0.09461947356260593, 0.07086153187218212, 0.06899750205658137, 0.1247040221407529, 0.14447696597105072, 0.18807814005882512, 0.11199557342596593, 0.13448155635306913, 0.11766999434199064, 0.13091520256092473, 0.1612861607704432, 0.13386772074286016, 0.19531459126981998, 0.2167218917560193, 0.11022634699099487, 0.19933500537468543, 0.09239547435314426, 0.15026678271110983, 0.15317391784441087, 0.21028183490758945, 0.14084140379582683, 0.07811312864144003, 0.14149925881816497, 0.17660237277948088, 0.1404883598368014, 0.22399925206217075, 0.11126788182845039, 0.1338334919344033, 0.11198923021795289, 0.1350485686693461, 0.13710842588015143, 0.15839293779384706, 0.08519676063329944, 0.1375751113218646, 0.14021860495690378, 0.17291915993536675, 0.22994453868558332, 0.20919504725644666, 0.09456809970640367, 0.1703147061409489, 0.20091883087110138, 0.30889210561590813, 0.09585476735787046, 0.07236479556248074, 0.22143457355278157, 0.14379744598221395, 0.08517259055928839, 0.19045069903856326, 0.19607885590484067, 0.20222441323341864, 0.1396426753771882, 0.12027121524536803, 0.10648459736858645, 0.0885099683317446, 0.10750321851622675, 0.10265858573538643, 0.2548568293211922, 0.176086918180508, 0.2376882320330028, 0.13004903291021624, 0.13651352796343066, 0.1525122936694853, 0.30660527187489695, 0.1621716664803605, 0.3087528308312739, 0.10895791989300521, 0.13341339996024487, 0.16096624245326366, 0.16124650805948243, 0.10084189249262696, 0.14813304398088686, 0.20920059373301847, 0.11756280331962532, 0.15979552220913673, 0.12262365675621456, 0.1313580473464343, 0.12422325600299144, 0.12394616966165843, 0.1782005854071148, 0.17446060544781147, 0.11822857203022127, 0.17260005367138695, 0.16130160510299668, 0.1279994489384755, 0.11474715440624184, 0.16227806077128457, 0.14597284457375928, 0.3634522440693071, 0.17934924231902247, 0.12264985696322496, 0.23732032596824632, 0.12134715509150298, 0.12161501773422766, 0.08543888272176828, 0.08200173731893301, 0.06346466951072216, 0.14624638392800285, 0.1622487655690601, 0.08502940106536112, 0.18900075506779457, 0.17539324088683053, 0.14274997396334527, 0.13589901819584832, 0.17950282762608222, 0.10013601907919492, 0.14944598078727722, 0.20422810087761573, 0.16838174373392137, 0.20058671643416728, 0.2129832447897042, 0.1240414480168012, 0.14746467823222761, 0.14530970354474362, 0.1378338498574111, 0.14303235397223504, 0.13400500369889123, 0.0906229001139441, 0.11916373555939044, 0.20569534311371468, 0.13358538669924583, 0.07319226245125456, 0.1660728926259664, 0.15636997537747507, 0.09241831143416705, 0.1597351851242204, 0.08398599697337036], [0.09509839342846986, 0.05411429826410548, 0.023705322941344593, 0.04099073331622828, 0.04049376441886829, 0.010371231286215686, 0.05165779136962468, 0.03697631384937033, 0.020323548458456513, 0.01504761966756515, 0.04491645129277341, 0.04294966993432853, 0.0601379671734908, 0.05865887355720324, 0.034629748232903025, 0.0026823041280881776, 0.07715696664226633, 0.03925526837608026, 0.023429870282510118, 0.036287953205887354, 0.027724235513878447, 0.09613367698846326, 0.03964858174684548, 0.03511676947856623, 0.015390660433519273, 0.01428563988977863, 0.03518387495029358, 0.07362127168885163, 0.02583367415824004, 0.04635810236176176, 0.02752206491066083, 0.022519315412688642, 0.0388562553111584, 0.015417105788665434, 0.025293245092935623, 0.013866178980547816, 0.05408122624841429, 0.03128356619497701, 0.019798241968777393, 0.032100859436116395, 0.04455778041794416, 0.011291447482372244, 0.021097465801323136, 0.055208425037562854, 0.022890036850566828, 0.07052951702667822, 0.05307820265091235, 0.05093566540087904, 0.059983117821355986, 0.05272151211336736, 0.05309701393989306, 0.05546904431896345, 0.028240569198744434, 0.05826130073757903, 0.029084715736849658, 0.05302147000967976, 0.019505060120155255, 0.019661355463247147, 0.03486345101508402, 0.061812742628277316, 0.02072390983812511, 0.04094188755017616, 0.01679369301024464, 0.03389723028146452, 0.03676903727013738, 0.07748138955644063, 0.009678976043247649, 0.022261802617821003, 0.02775073641039912, 0.07085881992093018, 0.023461074958885872, 0.034824016639181686, 0.02596057279245748, 0.011941944230197659, 0.026191471692835613, 0.035012098885471785, 0.020480803326673565, 0.05580642561037695, 0.009714483260928143, 0.05497787470719027, 0.057920230732810114, 0.03847559005202305, 0.07171119232812236, 0.03827183364680217, 0.007787125265871686, 0.040389890557215105, 0.040453012371736194, 0.04107017663397616, 0.034430006128405376, 0.04445497907938496, 0.04106494808389295, 0.058759866928261135, 0.022705108971304955, 0.026688747025365313, 0.07358497444299922, 0.014977183628586993, 0.03143829105782413, 0.058917734666817614, 0.029748293435982162, 0.06527245315092225, 0.05062761378564662, 0.060287852275876276, 0.004232913967327125, 0.01959802105932707, 0.03197590858044644, 0.034469199186611565, 0.07736008719451005, 0.02361577109343583, 0.019407190472608613, 0.044884662474355394, 0.024615971656936794, 0.08005272536989182, 0.001094314345297584, 0.01819436029050379, 0.012115811715052735, 0.06899841370121126, 0.06699370716007487, 0.01957576428990691, 0.028287279494707624, 0.05605875582043683, 0.048464407483416225, 0.027699310843261982, 0.022551583036059336, 0.039503618759373506, 0.03469208863774135, 0.012088286175933338, 0.04331945291449947, 0.027675979635528022, 0.0285693722206258, 0.04376142819021498, 0.05026595133747305, 0.04602024992627483, 0.07825781966769889, 0.024222141176822688, 0.00846759089449, 0.015642835510774486, 0.07567869274005776, 0.06278818323006553, 0.033776433537563974, 0.061959283756873304, 0.06521015488091977, 0.047055092985711755, 0.010860040389572181, 0.0608070032490838, 0.017467955720701048, 0.027130827638170412, 0.00617775361001071, 0.020657495760749427, 0.01605416726951878, 0.0681070474186732, 0.007823154380950596, 0.023086015548136447, 0.0475785072382179, 0.031663668379488016, 0.03728081081663409, 0.07487429275868401, 0.019907702526618398, 0.02560683169342097, 0.08484945467282688, 0.06281544829929067, 0.026443093271565535, 0.0033779129209447535, 0.009707387371529496, 0.047856731220118465, 0.06419170227262282, 0.04519307415091223, 0.057314485011081544, 0.02292620769191173, 0.044218303876057755, 0.05836518609055108, 0.004474655884663545, 0.05391444507685881, 0.0516009170021261, 0.04109783623848231, 0.030563928096765475, 0.014327397427311348, 0.15441131838146718, 0.015187047669784197, 0.08083724536963048, 0.01825458820789091, 0.023091305385253603, 0.03844543300088375, 0.036990835045975064, 0.0743854980194761, 0.030716580691777413, 0.045762901840310906, 0.022973605551786964, 0.04043322432065203, 0.04663226607766363, 0.09600440731212016, 0.02269936331187285, 0.04292283387434098, 0.05562171415095368, 0.03550187421722278, 0.04153297800991324, 0.04778355067115157, 0.016323883845020207, 0.044705941822500005, 0.017398080841127424, 0.029181193019593918, 0.03716870917067413, 0.015183973741988021, 0.020287615104368138, 0.10101388689250716, 0.02459640768657048, 0.01716559805396584, 0.03859741335374214, 0.012340363576978207, 0.05179683632788159, 0.027294027348679882, 0.007805193928370794, 0.044702436970246416, 0.01786696495518329, 0.057834275667705846, 0.04241300236073233, 0.007822743566301202, 0.08757836711142333, 0.007716102690826501, 0.009084958170029906, 0.05099583777689165, 0.018501163182419636, 0.04485129168437374, 0.03935193335036597, 0.015225336744239735, 0.041694151417862986, 0.021806208214031595, 0.029728773515671495, 0.06885160061140215, 0.04156693102671735, 0.012562608556641687, 0.011817045085462592, 0.01999318261720961, 0.020966899521168203, 0.03097886812963313, 0.011352023012155007, 0.05972361702832484, 0.016513948343814384, 0.07929304960153757, 0.03035591990356484, 0.0390507803568917, 0.07467058231873859, 0.06329134211785371, 0.05009627052312417, 0.027560024567308928, 0.01703263966426734, 0.03777421357470655, 0.01940365880727768, 0.14374398836685767, 0.012464969693082235, 0.09130828067540162, 0.040842989429591164, 0.014722104120488851, 0.027105157947047587, 0.08949225392913626, 0.0601157391323678, 0.07069278568510087, 0.03097515643363999, 0.07325672108920352, 0.05131987381666418, 0.028127592297330983, 0.02661709290658755, 0.02265946353755651, 0.017211310520407655, 0.04626111563054785, 0.01233864083675848, 0.061376673890458006, 0.05082288193666647, 0.012395358156232585, 0.01864143388135539, 0.06063426191347742, 0.09409465736919835, 0.031961580821042584, 0.028698567203396273, 0.03323765156129676, 0.06208003836593801, 0.07584789091901434, 0.033265671227127314, 0.13266586668549046, 0.035849030790550095, 0.03591171593495435, 0.0261805338724967, 0.0177833866778641, 0.05007763160392643, 0.03456061645861595, 0.004268442252425537, 0.05918083607309288, 0.055730165387954445, 0.0456178967180031, 0.004347153956205735, 0.05731210247763703, 0.04313156985106968, 0.023825696421666973, 0.006030535930016589, 0.060757161568730116, 0.008122108223277235, 0.050776713647909706, 0.05307871592982162, 0.019360273332905867, 0.03944369919237591, 0.0353634612815034, 0.040394410475968354, 0.028079202353593805, 0.06524416152387857, 0.02359660357357033, 0.05767116405730767, 0.04433277656414336, 0.021290799580334176, 0.04124972466078978, 0.04401815191452061, 0.031762281132321206, 0.05369186206089874, 0.00590578665123171, 0.003535736848848061, 0.04229558789501748, 0.051227755574209076, 0.008594117976064164, 0.017003204650996674, 0.03238762721359249, 0.025050052396592595, 0.11420511655629643, 0.05364026986963807, 0.06421746197907675, 0.006942853280868863, 0.04103905814249189, 0.011129242728554435, 0.08766161022527565, 0.08386977377437776, 0.039881464814947504, 0.044268838865982915, 0.014732708692580703, 0.05499056495365597, 0.05372941569094697, 0.06589674586129766, 0.03757095895707607, 0.1211537255515014, 0.0870121821701046, 0.026182908745061968, 0.046574330678389925, 0.037473412981677445, 0.029067495995531642, 0.07171594973413215, 0.06260113903291284, 0.04322640004477674, 0.031267888205606616, 0.01444320023555549, 0.1075276413992528, 0.029137799884342862, 0.03437683962646031, 0.032309325366851785, 0.07753866228965983, 0.02054688224058238, 0.03206216816550061, 0.23209336934791458, 0.12034289809244296, 0.20215630801695011, 0.12086946862719714, 0.09327614604825936, 0.0873671566706992, 0.19227282384470587, 0.1765136751196077, 0.08837715932919134, 0.1336486808835499, 0.0834120745440164, 0.10522194657354586, 0.09371506846359662, 0.22171382792294028, 0.10308451529952789, 0.12434634334978559, 0.10409202817226611, 0.16298666145772706, 0.10584267697507337, 0.12943152007797074, 0.05202860090761416, 0.24320783424040965, 0.09295487175545386, 0.12077936902642251, 0.13306991677851449, 0.21056206987029125, 0.07573259468641012, 0.22962204631297822, 0.09388666449775619, 0.17634017152651665, 0.11929828358153183, 0.0982911644443389, 0.16612051265133967, 0.09520810488010607, 0.08532544042194083, 0.14529398342053737, 0.11417554556241921, 0.16860193272511806, 0.12044319432348975, 0.12707966845482588, 0.16445747366355312, 0.1384207957814778, 0.16469105387166624, 0.24781188476950894, 0.14059475412772549, 0.21677530340610013, 0.12369979578520983, 0.10447476569923664, 0.16165581351566702, 0.08776288704886552, 0.11348160779884747, 0.1518607971769187, 0.15047544973992533, 0.1600925957844142, 0.13062854778141747, 0.10479400219816355, 0.19261498935520652, 0.1031440633138822, 0.14736789068387401, 0.17399064114978238, 0.08897061700061445, 0.2505526868926902, 0.08389476356246779, 0.1927075021329426, 0.14270313534765475, 0.07848173950708683, 0.1029429345902416, 0.13418809871279425, 0.09456790818442261, 0.19184793616014142, 0.08149315452864093, 0.12001878927431761, 0.06795399837316045, 0.12043454519082462, 0.28023294022967743, 0.10622813411417509, 0.1268299697567859, 0.18819631678202461, 0.14701532169936166, 0.24904018418202478, 0.178491591566032, 0.16668819912498997, 0.11557262946641254, 0.13959392154168698, 0.19310971361494836, 0.14816503581260482, 0.10075662690665453, 0.09227843144007268, 0.08450640816121333, 0.1205013174143049, 0.12269858781608844, 0.14415412119800045, 0.11242271340902775, 0.11122228427519722, 0.15520109374436641, 0.1464508527949933, 0.09420359507203103, 0.08718272866380793, 0.10379951282013809, 0.10787853265121099, 0.24090891163195335, 0.13591541247742792, 0.10399766146175324, 0.07159298496140588, 0.09070162330904315, 0.15229564400449877, 0.14696954028500667, 0.07007035456838147, 0.08400626765984683, 0.11783243562545508, 0.16674001731218832, 0.13362378302601077, 0.1238265909975575, 0.10470555734730537, 0.2738979140356664, 0.1634675195260394, 0.15512532764865508, 0.13809811954777088, 0.08230477871914064, 0.09925720131685657, 0.28184592303249145, 0.23372463100860197, 0.11985961152541062, 0.08561062431263347, 0.12398177742837899, 0.11740577061690631, 0.16157672259836428, 0.14480243076480206, 0.1474132737325084, 0.12762506176987964, 0.09741574811238436, 0.19715617470923932, 0.10989309108305363, 0.06832173589857356, 0.15062780930630623, 0.08684047888363562, 0.12487227803156262, 0.13417703640316764, 0.13270515167424757, 0.11771650353987372, 0.12013744097203018, 0.1074437011453894, 0.15097173681903273, 0.22886335879804628, 0.11695682777151947, 0.1795897326402126, 0.0643933825795689, 0.1775608407033067, 0.059102924931193554, 0.13687640849140384, 0.1698348286651796, 0.09027824481768955, 0.11051529237339575, 0.16100077769689022, 0.17558333794436148, 0.1816214131371629, 0.15741352502617145, 0.1636581375233589, 0.17832268450048663, 0.16911164166465883, 0.17312915995717051, 0.1676913452965598, 0.13638200598859018, 0.12479317945338066, 0.18317320083658542, 0.20362702829222526, 0.12171851621279794, 0.1644941386316092, 0.0824968982487917, 0.2401585591536376, 0.12205748713665432, 0.12663756677460286, 0.18007855802293748, 0.18114702085093146, 0.0924384901900926, 0.1630385715754763], [0.04831759439360711, 0.008197574587088198, 0.05206964023771787, 0.040917732797923594, 0.04318877746681533, 0.027212337478094047, 0.008843993831936632, 0.005029494585018726, 0.042801041216138876, 0.017399662812691064, 0.07405454037530769, 0.0566044747228584, 0.021733387726389115, 0.02050995105697263, 0.020952700081491665, 0.014136643449385321, 0.045442638783565456, 0.026846444309358636, 0.04702263384035999, 0.08173603504415482, 0.024966772893563877, 0.0399550590513935, 0.017277845256631414, 0.046100237166448954, 0.026201086096285332, 0.03113868173151728, 0.047828056549112645, 0.07199836804741813, 0.02839078371893735, 0.01485919172409922, 0.03161911653625148, 0.028398136247790633, 0.0501902541896749, 0.053499194778381824, 0.021628288124057076, 0.0417978682314917, 0.04027882696039254, 0.0785443595340175, 0.10761240902807444, 0.04143492258604496, 0.009035699674108577, 0.10153699470984359, 0.05113941414522068, 0.02578306255952245, 0.01124321171382983, 0.037333778135718844, 0.05350721954938866, 0.08106527910117181, 0.01719018373067581, 0.025399133765829668, 0.05786108491461604, 0.01630479867960657, 0.03832647486800148, 0.014839597110215937, 0.011659714566063017, 0.07532567176367007, 0.04838422872126103, 0.033724458302341165, 0.03677419687230741, 0.0401708813414218, 0.04617757374240507, 0.033227780518392404, 0.07807464038412418, 0.03923258068220269, 0.017753214304966312, 0.08131300129236714, 0.019686421860129606, 0.07111861565781218, 0.014043348304356539, 0.05445715708417758, 0.020006160146646926, 0.08309666082383164, 0.025377436240594235, 0.0319437041593295, 0.09422882234737759, 0.01833316776150417, 0.09551289296078105, 0.027396215816899657, 0.07163299773369106, 0.005114843004247955, 0.014563375490627464, 0.0347983373719598, 0.013060769678333835, 0.008045403669858653, 0.0014037892082518328, 0.07927067983414858, 0.04590624455182303, 0.018666348975872802, 0.007642648265426679, 0.12644117247433434, 0.0307571335560492, 0.005937620956120232, 0.014431117113769777, 0.026866833739463362, 0.059095332999863935, 0.09386956541528625, 0.033507728198122595, 0.05611402906417366, 0.03536379452975046, 0.020344602469835552, 0.05250418446056786, 0.03031915342885881, 0.07059409823869506, 0.07480641736859277, 0.03096928436970038, 0.01306395277365922, 0.0454197557372672, 0.004516949204938306, 0.058445755557547656, 0.07860405310507744, 0.04828786635170541, 0.01918760477565229, 0.02823542108789327, 0.03289203865513687, 0.0479374002785452, 0.025932980220644705, 0.01223554551195834, 0.09759190236969341, 0.02386458495992326, 0.06027632265261585, 0.019982286931706533, 0.012770973938337017, 0.06621581382088124, 0.0400644104417053, 0.03156017373135734, 0.07776720163923118, 0.04332424862490546, 0.04036904530479543, 0.016179315392829238, 0.02522870218531499, 0.04375828722972543, 0.09494467022558374, 0.08909821660528261, 0.020749246281000878, 0.03263891171363573, 0.0286894086222615, 0.025706543782425505, 0.015234236770700064, 0.023929644976892782, 0.02353623584513703, 0.049247479576978, 0.05058167149282752, 0.0630521081808594, 0.02906388772140828, 0.06433231005024526, 0.020434025998017, 0.03460303857742298, 0.01603303090368788, 0.023623209807180592, 0.0591053495994739, 0.024312778954364123, 0.007360620656982065, 0.05023788187592741, 0.02118272372641631, 0.09040561459598043, 0.01555442896431252, 0.12156368218242161, 0.04750812291017464, 0.08219253151647507, 0.03600813576110429, 0.023401624620741895, 0.041601140682976094, 0.04898322520837669, 0.05779759154745168, 0.013199274544604124, 0.02365445278795256, 0.06923693517643599, 0.02249623318353007, 0.059958744734045, 0.02853054879984308, 0.023524099097196615, 0.055482849223358985, 0.07284886353919584, 0.09479741280477855, 0.011188945875713422, 0.04501616146655814, 0.04371528288409595, 0.13239174510442442, 0.0476903101098874, 0.06690760653826498, 0.065752912853514, 0.028555967597170707, 0.04664598288194788, 0.08015747257177869, 0.036817354435521754, 0.05131561819824481, 0.10051290369442395, 0.021518567096321814, 0.063258568876453, 0.04189896885485899, 0.03675832353051632, 0.034186497420793584, 0.11809038509043956, 0.023774833929154183, 0.02751747412877458, 0.045578902842657226, 0.041074531843825694, 0.08268954637911051, 0.039535185412293485, 0.018923969023049842, 0.06394343232856163, 0.019777511629546364, 0.05691881591994917, 0.04671817134705283, 0.019040073478414167, 0.018680814631103028, 0.023989068501959407, 0.02464130426937294, 0.05030471921688126, 0.059261673670862956, 0.04143764219817616, 0.018355338346032847, 0.05584585232540004, 0.047677064449676586, 0.03132367472825272, 0.07112846754851841, 0.007835986353682295, 0.10639512595990974, 0.08672620920884995, 0.006781682266943878, 0.016851705018310778, 0.021545962400494084, 0.025112155314174392, 0.04546906881695313, 0.04305130681924282, 0.06752094419132318, 0.027227301090475053, 0.027296214529703704, 0.01350315864152846, 0.00916983305116094, 0.036536433824127725, 0.1016095508971522, 0.008796362315244492, 0.019883549689585646, 0.017839391535568624, 0.04120487021282315, 0.08845242746775189, 0.03548472533903776, 0.03299732211857073, 0.055639092855515986, 0.06637585724914266, 0.06341040367260575, 0.020288365870533932, 0.05852933958052628, 0.07273973431438208, 0.0014164543174575235, 0.04681793897743187, 0.09814340906638293, 0.0603777373720321, 0.019040146256766973, 0.07074809723323391, 0.06628057123312066, 0.0723781408141217, 0.05724973525972136, 0.025278756455067667, 0.05239043572557069, 0.08248839467283219, 0.040379192139352524, 0.018731590938724337, 0.04774064974739187, 0.08212766685192624, 0.0170228069257592, 0.038433336472559365, 0.05610993049377876, 0.006971767833155971, 0.010976800807721673, 0.04835714368269809, 0.01324513735580108, 0.03766966555567999, 0.022394040884870677, 0.10058500788985722, 0.031904744757940216, 0.07861640244241684, 0.10706459487517996, 0.05498857312505284, 0.015970611017227413, 0.03615525911652273, 0.07363752041372561, 0.04731846635320014, 0.0504060420057466, 0.01712656395900394, 0.03081056244310833, 0.019824719882660338, 0.0398694372345363, 0.02004815708665598, 0.012767709446169678, 0.029151035968454617, 0.01786341605287406, 0.012089125042210424, 0.054012986966559005, 0.0673789344727993, 0.09202013723552228, 0.031187837763178735, 0.021408327044017857, 0.04422867287611289, 0.016193175838599284, 0.024818866213242856, 0.033864610257648656, 0.04212770355685104, 0.08617266471828185, 0.03325555886652681, 0.025999292791370424, 0.03588022206038718, 0.04214851816575374, 0.034477036266076955, 0.050583789725938154, 0.0532735052758888, 0.03288060479286698, 0.07996931371669616, 0.055106002912526174, 0.04674072497554364, 0.026686460252911336, 0.04230166680269665, 0.05186967213728255, 0.07872447446589509, 0.0018117936316787476, 0.024314648208899364, 0.03170783909398221, 0.010428473375917924, 0.03891416772779438, 0.05802080275550966, 0.04017651591810488, 0.006100242749051822, 0.07762847077702323, 0.033882877624203125, 0.04356762326713051, 0.06481152869039966, 0.05193702658758529, 0.0817517628292403, 0.034499080446098125, 0.022955453098421136, 0.04732230062326116, 0.09463612065320054, 0.06354261129613846, 0.03486967164902918, 0.05177436313862282, 0.033250721021284985, 0.050562787425494006, 0.04548632494744755, 0.04290695670211027, 0.02546892820617124, 0.08069474535483508, 0.03248268340323721, 0.07383478805422783, 0.02883770217698428, 0.07890219920344892, 0.07333751272169814, 0.022856005309750477, 0.035363212302928014, 0.01666048564197075, 0.029552404753743645, 0.022390053397224798, 0.12420130758396081, 0.26510163120204405, 0.1488493361900891, 0.1525472272788325, 0.13446505481918014, 0.15155992380553676, 0.13252818536373878, 0.17632324098339006, 0.18082313419830415, 0.15333642041490925, 0.15596474550904768, 0.11752585489903727, 0.13120772557393198, 0.09864759451198964, 0.178744982807867, 0.08775484312566058, 0.2157044350620239, 0.12864436473577254, 0.18525778736558654, 0.2067635148282974, 0.11828910063711867, 0.1538805420240087, 0.13320891577149593, 0.08315764142260437, 0.1484087743465939, 0.107966372292609, 0.16174700862217337, 0.13309106080522462, 0.12661455349335748, 0.07915935193699214, 0.12868662214567586, 0.12886456904872773, 0.15704243203565, 0.18223261340491234, 0.16820873043710188, 0.07282237987965345, 0.11224762401393346, 0.11445848481549371, 0.14713769658438622, 0.15151175219685803, 0.063469507355964, 0.18499351767522676, 0.22764143323706043, 0.1235077528643512, 0.15299325899010704, 0.148852140071892, 0.09035570396771354, 0.16548153403545582, 0.12254827370446537, 0.2158520295615158, 0.1708922904705809, 0.07378054136830954, 0.08670445997267963, 0.19791185915950807, 0.12217301319563582, 0.27716972234268344, 0.07734995185127182, 0.14469842666820174, 0.08954427896007415, 0.07240915971417582, 0.104253442897912, 0.08136169384083441, 0.28338294055673385, 0.2498055979489319, 0.1283895332486399, 0.14463353902101517, 0.08056733727214799, 0.13355979936257487, 0.2852574044898633, 0.12533209932547423, 0.16536374035621845, 0.2119323866622102, 0.1482311798439872, 0.2514868545075578, 0.1650642765866172, 0.12067014787105784, 0.1433537125347122, 0.10981746288316865, 0.10640674751372108, 0.12082356463877425, 0.1134093810293463, 0.15227508220461108, 0.11772654695256103, 0.1261478680516443, 0.24155697605061918, 0.13767629621490357, 0.28350634199957697, 0.10207235227308928, 0.09866876918221675, 0.21110580843542853, 0.16330339284914155, 0.08154307281778705, 0.15202120066650454, 0.10009773000473939, 0.2968691217322504, 0.16577580372893042, 0.1810551822305687, 0.23920611268089664, 0.1954648057900129, 0.10182767911183258, 0.1668306608353892, 0.09535642716312602, 0.07719488799451821, 0.12714156835910775, 0.13783418693609778, 0.09953493883292522, 0.11893655218544508, 0.07444869261234999, 0.10407201029480466, 0.1773272298516766, 0.1314920974114249, 0.15305756441047116, 0.087767161819483, 0.21408988943984433, 0.15286130800602898, 0.13861973349365497, 0.1103174654887088, 0.09567923363178008, 0.15359400981856933, 0.14112174601083802, 0.14931545472673832, 0.08345450815414229, 0.17048361320649424, 0.13262478905099054, 0.10128544973990611, 0.1536400210593016, 0.11193469241862336, 0.10466361403345101, 0.20516939311017915, 0.1537014613108289, 0.1666053543768583, 0.22508246974358637, 0.1917160464630973, 0.10180969902824971, 0.1631797462581627, 0.10680311374486455, 0.11229254740981326, 0.11290512663582641, 0.19655666494321442, 0.0896472488379767, 0.16910335259331813, 0.11740623793054013, 0.09013829587568199, 0.100832523237313, 0.18496131133889, 0.15315320282693834, 0.0958964731844683, 0.14806002047994446, 0.10501006197544838, 0.11342176867108192, 0.11500649049036926, 0.10924557824769329, 0.1318834610884228, 0.14824847810931746, 0.2179901809581826, 0.22795012070527002, 0.1885525017015396, 0.24953808004577316, 0.2007387389218615, 0.17686166289833286, 0.11657282619947389, 0.12269655002220986, 0.11263307349215593, 0.1470026199615771, 0.18911577550874603, 0.18726547398874838, 0.1753914635628462, 0.16700255564383923, 0.16481788738841013, 0.23641422781492435, 0.13166276647919609, 0.11002888016763235, 0.0986558759224511, 0.26524951681494713, 0.13590539204737834, 0.16664223384953317], [0.028443103693726084, 0.0482242580713524, 0.03734363385686471, 0.03743917268190173, 0.05749219825731651, 0.07467602154300099, 0.03911711591025514, 0.03902584419495637, 0.040521581071398916, 0.03108257345194298, 0.010734740006286773, 0.032228047268525246, 0.07777510766660975, 0.06667618669809834, 0.0444111741718746, 0.0706228112140971, 0.022469806980582017, 0.01057483830429133, 0.006047394652400287, 0.0021215203460381036, 0.080966591654766, 0.04044636655899306, 0.06290848967769454, 0.037037505122322234, 0.06893695046704623, 0.038398797398493174, 0.016647243812199564, 0.015558722887128113, 0.04894802729869562, 0.047885267995297916, 0.017204733655577707, 0.04894488250776645, 0.03880914090381515, 0.02375980902973923, 0.041424561246869065, 0.02171273399595051, 0.037082060795998385, 0.040901005268096924, 0.08526698025243898, 0.08112365500100198, 0.053634757867022875, 0.019707318823484164, 0.05781897689185797, 0.027458203821292812, 0.037350088147626775, 0.05285302259688897, 0.08190087418282226, 0.032572407620928945, 0.02111949274436601, 0.1173783293474586, 0.034921987793378295, 0.004231488086178058, 0.11367431721620022, 0.03023066261272517, 0.02770017843783623, 0.06595502216969767, 0.0846026900915369, 0.06517953434658628, 0.0187350383343836, 0.00999621784074172, 0.07013035457461111, 0.0483689031323358, 0.030003222599325162, 0.065094115543029, 0.01431341440747342, 0.04053716329977878, 0.052982759586865866, 0.05379688505443835, 0.04398689169677035, 0.04243374419128222, 0.031134481654472412, 0.04603823000985769, 0.016319833155120575, 0.05698045152389715, 0.026212010510085572, 0.019026839309522224, 0.01594454487560377, 0.011495536178230278, 0.09611932050076225, 0.016617111658917803, 0.06257615690570205, 0.07517505121687729, 0.0280422788308633, 0.04740791860967875, 0.04819357241954535, 0.07801018940705447, 0.0677566004977111, 0.03407758653103825, 0.03745780010978061, 0.03093313842621302, 0.014350647238203356, 0.030348523324655912, 0.054599220428856156, 0.023057549636089997, 0.021714926922633764, 0.00516348144775557, 0.024026859619264162, 0.06708645742506751, 0.030356636195774042, 0.031442083193049315, 0.09764993352995766, 0.05511528023728921, 0.016714485264533473, 0.07339706073605246, 0.03186102412010153, 0.06403515603573573, 0.07091814576978646, 0.020265187880384828, 0.0092322337854233, 0.023177013387002295, 0.08346693410027413, 0.05374049715277168, 0.012183191063213012, 0.005596557175815707, 0.04260037597569247, 0.08434070334319146, 0.015487138673873439, 0.03438433962723902, 0.04899383169568835, 0.03225528935511266, 0.0332616952308003, 0.02770661549162, 0.04543945568824007, 0.05168034882855512, 0.02783536231295476, 0.06634703702143123, 0.07164026790809247, 0.03574812551960349, 0.07244762498885393, 0.03367154077897149, 0.018983743033341823, 0.08806849484361949, 0.07007770135157532, 0.005346530017578194, 0.09232039007568553, 0.005059206826356991, 0.10371050106421595, 0.014900575793768852, 0.0038744085196090205, 0.07498831728533392, 0.04027919851303582, 0.02614322347536443, 0.002050338089541202, 0.06875839835453419, 0.044151091152021, 0.03180941086142294, 0.03970156821812834, 0.06641725664057078, 0.01960427425200901, 0.03914942183802205, 0.02863839099694404, 0.02923060952114963, 0.06380986489896333, 0.03355760435243288, 0.05289020850473354, 0.04831022845821516, 0.011219436175099785, 0.05776209869391977, 0.07337981609687691, 0.04973134837083278, 0.11729749941056776, 0.08910562467551039, 0.021419624925681183, 0.02111528692166171, 0.04759166479831742, 0.03144907374535838, 0.03593883544747387, 0.04245941579762486, 0.04548916330320701, 0.029135819547058597, 0.03838690771390835, 0.02140951064986087, 0.05409455617829677, 0.012958925949679989, 0.03719643772309346, 0.02865856783764978, 0.04422127246676434, 0.038529292815515113, 0.04602469706667527, 0.09808345502542873, 0.013766096296509909, 0.051779323557932536, 0.05012706725768024, 0.05816170547698295, 0.03411063939453133, 0.09238000703795303, 0.03147991261475029, 0.01324069021540063, 0.021239000545333953, 0.016918720474707025, 0.03243708584998404, 0.03235060984509126, 0.04195009373248585, 0.01818679517225152, 0.06036773992462024, 0.09944293167321913, 0.04758792245880731, 0.002074074366265127, 0.029448753057588494, 0.030526125488141855, 0.0827662700847272, 0.08570139040990223, 0.04715959886990247, 0.02261100847634577, 0.0637386991612373, 0.04525886961228905, 0.05810580787158782, 0.006466054042140323, 0.011470197820134703, 0.022201195486911365, 0.065469169208119, 0.04484117166289399, 0.09918260733566939, 0.01845932520565487, 0.045552901818507144, 0.022361399793636896, 0.03617823026293228, 0.028265702628320264, 0.02438988953438257, 0.03198782316288881, 0.05700161853324502, 0.022418392904763742, 0.08732996310197538, 0.0513885842425929, 0.027414285915813623, 0.015441508561883484, 0.02241297474791927, 0.014349287432137758, 0.05407809294880398, 0.04744819568229779, 0.06504134740680456, 0.025183614080531463, 0.025251401370511423, 0.11537949103982219, 0.05337795753392482, 0.06461190915996991, 0.04330431884755531, 0.03990750031305417, 0.04796701723769788, 0.026593968542593143, 0.029916995573007775, 0.0334924447440332, 0.030106971971690658, 0.05040672382399921, 0.07055071467954306, 0.012032224819244397, 0.043956451193099065, 0.020065125934178793, 0.050177192390565915, 0.09517740007610091, 0.006453835418553002, 0.017023471507033514, 0.01816218459768401, 0.014468390164115738, 0.050980726692585215, 0.00950992054816696, 0.013627243817843979, 0.0594428726171534, 0.02446556944520243, 0.08232183949721437, 0.03322277796424685, 0.05819193147603543, 0.023415040735515858, 0.06877608732470582, 0.03185733349152631, 0.036302826802937255, 0.04597408929839731, 0.014837022097180448, 0.02763126691382739, 0.03184371053301279, 0.04543994981495123, 0.05721488975048546, 0.04256389869917785, 0.04095984848156091, 0.018158089857728734, 0.036577829385116216, 0.06674944002541804, 0.011529555270117859, 0.020841556045437054, 0.062145121365545265, 0.028680489443603064, 0.15264796784087536, 0.039430081979521824, 0.05806881348572432, 0.057151856036075664, 0.05355092869590848, 0.06988817885998758, 0.0628504776696284, 0.02739694360042772, 0.004686158875213756, 0.00830257076755046, 0.019371239881541942, 0.04536797202402546, 0.049620483956870534, 0.07060019629857234, 0.03116438781181651, 0.02510668927683465, 0.02730786672703201, 0.005972809768507198, 0.030117134128006238, 0.02182843242471497, 0.04390118944068109, 0.06971747148782015, 0.005620359048818148, 0.02317305079721395, 0.005878277391480703, 0.021017028484493498, 0.04196584833064868, 0.04498298602899717, 0.01678319952090181, 0.03923815397185184, 0.044702142026395573, 0.023806283753665707, 0.039608971170720556, 0.04109757959902768, 0.04921384065622284, 0.10357953833356019, 0.04906669431816667, 0.020088160282842094, 0.022570350274984396, 0.05472866630542183, 0.055775360745047374, 0.012785410865270084, 0.04396031227623744, 0.036082120702391675, 0.02882789433633368, 0.07311422873528735, 0.013859444110083484, 0.09613873316876351, 0.019672894662606622, 0.06075863245754473, 0.015051162824214948, 0.033109596134313656, 0.010521247581158195, 0.03915946525070937, 0.0665537428651606, 0.02248543900467696, 0.030451537252614097, 0.06586515239530033, 0.06644557125025219, 0.028657799834505688, 0.045770712106698946, 0.03943555950818043, 0.009500635562524682, 0.06842247646061644, 0.05771786094673219, 0.044929597361554066, 0.020233450772901698, 0.09139749161418408, 0.017880030584731893, 0.03196556064780922, 0.018794262676589915, 0.14664217559320314, 0.14873923403361153, 0.18098009029223075, 0.21266940921064348, 0.10954016203721685, 0.13294228653032936, 0.09688425929315629, 0.203226977178166, 0.17322824576929693, 0.1245117876979132, 0.06487869161872134, 0.1061739640370492, 0.21692754039841317, 0.13064739354435476, 0.09631120254315677, 0.17246398113427625, 0.1623806552661042, 0.12032360033763033, 0.08304269759044533, 0.1452657454196484, 0.19592804383606682, 0.16998905748609575, 0.1396992126660001, 0.13470445729551778, 0.2571958796151223, 0.20347212531393577, 0.16436978723974, 0.22339886895591216, 0.11075719229636655, 0.13029361414092203, 0.13607436039995763, 0.18309748070614953, 0.10661552945572524, 0.16005891855926285, 0.2215815398601755, 0.14971489297045817, 0.16326102818692886, 0.17277435399591926, 0.15139129253164416, 0.12948799607974867, 0.13913521873614482, 0.16585860251178666, 0.19287314566393055, 0.21675941474255056, 0.24298485668916858, 0.13180718937468144, 0.2593174222255907, 0.10607177556882944, 0.10587594051274563, 0.1573345566829366, 0.1491900614552921, 0.10935765691101552, 0.20044295237429682, 0.12111691502673973, 0.15573012342135753, 0.2375826804387954, 0.16657232066556332, 0.20330971467398828, 0.17675637177401976, 0.10040257937244831, 0.27234585054459115, 0.1664435259637333, 0.13294463075937765, 0.17197973695733856, 0.10879006236791612, 0.18353660230434712, 0.15456726323933373, 0.08128847115703168, 0.2797494774624225, 0.09539104667642424, 0.17376049301557003, 0.1390717560124974, 0.09776565877179946, 0.12868717372898134, 0.13091812901679548, 0.07837117003697543, 0.11703257088459308, 0.07624363661893914, 0.18325871157069362, 0.08717761119647373, 0.14567253810744132, 0.14230987177260462, 0.11618150082687217, 0.13845173041186026, 0.17941999819970902, 0.15240013839737063, 0.08987470034269557, 0.19394327856359944, 0.1243525563228515, 0.1400161738837919, 0.2389221085656074, 0.11001092306668721, 0.1049733970073923, 0.07712185683269655, 0.18028750084340575, 0.13668534616308828, 0.12463254613741753, 0.18534093854888795, 0.14184677162237708, 0.19364573001380891, 0.13222915060337515, 0.20072183902225188, 0.11666464949807814, 0.198202068586984, 0.11758960107521665, 0.288681878798431, 0.08600266980788401, 0.12312221911645706, 0.13417769523878254, 0.14352657261394686, 0.258046911368447, 0.35764505245512535, 0.1562764513636789, 0.18832437603944735, 0.1050047683078916, 0.17662089678548998, 0.12873361397895122, 0.1696189297663589, 0.16501494052429355, 0.08649814483379165, 0.16133689111278904, 0.11612149315976328, 0.1099785098866109, 0.16658355151453327, 0.22367651454142987, 0.158676773369793, 0.16699815829915388, 0.15815842295846633, 0.1552111294961745, 0.1025276613091269, 0.059380509229677345, 0.10985803489963855, 0.16810768343988927, 0.10982055787838275, 0.21079948051802574, 0.12520030155898104, 0.2029048065624891, 0.10569684447780733, 0.10576184703818253, 0.13591919695177387, 0.17760124418043322, 0.21963097275264803, 0.08594552730961193, 0.12257258933518203, 0.14001471831673576, 0.10708959998502847, 0.08947366863609323, 0.17468742876043244, 0.09302408013853336, 0.07781240848764297, 0.16812645259403414, 0.1889239470925062, 0.18313694955600848, 0.0978505336529305, 0.15242920377321784, 0.13943524941081, 0.21783985918568027, 0.14041282356746737, 0.18955069894511856, 0.1575342145177626, 0.13510665345576503, 0.18165294531612627, 0.10930181676221472, 0.16066601259573815, 0.11355154396545504, 0.08830957505251132, 0.2066765332053746, 0.1043023193074811, 0.1773138079912432, 0.1423586562516228, 0.22905278169820387, 0.08555761102827326, 0.21453526231550404, 0.13351910477203707, 0.0986313917523911, 0.1362789058757405], [0.0391198278615071, 0.04972581338557986, 0.0466218089774972, 0.03447095735839779, 0.005547183766705735, 0.010980992266277393, 0.06184747705476419, 0.10801989885587847, 0.022822814550431027, 0.07937817729168362, 0.10835690093376946, 0.06157792518816649, 0.047083166277697014, 0.04877417130515941, 0.05126835823419595, 0.008736149719615859, 0.052187813130477746, 0.09716534461345404, 0.03838783851073634, 0.016310799063273495, 0.03492676818202581, 0.05069568835859818, 0.029902187093431433, 0.021930889023708242, 0.016642766028282144, 0.017048580038751808, 0.01866046925105395, 0.02889282028791645, 0.020258078584447503, 0.05394704211803694, 0.03490771940578857, 0.06476011652980121, 0.008291591769985614, 0.04975280649359188, 0.017624877340671037, 0.04178585597283898, 0.03622969604968544, 0.032790233230879234, 0.010041211142144617, 0.0740652273018514, 0.0199167768380815, 0.061861358567952156, 0.015118480885341285, 0.04021113926184274, 0.05914146681466411, 0.016201869021320058, 0.038215756010744846, 0.030927419579858263, 0.056720583008662354, 0.05859528825948796, 0.028940924863901832, 0.018972238307938944, 0.029308308073649966, 0.022968486169232957, 0.0327859316471844, 0.028784840194989118, 0.08510522078722717, 0.04745832336465678, 0.014022785546858946, 0.04544130962101683, 0.04699539941465182, 0.06554332651918934, 0.045768636008424145, 0.019791008183552374, 0.016929796190872308, 0.04218642036580751, 0.042808288407902566, 0.06505944240357607, 0.028833120971197085, 0.06978898579555173, 0.06728196306334389, 0.012700847207358288, 0.07719351669713374, 0.032857189315461346, 0.029545282051267645, 0.04941069460924595, 0.04133603978721846, 0.027620593393822352, 0.04157722724841968, 0.06392800331776662, 0.025171862291773, 0.02859869998158707, 0.004786217619004029, 0.0350029556260955, 0.008975082009489979, 0.026638798092702226, 0.011105677864003566, 0.037493442350457755, 0.06335018916175732, 0.04748797479776606, 0.047537107846789786, 0.012405802807470244, 0.055196726874959086, 0.055738427646217815, 0.035040919113183217, 0.05204825489331157, 0.02480393899003825, 0.03068623594909666, 0.034822430837178425, 0.025004677008837465, 0.030106738314873753, 0.02657864295366791, 0.0631909348040579, 0.04423770888317977, 0.01119440233695411, 0.05794090361544683, 0.039410236471843337, 0.032702140780466224, 0.047963451098410353, 0.021275495058826862, 0.07070914166228426, 0.06969870233367528, 0.0349322265584863, 0.03586004330446163, 0.046195982835225524, 0.02185399869396802, 0.03612337453711418, 0.005857717506812826, 0.05349743277615598, 0.011599373650707064, 0.03839970138224383, 0.04130167308293524, 0.02807159893094532, 0.05444598369180195, 0.04420608094322585, 0.05990298119403663, 0.03255500976416854, 0.04909621934676844, 0.036162697830267494, 0.016088915102544333, 0.05516742018141574, 0.02069342336917837, 0.02310327933951011, 0.08172665812796162, 0.05696164023491645, 0.059971913785463384, 0.03132136880360063, 0.06842878136423326, 0.04330572078845674, 0.0070810531483842965, 0.07811850657866848, 0.03571817148176413, 0.023111463073761235, 0.004332900411569544, 0.03180720069776139, 0.030675926320855657, 0.046059224649422595, 0.05304688114612814, 0.04700499083546381, 0.08051840723642419, 0.05083365313288185, 0.050054901775213025, 0.026648437394009485, 0.056639500262756506, 0.030048996352800922, 0.0440127624859733, 0.047030179806414156, 0.08496874988439583, 0.008745604202211385, 0.04713698778481734, 0.06468534634839143, 0.0351247827582542, 0.03192710111879053, 0.02493225871735523, 0.05117557732568634, 0.03209980798044032, 0.016413950887058052, 0.01882850680680525, 0.0398823228334227, 0.04567542226023732, 0.045578657694521456, 0.026215187859751528, 0.05331672029569746, 0.05888637102719757, 0.0542178197253135, 0.019080798712468917, 0.025756544426023483, 0.017410422517587582, 0.06722055345533356, 0.027807402018938335, 0.037639623417729334, 0.02054369339959756, 0.058844278326197985, 0.07300392739594945, 0.040300384674581795, 0.028504011514146003, 0.05899964478768169, 0.04047119929905861, 0.0408759618538522, 0.04063547919354132, 0.05945299263863314, 0.033247767752336885, 0.10534737048850906, 0.05594943124320238, 0.005088226236928736, 0.026801808196450436, 0.07634483683373659, 0.059619750827550895, 0.026054491341534643, 0.030236624691995884, 0.04279362931547146, 0.0048351639340962135, 0.03635522338651842, 0.02863508341233096, 0.0055951561925241785, 0.04483832564625529, 0.03722067291457807, 0.047604236301154866, 0.022130033579624953, 0.02458348569850768, 0.021279645340156653, 0.022287401445810835, 0.07384357508271933, 0.04795354941198903, 0.019376418635910077, 0.14020466215668187, 0.04992783077121262, 0.03868053772396619, 0.023541148383951476, 0.06862013480596005, 0.06724598757441967, 0.01729583300109352, 0.09812754338547107, 0.01054381174335797, 0.06707552535038802, 0.03743201359024933, 0.07658649160857163, 0.04486400108303755, 0.040836983300264806, 0.024885354984191158, 0.05673691600320801, 0.02425692156858502, 0.048342645468731085, 0.008551846202012272, 0.06651853346416066, 0.04620773462398399, 0.027555050741460536, 0.048674101070050275, 0.01696440229763187, 0.05454550617404523, 0.07951756698950645, 0.006838017500065748, 0.019534887753487117, 0.07037701956447094, 0.04434168233626312, 0.08466201594039317, 0.06606741492906887, 0.06891171553082044, 0.08105302169438332, 0.035449998573430126, 0.07417732894781136, 0.028308327760427233, 0.010559328854264272, 0.050631087994383234, 0.08146857842803001, 0.10140761012031187, 0.03355197360618942, 0.058441300756267966, 0.021190262031591228, 0.07519862374230739, 0.056785168051118814, 0.015852114452319523, 0.002748033514381537, 0.02191741928277958, 0.03689322395310287, 0.06114456457115951, 0.031110026212709568, 0.035900485085984396, 0.06941203989328877, 0.020898110571227247, 0.012186697830686407, 0.0569213631622974, 0.06876238201174044, 0.02432719672909908, 0.04817214877074284, 0.0666967255153483, 0.0246646354771069, 0.07882336875604046, 0.09052767538495603, 0.04221700259574479, 0.015817927778698504, 0.014554614317603411, 0.02263091910149782, 0.038475839030598445, 0.04224243288439128, 0.03560951340102381, 0.048747013488243666, 0.02539288248836754, 0.04347954996891561, 0.06031165079724404, 0.028332919182796634, 0.015325939410456247, 0.08845621960297709, 0.045983286183928294, 0.03130002559403018, 0.00790386988345774, 0.027373574088297548, 0.03772092832913322, 0.04213026612095776, 0.01835217631812538, 0.027538417057404597, 0.07245868729848055, 0.031241103856553955, 0.07608154007504064, 0.006662357369467857, 0.05111552752374161, 0.0539204741888229, 0.10878558841443832, 0.05703296302066696, 0.03798215665043362, 0.026534805487420772, 0.05424607304796096, 0.039990766409544215, 0.023408511751181176, 0.020493932158475923, 0.08021571823666174, 0.06779422307567251, 0.023035344577604727, 0.04554532520893601, 0.04791629072579165, 0.023277673509813124, 0.07693323066398021, 0.047313831521258246, 0.04814123712299813, 0.019098529817476388, 0.06572400069525165, 0.0230397783114665, 0.0665037939324975, 0.057140318751936, 0.020954561675147667, 0.061628257164791714, 0.00909213928671013, 0.05807978769523963, 0.0276342393349736, 0.07409933353624037, 0.050310947511705666, 0.01339200407176489, 0.0732749539818014, 0.062340990895585674, 0.024585331970405196, 0.011698835803526304, 0.02732384349069288, 0.056449613879404725, 0.02992413742768188, 0.03585658824792312, 0.02447456140221367, 0.020665419025106296, 0.027570447193518765, 0.04063298174690816, 0.029076510935180613, 0.08031268198523792, 0.008726832175236798, 0.10058938225190486, 0.16392075246380222, 0.25609373956197695, 0.12515135620149875, 0.09474839849938309, 0.09981741843324515, 0.20575667611293255, 0.1804663057649328, 0.07727645337581635, 0.13155269496623548, 0.1846766943532613, 0.18149605050923365, 0.20262601184508494, 0.09944574321590124, 0.12620891759833022, 0.14516393233451153, 0.2861243402284961, 0.2688702322061985, 0.09814783705458527, 0.08791726142648729, 0.08935898527382843, 0.10648681136268763, 0.14347487700081643, 0.13092894617828632, 0.11305561694767206, 0.07567103186081495, 0.14328045920739252, 0.19301560737432974, 0.08579646958218468, 0.21014487370848658, 0.14625554633957727, 0.20311601700321322, 0.12094131235273615, 0.14772041370311093, 0.09934812063171018, 0.13128960505127907, 0.1962124463170767, 0.15523503143941203, 0.1381842431522185, 0.28769120453826846, 0.14500575049990608, 0.08505043783976186, 0.14138085226858818, 0.12838505929516209, 0.09250325526321128, 0.11723435844384855, 0.25785471523000353, 0.08265809080893956, 0.12832712006544875, 0.1462229416375199, 0.21689891935356204, 0.13495276171353557, 0.21689888871004506, 0.12499986231447228, 0.17954252630231843, 0.17397881275223148, 0.22515042174247005, 0.16026078272731076, 0.11683607699289439, 0.11093000641032574, 0.21286758083489635, 0.256163974502875, 0.1192035491488153, 0.181647919779343, 0.12216241053876378, 0.08189538133240516, 0.14473650123803847, 0.1443118433798513, 0.1055678352713585, 0.2119498381451253, 0.11230713372389156, 0.16752689686273375, 0.2154898078691575, 0.11727123025564418, 0.19314795672412843, 0.2231456156099035, 0.08469554760883893, 0.2151383420512561, 0.16598275472079554, 0.1687817335609467, 0.13366194952639843, 0.12349587084064562, 0.09897960935749354, 0.1850573634428363, 0.12623161678352665, 0.18642317563776048, 0.10470071567162391, 0.15227885135719854, 0.12821139482360694, 0.1372635740065767, 0.15663236049154114, 0.15172561330180015, 0.30256608861588663, 0.16101989925148028, 0.16429006813033936, 0.14699561791794916, 0.16405639599167532, 0.08728984307738082, 0.0848353892985371, 0.1027869590888581, 0.21134910263842155, 0.1722941241197048, 0.26583741268804, 0.2082246130392436, 0.10938987856911075, 0.14118974397499717, 0.12589582512455602, 0.07766554177167916, 0.22909859375607586, 0.1640121314314104, 0.13782963637382756, 0.12174949680845584, 0.1888668888639058, 0.12992587661550892, 0.21404337258108203, 0.13867414105803738, 0.2365841001512543, 0.08434483255710333, 0.11622471584668083, 0.15300786062594385, 0.10591480415314437, 0.07560865698202003, 0.16237633453021127, 0.11642641913626464, 0.1705894099488374, 0.11038992974546649, 0.13383461042277275, 0.17091633030964484, 0.11901325290842403, 0.14765620021329773, 0.18823950881919554, 0.2827165666366777, 0.08312094581103133, 0.18721060677161142, 0.11618561471902555, 0.14753071501130058, 0.14689418787677444, 0.13620890076121978, 0.1991686263992902, 0.1480457252792774, 0.20878610952246576, 0.11493693736772384, 0.07279404228733433, 0.10530808549975196, 0.10751868583141796, 0.2087391176891904, 0.1974127069115639, 0.10974675296775757, 0.12032371525081897, 0.20596751883145303, 0.18163181661117464, 0.18879797159423753, 0.1489193106610929, 0.18406529490265156, 0.13699438603174302, 0.126049954354042, 0.15483378522819088, 0.21685707563113785, 0.1497876866450233, 0.1503239635137781, 0.1298538337071096, 0.14072843647051242, 0.1685344863442644, 0.09072612280086165, 0.13951524431186338, 0.040699696513794126, 0.19638804899108028, 0.06575333420187235, 0.19214700156402206, 0.10849874977382923, 0.12190103666075777, 0.12179037526009545, 0.09226192990618368, 0.09021927903015768, 0.14485332964649125, 0.07405198164164059], [0.05461480648767564, 0.02993817407367451, 0.03854431579971025, 0.0264281603027015, 0.0473021908152488, 0.046010252478862965, 0.03911106764609295, 0.04474086011008871, 0.030231442107188127, 0.04260277383089547, 0.014374166137478767, 0.00884523585198387, 0.06535894447757352, 0.04720105954836454, 0.05757488978786334, 0.029789355748723594, 0.05215108304494812, 0.0838568039058197, 0.06920413895239753, 0.005207753190094786, 0.07730565664748992, 0.020120477701927868, 0.0762529522480984, 0.04224031465128065, 0.016934287381328402, 0.061869777874239994, 0.072183508516079, 0.012933432458779745, 0.024713063725240292, 0.04973998601217905, 0.020722138259800214, 0.05712108228415732, 0.04856595626821922, 0.02926466404460371, 0.017117261736383362, 0.03713686289566179, 0.029888202158373692, 0.0023853768277237375, 0.024819626555507703, 0.05659083835780621, 0.041165290280215205, 0.07080533166205691, 0.08588210289036075, 0.044582065405143846, 0.00035821077319504247, 0.02104320379364635, 0.027932969575387337, 0.0349216851886482, 0.10761977113302677, 0.028446215925918474, 0.03635837583832684, 0.041406500724054156, 0.11307344381367007, 0.041895739794258154, 0.0845951900907582, 0.046859966560957894, 0.07928879781355781, 0.03852081988307257, 0.03290619979041719, 0.048221067315147775, 0.04416276633198704, 0.006412329732425392, 0.05164071526979247, 0.05045239798604481, 0.04681606206201738, 0.05814086022456327, 0.03957176611067788, 0.042220476804481405, 0.04109884747454236, 0.010211591969334311, 0.024612859424744404, 0.06933747655561856, 0.055889151614880374, 0.035428804751004905, 0.09117149567652134, 0.07271420826474506, 0.012420902400457812, 0.028452857908221985, 0.11296853573331911, 0.03049670005097024, 0.03709565885665436, 0.02158110285358083, 0.018215565604247877, 0.04117786178305265, 0.00830792189170156, 0.10211061070402784, 0.06428193210834457, 0.01978566663550033, 0.04745741172002689, 0.06148902451499336, 0.016878659821926587, 0.04592513244959616, 0.0502565284560044, 0.0531872054712186, 0.01841090270318091, 0.03993032973319773, 0.029184847258992737, 0.05328780047655587, 0.012769909076122268, 0.04133799714186499, 0.03398302446810469, 0.029923095548104857, 0.08234234001006811, 0.014880252438747596, 0.05853018610768261, 0.027073530007093668, 0.033690566572570996, 0.03565303102556256, 0.03066383170775108, 0.1583212472858929, 0.08268441359001784, 0.02439760978543951, 0.04063237653744798, 0.022753083312343207, 0.09089905182800948, 0.09207649832411159, 0.06880070172971295, 0.04099777366425242, 0.017655382961815885, 0.019467006617736433, 0.026930832724657752, 0.03692496680624543, 0.08741583389740798, 0.0725152169264132, 0.02822507315525605, 0.0239429097893017, 0.027744197849965388, 0.06335455969336533, 0.011736173013735925, 0.04654721116587039, 0.020201378501951694, 0.03946139965386641, 0.05829655227341479, 0.041620120511300145, 0.0642329867508623, 0.0386337029387153, 0.0435072363864991, 0.016600845697065516, 0.03327235151382704, 0.06897546170699982, 0.04245676513340685, 0.040915480499426206, 0.015710695579107252, 0.019009391657046733, 0.021056966563206048, 0.008026611533076053, 0.03520513772063198, 0.024606493234093633, 0.017120546338358716, 0.05189420610305764, 0.012702855315329808, 0.025748431554905353, 0.005113075735167631, 0.04659742822930698, 0.05456889100793389, 0.0937551731664327, 0.05331839036737239, 0.043650778280871536, 0.0431721993241339, 0.022419574595386946, 0.034739589919486356, 0.017626480379652594, 0.05015412548316583, 0.014311917663191356, 0.07288052595310635, 0.08777830073790205, 0.02421553366847577, 0.01694680717323096, 0.02450299667074315, 0.02364675743475316, 0.05214843238073011, 0.11543165396658644, 0.035040478612626755, 0.04520708589904732, 0.035477937800028635, 0.034466644283384085, 0.05296558772604312, 0.0208936634308268, 0.012966223894768666, 0.04225939790147447, 0.031012819231217428, 0.04669833350025358, 0.021638752885102745, 0.0511468451980862, 0.041589304624545964, 0.027646588672313, 0.02878339228881223, 0.03304253662786177, 0.05313621848941811, 0.033699031844134295, 0.025543031891086893, 0.040638570358315786, 0.003387690836285812, 0.06947340353602363, 0.004115336229123416, 0.0371891790400109, 0.06074509185348308, 0.05913117825384102, 0.020141661948254033, 0.017284787928445206, 0.08349631357217029, 0.015064171954779135, 0.04647906381456603, 0.06566106657227201, 0.04063486632320189, 0.044963711256822275, 0.08025084336798999, 0.05971239000979451, 0.09068229491071356, 0.053357257838210756, 0.130329865421499, 0.0667299967138998, 0.030607097151298678, 0.0522195713053788, 0.0605039656793158, 0.09157956773114782, 0.031508631335811756, 0.15063102687558821, 0.05139528751193036, 0.1234748034227279, 0.030378548225628275, 0.060930381709289175, 0.06407665118815438, 0.04484758764925984, 0.051072101829753774, 0.0499240156533497, 0.014035510267281245, 0.03470182178481933, 0.035526638009375146, 0.022612228471365188, 0.034793150956712426, 0.050151654849610025, 0.06498902360157621, 0.09061459572084489, 0.06914642954906149, 0.08079413760213122, 0.047690313940327016, 0.01090981791006221, 0.006573038220766091, 0.039646122604608536, 0.009663626514074784, 0.05803029841533112, 0.025444813673534704, 0.03389045040333464, 0.01856710228528227, 0.07701984456469936, 0.060208596649669835, 0.04868430536120169, 0.031824525776168996, 0.07553365697423298, 0.05321226420722181, 0.03207199707356913, 0.018974400591105223, 0.0407324620943156, 0.0683919018915584, 0.01704028522175166, 0.05723759276612152, 0.01262289584584294, 0.022760981678842537, 0.0829230499784312, 0.020537313802408117, 0.035486954654897415, 0.03537870643119659, 0.07530028360985941, 0.0166286010625622, 0.06184098062916629, 0.039998588167251124, 0.06413716064285367, 0.04814821618398832, 0.06734622251843253, 0.05784170289013175, 0.03772339130180978, 0.027634300622007543, 0.013902254060902184, 0.04080112655496886, 0.0409930469017596, 0.07224709381379428, 0.03529785734210764, 0.048332487142855124, 0.024533159467541886, 0.027155413314880385, 0.014666440171910631, 0.05151854722850746, 0.06552888576181666, 0.022707910937888008, 0.016100075088381287, 0.07252598046174935, 0.05715748678231913, 0.029556288819519744, 0.06206392370645077, 0.021691183942640503, 0.048556449117078904, 0.03963917801757494, 0.017746476561672265, 0.026430548581805442, 0.03125750005335337, 0.027993331558161208, 0.08118792977784911, 0.07775622359927624, 0.048197525433234634, 0.008927547211398282, 0.02087732852106133, 0.05808159566274094, 0.0677904462622058, 0.04200145226692961, 0.052678699289718946, 0.01891061419530982, 0.0188100096138735, 0.029500741699349978, 0.03349304612305376, 0.06392023901665403, 0.011043382466830795, 0.04802153205438968, 0.08301848155115882, 0.05374916926807454, 0.035849965417817715, 0.015000798288852939, 0.07997233976399706, 0.04704004318843927, 0.01802555281638859, 0.0356749985967913, 0.029156929099812146, 0.06283463497135429, 0.024152701052146095, 0.05198931974929668, 0.027179121820917054, 0.049456181079750104, 0.03420391059931248, 0.008927239818618664, 0.03744340531768338, 0.05369330996707563, 0.04266662725938424, 0.06744710863718102, 0.010034030025464394, 0.08424960782811527, 0.022372494662000288, 0.06903464199915048, 0.0070403552062118496, 0.06416078679443848, 0.010639433880456755, 0.05660133376236885, 0.03643164448740502, 0.07949758741644122, 0.04674136848940004, 0.06297642635481973, 0.037757758006093003, 0.063159134494321, 0.0630694868854217, 0.05387316059861934, 0.09023605635569942, 0.054421350134596716, 0.03892678519590728, 0.13937236891398508, 0.165519118309021, 0.16630451164899335, 0.20006070514359783, 0.2039357770474688, 0.19599136866388783, 0.05992786756025688, 0.1521590198840826, 0.10747262096453099, 0.14309042343689551, 0.1032976409600627, 0.06292604458247943, 0.12745423182364435, 0.16888780609494256, 0.2038924471144715, 0.1032348370720302, 0.17387833266008287, 0.15924366311200205, 0.14285946324948343, 0.11707218529115762, 0.20079490848846976, 0.11511765750906161, 0.19352887096183916, 0.09880123344520408, 0.20301984232519904, 0.10608283787845604, 0.24940214540448882, 0.23473583642513524, 0.1311742934969164, 0.17431434394130785, 0.13479911511944187, 0.21263822943212526, 0.17472881283010208, 0.15827486832295695, 0.23019278181656716, 0.10310365217587641, 0.09463714721101908, 0.1419884519230935, 0.19858293685941927, 0.21549785179236244, 0.15577340738907938, 0.2483980492838929, 0.17889135156668004, 0.27430774043163947, 0.19292586783487953, 0.13120853762713172, 0.13201838449364708, 0.13954138323183984, 0.20203880545112396, 0.11154984048898182, 0.09795087584925276, 0.12432490054878498, 0.2005182434954951, 0.1336603713852744, 0.21089090545090938, 0.18688584677875045, 0.16697414910360692, 0.2527552816055475, 0.20505411219933342, 0.10218937986440237, 0.12370772479522614, 0.06826837787464743, 0.12719236764936678, 0.18064861936915308, 0.13383405883946728, 0.17057477766948362, 0.10220034258259882, 0.18354887503289408, 0.12686140234431914, 0.15806883663660096, 0.13913783875684585, 0.25814778982631625, 0.10793072622149222, 0.2145775656906828, 0.1474247650513726, 0.1928839475036629, 0.10040854719737846, 0.08686975876410162, 0.1858857956023947, 0.11709293095214714, 0.11330296375578451, 0.10168508716648626, 0.09557311513250875, 0.10601136187512068, 0.16495702427721795, 0.19844064368836342, 0.18143324662120114, 0.11056853548413324, 0.10509647669330721, 0.18971882460098113, 0.12446777594666328, 0.265831008192993, 0.15344206393966753, 0.15022510752802895, 0.1882847233284866, 0.1734515757209832, 0.0722526096468491, 0.16301082387085886, 0.11708606680434559, 0.20384585364691674, 0.1453063174361183, 0.09747141972184183, 0.20258194646768032, 0.12918796540508348, 0.13721984570785878, 0.12653293448590464, 0.13009893587760388, 0.15792910219921222, 0.11226718223864034, 0.20141456636690325, 0.20430342264233098, 0.14050524441465256, 0.13131932926274117, 0.15153663473263865, 0.16682833192809937, 0.15893606348864495, 0.13424249095541818, 0.14146571948883996, 0.1416535029608396, 0.22416334809555163, 0.1454624001898112, 0.14615950955738946, 0.26974911891645004, 0.10418634125662428, 0.11357205980006727, 0.14141194011655547, 0.16651639624709086, 0.19609221647824013, 0.13685333392312451, 0.13901178664978475, 0.08902906184835781, 0.17409233166085136, 0.11595497628854168, 0.10739902289764536, 0.18964623010927634, 0.06411112131430738, 0.12190613114545423, 0.1694217080911321, 0.15924626781094461, 0.1458279160602439, 0.11974315850004075, 0.18814658235398032, 0.07275715515378021, 0.12611573832409997, 0.13145249066573958, 0.12737386153950808, 0.19894707377158827, 0.18001066731108775, 0.1280501333155459, 0.1434431916042682, 0.18034959993054792, 0.17420983422667752, 0.11241299941414788, 0.1369693196348606, 0.1910127164615739, 0.19085929969385748, 0.22217072276098115, 0.12934692864937167, 0.16731790807699004, 0.09986667022589715, 0.11530241493376032, 0.15841703891994494, 0.19269438670767894, 0.13289031512554617, 0.15621387730202368, 0.13725626552777906, 0.1513250259261939, 0.09377695304611999, 0.1077535760498816, 0.15524163511731934, 0.18311352258728397, 0.15965984803774666, 0.10773204897920932, 0.20307910688702138, 0.15126448965841724, 0.12864041172208326], [0.07960041173763814, 0.05221223601350381, 0.015005443654503795, 0.06111930665229598, 0.04749358256137179, 0.055944516789168126, 0.013282212180896633, 0.019312963573141925, 0.06075122821775656, 0.0274368682726016, 0.03542249984738808, 0.025888447529606284, 0.05954085909310849, 0.05473915787954485, 0.0860881805419922, 0.06110011231935313, 0.007586946012452246, 0.03238419897013134, 0.04086375424277879, 0.05139382045355536, 0.025008641513845613, 0.14231523438807459, 0.01769658700082331, 0.030328072607517246, 0.08900140607429129, 0.06516608184263592, 0.05349285157036878, 0.04250480267669886, 0.009577156254841436, 0.027924123175081708, 0.028528074335847652, 0.03598783826155048, 0.015598484765618079, 0.03824115182543474, 0.025621977251683994, 0.0725944840439385, 0.023814067206976396, 0.03132214446762397, 0.025990245292984673, 0.05765126875391411, 0.04300528025675205, 0.08821328546130851, 0.04070022511446188, 0.0714820784126078, 0.01948814298356733, 0.05409048825141884, 0.020412098646404284, 0.01828755105605289, 0.050596027980528535, 0.030018825895122947, 0.0049338365375484914, 0.08866671758193163, 0.006967442309213503, 0.04381348386466984, 0.03538719468539761, 0.035583313194013415, 0.0034173192867573594, 0.04657366035145618, 0.03211478882979962, 0.049206555160062934, 0.04458206923558347, 0.0500053933431064, 0.08690276949275887, 0.01885046480193494, 0.0041210517238435005, 0.0758509629315907, 0.04295229761590881, 0.03445976098338443, 0.05704158534025473, 0.02905402816982279, 0.05805113600687154, 0.07217791607423175, 0.05616459852805542, 0.04617075939031859, 0.05656273059186436, 0.03584660995270937, 0.04211876331077468, 0.03629926449408935, 0.0035174263898478525, 0.018520062571511637, 0.057308884908355055, 0.04304526238552025, 0.037563573869486014, 0.07877819255114564, 0.0809635656074651, 0.024894492497908014, 0.10133608815170105, 0.05277384740991458, 0.031005635241707487, 0.024147154575574304, 0.016468097981546196, 0.06379158604108999, 0.016578504657973687, 0.043536746093342384, 0.025176273042997046, 0.015640184846556476, 0.040721928385356744, 0.04384097876027227, 0.05034446385839293, 0.02709607214426562, 0.026061830463849252, 0.05034847049823692, 0.018609564623705322, 0.034216796198198875, 0.03121317229083469, 0.03355380455632845, 0.019157702448747812, 0.04439810471188638, 0.057052655310760585, 0.020617264653405836, 0.027897334995589433, 0.011095928437557193, 0.04343509005622999, 0.02966579725785602, 0.043284090295914686, 0.05178603065770961, 0.08621207994198607, 0.05309916281652066, 0.02072021729433008, 0.01734256819491425, 0.012581894820135449, 0.03019665405454655, 0.05686222883542219, 0.04333449505089272, 0.04055499016577679, 0.039995133110712615, 0.04051404659666362, 0.015449661652617639, 0.016405872489896514, 0.013773424885115557, 0.04946553884374519, 0.07573107783232005, 0.04228181746457854, 0.014661577428811261, 0.02819848990428352, 0.0372459308334416, 0.015761538919421936, 0.028527926863922227, 0.09045619938162067, 0.04846976626844657, 0.03536990791138622, 0.06244718217320981, 0.08952826006157745, 0.07540099352838532, 0.02494495853991999, 0.04937600231759491, 0.017987874697052667, 0.04312165284288987, 0.13060323623639922, 0.08859444484715501, 0.0753757202877633, 0.017550392527013056, 0.03743241578640957, 0.032665261307791356, 0.04738128939343076, 0.0170130527112633, 0.011792653803563407, 0.051941374136555585, 0.0477158859552395, 0.04254423705260119, 0.017333369394163453, 0.043075090018852104, 0.0196613286501698, 0.07832585593625423, 0.05414197702080973, 0.035129957682182716, 0.04238611650502971, 0.03817375140985654, 0.009576962817640556, 0.04040502845459888, 0.08992147001047289, 0.11883939691488782, 0.09624512745968758, 0.018317773224665754, 0.0316286945505248, 0.05269863672794835, 0.05355621853302564, 0.008471425164551025, 0.03541711041884076, 0.060535685549820625, 0.06031383031738862, 0.04283975929983201, 0.032708058809681285, 0.08075933422773116, 0.027152410250217206, 0.03462653066362104, 0.08067469683385665, 0.06372953674966289, 0.010665239552186142, 0.09661111830463333, 0.007941377548230513, 0.04860866183955823, 0.051676518388933716, 0.055404256263207045, 0.023323602396093553, 0.04035703687658233, 0.03368729920757394, 0.011787451108947638, 0.010118745943351139, 0.03794381011938376, 0.05270935812844865, 0.0674106275302268, 0.08392956693686786, 0.041230154944764036, 0.0012705486827349712, 0.11647652128651259, 0.062348395135373845, 0.06239477026787016, 0.02927818358124745, 0.04905286260069378, 0.025690835149538134, 0.06497963136362453, 0.03265364358441965, 0.07911720944027748, 0.06654335471290736, 0.053690532898350116, 0.04066646745007846, 0.009517384159769262, 0.05048858031870858, 0.0068176654167473325, 0.03252907768793164, 0.021680050769880898, 0.019112426652422836, 0.034547405272361734, 0.029464568942785267, 0.04371312251614948, 0.06531815795648484, 0.014470769824730534, 0.024996792048876806, 0.05152974360352082, 0.03711946503890138, 0.08687595641540904, 0.0642332012554811, 0.029145535457158284, 0.02749207256842525, 0.040991380660524296, 0.07022500473765597, 0.037018992607631994, 0.0627743246995153, 0.05361862405533752, 0.024463290333627694, 0.0481059204696888, 0.04017705217965188, 0.059739620605063055, 0.07102649358491744, 0.05276881421225206, 0.04622360413533546, 0.03932914223461863, 0.07814264600916256, 0.06913411085523906, 0.029424136737361554, 0.03201034040220323, 0.004174020479343111, 0.04380190827613396, 0.06764997638040973, 0.0330366913769995, 0.06734796919889989, 0.07393568949473482, 0.03681635086034094, 0.014205270563252272, 0.05177609832777132, 0.040738483545400446, 0.022094992717968363, 0.015675936254762834, 0.02648975760225327, 0.03311517325440242, 0.01973237947470719, 0.04514420540222237, 0.01745471963658929, 0.06262841176301723, 0.005058811812271034, 0.03362333469633614, 0.05503880551024791, 0.039842689274660045, 0.0689884162537994, 0.030950461589400808, 0.06603494812283786, 0.0480922649524385, 0.11675361528872483, 0.02782672275638869, 0.05867192769543298, 0.05486599139628872, 0.03351284566545679, 0.02707837359799493, 0.022181443825003602, 0.13949578567858667, 0.013979605001006878, 0.04697432433585486, 0.07084670807084731, 0.05614375327563575, 0.012041226352354693, 0.03328389262840633, 0.024856808632912657, 0.06259881778650227, 0.02252707205292198, 0.013863329133469493, 0.0717543843652933, 0.021733508385237188, 0.03548467554332268, 0.11167223069576487, 0.02173939194049566, 0.03867836969514047, 0.025376151128101255, 0.020691521555906343, 0.015154051305275532, 0.01905914715250894, 0.05614635031369906, 0.02068468422118214, 0.047972218974703745, 0.040831302758306265, 0.062075529938503626, 0.021999645414912415, 0.026562229519890204, 0.0030839302710392665, 0.017943876352341428, 0.030785120663142977, 0.08346324155647909, 0.07449867984940929, 0.13011087152746417, 0.052279521515893365, 0.04883859546915178, 0.050196432688784216, 0.023048586407375914, 0.019841684899743528, 0.02556119775099139, 0.039198290586711905, 0.06251877308973382, 0.05707339714131048, 0.03775721025322715, 0.050315540208811724, 0.04910311413808696, 0.03315425906029921, 0.03979569361094506, 0.07112197878379976, 0.10793643357652812, 0.06042840259690439, 0.007248416546762231, 0.07552657832181262, 0.029263503421398423, 0.07356410620794182, 0.03136511625451667, 0.014873876671997771, 0.07105753546760929, 0.004585923931200899, 0.015145725844758413, 0.045625772101864706, 0.04526772941913336, 0.07595682096096777, 0.08225306012337247, 0.03247928963373265, 0.032179998233914375, 0.06582148538361635, 0.09859417520102956, 0.1339191099208209, 0.2326842836074291, 0.1290304730496099, 0.1392014700198366, 0.21888120250115473, 0.12335793670987892, 0.11711815822749369, 0.10998289190953779, 0.10647564946163086, 0.11839646019882734, 0.16727226455846142, 0.186405586259019, 0.19363927955348648, 0.11945057419999955, 0.16460499155425257, 0.10046563606949584, 0.16669950658275237, 0.16512279038227376, 0.1032815301310151, 0.3060647508790416, 0.16730981818850965, 0.13663590284845523, 0.07386376916040337, 0.1608410943299532, 0.1908285182810599, 0.20726838209215673, 0.15969697265855728, 0.12162254071764408, 0.19201229266341657, 0.21461757080208874, 0.15598667094544058, 0.12091661367805735, 0.19415343180298808, 0.15335482184685048, 0.11777090344337687, 0.13133135684315236, 0.20890514426414045, 0.18946069893577408, 0.1539722274267866, 0.12673980886897734, 0.1535495154319271, 0.16292987902077938, 0.1427652804000724, 0.10688489363078149, 0.10542610900536661, 0.09381773956720868, 0.14584565865657023, 0.13819691424648609, 0.18449338483473948, 0.2079355680654126, 0.11926752515137197, 0.049905250329644456, 0.12433676725073207, 0.13292973801012964, 0.16766781107552592, 0.14202618941424355, 0.10221859079695518, 0.10297465829118606, 0.13418515693516503, 0.14990499002798913, 0.3148617691570713, 0.18048548860655678, 0.15710442387048276, 0.09367063536398834, 0.16426653390930546, 0.20692275386423836, 0.15863477642978394, 0.1495285191002392, 0.1014830697808535, 0.1615120800993135, 0.15481892312245984, 0.13270994738465355, 0.1678522390824172, 0.13855181213828827, 0.08777561943016707, 0.12910951800163717, 0.11607481542253688, 0.13394961554196574, 0.11245770064452965, 0.22672300106815754, 0.16325211092349023, 0.1459318282262933, 0.15518102224075025, 0.14081405445693002, 0.12246803365527623, 0.26258828058358163, 0.14047728220541633, 0.14142657239590922, 0.13710788961860443, 0.11084647984394144, 0.13452130099458082, 0.10342772268960554, 0.10152680574045067, 0.0927734008479503, 0.1339027003174828, 0.0760260676484435, 0.11423579071678462, 0.13492938071008653, 0.22084117716839238, 0.17003655493740114, 0.12341451996396627, 0.2527088719990946, 0.16772166705660282, 0.12174149118964711, 0.12190672103315593, 0.08674692422632249, 0.18435639299211964, 0.0684778952610589, 0.22950455906891057, 0.06424800207417819, 0.14369400879067762, 0.11057086439142305, 0.11154483027395704, 0.15269419358622643, 0.16015754471863472, 0.17364839903048931, 0.16214966443517517, 0.06320019680706244, 0.09454064311519747, 0.08446274114952934, 0.09770143762110703, 0.23782963654206646, 0.15657730941330233, 0.10819264402192448, 0.1840272356545733, 0.1406983445368467, 0.13201970216487685, 0.150149479328144, 0.08316850454937066, 0.20002393292323237, 0.20207640504644764, 0.10604181387011083, 0.17792347608314407, 0.1879572820278906, 0.17010568671168821, 0.07959569263602458, 0.13585513667954555, 0.2794616735510288, 0.1476491062391189, 0.13159905860741294, 0.21201035909114346, 0.23766785409421692, 0.21705710118816746, 0.1361175064718531, 0.1164892306851764, 0.06840814295555316, 0.12721325886706192, 0.20815145164247484, 0.19251674623979678, 0.18278906902959272, 0.1453805207124641, 0.09338131459850459, 0.1489141931937587, 0.16972590628410542, 0.1441441926985018, 0.15290151230029522, 0.19893106253397083, 0.25495799889247267, 0.11358541271258747, 0.1145933928989595, 0.10867761598239023, 0.10655040432128215, 0.15588746255924626, 0.07829856022351211, 0.21809770905923462, 0.21243255014621445, 0.15557212544785393, 0.11081749107688667, 0.09835243615652285, 0.15629145136523634, 0.22770501853477573, 0.18388261357622762, 0.13628017758169483, 0.11503319631540969, 0.1213930284364089], [0.038184128070790926, 0.022281793682205103, 0.0410484197369266, 0.03848672130956285, 0.025148013974690152, 0.010842727760093348, 0.017354387016366088, 0.01404726971691895, 0.0776839125601034, 0.017873834848644275, 0.016703022673966426, 0.06740128891842981, 0.06734874294770342, 0.010057273133087062, 0.05625879286878532, 0.022899183940382737, 0.04054102438291715, 0.09897820741659212, 0.022903847500621792, 0.01588754889164721, 0.050062800141712355, 0.030680310259002353, 0.03957573827656527, 0.07763214033818053, 0.044006472904114954, 0.0924750172623223, 0.043977449663103595, 0.04055220926661165, 0.07449759200455681, 0.020368567615326856, 0.04988538183932824, 0.0426295179603321, 0.017095259691198027, 0.08649861214742546, 0.041285328597070715, 0.066945658125464, 0.04742261983694569, 0.013937970037542045, 0.010512310207911558, 0.04401088940099843, 0.062472926557905255, 0.025038001833543665, 0.03198689619650043, 0.07664823063438939, 0.024104874183033264, 0.009005370253186313, 0.03831187706260431, 0.031792876768797156, 0.06640907482153947, 0.03763943189574826, 0.07296003821876741, 0.039766444373996034, 0.03407313556019818, 0.028172349069087256, 0.06558442713632699, 0.013028065384846303, 0.04729161880189373, 0.032263084299742215, 0.022591955869668917, 0.07597432607003758, 0.010220420175051738, 0.03721155263783951, 0.06437992241473929, 0.03227229267659207, 0.024352705541757808, 0.006981075801435979, 0.026622137595568935, 0.07145354163742836, 0.042427699757559646, 0.05158011388454226, 0.07242280374010725, 0.07535168044869939, 0.008846902093219181, 0.06515940921681543, 0.0626027095131576, 0.013430767163123577, 0.011452511722792783, 0.046130896005178654, 0.03163018267631772, 0.025991133954976837, 0.053643211647267305, 0.01492991121560936, 0.04287892937540047, 0.04652715115357311, 0.013205210768407392, 0.037976897456833435, 0.014600310504676835, 0.05311362655653108, 0.023389313587798707, 0.04469268850140995, 0.0391517584061911, 0.06419911800372986, 0.006112897563951031, 0.05840301551225205, 0.08675531288909336, 0.022776529433265812, 0.013300605951958607, 0.06214533203972444, 0.014455295806269974, 0.028468761893530047, 0.042585705391942494, 0.055775433523400184, 0.05094798026426185, 0.05497564922177023, 0.024167316094521555, 0.09491034948657598, 0.09683968063684241, 0.04022141633134696, 0.03576838088432147, 0.028404577132014018, 0.01992999760043477, 0.03591129458659599, 0.04957847935598224, 0.044374555169094, 0.04947984553573113, 0.06280240182194018, 0.04456529191004173, 0.03535036117799821, 0.0019195029604053427, 0.01384372398587725, 0.01679620577863628, 0.08096870605743701, 0.04300027387216688, 0.03889775429401667, 0.011077421668526388, 0.0651255787740792, 0.0669214420861775, 0.0254395870386713, 0.013792051355384532, 0.036645314070366086, 0.0872384385776616, 0.0351100355657118, 0.038449738415018204, 0.04242932769439874, 0.07707632056647733, 0.02964957726127919, 0.03569277183663461, 0.002767989865406567, 0.010836980185441433, 0.06978084994179588, 0.011177057148738494, 0.041142506825347105, 0.028092038156765125, 0.02312447507715514, 0.02472251341978629, 0.07545103439159932, 0.025454232724563732, 0.05513593396772781, 0.05563386430543277, 0.023266877415740204, 0.025057134879452568, 0.04535000343176146, 0.09067464935322923, 0.012467296685152238, 0.04303577821701766, 0.019365992179260622, 0.013173236173667736, 0.006813718148717477, 0.07993565947418252, 0.012699577416623793, 0.07017811249581075, 0.006598679183591759, 0.04925563075249234, 0.04317165540170766, 0.07190353402327146, 0.027166607774673935, 0.07863979876762436, 0.037237297022534956, 0.029710990699729132, 0.033075570339156736, 0.02504394284539646, 0.03687261618793972, 0.05311382573939139, 0.056192288776078535, 0.11543283374198984, 0.017039440609815142, 0.02744564189455442, 0.03106602978321814, 0.03539189080437345, 0.02692707697860897, 0.026564146654920715, 0.014314279129217952, 0.03586163293690451, 0.021468560707064408, 0.0602392478275203, 0.05295092863361201, 0.013710082820316237, 0.015079738861400516, 0.058609935860600204, 0.04539546691962788, 0.1050010297988211, 0.03607447514490735, 0.04822859795944345, 0.06123829542869522, 0.0030847638704618744, 0.005286549163546654, 0.02996462708969991, 0.02648653045687224, 0.05920833096869531, 0.016919273973232316, 0.03465337055404821, 0.039236916739854126, 0.030941561562940482, 0.08731277974983377, 0.06353263300092471, 0.017736044359363375, 0.0690087099229136, 0.06278287041031065, 0.030699592692056493, 0.029520338228453073, 0.04673419790642877, 0.0625608811124919, 0.023651756158459093, 0.057410115766669476, 0.034897568740791855, 0.0160830928343198, 0.03742634070917003, 0.01434906430902981, 0.08734896208249754, 0.04874471139403121, 0.13010183168995765, 0.038128713100788095, 0.013659807342675426, 0.030564858893593474, 0.10302325124822317, 0.07955225545071787, 0.06997469316927657, 0.033495191169241746, 0.005300122326345093, 0.036718793393623446, 0.030972950100418062, 0.0681339294439362, 0.04926369382789539, 0.03370143736021654, 0.014544586226674578, 0.036978470386877176, 0.05897974948428812, 0.04308293092875712, 0.04588437274158482, 0.05685868184833277, 0.06983383258263912, 0.05872114118368876, 0.015993716229023715, 0.02484513153772681, 0.0628898162845402, 0.04693306284025312, 0.02792311576946128, 0.0830766429463702, 0.018894189270213246, 0.08444787138291905, 0.05720966503084187, 0.05225941553832062, 0.04164625560083697, 0.03206416190932355, 0.07315135335609799, 0.04292139745948296, 0.08694917909921178, 0.014463158741202808, 0.03475563180062079, 0.06593750173886938, 0.02518739855487741, 0.016608998787799673, 0.089601666606482, 0.03728866321785796, 0.025523755203692183, 0.02396116374931749, 0.08195062393262502, 0.034857061841795524, 0.03688340653635321, 0.06073651166873113, 0.06756746105008549, 0.11013483778843958, 0.027296166649208437, 0.04585318530218736, 0.06683268313927036, 0.04026823579483936, 0.13194605047183652, 0.012876954541781978, 0.05820918760652985, 0.04753350723354567, 0.04674906001215981, 0.0766320508574286, 0.03526379707299414, 0.0738389325898982, 0.04804318936000909, 0.07589896600092612, 0.0051912545290355005, 0.050434927350931594, 0.05092006018986145, 0.014339675901517754, 0.051781008951365955, 0.040263359645201315, 0.024181739614915945, 0.01829771321236847, 0.04241071941871797, 0.026318944892996264, 0.059719434188258265, 0.03796732135777993, 0.056205649349477985, 0.041039199868757884, 0.028216818557871927, 0.010008690709758912, 0.04226341986307695, 0.03979954703320419, 0.026098141116240335, 0.019527747814032822, 0.026154249395814635, 0.03989541910648827, 0.03219213306663498, 0.022375409626552177, 0.03536651031144204, 0.06313384210150089, 0.05882217668958249, 0.046832126925789544, 0.023946318880564744, 0.023978034920629956, 0.037692418367031126, 0.01107625338444186, 0.010336200958268057, 0.015492919764872042, 0.06479185555250415, 0.05626759138859569, 0.01974215667184082, 0.0074390101250291114, 0.0275135938934381, 0.013444705175295954, 0.05660648187322002, 0.049249743366794246, 0.033570283107579715, 0.03289901388568744, 0.016223091572042436, 0.02120603003629273, 0.033341165361625534, 0.022568076909069094, 0.04306903792425029, 0.045225870374950676, 0.051484835529399496, 0.028732585337673946, 0.04170521755792922, 0.03764893138600934, 0.03085224720228824, 0.043577524953551834, 0.048326925344524846, 0.018859188628172683, 0.04385547697423928, 0.010089407648680913, 0.012048483120217439, 0.10334926762527998, 0.07881809041024217, 0.04281471588558728, 0.02417918088124885, 0.03238268594648088, 0.22591669352785235, 0.1233081256730422, 0.08465664566404398, 0.11447605121159747, 0.13663936556587297, 0.11029269020523756, 0.13523091291708333, 0.20958339254702293, 0.12185255095603005, 0.13675170469908945, 0.15832094085072318, 0.13973918713388905, 0.11809973902399502, 0.10509816974761987, 0.2256445024883555, 0.1961148007502479, 0.14364879428138658, 0.2694967082671581, 0.07791461993850048, 0.08194773578115049, 0.20303053691262202, 0.09315953980530463, 0.13075927302481669, 0.14126259893659623, 0.13005638735428934, 0.24213192503779168, 0.14067467241998644, 0.17423293943847382, 0.20591010820240746, 0.13580334913586417, 0.19147376349616438, 0.13110706162068153, 0.07307487479861706, 0.16541623270079014, 0.122251866625682, 0.15549608356048986, 0.19320201188806566, 0.14027889607654465, 0.1987197295191788, 0.15719875993747867, 0.2111664519555146, 0.12382647608436885, 0.11759160056469903, 0.14378443780925967, 0.2252626076581017, 0.14953283983613216, 0.12557918566369242, 0.13706174048204578, 0.19714420841586208, 0.11934993322938682, 0.2033963745399829, 0.13752196014167803, 0.1451978087425232, 0.08438728148898772, 0.1527306746931807, 0.11144113261252643, 0.24192115892806362, 0.12558038842173355, 0.10048203801195468, 0.2744969028619028, 0.14626532162149108, 0.10679168371303428, 0.15479839196608913, 0.19051649066950047, 0.1379538039045949, 0.196795592445039, 0.11613483075052501, 0.2410575939762977, 0.16580545133160007, 0.20305266153187523, 0.16155980737699618, 0.23802436077066008, 0.14785578143933129, 0.19306269113815602, 0.1637392355910232, 0.12225418021121334, 0.15976035877341227, 0.14216963171718583, 0.14807528095139613, 0.10285576144533773, 0.2103336224512708, 0.15091086347256938, 0.06274999757747977, 0.3074845569508691, 0.12721967868386738, 0.16578291302486775, 0.2291262035648669, 0.18861205737677314, 0.10392843775691525, 0.11041029236249386, 0.08834549691528083, 0.19403602116771285, 0.13663361990644088, 0.1803785733758442, 0.14409919269382954, 0.09611666983654422, 0.11363101026584065, 0.19113190442083344, 0.11703344422482675, 0.12684572052450913, 0.2792405499325645, 0.14488423363335673, 0.21804302570319947, 0.12529865192670014, 0.20661855567126505, 0.14808562313837392, 0.1759994156177967, 0.17711505414016787, 0.11570805848966684, 0.16909558446176592, 0.2360658110269616, 0.20458237057731998, 0.1285207411274314, 0.1763139253542308, 0.13594331339963023, 0.15093016888826125, 0.11240431197708654, 0.10822979162537283, 0.08454269774618649, 0.10982169934938993, 0.10849103526843172, 0.21947043136723582, 0.19268755320339434, 0.11555839555277941, 0.15351818243582405, 0.12053107993016321, 0.1760605187906373, 0.12752911691824276, 0.08219207952459974, 0.13977252728035375, 0.1546520078855176, 0.1870589979713963, 0.14835439742572848, 0.12253286001542885, 0.32313110607285656, 0.14269524464203467, 0.12488053645938636, 0.2940610111240418, 0.1933094020932913, 0.14952983677146897, 0.17471935930511645, 0.14284977989812053, 0.16221370938564503, 0.18974588282646673, 0.1851942939984222, 0.13065516167590696, 0.11583280058637743, 0.11324923800965471, 0.18257615787367668, 0.10322969662205828, 0.1365432981401682, 0.2245609477282532, 0.19124787481081104, 0.1894176754379465, 0.13392716916578432, 0.11527062228490269, 0.11051063455881611, 0.13388059101998806, 0.19129980025031876, 0.12480088629789891, 0.18017272555059005, 0.12757089935363303, 0.11684584461392895, 0.15350241634634235, 0.18089788905795545, 0.11271905920077717, 0.18224004445777786, 0.13760262920010474, 0.12242528594910138, 0.13442445215919327, 0.11514144453911052, 0.1970115066656182, 0.11202630121260883, 0.1325154989477127, 0.12882485505073302, 0.20312367788245603], [0.004936408677754263, 0.04743665839815813, 0.08728092581394219, 0.03288650750032356, 0.015450382732876368, 0.0668288067343735, 0.03471491039700566, 0.025382567114467104, 0.02165435809612034, 0.07623923927425377, 0.05025025802634416, 0.02695027220573637, 0.010736449339967823, 0.05560235893954674, 0.038782802800978386, 0.10207198455088562, 0.011767344173764991, 0.04481736165020735, 0.024786916516360738, 0.027109474852500905, 0.04379358856127628, 0.09444661348337129, 0.05468421022317583, 0.01792973819969883, 0.040243468172247374, 0.04374254795332109, 0.018342611710390738, 0.03483965632415587, 0.02998511036557536, 0.019339803463569092, 0.0206514417509278, 0.051362215496239164, 0.04622392206182403, 0.08724236094783391, 0.04585394755967202, 0.04040511272427055, 0.05488234737347211, 0.05342990212563065, 0.014200408777762807, 0.063092197561937, 0.10251325885615042, 0.05273976798860296, 0.030432557424290047, 0.005999204370328376, 0.05605384902728181, 0.03906574971493214, 0.0471605871233248, 0.01543414837215096, 0.006815997260292211, 0.013313224377681412, 0.07420391985966314, 0.04007181851193309, 0.014157106615452757, 0.09117455236733922, 0.015276454918597256, 0.04868922747611519, 0.05624957683105623, 0.04395735900728934, 0.022046384439172766, 0.0732941061799084, 0.06293263676906787, 0.04621451833255349, 0.0290339490053274, 0.050660153370230436, 0.01184691868406991, 0.017779311090106928, 0.005735442692023372, 0.06953839077464036, 0.01506102812145987, 0.04778227130431802, 0.06700094669095932, 0.020293125191763527, 0.013998518754247458, 0.026427581906318668, 0.09733118732730228, 0.09613071988907554, 0.0024877175559184605, 0.027491461613305637, 0.11996454258839931, 0.003921623954797284, 0.06588615086530486, 0.050013176796417085, 0.058904385584737026, 0.07572617486960466, 0.0529989623464644, 0.03164857070172026, 0.11078970506787301, 0.019362437531291958, 0.018534982133837, 0.0525505097973491, 0.06317426090038593, 0.047648795805270636, 0.08249238599091768, 0.037401178551297036, 0.027798883121220336, 0.07871336619099302, 0.04008391120981786, 0.01718687997650235, 0.07745354992127226, 0.026273701655408068, 0.03175999052942761, 0.03040401298823136, 0.053334428418067195, 0.016042582104883848, 0.04606613093205998, 0.05683888230592974, 0.005033404985067225, 0.020772759434616855, 0.06124646575640767, 0.047376903540064255, 0.000653453368408185, 0.036888125637966784, 0.019853942306532014, 0.01737176572092839, 0.018762720921527476, 0.025166047684427713, 0.0961469303095533, 0.017667667181681723, 0.020976441146265117, 0.08013183926983226, 0.043082850489525065, 0.08467621154963009, 0.050514577512419036, 0.05045242479912216, 0.03973964278796508, 0.02536308549855265, 0.0706368612666284, 0.026166342093699405, 0.05299621209081623, 0.07322450709198752, 0.041795347802220814, 0.04446501100075342, 0.022893827070572206, 0.12516468613138124, 0.010994398804952302, 0.05747149473116283, 0.02006984695101217, 0.039953833310714656, 0.026430832034337427, 0.06361511385729236, 0.059498103726054394, 0.0898838167889945, 0.018295533692223892, 0.015878830811068896, 0.019113485768978155, 0.04949593338214102, 0.02398361970159796, 0.01230188872620103, 0.08316414550908151, 0.04256415533863249, 0.06115199179358541, 0.03290923349859734, 0.05219926997538536, 0.04972224724629233, 0.04039423810618539, 0.013053309897171154, 0.03416174128952046, 0.02007470777889173, 0.008871815272516782, 0.10415800366430514, 0.027087382791984468, 0.03663194583608739, 0.06291389825843996, 0.03697776558598684, 0.04880650021556405, 0.054789283012430516, 0.10083058503486457, 0.030488347777375774, 0.055393282053691734, 0.06626740218170228, 0.017281735068066947, 0.030585746280848983, 0.046233858222201954, 0.015526594117193695, 0.042696749836566954, 0.15135710968846275, 0.02727384093187509, 0.03156050314916478, 0.05820078362200049, 0.007041469864141677, 0.04346082294960657, 0.021347137686285763, 0.010652125084532366, 0.010650829438330426, 0.05196880008424482, 0.0298538048105735, 0.0407935805889147, 0.022684081773003264, 0.022318094758497133, 0.05053312450106587, 0.06858274205437592, 0.019401375865263325, 0.0480133387440395, 0.012180220557286615, 0.054936188032790545, 0.021916289303091266, 0.02355959386594834, 0.027748258115964073, 0.0315801035087075, 0.007825297990723724, 0.06989222380422777, 0.03310412626653429, 0.02086719700826272, 0.011562386925722803, 0.044724040649711125, 0.02594405210637037, 0.04921684372088602, 0.02435213480625422, 0.006369976082726592, 0.06901300001528955, 0.05281220543228331, 0.0813732541076118, 0.019844440901051127, 0.02104905287494823, 0.02644968545815397, 0.058857501003771066, 0.17839834334388857, 0.08865932483346232, 0.015238832340635841, 0.06551218504506735, 0.004537978318459805, 0.05516042196822744, 0.10407051642335231, 0.07679357283538388, 0.040021348639481494, 0.002754784903616735, 0.0279092304258337, 0.04338648177743439, 0.033112576216339104, 0.012421100625708219, 0.03424361693642793, 0.04575483493446823, 0.04156971192588249, 0.029708401322545066, 0.03456080031971778, 0.08995371465120586, 0.05149480999417363, 0.02700834167039683, 0.04162482429115523, 0.030142081781260432, 0.01222475707876466, 0.022659858072837515, 0.11484185819544139, 0.028326641092257156, 0.05071837222203613, 0.056259210386704055, 0.011150516032601797, 0.042316923443708694, 0.062237806513064334, 0.030076370589555274, 0.09319670273051148, 0.06919689942151308, 0.05096671111401051, 0.1040750056985886, 0.10680571844380711, 0.05639165166705366, 0.11590115095098173, 0.0829755423230029, 0.10380646123761132, 0.044138236196651574, 0.09910589129093195, 0.028935470317880956, 0.0958653163885878, 0.03283522557467222, 0.04738509301997481, 0.05609448999166489, 0.04881215777488486, 0.03442460137809958, 0.05464014484577122, 0.06830294376179095, 0.04839946237963535, 0.10728555761518017, 0.033080392862640084, 0.01671087890562992, 0.1170958574080179, 0.03674338098555323, 0.0732290116889823, 0.006367303393480759, 0.052970460045241544, 0.047863200832639015, 0.013372743663738572, 0.06586123002512802, 0.038322008575402924, 0.026414703968311512, 0.028834260526984453, 0.07994289900506697, 0.04369549100257216, 0.04380033779588919, 0.08812223591150777, 0.03196955579633434, 0.07595678265657156, 0.05856815342520995, 0.012008451195734163, 0.02014417280142586, 0.027246267512260426, 0.06271633184364726, 0.042997784086412964, 0.03655851247810549, 0.0036618579038223556, 0.06029609538194153, 0.07061958598393588, 0.02355164187329431, 0.02354631564700075, 0.053284839546728524, 0.047799588721846385, 0.023509357650313648, 0.025949418552279956, 0.06832074764515124, 0.06884059192793024, 0.07932577687766283, 0.0354879543996386, 0.028176296337117112, 0.03626899252976141, 0.08646389304269707, 0.025469148456449472, 0.06116393510432494, 0.05631239604084723, 0.07542775297958045, 0.02976508991372201, 0.06858772162588374, 0.04013295232829067, 0.013250928022898735, 0.020041735354630698, 0.046639383034480196, 0.09127843388987165, 0.06742512957463342, 0.060436151576258486, 0.09435858231999221, 0.009433803009620358, 0.03064995977066217, 0.05428666804706859, 0.04520276516315438, 0.02438425112725987, 0.02248429370323016, 0.04189311594311749, 0.07181826843729905, 0.026014438349633448, 0.011814209602532849, 0.023339722801240224, 0.04864160745074192, 0.04190321681239913, 0.1205908730926533, 0.0784019667715315, 0.030035095687414852, 0.04359363195215983, 0.08723581855696055, 0.06503965435249191, 0.027995737074243448, 0.03342427824053072, 0.03430130335712626, 0.03736791118318516, 0.06750326288203079, 0.12436846030815957, 0.06380177884092254, 0.16538546660975104, 0.12099457078523214, 0.054789677547711524, 0.23340845120049294, 0.07546075604735844, 0.1541613132482575, 0.11805434065360217, 0.12756968127383342, 0.332625724014736, 0.11303382940710553, 0.058245779796233105, 0.13424838983243512, 0.12378955064641854, 0.1911159851137669, 0.1072220795697743, 0.20531219189926503, 0.17739369563998716, 0.15021861110243107, 0.17461376174563364, 0.1835526135419646, 0.1822659075861016, 0.132367720587119, 0.13778949336659524, 0.21681157000843557, 0.1253516881936981, 0.15332158895269518, 0.1577526874720089, 0.1090230833318445, 0.1641928209292312, 0.15326653787445638, 0.13204953362864832, 0.20313011302102, 0.13439880353548836, 0.20196982689442175, 0.10378484989726737, 0.11084983530904978, 0.10467258492304433, 0.12217266079519065, 0.2882525631256642, 0.2827079864519258, 0.12387472430184004, 0.1529477686891633, 0.1239180465739581, 0.200814351799988, 0.18311491686730616, 0.12625682873711472, 0.08444926566294125, 0.15155689009735662, 0.12251331711248045, 0.12663942836825887, 0.103025832964528, 0.18282441632641902, 0.13182686251257697, 0.09242667711430019, 0.1780664434115733, 0.15988582865365092, 0.12095832716553442, 0.26899700443590846, 0.16168120166947766, 0.11393367628296537, 0.22500328689573273, 0.1220299386148972, 0.09414006340047044, 0.09752156783736522, 0.13842885502644126, 0.17692195401797373, 0.09991556961810398, 0.15600544009958545, 0.14147033133814413, 0.11840402148663999, 0.14512282405649463, 0.07672202022325608, 0.18746788974010176, 0.18256829781157358, 0.15055009734726724, 0.16206260620345994, 0.2754909172654152, 0.28467395192673134, 0.20415587410811456, 0.13646198556788508, 0.16557850544491123, 0.24547035235070416, 0.2377517866872011, 0.13437134694428216, 0.21896165705496268, 0.12378635605977428, 0.11249392894246887, 0.12108810245990755, 0.152496098570766, 0.10505469425791696, 0.21418696810160914, 0.15147635893475625, 0.15373749808678705, 0.21914936391816986, 0.11931739747524263, 0.08132574133454792, 0.2029263183114029, 0.10542938786168253, 0.11910431777998326, 0.23444533588424807, 0.15827885198016323, 0.1489227120914767, 0.13929721568861317, 0.14790258941150483, 0.19236139893051118, 0.1874122870785575, 0.19478261981519962, 0.21852659572276378, 0.09542790316646138, 0.10492259771713328, 0.17384425706921086, 0.1472344075239474, 0.20580918377926274, 0.14457117946397874, 0.17074832722785013, 0.12580889712778792, 0.14008003497315993, 0.20457883125110982, 0.13468289958132854, 0.13887090308050956, 0.11070697523292997, 0.11531312484294177, 0.15874547613484247, 0.1011593440066903, 0.07893374670417079, 0.15139547537171072, 0.1342165665400605, 0.162571472446284, 0.18727180187500295, 0.15385489340030378, 0.17638376192940822, 0.22284860332165995, 0.11318863279396489, 0.08930143674895649, 0.085817429747793, 0.15403294755566507, 0.0916145549666497, 0.17065239769797172, 0.13077785831785974, 0.14938843226240528, 0.09549016313206765, 0.11509516516760473, 0.10668145132160957, 0.13266427322260796, 0.12793008733781117, 0.14070476435365217, 0.16413069119857204, 0.18293402818662508, 0.16072207491003698, 0.1268122884474935, 0.10160091708624557, 0.1095272840992097, 0.14218331404751347, 0.07182354678309734, 0.18479215912520888, 0.11198914594828122, 0.22407184655387558, 0.21512256064001592, 0.09168121227694136, 0.16646479256451133, 0.13423933467317012, 0.12973558037511765, 0.16605655963142074, 0.18781705729423032, 0.20768255986753972, 0.27353779142422063, 0.15270583812267552, 0.23361224591011004, 0.15676907654250824, 0.15513269741448665, 0.13560364533576275, 0.1402706529704794, 0.1864291358018114, 0.2742982409413784], [0.038325831354145086, 0.01024989540793843, 0.010193340882148233, 0.05852321087713203, 0.06342635362318928, 0.058358130420768456, 0.06966136320824586, 0.06267672892840159, 0.02047059520508253, 0.0773021632865552, 0.03158482261032107, 0.029742534370011384, 0.05876707964606824, 0.06260558234287367, 0.04653197367705646, 0.05006813594410497, 0.02361826279440955, 0.04106386023904047, 0.10861534069502547, 0.06851194786929315, 0.041905492093534245, 0.05188422397740426, 0.03980019820793983, 0.022701674982184367, 0.04134118789806962, 0.05516255552309656, 0.007762300186685377, 0.014355910262243162, 0.03663838863553059, 0.00776286086728496, 0.02403512953840677, 0.02351266906536635, 0.03580686914163732, 0.03860182985062561, 0.016061207617542917, 0.015099186960968281, 0.03378153185270006, 0.02151183126824758, 0.001715657258060791, 0.03863972822023976, 0.020198697194216714, 0.019998098986463684, 0.008323146931586728, 0.014552595675922932, 0.10428016404471091, 0.04007374905350228, 0.027730429334746256, 0.04824274760340491, 0.014001942209659085, 0.009827501339567526, 0.05447452812786064, 0.0781908865657545, 0.01896644093757195, 0.030601929888249408, 0.061890699735452095, 0.045314146686465516, 0.027569024185199412, 0.02260808585091464, 0.03530637240938602, 0.024524058343001434, 0.021839881608743342, 0.018374697387879415, 0.02718779585143972, 0.034909305207791834, 0.03620567536281963, 0.03858897489525619, 0.07324176705292157, 0.05804274351366105, 0.03396659571256849, 0.08398002914844022, 0.010790808066245048, 0.12050504060161692, 0.012278258744176599, 0.07001965486955258, 0.11012174534581362, 0.04632110414545863, 0.4670575152962439, 1.1208421592750857, 1.744973133167913, 3.2479806436646372, 1.6852217071479367, 1.7713042492828064, 4.099281814790541, 3.2470412360083674, 1.1006653645346243, 2.27285465886516, 0.854615941643715, 0.1564995361672294, 0.17261909861718455, 0.053056162301330805, 0.08320815726033143, 0.05428438127461461, 0.059773692365495436, 0.06554322692775919, 0.10618553196470584, 0.022002158183304053, 0.08638700845861629, 0.04850727393321934, 0.0489863240340304, 0.0927444427244125, 0.34947922933966885, 0.09019443479877326, 0.013479443432222451, 0.07053548485160836, 0.026655286220052553, 0.02040810541309897, 0.011815472689998007, 0.0849930655151125, 0.06414823061335953, 0.025468801801663735, 0.04411408910527826, 0.07647823572399155, 0.06164933607402829, 0.02238995763623426, 0.0025409350505909856, 0.04720079524803066, 0.026040016110205365, 0.01959813022685628, 0.04148554567608141, 0.05627969557779932, 0.0975301556829964, 0.07258650906864675, 0.03681187690686315, 0.014438535717706528, 0.04880560772313226, 0.04624950556805538, 0.07760571030479285, 0.04384966619733361, 0.09121312489432674, 0.005229648461775674, 0.025839088484644893, 0.04389898310745916, 0.052128016137548035, 0.020108065162334713, 0.04385949510540213, 0.07148577095640284, 0.01944014565989135, 0.05389982811926354, 0.04295904685052172, 0.02265142727523081, 0.018515613515891375, 0.04827931298003082, 0.04358364216562721, 0.02411729629872547, 0.04296948096805042, 0.05310167175447268, 0.0140281108155426, 0.09182759635751286, 0.10248385640161653, 0.04159076019160209, 0.005655609627044009, 0.05150485340686095, 0.04987595895785959, 0.027966960896587664, 0.022135514938723178, 0.030153638217598203, 0.03662313965539779, 0.02573329174230176, 0.11657741506614032, 0.022779511430511074, 0.042803665067279534, 0.05199491602158354, 0.04023400315594289, 0.024966089160091458, 0.026255060820990515, 0.02213820007689778, 0.07409227786645775, 0.04266189283601219, 0.0556848053219578, 0.058927586557523864, 0.03017742716286692, 0.06156082610569655, 0.029531299031429717, 0.03557575190620076, 0.01078805206493745, 0.013192866219117517, 0.03104169116986375, 0.05402551633456061, 0.02163704067859198, 0.04242984480374763, 0.06365283602668394, 0.040871476409055536, 0.04100556094800273, 0.014293970138345276, 0.004189731985060198, 0.027756160312903025, 0.0382759360476367, 0.0643047385458504, 0.08219657646071526, 0.01616090438478897, 0.0522446645153386, 0.0444692857713709, 0.029771913841907537, 0.06504229735583067, 0.04044486119622185, 0.06737180985510349, 0.04091212886475748, 0.04508219441519149, 0.014230480601620531, 0.03481252532031748, 0.025535041594036648, 0.013762459294089388, 0.040665697531714555, 0.04248468903824688, 0.051902916522756706, 0.042757263121705864, 0.052077235999487104, 0.04016155805138331, 0.055583700868150884, 0.03507504066933067, 0.07192273218665393, 0.07156979547993791, 0.05623017182393421, 0.04969793927645491, 0.03921638175304379, 0.05209797016915776, 0.04832160486389072, 0.02237348291542261, 0.04227845050815133, 0.026435026365722862, 0.07313655253740088, 0.08393882893987241, 0.044145736197430285, 0.025446433949494557, 0.04349332422979417, 0.05978862724957928, 0.0811590406022245, 0.02418655639273986, 0.016591610507138314, 0.01910738196344145, 0.13794931462935864, 0.057899596154569626, 0.01973472944941492, 0.03875849866158059, 0.038012953384989695, 0.03752071125012252, 0.024382937286469727, 0.06733133743006377, 0.06283103052767054, 0.031009616983693936, 0.0372227719954906, 0.05993061781590504, 0.05913420813158155, 0.019973679933877244, 0.06552601293210061, 0.035878701375857476, 0.05290806984468814, 0.02699600190915648, 0.0332729528928476, 0.056027101067405556, 0.12075339098491016, 0.1948175687463053, 0.8581897724540004, 1.7512121532232532, 2.9384544011085265, 4.575504622151775, 2.9758654775158053, 3.186338144925333, 6.332607317355372, 4.903185800198586, 1.8645860567208261, 3.7252568525652734, 2.0205745509555264, 0.19187058171918317, 0.2185389297383447, 0.025163893062140674, 0.09385664151200364, 0.034057890410505, 0.06424024160350524, 0.033267957999581294, 0.0606210507272232, 0.04259055089806357, 0.03469768491002821, 0.04351074506919231, 0.08798766490672866, 0.04315338037427395, 0.4726060449836716, 0.17431947673040052, 0.1223926276208893, 0.028882171665768952, 0.05088532959381419, 0.012982657438354387, 0.03197272356990124, 0.0255351584224451, 0.03803955578816034, 0.08824209802814069, 0.04585909184008356, 0.04880070859085649, 0.048119813474195625, 0.021126577142445792, 0.029714993509133498, 0.026014917154586124, 0.06062032677413476, 0.03412697621951661, 0.03740033585458033, 0.03381724304129039, 0.061444307962853106, 0.02267100848257542, 0.03678920453474407, 0.05647078854963184, 0.04186644076159404, 0.028565434528695, 0.08179960502011162, 0.03861299941256162, 0.06118365420749592, 0.07825839423364209, 0.03671526938917176, 0.022789872769686966, 0.026865228785261996, 0.07207581187568365, 0.003965387685081712, 0.08446133154774867, 0.04719257512460313, 0.04187513202909501, 0.03147541376341495, 0.05607268329890025, 0.04272081648870822, 0.055398326742673115, 0.033290553762907946, 0.06957795921592944, 0.03200371757209782, 0.023862798059839877, 0.02596500078065982, 0.08565680409270911, 0.02340471770073618, 0.08528552724108582, 0.02046888108335195, 0.07898780186810801, 0.03957145584506854, 0.07269012246040568, 0.014999802374551374, 0.08010626725491979, 0.028864444391201102, 0.04024985734553587, 0.06732617399745411, 0.00873836754415665, 0.03256906747757908, 0.022059088092177145, 0.06412864174513568, 0.04622040954869121, 0.03563818424159, 0.03275250340060842, 0.13707157705099354, 0.021266242631921367, 0.12348682334225987, 0.07202649113511847, 0.05207202277116237, 0.01581779658614147, 0.036548944039931225, 0.04805684487725939, 0.026923769393995888, 0.049292717068906755, 0.09701440997061231, 0.10944633158825098, 0.08805825990895111, 0.12962845063978626, 0.2079482544814387, 0.08551726883818066, 0.27622872122353126, 0.12141107746790494, 0.0968178241483627, 0.09248395750839865, 0.10345706385710549, 0.10991657933881206, 0.20612462814296448, 0.18522538184638948, 0.1833821130135367, 0.11669992018611201, 0.12363182846456768, 0.17190246932929562, 0.21231445003180735, 0.2813930118516568, 0.19922470403534753, 0.0828626822499979, 0.10044657580193975, 0.10416223246964718, 0.1436108882508932, 0.13855872225136528, 0.12830207665120402, 0.1554145718053464, 0.09774167255889024, 0.13911827287125972, 0.16759612056757175, 0.13906031065890867, 0.0836277359555806, 0.105632247944032, 0.13103993699675606, 0.14034099516368684, 0.13918061710653767, 0.1164451499860133, 0.08804390342125008, 0.18214187795116057, 0.0951924690255715, 0.09549718815833332, 0.1461830744219403, 0.13911048941794904, 0.20464564943986557, 0.17813804198897656, 0.13905379891155228, 0.15214935185447817, 0.11516667947533632, 0.1620288064042407, 0.1844721795209954, 0.1088922355143774, 0.22163403220474723, 0.0922877240865942, 0.21764367939003054, 0.14670995905274345, 0.1720331486074194, 0.11373214919360415, 0.13550943184283473, 0.08496139544032275, 0.10702263623956712, 0.11633307132269106, 0.128724267706275, 0.12684653257770886, 0.13952082143195216, 0.2139246902398525, 0.21738982849544097, 0.20448362184388025, 0.1026085755156894, 0.17231473188486793, 0.20646150764678756, 0.27071203015023665, 0.18190690346302527, 0.16682549740277952, 0.27400127461841034, 0.2473766702197252, 0.9317450609899337, 2.019699984981168, 4.07890975955994, 6.130580738667519, 4.28163182350897, 4.45423964531191, 7.1399247454058745, 6.14356231304907, 2.6658467323549333, 4.024622195189999, 2.4850257125593003, 0.5691958507222514, 0.36904670838867465, 0.17472159628185535, 0.1797807336814942, 0.1337768627150405, 0.13445865032413315, 0.18542514693352485, 0.18245416603261427, 0.15501677298978453, 0.24957802387014513, 0.22515042174247005, 0.19013019849456128, 0.2060130091323968, 0.6074153643942649, 0.2490950054338863, 0.17773272018999825, 0.20564925526418995, 0.12867865483126334, 0.10211409640408332, 0.11660777513057956, 0.11955044142180875, 0.1680991338986543, 0.1835126543958341, 0.2122112426666483, 0.16237210572486924, 0.18206951328583304, 0.13121895642290193, 0.13870343626026185, 0.1630963805702425, 0.14321342651401797, 0.12442254611561376, 0.11116383942745386, 0.16047070614032208, 0.21636461899165185, 0.1260827582389597, 0.12230609032896259, 0.209683412986417, 0.09803261743077347, 0.15757041983306408, 0.2679179236292839, 0.09831485188295765, 0.1556356034932598, 0.15023393286091669, 0.11643260912669283, 0.19841289598374598, 0.16428415393156393, 0.14172827314224937, 0.16005815247133856, 0.18076949272184603, 0.1458951939017542, 0.14078601563890136, 0.10312115728494622, 0.15573661984695544, 0.1712746449535893, 0.16407833674982672, 0.10401815431372774, 0.13746243510996142, 0.19230924366462618, 0.10349927530173333, 0.09211392938009194, 0.20758876006209082, 0.17777816452566655, 0.1536976308712075, 0.14038081641399092, 0.16733113075456313, 0.10821879060278017, 0.17696658630044232, 0.1316216735229377, 0.16983872039183495, 0.24206239489778397, 0.08495938062908188, 0.18936084703572337, 0.10427427282857318, 0.10563936490084856, 0.16225837231163057, 0.14446034186309384, 0.13165792480351465, 0.09724587577605441, 0.1190304285996864, 0.17249070228107516, 0.07138447115017522, 0.23282176574632046, 0.17190389425283478, 0.10174691812285494, 0.12299358529309112, 0.22313116719165157, 0.12945574377813648, 0.30329681392158236, 0.18550829811682626], [0.07528812579450107, 0.10291577677332586, 0.0473734752966031, 0.01956415422741444, 0.07150365910943478, 0.025572815474363107, 0.0721131739837508, 0.05132561181521705, 0.09445837293300899, 0.044966848386872205, 0.024959355247237032, 0.08163110398116612, 0.0349146869754599, 0.07954359099629425, 0.046830602410820224, 0.018170117438139937, 0.0391522410415834, 0.04504508128569973, 0.08590194456759961, 0.03229193900141024, 0.024930630780516133, 0.029510245020050677, 0.033444479979094, 0.04944310778932226, 0.07192884556828968, 0.03896931073658409, 0.027859291069269664, 0.040387802967621435, 0.014477283487306728, 0.08594247061879405, 0.06712150594760334, 0.023743485611292626, 0.06795028284672769, 0.004505642704785832, 0.06391834677948106, 0.051550512247148066, 0.017968197728717522, 0.020640752909164277, 0.02881360679654585, 0.05322501191028184, 0.038452113287583474, 0.13174132113495182, 0.036014563238789, 0.03459512871960479, 0.033646784647698366, 0.02293016262082083, 0.043285369662748235, 0.11995175658094308, 0.013197463704273106, 0.04161657352421073, 0.049194278601076336, 0.048890674126244364, 0.04760535095908469, 0.05778550651044615, 0.11093492469479961, 0.022011866432524497, 0.15055899928894736, 0.042724585641295686, 0.020662281895056367, 0.03265788771152016, 0.0009343961245312747, 0.020514850189248403, 0.026035645578597343, 0.011571669996145272, 0.03039545004045771, 0.04311107316865556, 0.03799539081932556, 0.013710608548154275, 0.010614610716490256, 0.04510214717517938, 0.03415723669252569, 0.14428752774913467, 0.07450647862447847, 1.2718404180580571, 3.2054057669255043, 5.470773846872392, 9.85743203470784, 13.020378389666158, 16.85375782751268, 21.087593609286895, 19.56275651531835, 21.95490025704907, 27.47454781686106, 22.954406469098984, 23.30651960065288, 18.72200627480784, 14.951574014079187, 9.288449095141504, 4.179449177557423, 3.488837951614011, 2.0225050925247134, 1.9229341322375884, 0.5039893883851267, 1.069045912834906, 1.1728804894993383, 0.5966348525497221, 0.7898291116279941, 1.513096827172464, 3.2555569468006014, 4.587031487495669, 2.424013979973332, 3.624205565260303, 2.8936302902237063, 1.2969862429365036, 0.643374857402617, 0.09772586816501233, 0.04953860447952344, 0.064112055941575, 0.02742429868498397, 0.04379201042015226, 0.03579078129522743, 0.03862079435719117, 0.05345735105595762, 0.04326467762791342, 0.02423982057089527, 0.08398652557403812, 0.05367935184509524, 0.06286383058214862, 0.01822910620830953, 0.06444514714061253, 0.05674156232646877, 0.03648868356380732, 0.012858821240614259, 0.10534176272490334, 0.102232625527728, 0.03017526871014026, 0.003554821774859222, 0.025036990597483613, 0.04783496666218966, 0.0801812059756729, 0.05991396306443119, 0.08590390575268576, 0.0345580117596734, 0.024025992024689916, 0.0568628570275201, 0.011545390307512737, 0.06386118129857125, 0.0598125406841357, 0.06335032705758369, 0.015613203229863318, 0.04232128631443747, 0.04143068611982369, 0.061384093452004664, 0.039228566381479466, 0.016218606127245773, 0.05917845737008799, 0.04605339472031882, 0.05373040394436929, 0.03854289087617109, 0.003713819493104013, 0.038615504520074014, 0.028938504026061105, 0.02091638751388077, 0.054820922443703304, 0.043643569393504056, 0.15665088449755024, 0.02064545477379955, 0.0906040543510068, 0.0834106802639942, 0.03073588227702966, 0.028532257175914226, 0.05351181224649472, 0.06916199645568287, 0.027452448585761652, 0.038392174568387775, 0.032508768697058966, 0.036422374823521224, 0.10669576950491437, 0.09337707047140406, 0.035236206416401177, 0.03969589150660942, 0.04437266293192103, 0.053807989498900796, 0.05208802634790059, 0.05445790785034338, 0.06919062516141324, 0.03745920205068204, 0.06366569481249298, 0.0599963826337649, 0.03423575687432482, 0.04499855293561855, 0.0415032078331757, 0.036896985444811084, 0.11290583143671674, 0.01792408255559783, 0.022870710367457043, 0.05353636153402829, 0.043955371009125825, 0.03057317286279173, 0.11805509141976796, 0.05309894065102262, 0.04036713391542435, 0.016355992505146612, 0.08260993452201928, 0.07498853945083196, 0.02562778228293023, 0.025754479819067547, 0.05347815800398108, 0.013028257864437277, 0.041406588824165445, 0.02252935691015615, 0.059534366497950214, 0.008241657201471108, 0.041578897320094614, 0.028922052287887183, 0.01232373946902132, 0.060011183452462, 0.06363890854822052, 0.06859100048219965, 0.03166705831855295, 0.03781332619368069, 0.018604606119615417, 0.04587234516117362, 0.04759004835279719, 0.01430538772124677, 0.026732048230065454, 0.03336695571159644, 0.03744340531768338, 0.025365992802225297, 0.10509613195374128, 0.032727394868890126, 0.024629768900453083, 0.03722061162754413, 0.05908565347894065, 0.07727466073007354, 0.0626080951112653, 0.023666758075236313, 0.01199293025438824, 0.04872911001345323, 0.008833697610234302, 0.05851310234697116, 0.04976844234812645, 0.032301806213874976, 0.016347213137534358, 0.04785411886029667, 0.061374950192628376, 0.026590789277707378, 0.08319507247858471, 0.027400274167678533, 0.051560613116429704, 0.025673741812727628, 0.03614870140389089, 0.020749267348418796, 0.042192047281611356, 0.014106449051459712, 0.05884907020616436, 0.11371521098959832, 0.1776781440862725, 0.5120993177256277, 2.6915402181686896, 5.340355528939155, 9.049706189863144, 13.807706929022267, 18.932329647002682, 23.515760398680165, 29.773101845095237, 25.545006452068208, 29.674467963557092, 35.83714692823349, 30.628698256707963, 31.05097474590425, 24.62893101476854, 20.540683807865268, 13.758297812554146, 6.259655644816737, 5.457582915982893, 2.7138310478579615, 2.835095044105284, 0.6003597558986756, 1.4598505295092061, 1.5664817561064999, 0.7893868031040315, 1.111649226757788, 2.2538196415670457, 3.389165867720881, 5.235768960368249, 3.6595010132558885, 4.653593128727329, 3.663286590768445, 2.3853886848495853, 1.2630989258327794, 0.2114725194030231, 0.02418620399229469, 0.048035375263181426, 0.042550557277976506, 0.02358092749941974, 0.015088958729569231, 0.04679695965962545, 0.025838381768534743, 0.03403635184851385, 0.03956176100238677, 0.05063684897557382, 0.05286428025893627, 0.03996852687710235, 0.024432371025003737, 0.06464076003119831, 0.008444210848650865, 0.032313975520552166, 0.026716669014985525, 0.011362950298784962, 0.009368206731103843, 0.022970801669984095, 0.033312620925566847, 0.04498715354730526, 0.017735431489023953, 0.056505032679847175, 0.12719282730212136, 0.04422591112914585, 0.07105758909376399, 0.07271505096146176, 0.02218493527071851, 0.06983531879321223, 0.01680044224485755, 0.07276947384760266, 0.11203409232679876, 0.03518553353064964, 0.03721798011552423, 0.029691047515840303, 0.001897533833060504, 0.07805024814461509, 0.0687406480973286, 0.04369932910307281, 0.042346287593846364, 0.0341058551754442, 0.024890133457618858, 0.041504115647365974, 0.023333170834267815, 0.03194411784680861, 0.03712222295542879, 0.045915713398567135, 0.06785253768846874, 0.07398678755928433, 0.018794431215933254, 0.0739384780547792, 0.08448428354196011, 0.03809498991036127, 0.03348822743001004, 0.02115454509734146, 0.04435448366547785, 0.09103032865471418, 0.03801632034141691, 0.05280301620763156, 0.10536805486246463, 0.09696732620678603, 0.071036544658484, 0.024489839110643636, 0.06571063246097296, 0.0275824805195894, 0.05287988546995386, 0.05649205898084948, 0.08257410458980069, 0.10373940556159905, 0.1738561314320372, 0.2226112539609594, 0.2017355265636598, 0.18592812962109045, 0.15677223282475627, 0.13144830782567302, 0.24617997959496515, 0.16675670270717916, 0.3213581334679358, 0.1422433446972601, 0.13517658196149335, 0.10950355835619474, 0.1346917862012502, 0.252600914888805, 0.12075192775697478, 0.1471470888223379, 0.1717153293711524, 0.22309318455236576, 0.18441432456095375, 0.2036846993911651, 0.10573926276617474, 0.12990643330399068, 0.16956803088466968, 0.1739019434899092, 0.13956631173289594, 0.16158899532691126, 0.10548795528349378, 0.10667510811359653, 0.1089300879187161, 0.10366868032442947, 0.17909047313995902, 0.18193766955406437, 0.24273437658144584, 0.08846319100308804, 0.1351456626528694, 0.09548024229344823, 0.1565011296301119, 0.10024174687362487, 0.14177759388281455, 0.09056690674755843, 0.14117025469820346, 0.26720196849876837, 0.11101626791059972, 0.21452263718651188, 0.0758671044041553, 0.09363424618758502, 0.17300703022028172, 0.2463116241438735, 0.13522522854468516, 0.18861279282118046, 0.18650284878188567, 0.12315702249085712, 0.18121647438214672, 0.14408437655337397, 0.19530758922619207, 0.1284862518490803, 0.175731300166057, 0.18600135230489317, 0.1332233182244724, 0.16286057870714896, 0.21987006879381596, 0.2058599294433671, 0.10230563370691192, 0.12666063368200295, 0.25693269776961497, 0.13646699578290986, 0.17127289827312195, 0.16799133000594957, 0.1188618892563447, 0.1424521343001435, 0.2503599085274243, 0.24943110352802664, 0.7489252871563359, 3.1304379961182995, 6.423540115356446, 10.422228824707771, 16.553345457200084, 22.75977649996358, 26.88054015559535, 35.2442689095774, 31.23580663434921, 35.927718377882435, 43.53367659353441, 36.86145820925313, 36.11592546586068, 29.2648587688323, 24.26011250865075, 16.53329626206429, 8.132304991445235, 6.7932774366871005, 3.4368302649067295, 3.3193332149136454, 1.3626852078783898, 2.4165293622401456, 2.3684381621499218, 1.3788641268207182, 1.8585915719309163, 3.2662358447428677, 4.828165077394055, 7.044074275801259, 5.478681835436053, 6.427904242469419, 5.571000700996769, 3.0855317606079966, 1.9314345212713366, 0.36646106971367715, 0.23548176091524864, 0.14655888651407536, 0.13038623417096754, 0.1591118806672673, 0.11721771901413319, 0.11878125850231418, 0.16504749926107545, 0.13484716415405273, 0.12892164259908662, 0.18180630079680876, 0.10661495488978202, 0.14358314054627574, 0.1579722329493492, 0.1935462151924449, 0.17345851647757715, 0.11458331118187598, 0.18546308360753522, 0.187088584287032, 0.20166063380818214, 0.11420794342073703, 0.13856653634819294, 0.14635277821892692, 0.15380109870626082, 0.1316013262276688, 0.22808521264983764, 0.18014151512855486, 0.2169695526601807, 0.16009038945119228, 0.10771042231710688, 0.1704276581445048, 0.1238864224644438, 0.20044848352911013, 0.19465203246762677, 0.14222157247845205, 0.10489986022754062, 0.14344670028696138, 0.13684277723152793, 0.21415440936482724, 0.16623655965010967, 0.14784237490065638, 0.10431141277114231, 0.15144687987142993, 0.14393077592455572, 0.13409016203255425, 0.08000300626360601, 0.1046997657225978, 0.17120894525320302, 0.06757878382960636, 0.24039877368317497, 0.23679154143939096, 0.11623612289587337, 0.19590789572365824, 0.17236347039861066, 0.166607269596669, 0.1877480940592866, 0.12481261510401966, 0.15009969893482425, 0.15422509772883308, 0.15180856530224124, 0.2537830191994867, 0.28496733295821375, 0.188944922579873, 0.2162878110163635, 0.21867080411363035, 0.1602324068305954, 0.1291909225044712, 0.237390423013318, 0.157400700714319, 0.14165235382895316, 0.23779257320828978], [0.08477593321473369, 0.09869870023741838, 0.07223639156549208, 0.16348676365469733, 0.04530716762547532, 0.03412233755713509, 0.014840941594523049, 0.08431062673128421, 0.017566664234524774, 0.05515924985370329, 0.10177177767599783, 0.03981065147766664, 0.08146124696659465, 0.10118607281436844, 0.10023658344101521, 0.04055371079894324, 0.03531880601639709, 0.005222269119845043, 0.043255136002816504, 0.03280814436654891, 0.016362818348551952, 0.03395515801985899, 0.025219101188403946, 0.08908579065915077, 0.06899917212825629, 0.021773168757077188, 0.03355275118543256, 0.003123646423656253, 0.015391436097542606, 0.029611653993807496, 0.01330652685400339, 0.04324231935184329, 0.026411873273431297, 0.01848418092835815, 0.09083095427242019, 0.04018462878922301, 0.041648082720536383, 0.055209126008013566, 0.016199628214141535, 0.0337396421650004, 0.06135512766758762, 0.025881654244937727, 0.03823221157935839, 0.011148773182574059, 0.02037083906602235, 0.03598826344034845, 0.053621745863628965, 0.08909738156944515, 0.028937946697096192, 0.034100335511949756, 0.04424174616654073, 0.02966006883540221, 0.03084964058812588, 0.01937998094475798, 0.030209202574746265, 0.04974124622681449, 0.08319031507257493, 0.014559340122486315, 0.028255107632327466, 0.04105862785851763, 0.06821662097448303, 0.08859039224203556, 0.028122168394827077, 0.04214860243542541, 0.022857723261920676, 0.10093060547425863, 0.0837914949102748, 0.04919724719178292, 0.03425471755045076, 0.4964138513370868, 2.8466942281492296, 3.908659282230562, 8.853417058144847, 23.812860327382243, 26.29394381277023, 39.201854121300485, 46.83770864240585, 47.76908328456264, 55.165453572427076, 57.54944270656955, 53.94009336348503, 55.6101248341222, 68.63811262192266, 56.56127998905798, 67.28403983577606, 55.18205696536649, 51.06905175793556, 45.61687092627249, 35.10217320534491, 25.316914742992772, 22.924225791808098, 17.217271327972412, 13.746062959394148, 9.94881933735263, 12.003697099224215, 16.59328106910952, 15.072298684427816, 13.302338950095638, 13.074181541319817, 22.038782104369133, 20.36512440250766, 23.35161312933891, 22.389416502368068, 14.742801939287494, 8.802469391976635, 5.00563467702558, 0.8203919748625448, 0.042270755154951926, 0.15986512895793686, 0.01348685246006015, 0.051937164483411666, 0.04246319261109156, 0.09043178415947384, 0.035814978182315826, 0.03477366167991873, 0.028532711083009362, 0.04771972405574015, 0.012885280002299096, 0.05130623362117237, 0.046946051861009294, 0.0296397177096937, 0.08362359908078948, 0.06813086509223908, 0.013304976483566627, 0.03516416733844146, 0.022671198089336677, 0.02709563547414878, 0.08622297371226935, 0.04979071252408528, 0.03128150733368051, 0.03386696597801582, 0.06684707027048835, 0.06720109482205684, 0.07362380743988099, 0.05772245747427787, 0.03632061919497867, 0.012642069111367869, 0.035992457771733884, 0.06626773159950972, 0.03426600968645465, 0.03101704803655946, 0.016409373511710477, 0.04753344977695135, 0.029007869457165082, 0.03345360408627218, 0.02284822760209922, 0.04668268615440015, 0.17729422678389858, 0.054300511255860336, 0.029982239451079123, 0.011715691653080286, 0.04849428108202354, 0.024704202003176176, 0.02397533637591668, 0.034716545994724, 0.02311529734382226, 0.09881810270129673, 0.06074280125058948, 0.03901325737036044, 0.0404996364828079, 0.09529353900542183, 0.07066833215855783, 0.04083596823376514, 0.08562897211842, 0.007773565509611922, 0.08407166858594264, 0.013103510681239348, 0.0657953464636399, 0.0720929109581536, 0.022794733597566525, 0.05283134613907146, 0.019811374631019372, 0.020443812771249684, 0.02499155392269454, 0.04449669639730165, 0.09177903404399272, 0.07825303161817213, 0.041112024186839985, 0.0343200495286334, 0.043344136267419786, 0.062464488099419305, 0.13120723527766046, 0.0493857009907163, 0.09696856726922336, 0.020732901795136354, 0.10070303139547188, 0.11356737134197067, 0.081525307238823, 0.059725597365609104, 0.15510983735082612, 0.1322773222120539, 0.056993053670251564, 0.09119290017312573, 0.03097307650492557, 0.01729115986475541, 0.029420773611373963, 0.03282046306037134, 0.04864573666465379, 0.061707355742973674, 0.05319804178490754, 0.029172396415003368, 0.039940476567754825, 0.03418523337571852, 0.024425652433907794, 0.014910961073192378, 0.04873691644940165, 0.024384731847432353, 0.023723291533608592, 0.039884636418954025, 0.026074430694983854, 0.0432175862032079, 0.05262526465700038, 0.009287192933111182, 0.04864562941234439, 0.04823308340424011, 0.01854730274287924, 0.042427466100742744, 0.041221632216606414, 0.08432712060429397, 0.06232469620543623, 0.014618950381484485, 0.04575008901977732, 0.024083507990825082, 0.03984565020448739, 0.018360982498814984, 0.049426361107297485, 0.07830494939680062, 0.026780137484292352, 0.06593688886852996, 0.05110001041283531, 0.020443240120526285, 0.01892734938601573, 0.05566381451283252, 0.04416699896776869, 0.03494120510895887, 0.019351141564848445, 0.044030470608343045, 0.05984691887973778, 0.020165711363417008, 0.052349469173819795, 0.04903703905461777, 0.03558948403224349, 0.030629376903356566, 0.0909772311006823, 0.1937830742568739, 1.2144735479547133, 4.263328083099858, 7.472437793208708, 14.29033398628235, 31.27799760910773, 35.66591193599086, 52.46232078921411, 60.6104721561555, 59.428179571705485, 68.1432193325412, 69.53567643319407, 68.2232827524985, 67.96977996826172, 81.06346745644846, 69.21384596055555, 78.01595057210615, 69.60385507152927, 61.06970325593026, 57.81709740238806, 45.93958000982962, 33.64604426968482, 29.070564162346628, 21.21998536971308, 17.70061912075166, 11.848852711339152, 14.387478347747559, 18.89958962317436, 18.931533405857703, 17.609443626096173, 18.764095267941876, 27.326237117090535, 24.232906949135568, 27.849730368583437, 28.521487251404796, 18.289019753856046, 12.05132055667139, 6.920553445816041, 1.3325886163980731, 0.037876382890728214, 0.20613231966572426, 0.016707069533426436, 0.05655712282825863, 0.007853247751031191, 0.04155076657151503, 0.04489544516188964, 0.03751149521239343, 0.007224849766991552, 0.05535834461390492, 0.026079040629068212, 0.04798374859796417, 0.04128799458304721, 0.02176462304628184, 0.007837587477444041, 0.06968220079978628, 0.01319406418910911, 0.06415746197284711, 0.05802672078472473, 0.022667754524117036, 0.0481282749153193, 0.037999841790165634, 0.06405702401553431, 0.06084602393750703, 0.027926289288687612, 0.058234583421219746, 0.06749657493445181, 0.05519222993884356, 0.00695045909754211, 0.01808413747517813, 0.02783549063268208, 0.0105749580055295, 0.08141794767711433, 0.015628213765129687, 0.026692500856194287, 0.020092580610165195, 0.017072317273085637, 0.04613578364613556, 0.042659609893997835, 0.1002916498410125, 0.0815610299187322, 0.05878242438719158, 0.0603472049378099, 0.011461948968410011, 0.031161919093480518, 0.03795785634147544, 0.05839923869878535, 0.010582114224352185, 0.03640714499558653, 0.08184792218549598, 0.12611958408547988, 0.10763654079768928, 0.1445747494337059, 0.11177408208529796, 0.0501361339082641, 0.07030106194677853, 0.059241134853612994, 0.03954605619993903, 0.0376711172922965, 0.050615034621929934, 0.046970482404914596, 0.10542751094626804, 0.0100162950900173, 0.00881659469732474, 0.010473345060862843, 0.03260395129121119, 0.13129009534755062, 0.08355789938040319, 0.015861318041119846, 0.2278361115003786, 0.22960925264464271, 0.22589988555879364, 0.29403763012059275, 0.20469348396985762, 0.20446718159702518, 0.2164814780436216, 0.20922786646312286, 0.17169885848078037, 0.1904591719710058, 0.28509882428953726, 0.18882935055561606, 0.3141547006464774, 0.2774849215582494, 0.27312490067655043, 0.2189416928036559, 0.18907843638331662, 0.14242055615590465, 0.06724663108827607, 0.11789840345661487, 0.11628125313549273, 0.28510835442331534, 0.09043327803092618, 0.24820265089792592, 0.1506960983838766, 0.09735617711539231, 0.06243361858651043, 0.1164611152583553, 0.08689548399659895, 0.14649370775347756, 0.06843045909678744, 0.14658677211451918, 0.08710642630654959, 0.13851983562832879, 0.19895050584548907, 0.11679392683530047, 0.08045374175473567, 0.1598304711402424, 0.16862889902005274, 0.14325617422019282, 0.13573798651416458, 0.14428106196705373, 0.16853071719167695, 0.14713705307052982, 0.16296236114876886, 0.118571434680733, 0.11696343144942677, 0.183457940396282, 0.1717053242628613, 0.19730375388697272, 0.16859479278566378, 0.18081323634232246, 0.17981859374671214, 0.22762903793444558, 0.23281402825828523, 0.18402674535830177, 0.18552037166251292, 0.07442880496983567, 0.1929244122678234, 0.2684283220479565, 0.15523210498354129, 0.15553310092899109, 0.1382626905556648, 0.15253748264043562, 0.1586576977804784, 0.14741502041297574, 0.1759875872202458, 0.26649165177537554, 0.24229367684212424, 1.382084147584054, 5.542547337470516, 10.127739233355369, 17.774846053892567, 37.313836928336855, 42.49974766085225, 60.856267483003684, 67.94575937332647, 68.74374989540347, 79.73740823807256, 79.83833082260625, 78.82082877620574, 79.72592353820801, 92.60983482483896, 80.11623074931484, 89.81633847759616, 82.05249309539795, 72.31387553676483, 66.2381947425104, 53.450707081825506, 38.99225442640243, 34.660298593582645, 26.040599884525424, 24.04338194477943, 16.591111998404227, 18.61082865345863, 25.99478856209786, 24.759408658550633, 23.1375164370383, 25.431946093036284, 33.556178846666896, 30.6852529510375, 34.39044344809748, 33.70625657420005, 23.729980645641206, 15.863519195587406, 9.058347171352757, 1.969330255543032, 0.32747638742289237, 0.28570516755984676, 0.08835573184994922, 0.18976137312429567, 0.09448920031108203, 0.19978915761795737, 0.14420777799621706, 0.17774824113134416, 0.10282933141195005, 0.1727775102781673, 0.19728777329287223, 0.1980286262809269, 0.1641096544241713, 0.11565126073096069, 0.1604226724274697, 0.15649342278559364, 0.10997519272589877, 0.20888217694817052, 0.12102542114594292, 0.20682544537609626, 0.1239922651720624, 0.1787019593100394, 0.1286149163159632, 0.12552193591311095, 0.1709508502315129, 0.20575102238405138, 0.17412046240943094, 0.1774815199596267, 0.058339629397397084, 0.14211615878007106, 0.1700117796539299, 0.10725328233093025, 0.1850730069582501, 0.07872237538498256, 0.0986797702048094, 0.151259969739664, 0.1997546223743308, 0.1548535809401543, 0.14351079120270668, 0.16526079346095363, 0.18432674538945, 0.23243709767778076, 0.15472824895574203, 0.10142804168525243, 0.15513217647469815, 0.1583736323781552, 0.18874644452045042, 0.115246337297703, 0.1251020431218128, 0.23784616871947245, 0.22595340446118387, 0.22375641751193234, 0.22097697391385035, 0.2707452477226334, 0.26068847446191695, 0.2413903059618127, 0.12845590710639954, 0.21044213114486587, 0.23418495792054364, 0.17884365493251433, 0.2154489447392764, 0.17983717903975519, 0.0870192684834042, 0.10332224004331136, 0.11554515755344784, 0.08054050887303968, 0.2617123969379933, 0.17218163176890344, 0.13169154074163208], [0.034156516569876866, 0.021325202673793803, 0.010405642040554556, 0.05217405036091805, 0.03703426457040253, 0.03951542034384705, 0.09000462885465353, 0.09358085752014192, 0.037322091464433944, 0.129918338310334, 0.07078744350902497, 0.04034811961314371, 0.030138785687966213, 0.10826873953544325, 0.037781767201639956, 0.04457888614025809, 0.057192301648038055, 0.15131878997049025, 0.05742459099799876, 0.06713850543864312, 0.04783410481327484, 0.05906553217960943, 0.04806655121126002, 0.03934934780362152, 0.054990794780033256, 0.043926443529105, 0.018501599852536476, 0.05161308247836367, 0.011471236826882008, 0.019155086258486397, 0.0246667115753817, 0.015179511279829088, 0.05809985153797654, 0.03135165800490687, 0.04868263911996638, 0.044366193319400477, 0.034928683401836504, 0.04538670287377412, 0.03489312543083103, 0.028224875887615547, 0.0235368391393774, 0.0031760401344077004, 0.038392224364102855, 0.05805465618088361, 0.020262948988426118, 0.04835059746138511, 0.06728339564776228, 0.0859884741986471, 0.07560691796243191, 0.06175941524786815, 0.05706759402528406, 0.07708017398873646, 0.11830214711446917, 0.032928998567043774, 0.06971578609438674, 0.03606063576655523, 0.09738394780264747, 0.08642512133284923, 0.01619136595587817, 0.029065728247646364, 0.05242924957025436, 0.04023186194019453, 0.04196998520543979, 0.07806085080148713, 0.12902394598049502, 0.46884072283583306, 1.4507362895434903, 3.1283245740398287, 10.286638371406063, 21.07110788745265, 27.46888391433224, 39.01946783065796, 52.80795612642842, 58.948175599498136, 69.69366950373497, 82.30622337710473, 81.4180967884679, 77.01507937523627, 69.99937903496527, 64.93685822333059, 66.26869509297033, 72.04727988089286, 69.63503791439918, 71.84915311874883, 74.55682800662133, 72.81581340297576, 72.52528344431232, 78.52807875602477, 64.8106441959258, 69.57519039030998, 64.09736902483048, 53.98005839317076, 49.271366750040364, 43.67699607726067, 43.75283902691257, 45.35513116467384, 54.51013534299789, 47.48025563455398, 52.71344661712647, 57.446868804193315, 58.00343744216427, 56.07281154201877, 50.06882382977394, 42.919911953710745, 39.73280575967605, 22.31542883380767, 11.711477579609042, 6.841226450858578, 0.6587808242728633, 0.9540974228612839, 0.050298391330626704, 0.033615773408523494, 0.04285080628770013, 0.010043904898808369, 0.024800393918168642, 0.032544533511803996, 0.033905143969722336, 0.017711383989080787, 0.056274463197276484, 0.016569344161619103, 0.013700862952147522, 0.06992107467545618, 0.02589114032866013, 0.016473527629709533, 0.0192935758029982, 0.10092319740403084, 0.03346982599806882, 0.06560121978362722, 0.034426589376263084, 0.09406208331065793, 0.06336754105324227, 0.031485911083197406, 0.030975734830022823, 0.04396435339003802, 0.040828839785629706, 0.026857123575023106, 0.04615455663072006, 0.024609101763475808, 0.0714152142585766, 0.03143692359087929, 0.07518965285271406, 0.1146881043490383, 0.07709287572652102, 0.0719226019517068, 0.012839591476104915, 0.02022569221744855, 0.04398973388296943, 0.0389523993456556, 0.05924501508894948, 0.0269947167966635, 0.041746176448800874, 0.03669257403441495, 0.03622850478296319, 0.028657600651645375, 0.05639159421045935, 0.022926531364059737, 0.08766913320869209, 0.09162732565234746, 0.025151120461223107, 0.12329985958433921, 0.0916097209518475, 0.16968973161232087, 0.026165574090555314, 0.029602091301292665, 0.024727450856458277, 0.042588654830450975, 0.07726761272117015, 0.03412045298084136, 0.017559484075454455, 0.022086623207395597, 0.03230961264982339, 0.043120587980675126, 0.07216810248792171, 0.06469925850509636, 0.0361643640715028, 0.0774942368509308, 0.047959681945822896, 0.0229770127278302, 0.021775401903376467, 0.04181538100144075, 0.03450590245906384, 0.11380822172448521, 0.02477501151001742, 0.14948662941253957, 0.02605877568825118, 0.11814172830312483, 0.030843732135009863, 0.02719230044843449, 0.009082737472659398, 0.06206748601529868, 0.10716870622408968, 0.040705859691144965, 0.03973129242959042, 0.00738614670661909, 0.08389310881255135, 0.0659194297247356, 0.06254783846558103, 0.09681412394368842, 0.020730718444552154, 0.03449817263190785, 0.013718620870232344, 0.0175542306275137, 0.03352578489049789, 0.01644691182000022, 0.05461733457782576, 0.04523333207133316, 0.041722297488201054, 0.07071242817947943, 0.03259506850172916, 0.04203353219875886, 0.07838352703519406, 0.009351056895308919, 0.050271570592397646, 0.04878921727199228, 0.11556368922033619, 0.0668818200187337, 0.09598667237667308, 0.03076360699900937, 0.03794857135583316, 0.04385005307173537, 0.06871594176177057, 0.09391772170220652, 0.04531293626754515, 0.027410060940911214, 0.13664612246136512, 0.03179247457263691, 0.06662311978758344, 0.10961708492569386, 0.024482295059809284, 0.06558171518507504, 0.04417095198145798, 0.07124233885758346, 0.016823195056208683, 0.025733320470598918, 0.045519768515782016, 0.027824177429260268, 0.022683811727009957, 0.02422498144780196, 0.08784749379922306, 0.08355313431351416, 0.19461922858270908, 0.8156988589513687, 3.2064920183151, 6.198169550588054, 16.769954427596062, 28.982689342191144, 36.982282900041156, 49.813712873766505, 64.35495107404648, 70.49297794218987, 83.5630056934972, 96.14731065688595, 93.33957610591766, 90.23829921599358, 83.2428147715907, 78.60100346226847, 80.18173433119252, 85.53289059669741, 82.47863508039906, 85.08080605537661, 85.28937416691934, 83.44363227967294, 85.46846174424695, 92.84813450228785, 78.21852530202558, 83.18546971967145, 74.13550269219184, 65.18651708479851, 59.141964220231586, 50.153515646534586, 50.49940986018027, 54.44112123981599, 64.34780059322235, 55.48001981550648, 64.9640480933651, 67.18671014232021, 68.55780601501465, 65.93071229996221, 63.77347538548132, 54.58859451355473, 49.742651293354655, 29.272521118963923, 16.66571940145185, 10.763484835624697, 1.8789723299203382, 1.0241516895832554, 0.11912606701615358, 0.03941622344897159, 0.05256848605049234, 0.028156860686478116, 0.07878703320579183, 0.009626887810056009, 0.02540948744412632, 0.012267144723615099, 0.03603540849120867, 0.04716434861503301, 0.06080816004184946, 0.05018866838767164, 0.026826081692331263, 0.04784860685768147, 0.0779975795998208, 0.054749856297407425, 0.015347409024534207, 0.05865009035915137, 0.04177845173305081, 0.013195879817489656, 0.002718924567283642, 0.03119808993482542, 0.054704132339646744, 0.05115707630231496, 0.04834276421235935, 0.010664174689971393, 0.08565141083372217, 0.041916516098764636, 0.031052293826735793, 0.03368330405904882, 0.021882416725519205, 0.08480180400393664, 0.0455244186694824, 0.04889544302357301, 0.03873484952735805, 0.02952169803451867, 0.02208345926426832, 0.023101005973594806, 0.014776522218580208, 0.04620212686037825, 0.019160466110934655, 0.05841477113145013, 0.04374914013990953, 0.02989163423227447, 0.010823583222865578, 0.025642146431510488, 0.05719414025905633, 0.132700968834181, 0.07852366749918269, 0.09454035200178625, 0.06505081625354868, 0.08692559125202318, 0.05910689326664133, 0.05425462258919593, 0.040116967903750564, 0.049238627431012934, 0.00694948377185351, 0.030790879729113756, 0.015587985530615816, 0.009407850823575451, 0.07442246942270188, 0.02508145051016923, 0.06139570351449713, 0.01885625451142269, 0.03497642600127766, 0.05202807996782565, 0.08257879304789728, 0.1701299716988879, 0.07758609079305204, 0.15875805529855913, 0.1466751173739472, 0.24289068916151602, 0.1863925167990308, 0.43922532650251545, 0.19820608288770725, 0.2414350301748322, 0.15086511270173136, 0.1047377253792459, 0.07374639682952436, 0.1824239974901561, 0.18013673473990735, 0.17357061046265787, 0.17774496227502826, 0.32335982928352974, 0.17741650973837222, 0.1523094335871358, 0.1327000035633964, 0.17598210203070797, 0.15941093074938945, 0.15151968886775358, 0.1588027182245447, 0.20196887694539564, 0.1108503562488383, 0.22640170379271432, 0.20029148146990808, 0.08780326754335435, 0.20437028679636218, 0.09873710422506256, 0.16776775490612755, 0.16092278994619846, 0.15350509765407733, 0.138201265625896, 0.1363501673744571, 0.209990062660748, 0.2007075591433433, 0.1475516904986674, 0.16312729987886646, 0.08533190620402176, 0.18562932468710408, 0.10862798880665533, 0.2845538293402041, 0.19760862623731937, 0.1656251755212584, 0.1689529082467479, 0.20245125186779808, 0.2184100124624468, 0.13691878847537503, 0.18058181650215582, 0.21317265236810332, 0.10471640515231317, 0.1375750193913137, 0.18187124973102925, 0.21864206049471133, 0.19568887118610645, 0.1143941947168881, 0.1502071810706008, 0.14623668525488148, 0.2050505115860893, 0.1432759086451223, 0.21529670774696336, 0.2549848885786149, 1.1287988097436967, 3.813651141620452, 7.175663911527203, 18.864529517389116, 33.153924096015196, 42.264032825346916, 56.29214263731434, 72.51670914311563, 80.88902396540489, 96.16153317113077, 109.25570703321888, 106.2417499480709, 102.48322502259286, 96.56080692045151, 92.19550701879686, 93.18716849050215, 100.53165758809736, 98.1929208386329, 99.75860549557595, 98.08093717021328, 95.77796459198, 98.48888720235517, 105.05320902793639, 92.50817483471286, 97.79795385176136, 86.53355783031833, 76.599927871458, 70.31928754621937, 60.07490388808712, 61.36856825120988, 66.64449737917992, 75.37361452656408, 67.78676217602145, 76.52865056068667, 80.55118237772297, 79.13366917640933, 77.48530095623386, 77.97758194708055, 62.87613514930972, 57.50478652215774, 36.42393350601196, 21.756045895238078, 13.82211575585027, 2.8643218499998895, 1.4535363715502525, 0.36056789239087417, 0.27690373661537326, 0.16285679423280303, 0.10920509050089507, 0.2296337674582197, 0.07354656279447579, 0.11289751172185906, 0.13071667853622668, 0.1296967856826321, 0.1657169375328287, 0.12004141185072162, 0.11382399547484615, 0.06515295109561374, 0.16152427621906804, 0.16076384202366875, 0.2982274875525506, 0.12166376390884961, 0.2559747354638192, 0.12665944624572031, 0.2818262805381129, 0.10297390752502027, 0.15977476122638873, 0.17290370028105476, 0.18108103003713394, 0.1534211190958177, 0.11769605665317467, 0.2071241583795317, 0.15383681372529076, 0.24028923843176136, 0.17828700012497364, 0.1467552501708269, 0.25835570608896596, 0.17617861890504438, 0.16932688172786467, 0.06957076565032044, 0.15381448992317723, 0.07244896564272142, 0.11196077005156588, 0.25102338663512663, 0.1574486884618959, 0.11311315015078553, 0.1647033572437302, 0.15820841785640488, 0.20838631887830075, 0.15009983683065062, 0.1914466899489203, 0.15810845870404475, 0.19943537821452464, 0.19905562843045882, 0.2238482408105366, 0.233366331686416, 0.37267208159450566, 0.1589119470407886, 0.10028251041207584, 0.10978822896797812, 0.13681358928161283, 0.16372553793893707, 0.12800420634448528, 0.14089331391357607, 0.1724367696912058, 0.20097633343069785, 0.15650278438002835, 0.14063909529678284, 0.1405315059086969, 0.11920148837229899, 0.11597503247039935], [0.01863159348196801, 0.024540404744085767, 0.022475544979134877, 0.03258380317880261, 0.04849780508647523, 0.017003650897212567, 0.03589889162310189, 0.10629994719619713, 0.0870179967774499, 0.05031310404921251, 0.13838125032282647, 0.099485932188409, 0.04911698415995606, 0.04336708826163123, 0.026241539369126963, 0.06607671523646963, 0.016694275865090952, 0.04012658230720028, 0.03716085676945025, 0.0682455561153831, 0.1429846879815863, 0.03504994745937086, 0.039256995904349515, 0.03187792018927153, 0.01263331559922306, 0.033654939653652335, 0.022269955708555157, 0.05633098133389027, 0.026823542110862273, 0.008921468303719116, 0.016825696333281456, 0.024006002875525626, 0.03644459137332536, 0.029778082764917807, 0.05180839659465898, 0.024707911783949505, 0.017417361358961752, 0.05077223969443191, 0.04116093123992605, 0.12396491583316557, 0.03211624248163595, 0.02512780457524763, 0.05172654393038923, 0.036943199698843306, 0.05054583006929006, 0.07315099329477356, 0.1228645760866423, 0.03549777181638825, 0.07685993137138505, 0.04205145099530778, 0.06432251944657295, 0.024439447762204275, 0.02608742737661927, 0.03481398471781323, 0.12179721642525927, 0.017791218011670055, 0.05350901985601072, 0.015463366007973111, 0.03337431015566953, 0.028051808964641347, 0.03011000759509062, 0.43738772672030235, 0.7474235709636443, 4.235524852429667, 5.149671954493369, 12.30865647715907, 25.05920325556109, 39.15478175686252, 53.30763078504994, 63.162903554977916, 65.31373131659724, 67.2594230405746, 70.31728713743149, 72.71421617077243, 76.86119694863596, 77.3766513024607, 67.22168199477657, 62.19903599831366, 68.682325578505, 65.17181996376284, 52.32872486114503, 59.83037940917477, 53.783622172571, 58.3378077322437, 65.12695197136172, 68.28999442438926, 72.06977859620126, 59.86914811595794, 66.34500088230257, 70.32109183649864, 68.84290741335961, 68.52926684964088, 68.55123996734619, 67.9185224348499, 61.92236769583918, 58.353320706275206, 75.45244632228729, 69.69557577563872, 71.99971722018334, 67.17225228586506, 69.49922976955291, 74.87805443425333, 72.7391859792894, 74.36491427883026, 68.0432616510699, 64.1024249599826, 50.16131724080732, 40.486497033026914, 16.32826122545427, 5.922796610862979, 3.6507690818079057, 0.7325031199762899, 0.06515066815359939, 0.09471606958897845, 0.019177672445713993, 0.11037851503539471, 0.034347502289399985, 0.09469514772776635, 0.030312214587484638, 0.057269201553877325, 0.03173425189039159, 0.0320844843067349, 0.0347104785783637, 0.024634629728332646, 0.024838958784276922, 0.06762620467211931, 0.05075672258352561, 0.0478288532805539, 0.12340859044343234, 0.022833135669990894, 0.04316589442051707, 0.06270127821593516, 0.03921343997541455, 0.04705962439578387, 0.09975734947910232, 0.02967823086486709, 0.08288504435650765, 0.0714759037439381, 0.03994184786513929, 0.019765798145184116, 0.03504064332153048, 0.019363125095204003, 0.02640557603069371, 0.03381145141658283, 0.026838595738574385, 0.02503834465788978, 0.07373951735996431, 0.06039885841610451, 0.028244947391231696, 0.06351017513342443, 0.018461359169093833, 0.023329597034101045, 0.11449517276618751, 0.11841906745347286, 0.16211784114280056, 0.034397359291512164, 0.03881708140515032, 0.056420766838615945, 0.04077035280305051, 0.06971783154914457, 0.06601247110313947, 0.04414277143716332, 0.08837003471149553, 0.14791887644077503, 0.063780527561903, 0.022375022752150413, 0.040241200551991506, 0.03142545908509243, 0.008321945131155513, 0.05403996858325216, 0.057722725605051366, 0.029863714157874068, 0.039441941020589684, 0.07322392486516507, 0.05373624153435231, 0.01917511754248652, 0.08743324707592688, 0.057505646930827256, 0.013438042125574524, 0.10621668876058633, 0.04850956453611294, 0.06967516045176214, 0.011518871216403862, 0.0526894819772532, 0.07199308970161984, 0.02962707151328364, 0.03466235676540002, 0.03906281559818214, 0.08754128845588816, 0.026679952335994572, 0.035453717930302504, 0.04663898466875957, 0.021312702034089356, 0.01877614469718068, 0.05074452263333144, 0.02570381842463488, 0.11200554789074006, 0.03677348441053783, 0.009386000080755161, 0.05343457909240838, 0.047736271554904605, 0.021225436958634568, 0.054285223971331314, 0.03786916634248149, 0.0701540649958676, 0.05111157451005233, 0.03894123361415921, 0.08095163761848405, 0.06722762444687468, 0.05478083689306533, 0.022638876839811285, 0.011325954955311553, 0.02633868889402478, 0.030533855315297845, 0.04304748021006104, 0.04810404738471393, 0.020041651084959027, 0.03270459609226354, 0.058425040540075114, 0.025479881348268642, 0.05340597719975537, 0.06039469089779643, 0.0700594607980982, 0.008572262445194347, 0.083909188998082, 0.026305542184760975, 0.02819297981688813, 0.01805511040372714, 0.06206975363555455, 0.015614378217217183, 0.06668429956921647, 0.04233812109657353, 0.03333234002873783, 0.0639690579696288, 0.03492159325809729, 0.04236982564531988, 0.03219942622367413, 0.7076915545809654, 2.035810385019549, 7.697381800220859, 8.737996412861733, 19.206201299544304, 34.254403883411044, 50.66751872339557, 65.32172118463825, 76.94151140028431, 76.17585689790788, 77.67279809521091, 80.50959740915607, 85.2519469107351, 86.0235869499945, 84.96946565566525, 75.91761589050293, 72.32658401612314, 79.90786660102107, 78.44203764392485, 64.98862566486483, 65.77118950505411, 65.47261868753742, 68.64278808716806, 74.96668431066698, 82.21231399043914, 81.62616283662858, 70.26105603864117, 78.3703524066556, 82.26624658030849, 79.6395686364943, 77.02974903968074, 78.30717086791992, 78.41184323833835, 73.70832520146524, 68.38596697776549, 85.76831125443982, 79.46414455290764, 79.97253864042221, 77.79002989492109, 79.80086434272029, 86.61046766465711, 83.11179976309501, 86.39032856110605, 77.62683576153171, 75.60680727804862, 60.50791394325995, 50.663043299028956, 24.095394534449426, 8.683355835176284, 5.12772923515689, 0.9292208319229465, 0.2506867676011978, 0.033209176073151256, 0.0188908338051049, 0.07140315603464842, 0.06718029553491263, 0.05929073521627053, 0.017483788842876113, 0.07005243577183255, 0.08642129089322784, 0.03010139868204152, 0.018363391845336845, 0.01720277438571136, 0.08728234307660211, 0.017724340451100183, 0.028936583060590975, 0.04871362354606391, 0.07129748186637318, 0.03095949951168751, 0.03679631000024177, 0.026724314572469845, 0.04237166042589853, 0.043481522645320625, 0.11197829814327341, 0.011015045832121565, 0.03696438586038928, 0.04145302524369571, 0.029681337351400047, 0.008240757048160078, 0.02559779568635408, 0.047839532546218366, 0.014043948725767195, 0.04095625169875641, 0.012965995983611192, 0.009988873930377586, 0.08910560935375192, 0.011858085373176203, 0.024587917517149643, 0.07656220662137193, 0.05037136503585404, 0.024434613747402065, 0.13606555038882842, 0.09473963445352931, 0.054450652997700445, 0.03431773977354169, 0.018421076350815354, 0.06405906563985252, 0.029442473051829204, 0.04864640699158754, 0.05444135269029968, 0.019890467463541898, 0.09562828112393619, 0.07936735246931353, 0.052355276120285836, 0.05527870594373634, 0.047790694441045486, 0.03394560107300359, 0.12824011545988823, 0.058777306919857386, 0.006492393102586991, 0.028333959147153844, 0.05680767188389456, 0.061612943067185344, 0.020847746035865238, 0.013777285010644026, 0.21643105413644545, 0.14511173110335104, 0.15716169660370197, 0.21855206048536688, 0.1258360779273414, 0.2084735609711178, 0.17206065116390107, 0.13617859432293525, 0.1495770890746386, 0.15628504687018935, 0.1808063721945209, 0.2064250571833503, 0.1294023627715726, 0.15403020496089614, 0.13888262422575107, 0.17780453327202028, 0.05018330194176205, 0.15995860700645756, 0.17850898176191315, 0.08667000133784548, 0.3180626990093339, 0.12908704098193877, 0.11503052266855394, 0.13752620426877854, 0.13628351772504468, 0.2092766969074165, 0.12750735236031394, 0.13449906912301818, 0.1268790070448191, 0.09766009185583362, 0.09527239497871169, 0.126720993749557, 0.19323608747893767, 0.13021682148739216, 0.14655441256059756, 0.18401310899324957, 0.11232429409339545, 0.1526138462847279, 0.2998097042643255, 0.3004007564196664, 0.10633972248122578, 0.14586056672757672, 0.09593110035864577, 0.14009586234967555, 0.14224138351217394, 0.15377880554766427, 0.18950127095224398, 0.1384742840403511, 0.17802919621669477, 0.11460592609740074, 0.1457892439418262, 0.1178309340931235, 0.19063489721907725, 0.11570485624214334, 0.19868006148645956, 0.15086586346789715, 0.30330744722197134, 0.13280963074536095, 0.10940118602687314, 0.09676104937229427, 0.12414911401367958, 0.6799799480265187, 2.0379473413190534, 9.095762660426479, 10.028065923721561, 21.21161699295044, 38.026429607022195, 57.18802767415201, 75.88577408944407, 90.07632886209797, 89.35789969659622, 89.5609058872346, 92.45433638172766, 98.06625181628813, 102.06237039258404, 101.18050390674223, 87.91269456186603, 84.78441607567572, 92.91019424315422, 89.42137149072464, 75.53764020243, 81.33833931338403, 77.38693575705253, 82.33011845619448, 88.64943335133215, 92.66506179686516, 94.83087693491291, 83.11621635190903, 91.63792640932145, 94.46062088012697, 92.2267447748492, 90.53685434402959, 90.90463146086663, 90.227018479378, 86.08001416729343, 81.77993543686406, 96.00717221536945, 91.61901274035054, 92.43436367281022, 89.5737006587367, 90.6018009493428, 98.0151511776832, 94.34735851903116, 97.60732666138681, 89.07384949345743, 85.49940924490653, 71.20518622859832, 59.32080861060851, 30.488897139026275, 10.690416962869707, 7.015224262591332, 1.5565282514979764, 0.42853266962112924, 0.123838564951814, 0.1385566844574867, 0.2138949813501489, 0.22692126462296133, 0.2065857517863474, 0.31764701970161935, 0.12546878473292436, 0.13527385980611847, 0.10133845536338706, 0.16804923093126667, 0.20217618033770593, 0.09484967532297296, 0.16375996593025424, 0.11935393220835155, 0.10859054242891651, 0.31319022659332524, 0.13459781785645794, 0.1559294901427723, 0.17310634585878543, 0.10393606033176185, 0.15089070003840233, 0.1799817551528254, 0.20158512818236507, 0.1725447268014954, 0.17485987515218798, 0.11861301793326294, 0.08838868129157251, 0.1332286195529084, 0.1325340076319633, 0.1311250800086606, 0.1386668632227567, 0.17873313908855762, 0.10072048287838699, 0.18669715932300016, 0.19916422905460482, 0.11545109727810468, 0.1502779829165628, 0.13833384480207198, 0.27650567732991715, 0.23422963616828765, 0.21148635495093562, 0.23300211816545457, 0.11391238669954962, 0.22057350604764878, 0.22614711745371743, 0.1343287064904167, 0.15811755982858522, 0.1830642171684773, 0.1590150165101213, 0.27559626967676226, 0.26793431791086353, 0.20343680866062644, 0.19359634798620978, 0.2849118069054619, 0.1517088512980169, 0.18935785929281868, 0.187024723197664, 0.13936907473591068, 0.09721691765251661, 0.1285625312237009, 0.2160596240672373, 0.1517770790885533, 0.1356288189849546], [0.0344840421401445, 0.019354535334353006, 0.010533330702943908, 0.054703381573480946, 0.061642192304134376, 0.05511030449622101, 0.09353433300050036, 0.008633836762108391, 0.05348764983336291, 0.01921929017220053, 0.06299411915543099, 0.0642944653067858, 0.054024072258823344, 0.01630583481352416, 0.050315536378372105, 0.0667478389016563, 0.004126558938409172, 0.037811096877821034, 0.0144574839449037, 0.047688034828752286, 0.05617719301353059, 0.08152805749447116, 0.04801700064431756, 0.027924161479477922, 0.051080222361751144, 0.08479985814060896, 0.08670879603033105, 0.10824993973778141, 0.033353897742927074, 0.03346687272912072, 0.04636029720366482, 0.004561982247152276, 0.07172452225800484, 0.042872417628044085, 0.028833145869054624, 0.10321109600725675, 0.044518648646771915, 0.04726690097501682, 0.030167303310947555, 0.06966228251375499, 0.06539799963995334, 0.05423411824590257, 0.053492518322121714, 0.04905796474626949, 0.05754808820183239, 0.06507563750229536, 0.1423780229543486, 0.030012478856670282, 0.04010961345967747, 0.08870830083446157, 0.02518821635373658, 0.0027833219181986587, 0.01362768240318063, 0.060481890855777654, 0.020596957577752973, 0.030235527271044352, 0.0583790599428598, 0.046958290115599675, 0.058883804632651235, 0.1878032217463178, 2.100951392804423, 15.948858203426486, 22.583254152728667, 29.953852507375903, 42.06101878996819, 53.27154497946463, 61.94971053831039, 74.86917418818321, 68.26950396260908, 63.74396347230481, 69.18409086042836, 68.50097087121779, 71.78554796403455, 61.9833174059468, 51.90958038453133, 52.131692440279075, 41.945532444984686, 49.91065817494547, 41.28459738146874, 43.09492418842931, 36.95675611495972, 43.215540993598204, 37.129485530238, 33.40919194682952, 35.489926953469556, 31.194215782227058, 35.05735620375603, 37.942863510501006, 57.858556855109434, 56.96767676261164, 55.32993424323298, 61.37095305227465, 52.114218281161406, 62.8152128957933, 59.811928579884196, 50.17679099113711, 55.688117242628536, 62.63268932219475, 57.11779371384652, 64.5976241942375, 64.72123376784786, 59.165357235939275, 57.86763321968817, 56.716268524046875, 68.59878693857502, 67.57361273611745, 66.29401007006246, 65.54906960456603, 58.42480198029549, 36.79791973483178, 21.388172680331817, 12.392083329539146, 4.041691859883647, 0.9011518606735814, 0.08802668942559151, 0.050523670976080244, 0.04918836823274051, 0.019454345099567887, 0.03207628525072529, 0.030198419887212016, 0.031132441945374015, 0.020264663110156695, 0.025221165795359882, 0.038117899769736875, 0.029807408610659263, 0.012131187099693044, 0.023578730742296865, 0.04254777254837175, 0.011085977913030695, 0.029396660993957234, 0.04846360309109573, 0.05733835631080213, 0.02562827449442158, 0.057103496735855463, 0.048700044637606035, 0.03703189352827688, 0.035098199507281665, 0.13410598940906987, 0.0374152937213019, 0.011379201896488668, 0.06533283620111405, 0.055018756989269495, 0.04918367977464392, 0.10496384389097653, 0.07681253351150982, 0.021616340982877923, 0.030001251838139953, 0.06660481028619313, 0.08244079763009664, 0.04701989507603069, 0.04875263274316827, 0.00970914745853553, 0.08539224328893809, 0.07624392007147113, 0.06875718793561382, 0.011371136905865805, 0.0662008291410823, 0.017756742139857624, 0.07156254062729497, 0.015097212369343447, 0.03731973191362716, 0.06136887128494921, 0.0385576572209116, 0.0657257090713228, 0.034837377212581136, 0.02901960783938487, 0.03167845387642663, 0.07676655291429452, 0.031275137312590115, 0.03262812902610148, 0.05452906209675055, 0.02231147767405116, 0.01350366904760801, 0.06534155428169236, 0.07750126953807569, 0.09928422123794595, 0.06508018040368635, 0.03519185375602495, 0.03527923374466839, 0.007381790060354698, 0.05475758612456341, 0.06801389878795994, 0.011691825141409233, 0.0398110919782231, 0.01891391603426347, 0.023508796490909114, 0.04946599083562051, 0.02116123304492043, 0.007168735741757818, 0.03601979178887221, 0.04726071098458864, 0.047263629779580145, 0.03676635979284202, 0.005238530293647801, 0.016018382344965734, 0.07413226765610519, 0.04077450883003973, 0.08206456418960326, 0.09637591399012074, 0.023738511785444234, 0.06048113242873262, 0.03763567806491929, 0.08820321906598345, 0.016726348136040955, 0.020882221907677672, 0.040575257021813624, 0.043027481484797694, 0.026854882767844587, 0.04139427013034302, 0.003916335075290033, 0.03437999590870834, 0.037674867292685855, 0.017215667645477, 0.013186342022832365, 0.031680217793872284, 0.013486885018796932, 0.06934860781315835, 0.06979619468291921, 0.013541311735377438, 0.038017998073971083, 0.054847348646651355, 0.019761607644238302, 0.07857612920023742, 0.014781608084787526, 0.08633532816724432, 0.06007069699285973, 0.10898708486028257, 0.03846627059242418, 0.05024997074337256, 0.011870062200262422, 0.038675791809275266, 0.03461108250062793, 0.04590540185510632, 0.07119710902653395, 0.27974270524517186, 0.39244229815179305, 4.516266536328101, 22.818378671523064, 29.206813573837284, 38.344392622670824, 54.85343294758951, 66.23208368978193, 72.08666832216325, 83.97830624734202, 78.33056388362762, 71.82258298320156, 78.4209745160995, 77.8885990573514, 82.3105222948136, 69.71405013915032, 64.36610629481655, 62.38005730413622, 50.924143714289514, 61.71424281212592, 54.584417189321215, 55.12732028961182, 48.61206339251611, 56.727819904204345, 47.72176773317399, 46.777492415520456, 46.82564343175581, 44.39883770481233, 44.34614066154727, 51.01669596087549, 66.48171901702881, 67.72289030013546, 67.29495186959544, 70.45244416882916, 61.629794182315955, 72.92590648897233, 68.45013695378458, 59.52809410710489, 66.23921455875521, 73.50602503745787, 67.33064543816351, 74.61085473337482, 74.03767878009428, 67.0603862885506, 67.58439925409132, 65.80102697495492, 77.32198915173932, 75.25215441180815, 76.37308151491227, 74.76112073467624, 66.32575773423719, 47.7456824241146, 28.388895450099824, 16.551094016721173, 6.273515339820616, 1.6826302462047147, 0.31284652890697606, 0.14094960605425222, 0.04523347379759916, 0.027518408756042202, 0.012579123497069364, 0.030042716347041632, 0.039192510453323205, 0.026967945854149522, 0.07152857228873238, 0.028657767275768905, 0.014345632235129035, 0.08278226600058618, 0.020157006689377373, 0.019537505858968345, 0.06990351594023167, 0.0420494323536273, 0.019454178475444357, 0.04898864528044097, 0.038007713343587615, 0.003944740657912447, 0.008984367952742165, 0.014074517549165796, 0.03991208917972061, 0.10733775884634066, 0.029216948258239898, 0.027213157192173026, 0.07260159333987583, 0.05581708572384331, 0.062397834619567286, 0.11524890369224934, 0.04805289569400972, 0.06603734597804085, 0.04570114366229504, 0.04624139652737687, 0.059150847561296925, 0.02893389600719656, 0.024987876700657993, 0.016195805435399377, 0.057216510026445316, 0.10385793468524372, 0.04724666859293657, 0.037167448956038684, 0.047484531232546416, 0.027112098703641566, 0.041339877887719104, 0.042573375206801205, 0.0870636173133408, 0.08829929415256747, 0.04715137491603533, 0.02792636015182061, 0.02279299457797841, 0.06944642958020972, 0.04427063917260497, 0.0445844364472695, 0.01738938957362646, 0.021997760838618683, 0.02178947302332569, 0.030967660263300906, 0.0352350113192393, 0.08298925529684752, 0.0410407780098819, 0.05717378147246857, 0.11175915103165374, 0.15271708429340394, 0.14878644037150568, 0.20514086399587894, 0.14845801847836665, 0.17316158079812605, 0.12072139149231297, 0.1326743242961745, 0.13288414045687647, 0.15137215565529563, 0.10095514327047334, 0.14770758939125847, 0.14412534693556447, 0.11030697008414615, 0.13727462099444482, 0.08061096597943576, 0.11543905437593499, 0.14892338624885007, 0.11257372466066193, 0.21161015475949935, 0.181707552063369, 0.16979578882455829, 0.27916305247814427, 0.2186486948161356, 0.1674479591630159, 0.3111730558016608, 0.14590824803998395, 0.25210295773802266, 0.17432658602633785, 0.2599383518099785, 0.20859755996254184, 0.07836452805467191, 0.16666739217696652, 0.1331180271001593, 0.14305769616077024, 0.2652000581785556, 0.1272205367023426, 0.15527587924753466, 0.08349436004796336, 0.14142287985211419, 0.14371628662751568, 0.20027534765822275, 0.11700575780724326, 0.11550806357615417, 0.16406810181515832, 0.1774642523378134, 0.2966999082315353, 0.18680531561615007, 0.27397323580038163, 0.1614554508799507, 0.16601278536742733, 0.1474264657665645, 0.10294334061684147, 0.1432165981180245, 0.16942074282034753, 0.10192448198194466, 0.24470005094284014, 0.20210101179057555, 0.540532088808475, 1.0132019642379977, 5.202766137738382, 26.203766561323597, 34.88048476557578, 44.68624153444844, 62.57028049038303, 77.85516477400257, 84.48011075296711, 97.44744300842287, 91.79975555789088, 83.38227072069722, 89.71609054073211, 86.67064466784078, 93.03814980291551, 82.0312495385447, 73.90528309729793, 74.60395136187154, 61.267794716742735, 72.39638651570966, 61.799036610511045, 65.33755971539405, 55.09367027590352, 64.20794456235825, 56.436509393876605, 52.66655075934626, 55.14053867709253, 50.441339169779134, 55.57227003958918, 56.86576181842435, 78.8347767245385, 77.5806616198632, 77.24576965455087, 82.28292449828118, 72.71639700858825, 84.61577769248717, 80.22294275222286, 70.46501144286125, 77.00054307137766, 83.48611939337947, 79.52092478352209, 85.55790747365644, 84.34883686804002, 79.93165969848633, 82.0371566280242, 77.04649756031652, 88.24892013303696, 85.0452301579137, 89.31167848648565, 84.80246682320872, 75.8966233653407, 56.29567277046942, 33.18220830732776, 19.487407784308157, 8.299103783022973, 2.2219263593996725, 0.7513507215246078, 0.3060906446508823, 0.10104927249372968, 0.12978680101373505, 0.14169344678521156, 0.11377403122042457, 0.15507844306768911, 0.1459506893109891, 0.2673007325539666, 0.11923564823284266, 0.17992201561649002, 0.1789799572960023, 0.19411013251350773, 0.08814805307455602, 0.14626682315382267, 0.12969267945135796, 0.1352171999432387, 0.14469013759686103, 0.16235868386443586, 0.09048517282691695, 0.1201148950044186, 0.12269088097157017, 0.12436789340309559, 0.17066857747493253, 0.14691726244505376, 0.15581004171361848, 0.15601706931427603, 0.1623373406548654, 0.12560669588105333, 0.16152657448284088, 0.1403204793290746, 0.1617723048454331, 0.15957018510708887, 0.14840354962695032, 0.14546051561351747, 0.12920416050380276, 0.19806680810307303, 0.17323653484063764, 0.1971467365060122, 0.2713279341978412, 0.18051053968168077, 0.17452317950946672, 0.2935436872705337, 0.12830530188136524, 0.16765736163623873, 0.1780779347304375, 0.22586823080576238, 0.18186912000659974, 0.1687841697205459, 0.1275980801531865, 0.1063482107354268, 0.2754227660836712, 0.10803613991987322, 0.1573399039766481, 0.1476031256419036, 0.1915437992542021, 0.16508860753909235, 0.11617313514673903, 0.0964127551583994, 0.2239153041474281, 0.13770657200967112, 0.17970786339813666], [0.0883158186690942, 0.027922882112644376, 0.0384122422415643, 0.07823535796975897, 0.06443451384022351, 0.013581607002584685, 0.007137135093686201, 0.01932900353905655, 0.03410646804578362, 0.07997793220584432, 0.09086541290725432, 0.03268291963444602, 0.013663068004403145, 0.04746221126087251, 0.07146125614282585, 0.04319757981706531, 0.01698238046599492, 0.06099557579164544, 0.018398848309692357, 0.022932941604766156, 0.04132407732428082, 0.012958624302559804, 0.03139601641094252, 0.10592631079376706, 0.05875256227990312, 0.058435202696390694, 0.07136829903409367, 0.05716475312628093, 0.08109635928825987, 0.04887806048857109, 0.06723358461092557, 0.01045554213511247, 0.018807644317407283, 0.04477294004191795, 0.03821646081163518, 0.03335462552645514, 0.06522969778386817, 0.02393592498265207, 0.052716528711419915, 0.0301659511657612, 0.13321973293298675, 0.07445799291975076, 0.04264613440740974, 0.06484309917375927, 0.03727811801758024, 0.03771642756257807, 0.017374041002063502, 0.012619479093700649, 0.04600019757485679, 0.05490650212572468, 0.03771623221015738, 0.030196395499872106, 0.07383396067926962, 0.08083624945532891, 0.07257242837259847, 0.2110672129258033, 0.11512724126899436, 1.2305263381811882, 7.203282790799295, 14.588162495243935, 38.90181241496917, 49.26143138639389, 65.12051928427913, 68.4375383007911, 79.5374850303896, 73.1104383160991, 72.68625751618417, 69.83342355297458, 62.17234819166122, 55.61519253638483, 57.51194484772221, 51.098089064321215, 45.617255318549375, 35.022670684322236, 29.639264691260557, 25.81366135228065, 32.54167741344821, 28.35229189165177, 27.570840043406335, 27.121003020194273, 18.57932809860476, 20.354065279806814, 14.348315442762068, 15.943992503227728, 15.418839108559395, 19.18877224768362, 21.92148558555111, 16.177398043294108, 24.069155839181718, 18.13007354736328, 19.663716362368678, 33.94037108267508, 43.41964152551467, 61.30821081899828, 65.00695097830989, 43.752305584569136, 41.99653110196514, 59.33977327039165, 46.77453102604036, 48.25722225250737, 53.427051267316266, 49.694982728650494, 44.12114958609305, 48.3276915550232, 49.88000485204881, 58.40246015979398, 59.91626754883797, 70.67542306838497, 71.98783243856123, 65.30260355241838, 50.353336872593054, 42.534076244600364, 29.35100578492688, 19.783078009082427, 8.286136427233297, 4.228830347138067, 2.221027401185805, 0.40796207504407056, 0.064415093511343, 0.0631026125272676, 0.07930365225840962, 0.06738680219578166, 0.04314964186520346, 0.044419880761134053, 0.027350658483262506, 0.05810080148700265, 0.027267122340779153, 0.031961862358354756, 0.006480692545958465, 0.045517742213222294, 0.05125971293197044, 0.041451328358943426, 0.060170682958297195, 0.024815150686810096, 0.02777706685235664, 0.04120600402295109, 0.031989937565559824, 0.03906933117597815, 0.11663701670664935, 0.019978843366486893, 0.015479344686853792, 0.011495816757932547, 0.05138279644832496, 0.08542584390529702, 0.06017254838239282, 0.03827932981714126, 0.07091454515654234, 0.05604763988465552, 0.09169911575173179, 0.009767549213833146, 0.07824075888962516, 0.03610484670066545, 0.003266122019399078, 0.03310054097504866, 0.06672203706036653, 0.018313561656302022, 0.06766448608569561, 0.06265605221532526, 0.03994542549574568, 0.10155860605018754, 0.02930550993750653, 0.07396234935449977, 0.01703888519607004, 0.06050622563869242, 0.021197080214117325, 0.015736145977561754, 0.012990861282413526, 0.018979774697894053, 0.01810020808460972, 0.011387333919804905, 0.03352994857836635, 0.05377893944481208, 0.04031052767869927, 0.008723821449694375, 0.05244134609857875, 0.03527549906603752, 0.057010853723172224, 0.06640604877423856, 0.09070382198138584, 0.045217225072725166, 0.026397658511996273, 0.07415593211208621, 0.05159564631720705, 0.03250658917691439, 0.047447084854807586, 0.07554678006037589, 0.014352854529035189, 0.057994430178716305, 0.023278960537525917, 0.05787793118807097, 0.0923123844568768, 0.004930472453950995, 0.036056043069449165, 0.04311320672352468, 0.03137931952463283, 0.05668112181968266, 0.019981825363732154, 0.008644397284144597, 0.018441833503123735, 0.1033661138987349, 0.009640009938589027, 0.0635824210551237, 0.09985217584236976, 0.12503314117390302, 0.05717834735649729, 0.02577836261010699, 0.02849009552700145, 0.0017944213909833063, 0.03192069662374354, 0.024558587840968565, 0.05559078718145048, 0.014646681806733532, 0.043691361788660295, 0.04815977645076571, 0.031118792173783147, 0.016319407976322597, 0.0353348976932466, 0.03465293388393137, 0.05977116810578493, 0.005940947214126468, 0.047238808530833454, 0.03028948475877124, 0.0449137470024007, 0.00550559141688169, 0.04564105172551448, 0.02834815284117095, 0.0639187987713564, 0.06173195482622232, 0.020901372190564874, 0.025953835049163432, 0.08402957205450343, 0.29188020395175107, 0.2055228354349252, 3.0550980904409966, 11.362335643460675, 22.317076229280044, 48.30706773265716, 60.115794597133515, 75.11342017881333, 79.74016174193352, 91.02999041157385, 84.3889078017204, 82.56095778557562, 79.711104823697, 71.42171675159086, 67.33409712391516, 66.40940620053199, 61.92638028052546, 57.74701249214911, 46.77386814548124, 41.777466727841286, 41.12349779375138, 46.06519391459804, 44.156901990213704, 40.726624534976104, 41.01515800722184, 31.38244248205616, 34.97686132307976, 25.35031568619513, 21.994204367360762, 26.28193743767277, 28.143786538031797, 29.12486545501217, 24.47816687245523, 38.30637701096074, 25.761554625726518, 27.931533359712173, 39.429233920189645, 46.25196149272304, 68.11992829845798, 70.85949205583142, 45.85691605844806, 45.55512889739006, 67.52763471295758, 53.742676550342196, 55.62191547886018, 60.458166522364465, 58.52531663833126, 55.796817887213926, 55.90826026854977, 58.568203833795366, 66.96558260148572, 71.29577729009813, 81.02671484793387, 82.77449946249686, 75.61323212039086, 62.233450874205566, 51.586526132399044, 37.113250840094786, 27.0679666919093, 12.16569490971104, 5.936622965720392, 3.608414348094694, 0.649981354513476, 0.12860777637650891, 0.015982249808017046, 0.04612904973328114, 0.038430471303722555, 0.044907687246919646, 0.03080154558823955, 0.040114769231407874, 0.050499654119654055, 0.04480289791019694, 0.036867678751267736, 0.022912500463726542, 0.05109386638768258, 0.045769754496793595, 0.042152965306154186, 0.04312488190349072, 0.0315127739562623, 0.05296609717451277, 0.03213580262156264, 0.05960777687329439, 0.050210199288783536, 0.023938265381260745, 0.024286243583886855, 0.02355404164371712, 0.020877853291289463, 0.11046348184707666, 0.04689418004765626, 0.02362142865275664, 0.17826505936682227, 0.027908832060113072, 0.06513029787569277, 0.038112648237015934, 0.07607256918544732, 0.029471829541087635, 0.05673600052813849, 0.04373015265070623, 0.047798397455124125, 0.07761641255309505, 0.04989794185084682, 0.034642028622329235, 0.03841982651201468, 0.022014390692235004, 0.051917717341453805, 0.03685601123218094, 0.037763817761574066, 0.05069974096371763, 0.02062046881614914, 0.026626640277343894, 0.014278570813457332, 0.0357638762873267, 0.04473428707569838, 0.056830202529747645, 0.047596586913230925, 0.07034254560787832, 0.012867060516239896, 0.013515212077407107, 0.005345007896633639, 0.04899467439240506, 0.02670949268635483, 0.15395765643446677, 0.13400869624268624, 0.12512268919137218, 0.12413345517650728, 0.17668629005070657, 0.13809514712662468, 0.08064241388872748, 0.09654190992155383, 0.12443950730225734, 0.16794812264702014, 0.2715412743629948, 0.21487514488399032, 0.0904862913152864, 0.2276919490747875, 0.21990333233148823, 0.15150381552596248, 0.1330083539529193, 0.22758553946210494, 0.20261206904486304, 0.22128933860409647, 0.11423231267760839, 0.11055312179509671, 0.08925432234161323, 0.2126536124776448, 0.21610261692154795, 0.1505196530131563, 0.2490499747856971, 0.22599017668154933, 0.18643287431088187, 0.1422682578765577, 0.1070228660659444, 0.09600708095897591, 0.13787587744093713, 0.12228142229780076, 0.11649520617098579, 0.058589140403895616, 0.09791469351658899, 0.11000232756017678, 0.176350973366249, 0.10195144827687934, 0.24011241001707895, 0.1488757509017183, 0.19676796731448945, 0.15322673194591077, 0.23614366088182698, 0.06841844683813472, 0.15915697260249048, 0.14233430997738916, 0.12442180301032721, 0.15793759045341324, 0.14553093441551732, 0.14872576620790268, 0.15381560841154668, 0.13975859980189032, 0.2823996207406444, 0.5022484382554409, 0.6106143024179244, 4.35844212770462, 14.370329745354192, 27.852358356598888, 56.3738848317054, 69.69126901318951, 86.12275231269099, 91.41668119738179, 100.48368700088994, 93.65684878441596, 92.66966665944746, 87.944379468118, 82.03878048927554, 77.83076763153076, 78.78205222468223, 70.605314623925, 64.03937285946262, 57.33682278663882, 49.81384231198219, 44.53706987442509, 48.133644057858376, 45.38057950235183, 42.64238465216852, 41.93616974738337, 30.590355127088486, 34.964360729340584, 27.14903227744564, 28.739219980855143, 30.854397319978286, 32.77043200308277, 37.64829351056007, 30.856150619445312, 40.7536300536125, 33.6458638406569, 36.13872228130218, 52.14410281950428, 60.94716841174711, 80.5156849276635, 82.8699307287893, 61.75556498189127, 61.49734358633719, 77.75617199559366, 66.73233493681877, 64.99502697298604, 72.52761333219468, 71.85769604098412, 64.76263830738684, 67.31825859315934, 71.6615539981473, 79.26983817931145, 81.3016337733115, 89.64382479267736, 92.60866595852761, 83.66061779760545, 71.72515130812123, 60.24282447753414, 44.977442218411355, 33.14198832358084, 16.326492236506557, 8.544083256875316, 4.805912000517692, 0.9404942140944543, 0.30297619080351246, 0.1885817509384886, 0.1541041171238307, 0.25470650754868984, 0.0726903752694207, 0.12696751318271124, 0.19535956063097526, 0.15073651718276163, 0.09185089309129024, 0.12227491055044437, 0.11353700361665219, 0.2666096599592317, 0.1205747469418472, 0.1578061297656067, 0.14952027599417395, 0.14312076051869702, 0.09020362785386463, 0.1368776189103242, 0.1391599480543406, 0.15071903505632955, 0.216067407520548, 0.1430973335499725, 0.0944308320721311, 0.14106050494217104, 0.19458389660764128, 0.277343746875563, 0.10383359607188933, 0.25485791716604467, 0.1904427776894262, 0.15674506734696128, 0.2225912284226187, 0.15701056277799993, 0.13064442112320854, 0.15808827994811922, 0.11012273359923594, 0.16092482774007708, 0.17123434872877213, 0.12388896587635241, 0.14347838568350962, 0.10416637700531753, 0.1571995719906784, 0.20049049579087766, 0.14985212996121378, 0.22754484487156715, 0.0752401840121996, 0.17837140769247087, 0.13856575493851017, 0.08596683221478617, 0.2762110092707219, 0.1450949690995678, 0.15404768708732822, 0.23459924294823603, 0.1864379611346991, 0.249952947300288, 0.15355351441089185, 0.10840717928423997, 0.19263403430100412, 0.1586452411908296], [0.06435756030822955, 0.05282422535181527, 0.07686597580510764, 0.035222332564092455, 0.020573566998204878, 0.028072625488763856, 0.04357005176585048, 0.022212776821106676, 0.061570352409034974, 0.029133777922740387, 0.03528798246876367, 0.05802003666758538, 0.03408074664372591, 0.04472928452155283, 0.05251051617726203, 0.02288906774934261, 0.005604731812772732, 0.06427048675475583, 0.04633589730327649, 0.04949713614018214, 0.04058138955564749, 0.05154729467786608, 0.03663932709323783, 0.045572054016614155, 0.055268555278739626, 0.03221287489718488, 0.05772249577867408, 0.05612458192533063, 0.0030390008900975513, 0.08443293266839559, 0.038973221615437544, 0.04294027003549761, 0.01515198191027007, 0.06287191664018939, 0.09008047922003655, 0.00998770756151287, 0.034249358765420415, 0.01881116640663916, 0.035134485261815215, 0.039162518111087626, 0.04788771564621599, 0.024683230346249, 0.03221940196629974, 0.08314201322894904, 0.0466372533100507, 0.01588361886059565, 0.037920088206808415, 0.03574817148487895, 0.027051999105981765, 0.06020016202162351, 0.06307876804062436, 0.05796951316897908, 0.10962947256742947, 0.17375039597672803, 0.4487423142117839, 2.2375405796112555, 8.834658322795745, 24.94737844313345, 45.823430784287, 58.08950208848523, 68.34386425633585, 69.67683469095539, 75.49845572440856, 70.28969718563941, 65.99433314415717, 52.37212980947187, 55.419752597808845, 55.322128726590066, 59.4859129382718, 38.309640422944106, 34.39139658404935, 32.51530339640956, 17.693156811498827, 20.31715185411515, 18.84636502112112, 13.184832584473396, 16.328817221426196, 19.470941674324777, 14.383361820251713, 15.543412604639608, 15.031078496286947, 12.792399448733176, 16.443630879925145, 29.171612262725834, 18.925132097736483, 24.627793527418568, 25.805102740564656, 26.677661441987564, 12.22691918573072, 31.357892367147635, 41.83026575273083, 47.03803977658672, 44.096003270918324, 34.221369681819795, 30.613624588135753, 39.52223723934543, 27.55989466944049, 38.484589899739916, 35.166025469380045, 32.9230063192306, 44.439081222780295, 33.57800291430566, 31.612646387469386, 31.818435499745032, 34.80107638143724, 35.44544335334532, 42.773772285830596, 64.8669929658213, 58.40923409308157, 58.29519902506183, 63.36303072590982, 62.05393968089935, 60.64642067878478, 52.54777746815836, 39.351629826330374, 28.8409407677189, 18.689128968023486, 6.717452137700974, 0.8931549446236704, 0.5605648590191719, 0.19315281372156837, 0.19021722608275954, 0.08161051153776147, 0.047362401495657624, 0.05959293008932184, 0.026671623045037833, 0.05335897770560077, 0.01614765872457816, 0.04852482883800422, 0.036262894469884135, 0.04855147720645032, 0.12528954314128046, 0.07619626940258088, 0.03198435853025125, 0.10783282018476918, 0.01632399684298904, 0.031149673178010893, 0.04736391068886846, 0.11150431188364184, 0.03651979439441235, 0.05470986650775998, 0.05416934551190465, 0.04887323413464812, 0.055636706491631854, 0.02987988818917544, 0.04531110914784574, 0.06468062724677787, 0.04565167736502425, 0.029606212854325294, 0.035304878537933675, 0.0310952847658266, 0.0092666320908334, 0.026938139288235578, 0.0234927048140596, 0.07740000037536507, 0.008299776461846646, 0.047628682166818655, 0.15652224301330506, 0.03211870545431251, 0.06678394462552763, 0.010712313739913366, 0.07562867485948148, 0.02814867120656756, 0.10176853712407813, 0.035446669921399124, 0.04619265418319453, 0.05591355151526871, 0.024153735270843874, 0.03153747646138072, 0.03906397622138743, 0.02386198600664014, 0.07942506953352883, 0.011631067665744454, 0.05720003147519404, 0.05234124138951302, 0.026812611951402603, 0.056462947639726827, 0.019568586046056404, 0.03612695599816019, 0.02070855743612253, 0.00837578866330366, 0.08318296062850183, 0.079754946993724, 0.02770578237100234, 0.019096827187064676, 0.01795926897396003, 0.04672423110253388, 0.07375983401171624, 0.04189945915113053, 0.03949962744128801, 0.02622145254375233, 0.0228175476959516, 0.0206100270377412, 0.022118593971695633, 0.0050533946130364655, 0.0611405541008759, 0.08104274079443947, 0.04240177917264162, 0.09295786715923779, 0.06620140370702551, 0.07640364174280437, 0.08429369618815762, 0.0576011014861926, 0.04629262865731313, 0.06065740542966993, 0.07761713267574388, 0.0374867199289222, 0.04271534662092886, 0.05971450824290515, 0.03858809006370364, 0.025466200933160803, 0.0048350590758115776, 0.023982081780089967, 0.04914172879991032, 0.014013181677118186, 0.04806588854520552, 0.03093197588778792, 0.056576615935491945, 0.08483839236320027, 0.023737184538115418, 0.07950953072718075, 0.03155595641733418, 0.010989119501544103, 0.08486172740137385, 0.036682086290731546, 0.06237480218612379, 0.0914203669996031, 0.046481097778004986, 0.0896796083918983, 0.40760765212678146, 1.3938604511560932, 5.601951143433971, 13.729373274310944, 33.046761020537346, 54.51106494472873, 70.54645553711923, 77.41740472855108, 80.86444639390515, 83.26252075933641, 79.18922562753, 73.36165043615526, 62.53343766735446, 63.49342992228847, 66.8547756441178, 70.02657674974012, 47.81589677256923, 45.58995169977988, 44.21292128101472, 31.041690495706376, 32.13755757577958, 29.7032993455087, 27.464543811736572, 25.856332817385276, 32.70613651121817, 24.502691491957634, 25.355546166819913, 19.754456473935036, 24.13334542705167, 20.281509276359312, 29.840703895015103, 32.92933702468872, 29.37826429643939, 36.63131706176266, 27.472076723652503, 14.648567976490146, 30.68155807833518, 39.82970399241294, 50.79953393628521, 52.465078215445246, 44.19279559966057, 43.723833099488296, 47.603076811759706, 36.883427404588275, 50.630526850300456, 44.082451481972974, 44.388647387104655, 56.391194251275834, 42.822193945607836, 42.05188358983686, 40.64332515962663, 45.84985186976772, 46.57431364059449, 50.30595856328165, 73.45479888300743, 64.15820890857329, 68.55319330769201, 73.25947269316643, 73.29899449502268, 68.82852015956756, 61.731658135691, 46.74860023683118, 35.91490399452948, 25.192687396080267, 9.649256160182338, 1.740242509591964, 1.3005506968305958, 0.3366479001218273, 0.1194517999406784, 0.12996099408595793, 0.03290087930978306, 0.06878833707061506, 0.026511681123426365, 0.03128872196670742, 0.015276288294473724, 0.02036287366682964, 0.013380195784022011, 0.0359893627765198, 0.016733534040770704, 0.12902629020954334, 0.02603842456254267, 0.03432962945812652, 0.013826860475444026, 0.03289051030972793, 0.04747565993438325, 0.05436249926025349, 0.05494998527630683, 0.04180515755809123, 0.0574564372730111, 0.07630447166100626, 0.005413651768673933, 0.03234912746495778, 0.028890543091561527, 0.033360011124562834, 0.021616655078926877, 0.007536679632105535, 0.0505286735302258, 0.05705486164398252, 0.00818716919785666, 0.04653754313626597, 0.052322824635813316, 0.07390299286212652, 0.07111044916053934, 0.09897224725254121, 0.09619645789385804, 0.01852725805234044, 0.06216086447238923, 0.07527178513907617, 0.03434590499607786, 0.019081331143576293, 0.04295226697239184, 0.023762082395654534, 0.03177392949920989, 0.0366734333276268, 0.04576142329061705, 0.014993118257412027, 0.040274169145812916, 0.04953466295715302, 0.03386900760233402, 0.05133301222456559, 0.0907982959442081, 0.07636067187113148, 0.038182603555821606, 0.12168324552476407, 0.2882053721095285, 0.18178226095774483, 0.13289520276650307, 0.05130514194588027, 0.3181960289516757, 0.19193683300287495, 0.12152959126979114, 0.10071085315317878, 0.1770615812030531, 0.1429134724481452, 0.1609142404049635, 0.17538011013980837, 0.1457157914316462, 0.16521315811382187, 0.1349820262722431, 0.07350569200371543, 0.14645302848469827, 0.10001617994519973, 0.13374028967753535, 0.15489380055617902, 0.22898576432658782, 0.15484097113292064, 0.13823350260574974, 0.20096387684104905, 0.12247826858994462, 0.22326121827767742, 0.16617007854004062, 0.15575822352642016, 0.1709776939523797, 0.15086509737997286, 0.14076621992693794, 0.19217035192395412, 0.13593169950669812, 0.14287639379261002, 0.10292454848005887, 0.13705391106345963, 0.13834430956311766, 0.19149228750217348, 0.10313068741872426, 0.22661440044401154, 0.17680446677390607, 0.15175636407108078, 0.11943227235948849, 0.17921142310144442, 0.11913614873323711, 0.13227096368228236, 0.17264664713894168, 0.18666179670441538, 0.20626456176321353, 0.2514175695156859, 0.13697164854215038, 0.2776719082988078, 0.6600438274683491, 1.874529510255783, 6.636636603263117, 15.373429829074492, 37.99331303565733, 64.07013993109426, 80.23313306993055, 90.15186586687642, 91.14546498944684, 94.47161136134979, 87.4940364591537, 84.91845915394445, 72.53221035003662, 74.71753535732147, 75.15497376841884, 78.71140249313848, 54.57552909851075, 51.44942360539591, 47.35792867598995, 31.583534556050456, 34.50391761718258, 34.79392590061311, 26.633862295458396, 26.262009836012318, 32.654192563026186, 24.154071231042188, 25.435560557150072, 24.29607475957563, 23.83364300574026, 26.93609464553095, 44.38073988883726, 31.773830306145456, 35.89327604539933, 39.09188262877926, 42.39318863038094, 25.398645170273323, 46.97321476474885, 57.4574552812884, 65.5184555053711, 61.4259054583888, 52.653595170667096, 47.133698540349165, 55.628183426395545, 43.116575671780495, 55.92202386548443, 53.87244816749327, 49.776171868847264, 62.140373030016505, 49.85753751570179, 48.12131604840679, 49.29019412686748, 50.953377139183786, 54.43380994181479, 61.097999234353345, 84.41496018440493, 75.67665684607722, 78.07018126210859, 84.57015268264279, 83.85669708251953, 80.87661358617967, 71.59713299043717, 55.937089689316295, 43.71414876753285, 30.91175610019315, 13.222578533234136, 3.256372799796443, 2.395917061836489, 0.8250063982221388, 0.3752185884983309, 0.23556089779782682, 0.2089411810400986, 0.2595733875228513, 0.09056378110882737, 0.0922142179502595, 0.1454903011120135, 0.09761471646807848, 0.13317350718763568, 0.11579296401431484, 0.24204436118804643, 0.18968295636436633, 0.16533682002655922, 0.17391689752619113, 0.051515651416153684, 0.12795870838266227, 0.2208765091434602, 0.19284886067673085, 0.08521218964409444, 0.13163800651748336, 0.15704652294516563, 0.1370851368072533, 0.2022103938244043, 0.16113715666917064, 0.08200939053729658, 0.20472835629217087, 0.149877977767779, 0.16949707582112283, 0.1208116366497932, 0.09949697151539788, 0.05444902889130097, 0.16909523206132074, 0.15593370362635584, 0.10016064880596054, 0.126139939041628, 0.1435572161309181, 0.38349243001111094, 0.06515790768448385, 0.2574729276520591, 0.20695903578833227, 0.17109557956216798, 0.18843686839024867, 0.21211517524094353, 0.09909760988047046, 0.11057988124629183, 0.15503390271577144, 0.09295746879351717, 0.14817056696741812, 0.10287582528807464, 0.13177447742031467, 0.1220103420857941, 0.18966928935579716, 0.20400371372459397, 0.17004944053628754, 0.11548197828233243], [0.033854191461878444, 0.08141159680822203, 0.08237784052447927, 0.04541575675830246, 0.07007220850115822, 0.0016107938262716597, 0.14086365098914794, 0.02780066044520467, 0.016156713883843155, 0.017707611006053708, 0.07763633850000559, 0.04077172026999536, 0.06366293689596557, 0.036567471876379945, 0.03856054537238614, 0.08434511600963532, 0.02704977936622116, 0.04017536295577884, 0.04259783639422348, 0.1165456070955242, 0.011332107598953431, 0.05931108634197905, 0.003766542382260424, 0.04383578851458527, 0.05214989177822586, 0.03013855586158893, 0.06517991739054842, 0.017554676873729597, 0.0658418096962475, 0.04291600803093564, 0.08057156607749001, 0.009990313218065329, 0.12492652471748092, 0.029906157344099016, 0.08318217921881907, 0.11608098243032733, 0.053113415882351904, 0.03990230623692755, 0.0655917662586416, 0.03206206091319121, 0.06913981821027494, 0.006967099484867387, 0.06064649633762818, 0.028910333057865504, 0.009908956595726553, 0.04984248091556853, 0.047848599196802226, 0.04137265495955944, 0.031332440689326294, 0.02296791734894918, 0.13214770013526564, 1.4522142876540463, 3.860208940121436, 4.9091566281933945, 22.069629584589315, 34.02100324630737, 45.60663746249291, 64.07657654054704, 69.21746238585442, 74.05703175452449, 66.9274571634108, 61.91693129078035, 65.58145661507884, 56.61163145496, 51.306927819405836, 44.59238313859509, 38.06706536200739, 35.26723046456614, 28.83160552670879, 43.26355472687752, 23.101987608017463, 16.08519881002365, 13.97622077695785, 9.591677727237824, 15.411650384626082, 22.208689374308435, 30.511795936092255, 36.65835395936043, 24.591182124230173, 27.730815872069332, 39.87861987083189, 40.14208547530636, 31.163129037426366, 24.77955395175565, 29.357854243247743, 39.89787086363762, 25.989440410367905, 23.811169785837976, 29.71090089890265, 32.880630993073986, 37.19638939826719, 19.567767343213482, 19.899382168246856, 25.09123136920314, 18.524163884501306, 14.134651191772955, 18.302950051523027, 15.07002272913533, 20.58373574287661, 18.716714997445386, 22.363011106368035, 21.75293153332126, 28.257384261777325, 27.25876842775653, 22.47443191466793, 23.182698219053208, 32.337863214554325, 39.338901735121205, 38.23429953667426, 50.200246764767556, 46.37839909522764, 59.122999560448434, 62.9767047205279, 58.38662162903817, 51.08013245367235, 49.564744349448915, 46.6679641508287, 37.5494223256265, 25.60914504912592, 11.928182648074243, 3.31211164113014, 0.42837696991139845, 0.5811718274508754, 0.03635011741050309, 0.051456088080040874, 0.0456063709251823, 0.05717547835722085, 0.011117511049603984, 0.04077846950460826, 0.025663819058888385, 0.017573717989087585, 0.02960560189920568, 0.04651948261345106, 0.025605427837299726, 0.147495137888097, 0.056335110547802145, 0.016077488901153687, 0.05125564117465289, 0.05899398339792125, 0.029082331288185333, 0.11756965980654764, 0.05382081381075325, 0.07223549524262067, 0.04281254019588233, 0.012236203389963316, 0.007263205874140465, 0.05511328457824646, 0.024452605322303794, 0.004636018420569599, 0.01944675699867789, 0.043221378338433085, 0.1228288380849746, 0.035411326455012444, 0.0656558571743869, 0.07982811605137202, 0.05502873911492287, 0.0490974833918435, 0.04708861699327827, 0.040728509080626314, 0.03834463498224655, 0.03030770999048987, 0.022073389038503654, 0.07109484394952174, 0.08598996807009944, 0.02140331682899306, 0.01885284350493983, 0.03199881269416261, 0.1409117153455173, 0.09532685616924878, 0.04836244118069449, 0.05182060420573239, 0.03011738310658163, 0.010869278452329097, 0.10900865023535107, 0.027649721971923308, 0.03788977027720502, 0.06478127587826983, 0.04817950704525556, 0.026133520971803416, 0.052676175030008446, 0.04265914641080364, 0.04597780865526969, 0.11829214200617806, 0.043425854866302786, 0.024038069400816195, 0.04568129049373731, 0.02860841972212638, 0.029896753614828474, 0.0551227955598264, 0.01973310917345507, 0.023663477303700584, 0.07165091653023997, 0.03427960391667101, 0.055430027460979844, 0.014122704479603038, 0.0499617071792243, 0.023837279671082096, 0.06756833439031917, 0.06429882434707496, 0.06080193174702506, 0.03177203151637749, 0.014831883562428337, 0.04577157012517414, 0.039117456819381446, 0.12566175462017137, 0.030976692439928174, 0.04090249147867003, 0.041305802296847105, 0.04758040713627012, 0.010198948645753967, 0.07262891969613491, 0.05121606890292418, 0.047070322813646454, 0.016715419891801093, 0.01441675488040933, 0.10998984032701101, 0.07184116680535578, 0.041560028574519584, 0.038335097187589255, 0.028482878978754726, 0.016481209576370257, 0.03791535761387598, 0.025951161402307694, 0.036449992293191534, 0.04609553721703349, 0.03484185882693818, 0.31854686657747916, 2.1753080093091537, 5.604095699325685, 8.320900394070534, 30.305849929009717, 43.58521653759865, 56.954795698965754, 74.01386214840797, 80.0141392984698, 81.43850880284464, 76.70623979260846, 71.43592357635498, 74.9220085144043, 64.53085368679416, 66.02481780513641, 57.81269650305472, 53.22381365683771, 45.59713355956539, 41.05556626473704, 47.86514605245283, 37.78348976565946, 32.292791258904245, 21.989909372022076, 21.531045013858428, 26.266716680219098, 31.4738650860325, 32.2435341342803, 41.051306570729906, 24.127497173124745, 27.574627091807706, 33.706778249432965, 27.952751421159316, 28.505923286561046, 32.9883804628926, 33.98376818626158, 39.40554672671903, 30.95597690151584, 37.2417986777521, 38.687121483587454, 48.976737914546845, 50.19945052362258, 35.4680440502782, 32.56611181843665, 35.20812426843951, 24.28876542275952, 23.278457003255046, 21.414113275466427, 25.11689151487043, 29.639547101912964, 28.86417296624953, 33.1807727198447, 34.165495518715154, 37.63502020989695, 40.23261377888341, 32.46483818177254, 34.787716788630334, 45.49097461085166, 47.311354452563876, 46.19565979126961, 58.8632562852675, 52.93885346381895, 67.48759515823858, 69.9332949423021, 68.27899609842609, 61.68421706845684, 60.406461838752996, 56.921506543313306, 49.572090948781664, 34.641937978806034, 17.223488284695534, 6.274041918016249, 1.5707814092597656, 1.038154305950288, 0.05512829607112273, 0.04271168855109042, 0.05410204085731699, 0.06886532124612602, 0.01935151311749172, 0.04085834949247299, 0.0101366542061911, 0.0331637968549565, 0.008975871080051987, 0.034457646580713416, 0.01708911758126511, 0.07461262776726678, 0.10060742362252167, 0.013100466439350238, 0.05297668834006595, 0.050260439334857854, 0.02278720486849066, 0.09066770859663525, 0.07516506143034467, 0.14410460127457497, 0.057325899721153324, 0.05561996747048632, 0.030937447670787096, 0.041002845166311155, 0.04708912261130829, 0.07689631288690914, 0.05045864543306732, 0.06797746364628116, 0.07908384631117506, 0.06298114162599368, 0.03852879485836433, 0.01437484316768185, 0.046638743351063425, 0.024818967719892823, 0.018054692885808406, 0.027388491735403097, 0.0749266395465501, 0.036586635565805825, 0.09793706328397798, 0.1004587565999358, 0.08461343064423531, 0.041315209856557275, 0.031524500847163225, 0.045935110744809916, 0.033085556295249736, 0.038482756804554694, 0.035543196999858466, 0.03492618978564297, 0.05271666660724629, 0.05922829905044168, 0.042644012343859485, 0.0274102371411338, 0.060610206752655015, 0.22753045774034916, 0.24650628708543318, 0.30633603793478786, 0.12012541339161897, 0.14246567873464477, 0.13011568255962866, 0.2692364835210385, 0.24187283410180002, 0.18298995260509754, 0.10749410973080706, 0.1838587882417825, 0.09911271713433728, 0.13842139333005876, 0.16552904680851968, 0.20370140010791443, 0.19891886641421627, 0.1682402013290313, 0.15930052215774215, 0.1106721718585299, 0.18625244528295534, 0.1294403913761339, 0.14347408026937516, 0.12566576126001536, 0.19052343142609443, 0.12721220166572642, 0.17198508425105005, 0.11106828528065836, 0.2245150437398303, 0.2362470061428124, 0.14319652661440835, 0.18956571426843444, 0.1493179521733715, 0.21627668741970293, 0.17435882300619157, 0.16782021660718227, 0.1638757371373715, 0.09774649125193396, 0.1602428409481241, 0.2142353848584237, 0.21225273398862732, 0.13860986628119024, 0.1226628038491453, 0.1969182584434748, 0.09144734861629625, 0.0817336678324688, 0.18063125981678887, 0.12533514835541287, 0.11355813232160385, 0.1978950052251739, 0.19752596535028952, 0.4159338021230313, 3.4578627492150957, 7.508722168783988, 11.327379480484995, 34.43670388190977, 52.4385041575278, 71.4658591055101, 87.00888633728029, 89.48969133438604, 90.90461577138593, 86.73938028274044, 80.45985391063076, 84.49241915056783, 75.13103946562737, 70.56234898105745, 63.072571369909475, 55.55801222401281, 50.597371055233864, 45.6347922355898, 63.33291476772678, 37.83270766658168, 29.02796918346036, 22.795605390302597, 22.563734477566136, 28.488925695419315, 32.097941637039185, 43.154034306926114, 48.10967053136518, 35.65514502986785, 41.11836341119582, 55.81852036137735, 56.71729226266184, 48.95239568525746, 40.19501001604142, 44.37230679296678, 58.03754245081256, 40.242019622556626, 43.12556574421544, 50.86817149193057, 50.29536424144622, 53.514547578750125, 34.54039173741495, 32.71290848332067, 39.196025479224424, 29.49743178582961, 26.288038684475808, 29.48293470567273, 26.920485573430216, 33.412004286243075, 29.427501809212472, 34.639223698646795, 35.008675667547415, 42.164443846671816, 42.57512777082382, 37.43828196679392, 42.430761014261556, 49.36358167279152, 58.51417318467171, 56.895673813358435, 68.82369564425561, 61.99173873470676, 77.07120064766177, 79.47124404291954, 77.55352666301113, 71.58337331587269, 69.45794290111911, 65.68379125287457, 56.84645199006604, 42.313078141981556, 20.993801893726474, 8.8025095962709, 1.8879691439290203, 1.1801924003708748, 0.2435597597110656, 0.22214557975530627, 0.15935574177532427, 0.1469912205732638, 0.0651718964499812, 0.10316495453157734, 0.13966046393879, 0.13604952382945246, 0.1345933898682556, 0.1561382797456557, 0.12949738831770036, 0.23354205693448746, 0.1612902210364419, 0.09680420310506899, 0.19305867683743277, 0.23739089798783106, 0.1269947476084194, 0.2659653187278779, 0.2236776789950748, 0.43984830920254037, 0.29838677255376694, 0.11342064252183323, 0.15214530691023798, 0.08466833616576849, 0.12903813392885272, 0.1936806636231561, 0.13651994778023613, 0.15774815223149716, 0.25798540982988577, 0.15030930059090739, 0.17622899684694507, 0.12528196653170934, 0.14386219573357414, 0.1609033772781972, 0.1666121572376259, 0.22169967061809956, 0.1597115742943941, 0.1547321100388804, 0.18574049936667567, 0.15562392831329377, 0.1758756004874745, 0.1160019604609378, 0.13244900251588515, 0.18585352797902402, 0.2844099273845073, 0.12224055150704038, 0.1812919953297223, 0.14295816601764771, 0.15153678795022352, 0.22125379212440985, 0.2230671682064572, 0.10194512805150402, 0.1839653970373254], [0.023264937298071962, 0.020889001785807555, 0.03706277836294424, 0.052309919884728814, 0.054856821323835084, 0.05274576262661046, 0.04835270037273726, 0.13507528981614497, 0.06522621208381268, 0.06623957020741317, 0.093043347249829, 0.08789127572409569, 0.03539899243943153, 0.07093352115442676, 0.05295619165765182, 0.06656053040416972, 0.05054798277635729, 0.06355096165451311, 0.03849434005396982, 0.07677456619398249, 0.047982465400690996, 0.018827978206137498, 0.02542136563739229, 0.0357865524898854, 0.03722154242437213, 0.04275525980178387, 0.038782408265697385, 0.03543978662139947, 0.06443682742575485, 0.008541469541077894, 0.06787234872219063, 0.01574315376684911, 0.09615069180126153, 0.01406890212468082, 0.05743655729137602, 0.11349486111993752, 0.05251797021276528, 0.05570274710114445, 0.02834618974086498, 0.06661209578235304, 0.03523332592580588, 0.04504878532081362, 0.06422612260306074, 0.05022485455077502, 0.03353723407452626, 0.04144392794959488, 0.01400310091764456, 0.03617798128435689, 0.46231693257727935, 2.485313516470694, 4.8042587214900605, 18.797398151889926, 25.841888689225723, 41.18571050705449, 61.78344126670592, 73.95705838357249, 74.18854882640224, 70.8324041674214, 64.69751519541587, 55.66690898710682, 50.99489542745775, 47.925444649111846, 35.922368264967396, 39.717849762209006, 25.50853233183584, 21.724890508959373, 18.345737226547733, 24.738888778994163, 27.46028215654435, 26.5895002888095, 21.547397375106815, 12.013498121692288, 24.819036529910182, 22.41574345096465, 28.741563597033103, 35.13501913316789, 52.5312368331417, 50.243443827475275, 37.45525798489971, 33.30320950477354, 28.966293834870864, 37.24098282475626, 29.50673172550817, 30.5266381848243, 48.41931027750815, 43.25975787255072, 39.947233892256214, 41.91451826403218, 27.44697747691985, 22.724567344111783, 24.262581640674224, 34.04673399463777, 36.45831308057232, 25.32853476462826, 40.07397743963426, 35.47612413283318, 31.927718616301018, 25.816256000149636, 22.691044807434086, 24.84518304947884, 20.1018843343181, 22.49178448031026, 26.130875195226363, 16.369232343089198, 27.79117918783619, 19.593347080292244, 22.36857891082764, 35.82082594594648, 36.91228035957583, 35.66963034291422, 36.613207478677076, 39.6803322915108, 50.57043613926057, 59.540206386197006, 66.57682080422678, 61.24949293751871, 63.35588416745586, 59.06559959534676, 61.331348880644775, 49.65896752572829, 27.1439233902962, 14.21299563300225, 6.8795489880346485, 1.5660743199048506, 0.4165670197577246, 0.26262839294729695, 0.021121949971383138, 0.04376766414591863, 0.03338569805266396, 0.03605197897301086, 0.014441617306381946, 0.02935000049370912, 0.04596745114653342, 0.03139959787198853, 0.06379054033107336, 0.036577090110269286, 0.037753525370311354, 0.026008284748381665, 0.025940564491095084, 0.05969717167317868, 0.039490150933664654, 0.061128610790136366, 0.05066096542343017, 0.04430674106603669, 0.014925488015456546, 0.05219730495985958, 0.03388080918680757, 0.10020365698202964, 0.07236068167032735, 0.02982277824964014, 0.07687546763448946, 0.035779378076474515, 0.00864093648194666, 0.024562270808664542, 0.01817883551871825, 0.032267316935523864, 0.07676416271997076, 0.0115718538572471, 0.07058855942300252, 0.05861776144874673, 0.06529552771920158, 0.054052781403785756, 0.0434273257551174, 0.01748686851633172, 0.05607311230813784, 0.032642389752811966, 0.04106355763431038, 0.016340971436171282, 0.052915431949640476, 0.04876875889397437, 0.05852227624986441, 0.06188012772209703, 0.07466962470883325, 0.03496034964618664, 0.03940093233400295, 0.03263318137596211, 0.022139033197515437, 0.04012005140764579, 0.07943160426352294, 0.01883978745149028, 0.02576405208768143, 0.045386668399817524, 0.0645832191672056, 0.06911099798256351, 0.036483562266033505, 0.04957096020300543, 0.08342466136861233, 0.027874080396647898, 0.028765458170504823, 0.08246748047249933, 0.0864045518720823, 0.009936165165967278, 0.0678651858000986, 0.031422128517841624, 0.020727671329833327, 0.048829804610220656, 0.03555803229251216, 0.024581855846448772, 0.035933369410134135, 0.04390342258698037, 0.006879265110323867, 0.07174605698955637, 0.01780751078659969, 0.03733099340611408, 0.052798220497225566, 0.06434955468942082, 0.01856666944560505, 0.02372691704471025, 0.03220647423257751, 0.0865680963221577, 0.05489957669088918, 0.07177267088404587, 0.06764036963783926, 0.04674057941883803, 0.10439592759094893, 0.07064316617024523, 0.02873540262601549, 0.026824114761585673, 0.03705626661558786, 0.11887955524387861, 0.03030159277841449, 0.06902813025179409, 0.047466141291924065, 0.03826635611814357, 0.6590455842594947, 3.6574623613588275, 7.340213223811119, 22.345515374214422, 33.071613157949145, 54.07721550233903, 72.09026121324109, 82.64000923402848, 85.48673998924994, 80.36237516710835, 76.46695167787614, 64.65998987997732, 63.15027744539323, 56.81688124133695, 45.63352531002414, 49.25862296935051, 37.475309141220585, 37.34205053698632, 31.508787908861716, 30.174219108396965, 34.930145894327474, 44.23050134412704, 28.42472630162393, 17.514516384370868, 29.079589536113126, 28.033634616482644, 33.31616117108253, 31.613209247589115, 52.16183585505332, 43.90825902262042, 28.15913477251607, 28.566847501262544, 26.833038291623517, 30.17253641159304, 26.087293740241762, 26.293104425553356, 33.65682686528852, 40.555652341535016, 41.82976761171895, 40.48415145566387, 35.45941483589911, 28.771469708411928, 30.485412113128174, 30.84620741105849, 33.34899140942481, 32.88815802143466, 41.197763950594016, 36.00727188971735, 35.83382468069754, 29.681830252370528, 27.064813106290757, 25.594900961845156, 30.001289652239894, 29.48980473702954, 29.747061229521233, 24.32534936935671, 33.67854110656246, 31.540009975433353, 27.914982918770086, 42.833321709786695, 47.55721253733481, 43.540450526822, 47.15080791904081, 50.70523623497256, 56.52224848347326, 67.29820743683847, 73.84151320303641, 70.44476416803175, 73.65762464461788, 67.41787110605549, 70.93793945927774, 61.12104708148588, 37.05210501147855, 20.531858474977557, 9.404100179672241, 2.4795934750187785, 0.595813115998622, 0.22644861901719726, 0.059164024273594545, 0.03360419015910837, 0.020020995439300616, 0.049430287307909423, 0.08328664296817395, 0.006974711526005019, 0.051006570668710824, 0.06166219102939772, 0.09523464216580314, 0.11557803038627872, 0.029533137642447988, 0.02716012667083452, 0.0676334135594868, 0.02423362675002746, 0.059774826175623366, 0.08301285080491536, 0.05513030705192397, 0.05235881161605639, 0.043877819928550915, 0.028951755431931347, 0.06456212110577092, 0.06105814602286105, 0.06291589391748272, 0.030244327706074527, 0.05954831312861174, 0.045943403646590254, 0.06225633817995268, 0.026675775241587433, 0.019498669031646945, 0.034542211196235115, 0.07435801844563215, 0.013086708457840067, 0.024281250605840358, 0.07537228821386253, 0.07831071803887045, 0.06131282429240885, 0.023371222421466824, 0.03549503305205896, 0.03243227098737994, 0.06048895418643952, 0.06434871965358335, 0.03683215908465847, 0.06769654686532675, 0.12130879706913426, 0.018525582235006076, 0.04123959697843079, 0.0784910244927291, 0.01087134784733456, 0.029498929901409055, 0.053421781593633276, 0.17036964996687828, 0.14486575559262307, 0.18273365022915025, 0.11014138017931294, 0.11505237915703367, 0.15429168609121155, 0.2072974627897624, 0.3709925717163471, 0.17356628972676494, 0.17323238264408805, 0.27201974223698344, 0.1542041069197078, 0.11745590341067123, 0.18221868592644894, 0.2156259723368191, 0.22766983977729277, 0.23482942172596533, 0.15144539366085685, 0.08548231224619574, 0.18726941168067918, 0.11974482857171567, 0.09015826778786798, 0.10249999021330189, 0.11074075971039073, 0.14321099035441875, 0.12538530413181553, 0.11394109201407242, 0.18458188331175238, 0.14473950430270166, 0.24419965763245863, 0.17407311817571042, 0.17212112614464375, 0.11998976986374586, 0.21504334714864531, 0.19094035179624635, 0.24091980540223662, 0.17750001332211882, 0.15964806560547123, 0.21911533429257332, 0.16297320895377668, 0.16013566524751727, 0.11941454508492064, 0.19729318187361766, 0.2235718362874562, 0.1770857282944264, 0.13002126988384033, 0.08605014427655167, 0.2865639521229652, 1.2128400033520115, 5.823719501495362, 11.621796507989208, 30.06404365262678, 41.745844579512074, 67.4463475135065, 85.55545206992858, 97.12959766387941, 91.0939956480457, 89.60425592237904, 82.7596729032455, 76.16986351628458, 68.35950666858305, 64.86150949232041, 51.81988754580098, 55.22561096375989, 41.464583181565814, 36.68481819091305, 29.75817918777466, 40.00278642100673, 43.30952490529707, 43.22061261823101, 31.680242553833995, 17.824060032444617, 35.04299248418501, 34.98699280523485, 42.13548498768961, 48.38910018244098, 67.6132365195982, 70.14548732388404, 55.417846325905096, 51.588114692318825, 46.814700018975046, 54.528260615564164, 41.65873266035511, 43.2732351364628, 63.93847773152014, 56.157177802055116, 57.62056312253399, 57.75084857017764, 41.267119299980905, 37.15837378655711, 38.27581782494822, 46.15316091045257, 49.99261217732584, 39.06786595621417, 56.993780136108406, 51.80259773808142, 48.78194516704929, 37.48709978595857, 35.38436420502202, 35.524333984621116, 33.6604001445155, 36.59230909039898, 40.68708704363915, 27.45284338151255, 41.87596528760849, 31.93250390791124, 32.799312414661536, 53.02613404489333, 55.43766606238581, 52.081666531101355, 54.393911592422, 59.116829672167384, 68.69594404774328, 80.93464897524926, 86.8093082981725, 80.55791316493865, 85.13167919651156, 78.78265626968877, 81.21593782978674, 69.1699154146256, 43.92858082248319, 25.466743400019986, 11.787783368941277, 2.9390846769655905, 0.9558660440867948, 0.48716732330860635, 0.231133614396376, 0.17420935925216446, 0.10436362932406126, 0.1413776193775477, 0.11297071908390331, 0.07226494366243001, 0.17560636654736536, 0.11730895242503575, 0.2578764108400191, 0.3109900220747917, 0.13416925294985696, 0.13743770579176565, 0.16710409293732337, 0.2408465827184339, 0.24631274263224295, 0.3202567748244732, 0.21652293872208367, 0.23061409953140447, 0.10703092531090784, 0.08272087171433434, 0.15773240146377396, 0.1798032107011926, 0.21664611033854947, 0.10419183410704137, 0.18368744501663795, 0.12494560796767475, 0.12814198725766715, 0.18572007546261435, 0.13927574990497482, 0.17909200531580757, 0.2196686183132472, 0.13062975820033781, 0.14962667028509802, 0.20634400508096143, 0.23742595417124612, 0.28825366629227517, 0.17674544736021952, 0.07574718100048843, 0.15835769774933017, 0.11071528728690841, 0.14657005607601137, 0.17519975772067425, 0.1754069998259506, 0.20889334651010655, 0.1058088388714579, 0.16074807593418708, 0.15675087429342732, 0.1452355155901563, 0.17057998706736874, 0.12295989274618127], [0.054035892995494994, 0.016773816859049183, 0.07044719321833504, 0.046876816664852446, 0.005905622421132942, 0.031133185050660567, 0.059454245192389336, 0.032035588744967695, 0.039221047228502656, 0.056444641968776146, 0.04933185650095825, 0.07913972476437207, 0.033930842389142325, 0.12147988748526382, 0.06548409260088398, 0.06808846212563015, 0.060913592892428564, 0.024319204516829025, 0.06753685583751048, 0.062287763106606664, 0.03583110050268231, 0.04538223658117556, 0.0814737648432774, 0.052197619055908535, 0.03896138555700741, 0.046937785772306305, 0.03433411873336281, 0.03459345098705061, 0.021488469416996645, 0.03605543402954936, 0.025753870779167742, 0.030925422005595702, 0.028096636599530617, 0.02888761855091059, 0.04093958545596369, 0.038791674099141554, 0.05871682810867506, 0.07947999803769974, 0.06596050735923552, 0.0178034677575793, 0.14837112878599476, 0.011881484571213444, 0.0431951436574661, 0.08763469755649568, 0.041937292403271126, 0.07789466334807296, 0.1696453138344711, 1.594338796792492, 7.0158538030039885, 16.052195006801238, 24.85586170227297, 41.47580900499898, 67.14816893300703, 80.38268519986062, 77.39394111018028, 73.35245640047135, 68.90249606101744, 56.349209200951364, 50.50087682662472, 53.167064805184644, 33.2007924972042, 31.754151774990945, 30.777662031112182, 30.3661387197433, 25.55488886371736, 14.054707404105896, 23.102574002358224, 27.1657141177885, 18.94187277363193, 11.991264166370517, 29.927900145130774, 45.17744387349775, 40.91241936529837, 36.909581768897276, 36.87743402296497, 51.73265795553885, 34.85384402736541, 31.19644957204019, 22.772481056951708, 25.518163711793964, 18.891848825639297, 10.56302426322814, 18.24260634760703, 23.931153128224036, 34.84725052310575, 23.892917863784298, 22.790737728918753, 29.15741328270205, 25.562923839015347, 29.075961343703735, 27.278376356247936, 32.64489066216254, 37.744277831046816, 30.135662209603097, 32.022053580130304, 31.335113202371907, 30.542066827897106, 42.29281517767137, 39.209930281485285, 50.57484880570443, 30.41617443484645, 39.51569080352783, 47.281191425938765, 54.78917667942663, 63.570512340914824, 36.92260011549919, 54.61883206521311, 31.249882059712565, 21.713735288189305, 28.696156278733287, 18.17568090654189, 31.236781343337032, 32.882788296668764, 28.8524313511387, 40.01237661607804, 40.95506729618196, 54.088672745612364, 57.852900797320956, 60.565631620345584, 61.82836024991928, 61.53231936116373, 43.98956975629253, 26.8871924954076, 14.710638503874502, 3.8493341688186895, 1.6200082580889426, 0.15149405556580714, 0.07917621353220555, 0.05500659917391116, 0.048670768587579655, 0.05224965174772567, 0.021793583085039453, 0.05141604849467835, 0.045473148235149925, 0.057233927035403837, 0.07952378762345161, 0.03599932574997506, 0.007987354315006205, 0.06286519421865383, 0.05444496862530228, 0.045942840571965904, 0.01528284887993528, 0.029775112258991408, 0.04663001377916625, 0.02390306747157968, 0.03707536518754017, 0.03924520581119484, 0.01193157618775243, 0.0535115939114363, 0.047782332591351964, 0.04007855625522714, 0.05014656419535318, 0.04397924996972565, 0.14106519340026763, 0.0610475969921437, 0.056487378183632135, 0.04939293669116113, 0.024835930821756204, 0.05490730268760555, 0.02094053269003428, 0.030900709924378225, 0.03967475514077852, 0.06740652129895265, 0.03919769303813096, 0.010848098994052459, 0.035010237291815786, 0.051826215799777746, 0.05082352545052286, 0.08730669701171499, 0.05911355440114295, 0.024676262776577668, 0.051710609301564195, 0.010059316672625081, 0.05930594589200713, 0.018844247998429403, 0.02826158682094707, 0.06673977199581362, 0.05589369451627136, 0.03692399004414197, 0.04197495328562875, 0.028354522862261342, 0.0038870171298302954, 0.054033249992156224, 0.01466161860603719, 0.045522809884841406, 0.026096833021109624, 0.03522068164461563, 0.1040077125353198, 0.01270259771826527, 0.1495668694617287, 0.021578279819579858, 0.043044335419131864, 0.02571289082087817, 0.010754449533358698, 0.013456903210270309, 0.01429059552103882, 0.02258027494404345, 0.010954713535254762, 0.061767941806465394, 0.04769226363409431, 0.05660652783849547, 0.06742564285354269, 0.03866698945902529, 0.049984329755628304, 0.008581252486985779, 0.047173246726273536, 0.030203590980700912, 0.011715286584090323, 0.04743828633499723, 0.05972671968441817, 0.06617449103824555, 0.06245445617805086, 0.08055272031455271, 0.011369244668692833, 0.08421132641453898, 0.04817912400129342, 0.08741188088371869, 0.04480902278315156, 0.07372272471266408, 0.10502332295741766, 0.012805384692675885, 0.009637207972005972, 0.2449757659867887, 2.3344537663844327, 9.23208365517278, 19.656034400386197, 29.592002091869233, 50.14493742296773, 76.32660927311068, 89.31673834400793, 86.5205120271252, 82.68155497889366, 79.71070474193942, 67.22030916521626, 59.639285456749704, 61.656497678449085, 42.086447515795314, 46.77216191445628, 42.37977804676179, 42.9623951450471, 35.57923539992302, 25.983499980741932, 23.86714985293727, 33.61837979285948, 34.553292412911695, 21.183687756138465, 30.035596662952056, 30.78781116393305, 37.01786664224441, 33.262467845793694, 27.79995941346692, 31.415304099359822, 28.55845755146396, 25.290950613637126, 20.49503722498494, 19.547249424842096, 12.361365287534653, 9.420180916786194, 13.572400020014856, 19.444495093437936, 24.28165416563711, 20.55771670033855, 19.110030666474376, 25.20691775506543, 20.869319592752767, 24.517223873446067, 23.99527995817123, 26.82729790287633, 29.838028838557584, 27.064156109286895, 31.905402291205625, 35.663229034793, 32.081373545431326, 35.81491101172663, 37.514101382224794, 40.00288840263121, 28.908411418237996, 38.93104976223361, 46.086955224314046, 41.46202187384329, 51.967352974799375, 31.922425377753477, 48.26135250829881, 43.22832399798978, 38.432159577646566, 38.415595408408876, 27.6398168840716, 35.986620610760106, 42.24003968700286, 38.72523123218168, 48.244054855838904, 49.8431267276887, 62.71509047477477, 67.23644579610517, 71.15146544671828, 69.6789841498098, 72.83365234251946, 55.62756761427849, 37.18803082742999, 22.495038086368194, 8.573856988260824, 3.389120270167628, 0.26598033405119376, 0.053363286950174844, 0.023857607814152876, 0.07742962499539699, 0.0883018222427176, 0.046730685393295945, 0.023016810995496573, 0.04731236063244362, 0.08893677123611973, 0.04545502259486145, 0.07935782233553548, 0.027305551226280873, 0.05428357688229411, 0.03481765044853091, 0.07734468882723201, 0.022487999653563868, 0.014707487162893579, 0.01765880737483742, 0.02755983879098729, 0.07466744901912828, 0.022636377477958318, 0.04825501267107264, 0.040416650008410215, 0.08612849974944707, 0.02811335263803842, 0.03402723157177529, 0.010629733292115553, 0.05546423328679897, 0.025837516089180307, 0.08407035857559213, 0.013349525453973443, 0.023562526067478523, 0.02285171521737451, 0.060334970513659145, 0.058870888390247865, 0.09093030821532012, 0.03547928994521499, 0.07859707404408725, 0.06660978985770095, 0.0052979490306649, 0.05321633596453936, 0.028823698089728435, 0.07145181027871948, 0.07336257145770135, 0.03851025553059675, 0.034105759414453665, 0.030684853160393336, 0.031676944683215795, 0.0702737432513987, 0.08548553747635695, 0.19580471900201615, 0.22082605459276708, 0.24376107229580804, 0.28295206206460155, 0.05260075367386303, 0.11192091049686556, 0.09945853688423673, 0.1269285116464861, 0.15404160434920944, 0.1042926359561182, 0.10248508214229539, 0.15769596632209518, 0.1977145302319719, 0.26291055845156797, 0.15861730962511034, 0.16627463421994643, 0.12043338073717973, 0.19278527537901557, 0.1629668963892806, 0.1833304020786478, 0.11691146770552283, 0.15085699216973397, 0.2446061592068403, 0.22412902735654386, 0.19418733885451672, 0.27617261294395695, 0.11360086470602021, 0.07582490828128592, 0.11193515207137793, 0.10871930648722958, 0.11209956220080776, 0.1271010040035171, 0.170273597862932, 0.18782225137035694, 0.14051727199506375, 0.20395816213661627, 0.14487024486785935, 0.18624826244288878, 0.13917883978255335, 0.11602655954418645, 0.2784846969429524, 0.10230541920229312, 0.147788472954304, 0.19252212417702522, 0.11385286166783302, 0.19252370231814925, 0.46326804605703203, 4.093694643628213, 13.079255127137708, 26.486143873583888, 38.770307110201934, 62.09699161591069, 90.17665524636546, 102.50436659782164, 96.86042108843404, 91.7098940572431, 90.70982302388838, 77.17186435576409, 70.03639836465159, 72.09486607582339, 48.02004045055759, 48.49888340119393, 43.897782371890166, 44.76023312537901, 38.07613780421596, 24.953081569363995, 33.9727424037072, 44.0570580574774, 30.666727596713653, 21.952737069899037, 44.098105661330685, 59.68589105913716, 55.86635366562874, 53.210136352046845, 52.90927879271969, 66.4248917179723, 45.4174772385628, 42.728708174920854, 32.835121693149695, 32.988109819350704, 24.039147746178415, 14.603396000400668, 24.230045580094863, 29.410139437644716, 42.35140362093526, 31.533510608057824, 29.744384211878625, 36.84775737024123, 34.16444824587914, 38.72430163045084, 34.91952803827102, 41.364088135380904, 46.355072759812884, 40.33735675196494, 44.392734496824204, 48.255967094052224, 44.55425770052018, 58.041378528841086, 56.299536305089156, 65.585853592042, 45.74710930547407, 55.55550975184287, 62.89713944158247, 70.17066109564998, 76.08008830778061, 49.456047627233694, 67.76628740372198, 47.945378134327555, 38.88216918514621, 43.56302376716368, 31.73876431680495, 43.38231232858474, 49.75800737257927, 48.25885003612888, 58.7401330855585, 60.85492211003458, 73.8362572270055, 78.67572461405109, 82.06082420964395, 79.56061132492559, 83.89680723990165, 65.81397471889373, 43.224523221292806, 25.045547523806174, 10.397563980471704, 3.226085973362769, 0.44036097524146883, 0.21687472629691326, 0.15488195683686964, 0.20719817779477567, 0.12165127667568384, 0.09257388856982993, 0.19292384536275942, 0.1620391179477015, 0.18134759799126657, 0.1945382837326296, 0.15658720726928405, 0.10111967597397105, 0.18418227652868918, 0.1861787016593641, 0.12897810327910608, 0.11044727142659888, 0.0793760092628579, 0.12961461509187377, 0.13654729711913294, 0.26822975205798305, 0.10847079522547223, 0.1338606420904398, 0.1527951792964051, 0.2526388362410569, 0.11609517803956425, 0.12308877171768297, 0.14874163954969377, 0.2115209668033546, 0.20441003143787387, 0.27849529959982444, 0.10420049856146497, 0.11874393469864324, 0.14882397867979544, 0.12035572240429541, 0.09568736182465669, 0.184822388954701, 0.19491593443578292, 0.20248132847970535, 0.12564722193224778, 0.08719146206614473, 0.12019703495165995, 0.15950557325155507, 0.2583330298864073, 0.22757904303650703, 0.18319353281009584, 0.18892957017787043, 0.20872149766693193, 0.2181990624916169, 0.21434665146854617, 0.19694471912037945], [0.0542026435235335, 0.015920332666756888, 0.05970949802788035, 0.033624767280754544, 0.057594126255642024, 0.024707319981027997, 0.05519576926505374, 0.06200540224991499, 0.09305724408477546, 0.009516730112203909, 0.010482294883038248, 0.011924108745710505, 0.039517902468721715, 0.028894570798823432, 0.009088521436487716, 0.06896336517867542, 0.0563804897659969, 0.004970101224664118, 0.040451572126438545, 0.06439366603210088, 0.02283173564430927, 0.05594575402116584, 0.053882464736459725, 0.012778197189853078, 0.040685650291702444, 0.00868478831234238, 0.04294678944373324, 0.04519796945274838, 0.06336764830555167, 0.014338606251253477, 0.03434775126797538, 0.04800867326858063, 0.016629275219935565, 0.014623594789525435, 0.04083814392347009, 0.03413939067432958, 0.0596358961305551, 0.03823282828013744, 0.05742718803606207, 0.03224056514520799, 0.046966345530123486, 0.015284323599189522, 0.07616313609985575, 0.044521000536699454, 0.012144712381996216, 0.401286967098713, 2.1251884535435708, 10.221289723150193, 23.179944715192242, 45.64202900855772, 54.86527458313973, 73.12399402741464, 75.37239074707031, 79.2539918038153, 68.8634684778029, 63.573756141047326, 50.12517259966943, 41.87638498121693, 45.72919191852693, 38.66982383112754, 24.527265141087195, 15.425035472839111, 14.496728124157077, 12.608889399036286, 19.81587882964842, 25.883932575102776, 61.96700426840014, 17.162787645093857, 21.1160994345142, 40.839741768375525, 42.82605748022757, 34.30980736209501, 37.11616908350299, 34.801299956537065, 23.890101602000577, 22.740096007623983, 12.324127285711228, 9.507085930916572, 5.748116306720242, 4.883259669426949, 5.00037330773569, 5.256001526309598, 4.77350341696893, 4.764989912509918, 5.846960035062605, 8.141148955591264, 9.816356974263346, 6.205554883326254, 6.906619225778888, 6.296797058274669, 8.582911779803615, 7.36909608687124, 9.44211579138233, 20.674777876946237, 18.143780269930442, 20.121902150492517, 25.88201845845869, 25.650143623352054, 27.44856799802473, 36.71765235162551, 47.37314747225854, 42.42308101346416, 43.11098237191477, 68.90999563278692, 74.21685264956567, 76.91370179576259, 59.17084070944018, 23.893686648338075, 29.64282424219193, 11.552406837863307, 35.12492687471452, 31.10731763224448, 21.452944740172356, 32.26407950924289, 32.62387460277927, 31.431387778251406, 37.46171028383317, 47.26809855430357, 47.27708078199818, 59.248236917680316, 59.246420860290534, 67.49305509751844, 61.78888551650509, 53.35964925827519, 37.158695420911236, 18.756868300899384, 7.7748113486074635, 1.392205088369308, 0.2356508978071713, 0.08434775135209484, 0.04504804604596669, 0.008308968559328106, 0.03638741823153631, 0.018167244608423883, 0.03962924951807626, 0.03213496375528555, 0.006315843831191981, 0.07627346042183138, 0.05646599283922584, 0.07687399674567484, 0.09375389379959914, 0.056745419579167525, 0.018308869367765806, 0.004581205308392284, 0.056995869043373296, 0.059120686679718, 0.09454035200178625, 0.03520067525847304, 0.10437795516824531, 0.021774503665285248, 0.08672020307952359, 0.021882889784812447, 0.04606313935871567, 0.07299121799728564, 0.08495953384666674, 0.03411662254121996, 0.024398885321833437, 0.047421692870557315, 0.02314058973664238, 0.13289062156071588, 0.04972849469331484, 0.05515367656405415, 0.05406210086338463, 0.11689678180001437, 0.07075979539583768, 0.07648929037273892, 0.015405602978482364, 0.018573696387090513, 0.025684905629004204, 0.03968645330338229, 0.09463474169493684, 0.031226050228841847, 0.030130996488996094, 0.06277658848933156, 0.09852102146514001, 0.03716358787290031, 0.020782645799279697, 0.05000000391455908, 0.08928207770710991, 0.003343490675287021, 0.04560100830971234, 0.07363398874839468, 0.003970228642555735, 0.04989601130927763, 0.11564559168032101, 0.03799100113551944, 0.0069456399256934325, 0.01144976050953471, 0.07377698672034087, 0.07962797558115375, 0.01890006707981229, 0.047315934432610396, 0.02562021524945815, 0.034355741565025626, 0.045764231002859534, 0.02735415950507647, 0.027708436865659974, 0.04982481492803462, 0.030055810704887397, 0.035907253472795414, 0.04223668722495918, 0.015374057392980305, 0.0038352688481550546, 0.10330626711009011, 0.008149839648526282, 0.03949623367178344, 0.06992528049816048, 0.021673883762090437, 0.09821378190310733, 0.054846203345204556, 0.08434901539716991, 0.04187945659542757, 0.04026525954325353, 0.027556416293185566, 0.06861373031091306, 0.019306704634800553, 0.05325295496731997, 0.13665750652791994, 0.01664632642191024, 0.07853861387458541, 0.018853019705162417, 0.637883048865103, 2.795128788678877, 13.167913440735111, 27.934718324292092, 51.48181061590872, 62.4133268479378, 81.88427832818802, 84.20825912106423, 87.19469685708323, 79.19983171647596, 76.24733817192816, 66.58838395149478, 56.92178895396572, 54.721747213794345, 50.26641714957453, 33.23164978334981, 23.046978327535815, 23.408999366144982, 20.264899999864642, 23.000382531073786, 20.220973376304876, 53.49683023268177, 27.54351877397107, 22.367482608364476, 41.85804790066135, 41.02032769110895, 31.592230450722482, 25.666282215426047, 21.669539982272735, 18.546962661127893, 19.500932116662305, 11.204879937633391, 7.8811938724210195, 4.374005111955828, 3.2658811153904086, 2.9619207161088146, 3.147801838574871, 3.142981245633095, 3.496752068881066, 4.606625197395202, 5.717885128913387, 5.77860047740321, 4.942573751172712, 5.587978189991367, 5.092788761661899, 5.567583335984138, 5.864259158411334, 8.660670807284694, 15.146260857582094, 16.68408197741355, 20.39240252587103, 23.238509624235093, 23.819981390430083, 27.24987053102063, 35.09757618750296, 32.843870539819044, 36.50173371837985, 39.396984192632864, 60.1606547447943, 70.9429600930983, 68.35828288908928, 69.43818200019099, 28.98022609372293, 32.176900909793, 23.577382795272335, 36.83173841045749, 45.08218911386306, 33.08488253624209, 45.406867227246686, 44.332737922668464, 43.18537796697309, 48.857199761175345, 57.56165304491597, 55.751855757928666, 66.55122341648226, 68.06196351205149, 75.06612423927554, 73.2850230124689, 67.4681951153663, 50.084827100076986, 27.14778692491593, 13.04466276399551, 2.527468699601389, 0.21168061952677467, 0.03471545048899228, 0.0823530575801288, 0.030436096750500224, 0.04728315736077005, 0.03789371946045468, 0.08293910718132412, 0.07715956368032964, 0.02000243504411511, 0.029665517635763656, 0.07737419087319605, 0.048972833225683826, 0.08425191375276736, 0.008378388574196687, 0.029950151858370633, 0.04724541603918037, 0.07845449742049941, 0.045202485541062015, 0.04394477218269341, 0.052592135184714874, 0.10379568238051669, 0.04058261146588672, 0.04310349655908443, 0.04992607642986602, 0.03561679506674409, 0.02199917044039936, 0.04192463663076201, 0.026150679426087488, 0.013191599301212739, 0.06532462373856576, 0.038495807112344814, 0.04849991948914625, 0.016487792186859637, 0.08245382112480941, 0.05421665910210821, 0.08289303465355789, 0.0147572273365973, 0.034836691563888904, 0.046657010717617894, 0.04175198339526692, 0.059348904272361155, 0.0629230491786955, 0.0776206796628333, 0.04779176696413948, 0.04458678067631779, 0.07315997184524614, 0.038338996575123845, 0.056529302345288385, 0.14296706795932787, 0.11700830888003112, 0.2223346502550187, 0.10340324618042478, 0.21386936336996096, 0.20962566527868473, 0.1992081258926661, 0.26805416470573795, 0.3767241351306439, 0.13163719446428362, 0.11297340039163829, 0.08037320293125608, 0.1673406455665827, 0.25862135473758946, 0.1018515044462777, 0.1494413229726976, 0.16697998669358993, 0.10659774855500269, 0.0931667103882759, 0.1680570756716113, 0.11710705761347087, 0.14345610784667154, 0.14306745612092558, 0.12576023522283764, 0.14846704299411467, 0.10045108805981376, 0.1987789327939672, 0.23217069826299147, 0.2846068732680813, 0.11388655421474289, 0.12652699730449146, 0.1398306886755651, 0.1799381034628999, 0.18250532538419773, 0.20865610440171536, 0.10693252897791325, 0.14485755845183326, 0.11365082129956254, 0.11728219297384063, 0.18779710836468205, 0.07922654550883078, 0.240909309997674, 0.19336312017854185, 0.16416104360213205, 0.09974147613731124, 1.4255176556687204, 4.6418078772483335, 18.638324468366562, 35.96710681915283, 64.9682411070793, 76.13058490137901, 92.73285604292347, 94.03344338940036, 96.47052964856549, 86.5250619765251, 82.08500954412645, 66.17660568606469, 56.97259541480773, 60.12011312669324, 54.89144463692942, 38.55576522888676, 27.026305237124046, 26.717726492112686, 22.697093102239794, 31.94101937355534, 36.222166784348026, 76.03141953868251, 28.43313978564355, 32.240633541537875, 55.32136778677664, 57.8416592844071, 50.21223352801416, 50.51261648055046, 44.79234164760959, 32.791114661001394, 29.748855713875066, 17.33772143240898, 12.194152685903735, 7.500301820616569, 6.914539471749337, 6.8981478867992285, 7.472046046487748, 6.224303812749925, 6.277680406647344, 7.936499291850676, 9.801355869539323, 13.066667260662204, 8.583131432533264, 9.52841381872854, 9.008387942467968, 11.728468306602972, 9.234961694286717, 13.085205362689111, 25.75616725029484, 24.242330443474557, 27.565056508587254, 35.80620727231426, 37.31532742900234, 38.985849195911044, 48.64467790049892, 61.76053462489959, 54.61503128851614, 55.14950913767661, 80.10166306649485, 82.03161039660054, 90.81218119590514, 72.339692577239, 37.50648413935016, 43.02598461028069, 23.405704575200236, 48.820243189411784, 45.97909004457536, 34.49824979228359, 50.059265013664, 49.06750156033424, 49.44136619567872, 57.106156041545255, 66.38187900666269, 64.43077048947735, 77.46335921748992, 77.00802695366644, 86.3574198753603, 83.45321070763373, 79.72933600025793, 61.37520097917127, 34.38486191534227, 15.408993959426882, 2.905702610169688, 0.38825522927987965, 0.2542184942191647, 0.23891829344774448, 0.12042888380106419, 0.16737481308800561, 0.1239742084796871, 0.18221739889873614, 0.18993878376580056, 0.10940059613917144, 0.24835542415178594, 0.13994193996392912, 0.2123414622920175, 0.2722318566614582, 0.11130480726640071, 0.11388234839203859, 0.15366396896781462, 0.1986336059147312, 0.178381382157245, 0.0982599693440622, 0.19407204262191252, 0.21810468045934556, 0.12462480098850305, 0.16096330067563444, 0.20371207937357888, 0.23340075967773316, 0.18460699567391028, 0.2019767063639818, 0.13731363019154919, 0.08261490643264786, 0.10961278717243865, 0.13208751626793416, 0.1852885994219011, 0.20398643078102222, 0.18535880371928218, 0.16379528258356357, 0.24040304845379246, 0.21766333720616757, 0.19453376381387635, 0.24119178193711469, 0.14712464244615647, 0.12781633094193476, 0.1999975794986371, 0.3157800634301478, 0.23118705668997383, 0.2508665377935094, 0.1412569911729905, 0.19900738021298764, 0.12303255618579927], [0.025103253372494253, 0.08050358343508937, 0.07689443597149465, 0.06651636543533494, 0.04212784528311703, 0.07140487207159882, 0.03435237843903803, 0.01362279859266334, 0.05965036370100514, 0.037382221705610716, 0.04836088219176858, 0.07689010757472246, 0.10956906653459995, 0.041218150346990556, 0.05740440075075435, 0.028808376331242825, 0.006105692507023173, 0.027197695622641235, 0.026262547415230545, 0.03573562679511886, 0.08911356900728519, 0.00860254685845106, 0.025820106741101034, 0.02836581308304543, 0.07186630981103068, 0.03654488760437216, 0.08266382880749241, 0.05315979484528784, 0.05952850209488984, 0.0018366639579330843, 0.0373767058725559, 0.05513643958575784, 0.048300368906629663, 0.04056194624412925, 0.022450735221707055, 0.045741175586778315, 0.04599422591948702, 0.11387638822798768, 0.024126669384479046, 0.05879488097684038, 0.058153948836749604, 0.08110041955425855, 0.09172027510020042, 0.07630634857642074, 0.3538614974146889, 4.002477718937782, 16.613973532953572, 35.120027834369296, 55.87574774219144, 69.80565317215459, 76.43691416709655, 79.32322163735667, 75.43017510444888, 66.69710420793103, 52.04520025560933, 45.2811631079643, 35.377915828458725, 32.59432346590104, 27.866877009791715, 18.93586370252794, 16.329259468663125, 19.10595924623551, 31.98550101249449, 29.349546663222778, 38.52592383661578, 48.184615258247625, 54.461941180690644, 27.631411244792325, 49.90284873593239, 31.726163702626383, 24.72407594803841, 18.93420453994505, 16.682762099850564, 12.471072020069247, 3.8762933544574247, 1.8803667325165965, 1.6930742922329134, 0.5629671268886136, 0.449412978224216, 0.458138351959567, 0.3497492906547362, 0.13285360419221465, 0.27832482971491357, 0.5597380969312884, 0.5581829997320329, 0.3136134135626978, 0.2671078009711158, 0.8830659956701341, 0.6383325279720369, 1.2183092582610346, 1.2156772253013428, 1.1652783232350503, 3.643777211827617, 4.2682109436681195, 6.399825955590894, 7.593579215388145, 9.519373736073895, 11.51256340165292, 10.736342034032269, 13.343488535573407, 18.03622691862045, 28.847512698942616, 27.6455690399293, 24.39776808984818, 21.272196039076775, 33.23070449213828, 26.82936695314223, 38.728824123259514, 41.25250454871885, 29.746639574727705, 30.272688250387873, 10.027652113668381, 15.062820276906415, 13.690315292727563, 18.825219523522165, 29.22128711977313, 27.63814203200802, 28.12601035641086, 36.34103421242007, 38.55484347189627, 55.01463059456118, 50.23247295810331, 61.77671047949023, 64.32852998856576, 63.46116058288082, 51.734889784166896, 39.966469195581254, 20.1105841513603, 5.9552723650009405, 0.9405608943873837, 0.10840458224617666, 0.06400787181431247, 0.023132631998328913, 0.042583104523439566, 0.023823524562401638, 0.021767145390772534, 0.02951554826370651, 0.08129780210794942, 0.08570321369916202, 0.009703449679598694, 0.04456492418783807, 0.042523613965679566, 0.03345304484208746, 0.04197734347995251, 0.04754598297539258, 0.03183774845374208, 0.02593372907159069, 0.05925168771476996, 0.06446843621351066, 0.027106466042178295, 0.04198018949659121, 0.06807774455556947, 0.05760837166059402, 0.035301212807215994, 0.020298585483443835, 0.05900338329675217, 0.01869690439273273, 0.022541769449749303, 0.018276197633015055, 0.0274621932241585, 0.042460300629177404, 0.03609553873238545, 0.039607703295205875, 0.03428410851366578, 0.06411012923044544, 0.0349729594534203, 0.00809945117291664, 0.052550073127232255, 0.005420612635075926, 0.0344395324317438, 0.0038333847506662774, 0.08614641088511675, 0.020904469100998777, 0.030313683561079448, 0.027373727305882403, 0.0903731631115079, 0.010211955861098344, 0.005850579482578343, 0.05859715751402321, 0.03771570360948963, 0.05246294594760384, 0.08670553249577362, 0.06366503980731772, 0.015453344620313617, 0.07747301621542824, 0.053407474901647344, 0.08408813181543544, 0.10548982453802902, 0.025149061599926605, 0.043424292046937256, 0.02809276402507338, 0.08315895909383413, 0.030869719752621268, 0.06345710056203027, 0.03995765608945682, 0.002778006465016534, 0.06971629171241676, 0.04644743204417248, 0.048313319622989626, 0.06821200912517887, 0.03319081677604587, 0.03654832350871256, 0.032478335854266925, 0.04355852214259006, 0.055438554019577084, 0.04144780435449174, 0.014042925040778375, 0.027379852178837025, 0.06988885301736093, 0.054963671437074105, 0.016019609043254487, 0.01747834961861372, 0.018925999156049183, 0.0467078942775486, 0.07010830656415032, 0.040570296602503914, 0.01867464379287295, 0.05169413075031293, 0.05382540650785931, 0.14219782375279935, 0.45826212112461373, 4.93203140074207, 20.290069849260394, 41.55918290538173, 65.27866140488656, 80.84574453292355, 86.17030712866014, 89.47767319217806, 86.70891915598224, 77.84753184164725, 63.0096604747157, 55.85635946642969, 39.666403955028905, 42.08041098810012, 38.609748809568345, 33.06602770282377, 28.88626963861527, 24.656821027878795, 29.638286059902562, 27.104819320863296, 37.356712356690444, 44.6594831251329, 62.7695486622472, 28.276135152386082, 38.04597085522067, 25.93747881151015, 22.646133668961067, 16.49588469536074, 14.967877345700419, 9.049841511634089, 4.37382762470553, 2.1217338260143035, 1.518286122910438, 0.5857651680707932, 0.45849697303868114, 0.3914120324677037, 0.3194067236636916, 0.23917183790716434, 0.2640974737944142, 0.46444665700677906, 0.43873696077254515, 0.25056370323704136, 0.4262328736724392, 0.6493416404531849, 0.5143509420656389, 0.7938499700638556, 0.7502449808582183, 0.9448207109685868, 1.936057157093479, 2.592874957669166, 3.9799807196663277, 5.500484820335142, 6.715501739132789, 7.127510934106766, 9.394149126545075, 12.268428648671797, 16.432613922703652, 20.162396700151508, 23.16717936146644, 26.661569918355635, 28.089759811278316, 35.72109968431535, 31.706118429860762, 43.16293808721727, 49.87438801796206, 27.320361406572406, 41.317200122341035, 18.397624300372218, 23.186312683167, 25.99424139145882, 27.01012742134833, 37.98949656947967, 38.30296454891082, 40.93525540444159, 46.91098636196506, 47.95267374284806, 63.33269119262696, 58.34405606792819, 68.86435493346184, 71.28395526639878, 70.83660110350579, 62.46971876390519, 49.840616410778416, 26.936482960178008, 9.648850194869503, 1.5953953852576594, 0.1010680339869953, 0.11480425860011771, 0.01004442392337707, 0.04725439458965294, 0.016941101733414878, 0.04902682327214749, 0.025128499800038916, 0.03456725461047984, 0.08093383373512376, 0.031615410585917776, 0.09290492282279077, 0.02995470242064086, 0.06670378118513093, 0.04269268190968902, 0.05063590285698733, 0.07210272454446362, 0.11295281560911287, 0.048106035382877436, 0.04478811241325833, 0.015525949645727394, 0.06756230527835508, 0.061507736212543906, 0.05516465843444871, 0.05326481400838783, 0.04421362690928002, 0.03003514548312993, 0.04674343309635597, 0.04624492436226818, 0.052658623955663175, 0.03133867089937051, 0.07230865663938946, 0.0671008445562855, 0.007482083418571781, 0.014466011461110847, 0.0316755848771502, 0.023658534121369163, 0.02247402429460518, 0.021636607838914763, 0.0044756805272622695, 0.016188592717592275, 0.015681023078580058, 0.08735185023397209, 0.031197896497624538, 0.009373193005881002, 0.02315074997773815, 0.005060632707506058, 0.15648639009844872, 0.16464482812631517, 0.1888737223681904, 0.11549002220553738, 0.17810788876827688, 0.18760596942757407, 0.13042027911832257, 0.1424360617754921, 0.1497403117677858, 0.25697858643627935, 0.15474824385056574, 0.20569522053964678, 0.1459265881848912, 0.10361637950183884, 0.12263835798348151, 0.11354435039984603, 0.1302533792031388, 0.13298158684084493, 0.16017082868324173, 0.1144651574413142, 0.17626777621767215, 0.13650306320238498, 0.13250852754760173, 0.16654863322694458, 0.14984790115587174, 0.15071541912132694, 0.15490668615506542, 0.19993161932835657, 0.1561368854656335, 0.12443493375734938, 0.11000317025689349, 0.13678372717432438, 0.17559997737407687, 0.1458689170859514, 0.11490332142960642, 0.1618047716516641, 0.15472447980315457, 0.1567873247568646, 0.24380763511984582, 0.12629851158107483, 0.11894550009240067, 0.1894031657326606, 0.1630225909813758, 0.2098497153530198, 1.0163719134946023, 6.672713583515537, 26.307587777414632, 51.31526677839218, 74.1205035486529, 88.4891103929089, 95.60300334807366, 97.9533189342868, 93.1134436207433, 85.53628736926665, 69.32151502178561, 62.16912008100941, 51.13745789374075, 46.730016046954745, 42.474620957528394, 33.56844017582555, 29.56209205812024, 32.00378514105274, 44.53592061996461, 46.517792286411414, 53.737546090156805, 65.10557113155242, 64.97008854343046, 40.24474174745622, 66.10151583148588, 44.29917420110395, 31.81230679635079, 26.13895331659625, 23.04518384318198, 16.051693924011722, 5.282232376836962, 2.8511382735544637, 2.3453733997960247, 0.8975688980952387, 0.9060498591392272, 0.9520904563607709, 0.7171821582221216, 0.4300454481234474, 0.6428865836031976, 0.9415623245220032, 1.1291854083538055, 0.7681040838360788, 0.8855483656929386, 1.48157273809756, 0.9584749718346904, 1.4222707911845178, 1.6225079110553189, 1.7156258369645767, 4.269140545398959, 5.104044983463903, 7.768646853585397, 10.204334297487813, 12.338160545595231, 14.47573854077247, 14.63004654453647, 17.456320178124216, 23.664728095454556, 35.429918612203295, 33.927717516499186, 29.538708848337976, 29.78418842438729, 40.54857638574416, 38.25431931403376, 57.07520854088568, 55.77187945765834, 40.784601088493105, 44.74498687251922, 17.517595444956136, 25.814930239031394, 25.583480981088456, 31.770215842031668, 42.38051937472436, 41.94622278213501, 44.26355907993932, 54.631360115543494, 55.96589557586178, 73.52103202573716, 67.93410208917433, 77.97405965866582, 78.84487290536204, 82.4391995706866, 70.33325902877316, 60.549840158031834, 33.24575070411929, 11.312041051926153, 2.2543842177237234, 0.32488535548890796, 0.20972660502358792, 0.17725178551289344, 0.1842242121816643, 0.1263642266032196, 0.1630579229564436, 0.14001790524250077, 0.19825483672320846, 0.16280178911983967, 0.0955600226898828, 0.11985232602925071, 0.09664763771598378, 0.2900903467689791, 0.20165358579927878, 0.1529263641925589, 0.17519430317465337, 0.13883276722363888, 0.21259290767052483, 0.16254444486431538, 0.1391673024984137, 0.13055769997018, 0.2533787086365685, 0.13802610728288853, 0.14468491287721744, 0.18422894660503636, 0.09452958080557086, 0.1171244401484728, 0.2469576967339362, 0.14185008112220995, 0.16688221855269325, 0.12159116175626555, 0.1612287654631561, 0.10453392300874957, 0.16160129869897522, 0.18663464654837886, 0.09248148304440322, 0.12056886338658872, 0.23899018313855896, 0.0823940432840778, 0.15969426070730533, 0.11048628062370325, 0.208029352549103, 0.15137318221311416, 0.06701781594705197, 0.1470318998420431, 0.08339429364329384], [0.06311560154802377, 0.06765235891385425, 0.021907735931416674, 0.0827632440374263, 0.0436811077017938, 0.04707899109850969, 0.05907552196614205, 0.009694157990687078, 0.009192356036134787, 0.08572508550940022, 0.042714155354206605, 0.05189465043405372, 0.022524214544964415, 0.03769688465962968, 0.024214401773567644, 0.04883846140376503, 0.026462911966166673, 0.036648972140204523, 0.04052625420773703, 0.02609943772005218, 0.06697959582050962, 0.029449932832991885, 0.08231931906794349, 0.003441593261443139, 0.042987978160982175, 0.07415556438988255, 0.05165075102160054, 0.054619184680162906, 0.028368536525616245, 0.04168110494051249, 0.010030664026647085, 0.049103910869528214, 0.011331313740341895, 0.004723141769758396, 0.027915590870825034, 0.03432428599485467, 0.0695243866873845, 0.0192218623124063, 0.01772264548156771, 0.046583876133926456, 0.032398769962451154, 0.04343290287520617, 0.09649034454337052, 0.2736180774386852, 5.3434576334491855, 17.311312114038778, 38.306506449176425, 59.139865752189394, 66.89095558658724, 74.45033565644296, 77.68775017030778, 72.61709828530589, 63.85961847920572, 63.96486351566931, 49.01108218777565, 43.9507108349954, 44.25891891602547, 21.149288569727254, 17.56394413209731, 19.723548196977188, 22.951113639339326, 20.709785030734157, 27.359202677203765, 36.28450893586682, 32.25563268507681, 25.78071540401828, 21.45321342252916, 30.41318754996023, 21.091233568806803, 21.92612967183513, 8.734463337929018, 5.706233728316523, 1.5458195680572142, 0.7160488383904581, 0.5705977303366507, 0.3131344860359546, 0.18734067317939576, 0.05199726408107146, 0.032900592026811455, 0.10918706445203674, 0.03611994629365302, 0.05118082885840728, 0.01432770194726125, 0.06697470051867348, 0.04131049458538333, 0.1799440483051923, 0.03647610056965101, 0.014351304158598427, 0.04255164512282899, 0.1376464647511321, 0.04325111021077441, 0.03122412351771228, 0.09371365120093669, 0.38794238961512045, 0.8420733662862933, 1.1824276610728235, 1.1150738236404236, 1.9682234117100317, 2.7469888041096353, 3.070939808122574, 2.7807118719623936, 5.177066278073096, 5.157970218889175, 9.569723240790829, 15.27022344450797, 15.824839722725654, 34.12065890527541, 31.70617138185809, 26.62458000644561, 44.37054564875942, 24.303268386471657, 39.95587095137566, 38.73364471620129, 25.47302899822112, 25.835079454606582, 19.334352977814216, 18.333268011769942, 22.975100894128126, 26.4649179673964, 29.898139161448327, 32.95588362601496, 44.03891709543044, 45.407420281440984, 58.55625237188032, 58.555260012226725, 61.45262464400261, 60.616814628724136, 45.31322456175282, 33.03365245942147, 18.071563551502845, 6.1993256691963445, 0.10963159463097973, 0.1000002836207709, 0.03237442368821752, 0.07602450482907795, 0.006433924793400952, 0.02085979085325474, 0.025563965243617856, 0.00595815594293057, 0.05463729882913251, 0.0142372939960971, 0.026198958287075646, 0.051003249677559065, 0.021686821071911725, 0.01853706014733161, 0.05983874089114609, 0.09516674379307417, 0.04069364824963193, 0.022578072441261143, 0.037283744933384086, 0.022427220152871265, 0.09850062820459567, 0.03684712078181967, 0.022565460718807676, 0.05936606081142541, 0.025316392439567757, 0.05051928129227412, 0.0691487584563513, 0.011954846108452448, 0.0589323171504563, 0.009894015008373367, 0.028506508960779157, 0.05001766990209299, 0.05837981453946522, 0.022144495404415557, 0.0527138588950038, 0.022854844686545195, 0.04105021621310904, 0.03048426644395917, 0.08709144162675066, 0.0029362000303433068, 0.04669070326452775, 0.03477624339622355, 0.050534101263169325, 0.05119724229218499, 0.01850846016989841, 0.0848676416001493, 0.04493502892493721, 0.01114482878737392, 0.046858660381046996, 0.06983351082571092, 0.07234038034033391, 0.0453083818748353, 0.06707790788383254, 0.04160441570885239, 0.045746771859065186, 0.015196672606942876, 0.02241073585596056, 0.0471272086724639, 0.0757092519873573, 0.010331280758574365, 0.04931605593751996, 0.05900758528901685, 0.041518778570236704, 0.11039259573144299, 0.04267600417557744, 0.026983888143853798, 0.04731664689437998, 0.06411410139633283, 0.03350768606328676, 0.06836939422834305, 0.06030201724159622, 0.08160065964705522, 0.0283681707186324, 0.1206230870898693, 0.06899705772558529, 0.03088532113319924, 0.04907728548371985, 0.06445558125814123, 0.06043350857291972, 0.09150837518034444, 0.022201963490055456, 0.02193989821769778, 0.008657593148640327, 0.02421517743759098, 0.031285885526167775, 0.08091586131242015, 0.03950438867773741, 0.05288581499048779, 0.5009968344482684, 5.773144460493519, 20.861888662461315, 45.10567234408471, 70.60916639143421, 76.60808640141641, 85.45528258046797, 85.24230572485155, 83.1808413228681, 72.3494985026698, 72.49895649571573, 55.49241842762117, 56.65855084696124, 53.21318795604091, 31.332583273610762, 27.294248227150213, 28.558373220505256, 28.675836440055605, 21.55495382124378, 37.44965684029364, 49.93886393885459, 42.3231743228051, 33.46079464881651, 26.409194815543394, 25.825959943955947, 17.950793773897235, 11.777925472105704, 6.975430836600642, 4.7982957382355975, 2.0254169620813864, 0.9550414883321332, 0.3593027441492004, 0.13482104055583477, 0.1835563060857596, 0.04869476246136812, 0.07914898676737663, 0.038059665596172694, 0.15373374425595807, 0.04694449287208338, 0.03002596391935743, 0.04284052155731667, 0.07522903743290132, 0.27469145855115307, 0.17692344022854684, 0.014808898051870207, 0.035757506266236305, 0.03100902709599224, 0.05325706502903373, 0.010456171284820284, 0.16316083920819147, 0.44382476518231057, 0.6574214165729861, 0.864413286889753, 1.1155297991729554, 1.546622673349996, 1.8407189245185547, 2.2780130659380267, 2.3695869263141387, 4.260353455620428, 5.265406879686541, 9.682926766334042, 10.706602623385768, 15.829875065434365, 24.75381731987, 30.546616777296993, 27.645939703910585, 38.1452028982101, 26.558017384621408, 34.366575825598936, 36.65829120143768, 26.462913636238348, 35.853232568310155, 29.928311993998868, 29.31149182781097, 32.97849609005836, 37.28932603713005, 41.339487029660134, 44.26179401336178, 54.946149933722715, 56.9593652602165, 66.6132753126083, 67.70372559947353, 71.09357910771524, 71.17399554098807, 56.340203439035726, 40.8656451009935, 24.18324778156896, 8.663549826991174, 0.450163591172426, 0.10047993127016291, 0.04416304212363978, 0.0915836816233012, 0.07322727266939418, 0.06396608171804298, 0.06615367642934285, 0.09492946338028678, 0.06887250715085576, 0.04067865207851414, 0.005521170293626886, 0.014259179212873983, 0.006834995762009415, 0.027408316175663666, 0.03530720744522349, 0.05991225085792042, 0.07031521925161924, 0.05887437792074296, 0.046658772719843734, 0.018462240170206756, 0.17355732649805086, 0.015765304241569775, 0.011656861846154977, 0.013589373218917079, 0.012485642575718945, 0.05886394380321426, 0.03152621688411361, 0.08804378850806145, 0.02691208846837042, 0.07883181870584527, 0.06025096897276179, 0.03356555251464729, 0.007021119696043071, 0.06542543324852182, 0.04523428202035927, 0.037521010024412986, 0.020535373684739875, 0.023432534353266803, 0.005862062182953401, 0.032293294977036216, 0.045154670163268046, 0.03810955324180184, 0.08854353830458657, 0.013634813724145775, 0.03791275291493343, 0.11599695024591301, 0.12444031169457782, 0.16926389397873035, 0.1718504366374785, 0.18051351210282696, 0.1514783660851179, 0.19889568459362755, 0.2064346486041623, 0.1867566537111998, 0.12443440515668162, 0.13131877767943567, 0.18970278271984672, 0.14710561282211734, 0.29953418840323726, 0.15698313683031068, 0.17815399193956008, 0.10223601929723256, 0.11543132454877901, 0.2360598508629107, 0.18182344584455415, 0.153364903563934, 0.13016638225845753, 0.26954509438045565, 0.12532338890577518, 0.16268255519530467, 0.14795636878378932, 0.12748679056042625, 0.16001394919810757, 0.2002093721661837, 0.2236235778658621, 0.09434087036718285, 0.20240620589785038, 0.15023223214572476, 0.1890742995085255, 0.2103422639230567, 0.1515099595511152, 0.13737130129048902, 0.11887624574404572, 0.14062985627641603, 0.15470459216064023, 0.29992443359186577, 0.11474530047346508, 0.14031531589646495, 0.9103228524327279, 8.680219900223518, 28.135086720989598, 56.44085145765736, 79.96801222524336, 87.86821488411196, 94.20611396912606, 97.47139300069502, 87.84676736400974, 80.65298357317525, 80.63950630926317, 62.320135255013746, 57.10650121012042, 57.890735980003114, 34.290344561299975, 27.10055962685616, 29.99542178646211, 35.03215889776907, 33.013801343979374, 38.105904671453665, 51.110515133027114, 47.28234068039925, 37.233749974158506, 30.841524101072746, 43.02769868604599, 27.903309945137273, 25.819982251813336, 11.336325426255504, 7.221188410635918, 2.5752174277459425, 1.3702559951812991, 0.8653903247848634, 0.7611621627884527, 0.44356147608449387, 0.3063835660296102, 0.13718186306857294, 0.3593519576374562, 0.281601510341129, 0.16497950129691633, 0.15727212051710776, 0.2002368440791484, 0.2389009185736218, 0.6057640465517199, 0.5162543334787892, 0.1495974363699075, 0.1619856603323452, 0.25279931633943514, 0.19188732840120795, 0.2610612222023549, 0.2839283032282707, 0.9234160305030885, 1.3618365050323549, 1.6888538219275016, 1.8388793329077384, 2.540460325056507, 3.8304141259962514, 3.9262849428961357, 3.509809148888434, 6.308642125898793, 6.270551008562888, 12.512401053982398, 18.74500313112813, 20.798732619131766, 41.95377334471672, 40.159830277965916, 37.0363566952367, 59.75382258815151, 37.11415690760459, 55.31723360861502, 52.16223985918107, 38.29466089125603, 40.898644001253196, 31.81073980946695, 30.739511097631148, 36.45331598097278, 40.36935152546052, 45.853048601458156, 46.64646956228441, 61.19026514791674, 64.10281719699984, 76.21038160016461, 77.48316718686011, 83.42485981602823, 83.51776507592972, 72.18817926222279, 53.15608216870216, 31.26868982468882, 10.573043957833322, 0.918965059663019, 0.23165539688160344, 0.23088878801753446, 0.17606673942458245, 0.3534257772468752, 0.11390040508441387, 0.16055773372852034, 0.25920453150906875, 0.1798540942611233, 0.21984068166104057, 0.09102462896055753, 0.18277275135680554, 0.13786628602012513, 0.15044797782696065, 0.23688583154111142, 0.18891434034993573, 0.2463191011620145, 0.14469405996703333, 0.15304945920023227, 0.1500956999558595, 0.36925168287369514, 0.13012017183486493, 0.10898931417614223, 0.1885130941387146, 0.28515928394852147, 0.14223882477850686, 0.21211353581278555, 0.28951112301118914, 0.24238026009932642, 0.21499171282254884, 0.09383435601428633, 0.13537483019453866, 0.17168034979652974, 0.09616352377399322, 0.15615851978861517, 0.09644743595873156, 0.06500807620825307, 0.06421034885269981, 0.19115615876451617, 0.0971240294916976, 0.10960472792747522, 0.1685535466118205, 0.179381693803495, 0.1506046581292345, 0.14692302342624436], [0.058741672340059475, 0.006409746100900756, 0.036408179214284304, 0.07035742303536785, 0.03610386610812238, 0.044901133364727425, 0.0632288446649909, 0.03526665075051208, 0.04571036353046375, 0.04756028200649927, 0.0270385293650531, 0.0076689327421087415, 0.041059424589958884, 0.036591140162800594, 0.02592695685434005, 0.01761742905082722, 0.04089835460387892, 0.031752957842282714, 0.06651867902086628, 0.01697462574098139, 0.060038023342889164, 0.02984539508038471, 0.030267953857659336, 0.041392247658222914, 0.0709135722248785, 0.04002811702629251, 0.042068860343387054, 0.009763504269592946, 0.014756525408536678, 0.05142418051799459, 0.030599378815461552, 0.061560611601077744, 0.032072947022595236, 0.07969614208465622, 0.043155395185514804, 0.09905493878308805, 0.05688857842957782, 0.03511964230828228, 0.0035436931507466666, 0.054864608607585394, 0.03213704751443959, 0.04884434112858388, 0.395564045156202, 5.221483688200674, 18.0032927374686, 35.387682530187796, 63.6056960013605, 77.6237763127973, 76.07982158660889, 62.159643634673095, 61.70091459828039, 60.942963630922385, 49.21848927774737, 42.48223820040303, 31.82376011725395, 22.928930674829793, 20.22392495985954, 18.481413971993234, 17.917424209656254, 34.7193734107479, 39.88881018853957, 29.735688317206602, 35.43561781606367, 27.781573303284187, 32.19544783715279, 26.39260711208467, 19.93900595172759, 9.846841635242585, 8.180514843233171, 2.708944755215799, 2.0453901612950913, 0.24134452454745772, 0.34819787067751734, 0.16874807165755382, 0.05332780175752217, 0.04203483837866976, 0.04787291482751889, 0.03516676437650477, 0.09331607455087286, 0.01056178225084178, 0.09422755830230252, 0.01954596730009202, 0.040450832851591616, 0.028984304592614214, 0.034103365389690284, 0.09171819900192561, 0.04478401767330305, 0.21903143234310612, 0.1034014611955612, 0.04329710229930859, 0.09232865616438851, 0.021389287843879674, 0.06739859994981559, 0.01858822141413487, 0.17820035558073752, 0.05801547844443591, 0.06351527727900014, 0.05194380263527555, 0.10419637700843234, 0.32795231188497237, 0.4319165106261931, 0.33446951378737727, 0.5941701331926931, 1.6964184805270166, 2.6937654277970715, 4.383056471424719, 8.875960880710233, 15.657902667599341, 28.49210673762906, 21.912085625433154, 36.452539351678666, 45.694769197894686, 36.048056694769095, 38.899757092998875, 25.22458411032154, 24.166828740027643, 25.152663530841952, 21.960956396595126, 20.343592551446733, 21.604773805987453, 19.282603186945764, 28.939441288671187, 38.781344659866825, 39.56372807102819, 41.83703576364825, 55.00433437285885, 52.547730399716286, 57.49491783880419, 55.97681937679168, 46.88525169126449, 24.72905343578708, 11.86245745228183, 1.8574229507677018, 0.37069441029621714, 0.04084504637566786, 0.016104784613895803, 0.07836178545990298, 0.025062577934154583, 0.019858148129236315, 0.0470550470204363, 0.051378165446822686, 0.04938075589316507, 0.028675176623848178, 0.01855653793280644, 0.05477992524843543, 0.036516109511496565, 0.04115237020737222, 0.06947302815294074, 0.008637586762497743, 0.09909789333300245, 0.04616446980846025, 0.08948405678834646, 0.026199347076697216, 0.0324382771167063, 0.02676734573117668, 0.011950025500188912, 0.023435575722326196, 0.049164941264016014, 0.07130664427794757, 0.06730522149272504, 0.06465569874572177, 0.01699781522244936, 0.011543822700097676, 0.04462924492996066, 0.011070908005950193, 0.01962834281937009, 0.041571098545025435, 0.03074511555173705, 0.036439362823242144, 0.028424095137104876, 0.04950541755064361, 0.057781170452794725, 0.016153266488183892, 0.03624166617350232, 0.00736282124454456, 0.020229214306680426, 0.03826237246093731, 0.012816090771417706, 0.06041939340291485, 0.060981855156921574, 0.04751733894790373, 0.022856838430368134, 0.040451595109076276, 0.05644425892481401, 0.04097158494856089, 0.0661380099312913, 0.019929064888386958, 0.06965604655805134, 0.026053426479319894, 0.06803051523503757, 0.027685423584414587, 0.05194104471874814, 0.02287023539294399, 0.07557244400583929, 0.04487364613000424, 0.06723071944208876, 0.059602628762443224, 0.0385499618677122, 0.03963139456426425, 0.06790797181066967, 0.040563210289204316, 0.004839160040231241, 0.06788420010237925, 0.039332444073572274, 0.021693057027615367, 0.02529692231497217, 0.048596921542118636, 0.0803649215207946, 0.052927329295104554, 0.05291174706672469, 0.03493786496560901, 0.04641629823092972, 0.025236906986984036, 0.04239538999935312, 0.03278059584479178, 0.0466293970783872, 0.09178406724165525, 0.03172778419309086, 0.5856292334295089, 6.414233801826355, 22.9087540026634, 43.96729461608395, 74.46543678160637, 87.24094160141485, 86.2174383286507, 71.94485895095333, 74.12005639845326, 70.4837917512463, 61.586455914282034, 56.47718045019335, 44.67620418917748, 33.81006210081039, 31.807356765193326, 24.07831849590425, 23.366253376007084, 35.91164058254611, 25.85522278662651, 32.036450639847786, 35.49313152990034, 26.355630928470244, 27.922256954254646, 18.46298275455352, 15.888614519949883, 8.851747109043984, 6.198121991849715, 2.80486558233538, 1.625412426167919, 0.2594527133530186, 0.21643785699721307, 0.24611090910771202, 0.08009855274952228, 0.02644135233675761, 0.2597251035753758, 0.07297429511503828, 0.07895842239621186, 0.11465789750218393, 0.20473862187035624, 0.1507318746899405, 0.10178103201812315, 0.09164849266169534, 0.04059357418408317, 0.1666607272120253, 0.06049971006089642, 0.1501355212061636, 0.22915706158645693, 0.40754002188482596, 0.23355489656809839, 0.1927660618938746, 0.14208292588591576, 0.12290256638680735, 0.2911261589296403, 0.08868635241543094, 0.12835328962894219, 0.06691148294316185, 0.11338188613374388, 0.16120492480695248, 0.4654679134968789, 0.4094443326034854, 0.6543751445508773, 1.1105085524820513, 2.2375246449824306, 3.6601893892211304, 7.449811110573431, 13.476087201026179, 20.443426678257605, 20.819258382243497, 31.55500323541703, 38.48146377071258, 36.803077651608376, 39.1413672508732, 35.29063524738435, 31.183413574772498, 32.736372101691465, 33.417566207147416, 35.23831475165583, 35.79428326699042, 33.126400824516054, 41.926116712631725, 50.07047122524631, 54.43736360919092, 51.55226815131403, 64.67929578596546, 63.1304890878739, 68.51013352794033, 67.76700127509334, 58.85845530417658, 31.463647311733617, 14.68365946123677, 2.547095504499251, 0.48813538265324413, 0.06213096023026494, 0.022314063220795606, 0.051350919529795654, 0.08906083151457772, 0.044448589906096465, 0.029487172366991162, 0.020194749926186858, 0.03244999826194779, 0.037985002667072325, 0.0501214939680311, 0.024008940822715243, 0.021941621915527412, 0.017386041769397356, 0.06719359482127814, 0.08030767177021311, 0.019728709913549886, 0.04961284989070508, 0.058580188666500395, 0.05598479769222679, 0.026774995119100618, 0.03259908280245239, 0.025534457451994383, 0.020985377561901847, 0.07213967296505167, 0.07177628681904848, 0.06251590026001777, 0.08369826200988986, 0.01673628238119906, 0.04088084566436949, 0.016950101351305362, 0.08070811358911377, 0.03895540241031878, 0.04117940545022007, 0.05385626069900971, 0.006363704216651499, 0.07887940808770158, 0.06957730038031455, 0.03130370473128653, 0.11074794561512048, 0.020330303438728856, 0.02321469533677784, 0.0707988505582175, 0.14328275747116537, 0.15054013820425158, 0.1445253367625898, 0.18300099959296567, 0.15150744678272357, 0.10344283760435159, 0.11907581930920003, 0.1214687332450863, 0.1795416069968093, 0.17671973744948066, 0.11315985087064967, 0.11031497570295488, 0.10815165831797546, 0.16422138068704836, 0.1437110465861136, 0.1607813701153763, 0.12394719621947697, 0.18594965669176272, 0.12829241628247884, 0.18434997317531418, 0.19498094465703736, 0.14343317117421858, 0.19658484165706944, 0.11893815330920682, 0.11392052255330548, 0.1377581297269752, 0.1490568387652597, 0.16984903193529577, 0.13619221536622894, 0.13835849751147533, 0.14372187906936293, 0.19890590420653745, 0.11258209034079507, 0.18234239380446174, 0.13048911977919841, 0.29682974481294233, 0.1381877671566702, 0.17303421101983518, 0.15505293233981057, 0.14166321695571946, 0.17463495173761923, 0.10012272745370866, 1.1868948729768878, 9.497051527423244, 29.483864307403568, 53.612089080195275, 85.46163682014712, 101.01719994698801, 96.8645081981536, 78.52388966468074, 78.49032202074605, 75.96122480207875, 65.9962001923592, 58.27366129044564, 46.33541384050923, 34.71847518797844, 32.03890212120549, 31.18904413715486, 28.461439686436808, 47.499675289277114, 56.97801613038587, 45.020819710147, 47.025786292168405, 40.72096455481745, 41.69565000841695, 35.51970951018795, 26.38445838805168, 12.749956461691088, 10.816476056652686, 4.262391617221217, 2.9161165029771867, 0.5620048591686834, 0.516123546948356, 0.5835615927653929, 0.11035720246934122, 0.13651228690099332, 0.28201798638028486, 0.11831854139604878, 0.5365094530486292, 0.17088121283919583, 0.2128083315948325, 0.21223830089213389, 0.34862939268350607, 0.3263218622774847, 0.14459025505329334, 0.3857920420986991, 0.1634712733568684, 0.6598462380709187, 0.5140639655292034, 0.4180346910030611, 0.24209156752594058, 0.25415311627570664, 0.23949990739985821, 0.1094310864385578, 0.3176784599500318, 0.30628768246500726, 0.24233982597868292, 0.17190976248633477, 0.20956443953177623, 0.5209339049554641, 0.5983763849062305, 0.5740339717557353, 0.9530123359253331, 2.2782329638158125, 3.32977113223845, 5.530779246361026, 10.999302633347051, 19.612639257984778, 35.971931334464784, 28.377491158823815, 48.28551038619011, 58.399836094148704, 49.97357299250942, 54.50665620065505, 38.37506555741833, 36.79643315653647, 36.55760788148449, 33.450549417926425, 31.699001289183098, 34.179149289284986, 31.418985243766542, 43.45700602377615, 54.50378502568891, 56.235852702971435, 60.06050094481438, 74.28014401466616, 74.60335516160535, 80.08886045025241, 79.1991884477677, 72.29159647418608, 43.11483806179416, 19.11875205655252, 3.3797725266025913, 0.931734151897892, 0.17891474789188755, 0.15371633873831841, 0.20285148684295917, 0.15467987816420295, 0.10443391023023475, 0.13238854285690094, 0.1277599775142247, 0.12284172368386101, 0.17778852203440282, 0.10897189333674409, 0.1711043129645048, 0.12998146395529472, 0.15404027135622117, 0.24543419300067812, 0.13624556572927585, 0.10108953807502986, 0.22644357815865548, 0.22228388926915585, 0.21730995616845547, 0.08354472266810556, 0.12569725513458252, 0.14011717491572903, 0.18524237367655003, 0.1169737659755253, 0.14223038248958128, 0.13318391066164742, 0.2155834851005385, 0.1863740694018141, 0.12202008672419096, 0.10706229661140712, 0.2493799135329262, 0.12387963492543468, 0.14860633310050736, 0.12823315938153576, 0.14348966249775502, 0.10694770517969325, 0.19041348248720172, 0.2474959041442602, 0.1431701731898131, 0.07091925659727666, 0.12850226308669777, 0.13651046361173355], [0.014804559121389064, 0.023416588233122905, 0.06258510481265765, 0.027596578452615973, 0.018178471626954216, 0.02297480447938846, 0.055185273860491095, 0.06067902826133275, 0.022923624060387095, 0.01688497430164247, 0.03666355462384321, 0.04570223533758714, 0.05638026377005924, 0.03428833348856818, 0.025328404698220473, 0.032157191796408545, 0.04550795927042923, 0.08049730917498951, 0.05158283349667346, 0.04547474935891167, 0.03330669906591216, 0.03856544833510153, 0.024991571159672835, 0.04078790387739578, 0.033967836775005825, 0.04700355825104541, 0.06922715989452216, 0.03194907252045889, 0.027247453033323252, 0.030867329558297515, 0.03470100973161959, 0.03197676851414144, 0.03125411202950824, 0.019610167383366538, 0.046924448181544585, 0.06021906524115513, 0.06902667468473797, 0.030000470428457184, 0.006730159502401347, 0.045068818520033554, 0.04641516825124141, 1.0086121782660484, 6.547587523537298, 20.980754129348263, 46.802328863451564, 64.83664558779809, 74.33655554248442, 80.25946786326747, 71.61257928417575, 61.692548182702836, 52.58967622633904, 47.25642165830059, 31.172395636958463, 26.764730215072635, 25.604634323427756, 22.807327393562566, 36.07267348997055, 35.67185824917209, 37.86268241943852, 47.0325170793841, 44.3430890575532, 29.72768472086999, 39.7372615721918, 26.993120024281165, 16.46746712346231, 11.790448619473366, 5.083434399097197, 2.8236404974614424, 1.3324469207755982, 0.30089384125125024, 0.07424597808670613, 0.07785977570400124, 0.03352409566662485, 0.12285816393071607, 0.15543977609805523, 0.1145118888046953, 0.008271894691842458, 0.05755279581212709, 0.028565794590019414, 0.08651663053540454, 0.3707778525929297, 0.056805270198251934, 0.021929584759017153, 0.04073862527166644, 0.11073551966898865, 0.15431405585860053, 0.03370597260072827, 0.14212787992531253, 0.1171504641552606, 0.11369828810735096, 0.22805761816280506, 0.08614271834132173, 0.16896510436650247, 0.2912484878493894, 0.23090129057245873, 0.08820194736002915, 0.045408333366316174, 0.01643011917269999, 0.05538001341084319, 0.08014535306081658, 0.06655207279348566, 0.07807607296854258, 0.03805776569812048, 0.18655223080948477, 0.1391583545914581, 0.7298797897754178, 1.4312511802681032, 1.5139234666862798, 2.8225870959220396, 7.433087104751219, 9.068302146850094, 21.01009738060736, 29.852571025971447, 34.437637406010786, 39.896815746061264, 35.28436337747882, 34.02742808864963, 25.19185389241865, 20.831192193492768, 17.839072904279156, 18.26475989434027, 21.66094606922519, 21.53717371725267, 19.55453326625209, 33.904901089206824, 32.6979426799282, 43.40533271912606, 47.44161636598649, 45.83834363568214, 44.014453272665705, 44.47733217670072, 27.87118181105583, 12.464512836548591, 3.600132263475849, 0.18684162818376096, 0.05626895885554053, 0.07490521206730798, 0.00987369835662145, 0.03784146460313951, 0.09477726469236998, 0.015361480144483429, 0.08380820328790335, 0.013003448107009454, 0.03212466944880303, 0.02197308706179742, 0.0428807066993848, 0.0157472149904577, 0.045093505703393495, 0.026550035315355467, 0.057117102457390684, 0.02029463055453474, 0.047574776390026656, 0.08312147441169909, 0.007084260183957316, 0.030648712962565404, 0.06088444324690969, 0.026390192985174157, 0.03768943062412643, 0.07329763784523934, 0.021548475168885726, 0.03487086674619106, 0.03156364219443452, 0.05392075764135488, 0.05284433515982763, 0.03445570837826498, 0.05900165959892254, 0.03306816992980819, 0.04345443760675769, 0.07318175938581267, 0.0025782634029089804, 0.04557416458884555, 0.03134314676806812, 0.017512505648717765, 0.04939430415810597, 0.07928872120476539, 0.013658278997266486, 0.055594169459636175, 0.01948988391837526, 0.04005976411844454, 0.007334028308715432, 0.04131744683329617, 0.05263767911181335, 0.012946644602643867, 0.012469586330435932, 0.01050201781664885, 0.04105231912446119, 0.03522591785557809, 0.054849034040084774, 0.0905099710930259, 0.04720379831269384, 0.04751666096009074, 0.08988999911854345, 0.06258548019574055, 0.03666062433753283, 0.04799597919167531, 0.06797740235924721, 0.020190687744968364, 0.01942719877397101, 0.0426685884444704, 0.03730495024712817, 0.04898272342078629, 0.03601963474084774, 0.06464876565000703, 0.006578158082125048, 0.03871455585824386, 0.07798238807628233, 0.02191207007384829, 0.03715085549159877, 0.03586302338648708, 0.013161413521776277, 0.008657754027104426, 0.023641821913300984, 0.07071412123379207, 0.017083285736941525, 0.014200091808884135, 0.02465452886216583, 0.06107151042670012, 1.5122880834725596, 9.049788559636763, 25.09696391320998, 57.417878566249726, 74.94317362385412, 84.9785263307633, 91.18180182672317, 80.39732348534369, 70.36893690786054, 60.6578936115388, 58.20017176289713, 44.529166298527876, 38.04900284736387, 34.42526232811713, 28.86945639887164, 39.17120864314418, 44.871326415769516, 40.339129663282826, 39.2926569907896, 41.4881605486716, 33.53258186771024, 30.72014243372025, 22.851685477841286, 13.902018358630519, 9.099384969280614, 3.8840260621040104, 1.9497133791446688, 0.5582132142397666, 0.17230822013751154, 0.03705306819850399, 0.2407471445058623, 0.22663385907728828, 0.19637337074645106, 0.2467037692305542, 0.2716917953183574, 0.5559547257519538, 0.5668190169718959, 0.44525063867049836, 0.4250791146149559, 0.6533353487330099, 0.24696935659214375, 0.04529797840082357, 0.047832507519952716, 0.02148657334938405, 0.11982974175724292, 0.15933812175306583, 0.3893256073276843, 0.34645385619613434, 0.4207482970049305, 0.5971117882478623, 0.9435976669192315, 0.8899667931179848, 1.1288855921837593, 0.7827887023168226, 0.6803780685990088, 0.6180981234196694, 0.5714212442117353, 0.45095879043782916, 0.47474229648228616, 0.25767842307686806, 0.11189595901317174, 0.3196903600567772, 0.20705401536918458, 0.1744230058524878, 0.4496396483192521, 0.723344385623932, 1.6317839487906427, 2.987583313257464, 5.996509713511314, 9.58125893146761, 19.395032044379942, 24.131876499422138, 32.04911401194911, 33.36407684510754, 35.69268211241692, 32.695422557092485, 23.91974295339277, 23.345033353374852, 24.587897139210856, 20.154761806611095, 29.871596482492265, 35.37438177293347, 28.511355769249704, 47.81633215565836, 44.561812185472064, 52.58660108812394, 59.379808902740486, 58.196398442791356, 55.388271654805834, 55.74714106898154, 37.25821379692324, 15.739478161258084, 4.757178512311751, 0.4205508301815679, 0.034597530405247406, 0.024845121961627758, 0.05258840050608401, 0.035786609946479725, 0.038134282559997616, 0.05893851863220335, 0.04005166273864527, 0.011860996507288469, 0.05638461514946915, 0.02701828357643418, 0.040428643114864826, 0.008828591634218973, 0.06331368890260497, 0.06856931253306328, 0.0291713104853707, 0.05246799063658523, 0.05225959556898283, 0.048067236859952255, 0.037022608542634595, 0.07086360797045693, 0.027592412849527695, 0.04032375801715159, 0.053722739234686866, 0.013609052102472033, 0.034827820265725735, 0.050220284836306694, 0.017674094659366438, 0.06768709334034113, 0.0872707981315832, 0.011493421775559265, 0.07009018092386185, 0.026567341241564964, 0.04631340496181961, 0.011417306152232473, 0.01273899551315774, 0.03287882746888265, 0.04444746758728739, 0.04303722612319454, 0.023086919531887098, 0.07227567655424919, 0.004639265675758643, 0.19521264028885674, 0.09035552010661171, 0.15185207909634038, 0.14262360009935596, 0.13049990629717229, 0.09899785757184991, 0.19355966769639524, 0.16062024650314163, 0.1369057190153868, 0.120454654998837, 0.1289022758963608, 0.17153238757483422, 0.13634831344168033, 0.11861877891445353, 0.12082287515964239, 0.1688524128328408, 0.13107513107599753, 0.23889976944173538, 0.13346953888333615, 0.21548827569330894, 0.1301209685663062, 0.1296631391009977, 0.23204260836205176, 0.12257343203189874, 0.15431011816666973, 0.11868076308840707, 0.1944094583872826, 0.11940452465487104, 0.1147621084425238, 0.2440897853023583, 0.14831711958733299, 0.07751338904903782, 0.19749588873838225, 0.13710894681993993, 0.13385828253963303, 0.14749106230033984, 0.21245018549023137, 0.12477096290357652, 0.07319230841653002, 0.09251953463160223, 0.23757154152037638, 2.468073718970822, 12.942401670640516, 33.14849553569671, 69.99473494868126, 88.65985116650982, 92.8989056617983, 99.76899977653258, 89.00947555418938, 79.38336726157897, 69.16470650703677, 63.12802583940568, 41.90439070424726, 40.635821665486986, 38.58680686643047, 32.01035314990629, 47.563021567560014, 50.76468367730418, 50.49466379227177, 63.28112379197152, 59.26511095416162, 39.3366777512335, 49.78758988841888, 34.92572538314327, 21.469724639769524, 13.970232298297267, 6.991931757619304, 3.8173099775468153, 1.6582702436754782, 0.6759302233976703, 0.22243853177755113, 0.27037534982927386, 0.21791660587393472, 0.1309161984752263, 0.4286871435901811, 0.4389695450663567, 0.6059657421804244, 0.40516533318065834, 0.3710037259565246, 0.3448001481592656, 1.021842761866508, 0.46823002818611364, 0.25755119119440356, 0.2271741808902833, 0.38719943754615327, 0.2968626253066525, 0.27493136664552076, 0.4656789247547427, 0.38712215459635185, 0.3503441119626645, 1.0703451979544856, 1.1172161731989154, 0.7599538889142775, 1.1683652285606632, 0.6501272176542591, 0.6428284834950202, 0.7708877409177443, 0.6506420287393755, 0.41440260686701347, 0.4427654494441325, 0.3966793465998865, 0.3872150350962916, 0.45558298907933703, 0.28200186789035797, 0.33163547876381105, 1.2447227441495465, 1.5897085613781408, 2.241702704660354, 3.7351733398052955, 9.488173242538206, 12.438748748071733, 27.314730844190045, 39.37829409876178, 46.12359016172348, 52.58904864711147, 47.914411021817116, 47.654048012148955, 36.84233273229292, 28.104460854684156, 28.881723611585556, 27.684914335127804, 33.814227657933394, 34.886497759049945, 32.38701051281345, 49.8147052334201, 50.0444737557442, 60.099501071437714, 69.6939048459453, 70.61088438956969, 69.47775871522965, 69.81632986376363, 53.15284229093983, 24.198144943483417, 6.9912355369137185, 0.6307136916345166, 0.1800200901925564, 0.1454028598363361, 0.10396071304116519, 0.13348498321588964, 0.17653593763468728, 0.1588008949352849, 0.15834485811571922, 0.14818447912412305, 0.17463501302465317, 0.20406785060561475, 0.13061937004808458, 0.14023835470359172, 0.14218037226988425, 0.2255263410869145, 0.12828948216572886, 0.12066261722676216, 0.14227319148279008, 0.1318814539380612, 0.22308423664541016, 0.17281400670688, 0.15565660962414357, 0.12367159608871707, 0.15989546603973837, 0.11253204947758107, 0.22748962525398503, 0.10032250786260252, 0.1458941213786602, 0.32215210699266006, 0.29005584216886954, 0.11356455979928856, 0.11960508647344767, 0.11383899547640355, 0.15224379517378347, 0.1865630786144926, 0.12707672667719666, 0.2909359852633169, 0.1292796048425859, 0.16754963435232642, 0.1504426152114907, 0.1849368118470715, 0.06722251464041971], [0.0386257394547424, 0.0566862469478961, 0.024912279144289996, 0.038637361008553736, 0.0430095856708865, 0.03104796926040323, 0.05353731531349402, 0.018282646178117683, 0.012540073122739071, 0.06764666688057684, 0.012956531924916612, 0.010901739512900672, 0.03979551741072247, 0.018277517219464627, 0.112873088838833, 0.02715230874356724, 0.04763654988980101, 0.04104967612112242, 0.02761878159588143, 0.034882055460325176, 0.052575549381154205, 0.06315379869192839, 0.023316585030707142, 0.04987455701695816, 0.01305564646534021, 0.050026816991908904, 0.0005466258787031797, 0.026477802800194874, 0.029710013937625675, 0.04605570830585015, 0.04699574415421775, 0.03770520820492699, 0.015861790142803183, 0.06341552497037957, 0.10453830503167645, 0.043123836193474076, 0.04915882788238026, 0.05554558033303869, 0.036631735161908215, 0.12688889723992156, 0.9821792031007429, 9.987331128889515, 28.487535215193226, 52.12021950752505, 70.59037823830882, 77.68398469494235, 75.94785736453149, 66.77194303081882, 63.53627397168068, 48.43594504940895, 42.764542948815134, 29.363851547241214, 26.00743232234832, 24.08904813951062, 22.319857189732215, 25.956882776752597, 44.560149100519, 39.06841901040847, 46.38412575567923, 40.16576090166646, 20.53470415453757, 26.76855060362047, 14.394114017486574, 4.866484672792496, 3.452222135759169, 0.5854291925507208, 0.3262868367375866, 0.08783779512610167, 0.16796088567183864, 0.0748626022569595, 0.09742122564104297, 0.07291332983802404, 0.166692964191879, 0.1898664344222315, 0.264537392124053, 0.39998320802565546, 0.4930550767289054, 0.530152332878882, 0.1517357869494346, 0.8722074654313826, 0.1446023132772215, 0.20023859075961575, 0.15617782520430704, 0.09627609273358699, 0.05950814713874172, 0.1219172394203563, 0.12941063652115484, 0.22720722992333675, 0.2258095178272455, 1.2702495292309792, 0.7310050810056349, 0.7537529281070157, 0.27006937431231626, 0.7499618960484382, 1.121607266606823, 0.2634113348059116, 0.8388238051725972, 0.49517652740882295, 0.3052258846019545, 0.35716630878948397, 0.2973651176979465, 0.15300498013534855, 0.18865380916864644, 0.07371553114705509, 0.15117854991507146, 0.028294827375981598, 0.07420738257708089, 0.28766154161384033, 0.4362247439642107, 1.002293607640651, 3.5859894223751563, 6.500258734149318, 14.597112363384618, 24.987845536201235, 40.94441806116412, 43.271987822748, 48.3895355655301, 60.441406234618164, 58.15411136996362, 54.66755574749362, 69.82230755590624, 51.17569708055066, 21.96010328108265, 32.34713962001185, 21.460822820663456, 21.416213704693703, 31.608214109174668, 38.557545984944994, 48.9758946049598, 47.25773172993814, 47.642857490047334, 34.91203631124189, 27.88641433562002, 15.177902617762166, 2.1363745629787445, 0.537509412294434, 0.11104841295990253, 0.019680423391682487, 0.06649911313528015, 0.10866437798305865, 0.08938251183398309, 0.05539936479181052, 0.02176086346979343, 0.01394706445881316, 0.06398516113779719, 0.08111105285464756, 0.036834491822387905, 0.013600907630227027, 0.07807444120126386, 0.04537529199414196, 0.02097088317837446, 0.03310258259936687, 0.028877617273059104, 0.03858824711172812, 0.031214853853828488, 0.039877688001480796, 0.04636000225981397, 0.03526144518306659, 0.04504782388046865, 0.0349631535279895, 0.024610072779919834, 0.041717992074066595, 0.02672908346979849, 0.06767714185820473, 0.07253426187221082, 0.04087665133298405, 0.045561474342379844, 0.08483746539681189, 0.02312278202284248, 0.012030423555012432, 0.05420231027528644, 0.006223435911740507, 0.034098489240052245, 0.008700554401824072, 0.0054016787720273345, 0.03869531939046518, 0.01816277831582533, 0.049639325889368216, 0.02155846495541834, 0.033208268258960984, 0.01867462272545503, 0.017933005564695886, 0.02064740063712722, 0.03376952342448696, 0.009807055410478386, 0.05258325239523284, 0.04507127383183088, 0.13329876256325554, 0.01442596517247899, 0.019281640153137908, 0.030444284315190973, 0.025319096729940465, 0.040945162576052456, 0.04033228074530921, 0.04769588339953654, 0.052695488106579556, 0.03467239634764772, 0.050756404657037034, 0.06087039319437839, 0.004991223705151389, 0.0371205605446331, 0.015884629139045797, 0.028981548591306614, 0.0047026340748303605, 0.031173577036468253, 0.04477300515939151, 0.04505461908035702, 0.0623278065224088, 0.030384797587870594, 0.02489691142052893, 0.017317815894080747, 0.016727547063642455, 0.03983857921294628, 0.005498391626808312, 0.06731161832689278, 0.050104011841599023, 1.6654980687364456, 13.218767950611731, 35.49400229607859, 60.355686756872366, 80.00862444600752, 89.7619979612289, 85.15588806521508, 80.86235969297348, 76.5840736512215, 59.91761292180708, 54.22117825477354, 41.3452019230012, 32.80302493802963, 33.937848998654275, 29.422339970065703, 24.92603682702588, 37.40111750941123, 28.693094868813795, 34.448176814663796, 36.8377161026001, 27.778070626720307, 20.537479231434485, 11.092615819746449, 3.4545027488662354, 2.4909855088879986, 0.24607307968601105, 0.17996001357753433, 0.17388599353932566, 0.39955622126017853, 0.25310498542122306, 0.6037039441927787, 0.23457877307889924, 1.110980462643408, 1.2962286126229072, 1.5055337620358316, 1.5002050995826723, 1.1493883113707266, 1.0686894674454968, 1.041609056053623, 1.4846397864241756, 0.8059231480283122, 0.37695056007754424, 0.13683678642396005, 0.09409845716530278, 0.06580881428934875, 0.08962110991800025, 0.2190343434772184, 0.49941829495852996, 1.6271301791552575, 2.263637088960217, 3.4017203940499217, 2.8460918991796436, 2.9582251079620856, 3.2019869310240594, 1.8282186985015871, 1.7461307226650178, 1.2711852596652125, 0.7883383658143782, 0.7237920261198475, 1.4116063569822621, 1.166783042492405, 0.9228969293255961, 0.7115902679581797, 0.487969417365328, 0.3466951432487657, 0.2157215954315278, 0.11074865041601081, 0.08800148513288268, 0.2118557319045067, 0.8324056431170433, 2.0959675312042236, 5.317068417226115, 11.502832001255406, 19.60783827689386, 30.570766810447942, 32.40936998398074, 40.24109394319596, 44.0102171128796, 39.973564763222974, 41.105756913461995, 55.29232655802081, 50.67799145175565, 30.31708948073849, 38.71749631820187, 33.53302117316954, 32.681252994844996, 43.270077628474084, 49.179653890671275, 60.865445829206905, 57.62728998737951, 60.57654757653514, 48.06799534828433, 37.22482658201648, 17.05709545843063, 2.2731677130345376, 0.8135554062262659, 0.05928940605372191, 0.07485488009068274, 0.01871225679473531, 0.010438833757483912, 0.04781656906068806, 0.020224702048806414, 0.034700829700957385, 0.06216540737378021, 0.018543876414637894, 0.021744499831730803, 0.034582829177980466, 0.05298806857618113, 0.07629812079211397, 0.05987309610411044, 0.025016153005943186, 0.006429415887161609, 0.031036916526875673, 0.04623639780367094, 0.029627640333567417, 0.04814646184264172, 0.04069372485842436, 0.016586914388162476, 0.04719088590073009, 0.04647549384483888, 0.047210574360384096, 0.034483276052220214, 0.02530334787743707, 0.04771776670109361, 0.033783408768114545, 0.05247794977960087, 0.10646212800976732, 0.0708907351438557, 0.04451890528622655, 0.04894850993408792, 0.10282900965502186, 0.0553684531440658, 0.0497013368763991, 0.017450881536088644, 0.02508589765056968, 0.018601978438035138, 0.12365455829328108, 0.11179997585713865, 0.15824473042401577, 0.21601859239801285, 0.2055914003041483, 0.05992632772352907, 0.14871373862749146, 0.12712166539483494, 0.1615817021698721, 0.2006843620009961, 0.17610573329992835, 0.2639681581527956, 0.14452383523025822, 0.17161282680688367, 0.17260258176153706, 0.13425582088530064, 0.13821623498393645, 0.16767672833896455, 0.13060334348870864, 0.16367474630955728, 0.16140971543087115, 0.27772081535189386, 0.16668720321068842, 0.18819352822198024, 0.13319163282792415, 0.17425920093251815, 0.09288370984816745, 0.08296382883864065, 0.17672361385437751, 0.14117763978579354, 0.13853875800005852, 0.1481450409177811, 0.1595736937897821, 0.11991005841522448, 0.161949148581874, 0.09296512201188073, 0.08286924762350899, 0.12333008941383132, 0.16261210574978785, 0.18609271595074287, 3.185103578913597, 18.2271953552, 45.12460170253631, 73.18325319597798, 93.48491561028266, 99.72987021169355, 95.48277485755183, 84.53414532446092, 80.08898596609794, 61.349411395288286, 55.53625483666697, 39.705427615873276, 38.03087365242743, 37.43010382498465, 33.972307020618075, 39.72570626966415, 59.21208835417225, 54.65274487772296, 60.95882569589923, 52.03754771140314, 28.73856886740654, 34.54036428082374, 18.319571095128214, 6.361562253967409, 3.913609068239889, 1.052490691504171, 0.4988615328986799, 0.29313456567545093, 0.37280813880985786, 0.2823578842705296, 0.542789290268575, 0.40602929649814484, 0.6968764768492791, 1.6110957750389654, 1.7704833707501813, 0.9894108279578149, 0.7031333314314966, 0.7566773615056469, 0.9965939747710383, 1.9478964637364111, 1.4293822934550624, 0.9628633686131047, 0.6196081746489771, 0.34906633859199865, 0.5038466815265917, 0.2794184049050654, 0.44788944384744095, 1.1265879412812572, 1.6294775951293208, 2.9264541547144614, 4.011401111079801, 4.307197832292126, 3.5319560766220097, 3.605150445815056, 2.583564966917038, 1.6772410321620204, 1.8167324051741631, 1.3007113914335928, 0.6299113217861422, 1.1878888260933662, 0.7112642822246398, 0.7321231403658468, 0.5539493527143233, 0.5688106617139232, 0.37443567728323324, 0.2720464633837823, 0.1823859688855948, 0.4345937734169345, 0.8534736126180619, 1.2354247656560715, 4.325465781073417, 8.381941299284659, 18.548537492752075, 31.122136346755493, 50.39469042131978, 57.472929031618186, 65.44273414919454, 78.05746493800994, 75.38844108581543, 69.50297955543765, 82.15983267753356, 63.40261136331866, 35.45777528516708, 45.71525181493452, 35.68928533984769, 35.586307433343705, 48.59673869225287, 55.29718245229414, 70.61535589156613, 72.74954888128465, 75.09067043181389, 61.21014764232021, 43.27039141808787, 24.716392024870842, 5.052499646140683, 1.3747909905449038, 0.2696531127777792, 0.11648590586358502, 0.16456267285731532, 0.15715104798155446, 0.2458572267524658, 0.16165993506869963, 0.25739585920687647, 0.14837549548716317, 0.1530358994439725, 0.18285852256080798, 0.15510216114982484, 0.16652085487881016, 0.12111416477109156, 0.133548476583054, 0.09371150615474871, 0.15757898469605755, 0.1506555416891652, 0.23719628101154683, 0.129090519021115, 0.08779503975904758, 0.08719811937020672, 0.09680139156238687, 0.18277659711818542, 0.11905305883696965, 0.16707631458918895, 0.17962814428873602, 0.08839894686975787, 0.2534140099681193, 0.19948794716788879, 0.14222402395980974, 0.20482738081726337, 0.19515097021095215, 0.12257551579105279, 0.10400432642669448, 0.22078618737718753, 0.18826806857701273, 0.10558224538521421, 0.10360800616082647, 0.11814306129611309, 0.13941197565967037], [0.042030161411892024, 0.03199006397006733, 0.04697425538794168, 0.03787870030669916, 0.042139669850228295, 0.029074185858330423, 0.042811387233556285, 0.03286244467862191, 0.09080489196123616, 0.09192492016741345, 0.06761778536583148, 0.027947262860834602, 0.03262951947568405, 0.036546017584060474, 0.013947032857686283, 0.03055678241165175, 0.019517185376776804, 0.07970413238170647, 0.019130705510296168, 0.02542431316068096, 0.042647187778305624, 0.042100833022906896, 0.007600220879765168, 0.09821441775608448, 0.02836493974281175, 0.06455373244300004, 0.032730359629157095, 0.07879903780356531, 0.048976008660129966, 0.04784656140292364, 0.08072374944364832, 0.008885958213208905, 0.006784452153595105, 0.06106430153933264, 0.03806226646467563, 0.038335181457260926, 0.023911542319242033, 0.04584643606757445, 0.35652892363648264, 1.676215209787892, 12.321662076057928, 38.54166823048746, 58.299141007085005, 79.83110581674885, 76.6718170719762, 70.00775721765334, 60.11730470964986, 51.07355071652321, 33.98944385590092, 50.22232578646753, 32.992208696180775, 21.938385117438532, 23.643502189267068, 29.725670583786506, 38.695001525263635, 53.817366323163434, 59.24161203445927, 64.39925424514279, 46.63050943805326, 16.75955230189908, 13.789868970071117, 7.7478783938192555, 2.9738800227642064, 0.7168767649319865, 0.21684448114566265, 0.12630069493165902, 0.12207818683236839, 0.24599334525485195, 0.3446138968631145, 0.4042619623003468, 0.5728841657119413, 0.5206548038028902, 1.573196731267437, 1.401657755336454, 0.6341251118048545, 0.9948090511944987, 1.014542127809217, 1.4613375981007855, 1.4351783308290667, 0.09824722164100218, 0.8836405616133445, 0.2202384498330855, 0.03923247726033292, 0.041083866625183055, 0.12075452479503809, 0.2759971175222628, 0.1967305362585091, 0.04535730808011947, 1.370045412932673, 1.1638645539360664, 0.7417572782404962, 1.8055241098327024, 2.665895271685816, 1.9921806358521985, 1.4292013741308645, 2.505818687139019, 0.9288504130897984, 0.9286097389075064, 0.9467875957489015, 0.93567349857861, 1.1784582224584397, 0.5947781618564361, 0.8389064200943517, 0.5213347221574476, 0.13765907455836573, 0.1476240858075119, 0.24326731330685078, 0.07037161098372552, 0.08795135999999701, 0.06326650554734854, 0.26994119248082565, 0.5120102063782754, 2.0508531649266524, 5.482062918524589, 14.977235140339022, 26.95307850837708, 45.25854279918056, 61.84422231489613, 80.83089443945116, 90.38355242821478, 92.06651595331009, 79.94461136479532, 42.76676301033267, 33.34783038785381, 21.781356949960035, 23.477066216930268, 21.083249584321056, 35.94716156682661, 37.96211450330673, 47.853406398527085, 55.149768014107984, 41.857494846467056, 34.01684945629489, 30.482642919786517, 16.491807391566617, 1.3944997974941808, 0.09513463704816758, 0.033893445807118575, 0.013010447277807662, 0.09321161846239721, 0.03452041982522896, 0.01596010795178553, 0.024703702130805583, 0.032423778902739286, 0.0362719074943133, 0.06261795849329041, 0.03810471922699963, 0.04069043068034996, 0.08719128586592213, 0.03831048661302175, 0.11445358951365757, 0.023879230645815694, 0.08497628052869151, 0.047455745478791576, 0.017643916540809216, 0.020551756475000613, 0.15121215053143042, 0.0063587428397318775, 0.021535840463794528, 0.04277693625960139, 0.03474506361770534, 0.0641768439973314, 0.06267773633402202, 0.06546523917706744, 0.026000058879294706, 0.04763746919531015, 0.047656383906160636, 0.020826845242071058, 0.06494941685589091, 0.03664474716530212, 0.008828947865103763, 0.02565370478306807, 0.10289387431957069, 0.06204733407245048, 0.06063251906344968, 0.013048066982939359, 0.05176547651870116, 0.04180598110260983, 0.03285532389136572, 0.0424617676875524, 0.05753734764913398, 0.06961415687035169, 0.07032180760776804, 0.04162684293283571, 0.0667576295053286, 0.08165136700676334, 0.027630705754422856, 0.088442996925404, 0.029877091968251817, 0.03272682413338654, 0.04578778437609154, 0.0807453454622338, 0.028546791779057636, 0.12334931822073077, 0.06003007135023514, 0.030685642230955344, 0.06115592948551621, 0.08113263355147454, 0.08428854807730644, 0.03916866213624035, 0.0642164507430167, 0.030824233282117114, 0.05608874816267241, 0.06803633750326211, 0.02153004883908697, 0.03098536647045084, 0.028760367516247977, 0.015894604561429833, 0.04447807663030202, 0.02016512339093512, 0.04704854676439878, 0.06304882549410386, 0.020955436930601156, 0.04638694557211092, 0.3230271326197732, 2.294483833735989, 16.30772565641711, 46.84594954213789, 69.18616187187934, 90.37464864792364, 88.19921585821336, 79.7044054154427, 70.27629052439045, 62.09699161591069, 48.216060899919086, 57.61895887313351, 41.10956161252914, 28.669495928672056, 30.153365827375847, 24.207364474573446, 26.278503402586907, 45.29032968705701, 62.721856563322014, 55.32690617345995, 39.47074436372326, 18.697836629806027, 11.461440209419498, 6.448652109792156, 2.819541620631372, 0.8321136716873416, 0.4894369353930797, 0.1725682610225293, 0.3275512188913361, 0.5001484380374032, 0.6240778380343992, 1.734483612160529, 1.6705392950004148, 2.1115538045283286, 3.3903099740705187, 3.43289882425339, 3.3267430624654217, 2.748701163837987, 5.069322691809747, 3.8618511874829573, 4.637724689898953, 2.5694669879251912, 1.7126519449295539, 0.4874095909537808, 0.08821069608412443, 0.007700186256589669, 0.04536713698818799, 0.3478299646127609, 0.300827007740736, 0.4362825069937014, 4.411006790976371, 4.344569684997682, 4.865688921943788, 4.64067284137972, 3.9577472546408257, 5.919510645251121, 4.898208802746189, 5.8318594001954605, 4.554628787502166, 3.9087558705960554, 3.394586583299022, 3.1414358317852025, 3.0426533904767807, 1.9224761955199705, 2.11995723747438, 2.755390521018736, 0.8761542278432077, 0.8546251346988063, 0.5119779081113878, 0.3416974307788957, 0.1624867278001001, 0.22880671425692498, 0.2939158527841491, 0.39741990847452996, 1.6324834789960616, 5.14988866544539, 13.124484958187228, 24.53093844075357, 41.926759981339984, 60.99509977525281, 73.60436670241818, 84.79611258352958, 94.1906519859068, 80.55362209197014, 46.68270834030644, 42.71989460914366, 30.137507684769172, 29.86945094600801, 29.789748384106545, 42.93667224145705, 47.07002670534196, 57.47584727502639, 67.33070819608628, 51.74445644501717, 43.864603042602546, 39.46067171712076, 17.844317113199544, 2.587071075554817, 0.12960272540728893, 0.01334391769036771, 0.0181584958843286, 0.03100590720292061, 0.03612977903216116, 0.0012736118374197115, 0.05783275115273653, 0.0545261356408798, 0.08063979386802643, 0.03938609321090964, 0.04968899903037856, 0.01959329621205407, 0.038106458246587746, 0.030987471297022798, 0.07302055916478557, 0.07164686392512053, 0.06880172062665224, 0.029614136118682164, 0.06204769796421451, 0.09597070710433107, 0.05353250045088991, 0.02351111007644044, 0.10099001559278659, 0.07825463274193388, 0.04325997384805833, 0.021713593929645517, 0.09093507328220914, 0.025656721254269925, 0.022518660407513384, 0.03344636072494811, 0.0476560008621985, 0.055668817066978064, 0.04146983704319404, 0.10384389229359166, 0.01991773636320666, 0.019382599050239212, 0.04964072399983003, 0.05556399325629877, 0.04418917721317661, 0.053824019888716365, 0.16502301509101547, 0.16501184552907944, 0.08301852751643428, 0.09703516329248106, 0.10697852489688706, 0.2770958101797489, 0.21302033876699789, 0.12498780409054411, 0.24876977046651227, 0.1592249705666496, 0.16568169748831182, 0.12299920837845534, 0.1460270069900059, 0.17548328686145045, 0.18285749600298945, 0.1473165934364642, 0.16055859174699555, 0.17734702556364, 0.08502854304688592, 0.10934635711413239, 0.15174687990257818, 0.16609192225000552, 0.16542243801297682, 0.1831879250464901, 0.24367482611729255, 0.21348544606758704, 0.19798112882962152, 0.26497712659259, 0.16551675875821423, 0.36701654474581447, 0.13957452419544422, 0.12060178984557429, 0.18207202605422468, 0.1426549790607345, 0.11490594145030746, 0.21123763684543873, 0.08678313720250323, 0.304308632208455, 0.7156519435586468, 5.230245772869357, 23.306182276818063, 60.903386915883715, 82.61789491099697, 103.10541491354667, 99.09483063605525, 88.63354775213426, 78.13222531349429, 65.49426624851843, 45.745779621985655, 62.98506721373528, 43.823245571505645, 31.37701980529293, 33.68271450842581, 42.890247068097516, 55.362203582640625, 72.19732622946464, 71.61551321706465, 73.0540503225019, 55.16999175471645, 21.874556387624434, 17.87824953756025, 9.733448855338558, 3.686313355161298, 1.2271198822605995, 0.5631430206760284, 0.3265742422832597, 0.2918006227381768, 0.5059407981893709, 0.5258655500027442, 1.214804865660206, 1.1181132928017647, 2.090845160907315, 3.6744202385025644, 5.670257749096041, 3.527859651273297, 2.794002578143151, 5.638536560919977, 5.315588703078609, 4.399581416960686, 5.033223648225108, 4.0099745940777565, 1.164239508009726, 0.36036264211420094, 0.4319650193135585, 0.33320543806879754, 0.9515008138072107, 0.3990561497067252, 2.821933040695806, 5.8042743513661055, 3.7919111597922543, 6.093046107599813, 6.777650713920594, 9.269351074772498, 9.074919185330792, 6.676907087526014, 6.728581372768649, 4.4235441569359075, 4.554765089865654, 5.182374225508783, 4.0856302505539315, 3.6375372111797337, 1.6514139406142698, 2.144755932592577, 1.893027653136561, 0.9115128014837542, 0.6449211905560186, 0.6405714046089881, 0.44396266100868104, 0.24071818638232448, 0.37787513627159985, 0.5039235048236386, 0.8379086058947348, 2.7510344837942435, 7.434678606448635, 17.386437269949145, 33.43840183750276, 53.93697507919804, 69.99067921792307, 85.10114746709024, 97.91806467117803, 97.13505760315927, 87.41033307967648, 54.920387806430945, 46.38787554156396, 34.627848825147076, 37.81348413036716, 34.985463080867646, 51.413879086894376, 56.52767312142157, 68.39014822436918, 77.13944988866007, 67.8465469421879, 62.495014129146455, 54.07620353083457, 26.507905183299897, 4.697841386641226, 0.3645909571599576, 0.11396929171056518, 0.18164051936999445, 0.13501769532599758, 0.15406711507708798, 0.10467389493339485, 0.11233034618799725, 0.11352761137870052, 0.16082145183557467, 0.11345368389400745, 0.11553848492762736, 0.2078532442570694, 0.2186723362894789, 0.1990370278156573, 0.2170276834118751, 0.2411830178912609, 0.14210485132230868, 0.13645083132770755, 0.14795411648529191, 0.21786345469374813, 0.17274790864077308, 0.09882950975048928, 0.27129143776912845, 0.18806603586962148, 0.13697811432423132, 0.17944140269631342, 0.1759814125515761, 0.14417076062771583, 0.10655137725294599, 0.15361386681756667, 0.1804480728723349, 0.14485950431516095, 0.12900156089134757, 0.22352524281990147, 0.08926523143365499, 0.12709041666840354, 0.14925243633408702, 0.17721443106570553, 0.11331322933396987, 0.12178744114334546], [0.01085079466593602, 0.07114237204434411, 0.035540500370365, 0.004248655637756231, 0.03598833621870126, 0.04982096533621511, 0.055705547152507695, 0.030393774223123348, 0.054105518896493225, 0.053149310932044065, 0.038979300523116704, 0.0489085776010348, 0.007112356937385255, 0.03747729321701392, 0.017903903799672282, 0.021888177706709793, 0.03346026905121342, 0.04401549741986298, 0.055978925628287185, 0.004477371666355119, 0.025249355915753592, 0.10449793219806687, 0.05418330746432466, 0.042204706884560086, 0.009404706990256185, 0.01753903910397522, 0.03215232330764974, 0.06464000160415327, 0.04079766383755111, 0.016194717590546897, 0.01818654427845632, 0.04728011216127104, 0.021907082841461225, 0.06141638022757346, 0.029039780849650986, 0.018013059837563385, 0.03884851016224392, 0.103363876921996, 3.2243745942269606, 17.939097266043387, 50.44820331758069, 71.42993019473168, 79.39123553614463, 77.17828919810634, 68.5182842131584, 60.84019753240771, 49.60012020603303, 42.80820677357335, 29.802747118857603, 30.325197019884666, 32.07840823358105, 33.77700044262794, 37.437262150549124, 48.96802633039413, 53.083843877238614, 42.272611048913774, 26.713035337386597, 15.554303065423044, 11.465638126096419, 6.165108382701875, 3.5645963251590733, 1.1695061479845357, 0.1460114400833845, 0.03210412871633326, 0.09209456267736613, 0.2793814794671151, 0.2890239523783807, 0.38067031531564655, 1.9022957235574725, 1.1224671236930357, 2.2990041202114475, 0.7012534129523462, 3.4636825659582695, 1.2686526342745752, 1.9284589131993635, 3.304565000918604, 5.743477613695207, 3.1898991667455245, 2.1715942602003775, 2.676579317738933, 1.1566413866896783, 0.28375657695916395, 0.12035150892071186, 0.052447490123731476, 0.11182057596142254, 0.3458427631806943, 0.14139389108505943, 0.3657662892533887, 2.5958853767764185, 5.037408326902698, 5.559031098119674, 4.732457284004458, 2.8175821515821644, 5.301668211337059, 2.8380380474752, 3.273456928230101, 3.387005867496614, 1.601241432851361, 2.231105195899164, 4.01098215291577, 3.282185917900455, 2.1155222625501695, 2.708759423225157, 2.656478886642764, 0.8070010643812918, 1.1357056133208738, 0.08677911524090075, 0.18280454400566318, 0.16678095705086188, 0.28615510631953517, 0.1026416858357768, 0.11050930922670711, 0.2282832004129887, 0.6704045231303861, 2.3031076548560976, 5.72729048229033, 13.294171594804334, 29.370492119942945, 49.38672365680818, 50.522151762439364, 48.87033185651226, 58.25923481295186, 35.239118837541156, 28.937952749190796, 23.865810363523423, 22.932445118504187, 20.731675778665853, 44.759201542023696, 46.901898230275805, 45.32343449131135, 51.09105625460225, 60.765056687016646, 58.01378073230867, 31.0412904139488, 24.839556409466653, 8.51124615438523, 1.4102133027007504, 0.079747217166568, 0.10005891999049533, 0.03402765675057327, 0.03740914203526993, 0.06066412402076587, 0.031349352080254786, 0.023084035210852182, 0.03265424113300058, 0.06511529021325611, 0.022569909774427934, 0.05310533748519036, 0.025972466307481932, 0.06734962394881634, 0.04876239653376322, 0.046323180243733435, 0.04699429241760124, 0.036179107433605584, 0.017447581612354806, 0.02194369226814278, 0.0860078945275276, 0.0425511280134801, 0.04186787334601245, 0.04638143739993534, 0.007950236397464911, 0.07279256373764047, 0.00690563912353208, 0.02805230500657232, 0.05421721068541369, 0.051278213955341816, 0.03737929908017959, 0.05345857679663647, 0.052800878822322816, 0.06617659011915808, 0.0202091466335039, 0.08322555511709183, 0.06710226947982466, 0.046406683827480005, 0.009118551125509605, 0.09259440440444217, 0.03394296190010444, 0.027809422575838627, 0.011632671662335916, 0.035942298164891626, 0.03803769419450433, 0.05261045617742404, 0.08700751669464574, 0.053531194270979014, 0.0063813448275229145, 0.034549914210313754, 0.09926863134868684, 0.06655691446916712, 0.027720516157006065, 0.03308182544705849, 0.010977302595312077, 0.04571358876062497, 0.02904479297989559, 0.040322785085487756, 0.027766431636747815, 0.08078600940925461, 0.024026564675413316, 0.037415684426143285, 0.04165357174051385, 0.11079725869480642, 0.028274225356477885, 0.035528449807316065, 0.07034269882546318, 0.03315405221655965, 0.1575708335205432, 0.030905406043354063, 0.05504093140423779, 0.05465083560275455, 0.042112458407157854, 0.01736439020943738, 0.011584550806982143, 0.022665791423811067, 0.012759144583176221, 0.1571119315321407, 4.1137764434660635, 21.18395055494001, 57.3797413610643, 81.8476277012979, 88.76207597794073, 89.51545346167781, 78.02261075665875, 73.14357449931484, 60.221302432398645, 54.11909857103902, 36.38956569856213, 42.578752040863044, 39.707977156485285, 29.47219329495584, 31.26042539073575, 47.055380575118534, 58.894066502971036, 46.909421336266306, 30.051613661550707, 19.611723384549542, 13.845518577483393, 5.613929081347681, 3.284836949840669, 0.9683807951308067, 0.18913918715571204, 0.052314298077216076, 0.18538128073898055, 0.8701742067933084, 1.0363918134281713, 1.832855430341536, 3.6760744981227385, 3.267715558890374, 4.0038939397181235, 3.8795373997380658, 6.086940448130331, 4.407157474948514, 7.161018761896319, 6.229182260651743, 6.787608140899289, 7.793232269825475, 7.843112561010546, 6.023156335276942, 1.9941049261439232, 0.5562971364105902, 0.17618131553453786, 0.09636161878945367, 0.09364411340004976, 0.10133146864151764, 0.1564687394326733, 0.9896060271609215, 3.1831521997528696, 7.530944356995245, 6.955419394277758, 4.462071637953482, 6.553256819325109, 8.265651849008377, 5.115084984610158, 8.285989338351834, 6.701233137038447, 4.589742335581011, 5.372534163536565, 5.7177017581078315, 6.857440058262118, 7.801239298235986, 5.034694046743455, 4.964173263119114, 1.9340827340079894, 2.826865911483765, 1.3596678020492678, 1.0861974570059008, 0.6792562094426925, 0.3402866951880917, 0.2939288762788619, 0.07227733896504487, 0.47838725089546175, 0.649740680331184, 3.222915472522859, 6.869695503865519, 16.37738008652964, 34.10276897491948, 57.4779849667703, 65.26908689929594, 65.37397500007384, 66.21735911215505, 36.80497607877178, 32.83379985440162, 26.28668154439619, 29.82056252418026, 28.0576277548267, 50.234583193256015, 56.390441156202755, 55.98439347359442, 59.33715704948672, 68.99929231212985, 66.8717908859253, 43.1028316866967, 30.72120735722204, 9.074353383433435, 1.2528128777780843, 0.07190023984519706, 0.054370547013898055, 0.030231302296141946, 0.07848377730096541, 0.062240326942335215, 0.06952534429728985, 0.03277242551707933, 0.05070918299738438, 0.03506127406933135, 0.07323561536688959, 0.0447958384099747, 0.03166680167909832, 0.04468938283201668, 0.0238283681533029, 0.046649307703539256, 0.027987821470765818, 0.0534954141344755, 0.03586967686010945, 0.01025295592919593, 0.009899658203545597, 0.01872905135725535, 0.039840391010887204, 0.06395958146200546, 0.03876980611934297, 0.09470023455158358, 0.04303102464144749, 0.04555575166558547, 0.05728229016606366, 0.01957461324280068, 0.04731231849760779, 0.05453349008495289, 0.05102206479697939, 0.12306358274673262, 0.05394552143350725, 0.06241170081099676, 0.013565921352335043, 0.013274672918111808, 0.04681412385956896, 0.07192709888782232, 0.13789576508345144, 0.1296857999817979, 0.1041156849673679, 0.0960732632947545, 0.12686793707431326, 0.15589581291762092, 0.24496324811010595, 0.17401943073397683, 0.13055587668092022, 0.168210722265705, 0.23891630161914135, 0.21482522659484418, 0.08048732704933613, 0.17785589180646405, 0.09681256878520213, 0.10256308521474562, 0.06855928444213445, 0.20820731477391338, 0.124452369918506, 0.23653595918609252, 0.0920494554203845, 0.17141364394657074, 0.11328573443836744, 0.27572598368410145, 0.18077099425417764, 0.1522752660657129, 0.13656168425035092, 0.25940843347099524, 0.22162226509423028, 0.1120986735388156, 0.16961995632417742, 0.1551127331631799, 0.11157052486293739, 0.17289945615395425, 0.24475975983565856, 0.10301270987838508, 0.1929399485309278, 0.5170641190582707, 6.926734120615068, 28.64468889851724, 70.05278602723153, 97.02407806150376, 102.87098269308768, 97.20095342205417, 86.21513981972971, 78.54106964603548, 65.95499177132884, 56.22599186435823, 40.522347496401885, 41.77375224328811, 42.131480247743674, 46.96309504970428, 54.594776168946304, 67.4461906186996, 70.19199094464703, 56.31762627632388, 36.949872355307306, 22.213225595412716, 14.87369437371531, 8.499110341072083, 4.761259738476046, 1.822863437475697, 0.4695622550864374, 0.13309360421713323, 0.3411762151987322, 0.6055736890242946, 0.6819215212618152, 1.8868464880412625, 4.667447920768492, 2.5900072147769313, 6.642174989946428, 4.646168572287406, 10.674829463804922, 6.1669705279411815, 10.04768071636077, 10.542166079244307, 11.968759567506853, 10.80305370592302, 8.893942006172674, 5.785035615967167, 4.6829937446501955, 1.129404325639048, 0.3144854054816308, 0.37543661712158116, 0.3404949485294281, 0.6151012487469182, 0.34450915732210685, 1.7062994212873521, 9.29385216005387, 12.014184536472445, 15.213604031070588, 13.178372440799592, 10.400513602841286, 14.255188568945854, 12.82607299666251, 11.031705333340554, 10.849985845627325, 5.678801651923887, 7.977040419655462, 10.31275547319843, 11.733715457300987, 8.319279474596824, 8.288067213950619, 6.720079635420154, 2.667523055307327, 2.84695384002501, 1.097749327459643, 0.9532493941726224, 0.6825197440001273, 0.4007275390528864, 0.48624535181349327, 0.24003852849766133, 0.5290464696384246, 0.9737573840445088, 3.5427107253382286, 7.345689342867944, 16.737861594846173, 34.40499544143677, 55.164029752054525, 59.11508029507053, 62.742676504196666, 68.17581422867315, 46.99047319350704, 42.26626857634514, 36.07030830075664, 35.94987192461568, 34.60728383833362, 59.59950085609191, 66.03460804108651, 64.34078739535424, 69.50237551043111, 79.02770242383404, 81.69128987096971, 55.06121658509778, 40.389759617467085, 14.012725295559054, 3.049263809957812, 0.2681443179326673, 0.20566978642056066, 0.07714850137070303, 0.09115543081274918, 0.10311334318811856, 0.12360562825755728, 0.08242454124434341, 0.1547489180079391, 0.13480354310764422, 0.14536542878035577, 0.20528565461356796, 0.19828872845297862, 0.15689594070276908, 0.13792689889669418, 0.1470573492828877, 0.102125350235691, 0.13751880385943, 0.14349585248818322, 0.16137095138190255, 0.17885791948966442, 0.06079205687368109, 0.22771704611518692, 0.18556293550758593, 0.11458871210174215, 0.2217291190379089, 0.1421639013795122, 0.1725496450859693, 0.17382286789436496, 0.17958004928884969, 0.10513914779068963, 0.2685882812065463, 0.11743636050772284, 0.2561764464142823, 0.15153534770492585, 0.15312828964764072, 0.1459984778757057, 0.1677164883022347, 0.09510570956814675, 0.18858875298211653], [0.023190147964464083, 0.010449602080869579, 0.030127311606080304, 0.05326352315023542, 0.02110824082797814, 0.04105999149502285, 0.010654742232403688, 0.007489772547306794, 0.039224402693611, 0.08490847408651345, 0.02918854746366701, 0.06525264977807961, 0.03503123576182031, 0.05851036741308147, 0.026739174762981075, 0.05937185243613297, 0.03393353135775655, 0.08162702839340895, 0.047327146129382235, 0.02159101794654083, 0.03528306035385017, 0.027875290815568263, 0.014643097472857806, 0.024631191908772436, 0.05571390517176159, 0.041194459077932184, 0.04647805257850597, 0.10842479164561919, 0.05241187086569206, 0.041609479550031886, 0.022191500644229596, 0.018219035982544866, 0.06832568891226284, 0.08237740385436243, 0.09415982846891689, 0.0992991369698317, 0.6164826584919807, 3.372354098866063, 20.292123210045602, 50.98528169816541, 70.83916633359848, 79.92690578583749, 75.90575464310186, 63.78024931876891, 64.96215358857187, 52.760707255332704, 40.754720472520404, 27.163774505738292, 34.38295172106835, 50.91982910709997, 60.059881210327156, 81.22868553284677, 85.08715245031541, 58.52080199026293, 34.37690342626264, 25.76143499343626, 22.580345715245894, 13.9653822875792, 3.8464073452257344, 1.2610856467677702, 0.22087356736583097, 0.14753984677935802, 0.21924605953597257, 0.13075173471964177, 0.2674265854781674, 0.4044169878527042, 1.3665214084809827, 2.6186689542185877, 1.3347856339908417, 5.621543872740961, 4.5158291920538876, 4.284646164986396, 3.8582276528881447, 4.792193510840017, 6.161887136197859, 3.928115218877793, 6.928134406766584, 6.4422071653027695, 9.085057531633685, 3.041686526229305, 0.5072160587916451, 0.2842148813989855, 0.10612058303048534, 0.03654342437643678, 0.06685489202819525, 0.11675526237776203, 0.3369363169035604, 0.6072020855161452, 3.491046000872889, 7.1908895719435915, 4.2737336408707405, 2.2288012937191994, 4.821238171669745, 6.421277398063291, 2.8836152534331045, 9.322382500094752, 4.408853900048041, 4.951627562122961, 3.5430929112818936, 2.550077976719026, 3.4938223035104814, 4.746997510233234, 3.1734411466506223, 5.977752939347298, 1.5452601400113877, 3.5424724413502604, 1.650460804662397, 0.6658228883339513, 0.39737614953229505, 0.44069722655319404, 0.19633762508390412, 0.15681462813048594, 0.055548384214841554, 0.05122649535957364, 0.15237805974339286, 0.6869778854231681, 2.9193428975920526, 7.5860364975467816, 16.239386200904846, 30.7601898331796, 33.74508019416563, 35.96967989398588, 57.75230376951156, 68.59986951274257, 60.12202332096716, 28.972975592459406, 25.558513133756577, 33.87678161744149, 30.7481324672699, 38.84076856797741, 46.46212208655573, 51.06042646592664, 50.7817538322941, 45.50640913747972, 39.034749384849306, 20.80822671613386, 4.1525917283950315, 0.37245393039718755, 0.046121285432168556, 0.02976372436199698, 0.018979374416953614, 0.0737846322778252, 0.03172153674606835, 0.04207580876086028, 0.018176717285607612, 0.05563739214032408, 0.03195280145343033, 0.1013280442284961, 0.039440018139899745, 0.039743898406384454, 0.08138090732597536, 0.046734649898304094, 0.03528870642185211, 0.007813068354622492, 0.022617271245126764, 0.049736021507170894, 0.016583558923054128, 0.0387515923789432, 0.04170401863032772, 0.05987409201841201, 0.03945037181819639, 0.02425863952075522, 0.028903890258422302, 0.031888584133177515, 0.047052323577865485, 0.18223895661292538, 0.014304179217546217, 0.037810690851221164, 0.035594766208481406, 0.03548310123263829, 0.08329766697340435, 0.07595411667059507, 0.0762000845204438, 0.0908273230156591, 0.06143314989223596, 0.04004931084871773, 0.04034252334085684, 0.008609918539502449, 0.045598192936590606, 0.033133425299198396, 0.023098052704646703, 0.0456248949311914, 0.023491318194916653, 0.002996417174618992, 0.06645802783990098, 0.03735526307155529, 0.020094654793220184, 0.016560015125921177, 0.043845785961997126, 0.033095140055182486, 0.03457940093451931, 0.05901729545345711, 0.023210889795013977, 0.06614731789957132, 0.0032249328233451857, 0.04030812982349627, 0.03195149718873924, 0.044605932874424804, 0.05180877197774188, 0.030155685587575844, 0.0050371482821872406, 0.007676422209178488, 0.06338521853209504, 0.12837741373767778, 0.023230011349604018, 0.014805413309424637, 0.056956725780882185, 0.05467623907832369, 0.06099744504618068, 0.035418914555902445, 0.03362958214335865, 0.04189446425786422, 0.6090232297297448, 4.334083718638267, 23.067647257158836, 58.12807075438961, 79.8881684580157, 91.12287213725429, 85.17426044710221, 77.0652308002595, 76.02822672936225, 64.13609850791194, 57.00584926912862, 40.81437972284133, 37.91531670478083, 44.72712047638432, 43.98087386162051, 56.73342889355075, 63.832816923818285, 58.424225391880164, 32.96723888766381, 23.42471826461054, 17.2045216637273, 9.490536470567028, 3.241963237524033, 1.5014682253522258, 0.21728073757502342, 0.3023321560073284, 0.5027406037815156, 1.1327214250641486, 0.8580182913330294, 1.6362870748965972, 2.8256494864340755, 4.702338874340057, 6.315992647601712, 7.118968992464005, 8.048151519990737, 8.419403856800448, 10.208855809703952, 7.075420387329594, 10.463452935218811, 9.05161246176689, 7.079808048663601, 5.0521216277153265, 5.725322433056371, 1.8133377163640916, 0.48657051017207487, 0.10604815707812387, 0.0695987125377982, 0.1283006747103026, 0.08826241467989261, 0.24215035711324986, 0.5408083707574876, 1.0993414420273997, 3.359811584795675, 5.1601098718181735, 6.195820050854837, 7.43750467415779, 6.678685392102888, 8.60157637826858, 11.598846720110986, 11.538301014131116, 12.046839248749519, 12.04237461090088, 8.788452802165862, 9.153168509083411, 7.653385064294262, 7.623978564816137, 5.585791468620301, 8.33804605468627, 3.072722770514027, 2.8835931901008856, 3.165594445120904, 1.642051610735155, 1.8902785619420392, 1.2688747384855825, 0.9181255498720754, 0.3760762698948384, 0.20353036331793956, 0.08240788649286955, 0.2112834642250692, 0.6887703473048826, 3.3768180012702946, 8.897788870719172, 19.67184155218063, 28.53049497450552, 38.960302798978745, 35.63135193240258, 44.07115897824688, 57.799380056319706, 54.7304391860962, 32.53459949647227, 30.1452680941551, 43.869345188140876, 40.10664293842931, 44.98292176954208, 55.46353017130206, 61.827097246723795, 63.228583643513346, 52.78181745160011, 43.865018813840805, 23.179291640558553, 5.258228942271202, 0.5190294103757028, 0.04435470200053627, 0.046084517042242715, 0.07471470898317714, 0.03677006382795592, 0.044003048491093426, 0.08967808387692898, 0.018062196717026736, 0.028494295604046316, 0.06749326543461892, 0.09479650116014866, 0.012891984229246456, 0.11670366635606175, 0.08324316747847103, 0.06113155639820522, 0.03329952082206165, 0.06142287282273174, 0.07839024562629, 0.040929948069876244, 0.04628453110795348, 0.01130664858200978, 0.05286065666305442, 0.0472549768164754, 0.07520714264002538, 0.02783123118382308, 0.0627570723994605, 0.036334010411895094, 0.01659347976167356, 0.05543321821718447, 0.07943767934076248, 0.02699577016755939, 0.011660370528848182, 0.031600207571060426, 0.003416681757962872, 0.012268665408144796, 0.07028439953442543, 0.024585569457661723, 0.04455617929418241, 0.07498609563035351, 0.14942744145950965, 0.07782400705881658, 0.13875595924835052, 0.15022725257421696, 0.25438573121303515, 0.22262780146012384, 0.08974830349606853, 0.07935353990403876, 0.12019829899673501, 0.18303976364193425, 0.10342927784809183, 0.14339691989364164, 0.24161150618906946, 0.27845215352792896, 0.14463781379163265, 0.18163114245380127, 0.19686155261531954, 0.20274766660746069, 0.12988818508963432, 0.13242885440347657, 0.13370128048043098, 0.1483426609587285, 0.08593798900443701, 0.10096661160669981, 0.09701913673310511, 0.11280902090572542, 0.22425391500996006, 0.25489752391173, 0.1136879152768562, 0.13906573456141258, 0.18483251663705996, 0.10848757255101397, 0.15655795803233502, 0.16437495067234964, 0.20935379599611606, 0.1878171645465397, 1.2137343037512995, 7.0418326412477805, 31.654770681934973, 70.72350348195722, 92.47620751780849, 99.98196878740865, 95.84820639702582, 83.06703767468854, 83.38420837156235, 68.3979380515314, 55.81995202649025, 36.95206103786346, 45.637596730263006, 67.83743919864779, 73.98666443363314, 95.5122632365073, 100.68346900324669, 70.70913191764586, 46.346729878456365, 33.24315017269504, 27.255130429421705, 16.245362912454915, 5.291993685307042, 2.0512814387198417, 0.3061032084928405, 0.4895610722803301, 0.3737930827323468, 0.8824798464775087, 0.8849734933145585, 1.9491318877666228, 3.25704695716981, 6.658904879323899, 6.666225492954255, 10.622217732091105, 9.325122275660116, 11.909535700275052, 14.058255187926756, 11.900141623712356, 16.818032879983228, 12.783599611251587, 18.087629579728652, 15.613323949998426, 20.222150087356567, 13.863071184004507, 5.049448532442893, 1.498184588647658, 0.3630288119517988, 0.3005887850398018, 0.36427894487015666, 0.4676031844029504, 1.8351570036142104, 0.9675241249703592, 9.121930753031085, 19.51268549888365, 14.049663236064296, 15.276721831290955, 15.091007409557221, 21.208390843483713, 13.886676007701507, 22.439591461612334, 15.505295991897585, 16.373977430405155, 15.07458640683082, 12.524680033806833, 13.561896893285937, 15.793294060614803, 10.443713607326632, 15.419603970742996, 6.5468427635008295, 8.540187362701662, 4.594042724178684, 2.386341085357051, 1.398841738700867, 1.2893841992462836, 0.9043009110516118, 0.35539070084210367, 0.29997530183003795, 0.22960977358443124, 0.3334786863096299, 1.1471868811115142, 4.568519371171152, 10.747933618484005, 21.378984528203166, 40.23865422894878, 46.42017233756281, 48.64816880995228, 69.99399754308885, 79.3966248727614, 72.49882313512987, 41.28807260144142, 38.21150664360293, 49.28373398319368, 47.731918827179946, 54.773502888218054, 63.578247254894634, 71.29848372551703, 70.78859913733699, 65.32174864122945, 56.56367263486309, 29.83841911438973, 6.606346589903678, 1.081638191976855, 0.24951027105412177, 0.12564782714170794, 0.24130148572787163, 0.25200506702305814, 0.11041901810395141, 0.1288388284944719, 0.21140662051977652, 0.09597581691078602, 0.19870328927232375, 0.18225634680880656, 0.2082890563554341, 0.15599439311171734, 0.2265225771454073, 0.12596978325276606, 0.1082974371890868, 0.1659964523728817, 0.1763172348540637, 0.16192045092823046, 0.18405175046815028, 0.0981428498221982, 0.12468483163824967, 0.1403933955777076, 0.21705720844047688, 0.07297582729088684, 0.1846063368382954, 0.09728375882391008, 0.11339386774887962, 0.3594188830785213, 0.13620894672649522, 0.10914573400852182, 0.1407788144124131, 0.14658193043883772, 0.19324885050375618, 0.18007777661325472, 0.15232852449820888, 0.21017357136213013, 0.1983323801429041, 0.10636340991984453], [0.009312211449498372, 0.05599288375026757, 0.08667013157279262, 0.011407919659940226, 0.04476053707842385, 0.023984393450401487, 0.022556288731134227, 0.03177565702747914, 0.02900942270043156, 0.06285838369700698, 0.016414196035193823, 0.05574426523620083, 0.0059000342885302684, 0.09945796997917276, 0.047454676786137205, 0.010872059351494236, 0.05390574997891823, 0.00814166549037421, 0.023300972158810305, 0.05546045264289264, 0.013863946791858444, 0.050338392611593015, 0.03488814202888358, 0.0670595370954083, 0.0370415807100794, 0.01858678308405703, 0.06329097439565005, 0.01732142416820411, 0.08462397967495265, 0.09011339035726364, 0.09638756618744905, 0.058302378372078946, 0.021700539791415778, 0.02809385378514567, 0.06142137512083977, 0.8173865200050416, 2.278287631850089, 16.814332123725645, 56.293331115476555, 67.89156790702575, 78.38717152995449, 69.39341206704417, 61.59223748791603, 57.32350633990381, 50.443296432495124, 46.22586204159645, 27.42440227539309, 38.08487684495988, 51.60202733932003, 95.51597379869031, 114.33512933792608, 104.25655211171797, 77.45260407847744, 46.76528992191438, 30.35171812580478, 11.337876723658654, 3.594257288402127, 0.9857048010153155, 0.4152190114461607, 0.06737966991720662, 0.10230855250190343, 0.4536156446462678, 0.5380258781294669, 0.8742700805587154, 1.1429383413445566, 2.427016064043968, 3.612364910302624, 2.99071581613633, 6.74952486830373, 5.576530752643462, 4.529357446778206, 4.857559319465391, 6.80756074766959, 3.842799254963475, 6.20236256430226, 8.85702661929592, 2.429440333958595, 5.435233741037307, 4.778604459378028, 3.5802458467022067, 0.7635396706961817, 0.16162733036664226, 0.046699379210270224, 0.09762645293507846, 0.055633929422906334, 0.07857687996640321, 0.18960755799085866, 0.3900650966792338, 1.057686361093675, 4.203807096327505, 4.917971174563132, 3.412175716892366, 3.8364472216175454, 5.590932715323664, 6.073511233252864, 6.625742220109509, 8.940978088686544, 6.561558515794816, 6.617242934242372, 7.292384822522441, 7.157689159916294, 10.044860532206874, 5.32927385260982, 4.0669646714964225, 1.8141310157314425, 2.880784773057507, 1.9812269268497347, 2.006923722163324, 1.5023668158438899, 0.9170385017510384, 0.9046737200790836, 0.3822841867804528, 0.30188745728904204, 0.06872581663511454, 0.07807005917833698, 0.02695540691004886, 0.39845182890853575, 2.307888533799879, 9.391584877044926, 26.586954670567668, 38.711244060147195, 68.58767094150667, 102.57703242763397, 80.50927577480194, 52.38064919748614, 26.189961779502134, 23.293330630948468, 18.117596487845145, 31.69788733605416, 34.62408334978166, 43.51683785838466, 46.97254796181956, 52.048310695155976, 53.43525294334658, 56.18160240111813, 40.850155661183024, 10.240061206202354, 2.1432124799297703, 0.14863910634190808, 0.04968876154312203, 0.0364675969936915, 0.026124829704302455, 0.049678557251970616, 0.02418199816959039, 0.10214055708098797, 0.05222951129619634, 0.03499004321413175, 0.060436140084939624, 0.009955332685832777, 0.05236784379268366, 0.030893797896081404, 0.0769903731622523, 0.05868353775792545, 0.052116513327364965, 0.029182681145386833, 0.011819876737952715, 0.054328243638719284, 0.06947971610051971, 0.06324789344122814, 0.03847882294306352, 0.034935949745798306, 0.07133409320827454, 0.01704099576830143, 0.024885209427485545, 0.016601962270215154, 0.06663040528374334, 0.06367400303603181, 0.0433641120100454, 0.032993296326528636, 0.020834812556483576, 0.022836768841971795, 0.034720805443583, 0.03814994139716991, 0.0161954338827561, 0.07476131011161112, 0.03494286751975456, 0.03790789974793311, 0.004111854359507561, 0.018622210820115382, 0.06847161334007978, 0.004410569278162814, 0.060505252707028584, 0.05740550774780493, 0.05016137650536914, 0.06427719002409328, 0.051103408012779496, 0.052406106054061846, 0.039542172134162924, 0.04725110041157854, 0.0314103843899624, 0.04938504215510142, 0.03584080300624332, 0.0675137889301104, 0.019978301359280463, 0.048518340073285565, 0.07313230074942112, 0.040328197496672796, 0.006701217179426984, 0.056917578687951456, 0.043227836459634766, 0.05206841832747863, 0.02419311219015189, 0.028385189361870292, 0.061535686930461284, 0.03677885468688704, 0.12819475539389158, 0.03231780596017357, 0.04053055579143186, 0.010457081971840273, 0.03935464147117831, 0.046284293620696956, 0.650010159419429, 2.743217935485225, 19.112962638178182, 63.83152254166142, 74.92495029203354, 88.25813770294191, 79.60684822451684, 74.50971249611148, 66.7687737557196, 66.20961635343491, 59.96221419303649, 37.2851251786755, 32.27606823367457, 42.39970368723716, 83.32460403442383, 102.40186722047868, 102.06319409032022, 80.69737695878553, 48.44453896245649, 30.74916993418048, 12.302660153758142, 4.830281196102019, 1.7653183446776484, 0.8579302218652541, 0.17895841490357153, 0.3418506483637518, 0.8131870711522718, 0.7256344369342251, 2.4857964582981604, 2.1216293929084657, 4.220177598537938, 6.167108301193484, 8.350790815968669, 9.249060653871107, 9.314256329690258, 8.148170488495982, 8.206953579379666, 9.80210013927952, 8.185494292166926, 13.389648948946308, 7.697523495843334, 7.16894293023694, 3.12118953754825, 2.2986905757457983, 1.0563549615683094, 0.2322586298349404, 0.2142616616742265, 0.1939653572175772, 0.12836323345019934, 0.04619238605242103, 0.16026643645619193, 0.24146126102535959, 1.897363220491717, 3.8344492643110217, 5.061922650183401, 5.696997527153262, 6.235250167308315, 8.100589196528158, 7.70869097402019, 8.306174835851117, 13.671174126286662, 9.244702900609663, 12.63811399859767, 9.853966620660598, 8.847409948225945, 7.934995062889592, 7.62846379510818, 8.9893977872787, 6.513407989855736, 5.112750193765087, 7.184326466052764, 5.480704797852424, 5.727010032823009, 5.1671392494632356, 2.7271744608879094, 2.0525689567289045, 0.9151289816344939, 1.1622785680717038, 0.3156655179637094, 0.08321764908971326, 0.14847445872522172, 0.3251986548064217, 2.9074674315990943, 7.499799757234513, 23.628548152985115, 34.06222735681842, 55.63630665502241, 93.02550408147997, 85.10965116562383, 59.329857518596036, 30.571586585813957, 28.58562977083268, 25.811478553279755, 37.447781947351274, 42.27664716782109, 51.253924831267334, 55.11847926724342, 61.50937741802585, 65.08011102676392, 66.58082162180256, 47.15672285326066, 11.884560988795373, 2.352672685538569, 0.3903329823045962, 0.08183404067230803, 0.0750118132019716, 0.053493230783891295, 0.03408971753331923, 0.05027413698694399, 0.024200309586200505, 0.016629007089162068, 0.06538270086410546, 0.05450274697655151, 0.043610221586160125, 0.038125786644917344, 0.03809722688710017, 0.04859520933560787, 0.05805983110481213, 0.07093681533250117, 0.04774788927827631, 0.036846645807306615, 0.042982542767159404, 0.03248797707079399, 0.059128140715221246, 0.04976235194912842, 0.04010306340792487, 0.025442762473117442, 0.016017658391877288, 0.04827038039483371, 0.01610035279525384, 0.05443658762341065, 0.035995322940570694, 0.04801531908132377, 0.06867089579182287, 0.055668702153789426, 0.04278115740406417, 0.07766851419282537, 0.020703183329333703, 0.08866301737725736, 0.048076081345038074, 0.037216716070449164, 0.17079780118600016, 0.18241786878676186, 0.24343428983082696, 0.13601727152784027, 0.1325735990558901, 0.21261345414865404, 0.09353593412426212, 0.16718505310916132, 0.12762520732658525, 0.1505722679317959, 0.1928429771214724, 0.10571575918865782, 0.10325922931153929, 0.2420900506718505, 0.12791186210609254, 0.10078496449897367, 0.21891518616147582, 0.15491701302028474, 0.16515280570714705, 0.208002753976372, 0.1464902450360598, 0.15456229898958437, 0.17551255142015798, 0.21781391944856415, 0.11851898830143676, 0.1805939513348764, 0.1052895844763806, 0.21127650814671672, 0.3185493793458708, 0.19324429994148595, 0.27959576958129484, 0.1847298455334479, 0.18618714394828967, 0.2066606598635835, 0.15543179346188424, 1.044537227961325, 4.673086818187468, 27.66327265770205, 80.18011831468152, 90.69407078527635, 102.06574363093223, 90.77828407287599, 80.97760677337646, 73.7172446712371, 64.35624937857351, 60.20281630177652, 37.884035802656605, 48.549340771090606, 68.07967693574967, 109.33655492721066, 121.2804388230847, 111.00745324165591, 86.84937138711253, 54.89713599604946, 35.856903906791445, 14.000933670228529, 5.485772990411328, 2.094779053042012, 0.7354208730882215, 0.4609052163939323, 0.3341094524629655, 0.8944357210589994, 0.7811726858058284, 2.0451377812893163, 2.2056512198140545, 5.786811959358954, 9.593498687590323, 13.669706179249673, 15.948290440344042, 17.13936717279496, 15.574926887789081, 16.095931395407646, 15.37622844019244, 12.935361016181208, 19.111015181387625, 18.814560482578894, 13.961342246301713, 16.688259301647065, 16.53879346386079, 14.398492363191421, 2.624957003901082, 0.6591728161419592, 0.3236486137874665, 0.3938538304740383, 0.20351502623769546, 0.5274358463864173, 0.5344070013492338, 3.7146534602488246, 8.916350506967115, 15.530501142624887, 14.96648588488179, 9.750322891819863, 15.021639312467268, 18.575164502666844, 18.83548240507803, 18.30531131836676, 22.512767199547064, 17.545895345749393, 15.903841160958814, 18.686522553043982, 19.500171176848873, 23.74218902280254, 17.20599843609718, 12.15157731886833, 9.738696986629117, 8.752990653437953, 7.865804943346209, 7.947116657610863, 7.341105563025321, 2.2757692250513264, 2.5215571974554374, 0.674845688045025, 1.3979047825259547, 0.43069343593332077, 0.3061880910348508, 0.23801294606058832, 0.5792694779173021, 3.4152655639956078, 12.115428755360266, 32.48434805100964, 49.902425119953776, 78.35103865592711, 107.29499263148155, 89.7041900696293, 62.500395621022875, 37.99687454777379, 35.896535535012525, 31.04508334590543, 47.54247619259743, 50.09306799980902, 62.11196722522859, 64.86858152574109, 72.09617614746094, 75.32065468449747, 78.49342853792253, 58.754504649869865, 17.623950512178485, 3.80131283594716, 0.6883751685100218, 0.22466896612557674, 0.27459523790786344, 0.11502837762236597, 0.16433188120924658, 0.12934677543178683, 0.2510659964454751, 0.12958184185047306, 0.09990546491838272, 0.1695116008481672, 0.11421320644477684, 0.23002241918396568, 0.10141490327735102, 0.15613748301421443, 0.16680341874880178, 0.1832228586558373, 0.19025454988643048, 0.12040686643412037, 0.14948532706306827, 0.10718092532648195, 0.17083293397820767, 0.19076032113404046, 0.16468707021446, 0.23782903899348554, 0.09672784712165595, 0.14323133764968765, 0.10834195455836673, 0.2337319701309166, 0.1494758275728072, 0.10553826427748127, 0.13913377849084718, 0.15209860619037383, 0.140361572285333, 0.1615107930716007, 0.06901468540872298, 0.15651067508564842, 0.12073305135052051, 0.10134839918464424], [0.02932039119543568, 0.034851511534784115, 0.02725236940257732, 0.029185395011858597, 0.03375695575208914, 0.04085515873626836, 0.079361813653621, 0.06651358453616982, 0.06778547435157722, 0.02619455519673084, 0.005667566344322216, 0.019989629884460763, 0.028700626064692775, 0.027584972220563123, 0.09135583941374095, 0.06528204457173425, 0.051019709076612234, 0.025966854713436578, 0.021319847719203082, 0.02240355761211005, 0.035759793038690285, 0.040328090244363395, 0.03246464969349965, 0.004809160994726324, 0.04856288808608248, 0.01831964822486043, 0.04540952846347805, 0.03063679071924379, 0.02942175037347742, 0.028313489277817072, 0.07077797466228086, 0.040015970702253045, 0.02767988859916166, 0.026252933011780825, 0.15830716658984462, 2.9658487246882532, 17.196388629175004, 40.42960305367747, 55.29935152299943, 65.08105631797545, 66.4741409978559, 58.484822088672274, 49.62245025942403, 47.006441162478545, 33.9975082489752, 40.37552925848192, 42.40332795727638, 69.72690766857517, 91.45735617606871, 68.00534802098429, 50.28281657926498, 40.038476067204634, 35.121420275780466, 18.311791073891428, 6.504208070616569, 2.094469921242806, 0.9432642654545846, 0.18206450307080824, 0.21585967511900012, 0.1509142495811947, 0.4149953444157878, 0.3359639368230297, 1.616217532465535, 3.792533590908974, 2.233106340131452, 4.2488202164250035, 3.7097970756792256, 5.654479034485356, 7.673415137875465, 8.003675764606845, 7.486647559750465, 7.836321467353453, 9.578041607333768, 6.1566556749805335, 10.058882024980361, 6.756239475742464, 5.414118151510916, 1.9524445745252796, 0.6946879168671947, 0.5384884113746305, 0.14670600603905418, 0.05874958602831729, 0.1136370700213217, 0.03514043776498687, 0.05353884748934258, 0.297125025742477, 0.5128751809318219, 2.542678180240816, 2.2153411901766256, 1.6788574163952183, 3.1005348265171055, 7.142008994856189, 5.59251097902175, 3.4939436518376876, 14.613862845205492, 11.916830328203018, 9.391478973050273, 16.703248639260572, 7.312629155574307, 5.752019065041696, 4.605599497595142, 2.88475715344952, 3.792509566391668, 5.805899193209987, 1.6673398666804837, 2.0138328546477906, 3.9635504013107674, 1.4218741415008422, 4.7366973661607314, 2.4997537222600754, 0.9406373193187099, 0.4847212964969297, 0.5390646320677573, 0.39754091972304934, 0.07068936127207934, 0.04464984120380494, 0.234712669926305, 0.12712545753006013, 1.483995169401169, 5.456413559375271, 23.630122984609297, 41.839526468707675, 53.011829160874896, 32.75911988750581, 29.558909054725405, 28.772052180382516, 22.001137156640333, 23.886973511788156, 25.121800361141084, 32.7950527206544, 32.46380659841722, 36.08743336892898, 46.389766123987016, 52.63506197160291, 56.67644862205752, 47.425369908732755, 30.427376724058586, 12.105972901467355, 1.0467940616992213, 0.017461589530050274, 0.1670687303187386, 0.0365342466431039, 0.03730017368892028, 0.01768614905285499, 0.0249321457193864, 0.025227156602927757, 0.01654832462419666, 0.03419549512346426, 0.022564116234500563, 0.02764416017359303, 0.06568079333632224, 0.008954559471608411, 0.006084389995873696, 0.04785763137342949, 0.009786099075309692, 0.0378870468346342, 0.053173818084741795, 0.07403184119011126, 0.04602941233784922, 0.02486038626351905, 0.027740114601328972, 0.02038715099315009, 0.032312385888109287, 0.10378758483115705, 0.07196318162905593, 0.04580894372456017, 0.05451822961350122, 0.005917170717786517, 0.02243192776316597, 0.05296664875781825, 0.00948795872259765, 0.03750024904166499, 0.044183860562982104, 0.07660864687134182, 0.04605281249349637, 0.05527299858870045, 0.028313420329903884, 0.009586103204187126, 0.03511996406521048, 0.05507397660685163, 0.03509451079392626, 0.015494683682317696, 0.026535259394515908, 0.0057915131460064126, 0.062476147957626856, 0.027529252730610392, 0.05346665902423763, 0.031394105021571445, 0.07319069197100979, 0.02734695636336842, 0.07442975491886178, 0.05760446461218019, 0.03989842217115145, 0.004179365857834778, 0.019601052852287408, 0.011849983993376936, 0.06890367926849474, 0.06702260399657874, 0.01041710941917113, 0.05145488915243938, 0.08097776121670201, 0.08359762103927713, 0.04612432297078833, 0.0423386688494394, 0.030390949273902564, 0.025954610713186766, 0.05573665032223348, 0.038360351276013165, 0.08281837172445752, 0.02208439197631613, 0.23526203157680653, 3.667065549281336, 17.21403145021008, 46.17429464094101, 67.95865612645304, 76.18316819590908, 80.2999153444844, 70.11638333720546, 62.39319724421348, 59.693374941425944, 42.294023267684445, 47.832417795735026, 36.158024264920144, 57.68308178071053, 80.80410465117424, 76.50771294870685, 72.4045293561874, 62.04917007876981, 46.50908462462887, 25.602398572429536, 9.67251483471163, 3.0779429549171082, 0.953901426926736, 0.34507903480722063, 0.2881880585224398, 0.4390231099340224, 0.9918485810199092, 2.4428428276892635, 3.3557502156303776, 6.756762621864197, 7.432215848276693, 8.381414721089026, 8.379655538066741, 8.97713645812004, 9.455719551732464, 7.553835309320881, 7.854001550905167, 10.219608006938811, 9.540581011003065, 10.787446595007374, 9.069101329772703, 10.55516089162519, 4.121520182778759, 1.7672803877822816, 0.3925795811078241, 0.12258056431047379, 0.1578110480500806, 0.04450225819563193, 0.12507758193439053, 0.07626490321971717, 0.04359286203379593, 0.09002063243139176, 0.2968200001745455, 2.6093999032051336, 2.261263074413423, 3.722650682733905, 3.6277790896354185, 3.88564232376314, 5.4641156235048856, 6.694230235392048, 7.601083690120329, 6.313438694323263, 10.941220175835396, 10.827897018001927, 10.935063035257402, 8.990392108117382, 10.163334742669138, 8.987565059815685, 10.770703957926843, 8.548175269557584, 9.685373344729024, 10.493130568535099, 6.966717781559114, 7.202801810156915, 6.650581609818244, 7.159052673847445, 4.328639468839092, 3.846007508616294, 1.9949343848613001, 0.9519043276386877, 0.5933944232040836, 0.23500752184660206, 0.302312329651848, 0.1757797475663885, 1.524889678243668, 7.351651835826136, 23.123221358945294, 46.40183133463706, 63.178989195054584, 41.50107691364904, 32.621546676082, 31.319188379472305, 27.265216804319813, 29.14794468110608, 32.9805161106971, 37.046523478723344, 42.23695670404742, 45.82132839387464, 55.6019506146831, 60.05991258928853, 65.60228440069383, 56.40888021838281, 35.55139441643992, 13.93704120189913, 1.3738297647045505, 0.09686879197796507, 0.05299221311185149, 0.010041711972125117, 0.00784603311800428, 0.06916103118489828, 0.09558008653261969, 0.09036414625663912, 0.028669752721344272, 0.037162147627602664, 0.049204241574531606, 0.059744148184695554, 0.0352791992707118, 0.03906124511793737, 0.05193880008113, 0.05679246503859759, 0.04094472590593561, 0.049851015135045015, 0.012763687484567205, 0.04739163924128779, 0.0326661997654986, 0.028828030316940242, 0.03314156498339388, 0.020516286604106426, 0.017902635924157598, 0.02957097280980839, 0.04425249821055801, 0.037097623872180144, 0.03235325284843003, 0.019075907241072387, 0.020162618283422726, 0.05231634736241353, 0.03602572897028539, 0.07144911364922601, 0.028625892272459406, 0.021820905610858914, 0.04883997442741548, 0.04625862967523356, 0.08903785653772855, 0.2528294695601348, 0.1989228807149395, 0.2194195478073051, 0.14887783466087234, 0.10348651227691483, 0.14342350314461416, 0.14311230290801297, 0.13189639265258468, 0.18060427820009572, 0.19502393751134797, 0.18828974886526986, 0.15741779979678894, 0.08569281022515028, 0.22021016586692105, 0.14730099588632584, 0.18438518257631412, 0.1779673269559299, 0.11517122237672729, 0.12435567430070332, 0.1854561888162167, 0.1473048876129812, 0.13103887979542056, 0.18278762878429505, 0.20150196167730516, 0.23746186837313638, 0.10862834886797976, 0.0653376242506408, 0.0967451990131409, 0.1701937561794635, 0.1608994395862664, 0.1385482574903196, 0.2148261918656288, 0.11673888341794092, 0.4727015301825539, 5.621419827784262, 26.890014640746582, 60.60513773272115, 80.16698621934461, 89.80228070289859, 88.01866131444132, 76.5859720783849, 68.05083182550246, 61.77592208308559, 46.607649864689, 54.071696727506584, 56.428401854730424, 84.86664464396816, 102.43474452726304, 80.63527014947708, 62.468930367500555, 50.606941638454316, 43.24512350943781, 23.79360148983617, 8.664499040572874, 2.7874517296591117, 1.1357623651143045, 0.6616084854448996, 0.4066736070859817, 0.34366480585548187, 0.7052247514647823, 1.9043273887326642, 5.523725844198658, 10.470274917541012, 12.633291444470807, 13.560944737926608, 12.683616434374164, 15.863582934102705, 19.645351825221894, 17.60401898814786, 16.389562968284853, 21.394332762687437, 22.72053514757464, 20.723580006630193, 23.707897701571067, 17.81182812106225, 19.887364026038878, 9.561153842556863, 4.624344994944911, 1.2505105690610026, 0.5535161146713842, 0.21900012999052004, 0.6038762833322249, 0.31737018616930135, 0.24350720607945997, 0.9485670647794201, 2.5973672972571467, 5.873443878466084, 6.8859198977870335, 6.738095081621601, 10.739559358166112, 20.80073695028982, 14.848499028913437, 13.535147309303285, 26.105050310011833, 23.1082869345142, 24.105441685645815, 32.6719863953129, 20.215276133629587, 16.66196373201186, 14.408647379567547, 13.296918234517499, 12.708143015061657, 19.784242953023604, 10.205062877747322, 13.218058982203084, 13.558370682501025, 9.442640408392876, 12.326332638340613, 7.793178827531877, 6.8577764015043945, 4.647065814464323, 2.4011686252009485, 1.0852716550711663, 0.6328063986955151, 0.19773749754794184, 0.8429739792500773, 0.25684744750540106, 1.8924983783114342, 7.506327561793789, 29.558463865710845, 47.06230355847267, 62.32972937245523, 43.08522808936335, 42.837761832821755, 43.32009177054129, 34.25436858207949, 36.12951255613758, 39.67206785755773, 46.40506729002922, 47.47090862643334, 51.90498728905955, 64.91391235782255, 71.42809452549105, 78.03734317902597, 65.5434488481091, 45.521875043069166, 19.741373408225275, 2.646251061270314, 0.2692580872005032, 0.24947546001884247, 0.11786223644570959, 0.14375561758154823, 0.12941454356956866, 0.11426771360058939, 0.19334119474214895, 0.09267777009236236, 0.1743980926731902, 0.13283109652899927, 0.12693627211715908, 0.16119827516376972, 0.1623109412649947, 0.16767922578559769, 0.14957384086183964, 0.11675666431866347, 0.20086430073265107, 0.10666406878660764, 0.19865920857316066, 0.20228185450598118, 0.09811110313861601, 0.2031557463229664, 0.11709672308737233, 0.21972229043322228, 0.1254102096502339, 0.22483025827715475, 0.10218869804614976, 0.09936816149180937, 0.09974623354332102, 0.08395556030013869, 0.20339415288500248, 0.13818482537904095, 0.14889861096537885, 0.20431315195896935, 0.18695632686778424, 0.275417679259854, 0.19676508682389415], [0.04078001700221531, 0.0578326209177894, 0.11170129607161207, 0.03328373558038185, 0.05987308078235196, 0.044583762289896134, 0.0007210155003591471, 0.022784569526031133, 0.05000931571327871, 0.02020990697576875, 0.06371091315222364, 0.032641026116306746, 0.04208117137633024, 0.07824890240426026, 0.1451342694100834, 0.03565219598972509, 0.04587115006401174, 0.04732010961179772, 0.031639697488337275, 0.057746405382790876, 0.03163712151769189, 0.07184302839901179, 0.06847441722188266, 0.08118333325030343, 0.05779715870777446, 0.06906323240048463, 0.018115029970724738, 0.08019416052247248, 0.08861123749445524, 0.0625149043457162, 0.06870339324157085, 0.039577860340115525, 0.05751725699331972, 0.01882523178092895, 1.176348600176073, 12.425883373906537, 29.000651836395267, 26.77439493517722, 52.02384295002107, 68.30544856286818, 58.80065525731733, 51.78319377283896, 48.91265030830137, 34.53333147110478, 40.050078438174346, 61.80631652955086, 84.30060740440123, 68.48800351542812, 59.65456701094105, 40.25163727421915, 29.764347114870628, 31.971613860899406, 14.959162819770077, 7.564009447251597, 3.7353057197986113, 0.8108981230085897, 0.1900520268827677, 0.047029727814538826, 0.09723851367110208, 0.09426926412890035, 1.6351775344341033, 3.2909761946047507, 0.40210012346506124, 3.913004287788945, 3.264166304180699, 4.167926234583701, 6.385102358556564, 6.795991226550072, 5.892154564780574, 3.350894811653322, 3.8053273818185254, 6.362660517615657, 5.462374091148377, 7.296036549152867, 9.246365985562726, 8.313422395337014, 2.8904149272749504, 0.37885762871273104, 0.14526107228331028, 0.18737154652274426, 0.01146635684680434, 0.06694728989274272, 0.0794311675934061, 0.016386978846463948, 0.03757846661873403, 0.24721787551478033, 2.1916843950748444, 4.701503899789626, 4.493332928226841, 4.73345797869467, 2.3344231228674612, 3.2678513709575903, 3.470762198971164, 5.412827691724224, 2.1707222682814447, 8.001780769517346, 3.5933654394841965, 6.851786942251268, 8.953433575168733, 5.097298016471248, 7.663341510680414, 4.598966279337484, 9.66728533467939, 3.0799664076297515, 8.406962098613862, 8.612598238452788, 4.753499329090118, 7.32319062755954, 4.442133740071328, 7.514255162208312, 4.40051592165424, 3.776104743442228, 1.7294264512677349, 0.7419603834709814, 0.3032760069735589, 0.15235270223309919, 0.035018258232383, 0.13537962590494465, 0.09597485930088068, 0.8168936496780765, 4.9925824999809265, 12.683627220892138, 27.318690476879, 38.86707982709331, 52.010550037507095, 39.71493936354114, 38.08591235068537, 31.319847337661255, 22.54035322896896, 23.907554188082297, 27.22671481870836, 35.58471495105375, 40.99724846501505, 49.48172738475185, 61.74340563435709, 60.25124188392394, 48.75337462271414, 24.91947666291268, 5.887859079145617, 0.22186460934819716, 0.022497301876184442, 0.021595681506779887, 0.013363663606616038, 0.05665662232786418, 0.03455983121849356, 0.06839497390413476, 0.05243491096001479, 0.04523559586114941, 0.03489719718814858, 0.05006417526953644, 0.06836839831404148, 0.03087035369037861, 0.04965618748458163, 0.01322741199645304, 0.07287766844514879, 0.010146795295088763, 0.007286402537682726, 0.08726347433102709, 0.09763411381432126, 0.07052331937537079, 0.04288979633260639, 0.03977938742947675, 0.10143613157373282, 0.026397020743799307, 0.07660605749415775, 0.024852018668166092, 0.022580782477293285, 0.07022647562647058, 0.0628904061722419, 0.009206400343006658, 0.06721179707035904, 0.014591921841905964, 0.04058877847367718, 0.011207515846997982, 0.030080111013845574, 0.07505734180731159, 0.024160620486063343, 0.07183525260658034, 0.08394152556936588, 0.03628446750583188, 0.007581395705440834, 0.0413126013271751, 0.09133860243544464, 0.03790598452812241, 0.07309420319694666, 0.07196803096561663, 0.04522907645291379, 0.024002166690244794, 0.028031672343551636, 0.030764334782537435, 0.08284831810141764, 0.06291106756355974, 0.024235955657317274, 0.05636457811980959, 0.012917025728271374, 0.03354876369778668, 0.009064374345114395, 0.06076518633973695, 0.022609683144236767, 0.07248037524761693, 0.033762011932389396, 0.09770919043090075, 0.03655929771822788, 0.04742639665041239, 0.0519192916521382, 0.03696902069233118, 0.02860282344983951, 0.027526196039792512, 0.05925633403803072, 0.0393202785973347, 1.289741502654168, 12.738424693384479, 37.067257127454205, 43.06497296979351, 63.23437698425786, 80.39442093141618, 67.58340297206756, 62.117678196199485, 59.49242407275785, 44.986765692310954, 43.327254018475934, 63.72434769907306, 70.71955757756388, 69.69365381425428, 71.26866586746709, 51.852968815834295, 31.300311973018033, 30.964137392659342, 16.762384253163493, 9.098517144879988, 3.439188099676563, 1.0621861776997967, 0.2671347366225335, 0.31898267867584384, 0.7228946000818284, 1.319236132887102, 2.8794734756792746, 4.574580903976194, 4.904019794156475, 5.243556336049111, 7.816880239594368, 7.678841246712593, 7.895917959751622, 13.572481409195932, 10.32308013208451, 10.511560805382269, 7.964645239614672, 6.711331279047075, 7.695890318962836, 9.60999127357237, 8.399841035566023, 8.007737378920279, 7.638424163864506, 1.862360969666512, 0.5982237189046798, 0.33271881901929456, 0.1950109140166352, 0.25262447975335584, 0.3148767844803872, 0.0890404612366711, 0.09384295152079675, 0.10008786279227465, 1.5638215311111943, 3.2412037685994184, 3.664080135283932, 3.3402281711178445, 1.9701029624669784, 3.2083154301489554, 4.8251835857668235, 6.869141959374951, 4.531322554234536, 7.570004790059983, 4.263294252657121, 9.612531008258943, 7.397984833486619, 6.934847543316503, 10.661116857682506, 9.25618269751149, 11.158681281151312, 7.216409492877222, 10.286143172171808, 12.167875747526846, 7.992704404938606, 10.42792312560543, 8.525904051719174, 7.957184891546927, 7.4186866129598315, 5.375625481528621, 6.769670651805017, 3.4482142088874697, 2.3476532774586834, 0.8870538203947006, 0.2331519036764099, 0.10310424972445735, 0.1218772572915881, 0.9469484742130003, 5.828728858501681, 15.664789369029386, 32.03030232460269, 37.73172232412523, 45.85061673195132, 42.30371152201007, 37.9270798929276, 33.71371692226779, 29.34118220883031, 33.64024308419997, 32.0180292283335, 42.35097608258648, 49.83658421424128, 58.61362880276096, 70.10677353028329, 67.22962087200534, 57.41703525666268, 29.866466022306877, 6.903888275546413, 0.3027470692271187, 0.05852521802749365, 0.08473186017644983, 0.04098383469447013, 0.00895892808799662, 0.05608115623134279, 0.045654278233527176, 0.015533569347744268, 0.037350704848405816, 0.0342625278168388, 0.03823673532855126, 0.1092003713992815, 0.05861419913989883, 0.006030835183112012, 0.07067916464180717, 0.14978571013817865, 0.04608576193511967, 0.050239957974202214, 0.07237175930171244, 0.0835214259343282, 0.024811883321813038, 0.029027188279395624, 0.046799024266581384, 0.0931528058924502, 0.029618117860668612, 0.03705120660484799, 0.05134028622940664, 0.027474527239739418, 0.03212969115514669, 0.042297644841094176, 0.06226822020365827, 0.07132691496442403, 0.11103190376513428, 0.06682694514071749, 0.0417177239432931, 0.0418731440309315, 0.05602763732895256, 0.23074079515232196, 0.1652856453532173, 0.19279403942486933, 0.10966186276486806, 0.09658439715783443, 0.10173151209469765, 0.19932959679394, 0.08558695219577321, 0.23090032530167412, 0.1883498867673259, 0.12011206047909877, 0.19203584220620895, 0.1937168536166991, 0.11985155228044718, 0.14133044368317052, 0.21802848535439662, 0.14315776256543977, 0.19094464188862234, 0.0973149232806698, 0.17462905286060226, 0.1091271027502033, 0.16193879107313772, 0.21943945077157792, 0.24594403983604526, 0.1662535668020287, 0.26213791281465565, 0.11103994768833923, 0.14320535194729606, 0.21689801536981138, 0.25546327984381106, 0.18221539174837453, 0.10114210702839399, 0.16863081423986345, 0.2232381437093981, 2.389679022373692, 19.198609552075787, 47.96556657360446, 56.06093068276682, 81.7711885513798, 90.5620438052762, 79.14902133326378, 70.38154340559437, 66.23455478299049, 49.295932554429584, 55.1799584973243, 77.78988868959489, 96.92856834780787, 79.56428266340687, 73.52005143319407, 53.806222869503884, 42.62658142274426, 42.134335733229115, 22.347676600179366, 10.319458803822918, 5.341492035696584, 1.2146988390914857, 0.47997305289872233, 0.2983050156504877, 1.4488414170280581, 1.1121910041378391, 4.3118571177605665, 7.786662790083117, 6.58906021425801, 17.404884176869547, 14.287896233220255, 15.900019791818435, 18.174863092360958, 18.6280047124432, 16.387789076374425, 17.420938437984837, 16.65720589699284, 18.474163470729707, 16.725629683463804, 18.32728639725716, 19.467286025324178, 18.3986754955784, 8.73461042681048, 2.2494064848269186, 0.7796892331492516, 0.8097961821383046, 0.22993257239220605, 0.2791606929273375, 0.5284781549726764, 0.30761816268486364, 0.3642916619296997, 0.7510697204739817, 2.489343751822749, 6.048513968144694, 5.683076054819169, 7.794869369076145, 6.676502593101994, 9.83039023414735, 14.284771084785463, 13.34991926147092, 9.666467520498461, 17.220562196546986, 12.221026805139358, 17.975126197261197, 18.56074586991341, 14.31143927958704, 20.346136208503477, 14.076915864021549, 20.71420946428853, 16.18699118014305, 19.50615671373183, 22.415631663414743, 14.801189361080048, 17.822549919928274, 13.293292003293192, 17.5258892966855, 9.704639046422898, 8.772802545178322, 6.853216155882805, 3.38237232258243, 2.052789835199233, 0.9561449613782668, 0.37530371618847697, 0.493517609974069, 0.2588075447467066, 1.1510043278817208, 5.963415205478669, 15.162929950221894, 35.34028460902553, 52.007255246562345, 67.13356202648532, 53.401524482234834, 50.515860280682965, 44.04874263271209, 35.19594923142464, 38.385593198960834, 39.72365487006403, 50.816211854257894, 56.2329383819334, 66.44895938134962, 78.76131073121103, 77.6907782400808, 68.5021162033081, 39.12492075274068, 10.658632036178343, 0.8811218483794121, 0.26670189694531504, 0.18141280739538132, 0.11399995054929488, 0.1425924816078717, 0.16669501730751607, 0.160998341537291, 0.13208891054795635, 0.13067529446655704, 0.10411624421155262, 0.16234890858252204, 0.27231698435160423, 0.3409372876969076, 0.11723648050739882, 0.18508144924717565, 0.36859211181440665, 0.12442367226486245, 0.1583674270659685, 0.18820829839716036, 0.2674908142897391, 0.12522605743499535, 0.11581898036022341, 0.13000656099569413, 0.35917664607686384, 0.07474290867966991, 0.14277649592728386, 0.0957486258759614, 0.13489743484364403, 0.13558205697805653, 0.17056751515596144, 0.12004009417949185, 0.21548819908451652, 0.263484358306854, 0.1685233167823284, 0.15373922944549592, 0.09201031598833301, 0.15480154824833717], [0.06697870715851746, 0.029092464716203754, 0.07503933874109099, 0.022398673801592762, 0.05002403226230414, 0.04162311591508408, 0.020940616959705952, 0.028370183614653446, 0.015160089993338673, 0.05330100017149122, 0.04289432008179926, 0.07801609594495067, 0.1124837859383514, 0.022442214408769243, 0.13058530977897106, 0.031056210451248675, 0.0632488510511335, 0.033671536948531866, 0.032812438289364504, 0.039717556473108075, 0.015037447935150517, 0.022436237007740046, 0.04040191430718668, 0.005180371771266143, 0.024396874341032198, 0.04657849819669801, 0.07235008667433455, 0.009838704417850222, 0.03675027960731137, 0.017632949992173144, 0.07094165700818263, 0.029036145762450276, 0.060089393368651794, 1.585890134015391, 10.722351920220161, 27.596027543467862, 35.58791952748453, 47.76585909628099, 72.74928216011294, 61.07133103955177, 71.0112956262404, 52.797538311250754, 32.987195907100556, 33.801836890559045, 34.58382021996283, 54.51825464925459, 57.01634160933956, 74.0781262613112, 61.717808246612556, 33.600572232277166, 31.07415987599281, 23.615278774692168, 8.51259348853942, 2.6734502469339683, 0.1779431645427981, 0.12900506957404076, 0.2322141048047812, 0.4652022342047384, 0.8395161035080111, 1.3130706572724928, 1.8608536763537316, 3.381985478824185, 2.530151845947389, 5.1828924686677995, 5.3887051151644805, 6.2701161157700325, 6.319127601961936, 8.513776083146373, 6.288016342347668, 7.475726210301922, 4.955103762688176, 4.839403648530284, 5.004693798480496, 6.533961209558672, 3.3622508087465843, 5.057955663050375, 5.512654464091025, 0.6578206403120872, 0.10621221480710853, 0.052408687770366676, 0.14828529629495837, 0.3853454128388436, 0.1470395607212859, 0.11538014987543707, 0.15716249333514323, 2.583555406139743, 9.071181166556574, 16.45998324117353, 12.807113239842078, 8.302394651597547, 2.898225101732439, 1.3186487579537978, 2.377442208028609, 5.814899071570366, 3.5399135851090957, 2.08334828576734, 3.34108030603778, 5.457401506362423, 7.872398447605872, 5.673802591139271, 5.225950287234399, 7.379011348370583, 10.289898841611802, 6.282975606379971, 10.583094050807338, 10.227836158967788, 5.7108621251198555, 8.139729057588886, 7.107864272209906, 6.090909886744715, 4.2222946978384455, 3.832738130323349, 4.1951886684663835, 3.197326910111212, 1.7613348100454578, 1.0705616637583704, 0.3359051932009959, 0.14322965225625423, 0.09000557880367964, 0.06693961369174142, 0.6195510551333427, 4.520932685944342, 12.829227562873596, 33.96967511023245, 46.98734706447971, 44.637333500769834, 35.30040194911342, 25.42274421261203, 23.821979838032878, 19.891798265518684, 27.660656436797115, 27.0420810099571, 33.156614841953406, 38.49881241398473, 43.60844873612927, 55.2041163752156, 59.17661051596365, 44.11371669461651, 15.539094075079888, 2.041516085305522, 0.16396939904699404, 0.036496884535036744, 0.0410198561486698, 0.11827862821519376, 0.014495950177191727, 0.03162709342676305, 0.0419778605893014, 0.12168316891597164, 0.033377405150883624, 0.013871826963769573, 0.024395932052885334, 0.04674421067559912, 0.08422324674264078, 0.23497197536691544, 0.05088405022698064, 0.04727800924991889, 0.04013783613880796, 0.002800986708720185, 0.0397672985620316, 0.07409596274937354, 0.04249799598549162, 0.04890663556814675, 0.03301362830003904, 0.030575476872224002, 0.004868284787892575, 0.056088732840913924, 0.02824178153288461, 0.01210248274278016, 0.03268275109510268, 0.023402802480925477, 0.059244517131798693, 0.15319567474146045, 0.06990123299821731, 0.05835803465977792, 0.02295507771533824, 0.06385305310569464, 0.050877327805445086, 0.046552014537155635, 0.07194795946200049, 0.034212590375494574, 0.035524784076598384, 0.06088067792476185, 0.05081142509175886, 0.038213361985981464, 0.03508415328518998, 0.020565479024944287, 0.02318489451652333, 0.06992705016126556, 0.06345960183910306, 0.024208165817864002, 0.029867672917222785, 0.030837837088432525, 0.05594204615561232, 0.04785741303837107, 0.03275291708808753, 0.10442056497859378, 0.08972944241137275, 0.0423818915301273, 0.05369161691276297, 0.059788642571337765, 0.0690699739742183, 0.019167406867528637, 0.07685579449659394, 0.07950429068577868, 0.022855181765231877, 0.004334951611986805, 0.07341168535452697, 0.06176460166311553, 0.08598970760020518, 1.7698589784483758, 9.957369123735736, 31.958677884071108, 41.58181498127599, 54.34865136300364, 83.75218945164835, 73.11460387322211, 81.59042219961844, 63.55812549591065, 42.552185827685946, 41.96987467427408, 45.372621013272195, 58.359400380042295, 73.785917528214, 85.52324941081386, 67.09733501557382, 34.915378170628706, 29.985966913161743, 21.976634110173872, 7.592534394033494, 2.5336927656204473, 0.26733670804289084, 0.21246025188555642, 0.30543285091557815, 1.2793070174032644, 1.1528192821048922, 4.06985423257274, 7.557248751963339, 7.1700289364784, 8.287493567312918, 5.720613627664505, 10.796285656190689, 8.97849359819966, 10.97201862642842, 16.915305699071578, 10.155165426192745, 11.501070857048036, 9.124711713483258, 8.26207955037394, 7.481179775730257, 7.310830258554028, 6.407180889960259, 7.033809923356579, 6.500930930337598, 2.706252048092504, 1.020746336829278, 0.21876541597227897, 0.5838946265078361, 1.2401048887160517, 0.4628396190462574, 0.1774731849230105, 0.02255653579448981, 2.6059832736369106, 8.397327776878111, 14.309154498961664, 12.021007499387188, 6.619311494211997, 2.307171965799024, 1.1039655487383566, 3.5027959510203335, 3.898555256666676, 3.7919503834939774, 4.708462674771586, 5.681465921863433, 6.894865843557543, 8.043039200767394, 13.107178480394426, 16.214824318885803, 10.335387549092694, 10.864868298653635, 7.388781972469823, 13.56559863013606, 9.383122363398153, 8.557806649515706, 10.055959859201986, 8.955364361886057, 11.89403449335406, 10.998515217534958, 9.90755404195478, 5.563162824799938, 5.774583480050487, 4.093328392313373, 3.946798448601077, 1.7432128469790182, 0.3490801588181527, 0.4258627612744609, 0.2969998776191666, 0.7366786668858221, 4.677568126109339, 14.166359632245957, 29.35025465103888, 48.10585798755769, 41.73959232145741, 31.880536425498228, 25.140886614399573, 29.24857504906193, 26.20682012650275, 33.17176303555889, 34.275121842661214, 39.76283934808547, 46.397752069657855, 53.55623845131167, 65.95157146453857, 67.05104320280014, 49.892980052578835, 17.651285509909354, 2.8315347577295, 0.235216296127727, 0.041890361857029705, 0.02723485663262827, 0.1549224675663056, 0.07415122833223113, 0.06999546947378306, 0.00039254237509017155, 0.03029934431035673, 0.012497365636180245, 0.0945081839698457, 0.009671488491397713, 0.010242162707952723, 0.04917290091754929, 0.09281837020910556, 0.04190846834512007, 0.029060654830367818, 0.05363755791838612, 0.030577112469942342, 0.05137669838844769, 0.04715029090162247, 0.010498670970029648, 0.06330114038240525, 0.0026249626863582604, 0.024461763903438568, 0.035658045071026975, 0.016051738770798813, 0.02937512817762552, 0.012544706039461158, 0.01626462311363749, 0.051770172637677005, 0.028404718858280012, 0.07988423199182557, 0.11142394926038482, 0.07822510005245287, 0.058084135244209925, 0.024476783057194085, 0.1996184579066692, 0.1457420069604151, 0.1324706521606253, 0.21324555329497785, 0.1248882739474216, 0.15915971519725938, 0.21449479755134354, 0.14955119530279792, 0.1186444198772792, 0.10588420660144861, 0.0845149960068445, 0.23304365545270905, 0.22601081509022947, 0.11899340357030593, 0.2681586897421268, 0.07516971924492429, 0.13159095339717405, 0.12140263517897938, 0.08983102567013233, 0.28949175630846335, 0.2257022195525708, 0.15649362196845396, 0.182170698178872, 0.22549687734534665, 0.19590054127958514, 0.1778462697421351, 0.13217239880994444, 0.14979229849432746, 0.16660331658297972, 0.13907630657476766, 0.2211851812899113, 0.17464792926705655, 0.1827436093721659, 2.348241387836395, 14.899779115953754, 45.06990817285354, 59.63173881653817, 75.94333094935264, 98.35153364366101, 84.8493391467679, 91.85193092592301, 70.73207778315391, 46.58129938187138, 49.15428007802656, 48.52046428188201, 66.1680627638294, 69.46403041962655, 84.51363132845971, 73.96636224562123, 49.6877851793843, 42.238768839067035, 29.08675962878812, 9.903190405138078, 3.1705224129461476, 0.27427268424822443, 0.40732818325200393, 0.2722915502325181, 1.5834333819727746, 1.8172885237201568, 5.9923024812052335, 9.267145722143113, 12.55003619578577, 13.456146851662668, 15.289564651827659, 15.208238228674858, 18.57161868003107, 18.105984310950003, 22.186435807135798, 20.458106148627497, 17.89030690346995, 13.916339912722188, 16.582329811588412, 17.056228614622547, 18.132758409746234, 16.048022585530436, 14.476456334514005, 18.09835922333502, 3.4496311651122187, 0.5451006081796462, 0.1560271050660841, 0.4493238668768637, 1.2589998038545733, 0.6080498690566709, 0.4945497449126936, 0.3142549049469733, 2.9496765473196587, 7.278479039669038, 13.59232467989768, 10.358882546424866, 6.745100925045629, 4.907665146935371, 5.481617729510031, 7.711164518710106, 14.621335940976298, 11.803397344004724, 8.89795066848878, 11.089723071744366, 14.691604222020796, 18.01982552774491, 17.603705198534076, 17.55209465180674, 18.40460611927894, 20.665213177281043, 15.195213017925141, 22.580677155525457, 16.83506577245651, 16.902799221777148, 17.833081483840942, 16.43893089986617, 17.99889576050543, 15.070706202137856, 13.208743353043834, 14.120944469205796, 9.000059769999597, 5.363512221843966, 3.164514812730974, 1.2652800087967229, 0.6018954863952053, 0.4224428528499219, 0.41626772452746674, 0.7904169155705361, 6.410363403058822, 16.827593657278246, 40.875662834413596, 58.38951633822534, 60.36594375487297, 52.471087286549235, 39.97139569251768, 34.85675442603327, 31.35922597300622, 40.93200768193891, 38.693307061349195, 48.297504994177054, 54.056811332702644, 62.06250613735568, 73.66761884381695, 77.9092150349771, 60.07162478662307, 25.81018417112289, 5.260937338875187, 0.45610782059450306, 0.15110405552531445, 0.1388886609985944, 0.2674604772079376, 0.12246023488020706, 0.10893676820541583, 0.09432741786323248, 0.19106291054237276, 0.1183928902291002, 0.18571370161108433, 0.0879952415162998, 0.10161115968179318, 0.15296103733201183, 0.30988124770022213, 0.16358931218424153, 0.17366027339331566, 0.09006898790117233, 0.11440412321638678, 0.15981628319188473, 0.2114674325792059, 0.15201971445593143, 0.10886667116034417, 0.06181342444652992, 0.09528728006708045, 0.16569521127929612, 0.14804927992724604, 0.102503590826546, 0.15379359104460286, 0.11041666621402388, 0.16031607895368533, 0.15584266173743433, 0.1963916496043244, 0.27444468630898383, 0.14650225729471253, 0.19984980113804343, 0.16657582934825652], [0.05409607686282647, 0.0696791441089684, 0.02990141525984772, 0.03164350111488133, 0.03635893891295118, 0.050002225569539496, 0.03243356184553235, 0.0940459341772141, 0.0684649407142593, 0.05542773302764662, 0.019337074275338845, 0.01092380284511995, 0.009378514444125036, 0.01637256681738842, 0.04546458720259609, 0.05662333963799381, 0.04625515546649695, 0.10273338656031317, 0.06564815799074789, 0.07754622357747248, 0.09523413654777313, 0.13459685258567333, 0.15339262062503448, 0.06976271664062816, 0.10763820320848497, 0.18646503468194317, 0.10779548872021899, 0.0403540414727984, 0.05069579561090758, 0.004693070424705624, 0.023181581186250817, 0.026234336227418917, 0.11689102081882378, 1.9241346226584528, 20.276190542405654, 25.993668725413663, 51.135029946604085, 72.91812450655046, 57.82252596270654, 60.288971162611446, 47.245784190393266, 36.592760162968794, 36.819233894348145, 31.972466976411884, 23.631254588404012, 31.85946741411763, 27.84962054221861, 29.623824281077233, 45.74327714981572, 41.29610169318415, 17.80174174616414, 3.7606775712582374, 1.1502202215694612, 0.24651525031414726, 0.22378531434843618, 0.1159111483983936, 0.4995057515559658, 0.3901914092561891, 0.3625080560243899, 2.64978634253625, 4.492001283553339, 2.8458344936370854, 4.564234672054168, 1.933193213997349, 7.352639292517017, 5.910896630056444, 5.125404740533521, 15.515070538366995, 8.956652860487662, 8.885768767326109, 8.206115172755334, 3.0587458947012505, 3.558085926117436, 5.931308154136905, 4.730721144906936, 2.5420682516790207, 6.1652858699521715, 3.007325092631002, 1.480582707351254, 0.7978637192037799, 1.1926952004432678, 1.5054540888917063, 0.7780203259279652, 0.6698417855847267, 3.9862550410532185, 14.788405376095927, 28.44968826540055, 31.711478348701235, 29.89970418714708, 19.963956148393695, 6.721322046172235, 1.7784814512537372, 1.420268911507822, 3.861180462183491, 2.470336926560248, 5.496325637063673, 1.908436316636301, 5.725607785486407, 3.243601807663518, 10.207552602214198, 11.56927401019681, 6.8695185069114935, 7.57348491299537, 3.7207299470901494, 6.918797204571386, 11.125783381923553, 6.739901823382224, 9.343829039604435, 6.436396173892483, 6.806402667876213, 8.293290830427601, 5.644350494107893, 7.087175240439754, 4.715196894061181, 2.6776959674973644, 1.924615725874901, 1.6796459353739217, 0.5583631836118237, 0.13620741455064667, 0.03300090357961674, 0.17792939028191954, 0.754168821919349, 4.560345642028317, 12.87428677082062, 21.217596646278135, 41.77360711559173, 34.95521768446892, 23.705101051638206, 26.479856314197665, 23.85750670586863, 21.184560483501805, 28.45435000235035, 31.747097392236036, 29.06167999390633, 39.05789529123614, 51.42399095719861, 62.44916162183208, 55.68862715075093, 29.82590283116987, 8.655188314376339, 0.5457120689172898, 0.12131559992990187, 0.07907645356270575, 0.050540804532506776, 0.09151130163621518, 0.0373151583687192, 0.09791682324101848, 0.013317050029253288, 0.037062720906349926, 0.14500608757859276, 0.1289562697732641, 0.2231601253151894, 0.172889068001701, 0.22902526381996371, 0.007419779881714814, 0.023493557086875363, 0.02167675659180649, 0.011160817042353654, 0.012043053472054102, 0.03649084010131417, 0.1109786453326383, 0.042855107871394967, 0.011209399465681806, 0.07805954079113661, 0.0498487207017118, 0.029508544304858775, 0.025528616031571746, 0.02699777157226157, 0.05807960383413781, 0.07829319760804215, 0.14856183871386514, 0.16143960818167657, 0.25278672185395995, 0.13976005536894645, 0.03285268471846658, 0.09421440457264263, 0.08043743174282775, 0.11659662855128128, 0.0182725012587804, 0.016642903924108516, 0.08391091269591162, 0.06314980737384289, 0.030885612246610468, 0.027739808166159258, 0.048786195055130994, 0.06868191213617403, 0.03411520527856004, 0.04842215390395253, 0.014364209867292836, 0.01992003079653988, 0.015083530039015799, 0.06054074173012088, 0.04577783289395514, 0.024900785910205978, 0.04098732039452561, 0.04830843964291196, 0.11863926410554879, 0.11428222330587526, 0.07297030379695278, 0.0869360100477934, 0.05067321516933942, 0.07274130479462686, 0.15377658389268384, 0.0751298443684655, 0.04507592015509163, 0.042722708725881194, 0.022170957996540015, 0.016506364073364005, 0.15428814676500138, 2.440955187043836, 23.18642839308708, 39.980781924340036, 59.88650068160027, 83.49223829084828, 72.42895787762058, 72.22043683451992, 60.23754888965238, 48.56595200877036, 42.364421967537176, 37.89657954246768, 29.72012042999268, 39.90265615524785, 41.39866775082004, 47.75004409974622, 55.43710516345117, 43.383124259210405, 18.388473410760206, 4.525277201206454, 1.4846856291255643, 0.425473986974647, 0.3780119595748763, 0.48695585239798794, 1.890326488402582, 2.313089841796506, 4.236529959786323, 6.773403277320247, 9.179647449524172, 10.96432391674288, 10.34294987878492, 9.817632725161891, 11.865826768259849, 10.341155394431084, 8.733545503308697, 12.692410388300496, 10.142907038811716, 13.154818607914834, 9.771933190284237, 7.459442980827824, 5.8672607521856985, 6.561957126663578, 5.270329454252797, 4.302183572323092, 4.287931640301982, 5.727120349484106, 3.7079616515867175, 2.4745743120870283, 2.0002384099268147, 2.8403179251378585, 1.249282499474864, 0.34737037314522656, 3.3513914817763917, 14.066688283797234, 27.49817813596418, 31.099649398557602, 28.169709482500632, 19.26149102949327, 5.717021717179207, 1.9687917876628138, 1.803078757178399, 4.368762373924255, 4.004861294261871, 6.159671977643044, 6.265739240954, 6.118164966183325, 6.238418952111275, 11.050792567191586, 12.152917788874719, 9.76257735683072, 7.760992838490394, 8.44543662763411, 12.825247337741237, 9.926578517883055, 11.177260568065028, 12.174536912671982, 12.587120244579932, 10.823676547696515, 13.974327252757165, 9.614567698970918, 10.467725376929007, 8.957514801333028, 7.529099862421713, 5.321308499382389, 4.2891078610574045, 1.5697088861657729, 1.2725786816689277, 0.6024626366073086, 0.2771071176375112, 0.6457216605063408, 3.9695222098981184, 12.71664083003998, 25.840062825910508, 40.73071164469565, 40.9161260051112, 30.712066273535456, 27.199681843480757, 25.494276477444558, 27.69133133272971, 34.30203714678365, 36.210776221367624, 35.88435265325731, 45.44787952976842, 58.50840730051841, 70.55684197333552, 63.92759707666213, 36.11846716173234, 10.523474024188134, 0.8187516886861095, 0.07625705847937254, 0.08751576240625113, 0.017388579435646534, 0.1393395343855504, 0.04702525769150065, 0.031511810600697514, 0.04265691326450437, 0.042837208227044156, 0.043068222040610935, 0.01592514561414118, 0.11225171492344911, 0.07500575344649053, 0.06449862773860655, 0.06498818856573875, 0.014781103424367406, 0.017172096394783547, 0.10881686778438669, 0.05225471175846554, 0.02230047090579906, 0.026474504791680845, 0.03447135189367879, 0.08636448547364244, 0.04903004467186909, 0.03705106870902162, 0.033538789233012546, 0.026937377030750918, 0.036242068369662574, 0.09011287707835437, 0.03722862873767172, 0.1202529363874947, 0.07745892785850071, 0.09225494318431424, 0.12036765039327646, 0.028724217742320993, 0.0715607020162767, 0.17840082546876324, 0.1629420751405339, 0.11272709546310287, 0.16283692191204718, 0.1984875435910879, 0.1548121815487262, 0.11394889845002083, 0.14146262449362587, 0.15668230942420422, 0.17654330740051885, 0.13976187865820625, 0.14730140957380497, 0.0633591906948676, 0.11438305579846907, 0.12487983931937527, 0.18946019331774405, 0.16642469552255448, 0.11303535392207485, 0.15795738616537663, 0.16201127831253315, 0.23108207200083042, 0.25799913812548886, 0.2719108658211847, 0.2544189487854319, 0.2694889554573644, 0.288575392576956, 0.3205958453397597, 0.27124498219740006, 0.1556525340363864, 0.14694162404104588, 0.14465580153609478, 0.10711979917100362, 0.4438110368867075, 4.680306921082159, 29.66642906588893, 47.701081152885195, 75.9007889224637, 94.91487056978288, 78.87772667792537, 83.23426400461506, 65.79451976283904, 55.235499258964296, 50.893686509901485, 44.787713250806256, 35.39931235774871, 48.02242917399253, 39.98234695003879, 44.63050073192966, 58.35228127817954, 48.240791443855535, 23.717056435923425, 5.005761663759909, 2.085219011191399, 0.5563526011763081, 0.7019667327404023, 0.7177346608331128, 2.0519415000754018, 2.7767559164954774, 4.047507754256649, 8.937101806363753, 12.840737758144257, 15.36820621259751, 17.973806319698213, 13.441484051366007, 19.157703153548702, 17.137894322795255, 17.35383649026194, 28.142082268191924, 21.44664345249053, 24.618234711308634, 22.186488759133127, 13.926163488818755, 12.010997610707438, 14.001323946060674, 15.01187163014566, 13.056693653906546, 14.634643562378423, 12.283678823901761, 6.0097187853628595, 4.126671725703824, 5.114217650505805, 5.2754172586625625, 2.6713468759290637, 1.4410328360334521, 5.404650040211217, 14.228043806168342, 24.088549998498735, 26.598670790272376, 24.439355019600164, 17.36450141476047, 6.618502015067685, 4.3784368999542735, 8.494656489741418, 12.771016647738795, 7.628001445724119, 12.350632702150653, 8.318415572566371, 13.611355039381213, 10.502254982148449, 17.161787440699918, 18.736103273207142, 16.95575906384376, 15.847071716862342, 11.357447389633426, 15.776880902628745, 21.134120764270907, 15.719965350243355, 22.590349720370387, 19.168870141429288, 14.753892440949718, 23.957156481281405, 16.522807844223514, 19.376130142519553, 16.712109273479832, 12.656448137375618, 9.742658580503157, 4.269500422862269, 1.0687035634633035, 1.0875347400865247, 0.8333309547555062, 0.48663823234458126, 1.0434423963869772, 5.143651116278864, 15.634947976758404, 28.249441462178385, 52.41383244914394, 50.353513379250806, 40.40895177472023, 38.69285598877938, 35.53363392429967, 32.32790823905699, 43.04900500082201, 46.071732505675286, 43.55972113147859, 53.276279280262614, 69.09343704100579, 80.1078054981847, 75.13536191755726, 47.15371439533849, 16.17744609232872, 2.370151012174545, 0.20242986269295218, 0.23102346627462297, 0.16603048199847822, 0.1638775757483898, 0.17414666261644135, 0.2010206899215137, 0.15957907172701052, 0.12447890720420307, 0.2832461172534574, 0.1956353676054747, 0.2818381089356638, 0.2552782083230634, 0.2926945860587782, 0.12494473462744106, 0.2350914697613447, 0.12485555433217557, 0.19993802382340356, 0.15862247305771998, 0.14775807458546855, 0.33221292519761675, 0.1594451442360878, 0.18264348168046246, 0.13056369077774788, 0.18266997300088408, 0.12603529909205052, 0.16034172757739024, 0.14570613872380028, 0.2838658823842003, 0.16690757606298695, 0.28702673051626454, 0.4064130759046924, 0.37508602464391344, 0.24916193087495145, 0.11729825017673355, 0.26628315328590335], [0.04332993682774325, 0.10050529644133584, 0.04847354308191327, 0.12872955371295253, 0.03428256867693798, 0.043924394243907545, 0.1485734985720727, 0.02402288936859658, 0.08366382635769345, 0.025436455654280803, 0.07019837552140798, 0.004236204314961909, 0.12707245190657918, 0.08254353002074265, 0.027433631551121513, 0.060076082590967424, 0.05807408034020375, 0.04424916572808739, 0.16406080865811917, 0.17474908351657853, 0.11579883990869408, 0.4115012480366615, 0.09373520891512595, 0.20179097600761922, 0.14270664403034797, 0.1482773902675798, 0.08057702828439013, 0.16404600783942208, 0.14285770124725758, 0.17978395125077618, 0.04008312213925585, 0.024975481398043134, 1.0205357545806517, 6.591753411677576, 17.63190507888794, 27.535811316582468, 51.816012244070734, 64.10842618634625, 55.62532401853993, 53.53643440431165, 40.39283867805235, 30.964598271154593, 33.38894074962985, 35.5976430831417, 34.6641032926498, 19.338191017027825, 29.106757833111672, 31.08634864130328, 28.861003691150298, 10.91638372790429, 5.255077317837746, 1.1872384480891691, 0.1496660931696815, 0.16689669761446216, 0.10177491863648738, 0.5675285369638474, 0.530593109226996, 1.5974694610603395, 2.4694504709013048, 6.111586170811807, 9.356649306512649, 8.42379887257853, 9.316836268671098, 5.858783529650781, 11.390105043688129, 7.452596483692047, 9.218937831540263, 12.479591408083516, 4.6396319423952415, 10.261591096078197, 6.823093333551961, 5.88373274572434, 5.25057198539857, 6.376889405712006, 4.977777023469248, 4.880781221774317, 2.012295898410582, 3.128881060308026, 4.657190432471614, 5.288251253866381, 4.345068316305838, 4.333442901411365, 2.91085317250221, 3.7756443552432524, 17.437084874799176, 40.43863234981414, 55.228333088659475, 60.75030465279857, 57.54070758819581, 44.75903680247646, 18.444276971201745, 5.481272560934867, 2.3197872888657356, 3.5876833959933254, 5.113576833278903, 8.229172825813293, 10.946734047705128, 8.155790182851977, 7.908139084616016, 19.636761834544522, 25.54519864820665, 9.580042996714193, 5.352459472994651, 6.762431917652008, 15.881818033033802, 7.348204562740942, 7.705533466031475, 9.08716090263859, 8.202808614700071, 11.536113312167506, 9.85556302532073, 8.42995503256398, 1.072654248245301, 5.889568251948203, 4.900630866327594, 7.006361176890712, 5.242452679141875, 1.286042585007606, 1.0993115339548358, 0.12074417494718107, 0.12050953753773244, 0.07392907049506903, 0.6265478280763472, 2.318795909804683, 13.05593663646329, 21.775461627591042, 27.395135510352354, 38.561699774957475, 32.8581303165805, 24.997673034667972, 21.937510428890107, 18.509227498885124, 27.39273894217707, 35.671599372740715, 43.97999917307208, 47.942334375073834, 63.56320888765397, 59.63277039989349, 45.93780317614156, 15.15339662951808, 3.633922011621537, 0.18693314504719552, 0.03857214394355974, 0.04613494477985848, 0.04032353202121393, 0.04390328852159362, 0.05458282997771617, 0.06683901868640416, 0.06839497390413476, 0.1257757101989081, 0.10967252670877403, 0.3091660893011478, 0.18979514227999797, 0.3128344553612894, 0.039242267864005226, 0.07748621591036359, 0.047388456145962404, 0.09567794660406728, 0.198368187092485, 0.02941011732834722, 0.029852023656149546, 0.05849206174213079, 0.03726345892514914, 0.08840363532785447, 0.0544332666322589, 0.012503828545431457, 0.11902147303185157, 0.03930684907602207, 0.028712747490874706, 0.1316469084591635, 0.34000584735505046, 0.5489934992886359, 0.2018413692712784, 0.04047063239399464, 0.07437917779410079, 0.051209855929858265, 0.03905504746662994, 0.03950945634935652, 0.020951520306088274, 0.057828939865313234, 0.11384909251524557, 0.04910174667114212, 0.0441496049414479, 0.04882682452819521, 0.11216235842796103, 0.016686352600734082, 0.04735467166850164, 0.06266120798705567, 0.11118116067542184, 0.122037063232593, 0.014853580130053865, 0.041276671803526344, 0.040912531060917724, 0.0605986618076361, 0.0618981461100761, 0.10657593037091917, 0.03438760316179645, 0.17083045185333298, 0.04180447573983862, 0.1307581851799642, 0.09110512181876168, 0.06604040266885873, 0.04145321676567678, 0.028299134705335866, 0.06801044373142143, 0.010766602560667502, 0.06937554346457606, 0.09455050266678296, 1.141843387196141, 7.019826183396002, 23.066833365348078, 36.11186189036216, 64.03977294122019, 78.37895808681365, 64.40711859733828, 63.97901542725102, 49.00619883691111, 39.08970179096345, 42.744327052947014, 43.42611343629899, 40.27909386542536, 28.461080789566044, 30.68782014231528, 36.317743178336855, 32.465040183836415, 16.54268445507173, 8.04592018165896, 1.5051970510713517, 0.35595588986912086, 0.268888832821, 0.5158847113770824, 0.9501007115167956, 3.321801856640847, 5.143764374717589, 6.636498830010814, 9.443425863019883, 9.293908053828824, 10.572940015023756, 12.904737111060852, 9.037854748387492, 15.754693035156498, 16.04534164551766, 14.18238643677004, 14.769512299568424, 9.330255677623134, 10.48748725844968, 10.83541424043717, 6.243724938361876, 5.80297359535771, 6.362570793397966, 3.7804737735179166, 4.979602886784462, 2.8504391110712484, 4.204061560092434, 5.210229917880028, 6.108248233795167, 5.171582804572198, 5.422864056402638, 3.446402809312267, 4.463612148838659, 19.06643548319417, 39.43504295041485, 55.32436839995846, 58.63458994896182, 55.87568498426869, 42.871847229619185, 19.1488484028847, 4.780725971344979, 3.5584448229882026, 5.436280523577045, 7.349741641552218, 9.533463870325397, 9.03262524835525, 9.588570229468807, 9.458484822703946, 10.191572866132184, 9.953359480827086, 8.371934352382537, 8.27547836688257, 8.72307179435607, 11.064818962927788, 13.967088518604157, 11.331274394066105, 12.721276090991113, 14.475255108648732, 14.627662724064244, 14.781381391709852, 13.913372639686832, 10.241233994883876, 10.278874039649963, 8.0546209792937, 8.454609090282071, 7.83277907679158, 4.293019935008019, 2.396454671698232, 0.81801857318609, 0.8939998476736007, 0.2333720620240896, 0.5382255512860514, 2.770256058823678, 11.753589126371569, 23.06293845176697, 31.06153376640812, 37.77320923343782, 35.447588889829575, 27.189821004867557, 25.344039893919422, 29.27025006663415, 38.30052483466364, 42.89260441257108, 52.49653562422722, 56.04041668676562, 71.56981760455717, 68.35449387950283, 54.33816686753304, 18.905798735157138, 4.597596881851073, 0.1975271604474514, 0.05383469149350159, 0.022643366115047567, 0.038310505765219854, 0.09419508383519228, 0.06067998970167772, 0.05850074534875251, 0.04911420326079092, 0.03135703019647589, 0.10000170854431006, 0.1902421852273326, 0.15574582822380528, 0.1159659696502551, 0.026496686867528388, 0.056059341877698905, 0.024189339207124808, 0.03933913968203049, 0.03315074654716638, 0.024050763477721525, 0.02607160766098288, 0.01068315068785582, 0.05987622174284151, 0.06363433883375218, 0.006566514024480938, 0.020086957524800976, 0.0034895247494381287, 0.032835332826981624, 0.10913755218949049, 0.04827233391904062, 0.12856121355247113, 0.33773056621993747, 0.13354116810425637, 0.05133411922161618, 0.08637075207286304, 0.021504578330824455, 0.1419123487486955, 0.169779026820775, 0.08567853800712094, 0.2172190215318434, 0.25785860695665885, 0.19237857462177355, 0.3025921049617952, 0.3070746999113791, 0.24629256387631743, 0.1512368798496262, 0.17636206631939258, 0.1507418797982316, 0.2701721833117547, 0.27846333841162346, 0.11650452946102428, 0.13141654582033235, 0.2610734489656264, 0.15581839207199313, 0.2647693941910421, 0.25815532813149117, 0.22771028921969477, 0.5813742585239873, 0.251127329444693, 0.3204734244894597, 0.1717288278403782, 0.20029505143963522, 0.1532964306252618, 0.26710210127695916, 0.20348850427375687, 0.27844342012559214, 0.18991353350781626, 0.1801226080785836, 1.6755182536378985, 10.335821951589278, 28.65563819485326, 53.69672990614369, 76.03856609713647, 88.37365150451662, 77.87377249810004, 76.08754081110801, 58.82144774160078, 47.7566062250445, 48.35468530654908, 48.789507496741514, 49.11819819481143, 34.46049305700487, 41.11097366579118, 45.22667354153049, 38.771217100081905, 17.07393027121021, 7.905992077242944, 1.8993565199836608, 0.3778814181925789, 0.47718927324298893, 0.43586722605170747, 0.7350981355674806, 3.4958016295586867, 7.107416631713991, 7.6221845707585745, 13.345131028083063, 18.934029994472382, 20.938584727625695, 20.2000710656566, 18.072246043912827, 26.131171334174375, 25.245557023632912, 21.985988963034846, 25.85988844594648, 14.649656434212963, 26.25407684233881, 16.43447410675787, 16.440988183021545, 12.77435556534798, 16.66572528500711, 11.073433468418738, 12.482511612676806, 6.669986065356962, 8.524534163936492, 11.987381019899923, 10.481871404955465, 10.057926927843402, 9.060574097018089, 5.491877178991995, 6.467598628613257, 24.032420881332893, 41.134515731565415, 52.79880915918658, 56.865275444522986, 54.13658841963738, 40.33001407500237, 19.92683287589781, 7.533886624920753, 8.252893359430375, 10.60026324564411, 11.530764179845011, 12.687441725884716, 15.80999747399361, 12.540127308137956, 12.586051398707975, 27.222798332091305, 34.10019590008643, 16.394687544914984, 14.779618286317396, 18.182207730508622, 27.09398965681753, 19.858324758468136, 19.76970076560974, 18.605107876562304, 20.855252012129753, 24.85208445979703, 19.856789150545676, 21.081825763948505, 14.822523132447275, 16.85971590780443, 15.514278219592189, 17.61800616018234, 13.809523967004592, 4.591627034448809, 2.756123513944688, 0.7260215871276394, 0.6800678336331922, 0.2213294203242948, 0.8662975567483133, 3.0454721037418615, 15.427967444542917, 27.683382649575513, 37.94198882195258, 52.8408020542514, 48.19040075425179, 37.58718298327538, 35.28940754552042, 30.770209527784782, 39.063206180449455, 47.71952413743543, 59.01251423743464, 64.69128647158223, 80.91948509216309, 77.12780829398864, 63.5881551619499, 26.542463225703088, 7.208173005811631, 0.7391550307793002, 0.1506368951090882, 0.1324155244735941, 0.12402369775959562, 0.1931349179076572, 0.11874103888628945, 0.2038059711095787, 0.2007996429118418, 0.2736093746798654, 0.2096004609859759, 0.4699496197844706, 0.2860120010952796, 0.3437681051511919, 0.10861901025618277, 0.22257345518277538, 0.12268796217657867, 0.19458734400330052, 0.22853832301353255, 0.12002171573018837, 0.15952792769718557, 0.09176174343954172, 0.25585818284701917, 0.18116232728765858, 0.10894222275143671, 0.1320836245412788, 0.2659008754116874, 0.1619599963868818, 0.24596150664071886, 0.27801033530023794, 0.5498960734375062, 0.6267707290187959, 0.3887098871411816, 0.21170956232855398, 0.22906732204700672, 0.1764536138263441], [0.0372653856362787, 0.06787305352308097, 0.06315779384045352, 0.2535679323538657, 0.1558475800219082, 0.0903784950834609, 0.008562450774104126, 0.0918768021848894, 0.05027672253368844, 0.0025104057286009797, 0.08609800178918146, 0.0665202954663865, 0.04349293352495279, 0.08107313150239569, 0.014917711265415195, 0.05285978332282074, 0.019628875250477466, 0.06388593359940475, 0.1880517559907129, 0.11265668432198225, 0.18441959524587279, 0.14913154765963554, 0.14981092975264595, 0.2651843074108324, 0.15218604746605122, 0.2071221359074116, 0.08844091316624995, 0.07243259434377955, 0.17529217856785945, 0.037084619529665484, 0.07148461416363716, 0.12459999506151485, 0.783827517542147, 9.493752814108326, 30.808740931172526, 42.007858907022786, 55.693847825450284, 60.557127921812004, 50.36641797711773, 50.15452369566887, 43.62965306928081, 38.21103203681208, 27.892868595738566, 23.79436831320486, 23.25928249666768, 34.152230062792384, 48.22154829579015, 35.775322529577444, 24.026568705035796, 9.723745892124793, 1.542987616792802, 0.10936288163065912, 0.015385898239459964, 0.3384977266673119, 0.4623361767059373, 0.5824587938766326, 3.2617682651166, 2.845202256594935, 6.419991841239314, 7.985107264211101, 6.794216354047099, 11.08875326571926, 8.651915096467542, 10.983541569402142, 8.629842938915376, 11.222590419553942, 10.419520428103786, 6.783739213020572, 4.757842373463416, 8.681017121961041, 7.523003518581391, 4.474857584122689, 6.57697735294219, 7.658017383467767, 8.005426122296242, 5.391846443376234, 6.694156200655046, 10.26631853272838, 11.38937940520625, 11.257847624440348, 11.532527285237467, 10.578026348544705, 9.866624109206661, 11.887151714294188, 34.50862053901919, 60.61729708025533, 68.44015059932586, 69.2082997291319, 68.90014263891405, 62.334130271788574, 37.50790795972271, 15.80978076304159, 11.43639881764689, 14.383109807968141, 15.258545567912442, 18.499590235371745, 17.55226331372415, 20.757814453494166, 21.704572631466775, 20.14672879249819, 12.045870423316957, 17.26564003575233, 7.497027622115228, 7.710432996672969, 12.130155294172226, 9.780330004230622, 11.07653606322504, 13.051042499080783, 14.21969896362674, 7.470586434487374, 11.651285867537222, 8.991124610747061, 9.35455378024809, 7.2839664355401075, 3.746599694413524, 2.4276333470498366, 3.3908777371529615, 3.452060583137697, 2.564074464382664, 1.2990806660344525, 0.17787046279878388, 0.21198536930305345, 0.4526790561935594, 0.8083704005806678, 4.248319623931762, 14.867481339362362, 32.12793992411706, 51.41169824907857, 45.82273260239632, 28.793635022255685, 30.42779641766702, 17.454768880721062, 14.959466803458431, 17.880952050608975, 27.864188225038593, 52.75544343456146, 55.38334123549923, 55.70066490480977, 55.63401991321195, 34.73133271740329, 10.634319224665242, 1.436262008163237, 0.1434390087642016, 0.05106890724310952, 0.058995281916952906, 0.04275641659454953, 0.04615482476149355, 0.1342356421293751, 0.03632496291350934, 0.15013277861139468, 0.12900840971739064, 0.24799131788313392, 0.18692798161458585, 0.23949442221032036, 0.08550669682482559, 0.08908860986271212, 0.04064967480277823, 0.07643562591364307, 0.06029688062206392, 0.003383172114544939, 0.05389953317541269, 0.06693677150554235, 0.08538917127636172, 0.07822573590543001, 0.015841074167720733, 0.03903520578939108, 0.05660190449787244, 0.04104229486397198, 0.04152465063417631, 0.05687291193152628, 0.20511231955982026, 0.3442306383963554, 0.14528247677991468, 0.05226383586564372, 0.03902824971103861, 0.032910432426198837, 0.025971208008066304, 0.0407985027038282, 0.020399236030155615, 0.10901010580240719, 0.07425232895559843, 0.01407887275901533, 0.06331351270238239, 0.11324562973553136, 0.055509103056524074, 0.09537382501988642, 0.03441944943680879, 0.03367054869510955, 0.07547720395509275, 0.05627604516884012, 0.005985185440118996, 0.024437999856027386, 0.06435810423065579, 0.015317582348812253, 0.0976459881771476, 0.05174455465748907, 0.0725470555405463, 0.09774555662466634, 0.025087226813118306, 0.10287410925112425, 0.14948814626662962, 0.15828298885495434, 0.07405001279567519, 0.1492976968086535, 0.11181403357054918, 0.01419943393087916, 0.057192067991221146, 0.037688384914109786, 1.089952513575554, 11.229614403940017, 32.1039605140686, 53.587311467816754, 68.66509852870819, 72.74432428421514, 60.14880134213356, 59.28729587985624, 50.0684747388286, 43.517508583684126, 39.97250572327645, 31.824040566721273, 34.07463381367345, 36.74329680781211, 44.59155944085891, 33.15673251305857, 24.02184421016324, 9.130551142077293, 1.8358057881555252, 0.13224618839881114, 0.17720819511000188, 0.6530376163221175, 1.8511046252904402, 6.002520255504116, 5.540773445560086, 6.681914973643519, 8.305686500764663, 11.510430612871724, 10.771990495343363, 11.160939585778022, 9.35606389276443, 13.600558715481913, 17.367882497849003, 15.146508947495493, 16.330517568895896, 17.03226097168461, 8.516777676920738, 6.351106685976829, 8.455664207858424, 5.595650836344689, 5.2888557891691885, 6.203667732977099, 5.789443869744578, 6.964708057142074, 7.346827810810459, 10.286082375434138, 10.626549989946428, 11.129873433420736, 12.886512798647727, 11.575786125275398, 10.777262160854956, 14.184635916063863, 38.37035086847121, 63.828643521954945, 74.84352973199661, 72.28062168244394, 72.4389991452617, 64.38433747137746, 40.88710046583607, 16.4946295369056, 12.210649194255954, 14.28266477200293, 18.613311513777703, 15.68432963663532, 19.14178421420436, 20.21894551092579, 20.051856463955296, 16.465045059880904, 14.149815074859129, 10.65625213807629, 6.8057848945740735, 7.320217470968924, 8.869557611403927, 12.946480935619725, 14.735595564688406, 12.882763012762993, 20.637076054849935, 12.24810782940157, 14.128260670169709, 13.706786305673662, 13.531687778811301, 14.447986791210791, 11.456302885086307, 9.875212138698949, 9.598026083361718, 7.063495401413211, 3.5660235776055247, 2.8059256028744484, 0.6257865818277483, 0.35586493991075024, 0.27471542178142455, 1.1951580811892788, 3.5943886878028994, 13.954510458054083, 24.638101516231416, 43.97705347307267, 40.043182911411414, 31.147463090958137, 30.542372772770545, 23.282873592069073, 22.434013851227302, 25.775531991835564, 34.72860274776336, 58.577044856163766, 63.84019097974224, 65.16989408000823, 63.83023992661507, 37.77475464728571, 12.14614385558713, 2.1237908640215477, 0.15793553733777616, 0.015593413263559343, 0.07866223748292654, 0.03455808836846583, 0.06117004848596069, 0.028098812289235574, 0.07384522217175654, 0.06831892435589144, 0.061582590663625356, 0.004055935686694518, 0.12093806413993721, 0.030123191968267484, 0.05484308153691311, 0.02807293192393357, 0.06963103378732359, 0.07162280876429812, 0.050260010325620254, 0.03901046881031606, 0.03233757868949925, 0.10253543710155834, 0.01899736024619591, 0.04387449893739916, 0.03749705445502074, 0.103626323323096, 0.07540952008698257, 0.043403887295074044, 0.08488779737343712, 0.0785684836427531, 0.21369762177909576, 0.3051267834680696, 0.08173244209178994, 0.04902569329245918, 0.022936285578555638, 0.020154829084452604, 0.11623797682865013, 0.16218586975047666, 0.1590126876028315, 0.4041433412461512, 0.3523816300495979, 0.16363042046225842, 0.2370713167493382, 0.3599437145936874, 0.18168479925201786, 0.19975540378401357, 0.21609564552143698, 0.22780343018952878, 0.19536138392023503, 0.18159044786326348, 0.11957436634768402, 0.07713723987821611, 0.10098164991265345, 0.2175430154367801, 0.40732386251611097, 0.19911374386039474, 0.2812718780290696, 0.34933260011096157, 0.2751439407227501, 0.3906665369868279, 0.3354731502552187, 0.32212750024853215, 0.24832559268801446, 0.27057597293488445, 0.36683951714827173, 0.19131771138598844, 0.1747067341761243, 0.31034319871856325, 2.392923312802469, 16.473460505085608, 44.44709070267216, 66.66332475600704, 78.55073436614006, 82.38315674566454, 69.63601066220191, 69.19848595896076, 61.05932074208414, 56.434516829829064, 40.18333704240861, 33.42677200994184, 34.166813435093054, 46.27411896182645, 64.95141021666988, 49.3618832865069, 31.74727978244905, 12.997117753951782, 2.769401227274249, 0.32164032961572375, 0.2643940723951786, 0.9484875142093628, 2.264259765225072, 6.324373772067409, 7.934970548076015, 10.863202271922942, 16.13560715029317, 19.56695345140273, 19.83243711533085, 24.62878000351691, 22.906902643942065, 27.221851079694687, 21.973959053716353, 24.378430804898663, 25.18170868196795, 22.956773619497977, 13.74650618722362, 18.01215337168786, 16.745323904099003, 11.09696965063772, 14.150209273061446, 17.74274145403216, 14.16158022419099, 9.25694755969509, 11.423053933728127, 16.632589101791382, 16.915750888086137, 17.709842574211862, 16.89170675892984, 16.940299041809574, 13.86144438097554, 18.711919899909727, 50.8544235844766, 65.33545340261152, 73.16204886282645, 72.47046439878403, 73.48565224678286, 62.41622547949515, 42.630884262823294, 20.916474326964348, 15.408197718281901, 20.728592795710412, 22.74600309710349, 22.24381616038661, 22.20281562497539, 24.791270071460357, 27.893409882822347, 25.78032316700105, 17.947924560116185, 24.705517253568097, 14.203834937464807, 14.841077904547415, 19.060504859493626, 22.00330818853071, 24.463263826985514, 21.602949903857326, 24.871943419979466, 21.37346967574089, 22.32500137821321, 20.20176749075613, 16.976930056848836, 18.634933579352595, 16.979595307380922, 13.238356267252277, 13.764365719210717, 11.666044765903104, 8.06760157308271, 4.089971088594006, 1.5992499719704352, 0.43339251690814573, 0.7085753748974493, 1.5348890255535803, 5.047443220692297, 18.430929145505353, 39.41782766772855, 62.93601012999012, 60.28579012040169, 42.02231284110777, 44.613316828204745, 27.782502905015026, 24.80399424029935, 28.44233382132746, 41.84244471211588, 68.17718705823346, 70.67697632697322, 72.59814539263326, 73.67134509548065, 49.60974962480607, 17.16687475481341, 3.2831890640720247, 0.5463176460996751, 0.22283128973457123, 0.3621244604789442, 0.20631621141106854, 0.21113605358667914, 0.25145098627094303, 0.23418100490685434, 0.24203406496634408, 0.3705240936288911, 0.5204341704806974, 0.4677545327332712, 0.4034935148252595, 0.17303969620937304, 0.15476828471066492, 0.19170490754467828, 0.20289893832898911, 0.27860445180727594, 0.22919098395974408, 0.11511546649759817, 0.2632215288617919, 0.31542493571196834, 0.1487438305611572, 0.12378389691753734, 0.12019382504325722, 0.1825130935157499, 0.05928646810653229, 0.20621525634440685, 0.16981658045082323, 0.5469340710870682, 0.615460145617685, 0.28697626064381293, 0.14587078634048664, 0.2007752506723327, 0.14122021895262504], [0.038385348724982435, 0.13234538146324698, 0.010574343219970264, 0.12011183065272148, 0.14374840103330153, 0.03366135564001818, 0.028896989721444347, 0.04706670304820423, 0.04687434986173626, 0.04786245772735246, 0.09119503755843447, 0.0733822139520799, 0.02734121453437594, 0.02876966207798931, 0.004198254713217818, 0.07532128974074319, 0.04315883492029483, 0.031483697089096235, 0.17553804682627802, 0.112571771136455, 0.1629731783102597, 0.21497159535365723, 0.2519035144078155, 0.20286596590472808, 0.11014959264186122, 0.17148683598685652, 0.1568314054560277, 0.05171294970017287, 0.14861669060924362, 0.16696984368947246, 0.2118392303706177, 0.43839393724356934, 3.6226000901191466, 22.95475163767415, 37.67339275729272, 39.97047001315702, 53.80307712862569, 52.45804148335611, 43.10451438350063, 38.896940831215154, 39.40334627705236, 31.48847395373929, 36.273177208439, 40.5587157126396, 37.44561679901616, 31.722390382520615, 30.580166770565896, 29.607203237472046, 10.929001992748631, 2.6765427906667036, 0.49347075603662005, 0.05922752913207777, 0.4318433951946997, 1.0476796593396895, 1.0472497920836172, 5.323588377045048, 3.508826104863998, 6.039854845693035, 5.144110523885296, 8.940719212255171, 6.321818838196417, 5.401838191093938, 7.444691436906015, 7.155885850229572, 18.27714870052953, 19.097106456756592, 14.042474512130985, 18.716150176140573, 10.082988912059415, 5.920832974295463, 12.228841147115155, 10.834665067734258, 13.560943757334064, 17.55803115906254, 17.12382674217224, 21.420096851164296, 17.698420632270075, 20.892700841349942, 22.492617983971876, 24.37777969145006, 24.44259685854758, 25.4797480183263, 23.557659156860847, 31.45412183577015, 45.196585039938654, 56.829319077153365, 62.62093790115849, 66.67909268409976, 64.88385523519209, 70.37153351691462, 51.54034022362002, 32.13812828063965, 25.80491642798147, 26.115171986241496, 30.316836487862375, 27.493235949547064, 30.31835444511906, 31.798609879709062, 32.27249299326251, 26.04208646282073, 19.422488635586156, 17.555108993284165, 16.115315748799233, 10.442336855396148, 8.759251736825513, 17.2887388736971, 8.698394202416944, 9.235613788327864, 15.362388357039421, 10.65310541660555, 13.28056195089894, 12.42737485516456, 9.351580623657474, 9.904372999745032, 8.520892243231497, 7.55744339958314, 9.760727959294474, 6.324940064261037, 2.1200016092869545, 1.211782066572097, 1.3663075167325236, 0.7813259033906845, 0.02225679431801602, 0.19294966252580767, 0.3195083069224512, 4.387821660887811, 13.626178656854938, 32.68709144284649, 45.139483174970074, 38.93426610577492, 28.85290791911464, 29.83177265813274, 29.061544672135387, 29.26477836024377, 33.68860198605445, 40.263643649316606, 55.70830960427561, 52.561439083468535, 61.403928418313306, 41.22852709985549, 24.528057459862005, 4.810389876365662, 0.257546441449273, 0.037328331250577204, 0.07209660350194863, 0.036631934344768524, 0.1279956568032503, 0.03892888044638019, 0.05872756483093385, 0.07710569237749423, 0.11774981304282144, 0.1158115876117541, 0.2546535095860881, 0.29881578179136403, 0.16309192193852318, 0.11002268251632491, 0.10091133070208373, 0.15741874974581505, 0.02171876119269479, 0.04926259449172405, 0.06900333198568515, 0.08308287890207383, 0.1305857081446917, 0.05001671229218764, 0.07137451200715958, 0.05938428221270443, 0.013622874243845864, 0.027773801402579394, 0.0692013044270777, 0.07528691537558072, 0.1749885626017086, 0.2710784346826615, 0.11663227462239804, 0.053544784670755755, 0.07745780170925202, 0.09994865695555365, 0.0030920012467240375, 0.04144007069689613, 0.059162239288730975, 0.11631788746003183, 0.15150977569001337, 0.05438094665747016, 0.01246730626125129, 0.11710141920634817, 0.0828324524205058, 0.07992399195509572, 0.07361036259680986, 0.06188383175721092, 0.03231178833952835, 0.06790589571239487, 0.08957420235439655, 0.036886057200571226, 0.020492874957140417, 0.04529302947283272, 0.023875712387023434, 0.03125483215215706, 0.09918539589571376, 0.04093901089002048, 0.16276892394788806, 0.08589072904038815, 0.006339604526968494, 0.09070112535189237, 0.06632439146238951, 0.03136553760287503, 0.018000662619728717, 0.13220675019246916, 0.13738858423406078, 0.35968410271790724, 3.188477062409924, 23.316349060304706, 46.24661922454835, 51.832039048594815, 67.26263153937556, 64.48287133247622, 54.72029985920076, 47.58329629898072, 51.26340127760365, 39.40805312125914, 37.622158758101925, 35.78571288816391, 35.27822486815914, 33.25046931543658, 38.06743798717376, 27.624480416697843, 11.199712214931365, 3.3399467410579806, 0.42033699972014277, 0.28963320678280247, 1.2193442736902547, 2.483308695016369, 4.193717779651765, 6.502367008116938, 9.055125924848742, 11.365437257674433, 9.797651190911571, 13.059000007567867, 10.139995659551314, 10.091460251039075, 13.76891468801806, 13.028681066728408, 13.21523585627156, 13.415144355066362, 14.498960933377667, 13.804837715241218, 8.120724683807742, 8.25295219498296, 9.901605767588462, 9.380812087366659, 13.850192081543709, 16.9601030888096, 19.007499910170033, 19.728021660158714, 18.255920833156956, 21.31504204965407, 22.980388249120406, 25.07801886527769, 25.67268548473235, 27.07878458884455, 24.562033030294604, 36.13479991112986, 53.84766271037441, 67.65254651346515, 71.1130968216927, 73.89807378092121, 71.430848029352, 74.4056127917382, 57.01985605301396, 34.298185379274436, 28.67948228313077, 27.417802887578166, 29.8802060850205, 29.668662855702063, 32.68722284224726, 30.74096041340982, 30.452122957475726, 23.014907067821873, 19.54927336785101, 14.26187817127474, 13.57937889714395, 10.903228098346341, 7.822544632419464, 10.73840323955782, 13.745274562989513, 16.294695542704677, 22.225675198339648, 15.418138965483635, 16.720662001640566, 20.14757602445541, 12.513852330946154, 13.32235578567751, 10.566396520983789, 9.187007777152523, 8.51657763604195, 9.199223999054201, 5.814026834503298, 4.695533071794818, 2.6488381095470923, 1.8477677914404103, 0.3913603062110563, 0.27800880312438936, 0.5605676782227332, 3.9399870076487145, 12.721901709033599, 34.7110422965019, 43.17631336950487, 41.8322112483363, 36.7772880677254, 25.84826057957065, 27.13927342045692, 26.56990020505844, 39.707675133982015, 51.97196175975185, 64.08331125013291, 59.30083590169107, 69.25547799756451, 49.76559323649253, 28.54988325026728, 6.193428875938539, 0.33483126050522255, 0.07123245632336025, 0.05331559797688838, 0.04898429390103106, 0.020151785800173398, 0.06755961630974086, 0.05125410899880433, 0.028587787059105696, 0.036329421545228655, 0.06353796114243808, 0.1658170345810152, 0.06611182504603941, 0.028840310706366456, 0.11401508844667867, 0.05174469255331544, 0.0393811634351169, 0.06517287704252428, 0.04994139052747239, 0.0555827011234097, 0.12090181285936026, 0.07481485965751833, 0.05958620383734665, 0.010887539115614228, 0.0859343194432797, 0.03172557785986893, 0.0004376793179788717, 0.06750052028726186, 0.07040777033375156, 0.06878599284156676, 0.12952435461263503, 0.08907433764468278, 0.06878847496644144, 0.02149800912687375, 0.028837547044179616, 0.1534646788551923, 0.19019199114653373, 0.148962318837162, 0.4201196452542659, 0.23394445227759503, 0.16169240187493064, 0.17813563647289432, 0.2681203240588788, 0.10929476875331133, 0.2762544311342701, 0.21192299442425852, 0.17716625945702677, 0.08213660709800259, 0.1965003574807798, 0.16721293870960513, 0.18857019833259045, 0.13389208233885228, 0.18940043845965018, 0.2901979055135481, 0.3466499134177162, 0.2128646543790256, 0.3308942120882773, 0.3167993280916445, 0.3949790910607384, 0.30081110375542797, 0.4023112572969929, 0.23323995782242668, 0.17981315452244975, 0.22579775071672856, 0.42532858348661856, 0.39672901974089686, 1.0246467662434424, 6.449614071076916, 31.190915107727054, 56.733275921114036, 66.12965491510207, 77.20361986467915, 74.85961929444345, 67.82415805324432, 55.436512885555146, 58.47333346643756, 44.594685569886245, 50.73623472644437, 53.63526244317332, 50.97070617060508, 46.566280626481586, 43.51805771550825, 37.74858067112584, 15.391147175142843, 3.8228750853769244, 0.8871064046698233, 0.579017220485595, 1.8930620964496367, 2.772616590223005, 6.08889231758733, 10.934814945344003, 15.143605412975436, 16.2922764209009, 17.539142985497755, 20.164055862734397, 17.884795973377845, 15.09713807413655, 21.435460775129258, 19.575386547273208, 26.95877378986728, 30.736200617205714, 27.92914071390706, 28.905044063445064, 21.600774949596776, 14.516688085371449, 19.60138793914549, 16.18713728843197, 20.23035372457197, 22.784505082714944, 24.0586595766006, 28.037764872274092, 22.377025734993722, 25.16922770007964, 26.98327683633374, 29.78810883337452, 29.066771230389996, 32.475846313661144, 28.36398643832053, 44.27611066449074, 61.90876491608159, 68.09625287209788, 72.23997023797804, 75.85636415789205, 71.6654920578003, 74.80748315011301, 60.51042033780006, 39.90301309093353, 32.3392281993743, 32.69320641794513, 34.034672706357895, 32.81539609355311, 33.751830593232185, 33.40316718624484, 40.28852324331961, 30.447500444227654, 25.106995374925678, 21.353228284466653, 22.534422605268418, 17.478605124258227, 14.45151202140316, 25.65833745464202, 16.345704986203103, 19.336018023952363, 25.026661311426473, 16.872928411729877, 29.587969895332094, 23.094399782919115, 23.366884877604825, 21.217014174307547, 16.549068112527173, 17.698208824280773, 19.820797481844505, 14.377468459067808, 8.49732272086605, 6.60547435283661, 2.7163737243221653, 2.6604360678503594, 0.32456862409749343, 0.4898044430921155, 0.7244225471250473, 5.370994142947659, 16.13143669020745, 40.5838502607038, 54.58703341022615, 50.35557262359127, 40.47397290506671, 40.912537036403535, 40.836729388083185, 42.86764637116463, 48.100005811260594, 54.53479136190107, 70.08446308874315, 67.71623011558287, 77.29514445027998, 60.3269632401005, 36.968664430802875, 9.787631496306389, 0.5159705132246017, 0.24339374845787404, 0.1735347115825261, 0.14349888619636336, 0.16482861261935006, 0.28057584118458534, 0.30899589520788967, 0.18958857433209497, 0.3255952125595462, 0.3179960800034385, 0.47311956904107527, 0.4668959013877377, 0.3241481644011313, 0.2521915787891034, 0.27007053876596115, 0.34986659403770204, 0.13641857902609533, 0.13297957969048332, 0.12434223711851145, 0.21079813220327903, 0.4148770297967619, 0.2030080905364406, 0.15956964884554187, 0.22156764302522908, 0.10323535035093946, 0.13264577986011583, 0.12996911461795532, 0.38141740425940485, 0.39655962237908, 0.47263337900080993, 0.2607102007154496, 0.20606772313194893, 0.2530632949163837, 0.2531718648970127], [0.0555939051593023, 0.03969114176147888, 0.0888152773522081, 0.06950866656317826, 0.29111181776369777, 0.07142511977543754, 0.017781188005521413, 0.07395131002751089, 0.04592910461548356, 0.05360398794554415, 0.03160788760250134, 0.06693880163854168, 0.018371297872715422, 0.08526197769829343, 0.04013964793674889, 0.09726900397048843, 0.05635006075364448, 0.08540969477185319, 0.19387480562492726, 0.1275112594087278, 0.20062499018686436, 0.16788936370322782, 0.23039593301232786, 0.08342256994857904, 0.19631461180265874, 0.21039703920964273, 0.10524142052858107, 0.025728936532452226, 0.16452976172008824, 0.03581169932599991, 0.13369866045972995, 0.6496152257727039, 9.255558060061547, 23.598349825028453, 41.08925550214706, 60.75121072030837, 59.12760442303073, 55.8831217981154, 46.24089256409676, 38.45857281838694, 29.660612190923384, 27.925779242669385, 41.79767870133923, 46.17115282243299, 45.04322428857127, 35.247269522759225, 30.906668786079656, 13.304308960514685, 3.5501705831097023, 0.6676203144654151, 0.18143482476232514, 0.17447534497947464, 0.5763897227664148, 2.5858092981000103, 2.976563169110206, 7.3070780211879365, 4.463154702417312, 4.9381140162867885, 5.590067832700668, 10.18201110824462, 9.316783316673773, 8.728225788762494, 6.769969242234384, 12.295629305224265, 13.387660307268943, 13.490210675424146, 17.614819234417332, 16.463221157750777, 11.972977096034635, 15.810239680351751, 18.226330472577004, 22.567676459589315, 25.69664920530012, 31.84745123309474, 36.83353093362624, 35.957614683335834, 35.482337167186124, 38.341505758223995, 38.80123107664047, 34.82473219594648, 40.43507476006785, 43.05042489882439, 45.237695401714696, 46.502283234750074, 41.74323228097732, 49.54986287701515, 53.47567689034247, 56.38629128856044, 58.55096109451787, 65.00364049788445, 57.45423501537692, 50.71182189449188, 48.55411429559031, 43.62885682813583, 42.28659429857808, 40.937173443455855, 39.79543032184724, 39.788311219984486, 41.16578094420895, 34.116858128578436, 35.807285924111646, 24.967323695459676, 21.437469028657485, 16.773276675132013, 14.694750943491536, 11.40982181795182, 19.426077604293823, 17.652495561107514, 26.659451838462587, 14.860814290661967, 9.809279057287402, 15.391224641953746, 10.173983977686975, 16.48195832006393, 8.888870381539869, 6.897854689628848, 6.213987488900462, 5.176606870466664, 2.655220541261858, 6.396410551763351, 1.2101066016381787, 1.088311859676915, 0.6565462377282881, 0.42592996250717874, 0.07506889441320974, 0.6293849274516106, 2.7956757141697794, 12.62372576421307, 32.84887940652909, 44.81895100685858, 30.476355360400294, 44.083785087831565, 29.380378453962265, 22.46681074942312, 15.948452238113651, 33.943144198386904, 51.774788133559696, 48.521244833546305, 58.46204488508163, 58.84447597688245, 32.11808300787403, 14.029616982706132, 0.6352472161093067, 0.02990283252250764, 0.04932935522388547, 0.029034504419072505, 0.04831130864218839, 0.08508619116318804, 0.08594555029224965, 0.08060170397643121, 0.21620954747401902, 0.16967505336769168, 0.19229447348944603, 0.22643669868909547, 0.14718496420931432, 0.04280198733472536, 0.1277050030447783, 0.1139507370610391, 0.0745020812797931, 0.060660385511695385, 0.016351598990900863, 0.09812680028018453, 0.07623944611799333, 0.07889268439142935, 0.025471802951107105, 0.018290094467961503, 0.0019304273742055823, 0.033363159745931625, 0.1033157512785927, 0.1012247602545446, 0.15715140038199965, 0.15051738539290044, 0.11669690179969035, 0.07971396895065423, 0.06191448676550101, 0.0222288531761977, 0.03094407241611231, 0.06703700644955521, 0.03945022626149078, 0.02430225865194394, 0.05614919249989814, 0.026200628358750578, 0.12670862909045913, 0.06300125909488528, 0.12666056473408976, 0.0457732631794868, 0.05393160161592307, 0.010019758765044953, 0.018175365140421257, 0.032517073090158166, 0.01281370249231376, 0.07599828930030908, 0.07940204859140419, 0.030780041500204997, 0.08254711531222829, 0.09960297510148057, 0.014607888071857875, 0.025819137639876817, 0.02788246905941877, 0.16107259077891228, 0.05986556545981477, 0.08881088000752273, 0.027523824997666865, 0.0568621062613543, 0.05845442001197127, 0.046977223978648265, 0.12496437712181961, 0.8711525317161315, 11.201671438832438, 31.33032987194677, 48.484323563114295, 66.20143428925546, 68.28313027658771, 63.327670558806396, 55.22973337481099, 44.27491434158818, 34.6965765953064, 31.0892217774545, 42.238094191397394, 44.70100925814721, 43.54138797329318, 38.36083519843317, 27.16766353576414, 16.532405884035175, 4.12255225643035, 0.6714484251795277, 0.14127511681327898, 0.27435018170264464, 1.9916931587842204, 5.305320428263757, 10.082759453404336, 7.429320648793252, 9.142202542674157, 12.624962291409894, 7.73168832063675, 11.84847322202498, 14.05122826176305, 15.099791557558122, 12.033092321888095, 11.785297566844571, 11.168644101388994, 12.18301707698453, 9.996865430185872, 10.416092276573181, 9.948264321973248, 10.649791994402486, 16.295774194502062, 23.630660349322905, 28.918733135346447, 32.66308065383665, 36.787462695952385, 36.12825739768244, 35.59042199965447, 37.65032137593916, 41.01600523917906, 39.19688447829216, 44.37489163491034, 47.05399990081788, 48.19772774173368, 53.018250080846975, 50.40271166832217, 57.59399690935689, 63.710960649674945, 62.92066581787602, 66.3290839041433, 71.40788647436327, 62.92609830056468, 53.07765045473653, 49.152240445536954, 44.7942675313642, 43.3030882958443, 42.18103547250071, 42.80922266744798, 41.34351922619728, 41.16437281331709, 39.89629014845818, 34.315020192054014, 25.778787559078587, 20.16632495387908, 17.72644792833636, 12.44807908611913, 12.27583408355713, 15.903137095512884, 13.866709182339331, 23.426444107486358, 12.981122328389077, 16.206301008501363, 19.76157557579779, 13.83519882156003, 15.066198418217322, 14.84102201077246, 11.424234567149995, 10.883830997251696, 11.227592422116189, 7.368046362553874, 4.684395011394255, 2.9877380017311346, 3.60977124302618, 1.446254123603144, 1.106925222181505, 0.18369916616187942, 0.8230059281472237, 3.482543528079987, 13.949932071470446, 30.42951833817267, 40.61076556482623, 32.40771866613819, 44.84933368621334, 33.99193456096034, 34.28679089392386, 23.0805734280617, 37.91885860504643, 60.11725764120779, 57.14896478960591, 67.17007144804924, 67.35989847490865, 38.70401513191962, 16.035771062297208, 0.9610698035647793, 0.09577714732938236, 0.036983426975747274, 0.0964897852991858, 0.01447785996846975, 0.042265220169699004, 0.04155356662287828, 0.18582257802688307, 0.05299113292787826, 0.027687438395655448, 0.018681749258370652, 0.05752915050834418, 0.11777952193252503, 0.06398649413078543, 0.07509850371148317, 0.09645148856385101, 0.03447074668421861, 0.1074976797005342, 0.0630931819849197, 0.056449303613795396, 0.09409946074048359, 0.06229728940994509, 0.047129246466342485, 0.06058266206133751, 0.0440688707655476, 0.11756582936692624, 0.039442270438397126, 0.10640235782991495, 0.09372286723866578, 0.11585468771837412, 0.10687085123912943, 0.03909273516206492, 0.06441130903699706, 0.08761942942416476, 0.1570852410288588, 0.19949148649409895, 0.23310745525504314, 0.2573707315229601, 0.4026451490579113, 0.26265171266371207, 0.1895718429718287, 0.1460027373245647, 0.19328548482829527, 0.18627086203665505, 0.17189393510981915, 0.23428310910540245, 0.16793514511758284, 0.22393323060485626, 0.245693038788534, 0.23759659259550034, 0.11596941704591436, 0.17136413934490374, 0.25649394389362107, 0.23387029496652467, 0.25739938321132816, 0.3993870690464974, 0.4775088851249987, 0.5232927816048746, 0.40848571146207474, 0.31997264813511606, 0.24318705793590317, 0.15900770803132366, 0.332063568695899, 0.2091183465334677, 0.34382626654640325, 2.047703991974554, 14.972879348262666, 39.04497500388853, 61.84885071169946, 79.19665459663638, 81.54577778231713, 74.60138613177885, 65.6932206307688, 54.852605327483154, 42.498653319574174, 42.19581104093983, 56.35650873184205, 60.915867897772024, 58.34793921439879, 48.47978145845475, 41.30408371648481, 17.806642747694447, 4.410393920636946, 0.9600034091741809, 0.3904731457512225, 0.25543311130135293, 1.7223058785161667, 7.071126862879723, 13.555320059099506, 11.600406842847026, 15.309632478221772, 19.502142167860463, 16.66402885990758, 23.67827792321482, 19.388803320546305, 25.041583968747048, 20.445336872531524, 28.6126882414664, 32.744966014739006, 32.24695051870039, 28.873480750668435, 25.864287384094734, 19.59383345419361, 20.75263104131145, 23.223771318312615, 30.12641129955169, 36.42401195341541, 38.517451517043575, 39.940722757770175, 40.923123513498616, 39.61492284651726, 43.21578418054889, 43.974876557627034, 43.8339771762971, 48.16889439859698, 50.18214502642232, 53.40037522777435, 57.63103977326424, 58.89855369444817, 60.795831603388635, 66.15533075025006, 66.00637482058617, 70.03534716944542, 78.01780193082749, 68.59164038012105, 56.82549084386518, 53.23312928599697, 50.28688407713368, 45.19540048414662, 40.98588928099602, 44.640804798372336, 45.68845810428743, 44.62224022034676, 42.01604881594258, 41.21301804819415, 29.949347665233, 26.84100070307332, 22.020784308833463, 22.121726505218014, 18.566970671376875, 30.02729104411218, 32.5961571739566, 42.80815186039094, 27.26077275891458, 27.183531484296246, 28.194494939619496, 23.659752568890973, 31.872185699401367, 21.365919113159183, 19.903847786688036, 15.473868981484445, 19.08255054104713, 11.512421215734175, 11.54374526393029, 5.775032101138946, 3.167730420827866, 1.8460170660288104, 0.992647457507349, 0.2512954704223141, 0.822749074187971, 3.9499718912186164, 15.413704726003832, 40.33505824304397, 57.860729848184896, 44.546409037805375, 56.976153004554014, 42.94208118992467, 36.14131496798608, 25.905260462914747, 46.891986400850364, 65.53265056302472, 63.74887427976055, 75.62441087538197, 79.93889254908409, 48.226192382074174, 20.608833028424172, 2.5721096848287894, 0.3655737253927416, 0.11855815837700522, 0.20416125204534302, 0.22053460410285383, 0.16452285160701122, 0.20576588448978242, 0.2576366559632363, 0.43082878834778265, 0.3285530780351931, 0.3656559113052584, 0.5103669171371769, 0.2191973516657468, 0.23746096438938574, 0.23346518767216515, 0.27742823105185266, 0.24270612325879837, 0.2482307816465055, 0.2165588988892494, 0.2318591303041866, 0.272032980236315, 0.1747790375544179, 0.1878139929425332, 0.10567097368860438, 0.24494195086581094, 0.12187587067244515, 0.29047158276361806, 0.21328286177689032, 0.40398583356891915, 0.302871267401403, 0.24201016302310654, 0.18034819032876723, 0.1494681820153229, 0.20366966874609072], [0.08506078002673965, 0.07717773528589357, 0.05028407697776153, 0.07277493605450278, 0.17576427259031804, 0.2130200016883112, 0.008574503252372868, 0.020469080266212265, 0.03261700159900131, 0.04209556233798785, 0.02469640131288719, 0.05185379496505184, 0.026715391563371788, 0.0698957554695587, 0.016222631919287866, 0.03640758166570337, 0.09510399353119636, 0.10939527948897694, 0.13821752201164925, 0.17322251543162331, 0.09686846256015763, 0.11954943784662794, 0.12965000835397553, 0.0772073062797708, 0.1585176722296784, 0.19841752315480865, 0.04710224952789084, 0.07262092939908467, 0.17043165712346955, 0.18605173024679386, 0.11577034143791085, 1.8792214004262802, 14.070139969548872, 24.620266499057895, 53.21021087708012, 55.02905707205496, 50.17058972389468, 43.543847299391224, 42.1153240050039, 34.87119659300774, 35.158945591219016, 37.80895379281814, 20.870990522446174, 28.917093584614417, 43.459481039354884, 35.24983083048175, 18.716616938191077, 4.641337683123927, 0.8092013914738933, 0.1546728148335411, 0.3744349418388259, 0.20861459775797783, 2.781723108022444, 5.294971744860373, 4.628756190499952, 6.870396627533821, 8.458556955860507, 11.515569898390002, 4.834016273098608, 8.68007085015697, 7.696598306778939, 8.556074923084628, 11.168358748958958, 8.874245824352387, 7.884000818575583, 7.792226672172547, 18.87659865040933, 20.95495277835477, 21.248240163249356, 25.82331822764489, 37.63645187500985, 39.16073983715427, 43.17081812889346, 47.8926654015818, 52.1359678237669, 50.989886560747706, 49.70360409828925, 51.47648403721472, 55.744191446611964, 57.270118959488414, 60.598489315279075, 56.66647403470932, 58.91321943652246, 52.78742644094652, 39.4445703875634, 43.5807881816741, 48.636735100899976, 55.34800852498701, 56.206489839861476, 58.04481452511203, 54.245410657698116, 64.70111200886389, 62.42573330479284, 57.77617923675045, 54.72537148383356, 52.748583209130075, 53.538172014297984, 52.789156206192516, 50.103940809926684, 44.09044135001398, 37.99550171821348, 38.20503865518878, 35.025557548769065, 34.10786021140314, 20.6728421872662, 18.282214441607078, 25.283252962173957, 15.076727040352361, 26.063047609021588, 17.98388288867089, 11.287790017743266, 22.33802168600021, 9.0875845186172, 8.714416103978312, 7.462846617544852, 5.802462216346495, 5.828482239477097, 10.503760191702074, 6.211687999386942, 2.059767486587648, 3.6333704283160553, 2.5607786928453757, 1.1517617130471816, 1.128845265315425, 0.15166726804548694, 0.26202532853330335, 0.910371636911746, 6.310665578611436, 14.929155707359316, 34.84102179927211, 51.347555729650686, 37.278429692791356, 29.69914555549622, 22.6323857615071, 52.846101176354196, 70.00601568529683, 68.67192345280802, 50.360805065401145, 53.24949341435587, 54.794609162115286, 48.025873015003825, 23.884537719911147, 4.570432997518971, 0.09869662413914358, 0.03813722816806647, 0.014143303626277035, 0.018395860566787662, 0.1444830793526865, 0.08973141891821738, 0.05872071217445116, 0.1260973598747965, 0.07981696947207374, 0.0959132275273723, 0.15352581267154988, 0.13843207259572324, 0.19055666432024973, 0.09410739741137913, 0.10481134642876926, 0.1292522555036891, 0.08701542272202431, 0.032262417803248095, 0.08726328280904601, 0.08222184204045804, 0.04176480387667975, 0.036650174898245645, 0.07255034205774147, 0.03748336446381385, 0.06660594409632106, 0.033863085742679336, 0.022982723913305712, 0.03860760615357468, 0.12949371109566382, 0.09714540334478503, 0.04044701390328907, 0.060525511902186184, 0.05817056911426687, 0.021725219313896472, 0.06849661078904906, 0.05314475653933422, 0.06615998899383892, 0.025954737117694273, 0.1109029558457194, 0.03891441287593015, 0.020336930099273884, 0.028454277086101716, 0.016539514613067432, 0.0769702403716022, 0.04185473110767142, 0.016183787431087227, 0.03578826852683579, 0.03132351959544805, 0.011738028861732494, 0.049227515325671246, 0.019532951466258497, 0.13602415099740028, 0.07483092452129049, 0.11974534951150419, 0.1076520081128805, 0.08972968755950851, 0.07484559510504046, 0.10834582330238436, 0.06904695303209367, 0.011155873860022234, 0.09831751786893415, 0.12225407295890393, 0.07855686974982101, 0.07758049835120479, 2.1948039051025146, 16.255742484523406, 31.394499847965857, 60.84174686862577, 67.06486563528738, 63.231541110623276, 57.19687654126076, 52.41407955846479, 41.92296704938335, 40.31454032467258, 37.49778432230796, 30.994667160895567, 32.35612577007663, 38.27393508726551, 37.1514468808328, 20.477170828850042, 5.499270356470539, 0.9188075519857869, 0.36256584969739764, 0.7184240786779312, 1.6927033831034939, 3.855426099992568, 8.61525466365199, 8.825332887711065, 9.4313165257054, 12.42207573306176, 12.409083862458507, 11.934102485256812, 16.69918114139188, 18.619987387810987, 17.81798231986261, 16.684644837533277, 14.103484038383732, 8.194849635324172, 6.8551989140049105, 10.54247300471029, 14.32562747309285, 18.514983577113, 26.359923962623846, 31.908138144400816, 35.97252753473098, 39.254751205444336, 49.04871732957902, 53.05094303623323, 51.58803624491538, 51.64031751694218, 55.563181907899924, 58.383683773779104, 59.29547009929534, 63.04504025366999, 60.41561665073518, 65.49756888420352, 58.89974217261038, 46.13305484094928, 52.89656639099122, 56.209717950513294, 63.22128803499284, 62.33271821852654, 66.81220223826747, 60.745664488884714, 65.97670601260278, 63.73447918122815, 58.477793201323486, 56.33653994529479, 56.29452351600894, 54.82916916570356, 54.95339062906081, 51.473248081822554, 47.70359931453582, 42.04006548850767, 40.44852456738872, 31.717363865144794, 29.26051082149629, 19.178248528511293, 17.269582017775505, 17.93479246477927, 19.528490689492997, 16.24236818282835, 14.221808218186903, 14.264946445342034, 17.672225083074263, 10.44689759131401, 12.593271501602667, 12.723043118753742, 13.679130654181204, 9.19843069968685, 9.76411492593827, 10.509138741800863, 6.876333134789621, 7.413265897381691, 6.572934369887076, 3.549399837370842, 2.1151432635322696, 0.5204683686456373, 0.1375813013122928, 1.1171682467383723, 5.292111356412211, 17.5641716295673, 33.46234790740475, 44.27385530164165, 38.825553694079005, 35.55124536637337, 20.891951668647028, 38.244858557178134, 64.5416872732101, 70.56078003298852, 56.436579996539706, 59.19080165124709, 65.7388299511325, 55.30361121700656, 28.65297490550626, 4.837563076326925, 0.13852970284079352, 0.05512109101419488, 0.10777226859523405, 0.0018498812489504478, 0.029975961360539642, 0.07430800822593513, 0.047071674958832806, 0.09860621044232, 0.02206857417589955, 0.060381138802415905, 0.05858039167980033, 0.13476733779234273, 0.038183388795944, 0.09202201415093676, 0.07519152210724932, 0.1497499644756317, 0.10765437532456652, 0.049014979552838116, 0.13380024371848953, 0.010501936419806894, 0.03372940723033201, 0.0329001706784531, 0.04577234387397767, 0.04351793097392206, 0.07997229379872162, 0.020885458629157756, 0.041763325326985894, 0.0880680122082272, 0.05283244164480318, 0.11839313537723596, 0.04381688529505365, 0.05884386846915849, 0.008862618386985795, 0.18103455914364708, 0.13846161294608347, 0.15243372369197108, 0.22677103478100993, 0.31481182022440823, 0.46437492053354945, 0.19581863115872108, 0.13771700612719984, 0.11944036224796889, 0.10745747540626796, 0.19328189953680963, 0.13843844644725323, 0.08258759539814726, 0.1448559343454338, 0.17065501771867278, 0.1557789538656512, 0.15793120128012475, 0.25394395895061955, 0.2165370807051659, 0.2596984743591278, 0.22966995745176272, 0.2736355748868758, 0.28756335978546455, 0.21221622223815612, 0.3324717096984387, 0.3014008075960221, 0.214998439074524, 0.20716042498186713, 0.3876023691508078, 0.2676433270737048, 0.43518982046554167, 4.48300777904449, 21.257685230624293, 42.19959220578594, 74.89653664250528, 77.76265175111833, 72.13185402654833, 66.32283949082898, 62.052480559195246, 52.45498595699188, 52.0635098795737, 53.977724582918235, 33.619046595788774, 43.80142150386688, 56.57751860157136, 46.45254758096511, 24.846848095616988, 6.592570245265962, 1.5196658166185504, 0.562819792859016, 1.021835346135401, 1.6728810725673553, 6.29101695552949, 11.4806451143757, 12.840661271925896, 18.80225600734834, 18.32225203514099, 22.56744307856406, 17.081875031994237, 22.02410459518433, 22.805148516931844, 18.18006415520945, 28.421103992769797, 19.12544362006649, 15.941525332389341, 17.763453529727077, 29.90093581138119, 29.170676777439734, 27.274138235276748, 31.804777806805028, 41.03456589483446, 42.864767351458156, 47.363667103552054, 55.84111713594007, 58.295446134382686, 53.74103307724, 54.316903698828916, 55.38154478996031, 58.208196932269686, 58.00862281553207, 62.91319370269776, 61.118246509182846, 67.16133240730532, 63.47912111589986, 56.742764134560865, 56.49661579439717, 61.44004168048982, 66.98020519748812, 66.30689897844869, 71.10716619799214, 68.33553314208984, 71.3671330482729, 68.13590803454, 61.56920533026419, 57.54643032627722, 57.041189824381185, 57.84400093939997, 58.56185743885656, 55.49368143081666, 51.26790808093164, 48.16687045558807, 43.83965284593644, 39.06523012345837, 38.492775886289536, 27.025063806964507, 22.413552807223414, 34.70892421660885, 28.119069722390947, 34.78196659395772, 28.306762979876613, 20.14477741333746, 37.03789034197408, 20.652891051384714, 21.729640499238048, 18.519457040294526, 18.652676420827067, 16.861265244022494, 18.823927102550385, 14.548978997815041, 8.527816207178178, 10.536820869291983, 8.44623581055672, 3.2623134745705515, 2.0102245192373953, 0.5445514763555219, 0.5150573364188594, 1.4305885448571176, 8.034289863801773, 19.675314810968217, 44.02257650129257, 62.86729020457115, 49.09638981665335, 42.66091785123272, 34.98478058845767, 66.91161863265499, 81.12726872967136, 81.80526610343688, 62.530813601709184, 69.96532501712923, 74.80702031043269, 67.90455879703646, 35.14964957391062, 8.906551445684126, 0.5490986065518472, 0.24829979084672468, 0.19518412649631503, 0.10450543985972482, 0.19116351320858926, 0.19782843218455393, 0.3308711988070319, 0.28403083643605637, 0.15479008757298993, 0.29348304375044765, 0.279823450912391, 0.2751327558390556, 0.32874067764609094, 0.232217506235165, 0.23289269016635036, 0.325199359607312, 0.208336032866951, 0.30897089009804113, 0.22016482878356214, 0.14606115918967033, 0.0963210314512253, 0.11437347203853632, 0.12732771240294943, 0.11299297393810366, 0.1452546831100218, 0.12047635826973185, 0.1365566127482922, 0.28243676068321355, 0.3507756033251363, 0.3442063074438803, 0.16160923536987076, 0.14463179234054782, 0.16083657441119995], [0.043299752963526596, 0.019519784330059926, 0.05512150470167399, 0.029535307586493514, 0.051816658852922345, 0.026570782891564795, 0.05927537515338871, 0.029837513950863676, 0.0777251280904297, 0.06044450959551239, 0.06263592325511479, 0.06265525931432363, 0.06759585226855933, 0.06946344439300799, 0.04623905229832857, 0.09059358958996112, 0.032850597128872915, 0.053757998431401874, 0.1006545150472272, 0.09794090138447863, 0.042304451532301404, 0.10459356295365481, 0.17348378205731993, 0.18324260840252524, 0.10230811583178659, 0.06749331139989438, 0.11333929930603313, 0.038828335236757994, 0.049969685984955686, 0.0849312652022608, 0.28659128614010354, 3.005451425429314, 19.77910464809787, 43.22462128054711, 58.80615834266909, 55.46566001830563, 51.62642448179184, 36.42583977791571, 32.221729678492395, 27.59568629726287, 46.47169266977618, 31.687063555563654, 40.519374339811264, 42.6301743138221, 43.53395900418682, 31.4631962391638, 8.189047959543045, 2.4533832169348195, 0.21902865910482025, 0.5665372191898285, 0.021788297078361916, 2.364006619299612, 3.7121164221917433, 6.005046752191359, 10.910409958131853, 5.443188798043036, 7.517437185010603, 6.862615135408218, 5.122444331645966, 7.3416203741104376, 19.13684595015741, 19.62216473394825, 10.439887335223537, 9.340704871762185, 10.325297251824411, 7.982932309950552, 15.203972651112466, 27.743896976594005, 33.11701067032353, 38.25624519778837, 45.11813371412216, 55.452504388747684, 54.36669034342612, 60.0735192914163, 59.49809974239719, 60.850580046253825, 67.65981074302428, 64.5683515456415, 64.43856423900974, 65.17890768666422, 65.7691930186364, 62.44292897562828, 64.7918874217618, 56.11324333375501, 41.39456102924962, 37.51338358848326, 46.915304891524784, 51.79665534727035, 53.1730503420676, 52.60630707586966, 47.36190203697451, 68.30106335301554, 72.37860248934838, 68.0187782164543, 63.815436901584754, 60.956923346365656, 60.5868398758673, 57.71459018030475, 57.170082830613666, 56.3090088290553, 51.324825594502116, 49.45466695293304, 43.625852292583836, 41.35940482539516, 30.731378063078854, 38.69355024829988, 32.060624207219774, 31.32389130130891, 29.56460825858578, 8.966739235385772, 15.011939291031132, 14.108561546571794, 11.430671176602765, 11.358670188534646, 13.299491309350538, 10.243115751974045, 9.392379157004818, 4.623117783377248, 7.665427721315815, 2.046459129741115, 2.29085662191914, 7.878092258207261, 3.1080868599876283, 1.6579858718379852, 0.8285418020621423, 0.16859626367447839, 0.13874094392503464, 1.2997255282055948, 6.842160955552132, 18.833719299685573, 44.14766088608773, 48.46368797363774, 38.79708120899816, 67.13780603101178, 75.22705124270531, 71.65679224075811, 53.214360744722434, 44.69059928770989, 44.08533050167946, 56.056004185830396, 54.20880317687989, 35.07060597019811, 7.143449485301972, 0.3203187973028229, 0.01598078849530148, 0.023089635313578674, 0.014732469290104366, 0.0326346637560956, 0.06246105602551853, 0.027078869639925902, 0.025202814159133745, 0.19015344160218395, 0.231539273274041, 0.195405050931919, 0.13995903904639906, 0.05355043456919732, 0.08001265897145195, 0.10726824402809144, 0.09185438645222495, 0.08738353563052031, 0.055477559386241826, 0.07959190050079938, 0.049633622364771944, 0.023288247438388008, 0.02074507301703336, 0.04892923516191302, 0.04709900131509189, 0.10918706445203674, 0.029170940847947236, 0.0256359736780606, 0.029823799061799244, 0.10290838402485657, 0.07446246687322855, 0.02896292882430698, 0.028802314660541957, 0.08415612211871533, 0.036063006808680874, 0.02689510429908912, 0.031346990614228194, 0.03434149232963401, 0.0770695177057097, 0.04826443938298091, 0.05461942216741943, 0.03736784606571159, 0.018297378048901598, 0.006349058530759067, 0.06502084689395082, 0.00841857371626482, 0.009784173321790032, 0.05435544359047086, 0.03182113009144462, 0.018078573761628042, 0.07609145325278083, 0.06825310974231652, 0.10010251805426613, 0.06047834003824861, 0.06972611295960604, 0.03894017258238408, 0.03749322401539933, 0.04526554606854916, 0.04736042115837336, 0.03355199658882714, 0.03844297768908643, 0.03792795209935115, 0.07164582204554351, 0.07539507166873063, 0.3521165942713138, 3.758668091989333, 23.94938626597005, 47.47688239620578, 69.04321501331945, 64.95619943065029, 60.85263929059429, 45.236981530343336, 41.27414034258935, 36.573650375489265, 55.09363497457197, 33.70562115023213, 24.6408667872029, 38.140778464655725, 46.14932483242404, 29.599995882280414, 9.844237181448168, 2.461950899131837, 0.1815693651235873, 0.5620065752056338, 0.8883760268649749, 3.663429512131599, 9.145130592007792, 12.906460992751583, 13.309516887510977, 11.815988152257859, 14.616282947601812, 11.937299216947249, 14.492553741701188, 17.16105984103295, 21.41377595163161, 18.824729227250625, 12.422893547242689, 9.233348619553352, 12.10519431098815, 9.08016731662135, 16.14788809130269, 25.19394647690558, 32.08491740688201, 38.61724445896764, 45.1284142463438, 52.59145698239727, 55.23429901369157, 59.50579935504545, 59.32795516906246, 63.3460743196549, 66.61319686520484, 66.33555581492763, 67.32613471246535, 67.62388967698621, 68.08170872349893, 65.63414581360357, 69.26195775308918, 62.88636076834894, 49.111232065385394, 46.43273568922474, 55.898619082666215, 58.74467911258821, 60.533950636463786, 61.38625029594668, 56.52936758533601, 72.18038159032022, 74.08433929566415, 67.9189617403092, 64.82272509605654, 62.266347792840776, 65.11457297109789, 61.64973551227201, 61.15495597162555, 57.70076774781751, 53.40508207198113, 52.016237474256954, 46.40714614622055, 41.280706390257805, 33.632629763695505, 26.670983606769195, 25.03506498952066, 20.699127950975974, 15.500885286638814, 16.784882968471898, 19.135788871395974, 13.989746089904541, 16.79851516600578, 17.08762130429668, 16.817981889170987, 19.90739949287907, 13.729920444949983, 13.454705380624342, 12.152556930818866, 7.0681350750307885, 7.517173405616515, 4.267742220432528, 6.746821374662462, 4.602436106051169, 1.2170554481206404, 0.24965477055839955, 0.25131368799315346, 1.5782913998250039, 6.992262707602594, 20.21602922870267, 39.198378901327814, 41.79125385899698, 31.641793520219867, 50.31586647033692, 74.49442309717979, 81.63706702570762, 62.63825124309909, 51.63922317566411, 53.687147555812714, 64.53922794711205, 62.48704387295631, 41.43495751965431, 10.222870438329636, 0.6080033521979087, 0.036858799792225325, 0.07404232893379466, 0.032835750344900355, 0.07683304934612206, 0.05627520630256303, 0.06504923811242466, 0.01466162913974615, 0.06830661332294827, 0.24612454547276422, 0.05279556983300755, 0.128663026637608, 0.03954329828341161, 0.065453203935777, 0.10198615205984923, 0.13997491238819015, 0.07735404276078747, 0.053093378852692344, 0.08831726657527109, 0.050852552521973855, 0.018690618641314008, 0.024059617538906397, 0.051972795232769944, 0.057646270030208176, 0.01476738949291288, 0.011103178502150602, 0.050244470232076226, 0.034999856800441785, 0.09338880693840404, 0.06179249109399896, 0.031475936618423274, 0.04559317889112619, 0.028655363674906474, 0.19986720665568308, 0.17202155003624578, 0.10819249846521886, 0.12116984404142826, 0.1962620581710531, 0.2442379007416387, 0.12945073356311168, 0.12109167242963469, 0.2476521247937795, 0.1824015204704577, 0.24502968325489954, 0.18093319038950628, 0.11725230788391446, 0.2086426672195235, 0.1691387305336614, 0.15483571576976007, 0.18592244524869228, 0.16146539470120785, 0.2012064968866687, 0.1278256618928525, 0.1853982725691411, 0.37124700483775913, 0.23756293069210746, 0.22552681606142755, 0.32160536536285955, 0.18060942631094687, 0.24161570435089452, 0.27698699505098406, 0.15820117066464118, 0.22312441029615943, 0.7634405082752629, 6.441064284693811, 31.54620143675035, 60.779228210449226, 79.86047652459915, 77.82864955163772, 72.44412176070675, 53.37390707385156, 49.186733768832305, 41.23543047135876, 62.92615321374709, 48.491791755922385, 54.69826790594286, 57.07725209574546, 59.36886156758955, 39.378152893435576, 11.372222958072541, 3.2761006057262425, 0.6042292966477333, 0.6434036623085699, 1.7996425157593143, 3.2867473892627226, 11.470022355356525, 18.547909913524506, 17.770043111616566, 16.63249888727742, 19.504324966861358, 17.648088778218916, 14.1970492370667, 17.98585976323774, 29.76177796240776, 36.70958011381088, 24.998996834601126, 20.776700665873868, 22.98252594086432, 15.031873756839385, 20.166944688366307, 31.360300702433435, 36.77722138743247, 43.35051367359777, 50.22153739006289, 58.904374491783884, 58.63344069450133, 62.73505926132203, 61.9212733545611, 64.80379965997511, 67.97380432005852, 66.28487094756096, 65.34173703962757, 65.22114376867971, 67.37923575985816, 65.0195300194525, 72.93957202665268, 66.63936691899454, 59.5103532268155, 52.12007830219885, 59.922464893710234, 64.35879107444518, 65.98286413377332, 66.35794470387121, 63.55643887673656, 76.49363163978823, 74.92160843264672, 72.64151111725839, 64.84436873466738, 60.8425784111023, 64.64228430101949, 60.36831286645705, 63.70823852477535, 64.57501957493444, 59.68493007844495, 55.91495967680409, 48.400490745421386, 46.72005714908723, 37.242881251919655, 44.89493516183669, 51.91839395030853, 46.06333078876619, 38.876222871964984, 19.79026379123811, 31.595256559310425, 23.919815517240956, 20.986941668295092, 20.681073281072802, 25.029773712158207, 20.257414156390777, 20.551593880499563, 17.045336192654027, 23.01659957055123, 11.426209480531755, 12.030567296089666, 15.799218800760086, 8.019138238122387, 5.956900148622452, 1.1869347095489502, 0.4663826224784698, 0.4031165689229966, 1.9980623524996544, 8.28884090146711, 23.339283158702237, 51.16971938840805, 62.14800204000166, 53.49857960977862, 81.3592141674411, 83.9089979663972, 78.15568108712473, 63.19579655124296, 57.58466951308712, 58.243337446643466, 73.55922806647517, 73.95425781126946, 51.08146998190111, 13.72860154797954, 1.1305226914344297, 0.15348453585418964, 0.14530040323734283, 0.08556072900612509, 0.18396677599558908, 0.17066152946602914, 0.2626616105196938, 0.17116576853779056, 0.36183451152136253, 0.5704554218438365, 0.32226346553333346, 0.18222872167825702, 0.1740237208263528, 0.2427434470624693, 0.3000957921387688, 0.3118820548538239, 0.23480504480821474, 0.21765158541740912, 0.2026271303334544, 0.14407915183373038, 0.1541374572702954, 0.09699423121468675, 0.1498957356858638, 0.13480087712166772, 0.20691976612133367, 0.11698682777463429, 0.162931349909594, 0.12962891029254084, 0.24267615389920053, 0.2903193151277881, 0.12024208092160764, 0.13212217408562862, 0.2271558560671345], [0.016536434939611825, 0.031625107343819354, 0.059623110123098864, 0.16779930240684943, 0.09919152459910802, 0.07536300322822026, 0.0325620194686757, 0.02999436662292048, 0.052277590974324176, 0.019087488575267698, 0.08520576982728897, 0.021256925087542306, 0.013879150764325695, 0.03858391105407669, 0.03287354912308436, 0.10110390988448936, 0.08584739910739084, 0.04748799778040379, 0.06616967234520182, 0.07639608045499172, 0.11726971340155411, 0.19612661382604032, 0.1430778595949373, 0.08227168372081173, 0.05543850805430163, 0.10632996252107044, 0.1263827352874702, 0.062090736783800594, 0.0015653326127287603, 0.12170427463828556, 1.2293029264096291, 6.454075276851655, 24.197552665587395, 54.52034135018626, 58.43742808988018, 57.676958960871545, 48.35408126154254, 40.993777167412546, 32.30279722521382, 26.493578726245513, 29.37259254917022, 26.035188974872714, 41.28342067041705, 49.37066939569289, 29.01921445323575, 18.137447603287235, 4.300973030828661, 0.7565610387152242, 0.2534581979195918, 0.3174140063985702, 1.092177723203936, 5.395801663398744, 5.06999243651667, 8.817228290342516, 10.773787921474828, 6.436246143233392, 9.009945123426377, 10.494837780152599, 15.635089182084608, 19.357449854573897, 20.31239009672596, 21.653552401450373, 14.12219080232805, 13.75771043762084, 12.611758612817335, 17.01912103160735, 29.03699847959703, 35.445588481041696, 44.05028412418981, 54.000435106215946, 59.938440707422075, 67.59566430122622, 67.38933194068171, 70.30318229429184, 70.08490239420246, 68.7347049097861, 66.60417541380852, 66.79068411550215, 62.9068551524993, 64.30844353091332, 63.95175103218325, 68.49048245337703, 65.9101826144803, 58.67575522392028, 45.71817005834272, 33.36778348492038, 40.6396028303331, 50.88604965517598, 46.07569409954933, 45.69168229256907, 43.056708535840436, 66.7078358127225, 67.71007983915268, 64.12693977355957, 64.51479942567887, 63.60110682825889, 65.47042216024091, 63.89977178265972, 60.29078722000123, 62.30468503890499, 64.81539810857466, 68.2959250480898, 57.12867436870452, 56.171266955714074, 47.221971481077134, 37.42909969822053, 29.849289963322303, 43.17937674060945, 23.392443041647635, 23.212072849273685, 21.365783791388235, 18.292194912510535, 9.805206656455994, 13.559243409864365, 15.283659523533238, 17.54447544774702, 8.163645219418312, 10.336950613606362, 9.601933744645889, 6.883395362284876, 9.13894207246842, 4.950021351537397, 4.897335094790305, 5.87180579862287, 1.9158633245575813, 0.08131705389748659, 0.25106788102176886, 0.2347691918933584, 3.199815408837411, 9.68216484592807, 19.356541825879006, 35.00624379804058, 64.97506210880896, 56.15973910977764, 55.860752521022675, 27.332124594719183, 25.955700182145645, 26.183150583697905, 49.22794611223283, 56.06169554495043, 61.60297693744783, 46.44142766152659, 14.354161735503906, 2.6211993732760033, 0.026537184190425663, 0.03504410986938784, 0.0609573939694993, 0.07348169046904772, 0.10777331813569031, 0.06855073490089948, 0.13790636774032347, 0.12142583232132659, 0.04378839448514966, 0.20351533267286517, 0.07556196392303513, 0.08815339270738826, 0.05691754804443448, 0.05875427065597427, 0.09441558692243793, 0.06242822915796311, 0.0741943744041266, 0.04289198351363021, 0.05360999024443088, 0.03840789852303363, 0.04138488172283096, 0.015135485164430595, 0.06535824733756243, 0.08181975313252018, 0.08570682197328537, 0.06025801315122555, 0.03929880515281712, 0.10020577904557991, 0.06346435541467321, 0.05382770477163215, 0.08914230496532495, 0.027426257954850316, 0.034516294441756704, 0.03110555608967139, 0.046537822758358334, 0.055934469546041185, 0.2497263844575613, 0.11780307913619666, 0.060737001965002674, 0.015410555736912836, 0.04266553175365252, 0.03659600482111977, 0.017849281730671084, 0.025781606992466316, 0.05227914613281047, 0.05932853016401491, 0.040203041712483095, 0.03984632436186075, 0.12057880720784589, 0.05077230098146585, 0.04548126493670768, 0.10659510555166392, 0.16196555818521208, 0.01313776821799336, 0.07443579169170511, 0.04513253405269596, 0.07706539615267709, 0.017800367016705777, 0.12832517420212108, 0.013809918440998563, 0.0389732139545583, 0.1657626270166328, 1.5644912758181173, 6.8913920944736855, 27.714622366812925, 61.1392076553837, 69.35490223669237, 68.06106136691186, 57.50101712442214, 46.261010400710575, 38.127191374378825, 29.917794158381803, 33.71579577845912, 34.71184638238723, 48.29344141867853, 46.451629746344786, 32.62519840271243, 18.76781563605032, 5.2687634479615, 0.41495756095936226, 0.26394747377884004, 1.4163057241709003, 5.103938098876707, 8.493653343569848, 9.165573004753359, 11.990048231617099, 12.45683087456611, 12.260625093213974, 13.973813422264593, 10.185521629548843, 17.40231110203651, 22.674259024281657, 25.596768010047178, 18.956573817037768, 9.909832939024895, 12.675526545893762, 15.214376737994534, 20.99439613280758, 25.21305234201493, 36.726042301424094, 42.17930570725472, 54.59611761954523, 58.370900769387525, 67.25039374443793, 67.95064664656117, 72.93177435475012, 71.39283241764193, 68.29394817352295, 68.14236425584363, 67.65461752491613, 65.9970631137971, 67.67906958057036, 64.81291132588541, 70.06069352549892, 69.09345273048648, 64.18362194491972, 53.096442530232096, 42.14430247583697, 48.73628093350319, 57.613561691776404, 53.96497295748804, 53.90143448306669, 50.92139021042855, 68.99344013583276, 70.5519703895815, 64.50930810743763, 65.54016974664503, 66.09239239846507, 66.01262707864085, 65.25945355815273, 64.38532198629072, 62.693348776909616, 67.68223101092924, 68.47257291117023, 58.102944051065755, 53.38236762631325, 47.03283871373823, 40.36967708218483, 32.04825697406646, 30.66409568632803, 24.64456165990522, 17.076440588120494, 18.079353378665065, 11.947544447837338, 15.921364349703635, 16.908112072175552, 18.675490886934345, 20.232811089484922, 11.70200211386527, 11.899723891289005, 15.031054962065914, 13.118792618474654, 6.9692344723209265, 8.961779398302879, 8.254469171647104, 7.370826832709774, 4.64899169821893, 0.9527872286496625, 0.5413534576373716, 0.28077545305413587, 2.8792638740231915, 9.90013683995893, 21.36710366895122, 34.331705954767045, 48.76658908782467, 56.45636835405904, 61.395048172243186, 39.32006651355375, 33.49993205839588, 34.121564972785215, 52.24975970483596, 64.08116179127848, 66.8112922483875, 54.39253876286169, 16.613006668706095, 2.6809356001115616, 0.05311795878374288, 0.05381028776267364, 0.04437737054221573, 0.021535970698741656, 0.03735925822008041, 0.021714358102349986, 0.13650543807495025, 0.129271530275864, 0.06532834692587776, 0.09748244372707221, 0.08342110672064366, 0.08196972250457733, 0.06644233835921173, 0.0931827829129273, 0.010478417520531485, 0.05008805423013626, 0.06286079304352885, 0.08960308386914193, 0.07320079667073104, 0.0182380847587821, 0.05048204941915409, 0.06701636037999584, 0.08324356584419167, 0.018384692920071465, 0.06596556353953577, 0.032382655302963914, 0.06379280029044998, 0.07282800296501768, 0.08208537879850596, 0.04112679053158049, 0.049673635137057116, 0.11749593150471488, 0.10351918592688539, 0.12463315900775696, 0.13822207257391947, 0.27231729078677397, 0.3550576058126265, 0.26149663593499894, 0.20745064973110156, 0.19476798753584587, 0.1693141033812877, 0.19291252258323854, 0.2655638580120379, 0.2692979544160828, 0.16990595226806982, 0.16731683555389606, 0.1264631438760027, 0.2595115182620864, 0.22549739828513515, 0.1733228269844286, 0.15441626730945804, 0.29311345229225777, 0.21915129445973905, 0.3510951845636291, 0.2552988160882266, 0.15406120087831252, 0.13965136281424953, 0.24684944851023538, 0.22661567214996586, 0.17427427754286798, 0.4125332910447352, 0.42177206626342195, 2.5533676195529202, 11.635119818872022, 37.95339899678385, 73.88896603738108, 79.25196001606604, 78.31998132890271, 65.80363142874934, 58.62921630182574, 46.527955147527884, 40.00825420502694, 44.907714243858095, 37.89070775431972, 56.671059285440755, 64.72488549447829, 40.77879598063808, 23.027188008831395, 5.87581544153152, 1.0193336094098708, 0.352495378784595, 1.4021498902190117, 4.574993243140559, 13.51448916619824, 13.518111475052374, 24.30787128786887, 22.984891130078225, 19.29434087968642, 24.522332760595507, 25.258392980021817, 27.13670034562388, 28.300808821955037, 34.93652366822766, 33.298781148848995, 26.86319543469337, 25.5565970559274, 21.18348967644476, 23.846237736363566, 31.107882453549294, 42.1121076614626, 50.623733305162006, 59.16733018813595, 63.23485159104871, 71.17830230343726, 72.09787061137538, 73.77068304246473, 72.91207621174475, 70.38702687909527, 68.7067227209768, 67.69899522104572, 63.241727505960775, 65.78412940425258, 64.10734753454885, 69.99092240487376, 70.85167869444817, 68.55701369623985, 60.30349569935953, 47.4835818044601, 51.37575364881947, 62.441081539277114, 57.163026486673665, 57.7336960454141, 57.61742130402596, 72.8184570804719, 71.1203218275501, 64.70710539048719, 65.30414896626627, 66.03851472177814, 65.36513005533527, 66.37284971052601, 65.7728212110458, 67.13269126030707, 70.4091961153092, 74.26028113211356, 59.38880681991578, 60.61289618092199, 52.43601345246839, 44.947396862891416, 37.24533665564753, 46.102754531368134, 29.40309289963015, 32.61981887202109, 35.50347089767456, 27.773389277919648, 18.00571676223509, 24.164047779575473, 27.98436180237801, 30.124155936702607, 20.324300373754195, 20.691948052375547, 20.067604780197144, 15.886102241854514, 18.249366552599017, 15.427432041014395, 15.342662757442845, 7.459574380228597, 5.551382476283658, 0.975664146244526, 0.568522367506258, 0.527329697243629, 4.063094517877025, 12.85146544056554, 24.407626967276297, 43.543415838672274, 75.84752313552364, 65.39415167224023, 60.84062507075649, 36.77559752618113, 37.92782514326034, 40.35681955275997, 63.6235898540866, 72.49710513699439, 78.76107538900068, 63.89516692007742, 23.97681147821488, 5.27787805564942, 0.26489334721719066, 0.10458614722254778, 0.165787969205168, 0.23098859395230972, 0.30943921496791227, 0.10564519482995234, 0.3191654059675432, 0.34922360112109496, 0.23518957498092807, 0.3283021995617498, 0.21997839362630922, 0.22750695416283226, 0.15154587375300546, 0.203795000730503, 0.2308934305103556, 0.11614640633906088, 0.20892962843420046, 0.14767097038847787, 0.21513115614652636, 0.09579305897556967, 0.14589603659847092, 0.13506683220546092, 0.1585269572153207, 0.11282589016181808, 0.27623809813972444, 0.12186637884306332, 0.2961813892808653, 0.19173340601546152, 0.30381147178911394, 0.15674618583533073, 0.26358284657039954, 0.17427176477447634], [0.059155034231803114, 0.0456695846702543, 0.04271510147279309, 0.06347588886837326, 0.0966416622301744, 0.08448802971190984, 0.08547412276628517, 0.060697425862834345, 0.013205315147887075, 0.05518820797724109, 0.04849803108241289, 0.04665645913431241, 0.03424252143069621, 0.0273930020780573, 0.1114556423178123, 0.044304511750177036, 0.10330764606835381, 0.03853123867884278, 0.01647745574554128, 0.02576618181211093, 0.07833715573313736, 0.05684747015156093, 0.10035392512837726, 0.11239857397853367, 0.057997188095243714, 0.0669590799858974, 0.012274141979193496, 0.0894966282911839, 0.01742795443973474, 0.33805177156482974, 2.2076016183822387, 9.170471064506039, 40.839353453728464, 59.84832033034294, 53.400222255337624, 54.762112325237645, 49.88720632368519, 40.73537926520071, 33.991648227937766, 27.549308192345407, 32.76238329948918, 30.890171297134895, 40.43063463703279, 36.937022670622795, 23.411219427662513, 8.35556532106092, 1.1275146012344668, 0.26809688176839586, 0.2549793727455601, 1.6135210255461356, 3.9412355471041898, 5.855798115653377, 11.771899730928483, 10.218888252012192, 9.279591402699872, 13.354358403913437, 14.52575856639493, 9.763549124040912, 19.515939104941584, 25.776579264671575, 24.831597920387026, 17.241435089418967, 9.292195939248609, 13.700730166127606, 31.941590078415413, 36.027503475066155, 36.31897480257096, 49.137347205992675, 52.548569786933164, 64.05862385226835, 68.62811057798325, 71.94900881859564, 67.68313315606886, 69.08301138108777, 68.8198438767464, 70.72504105106478, 68.57339351407944, 68.8591617153537, 64.95221822492539, 66.91194026700913, 63.07778812223866, 67.59882573158511, 69.24348338957756, 64.2750523936364, 55.40852677437567, 34.67966725749355, 37.28198336016747, 44.232811620158536, 42.18531477835871, 57.96526493564729, 44.84906304267145, 69.97373457877868, 66.3847815605902, 66.56779935283046, 67.34395796252836, 66.97977373676916, 62.21582766502135, 63.48079204559327, 66.89441511707922, 64.91884277712914, 66.8354069802069, 68.72144729860368, 70.06941687676215, 65.7220696633862, 58.72455343123406, 50.096841319914795, 44.9728883466413, 41.60501972321541, 41.62301163519583, 39.669537928796586, 28.09102869802906, 14.507117502150999, 30.103943963204664, 19.622266715572728, 17.3473390840715, 30.57971569799608, 10.757750330432769, 12.666187382513478, 10.059440962729916, 9.637634177361766, 4.168043415392599, 2.7099246123144707, 7.925442620631188, 7.366604401219276, 1.8614066079739604, 0.32127116716677145, 0.12429290105618777, 0.08074035056896749, 0.4324273993411372, 4.100185430818989, 9.275642556528892, 26.268097354519753, 34.43525652731619, 32.15631434994359, 29.375059720008608, 30.374416881991973, 26.220001251466815, 34.911514636008974, 49.55986492095455, 53.082486737158995, 55.40277657970306, 49.72272565287929, 31.608786775219826, 6.821437603042972, 0.37684321583759406, 0.09809266340227858, 0.04975654500266237, 0.0724624717728265, 0.03815798148993523, 0.06539041536950296, 0.04817420954725916, 0.1545338618058351, 0.012044326135618313, 0.09181657235228247, 0.07816082527560574, 0.11849135551000796, 0.056914273018558184, 0.08115942364618664, 0.08103085110985464, 0.026557751735972784, 0.04180658248163039, 0.058855302331428376, 0.03213237054766186, 0.0855969036779096, 0.07488376160542812, 0.03575219727692104, 0.03167849218082284, 0.036059731782804576, 0.0993116854900314, 0.03769326106374783, 0.07700708153988085, 0.028224205560681802, 0.03175878585616668, 0.05742802307189954, 0.03242521531759732, 0.025624899877115123, 0.03575710407007606, 0.009390453924424946, 0.08240667607394919, 0.05961385195053393, 0.00962776689594912, 0.02923241940387074, 0.1065214385368651, 0.025821857252008012, 0.01088267828773467, 0.050629674562162934, 0.018957906718095465, 0.01613362399380534, 0.014026245391446979, 0.06265415231727305, 0.015521411532385936, 0.09357175639560146, 0.09016664878975961, 0.05348601040520495, 0.08752493247870477, 0.01843900855390295, 0.10471753130156188, 0.12279193562966202, 0.20558910204037545, 0.046880578156560666, 0.05660219944172329, 0.08827848720454401, 0.06163913944375612, 0.017935347878524376, 0.05017371052095006, 0.2900129718886268, 2.51350702297303, 11.977777096533007, 43.881065230215754, 68.32366404994842, 61.88392454578031, 64.21641688193044, 55.75208325539866, 47.9076135543085, 36.09097919156475, 32.271247640732796, 36.94172167008923, 32.32886921974921, 39.400071097958474, 41.832842749934045, 23.425865557885942, 8.105744661823396, 1.4017080107042867, 0.4415851531009521, 1.575484698818576, 3.551615486221929, 5.996007159832986, 8.533679169993247, 10.449856039016478, 12.50634785621397, 11.708283789696234, 12.947026145073677, 10.899593041789148, 15.423133123305538, 15.478620932948207, 19.460017873394875, 18.507638938965336, 10.186640485640496, 6.3423862764912275, 9.47680131081612, 17.734373077269524, 30.606646691599202, 37.812581985227524, 46.6509763656124, 53.55878014718333, 61.647017309742594, 69.51659802467593, 72.43431583527597, 69.42984304120465, 71.51062119391658, 71.14223218733265, 73.50598581375615, 70.24270719097507, 70.53851665989046, 69.03307960879418, 69.44747017275903, 67.32118468130788, 67.21379803073022, 70.83813867261334, 69.41592647183326, 61.844712611167665, 42.36173514396914, 45.851911114108184, 52.20354633946573, 50.31223043318718, 62.34836455314391, 53.300346943639944, 70.40577580851894, 67.12946707202543, 64.68897227318057, 66.60850571047875, 65.95534478464435, 64.30805913863644, 68.29034743770477, 69.69614059694352, 69.95866483257663, 68.15864993679908, 71.62145953024589, 70.21608998698574, 65.88174543073102, 58.44969334140901, 49.89991088067332, 42.85625188581405, 36.54611141450944, 32.309018104307114, 26.415082293172038, 19.256778301731234, 16.27583384513855, 16.893493398543328, 16.102574909887007, 16.49881862824963, 14.798402517072617, 17.589431693477017, 16.568103374973422, 9.603038872441939, 10.653447643403085, 11.4230578560983, 10.737835476475379, 9.08375334355139, 10.224839468156139, 7.499948317004789, 2.0496498553022264, 0.8502786582516086, 0.29932725273313066, 0.9780532374016702, 3.975325111419924, 9.576787429471171, 25.055777065215576, 40.20366668701172, 47.10775206165929, 45.58948493772938, 31.81798246599013, 29.85402818649046, 39.08471645847444, 56.08947377051077, 59.27550915748843, 63.088315763781154, 57.24027364484726, 36.76192022139026, 8.820696646167386, 0.7644925614999187, 0.11245841310629923, 0.02667519492998479, 0.012676770021508058, 0.03698014045855211, 0.07195237212844434, 0.061647604715319416, 0.08775363270674022, 0.02111496516473351, 0.06917366397476966, 0.02197373823653306, 0.0705147315297396, 0.011324251367289935, 0.08092521524597561, 0.03844095138652671, 0.08217291966561349, 0.014017940998347777, 0.05455025974961539, 0.07249045696470045, 0.03289919774678927, 0.0321289231520026, 0.032822366788863175, 0.03372567255170115, 0.0030555328281010475, 0.01803435325141876, 0.06737716480969422, 0.11456489442817627, 0.018493331848613678, 0.026117201383796432, 0.030294395382365877, 0.034854108572847424, 0.017836168220627214, 0.18664529517052636, 0.10302177269852932, 0.15276701790430855, 0.15424838680173122, 0.1655086075826999, 0.12847729628124546, 0.22328219376504424, 0.1265894104876826, 0.19140214959700264, 0.1504459859983575, 0.14266907507854124, 0.09322596728921899, 0.14597695080503342, 0.20575479153663884, 0.12395073554568714, 0.1988239787639149, 0.25443204888893717, 0.25701397969838113, 0.1148695982391796, 0.16459434293210506, 0.2548851745743906, 0.20864133422653522, 0.2568902871421268, 0.288470009522092, 0.20778811146174708, 0.21744533922643433, 0.10036956864379107, 0.28977502497934526, 0.16553085477602097, 0.8361304238919289, 4.636234189233472, 17.1375903391069, 55.704383311733125, 77.78975532900903, 72.30869016339703, 72.91392757046607, 67.68956584315147, 56.5480576792071, 49.72235302771292, 44.79184350659771, 47.868538902651885, 43.6196235687502, 53.30963119383782, 49.38892410647485, 30.491938937094908, 10.033268947755138, 2.0641531867365686, 0.6533652568055738, 1.5552440429887466, 4.288719546410346, 7.476402819156648, 13.241361783396814, 22.918312818773334, 22.41384502380125, 22.60381325598686, 28.130403411003854, 26.260868426292177, 13.238346461326847, 29.439614088304584, 37.26187336829401, 34.482654448478456, 28.563915529558738, 17.414819540516024, 21.845077814594394, 37.41022133058117, 38.996423905895604, 41.77772560427266, 50.11629627596948, 56.11734613295525, 66.7779521019228, 73.6001854558145, 75.97034823509955, 72.8861415001654, 73.78157938680341, 72.60835924456197, 74.17409881468743, 71.01194673968901, 71.89568811847319, 67.51587544718097, 69.09408030971404, 65.91463058225571, 68.498562535932, 74.06094627995645, 73.46818985477572, 66.68318763855966, 49.58244208366641, 48.59898228799143, 56.49298367961761, 53.41703745626634, 65.43930207529377, 58.71005635107718, 73.84382740143808, 67.51924868552916, 66.62734093204622, 67.6909778964135, 64.8276908166947, 63.202252772546586, 66.16390505144673, 72.64042854309082, 71.2333566911759, 71.59485801573723, 73.75562898574337, 74.62364166013657, 68.098645517903, 63.986158063334805, 52.644338377060436, 51.35133297212663, 44.603907062161355, 50.5747821254115, 48.68993812991727, 39.607850813096576, 23.142864588768255, 41.95956668546123, 34.341817825071274, 23.717152533992646, 40.876451230818226, 21.642577609708233, 24.92837848201875, 16.84884702005694, 17.752594447905018, 14.227499577306933, 11.981880876325793, 19.66891154166191, 15.97454482509244, 8.980835253192533, 2.766506027790808, 0.9463818142971686, 0.5332350706861866, 1.0300856227836301, 5.0345548026023375, 11.87641912891019, 33.624192745454856, 44.989028899900376, 43.42818837012015, 41.07893966859387, 45.70575183437717, 36.943757380208666, 46.67306323205271, 62.60208306774017, 70.75760456823534, 73.05801976111628, 66.88091431894611, 44.92578852561213, 12.425372485191593, 1.5275443874059187, 0.260346707317137, 0.13045437003095306, 0.1502108123273619, 0.1490313127156227, 0.2356236097553084, 0.12424941024472638, 0.24453088340740053, 0.12014740011504582, 0.1993159757506463, 0.2325894112788862, 0.2250458200972888, 0.11259766490829569, 0.18819663853895283, 0.20657234524767246, 0.24284054104599262, 0.07954781980163629, 0.1992946785063513, 0.17627119296981444, 0.10662908155110576, 0.14215958064361928, 0.06938900362940566, 0.14874079685297706, 0.09798182580139368, 0.21626882735759984, 0.19899918307219783, 0.20140014859216832, 0.14262016802545519, 0.20974086958073804, 0.12882398171049933, 0.13481811409996403, 0.15030283480882645], [0.03871408471417043, 0.05268468243640758, 0.06425169078753361, 0.10417317986608514, 0.09933564105942365, 0.0019785932372249062, 0.10370216602759977, 0.12250260720329902, 0.04130617767993001, 0.023000684844690467, 0.04722775771252571, 0.11992700428010956, 0.013730746126853892, 0.018554992350419203, 0.0428283216071225, 0.026689298608670795, 0.016605675881428104, 0.032212511005420844, 0.04097951012813757, 0.030979885111352613, 0.09688825827212104, 0.025053068867794452, 0.13751599997762712, 0.11533568613231183, 0.08683218215141567, 0.09346479519961343, 0.03569075702539375, 0.08641065759283882, 0.03139400159970167, 0.3732690785921389, 2.598286112470012, 14.376986988129156, 39.856501625430205, 57.949606833919404, 66.01807917318037, 51.356902737771314, 43.232579769626746, 35.78437535993515, 32.800267511798495, 22.999474502378895, 20.106144028325236, 40.28302408033802, 42.61546542567592, 32.609777604379964, 13.16853121403725, 2.8170011505003902, 0.9702786094238682, 0.17072686144421179, 1.4133763265225197, 2.729739445832468, 9.885731935501099, 7.650895339827384, 5.930047112126505, 11.122115965812437, 9.340975515304073, 6.41480891935287, 5.752834918037538, 15.385051811895064, 11.606262941514293, 20.734007627733295, 25.079099478260165, 12.4964399491587, 14.880111371317218, 19.78231510808391, 29.268532068498676, 45.254898917290475, 48.402440163397024, 60.59133491208477, 60.6909199683897, 71.15192828639861, 67.51068222907283, 66.26306256940289, 61.67327757804625, 69.01148303862541, 65.31376269555861, 67.26650684110581, 65.97501939342868, 65.17608358014014, 64.61267432858868, 63.67421196353052, 64.17496135157924, 67.51261987993794, 68.68256092071533, 66.4693949299474, 61.461908894200484, 39.98073485589797, 36.49610511718258, 39.17716672343593, 48.32908791880454, 65.15386335311398, 46.317904380060014, 71.74298240292457, 65.1096974649737, 61.90934934923726, 59.82145209466258, 60.773054399798, 63.14623348174557, 64.15420809099751, 65.60602634183823, 65.95801984110187, 64.57573736867597, 67.89273677333709, 67.86797092806908, 68.17902272747409, 69.67505393489715, 62.27812667046825, 53.954135448701926, 51.62691870043355, 47.33700283112065, 38.231447973558986, 31.046595419606856, 27.41044059876473, 25.797905191298454, 21.90937722882917, 24.49860438223808, 11.765568044877822, 11.102141295709918, 9.955776641445777, 14.077868999973422, 13.92841983226038, 6.228328164546721, 11.089891733661776, 5.046477827333636, 10.055632341292597, 6.849141793866312, 1.68162391310738, 1.9471091704983867, 0.17677344021297273, 0.40455463853093887, 0.8586967387987722, 4.938414567901242, 8.581806652007565, 20.33597726975718, 23.03780194251768, 28.356843802236742, 25.391553525001775, 28.786190363668627, 26.805854305144283, 30.61337943999998, 44.20189157609017, 52.35526361773091, 50.58699638612809, 33.61753256090226, 13.592845374538054, 1.1744701525857373, 0.07609713762517899, 0.043604269082988464, 0.060896133748634215, 0.03868777725485064, 0.11306120172864008, 0.12819785038910567, 0.08012410178179703, 0.059883955400437124, 0.015488956217473794, 0.12920607572361348, 0.08412164050124346, 0.01684411117176135, 0.0690888580415518, 0.07499816151516092, 0.03388977241552165, 0.03307903688701411, 0.08687239410656114, 0.08518841027492478, 0.04866053748335089, 0.06121140574255298, 0.07499819981955713, 0.06542467482147679, 0.04670469969090435, 0.06923337286758809, 0.015772770726001792, 0.028663292684922778, 0.019244622784636675, 0.03831128717490262, 0.05420045251207006, 0.01412130541153132, 0.07096021931858794, 0.021380267158571272, 0.0393334323269946, 0.014337179412494504, 0.01133629905750915, 0.03287950162625602, 0.012752451847547726, 0.05717683433284683, 0.035686857637859164, 0.02428081776616314, 0.028229729054615866, 0.01684567016068726, 0.11994296189157233, 0.030504575434831843, 0.01456362734203257, 0.060776746606514345, 0.054532927010328545, 0.015784977379465298, 0.049653096319807154, 0.1092227794710667, 0.040550995017251665, 0.07046364112606934, 0.04601847260229049, 0.09641758151232235, 0.06768579099086985, 0.042611905598952886, 0.053386338535816445, 0.07480513800175921, 0.07007246897105249, 0.01002661812479698, 0.5856889882876027, 3.513337075710297, 16.967043722829512, 48.414258264726215, 67.85102628892469, 72.984467475645, 59.28046311101606, 50.57652365776801, 40.74313771340155, 35.96359237547844, 27.145082450682118, 28.43127077625644, 40.590686951914144, 45.05040222598661, 35.04611861321234, 12.453093836384436, 3.9124983020367163, 0.570674093980943, 0.5042128102673639, 2.1710363030433655, 7.750216616738228, 10.326100357117193, 9.892042048515814, 14.289321034185349, 13.050999353008887, 14.5693802256738, 15.912778281396436, 12.929875581495224, 10.826140776757272, 16.74655552833311, 14.192549297886512, 12.610841758789556, 8.135533102097051, 10.699048138433888, 20.883300881231985, 30.303441593723914, 41.51963364693427, 47.56131925890523, 57.45681593495031, 63.842928794122514, 72.4843966576361, 69.78883404885569, 67.89214841781124, 66.56661479703843, 69.23035129424065, 68.054212908591, 68.51986885070801, 70.38708963701802, 67.8521873104957, 68.38033445419805, 65.18886266216155, 66.05411006558326, 66.49551791529503, 70.2962318543465, 69.04803168389105, 66.88970827287244, 47.59385531948459, 44.583883362431685, 47.55356081070439, 54.76614844414496, 67.76762100958055, 54.73274161738735, 71.72504932649674, 66.80887606836134, 63.26749355562272, 62.28423772319671, 62.60882169969621, 62.146025165434814, 63.39005977876725, 66.67185198876166, 67.50988991029801, 65.96358960674655, 68.21487319084906, 69.71124172210693, 69.31794566492881, 68.43136449013987, 62.18287975557389, 57.548324831070445, 52.41989251106016, 45.589210371817316, 33.91853132555562, 26.969736814498905, 20.46750414756037, 18.65705574712446, 12.405287988724249, 18.91335322010902, 20.761795659219068, 15.399283151472769, 11.97171409283915, 14.170764453949468, 13.872408386199707, 12.986909785578328, 12.603265700801728, 9.99615155881451, 8.145757250247463, 6.485209090094413, 6.333481025311255, 2.7863061524206594, 0.283888527943242, 0.5553395265052395, 1.1850492752367452, 5.453741934991652, 11.639386377026959, 25.290605445061964, 28.488229474713727, 28.4426534944965, 29.242564016772857, 30.91566081969969, 31.251476503187614, 36.87559443135416, 51.76604909281577, 60.323527243829545, 58.03428296119937, 40.919683594857496, 16.201893245020223, 1.6479387206415979, 0.03628457475814127, 0.03573556933852454, 0.014511611887193738, 0.0766803220575375, 0.04796684869835454, 0.15534259018398103, 0.040373975080588174, 0.03715846274468688, 0.02603719882186382, 0.0005776686591543107, 0.05678321835735152, 0.02426641914362629, 0.032034922248473575, 0.01883388282881389, 0.0330534955156186, 0.04815850857525103, 0.10187807237549175, 0.040816513430928035, 0.05041274144464443, 0.06540359974267983, 0.029969447697963447, 0.0730841521233801, 0.035874189117983464, 0.05368443100803322, 0.03862111228367975, 0.09769231351392885, 0.1054729629428156, 0.023512711200202187, 0.055087842798281106, 0.039342701990878394, 0.01838677859444532, 0.15864750881108547, 0.18682160264542028, 0.17518293442985705, 0.26663297967564675, 0.19113400350174597, 0.16725220837660376, 0.13093934965229806, 0.19381079131797438, 0.25647276922339396, 0.151298304779395, 0.15512459220424776, 0.29501344227502424, 0.09792007145381744, 0.1315442526773099, 0.14964018407608234, 0.11693924605365723, 0.1721939351409674, 0.12165282417329089, 0.2780701208018488, 0.13316002404016833, 0.24426037776133708, 0.16603071182485551, 0.2987202353054478, 0.25746624736535934, 0.1755674799243289, 0.2790395284612333, 0.14017783375757356, 0.16740896528767002, 0.1297641707764518, 0.9413841018272985, 5.923966457766872, 24.776370948360814, 55.943632202763716, 76.88830837126702, 85.03973883967247, 67.94686548171505, 60.01701754908408, 50.20640096356792, 45.860218694133145, 35.00083877194312, 32.02921778925004, 56.59500060542938, 57.13973937496063, 41.507333094073886, 16.54472408756133, 4.155969379409667, 1.4582185783693868, 0.6772179865548689, 3.7684808815679247, 5.131996283608099, 16.05879145283853, 19.829781670724195, 19.15138617638619, 24.173383020585586, 19.796765119798724, 18.93461246644297, 20.85423415707004, 29.164249973912394, 20.038789087726226, 31.755546177587203, 38.177181982224994, 20.925566381023778, 21.333822358039118, 24.80363534342858, 33.99159331475535, 47.75915576565651, 49.838086482017275, 61.69305809082524, 67.9484893429664, 78.6005170883671, 73.473249712298, 72.38579611624442, 68.90501422266807, 74.72453286570888, 69.12868345937422, 71.17175978998985, 70.40450496058311, 68.04694867903187, 67.9801977834394, 63.88928728718912, 63.36296404561689, 67.18023823153588, 70.8554441698136, 72.269560598558, 70.03915186851256, 55.05412886219641, 47.48158924041256, 52.80359052842664, 58.497777677351436, 69.69090815513366, 58.20430594105875, 75.22645504243913, 64.41770507443336, 63.52460884278821, 65.22061817107662, 63.13800434912405, 62.87935933759136, 63.449471919767326, 68.24145901587703, 70.65865101352816, 68.80724522375291, 71.94167398637342, 72.90029341174711, 71.86459156774706, 74.38644024633592, 66.35579524501678, 61.246861027133086, 55.39849335147489, 50.17181350338844, 40.646561115018784, 33.59898759472755, 33.06210141028128, 33.79362344741821, 31.14120887171838, 32.10310543737104, 21.155103483507713, 23.29235592196065, 21.067487539783603, 24.560020854396207, 25.236111956257975, 14.33157084449645, 18.664057177882043, 15.398189790787237, 19.904951933891546, 12.565953173945028, 6.196408406380685, 3.47458896137053, 0.6330582271179845, 1.039817513477418, 1.7372232651518238, 6.558134286634385, 11.634267683952086, 27.27373226996391, 32.669766333795366, 41.20771108135101, 37.47938448382963, 40.063398807279526, 38.783929501810384, 46.8272594482668, 60.607012625663515, 69.09684165831536, 67.35145753429782, 47.42943740660145, 21.823714625450876, 2.31779178304057, 0.2020570843089973, 0.14778511748919565, 0.15363861145752092, 0.24780837608681572, 0.16464294355002143, 0.31824567144916904, 0.1709537460438667, 0.21936878682144229, 0.11924778306556326, 0.27470285793946636, 0.1567813645928137, 0.1177438835222875, 0.166983112332321, 0.11959711915903515, 0.143236807517467, 0.11717902391307777, 0.28744976426805224, 0.14341965738323428, 0.20080747233042795, 0.17881337913774675, 0.16948521678005496, 0.19473742062766708, 0.21223836217916783, 0.40541909214469696, 0.12674322562111964, 0.20810907165850365, 0.18414354312323755, 0.21097450096520687, 0.16488228473932515, 0.15077022505142998, 0.16699607453999982], [0.036251824499378284, 0.1140381093888033, 0.03453749209462154, 0.026895347532005082, 0.08153741142802662, 0.02508647796217232, 0.03320836018951189, 0.018377388271713452, 0.04923129980001719, 0.0568189908329758, 0.04076623508045751, 0.08359076455235483, 0.039221296207078045, 0.05701538513324434, 0.11756263478028199, 0.03300337804361217, 0.034215700692467155, 0.06451829321562283, 0.04761176311501092, 0.09547413657269171, 0.04911755872589927, 0.06942459607436773, 0.10412578966708914, 0.10566884396417488, 0.06716437622784607, 0.019734143392152844, 0.040134101460177096, 0.04878740547405136, 0.20831252928943406, 0.564002693901139, 8.012964427471161, 28.022828486657914, 47.37474779928885, 64.26321860282653, 54.79940229846586, 46.217083777150805, 40.16135607996295, 38.74549419649186, 21.922636801196685, 24.655132447519613, 27.3717366110894, 37.758543491363525, 26.491668531971595, 19.873398427040346, 5.592857618485728, 1.1616159326607183, 0.08742803767804178, 0.4210715248219429, 3.300505592938393, 11.998108702321208, 5.8253399306728, 8.18193817330945, 11.900883932267467, 9.855660103982496, 11.577702203104574, 14.381225109100344, 8.103846724956266, 17.288146595801077, 14.509014948721855, 10.412320917652501, 10.84295891946362, 10.891983643654855, 12.959029578393507, 25.843920476974983, 35.51475163429014, 45.591171556903475, 57.506324091265284, 59.259329380527625, 61.75969523768272, 58.288644744503884, 64.11869495145737, 61.679200357006444, 64.41249224447435, 58.987093356347856, 63.4049020274993, 66.36789967936855, 69.19104914511405, 69.91583255029494, 65.96318952498898, 63.622691631317146, 66.33335144289079, 64.28259118910759, 67.98476342231997, 66.25467654197448, 65.91455213485226, 48.590847292254054, 41.342601391576956, 32.60516293587224, 51.25086146016275, 40.90806945677727, 44.40519978923183, 71.19257188612416, 61.07457876205445, 61.1487860833445, 57.39861972870366, 65.85441435537031, 58.647345496762185, 65.08522579746862, 59.40104069248323, 65.00341300041445, 60.784044881020826, 64.68315539821502, 64.52533883433189, 64.89596359191403, 65.66628571479552, 69.29798864549207, 62.71890694095243, 59.364550882770175, 52.95698658112557, 47.096832183099565, 36.714345793570246, 38.59605581529679, 29.30983070404299, 23.38168986382023, 20.602594498665106, 16.37237023922705, 21.185974497948926, 13.164424492466836, 5.977575942393273, 7.434458463422715, 16.489173519995905, 16.026091633304475, 7.5056666424197545, 6.4971164253450215, 6.719611892777105, 4.188029362309364, 1.1756216133794477, 0.1562706137736959, 0.31987152452911105, 0.23727278255166548, 1.2334306081456523, 7.138271956674515, 21.578790064780943, 52.66442091234269, 51.527745492996715, 31.875576588415335, 22.636145353317264, 20.490916775118922, 28.155890972383563, 37.354825696637555, 48.66619994563442, 53.54012927701397, 46.791326615118216, 17.752500311020885, 3.1028147041797642, 0.06374633322740275, 0.06304893274641325, 0.08341385952887997, 0.06984454249182055, 0.09006058391664298, 0.07115629186192829, 0.01930789973196243, 0.09522172592339978, 0.10808261081336007, 0.0049881253583026275, 0.05128158474220865, 0.06352370424616723, 0.00941844198912863, 0.05572938014783206, 0.03145963043695496, 0.016314790381359, 0.006974507076290226, 0.04017244033034771, 0.06114035491801559, 0.0672143864475431, 0.05929158940430611, 0.1229167313525273, 0.07197920052755265, 0.055555010875386585, 0.039497934386975346, 0.04275518702343107, 0.03891630511310312, 0.07407363894726, 0.04038803662443834, 0.03781431444710301, 0.02040291325219216, 0.04803306550808972, 0.019367087684992342, 0.07589564117933474, 0.05578051651677778, 0.05859247288636624, 0.013808000348358145, 0.11018482502549888, 0.024049238962752205, 0.06827168737448032, 0.05848324407012232, 0.04060728332748817, 0.06671180978657738, 0.03883543687181608, 0.032025562569258675, 0.036097656965496085, 0.09283700146742406, 0.017739457281066046, 0.016122215029392994, 0.05435554318190102, 0.03341675908755391, 0.047429284801886934, 0.11138374496611858, 0.08271498815907587, 0.12785582277443142, 0.05555107318345578, 0.013706859505374827, 0.03581621158387392, 0.05147349742812015, 0.17869360895166475, 0.7618296398751198, 8.3244118959673, 31.66772823179922, 53.525440000718646, 73.09590201224051, 66.36702106844994, 54.323450134646514, 44.927749710698286, 43.30581434311406, 29.876695563716275, 22.548115599539972, 18.105796037181733, 35.823426477370724, 27.418581478057373, 22.992898648785008, 6.307538959287829, 1.3926698892347276, 0.16032870408267746, 1.338173213504976, 3.4828472666202055, 12.197048375683448, 14.190981330410128, 11.781970416345905, 13.854762623387, 18.540990852540542, 13.804237592604853, 16.424127874835847, 11.586173542084234, 14.829003868564484, 16.204858556870494, 16.54211178902657, 12.476155411812568, 10.614227864050097, 16.726498488456972, 26.831869425312167, 35.87347984313965, 47.83421424127395, 58.276787419472974, 63.047130876971835, 65.51723172587734, 63.81433863793651, 66.56203346867716, 66.42015349480414, 67.1060505220967, 62.892918971277055, 67.45851470578101, 68.61628070954355, 69.6987372059976, 69.92566985468711, 66.4744234085083, 65.45794510072278, 68.85777319631269, 65.02616274741389, 68.32518592957528, 67.91348611154865, 70.53459428971814, 54.38018329681889, 48.071709832837506, 39.4401498763792, 56.58829727480489, 50.787735446806884, 50.88564172867806, 73.69607171704693, 61.472813083279526, 62.92984416407924, 60.61491620156073, 64.51916894605084, 61.475256719896876, 64.54987718212989, 60.62982905295588, 65.75160511078374, 63.5724146904484, 65.86656585816415, 66.10259840565344, 67.06790154980075, 67.20034430103918, 68.4661872925297, 64.42578907935851, 58.61093021208241, 52.90093591136318, 46.64489669184531, 40.02754834390456, 35.76839562385313, 26.45357055048789, 17.990852940467096, 19.881521655667214, 19.0106358451228, 19.126626214673443, 19.068457465017996, 12.161269495564124, 13.805631995201113, 16.622610592073013, 11.484315472264445, 11.158598911377693, 12.920050044213573, 8.372084383041628, 6.5947785396729754, 4.652728736400604, 1.8420481177106982, 0.5427249388829355, 0.4229893799751036, 1.1285694736626841, 7.120351137653475, 20.825847964132986, 44.526997227822584, 47.24863183113837, 34.33150591388826, 28.430323523859826, 24.642649504446215, 36.9953247808641, 44.35155745475523, 55.327847542301306, 61.37549123456402, 53.25111727560721, 22.49535775953724, 4.555918266696315, 0.08062118559234566, 0.023773466462209344, 0.025694297866955883, 0.07551773000628718, 0.04577615516140096, 0.05043014696228409, 0.031782124724779884, 0.037874299131574175, 0.12974604513616333, 0.027790383375700445, 0.07605200738555963, 0.044886719420432084, 0.08592105846131042, 0.058054169715051694, 0.035257503660696174, 0.006792305991233837, 0.027671398429740823, 0.010128167867209884, 0.030638786378286542, 0.07220066888558288, 0.06229970258690658, 0.05327445905535452, 0.07538918811347216, 0.04319231296258588, 0.029515663176895152, 0.019669566010575623, 0.0958721345711139, 0.05611116389533686, 0.04766395668529215, 0.05676813791656206, 0.03445878805172059, 0.1967902451513275, 0.1051476437057699, 0.2303022098156714, 0.24413538285561148, 0.16474860239653819, 0.11226044066490666, 0.18274264410138133, 0.19032525980184156, 0.1343604378522404, 0.19072892685090342, 0.15593460761010647, 0.14714436154932747, 0.26828340885619967, 0.07566228313671966, 0.18581448813840268, 0.2162529080505333, 0.21351680970720707, 0.21535336760984314, 0.17175944071383248, 0.1598419931026236, 0.19152487688247236, 0.25250296288680646, 0.26717867942587026, 0.25793025149933757, 0.26314688125445, 0.1805423323305384, 0.16778952712493558, 0.1266745841431041, 0.2977300206980398, 1.352577872814671, 12.360219955444338, 39.69713180295883, 66.8685588529033, 84.3181090201101, 72.06519726783999, 62.59945900209489, 54.40369790600192, 52.02594926280361, 34.115147975183305, 39.46519028755927, 42.45377356006254, 50.40781467191635, 36.233859369831706, 25.913011066375244, 7.236493008752023, 1.9524703150795353, 0.33699763458101983, 1.8497286088043645, 5.212573534057987, 25.941483551456084, 17.15439573411019, 16.016201376914978, 21.508540414994766, 24.988922226813532, 25.989932667824533, 23.735320952630815, 16.75409040143413, 29.559795510384347, 28.917599570366647, 20.545059211792488, 19.01718424212548, 15.938777712083633, 15.898560670114334, 32.33091473579407, 40.651052228866085, 47.803878630361254, 62.61654876893567, 64.75668807183543, 69.48001800044891, 64.96644466154038, 70.41273409320463, 69.46934130883986, 70.91619383904242, 63.40247408036263, 68.50458729651668, 69.98110863470262, 74.45325389985116, 71.98023872990763, 67.49102330976918, 65.10109178481564, 68.75969040778376, 63.97690911446849, 70.70786891445037, 69.86386114551176, 71.22290749703684, 61.218745477737926, 51.65752887725831, 43.19987896950015, 57.921577576668035, 56.65951182765346, 58.29863894370295, 73.88737355509113, 63.25715026547832, 62.36478359468522, 59.463531894068566, 65.17631499998032, 61.60729938937772, 66.40371876378214, 62.10964518208658, 68.6008422605453, 66.0205816453503, 69.18567549797797, 70.0816938954015, 69.76363674286874, 69.69064143396193, 72.55258314071163, 67.9206483594833, 63.80694104779152, 54.43062497723488, 51.273979909958385, 45.45057812044698, 45.07863936885711, 36.109226057606364, 31.352073530997004, 29.274527411307062, 28.31604919125957, 35.63340333200271, 21.77697958484773, 17.820323974855487, 15.291406204623563, 28.314231172684703, 28.79436654429282, 17.571114224772302, 19.680841430541008, 14.785750912081811, 9.506944725590369, 3.2671085721062076, 1.2579639304068782, 0.5505650214129879, 0.5129760593896913, 1.5249998723306966, 9.385853313630628, 26.54333399188134, 65.81317455537858, 65.20528954844322, 45.62423321508592, 33.275035119825795, 31.626300158039218, 41.449482056402395, 50.4228687286377, 64.60976000755065, 70.73551377942486, 63.94637738504718, 29.241089205588068, 6.343645847612812, 0.3077107980366676, 0.1876119142698665, 0.1700657735308332, 0.25447885686111066, 0.09948201747911592, 0.21524688138836817, 0.12487520448743336, 0.1847214338880393, 0.26931076340617677, 0.12882105525462859, 0.21710631467642325, 0.2837379150573285, 0.08174847631204514, 0.17381831733209474, 0.09967799043102611, 0.12692336353563494, 0.11363023651703713, 0.09274926907833546, 0.22022439978055416, 0.1842379404772674, 0.15329457669248506, 0.22617008476968736, 0.12290371551869378, 0.09723636096403485, 0.1821923171800952, 0.1489066548885838, 0.3331194523601763, 0.2586600881430411, 0.18356669423801286, 0.13041796553279125, 0.13735578034914311], [0.02815020721285574, 0.016019701931415307, 0.01096395351323149, 0.06874433298024439, 0.05537904047917935, 0.05038555298421172, 0.060691335463836316, 0.051010787982733986, 0.04794981090291854, 0.03234747654548095, 0.013253091263674922, 0.019157976325180744, 0.029363228916941635, 0.07061010181543327, 0.03317123556870126, 0.015345353993677325, 0.09472026775080351, 0.03941652605370168, 0.0616361478704118, 0.02658656621802478, 0.05380877473902318, 0.11499869937617933, 0.05606011562650243, 0.08323561385153763, 0.018418624869457657, 0.07804589676520518, 0.05932197245138307, 0.13589555547843057, 0.06174149262087961, 2.344036607011672, 10.506946136874538, 34.29831873986029, 57.14718011117751, 61.18171438094109, 53.92375669171734, 53.975335859483295, 31.737807258482906, 27.29371282362169, 23.533483628303777, 34.480591281767815, 52.61420280702653, 45.18852064686437, 32.12717310074837, 12.415292974441284, 3.1562275800012776, 0.570761550578379, 0.29458755867615827, 1.2264072366299168, 2.6722335767361427, 9.971009166009965, 13.718368084199968, 8.598511045978917, 14.81491373431298, 12.930719871674816, 16.088831905395754, 24.151176521855017, 13.667239008411286, 5.302951806975949, 12.871142991127508, 16.89350320446876, 11.88460119308964, 17.13761583451302, 22.289911854651667, 37.60558282175372, 45.426282959599654, 56.47488978601272, 62.89840244477796, 64.66647355787217, 64.7844349184344, 66.00343304295694, 63.01067636859033, 60.39938196059197, 59.83969111596385, 59.4125920726407, 62.88121854105304, 67.17627663766184, 67.90879495682256, 65.88112569624379, 65.25889265921809, 63.5092096174917, 65.19800178466305, 63.89458248692175, 69.57139353598319, 64.44653057282972, 62.05532427757018, 54.622283750964755, 42.05629233391055, 33.66862927713702, 34.80307286785495, 30.79806031719331, 47.94717457986648, 69.09782225085844, 61.37671501405778, 65.27139717532744, 62.145009271560184, 62.7288579940796, 59.69057044675274, 61.91330309837096, 59.919150490914625, 64.27964156673801, 65.11456904872772, 63.209156144049864, 61.20984954218711, 63.77429516084733, 61.427411648534964, 67.46493954812327, 65.96752766639956, 65.53550212613999, 64.57405467187205, 56.45496022316718, 51.17189238148352, 37.976988131000155, 32.42897595128706, 22.82241479043038, 34.1522418299029, 37.13725966791953, 14.932442653563717, 13.781126987549568, 12.194859693127295, 16.351343393325806, 17.505220367062478, 8.855478263670399, 8.660706108616246, 5.027147896828191, 4.29768902640189, 9.249184208531535, 8.116000188935189, 1.7752826358041458, 0.5379919251126628, 0.3096303998702957, 0.3338001980896919, 3.104447881060262, 11.309127711480665, 24.60520067522603, 28.086206143902196, 31.851987454199026, 30.498554014390518, 29.88757621857428, 26.780588357679306, 40.255120338932166, 46.90642856782483, 51.583278409896366, 50.995005253822576, 27.488609513928814, 4.324162573583664, 0.38270489162495064, 0.06649360496310458, 0.05254831878588565, 0.028658282469897985, 0.07455953021323489, 0.05476898934331633, 0.09522072234821898, 0.053059448818525964, 0.07635390731476008, 0.01157547266507942, 0.1070065254105195, 0.03982235347071002, 0.10728691359080615, 0.04017178532517245, 0.010256217548533553, 0.034158240267706495, 0.023316971905108903, 0.06855754542254633, 0.067916942700263, 0.045709570629462126, 0.0411276523804953, 0.037493308285071004, 0.05943145790708162, 0.07035520138038744, 0.04685276150403004, 0.034063245365095716, 0.014610260071593427, 0.04856287659476361, 0.06228565253437527, 0.013442131119870372, 0.072046700534561, 0.03764157311149663, 0.014091901999387531, 0.02465627554263319, 0.05080502825759111, 0.060746815551312706, 0.032879528439333366, 0.03700157559867348, 0.02800664042062577, 0.0217978865839541, 0.08858491471337696, 0.010293045310273526, 0.038009421719658765, 0.025749477264921994, 0.032272798294622096, 0.05948254448031226, 0.048139191668240294, 0.05897096628623624, 0.017605129509202896, 0.01927937827854147, 0.04246174470491467, 0.07134941496676014, 0.05691673982167437, 0.0972599947764989, 0.12104795945267524, 0.0539934593853691, 0.03092107062618579, 0.08191787367386204, 0.07739803152939967, 0.05781374834177475, 2.250680519688514, 13.60115001278539, 38.695354538579146, 66.94092658258253, 67.9464183315154, 60.52707864392189, 54.68146447212466, 39.177445211718165, 37.06697863917197, 32.46821926486108, 25.073029610418505, 39.149776812522646, 40.202317391672445, 32.947956515896706, 13.529551067659932, 3.3638266209633123, 0.5515003228379834, 0.5148140881811419, 2.159194177196872, 6.584984871648974, 11.670993816468025, 9.953521278596694, 13.24699430696426, 15.74711109361341, 16.68274837155496, 13.17434318604008, 14.209589054507596, 15.827081357279132, 12.609294383756577, 15.000456552351675, 18.447171680388912, 11.764219730131089, 16.960881679288804, 24.571415339746785, 36.062608688108384, 47.84703646936725, 57.37548951179751, 63.72808964021745, 66.60354783458095, 67.20487856095838, 68.7523869545229, 66.89568596501505, 63.724139813453924, 63.5459896825975, 62.40817677590155, 65.82851102275234, 68.31472889069589, 70.5300521850586, 67.37354047836797, 67.85454073259908, 64.27288724530128, 64.75831585545694, 64.97184968763783, 70.65534837784307, 64.84669470017957, 64.32691397205477, 60.773760426429014, 48.82866844054192, 40.922574381674494, 42.149076000336684, 34.65453270942935, 52.35205904130013, 69.4631596534483, 61.847775982272246, 65.15875847108903, 61.67677633223995, 61.776553584683334, 58.88931651269236, 62.380214198943115, 59.128094719302275, 64.44837016444053, 66.50857940796884, 64.24074342173915, 62.682260236432484, 64.76494858341833, 64.0033458894299, 67.82182032062163, 69.10323512169623, 65.11685186816801, 63.90912271315052, 56.47991041983328, 50.605780616883315, 38.330146574204974, 35.3099686099637, 26.446982929783484, 25.54372972057712, 22.80246561573398, 22.352246161430113, 15.853892718591998, 10.170438155051201, 14.010719983808457, 20.38072366868296, 17.08981979277826, 14.99172829812573, 12.48446201124499, 9.085972424476378, 9.497143703122294, 6.403105547351222, 3.920837996467468, 1.576310112591713, 0.23118308835452606, 0.6751293857251445, 3.5837951014118814, 11.958118177229359, 27.005310750776722, 29.44437780687886, 31.095662309277444, 27.518597995081258, 33.03150300056704, 30.08106085561937, 46.06770815387849, 54.80749414813135, 59.949027184517156, 58.87142658233643, 31.966371613164103, 6.099076751739749, 0.4800156167437954, 0.12414211197005165, 0.07260064339084972, 0.03143914333063989, 0.08387162770715453, 0.02337860176339746, 0.05909402681995304, 0.008546253760165025, 0.05161405924046713, 0.07822276348428381, 0.06777553053032007, 0.01177508261941013, 0.032157352674872644, 0.02075247725682153, 0.07507172893852958, 0.05558757727304774, 0.045076249572899074, 0.09173139103598173, 0.08504938063842636, 0.03928773518231127, 0.046793240302753066, 0.09021814522002974, 0.03436816368071783, 0.07669580469448721, 0.07398912412745338, 0.042179648148556875, 0.02553128584798786, 0.08387159706363756, 0.033560553790941354, 0.030960637152255065, 0.02148902866118137, 0.14303641423823374, 0.08622111977949258, 0.0686239039585475, 0.17211668283468293, 0.25094011287775736, 0.20408159422297634, 0.193668513468677, 0.1349653102337353, 0.09555661359861975, 0.18374799660617308, 0.08196623680452186, 0.1068469722785296, 0.11101537924860755, 0.15964705436941118, 0.0935093355515311, 0.10722568018301841, 0.16345973607272873, 0.15627377005594392, 0.09493021414645257, 0.19399195579030823, 0.2363668835812038, 0.21959312800918857, 0.22693854756653312, 0.29662716052224564, 0.23020134667956063, 0.1761701766161188, 0.13154078995989216, 0.27939575934602373, 0.2002155621566119, 3.8239591304332983, 16.44604019580349, 47.51073637316304, 74.81564952481177, 76.11329509365943, 70.38127668442266, 68.46894079639067, 44.931373980737504, 39.479510861058394, 36.50936665073518, 47.46339728755336, 65.72440347363873, 60.891866914687625, 42.730186908475815, 16.871163345152333, 3.949903985185008, 1.2937850985796222, 0.6130108093061756, 2.8889293295721856, 8.56882066495957, 24.819560166328188, 26.893713435819073, 22.18116218043912, 27.82859075453974, 21.529795738958544, 25.692056109828336, 38.75890478011101, 28.10705746373823, 13.467187343105195, 22.36884759318444, 25.018661637460035, 20.49508429342701, 22.29215152802006, 28.15102723336989, 42.78892440180625, 48.572749476278986, 61.28678683311709, 68.21714032080867, 69.88428100462883, 70.57643028997606, 71.5281855675482, 67.83461509212371, 67.47709105091711, 65.96583320248511, 64.4268520416752, 66.81637564013081, 70.1904769097605, 72.17024618579497, 69.1729905528407, 68.20731870589718, 62.997101045423946, 64.3990110581921, 64.9457973049533, 71.0058827554026, 68.83893797474524, 65.20708207161196, 62.844638516826016, 55.32148153551164, 46.02538970208938, 48.49766354407034, 41.65786581654703, 57.91454868931925, 69.97485637664795, 63.12618232542469, 63.190913200378425, 61.43990439753379, 60.45252223168651, 58.91662405383203, 61.69432893876107, 60.87212170324018, 66.65964557278541, 70.06629467010498, 68.12147371230587, 66.53120363912275, 68.12455669526132, 66.4650175648351, 71.44358004293134, 70.23065766980572, 66.8099900214903, 64.22113157087757, 57.08034292344124, 54.45965836125036, 40.79450115080803, 39.43851817038752, 26.83306770939981, 40.52666994833177, 44.59337942061886, 22.458130544231786, 21.268032443138864, 20.823388638034945, 26.392873833256385, 27.465914680111794, 16.61153970226165, 20.952724872096894, 16.838994026184082, 14.493299972626472, 17.51850151246594, 14.994850504782894, 3.9631829242552485, 1.8775727792132286, 0.7984025548062017, 0.7926439638099363, 4.06580463051796, 14.241982929168211, 32.3993012597484, 39.995294693977606, 44.184335047198886, 42.108177446549945, 42.21034734479843, 38.643277229801306, 53.47376669606855, 61.44995743228544, 68.92435935235792, 68.69308856225783, 41.06645868670556, 10.163640687542578, 0.96474010016649, 0.2260792267418677, 0.10030953033316521, 0.1519971761491991, 0.185995667932495, 0.10300934675239748, 0.17092135584642812, 0.12988996241361866, 0.15938388784566235, 0.1802610248447426, 0.1401490748168961, 0.1298451922353237, 0.19239919770869518, 0.1138340465484127, 0.14562471889920775, 0.17991699007970674, 0.15418172183056034, 0.16742244843513737, 0.14941884595299923, 0.12498398131180195, 0.09600990016253726, 0.1570593625787766, 0.17792355269193652, 0.14821800313168956, 0.10247943607429344, 0.12853846074112002, 0.1401353311995345, 0.1899601422971295, 0.08392553731438615, 0.18019644363272577, 0.22774675500489053], [0.06235982899764373, 0.03425806152424024, 0.04400890906371417, 0.022370064248060508, 0.10408720947922238, 0.0486384358467354, 0.02964512629043912, 0.056928097075151826, 0.12965530968241154, 0.04348589317692865, 0.007568839045556924, 0.024594207099007986, 0.044991933935952765, 0.04621258396054468, 0.005762248108493946, 0.03143374624121333, 0.03868767383298086, 0.03164344557350682, 0.03873832756653428, 0.06179360958236841, 0.06860763225103579, 0.2047876514975102, 0.04935770813796309, 0.03401017845458081, 0.02797667297624773, 0.01438694544166567, 0.02157123947155572, 0.13835262927797534, 0.3517855217139567, 3.284471679118372, 13.251584460658412, 48.60725848905502, 59.19621452208489, 54.67806377718526, 45.17876571224582, 46.245611175414055, 42.05052644975724, 24.814062964531686, 27.887041914847593, 48.248169422149665, 31.056330742374545, 29.47370929102744, 13.85119620830782, 8.510554836642358, 1.0840949440194716, 0.10098040118933686, 0.3413281457558755, 2.1400672293478444, 4.281344509893849, 9.777696132659912, 8.158224013543899, 10.86447508104386, 11.30809416694026, 19.615820300194528, 6.758404624077582, 8.87210028786813, 9.226872786398857, 11.477483684016812, 12.69720744702124, 23.119942257481238, 16.630633800260483, 20.92942991564351, 28.423151469999745, 42.54977357002997, 51.51322880098897, 62.59594848079067, 67.44198583787488, 64.32668647458478, 60.128287346132346, 59.17452381503198, 61.28165245056153, 57.541837230805434, 58.105473979826904, 56.75795939660842, 63.2824299412389, 64.59157982180196, 67.91112484470491, 63.086868409187566, 65.39009986385223, 65.6111450349131, 64.28760005581763, 64.97909822771626, 63.48093717328964, 68.7269699958063, 70.1008350618424, 58.14267373854115, 45.158573350598736, 32.2511847173014, 28.68064134351669, 38.055894451756636, 51.776541433026715, 66.48357822049049, 63.28188865415512, 63.88332920689737, 63.079721850733605, 65.16247687801238, 62.814938329881244, 61.07819518735332, 58.615287965343846, 62.126860464772875, 62.40445444660803, 63.0178503836355, 59.813607354317945, 58.148259193666526, 62.50527112714706, 63.63518438031597, 65.98074605388027, 60.7463469812947, 60.5834666375191, 62.81551491829657, 61.98879303470735, 58.164215395527506, 50.01882145481725, 38.66838824364447, 36.35419376434819, 27.778382455149007, 37.70938050362372, 34.233297609513805, 6.745261742222694, 10.677284867532792, 18.055117053370324, 16.110611846370084, 11.966785634717635, 13.551883082236014, 6.3112132395467455, 5.011730040273359, 5.884795708041038, 6.048570352215921, 1.706821341668406, 0.30786913308885794, 0.07988091483111344, 1.306241565654355, 7.0016675706832645, 26.594979839940226, 39.36857838784495, 43.41773525361092, 41.14713791877993, 23.74134767440058, 30.033213823072373, 28.30702970104833, 36.11829457744476, 48.58707789451846, 54.46820520585584, 40.70397676960115, 13.025646132807578, 1.36821084685864, 0.03656673643197264, 0.0543924609589721, 0.010143103708903636, 0.03346734387319415, 0.04722486573061155, 0.04091066180638248, 0.08187440584503836, 0.0320899426831954, 0.03612567280088702, 0.01482267231274877, 0.04645077984840159, 0.036649707584611835, 0.03746816910983574, 0.14463729285184415, 0.026876511345166835, 0.06905757867160343, 0.026908338467981067, 0.08179097887008421, 0.046915492613709746, 0.015084628417577236, 0.030686860310754953, 0.017970720073208213, 0.03868847056442211, 0.07288349837425255, 0.030075257846845255, 0.04425226455374111, 0.03852389572608856, 0.027634811985697, 0.03416352244394441, 0.06800460614143841, 0.015377818884688522, 0.07570661664489778, 0.04982237876843541, 0.06141073032913189, 0.039693037829091476, 0.0220923688668277, 0.03545827615345198, 0.02803523848283916, 0.048245325489270116, 0.12204528335602054, 0.09261625323204264, 0.04074046005224509, 0.03563789312817878, 0.046674109800087835, 0.08578830308491185, 0.018626975887004408, 0.026689388624001897, 0.05612441338598729, 0.040855338766930566, 0.02448351313960889, 0.025443586017636043, 0.09617466269241226, 0.03682358656078577, 0.04012211984504135, 0.025674272328615192, 0.032061965152200674, 0.12577310549996554, 0.10104420865255018, 0.262516544110352, 4.043563565900249, 15.926806638317725, 56.00914755175191, 65.42145136863955, 64.82659647541662, 52.975480556488044, 61.02333299575314, 43.216290166301114, 25.467769099820046, 18.49933724249563, 46.90304748473629, 45.008499545435754, 31.960588078345026, 17.894305759860625, 8.794064733289904, 2.084797846694147, 0.13040552426490093, 0.9382946837332942, 4.401996126098018, 7.2353113947376135, 9.963236008920978, 12.830403293332747, 16.077665898107714, 15.847424730177849, 19.07439201108871, 13.40449413945598, 14.581478776470309, 14.378169582736108, 14.108282077697016, 14.643239436611054, 17.733102229333696, 11.988699916870365, 21.747650061884237, 34.08249424349877, 43.10911532371275, 54.45761480639058, 64.13127399259999, 70.17294391509026, 66.49030116296584, 64.87836783932102, 60.934052005890884, 63.884411781064934, 60.8641710589009, 60.110946547600534, 59.43276482243692, 66.4815228985202, 66.85597588939052, 68.77588195185508, 65.29362524709394, 68.57195008185603, 67.37008879261633, 67.28189822166198, 64.25692319869995, 64.18223734824889, 67.28484784403156, 70.96545096366637, 61.48921251296998, 52.400096308800485, 40.35774523212064, 32.82253088489656, 41.822307263651204, 56.281265904826505, 66.87934537087718, 65.1811905061045, 64.51684298053866, 64.52328743473177, 65.43983159526702, 63.38869087157711, 60.85405918859667, 60.43959017722838, 63.768082126494384, 64.50287149798486, 64.47808211849582, 62.25462382839572, 61.535484713892785, 64.08377801218342, 64.16408069672124, 67.89663560928838, 62.09870176930582, 60.971098792168405, 62.69510599874682, 60.50577232914587, 54.90159965330555, 47.02695123610958, 36.149693150674146, 29.690600672075828, 24.654583315695486, 21.117752713541833, 9.361446365233391, 13.17217117355716, 21.41210109956803, 19.75821018218994, 18.487472072724376, 15.775534549067098, 14.073381808496292, 12.601178019277512, 10.377366715861905, 11.322327467703051, 4.599399701241524, 1.8093128742710238, 0.5287254481546341, 0.14069377865281799, 1.4982915958089214, 7.092120368634501, 24.460412263870243, 36.04322825708697, 38.25591571869389, 47.32481210462509, 31.116545008074855, 36.34810232347058, 36.33890828778667, 41.50095924254387, 55.383917823914565, 61.67223030521024, 47.914356108634706, 15.234972123176822, 1.7011493492511012, 0.050334052723501964, 0.0643809642943163, 0.03933040244925407, 0.03750633944066302, 0.11718136048124683, 0.04919729315705838, 0.04875162150710822, 0.1256876024267366, 0.028060496401702686, 0.06305589648564497, 0.05644187256092987, 0.05855395015509379, 0.0526315504084191, 0.08230879301986388, 0.06003464106470347, 0.019254593418971188, 0.05347910029212794, 0.015542653235306424, 0.01864350614919057, 0.028119061908294118, 0.06264900420642187, 0.044840991632231784, 0.015959571690238532, 0.03208372971012948, 0.07568284493660735, 0.03319532903391988, 0.026641866274838968, 0.014847233091601202, 0.024132595074573354, 0.05094185539130723, 0.1747312489897013, 0.17067217808817664, 0.13588121431248804, 0.14598557695506081, 0.1390772258802768, 0.1265560320368217, 0.2746035116574457, 0.13798430952573978, 0.21376705998855255, 0.2027800261613823, 0.14625844215193104, 0.14810961701216238, 0.2518632335047568, 0.27188022230421344, 0.24678802358046656, 0.17728713280971975, 0.11186399782497077, 0.13949472847725117, 0.1051606365569657, 0.14454937660165373, 0.10279748513693772, 0.381124421593643, 0.19322174631299513, 0.1797284711632998, 0.09597507380549947, 0.11497446801513435, 0.2331929047021174, 0.2110452721676519, 0.5649674743894608, 5.500716730471581, 23.20228457450867, 63.896123978399466, 77.45618128007459, 71.39742943548387, 60.42848202490038, 61.41249879713982, 53.46132101551179, 36.684524013150124, 40.7769367771764, 59.486301252918864, 38.72497627812047, 41.16862858495405, 19.259443552263324, 10.581075010761138, 1.8728464457296559, 0.35907665628098673, 1.1833360574899183, 6.789614433242429, 11.94927421308333, 18.437728574199063, 21.644858467963434, 24.878487894611975, 19.858703267189767, 31.03121972853138, 15.467779501791924, 22.662954753445042, 24.24722360026452, 21.97453171976151, 20.58781893022599, 29.058924528860278, 19.307894629816857, 24.807900920990978, 35.384348515541326, 45.219703489734286, 54.482298281884965, 65.42686816184752, 72.15562358979257, 69.11704970944312, 66.02771251432358, 64.54802974577873, 66.55214125110258, 64.031300621648, 63.02171391825523, 62.124969882349816, 67.83752549079158, 68.64035621766122, 69.73017892529889, 66.03488260699858, 68.60176009516563, 66.29593987618723, 66.10122557609313, 65.67150638949487, 65.38447910739531, 68.68917403682586, 71.63674108443722, 64.14411191017398, 54.83182461031022, 44.932727198446955, 38.21469160818285, 47.2340053127658, 60.34514342584918, 67.37168911964663, 64.46616595791232, 64.68444193563154, 65.70594872197798, 66.3398390431558, 64.00098070021599, 61.48088924346432, 59.11915563767957, 64.97388932012743, 65.93950625388854, 67.64840449056318, 67.05352998548939, 63.10192638827909, 68.19038975623347, 67.0064615434216, 70.1945718642204, 63.93948578065442, 61.85554227521343, 63.845545015027454, 65.08450015898674, 61.54955425570088, 56.39004499681535, 45.86300357695549, 44.01151541740664, 30.730483762679565, 42.53684936031219, 43.184946506254136, 18.197416720851777, 21.240473870308172, 27.30357954579015, 31.614642873887096, 21.190079258334254, 26.657722073216593, 15.852419868592294, 16.909977159192486, 16.082503161122723, 11.999154013972129, 2.6187035201057314, 0.7376984218435904, 0.3059911451512768, 2.11469586818449, 9.551017457439054, 31.758611509876868, 46.934147957832586, 58.66444703071349, 55.211768919421786, 35.13570554794804, 41.261612292258974, 39.605073775014574, 50.85534534146709, 64.83237020431027, 70.62877039755546, 56.04963817904073, 21.815922837103567, 2.931290927433199, 0.17140291871563082, 0.1374908876154692, 0.09813094481585488, 0.14216144989815452, 0.20004182873714357, 0.15303168596038896, 0.1696327346707544, 0.18029865508358325, 0.11234439624052857, 0.18125149992204484, 0.28118230702896274, 0.1532442753593768, 0.21651929214356408, 0.24408664434186875, 0.11975605942068562, 0.1890048612990687, 0.12382381009839236, 0.26743375606113867, 0.24237460637044525, 0.16003576738219108, 0.17282658587059668, 0.09352674873004999, 0.10553271780090948, 0.18472212336717114, 0.12695782217046908, 0.21131545605678714, 0.13303812412965682, 0.10876806032273079, 0.174451534966788, 0.13481371675527867], [0.047754872169706135, 0.02619200795438261, 0.03838224223844948, 0.06621647265649612, 0.03573847281175756, 0.045014836134449135, 0.01985566983480127, 0.053417376588068666, 0.0597276543116858, 0.027833261316822424, 0.03806071130618934, 0.01753130736159942, 0.05877490523421477, 0.043169832112447876, 0.004692164525735162, 0.09828629212514048, 0.07007104404751333, 0.016567844544507323, 0.024710487754594897, 0.01616607164783824, 0.030643166485993616, 0.07942964307843678, 0.01958770185498701, 0.041219322461514704, 0.05013442936263258, 0.15381372383525296, 0.03982528758746001, 0.07242822764261116, 0.7541520292720487, 4.932573178122121, 24.29409788500878, 45.96489106455157, 53.16735113820722, 49.42191908436437, 42.92207710204586, 35.5721829783532, 39.32138442993164, 59.801377404120664, 61.840256798651914, 27.48331823656636, 35.96807172221523, 26.10648785867999, 18.021514108104093, 4.283347370163087, 0.46734544178170545, 0.1166030024028113, 1.6812262828311615, 2.8114708537055604, 7.62034890151793, 6.118539552534781, 6.026322178302273, 13.270915862052673, 13.405644374509013, 11.611926844043117, 11.09359052873427, 8.849549601154944, 10.064357653740915, 14.456988630756257, 17.997695515232703, 20.35758560703647, 20.249838098402947, 29.925505538140577, 48.94198571482013, 53.82434814207016, 67.75321022156747, 66.16177912681334, 62.58958639637117, 61.705648899078376, 62.07120203202771, 61.249194837385616, 62.76058996877363, 60.231763393648215, 56.478514056051935, 52.64082785575621, 60.71510138050203, 65.92147904057657, 67.30758974629065, 65.81744209412606, 63.81564086483371, 64.50269891369727, 64.25234579270887, 64.01532873030632, 64.53792179784467, 62.584546150699744, 51.799212732622706, 63.7851522814843, 47.67088282492853, 36.429432668993556, 33.1710530865577, 47.607430642650975, 56.09662817370508, 61.66550736273489, 64.04008280846381, 66.62068859223398, 66.87275578898769, 63.46682056303948, 65.0512110033343, 64.2469839126833, 62.61073973871047, 61.87831947880407, 63.945365413542724, 61.274462746035674, 59.69191581972184, 59.815658753918065, 60.70646824375276, 65.04574321931409, 64.12749282775387, 64.84534148247012, 62.67831040966896, 62.27208229803271, 60.64156870688162, 55.72822347764046, 51.41356137491042, 48.30887986767677, 38.11815815587198, 40.13694324801045, 35.64003605996409, 12.2097784280777, 13.187912625651206, 21.008583345720847, 21.00201141449713, 20.76177408618312, 15.995071568796712, 8.68869516157335, 11.454821209753714, 9.59442142517336, 7.364543685989996, 3.843359663601845, 3.0365249322306727, 0.08365895403849502, 0.12252430281331464, 0.24374305390782897, 3.441630020256966, 10.581122079203206, 25.838939066856142, 46.02341282752253, 41.87258028214978, 24.215389643946004, 13.965444064909413, 27.279305957978774, 44.602224365357436, 51.06173653756419, 50.5379589142338, 45.926769548846835, 17.73202749990648, 3.761786376276324, 0.09541059724025189, 0.03945284628219182, 0.07907019462436438, 0.035162596858196685, 0.017234040349121058, 0.04223743799112497, 0.04785171717465405, 0.04633742947912505, 0.025834936288095293, 0.008223832250692913, 0.018194337307866064, 0.020986953787806056, 0.05015334790392269, 0.04806984155889481, 0.021536455249353763, 0.06663415145369307, 0.044743660161451954, 0.028076657026465383, 0.024084871627330303, 0.05135515599601692, 0.04515164028552752, 0.017707568871217872, 0.019434961159863783, 0.03557117836129281, 0.035023218651692715, 0.0893360179578585, 0.05267618269088769, 0.018013147937674678, 0.056384366170893756, 0.050846983062764334, 0.0336617348535407, 0.02512034287886514, 0.050146759547773874, 0.054997157140244404, 0.03272772045625794, 0.024217793627852396, 0.040721028232045715, 0.03981120306097212, 0.04455973394215108, 0.031581373299441995, 0.06623690422143667, 0.016216392133144603, 0.10699111938236222, 0.06238284993976836, 0.01795363631249676, 0.02613901765266013, 0.07232728789770797, 0.029071540939771844, 0.03405980946075532, 0.044265188457023714, 0.029056602225248373, 0.06795257344962129, 0.03529722148913049, 0.055427418931597666, 0.07123051812091181, 0.048300610224325816, 0.13135178074721368, 0.07396591166334768, 0.8105023926304233, 5.633711555311757, 27.269468653586607, 55.00814691666634, 63.20461011702015, 57.41913764707504, 49.41763977850638, 38.08144869342927, 43.836224694405836, 47.627007192181004, 52.805469343739176, 39.06563412758612, 33.01710397966447, 29.7368787565539, 14.079382054267393, 4.572116184619166, 0.6390580438798474, 0.8532490569256967, 1.1644733793312505, 5.1078565466788515, 9.727484891491553, 13.168743022026556, 13.397929072380068, 15.921163328232305, 18.04419521362551, 13.529920751048675, 19.67321438174094, 13.209493506339289, 11.82117646740329, 18.28657219486852, 18.828251515665364, 17.616992227492794, 19.335482620423843, 31.40869490561947, 46.752055844952984, 56.63057258052211, 68.5177037023729, 70.21201856674688, 64.79120100698164, 64.92486753771382, 63.36988310660086, 63.788458839539565, 64.50617805604013, 61.94737672805787, 57.60537570522678, 56.00652348610663, 62.200648092454486, 66.9064332592872, 68.8852454769996, 67.80060814272973, 64.16463767328571, 67.28803280861148, 64.87188416142618, 63.19178396655668, 65.36345520327168, 63.79520923860612, 55.62391588764807, 64.98591922944593, 52.04872646639424, 44.23444332615022, 37.99928680542977, 55.3523035203257, 59.39671824055334, 61.71188154528218, 63.687340136497255, 67.89312116561398, 68.50490108613046, 66.33448893024077, 65.87698367334181, 65.57717338685067, 61.15217501117338, 63.83317778187414, 65.51961260457193, 63.987440678381155, 61.32468869609218, 60.047992506334865, 61.59723458751556, 65.76949504113966, 66.30857775288244, 63.34138708729898, 62.941925064209975, 62.92580020043158, 61.590037038249356, 57.2944611887778, 53.23356859145626, 48.23099728553526, 36.768419588765795, 29.5636276660427, 21.08259454850228, 12.215338387796956, 14.659132880549278, 18.18613402305111, 14.272854924201967, 17.240142668447188, 21.58858814547139, 13.349724123554846, 13.237435490854326, 13.72585588885892, 10.72273729308959, 6.451622814901414, 4.5023401610312925, 0.836751200258732, 0.28588195000925376, 0.5308605045560868, 3.7825783702635, 15.88118358965843, 32.54785122409944, 45.085676100946245, 39.27684591662499, 24.70218323892163, 19.085790418809463, 31.14107551113252, 51.021642069662775, 56.400976642485595, 58.47439642875426, 53.168759269099084, 23.21235133755592, 3.900975113914859, 0.20703628809461672, 0.15512845328738614, 0.02052524408716108, 0.03990915506297062, 0.10013080202043058, 0.007452687667307234, 0.05560828462964105, 0.02765873882679209, 0.023356777833654516, 0.08957754249774641, 0.07623759984609581, 0.056160733614477425, 0.016334363927824364, 0.08363489121679338, 0.04112373767120223, 0.025457115130378835, 0.10303752346625251, 0.0828761041104313, 0.01295884742566775, 0.062466663789124265, 0.018337463599539573, 0.0423745370860542, 0.019772869136725223, 0.03295971103192818, 0.0422219974890111, 0.06209372069626566, 0.06345127829380574, 0.013902002209497076, 0.10252727060428551, 0.04275149447963603, 0.13435921211156154, 0.13033124437976268, 0.1814642425386175, 0.24967885636273893, 0.1574110429012968, 0.1784784914625268, 0.13078505954434796, 0.15348226823393377, 0.15648795291781425, 0.16035010857928186, 0.1164408369109996, 0.07600805692134366, 0.28412825217650783, 0.1748676126402232, 0.10079162946391491, 0.19473863104658742, 0.19058648046226273, 0.12355983918232304, 0.1914149585870966, 0.13863180703934164, 0.17739274569096106, 0.14294682791636837, 0.1457326147224634, 0.147730985716466, 0.1311369084062115, 0.23024228641823416, 0.2511555521238235, 0.1607674273151544, 1.057911161934176, 7.354240109843593, 34.96033245517362, 62.152230355047415, 71.77786796323716, 66.48090316403297, 58.85365824545584, 48.63304022819766, 51.09884608176447, 69.91647581900321, 74.24511724902739, 37.18883491331531, 49.74151380600468, 38.775869031106275, 23.208711378036007, 5.728301963498516, 0.8870497141634265, 0.5697802838779266, 2.6533360875421956, 8.101592832996, 18.427742219740345, 16.663985713835686, 17.22459439308413, 25.44844162079596, 26.680007019350608, 24.87289067237608, 25.63952772848068, 18.54923567464275, 20.621123775359123, 21.69246819711501, 27.268862647394982, 26.373871910956602, 24.066019904228952, 35.354773844442065, 51.6320687724698, 57.13832339932842, 69.96453269835442, 71.49923063093617, 66.52145262687438, 67.96197445161881, 65.33331571086761, 65.98870062058973, 67.45492965944352, 65.17653465270996, 60.40511646578389, 57.65837477099512, 65.2221243612228, 69.5403205194781, 72.45024850291591, 68.33302282517957, 64.44801322875485, 68.2574858204011, 65.02695114381852, 63.59135581601051, 64.22837226621567, 69.24196935469105, 63.72289249973913, 66.1753583723499, 56.101876304995635, 48.506077028089955, 46.600868086661066, 56.986900298826164, 63.702888411860314, 63.59046543798139, 65.61852693557739, 68.17797153226792, 71.323681031504, 67.45551801496937, 69.14433371636176, 69.66997054315382, 63.11559584832961, 64.79359757515692, 67.50824251482564, 66.71782216718121, 63.84728262501379, 63.43248021218085, 64.35385281039824, 67.48106833427184, 68.94554799602878, 65.81276662888067, 65.21124762873497, 62.90845155715943, 62.51177833926294, 57.47905969619752, 55.30249334150746, 52.93471928565733, 43.14355373382569, 49.164807719569055, 56.389782198013805, 21.404891783191314, 21.15683913230896, 31.286754300517423, 32.36873815136571, 33.36712844910161, 24.31037768240898, 17.821941952551565, 24.239986827296597, 19.081556220208448, 15.343293278448044, 11.853823334940019, 7.9615014599215606, 0.9474815488342316, 0.25944275421000296, 0.9875616755697035, 4.1459639033963605, 15.017099168992813, 32.79697075966866, 56.34147428697156, 52.568644477475075, 34.01675924178093, 23.46576390727874, 40.7715239063386, 58.648537897294574, 66.40528771185106, 65.80739298174458, 63.24287676042127, 28.62839537282144, 5.715626333990405, 0.5182986237829732, 0.20305351955035042, 0.19852358036704604, 0.11051959012665095, 0.19036177155231276, 0.15976763660869292, 0.16897066616483275, 0.12832417062694026, 0.20187817213516082, 0.15173848357892808, 0.16476663610627576, 0.22698299598789987, 0.15155440797248196, 0.20538469446041893, 0.1499648674601509, 0.2053165739221919, 0.1693918000185682, 0.1476605975579831, 0.15067633331543015, 0.1437812355617362, 0.15885426062009028, 0.1039612493027122, 0.1137419091537595, 0.09378076050310366, 0.13665713880571628, 0.2038811549784676, 0.19469312542388517, 0.11736770370794881, 0.15962764170140992, 0.15597593039274216], [0.03373645906967502, 0.009549598156985258, 0.03282099549147872, 0.037804623434860865, 0.038079825199900136, 0.043528525969914855, 0.017962323749558102, 0.03502074035725767, 0.026044198950271935, 0.06301316027078899, 0.09895352406367179, 0.10332034014525915, 0.040574835673455274, 0.06858310977657957, 0.024375167239697713, 0.02638380572710547, 0.08027555736442728, 0.03985335321856603, 0.07188553095705087, 0.02381098561830098, 0.06935117420770469, 0.03289385428351741, 0.07809741617811304, 0.05826539930797393, 0.0257802433559611, 0.03839741460978985, 0.05897712563314746, 0.07928115991695274, 0.6805910410419588, 9.391212251878555, 31.766566076586326, 47.8582779822811, 45.926840151509936, 45.37311523191391, 37.94045125284503, 41.04490526260869, 25.615693446128603, 33.191743589216664, 21.152334290166056, 39.18501146378056, 46.15975441471223, 15.93208222619949, 8.402657297349746, 0.977765862499514, 0.2979649951861751, 0.24319445834525172, 0.6854294685106124, 2.1818294400169007, 4.709399140650227, 8.107086112422328, 15.42728691331802, 14.460566812945952, 18.595082298401866, 14.391335018219488, 17.297164124827233, 15.219992591488747, 11.37643656423015, 22.30370486936262, 28.423882992036884, 29.142082698883552, 24.640929545125655, 41.84463339467203, 57.026626063931374, 62.949644288709095, 68.88486108472271, 60.21565029698034, 59.57426040403305, 59.94297496734127, 61.20192243206886, 61.049150036227324, 62.3746758122598, 62.493707979879076, 61.06860891465218, 50.59660619305026, 54.70129597571589, 62.991562658740634, 64.06369547690115, 62.87295802947014, 66.64061423270934, 65.03724736552086, 68.71226895240046, 62.60336176041634, 67.44810473534369, 48.72461580461072, 52.53595936682917, 64.68642665493873, 53.70187213343959, 42.130785988223174, 31.93750100751077, 54.06558959714828, 59.930203730060214, 63.06586019454464, 63.205606399043916, 64.70744663669218, 61.82650496882778, 61.98770261579945, 62.48698503740373, 59.435345742010306, 61.53222130190942, 63.55250081708355, 63.05031584155176, 59.85391755257884, 56.00590375161941, 57.15831179772654, 61.55660667727071, 63.30354405987648, 61.79714995045816, 61.76085233688355, 62.648206218596435, 64.85027190177672, 65.57694588938068, 68.98125725407755, 63.99628562311973, 53.48265086450885, 41.66038397819766, 32.28831191216746, 20.160321766330352, 16.798270017870014, 21.841039734501994, 33.622451213098344, 17.18606887325164, 11.978562551160014, 22.11200098837576, 12.344022527817758, 11.700123298552729, 8.933654042982287, 12.690273677149127, 2.1194382588709555, 1.6951305947957502, 1.293878867741554, 0.12560571528851025, 0.2310293957951569, 0.8506576572695087, 4.40807972223528, 14.746433073474517, 40.93431403560024, 51.03295810760991, 40.0236181289919, 38.015584253495746, 29.77966593157861, 31.521468931628814, 45.3950922719894, 55.10029908149473, 52.438013861256266, 27.81221485907032, 6.317339491459632, 0.4492098729937308, 0.05633118434719021, 0.040731018018578334, 0.026776900762812268, 0.05747881087083971, 0.02525057591077301, 0.022388837232645002, 0.06365157964248812, 0.06013797100393042, 0.057758842820241574, 0.02996017420364003, 0.014344165176754037, 0.08350380591206974, 0.04778026798439603, 0.00428421552398152, 0.029167359386901223, 0.0546071570997517, 0.021859466646527572, 0.05138666136190296, 0.011603861968333443, 0.014274172511162057, 0.020364628008176244, 0.07085528059472, 0.028246523617135904, 0.06217892499520414, 0.025949031677878192, 0.016748664277275244, 0.02451181817319124, 0.015934866312290394, 0.029069064560556607, 0.005121996829045876, 0.024204425393573703, 0.008869775563418385, 0.02388421213254333, 0.003402332931141099, 0.027369797274830843, 0.03572751009356111, 0.017609850526036277, 0.03826915616950682, 0.10301457913292032, 0.11768540037014794, 0.00645305831811481, 0.03964067954990653, 0.04016469518143324, 0.027755110772446762, 0.06673805595886323, 0.019849022106838324, 0.031620418885722756, 0.03855373102029966, 0.05985841402904161, 0.0767676254373885, 0.035804743247647444, 0.08281141564610504, 0.06608034649323072, 0.10090990577854457, 0.06042769396557443, 0.048072381140363794, 0.05473016400731379, 0.760094971666413, 11.128886957322399, 35.65443115849649, 55.81307611157818, 56.512246439533854, 53.60482092826597, 44.19789075851441, 41.16820104660527, 27.538951173905406, 47.62421838698849, 37.41574795015397, 39.60166131296466, 41.35617671474334, 18.224461463189897, 9.106850220311074, 1.3794158327002681, 0.7529686379336542, 1.0744198051191147, 2.6084161237362893, 10.590366125106812, 14.96172804986277, 13.111506815879578, 16.842898745690626, 13.538654888829878, 16.215060641688687, 12.749890761990702, 17.79627984569919, 10.567688941955566, 10.224236403742145, 19.60955039147408, 20.028706635198287, 25.467953451218147, 28.84499061492182, 42.765951079706994, 55.64209999576692, 65.0367021560669, 70.34121359548261, 64.56910464071458, 63.471747059975904, 62.125095398195334, 63.785179738075506, 63.18206825563985, 64.09662377449774, 64.36986784781179, 63.10051825738723, 54.546903640993186, 57.201767736865634, 66.51002284019225, 66.86436191681894, 65.21459733286213, 66.64900026013775, 66.29831683251166, 69.63274725021856, 62.0595722044668, 67.58096325782039, 53.07734058749292, 55.537329566094186, 65.37902701285579, 55.369193246287686, 49.03381232292422, 36.94943697221818, 56.51589032142394, 61.72531958549254, 63.37743759155274, 63.79283620465187, 66.28090935368692, 64.70318694268504, 64.03610160273891, 63.62600211174258, 63.06238497457197, 63.16937154339206, 64.76637632616105, 65.0860377280943, 60.93978258871264, 57.69322110760597, 60.16980563440631, 63.33117715774044, 63.838308242059526, 62.60025524323987, 63.32770193776777, 65.20639173446163, 63.55671736501879, 65.04963421052503, 67.86182849637925, 62.15095166237124, 53.57664262094806, 44.59932181142992, 34.556642117038855, 23.848400923513598, 14.163488457279822, 13.217886397915503, 12.985568334979396, 12.628358083386576, 15.295601179522855, 19.383743463024018, 11.837033629417421, 14.04639982408093, 11.12857807067133, 9.202800220058812, 7.220850596504827, 4.789909220510914, 1.6595855859979507, 0.4941857612181095, 0.30245960239441166, 1.339724510908127, 4.921577303640304, 19.39613619158345, 41.48720741271973, 47.65441279257498, 44.16524487157022, 34.88037101684078, 32.107778941431356, 38.59865242435087, 52.87533460124847, 61.928627798634196, 59.82329953101374, 32.70176306847603, 8.074545639176524, 0.6429275846289051, 0.07103347264590763, 0.07698059788033848, 0.020580220471827254, 0.04414010928162644, 0.03986533483370178, 0.025020831887940728, 0.03875813093937693, 0.023673478581552065, 0.03998264204710722, 0.049313447408137784, 0.04512067118118848, 0.04150429567802818, 0.03979354856475707, 0.10778851732010804, 0.06048041613652341, 0.01691627856944838, 0.05360237533046354, 0.06055163550040415, 0.005496209712638971, 0.00803442850273343, 0.048301977691270655, 0.01803358907871429, 0.02965245392143486, 0.047590707188412074, 0.007624521188723345, 0.046389944806334474, 0.030980969125765468, 0.014839687125547039, 0.03471275385949881, 0.15516174746857536, 0.1414530024292969, 0.18541630627887865, 0.15633487322878453, 0.09973308747454036, 0.11987498691005093, 0.08689828787840183, 0.2227729904435335, 0.18143399738736693, 0.1790884659895974, 0.22313234696705497, 0.20009170106101423, 0.1748948853703276, 0.12880622379241452, 0.11508468508480058, 0.18542453406318543, 0.30093419876310135, 0.2761110194748448, 0.11348638818749499, 0.18649915623809063, 0.13558662286208523, 0.1796570258034814, 0.19430569943881806, 0.1546676820444484, 0.29811217599818784, 0.1628078412144415, 0.20141948465137713, 0.25370060346059264, 1.5242031408894448, 15.341115382409866, 41.83985594780215, 64.92888404477027, 67.56658384876867, 61.393977365186146, 51.60375318219585, 54.87186416502922, 35.85136552010813, 44.44974614727882, 31.195239520842033, 53.050660625580825, 58.19318209925006, 22.624301756581954, 11.447467746273166, 1.640406789318208, 1.139988718974975, 1.1949912578828874, 3.0473298363147245, 10.391414684634055, 17.07548745216862, 22.012468884068152, 27.290514130746168, 27.24533234873126, 32.47265350434088, 23.717725200037805, 29.323407988394464, 24.702902993848248, 16.844628510936616, 31.128947542559718, 34.93373094066497, 30.12573861306714, 29.456921546689927, 45.62792416541807, 59.23209244205106, 66.12927836756553, 75.02559046591483, 65.17786433619838, 65.06559433475618, 64.66687756199991, 65.96062429489629, 65.82116050104942, 67.64788673770043, 67.34781757477792, 66.61849990967782, 56.73130296891736, 59.92695208518737, 67.65112661546277, 69.32843408276959, 68.01303586652203, 70.31017980267926, 70.04662006132065, 70.2672141598117, 63.34374050940237, 67.62820428417575, 57.74314895752938, 58.965308512410815, 64.50210663580125, 57.77400624367499, 55.980235761211766, 43.41066322019024, 61.546337912159586, 66.78667545318604, 64.84950311722295, 66.8302059173584, 67.43284671537339, 67.36480143762404, 65.82525545550932, 65.63278475115376, 63.3881260502723, 64.10959113028743, 69.21928236561438, 68.4420725607103, 63.73971162303802, 61.89622902101087, 63.52794677980485, 65.91109260436028, 66.69065583136775, 66.2248900628859, 67.84792761648855, 66.21414276861375, 67.50151957235029, 69.9432969862415, 73.78163429998583, 65.59253731081563, 56.56415508639429, 46.68319863657798, 39.128725451807824, 22.77078659303727, 21.15546630274865, 29.976778761033092, 45.459352462522446, 29.062709616076564, 19.422306245373143, 30.790543094758068, 21.85157129841466, 23.59572575938317, 20.096089032388505, 22.425786679790868, 10.329382400358877, 5.005216454305957, 3.4111539394624772, 0.6296842533253855, 0.32799407899860417, 1.7955536900028106, 6.291664146607922, 21.999370128877704, 47.60668931468841, 67.59482491400935, 53.42673747770248, 50.759855239622055, 39.839623666578724, 44.10835481459095, 60.8355652132342, 71.25758124936011, 68.47320833513814, 41.3626290136768, 10.611000733990824, 1.0828341471572076, 0.2230783377683932, 0.15805147708423678, 0.14718854950079996, 0.1877799326734197, 0.18814391636800384, 0.14497089349935133, 0.2653430408287433, 0.1728894970109386, 0.30333168624389556, 0.13882870695764019, 0.12380445871742503, 0.20518833080366736, 0.163154925009416, 0.11800087537736663, 0.16781500720929715, 0.11246446520090105, 0.21411350026967066, 0.1304071330495419, 0.0621047523623753, 0.09795966287774426, 0.1363689212068435, 0.10723874964300664, 0.10695426289232508, 0.13263074921504145, 0.06806745599474638, 0.16540109480340637, 0.11270249637985423, 0.11426540001505807, 0.2353248507865975], [0.052955670717863314, 0.06434810678324392, 0.023644202531525688, 0.02102419332180533, 0.05210392650276904, 0.015175429946412484, 0.030206844939159292, 0.021985735173427293, 0.024693494009214546, 0.06000981598551716, 0.04070616229587505, 0.018301716021772836, 0.09839457865323752, 0.054143543670614885, 0.047608874963536385, 0.08328255971953755, 0.05873371651696582, 0.014475668957006308, 0.05961478657780155, 0.022047719347380826, 0.015888847410678864, 0.07084345219716912, 0.024211291456595067, 0.05755552691557715, 0.021870477245219296, 0.06007886732057218, 0.05820730686067574, 0.029221918253648668, 2.0741297352698544, 14.515380955511525, 40.2828005052382, 48.45083436658306, 54.71016053230532, 53.352067316732104, 43.39708789702385, 27.776552669463623, 30.32135505830088, 17.63652170858076, 37.45677201978622, 37.79910472131545, 31.95545565697455, 19.383790531466087, 4.388217329978943, 0.3298307901188251, 0.2861866997855325, 2.244569957256317, 2.2003881344872136, 10.67318501011018, 11.217623718323248, 13.577711889820716, 14.179972217928979, 10.650059696166746, 17.115697629990116, 9.938396619212243, 19.9865823407327, 13.144185062377685, 9.9703453048583, 33.06883611986714, 33.190778686154275, 36.67925234763853, 43.76936789481871, 55.40437298436319, 64.51829817987257, 67.44145239553144, 62.1162582981971, 64.31308761719735, 58.84857485371252, 59.98190841367168, 61.071864481895204, 67.46670461470082, 63.15055593367546, 64.18514382454657, 60.79498437143142, 53.88761205057944, 50.00617965575188, 59.76903353967975, 59.22003115377119, 61.926831353095274, 60.83812259858655, 66.17761765756916, 66.40170266551357, 64.37100925753194, 59.69593624914847, 64.09130504054409, 60.43793493701566, 63.50847613426947, 52.988032141039454, 54.79539363614975, 32.23599337762402, 39.41510946519914, 59.943112250297304, 58.21903051868562, 64.23908033678609, 62.62480928051857, 61.39960204401324, 59.965057911411414, 59.47336135372039, 60.876338251175426, 60.001747762003255, 60.54051668413224, 57.932379784122595, 54.99329290082378, 54.47638727003529, 57.08858774554346, 59.02101401359805, 59.748197909324404, 58.8308810418652, 59.38066005706788, 61.36839958929247, 61.60314952173541, 65.62080583264752, 68.33516443929365, 70.03218573908653, 65.69200077364522, 59.76315782916162, 45.25039603633266, 29.917700021497666, 20.48983616213645, 21.41690011947386, 13.286875986283826, 7.558484788863891, 17.079047003099998, 26.610432017234068, 9.222745472385038, 8.97527333228819, 11.98605231700405, 5.171993182551477, 6.03175122891703, 5.083853602409363, 1.240525195194829, 1.0510516719472025, 0.08713670210131715, 0.48560572968375304, 5.1076167918020685, 14.582683924705753, 23.29652540145382, 30.87839830306269, 20.007263037466235, 26.975467397320656, 29.144775406006847, 36.84050883016279, 48.587246556435865, 50.85918534186579, 49.987642534317516, 39.77259820507419, 16.585675593345396, 1.4094741810714047, 0.08316173233212003, 0.02318269009852121, 0.03699980593556839, 0.02211998633649801, 0.04597554103501382, 0.054806102472808094, 0.06946078606791074, 0.0923618354323891, 0.1666146087189836, 0.02278791733026024, 0.025939287039481347, 0.0532410039957012, 0.12200061276915575, 0.12516225763266126, 0.00518742265299924, 0.04283286067807386, 0.02316520988730894, 0.03020200517869765, 0.030600616047459266, 0.033602451139520255, 0.025176719289212942, 0.04875923259063594, 0.030176143965593753, 0.09480453742247436, 0.01685255729112654, 0.03862914471556583, 0.06519150063996354, 0.02433580181170856, 0.0379362105271749, 0.11503084442548214, 0.03274113082537248, 0.029418142099354058, 0.009455229531252577, 0.020271678560323293, 0.06380964273346529, 0.05082129996510283, 0.015427534160534702, 0.02126530417421412, 0.06050784208421266, 0.014796021071472957, 0.04149298055938656, 0.04510913772748844, 0.05143666775116036, 0.06208036012286621, 0.08205062138938135, 0.0626620736664101, 0.05192180825096946, 0.011050430475734176, 0.013603409864909708, 0.03815900421731415, 0.016305530293574257, 0.021835413400924975, 0.09467619471251966, 0.099019315694609, 0.0487113137909722, 0.04648934471450987, 0.06097244376677179, 2.25301849745935, 16.960740473962602, 46.027072398893296, 57.32293759622882, 62.17222267581571, 57.94370758918024, 47.20432473767189, 31.14269741119877, 34.07122527399371, 24.229055181626354, 28.629634841795895, 40.10466606386247, 31.399214536912982, 17.110425964478527, 4.561948910836251, 0.5529802208465915, 0.27977475836392374, 2.3379248188387964, 5.755288360580321, 12.226127847548454, 13.638950874728542, 13.624362599465156, 15.49121468297897, 12.624092505824182, 14.198600534469852, 9.481558165242596, 9.473104476928711, 8.085415507516554, 13.455033879126272, 20.772668469336725, 23.67371424551933, 34.395691579388036, 44.27992320829823, 54.57394446096113, 65.28751419436547, 68.63489627838135, 65.600193777392, 64.56684143312516, 60.73390522310811, 62.1567528478561, 62.99633226087017, 68.61781043391075, 65.23705290209863, 66.50311162394863, 62.84809020257766, 55.93458329477618, 52.618666464282626, 59.568274867150095, 61.54763229431645, 65.3148138907648, 62.24170746341829, 66.87030038525982, 67.16167757588049, 65.05526673409247, 60.419209541813025, 63.99346151659566, 61.009196773652114, 64.46717400704661, 55.41361801085934, 56.1562168213629, 38.67702530276391, 46.31917130562567, 61.967459263340125, 60.31687882638747, 65.67174565407538, 65.10266465525474, 62.99661859389275, 62.771439244670255, 62.03111148649647, 62.34471282651348, 62.03333939275434, 61.76305278655022, 60.91243974624142, 57.2447451468437, 56.27998328978016, 58.393434786027484, 61.19495630264283, 63.10172242503013, 62.411271525967514, 62.1685552597046, 62.74527703562091, 63.09907482516382, 66.65100066892563, 70.6884688715781, 71.62242443330827, 69.01098881998371, 58.25026435236777, 43.96385077507266, 30.309299653576268, 26.113253947227236, 12.801418938944417, 14.29407592742674, 9.648707028358213, 11.446404783956467, 21.252611644806404, 16.29030248811168, 11.868581252713359, 16.802617965206025, 12.992451114039268, 7.082698345184327, 5.942734508745133, 3.9808708525473073, 1.4206140800829858, 0.48198194994080457, 0.6199841093151801, 4.788162294895419, 14.448093675797987, 29.813890572517153, 33.690367052632, 21.627054829751295, 27.388779309488115, 32.48334392424553, 40.90617887435421, 54.103056077034246, 54.89684966302688, 56.434728637818374, 44.85884151151104, 18.704814526342577, 1.9166780743868121, 0.10713243196087499, 0.037722449013662916, 0.04177803421513208, 0.022790880175307397, 0.03425066494533131, 0.08446845616544447, 0.07860870325877782, 0.06077451729065469, 0.06907807152357794, 0.03031000825426271, 0.011349673037447277, 0.04533696461529021, 0.012015680192909654, 0.08219204888108277, 0.022882569408524903, 0.037410084323416797, 0.02506500643287455, 0.10421699243447474, 0.040794396472554055, 0.04873796982029754, 0.026545310468082468, 0.0215974377633463, 0.029733802882894397, 0.011111482895249802, 0.027130396713713006, 0.03209527465514839, 0.028554960191550276, 0.005382328827474868, 0.05509855653790217, 0.18014942115593344, 0.13567296097115164, 0.22889023316243004, 0.12485661153351107, 0.20691630340391592, 0.20365258498537928, 0.1172425096193629, 0.07275288038316273, 0.16972245888844614, 0.10450778408877312, 0.1194883116911496, 0.07812388451589693, 0.23147722015217428, 0.13470436536496685, 0.152856512295623, 0.1993877581891514, 0.2270895281746503, 0.13132446205183385, 0.1841400957275783, 0.09766563833240541, 0.10214769702044227, 0.10785014143273716, 0.09421693266279275, 0.14663203258908566, 0.24928487266503999, 0.12089211418623887, 0.22018969599758426, 0.24964871846379774, 2.853614514873874, 20.801986225189705, 53.396617597149266, 65.36656564281833, 70.11243743281211, 67.77839183807373, 56.83154306104107, 39.10031572464974, 42.00101829344227, 28.362225294113163, 50.469646915312744, 50.23586973067253, 39.76736184089415, 24.478690508873235, 5.631553761420712, 0.8370456231697914, 0.44547326382129426, 6.842699791154554, 8.139318189313336, 17.32362639519476, 21.061223514618415, 26.14835916026946, 25.029185356632357, 24.65272803460398, 33.48334827730733, 22.459599471861317, 30.20428799813794, 23.69542064205293, 18.506758366861654, 42.4055205622027, 37.537521854523696, 41.651884202034246, 46.53582342209355, 57.45849863175423, 69.05855148069321, 71.07243753248646, 67.17477044751568, 67.89668267773044, 64.50359713646674, 65.2958139296501, 65.22496807959773, 69.97672342484998, 66.87154769897461, 69.53725322600334, 65.95099095375308, 58.407355277769035, 56.23069870856501, 62.90359174051593, 64.69905276452342, 66.88356584118259, 65.4079152691749, 69.87360431301978, 70.64520512857746, 66.18974562614196, 62.34021386792583, 64.52324821103004, 59.088514081893436, 64.99986325540851, 54.46100373421946, 59.40356277650403, 43.40978853164181, 52.959273322936035, 63.98886842112388, 62.708897052272675, 67.71964257763278, 68.30802948244157, 65.60278254170572, 66.4061035648469, 62.803524232679806, 66.67652745400706, 65.1378640051811, 66.06897584853634, 62.07641486198672, 60.347630208538426, 59.61554335009668, 62.78829759167087, 62.63585075255364, 65.51295242001935, 63.44374525931574, 65.72647056271954, 67.9311603115451, 66.8203450787452, 67.6418698218561, 73.37903438075897, 72.8849647891137, 73.19692657839867, 63.82356797495196, 51.22058076243247, 36.50804481198711, 29.792158680577433, 29.751632751957064, 19.458648966204738, 14.953353789544876, 28.718656955226777, 39.51283924041256, 23.80114224649245, 19.419899871272428, 28.020463297444007, 17.306012991935976, 15.522678955908745, 13.761208211222003, 4.649732045588955, 2.502784243514461, 1.1915801441477192, 0.8802219708600353, 6.538261598156345, 18.012843708838187, 32.16287647524188, 39.80406345859651, 31.465088782771943, 37.92540504086403, 42.33769101481284, 49.82723328375047, 61.350945042025664, 64.88188620536559, 65.62638736540272, 52.91904941681893, 24.149421261202907, 3.2904121087443445, 0.279845851323297, 0.15389240106507657, 0.12578265861638133, 0.11311773135657273, 0.17906554463890292, 0.16992026279049535, 0.16340243269599256, 0.12155142477563313, 0.27281059012297665, 0.20470279959901688, 0.16234356128881056, 0.16626128896830544, 0.15196806480807645, 0.21839910337040502, 0.08100889502994477, 0.12088967036576041, 0.07463601643159505, 0.2328648658529405, 0.1238807304311664, 0.13951429436283727, 0.10769621904699073, 0.1722875970505899, 0.11770243050470469, 0.10434217886218142, 0.10823362972587348, 0.14785800309431169, 0.1600019829047303, 0.09709416738440914, 0.14261874310191602], [0.049754396126034765, 0.09133828067851645, 0.05833488731314579, 0.04358013348293401, 0.021365313122289318, 0.023533577520039775, 0.06078947515737626, 0.047803377026631955, 0.015165963014888187, 0.03382334876204691, 0.02879686011452108, 0.10268940545258023, 0.012202367201567659, 0.008390608634198866, 0.01780348882499722, 0.024183047710046656, 0.08215770515943728, 0.06216875900844894, 0.051984144825368166, 0.08132726584951724, 0.03364128030596241, 0.0436257884927815, 0.03645362738039225, 0.06999040563260356, 0.09972407061967159, 0.0623484411006493, 0.05911071221494387, 0.09493265030605179, 2.3741253537516442, 20.233340609458185, 42.39565580121933, 50.737136871584006, 50.55106355297951, 51.52978512548631, 31.710080023734804, 23.063169871607137, 22.50877226552656, 32.5446270358178, 49.498887754255726, 39.329735156028505, 26.393732832324122, 8.74022529971215, 1.359158629371274, 0.13774239428101048, 0.3748732360620653, 1.3978122391047016, 6.1658766769593765, 15.794695327358863, 14.874785773215757, 9.562466855972044, 13.085217129799629, 11.052508604141975, 9.263467519514023, 7.282536731612298, 8.545874799451521, 7.236997523615438, 20.631092479152066, 26.067852512482677, 33.81292150866601, 53.36162613284204, 57.72819296006234, 62.3040613820476, 66.54677544870685, 62.01759892125284, 60.15281392681984, 60.63046839929397, 58.45366670239357, 59.863080209301366, 64.3935001281, 64.87130757301085, 60.2916972098812, 61.25662772886215, 59.22971940809681, 53.909694994649584, 49.16068138614778, 49.73690502105221, 53.97259412273284, 59.04975321985061, 60.2080762001776, 61.81933487615278, 61.23749440716159, 63.657475210005245, 59.91805614963655, 58.922076148371545, 56.686262392228656, 60.02341101246496, 56.13017620578889, 57.648164841436575, 36.96196894491873, 43.57524979499079, 59.2843109561551, 60.654685112737845, 64.0959491268281, 61.00345050134967, 61.470804829751295, 57.57436544664445, 53.955104274134484, 53.71054057152041, 55.60380197340443, 54.26515979151572, 52.759350115253085, 51.47632714240782, 54.3956962708504, 56.7398694253737, 57.16743915311752, 56.442341958322835, 59.00266124356178, 58.80883339912661, 59.26830768585206, 61.058755920779326, 63.861238418086884, 61.96529411500501, 55.90731497733824, 52.17513661230765, 50.29812559004753, 45.76564642690843, 45.78849815553235, 29.048589083456225, 18.7590197209389, 15.520098036335362, 12.727983343985773, 12.568097729836742, 12.968185370968236, 12.575676729602199, 9.147530101960706, 8.834712255385615, 8.442429150304488, 6.1471841316069336, 3.6280708159169848, 2.495519033362789, 0.4349743352542001, 0.5076863142030855, 0.23954510658739075, 1.4397928767627286, 9.642796997101078, 19.034207328673332, 41.41430231832689, 66.66661170221144, 49.99642472113333, 32.695320575468, 19.66621098979827, 41.737140840099705, 45.92649498293477, 56.23372677833804, 42.69365787506104, 15.932169498935824, 3.438250162909108, 0.10934100215954166, 0.03642304132001535, 0.05561620980921773, 0.02900343189286369, 0.006292345999334489, 0.019655912408545133, 0.005228153632713422, 0.13687329817443125, 0.06420275309093057, 0.1275573472582525, 0.03399577983204396, 0.05992397583360153, 0.019086136430081342, 0.09670851872332635, 0.03727398880366837, 0.06326727163527282, 0.1261518210653336, 0.05413088406766615, 0.0501501111824426, 0.049468936443689375, 0.023081608627352024, 0.0505441561671755, 0.03795816660708478, 0.05292444497406964, 0.06551076778240743, 0.024036912608050534, 0.020362821955894752, 0.05845353901085835, 0.020145429185621684, 0.09835225995630027, 0.06705339307025557, 0.04091844909013279, 0.00876708913804783, 0.021714266171799074, 0.031237351940944794, 0.07621813355193985, 0.06230241453815853, 0.08212873171414099, 0.03685889172277624, 0.02371441065934637, 0.0316808287489919, 0.008431568482680427, 0.03200254737279348, 0.08066955638388473, 0.062029066705896016, 0.09934097303137665, 0.06493378866223559, 0.03146630880843488, 0.013333928861444997, 0.03179053062452905, 0.03220733991193195, 0.057178600165512294, 0.08980019829205929, 0.055312398490646196, 0.06965334992855787, 0.04371041056489752, 0.053138474618355115, 3.433313369750977, 26.17404676252796, 49.17477446217691, 59.888642295714355, 57.93396049930204, 58.38596267084922, 39.49199576531687, 31.015753822941935, 29.03527852027647, 33.92375592262515, 48.35299868737498, 34.717455371733635, 26.65344080617351, 10.115892694842431, 1.5334800366432437, 0.27258336844463504, 1.5678359544084919, 3.074221851364259, 7.753942868401928, 11.23521750973117, 15.416478822308203, 14.365046312732083, 14.025287666628438, 13.322069452654931, 15.101463467844072, 12.668984032446339, 10.393820078142229, 9.473829134818047, 19.77988127739199, 24.049171363153768, 33.584925897659794, 49.139222098935036, 55.71432652011995, 62.62053389703075, 68.85327031535488, 64.33533137844455, 63.54764492281022, 62.30293173943797, 62.02633796199676, 61.48252879419635, 64.43365735392418, 64.08605690925353, 61.77749103115451, 64.75605657023769, 63.410307053596746, 55.32689832871961, 50.77099869328161, 54.06764491911858, 57.95851061421057, 62.451346382018066, 61.080756495075846, 64.68105693017283, 63.561989030530384, 65.57139573558685, 61.386422880234264, 59.21123327747468, 57.442126658654985, 60.16715018979965, 57.4891637217614, 58.03403585187851, 42.951749832399436, 48.95378812666863, 60.07368010859336, 61.49837516969251, 64.4870957251518, 63.962019797294374, 64.36673779641428, 58.58960428545552, 56.97565486354213, 56.01809055574479, 58.57540922780191, 57.46353887742566, 55.68623450494582, 53.99146856800203, 56.892928154237815, 59.53355404638476, 60.166746185671904, 59.45587542749221, 61.406925109124955, 62.27107817126859, 62.009550217659246, 63.92668316441198, 67.57393437047159, 65.4450914936681, 59.424061083024554, 55.874535729808194, 53.55998039245606, 49.9813392854506, 43.15981588056011, 29.733217223998043, 21.68323297654429, 17.026530388862856, 9.100536184926188, 6.090822614008381, 13.415629748375187, 11.643244028091432, 13.1618014074141, 14.40617040280373, 14.504564039168821, 9.80490561454527, 9.145522829025023, 5.665162590242201, 1.5477844303654087, 0.5875427984902936, 0.40254874455351985, 2.0089495037832568, 10.100954348041165, 20.0446726429847, 39.25809698720133, 51.88560685803814, 46.3957477384998, 37.42798182272142, 28.813748936499323, 49.82372668481643, 53.71761652731127, 61.20906899052282, 49.37920055081768, 19.622513824893584, 4.23649710993613, 0.04188971451273368, 0.07034355684393837, 0.04513476719899524, 0.023399759196646275, 0.03203642761124478, 0.03316382749847347, 0.04779879582084475, 0.023950338926947406, 0.034220668772656115, 0.056647509712004857, 0.05132899409340275, 0.008898649417284516, 0.02304874345540039, 0.046397801037997975, 0.06897788254484054, 0.0734471628863004, 0.024958278893703417, 0.04390214705058644, 0.03672707480408492, 0.0021355335305880516, 0.06212303505068826, 0.04535841507717006, 0.05556879662758401, 0.03643753187310311, 0.049461677760606816, 0.05975851999415506, 0.06785272154957056, 0.07167402940291552, 0.04726885066878411, 0.16391125297354114, 0.2592803435700555, 0.14448353900544106, 0.16993829650023293, 0.11272002447156176, 0.0637515158122105, 0.1806856367376543, 0.17634536560264327, 0.14102246101585128, 0.23838618409729775, 0.11053053752308893, 0.21532751980327794, 0.1628287094494989, 0.0753006589929423, 0.15394320801621483, 0.11157307593572525, 0.19626817155268886, 0.20904369892612581, 0.10478610383166422, 0.10927323402175981, 0.13451036125902208, 0.10875736573530782, 0.12440893273319929, 0.15730673236952675, 0.2576928561733615, 0.1458356841917961, 0.14875061810016632, 0.1419731148428494, 5.511018345432897, 32.236258137610655, 55.901329440455285, 67.50915250470563, 64.57126194430937, 65.27887713524603, 44.3878903696614, 36.62371550836871, 31.331573263291393, 42.785217761993415, 64.64568891832906, 47.46960639953614, 32.993812945581254, 10.647865130055337, 1.966927190942149, 0.3233206055818066, 1.4716935133741749, 3.209994449730843, 13.69285208563651, 28.344107866287235, 28.742665783051525, 19.021873435666485, 23.512193003008445, 19.147842314935502, 19.883135710993123, 20.782752883049753, 17.33656825557832, 14.475563014707259, 28.821585832103608, 31.252094276489753, 36.56688036457185, 55.93956470489503, 60.08095218289284, 65.21864521887996, 69.5609208076231, 68.41907178201984, 66.50435893766343, 66.41441114487188, 63.64701817112585, 64.1890505052382, 67.18237984564998, 66.38144754594373, 62.73304708542363, 66.36673865779754, 63.09065349640385, 58.545508999978345, 52.69350136480024, 55.030994722920084, 58.87922033186882, 65.20261841435587, 63.034151754071644, 66.33779156592585, 65.12388860025715, 67.6081217488935, 62.046008648410925, 57.48406856290756, 57.79104501970353, 59.59373889430877, 57.140112000127, 56.70442296612648, 47.45641546864664, 56.507963211305686, 60.558143815686634, 64.9330613690038, 67.31471277052357, 67.78761725271902, 64.17312960470876, 62.39318939947314, 58.620618466408025, 57.952438785183816, 59.47735824892598, 58.83482694625855, 57.57460078885479, 57.2284516211479, 60.93229870642386, 61.967047414472034, 63.05837631225587, 61.359182019387525, 62.548032806765654, 64.10775153867661, 63.52139249924691, 67.13176558094641, 71.39750003814697, 69.62719317405455, 64.33454298203992, 59.945069513013294, 53.75995851332142, 52.99422556354154, 51.6424395192054, 35.08398909722605, 23.31875543440542, 24.96243053866971, 21.303294550987985, 19.330646338001376, 22.708001213689005, 18.650585797525224, 19.55357816911513, 15.753577120842474, 14.920752029265127, 16.17453863543849, 10.9073358005093, 9.157003606519392, 2.0636239119114417, 1.7207315371882532, 0.5866611845070316, 2.54915572943226, 12.494059070464104, 26.33989437933891, 51.81673003781227, 76.46789304671749, 59.924445690647254, 43.391624035373816, 32.90276100558619, 54.20706948926372, 60.800287415904386, 69.78095008480933, 58.234335607098, 25.617076081614343, 6.346741087975041, 0.34527319213075025, 0.20612327982821774, 0.13570974851327558, 0.13380606598671407, 0.08726697535284104, 0.14915047003136528, 0.07106655232247806, 0.252031788169857, 0.12909005936836043, 0.16494617647221013, 0.18230816499600488, 0.23296159211426015, 0.1246784118214442, 0.2007700412744476, 0.21586281607948968, 0.22809049865651518, 0.15469112433493137, 0.1742347474059751, 0.13047811875660575, 0.14507189453128846, 0.1333854530727671, 0.16172900555595277, 0.3229744257705827, 0.0885825245190532, 0.24187954503201672, 0.12083534707104969, 0.12744558269097922, 0.1736728985223078, 0.25056929567888864], [0.012192556488087342, 0.09695931292709806, 0.023040195829385234, 0.03669871422912806, 0.010008113270985984, 0.06435524672269821, 0.06304414852732612, 0.07534254868064197, 0.05108072031890193, 0.026207699350291686, 0.047361539646742806, 0.05477831263335482, 0.032113890591708404, 0.01911311230111507, 0.030177785308971524, 0.03498329397951884, 0.04597859389539208, 0.0542888552280924, 0.08466301185469474, 0.0552691413360017, 0.02197991865086219, 0.06688221838445434, 0.02491376918530272, 0.018965337770960985, 0.08990021873145335, 0.06769688394401344, 0.050801159513573495, 0.14869202769571735, 8.604616215152125, 25.059928894042972, 44.66013816095168, 57.06230394301876, 49.092334085895175, 45.33361696427869, 28.78621978144492, 20.110860678457446, 27.42025633012095, 37.92669942302089, 39.21412329519949, 36.46509093623008, 16.83450879589204, 4.924578897414669, 0.4085190822520564, 0.1576760480360639, 1.2764979874895466, 1.9101306579766737, 4.410792531505708, 8.192656540101575, 9.463271094906716, 16.0011943886357, 10.40549599355267, 7.426907410544734, 12.8685865863677, 7.351359128952027, 5.284198955182107, 10.746242096347194, 29.757057389905377, 40.2307741872726, 48.61922171808059, 56.446687944473766, 58.656010012472834, 64.1346707651692, 60.64537340594877, 60.181274644790165, 56.888668460230676, 57.1304629695031, 60.30005185834823, 60.61694406693982, 62.821814244793316, 64.5516344039671, 63.07692912317092, 61.82368478467388, 60.87139606475831, 54.01003706839777, 48.35861944383191, 49.103477539554724, 48.64724705296178, 52.11876038582095, 54.348906317064845, 60.17532440923876, 63.10915923887684, 63.67797743889594, 59.779392519304835, 58.21633977274741, 58.18215631669568, 56.03050485734017, 54.570280967220185, 51.643471102560724, 35.313573268152055, 39.23176611623457, 49.524649881547504, 60.127808816971324, 65.02311506579, 63.627080763539965, 59.297839210879424, 54.674663082245864, 51.55430778380364, 47.21908461663031, 49.05303193676857, 49.17219354260353, 50.89835413040654, 53.56554623573057, 57.415258422974624, 60.82666143294304, 61.495370634140514, 61.43793536770729, 58.01277268317438, 58.13513102069978, 57.034125635700846, 55.51873753147741, 55.3287692992918, 52.896825267422585, 53.47345682882494, 46.19691494972476, 38.84065874161259, 30.379296310486335, 23.4945168418269, 24.65575022082175, 15.784960985183718, 15.770588440279807, 9.83426651647014, 5.586871591306502, 12.808958715008153, 17.631202974627097, 11.62705836757537, 21.086261964613392, 19.536506052940123, 7.384218785070605, 5.940651730183633, 4.708206249821571, 1.8983697987371877, 0.3437087180153016, 0.27368972198136393, 0.8856532278080141, 5.1423650691586165, 15.720458588292523, 23.552140382028398, 39.504967043476725, 32.96001780417658, 22.893392039883523, 27.121316809808057, 44.62391507241034, 45.41877162071967, 51.53096575890818, 40.1499576722422, 23.50751949894813, 5.488807434035886, 0.25393956160593417, 0.04978505496476447, 0.033596571414701404, 0.015593916008759652, 0.012401235965831627, 0.06635009371224912, 0.08325326451731306, 0.05253455601632596, 0.14209096980912073, 0.021211482667093797, 0.07533522488008584, 0.08467336936343102, 0.03914793562744895, 0.058783569688638376, 0.042974544809229916, 0.030022731028316967, 0.06148580694571138, 0.0346163570159866, 0.014205310782868297, 0.045489423773101265, 0.01542236306704581, 0.06765176136527332, 0.08139601457984218, 0.016929355690315846, 0.022797083572274255, 0.02602806513858659, 0.03969398011723834, 0.04192296655908708, 0.02551240561109397, 0.040948054557966615, 0.13423410995352653, 0.028569789738544536, 0.09440997915883219, 0.039462364924651, 0.024951186834744392, 0.015265360050233863, 0.036638921066637964, 0.010387546086173144, 0.03951863025224978, 0.04975425056932915, 0.02739784375373875, 0.05001352536642263, 0.03947997345559059, 0.013437848688373643, 0.05522357825670512, 0.07836078188472217, 0.06547247104707264, 0.04295918857678772, 0.102297842592722, 0.025421409687447934, 0.08078080767224874, 0.020098019834427584, 0.0439698079360589, 0.041485024736292904, 0.07885443362137003, 0.0382910241493054, 0.30390946975638794, 9.673618981915137, 30.168327708398145, 51.69462665434807, 64.84718891882127, 53.44782413974885, 51.402574816057765, 31.44110937272349, 20.193636417388916, 22.477967931378274, 31.645264817822365, 38.99580809377855, 37.032795183120236, 17.413078008159516, 5.897449764513201, 0.40675842834095804, 0.9551211001892245, 2.5469057598421654, 5.395854125099798, 10.963199177095968, 10.387217748549677, 10.20581401163532, 13.41750660250264, 10.362494068761027, 11.326226303654334, 16.90489180626408, 9.800263489446333, 8.598980749807051, 14.694848022153302, 28.09535114995895, 35.94580834911716, 49.937797054167724, 55.334570484776656, 60.30812801853303, 65.09189774913173, 64.46602083021595, 64.15977785664221, 61.709339849410526, 59.45901332363006, 62.509538665894546, 62.74095458369102, 64.80845943573983, 65.74863195419312, 63.86996569172029, 62.58785270875501, 65.69922185713246, 56.58310405669674, 50.08025753882624, 49.72992712451566, 50.53793538001276, 53.84812555005474, 58.585779974537516, 62.21902831908196, 64.3748414131903, 65.20337150942895, 60.86575961882069, 59.19276675870342, 58.61022810782156, 57.41027309048561, 55.681613952882834, 52.46990665312737, 39.80154921931606, 45.05846661906089, 52.72887722138436, 61.59164913239018, 65.83066048160677, 65.27754745175763, 61.53559061788744, 57.33732877239105, 54.046060116060325, 49.55087877088978, 51.843539437940045, 51.778926234091486, 54.52165142182381, 56.600939073870265, 60.19571681176463, 63.58613514131116, 62.87046340204055, 62.566075709558305, 61.78417474992814, 60.907787815217056, 59.94703069809945, 59.52243804931641, 61.15748197801652, 59.57029881015901, 60.00066911020587, 51.96508584483978, 40.887555460776056, 31.899952157851192, 25.019344129870017, 24.02384069658095, 18.67454363453773, 15.410486421277447, 10.826374157782524, 10.752047204202222, 6.796676170441413, 13.038460516160535, 7.767981031248647, 12.619718082489507, 9.736954473680067, 8.504822292635518, 8.996957175193295, 6.541446072439994, 2.4637323906344752, 0.8375488510054927, 0.188621265753623, 1.1167035684470208, 5.683800712708504, 17.171409014732607, 28.4278759648723, 48.41376796845467, 42.10574949941328, 30.5126823917512, 28.360615161157426, 48.655915491042606, 50.83631400139102, 57.85707027681413, 47.951869656962735, 27.45316697705177, 7.289560225702102, 0.3140320652915586, 0.0721209574370615, 0.04699971632010514, 0.060809653913301814, 0.09734777313086296, 0.058663309206284826, 0.041457012731341586, 0.11716689674123643, 0.04596513373056247, 0.12255071752494383, 0.1277804933488369, 0.021496963416857105, 0.031178786434353362, 0.05506925750523806, 0.03889457119869129, 0.0337734496250989, 0.01629151663021936, 0.053252621719072905, 0.028540406436208757, 0.030375028051616206, 0.05504305729822767, 0.06659215451368401, 0.04772435888768204, 0.07976780960997266, 0.0635327938793888, 0.01820173005633537, 0.026872822631811424, 0.028252146702500123, 0.10154142269804593, 0.21151154392188598, 0.25960210049825333, 0.17027414944623748, 0.12838453069449435, 0.109715688102428, 0.20662053217810972, 0.12274612357179004, 0.13762798671039844, 0.10413668343737241, 0.1571740306192829, 0.18851804306670544, 0.15521040937352568, 0.2711229597128207, 0.18114734260785967, 0.15107037830016307, 0.22005962958979994, 0.25438456675939025, 0.11315778243325411, 0.13835619924770248, 0.17885430355466184, 0.09015322692932622, 0.16004515962014276, 0.10501420651111873, 0.06575128108623528, 0.18729179676982666, 0.16834884791845278, 0.12070728015274772, 0.5668505185073422, 13.288922482921233, 37.82002664381458, 59.57988900523032, 73.15425903566423, 60.75027327383719, 57.538522828009825, 39.77510852198447, 27.188820800473614, 38.69526040169501, 48.90230701815698, 50.971529868341264, 44.55474015205137, 21.997291272686375, 6.8621998544662235, 1.0790854644390846, 0.9015687350784579, 3.449630184519676, 6.021157887674147, 15.35074087881273, 16.569231056397964, 19.99742769425915, 30.399251368737993, 19.265999794006348, 17.460479851691954, 21.669720411300663, 15.843409203713941, 10.883699597850924, 17.573573550870343, 34.62785274751725, 45.00905259963005, 52.09983102736935, 58.849229889531294, 61.31036027785271, 67.54469702320715, 65.32647509728709, 66.00995986692368, 62.1922306860647, 62.69374101392685, 64.6970445109952, 65.22551328905168, 66.39396775153376, 66.44423684766217, 64.09326230326008, 66.53908760316911, 67.90726523245534, 58.522794554310465, 53.0417097768476, 52.608793858558904, 52.49366052689091, 58.049674341755534, 59.61642980575562, 64.63944450501474, 67.07172193834859, 68.03826455147036, 62.662311061736084, 58.8544427194903, 57.11430672676333, 55.6339846118804, 56.13194911710678, 53.5737322222802, 44.794075335225756, 52.80586158075641, 56.4796946894738, 63.294726571729115, 70.10789532815257, 67.41714154520344, 64.90028212147375, 59.545148572614124, 56.68534063523816, 51.23108094738376, 55.48044735385526, 53.248661871879335, 56.53196811676026, 58.417486759924124, 61.520081566226104, 65.32283121539702, 64.17993491695773, 64.16332760164815, 62.53974876096172, 62.61532106707173, 64.00101600154754, 60.2032163835341, 61.10292573128978, 60.783707557186005, 64.31093815834292, 57.14695261370752, 49.33903155788299, 39.01646721747614, 31.699415099236276, 29.080799587311287, 20.730624583459672, 24.145881322122392, 18.17021704489185, 11.972587800795033, 22.043657610493323, 26.328850946118756, 20.32414544013239, 32.41701468344658, 31.648185022415657, 16.487822263471543, 15.165036263004428, 9.356899357611134, 4.5180320932019145, 0.6876609294164566, 0.5035901646460257, 1.5394607931375506, 6.78907952001018, 19.215077623244255, 31.241380322364073, 51.29043033046108, 43.35795440981465, 34.70664139716856, 37.84927575818954, 57.84090226696384, 57.93187379837037, 68.27887058258057, 55.47711726157896, 34.31738538126792, 9.816853154090143, 0.7418590760038746, 0.17639989574109355, 0.155070016100522, 0.21884104417216396, 0.2353087935837046, 0.1860016587400629, 0.19074349784322325, 0.26796103905766244, 0.21865186642014214, 0.30741144151937577, 0.21771080401395598, 0.14222089832107868, 0.13057256207591103, 0.1781411829494661, 0.09547039040274198, 0.1204736463184799, 0.10174477307666695, 0.09375524211434588, 0.2273148193114227, 0.12530940780115704, 0.24379565350471005, 0.1629875654414777, 0.22633695404135415, 0.17295424676229879, 0.15330257465041455, 0.16370427133815904, 0.18815344650178187, 0.21405581384897235, 0.2952034627237628], [0.03494683968564195, 0.04593819424870514, 0.05095295217489043, 0.016320080218476155, 0.023800624279125084, 0.03495657283271994, 0.04885330818773759, 0.007814176788087934, 0.05284755655954923, 0.001204330795688645, 0.034386634060572234, 0.0873178129474963, 0.04927737232778342, 0.038021234795451164, 0.05621070552977824, 0.041510094963614984, 0.01845517492432508, 0.024163491400559584, 0.03681492210636216, 0.038930642448606036, 0.03569189849640093, 0.0653436380408464, 0.06018551059007164, 0.09590731332859687, 0.04180981920311048, 0.019956134605191408, 0.08108714325053078, 0.45334405115535187, 9.592523978602502, 34.53739896897347, 53.29307486934047, 58.12962009060768, 52.075033803139966, 41.70933908031833, 38.05266241873465, 34.33464381002611, 38.463354187627, 47.401317934836115, 32.63242340856983, 20.519828565659065, 9.520875023257348, 1.6084864182818321, 0.1472537589049147, 0.6934421966152807, 4.212685381212543, 5.354152956316549, 9.002360240105661, 5.708130684591109, 11.405665086161706, 8.77400573222868, 10.893192714260472, 10.516711858011062, 20.33080562468498, 13.794415977693374, 14.650789999192762, 23.47943336732926, 39.15601338109663, 42.12824821472168, 59.23769358665713, 60.33036393503989, 63.687967715724824, 61.59448500602477, 60.29142264396914, 56.9465861781951, 58.83123797755088, 58.10118290685839, 60.008235362268266, 60.16045862628568, 63.642982052218535, 60.49600170504663, 59.2027295789411, 59.29261853618007, 59.098163112517334, 48.718818541496034, 47.284246952303, 49.127957051800145, 51.55387240071451, 53.51329242029498, 55.494509050923014, 60.41905264700613, 62.70832830859769, 63.01089209894981, 59.23787401568506, 55.82298401863345, 55.325760841369636, 58.350308325982866, 58.648377080117505, 42.95321287647371, 30.212681870306696, 35.98028598293182, 51.84332762995074, 60.398566107596125, 63.43539061084871, 63.99004905454574, 58.09070233375796, 52.82534007103213, 50.387214383771344, 45.28257908359651, 48.9880657196045, 47.50342507516184, 48.218845782741425, 52.01867326613396, 56.5222563282136, 57.0997743452749, 61.9729035131393, 62.72330784028577, 60.96679595208938, 62.25700078472015, 61.578681776600504, 62.60954733817809, 62.27570264570175, 56.20277535530829, 50.84258587129655, 47.45845117876607, 47.87648170225082, 43.48136786491641, 37.81928923822219, 24.7531936630126, 18.004791082874423, 15.262316926833122, 9.630344452396516, 7.958979375900761, 8.108077981779653, 6.372762581994457, 11.561045858167834, 11.920758581930592, 10.000429884079965, 7.60432650966029, 9.715121580708413, 4.516839202373259, 1.7230572575523009, 1.0027321163685092, 0.44171563319621554, 0.2651865443875713, 2.8638129224700313, 8.213356358389701, 24.64349477521835, 32.14104652404785, 40.035267568403675, 22.999282306240453, 23.426787314876435, 30.76146068111543, 37.600479818159535, 51.9262465353935, 51.88390454938335, 31.94190779039937, 9.143584197567357, 0.7513694140699603, 0.0414981248397981, 0.048046801464572075, 0.030776678374217405, 0.020773395287594008, 0.0412829996897809, 0.011273470271619098, 0.0763586723816491, 0.03020599841200296, 0.010981359030871142, 0.05960066374691744, 0.028097504194104866, 0.0702198566268048, 0.008242569803710907, 0.022307306325303453, 0.01576350872299724, 0.08824209036726145, 0.06004789438579352, 0.05892115907983915, 0.06686338028239627, 0.07647227555994066, 0.09176873016141116, 0.03676520683051598, 0.04196888586926845, 0.09017247871886339, 0.013356137750369888, 0.02483458250700947, 0.07628871323240381, 0.02283694695741419, 0.06026804124215438, 0.08226498045147428, 0.026347682766255834, 0.03844583136660438, 0.049985088182673346, 0.06456969771534204, 0.03086961250031187, 0.03580656270646761, 0.03336589851026093, 0.022459200493270354, 0.020776298760827032, 0.06323375528858555, 0.04707365146567745, 0.06979774218052626, 0.08247697230188117, 0.09052513963392667, 0.0017300015362355138, 0.018088925524704882, 0.018280999089080482, 0.009208998338679874, 0.030837398503095876, 0.046556235681618416, 0.07825547543865058, 0.08230021283511194, 0.016403384619362412, 0.04112602827409583, 0.0324313516818708, 0.5605098232626915, 12.168010088705248, 39.65613911228795, 58.735590980898955, 63.60088717552924, 57.76387868389007, 47.16929797203311, 36.15518446891539, 30.615858377948886, 34.225162613776426, 40.70989562619118, 36.75167891287035, 22.01372012015312, 10.369816153280198, 2.521011252557078, 0.16841778050987952, 1.2137974293962603, 3.3509198167631706, 8.863715241032263, 10.611910723870801, 12.219401963295477, 13.016603108375305, 17.588319701533166, 9.302870669672567, 13.396086538991621, 19.17995672072134, 10.097114347642469, 9.507355593865919, 18.094595709154685, 33.71541530855241, 40.69986612566056, 57.85945900024907, 61.260236309420684, 65.5474731999059, 64.23682889630719, 63.24115876228579, 59.6489344873736, 63.15136001956079, 60.678466443092596, 62.36692520879931, 62.356864329307314, 64.92267101041733, 61.05035028150005, 61.21747462980209, 61.807540309044626, 62.276294923597774, 51.29811425362864, 48.988967864744126, 51.76313477177774, 52.053499990893954, 55.73667226299163, 57.2696953435098, 61.63217506101055, 64.52273438053747, 65.66756832984187, 60.05635107717207, 57.58952148499028, 56.41374787976665, 56.52102078160932, 57.856415240995354, 46.582829106238584, 34.71102268465104, 42.29432921255789, 53.67810257019536, 62.40075172916536, 64.85338626369354, 65.25983010568928, 60.84332366143504, 54.49849767069663, 53.32124925428822, 48.55338081236809, 50.489345058318115, 50.84837921204106, 52.81202754666729, 55.07370148935626, 58.76714252656507, 59.664153283642186, 64.77443287449499, 64.82855373813261, 60.99767677245602, 64.29108312053066, 61.49753578247563, 61.778373564443285, 61.72835157763574, 58.241631215618504, 54.56023577720889, 54.20078585224768, 53.39575075334119, 49.05813101799258, 39.69500195595526, 24.94672929086993, 18.413843301034746, 14.12134357037083, 9.376866182973309, 8.632290497902902, 6.674267822696317, 7.90264335370833, 12.302353228292159, 11.16388136340726, 12.207476977379093, 15.361195956507038, 12.425452893780125, 6.879837772538585, 4.079128431697046, 1.366361449322393, 0.5688291703981738, 0.49223101127051544, 3.1704206764698033, 9.528060805413032, 27.206504806395504, 35.070041148893296, 38.93718827155329, 24.604833933614916, 29.465417400483165, 37.45405773962698, 44.7698546994117, 58.07342821551908, 60.18989993679909, 38.823435614185954, 12.0155014722578, 1.1551261260624857, 0.033797872508124965, 0.07056505584548559, 0.04760959891662483, 0.08273970981639239, 0.059940174762760444, 0.0174057187377325, 0.03377540697974544, 0.03548059995556551, 0.06524669727490795, 0.08223501109187642, 0.036692122042539625, 0.09620198904867135, 0.04404292719799184, 0.041501545422380014, 0.005513993486191237, 0.12644323325085063, 0.030361261451616887, 0.019842581222614935, 0.05344598614160092, 0.0189695818980615, 0.042152930832197594, 0.05193942444278829, 0.08102136694135205, 0.011167491583393948, 0.043615350544813185, 0.038968582953056025, 0.0935463835635493, 0.06859204236177668, 0.14823186932311905, 0.1573626874315162, 0.13069012592877113, 0.12346530393246682, 0.2175199102249838, 0.17196302091883076, 0.2518184786482204, 0.07431453529505, 0.12309431053337552, 0.08509002926368868, 0.07207855447045258, 0.22935927815495, 0.12592852175716432, 0.1610061096688432, 0.22930588182662764, 0.1722599106330064, 0.07410205314837157, 0.062156578210452874, 0.12921753639896072, 0.08669320614107194, 0.11942176163316735, 0.1468803829723789, 0.2751914075305385, 0.24785264064708065, 0.1266922654523965, 0.1624929024687698, 0.22056068173579632, 1.0281369402523965, 15.80741459323514, 45.89001301796206, 66.24484708232265, 72.52744859264743, 66.5206132396575, 55.67025084649363, 48.31360632373441, 47.0334662929658, 51.88930565311063, 60.49932395258258, 43.68219714010916, 25.79188435308395, 12.900974577473058, 2.3838373874464343, 0.5560327441461625, 1.7671167514016553, 8.686216223624445, 13.20293922578135, 14.837536984874358, 16.560913670447565, 20.31410809486143, 21.274790686945764, 20.989359809506325, 25.158305860334828, 31.169755881832494, 22.075403313482962, 20.956176557848533, 26.02661075130586, 42.33701244477303, 41.54038298514582, 62.206037429071245, 62.9511034104132, 65.81104863074519, 66.52452776508947, 63.79622905485092, 62.542647392519065, 65.38037238582488, 64.03955721086072, 64.64330019489412, 64.30844353091332, 66.50314300291001, 61.300923055218114, 61.6025140977675, 62.87434654851114, 63.68436697990664, 52.519528558177335, 51.802907605325025, 52.02112866986183, 55.60225655955654, 58.840561451450476, 60.304774392035704, 65.08600634913292, 66.51884817307996, 67.89292504710536, 59.97584442938528, 58.443762717708466, 55.907373812890825, 59.1036505083884, 58.598637503962365, 48.80698950059953, 41.71861940814603, 46.708356718863214, 56.65044330781507, 63.78633683727634, 67.40216593588552, 67.92120533604776, 63.938666005288404, 57.553749469018754, 55.18122150051979, 51.1425805091858, 52.30852073238742, 53.26717545909267, 54.3210574888414, 57.31480652286161, 60.34089549895256, 60.582584104230335, 67.55520113052862, 66.81399868380639, 63.88657692940005, 67.8822797344577, 63.52885284731465, 66.37736043622418, 66.47130120185115, 60.916526855960974, 56.82347866796679, 58.35145365807318, 57.904927115286554, 57.88897875816592, 47.231149827280355, 32.04370898585166, 24.523813455335556, 20.3572129818701, 14.33029313241282, 11.673595328484813, 14.321185388872701, 13.400282494483458, 19.3873873449141, 19.816306367997203, 16.54791101332634, 16.41906605612847, 22.761890657486457, 14.016312303081637, 4.731145251181818, 2.283402157406653, 1.0256485641002655, 0.5648963201430537, 4.17192607156692, 10.966379238713174, 30.769968302019183, 41.047745058613444, 53.086499321845274, 35.05737581560689, 37.1021976009492, 43.789120951006495, 51.59587314051967, 65.32648294202744, 69.15109588253883, 47.01710608697707, 15.659261768864049, 1.7694695606347055, 0.2339173021215585, 0.16452750942159086, 0.1464664350233732, 0.20559319294989112, 0.12553584040893664, 0.12774352960649038, 0.21465468010114086, 0.16792648832403845, 0.16805019620205128, 0.1870371797873128, 0.10686609383311965, 0.19633566389881796, 0.1274718518459028, 0.12217539572908033, 0.11719429970628793, 0.3564097203554646, 0.1835740793256029, 0.1037782692019978, 0.2588193118572235, 0.14542329906215593, 0.10652176795467254, 0.13836067320118028, 0.1402250860607432, 0.16785302049209996, 0.17798707670261785, 0.09000505020301189, 0.17028269898747245, 0.15018217596075228], [0.0823537393983814, 0.014184715466633921, 0.055654744031809034, 0.054193906290757085, 0.013867848094612842, 0.06941607717664973, 0.04978364153254417, 0.018321124859334483, 0.017946433170788714, 0.002030223972284265, 0.0678416132746685, 0.024588434626498533, 0.10058280921751454, 0.01704612855739411, 0.04045630271937098, 0.05938092291715646, 0.06875406229688276, 0.08155219692496524, 0.056016854641418305, 0.004662521711115035, 0.0242817772912883, 0.013686714265795966, 0.04617725964635611, 0.06588420500197718, 0.05941302583162343, 0.009490980939458936, 0.03229775743919515, 0.51814871569795, 14.079599745811956, 31.905906315772768, 54.763159598073656, 55.42443590779459, 43.35826035468809, 32.80060091326314, 29.12543615987224, 24.92889427369641, 30.713898020405924, 37.23349109772713, 30.020772064885787, 20.712446358896074, 3.969977449986243, 0.8117781435289692, 0.0789897860358319, 1.3990345477096497, 2.0538552489972886, 5.297505595991689, 10.645501902026515, 10.922860541651326, 8.132580047653567, 13.170703226520171, 7.107478899340476, 9.781089963451508, 17.589366974369174, 8.9971689831826, 17.804154003820113, 35.55217889047439, 46.7136009277836, 53.48879329619869, 65.79673982435658, 61.949188863077474, 64.68483809501895, 62.92778491973878, 61.192661716092026, 58.68008159822034, 58.09253408062843, 60.890584299641276, 64.1447747907331, 63.70014667510987, 62.595222842308786, 61.73488624634282, 63.268646732453384, 60.50236378946612, 56.84493011043918, 46.08635902404786, 45.232223695324315, 50.933608393515314, 56.01681970780896, 56.6482271686677, 56.940690855826105, 60.15848959645918, 60.573135114485225, 63.767815405322665, 55.992857948426284, 59.10691784274194, 57.58319077953216, 60.28491935422344, 49.785405128232895, 32.93651103973389, 33.51202080326696, 35.62571940883514, 53.72140553689773, 61.68107524994881, 61.62377726647162, 59.26147099464171, 54.309615935048754, 48.13618183135987, 47.472312834955034, 46.67505579610025, 46.54589999106623, 46.72050429928688, 46.08787698130454, 47.53010503707394, 52.27228979910574, 54.654074561211374, 55.86628698533582, 56.0888461912832, 54.61471749890236, 57.361576864796305, 60.73540356851394, 62.09278683508597, 60.490361336738836, 64.93752894863006, 57.306777431118874, 55.53498791110132, 45.88602004512664, 44.11208106625465, 42.073750803547526, 44.7095835593439, 34.63306165510608, 26.53404385812821, 17.523567253543487, 13.851157965198642, 7.919879228838029, 8.792345754561886, 4.231430388266041, 8.368375782043703, 9.316185155222493, 11.33384943008423, 7.669070622613353, 4.012000498271758, 4.14212929625665, 0.5041265794106069, 0.45196058829465224, 0.2690484242573861, 0.9246832625039163, 6.027358664620308, 12.340366878817159, 29.890855320038337, 34.46015573317005, 19.677654504776, 21.863985600010043, 28.28057919779132, 39.819721560324396, 45.71365933264456, 53.29965660648962, 36.56598998654273, 17.68497866968955, 2.540186739736988, 0.14681057704071845, 0.04882528086102778, 0.09632828630386822, 0.013073990440687105, 0.04475928452466765, 0.06511521360446369, 0.04928949566918516, 0.046534708610946135, 0.04969520434256523, 0.03313561631066184, 0.004409335876604723, 0.04829691001965154, 0.01352543169031701, 0.06199373090038858, 0.05424347600989765, 0.010546411654250997, 0.04181765245213624, 0.014485076516716471, 0.04126779667492356, 0.1207463276542483, 0.060696391644136566, 0.022127825331183213, 0.04286173070150037, 0.013705357015433331, 0.003089592857812081, 0.021694506849012068, 0.04259028276729007, 0.04191841599681685, 0.09421324011899772, 0.0391143158588919, 0.04403247009782542, 0.040340573647089546, 0.021628088941196763, 0.021942539305816737, 0.023950365740024758, 0.035120477344119744, 0.03864156683125804, 0.04506846611958839, 0.09756850604448589, 0.07477247967354714, 0.00831576471682638, 0.06593316568121796, 0.03536425035206541, 0.03282621255024307, 0.014018495454482976, 0.05644877118268802, 0.03563200191204106, 0.027842157512843132, 0.026571688790535255, 0.05117001552735606, 0.012634306725475096, 0.05758615511078989, 0.07539765338503546, 0.030159809055828282, 0.044659712246709296, 0.7249423224599131, 16.748677530596336, 38.38481264729654, 63.246661847637554, 62.219212670480054, 49.778968518780125, 37.10731629402407, 36.36734547153596, 31.076321101957756, 33.24102817043182, 37.74783542079311, 28.565413874964563, 18.58388000918973, 5.528650870246272, 0.7372623033100559, 0.30637382139121333, 1.453369548243861, 3.529403349084239, 9.799178954093687, 11.731492454005826, 12.756446023141185, 14.307859136212258, 10.987361957949977, 10.52760329938704, 9.994058974327581, 15.794561966773003, 8.366821542862924, 17.864327084633615, 29.50126001911779, 42.82613200526084, 54.00392993803948, 66.61753500661543, 65.42980993947675, 67.03478890080606, 64.4191445842866, 61.28597490249142, 59.30751177572436, 61.42198308821648, 63.30864314110049, 64.89164506235431, 64.3374926044095, 63.51607768766342, 60.75437607303743, 63.1559491926624, 61.80887391490322, 59.50979232788087, 49.27379469717703, 46.98773537912677, 51.109624754997995, 58.76758967676471, 59.204612316623816, 60.50463876416607, 62.47188391224031, 62.66936740567608, 64.24774485249674, 55.84719680970716, 57.16543874432964, 58.42257407403762, 58.68563959675451, 52.12654629061299, 38.57922100251721, 38.86658953082177, 41.759784683104485, 55.698268336634484, 61.50981280111498, 64.27107903265184, 60.99051844689154, 56.91866282493838, 50.74594259262086, 49.662834982718195, 47.27806137454125, 48.568383878277196, 48.37796457352177, 49.71719903330649, 50.49261631504182, 55.08896735406692, 56.95234813997823, 58.75166877623528, 58.56726246495401, 58.54771337201519, 59.911803891581876, 64.04839431085895, 63.13542342955067, 62.11291251644012, 63.78301066737022, 58.31585814875942, 56.101660574636156, 49.36058105960969, 50.573993729006865, 51.10782830945907, 48.025480777986594, 37.91010779719199, 27.669681810563613, 22.102987381719775, 15.74770631328706, 9.30388460236211, 7.8800833513659825, 8.876664946156165, 12.404551563724397, 13.900168961094273, 14.75178808935227, 10.832926477155379, 10.69901381769488, 5.733442229609336, 2.9280694357810484, 0.5600571572299927, 0.2792098757720763, 1.28945394389091, 6.544865888933982, 16.07212260846169, 32.98308918553014, 40.709879936710486, 19.430374560817597, 20.196807653673236, 31.911738880219, 43.87047875312067, 51.63071555476035, 60.03499769395398, 43.48803589420934, 19.713244130534513, 3.4800694930937985, 0.29794133839107334, 0.06974416199110209, 0.022799245855440537, 0.027278224870021787, 0.030454046190566117, 0.00935676808078443, 0.03903545093752685, 0.0386979892068813, 0.029349856852223317, 0.05999830551445485, 0.019209172065940597, 0.005801630773461394, 0.01795047236936948, 0.06737777768003364, 0.04189328065202121, 0.08219691353940195, 0.018159878673031926, 0.03126968276656924, 0.04338597998984399, 0.048658365624085556, 0.049741590966380415, 0.036053361761714184, 0.054979196208859646, 0.04653875355518634, 0.028718293967446493, 0.0183521973855433, 0.06525272638687203, 0.05022842452050217, 0.14659400398452438, 0.11237985078966427, 0.15931935259892097, 0.1474553319595514, 0.07898927275692263, 0.13223745499647435, 0.15903113500004815, 0.08251381347015982, 0.09706292631885699, 0.08079460491576503, 0.15646123177101537, 0.12681945136958553, 0.17365434387278172, 0.17247412413839372, 0.1254064558194049, 0.14373694035795428, 0.19059291560082667, 0.20692298369061565, 0.1470822318186683, 0.14982701759905587, 0.09533107731371157, 0.10870103529023548, 0.14782365171178696, 0.16898617178442019, 0.13322238359720479, 0.08683015201841632, 0.13734686308570448, 1.7014045484604376, 21.617176340472316, 46.569006673751346, 71.98205086492723, 67.73104883009388, 55.26959642287224, 45.502745643738784, 42.21013161443895, 35.54981762363065, 42.98812197100732, 50.56735707867531, 38.57834631396879, 26.257275535214333, 5.858437380483074, 1.3725999790814616, 0.32199368000991885, 3.7444671507804625, 6.117569256213404, 12.801773913445013, 17.147306050023726, 25.193773892617997, 19.176926689763224, 22.51333005966679, 15.514248801815896, 18.021478806772542, 27.794244520125854, 16.722395689256732, 23.319002543726278, 39.2265336744247, 52.044494228978316, 58.28408695036366, 67.86488794511365, 63.647743809607725, 67.6310597696612, 67.36334231591994, 65.32673005134829, 62.37683703822475, 62.78510478235061, 65.61406720069148, 67.16161481795773, 65.56255471321845, 62.93169944517074, 62.50101143313993, 65.97971054815477, 64.63262742565524, 61.83948409172797, 51.86902307694959, 49.66148568737892, 55.02109466060516, 62.613728584781775, 61.792886334080855, 63.34668620940178, 65.98702969089632, 64.61374121327555, 64.76062613148844, 56.86387908074164, 59.633523494966575, 58.51253363393969, 60.328857744893725, 55.183869100386104, 46.579173457237985, 42.550408993997884, 47.45158310859434, 58.680736634039114, 63.833424891194994, 68.58432908211985, 64.38862069960564, 59.39192902657294, 53.331863187974506, 50.97232218711607, 50.832983909114716, 52.221404890860285, 51.819503153524096, 51.654202707352184, 52.93521742666922, 57.81285339786161, 60.683404707139545, 61.23425452939926, 60.40865052130915, 59.636661391104425, 60.98725503490817, 66.35031177151588, 65.37326897344282, 62.9636275383734, 67.81195948200842, 59.90387678146363, 58.77460287463281, 53.26301774671001, 53.640490962613015, 53.5560776341346, 52.29151725769044, 41.38979142712009, 31.493031747879524, 20.62678767788795, 16.579856757194765, 12.906843423843386, 16.79920550315611, 8.282774955995622, 16.109405717542096, 18.46432420515245, 20.596403037348104, 19.597153740544474, 14.38929440513734, 11.26313497943263, 3.0758393387640677, 0.8471638673255522, 0.835238207251795, 1.4303232945742146, 7.954088670592155, 15.73869662900125, 40.2844008322685, 45.75102383090604, 30.726206418006655, 32.96164166542792, 40.54932948081724, 50.389257938631125, 60.77310931298041, 67.98229232911142, 51.26719813193045, 25.93715717715602, 5.020393575391462, 0.4033411552588786, 0.14687362607688675, 0.1002435778237639, 0.12411957366331933, 0.18297695975390174, 0.1948226862136395, 0.1588427539794676, 0.15803715124005274, 0.1069948578914327, 0.17351794957874284, 0.0985857712165002, 0.1533489536133505, 0.07670669080389124, 0.14052686341587575, 0.17492166780416044, 0.1845155094539927, 0.14950130765716876, 0.11113726383736057, 0.10938587192926677, 0.2642448691110457, 0.15151398917359693, 0.15692192640516067, 0.16330759101096662, 0.11525274179274998, 0.13164655605871833, 0.10559634906390022, 0.11872658280715828, 0.0704569761611281], [0.07576480102274688, 0.03686976251042178, 0.06475260120726402, 0.016664942358470252, 0.012652458221231018, 0.002153708966591606, 0.03023554259280284, 0.03730407307645486, 0.04027578942177277, 0.04367247772132678, 0.02913987406739785, 0.01080042438491458, 0.06403252835415545, 0.03328877643892362, 0.03533438058389771, 0.07000442504161788, 0.04761034968279062, 0.014725603227083002, 0.048873682296083826, 0.042092700999590664, 0.07480917528512017, 0.04393670144641111, 0.07705256417994538, 0.025052538351906885, 0.05256311577414313, 0.003900411698381387, 0.033670200125104, 1.9583055761552628, 18.721590503569573, 43.2286613218246, 49.61816310882569, 47.67240078218522, 44.122738146012836, 30.126221064598333, 19.90855266970973, 28.17617747091478, 39.42431134562339, 32.42654408178022, 27.701445164219027, 10.883722151479414, 1.6824623197317126, 0.227777122730209, 0.17370246951618504, 0.10886985808610918, 1.5850995312775336, 11.304797414810428, 11.203830703612297, 10.21737813949585, 15.286980790476646, 14.312654233747914, 8.811708534917525, 12.982135280486077, 18.00318879465903, 9.717705442059426, 16.497771355413622, 23.24452850126451, 32.612593866163685, 45.33613120355914, 57.297916796899614, 60.73124193376111, 64.1551886835406, 63.18533166762322, 57.14604654619771, 54.90770678366385, 58.56859999318277, 56.313064559813476, 59.1065687517966, 60.140125059312396, 60.973718935443515, 61.615532444369414, 59.32402103177963, 56.48295810145717, 52.60666401155534, 46.23662894771945, 49.68687518950432, 56.624665491042606, 60.454095102125606, 60.77969105012956, 60.573084123672984, 62.14102414346511, 58.39169717604115, 56.505523497058505, 54.55202625643823, 57.86466006309756, 55.35158180421399, 51.449639335755386, 42.29007344092093, 49.56051211203299, 32.613931394392445, 33.70407573638424, 62.86666654771375, 59.790143735947154, 60.9682236948321, 55.86241560597574, 44.48216845912319, 47.03340745741322, 49.797293832225186, 51.974499533253336, 55.279123860020796, 52.69601952645087, 48.30645584291028, 44.9040860514487, 46.58246432581256, 45.315122988916215, 47.500389160648474, 47.827679572566865, 49.626960985122196, 50.95604042853079, 53.5181208579771, 57.487457490736446, 58.18595317102248, 59.34766115680818, 59.71594033702728, 59.84497847095613, 56.39272397564304, 52.11263756598196, 48.428092464323974, 46.65489873578472, 43.93847696242794, 34.286045643591116, 30.723703945836714, 19.684820675080825, 10.561833823880843, 5.505475055786872, 10.458763741677808, 8.827198955320544, 17.432813413681522, 23.651646990929883, 9.814314399996112, 6.655051640925869, 5.180463050642322, 3.1407624098562428, 0.5187013408830089, 0.026878056927554073, 0.4531345107863027, 2.765552401542664, 10.644068275728534, 24.851517677307132, 24.919721811048447, 28.99024186595794, 29.76474327425803, 16.786610772532804, 21.455288356350316, 41.49689958941552, 51.149503492539935, 43.926254856971006, 28.216917168709543, 2.665436109227519, 0.4591896697398155, 0.07466112879375297, 0.0396987336928085, 0.06151813585611601, 0.034463775284107656, 0.04338529051071213, 0.03218059195205569, 0.036673988741371906, 0.006653340993404028, 0.08966471564265029, 0.01498793758782408, 0.024296371266245845, 0.045134594829212275, 0.0589523082148404, 0.0606648977695694, 0.007786175795650531, 0.051615844225330706, 0.0715258909809974, 0.07119000739147587, 0.053104904645513144, 0.05595387072272359, 0.022397066932171587, 0.03585431679722763, 0.024857557483858643, 0.06694928172134584, 0.024857159118138017, 0.07714885377114819, 0.07397087591309702, 0.07117772700204965, 0.017330893014948216, 0.06265918168449594, 0.07984929838247838, 0.010006294769775725, 0.03655163300854545, 0.04194433275129526, 0.029576450338466998, 0.007259542058642594, 0.020334386687365272, 0.029190190722264593, 0.020153532480640758, 0.045278278449850703, 0.015933506506224795, 0.07334610056732932, 0.03030451540384562, 0.04895819328545083, 0.027017019531359116, 0.04101605252212575, 0.06768737679287311, 0.04129284008916828, 0.04845975732971584, 0.10237688754474926, 0.012038413852062679, 0.07540179792070582, 0.015722887868422176, 0.03503530368869824, 2.261805832386017, 21.95448644699589, 48.8113433314908, 57.610976849832845, 56.16941951936292, 48.949277400970466, 34.56959378334784, 27.18283526359066, 27.401815306755807, 41.141964312522646, 36.195353461850075, 29.437872555948076, 12.176213725920647, 2.830236943498735, 0.3564198327160651, 0.5581897413057666, 2.030204214876698, 6.339995591871201, 10.222369355540122, 14.551640325976958, 15.167738776053152, 10.557913414893612, 10.1860305570787, 11.171074990303287, 8.34163502339394, 11.134643035550273, 11.948367164980981, 17.797036863142445, 24.975346903647146, 38.00156962487006, 50.947564186588416, 59.92261002140661, 61.308850165336366, 65.00253438949585, 64.8041565956608, 60.5791598750699, 58.61292669850012, 59.99955123470676, 59.35351725547545, 61.44319918847854, 62.55320641302294, 61.68102818150675, 61.93877889264015, 61.350854827511704, 59.26962952460013, 55.03329715421123, 48.21215029685728, 50.634880681191724, 59.20212553393457, 61.615689339176306, 61.65304991506762, 64.64196266666536, 64.95447358777447, 60.58773025389641, 57.39749008609403, 55.20087257508309, 59.23773281035885, 56.4279664716413, 52.377738798818285, 45.70155882066297, 53.7815393940095, 36.99917654837332, 36.114466344156575, 63.350710561198575, 62.749399446672015, 63.357178549612726, 57.96835576334308, 47.47619205905546, 47.69410325634865, 52.55233526229859, 55.389609183034594, 56.41862338589084, 54.255526450372514, 51.958158939115464, 47.30470211275163, 49.2911982536316, 47.77056986285795, 49.53542071004068, 50.90617925890031, 51.07084035873414, 53.61720777327015, 56.15547157103016, 59.812626761774865, 60.94585441773938, 61.27204656600953, 61.59613632386731, 58.61319341967183, 56.68856090114963, 52.60056080356721, 50.075323197149466, 47.819207252994666, 45.83007920172907, 35.57699572655463, 33.08959330281904, 17.607598150930098, 12.653005276956867, 9.22727482934152, 12.958124491476244, 16.378646031502758, 13.165805166767491, 18.170668117461666, 11.31499263548082, 8.763816395113546, 7.7980572754336945, 3.381000718762798, 1.7770408382338865, 0.16188347952500468, 0.7413336009748521, 2.8829075107651376, 10.653896754787816, 25.493268428310273, 27.94023709912454, 32.16615557670593, 35.973610108898534, 24.73391325243058, 29.130637222720733, 49.25873279571534, 57.96677504816363, 53.3983277505444, 33.81366283662858, 4.035777906256338, 0.4782665460821121, 0.039873371096027475, 0.05910553346057573, 0.06705635783052252, 0.012161650586002057, 0.0295596634368262, 0.05165590679333095, 0.038309877573121945, 0.0349760927530306, 0.048747296940775654, 0.07313734926884213, 0.056174496384037126, 0.037797096621004805, 0.024302647441565513, 0.023056536484810135, 0.04871770679470032, 0.05055671617869408, 0.027376107924107104, 0.02242698841127417, 0.0254595244769007, 0.022348470144694852, 0.06419177505097563, 0.03160836832267383, 0.0888978386478078, 0.11836433813216225, 0.06287770826489696, 0.04679733887314797, 0.027037290217835578, 0.14480958602601482, 0.12384264820045042, 0.19054151110110745, 0.13739201630796158, 0.16152861227671947, 0.1647536892203554, 0.151685317076983, 0.1262330417070658, 0.13193887988886527, 0.16953982352729768, 0.15347802410683326, 0.1927477830360013, 0.17512511011333237, 0.12727122107941297, 0.18342041740975074, 0.18519708255846656, 0.21856994097751958, 0.10408003889625111, 0.08250450550187981, 0.19588062299355385, 0.13031371628805516, 0.20260590969795184, 0.24235968297768026, 0.12425817429058014, 0.20279049092242796, 0.12321951228284067, 0.11707102083751272, 3.409032427495526, 27.649915026080226, 56.96597837632703, 63.84921243113857, 61.76877552463163, 56.84118032455445, 40.80938654561197, 31.42859897305889, 41.40299804749028, 53.51765801829677, 43.84150812702794, 36.81064390367077, 13.83407408191312, 3.26264736633147, 0.40784232017974703, 0.5634513557437928, 2.3424767294237694, 8.149791898265962, 19.54909686119326, 21.3201528979886, 24.77800069316741, 28.916681735746323, 24.32091316869182, 17.426523893110215, 23.500698497218472, 25.2629860754936, 14.555694095550047, 20.212530474508963, 28.051652023869178, 40.65561002300632, 53.08918614541331, 67.24814230395903, 64.3749826185165, 66.94615902439241, 68.43596935272217, 63.56003569018457, 61.37247100953133, 64.07461927783105, 60.24655072919784, 61.441743989144605, 62.553877138322406, 62.06969584188154, 63.05653672064505, 64.06180097210792, 60.362692110000125, 56.919062906695956, 50.044446299152995, 53.78159038482174, 61.4263722204393, 64.2073836634236, 66.30344729269704, 64.74806670219668, 67.0076225649926, 60.633825948161466, 56.409433272577104, 54.38491759761688, 57.821666963638805, 56.921973305363814, 52.84220626277309, 54.65505907612463, 56.638287882651056, 40.48900342756703, 42.88310050964356, 62.06728358422557, 66.88565254211426, 67.36349136598649, 61.40197115559732, 48.483378271902765, 51.30362126135057, 53.138698224098455, 58.79560324453539, 59.70848391132971, 58.357262688298384, 54.491994380950935, 49.31674465056389, 50.65679888571463, 50.01813896240727, 50.53119282568655, 52.2740234867219, 54.08009844441568, 57.879933772548554, 57.572678827470355, 62.53712469531644, 64.42334544274115, 65.25540959450507, 63.194976775876945, 62.17445450444376, 57.58022939005206, 55.44560886198475, 53.81492660891626, 50.360628558743386, 46.884675102849165, 36.24950962681925, 35.95423752261747, 24.168625185566565, 13.876348407037797, 12.855845747455476, 21.643193421825288, 17.460260198962306, 25.784598550488873, 32.803962384500814, 22.06194370023666, 16.898645431764667, 10.110818128431998, 9.403743243986561, 2.8794918617894574, 0.35406785085797315, 1.2115850900450063, 3.1832649678953233, 13.81913181274168, 30.705398244242517, 37.45592086545883, 44.0643968120698, 42.64571474444482, 27.679226898377944, 33.31913432767315, 55.18779931529876, 64.39502200772687, 60.97378169336627, 40.45147811212848, 6.581930325877282, 0.729964672317428, 0.12587026843140203, 0.21459526232173368, 0.1532992191853062, 0.15885545571725215, 0.10918920949822473, 0.13534573417517448, 0.14855782441314191, 0.07449474981835774, 0.15523968925399168, 0.24321540318910154, 0.11660490996174275, 0.11820047192515866, 0.15903560895352595, 0.14618030118365444, 0.17281514051700794, 0.20187933658880575, 0.14398726724809216, 0.1283892804396249, 0.13394183208865507, 0.11601211878681376, 0.1520204958656142, 0.16431608447624793, 0.29674265593771015, 0.24668029629655425, 0.21425850539197847, 0.20434209476074866, 0.25882363259311647], [0.009125601049632797, 0.03648333243965622, 0.009976193260010934, 0.12394180296049004, 0.025232153411413875, 0.04992789205824656, 0.012073207650363687, 0.019778739285445022, 0.017979949517475984, 0.018005655597775214, 0.0602789081993603, 0.07156989507136807, 0.0901003208972754, 0.039422061038954605, 0.08967615333535979, 0.01903216362059597, 0.12894404300999257, 0.00498870040305079, 0.00521293864773226, 0.002164405469234372, 0.04993975492975405, 0.03952774669854872, 0.06894121757678448, 0.03299904964683998, 0.03751206977833663, 0.05069447027879858, 0.003841013789379729, 4.5367094393699405, 22.873566419847553, 39.60178682881017, 51.26507220729705, 43.1422907306302, 32.39927576434228, 20.353565177609845, 26.215384621774, 37.958054850178385, 39.507681323635964, 31.08217327825485, 14.18143133963308, 4.221293512851962, 0.5486298833162554, 0.14049096453574397, 0.4073342506683642, 3.1572868650959385, 6.0550657972212765, 10.7700724563291, 12.00036798754046, 12.481948752557079, 10.12516027496707, 5.661469678724966, 7.967432573918374, 4.8475705135253175, 12.041201822219357, 11.204867189930333, 21.070568561553955, 25.489761829376224, 32.543222827296105, 43.46584312377438, 53.305512705156886, 56.470312380021625, 60.39291789454799, 63.884145059893214, 60.65804658397552, 55.9809967010252, 56.65432645428566, 60.23470909364762, 58.754171248405214, 59.552389267952215, 60.79197199113908, 60.14741674546273, 59.339926242828376, 54.33700976833221, 45.615635379668205, 46.66612848158806, 57.192671760436035, 62.121690780885764, 59.70445171479256, 59.65925816566714, 66.01907545520415, 60.00769015281432, 57.498640168097715, 51.027329506412634, 52.31259215262629, 57.34146295055267, 55.485162042802386, 48.11236519967356, 51.483779645735225, 63.14739842568675, 30.905152790008056, 49.20132498587332, 61.09351204287622, 56.63985290834981, 56.57034066415603, 45.214231783343905, 50.22655017914311, 55.2079838322055, 55.6636102737919, 57.584928389518495, 57.207361036731356, 56.21146340523997, 57.940424565346014, 54.60556268692017, 53.43899880686114, 51.41283573642854, 48.15561717556369, 43.55981134599255, 43.62828808446085, 45.72569316433322, 54.01514007199196, 54.18584162189115, 55.551112774879705, 55.34947941380163, 57.95918918425038, 56.98116971600441, 53.854354273888376, 54.50141199173466, 54.572595165621856, 55.027998032108435, 49.40943418010589, 42.893475178749334, 44.266222369286325, 29.63049819392543, 21.468218449623357, 9.212916012733213, 12.668343705515708, 19.428889943707375, 11.993532276922657, 12.035503598951525, 8.187315742815695, 9.01624543051566, 7.0944934025887525, 2.6431391508348527, 0.942037421609125, 0.2876487939107803, 0.23801886025936375, 1.1408730908747644, 5.89966296188293, 15.669506999754137, 31.95755412501674, 30.91887127968573, 18.089537812817483, 18.680317363431378, 21.25123097050575, 32.15158201033069, 52.68781785042056, 50.8226719979317, 27.749498121200073, 6.147834264462994, 0.5610373207638341, 0.0387011761326463, 0.01546060234578627, 0.01660851040674794, 0.07698324854455649, 0.01216358400040096, 0.009921987751318563, 0.06067307575816109, 0.11253735846689633, 0.035711088998904156, 0.03461705798643731, 0.06305176344129347, 0.07026992047265654, 0.08132301406153748, 0.023139381232941826, 0.03717221402292771, 0.02881251129081413, 0.019542891457076036, 0.019148566850250768, 0.1155051677638004, 0.0296735079328139, 0.009187979758867334, 0.01997285255891902, 0.03586443681870738, 0.016731750971126943, 0.03916555948014702, 0.012370749496884886, 0.024381146555946722, 0.02993708622882203, 0.0802569490887465, 0.02198038021883657, 0.07216318420344783, 0.01857771068781374, 0.014409542162602228, 0.064170757428773, 0.06944692753736051, 0.021866985799504385, 0.042699293248475566, 0.02803409509661217, 0.057545360928821954, 0.0985300383200088, 0.024648166501954682, 0.04257941964052377, 0.02288266516951544, 0.046103109996165, 0.0438977190623841, 0.04016426234175602, 0.06530827542226161, 0.03059807838121009, 0.03686644151927002, 0.11367405674630597, 0.040781430434435606, 0.1035839586608833, 0.03947175333216306, 0.09918196382181299, 5.655092395121052, 27.821577556671638, 45.36867118650868, 57.324279046827755, 47.42547973509758, 40.07562875747681, 25.77083299236913, 26.714259116880356, 41.764491527311264, 40.154982228432935, 33.137720784833355, 16.53394933669798, 5.385546136286951, 1.047153203718124, 0.10580720710417918, 1.3365632031233081, 2.285544997261417, 6.585186873712848, 9.922431592018375, 12.597436078133123, 10.165141974726032, 11.831656059911175, 13.367841551380774, 12.340615949323102, 6.944062661740088, 8.101195693016052, 11.649222700826584, 19.737080374071677, 26.054730223071193, 34.34644622187461, 43.518834344802364, 57.23573938492806, 59.62491389243834, 61.01723371013519, 65.11546334912701, 61.75445102876233, 57.94192683312201, 58.25994868432322, 62.082592595008116, 57.70736125207717, 58.042594463594504, 60.56163472513999, 62.474974739936094, 62.08495386185185, 57.064578917718705, 47.905032634735115, 48.39213609695435, 58.24703624171596, 63.00777381466281, 61.87731535203996, 62.10674262815907, 66.33168835793772, 59.723184954735544, 56.61750716547812, 51.45885298329016, 53.47007182336623, 57.73519046844975, 54.80656846877068, 51.063285873782256, 54.33106737752115, 68.18379232960363, 38.412171179248446, 49.892619194522986, 61.92043396734423, 56.85183740431263, 59.2567406162139, 48.99482004104122, 51.54173658740137, 56.784054925364835, 58.194558851180545, 59.92007224790512, 60.085462908591, 58.19384105743901, 60.18809956888999, 57.08812490586312, 55.41954471218971, 51.89676600117838, 49.25379845403856, 45.83104018242129, 45.98756236414756, 48.09526758809244, 54.87841452321699, 56.48130286124445, 57.91619608479162, 57.571235395246944, 59.99649178597235, 59.03553855034613, 54.44117615299841, 56.21222042268323, 56.318759841303674, 54.995124647694254, 49.62081855343234, 41.302044083995206, 35.35795880902198, 24.6007703581164, 19.327541782009988, 6.027635682013727, 13.032093528778324, 10.441475895143325, 16.441166650864385, 17.355072036866222, 11.11665504594003, 9.650407375827912, 9.18620074948957, 6.3686990064959375, 1.3757540549962752, 0.3574997408976478, 0.3924256587220777, 1.5524649211475927, 6.475565452729502, 18.270588536416334, 32.67969581388658, 33.81610647324593, 22.665229728144986, 17.729105334128104, 22.657410483206473, 37.9911361202117, 59.766146675232925, 59.318945484776656, 34.306673388327326, 7.912000167754389, 0.6451216604440444, 0.01932496242525597, 0.09270996876781987, 0.027826418236438787, 0.03847994143143296, 0.025216963803095203, 0.06890274464122711, 0.03697859679138468, 0.08408749596245828, 0.01207988219140398, 0.07049573254921744, 0.05357493023057619, 0.07304761739027116, 0.03746512774077635, 0.042737383140070785, 0.029700361229779742, 0.023526989163890965, 0.024016877493610787, 0.024174254935895725, 0.14326591885858966, 0.015657656439279598, 0.06667700641217732, 0.020586228516373425, 0.06666891652369691, 0.029408407037056265, 0.10144626691697106, 0.026656148068967368, 0.04132164882556085, 0.14016413610548745, 0.19814242098119952, 0.12792857814460032, 0.28755735365613816, 0.1319290433199175, 0.0715938812842773, 0.1512421811780622, 0.17107419038732208, 0.16545646763857336, 0.12986302676220096, 0.12580307485956338, 0.1781789817276501, 0.2072726875062912, 0.1199777116398177, 0.17716013075363252, 0.15142788089090778, 0.30410172718186534, 0.12110194566869929, 0.09768068429923828, 0.20648236056008648, 0.14582658306725566, 0.1452683960838664, 0.2375242279301728, 0.10234827416077738, 0.2178005588751647, 0.15491151250898838, 0.3196729545391375, 7.636468862333606, 35.10102002851425, 53.82727815258888, 63.489409492861846, 55.79485670212777, 43.25501572701239, 30.504859224442516, 37.450025543089836, 51.12904440972113, 52.020410876120295, 41.697544513210175, 19.19577956199646, 5.895410622319868, 1.308877643558287, 0.39043726219284924, 2.2726347609873745, 4.971294326166953, 11.991579917169387, 21.74613602699772, 22.528711634297526, 22.93117230938327, 21.573379155128233, 14.871166406139253, 16.9103439008036, 14.391120268452553, 18.86357245906707, 18.89494553689034, 28.214246034622196, 29.650425795585882, 39.006669136785696, 48.3124178455722, 60.01576631299911, 64.78232076091152, 67.08415585179483, 68.10639612136349, 67.02776785819762, 59.386833867719105, 59.57407605263495, 64.15995044092979, 60.00193211340136, 58.785867921767704, 60.4271327295611, 63.0703866097235, 65.50907319591892, 59.47166688980595, 49.890089265761844, 51.38475156599476, 61.52142301682503, 66.04530042217624, 65.12342968294698, 64.01765077344834, 68.26795070402085, 59.61568455542288, 56.0103674088755, 52.03115817039244, 56.004464241766165, 58.43767519920104, 57.250275688786665, 55.10607673275856, 59.34347598783432, 65.74970276125016, 42.231124139601185, 54.19851872228808, 64.48362050517913, 61.72840256844798, 62.49306078880065, 50.47605214580413, 54.427832249672186, 60.21073556715443, 61.792294056184836, 62.366756546881895, 61.54383151761947, 59.68719720840455, 62.373157855003114, 59.09416229494157, 58.32034534023654, 57.24022657640519, 51.558896956905244, 48.5220253852106, 47.61649916248937, 49.9912001240638, 57.69267197578185, 58.29046472426384, 59.181944939398, 60.72921406838202, 62.92214847380116, 60.67928229608844, 57.66593317831717, 55.437921016447014, 57.931097169076246, 57.47818108527892, 52.02487845574656, 45.96960183112852, 46.976058483123786, 32.34166595243639, 26.573918673299975, 15.367431544488477, 18.446271496434367, 31.556179946468724, 21.2042272475458, 20.01735137354943, 15.519288066894779, 16.831745486105643, 15.414814756762597, 7.39924293371939, 3.199278779568211, 0.5423381564117248, 0.5947059657304519, 1.6688903060651596, 7.65280798558266, 20.30913845185311, 40.861173598997055, 43.317856019543065, 29.519424515385783, 28.573595939144013, 32.77188131886144, 45.27435387334516, 67.49175287062123, 70.51159351102768, 42.103239182502996, 10.421968967683855, 1.0729225628799008, 0.19330823763964639, 0.1726209831934783, 0.10742107090810615, 0.16287400056758236, 0.08778440645865856, 0.11716002493255562, 0.11051001402759746, 0.13002280205968889, 0.12611607540278666, 0.08207885939027033, 0.13647836452770618, 0.16135247334116892, 0.11955275500734007, 0.11708869448592586, 0.10376147655469757, 0.16793600313605803, 0.1144593045295727, 0.09939649142324926, 0.2102716459381965, 0.15160061839607455, 0.1310722812289192, 0.12190633032831455, 0.0956999256666149, 0.26967554383220216, 0.1252580109623171, 0.1343418985244728, 0.15710465369686005], [0.05824307933630002, 0.08455408181274131, 0.03106799671396373, 0.042745093815028674, 0.03838353692704151, 0.052649162769798315, 0.04724504065609748, 0.03675343971999903, 0.03452707329885133, 0.06620885774252877, 0.029177981195971373, 0.09014044092186997, 0.022061439982104688, 0.0476038494267531, 0.05668599413888109, 0.0543112249954814, 0.03574552082066094, 0.017784872888437202, 0.011582784974316676, 0.04521183181373824, 0.05063388421530685, 0.006499549321409676, 0.059895569293369214, 0.014025553997095316, 0.04318413880443381, 0.06755540282615731, 0.403793239064755, 7.500319961578616, 27.409744378059145, 52.91724904890984, 53.476433907785726, 41.97606025203582, 30.250067941604126, 17.77597177413202, 28.697921345310828, 25.221177531826882, 34.27425499885313, 27.96037454758921, 11.118292635486974, 2.4912519849115804, 0.29419541358947754, 0.10493637197801184, 1.3927509106935994, 2.4940444673261335, 4.490363694006398, 6.58500938646255, 10.36561333364056, 7.571496271318005, 3.7284874146984475, 11.670802600922125, 13.288395904725599, 2.8599780701821853, 7.911094590540856, 17.157312016333304, 30.662618913958152, 40.34412676288236, 51.71757644222629, 61.81089785791213, 66.7872324297505, 63.83720997841128, 62.078936946007516, 58.10404623708418, 57.95898522100141, 57.10163747110675, 60.351889902545565, 61.83660899439166, 62.40432893076251, 61.00877708004367, 61.0961361085215, 60.677038700349875, 57.20339944285732, 48.010736588508856, 41.68946050828503, 49.48816007183444, 60.807900736408854, 58.964347531718595, 62.71843625653175, 60.777451376761164, 60.97933576953027, 60.88432419684626, 60.744754499004735, 56.488351360444106, 58.48652047495688, 58.76187478342364, 64.07034389434322, 47.54029927715179, 52.88190849365727, 54.055866041491115, 28.275083957179902, 62.411377429962165, 58.852403087000695, 58.992529761406686, 49.43359598036736, 49.64231706434681, 55.616349635585664, 58.73889753895422, 58.21106810723582, 59.160972026086625, 57.50358627688501, 57.06298251305857, 54.52867246443226, 57.246086597442634, 58.337419417596635, 58.512243378546934, 58.15237375997729, 53.502996198592655, 46.93332033772623, 40.26786411962202, 47.5952281490449, 49.0791823787074, 52.04552188996346, 54.86106195757466, 57.303274754555, 60.04376419128911, 60.72552311804987, 54.24275129072128, 56.69626051379789, 51.59737540829567, 51.23277148892803, 45.22417499173073, 36.03954907386534, 25.624516817831225, 14.778899511983319, 9.807130579025516, 20.80857384589411, 8.333350977590008, 12.16764432768668, 21.054482921477288, 8.761510041452224, 4.421096597948383, 6.9423907514541385, 4.777493448026719, 1.2532521832373835, 0.059410279406414884, 0.047354686990260124, 0.40227862195141856, 3.7743284000504405, 13.70627639755126, 26.020405561693256, 41.06773737938174, 41.59016178500268, 35.28671679958221, 32.58140317855343, 35.58995523760396, 42.436824998547955, 52.452867877098825, 37.504401360788655, 10.604046371675308, 0.7151670405460943, 0.03971796633014756, 0.05248881673680679, 0.03738072783415837, 0.07216149114913518, 0.039524188220140435, 0.03787336067386693, 0.032797993701552196, 0.04633695067417237, 0.02332185188518657, 0.019668309626379804, 0.04044083923461937, 0.024451821997401216, 0.0736181690327583, 0.03831172001457984, 0.06514437091086181, 0.05326808520382451, 0.052650009296954646, 0.06829740494609841, 0.02089721233313603, 0.05666778805936056, 0.020755440101868684, 0.039251139162168394, 0.03247738590524082, 0.008805074650163372, 0.03324874834487996, 0.03681248977720257, 0.03185827577967317, 0.006694366916969058, 0.07214252281212999, 0.030856347687902953, 0.030922702393464507, 0.0277951177990725, 0.049298152462729526, 0.06405708530256826, 0.024623981106185147, 0.025050356916542497, 0.014985985978836975, 0.050435195481705095, 0.009018432052295295, 0.051825296494268605, 0.008812220335277099, 0.06260643270046962, 0.04504304732226076, 0.03168811041471218, 0.032889288399488695, 0.019825482140144995, 0.057265014883371136, 0.013252100137422883, 0.05646493180745071, 0.034786068473852454, 0.016322068216639663, 0.010754155547117755, 0.07337207094796243, 0.42722740901574013, 8.88739655094762, 31.461964614929695, 58.476318390138694, 59.87589067028415, 47.089073734898726, 33.31477265204153, 20.85866447417967, 29.934772137672674, 31.373711286052583, 36.72725823617751, 29.869782386287568, 11.926739215850832, 2.620850282330667, 0.33996634786167457, 0.02023498103353045, 0.9696063519485536, 3.8712577666005785, 9.880489687765799, 11.429387580963875, 11.051781985067553, 14.170282983010816, 11.728870349545634, 11.79180674014553, 10.64379959337173, 5.436331514389285, 8.551116066594279, 18.468738832781394, 31.535089362052183, 45.44171748622772, 57.128121314510224, 64.72481096944502, 68.45509482968238, 67.5164794921875, 63.54324402347688, 61.744786308657744, 62.20009111589002, 58.51299647362002, 61.30143688571069, 62.65728650554534, 61.93485260009766, 61.25126977120677, 60.945936787513, 63.1189690866778, 58.22223901748658, 51.335721938840805, 44.881348071559785, 51.52797691283688, 61.787446006651855, 59.93935461967223, 65.20941195949432, 61.018555548883256, 61.02614533516669, 61.99156615041918, 61.603192667807306, 59.41019942683559, 59.65785395714545, 60.68190243936355, 62.2559025210719, 50.57500177814115, 55.77306009108021, 55.91337503925447, 33.281044190929784, 63.0967959280937, 62.37184778336556, 62.177968948118156, 52.31710287832445, 51.01236958657542, 58.7682996257659, 62.18290328979493, 58.08940010686075, 60.57502177453811, 59.90007992713683, 58.5540166208821, 56.38521263676306, 59.73897641704929, 61.05397455153927, 61.758349864713615, 60.33762031985868, 56.054913766922496, 47.623563351169715, 43.64243607367239, 49.32790379370413, 51.92952563685756, 55.262049782660704, 56.51259160810902, 58.75811323042839, 60.587789089449, 59.60471760842108, 55.35208778996622, 57.32863287771902, 52.140874708852465, 54.27674255063457, 46.94850775503343, 34.403391192036295, 24.12202350554928, 19.068090723406886, 8.42715936322366, 7.632091987517573, 15.313000813607248, 16.49922263237738, 17.46402567432773, 13.876831839161536, 11.941436336886499, 7.256949149793194, 5.4227954149246225, 1.9771117476686357, 0.45841864820930267, 0.16305055319061204, 0.24433248195677038, 3.976864641712558, 13.613015182556646, 28.61792068327627, 40.610436085731756, 40.21850109100342, 36.904808244397564, 37.78538427045269, 38.353253256890085, 48.87148895571309, 60.649531118331424, 43.50343511950585, 14.03497886273169, 1.0402028863468478, 0.03284559457472736, 0.03713432714463242, 0.029991074360065886, 0.07035801292306955, 0.0539137096324515, 0.08034830507371696, 0.007194105222175319, 0.04878515700599359, 0.02702612831677881, 0.02966250499500142, 0.026948893247472665, 0.07156088587737854, 0.04395548209187485, 0.04354205125221803, 0.025822757405319044, 0.09431599549228147, 0.034998749803391196, 0.07840042693480369, 0.039908270231418075, 0.03645931558323003, 0.023374886236964695, 0.027919756473913312, 0.046673864651952064, 0.024527252929645683, 0.10160775825140939, 0.013597883498145929, 0.028607381672988978, 0.14956832502878484, 0.19158152142359366, 0.08709848963565404, 0.0960922699361559, 0.07164776790887117, 0.1626922232249091, 0.14437028056671544, 0.06792033646976756, 0.15261018438444984, 0.153602865794974, 0.08917851028062644, 0.21781883773303803, 0.13152134664837392, 0.10611956413354605, 0.1540504909691311, 0.11394739691768924, 0.1384330531882663, 0.10555194660780892, 0.12790338917365, 0.11274215675169423, 0.08688930166705001, 0.1488884373177444, 0.14252161847487574, 0.06673629395663738, 0.11510127854924049, 0.23206864002971883, 0.6804351268276092, 11.49407236806808, 38.45377968203637, 66.2571947036251, 66.47910671849405, 55.45115901577858, 41.36659452992101, 27.371542453765873, 39.45120703789496, 36.955226390592514, 46.65907213764806, 35.69123083545316, 13.230456613725233, 3.6436436060936224, 0.5206513717289895, 0.2799346562354796, 1.9444827759458174, 7.34459549188614, 15.68559067864572, 17.452119319669663, 22.163619379843436, 17.84716279275956, 13.608477980859819, 20.689363210431992, 23.689419415689287, 8.617301160289395, 12.722391024712595, 24.277061070165328, 35.165401812522646, 48.57517742341565, 59.37915778929188, 65.53253289191954, 69.65756016392862, 66.47312902635144, 66.23545692813012, 63.44879334972751, 63.55583483173002, 61.08088593329153, 63.84690607747724, 65.92702527200022, 63.66971300494287, 61.38145715959611, 61.031338553274836, 65.27233854416879, 61.54907180416969, 52.10593423535747, 46.085672609267704, 54.28961969191029, 63.341740100614494, 62.51224117894327, 65.46038089259979, 62.19993029871295, 60.323778275520574, 61.92120667426818, 63.717075624773585, 61.231924641516905, 61.355526370386926, 62.692513312062914, 63.194204068953, 52.78322950486214, 58.36348748976185, 56.01335625494681, 38.9645311140245, 62.95768514756234, 65.16667773646694, 63.39295448795442, 54.54957085271036, 53.45629253695088, 60.734858359059984, 64.5742743246017, 59.77645858641594, 62.20472343506352, 60.11587304453696, 60.234846376603656, 58.15110291204145, 60.8140431680987, 63.425694511782744, 63.570139715748454, 62.215808053170484, 59.39210945560087, 52.367917183906805, 46.07365054468955, 51.79291732849614, 55.011112228516616, 57.50722231403474, 59.1636392378038, 61.862680988927046, 65.07853815632483, 62.00181530367944, 56.9924347631393, 58.38666477511006, 54.0154734734566, 55.664963491501354, 51.5679576320033, 41.15687716391779, 33.53262501378214, 20.309564029016805, 13.726797257700275, 32.73482472665849, 23.134631533776563, 21.89644713555613, 37.10839494582146, 21.807472090567313, 14.009806071558307, 17.346889972686768, 8.87087650837437, 3.7705496866856856, 0.8813580486082262, 0.3856520625131746, 0.7402203832903217, 5.077511620137, 17.48598506373744, 34.55818360851657, 54.562432304505386, 54.685822225386104, 46.646901023003366, 42.82222532456921, 47.07084648070797, 58.20013646156558, 69.40234722629671, 52.41087498203401, 19.062005166084536, 1.8109059694313236, 0.23426855343484113, 0.19394649613288142, 0.12526337357778705, 0.12676670621599884, 0.08960942707715497, 0.1705249666326469, 0.18165320578602054, 0.179351877661482, 0.1935839067183195, 0.14777727274885102, 0.08971265742495176, 0.13387357365460167, 0.13241629056151838, 0.14980185927162248, 0.15211549076822498, 0.2027723652821395, 0.14008227194989883, 0.29774506666487266, 0.09463852616928278, 0.13159050906617797, 0.10978291231778362, 0.1270988742790876, 0.21546667201384423, 0.10462900218103202, 0.13225957961572757, 0.1119024477778904, 0.1459399181147737], [0.03238041066534577, 0.08991123507580451, 0.03287488594651222, 0.04984332361228524, 0.02650019171978197, 0.04267956265398572, 0.04649946090554999, 0.048138525171746174, 0.019102145752478993, 0.08466201594039317, 0.058355755548203186, 0.036971602408636006, 0.044876308285541115, 0.03877814498639876, 0.06030826851905835, 0.010691773007443596, 0.03412622928379044, 0.0241053280901284, 0.05198201127049904, 0.043419684028072704, 0.04854265570400223, 0.03849180813338007, 0.10933612984034324, 0.03966903246398415, 0.09174013976007701, 0.06281994906584583, 0.7932370384373973, 6.582576536363171, 38.43652125327818, 49.376050887569306, 44.621181180400235, 35.46909132311421, 26.503786694618967, 18.01451071616142, 23.172819729774233, 33.67335181082449, 29.889831581423362, 18.17878350134819, 6.059771170539241, 1.0716924095346083, 0.12524533986804948, 0.07903527633677568, 0.9301409341635244, 1.9005296763873871, 5.662729249846551, 6.02686248479351, 9.048748150948557, 8.352128344197428, 12.745454561325813, 12.420089052569482, 9.36134438360891, 5.458998401318827, 16.33103139938847, 27.65629868353567, 39.51873456278155, 48.45466259987124, 52.60387520636282, 58.81470518727457, 60.57052673832063, 62.00927172937701, 62.96085442266157, 60.03571941006569, 54.23360432347944, 54.14913608181862, 56.95777277792654, 61.025062760999134, 59.93824851128363, 62.211418920947665, 62.025984948681256, 60.94274397819274, 56.134412365574995, 49.087952798412694, 44.73733432831303, 52.64474238118818, 60.385461468850416, 62.919983325466035, 58.0445360368298, 59.44801107529671, 62.048738618050855, 58.99248661533479, 54.81770407768988, 53.46709474440544, 54.031617949085856, 55.81152285298994, 64.64989369915378, 50.04829022192186, 54.149732282084805, 50.877871513366706, 32.696714978064264, 60.389454441685835, 59.196716585466945, 56.75573541272072, 47.760410924111646, 54.57262654458323, 58.093440148138235, 59.36548048450101, 57.99757349875666, 56.469100367638376, 57.131184685614805, 56.33857173304404, 57.2450432469768, 56.553619600111446, 57.87050831702448, 57.78227067762806, 56.35619886459843, 58.73694027623823, 54.56455038439844, 45.479497755727465, 42.69452471886912, 46.225897342928, 48.78825233828638, 52.25107762121385, 55.501071176221295, 56.09382760140204, 58.16452526277112, 56.98364865395331, 54.69372580128332, 58.031702041625984, 56.00140871540193, 45.78256360946163, 39.865060237146196, 31.892909542206798, 26.146037117127452, 7.498568623296677, 6.1553171661592305, 8.982460095036416, 22.87198570466811, 12.993858264338586, 10.428243779367017, 10.93116125752849, 5.432714598794138, 6.101035485344549, 0.8374709551853519, 0.9586470045389669, 0.24528302853145909, 0.21699376103858795, 1.7328835302783598, 7.964767323386285, 24.22669391478262, 36.71387903151974, 29.18178689095282, 24.141372557609316, 17.324773688470167, 25.249777493938325, 42.272305104040335, 47.8047650860202, 47.288612550304784, 19.31423710238549, 1.956055729139236, 0.24442272711425062, 0.059429052390999375, 0.006349482751947137, 0.014427171760959732, 0.02386780444442505, 0.06335773512781148, 0.06351160005696359, 0.05178220404852783, 0.032558434177190065, 0.09429921050586047, 0.053113726147961234, 0.04867621547272129, 0.029617480092471647, 0.04155630538720758, 0.02415520041399906, 0.06097778723004365, 0.016228710826967033, 0.041007077802092805, 0.04713252915309803, 0.09321119711403886, 0.007280197225496054, 0.02715151584256561, 0.02310954402351091, 0.026774357350903655, 0.04661660724049134, 0.03774415994543703, 0.016695873158413078, 0.040322762102850025, 0.019137849280190085, 0.005491907650139184, 0.021603147033602003, 0.018159685235831047, 0.026914965128526095, 0.00200854679625932, 0.043621697583265846, 0.03250910577574565, 0.04701907536195171, 0.026441239338788777, 0.07434911650395201, 0.019480476358665094, 0.011239437773192843, 0.03373158292003697, 0.026890421586651957, 0.015315783957410005, 0.05394212383356306, 0.03713132407996924, 0.051544559743976405, 0.020946012133912697, 0.052224462776775324, 0.055772664115553906, 0.03162820808469288, 0.04477773192188433, 0.09931484177227944, 1.002818653660436, 8.791160218177303, 44.436767024378625, 56.88796243359966, 52.16069836770335, 43.17359908934563, 33.09561414103354, 20.85056674095892, 29.992850672814157, 36.2925458723499, 33.19161415100098, 21.157721665597734, 7.246226860630897, 1.1138225875554548, 0.16413283624476002, 0.4347009031522659, 1.2921087756272287, 4.1182729505723525, 9.571301994785186, 8.911209260263751, 13.673905076519137, 9.706688484837933, 9.805816585017789, 10.476426174563747, 8.398913395020271, 7.217173374468281, 16.237946691051608, 28.872362875169326, 42.449070638225926, 49.71493582571707, 55.66861521813178, 61.94853774962887, 63.765814996534786, 64.7863176561171, 65.63895463943481, 62.225625745711795, 56.90664076036023, 55.39505343283377, 59.60052067233671, 61.10217263621669, 61.19731364711639, 62.42828676777502, 62.23280368312713, 62.20721414012294, 58.57788032101047, 50.386214179377404, 43.99739096241613, 53.724672871251265, 61.252548463882945, 63.66983459841821, 60.04634511086249, 59.42156645559496, 61.054657043949256, 61.107126589744325, 57.50990521523261, 57.20267772674561, 57.88349528466502, 58.70986023256856, 66.0284028514739, 51.71303825993692, 56.188556763433645, 54.94791107793009, 36.637510484264745, 63.18029926669214, 60.027811911798295, 58.59315403046147, 49.58050835517145, 55.81102471197806, 60.07431553256128, 60.54301915630218, 58.60776878172352, 56.84929570844097, 57.4422247179093, 57.456388396601525, 57.920220436588416, 56.7367668305674, 58.909163705764286, 58.68821659395772, 59.93995474230859, 61.69002609868204, 56.868844801379794, 48.087968057201756, 46.204642018964215, 48.51107412768949, 51.50995754426526, 54.28477556474748, 57.600762997904134, 59.743271412387976, 60.06294065906156, 58.290637308551425, 54.49921938680834, 59.86101704259073, 56.30781642852291, 49.03908398843581, 40.9277166089704, 32.74642317525802, 23.343613455372473, 9.874289401115911, 8.01052128115008, 9.367382872489191, 16.991880170760616, 17.329798244660903, 17.855160505540912, 11.877274205607753, 10.35852070777647, 6.722701249584076, 3.223147382659297, 1.47618965275826, 0.15519870355004264, 0.2199728931150129, 1.9832992866154642, 8.526318842364896, 24.860321437158895, 40.063987162805375, 37.602597898052586, 29.17444617517533, 22.714398599440052, 31.634419464295913, 47.46222842124201, 52.83381239060433, 53.897625861629365, 23.610103207249796, 2.17411904085067, 0.2324008617189623, 0.0681274330183383, 0.0504212909858794, 0.034257241810161265, 0.08404123191271098, 0.021581985769913565, 0.04444267953776064, 0.01607128550418683, 0.02189829964340935, 0.03324785202200855, 0.07669013564384754, 0.028628338008157672, 0.044692397387998725, 0.04943194205782587, 0.07171958099089323, 0.009682964488503434, 0.016913972644796296, 0.016161051856714393, 0.037214390993598974, 0.08491781269831043, 0.07875984474535912, 0.05933367061398684, 0.02294232235139897, 0.05403829468113761, 0.028846962264769023, 0.013004428699552532, 0.048616039266269055, 0.13219101474650446, 0.12129958103140517, 0.12703981656100483, 0.16264457255601883, 0.09177943240971335, 0.09890093212766994, 0.06209452508858616, 0.18645798667303978, 0.13562172501077577, 0.3233426076269919, 0.17703257711423984, 0.2027291272796931, 0.12807704598432587, 0.12873955882124363, 0.1605451239212867, 0.1465065780306055, 0.16347041533839318, 0.12626602179220608, 0.17453304672193143, 0.10394749802447135, 0.14098110758969862, 0.18763816044215234, 0.2676922647703079, 0.16457113046799937, 0.14649736965375562, 0.19829691027200994, 1.6469573926541115, 13.969135995834106, 54.82846313907255, 62.84860011070006, 59.23502245256978, 46.618699181464414, 37.70153184090891, 27.51339104867751, 34.03553955016598, 46.56577856309953, 42.24835511176817, 23.89492807849761, 8.581524241355158, 1.473042440991248, 0.4720063207130279, 0.7696352790920966, 2.9623161400518114, 5.728156345505869, 13.79313434323957, 21.09425771620966, 16.11536183664876, 19.300091074359035, 20.794333680983513, 23.99543293060795, 16.553633751407748, 8.932189037722926, 20.367974004437848, 31.447426349886005, 45.855994301457564, 54.501251174557595, 57.38173784748201, 62.26450035648962, 62.53181380610313, 62.73403552270705, 65.35547317997103, 62.66714734415855, 59.94740332326582, 58.60046925083284, 61.81512617295789, 64.06290708049652, 60.6157006755952, 62.43522936298002, 62.02279213936099, 64.02249097824097, 60.04827491698727, 53.75915834980627, 47.084421803874356, 55.02255378230926, 64.30522326500186, 65.71856698682232, 62.660369488500784, 60.78312704640051, 62.95614365608462, 63.972229726852916, 61.32150373151226, 59.5775120489059, 60.89722487234301, 63.124699669499556, 67.61621752092915, 55.37351177584741, 59.92731686561339, 59.598096647570216, 43.13210825766287, 62.467898784145234, 64.53216375843172, 62.09208080845495, 53.336268009678015, 58.800823919234745, 62.39375814314812, 62.422626787616366, 60.583694134989095, 57.509065828015736, 60.23851379271477, 58.057319041221376, 59.15030317921793, 57.6797987568763, 59.127988815307624, 60.64488310967723, 61.05753214128556, 64.58160131208359, 59.160913190534046, 51.743660203872196, 48.27723810749669, 51.029290691498794, 52.891902692856334, 55.58326052081201, 60.92666226048624, 62.675733412465746, 62.41053412037512, 60.29764352306243, 55.46633466597527, 59.061386969781694, 58.26632645822341, 51.17515187109671, 44.61395617454283, 35.94205856323242, 32.49054343469682, 13.726875705103721, 13.331945980748824, 18.29363246117869, 36.27192597235403, 25.556712765847486, 17.28330246863827, 21.52399847584386, 12.911241381399094, 13.841208873256562, 4.923772850344259, 1.7875619833507848, 0.5422096375015475, 0.5100319834966813, 2.475527448038901, 10.14443382140129, 27.87354111671448, 46.012081100094704, 41.9053203059781, 33.63367311416134, 27.71210812753247, 38.013324968276486, 55.78101858015984, 62.516528329541615, 63.30199472365841, 31.7283013943703, 3.749772401586656, 0.3814954532971306, 0.16762857205204426, 0.16431283626344897, 0.16331454708931908, 0.11681009895138203, 0.09345545658781644, 0.16061411779974738, 0.1229602757901434, 0.11047588481057076, 0.2177523413012105, 0.15398348891927352, 0.12374920845632592, 0.10890100722111042, 0.1743681692788678, 0.17293477280726358, 0.15083011780535022, 0.1314428992449276, 0.14398545928059087, 0.14744975483946263, 0.19725242599604592, 0.2077035659984235, 0.11988742817794124, 0.1374512808697839, 0.11434279787804812, 0.13025722496451872, 0.1368111990872891, 0.11096902326830935], [0.04561650626842053, 0.05901759422774758, 0.04409895886877372, 0.08279161993414164, 0.008126537169089482, 0.04093509618072741, 0.06805873791416807, 0.05792990259285416, 0.024042596980448694, 0.011239169642419345, 0.04400667208697527, 0.0777412542412358, 0.02670234891646091, 0.016918425530856176, 0.07379507405623313, 0.04156568996428002, 0.03796332620925481, 0.035566708238254634, 0.013635922636416171, 0.029262618589845878, 0.05159160903384609, 0.02773940022433958, 0.02483734233875669, 0.01509372092362854, 0.12231208113653046, 0.016742183173435832, 2.184338531186504, 11.701067609171714, 42.5644471568446, 56.048414399546964, 56.63820551287744, 30.12565035973826, 20.542013491353682, 17.939809176229662, 25.916415683684814, 29.14882133083959, 29.76179365188845, 14.294634865176294, 4.312226310853036, 0.4027474064740443, 0.04296327182542413, 0.3262014638993048, 0.582302879662283, 3.533211970521558, 11.716670797717187, 8.178011880766961, 10.436376813919315, 13.021297204879023, 8.946173267979777, 6.307081512866482, 4.844902321215599, 10.656381576291977, 19.332709504712014, 34.65161054365097, 46.117977250006895, 57.525076943059126, 60.72043972630655, 61.473636781015706, 59.0812498523343, 59.34215414908625, 58.76542845079976, 56.91512876941312, 54.006106853485115, 55.271294809156856, 58.35313635487711, 59.68186670734037, 58.44679470985167, 59.59869677020658, 60.12006605825117, 59.14616507868613, 54.533693098252826, 44.81971979141236, 44.442203429437455, 55.046735194421586, 61.33696571473153, 57.419910353998986, 46.15942493561776, 57.996334029782204, 62.51750499971452, 56.661092542832904, 52.24593931628812, 50.334866431451616, 48.22996177980977, 53.1530305647081, 58.386445122380415, 61.35795431752359, 40.91259194958595, 41.17534760505923, 31.566884094668975, 64.1033310274924, 55.327851464671475, 56.43636426618023, 49.39490572098763, 53.31951164430188, 54.73344764401836, 57.54988593439902, 57.561519684330115, 58.004445491298554, 57.101143252465036, 56.50874376296998, 57.01227803384104, 57.77818749027868, 52.52376471796344, 53.524961471557624, 57.086810911855395, 58.67717119955248, 56.97043418884278, 49.077931142622425, 44.211187593398556, 44.83962189766669, 46.18193934040685, 50.69783864482757, 55.295456609418316, 57.85969042008924, 56.712636409267304, 61.224754548841915, 54.2615080648853, 53.55996470297537, 49.51380060565088, 52.23172072441348, 39.63740979471515, 30.493758916854862, 28.88198248801693, 16.70454694378761, 3.5084694143264525, 12.539038850415139, 5.69379295072248, 10.36555253690289, 19.692126089526763, 12.334126387873004, 4.5954278111457825, 3.384881413752033, 2.7817598802428094, 1.3388256752683272, 0.18388812940928245, 0.0781989764542349, 0.9135133941327372, 4.702679630248777, 15.32803623907028, 27.95586382189105, 30.55608145652279, 25.567738548401866, 24.19033354328525, 29.388633081989905, 41.578112263833326, 52.458465099334724, 44.518705337278305, 19.85926220493932, 3.185570586112238, 0.28821848753479223, 0.070210870415453, 0.03160399013018656, 0.009192864526994526, 0.13103371636281091, 0.009588277936282178, 0.07940055471995185, 0.0010041807493713175, 0.07276503053764183, 0.02782275633616073, 0.015767226164649813, 0.028219214497855114, 0.04210469793648489, 0.024652115685204347, 0.019816628078960126, 0.08260156884188614, 0.037734614489900495, 0.014257441150895772, 0.019912781689556378, 0.023853310060897664, 0.04165288609182162, 0.021113180179869937, 0.0935503748816348, 0.15419592510067648, 0.09549730307152195, 0.0163807065015839, 0.035811534617096186, 0.04741532284946692, 0.02995511227768035, 0.062099125446571465, 0.02695532838603662, 0.06325948435152251, 0.06398872727708471, 0.019717764432331728, 0.06538074733989854, 0.05891973415629999, 0.008501344728433799, 0.13808538716646934, 0.051060545393416, 0.01426953767922016, 0.016860580146913568, 0.09253219040411134, 0.0030893912809270047, 0.06601660031705134, 0.04625675659025869, 0.015991475421845192, 0.10355539890306611, 0.04191453193104075, 0.037860030743984446, 0.08357856843260028, 0.05600574253607662, 0.1278338973380385, 0.04225359861588767, 2.025246093830755, 15.802663622363923, 50.0223711998232, 61.85331829132573, 60.81661232056157, 35.23938555871287, 23.85363728769364, 21.31754844419418, 26.494929982769875, 35.18481754487561, 34.20180489940028, 17.21161134781376, 4.4307073854631, 0.5527070032492761, 0.07296562299973543, 0.41772804132873015, 1.63667808617315, 6.215672637185743, 12.376095748716786, 11.537074292859725, 13.14709153867537, 10.930245384093254, 14.538469006938321, 7.813997297517716, 8.807852845038138, 13.843418148256118, 21.322445523354318, 33.53198566744405, 47.56518671589513, 56.3845693680548, 62.84331667807795, 61.30710078823952, 60.88662662813741, 60.631774548561346, 61.47717868128131, 59.82629622182539, 57.58903118871874, 55.72161036152994, 60.95862565502044, 61.36097846492645, 59.00821139735561, 59.78867676950271, 61.07577116258683, 62.605240575728885, 56.93406205023489, 47.84636574406778, 46.054654505945024, 56.0515405285743, 63.87687298559374, 60.067016001670595, 51.85741286123953, 58.4877364097103, 62.8007903406697, 57.91887506361931, 55.91965083153018, 53.00857359363187, 52.081384120448945, 55.88483195151053, 60.82891287342195, 59.64088970615018, 45.24641875297793, 47.00393869030861, 35.220883738610056, 63.297138829385084, 59.2079580983808, 59.4962562284162, 52.410812224111254, 55.011363260207645, 57.6537149952304, 58.46297840918265, 59.710394105603626, 60.13652824586438, 60.03948096306094, 60.2878297528913, 57.182971738999896, 59.083434612520286, 54.431507510523645, 54.9113271313329, 58.48553988241381, 60.10980121551022, 59.165341546458585, 51.224667872152025, 45.87372341463643, 46.391746920924035, 49.01090568111789, 52.79503583908082, 56.93470531894315, 59.1611602998549, 60.16390246729697, 62.657015862003455, 55.4646009783591, 53.766673611056426, 52.284013763550796, 51.8904862865325, 42.988745627864716, 34.65317164697955, 31.107060716998195, 18.196985260132823, 7.145577371120454, 13.03485389678709, 13.067381132033564, 17.772778964811756, 11.686278312436997, 11.360121465498402, 12.123093066676972, 6.5137345271725815, 4.53247671165774, 2.159256935119629, 0.312884894590224, 0.1297896202172964, 0.9237876137898815, 5.230083975099749, 17.867378688627674, 34.73585521021197, 32.0735699899735, 26.820065052278583, 22.55285970626339, 34.27361957488522, 50.810846051862164, 60.280134062613214, 51.33993848677605, 26.438720457015503, 4.655292005308213, 0.2552873400911208, 0.10930719469944317, 0.0466710262961926, 0.07987561350267741, 0.048383117893770825, 0.03928634856316832, 0.0704987509356391, 0.052432704626792864, 0.027619882847272584, 0.05083815006899738, 0.021245805321321375, 0.025364435728519194, 0.06050169039818068, 0.0482340295228266, 0.009052757579352587, 0.13886206242586338, 0.051385489247378804, 0.05328361380604967, 0.02161306595700162, 0.08714748861929102, 0.022234196639469555, 0.10833476099275774, 0.03040876847902133, 0.07553545728085503, 0.0487089695619239, 0.0767983379022729, 0.06621483322833815, 0.11748985642747534, 0.17573339924696954, 0.2531005421112622, 0.3035225034240754, 0.1685508959476025, 0.19119529053568843, 0.12124254578544248, 0.1888571901907844, 0.1450311846189922, 0.20212430086347366, 0.21212092090037563, 0.12623014589471201, 0.09906221661836871, 0.1733736186138084, 0.18095902287431304, 0.1848757086742309, 0.18265671967979402, 0.1614514059357105, 0.10547011309573728, 0.20399801403043732, 0.11978909313198059, 0.10790410466612348, 0.1645682346556456, 0.22316873614345828, 0.2433598414063454, 0.16520629396602032, 3.0755620762225124, 21.388207981663367, 57.910398821676935, 67.79321839732509, 70.2756315662015, 40.95256874638219, 30.161604765922796, 27.7462072526255, 35.49390031445411, 42.3883209689971, 40.89430978221279, 19.869529008865356, 5.682996136526908, 0.6877010724236888, 0.32850558058388774, 0.7527875347483544, 2.618224745796573, 8.676118081615819, 23.41364541361409, 20.426442815411477, 22.259976325496552, 25.56032526877619, 20.075984924070298, 13.092121481895449, 11.810246782918131, 14.682102280278361, 23.558871169244092, 39.7458750970902, 50.77661944973854, 61.27565906893823, 65.44064744826287, 66.05483962643531, 64.0825738445405, 64.80008517542194, 62.79107462975287, 60.95308726833713, 58.07831156638361, 59.421495852931855, 62.59897655056369, 63.56192627260762, 59.960151026325846, 60.78477836424305, 61.567569701902336, 64.05594879581083, 60.17632853600287, 51.19605025937481, 50.49260847030148, 59.5788299652838, 65.22421498452464, 60.757176645340465, 54.490319528887355, 58.799078464508064, 64.47710544832292, 62.3800455370257, 58.064394997012236, 54.28940396155081, 53.605648548372336, 57.788903405589444, 63.72120588056503, 63.67040726446337, 49.18467060212166, 51.342601776123054, 37.87140577070175, 66.07648326504615, 61.85875077401439, 62.166084166496034, 55.318006315538966, 57.077452136624245, 59.71361829388527, 60.45181228268532, 61.495547140798266, 62.54241989504907, 62.80255148487707, 62.099780421103205, 59.92131563924975, 61.38750545440182, 54.93303352786649, 56.58032309624457, 59.36441359981414, 62.622785337509654, 61.83159228294127, 55.77174609707248, 47.70014762878419, 50.88130358726748, 51.507761016968765, 54.52012169745661, 58.711095779172844, 62.14832367435579, 61.82427314019973, 66.62341071713355, 56.2456194047005, 55.448562406724506, 53.32124140954787, 54.00273361513692, 42.77023430793516, 36.30780389232021, 31.821653804471417, 22.559313966381936, 10.365666285637888, 21.218185001803985, 15.16974408780375, 20.4081057348559, 29.49655317491101, 22.618043614972024, 15.567842106665335, 13.34874745338194, 6.080295462762156, 2.7512144225258983, 0.4651988327743546, 0.3952889889478684, 1.4063490326366117, 6.268777116652458, 19.224157910193167, 37.22280263900757, 42.36920333677723, 37.984726967350134, 36.150818870913604, 41.60648668965986, 54.24150789937666, 66.39604660772508, 58.23721854917465, 33.25149697642173, 6.855551437024148, 0.5257755806369167, 0.17662491108621323, 0.18130671953962696, 0.16566672813027136, 0.1654344809151465, 0.07122932302374994, 0.2209563814704457, 0.09287098512774514, 0.14212565827033213, 0.1194438019827489, 0.09100736899962349, 0.11310398007833189, 0.13160520263256567, 0.18299958999118499, 0.11633573730866756, 0.15224995452069467, 0.08476739133437795, 0.1994601381762374, 0.16554075263200269, 0.14323178198068373, 0.24714535763186796, 0.22056509440224017, 0.22419845024424218, 0.2352353410735246, 0.2590233670367349, 0.16343238673383192, 0.1493881105054771], [0.00829847602759518, 0.07147727504132256, 0.025832071119258483, 0.05653284167149856, 0.03234875208187488, 0.024529014931871526, 0.007018464722580487, 0.047812753942825144, 0.02624206988501453, 0.04539631727722384, 0.05927459757414557, 0.0393995265626619, 0.07288519908944446, 0.06006905756470177, 0.07767114187440566, 0.020220337262857827, 0.011951856450327944, 0.008450536819685613, 0.04272566965570854, 0.036209896507282416, 0.06871931254863739, 0.01319146332060618, 0.003554538082924762, 0.04171660545492365, 0.04742828505714575, 0.04221473497548892, 2.310463079521733, 19.511946132106168, 39.19289542782692, 56.230824224410526, 41.88064075285389, 33.672669318414506, 23.546429411057506, 21.408331701832434, 44.45192698509463, 39.55894670178814, 25.877652860456898, 9.208429801848627, 2.031834327405499, 0.08840569610437078, 0.0775885729179267, 0.4172451607882977, 1.459719742978773, 3.986996614163922, 7.110582965035593, 3.13476289952955, 12.315324506452008, 4.916183064060827, 11.169614888006642, 7.358652776287449, 6.26487631951609, 11.355428349587227, 23.088775104092015, 36.043138042573005, 52.34478696700066, 55.59782820363199, 61.883218519149295, 58.1775632212239, 59.97795074216781, 54.382713225580034, 57.13281639160649, 52.04584352431759, 50.019378431381725, 52.012691651621175, 54.490837281750096, 58.45452177909113, 57.61164365276214, 55.95737226547734, 59.0514829850966, 59.02698386100031, 55.152494061377745, 45.435571132167695, 42.69113579104024, 55.71756639788228, 61.14150616430468, 61.614873486180464, 57.90659804497996, 60.15072722588817, 59.41822067383797, 52.450228121972856, 49.90295856229721, 41.412345055610906, 46.336319908019036, 51.28860642833095, 57.87227338360202, 56.90772333452779, 44.69148182099865, 38.39776431360553, 27.12128935321685, 60.0977752285619, 55.18024483034688, 55.28742359530542, 53.8055835231658, 51.042944462068625, 50.7798122590588, 53.631646017874445, 53.14494263741278, 52.890922100313254, 53.269932885323804, 54.43301370066982, 55.407044118450536, 56.607269779328384, 58.95661261773879, 57.352469121256185, 54.810035844003, 58.13761388101886, 57.04850896712273, 54.03942346572877, 45.964314476136245, 45.566856784205285, 45.78476013675813, 47.643516448236284, 50.51021599000501, 53.76363377417288, 55.220790370818115, 56.79024442549675, 60.42606584487423, 53.373636430309666, 52.88036307980938, 53.19457630957327, 49.06991774036039, 35.07536380521713, 29.354922271543934, 25.48198769169469, 11.199394502947408, 6.366232816250094, 17.01273149059665, 22.565173987419378, 15.067886998576505, 6.927505356650199, 13.825474285310316, 4.292191334309117, 4.632762401334701, 3.1745014123378263, 0.10444486528755197, 0.1016301510014361, 0.23353588226581776, 2.128352580531951, 11.289532530692316, 26.935567086742772, 36.909369960907966, 31.85745131584906, 26.433660599493212, 25.477551491029804, 35.083373285109, 46.546637396658625, 48.14993758355418, 35.59207723986718, 6.999466630720324, 0.7144953959411191, 0.08330286871041022, 0.02176107988963204, 0.10717694166927569, 0.049977362185956976, 0.020046092479700045, 0.04646471881818387, 0.005955391323133823, 0.023852082404999003, 0.016395627979129072, 0.03956112514940962, 0.0927538579450019, 0.04371769606105743, 0.06868648568108197, 0.031614966254921696, 0.0070244957497643855, 0.0756080977378353, 0.02157940405360874, 0.0606168449045189, 0.015627613343719034, 0.08617085675078054, 0.028755062357372338, 0.1066197122957918, 0.04325267686057956, 0.028062013255792762, 0.05046419957051835, 0.021666582944172046, 0.08774102289950655, 0.04561495494037386, 0.016912432808068492, 0.0756591038718339, 0.02196371589126366, 0.02546662419673897, 0.05889504697294005, 0.05917086160831875, 0.03213162169671588, 0.07028455275201029, 0.019661230973959453, 0.04517826184089627, 0.05557585612780625, 0.02464628001044114, 0.05941805136840671, 0.02581581281828544, 0.05134518919212203, 0.0460800047843687, 0.06681263461829194, 0.037606938276439905, 0.04108839803525517, 0.0287882377949333, 0.03153442743144209, 0.06922869207037073, 0.04715955673506664, 0.07214013261780625, 3.1169418557997677, 22.44958369962631, 46.47988257869598, 60.99965756939304, 49.19886958214545, 35.64007136129564, 28.07572949317194, 20.49872229176183, 38.984284170212284, 40.229166015501946, 28.710051275068714, 10.357709757743343, 2.128587677594154, 0.2425027269149019, 0.063166864321477, 0.88067690451299, 3.264681115265816, 8.267661083129145, 10.876485378511491, 11.334266181915037, 10.930274801869547, 8.627913132790598, 11.99533558660938, 9.30539079250828, 9.560431145852613, 11.545344610368053, 22.95509288387914, 36.56003582862116, 53.560513834799494, 58.993788842232, 62.96813041933122, 59.76145159813666, 62.61929442805629, 58.66091297518823, 60.08889890486195, 54.84433697115991, 54.172270221094934, 56.128513120835834, 57.46959501697172, 60.083591938018806, 57.98835592885172, 56.12139009660291, 60.14949560165406, 61.56229803639074, 58.174633210705174, 47.12719917297364, 45.493814406856416, 57.065218264056796, 61.76718304234167, 61.44385422429731, 57.48012265851421, 60.74306787983064, 60.772085574365434, 56.248474890185946, 52.41671539122059, 44.38475639589372, 48.756132048945275, 52.43482889667634, 61.28793216520741, 58.43666322769658, 45.68403367073306, 42.67387343991188, 32.06305607672661, 59.5882514984377, 57.94021667972688, 57.14241050904798, 55.856363388799856, 53.5156419200282, 53.52384359605851, 57.129101907053304, 55.51512895091888, 54.563161865357436, 55.565143092986084, 57.580468654632575, 56.69944940074798, 58.577601832728234, 60.47803332728725, 57.33201396080756, 55.566268813225534, 60.16485952561902, 59.61920684383762, 56.81397476503926, 48.51260777442686, 48.629106090914824, 47.730161605342744, 49.9844144236657, 53.441469900069706, 59.19566146789059, 58.16567843960178, 60.02232451592723, 61.87094542288012, 55.510516243596236, 54.33109091174219, 53.32118257399529, 48.85499146676833, 39.43754934495495, 32.57613347422692, 28.088810597696614, 20.43702929250656, 5.99631751737287, 11.680454573323651, 18.242735785822717, 10.866858901516085, 11.973474256453976, 19.184381154275712, 9.99346963820919, 4.562270545190381, 4.993142418323025, 0.5016261909998233, 0.19963396352625665, 0.28454059134087256, 3.0112386374704303, 12.388875811330735, 28.240310184417236, 39.82209851664882, 34.32349643399639, 28.620664381211807, 29.488382877842074, 36.8545901390814, 52.66756665322089, 53.90827117427703, 40.79221440899757, 8.882244517726283, 0.7794778541691842, 0.06596357937181188, 0.05218272630666053, 0.08973391636485055, 0.03121382538079014, 0.05475832922984997, 0.010547994583424543, 0.002684360834762394, 0.028913479764014486, 0.04523013365424929, 0.03228322475127155, 0.06574602572307472, 0.0500077567243528, 0.05166201251408747, 0.009268921736117092, 0.02597734054190017, 0.051783418297887816, 0.08092055743139598, 0.00944309565614188, 0.09045311970816505, 0.019340085000881267, 0.008192391044670537, 0.07231486961245537, 0.057384884660883304, 0.01841735316350335, 0.033635285667954914, 0.029492318562622515, 0.15726424513324616, 0.2330213622941125, 0.1134296210723058, 0.28962196061207407, 0.11086220762902692, 0.07567771980839391, 0.16806112061585152, 0.10451615742978551, 0.192793870885526, 0.1600437346966036, 0.16587905705936495, 0.16611075269118433, 0.2387667765780803, 0.09968123098294582, 0.2299892628986028, 0.10321624411810791, 0.13172861939716723, 0.18777113798404896, 0.15308227840690844, 0.19868073564383293, 0.17172910363203095, 0.09406301027704632, 0.12484262276801372, 0.16372020596698408, 0.12641943089904326, 0.16089772354931603, 4.077127042316621, 27.272684997127904, 55.196565812633885, 69.09372729639854, 53.42439582270961, 43.70240519123693, 33.423132050421934, 32.1431940217172, 58.20549441922096, 53.07559905513641, 33.169029143548784, 12.682462276950961, 3.040160724232274, 0.3483305571060027, 0.13641087218157708, 1.2469026013728113, 3.4911661234594162, 11.850376552151097, 14.930840365348326, 14.344355810073115, 29.9006082934718, 13.604463434988453, 19.6932400426557, 18.122297448496667, 12.385431970319441, 17.24425527357286, 31.226816561914262, 40.90995219445998, 58.01329828077748, 60.37001125274166, 65.36456915640062, 63.22864247906593, 64.47068060598066, 59.012392643959295, 63.36570970473751, 56.03438408144059, 55.90691489558066, 56.542695799181544, 59.77481903568391, 60.98085764915713, 60.005434789965236, 56.654746147894095, 61.40210451618318, 63.09606244487148, 61.358699567856334, 50.11879482576924, 46.52856311490459, 60.31369386180755, 63.854444872948434, 62.94075619789862, 56.81948961750154, 62.88549000217069, 63.86258379105599, 57.874116897583015, 55.12811260838663, 46.58810469412035, 51.78228770532916, 57.107168013049716, 61.33571447864656, 61.81404359879033, 49.07135725021363, 48.035306315268244, 36.68093112207229, 60.901747365151685, 60.791697425227014, 60.36016218123898, 58.79434808608025, 54.883093910832564, 56.34989561573152, 57.75759896924419, 58.55034136003064, 57.955325649630645, 58.60426610515964, 59.36073049422234, 61.37623256252658, 62.02325105667115, 64.56722190303188, 59.1040192111846, 55.872037180008434, 60.35864030161212, 62.16876314532373, 58.89418417407621, 52.70662561539681, 50.366688620659616, 49.96717952912854, 52.49697885205669, 54.85628058833461, 60.80877542495728, 60.08279569687382, 61.99615924589096, 63.53529730150777, 55.33750834003572, 55.92575011714813, 54.98634638324861, 52.85728777608564, 40.20945218301589, 36.34201480496314, 29.48483117165104, 18.561234204999863, 15.836942195892336, 25.29100356563445, 32.75495433038281, 29.91431501603896, 17.952966766972697, 21.342369202644598, 12.133281423199563, 9.421053644149534, 5.593411653272567, 0.8009974478233246, 0.2061114054653914, 0.49588126701212704, 3.312021181468041, 14.625863336747694, 34.985733724409535, 48.85964732016287, 46.081087358536266, 38.10721082072104, 36.77682130567489, 45.466393116981756, 60.422292524768466, 62.854315004041126, 51.15810525032782, 14.171607763536516, 1.2026213710346532, 0.2439744737479956, 0.1072393165480706, 0.21441713155758, 0.09061097978584229, 0.1258014660749224, 0.10442641789033529, 0.16268439380632294, 0.07722881802868459, 0.119383541506625, 0.13345964102735444, 0.18427653598689264, 0.12276930539237878, 0.17221561542922453, 0.15848401032628553, 0.156156052985499, 0.32141755124734295, 0.20571797335099792, 0.23131457968584954, 0.21331408752068398, 0.158050190056524, 0.11310946526786975, 0.18692597446422424, 0.1950454186167448, 0.09508736942323948, 0.1559003175146157, 0.07609794201749949], [0.06731331138120544, 0.04985333638145559, 0.03950494409148251, 0.03651383806080107, 0.01666575249645018, 0.02665849995889491, 0.09075889604226237, 0.01626824862473915, 0.03475432179027027, 0.10926178866817106, 0.03926230106322516, 0.053672353631906936, 0.01520215683887082, 0.016311961601698594, 0.10357178552376647, 0.04059634359192945, 0.04742861447495319, 0.04286794367456629, 0.10135949213778782, 0.01876751280149385, 0.04065835457896033, 0.023648758839455344, 0.07587410644778321, 0.024315008270223776, 0.041370801026782686, 0.04350593403702782, 3.1040610373020177, 25.81265722551654, 42.54151698081724, 49.06479120254517, 44.52210603221771, 29.101829374990157, 22.207683286359234, 33.39030573444982, 34.00062261089202, 36.19677335985246, 19.692145701377623, 7.682565046894935, 0.7743349527159046, 0.1844966636910554, 0.21622430232744064, 0.5362184622114705, 2.4473209486853693, 7.899754528076419, 10.892828914426989, 12.824973752421718, 7.432085919764734, 7.691937060125413, 11.171945756481541, 6.323540268405792, 11.186074133842222, 14.973494179787176, 27.33544291988496, 41.147083005597516, 58.560359093450735, 62.075069489017615, 62.60213013618224, 56.119511281290364, 55.36039929236136, 51.17463804060414, 51.33253697426089, 48.723843097686775, 51.74548018363215, 52.58928006695163, 58.63369564856253, 56.53041485817202, 57.4244995271006, 56.22518385610273, 59.669338657009995, 57.59522068885065, 55.891464679471916, 48.56479098719936, 41.69364959962907, 49.982653279458326, 60.80701428074991, 58.85118715224728, 58.41394093728835, 57.85379902009041, 58.55990802088092, 48.878753185272224, 43.65030042586788, 41.27532489838139, 43.70160895009195, 51.22612699385613, 55.86796183739939, 57.42078896491759, 43.96462740436677, 25.281156455316854, 34.21308171364569, 62.04505159008888, 58.12003774027671, 57.2626821456417, 55.3440430087428, 54.87641803679928, 52.826744279553814, 50.689378092365885, 49.18551783407889, 50.21952129179432, 48.24799683786208, 49.04135111839541, 50.778321758393325, 52.88845100710469, 56.28651795848724, 60.034107315924864, 56.13413387729276, 55.713553813196, 58.0848736916819, 54.33319722452472, 51.927415401704856, 49.28702092939808, 43.99331561980709, 44.45214663782428, 48.475200130093484, 48.815591258387414, 57.00710834995393, 56.607426674135276, 58.522104217160134, 55.17572625990837, 56.361862767127256, 54.8367158059151, 56.24089294864286, 44.55357913048037, 39.95948345430436, 23.537717826904792, 23.397302858291134, 7.3770158425454175, 10.92898630326794, 21.423291621669648, 3.424355902018086, 10.596660548640836, 16.296867555187596, 6.833136562378177, 4.076279565211266, 3.8321595807229323, 0.39965688521342896, 0.15582200800699575, 0.13702191923174167, 1.410566316016259, 7.910598410714058, 26.022923723343883, 28.29246201822835, 22.996181672619237, 19.767449325130833, 30.133755937699352, 39.30387104711225, 47.66848625675325, 51.95867276960804, 38.00023601901147, 13.171654401286958, 1.17903713978106, 0.02994175744994033, 0.03169708896518475, 0.01689563058466921, 0.02647306646160301, 0.014520773341158226, 0.05483514869645719, 0.04078231143554853, 0.08814348719052731, 0.012693385510975796, 0.07618536797141837, 0.02279968444077719, 0.03866320881511896, 0.03869844119875662, 0.029112434713169936, 0.05122238146742025, 0.038427383969387705, 0.049672826914297, 0.027338851153129534, 0.1042935322789896, 0.08283231452467942, 0.03670064477069724, 0.06655407994384728, 0.025871877047804095, 0.02880246404768719, 0.04721987849822448, 0.06145366189640857, 0.07030731322424066, 0.06289951878810121, 0.010485184949732596, 0.029465348437248223, 0.016753613205266096, 0.04087128488707446, 0.11542002475189587, 0.09175955242807828, 0.047516270255249356, 0.08584511616537649, 0.03650049663959973, 0.009943236157508388, 0.024294480944292682, 0.03573835789856892, 0.013547394473496224, 0.028352992601632595, 0.037305386917245005, 0.035104274584521214, 0.06994947355480925, 0.038461716199714335, 0.008335411999254458, 0.03187975688507, 0.013919011276635914, 0.03270844568408305, 0.01755129268032409, 0.05691703476552522, 3.8909225694594847, 30.59018646517108, 48.8491157562502, 56.53023835151427, 48.5147846898725, 35.392067740040446, 27.322051948116673, 36.65495326442104, 39.065555680182676, 38.490281258859945, 22.65117391463249, 8.04459196905936, 1.0746528184221638, 0.07886014097640592, 0.10174707900131903, 1.2035872546895858, 3.1107932954065265, 8.612237380396936, 9.866436816030934, 7.792327182908212, 11.58745909890821, 9.524104114501707, 8.278225006595735, 6.3471931411374, 8.933889385192625, 18.116245231320782, 28.013006871746434, 44.414731148750555, 57.646364473527484, 64.98414239575787, 64.43262184819868, 59.065144600406775, 56.80144279233871, 54.182358557178134, 53.370745643492675, 51.673328184312396, 53.895645064692346, 55.88122337095199, 58.20004232468144, 58.40034600227111, 57.72805959947648, 56.813719810978064, 59.924143668143984, 60.0971947177764, 57.41739219234836, 50.499868777490434, 43.84573251970353, 52.64586810142764, 61.03095808336812, 60.680121683305316, 60.37109774927939, 60.90618748818675, 59.94424189290693, 51.999030036311, 44.83200073242188, 43.10055671199676, 45.479211422704886, 53.64611171906995, 57.266000470807484, 59.977656564404896, 44.83716257156865, 31.043320240512973, 37.64470061948223, 62.375974116786836, 59.95518138331752, 59.02576400387672, 58.36792761279691, 57.14957275698262, 55.16503387881864, 52.86713292521816, 51.58372163772584, 52.6888180548145, 51.39128623470184, 51.97789630582256, 53.200185298919685, 55.633604141973684, 58.564422668949256, 60.62389058451499, 55.87113895723897, 56.5811271821299, 59.455906806453584, 59.54977696941745, 52.7385066401574, 51.926242613023334, 46.03699991779943, 47.04473134010069, 49.83064182343022, 53.01726164356355, 59.075597716916, 60.87062335783436, 60.10056011138424, 57.658955281780614, 56.9383962692753, 57.358905730708955, 53.73680083982406, 46.25006698792981, 35.923509674687544, 29.385657964214204, 23.35632977947112, 12.674972511106922, 12.53174618367226, 16.33193060275047, 13.184271685538754, 14.423204275869555, 21.330364788732222, 11.909420970947513, 6.1574813339018055, 4.636607304696114, 1.1743955049783954, 0.24745680301660494, 0.19782162932378633, 1.684505016573014, 8.629529149301591, 25.954066514968876, 32.08593526194173, 32.553536699664214, 27.982875224082704, 32.4364362993548, 44.726096737769346, 51.92411668838994, 58.69017777904388, 43.29400800889538, 17.165545071324996, 1.5501683734117018, 0.02186491927732864, 0.030219768842441902, 0.019150254158903996, 0.044019906255867214, 0.06401164096689994, 0.07688089153699337, 0.055143556542574405, 0.0647709260304128, 0.050171791470699736, 0.04912346526379547, 0.07141347523898849, 0.030094708819242737, 0.011879808753879081, 0.04633942130772818, 0.007588023323595765, 0.03981094642151748, 0.05773794011122758, 0.05248654911655092, 0.06743885020935728, 0.08367789939286248, 0.06748223376850929, 0.06756734613689684, 0.02368269270406135, 0.003101860319504575, 0.07103572494440502, 0.04652100712842038, 0.14168105148259671, 0.22083150913878796, 0.1357118935594636, 0.17139599328079533, 0.1540544899480958, 0.11519872493320897, 0.25691873964763456, 0.10565379799734201, 0.1077778074109266, 0.2283426028706374, 0.10444883362299974, 0.061295706057740804, 0.06298980224997767, 0.11924148582282568, 0.22371570759963608, 0.14285750206439726, 0.1269346480107596, 0.138276863182264, 0.20299454610193932, 0.1654158343350695, 0.11962367942736996, 0.18934193998575213, 0.1545471610922006, 0.1572978457496051, 0.20551811633331163, 0.2732872806729809, 5.263340280902002, 36.336743139451556, 56.844616320825395, 63.36915354574881, 56.12536345758746, 41.73574447631836, 34.65862766388924, 46.74065351486207, 46.569281239663404, 46.73419729355843, 26.36947297280835, 10.383915112864587, 1.0740856682100604, 0.4076892558124758, 0.2901304897762114, 2.36778631325691, 4.527652196345791, 16.11475386927205, 22.76714467233227, 25.854108833497573, 15.88122477454524, 17.378106155703147, 23.249974712248772, 15.425202173571433, 17.313512563705444, 20.009139891593687, 29.476590271919008, 43.68168330961659, 60.12781666171167, 66.00366838516729, 66.7558926920737, 60.279165237180656, 60.36121337644516, 55.35263692179034, 55.68266122571884, 52.600286237655155, 56.42317333529073, 57.59604438658684, 62.34610134555448, 58.06652876638598, 58.196665163963075, 55.663982898958274, 61.758314563382065, 62.536371600243356, 61.33607141433224, 51.4555307357542, 47.778293009727236, 53.98543204030683, 63.60093424397131, 63.29059631593766, 61.91150665283204, 61.5728727463753, 62.557677915019376, 53.22970113446636, 47.58566541056479, 47.09585551292666, 47.62253569018456, 57.55867988832536, 61.148487983211396, 62.78714833721038, 47.87732501183787, 34.8568917089893, 44.55654444233064, 59.58389374517626, 62.660385177981475, 59.38967366372386, 60.71789803043489, 58.6140484963694, 58.11276174360707, 53.92620032833469, 54.00727179742629, 53.888102346850985, 53.92670631408692, 53.93280559970487, 55.24620340716455, 57.01270949456, 62.10403227037, 62.642432489702784, 56.7393869738425, 57.159892512905984, 62.41129506018854, 61.35548322431503, 57.17161647735104, 54.98673469789567, 48.30874650709091, 48.791696179297666, 51.83058384926089, 53.93630827626875, 61.887160501172474, 62.074033983292125, 63.2434102027647, 58.70897769927979, 58.23691260430121, 57.43421523801742, 58.141740214440134, 49.948175645643666, 43.80166469081756, 25.58468907110153, 29.238788735482004, 13.75081196908028, 17.14696284263365, 35.6899364532963, 13.491943382447767, 19.55645718882161, 26.703198032994425, 16.902305003135435, 10.699936555277917, 9.376933843858781, 1.587646007537842, 0.5043064874987448, 0.4036447405815125, 1.9946357944319326, 10.059536080206595, 32.78983989069539, 39.454694024978146, 35.80499918230119, 33.850097733159224, 42.751685419390284, 53.178310240468676, 59.60943229736821, 66.27825783145043, 50.44389655513149, 22.681923335598363, 2.971407948963104, 0.103108340633973, 0.09995513039851382, 0.1493612514628518, 0.12643320515992182, 0.20477036855393843, 0.1616130351659752, 0.11276436564061912, 0.11800226199650958, 0.1579647865747252, 0.16553534405125728, 0.16370445519926088, 0.09835736210187597, 0.1690339756708953, 0.13733344122527108, 0.10875639280364399, 0.14442300273766442, 0.1120553436058183, 0.1360378946147619, 0.16857519625656067, 0.18697765475559622, 0.14762148110856935, 0.262916901659581, 0.2028134582383979, 0.13832385501553937, 0.14524927452927636, 0.13174633134997663], [0.03620653338129482, 0.026494965084918567, 0.026018048538976622, 0.03731413947177991, 0.013697388743410909, 0.04973544311078806, 0.05864603009315268, 0.04003157591327064, 0.04078082522497543, 0.02266618021343264, 0.007065412984605158, 0.02641251487206788, 0.019560413803124142, 0.04241762187091574, 0.020525590741946813, 0.10931006752915921, 0.011913625790076631, 0.04080714800605371, 0.05468664638277504, 0.12454284490236353, 0.02631967459174414, 0.08614972038494964, 0.024808313352085894, 0.030304584351758805, 0.044050496146683736, 0.24878766628042345, 4.26779370154104, 24.162765164529127, 49.97738945868708, 46.51533688268354, 37.190321491610625, 21.069401656427694, 24.592519652458932, 22.075681801765196, 37.90406734712663, 33.73834548457977, 14.989009115003771, 4.499799445752175, 0.5324557447625745, 0.18081907393230548, 0.16358937347127547, 1.2236552036577657, 2.9498302552007862, 6.318865783752934, 7.765079457913676, 5.7074589786991, 5.643005121138788, 5.266944448794089, 3.997185951279056, 5.347522189540248, 8.98280918598175, 17.915741512852332, 28.52321113309553, 42.99257778352307, 52.167903761709894, 62.41950065858903, 60.247397961155066, 57.72818903769217, 53.614744524801935, 52.067545998481016, 48.879502357975134, 50.53300496070616, 53.280307554429584, 57.92793573871736, 57.65133411653581, 57.61039633904734, 57.292798103824744, 56.729910527506185, 55.9180740387209, 57.554141706035985, 56.66135141926428, 55.22512066748835, 45.76283408749489, 41.04093190162413, 50.0493767184596, 62.40771785859139, 58.40315441931448, 58.06326927677278, 52.17423446716801, 44.5710729014489, 41.614676598579656, 41.542759941470244, 41.1109422868298, 47.58186463386782, 52.552703965094786, 59.680572325183505, 55.71112586605934, 24.886420888285485, 29.209678865248158, 47.55669870684224, 55.58108752773654, 53.68894792372181, 56.879913730006066, 55.49741944959087, 55.82217993274812, 57.709032181770574, 54.16988149765999, 52.62556591341573, 48.196433359576815, 48.04736760354812, 43.72451951426845, 49.9769893769295, 53.775087095076046, 56.85025668913319, 55.724916919585205, 55.92507154710832, 58.95805212759203, 56.0728076196486, 53.15419550864927, 46.89711293866558, 43.526941883948545, 44.590963240592714, 44.987636458489206, 49.24209410144437, 48.82005099327334, 56.33068776899769, 55.35044431686402, 58.00127229382915, 56.886440553972804, 61.35273756519441, 54.43086816418556, 54.33030251533755, 36.38451368578019, 42.85765217196557, 32.93647966077251, 13.008570094262401, 7.927453325640771, 7.203148449620894, 11.398577363260332, 13.455273143706785, 28.702043756361935, 13.511695458043008, 4.207511284658986, 4.14116733497189, 1.1448790565613778, 0.22836788377213865, 0.02545586640706226, 0.8213464591291644, 5.400698252262608, 18.4443397291245, 33.6487546274739, 30.372665543710035, 26.457512532511068, 25.82334372305101, 26.103544119865667, 40.28493819698211, 45.038948905083444, 42.99633149177798, 14.799624335381294, 3.146071828180744, 0.06556540517316711, 0.010671509024236473, 0.024614096656742118, 0.05692647296875235, 0.07407392239979199, 0.06899937131111661, 0.05812620879301141, 0.07841875941883172, 0.03526716402942135, 0.058498132988930716, 0.017107218323696046, 0.05263170362600396, 0.09313180742244567, 0.020272777896494638, 0.011531830551252972, 0.049574150959210056, 0.02770992882189251, 0.052147597344892646, 0.0465164106008747, 0.010628249954372164, 0.0573168215792506, 0.008952107032640808, 0.027332887158639012, 0.03373092408442209, 0.05433010523237529, 0.05541084078891624, 0.03151010413984618, 0.03180123670327087, 0.051131002499812075, 0.07307286764825545, 0.020249776106568116, 0.06201919949343128, 0.06320238781852588, 0.07906834069158762, 0.08724935533058259, 0.036818166488721486, 0.0019751962357869132, 0.02480188012874175, 0.02441495593126503, 0.028009270017425862, 0.04672125485094805, 0.11394640866426692, 0.041911260735604076, 0.024237870877127976, 0.059599353736566926, 0.027033132275626547, 0.021395904928325646, 0.0474022725416768, 0.013805664737798996, 0.023647776331692457, 0.012776520414908808, 0.3431661132602923, 6.272720079268179, 29.496335483366448, 56.70053981965589, 53.77625203901722, 44.37457784529656, 26.75344751727197, 29.484323224713727, 31.645564879140547, 39.709922652090754, 38.0392518351155, 15.330924084109647, 5.278761079234462, 0.718155886617399, 0.14940776832161412, 0.15193800351792766, 1.2356371865157159, 5.662126185432558, 9.701229526150613, 9.751448612059317, 11.864296063300102, 13.997355488038833, 11.299634595071117, 13.329949494331116, 7.159826361363934, 9.074889767554499, 16.144167723194247, 33.04454095901982, 45.50103941271382, 55.05332477631108, 63.90966792260448, 64.01446973123859, 58.704157106338016, 55.878614994787405, 52.31369433864471, 51.63639906914004, 51.794992262317294, 56.01037133124567, 59.80097732236309, 58.6541311971603, 59.4519373678392, 55.70640333237187, 56.32466693078318, 55.77777085765716, 59.345597990097545, 59.73159059401482, 57.56117451575495, 48.08177463469967, 43.83453807523174, 53.95038566281719, 62.59637209676928, 60.268315961284024, 60.981136137439364, 55.3821409902265, 45.656373116277884, 43.732576062602384, 42.6382504740069, 42.87363975278793, 51.14699317562965, 54.56862572700747, 60.67201806652931, 55.06094986392606, 28.516627434761297, 34.59042156896284, 49.44580631871378, 56.70899252737723, 55.392280317121944, 59.38169556279337, 58.01817378690166, 59.63251544583229, 60.62429458864274, 57.023182222920084, 54.54828823766401, 49.13783357989404, 48.6409673383159, 46.47679567337037, 51.87962916589553, 56.57044656815068, 59.00912530960576, 56.139507524428836, 56.377909183502204, 60.30519016327397, 57.851135730743415, 57.48458239340014, 49.16729450225831, 45.54442082681964, 46.82393720073085, 47.82993493541595, 51.4816851000632, 52.15588169713175, 58.54800754977811, 57.71589632957213, 60.53241698972641, 58.677096674519206, 61.125400912377145, 57.29002498811292, 52.47027535592356, 35.71873057273127, 34.01233873059673, 28.697989986788844, 14.145813276690824, 8.034274664617355, 9.581753150109323, 12.157510884346502, 12.287960090944845, 14.292597193871776, 9.078370871082429, 5.533441555115485, 7.144749260717823, 1.3268256740223978, 0.3139504616058642, 0.25267560846142234, 1.0587047064496626, 6.501879163326756, 19.173990795689246, 35.0223215933769, 31.217534272901474, 30.160200557401105, 32.514171792614846, 33.64989995956421, 46.22794874252812, 51.30509999490554, 50.52344222222605, 17.800068855285645, 3.7908141218846847, 0.08011275601963844, 0.051248800009489066, 0.03654055154672073, 0.04963893901496645, 0.03708829292126241, 0.06953735655594258, 0.04472323242695101, 0.08519833877442345, 0.06640851557735475, 0.026062087103303884, 0.01931078979865678, 0.051618307198007266, 0.010376056682528749, 0.02188966774772252, 0.041886450978176254, 0.030445793508401806, 0.01423542186873214, 0.015244968704909328, 0.03375212173728693, 0.02429111781830509, 0.04278972226705763, 0.021060406297986067, 0.0194557432100297, 0.05356589805394892, 0.07750682367552673, 0.023095654849443707, 0.17424069224826752, 0.12930349146406497, 0.14276626099261547, 0.11834099543310943, 0.17787057005109327, 0.16915881735903604, 0.18498012645831033, 0.12047287256967638, 0.19249615379639212, 0.15051730878410802, 0.08642289967786881, 0.14211902394890785, 0.08492476111578365, 0.1350256626404101, 0.1852786096353685, 0.25299508244760577, 0.13593770563602448, 0.0994150767162923, 0.14457117946397874, 0.13586524904014605, 0.1296864281738958, 0.19219494334632353, 0.09243753258018725, 0.1221105310645315, 0.2176098642690528, 0.5535509869936974, 8.775944363686348, 35.322006364022535, 64.80141485891035, 60.04676480447093, 49.25796401116156, 31.224941668971894, 34.463226949014974, 32.18711868409188, 49.69354321879726, 44.06447133710308, 20.161055249552575, 6.211906671524049, 1.1253716388056356, 0.413610962249579, 0.4683836747802073, 2.321941895831016, 10.918408651505748, 16.420600683458392, 18.25254563362368, 16.67835923933214, 17.939797409119144, 14.740910376271895, 15.733837792950293, 15.1154084743992, 15.96062139157326, 21.663260267626857, 33.88581875831851, 45.15601596524639, 55.77869261464765, 67.09682510745141, 64.40271377563477, 61.880190449376265, 57.82656208161385, 56.239884899508574, 53.76582245672903, 54.65768314176991, 58.962594232251575, 61.31208612072853, 58.19694365224531, 59.18078391782699, 55.92171399824081, 56.25392698472547, 56.325580843033336, 60.671335574119325, 61.3714551156567, 59.12004601570868, 50.855047241334, 46.72918842684838, 55.28219507586572, 65.0627153150497, 61.85839776069888, 63.05452062237648, 57.2024384621651, 48.062064724583784, 45.09804333409956, 44.282872830667806, 44.47391579228063, 53.12666047003962, 57.84420098027876, 63.96145497598956, 58.915368895376886, 33.032852295906316, 38.30989929937547, 55.91843489677676, 57.98112700062414, 56.797351760248986, 61.868262521682254, 59.9517846107483, 60.70689970447172, 63.57820410882274, 58.97434173091766, 58.50473203966695, 52.07810501898489, 52.13507744573778, 48.93682779804353, 54.134776284617764, 58.016138076782234, 61.832447359638834, 58.79309292762511, 55.91720719491282, 61.12303572316324, 59.520920092059725, 59.63956394503194, 50.54053591143701, 46.54884961343581, 48.10998824334914, 49.47645179687008, 53.23255269758163, 53.13689393381919, 61.99811258623677, 61.153441936739036, 62.58214958252446, 61.74499419427688, 65.10100549267185, 61.32818745028589, 58.61249916015133, 42.67581893551735, 47.04012255514822, 38.40926078058059, 16.575687277701594, 18.304391522561353, 19.235803427234774, 21.998858259570216, 21.508773796020016, 41.3465198393791, 21.274078776759488, 12.98082717003361, 13.20062110500951, 2.654607180626162, 0.8135682152163598, 0.31785395537172595, 1.5641441460578673, 6.9682631954070064, 22.636276752718036, 42.73314045321557, 44.20432736796718, 38.41887450987293, 39.70240346847042, 38.79664582590903, 53.33661317825318, 58.34953169668875, 59.72637776405581, 23.325803933605073, 5.119656507045993, 0.31510532382995854, 0.1545298168615949, 0.1054362903138803, 0.1375441307262067, 0.20046049578776284, 0.10538628009418327, 0.20317765643760083, 0.26054677883944205, 0.1708433221304609, 0.12739207144946824, 0.1824998095511429, 0.2796373528338248, 0.14721573030035343, 0.11578949363601786, 0.19765825341305426, 0.12843872375425794, 0.12006447109724246, 0.09441544136573231, 0.16293320384237076, 0.16292911293285509, 0.10329227068371351, 0.13773621961234078, 0.10909653584202451, 0.24999860614057512, 0.20924020047870376, 0.1494380441163817], [0.04945718465493091, 0.1261091346461927, 0.013786580529995264, 0.0780812823664277, 0.05565147666681198, 0.03676957353168438, 0.04062319114323586, 0.09471502004852218, 0.051211836267142534, 0.034829972972792965, 0.06574843123915695, 0.09035673052553209, 0.03789694469061591, 0.04799139032500887, 0.038029228922941034, 0.028013887612389463, 0.06970107720624055, 0.03340165566412672, 0.038281229715193474, 0.01502080946304505, 0.0187064383569504, 0.04010056213085209, 0.03853655149859767, 0.0016855169650948337, 0.07142651405545973, 0.3636030408163225, 5.394672511085387, 28.92622486237557, 54.12034588475382, 48.22904002281928, 30.76136458304621, 30.19802789534292, 23.15802258829917, 26.99402609179097, 43.37990007092876, 29.14120408796495, 14.41259132277581, 3.9149801817632492, 0.2719019485577461, 0.09971379738060698, 0.39945871358917606, 1.2274401682999827, 4.8300478150767665, 9.254422533896662, 6.848478913307191, 5.996947057785527, 15.997419107344845, 10.999749783546696, 9.972517317341222, 2.10800479496679, 6.329681229206824, 24.486994166528028, 35.97908966002926, 46.89194717714864, 54.68854435028569, 58.99761707552018, 59.875090506769, 58.480538860444106, 55.952779170005556, 52.62748787480017, 49.03534204729142, 49.327931250295336, 54.91504946062642, 58.59330308052802, 59.169456112769346, 55.16986623887093, 58.18085408979847, 57.67980660161665, 58.420624656061975, 56.60459080050069, 57.829550927685155, 56.82545554253363, 56.06251532031644, 47.02835544463127, 41.05954747046194, 46.43038618949152, 48.38221250041839, 47.17708387682515, 43.56978985571092, 40.687204714744325, 39.02644572719451, 38.635079476141165, 42.46086520533408, 41.36514717532743, 48.54171568347562, 49.101551655800115, 59.919931042578916, 26.425998249361594, 28.68769964864177, 49.790751318777765, 53.36019054535897, 57.05323542318037, 57.642191071664136, 57.09440069813883, 57.766490982424834, 56.834916299389256, 55.684108580312426, 54.83236197502383, 55.382474391691154, 49.716249819724794, 42.82401784773796, 45.50542854493665, 54.690383941896506, 55.147736226358724, 56.87882331109817, 54.79378154200893, 55.47697605625276, 56.25269928286153, 54.75498930100472, 54.23927214837844, 46.658205293839984, 44.63813758665516, 46.08511563270323, 46.64233538412279, 47.7929195280998, 49.783494933958984, 52.23426634265531, 54.085350498076416, 54.00335334962415, 57.28831091234761, 57.16456405578121, 53.36490915667627, 38.582970788401944, 32.492104538025394, 25.215521474038404, 20.60549116903736, 14.928391825768257, 5.95495367242444, 15.79821663518106, 12.434382169477402, 12.259443479199565, 9.031451479081186, 3.7158980773341272, 4.314151704311371, 1.123287511929389, 0.3383316388053279, 0.2724020813982333, 0.7023012986586941, 4.145578040230659, 14.254835555630347, 29.932336345795665, 36.633391995583814, 37.45655628942674, 20.183852064994074, 28.542540573304702, 39.71053846420781, 43.411773250949004, 44.64418588146087, 22.339365097784228, 1.918830107296667, 0.20219594540615238, 0.02118327339450198, 0.07436613897762953, 0.04376290290946922, 0.008688462661549209, 0.06150518130931643, 0.0279385466954761, 0.03176141545296677, 0.04313122511150376, 0.029718149791381536, 0.0637953283806001, 0.042022462228253, 0.11621875568262993, 0.11402674064400697, 0.027740909417550412, 0.026931411121040586, 0.03593469474224314, 0.034753122862668774, 0.014696410489118388, 0.017345770442437743, 0.03156538312924245, 0.026240282984931144, 0.07732707646585281, 0.10993988373346868, 0.018716194486666112, 0.026482288244991537, 0.07476469622023645, 0.061255677963697144, 0.026985655891739076, 0.04748738874050398, 0.030923845779691494, 0.034241594464307835, 0.05544975039459044, 0.061592446384771224, 0.04904877935205737, 0.10085965807159102, 0.07715439258684074, 0.03762736601094085, 0.05560040924577944, 0.06174399772839201, 0.036456906236708164, 0.029139504429974386, 0.04655559982864126, 0.04482448243746354, 0.03113182332937516, 0.012940476637243504, 0.01927719684317708, 0.04130199100942381, 0.09734844728823631, 0.040917043318791736, 0.04374873028287003, 0.6459437647173483, 7.225702568407982, 34.138807712062714, 60.884861561559866, 54.33069867472495, 38.5258924576544, 32.25869997855156, 26.17930469974395, 24.32652411922332, 43.55154298966931, 31.497966089556297, 16.14214279959279, 4.709104472591031, 0.4328021695536952, 0.13504086182482783, 0.7500533363030804, 1.6660318788020843, 4.723708927631378, 8.718059985868393, 8.895587440459959, 10.232897977675162, 15.252915005530081, 9.426527311725001, 11.13726317882538, 10.117645994309457, 12.475484686513102, 17.08351654391135, 36.24895265025478, 44.46087783382785, 56.68322255534511, 58.55569147294568, 62.10192595758746, 59.24265538492511, 59.34171092125678, 55.011131840367476, 51.814710017173525, 51.60435722720239, 57.857560573085664, 60.209531399511526, 60.81065424026982, 56.636809149096095, 58.82001999885806, 57.09894672516854, 57.17822174872122, 58.26322386341711, 59.46334754267047, 59.077696184958185, 58.233464840919744, 47.1918123768222, 44.04544391939717, 49.96788947812973, 52.20475835184897, 50.582893586927845, 45.87566498787173, 42.615120257100756, 41.59520203067411, 40.57735481569844, 43.69906725422029, 42.84772857542961, 50.5519147073069, 52.72238962111935, 63.65833028670281, 30.628921831807784, 33.16131776379001, 53.205021581342145, 53.67080696167485, 56.794496274763546, 57.540252593255815, 56.97384272852252, 59.466206950526086, 58.84628026716171, 59.13568842795588, 56.72807878063571, 56.29531583478374, 51.67978048324586, 44.4426505796371, 47.1186601731085, 55.633921853957645, 59.140057948327836, 57.378160645884854, 54.764104889285186, 56.507163047790534, 59.288551038311375, 57.05267452424573, 55.4080835465462, 47.938976826206336, 47.38116479689076, 47.59230206089635, 48.457722048605646, 49.559076524549916, 53.08989217204433, 55.16406897575625, 56.652643757481734, 56.691938061867994, 60.24702925835887, 59.167620443528705, 56.66532478024883, 42.36859929177069, 34.176136908992646, 21.730764258292414, 16.579654755130893, 15.433233226499251, 11.24158645829847, 16.576479596476403, 13.542590987297798, 15.118516952760759, 8.499057389074757, 7.660595361263522, 5.243978481138907, 2.3317718457791115, 0.37976219469020445, 0.17090405758109786, 0.6858055870379172, 5.564232651264438, 15.488430780749168, 31.569563073496667, 37.1887093974698, 40.72385141926427, 25.981681962167066, 34.67664703246086, 44.90959305917063, 50.06119481978878, 52.68371112885014, 28.271842118232485, 3.029621070431125, 0.2671669736023872, 0.01567009866477982, 0.052725434483539675, 0.03448554750291571, 0.027552785036424478, 0.011226203604300898, 0.08381503679218792, 0.04663364886636696, 0.06863649078314343, 0.06599169479863298, 0.01880774773927706, 0.014628896117961455, 0.04528073376164802, 0.010359185511216281, 0.03408157401868413, 0.03807061682305029, 0.014191232002039832, 0.0368172739962897, 0.043524814273921714, 0.01878000003465962, 0.008928411933142812, 0.013823462875499843, 0.06740598503740565, 0.019512378175051946, 0.07808846827115744, 0.054473474756964756, 0.12752521753070817, 0.1946840549428617, 0.15292201281314896, 0.19058781345525097, 0.23644830340579634, 0.2779219593972929, 0.10632790940543337, 0.1018976612437156, 0.19992250288205765, 0.1992155875890486, 0.19037041302409866, 0.15756308071074948, 0.14220592896303824, 0.1713887767325486, 0.17755298064120356, 0.11204243502429417, 0.12639323069203284, 0.1438963019679631, 0.19697332484347208, 0.0588315382840172, 0.1278757946866174, 0.14939505126207106, 0.18576380376133228, 0.09666821483762995, 0.1796376437789971, 0.9188179094945231, 10.595667208394698, 43.85755062103272, 67.76052151956867, 61.04254868722732, 43.446372478239, 41.69862316500756, 34.11034699409239, 37.6590721837936, 53.75695005539925, 38.59132543686898, 18.772253797900294, 5.119748682745042, 0.4924989275393948, 0.4115466617288128, 0.9347365424036981, 2.3549822261256557, 6.6936350157183995, 14.543158200479324, 16.366225846352116, 20.317495061505227, 27.203413978699718, 26.789701984774684, 16.408665891616575, 12.07416836292513, 12.803772361047807, 28.186612936758227, 42.32571601867676, 50.03717422485352, 58.675029585438395, 61.173285207440784, 63.38682382337509, 63.56798241215368, 62.42206196631155, 56.96888093025454, 54.23009380217522, 54.141405090208984, 59.31692546413791, 63.008534754476244, 61.998496978513664, 56.614843876131125, 60.13104084999331, 58.11827267369917, 58.60244612539969, 57.13716237775741, 58.79013546051518, 61.62291826740388, 61.685452615061116, 51.34912075534944, 45.69107824756254, 52.03198971286897, 53.817095679621545, 50.66040354390299, 47.40904892644575, 44.89258566210347, 43.678608171401486, 41.99112999823786, 46.950339501903905, 46.654996795039025, 53.922242656830825, 55.63687147632722, 65.18936472554361, 35.3270976005062, 36.92874254718904, 54.3666236631332, 53.52245899938769, 56.8406351151005, 59.87081904565135, 59.439715262382265, 62.02835013789516, 60.05524496878348, 59.41283918196156, 59.74146319973854, 60.18982148939564, 54.889620734799294, 47.51458814067226, 49.23587714472125, 58.99722483850295, 59.62684369856312, 58.69348041472897, 54.999384341701386, 57.29722645974929, 61.8109017802823, 59.43927595692297, 59.62320766141338, 50.3892187149294, 49.02261395608225, 51.05930074568718, 50.9220060225456, 51.902833907834946, 54.45195090386176, 57.87799219931326, 59.2812083613488, 57.87617614192348, 60.732379421111084, 62.15130859805692, 58.70484744348834, 44.59922375217561, 36.712282626859604, 28.12252925288293, 26.377988438452444, 21.206235501074023, 12.863744420389976, 27.261239520965088, 25.015196223412794, 25.928655439807525, 20.204724957866055, 14.562754361860215, 7.386012779128167, 4.023536434096675, 1.0061018613557662, 0.5575709874110838, 1.0142757130726692, 5.960336635189672, 18.103028805025165, 37.48470714015346, 48.94261721641787, 50.750971071181766, 31.124338757607248, 40.895968944795676, 51.07083643636396, 58.84229906143681, 59.48878411323794, 33.99007927986884, 4.691405757780998, 0.4562582802628318, 0.13840384991659274, 0.15903283571524007, 0.21449107436403153, 0.12814823853512927, 0.13400702617101132, 0.26777828112244606, 0.1426141772178873, 0.21262044087052348, 0.12279467822443094, 0.2259417599247348, 0.12692394576245739, 0.31252903142763727, 0.13849711346049465, 0.22958188798398743, 0.12120860809039687, 0.09202414387536627, 0.2135510844809394, 0.1117145264100644, 0.10495444399214561, 0.114596058884936, 0.18235319564419408, 0.23747732802744836, 0.22013079915796557, 0.15042061316630534, 0.21235557363158275], [0.06803439930081367, 0.04529076951345609, 0.04279317732359614, 0.0692295271062082, 0.01899610386200009, 0.062230731691083604, 0.05406846322359578, 0.033635419733341665, 0.030856410890156706, 0.014326451308724862, 0.015699413976812317, 0.09184527766680525, 0.08076245220558298, 0.015036453936068762, 0.04750235043766518, 0.10644764894799841, 0.0676348461439052, 0.0019801091337050764, 0.03344169141904962, 0.015613187908104833, 0.035243442116846005, 0.07458254349448028, 0.006228948871965611, 0.08306671444687151, 0.07742875165516332, 0.8186292371922924, 9.638818733153805, 35.70156235848704, 49.206451523688536, 42.10232919262302, 35.07015881999847, 25.244580353460005, 31.75486956873248, 47.44167520153908, 46.7089254625382, 33.1787173978744, 11.674332734077208, 2.270121992595734, 0.23868960088058827, 0.0032820631120909728, 0.9541751348203229, 0.715510125362104, 3.5214473114859675, 10.094394183927967, 6.826399401310952, 8.413999811295541, 11.820580267137098, 7.518239800007113, 12.56133556365967, 10.849405334841821, 13.539214807171977, 12.956504552595078, 38.719622242835264, 45.72121381759644, 57.355371675183704, 55.799367427825935, 61.25739651341593, 58.04568529129029, 57.547293247715125, 53.90695718026931, 53.29144316334879, 49.67273504503312, 50.3096063675419, 51.2003452547135, 54.09811389061713, 53.330541349226436, 56.51352513221003, 55.71682114754954, 59.405194482495716, 57.52179784159507, 61.00445855048395, 58.29592858591388, 59.14348609985844, 55.82634548987112, 48.18653721963206, 40.87961658354729, 39.4837744774357, 37.737092048891135, 40.71020941580496, 37.70563856247933, 46.22011969166417, 42.45551509241904, 44.69364696933378, 38.632388730202955, 45.742123972985056, 43.8117608716411, 63.26666201314619, 33.382500217806914, 37.85374726018598, 62.623565889173946, 53.57192793200093, 61.6589177808454, 54.07851380686606, 58.38009088270126, 53.74093894035586, 59.98808222432291, 54.08031809714533, 58.94715186088317, 54.586072429533935, 53.90699640397103, 42.51064008282077, 46.281100780733176, 53.95630059703704, 56.16293584146808, 55.236817175342196, 53.550476489528535, 52.94895748938284, 55.784285914513376, 57.696888523717085, 54.01515183910247, 52.72395072444793, 49.98030770209528, 46.850519103388635, 47.15290638708299, 46.99041435795446, 46.12200160180369, 46.35499823477961, 51.720953602944654, 52.2198869336036, 58.65721418011574, 59.278368565344046, 59.896863583595525, 41.426289081573486, 37.02053777633175, 29.30685558626729, 12.286600989680137, 11.40985711928337, 10.68886370428147, 9.784245510255138, 6.669213358433017, 10.013687495262394, 4.059182934222683, 3.8719603611576945, 6.27168849591286, 1.4303733047939118, 0.3580136020337382, 0.027940477237045288, 0.2758982002494797, 2.7305322549035473, 10.486163458516522, 28.389819168275405, 28.964736653912453, 27.546033013251524, 22.09288335615589, 21.14636052039362, 44.37294613930487, 50.90433574491932, 43.38633668038153, 27.07752746920432, 4.882488923688089, 0.6455995154476936, 0.047978688587224295, 0.0682768048418145, 0.03387510949265092, 0.008646761623000907, 0.04878129592285522, 0.13971557630406273, 0.03704261875921681, 0.06597190674754881, 0.09990200986184421, 0.012861238248015364, 0.031174672542199976, 0.04424770250015202, 0.03477727761492133, 0.0920605177300111, 0.039380094742462526, 0.06516324731731607, 0.017316251159495404, 0.011114610449200677, 0.02878446672712603, 0.03929426225142614, 0.05002943318217032, 0.00396066164079633, 0.07144231844933764, 0.13626536144123924, 0.0893113729093344, 0.028850842500105504, 0.02257615530623063, 0.01471623014132943, 0.025608645406581705, 0.051684083507185986, 0.06809544884749959, 0.0431966107158411, 0.048141539727728215, 0.08374101737694395, 0.01328956566735982, 0.013952758407310374, 0.061303282667311935, 0.05025182467614932, 0.06582219018450668, 0.05648977220839551, 0.02322095619033902, 0.05124947033642281, 0.029988174717272484, 0.023445008179893898, 0.02468842250715581, 0.020782040589819514, 0.04655889017627605, 0.04513829886432617, 0.036896774770631906, 0.039328812816811186, 1.0522704259041817, 10.887592550246946, 42.73283450834213, 56.208827572484175, 49.70866787818171, 40.516307046336514, 32.82017746279317, 30.349474530066217, 42.902622145991174, 44.63377591102354, 32.44456541153693, 13.538166553743425, 2.5950006371544254, 0.17553983947202084, 0.11224850501504638, 1.0067850892101566, 3.867767347443489, 8.048823225882746, 8.640756933919846, 10.92226238020005, 11.39891076472498, 12.476275044102824, 12.424829236922726, 8.83015053887521, 7.4013938634626335, 15.21808533899246, 18.612313270568848, 36.16851268276092, 45.44394539248559, 58.233786475273874, 58.40547254008632, 61.705954843951815, 59.744754068313114, 58.744110368913226, 54.9200544049663, 55.43488902430381, 50.87500033840057, 53.90410561715403, 54.05437946319581, 57.5380874449207, 56.378642666724424, 58.351559562067834, 58.46480231131277, 61.540815214956964, 58.81421096863286, 60.48030830198719, 59.380044244950824, 60.67621108024352, 58.25862292320498, 49.61506051401938, 41.33878100302912, 41.28089466402608, 39.74592216553227, 42.07534720820766, 39.64225784424813, 46.91904683266917, 44.71039941233974, 46.34419602732505, 41.604035208302165, 48.340596152890114, 47.21572314539264, 64.78989878008443, 35.55233970765145, 38.720387105018865, 60.42743475206437, 54.44463568349039, 62.57908621141988, 54.495449989072746, 59.809116240470644, 55.8714174455212, 60.0463294213818, 55.06810426712037, 58.96493980961462, 56.666638774256555, 56.613365142576164, 46.049355383842226, 48.54482612302227, 55.80093245352469, 58.48662637895154, 56.152922030418154, 53.59211244890767, 53.51377879419635, 56.878023147583015, 59.05515432357789, 56.8114762152395, 56.43226538935016, 51.92423043712493, 48.94772022001205, 49.45568676917784, 48.97155646354922, 49.435172773176625, 50.72984518543367, 54.522945803980676, 55.430201791947894, 62.4267727328885, 61.33798553097633, 59.23916055310158, 42.1371441502725, 35.543290799663914, 24.71140669238183, 11.221954995586026, 6.184896249924937, 11.966179628526012, 15.662818378017796, 15.949158264744668, 12.549875378608705, 8.33529745378802, 9.746743729037624, 6.767419701622379, 3.4313340437027717, 0.5121977140586222, 0.17228318438414605, 0.4040563443014699, 3.3644480714874887, 12.328288920464056, 28.748847438443093, 33.77508240361368, 31.96536944758508, 25.218492669443933, 24.46586631959485, 47.95756493845294, 57.47241127875544, 50.607498615018784, 32.41112916700302, 6.5100695625428235, 0.5481067984815567, 0.010797053598047746, 0.07447110068413519, 0.03809656422104567, 0.05062176853478436, 0.042327575896295815, 0.11708045904073985, 0.08697805295307791, 0.07183945842928464, 0.07080510183567963, 0.06105217436749128, 0.015851714171379084, 0.018186730054777958, 0.07301266845916549, 0.043610711882431666, 0.007971888915034793, 0.00968623185350049, 0.018478329931836457, 0.030661010588969917, 0.04793497561026485, 0.03439325306023802, 0.04781065486191262, 0.08862322677047023, 0.08335373694858245, 0.016286682615417148, 0.03747306058123227, 0.1583275445286305, 0.17047987469742376, 0.20225593009062354, 0.22200081978113423, 0.1253302683753352, 0.2035738771120387, 0.10933900267005929, 0.11479695778219931, 0.1584186783481029, 0.09739894780420488, 0.08863290246095389, 0.20687963843585985, 0.148906409740448, 0.13253711794893588, 0.21858923107145295, 0.20649962818189976, 0.17326605986923943, 0.07345431048663394, 0.14049468772305598, 0.08235800650811965, 0.17719819000171078, 0.19451672601844036, 0.11468528514547695, 0.16755845968521413, 0.15081962240078758, 1.6145077467926088, 14.62377565522348, 50.258756760627996, 64.22588156115624, 58.03172949821719, 44.43022058856103, 38.827393285689816, 42.88078631124189, 60.55811635909542, 55.514313097923036, 38.54391574859619, 13.54183396985454, 3.3367804077363785, 0.3440180949626431, 0.3954529011201474, 1.6886353949385307, 4.87469909652587, 11.99597885531764, 21.43994208305113, 19.477797977385983, 18.686895178210353, 19.88448108396223, 14.589860881528548, 22.48669324382659, 19.432004305624194, 21.779346735246722, 17.28171390871848, 41.47878216158959, 47.6319533009683, 59.99142800607989, 57.862906763630534, 62.49572800051782, 60.842774529610914, 62.44203859759916, 56.730891120049264, 57.55311012268067, 54.29842149057696, 57.15487187908542, 56.791150493006555, 59.88644576841786, 57.79482226217947, 61.694458376976755, 61.03873222104965, 63.552398835459066, 60.276886340110536, 61.03630035154281, 59.94340642806023, 63.29773502965128, 60.92588563119212, 52.787661783156864, 44.58954334259034, 43.51420594799904, 40.9620608821992, 45.12438204980666, 41.217822951655236, 51.16680898974019, 48.05697741047029, 49.13254230253158, 43.56276489073231, 49.577311623481016, 49.81365403821392, 66.94337414157006, 40.482700178700114, 41.4226608891641, 59.96701909649757, 57.111431629427024, 66.54598312993204, 57.935643196105964, 61.85034121236494, 57.523649200316406, 62.823387115232414, 54.65238794203728, 60.71785488436299, 58.99516167179231, 59.27239479557161, 48.29392387020973, 51.48348939034247, 59.58668255036878, 61.21485056415681, 56.8357321523851, 55.53202259925104, 53.110119835022964, 57.591329697639715, 62.19982831708847, 60.02234805014826, 57.246482756830034, 54.52397346496583, 50.49609545738467, 51.918644981999556, 50.82926157982119, 52.12583241924163, 51.465972085152906, 57.038463777111424, 57.49069736849878, 66.49866365617322, 64.10133454107469, 63.26124129756805, 45.73743281825897, 41.43806011446061, 33.533484012849875, 16.652865794397172, 16.932191502663397, 18.670889946722216, 21.10389497972304, 18.233822199606127, 16.512943083240142, 11.795667332987632, 13.315248450925274, 15.55080823359951, 4.080818482945043, 1.312176111725069, 0.5969243112110323, 0.7782049837612337, 4.040909101886134, 14.376932074946744, 36.838202476501465, 40.08715660341325, 39.12962759694746, 31.97135106209786, 32.25120629033735, 53.916504229268725, 66.21688842773438, 58.143928896996286, 38.87564236117948, 10.582400771879382, 0.9067548438906671, 0.26858984402591185, 0.16603048199847822, 0.11482389343361701, 0.11369441936333334, 0.0949587126172358, 0.2683371269414502, 0.17441441034597738, 0.1961135290442936, 0.1896770421655909, 0.19760704809619536, 0.1234855056710301, 0.10115163716217203, 0.13865017782776587, 0.23363130617766614, 0.1556434788771214, 0.2273346456669031, 0.09565011462977818, 0.091559948219407, 0.11640705243353883, 0.18514163311450713, 0.17196357250213626, 0.19416552067043322, 0.19690569460151658, 0.16692064552297517, 0.10466317736333418], [0.06112486462018663, 0.005556822110403089, 0.033831986403393174, 0.047727672217954556, 0.032415007196006276, 0.051648226761890036, 0.012346228937648479, 0.05641179594902262, 0.03500807309342969, 0.06257519163491745, 0.057270182146420406, 0.008719830131608873, 0.03655393127231829, 0.0723467848353809, 0.091096265842357, 0.02811499781185581, 0.05094608802708888, 0.023339106100461176, 0.04534721487171708, 0.041150838031523654, 0.04035285403651576, 0.05950916986612063, 0.06745309178386966, 0.019080346720593593, 0.027739231684996236, 1.9198773801326754, 15.549265761529247, 40.95557720430436, 49.06587377671273, 41.68065478724819, 27.27439318933795, 23.283118740204845, 46.62373158239549, 52.5244079866717, 51.18011759173486, 29.767661517666234, 9.385524815128697, 1.2318080952090602, 0.2354730734781873, 0.38575998897994723, 2.7075694741741305, 5.778652448807994, 3.9152118467515518, 3.171092627509948, 5.893977486318158, 7.387871982589846, 11.431838081729028, 4.643039501482441, 8.154494329806298, 10.571768206934776, 22.476677471591582, 27.386161127398093, 36.82914964614376, 49.10504256525348, 56.160452981149, 57.61250657420005, 58.006834214733495, 56.815163243201475, 58.548446855237415, 55.17966824193155, 55.28841203258884, 52.03036977398781, 50.32252665488951, 48.05181949369369, 48.764847555468165, 48.13531498755179, 50.25957653599401, 50.65946217506163, 55.67866433051325, 57.59878612333729, 56.563700091454294, 58.415949190816576, 57.87446206615817, 56.88362036981891, 53.88723942541308, 45.58157743946199, 40.81923169474448, 39.32033323472546, 39.71925789310087, 48.02136621167583, 53.20286427774737, 51.32458240755143, 48.77383762790311, 41.33339166641235, 43.49015005173222, 46.53710995951007, 56.321717308413604, 42.78651214415028, 39.852830286948915, 61.14999809572774, 52.63055124590474, 55.37581420713856, 49.04832509256179, 54.01245717079409, 53.26307265989242, 55.95521888425274, 53.972821620202836, 58.05260042990408, 54.80465827449676, 57.222807330469934, 45.897689096389286, 40.86702577529415, 54.66540236626902, 55.40665580380348, 57.52919935411023, 54.03389684615597, 53.80195533075641, 53.33735058384558, 57.53052903759865, 58.174362567163286, 53.36184578557169, 54.00782877399076, 52.74892837770524, 51.84104481051045, 51.45415006145355, 50.96327720149871, 49.00089971480831, 49.86259345085391, 51.90335558306787, 57.7316838695157, 58.84956329099594, 57.94674350369362, 47.2362018400623, 34.847885947073664, 15.551577998745827, 14.87687933829523, 9.596197278268876, 15.813399149525551, 14.248411693880636, 17.346336918492472, 15.346431174585897, 6.548929954728773, 7.951186116664641, 2.759187375345538, 3.113284000465947, 0.44722536819115766, 0.05034036528799803, 0.19632123080232453, 2.1945381645233404, 8.697264559807317, 24.504229061065185, 43.50551005332701, 47.837144251792665, 41.965909158029866, 39.84800969400714, 39.83639163355674, 39.85043371877363, 45.835774483219275, 30.180583154001546, 5.450379973457706, 0.7863181000274997, 0.07443945359198317, 0.03167510415697771, 0.01321346823862123, 0.026063410520193078, 0.046348782902162884, 0.10289952038757263, 0.03951084679893909, 0.03031046407657766, 0.04355860641226173, 0.03694362487764128, 0.0208910683079833, 0.02393868864483891, 0.044283210675442414, 0.032809435224701325, 0.04552243067131889, 0.04285724142626409, 0.059874237575117624, 0.014308055622443078, 0.04628476093433077, 0.035481048117001215, 0.010056646856208964, 0.021396822318614974, 0.015474433105649247, 0.05633213812665594, 0.026716400884212028, 0.04873378314979134, 0.03590930275799286, 0.011883841249190513, 0.014844776822193978, 0.06625524436634395, 0.04401444787940672, 0.04294823734991012, 0.059730653545909354, 0.0741027043231072, 0.05425960599114338, 0.018041318905870282, 0.021516056243149985, 0.04492836012955635, 0.04983807974044354, 0.017805760275692712, 0.03910112382483579, 0.07023495621979237, 0.09551032656623472, 0.0669298920359823, 0.06260343729668567, 0.05292731780378569, 0.038843082429300395, 0.05380487152104897, 0.052355977090736555, 0.036879832736186446, 2.387663414401393, 17.18396059928402, 45.37753182072794, 54.247411066485995, 47.02943017405849, 31.343214857962828, 27.64697324845099, 43.8142123529988, 51.3411504991593, 50.32344056713966, 33.12050157977689, 11.474017289377029, 1.7782000211938735, 0.07962208436501604, 0.22428641245970804, 2.0252654605334808, 7.2756264959612205, 9.35071966340465, 10.063118184766463, 10.434751972075432, 10.001704654385968, 11.569201446348622, 12.68287902878177, 10.072912343086736, 9.863747050685268, 15.109976972303084, 27.9163126022585, 41.016436699898016, 48.860031712439756, 56.43525423542146, 57.5824769081608, 58.96392783811016, 57.656272380582756, 60.593731480260054, 55.813362444600756, 57.841369029014345, 54.63614932952389, 54.01949390288323, 49.83651361157818, 50.537088148055545, 50.27126127673734, 53.52089005131876, 55.0999774471406, 58.50766597255584, 60.05091074974307, 58.81507781244094, 58.449952217840384, 59.88925418546123, 57.89740793166622, 55.50022394426408, 48.241395488862075, 41.855819994403475, 39.86588785725255, 41.012306444106564, 48.17604880179129, 55.82617682795371, 53.19985974219538, 51.19256327229162, 44.44549429801203, 45.80117917829945, 48.41461127804172, 59.86791256935366, 45.454645618315666, 41.534064046798214, 61.64739777964931, 55.19858191090246, 57.11975882130285, 53.04917796965569, 57.28447483431909, 55.00199664023615, 57.87498766376127, 55.83569249799175, 59.77530540958528, 58.212586064492505, 59.043124414259395, 46.762532495683246, 44.950648507764264, 57.51018762588502, 57.20305035191198, 58.13465249153876, 55.65354939429991, 54.29567583145634, 54.105499713651604, 57.08122545673002, 60.731810677436094, 55.742959822377856, 55.95090427706319, 54.62503725482572, 53.35477767452117, 53.164299534213164, 52.6423732696041, 50.69082544695947, 52.9129187522396, 55.71466384395477, 60.294309508415964, 58.785310945203236, 60.3683913138605, 47.94511533552601, 37.28158720078007, 22.509268445353356, 13.886171983134362, 10.575483672080502, 12.245972098842746, 16.83660138037897, 12.55329470480642, 14.439393858755789, 9.583199524110364, 10.129068916843785, 5.620230859325779, 3.7742068065750987, 0.452465501523787, 0.010079041521455492, 0.2648988630502455, 2.0680446682437776, 9.794602528695139, 24.9243619749623, 42.794368651605424, 42.30053440217049, 36.86024227449971, 37.01356772453555, 44.134313060391335, 46.772056010461625, 53.039591696954545, 36.113026834303334, 7.448053888736233, 0.8176424546587853, 0.048376058393548575, 0.053796574788829016, 0.041529185874688054, 0.02860457396074649, 0.05524404429560227, 0.07430353427245733, 0.04258600799667259, 0.07841166544465289, 0.05814981196195849, 0.03617476754551453, 0.02328658502759232, 0.05449564917193306, 0.03758088745657475, 0.06313527468591928, 0.04471746378488118, 0.05420500690477991, 0.053270778002878355, 0.05927949287598172, 0.06622932761186553, 0.0459281278533801, 0.032528196686818715, 0.05926899747141908, 0.04189575511601664, 0.04084245316804417, 0.01166516145120465, 0.22484622354949677, 0.14903544959041382, 0.0827647149262409, 0.12778708936586497, 0.13015797061304893, 0.156677758861934, 0.10969326470888431, 0.1605318859219551, 0.10452220952438732, 0.13366360427631488, 0.12273229568475678, 0.13465312940459098, 0.24524418787369806, 0.162395793163488, 0.2764509173650896, 0.09364320941629911, 0.22819684698216378, 0.14753950970067134, 0.1326330321570558, 0.159563658037974, 0.12646544980065477, 0.1325920617748653, 0.1540994593092511, 0.1350032928730211, 0.08559418406577841, 2.967740287703853, 22.106054675194528, 52.51365284765921, 62.58491093112577, 55.242418319948264, 39.00093855396394, 36.17015223349295, 58.7667267553268, 64.1398012253546, 56.77464908169162, 34.628849029541016, 11.8955308775748, 2.328617524716162, 0.29267914172622467, 0.750090966541921, 4.435799112243037, 10.349283526020667, 9.49256923890883, 13.568952256633391, 16.66874747122488, 17.062361240386963, 19.05343674844311, 15.231893062591555, 18.27837051883821, 18.17231551293404, 29.51727309534627, 32.2980119336036, 41.97604064018496, 49.42072668383199, 57.031791825448316, 58.08843520379836, 59.39980906824912, 58.324240253817656, 63.07335976631411, 59.16738510131837, 60.747037318445024, 57.54006431948755, 55.177503093596435, 52.853322259841434, 53.35504047332272, 52.0144449510882, 55.600766058891054, 57.06803844821069, 60.40247671065792, 62.867902094318026, 58.442656609319876, 59.12407036750548, 61.61985097392913, 59.76392269134522, 58.5149262797448, 51.09931284381498, 44.32567373398812, 42.77927144881218, 44.2842338931176, 51.91745650383734, 59.51389904945128, 57.28856586640882, 54.12262085945376, 46.69658176360592, 48.08494783216908, 52.614159660954634, 59.648479492433616, 50.30303639750327, 43.55592819952196, 62.92347031254923, 58.405272499207534, 60.06177571512038, 55.01088473104662, 61.59611278964628, 58.38999094501619, 60.37742453236734, 57.995208309542754, 61.73374483662268, 59.868818636863466, 60.49603700637818, 49.02422212785291, 45.16700252409905, 60.185408822951786, 58.891250241187315, 59.835890339266875, 54.453845408654985, 54.60252285003663, 53.49316673894083, 58.45746747909054, 62.5665581610895, 56.735095900873986, 58.65792412911692, 58.45060333128899, 55.79178156391267, 56.39881933889082, 56.625022426728286, 53.76163728775517, 55.191607936736084, 58.24951910203504, 62.12069842123217, 62.3259795865705, 62.11683880898261, 51.15102929453696, 41.48282612523725, 20.995690514964444, 20.348879906439013, 18.75811561461418, 28.66221404844715, 21.805230456013835, 23.613996159645822, 28.370848624936997, 19.052175706432713, 18.88913062310988, 9.038910846556387, 8.3703810937943, 1.8922434242502337, 0.47901397210455715, 0.535246878862381, 2.9799797986784293, 10.981370537511765, 30.254160934878936, 53.503478650123846, 58.976197012009166, 52.28386079111407, 52.54140753899851, 49.61934374224756, 54.885584615891986, 62.255667178861565, 43.69026153318344, 11.349431045593755, 1.0483650935273017, 0.15917712071489903, 0.13932125552767707, 0.12570350641204467, 0.1017333813492329, 0.12323276560393073, 0.2658550020667815, 0.11253544324708563, 0.16629216231165395, 0.1405580891596694, 0.12939741384358178, 0.14988312587863015, 0.15765075181280414, 0.15685213579525872, 0.15335220182614942, 0.1514693722128868, 0.19055326288986593, 0.23115941623766578, 0.15120019955981165, 0.1577759152578731, 0.12435773507721963, 0.09948650675435221, 0.24878846301186472, 0.12240328390391604, 0.20688541473880892, 0.06898357457811795], [0.03650926451589312, 0.07350850354639754, 0.025515789804499478, 0.04800088598483032, 0.08003849911713794, 0.053116637282073505, 0.045896373508918675, 0.05633941213149698, 0.02072117298901562, 0.06244853814883579, 0.06578543328589971, 0.017941995606487317, 0.047637220216734756, 0.1302764231279012, 0.06558529281568143, 0.1630283366408079, 0.04139686716840633, 0.06231664079091242, 0.014324770703340971, 0.0007119482512690969, 0.027450485485455686, 0.05194946402503599, 0.028326658329235452, 0.012198250436584556, 0.0274781221073241, 1.3545114787355548, 19.18681106259746, 40.790253223911414, 48.921612924145116, 37.54749644187189, 26.46778521999236, 43.9083335476537, 60.36122514355568, 57.74150156205701, 49.9717334008986, 20.54724201079338, 6.781711837937755, 1.0027543635618303, 0.1393164751390296, 0.6488117527577185, 0.8792057705502357, 5.53739530424918, 14.846822215664773, 9.65567413837679, 7.2057009320105285, 7.813000034901404, 10.582918524742126, 17.784628445102324, 5.896138712283104, 5.011583441688169, 16.477694703686623, 34.66850026961296, 46.518306116903986, 53.02790695621122, 54.59428587267476, 55.189254514632694, 57.33346916014149, 54.48547147935437, 57.238151642584036, 56.09971507903069, 56.765349142013065, 55.280943839780754, 54.75791538915327, 52.18874723680558, 50.40129569268996, 47.22021033686977, 43.651524205361646, 41.3156468637528, 47.18790569613057, 51.325198219668486, 58.2654203907136, 56.30145826647359, 55.91823485589797, 55.23384794112175, 54.056987839360396, 45.30169279344621, 40.20535722855599, 37.49944740726102, 45.82934571850685, 54.271768985256074, 60.27625876088297, 55.232934028871604, 52.69527035374796, 44.99660299670312, 44.27629109351866, 44.535924542334776, 58.72458481019544, 45.56431508833363, 45.2492703160932, 61.09949757975917, 50.59324472181259, 53.18497434739144, 47.32733418864589, 45.61726316328972, 46.02153793458016, 51.141023328227384, 51.81297632955736, 55.80031271903746, 54.7795747172448, 56.547669364560036, 44.953762869681086, 40.98132364211544, 50.45190211265318, 55.79686103328582, 56.16710532096125, 56.180821849453835, 53.550829502844046, 52.450459541813025, 54.11245799833729, 57.00916367192423, 57.03778912944179, 54.468334644071525, 55.199844914097945, 58.38753554128832, 54.47335527789209, 55.01832938963368, 52.87727617448377, 55.755833041283395, 55.30402698824483, 58.03380050966817, 59.11582554540327, 60.336737786569905, 46.161637152394945, 33.40732882099767, 29.075878973930116, 14.2545090183135, 1.8110867661814538, 6.273425125306653, 16.831074760806178, 14.398078553138243, 10.310791346334643, 4.69143174348339, 8.83468872116458, 5.388774737235039, 3.273316703496441, 0.5920214097826713, 0.17479737769932518, 0.04112797030698388, 1.006044619266064, 7.278191726053915, 23.60258206244438, 49.01276488457957, 72.16218179272067, 57.37663484388783, 39.2729627701544, 30.57332027343012, 39.874744569101644, 52.874106899384536, 30.80000581279878, 10.87199426466419, 0.5735486397339452, 0.10697785073951369, 0.05465170511254861, 0.058534215730164325, 0.04093524173743302, 0.0668158675093324, 0.0672004436473212, 0.021114375277031815, 0.0553729807236983, 0.030989564632275896, 0.05309440158007126, 0.05596872516757539, 0.012648753228507215, 0.05113341950721318, 0.04492905343912783, 0.013392765371639644, 0.033473108684824365, 0.04131704846757554, 0.019684594740430196, 0.026342605518537666, 0.018154851221028837, 0.0840207620433742, 0.0284273931456189, 0.024413314587887258, 0.036703739765911333, 0.018561770313329274, 0.03997797657164835, 0.04322774835952348, 0.02699616278762058, 0.035379633397584966, 0.07827858831132613, 0.023965294878449173, 0.06888721603900194, 0.04965111981296251, 0.011714330889404783, 0.012809559871863215, 0.005529262576132052, 0.050943031336271, 0.018068995747354724, 0.0773647143655727, 0.024788760873038444, 0.03427577347704961, 0.003268941701765383, 0.036428499696475845, 0.0206183678200168, 0.05407895862815842, 0.03357003029856471, 0.004758739002769994, 0.03063037281765813, 0.041981285002322934, 0.006808484810584736, 2.004400902698117, 22.106958781519246, 46.7073525920991, 55.03042990161527, 44.32707794250981, 30.15173019901399, 39.60538756462836, 61.44916511351063, 64.7615243542579, 54.363897615863436, 25.80931144375955, 7.315759206971816, 1.0141914434009984, 0.1500051023979341, 0.6137486439078086, 1.7065057134436024, 4.986941151080593, 10.930822953101128, 8.352236209377166, 11.411508437125914, 15.26353580336417, 17.43611408818153, 17.242327428633168, 9.10174721671689, 9.448636731793805, 20.27377240119442, 33.550193309783936, 45.076525211334236, 54.17277228447699, 55.10222104287917, 55.908942760959754, 57.29462200595487, 55.75873167284074, 58.13859055119177, 58.51689923194147, 59.810645964837846, 57.24276042753651, 57.22840455270583, 54.206265403378396, 52.48135212929019, 49.952807964817175, 46.09557267158262, 44.93752817953787, 50.79751783801664, 55.26112802567021, 60.60753430089643, 57.20619609279018, 58.222462592586396, 57.221532560163936, 55.761194921308956, 48.10760344228437, 42.42875276073333, 39.82252997736777, 48.73155447744554, 57.231075686793176, 61.54513374451668, 57.31528505202263, 54.236216622014204, 47.17638569493448, 45.46995070672805, 48.06055461206744, 58.167502341731904, 48.63940623498733, 45.97104134098176, 62.46296052009829, 52.849380277818256, 55.272961816480084, 48.45958125206732, 49.25877201941706, 47.81046428988057, 54.041353271853545, 53.82639561930011, 58.45360002210064, 56.993391821461344, 57.90611167107859, 47.247388439793745, 43.53176639926049, 53.63466624290713, 59.11350350226126, 57.56770918446203, 57.5590838924531, 53.73804423116869, 54.408757763524214, 53.830588633014315, 58.710950651476466, 57.89464266069474, 57.43762770006734, 57.31783851500481, 62.036504745483406, 57.93561181714458, 55.897246253105905, 56.804447327890706, 57.833881224355395, 56.89021387407857, 59.41503178688788, 61.958422122463105, 60.92121016594672, 51.15684616950251, 36.94015272202031, 23.078169015146074, 18.35642764645238, 9.113924214916846, 9.550914495222031, 14.289032739977683, 20.20623310919731, 13.264838149470668, 11.060823048314742, 12.134727797200604, 8.077701676276423, 6.329588072915231, 1.7226957866261083, 0.3995252100210036, 0.10339397651654098, 1.382867763600042, 7.50651877733969, 24.21027095087113, 50.909627022281775, 72.2534082781884, 59.99951593337521, 44.45378226618613, 34.72541386081327, 42.38409265395134, 59.35765927837741, 35.752984631446104, 13.24290817783725, 0.6308950399679523, 0.01660470678020389, 0.04812832471103438, 0.013499125188607122, 0.06741255807179598, 0.07811001832446746, 0.0424552712619545, 0.03220176662228281, 0.041176781599079414, 0.042751624714583165, 0.06036935637014047, 0.05178811058642403, 0.057586063180238976, 0.01296477120054225, 0.0129147035242509, 0.0378788496938444, 0.032669566721925815, 0.018006643851197535, 0.027547686721288392, 0.04812504585471846, 0.04155880666428036, 0.020877029746770862, 0.02789520335594012, 0.06406648520139918, 0.02994036508513795, 0.013577062185973892, 0.130528956351261, 0.1524173294103915, 0.1311554324122206, 0.1084254198377171, 0.15592051159229972, 0.17372373611696307, 0.12458518658193851, 0.15929112991979047, 0.13956105636973537, 0.10506725043899591, 0.12815760012956398, 0.1516735959317415, 0.14776565885591894, 0.2765608356604653, 0.20867530256509784, 0.2743254217409319, 0.0933443431952788, 0.13746517770473035, 0.13864971817501132, 0.08397020024037169, 0.1603700728305886, 0.13082492675992752, 0.1652437097002422, 0.148873437316187, 0.1550877127315729, 3.283082914929236, 27.301761527215284, 54.843960423623365, 63.991115939232614, 52.03150726133778, 39.908684838202696, 54.060749392355646, 67.97263545374717, 64.43475169520225, 56.21238516223047, 26.37810414837253, 9.194244550120446, 1.4626095492032267, 0.40554868357796825, 1.0893716350678475, 2.1026054072764615, 11.432193056229623, 23.412576567742136, 18.211007733498853, 17.046860033465972, 20.155740437969087, 22.676910546518144, 30.264231620296357, 16.601975002596458, 11.710887262898108, 22.091002579658262, 41.24277707069151, 50.3040522913779, 56.99837715395036, 57.23655131555373, 55.969394330055486, 59.02666614901636, 54.73311032018354, 57.73772824195124, 58.32337341000957, 61.14231025019, 60.137257806716434, 59.70309849708312, 56.615628350165586, 53.90857711915047, 54.09062216358801, 47.885546299719046, 45.60116575610253, 52.533754994792325, 56.29460588578255, 63.57960831734442, 59.78634295925018, 59.35627075933642, 59.67036239562496, 58.21739489032377, 49.62981254823747, 44.13790202909901, 42.64500479544363, 50.45158047829905, 59.5759117218756, 62.35603278683078, 58.29111583771245, 57.7703349051937, 50.597061187990256, 48.08850934428554, 51.97597434443813, 61.22731585656444, 52.27732220003682, 49.50057045105965, 63.18520222940753, 56.73639028303085, 56.53831843406924, 51.882618011966834, 49.82114184287287, 50.225138125881074, 55.69476173770044, 55.632925571933875, 60.79009709819671, 59.264067603695786, 59.66884443836828, 49.9053394409918, 45.085103434901086, 54.70668531233265, 60.92629355769004, 60.1295974177699, 59.25375961488294, 53.699518711336204, 53.485471048662745, 53.997532552288426, 59.33632158464002, 60.56020698239727, 58.87653743067096, 59.6703153271829, 63.503671230808386, 59.99818232751662, 58.857004027212824, 58.32464033557523, 59.94634820568947, 60.604353258686686, 61.78764604753064, 64.54306794751075, 64.40077220239948, 52.7489479895561, 40.39848296873031, 35.403858384778424, 20.970916824956095, 8.902713406470514, 13.168219385608552, 27.4488268744561, 23.187824756868427, 18.399779642781905, 17.161126521325883, 19.11106813338495, 14.80750241587239, 8.4380704164505, 2.5434952589773365, 1.003855630274742, 0.5215147834631705, 1.6169540800394553, 9.246615056068666, 27.2508099386769, 54.742120004469356, 79.48822790576567, 67.03675008589222, 50.53553096709713, 42.807951819512155, 52.132190581290956, 69.12176439839025, 44.685896365873276, 16.40923365469902, 1.1692598966821548, 0.13587749112517605, 0.17120853156572388, 0.12476241336234155, 0.22762116255058398, 0.2390583802855784, 0.11382215686382786, 0.09387620739758977, 0.21461027764504959, 0.10857862976169395, 0.172475932105895, 0.1390123688766072, 0.09227834717040101, 0.1965426302124416, 0.0831540484702395, 0.2959829112214427, 0.10780757758766414, 0.1117135611392798, 0.1367732930567957, 0.14569306926381204, 0.13236234264989055, 0.16788539536778005, 0.13514261362293076, 0.1521415684011675, 0.15778198267423338, 0.13692301728071707], [0.014662371287422796, 0.030587749600770976, 0.03649830562813628, 0.044121137114181634, 0.01678743407190327, 0.06633952169889404, 0.05831915952806031, 0.05560320546670307, 0.033374942178207065, 0.029569457870938128, 0.0234587173232989, 0.05916307049412882, 0.023255522077482556, 0.054250949197599006, 0.028002229669401725, 0.10018122592760671, 0.06873406740205903, 0.018392336562335975, 0.04047180450851879, 0.03127094489642449, 0.04247056237692314, 0.12434095009079865, 0.04997972173676376, 0.025715880479002674, 0.05620338172922212, 3.353238427831281, 20.19507984961233, 41.36749667506064, 48.24297228167134, 41.8870146043839, 29.885313010984856, 27.764983638640377, 30.77109794462881, 19.664467496256677, 24.268888811911307, 14.361862328744705, 5.931871994849175, 0.8086196549477116, 0.06690703197232177, 0.07454717321501625, 2.0231379424372027, 3.9459651900875956, 6.805415211185333, 7.440917626503976, 10.607542184091384, 11.450623293076793, 15.707246084367076, 15.020195880243856, 7.538857248521621, 16.164575815200806, 27.77706846114128, 40.52691705765263, 51.291238338716575, 56.03972242724512, 61.90558387387184, 57.52948568713281, 59.485285359044234, 54.97979994743101, 58.291668891906745, 52.87874314092821, 54.463415991875436, 56.54082875097952, 57.23089133539508, 53.519611358642585, 53.41478993815761, 51.62251387873004, 52.750167846679695, 41.05784908417733, 39.41136752405475, 42.79584346279022, 48.967896892178445, 52.48312896297824, 55.93176703299246, 51.95968866348267, 46.96057296568348, 43.21388967575566, 41.34953221967144, 43.02192887952251, 53.172018758712284, 58.52335937561528, 54.07816079355056, 49.14876914793446, 53.26880324271418, 44.67578057319888, 43.863249824893096, 46.24801951069986, 56.131407830023, 45.02078440881545, 44.49548882822837, 59.52534844798427, 51.26380920410157, 50.651456617539935, 41.470843284360825, 41.42604981699298, 39.937514258969216, 41.956624907831994, 45.893339187868186, 51.273768101969075, 49.9555104778659, 47.44693117756998, 39.62349714771394, 37.83519052690075, 41.508815749999016, 48.67744930328862, 53.70946976446337, 55.73077301825247, 56.71012216998685, 54.22889747927266, 52.75518455813008, 55.99099090022426, 54.545534733803045, 58.41433317430558, 55.21978232168383, 57.95631016454389, 58.89616497101323, 58.61276588132305, 58.69367261086741, 57.39259104574881, 56.50187569279825, 60.96338741240963, 58.121214451328406, 58.11788828142228, 50.236097228142526, 36.95145699285692, 20.12574999563156, 16.90607636205612, 16.11323493142282, 9.666197857549115, 14.76315119574147, 13.859302766861456, 13.849212469593173, 9.287146868244294, 9.516462356813493, 4.258829124512212, 4.394156288716101, 0.8683525109964033, 0.2858836047591702, 0.13410799655943148, 0.8210935888271179, 5.1164073136545, 16.04541518995839, 35.30860362514373, 46.4434947506074, 33.594029718829745, 20.188198051145, 27.27101798980467, 48.203230827085434, 52.11756014054822, 34.87725665492397, 7.497229133882831, 0.590826006185624, 0.019478417497368592, 0.07053628924392885, 0.06746200138642904, 0.041999291898983146, 0.03952356768892177, 0.04458758123819867, 0.03809140844931526, 0.026479415415275483, 0.09018393173333138, 0.020833699813773556, 0.02140538909682824, 0.03281814181396077, 0.018453878320513234, 0.07519801087196797, 0.08815960568045417, 0.03713913434635728, 0.03118910946913304, 0.08040569272012481, 0.02139588577612754, 0.10522583063932196, 0.004061226002616628, 0.06991543626833348, 0.007557694381478453, 0.013450301447582823, 0.028144268116222757, 0.0633754777241378, 0.04283705883989892, 0.03494290582415077, 0.0714547137519525, 0.03655832478656404, 0.012588704384172396, 0.0909060538716374, 0.02491816652998809, 0.030887619396972082, 0.016212017771096963, 0.07633963509673074, 0.046822592961571874, 0.020249228353702256, 0.023882794869883407, 0.01867849913035189, 0.06742872252699829, 0.05939495764792927, 0.017388690518395557, 0.031333248912086414, 0.018024258127796556, 0.03117168479929528, 0.0008317306468773994, 0.07028560229246655, 0.05455592496981544, 0.017908054081002073, 3.883246736180398, 23.31821610850673, 47.34389835788358, 54.795197517641135, 46.616628170013435, 35.90087759879328, 37.4845306334957, 44.082518162265906, 35.30466164312055, 36.49112370706374, 17.6789499867347, 6.208399582293726, 0.6145271730999793, 0.08027954102163354, 0.17399110080253694, 1.7607804075364144, 5.278566431614661, 10.776855214949578, 9.637601817807845, 11.396752480537662, 12.81765559027272, 14.002198634609101, 14.094422382693137, 9.07710296492423, 14.614564949466338, 24.982609172021192, 38.815747768648215, 49.476977394473174, 56.965076231187396, 61.161635768029, 58.089411873971265, 58.87690221109698, 56.53281534871748, 58.10068868821668, 54.11740410712458, 54.7351421079328, 58.82577803827102, 59.72924893902194, 55.778653390945934, 56.21725282361431, 52.73747897917225, 52.67026524389944, 42.80674372949908, 41.01690738431869, 44.89338582561862, 52.44079482170844, 55.268784492246574, 56.57946801954701, 55.61159180056665, 50.18371397449125, 46.59072091502529, 42.66563646255001, 45.24670508600051, 55.96271453365203, 58.977836562741196, 56.478765087742964, 51.13151158055952, 55.810259849794456, 47.2487691140944, 46.45446561997937, 47.805035729562086, 57.63752345115908, 47.33617128864412, 44.751090080507346, 61.77341176617531, 52.93813567007742, 52.68242066906345, 43.44651368356521, 43.357773980786725, 41.09544500227898, 44.147143133224986, 49.75059017058342, 53.962929402628255, 54.467997320236705, 51.15555570971582, 42.14998991258683, 39.84007473914854, 44.640134073072865, 52.74415093083536, 54.73423996279317, 58.75598338342483, 57.79823472422939, 52.51843421689926, 53.98322766826999, 56.33409238630726, 56.78126612017232, 59.93062342366865, 56.71649209914669, 59.735395293081964, 60.71834125826436, 60.210798325077185, 60.379883858465384, 60.67735641233383, 59.38079734002391, 61.220318348177024, 61.8773231967803, 60.287582643570445, 52.74955203456264, 41.50270861964072, 28.29844363274113, 18.14393912592242, 11.668229526089085, 8.99913703241656, 12.917162199174205, 17.432617295172907, 11.581380405733663, 12.586832930964809, 11.205731091960784, 10.16572738847425, 6.174608853555495, 2.543376116983352, 0.32171460950086195, 0.16201458781236605, 0.8984516152451116, 5.721278469408713, 19.64738949652641, 43.86447752675703, 55.271942000235285, 42.2697594857985, 29.5807429282896, 32.50577988163118, 54.12194621178412, 58.401636462057795, 41.305609518481845, 10.62118124577307, 0.8537573715852154, 0.05709817242478171, 0.05343254512896942, 0.08567509061146168, 0.058935101880061055, 0.05232816043820593, 0.008734738202615371, 0.03430888379713701, 0.029825750670786348, 0.019194963050165006, 0.014592623769966586, 0.027281030667044466, 0.08448276668787004, 0.021756071589827057, 0.03142012902835925, 0.03463146810029303, 0.047540137724530314, 0.028968297185436375, 0.06584386281188458, 0.06915265784388588, 0.0943976144997343, 0.06506732544831692, 0.020104273027109525, 0.06385375024570573, 0.04438167978678981, 0.03947564888925802, 0.13756397240344556, 0.12359060527336214, 0.07182130214547919, 0.1559341632791104, 0.14927891233275015, 0.22204988005180515, 0.26137164102927335, 0.1728011364297521, 0.09848450971466881, 0.11067798646587519, 0.24076364603975128, 0.19559196106368498, 0.09473496897807045, 0.07871213278943494, 0.1993073342788604, 0.1579482850408362, 0.14833313082495045, 0.1677453391734631, 0.12555667033959783, 0.11135010604536343, 0.11860072988295749, 0.2284761013523225, 0.1945048669773725, 0.16843394496508185, 0.14764172115152882, 5.362398268715029, 28.671053109630463, 55.4311353160489, 62.49174679479292, 54.82945549872614, 41.97991201954503, 38.78568672364758, 40.801608485560266, 30.815558010532012, 35.73717747965167, 21.03695777154738, 7.981967406888162, 1.1035191339831198, 0.22080491056605694, 0.27138339896355906, 2.627006687464253, 10.215493440628052, 16.137077058515242, 17.809215822527488, 18.349077124749464, 19.226517215851818, 28.35684576342183, 24.35506916815235, 17.542096530237508, 22.637312258443526, 31.89333708055558, 43.91325219984978, 52.45233443475539, 58.79450890325732, 62.486259398921845, 58.677743865597634, 58.28607951441119, 56.07391372803719, 59.00735632065804, 54.30880008205291, 55.06203636046379, 58.77701513228878, 60.32998346513318, 59.5595750501079, 58.87808284451885, 54.95020566448089, 57.21462918866066, 45.77317345526911, 44.34164170295962, 46.21293390950849, 53.821104341937655, 57.58056279151671, 59.696795248216205, 56.98917135115593, 51.19155130078716, 48.19182065225417, 45.5836013824709, 47.73883788816391, 58.73135089874268, 61.23679622527092, 61.26671214257518, 54.837794457712484, 57.925907873338275, 48.76521233589419, 49.43023450912968, 51.38326498769945, 59.37737311086347, 50.320585081654215, 48.59121599505025, 62.683864485832956, 55.54005561336395, 55.766831367246574, 44.8372253294914, 45.10190686871929, 43.96016374711068, 46.538847569496404, 51.80700255978493, 54.78696838501961, 54.696428314332046, 53.486114317371005, 44.159004380626065, 42.21975318847164, 45.16186029680314, 52.70530769901892, 58.047446435497655, 59.58441934277935, 59.97365574682913, 53.63592140136227, 53.33629154389905, 56.798834416174124, 56.49950658121417, 60.982226556347264, 57.94334280875422, 61.531472129206506, 63.132489496661776, 64.5866141011638, 63.861430614225334, 61.50489807128907, 60.95976314237041, 64.83224076609459, 61.02130905274422, 63.98787213910011, 55.47058651524206, 46.299430016548406, 24.89488144074717, 21.991650904378584, 24.020504720749397, 17.979097597060665, 27.312230333205196, 22.4197462297255, 24.916044589011904, 19.22957274221605, 21.774586939042617, 13.373275014661974, 10.885621559235359, 3.775192547229029, 0.631803497672081, 0.3543120184011998, 1.3869460479867075, 6.443173539253974, 20.042227045182262, 42.87162757688954, 56.90429910536736, 44.56465590384699, 31.923568748658706, 41.27991014911283, 61.36599517637684, 65.73511546657932, 49.47357669953377, 14.969861084415069, 1.8962584604178707, 0.14117932517922696, 0.14895307981679518, 0.19413530616269958, 0.1376049427856361, 0.12679917302222984, 0.11711310204719344, 0.12547862896275136, 0.16166322924677404, 0.1299575160467817, 0.10316199743218961, 0.14454851858317852, 0.14152982572634376, 0.08908902355019124, 0.13566560652707854, 0.13323171454812252, 0.1996077173539708, 0.10667727614242224, 0.17830213802235742, 0.24185860018816688, 0.180551785855524, 0.10845702096459367, 0.12535158860226794, 0.1492319971082672, 0.09652420562962372, 0.0929178314043149], [0.025734843070348425, 0.01863309884473922, 0.019428269381845192, 0.015168116679565321, 0.047552065713511366, 0.04784568423225034, 0.08774129103028006, 0.033060654607271, 0.005188106386471661, 0.04318946311550756, 0.052064158878619635, 0.013781397945187507, 0.023659715811992367, 0.03950335828947925, 0.04271237036934303, 0.030649153463121866, 0.054674852459180745, 0.014114649065079228, 0.04142120961220034, 0.03470945585098478, 0.03483286878514675, 0.04593292739422572, 0.03869308241372628, 0.03809398633518046, 0.027831108609755194, 3.2411309596030944, 19.216825039156024, 42.37989179549679, 45.588857358501805, 37.72576032146331, 27.345068416287823, 23.07817685988642, 25.30026035924112, 27.22140589068013, 34.32770121482111, 17.234351288887765, 4.7959908554630895, 0.2410275786514244, 0.0909917484668474, 0.2230403244855904, 2.094120094853063, 3.2872224863498443, 11.101381336489032, 5.8800525819101646, 11.0717527327999, 16.28282154760053, 16.25563854171384, 10.775605940049696, 8.807323325064875, 22.877624111790812, 35.156847123176824, 42.934354120685214, 55.281065433256096, 58.889571466753566, 58.27748560136365, 59.10900454367361, 60.4213236993359, 55.672290478983236, 57.31404558304818, 56.35085267405356, 55.316386376657796, 54.59711782393917, 56.1380248685037, 55.52350713360695, 55.531304805509514, 54.84833778873567, 54.624637173068145, 48.4001338097357, 40.10373253976145, 36.59949487255466, 38.948284656770774, 41.29679595270465, 44.4442940527393, 39.912073766031575, 39.80712682970109, 39.83163772090789, 44.47819509813863, 47.37631674735777, 58.4740081141072, 50.64574172419887, 49.36929656613258, 57.34036860927459, 54.57856109065395, 45.71207077272477, 42.8332354176429, 44.407027613732126, 54.52910000278104, 48.97662416581185, 47.90418932514806, 56.77010305466191, 46.3811682885693, 49.66075612652687, 41.73525418004682, 42.588989427012784, 40.09867660460934, 39.080374394693685, 37.525884182222434, 39.489834539351925, 40.12834149022257, 39.39586631713375, 39.50681055745771, 43.83535392822758, 38.01842012713033, 40.24245500564575, 48.94260152693718, 54.17437653387747, 55.22093942088466, 55.81305257735714, 51.0391083840401, 55.05994965953212, 51.633771081124586, 54.53905105590821, 54.522286845791726, 55.66290424716089, 55.08518226685063, 58.61401711740802, 57.40180469328358, 57.60174751281739, 59.09242076258506, 58.28648744090911, 57.79649711424305, 57.44337789473995, 47.863333917433216, 41.88889734206661, 28.959508134472756, 23.2290724016005, 12.988302226989502, 8.849865351953815, 7.37072043841885, 29.625324587668146, 8.404157603940657, 9.687313937371778, 7.943385012688176, 9.341908058812542, 7.135164458905497, 1.6179191056759128, 0.5531722944109672, 0.07884894077095293, 0.5988579784189502, 2.854445812202269, 11.163635234678946, 21.487416490431755, 31.48682655826692, 19.20469314821305, 23.33598836775749, 38.73639037532192, 44.379751451553844, 51.576896713626006, 32.98727043213383, 11.542194947119683, 1.4100983282250743, 0.037668064431918245, 0.013979298565837165, 0.026812294024914026, 0.030579535223002878, 0.029277769893768336, 0.10964491689998297, 0.057257047568958615, 0.054632878501809416, 0.03617525018090683, 0.012160172993918101, 0.06541334438107668, 0.03670407684459802, 0.14916612886853758, 0.013403573914641335, 0.013885672087781133, 0.035228645128588525, 0.04174549463054827, 0.03151699127028546, 0.009893869451667753, 0.0462323643507496, 0.055374807843397704, 0.044934297310969526, 0.026159537317711982, 0.05787866280203866, 0.017615042686943087, 0.06127398363464783, 0.03516633919770679, 0.047194804440462784, 0.06175993235721704, 0.028958192485715115, 0.0590409369268004, 0.027422509869680773, 0.048923343945775306, 0.07389454291232171, 0.04661127909897797, 0.04086623253721384, 0.03238785320953016, 0.022170140197680845, 0.07240400394244541, 0.037405399695759824, 0.03179409676381657, 0.0107632911456148, 0.007973016979503296, 0.07856695912778378, 0.04180864708858632, 0.08638533838694135, 0.035923318336567575, 0.06396621961386935, 0.012933733148290025, 0.020630623311585477, 4.109345390912026, 22.961156868165542, 48.40355019415579, 53.26007989145095, 44.807203508192494, 36.35622555209745, 28.021922419148108, 29.81934266705667, 27.91647538062065, 32.95911565903695, 18.02076493540118, 5.0351073665003625, 0.39119752784890516, 0.031968335801314925, 0.2625695573947122, 2.6744796239560653, 7.028611802285718, 9.070573199179865, 12.238454876407502, 14.706346450313447, 11.818423944134867, 15.039205647283985, 16.148033218999064, 13.009584026951945, 17.0791176057631, 29.84647370153858, 44.7552046468181, 56.1285876458691, 59.95025096401092, 61.50151698820053, 60.61672049184, 62.43143250865322, 55.93932936268469, 57.21564900490546, 56.30992666367562, 55.516580227882635, 54.12814747902655, 56.616146103028335, 56.072101593017585, 58.03918200154459, 56.24343856688469, 56.66962369795769, 50.67148816200995, 41.68447909816619, 39.214331180818625, 41.26078074978244, 44.13596437823388, 46.718927506477606, 44.11821173083398, 42.095951418722834, 40.23860716050671, 46.47918047443513, 48.48538260306082, 59.3310381520179, 53.3104274349828, 52.69127738091254, 57.12394006790654, 57.59490689923687, 46.64245305522796, 45.437194993419034, 47.184151987875666, 57.329150630581765, 50.79246974760487, 49.854685952586514, 58.34977096126926, 50.15935997809134, 51.83197629067206, 43.9001867848058, 44.04446724922427, 40.769037123649355, 40.88352326423892, 40.02419079503706, 41.46457533682547, 43.04107789070376, 41.76435816672541, 39.65808068552325, 44.46877356498472, 40.6985717435037, 42.62716585589994, 52.06289014508648, 54.87031482881116, 59.06175175020772, 57.46943027742448, 51.96416016547911, 53.06323966672344, 52.643447999031316, 52.65226156480851, 54.8843490692877, 54.89003258366739, 57.37623476213025, 58.843122759173, 59.07355416205622, 58.289370382985766, 60.862449138395256, 59.091173448870265, 60.580662142845895, 57.828189865235366, 50.36759468816942, 42.31312128805345, 31.487393340756817, 21.336422889463364, 15.685336705177063, 13.127723855357017, 14.436090242478157, 21.78086861487358, 17.312133850589877, 16.83585024649097, 10.908910632133486, 9.660772239008258, 5.920573607567818, 3.2410927164939145, 0.9193052027013995, 0.134562608455458, 0.7952147097356859, 3.8134966982949168, 13.07490521861661, 24.495882257338494, 38.34714612653179, 26.31701715530888, 26.850645811327045, 44.86490549579744, 49.084187323047274, 60.085576657325994, 38.35950159257458, 13.848544686071335, 1.9219480238614546, 0.02696788265189577, 0.03838091307590085, 0.029686495038350264, 0.05494202562277356, 0.028121787266084747, 0.06470070641127325, 0.09122060191246772, 0.08779358419199144, 0.07017496387444197, 0.04064729609977334, 0.012866393062135866, 0.07669054933132664, 0.05525240997573542, 0.02895446355274368, 0.008190520832525387, 0.041039383729859706, 0.09369943260906205, 0.025672864642054326, 0.018807786043673273, 0.05706457946930201, 0.055824999412101124, 0.04150017029455593, 0.0099795697925372, 0.058648385813519846, 0.032479358581645836, 0.09758879205272084, 0.13336904346942902, 0.12373455319433443, 0.13404552975008566, 0.08126661466855196, 0.2127958596834252, 0.16227567057696082, 0.1320365714209695, 0.2608724274942952, 0.1981837590855937, 0.1667609927995551, 0.07687057233265332, 0.06867112561820016, 0.18567312959461443, 0.08686313210355659, 0.1316035632044077, 0.12099004320559964, 0.10362930340512146, 0.1252512157624287, 0.11796802552717349, 0.2631923255901183, 0.20294304967166918, 0.18926485621881103, 0.07297711431859963, 0.14160465719478746, 5.222540766962114, 27.24372809933078, 53.94240363951653, 59.61353509656845, 52.40461880160917, 40.09341278383809, 32.94701906942552, 34.90050062056511, 38.198252954790675, 44.535944154185636, 22.522637844085697, 6.430878869948849, 0.4955226459330129, 0.39941428048956784, 0.6236726694530057, 4.3395323811038855, 9.269546212688569, 21.604261936679965, 13.636511160481362, 19.75013598319023, 25.227780842011978, 28.945391524222593, 21.548250490619292, 15.799710077624168, 29.819528979639855, 41.131448438090665, 46.72873735427857, 59.457562046666304, 62.47919521024151, 63.39068343562465, 62.998995550217174, 63.565872177000976, 57.62293223411807, 57.86708801023422, 56.76228969327865, 54.76266930180212, 54.97370850655341, 58.15062046051026, 57.419447514318655, 58.78001574547061, 59.13798693687686, 58.90399402187717, 53.62839829537177, 43.65636441015428, 41.625482728404386, 42.89883313640472, 46.540589101852916, 47.3130371493678, 45.060055178980676, 42.934832649846236, 42.93463260896745, 48.85366570565009, 52.38394791080106, 62.39113799987301, 55.13665160825176, 54.56997109997658, 60.30440961160968, 59.79635284792993, 50.30592718432027, 46.888475879546135, 50.086772595682454, 59.37385082244874, 54.84412124080043, 53.38831786186465, 59.94257096321353, 51.50735701284101, 55.45815260179582, 45.48824464121173, 48.50661439280356, 43.48175225719329, 42.982418844776774, 42.649566511954035, 42.216505465968964, 42.743201332707564, 43.888372605846776, 41.54054380232289, 47.89197898680165, 41.7754820085341, 44.74165285787275, 55.11849495672411, 59.58049305023686, 60.25331681774509, 57.30275307932208, 52.071609573979536, 53.704453053012976, 52.02173663723854, 53.54650705091415, 55.12312335352744, 55.767886484822924, 55.702559409603, 58.778450719771854, 59.64674188244728, 58.78020401923888, 62.010013057339584, 58.622885596367624, 61.048969607199396, 59.68167058883175, 53.28789341834284, 47.272315102238814, 34.14298503629623, 29.363420086522257, 19.908652690149125, 18.188993430906727, 14.815566808946672, 43.9125265613679, 18.936151996735607, 15.651349367633944, 20.398138992248043, 21.293651403919345, 14.142061529621003, 4.93904116653627, 1.3470211000211778, 0.3936446884707097, 1.059690079381389, 4.161676918306659, 15.268874149168692, 29.17608376472227, 46.50723326590754, 31.676477078468572, 33.686793773405014, 50.57782196229505, 56.387452310131444, 69.1378382713564, 47.35472409955917, 19.97528003108117, 3.0173045829419167, 0.15031319231756274, 0.17138361329993895, 0.14284057152127067, 0.1928656226805141, 0.15310673193345148, 0.19545631753581186, 0.14900463753409926, 0.22261992607626224, 0.10152670614902051, 0.09240021643739554, 0.14240099027031852, 0.2524373244734541, 0.22971466634302373, 0.10699269752348624, 0.05690132230219822, 0.1196478111969848, 0.2342916739683959, 0.09726851367421689, 0.1526313130894015, 0.13184244474095683, 0.1392504383599566, 0.16067365815322246, 0.09548716006740447, 0.15127259486865613, 0.1345967912986394], [0.05076927876460457, 0.030657237605942838, 0.039117399362787124, 0.04926835547291464, 0.045965179695837924, 0.03375086535309111, 0.024323416085192756, 0.08937514206815152, 0.01438242648052232, 0.017467882942348238, 0.07933615736903683, 0.02827762104120226, 0.04711934094948154, 0.030677069707082647, 0.04731047988658951, 0.0072074610075252435, 0.04853814727656784, 0.07352411641829437, 0.051558376139690804, 0.030476343179602298, 0.02747156630991207, 0.06791171031974017, 0.018979897271961938, 0.03811178638810112, 0.005626648630676491, 2.3575175481457866, 19.16451042698276, 36.918391412304295, 46.81768494267618, 34.96900481562461, 23.487095717460882, 24.288894860975205, 29.7480006371775, 44.84697634173978, 30.777832654214677, 12.703963729643053, 3.0260070966136072, 0.37737659689399505, 0.07448312060366716, 0.1750048802744958, 1.9910531995757936, 7.329008973413899, 4.647852739980144, 12.327943751888892, 11.58965366501962, 9.838276159378792, 10.362027306710521, 12.934254907792615, 17.343234323686172, 19.62785020951302, 31.311973179540328, 53.42417616997996, 56.67362059316328, 55.44044310046781, 54.636816132453184, 53.10291051864625, 54.62999513072353, 54.19118781243601, 58.161152024422925, 57.16186154273249, 57.723254696015395, 54.48555384912799, 54.389589140492106, 55.0305397279801, 56.47692157376198, 56.7811131477356, 54.03516377172163, 49.776509192682084, 39.66165396475023, 36.106551001148844, 35.54750342522898, 35.74408477352512, 38.382333709347634, 37.648167994714555, 41.03196144104004, 44.706771219930346, 49.694245323058105, 55.147414592004594, 53.876370537665586, 53.93244866401919, 61.4066505432129, 53.750638961792, 50.90399057634416, 43.658529558489406, 40.27348095370878, 44.46533756871378, 53.663703549292784, 46.949500114687034, 47.38750726945939, 55.899846784530155, 47.42160051099716, 44.14938672896355, 40.490238974171305, 39.75653217684838, 38.875775721765336, 38.656099457894605, 39.484747225238436, 38.65940601594987, 36.74995306999453, 36.91964657075944, 39.923248598652506, 47.431198550808816, 38.094812208606356, 38.276359112032004, 44.55996867149107, 50.14785566637593, 53.92954611009168, 55.95325769916658, 57.28547503871303, 54.17623573733915, 53.29231392952704, 53.3026336854504, 54.070484715123335, 52.20622531829342, 56.90084741961572, 55.29072623099051, 54.526491626616455, 52.428619784693566, 53.0387483873675, 54.962710180590236, 57.35479508676837, 52.63281837586434, 53.52269041922785, 43.243848739131806, 42.757659189162716, 24.546078789618708, 22.170711025114983, 14.473180174827577, 20.810531108610093, 11.840383333544578, 12.945497401299017, 20.19446795986545, 6.550018902747862, 4.4971910695875845, 2.5810958348935653, 3.441361337900162, 0.546700077191476, 0.21698303580764802, 0.28557701637187316, 3.1664845780018838, 10.966966613646477, 27.454106384708037, 29.670376931467366, 33.995060689987675, 30.929261638272195, 42.04278761340726, 56.93101829098117, 51.80669661491148, 37.32028138252997, 12.7205200541404, 1.48097237031306, 0.025206167709022283, 0.0319968419329774, 0.07386611338945166, 0.0316708255559206, 0.027981303977750005, 0.060284630876154675, 0.06403852682260257, 0.07158211417376034, 0.01566217923086257, 0.04339191717125716, 0.03452995378944663, 0.026869426947087053, 0.07442317422359221, 0.04394401375564837, 0.076115500752724, 0.058452412861609654, 0.0816381519900695, 0.03335946337169698, 0.06003767477288362, 0.023591237127660744, 0.09097506307185659, 0.038852888354731184, 0.12366444848838354, 0.031062844772672946, 0.08639879855177096, 0.01842917006973538, 0.02821995760314167, 0.042283525840649684, 0.0412089764440973, 0.03149874497114891, 0.051404741036915974, 0.056645146330758456, 0.11896853635628378, 0.07623420607659125, 0.0518201943486929, 0.0596802449604917, 0.025354509144240332, 0.03922574334747849, 0.011485242829357666, 0.024894931083244663, 0.036505629428692406, 0.03912747724943104, 0.010199532787796232, 0.09952188469469549, 0.04350338679467959, 0.034119836280062314, 0.003689291272988363, 0.1216370044576545, 0.07183025005243479, 0.029897789748746063, 2.9916856221614347, 23.01226339032573, 42.53358594832882, 54.295781735450994, 41.074005326917096, 29.12429278896701, 28.162433485830988, 32.65004465656896, 41.44304152457945, 33.58829913600799, 15.699570986532397, 3.9753895853796317, 0.3749176998051905, 0.12165068678798215, 0.3646145833115424, 3.255555230763651, 5.916770869685758, 10.41340055004243, 12.087745647276602, 13.038337942092651, 14.728623551707114, 13.511179666365347, 16.086856992013995, 16.056984220781636, 18.518921636766006, 32.455520591428204, 51.20171808427381, 59.41722831418438, 58.38515074022355, 57.32048219250095, 57.712201456869806, 57.11864094580374, 56.64755252099807, 57.77548497722995, 57.66669411813059, 57.74314503515921, 55.4249732725082, 54.07771756572109, 54.526907397854714, 57.58650125995759, 58.79898432762393, 56.456262450064386, 51.04780035634195, 40.36696280202558, 38.20179877742645, 36.73908025987687, 36.39444904942667, 38.801882190089074, 39.9755298706793, 42.80065621099165, 45.27566394498272, 51.96424253525273, 57.33530482938213, 55.36248599329303, 54.004471225123254, 60.42539904194494, 56.906852568349535, 53.62912001148347, 46.09038729821482, 42.78878319648005, 47.37139025042134, 55.60344503771875, 51.11320980133549, 49.13690005579303, 58.32667212332449, 49.427712425108886, 46.474218676167155, 42.51569209560272, 42.41815059415756, 41.13136214594687, 41.249170534072384, 40.46885813436201, 39.463001605003114, 39.51724406211607, 39.67730422173777, 41.4023430116715, 49.188157589204856, 40.597194164030014, 41.42804238104051, 46.874547543064246, 52.67871010688044, 55.51348547781668, 56.299147990442094, 55.55461152907341, 53.7346278467486, 54.34108511094124, 54.6762869434972, 53.76302580679617, 52.109797769977206, 56.64511672912106, 54.98283586194439, 54.34432106633341, 53.5216353016515, 54.811455742005386, 55.68142960148474, 57.04987787431287, 56.06036193909184, 53.48122312176613, 43.47544900832638, 37.96935127627465, 26.939154094265355, 15.571680145878947, 11.158163528288565, 13.994622576621271, 11.021468927783351, 14.659232900988671, 20.968386896194954, 14.20434190380958, 13.68367079765566, 6.8489123352112316, 2.6921685328406673, 0.9800652294389665, 0.13825965684748467, 0.5944456796972983, 2.8909020366207248, 11.315479009382187, 25.737004510817993, 35.95763821755686, 34.17464640832717, 30.9965322479125, 48.53342771530152, 61.86383808812788, 59.23793285123764, 44.067652379312825, 16.691963980274817, 2.244179436276036, 0.0009181608061959607, 0.04291770874612755, 0.04311279686648519, 0.020598803849650488, 0.0632364480876394, 0.044020197369278445, 0.09804093714563117, 0.04395319914986049, 0.004571866696595305, 0.03971965172358098, 0.054696919621839646, 0.050117897185226606, 0.0544764356867921, 0.039093420810757146, 0.03473324671147331, 0.07124350331122838, 0.07115543384345309, 0.025445012856395017, 0.020519935097845814, 0.01359155178145175, 0.007322815175528729, 0.02257019705739954, 0.02257909899907968, 0.035357075938654524, 0.05258021485661307, 0.175064803671933, 0.08872759092839495, 0.12144569698120318, 0.135558660652849, 0.11666471844599133, 0.17042398092246827, 0.15898152314607175, 0.21533513471724527, 0.15075222198520938, 0.18619454435763821, 0.1961939223110676, 0.11124225618738322, 0.10983783316107527, 0.08806411282069261, 0.16001566523505797, 0.10503017178346073, 0.15578218675669164, 0.20086393301044742, 0.23153820075094703, 0.15844098682845795, 0.14562520919547928, 0.18549650036279233, 0.2285446662215456, 0.11835474671135027, 0.1521690249923737, 4.117182041368177, 26.71213907580222, 50.37043056180401, 60.97118116194203, 48.51931110505135, 35.59816868074479, 35.0207918690097, 39.579166520026426, 53.93448437413862, 39.86157325006301, 16.680840138466127, 5.062890004727149, 0.7320810361735283, 0.290069172098752, 0.39513944858504885, 4.280721343332722, 13.595501799737255, 11.677733429016607, 21.50521032271847, 22.250909766843243, 27.168614710530928, 20.45360719003985, 19.698601922681256, 22.27900374320246, 24.325061075149048, 35.233470624493016, 56.93745490043395, 61.20229113486506, 59.15759094299809, 59.4859560843437, 59.53746072707638, 59.26740161834225, 59.17679094499158, 60.646785459210804, 58.90462552347491, 60.19242594319006, 55.345302089568115, 55.52619003480481, 54.38915375740298, 56.33614770827755, 59.737230962322606, 58.843860164765395, 53.89946545324018, 42.080528659205285, 39.21821040491904, 39.7970228041372, 39.047822644633634, 41.21954094979071, 41.20948399266889, 45.727540600684385, 48.29280991708079, 55.59804785636164, 59.61826939736644, 58.55066691675494, 55.148159842337336, 61.43719403974472, 58.4949771050484, 55.23875874857749, 47.39302996666201, 44.30171197460544, 50.55528794565509, 58.3497082033465, 54.41001292197935, 51.600948687522646, 60.84076627608269, 53.0335904705909, 48.05861303883214, 44.758864218188876, 43.60623259698191, 42.85619305026147, 42.12432192217919, 43.78539077697262, 43.155348300933845, 43.14275357031053, 41.510655341609834, 42.94882766662106, 50.378012503347094, 41.55742176117436, 42.599234657902876, 49.23659493846279, 55.627595070869695, 57.795763631020826, 55.738484398011245, 55.18448883487333, 55.374880683037546, 54.34387391613376, 55.33393506080874, 54.540239534070416, 52.051146568790564, 56.916391772608605, 55.80838495685209, 55.1404013941365, 54.13412124879899, 54.615580420340265, 56.42992765672746, 58.22551811895063, 56.16214744506344, 57.33356329702563, 46.187097257183446, 47.045433444361535, 26.68325670303837, 27.12214050754424, 22.11020846520701, 33.35114871301959, 19.039943795050345, 18.97372830298639, 30.94553947448731, 17.38961046741855, 15.926931173570695, 9.658174649361642, 7.684565455682817, 2.000655039183555, 1.0292667054360913, 1.2903032596072843, 4.120681285858154, 13.371292256539869, 34.578038646328835, 42.13359832763672, 47.151333516643895, 41.79104989574802, 56.274770459821156, 68.57079690502536, 65.59253731081563, 51.4675174990008, 19.162547280711514, 2.7116080445628015, 0.12392408334680143, 0.11182895696331417, 0.1561321970075369, 0.16426631940468667, 0.10288883346102892, 0.12080242827294335, 0.19382746139120674, 0.10265878491824675, 0.09055325506074775, 0.11610606414896828, 0.1089541967056932, 0.07988286835532035, 0.1861470775498498, 0.14159786965577834, 0.16098970006550514, 0.16919414933410384, 0.22125484932574535, 0.12082469078802294, 0.10129673421503076, 0.14479988735289345, 0.14637050549349478, 0.33698249668363606, 0.1631678106083024, 0.12883292961745493, 0.17276028862162945], [0.05740916198720375, 0.0395396976701675, 0.15953666109952236, 0.06050809872366729, 0.07943182642902098, 0.04450372908444655, 0.019389030358363545, 0.0272894308211342, 0.0616187691658495, 0.03329036224092687, 0.06640128370734953, 0.04888539195000645, 0.06649717493283172, 0.04414354518596684, 0.02325091980427744, 0.06739201925454602, 0.03391666593210351, 0.04842882652977302, 0.02126147373459272, 0.05695408660798304, 0.03403692641445706, 0.015398041690669715, 0.04356571570819905, 0.026500320039509286, 0.15695267717444128, 2.5152892499200763, 16.156221166733776, 39.510368147204005, 47.00360528884396, 43.90583107548375, 35.75092930947581, 23.666291159968225, 29.874534337751328, 41.09490763756537, 28.60854425737935, 11.679316105381137, 2.6604686725524167, 0.6735580474618943, 1.001727192872955, 0.279745769596869, 1.8543674244034676, 5.510999223878307, 10.125760397603436, 12.466860375096722, 11.646621188809796, 6.294108763817818, 11.379039056839483, 22.23538894807139, 21.10501873877741, 22.477085398089503, 38.902396848124845, 49.885154924085064, 53.815044280021425, 51.275725364685066, 50.38315080827283, 47.508339804987756, 49.78950792743314, 49.997471993969334, 52.964768563547445, 52.98583169137278, 56.14969784213651, 56.94308350163122, 55.215126468289284, 54.71809940953409, 54.016571737104854, 54.44554567337037, 54.25292591894827, 47.99730247066867, 41.781036084698094, 36.680099579595755, 40.09881388756537, 46.08336233323621, 49.07667206179712, 48.01294488291587, 50.078339499811975, 50.06279906918926, 55.31377800049321, 53.35797440621161, 55.89457904138873, 57.87802750064481, 53.55442239392189, 52.476527613978234, 49.19410782475626, 39.92411544246059, 42.46439533848917, 44.397543322655466, 55.408718970514116, 48.29964660829114, 48.322965098965554, 57.899592691852206, 45.858736038208015, 43.75636523769748, 37.94340871995495, 40.179548032822154, 39.08768569269488, 40.73793665055306, 42.0977557090021, 45.221586227417, 42.88617172548848, 40.98207673718853, 38.4057306474255, 39.49336859487718, 37.573772399656235, 38.525562978559925, 42.95897483825684, 51.983485683318115, 54.33586835861207, 55.120707173501295, 50.97439319856706, 53.71276847777828, 54.31608000109273, 55.834688371227635, 55.15820895471881, 55.53330521429739, 51.46852947050526, 53.9852241546877, 55.19058027575093, 53.72077795767016, 55.87208032608033, 53.843854088937086, 56.57076428013464, 54.9218822294666, 50.25570123426376, 49.14637650212934, 41.95444014764602, 31.204692432957312, 22.49919972112102, 15.837293248022757, 14.226452304470925, 16.655264323757542, 22.25110588535186, 21.626564533479755, 12.209405802911329, 12.039662291926723, 6.189214779484657, 2.2979820976334233, 0.8869113280407844, 0.1739723163266336, 0.36042895468492664, 1.951668925823704, 9.312566768738533, 23.830530605008526, 34.212167801395545, 35.53366530326105, 32.17395520979358, 44.368125546363096, 50.938758465551565, 42.735501720059304, 32.353366382660404, 10.745569409862643, 1.6275946122984735, 0.06824544886307371, 0.02232786812519114, 0.031513580263802604, 0.034801949476522785, 0.05775401263587898, 0.04643856840688856, 0.07405352913924763, 0.011097901113962215, 0.01263376854870829, 0.07535049301241675, 0.047627636456802014, 0.04469836138248925, 0.05279013443918479, 0.028102713591989972, 0.016953880079991875, 0.03100315694727244, 0.029024993437492562, 0.08122865501190386, 0.009346467071032573, 0.07911091219753989, 0.04687138893190892, 0.060879394727488684, 0.06925068645467682, 0.043706197081313986, 0.04051968500378632, 0.013050496439269234, 0.07666841705119418, 0.015647985536845464, 0.01023099601884643, 0.024002442481897535, 0.015952222034214966, 0.05106259850905307, 0.08688027715130199, 0.03664251784944246, 0.030631416612454963, 0.03979680060799565, 0.026208814008221514, 0.01394570465274756, 0.014427610346296383, 0.018886172160085653, 0.04106132065757148, 0.015305248333231337, 0.01920125646246297, 0.03891969122172844, 0.04110020728060796, 0.022246099730593064, 0.029188813679220698, 0.04395827448235885, 0.07802856785635795, 0.10050197161974446, 3.131989783817722, 19.200468755537464, 44.32972946474629, 53.76435156791441, 49.81461109653596, 38.783019511930405, 26.65315055078076, 28.03077716981211, 40.77562670553885, 33.52820058022776, 12.491093758613834, 3.015594429546787, 0.8196461116594653, 0.8660027661150502, 0.18195355821761394, 3.959130625570974, 6.819578399581294, 10.039680061801787, 11.207469682539664, 12.350954336504783, 14.50613396783029, 16.886886165988063, 18.581132388884022, 15.401576757431032, 21.91182282663161, 39.69805355994932, 53.82810577269524, 56.3597878333061, 53.40639214361868, 52.21721972188642, 51.28128728558941, 52.624106791711625, 51.760189071778335, 54.08227928223149, 55.612439032523866, 58.00258628783688, 56.11820120965281, 55.22497553979197, 54.95721493997882, 54.443129493344216, 56.482793361909934, 55.10371938828499, 50.6391913660111, 43.48351732377083, 39.33000972194057, 40.968642619348344, 47.013254319467855, 48.618802024472146, 49.11207929734261, 51.298067185186575, 53.309846924197295, 56.17387925424884, 54.965138127726895, 54.793612880091516, 57.35942740594187, 56.27528036794355, 53.8829561971849, 50.350328414670884, 42.07327619675667, 45.04371850721298, 47.68871391973188, 57.18888667321975, 51.92454030436855, 49.89325069612073, 58.25674018552227, 47.892590876548525, 44.116411362924886, 39.656241093912435, 41.54944758261404, 40.876949371830115, 43.054245287372225, 42.88977246130667, 46.922757394852184, 44.60955135283932, 42.53597859413394, 40.34418167606477, 41.348983087847316, 38.762266251348684, 40.75386931819301, 45.8379239420737, 53.01732047911614, 57.11977058841337, 56.35691273596979, 52.9030579136264, 54.98825265515236, 54.974763624129764, 56.68065340288224, 55.65774633038429, 56.74119126412177, 53.02508677205732, 54.176294572891734, 55.17127436976279, 53.26169198559177, 56.783588163314334, 54.02569517012566, 56.62229245708835, 54.73198459994409, 52.195646685938684, 47.52772023600917, 40.245032002848966, 29.11874851872844, 19.145498698757542, 12.049596674980657, 6.796077028397591, 8.44524247031058, 13.606512873403489, 20.19497198443259, 15.033960457771057, 13.87607187994065, 7.5312213743886645, 5.31247434116179, 1.6557724293201201, 0.22043459898521825, 0.2559332594635987, 2.1436150131687044, 9.903703255038108, 26.140188863200528, 40.59821398027482, 43.756424073250066, 37.46014918050459, 49.34293823857462, 60.141380217767534, 50.11667674587619, 38.09597323017736, 13.256403092415104, 1.7622745854239312, 0.042774247290987166, 0.038676776232257966, 0.02463445735854968, 0.06669471836498668, 0.027820751101018924, 0.02403100607015433, 0.042794303472844825, 0.04879727268651609, 0.032259663717160304, 0.0818551387337427, 0.03490307691296743, 0.046484874591471693, 0.03742220766481854, 0.009928948617720557, 0.04851959645748139, 0.05772662116214634, 0.037805148205089, 0.05134089909974606, 0.004708464482739087, 0.0574609648526436, 0.04101064011094071, 0.061576837343314005, 0.08155163001990126, 0.04781331318700987, 0.007497408528692059, 0.09015666666410624, 0.20797097664927283, 0.20594426040207187, 0.18325645927219622, 0.1521116450068451, 0.152682947415498, 0.10467094549488638, 0.22154066140853593, 0.16737173341455, 0.14357239999357732, 0.10517562889764387, 0.15376103230782096, 0.13235883396719733, 0.12640579453399106, 0.09063399306708768, 0.1797631596245112, 0.11233302749573224, 0.12939788881809483, 0.09520337045673402, 0.12813907612355488, 0.16703312255201802, 0.169396304615563, 0.10409842500643385, 0.17000568159405263, 0.19448188433964408, 4.2338921658454405, 23.25284000365965, 51.575312076076386, 61.109464322367025, 57.825397137672674, 46.159621054126376, 34.83589526145689, 40.24898182961249, 51.79204263994771, 38.06359014203472, 15.848737743593032, 3.8890349288140578, 1.147435338747117, 1.8338971873444898, 0.8401754907061978, 4.729012462400622, 12.739767124575954, 21.734196332193193, 24.73016738891602, 23.95776052628794, 20.009418379875925, 23.867857840753373, 32.28985536483027, 26.294785161172193, 26.938648108513128, 41.84611605059716, 54.98536186833536, 58.744184893946496, 58.391257870581846, 54.786744809919796, 52.8468660385378, 54.4226586434149, 54.57096738200034, 57.358760603012584, 57.505806338402536, 59.77574863741475, 57.66221477139381, 55.80913020718483, 54.747293610726636, 53.840088613571666, 57.832629988270426, 58.27090778658467, 52.66271860368791, 46.310149854229344, 41.212888609978464, 44.14102423575617, 50.90669308939288, 52.95686106528006, 53.431342340284786, 54.85520193653723, 55.46683280698715, 58.720991919117594, 56.397093496015, 54.87764181629304, 57.616644674731845, 59.18627523606824, 56.78097586477957, 52.77755775759297, 44.758436679840095, 46.86443567276002, 49.939958280132664, 61.48923604719101, 56.26495668965002, 53.78159430719192, 61.28764583218483, 51.537574952648534, 46.54879077788323, 41.3161567718752, 44.41659035221223, 44.13964748382569, 45.677832403490626, 46.669207542173325, 49.742615992023104, 48.32611083984376, 45.92925240916591, 42.85012122123472, 43.5105267647774, 40.219681724425286, 43.78594383116692, 48.15837460179483, 55.634961282053304, 57.60713292706398, 58.07387144334855, 54.416190655000754, 55.72170449841408, 55.81182095312304, 57.486214099391816, 58.06344578343054, 57.84706823287472, 51.705993683107444, 53.889192765758885, 54.89250759924612, 53.29343180502615, 56.50520970744472, 55.86646741436374, 57.567187509229115, 55.89237466935189, 52.75211726465533, 52.34956441387054, 46.06038116639661, 38.01483115842266, 29.282583959641, 23.697928997778124, 23.066376409223004, 30.991950919551236, 33.738796557149584, 35.643695631334865, 22.044820593249415, 16.032172287664107, 14.045240763695011, 5.246518215825481, 2.3728388163351246, 0.2555524984434728, 0.5924580186124772, 2.634489098864217, 12.645030117804005, 30.085861836710286, 45.56000440351425, 47.19198496110978, 44.41704142478205, 55.95384213232226, 65.93026514976256, 57.572627836658114, 44.16964184853339, 17.947302864443873, 3.722668088251545, 0.17303614156140437, 0.15417927034920262, 0.18663303776373788, 0.1278173268562363, 0.13738061691964829, 0.1552325339927789, 0.140038421077113, 0.11970108495123925, 0.1890914598780294, 0.19951138945837177, 0.16974835266028682, 0.18393976373537896, 0.11800005566328765, 0.16431640623317612, 0.13850601540217478, 0.14767878448530553, 0.12898119827432017, 0.1443596932316019, 0.0712035441650979, 0.26038452141707946, 0.1830265256426027, 0.17217285240129118, 0.1573175648527761, 0.18954450895469035, 0.179640417017283], [0.014467036103709571, 0.041291012969468875, 0.008961311579051038, 0.036536629176548416, 0.07304876652215758, 0.0883720342009779, 0.028441801344254808, 0.03327384538527939, 0.01418636542850084, 0.03815635738353576, 0.026921187677691062, 0.053034635230658524, 0.05154231127591864, 0.060748048952870795, 0.016122737884401314, 0.04908353293074235, 0.046741425945994355, 0.02662649663585809, 0.044553095790287184, 0.018546096154398495, 0.03508977254011458, 0.035343259542940125, 0.03320854405061372, 0.007187584377524834, 0.0792445715576891, 1.3694977519973632, 12.34192111799794, 31.270872623689716, 46.81162880313012, 37.526095990211736, 29.76836362192708, 22.83896915374264, 26.246849875296316, 27.56877491551061, 24.844165194419123, 11.52644859206292, 3.256370593463221, 0.0738216802898434, 3.840203871650081, 7.917999923229218, 9.177908858945294, 5.13023857147463, 7.841492131833108, 6.353395879268647, 11.643009666473636, 11.713995741259668, 13.571093870747475, 14.044942663561914, 17.516889418325118, 25.410761371735607, 43.11972925739904, 50.98874122865739, 51.18365556963029, 48.798987865448005, 45.998548923000214, 43.99529641674411, 44.67978923551498, 42.43497363982662, 45.790063181231105, 49.008830747296734, 51.31489023085564, 55.894284863625806, 56.590242770410356, 53.910495158164736, 55.58715543439312, 55.78999688548427, 52.14076096011747, 45.54320096969605, 37.65074891428794, 40.18751436664213, 47.19100829093687, 55.480263002457164, 54.87844590217837, 54.783053859587646, 54.78645063215687, 55.565288220682454, 54.9703235010947, 55.1572754306178, 57.644101265938055, 56.8998589823323, 54.9861071186681, 47.85352406963226, 45.773553925175825, 38.31614763505998, 40.55982574339836, 43.87886085817891, 54.89046404438635, 48.89495257408389, 45.83089897709508, 56.511301148322325, 47.40763295081354, 42.16557741165161, 37.607751892459014, 41.09226396006923, 41.85666722636069, 49.86241302182598, 52.93637844824022, 54.66651239702779, 51.97101646854032, 54.323877672995295, 49.30570710089899, 45.53616031523674, 40.095707370388894, 37.71347938045379, 37.48857851951353, 45.95257874458067, 53.96530635895268, 51.39622057637861, 52.24332309538319, 55.367392878378595, 54.95654813704952, 52.5147589560478, 52.65779602912165, 53.114630560721125, 56.19835484412409, 54.56511520570325, 52.80305316371303, 51.51444081337222, 56.87703471029959, 56.79874420166016, 53.6316381731341, 53.84981609159901, 54.805662401260875, 49.47206266464726, 39.862918623032115, 34.76696352804861, 13.918580566683124, 6.618765304165502, 5.324002677394498, 0.28939578081330947, 8.405163691889856, 14.346410151450867, 12.792276874665292, 25.76869922299539, 6.588349774960549, 4.406609323716933, 1.2486492818401707, 0.1424507706636383, 0.1816448247841289, 1.5603715613965066, 6.917029686512486, 18.075268230130597, 28.267666755184052, 26.669481338993197, 22.143054393029985, 32.05024169337365, 45.353950531251975, 46.24835683453468, 34.53955627256824, 12.680451081645105, 1.8190265014286966, 0.019254013107368545, 0.059596400467618826, 0.05537587270561246, 0.05203328170483151, 0.04799635840519782, 0.008143375781665166, 0.0819444645857138, 0.0688921649669928, 0.038156464635845155, 0.07414134579800791, 0.009418164282256078, 0.08388649747376481, 0.020244804195939534, 0.02037246125720201, 0.05056962476021821, 0.010137592663898343, 0.03247751997062757, 0.03497154985163962, 0.040997942203595754, 0.06343567308278815, 0.08620253448644954, 0.02264594400091277, 0.023040529077632294, 0.05790315846341753, 0.02157973921707561, 0.025270649329608968, 0.022015696872145902, 0.03238555111531769, 0.026127399929288416, 0.043243583396918354, 0.041785476759316466, 0.023966286962311116, 0.04953256387624049, 0.03163360325889963, 0.00782394967597699, 0.007928149603802951, 0.025416738466329636, 0.08055769988606054, 0.09412266554371004, 0.050035477615892894, 0.027645351440315286, 0.045189703364045396, 0.047996377557395935, 0.006687187236703693, 0.036776859027844284, 0.056130385041357055, 0.03506789306899713, 0.020744262879053434, 0.1244208530613011, 0.04241014102233514, 2.1593618585217387, 15.05827719165433, 37.67808783438898, 52.909000304437455, 45.88500807362218, 35.40778859969109, 25.86971398322813, 28.073199564410796, 32.33747882227744, 28.34130337161403, 14.034653306007387, 3.691560505859314, 0.24288659825200037, 2.951536976522015, 4.6831050419038345, 1.577828192422467, 3.8427975389265248, 8.681929073026105, 11.707202196121218, 13.100309429630158, 18.17847167291949, 16.77241179250902, 11.678528689569044, 17.454447246366932, 29.297124185869773, 45.91763042634534, 53.0052827250573, 54.64664951447518, 51.10073666418753, 48.36007464316584, 45.84913407602618, 48.1777471880759, 45.97100996202039, 48.83455199580039, 51.785260861919774, 54.17573367395709, 58.43178772157239, 56.27996760029947, 53.65734146487329, 56.24755313319545, 57.73362936512117, 54.822850227355964, 48.002589825660955, 39.485092393813595, 40.56603877775131, 49.634472324002175, 58.82216161297214, 57.405950638555716, 55.78688252356745, 57.086810911855395, 56.214515009234034, 55.94198872966152, 54.937375591647246, 57.99092115894441, 57.94775547519807, 56.908225397909845, 50.704710637369466, 48.35751725781349, 41.14647503822081, 43.78242546512235, 47.203018588404504, 56.25054197926676, 50.69119414975567, 48.83479910512125, 59.14481970571703, 49.857427689336966, 43.51679078994259, 39.507500894608036, 42.00751373844762, 44.19741615172356, 50.91970751362463, 55.534528993791156, 55.75815508442541, 55.185602788002264, 55.04250687937583, 50.76331084774387, 46.72808231845979, 41.47718183455929, 39.81915281664941, 39.91695319452594, 49.098056823976584, 58.00337860661169, 54.509327334742395, 54.73897818596133, 56.52768096616192, 56.73412707544143, 54.91482980789677, 55.47341846650647, 55.2353855102293, 55.24288900436894, 53.49633993641023, 52.700981324718846, 52.0752416887591, 58.385786164191465, 56.66065715974378, 55.78800039906656, 56.01132446719755, 54.57001816841864, 49.561324042658654, 39.85811371957102, 31.401199256220174, 17.73893479377993, 11.051621167890488, 7.05160326534702, 8.791294559355705, 11.863778310437358, 15.427081969476516, 14.70765063839574, 14.437911202830655, 12.874708425614143, 6.41987907309686, 2.1065714138169445, 0.4635972800033708, 0.2584988726002555, 1.4754048110015932, 8.090781309912282, 23.027203698312086, 33.01441323372626, 30.60174765125398, 28.19019994428081, 36.48534997817009, 52.41566419601441, 52.11959977303782, 40.99804470616002, 16.516928211335216, 2.4727028512185623, 0.049502805190821814, 0.027943505199566007, 0.026143365201630422, 0.10018217587663282, 0.05560180352580163, 0.06811552035111575, 0.0514729343534958, 0.0302844132567125, 0.0286470995014233, 0.030674800171606967, 0.05806766818427752, 0.07466298272652973, 0.05360159009034115, 0.03739032308540998, 0.1290688080893409, 0.01139342144597322, 0.02691000279399657, 0.028026447623908043, 0.033454216956611604, 0.028926870980930906, 0.07271921847976985, 0.042006316925248796, 0.04889447009190918, 0.04135660158710615, 0.04097418581706382, 0.13450237862285108, 0.19429466777270843, 0.07939181365673581, 0.0928738043313065, 0.17921807274462717, 0.20043628740935557, 0.12317334782452354, 0.1834875267119177, 0.09830686924678665, 0.08850376301955792, 0.11199601009608277, 0.11292264706665471, 0.1232242773497297, 0.19622154744161716, 0.09919081979821767, 0.10888270538059935, 0.1038455623652666, 0.15071805446378647, 0.13107958970771683, 0.14877545467067152, 0.19227305367108316, 0.1371230428377467, 0.13461876270030776, 0.32512924724048187, 0.23242474834044136, 3.2127195164080593, 18.9897374568447, 46.758790554538855, 62.076760030561886, 51.38834053470243, 40.789629567054014, 33.3365104275365, 37.74037115035519, 39.54623430005966, 32.92326911803215, 15.512946574918686, 4.449855906348075, 0.29728489297051586, 3.92582283866021, 12.237621372745885, 15.39762398888988, 11.698918150317285, 16.789732979189967, 16.18674897378491, 19.138279576455396, 20.32642629838759, 20.76431578205478, 22.17452160773739, 22.842161963062903, 28.45826845015249, 47.50874380911551, 54.036560135502974, 56.47658424992716, 53.118019488550004, 51.0326050942944, 48.70478822338966, 51.15082140891783, 46.195742161043235, 50.7304649199209, 53.85839039279569, 56.08691638515842, 60.1527197899357, 57.365656129775516, 54.209921052378995, 56.45874923275363, 58.745039970644065, 56.848236668494444, 51.100819033961145, 40.85214430286039, 43.13029220027309, 52.89938265277494, 60.98754529030093, 59.574119198706846, 57.76708718269103, 58.50704231569844, 57.65951618071526, 56.2654273740707, 55.72339503995834, 59.04059448549825, 61.768175401995265, 59.6851065851027, 53.03070360614408, 52.1038200778346, 42.96061831135904, 45.326945012615575, 49.219681678279755, 59.46810145531932, 54.06928446985061, 52.23449776249548, 60.38412786299183, 52.362551381511075, 45.543393165834495, 42.31041093026438, 45.502639739744126, 46.66780725602181, 55.67503221573369, 58.96954859456709, 58.10681935279601, 58.362683403876524, 59.7278251186494, 54.071445695815555, 49.4018522385628, 45.11900448030041, 41.90946625125024, 41.21765428973783, 51.221192652179354, 60.66245140567903, 56.85923891682779, 56.83754820977488, 58.050796139624815, 59.8829117128926, 56.398944854736335, 58.81326567742133, 56.367962052745206, 57.80602455139161, 55.007264383377574, 53.04616166699318, 51.44105326744818, 59.59616291907526, 55.65191768830823, 55.464930457453576, 58.593754153097834, 57.608999975266, 51.418891875974595, 46.26069661109678, 42.31753787686748, 20.41421482639928, 11.53971600917078, 13.964184003491557, 9.028231213169715, 17.501805943827478, 28.070940279191543, 23.550108594279138, 40.05861743803948, 18.51373234102803, 10.75318959451491, 5.207141051369329, 0.775220243921203, 0.3394411792678218, 2.084555885484142, 8.78272908349191, 23.675800946451005, 38.98216609031924, 38.32004647101126, 33.495637063057195, 44.44627877204649, 60.35745574582008, 60.56751435802829, 48.86330689153364, 20.356975678474676, 3.2022112415682886, 0.10467439289054564, 0.2811772202051455, 0.14280413637959188, 0.25308489859584843, 0.13602856366384414, 0.11443249911310212, 0.15262754393681405, 0.16556073220506792, 0.1374121950638871, 0.18048424754411946, 0.16374231526447883, 0.24552083754491424, 0.09288653671260803, 0.07025111301411545, 0.24153411598695865, 0.10508499303532225, 0.04811247435188101, 0.14122146001506236, 0.1625970444611965, 0.18071681651617252, 0.2629539496715992, 0.11194601519814423, 0.15667032780906848, 0.12276637127562878, 0.10315214554148336], [0.029702387532339464, 0.048575984359148054, 0.036679711418166276, 0.07345134572636697, 0.00966935110608897, 0.027508271497584162, 0.04494326820056285, 0.04337495598461359, 0.028835220052109613, 0.012941265707805514, 0.03568710661643455, 0.06731576286256313, 0.03283832823076556, 0.061722079952878345, 0.05364262942044486, 0.0435821712768126, 0.02717058568622076, 0.07461530907500176, 0.03287984636582194, 0.03656367591071514, 0.0512453526138298, 0.056585349337828744, 0.04123192460786912, 0.07535620802833189, 0.08968873249907648, 0.6187293185822426, 11.369503774950582, 31.247371742802283, 40.70693423671108, 41.340930461883545, 30.71089936840919, 16.163238286972046, 16.7953243178706, 28.6950207525684, 24.848344479837728, 11.40278704704777, 2.170515118106719, 0.7432724775806551, 4.792248914318701, 22.350940012162734, 38.55748322702224, 8.011100321046769, 5.974394409887253, 11.19269705587818, 11.963236870304232, 17.777725073599047, 18.67795217421747, 12.957956810151378, 15.348678692694634, 29.741658164608864, 45.63152490123626, 48.500299376826135, 51.01237743131576, 47.33519854084138, 47.46404055626162, 48.71763006333382, 47.38631486892701, 40.95016041109639, 39.08621088151009, 42.31153665050384, 49.73966244728335, 54.831357848259714, 57.19970849252517, 54.896371133865856, 55.03272841053625, 53.771721701468195, 50.765793708062944, 46.26981612174742, 37.14932487856957, 41.021076863811864, 53.58999044664445, 55.269874911154474, 57.24019911981399, 55.46534622869184, 55.196240255909586, 57.231307106633345, 56.17570707874914, 56.89872933972267, 54.88558069352181, 53.82066503647835, 50.18121542469148, 43.953876187724454, 41.939331177742254, 38.31488463186449, 42.38162156074278, 46.311844318143784, 52.78123694081461, 48.15400508142287, 45.90540047614805, 57.257453626202, 47.1154869756391, 43.58115296210013, 37.88493402542607, 42.6430396879873, 46.445428479102354, 53.10681719933787, 53.850255397058305, 53.89942622953846, 52.50191711610364, 55.945577698369185, 53.875287963498025, 55.442380751332934, 51.95476216654624, 48.903958335999526, 41.82004797843195, 39.57902139233005, 47.18346949546568, 53.354255999288256, 55.277751030460486, 51.16920948028565, 48.87851392069171, 46.432535648345954, 47.46632729807208, 50.83547461417414, 55.49521115518386, 53.897088496915764, 52.854408756379165, 56.25659419644264, 55.28228529037968, 54.43809317004297, 58.231821367817545, 53.569586277008064, 51.78624537683303, 49.19564147149363, 41.12705538349767, 23.754693538911884, 17.977887545862508, 15.399559678569918, 4.000775900579268, 7.028802527535347, 10.117645994309457, 15.690391659736635, 15.27334467057259, 7.430930291452716, 7.784775639733962, 7.827371108916498, 1.4446899559228652, 0.32018549800399815, 0.192357890247818, 0.9691201619082882, 5.930539369583131, 16.238941992482832, 35.21268990732009, 28.930135465437367, 24.158019096620624, 29.609535086539488, 40.81833739434519, 53.04138029775312, 31.579053248128584, 10.896543398980173, 0.6941325337656084, 0.04529911221095151, 0.026980134313024824, 0.004539700579874579, 0.02998928362954288, 0.04201402376976706, 0.036581016310881224, 0.04434694152986331, 0.07141959628150349, 0.021476466734442982, 0.06513801238109028, 0.021180438869182142, 0.035142950533378514, 0.023004611045302405, 0.04457761443430378, 0.08611372957426695, 0.06400550460262645, 0.07641926993645969, 0.05331976932563609, 0.04951653731686454, 0.036969614410472494, 0.029890421898134296, 0.034996696687754125, 0.03340681909673637, 0.03339417481554612, 0.10612461265296706, 0.02080488916216118, 0.06747059689293947, 0.05762025368429961, 0.050460081847925345, 0.035925398265281995, 0.026287971958217603, 0.033483090810477734, 0.028618375034702402, 0.01772589177914685, 0.0911702009879293, 0.027553359602367686, 0.03946336466939219, 0.05280074858737569, 0.044312977021740335, 0.06468373756375044, 0.06294863268492684, 0.03948538586677563, 0.017021186649799347, 0.0453998719251925, 0.04418882481273144, 0.02243684987807947, 0.030164237044030623, 0.041529185874688054, 0.03088461441708909, 0.08966984843174297, 0.778496526181698, 14.238991141319277, 38.78761260740219, 46.8544493183013, 45.518807749594416, 35.785642285500806, 23.07630196694405, 27.700864653433523, 33.00884346808157, 27.795040761270833, 12.460542417341664, 2.7595374468834173, 0.594404494810489, 4.92248974500164, 24.098642256952104, 32.31575477507807, 2.5912010861981303, 6.521058572876838, 11.774322775102432, 13.855521602015342, 19.94185163128761, 17.560641496412217, 16.302227474028065, 17.565524847276752, 29.104229865535615, 49.19169556710028, 53.369431649484945, 52.356365803749334, 49.72140773650139, 49.2662049108936, 50.648781561082416, 49.03802494848929, 43.631163181797156, 42.04960077039657, 45.36321124722881, 52.21802380777175, 56.62371235509073, 56.621280485583895, 55.11095616125292, 55.53842390737226, 55.80195226976949, 54.30590145049557, 48.34900179216939, 39.272131227677875, 43.103270992156, 55.83565327429003, 57.37727419022591, 57.28061129969936, 55.1472576971977, 54.34268151560138, 57.19496634698684, 57.32123920994421, 55.816465039407056, 57.60808606301585, 55.01747431293611, 50.980947479125, 46.50834721903647, 43.46950661751532, 39.708671416005785, 43.67572522932484, 47.73379372012231, 56.518773263500584, 50.68933886866416, 49.27570489145095, 58.86095385397635, 49.866809998789144, 44.65161877293741, 39.57046670298423, 44.657639611151914, 48.810558857456336, 54.708622963197776, 54.82917308807374, 54.139479206454375, 55.31949289383427, 58.8067663100458, 57.620013990709865, 58.48706960678101, 52.654183526192945, 48.99857374929613, 43.414126673052394, 41.805225341550766, 49.463496208190925, 55.92000776721586, 57.663462085108605, 54.44665178175896, 51.04199132611675, 49.19106406550254, 50.954036097372736, 53.84170463008266, 56.31481001454016, 55.14145258934268, 53.227390858434866, 56.69680572325184, 55.53026537741385, 54.99283398351362, 58.175625570358775, 54.75366746225665, 52.88901975077968, 50.561763778809585, 41.569216328282515, 29.254095785079468, 18.310733995129986, 19.041695133332286, 12.928958727467446, 12.36189284632283, 14.43776019157902, 16.230930551405876, 9.662568684547178, 13.524170556376058, 8.020611578418363, 5.442111617134464, 2.001629748171376, 0.19419754314566814, 0.32261742879786803, 0.973873277825694, 6.513866907165897, 18.196365525645597, 36.375041161814046, 32.01381268039827, 27.631197475617935, 36.183727556659335, 46.559510615564164, 59.993828496625355, 37.437936798218765, 13.729313458165816, 1.2348449903149759, 0.10466968144981131, 0.1085458335376555, 0.017568133208119584, 0.038947986679211746, 0.03727854702681784, 0.025466731449048367, 0.02683230041105661, 0.07060210385750379, 0.05493913747129902, 0.03202982776377711, 0.05844788145153754, 0.02963040591097407, 0.015993386811216273, 0.030466723030493147, 0.015279176445948261, 0.07805595549965098, 0.009230387513525784, 0.04497715993033302, 0.08103371627869145, 0.03545619622473756, 0.07569339396732469, 0.015336468331365576, 0.03972620177533358, 0.03667276683113268, 0.05015642374693867, 0.1172427777501364, 0.20820650272071364, 0.19222020892606628, 0.09461835507423648, 0.07104375354585148, 0.08097613711030253, 0.13356237341800045, 0.13409219982643283, 0.08178850440608879, 0.14423834490439585, 0.14133355400014308, 0.12327565886681119, 0.18201925791800025, 0.17975735267804516, 0.2527700824242446, 0.2559586935826848, 0.1016255314912527, 0.22785936992975975, 0.1316029196905513, 0.2399321954937712, 0.21723802051236554, 0.20645128803387766, 0.12194357752319306, 0.10058168306826584, 0.1355053102898021, 1.13123778854647, 16.96384502995399, 46.09210921872047, 56.021828574519006, 54.508915485874304, 43.89719009399415, 26.361869458229314, 28.494085573380996, 41.75554852331839, 34.72426852872295, 15.510716707475725, 3.1027418951834402, 1.1253971342117557, 5.588200294202374, 28.256462504786832, 48.79408490273261, 17.698181367689564, 19.445897340774536, 24.554625634224188, 22.96823870751166, 31.4407681265185, 25.82924492897526, 21.036239977805845, 20.477816058743386, 32.74654869110354, 52.557763822617076, 55.95216728025868, 56.27022835516161, 51.744354463392696, 53.296569701164, 52.45150289227886, 52.401045522382184, 45.060874954346694, 44.003635375730454, 45.94638924444876, 53.993076739772675, 59.121571817705714, 58.74051747783538, 54.19555733280798, 55.69577370920489, 58.45915802063481, 56.592611881994436, 51.28812397679975, 41.31732563818655, 44.76126863110451, 58.80986106011176, 57.94510787533176, 58.36181263769827, 54.83089893094955, 55.6523609161377, 58.12935729180613, 56.68942382258754, 57.03187027285176, 58.86440553972798, 57.53974268513342, 54.527209420357984, 49.82634682809153, 45.894359004112985, 42.5469220069147, 45.48783671471381, 50.08011241112986, 57.91090872979934, 54.18678691310268, 51.956389950167754, 60.20280845703618, 53.62222056235037, 47.396901346022084, 41.63713216781616, 47.189211845397956, 52.431930265119, 58.358278582173014, 58.5920165431115, 56.020420443627145, 56.30903236327633, 59.88572405230615, 59.14167004246866, 61.18339315537484, 56.38226693676364, 53.099764777768044, 48.44042047377556, 43.145989525702696, 51.57619460936516, 57.49643579606087, 59.30243230635121, 55.64273934210501, 54.069821834564216, 50.113581995810236, 52.95129129963537, 54.81134199327039, 59.79951820065899, 54.340332015868164, 53.40329739355272, 56.58049175816198, 56.335069056480165, 55.01088080867645, 58.752508163452156, 56.258924084324995, 54.985691347429835, 51.74267568895894, 44.777711206866854, 27.877161464383526, 22.229950581827474, 18.30461705884626, 10.294365440645526, 12.337687899989467, 19.383665015620572, 20.091366498701035, 24.081621131589337, 17.007695167295395, 14.866365425048338, 15.132384492504983, 3.8592668358356725, 1.1703177108880014, 0.49206143004759667, 1.6334264413003, 7.421578380369372, 22.14574121659802, 45.33810807812599, 42.05050683790638, 36.37210330655498, 43.516371096334154, 53.4466984195094, 70.20640173266011, 45.4249297418902, 18.038041014825147, 1.9042737012909305, 0.26441104890358064, 0.18045345080956338, 0.2934008884814478, 0.16349828561707852, 0.14844134840513432, 0.10972848177076348, 0.1324723528758172, 0.1558528047415518, 0.11911584740324367, 0.11741528542892588, 0.1307160197006118, 0.15094486245464894, 0.14790594487661315, 0.1159512377794712, 0.20899684498867682, 0.20300589952497713, 0.12421018654300321, 0.08111015653177615, 0.16453549205776186, 0.21044426086929538, 0.1554949497503619, 0.09291518840097612, 0.15838602768077006, 0.17856391026608406, 0.19143001987568795], [0.05557526624010456, 0.03136225108567986, 0.008831067055824303, 0.055124369870510795, 0.01801075008247168, 0.08969143678944919, 0.023775935180545337, 0.043759390396336396, 0.05944314074792689, 0.106074380267772, 0.014886022038427333, 0.01604589160471674, 0.01907945997382124, 0.05027638545500175, 0.02733269563665794, 0.02230284960880395, 0.04768534202969844, 0.00669799673731529, 0.042349915020167835, 0.045852813749544086, 0.03290827588869199, 0.0327075953264871, 0.1079306496126998, 0.022557723230772445, 0.02861656323676148, 0.1369219907228985, 6.521031606581904, 24.842533488427442, 35.84279121891145, 38.50697486631332, 31.006848081465694, 13.864197884836505, 12.570093235661908, 17.449542322466453, 19.092701635053082, 11.87239379652085, 2.185261759065813, 0.463328812151186, 0.7528897002339364, 2.1718663746310822, 13.834142723391134, 7.62420557198986, 5.97140311233459, 10.743591554703253, 9.632843982788826, 25.398705967010994, 19.797963403886367, 13.080457333595524, 19.32378219019982, 33.94652135910527, 45.11058315154045, 51.303538891576956, 48.9958712362474, 49.18581985658216, 51.957802003429784, 54.27833503292453, 54.26284167074389, 49.23670084245744, 43.24925768759943, 39.087720994026434, 43.2662925412578, 50.85698489219912, 54.46283155871976, 54.05767033177038, 55.276652766812234, 53.91280543419623, 54.05236728729741, 44.42236015873571, 37.14443760533487, 40.49445552210654, 51.673563526522734, 54.98177289962769, 55.698691952613096, 55.094176261655754, 55.84432171237085, 55.76500746511645, 55.252024204500266, 51.80921085419194, 54.06108279382029, 49.20141912275746, 46.96593092333886, 38.87657588528049, 39.08220614156416, 38.20278721470987, 42.89001172588718, 47.000396790043006, 53.695965043960086, 49.982853320337114, 42.81989151431669, 58.54044914245606, 48.14483457996, 42.501540184021, 38.82009375479914, 45.895963253513465, 46.5509049354061, 55.260421999039195, 52.72766128663094, 52.66431893071821, 54.8040856084516, 53.91203272727228, 53.02752256393433, 55.78674916298159, 54.166312140803186, 54.75901757517169, 51.79620819707071, 43.181165341408025, 36.30170068433208, 37.85712834327452, 41.04359519097113, 42.29662772147886, 39.37293614110639, 41.0924796904287, 47.486500047868304, 52.17403050391905, 55.33886548011534, 54.310078774729085, 53.57160237527663, 52.933624944379254, 54.926161535324596, 53.79610315445931, 52.4884908430038, 56.04344867890882, 55.648218893235736, 49.50893686663721, 42.24542510124945, 37.18513611824282, 22.551796743946692, 16.295794786945468, 14.090411759191944, 15.535009907137965, 13.339299444229374, 12.262801028067067, 7.099974914904564, 10.655916775426558, 9.208679852947112, 2.4522643608431665, 1.7373503744602206, 0.4004097964254118, 0.3191274999370498, 0.7036996236251247, 5.451478237105954, 18.018658622618645, 30.356464193713283, 21.126760436642556, 24.31114254459258, 36.08447590181905, 50.4070419649924, 41.77642729974563, 34.289010955441384, 11.545516214063092, 1.8624608675318381, 0.012698708864439641, 0.03189002820891479, 0.07992929328353175, 0.041836394793203766, 0.04320921669263513, 0.04096953949380306, 0.0320014422909627, 0.01977764569493311, 0.01875446057848392, 0.009376605927583673, 0.04640228265235501, 0.02012241973481592, 0.01881981362408448, 0.05452469539558215, 0.024925166658396204, 0.02335561529522942, 0.05635636182682169, 0.05732406877101429, 0.028830631185443174, 0.059557161444137176, 0.07451282183249151, 0.06461017780126103, 0.03678150535110505, 0.033097135714225234, 0.09924402460455896, 0.03083069523375842, 0.07309933598603933, 0.03981344769859026, 0.024169915047804677, 0.035339789164643136, 0.01609586926567699, 0.012028249780527286, 0.011733509900589145, 0.014081886357387469, 0.056323990781581214, 0.12081146811044986, 0.03623851372169391, 0.030594845490169623, 0.057307655337236585, 0.05421778142091729, 0.07660385882181507, 0.02352777631923316, 0.055895299470472726, 0.08153292215279034, 0.04623216516788929, 0.07913586368123371, 0.08010719422130816, 0.039179077101570946, 0.00823190011414549, 0.07653223726177409, 0.4548052259750905, 9.319845707185808, 31.807284201345137, 44.39639799056515, 46.79661004774032, 36.3888910508925, 18.940543090143514, 18.564203439220307, 27.386143476732318, 24.389399713085545, 13.55800884385263, 2.3887347117547066, 0.6581800887661596, 1.1521176681403191, 7.021013190669398, 26.91535315205974, 12.63434656204716, 10.361345794893081, 9.627671357124083, 16.476380709678896, 15.906032785292595, 12.253437349873206, 17.000834941864014, 20.77486107426305, 34.96145817541307, 48.492113390276515, 54.109779019509595, 50.76817458675754, 50.84988147981706, 53.10698586125528, 55.812295559913885, 54.450099545140425, 50.149758015909505, 44.62928087480607, 41.24543251529817, 46.34329780455559, 54.05621905480662, 57.65935144116802, 54.75484809567852, 56.32845594036964, 56.647717260545306, 55.11782423142464, 47.28429794311524, 39.765506559802645, 42.60283147135089, 54.39283294062461, 57.42275799474409, 55.71157301625898, 56.12875238541634, 56.45725480971798, 58.340451409739835, 57.41046136425388, 54.470174235682336, 55.198899622886415, 52.11702669820478, 51.05753960147981, 42.53472343567879, 40.633185832731186, 40.3747957752597, 45.03918032492361, 49.01889162678873, 55.71918633676345, 51.26606064458048, 46.55998129998484, 59.07120073995283, 49.139614335952274, 43.17610940625591, 42.02747468025454, 46.03696461646788, 49.4738708772967, 57.73608084647887, 55.30707074749855, 54.470813582020426, 54.515799245526715, 54.18667316436768, 53.80977653688001, 58.289997962213334, 56.928425604297274, 58.921719212685865, 52.03109149009951, 44.29148243319604, 38.34491822027391, 41.472839770778535, 44.12971604254938, 44.735279006342736, 41.928183801712535, 42.22107502721971, 49.70566334262971, 55.04710781958796, 57.004252864468484, 54.01878003151187, 53.432381768380445, 53.48327059899607, 54.36895747338572, 55.52985745091593, 52.323151173130164, 57.95759277959024, 54.3499888912324, 52.37081581546415, 45.47830927756525, 38.69185970675561, 25.91487615339218, 24.450769116801602, 16.80738952852065, 17.344803271755097, 13.246900170080124, 14.448961500198612, 8.955074106493305, 17.314901082746445, 12.931464141415013, 5.2013290793664995, 4.224948181260017, 0.12736325888263603, 0.44333587851255174, 0.6507476262988583, 6.922677899560621, 17.972578617834277, 34.39186334609985, 27.798162967927997, 29.277298565833803, 40.073722485573064, 55.69390666100287, 50.33692175342191, 40.44967382184921, 14.594051934057667, 2.016556205288057, 0.06327885105424831, 0.05313938243254539, 0.05626674486143936, 0.05361737533202095, 0.08323441109349651, 0.05337356785011869, 0.008901827724560375, 0.018196744739168116, 0.003082403362045185, 0.06358517514121148, 0.009299542270450583, 0.0721838838991619, 0.05473103734754747, 0.04797468194738031, 0.04160949870223, 0.018835589289665222, 0.01925749880742402, 0.027851955777394678, 0.02807489502423954, 0.0378495161872237, 0.06862310722710625, 0.01976308236349254, 0.032090771973373435, 0.05516624806689159, 0.016521304703107285, 0.09967883312774282, 0.15775074160868124, 0.15676664038290902, 0.16340592605692728, 0.19212987183803515, 0.1648739956679844, 0.09718396055001406, 0.1362444472409064, 0.1851979865422172, 0.2538815993935831, 0.169064098248078, 0.12915817990658746, 0.12411767376526711, 0.19075501980560441, 0.17693169865637057, 0.16535672299083204, 0.1311871637740443, 0.11313722829424566, 0.3544958182159932, 0.18414343587092816, 0.13085653554768334, 0.15017020966737502, 0.18149860924290073, 0.12541400178545906, 0.09008565031352544, 0.9849317876561996, 12.222130952342866, 39.133110661660474, 51.9660742821232, 52.157187846399125, 42.46072792237805, 23.573829127896218, 22.711464666551162, 28.97373849345792, 28.275662506780318, 16.02108374718697, 3.2215517134435716, 1.1057344151120032, 1.0945997867853412, 4.931518550842039, 22.212870620912124, 12.591205393114398, 12.477664543736367, 19.2602260651127, 18.691233319620935, 32.46995491366233, 31.925422068565126, 22.298401824889645, 27.168218551143525, 36.30637222720731, 50.80901822736187, 57.11737009786791, 55.03757646006923, 53.456339605392955, 56.1610060353433, 57.88405618359966, 57.735363052737334, 54.88816945783554, 48.53013292435677, 45.71014488897016, 48.82404396610875, 55.88940935750162, 59.38134254947786, 54.853405490998306, 57.29170768491684, 58.83323446396859, 60.09214270499445, 49.57721748659688, 42.83136444707071, 45.32385418491979, 56.26964392200593, 59.15932855298443, 55.42100775626398, 56.641555217004594, 58.171542383009395, 60.78307997795844, 59.124301787345644, 56.55660844618275, 58.46003663155341, 54.686983246957105, 54.09831785386609, 43.70539403730824, 41.34986169876591, 42.244530800850164, 47.05498441573113, 53.85979852368755, 57.7286518773725, 54.20035439152872, 49.074079375113214, 61.4371116699711, 52.63454029636999, 44.63044581874725, 44.847078323364265, 50.15932075438961, 51.16325924473425, 59.52109659871748, 56.61941735975204, 55.882290255638864, 55.8096440376774, 54.34452895195254, 54.871036544922866, 57.77795214806834, 57.55596953053629, 60.80752026650214, 56.96249138924384, 47.23295803992979, 40.47308252703759, 42.62605582514117, 45.504012569304436, 46.19500083308066, 43.11277097271335, 44.64233060036936, 51.980634120202836, 57.073941615320024, 56.8139982992603, 54.22766193266838, 54.67573781167307, 54.033367326182706, 54.078219629103145, 53.810031490941206, 52.42192037643925, 56.00811596839659, 56.44558968082551, 53.244578684529955, 47.440039573177216, 39.382934262675626, 23.336170757970503, 21.56017057357296, 23.269629709182247, 23.12329000042331, 18.850444286100327, 21.002735091793923, 15.596669566246772, 22.08920809530443, 14.308603405952455, 8.5894739051019, 5.206923850121037, 0.8025756502343763, 0.832183416331968, 0.8549801704864349, 8.085197815971991, 23.197911131766535, 40.344420940645286, 33.19449709307763, 35.76734442864695, 47.211894912104455, 61.8360794744184, 58.36140471120035, 48.702148468263694, 19.190880521651238, 2.914968474257377, 0.14214695551462714, 0.14843658333824528, 0.12170071232943766, 0.16214244788692844, 0.12537353702129858, 0.25902940380957823, 0.16595298454405802, 0.1533284990657722, 0.16617321950053016, 0.10453958439851001, 0.20162594534697073, 0.22317627444863322, 0.2075847610831261, 0.1256137745334737, 0.13487903341170282, 0.10687022304703152, 0.20951467446021496, 0.1353087627719487, 0.11042263403895403, 0.16423992001481597, 0.17546690790162933, 0.14605374345856328, 0.15423448996678477, 0.1614346898972027, 0.13688394679657875], [0.05969910604518749, 0.048670519609004266, 0.054924118317543506, 0.026407094800003597, 0.013775768156553951, 0.08753521337864861, 0.051257020132916595, 0.038869382227740945, 0.06065775016923586, 0.056751916004765424, 0.06792746874834261, 0.09659341401270322, 0.047245339430387945, 0.018635948691817544, 0.013335827801887308, 0.04922370786868757, 0.038735845441659617, 0.07770489570834944, 0.05935028706106448, 0.025571959371107723, 0.02559713110507977, 0.0724847189661476, 0.014562493531904636, 0.06688007333826634, 0.09625027557053874, 0.44636060814222983, 7.2011485311292835, 24.188303716721077, 38.54657119320285, 38.914250250785585, 33.0133306595587, 27.912090170768003, 23.937570125825946, 28.844653291087, 26.297368041930664, 8.50195307885447, 2.31805139491635, 0.017547739947575237, 0.07049437657359146, 0.28957332935064073, 0.24170331416591523, 2.8023447240552595, 4.123802021626504, 7.097194444748664, 17.22643006232477, 9.77924939124815, 11.321020337843127, 23.951545530749907, 17.47692438863939, 29.375626502498505, 45.89582597055743, 51.6451184980331, 49.76958620932795, 52.4763903310222, 53.01295488111435, 59.80085180651758, 57.33229244908979, 51.375157448553274, 45.087652975513095, 38.874371513243645, 40.0563463857097, 46.31931643332205, 51.2433461989126, 54.90234882600846, 54.015324423390055, 53.29987233684909, 50.836600334413596, 42.0851178323069, 36.06555831047797, 43.25717303060716, 52.99032672759026, 55.72497967750796, 55.47887056104599, 54.099133706861934, 53.21790264498804, 48.18882788381269, 48.74660461179672, 47.93718822540776, 47.5531058157644, 44.15214807756486, 41.528443290341286, 37.06981843517673, 39.45844773323306, 38.07875010275072, 45.271761186661266, 46.60298616655412, 55.48865687462592, 51.08527468096826, 41.83020691717825, 58.70815007917343, 47.493717208985366, 43.298169643648215, 37.534799729624105, 43.65264208086076, 44.93303706569057, 51.94081029584331, 52.832055168767134, 54.74669348809027, 51.290936316213305, 55.24962763632498, 54.49532055085706, 54.82089688701015, 53.41038903882427, 57.42382487943096, 54.13884378248646, 51.49921024999311, 43.32283742966191, 39.32591476748067, 38.22206174173663, 37.3522133981028, 37.4567327960845, 45.42694584015877, 47.50080885425691, 53.8343031175675, 51.01781383637459, 54.02795053297474, 54.22968195330713, 54.68866202139086, 53.31769950928227, 57.412920690351925, 54.488734891337735, 58.78780165026265, 55.995603607546904, 53.86567031183551, 41.41902485201436, 33.73782773171702, 20.108762210415257, 29.543904027631207, 20.801295888039377, 17.2932868619119, 18.286252521699478, 16.988048015102265, 6.0819654118630195, 14.869958316126178, 13.21671066745635, 5.5332047420163315, 3.3541150775647934, 0.38768624045675804, 0.5126800736592663, 0.6234013517537426, 5.302456607741695, 12.602887192080098, 33.17736418016496, 34.08587140421714, 27.208709178432343, 30.8811027772965, 39.05770701746787, 51.099493272842906, 38.00338175988967, 11.413717712125472, 1.7312920285809426, 0.060752488432392004, 0.014913143466166673, 0.04821033825376823, 0.012051540768645223, 0.06029177081560897, 0.023458512394779155, 0.05792982598406173, 0.09663721892021357, 0.020018888697508844, 0.040036229897410645, 0.06247036016335892, 0.028720316439566594, 0.024712632800782883, 0.06567104103704614, 0.0174988558771269, 0.03548392477715689, 0.08341853266521808, 0.012154464681272306, 0.03891834673742133, 0.03726542394067492, 0.02194497929585557, 0.05199102812536782, 0.02513538884569801, 0.03375938042036949, 0.030179805865871812, 0.07363843971923476, 0.09526245881833377, 0.022468789998862534, 0.028378673784074285, 0.01357098040546501, 0.03735630878157193, 0.020835360309349436, 0.06252727283525371, 0.07381552094293219, 0.06085588731953214, 0.021627767184268565, 0.03133175504063407, 0.06289196133072819, 0.018765697173113306, 0.04941221912421527, 0.06679719794661769, 0.03310474679775296, 0.04476775362667057, 0.040732419959479765, 0.006617041832331809, 0.059130404505037495, 0.04435976967215539, 0.0668909288041534, 0.00721744696361824, 0.006380155954825422, 0.44216425428467415, 8.663563555286778, 30.436717848623957, 44.211368022426484, 44.89706108647008, 38.027731833919404, 23.90313171571301, 21.012184081539033, 26.43473532892043, 27.09570961613809, 10.359108082709774, 2.7286313762587886, 0.11046256254156751, 0.022195156798848224, 0.2595870238879035, 1.1482728873529742, 4.04310685492331, 7.237187268272524, 9.596110005532543, 13.278516434854078, 16.633622646331787, 15.616326524365334, 17.048303465689383, 20.47458206453631, 31.696428214350057, 46.54599020558019, 55.15434934246925, 51.25891016375635, 53.859272926084465, 54.80006910139515, 60.64498901367188, 57.54093900803597, 53.989256351224846, 47.62425368832004, 42.17078239687028, 40.1582181838251, 48.134287326566636, 53.814279417837824, 55.82286242515811, 55.201660971487726, 55.759755411455714, 55.31721399676416, 45.010688227991906, 37.95855299119027, 45.05594845741026, 54.319861165938846, 55.29144010236187, 54.55449342727662, 55.66191973224763, 56.049230252542806, 52.44161067470428, 51.46883149300852, 52.044780562000895, 51.12191354074786, 48.185921407515, 43.752560538630334, 39.504896440813624, 40.88375076170891, 38.966609970215835, 47.58192739179058, 48.45885561358545, 57.31050368278258, 52.86535216915993, 44.239856196988015, 61.79305891836844, 48.307165791911466, 45.00989198684693, 38.68131637573242, 44.35167904823057, 46.82554929487167, 53.88920061049923, 56.49303859280002, 56.7472787826292, 54.39828111279396, 55.16325704513058, 55.469441183151744, 54.66774794363207, 54.057399688228486, 58.074471565984915, 56.926766441714385, 52.549817100647964, 43.672689314811464, 41.06383069869011, 39.80420466392271, 39.51576532856111, 39.18150878721668, 46.16657541644189, 50.74894712817285, 56.463467844070934, 53.01943071426884, 52.55335900091356, 53.972072447499926, 53.80980791584138, 54.072928351740686, 56.455783920903365, 56.087398836689616, 58.47224304752966, 56.568834474009854, 51.71742739215974, 45.61701997633904, 35.90585116417178, 30.32694443579643, 26.279954679550666, 21.86707446652074, 17.19970303197061, 18.617133863510627, 16.568505417916082, 5.496128047666242, 16.08155688931865, 14.189828153579468, 7.52775792152651, 2.5146376461752, 0.447816971929804, 0.4157773976124102, 1.116480851365674, 5.534774670677801, 17.71671848912393, 36.53576812436504, 35.384226922065984, 30.954631528546734, 38.62902333659511, 46.85214688701015, 56.65764870182161, 42.81590246385144, 14.12440105792015, 1.9186518846019622, 0.09540953237803713, 0.030804270946030176, 0.030986703293878707, 0.03466527556039153, 0.01870204484270465, 0.022709784022862875, 0.016429450760986057, 0.0586899001181366, 0.021706348653101636, 0.021676325667349082, 0.022880269229532253, 0.050131736563578735, 0.041890963236050266, 0.04322089570304079, 0.020461185730152556, 0.04289350802859953, 0.07573686945702761, 0.02397876078893821, 0.03983478707772109, 0.040125467649270455, 0.02458875446820692, 0.06388224871648897, 0.018597554280272415, 0.07513280146785321, 0.03377041974735837, 0.21769698378780197, 0.2718137565159029, 0.21437393952040903, 0.09732744115735255, 0.10848268491005707, 0.19945859067863037, 0.14822656799468303, 0.2204777757006307, 0.15291162466089572, 0.2003675999660646, 0.25718616562024244, 0.1304604834125888, 0.22361640728289084, 0.19481430521174786, 0.07003693781312435, 0.1334568065020346, 0.1016290938001006, 0.22467590688217073, 0.20686742699434682, 0.1295815813805788, 0.15709293255161855, 0.1309161984752263, 0.1974185598233054, 0.16161318838356004, 0.23576875277344259, 0.6950582131262749, 12.031008562734051, 36.148822384495894, 52.27873817566903, 53.534375159971184, 44.43221707497874, 38.45785894701558, 35.205645330490604, 40.114013071983095, 35.47825790220691, 11.619029275832638, 3.4318339007516063, 0.21918069691427294, 0.22663673956788358, 0.4576723866405026, 0.8164001664807721, 4.7868144704449564, 8.264307456631816, 13.033389872120274, 26.352995095714448, 18.43111938045871, 21.037940325275546, 31.803350064062307, 21.876782332697225, 32.4106074917701, 49.453764807793405, 57.0820923005381, 55.19867212541642, 57.4545213483995, 58.621238200895256, 62.575524699303415, 60.099889386084776, 56.82610665598224, 49.52808587781845, 43.46958898728894, 42.60978191129623, 49.680093411476385, 55.44848395932106, 57.7234665040047, 56.39137468030376, 56.89165730630198, 57.963084097831484, 46.98658612466628, 39.90471932195848, 47.15544416058449, 57.659806436108006, 56.93166548205961, 54.44915817629907, 58.11713910871937, 57.35960391259963, 54.023832044293805, 54.08121239754462, 53.930750277734575, 52.69136367305633, 48.33275925728583, 45.707909137971946, 41.49127098821825, 42.24991621509675, 42.57412756642988, 50.259325504302986, 52.2243074447878, 59.96166506121236, 54.86680430750693, 48.70926364775627, 64.24242219617291, 50.5986419031697, 47.52163271750174, 40.58141446882679, 47.113196311458466, 48.53777762382261, 55.31830049330189, 59.42053487223964, 58.86202073866322, 55.63271376394457, 56.84607936489967, 55.38186250194427, 55.729431567653535, 54.374829261533684, 59.41349421778033, 59.07542121025824, 56.03756512365034, 47.283136921544234, 43.40810975720806, 42.89377327888243, 41.848367491076075, 41.06959658284342, 49.29540695682649, 53.02594577112506, 58.3112689756578, 52.73857332045033, 53.274906450702304, 53.306905146568056, 53.55137863466817, 54.844886102984034, 58.41708667816655, 56.33873647259128, 61.12262779666532, 59.49668768913516, 53.687394665133574, 48.565622529675885, 38.05537277652372, 28.979049382671235, 33.771065896557225, 25.661251775680054, 23.27623498055243, 27.602774020164247, 30.963150916561005, 19.482775465134655, 26.744420182320383, 23.20187664801075, 8.1312685051272, 5.305364554928196, 0.7301816897046182, 0.7683062697610548, 1.3584023473724243, 6.841839321198003, 18.877318405335952, 42.71213223857265, 46.43457528083555, 38.96730422973633, 42.017147079590835, 51.44512861005722, 65.53351348446262, 51.073766446882686, 18.565852795877767, 3.1377215923801547, 0.1876916793445426, 0.05553786965808081, 0.20273813647368263, 0.1648636841245236, 0.159362422062024, 0.14011904417026427, 0.11303586720098412, 0.17479570762765023, 0.11443216203441543, 0.12111441758010658, 0.11532771881789931, 0.131573946245255, 0.12014448898093355, 0.19126714958298593, 0.10432636680742426, 0.17471221936566217, 0.22418035524747065, 0.15967487868282104, 0.15258398417743946, 0.0981666904784018, 0.11406633206793379, 0.11825983607841116, 0.08822820119319424, 0.1592427744500099, 0.14504393232205223], [0.034923110112187364, 0.06214633944534487, 0.02290422288370469, 0.0509206960428386, 0.08674716171357902, 0.04366180611654155, 0.05241335324582554, 0.0168992618414303, 0.06705094158889786, 0.022815010029702418, 0.049995556774158637, 0.058342310705132065, 0.0374312398414458, 0.022503173940124053, 0.09076697826986352, 0.037066030406182816, 0.01716448339603601, 0.012353772030872925, 0.013488828966904794, 0.014394425332636364, 0.019682842314303405, 0.08449841020328384, 0.033984146786913756, 0.05238193214961118, 0.013213077533779847, 0.09290058676513935, 5.581148853225093, 17.567003580831713, 43.33608327373382, 44.41302884009577, 34.67041830862723, 29.67744504251788, 28.20295156971101, 36.610838367092995, 17.58797649414309, 8.417223999577185, 2.1789688064206034, 0.16030049672530544, 0.12648747482847783, 0.6415309756994247, 2.6772399919648326, 4.702992929566292, 12.762131498705957, 7.106459083095674, 14.395072056401162, 14.7284274331985, 8.04082453250885, 11.358339728847628, 20.953489734280495, 30.697800613218742, 42.601858723548155, 50.19003683520902, 53.000293470198116, 53.16521344646331, 58.6928802920926, 57.58395956408594, 54.23246683612947, 53.116501531293316, 48.965417954229544, 43.92598421342912, 39.496624162120206, 38.42029048550514, 44.974017989250925, 49.806907561517534, 52.867372189798665, 54.750572712190696, 49.868304421824796, 40.104654296751946, 37.737182263405096, 45.67486316927018, 53.15414059546686, 55.9111471329966, 54.9428080743359, 52.22700995783652, 47.3909628775812, 47.41488933563233, 46.24978849964757, 44.81064734920379, 42.57129953753564, 38.94924563746299, 38.774460900214414, 37.78640016432732, 39.19863777775919, 40.76487548889653, 47.903357782671534, 46.695891426455596, 54.331028153819425, 51.27923588598929, 41.65478675596176, 56.25158532973259, 48.70116395335044, 45.50280447929136, 38.60141377295218, 39.91301121250276, 42.32354694797147, 47.33678710076117, 48.69552750741282, 50.99084361906975, 50.580751972813765, 52.805347750263834, 53.44151696851177, 57.09646778721964, 54.13422715279364, 52.295886778062396, 53.88615685124552, 54.91231949098649, 50.7158423239185, 47.9034754537767, 44.66898310569025, 45.42376087557885, 42.989655617744695, 47.08430413276919, 51.76004002171179, 55.459015523233724, 51.745056567653535, 54.409059786027484, 51.9482510320602, 53.633340481788885, 54.32525442492578, 56.36422795634116, 53.94470214843751, 56.59607925722676, 55.52997119965092, 55.42727178142917, 44.08484805014826, 35.327889919281006, 37.74331292798443, 26.740729231988233, 22.22196267497155, 22.216416443547896, 13.732643550442113, 12.403897508498162, 4.457245161456447, 15.905092397043783, 13.25194335752918, 5.934924089139508, 4.062442178687742, 0.25122289125236774, 0.2706068309564745, 0.424088808076997, 5.1593405969681285, 12.667921070129642, 25.421373344236805, 33.48496037144815, 28.512401080900624, 22.262490564777007, 40.711170396497174, 48.90040859099358, 40.90972861936016, 14.815510915171716, 0.9486347869519265, 0.04297393193889049, 0.06826025734265005, 0.05409554826215871, 0.09179443241127076, 0.021728695437852896, 0.0505520660249937, 0.049890430358749245, 0.05866442003377503, 0.04581731706557255, 0.06120094481194693, 0.026275681992692333, 0.015397032369829476, 0.052432076434694955, 0.04750297096888385, 0.06225129349097129, 0.09327376351481484, 0.04876745271406347, 0.08529133418755186, 0.0693975838141576, 0.01740835982585146, 0.039203189718987674, 0.01582888858167515, 0.0507627172215331, 0.0839785965640218, 0.04620507629888673, 0.02062104146687254, 0.043675419498956015, 0.02967506117608038, 0.07238749474767717, 0.03175293677486479, 0.030166380174998796, 0.03377035846032443, 0.04712333609800666, 0.07488067427109327, 0.003143344459409315, 0.03206608095957387, 0.02204833604815987, 0.0416813385973294, 0.0885090566871147, 0.10350866753968502, 0.02088800587150599, 0.06421256284680098, 0.018160255971334634, 0.022654721453305215, 0.013313673496727022, 0.043309692954344135, 0.1255305544022591, 0.018419565242384712, 0.02377518632959935, 0.03824276444051535, 0.26385345946877237, 7.466870969341648, 23.47888227432005, 48.598315485062145, 50.26821359511345, 37.35026398012715, 36.94931930111301, 30.702070113151308, 36.968291805636504, 25.419165049829793, 10.135267242308586, 2.0739360682425962, 0.1668816363258708, 0.197574443394138, 0.9645687416195871, 3.2441144124154127, 7.192895864286731, 12.472734124429765, 12.22129156512599, 11.435528051468635, 14.325348004218071, 17.606662665644002, 16.457341524862475, 23.647491239732314, 35.176117727833415, 48.15970428528325, 51.99967330501926, 55.92458125083677, 54.236859890722464, 59.048870686561834, 58.77737991271481, 58.105579883821555, 54.6885561173962, 51.671551350624334, 45.87450004393055, 42.06754561393492, 41.29536428759175, 48.62132410849295, 53.16215792009908, 54.46214514393961, 56.06737513695994, 51.938574544845096, 42.686527006087765, 39.83370873235887, 45.91927389944754, 55.35016582858179, 55.77255018295781, 54.8413912711605, 53.6307321056243, 50.567898365759085, 50.02479130221952, 47.65333021840742, 47.2586730987795, 44.70493947305987, 40.45099173822711, 40.546081758314564, 39.774939860067065, 40.926351624150435, 43.288046006233465, 50.299816131591804, 50.02981585841025, 56.21275778739684, 53.25849525390133, 44.73587520660893, 57.687102210137155, 50.28042785583004, 46.43137070440477, 41.03252233997468, 42.04201098411314, 43.738953836502574, 50.186573382346864, 50.62340382606753, 52.85618166769705, 53.376491915795114, 54.72184919541883, 56.419184284825484, 58.36290697897635, 54.10993591431649, 54.11978498581917, 55.60858334264448, 57.04313531998665, 52.76963064747473, 48.75319419368621, 45.75687600720314, 45.15981281957319, 43.48711805958902, 48.552302160570704, 53.454221525499904, 56.60514385469499, 50.22431835051506, 53.54434974731938, 51.09315864501461, 55.264807208891845, 54.49999993847263, 56.86241211429719, 56.45242244966569, 57.61994731041693, 57.56103723279892, 55.47319489140665, 47.20496800638015, 38.167125025103175, 34.86926678688296, 29.595691081016298, 19.358299047716205, 18.123831095234042, 17.425682544708252, 13.12703645998432, 9.978320464011162, 14.89200007530951, 11.615805087550996, 4.534964474939532, 4.3592854372916685, 0.9686681700329628, 0.15902793275252466, 0.8369860521727993, 5.807411266911415, 15.47698824636398, 31.256938403652562, 40.3200630218752, 32.724228443637976, 27.609204746061756, 43.88886290211832, 57.930030284389375, 44.70893244589529, 18.099539856756888, 1.259247280897633, 0.04960904626416103, 0.026229199607886618, 0.018702270838642315, 0.08314945960357305, 0.04897543792462638, 0.016444988939310276, 0.033382384722391446, 0.02849348355084658, 0.027487579462749344, 0.055214932954479615, 0.061092520388023513, 0.028823516143846418, 0.053355756305879166, 0.0017069091324716987, 0.03292812905724972, 0.011875669963868156, 0.029470473565461657, 0.08528219475861519, 0.023541851269622004, 0.041199898302194574, 0.04614496137946845, 0.074031327911202, 0.03560406268544255, 0.04606892332254399, 0.02150943532826439, 0.20290525089348518, 0.40377169667232427, 0.06522721565899349, 0.1686755537746414, 0.1598599808470857, 0.08155741398372958, 0.17964046298255845, 0.19695080185849823, 0.18149071853728066, 0.14345198629363892, 0.14399045417385717, 0.1458876402748208, 0.08806698565040866, 0.15872469983033596, 0.37180079447646297, 0.12020612075444191, 0.08348859906677278, 0.15088346816839712, 0.1558204605093887, 0.12059389147907497, 0.14567973933392955, 0.22327906812631318, 0.27759189807599594, 0.12675978844204258, 0.11457568860702938, 0.4465846122512895, 9.18633509066797, 27.503632191688787, 57.92271114164784, 56.78653386331374, 46.55336818387432, 40.382899392035704, 39.62155165210847, 48.10053925360403, 26.635894083207656, 12.029939716862096, 3.451563422718356, 0.29596507669456545, 0.6131926479358828, 1.782445619183202, 8.77205043069778, 11.233368112194924, 21.35938052208193, 15.33560739409539, 23.682574879738596, 22.941284179687504, 15.17059131976097, 15.604427033855071, 26.369504351769727, 34.08538503031577, 47.626112891781716, 54.36107743170954, 58.90118560483379, 58.085630709125155, 62.236737820409964, 58.31447747445876, 58.89981277527348, 58.2637494610202, 53.769564397873424, 49.07629551426057, 43.39993946013912, 43.09289240068005, 50.21729338553644, 55.570775616553526, 56.8311272898028, 57.76711071691206, 53.40210107065017, 44.29405943039925, 41.714159673260106, 48.122390777834006, 57.5988410365197, 56.77641022589899, 55.48911971430625, 56.71624498982584, 51.84083300252115, 52.84002542495728, 51.0115929572813, 50.685298827386674, 47.24822782701062, 41.43411813243743, 41.45074505959788, 41.19925837362967, 42.93456200630435, 46.787855317515714, 52.89269893400131, 52.15286539446924, 58.07676223016555, 55.595145302434126, 48.40968085873512, 59.86592000530612, 53.745175100141964, 51.42570895533408, 43.0226819745956, 44.728701191563765, 46.31304456341652, 52.55115855124689, 53.450973802997225, 55.453751702462476, 57.89431710397044, 56.91314012773576, 57.982189962940836, 60.54842418239963, 55.27205182660011, 52.474154580023985, 54.86489803560319, 58.92127598485639, 56.50493906390283, 52.576540208631954, 49.07533061119818, 49.38980271739345, 47.135965670308764, 50.76064755839687, 55.97418746640606, 58.56956097387499, 50.611573957627826, 54.381481601345925, 50.70808387571766, 55.5256252135, 55.51892580524568, 60.04851810393795, 57.441177445073286, 62.06065085626418, 57.97708303697648, 60.00563483084402, 48.49188981517669, 45.47193150366507, 45.689191587509654, 34.71489798638129, 28.38969365242989, 28.551350216711725, 21.60861968994141, 28.33846945916453, 19.428533008021695, 27.61703968048096, 23.629105129549583, 13.703730779309428, 7.509231586610118, 0.8656118161255314, 0.7587656559002015, 1.0476447257303423, 7.285273075103761, 17.693031295653313, 35.273569014764604, 45.72699146886026, 39.096542404543975, 33.12527118190643, 53.3722714454897, 63.76433234060965, 53.40430936505718, 22.58931225345981, 2.008443763179164, 0.2588998736633409, 0.161754317100971, 0.13822225643502128, 0.20206555724143985, 0.1805776796273647, 0.08160436751260873, 0.23081896676411554, 0.13727612252677643, 0.22113051325563463, 0.12198411889614598, 0.16770898064057674, 0.1175106097493441, 0.16779435347885857, 0.20426194664211045, 0.12582823318699676, 0.19744877433103902, 0.14353617935651733, 0.24503827876140996, 0.17571539618074897, 0.22892312897789865, 0.11967837044428434, 0.10341309041025178, 0.15805870895424198, 0.1343036554152927, 0.18769523399251123], [0.04209040656625744, 0.02111100257494517, 0.03699554648670939, 0.08858800970859106, 0.030291796429082755, 0.05332387938734986, 0.037445672937939246, 0.028823565939561497, 0.019257247913628817, 0.05146831484331239, 0.020559254560559508, 0.0355512026186672, 0.040489290465390494, 0.04218921275629152, 0.021245826388739293, 0.02153597644440109, 0.013902383338239406, 0.042986760081182566, 0.04211227071561641, 0.02724158096938364, 0.0301903989466448, 0.016915964473399426, 0.025049108193225922, 0.005610873922705651, 0.008017955218336635, 0.0035776133694115186, 3.698341548442841, 18.772218496568744, 39.98626932021111, 42.21779984812583, 37.21840958441458, 18.679032787199944, 18.68823858999437, 24.561383878031087, 20.450410458349413, 9.25239662970266, 1.9360035922258132, 0.21500262191459057, 0.10118421888159168, 0.7899780391204743, 3.214379659583492, 5.672743060896474, 5.987528956705525, 12.218560614893514, 5.405539437647789, 17.329415813569103, 32.636526207770075, 18.855209965859693, 18.960070610046387, 31.577684340938447, 40.90660249033282, 50.217254161834724, 53.42627856039232, 55.26756463512298, 58.51828775098247, 54.89237031629009, 53.29301211141771, 52.77091326252107, 51.01544864716069, 48.75097020979851, 45.10885338629446, 42.48123015126875, 40.36160092200003, 40.37401130122524, 42.52221891956945, 44.362959784846154, 43.40459139116349, 40.03151386014877, 42.267864981005275, 47.874320476285874, 54.18099749472834, 54.717044291957734, 54.70241777358517, 51.324080344169374, 47.45254016691639, 45.40109742072321, 40.00275111967518, 38.48126372983379, 38.462397129304954, 36.767101672387895, 36.67711073352445, 38.29590428260065, 41.32995959251158, 43.375028487174745, 51.49515844160511, 50.7025101877028, 59.511008262634284, 49.02622645901096, 42.3599269313197, 57.51863641123618, 48.49711833461639, 46.685693264007575, 37.62503385543823, 40.32340095889184, 37.56197391017791, 43.522415468769694, 44.240526922287486, 48.47530995645831, 47.31386869184433, 50.033216553349654, 51.78873608189245, 55.28873758931314, 55.20669729478898, 53.61774513798376, 52.722730867324344, 57.4303085573258, 52.499614684812485, 55.81587668388121, 53.973033428192146, 52.34109993903868, 46.2024768706291, 49.38852402471727, 52.237345403240575, 53.810251143670854, 52.06775780647032, 52.7259668227165, 53.562329892189275, 55.82290557123, 53.56561683839368, 50.537817708907596, 54.00384756826586, 52.51242514579527, 54.08415417517386, 55.74044950546757, 51.911337606368534, 37.01825495689146, 36.826341229100386, 35.40574896720148, 26.592685253389423, 20.63469909852551, 25.910367388879102, 9.655580001492655, 3.4055280348946972, 10.401510865457597, 8.004160667619399, 5.446608124240752, 1.241025665114003, 0.9127798496234802, 0.1446485390225726, 0.8148413307724461, 3.584152037097562, 17.031860889927035, 28.516566638023626, 30.96590638160706, 32.41817570501758, 39.55463209459859, 44.52082733954153, 51.59736756355532, 38.15148653522615, 12.054930117822463, 0.9564256559937232, 0.16352163597701058, 0.046380138880903685, 0.024068437126134674, 0.023545325478358616, 0.051805673152088165, 0.0227093052179102, 0.05403513456844995, 0.14682807448890903, 0.05949519259194213, 0.048361935562664465, 0.035375404592242934, 0.0279415535905789, 0.01369856277315487, 0.02406197134405375, 0.051026868168264634, 0.028421771975474495, 0.034644204312034195, 0.05723519491091852, 0.03622503823510582, 0.044481830461130994, 0.06655414889176046, 0.029733278112666264, 0.029625177360890858, 0.04437483479118636, 0.10491410946293224, 0.028513712102487206, 0.033266640328351534, 0.02194216583795365, 0.050633968484978524, 0.10499831018668991, 0.029430610180321722, 0.04449982586647234, 0.13570073931928606, 0.02065922520423849, 0.06107273616737897, 0.03391141056894295, 0.002905995577513691, 0.031793734787272356, 0.07676099111596424, 0.03998991222150865, 0.021875857097667553, 0.05942203119517334, 0.10248079971079865, 0.05074901956944697, 0.020459038768744758, 0.009384503336473098, 0.020582407652851076, 0.046127582674906145, 0.01847582482432406, 0.0266652281260899, 0.08403292751961178, 4.477920955227268, 22.964308492598995, 47.38536957771548, 47.58677151895339, 41.11859875340616, 23.583136912315126, 24.72305024823835, 34.74837933817218, 21.323706565364716, 10.136040929825077, 2.104373170483497, 0.2569373249406776, 0.12092192266737262, 0.7145931487602573, 3.049693064343545, 7.617345836854751, 10.841040880449357, 12.024265027815296, 12.131135886715306, 12.35312831017279, 19.13704206866603, 17.987230631612963, 22.602289415174916, 29.31985235983326, 44.968616885523645, 53.1400945878798, 56.11871111777521, 57.20936929025958, 60.18957045770461, 54.98087075448806, 54.2303369891259, 55.448209393408995, 54.24629319098688, 50.42734415300431, 48.21795932708248, 42.702781308081846, 41.58553731056952, 41.40970922285511, 46.15332172762963, 45.802081323439076, 45.10768059761294, 40.399581232378566, 42.941630117354855, 49.0624064014804, 55.43595590899068, 55.32760043298045, 56.55347447241507, 53.201915064165675, 49.69058182931716, 48.3734263912324, 42.20059633255005, 42.26862199844853, 41.20130192848944, 39.571251177018695, 38.3469186290618, 40.18890288568313, 42.55141704313217, 47.76876557257868, 52.881222078877116, 53.59414815902711, 60.206432727075395, 50.08989872470979, 46.273279574609575, 58.255445803365404, 50.47098836591167, 48.365228637572265, 40.00380231488136, 40.97457324304889, 39.76300801000288, 45.85307998041953, 47.27009504072128, 51.045352797354425, 48.969783552231334, 52.56420827681019, 53.19160315298265, 55.59517275902533, 56.502832751120295, 53.815416905187796, 52.70605294935165, 57.09614223049533, 55.22476373180267, 56.78477664147654, 55.12228788868074, 54.00713451447026, 47.42480508742794, 51.14055264380671, 54.84976160910822, 54.62963427266767, 51.84330409572971, 52.45428385273103, 52.39582877005301, 57.92873197986234, 55.66425354250016, 55.16141745351977, 53.66002044370098, 55.5708226849956, 56.22022598020492, 58.477479411709695, 51.668201646497174, 44.159396617643296, 34.153496988358036, 24.07116017033977, 14.700020647818043, 16.162378307311766, 17.440883690311065, 18.431695968874042, 9.921315677704351, 12.90153253463007, 12.180318486305977, 6.800551472171661, 3.0950783193111424, 0.8506799657498637, 0.14519030108086525, 0.6103242308862749, 4.427536149178782, 17.049048716022124, 29.0160765570979, 35.02990745729016, 35.763912354746175, 36.975104962625814, 49.14807881078413, 56.92865310176727, 44.038058096362704, 15.138360223462506, 1.2237966541321048, 0.11026479694391451, 0.007199715858610768, 0.06014126518200483, 0.044629095542815425, 0.023183191886111613, 0.03411915063137009, 0.035469032027908874, 0.04892541621361048, 0.052896647473737124, 0.013714418877967665, 0.0183646539751921, 0.06507474117942395, 0.016561547301769737, 0.026266362533093463, 0.0472908795270468, 0.10075022241160755, 0.016226935418202512, 0.02937326849918933, 0.05363695653936556, 0.03714745023077534, 0.043991526528712244, 0.01925364921560451, 0.041319971093006676, 0.0596981063004463, 0.09093740218949896, 0.19086391154316165, 0.19305262474283097, 0.0922298078395186, 0.17846318502579966, 0.23883357944507755, 0.14060480520129204, 0.14431699149070248, 0.3240836597979069, 0.13353179118806316, 0.08941601285891188, 0.14378400880002207, 0.0837758896992572, 0.10229670112171482, 0.10909694186862438, 0.15994723826166124, 0.10648386192417915, 0.09218401876428435, 0.18830490208441214, 0.1955351633049788, 0.09685003814557869, 0.1527607819486049, 0.15861481217847717, 0.1285215608415104, 0.11868011957455067, 0.11315218999140686, 0.33468435548486253, 6.511354629070529, 29.76240161926516, 53.96459640995149, 55.05541147724275, 49.45398446052305, 28.847038092151767, 28.432841685510454, 35.381210619403475, 28.942991033677135, 13.060115921881891, 3.2872923535685388, 0.5076179791602397, 0.2723213050874972, 1.8924711668683638, 4.314408129261387, 14.977850952456075, 14.038155982571265, 22.94584393501282, 16.519081592559814, 30.51983875613059, 43.87964925458355, 24.846895164059056, 19.64906434858999, 33.75680808098086, 45.6818881342488, 56.51815352901336, 58.6779046827747, 58.715947751075994, 59.45750321111372, 56.49236002276021, 53.916912155766646, 56.68586231047108, 55.77827292103922, 52.29718508258943, 51.062324893090036, 46.817802613781346, 44.73771479821975, 43.358503541638775, 47.199006003718225, 47.497180661847516, 48.04436699036629, 42.98202268538937, 46.55505872541859, 52.62910389131116, 58.154197662107414, 54.06106710433961, 58.301388525193744, 57.293186418471805, 52.390164867524184, 50.26797433053294, 44.91194255890385, 42.228033311905406, 42.19675633215135, 40.64131298372823, 39.88245202649025, 41.87291368361443, 45.323395267609634, 49.19540220691312, 55.14528082263086, 57.11193369280908, 63.96637755055582, 50.785578143212106, 51.04421923237463, 60.82769301629836, 53.45136211764429, 50.04430117145662, 42.34872464210757, 43.747139823052194, 40.550910195996686, 48.24114053480087, 50.60078351728378, 54.1746275655685, 51.78472349720617, 55.12289193368728, 56.97877707019929, 59.233669234860336, 58.92965024517429, 55.70826645820372, 53.566715102041925, 58.480346664305664, 58.45416484340545, 59.98950604469546, 57.321784419398156, 55.966487853757805, 51.370093668660815, 53.7804489751016, 55.91464196482013, 55.18009578028033, 52.77933066891086, 51.83821285924604, 53.38438372458182, 58.85911033999536, 56.106669441346206, 55.36381175441127, 57.23282506389003, 56.90069052480883, 59.245761902101584, 62.26378648511825, 56.267325801234094, 45.29423244537846, 39.28260395603795, 42.68429125508955, 35.53048033868113, 26.94826379899056, 37.32338789970645, 20.91888854580541, 9.1804652637051, 24.19223197044865, 19.730175041383315, 15.80539849496657, 4.049366222273919, 2.248004972934723, 0.4984986830142237, 1.1092432203792757, 4.893984410070605, 21.615879997130364, 37.646242110959946, 44.404407470457016, 43.89313436323597, 51.289649778796786, 57.77687741864113, 65.1092307029232, 52.90986714824554, 17.80932172652214, 2.083602014087862, 0.30926396469435385, 0.08106097368703735, 0.12643472967489114, 0.2024668800614534, 0.22849416570557704, 0.18458283326077848, 0.2348008160028727, 0.270411417248749, 0.20870586947327663, 0.07489940512084192, 0.08350798109125707, 0.15279787592589855, 0.14795875897811306, 0.10120520969071697, 0.18667204696084225, 0.18463664327657994, 0.11442818603808842, 0.15561493444106272, 0.17621925220854823, 0.09844058989396981, 0.11885621254482578, 0.10444425241721254, 0.09845252554383009, 0.17238701994140304, 0.2049498935981143], [0.025966454432496143, 0.025245793606905688, 0.05022770822829297, 0.07718364182378977, 0.031493096987927155, 0.027795824515182647, 0.05957073652215543, 0.0443516836141146, 0.02439679198658034, 0.06444516246237102, 0.05478937111254181, 0.14326320690733774, 0.054131416498773524, 0.03626178364239393, 0.0720828369019493, 0.008892219066770088, 0.05179219766550007, 0.08689723067706631, 0.031501571835589506, 0.02950970492806406, 0.021472540533831044, 0.03275788516827649, 0.05986854937227984, 0.06731885785777723, 0.03257480164569232, 0.09055418968801537, 2.9806853350131743, 18.263787146537535, 39.23341351170694, 48.81683464973204, 36.48956652610533, 24.07814787280175, 21.851453627309493, 22.847961187362674, 18.90698132976409, 8.930248445080174, 1.8030962852701065, 0.26963592176475837, 0.04557492684633021, 1.0015598179832583, 2.1713907872476885, 6.8047807678099606, 12.42283667287519, 12.425884354499079, 11.247015999209497, 7.6613121744125126, 11.817987580453197, 16.493813683909757, 26.260336945133826, 29.509649968916374, 41.83608262769638, 47.1769073701674, 52.272933067814, 55.25418543046521, 54.65522381567187, 56.29879497712659, 54.947181517078036, 53.81956677283011, 52.54672627295218, 46.874104315234774, 50.16672618927495, 50.295893761419485, 48.29380619910456, 43.51231928794615, 46.59451776935209, 42.82084857263873, 44.84229695412421, 44.334467687914454, 49.04507737005911, 52.06794608023859, 55.28168516774332, 52.25370953159948, 53.86798451023718, 48.618978531129905, 47.169227369370006, 42.069777442562966, 39.558805496461936, 38.0415895677382, 38.47528211532101, 36.63091305763491, 38.823949444678526, 40.04172378970731, 43.320542843111106, 49.14827492929275, 52.948777060354914, 51.25699604711225, 54.898034218818914, 48.929704773810606, 40.66033255669379, 56.556208364425174, 48.77130769914197, 47.491457923766106, 38.40144741919733, 40.193225337613015, 38.11183137278403, 39.59752321243286, 39.41134398983371, 42.62640491608651, 44.258483532936346, 48.96724185635967, 48.21011850910802, 51.09267619348342, 52.41033369495023, 55.25209088479319, 53.52067824332945, 51.10613776791481, 55.284470050565666, 54.20949743640039, 52.3733300547446, 53.19215620717695, 50.7930737926114, 52.565435978674124, 53.772808198005926, 53.473260710316325, 51.352996057079686, 52.09395923922139, 54.73917038209977, 53.38639590048021, 49.1930527071799, 49.971207803295506, 47.57810308087257, 51.23226942554597, 52.10476144667595, 55.040867328643806, 51.945995669211115, 45.67620069749894, 35.44647493670064, 32.89218433441655, 18.790624218602336, 17.446514252693422, 10.19193176300295, 12.89195312607673, 14.2632156995035, 9.395597461731205, 9.273596059891487, 4.728650623752225, 4.517688885811837, 0.9671256979626994, 0.06247950342273521, 0.5397973798455731, 5.107517261658946, 14.560692175742119, 33.62745223506805, 34.64006700823384, 35.59177521736392, 43.14366356019051, 51.14835423807944, 53.893774094120154, 32.68982141248642, 11.981505309381793, 1.6295790864575295, 0.05396951913773533, 0.07546181324869394, 0.02235304943526224, 0.023413064228671215, 0.06729207542394439, 0.03626636867862075, 0.06911331156809485, 0.006671161156132698, 0.05112942052824844, 0.03341093298888976, 0.10182819239074185, 0.026424624806930943, 0.03205198877220673, 0.038981292351719835, 0.03299741404912165, 0.06299972308859711, 0.06609707019261776, 0.049074519906313195, 0.06470390865879674, 0.050825823714295705, 0.03721631770472854, 0.04044219521024535, 0.03225556131632578, 0.052912310141349034, 0.03864767638245418, 0.015323235120083538, 0.0103660257187702, 0.06901001227238486, 0.033770783639122406, 0.027032984803701123, 0.06274680682127515, 0.010087007878258104, 0.03400909827060757, 0.029988638200466673, 0.015222673631092955, 0.03280142194501335, 0.06755096717707573, 0.02229959181990595, 0.045208575940060045, 0.047480582049296755, 0.009600168578476917, 0.03360925016984825, 0.07617216061560378, 0.03348301037124569, 0.09510672080420679, 0.024806216186393174, 0.04144767028910499, 0.11179072917589258, 0.015622512155753231, 0.04182619050205235, 0.10559199002361107, 4.342590849245749, 23.087219884318692, 45.612866186326556, 52.3525454152015, 40.99815845489502, 24.033956489255353, 21.65521352521835, 28.433237844897857, 25.244745093007243, 11.286140661085806, 2.144050641405967, 0.19571775270085182, 0.12229941004226286, 1.1907613493742482, 4.269643099077286, 5.462449596774194, 12.919935314886033, 11.662373427421818, 12.461031733020661, 10.470169994138903, 22.631773871760217, 18.515460145088937, 23.28092613527852, 30.4436682885693, 44.37253821280695, 52.77517295652821, 54.05848226239605, 56.70611350767074, 53.8150913484635, 55.77996738495366, 55.14333924939556, 54.425353311723285, 53.69410976286858, 50.94679147966447, 51.18169046217396, 52.162357530286236, 49.803338204660726, 46.175687082352184, 45.634372541981364, 44.16824548475204, 46.9369367630251, 45.69959763557681, 50.182419592334384, 54.858861507907996, 55.47945107183149, 52.98860872945478, 55.778096414381466, 51.97462112672868, 49.604627009361025, 42.80807733535767, 40.82309522936421, 40.662160381194084, 40.08409323230867, 39.80542059867613, 39.6826700241335, 42.49333458562052, 44.496296836483864, 50.71159047465171, 54.491386413574226, 54.474704573231364, 56.07434911112632, 49.513345610710886, 43.067993194826194, 58.739262319380245, 50.45681292010892, 49.179316566836455, 40.24809145158337, 42.7615148790421, 40.17528049407467, 41.09419376619401, 42.13891313922021, 45.17742426164689, 47.44446792910176, 50.657983441506666, 50.946477690050685, 53.34993746972854, 54.62043239224342, 57.345314718061886, 53.583953918949256, 51.661812105486476, 54.711011686632716, 54.234180911894775, 54.944792793643096, 55.12628086151616, 52.22612350217758, 56.08515131858088, 54.68173903803672, 52.187817635074744, 51.38108807225382, 52.97633171081544, 54.69186267545147, 56.28978921521095, 51.64758174650131, 53.341367090902025, 49.881283544724994, 54.61748276987384, 54.700405597686775, 58.90601404251591, 54.3312870302508, 47.57572220217797, 35.52904082882789, 26.31997266123372, 16.79744043657857, 19.220992557464108, 13.62685134333949, 13.365973522586208, 18.418732535454538, 12.71570142238371, 11.018744841698679, 5.274669066552193, 4.349357918385537, 0.593445168868188, 0.1905810718815173, 0.7596367285136254, 4.899105064330563, 17.17848889289364, 39.19326413062311, 39.9495167116965, 39.151777221310525, 48.015816057882006, 56.68985136093632, 61.70672755087576, 39.596715204177364, 15.028632898484508, 1.7718080287018132, 0.12632383844785153, 0.050047202591574004, 0.06136961822067538, 0.1111962219640132, 0.036341242281900304, 0.020564622921688903, 0.03929826123039088, 0.02999517867612022, 0.04809706066284449, 0.024836530285556952, 0.023548330458241607, 0.06796968785384971, 0.07288236456412463, 0.04386245986566909, 0.04915326225361036, 0.03741564229130745, 0.1488700205640447, 0.029783273010604808, 0.031998670967896624, 0.02343142544099641, 0.06738513212410674, 0.02305613811908951, 0.03091918988033168, 0.08456287650211204, 0.039789201015786785, 0.12623451259588042, 0.08067134902962754, 0.13961207782549245, 0.1229469228776232, 0.12956173970333992, 0.18464620405387494, 0.17492048802875704, 0.1688327243731868, 0.2371835333084868, 0.1572110633095426, 0.13241206175617634, 0.2842038497328758, 0.11816936109455363, 0.08298147950441608, 0.18943975409192426, 0.1989195865368651, 0.10642916324638552, 0.23927935068645786, 0.16645881707870192, 0.12340557205701068, 0.16283056338227567, 0.140253507922734, 0.29128431012072875, 0.12130940993947369, 0.2124806145025838, 0.36383792337390686, 5.965986809422893, 28.471145591428204, 51.87114507921281, 61.050789586959354, 47.57759709512034, 33.52458415492889, 32.27951207468587, 35.15704324168544, 27.71896835296385, 13.592472749371684, 2.9696495013852275, 0.477520315156829, 0.2103141178527186, 2.020087196461616, 5.864684245278759, 12.632080412680104, 23.467742743030673, 23.19366712724009, 22.147882830712106, 18.522083067124893, 21.519342622449322, 21.758314986382764, 30.934749034143266, 32.15207034541715, 46.28052419231784, 52.00976164110246, 56.809079647064216, 56.56295876349173, 55.923965438719726, 56.87366931669174, 56.65810761913177, 53.91048339105422, 56.42848422450405, 52.380123599883056, 53.81160828375048, 54.61539606894217, 52.456539215580115, 49.460507362119614, 50.60706323192966, 47.82372582343317, 49.46753624946841, 48.219414526416415, 54.51345759053385, 57.27021309637255, 56.28335652812835, 52.87667212947723, 57.459436078225416, 54.16489224280081, 52.4598849973371, 45.802293131428385, 43.44141067997102, 43.32714419211111, 41.57856725877331, 41.96967855576546, 42.00515247160389, 44.31427924863754, 48.622653791981364, 53.468291067308, 56.743117147876376, 56.02429182298722, 57.662230460874504, 51.409454653340006, 47.02730424942509, 59.49500891470141, 53.080419648078184, 51.62825230629214, 42.443563630503995, 43.623428267817346, 41.13637101265692, 44.13328539940619, 44.421932620386926, 46.563840912234404, 50.19811691776399, 53.91129532167989, 53.12736649667063, 56.648933195298724, 57.25619454537669, 60.533538787595695, 54.67367464496244, 51.5310481286818, 54.53370094299317, 55.26663111102197, 54.84166583707256, 57.04871685274186, 54.612921053363436, 57.39616824734596, 56.53174454166044, 53.966992978126775, 51.620435022538715, 53.38996525733702, 55.80021858215333, 58.72965643482824, 53.3959194152586, 55.532461904710345, 52.08863266052739, 56.17227108247819, 57.689381107207275, 60.08946372616676, 58.069066539887466, 49.942362693048295, 40.11326782165035, 36.51202209534184, 22.098857125928326, 22.650054077948294, 16.7604564082238, 24.364735849442024, 29.365940209357973, 18.978341010309038, 19.991269573088616, 7.954677516414274, 9.434129845711494, 2.375794322259965, 0.3873159748411948, 1.0866151894292524, 6.3322915665565, 18.938678003126576, 43.96694944750878, 46.97949055702456, 48.19970069393035, 53.67372912745322, 62.046667606599875, 69.4876980012463, 49.009721125325854, 19.11876186247795, 2.837372470286585, 0.2871736048931076, 0.2485623291783756, 0.16733609500431246, 0.2952411848931544, 0.08460705679270529, 0.16153892382018029, 0.19932294715075724, 0.13922469780570076, 0.14881179788179938, 0.09367867162631405, 0.22933623423018765, 0.12142068421047543, 0.19557360559701922, 0.12095284197599658, 0.13831576512705895, 0.10567746245332303, 0.14290944282566348, 0.1858190387006729, 0.17880584083257184, 0.1324320106857246, 0.2793554018341726, 0.13396620900640566, 0.12376181060268034, 0.16307250927052191, 0.20222609862685206], [0.03668637638310752, 0.024992584310952696, 0.022893436365730824, 0.054342561822024085, 0.025629573013453234, 0.024697895184339538, 0.07078840111893031, 0.015573527536264833, 0.020551836914232662, 0.022239076619547223, 0.03514236830655606, 0.06532060943784253, 0.08980845671988304, 0.057047216086498195, 0.020350338553168604, 0.02328473301003537, 0.03745963872079888, 0.03237143977575245, 0.02247448969301918, 0.029825555318365657, 0.046171107960324136, 0.07540957371313727, 0.11548840576001715, 0.07296310257046454, 0.06978854146455565, 0.13320739891740585, 2.0165524054919524, 15.208856001976999, 42.068318320858864, 42.6873154024924, 36.145288328970636, 27.151150357338693, 17.556271976040257, 26.40071857360102, 22.07022970722568, 11.354699769327718, 2.3472387319610966, 0.22680858841105817, 0.05189715937200574, 0.7551231836119007, 6.0093726361951525, 4.172150136963014, 8.902686930471852, 7.249784450377188, 9.096572629867062, 6.084859630753917, 23.31707665997167, 16.668953395658924, 20.860319714392386, 21.95516109466553, 37.01521904237809, 45.95480272846837, 53.26697541821388, 54.68303342019358, 54.933186500303215, 54.174549118165054, 53.641804956620746, 53.218906771752145, 50.396745743290076, 52.09036242577338, 54.173262580748535, 52.761487806996996, 51.96459554856824, 54.39950489228772, 52.39705254954677, 52.432455862722094, 52.88902367314985, 54.26445768725488, 53.9565477063579, 53.595062071277255, 54.31892764183783, 57.38813523323306, 54.7484036414854, 48.16408165039555, 45.86391748920564, 38.537345778557565, 36.74088847252631, 39.386283966802786, 36.264634286203695, 37.288710225013, 37.36680461514381, 37.83551216125488, 42.3905174962936, 47.76478436685378, 53.55241021802349, 52.085855622445386, 56.11323548901466, 49.160508801860196, 41.062202915068596, 55.06646863875851, 48.07332192697833, 48.53425925777805, 39.79163346752044, 39.95251340250815, 37.896497172694055, 38.80960925932854, 38.64916078505978, 38.36877799803211, 38.473399377638295, 42.3292383070915, 45.82897309334048, 48.42533111572266, 47.67422860668552, 53.302002183852665, 53.09366941452027, 53.211701377745605, 51.71608594156081, 54.575572244582645, 53.501693971695445, 54.981000192703746, 53.03768150268063, 53.33442057332685, 52.71490966120074, 52.72865756865471, 51.854200440068404, 55.3920018288397, 52.870349268759455, 50.13630428621846, 47.37977627784976, 46.85015432296261, 45.52883332775485, 48.22605902148832, 49.9276263483109, 54.58697065230339, 52.90037501242853, 54.55643107814174, 36.33977120922458, 22.562394988152292, 13.213455100213329, 20.659751276816092, 22.45734803138241, 14.791863925995367, 10.406055911894768, 10.2417125240449, 9.30262356035171, 3.821498578594577, 2.8377975571540097, 0.10016759722343377, 0.1648693378534048, 0.7502307622663437, 3.7357521345538482, 14.894106388092043, 27.430095595698205, 33.94982399479036, 37.88003498508085, 39.53291393095447, 49.04079021946077, 50.891799849848596, 35.14273443529683, 10.494505359280495, 1.0382455010567944, 0.18515539205362722, 0.03225492546334863, 0.0600265741588608, 0.07281121797859669, 0.07651388179510832, 0.033033435503321315, 0.01482547140650211, 0.036494425392799804, 0.05338077673748617, 0.03247206925504631, 0.04840242713990231, 0.09666328889227684, 0.07862404799990116, 0.079106530174613, 0.02622831669155388, 0.008270352939894844, 0.030728637000485778, 0.028571911802094792, 0.010736728962060186, 0.01838437882402251, 0.03327227873547423, 0.015037261201218973, 0.04299818245213359, 0.06403622855882972, 0.06845769352249562, 0.01355736606544064, 0.0481149947811519, 0.034202255849396034, 0.07100606968085613, 0.12324804139714088, 0.03389078748202132, 0.05236713899179332, 0.044283612871602665, 0.05986947633866822, 0.10752820064343753, 0.04390899587662951, 0.030508995762154944, 0.03119275987809224, 0.023707565663742925, 0.01701900904487458, 0.011428720862304252, 0.01721425038281708, 0.01056332879083892, 0.07925872886252981, 0.0413939981691299, 0.005474195697329818, 0.0236359900689774, 0.05506100673829356, 0.05943435754987502, 0.031725943666852774, 0.11720435844073374, 2.634435901718755, 18.717491626739502, 47.293033061488984, 49.69551224862376, 39.95219176815402, 30.120439490964337, 23.11631798744202, 30.05534971913984, 24.89199261511526, 14.099787204496323, 2.8083606593070494, 0.17616162707488384, 0.0159252748914784, 0.5975765278262477, 2.7017511283197715, 3.59840642060003, 8.737626729472991, 11.812979694335692, 12.525390963400564, 12.048121863795865, 16.099178137317782, 11.741070881966623, 19.672516199850268, 28.49263429641724, 41.015154084851666, 50.27227717061197, 55.18232760890838, 54.7862623583886, 54.744442047611365, 55.43451247676727, 52.987785031718595, 54.674235543897076, 52.99239773904124, 52.7993308344195, 55.577412266885084, 53.05750123916134, 52.68608024043422, 55.89891326042914, 54.262119954632176, 55.115282535552986, 54.96803675928424, 55.59419608885243, 55.644461262610655, 55.01542683570616, 53.99171175495271, 57.1567310825471, 56.314355019600164, 51.122819608257664, 47.08585739135743, 41.319537854963734, 37.6387111602291, 40.89540020112069, 37.56270739340013, 39.569219389269435, 38.22527024053758, 39.06221774316604, 45.35112642472791, 50.03591514402821, 56.213852128674915, 53.407651224443995, 56.23679407181279, 49.89119145178026, 44.19798489539854, 56.962636516940215, 50.41352172051707, 50.57191879518571, 41.76089471386325, 40.85349752056984, 39.608584296318796, 41.08963989442395, 39.92193852701495, 40.51596187776135, 41.30331493193104, 44.41321319149387, 48.6452191875827, 51.333917648561545, 50.72873907704508, 55.19394959172895, 55.895265456168886, 54.667908760809134, 51.65796033797726, 52.9580024750002, 54.21174103213895, 54.751290505932225, 54.23677752094885, 54.46203139520461, 53.13789021584296, 51.69410890148532, 51.96503093165737, 56.123449340943374, 53.68219752465525, 52.35600102332331, 47.88705248986521, 49.935180833262784, 48.44084408975417, 50.38354304529006, 52.71639231712588, 56.9267782088249, 54.89107201176306, 51.868069940997714, 39.422730630443944, 25.15410500188028, 18.96417929280189, 14.809190996231573, 11.353725060339897, 13.148451620532622, 13.610597041345413, 13.516854355412146, 9.279010891914368, 8.46461505659165, 3.327033808154445, 0.8382579419882068, 0.12478715034141658, 0.7224551720484611, 4.343656263043804, 16.763619799767774, 31.289327375350464, 39.57135315864317, 43.08150576006982, 46.3073375148158, 53.397915901676306, 57.36240840727284, 40.96026835903045, 14.048489466790231, 1.736487453022311, 0.1334344367346456, 0.026201559155578577, 0.05093494527823022, 0.057932970774990905, 0.08064337915951207, 0.05180944230467562, 0.02950719024445261, 0.01781985054784004, 0.0513723163655208, 0.11199937322207036, 0.010042449331752235, 0.016916447108791723, 0.034704951253990014, 0.022720773554136677, 0.05380630410546738, 0.043705791054714116, 0.09812928240505919, 0.08763392380769215, 0.0378072970817166, 0.03236990376946426, 0.08946319621416832, 0.016465016392870777, 0.07860993666033592, 0.08661680419238345, 0.04033053023440223, 0.09731283952151576, 0.13707666387481077, 0.13203226600683507, 0.25502440339374927, 0.14606082211098365, 0.17621355251439158, 0.19054678178602652, 0.15841710020697888, 0.19265925391547142, 0.17924888480094173, 0.11901144494092274, 0.13880926364612195, 0.19558515820291736, 0.08056326934527006, 0.10279247492191293, 0.12594667038009053, 0.08623584398939725, 0.07289851369756846, 0.15255200766747998, 0.12467291897102711, 0.20473880573145806, 0.11954919269849217, 0.22459814895785626, 0.13121138747421005, 0.16315104860451915, 0.25355924491680437, 4.417008017340015, 23.695167649176813, 56.028426001148844, 56.678029337236964, 47.94207549864247, 37.40033695774694, 27.39166029037968, 37.44950386785692, 32.7811538019488, 16.046318315690566, 3.1772578579764215, 0.4578161353786146, 0.18062002896781892, 1.7467775460212462, 9.318010037945164, 9.260724802171032, 17.242951085490567, 14.484401095298029, 17.711739040190174, 16.628904035014493, 31.76977457538728, 25.498059603475756, 25.913762200263243, 24.223354016580892, 40.977193386324, 50.266707404967285, 55.472186842272365, 56.12652447915847, 55.22710146442537, 55.53437994372461, 53.74247258709323, 55.89464572168166, 52.539489499984256, 53.87745311183315, 56.1392721822185, 54.77935898688532, 55.15948372502481, 58.25097430136896, 56.10177432337115, 57.81561474646292, 57.8878059694844, 60.01151054136215, 57.496608380348455, 55.13092887017035, 53.87782181462934, 59.48272797369189, 59.53757839818155, 53.41709629181893, 49.96953295123193, 43.177886239943966, 40.319109885923325, 43.18835896830405, 39.702611354089555, 41.860797482152144, 40.27877223107123, 41.732022147024836, 47.8516334872092, 51.878672107573486, 59.43243534334245, 55.53332482614825, 58.20971881189654, 51.18897038121378, 48.111568958528586, 58.54414401515838, 53.21866358480146, 54.30277139909806, 43.25677687121976, 43.65839619790354, 42.628350411691976, 43.32039379304455, 41.76441307990782, 42.435346264992994, 42.126118367718114, 46.54386035857662, 50.10287392523981, 53.82170838694419, 52.438158988952644, 59.23111184950798, 57.28194098318777, 56.857309110703014, 52.12776222536641, 54.01004099076795, 54.1612522832809, 56.672039877983835, 57.391673211128484, 58.212119302442005, 52.46593329214281, 53.33677791780042, 51.24438954937843, 57.88668024924494, 55.89013891835367, 56.05346641232891, 51.14222357350012, 52.81199616770591, 49.74586763689595, 51.23771759771532, 54.56285984285417, 60.01600165520946, 56.946001745039425, 59.51849214492306, 41.31336012194234, 26.673811635663434, 16.510532786769254, 26.98217268913023, 33.086482863272394, 28.01939641275714, 19.481906660141487, 17.111316342507642, 19.733732631129605, 11.214536812997634, 6.528206111923342, 1.3646549731492998, 0.4398398209483393, 1.3461630815459837, 5.042153414218657, 18.746405378464733, 36.42784410907377, 48.13206726504911, 51.13922688268846, 52.25976174877536, 61.08720487163913, 64.8958969116211, 49.56764298100626, 19.330767931476718, 2.498943752819492, 0.36494985403072455, 0.1081025903864253, 0.21630333195770943, 0.17332959920167926, 0.21008689617437704, 0.09415376105255659, 0.12685359590837073, 0.12327295457643848, 0.14292939175521174, 0.2121100118083339, 0.14011507583481653, 0.2918303469496389, 0.11827457561007432, 0.1430510465175875, 0.21356177906836235, 0.12456067176836154, 0.21401052273088889, 0.14995294713204907, 0.18209534577063977, 0.1279114254359757, 0.10805860927869236, 0.09188264743575165, 0.1020331975192793, 0.16876512477474828, 0.20964123218530611], [0.027199984310315024, 0.09659663158198518, 0.01921609367033647, 0.03143840597101277, 0.08169056006496953, 0.008629848316852606, 0.03912595273446172, 0.02729437400346562, 0.028458490569685257, 0.02784456494414518, 0.020630115778335643, 0.04855348818725155, 0.023805025454250076, 0.07622149667792744, 0.03404031252308238, 0.07217130473544521, 0.027383519824774518, 0.1288985527090488, 0.035222654321020654, 0.025759018890018907, 0.014047383672497688, 0.022001893882970178, 0.03656371038467173, 0.039682730116070285, 0.029493502168465528, 0.05057085050089706, 2.8439171900672298, 15.456226160449368, 37.83260960732737, 45.79926898402553, 35.212897792939216, 30.63563692954279, 19.42063335449465, 27.737776117940104, 29.08070545042715, 13.595632218545484, 2.7687692353802347, 0.37561802674205075, 0.046354206804666793, 0.7951014512969602, 2.854166833623763, 2.982556795881641, 9.692495388369407, 13.4618519390783, 11.37828694235894, 8.429945226638548, 20.650061061305387, 11.825110604686122, 18.58716695539413, 31.511978756996896, 39.093224079378196, 49.597178428403794, 49.47218033575243, 55.64543401041339, 54.00934280887727, 55.191823667095555, 54.108390500468595, 55.988170716070364, 53.40859259328535, 55.347106379847375, 54.12976741790772, 54.258534908294685, 55.11892641744306, 54.56087512354697, 54.42298812250937, 54.450707512517134, 55.485060061177904, 56.9709833206669, 55.47053552442982, 53.91380563859017, 55.711600472850186, 55.38542009169056, 52.656929185313565, 49.2120958143665, 43.88950617082658, 37.77074990733978, 38.17886860139909, 37.330099075071274, 38.30134853239983, 36.86851063082295, 38.4739092857607, 37.711122035980225, 40.09585249808527, 45.45373170606552, 47.83984676484139, 51.7737094817623, 53.679640139302904, 46.304619312286384, 38.35053897673084, 54.03739167797951, 48.76645964960898, 48.52437488494381, 41.91271789612309, 41.78671175433744, 38.15277307264267, 36.966452214025686, 37.289965383468136, 39.79480274261967, 38.00309542686709, 38.65722910050423, 39.96861080969534, 44.86898476077665, 49.011148868068574, 47.60624216448876, 51.97907301687425, 54.39336246059787, 51.932483103967485, 49.95432199970369, 48.40373846792406, 51.71806673849783, 50.2067304426624, 54.509645046726355, 53.16789634766118, 50.309657358354144, 52.81960164347003, 52.90003768859371, 50.852842869297156, 46.4934108334203, 47.3024389051622, 49.88266814139582, 47.71306791613179, 46.21644835318289, 50.68598131979666, 51.58102304704728, 54.502961327952725, 48.78334545320081, 39.954396140190866, 31.484888907401796, 27.242853410782356, 20.58797582503288, 9.90406999664922, 7.00099733568007, 15.641215924293766, 15.415631590350984, 7.385621522703479, 8.149776699081544, 3.015613551101377, 0.9692597124845752, 0.140788528407293, 0.5878641876962878, 3.7031405683486693, 15.559487458198303, 34.120086239230254, 34.47535491758777, 31.237228493536676, 32.334744930267334, 44.24142906742711, 56.9903519845778, 33.71008088511805, 11.74126111691998, 2.4334693435699712, 0.07496785507687638, 0.036542114366086266, 0.11029651298397973, 0.02137286483400291, 0.040441118856711734, 0.016512940938193953, 0.06734382466322954, 0.01282646647474218, 0.08385261340487389, 0.016729657635873845, 0.021697829755383636, 0.06233882669719958, 0.04593975706807068, 0.009921614283455477, 0.04196595558295808, 0.07719472711605412, 0.07966523043691151, 0.04578234515182915, 0.06777284156170583, 0.11696806628136866, 0.02253764215105724, 0.04160949870223, 0.07168666985366615, 0.02192290830275705, 0.08703796102875665, 0.027008213350669514, 0.07120036490021214, 0.03832248354991598, 0.09675515815615655, 0.04489946712349211, 0.03454354035878374, 0.03883603825083664, 0.04898206841561103, 0.0780657307815648, 0.021662955517850576, 0.02529534034340853, 0.04926894536061634, 0.015541165109513509, 0.05866697876744213, 0.05439953578095283, 0.020030134868237282, 0.026209336863229835, 0.13026454876507484, 0.02764625925450556, 0.025837958504956578, 0.01251539072742866, 0.03674484038304898, 0.022471000162524082, 0.060213135720621196, 0.10747828235429142, 0.02968666740813323, 3.0770182561489845, 18.8285300039476, 45.21741282555365, 51.72686461479434, 41.663596399368785, 35.52051751844345, 22.560198460855794, 32.08794743784013, 33.75193649722684, 15.797693979355598, 3.9453949755237954, 0.285462164470265, 0.13646627566026104, 0.42659667350592156, 3.5601978773070924, 4.916149233618091, 8.518597656680692, 11.411705536227073, 9.52504744452815, 11.992697792668498, 12.897081625077034, 13.211144824181835, 16.068448328202773, 31.217071433221143, 41.06233235328428, 48.2904133489055, 51.514236850123254, 55.08785732330815, 53.84762348667268, 54.471099915043006, 54.45283343715053, 55.178232654448486, 51.967352974799375, 55.765799783891254, 54.71038018503497, 54.13461154507053, 54.79766861084969, 54.56705677893854, 54.75718190593105, 55.882447150445756, 56.69789221978957, 58.743400419912035, 57.63058085595408, 54.85714350977252, 54.97204542160035, 57.79766205818423, 54.71259240181216, 52.22151863959528, 46.39220976060437, 40.23029565811157, 40.85128530379265, 38.115514478375836, 39.95682408732753, 38.36473011201428, 39.623473613492905, 39.84388336058586, 41.21064893661007, 47.41152786439466, 49.37914563763527, 54.65742034296836, 54.33497798058295, 48.1284979081923, 41.99820987639889, 55.48789593481249, 50.85487073467624, 50.53689202954693, 44.397417806809955, 42.57298615670974, 40.434149080707186, 39.68916154676868, 39.66092048152801, 42.19528152096657, 40.60448192781018, 40.54794096177624, 41.989765013417895, 48.33511267938922, 50.68864068677349, 51.76132655912831, 52.933369990318056, 56.21333045344199, 52.39015310041366, 51.31872238651399, 48.88325606623004, 52.38415187405002, 52.056014230174405, 55.54077732947565, 53.49306867968652, 51.61477504238006, 52.65188893964214, 56.21460914611817, 51.644396781921394, 49.91767921755391, 48.97694580016598, 51.55780261562717, 48.12273986877934, 49.32111417093585, 52.17221836889944, 55.348338004081484, 55.65611070202243, 51.30239355948664, 42.65836438825054, 32.32664327467642, 21.563771309391147, 20.831617770656464, 14.134421733117874, 10.491082110712606, 16.246035598939468, 10.413096566354076, 9.392099688130042, 5.077305695702953, 2.2599324103324645, 0.3969988971948624, 0.12129476233836144, 0.7198288387829258, 4.205928608294457, 17.43579637619757, 34.31020352148241, 40.2275578437313, 40.5902398017145, 39.292296132733746, 51.105827900671194, 62.4799051592427, 41.75612118936355, 15.271099113648939, 3.080749655923536, 0.1957122215460385, 0.052919821633446607, 0.08551869376171982, 0.018852385767405073, 0.039818258730754744, 0.036281506576004534, 0.037835351221503756, 0.024333066877818877, 0.006170949791633194, 0.07763350397468576, 0.007819753429371743, 0.05017282951983714, 0.052657957459169055, 0.031337270873688886, 0.0035913177247669913, 0.020121130791883317, 0.07518075091103393, 0.03471702096923705, 0.07177828630853085, 0.06168235063312515, 0.039212413417596015, 0.014748778344402391, 0.05697679728449834, 0.0005967625627583344, 0.06495268039044834, 0.13996749665708313, 0.19043131701407895, 0.14847091939901153, 0.13816650055589216, 0.18263056543805908, 0.09143520612269641, 0.15629587935343867, 0.168990615094381, 0.1964403881180671, 0.2544144135449202, 0.07455453531996858, 0.1861285535438407, 0.11058851505719847, 0.19302913648707254, 0.14259393717492783, 0.13371199038961243, 0.19233521404525927, 0.237040673232367, 0.11386121202620769, 0.24305090879000005, 0.13500810390518558, 0.10625389765106863, 0.1352415768609893, 0.11782072980197207, 0.24610563842279298, 0.1671146036636445, 3.926866189126046, 22.89340380699404, 54.332652015070764, 57.97860491660334, 47.418827395285334, 41.13523352530695, 29.576371446732555, 37.79700625327326, 40.51888012116955, 18.320671319961548, 4.972464663367118, 0.6144076020967576, 0.3120085512918811, 1.1750989575539867, 6.23831206752408, 10.454282433755937, 16.510905411935624, 23.642666724420366, 26.20243295546501, 17.778703704957042, 35.049680125328806, 22.510447117590136, 23.867540128769416, 35.49273929288311, 43.10574208536456, 51.26871608918714, 51.78398609161378, 56.412175009327555, 53.97664985349102, 55.870115218623994, 55.077863124109086, 56.78612985918599, 54.01172760994204, 57.50454333520705, 54.80679988861085, 55.50678606956236, 56.804768962244836, 56.96578618018859, 57.05422386046379, 56.33625753464238, 56.792111473698775, 59.646714425856075, 57.30443185375583, 54.184496248922045, 55.9774822573508, 58.18547464186146, 57.53965247061945, 54.36025765634353, 48.32725617193407, 41.566168646658625, 42.114417937494096, 40.138774994880926, 42.42855664222471, 38.990089278067316, 41.41419641433224, 40.37203050428822, 43.81318076964348, 50.175053381150775, 51.697023222523356, 57.28510633591683, 56.356034125051195, 49.17952837482576, 45.68832866607174, 57.28633011541059, 53.499913215637214, 52.834388979019664, 46.43334365660145, 46.14589275852327, 43.136701353134654, 42.09410790474185, 40.5046772187756, 43.55631259179885, 41.98233604431152, 42.857318770500925, 43.974539233792214, 49.170993297330796, 54.131387356788885, 52.55816390437465, 57.04017785287673, 58.26522034983481, 54.959199659286014, 53.79742499320738, 48.71299774416032, 53.41970859035369, 52.45458979760447, 56.32056020921277, 53.87697066030195, 52.315482939443285, 55.64958780042587, 57.65651556753344, 55.104484250468595, 51.127185206259455, 51.508478810710294, 54.38896156126454, 50.836604256783765, 52.27685543798631, 57.2185201798716, 57.319501599957874, 58.11657428741456, 56.3813373350328, 46.72873735427857, 35.47725769781297, 31.466120366127264, 27.704359485257058, 15.26457719264492, 15.366641186898756, 31.350367299972046, 23.01794102115016, 15.68469245587626, 14.69223278184091, 8.860715608442984, 3.684758625684246, 0.6055584898398769, 1.435884847756355, 5.617081196077409, 20.53213304088962, 43.21370924672773, 45.99785858584989, 43.0558495367727, 45.391181668927594, 59.19741868972779, 72.92393745914583, 48.39287350254674, 19.371366423945275, 4.338180634283251, 0.2988057920048314, 0.17817466099175716, 0.23743900830947587, 0.16908511970072024, 0.11470609975437965, 0.12313987744311172, 0.14365985659101319, 0.08759835434536781, 0.13587873218761337, 0.26421630935322854, 0.12731358574162568, 0.15093818216794921, 0.10092101405344664, 0.1108835584994766, 0.1390967917658629, 0.17302829682105975, 0.19787516354793505, 0.08230976595152771, 0.18103553973619016, 0.2515078299949246, 0.10093468106201581, 0.11909105679801396, 0.1337004224619558, 0.1441915369322223, 0.15939191644710882], [0.011383389524604765, 0.038117838482702934, 0.10834045302603515, 0.02665727804865568, 0.06397094637636216, 0.060248935009322824, 0.029942864446990916, 0.0708525073564341, 0.051902636900664344, 0.02402176896500732, 0.03364324915192781, 0.09561563301230631, 0.07197033689026872, 0.059302552122502565, 0.029219916848946485, 0.030828659355099645, 0.036447617420626265, 0.06390038201765669, 0.051016231037435994, 0.029645957495836966, 0.02878631491424336, 0.065291628331667, 0.05565846338868142, 0.09882035499979412, 0.01700212063658382, 0.08507387246936561, 0.9319026912412337, 12.977047966372583, 41.02564250269244, 47.3352103079519, 37.62977992334674, 26.277279623093147, 28.896206963446836, 34.45458204515519, 23.716173902634655, 13.009945865600342, 4.379309627317614, 0.3119426983739099, 0.10186504888077898, 0.09914984941602716, 2.0275533055105517, 0.8854346169579415, 3.528549743275489, 7.816866021002493, 5.820758112015263, 11.146036540308307, 7.302407458905251, 7.355394757563069, 10.553738051845182, 29.02925572087688, 35.18430763675321, 45.25163942767728, 53.42110495413504, 55.47312821111372, 56.37167261492822, 55.891896140190866, 54.007409080382324, 54.990864953687115, 53.43117367836737, 50.82009892309866, 47.63769565090057, 50.962076956225985, 51.556296425481, 52.09698730899442, 53.404646688892, 53.84819615271784, 53.89927325710174, 53.198992898387296, 51.2778591340588, 52.599042846310525, 51.23184973193754, 53.30162171394595, 48.74964837105044, 47.73666881745862, 40.13206774188627, 38.07388244136688, 37.906926754982244, 36.25668756423458, 36.50611108349216, 36.89752440298758, 38.36713452492991, 38.05465498278218, 37.769561429177564, 40.07297723524032, 47.33577512925672, 48.58265738333426, 53.4809720900751, 48.73782634735108, 34.475147031968646, 54.63436857346566, 48.81335158501902, 48.41111644621819, 44.527154122629476, 44.64251495176747, 39.59897056702645, 38.33023286634876, 38.023181884519516, 38.657491899305775, 39.00759089377619, 38.21444842123216, 41.04332062505907, 39.815960007329146, 42.35296472426384, 50.71259852378599, 48.39000232758061, 52.79850321431314, 51.33028945615215, 53.1838329376713, 54.47495560492239, 51.82102503315095, 51.732469681770574, 51.59960723692372, 51.26715106348838, 51.94566619011664, 51.769763577368956, 52.39619355047903, 50.075523238028254, 51.89711901449388, 52.37236515168221, 55.145684826758604, 51.66393018537953, 48.522990288272986, 45.98853903432047, 53.18095784033499, 50.98773710189327, 45.23260416523103, 44.04895836307157, 29.060203221536455, 23.22063538335985, 14.403564968416768, 14.848190142262368, 14.56488028649361, 9.722168118722978, 9.004308677488758, 9.185571209076913, 3.2149050120384466, 1.3638278433392126, 0.13979826783460958, 0.1266298599300846, 0.5831635947669707, 4.388026114433043, 14.947646740944156, 30.904397733749885, 27.83926744614878, 27.67373754132179, 38.549842449926565, 43.3250065003672, 53.03312763091057, 37.59451389312744, 16.134522614940522, 1.9433156256714177, 0.0819101898119815, 0.09943137906732098, 0.07003539797639655, 0.05068004101274475, 0.043922046184419625, 0.062231543744283344, 0.07890632075648155, 0.018055692630549593, 0.005527011714049525, 0.04925910113078933, 0.032118525423650304, 0.05364533371081757, 0.024827302756508993, 0.01847535559547044, 0.015823914755826757, 0.053411362797863064, 0.032799805499493115, 0.04431683427443908, 0.03386621904228965, 0.05567663499424535, 0.03681810903212717, 0.05417748136566051, 0.03752002943186991, 0.07912586623382184, 0.11937377388559042, 0.05773775241968613, 0.02021570051569612, 0.10465492659638967, 0.043148871946839557, 0.012807030824103184, 0.05959708994675068, 0.029086178964785034, 0.021248591966145945, 0.08542389804196936, 0.019411953624277827, 0.0431002521767251, 0.06508754250863868, 0.055485078539218635, 0.03435067389340651, 0.034745324087599595, 0.05151827143685472, 0.02576254097925079, 0.030062630802633303, 0.039459063085697355, 0.03349927441787816, 0.04198588152986862, 0.03658402320598403, 0.06283197281581741, 0.045932138323663704, 0.03910406943290465, 0.030724645682400277, 1.2203213115853648, 16.591690548004642, 44.90738476476362, 54.17376072176042, 42.22769206570041, 34.52484738442206, 30.271823367764874, 34.50701628961871, 29.815312431704616, 15.963552382684524, 5.421519173729805, 0.4377257859995289, 0.06591532349346146, 0.24514933086691365, 1.78933207546511, 3.476451351757973, 7.58887384207018, 7.9238687695995464, 11.21494964245827, 17.530947193022698, 9.948578111587032, 16.64701165691499, 20.574371084090203, 28.58054441790427, 40.19131906570927, 46.911649242524184, 54.13530188222086, 56.24709813825546, 56.84423585091868, 54.90579266701975, 55.166645972959465, 55.323023026989354, 56.40453815460206, 52.82408099020682, 49.85707859839163, 52.653755987844164, 54.67558483923636, 54.564554306768606, 55.01916485448038, 55.96304009037634, 55.93770157906317, 54.612426834721724, 54.065456236562426, 54.41852054288311, 53.531417692861254, 54.39257798656341, 51.476385977960405, 50.290488735322036, 41.37101504110521, 40.08790969848633, 39.45464303416591, 37.58734772282262, 38.931896994190836, 38.20152028914421, 39.2943004638918, 39.054059213207616, 40.406712101351836, 42.9362682373293, 50.42258631798529, 50.33841225408739, 56.413241894014426, 48.489403032487445, 38.492615069112475, 57.04708514675018, 52.05168393350417, 49.887469122486735, 46.49449340758785, 46.784870393814586, 41.74991599975094, 41.033750041838616, 40.166364946673, 40.88234263081705, 41.152739063386, 40.02519884417134, 41.74471885927262, 42.53744163820821, 46.587677155771566, 52.22504877275037, 51.220851405974365, 54.52942163713517, 54.40063061252717, 54.03670526319935, 54.702955138298776, 51.81202319360549, 52.17721546849897, 51.662490675526286, 51.90742308093656, 52.671014416602354, 54.767368301268554, 54.74733283442836, 53.352506622191406, 53.93167987946541, 56.03118342737998, 57.585246101502456, 54.252208125206735, 50.579434056435865, 47.88835471676242, 54.62435868478591, 55.428915254531375, 52.21989085597377, 45.57652150430987, 33.08677311866514, 25.26893238867483, 17.75013708299206, 10.875563621520998, 14.353237036735782, 13.784772830624735, 10.14719222822497, 11.700214493659235, 5.916896875827543, 2.3493254328927686, 1.0756782730740886, 0.2701742057838748, 0.787259039859618, 5.094148353222878, 16.53969168663025, 34.70909680089643, 34.45478208603398, 33.25977709985549, 41.857483079356534, 49.61319346581736, 60.201353257702245, 43.03763797206264, 19.370944769151752, 2.6923379302024846, 0.1616508186224007, 0.05598099023524312, 0.05361022007080817, 0.06112176962497254, 0.014139922305701241, 0.04966413947723566, 0.015418779690779988, 0.023667639076349237, 0.05407862921035098, 0.023602812716196624, 0.02234755658484515, 0.03380754053772938, 0.03963590299169864, 0.03882626679936244, 0.04655597138128454, 0.041990363144225655, 0.061382814085171114, 0.03716997704618881, 0.012224183470431355, 0.031249779802296433, 0.015199899752323907, 0.05075705583177267, 0.05118148769402216, 0.07839427524877172, 0.027658459204699726, 0.10149979348024053, 0.12731190800907152, 0.22817262328199803, 0.06187757281886955, 0.16999984400406962, 0.1755110345660679, 0.11499073206176681, 0.16190728953769132, 0.15623033287063723, 0.12285594227573565, 0.20932808608537723, 0.23615447804331782, 0.17835236274667327, 0.17009399620996368, 0.08987678410184961, 0.11576100282611386, 0.115327519635039, 0.13266712306968628, 0.15525671172766917, 0.12247367206239894, 0.20399019993360967, 0.11981196851739961, 0.142964264077525, 0.15729822879356725, 0.1307777817090673, 0.17307381776552047, 1.8484879140892339, 18.817680728050973, 52.967726030657374, 61.18517391143307, 49.8733054437945, 38.076420214868364, 36.89317449446648, 44.98462800056704, 34.880508299796816, 19.72230676681765, 6.02576373084899, 0.8727310405623528, 0.2535744594229806, 0.7404448164086188, 3.8818444888437953, 6.249177523197667, 11.861245439898584, 19.622049024028165, 20.357530693854056, 20.31131340611366, 12.931798523472203, 13.09226562899928, 16.11643362429834, 31.08720567918593, 40.934090460500414, 50.2272601281443, 57.49851072988203, 56.79499441577543, 56.67285573097968, 54.284971683256096, 54.19643594372658, 56.86796226809102, 57.624740446767504, 56.06875973363077, 52.10649121192194, 56.11796978981265, 57.40182822750461, 56.54697118266937, 57.602896767277876, 58.04701105240853, 58.720438864923295, 57.839050908242505, 55.51906308820171, 57.88343252674226, 56.083566681031265, 57.715147156869214, 54.906769337192664, 52.50310951663602, 42.76309559422155, 42.27227764744913, 41.38424127332626, 40.346115404559725, 40.23144099020189, 40.53011378934307, 41.71932935714722, 41.63127999151907, 42.34468460083008, 45.19921302795411, 53.262190126603656, 53.602585177267756, 57.8100214465972, 49.81995728708083, 41.47617770779518, 59.18539270277947, 55.06566063050301, 52.301170210684504, 49.02786208737282, 50.7726578558645, 43.7245548156, 43.79886411851452, 42.809238356928674, 41.99575839504119, 43.092613912397816, 42.394965464069, 42.88362610724665, 44.15645876238423, 48.595981674809615, 55.85544555417953, 54.11488986784413, 57.661375384176935, 55.87481029572026, 55.86751468719975, 56.33621438857048, 53.56713871802054, 53.44143067636798, 52.10586363269437, 52.394836410399414, 54.28231231627926, 56.10214694853752, 56.90633873785696, 56.38581668176959, 58.72900924374981, 57.424864307526626, 60.232457653168716, 56.41245349760979, 53.42868297330795, 51.14459268508419, 58.06972157570624, 56.93982401201802, 54.41712417910176, 51.89332216016708, 32.01657402899958, 27.633774472821145, 17.057075846579767, 22.315342541663878, 26.000115140791863, 19.20650920560283, 17.019032778278476, 18.112126742639852, 10.107463521342124, 3.7511006141862566, 1.1594810601203673, 1.0448233158357683, 0.8873977632291856, 6.792641032126642, 20.0668889476407, 41.29110459358462, 41.49200839381064, 40.337384208556145, 50.794262270773615, 57.68630596899218, 67.50818760164323, 52.258204567816954, 24.517841646748206, 3.15678259538066, 0.35163291699944005, 0.21011681956869943, 0.14060158763201008, 0.1254106616421092, 0.20791696745061106, 0.28265865038960214, 0.16908064574724244, 0.1531760169253234, 0.11606103350077906, 0.08666155138804067, 0.10792616033746351, 0.16459097214523824, 0.08016773814996404, 0.08918859965858922, 0.10250540645492655, 0.08834869916280431, 0.1405553772084175, 0.1175167844180138, 0.16155108929641787, 0.1072904988822918, 0.18908499409594845, 0.23481074450237138, 0.17782578455103984, 0.26903025265182223, 0.14952726271604339], [0.017184957095812407, 0.01594325401745136, 0.040175202077314745, 0.06610827039807074, 0.04708758277458049, 0.07338313325758904, 0.013387696742410622, 0.025292415802757588, 0.06793889111929363, 0.02126529268289526, 0.029177925654596863, 0.011484857870175714, 0.04039635633929603, 0.05980334762904433, 0.020829478669310772, 0.009686241429599543, 0.054660277636421305, 0.018677441929016384, 0.022122974079402707, 0.06957461141170034, 0.006381627322444993, 0.028397303127172976, 0.056047348771244294, 0.033704505542353276, 0.08158952838951543, 0.06293329177424312, 0.2558247354482451, 10.785189270973207, 39.52396308222125, 46.23726829405754, 42.45498557244578, 31.076662348162746, 20.851659121051913, 24.788306720795173, 20.49578247531768, 14.32192671683527, 5.734769951912665, 0.6929640351764618, 0.06707887315461714, 0.2936751479583402, 0.9327965626312841, 2.969270747515463, 8.35329426873115, 6.801914495806541, 6.71711334297734, 17.107215504492483, 7.302963454877177, 21.875986091552242, 21.682068032603112, 26.354615034595614, 35.15133227071455, 41.89456908933578, 51.998571119000836, 56.25646868059712, 56.28645520056448, 56.32748711493708, 55.3836432580025, 50.071851899546964, 48.54542624565863, 44.70058171979843, 44.88416041097334, 43.71046173957087, 44.53273957775485, 45.77400892011581, 46.84904036983367, 46.28425044398154, 48.17904549260294, 47.2278707258163, 49.074879538628366, 46.935716905901515, 48.72112881752753, 48.19254629073605, 44.200326550391416, 39.69599431560886, 36.79462102151687, 36.79349922364758, 37.164684880164366, 38.09261960368003, 36.943600485401774, 37.099973617061494, 36.34743159817111, 37.73330696167485, 37.310699032199004, 38.80070155666721, 44.43846541066324, 47.905248365094586, 52.59149228372882, 47.05384300601098, 32.04259699390781, 54.023651615265884, 53.569299943985484, 51.097339891618304, 47.71573905021914, 46.56798685750654, 43.85950003900836, 39.054914289905184, 37.749576953149614, 40.313045901636926, 38.17877446451495, 37.9645699070346, 36.75594645161783, 38.73126775987687, 39.16036328961773, 41.927952381872366, 47.314747302762925, 49.708797316397394, 51.180384312906575, 51.8348474656382, 52.2250997635626, 53.569766706035985, 52.85490297502088, 52.638580337647475, 53.29929967080393, 51.69682710401474, 50.83401549247004, 55.32460766453897, 54.05033157717798, 54.48981354313513, 52.17293616264097, 56.61547537772887, 53.571833795116795, 52.92714126648442, 46.00884906707272, 51.867230553780836, 51.560140348249874, 51.09657110706453, 39.60539148699853, 40.28713080190843, 18.477191540502734, 24.54579834015139, 14.727253663924433, 7.384021685969445, 18.09682361541256, 4.276675418499978, 8.278808459158867, 4.708449436772255, 1.9748970794100917, 0.9460083311123233, 0.12034041596756828, 1.3120703303044843, 5.247668450878513, 15.985677492234016, 29.548585376431866, 32.32513120097499, 30.050121199700143, 33.65451658925703, 49.7200741306428, 52.24125600630238, 40.56893740930865, 14.937138711252521, 0.7058375605171727, 0.15624435227965155, 0.04672007507554466, 0.03901018152734445, 0.01068066856298115, 0.012130768624164406, 0.09740271695679235, 0.058935262758525155, 0.04115929564220771, 0.06070984797852655, 0.05814803463797416, 0.028565223854515823, 0.04108506172234493, 0.04127036689990952, 0.06198146583272084, 0.02732471491570675, 0.03962369155018561, 0.004591929102917352, 0.042489465596454765, 0.0514078053886131, 0.025024953440973358, 0.07090113095698819, 0.09151747630488488, 0.04762702741690221, 0.04516147685447528, 0.03934807609766722, 0.016374043451862472, 0.022125218717020848, 0.026586457050495574, 0.011332518413602825, 0.034804971693384076, 0.028024116801398418, 0.02064865702132304, 0.0331545271910727, 0.07621173671777211, 0.05115243763993344, 0.02831684857336504, 0.08615361977248423, 0.060449301475478764, 0.02672418625274253, 0.060976255054195086, 0.032120997972425916, 0.021516877872448777, 0.017385758316865372, 0.04756677460165755, 0.11620294362787278, 0.036172254777122895, 0.03461745252171832, 0.06584511153520116, 0.07187590123184266, 0.008418071928674416, 0.0551135067437445, 0.4417691980638812, 13.944072050433006, 46.80563542150682, 51.231155472417036, 50.12489018901702, 32.92806225438272, 26.80911771712765, 32.30516241442773, 27.694610434193766, 17.096403491112493, 6.096265883215013, 0.9646973218167982, 0.10090759985389249, 0.24484900907883722, 1.879018295195795, 3.8350989068708117, 5.851327594249479, 8.518471160242635, 9.44677850892467, 15.879948043054151, 10.810717036647182, 15.9264418578917, 22.368427899576005, 26.18886547703897, 36.75140042458811, 44.730803581976126, 53.52837785597771, 57.060817364723455, 56.95665490242743, 56.848358261969786, 56.043684021119155, 53.37756664522233, 48.81062553774927, 47.99855370675364, 47.41252022404825, 46.737488162133005, 47.408217383969216, 49.68236446380616, 49.88488035817301, 51.96154786694435, 50.68400052285964, 51.61159007780014, 51.78458621425014, 49.63724151734383, 50.27989049111643, 50.82466848434941, 48.13198489527549, 43.24320939279372, 39.613899107902284, 38.18152012363557, 38.11964081179711, 39.85925512929117, 38.23049483760711, 37.48667616997996, 38.52011480639058, 39.234354880548295, 40.161077591680716, 40.7780271960843, 47.09024260121007, 51.2820678372537, 53.40512521805302, 49.86571565751107, 35.221205372964185, 55.10860273914953, 55.22820365044379, 52.73600416798746, 49.63353095516082, 48.783157179432536, 45.9232315709514, 40.823750265182994, 39.5149455531951, 42.214418765037294, 38.91517200777608, 40.2648635064402, 38.98124433332874, 41.082650230776885, 41.04613296447262, 45.1464218478049, 49.74535772877355, 51.91120816815285, 53.07046467258085, 53.83847259706067, 53.592300722675944, 54.187508629214385, 53.84230475271902, 53.67123057765346, 53.52220012295631, 50.77144976585142, 51.86034287175825, 55.49775677342569, 55.05150087418095, 55.673890806013546, 53.484082529621745, 57.57246309711088, 55.616059380192915, 55.77058507550148, 49.99572653924265, 56.49148141184161, 53.95924237466628, 53.27820908638739, 44.2359063702245, 37.80501573316513, 19.789657785046487, 23.216001103001258, 10.821493748695621, 14.443389773368837, 13.621911118107459, 11.459469218407909, 14.522948188166465, 4.9803378408954995, 1.6568548809136114, 0.3007100107929399, 0.24397721634276454, 1.2335677685276156, 5.902229662864439, 18.69351221669105, 37.912484753516416, 36.71436932779128, 34.08263937119515, 42.868230804320305, 53.86799627734769, 59.74066695859356, 45.65181924450783, 19.116473159482403, 1.0548197213680515, 0.08655095893529155, 0.05751522302988076, 0.04188080874061392, 0.05628629159482737, 0.0714558245794427, 0.06210444592720559, 0.018306354684154355, 0.016279900822067456, 0.11499458548402595, 0.03600139418737062, 0.013908504380754406, 0.04425242543220521, 0.012901167708238768, 0.0844978662808576, 0.02887200376379394, 0.015985109231194422, 0.03918291137163197, 0.045515995532754934, 0.02431280385222166, 0.03916759344358598, 0.09766926192828725, 0.08130059832887304, 0.025046886538245508, 0.017512821659986532, 0.04210848241083084, 0.10607181387322565, 0.1184689014729473, 0.13945916667580605, 0.17646496724938193, 0.10270388451434913, 0.1466786260566404, 0.14272579622845497, 0.12676504380520315, 0.13434171466337097, 0.0830093497831014, 0.13142026900764436, 0.33837521388646097, 0.0899516462138103, 0.1227224361331713, 0.11941497409415823, 0.11973217279920656, 0.18490183227244886, 0.1492724618724277, 0.20993064488134078, 0.1766588947465343, 0.06417436953333598, 0.12425446642502663, 0.1990635497795959, 0.10335872881114484, 0.25582576200606366, 0.17587544726988963, 0.6129877653814132, 17.179904868525846, 53.034151369525546, 58.48167634779408, 55.8304286772205, 42.756211834569136, 32.55652946810569, 34.07794821646906, 33.41825654429774, 20.352017802576867, 8.24308253103687, 1.1470606298215928, 0.3589142149975223, 0.808387131940934, 3.7932682998718756, 11.558430617855443, 19.92057865665805, 15.984909688272785, 16.50474532958, 32.0678178341158, 16.982713591667913, 29.230104607920495, 25.150166942227273, 30.233790105389012, 40.36870041201192, 45.26084523047171, 52.702675788633286, 57.94569623085761, 55.8854869873293, 56.79078179021036, 56.72300715600291, 53.65918497885428, 51.810681743006555, 49.852042275090376, 50.225189116693315, 48.35484220135597, 48.859317841068396, 51.86598716243621, 52.81565573907668, 53.053763220387125, 53.43021662004533, 52.00558431686894, 54.99591696646906, 52.23488999951271, 53.09838018109722, 52.8687136403976, 50.09225214681318, 43.53222531657065, 40.331586945441465, 40.41576100933937, 40.00368464377619, 40.941633178341775, 39.911720752716064, 39.6420068125571, 40.3483001647457, 41.793995595747425, 40.98915661534956, 43.16327541105209, 49.31622689770114, 53.86266969865369, 56.29362529323947, 49.95150181554979, 39.929226290795114, 55.90560090157294, 58.06647777557374, 56.22755689005698, 51.5502049846034, 51.59942288552561, 48.29941518845097, 43.83512643075759, 41.13040508762483, 43.268469456703436, 40.21464932349421, 41.3650098923714, 39.537271684215916, 44.84771374733218, 41.19123320425711, 46.52990064313335, 52.44723143116121, 54.53916480464321, 55.36688689262637, 55.84825584965368, 57.25335082700176, 56.18808215664279, 55.50456600804483, 55.07542733223208, 55.24319494924238, 51.76711597750264, 52.41991212291103, 56.76529030646048, 55.48689965278872, 56.80856189420147, 54.58734719983993, 58.9959853695285, 57.13191816883703, 58.90663377700314, 50.77016715080508, 58.45678498668056, 56.95359153132285, 57.45013613854685, 46.432963186694735, 43.396742728448686, 21.312155185207246, 30.41397398517978, 20.970869756514027, 16.443423974898554, 33.16472238109958, 13.195660287334075, 17.265063447337, 8.90702703306752, 6.104319980067592, 2.1075924558024255, 0.44577779909295423, 2.498894968340474, 6.922033159963547, 22.070757266013853, 39.29235496828633, 44.55705042808287, 41.702855402423495, 46.25544063506588, 60.54702389624811, 65.84299241342853, 52.85953921656455, 23.738376478995047, 1.8685898160742176, 0.4104137402628699, 0.1820600597608474, 0.21131586974426625, 0.14987777858491869, 0.26501304079448024, 0.2780841248891046, 0.08840915882178853, 0.11367804806439147, 0.1768282921083512, 0.15004590424078126, 0.19117630687692475, 0.10302548822496208, 0.16374473610231954, 0.21505500700685287, 0.12873198987255174, 0.11392807618023888, 0.15807430650438034, 0.14460064320554658, 0.15639755454274917, 0.10301121600693273, 0.1642964113383524, 0.2513593468334406, 0.12372657821904268, 0.07373296730821172, 0.22946836907536755], [0.10221083798716146, 0.04974079806537879, 0.07329119504579613, 0.043688397028393326, 0.05270454709628417, 0.0260679783194416, 0.033867123026040294, 0.037331330484800765, 0.0172649749795035, 0.024376343184661482, 0.087727784900175, 0.02413799599443953, 0.05439388588251126, 0.04677493080136277, 0.11524255282335705, 0.055355464123309626, 0.022864895760111754, 0.011305028306049927, 0.07464471152953564, 0.06229495667221566, 0.03724564355046999, 0.06262295721699634, 0.032615695419090415, 0.040521224840514125, 0.04072101291028723, 0.008702194787591936, 0.14633004072933428, 9.623674461918494, 31.642744694986654, 44.59852949265511, 39.23080121317218, 31.50254741791756, 21.900267524103967, 26.64608047854516, 36.64373920809838, 20.79322365022475, 6.828975417921621, 1.1122173575624343, 0.06096899637111253, 0.09902870027168144, 1.0087271527417245, 2.8230710183420493, 3.275852760960979, 2.6840264278073467, 8.169827855402424, 15.168379102983783, 9.888356001146379, 15.45278428062316, 25.3874977942436, 22.357855150776526, 33.109263989233206, 39.65765314717447, 48.9621937659479, 52.030585504347286, 56.01923981020528, 54.194306096723004, 55.31147164683188, 49.67450795635101, 45.18774793994042, 42.74674323297317, 39.58740349738829, 38.2966063868615, 38.50125997297226, 37.45480298995972, 38.4706929422194, 39.02295874011132, 38.87172783574751, 39.72060718844014, 38.815179024973226, 38.90826471390263, 40.2956227333315, 37.33803795230004, 38.14164530846381, 34.99019345929546, 40.02598724057598, 39.26982879638672, 35.6902620100206, 37.82396862583776, 38.28882440443962, 37.190717650998025, 38.815324152669604, 39.11540116033247, 41.13050706924931, 42.82847758262388, 47.191106350191184, 46.475666030760735, 54.37688458350397, 47.88712701489849, 33.95598996070124, 49.89216812195317, 51.41894678915701, 53.606260438119214, 50.11941848262664, 50.20820917621736, 46.145665261053274, 42.42481077871015, 36.97839975357056, 37.92793496962517, 37.2736208669601, 40.65999523285897, 43.485584412851644, 38.055788547761985, 37.46850775134179, 40.45960918549569, 43.58898593533424, 46.4960309766954, 48.856254469963815, 47.11469073449412, 46.19771903561008, 47.02373097019811, 47.65913924863262, 50.892372515893754, 54.80522701817175, 56.95658429976433, 50.585847131667606, 52.93723744730796, 51.5632664772772, 52.92659997940064, 57.3898296971475, 58.57294205696353, 56.70860813510034, 50.718811558138945, 49.781965209591775, 51.9570920544286, 52.27221919644264, 48.22620022681452, 40.19099743135514, 28.940661145794778, 24.25566061850517, 21.399300444510676, 5.22496332083979, 18.82741997318883, 6.417892392604582, 13.82765414253358, 14.170342799155945, 5.141282004694785, 0.6225821892580679, 0.3560087499358962, 0.2304970412965744, 0.8636249517721515, 5.347932567519527, 16.071860790252686, 31.78264975547791, 37.9492255949205, 29.34232165736537, 32.67770717220922, 41.89744418667209, 50.136845573302246, 41.124996139157204, 13.691159582907154, 1.1297479007513294, 0.06631000433117151, 0.016549602075810396, 0.03158911844835647, 0.07430974724552325, 0.040763201372277354, 0.019713380494185036, 0.020874773617833856, 0.04471826434676205, 0.06023912142301279, 0.03795058999751364, 0.1008104905486107, 0.02821171641229622, 0.025055204337883382, 0.04230151741555141, 0.03426500228083423, 0.06947207820391463, 0.010388458688412944, 0.036402590602876685, 0.016018627493101505, 0.09251792584696124, 0.032470180848312956, 0.04593138755749791, 0.024092030718982704, 0.03352599173423744, 0.044922610639684626, 0.10428654555712016, 0.032439809292554855, 0.02135893160988006, 0.06075307448965408, 0.03768432081767148, 0.049564310559822675, 0.015054677252567586, 0.0271582076205842, 0.07907427021212156, 0.0359990461278827, 0.04686734781810834, 0.021680140785212, 0.031535869591959545, 0.038512523150852615, 0.09416040303486009, 0.07897426509448598, 0.023638069997691823, 0.030688128186269637, 0.08837100764315936, 0.02571164018234178, 0.056860600898583094, 0.0592013672294636, 0.08780538960690461, 0.030096204605914896, 0.04055091457801961, 0.024045297440381783, 0.15310218137118126, 11.159823671463998, 37.393582636310214, 52.36934492664953, 43.99679476214994, 35.87561753488357, 26.66361935677067, 29.450214293695268, 36.07502298970377, 23.608169478754846, 8.327984194601736, 0.859048403799534, 0.1069854426708433, 0.08767903872555302, 1.1809228192414007, 2.944079079935628, 7.408086897865419, 9.118171161220921, 12.852026339500183, 10.435615874105885, 9.344198722993175, 17.161822742031468, 23.396210478198146, 25.91049094353953, 33.61619895504367, 43.74088756499752, 49.84708439919257, 53.65455265968077, 55.37478262378324, 56.66400686387093, 57.54510848752914, 51.88909384512132, 47.8683663183643, 44.49077806165142, 42.038025856018066, 40.96408482520811, 40.26909182148595, 40.73207662951562, 40.62365447321246, 41.6110287943194, 41.741867296157345, 42.333635284054665, 43.29214096069337, 42.52800049320344, 42.04200706174297, 40.95596944132159, 39.98427675616357, 37.10700250441028, 39.7409878238555, 40.397125828650694, 37.94898633033999, 39.66559594677341, 40.15432719261416, 39.06867396446967, 40.28208663386684, 39.38970035122287, 42.625216437924294, 44.73528685108308, 49.958162000102384, 48.749228677442, 54.400858109997166, 49.74823282610986, 37.9698258830655, 52.251089388324374, 52.65786663178475, 56.11133706185126, 52.48587069972869, 51.958813974934245, 47.030493136375185, 43.648974664749645, 39.59296149592246, 39.60561506209835, 39.08192373091175, 42.504999714512984, 44.66050686374788, 39.7493895407646, 38.911524203515825, 41.991224135121996, 46.719300131643976, 48.84083171044627, 52.16758997209611, 49.207400737270234, 49.09715860120712, 50.024477512605735, 48.112930020978375, 53.779888076166955, 54.46520851504419, 55.75717449188233, 51.100422874573745, 53.448286979429184, 51.03541351133778, 54.698056097953554, 57.347938783707164, 59.48712887302522, 56.90616615356938, 53.8197942703001, 52.57681477454401, 54.03014706027124, 53.04242364821896, 51.77202286258821, 41.35023040156211, 36.06432668624386, 23.950814008712772, 20.923522826164, 8.50538613334779, 14.210349013728482, 10.123580540380171, 13.369624268624092, 17.026767692258282, 4.562702986501879, 2.6399850749200393, 0.5019605730570132, 0.2868499480668576, 0.9946736068494859, 6.109773545495926, 18.22301999215157, 34.19069282470211, 41.06922003530687, 32.11740247664913, 36.25849577688402, 51.32230743285149, 57.24394498332855, 48.000503124729285, 17.504216240298366, 1.4388658490873154, 0.17682942591847914, 0.06703730522384567, 0.012977434633930605, 0.06837936103223793, 0.010806483182785733, 0.0867849221873668, 0.030701115291806, 0.037794794526792345, 0.04518060990038418, 0.025411306902946487, 0.04258485886478617, 0.03352461277597374, 0.05949055009912099, 0.019540430399619287, 0.03831953794184712, 0.04367579105159929, 0.038290296365777333, 0.03963830467734126, 0.07186308458086944, 0.05038956728493495, 0.08338314706399556, 0.11016061664709162, 0.10048300328273928, 0.06423371453439036, 0.052737657416371576, 0.22632526353962962, 0.19812772741481183, 0.20136486258237593, 0.10181516123514983, 0.15933003186458544, 0.11737494323883327, 0.2134335206280793, 0.10302011028773363, 0.2045497811970211, 0.164026411310319, 0.2297385529645028, 0.17952982456453387, 0.1455950712965381, 0.15777050667712766, 0.18713841064562722, 0.18624161279970602, 0.13895396233326004, 0.13108723526520114, 0.233274768857706, 0.12135329145577647, 0.08148479650938704, 0.14939823818783607, 0.2262989714020683, 0.13362393624359561, 0.10523294759613853, 0.10583634142793956, 0.52572091260264, 14.23501778033472, 42.59602223673175, 59.03666427058559, 51.830999620499156, 43.08078404395811, 32.01048847167723, 38.00249138186055, 47.18321846377465, 29.3219292548395, 9.129542112350464, 1.3597223475094766, 0.37296592227874265, 0.505113453874665, 2.310254948754465, 6.138553936635295, 9.031437750785582, 14.265210224736123, 16.620892593937537, 27.069223811549527, 18.12320939956173, 21.215025532630182, 30.809001768788985, 26.594144375093524, 36.83264055559712, 45.47163340353197, 50.61566891208772, 52.978959698830884, 54.74193565307125, 56.50067936989569, 61.50439993027718, 53.98192936374296, 50.493749880021625, 47.28929504271477, 43.01283682546308, 42.019037662013886, 42.76917134561847, 41.36337818637971, 41.36243289516818, 42.1827652377467, 42.23861586663031, 43.57918000990345, 44.64328373632124, 44.34182605435772, 42.95298145663354, 41.82821043076054, 42.7148308292512, 38.88179263760967, 43.11788182104788, 42.32879507926203, 38.98492743892055, 41.00056286781065, 43.53888550112325, 40.68900900502359, 42.145765519911244, 42.70120843764275, 45.10071839055708, 48.23718286329701, 52.08761676665276, 51.79002654167914, 56.036286430974165, 49.23801091409499, 41.16021117856426, 54.29177699550506, 53.91997160450105, 57.32239630914504, 55.13470219027612, 55.31090682552707, 50.29578393505466, 46.240366966493674, 42.18451461484356, 42.00354037746307, 40.55865295471684, 45.398041894358975, 47.12235504581083, 43.0466398116081, 41.69500281733852, 44.15639992683165, 49.32632700089486, 51.08493735713344, 54.389271428508145, 51.449607956794004, 51.02522711600027, 51.746248968185924, 51.434165585425596, 55.71679761332851, 59.649228665136526, 58.3939996073323, 51.7834016584581, 54.05582289541922, 50.74740563669513, 53.45753200592534, 57.70111683876284, 58.61893184723393, 60.75613329487463, 56.34300793370893, 55.930045112486816, 57.31660296840053, 54.95406919910062, 53.73158800986506, 46.91643845650458, 33.35967202340403, 28.10318804556324, 25.073041377529023, 9.21372402098871, 31.876970991011593, 18.28688402329722, 18.79314826380822, 24.840856675178777, 12.186566821990475, 3.2781561728446715, 1.96962651706511, 0.5443748471236999, 1.3887319521557902, 6.902357570586666, 21.79727981167455, 41.48486183535668, 51.06078340161232, 40.17517066770985, 43.18750781397666, 56.78540029833394, 64.38145452930083, 55.11242312769736, 22.15528630441235, 2.331987330990453, 0.2396819911777012, 0.11095141856780938, 0.14032081640776128, 0.31045826512479013, 0.08637215401376448, 0.16697945043204293, 0.11354314764180493, 0.15280523036997165, 0.1579258999516887, 0.11643923578723786, 0.2763926333958103, 0.11538905947799645, 0.2061551490858678, 0.1406060156202124, 0.11617567855864765, 0.11811523698270322, 0.07701950748601268, 0.14914996441333525, 0.21885788278473964, 0.4956564355281092, 0.133011341695824, 0.1886257090635838, 0.1906317562585877, 0.11746263732352566, 0.18577834411013514], [0.05283511912209853, 0.048287697812362064, 0.016522788998460578, 0.07058554869746009, 0.04223761036090794, 0.05922709246196094, 0.02088891560091607, 0.03584365668376127, 0.04583080404347951, 0.0405776855205336, 0.02110830403023189, 0.012641836412160868, 0.03568766203017966, 0.09575557429343463, 0.015109571282781903, 0.10695436248375524, 0.08869946017981538, 0.04604402546500487, 0.04170574232815735, 0.03973655928406985, 0.10607994972698151, 0.02374011482442579, 0.019350565083685423, 0.020130339168733167, 0.0429157858654376, 0.028042112206739765, 0.16071721791259705, 6.877705964349932, 32.3201282178202, 45.967864221142186, 53.09178275446738, 32.28271076756139, 29.588811243734053, 30.372490998237367, 28.34997377087993, 19.442590782719275, 8.301720003927908, 1.8571507137629295, 0.13013455896608292, 0.2850392839360622, 1.023042639417033, 1.8021430267441658, 6.978119621353765, 8.441224982661586, 12.590040449173221, 7.652251989610734, 6.441123120246395, 9.36604436366789, 15.184821678746133, 23.62310782555611, 28.715336668875914, 40.31795670909267, 46.72128877332134, 52.66215770475326, 55.729717900676114, 57.01969915820707, 51.75196386152699, 45.03892537086241, 43.72568445820963, 38.62409291728851, 36.95890949618432, 37.86518096923828, 36.574540753518384, 37.22925493794103, 38.37014298285208, 36.99256735463297, 35.20716721011747, 36.86641608515094, 34.93658642615042, 34.954852904042895, 35.36087705243018, 36.97370075410412, 35.195145145539314, 44.28296304518177, 51.39152549928235, 37.71537780761719, 37.65129804611206, 37.45782713736258, 40.866056949861594, 43.85126698401667, 45.94158826335784, 46.5958474528405, 47.19308322475803, 46.220433481277965, 45.84592557722523, 52.352780757411836, 53.68972063064576, 47.59155681056362, 31.415155049293276, 44.69267422153104, 52.559674016890995, 55.07217176498906, 51.4469015213751, 49.27818775177003, 45.51319091550766, 39.73544551480202, 37.56967744519634, 37.5046641595902, 39.957800757500436, 39.899490802518784, 39.11381260041268, 38.997455489250925, 36.66783825043709, 37.89889766323952, 37.78516854009321, 38.69809235295942, 42.219537458112164, 43.139431322774584, 44.598929574412686, 45.72501851666359, 47.08134274328909, 49.73916430627146, 49.28986857014318, 51.436770039220015, 54.61640411807645, 55.7576608657837, 54.87850473773096, 56.93259116142028, 53.73979753063571, 53.48631828061996, 57.87659191316175, 58.12810997809134, 53.023706097756666, 54.27093352040937, 46.732742094224506, 50.93250620749689, 34.971217032401796, 33.83811096991263, 17.156760923324093, 18.442672721801266, 5.376862989317987, 8.292246499369222, 8.81314020003042, 13.282312308588336, 17.68880690297773, 3.731952338449417, 2.12300663513522, 0.15886878564713464, 0.21739264769900232, 0.6214276641126603, 6.523070748775236, 15.78681234390505, 36.369518464611424, 40.474780913322206, 33.13074288829681, 41.191456779356926, 45.41484532817718, 47.10527704608056, 43.326877470939394, 14.171586190500568, 1.2291527731764702, 0.1515872578226751, 0.046100692988763896, 0.04587673484497974, 0.027722858470834555, 0.02610389060611206, 0.09580980565759445, 0.02182730627546628, 0.02569199768796323, 0.06542114315614586, 0.0536792369319066, 0.08772353311219523, 0.06728904937664348, 0.04306302413404469, 0.07018945059709011, 0.07219296204106462, 0.0719589145193177, 0.058240378876366926, 0.07587976017666441, 0.033080664823853204, 0.034467069462182066, 0.03302361808657166, 0.04197293464394827, 0.020161492134174033, 0.012194242839130663, 0.06918284170810254, 0.007710986659907166, 0.06419669716588913, 0.02226425984483813, 0.04712705162443942, 0.034414768639591434, 0.06831267307842932, 0.028646919470761093, 0.036622289297801834, 0.06340594887132607, 0.07029209105718522, 0.05830581427641934, 0.04546964721333596, 0.03695972804580966, 0.0859231498813437, 0.0641545431778556, 0.03643187048334268, 0.07141579648539906, 0.029562216424833865, 0.04921764428276689, 0.05819072871799431, 0.08913945511824663, 0.054342979339942823, 0.03146546036605874, 0.048429201912855914, 0.03664758552106158, 0.031173764728009704, 0.22087987993032704, 8.399431147883016, 36.612925068024666, 52.39037667551349, 56.97434479190458, 39.02841475702102, 32.057662817739676, 36.052069279455374, 42.650707921674176, 26.23596137569797, 9.77826193455727, 2.0119884826483267, 0.2870404588118676, 0.12178200191908306, 1.0041328928162976, 3.458228510233664, 4.818159601380748, 6.897401655873945, 9.236187434965565, 7.890691401497011, 6.755312815789254, 13.815424192336298, 18.418548184056437, 27.125411764267955, 29.963523111035748, 42.60263535284227, 48.83486578541417, 52.967871158353745, 56.05371352164976, 59.019095974583784, 53.80554822183425, 47.30742816002139, 45.206198769231, 41.96156709424911, 38.5245039386134, 38.44511124395555, 39.55047830458611, 40.01718151953913, 38.74716904855544, 39.43549010061449, 36.73733872752036, 38.45222642344814, 37.15761284674368, 37.50148703975063, 37.471080826174834, 39.266624219955936, 36.301163319618475, 46.10577867877099, 51.11969347923033, 39.552729745065015, 39.404825010607325, 39.344640162683305, 41.470411823641875, 45.239017240462765, 48.01496490355461, 46.55368981822845, 47.72283854023103, 48.76671460367019, 48.40665671133226, 54.73658554015621, 55.9471191898469, 47.46760991311843, 33.95775110490861, 48.2618506493107, 53.573116410163145, 56.25401719923943, 54.372742560602006, 52.983733223330596, 48.033737367199315, 42.18998632123394, 40.11281674908054, 39.09191400774064, 41.27844710503855, 41.676218586583296, 41.71409691533735, 40.026355943372174, 39.952309439259196, 40.02148828198833, 40.233798334675456, 43.20136947016562, 45.88629068866853, 45.02868406234249, 46.18924671603788, 48.06380625694029, 48.875525074620406, 51.99736302898776, 52.86167690830847, 53.824175557782574, 56.34770693317537, 57.57079216741747, 55.91408498825566, 54.70002512778006, 54.400022645150464, 53.92006574138519, 58.813269599791504, 58.36021231066797, 54.90740083879041, 54.787533206324426, 51.51710802508939, 50.638748138181626, 41.66010156754525, 35.38348559410342, 25.538030516716745, 20.184010920986054, 12.478435289475227, 14.309753641005486, 10.991836401724047, 15.206278024181245, 13.16872242958315, 3.2841142531364196, 1.5110345184803011, 0.4829550961092596, 0.23659713896772555, 0.7826213274271258, 6.691405148275438, 18.62070518155252, 37.88585578241656, 46.14476703828382, 38.72884765748055, 48.84021982069939, 49.97317291075184, 55.87714410597279, 50.161987966106786, 17.393350447377852, 1.530811721759458, 0.12872679579642513, 0.05275528509950927, 0.08991940923395658, 0.03091571950203469, 0.08484717173081252, 0.06070852647685717, 0.018684495683579196, 0.008168811815971089, 0.023499896464448784, 0.0255667289058047, 0.04972322783883541, 0.018205290449963465, 0.04988091554672969, 0.05115986486235934, 0.020319861660320914, 0.026634540559063037, 0.010208723927667786, 0.037232041659374396, 0.04579661353941887, 0.0304308126590425, 0.0409595420463912, 0.04163955616193914, 0.07504518399195326, 0.03616750120155273, 0.024511965645116665, 0.23762757319115826, 0.18296559100910542, 0.14607196102940267, 0.15815879068067, 0.12345046480937351, 0.09916280396282674, 0.21501265766639865, 0.1692655334068883, 0.13321220994957034, 0.22701552408116482, 0.24597020939953868, 0.09944184382836666, 0.10956593323498966, 0.20091516897082332, 0.23041002903013463, 0.31217745835742644, 0.23415354831564814, 0.17018025771023768, 0.2021344745111081, 0.2284048551753644, 0.16094584919271931, 0.14364059714059677, 0.10296474511344587, 0.16398233061115589, 0.1364828231594255, 0.23388831335450375, 0.45662949582742113, 9.880574018724504, 43.462030579966886, 58.315826769798036, 65.60730895688458, 43.4321185850328, 40.50962724993306, 41.918099387999504, 40.46428857311126, 26.865566507462535, 11.889997393854204, 2.632485748298707, 0.4976076001842176, 0.7385123749413799, 3.0876772970922532, 7.593489981466725, 13.775522901165871, 14.622363601961444, 18.553061946745842, 15.89750849431561, 10.793930272902212, 13.324054171962123, 20.072576384390555, 26.483433515794818, 32.060126066207886, 42.99861431121827, 50.15033852669501, 52.13546183801467, 57.594785305761526, 62.37375405526931, 56.62390847359934, 48.40603697684504, 48.636664498236875, 44.336981927194905, 40.25885443533621, 40.168086867178644, 40.21552008967246, 42.214454066368845, 43.46484684175061, 41.75100249628867, 40.873348636011926, 41.582732815896314, 39.708640037044404, 39.062045158878455, 39.03872274583386, 42.38416717898461, 40.22621247076219, 48.73420599968203, 53.136717427161436, 40.79274000660066, 40.82309522936421, 41.66047419271162, 44.41491157777848, 48.437004089355476, 48.868092183143865, 50.59583348612632, 51.075198111995576, 52.533060735271825, 51.77646298562327, 57.62893738285188, 56.9509360867162, 46.84481989952826, 39.472168184095814, 51.48316383361817, 54.68681850740987, 57.456976752127375, 55.396398805802875, 54.43645361931094, 51.38694417092108, 43.089421103077555, 41.144607990018784, 40.58431310038413, 42.920272811766594, 43.66493871135097, 42.20207506610502, 42.0206654456354, 40.57079269040016, 41.94983920743389, 41.604054820153024, 43.706390319332, 47.335692759483095, 46.95523069750878, 49.08957665966403, 49.5125493695659, 51.76526069641114, 54.133415222167976, 53.96129769663657, 54.42846375126993, 59.55986138313048, 61.41249879713982, 57.00499027006088, 56.491026416901626, 54.3225166105455, 54.15461171057917, 60.16961343826787, 62.790686315105816, 57.565191022811405, 59.61593950948408, 51.27031641621744, 52.711728618990996, 41.36309185335713, 40.45209392424553, 19.939003990542506, 24.32537094239266, 11.778345165714143, 16.102516074334424, 19.3952928819964, 23.134507979116133, 22.741437458222915, 7.152020354424754, 4.9972618875965, 0.9608850231574428, 0.7587640011502851, 1.1447846745291064, 8.546521990529953, 22.300653265368556, 45.86218380158948, 50.74950410473732, 46.18790526543894, 55.193549509971376, 58.76220426251812, 64.16022892921202, 55.76951034607426, 22.40372923112685, 2.5309887816829066, 0.27327523777081125, 0.2033115073197311, 0.13782983555668785, 0.0881112885150698, 0.2672956150866324, 0.19150344174235098, 0.1620695469600539, 0.08843475381933874, 0.15008977043532556, 0.07687891503014872, 0.18064013111495203, 0.17888433420129363, 0.18982316577626815, 0.1676371522367962, 0.14294019359494411, 0.17917874179059462, 0.19380121521892088, 0.11215113523987033, 0.12838892037830046, 0.11968721875980978, 0.12425405273754751, 0.1699865600394626, 0.112466640890606, 0.18611096416509923, 0.21518208567173253], [0.033677504773462014, 0.0777508303402893, 0.03154279119635542, 0.029484615548543876, 0.08262975321662042, 0.017106670570830186, 0.06989132748135636, 0.06985254044975005, 0.035536014925568335, 0.031148006936775583, 0.03558543142712405, 0.053414496097473375, 0.03142924355943838, 0.019899361744342793, 0.015808375619892633, 0.03931570505242675, 0.029983612663683393, 0.015298498141008521, 0.035344232474603964, 0.05878886335619515, 0.03554659076936303, 0.043318365069646994, 0.07023499452418859, 0.02341222727761394, 0.03952895328702946, 0.02717402542100078, 0.020894446755729375, 4.509738241472553, 25.46065195914238, 44.38547811200542, 46.884337779014345, 30.84659964807572, 21.365619051840998, 20.737070998837872, 38.427633162467714, 27.570649808452977, 12.967957873498241, 2.834501050172314, 0.4221021888717529, 0.03759039460771507, 0.04884338351867853, 2.117097584470626, 2.9165874325460006, 5.598568589456621, 9.811822714344148, 5.288679772807706, 4.140082309322973, 17.524110501812352, 13.28534528132408, 21.00682612388365, 28.657817071483983, 37.91759167948077, 45.89393538813437, 52.0879933141893, 53.466506388879594, 58.19565319245862, 50.21562637821321, 46.14388058262487, 40.490309576834406, 37.350452253895426, 37.547637647198094, 38.03165812646189, 40.987540598838564, 49.20143088986797, 49.434172568782685, 47.443640308995406, 43.13186899308236, 38.92078099712249, 36.602366047520796, 37.58166420844294, 36.51896469054684, 36.691313635918405, 36.93662258886522, 40.98035481668288, 40.80511508449432, 35.83030631465297, 37.714075580719985, 41.22602855005572, 47.828711155922186, 49.153734868572606, 53.13831775419174, 49.66441569789764, 50.808826031223425, 51.61029569564327, 53.15396408880911, 55.05121454115837, 55.032508757806596, 49.99788384283743, 28.459168634107037, 46.67115696014897, 52.28292334464289, 53.431063852002545, 50.61764578665457, 46.85535930818128, 41.85025415112896, 37.58027961177211, 38.375273443037464, 40.93759705943447, 40.75527744908487, 38.73721015068793, 36.923792516031575, 36.49970193063059, 37.657311039586226, 38.260473512834125, 37.34883623738443, 36.577929681347264, 36.28760368593278, 36.42620063597156, 37.82875783981816, 38.162045555730025, 39.99945240636026, 43.02434113717849, 47.37847405095255, 48.87036323547364, 49.57669188899379, 50.80824159806775, 52.941642269011474, 55.9700297540234, 53.742570646347545, 53.03570070574361, 55.14419432609312, 57.01247022997949, 55.505542678217736, 52.377170055143296, 50.83302313281644, 45.621711131065126, 36.24315930951026, 28.14222151233304, 23.345874701776815, 12.482905810879124, 14.33250338800492, 14.432465972438937, 8.429861876272387, 16.492252580581173, 14.469336252058707, 3.3149019172114715, 1.4943482654709972, 0.23467067298629593, 0.07336165981307145, 0.7666229600867918, 5.263274090905344, 17.752576797239243, 28.472377215662313, 32.53322274454179, 25.034786501238425, 26.186974894615915, 40.928132380208666, 48.39835305367747, 41.36644547985446, 15.073156702903011, 1.3067037924643488, 0.03979822936197443, 0.07048008903380364, 0.03209986543703464, 0.040481476368562835, 0.051655450971016, 0.06421805186677845, 0.012250225671807365, 0.027782525228817138, 0.07143671834661115, 0.03069487933610236, 0.007204164435426074, 0.009694061272086637, 0.018930363941997774, 0.04268679069355131, 0.09739510970370424, 0.0421111598881262, 0.023805019708590645, 0.019915120172945243, 0.04922133682656193, 0.05125256150119728, 0.03506220103571973, 0.033492080852269165, 0.020949101383467356, 0.0017870261287879982, 0.02130473663489665, 0.045976739962615316, 0.012685936263522074, 0.03854577902764563, 0.046466335263704105, 0.05292628358508791, 0.02653474036994721, 0.024123095584312276, 0.032738529956869544, 0.05086839138980835, 0.14167812502672597, 0.041074060699752266, 0.03555802846207254, 0.06049142865043494, 0.0191205452692004, 0.00938175116560512, 0.0578875111175641, 0.049939525103376764, 0.049959121632479855, 0.05528172433015801, 0.02897495065905875, 0.04567320826613615, 0.059236542156506936, 0.018175665829931537, 0.04115139727570838, 0.012767288097811323, 0.019106196442378626, 0.038600665396980705, 5.399082726047886, 30.424640870863396, 51.29048916601366, 53.63521537473125, 35.75042724609375, 28.405175247500022, 27.542371480695664, 38.45110070320868, 29.02378009211633, 13.318026469599817, 3.1276771378132606, 0.1995805518761758, 0.11968240006676606, 0.1968098723239476, 1.6065813721187654, 4.368922700805049, 7.013511167418573, 9.214174112965985, 10.271290136921792, 7.937266605515634, 14.968439225227604, 18.094009314813924, 26.010736919218495, 30.69864392280579, 42.124443515654534, 46.793911457061775, 52.50025795352075, 54.57124979265275, 59.989584492098906, 52.54422772315241, 48.383542183906805, 43.34328082300002, 39.425189956541985, 39.92742592288602, 41.30950835443313, 44.04943689223259, 49.686259377387266, 49.76271421678605, 49.40843789808212, 43.717133691233975, 39.304973233130674, 38.17708000060051, 38.71556258970691, 37.213337959781775, 38.59209029905258, 38.67029843791839, 42.180313756389005, 43.43554673656341, 38.41286151639877, 40.664121566280244, 42.60928769265452, 50.202204027483546, 52.00729447026407, 54.9070752820661, 50.91507127208095, 53.67203466353878, 53.413624994216434, 55.5666139818007, 55.94366750409527, 55.54887310151131, 51.78603356884372, 30.58610131663661, 48.239151893123505, 53.542345416161325, 55.27492692393642, 53.49557115185646, 49.73171572531424, 45.70327289642827, 39.445762788095784, 40.29654449032199, 42.11870901046261, 42.84543791124898, 40.682497870537546, 39.90124017961564, 39.232950672026604, 39.82188670865951, 39.5472619610448, 38.95630198140299, 37.890770512242476, 38.532317299996656, 39.41114394895492, 40.882048453054125, 40.75070396546395, 44.14637434867121, 46.528861215037686, 50.28145943918536, 50.72173372391732, 53.59744687234202, 52.644036354557166, 55.29281293192218, 56.93799226514755, 54.542824376013975, 53.163409156184045, 55.227250514491914, 60.65591281460178, 57.511368259306884, 54.20114278793336, 55.14126823794458, 47.664920822266616, 42.76191103842951, 31.591141992999663, 24.325035579742927, 18.99362256450038, 13.776984964647601, 13.37549017321679, 8.322576226726655, 13.180883738302416, 8.001900401807601, 7.758289835145397, 2.480816028771862, 0.713720360109883, 0.20864108907839946, 1.1419962370587935, 6.440253824956956, 20.344259354376025, 33.669409828801314, 35.79889205194289, 30.120486559406405, 33.66016087993499, 48.884923073553274, 55.427008982627626, 47.86275340664772, 18.41660661082114, 1.7696237588121047, 0.0860032596955857, 0.022547643428908724, 0.06119726375947076, 0.016732009525801388, 0.04882062304644816, 0.014503499973685512, 0.01694491110561836, 0.05727198628348209, 0.04817253181470498, 0.043725268840188944, 0.035839224865119305, 0.015503773315539284, 0.069020522998706, 0.0377065718414322, 0.05459719412629643, 0.02361231412167751, 0.03507504833020991, 0.046506022448621454, 0.06007476491973766, 0.03199971093225383, 0.03220839328282783, 0.031218354875642448, 0.030448028569920894, 0.033430487383157015, 0.049908498542443405, 0.1872635434471792, 0.1482371553297966, 0.15910857116743443, 0.12296153217433922, 0.1345499526829489, 0.12566540119869093, 0.22929788386869818, 0.19725424928530572, 0.16079082364036193, 0.16496753500353906, 0.11997170551049134, 0.1707306918838332, 0.13356810375567407, 0.0637664966615698, 0.14089663873516745, 0.11972963704817718, 0.1231576277003173, 0.11331576508499923, 0.13059356820679482, 0.13419269524033994, 0.11449484334838007, 0.1938021498461885, 0.0850042350770485, 0.10344721962727847, 0.14279097498905274, 0.1057393087314502, 0.14551728272870665, 6.618079379681618, 36.42470621293591, 57.9128973714767, 60.21105327913838, 41.985803419543856, 33.58662036157424, 30.70649846907585, 49.18978929519654, 35.690171795506636, 17.13107135988051, 3.622159068622897, 0.9500948892485712, 0.16238606384684964, 0.9428447557072487, 3.7637853141753905, 10.285514612351696, 12.730111229804255, 20.597877848532892, 13.505817786339792, 8.9796144154764, 24.888507589217156, 16.095953949036137, 26.769148765071748, 28.87089590872488, 43.62857049511325, 46.305745032525834, 53.805273655922186, 55.74040635939568, 62.73229791272072, 55.26023372527092, 52.06011702937465, 45.57887492641326, 41.51722138927829, 41.9858112642842, 43.35899776028049, 46.63580463778588, 54.134454650263635, 52.453562136619325, 52.70106369449247, 47.64819583585186, 42.81144272896552, 39.262701849783625, 41.50830976424679, 40.32177317527033, 40.34926114543792, 40.61114211236277, 43.50467066611014, 44.38043394396382, 39.751531154878684, 41.91585971463112, 45.61895762720416, 53.2418800938514, 53.06265131119759, 57.114906849399695, 54.1081630029986, 55.4988040462617, 56.48705697828724, 57.16449345311811, 58.595072069475734, 55.10768490452921, 51.68402056540213, 35.38156363271898, 48.60670151249055, 54.470444879224225, 58.19237801336474, 55.2991436373803, 52.90428169312016, 46.554733168694284, 41.23079422981509, 42.39293367631974, 44.298672137721894, 44.76732869302073, 43.3059359365894, 41.64583590722854, 40.582053815164876, 42.240267184472856, 42.731108665466316, 39.91767491063764, 40.483182630231305, 40.12816498356481, 40.81762352297383, 42.35482000535534, 41.813905546742106, 44.152497168510195, 48.15808434640208, 52.6444560481656, 53.46432555106379, 56.63060788185366, 55.78700019467262, 57.888327644717315, 59.598328067410385, 54.29292624996555, 54.07817256066107, 56.25201286808137, 60.24005136182232, 60.38727360387003, 56.65012951820128, 58.38057725660263, 50.20198045238372, 41.32488012313843, 30.68923023439223, 29.088416830185924, 15.950454608086618, 17.640610779485396, 23.422749234784035, 11.372856420855369, 24.561383878031087, 23.939021402789702, 11.439471014084356, 5.638252679378756, 0.8621294255698881, 0.776295586218757, 1.3669178130165225, 7.524135122376104, 24.02178537461066, 40.448022504006666, 44.424839096684615, 35.314306751374275, 39.44043620940178, 56.779861911650634, 65.90325570875599, 55.49124956130982, 23.49130834302595, 2.233580456626031, 0.2611689341645087, 0.13461194451778166, 0.12654530680588177, 0.10345563893356632, 0.13607377817313518, 0.20759409203404383, 0.16124969498524744, 0.18641389065211822, 0.11790020376323693, 0.08388721759641364, 0.1342255144470161, 0.09080765753864281, 0.1465386924363913, 0.11149138031947999, 0.1848668986631017, 0.1664355280058038, 0.1642439343155392, 0.15205544479671987, 0.18092176035767604, 0.08158100183091818, 0.11656564795562338, 0.09555969327207535, 0.1492322269346445, 0.09724936913698913, 0.13071125463372277], [0.04288111272598467, 0.0828007593630783, 0.056650007158638015, 0.02775594963872385, 0.03479167240701857, 0.0695519275482624, 0.07468427997082472, 0.045298108635770704, 0.019692081334670226, 0.033863097233998204, 0.04671598799646862, 0.09287954232985936, 0.03531130984605801, 0.04167660417395734, 0.04447638740642898, 0.03542104811077157, 0.0733611312124037, 0.06838651629345072, 0.02740726471998759, 0.030301521915281494, 0.01957775420329023, 0.061084388364707275, 0.04602008521737111, 0.04478428580407654, 0.0863194318428155, 0.09504760945996932, 0.020646515805574677, 2.7825232715375963, 25.125936500487793, 40.542798734480336, 46.293318963819935, 33.17434395513227, 21.812239731511763, 28.269037623559278, 34.35503229018181, 36.71577745868314, 13.291926037880684, 4.184608565222833, 0.4508499446655474, 0.1600303281579287, 0.3430900254076527, 1.5327494951986498, 2.5571661899166727, 5.689015013556327, 4.492037565477433, 7.41671169957807, 6.625724079147463, 9.134988323334726, 12.731921403638779, 19.618997420034102, 25.126001219595633, 38.8163439689144, 46.384627819061286, 49.99216110475602, 53.54143934865152, 52.98493739097349, 47.729518336634484, 46.665814691974276, 40.22527502429101, 37.05828274449995, 37.293903443121145, 42.24287948300762, 47.57407088433543, 52.70275423603674, 53.328066333647705, 50.749672766654726, 49.593714975541644, 48.57545591169789, 42.96883567687004, 37.43897622631442, 35.19598845512637, 36.453523866591915, 36.66140948572467, 38.01237575469479, 37.01232041082075, 38.37725816234466, 37.920419708375015, 45.97832126002158, 51.853678764835486, 53.63522714184177, 52.842539664237734, 56.737555226972034, 51.35070539289906, 41.871493785612046, 44.96218419844105, 57.74234879401423, 47.765725735695135, 38.29053063546458, 26.087187836247107, 47.317571409287, 54.57816885363672, 49.8579179856085, 48.30323949936898, 46.43850157337804, 40.22376491177467, 39.332033664949485, 38.2127578796879, 37.413367071459376, 37.17089791451731, 39.433211203544374, 37.2577941033148, 38.91984747302148, 40.288974315889426, 36.26457152828094, 40.440040480706, 40.040739274794056, 36.26273585904029, 37.10322526193435, 36.38009709696616, 36.40056794689548, 37.974383677205736, 40.30900193798927, 40.23344924373012, 44.57080225790701, 47.589226922681256, 46.24800774358934, 47.44858641778269, 51.97240890995149, 57.29364533578196, 52.32995256300896, 55.47868620964789, 55.09012445326775, 60.16620097621795, 54.25920171122397, 49.53913911696404, 41.133374321845274, 39.69639831973661, 29.574006257518647, 21.08410466101862, 18.929948768308087, 14.812677983314762, 12.123769675531696, 10.428748784526702, 12.108595986520092, 4.451774435658609, 5.117227089020514, 1.1101524748148457, 0.3621740723329206, 0.30373023582562325, 0.8283924455604246, 6.74026366203062, 18.342418901381954, 31.090220020663356, 39.71994430788102, 30.112029929314893, 32.87186449573886, 45.14119725073538, 52.88171237514865, 38.59083906296761, 12.959358076895438, 0.83989835073871, 0.11163786399148165, 0.039089892975865834, 0.022856706280201193, 0.022333556328028924, 0.04788136094688408, 0.05287348863578612, 0.05557076547354941, 0.034789623121821114, 0.0263941019488078, 0.035278184204212124, 0.04170986005075036, 0.15355872380877697, 0.047550568011619394, 0.039158902176085024, 0.050380404873360554, 0.09236718272610057, 0.08558297619944619, 0.008143174683585042, 0.02015730737888765, 0.07476498733364767, 0.050098607091293226, 0.04115213655055531, 0.02974293848139144, 0.02162205216835343, 0.026302006688990423, 0.0908842739919501, 0.047148620829947537, 0.016043454487507623, 0.0324626004083022, 0.06581496597538072, 0.10445444904748472, 0.034860773537788665, 0.011416719137360493, 0.033960585752802516, 0.06268169317815094, 0.07331077625314075, 0.0015932870413845166, 0.021475599139868733, 0.01792690367437899, 0.08998253487891729, 0.05109195882875112, 0.011217118759128836, 0.04853603287389682, 0.018186879441923192, 0.03351022564475575, 0.050968312237772255, 0.06840837278193043, 0.04186881563415931, 0.015659071786719707, 0.04322974018812661, 0.07821019198144637, 0.09644300797052922, 4.06136842985307, 28.085837441105998, 47.503166198730476, 51.968972913680545, 38.304886510295255, 25.019630462892597, 32.19822291404971, 45.82174808748307, 40.17957156704318, 14.827340783611422, 4.858471270530455, 0.44651980121289536, 0.17747324621004446, 0.16986950180463253, 1.8352945317183773, 2.7784194917448106, 5.840213558366222, 7.5871014210485646, 9.529374799420758, 8.304810831623694, 9.451503984389767, 13.331864591567749, 21.502941231573782, 29.412118273396647, 38.46296979535011, 49.16780833275088, 52.47229929893248, 54.367466972720244, 55.186042093461566, 51.868532780678045, 48.590255014358036, 41.961469034994806, 38.14964694361533, 38.190478817109145, 43.655772132258264, 50.256905401906664, 55.72983164941111, 54.45728924966628, 54.51053542475547, 50.24740542134931, 49.02797975847798, 42.925011034934755, 38.53498058934366, 37.83386084341234, 37.49224593562465, 38.638142847245746, 39.85705860199467, 38.24073222375686, 40.43328615926927, 38.88742516117711, 48.7679736844955, 53.83117306616999, 53.951609442310954, 53.69326645328153, 57.746059356197236, 53.31151000915035, 45.66461401600992, 48.42332678456461, 58.348151022388095, 51.61674014983639, 43.20870430238786, 30.08296516633803, 48.08766603469849, 56.73382897530833, 53.247983301839525, 50.33489388804282, 48.512113555785156, 41.91993505724015, 40.12115178569671, 39.998220782126154, 39.626807628139375, 38.376053994701756, 41.45943310952956, 38.807047951606016, 41.448556377041726, 41.08503503184165, 39.28186262807539, 41.008164421204604, 42.010498662148755, 37.58226040870913, 40.79454429687993, 39.03454934397052, 36.813632749742084, 39.42957908876481, 40.765699186632716, 43.26963047827444, 46.101346400476274, 49.37938097984561, 50.237666176211455, 50.17201354426723, 55.42685993256108, 57.05745981585596, 53.11458349227906, 57.01440003610427, 55.532889443059126, 61.14202391716742, 57.17756279053227, 52.79647142656388, 46.01616820981426, 42.04943995321951, 29.931371442733276, 23.341003118022797, 20.73782409391096, 11.856529770358918, 17.363542395253337, 12.787723002895234, 11.272601619843515, 7.1914416455453445, 4.004976268737547, 0.8295725273989862, 0.10876694183436134, 0.15262133862462737, 1.0238459285709167, 7.164970549844927, 21.489569871656357, 36.16705748342699, 46.368946183112364, 33.127146074848795, 35.897445524892504, 51.310638381588845, 61.22937117853473, 44.85810802828881, 16.44307194217559, 1.131225898861885, 0.1510997041459045, 0.03701853295487743, 0.030501568539729042, 0.016590976569380973, 0.03452169536162288, 0.0467011297211772, 0.025785920067480015, 0.08023909924011077, 0.05692614355094491, 0.004211961941403007, 0.07495710686329873, 0.08291101473714076, 0.046179017818142334, 0.04772743473069803, 0.033486779523833145, 0.07137789811578489, 0.013866776529128754, 0.03070496488362551, 0.02269998767353114, 0.025078650458805987, 0.05251282210191412, 0.02325501454423272, 0.03211447664897048, 0.060344921995795546, 0.02767693724543337, 0.15224678291668817, 0.14146096974370942, 0.12306006640316018, 0.20534217658062137, 0.1685371523302409, 0.2473809296685842, 0.12386701745732177, 0.14864371819121225, 0.16269217725963364, 0.16625198866090468, 0.14924891232963533, 0.17538478327614648, 0.22625712767964412, 0.1322864846236283, 0.24316813556417344, 0.18870195013380822, 0.14254640908010546, 0.13735784878653867, 0.06201257666332587, 0.1469612818571829, 0.09550726221453759, 0.28253552473841176, 0.12705018939149956, 0.11980823000832913, 0.1578842707338833, 0.31165627342077995, 0.16120728435775927, 4.937734036676345, 32.411860689040154, 54.47576361317789, 58.97262373278218, 44.66520978558449, 31.778158641630608, 38.878027162244244, 45.524157862509455, 44.91587277381651, 19.269502470570227, 5.365329259826291, 0.9017285103759459, 0.3158093279888553, 0.9690808769195312, 3.88298933063784, 8.067258365692632, 16.077593334259525, 14.432596391247166, 15.365514486066758, 13.939463265480535, 15.265765670807133, 21.99245499026391, 27.269229389006092, 30.44074808397601, 42.3702702214641, 50.85054043800601, 53.57998448033487, 53.49276273481308, 58.09719385639314, 54.73605209781278, 51.74814739534932, 43.64962577819825, 41.70298876300935, 39.62569759738061, 46.188364182749105, 52.437982482294885, 57.90713933206374, 58.426645494276485, 56.865028335202126, 53.090986513322406, 51.51691582895095, 47.20016702528923, 41.9172364665616, 40.17046382350307, 38.94681376795615, 40.25088025677589, 42.734199493162095, 40.106576258136386, 41.44549692830732, 41.18971916937059, 50.9255910688831, 56.388495660597286, 56.75765737410515, 56.68939244362616, 60.10310572962607, 54.305909295235914, 45.59207370204311, 49.61722566235451, 56.897689911627005, 49.40775540567214, 47.19894716816564, 35.637062903373476, 48.622383148439475, 58.354713147686375, 55.65040365342171, 53.08172187497539, 50.44976442090927, 43.697792483914284, 42.478076565650206, 42.653026042446015, 41.05579768457721, 40.545450256716826, 43.62951186395461, 41.50862355386057, 42.445932742088075, 42.7238562030177, 40.0234337775938, 45.639149988851244, 45.55238716063961, 39.844008876431374, 43.55274323494204, 41.60312129605202, 39.701952395900605, 42.134979001937374, 43.19849829519949, 44.46602398349393, 48.6577864616148, 52.60760538039669, 53.21840470837009, 52.879119688464755, 58.29959600202499, 59.89071722953551, 53.34872545734529, 58.247032319345784, 56.35290799602386, 62.929463694172526, 59.85700838027462, 53.74277853196668, 46.44332216631982, 44.8583080691676, 31.11866504915299, 29.344202433862996, 27.200295694412727, 19.78089717126662, 25.06483577912854, 19.297986722761586, 25.29754411789679, 12.960639711349243, 11.127601400498422, 2.335560365069297, 0.7049371314144904, 0.8768172309763971, 1.5460621421375584, 8.982897439310628, 23.940054947330108, 42.484352357925914, 51.151182266973684, 41.87752639093707, 45.51457551217849, 60.3625391375634, 70.28910098537322, 51.19330067788401, 19.787678949294552, 2.317329433656508, 0.25091798825850414, 0.28061644384457224, 0.18709523393021477, 0.1933330282448761, 0.14515935112872433, 0.17456500791013244, 0.09767871545327288, 0.14632699169939564, 0.08608619637426831, 0.12938069780507397, 0.12235010208021249, 0.3521501182788803, 0.10341859858242736, 0.11712430225264643, 0.14438794655424936, 0.2524527841277661, 0.20426384654016266, 0.09296652395278217, 0.10711792225558912, 0.13269295555449304, 0.17471989556666345, 0.16086461322922863, 0.07765690029989328, 0.14802209912769257, 0.2017322170638269], [0.06390200612405617, 0.023441256264284737, 0.02112463319433793, 0.07547947923622786, 0.03579634692399733, 0.03366186891892745, 0.07107753802331225, 0.038420420230155995, 0.026133760374279755, 0.07177266322316662, 0.03326304354554704, 0.027424377208996206, 0.07015725958251184, 0.055471817557249344, 0.01752950130931793, 0.0142545108645854, 0.03545520797131523, 0.03579175805733089, 0.020691632638655363, 0.024105274463973703, 0.06400829699311046, 0.013873767081437813, 0.03321587551204908, 0.011472488423028301, 0.06712558919623976, 0.03975174697716871, 0.06999342401902522, 2.3093425073931297, 16.765406439381263, 42.90849785650931, 45.05202216486777, 40.94114680444041, 29.555518165711437, 22.632426946393906, 20.656172114033854, 39.26021506709438, 20.056751581930346, 6.5445829879853035, 0.9105681231425655, 0.4835438193573106, 0.14824680803764254, 1.6705293665009162, 1.7738388358585297, 3.998643356946207, 5.762624173395096, 8.723348321453217, 7.88334382157172, 6.12422110572938, 9.560084016092363, 15.012708075584905, 23.97832943547157, 30.47795176506043, 40.02868190888436, 44.9319701810037, 56.78385488448605, 54.08961019208355, 48.558236706641416, 47.11795022410732, 42.98724336008872, 38.99453332347255, 39.64734123599145, 42.75494098663331, 50.651868466408025, 54.044475478510705, 54.30759591441001, 54.53809007521599, 55.25287535882766, 50.62765959770449, 50.99431883904242, 46.731157456674886, 41.17109967816261, 38.27945778446813, 37.625045622548754, 37.57423916170674, 37.34281147679975, 37.7240187891068, 36.74596401952928, 45.191266305984996, 52.64269490395823, 53.84277151476953, 53.815754229022616, 54.009939009143466, 48.95145039404593, 49.42415483536259, 46.38316085261684, 44.14774325586135, 44.16899465745495, 50.47363596577799, 29.128007273520197, 46.69948431753343, 54.45759127216955, 45.894339392262125, 45.29225164844144, 39.379333526857444, 38.15875468715545, 36.59328968294206, 35.56871952549104, 36.93765809459072, 38.743372194228634, 36.96115309192289, 37.755366371523955, 36.57592535018921, 37.15245100759691, 37.744670068064046, 41.04830595754808, 41.11307213383336, 39.38940225108978, 37.243363703450854, 36.53173200545773, 37.72370107712285, 37.61415320058023, 39.10490489775135, 38.49969886964367, 38.40495794050155, 42.08841262325164, 46.19670314173545, 46.527708038207024, 48.40979460747012, 54.914916100040564, 55.40544771379041, 53.22442162421442, 57.04036220427483, 54.35100086273686, 56.69333442564934, 49.809362965245406, 44.090668847483975, 34.989067739056004, 25.302325487136844, 17.365293733535275, 20.073033340515632, 11.30327945755374, 9.908008056302226, 8.894270504674605, 8.715184888532086, 4.363049932064549, 4.498805124913493, 1.8483198650421637, 1.3755596525246099, 0.15880337706015957, 1.4319812314164255, 6.496996793054766, 21.711654470812892, 30.943978371158725, 29.43707827598818, 33.50849851485222, 37.94038065018193, 48.81686995106359, 58.95687933891051, 37.17298461544899, 12.585713094280614, 0.9302780332584536, 0.03413480180766314, 0.03812631907602472, 0.02761566744846923, 0.008773832627001309, 0.02418505869084789, 0.026155172531763395, 0.015185241617502706, 0.03820571259805753, 0.06134907940342542, 0.05095529640393873, 0.026604419897100138, 0.02501966551907601, 0.05023670210052402, 0.033295621434527065, 0.015053075171195933, 0.02227730249174901, 0.02643152342868909, 0.04002248244960943, 0.04875232247755893, 0.03571048378944397, 0.0113520038599569, 0.02970799721116501, 0.13154806779517283, 0.022074789064185276, 0.048729458583458785, 0.05029129735644787, 0.04558694676586217, 0.031939364271238446, 0.08522409465043776, 0.01930502881746619, 0.013604596343582437, 0.030826590917704087, 0.05717544005282464, 0.01418454884251039, 0.010468421030729529, 0.04275058666544576, 0.04206230646119483, 0.043018242464430874, 0.08786670728436402, 0.04563417608639406, 0.011183864797555633, 0.03269224675492414, 0.010473848763673056, 0.052312712275212815, 0.09984534999896442, 0.05676988459702942, 0.04600883904664267, 0.011078149452054454, 0.04464961520786728, 0.04464909809851839, 0.04720266067212628, 0.030159918223357493, 2.867926263040112, 20.748936168609127, 48.213656487003455, 52.632857599566066, 44.337856615743334, 32.30576645943427, 24.494207405274917, 24.207968519579982, 44.0212546625445, 22.306136738869455, 6.441951230649026, 0.7661060652425213, 0.3672341137163101, 0.23873527504263387, 1.1171027921861219, 2.2405357995340904, 5.28542616674977, 7.357316718947503, 9.77403263891897, 5.889765841345634, 7.41580072910555, 12.038521862799122, 16.901314604666926, 25.863008691418557, 32.27741556782877, 42.68986886547458, 46.08000870673887, 56.92985726941017, 55.904592852438654, 51.501771557715635, 47.40437346120035, 45.53237915039063, 38.63384000716671, 39.71005601267661, 43.89337362781648, 53.09928232623685, 55.75484852637015, 56.18838810151624, 55.84865593141126, 56.59966430356426, 51.74660198150143, 52.5886328758732, 47.089073734898726, 42.51608825499012, 40.24816597661665, 39.96605342434299, 39.789433017853774, 40.13094202164681, 39.83093169427688, 39.076663832510675, 47.58359832148398, 54.009978232845185, 54.80049271737376, 53.770756798405806, 54.87713190817065, 50.03557782019339, 49.85633727042906, 46.21006273454236, 47.33120556800596, 46.28485841135825, 50.06197537145307, 31.494918407932406, 46.869185663038685, 55.82064236364057, 48.33606189297092, 47.873637983875895, 42.11825401552262, 40.589059168292636, 38.52132289640365, 37.46620139768047, 38.22302664479902, 40.231750857445505, 38.685882014613, 39.592753610303326, 39.09420467192127, 39.24466286936114, 39.57468325091947, 43.36945872153006, 43.725260842231016, 41.420672247486735, 39.26869915377709, 39.14208112224456, 38.26929100098149, 39.75081336113715, 39.30831901488766, 40.261188245588734, 41.135139388422814, 45.030531498693655, 50.30103991108556, 49.285628487986905, 51.88005278187414, 55.151082008115715, 55.40274520074168, 53.8858469840019, 56.48007515938052, 55.805843260980424, 59.86413140450755, 52.58621277347688, 44.4016186652645, 35.674219516015825, 29.28550808660446, 19.752181499235093, 13.719659524579203, 10.990619486378087, 16.154298224756797, 13.79462778568268, 7.6900464777023565, 4.477634622204689, 3.2686348643995102, 2.8428051981233784, 0.17375120802992777, 0.044381951748002926, 1.689783668806476, 8.116318881511688, 22.913896229959306, 36.60109912195514, 38.82410241711525, 38.94967317581177, 41.779349465524, 54.98673862026584, 64.37525718442856, 42.8962992852734, 15.545108049146592, 1.352362510177397, 0.011664892362821247, 0.009111112411764842, 0.0256175933135373, 0.0534563628025353, 0.026284591595251715, 0.0531023727249234, 0.05705321072450569, 0.09162490481450673, 0.04081401215385526, 0.029255752526824514, 0.026284582019152663, 0.07766202542810671, 0.030746410240329085, 0.025696155630172263, 0.04486160322783455, 0.0012143953954951178, 0.01372370865165947, 0.028533189887962038, 0.020772565997415976, 0.027988545423854264, 0.03597063575721076, 0.05207798293521328, 0.050039365512108615, 0.024235735407039046, 0.04673015296218857, 0.18956877862013158, 0.16933054362814273, 0.15519848904542385, 0.16135394422998353, 0.12019951707653462, 0.1517377174910038, 0.21444527762791804, 0.11971209363471116, 0.1351469496805822, 0.11414282594717319, 0.12683026853107637, 0.07842206891866461, 0.17811577947389695, 0.22465670871878826, 0.06919852352791256, 0.15005702783744182, 0.12696959694186527, 0.19498379450411568, 0.07201241809994945, 0.13788822677827653, 0.14719665471103885, 0.16004276942581902, 0.13787964659352459, 0.10687950803267379, 0.14512830924603248, 0.14275286977569904, 0.22967754172221308, 3.875433865093416, 23.48636615660883, 55.72132402850736, 59.86539048533286, 53.39436223430019, 41.57962629871984, 33.10980527631698, 30.104159693564142, 47.17108657283168, 25.651912612299768, 8.596398849641124, 1.253316657197091, 0.9745468836157554, 0.9194220770751277, 4.485954949932714, 7.063581693557001, 8.592551004502083, 14.962438979456502, 17.364538677277103, 17.520146946753226, 11.529638459605556, 15.54808512810738, 21.75816397513113, 27.714638056293612, 31.378539723734704, 44.35013363438268, 52.803155145337506, 61.03157781785535, 58.116739026961795, 55.17932699572656, 51.43430286838163, 47.88856652475173, 41.94450478399954, 44.13100650233608, 46.20039801443777, 55.79829662076889, 57.82381642249323, 56.61829948425294, 57.38611129022414, 59.582944531594556, 55.320077326989946, 56.39576773489676, 50.182258775157315, 46.164025875829886, 42.92384609099358, 42.72575855255128, 41.98285771954445, 41.238662504380756, 41.18947990479008, 40.63016953006868, 48.66478789237238, 57.2477065363238, 57.20976544964699, 55.38968763043804, 54.106339100868475, 50.81259935132919, 48.71187986866121, 46.55926742861348, 48.2530802296054, 48.17972014027257, 51.76203258575932, 34.581011802919456, 48.587654482933786, 58.14581555704917, 51.57696731628911, 51.02518789229855, 45.54105151084162, 41.7870569229126, 40.7329434733237, 38.54830880318919, 40.377957205618586, 41.989694410754794, 40.24703633400702, 41.98574458399127, 39.78443591825424, 40.951184149711366, 42.3912117558141, 46.29484476581697, 47.29764184644146, 43.82756410106536, 41.62377649737943, 41.62495320843112, 40.5926912830722, 41.67726193704913, 40.98876437833233, 42.938437308034594, 42.30476271721625, 46.161068408719956, 53.076014826374674, 51.54453323733423, 53.27386702260664, 58.79088071084792, 55.805180380421305, 53.892475789593114, 56.427742896541474, 56.491759900123846, 61.01424878643405, 56.85115883427282, 47.855657839006, 39.77578316965411, 28.197624991017005, 23.642876571224583, 28.003436288525982, 17.172128769659228, 19.958784503321496, 14.26970918332377, 18.73345567334083, 12.311109919701854, 10.447758551566832, 3.8621009934333066, 3.2829306779369234, 0.3107159771025181, 2.1860859470982708, 9.284442394010483, 28.15298841845605, 40.46134679548202, 42.352262620002996, 46.52550758854036, 50.23106482721145, 62.390318224507, 74.32303121013027, 51.1188344801626, 19.168268057607836, 1.9559345033860978, 0.22478564131644466, 0.1392958980173834, 0.1254970533773303, 0.15575776387366558, 0.1325223171302388, 0.15657729409154386, 0.1471658426547243, 0.18232449799055056, 0.15733230438443924, 0.12047503293762285, 0.16364231014684325, 0.16734162615912576, 0.0913005278656079, 0.1250058071567647, 0.1714536184144597, 0.10600274338597253, 0.10192534000041986, 0.11394097710088377, 0.10331148416885447, 0.1517034120737545, 0.21006046614098936, 0.10516238323743306, 0.19431928983859478, 0.09354861287940895, 0.21244443983079928], [0.059207672133080425, 0.032319928023723826, 0.046057880165115486, 0.06511973352321694, 0.03404675532252558, 0.08875276457758681, 0.019197362820587812, 0.023992232445086685, 0.03683061158705143, 0.006825850108608364, 0.0836598427004872, 0.06315918429003609, 0.020150897138181235, 0.15725191111766523, 0.09166261166213982, 0.007868240570514313, 0.06733036449839992, 0.02604251738727814, 0.013892000931645594, 0.017119048636466745, 0.05599120218727378, 0.03702823928887806, 0.03560932570948236, 0.07133479800916488, 0.07280693554709997, 0.05521049730539803, 0.08248916842163571, 1.6929378672953577, 12.333525284644097, 39.22072072182932, 51.29187376268449, 45.11554887217861, 37.08055788470853, 36.97064915011006, 46.255095466490715, 37.9921833930477, 22.84827889934663, 8.384232944057834, 1.480871124132987, 0.36001974115929297, 0.2745485065444824, 0.39946205373252597, 2.527173541245922, 4.734732749000673, 5.80660718102609, 5.475614541961301, 3.0847960710525517, 5.7400269085361115, 4.221417557808661, 10.604784757860246, 19.926752467309278, 23.823021227313628, 38.20226161710678, 49.5684588340021, 52.62730352340206, 53.654038829188195, 51.558520409368704, 45.44841689448203, 42.86406916956748, 38.75651997904624, 38.30006591735348, 39.28149784764936, 46.22839981509794, 50.99171046287783, 55.411692127104736, 54.27533834211288, 53.66043229256907, 53.75261975872902, 48.89937700763826, 50.12121100579539, 45.79497398868684, 41.60287026436099, 38.5250569928077, 38.57709900025399, 36.44299230267925, 37.17696582117389, 37.502298970376295, 44.559423462037124, 51.94798431088848, 53.60279698525706, 53.342614404616825, 55.80293678468274, 55.8113581134427, 56.29813601893764, 55.70457943024174, 55.009119664469075, 50.4679524513983, 56.95272860988494, 33.0964417611399, 46.95339502826814, 55.87298639359013, 47.954901649105935, 44.35404031507431, 37.03366202692832, 38.98145614131805, 36.97237891535605, 38.283846916690955, 38.25947330844018, 36.87108370565599, 36.95680710577196, 38.111129268523186, 37.10109933730095, 37.967507762293664, 41.50574061178392, 43.85025109014204, 45.86026576257522, 44.56777811050416, 42.573115594925426, 39.31050377507364, 37.227297675225046, 38.180625823236284, 37.273205095721835, 39.298622915821696, 40.332194912818174, 40.191636777693226, 43.53722241617019, 46.81053446185204, 51.55127186929026, 55.01423051280361, 56.04053435787078, 55.231380770283366, 57.035608291625984, 55.742834306532345, 52.196964602316584, 47.25025177001954, 36.07399532871862, 33.949416068292436, 30.21129531245078, 21.580274681891165, 8.72521831143287, 7.549421171988211, 22.170924794289377, 19.917279943343132, 3.1928634980032524, 3.2782809532457784, 1.4471438887619203, 0.9413407718943012, 0.24084313532277463, 0.1785424904477212, 1.7180394429352976, 7.835393336511428, 21.457398591503022, 34.39851960828228, 28.74814533418225, 31.388579030190748, 45.7211628267842, 47.66244188431771, 51.45623284001505, 39.9702032919853, 14.064255433697856, 0.7925929729976963, 0.05225239434249459, 0.006165657560491274, 0.07394521962851286, 0.03967827531479059, 0.046356122024477496, 0.03926605106361451, 0.032106631908625845, 0.034186225459580465, 0.033002646429644476, 0.03535815229218814, 0.06320177494818646, 0.00862304449847509, 0.038116850229280616, 0.031763292368381255, 0.03428803854471734, 0.060142770544776035, 0.05767306778579951, 0.06538803283605846, 0.06855982070368144, 0.012681862590984713, 0.060168085920233885, 0.012414604200110322, 0.06273227030291192, 0.031594841125150847, 0.08043223000582188, 0.07630037309061136, 0.051596397083372846, 0.042223518173540794, 0.02733391754689717, 0.016365348353921887, 0.05874909573204576, 0.011776362943853582, 0.05598587404576041, 0.07899539379943764, 0.05236168061533282, 0.050414369381483526, 0.1359028639572282, 0.020846311536227024, 0.06753228229260252, 0.029599337215204875, 0.02844620634981942, 0.027860363592363657, 0.05257872864603997, 0.029089105420655785, 0.016897344706399788, 0.10039945373371725, 0.011196708261606195, 0.05856979668380753, 0.030091627230567318, 0.02627654767204677, 0.047641414548120195, 0.02152622989078443, 2.006976919308786, 14.798789851127134, 46.12060523802235, 55.87334332927581, 49.04276317165744, 39.65892007274013, 37.25484840331539, 42.64061174085064, 40.21390799553164, 27.959464557709236, 8.434486350705548, 1.6979678167450813, 0.21985529861863584, 0.18095977364047883, 0.7781637375873904, 2.577597325847995, 5.583467954589475, 6.174665727922994, 9.637561613513578, 5.359321659611118, 6.220750145373806, 8.054071357173305, 13.728336787992909, 22.837009929841567, 27.57427800086237, 42.087035871321156, 51.53699444186304, 52.680922323657626, 56.16692489193332, 53.74387679561492, 49.46128006904356, 44.70651626586915, 40.57303236376855, 40.53128657802459, 41.338875139913256, 48.211714913768155, 53.275047656028505, 57.25379797720141, 54.98316534103886, 54.18767336876162, 54.97503034530148, 51.65685030721849, 51.86256293327578, 47.52057759992538, 42.619901626340805, 40.17679060659101, 39.88824536723476, 38.14091182524158, 38.4071623125384, 38.228812140803186, 47.62939983798612, 53.49919934426585, 55.27669591288413, 54.90323135929724, 55.36361955827283, 55.299375057220466, 58.303581130120065, 55.44072551112021, 56.44018857709823, 49.92228408013621, 57.1633049749559, 34.41752741413732, 49.08305375806747, 57.04426496259628, 50.49497365951539, 47.76156410094231, 40.08011594895394, 39.483613660258634, 40.047120971064416, 40.37281890069285, 38.91024551083965, 38.08974058397355, 39.25279786509853, 41.28592314258699, 38.81811295786212, 40.081547614066835, 42.87744445185508, 45.637510438119214, 46.7600025669221, 46.430648988293065, 43.37367919183547, 40.17888122989286, 38.838815227631606, 40.022821887846916, 39.859196293738584, 40.58031228280837, 40.88836346903155, 42.44443047431208, 46.167434415509625, 49.39725914309102, 52.610947239783506, 55.64195094570037, 56.57398846841628, 53.462403589679354, 57.85346954099594, 56.47720398441438, 55.36488648383848, 50.75748612803798, 40.9292894794095, 35.200942408654, 27.389006806958108, 14.194060390995396, 13.932175501700371, 9.972215294837952, 9.820088128889761, 11.49925087728808, 5.97319269372571, 6.428023874759675, 1.558629293595591, 2.2087305255474585, 0.07487322789646926, 0.09054513452875038, 2.355348477440496, 8.581458541654772, 26.121390904149703, 37.11529439495456, 32.22575403028919, 36.09328554522607, 50.422743212792184, 55.36386666759368, 61.21770604964226, 47.043954710806574, 17.372240251110448, 1.001124618755233, 0.1479391164837345, 0.04264195539778279, 0.047934328265968836, 0.027056128319893635, 0.04160282224596989, 0.050383381124946384, 0.04611398844468979, 0.04336093657559926, 0.03852171620594398, 0.0194813899185148, 0.024028158138295817, 0.028804584196017637, 0.0339503469876945, 0.04842218071702988, 0.011804577962104833, 0.036303255812174855, 0.016321928405593482, 0.07049384031204448, 0.04707531004603352, 0.007007323410136686, 0.011257910068267056, 0.07954245718616633, 0.044634936963238066, 0.023102065090150125, 0.04985759199987497, 0.08698154631401263, 0.13432499862486316, 0.09416535196285095, 0.1651185768986902, 0.1154899379358657, 0.1725352579547513, 0.12606457897251652, 0.20956972553845377, 0.09766215263234992, 0.07291527570135171, 0.17539256672945716, 0.30081600671814335, 0.03788169188004348, 0.2162588375710672, 0.19490216017490436, 0.12825936724942538, 0.1362457342686192, 0.09662062545577366, 0.17881806759584337, 0.1782432871480142, 0.24568436667323115, 0.073625669033537, 0.15488330515161639, 0.1568978406008213, 0.16564510912904817, 0.13535926328791728, 0.17696487026349192, 2.537548455499834, 16.55535371072831, 52.10219229421308, 64.59377242672828, 58.469328726491625, 49.865613675886586, 49.63493124131234, 58.60875721900695, 48.02633977705433, 30.082947515672256, 10.63817491454463, 1.9684635343090182, 0.657058597332047, 0.6756658311332426, 2.353755504854264, 6.735099371402495, 13.246302008628847, 12.253546195645487, 13.922550985890052, 6.674701244600358, 7.243780772532187, 7.17198129623167, 14.084714516516655, 23.794156505215554, 28.49392475620393, 43.49910090046544, 53.03202152252198, 55.6379226715334, 58.4683402892082, 56.56353927427723, 51.88896832927581, 48.75070741099697, 43.00674538458548, 42.12198811192667, 42.713477611541755, 50.968533177529615, 54.82991833840647, 59.96767020994618, 56.71924168063749, 56.17688378980083, 57.5682661610265, 53.952750852031095, 55.31375838864235, 49.92789306948262, 44.549154696925996, 42.08853029435681, 42.466183939287745, 40.2394308582429, 39.93425869172619, 40.38157363091746, 48.98658306367936, 56.133722028424664, 58.48838360078874, 56.18954912308724, 57.72923631052817, 58.105972120838786, 58.547274066555886, 57.33386139715872, 55.752071488288145, 51.92324984458185, 55.971324136180264, 38.46427594461749, 52.25125805024178, 60.12915418994043, 53.32451658864176, 49.94038581848145, 42.31449411761376, 41.47273778915405, 41.84614350718837, 42.75775724841703, 40.78549931126256, 40.593409076813735, 40.1932841731656, 43.15345379614061, 40.88361347875288, 42.005344667742335, 45.44156451379099, 47.81605758974629, 49.440248320179606, 49.93586332567277, 45.88127005484797, 42.78116987597558, 41.05712736806562, 41.97353032327468, 41.24093355671052, 43.27087386961907, 44.109198124178, 44.27091744638259, 47.98369969091108, 51.929090253768436, 56.85938012215399, 57.33828975308327, 58.04372410620413, 54.62029903165756, 57.73483353276407, 57.03090536978937, 55.83552775844451, 51.80985020053003, 39.82450685193462, 37.65795038592431, 33.10857757445305, 29.62997259632234, 15.249227977568104, 15.412292672741799, 35.43832425148257, 34.55897200492121, 11.580939139089278, 8.407664202874708, 3.767368889624073, 2.341009762979323, 0.4152237305477743, 0.6766417045747081, 2.963641656021918, 10.485575102990675, 28.656391289926347, 43.80592830719487, 41.321954034989886, 44.14118897530341, 60.20070214425365, 62.30548912479032, 67.74590676830661, 54.634619605156686, 20.87929221891588, 1.6159039879998855, 0.2368481553369953, 0.1311798093299712, 0.23758022895743772, 0.13392896181152714, 0.1185189423361613, 0.12501608805670855, 0.16864153947080338, 0.15690088963075993, 0.13012709726970043, 0.10689233234452625, 0.17237965017557147, 0.09157536956932276, 0.2067202002170586, 0.21299761659916372, 0.10454696182522083, 0.17832674476648533, 0.13443804255897, 0.20569780991683084, 0.11722141921880747, 0.10333458938065077, 0.10269573333883479, 0.15639822870012254, 0.14922747718951396, 0.2959311543212783, 0.26359792318074937], [0.012227243991688857, 0.019704256387006854, 0.04136057375299354, 0.01830331139987515, 0.03007783956315008, 0.024612872831283078, 0.008663941144702897, 0.0409131515921364, 0.024705588622319124, 0.06520368909883885, 0.08500629585356483, 0.021797478642134417, 0.023416919566150156, 0.013195170228549791, 0.04102601932602064, 0.01912641924835982, 0.037181813104618947, 0.03724014686961328, 0.03401973923187583, 0.029456231990949284, 0.0966562485442527, 0.05175251431102234, 0.05317864826910439, 0.09019989700567338, 0.02298165522065134, 0.05234675722256784, 0.0706312764856604, 0.45604904632895227, 10.423207456065763, 34.13073939661826, 47.1976920097105, 42.20110624067245, 32.93022740271784, 19.204296988825647, 20.61752696191111, 28.429580234712173, 22.25922323042347, 10.615521265614419, 2.351423655786822, 0.3345167354470299, 0.08145325666954441, 0.6444817625226513, 1.0265301780835276, 4.407257495387908, 5.516540552339246, 9.915779252206127, 3.4085367379649996, 5.6680141533574755, 7.795533720524081, 8.210417522538094, 15.950836058585876, 24.61261591603679, 37.22095520265641, 48.35576003597629, 54.746418922178215, 53.232866487195416, 52.14967258514897, 45.753216435832364, 43.94819267334477, 38.701387143904164, 36.5469390346158, 38.04417833205193, 43.205072187608295, 49.97544004071144, 53.18764155910861, 55.48811558754214, 54.042592740828, 53.14638999200637, 52.99770470588438, 49.57640947834138, 48.26389420417048, 46.07066562098842, 39.42637451233403, 38.97262296368999, 37.14619482717207, 36.83501751192155, 38.36381227739396, 39.659288775536325, 47.32574170635593, 51.67987854250016, 49.59318937793855, 54.0746698840972, 52.20998687128867, 53.482035052391794, 49.88018135870657, 56.40029022770544, 52.05417071619342, 58.0138474126016, 38.36193738445159, 47.33488867359777, 52.669014007814475, 46.44017250307145, 44.84901205185921, 39.13459331758561, 40.726891256147816, 41.05160074849283, 41.44887016665551, 43.22806904392858, 41.66047419271162, 37.952994992656095, 37.4128100948949, 36.11851815254458, 37.71053368045438, 42.85839742229831, 47.1480465704395, 51.15374357469621, 50.233743806039136, 50.83716515571841, 43.71891052492204, 42.16256503135928, 38.79637910473732, 38.49324264834004, 39.360776793572214, 38.994905948638916, 42.62534195376981, 46.7818933148538, 48.43330921665315, 54.17669857701948, 53.50054863960513, 57.2938100753292, 56.68699979782105, 57.277979389313735, 52.6664880014235, 52.26158565090549, 44.054084900886785, 38.979341983795166, 25.687741502638787, 23.414067068407615, 8.199796724704004, 7.861310887721277, 7.7307082183899425, 7.471242450898694, 6.735727440926337, 3.779578737674221, 5.164523028558301, 1.0018589599959313, 3.7885859704786733, 0.5305766230148654, 0.13725637278008845, 3.0522264251785898, 10.126239907357002, 22.498497616860178, 34.62498941729146, 30.186088200538393, 29.7498853360453, 39.231997536074736, 46.25717432268205, 50.98284198391823, 32.8447275777017, 11.42248224827551, 1.0374954703354067, 0.029472869505444844, 0.0478529965414876, 0.02704013623447428, 0.03214529828138409, 0.013470417001254618, 0.017785857311419902, 0.09839974974672641, 0.02834897064003012, 0.043786184321488106, 0.020661839479280096, 0.01820224908090407, 0.03147286843628653, 0.013976353915378213, 0.02939787715853703, 0.014249075470762628, 0.0387193056033744, 0.029732157709077004, 0.0516440132783065, 0.005038308426587573, 0.04261821050256972, 0.013916444882089573, 0.00781431181108459, 0.04895773746313588, 0.032439253878809755, 0.02127182932810918, 0.025117381949037797, 0.05970471380879322, 0.05397580105871443, 0.06480314768850803, 0.07565030152158392, 0.013751871958975832, 0.02058310287764236, 0.026449154942266406, 0.02629760359864562, 0.01705932250667003, 0.07622167287815003, 0.06373709803747554, 0.02609596542653538, 0.046233808426486875, 0.06391457379645397, 0.005706708649203422, 0.03806047764937243, 0.035812231757107287, 0.061105225956247705, 0.013468882910186246, 0.05206471812280436, 0.04160093766967616, 0.016636631579228466, 0.08390184221488815, 0.041475992559665636, 0.02683959356809576, 0.025619633022635698, 0.9032068762087053, 12.98743244140379, 39.15765685419883, 54.840108656114154, 50.51508365138885, 41.12910286072762, 28.420501908948346, 28.032434371209916, 34.49402147723783, 24.99141097068787, 11.731812127174871, 2.6505732680520704, 0.34242156772844257, 0.09243032369281977, 0.8309187583865658, 1.9906717490765358, 5.43629817424282, 5.399634309353368, 7.9615622566592315, 6.90677906236341, 6.95476730023661, 9.30409444916633, 10.407169865023706, 18.060576992650187, 28.482555766259473, 39.199434018904164, 49.89678082927581, 56.39360258656164, 55.92134137307444, 54.57099483859155, 48.34470287446053, 45.210544755381925, 40.77333996372838, 38.46625674155451, 39.8634442206352, 45.659989541576756, 51.3185929482983, 55.49034741617019, 57.36941768277077, 55.38296468796269, 55.433641710589015, 54.77926877237136, 52.31618504370413, 49.699842545294, 47.12843864194809, 41.48617190699424, 41.260686612898304, 38.910292579281716, 38.812327461857954, 39.70232894343715, 42.04405453897292, 49.60516437407463, 55.00431476100799, 52.47398984047675, 55.23215739957748, 53.49644976277506, 55.15543191663681, 51.999426195698405, 59.36409981020036, 55.40745204494846, 57.57713071761593, 40.739368315665956, 49.3061738629495, 54.09776479967179, 49.7117430163968, 48.01506296280892, 42.393608323989376, 42.35138008671422, 42.57972871103595, 43.76629275660361, 43.846618975362475, 42.283519160362985, 39.10932148656538, 39.19569992250012, 39.64285404451432, 39.8598591742977, 45.30127702220794, 50.24619340896607, 53.08288681891657, 52.405336595350704, 50.73975701485911, 46.193373049459154, 43.30629287227508, 39.46054227890507, 38.9795067233424, 41.24153760171706, 41.014761847834436, 44.115356245348536, 49.7193798711223, 51.78863410026797, 55.35464909768874, 55.808851718902595, 57.91445063006494, 57.76061919427688, 56.64462643284952, 55.16241765791371, 54.03623457877867, 45.94363966295796, 38.828746503399266, 31.59996928707246, 25.495253147617465, 17.526514914727983, 17.39538811868237, 10.470285704058986, 11.921672494180742, 12.997963024723916, 7.70668468167705, 6.183489099625619, 2.6642466504727644, 2.136188740691831, 0.3688222139833435, 0.14658004586254397, 2.4517843607933294, 10.7307977637937, 25.09852501653856, 38.51801633834839, 35.872471794005364, 35.03870925595684, 47.28539620676349, 54.92842474291402, 57.39064947251351, 39.915854930877686, 12.915992352270312, 1.2893925342828998, 0.06642990475220066, 0.010651065010367142, 0.026798140550512942, 0.08634816780085526, 0.019981961344338713, 0.07295508162989732, 0.059872502385969126, 0.05201446658541119, 0.028890782494037866, 0.04338730149151337, 0.011899995170683872, 0.049834027135324095, 0.038245284869786234, 0.03501036369632329, 0.010148807233499904, 0.04466960244181176, 0.08220570056789345, 0.08095314681169488, 0.006392681971192361, 0.06998843678663816, 0.0294014873478802, 0.07547511253505945, 0.05564126471478132, 0.041574925154207215, 0.008473905374205882, 0.14506119994386552, 0.25148129270922753, 0.09075302780876238, 0.19211732331783543, 0.1747114226342209, 0.10587504418987422, 0.1588730910612691, 0.1333348912697646, 0.15221206381195976, 0.17697322062186657, 0.2476538101872129, 0.24656890711236387, 0.08797869401713533, 0.13085354780477862, 0.18091420673074263, 0.08521489393446716, 0.10866192650170096, 0.12333725233592334, 0.10530315189351959, 0.09920988772665301, 0.16791306646360507, 0.12970778670522476, 0.10952377541651649, 0.2600198942086389, 0.11801942236601345, 0.11455557879901702, 0.22021313828806724, 1.1808474361896515, 15.401024683829277, 44.95346869191816, 61.51705741882325, 56.962173677259884, 46.5863553170235, 31.74616582932011, 32.55274634207449, 40.256795190995746, 30.63187929891771, 15.401214918782635, 3.683275969759111, 0.8971074067296521, 0.33159429387700173, 1.7553992833822005, 4.681327227623233, 10.443661635921849, 14.064788876041291, 20.276237610847723, 11.006679631048634, 9.962428981258023, 13.466557802692538, 11.252418083529319, 21.54897809028626, 31.219856316043487, 40.5036142564589, 50.49900193368235, 56.056910253340206, 56.80412569353658, 56.89623471229308, 51.37541632498465, 49.111306590418664, 44.68178964430287, 41.243745896124075, 41.945159819818315, 48.139492311785304, 53.82665841810165, 57.93270926321707, 59.24568737706831, 55.61901684730284, 54.77941782243791, 56.863443697652514, 55.50544461896343, 52.76564159700948, 50.14466677942584, 43.52179965665264, 42.949631752506384, 41.33735718265657, 40.37967912612423, 41.47671899487896, 43.26766537081811, 51.45718989833709, 56.62677964856548, 54.405102114523615, 58.27254341494653, 54.3420696258545, 56.68107309649068, 53.374852365063084, 60.75202265093404, 58.39308569508215, 58.84850032867924, 41.83607870532621, 52.496759199327045, 56.0764632686492, 52.36690913477252, 49.63753177273659, 45.20500636869862, 46.20898408274497, 46.472543824103575, 45.45108802856938, 46.87699510205177, 45.11925158962127, 42.21122203334686, 41.85160344646823, 40.91258018247543, 41.999284605826105, 48.35119831946589, 52.23640795676939, 56.189894291662405, 54.81998297476, 54.53329693886542, 48.176554787543516, 46.399964286435036, 41.8002753103933, 41.78773157058224, 42.38245702558949, 42.001587037117254, 46.4935520387465, 52.31670279656687, 55.24401864697857, 58.43878130758963, 57.46710823428247, 61.594241819074085, 57.97043854190458, 58.083885254398474, 53.612002788051484, 54.7269247424218, 48.18873766929873, 42.21758019539618, 30.256839913706628, 28.378901250900764, 14.347297587702352, 17.7673464821231, 16.95066978854518, 22.564746449070594, 18.597086629559918, 16.30165186620528, 11.597947516748983, 3.4912350100855676, 6.4778928891305005, 1.181724453645368, 0.34627220142752896, 3.5367896624149817, 13.110291861718702, 30.718736264013476, 44.577038826480994, 41.57468411230272, 43.67337180722145, 53.81047471877068, 63.47236287209296, 66.89643906008813, 45.55401102189095, 15.90597983329527, 1.5418136023706006, 0.16456350023227354, 0.15609396922011531, 0.18858054051956824, 0.22652389481663707, 0.06703910553046773, 0.16562373527596075, 0.20214909146870338, 0.08870690655443939, 0.11690992786879502, 0.142818400936742, 0.1696091238409281, 0.14048099007096984, 0.10696013112582507, 0.17803796026254856, 0.09913125646210487, 0.15500643080280674, 0.19119139880903308, 0.12120142984654635, 0.09925241326732982, 0.11683197842249948, 0.077756215938397, 0.161128239405732, 0.12797225281716357, 0.11632695794105531, 0.1899192485237314], [0.023758445393234014, 0.05345405304744359, 0.061095128917405685, 0.016376910535919092, 0.039978367276489735, 0.06058511737313482, 0.03202144676188548, 0.033382878849102605, 0.05233115584198987, 0.018954022652319363, 0.030974491852365678, 0.02219910023643846, 0.05498877613835278, 0.031045822298995433, 0.060315891093904936, 0.02133371391063256, 0.12411765844350862, 0.03696536645293236, 0.055677573451952594, 0.08208125724547333, 0.006699375695578995, 0.01907796993280851, 0.03168221536813484, 0.05795520647699314, 0.014979343996533464, 0.049084988497798486, 0.08176775874509927, 0.1614581015441687, 5.757008319900883, 28.297778790996922, 48.211663922955914, 47.019243778720984, 35.75004677618704, 30.19939680253306, 30.9224602483934, 34.838789970644065, 30.499646394483506, 15.725545902406017, 4.195748096512211, 0.8625360037530623, 0.05979355702537203, 0.5739262904370985, 0.8621185164778464, 4.1441900114859305, 4.021465177497556, 5.0632395859687565, 5.28028590063895, 3.063753290522483, 4.092422324803568, 7.526346848857019, 13.612537633988167, 26.23105645179749, 34.289328667425345, 45.27906856229229, 51.08842434421663, 52.27712215915803, 53.27281974977063, 48.62351671341927, 44.59791760290823, 41.8756946440666, 36.7937659448193, 37.19354175752209, 36.083695350154755, 44.37611933677427, 49.80418935898812, 51.97244028891287, 56.0763495199142, 51.7633387350267, 51.783244763651204, 54.08746073322912, 48.82999420166016, 49.49621269779821, 42.14222754201582, 38.12133135334138, 37.12299792997299, 36.972535810162945, 35.325340378669004, 38.185485639879786, 40.67400593911448, 47.709514248755674, 46.94083952134656, 52.08396111765216, 48.864334552518784, 52.354690951685754, 47.61470663932062, 51.03497420587848, 50.694084936572665, 58.77705827836068, 35.299327219686205, 43.01418219843219, 57.111568912383056, 47.13148632357198, 48.31030761041949, 43.13120219015306, 46.836700593271566, 48.30671079697148, 48.74489053603142, 51.464579643741736, 49.40311131938812, 45.03439503331339, 38.68735682579779, 37.31206793938914, 38.45095949788248, 44.651152010886904, 51.57385687674246, 55.63814624663323, 54.77905696438205, 51.84168023447837, 50.51426779839301, 49.24076049558578, 43.399774720591886, 39.46695143176664, 40.96646962627288, 39.95297624218849, 43.748206707739065, 46.68297506147816, 50.371054218661406, 53.296228454959014, 51.446897599004934, 54.246752108297045, 54.855527493261526, 58.78234171098279, 56.65116894629694, 48.24124643879552, 38.19928061577582, 29.5767479942691, 27.29092205724409, 22.307178128150202, 13.632016124263888, 19.45843323584526, 8.868422085239041, 6.605679296678113, 8.687670442365832, 5.169718207851534, 5.663783877126633, 1.298374026533096, 3.151154484479658, 0.5379010977283601, 0.2326410456049827, 3.50007823878719, 9.538997354045991, 29.21410525998762, 39.58857628606981, 36.10604501539661, 28.18383589867623, 37.1697094363551, 58.02895638250536, 50.25474025357155, 32.84855777217496, 7.190705220545492, 0.7397984833486619, 0.04224651230258807, 0.025887139434475574, 0.03248277533378813, 0.04339919500653783, 0.0681961051398708, 0.04487974802032114, 0.06676807128373655, 0.003926168771408078, 0.034195747932479266, 0.03580228793585012, 0.08731746054705113, 0.04125625556034427, 0.07366690754650101, 0.013522462142000516, 0.011133611344942644, 0.04557545544699796, 0.03885027216446977, 0.07983317223167227, 0.04891931049285397, 0.0456895565824403, 0.012778616622991621, 0.03835183620873479, 0.04365419503301383, 0.032019583253009666, 0.09763499481543418, 0.02345773673075582, 0.03108462656758005, 0.029995824105196425, 0.03971055825991977, 0.041488357218763525, 0.09251051777673346, 0.07488258949090397, 0.05654313406276126, 0.06322133317289334, 0.05574414266213294, 0.05560073483314726, 0.011358265671127988, 0.0375321259601943, 0.017486573572480874, 0.04548657392602294, 0.027246413068966042, 0.10478248789666161, 0.0500245263890153, 0.03964179420783635, 0.05284759103350582, 0.02298132963328352, 0.03850343734807065, 0.02879563820428185, 0.04498193648854091, 0.02313578636535714, 0.04540456421372872, 0.061102816609725843, 0.311529531834587, 8.055239733188383, 33.91598178494361, 53.681401283510276, 52.96420766461281, 40.61572736309421, 27.695045817282896, 30.45129337618428, 41.03550334130564, 33.423520365068995, 17.603807180158555, 4.468381750968195, 0.8386343669506812, 0.012848138144510168, 0.6748324500456934, 1.6511355749061032, 4.8499685525894165, 5.421047508716584, 6.911048071999704, 5.802404851682725, 8.482919777593306, 8.108689381230263, 7.835261446814384, 15.81493083507784, 26.17004006139694, 37.314197786392704, 45.89859908626926, 51.56448241203062, 54.11101456611387, 55.573988037724654, 51.73500353290189, 48.06097038330571, 43.018430125328806, 39.48661819581063, 39.24186621942828, 40.52410864060925, 47.53505899060158, 51.30941852446526, 55.09536081744779, 58.03438102045367, 53.70817145993633, 52.91821395197223, 56.18897645704208, 51.217587993990996, 51.13874835352744, 43.533001945864775, 40.17303297596593, 39.58368509046493, 39.29626557134813, 38.21373847223098, 40.87687484679684, 44.04297282618862, 51.05753567910964, 50.62538070063437, 54.07754105906333, 50.590577510095414, 53.172073671894694, 51.69186922811693, 52.49026767669186, 50.69099803124705, 59.00672874143047, 38.64571694404849, 44.87357785624843, 59.909540683992454, 47.87088448001493, 50.323671986979825, 45.28711726588588, 47.84573424247004, 49.69752442452216, 51.849846609177135, 52.89225570617184, 51.190296142332016, 46.02162422672395, 41.203651428222656, 39.37777242352886, 39.36830382193289, 46.69925289769327, 54.869687249583585, 55.93620715602752, 58.08095524387976, 54.14305248568135, 52.341456874724365, 49.95445536028955, 44.488534465912856, 41.1470006358239, 42.429227367524184, 40.49292187536917, 46.013465696765536, 49.70096434316328, 52.75657307717108, 54.49836823248095, 54.01613243164555, 54.92726372134302, 56.24242267301006, 59.189817136333836, 55.10198177829866, 50.88524556929066, 41.07936328457248, 33.31052080277474, 25.950018628951042, 19.29247187029931, 18.502122125317975, 13.42954827893165, 11.530723975550744, 10.638728949331469, 12.633836653924758, 5.537413935507498, 7.0638288028778575, 5.082372417373042, 0.4605517127821523, 0.5732850442009588, 0.5776115410750913, 3.31070865834913, 11.19739507475207, 31.5604906312881, 40.68596524576987, 37.64384554278466, 36.21940543574672, 42.272665962096184, 62.59704674443891, 58.08832929980371, 38.677939215014064, 9.78848167004124, 1.047586503048097, 0.04611096239738888, 0.008165186304869431, 0.011550467555230905, 0.0536813666563361, 0.03779872838828353, 0.10481346849231951, 0.08413707717291771, 0.05149710442750685, 0.03753895946447888, 0.048146511638356794, 0.08475740154784533, 0.046547873831924894, 0.002773142524904782, 0.02575091367978002, 0.057006322313100107, 0.028785282610765392, 0.04328980531182982, 0.060424748357505574, 0.021967860426934018, 0.06960290303874402, 0.05056174937635661, 0.010126383839956215, 0.03732124110683799, 0.05654963431879879, 0.04654742184004957, 0.12574686698855894, 0.15629312143691126, 0.16968082967064074, 0.11212809897598722, 0.18418155640604036, 0.20712207462037766, 0.18647110209830348, 0.1660737353226831, 0.21371170247514404, 0.10557298338220966, 0.1437906890867218, 0.06556385767556007, 0.1432345858624866, 0.1262231974772388, 0.1791721227909288, 0.12106381747270785, 0.16975886338660795, 0.1592355272582462, 0.15978787665165242, 0.21584283650642444, 0.13382884944158216, 0.16149341819747803, 0.1615178257587456, 0.10615439049058384, 0.085945182570046, 0.1323679197699793, 0.15256492390988335, 0.5658777094175739, 9.799815358654145, 38.322195929865686, 61.2272217196803, 60.22814304597917, 49.36516631034113, 40.100520118590325, 41.457311107266335, 46.66366915549002, 38.97879285197104, 21.285159472496282, 5.9632720389673795, 1.510273456092804, 0.3923579059060543, 2.4233373711186075, 5.894770785685509, 11.719740052377025, 13.789642453193666, 9.795212457256934, 10.468988380124493, 8.422823182998165, 8.1887248543001, 10.708527526547833, 17.411159969145253, 29.316388906971103, 37.831636859524636, 49.26493798532794, 52.24812015410393, 53.438065282760135, 59.04693303569671, 54.39278587218254, 50.00150419050648, 45.71843677951444, 41.685510681521514, 41.48568553309287, 40.83112824347712, 48.873854144927, 54.4151355374244, 56.95652938658192, 62.261782153960205, 53.803508589344645, 54.748505623109885, 59.451141126694225, 54.16776341776694, 53.06867607178227, 46.701563173724765, 41.90690494352772, 41.36702991301014, 41.3056016737415, 39.821310120244185, 42.060544183177335, 46.366016172593646, 52.96496075968589, 52.967828012281856, 56.28618847939276, 53.82647798907373, 55.791436395337506, 52.15746633468136, 55.21468324045981, 54.22467308659708, 61.15228091516803, 41.57936742228847, 47.32706746747417, 61.961932643767334, 50.16363928394933, 51.9829208620133, 48.600406108363984, 51.136865615844734, 53.76412799281459, 54.09543098941926, 56.299571606420706, 54.699817242160925, 50.74482079475157, 44.011189860682336, 39.85368928601665, 41.81643547550325, 49.44750470499839, 58.21471983386625, 58.97986442812028, 60.833698165032175, 55.56265238792666, 54.82779633614325, 54.19578875264814, 46.952069267149895, 43.894664087603175, 45.66337454703547, 41.63436689684468, 48.055737941495835, 52.18934343707178, 55.792330695736794, 57.56100977620771, 55.65079589043894, 56.91410503079815, 59.20274526842179, 60.93295374224263, 56.616130413547644, 51.189472444595836, 42.48368555499662, 32.29456417022213, 34.04988365788614, 24.418670400496453, 23.139603137969974, 30.45852818796712, 16.782674674064882, 13.499586120728525, 21.821359242162398, 14.173251236638716, 11.504662767533334, 5.006189202108692, 3.16083979702765, 1.0432886885058497, 0.7414346020067892, 4.897469435968707, 12.59112988748858, 36.61692980797061, 50.152538976361676, 48.923856519883685, 41.20631471756966, 50.92843478725803, 72.06578562336584, 65.91289689463954, 44.77345935760006, 12.004194259643556, 1.5028956003727452, 0.14875984179877466, 0.1228085061114642, 0.07687794209848489, 0.18724672015636198, 0.15228818230811628, 0.16048543035022675, 0.20419145123131816, 0.12753876196520944, 0.16113878077557012, 0.22121142746219713, 0.2002809247783115, 0.17853164264271337, 0.16707522674433647, 0.08048432398467295, 0.14686021953821182, 0.18976158762891449, 0.1852138752057668, 0.1311068930813382, 0.12676959436747337, 0.17838155069658834, 0.14460527037660922, 0.1680716773074481, 0.09457869470239648, 0.20938044053412255, 0.17949208707338382], [0.010804219392969484, 0.05110655280370867, 0.015107985480778642, 0.017660226552717147, 0.08993260126801268, 0.005350172286853195, 0.04648318153715903, 0.08325693407847036, 0.023321616313149853, 0.00832130927817836, 0.044257228803490443, 0.08606009575868807, 0.025808119380305854, 0.10353443873745781, 0.09470341381646934, 0.03758064230843898, 0.03616150656354524, 0.011611962390522803, 0.025716349707856297, 0.05311318988641424, 0.07797498766693377, 0.04398513352498413, 0.0398646415241303, 0.03725494385787076, 0.05043979967013002, 0.04622747670979269, 0.055490831859529986, 0.10638902790003246, 4.4043480773125925, 24.55760075199989, 42.962771692583644, 49.53340068940194, 42.62091359784527, 28.529883084758637, 26.87579408768685, 31.047611313481486, 26.71436502087501, 18.806856947560465, 6.448095133227687, 1.1356059606036832, 0.17299828149618643, 0.3935775485250258, 0.35647833118996314, 2.563209091463397, 3.2581236477821105, 3.6435249543959096, 3.5112829794806824, 6.168176656769169, 7.998937541438688, 5.0173400102123145, 10.22329209312316, 19.40234334238114, 33.97496246522473, 43.191845955387244, 51.92006095763176, 52.97701812559559, 52.731320858001716, 48.22361930724114, 46.17867200605331, 45.52163970085883, 39.64562716022615, 35.52500470992058, 36.71034889836466, 39.08754448736868, 48.044186561338364, 49.96086059078094, 52.75219571205878, 53.69734964063091, 52.57170392620949, 53.82390099187052, 50.6650907762589, 50.202866908042665, 47.02253856966573, 40.867233660913286, 36.730482424459154, 38.06371565788023, 36.433413874718454, 37.313840850707024, 36.99108469870783, 40.05189449556413, 40.5325182022587, 43.71129720441757, 42.787892818450935, 45.21575758534093, 44.234451170890566, 50.63634764763617, 47.13154515912456, 57.103355469242224, 39.15169877390708, 40.182364294605875, 58.370241811198575, 49.68675359602898, 52.05747335187851, 46.0950235397585, 49.17916359439973, 47.283650752036806, 50.43791886298887, 51.37998196386522, 52.8645480832746, 49.44792047623665, 44.11413246585477, 37.01613295462824, 38.61615404005974, 44.51179412103469, 54.60251500529628, 52.467949390411384, 54.8416187686305, 51.98732960608698, 53.07363394768008, 51.22979440996724, 52.52003454392957, 44.287187437857355, 41.06506232292422, 40.2123978830153, 45.36852998118247, 46.38196452971428, 50.58947924644717, 50.21959973919777, 50.06028090753863, 51.80824987349972, 54.63527071860529, 53.87538602275234, 57.497608584742395, 50.47485974527175, 34.98646720763176, 28.904394911181544, 19.355984849314538, 18.113889848032308, 24.382753256828558, 11.373342794756736, 12.243332343716776, 10.75597938029997, 10.759020197776056, 3.632597231095837, 6.44181885065571, 8.005690882282874, 1.2752224817391367, 0.5715975057213538, 0.4940748929737076, 3.370629726879059, 10.04750911266573, 23.589506841474964, 38.902020300588305, 35.91129933634112, 29.218457129693803, 38.32993868858584, 55.34356447958178, 45.51025698261876, 31.758227117599983, 6.412747713827319, 0.7776884566391669, 0.029486383296429153, 0.058805123572388006, 0.08990329840490896, 0.06714862546012287, 0.06529648532910694, 0.026584032382215225, 0.02209760507779016, 0.033477624773137996, 0.07154565604944384, 0.015993656857209583, 0.019613710540016333, 0.0306574999910569, 0.05546155197906399, 0.01745420061202059, 0.0766584502472993, 0.08129225563137762, 0.13637097432248055, 0.03336857981799591, 0.030767040988129955, 0.0166072138029361, 0.01963323237554681, 0.042554617543975194, 0.027302846935908162, 0.026245768174468994, 0.05904651021644954, 0.07455791376771466, 0.03679110443279628, 0.015635174631531683, 0.0636553526255152, 0.014479495566188088, 0.024603545710804964, 0.02630478758815556, 0.08376393106675918, 0.015552296367053305, 0.00516274408812845, 0.05820956682005237, 0.012241606225049304, 0.018135804360011415, 0.03920026709355655, 0.06571417178718314, 0.010742055188353744, 0.06466266248495349, 0.026434606932584318, 0.03115305545619659, 0.05798013114760961, 0.023456273502820445, 0.04839362095921271, 0.08653677864781312, 0.03141557846608902, 0.07505017888521956, 0.06027750625845887, 0.07719255142634915, 0.1661033216383188, 5.619443933809958, 28.075941301161244, 50.399742434101725, 53.694953072455625, 48.78409854827389, 34.536441910651426, 34.78688132378363, 36.23914280245381, 33.93609177681708, 23.19935456398995, 7.052937361501879, 1.249044092912828, 0.17555865459144118, 0.25154475543287497, 0.8661355138305695, 3.3674077449306368, 4.442211206882231, 6.527461842183144, 7.49685945049409, 7.484897202061069, 5.848644202755344, 6.960781764599585, 13.503360421426835, 22.32441302268736, 34.91113024373209, 47.612102185526204, 52.78122125133392, 53.79593841491207, 55.702704537299375, 52.1867899740896, 48.262184050775346, 45.689587746897054, 40.89880089606009, 37.07242288897115, 38.02427230342742, 43.013672290309785, 48.95385872933173, 53.339315691301906, 54.01579118544056, 54.18896382854831, 54.17478838274556, 55.55627853639665, 51.81259585965065, 52.589844888256444, 48.42399750986407, 41.95436954498291, 38.92679399059665, 40.04624628251599, 39.064916333844586, 38.5949065608363, 40.68668696188158, 42.1233570191168, 44.043298382912916, 46.21987650471349, 45.83166776164886, 48.022570379318736, 46.111269997012236, 51.9356406119562, 49.144807554060414, 59.33794152352118, 40.72247858970396, 43.13517947350779, 59.35794168902982, 52.92775707860147, 54.14863401843656, 47.75466072943903, 51.26333067494055, 49.54139447981312, 52.3300741564843, 52.61850172473539, 56.37800724275651, 52.80668135612242, 44.593830493188676, 38.20825499873008, 39.59313015783987, 46.865620228552054, 55.398359990889034, 54.05603470340852, 56.36285120441068, 55.00384015421714, 56.016176439100704, 53.71660063343664, 53.663452517601755, 44.655376403562485, 42.79788309527982, 42.041587368134536, 47.326294760550226, 49.557256544789965, 52.67888269116802, 53.53614807128907, 52.4931663082492, 53.86010839093117, 57.15094950891311, 56.98037347485943, 58.71898758795954, 51.4952878798208, 39.0305132250632, 28.06696103465173, 21.13245964050293, 18.901135037022254, 19.42462044377481, 10.983422917704429, 11.161143549026983, 11.345253721360239, 11.09900143838698, 7.627987717428516, 4.601480028321666, 3.9657256007194523, 0.7181702277833416, 0.2844396515959694, 0.7255851008719014, 3.048816904906304, 12.21926664152453, 28.65585784758291, 46.617969620612364, 40.67526501993979, 32.25470112216088, 47.53272518034905, 66.18029271402668, 51.031393081911155, 36.40556504649501, 7.298897918193572, 0.9898657003237356, 0.027528925228022763, 0.10388489331929915, 0.10234248253606981, 0.031519693645438364, 0.039491315387309565, 0.033908480282632575, 0.006303043938392113, 0.03562648607898624, 0.038254979712468, 0.021643006588302312, 0.04724222145253613, 0.03779221664092714, 0.01631777237860426, 0.02732141499197291, 0.10595700027601374, 0.010668086526434748, 0.05321093887511281, 0.06253453534877589, 0.05979945973282861, 0.044927199506351066, 0.012881846970788414, 0.04664635443459115, 0.017507550975067482, 0.011157320808589218, 0.042316678295572924, 0.15503606308371792, 0.17908653544802822, 0.07031487451205332, 0.18266551436916476, 0.12732436459872032, 0.11181823939325349, 0.20727110936516718, 0.20707051690307357, 0.05945011980891709, 0.0778958507843556, 0.12133713466145339, 0.15279724773380066, 0.1040335756636435, 0.2094398123482543, 0.2258176383592429, 0.0766901126612098, 0.14432175655759152, 0.11599249927507294, 0.21305890363310614, 0.13676255250409727, 0.2049394901241026, 0.19148966748147242, 0.13665441153270586, 0.1522717573830197, 0.12900208183113607, 0.14138748659001243, 0.16927567641100577, 0.4670051761692571, 6.492703268604894, 33.37915443604992, 57.10541471358269, 61.10797774407172, 56.139119209781775, 41.350057817274525, 39.28447884898032, 40.766467971186486, 38.09365510940552, 25.782545189703665, 8.384459460935286, 1.7185518025390565, 0.5386130692016694, 0.8525846441907268, 1.9226886163796149, 7.275171501021232, 8.998583978222264, 12.494332655783623, 10.858283619726858, 12.930090331262159, 11.853297737336929, 8.125357002981248, 14.56565103223247, 24.300681583343017, 37.52022812443395, 48.212660204979684, 53.44193273975004, 54.59816509677518, 56.21666054571829, 54.23279631522394, 50.51352647043044, 50.17342167515909, 43.95067553366385, 38.33559082400414, 41.346382556423066, 45.05426576060634, 51.06984407671037, 54.470421345003196, 55.49029642535795, 56.34984070254911, 54.887208477143325, 58.80343229539933, 55.15349818814186, 55.64353558324999, 51.147471704790675, 44.984176927997225, 41.26142794086088, 41.72366357618763, 41.20900938587804, 40.547309460178504, 41.5333580201672, 42.341001495238274, 44.90790251762637, 46.91020973267094, 46.79183260087044, 48.83369299673265, 48.90182848899595, 53.47706933175364, 51.78319769520914, 59.90770893712198, 44.846509579689275, 43.92836509212371, 59.57901823905207, 57.237673113423014, 56.91237134318198, 51.3579107869056, 52.46767874686949, 51.2599927379239, 53.995288956549864, 55.45687390911964, 57.439773236551595, 54.026773821923044, 47.23515064485612, 40.20319992496122, 42.4624498428837, 48.821651320303644, 59.151075886141875, 56.40996671492054, 56.70460339515441, 56.69258525294643, 57.578115232529186, 56.76915384108021, 55.60300180988928, 46.155859501131125, 43.515159083950905, 43.69903195288874, 48.16636839220601, 53.03644987844652, 55.21525590650497, 54.8912642079015, 54.662931273060465, 57.593024161554155, 59.98913341952909, 58.965449717737016, 60.65281414216565, 56.34234505314981, 42.01431905069659, 32.74242431886735, 21.82354988590364, 22.92721659906449, 31.666969253170876, 18.612458398265225, 21.49558678750069, 21.791245245164443, 23.617128172228416, 10.201888699685375, 14.459328324564042, 13.737513173011042, 2.9743747317021896, 1.0176800239470698, 1.1132912289711738, 3.921758527717283, 13.952985636649595, 31.31040619265649, 51.31128949503745, 47.43140251405778, 41.017652634651434, 53.06110197497953, 69.3062020886329, 61.54702432693974, 43.930694980006066, 9.252732972944937, 1.4246733654891293, 0.1703069226876382, 0.15573494977528052, 0.20695269258031923, 0.1183020092186428, 0.12445660638472728, 0.16398251447225773, 0.11441758338121638, 0.12603596558854466, 0.1164472797104428, 0.1580422687073869, 0.126339596876454, 0.1145552876856058, 0.16071115049623674, 0.10737728132235427, 0.1568262879886935, 0.14331531620794727, 0.20561741665005687, 0.15534703349394186, 0.1191651221785334, 0.2815608157505912, 0.09783513528565246, 0.1924907605374052, 0.13498196498520915, 0.19012319645093334, 0.13322515683549066], [0.03145276820437322, 0.0601164017984223, 0.07758845034385882, 0.02146698256594039, 0.03214268209112268, 0.01004932975892218, 0.07158642724877404, 0.0395160025706695, 0.026032858933772773, 0.0219018523761582, 0.020076019704462062, 0.08976890360035243, 0.030358507365529096, 0.013560976254783813, 0.014672801574511875, 0.03788289846852422, 0.026261065035097064, 0.034336478284169594, 0.0677972644447319, 0.11442051749796638, 0.03190508375184671, 0.07235420056648793, 0.042991069325756644, 0.011775745285464632, 0.0039995736404952985, 0.05517827947774241, 0.04189355644367395, 0.10358650207279191, 1.4209360821593193, 16.345288234372294, 38.46197351332634, 53.22182109279018, 42.3505053981658, 28.65034103393555, 28.897391519238873, 35.68139353106099, 36.360689209353545, 22.069107909356397, 10.200159915031927, 2.4280400478070785, 0.2692443589049001, 0.27397982415653044, 1.48371288132283, 3.2081570644532484, 2.1326760130543865, 4.110085983430186, 5.958990771924296, 6.651565634435223, 3.240981419240275, 4.276224345930161, 11.591728598840776, 19.713958001905873, 31.99873116708571, 43.27649854844616, 51.45421674174648, 53.57159453053629, 53.40411716891874, 51.738596423979736, 49.18696911104264, 46.43319068416473, 42.09502966173234, 37.93519527681413, 36.69240405482631, 38.647305503968276, 42.900088294859856, 48.984386536382864, 49.569396280473285, 53.652591474594615, 49.39505869342435, 53.55615215916788, 52.85738975771012, 49.50739929752965, 47.92988084977674, 45.42127801525978, 41.782479516921505, 37.5750236357412, 37.09026182851484, 37.61084664252497, 36.4129900932312, 36.952178708968624, 38.0838256497537, 39.434258476380386, 38.79507687784011, 41.78021238696191, 41.464814601405976, 49.78052962210871, 47.84343181117889, 56.931261477931855, 42.65832908691899, 40.70724018158452, 58.909199007095836, 49.439769791018584, 53.40746295067572, 53.03299819269488, 53.92817720290154, 53.2016561877343, 58.29009209909747, 56.97871431227654, 53.93200151381954, 50.26061596408967, 43.663969885918405, 37.822062353934015, 37.777261041825824, 42.09781062218451, 53.167829667368245, 53.54658942068777, 55.51782361922726, 53.102828148872625, 55.6351887795233, 54.516756303848766, 51.93871182780112, 48.44996360040481, 42.957511794182565, 42.47876298043036, 45.47639123855099, 47.52546879553026, 50.531636053516024, 47.125034024638516, 48.079676166657485, 48.764082693284564, 53.529346681410274, 55.351487667329856, 44.95065635250461, 35.714133554889315, 29.823188551010627, 22.25950956344605, 15.453070613645739, 10.68316351982855, 8.420783550508562, 5.663568637063427, 5.732703353128126, 10.228707905738585, 8.447778282626983, 4.151072790545802, 5.823562606688469, 2.1233505779697053, 0.34384636869353635, 0.12292492849331711, 0.5019745465007521, 2.9711958958256632, 12.293381787115528, 25.874440439285774, 28.17953698096737, 30.391563523200254, 31.05452056854002, 49.88157380011774, 46.73180857012349, 45.589979156371086, 25.88949449600712, 6.574982827709568, 0.34047742043772056, 0.1149574761849738, 0.030574929119358142, 0.02792006099386321, 0.05755898580255528, 0.019708630749054497, 0.07837391263174434, 0.025960944345100753, 0.09655121788983384, 0.011358348025579848, 0.04913068181204219, 0.011503796521273833, 0.009326082428977376, 0.11167911782620416, 0.09986997972573004, 0.03493947375025, 0.04030939386857133, 0.08508920188873045, 0.054848823365905595, 0.06985414157351179, 0.032313780168131474, 0.03213605543057765, 0.04934346656345072, 0.06288358415927618, 0.04111760513736837, 0.05567483851806291, 0.03495950311903031, 0.02494296671131686, 0.03399668381579461, 0.07644077402449424, 0.06580904411572604, 0.040638397988532825, 0.03949937846271261, 0.040931020592970234, 0.08284070318745029, 0.03550904096975442, 0.034187945326970476, 0.07680764587055292, 0.05637097878441696, 0.030537193543427897, 0.0653796135297706, 0.047601727363202846, 0.05930041473719382, 0.012456924812267385, 0.03341719575767075, 0.027899857340080124, 0.012608718431194224, 0.03314547203180771, 0.04118197950564566, 0.0528631043139725, 0.024451596001463554, 0.012992657758595963, 0.05044685533991264, 0.026749993839691726, 2.350046168411932, 21.056481369080085, 44.87943003254552, 58.18465878886562, 49.75737587098153, 31.724694774996852, 30.226765140410397, 35.51541451484927, 37.365596525130734, 25.481315005210142, 11.044806049716088, 2.4406681185768497, 0.2107755019659958, 0.06836189422756433, 1.2208373484111603, 3.27658403784998, 3.743562799307608, 7.153093612963154, 7.374467772822227, 7.8880658649629165, 6.355621334045164, 7.769359744364216, 11.806331276893617, 20.943919151060044, 33.63880357434673, 45.11351316205917, 53.07660710427069, 55.82289772648966, 53.784845952064764, 54.82851805225496, 51.13688130532542, 47.87571684006722, 42.88161000897808, 40.006457759488015, 38.504935233823716, 41.50209672989384, 45.10757469361828, 50.39922075886881, 52.16947663214899, 55.49705074679468, 50.22490670604091, 53.21903620996783, 55.34925191633163, 51.124208127298665, 49.78309092983123, 46.71883336959347, 42.15978799327728, 39.43106566706012, 39.308985817816954, 38.63182390889814, 38.17695840712517, 39.04203714862947, 38.46638225740002, 41.80928499467912, 41.4842224890186, 44.65522735349594, 44.3893494913655, 51.70688013876639, 50.96825076687721, 58.22180363439745, 44.598800136197, 41.7542149174598, 58.57944534670923, 51.9737817395118, 55.74297158948837, 55.33543340621456, 57.453854545470215, 54.38905962051884, 58.65287996107533, 60.231873220013036, 55.59628671215427, 52.577842435529156, 45.50304766624205, 39.3113588517712, 40.217222398327245, 44.653932971339074, 53.07983913729268, 54.739774427106305, 55.45809376624323, 53.19118738174439, 56.77879894933393, 55.919140923407774, 55.16230390917871, 49.28804074564288, 46.14852466890889, 43.288724576273275, 47.633851728131695, 49.34365995468632, 53.09122970027309, 50.027940965467884, 50.97622102306735, 51.562583984867224, 56.966362768603915, 56.608999544574374, 50.940915769146336, 40.25593226955783, 33.59397088327716, 26.01867775763235, 18.31500349506255, 13.874095985966346, 10.364626857542223, 7.028740750205133, 12.082191571112602, 9.04608682278664, 11.533968756275794, 11.954030086917262, 3.7085102931145704, 2.233453715039838, 0.23012283798908034, 0.16721986414444062, 0.5806731348556857, 3.798485052201056, 13.856328629678297, 30.082078710679088, 36.649650219948064, 35.13957692730811, 35.14156164661531, 54.80808250365719, 55.65903679017098, 51.53981070364676, 31.01093715237033, 8.328491160946509, 0.5356837941273567, 0.0553107705538071, 0.04253906212867268, 0.021691840863035574, 0.030146810458973054, 0.01680453698481283, 0.07421863640868857, 0.07163620764209379, 0.05800822359179297, 0.024045421929669478, 0.05425895098596812, 0.03907081355611163, 0.027047933094323646, 0.1640946544226139, 0.024113720583338893, 0.0289676575020196, 0.038573243279731086, 0.054437012802208626, 0.021888020658685316, 0.02653293814810534, 0.035064047307617245, 0.06082936918603317, 0.02201965946193424, 0.03506717677678793, 0.04920170582350224, 0.04264347991275211, 0.11599744820306379, 0.18733304294366993, 0.20031018933701902, 0.18269747555736573, 0.1265911112028745, 0.1400829307855137, 0.11702246618487182, 0.08239847127228014, 0.15636606832906125, 0.0877179253485895, 0.1361706423302812, 0.1656039855292728, 0.15589319289691989, 0.11949752772887869, 0.17448640728910125, 0.20302485254022384, 0.19609036254546336, 0.15414471978381758, 0.12100838335050691, 0.20589754436044924, 0.09065402626630761, 0.1612255478938741, 0.20060220673199625, 0.24766263552010062, 0.09006283621514037, 0.1116560739014418, 0.1352590283439044, 0.14749752808242075, 2.9234307427560133, 23.10585310382228, 49.85523116204047, 65.90583662832937, 54.744512650274466, 40.16898901231828, 40.39998915887649, 46.354252984446866, 46.6772170220652, 30.03426697946364, 13.775970051365515, 3.3467709297134034, 0.48533006060507994, 0.7420572169846105, 3.254925690350994, 7.912816020750231, 10.704917965396758, 14.852446894491873, 13.065743542486622, 13.851698271689878, 8.860725414368416, 8.531413020626191, 15.06408622187953, 22.353854333200765, 37.16342972170922, 48.08728556479178, 55.08135011119228, 56.676758489301136, 55.02358536566458, 56.852712092861054, 55.61478068751674, 51.873290615697066, 45.89329996416646, 41.75663501985612, 39.83153573928341, 43.41918653057468, 47.85285726670296, 53.14753532409669, 54.41632401558661, 57.026657442892756, 50.8337801502597, 54.45547711464667, 57.723737147546586, 53.87413870903754, 52.31704012040169, 49.749766472847234, 47.43967871512137, 40.857588552659564, 41.318714157227554, 40.97430652187717, 41.19222164154053, 40.824499437885905, 41.28293037414551, 43.74114251905873, 42.070063775585545, 45.837876873631636, 47.15138842982631, 54.173725420428866, 52.94967528312437, 60.31656111440351, 47.595526249178, 44.37558981680101, 58.031882470653905, 52.65317155468849, 57.376823117656095, 57.8740188383287, 58.37299139268937, 55.45515198861399, 58.92999933611963, 61.91419347640007, 58.653382024457386, 55.70158666180026, 47.97070095616002, 41.43745999182425, 42.28718265410393, 46.06013405707575, 55.677711194561375, 58.52153547348515, 56.59859741887739, 54.787674411650634, 59.55654698033487, 59.272288891576956, 56.81665374386696, 53.23285079771473, 48.06578705387731, 47.350201606750495, 49.06396358243881, 51.76481746858167, 56.31038950335596, 52.01307212152789, 52.56811103513164, 53.51026827289213, 57.98493562206146, 59.752010453131895, 51.40643442830732, 41.16878940213112, 36.10711974482383, 24.752628841707786, 18.66793836316755, 15.20449334575284, 13.345036891198928, 13.091098723873017, 13.74420081415484, 18.92710897230333, 23.306829467896495, 18.493116363402336, 10.66143064729629, 5.3886943286465065, 0.6102351195389225, 0.5412462053279723, 1.0515484646443398, 4.367288543332008, 16.991334961306666, 33.627942531339585, 39.556510909911125, 42.07398222338769, 44.97914452706614, 66.10439485119235, 62.19052053266957, 61.17870984538909, 34.764751311271425, 9.742728202573716, 0.6501057671923792, 0.24041501474716973, 0.1431309801316069, 0.11433456243286211, 0.14265666445416791, 0.0896303719210048, 0.18472074440890746, 0.18832318094228545, 0.17855635663915068, 0.09838732380059459, 0.14912891231717604, 0.19182651634177855, 0.11572871988098468, 0.21720258128498832, 0.16494470558339552, 0.0943117053999055, 0.10470692098381058, 0.15136546004683743, 0.21059643657457447, 0.08067331787559294, 0.20530119087667237, 0.08115938534179042, 0.1582060429838396, 0.13735544327045643, 0.1693585824461714, 0.2107579125872543], [0.05815918504771206, 0.04081238421701616, 0.0736965781318084, 0.05753491915041401, 0.027491070908464255, 0.01794585094396626, 0.014047702556596169, 0.0205442909481785, 0.037015989542968815, 0.030174759261670615, 0.02268857679389898, 0.01656035028938805, 0.07028644498918327, 0.05838368711392245, 0.04387360644496737, 0.0462971332543079, 0.037319643813515865, 0.0657999659738233, 0.030023456896625222, 0.024687786654178655, 0.02787566428343135, 0.023948450520214055, 0.06615916927975994, 0.05705132231777234, 0.04686812539735148, 0.11497126576761085, 0.015543354205757141, 0.030893608289320144, 0.6561657065345395, 7.122905581228196, 30.929496980482536, 49.397251298350675, 48.91619613093715, 36.08994368583926, 32.587757418232584, 26.880691166846987, 32.829800998010946, 32.638326575679166, 12.663759435376814, 3.5495292755865284, 0.6268101978686549, 0.044173085536327095, 0.7888956488140169, 1.5940572441585603, 2.488578644491011, 5.120895976020444, 6.590061399244494, 5.282215706763729, 5.279654399041207, 5.7915384154165945, 8.6711121566834, 16.766945969673895, 30.87432884400891, 42.93194578539941, 50.913478789790986, 52.77468658262684, 53.41956738502749, 52.84698370964297, 50.060049487698464, 47.77826555313603, 45.04021190827893, 39.40847673723775, 37.68499120589226, 36.89932477089667, 43.02812622439477, 48.38563280720865, 50.407410667788604, 54.110743922571984, 52.65385404709847, 52.76730860433271, 51.940645556296076, 53.66352704263503, 49.40961068676364, 49.46792848648564, 48.03727926746492, 44.95584172587241, 39.16643904101464, 36.54242438654746, 36.56994373567643, 37.48838240100492, 36.08894740381549, 37.08035392145957, 39.17217354620657, 41.33150892872965, 41.153892240216656, 50.18251765158869, 48.90877108420096, 57.67962225021855, 45.63509425809307, 36.70361026640862, 46.829051971435554, 49.05999022145426, 54.72226104428692, 47.963726981993645, 53.28746587999406, 52.60376930236817, 46.47845483595326, 48.29836791561496, 56.239649557298236, 50.01016478384695, 44.54218856749996, 35.97746579877792, 38.44355798536731, 38.95376420790149, 49.41016374095794, 50.171240837343284, 55.62438264969857, 51.81663197855796, 52.17742727648828, 53.86547027095672, 52.995414041703754, 49.357011702752885, 47.143861401465635, 42.69382653697845, 46.74945923589891, 48.22830653959706, 49.06213183556834, 45.982251474934245, 46.64053109384353, 49.242607931936945, 51.77498032969814, 55.790263606655984, 53.3593511581421, 37.64129992454283, 28.78357022039352, 18.034718767289196, 13.580540899307499, 9.669461269532482, 12.130061157288091, 6.400070613430393, 9.865789624952502, 5.110176138339504, 4.0662228532375835, 10.718218722651082, 1.3924325858393025, 2.0368444198562257, 0.22031842941238036, 0.09639823779223428, 0.6638070965005506, 4.801335575119142, 14.9147488417164, 28.071230534584295, 39.39918464229953, 34.95791627514747, 34.04871086920462, 51.76165996059295, 46.65241195309547, 46.89546946556338, 25.518648124510243, 3.6913511493513664, 0.16769727481709373, 0.023799065290199175, 0.013237711090985085, 0.016483718514322274, 0.03251048856444898, 0.062072863952527126, 0.06228762138034068, 0.09898370792788845, 0.06680873523075735, 0.022727626210619366, 0.044899459462612874, 0.02912548119052043, 0.01560035880820285, 0.026388467372124715, 0.04137501451036623, 0.056071633758443984, 0.024765073434419693, 0.059948724303995414, 0.07893428296571778, 0.04384543739199158, 0.04685784066696802, 0.015879469536875766, 0.051459972145816976, 0.05199465938212891, 0.05291091203088722, 0.0751940808409164, 0.0652843275137486, 0.09179633997020223, 0.021252408999228672, 0.0209708716870556, 0.0371455809762401, 0.035768920976308086, 0.09557595731870783, 0.03314008643370002, 0.04346292969139834, 0.04456846734448787, 0.05945190096334104, 0.023368104443615003, 0.01302299484039747, 0.016038744004383203, 0.020461984376813618, 0.04132388963273937, 0.025721066894250053, 0.06255625777186886, 0.02041533919832399, 0.01315373253272546, 0.03339363855399913, 0.08794219758842262, 0.06445498370956029, 0.023148966908094384, 0.03071110890877824, 0.09945615435079222, 0.027666460993068836, 0.00803403109462271, 0.8896938206688051, 10.14364738618174, 38.2029244976659, 55.84326659479449, 53.16780221077704, 41.11577072451192, 34.654501330467966, 32.178185486024425, 36.63354104565036, 31.638104531072806, 14.580646253401234, 3.9860687284700336, 0.5898183247735423, 0.19570595494681792, 0.2767950134171594, 2.4197172685976955, 3.1752635778919345, 6.932262211076676, 7.1184919341917965, 7.7896114318601555, 5.75595663439843, 6.502193933533085, 12.52078119785555, 21.705031548776937, 31.36699422713249, 47.64790558045911, 51.62607931321668, 54.4269654058641, 52.58145493845786, 55.95854897652903, 53.18167171170635, 50.712751496222715, 46.22499519778837, 41.631989940520256, 38.872320113643525, 39.49378044374528, 44.29254539551274, 50.59666110623268, 52.2531250984438, 55.53674121056834, 53.97235093578216, 53.529044658907004, 54.338300228118904, 54.60327594510971, 51.35471405521516, 52.6367917368489, 48.734970861865634, 46.54300920424923, 40.80377755626556, 38.658041031129905, 38.581774465499386, 39.10926657338297, 38.3275931112228, 38.20284997263263, 39.99551434670725, 44.71033665441698, 42.05154626600204, 50.990121902958045, 49.949383735656745, 58.922464463018606, 46.694251875723566, 39.47181909315048, 49.62104605090234, 49.993973239775634, 53.77108627750028, 51.00034752199727, 53.963980597834436, 53.80198278734761, 49.481856822967536, 50.51353431517079, 57.541284176611136, 52.288457808956025, 46.652859103295114, 38.300089451574514, 39.506641895540305, 41.92830539518788, 50.94228467633648, 53.420559744681086, 57.04177033516669, 52.34192755914504, 53.743712056067686, 56.43201435765913, 54.13392513029037, 52.10773852563674, 48.537452067098315, 45.55403063374181, 48.38708016180223, 50.534330721824404, 52.52233305285054, 48.33316718378375, 48.89240303347188, 52.022548567864206, 53.78340644221152, 57.18193231090423, 54.09743532057732, 41.432404056672134, 30.264602284277643, 23.29203232642143, 18.2190485923521, 12.915681504434156, 6.030598052086369, 6.419693250809947, 10.78235928089388, 10.61152535100137, 10.640929398998138, 8.535300089466958, 4.330179979724269, 2.176876221933673, 0.551389025584344, 0.06534793579410161, 0.7515550524957719, 5.189082949392257, 16.708826249645604, 28.866506776502057, 38.926750844524754, 39.160457426501864, 39.54470065332229, 62.07357506598196, 55.05491333623087, 54.26622667620259, 29.059222628993375, 4.852712740821223, 0.2598882803032475, 0.03837214519960746, 0.014058651868253948, 0.03518211294806773, 0.05515138596116055, 0.023569740700505437, 0.01630032089568915, 0.02434918728296555, 0.06703361268005065, 0.04212020355607233, 0.03973850514739752, 0.020535839083153876, 0.0036954228492123227, 0.03158719748288634, 0.04686284705155319, 0.03934555183795672, 0.016822557288011717, 0.02891919669514943, 0.01914676845884852, 0.009137064597809748, 0.015375805988667474, 0.02336601110836191, 0.06555063499798698, 0.0587907326107304, 0.04320879151383716, 0.04366583190858365, 0.1288460756862356, 0.16644216232722805, 0.14242119966976105, 0.11831913894462971, 0.2260240684113195, 0.13765178140132658, 0.22285606501804245, 0.11687314798755032, 0.14049614329011212, 0.09883830443986001, 0.12845576154969393, 0.16989164174564425, 0.2301123579062762, 0.18040802179565354, 0.0926506275972051, 0.15811803480309827, 0.15409032754119367, 0.17948448748117496, 0.1315897123347367, 0.2508014356417041, 0.1752908455748712, 0.1379735536512829, 0.16867863344809703, 0.12956788372849265, 0.220092035108997, 0.26712370495642385, 0.19859631275457723, 0.15529774339689364, 1.0604350845659933, 11.900170060896105, 43.570770448254, 62.50928763420352, 61.24499397893106, 48.6744055440349, 43.744817779910186, 37.70932559044131, 42.76945375627087, 40.34526032786216, 17.205896454472697, 5.1265613494380835, 0.994753402567679, 0.5583335819744295, 2.1869140575009007, 4.537764556946294, 7.564510039744839, 11.483023051292667, 17.848323814330563, 12.619616100865027, 10.192002365666053, 10.543509491028326, 15.566143720380722, 21.645089887803604, 33.60273738061228, 47.72467813184185, 53.66522935128982, 55.46699754653439, 54.9663422953698, 56.12738347822621, 57.25417060236777, 52.76495125985915, 48.809166416045166, 43.060701508675855, 41.692821979522705, 40.819902420043945, 46.594686431269494, 52.25676898033389, 56.39029602850638, 58.110251426696784, 55.19730714059646, 53.847615641932336, 55.453696789280066, 58.78478926997031, 53.21469022381691, 55.06281298975791, 51.599454264486994, 49.11350311771516, 43.080293747686575, 40.44737139055806, 40.93399632361628, 41.27269298799577, 40.11739415507163, 40.820847711255475, 42.8070535967427, 45.79066330386747, 45.097529503606985, 53.22872446429346, 54.90472185996271, 58.942966691909305, 48.84178876876832, 42.073719424586145, 52.54738130877095, 50.51472279333299, 55.37379810886999, 48.85791755491688, 55.11105422050723, 53.225770919553696, 49.29190820263278, 51.28224826628163, 60.12547892908896, 54.75818603269516, 47.46680974960328, 40.39842413317773, 41.82682583408971, 43.04527090441796, 53.399775105137984, 57.0903802687122, 59.7330810946803, 54.09716467703543, 53.88697662661153, 59.195645778409904, 56.49613334286598, 54.44323931970904, 50.950811909091094, 47.50240133654687, 51.518280813770915, 51.86857200437977, 54.57317959877753, 51.11589662490353, 51.00235969789567, 54.52755851130332, 57.37217118663173, 60.78680230725197, 55.777798314248365, 43.389325526452836, 32.11825166979144, 22.649136243327973, 15.596940209788663, 12.510797785174463, 18.781955780521518, 10.733545384099408, 17.487875646160497, 16.881781201208792, 13.554223756636343, 27.17406484388536, 9.64411001051626, 5.781621683028437, 1.479882073979224, 0.5036935865158035, 1.4630944522157794, 6.37798668876771, 20.182198785966445, 37.504436662120206, 50.81508613401844, 46.667885703425256, 50.365515831978094, 70.25827115581882, 63.3624815940857, 60.42716018615231, 32.864590460254306, 6.327617572199914, 0.4408596371931415, 0.17447297010690938, 0.1072899089945901, 0.13256143357965255, 0.12702719909289192, 0.12145416225276648, 0.11010804003284824, 0.23675971814701635, 0.13618081597791565, 0.16464275968891962, 0.1194973515286561, 0.14896489289258757, 0.06745195031286248, 0.06701372503753632, 0.10580379035203688, 0.12338330954193108, 0.14192580125264584, 0.11135302484035493, 0.26974780124522024, 0.1264173471398892, 0.24886239049655778, 0.07749070518559988, 0.16036972043014344, 0.12176633542103153, 0.09318426146262115, 0.18612435538201563], [0.05689635805244889, 0.03448418769685011, 0.06351547263142082, 0.046186705510462486, 0.014024013202757606, 0.05766474041006258, 0.07772495189020712, 0.009428351336429197, 0.017049591274811857, 0.02133303400759976, 0.05425587897339175, 0.10795115778643279, 0.027782326045956825, 0.05424909909526187, 0.06992056139654691, 0.027220069220469847, 0.048928193282336004, 0.012336864470384054, 0.05599298717213735, 0.051521186401406606, 0.10732400756809982, 0.023969129148510196, 0.013201475132166619, 0.02424466224657672, 0.0418537964804038, 0.027375642525693102, 0.07657074084084842, 0.05301102057039257, 0.2759480572515919, 6.667089394984707, 27.889632640346406, 50.82818292802381, 49.35375221313969, 45.683594365273755, 35.93251543660318, 24.50251106292971, 41.62087786582209, 36.008621185056626, 19.24523868868428, 5.378342213169222, 1.0762251985649909, 0.0739981639649599, 0.3266076437167583, 2.38211301545943, 1.2363479935353803, 3.5935198828097317, 3.4715623624863166, 5.476313704444516, 3.1962384523883944, 4.838086222448657, 8.088201861227713, 19.446905389908824, 27.278178276554232, 42.94842366249331, 47.708839601086034, 54.5077544643033, 53.54019987967707, 54.30658786527572, 54.03013529316072, 48.419898633034, 46.827231991675596, 40.469254293749415, 38.44063189721877, 39.88166755245578, 41.891156627285866, 50.125619749869074, 50.31359149563698, 52.71484690327799, 53.09748588069793, 52.84195915345223, 50.17247246157739, 52.39523256978681, 51.556198366226695, 48.44382509108513, 49.306487652563284, 48.89168916210052, 47.22426998999811, 40.957605069683446, 40.72522424882458, 38.43143393916469, 38.75630424868676, 43.03136217978693, 37.33957159903742, 38.95011248127107, 39.712436891371205, 48.66496439903013, 48.70716910208426, 56.24190884251749, 47.5577812810098, 29.40252219477008, 41.83867923675045, 47.35597533564414, 56.52542560331283, 47.56577507142098, 53.102812459391934, 50.849704973159305, 52.93084790629726, 51.64709537259994, 55.63598502066828, 50.83570603401431, 45.534265810443515, 36.81114204468266, 36.58287579013456, 36.938693600316206, 45.63530606608237, 49.093491185096006, 51.488168777958045, 53.29544005855438, 51.9440854749372, 53.982804052291385, 53.76442609294769, 51.50543505145658, 50.59921849158503, 45.358853493967366, 45.23001932328747, 45.7138240721918, 47.487912101130334, 44.70428051487092, 45.674714119203635, 48.05704801313339, 51.341766311276345, 55.84985225431381, 52.67051627559047, 36.88752235904817, 30.77370239842323, 18.100847967209354, 12.095969876935406, 8.588357010195333, 2.708906266958483, 3.544296833776659, 14.444423317909242, 9.082005927639624, 7.371640234224259, 5.528684210392737, 2.041706197684811, 1.0134639663081015, 0.29063598523216866, 0.18694279775504144, 1.55757638235246, 4.504010110132156, 17.590122030627345, 35.05645013624622, 50.54895724019697, 32.57283279972692, 42.795474759994015, 44.97377872467042, 40.19819498062134, 39.20986360119235, 16.409454288021212, 3.866644814129799, 0.014939857909696238, 0.035732420717155745, 0.04739403326605116, 0.12388808487523949, 0.07503522484893761, 0.021565760027677305, 0.018107200552138592, 0.040158585630237095, 0.007550401224439303, 0.07460345769481314, 0.10581453856561454, 0.0348812012722896, 0.0066349716413946404, 0.09568615140573633, 0.07220135070383549, 0.04696975845182615, 0.029490985569634268, 0.03523911755051344, 0.07578739295563391, 0.08506782037476379, 0.06668230774061334, 0.039794885388184945, 0.010744850451667464, 0.06292427108893472, 0.00938461441922212, 0.009895661139800664, 0.04436515527026308, 0.03411051299002382, 0.012858707285035523, 0.02570876735262573, 0.06245775035612526, 0.03145596470623728, 0.0005448316169936481, 0.02299992833286524, 0.031442650098113284, 0.04029842348949563, 0.017234385088686983, 0.07425698677017804, 0.03843112630889781, 0.013602747198855205, 0.041118853860684944, 0.026064002323114586, 0.020528109255997885, 0.06459492499068861, 0.014218092959884916, 0.06025572254833195, 0.020152312485621344, 0.020194629267338785, 0.05321787197082754, 0.06721555090118801, 0.07019288267099089, 0.011687709334036036, 0.024390722655000228, 0.0933992333950535, 0.3139431378053081, 8.538233041763306, 33.28258960477768, 57.101143252465036, 55.51368159632529, 50.31566642945813, 41.79298754661314, 29.739689134782363, 41.4851717026003, 39.48490412004533, 21.688137900444772, 6.2753882715778975, 0.8783456683158876, 0.15524731948971748, 0.08573424792097462, 1.463090652419675, 3.01984382733222, 8.377784567494547, 7.67804108319744, 6.642858953245225, 9.39228698130577, 8.179793127121465, 11.441973486254293, 19.76466444230849, 29.863443836089107, 44.451632807331706, 50.500312005319905, 56.77972855106477, 54.102679529497706, 55.283673809420684, 55.442572947471376, 52.263229124007694, 48.15228316091722, 42.24443274159586, 41.83361937922817, 41.45543621432397, 44.360214125725534, 51.639654636383064, 54.035253986235595, 54.34341892119377, 52.635571879725305, 52.4092471984125, 51.70201247738254, 55.32692578531081, 52.88020226263231, 50.69003312818466, 50.325397829855646, 51.687452639302904, 47.465409463451756, 42.300722675938765, 40.688130394104995, 39.11646020027899, 41.094511478177964, 43.62470303812335, 39.27692436402844, 40.06772518157959, 41.41605954016409, 48.51909537469187, 51.793066378562685, 58.426594503464244, 49.43170147557413, 33.78293106632848, 43.37649545361919, 49.386374565862845, 54.58196570796352, 48.89275996915756, 52.04303118490404, 51.497100014840406, 51.71747838297198, 51.54834578114172, 56.326506522394, 52.38894108803042, 46.87190778793828, 39.482358501803496, 38.775763127111624, 38.86350262549616, 47.62900760096889, 52.15750163601291, 53.111618180428785, 56.08113088915425, 52.502536850590865, 54.03413218836631, 54.993481174592056, 53.36452084202921, 52.089903508463216, 47.38476161033877, 46.213745840134166, 48.621653587587424, 50.24539716782109, 47.72116761053763, 48.54562628653742, 50.45270619853851, 51.9805399833187, 59.338537723787375, 53.340668909011356, 39.98674784937213, 29.62777214665567, 19.675020633205293, 17.94772255805231, 11.750728737923408, 5.542062434457964, 7.658008067838608, 10.918140949741488, 7.93478423549283, 12.701412227845962, 7.569388977942928, 3.093448574504545, 1.8807121462398961, 0.3332474503305651, 0.2567784689486988, 1.1921924016168042, 5.7083238613220955, 20.29087785751589, 34.66158513099917, 49.407822085965066, 38.03094425509053, 47.156750309851866, 52.8948680047066, 49.504433985679384, 48.16192434680078, 21.979299360705962, 4.11744091779955, 0.13300677581179526, 0.04405131586076271, 0.05222455470732624, 0.03549868346101815, 0.023799643686582005, 0.05748641812392781, 0.02322243090959326, 0.10236790899427668, 0.04017364308838883, 0.09722714492630574, 0.05152796627953649, 0.07933315430437365, 0.04948776305442856, 0.01695599256744308, 0.04029285403028612, 0.023427487749065605, 0.03538217297905395, 0.009485847192756351, 0.020984395054138957, 0.09659994108181807, 0.07775921134218093, 0.0998128602100957, 0.024986356016128294, 0.07265940233464203, 0.06178203016339291, 0.02276866171028345, 0.17369830199787695, 0.10109521478654877, 0.1703390830586995, 0.18001581542193892, 0.13496724077530448, 0.08456758028196712, 0.14191299226255188, 0.09719726749725881, 0.127650503549845, 0.15906426064189405, 0.13317461035424663, 0.213384322461582, 0.15443011817912902, 0.14197496877562615, 0.1079300597249981, 0.11902693523875169, 0.12493206353317346, 0.1770310142948743, 0.11939811249894482, 0.17306241837720718, 0.1960954340475221, 0.08439635197001119, 0.16235316803138103, 0.17173336308088996, 0.17453551352504762, 0.16162330074416054, 0.14330393214139248, 0.1773710807244624, 0.5995925035207503, 9.911985339656953, 39.32525188692155, 62.83984930284562, 63.61641583904144, 58.71693618835942, 47.972764122870664, 36.195981041077644, 53.15103800066056, 45.692600127189394, 25.280909345995997, 7.545118822205452, 1.7508335219275568, 0.4247170921054579, 1.1403774013442378, 5.746422823398344, 7.567953880756133, 10.86255508084451, 12.317322954054802, 14.028034306341603, 11.438919921075145, 9.911911795216223, 12.621731238980448, 24.373514113887666, 30.099525413205548, 48.91638048233525, 50.12951858582036, 59.81268559732745, 54.23744824624831, 56.10843450792375, 57.247902654832416, 54.9419020068261, 51.6818279604758, 43.81197660200058, 42.63024883885538, 43.981258253897394, 45.92487504405361, 54.35143624582599, 55.54775522601221, 55.31582940009333, 52.57628525457075, 52.731717017389116, 52.0313346770502, 55.232577093185924, 55.026287878713305, 53.99898382925219, 52.96789469257478, 53.91817123659196, 50.89822076982068, 45.703916165136526, 44.143656146141794, 42.51561757056944, 41.80801806911346, 45.7908437328954, 41.10647470720353, 42.313270338120006, 43.475154830563454, 52.35146284103394, 54.14487638781148, 58.78257313082295, 51.50198336570494, 37.70895296527494, 47.34360418012066, 51.935903410757746, 55.59180736541749, 49.31690546774095, 53.5916692210782, 50.86249582229122, 52.006945379318736, 50.42808155859671, 58.26181181015507, 54.22861506862026, 49.13116162823093, 41.905237936204486, 40.60015947588029, 41.57885751416607, 49.55842541110132, 54.01105688464258, 55.90546754098708, 57.57757002307523, 52.242373881801484, 55.826059156848544, 59.3359411147333, 56.01438391593195, 55.678707476585146, 50.79741193402199, 48.38815096885928, 51.08465494648103, 52.49706122183031, 49.699917070327274, 50.02783898384341, 53.11205356351791, 55.805929553124216, 60.6687742663968, 56.45465035592356, 40.77355177171769, 34.20063211071876, 19.802752617866762, 15.301432763376544, 15.525546208504709, 8.51602065947748, 11.263505643413914, 22.80162818970219, 19.344966911500503, 20.118978023529053, 13.57149689428268, 8.701142803315195, 3.1755332408412813, 1.23809871894698, 0.6062195930750139, 2.1197576868918637, 6.8122504315068655, 23.70237304318336, 43.635230679665845, 62.46898920305314, 45.22993695351386, 58.19641413227205, 57.77624591704338, 57.71016574675038, 54.021098152283706, 26.504420157401796, 5.580938025828331, 0.23257346132830267, 0.14624181804397415, 0.19014875314408736, 0.21680861290904785, 0.18731179166465037, 0.22774016664874172, 0.1748943337870221, 0.3179333220806814, 0.0984450102212929, 0.1801437214617768, 0.17086022203007054, 0.17862453846441162, 0.13959651091887107, 0.17968336390631814, 0.11813071195877368, 0.1491132841235207, 0.12520016366315465, 0.16350743270689444, 0.14555232359036324, 0.25544130844214274, 0.18292895668456632, 0.11089744001266458, 0.1105847076002148, 0.18482358405186286, 0.09656634046545914, 0.10980376523108253], [0.05953900899077135, 0.03061056561437586, 0.03744909735096078, 0.06469895206992665, 0.019679777962606282, 0.005662839103024454, 0.0021203949149968403, 0.05602866388677109, 0.05824921953101313, 0.03197281741567197, 0.03789628968544064, 0.043120231749790336, 0.039298820474575606, 0.06265528612740098, 0.008874704381601225, 0.053878925410249544, 0.009191091991059724, 0.02033490571193397, 0.04571716639123136, 0.07987310073428577, 0.042308841216107534, 0.05507172047791462, 0.04790770671060009, 0.03283679988535662, 0.07002100318429932, 0.028624068983199618, 0.013299834118374895, 0.009456533795943665, 0.041734501268834844, 2.6606508176172934, 17.562510505799327, 38.75860667997791, 51.89118446842317, 51.32219368411649, 33.37799733684909, 31.965765606972482, 29.611127568829446, 32.86334510772459, 18.52540727584593, 9.464148725232771, 1.6143480327821549, 0.15561093546209798, 0.03873502955802026, 1.080807630092867, 1.4689832781591725, 8.839059222129084, 4.824320174032643, 4.48364467390122, 6.276089395246198, 4.667073334417036, 8.844679978586013, 14.318387758347297, 28.26454454852689, 38.82304729953889, 49.58459154252083, 50.93659331721645, 52.30148007792812, 52.46100679520638, 52.21958491110033, 50.84752805771367, 49.05963328576858, 42.148895571308756, 39.65270311601701, 42.83490242496614, 47.97355644164547, 50.1637294984633, 51.149840816374756, 52.76463354787519, 51.75155201265889, 48.59112578053629, 48.964115727332334, 51.42353203988845, 52.083447287159586, 54.64832436653876, 52.94944778565438, 49.72879355953586, 51.42557951711839, 47.16564624540268, 40.96919567354264, 39.55451442349342, 38.94831603573215, 42.358754142638176, 37.74567811719833, 40.758913486234604, 40.743098489699825, 48.88795898806665, 48.75248032231485, 55.760488894677934, 46.369444324124245, 34.74393137039677, 52.94121080829252, 49.380169376250244, 52.23933012254777, 52.79399641098515, 50.05307159116192, 51.38691671432988, 50.16175654626662, 51.213865664697465, 57.87261855217719, 51.85616946989491, 44.85393462642547, 35.92176814233103, 37.18901534234324, 36.7838619601342, 42.38075079456453, 48.09540487104847, 52.44282268708753, 52.65737633551321, 55.64610865808303, 52.78435130273142, 55.70053546659408, 52.390306072850386, 50.25910585157333, 48.1843916831478, 45.541435903118504, 45.52363226490636, 45.44653807916949, 46.36579259749382, 46.48649177243633, 50.212284518826394, 52.50845962955106, 54.47512034446963, 51.116257482959384, 40.79218303003619, 26.724376870739846, 17.28202377596209, 19.160768485838368, 10.092736982530164, 2.7403053304841443, 6.3961678551089385, 4.57702208911219, 5.844965019533712, 10.711345749516642, 5.454499933027453, 2.8178236224958977, 1.337577993831327, 0.3840667508061855, 0.20109921393375244, 1.6286084224139492, 6.196735433993801, 20.288640145332586, 28.136279121521984, 36.79871205360659, 47.050101064866595, 49.143823039147165, 44.29862114690965, 54.05828614388743, 36.684131776132894, 14.747554871343798, 2.5464838599005057, 0.10071906561572706, 0.011656369634663627, 0.021134780028895028, 0.011628635336584862, 0.0489976889483871, 0.02987645036961523, 0.024798268024178765, 0.006006294514067592, 0.044537632305535584, 0.021433977582942576, 0.03557889286669032, 0.1081183947803032, 0.011294176670602493, 0.017701022649904894, 0.02653960119782677, 0.024803653622286457, 0.08575608908769586, 0.03463641319784426, 0.049490758458212505, 0.03988702278283816, 0.027360615711058342, 0.050277105577650576, 0.017644343634827003, 0.0278251139717477, 0.022518805964218996, 0.034472696377985904, 0.07327220372615323, 0.021002446000854817, 0.05014298656474679, 0.04387580511731006, 0.0532127813165707, 0.026031142896822384, 0.013013293294446364, 0.0915624916313156, 0.03894743892634588, 0.016987467289812142, 0.059851921433883334, 0.05540513343388035, 0.00950641090786385, 0.05902772957098581, 0.061148463958694096, 0.024339831434190277, 0.0435175096255637, 0.027845972630706047, 0.034262769134534944, 0.017318074448755192, 0.019687082610964295, 0.010087835253216326, 0.016540043213735187, 0.04166397521452558, 0.046171969809238954, 0.026720987835658655, 0.03724948165097064, 0.050483221533678235, 0.10392510527444464, 3.955313178800768, 23.028823637193252, 45.98174548918202, 56.313084171664336, 57.658041369530466, 39.54137056104599, 36.29437761922037, 40.10709401099913, 40.86983026996736, 23.706689611557994, 10.119444401033464, 2.1971774293530375, 0.4048193985175702, 0.14642552592821662, 1.007770462141883, 2.7026971549757066, 7.8492064533695105, 7.61115437553775, 8.54878519811938, 7.33796815718374, 8.466289908655229, 12.629357307187973, 17.521184413663804, 30.098619345695745, 42.25319923893098, 52.0123621725267, 53.66196201693628, 54.416241645812995, 54.29114941627749, 54.564181681602236, 51.62117242813111, 51.17256310678298, 43.3846265269864, 40.83423083828342, 44.90126586729481, 49.31963935975106, 51.515252743997884, 52.50102673807452, 55.030979033439394, 53.52074100125221, 51.24648801742062, 49.051741476981874, 52.79624785146406, 53.61827465795702, 55.05196763623146, 54.11508598635274, 51.51990859739242, 53.26239801222279, 48.67298172366235, 42.432792802010816, 41.67995660535751, 39.24484329838907, 45.03879201027655, 40.266499134802054, 41.86899131344211, 42.44768996392527, 51.10402361039193, 50.970404148101814, 56.859144779943655, 48.65505256960469, 37.85682239840108, 55.133878492539935, 49.33275184323711, 52.15845869433496, 52.69467415348176, 51.67551686686855, 53.49167231590518, 50.605051056031265, 52.613877250302224, 59.29188897532802, 53.90491362540953, 47.1815396893409, 38.64767812913464, 38.8666287545235, 39.18460353728264, 45.70232760521674, 51.86595578347483, 53.377951037499216, 53.59653296009187, 56.04517452178463, 52.641631941641535, 56.566567344050256, 54.779935575300655, 52.846336518564534, 49.79717616112002, 48.0512664394994, 49.04570102691651, 47.60152355317147, 48.645187808621316, 47.73364074768559, 51.19373213860297, 56.024731128446525, 56.66839599609376, 52.71436052937662, 40.32915507593463, 28.65573625410757, 17.448340116008637, 15.389570382333572, 7.645889905191238, 5.781857025238776, 9.463717264513816, 8.012047083147111, 10.064338041890053, 10.000105307948205, 7.441934010674877, 3.6632988481752338, 1.016306397655318, 0.3928536260800977, 0.07292857498771722, 1.6812347404418455, 7.103350114437842, 21.17214225953625, 35.30818000916512, 44.18756708022087, 46.38845605234946, 54.30024539270709, 51.55575906076739, 57.00263684795749, 42.99409966314993, 18.57475265379875, 3.2904302497063918, 0.08858689888110084, 0.07035440464894618, 0.04734884556983748, 0.027604656849777507, 0.023917994694784287, 0.061390934617168484, 0.04937469230724439, 0.02577604136369642, 0.016369529278768648, 0.06279962092277504, 0.018810821667073235, 0.16720147803425792, 0.031837112600764925, 0.015414281797054556, 0.07434540097751925, 0.034915675228882226, 0.03091514110565186, 0.041188062243764444, 0.02792295297577737, 0.028981163632124666, 0.005549388184707853, 0.018437878574214635, 0.01001918707193146, 0.03313286605501368, 0.023625894945355195, 0.00514216217843275, 0.18405840011133304, 0.2867906528615183, 0.1677031736941107, 0.1109477719892898, 0.28110585145411954, 0.06732723885966886, 0.07731034510558651, 0.18863119425312166, 0.09177308920170031, 0.1300581340347567, 0.28892396258250364, 0.16006722295236203, 0.12733888962576467, 0.14876068449549137, 0.1936985594370673, 0.14016009116124722, 0.07967528917135731, 0.10480042201496902, 0.13323995765418778, 0.15123830477316536, 0.09126613817868695, 0.07513268655466457, 0.11080516472218499, 0.14897229330193612, 0.17385994654990014, 0.2221594765902527, 0.1017650973892981, 0.12601747222605253, 0.20514588953266222, 4.838073965041868, 25.64639775983749, 52.88693697221818, 64.98196155794206, 62.727363571043945, 45.19855406976516, 43.412526346022084, 40.8416441179091, 44.00358830728839, 25.533608044347456, 12.66556372565608, 2.854448263683627, 0.5678745022704524, 0.3146202063127872, 3.065501687026793, 5.79902425889046, 17.996177557976015, 13.676073166631884, 13.782282125565315, 14.251525075204912, 11.265134407627968, 14.505990801319001, 17.282763142739576, 32.32616866788557, 43.14025894288094, 54.37412715727284, 54.16053841190954, 56.69199297505041, 54.49191593354749, 57.27483364843554, 54.97459103984218, 54.40015208336615, 46.154294475432366, 43.71294852226011, 48.39525830361151, 53.860720280678045, 53.13674096138247, 55.50052596676735, 55.39521817238101, 53.1611341814841, 53.37246756399832, 50.31732166967085, 52.37046280214864, 54.2176285097676, 57.18339143260833, 56.81245680778258, 54.535367950316406, 55.176455820760424, 53.00034446101035, 45.09000247524631, 42.99938701814221, 41.83603555925431, 46.035717302753085, 41.76876298842892, 43.96356444205008, 44.41999104715163, 53.29922906814083, 55.59765169697424, 59.13484511836883, 50.44327289827409, 42.6253576432505, 54.99292812039776, 48.79956445386333, 51.47692726504419, 53.21611404418946, 52.113476953198834, 53.58869214211741, 49.86455463594007, 53.107495769377685, 62.58942165682393, 56.51050098480717, 49.91716146469117, 39.63227148978941, 42.246613579411665, 41.981226013552764, 47.18425396950015, 53.58899024225051, 56.51714155750891, 56.48670396497173, 57.249204881729625, 54.04319678583453, 59.43580465932047, 56.45301080519154, 53.138341288412775, 53.89571566735545, 50.63136231514716, 50.41571040307322, 48.41243436259609, 51.088643996946274, 51.11251554181499, 55.52530357914587, 59.049545334231475, 58.69046411206646, 56.74168548276348, 45.67577315915016, 30.528150258525727, 21.7582953745319, 26.65841241036692, 14.477584996531087, 8.084179960912275, 15.041163890592514, 13.044250915127417, 14.68166885837432, 20.07720870356406, 13.443966911685083, 9.837770173626563, 3.737943513739494, 0.9864531156997528, 0.6783784565425689, 2.2696802356550774, 9.040576873287078, 26.464710081777266, 38.10299035041563, 48.132396744143584, 60.935534661816014, 59.03010999002765, 57.86894329132573, 70.6303785693261, 49.58961609871157, 22.348117866823753, 3.8337425022355975, 0.22971166327836054, 0.17893301142800241, 0.11554606919807774, 0.1570709458281917, 0.13508722546600527, 0.20787138521911638, 0.14702630740019584, 0.16022872960855886, 0.18891783371087045, 0.07748132826940668, 0.14495642975934092, 0.2029317268921483, 0.15490371373391923, 0.13370229171649103, 0.19530354428195185, 0.10837760829036275, 0.21745923606138076, 0.1781709990914791, 0.102115506005864, 0.13585489153140975, 0.29379585277168985, 0.1519719412129733, 0.1484006844581135, 0.09949766865540897, 0.16417340826122992, 0.19062190436788146], [0.03387039805191659, 0.018047602742069194, 0.034505527075980945, 0.058119919211153066, 0.07051083214220501, 0.028747365088953127, 0.040118925258397095, 0.06551038473844528, 0.019595565747529752, 0.03435436643720154, 0.024680409227467837, 0.09068055589112545, 0.032839416075618036, 0.07901701280066083, 0.00506971946789793, 0.01811432133939478, 0.027880956035768314, 0.022610407097325213, 0.056651409099539446, 0.012647965115555113, 0.05022996435722998, 0.027632123017082774, 0.021259386144999056, 0.035705925566294504, 0.05602216363073357, 0.008396966206360488, 0.04342447590803908, 0.03394672339181266, 0.024423384813651926, 1.0956323507332033, 13.812339248195773, 35.57198293747441, 51.035460579779844, 47.64943922719648, 38.46684901945053, 29.429714025989657, 31.26674432908335, 34.030181592510594, 22.096311507686494, 11.390480610632128, 2.283749532315039, 0.5129789398802865, 0.1165465034183956, 0.5973085196268174, 1.5920388169827002, 5.598688712043147, 6.825317317439664, 5.965951017795071, 6.61113384269899, 7.069576546069115, 7.527145541483357, 15.519952908638986, 25.38162208372547, 37.79727297444498, 46.54559796856296, 53.296334358953665, 54.51248876510128, 53.33991581393827, 52.815173287545484, 50.681019521528675, 45.360191022196126, 42.35875806500835, 40.18410190459221, 45.973484977599114, 47.59785221469018, 50.71809376439741, 52.76716739900651, 49.97685209397347, 45.47968602949574, 50.595676591319425, 50.99458948258431, 50.23550102787633, 51.22643686109974, 52.23424673080445, 51.011483130916474, 52.68061245641401, 51.22741745364282, 52.3205388745954, 47.96754737054148, 42.517229664710264, 41.25569735803912, 39.607529178742446, 40.106187943489324, 40.8249387433452, 39.8076641944147, 48.01056400422127, 49.32200454896497, 54.904839531067886, 48.91991061549033, 36.20086831431235, 53.300794093839585, 49.0505333869688, 54.81141651830366, 52.238180868087284, 53.442901565182595, 51.75067340174029, 51.24236168399934, 52.002403274659194, 52.551633158037745, 50.00814476320821, 42.07399791286838, 36.18536318502119, 36.5216201351535, 36.103640602480986, 40.3552859060226, 43.01127179976433, 48.51302354566513, 48.18639209193569, 56.200088531740256, 53.45390381351594, 55.16788544193391, 52.74607289221979, 52.34456731427101, 49.94102124244937, 47.33229990928404, 45.283030156166326, 45.345642951227006, 44.23280769778837, 46.43334365660145, 47.03140704862533, 49.93767546069238, 54.777103624036236, 50.449842868312714, 39.03024650389148, 24.463942397025324, 14.946507292409098, 13.30682319979514, 4.980949730642381, 4.902093420105596, 6.382754329712161, 11.310809427692044, 7.6834309101104745, 10.876726604277088, 6.604840399757509, 0.8086526273719726, 0.6230291555966101, 0.015745492250237976, 0.3127632091843313, 1.6830929633109801, 9.05860016422887, 20.03512559398528, 31.374383972537135, 32.86031899913665, 56.50594711303712, 41.62750274904313, 43.02976185275663, 51.808771548732636, 36.91224505824428, 12.89673645650187, 1.0186776542855849, 0.08038030456631415, 0.060593640101292444, 0.04034087625181964, 0.09319125584536984, 0.03443970480152676, 0.0510993822207374, 0.0492832022568872, 0.035078955378623745, 0.039521997208676996, 0.06369187203686565, 0.05776079251400887, 0.05432482688657699, 0.052856213353093595, 0.05007708768150018, 0.05729662367112695, 0.03529782286815105, 0.042156324601702155, 0.042052879749286565, 0.04230871481160003, 0.08905894693828399, 0.04016872480391495, 0.061872087629331704, 0.017041193035941933, 0.07737576901432007, 0.04911286260692343, 0.007232812293354543, 0.038153572653930996, 0.030747861976945595, 0.062297270257746985, 0.009114282100551553, 0.07574398641384418, 0.0368755464742501, 0.06289636250585318, 0.04738862085486612, 0.01792438707554773, 0.05188725385514479, 0.05588957679367835, 0.06112252039113834, 0.07423686930128644, 0.02954002285766746, 0.055437948810116905, 0.03320860533764766, 0.0395199747365569, 0.028026587434954224, 0.028444032575334274, 0.037358097596875126, 0.061043682282850634, 0.008678534162050534, 0.054966379557886434, 0.02788503736918492, 0.05237582259841504, 0.025091639479562163, 0.03657388403230617, 0.030866182341630903, 0.05661486670555127, 1.5704423693879959, 16.55223346525623, 40.103187330307506, 58.12850221510857, 52.37327121919202, 42.56697316323557, 31.76048444163415, 33.0089376049657, 40.03977437173167, 24.46430717745135, 14.381588908933825, 2.712748718838538, 0.24156266042301733, 0.08100612179165886, 0.3317340283143905, 2.0967260195362956, 3.538927354158894, 5.982589221769764, 6.246407349263468, 7.655395279007574, 8.28383497653469, 10.436754342048399, 15.756933689117433, 25.87839811078964, 40.337027272870465, 48.577134686131636, 55.25789599264822, 55.425581239884906, 55.29022416760845, 54.998850899357954, 53.890616586131436, 47.638127111619525, 45.38897337452058, 41.86961497029951, 46.459297980031664, 49.80174180000059, 52.44547420932401, 55.39946217690745, 51.62601263292375, 47.618091644779334, 50.74908048875871, 49.70230187139204, 51.14978198082217, 49.71046432372063, 52.16470310764929, 55.399195455735736, 54.99970205368535, 52.102647289153076, 53.07065686871929, 48.87130852668516, 44.979026855960974, 42.57824605511081, 41.785990038225734, 42.14070566238896, 43.05004835128785, 41.99784901834304, 49.24473777894051, 50.8965184611659, 56.05699262311382, 50.23978425610451, 38.91711358101138, 54.167845787540564, 49.351559608213364, 54.244971352238814, 52.5961285252725, 53.634995722001605, 55.9577605801244, 52.09312769674486, 53.612446015880955, 55.24883923992034, 53.024651388968195, 45.08082020667292, 38.37214339163996, 39.798991833963704, 37.612564640660445, 42.726174323789536, 45.56257355597712, 51.00188116873465, 50.74795476851925, 57.029740425848196, 53.874640772419596, 56.58610074750839, 54.463667023566465, 53.58948838326239, 51.734073931171054, 49.98000175722184, 46.47481487643334, 47.60951734358265, 46.63071732367239, 48.48012270465974, 49.945892826203384, 53.41809649621287, 55.940729648836204, 53.926290542848655, 40.84829645772135, 27.921782347463793, 16.59830954767043, 11.681181192398073, 4.4354544339641455, 6.099326802838234, 9.481819983451597, 7.161394819136589, 11.895199437295238, 7.539631916630653, 7.504086417536582, 4.036537865477224, 0.7607707837896963, 0.501381594447359, 0.3256592268664991, 1.7985671734617603, 9.951651288617043, 23.84199961539238, 35.12042791612687, 36.945863692991196, 60.9399434058897, 49.484892737480905, 49.98155501581008, 60.40479875379994, 42.72883369076637, 15.939680837815809, 1.389797856250117, 0.07225824805397181, 0.06569920242914269, 0.04157278010801923, 0.03081173264241267, 0.05606797568860555, 0.037704242934142394, 0.059925940849127314, 0.026741484518072782, 0.027997650378834338, 0.03781282440609029, 0.02100001941735466, 0.08058737813224716, 0.0682594606112088, 0.06443069106148136, 0.015748056729564506, 0.03632764422124432, 0.07177526792210918, 0.035024340970501784, 0.02873281133361161, 0.08003472230367123, 0.030057091986940756, 0.06644663611246694, 0.06852359240574223, 0.04432290935167863, 0.026118492241948846, 0.016486993540198575, 0.1624559463873025, 0.11216776700870645, 0.1499809399848023, 0.17176967564850085, 0.20088555201167063, 0.115364245890129, 0.15962586437742557, 0.22596351682178437, 0.09315306636234445, 0.21457733586430552, 0.15680949534139327, 0.2490361545595431, 0.21475460860998402, 0.14504250739851307, 0.1872797385458985, 0.10737439317087974, 0.12411990308112676, 0.14742214503067155, 0.21461473627676889, 0.12848178555648174, 0.1900810922586149, 0.14564641450922336, 0.08802652088624817, 0.1163936765383809, 0.1314931546127604, 0.11727250962247772, 0.15342560837105398, 0.10266631556254241, 0.09520574532929929, 2.1808701753616333, 19.33228784991849, 47.079165827843454, 65.06846550972232, 58.772924100199056, 50.30125564144504, 39.666062708823915, 40.47056828775714, 46.19983319313296, 29.424242319599276, 15.858998663963812, 3.557722616580225, 0.942189597314404, 0.5435908633855082, 2.560075362843852, 5.632539747222777, 11.892008589160058, 14.355877772454294, 12.990433054585612, 14.02897567518296, 14.19377503856536, 11.718441747849988, 18.832911291430076, 28.99243643206935, 42.665840425798976, 51.88873690943564, 57.32327492006364, 58.95649102426345, 57.28100353671659, 57.638986495233354, 56.020083119792325, 50.1643806119119, 47.52258977582378, 43.598238806570734, 50.653421724996264, 52.13448516784176, 56.47905142076554, 56.00095372046194, 54.41404119614632, 49.12352477350543, 50.60443916628438, 51.27276397520497, 50.986591769802956, 52.11626183602118, 51.773505518513346, 54.27580118179322, 58.30755056873445, 55.89094300423899, 55.98933958238172, 53.157862924760394, 47.95197163858722, 45.42794212218254, 43.11062543622909, 44.82068469447475, 43.84338301997031, 44.10464033003777, 53.34995315920923, 54.61756906201763, 58.50984288800148, 52.57704619438418, 42.04677274150234, 53.2288029116969, 48.76354140620078, 56.727753223911414, 54.33451121853244, 54.87639842494842, 55.69817419975035, 55.21491466029998, 55.631976358352176, 57.01522373384046, 55.84368236603276, 45.820481161917414, 40.60062231556062, 41.73169266793036, 40.59368756509597, 45.70875636992916, 48.0265280508226, 53.88549004831622, 52.753929399674945, 60.985501735441154, 54.920332893248535, 57.84320077588482, 56.28223865262924, 56.61159223125827, 54.198314759039114, 52.33831505621634, 49.67801455528506, 49.90897547814154, 48.21127953067903, 51.41188652284684, 51.72951221466065, 55.993642422460745, 59.45756989140665, 57.00188375288441, 44.4266826106656, 29.083019648828817, 20.347499232138357, 18.55500744235131, 10.618740550933346, 12.511646978316769, 14.569805802837497, 19.92786249806804, 19.13919152752046, 19.804772638505508, 15.088624569677538, 5.777749323075818, 3.3503672528651456, 0.9129619334013233, 0.8127672549697661, 2.574824700432439, 12.469268710382524, 27.50505601206134, 42.78859884508195, 46.12440209234915, 67.69406087936895, 54.41435106338994, 60.89687578139767, 64.50669188653269, 46.34272513851043, 18.807602197893207, 2.2225399651835045, 0.1863136097428299, 0.18224421197608595, 0.1066770003507695, 0.11890771663597516, 0.08384358122824662, 0.16625126853825586, 0.1526017114520073, 0.12367594746812699, 0.23122626506993849, 0.17420784239807438, 0.15880757522198463, 0.22577423181745315, 0.15381789135356105, 0.14869829429493797, 0.15420445932015298, 0.10559821831843547, 0.14557884555430184, 0.18040904835347207, 0.10602902786265458, 0.19151343152888362, 0.13016112689529696, 0.09967078154365863, 0.142334999456521, 0.19030123528453613, 0.06079391846733709, 0.08586411514589865], [0.03215187897665366, 0.08544800682894646, 0.004573920291037329, 0.05656903166504157, 0.01672702037819451, 0.043856304349197496, 0.03168593472500723, 0.05360802139846548, 0.11433683771399722, 0.007132370026797177, 0.04795276417186664, 0.042805189582248854, 0.01711173441200968, 0.02037434200305612, 0.06493558896885765, 0.06769329099164856, 0.06667699875129808, 0.006863538282848294, 0.054227526059314135, 0.018085978001416213, 0.033768025722595, 0.03451218821048256, 0.021252468371042804, 0.0602223709105484, 0.014923708776252405, 0.05012414080180949, 0.03999732795261568, 0.05530448097194876, 0.015945564730152968, 0.7265219957597795, 7.813446694804777, 29.899090336215114, 50.427716778170684, 54.66602602312642, 44.691901514607096, 29.797232266395326, 28.188872221977483, 26.536411008527203, 21.960160155450147, 13.00871326077369, 4.650977888414937, 0.5146469584395809, 0.19266757363032913, 0.18632206735351395, 1.6090237829954395, 1.9013586448084925, 3.452380991751148, 6.3151463962370356, 4.245622504142023, 5.785169957145568, 9.467010094273476, 10.139536742241154, 16.78165093544991, 32.05423466620907, 46.230972889930975, 50.73057474628572, 51.44536002989739, 51.77569027869932, 50.464869468442856, 49.207055568695075, 44.62174207933488, 44.3083054788651, 44.19023429193805, 48.92570003386467, 48.856128954118304, 51.50062230325515, 53.64635098365046, 48.87484258221042, 52.40947861825266, 54.22355521109797, 50.35486659696026, 51.092778175107895, 51.51126761590281, 51.53713172481906, 50.37805957178916, 51.880084160835516, 52.900461304572325, 50.16643985625237, 50.012655488906375, 51.55639448473531, 48.624830707427, 49.67200940655124, 43.84566191704043, 42.77019900660361, 38.342784450900176, 47.45130069794194, 47.91165751795615, 53.58027473572762, 48.96405296940958, 35.555807082883774, 53.83983365951046, 50.85565128634053, 55.5183570615707, 52.441438090416696, 51.7661157731087, 53.283374847904334, 53.00622801626883, 51.36885419968636, 50.12341145546206, 47.57993090537287, 39.052325525591456, 36.577710028617616, 37.39661855082358, 36.892644974493216, 38.70159895189347, 43.86683879360076, 48.017173197961625, 49.52597172029557, 53.08489899481497, 55.155129894133545, 54.300880816675004, 55.910829421012636, 51.17054700851441, 51.52703946636569, 47.88320464472617, 46.03920821220645, 45.61209740177278, 45.60657470457016, 48.16392475558866, 47.78975025300057, 50.17084467795588, 49.95503587107505, 50.542242142461966, 39.928936035402366, 28.29344261077143, 14.954796241175744, 5.966962989299528, 2.6511439729121427, 3.4042407620337705, 8.471470379060316, 3.368732035160065, 7.7656795805500405, 3.91251374636927, 5.390567750700059, 3.147090663833003, 0.5333788500678155, 0.41181188136819874, 0.31473490499681045, 2.615566849708557, 9.254244066053822, 22.419444207222234, 38.99958141388432, 48.385981898153986, 48.71188379103138, 32.13690842351606, 52.54469840757309, 48.029297244164255, 34.77167037225539, 7.9351818657690485, 0.7449692704023854, 0.012584190211078573, 0.08242820314462147, 0.060953659290868434, 0.046965525816044504, 0.027014755741542867, 0.06295225628080868, 0.029610774907914382, 0.06955553582238574, 0.0799272248461362, 0.024262240133999337, 0.011704445482351849, 0.07346744889453535, 0.04117153006635847, 0.006607124824151998, 0.03400552064000118, 0.05654648186699037, 0.013637120606407765, 0.061775568211751605, 0.02650748487682112, 0.03610429128692035, 0.015438577317963205, 0.05306573073950507, 0.08187480421075899, 0.07502350370369612, 0.04503121509427025, 0.0466461667430497, 0.02611446644990675, 0.07511911913752556, 0.01981333964654515, 0.07047909311950207, 0.05542559564233788, 0.020055310432648948, 0.008290819936401902, 0.040858226918405106, 0.05446423190615831, 0.019721742343878555, 0.016746869716312618, 0.01721963215048515, 0.05824621263591032, 0.01915504220843075, 0.09059886027488018, 0.07805125171979589, 0.03417646932986475, 0.013145621576827141, 0.015395594997361544, 0.038974083464352355, 0.05982008665018986, 0.045022255695995786, 0.03604414189354547, 0.007947128474517095, 0.03883918687220543, 0.04586039801999446, 0.05056454942771985, 0.020875122187839403, 0.016200369404208277, 0.935876848957231, 10.782978034788563, 35.08240838204661, 56.74424286811583, 60.37879736192765, 49.017295222128595, 34.534057109586655, 34.228174994068766, 32.011592618880734, 25.424109197431996, 14.700401117724759, 4.849218399293961, 0.7198076947562156, 0.10612269743315636, 0.4884395808462174, 1.2611587009122296, 2.3190400773479096, 7.592907019199864, 8.692619492930751, 6.6671148903908275, 7.8026817498668555, 5.907267457054508, 13.837654225287901, 23.888877822506814, 36.77156532964399, 48.15939834040981, 53.68227989442887, 53.99999580075664, 54.040321688498224, 53.34727418038153, 51.7662569784349, 47.005821427991314, 45.40786743164063, 45.05332046939481, 49.83570560332268, 50.658054044169766, 54.597239417414514, 54.13898891018283, 51.934785535258634, 53.00931492159444, 54.548492200912975, 51.53089123387491, 51.329944287576986, 50.37721626220211, 52.13843891697546, 50.75453258329823, 52.07104083030455, 53.96408257945892, 53.89548816988545, 52.44675682437036, 53.2863401597546, 50.84096593241538, 52.387203478044086, 45.62707301109068, 43.23465862581807, 40.0745540280496, 49.35323838264712, 51.592142966485795, 55.35135038437382, 50.482304403858805, 38.32374134371358, 54.940376204829064, 52.31596539097448, 57.622441937846524, 53.7743849908152, 55.568567322146514, 55.676942410007605, 55.89128032807381, 55.19552246216805, 53.83345196324011, 50.85059142881825, 41.788955350076, 38.144771437491144, 39.93604729252477, 38.342125492711226, 39.57913906343522, 45.2924556116904, 52.4946254299533, 51.80193093515212, 56.87477150271016, 54.05208879901517, 54.183570569561375, 58.16021065558157, 55.31389959396855, 53.3175818381771, 49.534973559841035, 47.574498422684215, 47.23737855111399, 47.57574181402884, 50.50754485591766, 49.764043900274466, 51.889301730740456, 51.834247343001834, 53.45517466145178, 42.14917405959099, 30.275418220027802, 17.33412265777588, 9.495472773428887, 6.091807128921633, 8.231558607470605, 9.470054834119736, 10.076311076841048, 10.269750606629158, 7.732034469804457, 5.565878085551724, 3.570746356441129, 0.7202628122702722, 0.1432818534874147, 0.21027020569289886, 2.6989083905373854, 10.217016300847455, 23.817810358539706, 40.519907782154704, 48.42632347537626, 52.77339612284015, 40.39394086407077, 57.87453659119145, 54.860128433473655, 40.22014848647579, 10.515525341033936, 0.8396772884072796, 0.04303898812542039, 0.058986253570765264, 0.08112020760534272, 0.04151286820190088, 0.02265203248469099, 0.02049932350224305, 0.03904896089807153, 0.06294172257184982, 0.08720987115896518, 0.05358752471605136, 0.038528775706166224, 0.08345692899198302, 0.005136215420920523, 0.027110317549217614, 0.008627915860063607, 0.016423653390619065, 0.04185055975892371, 0.05500749932722219, 0.03594942661302705, 0.05578468020464625, 0.03874637532017885, 0.010401730204091198, 0.07979410174753397, 0.02478981232871452, 0.04279220822237192, 0.0788821506824705, 0.16422775453857838, 0.2513300363094576, 0.1602955171537976, 0.29199012224712684, 0.1593541329906833, 0.2089841126073753, 0.08155172961133142, 0.15790587441334802, 0.13419640310589345, 0.042336075641815706, 0.15270131820392224, 0.15493011312378993, 0.18629588246826204, 0.15752978652956026, 0.22884543234061813, 0.2472758224053729, 0.14476915190537132, 0.12432675448156173, 0.11950027032364761, 0.09829644279013719, 0.0987590526440932, 0.13450763398601165, 0.12011408295121886, 0.16479180975546762, 0.10981344092156618, 0.10555642056128672, 0.11128998346506588, 0.15673941361808008, 0.1330900342474061, 1.243491365063575, 11.689881990032813, 38.67612707999445, 62.471589734477384, 66.65608406066895, 55.48880984706264, 42.27395249951271, 38.12299443829445, 37.60839908353744, 31.833987697478268, 17.96839148767533, 6.598294454236185, 1.1392285146059529, 0.6207772248214292, 0.7636811824575548, 5.235834169772364, 6.360383581730628, 11.41020424904362, 15.601534285852987, 13.194791482340905, 13.416525029367017, 12.868457148152014, 13.729787084364123, 19.26188522769559, 35.42450966373567, 51.16319256444132, 55.78896137975878, 57.07186668149887, 56.60440252673242, 54.801261501927534, 53.89564114232218, 49.66842436021375, 49.48871312602874, 48.41451714115758, 54.527652648187455, 53.40589792497697, 56.094674833359264, 55.36825972218668, 50.988231320534986, 53.668763406815074, 55.65505950681625, 51.67722702026368, 52.03336254242928, 51.85026630278557, 50.98735270961639, 50.54537219385947, 53.49443758687666, 57.882585294785045, 55.58269962187737, 55.66923103024883, 56.39848593742617, 51.79410972902852, 54.68948179675687, 47.99902439117432, 46.04930831540016, 42.32545714224539, 49.52051570338588, 53.82627794819494, 56.17206319685906, 51.12620853608655, 42.32207605915685, 55.96975518811134, 52.36984699003158, 59.564760423475704, 56.441910497603885, 56.520816818360366, 58.31681912945163, 59.115864769104995, 56.454395401862364, 55.31939483457997, 53.0824435910871, 44.10766055507045, 39.77080960427561, 40.47747950400076, 40.01732664723551, 41.85021100505706, 48.10521864121961, 52.709359507406916, 53.91052653712612, 58.68537287558279, 55.239476542319025, 55.116659287483465, 58.96223729656589, 57.205046838329686, 56.0908152211097, 52.87363229259368, 49.71270399708902, 50.45103919121527, 50.668448325126406, 53.1381255580533, 51.85493392329062, 54.91212337247787, 54.91350012440836, 56.508037736338956, 44.74642638237246, 33.742954269532234, 19.325963028015632, 10.122066505493658, 6.7798340032177595, 9.09386815563325, 18.655367166765277, 12.471953572765475, 17.618457232752156, 15.118045287747538, 12.151278238142691, 6.376895289267264, 1.4389804558407877, 1.0385628453185483, 0.738281261536383, 3.3193994049103033, 12.39709415743428, 30.306310807504964, 50.43850721851472, 59.885488710095814, 58.678077267062285, 45.17754585512223, 67.54244558272823, 63.44488666903589, 44.8594847802193, 12.771615789782617, 1.2412849092675795, 0.13427638268518832, 0.2255944616251415, 0.19173337537194454, 0.2731305084401562, 0.11597851050957558, 0.134189983289088, 0.12305656538134623, 0.17681065676433427, 0.14776974976543458, 0.23515329305683416, 0.11627266528986155, 0.13465011101816932, 0.13951461611976548, 0.09622898598712298, 0.1026710193423975, 0.15505794255483538, 0.11216991971577368, 0.16133062451356844, 0.20157300867140296, 0.1469576812439388, 0.14184465721970604, 0.11848024723510589, 0.16672238196817138, 0.19501459123867174, 0.22661898164979874, 0.16664722874279947], [0.10152322810984428, 0.03245963181759561, 0.026323007074214762, 0.051061671542664694, 0.0279142425560783, 0.028457904512423183, 0.033093554253179225, 0.029325591017221733, 0.04596552443540385, 0.04713347527168451, 0.0036444861419318666, 0.029001325151071917, 0.028804796785416625, 0.004291432072228242, 0.007400213517323738, 0.05715653683329302, 0.025044898540082, 0.018163615266882607, 0.029581090916068326, 0.13078303707222785, 0.02911824165963598, 0.022947935860664136, 0.027405454837266478, 0.04998051080732577, 0.07001876620756042, 0.05078726267862705, 0.058495145246026024, 0.03175578087628369, 0.0419946302539639, 0.1744348189282802, 4.1660856623803415, 21.430971622467045, 46.53195988747382, 49.97766402459914, 43.0804467201233, 22.7695922313198, 19.586449592344223, 30.338697818017778, 26.835772183633622, 19.14480051686687, 5.2067591105738, 1.2896246895674737, 0.25574300918848286, 0.03503041987818095, 0.5653970352103633, 1.5975298900758068, 5.950296348141086, 4.055711636620184, 4.265207388708669, 4.81878423883069, 2.785687888822248, 7.636027105392949, 18.001415883341146, 28.675346143784065, 38.41296349802325, 45.61189343852382, 51.53512347129084, 51.74421325806649, 49.642885808021795, 48.82706419114144, 46.61428651502056, 45.45771683416059, 46.92651502547726, 49.42134249594904, 49.78808410706059, 53.50345119353264, 52.51931675018803, 52.947459143977014, 55.739268872045706, 54.51126106323735, 53.706402470988614, 54.426353516117224, 53.689191110672496, 51.853753289868756, 50.52116332515594, 52.731983738560835, 51.87811120863884, 52.8714475324077, 52.2382632378609, 51.691802547824004, 52.67189694989113, 52.84493623241302, 51.93055329784271, 46.98796287659676, 38.73435074283231, 43.075928149684785, 48.96307629923667, 52.80154697356686, 52.580819514489946, 35.823920696012436, 53.51609691496819, 53.27639302899761, 52.0451767213883, 48.84158480551935, 48.85472474559661, 48.36543260082122, 50.18850318847164, 49.25589299971058, 47.488194511782744, 40.54965895991172, 40.09040432591593, 37.57180336982974, 37.49213218688965, 38.380270542637, 39.370700390108176, 43.45841807703818, 49.219932709970784, 48.58237105031168, 54.359763437701815, 54.449224856592, 54.188187199254195, 56.291715098965554, 54.22933678473196, 50.172990214440134, 50.19614004319715, 46.97989848352248, 45.4248591392271, 46.47512082130679, 45.888585275219334, 47.644959880459695, 48.64867479570451, 51.26928483286212, 51.107624346210116, 38.6850034036944, 28.476164264063684, 15.837829632143821, 10.149635864842324, 4.468086102316457, 6.502002227690912, 6.136937429828029, 9.27401771468501, 10.10280276498487, 5.459673539284737, 4.497930436365066, 4.298422019327841, 0.900769123146611, 0.04675012487437456, 0.42142579452164713, 3.698057176605348, 11.09415731122417, 25.44311308091687, 36.805717406734345, 43.92524680783672, 47.61219240004017, 39.298324815688595, 46.88825622681649, 50.92739928153254, 29.657417420418035, 7.015127674225838, 0.2992811648836059, 0.045732740958731984, 0.02935641839529478, 0.02314184995127782, 0.04393664015937717, 0.032933560620632865, 0.06260452514153815, 0.02162237392528163, 0.030898796619787335, 0.04571684846474279, 0.04289805092999051, 0.06042808467041581, 0.03560703893702838, 0.04799108388983915, 0.010129273906650563, 0.024207244597135052, 0.02360744180247909, 0.06499172789194892, 0.08357391827889989, 0.034250971380501025, 0.032519597349868666, 0.032511821557437225, 0.03199151379146403, 0.023583415369953842, 0.08533264164842906, 0.019223009529072913, 0.02215043258582873, 0.03084675052143153, 0.039836537588628075, 0.044620852436750166, 0.01526507851292169, 0.05606993304325208, 0.062252193644282326, 0.016244132176882798, 0.029571669949819485, 0.05081227544935481, 0.04523839208207304, 0.04916137512472849, 0.027209627442061905, 0.0502252261034183, 0.07178031644153018, 0.016062515712673628, 0.12019513505360774, 0.06784100040432907, 0.062453253420009736, 0.017542107286111965, 0.09868907817308942, 0.015309608331130398, 0.006748012702671752, 0.014340549241751434, 0.0610431038864678, 0.04027708027992518, 0.06707173321516284, 0.06038325703552654, 0.027026022979689222, 0.018935510137629126, 0.2626768097041115, 5.44529511082557, 26.059258599435132, 54.67958957918229, 56.44234980306318, 48.82235342456449, 28.826830041023996, 21.66967922641385, 31.33193608253233, 32.42392197732003, 20.370164648179088, 5.966545747172448, 1.1113901051782793, 0.41453498686032914, 0.08140808812552884, 0.7980202462884688, 3.5879599230904735, 6.550255225550744, 7.0476897205075915, 8.769309674539874, 9.334785034579616, 7.403941442889552, 8.574315905570984, 17.52071176805804, 28.49304222291516, 41.58853400138117, 48.82046284214143, 54.26917629857218, 53.823085138874674, 51.147526617973085, 50.50312042236329, 48.83003342536188, 47.49677665771977, 49.554189251315215, 51.584564947312884, 51.61225688072943, 55.00538164569486, 52.46875739866688, 52.42535245034003, 55.630768268339104, 56.66436772192679, 55.666834462073545, 56.047806432170255, 53.46189368155695, 52.90063781123008, 51.521332417764974, 52.67152040235458, 54.59813764018398, 53.99264135668355, 51.88519108679987, 54.2933302540933, 54.57214017068186, 53.914503820480846, 52.73738091991794, 49.041951241031775, 40.71475544283467, 44.343736248631636, 49.79905497643256, 54.78816470792217, 53.74282952277891, 39.1737699508667, 54.69637340114963, 55.95683490076373, 54.91310396502095, 52.24404088912472, 51.479272842407234, 50.52814906643283, 51.09816358935449, 50.92812099764424, 50.10681590726299, 42.66111396974133, 40.4419820539413, 40.131624514056796, 38.6147145302065, 40.61448789411976, 40.905068843595444, 44.577697784669944, 51.032001049287864, 50.620387523405014, 54.94450646062052, 54.79773921351279, 53.388007994621034, 57.47213671284338, 56.5268337342047, 52.53894821290047, 50.77562316771477, 48.85629369366554, 46.94794293372862, 49.16374867962253, 48.769326902204945, 49.94657139624319, 51.13232743355536, 55.0765295182505, 53.975073060681744, 41.59229163200625, 28.7621364285869, 17.371189055904267, 10.697511549918882, 6.182903195581129, 9.871064232241723, 8.216939443542111, 8.084591319484096, 6.740453406687706, 6.739080086831124, 6.7152070710735945, 2.821955349176161, 0.8186581033852793, 0.17491610600583016, 0.4640678112064639, 3.514448822506013, 11.962152334951586, 29.64415784805052, 42.9238853146953, 49.91170937015165, 54.85958714638987, 41.99344027426935, 55.41388865440123, 58.980837175923014, 34.64238905137585, 8.113810525786493, 0.5322852442341467, 0.013665810599172068, 0.03634991056676354, 0.014647784015734591, 0.03171791698062613, 0.05508492017284997, 0.10163932873476898, 0.03699670327947505, 0.03924150177608094, 0.06438719258914072, 0.0759348112549032, 0.026488817229326216, 0.0033807297304813424, 0.009235083632501624, 0.0557616018059273, 0.028435345138272936, 0.00528881247455795, 0.03744506772847907, 0.02094949208830874, 0.10281073079714853, 0.00852071526159923, 0.040351586161001075, 0.1382003003551114, 0.05601800760374435, 0.016107737882843903, 0.06923717266369252, 0.04559694804371365, 0.18691212359455325, 0.11651245081016134, 0.11748819401667965, 0.2132695471687663, 0.11487108444975269, 0.11833571708731114, 0.11267987380345022, 0.1898047949878439, 0.09787412916099834, 0.1188940343056475, 0.10634239612808151, 0.12941454356956866, 0.1243134858387132, 0.16057564486419001, 0.1164154410963097, 0.2733786289970721, 0.12179775268680627, 0.12961695932092207, 0.09821113123888932, 0.2519510118591209, 0.12253836818760443, 0.08310007757597393, 0.1287163770006549, 0.13310258276760578, 0.14185133750640577, 0.224003771980924, 0.1717295939283025, 0.12855606544162, 0.12273405002610338, 0.435193742835714, 6.4820658006975735, 29.553088257389685, 59.46747779846192, 63.529845206968254, 55.25487184524537, 34.00878898559078, 30.055720383121123, 41.874027636743364, 39.55094114426644, 25.719132231127833, 8.537459354246817, 2.088132106488751, 0.7740671283775761, 0.7336199535958229, 2.7223852469075114, 7.954843726850326, 14.440456821072488, 14.818963581515899, 13.187688069958842, 12.599623780096731, 7.433416583845693, 9.966990697768427, 20.808730740701, 31.40027749922968, 43.592210123615885, 50.946818936255674, 59.1109892629808, 56.097757816314704, 54.45476716564548, 53.32463425974692, 51.37775405760735, 48.77188820992747, 51.497260832017474, 54.33306778630903, 54.64715942259758, 57.420800732028106, 53.44984023801742, 52.987126073529645, 56.45035143821471, 57.90985361222298, 58.58207725709485, 58.42845762929609, 56.08174670127131, 55.60263310709308, 51.79398029081283, 54.15400374320246, 54.757421170511556, 58.191209147053385, 55.667528721594046, 56.2107926799405, 57.91971052846601, 56.169980418297556, 56.48043601743637, 50.74877062151509, 43.09224520960162, 46.27597816528813, 52.329925106417754, 57.24652590290193, 56.25907313439154, 43.43161259928058, 55.450955052529615, 57.27926200436008, 56.72787089501658, 55.264238465216856, 52.84113153334587, 53.60973958046206, 54.12773955252863, 54.51548937828311, 52.70909670860537, 44.43814769867928, 42.46652126312256, 42.59976025550596, 40.09700175254576, 42.78854000952936, 43.17862756790654, 46.94418138073337, 54.34004176047541, 53.11121417630104, 58.72889157264464, 55.97874918291646, 53.58522868925526, 59.45097246477681, 59.15430007442352, 55.41829347610474, 53.51833658833658, 51.922775237791, 49.49514581311134, 51.90168465337446, 51.0454273223877, 52.68298156799809, 53.86882389745405, 56.132007952659364, 55.78477621078492, 42.89293389166556, 33.28084807242117, 19.61763439639922, 15.90850583968624, 9.839686251455738, 13.15218375575158, 18.08674704643988, 16.690946125215103, 17.656527757644653, 10.569545203639615, 11.524608019859562, 9.18800700095392, 2.246359293499301, 0.38654985627339733, 0.8622891395803421, 5.0064843604641585, 14.753449213120247, 33.656999449576105, 49.18823995897847, 55.976686016205825, 57.844346107975134, 53.64665300615373, 62.35460504408806, 65.98704538037701, 39.905656768429665, 9.320918475427936, 0.5788187117826554, 0.18139382373661767, 0.10645449011316223, 0.14713169045505986, 0.10152479092920981, 0.17647147899673832, 0.2286986345725675, 0.15248817722162894, 0.14391448889528552, 0.1428104029788125, 0.09918170335191874, 0.2053429120250287, 0.1438151732567818, 0.08428768239795201, 0.15706994991389014, 0.2951477221663921, 0.21195541526521408, 0.14349082695139995, 0.08959865588093958, 0.144051879103626, 0.1333020107760545, 0.10871633406608336, 0.15434468405381327, 0.1133564749972955, 0.12359778351721265, 0.1198737458476136, 0.13661641357166154], [0.0530838487189143, 0.09483082956003566, 0.042534787358055194, 0.016706188532313513, 0.06260873096424245, 0.009329311489578216, 0.02858080991333531, 0.05211385883270733, 0.021450331644906152, 0.027263531303634087, 0.022364626939017928, 0.04444672831244046, 0.04822365669233184, 0.01901568698456451, 0.03119318122645059, 0.027623267040678093, 0.011604154039354575, 0.02636984760512508, 0.0021196692860910612, 0.028052331819649667, 0.023049739369701956, 0.014229254860941683, 0.07176785219100214, 0.09236626342059144, 0.016021281030149232, 0.0795388029467675, 0.07532899658526145, 0.023639447040735714, 0.034900679057764436, 0.08660348958425945, 1.538460466169542, 10.604099323672633, 32.34200523745629, 52.98147786048151, 45.13830254154821, 31.20014248355743, 21.990227084006033, 29.304449212166574, 29.310507312897716, 16.764033609820952, 7.659152419336381, 1.9144661027577616, 0.2604056041567557, 0.17376199454790162, 0.4399605257616889, 1.9889416161083409, 3.577566132430108, 4.872469229082908, 4.884492764549871, 7.644790660950446, 5.858718810542937, 5.409448569820774, 14.334835237072362, 20.695809625810195, 28.785892263535533, 43.23096767548592, 50.299529798569225, 51.19364976882935, 50.663259029388435, 48.93621198592648, 49.503861319634225, 51.35912279928885, 50.466026567643695, 50.47910374979819, 53.13550933714836, 53.55322214864916, 48.93617276222476, 52.172445866369436, 52.755106110726636, 51.48634095345774, 52.28753605196553, 53.59050427713702, 53.90492539252005, 54.854354704580004, 53.87584886243267, 50.76427182843609, 49.22176053447109, 52.43392282916654, 53.58233790243826, 55.604527611886304, 54.978258455953295, 54.26711705423171, 51.94247338079637, 48.21977930684244, 38.40673085181944, 43.73722799362675, 49.99458120715234, 52.72475481033326, 52.013009363605136, 39.333481019543065, 55.03731758363786, 50.699203629647535, 50.52960034339659, 46.502420517706106, 44.49712445659023, 44.367364606549664, 43.64149470483103, 42.833215805792044, 40.64827519078409, 38.147175850406775, 38.69646456933791, 38.98325650922714, 38.84101567729827, 38.56482982635498, 41.32852400502851, 45.75561300400765, 49.94095848452661, 49.64202680895406, 53.097995788820334, 52.98854204916185, 51.409725296881895, 54.40858910160681, 56.850801898587136, 51.20244372275568, 50.45571465646067, 50.12879686970865, 50.639677739912464, 48.92827310869771, 49.41026964495259, 49.42198184228713, 51.853878805714274, 51.26198922434161, 49.54177102734966, 40.024783072933076, 25.211652055863414, 19.35832650430741, 10.155385078922397, 6.4525274115224045, 12.670314696527297, 4.902489579493, 7.399291473050272, 5.851223161143642, 6.116677407295474, 5.502976996283378, 1.6291120792588882, 0.7643244511658146, 0.1381414188372512, 0.47378355276680767, 3.1134153998667196, 10.846486110841076, 20.966019745795958, 31.365466463950376, 48.00532371767106, 39.195350831554784, 42.19752119433495, 56.53664358200566, 47.07483945354339, 24.95638616623417, 3.8793057347497637, 0.27213189750909805, 0.06490101542083487, 0.05879229159965631, 0.01261738384322774, 0.05721876998582194, 0.0018946727340657925, 0.04389865368965172, 0.04750504706715865, 0.0628116944684617, 0.05554597869875932, 0.037775948763855045, 0.056201462678971796, 0.012377542781553442, 0.025800632786065824, 0.026770779720297264, 0.056158665177081867, 0.021586961510981766, 0.012593958789723055, 0.047504277148794745, 0.0013198539818404245, 0.02319899436476971, 0.037189761266833356, 0.0233588328645114, 0.05615528289889617, 0.06555317074901636, 0.06753111017807838, 0.06541643171541153, 0.03342181526785416, 0.04361378772544765, 0.024065257861248912, 0.01981437961090236, 0.026130422146149704, 0.027270621447373303, 0.0067983020656561905, 0.06262790997542682, 0.0128145327401017, 0.049705155824701634, 0.043910294395661166, 0.0122997178245456, 0.06371331483786626, 0.1271769616212095, 0.05232490073408812, 0.00981347426967395, 0.05506133998654062, 0.0034051296308696753, 0.037402837131653106, 0.012958084210573186, 0.011851429026724111, 0.027456966589295098, 0.10526609622062215, 0.04169497113194197, 0.031416752495832985, 0.030194012966427593, 0.03622395422069296, 0.024828915371589606, 0.048088468986773686, 0.0714675840290804, 2.2013937321401413, 14.783693628926432, 40.29932152840399, 59.0491452524739, 48.539911393196356, 33.94139089891988, 27.823468139094693, 35.25090163753879, 35.07646991360572, 20.705792057898737, 8.483006069737097, 2.4803848132010433, 0.2714025205181491, 0.23062859391493185, 0.8178925670443044, 2.8435546159744267, 4.465117848688557, 5.597059457532821, 9.126570916944935, 8.419295011028167, 6.907994506820557, 7.173441888824587, 14.000804232012841, 22.89413336784609, 33.522450385555146, 47.345106447896654, 52.237980827208496, 54.91220966462166, 52.5423449854697, 51.546768988332445, 49.49796599726523, 53.173034652586914, 52.44790215646067, 53.825901400658395, 54.7456972060665, 52.94849857207268, 49.09593482171336, 53.36275577545167, 54.26828199817289, 53.93061299477854, 53.620486874734205, 55.697821186434844, 56.2712364042959, 55.26514061035649, 53.87397789186048, 51.23998472767492, 50.49655437469483, 52.69655689116448, 55.60956393518756, 55.07177952797183, 56.9565176194714, 55.914132056697724, 53.67542751373784, 49.90653184152419, 40.19677508261896, 45.02979017073109, 52.436570429032855, 55.67281215421615, 54.90117995969711, 40.04656399449995, 57.12580319373839, 53.48735770871563, 52.506333704917665, 47.753123160331484, 47.362470780649495, 46.782787615253085, 47.18889021104383, 45.99688191567698, 43.553006033743586, 40.874901894600164, 39.14858048962009, 41.01413034623669, 40.9995508963062, 41.51816275811965, 41.87121921969999, 47.522742748260505, 52.60928415483045, 51.35887568996799, 55.4005604405557, 54.70096257425124, 51.46143782523371, 55.001612247959265, 57.58379874690887, 52.59819953672348, 52.7319170582679, 51.356628171859256, 52.365916775118926, 51.230943664427734, 51.265837069480654, 52.089064121246345, 53.85642528533936, 54.608500542179236, 51.852933514502745, 42.45085139428416, 27.503000690091042, 17.672074071822628, 8.056252194989113, 3.3780214334687884, 9.629252072303526, 8.977135477527495, 10.57859116984952, 8.304103824400134, 7.245611048513844, 5.722687090596845, 2.304834723472595, 0.7461312112789, 0.19033483590089506, 0.5544948686034449, 4.090581262303937, 11.657322395232416, 27.02059034378298, 37.257394021557225, 49.542763387003255, 45.6069943981786, 48.13039241298553, 59.955985469202844, 54.57185383765928, 28.57284284407093, 5.574051324398288, 0.3051523095177066, 0.01415744369413944, 0.025912357133723078, 0.06340336715502125, 0.031138675985857848, 0.031007663459487023, 0.06191598446739297, 0.016795974037039186, 0.047731636722962704, 0.004603392172289352, 0.011111111342606526, 0.029543828399431322, 0.02894981531426311, 0.030596971384159503, 0.034515015074923154, 0.035698617087496866, 0.04918434244069842, 0.10181598094922882, 0.0035643329958416404, 0.051368459112822056, 0.05512059688748372, 0.03425149998116878, 0.04739864894579496, 0.031464177168785565, 0.0540703822738461, 0.03957818592748335, 0.050840804563655015, 0.12261399638748939, 0.10688266431492184, 0.14488784956835932, 0.13794336978706623, 0.1592793934527905, 0.11787013481220893, 0.1044507258601727, 0.09655090379378489, 0.09013764470094636, 0.11553201914554644, 0.10723210766070312, 0.12686295750280543, 0.23465038697806098, 0.23795666924167067, 0.10460326928765544, 0.12005805894131623, 0.13429617839715174, 0.137031173573867, 0.12807322320558373, 0.13684219500470546, 0.06645533887128677, 0.20405151761106907, 0.2069850061689654, 0.14786417776298139, 0.10644416324794294, 0.1535289995973149, 0.13019383884966373, 0.12189714493410242, 0.0911860207035657, 0.22755224528091572, 2.3339156662264178, 16.377117287728094, 45.01137856514224, 65.62548914263326, 56.20802348659885, 43.745892509337395, 34.41138890481765, 39.85867069613549, 40.25540274958457, 24.52969308822386, 11.734685263326092, 3.087701076461423, 0.7456109456477628, 0.4454209553378244, 1.7233379521677572, 4.711781490233637, 10.203132091029998, 14.747538201270567, 14.338283000453828, 13.773438161419286, 8.008882220714323, 8.55575034695287, 16.081109739119007, 24.883241807260823, 36.229176059845955, 49.08719578096944, 55.28492896787582, 57.04603002917383, 55.46677789380474, 54.38302309282365, 54.05846265054519, 56.181476885272616, 55.44137662456882, 56.65729961087627, 55.21821729598507, 52.10890346957792, 48.3180856704712, 55.44644824920162, 56.9516578028279, 54.874405860900886, 55.652855134779415, 57.73262131598688, 58.40913211145709, 58.48861109825873, 54.70780318783176, 50.769174791151485, 50.192598142931544, 52.81186672949022, 56.00095764283211, 56.91552492880053, 57.4525248619818, 57.257622288119414, 55.76279524833926, 53.11232028468963, 42.42781531426215, 47.2102592837426, 54.05223392671155, 57.27268811195128, 57.1251363908091, 45.33607629037673, 57.72745163209977, 55.10313103275915, 55.14581818734446, 49.74214138523225, 48.155927042807306, 49.36361697412307, 48.27310785170525, 46.40050557351882, 45.549414004049, 41.90160974379509, 42.03964187252907, 43.70513908324703, 43.57601857954457, 43.65239104916973, 45.30569753339214, 49.214935610371256, 56.062601612460234, 54.49097064233596, 57.365393330973966, 54.13027732603012, 52.16569546730288, 56.150925544000444, 60.86848566609045, 55.049947615592714, 54.683774748156154, 52.73636502604331, 54.266681671142585, 53.19720429758872, 54.691191950152, 55.17934660757742, 57.15697426949778, 57.10509307922856, 55.626135949165594, 43.792847202670195, 29.8418806060668, 23.4450694822496, 13.656301479185782, 12.099842236888025, 19.53693555247399, 11.446621494908488, 18.648828575688025, 15.172526028848464, 13.075232736525997, 14.22269565443839, 6.438442180233618, 2.3090132734467907, 0.6106589193786345, 1.0172163262482614, 5.0421700842918895, 15.2840615664759, 29.625465792994348, 42.69148488198557, 61.212901146181174, 50.42581442863711, 55.43861135359734, 68.6886876629245, 63.10616647043536, 33.98210117893834, 6.298515056410144, 0.6863920426657123, 0.13306257765619986, 0.12744618023956014, 0.15106857033266177, 0.16965375612339667, 0.12657212754411082, 0.18388197006237122, 0.16683525736293486, 0.21615520119667056, 0.0768669180932545, 0.12942732191614567, 0.13733802243105828, 0.175814911002113, 0.13750401836249138, 0.09604189965513446, 0.1496625691652298, 0.13474050939323443, 0.1765856567409731, 0.0938064474312048, 0.20649121653649116, 0.1695651197505574, 0.1458435595756577, 0.12325501279725183, 0.1527677227051989, 0.14651719600923602, 0.17122627416205022, 0.1330689361859714], [0.0313471170187357, 0.06871787996421899, 0.0899098024913861, 0.029749019304290417, 0.0337988645919869, 0.019660127807348486, 0.022424736112776785, 0.029668978437961593, 0.02953841024258685, 0.021978555014356974, 0.04767956955718899, 0.0535067790488322, 0.04444959348127727, 0.01734991306288829, 0.04016846816446032, 0.0182396418324882, 0.04199091089709152, 0.2166441644752218, 0.08847246066697183, 0.04716723293606793, 0.055438370158475254, 0.05690232970781865, 0.018757741350019654, 0.014795442675090125, 0.02297263836578256, 0.0760477249540629, 0.029790581489402442, 0.024823319099302736, 0.07912280954300396, 0.0275954561338069, 0.3332094217260038, 5.3822788019334125, 27.078045222067065, 46.04328355481548, 47.54100922615298, 36.451719576312655, 23.399968108823224, 22.743957581058627, 28.353817693648804, 25.39093771288472, 10.31935388042081, 3.521166616870511, 0.6263950395007288, 0.15222977576476915, 0.5312791562849476, 2.9085987902456716, 3.3033424471655204, 3.7446907258802846, 8.252552113225384, 8.748249488492167, 8.289467500102136, 2.658702625382331, 4.749552934400497, 12.64433095532079, 24.515092065257413, 38.30805578539449, 49.17545695458689, 52.19563884119834, 51.785237327698745, 55.38032885520689, 52.02651408410842, 54.22725792854063, 53.90169335949806, 51.706797768992764, 51.087035825175626, 49.44512382630379, 49.78643278921805, 52.45165194234541, 49.89137188080819, 49.070529630107266, 49.23636744099279, 50.364515627584154, 50.117755397673584, 51.98742374297112, 53.86047709372736, 51.878122975749356, 52.31496910895071, 51.13619096817509, 54.836790330948375, 56.65827628104918, 53.40977714907739, 51.78883806351693, 48.841565193668494, 44.6219656544347, 40.07958250661051, 46.29369943372665, 49.006457713342485, 52.968047665011504, 51.5028815884744, 40.26298076875749, 55.55980082481138, 50.59019311781853, 50.10251306718396, 44.08286333084107, 38.103174701813735, 38.45508190893358, 38.18372057330224, 36.67255686175439, 37.84898158042662, 38.91151243640531, 39.12778408296647, 38.699778972133515, 39.58980006556357, 42.68318514670096, 46.51565851703767, 46.787231660658314, 48.094279150809015, 50.93143540043985, 53.23818522114908, 51.00623107725575, 53.5639419863301, 52.87485607208745, 53.78155508349019, 54.79189488195605, 52.294443345838985, 52.55077808134018, 49.65713970122799, 51.42878017117901, 52.36255530388125, 52.11438694307881, 52.457896355659734, 52.22775913053944, 45.70662260055543, 34.67807869757376, 21.164964322120916, 11.463033672302, 5.235144813214579, 3.231083808406707, 5.5660114461375825, 7.204839481461433, 5.649620688730671, 4.57956035290995, 6.162068055522058, 3.250004831821688, 1.6500735931819486, 0.2662837967997597, 0.32200189247246713, 0.5446369104808377, 4.128172032294735, 13.954203532588098, 32.28489748893246, 35.331063116750414, 52.086714621513124, 47.169925551260675, 42.12138406692013, 55.075992153536895, 44.32848999577184, 18.59149136850911, 3.3000390760360228, 0.0966921167808675, 0.027049681690010815, 0.019427673748484062, 0.10911203380073271, 0.08370567008011764, 0.034082910842112, 0.010965912783097838, 0.031143751318356207, 0.05472564791900016, 0.09526947618372018, 0.022255717964482405, 0.13844627586583938, 0.06066495905660334, 0.045105368574900974, 0.08032326932035147, 0.05771511452152364, 0.02316842745659092, 0.0683365980043046, 0.011193776060076011, 0.015464987241542869, 0.08622108147509637, 0.04651255717861556, 0.022227550826726422, 0.05388970426734417, 0.024974858951604655, 0.057309375204626596, 0.05973791222899191, 0.05951680393228608, 0.03176335940107463, 0.12974080509476124, 0.07030902926119105, 0.07556495166593984, 0.005529690627759744, 0.010675661220786073, 0.04993968981228048, 0.05968328249911147, 0.04501229655298014, 0.03828790234101396, 0.04041200368514946, 0.010681588826100192, 0.06140267491460808, 0.10085234193191414, 0.03194662869998044, 0.0694933524655719, 0.05232134608611946, 0.038215533845246806, 0.03212346094510248, 0.08585903598296066, 0.020983560018301494, 0.03678989784431554, 0.06328894809309034, 0.07801788859069347, 0.033330953409594875, 0.03183584855568986, 0.05908843820854541, 0.06846781354397535, 0.04698195840202032, 0.6224348552284703, 7.496886416789025, 33.96615282181771, 54.66604563497729, 52.55660280104607, 41.94292799119027, 24.471640048488496, 29.719163371670632, 33.96794926735663, 27.896826267242435, 12.120889675232673, 3.684217093452331, 0.45837522634575445, 0.16979707585227105, 0.4212933532412975, 0.6410141421421882, 4.503479609566351, 9.510351304085026, 12.479811060813166, 8.716808749783425, 8.26142647574025, 6.85055531801716, 7.65322522770974, 19.063393685125536, 29.23230701877225, 42.74322094455842, 51.404053549612726, 55.071320610661665, 53.49035047715711, 55.897854220482614, 55.5691635224127, 55.228282097847234, 55.48769197156353, 53.97559865828484, 52.29579656354843, 49.34526028171663, 50.126757237219046, 53.003698087507686, 52.446344975502264, 51.126400732224994, 51.20135330384778, 53.73795009428456, 52.2871438149483, 53.714584535168065, 55.092356281895796, 51.09319394634616, 52.5254709489884, 50.90391212894071, 54.541557450448316, 57.37204959315639, 55.038568819722826, 53.286975583722516, 51.75471344301778, 46.993391436915246, 42.09729286932176, 47.649933445838194, 51.868568082009595, 54.96714638125513, 53.388470834301366, 42.919539328544374, 57.64930232878655, 53.42474883602512, 53.010530856347856, 45.692992364206624, 40.198893162512014, 40.49777384727232, 40.5611515045166, 39.519479813114295, 40.31207315383419, 40.58898464325936, 41.6761048378483, 41.332462064681515, 40.41949118337324, 44.04217266267346, 49.76996667923466, 50.31114785901962, 50.51941394805909, 51.693567614401545, 55.342203417131984, 51.198278165632686, 53.35472668370893, 54.62759856254824, 56.037235644555864, 55.5263194730205, 53.09606206032538, 55.14650852449479, 53.1391453742981, 52.61812125482867, 52.944509521607436, 54.826917725224654, 53.46117981018559, 55.74410907683834, 48.91933794944517, 38.88233000232328, 25.91423092349883, 17.146698082647017, 7.635474541494924, 4.5274546069483605, 7.682068867068137, 7.2222410767309135, 9.148166506521164, 6.777191306314161, 9.59618551115836, 4.512802102873403, 2.864696926647617, 0.3692182507966796, 0.19772375393058025, 0.4655979952264217, 4.3538858044532045, 13.942281488449344, 31.79333821419747, 34.5812039990579, 54.86443911829303, 49.007367703222464, 46.647418775866115, 64.06462900100216, 51.117630312519694, 22.735506834522372, 4.489155113697052, 0.1394171544140385, 0.04402177551040246, 0.04496644619071195, 0.030053276869077838, 0.03288637343493681, 0.03411719710716317, 0.016400255150191726, 0.07012120748479521, 0.033142392358352105, 0.12516422647862666, 0.02164859519970994, 0.013004480410487422, 0.0708835569000052, 0.05220382436809521, 0.07906007460288464, 0.08133611416504269, 0.020977536651996836, 0.018807872228564757, 0.01024057116029003, 0.04075070647823234, 0.03148804463806652, 0.03244262083523697, 0.04578175143368783, 0.013254143676960902, 0.08411112211404309, 0.05013136118049583, 0.05110995806453209, 0.09633120509885973, 0.1292034863464294, 0.27489548308714745, 0.10924188570389826, 0.16487840833442827, 0.16801068138691688, 0.08924254757021705, 0.11237643403752197, 0.2530577637615704, 0.15247080234750626, 0.1252174389458472, 0.21382595682817124, 0.14023049464148862, 0.21048562961720654, 0.18751393162435104, 0.10341646119711861, 0.13703603057130692, 0.2432997954348403, 0.09526238220954135, 0.1178602522779857, 0.10353815426389057, 0.11333914608844828, 0.0934688171612159, 0.10168360095591315, 0.20540874962124134, 0.2388843251091819, 0.1842150497700899, 0.1926471497262678, 0.4059531473584714, 0.12061404725236279, 0.8482160431242759, 9.676083210975895, 40.609620232735914, 61.238016082394516, 60.03842192311441, 48.42013005287417, 34.604102796123875, 33.47058096239644, 38.83486540086808, 35.57051989340013, 16.25359498685406, 5.337305395833908, 1.1052236489711271, 0.43380243523466977, 1.5019814429744598, 5.257160586695518, 6.309544271038425, 8.195667449505098, 14.519032682141951, 18.604799970503777, 17.72623808153214, 8.61804444943705, 7.251415175776328, 17.396908037124142, 28.415247894102528, 43.326767644574566, 52.474225182687086, 56.75815551511703, 54.998282155682965, 60.33603175993889, 57.12622288734683, 58.54995304538358, 58.253912156628026, 55.03512105634136, 52.22016149951566, 50.26461285929526, 50.34340543131675, 55.21408311782345, 54.1612248266897, 53.560906071816724, 53.18759056829637, 56.70397973829701, 52.92363858992054, 55.27106338931669, 55.754730855264974, 54.18852060071884, 54.50647577162712, 51.60269021987916, 55.62293137273481, 58.881773794851, 57.53143118273828, 56.56497878413047, 54.38403898669828, 49.21564163700227, 43.384744198091575, 49.72716969828452, 54.100271194211906, 56.78138771364766, 54.419736477636526, 47.26527837014968, 59.97493836187548, 56.35652442132273, 54.693647353879875, 47.98915963019095, 41.2357795623041, 44.11374415120771, 42.330262045706476, 41.70566774183705, 41.79137153010215, 42.18934697489585, 42.28306024305282, 42.383037536374985, 42.52519992090041, 47.91374421888783, 51.5508992441239, 52.26757511015862, 53.22850873393398, 54.668312764936886, 57.092192403731815, 50.78121254521032, 56.800348451060636, 54.52161612049226, 55.68827021506525, 57.63560541214482, 56.66898042924943, 57.653816976854884, 54.3339228630066, 55.46009025266094, 56.27341331974153, 57.51736948567053, 56.22533290616928, 56.90827246635192, 49.55326749432472, 40.251358785936915, 24.392074769543065, 15.354202370489798, 8.562388958469514, 8.584313046547676, 11.538080380808923, 15.815546647194894, 14.450943277728173, 11.8166127897078, 15.242156924739962, 9.56027719282335, 6.828547879572838, 1.6764776408672335, 0.8331328137747703, 0.8566127957836275, 5.842617480985581, 18.67101546256773, 40.146188274506606, 48.00480204243814, 60.580968087719334, 56.93861199963478, 56.3070397992288, 69.59215071893507, 57.09789160759219, 25.723660607491773, 5.7042352807137275, 0.5587007525947787, 0.14350199651333595, 0.13522483017896453, 0.2481695712213555, 0.15951783065834355, 0.10381756951251339, 0.12481157322444263, 0.2205092772360771, 0.2131769271387208, 0.1850996361744981, 0.06553988678440933, 0.16974953243569021, 0.0924744810007753, 0.1234963534760379, 0.17704078957678812, 0.18000280724898463, 0.0723393384607569, 0.15862313189333485, 0.10693998301341649, 0.19866166005451835, 0.10409550621144234, 0.13259019252033005, 0.1265762567580227, 0.14204566336927876, 0.13654806320705723, 0.16374357164867465, 0.19550200701961595], [0.04915905387831792, 0.05938030621637741, 0.016757357459996017, 0.0641078501188707, 0.03464851355660827, 0.04036053406795667, 0.030945213887119488, 0.08441322122610385, 0.032594539901061405, 0.015169863360032681, 0.01305724471627224, 0.1435750966230708, 0.02965982368726644, 0.04440242927821894, 0.06597471062935169, 0.12565159629429543, 0.062488696477826566, 0.04073862910210606, 0.048102113012705124, 0.014138491636502647, 0.05446036699258032, 0.026860452227054105, 0.0506841127700623, 0.06073448153573179, 0.022501710712188677, 0.022579912967499227, 0.06159343846863317, 0.01585736694265037, 0.06248966174861116, 0.023060912762077588, 0.12391247711474858, 3.6849748463399954, 17.163321087437293, 47.27864580769693, 49.90482561049923, 38.383294690039854, 37.533120955190356, 22.33663316695921, 26.777795630116618, 24.04178357893421, 12.558773275344604, 4.722479754878629, 0.823611505329609, 0.26999932323252, 0.3268213822476326, 0.1561670999733671, 4.004016023489737, 11.755688575006301, 14.772330522537233, 6.146714427778798, 4.549889093445194, 5.783212204133311, 7.001771513492831, 11.596918875171292, 17.925286600666663, 27.502153458133822, 38.68934154510498, 46.551108898655066, 53.25102706109324, 53.598929528267156, 55.75846102929885, 55.77852395273025, 55.105460920641505, 52.393875429707194, 49.60687452746976, 49.01041146247618, 53.11142598429034, 53.638737663145996, 49.47998585239534, 50.645200437115086, 47.58725397048458, 49.73948201825542, 49.63485279390889, 51.55131109299199, 51.7203377908276, 53.087621119714555, 54.735365683032626, 53.79347908881403, 52.80595571764054, 52.972931015876036, 52.40937663662819, 50.3914152422259, 44.13938860739432, 40.919954238399384, 39.68829078059043, 47.80358053022816, 49.73543805460776, 53.07517936152797, 53.97968184563422, 38.107226510201734, 54.813773862777225, 49.982970991442286, 49.74440459282168, 40.55176135032408, 42.40041363623835, 41.631558479801306, 43.312702025136645, 40.73436337132608, 40.40378209083311, 40.88259366250808, 40.76699356878958, 41.9320277244814, 47.71559784489293, 49.943876727934814, 48.425527234231275, 48.13128279101465, 50.810736225497344, 52.92507025503343, 53.31048627053538, 51.97908870635494, 52.74437842830535, 53.36999254841959, 53.96036417253556, 54.762751671575735, 54.46211376497823, 55.078486780966486, 54.48493019227059, 54.842516991399954, 55.75760203023111, 55.102487764050885, 57.14714480984596, 50.8777303080405, 41.45460467184744, 31.00417498619326, 20.864608826175814, 12.875523298017441, 4.672537686363344, 0.9217273888568726, 7.160200457419119, 7.177923687042729, 7.011135681982964, 5.531590686690423, 6.868351601785229, 3.3916259292633306, 2.320969638324553, 0.2000864150543367, 0.27327520712729425, 0.8885765580400344, 5.638505672254871, 14.605388564448203, 31.49609119661393, 55.82797719586281, 43.89610359745641, 43.344131977327415, 53.672881895496005, 50.38495117618192, 39.94741039891397, 11.359324243760879, 2.356517588899982, 0.1490633658343746, 0.10509845320015185, 0.033612659261111295, 0.029700615954014565, 0.04274948732927442, 0.048972097781276515, 0.02625643786403441, 0.032278915506697474, 0.061116395518183715, 0.06850516033028403, 0.05067270955130939, 0.05343695396497365, 0.052796416360163884, 0.03619059875246979, 0.028836426640590353, 0.020656754570682685, 0.050640583654204686, 0.04375687762794476, 0.02584932916497271, 0.014107249613340585, 0.022737753892978354, 0.10184576644772485, 0.03940705337651795, 0.037222040381522915, 0.036668848291399984, 0.0134596754909463, 0.052547230941033175, 0.03357090746923801, 0.07340993101318037, 0.021922998318088152, 0.027185350115741455, 0.013093254679153043, 0.031689592794845664, 0.10599730416171013, 0.05327103464233299, 0.06863139629844697, 0.059538855773186496, 0.041754611076847206, 0.0807767014409746, 0.028123989768867052, 0.02581398569858603, 0.04393539909693984, 0.033323154634525703, 0.06747980526978932, 0.005000355952013765, 0.03830670979955504, 0.028798103092178225, 0.0750514735738116, 0.02732362898607408, 0.08658382410724318, 0.007301886132242339, 0.039197616429338535, 0.042531267184043126, 0.0541143020945451, 0.020587823894475738, 0.01455972029361874, 0.025310752117225242, 0.16678622773578092, 5.198468200622067, 23.242208419307588, 52.99718695302164, 55.64015842253163, 41.47766036372031, 40.97351420310236, 26.42270934197211, 33.80130737058578, 30.76220004789291, 16.0707252640878, 6.603777927737083, 0.8795861791699164, 0.2928103879094124, 0.17258877685714155, 1.0523992512495288, 3.889990761395424, 7.298901840563744, 7.882678489531241, 7.1399968189577905, 6.020014516768917, 7.159625339892603, 7.754663603921091, 15.65853613038217, 23.82694163630086, 32.96360285051408, 43.16210262237057, 50.36715930508029, 55.87785405497397, 56.611474560153106, 57.40707635879517, 56.519094897854714, 54.56977498146796, 52.35710320934173, 50.375961103746974, 49.51074115691647, 52.989706993103034, 53.74058592704035, 50.06561140860281, 53.29102346974035, 49.27271212300947, 52.260267734527595, 53.85342467215754, 53.28978792313607, 54.61822802020658, 54.812797192604314, 57.35675234948435, 54.929479860490375, 54.80903956197924, 54.45506918814875, 54.07512880140736, 52.426819416784475, 47.20149670877765, 42.993687814281834, 42.01498977599606, 49.70491809229697, 52.707955298885224, 54.66173102778774, 53.94460801155337, 41.38870493058236, 56.8979448656882, 52.07800695973059, 51.428246728835575, 43.185801582951704, 44.134862192215465, 43.601106059166696, 44.60575449851252, 43.231512884939875, 41.560873446925996, 42.075731600484545, 41.66697748245732, 43.66586439071163, 48.924966550642445, 52.275710105896, 50.41000727684268, 50.58873399611443, 52.671261525923214, 53.86554479599, 53.88308171303042, 52.309991621202045, 54.09243822097779, 53.13674880612282, 53.9847573926372, 55.14051906524166, 56.475356548063225, 56.226372334264944, 56.73603726971535, 54.98871549483269, 56.85565779286047, 57.180869348587535, 58.42066780213387, 54.3652626006834, 45.2500351782768, 33.87797401797387, 25.86043561658552, 14.139040323995776, 6.984420909035591, 4.897069844507403, 7.255013950409428, 6.890899346720788, 9.475538307620633, 6.25553862702462, 6.911403046500299, 2.571420328271005, 1.373188212033241, 0.37774701572714314, 0.33320978944820745, 1.0143623116516298, 6.327962250478807, 16.82478916260504, 31.218718828693515, 52.68955546040689, 50.092883648410925, 50.465438212117846, 58.38079690933228, 57.54165287940734, 46.404526002945445, 14.027414571854377, 2.8945937223972815, 0.059697608343295516, 0.09633547986947721, 0.05209474493899653, 0.04301811989036299, 0.051099079616007306, 0.0031763575820913242, 0.0880049784938174, 0.08149510805284785, 0.010191629633247372, 0.05944952609077577, 0.01424029706076028, 0.07271839876569088, 0.035738710299014084, 0.02126122667123714, 0.03310844700242723, 0.01952156356926407, 0.03588567277596843, 0.06067606350106578, 0.10433655577681719, 0.03841980735981657, 0.02410765125175878, 0.04804613113763833, 0.09275087020209721, 0.014381226595310916, 0.011445738547932238, 0.033481930187272455, 0.07152484910142037, 0.11115024136679788, 0.14780396325213296, 0.10660456673752879, 0.19492115915542652, 0.0740906231165413, 0.11221734821916589, 0.1797516529838885, 0.2105772230894335, 0.13314192904339683, 0.13907898788250264, 0.09496351598852104, 0.23348178113660506, 0.0991801558543117, 0.16228149284518537, 0.11723759133488902, 0.24465915716944203, 0.18158313938446585, 0.12758064399202987, 0.22204539077656887, 0.10414304962802319, 0.15278359604699, 0.17054801055740926, 0.37323598359381, 0.1477817620240873, 0.12548799055718607, 0.1293324495876028, 0.21186023650150146, 0.07201673883584238, 0.13670858927071095, 0.09994325603568747, 0.38530744552131624, 6.6103091643702605, 27.253512451725623, 61.64653878058157, 61.818311137537805, 50.197818817630896, 48.86148298940351, 33.7891480230516, 36.442380412932366, 33.54484711923907, 18.66253725944027, 7.278870296093726, 1.3623567093764584, 0.5317208519385708, 1.1651537879820795, 2.975246478472987, 9.828811480152993, 19.896095222042455, 27.6818823429846, 12.998204250489513, 11.719857723482194, 11.856816103381496, 10.331706404685974, 14.87158021619243, 24.10994456660363, 31.300437488863547, 41.58630217275312, 49.886363014098144, 56.82162338687528, 56.32369810535062, 58.246228233460464, 57.89424257893717, 57.331464828983435, 51.9204100485771, 51.75328962264523, 49.377890479180124, 53.40846707743984, 56.94504860908755, 51.99948503125099, 54.97730139763125, 51.34558277745401, 54.183194022024836, 54.626013924998624, 55.3813761280429, 55.88247068466679, 56.53585518560102, 59.305629038041644, 57.068877835427564, 57.12404597190119, 57.07995068642401, 57.1626107154354, 52.95843001334898, 48.91284642680999, 45.311392814882346, 43.77676940733387, 52.17397166836647, 55.42271790965911, 57.1755898383356, 55.259586534192486, 44.941964380202755, 58.73460254361553, 54.00933104176676, 54.315107253289995, 43.47259352284093, 45.89488460171608, 46.52367976404006, 46.10673573709304, 45.990343324599735, 43.54877379632766, 44.82184571604575, 44.057669947224284, 46.565480462966434, 54.36465071093652, 55.735879944216826, 53.31413407479563, 52.74885777504214, 54.94256096501505, 56.008245406612275, 54.205214208172215, 52.64600538438367, 55.251616278002345, 55.96414619876493, 54.42130150333528, 55.94697406215053, 57.80859370385447, 58.65725732618763, 58.22156044744677, 57.93073238865022, 59.82257781490203, 59.90364143925329, 60.60747938771402, 56.50942233300979, 45.3145307110202, 33.91503649373209, 26.58152218787901, 15.688971761734257, 7.765274595829749, 5.636122342078917, 14.291341054824091, 15.995781517797901, 17.617868877226307, 15.91875401235396, 17.33639371010565, 10.029032787969037, 4.553164272539077, 1.1752410208986652, 0.7539701906423416, 1.464258538138482, 8.103531464453667, 19.22564252730339, 42.25166951456378, 65.98516264269429, 53.29822886374689, 58.29493622626028, 66.00387234841624, 65.98842605467766, 50.45942521864369, 17.519515445155484, 3.7647002070180835, 0.305250950998837, 0.16127630887973696, 0.19158795656215763, 0.1462388915881034, 0.1042046201144976, 0.14096365610678352, 0.1360946310864341, 0.2581942760415616, 0.11260889575726564, 0.1894312811594817, 0.1917115725096195, 0.1424044376659778, 0.23249585662157307, 0.12258708371870941, 0.2247910498971901, 0.09978769422178307, 0.14164913625967118, 0.13547206207388832, 0.17405986485462036, 0.08120554213922831, 0.12189261735446992, 0.21556479255518607, 0.15405019985571985, 0.12506805180061248, 0.15351372380410472, 0.04979358535380133, 0.24275812530709853], [0.030622290590056972, 0.014880526315180526, 0.03522707081790413, 0.024360017850995067, 0.06642621986928486, 0.04835405251792362, 0.04591949787291308, 0.01633482166535912, 0.09038410284706662, 0.020286571309571306, 0.0003948106237775421, 0.03832282445904228, 0.025710686402876052, 0.06879672573338594, 0.0566676156895776, 0.059929763627869476, 0.007842607747372842, 0.038343880385641134, 0.050180318029296976, 0.025763921852734302, 0.060878555861211596, 0.047187151222099225, 0.04302073225018479, 0.03391756608541455, 0.06116626401161475, 0.037438318493866155, 0.04003357923319263, 0.1466693410709981, 0.0424206938834921, 0.07827890240737508, 0.012608061510799153, 1.8950089403698522, 12.96222827126903, 38.71158530635219, 48.262741027339814, 43.872130070963216, 33.38796015708677, 28.11560626952879, 26.36881205343431, 25.658637515960205, 17.563647993149296, 8.49796304779668, 2.6257221112328195, 0.32471292441891086, 0.13364201591860864, 0.3786304683214234, 3.314938199135565, 6.993058458451302, 6.306162207357346, 5.8616767679491355, 4.81688630196356, 4.009328628740003, 2.567154995856747, 6.876964636387364, 13.784824802029519, 19.242912723172097, 33.154496762060354, 45.66990921574254, 52.56950739891299, 56.421247451536125, 57.438686740013864, 53.82419516963344, 52.90976908899123, 47.5794170748803, 48.14039445692494, 49.4383498930162, 53.0430982958886, 50.52091229346491, 50.133138933489406, 50.143019383953465, 47.93210875603461, 47.09603201958441, 50.74217319488526, 50.00026472153203, 51.89257298746417, 51.306088432188965, 51.72887286832256, 50.45101173462407, 50.74641327704153, 50.55388765950357, 48.0797585364311, 43.412518501281745, 38.15463619847452, 38.2654078545109, 39.02940711667461, 47.60242177594093, 49.50835243348153, 52.12116872110675, 54.49768181770079, 41.82189933715328, 55.3569358394992, 50.42941516445529, 47.862890689603745, 43.05786955741144, 47.470261435354914, 46.61411785310315, 49.027152138371626, 50.17087213454708, 51.195575652583955, 50.06419151060043, 49.56828624971452, 49.635986358888694, 50.836835676623934, 52.983329219202844, 51.47366777543099, 53.19644728014546, 53.17708253860474, 51.23213214258994, 49.734127982970215, 51.66341635488695, 51.32742220355619, 51.31205827959123, 50.91102730843329, 53.80597576018303, 55.48488747689032, 57.43605482962824, 54.08493080446797, 59.204545636330884, 58.58231652167536, 57.59422440682688, 54.25235325290311, 49.02051941041024, 39.406217452018495, 25.071472429460098, 18.15980315208435, 12.415157652670338, 5.818968530624144, 5.00156766945316, 5.85207921843375, 2.950798345188941, 6.28797221568323, 5.39785796596158, 6.123416529547784, 2.2013792684001308, 0.7720561169328228, 0.16318995054931412, 0.3999593980129688, 0.9091342516964482, 6.835463018186632, 18.855284490892966, 35.89336625991329, 33.68560137287263, 41.32701389251217, 37.21595810305688, 35.945600463498025, 55.11946378215667, 34.91747271630072, 11.340195825023036, 1.327539790541895, 0.11053351760511437, 0.10491878259927036, 0.0016940393341487395, 0.015348444200841891, 0.008997184603715376, 0.048387143685812914, 0.02308152052724073, 0.024331904339393782, 0.05522114209710591, 0.049721220688473795, 0.04861317026699263, 0.07505182597425676, 0.013956928798448176, 0.05764968295191085, 0.04920441011387495, 0.02685084356926382, 0.016740089838182735, 0.058822839355636994, 0.04526309075675184, 0.03391623692286592, 0.0831785326402995, 0.05244122352451087, 0.03785008309228766, 0.028069344717228127, 0.13971387558887083, 0.05108777215824493, 0.032897550657752066, 0.025551225201437072, 0.0160858488356274, 0.013620947532716298, 0.06332921367439051, 0.02783609201170264, 0.036259719035437996, 0.019762948298105792, 0.04625729668224531, 0.022877201047395507, 0.031266227710030736, 0.01627322819624697, 0.01887636048899543, 0.019961587235992475, 0.06438198319125561, 0.019626531021429167, 0.033168841543937885, 0.028760622240482803, 0.017927166059493058, 0.06993422840511607, 0.051457405751270634, 0.0036835882271970474, 0.023988346464090773, 0.026669903177647825, 0.03935924949004285, 0.09483369472887247, 0.08167382104382401, 0.11453101802016459, 0.08883317316611929, 0.011427004825353864, 0.028192453131440188, 0.04905315754454463, 2.2613758425558768, 15.635278436445422, 46.56203269958497, 53.15408568228445, 50.37693385154971, 39.10481860560756, 28.70485217340531, 28.304990068558727, 30.641636194721347, 21.886584335757842, 8.943843380097421, 2.1601166696317735, 0.22692123397944436, 0.18661227678098988, 0.5699730928867095, 2.6957057752916893, 2.898276092544679, 6.5025268447014595, 9.086677470514852, 8.737341377042956, 4.484850312432935, 5.010143931834929, 10.816012236379809, 16.134894259514347, 23.139077540366884, 36.132509246949226, 46.97859625662527, 53.97456707492952, 56.38065092025265, 58.62582345162669, 54.709658468923266, 54.07948263229863, 49.85890642289193, 49.40342118663173, 50.41680082198113, 55.08952825300155, 53.2610918629554, 52.733301654938735, 51.065941318388916, 50.726675910334436, 49.364679936439764, 52.73304277850736, 52.62857044896772, 53.51939170591293, 54.75240053669099, 54.28697993678432, 52.273482199638124, 53.85628800238333, 52.17957281297254, 50.708472190364716, 45.24697965191257, 40.884225368499756, 40.33870996967439, 41.70137274649836, 49.411826825911, 52.28688101614676, 54.66855595188757, 55.959678619138664, 42.62238840903006, 57.63574269510085, 50.2811848732733, 49.31715649943198, 44.74869743470223, 49.0800178435541, 48.85592891323952, 50.87966011416528, 51.00901596007809, 51.552617242259366, 50.387316365395826, 50.890552536133804, 52.02236029409593, 51.75827103276407, 54.59742376881262, 53.60847657726657, 55.285795811683904, 53.54208653972995, 52.86046881829539, 50.669397538708104, 53.581333775674146, 51.623164992178644, 54.14497444706579, 52.49065599133892, 55.5773534313325, 56.69443661166776, 58.32710358404345, 56.752977986489576, 59.3495713510821, 59.51378530071628, 60.32969320974043, 56.58287655922675, 50.93877023266208, 42.62371024777813, 29.36653248725399, 20.811872559209025, 13.975998182450573, 8.022672293647643, 4.606483992068998, 6.766510692334945, 7.087022268003033, 7.2516005077669705, 4.010596044601933, 6.488578406072433, 3.570580881449484, 0.5073419730028799, 0.5294086760090244, 0.192812517465603, 1.2575067291336677, 6.878633604895684, 21.884399575571862, 35.05450856301093, 44.326889668741536, 47.19260861796718, 43.12583638775734, 45.897798922754106, 62.78939977768929, 40.57853937149048, 13.9878035360767, 1.7230904751246976, 0.10017819988030581, 0.07160330416574594, 0.02373497245923406, 0.032230334040979226, 0.029617662038353663, 0.027212274275840293, 0.01268531094425388, 0.04193187616164646, 0.06447407462063336, 0.06518409256973574, 0.053127316547737974, 0.05883455283999924, 0.01617396809911776, 0.04651407403270564, 0.026149700748764222, 0.08117853753989743, 0.10080414734059766, 0.039487848839452194, 0.04070675984445599, 0.005553641409102467, 0.1252538664266467, 0.08018764111423686, 0.044486246958014466, 0.028458772106997432, 0.06095024253872614, 0.03300475317143625, 0.020838846009404912, 0.09747300552384508, 0.13925782344754667, 0.10716558824623786, 0.08224026645503699, 0.15144905556113492, 0.15560690583961626, 0.16234759091129228, 0.13712160259244904, 0.17826973250316036, 0.1288832309505632, 0.15366721718061357, 0.08094156356227976, 0.13809179166151633, 0.10415206648289196, 0.12952475297835567, 0.11295684523159459, 0.07927313897638552, 0.17136476753700167, 0.12101369233982218, 0.16793160579137265, 0.13594282310335867, 0.1773444515082144, 0.1409783803166882, 0.09991268912750868, 0.1619250934210516, 0.16539495077825364, 0.1780520562803553, 0.291121133392857, 0.10608862950316361, 0.11271397237695994, 0.21022486860953996, 2.5364276382230946, 19.353598087064682, 52.05719486359627, 61.460426238275346, 57.696139351014175, 46.082460188096576, 40.0783783389676, 37.20546576284593, 37.36328624909924, 25.963897935805786, 11.929623138520027, 3.266388572031452, 0.8251985943605824, 0.6659528168459093, 0.993403310496961, 6.54583667555163, 14.011830995159766, 19.1302877472293, 15.110513356424148, 12.699230409437611, 8.58323537534283, 6.437335091252481, 12.328075151289664, 18.872701775643137, 24.786382798225652, 40.7300958325786, 50.91628328446419, 54.82993010551699, 57.36267512844455, 58.74449083881994, 56.13538119100756, 54.25774651189005, 50.979304006022794, 50.39525916499477, 51.05831623077393, 57.742850857396284, 55.75799426724834, 54.049037195021114, 53.71713407578007, 52.49864585937993, 51.130625124900575, 54.23981735783239, 54.29511101015153, 56.39071179974464, 55.8196186250256, 57.88147526402628, 54.7150517279102, 55.33769661380399, 54.16413130298738, 52.33629111320742, 47.44278523229784, 42.09061307291831, 42.134888787423414, 42.204683442269605, 51.76677473129765, 53.54762884878344, 55.67613047938193, 57.8923676859948, 46.091203151210664, 59.81071264513078, 53.51002508594144, 52.9586967345207, 47.250651851777114, 52.93144410656345, 51.2363173115638, 54.435198460855794, 54.189971877682595, 55.08912424887381, 54.089790621111476, 54.705253647219756, 56.354355350617446, 53.637670778459125, 57.91818080409881, 55.450915828827895, 56.91985914784094, 55.85681838373984, 53.66260528564454, 51.686793681113954, 54.11886322882868, 53.22529631276285, 55.08730819148403, 56.631051109683135, 55.223610554972005, 56.775551226831254, 58.46630457908877, 57.703858575513294, 62.17336800790603, 61.42330492696455, 61.22520562141173, 56.17610323813654, 51.76833191225606, 43.710285232913115, 29.759091138839725, 22.25541853135632, 16.92282292150682, 10.142124525962338, 11.611597364948643, 14.845596474985923, 10.919949162390925, 15.11583895452561, 14.41546053655686, 14.29883082066813, 5.8301806257617095, 3.448645179310153, 1.2799316548532056, 1.0096488484451849, 1.4878794190383728, 9.267893914253483, 24.539818686823693, 46.142060602864916, 43.3080618612228, 52.21372881243306, 51.681604385375984, 50.390383658870576, 68.8868614935106, 45.778598093217425, 16.96006778747805, 2.0174259908737677, 0.16997860804680856, 0.23534470778559488, 0.153710930157573, 0.12075588077066407, 0.08242871642353074, 0.138341291176696, 0.09141730264790597, 0.10333379264920951, 0.13751881918118847, 0.09975741076613627, 0.21314672795274567, 0.16072166122255788, 0.16925942002525254, 0.134830386828511, 0.18645047901138184, 0.19690549541865626, 0.1613071515795685, 0.18064927820476795, 0.1838721947804574, 0.14173475424608878, 0.2509966961318447, 0.13016889502684917, 0.1046183842024015, 0.11155420719015022, 0.18322705681766235, 0.1744394920646183, 0.19248749700284776], [0.0297381887362609, 0.06003598171857096, 0.0022677852041764006, 0.024586793283120762, 0.0838156956278028, 0.06083383547863173, 0.08438045564558237, 0.007751342256538451, 0.028177091153338555, 0.06855674103022584, 0.018877247235767784, 0.04282587778664405, 0.026014539856283415, 0.03162524715486554, 0.025330101582972754, 0.024317436768943747, 0.09789533447474243, 0.052483312395070834, 0.052116279670548056, 0.05464912722668341, 0.03996031824499369, 0.06107782682163581, 0.005285649489040577, 0.04079342737132984, 0.0291506031287774, 0.025891979194937215, 0.021008044188361497, 0.04495588183823613, 0.008255257177346898, 0.049374757424717954, 0.023579065905763738, 0.5508205883445279, 9.137930100963963, 30.516906784426784, 52.032319191963445, 44.23854612535046, 43.859900120765936, 26.244839660583008, 19.05489390896213, 24.817451892360566, 21.478436223922238, 14.417612937188919, 3.5900576556882555, 0.9468484537736063, 0.08673300440873831, 0.8299075836135495, 0.5772098045675986, 2.1785434744050427, 3.026672183505951, 4.960621556928081, 5.117870848025046, 3.5155966060776866, 1.7284887596484155, 5.947289361107734, 7.3880274065079234, 14.141998771698246, 27.555780103129727, 40.48754038349275, 46.52577430971208, 52.896005492056574, 51.689539340234575, 51.913141896647794, 53.82834503727575, 49.546168004312825, 51.448894085422644, 52.788395266379084, 54.58762961049234, 52.61135124391126, 51.00221849256947, 49.75194731066304, 44.25764414571947, 43.40119069622409, 46.180609656918435, 46.787176747475904, 48.52103694792717, 48.11581296305503, 50.46439878402218, 47.868217268297755, 44.86609789632982, 43.479822451068515, 39.11004320267708, 39.32715815882529, 38.07573772245838, 40.14418786571872, 40.96672850270426, 48.02707326027655, 49.16370945592081, 54.32117908231674, 54.663594153619584, 41.42745402551467, 52.52579258334253, 50.67853273883943, 47.46283246624855, 45.53448546317316, 49.62619220056842, 54.49863103128249, 52.149378407386045, 53.82185743701074, 53.963835470138065, 54.33897095341837, 53.43840260659495, 51.51750418447679, 50.08839645693379, 54.27311043585501, 53.994629998360914, 53.47704579753261, 51.99178934097291, 52.04684372871153, 53.635478173532796, 50.622862538983746, 52.14345170605568, 50.18443176823278, 44.874538836940644, 48.75144481658936, 55.0640759929534, 56.995545202685946, 54.56456215150895, 58.882766154504594, 63.745426516379084, 59.80863378893945, 53.32961566986577, 42.147844376102576, 34.46565489615164, 25.299011084341235, 14.58919603978434, 6.8171406465192, 4.279009719048777, 2.705401384061383, 2.835476249456406, 5.282625594446737, 5.753296286829057, 2.67495398559878, 3.3998692804767243, 0.9914876003899883, 0.6494413544574092, 0.1536599393453329, 0.46121526749864705, 2.3442386090755463, 8.503755407948649, 22.203711886559766, 34.41571920148788, 24.40769168638414, 39.951011134732155, 49.486567589544485, 41.67517915848763, 46.14648111404912, 31.771323911605347, 5.62799911345205, 0.4796471897392504, 0.06732090331253505, 0.04898750380943379, 8.640354075572349e-05, 0.074001511769189, 0.05258916276356867, 0.03781929018817121, 0.035869780281979236, 0.012743385196963867, 0.06416402734635819, 0.02498587912639543, 0.01514590779064043, 0.030552251001579628, 0.029324855572814425, 0.05167884729622353, 0.012491896726010789, 0.011086753577054029, 0.03711119895019839, 0.022624930209149758, 0.050759392399941726, 0.07731954582155713, 0.01185115131985156, 0.056099285702070886, 0.03425775125863091, 0.06843742283601915, 0.014029154610339434, 0.07197340890284508, 0.017493828425123807, 0.09057786946575488, 0.014081652700570563, 0.04014683384147864, 0.088308050537542, 0.09181635018678443, 0.008774332499371902, 0.07026877900164935, 0.0540572093919881, 0.05449494820148234, 0.030846783080168312, 0.04743949292347797, 0.05072834285637064, 0.04585954383195889, 0.03283190458352047, 0.03690252426050363, 0.04885037407098759, 0.0585988199248189, 0.030058319642839414, 0.06334656173543585, 0.03310445185390211, 0.04242214562010862, 0.02737018989489204, 0.07329972926527262, 0.02176910083019926, 0.0380737692748587, 0.04022585581086817, 0.006010563060220692, 0.05046656295176476, 0.030602228662539876, 0.044404884590016264, 0.007610135972725168, 0.8199962444843785, 11.248784988157212, 37.668866342113866, 56.82542024120208, 47.97072056801089, 47.4197962207179, 34.24847718208067, 23.81126980627737, 26.019042538058375, 24.337236112163914, 13.726984550876002, 3.8881555824510516, 1.0195598811391862, 0.14314545919337582, 0.7625636746806483, 1.4455402522317826, 3.130215156462885, 4.614388548558758, 7.41320215886639, 6.907359573148913, 6.646990679925488, 4.67486463246807, 7.10879534482956, 11.561929372049148, 17.25842091345018, 30.982998109632927, 42.92352053426927, 49.74669525700231, 55.40621649834418, 52.48686698175246, 52.886948739328695, 55.08901834487916, 53.55060200537405, 51.99342496933476, 52.13815258395288, 55.707466294688565, 56.40493431398946, 52.438213902135054, 51.31672590009628, 46.606202510095414, 46.34418426021453, 49.16931844526722, 49.15048322369976, 50.97492271854032, 51.29315637773084, 53.55702292534613, 51.373106048953154, 49.23170766522808, 45.49417526491227, 42.260573294854936, 41.49457362390334, 39.8343284668461, 40.24605574146394, 42.09449229701873, 49.05835851546257, 51.58012482427782, 55.9922460586794, 55.41595182111187, 43.91855524432275, 55.341297349622174, 51.578022433865456, 49.78402053156207, 47.2948020504367, 51.04479189841978, 55.43842700219924, 53.8277998278218, 55.16139391929873, 56.27859477073916, 56.77205247263755, 56.1197191669095, 52.867744814965036, 53.13936894939792, 56.188560685803814, 55.296688233652425, 54.033904690896314, 52.87842935131442, 53.24485717281219, 54.65680845322148, 52.69863182498563, 54.34982415168516, 51.10142700133785, 49.57078087714411, 52.27336452853296, 56.07711045972763, 58.03755421792307, 55.199256558572095, 57.756751737286976, 63.0796943941424, 60.323825343962646, 54.56530740184169, 47.01814551507273, 39.01254092493365, 26.154952664529127, 15.992820128317803, 8.858193524422186, 5.375295021841604, 6.471682796555181, 6.997959459981611, 7.875376507159203, 6.8939357515304325, 6.101592952205289, 4.974880353096993, 2.163992951954565, 0.780966516223646, 0.4484890149004998, 0.2607401700750474, 1.9044909025392227, 9.54845222734636, 25.482154392427017, 38.32010138419367, 31.38691986760786, 46.00584453152072, 54.179840395527506, 44.99328074916717, 54.79934346291327, 36.41875597738451, 8.06294571968817, 0.5951575898835736, 0.14852313595193048, 0.0229079652232148, 0.03980915377577467, 0.059463526347592, 0.033317374501137004, 0.04065442071746915, 0.06281468604180603, 0.03483974825470679, 0.021768882495140838, 0.013569926076959218, 0.006900493406705679, 0.05543450141445764, 0.07276139928088074, 0.029249213966390783, 0.05198106898235218, 0.020872866058902397, 0.04612448001881281, 0.017220405899288676, 0.07593226018211535, 0.010795361501344991, 0.025756745524103605, 0.07300061789611656, 0.039257735179196444, 0.042376854502025156, 0.012575013435355598, 0.04394772545164151, 0.029325818928379207, 0.12839710219733177, 0.11826929726427603, 0.14302475438002618, 0.1436683448452142, 0.2699579544846089, 0.14668147590371872, 0.1834557800283355, 0.15936226884443916, 0.16182504233814057, 0.24631188461376777, 0.1334660608441599, 0.15616489364014519, 0.1015562158558638, 0.08897056337445976, 0.09354316599426732, 0.13363734278227055, 0.2953424923602612, 0.15026715043331348, 0.20349757475478036, 0.13002252626803615, 0.186832542380979, 0.1523539432955365, 0.18179159190866256, 0.18035773578430378, 0.1614289289160121, 0.12796601686145992, 0.13663875269553355, 0.10393322580644201, 0.12849655573166188, 0.11788822214810118, 0.08776618122693994, 0.9593065755982554, 12.6645193945977, 41.82981860253119, 65.65748783849901, 56.073423431765654, 56.17101984639322, 39.335261775601296, 29.86573450026974, 33.84035064328101, 29.635742402845818, 18.346584458504957, 4.970027890897566, 1.7044776029163793, 0.4432155414214058, 2.2985285328280542, 3.4875948054175225, 6.908258286214645, 8.716274326847447, 14.344626453615005, 12.993706272494409, 9.124560702231623, 6.012822360761705, 8.845869437340768, 10.725181910299487, 18.916344027365408, 33.00056334464781, 46.955313067282404, 54.32265389350153, 58.91680448285995, 55.93246129251296, 56.169317537738436, 57.243682184527, 54.31421687526088, 52.4259094269045, 52.4749312093181, 56.5682186618928, 58.54875672248102, 53.90714937640775, 54.432523404398275, 48.03421197399017, 48.882620642262125, 50.72395770780502, 49.7413412217171, 53.40491341006372, 53.08871153862246, 55.35779483856694, 52.13141395199684, 49.354320956814675, 47.639617612285, 42.83621249660369, 43.97634744644166, 42.500469376963956, 42.52083824526879, 43.30744997147591, 51.87426728586997, 53.53115489405971, 59.47806035318683, 56.26672567859773, 45.99127684870074, 56.77926963375461, 55.16729708640806, 51.9251992625575, 49.55202802535027, 54.911652688057195, 58.31230840375347, 56.62659137479721, 58.49531050651305, 58.89407827008156, 58.233833543715946, 59.39241147810414, 55.62903458072294, 55.41680689780943, 59.48915673840431, 55.316351075326246, 54.20762254345802, 54.19689093866656, 54.03227298490463, 56.382710164593114, 54.042757480375236, 55.08612755806216, 51.628299374734205, 50.92124508273218, 54.87568847594723, 56.55818523899202, 59.68990364382344, 55.356516145890765, 59.85496482541485, 65.07938931065222, 63.17362731502902, 55.85110349039878, 46.851923311910326, 40.06245743843817, 30.687996648973037, 19.60788534533593, 10.08929902507413, 10.70030623866666, 9.71874192837746, 9.89768731978632, 12.440855060854267, 14.30227073930925, 10.922445751005604, 8.714595552413694, 5.735426458620257, 1.3112536192901674, 1.1971977136788832, 0.7700392832198452, 3.2717521680939585, 11.039873669224402, 28.452177009274884, 43.16986107057141, 36.012472952565844, 51.89742103699715, 61.95069505322365, 58.26873087113904, 61.435519187681145, 43.52563181231099, 9.865723925252116, 0.892895455321958, 0.23446246561023498, 0.10952826469175278, 0.1930181048209629, 0.20707224826178244, 0.13528452375002448, 0.10160820258240547, 0.11649151362719075, 0.07831898412757343, 0.2211032711690472, 0.09945573300243386, 0.17430832249022302, 0.21655672319954444, 0.1597614925835402, 0.22262619267548286, 0.16871191230752777, 0.09701141456682837, 0.16612834206992583, 0.09345317364580209, 0.29442959134617164, 0.14795353425846947, 0.12440016868734553, 0.23147280748573043, 0.2503554345739465, 0.13308545304161887, 0.12604774035994085, 0.1101495007113103, 0.11784540549401315], [0.006594302906324306, 0.055705891892073624, 0.016831210251116467, 0.08505023865690155, 0.06283181193735331, 0.02441575266270628, 0.07500487244537762, 0.06033173379217906, 0.03906763812166549, 0.03221171427397959, 0.09958956856280567, 0.06791691205674602, 0.028025013124269825, 0.03832251802387257, 0.043543571936747724, 0.07638931589862032, 0.0545734032658079, 0.03504025261668909, 0.022806313016542026, 0.05949708099867548, 0.11350069870992054, 0.07444431058942311, 0.01326735486321512, 0.023615663841126427, 0.052586512099350655, 0.01567164711999677, 0.05579190824421183, 0.05008835300442673, 0.06488818344810317, 0.016255891626520504, 0.04632860797667696, 0.19708886622421204, 4.047312861488712, 20.886538797809234, 47.43422269821168, 49.706871432642785, 41.873152948194935, 26.972058857640913, 25.60554627449282, 33.90421859679684, 32.34265046734964, 20.314090444195656, 7.3577702429986775, 1.194791339578167, 0.25670936781792875, 0.3521241325764887, 1.6892604001106757, 1.777374484846669, 4.545722555729651, 9.30927295838633, 7.988986978607794, 4.058308490822393, 2.985948910636287, 4.297766493212793, 9.49316151680485, 16.0726805656187, 25.0353140600266, 35.91588458707256, 47.11658916165752, 50.62771843325708, 49.110969266583844, 54.44251760359734, 50.39351371026809, 50.42954460267098, 51.14323946737474, 52.9518678880507, 54.92539275077082, 51.63106464570569, 50.33041454130604, 47.165701158585094, 42.76699050780266, 40.99875857753139, 39.41181859662456, 39.74822851919359, 40.882048453054125, 40.89009715664772, 39.610208157570135, 39.98069955456642, 38.12222957611084, 38.147870109927275, 39.28998193433208, 38.92550745318013, 40.21596723987211, 41.93717387414748, 45.655745537050315, 47.6073992636896, 49.87424681263585, 51.79578065872193, 51.492946224827925, 39.26835006283176, 54.18906188780262, 48.706333637237556, 48.84263992309571, 48.19141272575625, 53.04774630454279, 50.983387193372174, 54.423929491350734, 53.364701271057136, 54.58892007027903, 52.3491447202621, 55.60992087087324, 55.00183190068891, 54.42201537470664, 53.213093819156775, 51.49263243521414, 52.81647943681287, 52.371961147554465, 51.42431651392291, 50.65405322659401, 52.74268004202074, 53.33323209516464, 50.719811762532885, 49.962919835121404, 53.02618503570557, 54.28132387899584, 53.92437250383439, 56.5509759226153, 51.8340394573827, 56.699174834835915, 59.44525364906558, 58.01730302072341, 48.444731158594934, 31.379298702363048, 17.688273460634296, 11.170845531648206, 9.405515174711905, 4.525412032681127, 4.380634898139585, 4.131480551535084, 7.523821332762319, 3.7615686847317606, 1.6496513255180854, 3.3128831223134076, 2.1580044732939814, 0.2696063814143981, 0.38648522909610505, 0.26766447110041497, 3.8799627317536265, 8.317025092340286, 27.424598393901704, 39.26975034898327, 35.39248743364888, 30.807966263063495, 49.47198029487364, 45.155047139813824, 44.18700618128623, 23.41524377945931, 4.3666271336617015, 0.31011067571178563, 0.07461560018841298, 0.02585705324646927, 0.03898913326162485, 0.08042931121083037, 0.04944318439811469, 0.06582831888790093, 0.017878021519150467, 0.06749713417863654, 0.058126243266968004, 0.018876347082456755, 0.10626825413876965, 0.030916901192657893, 0.022121466801411683, 0.013725939882738937, 0.04988894414817614, 0.0129349454824302, 0.013908758147379324, 0.023569160388902794, 0.05138172775567059, 0.06626626071069511, 0.022032912783024293, 0.008695794122984574, 0.05006411015206287, 0.06539284386822293, 0.03442513763964657, 0.021709355548204436, 0.009385241653710123, 0.019541633157660405, 0.07888588919154099, 0.0469014349002992, 0.025153826666815628, 0.031041246838867668, 0.05764862192013572, 0.04009039231365727, 0.07338511742531292, 0.08829380130215038, 0.02066264195638078, 0.06509383975137627, 0.04253661064731498, 0.03908850635672289, 0.04761101234884513, 0.010080625408238942, 0.07025953232040329, 0.04580432421437675, 0.06701255292301217, 0.010127203554035196, 0.019529753049174627, 0.034687802375804995, 0.09466969828692176, 0.05295010508909341, 0.015931846968258823, 0.12209625884650216, 0.04546481702897338, 0.011939674694721979, 0.06862675380562583, 0.05785974426074855, 0.034692613407969475, 0.005255275539257714, 0.29500216546077884, 5.151125192642212, 26.610602640336563, 54.608806487052675, 55.25779793339392, 49.663140927591634, 29.376218780394527, 23.75509165948437, 31.20201345412962, 32.6834475609564, 20.99237415098375, 6.955794961221757, 1.5886259872105815, 0.05693359375600854, 0.4685705695902148, 0.5140235467303185, 2.2312064420792366, 4.057447285421433, 7.856021081247638, 5.225377621189241, 7.260726392269135, 6.228931228960715, 6.256985001025662, 11.71790732491401, 18.463547575858332, 28.728149091043782, 40.59132237588206, 50.98183785715411, 53.22112683326968, 52.69550177358812, 56.227388228139574, 54.80993386237852, 52.63885882592971, 52.031248384906405, 53.37633502098822, 55.84420404126568, 53.906694381467766, 53.76817195646225, 50.06444254229146, 45.671313424264234, 43.339872283320275, 40.783906828972604, 41.54120276051183, 44.60773921781971, 44.07628943843227, 42.28718265410393, 43.32477508052703, 40.61722570850004, 39.81844286764822, 40.02160203072333, 40.43743994928176, 41.22034503567604, 44.32643859617172, 46.40186663596861, 50.69495962512109, 52.3098425711355, 53.42263467850224, 52.495425593468454, 43.44918481765255, 55.33540594962336, 50.39367452744515, 49.75068038509738, 48.5103210326164, 53.79562070292812, 53.38951810713738, 55.02845302704842, 55.37633980474165, 55.659291744232185, 57.338525095293605, 55.90987236269059, 56.04260144695159, 56.96042430016303, 54.54602110770441, 52.34829356593471, 53.59553667806811, 55.13029344620244, 53.24300581409086, 52.65329314816383, 53.25300785803026, 55.14367657323038, 50.52417962781845, 50.133444878362845, 54.84614126143917, 53.60407175556306, 54.569174858831595, 57.05154095926593, 55.760912510656546, 59.29918458384853, 61.06728707590411, 58.870567583268695, 49.443884357329345, 34.32295906928278, 23.301520539868264, 13.476680459514743, 10.04599605837176, 4.11589011069267, 5.2350232197392375, 8.39635600966792, 7.950703174837175, 6.4828581194723816, 3.969616346782254, 4.382907911654442, 3.304247534082782, 0.4698844410238728, 0.40309220732700446, 0.45359511348989706, 3.9133222449210385, 10.51201383913717, 24.530273599009362, 43.103757366057366, 36.24822308940273, 35.18378596152029, 56.43616814767161, 50.3963456615325, 51.538586924152995, 28.663708471482803, 6.067970395088197, 0.25007086355359326, 0.10478701547629411, 0.037399102453022234, 0.07757086862599658, 0.04591496646284096, 0.07809294222463524, 0.033903830128932194, 0.08188824139295087, 0.017421645705678293, 0.01199546983585723, 0.0225020018255999, 0.06153969357030527, 0.06974258384997807, 0.05802629177548713, 0.04540318525546501, 0.05140538072033275, 0.04979634327032874, 0.009683443293456108, 0.03191352412555247, 0.03688443309417175, 0.06487778763497068, 0.02298492833130783, 0.06822594426452153, 0.045708111231966365, 0.08359417364361786, 0.06998104403816885, 0.0517662885719009, 0.013175617749502343, 0.14795358022374494, 0.198937788785946, 0.118573832535936, 0.18230263384119158, 0.16738383760375364, 0.10124359069572342, 0.12115972401994853, 0.16811535964089055, 0.21582645754660332, 0.08965769061638464, 0.21702556900920408, 0.14881866202960092, 0.0922899227589369, 0.13635268014284874, 0.08255089212569498, 0.224326923189144, 0.10070372087460372, 0.12079301305235395, 0.1734481589688409, 0.0837148248308128, 0.1880687631426319, 0.12940810843100473, 0.1414892996751493, 0.15375393833364212, 0.20643660978924847, 0.13775167926665277, 0.13722995806845928, 0.17587943092709588, 0.15208872365615062, 0.12545912436419918, 0.18472106616583564, 0.33385661280443596, 6.784490837204841, 30.097642675522838, 59.90312368639054, 64.30921231546711, 54.85198559299592, 36.6839474247348, 38.03265833085583, 45.425714215924664, 43.087797241826216, 25.784290644430346, 9.242140612294598, 2.0815153131561894, 0.5979631264363566, 0.676417026308275, 4.27334189414978, 6.0052227685528425, 11.304883706954218, 17.579757167447, 14.165686945761404, 14.171989214035774, 6.832069187395035, 8.939972981329888, 14.931224757625213, 21.542009999675138, 28.421205974394276, 42.562623254714474, 51.42981959927467, 54.908534403770204, 52.97493926940426, 57.05335701665571, 54.85600210005238, 54.24390838992212, 51.77834964567616, 53.37487589928412, 56.699774957472286, 56.07236439181913, 55.93023730862526, 52.209979026548325, 47.223748314765196, 44.35119659669938, 43.004223300564675, 42.807504669312515, 45.585523343855336, 45.316731160686864, 43.14102772743472, 45.44186653629426, 42.144886908992646, 42.06749462312268, 43.24120113926549, 42.06711807558614, 43.58942131842337, 45.69902496953165, 49.00837967472692, 51.75772582331012, 52.97600223172096, 56.33781863797096, 51.91202009877851, 45.922333348181944, 56.98238172838765, 52.715407802212624, 53.5027059431999, 52.62553845682452, 57.12818407243299, 55.16919943594164, 55.96425602512976, 56.95488983584989, 56.927731344776774, 56.664159836307654, 57.04153499295635, 58.60243828065934, 58.83425820258356, 57.29262551953716, 52.27338414038382, 54.50411450478339, 57.40606438729071, 55.27731564737136, 54.78894918195663, 55.92596192513743, 56.865526476214015, 52.02702791460099, 50.75472870180684, 54.52129056376796, 54.112116752132295, 55.165579088272594, 57.430645881160615, 54.91865019644461, 59.864966869354255, 65.08862257003784, 62.95307636260987, 52.830756864240094, 36.91918765344928, 23.659895735402262, 14.331550252053047, 14.14609568734323, 10.54740636579452, 9.458748602098035, 12.810444312710917, 14.099185120674873, 14.272800011019553, 7.841169026590164, 12.816812280685673, 9.158204832384664, 1.530216379511741, 1.3089961726819317, 0.748277850929768, 5.051408246640237, 11.765020874238784, 34.040591562947924, 48.10250436106036, 48.177213745732466, 42.52222676430979, 62.87184015397103, 59.79929854792934, 58.72522415653352, 32.68721891987708, 7.6861358746405575, 0.5047878971503628, 0.1605392403660282, 0.14979966826015903, 0.11923131983607047, 0.1884302647123414, 0.17903398181642258, 0.1514751331940774, 0.12085963971912862, 0.2415170169044887, 0.10318386924242783, 0.09583107991925172, 0.20306688012374988, 0.23982501979316437, 0.12823597092421787, 0.12462732907865318, 0.11155655908007776, 0.09993410128499232, 0.06523696795826958, 0.1151554562872456, 0.1493574363449889, 0.16343895976822223, 0.1312137776685338, 0.12819602709984587, 0.2371100654765483, 0.19274556138102086, 0.12956690313594957, 0.2552909866696404, 0.11992046188923622], [0.04160946039783378, 0.1821666532346318, 0.07234746665363351, 0.04394490624808016, 0.003988575490732347, 0.0371732137676689, 0.021605993050240704, 0.005268071122813009, 0.09241196056527477, 0.04375125454258054, 0.05891210775101378, 0.034497483152775996, 0.01633400003606033, 0.12050815091858949, 0.04181223621051158, 0.03375222515915671, 0.051334705278878255, 0.028951192357307, 0.0449901681032873, 0.05797206424176694, 0.03304852743542964, 0.06490914361371149, 0.0603475803208928, 0.03171042464072666, 0.04056400702064557, 0.018809291406444485, 0.014256427999615911, 0.014702747951471999, 0.032426042692555536, 0.09981400168110287, 0.04678996144643715, 0.09179773425022442, 1.935578015062117, 17.136723495298817, 41.92111569066202, 50.8955967041754, 41.9614415784036, 37.22545023887388, 33.51403297916536, 33.77003823557208, 29.63518934865152, 25.413756101362168, 8.325414061546326, 2.1731308487153824, 0.2980689992827754, 0.3505947146444552, 0.42232867510568717, 1.9412645937935, 1.7789411040083056, 2.768201227149656, 3.4771980729795273, 6.819773047201096, 5.793620703681823, 4.492064041476096, 7.6980574284830405, 12.955666145970746, 26.181624781700876, 36.9067733518539, 50.22715814651982, 58.10644280525946, 60.024352381306315, 53.31781325801727, 48.27572015024001, 51.44114348196214, 51.28958702087403, 51.97189507945892, 53.08977450093916, 51.01498972985053, 50.45683645432996, 48.65102037306755, 43.66772359417331, 43.08023491213399, 43.23729838094404, 43.14253783995106, 37.02003963531987, 40.105866309135195, 40.05173367838706, 37.921827839266875, 38.18840388328799, 41.133107600673554, 44.33683287712836, 44.58177312727898, 47.26851432554184, 48.31922708019134, 49.380294892095755, 49.058103561401374, 50.49163964486892, 53.63171269816738, 52.979191118671054, 36.23402803174911, 52.72146001938851, 48.406468437563994, 48.238132076878706, 44.49086827616538, 50.89672634678503, 53.10237707630281, 53.16082039187032, 52.90292455304054, 53.602604789118615, 53.77925657456922, 53.47216636903825, 53.130657365245206, 53.42576080752958, 49.11904542676864, 52.114755645875015, 49.94494361262168, 48.18568998767484, 48.17786485918107, 49.2816904283339, 46.84626725412185, 52.27499231215447, 53.06831913609659, 52.87451482588246, 54.97401837379702, 54.52304778560516, 57.559613412426366, 54.107460898737756, 55.278433522870465, 51.69161035168556, 48.889841725749356, 43.9390496284731, 40.32024345090313, 31.23706375398944, 20.49729454901911, 10.654770462743699, 7.5184692586621935, 3.7717239462560226, 4.666466837929142, 7.1139792473085475, 6.397016067658702, 4.962992139400975, 3.988460638830739, 2.1567044527299943, 1.7728522371861244, 0.19058770620294158, 0.4784978739917279, 0.6802804996409725, 3.54804098125427, 11.892220397149364, 24.142806183907297, 23.646712649253107, 23.943583119300104, 32.40231364004074, 46.13072887543709, 49.52642279286539, 39.31542634963989, 16.687749393524662, 2.4098630489841586, 0.052826232502176884, 0.07264764288500433, 0.03312922713737334, 0.07171064074481688, 0.022887162105630965, 0.0190237213316704, 0.05823437657748019, 0.036859316901574214, 0.035899293819262136, 0.027351148779534047, 0.022991306013277462, 0.052981687063771876, 0.02775895270338703, 0.02192561642356938, 0.04137294607297067, 0.0447138708325163, 0.017008337440089356, 0.05243725901950271, 0.07624988789640127, 0.06154654239634834, 0.051887012537448644, 0.024327614247017813, 0.10834698775602926, 0.035942056847195474, 0.03407536870649746, 0.10646422709067983, 0.020649683579141577, 0.030316813030250134, 0.037655565707433614, 0.08546923512532827, 0.049693725792871374, 0.04837082218258612, 0.03423434344210452, 0.04808142863874955, 0.040341546578753384, 0.04462456413274331, 0.012411953535892311, 0.02004485524770233, 0.03856135742558587, 0.06823058675734267, 0.023116228140650258, 0.12092330162563633, 0.05619969684630633, 0.024632275923185294, 0.019739469618446404, 0.1744580313923859, 0.0971068844439522, 0.11611740991112687, 0.016708772163838148, 0.05244227689540675, 0.015273031463185626, 0.05485088031198229, 0.03536832593982259, 0.054036356478689186, 0.01106009754772869, 0.041295306892284465, 0.08524750629740377, 0.07015956550716393, 0.041473410843360814, 0.04613651909054287, 2.959531012081331, 19.133451138773275, 48.1442109231026, 58.25040948006415, 48.4562550821612, 38.07224681300502, 37.46265949741487, 36.44143512172084, 36.56184796364077, 26.419049770601337, 9.992312539008356, 1.79297779596621, 0.37772679100594214, 0.09060015496347221, 0.6901496732907911, 2.2171609247884443, 3.8948993625179416, 5.095259854870458, 5.019301195298472, 8.418055542053716, 6.741110403691569, 6.325553915193004, 10.588094092184498, 15.289724488412181, 27.34869464751213, 38.216229177290394, 51.11353928042997, 56.963048365808305, 58.08612492776687, 54.93479467207386, 51.415397044151064, 52.3325962405051, 52.468714252594985, 51.87182364925262, 54.576572448976584, 52.92359152147847, 53.862022507575254, 50.61928925975677, 45.7076031930985, 44.5956975413907, 45.42684385853429, 44.441779813458844, 39.70431758511452, 41.15828921717983, 41.19972513568017, 39.264447304510306, 40.392415062073745, 41.65053882906514, 45.68214701068017, 46.06435844975133, 48.986492849165394, 50.84709267462454, 51.07953625340616, 50.868387222290046, 51.63583032546505, 55.54449181402884, 53.00459238790697, 39.143002879235056, 53.86638418320687, 51.98302676600795, 49.147937605457926, 46.185920546131754, 53.66560982119653, 53.9872363305861, 55.81582961543914, 54.24388093333091, 55.57875371748402, 52.18375405957622, 54.23642843000351, 53.11523068335749, 54.67287055907711, 51.852380460308446, 54.48497726071266, 53.226163156570934, 50.47700528175601, 50.0195510156693, 51.65426938764511, 50.686883464936294, 55.0878220219766, 54.5067621046497, 53.554469462363954, 53.14868850092734, 55.82970303873862, 56.588422790650405, 54.97281028378395, 56.449331621969904, 54.135843169304636, 53.444686243611, 50.824123274895456, 45.05327732332292, 33.57776757209532, 21.969950391400246, 12.992918856682317, 7.650253542007939, 6.177845789540199, 7.423046327406361, 10.20326937398603, 10.529368365964583, 4.83395645695348, 6.357949260742434, 4.139240960921011, 3.2245035421463752, 0.614453015788909, 0.2723250435965677, 0.6450108534866764, 4.597141396614814, 12.264893612553998, 24.89073549547503, 34.52101915113388, 30.172722724176225, 36.06487189569781, 52.69268158943423, 56.485892034346065, 47.06772819642098, 21.017736196517944, 2.944091827638688, 0.08715040741428252, 0.024917088261234666, 0.015458894927325028, 0.08326965879889266, 0.04012294338955995, 0.047942609676430305, 0.07434495664652317, 0.019360160334937034, 0.019113192740347118, 0.0685900045678981, 0.0791685066876873, 0.0201588912656711, 0.05745542603695104, 0.03758408587365862, 0.06497259101560039, 0.11956562528446799, 0.03269364486538595, 0.036341081403436205, 0.05708088948120994, 0.04067173813499751, 0.07171441755828357, 0.07052614623981138, 0.06581987659897535, 0.11698000193122896, 0.004793291483374854, 0.0451618024418431, 0.05288181984196267, 0.042411680859062946, 0.1389041972616988, 0.25946726902357997, 0.15611045543224583, 0.12344933866012482, 0.12801054955249833, 0.2029153326105687, 0.09842173647015326, 0.1350957137202063, 0.14339305881050327, 0.15131134359586626, 0.12293225229387322, 0.12947272028653853, 0.07969917579283638, 0.2746592828583333, 0.23722258847086664, 0.18442626021081404, 0.1020387976220058, 0.19023700647296446, 0.19213115886574794, 0.190718753203269, 0.12421797765719315, 0.1465208272659971, 0.17428317948454813, 0.14345252255518592, 0.12159829403484061, 0.07504886887486904, 0.08455430397823935, 0.10333717875783482, 0.1655289089126933, 0.26914069188698647, 0.11362253733339811, 0.2852761276787327, 3.430194595167714, 22.37084604078724, 53.846172209708925, 62.88296007340955, 55.79706107416461, 48.90791208513322, 43.461285329634144, 44.66654731381325, 40.147439510591575, 32.79568814462231, 11.213445413497187, 3.105754765772051, 0.49444056206172515, 1.1534527448877212, 1.0720399070170619, 6.594043095265666, 7.962329570324191, 9.743429326242017, 10.501548955517432, 13.641702417404423, 14.390734895583122, 6.9240149374931095, 12.088277128434951, 18.07941809777291, 31.75475778118257, 39.39764707319198, 53.12294206311626, 57.4638448222991, 60.22607203452819, 56.96166376913748, 56.15935079513058, 52.058281360134, 52.91120075410413, 51.00705085262176, 55.75967696405227, 54.10553893735332, 56.291801391109345, 52.209884889664195, 47.038635976852916, 46.74366981752458, 47.48413485865439, 46.85315101377426, 41.14232909294867, 42.88141389046946, 45.22999578906644, 41.5816149403972, 41.076856890032374, 44.67727499623453, 50.34726896593648, 48.77504179554601, 52.73172878449964, 54.235926366621456, 54.6451590138097, 52.975535469670454, 53.59840393066407, 56.985621606149984, 53.19027346949424, 43.103616160731164, 56.93754511494791, 54.56329130357312, 51.66283976647162, 50.209017184472856, 56.95232068338702, 55.78891038894654, 57.93208952872985, 54.89285669019146, 55.40149004228654, 54.85071082268992, 55.654016156350416, 53.672564183512044, 54.510711931413226, 52.62253392127253, 57.39324215919741, 55.26612120289957, 51.64743661880494, 52.78424932110695, 54.85851633933283, 50.45788764953614, 55.85968955870598, 55.49379125718148, 54.55032394778345, 53.62514272812874, 55.14989745232367, 56.83116259113435, 55.13087395698794, 57.65619393317931, 56.516596348054954, 54.56274609411917, 53.9070434724131, 47.78363527790193, 38.346585227597146, 25.548538546408377, 12.973694339875253, 10.849310217365142, 9.211923653079618, 10.497517739572833, 16.79137449110708, 17.577986217314198, 14.187353138000736, 11.43567612094264, 8.724557392058834, 3.9042103338626126, 2.7539483145360024, 1.3574937058071936, 1.327414274696381, 5.005236066156819, 15.954377958851477, 31.150255818520826, 33.10312547991353, 36.23028216823455, 45.12742580906038, 60.054056490621264, 63.574222903097834, 53.71354118470223, 25.405197489646177, 3.992538432921133, 0.325625212562661, 0.15867936274697705, 0.1069192220306685, 0.3166432606597101, 0.22010358771489513, 0.1578676772694434, 0.20921315757497666, 0.13371352256546098, 0.08492479942017987, 0.2104245264443659, 0.12837402762905245, 0.1156865927060285, 0.17111951214892251, 0.050043414286788435, 0.0767684681341052, 0.2861383443157519, 0.15705122672502073, 0.12462119271437969, 0.1779471022347289, 0.14851408079266548, 0.15449483728697225, 0.1598519982109147, 0.2979239635169506, 0.31312559941603296, 0.12720184415699015, 0.35786130375439124, 0.11198579048317288, 0.12740234468853281], [0.07411103169884413, 0.03152243240976767, 0.0598931139815719, 0.05252059406390595, 0.03057517618271372, 0.03941233555275587, 0.04374003135448983, 0.09045189396748621, 0.009644981849217608, 0.05270427896551067, 0.016595262831317324, 0.012104872937103914, 0.012383739475250967, 0.015751396872914367, 0.07746003868599093, 0.10039149408018398, 0.04057844777801826, 0.020943694717941747, 0.040909144952292406, 0.04960528477245281, 0.038008069574472406, 0.02591637909532555, 0.04130962124514965, 0.09215707545198741, 0.007525377920002587, 0.10013613399238357, 0.033353759847100706, 0.11453734590641915, 0.06213389434701493, 0.037757704379938306, 0.040782533601046576, 0.017047181928289995, 1.129373436973941, 9.20043699202999, 28.29788665617666, 46.10785753496232, 45.069559081908196, 34.99741454278269, 31.70082715249831, 42.93250276196388, 33.53028728115943, 34.799750620319, 11.71232775334389, 4.533605373674824, 0.22162430288810886, 0.17436711207753228, 0.3547593218184287, 0.5906195301682718, 4.654402117575369, 4.901449661101065, 3.1744744460428915, 5.2328423819234295, 5.388648731093253, 4.1712014136775855, 8.473921860418013, 14.274965159354673, 27.033216453367665, 38.493701565650206, 54.700087885702814, 59.365817808335834, 56.86763671136672, 47.77099740120673, 49.337670495433194, 54.00502820168772, 51.85777764166556, 53.252333210360625, 53.82623087975287, 52.717725922984464, 51.938951092381636, 47.837128562311975, 42.2897518065668, 42.29987152161137, 41.05411498777328, 41.635559297377064, 39.124034297081735, 40.036193247764345, 38.81774033269575, 38.27715535317698, 43.13864292636995, 47.344478868669086, 49.10441498602591, 49.19296249266594, 49.68878538377824, 49.969713380259854, 52.191920434274984, 51.08106597777336, 52.514378486141084, 52.37697785900485, 50.51971204819218, 36.51277126804475, 52.48274849307153, 50.0517419076735, 48.323671125596576, 44.81695452044087, 46.43639526059551, 49.63211105715845, 50.971329827462476, 51.99736695135794, 54.910279858496885, 55.014430553682395, 54.64165633724582, 55.10804576258506, 53.76923099640877, 52.33793850867979, 49.26249042634041, 48.47547861837572, 47.52271529166929, 44.8797163655681, 47.538632269828554, 49.028242557279526, 51.17073528228268, 53.758295428368356, 54.7120903384301, 54.89861472960442, 56.86862122627997, 55.42500465146957, 56.940584951831454, 57.78356505978493, 59.76285972902852, 55.17909949825656, 45.810102570441465, 31.82358164941111, 22.711205790119788, 21.394330801502353, 11.410266026373833, 6.531951485141632, 2.7868734252068306, 5.979803358354877, 7.3616357388034945, 6.337419575260532, 2.859976354145235, 3.715943429739245, 3.3610900323237147, 4.527965985959576, 0.2416862916922377, 0.1184697058652678, 0.724051270273424, 5.0795850830693405, 15.335017077384459, 20.588568102928903, 25.267239885945475, 28.296186308706964, 34.866462292209754, 48.12083751924577, 46.11429414441509, 32.37500413771599, 13.125462608952677, 1.2195604943460034, 0.118826970968756, 0.06414220916227469, 0.03510525517706429, 0.06622960340351829, 0.10892283306607317, 0.019254286983801473, 0.07844408628560844, 0.015611766815005292, 0.041263150351662795, 0.053416936087512204, 0.034140340623355685, 0.07988418602655012, 0.019159146524485082, 0.08505868860670636, 0.03394926297328165, 0.04927691267502885, 0.06227322658824344, 0.052552620369580486, 0.027714640262626836, 0.05613715342816807, 0.03955363663994978, 0.031231129391779824, 0.04251355906167338, 0.061881571797834295, 0.02140768927582089, 0.11739722873655059, 0.044559684146436, 0.06151127170831446, 0.019247698627652663, 0.0471544124546551, 0.05973499726444002, 0.018836500934295116, 0.03881240443837258, 0.04959363640556413, 0.035681858914153236, 0.03651261232012222, 0.02165927638059422, 0.06368973848199652, 0.05885359778579685, 0.005301721056082076, 0.012729801500456469, 0.02093159818961736, 0.09322586769778883, 0.03590009438114301, 0.039356231103621186, 0.06148047880419801, 0.07838792437987943, 0.021522148557367827, 0.03720879089087248, 0.0190439269006733, 0.03830834539727338, 0.0453729362737748, 0.06563298944984713, 0.08294234007236459, 0.010673444353855185, 0.061110086784127264, 0.08154843543325702, 0.04127795883123914, 0.06877968793794995, 0.1514375489205122, 1.3358153787351426, 12.048022823949015, 36.21004666051557, 50.67987026706819, 49.96040559584095, 39.72443934409849, 34.139486282102524, 42.84418275279384, 34.19117527623331, 35.30608154112293, 13.896744731933842, 4.178985847580818, 0.5032273454050864, 0.11502044861234965, 0.6633777195407499, 0.5827857602027156, 2.8723305944473516, 6.9390268287351065, 7.052034235769703, 7.672853258348281, 5.718205292378703, 6.219178745823522, 9.006772906549516, 16.37607393726226, 27.40808717666134, 38.92398949592344, 55.744654286292295, 59.7737874523286, 61.15763887282341, 51.68343220987628, 52.603000517814394, 55.379250203409505, 51.92511297041371, 55.05720792278167, 56.50787299679172, 54.70945842804448, 54.9932615218624, 50.12984806491483, 44.14675089620775, 43.35059604337139, 43.05234686020882, 42.79141902923585, 41.05903756233954, 42.513519102527255, 40.44852848975889, 40.077409513535045, 43.621980913223766, 47.09461604395221, 50.47877427070372, 51.22657414405577, 51.68011780708067, 51.81400791291268, 52.884199157837905, 53.60000425769437, 54.664319792101466, 53.079101731700284, 52.16974727569088, 39.26064260544316, 54.35211873823597, 52.185244560241706, 49.97977425975185, 47.22180281915973, 48.17290306091309, 50.35706704662692, 54.22005253453409, 54.77735857809744, 55.58104045929448, 57.37554050260975, 56.17766041909495, 56.90257718486171, 56.50642564219814, 54.60731206401702, 50.69858781753048, 49.1907581206291, 50.73001776972125, 47.05380770467943, 49.77523050000591, 52.22740219485376, 54.930546745177246, 55.12715162769441, 53.20045594246157, 54.586801990385986, 56.40496177058066, 54.802630409117675, 57.136958414508456, 57.313543519666126, 59.73829784700948, 54.917289133994814, 48.92782988086824, 36.941623610834924, 27.167188928973292, 19.686215077677083, 11.59958020333321, 5.691484635876072, 3.8088420706410564, 5.875308475186748, 7.217617582890296, 8.552492818524762, 6.456431150436402, 6.892587927079971, 3.2678582351053915, 1.2317409246198594, 0.4747847683968083, 0.2902741465837725, 1.048829036374246, 6.041851332110744, 14.747295994912426, 25.23275244620539, 25.468141724986417, 27.806845134304417, 40.71625771061067, 53.230101216223936, 53.54864082028789, 39.46389982777257, 16.037245873481996, 1.9882431890695327, 0.04408134650739451, 0.03741437441579277, 0.022508515488176097, 0.04307062755669317, 0.047098691049482555, 0.05784611172613598, 0.07954234227297768, 0.05585815569746399, 0.02024091246928419, 0.017497915504199844, 0.044452638680776285, 0.036249890127369476, 0.04515334483115904, 0.008647900221178369, 0.06246587088812263, 0.04462561750363919, 0.022117584650855393, 0.016617427670186567, 0.01910538438917889, 0.08572087968669592, 0.07220610044896603, 0.03881509340698681, 0.013229668125390046, 0.043142436808275605, 0.03534513645835462, 0.05547985381957504, 0.03408540828874515, 0.014131770172576993, 0.15781351485319678, 0.15800538923471205, 0.17110512501770453, 0.07119409830099152, 0.16543973627830708, 0.09074257836947519, 0.11277374255681231, 0.13402807826717056, 0.06918063537488062, 0.23395350743686003, 0.13919213906891886, 0.09344505311380472, 0.2526681774085568, 0.12908474271816592, 0.13771058631039437, 0.23430128071096637, 0.1416457195075289, 0.15276769206168192, 0.18394806812847816, 0.1511084681917583, 0.14441978516838244, 0.2104477695519886, 0.13934175604053084, 0.29696488272278543, 0.1295498500187551, 0.2734974339123695, 0.08791308624729996, 0.19829252824908306, 0.11910067886234292, 0.1437025430101541, 0.139502864331007, 0.21267423556456644, 1.772155403610199, 13.462688384517548, 40.28456164944557, 57.44466835452665, 58.16227382229221, 45.66928555888515, 44.61124189438359, 50.8235074627784, 45.51089632895685, 43.846779792539536, 15.754398857393573, 5.8041287333734575, 0.947233152485663, 0.9401022835123924, 1.9311196284909404, 3.4362117561601826, 9.656518428556382, 13.693501237900028, 12.800770767273443, 14.096804241980276, 10.884439945220949, 10.820872053023308, 14.222997676941658, 18.78096930442318, 29.32557313672958, 41.01548356394614, 58.449003004258685, 61.55970142733667, 62.433452529291955, 54.894609989658484, 54.26317507220853, 55.876245883203325, 53.45284085119925, 55.37157020261211, 57.949261665344245, 56.087736160524436, 57.0330273720526, 51.91306344924435, 46.378838400686945, 45.35615882565899, 44.625923325938565, 45.04835867112683, 44.611018319283765, 43.856499425826534, 42.673865595171534, 41.32384069504277, 46.4205841864309, 51.41105498037031, 53.07788971931704, 52.85858608061268, 53.2304189282079, 54.71059983776462, 57.005566858476215, 55.87067611755864, 57.6705341185293, 54.56962593140141, 52.26259762240995, 43.02691028964135, 57.49976981070734, 54.94243544916953, 53.094285226637325, 49.1963827994562, 50.39481201479512, 52.84297504732686, 56.964778131054295, 56.94638613731631, 58.82586433041481, 58.25848171787878, 56.03889480713875, 59.16383927868259, 57.25484132766724, 56.046123735366336, 52.132492603794226, 52.182840147326075, 51.80035021997268, 47.42999438316592, 52.2516385201485, 53.3182329516257, 56.10596733708536, 57.65840222758632, 54.39477451385991, 54.6718389757218, 55.880505577210464, 55.20928998147288, 58.117849057720555, 58.37144990121165, 63.12472320372059, 59.41797748688729, 51.71030829029699, 41.41208225680936, 31.193017498139415, 26.870138029898367, 15.745730419312755, 10.301079557787988, 7.01472367009809, 12.866839170455934, 15.949453423100135, 13.030499085303276, 12.915350064154595, 11.688058087902686, 10.171936500457026, 9.109093816049638, 1.0608040325103267, 0.777999120614221, 1.9416019176283192, 7.032377767947413, 19.475475934243974, 29.17641716618692, 36.81552725453531, 39.818740967781316, 48.34900179216939, 62.60477773604855, 59.16415306829638, 43.821198094275694, 18.172450834704986, 2.778502351814701, 0.28302214378791474, 0.19349197616740582, 0.09981951751415769, 0.16601102336520152, 0.17996166832745078, 0.19458287004982272, 0.13991338020611194, 0.11692832163985699, 0.1415597950859416, 0.13389574423913034, 0.10710189569621317, 0.18529823680798854, 0.11689310457797782, 0.13773640347344263, 0.12774604237488202, 0.19903826887809462, 0.17110584514035335, 0.15430193634763842, 0.08646214636222971, 0.24130271146855048, 0.12258378954063501, 0.10831152554601432, 0.0774261009909453, 0.15121595032753485, 0.06936631976596772, 0.13954948844207873, 0.19607044425943207, 0.12333348318333588], [0.0526406591938388, 0.05396109600100787, 0.025665492961002935, 0.05070511507050646, 0.0362008911437325, 0.006767353549930117, 0.007243623230380998, 0.07444994899654582, 0.06385689886707453, 0.024624140069429434, 0.04519590101535282, 0.03746824571862817, 0.0371455809762401, 0.07949527383090989, 0.0352332225039361, 0.10175982670437905, 0.07473369264194081, 0.09914401948692338, 0.011813302745952482, 0.15950486845066472, 0.06315797387111573, 0.01811293472025183, 0.05333044859130056, 0.0593257722474875, 0.01552939608377675, 0.016589725930844585, 0.057425517964387135, 0.014159359871560048, 0.011036629401778263, 0.033314455706145496, 0.029227939704733513, 0.016798565329443065, 0.6054229229207962, 5.296507843079106, 20.558414882229222, 47.11174111212454, 46.945954292051255, 37.876634290141446, 47.251722658834154, 42.094366781173214, 34.863555815912065, 23.7212533720078, 11.897859784864611, 4.850724589440131, 1.049731916958286, 0.16128049171980352, 0.5576952775159191, 0.6442724673017379, 1.4885305324869773, 2.80828760516259, 3.5427830440382806, 6.9615078933777355, 3.2980504343586587, 6.3155754054746325, 8.983007265675454, 15.04903804871344, 25.679955597846742, 38.6225357363301, 47.17313405006163, 47.72212466885967, 51.553256588597456, 49.50044885758431, 57.152557680683756, 57.30416513258412, 54.025098969859464, 56.565335719816154, 53.49089960898123, 52.358876120659616, 51.3435156883732, 46.23772328899753, 41.85190154660133, 43.30957589610931, 42.960257453303186, 42.46002189574703, 41.2099939007913, 41.75792155727264, 39.93912635311004, 46.175224242671845, 49.71107621346751, 52.66721363990538, 51.87303566163587, 52.54584766203358, 52.03657496360041, 51.676344486974905, 51.86146074725736, 53.062302220252256, 54.80647040951637, 51.478880605389996, 54.932315734124955, 32.55893976457658, 50.66063496374315, 50.060418190494666, 47.69984560628092, 46.937019132798724, 42.289598834130075, 44.24461795437721, 45.84540390199231, 48.47659649387483, 49.39751017478205, 50.63816370502595, 52.1330770369499, 51.701482957409276, 49.785977794278054, 51.70749595088344, 49.212817530478205, 44.69767524350075, 43.9737900610893, 42.76722977238317, 45.84816525059362, 48.36138863717356, 51.97322084057716, 55.027001750084665, 52.29400404037968, 52.15814490472117, 54.623013311816806, 57.27799115642425, 55.80640023754489, 57.25213096987817, 54.71087832604685, 54.89255466768819, 49.13937114900159, 39.84112201198455, 25.736631885651622, 13.352119711137588, 10.748170921879431, 3.019447913092952, 4.733777161567442, 5.804010081675745, 5.6331099617865785, 8.883146662865917, 5.438238276589302, 6.348548810328207, 1.45670760783457, 0.4489675440615224, 0.529606020258319, 0.4917219918101065, 1.3228355203905415, 8.538327178647442, 21.45563744729565, 25.212120779099006, 35.92043061410227, 37.51423866518083, 40.21437475758214, 43.20014176830169, 46.06287971619637, 23.770545797963297, 5.761560720782127, 0.7676178325087794, 0.047786745257795825, 0.004737838687780764, 0.021194866220016154, 0.05801886838350085, 0.161135180162326, 0.0627697779676847, 0.06150701992033471, 0.03542664821349806, 0.04419680361846282, 0.028536922651373094, 0.023454275928557883, 0.05466820664643761, 0.04256493291787563, 0.017498706489981666, 0.04668510316180126, 0.033200285622789975, 0.05677031360626702, 0.039735885126696485, 0.016643292713730086, 0.011947300142398285, 0.08461140817211521, 0.047795605064640125, 0.008895458661079889, 0.040344204903850635, 0.04079093375513631, 0.06958509915538373, 0.012365956659308605, 0.018125705405949585, 0.032583550369787606, 0.0303124578204006, 0.06456864051400654, 0.00551098563347853, 0.0089310223777448, 0.031062733689923922, 0.02315416481466063, 0.02354082854224309, 0.03381217536967128, 0.028291510215269464, 0.05707833840842209, 0.040099968412710775, 0.06502179684297693, 0.05474471967787512, 0.04670091138611879, 0.09442336271486937, 0.04608603389633279, 0.010528712150370403, 0.02854038345357103, 0.07021506091639881, 0.014293132229678094, 0.02493481745102233, 0.03785689744437414, 0.019244948372004494, 0.06540076521735999, 0.04906503956825022, 0.0605204135870501, 0.05441901356642766, 0.062285855547675205, 0.009229085164054508, 0.060680104614866365, 0.060570929424777153, 0.6791492022814289, 7.181941174691723, 25.88073976578251, 52.05106027664677, 53.88260710623957, 42.87913499339935, 49.06621894528789, 50.09850440486785, 38.99282317007742, 33.39099214922997, 15.309261814240488, 6.108267845646028, 0.7792526243194458, 0.18991503504014787, 0.14593904477454003, 1.093260665093699, 3.6922113741597826, 6.578154063993885, 5.6227171517187555, 8.074782452275677, 5.835827858217302, 6.725069380575611, 7.843204246413324, 15.88092177144943, 25.573120040278283, 41.44804646891933, 51.51735905678042, 53.618094228929095, 55.47819199100618, 52.7794954084581, 56.912218370745265, 55.90898590703165, 54.41173876485517, 56.76240344201365, 56.59067423112931, 55.18408875311575, 53.66366824796123, 47.84053710199172, 44.11235955453689, 43.977532002233694, 43.47846531098889, 42.59564568919521, 42.25516042401714, 43.03162890095865, 40.96000556022891, 47.18564248854115, 51.9975983711981, 54.30005711893882, 52.39358517431444, 54.69692645534393, 53.36350887052475, 53.83816272981706, 54.38522746486049, 54.57151651382447, 54.73637765453708, 52.18303234346452, 53.831302504385675, 36.44085068856516, 52.33780907046411, 52.25885960363573, 51.27926726495066, 47.39108839342671, 44.87351509832567, 46.062189379046046, 48.64630176175026, 52.49575115019276, 52.53828533234135, 53.11432069347751, 55.20989402647942, 55.523032526816095, 53.33608758065009, 53.69407446153703, 50.46729741557952, 47.826930399863954, 45.12683745353453, 45.68442198538011, 48.172118586878625, 51.47791177995744, 54.56825702421127, 56.27611583279025, 51.84759516869822, 52.96960484596991, 55.12158970679007, 57.91896920050345, 57.01601997498543, 58.677865459072976, 56.60483790982155, 57.62839217339793, 50.822322906986365, 40.880499116836056, 29.018563339787146, 18.847173029376616, 9.646436956620986, 4.865882588971046, 4.213942500852769, 7.891453812199255, 9.098761312423214, 8.815648555755615, 6.520755079484756, 6.2992362822255785, 3.5711108917190186, 1.515619278915467, 0.4293931089341641, 0.39311948923334, 1.8162703009382373, 8.018898483245604, 20.612543590607185, 33.11315890281431, 36.56430336736864, 37.4990120241719, 44.611677277472715, 50.66688722179782, 51.81411381690733, 28.49665472584386, 7.998764957151106, 1.0638397018755636, 0.08784658981547241, 0.062524963080162, 0.040174305754443335, 0.02797459879319274, 0.05060172001380594, 0.0655067381599257, 0.0459407989476477, 0.05805672844871879, 0.00995516318887953, 0.04458936622306224, 0.013544154879186424, 0.12659881038651352, 0.046204716237562324, 0.08380602759819838, 0.1121051163382588, 0.018956792060165636, 0.021194274417094646, 0.057693116306777925, 0.016591150854383747, 0.04521845081340402, 0.03498532028207856, 0.05703352992573092, 0.07264070978928959, 0.11007702879367337, 0.05953039816250244, 0.04744439588619336, 0.016013579931290402, 0.026141900058475234, 0.2574736324529494, 0.15008627707439084, 0.15682861689598332, 0.053701629681933316, 0.16600031345602007, 0.05947689458187069, 0.1459441775636327, 0.11549445785461895, 0.12134105703162572, 0.11726536968302344, 0.21255175342723248, 0.09216354123406834, 0.10240891768086342, 0.20788990922512549, 0.2533151233388532, 0.1207424282667137, 0.26681187652772476, 0.20157218129644472, 0.1557386729625925, 0.3296528738592902, 0.1245226891290757, 0.11370587237780133, 0.12719420626038505, 0.08451058334040065, 0.1427879259591141, 0.09047420244784125, 0.17785665789438834, 0.10135611369004173, 0.16690863326432245, 0.11562507584570877, 0.1703586642660441, 0.08530345369851397, 0.9227996055156955, 8.517615102952528, 31.727063886580932, 58.819867026421335, 59.65866588777112, 51.318659628591234, 57.56887412840321, 52.997500742635424, 46.589991354173236, 33.58477292522308, 17.722582432531542, 6.808772760052835, 1.5973396551224495, 0.4538742146424709, 1.5103824244391535, 2.827989915686269, 7.462160693060968, 9.99206150731733, 9.856045476851925, 13.298177315342812, 10.484154224395752, 13.000778305915095, 12.330012802154789, 19.133311894632158, 30.20808485246474, 47.72872994022985, 56.20969049392208, 57.544367159566576, 59.78074181464411, 55.58250350336875, 57.93839277759675, 55.9906731882403, 53.55374774625225, 57.69311912598149, 57.98357063724149, 57.22752201941706, 56.25808469710812, 50.021790689037694, 45.083675692158366, 46.76095570287397, 46.214447944395005, 45.51091594080771, 44.764892901143725, 44.63903973179479, 41.60814585224275, 52.59352014910791, 54.18237032428865, 57.196845162299375, 54.282928128396314, 56.74531367517287, 55.557388567155414, 55.94503641128541, 55.11881266870807, 55.874265086266306, 55.3464513440286, 51.1529512559214, 55.921917961489775, 39.98056619398056, 53.702617383772335, 54.39682591346003, 53.8642268796121, 50.62242323352445, 46.66468504936465, 48.81718374067738, 49.00070751866987, 54.83395445731379, 53.20178562594999, 53.80743488188713, 57.26678102247177, 57.33588141779746, 54.41085230919623, 55.987511757881414, 53.54524797008884, 47.99780061168056, 47.669360945301676, 47.17859791171166, 51.09015410946262, 53.00262728045064, 56.38658154395319, 56.16482250152096, 53.231850593320786, 53.19277986403435, 54.41985022637152, 58.323169446760616, 58.49290609359742, 61.059991467383604, 57.884334671881895, 60.38800708709225, 53.09586986418694, 44.96228225769536, 31.982229755770778, 19.877146251739997, 13.913925693881128, 6.129917367812126, 8.729461335366773, 14.48108277013225, 15.79116225242615, 18.30100259473247, 11.642184007552363, 14.906367717250703, 6.839656522197108, 3.807374368752203, 1.5318938056307456, 1.3740445144714848, 2.222394347190857, 10.89234842408088, 26.040976432061967, 36.53014344553794, 48.673232755353375, 49.034165336239724, 53.240177785196614, 57.32420844416465, 61.15854886270339, 33.159278131300404, 9.861472075985326, 1.5688551577829546, 0.12754892029108542, 0.15593293753843154, 0.09756760206073524, 0.20183425997534107, 0.21554145751701248, 0.24157818136436326, 0.12558339914727595, 0.12984856302219053, 0.14869694598019123, 0.17147634058229386, 0.12240208114587492, 0.19922539351447938, 0.14546178731947176, 0.12857439026476877, 0.23139304241105435, 0.16395153387659983, 0.0940153289646391, 0.11026501910941255, 0.09805968331713831, 0.13585763412617868, 0.17010306669098718, 0.1987723137943014, 0.18018685221191377, 0.17174476246920325, 0.1692477754888035, 0.14494892209768295, 0.07601385620693046, 0.12241709646919083], [0.050647574206513744, 0.04088585587939428, 0.033905611283356146, 0.05847630714396796, 0.024055877114616098, 0.0696950710769142, 0.051639305668011795, 0.01263862937658785, 0.043055033836994445, 0.028702889854509025, 0.013005686041358258, 0.01956057085114862, 0.03158428060311464, 0.013563611597243338, 0.0594513378887167, 0.05705216884492867, 0.031162267663486065, 0.02475144281502693, 0.0804972555488348, 0.03596279867774537, 0.06236274396219562, 0.014208532182589896, 0.022237858539747617, 0.015535911661572756, 0.06071162147207126, 0.056028330638524027, 0.01893017050479689, 0.02368788294974835, 0.06134698798339214, 0.0951683602385944, 0.10854366550882978, 0.010418156086797676, 0.11175428637333455, 3.8517817278062148, 19.691110195652133, 44.62591548119822, 46.046735240567116, 48.54137051490046, 37.11484332238474, 37.78634917351508, 27.38253881854396, 35.2438021475269, 28.32558643433356, 10.53217286063779, 1.5702184265659702, 0.121038107561969, 0.18678499896439815, 0.6066734235613578, 1.8347292201172922, 6.680186679286342, 3.8895401791218793, 4.167892404140965, 4.25815692832393, 4.850858930618533, 6.660282611846925, 10.814132440474726, 20.595502853393555, 25.579282083818992, 35.99277873193064, 43.12909587737053, 53.33984521127517, 53.90630214445053, 54.46480843328661, 53.67007347845263, 55.76302274580925, 54.70636760034869, 52.233830959566184, 50.128090843077636, 49.60211277008057, 43.14322033236104, 43.417386162665586, 42.726817592497795, 43.599290001776914, 42.0584810164667, 44.88800041137203, 42.84904649180751, 46.47857250705842, 49.72230595927085, 51.89080399851645, 54.5025259448636, 55.15740879120366, 55.269035523937596, 56.02802984176144, 51.92083758692588, 53.90145017254738, 51.39057628570065, 51.75688251372307, 47.01234040721771, 51.30817121075046, 34.58149425445065, 50.19335908274497, 51.76892026778191, 49.82384827829177, 49.270613654967285, 40.90193486982777, 40.15180118622319, 38.840905850933446, 40.660446305428785, 43.16350683089226, 45.348157190507465, 46.49707040479107, 45.95939190156999, 46.21189448141283, 45.28503840969455, 43.679996690442486, 41.25818414072837, 40.54767031823435, 42.08231333763369, 48.7074750469577, 50.40651244501914, 53.08092171146024, 55.215746202776515, 50.55392296083512, 53.735498612926854, 56.75993627117526, 54.90857362747193, 55.24622694138558, 55.532089279543975, 55.3883187232479, 54.344234774189616, 49.93471799358245, 37.88598522063225, 27.801079250151112, 15.942475526563584, 7.803298052280181, 2.5538603673058176, 2.1539215310927364, 3.005397983135716, 5.335500615258371, 4.694019036908304, 5.647479074616586, 4.215087832943086, 1.8295124677881118, 0.26329623775616773, 0.24950282467949778, 0.5132981227530587, 2.020236614250368, 10.407112010063665, 19.35755575856855, 17.36825708420046, 24.309440235937796, 34.69920066095168, 37.58566894838887, 50.56128524964856, 42.568396983608125, 21.39228528545749, 6.237784508735904, 0.5301605453414302, 0.05549065948974702, 0.05404512052454295, 0.04893015829786178, 0.047734141830475106, 0.045334444186019326, 0.08663555036389059, 0.012657842861728804, 0.0706930231723574, 0.025302694787481622, 0.028053992315225547, 0.034946429828602465, 0.03369604793166922, 0.02756639458839932, 0.02812572878845517, 0.04231270996012515, 0.029317545178796978, 0.06770035432231042, 0.01121608837087068, 0.04147679312154651, 0.02838455350889314, 0.01666670819113572, 0.037118721933614825, 0.03569873583112513, 0.01683097467907975, 0.06639169994741678, 0.07509076622344794, 0.019210830646296664, 0.08598628318718365, 0.08754085944665056, 0.03351951446083765, 0.06441806593248922, 0.045260907406167644, 0.013418182253747458, 0.05818119475377664, 0.03048009126477184, 0.08017771261473818, 0.036120007580686966, 0.025213282750619036, 0.07538315900150808, 0.034521925188000166, 0.024345517721808246, 0.010146801040748195, 0.02669226911459719, 0.13393918142443703, 0.019344681528426947, 0.03514776539598261, 0.043227258063251936, 0.061089471358084874, 0.041414939182540106, 0.013601038822784059, 0.05306535918686179, 0.04466325923379871, 0.050518473069514, 0.031059276718165607, 0.06714264997431348, 0.027867321585935932, 0.03421282403231148, 0.0301783005031006, 0.021048903487802997, 0.03299236936014026, 0.26323121221315476, 4.906161898566831, 24.237947194806992, 50.89217639738514, 51.448035086354906, 52.24637469937725, 44.23565141616329, 40.78017273256856, 31.164466565655125, 31.054534296835627, 23.613313667235836, 9.756779113123494, 2.0500927154094946, 0.056409892220530784, 0.08127816727445011, 0.6804337172258286, 3.0864616074869713, 6.430797480767773, 9.284723824070348, 7.528107502768117, 3.5375819811897897, 4.834930675645029, 4.95424819569434, 12.629845642274427, 22.620196996196626, 33.30055406016688, 40.88790062935122, 47.39470481872559, 56.094145313386, 57.318164071729115, 56.84954281776183, 55.81766920704996, 55.38164284921462, 56.25576657633628, 54.957881742908114, 54.06063956599082, 51.305751108354144, 45.74462252278482, 44.36512493318127, 43.84203372463104, 46.32190519763578, 43.538065725757235, 45.823564144872854, 44.664503758953465, 47.361917726455204, 52.76217814414732, 54.76463048688827, 55.01603872545304, 56.583770859626036, 56.609066224867306, 56.50085979892362, 55.29538992912539, 54.82759629526446, 52.280824876600704, 51.96368555868826, 50.22055679751981, 52.78886595079976, 38.55976604646252, 51.868513168827185, 53.9612937742664, 52.56469465071156, 50.82828098727811, 42.90243387222291, 42.5657650732225, 40.97622063852126, 43.93135786056519, 46.39056628750217, 48.96372741268527, 48.98899139896516, 50.23233175277711, 49.040582333841634, 48.26702033319781, 46.05061838703771, 44.401167592694684, 43.53516709419989, 44.37979067525556, 51.47712730592298, 51.61530456235332, 56.12490061790713, 55.93103747214041, 52.85452250511416, 53.783327994808076, 55.84351762648552, 57.05681262477752, 57.34368693444037, 56.531320925681825, 56.50890458014704, 56.215283793787805, 50.5813128717484, 40.202741007651056, 29.832464956468154, 18.901244863387078, 9.144282379458028, 3.498621568564446, 4.609454206881985, 6.722306561085486, 8.7917770108869, 9.079139655636205, 5.127563024720838, 4.484233029427068, 3.219815329197915, 0.9951971819804561, 0.33874210871515736, 0.6580428058101285, 2.8878489617378484, 10.162312965239249, 21.853189276110744, 23.398357975867487, 30.95234674792136, 36.869844236681544, 43.11647761252619, 53.78373984367617, 49.65113847486435, 25.58442823348507, 6.42943004446645, 0.6467102816508663, 0.05657105413716167, 0.02819994164090003, 0.05874685875530686, 0.028157858515999494, 0.07069712174275229, 0.07213893752064436, 0.05582740875862299, 0.013482774957083167, 0.057322835369456204, 0.09920583512153357, 0.007986271737008206, 0.039693014846453746, 0.002163621904929319, 0.044807456133346406, 0.03925250279867361, 0.023239411248434937, 0.0921186101773093, 0.008314067832074098, 0.02816399679549279, 0.020140173822461117, 0.022775064290110624, 0.008594731804013492, 0.004008670934596129, 0.05355632961577466, 0.07080357732071031, 0.024266568530771523, 0.04176085469343009, 0.0560643176187671, 0.15436063400439679, 0.11186583643598903, 0.10302554951199602, 0.20750631367967975, 0.11166270056198682, 0.21682243313520186, 0.1471265423442087, 0.1867144575883304, 0.11743684314311513, 0.20920258556162158, 0.08912123754740724, 0.08647466423891245, 0.27869604527950287, 0.11945491025765097, 0.08189191095410817, 0.2625510487104616, 0.1255949134487779, 0.11299839784060756, 0.2323109842836857, 0.1093833898043921, 0.17171100863525945, 0.12284395299972066, 0.16726212155434395, 0.11466732038365257, 0.13075542726343678, 0.11941812271552703, 0.11393690917400584, 0.16708523185262758, 0.11283833909058764, 0.1445809087806171, 0.17741136162752108, 0.10123307230852305, 0.39314225736644964, 5.984813205657467, 26.519611497079175, 55.6675208768537, 58.093114591413936, 58.60086933259041, 47.7744020185163, 50.37247803903396, 39.94964614991219, 45.99364988265499, 34.34664234038323, 13.139811619635552, 2.570804761302087, 0.3401011486928309, 0.5506912114158754, 1.7512233074634307, 5.440334783446405, 11.614568560354172, 11.77017584923775, 13.070537659429736, 9.13133071314904, 8.792450677963997, 9.506280864438704, 15.272324854327788, 26.566440674566454, 35.67516088485718, 44.83171047702913, 50.28742144184728, 57.79170397789248, 58.816442797260905, 56.306612260880016, 55.743014735560266, 55.51327759219755, 57.655601655283284, 57.3374346763857, 56.350684012136156, 54.73214541712115, 48.5637790156949, 47.3199797445728, 45.72244936420072, 47.47867099700436, 45.49378302789504, 49.486873534417924, 46.766403875043316, 50.53622130424746, 54.602832717280236, 56.64038242832307, 57.82355362369169, 59.08749426564863, 57.643097139173946, 59.37562765613679, 54.21319230910271, 56.76077958076232, 52.06471796958677, 52.131068783421675, 52.4865218131773, 55.23828021941647, 41.465728513656124, 52.89337750404112, 55.98689202339419, 55.09539219640917, 52.97374686887188, 44.24706943573491, 44.10023158596408, 42.3955891209264, 44.88220707062752, 47.35611654097035, 49.994404700494584, 51.09597490679834, 51.120854500801336, 51.027419720926595, 48.966543674469, 48.76846398076704, 46.072230646687174, 45.57849837887672, 44.73835414455783, 53.38338352018788, 55.52229119885353, 57.969979624594416, 56.170980622691495, 52.86725844106367, 55.631286021201845, 57.00381355900919, 57.61253403079126, 58.566725100240404, 59.33553711060555, 61.04780074088805, 58.52896836496169, 52.56146261768957, 41.91479282994425, 31.798256866393555, 19.71027489631407, 10.364082628680814, 5.710405168994781, 7.683333341152438, 9.532276372755728, 13.889283403273552, 15.828831714968528, 12.05335528619828, 9.679125989637068, 6.010458642436612, 2.211095714761365, 0.9186767654553537, 1.039195695231038, 3.3479304803955943, 12.758095379798645, 25.8200724663273, 28.175200800741877, 37.11910693876205, 47.56295880963726, 50.61355083219467, 63.245630264282234, 57.33971749582599, 29.513870439221783, 8.413309474145214, 0.9333000356151212, 0.17633834823725686, 0.22527127977340455, 0.2024711548320709, 0.18191906893926282, 0.15561370870038388, 0.21050646720874697, 0.19844729333154618, 0.10791725073490413, 0.21717117168009284, 0.14054232307018774, 0.10499731427238834, 0.1076696357960182, 0.06799277774388753, 0.16147998101528616, 0.09863716805534017, 0.09495759412886635, 0.19229821199851652, 0.17000342929555526, 0.1726094612310971, 0.11873738464689064, 0.11267670986032295, 0.11686835993802357, 0.26018150811714513, 0.15667625732960241, 0.16070941913752787, 0.2089793168969693, 0.16840604404287954, 0.13905747613358882], [0.020985086448490623, 0.02196983310333904, 0.06313152468552993, 0.058594751997940966, 0.03051316902612246, 0.04864860566393022, 0.060277004470868464, 0.01959804978762423, 0.12022020911136944, 0.06693668723587068, 0.05333005788645918, 0.04037267656155652, 0.019874228314766963, 0.06366590931711179, 0.02848958416331199, 0.08233013622943433, 0.023142407280242732, 0.059425114699068575, 0.025747232627303853, 0.020437913894232725, 0.04736489894229078, 0.06482536423831217, 0.08540028721214303, 0.03890153110748337, 0.059465491363117774, 0.03279458461028915, 0.089589171712437, 0.021899981206403147, 0.0425321213720787, 0.03926172649728195, 0.13079008508113124, 0.054707648683219194, 0.03366234006300088, 0.9583052680377038, 14.274191471838183, 39.547630663841005, 54.94321207846365, 51.655430409216116, 55.263901141382036, 50.35334863970357, 68.66211752737723, 72.90663196194556, 41.876181017967966, 14.010342455679371, 3.7042000985914663, 0.2352666281043522, 0.05521210609003902, 0.9224469599223907, 2.334162530399138, 2.9310509274082803, 6.185509610560633, 7.520387297676456, 4.289503039852265, 3.2657394197679337, 4.33494762066872, 13.473057170068065, 19.891186375771802, 30.0334648547634, 40.160293117646255, 52.31251762759302, 49.46490041671261, 54.915324026538485, 57.985884835643155, 54.10419356438422, 55.99277950102284, 55.50895906263783, 52.565894895984286, 50.33027725835001, 46.445550072577696, 44.266610683933386, 43.293909949641076, 43.7255040291817, 46.36840097365841, 47.387393520724395, 48.6571628047574, 46.79092653336064, 47.997541735249186, 49.00639103304956, 55.65490261200936, 53.93681818439115, 52.406815328905665, 50.62587099690592, 51.558924413496456, 49.563387209369296, 52.88923940350933, 48.78128228649017, 56.46748827349756, 36.88153289979504, 37.14419441838419, 34.95058144292524, 50.7390078421562, 52.902100855304354, 49.54141801403415, 52.15017464853103, 47.23063207441761, 43.650669128664084, 40.04304955082555, 37.48075339101976, 39.044429794434585, 39.219073326356956, 40.13730802843648, 39.2659495722863, 39.64918474997244, 40.49753458269181, 38.85881931551042, 40.984308565816576, 39.03993475821711, 44.04047819875902, 49.863774084275775, 50.551047863498816, 54.18847745464694, 52.7669987370891, 52.558108991192235, 54.85118542948077, 54.68428073390838, 58.33978068444037, 55.279735749767674, 53.95968168012558, 54.458799362182624, 52.745853239490145, 49.120167224637925, 40.47251378336261, 26.62188533813723, 17.078244878399758, 7.6888138728757065, 3.8042884440191336, 3.5488666401755427, 6.995997784599182, 9.073744435464183, 6.680939774359427, 4.421161807352497, 4.558084885920248, 3.3624483981440147, 0.48766322734375156, 0.28768351301550865, 0.6511885865080742, 4.527753687674, 12.500613351022045, 22.722145280530377, 31.05536387812707, 29.385995288049024, 41.1868989852167, 44.729399373454434, 47.42643287104946, 36.45606164009341, 15.132430580354507, 2.8493006431287338, 0.15762193158509272, 0.07909982690527555, 0.08893461852905252, 0.10569259268982757, 0.03851711584795867, 0.04537466763248367, 0.08531746544664906, 0.09755877672784752, 0.022827650480453047, 0.03332449145795357, 0.01731304316631248, 0.01525438296788883, 0.021802986814309994, 0.01898605278843353, 0.036028241738677025, 0.02019313539588644, 0.018554209025516626, 0.040786387023305705, 0.04075657854217195, 0.05147213762205455, 0.042070656819569494, 0.060545476153492934, 0.04419086643704965, 0.09801246931836491, 0.027406898913003748, 0.011407527997488938, 0.04549480554076933, 0.028313142623031334, 0.032118785893544555, 0.027288921372664553, 0.019774380245155865, 0.06918953731656075, 0.010198949603363872, 0.07347740037667175, 0.00565371451704132, 0.017790036321046854, 0.03840070878786426, 0.015809004769600447, 0.011696568183270434, 0.0638415388041927, 0.03694644025076301, 0.07326921598324854, 0.04408456790711611, 0.0626137871445427, 0.09334614350190086, 0.01646595868101764, 0.03262104654324151, 0.03178613902550311, 0.023998600550957268, 0.03693016471281167, 0.0363031753729428, 0.05986908563382684, 0.023411149008860512, 0.0630520890286613, 0.02875827035055526, 0.03282176924028224, 0.016707793486514882, 0.03478220739071408, 0.08720470772635552, 0.04934812054759072, 0.09046449611384062, 0.09994171619895967, 1.9682171604325696, 18.7187389404543, 46.32853008085682, 59.08704319307881, 57.468080982085205, 53.75751879907424, 50.4923495938701, 61.81480061623358, 65.78343514473208, 40.159779287153675, 14.603143988117097, 3.331614155923167, 0.34736724750649545, 0.14034055083269073, 0.6298531603909309, 3.602296921514696, 6.560725012133199, 7.090129765772051, 8.865707805079799, 5.699636301686687, 4.731948846770871, 6.033413333277549, 13.975676548096443, 24.212061512854792, 32.39076814343853, 42.94739207913799, 53.513300265035326, 53.81338119506837, 55.78079892743019, 58.42856745566092, 53.61745880496118, 56.568759948976584, 56.5531293038399, 53.42538033762286, 52.23271308406707, 49.97458888638405, 45.94216877414335, 45.53679966157483, 46.42957033649568, 47.67321663518106, 48.344443998029156, 50.073165893554695, 47.117828630631976, 49.3127909014302, 51.31517656387822, 56.49997726563485, 55.87981916243031, 53.78541077336958, 54.05070027997417, 53.59896090722854, 50.47613451557775, 55.034952394423954, 51.229661049381384, 56.84911920178322, 43.346250057220466, 40.92887763054141, 38.66527388172765, 51.36962690661031, 54.62646891993862, 52.322276484581735, 54.76474423562327, 49.06618756632651, 44.932354573280584, 41.31758451461792, 39.166945026766875, 40.6795011797259, 41.88441015058949, 43.724546970859656, 42.494691725700136, 42.57000515537877, 43.1162775716474, 41.11565697577692, 44.07011955015121, 41.166396756326, 46.54047535311791, 51.836494861110566, 52.55654396549348, 55.85474737228886, 53.967153795303844, 52.23108137807539, 55.30012422992338, 54.88432945743684, 58.98784252905077, 56.76676904001544, 56.970822503489835, 55.0738936854947, 55.260959363752804, 51.541940550650324, 41.68274148817986, 28.70623088652088, 17.70438655730217, 7.988638868255, 4.1229194883377325, 4.459442669345487, 9.038564697388681, 12.280684094275198, 7.853983900239391, 6.4170481024249915, 5.142308194791117, 3.182516775784954, 0.9098538840490004, 0.38178739408331536, 0.44751390754695863, 4.510053992271423, 11.82059693721033, 28.352248745579875, 29.688515932329242, 31.387465077061808, 46.07197569262597, 49.19359007189351, 54.75318893309563, 43.49789673282255, 18.130332423794655, 4.277628064155579, 0.2349265616747641, 0.01563407050731081, 0.02193241162345775, 0.0718557377976756, 0.024790270066249277, 0.0362668245009357, 0.08182878530914746, 0.03985613028729155, 0.026298235621183153, 0.018596135102392688, 0.0638236966164362, 0.013834924508456983, 0.029298555774373874, 0.010622186368451485, 0.029048033531815298, 0.044518242620172045, 0.058567023445521636, 0.041982526064760266, 0.008634786711134499, 0.09084785417202981, 0.0850506217008637, 0.08215162242131849, 0.017796155448342045, 0.007372584556334562, 0.03977378732675026, 0.023232349832992882, 0.05387169737068396, 0.017884295779250322, 0.042265465317834774, 0.1677734546002842, 0.10125253094179977, 0.15608148198694954, 0.1258965146036879, 0.1788943546313432, 0.0720746397611595, 0.12062467289187255, 0.15937357630220153, 0.144933998704918, 0.168728704954828, 0.1496425742704061, 0.09716164440877977, 0.1656844860483562, 0.2903883549715242, 0.2528753429050407, 0.17781979374347195, 0.13404012116934025, 0.10503862173326554, 0.1330742681579244, 0.11666946819112187, 0.14094585222342323, 0.13683735332902403, 0.18625911024789657, 0.22167510983924713, 0.10733943657889482, 0.0896464444456562, 0.16586105399314435, 0.13485770552389084, 0.1721761619011241, 0.14474195578405935, 0.16867988983229285, 0.2165420602766737, 0.16127045596799544, 2.5199948683861764, 21.156609673653882, 50.092954251074026, 67.4761575268161, 63.315103284774295, 67.03970755300215, 62.44336828108757, 80.69933029913133, 79.04123460092853, 46.845027785147394, 15.794981660381442, 5.324649378176659, 0.5924587540568844, 0.3820824911517482, 2.16544839643663, 7.175139784812928, 9.376012086868286, 14.334337096060477, 16.402557780665738, 10.48253526610713, 7.4849982030930065, 6.500210685114707, 20.11259436607361, 31.448865859739243, 42.37999769949144, 46.77343668476228, 56.174400929481756, 58.1895068383986, 58.944410124132716, 58.297485766872285, 54.11238739567419, 56.83595180511475, 58.066054159595126, 55.92673855443155, 54.552916634467344, 52.3763189008159, 47.87994907748315, 46.20245725877824, 48.27203704464821, 50.38923048203992, 50.76385213482765, 53.04070565008348, 50.00972940075783, 50.88406493586879, 52.90922387953728, 59.87359216136318, 56.756743461855, 54.8580103535806, 56.63166692180019, 55.32981657212781, 52.64613090022918, 56.63154140595467, 53.554826398049634, 58.102857758921964, 44.258075606438425, 41.57048717621834, 42.05621780887727, 52.059630655473285, 57.01640044489215, 54.07825100806452, 55.83814397934945, 50.673135557482325, 47.633545783258256, 44.24150359246039, 40.93675767221759, 42.485085841148134, 43.401735905678045, 45.50207491843931, 43.18337363581504, 43.271497526476466, 43.75890693356914, 42.43915096406014, 45.89620251809397, 42.42408906259845, 48.55048610318092, 52.998179312675234, 55.11645532423451, 57.70243083277057, 53.34820770448255, 52.494354786411414, 53.964106113679954, 55.20850550743842, 60.96415227459323, 57.93331723059378, 58.37054775607202, 58.43801644540603, 57.898510117684644, 56.39813292411066, 45.07590939921718, 33.19613664380966, 22.56566232250583, 10.704745381109177, 7.924018800258637, 9.297904949034415, 14.822547647260851, 16.51087599415933, 15.24864354441243, 11.38609245900185, 12.441622864815498, 8.154930693487968, 2.2542618888039745, 0.9084325764448413, 1.1692021642961812, 5.9390332621912805, 15.82248826180735, 30.279413154048306, 41.041328061011534, 40.018307239778586, 53.20382525843959, 56.57254503619287, 62.91660616474768, 48.8973726764802, 21.946153371564805, 4.306093194792348, 0.3853816334759036, 0.24689642502175224, 0.3001350771275259, 0.22369637154042724, 0.11168608156543587, 0.14766107253249616, 0.24913467346660553, 0.30725938838816463, 0.24101283911976124, 0.12901486017771308, 0.21716462928921948, 0.08487517990532421, 0.13584833381877792, 0.10846845099642392, 0.17384562070571608, 0.11381720793583702, 0.11450062731220839, 0.1103760252496408, 0.19769513288572912, 0.15452796292881812, 0.27702578974346964, 0.15751573647702896, 0.1095390435488474, 0.18288145923326093, 0.13491913045365966, 0.15175811075154813, 0.1615510586529009, 0.21686993058650725, 0.08012090719515279], [0.010345719600727242, 0.05341082653631607, 0.02240786685668413, 0.03791989668482735, 0.08500575959201782, 0.08687090789598804, 0.027521992132308024, 0.045227655359814246, 0.03151228557521057, 0.09676003813623421, 0.03106529433881083, 0.03812656422416049, 0.037359403776786024, 0.01533647599224482, 0.07003735916148271, 0.03430435621750451, 0.0807046661934545, 0.08914828045113433, 0.0431842805306998, 0.06560531835402213, 0.09537657527553459, 0.04783485174900101, 0.05732919772966735, 0.02418795641842148, 0.051269396283333345, 0.035917859960107074, 0.07689159378529557, 0.04890890701884224, 0.05692518977147918, 0.05091948562391824, 0.025829755618507345, 0.10020643022031554, 0.050544692428722504, 0.7730742171406747, 11.194762183773904, 34.49053056778447, 50.013012424592056, 51.52225809712564, 48.171137994335545, 55.59768699830579, 84.24062651972618, 78.41681680371686, 57.254017629931056, 23.992763757705692, 5.822801176578769, 0.5664012845485442, 0.38498997868549445, 0.3057243014054914, 2.2243422942776836, 7.498256304571706, 8.577253760830049, 6.721796652963085, 1.6523695280475001, 1.2798851992814773, 8.066458202177479, 13.238466093617102, 20.758204729326312, 28.53471544481093, 41.29140661608788, 51.50875729899253, 49.96790516761042, 56.34401990521339, 56.49442711184102, 57.31222168091805, 55.040839872052594, 54.250121424275065, 52.724511623382575, 49.28866440250028, 46.16883470166115, 44.20387237302719, 48.230608970888206, 50.427446134628795, 50.45581663808515, 50.3576946258545, 54.287344717210345, 49.886806241927616, 50.533401120093565, 50.85449810950987, 53.882061896785615, 51.97190292419926, 52.284660954629224, 48.05698917758081, 49.70217635554653, 49.73224916765767, 49.37476435015279, 48.991642921201645, 54.24857601042717, 49.3776669040803, 45.672042985116285, 30.404191593970026, 45.506205174230764, 55.571771898577296, 50.713108431908395, 51.83884043847361, 47.45258331298829, 50.754003063324966, 48.032078204616425, 45.268431094384965, 38.28300360710391, 36.49874094993838, 40.463425651673354, 38.31450416195778, 40.821487057593565, 47.19997875152096, 45.91705776030018, 43.20782961383943, 43.473762389152284, 46.15433762150426, 49.104866058595725, 51.77687091212119, 52.51492761796521, 55.516631218694876, 53.654682097896455, 53.75748742011286, 56.02265619462537, 54.97038625901746, 54.09324230686311, 53.98295310235793, 53.17102639905868, 53.75714617390787, 48.136444630161414, 37.91702293580578, 27.441025280183364, 16.462411188310195, 5.534573158910198, 1.7057349677047424, 3.0280300590299793, 6.945415389153266, 9.038938303147594, 5.838714722664126, 4.050943995675733, 2.3721550981844626, 2.2392767187087768, 1.041700741456401, 0.5109805229210085, 0.5937085805400726, 4.619100786024525, 15.801134878589263, 18.698709357169367, 22.880377615651778, 28.73374042972442, 34.2736509538466, 48.86720180511475, 43.103361206669966, 28.266562607980546, 8.44586612716798, 1.1155103098961616, 0.013328028069208226, 0.030811498985595764, 0.06816511688333365, 0.034890631814637495, 0.031384314417899135, 0.024541659213061777, 0.04857163297973814, 0.044155591918576154, 0.02589688598809223, 0.06789098764138837, 0.003633121945782595, 0.08010101189175922, 0.05264075878526896, 0.018181474691617395, 0.050282862728401545, 0.05602770244642612, 0.07669211215069217, 0.04290582672242196, 0.041471101088269104, 0.03576998583852284, 0.04915412027208556, 0.04647491927889567, 0.07695385375090184, 0.092695995324081, 0.025107305977613698, 0.018651444735305927, 0.05532072969682275, 0.01573740523458729, 0.0038816923399515933, 0.07354340651222775, 0.035011849906896396, 0.01180063643973441, 0.034199474950230895, 0.036143051505449324, 0.11050000891930635, 0.02016326562771874, 0.03142707744583247, 0.1007530416151689, 0.034915947190095345, 0.054630147398359356, 0.054970202336628596, 0.02565736668334613, 0.02034620550881711, 0.05607914525054156, 0.04448805109507615, 0.07161114124521133, 0.03812561427513438, 0.02723258709715259, 0.030274078730613958, 0.027440761914476756, 0.009189497570567315, 0.026028086206004507, 0.013131965101966936, 0.023524346160552195, 0.028162116049638683, 0.03401172212174824, 0.03001023421905214, 0.05843437915187209, 0.04343328208872869, 0.03224326177470146, 0.03227961264670857, 0.060659267023325934, 0.9920816556099923, 13.979199817103725, 41.28895121236002, 56.77098558795068, 58.11525637103666, 56.54539831223027, 57.76906405725787, 88.0171629690355, 82.9778508217104, 56.569705240188114, 25.18767264581496, 7.099358612491239, 0.7927971813947925, 0.2162603391033988, 0.18389451858257094, 2.1518539517156543, 3.860332985078135, 6.0894796925206345, 4.890290517960826, 2.578244762074563, 1.150526043868834, 8.668960736643884, 17.79066889516769, 24.628148501919163, 33.529745994075654, 42.96429749458067, 53.82419516963344, 55.20964299478839, 58.695975042158565, 57.24135229664465, 57.334802766000074, 55.170815452452636, 56.36562824249268, 56.961102870202836, 50.886681156773726, 48.383134257408884, 47.07973457151844, 49.09765674221901, 51.06678462797596, 52.79792270352764, 53.53020960284818, 55.35180537931381, 52.3165302122793, 52.625067772403845, 53.38232840261152, 56.39378693795974, 54.7089171409607, 54.63040697959162, 50.71097466253465, 52.47975964700022, 51.84657535245342, 53.006431979517785, 51.92768212287657, 54.956473612016254, 49.68092887632309, 45.71378484849007, 34.49437841292351, 48.61855099278112, 56.22079472387991, 53.62267947966053, 54.64295464177286, 49.91072877760857, 51.302793641244214, 50.162486107118674, 45.63836159244661, 40.62101471808649, 38.59360433393909, 41.4437004827684, 39.18055565126481, 43.279809028871604, 48.428115998545, 47.65462852293446, 45.16613960266114, 44.98178428219211, 47.391543388366706, 51.528141652384114, 53.411236270781494, 56.30607489616641, 54.87379789352418, 53.766406889884706, 53.226979009566776, 55.75626450200235, 58.52595990703952, 57.01836162997831, 55.531108687000895, 56.87721513932752, 57.65060063331359, 51.06158748749764, 39.800772590021936, 30.32546374105638, 17.253461076367287, 7.622657216364338, 3.1075308640157027, 5.608449530216956, 7.7803291428473695, 8.7694901035678, 8.615075215216606, 5.566251691310637, 3.5733625773460638, 3.092250780713174, 0.6253191456198692, 0.27468992637530454, 0.9916099905967714, 5.068618136067545, 16.520609355741932, 24.947003856781993, 28.444391104482836, 31.018883874339444, 41.68856228551557, 55.230847327939934, 48.56097452102169, 32.29857087135315, 11.225897958201747, 1.1967566921826334, 0.06951107207926051, 0.043512461106142694, 0.050761499141733495, 0.08893091832437823, 0.08992930708993828, 0.0668423358471163, 0.07059782142600707, 0.011437326902523639, 0.0378716369760373, 0.06066143888259127, 0.03120256771874284, 0.06845767053985788, 0.07204499981936908, 0.02413637763369949, 0.07286642993529958, 0.007032897819073932, 0.023478610711472652, 0.02724299631682375, 0.020499779324557994, 0.029365257134721167, 0.057117006696400144, 0.06363302882340166, 0.06088969861007026, 0.007497984052245175, 0.05957173243645699, 0.04460570304804752, 0.024350280873477462, 0.03110006515447411, 0.031044799571616516, 0.2405225734917387, 0.22508268424820518, 0.12127976233680403, 0.13690368122150823, 0.14387132750163156, 0.2226048341441539, 0.1306348909894305, 0.15186943864870459, 0.20436541447716378, 0.213970486975966, 0.16561232056588898, 0.1337992018389125, 0.20475668622361076, 0.1035056951185388, 0.14862965281692245, 0.1835040435675652, 0.19219157255945668, 0.1981699082159227, 0.15311220180123084, 0.10191736502512809, 0.15555616017551194, 0.07966287854698398, 0.11479239955904985, 0.0735991470695984, 0.22427318978213498, 0.10695428587496282, 0.2386959747321183, 0.1827669444103395, 0.14766596017345307, 0.16353659001329254, 0.12484318201219845, 0.253706103971889, 0.17962472753659373, 1.4295793925562215, 15.86660021735776, 45.16160926511211, 62.93164845435851, 66.6045754955661, 60.4773037664352, 64.80658846516764, 91.32146173907866, 83.90359294029975, 61.771901653658965, 28.510743879502822, 7.205294966697694, 1.1797283349498626, 0.6406796375109304, 1.1315311082909185, 5.3761197001703325, 12.781893380226629, 16.95637095359064, 12.300615618305823, 6.191634881880976, 4.35448935916347, 11.708404402579031, 18.67120569752109, 25.467818129447203, 33.60338457169072, 43.943819230602635, 54.0887668824965, 58.0166950533467, 63.105303548997455, 55.3959987240453, 59.262035815946525, 56.73620985400293, 59.059402250474506, 59.136829837676025, 52.7216169141954, 50.21795234372539, 49.18818504579606, 51.854074924222886, 53.68533149842293, 55.603256763950476, 57.10935669560587, 57.705372610399806, 55.057666840091834, 54.64355868677939, 56.00595474243165, 58.48105269093668, 56.082637079300426, 56.229329801374874, 52.82792099060551, 54.49388104100382, 55.63927588924285, 53.795703072701734, 55.297221675995864, 56.550520927675315, 53.54868396635979, 47.63586782640027, 37.82401177190965, 47.6566760001644, 56.23010250829882, 56.06548063216671, 57.27451593645158, 52.62207892633254, 53.7570285028027, 52.73375664987872, 49.56846275637227, 42.76409187624532, 39.96563373073455, 43.9712405204773, 40.54693683501213, 45.9390583345967, 51.647499376727694, 51.375851708073775, 47.481808893142215, 48.31661870402675, 50.69361425215199, 53.63521929710142, 55.355108014998905, 56.90071405902986, 55.16795212222684, 52.45635094181184, 53.37084762511715, 57.7895466742977, 59.987964553217736, 57.76866789787047, 57.81887031370594, 56.90870392707087, 59.77956902596259, 53.026953820259344, 43.6145087980455, 31.890195262047556, 19.619719136145807, 8.378613168193448, 5.095145125542918, 7.927420475790578, 14.193795631008765, 16.408464870145245, 15.029784114130083, 12.950116972769461, 8.566361338861528, 6.840258115722287, 2.0364459315615315, 1.3996696039553613, 1.1123630981291495, 6.391961603395401, 18.71180615117473, 27.031082683993926, 33.24349926364037, 39.915035155511674, 48.944397972476104, 62.58916670276273, 56.023985878113784, 37.04332674703291, 12.512850165367128, 1.8348270342234643, 0.10723068273716396, 0.1361782112789731, 0.165801789431322, 0.1123775831694084, 0.22609886923624625, 0.15455192615908964, 0.18582921234830735, 0.13399067785470717, 0.21045546107474836, 0.31651795931881477, 0.1341356676552565, 0.1457797904168406, 0.13948907474836997, 0.1576826363922127, 0.16253650819341983, 0.13079270510183227, 0.1299693138008156, 0.13227733753381238, 0.13502904874903543, 0.09482912118396453, 0.1393044322368599, 0.11374507309688676, 0.32730386442234444, 0.12052616930656856, 0.133764635951769, 0.12683930070770363, 0.1567699652045004, 0.12855079475670092, 0.08922090558635612], [0.0672927955465932, 0.02541301336379782, 0.070433120183166, 0.013986633857712151, 0.035356765673045194, 0.038310187838731274, 0.04033712242099066, 0.0494029188168145, 0.015873087066856605, 0.050195877275039116, 0.04527345975680698, 0.021419984987005595, 0.0177739369833181, 0.02502534223059493, 0.04210578195089775, 0.06853494582878006, 0.1330430577358892, 0.05076589265597924, 0.0188778581908874, 0.07456875391184323, 0.029706817435761614, 0.023975767300374085, 0.07218945335837142, 0.03520665074428243, 0.08619244510848677, 0.01668706314728385, 0.03963750411546038, 0.018205188943313497, 0.07257015309146336, 0.05586228108093624, 0.045738138048158544, 0.0229670440087155, 0.030350825418868375, 0.21270114057246717, 5.946196490718473, 29.965515675083285, 49.0469483406313, 50.62966392886255, 48.94537072027884, 49.72349051506289, 45.428365738161155, 52.52913052035917, 32.21412616391336, 15.513275073420619, 5.935029993134161, 1.6912389907144731, 0.024615870150286826, 0.7010348021022735, 1.8758664256142032, 4.25481604952966, 3.4460149849614794, 16.40995046784801, 28.913506577091834, 10.556527837630242, 7.431823611259461, 6.223363914797384, 16.90711775133687, 25.145479709871356, 37.582217262637236, 46.450492258994814, 45.208956195462136, 53.120941654328384, 55.392978499012614, 55.29029869264173, 57.41858851525092, 52.43276180759553, 53.091610170179806, 51.98223052486297, 51.165475383881606, 49.57321666902112, 51.616171406161406, 52.103259178899954, 56.46315013208697, 53.77847210053475, 54.99031974423317, 50.488368388145204, 53.05258258696526, 51.89289069944813, 51.49914356970018, 52.29429429577243, 50.13272316225114, 45.61489797407582, 47.47772178342266, 45.154313656591604, 48.31453592546525, 47.87390078267744, 53.00992288897115, 51.19335559106643, 56.35483780214864, 35.373224673732636, 42.666287575998616, 53.774859597606046, 52.200973264632694, 54.428491207861136, 50.248115370350504, 54.16767712562315, 52.610150998638524, 51.637748364479314, 42.666287575998616, 37.42030966666437, 37.88252961251044, 42.847779566241854, 49.730225224648755, 51.45362446385046, 50.26217706741826, 48.193315075289824, 43.54365902562296, 44.07572069475728, 50.03597397958079, 52.20663324479134, 54.824238746396965, 56.833684675155155, 51.19526578534035, 55.01016693730509, 56.09264696798017, 55.19195702768142, 56.077204596611764, 56.369174065128455, 54.67057597252631, 53.73589084994409, 47.13461245259931, 39.09196892092305, 23.92727782649379, 13.298484240808795, 7.337261640256451, 3.162213852328639, 3.9098737460951654, 8.410873682268205, 12.042974733537244, 7.517426888788901, 3.807052734398073, 2.76395722262321, 0.9422335401177407, 0.10368397143939811, 0.3589648993745927, 0.9033201959344649, 8.016724999873869, 14.845947527116346, 30.257420424492132, 31.42453343637528, 26.899508737748672, 41.19250405219294, 49.961974543909875, 36.102648242827385, 20.018257441059237, 3.2710454060185343, 0.4050845875134392, 0.07068610539840114, 0.08535461305009742, 0.05887925023994139, 0.05725579884564204, 0.02295745450312332, 0.09066629899485458, 0.13646244522063963, 0.012250029361776769, 0.03519260835263037, 0.01703577296387765, 0.009822929709879382, 0.022777527262787187, 0.022237176721495007, 0.0011797337473610477, 0.038162037925494295, 0.07692627458562774, 0.03792176976980221, 0.08154371633164345, 0.05861029975236424, 0.03117722169976802, 0.033818909282525705, 0.04449743567214859, 0.019728167906343456, 0.08912175848719575, 0.05561704484505519, 0.04934530900490861, 0.026328808275021376, 0.0774214661590034, 0.05942132256384339, 0.017000038792649587, 0.08981750421826878, 0.020750657798001365, 0.019143049101976138, 0.009509528885715672, 0.036904056436352195, 0.032248494155224294, 0.022516189773957578, 0.062493580288343856, 0.05023833769824236, 0.048967757893185464, 0.058030191163021716, 0.05352040775300515, 0.036797252288388635, 0.03338607343574686, 0.07080966771970834, 0.018444371169372913, 0.06131110059457922, 0.0557093431181725, 0.03779104069596337, 0.04195984986220156, 0.049285347303075176, 0.017839079354739478, 0.03590434233868315, 0.047989168670028455, 0.025653825441916144, 0.045383381882622365, 0.015207872812395856, 0.025575799386828177, 0.01571095700661141, 0.01569940057027364, 0.02607813664531756, 0.0397566844138407, 0.35078424479692216, 8.373058111436906, 35.256934242863814, 54.95523022067163, 57.35592865174817, 54.261531599106334, 54.7683959622537, 54.79538186903923, 62.41095773635372, 51.911372907700084, 26.371016425471154, 7.454162980279616, 1.6302357157391887, 0.18699812462493298, 0.13869494800606083, 1.2220341616099881, 3.6618882658020144, 3.3365931145606504, 11.291083828095468, 18.080098628997803, 9.945453943744784, 9.658987560579854, 11.148805733649962, 18.797633494100264, 27.90813053807905, 40.172985907523866, 48.79033903921805, 50.04113581872756, 55.33798294682657, 56.53121894405734, 55.649595645166215, 57.079162290019376, 54.5236792872029, 54.91585354651175, 54.822191269167014, 53.333667478253766, 51.57644956342636, 52.91624492214572, 54.181468179149014, 58.43219957044048, 54.76916474680747, 56.70867873776344, 53.61026125569498, 54.716754036564986, 54.30235955022997, 52.99295471560571, 54.805305465575195, 51.563976426278394, 49.01890731626942, 48.63116533525529, 47.95885147586946, 51.780279451800936, 50.90645774718254, 55.16005639106997, 53.06915460094329, 55.74517988389539, 39.16721174793859, 43.04239972945183, 55.719853139692745, 54.36756503197455, 55.70096692731304, 52.42481116325625, 57.27043667147237, 54.20787357514905, 53.164797675225046, 43.545945767433416, 40.19612004680019, 41.2588038752156, 43.59220227887554, 50.95651111295147, 53.82792534366731, 52.34714431147422, 49.87203851822884, 44.27002706835347, 45.78559952397501, 52.26897539631013, 55.0123320856402, 56.94731181667697, 56.55299594325405, 53.028946384306884, 54.58647251129151, 55.93039420343215, 57.18824340451149, 56.947107853428015, 57.48123268927298, 57.09544797097483, 53.72746167644378, 50.31945543904459, 41.34678263818064, 27.747356507085986, 16.199670241725062, 7.351502295463317, 2.0679926968389943, 5.4626815069106325, 7.1316362869355, 8.870376406177398, 5.772021191735422, 5.375393571392183, 6.049150372705152, 1.2735444427497926, 0.5839670064949221, 0.2762412544219725, 1.041479250115733, 6.5056676826169415, 17.699760121683923, 28.405877351760868, 29.07951108870968, 31.959858517492975, 41.68440065076275, 54.35458590907436, 42.34413939137613, 24.2336247428771, 5.049404405778454, 0.6711263618161601, 0.015812476105507345, 0.06613134496635006, 0.037375740601771304, 0.09229870978742839, 0.029491868485967, 0.024283502904337742, 0.05025975751660524, 0.07315328389766716, 0.040149430879541946, 0.009217646513735096, 0.08002901494863533, 0.016059736728728298, 0.030016292059313388, 0.010022564562067631, 0.03411565727043537, 0.04454076177470627, 0.021674693900070364, 0.03481427583122446, 0.011889745871866904, 0.03314176799669381, 0.05879827474634494, 0.007539327423493829, 0.02621511316617891, 0.0578201107019859, 0.025527955280737053, 0.0425303670307321, 0.020181963918730617, 0.04801305912194714, 0.04406632735363899, 0.09392450924121565, 0.1989008480262372, 0.199145934874973, 0.18021761830295288, 0.08554045831964863, 0.12312707611389699, 0.15103870822537332, 0.16283479218761768, 0.2333117249391733, 0.14156500448382672, 0.16030878579664617, 0.09930253073933626, 0.08730777719568822, 0.15999190118764678, 0.2203832098072575, 0.1659975861830096, 0.22819442614432306, 0.16384921517343293, 0.11938366408069288, 0.18590451879126413, 0.16759875591003126, 0.10385006696226136, 0.11811184321319866, 0.18557909996278826, 0.1497955773506434, 0.1601276366460708, 0.1598706141474747, 0.09341714453072318, 0.21131948567926886, 0.16836939439658197, 0.10771492691410166, 0.22077869503728806, 0.1353163010771236, 0.7231741302436399, 9.732311367988586, 39.42857888437087, 60.93969629656885, 64.13270565771288, 61.59423789670391, 60.33054044169765, 56.736558944948264, 61.008322085103686, 42.85583219220562, 21.496102579178352, 7.905784191623812, 2.5320228165195835, 0.28243676068321355, 1.3382557058526625, 3.9027053694571223, 10.39563907730964, 9.928084708029225, 23.4489232109439, 36.85259757503387, 14.85827063360522, 9.244753891421903, 8.487181432785528, 17.954892650727306, 26.568896078294326, 40.727103064137125, 48.76011717704035, 53.846525223024436, 59.269100004626864, 59.286138780655406, 56.80001504959599, 58.591840036453746, 55.56992838459631, 56.520412814232614, 57.010756154214185, 55.01055917432232, 54.35245213970062, 56.975529347696614, 56.42791940319923, 61.72734352850146, 57.83058643341065, 58.554989368684836, 55.28084578052644, 57.2474084361907, 55.194977252714104, 54.211576292591715, 56.344463133042865, 53.59252037540559, 49.19129156297254, 51.3181261862478, 48.558719158172615, 53.05877993183752, 52.874412844257975, 56.34226660574637, 55.010170859675256, 55.788494617708274, 43.361410017936464, 44.92747514478622, 53.851926326751716, 54.046722996619444, 57.37730949155746, 54.77029046704693, 58.56418732673892, 56.39613643769295, 55.51844727608466, 47.1727692696356, 41.92738756056755, 43.3547459110137, 46.38690279376122, 53.85108693953484, 55.59667110443116, 55.48499338088497, 51.91005891369235, 46.212608352784194, 48.80857413814914, 55.654286799892304, 56.375897007603804, 59.26363614297683, 58.063845865188114, 54.179146136007006, 55.562824972214244, 56.83590081430251, 59.07282460120417, 58.29556772785803, 60.99353082718388, 58.35364626299951, 56.97050479150588, 51.88401829811835, 43.55917199965447, 28.518292480899444, 19.08264663911635, 10.395752826044637, 5.636905345224566, 8.549230387133937, 18.935387134552002, 24.235425110786196, 16.31074195907962, 10.535674556609123, 11.249777347810808, 4.308232847721347, 1.395925088755546, 1.0226959386660208, 1.7894019426838046, 9.568558296849652, 21.438581020601337, 40.774136204873365, 42.547016143798835, 39.33573638239215, 52.02683571846255, 64.6639750080724, 47.17542863661244, 26.76582063398054, 5.937384886126365, 0.8794431965197287, 0.10631470204961878, 0.2779584251824887, 0.18096705147575948, 0.18083727618138637, 0.2266899213915871, 0.20309459718485035, 0.18730737899820651, 0.2570722636676604, 0.098684205853891, 0.09993216308254389, 0.1667815545994428, 0.22021281653113906, 0.1057128557154248, 0.18822265488486137, 0.16846837295639902, 0.18436279748716664, 0.0902260282647706, 0.1706852169046479, 0.11529129899797902, 0.09538425913741512, 0.13841036166394913, 0.12287986720161093, 0.13674102543342498, 0.20224157360292253, 0.1260600667146425, 0.2509324060332391, 0.0852407647236701, 0.127280529047693, 0.14360710377654723], [0.04083788728401546, 0.00128656470840196, 0.027444720673825473, 0.008968988737662234, 0.06530262935425966, 0.0026730533770000144, 0.017938783782864773, 0.10255435181240882, 0.0819255268922256, 0.021251323069596005, 0.016554734864903074, 0.03662600865467422, 0.021852033678442243, 0.007436530872984159, 0.03396995500811646, 0.024664819338208726, 0.0150665994958892, 0.07032811251138488, 0.07295412401999198, 0.031899334261974985, 0.10565652527035245, 0.06285786658765809, 0.06253772610498053, 0.06540716205152773, 0.04082769448418291, 0.02408997377290601, 0.055758817076322534, 0.038526979229983785, 0.024381447245457002, 0.009183180218021716, 0.035546422230019685, 0.06204040097673574, 0.060183648996415644, 0.04573852875299993, 3.107357544283713, 17.266346062383345, 38.465264381900916, 52.127981878096065, 54.84538816636609, 41.10705129561886, 26.236722315511397, 22.992247535336404, 22.674951322617073, 22.4494150377089, 11.573158137259945, 2.2622152297727527, 0.9020384389065927, 0.05322030046954752, 0.6925383967257316, 1.336086389999236, 7.830405062244785, 18.72942739917386, 5.088283429222723, 4.899912582289788, 3.789510424098661, 7.792818459772295, 9.793324816611506, 19.65766610637788, 27.372070012554047, 43.33086652140464, 43.70243657019831, 48.978679487782145, 53.32212002046647, 55.66827004955661, 57.02813225407755, 54.74972548023347, 52.1975294236214, 50.53602518573884, 48.60479524058681, 51.54991472921064, 53.54505969632057, 54.20020926383234, 56.1595037675673, 53.969005154025176, 55.95469720901982, 52.83352213521158, 56.32031309989191, 52.54194490371212, 52.690622345093765, 49.59298149231942, 47.117867854333696, 43.375118701688706, 43.25388216203259, 43.38625038823774, 45.80513292743314, 47.02324459629674, 52.600356840318256, 52.858240912037516, 57.111568912383056, 34.603424226084066, 44.10979040207402, 54.97676795528781, 51.50500359073762, 54.59720411608296, 54.68781871180381, 56.076043575040764, 51.84161355418544, 54.48045476790398, 45.52435790338824, 37.87747759972849, 38.38458122745637, 46.828730337081424, 50.658603175993896, 53.58612691202472, 52.125950090346805, 50.99601330295686, 46.81368020273025, 44.36840403464533, 50.410136715058364, 50.98947078950944, 55.96809210315828, 52.50743196856592, 50.86309202255742, 53.01948954982143, 54.13625501817273, 55.63644001560827, 55.20207674272599, 55.80928710199172, 55.61476499803605, 51.75544300386983, 43.80671278122933, 32.35448229697443, 22.101288995435162, 12.937677175767961, 5.755574693602901, 0.8359890959916577, 5.394418537616731, 3.917209313761804, 5.380273980479087, 4.912850030006902, 3.4739569694765153, 1.90939778762479, 1.6278509146744207, 0.2826473122883228, 0.195707441157391, 2.046415493372948, 7.986951268488362, 15.526047291294223, 23.13090135974269, 33.81095247883951, 33.64267495370681, 44.06655411566458, 54.802638253858014, 29.572721681287213, 7.704950994060886, 2.1001519647336777, 0.0964910033789854, 0.043119274139884985, 0.03336512093101779, 0.02244353399521882, 0.03428220478517394, 0.032869860409728946, 0.0458901145705773, 0.0512879126284632, 0.07469525034990042, 0.06251112370180988, 0.01604743048383464, 0.03628542511573723, 0.03809465666211421, 0.04066816433483074, 0.04232118672300731, 0.014973126235418023, 0.008047497962721655, 0.040815111490026604, 0.007764548175938188, 0.05431285676276011, 0.059150280656232956, 0.0448229540920546, 0.016213057735454173, 0.030412667866555915, 0.03628173640238182, 0.016512668976980834, 0.06757434051964553, 0.038483894445122256, 0.053390142162360495, 0.02473033134705357, 0.08973899552778852, 0.036040418706233465, 0.0006840263214995034, 0.050405092056720495, 0.036422348010443875, 0.03861943072068595, 0.031778263641641505, 0.12635407593822287, 0.009904861855771272, 0.031841134562367396, 0.011724151178984153, 0.06946132232945773, 0.041162988186002746, 0.0721989911530287, 0.027145915739839117, 0.018709569741340897, 0.0476506688902455, 0.04752126897895529, 0.04927956333924686, 0.04701759298181823, 0.0793863897542319, 0.04630867053844756, 0.014525536492827439, 0.023827184547459888, 0.012670119420715399, 0.009477659628065604, 0.046622195851898966, 0.05603045270207429, 0.05118654770476203, 0.1052926641498362, 0.029096835247811773, 0.0597184382739567, 0.023614173800113703, 0.04038149806400461, 3.697225634128817, 22.058703822474328, 47.22831787601594, 58.58041809451196, 60.91944902173935, 48.64588599051199, 32.85934625133392, 30.98966221655569, 24.036476612091068, 19.142470628984515, 11.52344503710347, 1.962974177252862, 0.6442097706660148, 0.18311919163792365, 0.6523474630328917, 1.5759077019268468, 5.155929605807028, 22.37816518352878, 10.808616607419907, 6.123817591897904, 6.697892748540448, 8.467706864879977, 12.755720384659307, 20.598207327627367, 31.567348895534394, 45.341936311414166, 48.106493411525605, 52.15418331084713, 57.1295843585845, 56.345820273122484, 58.02128030407814, 56.68347750940631, 54.6837119902334, 53.73879732624177, 49.54731333640314, 52.693756318861446, 55.33610020914386, 55.967844993837424, 57.52826190763905, 56.52431949492424, 57.145105177356356, 54.99734863158196, 56.01254824669131, 54.90743221775178, 54.92774617287421, 51.90518340756817, 50.49509525299073, 47.92684493526336, 45.189344344600556, 45.63938533106158, 47.58448085477276, 49.718603241828184, 54.25257682800294, 54.199326730543575, 56.95282666913925, 38.75972063310685, 45.60013025037704, 53.6575101267907, 51.37625178983135, 54.86944014026273, 56.663089029250614, 56.20175946143366, 55.873249192391675, 57.20214428440217, 48.32010569110994, 40.48640289614278, 39.99203128199424, 48.481079762981786, 54.17853032388995, 54.72574803137011, 55.06621368469731, 52.26017359764346, 48.79486153202672, 46.90562055956933, 51.767304251270915, 53.92803207520516, 57.80877021051223, 53.81603271730485, 51.702710659273215, 54.05202996346259, 54.32850606979863, 58.10668991458032, 56.50941841063961, 57.654632829850726, 57.27729689690375, 54.303853973265625, 47.15116877709666, 35.924274536871145, 24.54415878941936, 14.22983927111472, 7.102261656715024, 2.7487570576129423, 6.723580841095218, 5.947722783011775, 7.278285372641779, 7.573429999812958, 4.487736686583489, 3.7614100738879177, 1.148750190773318, 0.3535534994256112, 0.21833616158654615, 2.097913517105964, 8.882439655642356, 18.43754618398605, 30.45383507205594, 34.50881273515763, 34.66035742913523, 47.25195015630415, 60.61789720289169, 37.81868911558582, 11.848203559075634, 2.7070605466442728, 0.11878878148573062, 0.010959949746217218, 0.11148307592638078, 0.02144974558764408, 0.08206895387340939, 0.03464775512956324, 0.006228972333408292, 0.01237910464330907, 0.07451178761379373, 0.018187049896486344, 0.033681588022098426, 0.027010954030218626, 0.026385575390210556, 0.01779934045888724, 0.037187252328881336, 0.027275614425419804, 0.013599400352236005, 0.030767332101541183, 0.0071482941219132515, 0.02194809152804796, 0.08580835160589026, 0.04505938031680642, 0.06333278364411767, 0.031647249200050874, 0.047022974749486295, 0.04152907862237865, 0.05848219836010568, 0.019792867861988566, 0.0071618074340926065, 0.07241739515936182, 0.1412602700293064, 0.10934104046393787, 0.07581180817778073, 0.08251330019125054, 0.16787888362042366, 0.10814755208670132, 0.12400600112854474, 0.3167768663937046, 0.1280841399585047, 0.0629798048025658, 0.08391092801767011, 0.16117012909343167, 0.09518680763581107, 0.14980912178514466, 0.19400378418785913, 0.131084737818568, 0.15897531783388508, 0.15743057814336595, 0.1890153107383559, 0.1659983522709339, 0.17568089158063935, 0.1585737958310112, 0.20395350432203663, 0.15650063933384034, 0.12687729866874795, 0.13772753217527944, 0.11276324715224967, 0.1229866905017726, 0.14896489289258757, 0.2140775554242634, 0.17183886870982187, 0.16724145250214686, 0.26416142681433313, 0.16859068655438963, 5.348661147779034, 24.079883521603, 52.365297040631695, 63.41688094600555, 69.89268272153794, 53.713478426779474, 40.77085710340931, 36.20250394267421, 32.27870994998563, 30.224631371036654, 15.161353157412622, 2.979225723012801, 1.1300536004766342, 0.287761960418955, 1.4172798202883814, 3.5202039201413435, 16.142185945664686, 25.973480286136752, 6.602210450556971, 5.899931644239734, 4.671789984549246, 12.56780747444399, 12.970934952459029, 22.288335061842396, 31.4505583624686, 47.97207378572034, 52.13033530019945, 57.331001989303104, 57.11207882050545, 56.857042389531294, 58.70726754588466, 59.4291836984696, 56.329487523724964, 55.44433016930857, 51.25770207374327, 56.238312029069476, 58.971674519200484, 58.45774596737277, 59.11420168415193, 55.609536478596354, 59.93759739783503, 56.06587286918394, 60.104847261982584, 56.96938691600677, 56.00841014615951, 54.28210050828996, 51.741648027973795, 49.01066641653738, 46.45315554834182, 46.93171216595558, 48.85900405145461, 51.22528760663925, 55.48362447369484, 56.97631774410125, 57.34707586226925, 41.62996207514117, 47.64810954370807, 54.95666188578452, 54.81258930698518, 55.839355991732695, 58.05134134907877, 58.89510200869653, 57.40576628715762, 59.452227623231956, 51.07924992038358, 41.048203975923606, 41.090192948618245, 51.93193004977319, 55.50911987981489, 55.823509616236535, 55.542283519621826, 54.185041458376, 51.46268906131868, 49.395392094889, 54.3446623125384, 55.84230953647245, 58.99195709536153, 54.26656792240759, 54.660271906083636, 55.583327201104936, 55.494920899791104, 59.25252406827865, 59.128808590673636, 59.92348863232521, 59.75360685779203, 54.8996933814018, 47.77070714581398, 37.02709990163004, 27.052012451233406, 16.03256844705151, 8.559324606772392, 2.905885245530836, 13.552146861630103, 9.496242538575205, 11.85428225225018, 12.679835269528052, 11.383695890826564, 5.783726524922156, 2.796172139144713, 1.1885707056330097, 0.5100435054590625, 3.4557456499145878, 10.08700345793078, 23.01167699598497, 33.564670778089955, 43.80282963475874, 44.58029439372402, 56.78603964467203, 64.67170599968203, 43.49586102270311, 12.667314083345476, 3.212165236473084, 0.48221971298898425, 0.194897732186702, 0.18957988689503363, 0.09533461663992175, 0.20475818775594237, 0.11603569131224387, 0.13246625481593993, 0.1385340848637204, 0.25054807504338605, 0.17846287859062995, 0.21388888329027161, 0.1448310211661362, 0.11991897567866311, 0.18113341512939624, 0.11661269341505344, 0.1163149456824026, 0.11375194490556756, 0.10730918376676499, 0.12905203076379915, 0.11958830914790593, 0.22126824054266178, 0.1487225639603792, 0.20016621077252975, 0.11836632996076539, 0.19530017349508502, 0.123143041386239, 0.14531658301430364, 0.17076501262284097, 0.2189701453091637, 0.11780205257837811], [0.007598784464907142, 0.020977318316938418, 0.03417342413036573, 0.04490060093362005, 0.06544208799999568, 0.047378305480965686, 0.058730881991645986, 0.026199393041972673, 0.01934380435775365, 0.009569460901642039, 0.04425963431957268, 0.029947418839700764, 0.020942474722922332, 0.0407735895245306, 0.03316139133887426, 0.011225966117044371, 0.005407502476666724, 0.06020537908038786, 0.04987432336014125, 0.08588817030672105, 0.06912663383709808, 0.018034657771368662, 0.036240601311287576, 0.01854799605245071, 0.010110601471106132, 0.06083186663266632, 0.02711648072656845, 0.01006390362407171, 0.020644730820711103, 0.051169027273933736, 0.037460768700487194, 0.027382284507996617, 0.032677216109849756, 0.02980578450425979, 1.838345277693964, 13.072324299043226, 25.477121991495935, 40.86597458008797, 51.60708719684232, 47.662892956887525, 38.27073835557507, 28.700078648905603, 39.29533596961729, 32.270292543595836, 10.472140004557948, 3.5848874815048712, 0.809133546727319, 0.4351438858336018, 0.6077605329694287, 2.429482009141676, 1.0085139964376728, 1.8893750684876598, 1.5226317413391606, 1.3017470197331522, 4.689807882232051, 3.2325618065172628, 7.550747913698997, 15.109437646404391, 24.26337395944903, 34.93988513946533, 39.52097423614995, 47.41479127637802, 52.440598703199825, 56.48786498654274, 57.659449500422326, 53.564361679938536, 53.73123891891972, 51.89308681795674, 51.61589684024934, 52.396083724114206, 55.02533474276143, 53.78232386804397, 54.07849811738538, 52.59132362181141, 53.42891439314812, 55.50896690737817, 57.30687156800301, 53.295675400764715, 54.008550490102465, 48.81535983854725, 45.5237264017905, 42.77872231698806, 44.93128768859371, 42.51355048148863, 47.58446908766224, 49.60745111588509, 52.72577462657806, 51.21161030184839, 59.58860843412338, 34.599949006111395, 42.23625067741641, 57.298536531386844, 51.73954171519126, 55.08395064261652, 51.95861393405546, 53.580408096313484, 51.51247570591589, 52.713623123784224, 41.523167702459524, 36.62079726496051, 40.32261648485738, 49.846499966036895, 52.41539747484269, 54.83031057542371, 53.09783889401344, 51.912353500243164, 49.69444536393689, 44.96869925529727, 47.30283114217943, 51.77022641704929, 55.88373761023245, 54.93501040243334, 53.0022507329141, 49.58641152228079, 54.68292359382876, 59.204173011164514, 55.53257957581551, 57.76225874500891, 53.62589582320183, 46.275899717884684, 38.473360153936575, 26.664046895119455, 16.78090568511717, 8.523478065767597, 3.935031338084129, 2.3325075353345563, 3.8054271571097837, 3.824921827162466, 3.828170285109551, 4.4139269955696605, 3.7135971169317927, 6.374226606661274, 0.28767340065490815, 0.051025493040440545, 0.5428475129508203, 2.148592500917373, 8.604581894413117, 19.557612326837358, 21.140941766000566, 29.18388339780992, 37.71103574383644, 45.062977344759055, 39.97299994191816, 23.259411934883367, 4.603330406450457, 1.0757456888114254, 0.01608503295198804, 0.14343897812068462, 0.06358535900231331, 0.027925528946422765, 0.07249987218528986, 0.039053699151883205, 0.07015961913331863, 0.044954916567451535, 0.0438684928080728, 0.053539762964412096, 0.0790286573371099, 0.01813705116810818, 0.05981352127667877, 0.036534959104873484, 0.04492765149822639, 0.0247759384764058, 0.02623283852552695, 0.024869891499439557, 0.024149180878134027, 0.019473909069934202, 0.012525889004821019, 0.07960342246318057, 0.00400991223643594, 0.032935134931317264, 0.04949256259527418, 0.0700280511932027, 0.021564861789586085, 0.050240942397184914, 0.02359738689847291, 0.019400510185908888, 0.019890737509535208, 0.09021456758942335, 0.012028016123710381, 0.04297293985502855, 0.023501024528917287, 0.026649205397153576, 0.017153124227338744, 0.058319849007192164, 0.030431785590706334, 0.022639606538559162, 0.016167559773631154, 0.06408168821625652, 0.03595998330462364, 0.06293902211191674, 0.053869854929226066, 0.026259032986877907, 0.04692356718043166, 0.03864438986525901, 0.14515932048520735, 0.02945135967175086, 0.057316721987820445, 0.028963216107278585, 0.05527170773054804, 0.12116631237609733, 0.03926233936762137, 0.05788101852240582, 0.08793105100912434, 0.09671758154347058, 0.044563315403197086, 0.10194456114644006, 0.08507469218344459, 0.06482776209351516, 0.008976242632695265, 0.027514321676966165, 2.143946698596401, 15.321989905449653, 32.41310996394004, 50.9055006888605, 59.214116219551336, 53.62371106301585, 39.47804389461395, 29.96284454099594, 41.9472739773412, 36.5698064527204, 12.651503989773413, 4.015908895000335, 0.5013500009813617, 0.12406203279932662, 0.31483743820459614, 2.4787141286557723, 4.321102634552987, 2.785825171778279, 6.811124220971139, 4.4276052809530695, 3.4879198718455533, 4.155712464163381, 8.087645374959516, 15.755951135389267, 27.064575802895334, 37.00507579311248, 44.4586185486086, 49.0107056402391, 55.243520505966686, 56.093764843479285, 59.38416665600192, 57.087701289884514, 56.81581435665008, 52.91735495290449, 53.74340611119425, 54.3951432166561, 56.05738093776088, 56.75304074441233, 56.53013636988979, 52.423861949674546, 53.990688016337735, 56.44240863861577, 59.26778993298931, 54.872056361167665, 54.91213513958839, 51.85119590451641, 47.80712635286393, 44.461152399739916, 46.405581120521795, 45.19576918694281, 48.506324137410815, 51.66077267739081, 55.438172048138036, 54.82847490618306, 59.89815404338222, 36.566837218499955, 42.94215963732812, 56.3179204540868, 53.13168894860053, 56.95000256261518, 53.35127107558712, 54.91470429205126, 53.73385906219483, 54.444969084955034, 44.80216326252107, 39.2198460332809, 41.57763765704247, 51.46533666118499, 53.73747940986387, 55.231384692653535, 54.68764612751623, 52.29618880056566, 50.67142148171702, 46.74875713163807, 50.06279906918926, 53.37234989289315, 57.018510680044855, 55.6806412050801, 51.89405172101913, 52.665338746963016, 55.472845800461315, 59.21745415656798, 56.80764405958114, 58.75370056398454, 55.431684447873025, 49.12899255752564, 40.37843965714978, 29.19291465513168, 19.171827608539214, 10.783907636519402, 3.5690479701565163, 2.5496523995553297, 5.630167203564798, 6.86188018129718, 8.035461671890753, 5.637316703796388, 4.097477034215005, 3.3657963862342224, 0.5246656724522191, 0.4005660170749311, 0.45182342791268904, 2.616143192975752, 9.845519796494516, 22.56404042243958, 24.579881775763727, 32.211331475165586, 41.76572315154537, 51.89413016842258, 47.55516506010487, 29.25651980984596, 5.473316523336596, 1.4794970688319977, 0.027065560777461337, 0.04030147251943427, 0.07237222661534626, 0.03045853738102221, 0.07152219843720237, 0.08980264211253774, 0.10056318970577371, 0.027997204132618445, 0.011722371939780011, 0.03342217149873895, 0.060456498871527375, 0.027716034542649027, 0.03014726819650781, 0.027873218547733083, 0.039401874622149814, 0.009399398958550827, 0.017411129233697732, 0.05279295364274614, 0.06037925039568256, 0.06511790257307791, 0.032884994476673104, 0.07744950497703207, 0.08281103260214291, 0.04185729367177814, 0.017462487768141494, 0.06921117930042167, 0.029552921863092534, 0.034378145806371205, 0.03371656759672108, 0.050542961070013624, 0.16299455216334713, 0.19854647107422355, 0.10015431325882675, 0.13194433443488615, 0.13979092871229495, 0.1463226709635027, 0.15393816715767308, 0.13776638815479894, 0.12602312595493373, 0.08350806536092874, 0.21981768370155366, 0.14038959578160318, 0.14513099055376746, 0.17656183140652795, 0.10978519525979796, 0.10379686981679932, 0.1028503145601961, 0.21819756095928533, 0.2858391716595619, 0.14315099034818912, 0.22846238837847788, 0.13375389539907057, 0.14049277250324527, 0.21832771929762057, 0.09314620987542215, 0.1258364916148205, 0.13188929867840585, 0.15696228391701178, 0.10389401742647733, 0.10623749570860978, 0.17474825614162032, 0.15501894867948948, 0.1263002429397837, 0.10720491153939117, 2.5646446789464643, 18.148536143764375, 40.22734211337182, 59.82017732435658, 67.75812887376355, 62.23400000602969, 50.07871604734852, 42.1851461164413, 51.32622588065363, 40.683694193440104, 14.21667383563134, 5.227268203612297, 1.131594479084015, 0.7969080704835154, 1.293041073987561, 5.4355313508741325, 5.419780583150926, 5.719611462085478, 7.964673676798421, 3.790362068722325, 8.849675117000457, 4.577008851112859, 9.296513488215785, 17.494382858276367, 28.01538382807086, 38.55327060145717, 48.360168780049975, 56.610584182123986, 57.878843353640654, 57.60768990362845, 58.88701408140121, 59.09664123289047, 57.53210975277809, 55.66461047818584, 55.96154566734068, 56.68920024748772, 57.82342026310583, 57.428217934023955, 55.379516924581225, 53.51672841656593, 53.81510703794418, 58.11871197915847, 59.91256090902514, 55.971555556020434, 56.926248688851636, 52.015292183045425, 48.58376349172285, 47.750197072182935, 48.535702690001465, 48.93143061668643, 50.2394586993802, 54.46228242689564, 55.87700290064658, 56.31283313997331, 59.66676558217695, 41.591644440927816, 44.79726814454602, 57.28064267866073, 55.37484930407617, 58.79631319353658, 55.10224849947038, 57.444032930558734, 56.17858609845562, 57.19489574432374, 46.42115685247606, 41.140666007995605, 44.199902934412805, 55.17648327735163, 56.25839456435173, 57.46919885758431, 55.66227274556314, 54.928428665284194, 53.601196658226755, 47.9875514584203, 51.46879619167697, 55.97698803870909, 60.037904170251664, 55.61433745968727, 53.06069012611143, 53.721680102809785, 55.80306622289843, 59.98433243843817, 58.867413997650154, 62.029071854006865, 57.46729258568057, 50.61245649091659, 42.21068074626308, 29.78271165201741, 19.717772506898452, 14.629994573131686, 6.092256240306362, 5.783361744496131, 9.26013154368247, 11.598090683260272, 14.548897608633965, 12.326757234911765, 10.282472814283064, 14.021954632574513, 2.430049527075983, 0.7163846913364627, 1.0158757949548385, 3.0516880798724393, 11.905998702972166, 27.54944939767161, 31.798143117658555, 40.46461412983556, 50.05693512578165, 59.10972233741515, 54.17146613520961, 34.27917365104922, 7.8935939554245245, 1.5983322599241812, 0.10411070539586006, 0.36560844449747, 0.17452229084747453, 0.13972107681535906, 0.22767773048291284, 0.19369878926344458, 0.1548686115852287, 0.18250134172699145, 0.21100785643343004, 0.14396079124942904, 0.22153738255222, 0.12502762534084821, 0.09468425395748309, 0.14687915723170006, 0.14797999493537412, 0.16412663093257338, 0.10767976347837718, 0.10187575112908118, 0.14872939746466377, 0.14512066368854817, 0.11247848460991537, 0.19240901895588447, 0.1434922365531806, 0.08874056079695303, 0.1921329055462153, 0.16321376056200074, 0.10290214040827367, 0.15945415343007735, 0.1161362786567019, 0.14885537296293244], [0.03920602041386789, 0.002579059176740327, 0.06211057463059984, 0.04357801908026299, 0.0193500958548318, 0.05782937270499045, 0.062410409952844345, 0.05096816285062702, 0.057188674221716584, 0.054518068735037124, 0.032640830763886054, 0.11433083158467086, 0.05466854755556392, 0.020374552677235296, 0.08647624238003647, 0.061028249441616, 0.042664359639128374, 0.03190142376678846, 0.04370522031921052, 0.049625390750025554, 0.02930422290979374, 0.07103399358569615, 0.09062732044126719, 0.03929362256800936, 0.05798429100503845, 0.051041079099260034, 0.07340657554807202, 0.03790971537631366, 0.06235910121411566, 0.0689860720247511, 0.017398544324321613, 0.03681207608972346, 0.039653377457251476, 0.03030306366722911, 0.5089927699056365, 3.005532079165982, 15.025502847087, 33.74015761959937, 45.20049564300045, 50.230680434934555, 34.57159026976555, 31.979611573680756, 18.335825397122292, 20.49415861406634, 13.87717406595907, 5.704162226569268, 1.2395059918203664, 0.32598040156787444, 0.1837160200962136, 0.5898679672710357, 0.7768709488934087, 0.40269335131010703, 5.326677243555746, 3.1584826977022233, 3.1625521567560013, 1.6080457645077861, 3.1428721547126774, 7.304330891178501, 16.985147422359837, 29.196403603399958, 33.12574578869727, 38.79805787917107, 49.08710556645548, 53.16386807349421, 59.28041212020382, 54.38904000866798, 54.61259941900931, 50.86853234998642, 52.33315713943974, 54.41135437257829, 57.715002029172844, 55.124076489479314, 54.08480921099263, 53.64053803105509, 55.98195768171742, 56.55522384951192, 57.26963258558705, 55.02042393530569, 53.89843386988486, 49.08374017284763, 48.00096988677979, 43.82512438681818, 45.429777791423184, 42.69850984696419, 46.89887800524312, 48.61546016508534, 51.70705272305397, 53.08969605353571, 55.893892626608576, 39.99310601142145, 45.60225225264027, 57.294967174530036, 50.74589944654896, 51.35243908051522, 48.333053435048754, 49.477389243341264, 46.28228925889539, 41.648569799238636, 37.711545651958836, 38.611655081472094, 43.110319491355654, 51.588722659695534, 51.4381036450786, 54.21876599711757, 53.612732348903535, 53.721107436764626, 50.65042111181444, 48.17946910858155, 47.561358482606956, 52.82561463694419, 51.76145207497382, 55.348655716065444, 53.09616796432003, 53.090045144481046, 55.565911877539854, 56.23985352054719, 57.95791833631454, 55.250353274806855, 49.82355017815867, 41.28480918945805, 32.13958347997358, 19.653728046724876, 12.383348211165398, 5.152750034486094, 1.8466057892768615, 2.227487054563338, 5.303909355594266, 5.2746641635894775, 4.528953442650457, 5.6800636745268305, 1.1354580137037462, 1.7718711543467738, 0.5404743564225013, 0.38457098987794697, 0.49924561874039713, 3.7120597929723806, 14.744112991517591, 27.664064976476855, 32.548337598000806, 32.89172149473621, 34.65405418026832, 42.74098127119003, 40.08451684828728, 15.671933966298258, 1.995325396137853, 0.1425120576975807, 0.0038163455188154217, 0.08321645399255138, 0.04057541790027772, 0.04449414915495342, 0.10878050925150033, 0.049105385588782455, 0.05121222314154429, 0.11731910309003246, 0.05431713919425684, 0.0135298864915967, 0.03450546195850738, 0.060215962585061795, 0.09814416749342796, 0.0770120840940264, 0.06570357679119034, 0.022613500177319494, 0.014074979117140176, 0.04882870527404932, 0.06225364538089884, 0.04004742244198438, 0.048163434520604155, 0.031717834626174266, 0.032604307522095984, 0.030092019850628513, 0.03775012393992755, 0.0227396767736683, 0.08802880382826252, 0.03730892241301556, 0.015218761794629599, 0.005790601980181472, 0.07616140474114688, 0.04162648287151129, 0.017864256834370956, 0.023355917899959514, 0.035647476888111526, 0.0701470323087227, 0.0057254600875650445, 0.04406665294100681, 0.04666908043286493, 0.03767916121550145, 0.03761790099463636, 0.052401406104646386, 0.04168117005798606, 0.062424038657017296, 0.06764154941324266, 0.07448032438274353, 0.0559842614306798, 0.006905740151377095, 0.03259519873667629, 0.022520815029800422, 0.06984833462704575, 0.04885851375518307, 0.10680701313239914, 0.12258312304414089, 0.012256271063139843, 0.05552339442675153, 0.013923683455364119, 0.03859100502825553, 0.07543746697446031, 0.03966671121757358, 0.01136455525298633, 0.047330861655814994, 0.04873494377299663, 0.034012465227034785, 0.5655829800713448, 4.897927862982597, 19.624928043734645, 42.32193485383065, 56.302583986713046, 55.943255655227176, 39.44564119462044, 36.34983993345691, 23.794013338704264, 25.238267298667665, 17.024298560234808, 6.26515039513188, 1.3909024937498955, 0.4447300666041913, 0.22910234758690481, 1.495969920389114, 1.3734730741670056, 3.29200777796007, 6.906291707869499, 5.57918276517622, 4.734370420056005, 3.1164986279702958, 5.721521656359396, 10.685788566066373, 20.36390454538407, 30.803667345354636, 37.1963462521953, 43.327909054294715, 53.70559838510329, 54.919697469280614, 57.737002603469364, 57.126442540076475, 55.36860881313201, 52.31387476767264, 54.545840678676484, 55.54609214105914, 58.48325706297352, 54.40413328909106, 56.23022410177416, 55.131262271635, 56.966888366207, 56.12505751271402, 58.08181424294749, 57.33186883311118, 55.62302550961895, 50.95033730230024, 50.111232496077015, 45.375880502885394, 47.68844719856016, 45.15040305352981, 48.35764669602918, 50.28477776435114, 54.36478407152238, 53.597450794712195, 56.85287291003812, 42.28400553426435, 46.60437468559512, 58.40481750426754, 52.530079733940866, 53.52794639525875, 50.99736259829614, 52.31189397073562, 49.4894976000632, 45.06108283996583, 41.037225261811294, 41.13632394421486, 45.50489118022304, 52.57868574511621, 54.15672586810205, 54.930856612420854, 54.796911593406435, 54.36421140547722, 52.08110563216671, 49.34402473511235, 50.06428564748457, 54.471045001860595, 53.993057127921816, 54.96591475702102, 53.58817046688449, 53.618506077797186, 56.246800038122366, 57.17232250398206, 58.37779629615046, 57.57737782693679, 52.53909726296702, 43.793937621578095, 33.9478628097042, 24.28320546304026, 14.676570757742851, 7.055992887866113, 5.278913561374911, 7.165912899278826, 8.993178952124811, 7.502131606301955, 6.981142788164078, 6.0842139105643005, 2.7633225340997023, 2.36159828401381, 0.7473952563539629, 0.08532097412934227, 0.5315617507984561, 4.260579972497879, 13.526099381908296, 30.04847772659794, 34.036257343907515, 38.951140142256214, 38.90974736982776, 49.907453598514685, 47.20162222462316, 19.435077482654204, 3.1917113017651344, 0.2989836776208493, 0.048418009368282174, 0.03677136234698757, 0.019995779655272924, 0.0370417415885435, 0.045258482737887296, 0.026872995001594388, 0.09771736458905282, 0.0559417205682445, 0.08538023103028537, 0.07310503568019598, 0.02734673611309019, 0.08393258532328952, 0.03423789809007318, 0.046068402382755475, 0.03773267628745206, 0.03822432853461754, 0.014994949207551058, 0.03296467911211714, 0.01555329228135487, 0.010334388202717228, 0.06501483310374521, 0.030054797553607536, 0.04526198759014088, 0.040578378830105066, 0.12057640935264288, 0.016247430185396827, 0.09964239798606404, 0.04695063306679649, 0.06930157767548677, 0.03384325172631972, 0.2858658928063608, 0.15157241103870256, 0.12155518626734135, 0.18232921709216413, 0.1840227617010955, 0.19720094488753429, 0.12021743587308353, 0.13696273127871175, 0.16290130394120372, 0.1607617889080317, 0.1434051476779484, 0.21916791856769594, 0.20485233996183644, 0.19579020929673027, 0.17962180108072298, 0.2145475503658095, 0.13393395670479344, 0.11066957482046659, 0.129809201424641, 0.15270911697899142, 0.13410228154351636, 0.1503630646414334, 0.2359769907930205, 0.20696346377653463, 0.23241452872753146, 0.22090848565341967, 0.16446807632042518, 0.17292254604399207, 0.1285043085414556, 0.2314636910394315, 0.15457743688696815, 0.1362591254855356, 0.19086043350398543, 0.12188318681212203, 0.8156057026597762, 4.887460527881499, 23.611809438274754, 52.153069357718195, 63.35986537318077, 64.85661437434536, 47.84032529400241, 46.228493951982074, 27.872766448605446, 30.49308034681505, 20.921696962848788, 8.190940993447459, 1.9438642671992703, 0.698590797762717, 0.43147864541219133, 2.197431157673559, 2.9948732833708487, 6.189565341318808, 9.025487515234179, 8.689057980814288, 7.729454040527345, 3.773467194649481, 6.218139317727858, 8.824544491306428, 19.3175515051811, 32.32289544997677, 41.074252436237956, 49.585905536528564, 55.584488222675944, 55.23580912620791, 61.19878845830118, 59.01500494249406, 57.94998338145595, 55.41161760207146, 56.94221665782314, 58.93818532266925, 60.13372375119118, 54.94789146607923, 56.37326901958835, 54.897767497647195, 56.355873307874134, 56.84829550404703, 57.422475584091686, 59.88660658559492, 57.81913311250749, 53.56761724718156, 52.76020519195065, 48.12690542590234, 49.05051377511794, 47.319454146969704, 50.09916728542697, 52.441100766581876, 55.44738569567281, 56.45992594380533, 55.777421766711825, 47.042362228516616, 49.33921590928109, 60.50835324871925, 55.771130284955426, 55.622119442109145, 52.8023628265627, 54.15844386623752, 51.95097315695978, 45.45258245160503, 43.43032213949388, 43.2057233010569, 47.353696438574026, 55.005856252485714, 57.64356390122445, 55.41888575400076, 55.54106366249823, 55.983514862675825, 55.5214871129682, 51.222334061899495, 51.3341216118105, 56.305921923729684, 56.80369031044745, 54.35745316167032, 52.956366846638346, 55.14588486763739, 55.49696053228071, 58.267605150899584, 60.57739480849236, 60.08483140699325, 52.963799738114886, 44.24391192774619, 35.53001357663062, 23.50466989701794, 16.04217040923334, 7.169629345017095, 4.08311699186602, 6.344724499410199, 11.417107620546895, 14.993672813138655, 12.783758467243565, 14.904333968316356, 6.1638130199524666, 3.7547535665573615, 2.0049820263539595, 1.173826516155274, 0.9327523133927776, 5.748743885947812, 17.60801588335345, 37.28642348320254, 43.10412606885357, 46.49553283568352, 45.89083279332807, 57.07335718216435, 53.47806169140724, 24.86893888442747, 3.688120096921921, 0.5331680226710536, 0.14275084730357895, 0.15488002629530045, 0.17714261798368347, 0.16804700927628627, 0.19809959666623225, 0.14217059698797044, 0.1854812092478237, 0.19247879424402792, 0.1769540377802426, 0.10244628744980983, 0.14697744631238524, 0.300262738019228, 0.22344176987967185, 0.14695667000787874, 0.1718689606434876, 0.1255061238583538, 0.11851378656443089, 0.16906012991263022, 0.17219822523334335, 0.11838488461029147, 0.23529842075320984, 0.09842429520382036, 0.14833933613713712, 0.17673764858515034, 0.17366376675425038, 0.11677205502506226, 0.22210819466460138, 0.17473419076733052, 0.22184351128676247, 0.12325522730187063], [0.05713308688193079, 0.03319149859429848, 0.07156828628672708, 0.09894475235693878, 0.029569329551210808, 0.056503151933993065, 0.007943160617874276, 0.027446390745500406, 0.028601624522238012, 0.03903183117208462, 0.04509922838018787, 0.1298180267575287, 0.007416483788420597, 0.03950279904529452, 0.0204005402948467, 0.04261896126873551, 0.005752919551600973, 0.05383846064608905, 0.026721045292252978, 0.06409978321302803, 0.04998802996030258, 0.026084315144426884, 0.03206933683325206, 0.0439615226951578, 0.03814237244847802, 0.10125619284207783, 0.026922737090517918, 0.04326695290904853, 0.02463424285393088, 0.046257403934554714, 0.07511145059740351, 0.11459648789417361, 0.06334825478974851, 0.10069455846302933, 0.10478160689554869, 0.5957830853519902, 10.108692203798602, 23.713414515218428, 44.15885533055952, 52.69581948557208, 44.384266099622174, 29.949314325086533, 45.141601254863126, 38.9052091875384, 16.07455349737598, 7.568089202527077, 1.5585916633567505, 0.7758031449010296, 0.21693875592562462, 1.0877563540012607, 1.0640983331588008, 2.59377121925354, 7.563221050846962, 5.5128486214145545, 1.9251340916079862, 2.2900883276616377, 2.676038766099561, 7.52758288575757, 12.504581809043886, 20.7406658511008, 23.46497747205919, 34.54695386271323, 43.01287604916481, 52.45791988988077, 60.04992623482982, 57.15871580185429, 54.83030665305353, 52.23965567927207, 54.52333411862774, 55.53839252841089, 54.72138635573849, 56.84603621882778, 56.285239265811065, 54.526872096523164, 55.02490328204248, 55.41481041139173, 55.87440236922234, 55.24932169145154, 53.271195888519294, 49.83525845312303, 43.53284897342805, 42.771705196749785, 43.44093607318017, 41.99808828292355, 46.00852743271859, 47.23656269811815, 52.98349003637991, 48.22807511975689, 58.243357058494325, 40.12129691339309, 42.942234162361395, 57.220167575343964, 47.60407309378348, 50.36332322705177, 45.017658279788115, 43.28886185922931, 38.629286135396654, 40.59802570650655, 39.310138994647616, 42.435593374313854, 47.56568093453684, 50.666949979720584, 50.357831908810525, 54.63562765429097, 53.8052148203696, 54.44963278308992, 52.113916258658136, 48.13266738768547, 48.82333009473739, 51.46612113521945, 53.62245982693088, 54.35896719655683, 55.33467638877131, 53.80979614873087, 55.96786852805845, 57.57172961388865, 56.37919964328889, 55.355182540032175, 46.08987346772225, 37.01866680575956, 27.42322360315631, 19.801985794498076, 9.755363137491289, 4.008754001509759, 3.2903674917836345, 4.775847033146889, 6.144699800399042, 4.771225010195087, 5.524581901488766, 2.0543418680467913, 3.654123688897779, 1.8573393552534043, 0.24278431019235044, 0.020939730212933595, 1.0456057061110775, 5.633468368361074, 17.358576674615186, 22.87916168089836, 23.604345167836836, 18.995477845591886, 39.9729097274042, 47.979914603694795, 31.348198229266753, 9.139112695570915, 0.7293956222072725, 0.014989985915411626, 0.06568576524695081, 0.02973651674936616, 0.08019609106404167, 0.027560070532584385, 0.0715187663633016, 0.0606008260060222, 0.015613724169651828, 0.03321459997565516, 0.04979516732536497, 0.027717748664379604, 0.13021887460302922, 0.01135197704687955, 0.05614846088593045, 0.030080766019020832, 0.035854749636904854, 0.006669410645225716, 0.01935528227007918, 0.12483826372772457, 0.036449138105155966, 0.019790108030241345, 0.09846276047849849, 0.00541747406861114, 0.013933407983952954, 0.059472811333234274, 0.04272239079939262, 0.036095665136892954, 0.03069407111334224, 0.07078444810524102, 0.0060023654406259385, 0.03988537952424057, 0.040315281254269426, 0.04632569301212507, 0.08051106045323034, 0.10033728569866189, 0.042320271247937795, 0.02593470774891396, 0.020591499201292475, 0.0910982346883224, 0.034181908554127144, 0.07626709423118061, 0.07083383779371939, 0.028794826151082115, 0.007206061939453527, 0.015326703583160716, 0.03263978505386941, 0.06625006561197581, 0.008843074526427495, 0.1797080166157215, 0.05562192482513286, 0.0434982693273454, 0.07205937928970783, 0.0920618430621201, 0.04211120968384128, 0.030331701949058525, 0.12540203549208181, 0.05152178394998755, 0.060603296639578, 0.016060201169532395, 0.054782874686943914, 0.033460586977701996, 0.09898052866300268, 0.07429637901124454, 0.11182567810699826, 0.09044666924784261, 0.13456849201071647, 0.8638035421890597, 12.498069693965297, 29.898813809117964, 51.918111539656124, 59.25497162726618, 48.093890836161954, 37.09272507698306, 32.49227516112789, 35.470903458133826, 18.108435792307702, 9.952644628863181, 2.184045579164259, 0.5003633716654393, 0.15864075191559332, 0.5381133347269028, 2.033356574754561, 2.174998877509948, 6.285196648490045, 6.67711252166379, 3.679740933641311, 2.7052410571805896, 3.636060929106128, 7.145545992159075, 13.627331833685599, 23.269009974695024, 28.805504114397113, 35.48063093616117, 47.10133506405739, 53.86479562328708, 61.98335662964852, 59.665718309340946, 57.37642303589852, 53.97962693245181, 55.75223622783538, 57.2309737051687, 57.311354837109974, 57.61116904597129, 56.054564675977154, 52.463744609586655, 54.98094527952133, 55.39241760007797, 57.50599853454098, 56.610242935919, 56.03610207957607, 52.19122617475448, 45.54850401416902, 45.86378020624961, 45.108068912259995, 44.25432582055369, 47.090089628773356, 49.3848369967553, 54.9047806955153, 52.3826535286442, 60.10778903961182, 41.28638205989715, 46.08961851366105, 58.40790048722298, 49.889540133937714, 54.00471048970377, 47.769149964855565, 45.71054497072774, 41.41689108264062, 42.07237405161704, 40.86420951351043, 45.00937815635435, 49.59312269764562, 52.72875955027919, 52.79809528781522, 55.45990590126284, 53.9547198818576, 56.73142064002253, 52.79826002736246, 49.39706694695258, 50.948866413485625, 53.59672515623031, 55.81028730638566, 56.67061997998146, 53.465859197801166, 55.69085897937898, 56.17650331989412, 58.709864154938735, 57.02413928124213, 55.92497348785401, 49.0250732821803, 40.09934340753863, 29.23556846957053, 21.736798824802523, 10.171981607714008, 5.277261753236094, 4.039873351012507, 6.1207473566455235, 9.932577783061612, 9.099149627070274, 8.4439363210432, 6.733529933037297, 3.950862269247732, 1.6352350216719413, 0.315956600731419, 0.13174734258603665, 1.3040037308969807, 6.141349605975613, 17.521578611866122, 27.99141618513292, 28.83105051132941, 22.720299805364302, 45.918050119953776, 51.381037081441576, 39.44028323696506, 10.925239459160837, 0.8119371833820498, 0.07625948697809251, 0.04282296665253178, 0.03848920343443751, 0.042130675977997245, 0.024714214772346522, 0.07233510965541487, 0.021527327311735962, 0.07167704012845794, 0.03860743378379172, 0.02524844235590389, 0.06434672016410098, 0.04940260089032593, 0.0031035840173342056, 0.013329710589811928, 0.02905552395649495, 0.032462822573800246, 0.02807984778267001, 0.08644064227419515, 0.026601152532103083, 0.06412926610679397, 0.023390757663535978, 0.03576566510262989, 0.012640611629091926, 0.030447214601501345, 0.04024888441387204, 0.0066541338944056585, 0.07020268859642168, 0.019506094338853034, 0.062172137456195015, 0.05447465070192853, 0.06717610503396682, 0.14224956533120525, 0.11432366100169959, 0.1820311322808266, 0.2042795819861274, 0.18789052512616883, 0.09592975970477828, 0.1691661105160752, 0.26840417495658325, 0.1873051879867431, 0.11163725878202146, 0.24932781955407513, 0.16223093104218284, 0.11778756585572997, 0.10577287870429217, 0.1563061602533825, 0.144883957841704, 0.07205044670451073, 0.2472575435474996, 0.1905580892437889, 0.16621457292668282, 0.1927356328815222, 0.1659778057928047, 0.09528446852439836, 0.07704952281088599, 0.24292496393524834, 0.25523251883925935, 0.14886140973577577, 0.08872914608688125, 0.13412455938035442, 0.2000852506006918, 0.3036291428631352, 0.24367589864038655, 0.13232868074649765, 0.22762191331674977, 0.2410975224789112, 1.3163162960160164, 14.244479517782889, 36.49254752743629, 61.00883591559626, 66.18183812787457, 57.50590047528667, 42.42272015540831, 57.34782895734234, 49.16012833195348, 23.888738578365697, 11.479262478889959, 2.740283757448197, 1.2790839325997139, 0.5698166270890545, 2.510024203408149, 7.3580595177988855, 5.810378049650501, 16.596297371772028, 15.909515850005613, 6.707513341980596, 5.8549160726608775, 4.409420682537941, 8.92665163163216, 14.869701400879892, 23.4803060946926, 30.405511471533007, 43.75303514542119, 50.422813815455285, 56.14814850591845, 62.981788112271225, 60.87570282720751, 59.30034560541953, 55.38656542378088, 58.479577879751886, 60.018578652412664, 58.46536321024741, 58.76203560060071, 57.00131500920942, 54.07512487903718, 55.696162023851954, 55.956026892508234, 57.89231669518256, 57.79739141464234, 56.59473388425766, 53.57477949511621, 47.325474985184215, 48.35972947459067, 46.667422863744925, 47.17371848321731, 50.81805144586871, 51.87139611090384, 56.918603989385794, 54.146292363443685, 61.05956000666465, 44.945239559296645, 47.587657974612334, 59.79282663714502, 53.38544668689851, 55.13866770652033, 50.40232335367511, 47.16546189400458, 42.136206703801314, 44.29482429258285, 42.83972694027809, 47.6597079923076, 51.53633156130391, 54.15896161910027, 54.549206072284335, 55.74016709481516, 54.57732946641984, 58.142858089939246, 55.136357430488836, 52.92287765010711, 53.4059646052699, 57.10199048442226, 57.47602378168414, 56.90421673559374, 53.44705927756525, 54.24071950297202, 57.3684488573382, 60.48673706669962, 58.56718009518039, 57.797226675095104, 49.95098014031687, 40.38323279350035, 31.65743789365215, 24.94019069979268, 12.745360424441676, 6.293243390898551, 5.90020130718908, 9.776528246941107, 14.478587162110115, 10.666505213706724, 12.004840470129444, 13.18500909113115, 7.080267946566305, 5.592083930969239, 0.9179743547593394, 0.6366940191195858, 1.9228018748183406, 7.996445855786724, 21.505394674116566, 32.41205484636369, 35.277256042726584, 28.53651777390511, 52.72218565787039, 59.48550501177388, 44.63502714710851, 13.926071313119705, 1.384290235657846, 0.1532931517689459, 0.23999754279371233, 0.2068308233133247, 0.15380529686808586, 0.13476111715839756, 0.3510214869053133, 0.13079880316170955, 0.2943178037962606, 0.18810078561786683, 0.12890627487532555, 0.18609037172169457, 0.18128395140651735, 0.08167963565116929, 0.14484703240375366, 0.06414762157345973, 0.11272392385909635, 0.15718642592189774, 0.35115064932934703, 0.20266243166500525, 0.10472071056644763, 0.15753150256651063, 0.29556232895101275, 0.1672988018441585, 0.10543810594226084, 0.1745071069848153, 0.24402008662300728, 0.16653269859811953, 0.14614182824809707, 0.16377347972123854, 0.13770169969047272, 0.12344353171365878], [0.05928913409250879, 0.02584415615626401, 0.04473131465455217, 0.12480215800385322, 0.05591455892088914, 0.021652630567851088, 0.0322034290330785, 0.026787980309417172, 0.01870200845352825, 0.0399263690586292, 0.08138243184094468, 0.007227576082392086, 0.042325978602973685, 0.03286681521022993, 0.011229824327353028, 0.07972920643946818, 0.03337090106440648, 0.057448125219032656, 0.019559387245305607, 0.01974459283144003, 0.024264982728768262, 0.04241559939879564, 0.02905292883365145, 0.03609259312431659, 0.021728140024107792, 0.05515653024157209, 0.06356313862206955, 0.05313334182926244, 0.018495204933588544, 0.03705376150807546, 0.03335500473997766, 0.0025499394565309972, 0.012091703885685534, 0.03551944444376615, 0.0441572466684926, 0.17534373628516353, 2.8481722262597855, 11.383730211565572, 30.010360133263376, 53.18512731982816, 40.47196072916831, 29.56793050612173, 26.34982974298539, 21.60629568561431, 23.1873324994118, 14.720477769451758, 5.708997528399191, 0.9273779308122974, 0.44835703327290477, 0.17812120337640086, 1.148607637132368, 2.361792931633611, 1.4961269377700745, 3.392949974344623, 4.1606134656936895, 1.7182928035336158, 2.3089210977477412, 3.8595095324900845, 8.677372259478416, 15.658976416434012, 22.77987668591161, 25.0069494401255, 39.70705932186496, 46.54586861210485, 57.80882120132447, 56.64932150994578, 57.55436528113581, 53.54922917581374, 53.37079271193474, 53.03931320867231, 55.40562814281833, 50.54498387921242, 55.71549930880147, 54.65358426493984, 57.27229979730422, 56.20548179072719, 56.287659368207386, 54.09748238901938, 53.3909458498801, 48.82598946171422, 43.94839663659373, 40.58502304938532, 45.0425535632718, 42.452977318917554, 46.17814248608005, 43.96748681222239, 52.01076576786657, 49.054502825583185, 57.158260806914306, 40.20655355145855, 45.13587459441155, 56.15685616770099, 49.06285355168004, 50.57122845803538, 45.480231238949685, 47.79831670945691, 46.28602335529943, 49.31651323072372, 47.1882979331478, 49.70566726499989, 48.93860855410176, 52.512840917033536, 52.47829268055578, 53.75550662317584, 53.03234315687611, 53.515602696326475, 52.86383028953306, 51.87918201569588, 47.23750798932968, 50.60030498812276, 51.6061262161501, 57.64135952918761, 54.807407855987556, 54.51800361756356, 55.943545910619925, 55.795092044338105, 55.26806669850504, 51.412416042820105, 42.38003692319317, 32.188938663851836, 22.26305538608182, 13.175916056479178, 4.813883727596653, 2.409931200165903, 4.700645881314432, 9.968606714279423, 10.915894412225294, 5.71100676251996, 7.096860552987746, 4.904328680807545, 2.0045711580784094, 1.210548236004768, 0.04008138695010736, 0.23950637318193915, 1.3950857015386706, 6.733536797185098, 19.523395530639156, 25.055955533058416, 26.28879374073398, 35.15363862437587, 49.64300347912697, 45.68695191414126, 20.79470238377971, 6.575145606071719, 0.18539995796257452, 0.07432334530617922, 0.07295007141487253, 0.060399590030072205, 0.025940099092681083, 0.02923084700840616, 0.019932636773333918, 0.04250808919389402, 0.0815503659748262, 0.08039043224867314, 0.03218500461849955, 0.08084862177530605, 0.023021962936787356, 0.058895724960753036, 0.07115687408875074, 0.04566173609947005, 0.07287013780085311, 0.060326103045935595, 0.06667592622820409, 0.02551669187303032, 0.07029721618539865, 0.03387751500873316, 0.05194423547495277, 0.02562027079083266, 0.051889690014744, 0.060928734620251966, 0.032801046561930454, 0.032757253145738956, 0.06032935508917417, 0.032752258252472646, 0.0582574473153199, 0.03526397327321672, 0.023639630901837544, 0.03811436427396633, 0.055434271588080355, 0.04787613622724049, 0.06897424362720021, 0.04529039796081282, 0.060602679938798955, 0.04368845448498765, 0.021149825995727893, 0.01655362595263268, 0.04899480462735219, 0.03981913973186766, 0.02065600380451689, 0.0087283001912217, 0.007288022334837625, 0.04461234503035103, 0.03136705828740472, 0.017256448420906262, 0.0717194507559461, 0.03765812827154033, 0.028250539833078944, 0.036944073039076986, 0.038787774711606965, 0.017507459044516567, 0.058998507147114125, 0.011386275760859493, 0.00979056728312806, 0.025428377257119265, 0.025883136625071208, 0.019427428600348292, 0.015224439463758422, 0.0645160868824009, 0.03717776432993912, 0.024570113633789366, 0.058615210375958876, 0.2974283046299412, 4.36969393684018, 15.77558259810171, 40.26672663227205, 58.26925254637196, 47.489532040011504, 32.36099539264556, 37.648544542251095, 29.488286779772853, 24.561395645141605, 14.17865430155108, 4.929792707966221, 0.890477620545895, 0.20681269767303623, 0.2158631071929009, 0.6819409492515749, 1.8509566783905032, 5.796440397539447, 6.238760198316267, 5.887413890131059, 3.5944708124283826, 4.244108469255509, 6.014118213807383, 11.166475030683703, 18.828692782309748, 25.88495239134758, 30.639233742990804, 42.79323116425545, 50.36002843610702, 57.54817185863372, 58.55446377108174, 57.682658164731926, 56.036662978510705, 54.998478274191584, 55.344929464401744, 56.0011576837109, 53.922191666018584, 58.725428119782485, 56.563715780934984, 57.16281860105453, 56.91510523519209, 58.40820250972625, 56.56189187880486, 56.4701319509937, 50.45979392143988, 45.99545417293426, 43.851129701060636, 46.44108249295143, 45.005451863811864, 47.98214250995267, 46.547363035140506, 55.439791987019206, 50.354725391634055, 58.90735157074467, 42.482285268845104, 46.891021497787975, 57.391382955735736, 51.16091758974137, 53.20996376775926, 47.17582871837001, 48.02380200355284, 47.64463040136522, 49.78657007217408, 48.30619304410873, 51.50318361097767, 50.75494443216632, 54.08181252018098, 53.432648489552165, 55.24426575629942, 53.64276201494279, 56.09356088023032, 53.46880882017074, 53.0688565008102, 50.51253411077684, 53.27553402992987, 54.67207039556196, 58.478173671230195, 54.05949031153033, 53.74991332331012, 56.027798421921275, 57.30032513218542, 57.33053130488242, 54.9055455576989, 44.086926906339585, 34.89717052828881, 24.948959158312892, 14.708060526078748, 5.622156743080386, 4.801425789633106, 6.476508782755944, 8.527398474754827, 7.411370902292191, 9.617912500135361, 7.120362904763992, 5.2210331059271295, 3.678533824220781, 0.9032678568074781, 0.12145921077218749, 0.17455751557023297, 1.563014993744512, 6.87603013169381, 22.00206675837117, 28.392080414679747, 28.14950143137286, 31.465502592825125, 53.28695204950149, 53.37347169076243, 27.746362186247303, 8.133561620789191, 0.3654906508182326, 0.1390117253627508, 0.06420645329560484, 0.060505065015487136, 0.0692923309942407, 0.046510373828031366, 0.04468449519105977, 0.04155443996311196, 0.025294273565973968, 0.08813141364484064, 0.041135975925792614, 0.09015317330317152, 0.07831052651688938, 0.05165903626250164, 0.0190655286649182, 0.02726545226910422, 0.07546288577178795, 0.028473071138104124, 0.07135660853236914, 0.019628817793883143, 0.06330978568463076, 0.01974753269384946, 0.008879280799338895, 0.04691185752650903, 0.04158071677891478, 0.037554112683621146, 0.01346326748570127, 0.017505390607121012, 0.05363918202478559, 0.017977011570286368, 0.03701962846060915, 0.0652007473212096, 0.2005141832294964, 0.11108119386218249, 0.1418407961365677, 0.2898535949568595, 0.21076160513104933, 0.0886401879571138, 0.14509585776155995, 0.17003713716422358, 0.13220612200037127, 0.1526203580320843, 0.17644210718572143, 0.12517246192381268, 0.1126384897337806, 0.17541351157330698, 0.2066170234954165, 0.12211420828656805, 0.10032554157078268, 0.09798177217523898, 0.2183185415642877, 0.1676191491705756, 0.1411661944322048, 0.11284478955091008, 0.07913790913599153, 0.20686057816830375, 0.13648103051368268, 0.12314616702497007, 0.12818268950908415, 0.14524418770545913, 0.20377086896088817, 0.16522346965728268, 0.18740009095880295, 0.21646385802136314, 0.12632987522069486, 0.1783709786832333, 0.24142361546476043, 0.3034719416210729, 4.831031839693747, 17.59928664853496, 45.92112918053904, 68.4865757726854, 54.34476821653305, 44.32359095542662, 40.25322191176876, 33.22644479813115, 33.09660257831697, 18.750049260354814, 7.353562030100054, 1.4137055604688584, 0.8457311603330797, 0.6630547981589072, 3.0172222131682984, 6.624527756244906, 9.39830291655756, 8.487112791307512, 10.500395778686771, 5.167783498764038, 4.135951563235253, 5.941139084677543, 10.384640751346465, 21.476333833509877, 27.40946000622165, 35.21799295179306, 48.04834427372102, 50.73752518623106, 59.20532226562501, 61.18676639372303, 60.0103142184596, 57.048999263394265, 57.16414043980261, 56.278751665546054, 58.38918293676069, 54.70395926506289, 59.40839121418615, 56.760665832027314, 58.93415704850228, 57.880694712361986, 60.88020178579516, 59.22737383073377, 57.93869480010002, 53.79422433914677, 47.427060450277025, 45.073783474583784, 48.88551535144929, 46.29441722746819, 51.318659628591234, 48.98908945821947, 57.14476393115137, 53.82637600744925, 59.67738736060358, 44.73867185654179, 49.48937992895804, 57.22293676868562, 54.070680833631954, 54.38311330733761, 49.324118706487845, 51.534986188334805, 50.39661238270421, 53.98882489050589, 51.60659690057078, 53.850577031412435, 52.55119777494862, 57.67932022771528, 55.024864058340754, 55.1229586139802, 53.847027286406494, 56.25088714784192, 56.38352993995913, 55.07723162251135, 52.62855868185721, 54.73088633629584, 56.41434015766267, 59.294913122730875, 55.451719914713216, 54.25342798233033, 57.49091702122843, 56.737680742817545, 57.76835803062686, 56.85390449339344, 45.98948040316182, 36.05275569423553, 26.072710367941088, 16.35035005307967, 6.222577969874106, 4.247680277593674, 8.269757589986249, 16.733203780266546, 19.31290545771199, 16.422549120841488, 13.709731025080528, 11.505128548991296, 6.7385971450036575, 2.542973828892554, 0.18939052528191, 0.5822933801720219, 2.468605935573578, 9.634413911450295, 26.15696287924244, 35.93826170890562, 36.780010192624985, 47.1981313151698, 59.74221237244145, 61.44113209939773, 34.06927977838824, 9.84717405611469, 0.484242951197009, 0.254366701588996, 0.21189869411530035, 0.4162733935781064, 0.25405456672512716, 0.1306906009032842, 0.20425535828596164, 0.12292636107773551, 0.1516476408728669, 0.2882164037756382, 0.10804749334291106, 0.20966085935792617, 0.10853628808211897, 0.17056320974182698, 0.14115615868039671, 0.1681373616860759, 0.13099683689013605, 0.20539062398095287, 0.12535669840872288, 0.1008758148659141, 0.16204691672277066, 0.11675043602383907, 0.1406701065359577, 0.1178956532009667, 0.1440463019835372, 0.11993484135957495, 0.07250141202201767, 0.05922514276819364, 0.0815269007017055, 0.16560203966594514, 0.14817792141149122, 0.1932293305834455], [0.025900065252977996, 0.062293937775276365, 0.0678070014222495, 0.0558778096831614, 0.09042548691673626, 0.03824927235743211, 0.05590643838889176, 0.054689025085779934, 0.014639793718684346, 0.03716143899627271, 0.026873640430670594, 0.013821324532581194, 0.03865732142942087, 0.04169862537134079, 0.082887327298522, 0.03694451353963345, 0.04075329202497679, 0.020872092310098872, 0.027864981187327255, 0.058304419996397155, 0.08996470035204003, 0.026859923626386353, 0.037526778666482824, 0.03637894146865414, 0.0795507922227825, 0.018839820010227062, 0.015168802328257552, 0.032384781196953795, 0.04739219082459327, 0.04453474415406104, 0.004348092892717931, 0.017606006679876197, 0.010233820968067214, 0.024975345417436574, 0.0570370692519411, 0.05988010580861761, 0.819916939062457, 7.0679919085195, 18.62431376211105, 48.717441789565555, 42.9049284996525, 37.717856745566095, 18.449727104556178, 25.240181415311753, 28.176012731367543, 17.978721049524125, 6.474043082806372, 1.3710464753450886, 0.2571034281244201, 0.3467623751250006, 0.5619656354669602, 0.7644584859090467, 3.8698275723764977, 5.927082290572505, 1.6928208090605277, 1.51014965628424, 2.646786709946971, 2.776998122853618, 4.44894346498674, 9.454709541413093, 16.525355423650435, 20.459814340837543, 35.044596733585486, 41.48734469567576, 51.330477729920425, 51.14780510625532, 56.38833092105005, 55.93743485789145, 55.015556273921845, 52.793561027896025, 55.70968243383593, 53.573222314157796, 55.02444436473232, 53.6115752497027, 54.854468453315, 54.394884340224735, 56.3063729962995, 51.966764619273526, 51.00528970841439, 47.05167001293552, 46.24501105277769, 42.409686119325706, 45.352295291039255, 43.57748946835918, 44.96035637394075, 46.77785719594648, 50.80362496837493, 50.679897723659394, 57.79093911570888, 43.840966839944166, 43.156050405194684, 56.53773400091357, 49.2578031939845, 52.09167249741093, 47.04595511959445, 50.329057401226414, 49.97763656800794, 51.72948083569927, 51.186675794662975, 52.44682742703346, 52.29234095542662, 54.2260576832679, 52.308355992840184, 53.27942502114081, 47.061550463399584, 51.85647541476835, 54.85265239592522, 52.24762985783239, 50.39589851133285, 51.37030547665012, 52.947062984589614, 56.403404589622255, 54.57447005856422, 56.30774974822999, 52.58323961688627, 58.91612199044997, 52.787497043609626, 46.92971960190804, 37.25372660544611, 29.533682330962154, 17.98223549319852, 9.441636281628764, 2.9638434129376567, 3.0583271816853554, 3.0835867552987994, 2.3732636580544137, 6.844694316387177, 8.300714896571252, 6.234735356223199, 3.2600446285740023, 2.9839051106283745, 0.19437175153964953, 0.37390814913857373, 0.17089877157442032, 2.637991285131824, 9.354769510607566, 27.81431136592742, 26.52173742171257, 32.52830997590096, 37.69877833704795, 48.29204113252702, 41.920609704909786, 16.451858051361576, 2.8106613745612483, 0.09088222087631304, 0.07418658328993667, 0.016157428260832545, 0.02479940566474632, 0.053127400817409645, 0.030231057148006175, 0.03721894921674844, 0.03610388142988086, 0.06266069853858602, 0.037360338404053645, 0.02417592883801028, 0.04485853504569781, 0.055873749417162714, 0.0927564703048237, 0.04245773806507069, 0.11571630925661135, 0.017402353696525097, 0.033443365321164174, 0.024795887405954065, 0.012927078717057745, 0.013247420297815435, 0.00923224431913226, 0.024269408801750793, 0.045803558126452475, 0.014562971379247405, 0.07027124580476554, 0.010283128302093717, 0.05266739949283581, 0.02977451279519066, 0.07861192848893904, 0.06673591857355449, 0.02535488835776285, 0.03286605295274527, 0.04954179140528844, 0.058438397283034946, 0.07414254089516979, 0.08031245981973988, 0.041238141411374656, 0.0873012577874526, 0.008976493526490466, 0.03922229212137961, 0.0213993867979415, 0.027316494792279218, 0.03373315723072137, 0.024944347584800377, 0.031942844225634495, 0.05010513799084772, 0.040942814516564535, 0.012603726410757632, 0.05709917983040214, 0.03705741574747428, 0.040246616793616165, 0.023532401575076006, 0.06844132222355374, 0.03600616308469926, 0.036356161844225666, 0.030369945058238604, 0.04320489595674219, 0.044263575841943105, 0.0597319137605448, 0.062283936497424884, 0.08572225864495962, 0.04716943543885024, 0.07432080189427061, 0.061569774012652144, 0.046331706802330674, 0.10945683465369287, 0.1526927380191703, 1.3630111323248957, 9.137879110151722, 26.136125287702008, 56.80433357915571, 47.1500587463379, 42.69712525029337, 22.382999504766158, 27.54950038848385, 31.33606045476852, 19.18397322777779, 9.084634896247618, 1.0066553445593005, 0.4421758375340893, 0.153838177361796, 1.042799495400921, 1.1376658178144887, 3.7897536110493446, 8.79995221091855, 7.119736796425236, 3.863400768849158, 5.814395047003224, 4.386872447306111, 7.569119805289854, 13.637843785747407, 18.96929798587676, 24.061322865947602, 36.746599443497196, 45.47845048289145, 54.273459526800345, 54.436481075902144, 57.09667959520894, 58.514275166296194, 56.352543215597834, 53.52894267728252, 57.66585473091372, 54.75348703322872, 56.24919660629765, 55.89568122740715, 56.104516060121604, 57.48089144306799, 58.001076175320534, 55.47768992762412, 54.32498770375406, 49.338984489440925, 49.6444861350521, 44.41255815567509, 45.67765589683287, 45.216534214635054, 46.32017151001961, 48.34121196500717, 53.54806030950239, 53.22707706882108, 59.10343085565875, 45.651878080060406, 45.918748301844445, 57.638198098828724, 52.13865856970511, 54.810765404855054, 49.07789976366105, 51.78824578562091, 52.71353683164043, 54.366164745823035, 53.361531995957904, 54.00836613870437, 53.06134908430038, 56.63027448038901, 52.1667270506582, 53.55497152574601, 50.09843380220475, 54.140604926693825, 55.921227624339444, 54.965440150230165, 52.37625222052298, 53.78170805592691, 55.845772989334606, 56.270730418543664, 54.59187753738896, 56.73296605387042, 54.506009009576616, 58.1355114906065, 52.97720247699369, 48.477871264180834, 40.77913722684307, 32.733677433383086, 21.304126093464514, 11.149073435414223, 4.9808011708721045, 3.2241137566105014, 5.5306105844436155, 7.3840785603369445, 7.475465862981736, 8.133850405293128, 5.911114811897279, 4.567247052346507, 3.197453896845541, 0.7496079021403868, 0.3369843352946543, 0.3192539044445561, 2.7150491889446013, 9.257184863090515, 28.013691325341505, 30.91403695844835, 32.78046542598356, 42.34477089297387, 54.63512559090891, 48.197006025621974, 19.989790839533654, 4.220895882575743, 0.06624869431459135, 0.01823208245989536, 0.06516883209828409, 0.04065635508947796, 0.07699997990482277, 0.010810058898172312, 0.02772878033048924, 0.07313927981041132, 0.05912833223720232, 0.045010358350531715, 0.006386334932739697, 0.024540674790079077, 0.05034590410369058, 0.018225664558309703, 0.06432248880305598, 0.08544623716584138, 0.04664615908217046, 0.01979000843881119, 0.04390075277056425, 0.03840333646944454, 0.05106483548579197, 0.03081367467530072, 0.0175021136660249, 0.038306188859766534, 0.06149580056268362, 0.03453012998966921, 0.004506057828679801, 0.0625184666545641, 0.05226537953281114, 0.014918706222106854, 0.10007768148376096, 0.04047114567290391, 0.074537857585857, 0.16110554788141482, 0.16418840826278733, 0.132088742008613, 0.10985726881171427, 0.13037610648860856, 0.1338299679299516, 0.0735792441053256, 0.170588766434981, 0.11737755559865506, 0.09464388878475274, 0.0896371211556177, 0.1494704189920618, 0.15546361675425885, 0.20043261018731903, 0.12038153956734365, 0.09347505311691955, 0.09423817628093305, 0.2249319947534992, 0.17455638176010502, 0.13193986048140835, 0.1255301253930215, 0.18849216461662324, 0.2535655268377835, 0.20386897418047153, 0.06641222344290826, 0.10331883861292755, 0.18733538717271822, 0.13851707771180138, 0.24273050017654899, 0.23100796065503554, 0.17992593798666232, 0.13639067810389305, 0.1894675937270926, 0.30585573144978095, 0.32699176020199255, 1.2699088958963272, 11.611120796972706, 34.17284604041807, 63.69876207843904, 55.88107824325562, 51.227091896918516, 29.40412252180038, 37.219009707050944, 38.39470878724129, 25.33763466342803, 9.51389124316554, 1.7357342353751584, 0.6948870997275076, 0.7852736463950527, 1.6822902257404022, 3.302258892405418, 7.003474312443887, 14.262440050801924, 9.479517552160448, 6.818988573166632, 6.717818389015814, 5.653720055857013, 6.532441781413171, 12.215794363329488, 21.602663570834746, 27.86836358808702, 42.32641027819726, 46.53229721130864, 55.9160344062313, 54.70807775374382, 58.84311883680282, 59.24912337333926, 58.36001226978918, 55.92211800236856, 59.30324815934705, 55.81344481437437, 58.62142255229335, 57.60206522480134, 58.19731235504151, 59.15295862382459, 59.60876549443891, 56.76264662896433, 55.335500086507494, 49.72645582691316, 50.25748199032199, 46.83060915239396, 48.87211653494066, 47.87543050704464, 47.71246387112526, 52.25396448566068, 56.051140446816724, 55.9279074207429, 58.401365818515906, 48.873799231744584, 48.33445372120027, 59.31930634283251, 53.95607702193722, 56.420659096010276, 50.73859599328811, 54.368322049417806, 55.25333427613782, 55.98764904083745, 55.23683286482289, 56.290463862880586, 57.29230388518303, 58.76535392576649, 52.984749117205226, 54.76918043628816, 51.00661546953263, 55.07690998815722, 58.46777939027356, 57.34354180674399, 54.57433277560819, 55.038231495888006, 57.1170876872155, 59.29841187692458, 53.940858225668634, 57.15975522994996, 55.837269290801025, 60.75445844281105, 53.70830482052219, 50.753312726174634, 40.884990230683364, 34.50307430759553, 21.985857563634074, 11.690860621390804, 4.5915172080839834, 6.19006593381205, 8.076434260414493, 9.64568974510316, 15.126640181387625, 20.941646137545188, 15.283034886083296, 10.37326587784675, 7.2126847121023365, 1.48077012310105, 1.1810859653257555, 0.4673585878504861, 4.049240951576541, 12.797815261348603, 34.090405664136334, 36.4981565167827, 42.465403387623454, 50.02828221167288, 61.65469338816982, 54.761704398739724, 24.23694306804288, 4.43817263649356, 0.2696551352498993, 0.1351019956411854, 0.13279725076450458, 0.1324403150788238, 0.14586298756541746, 0.10391725287322076, 0.1545427943910322, 0.1876113780083195, 0.14803118493047454, 0.10307824870030727, 0.09561466774152172, 0.1526548319886769, 0.12454640721121144, 0.08006805478925667, 0.1122577287136547, 0.24087771653167664, 0.15704059342463172, 0.07920094285040133, 0.14319645000561593, 0.1052388464731555, 0.1294443290680647, 0.10287921139669996, 0.17645539115032843, 0.11055812434924227, 0.09375162617934328, 0.28276201097234605, 0.1297632055056672, 0.15271519971711023, 0.11405726924778954, 0.11603934555164269, 0.21090167664712478, 0.09309889628521859], [0.08847226148411151, 0.025742134312167767, 0.06685679192624747, 0.03764001795301034, 0.04392327958597772, 0.029642268782481555, 0.01833628382413618, 0.025138137186126366, 0.034372154998803334, 0.03252719694207753, 0.0233718084787289, 0.04752020411674054, 0.04072335713933553, 0.015856732047283124, 0.12016001758315872, 0.0041033215764459344, 0.02333835533429538, 0.038866245097691016, 0.0883379586101059, 0.058272815039080966, 0.057573778960373134, 0.07495100114254222, 0.05588184696652236, 0.0546891629816063, 0.04518516812353365, 0.03169563531334842, 0.08986723864631307, 0.04037409765465606, 0.01945876925733061, 0.08114022548280417, 0.05376500813590904, 0.05583912224298524, 0.06440243773883389, 0.06966517066522952, 0.036361417207386226, 0.02873617637481901, 0.05617805869288503, 3.6567928618000405, 19.890731380831813, 42.38652452345818, 46.640338897705085, 33.72347970162669, 26.794338226318363, 19.541069730635613, 20.422973478994063, 13.866405198650977, 11.48842513561249, 2.7311009985785333, 0.6070371621078061, 0.10442860890179874, 0.5003802255997735, 0.6608537969089324, 4.7523177150757085, 6.066750047668335, 7.993310901426501, 2.8684521057913384, 4.416164217456695, 3.1704787765779807, 5.312187027546668, 6.560780905908154, 13.747071989120977, 17.660305000120594, 26.577905762580137, 34.02395286867696, 39.87526624433456, 47.90559745603993, 54.71207072657924, 56.35001328683669, 55.742245951006495, 55.28725101101784, 53.77076464314615, 53.14493479267244, 54.1761298333445, 54.33209111613613, 53.45369592789681, 52.62715839570569, 54.26982741202078, 51.43173371591876, 50.876129981010195, 48.66528995575444, 50.29707831721152, 47.25221687747587, 46.90675020217896, 44.79315750060543, 45.448389437890825, 46.01784306187784, 52.237537599379024, 49.33241844177247, 56.21486410017937, 42.1844950029927, 40.99883310256466, 58.15624513933736, 47.08254691093199, 53.35754294549265, 48.8400629258925, 53.035755618926025, 52.28882258938205, 53.960270035651426, 51.050522481241536, 54.94831508205783, 51.48678810365739, 50.88075445544336, 51.07219749881376, 51.172931809579175, 48.02709287212741, 52.91712353306433, 52.94404275955693, 55.205908898384344, 51.70622902531778, 52.4674081033276, 50.90004074958063, 54.985605055286044, 53.93309585509762, 55.8494717844071, 53.17491739026962, 51.2708184795995, 51.334611908082046, 45.77291850120791, 34.47566086246122, 23.365206103171072, 13.861936638432166, 7.093676569000368, 2.3621925230949157, 2.9848165713971664, 8.985347940075783, 7.788401870958268, 3.295897298282193, 3.8117581077160376, 4.291545614119499, 3.0521511647009083, 2.838672490850572, 0.4870699075681548, 0.24209925904870036, 0.629363170554561, 3.560255487118998, 12.079529262358143, 29.68119286721753, 31.167882950075214, 32.94863116356635, 39.38471109636369, 41.38152699316702, 28.55684349613805, 10.594184552469562, 0.9289677164727642, 0.06341464396926665, 0.03256575797774619, 0.043523852833576744, 0.011060518896087043, 0.06826608727175383, 0.031861790208025806, 0.018379200069654374, 0.016165290238155473, 0.05208363666409447, 0.0854330527926645, 0.0750479648911184, 0.018389406276025602, 0.04689258275433414, 0.028915366255528027, 0.05022365179273391, 0.03047703265873415, 0.053354136029919313, 0.033922714196265705, 0.049020146815887386, 0.07176978273257133, 0.04796740411209965, 0.03568734027325146, 0.09592700178825087, 0.008476075318251407, 0.035009907874008345, 0.09652936140135412, 0.06880982583689113, 0.06404499260468349, 0.03036164641079884, 0.014691287276124763, 0.04487848014480645, 0.024021489342914957, 0.07723869290202856, 0.04644832070616465, 0.04004389843753269, 0.019683861211242697, 0.05473062366006836, 0.08564766466377244, 0.030729395427530816, 0.04073308645597389, 0.03468572627753019, 0.027911411861198086, 0.11068789198273614, 0.026472154816973115, 0.048319950113974275, 0.05353374534376687, 0.024891654142148556, 0.07824428289407685, 0.04987341171551136, 0.04813073405755624, 0.11527994557494119, 0.09352795914897034, 0.07985539644235566, 0.03836647231852816, 0.01619846759093625, 0.0287176868427665, 0.03794739158042977, 0.03995662187075904, 0.019618554130917596, 0.015555146214131628, 0.10448182136901926, 0.03171550188844483, 0.00915528791430857, 0.01949644737666653, 0.03198450217173705, 0.04456728373864486, 0.029150685483229258, 0.04396539143917542, 0.2838818476565423, 4.8978322552096465, 24.11895425088944, 50.86056993853662, 54.44677729760447, 40.88888906663464, 31.312463475811867, 25.674205403174124, 28.270333966901227, 18.795725261011434, 11.098748445510866, 3.1605635150786373, 0.46064266274052285, 0.2187778572401693, 0.5750157900394932, 0.9007181323343708, 4.360609237224826, 5.214530306477701, 6.816997970304182, 7.97893149237479, 6.396904770405063, 4.070340361325972, 7.545427708856522, 8.748517190256427, 17.28599125339139, 23.1478597271827, 29.939588808244277, 39.08269643783569, 44.92644748380108, 50.38200547618251, 56.84553415544572, 57.0094931510187, 57.5546359246777, 57.06594782490885, 56.757131776502064, 54.52035311729678, 55.824847144465295, 55.423623977168916, 57.60671323345554, 54.73289851219424, 55.811938624228205, 54.637631985449026, 52.33155681240944, 50.153625472899414, 50.69934091260357, 49.75378297990369, 47.40751920207855, 47.117173594813195, 48.36089441853185, 49.04837608337403, 54.70743840740573, 51.09606904368247, 58.069815712590376, 44.1269507715779, 43.506569093273534, 59.61344095968432, 50.37721626220211, 55.40647145240538, 49.94675967001146, 53.40507030487061, 54.117588458522675, 55.02475030960576, 52.62700934563914, 56.92453069071616, 54.09131250073833, 51.12771472623272, 52.12652667876213, 53.41438201165969, 49.75524602397796, 53.35210654043382, 53.09871750493204, 56.11158417117212, 54.07359907704016, 54.44127028988254, 53.33414208504462, 57.09644033062843, 53.259534681996996, 54.632787858286214, 54.703457201680834, 54.391538558467744, 52.41577794474941, 48.427986560329316, 36.418563781246064, 26.48910722424907, 16.50430210175053, 8.90707508210213, 4.887536033507317, 5.530496345412347, 7.427360444299637, 8.343104931616015, 9.860865089201159, 8.083935303072776, 5.326813055622963, 3.826124278768417, 1.4460135107078862, 1.0774248309673802, 0.4775486604100274, 0.4366329156102673, 3.693240260885608, 11.365706920623781, 34.31381602441111, 29.935754691400838, 33.05717883571502, 42.66697399077877, 49.10745874527962, 34.869317777695194, 14.123237094571515, 1.2838042599539603, 0.0627525792937846, 0.06062026548710081, 0.06941297452055639, 0.012208152123005881, 0.024097152016756516, 0.07177847016963267, 0.049731233457644144, 0.01043442683669949, 0.01577993652092353, 0.09311151375333149, 0.03201024847165231, 0.005829578139744098, 0.0489161657019248, 0.03612473051274016, 0.014726127039701229, 0.06513634230941534, 0.022218179656192664, 0.0049380299113240215, 0.02085285009666076, 0.03719438460745639, 0.04315760151873674, 0.025815018002064, 0.02779907464320141, 0.0271419933696668, 0.05036163571921568, 0.03731282563098977, 0.03425573644739005, 0.02335127349191856, 0.06279007929767813, 0.03955862387233684, 0.04213864329240976, 0.024511967560336478, 0.20570205404393135, 0.10883110935889906, 0.192653875978243, 0.17176273489190688, 0.16714106434054915, 0.27426128485991114, 0.10061801861851447, 0.13560050437527318, 0.12657336860654816, 0.10797418638943665, 0.12096077864689213, 0.11605878886316093, 0.14117704223721259, 0.13460386995105975, 0.22517158109093868, 0.14880490309048086, 0.08141423215068157, 0.2031512876912471, 0.16547214179750414, 0.18771054042923838, 0.19798837602138522, 0.18942357431496346, 0.1463432327633904, 0.13559956974800558, 0.16847624834026062, 0.14947339141320798, 0.13862521868319283, 0.19150667463339147, 0.1660549048815043, 0.20697043517664557, 0.15698857605457306, 0.1841900140167244, 0.1703564426110637, 0.19850911662703563, 0.14409974427713504, 0.15069055190730482, 0.5649831638701501, 5.673997729055344, 28.51523695453521, 59.27559544963222, 62.1525009985893, 46.71488746520012, 39.390692710876465, 30.642689351112615, 30.684219406497096, 21.509444521319484, 16.391538862259157, 3.871178583752725, 0.7124802169780577, 0.5116256608838036, 1.0553651759701392, 3.0134219267675957, 9.677609012972924, 11.180386697092365, 15.141821715139574, 7.91744000488712, 10.204571600883238, 6.236088083636377, 9.530385790332671, 9.765024915818246, 15.47914751114384, 26.59090057496102, 35.28206486855784, 44.21632982069447, 46.480721965912856, 54.731925764391505, 59.1853887804093, 58.91201526887956, 58.82036516743322, 59.40476302177676, 58.196896583803245, 57.926158905029304, 57.58979997327251, 57.031360364729366, 59.0363230243806, 56.55784007041686, 58.23413556621921, 55.99154787678873, 54.75349487796907, 54.26681503172844, 54.21675382121917, 52.194356226151996, 50.81201099580335, 48.51159972529258, 49.29339085855792, 51.540336301249845, 55.3964654860958, 53.90856927441013, 61.47007919126942, 46.91566967195081, 46.04139297239242, 61.35239239661925, 52.68443284496185, 57.36408325933642, 53.897535647115404, 56.621139280257694, 56.00429557984876, 58.353944363132605, 53.04524775474302, 58.84715103333997, 53.70790473876461, 49.80348725472727, 51.836424258447465, 54.17316059912405, 50.36311926380281, 54.054277481571326, 54.3957394169223, 57.41243431645056, 57.1317102832179, 55.83875586909633, 53.66929292678834, 57.531870488197576, 55.05897691172939, 54.94826016887542, 55.12554737829394, 56.500534242199315, 55.445730455460094, 51.443543972507605, 40.29719168140043, 28.146565537298883, 18.300329908247917, 8.805063059253078, 4.859168471828585, 5.592671796198815, 16.875897645950317, 12.045478186299725, 11.594982204898713, 11.42033180882854, 11.083258025107845, 8.238759098514434, 4.947548787440024, 2.3445580370964545, 1.028140740048501, 1.1756244325830092, 5.258844264091985, 16.804298700824862, 37.67083929431054, 40.12022218396587, 43.839562631422474, 50.683780870129986, 55.531410709504165, 40.876737563840805, 16.159705212039334, 1.961872113808509, 0.15281886673502384, 0.22210919057890294, 0.2508379933574508, 0.07871348110418167, 0.09825361847516992, 0.12212334005462548, 0.19427655745417843, 0.2008369207502373, 0.10071169584989549, 0.19050806370233336, 0.1908286255333693, 0.13562690376514389, 0.181231627601289, 0.10005239292138046, 0.22549827162536884, 0.17023530878847645, 0.12971010029075608, 0.1489131359924232, 0.112016525930695, 0.16041104321277913, 0.08847156434410042, 0.08411844591459922, 0.17671851170880182, 0.1467720121746102, 0.19248634787096133, 0.16844779583475283, 0.2006476204241476, 0.1450267259872729, 0.20792916357036562, 0.1232050025775548, 0.12077160855574955, 0.07425395306199789], [0.02749302634789098, 0.030062851052911534, 0.046409165952354677, 0.06693402124989419, 0.04108406580804337, 0.026359898038208488, 0.04699483634002748, 0.0404346875485874, 0.057628358894538496, 0.01829741252285819, 0.05146255003168218, 0.05612054464196967, 0.07553179538057697, 0.055419765713234106, 0.07160327352222896, 0.08595713354166477, 0.11299590805485366, 0.04425712155118104, 0.03498320970984717, 0.0688124152140752, 0.08943947813203258, 0.05141842336724362, 0.03932813099855858, 0.009939534037614302, 0.06974329631174765, 0.06550836992720444, 0.041146249164857214, 0.05718502764319701, 0.02706632878060543, 0.09029691438040427, 0.04664179621144168, 0.03050051325361335, 0.05421245327940392, 0.1077923937250049, 0.0351600572767277, 0.057117948984547015, 0.09275607193910307, 0.9132002173892914, 11.107229590415956, 33.36630082899524, 45.17625539533554, 38.22294035265523, 18.32882396636471, 10.853358103382973, 20.880865089354977, 27.51995121279071, 9.22186391968881, 4.04540634443683, 1.0665731035893964, 0.25000815159611167, 0.49967781490375923, 0.90578920538387, 3.0164289138009472, 4.585335552692413, 5.877044123987998, 5.588774921432619, 5.078940833768537, 2.5209318245610883, 3.247958825480554, 5.674053622830299, 7.941172305614718, 11.333906304451729, 20.425171967475645, 27.08541535562085, 36.842799494343424, 44.63557235656246, 50.481876865510024, 56.37938399468699, 56.75480973336005, 55.446087391145774, 53.593473511357466, 53.90060686296033, 51.838644319965, 52.178384334810325, 51.424363582364975, 51.8508428912009, 52.435570224638916, 51.825924073496175, 54.6743179136707, 51.92586998785696, 53.669598871661776, 50.360185330913914, 49.060394225582, 46.761555825510335, 49.72976630733859, 49.35197930182181, 53.94598084111368, 50.190833076354004, 63.75754271784137, 44.741539109137754, 39.06264135914464, 60.03369938942694, 48.59247899824574, 53.71950710973432, 47.26957728785854, 51.17349270851382, 50.482465221035866, 55.83506884113435, 53.4634312506645, 53.98752658597885, 50.26221629111998, 52.18768035211871, 50.944536116815385, 52.24248763053648, 52.79876601311469, 51.92050418546123, 50.755968170781294, 52.385407032505164, 51.82559067203153, 52.24429976555609, 52.92250110257057, 50.92511253972208, 49.969317220872455, 50.30096538605229, 48.98676349270729, 44.70339013684181, 46.228921490330855, 46.997027474064986, 37.50356197357178, 22.731735475601692, 11.806607803990765, 4.523367987525079, 3.8774043658087334, 2.153556750666711, 3.523439875533504, 7.856259365235606, 8.911631895649819, 6.624515008541846, 2.6578215629823747, 1.590641962905084, 1.1229906375369718, 0.6238084202331882, 0.13909159768973628, 0.8609183324921517, 5.909926333735067, 9.740604239125407, 27.063177477928903, 44.37903365781231, 26.86598620107097, 41.15524938029628, 43.32749328305645, 24.732665938715783, 4.967154264450073, 0.2028970384309369, 0.024868305697436296, 0.06502955731364989, 0.0488897318380975, 0.007879953097266657, 0.04982005752202484, 0.00591141548225536, 0.021903476482557676, 0.02397284659016277, 0.031716739120442546, 0.047358279942624995, 0.06287729074697822, 0.038619128115955866, 0.03973645203176045, 0.028857375314879804, 0.06933060474693775, 0.034449346018053835, 0.03545169545818241, 0.057230410691831386, 0.029600541888465805, 0.016208828930112145, 0.044386406549282616, 0.05723512213256571, 0.03512544159386908, 0.011512753046718577, 0.04652706305346182, 0.0584774409540959, 0.055709963649391174, 0.07210835529070708, 0.02911922416739887, 0.016881703106205792, 0.05652264504122639, 0.05789124196575535, 0.06784370469470179, 0.03321717020064112, 0.041919837089916395, 0.06896757100137972, 0.03731044692798488, 0.028451523000013926, 0.0409156222256922, 0.052529086148546594, 0.03664056049479592, 0.08581733781724207, 0.07659409886165973, 0.02406302088451001, 0.02029988400247549, 0.04162302781497279, 0.02917273732412967, 0.01698997048210473, 0.02219914045605448, 0.048353903130778385, 0.08893615836578031, 0.049856527137660214, 0.06093048513115895, 0.017071610556975488, 0.04435104393069783, 0.06581817588378346, 0.13590710808432874, 0.04039379760562893, 0.05659826174979249, 0.056437207085471, 0.043594436344480327, 0.0344142438693633, 0.060988815065713665, 0.014970699651917864, 0.07183012747836691, 0.08661815250713019, 0.033032956698368636, 0.08752688600291168, 0.06636020607284962, 1.7199471857278579, 15.68939341652778, 41.131483739422215, 50.138528270106164, 43.97704562833233, 23.07955949537216, 16.25093463928469, 26.68823419078704, 29.593447485277732, 15.073307714154645, 4.308799630211246, 1.2016295016773286, 0.09621669793681753, 0.24492969345902246, 0.9704985073016537, 2.8770653855416084, 6.333707542188707, 6.555956390596206, 9.222799404974907, 7.896333240693616, 5.6674007927217795, 6.19438789544567, 5.850378380667779, 11.664694489971286, 14.749222859259575, 22.876927891085227, 31.4568910291118, 40.88088743148312, 46.484381537283625, 54.48767192902104, 58.56966687786964, 58.8801734678207, 58.282882782720755, 55.12699473288752, 54.77064740273261, 55.351989730711914, 53.61507792626658, 53.643358215208984, 52.568840595983694, 54.83890448847125, 53.157627582550056, 55.65530661613711, 54.42386673342798, 57.12626211104855, 52.46281108548565, 51.24209496282762, 49.44569256997878, 52.714493889962476, 51.831607587875865, 55.60799498711863, 53.24402170796549, 60.82302147342313, 45.88434519306306, 42.24646060697494, 60.05839463203185, 50.99737436540666, 55.45476367396694, 49.235512364295225, 53.04500064542217, 53.396150835098766, 57.6902126496838, 55.309914465873476, 55.207956375614295, 53.05277870547388, 52.884128555174804, 52.745264883964296, 52.1863075225584, 51.94178304364605, 52.45911229041315, 53.51305707808464, 54.8355822409353, 53.99974869143579, 54.63657686787268, 54.990115780984205, 52.81541647449617, 51.472036069439305, 52.16960607036468, 51.52094018074774, 50.10603143322853, 49.16188555379068, 48.70514515907534, 37.40970357771843, 24.16735629881582, 12.161288126822441, 6.646181200781177, 6.245211026360912, 7.817697073182753, 6.819408266775071, 4.750450176577415, 6.54926973004495, 6.894204433887237, 4.238325915028972, 3.295906613911352, 1.0447850727265882, 0.39914424981801744, 0.42815860420946156, 1.052492652689257, 6.027147837223546, 13.627228871468576, 33.909443193866366, 43.19296383088635, 30.996489101840606, 47.044091993762606, 49.87547843686996, 30.013825547310617, 6.128041984573488, 0.1654895473151438, 0.0564084098403973, 0.04122423308510934, 0.04658516316163925, 0.03603962963567146, 0.03188962792797435, 0.041751504590314244, 0.04508374191279854, 0.021199047144862915, 0.05325454459976285, 0.008286368965561832, 0.047296104246690396, 0.044508995938925974, 0.058289929443309386, 0.03285762981601781, 0.06593396241265921, 0.05011124754204385, 0.08125002120411204, 0.04452778424526896, 0.03315207954015463, 0.05304791536482592, 0.08304904079845837, 0.026821550282259143, 0.0253439620287428, 0.021720661090747006, 0.06204497069120408, 0.021501037089394468, 0.03847159873393755, 0.01613163599564183, 0.040900216197534915, 0.027937311378698197, 0.06370000022974226, 0.05690478501961597, 0.12534523773337566, 0.10863774110593143, 0.2740877812668201, 0.11555205234476637, 0.1866548253043044, 0.18833850270077107, 0.07910918083883102, 0.09112781334307887, 0.15309637442471521, 0.17338276570362432, 0.12823990861614867, 0.15805052713521067, 0.203102411281678, 0.1031805903861119, 0.1937669098016716, 0.11914177181860132, 0.20293250830183107, 0.07918002098918923, 0.1733459168744664, 0.14679822770337905, 0.2256627047374364, 0.17688283756855996, 0.1842100548768236, 0.16164790748828844, 0.2074387753682752, 0.07521657318237328, 0.16211257045788152, 0.10152432361557599, 0.15242535801183793, 0.15124766636760006, 0.14922638934466148, 0.10486688780327959, 0.16329976159238047, 0.3041551081884292, 0.15082591964352518, 0.1234494612341927, 0.16383694244488595, 1.9338400373535773, 18.004151736536336, 46.731016251348684, 58.84336986849385, 51.63804254224224, 29.391853347901378, 19.368654104971117, 31.312796877276515, 36.838057348805094, 15.605243867443455, 5.398793941543949, 1.7003849773637711, 0.3001873549674788, 1.540800772847668, 3.1313602434050654, 6.915033200094777, 10.363838461137588, 14.955707211648265, 16.89170479774475, 11.77116918948389, 6.917581269817968, 6.542055510705517, 8.510554836642358, 12.742143100307835, 20.27582576197963, 28.202198474637925, 34.261777939335, 41.61479034731465, 48.80499301418182, 53.3219317466982, 61.431208502861764, 59.97836259103591, 60.19969801748953, 55.388361869319795, 56.659931521261896, 57.49051693947085, 56.47044574060748, 54.79616634307369, 55.55966354185536, 56.862086557572894, 57.02574353064261, 57.43988698528659, 56.096561493412146, 58.99143542012861, 54.76746636052286, 53.213466444323146, 52.50470592129616, 54.06339699222196, 54.08040046691895, 57.835501163236565, 56.01465063710367, 60.35557300813737, 49.481095883154104, 46.13668303335867, 61.762844900931086, 53.123801062184, 56.72421524601599, 52.28912068951515, 55.08275824208414, 55.90055281116117, 58.601238035386615, 56.23882193719187, 57.298073691706506, 53.4676399538594, 55.35104836187055, 54.17156811683409, 53.7265516865638, 53.261511556563846, 52.24095006142893, 53.21967555630592, 55.87490051023422, 54.43129570253434, 56.295935569270966, 57.04308040680424, 53.530025251450084, 53.116717261652795, 52.72029115307716, 51.95841781554684, 52.745500226174634, 53.06464387524513, 52.85180038021457, 42.022320685848115, 27.404247176262643, 15.496060771326865, 7.545741498470307, 6.516058041203407, 8.689789502851426, 7.871912564000777, 18.496215035838468, 15.806231018035644, 14.079901768315224, 9.623723491545647, 4.986062049865723, 2.5954431295394897, 0.9944691533042539, 0.684679253928123, 1.4092296458059743, 8.477925619771405, 14.680102852083023, 35.023666966346006, 52.30634381694179, 40.40125608444214, 52.642679214477546, 57.07618521105859, 35.52312981697821, 8.334882663142297, 0.2850296925152502, 0.12266386105048081, 0.1442747187590407, 0.11101774646029358, 0.12594857027814274, 0.1646571468201376, 0.14869268653133225, 0.1082636297289883, 0.15750510317663993, 0.2418719914050833, 0.24026826294439457, 0.13564774135668434, 0.2754020510661987, 0.08997167175215098, 0.09885016348092787, 0.16005389302247958, 0.13446004460415534, 0.12119140175561752, 0.1791628990923205, 0.09246539519799334, 0.1346963520852789, 0.1563616556626174, 0.1720597625019089, 0.1444894532042165, 0.1135056323161529, 0.16506905697526472, 0.12113969082072859, 0.16460747367912726, 0.1283988258951614, 0.13195722003377255, 0.10442266405950631, 0.11879042091388857, 0.07967000316467979], [0.0205490694216062, 0.03462020660780611, 0.0031012184814655135, 0.07791158623032032, 0.010876212505653743, 0.04310840718267907, 0.02113675270530005, 0.0581335096109298, 0.03739113513860972, 0.023560584034590472, 0.0498263854082794, 0.02544687828049064, 0.05194460702759605, 0.04065808644818683, 0.08328730946466809, 0.06989093677651498, 0.00898060358820423, 0.014519976609716974, 0.0734988661603101, 0.026785998056913098, 0.008136508761033898, 0.02246279344563523, 0.059789343541788484, 0.03535077869591694, 0.08810873744228194, 0.175804783319754, 0.02790459176345218, 0.03041442412312233, 0.07042647053998324, 0.004668693985759972, 0.05102782194773036, 0.14402528053089497, 0.04176381179281781, 0.03353126624959611, 0.1429757400746307, 0.07983642044447123, 0.013935280111317914, 0.35441035344716043, 8.03829852611788, 25.343708453639863, 48.14525819593861, 40.33605452506773, 33.66647589591242, 20.922812877162812, 34.53922679347377, 21.487928359739243, 11.305492654923471, 8.70114770627791, 1.356032622918006, 0.5694787516709298, 0.2198788941267037, 0.7429111905155644, 0.7579680051534408, 4.523887701572911, 3.708088883469182, 9.303818902661725, 4.049482912786545, 3.4921837333709966, 4.367383660808686, 0.3118925042931111, 4.381551752167364, 5.560578963448925, 13.39537560939789, 20.435938873598655, 31.79610936872421, 36.75445595095235, 46.24097101150021, 49.371967700219926, 55.20145308586859, 56.12955254893149, 56.625328371601725, 52.85374195344987, 54.68342173484064, 51.94953364710654, 53.55634435530632, 51.98911428451539, 54.06484826918572, 55.22764275150915, 54.90559654851114, 56.15057253068494, 56.424973703199825, 52.12013321538126, 51.546039427480395, 46.56122469132947, 53.08907239667831, 51.71082996552991, 57.23197390956264, 50.548749354577836, 66.46216207934965, 51.69648978017992, 35.783881141293435, 60.03687650926652, 49.50707766317552, 52.82780724187052, 47.09807557444419, 50.02557577625398, 48.79538320725965, 53.222472206238784, 52.35154128843739, 53.97249214110836, 52.040395352148245, 52.34531648697392, 52.98927553238408, 52.66273037079842, 52.71762394135999, 54.46274526657597, 51.152429580688484, 52.21039087541642, 52.15836847982099, 52.92796496422061, 51.7221656153279, 51.74620189974385, 47.845581270033314, 48.84314198647776, 45.51295165092715, 41.54882392575664, 42.34892860535653, 38.304333456100956, 31.513949748008486, 24.724164201367287, 11.349021157910748, 5.572643683802697, 5.458033498256437, 9.0949664192815, 1.395308663768153, 6.00466137932193, 9.123595799169234, 6.320343046419083, 2.6960033851285137, 3.085404773873668, 1.0149685017043546, 0.5438655518716382, 0.37129958911288174, 1.628694837131808, 6.983071613696314, 15.033963399548686, 29.39211614670292, 38.998702802965724, 29.956449116429976, 42.045227327654445, 41.58666303080898, 17.169151690698442, 0.7610001198707089, 0.11820307662410122, 0.07571617742219279, 0.08608903856046739, 0.032903732987301, 0.04038922023028135, 0.02248879830022493, 0.06019971769062742, 0.04481629295755298, 0.03307798734655784, 0.017161706327310493, 0.09495576317872732, 0.047426641798548164, 0.04351225809284276, 0.056851656822067116, 0.15389423967609484, 0.04895512510331408, 0.14298352352794141, 0.03645198795223429, 0.05221818085579623, 0.031689887738696514, 0.03786645439122954, 0.013144625662525576, 0.03928749769505474, 0.05477735885388909, 0.07083138631236169, 0.005802654458450214, 0.036176782356755394, 0.07138862334672483, 0.05095279512686595, 0.04043899296272186, 0.013306858187030642, 0.05294622868419655, 0.033987272425644824, 0.0683629973941753, 0.028955924865459243, 0.037583859877720956, 0.04109652239769217, 0.018578779380468112, 0.035718052738135865, 0.035607521572420676, 0.03549561910932103, 0.022794999813120213, 0.08757193197285937, 0.07287575322533808, 0.05987966530806115, 0.04078324606281616, 0.10491161967717832, 0.024226299119031718, 0.02697830144766598, 0.024886488794319095, 0.024379129829486052, 0.14904700219631195, 0.02677040433721437, 0.03153146075595531, 0.03186616648529326, 0.05995213722569808, 0.02056423221684752, 0.04114822184126224, 0.038306411025264574, 0.034578094754608414, 0.08743783594259331, 0.10566203344252803, 0.04826105710479522, 0.028541892646781863, 0.05600003901148035, 0.003490287246325264, 0.044813891271910364, 0.10273850402764736, 0.0649449045980169, 0.03581380606779168, 0.4510916913709333, 9.944527283791574, 31.296436671287786, 53.58955898592549, 46.09128159861411, 34.48643953569474, 18.744973713351836, 26.078413494171638, 22.23290216538214, 13.014782148022807, 7.497651278972627, 1.8259607615970799, 0.5031392759373111, 0.25660384686723836, 0.4732610808024484, 2.2151308530761353, 5.509718570017046, 6.611673658893955, 7.347470589222447, 8.189289185308642, 7.297729542178493, 5.9629204965406855, 3.2394306121333956, 6.509769501224642, 9.374169553479842, 17.67803999685472, 26.31248289538968, 34.139215638560636, 40.25552434305991, 47.943919012623454, 52.29740865768925, 58.54012750810193, 57.65926122665406, 56.948178660485056, 56.8538535025812, 55.63105852373185, 55.47870582149875, 56.096867438285585, 54.66501012925179, 56.74954983495898, 57.45463117476433, 57.369633413130245, 58.5051360437947, 59.74196918549077, 53.643570023198286, 52.8394135352104, 49.27479882394114, 52.85081194293115, 54.09369337943293, 58.090996511520885, 53.465572864778586, 64.56851236281857, 53.31541668984198, 40.77131602071947, 61.27835765961678, 51.71104177351921, 54.33673912479032, 49.91675353819325, 51.19439109679192, 51.21964723833146, 54.55944738080425, 53.60352654610911, 56.64401846547281, 53.955743620472575, 54.4037018283721, 53.57819195716612, 54.46860136524324, 53.96447089410598, 55.29052619011172, 53.4619015262973, 54.16193085332071, 53.924313668281805, 54.118141512716974, 54.72765038090368, 52.231567751976755, 50.25986286901659, 51.22429916935583, 48.40267942797754, 47.00181276567521, 47.333657049363666, 45.09793350773473, 36.22324151377524, 26.89255241424807, 13.288452779093097, 5.358405786175882, 7.239574030522378, 5.8701505584101525, 6.83803266094577, 6.862683286589961, 5.136110849918858, 5.6016138195991525, 2.432386524254276, 1.4435403337401729, 0.672930161799154, 0.1573509662862747, 0.33457814505504024, 1.3177694115907916, 8.73419269438713, 14.672205159741065, 28.497264654405658, 41.982347811422045, 31.204710083623088, 48.28955827220794, 48.010038406618186, 21.273968950394664, 1.8233811903384425, 0.16837869470398273, 0.038156958762556314, 0.03087707036625474, 0.04467126102216783, 0.016432635771531253, 0.037051984184091134, 0.06332261765736245, 0.025145217753766526, 0.047094837627223426, 0.044760820530955835, 0.05584222489907857, 0.08590213608958068, 0.023965277641470877, 0.02263277494949439, 0.06954366912043865, 0.03507700568485645, 0.056204381473963304, 0.0486601812524661, 0.024694794443466013, 0.010923020477827278, 0.05862188300177936, 0.07641651201993227, 0.021186774416315942, 0.046599416227470485, 0.10094892263652817, 0.011415984650563088, 0.016370718630271095, 0.04521835122197386, 0.073550607738716, 0.004264962776834446, 0.04962271710316982, 0.0601870963920749, 0.013179855173333518, 0.11984263501700856, 0.14769242085035772, 0.1879479357552144, 0.23235636733232007, 0.23109091265547663, 0.18088973788244112, 0.09611422601606577, 0.13976230766744385, 0.07522317686028059, 0.16452280564173577, 0.13448996799847773, 0.19277252767595554, 0.16142503718935675, 0.15238080233816179, 0.1362255861562106, 0.23771254766371944, 0.07333080179148144, 0.09881724468282155, 0.22324185157495163, 0.1470478344708681, 0.08468107620794928, 0.08563340010662233, 0.24319784445387704, 0.20755116046676714, 0.2557818345244854, 0.256103836600819, 0.13326928349992923, 0.272099997607931, 0.1722242722227689, 0.10462224528553987, 0.08018617788630147, 0.29178876369710893, 0.18594584157389982, 0.12046112844179716, 0.2812875368662419, 0.31342734612764855, 0.14525730313072283, 0.7530640618455026, 12.022834343294944, 35.87952029320502, 59.86155048493416, 52.795581048534764, 44.67408610928444, 31.058087964211744, 46.84330194227157, 32.018750944445216, 17.094087331525742, 11.444239635621349, 2.2695733510678817, 0.9829374462846787, 0.527315846373958, 2.166774157554873, 4.674182630354359, 9.918145422012577, 8.67003252429347, 16.9116186711096, 13.820083968101011, 10.855983149620796, 8.625354766845703, 3.246615903992807, 6.883608641162996, 8.86771115564531, 18.156441680846676, 27.282900810241703, 36.48724448296332, 41.21468113314721, 49.255073224344564, 52.71598439062796, 58.623615157219675, 60.22621716222456, 59.40448061112435, 58.94167623212261, 58.122587280888716, 56.73173835200649, 57.41377184467932, 56.587622627135254, 59.7156108579328, 60.853274714562204, 58.49793064978815, 63.262441542840776, 61.92372875828897, 54.3068741982983, 55.56231506409184, 51.55031873333839, 56.0404755223182, 57.14769786404025, 61.85429103912846, 56.08302147157731, 65.99044215294623, 54.28591697446762, 42.845888983818796, 62.52997813686248, 54.00390248144827, 55.296970644304835, 51.995766624327636, 53.62509958205685, 53.66993227312642, 56.866044229076756, 56.09770290313229, 57.61984532879245, 55.72450507071711, 55.75588010972547, 54.53836071875788, 55.81920285378733, 54.37790439974878, 56.844008353448686, 52.96663561174947, 53.64056941001646, 54.7526554907522, 56.38867216725504, 54.79451110286098, 52.01540985415059, 49.2694487110261, 51.7964788406126, 49.28033328825428, 51.18203170837895, 51.69409713437481, 49.79248500639393, 39.77569687751032, 28.225991572103194, 13.386645393986857, 8.928210773775655, 10.257784435825965, 16.373524396650254, 9.575648961528655, 14.393491341221718, 17.52167667112043, 13.770842532957754, 8.918426421380813, 7.530881108776216, 2.288448041485202, 1.1459922742459083, 0.9102908606010099, 2.2119917311976036, 9.965547265545016, 21.570249103730728, 36.837845540815785, 47.588191416955766, 40.97294545942738, 55.99130076746787, 56.350884053014944, 26.303906633007912, 3.0311507947983283, 0.34354845242154214, 0.17062429759290912, 0.152416241565539, 0.16867849555227066, 0.09988093478304726, 0.2896648002487998, 0.14763191522609803, 0.1615570034951933, 0.09703584511073367, 0.16818481317210585, 0.30306015404001363, 0.15173469910458212, 0.18262455930873273, 0.15523743695549427, 0.26879622811271303, 0.12563232918299977, 0.32966405874298466, 0.20019552129651272, 0.1922878085245048, 0.12036388890156824, 0.09112602835821529, 0.20067333033488644, 0.16497927147053904, 0.15903131886115, 0.2800797532883383, 0.05502571689806158, 0.1290711369966307, 0.2439493613858377, 0.1933985134406436, 0.11938535713500555, 0.08992143170607668, 0.1291051206569518, 0.11615035935275017], [0.009669270666856921, 0.023347247699876467, 0.0904682346229111, 0.11328728193597448, 0.035299332061361884, 0.006124954351464347, 0.04376876348208997, 0.05798874197587852, 0.019570097154487046, 0.03586977262109999, 0.10006771467986608, 0.08864913586406939, 0.0648456808900641, 0.030681518762702906, 0.04466906618026476, 0.040533463095104506, 0.038478336477231596, 0.02811600138703662, 0.0413867509773662, 0.04210560958111479, 0.038181151819205096, 0.024991923560118003, 0.03594533187307177, 0.01784670384480588, 0.04731151027484767, 0.06386420734587216, 0.012301395557099774, 0.07579946650132056, 0.03189579876620443, 0.02729158735864105, 0.01327880404724349, 0.03837185025575661, 0.037896864251383854, 0.15020209424678357, 0.05590291821487969, 0.06589709060086359, 0.020892807327571417, 0.09122127606984108, 5.3990479150126065, 19.736382192181004, 34.2321797340147, 45.16587288148942, 38.58390039013278, 42.01720983751359, 30.90545677369641, 29.980977658302557, 27.049551163950277, 10.659551831983752, 3.630204094994453, 0.902670553374675, 0.2517834071430468, 0.35433561390926765, 2.122692600373299, 5.8531206077145, 5.6789840421369, 3.015309322264887, 8.49506147446171, 5.996552859583209, 3.6701421583852465, 3.3927161030230986, 2.94878690473495, 3.986226849017605, 5.793601091830961, 12.920905120911138, 21.783688799027477, 29.292660528613677, 35.43075407705, 39.94950886695616, 48.60326159384943, 53.781080476699344, 56.58598699877339, 55.65350232585784, 55.942118167877204, 55.08744155206988, 55.63248626647457, 55.359571672255, 56.82422391829952, 56.61620886095109, 57.42375035439768, 58.65580604922388, 56.93487398086056, 53.530201758107836, 50.518460812107215, 48.759069904204345, 51.91475399078862, 53.35264390514743, 54.50688762049521, 52.84574031829835, 47.302493818344615, 34.59704645218388, 40.11172240780246, 57.95280748798002, 51.59557896275675, 51.530440161305094, 47.09222732051727, 48.052956981043664, 49.17065989586615, 51.078124200144124, 51.01293833025041, 51.06409388203775, 51.432526034693566, 52.24066765077653, 53.1662489521888, 52.26573159617763, 52.49127964819632, 54.744100801406375, 52.941340246508204, 52.87621713453724, 53.16866513221495, 52.58542437707224, 50.39112498683315, 51.54342320657546, 51.06395659908172, 49.629906685121604, 44.623871926338445, 41.7970746563327, 35.117003686966434, 35.15382689814414, 31.698516876466815, 28.37176057600206, 12.480956392903483, 1.9851119119313456, 5.453173681612938, 5.671650680803484, 11.518102768928776, 4.192922519099328, 3.5542084180539657, 2.712296420528043, 1.3885871921816182, 1.0283521803156024, 0.281495085406688, 0.18127776141608917, 0.4223860704129742, 3.099086981627249, 11.131497294672075, 21.29630880971109, 34.796753929507354, 44.455951336891424, 33.55505312642744, 46.40084681972381, 35.89871245045816, 10.21567386965598, 0.5940288665794557, 0.04496731953094563, 0.05188341192420452, 0.08771942688092109, 0.07543314623856738, 0.053102529772947875, 0.06266635609790683, 0.03957689123889131, 0.03677789707698169, 0.023736939389979648, 0.045446859928028244, 0.05739405856377656, 0.06949821712389108, 0.0573311206103573, 0.0229640371136127, 0.04861585540516723, 0.08245940590577741, 0.04829616691436499, 0.05568683162451752, 0.11349624773908047, 0.02978565554404932, 0.03350298228343168, 0.013293393234151506, 0.040761661535549554, 0.05236834174983444, 0.07464636627945208, 0.07017945314967824, 0.07025952465952405, 0.030212856814145084, 0.07786773535753451, 0.0588603891552456, 0.039636600131709734, 0.012511160964476726, 0.019057570926604733, 0.024847734321449554, 0.018622388935557777, 0.014443469323938894, 0.09371749696231658, 0.015316513656157882, 0.05411418718135646, 0.08830602040454265, 0.06088638527979774, 0.0372663700592614, 0.0379688918380247, 0.04217717751500107, 0.08385332586664347, 0.001962747785822308, 0.1228893130657173, 0.04304164262007802, 0.028757272521033887, 0.07239685634211188, 0.010987120969671636, 0.04725288922688173, 0.03802323811537316, 0.023259187808200237, 0.011097528603709033, 0.014848387969147055, 0.007361072170052438, 0.023640575105204217, 0.07226129708391044, 0.1205986948503602, 0.007869311178388495, 0.04108023153798234, 0.03777663058210765, 0.08700140331300997, 0.042263362406482624, 0.052288048074490605, 0.058114284634469986, 0.08160408406007676, 0.09661905497552888, 0.05469784658822802, 0.1826206369385604, 6.819816193272991, 23.088994756821666, 40.42854793610112, 50.049796412068034, 42.365355491638184, 38.45934944768106, 40.177335816044966, 34.04614563911192, 23.689144849777225, 13.320863323826945, 3.2545329630374913, 0.8341948567859588, 0.1499023546855296, 0.3416461948185198, 0.2663511206065455, 3.931627456218966, 3.0225411922700944, 6.571401213445972, 6.0443665519837415, 6.930895265071624, 7.64771233643255, 4.672470515774143, 5.362483580266276, 7.039176216048579, 9.763539318115482, 15.927436178730382, 26.71915815722558, 33.792740914129446, 39.221818985477576, 43.77537304355253, 52.02377234735797, 56.3488640323762, 59.771139852462284, 57.73039340972901, 58.42025595326578, 56.44079262210477, 56.650145207681966, 56.98859868511077, 57.886099738459436, 58.54976477161531, 59.27718008718183, 59.552930555036, 57.986112333113155, 56.390766712927054, 52.80321005851992, 51.44252023389263, 54.77565234707248, 56.93190866901029, 56.61417707320183, 53.10818610652801, 50.60586298665693, 39.34254953938146, 43.03186032079881, 58.02416716852496, 54.40320368736021, 54.09486224574428, 49.190103084810325, 51.796467073502086, 51.23024156016689, 53.35272235255088, 53.95505720569242, 53.41739046958185, 54.46140773834721, 54.690623206477014, 55.87366104125977, 53.5723005571673, 54.00289443231399, 56.0330230189908, 53.726688969519834, 53.545126376613496, 55.80312113608084, 55.916375652436294, 53.48693801510719, 54.11576455639255, 52.6835189327117, 52.026596453882036, 47.77707707497382, 46.15416111484651, 40.334815056093284, 39.844220684420684, 36.05960415255639, 30.846356461125037, 13.146843448761972, 5.204364503583601, 5.048996969576805, 6.606752064920242, 10.235914280337672, 5.806909203529359, 4.334699040459049, 1.986197550450602, 1.9317678001619156, 0.5268347431575099, 0.32464057507534183, 0.1947560212424686, 0.7336377268356662, 3.5957249902909805, 12.202040572320263, 21.510534940227387, 34.21572931351201, 44.79890769527805, 36.86849886371244, 50.50421084127119, 42.54781630731399, 12.4547637854853, 0.5785723379062069, 0.01758770483936514, 0.018622375529019103, 0.0629177363589406, 0.022585539883303068, 0.06557397003616057, 0.04722679627218074, 0.020797691766112562, 0.018217088203997384, 0.02725933122658922, 0.026486222106482715, 0.07127077604133276, 0.07724796256591236, 0.04664259677332255, 0.02297337764062949, 0.036432977480393265, 0.06897432789687188, 0.06059007779244454, 0.01700102704607191, 0.05254584815232985, 0.04480292089283467, 0.04729747554407485, 0.06116414577850412, 0.04547392964483269, 0.07342886104578934, 0.10234720929856263, 0.12239258165561384, 0.05532908771607665, 0.031624195699189464, 0.05261861118337801, 0.041789280385860515, 0.057556197242510904, 0.09753608520353034, 0.04471626485727968, 0.12185260458218476, 0.14252632225473083, 0.11922958081648236, 0.3708959220638198, 0.18392686281473408, 0.12569606769829988, 0.2037462315732433, 0.08661553248642914, 0.13290271042816101, 0.09574733118736937, 0.14983754364713547, 0.15136732930137267, 0.18947450384016962, 0.19552221641905848, 0.15396344805917433, 0.132232490746725, 0.15439239600973745, 0.14065524443022667, 0.15173690543780405, 0.15261586875684802, 0.15482765652479666, 0.15267508735339488, 0.05991068803855489, 0.08379816753609527, 0.11070810138217865, 0.10215878997358585, 0.23340106611290287, 0.16819834228484862, 0.2560829224004861, 0.17892489089600502, 0.16660155458075387, 0.19112284926156844, 0.10681212293885409, 0.30417876498353097, 0.167686365725052, 0.1565787343368415, 0.12698966844548143, 0.34946029164618064, 8.116832712004262, 26.83002002777592, 47.66242227246685, 58.813873644798036, 50.088890675575506, 52.35220416899651, 44.155313430293916, 42.495193789082194, 34.882865644270375, 13.823264029718215, 4.896495217277158, 1.3623706828201971, 0.6662697933854596, 0.6217669491325656, 3.1533841067744843, 12.091079661923072, 14.175148683209574, 11.035509051815158, 15.144729172029804, 14.95124355439217, 7.898332668888954, 5.066473580175831, 3.630453165500395, 5.6952927670171185, 10.140971349131677, 18.386639702704645, 25.89749416997356, 33.98837697121405, 38.02326425429314, 45.16675149240802, 51.79276827842959, 56.74442721951393, 59.47976658421179, 59.55588802214592, 58.471948869766734, 59.59417035502773, 57.83428522848315, 58.88737886182724, 58.591345817812034, 59.46758370245657, 59.582477769544056, 60.772065962514574, 58.318019374724365, 57.95651020542268, 53.973821824596776, 54.06548369315363, 56.50469587695215, 56.693895324583984, 58.3230713875063, 53.270964468679125, 52.32585368617889, 43.69151276926841, 44.541666892267045, 60.348147961401175, 56.86648353453606, 54.07775286705264, 49.99194929676671, 52.91743732267811, 52.66840211806759, 55.74013179348361, 54.80446607835832, 55.3022736887778, 57.10514799241097, 55.783470061517534, 57.924672326734, 56.300520820002404, 57.92167171355217, 58.02290808769965, 56.58092714125111, 55.75284811758227, 57.46978721311016, 57.81219051730249, 53.814365709981615, 54.167645746661776, 52.634018621137066, 51.54893021429739, 48.852402702454604, 48.14021402789701, 42.77325845533802, 42.70761366813414, 40.78092190527147, 36.808659184363584, 16.3621053964861, 4.753943537512134, 9.817420917172587, 11.782756851565454, 19.665004860970285, 9.326782418835549, 9.894426849580581, 7.891476365827746, 3.9618848648763474, 2.560846353730848, 0.8351451735342703, 0.9474501698728531, 1.077871245722617, 4.8022838081082995, 14.908187697010657, 30.818597847415557, 43.836350210251354, 52.66923758291429, 45.80005738043016, 59.083203192680116, 48.61507185043828, 15.339548395526025, 1.1333908020488679, 0.2156026679421625, 0.1818558666855097, 0.22013274502129326, 0.20722483765454064, 0.19643969863893526, 0.16165221290242288, 0.09514559210548479, 0.14724212969022413, 0.16203085951987775, 0.09871595253747317, 0.22438237263310343, 0.2099246693955314, 0.21135947546891629, 0.2547151336987173, 0.22404009987029339, 0.19163989732342382, 0.1610977950716211, 0.16098001671414222, 0.17586083031229435, 0.1565316812165322, 0.10449048582344286, 0.14587403455328557, 0.13949538731286604, 0.20818050169656355, 0.20980666121167524, 0.2219693182456878, 0.1756125105725181, 0.09414502765021979, 0.3130806147331192, 0.12550441548228264, 0.16700889885185227, 0.20526349935079777, 0.20295075651618744], [0.03699485317713792, 0.07586146599703258, 0.06030019012189681, 0.015875437041564334, 0.05847265290456915, 0.028763564018112038, 0.008086646013262292, 0.011935991727026, 0.04082681731350961, 0.0941687993585102, 0.02172823961553795, 0.0623530759325912, 0.05346294732824449, 0.027849331926254016, 0.07307176448164449, 0.08477939593215143, 0.011832981629507437, 0.0067660909412699125, 0.03486453502949688, 0.017843334973158858, 0.032372332268184235, 0.08787306581413554, 0.0509785395115614, 0.02696234192098341, 0.07308913935576716, 0.07462398885118385, 0.07946407106975395, 0.04029606393868885, 0.04357122004993501, 0.10316120836162761, 0.0736802374763835, 0.051024443499984286, 0.03302712293882524, 0.0693659060784886, 0.01708273223841623, 0.12222434108656262, 0.11493933522292685, 0.06032670059451654, 1.629617942437049, 10.183591823424063, 29.732128766275224, 44.51126460106143, 39.801270731033824, 24.353408044384373, 14.417657063853357, 25.075065320537938, 25.4379512417701, 12.329635274025703, 5.327902003642052, 1.3796401432444974, 0.18140480943745185, 0.11141285630724124, 1.3909075192866789, 2.0210213334329667, 2.1818983266430516, 6.8483205476114835, 4.697810497976119, 4.389863744858773, 8.988119094602524, 5.588711182917319, 5.029828836840968, 3.9347781000598787, 4.157239737049226, 6.744417452043103, 13.731151088591545, 19.05901828119832, 27.518282244282386, 29.75154842099836, 37.683539928928504, 42.73015945188461, 49.05640517511676, 51.74089101053054, 56.28847522120322, 57.774763261118245, 58.614966330989716, 55.307164884382686, 56.309612874061834, 58.894670547977576, 57.35321044921876, 56.21159676582583, 54.40371751785279, 55.021349614666356, 52.24401735490369, 52.536371215697265, 54.875182490195, 54.18980713813536, 56.67691538410803, 53.21026971263271, 56.516757165232015, 42.762279741225704, 39.08659135141681, 59.058425580301595, 51.95169095070132, 53.41157751698648, 48.854222682214555, 47.18276739120484, 48.746624223647586, 50.20382004399454, 49.609153424539876, 51.75155201265889, 48.84727224226921, 50.800345866910874, 50.74012571765531, 51.63894468738187, 52.69667456226965, 53.454633374367994, 55.686426701084265, 54.56773927134853, 53.71338036752517, 54.17008938327913, 53.47829703361758, 53.09436367404077, 51.661086467004594, 47.40209064176006, 41.95800558213265, 39.47169357730497, 34.551601871367424, 27.67477893060254, 21.32675816935878, 14.261514371441258, 9.593709514987085, 3.253159398032773, 4.67433903486498, 2.9017275331481813, 5.31571961218311, 1.6406177392890378, 2.93659397190617, 1.6658210514053222, 2.4615294894864483, 0.23806206761829315, 0.6479751234573703, 0.08753744269450826, 1.920862507916266, 4.925855138609487, 16.521113380309075, 24.77120714802896, 25.354177259629775, 38.465248692420225, 40.67114653125886, 46.773052292485396, 22.757050452693818, 5.112268722826435, 0.10019729079137887, 0.07689204577717089, 0.010316525905152724, 0.017351571643244357, 0.06464663592557754, 0.0636668592661379, 0.06752924092354314, 0.04872942793994181, 0.02432389297492562, 0.059837235528374874, 0.021182275564980604, 0.013300900895809455, 0.060467607146429445, 0.06220110324061206, 0.16428271368626626, 0.03883013171294043, 0.030915215799224474, 0.05721095971943391, 0.04099405813781966, 0.04718870638058551, 0.12866737801701794, 0.05628432274886197, 0.082250363493879, 0.047247626202841925, 0.01794901680231335, 0.04493482208119766, 0.048350532343911554, 0.00854699399262186, 0.06854269863857378, 0.029693454947142355, 0.01802398999702306, 0.04399142310684247, 0.016734355670069496, 0.05284018679371765, 0.06463260885568396, 0.037382114453301314, 0.03862528746286708, 0.03913431841459486, 0.02400377547488578, 0.09430837291743487, 0.03780116454788274, 0.009837139683264879, 0.05064083263278008, 0.04101479613792993, 0.026958159080916838, 0.031063942193624475, 0.038818356941544244, 0.0163722584669989, 0.08725484052012045, 0.06264022100837001, 0.011182969432294129, 0.004453820687147879, 0.008763815069781437, 0.10530646905423173, 0.06109815879514622, 0.034470432588169654, 0.059567580239907394, 0.1240665757007176, 0.0705810594222238, 0.08193763108142922, 0.015235503688604842, 0.03889036537598699, 0.05878053598045822, 0.09148913871256575, 0.021760273582091736, 0.06156319714782219, 0.11650148809196488, 0.025981203540258353, 0.12466823817380976, 0.08131162233410344, 0.0778740172785136, 0.0919116132201687, 2.363583003321002, 13.999786376953127, 33.82704204128635, 51.516672642000266, 44.65823973378828, 33.70488374463974, 21.791606103220296, 35.45196625494188, 27.927712971164336, 14.850988753380316, 5.435511739023271, 1.6077074600804238, 0.09065722085295186, 0.2031760936182353, 0.39198837573489836, 3.659795681315084, 1.5191176653869691, 5.354461842967618, 6.626612495991492, 6.605616538755356, 10.282389463916903, 5.378682969077941, 5.362390423974683, 7.442546881014302, 8.246302796948342, 7.407614252259655, 17.67752616636215, 21.80241027185994, 31.8980243129115, 32.35551191914466, 42.713607049757435, 46.44442042996807, 54.243649513490745, 54.36683154875233, 58.600955624734205, 59.400511172509965, 61.458841600725734, 57.72422352144795, 59.42367276837749, 59.67329240614369, 59.525968182471495, 58.89180721775178, 57.62838040628741, 57.7109698326357, 55.492281144665135, 54.69628318663567, 57.22566673832556, 56.78107784640405, 57.73382156125961, 52.862280953315, 55.506558572092366, 42.21531306543658, 43.664844574466834, 58.65070696799987, 55.094305699871434, 55.11809879733671, 51.55700637448219, 49.10164971505442, 50.826994449861594, 52.116610926966516, 53.049985977911184, 52.80283743335355, 52.285002200834214, 53.861151741397, 53.263868901037405, 53.65372896194459, 54.61806328065934, 55.9729479974316, 56.02889668556952, 56.25995174531014, 55.50320494559504, 55.20379866323164, 55.68130016326905, 54.8927939322687, 54.56881400077574, 49.5817203675547, 44.37849237072853, 43.162749813449004, 39.381475140971524, 33.75122654822565, 26.44203485981111, 19.35000127361667, 16.058303117752075, 4.035726915444098, 5.913512850961378, 6.630350024469438, 8.169725383481673, 0.4818840132605645, 1.012957796694771, 0.5772900905820632, 1.4342679732268857, 0.35322944423364055, 0.045750962360011, 0.16686613070628337, 1.3439356655843797, 5.608871675306752, 16.98353925058919, 27.2197526116525, 27.68292961582061, 42.93926492814095, 44.33106699297505, 51.61300605343234, 26.927587024627197, 6.343865990638734, 0.11212419958845263, 0.10212109844771125, 0.03564316764353745, 0.017114735561453046, 0.11958773458196272, 0.042208682880887104, 0.03204427809724885, 0.04174939401808285, 0.015501951941499307, 0.04955878323544899, 0.061785324341467315, 0.037042817942077116, 0.02325602769551258, 0.0343549141900674, 0.12219924404616318, 0.02052571714645432, 0.056042614347872236, 0.023219818549771464, 0.024261642585418398, 0.020079040006103537, 0.060363043805644404, 0.054513970164642225, 0.07351532938980287, 0.050479935016483075, 0.03943742110183643, 0.02765918507300798, 0.03888112252518054, 0.01870914839298254, 0.026410645617532636, 0.011520937738579609, 0.038626291038047884, 0.0319419862071593, 0.04559674886085334, 0.06255341941610941, 0.21333694758434452, 0.20679926049084435, 0.10244882320083919, 0.07893424466132157, 0.10126700234268943, 0.12675419600019533, 0.10053072289954271, 0.11667250189930202, 0.14866060276906337, 0.18839526981596025, 0.11224925578121217, 0.13157863470335163, 0.1785048908523975, 0.11056234549370506, 0.1963585239624785, 0.15807734021256048, 0.08460537906015113, 0.16047914842924765, 0.10214332265839463, 0.21536093655853503, 0.21461203964727543, 0.2737112337302777, 0.24752729842739724, 0.19111036202840267, 0.307244035986162, 0.16603570671812182, 0.14539758915141707, 0.15917926576108704, 0.23840375815428075, 0.14437922847367105, 0.1580291992473987, 0.190399861443908, 0.2196519788835318, 0.18113139265727612, 0.18560113265149056, 0.23239989644817768, 0.21594872517931848, 0.1511058788145742, 2.647499355577654, 16.00240934279657, 41.465026409395286, 59.10083424660468, 52.39911963862758, 36.84301130233273, 23.12844595601482, 40.049011553487475, 34.4153622658022, 17.4688894133414, 7.2963567126181825, 2.3380652887205926, 0.21350302012457004, 0.5067176419881083, 2.7536938507710738, 3.8760212400267204, 6.940643825838643, 16.99964254133163, 17.409743993513047, 12.828078308413106, 17.17134625680985, 12.513775844727794, 8.179171921745423, 7.378038600567849, 7.245378157784862, 9.994632620965282, 18.438203180989913, 24.304968733941358, 33.12713823010845, 35.01601049976964, 43.52914233361521, 48.60870976601878, 53.81016877389724, 55.16008384766118, 59.36295840048022, 59.44259428208875, 61.617952546765736, 59.27841955615629, 59.75561511132025, 61.97733971380419, 59.979103918998476, 60.415236180828465, 58.832736322956706, 59.49474219352969, 56.384757641823064, 57.03313719841742, 58.94658703957835, 59.1131151876142, 59.22717378985498, 54.287615360752234, 56.618252415810865, 45.49794074027769, 48.057091159205285, 59.97788798424506, 55.94537373512022, 56.15587949752808, 53.74331197431011, 51.882814130475445, 52.517190825554636, 54.118121900866115, 54.025185262003255, 53.90852220596806, 53.7135176504812, 55.26510138665476, 54.01700712019398, 55.10566880626064, 57.0725570186492, 55.48187117422781, 59.08688237590175, 57.87701945151053, 56.396324711461226, 56.78243498648367, 55.46667983455043, 55.6061004823254, 54.27642091628044, 49.136535275367, 44.71062690980973, 45.8643058038527, 40.301086594981534, 31.02556955429816, 24.935846674826838, 17.155566561606623, 12.417487540552694, 5.96704928144332, 8.677419327920484, 7.281382574189094, 12.055200761364354, 8.151348098631829, 6.421689737227656, 4.713088620093561, 5.084088944619702, 1.9551095799092326, 0.9515806708124377, 0.32729819537170474, 2.5387945434739514, 7.581997927158111, 21.64783750810931, 32.70396940169796, 34.79998596252934, 48.86539359246531, 53.280134970142, 58.39325043462939, 32.239717668102635, 7.492488459233315, 0.32197802117274654, 0.273832336909348, 0.1137890695263782, 0.08728269547704728, 0.15903038423388235, 0.2827911529569857, 0.21156725383573965, 0.262659250968887, 0.1531291783096329, 0.14042837515233025, 0.2944435647899105, 0.1259235958118112, 0.20928362234225198, 0.18239208226723058, 0.23040713321778084, 0.10731418632091054, 0.18573579558682057, 0.23733076008577503, 0.10367342240868077, 0.13565353298139188, 0.23215598937484527, 0.19752202765835872, 0.14538395278636487, 0.2178430154679283, 0.14909004101589804, 0.12171775012487367, 0.16261483302279828, 0.17310663697219666, 0.15562610400299873, 0.12927552925482874, 0.19869136894422196, 0.1799973067376883, 0.09170859992023438, 0.1742990681480977], [0.02249213652835498, 0.07025657522101557, 0.043257300201202595, 0.03427482735846312, 0.1026538742946521, 0.10769707706546593, 0.05776880196325722, 0.0712963940215207, 0.03430453624816672, 0.007009923799834665, 0.041516602880531744, 0.014771504342676172, 0.037019471412584666, 0.05395812357986166, 0.023060719324876706, 0.10460699247496744, 0.058063676866192016, 0.025025217741307233, 0.05862826834462824, 0.06070383801876057, 0.06430730494039674, 0.055753780048220396, 0.04465678962127817, 0.01774007015140547, 0.023628846299083486, 0.06115248208985694, 0.09004693989071155, 0.0682617512141024, 0.11263733294101493, 0.06786441205129509, 0.1262574339465749, 0.07887324874079035, 0.026484580763104944, 0.07377502553525471, 0.006629608068314772, 0.011517359150363313, 0.09388255826648205, 0.013964977509702646, 0.2506493978322514, 5.841508430819358, 27.767148786975493, 41.16827557163854, 40.84364060432681, 29.321417385532012, 29.202330304730324, 28.32398218493308, 33.133923930506555, 24.598265924761375, 7.674147150208873, 3.129221816216746, 0.4689228474613159, 0.19194008121567388, 0.09222893449928492, 3.6278984767775384, 0.8326322212815286, 2.8912280836412987, 2.371659408653936, 5.213573738451927, 10.961944018640827, 4.830788162446791, 4.017507015697418, 4.266765550259621, 3.243481194780719, 1.302233883930791, 5.435330819699073, 7.728146420371148, 14.07512628263043, 18.606204179025468, 25.895842852131015, 32.74692916101025, 40.56562692888322, 44.516155796666304, 52.07891302724039, 50.780734016049294, 52.14777808035574, 56.14291214173841, 57.224140936328524, 56.84205893547305, 57.17973970597791, 57.60377930056665, 56.039267432305124, 54.83524883947065, 52.962356305891475, 53.72441791719007, 57.509159964899865, 55.3026855376459, 57.49501197568832, 53.56340854398666, 55.78763169627036, 47.156322771503085, 34.3260734311996, 56.38216103276899, 53.71646727285078, 53.84901592808386, 52.11415944560882, 46.49803138548329, 44.32827034304219, 48.02205654882616, 46.34790266713789, 47.040887417331824, 48.673817188509055, 48.632651913550596, 50.69770920661188, 50.612629075204175, 50.677646283180486, 54.090881040019376, 54.46711870931811, 55.67715421799691, 55.36442756652833, 52.026506239368075, 54.16179357036468, 46.95070035995976, 44.354475698163434, 39.50879527676491, 35.67383904610911, 29.075980955554595, 25.244009648599935, 19.540098944017966, 15.123905308784979, 7.281124678350265, 4.014562051142416, 4.995114880223428, 6.524065069613918, 4.9234821046552355, 2.138831437595429, 1.240565644637231, 0.09314521396112058, 0.293681736314489, 1.18141544442023, 0.15395480658738844, 0.09850507917543573, 0.7154786238266576, 2.4748844244787773, 9.78078794094824, 21.58302818575213, 22.18884022005143, 33.62491838393673, 47.24653728546635, 41.66774626701109, 37.223520432749105, 15.275103853594873, 1.6727799489613504, 0.011300004684486458, 0.029883912065997723, 0.01449054925732555, 0.05289801111024234, 0.030568907668273297, 0.027260057094897476, 0.026000146979406, 0.05426654674773736, 0.021292381551897815, 0.10267883343922515, 0.016589342886882446, 0.04166398287540482, 0.02424049855870826, 0.026360819258937435, 0.037579922185790156, 0.04685001890926112, 0.11056152577962607, 0.05306087757250475, 0.045181942893372434, 0.08769490440646488, 0.048957446349724654, 0.04543415435980405, 0.05629028674335249, 0.08921286932403043, 0.014470237393623159, 0.04169591342008883, 0.013019634587239596, 0.04833417253628854, 0.020728291861051996, 0.023598587741294218, 0.08191139257002263, 0.048666696830262104, 0.02510070421492621, 0.04011779527870878, 0.039478954558651295, 0.04916252425661491, 0.0526061890676858, 0.025668520923523654, 0.011442301685981935, 0.05587559185862061, 0.016074305805828304, 0.052399601967584704, 0.005757275719060413, 0.022560270473120675, 0.028838939408981995, 0.004237177725430698, 0.05223534505573973, 0.06599786946730268, 0.051164020889348565, 0.01903310782396265, 0.02929340191786328, 0.03030737865746262, 0.06844057911826719, 0.07288054893574408, 0.13211071341028138, 0.028930008110980836, 0.08638050437213914, 0.036693240530909076, 0.027913643092277552, 0.08732710559401782, 0.05012018012724096, 0.060174061406043276, 0.016214055564975547, 0.06157913177664723, 0.03586200065910816, 0.09599042620750205, 0.04812976112589241, 0.010434729441429579, 0.014633517543364678, 0.0038607314561358505, 0.059561011035956686, 0.016084500520880667, 0.3931734831102433, 7.43821511345525, 32.08870837765355, 47.91132019412133, 47.10894446219168, 31.20771069680491, 24.041157960891727, 27.980464927611816, 34.89615463441418, 23.264948360381588, 9.156527038543455, 2.7054817926499153, 0.5463156849145889, 0.06805483086575424, 0.07421461444708609, 0.18952396247656117, 0.7626654111569928, 3.125741938429494, 6.764861825973758, 5.286918628600336, 6.2871200807632945, 2.7990190444454073, 6.531170443181069, 6.0485223031813105, 4.156074302811777, 2.409623784403647, 7.212516050184927, 12.482363543202801, 19.10238596700853, 22.6884070134932, 31.254894848792787, 36.47942327683972, 43.83190224247594, 48.15777447915847, 54.509539142731704, 54.79492687409925, 55.590301175271314, 57.06967407657255, 60.13210381231001, 59.07458574541154, 58.193597870488325, 59.853042864030414, 59.471431547595614, 55.699652933305316, 55.894249562294256, 55.85788919079689, 59.79342675978138, 57.08175497670328, 58.80917072296143, 54.23208244385258, 56.773586119374926, 48.791233339617335, 38.26405463680145, 57.4296574438772, 57.201175458969615, 55.53778848340435, 53.140498592007546, 49.2102248437943, 47.557620463832734, 50.43439265220396, 49.7815651278342, 48.48019722969302, 51.610735001102576, 50.43447109960741, 52.910765371014996, 53.39130278556578, 52.639564852560724, 56.12222556144961, 55.59524728405861, 57.25752422886511, 57.517628362101895, 55.01458352611911, 56.25071456355434, 51.59177818605977, 46.676871853490034, 43.688253279655214, 36.990041348241995, 33.761365875121086, 27.689328962756743, 23.38222526734875, 16.708051581536573, 11.45312870702436, 6.011266160395838, 4.841009368819575, 11.547336193823046, 10.530132247555642, 5.057983609937853, 1.2638385377583967, 0.15390297307843162, 0.12917103486195688, 0.3974013691467624, 0.08800858676794075, 0.13263300151353882, 0.6948470792943432, 3.899445634695792, 11.204370029510992, 22.93869737655886, 26.48638706053457, 35.40492919183547, 49.735696931039136, 47.942671698908654, 43.02887147472751, 19.457689946697606, 2.2944696151441146, 0.054752920649104544, 0.020960186675731695, 0.04668859269229635, 0.029747820376688917, 0.07177662389773516, 0.016790804858770103, 0.01840005681339291, 0.0483112205420771, 0.033723891397277196, 0.05213256286937864, 0.03924217593345431, 0.038435722836443496, 0.04163109089037584, 0.033092340003819234, 0.046468710136269374, 0.030680745013899384, 0.08481091278935633, 0.01839694266598071, 0.0356157761698048, 0.053722386834241694, 0.04675918003363956, 0.03202418744143459, 0.04579956680836697, 0.09640415965188896, 0.08589448287121712, 0.03641808856158488, 0.02813012804836035, 0.08229219955542395, 0.02936677207359143, 0.04707761980112522, 0.03926051607836158, 0.050524877564560984, 0.014918869015790764, 0.053831634802683714, 0.05609072083907743, 0.17435319992082735, 0.10220702286929854, 0.1425480638300219, 0.18325918654520668, 0.25913052741558323, 0.23436632157573778, 0.14394595978721497, 0.10929618601597126, 0.09843211696152726, 0.1740519435054833, 0.10184444111561584, 0.08642219487697848, 0.21657864863593734, 0.1594455885670839, 0.16795146279037002, 0.1097063265079933, 0.08148422194344383, 0.18423417132467995, 0.1869236915222099, 0.2771555343943258, 0.1394112095717461, 0.1425837175620179, 0.2426168740156197, 0.17809598376193356, 0.19421893232051404, 0.28831418723829333, 0.12631639207322753, 0.16320191684269136, 0.17301659099757674, 0.18418348694760955, 0.2493901484675946, 0.2371357447437702, 0.28281741445103004, 0.14470945833431137, 0.13971196036906014, 0.2112686634063721, 0.13635321640439574, 0.45068747273856596, 9.284320800535141, 37.186654075499504, 56.68299505787512, 52.880217952113, 40.42736730267925, 40.66275658146028, 41.295893807565015, 43.47435858941848, 32.47269076685752, 10.333452840005199, 4.011835758724521, 0.8433064001221812, 0.48715111288812857, 0.4861248615047624, 7.388208816128393, 2.0611170270750603, 8.736557883601035, 9.58073921741978, 14.95089936640955, 22.59172647230087, 10.81071017249938, 8.720891937132805, 7.8285434073017495, 5.470832682424977, 2.9277367697608088, 8.44565628036376, 11.805708600628762, 19.097029970538234, 24.64118646037194, 32.65191758832624, 36.74461080181983, 44.07048433057724, 47.59163918033723, 54.603797620342625, 55.12158970679007, 57.01319979083154, 57.34864873270835, 59.6812391281128, 59.37391358037149, 58.476510586277136, 60.82877166809575, 61.65770184609198, 58.03150984548754, 58.31514819975823, 58.08514825759396, 61.41993561098653, 59.29179876081405, 59.62656128791071, 53.951966377996634, 56.43688986378332, 51.44938045932401, 44.18002828474968, 56.925519127999586, 59.13127183914185, 56.44384814846901, 55.92747203765377, 50.06727841592605, 48.588599774145315, 51.94760384098176, 50.48466959307271, 51.177552361642164, 54.47478694300498, 52.53955618027718, 54.601165709957, 55.34188570514802, 53.368345152947214, 57.3211686072811, 56.937588261019805, 57.12507363288634, 57.526006544789965, 54.949107400832645, 55.19067441263507, 51.26686080809563, 47.03855752944947, 44.47619861172092, 37.62075454958024, 34.507651713586625, 29.13593634482353, 25.975659162767474, 17.650332373957482, 11.138681115642672, 7.778407671759206, 8.10616974869082, 18.37824975290606, 10.854260248522605, 13.139410557285434, 3.5693563665113146, 0.32076806190513796, 1.4091189614226742, 2.760766129339895, 0.5024759970124691, 0.3650169326893745, 1.3721201016056923, 4.326607681089833, 13.95888880375893, 29.211808712251727, 31.53632686984155, 45.55021416756415, 56.295096182054095, 55.47784682243101, 50.41794223170127, 22.967413048590384, 3.2297769236949185, 0.273556545256607, 0.12260307197368915, 0.10701715871090851, 0.23494353818316616, 0.12039041086550682, 0.10252829716210404, 0.1382041614382498, 0.16992369486439615, 0.2464456742088641, 0.13524652578898017, 0.1908680330961943, 0.13586920205383532, 0.11828144741875511, 0.2188494098522971, 0.2488228910031819, 0.11425316559090731, 0.25891449062093613, 0.22566290392029673, 0.10426325648422204, 0.1783396456871302, 0.09708993091818788, 0.198514019589751, 0.2083312218347865, 0.2617557881580245, 0.17721440042218856, 0.16818724933170504, 0.14091906978959037, 0.11036477907891236, 0.146434152078244, 0.16214209548648328, 0.2153281020301004, 0.1568734483613122, 0.12016888888132189, 0.1443960977297637], [0.05963690353617553, 0.02845240208590704, 0.06411125537969413, 0.0536143952499955, 0.022705221969273784, 0.04102244935629349, 0.02646001423859308, 0.03424337178829216, 0.07174784197441994, 0.09034086484462024, 0.06005222278256571, 0.04184800485569624, 0.02493359362556329, 0.024881911418971517, 0.025903558613912716, 0.028596890098865957, 0.02802419532541066, 0.015394822206167925, 0.04264910682855595, 0.027121973576985543, 0.035679621937414335, 0.04467476587442141, 0.09197192732244731, 0.007053723919295496, 0.07850970937720231, 0.03532722149224531, 0.03693428243540468, 0.06322222566532512, 0.01719007073270698, 0.03586031909611437, 0.07988301391202597, 0.05336087760365298, 0.043340531823736046, 0.04067027873750176, 0.05165341317713742, 0.05194854088908723, 0.00372801773576817, 0.03782006010653512, 0.0935194479121316, 3.2946203216429684, 15.676680034206761, 35.216412236613614, 41.23370462848295, 38.48737086019209, 27.76209677419355, 29.156138512396044, 23.642947173887684, 18.16457275421389, 14.325973622260557, 4.122398303401086, 1.002734445275799, 0.21145716700102055, 0.11725158776126562, 0.7273863267994697, 0.6235013721931366, 1.9003358867860611, 6.965690120573967, 4.658049431539351, 3.7475699907349007, 0.8491311198280704, 4.837981789342819, 3.961067786139827, 2.0392624384933904, 0.9065275915688085, 1.2634941046276402, 3.2324313877090334, 7.240258484117447, 9.527548936105545, 15.36960453756394, 22.209052193549372, 29.40959030582059, 35.74230009509672, 42.53788094366751, 49.11729997204196, 52.127966188615375, 52.30003664570471, 55.389377763194425, 57.33876435987411, 58.369614231971006, 56.747682786756954, 56.18936869405932, 54.283249762750444, 52.18835892215852, 53.26282947294174, 55.329451791701786, 55.99229704949164, 57.47762803108462, 56.23739419444915, 56.22558001549014, 47.60305719990885, 33.80999149814729, 54.40350570986348, 56.123931792474565, 54.34716870707851, 52.23341518832792, 49.40714743829543, 47.896980008771344, 45.74868609828334, 47.51057555598598, 48.243823435998735, 50.08063016399261, 52.6777099024865, 53.852859850852724, 53.10325960959158, 53.611124177132886, 54.80059077662807, 54.820943955452215, 51.726637117324344, 50.65715582140031, 49.01591062545777, 41.863574520234145, 37.997670788918775, 33.03598234730382, 27.36943614098334, 25.051586012686453, 22.56823931970904, 12.666037351854387, 7.487629132886087, 6.496438345601482, 3.604349546855496, 3.30104933150353, 1.6648218276039248, 5.335020124912263, 5.787507689768269, 2.7567689889861695, 0.5319439980291552, 0.32287756161343667, 0.2396375887216099, 0.32700349666899253, 0.06732773681681964, 0.26601888359554354, 1.2322563485753153, 6.148344172585396, 12.081783644614681, 24.194436342485492, 21.832081041028424, 35.31852329930952, 45.65655354530581, 36.26277508274202, 30.75543788171584, 7.458916402632191, 0.18540513671694264, 0.029008227603269682, 0.04744394772475766, 0.10816602246655573, 0.015401071568410245, 0.02487776879852097, 0.020743510197667826, 0.03710691651870166, 0.022469559917226437, 0.01159481446994769, 0.03192070811506241, 0.014651500499777257, 0.028239151936084516, 0.11826597244268465, 0.06947385552789896, 0.03205965731232878, 0.07102903699682606, 0.04122748129790829, 0.03786245924270442, 0.01308069562524437, 0.022092439729960698, 0.014608699167447706, 0.013143478445858966, 0.04253569900268509, 0.014316826371566184, 0.05345642025912962, 0.05052909104814453, 0.05263422022483522, 0.007619020198622058, 0.046491359525750724, 0.03852484184467504, 0.057953980736314296, 0.059388714031346386, 0.10796873950429502, 0.05475085987258823, 0.06554822948190474, 0.04338600680292134, 0.0386890949260804, 0.12025946345660957, 0.031121816305864244, 0.005407394745552372, 0.06941731823908706, 0.06836073743479867, 0.03280899472414486, 0.0538932704066317, 0.03352708723996917, 0.027687486276150714, 0.019711036265136737, 0.015343720311178796, 0.104627424039908, 0.018382136101624178, 0.029805005009796832, 0.020491428966183337, 0.03448447114938209, 0.033009954908442114, 0.0240483962660355, 0.01164878727943306, 0.02013408150824328, 0.06804420522624446, 0.05479400977492333, 0.06798222871317018, 0.005133415369557278, 0.050214906899078246, 0.04314967633916005, 0.02245722973208514, 0.06762710099499072, 0.03966283481267672, 0.030103769724167166, 0.02977424274919735, 0.04563902925339438, 0.012613545742727095, 0.03879203799090559, 0.08643248343780156, 0.11743677419520195, 4.02656989712869, 20.6229692505252, 41.59949702601279, 45.84982833554668, 41.16370601038779, 29.720963739579727, 34.486098289489746, 32.21556763495169, 24.500308652077955, 15.950024127960207, 5.051577398853918, 1.0324753268111138, 0.22276600372166405, 0.26659050776112464, 0.17011422093116468, 1.1315999949170699, 2.156954013532208, 5.115813564869666, 2.9385831038798056, 2.504477236540087, 2.5332740526045523, 2.336533603168303, 1.3930563652707686, 2.1901882560022417, 1.6358143067167652, 1.9978047018089604, 4.419513431287581, 9.181189921594436, 11.153481198895363, 17.539233200011715, 24.056990608092278, 33.183377173639116, 39.36365581327869, 44.96796577207504, 50.769923963854396, 56.31144069856214, 56.57505535310315, 57.939440050432765, 59.50756049925282, 61.35525964921521, 58.68234088343959, 58.5672075517716, 56.28586684503863, 54.94710306967459, 55.816323834080855, 58.211605471949426, 59.340177274519405, 57.59169055569557, 56.32675755408503, 55.00949621200562, 49.60682745902769, 37.69340468991188, 55.92138844151651, 57.587889778998594, 56.77735159474035, 55.159958331815666, 51.377616774651315, 49.686835965802594, 48.72141515055011, 49.75463413423108, 49.79024925539571, 51.345437649757635, 54.330581003619784, 54.619577315545854, 55.458062387281856, 55.988272697694846, 56.14900750498618, 57.207717972417036, 56.248368986191295, 54.459854479758974, 51.79571005605882, 45.96688755096928, 41.10090101918867, 35.67441563452444, 30.428586775256743, 28.00485618652836, 25.927174745067475, 16.41022993672279, 10.656370789774003, 8.650120612113707, 4.813289488515546, 1.1675465563612601, 2.5445638597011566, 7.746370242488, 5.59563220508637, 2.1694014101259174, 0.2287933843270425, 0.12704752340552308, 0.09139477200205288, 0.032849712297320366, 0.020139951656963077, 0.22939836396084679, 1.3023823211269996, 7.416965673046728, 13.220526153041472, 29.30898347208577, 19.877532605201967, 38.71468790115849, 49.930364162691184, 41.88513971144154, 36.05409714483446, 9.687866991566075, 0.40907639589521194, 0.07333668534673991, 0.05918063689023257, 0.06303977033483886, 0.04368105790607872, 0.041490398843081734, 0.03230718798154304, 0.05182322422643343, 0.07355610058913309, 0.1183019555924881, 0.03830256526388469, 0.04936777453328814, 0.06065016589878548, 0.07956288109022765, 0.03693463483584985, 0.057748312941722335, 0.11304132940788424, 0.06177437311458973, 0.06926035448428124, 0.021852225200423313, 0.039899375950617176, 0.039948386425573024, 0.020412215474812735, 0.06055111456061564, 0.018193705285328533, 0.037479036067041664, 0.1123245545632897, 0.06124285365184469, 0.003594519014680578, 0.021507129403612307, 0.039055851858950434, 0.018474489916116, 0.056813482660800226, 0.04121504003001798, 0.016784360144107092, 0.13642487626883293, 0.15717707964922153, 0.10233398662098955, 0.24891575618136316, 0.12373341172332726, 0.1732616165592786, 0.12956040671035168, 0.07010190206910334, 0.13382370133073102, 0.3139700734567258, 0.12176370773945125, 0.16426205995582766, 0.08785259594479877, 0.10900370896823945, 0.26679376620919476, 0.0880858927003799, 0.11077877299319352, 0.10503044757511347, 0.13036688279000022, 0.264264848684111, 0.09895475746522989, 0.17821471206843856, 0.20141853470235102, 0.27207315388706427, 0.1874284515337598, 0.13161136197947687, 0.10229625679071873, 0.27105073294331955, 0.18240282281992898, 0.19936733428509007, 0.1161067306454624, 0.2695142670023826, 0.18732631669169475, 0.09964509461555751, 0.1588764924916529, 0.10165378481390015, 0.12276101632103806, 0.2612017227276679, 0.22339928264339126, 5.288217423423644, 23.35361549931188, 48.632906867611794, 55.021118194826194, 51.46884718248921, 39.27799124871531, 42.20271833481328, 35.762806246357584, 27.692043242915986, 17.848614069723315, 6.301638243659851, 1.13615264094645, 0.6679410295140359, 0.6495779632560669, 2.629791815434733, 2.4121436620912244, 6.234825080440891, 12.321786611310898, 11.99051989663032, 12.504884812139696, 5.976161437649881, 11.79605858941232, 9.420200528637055, 6.606075946361789, 1.1795293972376855, 2.738990601032011, 4.74108845956864, 11.040256100316203, 11.99503944766137, 19.80043645828001, 25.005649174413374, 33.51004000632994, 38.64008049811087, 45.95397903073219, 49.9062611979823, 56.08040525067238, 54.883964677010816, 58.99203946513515, 61.030914937296224, 61.380398119649584, 60.378848352739894, 59.57145198698967, 57.56512826488864, 56.888256611362586, 56.18913335184897, 59.85906370224492, 60.89906054158365, 58.33081414622646, 56.690922167993364, 54.68985442192324, 51.64754252279959, 43.94266605377198, 56.668097895960656, 60.48538384899017, 57.341502174254394, 57.741195617183564, 52.77473757343908, 52.17284987049719, 49.72329439655427, 51.63892115316084, 51.006897880185036, 53.85793147548553, 57.1178250928079, 56.77032662976173, 57.030873990828, 56.83915245917536, 56.78848720365956, 59.832787744460575, 56.56058965190765, 52.9067410192182, 52.42041418629309, 45.59245024957965, 41.82724160532798, 35.955759402244325, 30.536620616912845, 28.010084705968058, 27.17098382211501, 17.85264430507537, 9.998284347595709, 9.028640120260178, 7.728396471469634, 7.234225388496154, 5.297620815615501, 11.637345763944811, 11.13200524160939, 10.071203170284148, 1.9630802038215824, 1.2293263380565953, 0.9591349106161826, 1.0330109754877708, 0.28686257319584973, 0.6697162084521786, 1.283978192556289, 8.453552011520632, 16.590245154596147, 35.641703067287324, 31.39779071654043, 48.42091060453846, 56.19502082947762, 49.826566480821185, 40.68718118052329, 11.876319108470796, 0.7928740966223902, 0.15567069032019185, 0.2082355987400778, 0.20245797811977326, 0.13434343070032137, 0.18593025934551993, 0.12107389152891214, 0.10471482701118916, 0.09767760462578266, 0.24582140448112644, 0.11410172533003554, 0.0762920227322367, 0.28526053012859437, 0.2715548187974961, 0.16196519046300845, 0.22651198981029375, 0.17804724524819082, 0.12365888669005326, 0.18210930389262017, 0.14170411072911757, 0.11188003970610519, 0.08980563751632169, 0.13252884419935365, 0.14247527015545677, 0.11451686837620313, 0.1409742127983801, 0.14366443779680038, 0.1891611892008974, 0.16584144214228277, 0.1459863277212266, 0.14015837512429685, 0.1603695518908001, 0.13007131074705433, 0.17453451761074606, 0.13690637785100168], [0.07345819455241004, 0.025558987587329843, 0.015608844189574162, 0.03938891241447099, 0.014407833786531082, 0.011227938793449393, 0.07168444053780648, 0.05619353749939511, 0.06924255060092097, 0.047407386178571376, 0.034682121833846453, 0.046138051266391436, 0.004017386621149678, 0.04195869689987552, 0.07259071489135105, 0.04837397080395491, 0.03988602686853659, 0.037194016885252736, 0.01790826667040106, 0.051074304332536076, 0.04847247055881927, 0.17139340390361127, 0.05115539090888155, 0.09278126091005341, 0.1129214289868551, 0.12006157528488867, 0.06688898294082572, 0.01282644349210445, 0.024250767967333237, 0.038508156449684215, 0.052811006504681804, 0.06183884324385755, 0.06733637828860553, 0.028271251020111868, 0.03988372094388451, 0.053477556624960516, 0.021946005853674105, 0.02592313024515827, 0.07524409106061344, 0.8901610117285483, 5.671953193603024, 29.343431688124134, 48.46978333688552, 42.1978271392084, 30.81323204501983, 18.31391895970991, 15.734577159727774, 20.763237130257394, 16.655146652652373, 7.8342004456827725, 2.610629321106019, 0.3301639157918192, 0.18055673478351486, 0.1223760188346909, 0.6020100318616437, 1.01107646861384, 5.375468096425457, 1.5430704768626922, 1.1761564040376296, 1.7097281856882958, 1.5498653703158902, 1.2554281180904758, 1.8093994115629506, 1.5268729266620453, 0.4158821065099009, 0.6187864993849109, 1.8681789477986677, 3.552816221790929, 6.726942802629163, 10.985756727956957, 17.804403074326054, 26.7702038826481, 34.949236069956136, 40.30515409285023, 41.74494243437245, 45.34463097972255, 47.587803102308705, 53.311847332985174, 54.24174716395717, 55.6423431827176, 57.54646562760877, 55.00597000122071, 54.403070326774355, 54.03938031965687, 55.38541224695022, 56.01890248637046, 58.52250037654754, 56.14519103880852, 54.66372359183527, 49.76785644408196, 37.654514389653365, 57.36939414854973, 56.42212998482489, 55.59529435250067, 53.869722120223514, 51.65104912173364, 49.32603282313193, 49.262910119948856, 49.93713025123843, 50.89689500870244, 52.49589627788913, 52.15261828514838, 54.30318324796615, 52.59559508292906, 51.67115126886676, 53.654391842503706, 48.51374526177683, 46.00212612459737, 40.43086213450278, 36.20799526091545, 31.562993103458037, 25.490683586366718, 22.375207716418853, 18.67307862927837, 16.26907265955402, 12.184586025053456, 7.142773366743519, 3.7534407982903146, 1.4492991085975402, 3.221562990257817, 0.4276405142680292, 3.3000042650007435, 7.7908165800955995, 2.0312704866932285, 1.7128499020491879, 0.1709648236752518, 0.11075892365507542, 0.0811609558220352, 0.0514791971222768, 0.22791396135524397, 0.8545624380630832, 2.284835293408363, 6.425092883648412, 19.709019737858927, 24.519506692886356, 23.411054688115275, 40.585034816495835, 39.82669945686094, 35.013880652766076, 20.807669739569388, 3.0143657470903094, 0.12430688982168514, 0.04596697234158074, 0.02559352857661584, 0.054554235745942405, 0.03898168688700084, 0.0433644337669736, 0.02538755434685417, 0.022485170873903462, 0.03839086838847688, 0.016398125425762227, 0.10118983430607666, 0.03805874246022394, 0.01460049915382819, 0.03987329065679543, 0.018647145066830902, 0.02395255483626839, 0.02122670674936906, 0.041093649567976114, 0.051975668062486, 0.028499020451319315, 0.042126286294191115, 0.05974517474251409, 0.05914607100308903, 0.032363648661562515, 0.024794703800111048, 0.05491332796913001, 0.018879158625138864, 0.05143184522767702, 0.004401096600979086, 0.03975814764177607, 0.010010039024505644, 0.02820464159031549, 0.014266721348488524, 0.0673742613364612, 0.05156006536356384, 0.009608207713632334, 0.017604702415185112, 0.06690595944922778, 0.08915642396576944, 0.06083642485581579, 0.04987563337049177, 0.03142073423781943, 0.09343183043623164, 0.06018785098868032, 0.05977025646115503, 0.03443376762011359, 0.015218761794629599, 0.017140569961479595, 0.06132496295556907, 0.06170796095243385, 0.01725727005020505, 0.037745060098748055, 0.03926059268715401, 0.017664093381514954, 0.04481620868788131, 0.07613401709785385, 0.12296230592314275, 0.07152127147081398, 0.049696307509176196, 0.08332878546488863, 0.09882617726801865, 0.04680840884365382, 0.026933293782114506, 0.03445994484448626, 0.04837029358191837, 0.08363255464862432, 0.04634409061362667, 0.09311616390703187, 0.13408148991725138, 0.027956178209053415, 0.033896805102666544, 0.01757430213112985, 0.037209173934834625, 0.02021995996455512, 1.2958703286224798, 7.956160172339409, 34.58525188507573, 54.79412671058409, 46.17138424227315, 32.107975059939974, 22.111263582783362, 18.45388089456866, 20.030406982667987, 20.19061423117115, 8.086877570998285, 2.5851498496147896, 0.270385860555595, 0.029339411243375753, 0.09367845712169524, 0.3358449174031135, 1.5229776453587318, 1.9120714957675629, 2.355343084181509, 1.290499623264036, 0.919605938176955, 1.7588205707650033, 0.49879761052227795, 0.7708999370374988, 0.949686288593277, 1.0797550865719396, 1.4839202766456914, 2.842286219519954, 5.017095352372816, 9.444855566947691, 14.196400084803182, 20.50926366159993, 28.463863711203302, 38.006386295441665, 42.3137527896512, 44.5356656659034, 47.341380196232954, 51.70704095594345, 56.31024829802975, 59.4331649041945, 60.30364474942608, 60.933495029326416, 57.68864762398505, 57.45152465758785, 56.444032499867106, 58.472752955652055, 58.106595777696185, 61.205550624478256, 57.12424601277998, 56.598962199303415, 51.019877003085234, 42.07428032352079, 57.39963562257829, 57.66820815301711, 57.94438615922005, 55.916375652436294, 53.57941181428971, 51.19197491676577, 50.84194260258829, 52.02931857878163, 54.113681777831054, 55.16853263301235, 54.513477202384706, 57.0799389193135, 54.491123614772675, 54.45563793182374, 56.13007422416441, 51.314023387047556, 48.76792661605343, 44.2025819132405, 40.71243732206283, 33.36395132926203, 28.215152102132, 25.237969198534568, 21.127811631848736, 18.50851558869885, 14.478901932316443, 7.544759435038413, 3.922306924097, 2.290883588214075, 2.176753402717652, 0.28961825274652053, 0.6694538386598711, 5.773948546378843, 1.024303497566331, 0.5685302735336366, 0.10940821871401803, 0.16073309125438814, 0.05139329568332723, 0.026170706879647992, 0.08320887738298025, 0.27864560605056826, 2.242429323734776, 8.169385117869224, 23.124578499024917, 26.40945173078968, 24.884169447806574, 44.385901727984034, 46.32690621960548, 41.114797976709184, 24.22481902184025, 3.9761990645239433, 0.0930208855518891, 0.05281339286856594, 0.08365061134099962, 0.049740089434048826, 0.055594770838656736, 0.02811936068258459, 0.05003579171194185, 0.07143081946959419, 0.08420235552494565, 0.07002148581969161, 0.1220093385106133, 0.02232420239447346, 0.024489094090137272, 0.03639657298223146, 0.0602457442531182, 0.017815062498313286, 0.05237229859396335, 0.02160702535371867, 0.1780367651653867, 0.06333213246938202, 0.014160957164882172, 0.058613965483081926, 0.04341805226079399, 0.039035454767966465, 0.0072489298256714985, 0.05811751752551045, 0.01777743417469244, 0.036582785973986315, 0.03240307154614599, 0.06293016996595167, 0.022128834652023453, 0.048290363798338565, 0.0233798083518782, 0.08463845873672156, 0.03774745029307181, 0.1607022791980736, 0.10778725327503298, 0.11333914608844828, 0.3070969164611832, 0.1495307713987366, 0.14510702732349598, 0.17076098300035925, 0.1505925999053063, 0.25025582782203154, 0.19985209940181625, 0.1183881481448489, 0.08647493236968595, 0.10795857351753982, 0.19751491836242138, 0.15735510316106582, 0.15027920865724165, 0.10258938501318617, 0.2199852577741108, 0.12180824043048967, 0.12525896857222243, 0.16052900543135984, 0.2741303451118931, 0.14928646595968356, 0.18953972856604284, 0.149131088006881, 0.23542903874429966, 0.11179370925791803, 0.11924321718153455, 0.16446285160078158, 0.16313902102410793, 0.1259316857002916, 0.1157329103819305, 0.24745766103508013, 0.24165226206664117, 0.10649674752306555, 0.32783491657145564, 0.1544889230881968, 0.13919321159201284, 0.16444745323350354, 1.6285741016749413, 10.533408407242069, 40.29292806502312, 62.37198898869177, 53.67266224276636, 40.90935991656396, 29.29934032501713, 26.655502011699063, 28.92979225804729, 23.245585580025953, 10.877883703477922, 3.436160520199807, 0.5439886775228285, 0.3187784089917137, 0.3659901707883804, 1.3853114002173947, 2.7651464362298293, 9.324727096865255, 3.604784194500216, 2.2712869365369124, 5.655257624964561, 9.03562488094453, 5.89139215407833, 6.75587861768661, 4.6700965012273485, 1.7013789304802496, 2.3262702313161667, 3.923573604514522, 5.851744346080288, 8.34664487069653, 14.536242081272988, 20.755043298967426, 29.599705626887662, 36.64420597014889, 42.631966836990856, 42.574453123154186, 47.65899412093624, 52.928486639453524, 56.65946475921139, 60.94595639936386, 61.08844826298376, 62.33487159975114, 57.5510940244121, 58.1201240324205, 58.06103352577456, 59.21720312487695, 60.29816519829535, 61.44181851417788, 57.62159862825948, 55.02509940055109, 53.8287490414035, 47.204462020627915, 59.7886218563203, 58.845593852381555, 60.04506249581615, 58.55610724418395, 56.24840036515267, 52.71490573883057, 52.44124981664842, 53.940211034590206, 55.62737149576987, 56.606767715946326, 58.2684955289287, 59.18277255950436, 55.061448004937944, 55.07751403316375, 56.24322283652521, 49.54578753440611, 48.18451719899332, 41.87940128387944, 39.94983050131029, 33.67405391508533, 28.204769588285878, 25.034000066018876, 20.458537609346454, 17.837986407741425, 15.544883493454227, 8.209299156742713, 5.668240670234927, 2.997795939445496, 6.677834237775495, 2.3617017365271047, 10.485772202091834, 17.307723145331106, 10.009022816534966, 3.9679674804210667, 0.20082527621378823, 0.4630717436873144, 0.3360894526685438, 0.1278179703700927, 0.9201917809344108, 0.9625280672504056, 4.0976491282063146, 11.425453443681041, 26.865974433960456, 36.69454959131057, 34.02461574923608, 53.21977361556023, 52.73441560806767, 48.09435759821246, 28.32295648513302, 6.033291739802207, 0.30941108421933267, 0.1458404492586851, 0.17246125386126582, 0.11787801019607053, 0.11855877124734464, 0.07748911938359661, 0.12784076148584006, 0.22850449257079633, 0.17162234161890325, 0.1376478130658788, 0.2834545238123786, 0.19245214970602145, 0.16302708025661208, 0.1924285695197121, 0.10758918124221026, 0.11855188411690536, 0.17153205049614753, 0.14420736430873796, 0.2008844948103351, 0.16464072189504103, 0.12238014804860278, 0.2085932392266489, 0.1159869987637766, 0.17808964055392051, 0.08876213383290077, 0.1323491812593514, 0.14144701162172904, 0.14945024023613623, 0.13921961098188354, 0.09674290074936806, 0.10460484742877946, 0.13878640358246144, 0.17968307279290693, 0.19479389662944502, 0.18175117310977754], [0.01164130260041284, 0.017342669701564218, 0.04157680973050095, 0.026249374533372543, 0.03923373747496836, 0.04917781154114393, 0.024256113345824906, 0.013466635399738388, 0.029957163478097612, 0.03930476914730765, 0.017961806640209212, 0.028712891132360505, 0.04073965949036422, 0.0208549338558148, 0.07829233958956697, 0.04192138075708382, 0.02834829265221713, 0.049153212457895286, 0.05265986118766089, 0.014658602134835337, 0.032214357277318355, 0.031076831622950496, 0.036564246646218726, 0.07343620782898319, 0.07832136666101795, 0.022772176138636087, 0.008337851989293292, 0.026706669652353854, 0.04372354897279893, 0.05249994033346734, 0.034260750492854465, 0.016986626508315245, 0.05177384219883431, 0.04392650098569932, 0.03339647690975859, 0.029522552222554243, 0.026079383453414328, 0.03583465515065097, 0.08826361743793373, 0.12406727284072869, 5.114775607662817, 19.66668167421895, 40.363016897632235, 46.976078094974646, 36.74683870807771, 26.2117858471409, 30.07117256041496, 29.73043037999061, 24.96079294912277, 13.693647346188946, 4.469688390531848, 1.7738167725263105, 0.23635194486668035, 0.5746548706966063, 0.6141981230147424, 1.4354987394425178, 0.9711258413810885, 0.7733131752860162, 0.026093533097375787, 1.0335635393857956, 0.4928284372773863, 0.05514327309004242, 0.433724478127495, 0.9437009968584584, 0.047095810558887265, 0.021504438519778273, 0.14209412609136876, 1.134671455910129, 1.7054188491836673, 4.1068061465217225, 6.30788657934435, 15.53579536176497, 20.278889133084206, 25.305934067695375, 29.936527398324785, 32.583995865237334, 39.48660250632994, 45.34938097000123, 51.54522749685472, 51.907058300510535, 57.00518246619933, 56.29126794876591, 55.49316367795391, 55.97895314616542, 56.252467863021366, 57.68337988084363, 55.962891040309785, 55.62335498871342, 56.369833023317405, 50.421425296414284, 40.67976397852744, 52.11060970060287, 57.92340932353851, 56.672322288636245, 53.68849292878182, 52.27755754224716, 50.21496349765409, 49.16953809799687, 50.087533535495886, 52.70879860847227, 52.5553515649611, 55.292891379325624, 57.739532532230506, 51.414361538425574, 46.87872486729776, 47.160354968040224, 42.55983052715179, 35.9392423014487, 31.663142981067782, 24.532564263189993, 19.76178542260201, 17.52736803024046, 13.206017305774074, 11.071015327207505, 7.556656964363591, 4.674696951143203, 2.3638176100869335, 2.0008489513589494, 1.4947618303760406, 1.6023955902745648, 0.1440581457028466, 0.5864025532237945, 1.3843875594677464, 1.2715548204798854, 0.18964489711628807, 0.12369561294514327, 0.008356839478496582, 0.1427494989888322, 0.39274104179874547, 0.09264315057906414, 0.6513673607860843, 4.879500077616784, 12.631000780290174, 18.679238711633992, 29.319848437463087, 30.965996596121023, 45.26398312660956, 44.00976996267996, 29.617436701251616, 11.529423709838621, 0.8104640882342093, 0.05393792950217763, 0.03183704939851117, 0.014459013247922545, 0.03622570090116032, 0.045129994471226974, 0.017356679534479495, 0.05159079698064635, 0.03714871810629003, 0.058988233908049525, 0.0385956360297578, 0.027198645571667342, 0.03186764886542674, 0.014559166795093448, 0.04996738389074322, 0.04654106331027804, 0.05180995558358489, 0.08242644114239563, 0.0339662203294856, 0.01466948249857993, 0.0526071198645138, 0.07855651734937584, 0.0748735573142767, 0.05242371458500143, 0.028891466227510286, 0.02619225310251838, 0.03363220982493893, 0.04638588070989617, 0.039761326906661836, 0.09047370449069048, 0.0669565212522303, 0.025394278683609543, 0.08474502156698897, 0.048925477500644424, 0.03106655072300665, 0.04243167575388666, 0.0304873863370308, 0.054277298791754636, 0.025539163147069277, 0.034793671896500934, 0.06549346951707717, 0.06921517827938642, 0.040259862453826976, 0.033984935857475765, 0.03352923994703639, 0.07137857993403751, 0.062231421170215455, 0.046572216275718906, 0.060606284382482695, 0.017810460225108172, 0.07076559468142449, 0.016510807383324833, 0.09377387337266438, 0.09448235914591821, 0.04956035371569376, 0.0657188525844005, 0.055684866608991745, 0.009282763987298935, 0.03444244739629569, 0.02798102244043783, 0.10281923437310804, 0.041328076303245566, 0.04952326739927934, 0.01818673388521758, 0.0765930186776865, 0.09945947151150435, 0.018245716909727743, 0.05080470650066292, 0.03839015209626767, 0.05467129398077246, 0.03637754718863195, 0.04494321457440815, 0.029396042377958377, 0.045706241977431124, 0.04992560528579259, 0.2240972806729617, 6.892160388731188, 25.457727832178918, 47.45162233229607, 51.61657541028915, 42.35049363105528, 23.71755457693531, 28.311259977279175, 29.238522014310284, 25.717104365748746, 16.210705830204873, 4.2617959072512965, 1.5250230388295267, 0.3208977146254432, 0.22930395128505848, 0.2610895674555533, 0.616294936307015, 1.486328979653697, 2.208005622509987, 0.41322632482455623, 0.31872257650379215, 0.20302800882247188, 0.033444165883045045, 0.16155704946046875, 0.3990811854600907, 0.15735358630697574, 0.29807757946752733, 0.6713483434530997, 1.2313747958790873, 2.0413504877398094, 5.861294336857335, 8.313597921402224, 16.86524841093248, 24.411037468141128, 29.630539378812237, 33.043889845571215, 36.72649729636408, 43.94138343872563, 48.45918509267992, 54.691317465997514, 55.68765048057803, 60.70655845826673, 58.45190163581603, 58.66485887958158, 59.18986812714608, 60.36430420414094, 58.56450896109305, 59.00418312318864, 57.23404492101362, 57.968516580520145, 52.72677090860183, 45.195980994932114, 54.17371365331835, 58.641956160145426, 59.26205150542721, 56.80133688834406, 55.28011229730422, 53.02301576060634, 51.31080312113608, 52.44318354514338, 55.77067136764527, 55.247964551371915, 56.5636569453824, 58.26730705076649, 52.81967224613313, 51.05386041825818, 51.65488127739199, 46.95482277101087, 39.51480042549872, 34.3116783326672, 26.536562019778838, 22.57295204747108, 18.74533457140769, 15.415459986655945, 12.965103368605337, 9.31833363348438, 4.693250742650801, 3.813877413349767, 2.428846585173761, 1.707411168083068, 1.466098497471502, 0.8850863227440465, 1.9574049019044446, 1.3474070857609473, 0.2904209596735816, 0.14154865616752257, 0.05565994193837528, 0.0920081862639035, 0.08817265215780466, 0.3186605233819254, 0.21391843896239035, 0.6594425403783399, 4.099815747430248, 12.322683853487815, 23.618777528885875, 31.894692259450114, 33.76975974728985, 50.64487488039079, 50.56865538320234, 35.456410300347116, 13.686381155444732, 0.931086838245392, 0.09712101110527593, 0.07561599610433464, 0.04089302263192592, 0.050723152610683636, 0.01468181555655094, 0.051283113087617585, 0.034514141734689474, 0.017243126151903022, 0.08140612694044268, 0.03936875281074355, 0.08057194912145216, 0.057752729438605814, 0.042641365510081096, 0.03558157800486492, 0.04199909271612283, 0.033424753215043776, 0.05986502919826777, 0.07045521415890225, 0.03963829318602239, 0.023140541856147112, 0.034807572561887004, 0.074210983190325, 0.03434482481210463, 0.020400216622698693, 0.028254885466829426, 0.06618601300062672, 0.009219305094091163, 0.0208222716971631, 0.11136889052126678, 0.0352160046778379, 0.012144265178170417, 0.10275540392725699, 0.07938362417682525, 0.06813425886174364, 0.017977011570286368, 0.13360846126752515, 0.1316227307242732, 0.1235308044499928, 0.10289541415629849, 0.1355693092749965, 0.19344599557019052, 0.16589059434350462, 0.08416674009734586, 0.1034912696829246, 0.14434469323004448, 0.09350565832949455, 0.0806980625155472, 0.09363744843510852, 0.27222955839768537, 0.2723624593307895, 0.11755187890582508, 0.20341154308088366, 0.23951789514432031, 0.13248764399078586, 0.21352577293592118, 0.1287511114271418, 0.1854704533733668, 0.1393886252997383, 0.18416376784443858, 0.2449504237982535, 0.19562171591866404, 0.17772843009762226, 0.11740522669448007, 0.18090643859919042, 0.25890937315360196, 0.2104491178667353, 0.16115813215653743, 0.24471495901384663, 0.1232314019674255, 0.10853116295390552, 0.1403460513439871, 0.15812489895089982, 0.22510709180947275, 0.18789420234820536, 0.42572262847135145, 8.236194849014282, 29.16719763509689, 52.039983503280155, 58.772108247203214, 50.561034217957534, 37.30534499691379, 41.3827625397713, 40.125940999677105, 31.593824894197528, 17.65630026017466, 5.498247598448108, 2.6044393306778324, 0.531179687428859, 1.218327031500878, 1.116653435653256, 3.0103928764020247, 6.239527021684955, 11.563096277175411, 1.9078164595750071, 2.003584314257868, 1.55378173435888, 0.7626101915394107, 1.768449989538039, 2.7069124771702677, 0.5594363195761558, 1.0073867440223694, 0.8491769012424254, 1.7441165855815335, 3.211866891191852, 5.936046867601334, 8.382949348418943, 17.301113951590754, 23.51505437204915, 28.69406761661653, 35.405191990637014, 37.1873208784288, 45.60735133386428, 50.88355895011656, 57.345369631244296, 58.44957959267401, 63.36742770287299, 59.72798985819663, 59.97616998610958, 61.47975175611435, 60.54760048466345, 61.415570012984745, 60.54510585723385, 57.87111236203102, 56.929727831194484, 53.50299227622248, 50.210892077415224, 54.50159242076259, 60.47456987442509, 60.8329725265503, 58.82167523907077, 57.19876712368381, 54.10759425932362, 52.01601389915713, 54.140138164643325, 57.14739976390716, 56.519447911170225, 60.11931688554826, 58.625858752958244, 52.67465437612226, 52.26072272946758, 48.32398883758053, 46.0828681145945, 38.928107984604374, 35.1548388696486, 26.634352591729936, 23.14728706113754, 20.674305231340472, 16.829472472590787, 12.574214666120469, 10.827010562342982, 6.113504700122341, 4.511297383616048, 3.056356190673767, 3.1956876045273197, 4.29588032345618, 2.3731731983923146, 3.560280247080711, 6.383479968194039, 4.726750235403738, 0.32705905336526137, 0.3470761340952689, 0.21239593114343383, 0.3195488482954041, 1.0701656269450341, 0.5252703916161291, 1.498217561071919, 7.902706601927358, 16.42125081631445, 28.144537671919796, 39.14545436059275, 43.588554474615286, 55.774032838882945, 58.15849657981627, 41.84312720452586, 16.92552347337046, 1.5653318887756718, 0.222229435739498, 0.11744285693332074, 0.16473236133254346, 0.14171423841147654, 0.12578291142539633, 0.12264172877034835, 0.1434760720979783, 0.20868457222898162, 0.3354814240048009, 0.14019715449502393, 0.18032058051997618, 0.19054517300138551, 0.14505275765493994, 0.17104245902549836, 0.21781730555718948, 0.1414448206102656, 0.17648448716969262, 0.15359411707087872, 0.12513690778324682, 0.14381025497230793, 0.23530517764870199, 0.16339765230734504, 0.12601293698554078, 0.15517326943095655, 0.11170198555074393, 0.15674148205547564, 0.1265415529750528, 0.084313775352653, 0.23899995842047278, 0.18682889580245943, 0.1707485723759859, 0.2219288841250443, 0.18971965197593937, 0.17431518663802456, 0.15524543491342377], [0.0561653646159797, 0.08129758760333061, 0.06298863013545353, 0.010654575608280158, 0.06530785407390326, 0.028562870049368472, 0.10135454320979696, 0.025298125073013288, 0.015578530090410384, 0.04388931124741512, 0.017033083995263425, 0.051713409352927446, 0.0735927732180684, 0.07533429025281822, 0.010780153698438119, 0.029921172667414914, 0.08075283014125402, 0.013390906650813357, 0.08263931399391544, 0.0647438831266857, 0.04350877239278728, 0.04924762896412323, 0.05183952274702249, 0.03519818164227951, 0.06019850344126744, 0.02848289047007359, 0.009817659982570238, 0.07674549315725604, 0.026161264845981236, 0.03579771439094217, 0.018782968625366207, 0.10319457149073001, 0.05045242096868254, 0.023680191426988573, 0.061376195085505326, 0.030807971150704452, 0.019458439839523167, 0.005925028864669824, 0.03537667629819724, 0.020461302558561007, 1.1772113990399147, 12.608776630893832, 35.16029488655829, 47.33752450635357, 36.54456207829137, 34.79086252950853, 22.851257939492505, 22.446077100692257, 22.639006722357966, 16.338124025252558, 8.94478572953132, 2.578588950057184, 0.7316772771939155, 0.3068045466657608, 0.34421455054994554, 0.45319619618596574, 0.5693729702503451, 0.635251138479479, 0.4761556980590667, 0.3621191591505082, 0.0791251231285353, 0.09474064568958937, 0.0642286545236505, 0.020740447761190516, 0.06454054806982318, 0.125616371571537, 0.907621626411715, 0.06966478762126739, 1.2105826793178436, 1.5111334357530841, 1.9589619602887862, 4.97486662480139, 11.738947899110856, 16.614973737347512, 22.83311893863063, 24.756176625528646, 30.64157343679859, 37.31994405869515, 48.278838434527, 52.820786199262066, 54.02469104336154, 56.388648633034, 57.1090115270307, 57.874458143788004, 55.818747858847345, 56.12030360006518, 56.50792398760396, 55.813362444600756, 54.49738371756769, 52.13877624081027, 42.16867608408774, 51.232069384667184, 55.966205443105395, 59.310355494099284, 53.128515751131125, 54.873358588064875, 52.178509850655836, 53.57702701322494, 53.21865181769095, 53.71683989801715, 54.064099096482806, 54.53181036057011, 54.29293017233572, 49.2241100342043, 39.9081592405996, 37.95347744418729, 31.583873841070364, 25.055598597372732, 19.190390225379698, 13.535651333870428, 9.316775471933427, 7.580899173213591, 6.098891419749107, 4.102474869258942, 2.714399546384812, 0.7963567936132032, 0.29654810024845984, 0.1158544502311176, 0.08208813671503337, 0.9265595037610301, 0.5103576321515345, 0.42299180081294435, 0.14369993831121153, 0.03549546206129655, 0.06797243044861863, 0.02609662809258988, 0.14197020370873714, 0.03251897298821038, 0.06121064348506832, 0.8913661599639924, 4.076960341584298, 10.041143105876062, 19.608742383218583, 35.741645059277936, 23.023628457900017, 39.0067397394488, 44.23595343866656, 42.94561524544993, 22.962721893864295, 5.099287148444883, 0.1782822503798431, 0.04759199038568524, 0.054245402721027215, 0.03769754349524456, 0.09147347987539346, 0.01686571868166568, 0.0305672797314342, 0.023389570227253343, 0.01630251190715259, 0.008744176405842507, 0.057420507749362346, 0.023958229632567496, 0.029432755226509708, 0.006000637433551733, 0.01593477629695929, 0.06858328597680216, 0.047022748753548636, 0.03819641229065676, 0.022254371564955484, 0.013494860951698596, 0.09434036474915282, 0.049524883844799576, 0.015346409279793022, 0.09619821989608389, 0.03586418017925274, 0.09938392758129105, 0.040787505511675155, 0.06715559686023383, 0.06906035957076857, 0.010227536174258398, 0.04392848132298358, 0.08820298923960618, 0.04756172608223654, 0.04274335096500093, 0.02287356979063442, 0.03144088426544782, 0.03821144676617077, 0.03441300280692597, 0.026362788104902835, 0.05760348018919749, 0.10225299580563461, 0.026770178341276707, 0.06262747330530997, 0.03457769638888779, 0.0432010501953623, 0.07061838322589475, 0.025079108196340745, 0.028460039982512116, 0.03415809471100088, 0.1367194064322018, 0.038632626585181684, 0.06543189903060276, 0.0363630949399404, 0.011296876172925676, 0.023404058865121296, 0.024074770758048664, 0.006849555263010365, 0.046209010160377914, 0.08309636204954117, 0.017784853736239097, 0.05421327299348289, 0.02401978288206362, 0.015377561287623982, 0.049490417549086195, 0.07604728062306682, 0.012881780895704945, 0.0068551812212043, 0.03892252191660866, 0.05575955635116947, 0.02365087324212636, 0.09003864315849158, 0.026173635250738552, 0.027359660016372803, 0.020985063465852893, 0.023262058722696478, 0.07821199228806842, 1.9808739135342261, 15.927236137851594, 41.97041596135786, 55.41717560060563, 41.58521959858556, 36.046064130721554, 27.412019352759085, 28.79308589043156, 29.499418466321885, 18.65892671769665, 11.033110522454786, 3.459386099730769, 0.5347842843301835, 0.07537909107463014, 0.1570803074226264, 0.4880859853038865, 0.2886242383430081, 0.46570365407293846, 0.20482338183829862, 0.10177304938195214, 0.09915635350250429, 0.09437698375193343, 0.035910846425160285, 0.18575647996077616, 0.3807339925439127, 1.0415053583921925, 0.3748092217551124, 0.5489367474952053, 0.7884367927908899, 2.503110290535035, 2.852027916139172, 7.208321075285635, 13.47816703781005, 16.431933391478754, 23.383470619878462, 25.364718629467873, 33.20662113928026, 39.763545374716486, 52.01594329649403, 54.88960896768878, 57.38123186172978, 59.71150021399222, 59.04932175913165, 58.837356875019694, 57.864632606506355, 57.96149946028187, 57.48399796024446, 57.51202329512566, 58.02083707624867, 54.243382792319025, 46.65410641700991, 54.82284630498579, 57.635291622531035, 62.60665655136109, 57.372790921118956, 57.05929156272643, 53.82446581317533, 54.96257682000437, 54.10685685373122, 56.178629244527514, 56.56190756828555, 57.31473592019851, 56.83696769898938, 50.8661828502532, 44.836311417241255, 40.560594527952134, 32.96616808060677, 25.472224912335797, 21.807258321392922, 17.87882024242032, 10.988425900859218, 9.17412377172901, 8.320048259150598, 6.400206915793881, 3.987745051422427, 1.5002003191940247, 0.3006675388784178, 0.42092483430620165, 0.4984464051742708, 0.9321373592941993, 0.47777281773667185, 0.6396368386283998, 0.03691576992071444, 0.045511981232031706, 0.10279493406414987, 0.03517548245708308, 0.06463558127683017, 0.11653610760526312, 0.047259374161160765, 1.0238151624798775, 3.5280371385235942, 10.836491911642014, 23.061832343378377, 35.06655416181011, 28.555201984220936, 44.1181097492095, 50.105650963321814, 47.78720463475874, 28.640068346454253, 5.918384434715395, 0.3036776209069837, 0.05719512468203903, 0.06162325461064616, 0.007463537866339809, 0.05003557337688343, 0.018698128218191768, 0.032340164236243696, 0.06426266499704893, 0.0454317833176784, 0.020336278924538244, 0.069226807494077, 0.03675676071115079, 0.08100768461102441, 0.03159616262682023, 0.061093416710894924, 0.07736777105639059, 0.08855044841766359, 0.07346960160160258, 0.11049223312687491, 0.10491898944300991, 0.03210763548380666, 0.053944525519205686, 0.03405139015446748, 0.011897551350205416, 0.024216045032165224, 0.12589648396017092, 0.05605548462500015, 0.039804725787572326, 0.04075545622336288, 0.05608848003189891, 0.08670160246472206, 0.04124575249490239, 0.020520762472804037, 0.03850116589737516, 0.03778796102250776, 0.008367604929052534, 0.1310060605887444, 0.13438027952947926, 0.09051157221678766, 0.1993175692135288, 0.2650097925816813, 0.11695498916050119, 0.1961866751193039, 0.13798954956714185, 0.1076279529520581, 0.2744316321707541, 0.2295486857333491, 0.17135788806744162, 0.12922217889178184, 0.26341372500023535, 0.21011763162189917, 0.2711334091521079, 0.14474327345528912, 0.06547666154801846, 0.20674232483631183, 0.14562790582497276, 0.07862095300468706, 0.1752302786635776, 0.1907837787462819, 0.14897212476259278, 0.14603505091321084, 0.13019923210865067, 0.18659811947614918, 0.11833219308285944, 0.10990884951165608, 0.10238048049711412, 0.14674576600232433, 0.2640915902391557, 0.11913490767079978, 0.1433294581910295, 0.15576015406798932, 0.11052079288469208, 0.09219326544553043, 0.10417828967254009, 0.0990591369449131, 0.2119266410027781, 2.3985229865197213, 20.15754080587818, 47.281850384127715, 61.29620444390082, 49.750711764058764, 46.67483222100043, 33.05634729323849, 34.89916309233635, 32.59910287395601, 23.040608398375973, 12.023926723387934, 3.4647548439041262, 1.4629268934649806, 0.5962477023563078, 1.2645911425352097, 1.7895209621037207, 2.3749706245237783, 2.710133723674282, 1.676995393729979, 0.9003754152405647, 0.5773130119327576, 0.38711575010130483, 0.2721115195703122, 0.46377194805010674, 1.126497726767294, 0.8973491227915211, 2.480566222821513, 1.2588800489902496, 2.8526726557362467, 3.075013679842795, 3.070011186984278, 7.746088812428137, 14.651736270996834, 20.177231104143207, 25.690096885927264, 27.04768999930351, 34.66351493712395, 43.09730506712391, 55.23322820663453, 57.751389857261415, 60.24207922720141, 62.4817604403342, 60.93821364064371, 62.27262750748665, 60.31906358657345, 58.79728201896914, 57.930042051499896, 58.047513115790586, 56.83772471643264, 55.778382747404045, 51.22143191675986, 56.690188684771144, 59.10085385845554, 63.435480825362674, 59.11392711823987, 59.12621198161956, 55.18152744539323, 57.081139164586226, 57.176590042729536, 58.67969720594345, 57.97733406866751, 58.06674449674545, 56.56239001981674, 51.0931037318322, 46.12828523881974, 39.86178898042248, 34.16018855187201, 27.152472196086762, 22.36729825696638, 15.652858499557743, 11.818860307816538, 9.37237604971855, 7.71987610286282, 5.451164937788441, 3.5224661471382266, 1.9820378768828608, 0.9646595077168558, 1.0543513658546633, 0.5132133934286334, 1.6392912427263877, 2.008390320885566, 2.0871902473511237, 0.5363347237148594, 0.10272977062531057, 0.2786488542633672, 0.2672487917927004, 0.21597589065711345, 0.2984503578514822, 0.2289102893442877, 1.4615916941435108, 4.906380570703938, 13.24801706498669, 26.804850178380168, 44.316962149835405, 34.906662664105816, 51.696917318528705, 56.02722575587612, 54.00576560728012, 33.42702304163287, 8.00343208735989, 0.556403898423718, 0.1965462308256857, 0.1531339740200389, 0.10850408940666145, 0.157450741577533, 0.14358787496964778, 0.1250287131857007, 0.11115952635244017, 0.12829761035860549, 0.10306115727871658, 0.1791563873449641, 0.17293043674961214, 0.16469509881590644, 0.10039664219103514, 0.16379701394227245, 0.129943895003488, 0.16388519066235713, 0.15576341760254678, 0.2323012090017719, 0.19220384528800366, 0.09801194071769716, 0.21673172832496707, 0.17042695334361446, 0.2213464734414893, 0.14542653195319638, 0.2540126157503936, 0.10648122658171963, 0.12998422187182213, 0.164055154929238, 0.1273572221097927, 0.20558635944560652, 0.22193810782365261, 0.11100841550937585, 0.1363666689083461, 0.12482285003868804, 0.14115101056954554], [0.04154726554970107, 0.0729613252464802, 0.015947557516366003, 0.06348574458951912, 0.04493086906750837, 0.0396255876177982, 0.06912107969964705, 0.0889740260918775, 0.04275443625726527, 0.053336443229308056, 0.038639429445949294, 0.0311644759119278, 0.02945422675580748, 0.026895799523880406, 0.030627844727508007, 0.07443000772787679, 0.0853274935375779, 0.03079687628234106, 0.004467617451859218, 0.06292792532833354, 0.06927342394426947, 0.049189023237915776, 0.08977382954570556, 0.05633457428625515, 0.055425882925309485, 0.01637775706307542, 0.08167395893965038, 0.036318202187577565, 0.036293672052242106, 0.034398960415273905, 0.037925967931627266, 0.0610550586885262, 0.047738546836039716, 0.03516907030115685, 0.09923432593143756, 0.03269449139254228, 0.041127847732915994, 0.0790562901285387, 0.06970405728826601, 0.15241046526258992, 0.6373635186783729, 6.260669577506281, 25.359337137591456, 34.68805720729213, 47.36616565335182, 23.996346842858102, 16.94343693794743, 17.888586944149388, 22.728052370009884, 33.33423545283656, 9.657173464375159, 6.89674073649991, 1.7062255091244176, 0.5348695958814313, 0.09807291365559064, 0.19920956613796376, 0.18268702611807855, 0.14011610239263506, 0.08370196221456414, 0.10223847077859026, 0.017999819923012007, 0.035357945448448586, 0.015153178922651757, 0.10992673766468802, 0.06049221389055733, 0.37213143802458243, 0.3290765918791294, 0.5468100874174027, 0.4936575282725596, 0.6699638080693061, 0.874115024362841, 1.8232694027885314, 4.319394442342944, 7.804360034004335, 12.825711158014114, 18.732314263620687, 23.72242812187441, 30.244441301591937, 38.71221680794993, 46.718856903814505, 52.32656755755025, 58.84018098154376, 58.89005784065493, 59.720792308930434, 58.28419677672848, 54.92157628459316, 55.38791079674998, 53.94384707173994, 55.02159280161704, 52.61637972247217, 43.3810846267208, 50.870960297123084, 57.877148889726215, 60.19107664785078, 56.219974948513894, 54.25583631761613, 53.41555872271138, 53.87463292767925, 53.960670117409, 54.423039113321614, 55.48320085771623, 56.2105102692881, 53.32475977559244, 46.2395981819399, 33.7655431993546, 28.278529759376283, 23.304536842530776, 17.77465974130938, 12.221439634599994, 8.783955804763302, 4.89017088567057, 2.804911425036769, 2.909155276513869, 2.170355526670333, 0.49112432065509987, 0.31130972588735245, 0.3659671268636181, 0.3185007480844375, 1.393040920938215, 0.07092048999883475, 0.2726826534396218, 0.32214677502070704, 0.07558549048318979, 0.1275485985341572, 0.10063082760860843, 0.059900820826090155, 0.07572537813816341, 0.051933131030490326, 0.24486708875385024, 1.805386091432264, 8.63218459390825, 23.73014342400336, 29.519852053734567, 22.376103978003226, 22.463410054483724, 42.047902384111964, 38.45325800680345, 32.112550504745975, 14.447055228294866, 0.7862452910311761, 0.13171764901809155, 0.06880447854317966, 0.06839096726429078, 0.0070771144988435895, 0.06563944757104882, 0.014211540992912507, 0.07993290155765512, 0.022739776365098455, 0.014625474577769639, 0.10669843549089086, 0.040467085406905225, 0.03518431162041041, 0.05468782615817843, 0.029681390977554747, 0.0147684131779017, 0.029198744093939185, 0.00836491787565812, 0.08457072890333592, 0.06729927665043263, 0.022822827956969702, 0.04066905682726253, 0.0801603913667702, 0.016776611164752996, 0.022588860874454823, 0.10303066697933021, 0.011366959811458665, 0.029801277992045207, 0.025801599972070228, 0.0450471344013368, 0.03995419720247869, 0.0709511181940475, 0.09358425128964648, 0.06402201762783431, 0.03323423480915447, 0.058225666157781124, 0.04458998292384129, 0.026069144688306317, 0.020243170513441006, 0.06130877551772903, 0.060670053541299805, 0.036395270632760185, 0.04587770394620396, 0.05567669245083967, 0.031434429974685756, 0.032825304736052795, 0.043370213900362296, 0.05720190456016891, 0.02798432044895186, 0.07607436183119014, 0.03536073400849297, 0.040994923817174095, 0.09764038041354188, 0.05680946069919775, 0.03408072366108818, 0.0010869988041268962, 0.035706415862566045, 0.06430423292782038, 0.05531594547773561, 0.048328637551035614, 0.036474150875883724, 0.033537954197175084, 0.06127891724088019, 0.025072439400959882, 0.003603424786800339, 0.10473531986316366, 0.08113191342882572, 0.06797573228757228, 0.03770387904237836, 0.06987146282147977, 0.020099281964282838, 0.05730172964714228, 0.027281775687550826, 0.032693330769336996, 0.01574593562362415, 0.013894124910415662, 0.057906625011274894, 0.5523615282389426, 8.463041205560009, 30.502827436693256, 43.677909989510816, 53.18630795325003, 32.35847330862476, 21.767783587978734, 20.079781778397102, 24.662551610700547, 36.49662287004533, 12.392936445051625, 8.008230616969447, 2.4627517980913964, 0.6346086665026603, 0.10431424729646215, 0.12394708130628833, 0.15462450532903596, 0.11005979181537706, 0.08469875751724167, 0.11973805635446504, 0.11142945743256039, 0.022121861336692687, 0.020753245259965622, 0.16550522147407457, 0.1802833946121316, 1.1407749090463886, 1.3086534555881255, 0.8621354929862485, 1.098151860698577, 0.9617947066022504, 2.3181384225045485, 2.8027904033660893, 6.469616688066914, 11.15350571370894, 13.615288196071504, 19.54213269295231, 25.80809354782105, 32.56120689453618, 40.907045718162294, 47.892304543525945, 53.81911962263046, 57.64672925395351, 60.9019866297322, 60.98621168444234, 59.6984112647272, 56.48173824433358, 57.42503296944403, 55.14881095578594, 55.534854550515455, 51.96577225961993, 45.8992737339389, 53.63385038991129, 60.067388626836966, 63.03779171359155, 59.7752465740327, 57.6965747341033, 56.37604213530018, 53.998477843499955, 55.19628340198148, 55.82002655152352, 57.09707575459635, 58.84671172788067, 54.45023682809646, 46.78093233416158, 36.46344354075771, 30.55453996504507, 23.85829706345835, 20.044990354968657, 16.591521886087236, 11.580877361759065, 6.653323346568692, 3.2869998918425654, 2.1262045925663364, 1.7405826526303447, 2.4823964988031695, 0.12540234958813076, 0.35290866789798586, 2.064076945666344, 1.3985229235502983, 0.22737166303540432, 0.2643759620766486, 0.08297914293624702, 0.08067650480135795, 0.06344941670014974, 0.08518014418622179, 0.021288962884535714, 0.07176006107681221, 0.17830393066810024, 0.3231208404946712, 2.952503105325084, 10.86821408041062, 21.870906622179096, 30.07987237745716, 30.431918828718125, 26.47348246266765, 45.85990490451936, 43.75393729056082, 38.27730440324353, 17.358168748117265, 1.3919998993796687, 0.08784459032599004, 0.0440537290377242, 0.03710021707980383, 0.05713854908883091, 0.020466563667381005, 0.04577953743958666, 0.06607019582823401, 0.08449778967206517, 0.06252811936241004, 0.03343095852723045, 0.05253031188922544, 0.030469509675317717, 0.019543224705323096, 0.02436923580394397, 0.051486248961619796, 0.023333467693338474, 0.04412967516409774, 0.06577814012886056, 0.03395885056365402, 0.06449748626759937, 0.06638853600428951, 0.039736723992973566, 0.01142293594086603, 0.0358551709852632, 0.06650867391257517, 0.010046690586023033, 0.013041271783050992, 0.03774495284643866, 0.08253540182786603, 0.034305290844772136, 0.04784527054477123, 0.11738310207522686, 0.00400386373287127, 0.061997772014189156, 0.009069736960584359, 0.04139189908821737, 0.08389520023258464, 0.13476332349161949, 0.1292671329311786, 0.13931160281983115, 0.1586693116734105, 0.24461689975953874, 0.1805353915739444, 0.25661205932978665, 0.13193613729409634, 0.13731684776083117, 0.1656226321093498, 0.1019116729918507, 0.17424577907208474, 0.0759579700928542, 0.1567370847107903, 0.24021440696331764, 0.13706166387325333, 0.1435289781300291, 0.062231470965930534, 0.1383620368376855, 0.22569886408746245, 0.12277404747663007, 0.12846205113155226, 0.11343573445394156, 0.28430904892663805, 0.1631787809873781, 0.22102402703415966, 0.09908064103294766, 0.18660204184632148, 0.1497571197368445, 0.1176024407088276, 0.1983542136487461, 0.2267611828903037, 0.12501605741319158, 0.3169477346443361, 0.13188801165069305, 0.12078153705524823, 0.08706440638390281, 0.2233980722244709, 0.22963320055315573, 1.1465881067898966, 9.523399068463235, 34.91380922255978, 48.41925928669591, 61.98139544456237, 35.79071783250378, 30.596564239071263, 29.484615441291567, 33.70388746261597, 40.935494669022106, 14.162199958678215, 9.604670578433621, 3.102019198479191, 0.9376648368854678, 0.3041262726389593, 0.7252114951129883, 0.39390454549462567, 0.6358423132088877, 0.2709138789965261, 0.193433232545372, 0.2193142413612335, 0.19620359034067203, 0.15749371911008514, 0.3295215970325855, 0.2296592168990643, 2.4967222204131465, 1.6365411709393225, 1.501539440885667, 1.1189697178140765, 1.9405953393828486, 2.4711169879282675, 2.611184581633537, 5.842308104038239, 9.287519493410665, 15.289603875529382, 23.190550804138187, 26.332651722815733, 34.90070458381407, 43.140643335157826, 51.74907699708016, 56.85207666889314, 60.410027273239635, 62.17233642455071, 62.61423064816383, 62.486537887204086, 57.295559452426055, 58.407390579100586, 55.665136075788936, 56.31626129150391, 55.09634140999087, 52.21756489046159, 56.96454671121413, 61.55576336768366, 65.49248941483037, 61.1059263444716, 59.0930522641828, 57.81725429719495, 56.186364158507324, 57.47964805172336, 56.94418176527947, 58.77020197529947, 59.67612043503792, 55.62538285409251, 47.52327619060394, 38.695711474264826, 31.979350736064298, 26.880620564183882, 20.57994673329015, 15.284769554292003, 12.707740972118994, 7.566335903060052, 4.534681083694581, 4.650366488964328, 3.657805813897041, 2.5727335868343233, 1.6369167378833218, 1.2541602119322748, 1.3568935831708293, 3.452286119422605, 1.10057404685405, 1.2827376204152263, 0.9941554862645365, 0.5124481635228281, 0.21774613598902381, 0.19234618442433496, 0.34155064833260357, 0.20575676804348347, 0.37095926221339937, 0.5821813474739752, 2.888250759532375, 10.740825303139227, 25.905223200398108, 35.417225822325676, 32.28035342308783, 33.14788756832, 53.3706005157963, 49.8836761905301, 43.87365979533042, 20.90723518402346, 2.8163926928274097, 0.33160930920031767, 0.2024432385881101, 0.19702096019060383, 0.16894023715248033, 0.12254497952639096, 0.14107614845758484, 0.19093926395139388, 0.10097661671499092, 0.10578429341436395, 0.18700953933500475, 0.16716928701967965, 0.1275019744230855, 0.1938376963258751, 0.13760212358207474, 0.18442998339812602, 0.12890819009513627, 0.20021242119612234, 0.22075952751742256, 0.20415780464968375, 0.13385314975054036, 0.1573199090818244, 0.28936532115744007, 0.09035802521412412, 0.1323419340675877, 0.24879623114341692, 0.08505789187526511, 0.13394204659327386, 0.21188678910895703, 0.2012813436768709, 0.09692418779576979, 0.15701860670120488, 0.2013569259114804, 0.18912653138320293, 0.15566381085063183, 0.14455688426331167, 0.1294718163027879], [0.1025261061506406, 0.0407717815570293, 0.06070713985771422, 0.01922038567793225, 0.059521561338295864, 0.031286984862339114, 0.017185581457470695, 0.013925461736958356, 0.04521922456220754, 0.04054683515982282, 0.08214341761964945, 0.048132101524501085, 0.04523002257150027, 0.09588452987372877, 0.04663662894839241, 0.09533863094064499, 0.031869738370240215, 0.06111081456765533, 0.03671047367876576, 0.035065721209731796, 0.04429250332196394, 0.01617535854870033, 0.027227280023057136, 0.02226450116253428, 0.012000938746026688, 0.08357794024050237, 0.11313438610804659, 0.07078905229366596, 0.0686888682145265, 0.0799699648914318, 0.029666664852430264, 0.06398934014742413, 0.01604680612217635, 0.04979135603794167, 0.07168945841371052, 0.012542290947279863, 0.02285325696932212, 0.02249464738152681, 0.039654572554413355, 0.07847960212177808, 0.1321090893038819, 3.4264332873205987, 15.964196631985327, 31.97080977501408, 43.95068730077436, 43.08967997950893, 35.23701252475862, 29.914562125359815, 28.13294118450534, 19.42400267047267, 20.99752422302, 9.379677541794317, 3.8387231769100314, 1.4674731656428308, 0.12834383610395655, 0.09462066099888856, 0.04861342690644726, 0.12879664769336102, 0.03621632781540675, 0.03472334885549161, 0.08253108875285234, 0.07762269447407416, 0.10672635939573089, 0.08264255454583515, 0.25361559834451447, 1.4597442577923498, 1.2346318340109241, 0.499767477834417, 0.607764516626635, 0.14181143964730925, 0.8017477236928479, 0.8912140455457472, 2.9241831023846907, 2.7995578800478294, 4.522568314306198, 8.37661668177574, 16.427595250068173, 21.608855032151748, 30.146062374114994, 35.53332405705606, 43.63814892307405, 47.167838850329005, 53.39135377637802, 55.13112891104914, 59.09371514474193, 55.16052707549065, 57.804871374560946, 54.94351802333709, 53.18724932209138, 54.22495549724948, 46.49912572676136, 51.42439496132636, 55.51506227062595, 57.678598511603575, 57.77113506870886, 56.098275569177446, 54.2728986278657, 56.617236521936235, 55.22791339505104, 54.919387602037006, 56.6216766449713, 53.97185671714045, 47.669863008683734, 39.007602660886704, 29.842835703203757, 24.403135853428996, 15.861461912432025, 9.60884496088951, 10.009925942267142, 5.974675839947117, 1.8130528542303272, 1.2486255024710011, 0.6278635381210236, 0.9544522135007767, 2.7282977296460063, 0.3089038114393911, 0.35876200864872626, 0.726250923208652, 0.43666073992367715, 0.3704952580794212, 0.08601868104550146, 0.07094682044079227, 0.11449618400224756, 0.042477422694285075, 0.07829387942629476, 0.08256485790855463, 0.04807409717731419, 0.21187886775981998, 0.7506850217619251, 2.4958833234925426, 8.611174418080239, 21.060001696309737, 33.593743385807166, 25.03710658319535, 21.970093557911536, 40.35989469097507, 39.40453475521457, 26.98400051363053, 5.740057306904947, 0.4386808218494539, 0.033447992492226825, 0.035335338193803065, 0.06234070361261407, 0.009413517958995317, 0.08671441145481602, 0.03372800528943058, 0.07122059728229238, 0.05505783513428704, 0.08456109151724847, 0.06165363765772312, 0.055537681966539354, 0.048311377590101574, 0.044234284470158244, 0.060422718224506226, 0.030507494229823354, 0.020581882882622943, 0.016751784170346878, 0.051228150109490084, 0.03560598939657211, 0.0072820334424895635, 0.08197811116734821, 0.015641649032101756, 0.04014118777347669, 0.031881595496088266, 0.12045307685771298, 0.027191409871222514, 0.03745780777065985, 0.020162308017813393, 0.03313015410376172, 0.030923106504844564, 0.10530593279268473, 0.032237025818997816, 0.07596024537398931, 0.0804757054955248, 0.009795274893422763, 0.037212437469392054, 0.03737590914111465, 0.0170108865976574, 0.006037696458083848, 0.007281141428862729, 0.009715387244678794, 0.07001585507344815, 0.032660990367613496, 0.08115550127601431, 0.018430765447837692, 0.006385776167359925, 0.0958147009594306, 0.06258380246318637, 0.03670344482206049, 0.04018632950441491, 0.079192508222355, 0.1301259634595725, 0.03191907443256388, 0.031083094391731486, 0.11461456756918662, 0.027636074115552252, 0.06055410230352033, 0.043654704481483474, 0.03445190092128131, 0.03935244279883562, 0.021323320012719884, 0.06480139334716144, 0.07445337340956734, 0.049223998982098796, 0.10286756686025089, 0.04126913349835142, 0.05979040840400323, 0.06992128918007498, 0.036653189454227686, 0.06341170602207703, 0.036665194052001165, 0.03104188843750425, 0.03822637781981499, 0.0458331482725278, 0.04865207221178759, 0.10683067758838016, 0.2043119262182905, 3.7894675231749013, 18.956193347131055, 37.742920690967196, 51.41633449062225, 45.170877825829294, 37.200790297600534, 32.43957615667774, 31.257497341402118, 27.736130683652817, 23.90678148115835, 12.875979273549973, 4.233084157589944, 1.7135776242902203, 0.2591717735894265, 0.05285365078898688, 0.031082707517329725, 0.033055812931589545, 0.058985847544165394, 0.07426670076505792, 0.040617215657426466, 0.04023008461621019, 0.10556265651699036, 0.02814863864783078, 0.4116642715469484, 1.3755806126902181, 1.5594232058332813, 1.2397583718261411, 0.806727295200671, 1.03646548044297, 2.6948080428185004, 3.1255499874391868, 4.55096431316868, 5.978278046654117, 6.541140127566553, 11.784698424800752, 19.097851707089333, 23.173329637896632, 30.59844893793906, 36.83391532590313, 44.756087180106874, 51.513624960376376, 55.07310921146024, 57.20863580703736, 59.29986315388834, 56.68033569089828, 60.41304749827231, 57.066198856599875, 55.566339415888635, 53.76791308003088, 49.9606683946425, 53.49830112149639, 57.008951863934925, 61.248539801566835, 60.53597065710253, 59.5011591911316, 57.30113314044092, 58.05897035906392, 57.39890606172624, 57.32720121260613, 58.39296017923663, 56.4042478992093, 49.97895056201566, 40.374819309480735, 31.178643972642963, 24.918794170502697, 16.925244985088227, 14.804618493203195, 13.498310369829978, 8.33244392948766, 2.851744279746087, 0.39191814079400034, 0.834685520779702, 1.6886281630685254, 1.1047528419763812, 1.0203353459796598, 0.5230135578782328, 1.8140973078627742, 1.6562353915745214, 0.3270554680737757, 0.219205656058846, 0.16887014010740867, 0.18769405421710786, 0.0562547977202602, 0.061820089411471164, 0.045628150804869594, 0.19320556653603432, 0.1043276614960163, 1.2553451354465177, 3.0305970051596245, 12.268474736521322, 30.731582026327814, 39.46190726372504, 22.863570259463405, 25.646134961035948, 46.73555835600823, 44.213470412838845, 31.55689774021026, 7.110599635108826, 0.6126902781186566, 0.05053667914903453, 0.07328852905981964, 0.02402207348495722, 0.005774916808736781, 0.06383912562723122, 0.022598749154337475, 0.07108778827973912, 0.04920365551726953, 0.04215366244616528, 0.030584035989558025, 0.056615843467654726, 0.06073969859449614, 0.06828471853007233, 0.057125981416433096, 0.0635940541002539, 0.05543045263977782, 0.04239492651615893, 0.012254714947043648, 0.031500167979468266, 0.06487907466268347, 0.11748401883749232, 0.020125263836234808, 0.0426708254212093, 0.014846851962858872, 0.02814320899966744, 0.11911135046712815, 0.03114057205347044, 0.06517467734914634, 0.05623502499093452, 0.004120906167137887, 0.05416677145647907, 0.09217516278787967, 0.0315633702332214, 0.025225630172738628, 0.04468348778543934, 0.01584311387681913, 0.181749610290412, 0.14834708894693083, 0.09144768569498293, 0.10594787616883555, 0.1373306373434682, 0.18180709752825, 0.09109187615855087, 0.2397146878103095, 0.17826076927444628, 0.1395833648500904, 0.14741171091314287, 0.1629079229408695, 0.1546523602859628, 0.23280753183268735, 0.2080981319229449, 0.30618885712277505, 0.18457900282115708, 0.1256704420572327, 0.26737884287872626, 0.18865603082362684, 0.34214249721938567, 0.10537704107381644, 0.09308655460875842, 0.09800912917501504, 0.09905815635237003, 0.27429998762184576, 0.25257168097361443, 0.19188103115847036, 0.168467867338369, 0.23679292039765468, 0.16591832672636356, 0.13072156617718358, 0.09989328412038666, 0.10745768991088676, 0.2195606305594406, 0.11951107982425921, 0.12065912386582744, 0.18718520329604227, 0.1701354109231503, 0.2211316164222456, 0.24632988767998837, 5.237969410034919, 21.474054936439764, 43.97184848785401, 57.085563598140595, 57.634581673529844, 47.59979771029565, 44.082557385967625, 39.66555280070151, 29.58257467516007, 28.613835534741803, 12.481298619701017, 5.254566919419074, 3.1150444092289096, 0.48123280788140915, 0.25158305982908896, 0.13609247071848762, 0.28407012142481347, 0.20805808084626354, 0.33085731729384393, 0.1751742469927957, 0.3156334342014405, 0.33075257775283634, 0.5597213042839881, 0.6684922450973142, 4.193504010477374, 2.840053410299363, 0.8139133225044897, 0.8832650559563792, 1.5615870058536532, 4.732253320755498, 2.444512776790127, 5.496175606404582, 4.649872760618887, 6.027044875006522, 10.140147651395491, 19.305123475290117, 24.227666662585353, 32.78637643783323, 37.33813993392452, 46.50581729027533, 51.06839672211678, 55.50587215731221, 57.689741965263124, 61.3960091529354, 56.40151008482903, 61.10756197283345, 56.66960408610683, 57.04813241958619, 57.68190114728866, 56.10500635639314, 57.24891462633687, 61.62919405967959, 61.95963805721652, 63.58890041228264, 59.87935412314631, 58.7015526525436, 60.13743039100402, 60.07417432723507, 58.48505350851244, 61.63778012798679, 58.46950915551955, 50.883241238132605, 42.45878242677258, 33.619846759303925, 29.069254090709073, 18.884160980101555, 11.384114603842459, 12.43029505975785, 12.305990246034439, 3.5127862278492223, 2.269433371482357, 1.436352345251268, 2.099244426335058, 5.794677782443262, 1.013847929575751, 0.8600143487415007, 2.2024304636063117, 1.5209241619994565, 0.9475581576266597, 0.38602772138772473, 0.5560447564048152, 0.29279194051219576, 0.20008286040636802, 0.36071917943416104, 0.2303959942993618, 0.3021538720255898, 0.2827049221002287, 1.217238941500264, 3.720691703980969, 13.228669974111742, 30.08348095801569, 40.56079456883092, 34.16318916505383, 34.43525652731619, 53.39595863896032, 52.849333209376184, 37.03979269150765, 10.027022573255724, 0.8419607207179071, 0.28564345151666676, 0.12791875689741106, 0.12935224529956618, 0.115896079448923, 0.1951940243522967, 0.10974302211956632, 0.23331834393883907, 0.18978449365785047, 0.2508389126629599, 0.2651502624634774, 0.27525805717995094, 0.14107078584211488, 0.14340294134472648, 0.18923042822749386, 0.1357528639416541, 0.12926420647530787, 0.11877866146425087, 0.14449650121311988, 0.12641529402425214, 0.14627149629016079, 0.2256025361918634, 0.11228519296574016, 0.17062704018767805, 0.12771955871533963, 0.206220435098775, 0.1502308072221856, 0.2062701235615438, 0.10830379571885833, 0.23236549910037751, 0.19186560214767534, 0.2586304558621299, 0.14123488187549577, 0.19149115369204553, 0.18867856913035919, 0.1318152179761279, 0.17153935897494518], [0.09835301072246606, 0.060148205938598806, 0.043328121199362704, 0.030959602933557286, 0.033793505806956566, 0.06336263042964763, 0.05672826687054289, 0.040775045091586734, 0.07188063565521471, 0.033280134967137734, 0.02336541547500078, 0.08822152090649452, 0.0101929233642295, 0.10074907327972113, 0.04838368862927441, 0.07396329930352588, 0.06852939935220827, 0.047937036386781165, 0.05695760678199511, 0.024176712162912856, 0.02868217483703648, 0.01112181837895825, 0.012146881368431834, 0.03242793876016813, 0.04158651606450158, 0.02426663939390452, 0.03157459916697154, 0.025531283932768052, 0.034816145085759705, 0.055692546640432654, 0.06946390404576255, 0.035190926789636576, 0.031232155949598363, 0.017393593481110952, 0.08125767442247561, 0.06091331710077583, 0.03205580580528946, 0.03066126914364436, 0.052591296318437786, 0.05563893963793113, 0.03293173350093346, 0.4500683511216795, 7.685043494547568, 23.09866143811134, 44.84704302203271, 50.33858483837497, 31.537566338816, 17.54774670447073, 24.84452605247498, 32.58301135032408, 23.92797993075463, 14.45564619956478, 10.098819598074883, 5.087646534365993, 1.4024401456117632, 0.03637408447121421, 0.12337065376942197, 0.09386178196197557, 0.06730709840813953, 0.14479449409390652, 0.059778120353697776, 0.06531293323684124, 0.028388211578731577, 0.09244139366332563, 0.01645797987528626, 0.556542223259326, 1.0306901580864385, 2.1541169141569445, 1.8481027863679396, 0.6692767191317774, 1.557389947195207, 1.7444007122708907, 1.4167136506688212, 3.9690149984052105, 1.4365721205549857, 3.5277527666861013, 7.826527309033179, 12.476527056386395, 18.935916654525265, 25.310444793393536, 30.82115915513808, 35.81624069521504, 43.703993751156716, 50.99922572412799, 53.81358515831732, 53.18822991463446, 57.09767979960288, 57.59553447846444, 53.27553402992987, 55.84321560398225, 46.74376395440871, 48.10907040872882, 53.30184921141594, 56.54658679039248, 58.780945347201445, 56.323874612008375, 57.44489977436682, 58.467226336079264, 55.68097852891492, 56.69848057531542, 53.4813251033906, 49.0623357988173, 41.99310295043453, 33.603196297922445, 20.614334152590846, 19.73483677833311, 7.767543686974434, 9.9180640328315, 9.160109143103323, 1.6270315070306103, 1.0992975605110968, 0.232302664568828, 0.3707958096938749, 0.6414812106278636, 0.8745250346199159, 0.12935518707719543, 0.5216989510001675, 1.9291550113308815, 1.595293893929451, 0.1531692140645558, 0.07027077849113172, 0.06680514993927171, 0.07346641467583757, 0.03305509280894072, 0.049246012518603, 0.108075761987317, 0.3952126253035761, 0.8507997819012212, 2.259302624771672, 7.05204257080632, 11.01890762006083, 13.09798836708069, 19.400458643513343, 34.495170731698316, 40.646270859626036, 43.05058571600145, 35.90460777282715, 16.70971662767472, 3.362906089713497, 0.022219154503076308, 0.06122495400749388, 0.13204706682553216, 0.06883005821897138, 0.01951697470259763, 0.007072428434771756, 0.05644715856760741, 0.04336165286780846, 0.024982395341559768, 0.022559418200304913, 0.03111372450216403, 0.07475751797638594, 0.02843205096019853, 0.05039485329161248, 0.03712348317006423, 0.011151949574630107, 0.04599537505137344, 0.019795715793847077, 0.055723986888845126, 0.0258175058725981, 0.004171500050072228, 0.06482455984599168, 0.03529272838345459, 0.029183424250673384, 0.0422244489703688, 0.027654632595517946, 0.027734472363766645, 0.05123381149925051, 0.025310920656568585, 0.021989155756009203, 0.06382277731092707, 0.03168836705416682, 0.058969878441383766, 0.057582818797879645, 0.008207565331230722, 0.0462106534189755, 0.01766763462294494, 0.030847909229417003, 0.056397650135500785, 0.035438855824571465, 0.035773410251544374, 0.014327705777700872, 0.04807586300997965, 0.06528032087390462, 0.013690419258519769, 0.013167601596984654, 0.0527624671737994, 0.07023989748690398, 0.035239098398315336, 0.03589809106122102, 0.007372279078774756, 0.010521643074049104, 0.07634498239044221, 0.03374097132754903, 0.0504222217827074, 0.043070068312508446, 0.0462318089370045, 0.03616545957723453, 0.00684933788556185, 0.040088833324731364, 0.07636857789851005, 0.03576081959650882, 0.03348540439600906, 0.02047733486359639, 0.031216889732487263, 0.05885139911345417, 0.053891680774188815, 0.01922351706232275, 0.05417212641106979, 0.02275338974751292, 0.042715139777189305, 0.1410932168965378, 0.05909093565517857, 0.02863361060829653, 0.052808849967174956, 0.044281276303433606, 0.03197787359597222, 0.04548159435451512, 0.5023527794307279, 9.730110918321918, 28.699047065550282, 50.551604840063284, 56.4379410589895, 37.404635875455796, 24.008712114826327, 23.156002567660426, 31.60090869472873, 30.02878546714783, 17.539525416589555, 10.692335001883968, 5.541655488552586, 1.3027781127921998, 0.13379365536234072, 0.023596157327354438, 0.06264808490091274, 0.1163342587589737, 0.06406185036945729, 0.09181051259680141, 0.056814038074545326, 0.1429793866531503, 0.4482724878095812, 0.19791955068226785, 0.7796200400879307, 1.9097995854193166, 2.8254364527040914, 3.589397962054899, 1.2695238907491009, 4.559959288566343, 4.964825357160261, 3.7524771209686034, 5.516701369516311, 3.4146490164341468, 7.910887195217994, 11.886315268854942, 16.534486701411588, 21.11399704410184, 27.553511011985044, 33.279632137667754, 38.59722468160814, 44.81901376478134, 51.79756925952051, 53.10542083555653, 55.726897716522224, 58.805707270099276, 60.36657133410054, 54.79574664946526, 52.93428782493838, 47.276755225273874, 49.981621696103005, 57.01418822811496, 58.903515492716146, 63.2225549605585, 59.151107265103256, 58.35227735580937, 59.514750203778675, 57.55233349338655, 58.761921851865715, 56.82545946490381, 49.766346331565614, 44.309795979530584, 34.86181428355556, 23.26040625572205, 21.43569415615451, 14.395148542619522, 11.624986375531844, 11.627820287981342, 2.84578031589908, 0.615606008758468, 0.2595103231649245, 0.7936136472609736, 1.1652886194567527, 1.6982138228993264, 0.4509307209762835, 2.7753433729371717, 4.354876202921714, 3.6047013344303256, 0.729826286194786, 0.1947408986668433, 0.17679970170701706, 0.08436667372382457, 0.1454252602472421, 0.0390163293829368, 0.060563889076753016, 0.11130230981976756, 0.7513536020152031, 2.403174917544088, 6.534907971659015, 11.905401522113431, 17.472023387109083, 22.83165981692653, 38.161064963186945, 43.67686271667481, 48.02896776506978, 40.43136419788484, 21.44140708831049, 4.216456249836953, 0.08546260846478325, 0.07419537031842817, 0.0477744993423262, 0.03811405400835699, 0.03541115408522948, 0.03839585945130356, 0.0448375404061329, 0.043565382459951986, 0.04745682183232519, 0.03133628070504675, 0.029504099079678138, 0.02383068748449366, 0.061002248417465925, 0.10603476586120744, 0.0072977147834946314, 0.019744924164467284, 0.07981540665270821, 0.04911925561065155, 0.08956050470231042, 0.069544879539359, 0.025278174228245215, 0.06833778544058723, 0.03771658461060255, 0.04987162290020816, 0.04644897188090029, 0.04152710594597363, 0.03419107862658078, 0.07650792929193667, 0.0328273999865257, 0.03338786225105005, 0.016067780651933244, 0.08664077508353418, 0.05255797532417121, 0.03147811039290842, 0.04467744335171677, 0.05027590665004907, 0.04450285574421287, 0.22467803660660024, 0.1426904336098702, 0.10423638978071752, 0.11658803304477085, 0.09580831178614209, 0.16647271391364837, 0.18082485023525455, 0.11946754304752236, 0.10862051178851437, 0.17336238776483845, 0.21049065515398982, 0.21603271905933658, 0.1512762567689342, 0.19481462696867605, 0.22819533012807372, 0.25401963311577996, 0.19482645536622695, 0.1763951613177215, 0.18602085690344536, 0.11365649035020221, 0.09688085020189324, 0.2044056340931885, 0.16508060958116286, 0.09405882743697974, 0.1439524102475374, 0.1824436706280516, 0.17958080005501548, 0.13540890578541065, 0.17763256185477783, 0.17693871602175698, 0.18300633156491866, 0.12476982143256934, 0.19819315132354537, 0.08568776170572928, 0.2312330526089476, 0.10170334304172186, 0.10804060621247177, 0.1023290376929987, 0.08997223099633571, 0.16608456780593242, 0.11281544838341014, 0.9191642425233318, 11.47100196730706, 32.5453487519295, 58.667612383442545, 62.92934602306735, 43.87220067362632, 31.52520695040303, 36.17230561471755, 44.38498781573388, 32.199432965247865, 20.746119906825406, 13.916551720711494, 8.171772860711622, 2.319823815937965, 0.417425865607877, 0.28901745595278283, 0.3317652540581842, 0.626930320455182, 0.35805006781893395, 0.23673229219932712, 0.184072281624521, 0.24476144522909196, 0.27086619768411885, 0.38401033609144153, 2.5483854739896716, 3.560292994783771, 3.09642001505821, 2.6752268354738913, 0.8627088944758139, 2.7956470318378943, 5.075509250164032, 3.685600709530615, 7.42486777805513, 3.0317168418438207, 6.210918724536897, 12.144696500993545, 15.933057915779854, 21.0040843871332, 29.501079590089862, 32.73562489017364, 37.49392863242857, 45.15116791571341, 52.51821456416961, 54.48494588175128, 56.201998726014175, 59.26502073964765, 60.87856223506313, 56.77331547583304, 57.05154095926593, 54.218083504707586, 55.17107825125418, 59.96802714563186, 62.4071216583252, 66.1541618839387, 61.504050839331846, 60.60180371807468, 61.025168664993785, 59.56250898299679, 61.15902346949424, 57.805428351125414, 52.054566875580825, 46.5928154606973, 38.293048797115205, 24.659713775880878, 22.19752630879802, 9.606377790051123, 15.030780396153851, 14.819036145364086, 3.5618082554109636, 2.0885128215436013, 0.7645474746823312, 1.2437229074778096, 1.2381765534800868, 2.337831417399068, 0.26714693274228807, 2.3676487851527432, 11.055642577909655, 7.955059947506075, 1.517044815324968, 0.27196819984143783, 0.33138781785964966, 0.24144295152396927, 0.2905095194376284, 0.2465993208029578, 0.2800340638045342, 0.5397385442929884, 1.5125801774763292, 3.415697269862698, 10.244391502872592, 16.953076162645896, 21.759487775064287, 31.141061782836918, 45.37531568158058, 52.4537504103876, 53.28288847400297, 47.05766731692899, 26.405482292175297, 5.061198972886609, 0.2726096605821964, 0.16902901142114596, 0.2103319217360789, 0.10170935683192746, 0.16937905231550818, 0.1406719298252175, 0.178874344414761, 0.10484565184601854, 0.14955649663123394, 0.09985860332005447, 0.10273492639704097, 0.15314984736183, 0.10690697228475925, 0.18101436506596305, 0.11772928188645071, 0.09157771379837105, 0.14221988708501862, 0.15994880108102677, 0.17444379747875277, 0.10208114696246001, 0.10924606088308558, 0.23492556576046253, 0.14880537806499392, 0.12146314846411829, 0.09658096508393366, 0.16043489919074122, 0.19851749762892726, 0.1883811737981535, 0.12408057978797345, 0.10974915082296056, 0.18102717405605703, 0.11243468736328426, 0.11199420212858147, 0.10075537052245871, 0.09839123850988765, 0.1255704829048726, 0.16169984824955463], [0.126621731737208, 0.07080252011937481, 0.01621646682671722, 0.029955840061208414, 0.06763846207890781, 0.06668603858880459, 0.010644126168992973, 0.020370902268276102, 0.010253440479808038, 0.03738767625163159, 0.0628388790984548, 0.11496934288692091, 0.06438898523488353, 0.09769933854019451, 0.06830795397681576, 0.06474247352490503, 0.07035983621232933, 0.005521684051341107, 0.035454415070313605, 0.054990231705408905, 0.04327356807827469, 0.041055770350560065, 0.03420838455279027, 0.053743668756778204, 0.07134932303620924, 0.10002376421565011, 0.07040848279552114, 0.059776940578294385, 0.02850484846520328, 0.07152990528172062, 0.029879413214662386, 0.022556062735196565, 0.050289198275535345, 0.03489876766839335, 0.12125597530675512, 0.04709628170296069, 0.08288671442818257, 0.05191058506287875, 0.0829321051376962, 0.03906758449551079, 0.04329493427048287, 0.028461704308527614, 2.666098499490369, 17.167204233907885, 33.71619978258687, 42.02942017586001, 32.18757171784678, 23.640454507643177, 30.61169674319606, 24.489212266860473, 31.900593465374364, 25.734817789446925, 12.945376788416217, 5.923661983782246, 2.9231571574364943, 0.8531920599841303, 0.13574065250014106, 0.051889644049468546, 0.10814084881736387, 0.08800514703316074, 0.07616006408727939, 0.04822148483306651, 0.10291907861227952, 0.5658272701886393, 0.2814964643649517, 1.06423108087432, 2.5162776872035, 4.048003688935311, 2.9559702354092754, 1.7705819203007607, 5.363870628418462, 5.623198622657407, 3.2141352468921296, 2.262420418762392, 0.9775451066032533, 3.2845866535940482, 2.3449316428553675, 4.7657170218806115, 8.288590850368623, 12.40983303516142, 18.21531253476297, 23.353052639192153, 29.517586884960053, 38.67848442446801, 45.73403604568974, 51.021214531313994, 52.76041307756978, 55.00455794795867, 49.13932015818935, 49.67874803850728, 46.61346281728437, 45.85221705898162, 52.756620145613155, 51.08103459881198, 56.85104116316765, 59.58999695316438, 59.98892161153979, 58.359361156340576, 55.52052613227598, 55.395724158133234, 51.61777173319171, 44.288113117218025, 36.10081649595691, 25.822969136699555, 18.306656691335863, 13.476216639241866, 6.991499316307807, 7.238856727077115, 4.209529344112643, 1.8010680521688156, 0.2541843420195003, 0.41701309743427467, 0.2681155436702313, 0.8295416387338793, 1.6361885253460178, 3.172731197649433, 2.70454213984551, 0.611312177873427, 2.0142172469246775, 0.15829434227799216, 0.05146808501693511, 0.07520874376378714, 0.09355982840662042, 0.10705568527262058, 0.1481883708507784, 0.08656002941631502, 0.6239013313766449, 2.6518688759496136, 7.311491668224336, 9.766801749506305, 19.512044191360474, 30.36588964923736, 33.38709331327869, 25.540201548607122, 37.79932045167492, 41.69458312373008, 28.767176674258327, 11.225823433168474, 0.4231478069578448, 0.026998840264915943, 0.08554223564363296, 0.04982992090404995, 0.03607437938391682, 0.01007024108642532, 0.02306165969780376, 0.00884464883711189, 0.050191066242874637, 0.01245193949510013, 0.014758982635553808, 0.02184672468912698, 0.0892864750517953, 0.08348660723816964, 0.08526447514492659, 0.07733174960219091, 0.042148686705097076, 0.09268472617071483, 0.04017447046334705, 0.03885377318628373, 0.022921867803820682, 0.0820244288432502, 0.03663850354871923, 0.035985811958990754, 0.05811861303124217, 0.014503703944595351, 0.028936646262844725, 0.08080985006545821, 0.03317993449708147, 0.01586586668817026, 0.04112594017398454, 0.09897577891787214, 0.04087379765546611, 0.03813514057847281, 0.03949193974896785, 0.048788769110556574, 0.05423431359832326, 0.1496200819289492, 0.0736441930395461, 0.017319531931031137, 0.07210480830361767, 0.0065524002908909276, 0.0101406809558431, 0.056199275497947974, 0.06757215716906133, 0.01367824229096333, 0.058116743776706926, 0.06762041304741176, 0.05462369310759729, 0.021628069788998654, 0.10668090739918333, 0.03841873100628296, 0.046794014051556594, 0.08787886509972234, 0.05636345580100052, 0.05882637485140755, 0.08298662761526723, 0.03878013298456227, 0.06844414908799433, 0.06822467255856722, 0.04699343056868642, 0.06562339802903515, 0.08433103531358704, 0.012163561017763232, 0.03396993585591836, 0.0392417813981733, 0.013681660000715527, 0.019556407163280155, 0.003332005820289675, 0.014762174349368341, 0.04164532097356935, 0.051461274495288256, 0.08224835634351739, 0.006830353269188275, 0.042320098878154834, 0.03657087330676375, 0.12419449706231395, 0.03602773995108662, 0.02520594937396386, 0.020215030188762376, 3.3416122774924, 20.247700406659035, 39.57557362894858, 47.87038241663287, 36.04239279224027, 27.489662670320083, 32.67253944950719, 29.60545974393045, 35.76132359043245, 23.63211358747175, 17.259548594874722, 9.655519204754984, 3.5959529780572463, 0.7951542194331847, 0.09067599000709672, 0.049296984178645, 0.08524612733914007, 0.08120394101546657, 0.27061807712720287, 0.19046350802865722, 0.2648917537543082, 1.0172004529064702, 0.7316474916954195, 0.5095944553613663, 3.986248422053553, 3.111177197387142, 3.069186753803684, 5.805353493459764, 4.8669107402524645, 8.85653632302438, 7.520650586774273, 4.10365893475471, 3.247286629292273, 7.494720287861363, 6.523484068532144, 10.341403484344482, 11.319559254953939, 18.68151760870411, 22.430407231853856, 28.97026131230016, 32.71351841188247, 40.836160644408196, 44.77449878569573, 51.64446346221432, 53.75752272144441, 56.740461703269716, 52.266119910824685, 51.17163350505214, 46.36674181107552, 45.691690137309415, 55.784964484553186, 54.59374850796115, 61.08684793595345, 61.24091471395185, 63.84598039811658, 58.99555390880954, 56.8873623109633, 57.391100545083326, 53.93085225935906, 46.205140159976104, 38.054847178920625, 27.321373378076864, 19.447150538044593, 16.196119516126572, 11.6437941405081, 9.032278118595, 7.472029376414515, 1.6044250491165346, 1.1085204011009586, 1.2188411071415872, 1.817473610562663, 2.235918679545003, 2.85784577169726, 3.2445833807991398, 7.149558086549082, 5.567435266510134, 2.6380258510189676, 0.4233954372184892, 0.3411780231662335, 0.3719512235012747, 0.2822145645416552, 0.1137241742183124, 0.13210988603532314, 0.13356824165150044, 0.6640762078665918, 2.9913230480686313, 9.320537024928678, 15.305473785246573, 23.357126020616104, 30.31913107441318, 36.50944509813863, 30.576491509714437, 44.559443073887984, 45.27648372034873, 32.4573915620004, 12.51979079938704, 0.6376087281011766, 0.04927316650507912, 0.04511260810578543, 0.09426112061426525, 0.05188421248608539, 0.030644591409532778, 0.0431540698534058, 0.042249239575598514, 0.042184374911049684, 0.02908360873979907, 0.056918417554228544, 0.03774822787231496, 0.07748038598125981, 0.09561155742454915, 0.05741349421441556, 0.0316533568360272, 0.04709627404208145, 0.05342843123681603, 0.08857090296524187, 0.016257862387705716, 0.044348626923296726, 0.08885952659071454, 0.011149896458993036, 0.05165637793740438, 0.007089186608115392, 0.03686893896590318, 0.04976675695469303, 0.03890619275250262, 0.0490289721487751, 0.04325784795406846, 0.04155137561141484, 0.090566830138766, 0.04838932320595749, 0.024976283875143817, 0.021946635960991827, 0.08951489948817799, 0.02204216520992979, 0.07885458683895488, 0.3308003816393114, 0.21519912346716852, 0.20422427043799432, 0.07391903474326096, 0.12994084597354935, 0.14726097545316144, 0.2293848501698625, 0.1451946064949997, 0.08172586139652037, 0.14252454493074648, 0.18531080064994676, 0.15183910156690306, 0.2057880397525526, 0.1822260556922805, 0.10606139507745543, 0.18670676606557063, 0.18993135271293504, 0.133141239564265, 0.15598783539908548, 0.17223105976177802, 0.2778093444724237, 0.12945994193996155, 0.1576278917491436, 0.20316250321845855, 0.16388330608606339, 0.286275596628266, 0.14725354440029592, 0.3114257422426055, 0.1359301520090911, 0.22878428320250205, 0.14811819719691433, 0.13888113801517796, 0.13208457449030492, 0.20265144596417106, 0.20289826417161574, 0.20143427014831575, 0.11736462403449321, 0.1706355131201206, 0.17914943126661165, 0.1073430295312597, 0.09861687438622599, 0.16090886246773506, 4.266485591088572, 21.818288026317475, 45.348890673729684, 55.061267575910016, 45.828682837947724, 34.90357575878021, 46.12720266465218, 38.10522217904368, 43.863916627822384, 33.32617498213245, 17.694382552177675, 9.37245253593691, 4.235577314130722, 1.15755750527305, 0.35049386683010286, 0.18649434520592614, 0.21078268787072552, 0.35471718698259325, 0.2958821859811583, 0.3442592287976896, 0.4913364963666086, 2.2672304703343302, 0.6599975557577226, 3.9190383640027817, 10.58269691082739, 7.948146770077368, 7.347514715886886, 9.796427411417808, 13.732514112226426, 10.746018521247372, 7.8500482920677435, 6.090184738559108, 2.299230637088899, 6.2980482943596385, 6.14368292593187, 7.945079476602617, 10.078148707266777, 15.493676950854642, 22.490776431175973, 26.782096509010564, 31.144487973182436, 41.301636157497285, 46.42342006006549, 53.95473557133829, 54.26351239604335, 59.23901150303503, 53.11552486112041, 55.38503569941367, 53.20848895657448, 49.77956864141649, 60.73789819594353, 56.58391598732241, 62.20828886955016, 62.31925272172498, 64.81570013107793, 61.581764759555945, 59.492522132012155, 59.25145718359179, 55.99744319915772, 47.96851227360387, 40.09087108796643, 28.950092484874112, 22.46069577432448, 15.698789454275563, 8.31406468345273, 10.255174098476287, 7.467716730410054, 3.4754700237704865, 0.9210781140192863, 0.7345043867826463, 1.0089337513331444, 6.118330196026833, 4.498557525296365, 7.913853487660808, 7.996557153040364, 11.428592320411436, 6.987740214793914, 0.5547476163314236, 0.4928443106191774, 1.284638253911849, 0.7171521275754899, 0.5208408099509055, 0.2997650873036154, 0.43155344623711805, 1.3037411772435712, 3.1851751621692412, 10.317760417538306, 15.817317597327696, 29.17886668635953, 39.944856935931796, 44.959575822276456, 35.76530871852752, 51.35391389170001, 52.653826590507265, 37.62395912601102, 14.290388899464762, 1.3545241038645468, 0.13056886953211602, 0.16605055350209438, 0.14862186936361177, 0.23491606627020145, 0.15321493419187684, 0.14001782863370835, 0.15357755424995578, 0.10603615248035039, 0.09353830133594813, 0.1344544368405496, 0.09386932026715049, 0.182937812660971, 0.34137904463756474, 0.16766456286272696, 0.12107975976241213, 0.2186067591631605, 0.20813194704392265, 0.1947999946893223, 0.1621794346119127, 0.14950953544147555, 0.17160596265908212, 0.1533405266461834, 0.11821757866850785, 0.1188971293008616, 0.09972453027242616, 0.07826401731900631, 0.1649278976143368, 0.15873793782966752, 0.1382682523539951, 0.11470074479978894, 0.2440373236013036, 0.19748445870655199, 0.09393868952869408, 0.14125089311311323, 0.1929007861162386, 0.12877076924327882, 0.319328521408381], [0.04819804637302314, 0.1392455507189997, 0.019467996786378568, 0.062237017442502325, 0.06357037432251439, 0.026858326333064227, 0.028862107823032047, 0.0574719007577627, 0.011794183106582251, 0.0677207705654925, 0.03061692988980682, 0.018932204468235857, 0.04698536366284375, 0.023825075890448306, 0.01906899712799538, 0.01437634661523325, 0.12037284446940308, 0.0704267846360322, 0.05208880009670412, 0.07500094241432606, 0.04890881508829133, 0.07194246661158339, 0.048064321895400365, 0.05210938104878991, 0.07517631526195234, 0.043425203691567146, 0.11494698078041116, 0.05055324580039709, 0.07463764053799453, 0.008049761752537903, 0.06222549931056077, 0.052781420189046094, 0.01783791298587476, 0.06236802230799391, 0.05816516436396107, 0.034659449461727374, 0.05531839312865369, 0.0693867206873913, 0.060543928655885884, 0.0294525834972099, 0.0747403652677613, 0.05693909426730487, 0.18042662241045507, 5.341492035696584, 20.0828706449078, 41.56980860617853, 42.71104574203492, 32.256011193798436, 23.89238834381104, 15.639791123328672, 25.584598856587565, 31.006704914954405, 23.171597911465554, 11.283977473935774, 11.40735072474326, 4.021188650400409, 1.2112239868410173, 0.05736377893856937, 0.0431728619901884, 0.05779434333465273, 0.2619314980843375, 0.4249041401330502, 0.5999005321533449, 2.570915568259455, 0.7140721476847126, 0.2874415518055039, 1.8876434646306501, 2.230118964948962, 3.8907389535057932, 4.530588090419769, 7.061094420571481, 8.285256835722155, 5.2963141760518475, 2.96067732476419, 3.2146645217172565, 5.251366755654735, 3.1051855318007933, 3.3284706213781914, 3.2325059127423073, 5.736922352544724, 8.305040290278773, 13.034721516793775, 20.461644126522927, 28.474795356873546, 31.71612047380017, 39.680504875798384, 39.43188544242613, 51.702373335438395, 42.95764123239825, 43.54019949513097, 38.8350889759679, 38.994066561422045, 49.41176799035842, 47.57270589951546, 54.137784742539935, 57.04105646379533, 56.70908666426136, 55.05320710520591, 52.15864696810323, 49.92692816642023, 44.53556368427892, 38.022738656690045, 26.99198449811628, 17.69470222534672, 13.036138473018525, 8.360213329715114, 10.823254892902991, 4.496251171635044, 2.994969871736342, 0.19890775813931422, 0.5969520129503743, 0.542858605903964, 2.5455150344679436, 2.1239114769043463, 2.73364931344986, 4.367454263471789, 9.474102720137566, 5.33650670320757, 1.2077227811659537, 0.3770898348621784, 0.2052469518516333, 0.2548231674177993, 0.2820801007891855, 0.19118024456885555, 0.12604938744897806, 0.5957419004651808, 2.439996167536705, 6.110194219696907, 6.913581432834749, 13.548895216757252, 13.155304981816201, 21.819156831310643, 27.034585360557806, 34.613320366028816, 32.82779666685289, 29.253107347796043, 13.250976493281703, 3.4749118214653385, 0.14168354892922988, 0.04642154976365067, 0.039293680024603685, 0.04210204344182726, 0.06668937873215446, 0.017277600108495644, 0.12827938512688683, 0.04461058302812519, 0.05579865364838512, 0.03340561250825563, 0.019932002835576574, 0.031896199047144864, 0.07996064926227255, 0.1326051312348535, 0.10566643844809263, 0.11181979455173978, 0.022761740105887576, 0.06452176359391983, 0.012121271049123139, 0.04803838215828423, 0.012093570267391062, 0.026162743395675096, 0.04620131863761814, 0.014042895354871309, 0.004308760981075466, 0.04923988381520875, 0.06592130664015008, 0.03948487641830598, 0.017506545484666864, 0.059458956633123665, 0.07468554401589979, 0.0777162338096288, 0.03572014032772953, 0.09588823007840304, 0.1214208221063018, 0.0017641118404665783, 0.07157946350954233, 0.08847842083102272, 0.011599010716552937, 0.027212856502662745, 0.01745536889610512, 0.019738492856342948, 0.01973799872963179, 0.0687263299140238, 0.03089512705863003, 0.06927631975662324, 0.0211132625343218, 0.07662108813923213, 0.03639007655663356, 0.10475116256143778, 0.04939314353490069, 0.04715600974797722, 0.03647103672847152, 0.022436346175269257, 0.04620760438903686, 0.07470279631595458, 0.027904453867625807, 0.042983768507838256, 0.029816921507459015, 0.04095824352735954, 0.04225874289629921, 0.03739479320844816, 0.08589112740610877, 0.029427090006309654, 0.03320556779902789, 0.027626245207483732, 0.06784667711584799, 0.03226201943752747, 0.024989433774364092, 0.0404294973029004, 0.04059997867913016, 0.06328530917545, 0.040724360714516336, 0.035556186020614645, 0.07186405751253329, 0.02054262087650357, 0.04397583321758336, 0.03189453280590956, 0.025445698505087246, 0.0251905107870698, 0.4817166996579017, 7.420939034031284, 24.326198562499016, 47.58497899578464, 47.46975152723251, 37.272173512366514, 28.691218014686342, 19.47852361586786, 28.06069700948654, 35.22292729346983, 27.20614787070982, 11.232721901709034, 9.872753793193448, 4.004117759966081, 0.8872799082629143, 0.1385603157142478, 0.1029473702393232, 0.04850790978619649, 0.11428678152902473, 0.1649173409227402, 0.33618843122836084, 0.14925239036881155, 1.4190312811443884, 0.7425844080505833, 2.703599790411611, 4.563914508588852, 4.164805498815352, 4.80514076448256, 6.661242611946599, 10.237670521582327, 11.27149158908475, 5.036815068414135, 3.9634989202022557, 5.795050897905904, 5.123349418563228, 6.230706101463688, 4.983631651247702, 9.551685240960891, 10.935894577733933, 18.386349447311893, 21.020738770884854, 29.590560620830907, 32.63603002794328, 41.3147682528342, 43.45128720806491, 54.575948792119185, 46.57634542834374, 44.47942280000256, 41.28504453166839, 41.01229467699605, 52.77376874800652, 51.10100338535925, 57.64799225714899, 59.67285702305456, 59.070941863521455, 57.45996167582851, 53.037508918393044, 51.77143450706236, 45.34652940688595, 39.122022121183335, 28.14516328996228, 20.792052822728312, 14.755128968146542, 11.209545596953362, 8.530086278915405, 5.731550666593737, 6.80221357653218, 1.4959811972033594, 1.626350362935374, 3.276617132848309, 6.743248585731753, 4.159510299082726, 3.6511015026800098, 4.839607121482973, 4.090951435988949, 1.5188600146962752, 2.079625711325676, 0.9415389741620711, 0.8122631078285556, 0.18205590756429782, 0.21251536425082915, 0.18745799188412007, 0.13175717915498442, 0.42601309836872164, 2.18527524221328, 6.87205873189434, 9.827312154154624, 17.17715136466488, 20.566814637953236, 27.31404442940989, 31.019558522009085, 38.39643463011711, 39.29893670543548, 34.18764122070805, 16.33816324895428, 3.8205643190491587, 0.16059455191416128, 0.07770203053951263, 0.011459258084575976, 0.06231609686848618, 0.051134361795360045, 0.027717633751190962, 0.029779860088902137, 0.03424566239118576, 0.04847851499254185, 0.01734472856286072, 0.08475406140449547, 0.01890381133454221, 0.0199318285505738, 0.06890973902397579, 0.0283582019995177, 0.013560157498314738, 0.07651519180545885, 0.05096434390232448, 0.022958243573685328, 0.051895661670113766, 0.05888627526620704, 0.025361564814022956, 0.05264222967408357, 0.04604219068442622, 0.02047355038925044, 0.0255122677152676, 0.06194456720784788, 0.036078466462992856, 0.017050353532296517, 0.024085880948170543, 0.02151961089111865, 0.03303749959975962, 0.016443452933022094, 0.06224883434873435, 0.07154103653926043, 0.06461103581973622, 0.029820671507848368, 0.09523375350381098, 0.22650045252615408, 0.22333293942914856, 0.1344603970046005, 0.1966926302280157, 0.18107814954653864, 0.14881216560400304, 0.1174036025880806, 0.21374248388794162, 0.08843444738416903, 0.14887570493644284, 0.16037886751995933, 0.21928520662890327, 0.13381309867385896, 0.18718236877072245, 0.15488066980915685, 0.17022242318959008, 0.176448940690006, 0.18823705733783785, 0.11603416679727456, 0.15609701825005395, 0.20628860160227747, 0.1955276249998039, 0.13021279186491044, 0.09822718078090299, 0.2547254145986611, 0.1724251711200322, 0.17807384382092184, 0.1523727124496814, 0.27691418605466045, 0.20219681874638606, 0.15849380092995782, 0.11355941168843739, 0.1433777983390516, 0.1285417855627114, 0.17925901248330073, 0.18638070372323837, 0.28203680149970517, 0.2488764252273306, 0.15765962311096732, 0.10085604979746765, 0.15675499584645997, 0.1715101557032716, 0.6742362497795014, 8.191519052751604, 27.815301764395933, 53.61259114357733, 54.67465915987569, 44.55428123474122, 37.192733749266594, 27.08114585568828, 38.45528194981237, 43.268328251377234, 30.660285103705625, 16.257903710488353, 14.069272145148247, 4.7483659271271, 1.787361329601657, 0.332259503343413, 0.24695273248418687, 0.43231358931910613, 0.7801053108226869, 1.0957533313382057, 1.8127637020041867, 4.59726446097897, 3.952851401221368, 1.5279328246270458, 5.303968191146851, 8.975510635683614, 13.084449325838397, 9.536351715364765, 15.937455873335562, 16.13002855931559, 11.651707522330746, 8.888557572518627, 8.327926339641694, 10.22480514741713, 6.895845455508079, 6.861741917748605, 5.667193397398918, 9.431950969080772, 10.438092850869703, 17.94231557076977, 21.29641471370574, 30.576905319767615, 33.235419181085405, 41.50695262416717, 42.18410276597546, 57.648219754618985, 47.28958529810752, 49.14332489813528, 46.09347812591061, 46.754064098481216, 58.764083077830655, 55.002596762872514, 59.54718820510372, 60.67904303150793, 58.79197112975582, 59.159846305847175, 55.81686512116463, 53.71218404462261, 46.969002139183786, 40.88275055731497, 28.368634446974728, 23.820960021788075, 17.082504572406894, 12.361526104711718, 13.377913217390738, 7.499858102490825, 8.054315524716532, 1.1356706797115266, 1.0834112258688098, 3.165503985458805, 8.874340941829066, 11.651282925759594, 14.193494589098039, 13.711504916990958, 18.986795679215465, 12.065846074012018, 6.776705913005337, 1.5873611454040775, 1.9960529958048177, 1.9057944777511784, 0.8050143226019798, 0.6112424332288005, 0.3268157438405099, 1.1161237931059254, 2.885358011530292, 8.375501748054258, 12.370665227213214, 21.672228767025857, 24.707041094380042, 33.230696647397934, 36.720727489840606, 44.91674353999477, 45.748540970586966, 39.95072087933941, 20.95170701703718, 5.037425977568473, 0.4812050142115163, 0.14189564803194615, 0.2206863354771368, 0.11934804865309309, 0.12238505867219741, 0.14107401873315537, 0.1922489372232268, 0.1527764407857772, 0.21712292346262166, 0.12909198990992962, 0.15854629327452954, 0.08208324141319721, 0.14190298715426078, 0.2603767992508027, 0.220946989232494, 0.21579008369195848, 0.147191705783048, 0.12431994395991489, 0.147001670012551, 0.12981586638958226, 0.12485795218737857, 0.25591465884879716, 0.2258986444963563, 0.21677718798239387, 0.11895363594615653, 0.140378073819222, 0.14603892731810772, 0.18746787441834328, 0.1437772825480469, 0.08558865291096511, 0.1447000814181182, 0.14643764543917873, 0.14640821234112786, 0.16995334246706578, 0.2029868852226965, 0.1253933557158997, 0.1448323235156075, 0.3393900352379968], [0.013163075932571966, 0.04346004537036342, 0.015895383098282884, 0.04520119085246998, 0.019156124307623795, 0.044865567732842705, 0.026529569276458314, 0.06579547669858703, 0.0623424273104437, 0.049696625435664776, 0.05898952093576232, 0.07898486775135802, 0.06465569874572177, 0.015710867948890213, 0.0649858903019659, 0.035157494712620974, 0.04968101639420756, 0.009372807089089146, 0.02407322709088124, 0.10825333350728597, 0.0346145145745287, 0.027301130898957773, 0.11861106440905603, 0.04332600296625207, 0.05025369010024494, 0.0642322168324984, 0.037341036818801396, 0.08129639250616874, 0.0715481918004732, 0.09270558674489299, 0.05696741653786552, 0.017339090155738018, 0.023948147915483966, 0.004955564706300896, 0.029226878672958385, 0.021858045553428032, 0.08354125995068781, 0.05391773925493321, 0.05728525875677025, 0.0545514242032603, 0.0944971063384606, 0.04445249695451029, 0.034278833998307105, 1.4438250732998696, 10.399208434166448, 32.1464809679216, 40.85276403734761, 40.77115128117223, 34.22357405385664, 18.610752167240268, 25.247061252593998, 30.332802495648785, 30.723527439178962, 18.88807550553353, 14.115652211250799, 5.629910288318511, 2.870638336866133, 1.341577095370139, 0.33328786912945013, 0.09637176945445039, 0.17607443094734224, 0.053948857746417486, 0.03642052472118409, 0.22137748468066418, 1.8056243754202321, 0.7232439361753003, 1.045568933890712, 2.454987956631568, 2.739105575507687, 5.085731437129359, 1.0531541849336317, 8.543097761369522, 16.493309659342614, 4.014581172697006, 2.352446658957389, 3.901978505234565, 3.227803726350108, 4.251816416940382, 0.9475056346385711, 3.4967613845102252, 3.4923021399205734, 7.160119558534316, 11.798661082021653, 17.77722889377225, 24.118540440836263, 30.169745645215436, 33.42978439023418, 41.37837340754848, 34.83695822377359, 37.02270684703704, 29.67036516435685, 31.20322546651287, 46.83168388182118, 44.08606006253151, 47.631463004696755, 49.219862107307684, 49.07795467684346, 47.46916709407684, 44.589394292523785, 40.07126708184519, 36.842477859989295, 28.890501876031202, 18.791089019467755, 13.732398402306343, 8.437375176337458, 4.0677371332722325, 4.388153591463643, 2.3027436098744793, 5.190619537907263, 0.47566356317650893, 1.2807046069252876, 4.1617788999311385, 7.118564007743713, 4.733181451597522, 1.472246199846268, 1.0900256902940813, 1.4631434818429332, 0.8768198663188566, 0.8148127710146289, 0.844231773047678, 0.5655090679084102, 0.18227739890496578, 0.09165022402040421, 0.19593542892365687, 0.7262537424122134, 1.5112899628377732, 5.672122836112977, 9.497371200592289, 19.264015074699156, 24.1863307645244, 21.100564887446744, 26.56093170565944, 34.7423545775875, 40.30609153932141, 35.06904486686953, 21.444299836312574, 6.870206392580464, 0.5364303927748435, 0.03370047591987156, 0.06028039057949378, 0.011134829424742249, 0.03205809640818306, 0.024256375730938973, 0.01363358702585702, 0.13159499834141425, 0.028063713970984665, 0.09723521183214842, 0.035244698501041824, 0.04891141595679426, 0.04401560084173276, 0.05340951269552593, 0.025477180888335553, 0.04577520138193523, 0.035347120626078504, 0.040687565511513146, 0.03666623210113856, 0.05289133848442186, 0.07907977072341789, 0.050977329092641036, 0.07616109830597717, 0.02471099337262492, 0.016884715746968024, 0.04247347734147503, 0.0974820300395931, 0.048194545351209185, 0.04103703183993217, 0.04567923354766062, 0.07125973671434388, 0.04456844053141052, 0.01995386315449592, 0.03189765844464062, 0.05348829717765893, 0.04852489012503817, 0.0919402649085368, 0.20013337624409508, 0.13968125556505498, 0.0367882086204425, 0.04963317037289662, 0.08189928838081899, 0.03752336191434053, 0.030351308054260673, 0.046352923607393626, 0.04336336890475885, 0.0881580888263641, 0.106641331297015, 0.056457879968107715, 0.06239108538495437, 0.00405585907790209, 0.037894328500354485, 0.04695055645800406, 0.09439402920824867, 0.07160323521783275, 0.01489826316584743, 0.10273154028841566, 0.04485549750707803, 0.060639314263338046, 0.045216524102274454, 0.017759327686602072, 0.02349564659168884, 0.06170847423134312, 0.03571760457670016, 0.07070322746350881, 0.09482990259364729, 0.05738568905320379, 0.08090873669472434, 0.05307805709420674, 0.04295027131334909, 0.07192368213568004, 0.008932167679191598, 0.010149331046118131, 0.07027568911472637, 0.04122584570018996, 0.016844725957320585, 0.07655128986845094, 0.03762400288495325, 0.028312958761929508, 0.03807091559734076, 0.029531124746426943, 0.015121564389236513, 1.9780992043595162, 12.753831763421337, 37.28441522967431, 46.27210286355788, 43.67647440202775, 41.16928362077282, 22.780119872862294, 29.01946548492678, 40.324707108159224, 36.503243830896196, 26.556171909455333, 21.445390255220477, 8.441826085890494, 3.444622543550307, 1.1024349663526782, 0.2448745044849573, 0.099150286086144, 0.03091853487515642, 0.17611936966498054, 0.10562785059934664, 0.4342425067818934, 0.7537428157464151, 0.9860491728590381, 1.6817968651171655, 3.170884251594544, 2.6764672850408866, 5.281272867033559, 5.615567161190895, 7.329912589442346, 7.7267529983674335, 9.21353574722044, 7.183095822411199, 6.925837368734422, 5.093370253039945, 4.740172586133403, 2.8570093262580136, 5.0907094151743, 7.114441106396337, 11.612588744009695, 15.238604237956388, 21.497359698818578, 23.855206235762566, 31.437171313070486, 34.725778641239295, 46.004416788778, 38.20043771497665, 40.384127093899636, 33.29098347694644, 34.358287857424834, 51.12109376538185, 48.90129504665252, 50.46457529067994, 53.372491098219356, 51.45316162417012, 51.08396068696053, 45.94078025510235, 42.506905986416726, 38.188737284752634, 31.223988533020023, 22.931439030554987, 16.363684150480456, 9.867348767095997, 6.6566607932890625, 4.6937601604769315, 3.4335234617033317, 7.843563633580362, 3.365453669140416, 3.2033175951050175, 5.640055989065479, 5.186883480318132, 2.625866258336652, 3.3197271679678275, 3.08536873709771, 2.954549111666218, 1.4775899389097769, 0.996141799034611, 0.5565525194810284, 0.39165816119601654, 0.14419054101792075, 0.03281896152803975, 0.1478022165716656, 0.33663827805749835, 1.787846110040142, 5.971626687434412, 10.366528226483254, 20.76985809110826, 25.809209462135072, 22.381169719080773, 28.095635521796446, 38.15340457424041, 44.63584300010435, 41.130322717851215, 25.248757677693522, 7.845689067917486, 0.4530072789038382, 0.06882668743210454, 0.016422312736751574, 0.06068056809806055, 0.0478484689618551, 0.07314483394786235, 0.03818097561898251, 0.024293638247575973, 0.07769338140684752, 0.12799821553691743, 0.03848792406760397, 0.009338990052891596, 0.024029923970961285, 0.08891703681119027, 0.03654695987220734, 0.07292865159650964, 0.030100257211034338, 0.06211021839971505, 0.009864067673803338, 0.06276985840691675, 0.02424935645033275, 0.04194892544840132, 0.03415969583476263, 0.05017726899935834, 0.07533576880251208, 0.018666046371142712, 0.016268330979191007, 0.031625513370419224, 0.039274880226941845, 0.021140048798594265, 0.0555566426426653, 0.05680453475384463, 0.029431382013905435, 0.055112288663944894, 0.010816589797726803, 0.07353302602085375, 0.04187778269331302, 0.07861537588459831, 0.09955143270593497, 0.15933980714649926, 0.14694001525640488, 0.17942297062085522, 0.12873085606242382, 0.12746229106860776, 0.18036129043227245, 0.17881336381598828, 0.4148770297967619, 0.2304717144297977, 0.15755307560245838, 0.15096297277317894, 0.1610752414431303, 0.2060004606121971, 0.13647647995141246, 0.19359162888459622, 0.14900859054778853, 0.2093003230590013, 0.13822588769178237, 0.17662665776668057, 0.17582494675392107, 0.11077479699686651, 0.15693229923565544, 0.3419445094562346, 0.12003332962312045, 0.21240527741611007, 0.11133604833195287, 0.2206197011494829, 0.1538564868631863, 0.23623960573346386, 0.263171334780993, 0.18349524887819446, 0.1721057737426412, 0.07509216050347013, 0.10958919932525005, 0.234294738320093, 0.14862131778030627, 0.2093214977292284, 0.21519527770578864, 0.17886751091047642, 0.11721466998419455, 0.22274349605844868, 0.10464619319405287, 0.12583587108360184, 2.613435776964311, 15.763061411919134, 41.899056280812914, 55.16038194779427, 51.665150042503114, 50.31875333478374, 31.885761022567753, 38.446652735433275, 44.68183279037476, 43.34155890249437, 27.520384634694746, 18.923876939281342, 8.237379404806322, 4.057878991288524, 1.7703009805371686, 0.5844681505714694, 0.3637070449129228, 0.35100356044788517, 0.5520143984786926, 0.37256942581265207, 0.7715400188199936, 3.8204741045351955, 4.306014747388901, 4.792291079798053, 7.822968738694345, 9.44623428006326, 14.557299325543067, 8.48412492582875, 21.216210088422223, 28.38395130249762, 12.678106484874604, 9.842606456049028, 11.008178957047003, 7.150304807770637, 8.597973681265309, 3.051511328066549, 5.4309063861447004, 7.602200094730624, 11.60286714953761, 14.71229080230959, 22.748762484519716, 25.275539621230095, 32.201060748869374, 34.95029903227283, 47.28234068039925, 39.90103621636668, 44.54675420638054, 35.88832601424187, 38.479153494681086, 54.49815250212147, 53.428761420711396, 52.84682681483608, 52.93995957220755, 51.6513942903088, 52.287689024402255, 48.33876048364947, 44.56362432049167, 40.57666055617794, 31.888065415043986, 23.80803385088521, 18.17015036459892, 10.718907098616324, 8.701005520359162, 6.424459420865582, 5.6463401163778, 10.433152625637671, 3.4234589049893045, 5.002583073031518, 13.026594365796736, 16.64675081929853, 10.31129046793907, 8.329547259115405, 7.005447754936834, 13.474469223330098, 5.121240164003065, 5.257855336512289, 3.081781484426991, 1.1122323115987163, 0.4230107997934665, 0.48422980512822833, 0.9011020956020203, 1.3445394654427807, 2.534744941419171, 8.24447105007787, 13.620907971935889, 27.15662990846942, 33.74508019416563, 30.897790501194617, 34.53423753861458, 46.05897695787492, 53.374511118858095, 47.64551685702416, 30.6712402835969, 11.382741774282149, 1.063523338206353, 0.1117720136479024, 0.12381252562326771, 0.14919917790159104, 0.16418975657753407, 0.1357074808930197, 0.16481166675446496, 0.2886343813471256, 0.22475533487816013, 0.24782242613934705, 0.13645357392247648, 0.15286159911944022, 0.12414827131696286, 0.17303548272578947, 0.10160945896660128, 0.15333015381568862, 0.1631436328734121, 0.20946264176839785, 0.10058611105646818, 0.09636101357999349, 0.1716101148556317, 0.2015973243021196, 0.2977282127305385, 0.1257227505407026, 0.1826389464399507, 0.08950040510465061, 0.18565684256534423, 0.12049155745414958, 0.15547873932988415, 0.15046064892122823, 0.14131559689919795, 0.19974403503921725, 0.13101534557438668, 0.19930912692460323, 0.13792161289001667, 0.12804579725789447, 0.16537458816122624, 0.24584247189904415, 0.25883359173613213], [0.03240678707257875, 0.06087356096794529, 0.017748221326919816, 0.04173678038040957, 0.04659809089536148, 0.013214494796439767, 0.03285649600588987, 0.06213929909732073, 0.017729323853047627, 0.05550645239230606, 0.06940290812523135, 0.07731121078494095, 0.018721976535274618, 0.10144762289259704, 0.02998664062620411, 0.025310570171343225, 0.06877882991947475, 0.025534467028093435, 0.026300784778751196, 0.03556186273213356, 0.01025000840590726, 0.04178696296988957, 0.0731972803271586, 0.01827943435449514, 0.022019207470058914, 0.023659110602532184, 0.0549596801189886, 0.06882131715575535, 0.1323266276308606, 0.005077882134731138, 0.06752327309861299, 0.09973232904749532, 0.02534373794802495, 0.05198738537728787, 0.05300330989543469, 0.02261029218413657, 0.04601377648331466, 0.03824767506410999, 0.013542125703796986, 0.009434103699130638, 0.04275585351992519, 0.0392890107187052, 0.06167858531097732, 0.08589265192107809, 3.8110917950830157, 20.14741716846343, 32.841693624373406, 45.11567438802412, 41.67996052772769, 27.706954133126047, 12.861474348652749, 19.539806727440126, 18.90201560912594, 13.98350069599767, 15.207506706637723, 12.479144257883872, 9.950402994309703, 3.2626326574433238, 1.4691405406882687, 0.22142950205072282, 0.057038643562625495, 0.03962069231596205, 0.17220095250635378, 0.07314532424413389, 0.37001740307577197, 0.5270434255080839, 0.9555830818510825, 3.005859106779099, 1.2416116917325606, 1.3281980132864368, 6.70841891919413, 7.000935558349856, 5.266495337409358, 5.4266334541382335, 3.4787834459735505, 5.5154089485445335, 2.8703909823971414, 2.25360440150384, 2.069828611227774, 1.54464224413518, 2.337331070053962, 3.423494696617127, 5.043912597240941, 10.705652429211526, 15.300193294402092, 20.75907353431948, 24.142386490298858, 27.353913361026397, 25.503699971783547, 27.371699348572765, 22.083432405225693, 26.113679524390932, 40.33512100096672, 37.28109690450853, 42.709790583579775, 42.348148053692235, 39.800274449010054, 37.53103033188851, 34.389596216140255, 31.286375791795795, 23.769206308549453, 19.134990669065907, 13.882836007302808, 8.26736004121842, 4.305092500102136, 2.4663174777261676, 1.301213577389717, 1.8906272851651715, 6.659582468771166, 3.312201855644103, 3.8574801962221827, 4.862278911375231, 4.0771064498732175, 1.9854663961356687, 1.8930994815403417, 2.0849640571301986, 1.6345537550026372, 1.0652334916014825, 0.6832257706311442, 0.38522366614591697, 0.40564983782749026, 0.10946215896476662, 0.08634197014954784, 0.5684253501315271, 2.145648026658643, 5.315479367010055, 10.647548398663922, 17.079986410756266, 15.07413729544609, 19.27022614786702, 28.66261216901964, 30.22629837835989, 40.661497500634965, 39.85542297363281, 22.87366447910186, 11.10303363492412, 1.1075398085578796, 0.10641361932240187, 0.042333367521003376, 0.027428000804878054, 0.038472284382629784, 0.018072674884611083, 0.02450561669144419, 0.024325124461263902, 0.011712546862151113, 0.019580142482394175, 0.030375380452061375, 0.06559185818919251, 0.005714277597895313, 0.0623252286365436, 0.0258039576076572, 0.009455005450534725, 0.0594521614332353, 0.045672327265023224, 0.044042168770946806, 0.02987662082417838, 0.017311380755516793, 0.0443578582827843, 0.07654453297295878, 0.029336145793598507, 0.02308809547685087, 0.018752430445484577, 0.0199694300611173, 0.048022853556059064, 0.01949835302037818, 0.04359084339211545, 0.02903613044069179, 0.04178089555352927, 0.10401031723426235, 0.04805785611331944, 0.01017645055863766, 0.04521503023082211, 0.03228805110519452, 0.06895175128574334, 0.03391901399159143, 0.009591010954952049, 0.012429076558609885, 0.04953183992315204, 0.05648038763132307, 0.07062352367586668, 0.013592002815717171, 0.09126190171246568, 0.032909348411785985, 0.060926888348354455, 0.059911607344064026, 0.06150043922506514, 0.09047699866876488, 0.01746586238544795, 0.03732882537728837, 0.02880030367974072, 0.06564979741890585, 0.06834638094709766, 0.09204121997519847, 0.03117210997809326, 0.033840401879241394, 0.03457566625588844, 0.0453420284564697, 0.02775562596657584, 0.042919604813740145, 0.04315130044555953, 0.10314094533603038, 0.0658692279830575, 0.02280480190811138, 0.04075778130021307, 0.053344092617232, 0.03824445366438839, 0.03570944574030657, 0.05931991550530638, 0.019601974073016358, 0.050363968456945116, 0.03592232625270563, 0.025489187401328838, 0.03424891060398471, 0.06406674184085381, 0.032914948514512474, 0.0458505959250033, 0.05909804495111589, 0.030963249512076862, 0.00742528613867058, 0.08848448824738303, 5.127432115616338, 24.220061186821233, 38.003946581194484, 51.5630978153598, 47.121162645278446, 34.61611309359151, 19.878250398943504, 25.267622317037276, 28.916997486545196, 21.349349060366233, 21.8305120929595, 14.75744120536312, 9.455382227897644, 3.8853010775581485, 1.14584555308665, 0.18888633217542403, 0.11100572654076162, 0.015367773556781393, 0.16938216263248076, 0.1913435132272782, 0.4397934266636449, 0.9634870867575369, 1.3010060594927881, 1.2758409904856838, 3.366491871495401, 4.204683255764746, 2.5815010647619925, 5.523144352820612, 6.118085047891063, 8.026787840550947, 7.6935721981909975, 9.189696561905647, 5.47913977215367, 4.007489037129187, 3.288901996228003, 4.02391053015186, 4.159104333769891, 4.96113391653184, 7.430464509994754, 13.498531983744714, 18.05977879032012, 24.23288537609962, 27.910950722232943, 33.59986620564615, 29.855961914985414, 28.854776928501746, 25.792413873057214, 29.762735020729806, 46.57660038240495, 42.1304565091287, 46.86637724599531, 45.563146222022276, 42.83653805332799, 39.64229314557968, 38.14025678942281, 33.962606999181936, 27.81914176479463, 20.771164240375644, 15.0763249974097, 8.270542064020711, 5.610226363905015, 4.3926559821251905, 3.928445188268539, 3.343624208242663, 7.426222956949665, 6.71704666268441, 4.203631570262294, 5.326267846169011, 5.2059707141691645, 2.9695867434624703, 2.145393072597442, 1.564009314583194, 1.9270491888446195, 1.2047176327436202, 0.13009662229207256, 0.5046829737482533, 0.6335465009174039, 0.13497010594414127, 0.06888091113538512, 0.5173580516730586, 2.044676780220001, 4.921743023780085, 12.883865198781415, 21.45633759037141, 21.922934901329782, 25.91323660266015, 33.11435522571687, 33.70396591001941, 44.75271001938851, 46.021953705818426, 27.941643268831317, 13.592975793346284, 1.5694291721428595, 0.07624949719155989, 0.04882457989057706, 0.03006008164506526, 0.02379517356354383, 0.08217533284257497, 0.060199039702814434, 0.010476701483581095, 0.07243138392485919, 0.05229147631795176, 0.03377150759221085, 0.03827526955114257, 0.033337484309149366, 0.07717093242512596, 0.05759984510199678, 0.01522316296975459, 0.07811993916308688, 0.015510079176766018, 0.04067556857461891, 0.04231757078800471, 0.02086883835164049, 0.01784349968206258, 0.040232432675698114, 0.020762564719564492, 0.11268094632654421, 0.029649127184623675, 0.05645399973277123, 0.08274981451611366, 0.028971250454384475, 0.08023733723788493, 0.055970307139139024, 0.04775468064772506, 0.08554363758453438, 0.019983244541611885, 0.04368918992939495, 0.06375810799879894, 0.0030179732129909102, 0.04706479548927277, 0.11223094627982187, 0.10504062122274792, 0.16720854136491978, 0.17170389933932215, 0.227158016435081, 0.08920983561585027, 0.09165623014973057, 0.2864913576312604, 0.22915594309808748, 0.12711110104235912, 0.20034326901358945, 0.19523240535730318, 0.19183649080655268, 0.17985168874504107, 0.1879401676236622, 0.12763839169976213, 0.23608300203998245, 0.14891635356170518, 0.2937186617524393, 0.14651215515069424, 0.07361515064633663, 0.150128687701879, 0.18412311921917623, 0.15840925546663423, 0.18871164880692962, 0.14047314533062522, 0.22742176518565227, 0.18268707208335402, 0.15844423504125688, 0.1535411037865185, 0.21831397568025898, 0.1114247153483091, 0.13919406961048805, 0.19661530131293883, 0.04286874423644716, 0.12691711225817282, 0.1383263524621725, 0.07471829427466278, 0.14974547520039544, 0.10291831252435524, 0.14011889095267943, 0.15346817221612702, 0.11157226388252552, 0.21644211644607209, 0.1484774464681264, 0.28133273605377446, 5.806083054311815, 26.615788013704364, 44.850482940673835, 58.896047299908055, 54.39887731306015, 41.13612782570624, 24.01554684485159, 33.34799120503087, 31.25322391909938, 23.17089972957488, 23.469176369328654, 17.649977399456887, 12.732527409830402, 4.848158378754893, 2.4623683864070527, 0.4999453940939519, 0.5990256597438167, 0.25674021051776025, 0.3440560009931365, 0.9502531936572445, 1.4361610071312998, 2.408577492160182, 4.688700793250915, 8.692658716632474, 7.646270865394224, 9.929204544713421, 16.857799829975253, 16.934136998268865, 14.581416999140094, 15.725030110728358, 10.916668099741782, 11.8557600052126, 9.731662215725068, 5.909369357170598, 4.5590115458734575, 4.568646357905481, 4.890619506759029, 5.558784969391362, 8.17537751889998, 15.358644454709946, 17.15591565255196, 24.19654461645311, 26.53023719787598, 33.82468469681279, 34.50615729055097, 31.67620251255651, 30.592647752454205, 34.88370895385742, 49.40552749941426, 45.03985889496342, 49.224011974949995, 46.04562128743818, 42.21552879579606, 40.80733514601185, 38.114106347483975, 34.352996580062374, 25.58906839739892, 21.732688180861935, 15.374025048748141, 9.927326709993425, 5.407729591092756, 3.855522933506197, 3.7921114458191783, 5.272528923326924, 13.487195353354178, 9.320682152625054, 11.752575193682025, 12.016172197557266, 11.78879043748302, 6.695083841200798, 5.939458349058706, 7.715392833755863, 6.490240510432951, 3.6728951719499405, 2.376734220212506, 2.2045899735343073, 1.6921477548537718, 0.678331510674569, 0.3048305832330258, 1.118582506333628, 3.0538117981726125, 7.431490700091086, 14.72554841349202, 24.680814166222852, 25.143820547288467, 31.110596733708537, 40.005065318076845, 38.66033169531053, 52.81406325678672, 52.09408083269673, 32.88670674447091, 16.399175716984658, 2.382682249430687, 0.21571822464466098, 0.08509212068372196, 0.14877203791852922, 0.08325940854246579, 0.12131543139055853, 0.08202508767886509, 0.18470834910629258, 0.10509578721417535, 0.10941700574250952, 0.07044143989802369, 0.1487360777513635, 0.10543202320414205, 0.1898064037724849, 0.16358485355252222, 0.14957278366050414, 0.189773814392186, 0.14128142937777505, 0.11336881667375566, 0.13355511090447827, 0.08967672024042377, 0.10599743439665726, 0.0996182125902945, 0.15088037317318304, 0.20490676284797732, 0.09408395512089615, 0.12737908625915167, 0.11867946073893579, 0.11703273942393642, 0.2192586846649647, 0.14257185852095006, 0.12124000237353387, 0.2520022171759798, 0.12325592444188173, 0.13176393605047657, 0.14019393692574195, 0.17840516152641467, 0.1619362629829876, 0.25119019461975944, 0.2574769419527823], [0.061455420068194794, 0.07314008420273181, 0.024163734633475546, 0.02286475211862595, 0.053683572989558025, 0.048286039232006, 0.04014315278900247, 0.06879681766393685, 0.0651927110588839, 0.06531407470784842, 0.06216160374723616, 0.11530558653776685, 0.02628223012922512, 0.02835579456821565, 0.03355112324859347, 0.024530820984153018, 0.046016377351817586, 0.032097639951614604, 0.04943014175120381, 0.043575150080986565, 0.03559324935439133, 0.020330351319224126, 0.029281945072955666, 0.04136399050513583, 0.03476653706222292, 0.03260040047368215, 0.05907366420292567, 0.07077387609188596, 0.016285317063692118, 0.014782712209008396, 0.02815528637579372, 0.016211048669872746, 0.039986434182332414, 0.038989079635470145, 0.015059035335246836, 0.062285277151292374, 0.011517396497149623, 0.020366550888866186, 0.015855202744264277, 0.09693387880801194, 0.06452535654628469, 0.04190690552575454, 0.0546901282523909, 0.008699555614692791, 0.4156029747138101, 5.874753950103637, 19.191717947683028, 38.54279002835674, 43.27931481022989, 28.728209887781453, 27.615806095061767, 21.78559114856105, 17.412309223605742, 25.484201869656964, 26.10578771560423, 21.122273245165427, 15.821132102320272, 10.995804859745888, 4.6082588645719715, 1.4723831150800952, 0.4804836351784968, 0.16101298913840326, 0.11374170231001993, 0.06859976452805343, 0.49608345293710315, 0.6355249689471337, 0.7933900721611515, 0.7681186088631231, 2.133696564743596, 2.553575505172053, 2.465847528749897, 2.697867491552907, 2.9023970327069684, 8.972461973467182, 6.756132591155268, 8.149862991225335, 4.1458751597712125, 2.1911181028812163, 1.3486759725116915, 2.7051631000734147, 1.2693330429254042, 2.637795411771344, 2.7087562362993918, 5.556652670906437, 10.130259356191083, 14.713450843288054, 16.26599261837621, 21.64999677288917, 14.799461557019143, 19.53221497997161, 16.144723719166173, 20.676391932272143, 36.03464218877977, 30.831831924376953, 36.410911237039876, 34.225382266506074, 31.659079405569265, 28.739929929856334, 24.561472131359963, 19.97011034719406, 15.841540194326832, 11.734037091655116, 7.1883679782190635, 4.062656683306541, 1.8423952474709482, 1.9962325668142689, 1.9209590962817593, 1.4003838430489264, 6.907949889859846, 6.502330726192844, 2.3367633069715192, 4.383523233475224, 2.726696422023158, 2.8795298597505017, 1.3362600774534288, 1.4116963263480895, 0.6215507897638506, 0.5988117679953575, 0.16873451190129404, 0.22913406362697003, 0.3591222538342399, 0.35681225359439855, 0.5134851094936171, 1.8791417272821551, 4.2950546645349075, 8.073937181503542, 7.419777031867736, 15.32766067212628, 23.777286391104422, 18.40763811142214, 25.95283685191985, 38.575161349388864, 40.03038813990932, 26.43268196813522, 11.538278460502626, 3.224985013085027, 0.1690315088677791, 0.08246143603877676, 0.059506687741245956, 0.08048205636441708, 0.05031608796167759, 0.07405296989506291, 0.03516919670566436, 0.05771051799397796, 0.05709479014659601, 0.03337216893992117, 0.03696342058960469, 0.0225911112577324, 0.06852109495910906, 0.0665838654423433, 0.020875260083665772, 0.03619771187884673, 0.07276530632929457, 0.023164106720697977, 0.029909133595684846, 0.04851517996059791, 0.01783059301575826, 0.02348643821483899, 0.08140808812552884, 0.029816724239818515, 0.01739792762354257, 0.028270695606366764, 0.008600490869984271, 0.008077640649712375, 0.02511772094294429, 0.045064501614580234, 0.010776889206270778, 0.043480561204975655, 0.04426000970265558, 0.06777297945753222, 0.07352417004444907, 0.022949906621849345, 0.15867943935576947, 0.051958423423310446, 0.12066797984223213, 0.049371064880922924, 0.09409929986201948, 0.03738521327895503, 0.04232834198422009, 0.07821475020459584, 0.09628311775985265, 0.03784271715689571, 0.08181083586908157, 0.02033017128856192, 0.028342797886580232, 0.055994389113038785, 0.10830106844584789, 0.050291439082713864, 0.0248842882067566, 0.02656235783961752, 0.043540162845484676, 0.029965446803778894, 0.03532154861116602, 0.02161267333694043, 0.019774102538283315, 0.03984369284984085, 0.022727352334186438, 0.02324214426710481, 0.0269802377348946, 0.068227032109374, 0.022559596315747308, 0.05046770059233231, 0.06982614105987935, 0.13401655630478937, 0.04180850153188071, 0.0666237403188021, 0.016460203445486484, 0.04829374224608464, 0.06603172289267664, 0.017390653618701526, 0.026169456241111604, 0.1126100525500313, 0.015703688747429802, 0.040374982486208605, 0.03441101863920208, 0.15685049636710077, 0.09714719599052783, 0.01498275979106585, 0.04599269374363846, 0.0535147616850032, 0.6553037656891731, 7.843736708164216, 23.821809214930383, 43.94798478772564, 50.079316169984885, 35.758405347024244, 29.079301241905462, 27.351442267817838, 19.213351780368438, 25.783929786374493, 27.692641404367265, 23.440758797430224, 19.540095021647794, 10.54775349555477, 5.282882999989295, 1.5301847554022268, 0.4318645392214099, 0.26312487920926464, 0.14499752271559932, 0.20510234509504613, 0.2567989847833111, 0.3016374981211078, 0.90202440417582, 0.6102178978823847, 2.6825072448099814, 1.1607471276675503, 2.9821187161630203, 4.5590958768321626, 4.341811768470272, 5.492112030906062, 7.652719241957511, 8.454415913551085, 7.155960865559117, 4.873765082128586, 3.3810990231652416, 5.175852304504764, 2.509141915267514, 4.276986756632406, 4.577044642740681, 6.624626796091757, 11.13398309676878, 16.01680640251406, 19.44718191700597, 24.058934142512662, 19.103754874198668, 21.52202944601736, 19.358161764760172, 25.94203660565038, 40.73832496520012, 35.17654134381202, 39.22376055871287, 37.20888999200637, 35.05492825661936, 30.33117667321236, 26.480036743225593, 21.923507567374937, 20.234015257127826, 13.957961163213177, 10.611373359157193, 6.125962147789617, 3.127883552543579, 4.016748527365347, 2.936872950484676, 4.189390424759158, 6.406855333235956, 6.533247828483582, 5.726869808089349, 5.638959196306044, 3.5355528900700235, 1.8974093083412418, 2.17152169635219, 1.7186819761991503, 0.8051335258829979, 0.7162330059274551, 0.2261405444193271, 0.26714653437656743, 0.11430804046892351, 0.22961590228782547, 0.5541617735739678, 1.7382181988608454, 5.017742053154977, 11.28083565542775, 13.196137835902553, 24.846626481702252, 23.241667132223807, 22.154586161336592, 30.42721002332626, 40.81990634241412, 46.119777617915986, 32.41325313045133, 14.708285081771113, 4.034131001080237, 0.26615742293577044, 0.04390123923639617, 0.06422982280773502, 0.0422041361490565, 0.0815925850803333, 0.11406797149609174, 0.00807656238095895, 0.02281883855410401, 0.014212229514434455, 0.026176757059029998, 0.05602811230346561, 0.013875689962127758, 0.050712906184696385, 0.058858895283793254, 0.09276606172563569, 0.03264492933428095, 0.0032777248998172586, 0.10643159940598473, 0.06470355625835157, 0.03247219182911419, 0.03889575097409468, 0.03207227478044168, 0.05275279531375535, 0.0959826121106744, 0.17284820487181987, 0.03789275802010971, 0.036152129647352045, 0.03574781525399416, 0.02875501830731669, 0.0018241037070120295, 0.04624488605787197, 0.05613987687073889, 0.027069048392736626, 0.0001988907892917914, 0.06495122482339222, 0.0430831607551344, 0.07694158868323411, 0.03165687509481946, 0.06611457530168757, 0.011516174586910394, 0.12057173621630478, 0.0916736126847325, 0.11673303050619942, 0.2211996450299217, 0.16318075749422276, 0.13599255753140296, 0.14885698174757345, 0.14754877936455513, 0.1397303158357259, 0.16469987920455395, 0.1788773168359072, 0.22390053397224796, 0.1711093078577711, 0.12700288346217525, 0.1964673390912433, 0.13246602498956267, 0.22357934394911413, 0.15569111422425316, 0.14498054620719728, 0.1694291851092731, 0.06945982079712615, 0.17244944078547342, 0.273336187726067, 0.24384137363203112, 0.2634035513526009, 0.255035404416342, 0.14808730853180732, 0.24059260924977643, 0.17367607012631434, 0.10619758252775478, 0.16594328587093662, 0.141555673532909, 0.17821949245708604, 0.1821708054311814, 0.08229612192559628, 0.2778444619428727, 0.239701357880427, 0.15818188057070778, 0.12211757907343489, 0.2611030812465376, 0.27944138754279385, 0.18613498868240466, 0.10851152045952697, 0.19241572988610114, 1.0754678133995303, 8.666732830386009, 27.487297481106175, 51.6504176201359, 56.95790221614223, 42.69001791554113, 41.53220876570671, 33.55538260552191, 27.99522480657024, 36.06291071061165, 34.73143862139794, 30.1433833952873, 21.40273447959654, 14.110687471205189, 5.828277295635593, 2.4254770240476056, 0.9178028123513345, 0.44963799356933565, 0.7531713141549019, 0.616269440900895, 1.4572599265844592, 2.270913330777999, 2.6561324923269214, 3.580456428950833, 5.814745608837375, 9.468057367109484, 9.613036013418629, 11.85131105684465, 10.4170532572654, 18.291761490606493, 17.49435736287025, 17.688089109236195, 11.940718543144966, 8.55037473863171, 5.483632356889787, 6.906573628225635, 2.9822805139326283, 6.3406177778397845, 6.1942324715275925, 7.410937970684421, 13.735444122745147, 17.593530570307088, 19.69512866389367, 26.496948042223533, 20.956808059446274, 28.301034358239946, 24.943183468234157, 29.938945539536018, 44.5789647102356, 37.66552056035688, 40.70363160102598, 36.00784455576251, 35.96195674711658, 32.70977058718282, 27.174431585496475, 23.005901305906235, 19.533242640956757, 14.32361137482428, 11.190297545925265, 6.934961782347772, 3.5205873318256873, 4.9092399785595555, 4.719663002798635, 5.578008505605883, 14.426719700136493, 13.368851561700145, 7.917234570749345, 12.891108835897139, 9.646466374397278, 8.77841055393219, 4.472391393876845, 6.187697802820514, 3.20561929095176, 2.3759718095102618, 0.6586303646045347, 1.0099984909738264, 0.51792936940347, 0.8606850740409667, 0.97099217436006, 2.6138792499419186, 5.900715627977926, 11.68081739256459, 14.055800764791428, 23.93001367968898, 33.06519223797706, 27.071730206089637, 36.58654712861584, 49.654276371002204, 53.93065614085044, 38.66162999983757, 19.32091493760386, 4.998248363694837, 0.5903567313667267, 0.1446191212462802, 0.22243163698623258, 0.18439953906401513, 0.21863602372186802, 0.16045772861088478, 0.1222817900200044, 0.12151005602772198, 0.14120033131011073, 0.17555039616361742, 0.18761392142022812, 0.17717830235919646, 0.17454427757090138, 0.17418711205884335, 0.16417448078432392, 0.10765154079924669, 0.17909548335498382, 0.19600341156605752, 0.1429638350682874, 0.2459292083738312, 0.09971402720698427, 0.12295471399181312, 0.2060296332403537, 0.19130546930095843, 0.11515899561345579, 0.19179927425519114, 0.22882194408485967, 0.15725932684877228, 0.119116299395119, 0.189936179066858, 0.14481341646563622, 0.15654937784758308, 0.18369723562031023, 0.14997170096443546, 0.13124866531260554, 0.1575235812173736, 0.20484356059422418, 0.14204451423739234, 0.2147345217846094, 0.17753945152846076], [0.039529585309566996, 0.2382206631403777, 0.10004562070412983, 0.09705508157851235, 0.026212037323162924, 0.07139685879191084, 0.04769066634077219, 0.04219754013202844, 0.002784427957639339, 0.08333443153289058, 0.11337719001476804, 0.044894123660220255, 0.050119509800307216, 0.03342888242895565, 0.048088162551603975, 0.025559654083823966, 0.03126867153050919, 0.06392342977285867, 0.015194409774736533, 0.06535419473244299, 0.01913267052582195, 0.048619777775339545, 0.06140219994009503, 0.057887813722294186, 0.06081114012387492, 0.05415007073972976, 0.056272371777243195, 0.08931861244021885, 0.03620113246142864, 0.018767440023141044, 0.04923156026991145, 0.03746107130521729, 0.03678328267508938, 0.008823307542761248, 0.021776438037294055, 0.013151116342464042, 0.05225496073704093, 0.0351215422063345, 0.055022127776136326, 0.05257566429434284, 0.022056889419834462, 0.048008837977484356, 0.044467401195077166, 0.03566498965806058, 0.07474653227555175, 1.07563010146541, 6.566775758420268, 27.49442246652419, 29.320311277143418, 42.346987032121234, 34.4988852162515, 18.670254522754302, 30.188037618514034, 27.16758312717561, 30.264004122826364, 24.605873361710582, 25.729304898169737, 18.152042742698423, 10.480727053457692, 6.582941316789197, 2.748736220021402, 0.7383051021925865, 0.18260715379109307, 0.06718125314481797, 0.28385794571330475, 0.15111753867278177, 0.7182804831574041, 0.4374187073159603, 2.016798901942469, 0.8778296927771262, 1.350356585556461, 3.173308521509171, 3.488129228353501, 3.1997114660278445, 5.156312036898829, 6.913119573746958, 4.365404334760481, 2.8935420368948295, 2.0606779667638966, 3.1891377366358236, 1.8938887359634524, 0.9489454509269808, 1.510201014818684, 2.2829942309087325, 5.42536505768376, 7.087761144484244, 10.028843533608223, 13.476277435979537, 11.096341090817607, 10.123346178762375, 10.914946179236136, 17.376823540656797, 29.953240617629024, 24.220216120443038, 29.29087388900019, 29.554364988880774, 24.90492663075847, 19.234763999139112, 15.493877972325972, 10.242835302506725, 8.807758708154003, 4.445942361508647, 3.4946447755059893, 1.0800659344080956, 1.1678518883643614, 2.950106046853527, 2.6815796042642286, 3.256611574080683, 3.660572555757338, 6.8118537818231895, 3.7303721135662453, 2.2094426808818697, 2.692751004811256, 1.1030152319900453, 1.7189574001296875, 0.3259777968689319, 0.4668634805467821, 0.21674717265752055, 0.06885742287962668, 0.30083828455498146, 0.25482672206576795, 0.6061494194211499, 1.8810107366692637, 4.2366035042270545, 5.944888380266005, 10.641023535882274, 16.79124701407648, 14.723173418352681, 21.38389337447382, 27.206632283426103, 31.500798040820708, 36.20000147050427, 28.28436036263743, 17.228118642683953, 7.691711033544234, 0.5766952386306179, 0.1087096844229006, 0.044791414252211975, 0.06285061173501515, 0.01980680874699066, 0.06266526442261473, 0.04200707535229383, 0.05128278750024977, 0.04364131709500667, 0.0664191029124683, 0.05048202260607674, 0.03255408279778015, 0.037039263294108456, 0.03903583015104936, 0.014960244466971247, 0.004006694427751486, 0.014287952517700053, 0.04693544920413725, 0.002777208057757948, 0.04964524008814366, 0.06857524971447646, 0.03464857867408184, 0.009446661795429405, 0.04944915988392407, 0.04327590847688337, 0.05369311078421531, 0.047164340954153776, 0.015527109311322774, 0.0315547076940176, 0.06813579869847144, 0.06824735642200516, 0.04313404048462549, 0.050251456953945665, 0.06179152965365399, 0.04386547825209076, 0.07884175486622319, 0.025340650613690098, 0.06710576284075938, 0.031811084763537494, 0.06465889333236603, 0.07394191778955922, 0.026326548315644748, 0.11107634452562179, 0.037962330294953245, 0.019175592516999573, 0.05442816065624357, 0.08323775889772562, 0.08482215129920552, 0.07295634567497239, 0.082093583600175, 0.06986000980701178, 0.029672642253459464, 0.04180776225703378, 0.008750778168529995, 0.013699625720149808, 0.045272655364486485, 0.0204004502795156, 0.028420375780232494, 0.02602236161399032, 0.024977126571860526, 0.023656624647217895, 0.032781227867329316, 0.0012692585427899875, 0.033573799451152166, 0.04118784773914565, 0.041822570736610123, 0.020436743694928386, 0.12036683067919747, 0.082891050485834, 0.01758602327637134, 0.005569073292727192, 0.025189917068928484, 0.013499673899082888, 0.030574779732212908, 0.05479031340068868, 0.012538538074060794, 0.03692808095365763, 0.052978921486365224, 0.03780582236246236, 0.0076558479603620316, 0.03214214199913606, 0.01222737518424589, 0.04536304607867234, 0.0825534891637583, 0.0323303391586148, 0.05785370748790522, 1.7716136262301476, 8.8518226146698, 32.886620452327115, 36.75958641113774, 46.54269933700562, 40.85958503907727, 22.11317377705728, 27.896492865777788, 26.056975779994843, 32.59426070797828, 32.6825552217422, 29.850025407729614, 22.760253067939516, 11.65919630758224, 6.829546122781693, 3.020419925451279, 0.7010338827967645, 0.2514432947481832, 0.07329306430033139, 0.08255361939870542, 0.17058479809953322, 0.4898559242006272, 0.27217482907637475, 1.1493876985003872, 2.266654372215271, 3.3067399551791534, 2.4919138848781586, 4.054229470991319, 5.22347919402584, 5.803365832374943, 5.561122702014062, 6.351960291785579, 7.0802630436035905, 6.7930710219567825, 5.500851071649983, 3.19213810466951, 2.9940559594861926, 2.3389407127134265, 3.447214985086072, 6.075725901511408, 8.58000530350593, 12.79942245252671, 16.207659129173525, 13.577569703901968, 12.60284894897092, 14.848775556010587, 22.459793629184848, 35.084196982845185, 28.61067802675309, 33.883398655922186, 31.49329846905124, 26.604128768367154, 22.73179234996919, 18.297821552522723, 13.279830428861803, 10.933822585690407, 7.027476276120833, 4.936540165255147, 3.8272529407855007, 3.1014587898408217, 4.881842222905928, 4.3913503231540805, 4.4664872461749665, 5.965691651067426, 5.227082381325384, 4.697814420346291, 3.9939507313313025, 0.4097522386620122, 2.528101917236082, 0.9314465318476001, 0.4547487806168295, 0.3924963533157303, 0.19369157271519785, 0.0945375174764664, 0.26981267357064836, 0.03482757128715035, 0.6874006433833031, 1.7140621595805692, 5.373552999188823, 7.358783195095678, 14.366850603011347, 15.374761473747993, 17.295779528156405, 27.582307092605102, 27.82233653529998, 36.96731513546359, 42.783903767985684, 35.229065802789506, 20.91144192603327, 9.493460597530488, 0.8287640288472177, 0.05699180494693499, 0.035093055226870125, 0.012233052853374712, 0.05073398509393296, 0.010148348538355242, 0.05680587540771212, 0.061946685440958514, 0.026563257992928548, 0.08708212599759141, 0.03059844227297412, 0.0569470998861136, 0.02342860049177562, 0.043623804325057615, 0.005990837732585328, 0.05610231941025104, 0.041284087534633376, 0.04470223395694648, 0.04485092013173046, 0.06641360240117197, 0.06866892694585747, 0.049650227320530725, 0.013941462440866859, 0.035061450269553936, 0.03190291955346062, 0.027813561365849553, 0.030347833845524058, 0.03231089584709656, 0.03359326574530813, 0.0825582312480096, 0.07039679229379663, 0.044160487220412305, 0.059290463255057414, 0.06835405714809895, 0.09128165912003287, 0.02711472830044166, 0.07222191250372319, 0.06782816843159738, 0.03543155117621345, 0.05905065858255952, 0.013931284962792792, 0.1372640030158143, 0.41735753056503117, 0.23089199026505794, 0.21989841404701435, 0.1834798658326749, 0.19073998916053003, 0.15592241149035194, 0.13242346114448963, 0.16674643712899379, 0.23064766950424642, 0.12279849334229385, 0.23527024403935481, 0.23313247568665013, 0.10239607038637323, 0.1332983795192934, 0.14563962697021424, 0.14167653156384347, 0.15504963816173617, 0.18370992203633632, 0.2585847970218428, 0.1447589322924614, 0.16790679986438445, 0.17638903261432726, 0.17462272497434772, 0.1413637991513937, 0.06991781114089875, 0.2585756346102684, 0.27342247986985796, 0.11282964399264706, 0.15148031194844555, 0.09920483920723201, 0.10735071339314023, 0.16288835705528337, 0.12911379277225465, 0.11281271344952046, 0.11677579353413275, 0.1673266874446023, 0.09193388339612754, 0.21023252948878274, 0.1687816109868788, 0.08647781286028125, 0.16012285625742328, 0.18196357864766352, 0.10295978086369653, 0.1949313634465779, 1.9221686571836474, 11.569063182800047, 36.821516713788434, 42.94851387700727, 57.56137063426357, 50.20897403840096, 29.180323846878547, 42.37787961959839, 41.24406360810803, 44.2286656748864, 36.06085146627119, 34.978351823745236, 26.57527385219451, 15.238009998875281, 9.26236435290306, 4.604896903038025, 1.3841381212396007, 0.679867854041438, 0.4767184049612092, 0.8123980618772969, 1.0685659127850686, 1.9783937498446436, 1.5001677144919674, 7.182790858130302, 6.669467822197945, 6.4552887601237146, 9.664442596897002, 10.7413459977796, 13.015425416731066, 15.47722064679669, 19.332264315697458, 9.983570556486807, 10.423440837091016, 11.228928969752404, 7.825218217988168, 6.321514854508062, 3.2137827238728924, 3.5548656602059645, 3.097233906868966, 7.066405800081069, 9.895847728175502, 13.244790915519962, 18.123813444568267, 18.52460515114569, 16.326778569529136, 18.908342392213886, 25.61271244479764, 37.21460096297726, 30.439736112471554, 36.36367805542485, 32.66072527054818, 28.3716134871206, 22.947897295798025, 17.39394860882913, 11.675207422625634, 10.834906293499856, 5.597407077589343, 6.162464214909462, 1.9581141154612265, 2.9616596333442198, 5.932469666004182, 8.680987704184748, 10.634518284951488, 10.709881724849826, 17.559517737357847, 10.005083776289418, 10.927214372542597, 9.70882813776693, 7.301476386285598, 6.888315975666047, 2.717984102426037, 1.9138891466202277, 1.3071536392934862, 0.5148078369036798, 0.7961630040118772, 0.6555174122894964, 1.4021446195340928, 2.6589065886312917, 6.087305228556357, 9.561398010100088, 16.581900312054543, 24.823364865395334, 25.19403669141954, 31.99515396548856, 37.22193971756966, 45.51539136517433, 49.14844359121015, 40.455408327041134, 24.5809486604506, 10.266526418347514, 1.0868370484921241, 0.3145751296993225, 0.14746924411625634, 0.1616224886909608, 0.15325173705575929, 0.20526216635780953, 0.18762063235044482, 0.15513314174548273, 0.12987456404634062, 0.17259055418112587, 0.1788989358371304, 0.185759850747643, 0.13411688317935314, 0.1369596975705316, 0.11693384513379106, 0.09971865437804692, 0.16280051741388538, 0.19347535205944894, 0.10869971761900572, 0.17952548850688244, 0.16744802045004983, 0.16372376061495275, 0.07737859587876067, 0.26049695248084687, 0.0885182727248438, 0.10976559873069487, 0.2274077764201549, 0.18896785925232595, 0.14187926907212506, 0.19343542355683543, 0.28228302215856893, 0.10875149750180783, 0.175028077416843, 0.12922174988254426, 0.14946334033964143, 0.21936777558538223, 0.2441195095138204, 0.19579546465989084, 0.18736137287510982, 0.1360671744952279, 0.1530346277380182], [0.03865103184756252, 0.0062509083035101574, 0.028261816647324352, 0.06716231545132977, 0.06872104390734626, 0.08095703853835022, 0.030997999260322224, 0.004555097989542711, 0.058558906743963884, 0.05216438616175325, 0.028963007348319216, 0.07655300590540133, 0.04285215077200725, 0.08513734285389224, 0.027431865718456048, 0.04077484973916604, 0.02536529949265382, 0.0022399819581844513, 0.06607045629812826, 0.05825939317864757, 0.03748515327911704, 0.02321456510183071, 0.04321079100331953, 0.04517771791847003, 0.0519314264848588, 0.010713492557706853, 0.06377051096229304, 0.03886193585311694, 0.045715419710764, 0.03649350991773029, 0.01964702004296405, 0.005360677746319843, 0.026964186277661114, 0.01586614918309234, 0.03347980812372219, 0.05240965687159089, 0.029179704893801003, 0.019180250331579198, 0.08378613995568407, 0.06866171039761075, 0.05069342456878193, 0.017940969048668782, 0.06525632700011616, 0.03436558962529225, 0.047003473981373736, 0.07542671110000342, 1.987360410632626, 11.873533245055906, 24.36209805550114, 41.086109761268865, 34.88754503188595, 31.644407779939716, 19.911547399336293, 26.217377185821537, 20.59208058541821, 20.32324525617784, 27.295360219094064, 25.6502220707555, 23.21104322710345, 11.822261002755935, 8.813430455423171, 4.627934453948852, 1.5378325192197677, 0.568883225562111, 0.1759433992687733, 0.14709390699863434, 0.21019823939329196, 0.1497757663169215, 0.3513445615047409, 0.27110426716746827, 2.581633689903444, 1.3130966429748845, 2.451563482323001, 2.827283398758981, 3.514679752049908, 3.961349951644098, 8.21018365121657, 5.792622460472969, 5.077573887763485, 7.351365502803557, 1.3265855514234113, 1.9911302986644932, 0.8408208431736116, 1.25122235667321, 1.5420918455046992, 2.6957011174771095, 4.861546899041822, 6.952009874005472, 7.646966595803538, 6.063085573334848, 9.080503659863627, 16.60135526810923, 21.541217680900328, 25.712170024071973, 28.52198931478685, 25.525859402072047, 19.49644688637026, 10.996700140737719, 7.8668227984059245, 5.058878400633413, 3.8282668734750445, 2.5277947466219626, 1.2222326090258937, 4.874050434558622, 2.6554634830644055, 2.4240527133787833, 2.060684830911698, 2.7885281751232767, 6.088574605603372, 2.4623286724090576, 4.793786483426248, 2.4108255005651906, 1.111160523949131, 1.27649026532327, 0.23682439128958413, 0.20608123692293323, 0.250597074027023, 0.2499792547596078, 0.1507723241323425, 0.2696783630357635, 0.9865783863971311, 2.4058766951484065, 5.138189706110186, 7.620504325436008, 14.287035272967431, 14.678634905046033, 24.237998185619233, 19.999908593393144, 17.930866172236783, 29.94628429412842, 33.831180141818145, 27.38871459038027, 19.444634337579053, 10.204004818393338, 0.9431492909789086, 0.1250249210504755, 0.046179347235949776, 0.05138822801170811, 0.08657551205326473, 0.03743058866671017, 0.07102414935586915, 0.03871410769680816, 0.031876972155465234, 0.03430269380670882, 0.023899549212787422, 0.08439218445170311, 0.0719813225911029, 0.00882398265774452, 0.035475539944825635, 0.06702228223965054, 0.0775272399187088, 0.023386816141165556, 0.04721320204196438, 0.03774492986380093, 0.08400033813931289, 0.05703377890430632, 0.011236967139637039, 0.022889433556326458, 0.08523109669406569, 0.0759071784634744, 0.032384781196953795, 0.026859163284121503, 0.011912686374759483, 0.04514506342069757, 0.011727019220650678, 0.03723907434651929, 0.031608144241955974, 0.03559500369573793, 0.02739854472418947, 0.015403229063526999, 0.03309356191405847, 0.034473236469972524, 0.04368804845838778, 0.03485373702020415, 0.042350669616773244, 0.04431618309970345, 0.03293394749503463, 0.092469738916524, 0.04272783002365501, 0.01880564865836453, 0.0631368528270433, 0.10757389778812086, 0.03557942529779769, 0.08424371661197755, 0.08056271776196458, 0.006868388577018895, 0.08215775878559198, 0.028716763706817746, 0.026117620816934976, 0.016799770002703995, 0.04261595054319309, 0.0819568139230532, 0.02739934911650996, 0.04012687725105113, 0.07136173366058259, 0.033077588980837215, 0.06477729222106357, 0.06219284481278831, 0.03670240294248347, 0.03673700330358359, 0.04390724919616215, 0.05819426421376486, 0.13024384906936076, 0.08385960012674333, 0.03192334154230212, 0.04898667643447557, 0.0397246849212435, 0.04433937258117142, 0.022060342561153155, 0.011805802745173776, 0.052361623158738504, 0.005841063234143921, 0.03370976473595347, 0.04545579251322535, 0.07564460182742727, 0.14145787474849533, 0.03354597896818192, 0.017059766837666114, 0.06628219533952014, 0.042380796024395574, 0.10530862176129896, 0.07699241095613088, 2.9510341776955515, 14.46162683348502, 28.57077379380503, 48.87257152988065, 42.82398254640641, 36.286544645986254, 28.214420580094863, 31.41946965648282, 28.120891663335986, 31.255181181815367, 32.92936055890976, 27.194988727569584, 27.634555024485437, 14.655447813772387, 7.873829132126224, 3.7655508710492045, 1.3587992422042356, 0.13305516192509284, 0.14824872325745322, 0.14078555598614678, 0.3760796406817052, 0.11578105134709228, 0.6713453403884365, 1.0922250367941395, 0.33121599965999204, 1.1383193827444509, 2.639526157609878, 3.137823574004635, 3.118118811999598, 4.100264613666843, 6.192248242516672, 5.320565210234735, 5.959595307227104, 5.24374362922484, 4.357802781366534, 5.201656597275888, 3.504527432303275, 3.59993516437469, 2.738666270048388, 4.429711103439331, 8.046405084671514, 9.680052649590278, 10.309924502526561, 9.270255181097216, 12.045264417125333, 20.867252503671956, 24.535366796678115, 29.20132225559604, 29.920773198527677, 29.27545112948264, 21.55977245300047, 13.56950923319786, 9.530979048821235, 8.159734616356513, 5.607449325823016, 4.546947806112228, 3.9791788401142245, 4.216093430596014, 4.416491245069812, 4.633207100052988, 5.132565027283085, 6.109036630199802, 5.0182549030550065, 3.1828161016587293, 1.8740220536147396, 2.920213173474035, 1.5347858181884213, 1.3671222665617544, 0.7476854504596803, 0.29287388127657676, 0.5318477773858655, 0.1565274064459147, 0.08515833366301753, 0.32891120881803576, 0.42140940024006757, 1.6560449114730282, 5.77550474674471, 9.639914055024425, 14.739463021678311, 17.599718109253917, 29.36572644018358, 19.89537350593075, 21.127072265071256, 33.96981239318848, 38.090591738300944, 31.835725307464603, 23.60942659839507, 12.45906956734196, 1.4625595389835297, 0.036017317324876785, 0.10974024122040119, 0.019902234574058847, 0.030454475199803713, 0.0446803659771479, 0.11655494570732118, 0.013852391313130577, 0.06811855405929589, 0.04879358014272106, 0.01083161373953185, 0.03332749069217713, 0.051009669494364536, 0.054780032500744834, 0.021203791144334024, 0.05979881621897221, 0.031173871980319103, 0.12020982861999543, 0.011317020454894633, 0.038308437327824296, 0.03648243611678481, 0.03609470369654798, 0.01903104513222652, 0.022219083639943314, 0.04511429349921885, 0.07682149674022391, 0.02189259037315365, 0.08539622694614434, 0.026836207459470438, 0.0928466924796662, 0.05949516577886478, 0.050741975390983206, 0.04333114341622399, 0.059985209241389274, 0.019474684733957536, 0.01521729282103479, 0.0036469469599861412, 0.013811297399262268, 0.023826345681182803, 0.024586029110416293, 0.027711673587140058, 0.045405563958469904, 0.2602516817710092, 0.13172832828375602, 0.20649029723098203, 0.14466956047521484, 0.13580498856402215, 0.20573419909323418, 0.14348848272235165, 0.18874316566413452, 0.12751044735552805, 0.24749377441983073, 0.2944182532448923, 0.13863124013427766, 0.15265466344933357, 0.23600253216441602, 0.15103077155447778, 0.15772847909360163, 0.13230937533080578, 0.13834492243345708, 0.21126541519357314, 0.13176552951335907, 0.17171923641956624, 0.2496407817929022, 0.11262139065131066, 0.1593798888666976, 0.23552274661919764, 0.13169953869956155, 0.30000502604150003, 0.1540076819759223, 0.21829057935505145, 0.10204977566196073, 0.12013344965394467, 0.12443304918105565, 0.20491339716940157, 0.13107139256692704, 0.1370307292428709, 0.21693658023591966, 0.11780481815578477, 0.1702254875412872, 0.18188591265389997, 0.3054163340599306, 0.12524497980672505, 0.14609862088916764, 0.16484238688022862, 0.16597938393392872, 0.271127954606087, 0.1935438556416381, 3.2857665515715078, 17.511833483173003, 34.31633026369157, 55.622244957954656, 51.66698963411393, 45.921811672949026, 34.52331373768468, 42.212759602454405, 31.873256506458407, 33.01940641095562, 38.15749168395996, 36.65823628825527, 32.098992832245365, 17.77022942419975, 11.49018627981986, 6.651453356589041, 2.6220262579379545, 0.8091572035224208, 0.6291954279426606, 0.6765908976235698, 1.4666661379798767, 0.7623530924320222, 2.5662781009750986, 3.1433460260591204, 7.153610385233357, 6.695396159925769, 8.441499548573649, 9.68144509100145, 12.7481129477101, 10.84184104396451, 19.009582688731534, 14.335233357644851, 10.912800642751879, 16.60732315432641, 7.751198680170122, 7.743829527208883, 3.6653602988489213, 3.1786071533156983, 2.9364115816931573, 3.556589787044833, 8.294358695707015, 10.22535918220397, 12.783633931990593, 13.517838870325397, 15.291132619304044, 23.654610341595067, 25.694721360360425, 28.97961812634622, 31.92723224239965, 29.494180140956757, 22.855794160596787, 15.00458876932821, 9.61401072240645, 7.801533966295182, 6.125390462337002, 4.385611895591983, 3.0171283214322986, 9.029552071325242, 7.411403752142384, 8.507110995631065, 7.029524733943324, 8.407375908667042, 14.188099368926018, 7.498738756102901, 13.713401382969273, 8.170436803371675, 3.719057546507928, 3.8885880237625496, 3.2174062584677054, 2.3493153818192023, 1.4175829459582607, 0.6336733650776648, 0.551925716140578, 0.9652878223888337, 1.8138070524700227, 3.5826215772859515, 7.072040775129873, 11.58460851638548, 20.406387736720426, 23.502520438163515, 35.52631085918796, 30.655852825410907, 28.81915592378186, 40.199552120700965, 46.1662616268281, 38.83127250979024, 28.596379026289913, 14.428029771774048, 1.9622185081243517, 0.17751646889073236, 0.16808470080216087, 0.08969969521727293, 0.17943561107160585, 0.1620897870030134, 0.15235480131401172, 0.1259134681294522, 0.13077208201491064, 0.1413159952649186, 0.11552484090169592, 0.0966997393557141, 0.11371561701619819, 0.08416227380474729, 0.18239890044975668, 0.2653289141674196, 0.12070699670021573, 0.12638156317294608, 0.17981508506401894, 0.09360323494841015, 0.18359827238225168, 0.14895966817294398, 0.11719377876649942, 0.12057291599170816, 0.20723484276283174, 0.20397613455931987, 0.14338061754261294, 0.2743590683225663, 0.1575445260612234, 0.18174273082085196, 0.11869174878924124, 0.20004843241505085, 0.1503928654616879, 0.09987675960385993, 0.2031824827915238, 0.09181923833825896, 0.08191863210090707, 0.1557681826694358, 0.1684242922572359, 0.12167952233745206, 0.14691278849157596, 0.13545605083627088], [0.07771579713951196, 0.10194335838839894, 0.06138277961121452, 0.07979459970468476, 0.03557844087481499, 0.08303722772266596, 0.023783938884134256, 0.07251201467888971, 0.06890705005536157, 0.10178147634911923, 0.03572451852021679, 0.042838771046409686, 0.03906777984793148, 0.0524835383910085, 0.03598042636088306, 0.0669913859136643, 0.05818893990269112, 0.044797144589885596, 0.07214740279220766, 0.04666303216870274, 0.03770623859318514, 0.046029588538071806, 0.0431962889589129, 0.0443723373445532, 0.03927701378181096, 0.08882479216422766, 0.06651899311691523, 0.057349774851313526, 0.038257791255150116, 0.05810892201900002, 0.02864737720829585, 0.02243963460768423, 0.09561474435031415, 0.04668601097599153, 0.0351408016567509, 0.00892635690228593, 0.01546016759088924, 0.03530762879358184, 0.034795472203123, 0.12250686665215801, 0.03537829657415709, 0.0398086060229088, 0.027976952598340092, 0.009784586051659239, 0.05952558713033796, 0.016738854521404833, 0.11389864308218803, 2.529669149268058, 14.355168804045647, 24.33418646935494, 40.16177969594156, 35.69218004903486, 29.012805300374186, 19.30113442482487, 17.74655007546948, 23.431186253024688, 26.7777269886386, 28.088798830586096, 14.185662596456467, 24.325598439862652, 15.057392697180472, 9.469211524532689, 5.818428714429179, 1.9829392865780864, 0.6367819047262592, 0.2395241157782655, 0.21924622807531588, 0.14484173107531764, 0.2913980894992429, 0.3278915764343354, 1.0744250758040337, 0.325704027688311, 1.4115894417608938, 1.8752415430161262, 0.3275052229723623, 1.7485850232262767, 3.624418598990287, 6.0387492276007135, 5.175848872430864, 3.053453636746253, 2.719947493845417, 2.8576854448164664, 2.782771851747267, 2.3546954028068052, 0.8944732900108061, 1.6046599010306022, 3.0523543925054613, 3.7308847183181397, 5.151628236616812, 2.812340884439407, 5.488587291009965, 12.344448104981455, 19.06451156062465, 22.990878628146266, 28.375265213751025, 22.835984230041507, 13.509210636538844, 6.436996296528847, 2.6995109646551074, 3.4216293644520546, 2.418860721011316, 3.2126604357073387, 2.815652345457385, 2.867668857497554, 2.3676664358185184, 3.886382671133165, 4.860999238106513, 3.232417904561566, 2.058713104455702, 1.8320461963453603, 0.912109308185116, 2.156122471055677, 0.3407628035112735, 0.7770065770995233, 0.3537731521552609, 0.12922034028076357, 0.10881960271827637, 0.20057635892543102, 0.33104914571008376, 0.8298893200774348, 1.321871352772559, 4.117203614404125, 7.994838664608618, 11.135898194005414, 17.671069945058516, 19.863665065457745, 9.834223370398245, 17.88544512564136, 22.12570182738766, 32.50838041305542, 31.70345514051376, 23.13258013417644, 11.61657093032714, 3.305220527033652, 0.054155034989479094, 0.03461200946701631, 0.04094693223915754, 0.01454420318271244, 0.03429058961750519, 0.04620585387812988, 0.11625580369464814, 0.016925548233332175, 0.039485339901500174, 0.06801808928890575, 0.025394146533442602, 0.01709846768438095, 0.019293277028707728, 0.02921228278278103, 0.05906625230225825, 0.10303738557042615, 0.02627509018977083, 0.0930517588952376, 0.020015209560252486, 0.005036154283105486, 0.027981328875607545, 0.02665479209334139, 0.0760314379247927, 0.013303444307718067, 0.06392696526862922, 0.04673124846792029, 0.03040461628247173, 0.022383712104431564, 0.03299190204650645, 0.053396745840267795, 0.05894898339324902, 0.014812216170192247, 0.012986781864216732, 0.012255365164169382, 0.01239067544379542, 0.03278339589615503, 0.0184216030362633, 0.03259611804218542, 0.02611096159765317, 0.030606365537330992, 0.019781089260152752, 0.0238499335283714, 0.04419655463988743, 0.018899701272828445, 0.03424831688584339, 0.10919448018314377, 0.0649157166481018, 0.026093667162762537, 0.0409212070066602, 0.06359190522362629, 0.059162844498191154, 0.049388753851094556, 0.04381742538704027, 0.06875545657690495, 0.11365177124858865, 0.028012566110720078, 0.05011477920737478, 0.008850533349980271, 0.06909896274127307, 0.06310670726722287, 0.03760362111572777, 0.08026902263443317, 0.07575271215530173, 0.01827987677027141, 0.055185162777742075, 0.012076277747720241, 0.0371262334257124, 0.06669192214406307, 0.03315721615968693, 0.037772160459069476, 0.03332251112066931, 0.05509694009238193, 0.034695972703517444, 0.04158856151925941, 0.02416741951639133, 0.01266769475243505, 0.06961198884152597, 0.06117056559530958, 0.040211100957446524, 0.07277472921076321, 0.02010780469244046, 0.08331026145887953, 0.07531107012783328, 0.07628282967714534, 0.011828286468141503, 0.09401184326458363, 0.06588862532930029, 0.047602321081344164, 0.10597658914423759, 3.884212864983467, 18.09366806860893, 31.418377276389833, 45.84985186976772, 43.86274383914086, 33.633363246917725, 25.580974586548347, 19.655810825286373, 24.404836200898696, 31.3934878764614, 43.24256220171529, 26.086481809616092, 26.791784763336185, 19.409766427932247, 10.19154639013352, 4.675439749994586, 1.8569744522533111, 0.5768381599937716, 0.2666691696691898, 0.13455119374538624, 0.20789876520153017, 0.23041454894888788, 0.3159644761152806, 0.49004956058436827, 1.0337193310260773, 2.115737012317104, 2.2461563108428835, 0.7581679847451949, 3.0802385220604562, 4.8555363570490195, 4.119724717832381, 4.5013468207851535, 4.929131788592185, 5.2972570157820185, 3.101838279154993, 4.758572424611738, 3.769675978729802, 2.1204541527455856, 2.289803220379737, 3.90452804584657, 5.776096534344458, 7.29891311737799, 4.962627849271221, 8.081303392687152, 18.5382765723813, 21.158690491030296, 26.917775215641147, 28.358069542915594, 25.569003512782437, 17.06184937107948, 8.657062226726163, 5.915835874695932, 4.187547401074441, 3.9954552054405217, 4.373022558227662, 4.193754061575859, 3.673170718454546, 4.545780900985965, 2.70441000500033, 4.553640840515014, 4.065739175965709, 3.6936594641977742, 1.8724290810285078, 1.6961824028722703, 1.8827315540082994, 0.7865207149617134, 0.9126953348036736, 0.6940917778880366, 0.056845800079885996, 0.11497933267345352, 0.17317555424186493, 0.12170134818241482, 0.7921606542602663, 1.7467942160944787, 5.71894318826737, 8.402514130838457, 14.336155114635346, 22.278193773761874, 22.042369111891716, 15.770338389181322, 22.09427775875215, 27.0946741104126, 36.26482255997197, 37.52127931964013, 28.70069838339283, 14.626643888411985, 4.098381630835995, 0.2032874674806672, 0.023817780818189346, 0.05217927125012202, 0.03500551052932297, 0.0713474001555193, 0.07348771192013256, 0.12293933094629358, 0.014703154935681773, 0.01826217630878091, 0.07949060835545102, 0.04649972903632349, 0.066332105967787, 0.07947627485038773, 0.06401714913907551, 0.06181464252632953, 0.10093823570998446, 0.12929838931848928, 0.046551317397144534, 0.00870777765334013, 0.0448203762061894, 0.08775488909093604, 0.027567583939901767, 0.05989991301189988, 0.05046825983651704, 0.036617857479159875, 0.05911777937604536, 0.016953328496686394, 0.022073264549215956, 0.01312408205722609, 0.0849413239367066, 0.07341605971657461, 0.04305439798401729, 0.04328820801850769, 0.048949007891238704, 0.011165372392673407, 0.01785454475471089, 0.0496698736453489, 0.02109587233844063, 0.029720524663946805, 0.016309458409406005, 0.060825534915972146, 0.07326705561530206, 0.24155930495790898, 0.245982114405882, 0.15265556743308423, 0.22855545273951947, 0.13537107636370968, 0.16304755012594885, 0.13474038681916653, 0.19882073055111593, 0.13001039143531554, 0.2694939503506307, 0.11965293632519823, 0.24183253787698286, 0.21659213178340467, 0.16079771843168045, 0.16657674865376565, 0.09473382750706327, 0.1933116390700302, 0.15915973051901788, 0.1489336977923109, 0.18083122408678456, 0.14770933607172582, 0.1219400228752244, 0.2416874867893996, 0.1555063491386752, 0.17176210669980896, 0.22731540153824517, 0.1742984246342413, 0.1464148619843106, 0.18568708771659484, 0.20029013315516137, 0.09936978559820883, 0.06727159023284912, 0.18013403811041387, 0.14794567419636637, 0.1710552067285584, 0.14546675156922112, 0.18301855832819017, 0.0972417389012633, 0.10157439512230697, 0.31601304608968, 0.22587606022434853, 0.12985225556598556, 0.29747825356260427, 0.19092510664655318, 0.1792808613109012, 0.27200616715896514, 0.27418691304422194, 4.051090839409059, 20.63943143813841, 36.25126684865644, 53.99665394136983, 51.94973368798533, 43.909286683605565, 32.64870320597003, 29.20851392130698, 36.22967027848767, 41.99537792513448, 42.0782026936931, 25.177176383233842, 33.35132129730717, 21.377758787524318, 13.68128207422072, 7.600938562423953, 3.2147429691207026, 1.2978044248396352, 0.7968653534208575, 0.6560459516702161, 0.5544793629838575, 1.3531661057664504, 2.5908772455107782, 2.662545322410522, 3.5292079660200306, 6.048084468610826, 6.311750113964082, 9.755295476605816, 8.132397167144283, 11.161950576689936, 13.541092641891973, 13.476182318502858, 9.530734881278008, 11.650604355719782, 8.071293994303673, 8.623717177298762, 5.110906189487827, 3.4741753964654865, 2.026951589411305, 4.544231074471628, 6.539824662670013, 9.86782435447939, 4.823675434435568, 9.408114725543607, 18.13875767492479, 20.901179044477402, 27.46563619182956, 30.714353015345914, 25.625103212171986, 17.116939060149654, 9.692452242297511, 5.463584632642808, 5.157742231122909, 4.497725492523563, 6.566965503077354, 6.2065943114219175, 8.202784099886495, 6.931641495996907, 11.923523852902076, 11.782489149801194, 10.953368736851601, 8.876172688699539, 10.337684096828585, 4.392525563316961, 7.8936836796422165, 2.845039478232784, 3.615788649166784, 1.6490474030856164, 0.8229963060828948, 0.5184955390230302, 0.784856955851278, 1.2909378255567243, 1.317684835483951, 2.4888041807759196, 6.380851980178587, 12.106168039383428, 16.59853704514042, 26.768944801822787, 30.244092210646603, 20.09396899131037, 29.98537659645081, 33.84999967390491, 43.30634778545749, 45.12809261198967, 33.13200589149229, 17.913129214317568, 4.811065504627844, 0.4240105445346525, 0.10279555459536853, 0.17957123927772048, 0.11696101061158604, 0.1123594728508784, 0.153785991452394, 0.2586930605673021, 0.10657219952272792, 0.1381787119974052, 0.16232931205341894, 0.14469032145796284, 0.17099405759044234, 0.17546016632789568, 0.07129152936320152, 0.1737024235509096, 0.24031312505324043, 0.2362174045054182, 0.14874740053088437, 0.12878782236047331, 0.2073566660645508, 0.18131002903945986, 0.10195606778706275, 0.19849845268312963, 0.12269890191213739, 0.1721366470859897, 0.1276288692268633, 0.12348332998132515, 0.06220513669353339, 0.16117065003322018, 0.19472988232249216, 0.21647171808346627, 0.09980173661343514, 0.12341514815606418, 0.19282560224734968, 0.11994951194332493, 0.14471897314633095, 0.1926654592276581, 0.15594415306564302, 0.09887624877474963, 0.11301936566709511, 0.15669536356243396, 0.13010236795150465], [0.023332362611507697, 0.01708684804578943, 0.011841169194198184, 0.05231118392980388, 0.01614449095101126, 0.09182100800136406, 0.04844483393695086, 0.08851001429702006, 0.0242135169420151, 0.02707295735637027, 0.01235701258279263, 0.04159079083511907, 0.018473110957852295, 0.06159413560864426, 0.08262956169463935, 0.04888137764928322, 0.15790720740633626, 0.006927240887776979, 0.08695851005012951, 0.03605078387584898, 0.05682143465345425, 0.06290876163890766, 0.044573833790397456, 0.018166265931100618, 0.010599353117868306, 0.05139521856401717, 0.024052410566758727, 0.018258175414596355, 0.05644619712726243, 0.04616700938992924, 0.039644605750518466, 0.04872355970644182, 0.06988826312965925, 0.020801681168978254, 0.031067648143958182, 0.028558721683258494, 0.08888318338581631, 0.08753447027336206, 0.02524994197301567, 0.04241393315756033, 0.014974846102808033, 0.03986901205573832, 0.04042271742477052, 0.04010010630853715, 0.15805841784083074, 0.035742582873471325, 0.02147175720892847, 0.02256891002968675, 2.985169094416403, 11.25194053496084, 27.18459248542786, 39.59529138380481, 38.37319850921631, 31.669703145180982, 27.754607008349513, 19.162774778181507, 20.9895618115702, 14.295543874463728, 30.648335602975664, 33.65492843812512, 15.722700222846, 10.900923705870106, 8.737528670218683, 5.78028513539222, 3.811254328297031, 1.241662314822597, 0.4483658892493095, 0.041496500733398625, 0.16949917490203537, 0.3845330225604196, 0.20403253395230542, 0.5193431387024542, 1.140244285906515, 1.403292035383563, 1.1585088026139045, 2.0622677524243636, 2.354594156626732, 1.3754629415850486, 3.1450473541213624, 3.117968781340507, 3.7422451280778457, 3.827756965352643, 3.4105746544176534, 2.9941400452967617, 1.0479435613078456, 2.383117142223543, 1.4665629306147177, 3.1489795302191093, 2.9117143779031696, 4.479244755160424, 2.4983335791095613, 9.962528021104875, 12.711978112497638, 20.48132265767744, 15.617334573499619, 11.365986389498557, 8.82429934317066, 3.8500801545958367, 2.3915009633187325, 1.5790820025628614, 2.517065348163728, 2.459186608752897, 5.333490400545059, 2.0289526110695255, 3.183740310130581, 1.4115811067242778, 4.376328135690382, 4.9038177920926005, 1.7962588586153525, 1.9481364637613299, 0.40151694669358196, 1.2011725455522537, 0.367472704139448, 0.18250679627301233, 0.2720335931066544, 0.301485015980659, 0.3113025246608642, 0.28016497290903525, 1.0540807223127735, 2.703695643332697, 4.611932654534617, 7.799679175499947, 13.345458545992452, 13.159210681915285, 17.590392674169234, 13.114997725332938, 18.241653211655155, 21.712207525007187, 30.17953391998045, 36.172890047873224, 29.641208225680938, 14.604665867743956, 5.768405256732818, 0.3610932142023118, 0.034640255128784526, 0.03044337841622051, 0.05445162209892466, 0.025524712813597535, 0.06680578579224887, 0.010707416522857404, 0.011527390114121861, 0.02537192998363847, 0.00845316737409561, 0.06557472080232636, 0.08176678581343544, 0.004181575063886422, 0.02041927689025479, 0.08817303520176681, 0.0031310774765217738, 0.07979633872427287, 0.11687431244119523, 0.01962905911157929, 0.022231840919102394, 0.03327947996196247, 0.045770516754278255, 0.04023156699634368, 0.05170171119032368, 0.05713345843457407, 0.05799892711483183, 0.04234406976930557, 0.009110063828918482, 0.10870672732351289, 0.04086011532513846, 0.042948677850466584, 0.05838847516344921, 0.05905461542668843, 0.02110351598070514, 0.021198892012058247, 0.020520708846649336, 0.021446240735390497, 0.049652157862099915, 0.042693601215198156, 0.07829967105100233, 0.04543015921127893, 0.04690776661699338, 0.0696801630059077, 0.04834042764419029, 0.03360096492894715, 0.09022153132865507, 0.04399626478252392, 0.04336976573892659, 0.035649644916937236, 0.026887661754904736, 0.013833219005215554, 0.13508288940835383, 0.033562411554157734, 0.0965907633484852, 0.05799873942329038, 0.05616438402343662, 0.05432213408752315, 0.08985311198498934, 0.029527405389554562, 0.045780901076091875, 0.04760403711829455, 0.08857482533541419, 0.027449836225939855, 0.04455601458527869, 0.0859083337408881, 0.022472204835785013, 0.027800060981403918, 0.020313384386921124, 0.0935000658876473, 0.054663610118891925, 0.015168538027923676, 0.07533173918003037, 0.028464299431371114, 0.04182952298452297, 0.04370637711197619, 0.012470615761084183, 0.06830755561109512, 0.0688214703733402, 0.043481361766856526, 0.03037754656566728, 0.10577931384285612, 0.03560094853803035, 0.025140513973911444, 0.025418950545210994, 0.0638109144394196, 0.04406859880433448, 0.052213266401761965, 0.07003663137795464, 0.05006541250153415, 0.02294740342955676, 0.1088685021104832, 4.988438515893875, 15.79143681833821, 33.67154359817505, 45.479121208190925, 44.17808278914421, 36.59363877388739, 29.618497702383227, 23.553983896009385, 28.178707399675925, 21.879888849873698, 27.00562454039051, 40.12386214348578, 21.66936347561498, 15.165345149655497, 12.378604104441981, 6.369136841066423, 2.7025753163522293, 1.2813243414125135, 0.23116936005892294, 0.1656139753158054, 0.11629493546582038, 0.5159005847188735, 0.23134549899447351, 0.29957905051208317, 0.7521703130295201, 1.109082158054075, 0.8219576134316383, 2.449896720147902, 2.708804040185867, 3.957155957337349, 4.284949658378478, 6.4388991363586925, 4.879922713002851, 5.763060537076766, 5.059257399651313, 4.285992518548043, 3.3191005693327997, 3.512496953049014, 2.4804291850136173, 3.3429811846825386, 4.86286481541972, 5.752229892438458, 4.4451549456965544, 13.897371330568868, 14.629999476094401, 22.765383528124904, 23.47970989442641, 16.495906268396688, 10.132673575032143, 6.057619750499726, 3.386018901102005, 3.9715258056117646, 3.2039363489997004, 4.269525918268388, 7.315154671669007, 3.786084478901279, 5.887913502031758, 5.173627340024518, 3.0622510227464863, 3.1972053166358703, 1.9784359153239959, 1.7940549768747824, 1.394772279647089, 0.6673822756255827, 0.879291633684789, 0.7547951141192067, 0.21490566582689363, 0.05860345858720042, 0.1187203928167301, 0.27214970139245837, 1.33443396899008, 3.338550622424772, 5.068721098284568, 10.822387068502366, 17.09469137653228, 13.635936533251117, 22.18619065900003, 20.2158409549344, 21.14269898783776, 26.157208027378207, 33.75041069522981, 43.078226658605764, 34.90967896676833, 19.574221603332028, 7.524188074373431, 0.7613326020298467, 0.011472693351548047, 0.08782746060000313, 0.05077268402542799, 0.05381552397363609, 0.035423721757627306, 0.04273749422281981, 0.029199709364723776, 0.060606985352933414, 0.042759844838010694, 0.09718476494233455, 0.0107718818640757, 0.02623150936297832, 0.06797728744605858, 0.012256868611720782, 0.062287713310891585, 0.04901260084983322, 0.08147555748902022, 0.0436796942695735, 0.025568939069466248, 0.031658234900885054, 0.008232138559011924, 0.04656619482463406, 0.056114488716928236, 0.08079662738788514, 0.030367252259184758, 0.010164108882177501, 0.053236445772551724, 0.08001077439515822, 0.06491916404376108, 0.014057775655190551, 0.013869097775539324, 0.0748183606793323, 0.0234550669143397, 0.049512729859880866, 0.02025004040690199, 0.07552428005803978, 0.01614853972569108, 0.027887481189663374, 0.06379521729785108, 0.01685296523294622, 0.021769579635151935, 0.048393647772290056, 0.1975220583018757, 0.14160508620402507, 0.16721736669780748, 0.1894116233433447, 0.10392931109714894, 0.18461234296762175, 0.12710088909032846, 0.18355287401185882, 0.1623625755910912, 0.21827240774948753, 0.21451100797182132, 0.11516736895446816, 0.16113010866026725, 0.12910469164771418, 0.17261111598101356, 0.21501795899483467, 0.16743882739495847, 0.14722188964726465, 0.15259880031789505, 0.1646097566211416, 0.15826449549246221, 0.1221907098266867, 0.11955429484406788, 0.17362717839498676, 0.14233956534054973, 0.18185612715540395, 0.14960511257090878, 0.13381254709055349, 0.19491417243355708, 0.1602845774182389, 0.11809685087252049, 0.19240308943535053, 0.14481732351405008, 0.12454187963157894, 0.15359368806164111, 0.15706428086325047, 0.232851030305028, 0.17227795966450246, 0.08052389242596204, 0.1421097389632656, 0.12399974219020336, 0.11856560475162922, 0.16066101770247185, 0.16589611017655942, 0.2668373719338448, 0.25120150207752184, 0.16324357670401374, 0.3548731011969428, 5.569268974565691, 18.622248634215325, 37.77833969362321, 53.680440302818056, 54.07211642111502, 47.499443869436945, 40.00210000622658, 32.088778980316654, 32.96661915317659, 23.89164113229321, 39.70083452040149, 46.1321448510693, 24.375702796443818, 19.011790983138546, 13.186612359939083, 8.027068780314538, 5.100959549027105, 1.7070380526204265, 1.0284838248645107, 0.7285672666565065, 0.8227132212731146, 1.576998856279158, 1.6130394320334158, 1.7480756054001472, 3.6626737204290207, 3.944642615895118, 4.691394480966753, 6.515632464039711, 9.367631942995134, 9.375905202281091, 12.019619960938732, 12.908279011326453, 11.191830212070096, 9.45727869387596, 8.869362473487854, 7.391514883887384, 4.357644415670826, 5.43212624326829, 2.940745310437295, 5.839260912710621, 5.5769117128464485, 7.597513352670978, 5.445061239504046, 13.147503387543464, 15.458486426261166, 23.331501176280362, 25.970595382875015, 18.45810332605916, 12.012784250320928, 6.880248640814136, 4.331207150413144, 4.301360364883177, 6.812427918757162, 7.303209093309219, 15.529115565361517, 6.220620216861849, 10.340343463805414, 7.822293110432164, 11.041718163797933, 10.665528543533819, 8.065489867041189, 5.92995640731627, 3.3437766903831116, 3.7862820682987093, 3.7452298066308423, 1.2882302869712154, 1.1675322151953176, 0.6212498704271933, 0.6570087709734518, 0.825258533079778, 1.7808926057431007, 4.143868377131801, 7.0576814682252955, 12.870022173850769, 20.232575747274584, 20.360825484798802, 27.04965118438967, 22.816525351616647, 29.712618897038123, 33.41948424616168, 41.919699715029815, 50.17936798834032, 39.492952823638916, 21.20288971931704, 8.394380115693616, 1.028204539850835, 0.16201423541192086, 0.22322012532141902, 0.15226542949676514, 0.1746078322250997, 0.10782669914225418, 0.0840077845139369, 0.13465507526791867, 0.11596382460406712, 0.10594003142849093, 0.23370391599112944, 0.20907175306591297, 0.10858060626853859, 0.14537426943500198, 0.1469865167934087, 0.19102468275495116, 0.21199214152030407, 0.19546088341984058, 0.14715787534031177, 0.17050268879580885, 0.10093320251232195, 0.15662086917267692, 0.14288776253740634, 0.17392860334967414, 0.25085558273619224, 0.17855241894721988, 0.18819882955041625, 0.20609165571870344, 0.14306279830634594, 0.20632719711190273, 0.1184701195527469, 0.16273118645673798, 0.2402671750995421, 0.0883519167320863, 0.1499632280319929, 0.09164502228339834, 0.17699902246315635, 0.1100751901826551, 0.21620344941414174, 0.18491779754479087, 0.10718493196632593, 0.21044925576256168, 0.13683376803753838], [0.06928479268906579, 0.04473498038526985, 0.022624213916940555, 0.10103951253357435, 0.022002824679798177, 0.05129319097426149, 0.10644748040865507, 0.08304845857163591, 0.02704903817615442, 0.037414282485241854, 0.04397923081752755, 0.04987938720132074, 0.034504075339364434, 0.0229098976800038, 0.07418715019500063, 0.03790303125917431, 0.05539530069537221, 0.05592738706318121, 0.023612024923486095, 0.0646737247945801, 0.05187996835898488, 0.14063675106773454, 0.08778831350707239, 0.02986737797337194, 0.014653257713953574, 0.050362826985937935, 0.03368270268002826, 0.030748520812560475, 0.03378297975887695, 0.023170264152389382, 0.03182866648139973, 0.010700603128380833, 0.0665784415398394, 0.04408076428057205, 0.07511762526607321, 0.07729463264225953, 0.032847977108171875, 0.019217055110681443, 0.06459754501138965, 0.05191785140684055, 0.1079049320410817, 0.030989108809960947, 0.06873175381652771, 0.008060187251577455, 0.019801624246963093, 0.07270210407554142, 0.027753565190059525, 0.15962018000502742, 0.4857482220376692, 4.5627603511656485, 14.950419856655984, 29.571827380887925, 40.063132086107814, 36.402125127853886, 26.423046665806925, 20.257369049133796, 14.656045975223666, 33.19765067869617, 40.62310926375851, 20.637731090668712, 16.31061840441919, 14.707549637363805, 9.870119921622738, 12.254630730998132, 5.242657132687108, 2.889043078307183, 1.3752014910982502, 0.5039647203539649, 0.16258728450104115, 0.34215113869117153, 0.0839988366069813, 0.20056912705542582, 0.7674562186002732, 1.27529357469851, 0.34833487784189565, 1.6203086871293284, 1.8693626455722319, 2.400631995931749, 2.7495285387962096, 4.646111697919907, 5.281370926287867, 3.060812738633925, 3.191785336502137, 2.345436893163189, 2.2590106533419703, 1.6102669291919278, 0.49531595541104195, 0.7367286158184851, 1.159595176577568, 3.49238058732402, 1.7713053524494173, 5.465379116996642, 6.364872244096572, 6.167354429921796, 2.359989131650617, 1.1788869865479008, 3.8659191756479205, 1.5625726239335154, 2.5091710878956706, 2.1509388137248258, 1.3458588527094935, 2.196166683589259, 2.780310074167867, 2.6926414235945675, 5.525508561441976, 3.6927497194659327, 1.6306013541836895, 0.7800261892618672, 1.3463086995386309, 0.29082649597717875, 1.2534181485252998, 0.4920652298437011, 0.33823759385174323, 0.16029305035068145, 0.17014863360072338, 0.2872469654727367, 0.4818487425725307, 1.17169470796662, 1.8467636646762973, 6.507454812526704, 14.340127495027359, 12.386448844786614, 12.895665649444828, 23.428297427392778, 16.549077918452603, 15.770285437183997, 19.461698609013713, 33.182678991748446, 32.52285984254653, 30.360137493379657, 20.397077991116433, 5.994560295535672, 0.8348329773833676, 0.06817481555645505, 0.0790133738830205, 0.043588951154942476, 0.029708694351176103, 0.02514431951567531, 0.03730714891947085, 0.0873951648452109, 0.07609556714493422, 0.02488360638850399, 0.06139479186986724, 0.0151296159733207, 0.010350034590960752, 0.015191429692711082, 0.07116627398758166, 0.017436260748053753, 0.02469016727240336, 0.07594110849764078, 0.06339529258829933, 0.010611612439876603, 0.06487567323229967, 0.08635196759695969, 0.027753153417800224, 0.06134960417365355, 0.05241745181622044, 0.10104739557831519, 0.003653434288289939, 0.042500539397400235, 0.055441085940166834, 0.028027658042828404, 0.015791843442486662, 0.020342788756674817, 0.030523087949522083, 0.08306551934970964, 0.03195256971183323, 0.05367642921966411, 0.02349379457413189, 0.04415882097917699, 0.057980755509267894, 0.04200124542319006, 0.015622770710427676, 0.07163684349507093, 0.018703136517996752, 0.021119485083486766, 0.03450003039512423, 0.03476790069872814, 0.0291408853034579, 0.025222833951815002, 0.040946235099146445, 0.06391691419506265, 0.09608005083376363, 0.022063027699327758, 0.04843612351725179, 0.013692122846541387, 0.051544942787938544, 0.03463804496512298, 0.01858340846675058, 0.0133200052134212, 0.025381498421812733, 0.025777362865365805, 0.03359398203751734, 0.0541001639419025, 0.05863573770188998, 0.03246507870273725, 0.019964699468184865, 0.07469586322023984, 0.05190197423460984, 0.06218391988847045, 0.0480027437480467, 0.020356873283162713, 0.013619228622936195, 0.07722016889601946, 0.06306649531207739, 0.01206567892128782, 0.02292658307499463, 0.013608175889408637, 0.028070428731640982, 0.042761112713525375, 0.050991183792751645, 0.05599785566089615, 0.024242950040065957, 0.059104250263302564, 0.021296020469538147, 0.011167956024198043, 0.06872293614451924, 0.04738109787144969, 0.02157290762801084, 0.06884089070222071, 0.07083432808999093, 0.028657763445329283, 0.061071678966043465, 0.10578721987023469, 0.8064235566604523, 6.523143802919696, 18.259549025566347, 36.37490780122819, 45.24957626096664, 43.15435986365042, 34.565804773761386, 23.77029476627227, 17.78330856753934, 27.873019441481564, 40.96957222107918, 30.82058256672275, 22.97799364213021, 17.83073982884807, 12.098160520676645, 13.83274047605453, 8.13437060963723, 3.611076411701018, 1.5941882758371293, 0.5418910062120808, 0.19476872298025316, 0.16814497660004324, 0.15031273266480816, 0.11398477434751489, 0.686282767884193, 0.3935101327876891, 0.7127041598000835, 1.8006859887992184, 1.6760990095715371, 2.2257075242457853, 1.873185975897697, 3.5199001816011246, 4.118012603252165, 3.1248527861410573, 4.194596390570364, 3.692634744990257, 3.2554015228825235, 3.152480490746037, 2.845999478332458, 2.7362826947242986, 3.8929369516911048, 5.474408413133314, 3.121488863422025, 6.8060525963383345, 8.503407297595855, 11.341041095795172, 7.104610175855699, 4.142493586386404, 5.305634217877542, 3.729020121597475, 4.0832425077115335, 2.412648176954639, 3.5902226403836286, 3.472740789574962, 3.4077860943732725, 3.8960569520150465, 2.058774881785916, 3.1013435702170096, 1.5802998985013657, 1.47530184878457, 1.2144383691972302, 0.9002869167635519, 0.6163222090371194, 0.5386543153755127, 0.5068664162630035, 0.2649239600906449, 0.03394320704824021, 0.18538126541722208, 0.5173605031544163, 1.3485040010944491, 1.9277381776802003, 7.2415813034580605, 14.64623514683016, 13.858909549251681, 18.82073037085995, 25.83663663556499, 20.977043567165254, 17.381857902772968, 24.671298496184814, 36.90802066556869, 38.932830518291844, 35.68379794397662, 25.49363713110647, 8.567084035565777, 1.3027339861277611, 0.07072942000963996, 0.06255571001900301, 0.004840265122062017, 0.059335608816435265, 0.05563158136341841, 0.05386849512316046, 0.08613927094566246, 0.050842949609842994, 0.09548012738025959, 0.07218867194868865, 0.02853549389739431, 0.04996776693470536, 0.006427176516397947, 0.03445871144292816, 0.013177587553077649, 0.012379239666305724, 0.060879367914411335, 0.04565291076658234, 0.05283346054174247, 0.02496554715288503, 0.05014112497109079, 0.0547158649762071, 0.0169598977006371, 0.06154928499111726, 0.12306490041796239, 0.0798991630454698, 0.04148698209093944, 0.06076129461308161, 0.020633126503878066, 0.02114364175095914, 0.07107065089287297, 0.022333292027695045, 0.10096445123875335, 0.03750370792864311, 0.05773896666904611, 0.036855011487439755, 0.02234218056283651, 0.03967444870560881, 0.033710419741128726, 0.006299874728410355, 0.05374730001353929, 0.01976652592871218, 0.0228603758413585, 0.16915445065786763, 0.15850366814242256, 0.18867149047793882, 0.19893017387197864, 0.1414103313319145, 0.1562731571856045, 0.20271702309048947, 0.23195351233645795, 0.13885069368106706, 0.1288875823299731, 0.1160904819205884, 0.22230517119169238, 0.1628101854434898, 0.16094686042877937, 0.12963073358180063, 0.14382036733290843, 0.2145353848895719, 0.17491740835530145, 0.177637679322112, 0.12383058997652224, 0.17384598842791973, 0.3249894515160592, 0.31111094139276013, 0.18687244024007552, 0.14265284933630498, 0.16313883716300612, 0.1566982900183047, 0.2202787767014196, 0.13803333915289373, 0.07523650679016307, 0.06830956276145674, 0.09651311267648013, 0.14006901862880877, 0.18745895715490465, 0.28004653571594146, 0.18432662281538212, 0.1003167238987742, 0.14802571506269518, 0.1063094620082167, 0.1806316581825095, 0.17397374125017276, 0.09391412108896241, 0.161870869717771, 0.11113113513396633, 0.14303385550456663, 0.19680915220129877, 0.1456305258456738, 0.4407173899873611, 0.9028840161138966, 7.50243902206421, 21.490715203746674, 40.57593099532589, 52.588860373343195, 50.3306459611462, 41.23175128813713, 33.41343987372614, 25.107709246297038, 44.72277056786322, 52.83343584306779, 33.22520925152686, 28.553752668442268, 24.963415053582963, 17.07055114930676, 17.844758379843928, 8.12152975028561, 5.004500131453238, 2.1337203441127657, 1.5608244725773412, 0.5364775225039452, 0.8146749364752924, 0.5927335651170823, 0.8495335917799705, 1.9505867193783484, 3.840730940141986, 1.4413666052203027, 5.140258266079811, 5.4032144527281485, 7.729506992524671, 8.278174996376038, 8.254621163491281, 12.12846867499813, 9.457952360953055, 9.70315933227539, 7.6851042912852385, 7.343082437592169, 3.9473929328303186, 4.0708306575975115, 2.6596099186328153, 4.5310023907692205, 6.824215621717515, 3.748698162455713, 8.703575653414573, 9.77191455902592, 9.847527069430198, 7.508166663108334, 5.321469806855725, 6.918591280137339, 3.8153313869430177, 6.278257975655218, 6.3763422350729675, 8.072540327425926, 8.569656129806273, 7.842029496546715, 8.704108115165464, 11.74214659198638, 9.10696985260133, 6.604299112673729, 6.363226319513013, 4.808139416479296, 3.6601165802248063, 4.791845400487223, 1.9102471033411643, 1.391172524421446, 1.584966048117607, 1.148204981319366, 0.5963593673321509, 0.988837732903419, 1.841672428192631, 2.9084593009564186, 8.442715483327067, 19.405618521475024, 19.148493428384107, 22.998582163164695, 34.86264974840226, 26.422236696366344, 25.446651058812296, 30.901049990807813, 45.72157859802247, 44.93120924119027, 40.91609070377965, 28.299692907641013, 10.200297197987958, 1.7481420405449408, 0.2693683119310487, 0.1361559487638935, 0.22766858339309695, 0.16757333711270364, 0.21395665142805348, 0.19489569439282342, 0.22637830746750678, 0.3401538248985045, 0.22943358868360522, 0.25655051182594996, 0.11344949339306164, 0.11350396224447798, 0.10203456881666377, 0.1348067606769262, 0.15152803922612823, 0.09306399331938836, 0.10971814724466494, 0.20692040963519007, 0.18433917133558184, 0.20663568539725197, 0.10988484797698837, 0.15735850459144962, 0.15224115983132394, 0.11820748929054507, 0.2455793360188123, 0.1533816196024418, 0.17938101964612163, 0.27811158148031084, 0.14150417710263885, 0.15638543503178706, 0.13700577009829784, 0.11358624774842493, 0.23642434017552486, 0.11612654934006354, 0.15320037852131552, 0.12363332999689926, 0.12205767099775615, 0.1883100348735048, 0.13838762417435646, 0.12936198993796302, 0.17571317452576854, 0.1252291830737264, 0.151357937063421], [0.014316195306638557, 0.04662408808907194, 0.03017861651436937, 0.011401347583159806, 0.08047680100125652, 0.02012980482240598, 0.05533753000500222, 0.039320018127440445, 0.012760065803905169, 0.04323833186419741, 0.045941791031509645, 0.052995541763882485, 0.028440615823191982, 0.028301126533938993, 0.06862575789132426, 0.16565715203121786, 0.0427996316143582, 0.026437217377186305, 0.09210793857252406, 0.08896549187240102, 0.04027299703128877, 0.027226567561287555, 0.018429867209746473, 0.0907966488551709, 0.05558986787594134, 0.017257817803070914, 0.024812749001167478, 0.02404529360994216, 0.06343084289842556, 0.045954400838743296, 0.09625000743976525, 0.06641113559805578, 0.023864868412455244, 0.05091788450015649, 0.15548509785965567, 0.05451087899986775, 0.048898867436594544, 0.054387864431426416, 0.02468397345153555, 0.06203832104802132, 0.051265297712938446, 0.0250117709830163, 0.054150924927765326, 0.025740334005545706, 0.12079005595296623, 0.04105932499852873, 0.03648417513637293, 0.016433951527541204, 0.09556394506005511, 0.7464588517623564, 7.377815025468027, 14.890320320283214, 30.693680163352724, 34.522858742744695, 35.5916497015184, 31.5059991036692, 28.23163978515133, 24.492277599150135, 18.570616514452045, 16.946076693073397, 19.525658738228586, 17.07858024104949, 17.487430457145937, 14.107086735387004, 9.237121939659119, 5.960122866015281, 4.429727283216292, 3.0140436224399076, 1.2816789481909046, 0.38471608693080567, 0.02402136293840745, 0.06903700154995726, 0.28438663831160915, 0.04866376654395173, 0.5585808751563872, 0.866596147177681, 0.999854383689742, 1.3007716978749921, 1.3593548704539578, 1.8490417037279376, 1.5943510541992805, 3.1709548542576456, 4.069166101755635, 2.493109472336308, 2.8076982690441996, 3.0486001939542833, 1.2224292178307812, 1.5959116672315907, 1.7351110688140317, 2.3805205331694697, 1.6532413973923654, 0.9103018309800857, 1.886675864938767, 2.5369632868997516, 2.9936235181746946, 3.5004856749888393, 1.269366015349665, 1.2614261575283543, 1.7529514792465395, 2.055664564813337, 2.3662803682588764, 3.7780132216791955, 2.3601028803856146, 2.3265717635231637, 1.6748828296699834, 2.7119370333610044, 1.0545791084727933, 0.8352841725272517, 0.4691896912071013, 0.5505655729962934, 0.44590640993368247, 0.14536673112982704, 0.5914684781624425, 0.15610282519652, 0.2415839883108293, 0.764579589088117, 1.483228468606549, 3.0487776812045806, 7.167845647181235, 8.426724960727077, 26.45285471793144, 25.412646070603405, 16.866880116924165, 16.043530491090593, 18.56047522637152, 30.093671275723366, 29.05569837939355, 34.39442857619255, 31.05867631973759, 20.049883511758622, 10.784204756059955, 2.9395406524981222, 0.23082426809255155, 0.026111359963373795, 0.052247625445165945, 0.019181719305174007, 0.0330053698722153, 0.05282424450401337, 0.03967266372074524, 0.046558878684957186, 0.03288741914495345, 0.037154126687035445, 0.005853977082522527, 0.0567520194266352, 0.06157175051949679, 0.06127748848690141, 0.04170388073450135, 0.04005465814242921, 0.0125951481412255, 0.04064265743739182, 0.018524900416753465, 0.06511193474814778, 0.10875610169023277, 0.07825369045378701, 0.04577880582561897, 0.04787799016001725, 0.058170603588223464, 0.012815133161512355, 0.033665718510746956, 0.0406088806208103, 0.02237648981052541, 0.026235719016122244, 0.05323470675296361, 0.05883479415769539, 0.07349044685402224, 0.02403862864500092, 0.023001123430027116, 0.03358629434519718, 0.04002847708761692, 0.03893751808772645, 0.06882064299838198, 0.03357534311831959, 0.10028553645937674, 0.05637550253360983, 0.050747510376236135, 0.009336586452029165, 0.019552004072935354, 0.010328912589278434, 0.041504831939575174, 0.04944745533829255, 0.012009348476215476, 0.035899477680363966, 0.021145572292528326, 0.07406879727157854, 0.047209379263222224, 0.014180489534121609, 0.049260805676420855, 0.01402003529121078, 0.05364064908316059, 0.022690970818662358, 0.0265721082236738, 0.08710659484589293, 0.03392534570828561, 0.046386696593535524, 0.044940655840741056, 0.039722673940442266, 0.033289979196964734, 0.08063913503241155, 0.056124309964117505, 0.03014868928960735, 0.042384584329181144, 0.015292548510666578, 0.03150422824546695, 0.053982354940906654, 0.09252862809526344, 0.052720244237852674, 0.03079294242084988, 0.05244145718132777, 0.036034577285810825, 0.031644418505170656, 0.11858805112781064, 0.06907945048184165, 0.012233832347837668, 0.09107357431803981, 0.056743033215283394, 0.04896991826113194, 0.05422358453694371, 0.01806780639585228, 0.050394895426448316, 0.054400845791303346, 0.07746235227152225, 0.040637658713685895, 0.06487882951454771, 0.03773844492952189, 0.08564368100656618, 1.2023270706976614, 9.551148856839827, 20.126838453354377, 37.96316569851291, 41.048811943300315, 41.4338396441552, 35.13631743769492, 29.23007715132929, 26.81800973030829, 23.617141900524018, 18.550708524642452, 21.0526962818638, 20.66511315684165, 21.57641506964161, 18.385549283796742, 8.950736945675267, 6.625500013751369, 4.4961256557895295, 2.737874196421716, 1.0019768762492365, 0.44813440812210886, 0.028087206057182727, 0.012264962330640805, 0.0925263834576453, 0.17215849591359017, 0.3958436672485644, 0.6224210043587993, 0.9511928464616499, 1.7734963639128594, 2.230590384814047, 2.4814512075916415, 3.21650484877248, 2.636203664925791, 3.819375840886947, 3.4374007246186657, 3.5362628390712127, 3.0285804165947825, 3.0589907976888844, 3.6905590757246944, 4.9824240515309, 3.2537350058555607, 3.0390305913263753, 3.005521292648008, 3.483363058297865, 3.344473401384969, 3.4136951450378668, 3.211498678691926, 2.7767836182348193, 3.6164409883560675, 2.5679603074827506, 2.041796779920978, 3.64471294226185, 2.6201567582545744, 2.5669875596800162, 2.7310610394324026, 2.0343006402254105, 3.0937246113054218, 2.0408392313026615, 1.2728390289891152, 0.7436812620970511, 0.2541062623382576, 0.34739188489414036, 0.31112356652175227, 0.2219792161016695, 0.278715136190576, 0.2564843065075336, 0.5449956847775368, 1.410764273135893, 3.3186036540615946, 7.793695109505808, 11.433837509924366, 30.58085318534605, 23.273283396997762, 18.852185818456835, 21.448883125858924, 22.093569770936046, 31.92400020937766, 31.802865651346025, 39.68707092346684, 35.47826182457709, 25.06206266341671, 14.279035599000993, 3.3818241713508486, 0.3283595335820029, 0.026944160739320423, 0.04211466090994016, 0.04588575553028815, 0.021776547204823266, 0.022683779168273174, 0.016983485547825694, 0.030844201363863486, 0.024673397607740857, 0.0013640329557200593, 0.016407184415466843, 0.04426660955012326, 0.024547933473161632, 0.09072031585439559, 0.03524450697906075, 0.04141820271709754, 0.0658654511695908, 0.0346838110577195, 0.02690175968793131, 0.061323151157628146, 0.06076189599210217, 0.026715362835074627, 0.009060422289035013, 0.026794974692165855, 0.03345557293223758, 0.025801109675798687, 0.0577438504795634, 0.057116535552326715, 0.04575426036852502, 0.03848049684517807, 0.11543533884950223, 0.029071324519933234, 0.10877113999618639, 0.01212182263242862, 0.05882574665930964, 0.022600333041120923, 0.0508238893422869, 0.026577311875899474, 0.055860633991899035, 0.019920521092811422, 0.1339008923499815, 0.0371054188168097, 0.033800752998720256, 0.03864221417555406, 0.16425021623651828, 0.16359162576977285, 0.17535168827781755, 0.12816460983407113, 0.22083874100879317, 0.1430369811432977, 0.0774531975208271, 0.15410172692950697, 0.1351439619376775, 0.20270839694046205, 0.17480454828229644, 0.0968584344692288, 0.19405025508134596, 0.07462577383604742, 0.09949141737794685, 0.25471939314757625, 0.10932261604935893, 0.1080128891513713, 0.27278714783249364, 0.2351972052166539, 0.1783416834810088, 0.1425998973389787, 0.13352883408867544, 0.15255471961873193, 0.09158072452391348, 0.08498374988595325, 0.11096450334955608, 0.1748732663691044, 0.1239499388142459, 0.1715313303734987, 0.16857046183318863, 0.21426638077584007, 0.18377502418814168, 0.2544435248860429, 0.19347470854559254, 0.15273654292668068, 0.10507827444422631, 0.3059543729309113, 0.13115860401622711, 0.14911464776002592, 0.16880188167335528, 0.15083597071709173, 0.1794571841075536, 0.16872207063340372, 0.24694933105380307, 0.24968524553602744, 0.20732271304774672, 0.11207880121805977, 0.18660599486001078, 1.3967677854722547, 10.094180414753577, 22.122807118200488, 43.23478806403376, 48.51811085977862, 51.21941974086147, 42.984929161687056, 43.287120326872795, 36.557368616903986, 30.255641629618985, 25.87119663915327, 31.60546256649879, 29.310564187265214, 28.962232220557432, 23.227328908058908, 15.261449102432499, 9.767418542215902, 6.70081050165238, 3.9458183463542698, 1.9224446939845241, 1.1006307986474808, 0.5229152534757892, 0.3738915403523753, 1.0960375806016307, 0.9857955058255504, 1.915197257072695, 3.2041055012133817, 2.7631791224402766, 3.744313442899335, 6.204192349987646, 7.317916510566589, 6.609170206131474, 6.832921322314971, 10.174747859278034, 8.837145105484995, 5.039757826635915, 7.883881676581598, 4.617012123907767, 4.566549360752106, 7.029084938187753, 6.960686156826635, 4.5600779402640566, 3.683932476466702, 3.8197827867923246, 5.677673480203075, 4.77840441849924, 5.956044581628615, 2.729776708349105, 5.8465035692338025, 5.096073746681213, 6.227706468874409, 4.241100011333343, 8.62016841288536, 8.763254515586361, 6.382941622887889, 5.715144863051753, 7.104995058428857, 4.082523488229321, 4.069990044639957, 3.097273130570689, 1.7344467173660956, 2.091248429590656, 0.9961006754348356, 1.1410467783289573, 0.9366200155308171, 0.6500998223500868, 1.1865877023627682, 2.387089522615556, 4.049210553207706, 9.642994096202235, 12.401763739124423, 32.067388334581935, 33.6304057798078, 26.186080594216627, 25.22233855339789, 30.514165047676336, 42.077335849885024, 40.505496994141616, 46.576212067757886, 41.45979004521524, 28.38432000529382, 15.290467777559835, 4.164884926811341, 0.551302733440553, 0.11550617899986045, 0.15079426489049388, 0.12333192802484959, 0.15546672707123144, 0.13521088737874262, 0.23250144906342032, 0.18441378829940674, 0.18437471781526843, 0.05220127712574698, 0.11319961849479906, 0.13275998824786756, 0.2065879734413278, 0.20813677339784561, 0.22102703009882282, 0.11931312270462514, 0.10571149207891957, 0.17311040612478412, 0.17313007926267965, 0.20925872448471286, 0.17595110611329157, 0.15621202336924692, 0.16417236638165292, 0.13722617359411332, 0.11838500718435935, 0.1479126098415544, 0.12303052605279993, 0.14570414689519715, 0.12841603222994075, 0.07951835606006846, 0.20690418389295379, 0.2296541147534886, 0.2624512427756863, 0.09522921826329925, 0.23305818047975344, 0.23649020841525448, 0.14917797258784696, 0.1532619260251522, 0.1334943907755998, 0.08713605092658151, 0.3741404882842495, 0.20164007200829445, 0.16996092673751617, 0.13740001426589105], [0.029838791402477412, 0.07265610815656763, 0.05866289934924534, 0.03494169923567003, 0.009408119911958855, 0.09412844184665911, 0.029939913093262625, 0.025678520286155325, 0.04698905237619916, 0.011523739705162664, 0.016417972848660523, 0.013302908046171071, 0.010454602719795321, 0.0442439601606419, 0.05212644182686364, 0.08495833108862562, 0.03328281244443309, 0.05843712557708064, 0.012382556827017858, 0.08061941592924057, 0.04482956543084114, 0.10344847601147429, 0.007101910849732738, 0.04638993331501561, 0.042078183633425546, 0.07827646624777587, 0.02595890655122217, 0.024961653511009874, 0.06643439402743694, 0.031553891810378244, 0.05980618981524341, 0.043516172802135836, 0.053692823501243714, 0.09958198429235529, 0.062088446180906996, 0.03933791777179126, 0.030881235969343016, 0.07054015032706723, 0.017188781789774378, 0.02782754247046767, 0.06545290516148652, 0.06394751940763767, 0.061376110815833655, 0.03753165481612086, 0.057135580498124325, 0.04228706516685986, 0.051724283971012606, 0.02085253025495237, 0.015577221995279675, 0.0074918970048818145, 1.1920804914928254, 6.046705755495257, 13.345081017863366, 27.084609308550437, 40.73706980674498, 48.89912205357706, 41.57252680870795, 35.062176796697806, 20.862506435763454, 25.953352643597512, 24.310458090997514, 25.10041363777653, 16.298122713642737, 22.15167772385382, 14.029748382106906, 4.869148452435771, 7.786094536704402, 6.1343452334404, 4.065442056425156, 1.61260919705514, 0.9520927852680607, 0.41120710091725476, 0.362963663834718, 0.13747686820645488, 0.1145895624593381, 0.027465975783284635, 0.5012186628676231, 0.9546290878807345, 0.25693527182504056, 1.5579356469454304, 2.176646027834185, 1.1623826334553382, 2.25062511620983, 1.9881925659794963, 1.4332515890559843, 2.18035462883211, 2.6246978823215734, 2.427450711688688, 2.6899389105458416, 2.338878445086941, 2.136998464984279, 1.7871350578723417, 2.044597107075876, 1.7318649397742365, 1.3275348875791797, 0.5180044460200495, 2.2166848471087794, 2.558274014342216, 2.0483943291248816, 0.8257531807307275, 2.7385812036452757, 1.1264129055123175, 0.672389242437578, 3.389938574644827, 1.3519396296431943, 1.1259512915726633, 0.8829183552053668, 0.1643805431141969, 0.26604208073789076, 0.10723946210477622, 0.20255079733267908, 0.06902314301940703, 0.30647476113611655, 0.41931457877639805, 1.0427949601604094, 1.7507371787101993, 4.398399802946276, 7.60653970703002, 11.815069337044994, 13.859964666828034, 33.165369572178015, 49.718869962999904, 19.33423726789413, 25.215341045010476, 24.605836099193944, 29.357934651836274, 38.21224012682515, 36.214643678357525, 20.282040757517663, 12.55447239645066, 3.780500004368444, 0.6988404811389985, 0.033922430743733724, 0.007401527358113879, 0.047439615497545856, 0.06797063014199657, 0.03941025562404145, 0.052437561624232805, 0.04394598643205339, 0.07376626148940095, 0.030344646919759053, 0.01924678698302277, 0.042787661490541314, 0.0258146062298047, 0.0844183310325588, 0.07768894575776593, 0.05112276322418644, 0.10002019424592296, 0.05522435966638788, 0.06784182011840806, 0.04097981656330728, 0.05567968785462361, 0.07641281947613725, 0.031861014544002475, 0.044488510747830716, 0.0468802449083136, 0.04370710489550426, 0.03193584218200657, 0.02632810921979047, 0.01833275407402506, 0.01994269359255991, 0.028262402704586426, 0.03480832715849242, 0.05673532637076513, 0.028181444447968277, 0.06325648128685933, 0.01704716852175132, 0.04098284261060819, 0.04284399576605328, 0.01611936326709486, 0.05092482908719009, 0.020314901241011197, 0.02191651338380912, 0.07660263308113621, 0.05232287826196802, 0.037774657905702634, 0.06048829535082464, 0.013158228511231081, 0.06032877669279134, 0.04001199470592603, 0.011515042692002271, 0.10079142262017536, 0.05785802439335854, 0.04363433037313723, 0.011603625438686822, 0.03973837491245039, 0.058594384275737314, 0.0620975741185248, 0.07570716056732402, 0.09429462930007328, 0.039823142541272026, 0.006121637190752213, 0.02471398877640886, 0.0742098723628348, 0.02272392026028566, 0.02955747817102219, 0.042844286879464503, 0.020892970121255326, 0.049127429768803625, 0.0454451170780005, 0.038072784851876, 0.005134571204713036, 0.06764495084362646, 0.06084327751229848, 0.017809845439548937, 0.052858990421819116, 0.04430807405902494, 0.023799975019609256, 0.06858011437279564, 0.07125907021784975, 0.032914308831095695, 0.06530982291986866, 0.05287522765537424, 0.05117653493559168, 0.022588652115495458, 0.036846952242476326, 0.02430884317765313, 0.029922189649134397, 0.06660326278858608, 0.048545463416244716, 0.05027223708889177, 0.11434852821572174, 0.05845478007329568, 0.022283775934709177, 0.013605133562739338, 0.10697563674541251, 2.0520335532003835, 7.782608039917485, 18.23829370160257, 32.583805630283976, 45.83741011158113, 50.56678833500032, 46.00085135429136, 37.6112388795422, 23.963022385874105, 24.4820245235197, 24.205007130099883, 26.580633771034982, 23.129520685442035, 25.028632302438062, 20.6681804503164, 9.299958309819623, 11.285867075766287, 7.4310494334467005, 3.931931685055456, 1.5651285383970508, 1.197953873103665, 0.2396170422434807, 0.3021333102257021, 0.19158619455993178, 0.2513368391702252, 0.3339133033108327, 0.23160213844910746, 0.8949526159032699, 0.4556710279035953, 2.081196130283417, 0.8399028246921878, 1.738237810711707, 2.9541402045757543, 2.7131603225584957, 3.7731911578486046, 2.521338035022059, 2.735072398378003, 3.8285973331620617, 4.280848820363322, 2.209918268265263, 2.430765849928702, 3.4068959614922925, 4.052051329805005, 2.6740876320869695, 1.7848246592667796, 2.184811176792268, 2.647153941854354, 2.6717709822039453, 2.993637736766569, 2.1507164643656824, 2.657450653852955, 2.26374470899182, 2.7876887879064007, 1.4273201073369672, 2.3031662452605466, 1.437184868320342, 1.1997937098626168, 0.4001943112140702, 0.4029803891335765, 0.1325924601405859, 0.190884841065253, 0.14876806958308145, 0.0991152988506421, 0.07045028055266989, 0.7085332707051308, 2.104059135721576, 5.242049165310399, 10.220103206173068, 11.896505586562618, 14.904811516884836, 39.65406810083697, 49.26707175470168, 20.946174513909128, 24.46734505314981, 26.000640738394956, 34.83269852976645, 41.576719822422156, 41.608828344652736, 26.831206544753048, 15.705860507103706, 5.287422653167479, 0.9644537058568771, 0.0307629864677907, 0.06448617114895774, 0.019066176009214213, 0.10256616488820124, 0.010235233442677606, 0.02284768176445317, 0.020890968716553143, 0.02940905055091266, 0.009304221152448127, 0.10938859154139796, 0.0406456413498569, 0.04565354661955949, 0.06079510973405935, 0.06888186108441123, 0.01918158907022688, 0.0370194407690677, 0.028535449847338662, 0.08244589211479311, 0.048795640919237375, 0.060110809356575055, 0.03968072296570867, 0.08128883887923534, 0.08536456453223383, 0.014041977964581983, 0.010146854666902894, 0.06297130505704591, 0.03041874294379546, 0.04396442616839082, 0.045784995816047155, 0.019829088499048547, 0.030354184714416345, 0.02428543153068712, 0.07483104709535837, 0.027848663514540083, 0.03238668492544563, 0.02661539602183527, 0.023972570798510028, 0.04555673608856817, 0.06129413940793565, 0.017289708128138896, 0.030417731707735412, 0.025392600951055368, 0.029221372416002617, 0.03892174816780514, 0.2715677810051749, 0.16531854116868588, 0.18375931938569393, 0.11498486382826684, 0.09502240516726049, 0.23063574917614463, 0.1723032865312792, 0.15095787062760324, 0.18632215928406487, 0.10371372629437717, 0.13175078998169593, 0.13701692433847537, 0.2205247368903891, 0.12405886885619934, 0.13197122412102838, 0.13994521882024505, 0.08064337149863282, 0.20785650779162684, 0.08799431454991141, 0.1908148819160077, 0.24932536807271743, 0.30372153306680344, 0.16786635042198245, 0.15822908690860196, 0.13311053476025983, 0.12941851190501644, 0.1713367133972145, 0.23078913530034406, 0.13900018807861114, 0.12464019935578109, 0.1972881103715589, 0.1623419065388941, 0.13877596946493273, 0.22376066163903285, 0.15551630828169086, 0.09755350604292848, 0.1379671338344774, 0.12162362856249656, 0.11375874776633517, 0.11415005015629916, 0.1755956566381839, 0.1400001932896914, 0.28694923306184433, 0.16968251506407417, 0.13099133637883972, 0.20433671682352023, 0.26352134503183827, 0.15271071044187393, 0.12207766589257987, 0.1924895807620018, 2.1833295014596756, 8.644093890343944, 20.231538280364006, 37.52102436557893, 54.21627136968798, 62.417064866712025, 55.35110719742314, 49.468811019774414, 30.09261223577684, 36.677408833657545, 33.87549115765479, 37.51372875705842, 28.480349433037546, 34.779209167726584, 23.502577312531013, 12.656017657249206, 13.932581467013206, 10.106626095310336, 6.0322949674821675, 2.4759785206087175, 1.7705586312278625, 0.6696457896501787, 0.7628601813508619, 0.5656597114378407, 0.8616449515665732, 1.4618082825214633, 1.8783495310814151, 2.9997000050160194, 2.914322263771488, 5.16815024037515, 7.1234292176461995, 4.566813140146194, 6.363368015135489, 7.680795567650949, 6.674786065855335, 7.366959866016143, 7.194075517116055, 8.613376828931994, 6.168720885630577, 5.948422926087534, 6.994955414725888, 6.409358785998437, 5.262627880419455, 5.200714247841989, 4.484941997835714, 2.7994532017938556, 5.459185204198284, 5.935354078969648, 7.580581951525904, 3.307224858191706, 9.880514202579375, 4.867357890452109, 5.695890928468397, 9.281657511188138, 5.427322810696018, 5.208638416182611, 3.9119955032102527, 1.5633605300418794, 1.4581898960375017, 0.7929223295181029, 0.8303568788593816, 0.5237051207692393, 0.6308600450715711, 0.7078372951476806, 1.5239212205333095, 3.14409127639186, 6.184086280484354, 12.334764753618549, 17.37234027154984, 20.955713718168198, 41.17211557203724, 57.78898185299289, 29.117118773921845, 35.00915027433826, 34.69330141621251, 42.85340816743913, 49.24984862727504, 47.27362125150619, 29.85791329414614, 17.392444379868046, 5.351632833480836, 1.2049568973241316, 0.11254583906021812, 0.14055510141676472, 0.08714625521773293, 0.21378409778398855, 0.19212752760898685, 0.2190912025229585, 0.09700239771195958, 0.1579823453099497, 0.27037510468113807, 0.17817974781557439, 0.14045681233607954, 0.15325824880311567, 0.13517596909115392, 0.22264770442439666, 0.18676963124063709, 0.16272890351472363, 0.07960883104392598, 0.2640738476428294, 0.19388894760800948, 0.14028998902968823, 0.1834678382522637, 0.2478245865072935, 0.23625652095483196, 0.20936818312733405, 0.1604090360624175, 0.12305412922174701, 0.165408939543751, 0.13986006048658203, 0.1795932413229058, 0.15435176270623363, 0.13862866607885208, 0.17938195427338924, 0.132762715520878, 0.16418260131632129, 0.18050413518663377, 0.1233151047340324, 0.12804618796273587, 0.17278906288406543, 0.15438036842932626, 0.13476281787358946, 0.08559230715036394, 0.13271570836584415, 0.1146459924958406, 0.14732079159828926], [0.042814535854925076, 0.04385683678030487, 0.017622441181071827, 0.014361796690331352, 0.018540708641070994, 0.04873781660271268, 0.00958653700147425, 0.07433413182415309, 0.04307204098891347, 0.12277560263511636, 0.025366209222063906, 0.05167877451787072, 0.10572096858654292, 0.05798522563230607, 0.03184752756609552, 0.029226066619758646, 0.07727472967798672, 0.02225463395006955, 0.016689731048480157, 0.04352127494771154, 0.05974561141263093, 0.17155048257160574, 0.021347045755734848, 0.0827664309631913, 0.08647433482110502, 0.03638344223520929, 0.021733479656940027, 0.05059379866466888, 0.0479380629445997, 0.01013314265066818, 0.03862853950610565, 0.04106235870670888, 0.03324354277743447, 0.0665625681980483, 0.021876944942520033, 0.025466938292787924, 0.04668535597081627, 0.02663116211131696, 0.06997433310795216, 0.08206149983790614, 0.059351033996790654, 0.05465792191605415, 0.031883600731230075, 0.052425545535140464, 0.05732951948659555, 0.09612087565924853, 0.03156858537676594, 0.041466776521936546, 0.05325716845090351, 0.014385301225458183, 0.08524516206835547, 1.4732353725740988, 5.552541046373306, 16.15514937908419, 34.08705988237935, 47.446350666784475, 48.26855790230536, 32.3056056422572, 26.95279021416941, 24.828911096818988, 22.936463586745724, 26.675515905503307, 22.867796613324074, 24.870245033694854, 16.95894402842368, 16.133414545366843, 13.42744000496403, 14.845473900918039, 8.731430365193276, 5.260862323545641, 3.067103239797777, 1.7133379919875054, 0.5192686136691801, 0.18447055541459592, 0.3171835977944636, 0.18915709829138172, 0.20679625742618116, 0.9786411639182799, 0.2859026650267263, 1.0207992888266042, 0.5102841489978376, 1.3432132140282662, 2.043255779051012, 1.8745846685863312, 4.04929316812946, 1.07741441217161, 2.570847171929575, 2.742689641252641, 3.070442157406961, 0.5265398912372128, 2.240869446146873, 2.6959739673522214, 3.0858028944461577, 0.7499586478356393, 0.9309893305743895, 1.9831491333823053, 1.9013846305108841, 0.7823365878674292, 0.8166125260533825, 1.918520362627122, 2.6251416004473165, 0.9678122353169226, 1.9751329119167023, 0.9169243240068037, 0.5419830593370623, 0.49911415805259063, 0.6968839538674201, 0.3059952820260679, 0.031340310327528466, 0.30332604783677286, 0.05167050842916773, 0.3304988800758316, 0.5074272845541278, 1.4283540195995763, 2.178577549995915, 6.347024969516262, 6.315881350348073, 9.622179058290298, 15.519263552081203, 17.39786901781636, 24.72891026927579, 55.05767468483218, 28.452355477117724, 27.229240825099332, 35.86327383595128, 32.154104094351496, 30.527048072507306, 20.67524071662657, 12.058705399113318, 4.452978113005239, 0.8218859688889596, 0.01386333583673883, 0.04121362276735806, 0.04384696956784014, 0.028570588385205598, 0.008421597848345917, 0.048377360743019855, 0.029754452782893376, 0.039348397854595416, 0.028687342100085753, 0.08295141055338806, 0.09552582452494292, 0.06966299497552457, 0.07812548563965867, 0.05187765860389318, 0.01313069339601263, 0.04646287254628636, 0.024269303464661204, 0.029572704168517264, 0.0815722914112191, 0.05541408900171519, 0.04907027194877306, 0.011683449885177036, 0.004077274108215446, 0.025557861438081152, 0.04322504023871115, 0.07008337806309424, 0.009701046078736264, 0.02599602925681299, 0.02986372373397312, 0.011713141537902337, 0.01939426082366657, 0.08692458001596313, 0.09077885263268987, 0.02742231260204027, 0.015596009344012748, 0.03004833560196623, 0.009618705991024693, 0.0026876133568059174, 0.030073785042810827, 0.05365781711354371, 0.08923885502642201, 0.04333371364120995, 0.030032234349017663, 0.05757572482370081, 0.08701403610288136, 0.02672971357711621, 0.029310324800110636, 0.008413364318379713, 0.012097730124819905, 0.051588092690273646, 0.02647989422022816, 0.03587057318298086, 0.08783505253133275, 0.024831458783498215, 0.081955703095563, 0.0656597565619215, 0.01992680492901033, 0.07110922341986049, 0.15486810596719866, 0.03411534700482603, 0.024630544564476418, 0.048597193503331755, 0.022768236531485474, 0.03664210033152373, 0.05559689673264662, 0.06545230761290559, 0.0693926961732007, 0.02987505992003266, 0.11425103586647781, 0.039132859017099106, 0.03677577884387105, 0.01619745252443658, 0.06304898254212833, 0.056550400406723066, 0.018919826402599295, 0.020541548353409576, 0.044088926947405266, 0.07688280675680408, 0.0305423129259819, 0.05872627397278144, 0.03169962471621412, 0.03849230609053085, 0.03148247709407682, 0.0531297565377768, 0.05430962770215927, 0.03555276926847235, 0.03890381787993735, 0.04590636712589091, 0.02083234575336739, 0.01703448785138467, 0.050970503249235695, 0.04570729534832701, 0.023166592676012267, 0.039496260484860796, 0.09747797743447366, 0.09797822518814957, 2.0740596229030244, 7.397124853826339, 20.1446871988235, 40.455153372979936, 55.34813011846235, 57.13668777096657, 40.645219664419855, 29.11547922318982, 26.497330473315333, 23.691839518085605, 32.21171978981265, 23.706473881198516, 31.70501820502743, 21.713925523142663, 15.365835139828345, 14.014607052649222, 15.226322316354322, 10.576673130835257, 5.204599355497669, 3.429306668619956, 1.2042571219705767, 0.47179337891359485, 0.18621228695396455, 0.10691881600406863, 0.13540262386443155, 0.32639690825054724, 0.429342087478407, 0.502203606790112, 0.4247018316340062, 1.250496350469128, 1.0648618470276556, 1.6022272960793589, 2.9610563237820906, 2.547366883485548, 2.6781972954350137, 2.8081061955421203, 4.161069931522492, 3.4839548458976135, 1.918325347285117, 1.7628027570824472, 2.7897144469522663, 3.323383552412833, 3.7347411436419335, 2.7894835174083714, 2.089141626511851, 2.7810786135735053, 2.5902332413581113, 1.1211820571653306, 2.145695830545118, 1.8235590453109436, 0.73105925874364, 2.4602049541088844, 2.1182137439327855, 1.060432265362432, 1.525712517961379, 0.7987251084658408, 0.4208510753608519, 0.21303291793071458, 0.15022503091923653, 0.06902475180404802, 0.1409633496716138, 0.4375657349103882, 1.1313770326875872, 2.8893595645504617, 5.555089606392769, 9.04642120484383, 12.071427606767225, 18.997990123687252, 19.899605743346676, 32.020384611621985, 58.62925160315729, 27.51052771845172, 31.661546576407652, 38.40132582572199, 36.82504684694352, 38.3026978277391, 27.951496262704175, 16.016847587400868, 6.305812626115738, 1.3909355887482244, 0.14168929458866197, 0.030516135701609236, 0.023348312562091217, 0.05656764504589862, 0.07197585272332353, 0.04958786393305467, 0.04186001711434895, 0.02500740236662809, 0.08611068820520755, 0.024199792476851615, 0.0414505354579418, 0.02143164676043295, 0.05950546583100673, 0.0588438339952019, 0.014336204565610858, 0.07449133306621544, 0.06960253531654036, 0.023472545210332162, 0.07612983425778728, 0.06462509353314677, 0.027209951114209912, 0.04155214936021836, 0.0486080834431754, 0.03408616671579019, 0.0037672069635347376, 0.024895963386722633, 0.14433090364740742, 0.013531859168001722, 0.07150699925278464, 0.06860513480440264, 0.04065975651986176, 0.04564258390136304, 0.03795755373674535, 0.02770875479214855, 0.012155985365802003, 0.024694855730499954, 0.018969438256575696, 0.005535247159235541, 0.006884492702797176, 0.07760655300150957, 0.03928612256723066, 0.03491251894663419, 0.05075679153143879, 0.032327125419772444, 0.044558052379157276, 0.15764393363027804, 0.2008724978734409, 0.11952709106187667, 0.0981856434936485, 0.13580734811482892, 0.12280924921675075, 0.17813424219287213, 0.1644749711117437, 0.13249315982384066, 0.1537257309762701, 0.15062480624164307, 0.24795604719510003, 0.23015769498963512, 0.20891248338645507, 0.1768732308259895, 0.1733230414890474, 0.22510965054313983, 0.1850393603766157, 0.1080739540198157, 0.14225062253254075, 0.1655970600944373, 0.237006030736431, 0.16399192203196788, 0.33924852347662376, 0.2546936679150789, 0.10187389719630442, 0.1318264947903733, 0.25809673772704217, 0.15204131813539615, 0.19225878911393304, 0.1402210257947445, 0.20357997517191595, 0.18614136253393468, 0.10646433434298924, 0.1421868227302067, 0.09556409061676073, 0.2218139862581607, 0.17935696448529923, 0.1552391223489277, 0.20741030754100895, 0.124765929705914, 0.24326556662638343, 0.1541269312222158, 0.16598880681539738, 0.1292677917667935, 0.1575651031828696, 0.07487234689535634, 0.1595830400624583, 0.08630175819440235, 0.17262918033426808, 0.35182226329080524, 1.9948477249953056, 8.690317061639602, 21.922003338413855, 46.58282126149824, 61.31545543670655, 61.377452419650176, 47.83286886830484, 37.58471973480717, 35.79382434968026, 31.942031345059796, 37.31262099358344, 33.24082812955303, 37.30383096202728, 28.224905075565463, 27.18521025873, 21.94481388215096, 19.67581883553536, 12.856368403280936, 7.556441724300385, 4.710423369561473, 2.7940766128801533, 0.993161594435092, 0.5956178555084813, 0.7918472936557186, 0.9150804423036114, 1.2970134543795742, 2.9490381815741142, 1.9720131567408963, 3.091148839842889, 3.02093449138826, 4.495265185832977, 7.131190117328399, 5.83321899175644, 9.99895703408026, 6.104468539837868, 8.014773620713143, 11.028738060305196, 10.095616982829187, 5.197632245479092, 6.14202719542288, 6.70520551743046, 7.788496498138675, 4.344178918869265, 5.6841806923189475, 6.425374804004547, 5.908797181421711, 5.465834602232903, 3.47706986050452, 6.774090182396674, 7.2097733328419356, 5.553941822821095, 6.956220538385454, 3.9557213504468245, 4.894016769624526, 3.6685106975416986, 2.718589618321388, 1.3027222190172443, 0.7317638144858423, 1.124053109557398, 0.4431175434541318, 0.6214936089611823, 1.077265362105062, 2.2630605005448867, 3.241018681756912, 8.241225288760278, 10.03187454515888, 15.447057620171579, 23.877132285025812, 26.43394889370088, 32.502353691285656, 63.06058460666288, 38.586442086004446, 38.68527796960647, 47.4303513188516, 43.22886136270339, 43.77155657737486, 29.84799950353561, 18.11071272819273, 6.752586768519494, 1.416569013268717, 0.3230724850248906, 0.12698632064125231, 0.07814858319057573, 0.1927378545365026, 0.12277080692471036, 0.14669250756982835, 0.10739516947538623, 0.15509350435628047, 0.1571264105939096, 0.08984152873557422, 0.16264991984973032, 0.18108902799506343, 0.1398757193237543, 0.1331551670427284, 0.08444842296622454, 0.15175460206885494, 0.11500226168502724, 0.1618772895345765, 0.22686831262563506, 0.13763269049025353, 0.12599548550262568, 0.08648117598626884, 0.0775081413467565, 0.09869012005266645, 0.21082080840583772, 0.2108533058555857, 0.19189698110905387, 0.14484026018650303, 0.1892387019770761, 0.14406038267958549, 0.1121718732399806, 0.3099992558840783, 0.18651230230687127, 0.09406740762173169, 0.0919630483634049, 0.10851753424973258, 0.13345047861578005, 0.1822988953321211, 0.1116351903446259, 0.19735826870366452, 0.14675034720811153, 0.19888969378605967, 0.09505625859263445, 0.17617898662724804, 0.18272575952353018], [0.025223090591269638, 0.05645938533087892, 0.07645601917418741, 0.04261615355649302, 0.014692215200123048, 0.03633816260844469, 0.017429151452116428, 0.018505367089904124, 0.008471996857664518, 0.056906129503923084, 0.04772095362685862, 0.06156433861882937, 0.025744451728138714, 0.10877625746352058, 0.04037484075994261, 0.058643421563770504, 0.0716727040708065, 0.03264761447245556, 0.01986709603619191, 0.052465968164465124, 0.08083505435816704, 0.027451477569317626, 0.014961055562561078, 0.044283723954351685, 0.02866498765445525, 0.06023485431327455, 0.018767972454248417, 0.08513278463074277, 0.04370610515076307, 0.044978017948808215, 0.0549819081601116, 0.038183725874630675, 0.03912009216184097, 0.03856877315669291, 0.06736667706601082, 0.02308640625297783, 0.09332340601230822, 0.06487457006568871, 0.04273021255709952, 0.03378541591847616, 0.060361285633858175, 0.02474094741046429, 0.04869638656776759, 0.02963095557905974, 0.010662394493157345, 0.0329334418770046, 0.043287855618062525, 0.039796003876554395, 0.0479179110017515, 0.04060695774012035, 0.024549383294558334, 0.12464822029634831, 0.8189318112788663, 4.931914219933172, 13.014126131611487, 27.706912948239236, 32.76440332012792, 35.00351775077082, 41.30025156082646, 35.96878951595676, 31.75744852712078, 21.438943839842274, 21.87784137264375, 27.29653496896067, 23.339649900313347, 27.693065020345873, 24.809677754679036, 15.013839679379618, 13.209732770919802, 7.749803787277592, 7.473834647286323, 4.058131984164638, 2.3380574439802477, 0.9650363616885679, 0.4316645289861387, 0.13392096385359764, 0.13839477943556924, 0.22780232702291783, 0.3072907979930601, 0.24137434068947072, 0.3289303303726258, 0.7018778665411858, 0.5702410397991058, 1.7028482258319857, 1.558224676597503, 2.120281078161732, 1.1827396120755904, 2.180130563436016, 1.5188358676049019, 1.9444207534674678, 1.0437773913145065, 2.8088622323928343, 2.626650732371115, 4.128277445993116, 1.1454426521255126, 0.8959578458339938, 1.1039198286110357, 1.3015350891697792, 0.910651718656863, 1.6415698946483674, 0.8883167010161185, 1.0515130407387212, 0.8772068326511692, 1.003737468873301, 0.5493389130119355, 0.3753080982114039, 0.16365925601172834, 0.11110978426351664, 0.2800600188634088, 0.14232704746386698, 0.5138273362911517, 0.5607409979547224, 1.5481995887333349, 2.1327792204195455, 5.17103563393316, 9.259643208596016, 11.897175331269542, 17.173611425584365, 12.47287238797834, 16.49159166120714, 16.113425166376178, 40.077123180512466, 41.9907416835908, 33.04368195995208, 42.070314807276574, 25.65217541110131, 22.746883669207175, 10.414917526706573, 5.081267779873264, 1.6319577588189034, 0.13137320056557655, 0.025281998922207186, 0.01770564790574774, 0.06689194770109269, 0.08350577475803514, 0.011780681764526714, 0.00634933480121676, 0.05020802359907858, 0.009690860939782955, 0.016547650466823292, 0.07060470855644635, 0.007120542586856192, 0.020197143950950236, 0.04213144589636115, 0.03018471265902683, 0.056818944867700345, 0.0053623612245334495, 0.009223613381055335, 0.02657560733026795, 0.032977208480118744, 0.020666074030281558, 0.07983669623612397, 0.023190050288253737, 0.07166907281404541, 0.008941350200574004, 0.05004832491038307, 0.049106454281436826, 0.10141442830283796, 0.015864317275343404, 0.05772424628958107, 0.10995455431721865, 0.07465852409481041, 0.03738980597606109, 0.015418362172861255, 0.035414057558462504, 0.04294133489771236, 0.03450162002756711, 0.02974599708742913, 0.03454904853095932, 0.05821818913964014, 0.039489472945851666, 0.04265137827925144, 0.037148381027603344, 0.06903674874094225, 0.03616180533783571, 0.008456651158931275, 0.03254198243901615, 0.0536147897852765, 0.06834196828065381, 0.03205494395637464, 0.028806685192149975, 0.07405820227558575, 0.0036187824556573986, 0.03449293259050577, 0.04681419663792176, 0.02575520377215599, 0.0427697618461905, 0.07178494361259284, 0.04589891692082729, 0.010857653068078142, 0.023326107503605947, 0.06472640866113287, 0.0041564650957532714, 0.04793717811304716, 0.02471696119755507, 0.006545956533837824, 0.009422982975299801, 0.055346918412514275, 0.019379530868102467, 0.016412914753140464, 0.041113832154341286, 0.05036247841593239, 0.04663848288116917, 0.040991851804597725, 0.03639284213404021, 0.020192535932085687, 0.03015898359608987, 0.024311373183023066, 0.05551738829742517, 0.08841445248934532, 0.02089035776143353, 0.030887383824935367, 0.08429145921141872, 0.010674271728813408, 0.07914510270160052, 0.020407243564184156, 0.040434722022543994, 0.07051635563613907, 0.04552295927198664, 0.04970970255653224, 0.014514364058061715, 0.031144975143815243, 0.03513646176865986, 0.10682745235821894, 0.024501303616430492, 0.03536124728740223, 0.026362684683033058, 0.08574194710461364, 1.5716021652183227, 7.83699268294919, 18.212231512992613, 34.459088848483184, 42.78465686305877, 40.51060392010597, 45.52184366410779, 37.28512125630533, 32.88239017609627, 24.44548764536458, 21.64000649606028, 30.21030687516736, 26.833091243620846, 30.3349401873927, 26.628537677949478, 24.27296611570543, 16.414293512221306, 9.261658326272043, 9.196381261271815, 5.526562698425786, 2.598891873513499, 1.038884724820814, 0.43516028011518143, 0.14518202733128302, 0.06383875407458794, 0.11146252178737234, 0.10429131062400919, 0.38351510621366963, 0.08946043063676165, 0.9821858221004087, 0.6310744271163018, 0.924950780407075, 0.4590597105843406, 1.368586658950775, 1.1108917190182594, 2.501332966550704, 1.7876658035862831, 1.8276915074356141, 1.9287070031127624, 2.498693946869143, 1.9466365248926225, 1.463438517624332, 1.2202046210727384, 0.8292314650550966, 2.31585854484189, 0.9127973164281539, 1.0355589226368935, 1.9818382037262765, 1.3490049613098944, 1.2250705664196324, 0.8882847091844006, 0.5841419196897938, 0.4117423205846741, 0.6236814947858934, 0.36208195792090514, 0.03915914349378117, 0.10505543736320351, 0.110316178460996, 0.3993049750645315, 0.7658115197573939, 1.3665010611857138, 3.199878166760168, 6.134699717644723, 11.570419342287126, 13.739470435727029, 18.825015560273204, 18.177991182573383, 18.602744648533484, 19.496537100884225, 47.341199767205026, 42.16980572669737, 35.55126497822423, 48.33247292426325, 32.17858164541183, 27.951961063569595, 14.150043552921666, 7.283437896159388, 2.030385379349032, 0.15811362213665442, 0.020022910659111316, 0.07142495889697345, 0.04765844468267695, 0.042044303394974246, 0.09355489480038805, 0.049701919103221553, 0.025464369983021772, 0.10052183627962105, 0.059034463483840234, 0.04063430707901716, 0.03536497813559348, 0.042091643798255154, 0.049424319482979276, 0.0445136001273509, 0.039214114132787914, 0.03253740506366857, 0.05578023689468542, 0.04793274629440519, 0.01875054969963047, 0.06002753559920577, 0.041077887308934045, 0.0464292872516859, 0.028302319715881062, 0.034824127721930706, 0.00624363334105921, 0.09323734369489456, 0.04802630478215795, 0.030548259683494127, 0.05823217024425826, 0.05929181540024377, 0.0752970966840944, 0.023559773896610545, 0.023913492013009328, 0.028769593130076127, 0.03728082230795295, 0.04996828787449387, 0.02199057301866912, 0.00365494946656268, 0.03662640318995522, 0.04084042303504483, 0.07738313878015166, 0.0378562462696385, 0.06938089075828753, 0.030344746511189208, 0.015631122026412238, 0.12138389666835148, 0.09652612084943442, 0.10521788630754718, 0.1876394781133821, 0.11132443443902078, 0.10057928521306285, 0.0748250562877905, 0.14878242607078246, 0.10271162966326361, 0.20421766676008704, 0.14933543429980356, 0.1374874861850854, 0.15588740127221232, 0.16076451618104212, 0.1507525437421376, 0.2760986701375054, 0.15248269203209108, 0.20733587443828586, 0.09493387604673063, 0.14776602657812257, 0.12964879793505515, 0.17960087155863164, 0.12659622100932946, 0.15121221181846436, 0.16426768304119188, 0.18456916625220932, 0.1201695170734198, 0.19724697145002504, 0.15124084818507397, 0.16197839781882303, 0.168181442385239, 0.09489050014845787, 0.18105086149467578, 0.24935510760593801, 0.14842987240802857, 0.17678252601575467, 0.2548121970387236, 0.11661227206669508, 0.18937385520867764, 0.11314718743726132, 0.1620367737186532, 0.16647081401559616, 0.15397579739651374, 0.10644821585306238, 0.15236390243855216, 0.1862454585610859, 0.13792277734366157, 0.14817576104354474, 0.14046425871070356, 0.17579356779254254, 0.11948674887178407, 0.22577201016247275, 1.4400691587117411, 8.790549309022966, 20.518151752410397, 38.70606653151974, 48.50525725272394, 49.87077551503336, 54.462564837548044, 48.8645306710274, 43.098442554473884, 31.726516715941894, 33.280165580011186, 39.416792162003055, 35.9413250800102, 39.98132321142381, 35.858900393209154, 24.301252288203088, 19.50317963477104, 12.389980939126785, 10.066624783700513, 6.179731959296811, 3.439371225333983, 1.3929293785364398, 0.8454299345612527, 0.714730738151458, 0.6621812127770916, 0.9007253642043761, 0.8302823538261076, 1.3123771331964003, 1.638922294782054, 3.0983054493704154, 3.448241665478676, 5.209727854497972, 4.27877486713471, 5.761925991504423, 4.792017984774805, 6.308990236251585, 5.552463089266132, 6.498343636912685, 3.557272279454816, 7.293415425285217, 6.415839031819375, 9.489940270300835, 5.9334330981777565, 3.928731521291118, 4.576672507870582, 6.503372605769865, 4.960989769428007, 7.031881097824344, 4.458982281146511, 3.3263464127817466, 4.4495955590278875, 3.957100308710529, 1.5795366297806464, 2.260429080455534, 1.2255666236723624, 0.8975902259830506, 0.4570339902514412, 0.5157995223999023, 0.8566615802626457, 1.1510913554699191, 2.3800748538586403, 3.2367592328979127, 8.494271116871989, 13.782371359486735, 19.476317282645933, 25.910232067108158, 22.356890247714137, 27.095760606950332, 25.380296322607226, 49.22010921662854, 50.539284675352036, 43.5048314832872, 54.60324064377816, 39.093855580975934, 31.671823186259118, 16.137329070798813, 7.491985905554987, 2.3200277791869257, 0.3602561865362429, 0.14002115345529972, 0.27197668809563885, 0.16763957307463692, 0.19984607795073142, 0.18617739930989283, 0.12005296445661977, 0.12468771212884497, 0.18927742006076922, 0.11141526948420272, 0.26819196860155753, 0.124475528756457, 0.10631277150804959, 0.11728649838797509, 0.10245559541808982, 0.2628185972571373, 0.12613736498620243, 0.13965988171196755, 0.11095678884415858, 0.08615118361288503, 0.13164007495487892, 0.18682460571008344, 0.1886624506404323, 0.2715525818207572, 0.12327533710988299, 0.10835991932019111, 0.22847991647018542, 0.21976215764880183, 0.14842354452177403, 0.14999523518546937, 0.2237498291557835, 0.36332436867298623, 0.19217617419217864, 0.13628039208631362, 0.1670612686223561, 0.20081369296437312, 0.12753411181150906, 0.2611062375287856, 0.11385990201585716, 0.16238074719665513, 0.15124011274066665, 0.21735711654107417, 0.09988502569256291, 0.16774684070579468, 0.12535974743866152, 0.04968450975514228], [0.03593461047257147, 0.01079249058684875, 0.04594960895877692, 0.026023934009454908, 0.018614341181913213, 0.011164880181182057, 0.02180824600791018, 0.03063793027503116, 0.05091254103688463, 0.02442191775527693, 0.015156656004218085, 0.04680557048789436, 0.06461667422685893, 0.03395393610961976, 0.05052169063879598, 0.040491688320593494, 0.03183585238612948, 0.019840415109009035, 0.056716296746726, 0.010253677009454659, 0.10778495501126013, 0.028163175166193998, 0.059129297507986914, 0.063028447555318, 0.029677451370404135, 0.02368899760767818, 0.05058655913378443, 0.03246762594508548, 0.06195617727034035, 0.054730087398521365, 0.020530706294061198, 0.10214456372083196, 0.01639411495547862, 0.025073264860698295, 0.0337542093268806, 0.02732507880747078, 0.02175262993982723, 0.13387780245994368, 0.07807774304021751, 0.04780274883453404, 0.0358998951982827, 0.053046287427986824, 0.03752223193465221, 0.0422359211370349, 0.024011074377584363, 0.016364517148524042, 0.03416868587655406, 0.040660664334052035, 0.05980046713844903, 0.042101239049506765, 0.035537133413937785, 0.13734625021536506, 0.02717186696827412, 0.3214469077366014, 4.098265920915912, 14.692896642992574, 23.56303280399692, 33.123529649549916, 41.949529340190274, 42.587381255242136, 38.71677852446033, 32.47666412784208, 27.520763143416378, 24.223907070775187, 18.76832946654289, 20.537473347879228, 19.573284156860847, 23.89760313495513, 22.927648059783444, 13.131774683152477, 10.471051546835131, 7.717814407040996, 4.87824688034673, 2.320580097936815, 2.304664590666371, 1.0934928203782728, 0.470137617761089, 0.21909273469880705, 0.1997284374890789, 0.05085274404395492, 0.08656474851792859, 0.18756481518428172, 0.09733864902368478, 0.4696912642928862, 0.4210874594507679, 0.8004984487929653, 0.6352481354148157, 1.4370887702511204, 1.7018433636234653, 0.8865279776434746, 1.692675681364152, 1.9706158123670088, 0.6722352894083147, 1.6917562532809474, 1.2216862964053308, 0.3920329620520915, 2.2022027209881814, 0.9480574630921887, 0.3504971150429018, 1.072871449493593, 0.890441338621801, 0.48657838555593647, 0.16492304061689686, 0.5172397064105158, 0.31984878703951836, 0.4586346543604328, 0.3998431058660631, 0.13990902882670203, 0.19735471405569585, 0.7766444933029913, 0.9146265505302338, 2.112286307158009, 3.74694878535886, 6.343900801674013, 8.170718723727811, 14.422115818146738, 14.139011886812026, 9.305269199032939, 12.410512585793773, 19.208344874843476, 21.260205353460005, 30.120333586969686, 45.46482416891283, 37.063068036110174, 35.60138502428609, 24.032673874209006, 11.299967996535763, 3.826578783412134, 1.6102100548244294, 0.16885363857351965, 0.06295311046884426, 0.022821261307164546, 0.028951324507473942, 0.025127385142109087, 0.030785038308691115, 0.0317893757469832, 0.04270261423962732, 0.022599388837754246, 0.06377508067676137, 0.024786384085253365, 0.056222821210300734, 0.05907767467320927, 0.026328781461944024, 0.016318555703506838, 0.03424553981711788, 0.029606574830869516, 0.024923965815574895, 0.020990604196765253, 0.030850831854848132, 0.003486806813124267, 0.031295017294225194, 0.03784744391938852, 0.06487948068928334, 0.019162042336838863, 0.05254711602784453, 0.10664136194053198, 0.08663781798414646, 0.019098029945105798, 0.050084354025461984, 0.03764592832134616, 0.04752665457706298, 0.06806438398217002, 0.026070198059202205, 0.07154122040036225, 0.04682915833508296, 0.05411706001107251, 0.02084031881343934, 0.08440572888620439, 0.04686735164854796, 0.04550219445879902, 0.011702422052621843, 0.01755607881463103, 0.04203244435390638, 0.012292625765586573, 0.012952284924986382, 0.03507889792202942, 0.0271876847686907, 0.07086096496711816, 0.09804322774852477, 0.01932734304348067, 0.06080106989811025, 0.05062950219237997, 0.012924242276518096, 0.021970535989009568, 0.003072355640113294, 0.046069386805738174, 0.04071696796604703, 0.025855923266780954, 0.06638809167329343, 0.059058660370928634, 0.05541106295441428, 0.002914134304099266, 0.07323804386560956, 0.05301032343038148, 0.030921189369814053, 0.08441335912193022, 0.05480083178788905, 0.0405723343963825, 0.06754875318297456, 0.08059138477209114, 0.032436867514925624, 0.02391511228896918, 0.026983062684115384, 0.059155635610823674, 0.04203039123826931, 0.018914415906634063, 0.04968871557784658, 0.0465913110172316, 0.014159015131994121, 0.03662876657120163, 0.03997256799090294, 0.0629737718601621, 0.017049658307505232, 0.07083128672093153, 0.14207952445553196, 0.019014957285816633, 0.09246747895714738, 0.094870658471219, 0.043254592080390265, 0.03323277158121909, 0.025150430982091257, 0.0355787817839413, 0.0075563915532022245, 0.012693332842431002, 0.03138311740551745, 0.08249559589932043, 0.03570245135755789, 0.020885075585195617, 0.08037371621016534, 0.7406824875262477, 5.661637360049832, 19.369799437061435, 28.491865511863466, 41.51296169527116, 50.14891470632246, 48.79588134827153, 43.048200914936686, 33.91831559519614, 28.344919796912905, 28.455765977982555, 20.398548879931052, 28.217072102331347, 29.661765367754047, 23.69166889498311, 23.85692423389804, 16.716984779604022, 12.689948120424825, 9.063901247516755, 5.8918505810922195, 3.7038105582037284, 1.6467113864998666, 0.8211753457303971, 0.6492317528013261, 0.16698968536671133, 0.0026225363422605784, 0.08442177842821806, 0.04478414024737093, 0.20115860106964267, 0.18320885456858144, 0.4384366543062272, 0.8101996346827477, 0.6615340216986595, 1.0254113219918743, 1.0727274249638281, 1.127066225294144, 1.2442637042653177, 0.8006587756737586, 1.8674702245381571, 1.3066580723370276, 1.4408728768748622, 1.1918426978011285, 0.6399651532692294, 0.8055972848688403, 1.1294567873401027, 1.2425466867223864, 0.672200907382273, 0.46747904751569996, 0.8128705236219591, 0.3177758144034494, 0.21191105877439823, 0.23353186796509454, 0.18448696501793402, 0.12438116970682338, 0.027874561116820382, 0.5005800826174598, 0.5772048403178492, 1.0316684217222276, 1.67203298259166, 4.8671730487577385, 7.686684516168411, 11.430901615850388, 16.567246337090772, 18.424869083589126, 16.44580877596332, 16.27216740961998, 21.65122055238293, 22.274834263709284, 36.36847119177542, 50.251268955969046, 40.348488438513975, 40.630334269615915, 26.920103142338416, 15.409463663255016, 5.802063605477733, 1.9190730490992147, 0.3655665548097703, 0.045179200298603506, 0.08271180123331086, 0.06389142261938223, 0.019914853957391555, 0.03194137525203968, 0.0220268108927074, 0.03952654777094722, 0.048135954946760214, 0.04017480371159412, 0.020525322611173315, 0.06875017823110666, 0.09402293621772721, 0.11360536164213574, 0.05205968875558146, 0.02426240292768325, 0.016916619478574684, 0.07958397915166232, 0.08475493474472916, 0.024073826554681987, 0.0278811858621456, 0.0687610490187522, 0.04711490913083957, 0.044007346244348634, 0.06588660285718019, 0.03785983156112414, 0.07506049042868038, 0.09079851810970614, 0.05488255038677205, 0.0810439971786353, 0.08015807012035962, 0.18349385459817227, 0.014748068755462527, 0.032029080828050935, 0.07008551544840298, 0.04925552350018294, 0.03508597657444977, 0.028793412718861818, 0.060940578339561347, 0.043803628143523975, 0.10774311128883593, 0.01233932073979128, 0.010016851461372309, 0.04927320097903571, 0.05735413389160268, 0.03844677748519086, 0.034420288303085876, 0.208009127827902, 0.10720379305102172, 0.2426513786157293, 0.14654970878074247, 0.1540977585940592, 0.1666740111766323, 0.08272086405345509, 0.13269632634135986, 0.16202753469828637, 0.1674874433346333, 0.14873581728146923, 0.18165253162864717, 0.11018161511709613, 0.2057582082887811, 0.16682801017117116, 0.15343031215090908, 0.19007514741632248, 0.16102639567707816, 0.16236519561179225, 0.12678424962946486, 0.1824154939141966, 0.13209808828128924, 0.16483031333454196, 0.12444246440164505, 0.1128417328600922, 0.09952076620632604, 0.26820591140177946, 0.2360002032571262, 0.22254394547593212, 0.1426437788552815, 0.1362119651129169, 0.1641955788457586, 0.1290184607909572, 0.16224655923583817, 0.12456194347431584, 0.21805142202684957, 0.21728444544057693, 0.14946447414976938, 0.21600425123207032, 0.15117881038496572, 0.15460829490855818, 0.19143855409516444, 0.16940496140910735, 0.11331915119362455, 0.20911379597119747, 0.1825532518447407, 0.1525613539401562, 0.12154542630718601, 0.1929665777471758, 0.2669115598884321, 0.17825051901801942, 0.24722861606747876, 0.16960874079696595, 0.9934068038578957, 6.713332178131227, 20.42417568545188, 32.690343087719334, 48.973223470872455, 57.05615366658857, 57.42871607503584, 51.73026530973373, 46.959713966615745, 38.5717410425986, 35.15425051412275, 28.1869424158527, 31.96230999885067, 31.213811943607947, 34.43402490308208, 33.72924950815017, 21.169996723051995, 16.21870844594894, 11.904700398445131, 8.428093867917216, 4.086023468163706, 2.8617166607610645, 1.7333961350302545, 0.8763738805728575, 0.5392541315767073, 0.6080983471005195, 0.5491851438437739, 0.6042300933791745, 0.7938665175630201, 1.2545960853176734, 1.8648388044488047, 2.1503967911966386, 4.709093195776786, 3.979371281400804, 4.299796319776966, 5.292843859041891, 3.1121835304844767, 5.011240724594363, 4.552616121307496, 5.467971803680544, 3.7814536306165882, 3.2288581084820533, 5.005280683117529, 5.071061772684898, 4.843393679588072, 4.180834754820793, 3.4144609878140115, 3.1207426324967416, 2.314144959372859, 1.1145128021317146, 2.021693161899044, 1.3310636724195173, 1.4293051943663628, 0.9547131124042696, 0.5297738854442874, 1.2192236608074558, 1.1899425546007774, 1.4746920427968426, 3.5153181177954522, 6.3469715272226646, 9.969420606090177, 13.575523207264563, 21.26667726424433, 22.979397850651896, 18.103042533320767, 22.353966120750677, 30.56264162063599, 32.08277775395301, 41.49369109061457, 54.93811691960981, 47.833398388278106, 47.39517158077609, 33.281161862034956, 16.78837191674017, 6.301825536835579, 2.3192572785962016, 0.5056849861096951, 0.1482590807661895, 0.17123851624708022, 0.17790286831798094, 0.09413332182673678, 0.14815990302351215, 0.15335644595324993, 0.17303782695483777, 0.19564662909796163, 0.17907052421041075, 0.13824297145249384, 0.23346400789676175, 0.1759620305270918, 0.2524192294766826, 0.14302265529911365, 0.10332937232188641, 0.11624528530744777, 0.1597226212822622, 0.18971148547866654, 0.11692744063874407, 0.12500866466472227, 0.27820602479961615, 0.12939733723478933, 0.19626231864094737, 0.21431790784962718, 0.16428312737374537, 0.23097284318458652, 0.23708901338038907, 0.16613958824065425, 0.1633923663006675, 0.18056969699119368, 0.2341582674172617, 0.17538162699389845, 0.07852683910318921, 0.15471999052791827, 0.2583021105777833, 0.10962735816475846, 0.09285729513653825, 0.18647113274182045, 0.15160680838650273, 0.1631068146877712, 0.09159632973493108, 0.09537822236457179, 0.13007017693692638, 0.12467688730647489, 0.16501400589702592, 0.1427838810148739], [0.005698963021483994, 0.05558431756892993, 0.017665784520607804, 0.03298256726514909, 0.02051011768109616, 0.018403404617622014, 0.048440628114246556, 0.054966758771408955, 0.03404831814189111, 0.06355534750787963, 0.08544456709416644, 0.03201705324763973, 0.010240239827262779, 0.007249495294320608, 0.02887683011771691, 0.06561353081657041, 0.031286243672272375, 0.009487289353273809, 0.043628849014039, 0.040360097397839835, 0.07009698378462946, 0.08677207489287661, 0.13991586233098663, 0.02746306081873275, 0.04048187473428346, 0.014771943885622727, 0.08433860426227893, 0.015873876137418613, 0.07840783500503148, 0.04571826189696308, 0.056167398579418666, 0.03511396942720298, 0.01744717558575494, 0.014000495261092101, 0.03963409885463696, 0.028832902636138663, 0.034317877669368065, 0.02682675776492444, 0.08693845386827186, 0.02657882489954993, 0.06746454479833765, 0.058690129944513884, 0.12024446345505216, 0.007256498295558437, 0.026770578622217142, 0.061410872055397886, 0.041907744392031626, 0.03544646307765957, 0.07106845988140953, 0.03711171605954728, 0.03839836072837634, 0.03217090093981355, 0.03667171729067641, 0.02405376462716489, 0.18448026940947582, 4.06413909408354, 11.405822961561142, 19.329187216297274, 30.934499963637325, 43.395746446424916, 45.73718963130828, 44.765622461995775, 32.162456781633445, 24.1409920877026, 23.930521626626295, 14.233918536093928, 23.07189714524054, 30.738808993370306, 18.06689004744253, 11.879858066958766, 21.572812372638335, 25.948518322360133, 11.181462407112123, 7.940146115518386, 6.1033864559665805, 2.834574349464909, 1.2774277117944535, 1.1143348245851457, 0.37090336843844385, 0.27605239842687884, 0.06580705994800215, 0.15285766142750942, 0.13978147518730935, 0.19466743083490481, 0.6635474233377365, 0.052253466865588585, 0.47372677032986, 0.7493287397007788, 0.5992717271850956, 1.019765744286199, 0.5037838623168007, 1.1358136010746802, 0.8017033518802735, 0.667548118339431, 0.5730647173139357, 0.6153063764495235, 0.3247833125773938, 0.2792954631149769, 0.5789925218109162, 0.22183329167385257, 0.19808390718554297, 0.5793971388090042, 0.1673112277902903, 0.13909129125456657, 0.10868818033486606, 0.26249766770389776, 0.22705802663920388, 0.3911427678840776, 0.8645425412443377, 2.3047055304050446, 2.1419227555874856, 4.814005321071995, 4.846630125276504, 9.622258486286286, 14.232060313224794, 18.722473036858347, 20.017871087597264, 20.0561632264045, 22.879475470512148, 17.871834501143425, 25.795634138968687, 32.407818686577585, 37.383902226724935, 36.05103769610005, 28.062946488780362, 15.913642183426889, 4.340596814309397, 1.2275968179587395, 0.13841187851803918, 0.045871330094673944, 0.021653147677199978, 0.08063633115060868, 0.04365985259233464, 0.04841515952120385, 0.11860079116999142, 0.05497906980435214, 0.04146231789021723, 0.02691064056219353, 0.05706567497503373, 0.035723488131958636, 0.05795500346369321, 0.0031809615311137736, 0.02167918126008684, 0.04380072083985133, 0.05552618681723553, 0.022466196791238846, 0.07391887386479686, 0.03835393912008694, 0.0658982550545085, 0.04503910579989034, 0.023932006442919377, 0.041724783443515344, 0.05095603184834604, 0.09900685910496021, 0.1112894855079151, 0.013804082766235357, 0.029632765461780855, 0.01137272175025916, 0.02223598545477275, 0.038251900039012396, 0.04261507720295941, 0.029171561379165902, 0.028270431306032885, 0.02137851090200486, 0.03549976747543101, 0.03139775351531083, 0.01784134697499535, 0.059063371811662956, 0.005202992911255288, 0.012021265931487566, 0.04247596712722894, 0.03135171929194081, 0.028519283476916533, 0.03559788801677285, 0.03329798098533385, 0.048160102038133534, 0.014057261418671379, 0.07938799853887289, 0.021160614428921573, 0.058115675084052555, 0.01490450582482041, 0.03233694666696172, 0.01457109765690421, 0.026929285227050705, 0.061767079957550576, 0.04591106707530637, 0.06672404421072814, 0.059775626737504244, 0.026822707075024807, 0.06246069596419412, 0.03607340262181336, 0.02117664098829752, 0.040392104551316275, 0.02223105950941963, 0.05685244206218951, 0.01620505211664544, 0.04592569552422051, 0.10373139228191107, 0.04516331163505393, 0.02513260794653287, 0.06888500970578001, 0.011620273486891342, 0.019817081986055262, 0.013051922320418302, 0.034476136112765926, 0.03968501688852426, 0.020060820520044337, 0.010776078110680947, 0.014174038116189261, 0.01232771450773843, 0.009461136069148779, 0.022782956910950523, 0.051756762268562476, 0.05003035248767945, 0.04031442706623385, 0.045476013403986736, 0.03125411011428843, 0.0630425320818059, 0.023921078198679516, 0.02750570510303782, 0.03478947373467588, 0.00634364516196412, 0.010088663585784455, 0.028562912184204307, 0.042503737814484105, 0.048792408028196906, 0.04722779984736154, 0.017807621869348714, 0.03080146706422731, 0.016252610854984775, 0.6488368804416349, 6.062550169806327, 15.28149143342049, 25.932799423894576, 37.57363903907038, 48.47305459360923, 48.753813928173436, 49.695618152618415, 34.637191910897535, 27.47983713303843, 23.143905978049002, 16.307010804453206, 23.42130776374571, 30.619310063700524, 25.20703934854077, 19.67671705830482, 24.460308321060676, 23.6164927482605, 15.677169349885757, 8.85773068474185, 7.628831027015564, 4.375289197890989, 1.306913148972296, 1.062289997935295, 0.30661176830049486, 0.09362848520639444, 0.14095478480862034, 0.0213592782646658, 0.16020193185296752, 0.13607103557836625, 0.20930973061871147, 0.09678232363395153, 0.5808685179198942, 0.4817058518528939, 0.4840180890694742, 0.5892430233859247, 0.3668090881359193, 1.1443850830678017, 0.5066733927496019, 0.5387084318264839, 0.9957369368883872, 0.5145849972482651, 0.6921758839199621, 0.3850484771593925, 0.37345244939769473, 0.6724790892293376, 0.22670662210833645, 0.277010467984984, 0.20352748282734426, 0.19832778361535844, 0.10712935228741939, 0.16728427681711414, 0.27342551357803807, 0.3392243150982165, 0.7362967260902928, 2.4032894017234927, 2.3998063370104763, 5.982778476130578, 7.703299185922069, 11.15950595948004, 14.238007606998568, 23.034797406965687, 19.940945563777802, 17.236194802868752, 21.192218911263254, 21.77014877719264, 29.321435036197787, 36.24353977941698, 42.839417073034475, 41.613162563693145, 33.11543779988443, 20.720524480265958, 5.954484458892576, 1.98504327045333, 0.26755862839279637, 0.09200452436362544, 0.03951855747389697, 0.04323908646080283, 0.021997810634333762, 0.014279133888081679, 0.08848810418238563, 0.015491398122732439, 0.0029392181773624957, 0.023150876382245653, 0.028755186846660032, 0.07864221194458586, 0.033572186836071556, 0.07881773034891776, 0.05725801283974321, 0.008697756265680636, 0.037776381603532264, 0.030721912663730404, 0.03239472884865057, 0.08917992754328637, 0.02651638681850126, 0.04973984811635268, 0.04973709786070451, 0.0016918179185708025, 0.08264444678300813, 0.007512502376020196, 0.09120728730434373, 0.016751489226496028, 0.029675494015757597, 0.0023056167804996574, 0.016970611440258163, 0.10561003139422787, 0.057910275420234095, 0.05244712623196745, 0.052318963552674944, 0.06570485615802389, 0.02400249227761261, 0.03179380565040535, 0.03805012397107579, 0.05432689149353293, 0.04475019489144606, 0.02355183914093481, 0.045060169387368426, 0.01802782043664446, 0.021581085616602533, 0.038144912029947006, 0.0561087737010131, 0.02353566127919382, 0.12758729363521262, 0.19706619002165335, 0.09465743321925403, 0.17637677520753878, 0.18094875729612767, 0.1116408976996618, 0.10832608887745489, 0.11866417728484639, 0.11220640848360716, 0.2494694692112746, 0.1945602091690225, 0.16555019083522982, 0.16438374536172037, 0.24141912618952416, 0.15968332097174662, 0.13051921171286415, 0.14770513790990078, 0.1622901802822467, 0.18747184275379106, 0.12745057758424552, 0.0932061562554971, 0.2171061461370799, 0.1906294120295394, 0.12536844253660212, 0.1425679821160532, 0.10340315424987387, 0.2596416919221801, 0.2476236722882717, 0.15693462814294523, 0.1531363335708457, 0.13797531565350873, 0.0701548540664296, 0.14441348792564485, 0.1716595581702648, 0.15795427584840407, 0.17958911976987318, 0.176596948876977, 0.13831138310413207, 0.12731834314763546, 0.18584376801886868, 0.1738432611549093, 0.1420612915629341, 0.20962336701491188, 0.11747665673253999, 0.08416393621554298, 0.20840537914585686, 0.17523895077888044, 0.11704796925187112, 0.21458424597738252, 0.160951487599842, 0.22250110583920635, 0.15299430086968407, 0.13940668965299285, 0.1279100847821082, 0.6809802749945272, 6.751845440556926, 16.42522123552138, 29.56005830918589, 43.08194898789929, 55.658385676722375, 57.58272793985183, 58.73002513762444, 45.39501382458595, 35.62945742760935, 33.18144344514416, 23.01108079571878, 33.296353201712336, 43.71153254662791, 30.38751563718242, 22.45552020688211, 32.54289727057181, 33.97843376282723, 18.398202849972634, 11.807490337279535, 8.26847791671753, 4.268558563724641, 2.153914176648663, 1.4635913674869847, 0.7369203216606571, 0.5827536457969297, 0.4581776063048071, 0.6733419493802133, 0.5124946803815904, 0.8172822707603056, 2.0113090545900407, 0.841486910658498, 1.6083453355296966, 2.764110440208066, 1.8949748647789804, 3.261268408067765, 3.553995874620253, 4.251410451627547, 2.7273806304700914, 2.7352540531466087, 2.6249550427159956, 1.219113957016699, 2.8036214555463483, 1.6621166179257056, 2.1360308652923954, 1.63017246752016, 0.9750890287180102, 2.238039210919411, 1.7073721895294807, 0.5965079271024274, 0.909320748140735, 0.6152405541750693, 0.9822583246615626, 0.7418687593552374, 1.2557828474429347, 3.6276329813465, 3.7603924639763373, 8.113022129381857, 9.225976524814483, 17.146633363539173, 21.971799788936494, 28.432708324924594, 30.45357619562457, 30.884866291476836, 35.63017129898071, 29.408256699962003, 38.353555279393355, 44.1141285434846, 48.4872418065225, 48.17025938341695, 36.2668857266826, 21.635786025754868, 6.5777583949027525, 1.9619863528397776, 0.343130229701919, 0.18842772130043278, 0.15220556738636187, 0.11114346914954724, 0.2044257515620801, 0.1604885559889578, 0.1816303610441185, 0.12965691846705255, 0.26905084509522686, 0.07321022721307893, 0.15844829530725557, 0.14615197125221455, 0.10145984965586856, 0.17483879241251177, 0.13064295023439393, 0.17959978371377916, 0.17682064655086688, 0.11472646237140703, 0.09042187864261289, 0.19973966833804885, 0.16741328602356298, 0.09929687701045506, 0.14712392232350766, 0.17113023737986244, 0.19422075560977384, 0.19271170029476767, 0.27637066199414195, 0.22883794000071866, 0.12246963477903798, 0.05082385869876993, 0.15706751375429093, 0.17739118287159553, 0.13901569369819858, 0.15843567017826343, 0.1725673110735032, 0.11249644937173975, 0.17469469127395462, 0.11101207740965391, 0.14064208303968753, 0.20355840213596824, 0.08687155140984444, 0.07603341443163734, 0.1123086812214986, 0.0953305793565608, 0.15355408131595583, 0.14313876358491762, 0.14801810014872782, 0.16330870949933607], [0.02691422010801973, 0.008350581497765117, 0.03683344994281088, 0.004827964144022835, 0.012489007616926347, 0.0420130470076636, 0.03825761505492753, 0.030956427499111143, 0.023207886730350798, 0.050718173039175814, 0.031625044141565604, 0.04918049284887891, 0.03608415849627026, 0.04699110932227585, 0.061505277070306966, 0.0797578274843193, 0.017000764660957842, 0.10927380092682377, 0.05324168964439342, 0.059371059535131346, 0.04253676386489984, 0.019859484952664184, 0.006789751088006363, 0.04180350280817478, 0.009470648965948533, 0.038898723395240885, 0.05182951380829177, 0.04439931513080674, 0.11398965432759255, 0.028515374513282895, 0.10182998503648466, 0.07278057446162547, 0.030404666078186808, 0.07278644269512546, 0.08044417331656141, 0.08709407696921019, 0.022809394605217442, 0.03217211518917353, 0.10299584062229242, 0.014360492425640265, 0.18169681151067058, 0.05292841330951741, 0.0026072186536170664, 0.010785478009511868, 0.05317551113905446, 0.013352453825064005, 0.0044420248483337706, 0.041468182293277596, 0.026816199158108043, 0.06776123532965299, 0.03795141354203224, 0.04236050618572101, 0.08902867880439566, 0.02570654952808494, 0.07172385576151072, 0.21170173290996783, 3.1418241464322616, 8.664410787243998, 19.229968901603453, 35.22048757922265, 43.00019502639771, 42.5237133426051, 37.783054382570334, 29.195387709525328, 26.89772798169044, 32.895788992604906, 41.367924213409424, 16.271353517809224, 18.094166209620816, 17.801290673594323, 15.92131139770631, 20.580839072504354, 13.946271519507132, 14.647433430917802, 7.487290828458725, 5.981429671087573, 4.715045882809547, 2.8708155789682945, 1.8480783941284304, 0.9685344417249003, 0.5584136841277922, 0.07928967881467074, 0.2079553790991345, 0.11618736139949291, 0.15201663478247582, 0.10202622611916835, 0.23373783836441658, 0.27191717838568075, 0.27817424747251696, 0.34612367230076946, 0.24769654257162926, 0.6721585580418188, 0.15743546578432285, 0.4651530513599996, 0.3865171289972721, 0.22372554416858384, 0.13972107681535906, 0.23351455437800578, 0.20988189104583957, 0.46923375658450595, 0.16324253482443674, 0.31227662077834534, 0.21362970042372906, 0.3906452397425329, 0.49847606809869893, 0.6688948396232821, 0.8228444980998194, 2.1606927677508327, 3.627347383768328, 5.086006003041422, 5.992731000146558, 7.925537247811595, 9.023674399622026, 20.088873832456528, 25.27451196024495, 18.669007209039506, 24.562003612518314, 20.736868996774, 23.92760338321809, 25.2554766977987, 28.952434139866984, 35.83420515060425, 34.904830917235344, 25.66654501422759, 14.722192825809604, 4.732067988764856, 1.1984110743768754, 0.17431006917069036, 0.07220356469793666, 0.011851436687603354, 0.013038768590758405, 0.008789071073425154, 0.05569472616057723, 0.06168396707864539, 0.028408034103772337, 0.055036645142301444, 0.03209450856722411, 0.019634714755680294, 0.022949309073268406, 0.1261906770448531, 0.04050703689215645, 0.027411912958468163, 0.020859938325180162, 0.04851506121696965, 0.02589430810222703, 0.0563365699452979, 0.09331047444814637, 0.047732188306268186, 0.12488348589789484, 0.06907588817299375, 0.01469531881382629, 0.08683300952637389, 0.043792236416089925, 0.11365947043222767, 0.12395062063249851, 0.045182088450078046, 0.07720214284716115, 0.059463001577363866, 0.014626459958362243, 0.030800626282730413, 0.021850244863139048, 0.09165072197755499, 0.09775748461364739, 0.10591964582882582, 0.02911343254269131, 0.03346328743763509, 0.06601095424904939, 0.09302598003658558, 0.03177848197669993, 0.03475898343528952, 0.02060939884564329, 0.06096074943460765, 0.05499712649672743, 0.03286397302403085, 0.035587224072866866, 0.06286570366712348, 0.04029466199778742, 0.031060887418026407, 0.05073041895464544, 0.06061547360713444, 0.033664182504458774, 0.05044937576918353, 0.00828301445806339, 0.04576883519128446, 0.06205318698419198, 0.02374865862000133, 0.0484345683587655, 0.03519467679002593, 0.023018325934366837, 0.03632027445541274, 0.02371965070074845, 0.08300884416507137, 0.07337872825202442, 0.040695797126259536, 0.046448630971773985, 0.0417974392222541, 0.023002975447584065, 0.05380175737363677, 0.11908187140380183, 0.025858275156708497, 0.05499888466851366, 0.024094374948031, 0.021898874209352562, 0.019629285107516957, 0.07874048570351255, 0.005038764727707472, 0.049520459687036854, 0.02626094820668861, 0.07271737220787233, 0.039192912649483456, 0.07529187196445081, 0.025501105814210834, 0.07818154029307828, 0.014611567209114232, 0.021394909014024084, 0.053755106449487715, 0.1569824626729373, 0.10053872851835144, 0.04477989612027042, 0.08035903796553612, 0.03989705470420661, 0.016281639841655572, 0.03790997967664753, 0.02374955685809255, 0.0432213630166746, 0.018898801119517417, 0.06005020797132485, 0.057824508046671275, 0.08496940105913148, 0.06347870424149499, 0.05540403792814863, 0.5356331710373202, 4.583061558585014, 12.2101608591695, 24.76505491041368, 42.54625912635557, 49.034588952218336, 48.121610226169715, 44.50712650052963, 33.77820853264102, 27.39190151614528, 30.48286257251617, 42.12505540540142, 22.600808720434866, 23.962747819962043, 21.30927420431568, 22.068017490448494, 29.487555257735718, 21.064255506761615, 18.468325022728212, 12.139556234882726, 6.972320887350268, 6.423551882466962, 3.664941095536755, 2.208189973908086, 1.5864944241700636, 0.6306161839635142, 0.22401648904046706, 0.17452711720139752, 0.07806206122040749, 0.08296919145411061, 0.23964949372795322, 0.1637547871758861, 0.11245090544464127, 0.10919459509633242, 0.24930259993960782, 0.02401137315187483, 0.2172449919124765, 0.23475409996125007, 0.6619620503437135, 0.4005804808149415, 0.08146870866297715, 0.17583217862392628, 0.15964198286735243, 0.34300909587933176, 0.06465323960348483, 0.10548715855205253, 0.20178094025581114, 0.16251256028490682, 0.2367563780036665, 0.1891328592694575, 0.6018705425723907, 1.0940353332027313, 2.2658311647753564, 4.10112532877153, 6.2654249610439425, 7.891713178926899, 12.20177875411126, 12.551596318521808, 20.829997831775298, 26.860088917516894, 22.078313712150823, 26.22508268202505, 23.762067594835838, 30.0012602344636, 28.307210130076257, 33.86016253502139, 41.320549826468195, 38.87584240205827, 30.855732887021958, 18.773530529391383, 6.848302406649436, 2.029033142232126, 0.33978708328739293, 0.10489573101362876, 0.01848257405893697, 0.10872511343369562, 0.007488647355668007, 0.022028130479156974, 0.1010166677916723, 0.08169083585662228, 0.04111267919201524, 0.059092563592017665, 0.026845145790326982, 0.0384760650265361, 0.032419412201570894, 0.05919380594165095, 0.027342378988020846, 0.07842071294303864, 0.047965963866802, 0.020649547598535017, 0.03371097898531345, 0.06029493475873625, 0.03970711086426051, 0.026867019515785, 0.029896862782357685, 0.014021374987468365, 0.0303562703887902, 0.08045234747471348, 0.020126594914003246, 0.05283265614942197, 0.014502358502678335, 0.053708076311816136, 0.0656569296974809, 0.020294548200082876, 0.02062800329088444, 0.03905444608760938, 0.011700607381851203, 0.0792351946414959, 0.058071552250053615, 0.05201000412325225, 0.07397888919278499, 0.037353301886469126, 0.06678242011055832, 0.031956760212779045, 0.059319701000687584, 0.03902322034381571, 0.03922825228543051, 0.03215028934421078, 0.03568350217275081, 0.07285311532717559, 0.04594014011203282, 0.11861450414383605, 0.11899856700291557, 0.17068587574026278, 0.15800145154278125, 0.1639336533844471, 0.14601553099290018, 0.14712925429546064, 0.08940665892535642, 0.15813412264950816, 0.14419895266332936, 0.21920721887821154, 0.24573207862915533, 0.21221930191161173, 0.11583898291592637, 0.1721910393286136, 0.25808101760283597, 0.22829941083346644, 0.278463859351412, 0.17152201474433945, 0.33756202687659576, 0.11834840350333722, 0.07579581226192175, 0.22731325649205716, 0.11721246365097263, 0.21657710113833029, 0.19046484102164546, 0.089121482695543, 0.1506346581323493, 0.17965045276909106, 0.12698604484959958, 0.29067622016995187, 0.18260058075670274, 0.17892395626873742, 0.25724417379786896, 0.1899833394394767, 0.18127877265214923, 0.20798712578271666, 0.173552913831607, 0.31089000163539765, 0.06315009848725411, 0.29843874395855013, 0.21037669191437386, 0.16242465935647488, 0.141155852245227, 0.1420551015725059, 0.1479755516254133, 0.17997587159756692, 0.09629370509496621, 0.17703407864657142, 0.12943182651314045, 0.19940090425793203, 0.13908841076397127, 0.17695281203956376, 0.2188943485699354, 0.21797199403086018, 0.744342610480324, 5.139188439615312, 13.064992408598624, 26.765144025125814, 47.08591622691001, 53.9907076281886, 56.94942205182968, 53.67213664516326, 41.59143263293851, 39.10979609335623, 47.1365265692434, 52.59035479637885, 25.212295324571674, 29.95529397841423, 28.1286403056114, 27.099484897428944, 33.79125041346396, 23.11061682239656, 22.1242368221283, 13.59972030885758, 10.19780747352108, 7.792449266679826, 4.619847997542351, 2.751501000696613, 1.5340990356860624, 0.7204074496703764, 0.5509446333012273, 0.6607154720733244, 0.7557269834703015, 0.4626589755137121, 0.7705679451746326, 1.0555798031630055, 0.6413738357443964, 0.8696445642459778, 0.864442214369774, 0.9159575210463617, 1.7699167108343494, 1.7298205268959848, 2.2644142085506074, 1.7877604307666903, 1.525731762090037, 0.7352593817537831, 0.8407999442950372, 0.8966386222070264, 1.0464797817891645, 0.6818234620075072, 0.6964406647509145, 0.6249614132027472, 0.9329483706143595, 0.6636025203812508, 1.326914907943818, 1.5874279482710747, 3.6387063226392193, 5.2582245296047585, 7.616226000170554, 10.654639063342925, 14.7284274331985, 16.369308829307556, 30.6454683503797, 36.17611815852504, 30.535916551466915, 35.8916364946673, 31.43520424442907, 37.17001145885837, 35.76190802358812, 43.40672123816706, 47.30983649530719, 45.07832557924333, 34.33089794651155, 21.182183527177383, 7.40852669362099, 1.903332087301439, 0.4092148739484049, 0.18765412571449436, 0.1292091553970691, 0.3123947515362694, 0.09949505629558718, 0.07145158045234219, 0.20887548133971232, 0.15270079726413374, 0.1263793185353279, 0.10343333045321126, 0.07705072556892711, 0.16067365815322246, 0.23192620896283658, 0.13946621468470943, 0.1268752838575071, 0.15959574180024286, 0.14070539254575007, 0.11212220009897025, 0.17343363394179653, 0.1417731812163707, 0.16516368415567184, 0.20885971525023062, 0.10456331014152496, 0.07174097782661838, 0.2859525833158724, 0.17593247485497307, 0.25899443955671403, 0.16788617677746281, 0.12903906855612032, 0.15392672180408432, 0.1173615443610376, 0.09077767285728648, 0.15762197755036816, 0.08473147713248769, 0.18095476342545402, 0.23446151566120887, 0.21573009900748732, 0.08089546039099656, 0.1638912887222344, 0.2331248454509243, 0.20586509287597674, 0.15090769186856287, 0.08135392570928221, 0.1552297454327345, 0.1727989760618056, 0.0974629161458823, 0.10526566721138456, 0.19871522492218405, 0.11883646279813782], [0.04721920434085112, 0.03945397626188013, 0.032346978588330175, 0.11480935308481417, 0.004891685901149627, 0.02466802350095203, 0.04158373516533644, 0.030535709248074604, 0.037300062606171254, 0.016783488719093225, 0.021440935576514854, 0.02729016051988208, 0.00803061817292004, 0.0103390364411978, 0.07106586284334622, 0.05827943020830712, 0.03964157970321756, 0.06397442058509877, 0.01559315662410471, 0.04207765120231817, 0.045219829771667726, 0.05000907056514294, 0.04770745515763279, 0.031064001565438606, 0.011142884839266058, 0.05632740370328388, 0.025907781673595313, 0.061813937725439194, 0.020911338994459763, 0.07783350654907766, 0.02998936023833531, 0.07472053891228092, 0.11560419228889289, 0.008882851726675947, 0.03017739843456976, 0.0413226064354662, 0.04798564466557676, 0.031742343694091804, 0.057914163316449815, 0.03674584778866941, 0.01808544940074846, 0.04446118439157163, 0.0518839979814666, 0.11626106671868794, 0.023939132975834995, 0.04503412239794289, 0.09845979571823152, 0.06000200571912912, 0.06736938901726278, 0.020401294891452117, 0.0563247223955489, 0.014626476237730635, 0.047203166290156306, 0.008602977782908467, 0.026438088802200173, 0.041706466281245795, 0.11421098478979642, 1.608169196594146, 6.588563053838669, 17.61509183914431, 28.534911563319547, 38.736041284376576, 35.79312616778959, 45.4714451297637, 45.79536622570407, 38.717355112875666, 39.99189792140838, 20.497571076116255, 22.504914614462084, 24.56397068115973, 27.18408649967563, 15.404531282763328, 27.505458055004, 19.339048054910478, 19.20456567118245, 11.388606698282304, 6.170560477241394, 4.821169039895458, 5.389200804695006, 2.232877371772643, 1.9801836989579664, 1.4825969670088062, 0.7550774634845796, 0.9034610948254986, 0.2990437695576299, 0.15923356607316003, 0.26266035413549793, 0.14908143018762912, 0.18036332822615103, 0.11259183497919191, 0.14182285435738104, 0.34748724751895477, 0.13080853247834792, 0.15391041945305564, 0.16266450616380862, 0.11800186363078895, 0.15597160965684922, 0.21086433752169534, 0.29948819248426345, 0.21658261697138512, 0.29653480096209434, 0.41164370974706066, 0.654029424392408, 0.8608101608772433, 1.2018400839259549, 1.8830123711978237, 3.626350121152017, 3.83158887586286, 7.606608348508035, 6.205447508442787, 12.702566385269167, 17.572192876569687, 19.38850914278338, 16.520752522253222, 15.025988240395824, 15.024080007306992, 18.11320931680741, 22.091202620537054, 25.681861869750488, 32.77676859209615, 38.73606089622744, 34.91362487116168, 26.801606378247662, 14.489757091768327, 5.988126627860531, 1.613985948985623, 0.17037277560560934, 0.03405725072708822, 0.037756819548385764, 0.023525479970680132, 0.03060920389309045, 0.056787205844997406, 0.014257978370052674, 0.04131496853886112, 0.047199477576800895, 0.023192773730824554, 0.05241997607593095, 0.060510193974140196, 0.041892725238276106, 0.1050508025312616, 0.03264402152009068, 0.09071078572061755, 0.012718675988576105, 0.03404184852937057, 0.03736991450310715, 0.05799190208856618, 0.014552780494634664, 0.014585201335590214, 0.029613042528170253, 0.06886643973449547, 0.07320268124702477, 0.045074280726933674, 0.019970950745646993, 0.020458259274281805, 0.08000698992081227, 0.0894816819157812, 0.045761695251830166, 0.01891462849603305, 0.05094270574890318, 0.03506019005491849, 0.016604737423720862, 0.05942305775299188, 0.03606798254974908, 0.046904556708590645, 0.02652419900010911, 0.028311342316409274, 0.09497428718473643, 0.061132042864037145, 0.028355670078927954, 0.07418033967335379, 0.02926739514805377, 0.030268045788210247, 0.019604563450200424, 0.0690602216749422, 0.01957551722655133, 0.05397547164090699, 0.04115973231232455, 0.049319729329116886, 0.02224993783109371, 0.055914294620555256, 0.17572743908291863, 0.010638761638303199, 0.06730388083885755, 0.020458109887136568, 0.022370184906908584, 0.06002621409753638, 0.0371271642225404, 0.027036527960350918, 0.028979966619742975, 0.10498549353571669, 0.055191682185977704, 0.035721163055108446, 0.09166736140727036, 0.019725231874373653, 0.012213997373868142, 0.09415184583274588, 0.008789781619974924, 0.023351196883126132, 0.06365210058227663, 0.05698028681499343, 0.03813199961798326, 0.03971897373576799, 0.11472614827535807, 0.05923949925589466, 0.06371863531850039, 0.056051064297677054, 0.06178873726316999, 0.0638687234341858, 0.10911089232972554, 0.11914689694681477, 0.008862678716409831, 0.03933561950801842, 0.014307082690779242, 0.02213953306988603, 0.06509380144698006, 0.05728302944091059, 0.02587702132821564, 0.008032656445603577, 0.038330018024651274, 0.009543387099139152, 0.062290049879060644, 0.06447602048396103, 0.026477775987117525, 0.060468185542812275, 0.010382959134726515, 0.016964061388505564, 0.056360203757761955, 0.05832610411509391, 0.011468963460966704, 0.013603087150371604, 0.014142028089883107, 0.03308366022763714, 0.5568091895791792, 2.862798989780488, 10.118385361086938, 22.199624776840214, 35.97202939371909, 44.92141900524017, 43.183809018904164, 48.41578798909342, 49.34264406081169, 43.169629650731245, 44.06138050940729, 21.04952112320931, 22.26771123947636, 23.64734022848068, 29.021018743515018, 21.81681517631777, 26.822722458070327, 24.852292345416163, 22.865731485428352, 16.288745307153274, 9.617111356027666, 7.891935773434178, 7.302302535503142, 2.940032909954748, 2.25995006099824, 1.5201225275954895, 0.8143982255170423, 0.9935019826216083, 0.37891352248768656, 0.11826068643600711, 0.13861055576032208, 0.10709794268252389, 0.04150279031525697, 0.03138427036784349, 0.0955701350504833, 0.14355225188116874, 0.11274454694601799, 0.12654909894110697, 0.15357683412730694, 0.10286092487794739, 0.0653437989193105, 0.09146482308184908, 0.23217138774212331, 0.016838991789207343, 0.2500068339248819, 0.36566752519819046, 0.5881570784314987, 1.0151512596395709, 1.1316804035056023, 2.2821474892477838, 4.257278317405332, 5.59360973296627, 7.849114277670461, 9.888355020553837, 17.700534789792954, 18.094125024734005, 20.323529628015336, 22.827398161734305, 19.796616069732174, 18.903100144478586, 22.48659714575737, 24.10205471900202, 28.726758610817697, 37.27309134698684, 43.66395811880789, 40.68112111860707, 31.788792187167754, 18.947091487146196, 7.998682097081216, 2.356005229296223, 0.2094656907983365, 0.056630728556023496, 0.05028414975611433, 0.1062975799845111, 0.04495830267607685, 0.022844412484236305, 0.005444647207285368, 0.07464337087566815, 0.0694737559364688, 0.08591925049380911, 0.04449469307737966, 0.020494160069633397, 0.0513384897532242, 0.03143641414240964, 0.03622741310767109, 0.036728944058620164, 0.01742644907696353, 0.0189099840879921, 0.05896564580560212, 0.08039721212680302, 0.012161144010362127, 0.03882927369446524, 0.04221879907192723, 0.025199755553096056, 0.09014320649927662, 0.021967885324791558, 0.020465452839890798, 0.0044955384838695255, 0.05922970865222235, 0.029240591646803003, 0.009080149053085235, 0.023684240201668396, 0.05070357906421827, 0.030116174602881077, 0.10993954665478199, 0.06090872823410939, 0.024892163590618202, 0.03938758708236199, 0.016204896983840776, 0.040533895934781725, 0.0856891253422345, 0.021978175800834453, 0.026244327929171345, 0.039537954820139755, 0.022530442839788816, 0.06626521883111808, 0.027485373129527417, 0.06721584201459924, 0.06563125043025901, 0.019634038683087118, 0.11870319414283, 0.14910107268200767, 0.10476266154118123, 0.26977158061438994, 0.22236501798033717, 0.1139233724003838, 0.1757306719739591, 0.28477335949578597, 0.09613404471066692, 0.19931974490323376, 0.17426261768466042, 0.08045001090654443, 0.11201654125245349, 0.11345113282121959, 0.18730610729225222, 0.12495675454697303, 0.1692303086841299, 0.16155848970576642, 0.06878243053271886, 0.21814816360992773, 0.11649960351567115, 0.138189023540866, 0.1853433440649702, 0.19209336008756392, 0.15361388213932514, 0.17075298504242975, 0.3451450715862936, 0.24953789618467134, 0.15201649688664945, 0.17044515559269538, 0.14999001046582577, 0.2156373870468909, 0.3860864037227246, 0.259807933001749, 0.18232586162705577, 0.22468022761806367, 0.15180608317736657, 0.14334369210466263, 0.15656070062710395, 0.13252532019490196, 0.12442274529847408, 0.13384355832972836, 0.15756036875949753, 0.3042866914503036, 0.26088410267426126, 0.1321050443596417, 0.1161636433173572, 0.2534891478717327, 0.17973466115372796, 0.08835949334165744, 0.10312774564109503, 0.10734441615040265, 0.10609901765541685, 0.08635506259217378, 0.13854828813383657, 0.08435159711347473, 0.4951616346595749, 3.038743768007525, 9.535408385338323, 23.762720669469527, 39.19383679666827, 50.988215631054295, 51.009498411609286, 60.11440607809252, 59.92917214670489, 50.87730669206189, 52.04120728277391, 32.160122971380915, 33.96619989025977, 36.88769494333575, 39.13535425739904, 25.771091868800504, 40.95142733666205, 31.06446181574176, 31.184615781230313, 20.800452578452326, 13.12508410023105, 9.48168073931048, 7.904119145485663, 4.037836905448668, 3.2490355160928543, 2.3498912347901255, 1.0852243414809628, 1.2684666894135939, 0.5791945851618244, 0.33638871725528474, 0.47186502345627357, 0.71662591710206, 0.48616117407237336, 0.7334964602224289, 0.48579752745647586, 0.7570559928013433, 0.6950249955538781, 0.49812682393577795, 0.7581549306069651, 0.5746956878612118, 0.8535706299927928, 0.5511501287260364, 0.9031435667026428, 0.38922518852256965, 0.7641339710643216, 0.7682715200128094, 1.3653715411501548, 1.5449407119904797, 1.9017014844763664, 3.2679670808776735, 5.1306278667142315, 6.434755152271641, 11.000445023659738, 11.553775745053446, 20.360960806569746, 25.2275788399481, 28.908933093470914, 27.527107577170096, 24.56918743348891, 24.926976234682147, 28.06413692812766, 33.71917293917748, 36.56791194792717, 45.18794405844904, 52.01342905721357, 46.441596323444, 35.41988911167268, 20.61950775884813, 9.391899647251252, 2.413495408911859, 0.2666547059291794, 0.26247744298269676, 0.10061012791289438, 0.32368731654940114, 0.16911521163438598, 0.13918322180548023, 0.16182122722027764, 0.1495071146036348, 0.19657007148188932, 0.21730937394163302, 0.11374161804034827, 0.14524565859427377, 0.16625735127637464, 0.2195459523148114, 0.1083702615071689, 0.1662365290065927, 0.0800120767446295, 0.10279881046904672, 0.1808255397143864, 0.16423644197563972, 0.12836121097807923, 0.11349922016022668, 0.10832650256493401, 0.13739154133344852, 0.22631306741987506, 0.15748201328660213, 0.14452188936693056, 0.1678566057835856, 0.25987130379484547, 0.17031751002275175, 0.10827505976081857, 0.09422065585010475, 0.10270294988708151, 0.12485196904068994, 0.1405713118372425, 0.19550344726491362, 0.15473715089742215, 0.19286534688886137, 0.1018876561354245, 0.25492087427166205, 0.16880586533056152, 0.19427557686163535, 0.13927659260169153, 0.17641126448588987, 0.1556956801082819, 0.11707600040902054, 0.1000775818923308, 0.16176778492667984, 0.15671613986694044, 0.1487890910357237], [0.035839163578085365, 0.016028274455288007, 0.0404222654328952, 0.08764929919233246, 0.020037194368459528, 0.04051858566761498, 0.055498668938995376, 0.060438465161789814, 0.02828330349838061, 0.10885995256924823, 0.0500785930442714, 0.07306864650379266, 0.01347987435667986, 0.0985717211639689, 0.05144345912060911, 0.06423347321669422, 0.08044910692279378, 0.019619398742854115, 0.06000046971284094, 0.04192673188123492, 0.09262895496982722, 0.04353551652222391, 0.052880617083921555, 0.0643343018788484, 0.10182380270693572, 0.0510556232785025, 0.05128805052428957, 0.03969350514272529, 0.051905050077625824, 0.050517936807967005, 0.16614872000871167, 0.11218057599880042, 0.02642949904134918, 0.08390194946719755, 0.05684873419663599, 0.015236128050263132, 0.050745246586419886, 0.06679384248150934, 0.019431069433208437, 0.0054233667211637145, 0.029346815483163924, 0.06280422128076035, 0.021654944153382413, 0.015122313240182497, 0.05394970427357382, 0.017133634950545047, 0.05161917670780132, 0.00791877986968405, 0.04063965054228902, 0.06550727442147271, 0.009039982105605304, 0.07116230565213388, 0.059083496941433805, 0.04958730085843033, 0.01492049886784967, 0.056192311758716265, 0.01937975494882032, 0.08356930642959573, 1.3109845692111601, 6.704220021924665, 14.973008786478351, 20.83788179582165, 35.402265902488466, 49.18244269586379, 41.16887177190473, 40.85110095239455, 37.95296753606489, 29.56900719673403, 29.12962329003119, 26.13143413297592, 22.826146925649336, 28.621839131078413, 28.4920733974826, 28.47088279262666, 20.45108118364888, 16.846956437633885, 13.05836066122978, 10.209441223452169, 9.881856633770852, 9.468216223101463, 6.509396876058271, 4.955211137571643, 3.6582500223190557, 2.1498148095223213, 1.9722389381739402, 1.1336129062598752, 1.117269860640649, 0.5657313559805194, 0.8036475604580295, 0.6900790706276895, 0.4238195128498539, 0.22820806250937525, 0.5397771551243721, 0.5378918433862349, 0.8430523040794557, 0.4618480867676197, 0.4018918088366909, 0.5922204087818823, 0.6377604747972181, 0.8647058099027604, 1.4720835440581845, 1.6205846013561374, 2.713613356313398, 4.270070637426069, 5.670337667388301, 6.846308371713085, 9.347232676321461, 9.186035029349789, 13.329506266501642, 16.639843525425082, 16.249853045709674, 19.46077489083813, 24.134680994095344, 17.915545394343717, 20.535831835962114, 23.924441952859205, 26.009462148912494, 35.91985010331677, 34.04116815136325, 34.15985122803719, 30.112078958942046, 23.37457468432765, 14.285279031722778, 5.459252374787485, 1.5391237144508672, 0.03230076433429795, 0.02434415408530303, 0.0587345170788467, 0.07897361391975034, 0.029327318545490987, 0.024216692376461242, 0.06629668206216828, 0.0632170660631551, 0.037326151730432626, 0.026390235120009993, 0.011053358846824738, 0.07769780939504986, 0.020893946883358785, 0.054121166242346655, 0.06740983079878554, 0.007115037766315284, 0.04856559620689481, 0.036513884026076526, 0.046875820750550884, 0.03037118037501651, 0.029047041447953354, 0.061866269191546794, 0.011896112062517675, 0.02004537235705122, 0.03974847961217165, 0.08999977951809283, 0.024603741063225656, 0.0036286321917413586, 0.06624474896178131, 0.04066725652064047, 0.09145373778958475, 0.03173275418849963, 0.04548221105529417, 0.012195744371462253, 0.012843570345261646, 0.017176438198094408, 0.043248811947001566, 0.07683009990761358, 0.03269151514095645, 0.07935672682980377, 0.041374072222219366, 0.016024621173499093, 0.017588154916020653, 0.03445192773435866, 0.04519497404896444, 0.02829418003168558, 0.05990241045853304, 0.026609987441089847, 0.031715815984493786, 0.043054137514123035, 0.07772173432092513, 0.07382027068806273, 0.02330521437069101, 0.05129711334443381, 0.04626230689727011, 0.027281496065458464, 0.05031200471304117, 0.04007670232245038, 0.019800191662544687, 0.014154961569264773, 0.05425199107717603, 0.052123944380230484, 0.03175240817419704, 0.023499206985316934, 0.04912026301627198, 0.029477429643814123, 0.05106516107315979, 0.08371939837572076, 0.06511651595393497, 0.06573347720287501, 0.016491365987026406, 0.10421049600887684, 0.011715039520734742, 0.015299075579781447, 0.04921078013496534, 0.06290203155649286, 0.029065084733789968, 0.05034780017130318, 0.026418375444688627, 0.022467344007905454, 0.08624515961855651, 0.14985026070667853, 0.07863007711186525, 0.07993169113873475, 0.11510620449459362, 0.04111475145985042, 0.06497236885010235, 0.11001548128983668, 0.11158773119771674, 0.05450881439291182, 0.049846437759697444, 0.041875771712511785, 0.020248638466000557, 0.018387678747756347, 0.10827997804529245, 0.0187920410216095, 0.045278634680735494, 0.07575897875452235, 0.013528088100194452, 0.028091021175045642, 0.014266866905194138, 0.04037248120913583, 0.10957442148919068, 0.06466880651010622, 0.07477199703815483, 0.040630882665995634, 0.08022064418201486, 0.06813912352006282, 0.1958315167576075, 1.8236253578816692, 8.813276502393908, 19.0237561733492, 27.750690521732455, 40.28587172108312, 55.990665343499955, 46.05819640621063, 42.79052080646638, 43.19873363740983, 31.21606142290177, 27.195743783827755, 27.077209757220363, 26.382628602366296, 27.2251086081228, 30.945906216098418, 32.438007208608816, 26.564654034952966, 21.62816878288023, 14.399672016020745, 13.861570877413596, 13.350678240099262, 10.251052668017726, 9.413155951807576, 6.31338672291848, 4.2558437105148075, 2.5845570814224983, 1.6285283815476204, 1.5628728078257654, 1.04462964880851, 0.9550286793420393, 0.8898738206874941, 0.5975776309928587, 0.46262401126084796, 0.12329261239257552, 0.7185529653103121, 0.48094065259060553, 0.6323654384862992, 0.3901445859622571, 0.6547146747189184, 0.6325527929490613, 0.7277009744317301, 0.864192898715696, 1.2937566613958729, 1.5937237201198455, 2.425245604207439, 3.750114138087919, 6.003142931768972, 7.501517755369987, 10.212591867293082, 9.179774926554773, 17.160016490567116, 17.04492630497102, 20.320589811571185, 26.962549071158133, 20.445432970600745, 19.492089133108816, 21.67408404811736, 25.732040751364927, 27.60422137475783, 38.51687885099842, 40.88922246809929, 41.444971330704234, 36.68532809903545, 28.30361527781333, 16.914623206661595, 7.521010954533854, 2.426237228416628, 0.2748121633645027, 0.017810446818569498, 0.04920918284164322, 0.08687379604746258, 0.040366164814200134, 0.03085200205415247, 0.03968714661295376, 0.02425894404070512, 0.028791692851471807, 0.0549123052417511, 0.03821106372220862, 0.03173120094523315, 0.0488728012949709, 0.016335461348775896, 0.08647949059283541, 0.05651323748151622, 0.06532889850918325, 0.05342383853970997, 0.03221801917759642, 0.07036637860320269, 0.045286705417017785, 0.05247249140314037, 0.02429264424849422, 0.025942326493320927, 0.08435610937134874, 0.06212227662364322, 0.08986036683763228, 0.04078053028112458, 0.05228085833932123, 0.03691019280062568, 0.018858573842613448, 0.035322333851288405, 0.06639768309410542, 0.03102626215906874, 0.06307008443400264, 0.02890346699484414, 0.052509857341647155, 0.030014773290003502, 0.043946645267668276, 0.05916442263931517, 0.030707960287409446, 0.0601864337260204, 0.032016346531529585, 0.05829937530741577, 0.05720591503045252, 0.04503282770935086, 0.03677243870052119, 0.07465455575936264, 0.04227914764816242, 0.02215518999183851, 0.08063803952667983, 0.13847653633884846, 0.11688381959233554, 0.26732987453860624, 0.185221643337319, 0.1710116622909423, 0.19641849332519118, 0.17736553424789062, 0.11562460853207497, 0.10928549142854829, 0.27319890477003594, 0.11019589499600473, 0.12645209688813458, 0.05563342763531593, 0.139781812265996, 0.17249773496822005, 0.19617310004128566, 0.21741956802866153, 0.136370514669726, 0.12717347592115402, 0.10915655117001265, 0.42993703136040323, 0.19344058698944508, 0.19476674647340853, 0.15896514418625063, 0.1310344671289767, 0.13125533027754677, 0.1235847830051376, 0.1606500013581207, 0.13170635688208765, 0.2562868090406541, 0.27277703547189314, 0.19994452024900145, 0.17656250556390132, 0.19165177168625017, 0.20776886733308916, 0.13586622963268913, 0.278868384418949, 0.23476670976848374, 0.1458843614185049, 0.10102025308315793, 0.11785960110325007, 0.18145285847206272, 0.11586696810780034, 0.2750927354058912, 0.10501874941250972, 0.102470587758768, 0.17614745444828467, 0.17431538582088488, 0.14472980562958027, 0.16306759098604803, 0.16833893474071257, 0.24249387093849722, 0.17780041171898767, 0.1563522634246657, 0.08655438334831307, 0.20112435693942732, 0.21211252457672553, 0.21769277030421844, 1.8476351662989587, 9.163730471364914, 20.09213528325481, 30.880424207256688, 46.34785952106599, 61.93833958718085, 54.83030665305353, 54.18061310245145, 51.485725141340694, 40.39608640055503, 42.79661616971416, 38.74480385934153, 35.28177461316509, 41.10102653503418, 41.55596263947026, 40.40845363370834, 32.895330075294744, 30.658274888992313, 25.068573797902754, 20.25101677063973, 16.69191691183275, 14.73104855706615, 10.370825183007026, 7.299111197071691, 5.117506557895291, 3.1160669221032053, 2.735176096039434, 1.7765499290920075, 1.6694075686316339, 1.4950770908786406, 1.2181133849005545, 1.30246922614113, 0.8991655479035071, 0.8591448083039254, 1.0846564558244522, 1.0813294278998529, 1.202583127925473, 0.7622216930312495, 1.374368110010701, 1.0614297731268791, 1.1114228324544047, 1.542770292970442, 1.9390941747734625, 2.2536686303154116, 3.1892232933352074, 5.311824698602, 7.729543764745036, 9.283401004729733, 13.410596366851562, 14.537842408303293, 20.978061422224968, 23.61160351384071, 25.038579433195054, 31.160202949277817, 34.70408008944604, 28.49010240647101, 30.38218709730333, 36.35421337619905, 36.63349005483812, 47.7524406679215, 49.40184439382246, 47.363431761341715, 41.32925748825073, 30.439388982711304, 18.33137939053197, 7.963013533622989, 2.251382378801223, 0.4353019144506224, 0.15150758467854994, 0.17694174972993715, 0.17958199515217738, 0.18865647515462292, 0.09726900397048843, 0.19593673127312816, 0.18119689317480211, 0.23210913543739628, 0.1694567489527887, 0.08214026133740142, 0.19890014322534685, 0.11318117875846163, 0.11953658289125851, 0.25403524598767685, 0.14532672601842112, 0.17227753065526488, 0.16963670300620218, 0.20685783557353482, 0.17833026877093702, 0.19795839134002888, 0.15368807009391247, 0.11285280283059805, 0.1658347005685491, 0.1570852257071003, 0.22100348055603045, 0.1276896429818965, 0.0808279757057467, 0.1341111834851965, 0.11995867435489932, 0.173376162025717, 0.17730461493615182, 0.18760501947854796, 0.12259276809110758, 0.11183999629030306, 0.13647012142164094, 0.129394487387711, 0.12144344468270579, 0.1059371815814126, 0.09515540569179481, 0.2833880580240681, 0.16068467449757362, 0.19520571485402125, 0.197827834635973, 0.20562176802946677, 0.13512067286477936, 0.3049085403402006, 0.25840850486870737, 0.19248568903534644, 0.08443809610100524, 0.17788275084908933], [0.018966425615813465, 0.026648644237749042, 0.019870030152941906, 0.0809597734722399, 0.006139081012788079, 0.018210237462734504, 0.044597368011431354, 0.05512599397691027, 0.04839498842615755, 0.010219428091189794, 0.07358233143966045, 0.027436178793469747, 0.05032661784019682, 0.02825470926660684, 0.043802298980975346, 0.018402014168039448, 0.03185856880830421, 0.006662560861572744, 0.07086096496711816, 0.03553604939952493, 0.03930688354997866, 0.05620876732732981, 0.056211291587040316, 0.019077075525156913, 0.025383961394489295, 0.0461665727198124, 0.023748915259455963, 0.02648574138631023, 0.0758314353504008, 0.07256246156870358, 0.05782403307215822, 0.03147126348208516, 0.03380301295809689, 0.04531187906620964, 0.04421550765513413, 0.032682276120589625, 0.050199569818834146, 0.045876903384323084, 0.10144855751986466, 0.06220155523248738, 0.04839673893706453, 0.050879740982406566, 0.03258553836795111, 0.06895325281807492, 0.015637831041409124, 0.033138492970817515, 0.02414817538773341, 0.10815920428402963, 0.03650054643531481, 0.07747029660329705, 0.027880774089886297, 0.015964787791392977, 0.0692203110684791, 0.07069650887241287, 0.12027463965838957, 0.02260726230639604, 0.008515405314674061, 0.1263767521407816, 0.029425919807005315, 0.6775174962897456, 3.614428077013262, 10.483717860714084, 23.54086356778299, 34.44812974622173, 41.261035703843646, 48.37677217298939, 39.847127160718365, 40.13674712950184, 36.00879376934421, 22.319743440997218, 29.109564288969967, 27.917891356252856, 23.02505620064274, 25.356601284396266, 26.825193551278886, 22.13788667032796, 21.75644401581057, 17.34159085058397, 18.063053969414003, 11.702229611335262, 10.014070906946737, 11.059936592655799, 6.866279119445432, 6.626652700285758, 4.512472623778928, 3.731588293467799, 2.841354411455893, 2.515791068153997, 2.3122151532480797, 2.6752170295484605, 2.8944221187022428, 2.874596988962543, 2.1607947493753126, 1.873975720617079, 1.9220517215228852, 2.2704806443183654, 2.5463997740899367, 2.78435085088976, 2.7971203721338704, 3.5429958326201287, 4.540014036240117, 5.365196879832975, 6.488896608352662, 9.471325682055566, 12.570488414456769, 14.544027986065036, 18.31617432255899, 23.674279066824145, 15.865120503210253, 26.0904904719322, 22.359443710696315, 12.20832028696614, 16.854597214729555, 23.40780108205734, 22.909450223368985, 33.248951358179895, 36.19788731298139, 33.44182214429302, 29.341586212958063, 26.337009476077174, 16.010680640897444, 11.136820931588451, 4.593727953972356, 1.2682937374038081, 0.2222570149047721, 0.027811052427897533, 0.0805615226648027, 0.03300288774734063, 0.038322069862436865, 0.03929036669433117, 0.011338068720614238, 0.0055308072009093824, 0.035988493266725735, 0.035451182179273136, 0.029451070473559444, 0.016751638613641262, 0.03219942622367413, 0.008516827365383506, 0.10055880002196758, 0.04950545585503982, 0.04495963183862548, 0.04934079291659498, 0.028754709956927166, 0.01992816281985612, 0.04847713220383852, 0.024020391921963424, 0.043581508610758095, 0.007182677105564865, 0.020929780646017002, 0.04353303439734925, 0.09486258390449709, 0.02176525315359956, 0.004178402981074948, 0.02207160596885989, 0.012140974830535632, 0.08358318028190444, 0.052452680369418477, 0.040853664864816015, 0.1263950080160172, 0.035173628524306326, 0.07162755084854942, 0.07763935688642726, 0.0625751111956854, 0.04502576437868899, 0.10468552414808543, 0.035319112451566805, 0.032465419611863555, 0.059768751098383824, 0.05642004671596712, 0.03355504178832616, 0.022304510104379827, 0.05674007611589567, 0.03195560533523319, 0.021067866079148748, 0.03264384148942848, 0.025866307588594577, 0.01817602780647576, 0.015431259263066516, 0.01297145052963207, 0.011851498932247202, 0.04642043510572084, 0.03674349206830225, 0.018266018239721175, 0.01732428933704092, 0.04530453611345542, 0.0704485108895648, 0.030047360755082582, 0.026946736709965814, 0.0715226504290777, 0.011897656687295005, 0.10010751294753245, 0.10074502833548094, 0.053862469841636, 0.019597253056182977, 0.04407587280917553, 0.06593990725495162, 0.03712225359894576, 0.04154890880829865, 0.03533284840804916, 0.06792783647054626, 0.011891233997659819, 0.022652593644095526, 0.06893834474706842, 0.030126135661116535, 0.05137465676412948, 0.1051914026480048, 0.0074544673853163285, 0.02241724377287732, 0.020984519543426654, 0.02457534792953201, 0.04782188571088257, 0.07457967832564347, 0.08891784886439001, 0.025705588087739966, 0.06734934049628435, 0.03220490375233274, 0.05334778899146665, 0.07091773208230734, 0.04037541915632544, 0.038131310138851404, 0.017293804783313986, 0.031835513392222986, 0.051628718332898234, 0.030291796429082755, 0.05446627353047652, 0.05588137199200931, 0.07429047247334834, 0.050868667181461096, 0.06677406209130442, 0.017435186309739947, 0.01302190508032518, 0.0726922904892314, 0.046471586796425046, 0.06811550502935726, 0.09488880709414521, 1.389176160577805, 6.219857315863333, 13.608743721438994, 28.723281429659938, 41.17971712543119, 46.06152649848692, 55.54073026103359, 45.38182289369645, 42.46974545140421, 42.31353705929172, 25.52280387570781, 29.7914977612034, 29.6016275882721, 26.737324614678663, 29.23091849973125, 29.16457945300687, 30.31184134944793, 26.177343514657792, 22.658665641661614, 22.913415739613196, 20.698188543319702, 15.172740778615399, 14.629570957153076, 10.59945523738861, 9.376518072620515, 6.789567855096633, 3.6612675507222456, 3.766061269467877, 2.814388606817492, 2.015460270547098, 2.8008275022429805, 2.6629265277616443, 2.7486624304325353, 2.4729408900583945, 2.409387951897037, 1.795698204828847, 2.156032011393578, 2.4191499958115243, 3.25810109415362, 3.216807116423884, 3.7575516873790376, 5.05197306794505, 5.819165139429032, 9.622653665081147, 11.86479812668216, 13.038997880874142, 15.93886890719014, 22.63859683467496, 25.667564830472394, 21.232387904197942, 29.21647241038661, 22.15607862318716, 16.5544339149229, 21.629755381614935, 24.665267852044877, 24.716968613286173, 35.82581912317584, 39.118829311863074, 38.12955264122256, 35.66536280416673, 31.956218557973063, 21.67253275071421, 14.816106134845366, 6.84578130322118, 1.8216118336685243, 0.28568681209318103, 0.02800371396475502, 0.0721804671470196, 0.05944662644798237, 0.06969976719589004, 0.01341442746530858, 0.02703363214799714, 0.06007949168223047, 0.04310468016492744, 0.03319455911555598, 0.026453330121453733, 0.04829294934508301, 0.034689326890774315, 0.07240299270638535, 0.06654736135275134, 0.17565800087346187, 0.03720871045164043, 0.04145197187279982, 0.05310568222475629, 0.07782980634440338, 0.03644812303865629, 0.027810025870078997, 0.06051757906173026, 0.05233015226680906, 0.022193586318603447, 0.008653750260090156, 0.0309643660852265, 0.07370625382229205, 0.027940289545503837, 0.024348453753778053, 0.048152644172190666, 0.03890298284409989, 0.04272859228113967, 0.003040828728004389, 0.055421294058643045, 0.03637736715796975, 0.01784159595357074, 0.07356170835273881, 0.056037607963287064, 0.017258838615230015, 0.03418728649135559, 0.05406692338686797, 0.05918845481749985, 0.011155488900840284, 0.026056002449965286, 0.02403207284758889, 0.022338884469542294, 0.009358917915021941, 0.03280148323204729, 0.04019186832010746, 0.08647332358504496, 0.022151323163040706, 0.14897390208657713, 0.06358575353759431, 0.13577270561889296, 0.17537794977186189, 0.09858819971522016, 0.15774963844207027, 0.16305030804247628, 0.10971592558968453, 0.11697156730318263, 0.1214545759402456, 0.12829745714102062, 0.14184465721970604, 0.2557620541342805, 0.14902156807722586, 0.1462067618605591, 0.36127557377180747, 0.13602016734019404, 0.17669853213573658, 0.12300960419158782, 0.16242766242113807, 0.10942153332214202, 0.2266720562211929, 0.1809919493332986, 0.17803219928135797, 0.1129074325604785, 0.10496562121496086, 0.1803586704115714, 0.06829851577358861, 0.1845848250893816, 0.21563772412557758, 0.2011041628617433, 0.08655734810858004, 0.19135664397430038, 0.22014198404166008, 0.1590569674848549, 0.19147760925754426, 0.27510107044250737, 0.1806258818795604, 0.24783309008325302, 0.14968967335599084, 0.12546883835907907, 0.23285599455477732, 0.07873317722471491, 0.19266115381352364, 0.07583705077488577, 0.17382553388034144, 0.17337944088203294, 0.2137539292415304, 0.12385616199143472, 0.2480683097195241, 0.15459329490700077, 0.10723504177745312, 0.15123275829659355, 0.19341973407614618, 0.1931978290479991, 0.19875123105462522, 0.2496854753624047, 0.25221132853579137, 0.27150453278614634, 1.4151663982099103, 6.5435013944102876, 15.418699864418278, 31.137364948949507, 45.27805266841766, 54.583828833795366, 60.357938197351274, 54.4814157485962, 52.42130064195203, 50.53888067122429, 32.98847459977673, 41.238038847523356, 41.2376073868044, 33.11968964915122, 38.327757850770034, 39.90680994526033, 35.0242631666122, 36.7490509248549, 29.44650177032717, 31.46938966166589, 22.0702689309274, 18.398277375005907, 18.277023184684015, 11.395740509033205, 11.167629188106908, 7.270562225772489, 6.005666976974857, 4.2077569230910274, 3.8665975005395956, 3.819902909378852, 4.302218383358372, 4.293750966748884, 3.5742058869331115, 3.1849662959575658, 3.2296876897734985, 3.0128043986135915, 3.3824490539489256, 3.3920466034643115, 4.638416988234367, 4.3021840626193635, 4.49602710623895, 6.661818710065658, 7.299640226748682, 10.459363864314172, 13.510094150420159, 18.31581738687331, 20.849760693888513, 26.00542995237535, 33.454059939230646, 24.767380875925866, 38.79974842071533, 33.08001879722842, 22.6568966527139, 27.56409356670995, 33.66943728539252, 32.92819169259841, 44.28402992986864, 47.38393791260258, 45.94789151222476, 41.650032843312914, 36.940713620954945, 23.251188685817105, 15.291073783751457, 7.043917380994366, 1.9989982055079554, 0.5805953616096128, 0.06322399149799059, 0.1774951256811619, 0.2036185706815412, 0.16194965419990404, 0.11788803062612012, 0.10617000336248068, 0.17039517601651533, 0.20360758498070702, 0.10123233686411574, 0.1522182997676634, 0.14643041356917352, 0.1984721911890853, 0.07751800089834199, 0.21078500145625687, 0.2590784027932152, 0.14350092399024195, 0.2013230648252272, 0.32238953296215306, 0.1369731347527235, 0.12108886088695257, 0.185837026445135, 0.14808485705044963, 0.18954342110983788, 0.14982029134708066, 0.0823150979234807, 0.25785615547530116, 0.19764103175651646, 0.17743302659401972, 0.11896560990041304, 0.14777906539459384, 0.14525335011703355, 0.17977333327214565, 0.10964569064878649, 0.2680504874837014, 0.10724977364823704, 0.18999902892016596, 0.314139103096339, 0.16793480803889616, 0.09024904154601598, 0.20811106348710678, 0.10639610655245282, 0.16396809669752277, 0.19077009641595427, 0.14759030133005113, 0.1763594003334161, 0.08502290463976322, 0.13285440092365589, 0.16074067552483853, 0.13772613789525726, 0.17871682141577044, 0.1842707443621851], [0.08862003984470522, 0.042701151011691946, 0.04610153568548061, 0.06243395949563673, 0.009143154996807778, 0.020577303592055556, 0.02521160310284505, 0.028392890460729122, 0.03655052218105524, 0.04186919867812146, 0.030549774622364394, 0.05562174479447066, 0.035460409708321095, 0.014793666308715701, 0.042680524094330693, 0.06353038070242732, 0.04582601599395276, 0.07117038787973505, 0.024098243692048618, 0.00928748787696203, 0.047744932178888595, 0.043071014431094935, 0.06905298214405775, 0.08636738894687546, 0.03537844979174195, 0.02835841267369688, 0.032496419359719565, 0.05166452145203949, 0.05758069673432939, 0.0684520551153729, 0.035611532042704286, 0.028957700274223765, 0.06228099855023527, 0.08845098722245424, 0.06800412350604612, 0.011995157655028087, 0.06270402847158332, 0.029955476169444384, 0.01780184748161945, 0.05190421887222798, 0.031923102139825785, 0.03508172861690964, 0.02304846383330803, 0.10544303188761396, 0.013639303956991963, 0.006073650879590142, 0.013875703368666432, 0.028458230099791003, 0.1333027462204618, 0.021940959249472907, 0.0486681638886371, 0.061898732167338176, 0.048432289247190764, 0.02120160013287058, 0.014114167387296837, 0.00863445250527753, 0.08563657171062886, 0.059274555439309734, 0.0257402612271929, 0.08025367789330982, 0.21883879187366656, 2.5551527882775953, 7.211347674169849, 15.887091659730482, 28.835198417786632, 39.88829635804699, 46.184563406052135, 50.88849329179334, 39.38007485482001, 39.185843006257095, 39.028724624264626, 33.554217661580736, 24.690016046647106, 21.528424870583322, 21.822685003280643, 16.01109641213571, 21.299183907047397, 24.808779531909575, 26.325193335933072, 16.169269911704525, 21.204617523377944, 18.493881225585938, 16.088049392546377, 8.19539386418558, 9.708967381908048, 12.832015387473568, 9.665481044400124, 7.083364657817349, 9.651829235015377, 7.3958319425582895, 9.638075444006152, 10.785901181159481, 11.906946935961324, 7.004359297214016, 8.2762324425482, 7.243082590641515, 7.270612726288458, 7.108195222193196, 7.393378500015506, 7.333027931951708, 9.548768958737774, 13.25899774028409, 11.865826768259849, 19.051297095514116, 25.738724470138553, 24.797216384641587, 12.865312387866359, 17.16159720574656, 19.023134477676887, 21.438877159549346, 27.046146546640706, 23.340193148582216, 19.324827501850745, 26.739652541375932, 34.69789058931413, 35.806752481768214, 38.364883084451, 21.43489399263936, 25.446305890237134, 13.528064489364626, 5.134354118377932, 3.015809424461857, 0.26971703515418116, 0.05904212436308304, 0.008036314036637064, 0.023030723152201504, 0.024086712153568387, 0.08056835616908728, 0.07180044157130104, 0.07202081442359956, 0.09188173579112177, 0.09264141155947601, 0.03804372713690804, 0.022020458108595303, 0.03302770133520807, 0.07341419046203937, 0.02298146369867027, 0.01653500043997361, 0.02152044592695611, 0.10434260021053976, 0.029198173358435595, 0.04182789887812349, 0.021290188625214562, 0.028165109538202806, 0.048465012692876404, 0.03618553108085067, 0.06522339288025134, 0.01590230374506885, 0.07483725240754505, 0.028120392986062556, 0.04822862860296042, 0.029065126868625803, 0.03725305928157703, 0.09324421550357535, 0.009290147159669188, 0.033156170449670286, 0.04205843771717722, 0.049527308513079925, 0.09305136819039622, 0.027172368755864523, 0.09739253564827866, 0.051729638925603325, 0.05442095176887609, 0.056762074330641385, 0.033936476965825406, 0.01124777376741892, 0.1021376459468757, 0.07220412394212139, 0.07126162129063761, 0.06204630751463194, 0.03794760991548819, 0.04497489231007715, 0.03471915069366655, 0.05010321511015777, 0.024224320696967266, 0.06248764310693068, 0.05569990874538499, 0.019626718712970614, 0.07945077178338844, 0.03615383802342319, 0.058908495646450794, 0.02530264116132692, 0.07057863858438308, 0.031049350133886745, 0.13482241951409848, 0.010415286129911341, 0.04337096466652809, 0.05213928146047458, 0.04710428349132981, 0.014028250626588782, 0.04612480943662025, 0.049632637941789244, 0.04272598375175749, 0.05589453338254845, 0.030862472560857574, 0.029723014449700717, 0.07289606987709, 0.017927317361858104, 0.018071826442234942, 0.10699483490879498, 0.051912860344013864, 0.13979629132776492, 0.036810206835188215, 0.024922791785830935, 0.12590356261259125, 0.0700389679461237, 0.037905927071528095, 0.03711128705030969, 0.05690436367125762, 0.04514781750678536, 0.12236304896613284, 0.021514307647462816, 0.025735484668985013, 0.028051939199588476, 0.05192382306221032, 0.020016153763619163, 0.01343416476306776, 0.055453684256081624, 0.03906808245266157, 0.10142840940745608, 0.017768143443390727, 0.05713455394030579, 0.051685029625772476, 0.05172125409327207, 0.052634859908252, 0.06725743292800843, 0.07581574586971153, 0.014341665814901072, 0.011668041941799946, 0.0538639560522091, 0.08381954905006193, 0.023892972347957474, 0.033035224318624504, 0.03575392097475068, 0.0413178107250602, 0.04676074285300509, 0.38723044878532814, 4.085004877659583, 10.144363218738187, 21.63559579080151, 35.135666324246316, 47.16472448841218, 51.986341168803555, 55.85503370531144, 43.97450785483084, 39.85466203381939, 43.03111899283625, 35.50594591325329, 28.90620508501607, 25.227335652997418, 28.0219381086288, 18.39699083758939, 27.283955927818056, 29.660443529005978, 31.440117013069894, 20.39069433366099, 27.650777947518137, 25.210528296809045, 21.495494611801643, 15.298688084848466, 14.908315174041258, 15.841590204546529, 15.174295998388722, 10.110328812753002, 11.26121105686311, 9.753639255800556, 10.919293145979605, 12.468829404923225, 11.49298587153035, 9.365506998954281, 9.07447889927895, 8.740185095417885, 9.603355603833354, 8.84179017236156, 10.126757660219747, 9.941217783958683, 11.530624935703894, 15.25961833615457, 12.808989113376988, 21.818060528847482, 28.49236757524552, 29.299644308705485, 19.794994169665923, 24.87807212337371, 20.495400044225878, 29.07130745149428, 30.79374767118885, 21.537605177971628, 22.29131410198827, 29.72941056374581, 36.48265923223188, 39.289781893453295, 44.375083831048784, 28.851085978169596, 28.388058024068034, 17.636507980285153, 7.994671963876295, 4.42786023501427, 0.7312419553918224, 0.12438592711283315, 0.023655264841152296, 0.06986820694780158, 0.021356462891544067, 0.03291682159948734, 0.06580392664839184, 0.08627280007086455, 0.024670413695275787, 0.022499186452478174, 0.022197533586633303, 0.04452958072145139, 0.008971224756791227, 0.03578327363356948, 0.027445461863892216, 0.013557984681439497, 0.049166929262179526, 0.06628221066127862, 0.033298440638088414, 0.03133723639973229, 0.03648641977399107, 0.04894276810509544, 0.03989664867760674, 0.046575376388406566, 0.0573359890991161, 0.031146248764989358, 0.04409296806120584, 0.1248095277696848, 0.010922350150893533, 0.057462669398275115, 0.02227406385504911, 0.03544049908316905, 0.03851458775780855, 0.03743001793120657, 0.13761050458396637, 0.013805202212214712, 0.033759985629829674, 0.03337703359824035, 0.02607210370291385, 0.07256460661489157, 0.04886402575779827, 0.05367910286651985, 0.018164837177121834, 0.04940856488481645, 0.05033602923034661, 0.05681898700253618, 0.07178145025165812, 0.039331214502453804, 0.0402665963666814, 0.040719515208395264, 0.042706245496388406, 0.05852243329788889, 0.02535371241279908, 0.07061643736256708, 0.13692108673914788, 0.11116236087776, 0.17942005948674294, 0.1330803355742847, 0.14181706273267347, 0.12768316953893633, 0.260969536799577, 0.1838225982482395, 0.1898405712939078, 0.19490356977668502, 0.1071931214462365, 0.22261151443085364, 0.1314261832064198, 0.07162097015327985, 0.13290090246065972, 0.14917426472229345, 0.17995270509873668, 0.14235690957115543, 0.10685224296344865, 0.10576323365732547, 0.20102652751149672, 0.12257962202232693, 0.18768181213207785, 0.2879016335693098, 0.17473739301485403, 0.243878758722736, 0.12035241290446251, 0.2396443149735851, 0.24866568976111952, 0.1610766050796355, 0.05852319172493393, 0.1407554027654471, 0.20762271307889493, 0.2049587342527605, 0.19237045408977618, 0.10268435693315922, 0.1878776548490409, 0.10630213820766057, 0.1396059491220982, 0.26822386850272456, 0.15868627286005407, 0.22931122912033913, 0.1938961488344977, 0.16901706044952716, 0.17029651921362648, 0.19093835996764322, 0.10117492623507016, 0.09465227744752362, 0.23298002418971833, 0.1741241396314675, 0.1680247007959312, 0.09266446314511761, 0.18224591269127785, 0.22910315964010455, 0.2738250743958258, 0.10097899158755619, 0.20645098159870795, 0.10323613176062223, 0.22409498240918885, 0.18594908978669875, 0.5190241396907838, 4.079614315302142, 10.039647702247867, 23.852574325376942, 38.79063675480504, 52.23651386076405, 58.08208096411921, 64.08233850233017, 51.56760069631761, 53.82716048148371, 53.48201151817076, 45.892558636203894, 38.7364766674657, 32.844243164985414, 35.41958316679924, 25.68736887747242, 36.6996447501644, 37.648795573942124, 42.33335287340226, 28.559102781357307, 34.3077677296054, 29.8374032205151, 28.349634485860026, 17.09348132533412, 17.633164159713253, 19.089924596971084, 15.454370879357862, 11.542420483404591, 14.144833664740286, 10.357781340998988, 13.642822254088617, 16.01712215331293, 14.598209646440322, 10.750052678969599, 11.661188871629777, 10.616047843810051, 11.2503098095617, 10.514910509509425, 11.35867509149736, 11.360973600418339, 14.700014764262786, 19.09143078711725, 17.448043977060628, 26.315085387999012, 34.89328345944805, 33.85992719281104, 23.28674104905898, 31.660795442519653, 29.63328111556269, 32.101634548556426, 39.1322281283717, 34.01763393032935, 30.925857020962624, 37.88519682422761, 44.91503730896981, 47.78139952690371, 51.69195552026072, 32.978994231070246, 33.45540923456992, 19.609450371034686, 9.396358401544633, 4.206807219213055, 1.0711590897652412, 0.3146212175488472, 0.138042118520506, 0.3341941511438739, 0.07838831508472081, 0.20388754415175608, 0.2003116908693506, 0.1776259888203875, 0.13754981509860487, 0.18699147498175023, 0.13060884400000497, 0.07981039643768342, 0.10078019943208465, 0.16038628325106638, 0.08525080813635742, 0.08776907703929371, 0.16109964900439785, 0.16061935784114947, 0.09197784152122275, 0.1272849340532576, 0.14382056651576874, 0.16260865835412858, 0.15373843271405468, 0.13301230696660857, 0.13710127061893865, 0.14642950958542286, 0.16739304598060348, 0.14499969840530427, 0.19642414705407238, 0.1385373790417948, 0.09624533430342713, 0.17107556934558577, 0.10728933442864688, 0.14364010684432524, 0.2019228350611464, 0.1632861099055698, 0.2642742562438211, 0.23118926302319576, 0.24614921350392605, 0.18207119867926647, 0.19804977030763704, 0.19878150684939278, 0.12713068224970372, 0.22009290844923068, 0.12085246913615735, 0.2323971232098918, 0.16892159057240333, 0.1870831757062866, 0.12206719347065496, 0.05963626385275876, 0.15058066425544603, 0.12734838911602575, 0.20625126247684802, 0.2145186841728226], [0.04395335619788497, 0.05894959243314882, 0.04054760890862635, 0.022800636305023107, 0.014371119022759941, 0.08018474530188308, 0.03756856110187308, 0.038676320409943024, 0.056129465735847914, 0.011282253469670973, 0.029571560782290278, 0.15483266673982143, 0.07918703835457563, 0.018367567024524176, 0.06685629396909668, 0.017755600668850447, 0.07860458936662444, 0.0648020828262933, 0.05055596924296791, 0.03474312541525691, 0.0390770533422549, 0.05584407500141571, 0.025003548944368962, 0.06930541577598742, 0.02428464437534492, 0.01952828982123925, 0.07209451208191534, 0.08720392631667276, 0.04423109371395362, 0.08056520754771848, 0.06736146766812572, 0.10130135372521416, 0.10422603227198125, 0.040545754975849585, 0.039637607537330165, 0.01826510084943185, 0.053492725165861274, 0.05730645257919546, 0.01106124859483492, 0.05830050528710408, 0.04934262769717363, 0.045695045602417765, 0.040508664828995546, 0.06218347172703474, 0.0611931728499551, 0.04012862393151849, 0.02546755307834716, 0.07320896316800388, 0.024579816137350375, 0.07853315932856453, 0.03921854595142988, 0.050991095692640355, 0.042571888996228095, 0.03641933728490145, 0.018235472398960305, 0.036438550770042405, 0.012751574676874424, 0.014624012307444168, 0.01446782134383196, 0.09306724153218732, 0.025703730324523586, 0.11319964913831604, 1.756396423424444, 7.505083189856622, 12.923098706430006, 22.684115940524688, 31.297840879809474, 43.00771028764787, 49.307891861084975, 47.17508739040744, 47.6888394355774, 39.1307258605957, 33.02068510363179, 21.694311711095995, 24.433524416339015, 30.610035619428082, 30.55872121164876, 24.209857140817952, 25.796410768262803, 31.81069274102488, 19.683167396053193, 16.751168235655754, 21.665790196388, 22.481837349553263, 13.308287224461957, 11.002802368133299, 16.152743004983474, 20.50304670487681, 16.1811537127341, 19.193051553541615, 18.39863823306176, 24.626646234143166, 33.445234606342936, 28.240763218172138, 10.117352797139077, 10.434752952667976, 13.183012604713442, 13.736631620314814, 15.449803279292201, 17.956177226958737, 14.440043991611851, 21.784100647895567, 22.01757973240268, 28.723605025199156, 34.68549197719943, 24.70920232034499, 18.242833845077023, 19.25051231538096, 25.81120987092295, 12.757176564585778, 16.209429098713784, 28.164798675044892, 37.885887161377944, 36.06008660408759, 36.45513203836257, 34.1599492872915, 24.477194124652495, 17.065036296844482, 11.037635957041095, 3.4142383933067326, 1.6597775369882586, 0.21194663589760182, 0.027455294602400357, 0.014173079548674005, 0.017981700028382966, 0.03975213385157047, 0.062002682637783794, 0.015533932281898396, 0.05690506464170833, 0.04511845718708731, 0.02535551654986076, 0.046245755567666025, 0.01838809818089489, 0.05306002338446918, 0.018691920990785284, 0.04569171695038677, 0.005833705917241113, 0.061137604662367416, 0.09957806192218296, 0.049773893063707705, 0.09910525543795479, 0.021928550540319374, 0.07928955624060285, 0.03422381356358528, 0.014393059780911334, 0.030232194788573735, 0.036971544952041684, 0.07071020652449901, 0.06732888594870606, 0.006667949811315105, 0.04327978105134061, 0.07797016897389004, 0.05403250305643005, 0.10735498050287848, 0.04389511819388117, 0.042750383652145826, 0.05694045407337047, 0.051365793126845555, 0.04442351201789514, 0.018639032195712772, 0.07366945095840963, 0.06628370453273097, 0.11620193239181273, 0.06919041065679443, 0.04699453756573701, 0.08458267987495469, 0.0886886889836, 0.023793951653304602, 0.03846285384028189, 0.06645347727763076, 0.0438059417290553, 0.06580145984527565, 0.026008279002722234, 0.0596228305010065, 0.014803213679472045, 0.0814656213286423, 0.06250967196519337, 0.04680458989535128, 0.03427619482540796, 0.04998789589491583, 0.04393211257974467, 0.07184790837908946, 0.006081448218244459, 0.031864791357469176, 0.024345077221251787, 0.01913360323786976, 0.10996789190798037, 0.039007592150160385, 0.04441419255829627, 0.02788190598479442, 0.018842960970716614, 0.008886643861901135, 0.032907885183850606, 0.03873002317343508, 0.03641312431183554, 0.011009680343821887, 0.019104421033614108, 0.041367912875308145, 0.023327166620161266, 0.02661539793705508, 0.018377014803850365, 0.04422170913688118, 0.05954954269973021, 0.09535059723402224, 0.02066227806461675, 0.049636951016802947, 0.02245143236171815, 0.04270537598659435, 0.10437253892662064, 0.037878321093176646, 0.0420047426145644, 0.03739419565986722, 0.03582574171765197, 0.03066484485903094, 0.037696470972150564, 0.030059938003579457, 0.01871837975247012, 0.03199017122237673, 0.048159623233180855, 0.05854914678380855, 0.07064086024559314, 0.012962354193141144, 0.027735698104445494, 0.04342047309863471, 0.030466087177515994, 0.0577182210080566, 0.028974613580372066, 0.054255258442173084, 0.03163849664551597, 0.037869342542704076, 0.024107164785926862, 0.009256237235310818, 0.022978908795442794, 0.011261653365387071, 0.03653096395634836, 0.06822971341710898, 0.030360194674182325, 0.13850488159204685, 2.244483665112526, 9.393227369554582, 17.30205532043211, 28.777602334176343, 39.01762823904715, 50.22169820723995, 53.10847636192076, 52.48176397815828, 51.99544106760333, 44.87943003254552, 37.64512423546084, 26.070370674133304, 26.205423762721402, 26.057158170207856, 31.97741112401409, 26.209428502667336, 30.700397222272812, 34.18615072004257, 24.675926892988144, 27.58839068874236, 28.000192488393477, 30.077499343502907, 20.934721193005963, 19.215003098210982, 21.41389166155169, 25.961258180679817, 22.80802949782341, 21.719293286723477, 21.511939148749075, 30.377203725999404, 36.23968408953759, 26.332288903574792, 15.538367456005467, 18.680125167292935, 18.686300939129247, 18.285972072232155, 18.912962944276874, 22.648385109439975, 22.456706723859234, 28.412708159415956, 26.86566652790193, 33.38173535562331, 44.405603793359575, 33.09105242452314, 19.825478830645164, 25.165530866192235, 26.25088207183346, 16.809083992435088, 19.495815384772516, 32.57398597655758, 38.84571467676471, 39.51729897529849, 43.491342452264604, 40.204600211112734, 30.76779923131389, 19.734830894777854, 15.231513573277383, 5.54956445770879, 2.3791481939054306, 0.4743897734630493, 0.03602803872537709, 0.0538259236172082, 0.03125756517082694, 0.05715533024481228, 0.04308105018290301, 0.04206587260048236, 0.06167205441142283, 0.02904274177947833, 0.051182705773821766, 0.02415721714045973, 0.02040998807417289, 0.032459957404963435, 0.03016868226921126, 0.04095558903270191, 0.016542274444814653, 0.028581623881754857, 0.09217326288982745, 0.03352290056946297, 0.005601627720264538, 0.028029835647753173, 0.03536734917771912, 0.013203557933710757, 0.05347773665562273, 0.013446715198487285, 0.06524066816294385, 0.027424970927137523, 0.06514630145243099, 0.014899415170563566, 0.032948422726363905, 0.022130996935189735, 0.02946047994848942, 0.020545608619408264, 0.029913776088505987, 0.02504965211565216, 0.035902775688877994, 0.09279768583514998, 0.04887119251032991, 0.016332377844880668, 0.046330205269999085, 0.03659243485139262, 0.10894126514153135, 0.12826868287858464, 0.05897296577571862, 0.06487274677642892, 0.05450610627209949, 0.11028751145086943, 0.05039009971604232, 0.0704674639048115, 0.09472995110216642, 0.03287412368902757, 0.07118207838145957, 0.05233308638355905, 0.012208726688949092, 0.04487497912299249, 0.12026351606172901, 0.1754163767421438, 0.17092475727681192, 0.18654135236095998, 0.1227106077356204, 0.16177927624554406, 0.07062533164336797, 0.16731493565584385, 0.12955682141886604, 0.11452501955171747, 0.1658687761594211, 0.2903702752965112, 0.18838816052002294, 0.12203206067844746, 0.14691672618350676, 0.09723122817494216, 0.10938037907884968, 0.11134937060095611, 0.12408192044184094, 0.14078359480106062, 0.12895910429858393, 0.1998918746868449, 0.13211711790532837, 0.13157966126117016, 0.10022613400172803, 0.1332366175108379, 0.2114286685302373, 0.14997873365158035, 0.10041848335775638, 0.3576394446915196, 0.20991700851628858, 0.1404345957862754, 0.2153633267528588, 0.1499967826830764, 0.21527521131980806, 0.126828552494126, 0.2179558908626918, 0.12484984697713969, 0.10740587938456767, 0.10738052953515323, 0.1658212940298742, 0.2705489759964328, 0.1740562029543423, 0.2105754151219322, 0.15483308042730057, 0.10063372342096222, 0.1156166488785417, 0.15954585415461373, 0.1480637130237395, 0.13274883400769005, 0.11701450653133855, 0.21580873027203545, 0.1146858137461447, 0.12859294491429485, 0.08982692709973744, 0.08459437803755845, 0.09685852639977971, 0.12829239329984113, 0.12201060255568837, 0.1669253186593133, 0.1104107826587654, 0.274996055109847, 2.550230213711339, 9.854446130414164, 19.34841271369688, 32.52152035313268, 44.18481749873008, 56.41212794088549, 61.1404549690985, 62.98499661107218, 61.15974518560595, 53.52034876423498, 49.74149419415382, 33.968545467622825, 38.191588847867905, 43.4525227546692, 43.31110562047651, 35.23753027762137, 39.9524506445854, 45.273510563758116, 31.048246737449404, 30.23863031018165, 34.90756480924545, 35.336981973340436, 25.260397311179872, 22.920736843539824, 27.09019280249073, 30.933835121893118, 25.33330240557271, 28.779877308876287, 28.30312498154179, 33.75024987805274, 41.71270839629635, 37.03354043345298, 16.22646983592741, 18.387518313623247, 22.02020772041813, 21.739605280660815, 22.794316891700994, 28.014589548110965, 23.769635808083322, 31.79832943024174, 32.653357098179484, 40.13268747637349, 48.13760565173242, 37.765493931308875, 29.975951140926732, 32.0038478989755, 37.769965433305316, 21.425574441109937, 26.989176081072902, 41.01999821201448, 48.199853666367076, 47.5772205475838, 50.02042570421773, 45.9881664091541, 34.28169181269985, 23.71455788612366, 16.38110829937843, 6.063564592792142, 2.5556722571772914, 0.6457787800219752, 0.23513953411771407, 0.14966935670423895, 0.13518084141035236, 0.16545161064113342, 0.10358343006021554, 0.18464249618832143, 0.21239455218517014, 0.07338238249142325, 0.20590307551526255, 0.12825428808648742, 0.15541349928225243, 0.08781475120133932, 0.1919077216617523, 0.17899022287418767, 0.11225616589428918, 0.12452501037548627, 0.33957509143698605, 0.126855434519389, 0.20926629343340475, 0.15383825397058842, 0.2181032555358064, 0.08049783011477801, 0.13335220485685334, 0.09679144774112972, 0.10422542706252107, 0.11026341032477156, 0.19853467332018962, 0.11107312695633982, 0.1315322404186572, 0.2204668206433135, 0.10744562402607934, 0.1354805196845724, 0.13929021364498523, 0.15131865207466388, 0.20894102782251375, 0.1527153222911781, 0.17062106470186866, 0.10857957971072006, 0.15691953621083693, 0.16499511416881316, 0.18347868605727152, 0.17844052414499945, 0.21181373496449765, 0.15193225785849557, 0.19216489737793324, 0.1759641449297628, 0.1664599202453129, 0.18062221997928235, 0.1592193321595269, 0.1526097860187292, 0.1724690373145765, 0.20936582357652728, 0.08766130379010593, 0.2821064542137808], [0.048781801540885246, 0.07673176486165294, 0.035139491646400386, 0.04557740897120488, 0.057881799932088585, 0.04552914926241483, 0.06744828075170517, 0.01636557051941993, 0.023773307498965054, 0.02118823572903151, 0.03660423643586617, 0.022770917839220455, 0.034815283236844886, 0.05783096233743334, 0.028601980753122803, 0.02893040264626184, 0.059764851710849234, 0.009633608316371759, 0.05193231514685097, 0.007676433700497353, 0.006261374500970687, 0.0036496392802350345, 0.04591813423640786, 0.0488426978699863, 0.09487499452887044, 0.08647280264525645, 0.05989112981384801, 0.0273869174247187, 0.005540404846185759, 0.04710710652533078, 0.06759778281012851, 0.023355427603687973, 0.02848518107296719, 0.08099425508971177, 0.009803035364095724, 0.06661349006237523, 0.0197149318222317, 0.036742339105976206, 0.04348564802879288, 0.029982522903611104, 0.03906467719183814, 0.030065616630318186, 0.04485859250229213, 0.053453175876770294, 0.06041973814248078, 0.03159148182960288, 0.017375686175880894, 0.018591619014079054, 0.028608245437123606, 0.015194288158278554, 0.03964336468808113, 0.026299696933898716, 0.06010123708796117, 0.08325145654981175, 0.03179622648824607, 0.11515352574567642, 0.0635503334624152, 0.01202529555396928, 0.01912767754777545, 0.08130760037250097, 0.010612050067603348, 0.02245504063584151, 0.07496478306430002, 0.5056747511750268, 2.2615761285828007, 6.466642060587484, 17.772473019938317, 28.8026584348371, 31.714447582921675, 38.738022081313595, 45.09828259868007, 42.22312642681984, 40.51343979374055, 31.227895213711648, 33.81575345993042, 31.37364656694474, 33.05537846780593, 21.481281903482255, 20.048385166352798, 22.184180444286717, 29.880329639680927, 19.684187212297996, 28.85313737776972, 22.65442163713517, 20.936052837679465, 18.21768949108739, 29.664342364957257, 23.724932555229437, 27.693994622076712, 28.28385045451503, 22.65195054392661, 11.283906871272672, 34.98242716635428, 70.4832112404608, 47.31334309424124, 16.359043005974062, 18.789165096898234, 21.908396636286092, 22.13016156227358, 24.982662124018518, 21.514686769054784, 21.688233998513994, 20.434324818272746, 41.754273753012384, 40.33776075609269, 28.503354134098178, 21.357397763959824, 18.819363424854895, 26.701081914286462, 23.461494407346173, 26.280645016700994, 34.972876194984686, 35.76399080214962, 39.18148133062547, 31.96162750644069, 21.753653249432965, 13.45480049810102, 8.314127441375486, 2.9389890691926404, 0.3918391111637316, 0.09331887077179649, 0.08637080569901774, 0.0455125711197334, 0.06106836180533133, 0.04444225052852304, 0.010868594718856678, 0.03612182703950713, 0.012953112299944605, 0.04811473048081802, 0.039945383360909845, 0.03489891705553859, 0.027807206666517644, 0.08502729432356936, 0.04201596963309473, 0.0555254475423886, 0.020220274060604074, 0.043988462177015124, 0.020338621238366734, 0.016590237294534044, 0.019628840776520873, 0.0439318674316089, 0.020393605283912153, 0.0096024563085408, 0.02241439775623862, 0.030450409188145594, 0.041810884065325224, 0.1023962772301128, 0.03893412048778227, 0.005101729015399132, 0.03639352778273244, 0.01915450020122432, 0.016040705189469363, 0.027985693661556132, 0.04925028345878086, 0.06232058614372246, 0.03154478494017836, 0.04414650611579419, 0.07130075306180986, 0.04584851216584925, 0.02571296551445079, 0.018126929231408625, 0.05858195449916586, 0.12225296979229297, 0.02509357002113135, 0.0715487816881749, 0.05703594693313203, 0.09957862116636769, 0.022922557282952533, 0.0331913760202306, 0.02747956235262175, 0.04193745711217484, 0.015301360437015613, 0.056335849822649074, 0.01687607619040195, 0.009254444589568003, 0.08101477858520324, 0.04200838919308397, 0.03834954943628081, 0.04097748765601747, 0.03082257661698086, 0.011212548087050599, 0.019136560337257483, 0.05991041224690215, 0.03890213248650393, 0.022192873856833866, 0.07962034534542792, 0.05609021905148703, 0.05296120953355586, 0.069097698696198, 0.049465983174741275, 0.037204217345964526, 0.03784468600286111, 0.0398008723653132, 0.06558479485853065, 0.010229298176484243, 0.019637147084839886, 0.0050943884566696665, 0.07851353215594446, 0.012650394571884986, 0.04411309319097669, 0.11744759135669279, 0.05811812273497063, 0.07045594960330956, 0.03427138379324348, 0.02997789956298807, 0.027166077258786368, 0.11820366651180292, 0.06568746596214271, 0.022110818179264184, 0.05075423662821132, 0.06506652871687567, 0.03655788045556795, 0.01265826804052678, 0.03357427442566522, 0.04108195140537235, 0.045025174490987294, 0.013454343518993307, 0.014037991434546008, 0.0741328958482031, 0.055440507543784, 0.025407842270308928, 0.05327783367266098, 0.038075975608080626, 0.013754465166599521, 0.055258270548356164, 0.06173951611403496, 0.03666196499140032, 0.04178696680032919, 0.020821486457040714, 0.02148367179137084, 0.014655280186073675, 0.06569796902758461, 0.09002955735570962, 0.029971845553166447, 0.02012679218164375, 0.0396363090182985, 0.012434642187379783, 0.06079145549466053, 0.05022904122128122, 0.9099132711848906, 3.8311287328120205, 9.792280485553126, 22.114122990638982, 34.960093190593106, 38.60724633739841, 44.91298983173986, 52.49546481717018, 48.88344433999831, 47.253075876543605, 35.84948278242542, 39.45692977597637, 35.601855708706765, 35.56176516317552, 24.086188731655, 27.667116580470918, 27.230546974366714, 26.317493723284816, 19.688648908369004, 32.66606753872287, 25.39241252406951, 21.86343058463066, 25.69409574231794, 34.9927233880566, 33.72053400162728, 33.46941209608509, 39.726859446494814, 33.032212949568226, 21.89579406092244, 49.8345406593815, 73.89905437346428, 41.94770151568998, 19.58617110406199, 24.707788305897868, 29.643926428210353, 27.160138468588553, 33.915542479484316, 25.36429697467435, 26.75229237925622, 25.32021345630769, 44.80397931991085, 46.23903728300526, 29.640453169422766, 23.092693551894158, 22.73496554743859, 29.901535934017552, 23.061226337186753, 28.390125113148844, 38.73671200967605, 42.19608168448172, 43.073570805211226, 35.35786859450802, 27.02362233592618, 17.211670183366348, 11.157860525192755, 3.8745456933975224, 0.6593960848066115, 0.2673930614706009, 0.14474831431383087, 0.050716472323983915, 0.07954816454120221, 0.03240211776668026, 0.06898955772480658, 0.05767918499787489, 0.04896216545133822, 0.09834963993559923, 0.060430379103749036, 0.05713484888415664, 0.016498737668077794, 0.07728992886240445, 0.07488147100253452, 0.0628425678118102, 0.01909760859674744, 0.04225159146552605, 0.03656436922028661, 0.006775641663660926, 0.04148774051798448, 0.04360987301615458, 0.04880450838696092, 0.014966554158637601, 0.04875097799325182, 0.0378618655245631, 0.051854155026376254, 0.03285541582191664, 0.06885783656710578, 0.060973045145792354, 0.03240177685755395, 0.012142038735140477, 0.04725056415003154, 0.0036699293583120794, 0.047845446744993816, 0.048784314309276884, 0.0191604737718139, 0.036935845254770214, 0.06511309920179267, 0.037364015626090194, 0.04308089696531815, 0.014429361814813269, 0.06343633191840303, 0.04136698207848015, 0.08616548647443134, 0.027850492549459302, 0.06343674177544252, 0.07307700452304657, 0.01865322588972988, 0.04865875632892694, 0.06105318177311171, 0.02980502607721475, 0.01154847476901787, 0.06968604656116617, 0.07814583293492756, 0.026894121791326234, 0.0755549772011657, 0.15682414294250552, 0.13907644447059403, 0.24397260449346037, 0.11912625853813465, 0.3139638834662976, 0.21715915942144012, 0.15561309583004446, 0.26017859698303286, 0.11469544347135291, 0.1435360261389325, 0.1535514612952548, 0.15765344844229762, 0.08165637722178813, 0.11254688860067438, 0.09298140904115093, 0.12439394805340037, 0.126676568310828, 0.1281428759196593, 0.23229529480299643, 0.12970512071924825, 0.12185273481713188, 0.21170262157196001, 0.11430876059157234, 0.21077482780862242, 0.2110619882061597, 0.23014677057583488, 0.2283040226827706, 0.17960723008840315, 0.11574452427486259, 0.24798589398063, 0.1891223178996194, 0.1441920731937693, 0.2042140814686014, 0.16792351590289226, 0.12523230871245747, 0.2531041886897818, 0.12355113642350321, 0.14927293684694076, 0.12845943111085123, 0.1891449021716272, 0.08912258586215396, 0.06969635810462699, 0.13288407916984252, 0.14253896270548144, 0.11946216511029391, 0.1299253863192374, 0.21901019638584507, 0.08619214633419629, 0.1422675071103919, 0.11461780046022708, 0.11207124759112636, 0.1556320182017742, 0.16922312277940013, 0.11542136540576337, 0.14440179742392034, 0.21585261178833826, 0.17790335861425247, 0.13433469729798456, 0.1603890105240768, 0.09767203516657315, 0.1625011915401105, 0.24531025529628803, 0.14997988278346677, 1.2674313062621703, 3.9800532835145153, 10.438422329964178, 23.649283762901064, 37.59414126796108, 42.95729214145292, 52.158007621765144, 59.63301750921435, 59.01485981479768, 57.19416618347169, 46.267878470882295, 48.91880058473157, 47.14365743821668, 45.54384423840431, 34.59052747295749, 31.86675321671271, 33.82423754661314, 42.88391244026923, 29.67662918952204, 42.16123927024103, 34.31763249058878, 33.68612304810555, 31.479105372582715, 44.4653767924155, 38.291319031869214, 41.257564406241144, 40.374929135845555, 35.84981618389007, 22.668873610035067, 46.62060153099799, 81.88158758224981, 56.53327426602764, 27.01613453126723, 29.002516923412202, 35.402520856549664, 33.35775398438977, 35.96261178293536, 30.833816643684145, 33.25280312568911, 30.803255496486543, 55.02831182172222, 53.195549057376006, 41.6439414024353, 31.6091162543143, 29.906954688410607, 39.14190461558681, 34.24767701856552, 37.375006291174124, 46.74649784641881, 49.90952853233584, 49.69317451600106, 43.35630701434228, 31.1813876705785, 19.555688404267837, 11.942250228697254, 4.360253282131688, 0.8202941607563727, 0.33235262899148854, 0.15277222730219364, 0.18163906380293832, 0.17959987564433008, 0.17218917007407836, 0.18794606650067916, 0.1386770981574251, 0.08912663846727341, 0.24131640912063662, 0.16543961370423918, 0.1832085940986872, 0.11768077319908528, 0.13966145985309156, 0.14717898872350493, 0.11536045375490382, 0.0915098920344345, 0.10704127515876487, 0.22466297531800888, 0.09284666949702848, 0.08357204902436464, 0.1102229149170941, 0.1704714477302567, 0.13789211850493185, 0.12259981610001096, 0.10427445668967501, 0.26106165121159247, 0.1583517069417623, 0.2076798172727708, 0.1282140531487042, 0.18092258773263425, 0.11658361271744776, 0.1335009791317486, 0.09726600090582525, 0.16209165625754865, 0.22191979832226233, 0.09543036996957757, 0.12123090124899343, 0.19599303873556276, 0.175322990624174, 0.13001527907627244, 0.1524866144022634, 0.13690599480703955, 0.27393716838090654, 0.11065754724005539, 0.17719661186058677, 0.23882663868848356, 0.2131645778013814, 0.09622829650799114, 0.14429080660545057, 0.12803716344698785, 0.0950906865839516, 0.058940924148285584, 0.2786379145278085, 0.19046058157278647, 0.19721058227362173, 0.20430909169297065], [0.02290247237279771, 0.018638017129213102, 0.042386108844150464, 0.07035935357693704, 0.05244005140998671, 0.02896068993234827, 0.10117789865621638, 0.018255413667629325, 0.035604104820278384, 0.042685974809911945, 0.09846325077477003, 0.009980896082256111, 0.012925192225544203, 0.02592072472907603, 0.024393601230375712, 0.11002527189350898, 0.112272598480265, 0.011233460372163644, 0.02234485612491206, 0.036425646018957904, 0.07189943545287655, 0.05028775036935845, 0.05138296115722868, 0.03991124265256428, 0.05929561902678782, 0.06401030414347207, 0.0783314177345845, 0.07508996183112746, 0.046682303110438014, 0.017994240887703437, 0.04873570220004167, 0.10477029177690707, 0.0430615226017131, 0.020691981208660913, 0.02839040833585445, 0.05284379506784101, 0.05196360983855782, 0.067793702135884, 0.015135913216058287, 0.02089857596964125, 0.06314026574874598, 0.013659606244595302, 0.033585792557606776, 0.014402410841637082, 0.08871683505393806, 0.014374011962284005, 0.06827524968332822, 0.05212254243932905, 0.0395221772393392, 0.042205078437203364, 0.025145026231785456, 0.06987721614179111, 0.02841992570357698, 0.09087774692283523, 0.02517972043865631, 0.01953501224277481, 0.046671761740599914, 0.026481907116249207, 0.04181993156371098, 0.028845336243149736, 0.010375618097192098, 0.02520643583979578, 0.036036802771230864, 0.04263859610223482, 0.25808677858402657, 0.9574874538567759, 5.508173156169153, 9.710586340196672, 16.42608807932946, 24.31338025677589, 33.29504705244495, 38.15107860872823, 39.44749647571195, 41.3316422893155, 41.90191176629836, 41.65390422267299, 29.758777349225937, 31.282912338933638, 22.590571334285123, 30.681126617616226, 35.683488076733006, 35.128072615592714, 29.834639910728704, 28.139909275116462, 37.301104914757516, 21.978987532277262, 19.54453318349777, 21.263659000396732, 20.971234536940052, 17.49100765874309, 17.034969368288596, 31.949736841263313, 17.708397180803363, 39.186007745804325, 92.48570749836584, 61.65695659575924, 26.23463365339464, 20.537861662526286, 26.121626246360044, 23.621270195130382, 25.458347566666145, 21.064500654897383, 31.4353552556807, 37.88986836710284, 38.849589978494954, 40.695688801427046, 20.335510507706676, 24.48146362458506, 34.35828393505466, 37.79770443516393, 36.55565454113868, 35.078329117067405, 38.15047064135152, 30.822718297281575, 20.696248931269494, 10.793759649799718, 3.6597120858007863, 1.201370502671888, 0.26627855675835765, 0.015587698247644211, 0.12221965262846601, 0.04008498756335147, 0.010777789359581808, 0.033711024950588905, 0.037759416586449074, 0.0038599371187193624, 0.04957954804863661, 0.005626903354911315, 0.05759453994312114, 0.0720809216821386, 0.01916255178530851, 0.10696447484435574, 0.03456612463079153, 0.07622536542194505, 0.02515770881737192, 0.010237985613545584, 0.03810997075972058, 0.028910193246819323, 0.06481664615773386, 0.058748892718745824, 0.022890337540077108, 0.03868503466008171, 0.031077291275705063, 0.0189211517347083, 0.05235881544649602, 0.04731039561691785, 0.05089473332308474, 0.024202408667113033, 0.03768305294215679, 0.052684678605967955, 0.02540192807153348, 0.05393710595765903, 0.045456432196642124, 0.011682873404014015, 0.06709647785511709, 0.07932398423192003, 0.06408843362042982, 0.013134669392339647, 0.026690849936717463, 0.05670977733849038, 0.07380412155461889, 0.01880643389848692, 0.02215862781139872, 0.10093013816062482, 0.0677748563729467, 0.0073905780464561, 0.05673728372541167, 0.046896240824172576, 0.04367160055065348, 0.07308875631180502, 0.020365482196211815, 0.02608004611946883, 0.03092430351722625, 0.056264339345357114, 0.07646387923629054, 0.008163626358333615, 0.029287238740512443, 0.02613006016960548, 0.10284811588785342, 0.035217969693363674, 0.030582747046625426, 0.025958808875011823, 0.11028571114424737, 0.02982804318889976, 0.056561730847123175, 0.044208919298985315, 0.029943050223312555, 0.03315161222652082, 0.020011306342278278, 0.03841730225230417, 0.023725624271338026, 0.04875038810555012, 0.054539262557462345, 0.01348998097162093, 0.030196311230200435, 0.06235160121333696, 0.07307407040629657, 0.030822869645611897, 0.058585896021536285, 0.026751204258612087, 0.029147042735149304, 0.050507169442191246, 0.043280734830806335, 0.019733959531051018, 0.032098082367390875, 0.012982344299915337, 0.04932088229144293, 0.05564037605278915, 0.02802455921717469, 0.037205964026431886, 0.04214689405935426, 0.06182852020907787, 0.04534445695518967, 0.09965634078628595, 0.07572916261250935, 0.0444700020635801, 0.02341458874364053, 0.05366238299757243, 0.04956836316494211, 0.09881088615305002, 0.08957532850364525, 0.09709890946866044, 0.019551377796057253, 0.014544814137832053, 0.08060344299601932, 0.041886485452132846, 0.07014700166520572, 0.062306877000317465, 0.06658161314384592, 0.019495903454240293, 0.026677903050797123, 0.017150586561089563, 0.03723088486660873, 0.038766159540823394, 0.0821838747229307, 0.028400530272554007, 0.009739659782949715, 0.06756200650406462, 0.035105959977954626, 0.013727544836940305, 0.45793405163191986, 1.5971018614307528, 8.120347155678658, 13.486707018267724, 21.59610732909172, 30.428886836574925, 39.91418792355446, 45.28231236242479, 45.90836186562815, 47.19896285764633, 48.169247411912494, 46.948358704966886, 36.82494878768921, 35.576505430283085, 23.59693188821116, 32.011151352236354, 36.76014338770221, 30.381643849034464, 32.2492294157705, 25.309634823952955, 36.57730994686004, 25.6459427648975, 26.355405392185336, 27.579114283284834, 28.53635107317279, 25.604298960778024, 24.030626396979056, 27.755326763276134, 22.762002445036366, 55.23962559238557, 92.8215879009616, 53.009428670329434, 26.80300666439918, 25.325112496652913, 30.71937953272174, 28.303725104178156, 26.83758627983832, 25.21489585599592, 29.819662340225715, 44.047597300621774, 46.65920157586375, 42.28356230643488, 23.36800471428902, 28.215510999002767, 39.83876858988116, 39.38320882858769, 41.6453730675482, 40.55743309759325, 42.36998781081169, 36.71076074723275, 25.637848954046927, 13.432842089283852, 5.093731111095798, 1.836088076233864, 0.666778353193114, 0.05121282452056485, 0.0642592252622689, 0.03533376771355829, 0.052606721498793176, 0.03369496391725636, 0.025213855401342435, 0.0413245561292335, 0.06341218099659009, 0.028497017131397323, 0.06098220755736675, 0.045366849705216386, 0.040008271518614025, 0.03515450696971628, 0.006370901612700114, 0.01785771827393722, 0.06504417427124516, 0.07910715070583167, 0.0068198056748857904, 0.030522601483690164, 0.040221129048375354, 0.09885124366490111, 0.06160800180007374, 0.03967510371078407, 0.03853206988424063, 0.03814262525749303, 0.050856122491701, 0.012698525960947718, 0.016321943727351965, 0.0436734123485944, 0.0664344936188671, 0.08976974629706914, 0.011839801727253343, 0.07553839905848427, 0.04475586011164612, 0.05580688143269189, 0.08391533302323473, 0.0931459494055279, 0.07075866158570975, 0.06009451849686523, 0.05773370364500631, 0.02182316557023554, 0.04278097737340197, 0.005980202516976504, 0.029448088476314183, 0.06353766619858724, 0.08022692610299395, 0.030351072482223955, 0.02144179742542967, 0.03069286260964169, 0.04053315282949517, 0.10225706373251255, 0.05032900037364133, 0.04264816070996946, 0.076864252107278, 0.0448366096093049, 0.05772762473732714, 0.05477276615678303, 0.13570939611283042, 0.12672091714076458, 0.17204439477814784, 0.1745309629627774, 0.24610274261043918, 0.09984032446218115, 0.18930665397595978, 0.11573241242477972, 0.17169343457827646, 0.12504133831469283, 0.27316728066052165, 0.14777552606838365, 0.10640808816758857, 0.14444482092174793, 0.0677481352261478, 0.2175071165566483, 0.2691958195740177, 0.1984284322468504, 0.11874794899936646, 0.12191618987990004, 0.19008430982789687, 0.17197707097136206, 0.15191416286172407, 0.3392592180640467, 0.19404786488702222, 0.1596528919593942, 0.12787404800615004, 0.19168924870750598, 0.12173058975848461, 0.08890074978192007, 0.19866647108668284, 0.17298835299668774, 0.15511205900580655, 0.1436678239054257, 0.124068544546683, 0.0980145990427944, 0.13710453415349608, 0.28119027434337523, 0.16973414939017067, 0.11455823712411428, 0.1937262305328923, 0.16417350019178084, 0.16342742248408257, 0.15108672661646722, 0.16878574786166992, 0.196326608739553, 0.12418295977817428, 0.1694694506905733, 0.13980968254468135, 0.1290265200359206, 0.17936854773471433, 0.20644053215942076, 0.19770193574649675, 0.11095112745439815, 0.16893181018531325, 0.13097627509024837, 0.11936333976806172, 0.08821261130393514, 0.2038020334176479, 0.10579207686767464, 0.14688110309502772, 0.13124803712050762, 0.20003634354760572, 0.2259673166178888, 0.4654048797824691, 1.9170958068101638, 7.789264792396177, 14.650925320963706, 22.81283832365467, 33.160345015987275, 44.80783108742007, 51.95272253405664, 52.17968263933736, 55.76364640266665, 58.27510080029888, 57.12523837243357, 44.324053795106956, 47.114157292150686, 33.59520250751127, 44.930071753840295, 49.110000441151286, 46.34938140069285, 42.21529345358572, 39.703038892438336, 51.562670277011016, 33.14259629095755, 30.77018011000849, 33.49870827890212, 31.88580416863965, 30.50279409654679, 28.110973950355287, 43.49651605852189, 28.07485088225334, 50.20389456902781, 100.12794371574157, 73.16455133499639, 36.86301539021154, 32.546656862381965, 39.059409326122655, 36.236146111642164, 38.86177286025017, 30.919349808846754, 45.08624092225106, 51.516641263038885, 54.878740079941295, 52.89284406169769, 31.442805797823016, 35.370302507954264, 46.42545577018492, 49.92475517334477, 50.68996252552156, 49.663458639575595, 49.530925673823205, 42.007521583187966, 28.70775668851791, 15.083362710091377, 5.761974530835306, 2.1064373177866784, 0.7802983036925717, 0.18625391617176995, 0.2788958716536722, 0.17280424674672468, 0.12566060548828495, 0.16708022163760278, 0.1272700259822511, 0.13380171460730414, 0.17036894516598794, 0.08540028721214303, 0.10715654840873134, 0.17468784244791155, 0.1250537872434624, 0.15002848340138314, 0.11210189110809758, 0.16535229500262968, 0.16530776997247051, 0.08545480202883483, 0.09066837509312937, 0.12243395040352499, 0.19124608216506822, 0.2589866254598864, 0.11153351515531541, 0.14253669508522557, 0.12960902265002652, 0.17794245974190775, 0.2904509290331795, 0.18587458007518323, 0.1032163130660211, 0.2029066145299904, 0.16627045137987984, 0.32889941106400183, 0.14457105688991087, 0.22382446144136692, 0.17666799587107476, 0.24522526550196835, 0.18674985085043216, 0.18229999849873205, 0.14854320745554664, 0.14478741544148616, 0.12427870544695085, 0.2524641528725624, 0.15789907155258043, 0.1668242563403422, 0.14119521384277653, 0.24354705797328105, 0.17645578951604907, 0.10534357835328388, 0.09252304331429544, 0.31551937903127364, 0.17112728028047472, 0.28594118392755913, 0.22020422102462864, 0.15471810595162455, 0.19981290634361007, 0.16585693244011174, 0.18514687315590922, 0.14040027504726765], [0.041108458047552456, 0.07092907784446593, 0.037849880078987735, 0.03059611719612393, 0.026934042633060488, 0.036944839127001264, 0.017200956842111006, 0.027781395249128826, 0.016788983484730124, 0.02201348287804473, 0.10205624144404166, 0.05414633223065927, 0.006834992410374746, 0.046079028022265246, 0.011491219272776958, 0.046155200144576455, 0.061421440238313335, 0.021346498002868988, 0.0355335213093748, 0.05187192826621956, 0.0216670943078615, 0.019455559348927873, 0.012280501466574929, 0.0072050191022666, 0.0026382849553614977, 0.08296644119846244, 0.03322840871049031, 0.029834269568504348, 0.05697832179946765, 0.01834270555616146, 0.039563354465269276, 0.09201728738844396, 0.08834711336080106, 0.06579019835278874, 0.02932229683914733, 0.027597382844936465, 0.009525004819396042, 0.03735415224406508, 0.041630328632891185, 0.029929978848104517, 0.0626272626311308, 0.029890151852140986, 0.024831945249330134, 0.031097594520918308, 0.04263620973835069, 0.029259096500614, 0.006137565595112862, 0.045032647678688656, 0.03367675400729622, 0.04054118143094163, 0.026483077315553546, 0.016409471187920823, 0.09299984111660912, 0.04813673635644298, 0.06240812318039037, 0.026759493329952803, 0.04479011956361994, 0.040625543033163396, 0.010905375557711289, 0.0148020061333814, 0.00526556745171547, 0.03010064600065591, 0.015611448888516715, 0.048955377912329096, 0.03692562564186031, 0.048582825524311875, 0.18242937542738455, 1.9316046540775609, 4.635079051217725, 11.650742619268357, 14.920458832094747, 22.498732959070516, 33.22000034393803, 33.09923056633242, 39.82258881292036, 46.8953674839389, 49.27513614777596, 46.97601925942206, 46.714240274121686, 50.271594678201986, 39.894458401587706, 38.19380106464509, 32.59542369073437, 34.31668327700707, 27.404372692108158, 28.234256006056263, 25.477427936369374, 31.938158004514634, 27.909989741540727, 40.09717433683334, 29.69759818046324, 34.25301928674021, 40.89006577768634, 35.36972591953893, 49.16188555379068, 83.237472503416, 46.4231494165236, 28.152484393888905, 27.572679635017153, 26.74806602539555, 26.369780878866873, 19.731608667681297, 27.29537198620458, 31.328366725675522, 33.546753391142815, 45.67052110548943, 29.079718974328813, 32.93181596263763, 41.80422121478666, 38.07193302339123, 33.829987741285755, 32.30331497807657, 24.40943910229591, 12.202570092293525, 5.773077780200589, 2.252540703742735, 0.4755954119947649, 0.07608092720470122, 0.044947462531948285, 0.08888571147596644, 0.028899381830987912, 0.058618213440622055, 0.06909769103531876, 0.018240157026617278, 0.04647465497856179, 0.07309936662955631, 0.04194710598958116, 0.029386495007202033, 0.01240064416291012, 0.03242622272321775, 0.012421021144086076, 0.05159904774759085, 0.011411980883548818, 0.024512783443975835, 0.018678177373423692, 0.06477023655128095, 0.05601146904331061, 0.03379821724769089, 0.024291479794849313, 0.029394954533105897, 0.02019279065632051, 0.04272812879794548, 0.07027955785874399, 0.10696727872615862, 0.06633507072805397, 0.03371899226500142, 0.011913485021420546, 0.026553630182940154, 0.02307998452095255, 0.03320522688990159, 0.03818890845943843, 0.024504320087632345, 0.029612906547563694, 0.09358245864390366, 0.09160729245312753, 0.08416804244681712, 0.06691396506803651, 0.07094276017479359, 0.08371422728223187, 0.014873646845620488, 0.02940271308855905, 0.11805979519962304, 0.012815784336247993, 0.05210376179386532, 0.02921550418250263, 0.0672292408923949, 0.040593359679464376, 0.057849371430253795, 0.016749558684926842, 0.028022688047419635, 0.04643464220627662, 0.0482226109823152, 0.15447096598725166, 0.07308058215365296, 0.05551121362875547, 0.04987868623087003, 0.022539779536365982, 0.05155240065388141, 0.008344918192784873, 0.017434766876601407, 0.09160797427138014, 0.033237149773706356, 0.031773772451185414, 0.026697105044619213, 0.0586313212050065, 0.06234035887304814, 0.043966996393376784, 0.00955060652021559, 0.014742496423423292, 0.08714621691333671, 0.05103486612619412, 0.03448776149701688, 0.011769872263915116, 0.05996961552169054, 0.05832978516757008, 0.005113528205847909, 0.04129104744342547, 0.02093105235197131, 0.019740996048635533, 0.030945445628716584, 0.040781959035103364, 0.04687434220085702, 0.046505172091025504, 0.06282652210023615, 0.056452417761207595, 0.042891202103947444, 0.04220378374861133, 0.13027752629451214, 0.08022845827884252, 0.04392298081168725, 0.01982068834495881, 0.05506037088531641, 0.00719752724117209, 0.08774159746544977, 0.10641852994599652, 0.02549015075689362, 0.02176222902151846, 0.04369474789728561, 0.0057715867202909246, 0.03483756873456221, 0.026465767558904427, 0.03832904126254782, 0.11279150047489714, 0.04018084431487707, 0.028519722062253186, 0.04439711645846406, 0.025728254714199615, 0.02700910392788149, 0.06029749349240334, 0.0347799206182601, 0.03988240327265474, 0.05086210563838963, 0.034614051091334516, 0.013561082549483306, 0.028481178263562824, 0.07534844755765892, 0.03620370651685423, 0.0763021350928372, 0.09088296398159959, 0.06525933772565858, 0.028683572947498293, 0.046780370025625156, 0.5144118000903438, 3.127205227651904, 6.509873444034207, 15.103630577364276, 20.22689615526507, 27.95370847948136, 39.86243224913075, 40.34962200349377, 46.530006547128, 51.78852819627332, 51.21161422421856, 50.34997540135538, 47.685105339173354, 52.089158258130475, 45.661911502961196, 40.30089439884309, 35.18849672809724, 34.362210227597146, 31.21190763288929, 25.561639262783913, 27.03745653552394, 31.029517419876594, 26.44721434962365, 35.034061247302645, 26.459848303948682, 32.573878111377844, 37.27162830291256, 35.992413951504616, 63.013045480174405, 86.19814811214324, 41.77026917857509, 29.842892577571256, 29.07219194596814, 27.308666859903646, 28.225287506657263, 22.370767593383793, 30.38412867053863, 37.27428766988939, 42.21155151244133, 51.915205063358435, 32.92917620751166, 37.042832528391195, 46.369283506947184, 43.40590930754139, 40.075793497024044, 35.97042514431861, 30.06991936314491, 15.77162100422767, 7.473581164113938, 3.3538147710984756, 0.6371240702367599, 0.10314682889128886, 0.03595077109733417, 0.15520587413301393, 0.037456264103492426, 0.018548526568338275, 0.01688333487348451, 0.01973227605283741, 0.006710559621663585, 0.04267996868058559, 0.02998696621357193, 0.08342653828402681, 0.037526384131201816, 0.06640698340150618, 0.04978282947934443, 0.05165516751848402, 0.042508594811924046, 0.049480205597055536, 0.029833039997385877, 0.05279230629845012, 0.03316782264699859, 0.0173372438838405, 0.05829472132327576, 0.02218665322288871, 0.026118249009032885, 0.03352486175454913, 0.044191770420800296, 0.03171276503933534, 0.02916679822749669, 0.06253957620731766, 0.05424013969698741, 0.0718010621025197, 0.023016992941378586, 0.03979621838117319, 0.006649306582872786, 0.059525951022101994, 0.05202750540188244, 0.05193830212397922, 0.0539425413514818, 0.1580290919950893, 0.06151987487570413, 0.0600864056257471, 0.06854891927251894, 0.04299390385107648, 0.14181838040390324, 0.0303423639777447, 0.08882545099984254, 0.061458507402529644, 0.041272707298518195, 0.02760785143642176, 0.04593240262399759, 0.052289572589459925, 0.10082073314415832, 0.07627626430363425, 0.015974204927202196, 0.019807235841008446, 0.0630018336608285, 0.08152025871940198, 0.05310655173455035, 0.017136469475864884, 0.10748450298823657, 0.18983062747265064, 0.17577937984418485, 0.09538440469412074, 0.1626592967659235, 0.13747294583628256, 0.24468053102252946, 0.102574928934055, 0.22870038125303485, 0.15221730385336185, 0.19359466259277638, 0.10937411247962907, 0.131713435534508, 0.15404347360374468, 0.1537980190328052, 0.12799780951031756, 0.12018747417436493, 0.13663484564711972, 0.1338803458718523, 0.09661490277897927, 0.10125827660123188, 0.09944300062113232, 0.20149811591592529, 0.19908660902611672, 0.11157341301441194, 0.11346024160663928, 0.1616872231205625, 0.14610194571075902, 0.16170792281627655, 0.16698017055469175, 0.18966204216403348, 0.2001546275231146, 0.11355122986940608, 0.15841520030892667, 0.15487069534438272, 0.11818837539683427, 0.16068530268967152, 0.1632338473873754, 0.22199093724691102, 0.10030461970957057, 0.1350100191249963, 0.1203622188298933, 0.12352814612489556, 0.12987805740727534, 0.12973400223399364, 0.1461343359081976, 0.19910280412483602, 0.09048375556425703, 0.1454994482018294, 0.18703445251430237, 0.08328319557251469, 0.09705227769670949, 0.17297157567114602, 0.09880459657119167, 0.15080937214436071, 0.15306619056049856, 0.12248675684414564, 0.12690670878416108, 0.15148202798539592, 0.20299178818541191, 0.08399456183636382, 0.1553743521893217, 0.24843986236280013, 0.2831350345044367, 0.16865041076896653, 0.25245837656961334, 0.7250852438230669, 3.05285228836921, 6.695741818797204, 15.49360634819154, 22.351730369752456, 30.529142618179325, 45.53218695425218, 46.67771516307708, 55.6297053060224, 60.93696632692891, 62.805167705782004, 61.027537776577866, 60.84623798247307, 63.65221531160417, 55.60597888885006, 50.56918882554578, 45.62833209191599, 44.73692640181511, 40.22519265451739, 39.32483219331311, 38.912163549853915, 43.82372410066667, 39.43201880301199, 53.74217056458997, 40.02164125442505, 48.31036644597208, 53.71585930547407, 45.83296998854607, 59.13958726390716, 92.85677156140729, 58.81128095811414, 38.18906676384711, 38.95298365623721, 40.11921413483159, 39.75055840707595, 30.052957073334728, 38.5068650399485, 44.25277648433563, 51.31874199836485, 60.546894458032426, 40.611079354440015, 46.285113365419456, 54.41882648775655, 51.99985765641736, 44.58911972661173, 40.77222601059945, 32.94053539153069, 19.03446032154945, 8.967800236517384, 3.993158412556495, 0.8016845980478872, 0.2783265763953809, 0.08745085177642685, 0.22056270420791643, 0.15697038912725064, 0.11779480538661442, 0.24225186376321703, 0.1468527884853463, 0.21450703963637355, 0.12994392564700497, 0.15533860652677475, 0.1952207761426126, 0.11035770042649201, 0.13935353847280627, 0.0993441139918662, 0.11923545671086158, 0.12877763339108036, 0.19591451472332402, 0.22525839417451815, 0.17636487020119546, 0.15697420424511357, 0.09405642192089751, 0.18627322158746182, 0.12222354435512137, 0.18182172980760375, 0.1096796436655906, 0.07966261041621048, 0.16954126377259532, 0.10416072327643634, 0.13380329274842817, 0.10748418123130837, 0.2176534087066689, 0.12472337352172022, 0.13403560125058697, 0.11632922556131117, 0.10116978578509823, 0.10009402213918586, 0.22297798025031246, 0.21609582938253882, 0.3049462931531091, 0.14768578652893344, 0.20412339198012508, 0.17807465587412158, 0.1946071856805394, 0.19014199624859518, 0.18124618327185033, 0.17222272472516184, 0.15304308534870226, 0.1880049020532639, 0.14361456547292972, 0.14302789534051574, 0.18093482981766426, 0.3045319315166243, 0.17419890981287728, 0.1471163380530573, 0.08061458191443836, 0.230541106673979, 0.17407877190459162, 0.18926271117262303, 0.14697084263447793], [0.08077139245165933, 0.05312638958134959, 0.0036990593728278916, 0.028127757006234703, 0.019122462404230912, 0.07313000248564828, 0.0969073491831941, 0.03070154813148322, 0.038222991711189674, 0.053161258073223215, 0.026640087035634828, 0.05750842016911315, 0.010218367059414667, 0.014630657162577396, 0.01427876903870774, 0.03395615010372093, 0.014021747497721546, 0.023693077025874972, 0.08342023338040999, 0.061386663676990624, 0.008347004824768632, 0.09682939973689857, 0.07968539387107858, 0.008845197547587657, 0.08034660435852506, 0.011183166699934632, 0.011309040691553345, 0.02481972614693786, 0.054538010003706144, 0.09163330113815685, 0.03824714646344224, 0.03516726233365555, 0.02451981613112073, 0.023617818463413466, 0.03491279473828693, 0.012903522470996026, 0.018817597714763497, 0.021222100645724325, 0.009185812687651526, 0.026875852509551955, 0.03791330449823891, 0.053088590803165595, 0.05713391042644939, 0.014732573669584048, 0.08200228124135926, 0.08985804559122171, 0.026668221614654028, 0.07207644006778156, 0.08710919188395624, 0.07757810049600179, 0.008341814579081633, 0.038468852308729005, 0.022446393418396195, 0.05791381091600465, 0.06311909873939811, 0.05782321335807924, 0.062431630588346915, 0.02156766375616914, 0.02488367150597755, 0.024135881591768518, 0.011353128093985781, 0.060482936565794294, 0.01654994681537632, 0.05039370799016568, 0.030803512518985138, 0.026366532359632756, 0.019292168116437334, 0.09953793423670916, 0.1785473780886781, 1.45894335883279, 2.7534168333776536, 6.792827835006099, 14.603754897271434, 20.60590301790545, 31.706449870140325, 42.368701273395175, 48.27647716768327, 48.79648147090789, 55.54581365277691, 52.6360974773284, 44.32636799350862, 44.949307057165335, 36.27260454239384, 46.61305881315663, 42.52869867509411, 37.56163266397292, 30.499840551807036, 38.0553610094132, 41.02237909070907, 33.897895736079064, 31.473547374048543, 31.854882163386193, 35.950644631539625, 39.59163965717439, 26.819655164595577, 48.15992786038307, 67.51346711189517, 28.734101287780273, 29.67781178412899, 32.61087586802821, 30.33624241428991, 30.613895231677642, 40.841451921770656, 29.490291110930908, 46.882003968761815, 45.80904353049494, 35.332824260957786, 39.666098010155466, 38.24692172388877, 26.647235616560906, 22.636906293130693, 15.628111285548057, 8.600787001271403, 4.017745299685386, 1.2543238483129011, 0.02040072607116834, 0.04241713923552344, 0.0932007170312347, 0.08981082393156906, 0.05461422809129281, 0.055959378894899166, 0.06263842453218757, 0.03281669007734426, 0.03330829635923428, 0.011671747892133651, 0.09036060693042894, 0.007518607617971758, 0.035633442157338706, 0.04619253927000588, 0.005376029190712519, 0.1082127997952123, 0.022474070259880637, 0.023289103541643392, 0.02409158638798662, 0.02021988335576269, 0.04398531738608595, 0.04328233212412846, 0.027620108843210246, 0.09982154764715703, 0.011010662851584776, 0.009249261047150339, 0.018602032064189835, 0.02312696869334867, 0.11516546905641595, 0.06481839283820122, 0.03390842282603826, 0.017706643820049304, 0.042600303197339665, 0.04863398487589533, 0.05938635831097922, 0.06351847186564438, 0.028047436517813516, 0.011423524870957819, 0.01657798946384461, 0.05967685502142676, 0.06461252203030933, 0.008902952916199162, 0.03376205023678561, 0.036198236649074865, 0.043931652926990104, 0.03491476358425233, 0.03680733400547216, 0.11892706801694249, 0.005359737852197742, 0.06714529297765225, 0.11905691992010801, 0.020645180897366618, 0.020475389000268716, 0.049822106807222294, 0.06320513807417405, 0.08451140305447964, 0.012410298785975864, 0.05656132865096292, 0.022325853313950282, 0.03874530279708486, 0.07958649192005396, 0.06269354455833955, 0.029245339476713733, 0.04612582833355954, 0.039628494921470844, 0.08687420207406245, 0.06548665133455107, 0.009021735806468754, 0.05294648915409081, 0.08205236040896947, 0.0769105161570253, 0.017497480749302817, 0.002809308578200158, 0.05664837922179892, 0.01988479841290222, 0.042113630521682, 0.06973977230729596, 0.058857822760699265, 0.0395238243283764, 0.042679685228053606, 0.027766872137304277, 0.009127831323102359, 0.03699193821258603, 0.018774049446707772, 0.06578750172329527, 0.10397264103014624, 0.02347625307588568, 0.04327314672991634, 0.040722188855251, 0.04136524305889203, 0.057774880870936386, 0.07717713773731263, 0.03751047248501451, 0.02438699180680898, 0.04451113332423472, 0.0018270732553285218, 0.05072715925052763, 0.05186352045125058, 0.04210048445290135, 0.004897603451559741, 0.016160684134510737, 0.008119479584087047, 0.09146751971134255, 0.023547290493884397, 0.05811173739212175, 0.04927912666913002, 0.05420496093950445, 0.05760020133288157, 0.02315946039743722, 0.046204444276349205, 0.046228974411684665, 0.036416640655407985, 0.07641098852599822, 0.034613989804300575, 0.08746920724309261, 0.0462755142530847, 0.03379920550111321, 0.028039790960329197, 0.035196300896425406, 0.023299901550936124, 0.03189726582457943, 0.023345114145007347, 0.03076439606957138, 0.03028897914074121, 0.03260686625576308, 0.032639612684086446, 0.05008004095044829, 0.042314502605867964, 0.1646918506031075, 0.5081142202740716, 2.595940289958831, 4.897835687283547, 10.259492628036007, 19.148662090301514, 25.742927289778187, 35.8817756560541, 48.44027534607918, 55.562613164224935, 56.49079499706146, 61.24067152700117, 59.20273350131128, 49.239928953109256, 49.363287495028594, 41.326970746440274, 48.34366736873504, 45.877331995194965, 39.29165286402549, 32.96034336090088, 39.15950821292016, 39.296249881867446, 36.64954431595341, 29.901759509117376, 34.789050394488925, 40.42180145940473, 38.45416799668343, 29.567963846268196, 57.60495208924817, 70.30102499069707, 30.267396973025416, 32.060553604556674, 35.57874118128131, 34.82850159368208, 31.027664099970174, 44.64703352220597, 35.93963846083611, 49.71126448723578, 50.27661138965238, 41.120304984431115, 44.35287537113313, 44.31007054544265, 32.45249056047009, 27.33970653626227, 20.28716141177762, 10.698750038300792, 5.384924440614639, 1.8165626400901427, 0.16429624279900906, 0.07210670820166988, 0.07193343443495613, 0.06643310699972414, 0.03449378294810172, 0.07073014013228879, 0.06511656191921042, 0.03251550644035301, 0.011192700664152302, 0.03021039575668833, 0.07452926207934657, 0.02163427510118533, 0.08636796351281867, 0.015713214093158324, 0.011058333630283034, 0.0936525327063376, 0.040818076250293565, 0.0590089910603579, 0.02240701649908818, 0.02644534557006292, 0.027470095421097455, 0.03799300828588106, 0.05280655553384174, 0.04218496479875138, 0.08190836652272171, 0.028712033113885312, 0.007465262521779346, 0.09472104149960703, 0.0696658448226029, 0.04755697250666638, 0.048489516015134515, 0.012905818819549057, 0.04383581915810224, 0.10262625682498179, 0.0971043793364398, 0.04352255431454509, 0.0314082355133348, 0.014804283329736323, 0.021933767599083727, 0.04159143051853584, 0.04112944885667774, 0.042986932450965534, 0.04584265925410775, 0.0526666104222738, 0.08687326744679483, 0.02327137435185573, 0.027136000646879117, 0.10302244685590269, 0.019634507911940737, 0.1393207039443716, 0.08546226372521731, 0.012928174222789466, 0.023936865355579123, 0.0342907696481674, 0.036915988255772865, 0.09259174607934491, 0.027012482375627565, 0.03636714754505985, 0.07374838099724824, 0.04716442522382544, 0.03496037262882437, 0.24288384033547294, 0.17911938529822136, 0.12236181556457475, 0.22060687683763044, 0.11835674620083264, 0.17908477344580237, 0.09146331388863826, 0.15780963844829993, 0.17931256202920792, 0.19321950933625623, 0.13467160744532464, 0.17295947148194238, 0.16357276468507706, 0.12993588172380002, 0.13953401346600827, 0.18072964082802498, 0.15271483199490657, 0.10787761334570185, 0.20144306483768648, 0.09963452260220244, 0.14507492823946863, 0.1637791487718782, 0.20631366799915993, 0.13554985064171976, 0.17966837922651924, 0.14899711455068282, 0.09963085304104513, 0.11873202203142068, 0.1389384720354311, 0.2682334599235366, 0.30116132851089206, 0.1873635179212978, 0.12665337882936, 0.1949056075705636, 0.07934381058740039, 0.12707186201887746, 0.1114410023775793, 0.08144750334923306, 0.11147723833639776, 0.18380952878825127, 0.09413603377798874, 0.15198666542287798, 0.21839816874313742, 0.1514205111250762, 0.1553300416637813, 0.1844531192534393, 0.1364804789303772, 0.15825078251861757, 0.18452278728927338, 0.21159239684141454, 0.1016413895112853, 0.1829084255281956, 0.18674762919545176, 0.18221070329027791, 0.19784968346357348, 0.13160406882243772, 0.15228217617878992, 0.19648443817371325, 0.12328692035929811, 0.15181337633440573, 0.11096985064326756, 0.17015848549142962, 0.0927296802101116, 0.07679099111907906, 0.12836972987579723, 0.2230347014002262, 0.11263881915158803, 0.2599999146355737, 0.6439276051617439, 2.7528792235159107, 4.467785060405731, 11.242846519716325, 19.746441110487908, 28.16860337411204, 39.497126225502264, 53.49588101910007, 61.59684235049833, 63.982357286637836, 69.31397622631442, 66.75588484733336, 58.39747874967514, 57.04517495247626, 49.27199825163811, 58.8525874383988, 56.42612295766031, 50.3119872462365, 42.889337078217544, 50.60742016761534, 53.0261811133354, 46.80986373655258, 42.975087934924716, 44.051700099822014, 48.679881172795454, 51.241820396915564, 37.52955552070372, 59.650499513072354, 81.1911641397784, 43.18191059174077, 42.75700415334394, 47.29661418545631, 44.20675923747402, 42.21501104293331, 53.67759658444313, 42.08600428796584, 61.534327614691954, 59.945391147367424, 50.277674351969075, 52.03793210368003, 50.90033100497339, 38.44643308270363, 30.81491081945358, 21.403389515415316, 11.742348594050254, 5.654227512498056, 1.9599291922584658, 0.27905625982149956, 0.13899536172468818, 0.12221178490548365, 0.1809331750677478, 0.21009539975033653, 0.1716284396787805, 0.18613030022430807, 0.08458252665736983, 0.11528636539174665, 0.11624717754462074, 0.3660495272807537, 0.07059080406062065, 0.13739627575682056, 0.1014439839749567, 0.14710861588678054, 0.19177848262892616, 0.14453407016492661, 0.17826579481122956, 0.08869716957692178, 0.19717426970601085, 0.12455577646652538, 0.13969902880489826, 0.12207887631150023, 0.20570398458550054, 0.25642946993391363, 0.13321461546565258, 0.13694301217554078, 0.1721670607765836, 0.21163719766322645, 0.1406712863113611, 0.15034015861249742, 0.053898127404071634, 0.1299040584314254, 0.2053643011998746, 0.240928967813811, 0.1023337644554915, 0.15262356027960777, 0.1483176098836045, 0.1066747633740306, 0.2021669719608561, 0.18288040203192543, 0.12599409888348273, 0.19742349342953777, 0.1387511941814615, 0.27358663719027276, 0.14589451974438084, 0.13695327775372615, 0.3326963266778377, 0.09119745073539597, 0.2924629517139927, 0.1758107281620464, 0.12557924695072636, 0.14383142964253504, 0.08695131648452052, 0.2378028694299921, 0.19255370232126406, 0.13404137755353607, 0.1789009583092505, 0.193535459317988, 0.15388380555856615, 0.38708777257031013], [0.08252797843587976, 0.048286020079807895, 0.014357704823205789, 0.010840147001398428, 0.1434578545271389, 0.03226950794698731, 0.08693413313237891, 0.029574529372996865, 0.05011493242495964, 0.05494084967780979, 0.05429224899759697, 0.014835894990321851, 0.10293514347605168, 0.011030005614062952, 0.040654462852304986, 0.07530452773695992, 0.06766760406354744, 0.002758574884219636, 0.044780271503353314, 0.06416245686611341, 0.046913795728957465, 0.005602774936931149, 0.07789689266393263, 0.0480228420647402, 0.051845375658764, 0.05335546902290756, 0.02374544105071935, 0.03675060902511881, 0.03195391994179978, 0.026601958839643388, 0.023176272196935552, 0.0870601469350438, 0.0709002576167545, 0.08044361407237668, 0.013482508741529479, 0.08855653115578237, 0.07502122076168176, 0.02986886418394504, 0.07657234962548941, 0.021458291298439427, 0.03826921362610113, 0.035016182134108204, 0.03709852785593079, 0.018073019624177008, 0.018977960984733318, 0.055229906142959674, 0.0560985004619485, 0.05201365070177182, 0.03700738637557915, 0.019372429233044386, 0.029370334382439335, 0.05077632677350795, 0.031705718945651766, 0.010626770447068399, 0.022506069752477834, 0.023919157233209382, 0.04958893262570904, 0.0677107654572014, 0.04358713935700156, 0.040190064183045784, 0.060293230213104725, 0.09122309935910088, 0.07753513828520814, 0.03979769310042743, 0.06063484030986025, 0.03754513030270896, 0.007763567104590156, 0.056077095965344104, 0.06123546090337539, 0.09980182088310681, 0.4193027197353302, 0.8947744544955992, 2.8465741055627025, 6.9104984498793085, 13.438620721140216, 17.760262681591897, 25.318979870888498, 33.52715330739176, 37.73360898417812, 44.300845130797356, 44.43155419441962, 53.417472839355476, 46.17509480445616, 54.88716533107143, 47.08246846352854, 45.739950979909594, 47.64855669390771, 44.49535939001268, 46.7781670631901, 45.37462142206008, 44.10165540633663, 45.66246063478532, 38.35533211308141, 40.34562903065836, 42.185322623099054, 37.56641403321297, 58.71866203123524, 43.598768326544, 40.89444314279864, 39.59482069938414, 34.29773822907479, 42.11484547584288, 42.280173378606, 39.77492809295654, 50.38343714129541, 35.57291646157542, 37.04282076128068, 31.59974963434281, 23.311801072089906, 13.517572149153679, 5.91048478118835, 4.039719888279516, 1.2469754103691348, 0.16296591579673753, 0.0721069073845302, 0.0515858480526555, 0.0755143668802996, 0.030739819968960462, 0.01074837732894887, 0.017817332033788966, 0.028679102824460116, 0.04308173583159524, 0.05818588704231286, 0.030751905005965984, 0.039184918521993586, 0.029224727881110968, 0.05849891439861348, 0.0715738021197819, 0.020156983706739642, 0.030819542908800707, 0.04174672037122711, 0.02900744810880673, 0.053827513249651085, 0.05015401056997719, 0.0376344982895159, 0.059043047499031796, 0.06909009910398914, 0.046281367164826205, 0.03855700987661558, 0.033821866381913424, 0.028477056710530194, 0.046096559944412405, 0.04433850690181698, 0.017187439220687075, 0.023044003286368908, 0.01394206765032704, 0.012339589828174683, 0.006486988352281192, 0.06079403338052573, 0.019260622530935273, 0.009602370123649317, 0.031143197819830912, 0.04439056640671146, 0.030904502059603413, 0.011950543567147708, 0.05388067592115653, 0.010986102072732344, 0.0684239013841556, 0.022801620728005807, 0.07695836600877586, 0.02232521554575332, 0.03870047516219559, 0.02097912628443972, 0.06949745869684605, 0.0826995131830054, 0.056040829363008665, 0.014417859004630197, 0.015638045546027924, 0.03368651013701193, 0.07732964286039914, 0.008947256738470208, 0.045359456956747084, 0.12228794936691562, 0.021550269729848352, 0.04474306261287101, 0.06519388317340805, 0.061226015039269006, 0.0702884214960279, 0.013524215525737213, 0.03053758233304947, 0.02687539860245682, 0.01218162249818805, 0.06576198333453748, 0.021088906683989113, 0.06120975865351577, 0.029305059860851017, 0.05169086721575549, 0.04963027073010322, 0.09250585996215382, 0.006372948503872801, 0.08584467183438041, 0.05632928061869837, 0.061450536257677504, 0.01960209090142481, 0.012846805151521921, 0.07542259720785004, 0.07977822840574288, 0.007024677216841449, 0.033823390896882743, 0.032260820509925965, 0.060126851237709486, 0.031231554570577802, 0.08221751364368586, 0.014530107164905678, 0.02913191632908439, 0.018550374755455602, 0.04982014179169651, 0.08239863215074425, 0.022942686243163004, 0.04202047039964988, 0.027477582015337485, 0.022491198070647738, 0.0854008387954485, 0.03584714238381675, 0.038574365598540154, 0.06054075705187936, 0.05015072788322165, 0.06111416620232406, 0.040886499393250675, 0.02377289381148594, 0.012974912289439911, 0.052887213100949605, 0.03165708576899863, 0.040842261646063104, 0.05489015380942053, 0.024279768225706877, 0.04819925679194351, 0.023874478985465342, 0.0571028953568349, 0.02253949799905381, 0.029642973583371892, 0.03382077470662133, 0.008016596369880943, 0.03889535643881367, 0.019515963466537577, 0.07497798275923537, 0.07178184861737875, 0.06643622497757597, 0.04998518394366388, 0.10721122410388724, 0.02276138962066222, 0.042500501093004024, 0.05088474353655212, 0.06597579081332491, 0.10213481142155587, 0.12813939788048306, 0.5690496198592648, 1.6776857308803068, 4.4136029097341725, 9.87664576499693, 17.59837861984007, 24.760071539109756, 31.768925382244973, 40.522170989744126, 46.72758025507773, 51.127793173636164, 51.348324514204464, 57.66108120641401, 50.76610357530656, 61.47526848700739, 51.741702941156205, 49.97162357453377, 49.50144513960808, 50.27652117513841, 49.2727082006393, 47.20037098853819, 45.019372355553415, 48.294884850901944, 41.63579071721723, 41.26118475391019, 41.50575237889444, 40.882460301922215, 66.0932239409416, 46.94480503759077, 46.12604164308118, 45.62284469604493, 38.5511407544536, 47.40345170420986, 47.398984124583585, 43.512589931488044, 55.45250046637751, 43.6744975274609, 43.34021745189544, 36.24923113853701, 29.196878210190807, 17.12824921454153, 8.944622951169169, 5.005215473713414, 2.008282700853963, 0.29144145007575717, 0.017356453538541834, 0.07646677504864431, 0.04683910981721936, 0.03615833878997834, 0.027197281935162125, 0.037579282502373385, 0.0445577153004706, 0.005885125738718818, 0.04112107551566536, 0.04580217150730952, 0.0458551426568339, 0.020460674366463098, 0.047413338681743036, 0.061160560487018484, 0.041791827628208746, 0.07508367224926911, 0.021976375494212396, 0.019430247803909645, 0.025821259703427076, 0.03673805284403986, 0.07387896834482109, 0.05305993145391826, 0.08299629564487165, 0.06577488425518237, 0.065344067050084, 0.018980197961472215, 0.025838741829859155, 0.028843463158174872, 0.04233013462996291, 0.04501568266160546, 0.05660205388501768, 0.06167392366595807, 0.03117901817595046, 0.07105824026849962, 0.021119203546174595, 0.01282657947271101, 0.020075215312141566, 0.03914881662856187, 0.03052562178533164, 0.039689437215847355, 0.03594615924803, 0.031228233579426046, 0.023657551613606276, 0.1422826143642587, 0.05415392416198889, 0.05930324926251366, 0.05455116373336604, 0.02010639509065978, 0.02518289778832226, 0.048890746904597174, 0.09540574024281195, 0.0415859108550414, 0.051600495653767744, 0.04963072655241817, 0.050545259333786466, 0.04085254254600695, 0.03982295101929096, 0.018285494109976198, 0.08015790924189553, 0.027785784932934952, 0.04240257207364325, 0.0342430385400451, 0.13657605605981044, 0.21356959316519, 0.1436823948977455, 0.20662304494650136, 0.16515355647331284, 0.15853337703212617, 0.1542058229566582, 0.14607522456396013, 0.15661287121474743, 0.18772097454676706, 0.2167082707127256, 0.07710760759730494, 0.20185986263377054, 0.11237798919600826, 0.1392817407125427, 0.2032543418388213, 0.11711532370217385, 0.16214540498631616, 0.10495064419604118, 0.2479290196131314, 0.3275955600603935, 0.20276065945865648, 0.20841368353895603, 0.2114966052073625, 0.21325027239659142, 0.16342063494507345, 0.15607668627654353, 0.09538824279462138, 0.09877786010263429, 0.10966060638067224, 0.2141099609434605, 0.3030827995990553, 0.1673755485324129, 0.16372538472135223, 0.15658497029254514, 0.1620932037551557, 0.1240891063465707, 0.16583761170266137, 0.13412377797067165, 0.16672025224374187, 0.150214949202153, 0.1892535794045656, 0.14644221132320745, 0.07814725019758748, 0.14288809961609303, 0.1620362681006232, 0.1806112189566897, 0.1376254586202483, 0.13539629597817698, 0.10784479413902569, 0.10932077743834066, 0.11648469544466465, 0.13534127554345515, 0.1319345744747308, 0.12291156025903842, 0.14940882552294962, 0.09411808433792285, 0.14215781864139343, 0.12283861336688842, 0.11967625604161333, 0.16805372020650297, 0.25052092488734956, 0.2113875602522204, 0.2172229439020157, 0.10575225561737053, 0.1836562958816367, 0.09117867392037185, 0.1645307729561483, 0.17362071261290582, 0.3605097309956628, 0.7924767114943074, 1.7225978499458683, 4.351576509014253, 9.698000434906254, 17.84290505993751, 25.98701442441633, 35.46537683856103, 46.12200160180369, 52.11594412403723, 60.63566553977228, 58.72225884468325, 68.55972797639909, 61.18062788440336, 70.70104399035054, 60.688594002877515, 59.39484726998114, 60.905881543313306, 59.96968238584457, 60.40538710932578, 57.51401585917319, 57.13300074300459, 60.10626715998496, 52.22377008007419, 53.92663571142382, 53.5055967300169, 50.66163124576692, 72.03678361831173, 58.206274970885254, 54.98465191933417, 53.17168927961781, 47.3659695348432, 55.525346725217766, 54.26913315250028, 54.43970134181362, 62.5053652640312, 49.99503227972215, 50.633680435919, 40.43751055194486, 33.00627823798887, 19.51581947265133, 10.810491500362273, 6.004122053423236, 2.0203987797421794, 0.358169271099952, 0.2032345308050994, 0.16404845932077977, 0.12016628418237933, 0.2050165585692852, 0.1230908171724408, 0.12334806183653495, 0.18638842588951512, 0.12813854752288711, 0.1321915203645345, 0.1526388973598519, 0.1718767440967983, 0.09729343451439373, 0.18641629616820043, 0.2305945489675768, 0.11259431710406659, 0.11667669240024783, 0.13221251117365976, 0.07071582960986322, 0.14070052022655166, 0.1720978523935041, 0.11952876113355161, 0.1540845359164861, 0.12477824073885718, 0.14396482087191076, 0.19359115391008316, 0.11742981811684948, 0.09733952236391845, 0.12496612380228697, 0.1243163663293085, 0.1506351790721378, 0.11818538765392958, 0.0957651427316089, 0.1477720633509659, 0.11323498877426309, 0.0985756971602959, 0.09901522478509335, 0.17192457862679036, 0.1125524580598839, 0.15834075188444507, 0.16301117627130401, 0.12630931342080717, 0.1130098048898001, 0.07481901185406793, 0.3576012322258565, 0.18268351743538536, 0.2440417975547814, 0.18697325741091084, 0.1987414404509529, 0.12079734911000538, 0.1697474027112607, 0.18616256784767876, 0.3264523730162652, 0.17569363928369938, 0.1684685874610178, 0.08904632947017109, 0.20932684502293988, 0.12562242366613882, 0.14376520900236023, 0.1968298825405298, 0.0753317621626681, 0.12721124405582107, 0.1795750237520664], [0.05994196740850326, 0.043249953418008746, 0.05310310816933071, 0.0223166928175957, 0.017605589161957466, 0.04645177959314278, 0.05471249035890064, 0.03257443392348867, 0.06265035635160823, 0.028742540650249972, 0.09951586324361064, 0.02820215180456158, 0.0459189654418057, 0.02892318801323493, 0.05703899596307067, 0.04548583848161563, 0.079116910665987, 0.019528184484149662, 0.01992879292717384, 0.039947486272261995, 0.011572066446646087, 0.08637288945817179, 0.047933232760237116, 0.01925031290269427, 0.035853114039186514, 0.05701780980152469, 0.028432912809113343, 0.01342401697090076, 0.03725161137540014, 0.0643684157741166, 0.017382557984561692, 0.020153281586845557, 0.02195114821886584, 0.07040932549223786, 0.012170063189020561, 0.0786334325769736, 0.060185564216226346, 0.06332104717711769, 0.016979143744514837, 0.02502510282811859, 0.05551429713265069, 0.052521494217216975, 0.04730646175542667, 0.16667877624352134, 0.08644652582945363, 0.05583902265155508, 0.11188026953248248, 0.06949785706256667, 0.030952064628382365, 0.034820193860439524, 0.054342439247956204, 0.04013597454515196, 0.07538879740863078, 0.04129321547225118, 0.056516474202996304, 0.02903334762630684, 0.018072621258456382, 0.06222603940254739, 0.037204067958819295, 0.015298517293206628, 0.0437434442761925, 0.005173348181415349, 0.06004712829786924, 0.02739718108768425, 0.022901675641356457, 0.05286416917618725, 0.045793729218383955, 0.025847572908406297, 0.045775373751718196, 0.013507222737966767, 0.033271041503476526, 0.09296737431037812, 0.3185801760804269, 0.34154602116154087, 2.2333892410801304, 5.374222743895746, 9.355567712937633, 14.497217439836072, 20.50094823683462, 25.892693188882646, 34.91708832402384, 43.672085269804924, 40.0771035686616, 49.19848126749839, 50.333368086045795, 56.34973479855446, 55.2069640159607, 55.24349304937548, 54.02770734602406, 52.624946178928504, 48.38072984449325, 49.45431001724736, 53.62466027659755, 53.21600421782463, 49.605572300572554, 47.06333906419816, 47.96314254883797, 47.088097064725815, 45.1709052824205, 44.88870251563288, 47.40774669954854, 42.01428374936504, 42.252657951847205, 44.38245396460257, 34.73126211474019, 21.61041025192507, 16.87879627750766, 14.071323544748369, 7.011494578853731, 3.513587126808782, 1.2433876674021445, 0.32944370121244465, 0.04825511609294242, 0.03602651421040778, 0.02573698811653641, 0.017811092247645703, 0.053591765012712254, 0.09846650664844821, 0.03597391461352668, 0.03828253589510437, 0.036893342696731134, 0.013241433320687184, 0.03030724076163625, 0.04602768864001959, 0.023585807479497407, 0.06199617855130665, 0.05418291675948328, 0.06491553278699999, 0.08310335643228986, 0.09968832495712465, 0.05024191149840913, 0.021967536754786007, 0.03487716398892864, 0.015627517582728498, 0.005909825849812479, 0.0130894883993953, 0.020469346481765953, 0.04424445045691344, 0.013067656808773117, 0.04143739705004039, 0.05943989636556757, 0.035811408212588686, 0.04447400104254485, 0.05225737008356279, 0.10369221454546337, 0.04415946832347301, 0.09375115120483023, 0.04974683866866174, 0.05652857456176032, 0.04723675924563601, 0.04051304302148281, 0.06671212388262635, 0.02139902482139728, 0.046202709087200707, 0.05213529014238908, 0.047125691818373824, 0.05507406470696292, 0.03335032777319993, 0.03109197718121352, 0.008193728825708312, 0.098619525050444, 0.033901171803834944, 0.03437547982039471, 0.03566053868722051, 0.057225565185710314, 0.05413432380244617, 0.05600975300636023, 0.10768742435761999, 0.05986066249709937, 0.0671391795960165, 0.054898228376142444, 0.05207605622408371, 0.020715913795415434, 0.046515196351514715, 0.014217003199812627, 0.07878166292944262, 0.0507373558807998, 0.03582628947051783, 0.047052495947648446, 0.016541809046400652, 0.03909493000396798, 0.050437865298121214, 0.011375113859802726, 0.023613053396524444, 0.046690362355401444, 0.07403508174203097, 0.04711468696534153, 0.047631091513340516, 0.016610481167933153, 0.030778231617483883, 0.013018089962462264, 0.0535038985582369, 0.0719802500680089, 0.02351121732874984, 0.07280174147097335, 0.1432156328472399, 0.0673138782862694, 0.08597787920265429, 0.05916336926841929, 0.004688089416782943, 0.04112055840631647, 0.052983820618640994, 0.07069742051704277, 0.06798883239107748, 0.01724757520752328, 0.0517831463366747, 0.04422934703348626, 0.05603046419339315, 0.043993441748522946, 0.033377638807700526, 0.029541817418630087, 0.10056002576264644, 0.02398287851153122, 0.04612365264385458, 0.027162650930545023, 0.04352441973864071, 0.03299737574472543, 0.0564144236306029, 0.03995443468973522, 0.05720057156718066, 0.07874434678665093, 0.10439362166629684, 0.055522597695310275, 0.04911215780603309, 0.08204406367674952, 0.046858794446433746, 0.04413252118073645, 0.007972130232730941, 0.06562199608813371, 0.009905217129046158, 0.12198366690427066, 0.03164704618675094, 0.06955729016373235, 0.03993274291015921, 0.06166793668882982, 0.01462834549226588, 0.024632825591270963, 0.07020577593075653, 0.05758987446766227, 0.019881000532017603, 0.07603810288973394, 0.030288224544135794, 0.021423572193711035, 0.07204034200478947, 0.054533888450673515, 0.016788740251814167, 0.046150883239123135, 0.03710263791764456, 0.4822077620173655, 0.9079167234801477, 3.655995394914381, 7.074273094054192, 13.882972309666297, 19.15440640141887, 25.213377898739232, 32.84647695479855, 40.711280222862, 49.71978387525005, 46.91792895717006, 54.93922302799841, 57.187953149118734, 62.02754605200983, 61.82388482555267, 59.97232606334072, 59.55009468140141, 59.702859232502604, 54.051767164661044, 54.80953770299112, 59.3465393589389, 56.381400092955566, 52.68180877931657, 49.99619330129316, 54.178698985807365, 51.00716067898659, 49.45081126305365, 50.65603402353103, 50.99624472279703, 47.60279832347747, 47.25085973739625, 49.81260284300774, 40.7676564493487, 26.92139752449528, 22.365537112759007, 17.56462074095203, 9.96388319999941, 4.9591565516687215, 1.7047201769967235, 0.5062442302944199, 0.05161187588988293, 0.055742415133863694, 0.03229453986991317, 0.05379475149956923, 0.08258412501985028, 0.057504861690704866, 0.027984456429558418, 0.013701235462400704, 0.05018569979696505, 0.017232236212059375, 0.014271653997110985, 0.03558614771933325, 0.02854286749366551, 0.12932696439806493, 0.021936364637147036, 0.04265069263055921, 0.08009760280049617, 0.06970552051620138, 0.07753516892872511, 0.06029819446285406, 0.032214257685888203, 0.06445774928696694, 0.03679409983658022, 0.06483628865211241, 0.015331065496279588, 0.01929546995539098, 0.0634394422353756, 0.015608842274354351, 0.11039615037941164, 0.05016143013152385, 0.03551521946886375, 0.05319750169292093, 0.04428257099202564, 0.10125658354691922, 0.03812741075131682, 0.051553270163675474, 0.059408371847483425, 0.03637346777043516, 0.06217674164461994, 0.056168900111750256, 0.015019775244347272, 0.011733229320886876, 0.07049583980152685, 0.03467705799266696, 0.1131825500558461, 0.0890256067918193, 0.0352565613725493, 0.028236893891927697, 0.06872210110868178, 0.03430395785178389, 0.08357159703248933, 0.011433490717242803, 0.06123719609252388, 0.07078669274285918, 0.02780462303499301, 0.01192178845690984, 0.05256613033012517, 0.02075057161310988, 0.07380035240203142, 0.05675921299224419, 0.031080131546684334, 0.017568671384886388, 0.017489664737255346, 0.056581476763371504, 0.12122284966490923, 0.12995714832457805, 0.2362897385272288, 0.11565430210002008, 0.15650011839405184, 0.1053605855052029, 0.18344926828097913, 0.13746643408892617, 0.21600434316262124, 0.14625032161993368, 0.18012118315504444, 0.13254969711265258, 0.16049011880832334, 0.09879486725455332, 0.10347633096840113, 0.2087542249430572, 0.16267236622591175, 0.16217253982059418, 0.15329129783616913, 0.2240031437888261, 0.16382181986926064, 0.1998333302476714, 0.1395044577938895, 0.12670981652674176, 0.14844150162271916, 0.14337891682742104, 0.20417259014662237, 0.12267160619939528, 0.14119777257644361, 0.21881257634489767, 0.14695409595245315, 0.07936613438951393, 0.09403617421705877, 0.104944707014628, 0.10589276380356281, 0.20668882125568008, 0.10813392338252838, 0.1589006702265432, 0.09078094405272315, 0.16562925110901558, 0.189265928741905, 0.1831107493489981, 0.10685626492505113, 0.19247078096433995, 0.19067166943944272, 0.16520797935945375, 0.15158600143847928, 0.0946663581435719, 0.28139972278187353, 0.18319033056257233, 0.1340690180058441, 0.10172932874411346, 0.2143876065289782, 0.11348955979150151, 0.18591490694351737, 0.10638706671494631, 0.14138993807137012, 0.19731012773850273, 0.13597414077770326, 0.11305656689669817, 0.1306749267443534, 0.08591150534489463, 0.13040117288549102, 0.19045439158235827, 0.16068498093274333, 0.0936720066613728, 0.15788181925252562, 0.13723475377886526, 0.1677549305942751, 0.23636237898420906, 0.10678197737903365, 0.310249766635318, 0.3921850458268197, 0.9814772827010002, 3.306670087960459, 7.210895621007489, 14.242306524707427, 19.629574091203754, 28.34772036921594, 35.077136716535016, 45.87992860424904, 54.295515014279275, 54.09331290952621, 60.99337393237699, 64.46613850132113, 70.62797023404029, 71.08872321344191, 68.99438150467412, 69.37609872510357, 67.77756029559721, 63.87510007427585, 63.38876931898056, 69.10445890119, 66.33583822558003, 62.8988495949776, 60.34659862518311, 63.13934972209316, 61.219655467617905, 58.55400485377158, 59.03663289162421, 60.79978143015216, 57.93822019330917, 55.362293797154585, 56.18156317741641, 47.29826942566903, 31.95490456396534, 24.58653215439089, 19.23243215007167, 10.761669758827457, 5.432071820382149, 1.9910389809839188, 0.47524564689205545, 0.24067753775706216, 0.1694379185116099, 0.15183904027986914, 0.1324406521575105, 0.11913971104208501, 0.17917722493650454, 0.1375541511562563, 0.07747183644002484, 0.14400323252043418, 0.09518516820765312, 0.23980585227329887, 0.18777938109011422, 0.2222857585236911, 0.19784691022528758, 0.14502930004269848, 0.1315380780086402, 0.23354165856876682, 0.13846817065871533, 0.23192636218042145, 0.17307945617264317, 0.12207044934433316, 0.15578880575635742, 0.09089038737358586, 0.20857240163510848, 0.13938588270496938, 0.09803479312047844, 0.12002749969401669, 0.1589212167046724, 0.2060632645002296, 0.12444306195022599, 0.11345001433285014, 0.1393949072207174, 0.12767256688206427, 0.29092124573165373, 0.17620924710025712, 0.22732221972077127, 0.1628129433600172, 0.15883144652170522, 0.14861322789182588, 0.20088371340065234, 0.12893576926041034, 0.10124998752989116, 0.16422381684664758, 0.13035640270719606, 0.18450378830875122, 0.23685278250805794, 0.15345035301100823, 0.1366062246022686, 0.22290227544163504, 0.20567121134409982, 0.16710272930081815, 0.11894106444331909, 0.17584163214891188, 0.15370743679663829, 0.21921092674376505, 0.26843769896414976, 0.21250086986730177, 0.13033348135650158, 0.12283510468419521, 0.13863361500684293, 0.07136588585713217, 0.10235103973818403, 0.2335584971813425, 0.13371327741732522], [0.05665328601495393, 0.011521211615012539, 0.009746582344955495, 0.031345462268819256, 0.09424331673090497, 0.09587454008719615, 0.048503240480298, 0.02251663027451404, 0.012457379676972427, 0.06016687550131352, 0.048912247162192106, 0.06533502721257749, 0.06176225360362761, 0.07885585854490919, 0.04782784587493347, 0.020372790675009453, 0.05098629998223436, 0.05327354358028501, 0.07804312352691928, 0.06376824717247678, 0.04276387829093203, 0.04134448590658365, 0.050646340804955656, 0.019700052479522365, 0.0168496863766303, 0.03968667546888033, 0.01545463547846603, 0.03380872031313277, 0.041142100798747236, 0.08966204965667379, 0.008430965188440056, 0.0613055311353697, 0.0457798668573941, 0.04036027742850204, 0.03866869017421719, 0.01848798838534182, 0.015154683327813064, 0.05693750846530161, 0.10665770259595687, 0.055707933516391826, 0.029641259461641315, 0.005482570474757063, 0.03165084406763556, 0.0685166976144237, 0.05238522632768559, 0.03395511588502315, 0.07245752284483564, 0.02604827645324892, 0.03110661520622671, 0.00767307392614443, 0.03251599673662455, 0.030389984003117973, 0.03374525758948538, 0.014816588617020078, 0.056559195096093806, 0.025864421097081036, 0.05749728891157335, 0.014639630925000436, 0.0553222235682751, 0.02555455002302845, 0.051651953779641664, 0.05166540628359203, 0.07806475784990095, 0.05083883571768961, 0.04814696746067174, 0.031488655593186136, 0.04324496618562168, 0.0425497145812598, 0.06304349352215087, 0.012038170619146719, 0.015727922023694604, 0.039538628977513125, 0.007890558148163461, 0.10406036575835559, 0.1412441055741041, 0.4258210248043461, 1.1455537042310162, 2.8338867089440747, 6.03783090268412, 8.473256038081262, 13.853513348487116, 18.689560428742443, 23.86660856585349, 30.019216845112464, 33.76413506846274, 35.98948786335607, 35.60963376875847, 37.28603909092565, 46.34231721201251, 45.235502796788374, 46.29982617593581, 48.894030817093395, 47.344804425393384, 46.54927322941442, 43.112402269917155, 47.56777155783869, 41.271167185998735, 42.78380570873138, 42.425591330374445, 36.437277409338186, 37.282748222351074, 35.28968603380265, 31.368941683923047, 20.713246522411225, 15.679456091696217, 10.753420033762533, 6.5307708517197645, 2.829672367342057, 0.73212614343051, 0.18495997834590175, 0.027437670749702284, 0.01891011815337885, 0.03557406651276735, 0.0036462735208202036, 0.051223339077325604, 0.034729676741746165, 0.0701049357772835, 0.08913468239047835, 0.04709489891425737, 0.12506475762253808, 0.051241457056734836, 0.009444960122627598, 0.010790638569291803, 0.028830274954558383, 0.07177834759556478, 0.016442085466077252, 0.03719232383094007, 0.04693014021482199, 0.02176975392015471, 0.07166076076006697, 0.03443027042873925, 0.01926918739392873, 0.03030768892307195, 0.010554989923783129, 0.037667842266420205, 0.04672057686313506, 0.02044560733221231, 0.02135024608803853, 0.061762073572965405, 0.07215828124073244, 0.004074530555836616, 0.019286983616409764, 0.03580317659784229, 0.061605918040919694, 0.04430902783849067, 0.08952092093926284, 0.04946086570740708, 0.012424918616400852, 0.02751908291341557, 0.060273928627852476, 0.045238380590754176, 0.06176931310384985, 0.05581474149479501, 0.045138900243346734, 0.031638563678209344, 0.02251493338976176, 0.05901339606592252, 0.10017734186183061, 0.10942801442598143, 0.08349295810706193, 0.042496758753493916, 0.021313358954484427, 0.06884755566716194, 0.09956608796792646, 0.008502247754574544, 0.04477299366807265, 0.039745112655744444, 0.0359368895841462, 0.036159449617468545, 0.09319622009511917, 0.055389535883742, 0.030839936169345054, 0.049441985470513185, 0.07785326395664485, 0.03165526631017847, 0.04313438522419141, 0.07073655228821502, 0.011609983968458349, 0.021329686203370654, 0.05864551298380379, 0.06523857674291057, 0.047179693356156356, 0.0325970794825304, 0.022691564536803675, 0.06648865603511372, 0.04990412034995614, 0.033921959599660295, 0.04840877417835498, 0.032206727041592526, 0.04982106109720565, 0.04719574672860965, 0.011923462359024393, 0.06835837788399189, 0.027729739855614402, 0.021580334850436738, 0.06616822443902493, 0.024330266826455633, 0.02645588119424159, 0.027400854479281173, 0.026305071040687543, 0.04286181880161167, 0.01901909990626718, 0.062454015677494396, 0.04231888079835523, 0.03104366001582915, 0.04743854297445186, 0.0218647871271617, 0.03111885346081709, 0.015851816635638956, 0.034111014777614225, 0.020113577164949912, 0.04594155354425312, 0.019054790027439594, 0.05894329902085085, 0.030673792765986536, 0.0397732932000391, 0.07295931043523936, 0.040827660010226315, 0.04565217532217503, 0.00741257721881172, 0.07900660166576987, 0.06051139290174169, 0.04292449628513667, 0.066938464559855, 0.028258294558092475, 0.05400334575003194, 0.07249691508590214, 0.011742790098181896, 0.11903062012166747, 0.049331293426333904, 0.07572001552269345, 0.05081227161891518, 0.03371029716706084, 0.10489193121752433, 0.054943592272578716, 0.02466395748929391, 0.03734592445975831, 0.02272222337553338, 0.0275274466783289, 0.05462155572228855, 0.022898950283565832, 0.04818608774052513, 0.05005863645384389, 0.04038346307953039, 0.07245068167967182, 0.07659764584874915, 0.052874457737010334, 0.08743516229573758, 0.024126194409965992, 0.019475176945448886, 0.16133997078624465, 0.837652977676161, 1.816316266213694, 3.746833810883184, 8.626943326765492, 11.444516162718497, 18.46371231540557, 25.664275923082908, 29.196644829165553, 36.65045430583339, 38.7925979398912, 42.418550675915135, 41.80340143942064, 44.41047537711359, 52.005968709145826, 50.040065011670514, 51.95533091022123, 56.41372042317545, 53.41039296119444, 53.02922095021894, 48.69126781340569, 53.84097506923061, 48.62477971661476, 49.0973037289035, 50.285075864484234, 43.05481010867704, 42.958935614555116, 41.676559832788286, 37.3587009983678, 26.402358124333045, 20.5886249772964, 14.205967726246005, 8.103449094680048, 4.00771898608054, 1.1326487386418929, 0.22510860866356283, 0.11582308659149755, 0.07779265874095502, 0.031728601991950024, 0.02101162564940751, 0.05322213141968655, 0.03758568316698074, 0.06038670826162543, 0.08342659191018151, 0.037522496234986095, 0.03267620104335008, 0.059547148674966834, 0.03947444996165653, 0.054249191025812785, 0.04122213017375719, 0.0701527396637586, 0.05679778551923172, 0.0747375920294754, 0.01248239149009028, 0.04468106311715899, 0.09242123789003781, 0.020960569719693834, 0.04494219950790848, 0.0722189630652147, 0.02822550599493327, 0.05652250331496039, 0.008196715611003099, 0.06771340846054016, 0.03858203030822258, 0.029473723693480416, 0.007954674440571258, 0.0467756892284078, 0.06036029354999624, 0.16890269884419057, 0.026740628414817398, 0.027985641950621244, 0.03540102257243088, 0.06557722590983876, 0.05725866018403923, 0.02787263823613044, 0.07439123601802895, 0.11179062192358317, 0.05996428738017717, 0.039753099122355064, 0.03923114043690505, 0.07177207333546493, 0.013680636315726706, 0.059281335317439614, 0.08910765480850974, 0.058048573442764824, 0.03695484423529237, 0.03257875848982123, 0.026963263141712355, 0.025049477830649387, 0.04769838084616969, 0.040218171948987635, 0.010721852492180564, 0.06553181987856666, 0.06328453159620685, 0.043094586956525044, 0.046149691972400875, 0.09195523426657723, 0.09776581965026357, 0.09427080396562816, 0.07022110535012138, 0.0492778511327361, 0.06598916670848286, 0.25642626768639015, 0.135979748541309, 0.09289341618216808, 0.08910201640138704, 0.16807106443710867, 0.16778022681753482, 0.21618616647056996, 0.10761079258255421, 0.15929091541517168, 0.1498469971721211, 0.11297808884973488, 0.13543437054801372, 0.19189223136392333, 0.18058837421478766, 0.3117418607636806, 0.1403303771850563, 0.17500852685301535, 0.21701455266485292, 0.2203311617936819, 0.22385390986117626, 0.09425810222784359, 0.09174969287649279, 0.2060204708287793, 0.20837174788598092, 0.1390411124955262, 0.17191008424326298, 0.1776583330525506, 0.09066597723792638, 0.15712455666113287, 0.3364347438177755, 0.12118342678032576, 0.2534680957755735, 0.1053043699733192, 0.1098001799395969, 0.1091923351369558, 0.15271740605033216, 0.07196367192532747, 0.14036716472718025, 0.1940764246448394, 0.11794571704681843, 0.15655112452805042, 0.12836458176494608, 0.1160648869230382, 0.07461664206799, 0.25356877505058245, 0.22138804137226076, 0.22378845530892574, 0.08431856340217976, 0.12562316677142538, 0.13437318555530042, 0.10687520261853935, 0.08425518494820403, 0.22678857819447595, 0.08499219983575806, 0.22331317436070214, 0.14825871304398583, 0.1412139983186799, 0.17361865949726876, 0.2399742843643312, 0.2155105688519055, 0.12905711758761637, 0.07424734172321136, 0.17435457887909106, 0.12453664725105609, 0.0909217510132059, 0.16572827563410805, 0.1345289618738236, 0.0911630227440788, 0.19462335013574172, 0.1847037525787469, 0.11513227446665687, 0.23764002978080706, 0.15105412191440984, 0.22535608570662238, 0.35150421422816097, 0.697231267488772, 2.036176023464049, 3.9653149775920378, 8.905463968553851, 12.65133140548583, 19.832797973386704, 25.818452527446134, 31.925012180882117, 38.69069084044426, 42.01331884630265, 47.62130798832063, 48.74633396825483, 50.27830585356682, 59.81545871303928, 59.51939821243287, 62.873609142918745, 66.45423104686122, 61.420398450666866, 59.671766604146654, 56.52023630757486, 61.49211898926766, 55.58969713026478, 56.17480101123933, 56.301548480987556, 49.880322564032774, 49.21707722448534, 45.81152639081402, 41.84126407869401, 30.920593200191377, 22.760447225263043, 14.99831788001522, 8.452840101334358, 4.383955184490451, 1.367989355517972, 0.4359292178865402, 0.1919324203364311, 0.2867614802333617, 0.07779592227551245, 0.24897514331725337, 0.1533155981451273, 0.20114776858639336, 0.1711590116422984, 0.2731627147764929, 0.16138553769598085, 0.2816402743900976, 0.09730987476124879, 0.10169588134533937, 0.08226126492504152, 0.10882317268800352, 0.23970478995432778, 0.1087904530727575, 0.13425484029275758, 0.13381596384269576, 0.1624102875470154, 0.22197048269933273, 0.09329922061653868, 0.2336063163895761, 0.1590695313268131, 0.06904995609675685, 0.10756993711355234, 0.1459772112749277, 0.11348523139472931, 0.08130579240499966, 0.1711628267601613, 0.21557703464021608, 0.16008542520144295, 0.11619995588496809, 0.22727541174859772, 0.17097344982527918, 0.11540150840676601, 0.17582439517061557, 0.16375570648139523, 0.20726965379811105, 0.10533852217298363, 0.12275135595231287, 0.18449182201537395, 0.18533435019273914, 0.12608556978164182, 0.14352530090799256, 0.15956114526958237, 0.13975709826955873, 0.12942114724747597, 0.2146980866429306, 0.21085241719359354, 0.19056185839637635, 0.14132463673670448, 0.14615417758543647, 0.17546911423485126, 0.19509133792692618, 0.10824063943038065, 0.2297878277397925, 0.1358344982708654, 0.16895600324196203, 0.19847721672586857, 0.2419316236891093, 0.1959224207507026, 0.15627606831971677, 0.189239330169174, 0.20898317798010765, 0.4013184379906424, 0.25896450084063316], [0.07725601414999655, 0.11464877339500575, 0.04370360004325067, 0.04489091375181752, 0.068104327806542, 0.03058030131092716, 0.04408669763154561, 0.053331927140994426, 0.09629467802663004, 0.04021454835310578, 0.055236977134500785, 0.04539517580621666, 0.010801497865618478, 0.07650114941380678, 0.03691447140168279, 0.02938187932745824, 0.03599687426861736, 0.024087321193468188, 0.07309225733361899, 0.0221227404225858, 0.01577823963617125, 0.03416515804166275, 0.01125909367411007, 0.05995270030032243, 0.11433029532312386, 0.035011248527875835, 0.04000150313180301, 0.039358176966948856, 0.037431822068268256, 0.0011514757563652952, 0.027899144878310543, 0.011317855490732097, 0.0901091079257669, 0.053317869427583875, 0.07794107295452588, 0.04345497769874431, 0.07030938166163622, 0.04050540129443811, 0.010964783761019429, 0.032682276120589625, 0.02550590343983664, 0.038665261930756034, 0.07378684627192636, 0.07569478058646764, 0.02804696345852027, 0.01154095082799153, 0.037348295501883955, 0.05273235608793555, 0.018242413155554284, 0.028441715159363327, 0.06769954992998993, 0.03781141863474923, 0.03726917777150389, 0.009248090847846, 0.025722465004711866, 0.055142993467950055, 0.04194699873727176, 0.036348734621799765, 0.03160631520703676, 0.04147172928036701, 0.008573312943260516, 0.014105308538062439, 0.0033389544771653752, 0.022550077673288125, 0.11640901361862499, 0.01880837784659478, 0.01187670705539565, 0.05590210999211958, 0.02280550862422153, 0.039096803088942846, 0.039539035004112995, 0.02614079497664446, 0.07137892467360343, 0.02878793710542302, 0.051665609296891964, 0.03584675550941498, 0.051053662093416344, 0.2982960983870491, 0.3163265599118125, 1.2282650917768478, 2.280809225574617, 3.5095821417147115, 7.005258990872291, 8.349101255016944, 12.779663512783667, 12.73318244564918, 16.686615828544863, 17.33109066563268, 18.983047854515817, 18.60155617037127, 22.54272626292321, 20.78178994117245, 23.302816883210216, 24.560195399868874, 25.892467652597738, 26.090839562877534, 24.358713050042432, 22.43601622120027, 23.296121397326072, 19.77614914217303, 20.40186720509683, 17.64399970731428, 14.467406445933928, 10.192895685472797, 5.874612254481162, 2.1589603058753477, 0.5980047403324036, 0.09777847542277268, 0.0018185037239867774, 0.07272037527253551, 0.015064145141701787, 0.06266758949946492, 0.06335735208384934, 0.036317378643058965, 0.023663563488592065, 0.017587557367439714, 0.018601620291930535, 0.02057203290713651, 0.03808783464914849, 0.017331306702427326, 0.03324915820191945, 0.025776870653874455, 0.021304692584841002, 0.10529371369029246, 0.03913021601376034, 0.03710971273962529, 0.06550508341000927, 0.10463435713562275, 0.06558291794311616, 0.032461769202904354, 0.03928330719410893, 0.08707978942942235, 0.008935576770454645, 0.04600335768754444, 0.0824756010044967, 0.04361912352784027, 0.024181247403424595, 0.00921763119197661, 0.0396493018694943, 0.04580356578733172, 0.04266002358147695, 0.03304495746570249, 0.03995395588478254, 0.031277487287297845, 0.07019565590927679, 0.03713523495882269, 0.029506761235215014, 0.03743244259948692, 0.05131863658466647, 0.022202176079454444, 0.0364747369331458, 0.01952479837552434, 0.04579650245666985, 0.06269315385349816, 0.014665304446562886, 0.015344260403165414, 0.04673167364671827, 0.008252017583037096, 0.06385359319768126, 0.03428438813575814, 0.048846547461805806, 0.03728573676198721, 0.05591474661243059, 0.02988896058541873, 0.028862289768914064, 0.02734695061770899, 0.0780014100394422, 0.010848817201481472, 0.0994606972521832, 0.05645713303238154, 0.07193721124842282, 0.0679139549573583, 0.032512055214254126, 0.0700120859208607, 0.1310761116685406, 0.05261358181615511, 0.021837621649366715, 0.029842698450891242, 0.04251440558882971, 0.06080442919365822, 0.05279904404174417, 0.038451680447906256, 0.032851014646791646, 0.07430683611141098, 0.014284810599600597, 0.03720586060456211, 0.08708976389419648, 0.04189536441117526, 0.021035144548682917, 0.029490845758588086, 0.06202550822748773, 0.026071079060315125, 0.05336624788000219, 0.013484978417475379, 0.1520532997505319, 0.06552721569014174, 0.08482584384300056, 0.10932206446605344, 0.05225787953203244, 0.07851607556785307, 0.0621194804027196, 0.0561410604765819, 0.05606980280830495, 0.08057636944877525, 0.05984897199537485, 0.05141704440897992, 0.049989236548783324, 0.02608990950149394, 0.02433515255219273, 0.012875938517672401, 0.03690265832589038, 0.05670860522396623, 0.01685515049875023, 0.051086864344054655, 0.010751393800150725, 0.046107124296888236, 0.029708024024242358, 0.05490094798827364, 0.031116765871223424, 0.05271519188799205, 0.05063198814769426, 0.02360651675131052, 0.00907469642228417, 0.008766546173231497, 0.03915691417792151, 0.05258827027113688, 0.01685847532034161, 0.03471137873167473, 0.06748689158308892, 0.027422184282312953, 0.005450760110116174, 0.037583377242328665, 0.019056661197194652, 0.09471613853689163, 0.05137993127948815, 0.06390479851454016, 0.03423150125590544, 0.03465653449717549, 0.0065690042890398015, 0.03895204311477081, 0.008689048718811284, 0.0531257996936479, 0.0409055634912464, 0.012325866320621104, 0.04346794756730238, 0.03315071973408903, 0.024729706985395283, 0.035839899022492676, 0.1335446614651911, 0.05337041539831027, 0.042227329460964094, 0.07888620328758994, 0.07735328433374244, 0.40562970503684015, 0.8287854793090975, 1.9886802881956103, 3.861371432581256, 5.084163469652976, 9.311163540809385, 11.336147939005206, 16.072500136590776, 16.44013604810161, 21.031458608565792, 21.692903580204135, 22.984785226083574, 24.43960605129119, 28.317737771618752, 27.574529032553396, 28.98075365251111, 30.084434093967563, 31.03758965769122, 30.83668193509502, 29.240716580421697, 28.83938554794558, 28.33004028566422, 24.581823348999027, 24.423820472532704, 22.248834833022087, 17.322910562638317, 12.417485579367607, 7.5331021508862905, 2.9045200155627344, 0.9568636744253097, 0.13162003409477974, 0.054151874876791434, 0.022690944005585006, 0.015631447613780058, 0.027797316471415184, 0.034064769880065036, 0.05961618851870299, 0.03859291258718699, 0.03780642757192254, 0.02671971229926473, 0.0232311719728093, 0.039714457647454356, 0.016998836034608465, 0.07907994692364047, 0.029253377654259245, 0.05081622080216485, 0.043704155456995776, 0.035308161224689216, 0.049077128435695366, 0.04204160293504115, 0.14650215004240313, 0.03314329251166313, 0.03169029951095581, 0.05107134340270873, 0.049266440253103935, 0.014857735199433182, 0.011951483940074762, 0.05223012799697538, 0.07503927745405706, 0.051193408022123965, 0.029212943533615723, 0.005693059356417508, 0.06529680708603514, 0.050426017748372215, 0.024424668010925094, 0.019376788273333542, 0.06628571934397183, 0.030235647929892428, 0.06052207599784579, 0.009591894828894687, 0.0217610722287528, 0.03917347316840484, 0.023852080489779194, 0.08708189617121413, 0.0517807676336698, 0.04171272521958717, 0.11040289195314532, 0.025053197187521768, 0.007834257867803137, 0.026968533826631405, 0.021674691984850555, 0.06473894185957409, 0.02253260895339472, 0.02996336304462485, 0.028475878850346612, 0.07258797229658212, 0.03358952340579802, 0.032108514569699764, 0.03641927982830713, 0.029393968194903388, 0.0629020928435268, 0.02053609189216889, 0.05958642217240507, 0.09033292051284544, 0.06906531615963868, 0.07208276795403612, 0.07144971885868619, 0.06094005739977283, 0.058659915436780265, 0.17432188224648276, 0.2238304522489348, 0.11131155650101363, 0.1454211999812434, 0.16666512455671065, 0.17712158120928273, 0.11562920505962065, 0.17728534016397693, 0.20966407692720815, 0.14919974480665502, 0.15027743133325733, 0.11753195295891455, 0.1918698003095004, 0.21168480236684123, 0.1266937516629696, 0.14875547509760628, 0.16619506832813064, 0.13184508008341636, 0.22229283717611145, 0.174462704528724, 0.13656312449564859, 0.25400325415595887, 0.14319131721652326, 0.21230945513854105, 0.20878227908284436, 0.13026983477175236, 0.11252906173467637, 0.19839323816760895, 0.15070458663807762, 0.17376740312864705, 0.2023243110987448, 0.06454679934728531, 0.13046120353523763, 0.13655840539403502, 0.131051167845726, 0.17033137621418123, 0.2565368294956223, 0.12152661884864494, 0.07582585823031203, 0.1432461997554187, 0.1564740867263848, 0.12832906592877644, 0.12135028073023404, 0.1496171248295615, 0.13547057586331523, 0.08658532563957476, 0.1268651714969066, 0.07809730892580363, 0.1204993485683395, 0.25637236574003774, 0.09323007352049313, 0.1668549305008304, 0.17089644266713053, 0.11202692940470674, 0.1507388920553269, 0.15289616500658376, 0.08362734525073921, 0.18587845648008008, 0.1086218601032611, 0.10244702289421713, 0.12886279172474338, 0.17760613182139012, 0.14537031642131268, 0.12380303379388587, 0.14244972878406126, 0.11158450596755552, 0.07817793967983416, 0.13434919168151196, 0.12069679240906432, 0.10729365516453983, 0.08459064718936721, 0.09475084231986154, 0.2580007009448544, 0.10948771565792062, 0.24898318724045831, 0.21376653904876403, 0.1968149438260063, 0.6016772432673363, 1.0133053554642586, 2.084911350281008, 4.5100750750111, 5.936242986109949, 9.483292833451303, 12.495550551722127, 16.21489884391908, 17.65398802295808, 22.74680522180373, 25.65488773007547, 26.494239645619547, 28.372896102166948, 31.171158129169097, 30.791719805809763, 32.57441939846162, 33.00137919764365, 35.64665309844479, 35.34301850103563, 34.031907435386415, 33.87271019720262, 31.948209078081195, 27.776401658211988, 26.97722658034294, 23.9323906360134, 19.29029691603876, 13.478325893802028, 7.501634936178885, 3.276083690504874, 1.092811063412697, 0.21762075803933606, 0.11493211101380088, 0.24464542887383894, 0.08452451847974332, 0.11356619156656728, 0.18618691412191238, 0.1522803988548056, 0.14526110292682726, 0.17793311346923152, 0.13706408471109408, 0.05022878075138696, 0.11854823753838578, 0.10678260557113156, 0.11664218780013824, 0.1777007130365218, 0.13698618889095324, 0.15685316235307725, 0.07059849558338042, 0.18947266522915135, 0.12263571498014274, 0.34023346739911264, 0.23895411571908384, 0.10964964366247577, 0.16800337290811926, 0.15882662016778223, 0.16757338307797912, 0.1371395443716357, 0.1894734772823511, 0.14934262020453332, 0.22188376154630418, 0.11509676629136648, 0.10834886467144375, 0.1108964977245177, 0.15541789662693778, 0.14321831415497488, 0.15092621587457197, 0.13458909977587963, 0.11468018299990124, 0.17917454362876956, 0.12061980823355338, 0.12613980880668088, 0.15330726310851114, 0.1592701237889067, 0.31218925611146037, 0.13908484079424413, 0.11554482047476115, 0.15549896405108515, 0.14697254334966983, 0.059603184176188324, 0.14411561761892613, 0.10174012292296657, 0.170629215877383, 0.12944172436912216, 0.13989303291084307, 0.10527753391333165, 0.18751796124683273, 0.11585543082366068, 0.1565905627343924, 0.14666397845552814, 0.2382179971544012, 0.14193231300000222, 0.12277138915153281, 0.1301301309778806, 0.34266070973488594, 0.1582223300131098, 0.1371667864582231, 0.22991533541390974, 0.17190435390558936, 0.15931406659224343], [0.11891339334749407, 0.03431992695456551, 0.05721857463340125, 0.028560592853013548, 0.010313274819524059, 0.10911116812137828, 0.07961662215811592, 0.03038374996263414, 0.08099766418097482, 0.07924924469402722, 0.03340033799289696, 0.11310024923014064, 0.06571656964238613, 0.06764851315247436, 0.040130868569136634, 0.08462195720283255, 0.057021372110372594, 0.05188389455959682, 0.020080531962336074, 0.06708245844610276, 0.02412822071252571, 0.05693379293886885, 0.07862020989940052, 0.014995743066162593, 0.012534602297349803, 0.015251065807176695, 0.09376151637444574, 0.07108436386671758, 0.08361184729203101, 0.07058306657258542, 0.005536696023022336, 0.034653359062729344, 0.03711575334290824, 0.030931437711021116, 0.053164012159311005, 0.0964088021447101, 0.0422985258422071, 0.019845551728541334, 0.05676169128667924, 0.06908473648851918, 0.03770433486469331, 0.05523110507056118, 0.01979164786696915, 0.019786946002333876, 0.04514671434017439, 0.06085337072070088, 0.04201017417794755, 0.03560014797614948, 0.02023804347000776, 0.028040656639683633, 0.03281538389743336, 0.04726091782832819, 0.029736227551174742, 0.04274499039315889, 0.0690989857239108, 0.04450813409001116, 0.045923807117487156, 0.019644271702535694, 0.01926677804740687, 0.06316987887745903, 0.046629443043662656, 0.05026992733380006, 0.08089601963518128, 0.026596167214935827, 0.03517583485752825, 0.017130725731652592, 0.047070495183429414, 0.017541243521977338, 0.012527387664322893, 0.012536925458980185, 0.07459152204495284, 0.07561205841240383, 0.00466607348625398, 0.026916763519928343, 0.02109496835468998, 0.035217264892473336, 0.03475929370089885, 0.02545127754039582, 0.02497456783819343, 0.07087610286450194, 0.3091205836784455, 0.23797862532158054, 0.05022910250831516, 1.0859447092779222, 1.1616734198985563, 1.5130915564875451, 2.2798734951403836, 2.874914210650229, 2.4686275086095257, 3.50284424520308, 4.659139850447255, 5.02203949997502, 4.544053096925059, 5.95921483732039, 6.2300182157947175, 9.10184919834137, 6.828833722299145, 6.767561887541126, 8.117550015449524, 7.474718161167638, 5.427639542087432, 3.4729040582333845, 2.677046815233846, 1.2581808865070343, 0.2907351476530875, 0.031806486320772, 0.08888964916789725, 0.0830047685773142, 0.0531044488231982, 0.09305944275711814, 0.015329247952679233, 0.019962782333154353, 0.14514464224057813, 0.06410081743172581, 0.02779091389158801, 0.021045345009394714, 0.04597949021826348, 0.0431670090784469, 0.04172436592559661, 0.020273909791402762, 0.02471505746906323, 0.04115182628494598, 0.03639134060170862, 0.06019557698539669, 0.06494300469996468, 0.06615874027052233, 0.0028439175577894336, 0.03478438691085866, 0.04951184885876794, 0.04846409721780689, 0.03652030001244238, 0.06654715450901179, 0.12729979615898865, 0.010279652178137293, 0.05803689826279879, 0.011926905924244034, 0.034554564364014134, 0.02038346227979468, 0.028796687744738116, 0.04454877122395462, 0.055151703887649124, 0.021082523256360043, 0.03134779500654869, 0.09452245618787505, 0.015473395056511848, 0.02586027656141068, 0.0687116516693946, 0.009231905325225765, 0.1336583795566713, 0.042782222266278924, 0.05101227802374671, 0.03465965247502731, 0.05185791268764485, 0.01711676186401277, 0.06316039087851683, 0.02831387232177921, 0.010147780675681369, 0.06898248673326547, 0.023172949290563984, 0.032470253626665765, 0.010418084266054775, 0.06301833902515712, 0.036178931233383, 0.023577857402063186, 0.044127790587804014, 0.018352348687908342, 0.045020987820481105, 0.039617398137887644, 0.017224858785348556, 0.033366863781045523, 0.0868631167817981, 0.03184259012942353, 0.016797226590795383, 0.018242832588692828, 0.018017313540762952, 0.050520729198451006, 0.0669874482217335, 0.045666037683164885, 0.15227888200071552, 0.07635357789695263, 0.04726554116895122, 0.04780986579135061, 0.007737472234669352, 0.03369459236461309, 0.12012162891727303, 0.0527060907634516, 0.04498668623367145, 0.048348846950478135, 0.050345111202688954, 0.0221785978083649, 0.08552784851241498, 0.05705540556640876, 0.012350433802742873, 0.028426299555106994, 0.04311276622296822, 0.03126686739344751, 0.026917968193189274, 0.02142642012556955, 0.010088479724682627, 0.023615679162884914, 0.02522673333934959, 0.04802761862294809, 0.0741389096384087, 0.016542799215042786, 0.03898826758227041, 0.02886640366106745, 0.058786534448905345, 0.02922443485247993, 0.011847136061518423, 0.0346205092125362, 0.04723424647724436, 0.03286376234985167, 0.023851590193507653, 0.029208281888596477, 0.003300588793917409, 0.029425301191006458, 0.06638794611658781, 0.02399579858437421, 0.058601581671785925, 0.027961994731618513, 0.02772301168841941, 0.05280216201959599, 0.04737086676722092, 0.025335695940039815, 0.12329957613180723, 0.05019215025728749, 0.06922943517565727, 0.025370734886476592, 0.049104355200524294, 0.03232560473524275, 0.040814533093643766, 0.021703548601738388, 0.03683055030001748, 0.008041699634744756, 0.12096313819769891, 0.04868789831356657, 0.028246734291315082, 0.044209252547232375, 0.04215070917721718, 0.018800738034769893, 0.029346710146074335, 0.01642569309971746, 0.05952922987841791, 0.04284740868775595, 0.03288858742903798, 0.043701500962338144, 0.0586132989865878, 0.08454282032025438, 0.020876732887700204, 0.0685286179425255, 0.03388196597957323, 0.028157370134947762, 0.04431575409046585, 0.022126597675284552, 0.030789462466453834, 0.09693654479398843, 0.4060858031434398, 0.4021065279601082, 0.38078320603216853, 1.3960531786564858, 1.8711399695565625, 2.541515197484724, 3.0669782142485342, 3.8764929050399415, 3.9568701146110414, 4.900274420938184, 6.212004240482084, 6.50825301485677, 6.32215763292005, 8.372355026583518, 8.357360786007296, 11.005991255083392, 8.892164191892071, 8.800014968841307, 10.553850819987636, 9.348411348558242, 7.342975553004973, 4.167783068072412, 3.783119167051008, 1.6335412932019082, 0.5137217693751859, 0.01844744892760871, 0.08015781731134461, 0.04169648415559242, 0.038141456973408504, 0.03240902787975727, 0.052659114251934716, 0.03233333456239874, 0.011797281932235967, 0.09405480547537727, 0.041352794130122474, 0.04204380543782346, 0.03207969625720815, 0.08726771079724835, 0.060304484044712406, 0.016382246338311705, 0.050301302464738976, 0.05312040643466096, 0.028337186292534875, 0.050629268535563064, 0.04977841681290058, 0.05053206729973036, 0.005416827681925028, 0.036404092135208274, 0.03933345914007195, 0.02290014729594752, 0.05136411539429138, 0.016629677416095813, 0.05903016956102464, 0.016142612120376962, 0.023310383548960093, 0.021481779554197868, 0.06415368898982002, 0.06358311436469517, 0.014072267165888223, 0.06409715553144775, 0.014549596441699373, 0.011070146706075439, 0.012695385000458168, 0.07414991832188061, 0.05669342902218623, 0.040922677895474824, 0.0258378014569321, 0.06468543827894234, 0.033816178179075645, 0.02430632466360206, 0.0309221642166977, 0.02840506742828556, 0.0036234290183206363, 0.003939747440463473, 0.03491999213433555, 0.03529623323570817, 0.020713569566367135, 0.04284400725737215, 0.07907927276626711, 0.00772433334796299, 0.02632270638470448, 0.04922437819562132, 0.0468809075743681, 0.02093182418555502, 0.028542208658050627, 0.012510347953667084, 0.02386501971482029, 0.04046421257718917, 0.01594455732453254, 0.05550928308718628, 0.008881225705056662, 0.017202169176251177, 0.010223917366426078, 0.022977933948559147, 0.04174083298552902, 0.0498472000171821, 0.24718134844255066, 0.2117393631488085, 0.2789117756389803, 0.18999225670291534, 0.15155218631750153, 0.21943205036222937, 0.20696873446145367, 0.18755784378417079, 0.33653574484971266, 0.2267110194530218, 0.19002286957636957, 0.2650351347702165, 0.1276229626889671, 0.13539588229069788, 0.2209451812649927, 0.24810499000933864, 0.18349641333183936, 0.09831781664322461, 0.1505704599642946, 0.1531719719810832, 0.15351666558173396, 0.11067522088846854, 0.107915258906301, 0.22670979371234296, 0.10355735242727304, 0.07539823561185792, 0.1488109245415657, 0.17780677024875918, 0.19398587305218945, 0.1826172508299351, 0.13476312430875917, 0.11060680923683029, 0.10896817014943208, 0.0954889910175435, 0.20961690123283097, 0.1216746959835291, 0.08022982957622699, 0.09021614573054737, 0.12661796258462052, 0.09770293149255938, 0.13367740918071042, 0.22352119787566124, 0.12818530952978519, 0.1393418020058063, 0.15660847387006208, 0.2188271473372175, 0.12028313557346983, 0.12909131575255625, 0.16031701358095293, 0.140978027916243, 0.21687962925962864, 0.16531356159717808, 0.11694642429750775, 0.0960012280472344, 0.16517846965261046, 0.18604855864278733, 0.1438989679539396, 0.1599674783046207, 0.19590999480457078, 0.18628158726759497, 0.13002134649263275, 0.11635856672881112, 0.20766356088701757, 0.1682001808958669, 0.2251174952834845, 0.1379562707077111, 0.15002577145013118, 0.09887161394280773, 0.1687045425416962, 0.11307348977894553, 0.22545651983349557, 0.19126013221759952, 0.1774978069888969, 0.1363134104758501, 0.11718778029805231, 0.09196396766891403, 0.10708022306883529, 0.14985234446583257, 0.12405244903939387, 0.29610009203034066, 0.6228161831536602, 0.462141651660204, 0.47439961003199704, 1.5317999138947458, 1.9592748918840963, 2.5783369377736123, 3.398817840122408, 4.352211442685896, 4.547350339351162, 5.196327076804254, 7.242204470019187, 7.6123938445122015, 7.332736695966414, 9.207043243992715, 9.130485442376907, 12.179151581179712, 10.980287963344205, 10.223581367923368, 10.98947415428777, 9.860484619294445, 7.909881107268795, 4.945325784144863, 3.8047282397747044, 1.9785793269834213, 0.5870622468571509, 0.27354971175232246, 0.13536246553544076, 0.20926258556785124, 0.16333714668308535, 0.1075994085159994, 0.11046746550428291, 0.11275324970483781, 0.21907837821110604, 0.23720502973564211, 0.16142597181662438, 0.18483922756727666, 0.09951128203782345, 0.14594787010742774, 0.23225089234690513, 0.10390465072686635, 0.18967590835546294, 0.10370195918386022, 0.08519442406513038, 0.14739767618237004, 0.26983311279646816, 0.13873015740706077, 0.1902744375289448, 0.09364181513627691, 0.12547495940159406, 0.12038042107897422, 0.15774600718530918, 0.16131406169264548, 0.17858362936925504, 0.06924595969218401, 0.13465912021215887, 0.06078223945693143, 0.10556886949005628, 0.141813324223603, 0.10964782037321599, 0.11169412548864081, 0.15791981721356993, 0.12180608772342244, 0.13286763892298745, 0.22359579951772768, 0.06933324008939729, 0.20562988856146414, 0.14159911071821568, 0.15015799822586198, 0.19963699723443679, 0.21899488994911795, 0.10457834078659935, 0.06201645689866236, 0.09911729067924524, 0.14124874806692525, 0.11561342364838047, 0.13155298607964672, 0.10445621104971056, 0.08299423486835535, 0.2635028057040707, 0.12141742833679724, 0.1579655220191325, 0.13224951322040251, 0.14198826806199166, 0.16616165157287352, 0.16682275480801062, 0.11942221362504268, 0.10779407911843832, 0.1848391969237597, 0.09464251748736828, 0.10993111968761492, 0.19420520402491095, 0.20993079809892565, 0.14221890649247554, 0.20457901511221163, 0.15006167033026296, 0.15013208913226284], [0.023692893164773143, 0.04451669895300462, 0.03326746770330975, 0.016312539998081424, 0.022641803295682036, 0.0494877515631097, 0.01985595328733325, 0.02556345962558783, 0.01238580887025643, 0.012244746227928949, 0.03562613367854107, 0.0435709136147653, 0.06742028023807273, 0.044838823603406075, 0.010167936448969189, 0.05986179247678769, 0.04689824414409457, 0.03408318663376474, 0.029270340756122625, 0.01618622933634587, 0.0138260503374641, 0.021408572192153624, 0.059295833531406626, 0.059704778926266786, 0.08981024170474661, 0.049971819539824804, 0.02355077044828044, 0.023061855050224452, 0.020491371509589015, 0.039265495649869406, 0.0502770749341336, 0.044113395795706785, 0.036493659304875525, 0.038333423285474705, 0.042725386203176556, 0.06797130429936994, 0.01517338544926456, 0.050990272148121754, 0.0742335674623328, 0.04826595240663137, 0.043244092845388, 0.01864083250233483, 0.033415380129290205, 0.07391196375171985, 0.05027360455583661, 0.06745351313222801, 0.02860018236172055, 0.05142587740274687, 0.0317370270438973, 0.0561587073119177, 0.02812873759877778, 0.0321963427197789, 0.06714025977998972, 0.04674708733575479, 0.05209698574617506, 0.029538940758474415, 0.027099582742178635, 0.05253345668015461, 0.04568458084137209, 0.06269260227019269, 0.05141707122205727, 0.04779029607532486, 0.031222191060923284, 0.01687041480064152, 0.03339779841142797, 0.029855651082471017, 0.04948594742604802, 0.08543620907491253, 0.043413088011044654, 0.023903071302019303, 0.06880226454907848, 0.007062254308332359, 0.07119741546170366, 0.07301740288253754, 0.09726798507354914, 0.018144139396627585, 0.057997766491626544, 0.02865475080456705, 0.05936052582617249, 0.024074006585344195, 0.05023734561438042, 0.08390291473798214, 0.02246189520754401, 0.037074162429499055, 0.0937096062566965, 0.1239301431022825, 0.07467111858028559, 0.05204485346292777, 0.10678945439717463, 0.22892973265580593, 0.2727035216746792, 0.16780768340874105, 0.4730534096879344, 0.47478991650765945, 0.23740955988966653, 0.5059000423117992, 0.5155817695683049, 0.9461541329660724, 0.7864775688898179, 0.5920014914966399, 0.4807959845469844, 0.19503067908508165, 0.09670027561726109, 0.07254039057560506, 0.041381281109586845, 0.014108782746799052, 0.04655175406726138, 0.013298270341399457, 0.04159161054919805, 0.030589601618327925, 0.004839469827035623, 0.029584909864370863, 0.05069711711257697, 0.04689641702439516, 0.010734083085891702, 0.014677699749177743, 0.03795965281765788, 0.022085860949910937, 0.03522175799814924, 0.055675604605987195, 0.05443876331311561, 0.051499498452270226, 0.06426505519137268, 0.02054494212291414, 0.07472793166075023, 0.022102894914907315, 0.08984575754091625, 0.013118494403428368, 0.03251075669522247, 0.04195133862536281, 0.01285622803299057, 0.04408410442392192, 0.03172638033696961, 0.023922665915902586, 0.1001690527904899, 0.08732741969006677, 0.13282343564975646, 0.028397950471468994, 0.008089146332725162, 0.02032315775361513, 0.021574853491338513, 0.07686028377183023, 0.041987769936601964, 0.022557424456481973, 0.0738875255469353, 0.03130535182032374, 0.09453051543283848, 0.05672616012875111, 0.09071904414844129, 0.01872957038182405, 0.0070708641789913665, 0.026927883286149274, 0.052598493714486404, 0.06899646017700434, 0.034605524532737277, 0.014658479560767452, 0.051788233160491914, 0.023032795420036684, 0.05056768272733016, 0.04424145122268989, 0.06277812449561973, 0.02485801905183302, 0.08012790157790146, 0.030412830660239826, 0.04599648970930327, 0.007428293991383286, 0.015394547372125091, 0.012842411637276173, 0.01759549786877488, 0.03708225614841908, 0.06332875019119633, 0.06247808999051491, 0.047408018201108904, 0.02499316845299496, 0.021071734823166363, 0.021673378144060413, 0.09518650886152061, 0.0334237726225007, 0.027492859723767447, 0.06778679968368623, 0.054775665799576434, 0.03594748074969938, 0.1394802953807577, 0.06765851826076547, 0.035381663530584306, 0.028585963769845908, 0.06406593361809369, 0.01309801112755292, 0.05371207529078088, 0.033659026732728366, 0.02848340374898286, 0.0526175539820425, 0.03790223069729344, 0.04810719600608272, 0.03908213250519287, 0.012656284830412798, 0.07023692506575777, 0.018786483053718845, 0.009133346198547271, 0.0281921505267101, 0.021308463652648275, 0.05465209198695037, 0.04386630179660936, 0.05284033618086288, 0.022144307712874105, 0.03598066767857921, 0.022572290392652638, 0.08140831795190612, 0.014301401191210796, 0.026599710371585625, 0.030855888035148386, 0.09056535158907214, 0.03625997567489263, 0.041187518321338205, 0.03581886990897117, 0.015891322832284196, 0.05556919116286501, 0.042114094004876194, 0.013805591001836284, 0.032172639959401665, 0.050747966198551084, 0.052121408629201116, 0.0468759854594546, 0.008620665795470198, 0.04138158754475656, 0.022802030585045298, 0.03555249347681961, 0.033711147524656794, 0.009154565876439936, 0.015861575638184387, 0.022488648913079695, 0.030088465202659852, 0.03313497279680545, 0.014920902021619824, 0.17511011011177496, 0.05507486909928341, 0.01527342216802701, 0.04611439064085003, 0.035571825705588825, 0.024703211834534042, 0.03397993330333022, 0.0357508298099762, 0.052650453627950726, 0.06542334182848854, 0.009218340780916474, 0.03375052061352519, 0.015687641120635937, 0.010774267270349929, 0.06307987503767495, 0.0933728876313375, 0.07634000281893438, 0.03440687793397135, 0.02779692385135399, 0.018091036096936273, 0.019090949377465635, 0.03239335372082649, 0.0523384643207875, 0.0703454950463868, 0.05902541215501486, 0.04392756201747445, 0.05402947317868952, 0.052282402006488655, 0.096140610084178, 0.12692349377058207, 0.1966248008031999, 0.2820675369472273, 0.37139326634426273, 0.36489950673234084, 0.701269654016341, 0.5073845368479529, 0.45569011881466837, 0.946012927639869, 0.9603741957295326, 1.3926589801426859, 1.4885000115440739, 0.7892017775485594, 0.6055817176257411, 0.20867689602798034, 0.15995275409471604, 0.041477344704851996, 0.02048668305149242, 0.01965319662685356, 0.09017490721758335, 0.08249339722697774, 0.024040461510359764, 0.050686430186033256, 0.01760084324726655, 0.02983690108052425, 0.027142014437084718, 0.05432407228997158, 0.05130035389635352, 0.031108564899994, 0.04335301905690182, 0.013229859647371117, 0.057800288176945144, 0.04958935014362778, 0.053152103322528066, 0.05400973492332044, 0.030565192141840537, 0.03921062843273244, 0.028699827418031714, 0.049468507434451775, 0.061187082450957074, 0.021918202607682156, 0.049281953533570615, 0.017864383238878463, 0.042801830286700884, 0.04226947195767876, 0.04333438779858332, 0.027071515195852807, 0.047990574441369505, 0.05998792119264122, 0.04083162451523446, 0.047596100447399, 0.04535457697666941, 0.014301256592115088, 0.03954224108207611, 0.035827143658553405, 0.0657045727054919, 0.01742779356127064, 0.01790427535231556, 0.012872459520886262, 0.08748510356752143, 0.038787242280499595, 0.05245650697860026, 0.04576131986874727, 0.043034000893033324, 0.05796221618150031, 0.03413411998941052, 0.04833275910406824, 0.03169805998162877, 0.027955682167122443, 0.04809397332850964, 0.01893753644018885, 0.04411209727667513, 0.048348896746193214, 0.05374636538627167, 0.04629172084312286, 0.049447286798949205, 0.03043608525918136, 0.05545231295869716, 0.013706845141226246, 0.0763307714594468, 0.05433598878763376, 0.02195213264184854, 0.027284010749069915, 0.044378213238932436, 0.031369797051734025, 0.05355226551933635, 0.044428564367755774, 0.046150209081749764, 0.042491334850990006, 0.1530722273333419, 0.15204799842209588, 0.1830642171684773, 0.08523072897186203, 0.15510579240658592, 0.10657262087108628, 0.20846059876343898, 0.21935472144715248, 0.1428104029788125, 0.14062706771637165, 0.174161923087893, 0.1408258981762394, 0.32284979858706075, 0.14508701710691377, 0.16417337761771295, 0.1320310555879147, 0.09649012237787248, 0.17399555943425626, 0.0983114427916946, 0.2012888666602873, 0.09557339858504073, 0.07428647349438361, 0.12589334299968136, 0.1315941862882145, 0.22511286811242182, 0.08300242434826591, 0.08823665880387829, 0.11811876864803415, 0.12685682113853194, 0.2928807454243783, 0.21160189633167562, 0.1507611545704065, 0.13783545864205207, 0.10428484484192826, 0.1318769953063419, 0.13225299125957873, 0.13373914054564892, 0.11088337463837479, 0.1415084671950148, 0.14544902429465326, 0.12006227242489977, 0.10686932672416011, 0.1541434021125878, 0.2057699447557811, 0.14437642459186817, 0.21151989428026063, 0.18966912081645382, 0.13311179114445565, 0.12104993595951989, 0.220517382446316, 0.10953146693927628, 0.0689633421960377, 0.19403229798040084, 0.1949482327026706, 0.13810141372584528, 0.18152278697779103, 0.12470278107831556, 0.10113468363640771, 0.23285181171471075, 0.13625811424947556, 0.13824712364904343, 0.10650046304949831, 0.21555173841695632, 0.17704466598168497, 0.15999977657150838, 0.11301913584071784, 0.10610691602191619, 0.1765890581713569, 0.10390592243282065, 0.10390809046164637, 0.1378244422977009, 0.09964395314455034, 0.1838449680156285, 0.18465214889616738, 0.14460361562669277, 0.08574308091474157, 0.14330819159025146, 0.15662172719115214, 0.15531092010919126, 0.1458573951235702, 0.1502067520613632, 0.10905243982110294, 0.18853624531578636, 0.20858519530344397, 0.11924502514903584, 0.26873592167131366, 0.17446883323211826, 0.1843085278186106, 0.2658637354691183, 0.3133616464272622, 0.6139461107311711, 0.33120539700312, 0.731666122953738, 0.6448125899318726, 0.5518825087816485, 1.0355399236563714, 1.2257561231813123, 1.6289858279689666, 1.5792968749038636, 1.27745051057108, 0.7804079461962946, 0.3835872716961369, 0.397062145413891, 0.19281919775230272, 0.10998332091877538, 0.1639698740215071, 0.12699535281787958, 0.19749585809486528, 0.18488304779654552, 0.09647612595149586, 0.15220015880561646, 0.1266319513501179, 0.10362657613211101, 0.3755705905777793, 0.1321521894105019, 0.10837868081345674, 0.2760168519471922, 0.11914193269706543, 0.11587308915031534, 0.20428958709441847, 0.17569094265420593, 0.10636683433286606, 0.14356006597799642, 0.11736664650661331, 0.21497433794842613, 0.11633929195663623, 0.16625833186891772, 0.09992687707586635, 0.12098870255173215, 0.14034012182345315, 0.12614203046166128, 0.12581581490174418, 0.1462492184533227, 0.13859515739304407, 0.161888443774754, 0.22272501801771505, 0.15967029747703385, 0.10528313401605814, 0.12538275305902766, 0.07743131804970965, 0.15375579226641886, 0.17348324579577293, 0.10694123939761233, 0.14741057710301492, 0.09470543628858943, 0.09302273948466586, 0.19361471877463404, 0.14616399883262574, 0.2511277584539306, 0.1369244728477732, 0.11362439126617487, 0.1986852402408277, 0.10352903015671239, 0.23134493208940954, 0.18034385427111582, 0.17253816908886357, 0.1346887984583455, 0.10926102258024678, 0.11138602024725369, 0.18007166323161897, 0.09551552064236134, 0.09959529890047927, 0.16393785154627216, 0.10304484726680864, 0.10006471927608214, 0.07555015850812197, 0.14361805883386444, 0.14207783906209853, 0.16873345469995854, 0.1258944614880508, 0.14635965768848697, 0.3219930977830964, 0.14634338598097527, 0.11097016473931652, 0.12654982672463502, 0.15669217663666896], [0.04280267298341759, 0.12035553088231433, 0.088147011194979, 0.0680419912321433, 0.05854542742693617, 0.133830611443808, 0.015582582695529828, 0.050111649738204096, 0.02628798727997609, 0.06228141989859362, 0.07771516128653481, 0.04244822325305112, 0.010178307364244136, 0.01258975200940885, 0.029276919536172386, 0.012864205881112046, 0.10417228354321373, 0.07224386092275381, 0.07975965843445833, 0.03654608270153403, 0.03696464633028354, 0.057063307763347705, 0.06485430704009149, 0.10758035590932255, 0.04593305379873322, 0.0696579541169828, 0.048402381174626856, 0.02562127436601347, 0.04596606835783009, 0.07104099562932407, 0.08227065716299319, 0.03969158226203534, 0.05772520389948642, 0.026366691322877046, 0.03023907042769415, 0.03053678943204784, 0.07423459402015133, 0.019440814071605285, 0.024592077374578487, 0.025112735625777035, 0.030071950262232177, 0.05540765769359085, 0.018951661186292768, 0.04174177910411551, 0.1337236042825445, 0.0688368993841352, 0.03782595898355207, 0.04161960723239087, 0.07647982152599482, 0.021038714518410065, 0.05084689113221342, 0.06591279540331134, 0.04046700496767317, 0.09800807963455878, 0.027577198343351487, 0.036629693537590005, 0.0350003968924284, 0.01884063972430604, 0.020483800645677314, 0.0157739715688231, 0.006403135240919167, 0.03002413679965802, 0.03416505078935335, 0.049219115171581514, 0.03691203141164395, 0.053032742993485545, 0.04424613201990724, 0.03316164031744965, 0.04730967932470864, 0.027609925619476748, 0.11811073238570845, 0.02429299664893939, 0.02968006564544574, 0.009329955003434613, 0.06382355872060984, 0.06205145179504349, 0.03794486732071927, 0.056050903419212955, 0.010884370384437424, 0.09475950677428516, 0.10697809588764945, 0.12002833472985415, 0.017239253577445785, 0.0695163504250588, 0.020855979565831444, 0.022298756784068483, 0.04041904020273397, 0.03324036734298833, 0.014411363536642205, 0.02793623119472496, 0.05794251240008782, 0.07434862620768047, 0.026315022522823948, 0.04767323401005519, 0.045616104072260286, 0.07565258446359828, 0.04598154716434018, 0.037636091752398404, 0.012329013026770086, 0.02003698943993978, 0.020905939989813396, 0.010059746639472584, 0.023111878676460158, 0.0834598784304915, 0.043857273450421716, 0.062230153294700774, 0.03181544188860684, 0.03719661775375566, 0.05647572598630383, 0.03250379295599076, 0.03647501655523816, 0.013119782388751066, 0.05583164139440464, 0.07129948135585555, 0.036427882995696804, 0.029041477734403267, 0.027401044086042433, 0.0831255576603355, 0.027325025181316083, 0.07753182878537525, 0.008534699239047065, 0.06659518056098493, 0.04478702839884547, 0.04189444510566612, 0.10171336347177144, 0.018396469606687466, 0.03476778961597912, 0.03917596295415875, 0.061363991304871544, 0.02589769804129197, 0.03334332572957201, 0.014793217189670091, 0.008461324295269386, 0.007694729316544029, 0.038254654125100186, 0.06089328390155589, 0.01109044420562925, 0.03173920081838245, 0.048917391442603646, 0.043020674793590466, 0.040662679145292896, 0.04782646308623014, 0.02740947871408876, 0.1294622248819759, 0.006618213946855958, 0.04286057390873471, 0.027245869146539804, 0.0328346663304875, 0.04787611324460276, 0.05418252988508152, 0.018412722162001075, 0.10161490585174292, 0.020870924026014346, 0.07163976995094169, 0.027458540899979494, 0.012767048695334985, 0.038693235631311135, 0.010450177604422696, 0.011496446865250268, 0.03840894806348989, 0.041342620482488025, 0.053749782138413964, 0.040870714151570876, 0.08890790504313285, 0.018101341894737655, 0.018036737700083086, 0.08147286085952675, 0.019879108294844627, 0.02459706652218536, 0.017792307771742344, 0.074076036802463, 0.024646890965560754, 0.052389547063578526, 0.052161769971491835, 0.04201751713070177, 0.021750105680116726, 0.027517728853009404, 0.041305886566518776, 0.054686416556397756, 0.02023120996572318, 0.032686087408012925, 0.11725975425853846, 0.031276931873552745, 0.0075139938534477795, 0.053899356975190105, 0.03685986082400045, 0.010997708304785194, 0.011298532838061934, 0.003929813913512795, 0.037228035019530405, 0.031008712999943285, 0.027877001106859218, 0.040871254243557496, 0.04317708696509081, 0.03364908291147121, 0.07515558492272131, 0.02662849037968103, 0.00717794603382748, 0.08662653350902182, 0.05285262423116834, 0.04293732825786837, 0.08058329488361075, 0.035264233743110975, 0.05491359609990351, 0.020556351087326487, 0.047870313959015955, 0.08732326749351718, 0.04145371855326718, 0.10595172193021545, 0.029152803716339895, 0.02841793579019366, 0.024662000134647376, 0.0175187224522233, 0.023041616922484773, 0.01829369508120562, 0.04414900739286696, 0.09147249928285038, 0.012656539554647621, 0.020676778193803567, 0.03784026567553801, 0.050599054027829445, 0.030139032751321796, 0.02786567258167892, 0.07518074325015468, 0.061231741546503, 0.04140633601515044, 0.019033115484841892, 0.02963581066127987, 0.012263577626717669, 0.061965841469505144, 0.031016318337811582, 0.039136563052213004, 0.01130257873991204, 0.03931750152860919, 0.05680251994260377, 0.04478869080964116, 0.007890303423928638, 0.06136263532924557, 0.012060444625545175, 0.010579845646486409, 0.06475251693759235, 0.021715825160724983, 0.026800877399622437, 0.0566424343795065, 0.01953186745184564, 0.08150484503036545, 0.10678294264981825, 0.03696754214263732, 0.032554201541408416, 0.009847019344658382, 0.054734097868804975, 0.023341011744172826, 0.05996272073037202, 0.032472689786264976, 0.02570247777076739, 0.0344317106740369, 0.09935581215446997, 0.04900375253430778, 0.052482599933301254, 0.04390912228113702, 0.040463542250255426, 0.010341727325031835, 0.04100392535028439, 0.012089102059572697, 0.04357458700636222, 0.05132126809668638, 0.08772429920011952, 0.029515559755025372, 0.0309567952213148, 0.033155802727466634, 0.07146353908484021, 0.07731366226629866, 0.019814149784525076, 0.026566282125009645, 0.028840331773784374, 0.07541191794218556, 0.027765617668328267, 0.01561262004543096, 0.041801556944847114, 0.03323022433887086, 0.05281733439093637, 0.04836215389772289, 0.009842012960073209, 0.08956620439646706, 0.04100062351133074, 0.05306855760394566, 0.024498516971605922, 0.005140994851958128, 0.010054727805958641, 0.041301148312707106, 0.0754852325565392, 0.03285926158329652, 0.07211149625119663, 0.1324460607382559, 0.030890036404373187, 0.04627690087222765, 0.050299536632073504, 0.026945420953955863, 0.01639535218747633, 0.04743053352520351, 0.02804438940309469, 0.02148397439610093, 0.07229705040733661, 0.04526490255469277, 0.05100922133292883, 0.026393868291990894, 0.015907929703262786, 0.020267696818336844, 0.02191367694326947, 0.021551482063988527, 0.031814193165290265, 0.06627892414408346, 0.015471519098707266, 0.04242567345499993, 0.023410930673802094, 0.028994438020632635, 0.03223867290803502, 0.05657712538396159, 0.038910448370922, 0.03653411257771715, 0.03045716799885756, 0.03671440370981732, 0.005719131722505535, 0.0484015652909875, 0.030371797075795553, 0.013620304976469808, 0.090170762681913, 0.041948488778284485, 0.03893836078444316, 0.018603642764050635, 0.08102476837173586, 0.025367666704339847, 0.04852305534445951, 0.030754618872437748, 0.05212015990588454, 0.06720058154314756, 0.02838163854434125, 0.09849171860203629, 0.011398596369901733, 0.08279472259023497, 0.05088625272976295, 0.0167489783733242, 0.04341560460987591, 0.03412005844556036, 0.051412095480989066, 0.07124593180994834, 0.05431328960243733, 0.03404712304472923, 0.040163519236469464, 0.03147451744054354, 0.03938264198481076, 0.013039766420279781, 0.21623164144975526, 0.13779424311172578, 0.22380645837514634, 0.15650226344023982, 0.17401737761833977, 0.2812206727122107, 0.09115522396900962, 0.21143997598799968, 0.11796001224748551, 0.16239960828135092, 0.17321557467502935, 0.14942381020274856, 0.1270877430215478, 0.16308269823991484, 0.08340546320522986, 0.1140875067381609, 0.15868673251280863, 0.23584686309820224, 0.2100072996390443, 0.1932334061712027, 0.11000763654949204, 0.11533629134177201, 0.20174614454229034, 0.2343287219804141, 0.12664757188289397, 0.2292573884610207, 0.1012316320632254, 0.24802847314746151, 0.12640945643426912, 0.2875518684666003, 0.1801865151332271, 0.10702265922220484, 0.31861057444926233, 0.05680643848233646, 0.10728256987227548, 0.1266496709638065, 0.22955725059634258, 0.17447776581731536, 0.10697701570367622, 0.12870634124884683, 0.1620922538061296, 0.1926883499348356, 0.1551672633016302, 0.09381896530788753, 0.15997927605865464, 0.19307545416297453, 0.09516532653041425, 0.1861732624351017, 0.1462778701416908, 0.15804030752230078, 0.1440491211870986, 0.11112585678816804, 0.17889767945293458, 0.2022038054682555, 0.18612300706726892, 0.15130080222602815, 0.1543308025406253, 0.1432834622720557, 0.20288995977851654, 0.1291340787804896, 0.16752133506440348, 0.0812227025087322, 0.12475686688576976, 0.13780872217349469, 0.10933452105570225, 0.12115645282451185, 0.16235837742926615, 0.14784982127528037, 0.17508489049730763, 0.1701342311477469, 0.23013656628468346, 0.1532477687203115, 0.1733348698865983, 0.10967051955841242, 0.1370378691823252, 0.12184937935202353, 0.14298914661330564, 0.1710765039728534, 0.11397923553182233, 0.18203067262807202, 0.15741344841737903, 0.21213348474233382, 0.19126267562950813, 0.14666308979353598, 0.09998267892027095, 0.09435682797864561, 0.11938594702270725, 0.09957451493509355, 0.180785519281222, 0.20681891830698138, 0.16695234624128188, 0.2151667639132469, 0.0742014607174262, 0.2597867276880049, 0.14358726209930836, 0.16083954683234616, 0.10966605326581387, 0.13627470771391548, 0.09147713411479227, 0.13942490722383225, 0.08375250869580815, 0.2298356316262676, 0.09256581400310801, 0.2707857278085524, 0.23978997893150777, 0.14023558146530582, 0.06138538814059669, 0.2118345572342796, 0.16878441486868168, 0.16058019542646024, 0.1472434626832124, 0.11735113322614663, 0.11468933008971716, 0.22595887432896325, 0.14631062806133302, 0.11098038435222642, 0.1495105466775356, 0.20484639511954403, 0.14829884072945965, 0.14861505118108567, 0.22078105458809485, 0.13753823184918973, 0.19258635298859691, 0.18664491212656423, 0.13853341070634706, 0.09642765556852664, 0.11496778772843462, 0.1669522389889725, 0.22966235785955386, 0.14357059202607603, 0.15474055232780595, 0.14918252315011718, 0.11543955233308578, 0.10172302384049663, 0.08670545588698118, 0.19104392688360908, 0.07787816947506321, 0.14254703727220336, 0.22779440567378076, 0.099464098682567, 0.0992778780299329, 0.2265088182062872, 0.08281029715773561, 0.23336507530222017, 0.12747146880194066, 0.08424024623368057, 0.15394435714810126, 0.13582487620653647, 0.1967299080664112, 0.13300738868213471, 0.182766929088581, 0.2219059780961083, 0.10615988334100093, 0.14810284479491173, 0.13761048926220787, 0.1333452181349839, 0.10888029220363787, 0.12869661193220847, 0.17969074899390822, 0.09506735920665726, 0.08889734835153626, 0.20923045584030692, 0.1448512458873372, 0.16954468052473762, 0.12179541611863721, 0.09965044190926899, 0.1486618591532592, 0.06684097221061107, 0.16129884718646928, 0.0950322877014837, 0.15879498073650947, 0.15286017419590106, 0.11215582369796692, 0.14008515244049413, 0.10958660228718674, 0.1154328107593521], [0.08454411500884641, 0.04455679599496146, 0.005677795533331172, 0.0498500460338208, 0.02975790017855264, 0.018035372148358056, 0.05150257046484659, 0.03722597424301409, 0.026634626743954518, 0.011374983624855598, 0.04728620639070869, 0.02907636346325519, 0.07124657532380474, 0.07758589161019172, 0.014466553468317276, 0.031585220976041696, 0.08808240700032442, 0.08740461837019652, 0.008467358195283001, 0.019010981289489616, 0.02882721060286126, 0.02029674112676613, 0.02675350060716512, 0.04384743305103433, 0.09462194802660136, 0.02100750409637488, 0.09049848743504094, 0.05525424092587444, 0.0331077958276916, 0.039871724006990274, 0.04501594313149972, 0.004854134186321209, 0.04599324532694394, 0.07120056408307246, 0.041450175396617384, 0.05107998870493424, 0.03600142866132721, 0.03845488269542975, 0.039535419069110386, 0.02415176067921904, 0.034324814595522425, 0.01035404506124436, 0.054398865454019084, 0.027903279837881847, 0.032164596036196716, 0.02923503559413216, 0.06913663894538918, 0.032748531234721025, 0.03911798158960958, 0.0009034586213191131, 0.12319325844967559, 0.0712588480523517, 0.05850520398047182, 0.02473732381458244, 0.004840359446637694, 0.03685707226395607, 0.059888333592924385, 0.046294704755587925, 0.02488833506621661, 0.008869465297809052, 0.02195833220837578, 0.0477436987773305, 0.04793832341449396, 0.033946861287639025, 0.0034671681491853373, 0.0321382655942392, 0.008285880584510104, 0.030173663755938895, 0.01137373298631921, 0.03408370757355325, 0.03577172868855057, 0.06005142222068483, 0.03156060465581475, 0.0654251421351106, 0.016370883339174813, 0.05490662086935294, 0.08275827212679772, 0.03403263249164147, 0.05284684792821927, 0.05136861616084653, 0.003348479583491421, 0.1419189371048443, 0.11718451676349487, 0.015152098738678522, 0.045678130381049654, 0.055040372160053065, 0.047691838455296336, 0.024016975169821132, 0.04446695303364147, 0.052624360673249736, 0.04362540544881936, 0.06830027777581446, 0.04313817352897698, 0.027163005246210004, 0.0267977211173744, 0.0803042320354331, 0.03222963307052851, 0.03771623987103662, 0.026791431535516056, 0.028318420968829628, 0.040927990715229706, 0.05254206750842352, 0.02605421746510171, 0.035034748274953134, 0.048118917151324214, 0.01811586309134239, 0.03157619837551348, 0.035626872953388004, 0.018011177176489465, 0.051883534498272404, 0.019164122265553283, 0.014849622328315052, 0.02933665141162853, 0.01513137510271683, 0.08042388730832646, 0.023115642083388184, 0.027063197396214933, 0.02356511352944278, 0.031457088940266165, 0.0031775136566495584, 0.04781950317743806, 0.06694265506080083, 0.05351074738427997, 0.04862837328184997, 0.013487082286437434, 0.0242223939858377, 0.06246512778283608, 0.021871337178914298, 0.009291296291555609, 0.06805461636113544, 0.004137630345329883, 0.008638638218173818, 0.0869254150518006, 0.03181062511078293, 0.06200976129020415, 0.04000251819830268, 0.047521575414125, 0.04229673319646428, 0.061214600329197226, 0.030711359802573442, 0.008896732282254004, 0.06366872085979389, 0.005650123001091303, 0.0554924636268087, 0.034692230364007336, 0.07448213235024484, 0.03181844686848983, 0.04788442912902083, 0.030784369896977182, 0.07035905480264656, 0.0608988342085673, 0.033036028710945, 0.055836716726903, 0.019309797714794838, 0.061978681103116086, 0.033763540277798335, 0.050279679633076155, 0.01424687775602985, 0.007590022334273184, 0.016425133855532736, 0.011294731126737692, 0.08234211784457007, 0.05444793338556925, 0.06835892180641813, 0.044424998228468245, 0.01615626380718764, 0.04185169356905165, 0.004878030862704281, 0.05050215922716645, 0.024610461569541407, 0.054584128496747826, 0.032355072307250196, 0.015206608767320794, 0.02102657394003003, 0.09935516864061357, 0.018951682253710685, 0.05388038097730568, 0.016821423477883783, 0.028365280651938052, 0.037718032516779444, 0.018038739104785265, 0.011824809386575175, 0.026225621977280227, 0.09756414700419673, 0.04281113442454127, 0.027716612939031857, 0.032133362631523804, 0.07076089856244865, 0.10461521259839497, 0.01319806221046395, 0.02363472793912215, 0.04626149101363075, 0.023386216677364804, 0.06487495310965084, 0.008891540121347194, 0.07291875374052795, 0.05179665629721938, 0.0013018091398877122, 0.020223449495050217, 0.059219431582718134, 0.05297708670578657, 0.017189132274999734, 0.04541386069068986, 0.030053621608643766, 0.06883828600327815, 0.031003767902392055, 0.020529963188774644, 0.0653089878840312, 0.02992418722339696, 0.05097250273871807, 0.01851253192721596, 0.08051127495784914, 0.04761496153209479, 0.01938702320800193, 0.014086490545812395, 0.03368059593823648, 0.08058970703953698, 0.03614227009576655, 0.032662978365777, 0.0632509463016064, 0.018691534116383524, 0.007498357998913215, 0.03133146967288227, 0.032996138512727716, 0.011021453199998267, 0.04972647988207398, 0.0761475921758721, 0.016662948614647313, 0.0052452819222854755, 0.09329001223968883, 0.018504683356431705, 0.0867250370943258, 0.026489489471479773, 0.046603645032812516, 0.015032472194082316, 0.04877398361361796, 0.08341405105086104, 0.10864449034054434, 0.04531340358117896, 0.06039889672050073, 0.006080468583311285, 0.0043512740728235055, 0.057788295070490533, 0.028733730639120745, 0.03669342056157128, 0.011672514937667838, 0.03195875970226142, 0.03773212470414658, 0.03384132501519015, 0.07664649161480128, 0.07253183337349085, 0.05170282967869313, 0.03296055755908451, 0.02615327837937061, 0.03268201182025575, 0.005747908857771226, 0.05386955232449597, 0.029162642200507467, 0.05851261971157886, 0.06021817274872334, 0.04173555463973073, 0.08136083582235921, 0.00833411826827233, 0.004707963173953636, 0.048010182461791465, 0.05045163955899978, 0.014920711457248659, 0.010334845940251986, 0.021317356018229358, 0.03704087207874945, 0.015794321736921708, 0.05645521781257084, 0.028881746486970977, 0.02014528362891607, 0.018573081601531278, 0.005801627900631678, 0.007742667268405879, 0.046063886294441844, 0.04731304245069624, 0.045370197509445494, 0.03463128040875158, 0.014510156320137604, 0.03512769006192684, 0.05429515630126961, 0.044099092934160464, 0.04106388705211782, 0.006463939160664356, 0.04891103674327174, 0.04684278703925591, 0.02224969651339756, 0.0724663558386026, 0.030510246400691332, 0.053894055646754084, 0.015391915860105188, 0.10883630343502569, 0.044540819231300585, 0.01707340894837774, 0.019342241538388115, 0.02780440853037421, 0.030497506358510548, 0.01592471756251349, 0.023305252675087224, 0.041744992842957865, 0.005390113717200416, 0.016791115124379436, 0.08904495817278663, 0.011227692687703718, 0.025914670719254403, 0.06344406557599865, 0.04354315441882899, 0.02019442050837942, 0.09629764278689701, 0.03670466673229972, 0.01857300882317847, 0.013725322224349986, 0.06653505798068739, 0.04554296948856885, 0.04937451993746143, 0.02595699324663128, 0.049516705856207884, 0.013830318404812247, 0.02084113661229851, 0.03154675570136357, 0.08403566245350146, 0.04687042749156395, 0.12763912714416945, 0.057059825893731854, 0.02405402892749877, 0.023405742343334902, 0.009228412921900951, 0.040694173019860065, 0.06684186853348248, 0.0628507994265566, 0.0744706180487429, 0.02183252333423063, 0.035156667337662754, 0.04858482501379425, 0.06754758872932966, 0.06406266625309665, 0.039045532654610374, 0.024799587610628337, 0.03266420027601623, 0.02649175134607621, 0.0843617401175922, 0.07231469341223279, 0.08570511359721424, 0.016183643789601423, 0.05432841600850225, 0.059924217151297685, 0.03440698901672037, 0.04554082827282049, 0.04687464097514749, 0.15039649671844899, 0.1263796326313769, 0.0917546724480006, 0.1614775601774454, 0.13725235847936523, 0.10862842547677218, 0.11666652641349262, 0.16580025725547345, 0.19190582176370008, 0.06821502751160054, 0.13652500396053638, 0.20992001158095178, 0.24500165975862936, 0.15122212499620455, 0.1286445026315989, 0.19450855952116752, 0.19835882549805028, 0.14563751256754323, 0.14026536696380185, 0.16024343849670503, 0.10467433926439094, 0.09792158064702827, 0.17702715321173593, 0.16604560457410353, 0.14252319661599977, 0.1391139368136083, 0.19794138418810983, 0.13312769512976372, 0.16784440966383105, 0.13329533048935477, 0.1333069903475623, 0.10774771547726086, 0.1831771691720332, 0.11440174068294226, 0.1665894657133087, 0.19952013818246706, 0.13171404840484743, 0.1113849477241597, 0.17865187248154996, 0.06098762762943103, 0.1145085946266209, 0.11183135481851716, 0.13551637259942872, 0.1895288041522426, 0.1478371501810128, 0.12440003079151916, 0.17689184676254952, 0.1909565162514487, 0.10524435464533106, 0.1136006502014014, 0.153559735044837, 0.1356864287968605, 0.15323675237596035, 0.11041480462036787, 0.1311378430334791, 0.19008144465906007, 0.23002425779498395, 0.13907866612557443, 0.14807849852067811, 0.18725569870683456, 0.1900419145221672, 0.2554192451099234, 0.11593866627663375, 0.1643795625216538, 0.15840701848989533, 0.10909525647519097, 0.17401196903759436, 0.1359618680491563, 0.06939401384443045, 0.06602619939874257, 0.09889811292410859, 0.14537244614574218, 0.11239687326334177, 0.1810365816157672, 0.16295911293596993, 0.1573215025447069, 0.11821344179371673, 0.10038541134206519, 0.09310912355900773, 0.1880170368859845, 0.12538268411111447, 0.3272548041516735, 0.2903923692722475, 0.10686279965504523, 0.09226026749538799, 0.1940471294426149, 0.16272199340164661, 0.08711748095529695, 0.09502140159207968, 0.1530957462326173, 0.15419895880885665, 0.12224594476602732, 0.17275621303387229, 0.08585754977238756, 0.14587193547237307, 0.10187606522513014, 0.10723359387127623, 0.09179297684421463, 0.11152362496021295, 0.11420003739335846, 0.08475238367194131, 0.15644250858214595, 0.13737957504007126, 0.14549212440127327, 0.11463512170819506, 0.15135318731829045, 0.11288343868669003, 0.1893928695109583, 0.15871481729611275, 0.09078504262311805, 0.07677347834913001, 0.12808908122561632, 0.11742483854534165, 0.10107783225154686, 0.125623534493629, 0.10639229909546914, 0.19137369709149485, 0.11541888328088869, 0.16936451196670535, 0.15980329034068894, 0.130058869479164, 0.13783931972519045, 0.18262987595892724, 0.22185311802933294, 0.09348312002276221, 0.16364324477411088, 0.17982838435038445, 0.18404174535985918, 0.09897187953033755, 0.12291591163844832, 0.07678071021913521, 0.18017727611286027, 0.18846044857655803, 0.10660149472495241, 0.13576185781388514, 0.22351067182758164, 0.12609844005876972, 0.15728518997709598, 0.19900247725027226, 0.15805051181345217, 0.07951464819451494, 0.1589721155863616, 0.03861336713476527, 0.13772518794623115, 0.10576753141058069, 0.12144159074992904, 0.10761350453380616, 0.27694360383095284, 0.10674024090891886, 0.21779986939603285, 0.19444295175133214, 0.09132023930789963, 0.10864969207755021, 0.11401052256264996, 0.1412395243683169, 0.12691796261576876, 0.12510958142698775, 0.2130211661419561, 0.20801931679729493, 0.07879339173556336, 0.10271990341284584, 0.20156297291959488, 0.16836887345679347, 0.13366821612561905, 0.16639607447770335, 0.11192011376542431, 0.1360813318000686, 0.21687091117905033, 0.1322166174049339, 0.16343413341429927, 0.10822688049126057, 0.18348826215632502, 0.1384127365365144, 0.06427972577512264, 0.18904782350986235, 0.08924005778446313], [0.03940743642048009, 0.05926773725678364, 0.023860685572388674, 0.031210753368213776, 0.01614608441389376, 0.028747414884668206, 0.0322768623910604, 0.065836493046053, 0.08443101744858489, 0.03783938467442509, 0.04270684687540897, 0.07321200453706327, 0.06454738157410776, 0.018591574964023406, 0.08546716668793271, 0.029016127884988824, 0.06085132909638267, 0.1206127449028915, 0.023216373069332014, 0.044282505874552076, 0.04458676152411969, 0.007902180180779749, 0.019604291488987305, 0.015913663871376025, 0.02557905526050637, 0.042200907088455655, 0.013427978603079194, 0.015299240288685168, 0.037866772317718116, 0.04439794000298266, 0.02031559646580248, 0.08404535346574361, 0.04737587698224572, 0.012409542274150639, 0.0703064781884032, 0.03536432696085784, 0.04568331679629703, 0.01949745095184734, 0.08316024612154692, 0.03369890543962679, 0.030263165808132583, 0.04064485994017413, 0.07828530690242207, 0.051942063615687435, 0.07458604451629423, 0.0409693326500635, 0.046695897340654366, 0.0701091415999878, 0.023740672153390707, 0.05631240370172647, 0.03975155545518764, 0.1293389153696837, 0.07086436639750196, 0.04616776398653465, 0.023791668711290247, 0.014253711260314432, 0.025412030856034933, 0.04740123066209978, 0.06096771700427898, 0.0064747199329787935, 0.05676525742596677, 0.035093005431155046, 0.03935461848854058, 0.031647176421698064, 0.05009904759184969, 0.055252168658039266, 0.0052547282651968065, 0.03176969111776881, 0.09027811458274242, 0.013826395077030025, 0.048147024917266065, 0.020837377035810102, 0.05625399715837933, 0.040955573710943424, 0.03277905600806398, 0.039664240584017775, 0.05613040802399478, 0.005698349672339616, 0.06918197602874811, 0.016288678274459897, 0.038657286955464276, 0.07341216032904002, 0.03499077482809944, 0.022837745604075255, 0.04625866031875053, 0.0296514043809786, 0.02983796402751919, 0.058541401634894075, 0.055669000928079894, 0.05639609114657487, 0.016806952076994123, 0.02533896138981706, 0.0849473760313084, 0.02503402966765627, 0.0344993983725867, 0.018411188070932706, 0.05379447570791649, 0.04584867687475297, 0.028826789254502907, 0.052290419116616256, 0.05267044852277445, 0.024069306635928732, 0.059746358348357106, 0.02366264992874236, 0.053024599478850444, 0.049163412918607076, 0.06537433518397232, 0.038802525734588984, 0.03885943840648379, 0.07894713026020797, 0.016942861820420912, 0.023682271355702996, 0.0489798084562344, 0.039208613621491584, 0.02338541228504431, 0.023147704778239134, 0.008406551881513048, 0.032394341974248814, 0.03048519341034755, 0.09817185391101146, 0.050957993033432195, 0.0464348528804558, 0.06155180925082776, 0.08915244030856317, 0.022296925833929452, 0.03876773768194741, 0.025818938457016504, 0.056021317103577245, 0.016470442210594495, 0.011743424993549145, 0.007489541284514652, 0.0431650938586362, 0.08788356121869818, 0.01530805317264411, 0.0592587280627941, 0.0475868997314284, 0.02864418453687141, 0.04540962039402897, 0.03283876107044278, 0.018157817896515615, 0.04545917479141105, 0.009766464241810385, 0.019574029100758415, 0.03250113080045389, 0.07339510721184554, 0.07629258197642143, 0.04890504976614349, 0.01926022799565427, 0.07319285233895625, 0.05571941334393717, 0.00950930672021763, 0.020722061651007786, 0.034112700171047644, 0.08734431958967641, 0.01613285982110087, 0.025305050507848783, 0.006719199178229657, 0.030152638472857016, 0.02115464660399143, 0.04428798340321068, 0.049562686453423196, 0.01850518897446173, 0.1266465223424377, 0.04968655904033973, 0.023557806965864958, 0.04262483716311474, 0.04778793652451808, 0.0313723347179832, 0.004513809202058662, 0.04946113383818058, 0.02138133202078602, 0.015050665824674072, 0.0178081389786976, 0.01971489926349492, 0.0844979199070123, 0.0562525071173666, 0.04083183901985327, 0.02723021030936751, 0.041764838350636345, 0.0275903195142746, 0.04165578573461502, 0.021706436753212925, 0.026235535155020417, 0.006689539126631234, 0.015313800747296023, 0.008655357129511335, 0.049049610557455214, 0.027900041201181953, 0.024701003586092306, 0.0484559383814133, 0.05849743967935924, 0.012828239968286888, 0.0344771703314637, 0.014705403403739535, 0.06119286641478539, 0.061446498974316546, 0.07453239537895688, 0.01772185449578589, 0.07336100097745657, 0.04414261055869922, 0.030564424138696446, 0.015171514279509505, 0.022996471361106923, 0.024364348162987062, 0.023161917624454346, 0.03252293749321853, 0.023717093882301164, 0.03700731742766596, 0.03486505979972501, 0.0736143232713784, 0.02039108293942146, 0.04780826849802848, 0.018489196889042374, 0.014718461372408898, 0.010121226153005997, 0.016735062386179646, 0.04898645043853791, 0.03230116270001858, 0.0281231566482494, 0.009447131981892933, 0.05444040274127357, 0.03677576735255219, 0.02192337178595124, 0.06152523366073447, 0.06597562227398157, 0.02081281242651805, 0.04688376125188605, 0.11242201626901666, 0.029650739799704284, 0.025889927994519956, 0.07731239822122359, 0.04320299605868998, 0.021615278035882982, 0.07770248253138796, 0.057671700318854664, 0.03702356615253995, 0.019780844112016985, 0.0787144004096908, 0.006678380577209136, 0.06366894685573156, 0.030971417924569502, 0.07576598079815026, 0.08675751156143605, 0.053848733885153655, 0.06695493545022703, 0.012870408320469002, 0.013448191832961335, 0.030645453258447593, 0.041666495643796465, 0.021520396131241036, 0.0071956407496585485, 0.035411644381501024, 0.014174037158579357, 0.016112908976332798, 0.04887928622924993, 0.03669433220620117, 0.030920427112329393, 0.09796651170378733, 0.01098117421215941, 0.026155532593087807, 0.10922668651948053, 0.017780640252655553, 0.03259651640790605, 0.0260377848791259, 0.031514846224097476, 0.029935925605616746, 0.048669906738664837, 0.06808345191060536, 0.04672845990787591, 0.007963746358009597, 0.04866421470538743, 0.021614490880540783, 0.019778199193458405, 0.03409337560315767, 0.0449024357141987, 0.03950212488792116, 0.025057508347315655, 0.06692949367026169, 0.004569638817150507, 0.033657264730502526, 0.06528232802426623, 0.06433442445291628, 0.036817553618382064, 0.012830712517062503, 0.038137201354989124, 0.07668752328402574, 0.029544789839776295, 0.07359933859157948, 0.004975250771930141, 0.010161594198566052, 0.02093777477350687, 0.03903866084592958, 0.08497945213269803, 0.06714175365144207, 0.010971922742863818, 0.06663080364946397, 0.050635198056096994, 0.06930061240470217, 0.022730652257920276, 0.020152036693968603, 0.011283465803811147, 0.03431348032468269, 0.03712020431374831, 0.03055746997556379, 0.024046184187154138, 0.017388989292686025, 0.017934455386092587, 0.025983662682495294, 0.06702697069774713, 0.029872805706315467, 0.027684153793680093, 0.1110339109154959, 0.033364634465185866, 0.022094672876259974, 0.0604316431488241, 0.03310643985206562, 0.07451773245608614, 0.04582288269434245, 0.05774206932513945, 0.04520851082258648, 0.06006310506153011, 0.02754623306945207, 0.02849940924094089, 0.024484076214233236, 0.0112702670664857, 0.02095463253828066, 0.08472696487461367, 0.0482031025533234, 0.05868524230355698, 0.04280855270823644, 0.015216372557915749, 0.03431031638155541, 0.012224528209997282, 0.028875372635440964, 0.0516216779848741, 0.01826037600215885, 0.07538310537535338, 0.002438026938527342, 0.00428731722246495, 0.047322396384251696, 0.03616886866849758, 0.05903924387248774, 0.09234090591029775, 0.03681700203507658, 0.023628683505399574, 0.03527220105752349, 0.010330123008198796, 0.05780327208941022, 0.050040326952453584, 0.020697198267425262, 0.08326646421224841, 0.07463908844417141, 0.13112745488122587, 0.20411409167272432, 0.20171761542799013, 0.08337344839087418, 0.14206005050049675, 0.11745595703682593, 0.1347615002023597, 0.1636285052424477, 0.09045999151684585, 0.060220233525239655, 0.15870928614129945, 0.08341534573945307, 0.14020849259630327, 0.1799526897769782, 0.18378876780550327, 0.08542907679633749, 0.1723495735636642, 0.18267653071351592, 0.14232726196848577, 0.11999059723870409, 0.19086371236030134, 0.13362326208622227, 0.10184303151383516, 0.07926117268300827, 0.15876265182610483, 0.09822368741996827, 0.08742846668727937, 0.12545674183075467, 0.22744416559655822, 0.19068985636676514, 0.11955713703026695, 0.1426938503620125, 0.12604072299455443, 0.12400854454045335, 0.16337793320417404, 0.1544175696589293, 0.1172806301544751, 0.12332188461216227, 0.19374512226110507, 0.07512929278516, 0.15643449530245798, 0.15634362195287982, 0.11992872031705996, 0.2012485244701947, 0.24338535213422394, 0.18902965190429843, 0.18912351299678126, 0.1450944328380208, 0.16223275433144263, 0.13247871140558876, 0.10979122437176206, 0.20164474514463257, 0.1349072867343503, 0.11005233011899457, 0.1444210262308198, 0.14566818672803142, 0.11890653686057176, 0.22047397590452628, 0.14913531681222303, 0.22692722478701224, 0.1775755955567283, 0.1523409657660992, 0.16185153365856217, 0.1755659630702388, 0.16451385773478017, 0.16492579853342426, 0.1347594624084811, 0.13895500421283707, 0.13530168411952836, 0.10073664733358931, 0.09424645003051528, 0.10903849702088103, 0.12049683579994787, 0.1773446813345917, 0.09576996908553186, 0.07940745717214961, 0.11145712086750616, 0.12658226288734906, 0.09621474441261062, 0.15569206417327927, 0.11774443510559299, 0.23150089226903456, 0.13383315485571662, 0.0803517677911347, 0.1267741832341398, 0.09084111259829614, 0.12960215850222495, 0.14126224653615108, 0.17111416485521103, 0.1407387786574902, 0.17026356211112392, 0.12105007385534626, 0.1532031824031184, 0.07956081265283209, 0.13368266454387095, 0.07831286308505843, 0.18054250086988174, 0.1749619487072191, 0.1934293867839921, 0.11266164091085235, 0.2338932622824946, 0.237305739654168, 0.0976095836789858, 0.138031990838147, 0.1667512175176413, 0.2314518473201221, 0.16425708038431985, 0.09036511152742371, 0.12389902461079821, 0.26929014031925513, 0.11084338484872734, 0.1107632520518476, 0.08052118813558932, 0.10845757254789914, 0.12795654035383655, 0.08617007534109777, 0.16900115646421912, 0.18644733805089228, 0.15752914301570387, 0.2653570142724822, 0.16794947096176688, 0.15662615517935446, 0.13912653129908348, 0.15805736063949524, 0.10455214057958896, 0.10862176817271019, 0.23787065288953244, 0.127491072991923, 0.09619681029430321, 0.18436531025555827, 0.0836944775355439, 0.07795253362987312, 0.14666068427745374, 0.08104493180590291, 0.1441979414272693, 0.24373635829937076, 0.11474094909405518, 0.09965046489190671, 0.11738691719308977, 0.13344969720609728, 0.26240086483378566, 0.10144295741713817, 0.16084052742488925, 0.12698789878237632, 0.15080142015170667, 0.17259832231267808, 0.14726330436045124, 0.14175114852766837, 0.17807493166577432, 0.09872521454047772, 0.16632867406212515, 0.13666582624277762, 0.0873562399177782, 0.2419175583148195, 0.11026846650507181, 0.14818420333247032, 0.12044924641809157, 0.14294819155287358, 0.11152171740128149, 0.21938153452450232, 0.14128567350487556, 0.11302180948757357, 0.1318217297234843, 0.10714835126794155, 0.12415420849837604, 0.183386602288773, 0.15842883667397886, 0.10405784532908471, 0.10069895580771471, 0.17454196398537006, 0.13067679599888865, 0.11613838539849367, 0.1465638354420662, 0.14412243580145223, 0.21805634031132345, 0.27672965079545975], [0.018838569371690674, 0.032945787383904385, 0.020967539204584978, 0.044618515868581114, 0.07214614640801184, 0.005111392256954024, 0.025541735287275047, 0.04501578608347524, 0.026390512826882546, 0.028225913936752948, 0.037125486489986224, 0.03872757935295663, 0.04308987934623034, 0.009303350685044162, 0.03503079526126385, 0.015156370636466292, 0.019611331837011442, 0.012398695426752732, 0.03437814963681083, 0.014973733360098015, 0.02680968932597147, 0.04460233609162031, 0.054265711711899894, 0.025410295666886434, 0.03819850371069005, 0.06051268759033373, 0.06729934559834581, 0.045519994511719675, 0.014496054556671412, 0.11028173514792036, 0.01998667470029285, 0.03801350496829518, 0.08454783819615842, 0.016568206521051548, 0.021846504438848748, 0.04412371116960722, 0.05328826395975006, 0.035517977385391156, 0.04749811397144391, 0.025065230513592402, 0.037814184212155884, 0.029737022367396185, 0.03792319086290175, 0.05487945539155795, 0.01968372906107576, 0.04079107165096268, 0.010590608224212643, 0.039368438714694594, 0.060641604866231644, 0.06586557374365869, 0.023365597420882796, 0.08829607658328549, 0.04352853746123372, 0.03842087222203132, 0.01163769241106967, 0.01589417842502195, 0.08168906619351718, 0.06885952962141845, 0.10333648927870298, 0.018760430318633878, 0.03998720027025669, 0.055918048451384234, 0.016879665312327204, 0.10932466150411677, 0.018505556696665384, 0.08632445737959878, 0.032283071533686696, 0.09104216471314432, 0.07235991558240307, 0.02766338515005285, 0.00437325983864045, 0.039959345313329855, 0.06488082134315083, 0.042815164047022986, 0.017577772509426843, 0.02043618253552385, 0.064186580974849, 0.0635044064913546, 0.0848102616146207, 0.019830896466549848, 0.06479242245756811, 0.0676739702541982, 0.0828467706038106, 0.047598015667209705, 0.05256781955399821, 0.0363058413589193, 0.03138923844803245, 0.02367463920475735, 0.06076994757618635, 0.0018030492168280387, 0.05504956521514443, 0.0729956689681257, 0.00991787960482461, 0.03216105670998654, 0.02909611895560257, 0.02556891800204833, 0.053731844189666936, 0.06270758694999161, 0.02166006736637604, 0.0341453546688201, 0.015386816587359195, 0.031213783245954304, 0.03160920335851129, 0.06529967991575118, 0.08395477889045593, 0.028488477166261406, 0.07590707887204425, 0.0062472200689597, 0.010071637281667321, 0.04692450180769928, 0.05578384516880878, 0.028514690779810472, 0.04828447641264047, 0.04880219097098997, 0.10935932698269045, 0.03552736962334283, 0.042737505714138674, 0.08517226114148095, 0.04116748895255789, 0.019389894122498173, 0.07008412882926003, 0.026089451763959184, 0.03248073370946992, 0.04574640030642191, 0.06951861804531467, 0.030040299339640527, 0.058661095212183656, 0.05190348725826029, 0.03729349340222055, 0.027654033131717194, 0.0743204418329462, 0.03441751506479998, 0.015377387960231113, 0.044593556724008054, 0.05623082299866984, 0.014770350422740225, 0.12214803872930428, 0.030991397497634736, 0.0646413499189, 0.016617126980676286, 0.039904972222904046, 0.014613482428924933, 0.06679612542352369, 0.03089321758447876, 0.03104615171680287, 0.10143185680311534, 0.026379996354901986, 0.04452601075172425, 0.04389543228993013, 0.047527194669049595, 0.02749122604126892, 0.10857908175356927, 0.05124616849746916, 0.024586551965424613, 0.01986193260358226, 0.022128047496681253, 0.060003047598706144, 0.06906126355451923, 0.0472204722163658, 0.13871918702798505, 0.012348915033432986, 0.03276001106226637, 0.06632216214652985, 0.08914783612013825, 0.0355233361704215, 0.042038132556744164, 0.03752090660254321, 0.011464568989111051, 0.04589700936189583, 0.04044669980724012, 0.036382932786739645, 0.02683490127955954, 0.049016124854284915, 0.013856035018820437, 0.008293110539295502, 0.0424261522599526, 0.031225441188942042, 0.007873230675731095, 0.053795912122774514, 0.04520495617461782, 0.01261412796954955, 0.061386123585004004, 0.031496281998472354, 0.12425491841690195, 0.011387424892745914, 0.056547868486133315, 0.10398397913142558, 0.07493899654476874, 0.028770244304811763, 0.02292918011305794, 0.019024083308214625, 0.027162809893789313, 0.03457571605160352, 0.044037518617246425, 0.043679345699567954, 0.02335234218457293, 0.026499743558346268, 0.03101754024805081, 0.04076993528513178, 0.07291260205449597, 0.03391608753572068, 0.09398932027960978, 0.06700067856018582, 0.04895160875974163, 0.02855464418028151, 0.03714516345832137, 0.01526242784870368, 0.06673546658167917, 0.01880616576771342, 0.038676875823688124, 0.030933368252590302, 0.05027552360608693, 0.06429769053694702, 0.09053926629525039, 0.03388836281374097, 0.05824251243123605, 0.051429623572696606, 0.07021882240810702, 0.048886636842883406, 0.047677558576387745, 0.06594278774554692, 0.03853430303053991, 0.016057092767779627, 0.024181055881443526, 0.022508097970257365, 0.013460949112120415, 0.027273925201546763, 0.0606385711580515, 0.06517856141492244, 0.03627714753571538, 0.050866108447793996, 0.03234816985505243, 0.08275335384232384, 0.0717260008076987, 0.028036180770986026, 0.051639776812085224, 0.01977919127732035, 0.0715381866921821, 0.03779882414927406, 0.038863958325237036, 0.07169789304175685, 0.03807219113373468, 0.08202998298070124, 0.07997715079616155, 0.11843427429876982, 0.04458710243324599, 0.03187417210410199, 0.09507041589747514, 0.009454525687972145, 0.03671873976746875, 0.005399757806557201, 0.03424997929663908, 0.04076982420238276, 0.04101896748667763, 0.08213266174519256, 0.03554991942139403, 0.01586139752274199, 0.027381213900122433, 0.03808971922544222, 0.0962064553412699, 0.06299616844062844, 0.051425440732630036, 0.052311099660132206, 0.06725052281493141, 0.02626334797711142, 0.018033732720200094, 0.05314349632469877, 0.06780853359809808, 0.0006373281752119862, 0.03840214520272228, 0.04451678322267629, 0.04504357975336813, 0.04650065217227225, 0.04870839116554107, 0.044893300115701654, 0.049427039095110474, 0.020286617274846763, 0.0974491878502792, 0.09732977772552161, 0.02150964791766338, 0.018397007783454274, 0.05808234642890673, 0.0391906833336238, 0.017140508674445654, 0.04527188161568296, 0.04336511558522621, 0.0716438685213366, 0.05774627514784375, 0.10369410678263634, 0.0850629174120484, 0.0297319604414365, 0.011512709954272837, 0.025879537927046902, 0.02051244275794635, 0.033130989139599186, 0.026313011542022712, 0.05241102050809611, 0.037221710963715474, 0.06112717054483872, 0.014952743508582635, 0.07023355427889094, 0.02075553777807903, 0.026541261693402648, 0.011682792964781965, 0.05072736226382756, 0.06784408773866392, 0.04803451724470623, 0.040938715946169636, 0.02923956891942409, 0.03971934528841127, 0.09033431479286763, 0.06293465924118796, 0.09988527084069868, 0.03529627154010438, 0.03379028057679534, 0.05176888944040384, 0.05075459285909611, 0.03613388143299568, 0.10605828476048286, 0.028433004739664258, 0.02105358236980054, 0.0770262413988671, 0.014456303211890403, 0.021450228223036376, 0.051839959417139335, 0.06298866843984974, 0.01884107064876345, 0.06359330716452773, 0.03715055288686868, 0.03782217450920613, 0.03901012024031051, 0.08630328270937167, 0.06914762464622337, 0.04472622400029533, 0.04707760064892712, 0.054214475751524015, 0.02512154180646664, 0.05773252770004254, 0.03913783858860693, 0.053764261200182864, 0.044673317968244516, 0.03976965045195915, 0.024039383241606337, 0.026031037559732798, 0.015164833035199873, 0.018832120826588045, 0.04024214284013837, 0.040032024074706345, 0.01395186112682906, 0.03657041748444881, 0.04203191575323863, 0.05141237510308143, 0.08721555553136334, 0.1542166554399075, 0.15312355522426868, 0.15572465355357817, 0.17205928752739585, 0.16591719291623563, 0.0946780639670549, 0.17906221981731155, 0.15567666580600126, 0.09824526811679525, 0.19845570497695478, 0.1364563165172454, 0.10889545308365937, 0.0883980735295242, 0.07168321479712764, 0.09902919822883222, 0.10228784514531013, 0.14330206288685723, 0.10123566168570712, 0.05440569895830366, 0.10184354479274443, 0.13722059647402457, 0.12727825376655788, 0.12237182067286585, 0.15381925499006627, 0.2791705907833192, 0.12321582739992488, 0.11078331589458451, 0.12665182367087374, 0.16795621253550055, 0.11194159487082113, 0.1372967149701811, 0.1515533967364219, 0.10894328761365145, 0.1327667451433597, 0.21938712696634957, 0.12973475300015944, 0.1930976247475032, 0.1932043101518385, 0.12229187939796718, 0.20379261053617925, 0.12688474504337197, 0.15693194683521025, 0.18279817015413316, 0.1527968953333555, 0.10380469923538548, 0.09583554621185027, 0.09698313826154317, 0.09571448133717622, 0.18509880879953985, 0.10992139037097655, 0.17053526285434925, 0.1635502417001032, 0.12379584022827687, 0.12963572847506694, 0.10687268218926846, 0.18981101562178906, 0.27782592261510514, 0.15432733982320757, 0.191065316058455, 0.12191205300510892, 0.15998967953266638, 0.11161539463266251, 0.21414619690227896, 0.2446180948567006, 0.13152375216445616, 0.1280347579309056, 0.14643801316138239, 0.17979216371332446, 0.10778894632934563, 0.10759139523631144, 0.1780828530149114, 0.1534345256344926, 0.12349899647937668, 0.0939138146537927, 0.14293821708809945, 0.1891715007443582, 0.18347813447396602, 0.16852003792601247, 0.11083197779953481, 0.09660111319634224, 0.23190855829706117, 0.12656697943325967, 0.16550987928865418, 0.14872798786288308, 0.13702250145856412, 0.17365253590528043, 0.12277515830412028, 0.24482420315184902, 0.11031019531430737, 0.1160702188949912, 0.10435466609534719, 0.05832905355360239, 0.14860346793167054, 0.26090110982618026, 0.11576185318370981, 0.11193116075329243, 0.1999987592740405, 0.2164904106288187, 0.16692738709670885, 0.12816980391019775, 0.18367613755887557, 0.14322550005970464, 0.11330109450124926, 0.14526125614441213, 0.17147255610794793, 0.11032035364018333, 0.11226265465900784, 0.10270256684311938, 0.18805627590946614, 0.174087398054619, 0.22997908925096835, 0.22470187726280383, 0.14628428995849627, 0.1866955198948422, 0.10746695957477055, 0.18752890098239147, 0.09935145311418081, 0.13012093792278923, 0.09965264824249091, 0.1570414514431069, 0.16797226973839346, 0.16870406756718315, 0.14228765522280049, 0.13666748099269407, 0.182773333583628, 0.10082224233736915, 0.144713610530861, 0.1370458211749792, 0.23699270080654855, 0.1766919131360708, 0.09045138834945618, 0.12000097006919885, 0.1114149247446368, 0.200185623440531, 0.1333823733993115, 0.24807707376537785, 0.07730081497180848, 0.20531429098017756, 0.11161801465336355, 0.09133721581630169, 0.10186669596981618, 0.16499523674288105, 0.10820615781290878, 0.10718140796187425, 0.15434108344056915, 0.0658031682213468, 0.13431801190299375, 0.24155260934945078, 0.24415638898649525, 0.12188886352364095, 0.31019641627227107, 0.12576252582573122, 0.16363322434406127, 0.12840031210573452, 0.191365530594222, 0.11032832861547509, 0.21192719258608358, 0.17620518683425843, 0.18123636202466104, 0.14842426464442285, 0.10309586106168647, 0.15859673250346415, 0.2514332283528582, 0.12469735717581165, 0.08978902106924404, 0.11386799956521682, 0.11090114787821809, 0.09938585046198099, 0.1696867285476577, 0.10847255722769808, 0.09376797449564743, 0.14367753790030557, 0.15954963862895966, 0.10934112473360955, 0.19665788047977034], [0.021884109779831865, 0.05357148666535655, 0.02229927197819756, 0.06807572208344936, 0.08396399492818503, 0.08634157944470645, 0.02013982333723576, 0.021085501423165686, 0.02516265391492315, 0.037994191891724066, 0.0973107710841202, 0.018556275547692375, 0.054368662437604326, 0.02374535103538825, 0.02814460711012925, 0.02663826949203447, 0.06724376591943926, 0.02368127735662124, 0.014440137799078179, 0.016998069946684184, 0.08157412236135814, 0.012693216971632455, 0.07887475793400119, 0.029481612483880697, 0.06053133417041071, 0.05558259004066068, 0.03520616044801089, 0.037258272509901755, 0.049514465049029364, 0.03951073188575045, 0.04450770891121319, 0.011026852204644633, 0.011765765075031067, 0.05194177250227621, 0.01122313829499387, 0.049907134905938184, 0.0014901099606387078, 0.03805324960980685, 0.05135716697681816, 0.01565309630091032, 0.033807762703227426, 0.06079227903917913, 0.04458942367965656, 0.020331598127320893, 0.057098907869189024, 0.019878495424505205, 0.017685892413400354, 0.05171422906700642, 0.03219379164699105, 0.018322005860447403, 0.0740083146299566, 0.12518533220094058, 0.06628244814853515, 0.04236899060948242, 0.031190572697068417, 0.05866267335330767, 0.05575338934337901, 0.045545237108824715, 0.041516380715033704, 0.06383773517764865, 0.04552790053909825, 0.10396671150961231, 0.08434618853272931, 0.08955073708127584, 0.04296725931307001, 0.015936314218467282, 0.02253327161944922, 0.05691307409095669, 0.02267983381546313, 0.09608285471556649, 0.024112699771179788, 0.05786774221867804, 0.015003849234011386, 0.04809659334921068, 0.01968748097668492, 0.08257857088239924, 0.020974207999965837, 0.06129028598567652, 0.05238707643002272, 0.03869571392574618, 0.061316298501145464, 0.05157516112611179, 0.006831299866579714, 0.006527273564584434, 0.04591258009895683, 0.018696956103667617, 0.0020879937050443504, 0.025432207696740667, 0.010700092722301283, 0.0475273210735571, 0.027014093075488365, 0.05938524748348902, 0.04324449887198787, 0.008498764927348783, 0.04839137632159456, 0.007125440282717108, 0.04213495074861473, 0.04283711246605362, 0.03553514541577428, 0.01162413552763962, 0.05209372604205724, 0.02895446355274368, 0.022810672056831183, 0.06152233401794107, 0.07449514052319912, 0.018342964110835906, 0.019420618078701442, 0.025410494849746747, 0.052824213860496405, 0.0343280857909591, 0.0625883530254566, 0.04868340520789066, 0.048013135730739565, 0.07774532216811374, 0.05667763228918757, 0.048586993042619965, 0.08364082839820655, 0.02126507243261703, 0.06531106398230599, 0.047931551197243315, 0.01725260074430656, 0.09378988461028184, 0.08127610649793379, 0.0745846042709966, 0.06415183505704326, 0.071609616730242, 0.10381836624395463, 0.0164432748175797, 0.1029755775966952, 0.012833488628178114, 0.010871723230417457, 0.08994330351631488, 0.051505355194451354, 0.009481743834311924, 0.03064661962731231, 0.05173609321636539, 0.03707985063233683, 0.015669759670873324, 0.02101818527725916, 0.05931201713880705, 0.027234810667352814, 0.06078687045843371, 0.0864397919165992, 0.042894917630380204, 0.03647147339858836, 0.01890156478170426, 0.0317589160911138, 0.039332650917311834, 0.031188623003301122, 0.0453829950082206, 0.019455752786128752, 0.03297021409737007, 0.018268714869214643, 0.02492635984033827, 0.02040173539200858, 0.04612939830328669, 0.02926920694599469, 0.03794683616668467, 0.013351673372991145, 0.06883835495119134, 0.04737963081307469, 0.04761879580215581, 0.007386480433671105, 0.06780988957372404, 0.07769444626906226, 0.041857676715740276, 0.03254090225504291, 0.050695224875403996, 0.06634090065715775, 0.12408639439531874, 0.03899757938099004, 0.04458086264710273, 0.06275696514715111, 0.046755422372370965, 0.005680763645232806, 0.06688130673982444, 0.039819449997477, 0.0688802982650457, 0.015683617243813654, 0.02650218929404453, 0.07364234676764858, 0.028527072675886656, 0.05516237549243435, 0.027723099788530704, 0.0527920879633917, 0.07577022492525078, 0.11164046102954496, 0.03431244993642454, 0.050056713573153944, 0.019117647541626807, 0.04375398947647022, 0.06955144491287009, 0.010051023770844745, 0.028656729226631504, 0.036356816849400925, 0.01718627859748179, 0.04412179594979652, 0.02774297977016578, 0.04014311448460625, 0.04349730022612118, 0.026445270876490304, 0.03528545820905316, 0.07288257140786418, 0.06343850377766837, 0.055312670451859315, 0.046704925686842015, 0.028951523690334255, 0.014267439555917538, 0.0358523594425811, 0.02348751839881222, 0.023452150034568003, 0.04198891523804876, 0.05574277902562773, 0.016213710825409622, 0.01887130430869518, 0.014433102239103568, 0.0819576872632869, 0.021263293193412885, 0.08332062662849504, 0.0435000772948467, 0.05671951431600798, 0.005612696254355533, 0.04001028249941526, 0.014969937394433206, 0.03077751532527468, 0.03509789307211195, 0.0846679607826856, 0.03923088762789004, 0.021572380942562898, 0.04062186581112685, 0.024206419137396643, 0.046672340136982744, 0.05033430170207735, 0.04919782941860538, 0.07343884317144271, 0.07956704094765649, 0.04520119851334922, 0.045410987860973806, 0.09558026273284229, 0.008528549468234904, 0.03907710313796997, 0.10882743213686252, 0.013208132436228617, 0.024680874625881834, 0.020389677168080406, 0.018999920895082817, 0.03521599318651903, 0.03667426836346427, 0.03583067149344472, 0.03988922145518084, 0.007841097596552103, 0.007768619454450786, 0.04050878357262381, 0.0617343680031838, 0.021847996395081285, 0.035527783310821945, 0.032107281168141676, 0.03728619641474178, 0.07880810828458878, 0.03293742170377124, 0.05361798437192075, 0.01885283967450021, 0.020580586278811097, 0.03632159978752175, 0.04028871332505538, 0.07683469643515926, 0.027864054220938878, 0.04523369213265758, 0.01540347421166277, 0.09711600089025113, 0.04687753678750127, 0.022117021576231046, 0.04317060203081177, 0.035805233543918985, 0.08003758747250804, 0.03799038826518002, 0.07605296499546498, 0.015733999973763863, 0.013535051839426162, 0.040982363805655515, 0.02649046814880304, 0.040473286888652274, 0.08193823629088941, 0.05536682903766633, 0.057346036342243036, 0.11144875518737302, 0.06055436660385421, 0.06421931591185351, 0.029173018861441847, 0.12097939458345214, 0.011583624798203669, 0.022893491907105334, 0.04889842693603808, 0.016356295109876705, 0.06956053071565206, 0.03267948756054525, 0.020885699946853905, 0.04696243082083041, 0.031173990723947366, 0.062225920658919125, 0.12571682102016865, 0.05313083289131042, 0.05687385421967315, 0.027688436225176822, 0.021555705123671123, 0.028816393441370422, 0.016018454165708636, 0.0520137885975982, 0.05729757745059268, 0.009047123002669504, 0.03268974547785136, 0.016746636059495713, 0.017149847286242633, 0.02873851485820788, 0.04105199736753299, 0.07792993403610685, 0.06827651372840328, 0.03176992477458571, 0.06953130446134076, 0.058551046681860765, 0.03875841822234854, 0.03768611346341429, 0.034716526842525894, 0.08009439289209344, 0.07120376633059594, 0.01202936348084721, 0.032319889719327616, 0.030129395365234346, 0.004669252751139744, 0.013401491113097198, 0.07296041360185032, 0.023686496330605402, 0.02892911178810943, 0.0323884162841545, 0.03996026078839937, 0.042825950564996856, 0.02589933363901031, 0.07835605512222937, 0.05626006457473963, 0.07401843465143636, 0.02520719809728044, 0.037292221696266246, 0.08824493255346053, 0.00548076059203595, 0.04199536186793158, 0.013240524548887005, 0.08393783302557084, 0.03275109762926737, 0.011985190851133198, 0.01923332873341297, 0.016552641529649977, 0.006058955876787584, 0.10839103781167539, 0.1639037453118832, 0.07756691561230729, 0.14778327887817738, 0.15580138492007412, 0.176976484156424, 0.13412166356800065, 0.18001340990585668, 0.10307987280670675, 0.15382745213085605, 0.17770546278165233, 0.09428725187336245, 0.11270808882170147, 0.06905040808863218, 0.20801332598972708, 0.14244827321700512, 0.13734240445398516, 0.13755666392464794, 0.13194422718257676, 0.10176128227143519, 0.13208454384678794, 0.251217819750309, 0.11159353048330355, 0.13484376272366894, 0.1301912341507212, 0.13098024342569614, 0.12676692072061763, 0.12920230657102602, 0.16978452733207136, 0.1262734145406754, 0.06468733051611532, 0.0864894190923341, 0.10859973548400788, 0.13953347720446127, 0.1165698384565692, 0.14691804385473653, 0.24690618498190758, 0.10253436457846435, 0.12555066421027147, 0.1257346402252874, 0.14281057151815585, 0.13966259366321948, 0.19077008109419577, 0.20122626195511512, 0.10904338466183794, 0.16271548165429026, 0.12357409607859389, 0.11477310180423722, 0.16986245379572915, 0.09601363867160775, 0.21796137605222965, 0.23606018794159736, 0.2140133725779672, 0.15211155307629418, 0.12801130797954338, 0.08919503479715317, 0.262924317390688, 0.17012525259727435, 0.1504854854917334, 0.22710543215995838, 0.1522659044712782, 0.19254772683545468, 0.19596729818130695, 0.13485735312344568, 0.1649468506295835, 0.15180314139973733, 0.10126764585654582, 0.1253988102619206, 0.17398302623581502, 0.1790241605692333, 0.1227557073317228, 0.16804783665124448, 0.17477065655252627, 0.14321033151880389, 0.06479148016942125, 0.15539471480634906, 0.17959448238534315, 0.13308922219420635, 0.21318092611768555, 0.135595386907939, 0.1576625189233211, 0.23598747087582467, 0.1103194343346742, 0.06446364050310466, 0.197110761017088, 0.04789792376780703, 0.14019074999997694, 0.1411293302812884, 0.130191984916887, 0.20479186498109372, 0.14918819220075685, 0.13010005436597333, 0.1227901429839192, 0.18015472248436945, 0.20664250357977806, 0.07639346043429068, 0.09554824025760736, 0.16157940390609926, 0.1495904956133135, 0.21510132468275486, 0.12750323080728132, 0.07980073606895824, 0.0967149002357356, 0.18361422233283523, 0.16989801559717427, 0.10029312072982711, 0.1340666737767958, 0.06925391934571729, 0.13191995751713553, 0.21093170729375657, 0.17068089616875495, 0.20795599196947392, 0.17708609601663006, 0.22407561570646303, 0.11110366322100164, 0.12569983685088734, 0.21757850062943276, 0.09561942514753151, 0.15276137949718585, 0.09885995408460017, 0.11514456251696234, 0.20107272261333084, 0.12815721708560182, 0.16175108420993053, 0.2237940324290145, 0.21900137105295736, 0.11757356685496147, 0.1411429666463406, 0.2084292964108529, 0.08949193217220808, 0.11604430980139202, 0.16770675898559634, 0.1594286580239573, 0.0975717312746471, 0.07270000499462889, 0.12201045699898275, 0.19435402426508167, 0.09589375357233709, 0.11283227167422734, 0.22505535023106685, 0.09820272725435997, 0.19509254834584652, 0.17440533986495388, 0.14534544920729053, 0.13361339487375753, 0.1373514136479747, 0.10641679858728763, 0.17594758210883987, 0.23017526904661811, 0.14509343692371923, 0.09145078835107627, 0.10721772052948514, 0.11723346212097716, 0.15077546509283205, 0.18152595858179754, 0.14515792620518517, 0.12137547736206364, 0.2088941125980308, 0.07940371100219988, 0.17223472166205608, 0.10206819241566044, 0.07825490087270737, 0.17059776030721205, 0.1293161625583326, 0.16516912337993422, 0.09515268607966362, 0.19864555688634997, 0.15172022004281321, 0.10670487062945481, 0.21632193257251095, 0.1800630983686255, 0.10936865027272895, 0.14615198657397302, 0.10691921436978925, 0.14484478010525628, 0.12541845275629915], [0.03571365156301087, 0.09469169267122785, 0.049669195657535914, 0.0041850478362081755, 0.09193173834993955, 0.0310983625240624, 0.011273875340609061, 0.07348608015285385, 0.008877017009522646, 0.010474802543138786, 0.0044632502718858665, 0.026678397177508282, 0.06605142667408913, 0.09472068143828262, 0.015419329358865658, 0.044297601637100024, 0.03497236190483936, 0.02632668812669093, 0.13116465611082892, 0.019606524635286584, 0.0557534582912922, 0.03143651181861999, 0.030372432928772706, 0.06498371461226095, 0.03535795693976745, 0.03578691255120981, 0.03302398580877531, 0.026181077794922937, 0.060113406394638365, 0.045622416636756355, 0.018521512392908335, 0.03946410777467874, 0.0858534052367172, 0.03122086764403409, 0.04733089996021121, 0.08558649254301864, 0.061212007121573535, 0.02468476443731737, 0.036501078866422176, 0.01787088157969617, 0.05215070766186522, 0.07231905245252195, 0.024145361929831487, 0.1162772924609242, 0.0338329938090136, 0.048451625306399605, 0.012540966572780764, 0.08341153062159017, 0.013260667873246056, 0.03605550680790217, 0.05135551222690171, 0.03816620161336276, 0.10555973006111961, 0.027210652084660628, 0.053439064537205046, 0.03539086041611529, 0.0466022277701526, 0.03942001175375716, 0.02053491977764474, 0.040518225606290564, 0.025353214455648296, 0.055632711343106725, 0.017988640784976945, 0.03769637138072041, 0.03725363001708062, 0.04092476165462886, 0.04659005080259616, 0.00947068439751503, 0.02047635618627312, 0.019496064332704392, 0.025551286488471013, 0.008274824978152831, 0.023501237118316275, 0.08421583867241299, 0.06499731267291693, 0.021498855654030077, 0.028262377806728887, 0.049032032670032595, 0.02133743326750494, 0.08636427096902363, 0.06600679439162055, 0.03567319829016924, 0.10693552438169719, 0.012220638398561749, 0.042704732472737955, 0.0679327087897447, 0.03982815658673644, 0.0060375044572978254, 0.09754045190469873, 0.038049120395894975, 0.07144166727460201, 0.029011747777281754, 0.050970997375946854, 0.03760303122802608, 0.045885207777422284, 0.0845612753783503, 0.06369520451933627, 0.05120100761433283, 0.07018006602001768, 0.04343216360035924, 0.06958309200502212, 0.040144696456169894, 0.02011854716035868, 0.041493819425663644, 0.0061298970549908145, 0.0560671981093624, 0.09232855657295835, 0.08674881646349546, 0.03450850715800639, 0.035747416888273535, 0.034474389432298566, 0.023530984312416087, 0.01119542793716274, 0.016120520059860522, 0.012026463838053808, 0.06991955016048686, 0.058748375609396934, 0.034941978857762394, 0.05758720465124615, 0.01853364722562894, 0.04759448017143915, 0.013773445952533474, 0.06054701982066036, 0.02536477855286531, 0.04273202818548007, 0.0309851443049528, 0.060807957028549534, 0.022831555613647067, 0.03939833146550002, 0.04816307062884012, 0.016174602036875103, 0.03463349440285275, 0.06858444276956782, 0.008546205879669757, 0.036585915443157, 0.07285247947419844, 0.04220058150108784, 0.02599621694835444, 0.08037033776241927, 0.03344658289044615, 0.06138962077637834, 0.03402047467628314, 0.028773013712658037, 0.042360517677039876, 0.01331918741456203, 0.07310201729377432, 0.011665483208132849, 0.016257063741044655, 0.030083797811981172, 0.0449647722885974, 0.028603949599088203, 0.04265061602176678, 0.03301225700265458, 0.06146306179523949, 0.05498008487085181, 0.05040478562155078, 0.1370056015589545, 0.053669178197460796, 0.010619946518882869, 0.006418825679218337, 0.068998153231317, 0.04711521939644891, 0.03761760605078551, 0.049782886935938755, 0.02444956012280478, 0.031290893825972756, 0.02039422581513082, 0.0548030419515506, 0.04091677518801824, 0.029895305708651582, 0.01392511891261224, 0.032602078206236326, 0.0697822135783011, 0.08722109434705588, 0.09991960690146494, 0.05491835733635291, 0.0661697949192697, 0.08192252382756242, 0.020748801950004794, 0.02901116746567911, 0.05129741211872428, 0.040466074170845176, 0.054022176191210754, 0.022023894012935703, 0.05934383277030242, 0.07773845802031218, 0.025575090755498218, 0.060386428639533064, 0.029713829055488594, 0.018077650625679283, 0.01872979254732209, 0.0764236213158696, 0.013444752098181316, 0.03457908683847036, 0.014617676760310368, 0.05261292681097985, 0.018081038649524414, 0.030312227994023316, 0.014426366411029332, 0.07792420369843323, 0.03779978175917941, 0.03206365054563409, 0.0862688010918998, 0.03988327661288842, 0.04514681393160455, 0.020815062809795625, 0.013565211763395178, 0.020523865128897374, 0.019230589969083667, 0.09061222850915887, 0.08477322126348173, 0.046697138403091705, 0.02797951899288643, 0.02278724125766706, 0.04266446306099815, 0.030961947162605585, 0.04750628812959598, 0.07382281409997134, 0.029483882019356377, 0.04210086366642387, 0.08519486073524722, 0.03153695552159221, 0.02103288841974591, 0.06913629420582326, 0.020041262295337457, 0.015265791932301176, 0.02347893821406028, 0.054522535027635675, 0.06207106747634469, 0.032083921232110554, 0.042527934701572505, 0.036672920048717535, 0.04829496032588425, 0.01617958352360274, 0.042762660211132425, 0.08544501142516252, 0.023529837095749476, 0.11830239992348418, 0.024693051593438275, 0.029289406769338156, 0.07278706322634414, 0.03412964986637235, 0.021277268552371574, 0.01366104840511276, 0.020913997319557016, 0.02206475714281682, 0.02154613477027705, 0.07327398105013756, 0.02300897008559156, 0.07435313080467525, 0.07860874922405328, 0.05879542489926662, 0.037606225814670324, 0.04127218252829006, 0.04750791606643508, 0.10134156568035965, 0.06122028853203501, 0.037421954855803526, 0.06696150848461736, 0.016856527541794123, 0.08114835367568078, 0.045077130574012, 0.012586818850268761, 0.03727163308330121, 0.10448341483190175, 0.037348345297599034, 0.046830510480269316, 0.02579275740220422, 0.07539047514118495, 0.037235067706675305, 0.029003016290164767, 0.04706473420223883, 0.02809674768227964, 0.09660730318677041, 0.07288025782233284, 0.02058138684069197, 0.1051622836460029, 0.014577808587120907, 0.02957911057878406, 0.045062260807401715, 0.03616612607372865, 0.04817591792333031, 0.016793555114418268, 0.02874892216265923, 0.01993860268304425, 0.0777261316656105, 0.025054668076336387, 0.028298322652136127, 0.029859282339232105, 0.00959254696124023, 0.03712342954390953, 0.02389235756239824, 0.007244532480986128, 0.052637744229286916, 0.01437570405898676, 0.01384463850333686, 0.04335964571744685, 0.08128451048246316, 0.036780758415378874, 0.021851254183979287, 0.015493550829799667, 0.025097597728393255, 0.016150165747310367, 0.057248593788714185, 0.05139156815505797, 0.021426462260405385, 0.006325353855162018, 0.04589042483618663, 0.04308415666943596, 0.07368830438222616, 0.03671283322957255, 0.04174851684740955, 0.021071054920133565, 0.03175330832750807, 0.07116492567283493, 0.04609280611358343, 0.06623364068687924, 0.018133730176956426, 0.0587254619195817, 0.05395089170985645, 0.03148262265078243, 0.08269588192624432, 0.0057521376631132545, 0.058731916210343765, 0.021356924459518447, 0.018350318554909, 0.035946519309354406, 0.06505924322071575, 0.041684694062437744, 0.07155603654081784, 0.06524092097195887, 0.018077277157816197, 0.17464491088063488, 0.047513121633880565, 0.031499346350169474, 0.027996491670848864, 0.044103628174672206, 0.07193753300535102, 0.023088961156205307, 0.03900245553062808, 0.018189509038723285, 0.053977114899504575, 0.04401560084173276, 0.05325984592819887, 0.03345170035778034, 0.030462222263938, 0.06162399005505347, 0.04459566729623945, 0.08127455900032675, 0.037161760753200906, 0.09360274465213861, 0.04383327191575401, 0.17150442536559798, 0.20395974027774028, 0.08219640026049269, 0.10958707726169979, 0.20323885154099236, 0.11457012680869912, 0.1442540343850851, 0.10249756937546116, 0.13863317067584685, 0.12558657841216173, 0.14704431046641644, 0.11011544810307604, 0.13603584149912482, 0.12526289094239473, 0.1663646189075324, 0.14358142450932534, 0.1708519636022468, 0.15573286601612646, 0.32189764322773107, 0.0595127972924421, 0.14387967786000622, 0.09853303372379273, 0.1569793983212402, 0.298497395650033, 0.07077073513139641, 0.08284747540470093, 0.12287412920305807, 0.11426693985178588, 0.25149561855341157, 0.13467044299167974, 0.09147079090677923, 0.1271562389428577, 0.15289725285143624, 0.1779201512615527, 0.1465061336996094, 0.141415617338592, 0.1431639985211434, 0.20347427036012375, 0.11413862778534813, 0.11127372707931266, 0.16597828076731774, 0.12671403767120454, 0.10787153060758307, 0.16718335239396942, 0.17047083485991726, 0.1033640914266148, 0.1111343143988521, 0.16259793312318865, 0.2310714540221999, 0.13995759880110142, 0.14107273170544257, 0.1822811374140363, 0.1457558425083276, 0.12843647145576056, 0.13402148991102172, 0.16809279069064126, 0.1573671460632355, 0.10718269498958703, 0.26456843400674485, 0.2419754898836536, 0.08359065730004542, 0.24655908586517458, 0.15930735566202672, 0.07553410130522906, 0.13805862005439498, 0.1887553004968551, 0.11689155708037077, 0.077678503979358, 0.14478669531883734, 0.19397393740232916, 0.12216736712763387, 0.15163159899173245, 0.1378061481180691, 0.17689019201263306, 0.1641847310407508, 0.15595584356736752, 0.22318093226321284, 0.09397766042140224, 0.16997585013028116, 0.1281942038105861, 0.12572539354404136, 0.15239502093003643, 0.15520895380646954, 0.105546806157837, 0.19543321232401556, 0.12849456390305874, 0.15261488816430493, 0.10195663469212671, 0.2549628865334296, 0.15504856563864217, 0.12274022469477308, 0.14630111324931347, 0.16871877645532932, 0.18225366550107158, 0.13906392659391129, 0.16222293308425337, 0.14953201246117392, 0.28853543343082555, 0.2578487397441941, 0.11394045616109526, 0.19439330925383877, 0.10860879830415211, 0.07259735687365455, 0.09615717290510094, 0.1353432826938168, 0.13969916670072463, 0.14218703723482548, 0.21194821403872585, 0.08710580577533092, 0.10282932375107082, 0.1819823784453254, 0.0887193478223297, 0.11847227225981413, 0.0701192003344336, 0.061932489831721595, 0.25854312183876194, 0.18221629573212517, 0.13525944203138351, 0.27371111115620983, 0.13041099413268029, 0.1232986951306943, 0.16950300534165677, 0.11820738969911491, 0.10109383582828507, 0.2471818080953052, 0.11986623818595564, 0.13778831359119187, 0.09081510391326682, 0.12683805964526632, 0.13978697569860568, 0.12602471175693697, 0.11903281879401016, 0.17583721948246803, 0.1928372008185233, 0.1816334407175741, 0.16569165663132746, 0.13326139279430912, 0.16977652937414187, 0.1651737352292384, 0.11888924625612075, 0.17193740293864282, 0.10540078979946914, 0.15101911169627022, 0.17577625420545379, 0.11369225133450762, 0.1824953509194236, 0.08162867548244615, 0.18177222520593675, 0.059648195672179424, 0.14728809496568096, 0.15137178793309197, 0.15799060373777346, 0.20382507734241026, 0.19048229250456059, 0.23437537673500278, 0.17327192810273942, 0.33981426408694637, 0.16010488383471966, 0.09105895736044453, 0.15038724237632367, 0.19938979598302997, 0.1247833811888291, 0.15857206447230232, 0.1524805469859031, 0.14630828383228472, 0.13535616829270317, 0.09900015583562274, 0.12799731155316676, 0.213009015987477, 0.07953845820720158, 0.14123521895418245, 0.15912101243532475, 0.20789554763224818, 0.17172898105796308, 0.21885904723838454, 0.22501467096228756], [0.07245899373365026, 0.03176577257803612, 0.02486274198388621, 0.040424238109300216, 0.03168719877008229, 0.06404198954002031, 0.031628822870252114, 0.030352388238233906, 0.028164663291986913, 0.024575707990856423, 0.018781488160452536, 0.022405124261915203, 0.06794225424528122, 0.027349335066373312, 0.011684958120777963, 0.04475780597497379, 0.015923186344274833, 0.06189924544624745, 0.0034753684022073308, 0.01042596539557581, 0.024574078138797514, 0.034397504848217776, 0.01642837057701282, 0.046370309972835165, 0.06485823707114305, 0.04693737591526682, 0.06245820617844021, 0.06185597680028408, 0.027184453792870048, 0.03358990644976016, 0.05351147899824766, 0.041807030643066095, 0.04811737348415679, 0.04765815356926573, 0.027345085193613367, 0.042079930313892906, 0.034978774060765584, 0.027971300784678712, 0.014590964232000613, 0.018866407091639215, 0.028251773234637036, 0.07542668811736569, 0.041006020600757295, 0.054011140694661494, 0.06519672535960713, 0.04876594352085264, 0.02860465631519835, 0.06103294173015222, 0.07161644257364735, 0.1029865326540124, 0.04083241358579647, 0.028350981620831356, 0.02617597564934723, 0.02227455606654046, 0.04812186275939307, 0.017650884110480547, 0.058745031635607445, 0.0733259984201962, 0.011675009511471277, 0.016248445251896497, 0.03075978422026721, 0.07913381822647587, 0.02213308835522302, 0.06492050469762857, 0.020075177007745353, 0.003294004507610695, 0.01320099920004366, 0.11241739675883325, 0.06405191420907937, 0.06394139453468305, 0.05875431279081011, 0.0307115494093347, 0.03640187048022786, 0.018899856405633114, 0.018307722151099194, 0.03607424148809045, 0.07323949177178644, 0.04316358083498575, 0.01556456622277056, 0.00603389714078437, 0.01128431999184672, 0.07508620033941923, 0.028876106164628462, 0.020116808140770565, 0.09100221322789308, 0.030870587347195517, 0.04697020661326186, 0.03061341163101456, 0.07970738825538466, 0.049584044984752135, 0.06548455991451779, 0.014407761008178276, 0.07272032930726006, 0.022776843529314767, 0.03230668236351302, 0.015338845119150657, 0.02598125333597343, 0.08517691129518133, 0.10185988544816933, 0.09338037997123697, 0.07839504899757524, 0.016593332289748134, 0.014490922725188636, 0.034473408839755484, 0.10833756487456062, 0.03372955661747725, 0.05244062214549031, 0.05356348870742706, 0.04987493240004105, 0.05243861116468907, 0.07015235661979645, 0.028194299403337703, 0.018098359897492394, 0.05545151239681629, 0.08023788882119041, 0.041008912582671454, 0.0862247357144952, 0.059670841231221156, 0.055931895490615606, 0.061729549310140075, 0.07061086790335756, 0.02541424293491629, 0.03688959269634178, 0.039551422645848607, 0.03479917623823689, 0.04496785196205301, 0.020314780582163124, 0.0041133199814677, 0.05895809983954795, 0.02764956109345921, 0.007269962290827666, 0.07580536537833753, 0.04108286305000225, 0.07797408368318312, 0.07036745878717593, 0.038170476383980245, 0.03407352243459994, 0.0639223610802043, 0.04550769497009535, 0.025587939965208212, 0.02465728869391305, 0.04095840823626326, 0.02502673842583693, 0.05323503234033143, 0.030932533216752836, 0.051522944573192835, 0.07322528850167029, 0.05614624689182928, 0.07885362922904954, 0.037478178048566464, 0.03309647687861035, 0.057136227842420347, 0.03529893369564126, 0.07486028867142816, 0.01580589636784768, 0.05008880116586244, 0.054125816396047036, 0.07272612093196762, 0.03216868311527275, 0.07027598788901683, 0.04255646381587271, 0.07184314331220043, 0.03512043520928391, 0.05475045384598836, 0.03460956947697747, 0.022737924347541506, 0.05822848536134247, 0.023188217422894897, 0.02755224111399824, 0.02365679893222067, 0.01853015194947441, 0.009762990990683678, 0.03817468603712417, 0.0074067372348039385, 0.025716562297255285, 0.04783303612062047, 0.03229792980897812, 0.030385182547052542, 0.030205201680561712, 0.072384744492029, 0.060109667885567875, 0.04918351123530058, 0.03581954023590492, 0.024300927574175502, 0.05752256215219537, 0.03923479850674349, 0.051138862561915195, 0.031453704746860656, 0.028134847149973916, 0.026318176889852173, 0.03915203419784385, 0.018393970244834502, 0.03039401745603931, 0.06894003014050185, 0.008344858820970741, 0.006293653615660245, 0.03960267009754335, 0.022484333922846184, 0.030940209417754126, 0.042948107114963, 0.04657325432485631, 0.03821880504068348, 0.019669525790959597, 0.057611194694595, 0.0563478620813018, 0.007128375357077007, 0.007319893986512457, 0.02507549609177776, 0.06729113313579752, 0.024137295023988814, 0.012468810666412597, 0.01710342618847086, 0.059622615996387705, 0.004660207646778755, 0.026380704986231945, 0.03755269542096123, 0.05758441226076215, 0.0292565550039252, 0.05039907826651489, 0.02334984665315959, 0.09346143973450508, 0.037204485476738026, 0.06326137275825586, 0.054650988820339405, 0.013640206025522805, 0.0387887476432708, 0.06914336519736437, 0.04970197272937625, 0.019168749436615937, 0.04640721625858738, 0.07762926750846448, 0.023981336759583607, 0.0412891743584506, 0.026924920441102118, 0.02442902513599444, 0.031822803993559176, 0.028441717074583137, 0.06723407490719711, 0.03324928843686658, 0.06756163878186096, 0.0583704874189871, 0.041235437121001944, 0.010467238382496422, 0.0767519819219747, 0.0752114940194353, 0.0402482332391364, 0.02842159577525191, 0.02630678324719831, 0.03274071330745374, 0.05443939533565314, 0.033310950853891914, 0.04049609715659772, 0.022343965547700084, 0.018754719133158366, 0.03419690089480531, 0.06261696640942847, 0.050121995755621505, 0.008302943277803641, 0.050633857402229504, 0.040620640070448, 0.05970192907918846, 0.001580357512143711, 0.08398958226485599, 0.0258205127677009, 0.028670246848055435, 0.03261767192593506, 0.0435629501307924, 0.049307782187937736, 0.039338197393883625, 0.029299670432303703, 0.02660849931529693, 0.05330270854756237, 0.015249698340231854, 0.018461709654319192, 0.061509705058509306, 0.02935245580550644, 0.05800428973030179, 0.02078664477824444, 0.02324023862339316, 0.09241801265987659, 0.10073535264499726, 0.03755348449152324, 0.03405671829598085, 0.13234889014594017, 0.026301581510192445, 0.042709738857323126, 0.05305117889938336, 0.0040874003541595755, 0.031003361875792185, 0.05286891892131779, 0.060293429395965034, 0.033236682460072546, 0.029222230434477813, 0.03161720131644078, 0.017133929894395897, 0.04298592121490548, 0.059277298034078656, 0.05205048803961085, 0.009282059186408597, 0.017877515901120442, 0.11033410491842417, 0.01854277899368636, 0.019130174994408604, 0.024063001732311906, 0.05319547155992158, 0.019508798629225745, 0.020248709329133554, 0.08374064965474029, 0.03558530885305616, 0.034184861823075244, 0.03524132388373537, 0.03976946659085732, 0.028259824818721222, 0.06285514314508726, 0.031980759832226945, 0.051696103426717946, 0.0636073342344213, 0.04608802572493592, 0.00043227959512507605, 0.040849926355745525, 0.019410316111339677, 0.06284014697396947, 0.05736881596667152, 0.060544641117655465, 0.06403579954959213, 0.014674847029269704, 0.05724979271631568, 0.09349806639816492, 0.0017903089352447781, 0.03748305419820451, 0.07805596316053022, 0.0410825144799967, 0.02941248645525306, 0.11049301453655767, 0.11733621749426089, 0.0744464556356111, 0.03265003914073591, 0.030637104815292745, 0.013315018938644039, 0.0303281721989474, 0.02214846948552276, 0.05061316153695507, 0.054629457919227506, 0.018102314826401494, 0.04779476619836304, 0.008285822170305877, 0.05950245510546431, 0.03883430306168814, 0.04213395866475279, 0.008015835548811143, 0.05386846064920387, 0.03995047018472706, 0.21482476694208963, 0.1198752856843414, 0.0961939987516211, 0.123925079261103, 0.12017071983146092, 0.163381181416973, 0.15071282974414288, 0.10736452595841502, 0.10876246022000428, 0.12619661422626627, 0.1077202665469339, 0.07096891441652853, 0.20489691095727108, 0.16941847520009165, 0.11476263704319155, 0.11477622744296828, 0.13444095369308226, 0.20191564915641663, 0.1273764432558129, 0.0948878571451191, 0.1341004276107396, 0.14901818196860053, 0.14295557664046366, 0.08903447042910323, 0.17585755145597845, 0.26954659591278723, 0.2170432196749795, 0.07186275516306201, 0.13881323198156972, 0.10931168397467945, 0.18278350723126244, 0.13564092317415824, 0.1820083335042, 0.1972206180254298, 0.13605301719038718, 0.09429308946334547, 0.1523221353249204, 0.1638676472488911, 0.20509655347033856, 0.12656311068924206, 0.1358552898971304, 0.1435720169496152, 0.1082446767137416, 0.09659126130563599, 0.20853176833160464, 0.1334078228401561, 0.15343532236593385, 0.1692840574128974, 0.14525483632760663, 0.16171978185734442, 0.14902414213265144, 0.18402973310120646, 0.09824366699303351, 0.18730414610716606, 0.16213238149160342, 0.09502653438117235, 0.1342230936091754, 0.15424303950801974, 0.09344723646438892, 0.07922168085051161, 0.11769974153609046, 0.17081843959468027, 0.11730641667400638, 0.2105960535306123, 0.1387007396307684, 0.1573417272659079, 0.08641537669445239, 0.14490669533129663, 0.32394947183708994, 0.27307942569736515, 0.12750235746704763, 0.14401286990652162, 0.11497750938419374, 0.15912153337511326, 0.09508955277382367, 0.13117548859407827, 0.12050309473828924, 0.19045865103121729, 0.11146364793662103, 0.1210896882619108, 0.08756448559823536, 0.11131059123022903, 0.1187366262198456, 0.1394312351100868, 0.19280582185714476, 0.180200457933449, 0.20584823894164256, 0.1341539924784053, 0.10102890221582306, 0.14043572959640335, 0.16887119730874417, 0.1480841675713178, 0.18657867616463095, 0.06971728762671833, 0.12769827679280313, 0.09927769416883107, 0.09498973151728993, 0.18449376787870161, 0.2148087097391967, 0.186444963178327, 0.1282725592834815, 0.12557511007593525, 0.09020453183761529, 0.2217590424322313, 0.16580571180149434, 0.08667677355509612, 0.13326936010872165, 0.17360002823895024, 0.13482936027069248, 0.15829559866218798, 0.15117156319320202, 0.1433204030317645, 0.09590713712837427, 0.20003419850141774, 0.2074686834408391, 0.06454646226859863, 0.1365957751629814, 0.34032944289426653, 0.12517775559136946, 0.13024011056029028, 0.16473669739019486, 0.13168699017936183, 0.13672020316364306, 0.13607042270802683, 0.2451273441434868, 0.15368313648768012, 0.12154689719600063, 0.07303938194508515, 0.12780498517977615, 0.10772402037776287, 0.19738359557044124, 0.34625019938234364, 0.11860451435730343, 0.1278869106223987, 0.13839222070190216, 0.14167093912199621, 0.15321634379365753, 0.23489715922023022, 0.0920416719670738, 0.15908355073582742, 0.1814709687905927, 0.15646777416188873, 0.22459836346247505, 0.1611114161149148, 0.11406923554116681, 0.15909023102252715, 0.1354616432781181, 0.2651023053594174, 0.174703348067499, 0.17980724032367432, 0.13074220458586372, 0.21819536994782188, 0.06696533892423877, 0.11232033341882691, 0.21604116134826215, 0.30003211491050263, 0.171243557105622, 0.1257286570785988, 0.19319649605501085, 0.13698061177086446, 0.12838234734391013, 0.17724734220293262, 0.10178342987332614, 0.15456668101251125, 0.1730965552551131, 0.23938602076903467, 0.07940430855078083, 0.15295314662639173, 0.13606325212505557, 0.11261901577874539, 0.08754658978432418, 0.11968094449970992, 0.09715294931083919, 0.18695153115737825, 0.11684651111042309, 0.14090506570233455], [0.04430089198473481, 0.04357218915115922, 0.05660137972764431, 0.025087025715038184, 0.0295122713226104, 0.007402932171845028, 0.07210516836494207, 0.02999930789003209, 0.0269985108471085, 0.04067304814534803, 0.03339886710408234, 0.05464574494849771, 0.03189880757652704, 0.1153741054417145, 0.08075260031487673, 0.029524218463789553, 0.018854138193531864, 0.10600384655258349, 0.01262716104036137, 0.1277098293987013, 0.015188011982958886, 0.06944334990675412, 0.011229381911576757, 0.030839041761693456, 0.03233591244826394, 0.04294340716554754, 0.017140774889999343, 0.010979776101697598, 0.07305588347897415, 0.04965447527807086, 0.03144981685064493, 0.04785655501989588, 0.005906443092821827, 0.036833863630289995, 0.017960360649252133, 0.021354928800475695, 0.059328878734020464, 0.025667343063340075, 0.08837042541633691, 0.055163118597720905, 0.02700162116408108, 0.031793439843421506, 0.07727998504114729, 0.030263206027748606, 0.08477918142753263, 0.02460041432641447, 0.04755162138251528, 0.02040375786412868, 0.004024443727347159, 0.07720147635066703, 0.043957374329047824, 0.0053831461475290845, 0.07346168791334476, 0.03180120222931428, 0.06494368651821729, 0.038274484311020186, 0.07157050028082824, 0.018950376073799787, 0.08015897410411028, 0.01758307192264305, 0.032862368069829485, 0.026812152298648032, 0.05375230639812447, 0.07904087643950217, 0.025286924867560307, 0.04388834597663053, 0.02001885230833244, 0.01922296547901727, 0.10784745246412293, 0.02375953323808649, 0.054879171939025966, 0.048480767291039235, 0.05315538217884399, 0.026005155279210983, 0.03912417158003777, 0.028697668965305054, 0.047456090218357505, 0.02064178138220262, 0.04171739835592528, 0.05802452594282166, 0.019409898593420946, 0.020061577031869563, 0.025792395425659996, 0.044450941796024004, 0.02930392222028346, 0.06636487920918772, 0.04969551460817457, 0.024864371835945115, 0.043901748684865814, 0.026214885255021435, 0.036167508862431974, 0.016116611096226884, 0.029243820707403848, 0.040556407428436705, 0.03565246029005897, 0.0343410250160002, 0.009636585525567494, 0.048853335000814936, 0.026822532790022034, 0.07880789377997, 0.04083147129764961, 0.05516362421575093, 0.026459753768698826, 0.06365747851950508, 0.05046247587268872, 0.03904245298115477, 0.02708034435918014, 0.016128811046421047, 0.024357453371668537, 0.08534907423440488, 0.03668702755784316, 0.0071413524077093655, 0.014966553201027697, 0.011037207798161095, 0.05786395391389247, 0.07655832255559583, 0.11272456737295275, 0.03672298006412964, 0.024489795060587988, 0.030540958865575736, 0.00671618749507733, 0.02535906545216999, 0.05074373739320905, 0.03448609525578157, 0.05927472397865308, 0.056564032941335635, 0.012441585816803479, 0.02345503244038311, 0.021815339982089017, 0.06690772145145363, 0.06870800509087502, 0.03545129326202216, 0.026509436485808224, 0.01959980604419064, 0.03965424696704553, 0.03409062151706988, 0.026847482358496037, 0.02367453386766776, 0.025878350490764267, 0.06513535405599302, 0.0502747115528872, 0.038856155719728246, 0.029645666382425738, 0.02732251241292444, 0.02686275240604676, 0.04037826134252452, 0.06374465166440894, 0.09265056631017117, 0.008979781001295534, 0.055706259614277276, 0.048530317857981696, 0.021443817982329957, 0.018167035849464518, 0.10494369577856795, 0.038829338811938806, 0.06898512973660423, 0.05842720090802159, 0.06884328089654446, 0.027593699877240488, 0.10416905065217327, 0.056821028626854383, 0.021519323608147043, 0.021216619286626097, 0.08240219445959215, 0.013988581636259633, 0.052634189581318255, 0.017495555953393062, 0.01430724165402353, 0.025536100710591963, 0.04584308826334534, 0.011656266212793849, 0.05093634338869203, 0.05979921458469284, 0.039872547551508875, 0.07629096553090119, 0.04026312215794479, 0.04167740090539859, 0.04209938511673001, 0.022115359165435357, 0.027404753866815762, 0.029992156459258932, 0.008882198636720498, 0.06798625067477265, 0.047698396167928175, 0.07303441003445657, 0.06723257337486552, 0.028176166102169987, 0.04428648953175834, 0.06179329165587984, 0.06870344686772555, 0.05663661594172159, 0.020960514178319324, 0.05579083572111784, 0.14401927440156861, 0.0376953678055396, 0.08743968221449083, 0.010439053050152237, 0.0371793348101839, 0.0714274027174519, 0.059686733725210356, 0.009567025699652731, 0.05407026736065746, 0.07970201031815621, 0.04374094682955935, 0.0909139828816537, 0.07979559561898632, 0.013529570480327935, 0.04794120007464963, 0.0032854099587101733, 0.042217243913440936, 0.041999724738660364, 0.06255678637253662, 0.04153511156478236, 0.019923922523195227, 0.030116931114706303, 0.11283411794612486, 0.0659186253324151, 0.0543468059491246, 0.01708518563499374, 0.0350241111441245, 0.032998268237157215, 0.006419955180101698, 0.008819947289603372, 0.026132526972721663, 0.09355779827362107, 0.03728991577161416, 0.045671584159736676, 0.0038786847266413637, 0.021282546898169864, 0.010279429055029347, 0.031968050433563135, 0.036108175352696455, 0.027891773197259155, 0.020929644665410443, 0.032236045226454735, 0.023454115050093784, 0.03567592173274006, 0.07115650636654708, 0.040792132682737806, 0.029575345256636222, 0.038734309435371435, 0.08612724336525125, 0.027658129786892284, 0.023172700311988596, 0.034366482117724036, 0.01924351578758609, 0.01742713089521614, 0.02473340719006956, 0.05844841005220529, 0.019192766293042132, 0.05588105023508111, 0.030529101739727685, 0.027800233351186882, 0.027204469755111683, 0.014634721259015703, 0.04154852959477613, 0.05815622794832434, 0.03693569203718536, 0.007805063693423666, 0.05161168436790186, 0.03902591697330918, 0.0864143961019093, 0.03676243359223008, 0.047389413755867756, 0.025143382973187876, 0.09231293604018227, 0.018755232412067634, 0.060563069362674034, 0.03644448412101596, 0.058083457256396936, 0.07371383809274243, 0.037881657406086885, 0.05904505464939341, 0.051103273947392745, 0.028207305661072175, 0.043252822417285175, 0.05864468177840595, 0.01305829521433841, 0.004190154291028458, 0.05230937213186295, 0.05324447054355856, 0.028724085592154055, 0.07758933134497174, 0.034196142467760274, 0.05268601542939583, 0.03102185906872394, 0.03916632939851092, 0.002207043050270107, 0.05040100497764446, 0.02423116569257071, 0.021420557637728994, 0.016769614866784504, 0.013102627764906616, 0.05253246459629267, 0.08959483310219743, 0.042809100461102305, 0.038961025495683, 0.022792167203020186, 0.05694019743391583, 0.005976565993360935, 0.008199893918278958, 0.05753027665759287, 0.011938964148172209, 0.030029300232267672, 0.028035408937402313, 0.04692269767063761, 0.042194349375823816, 0.03949300844162222, 0.044513914223399856, 0.02429955819201085, 0.10213459691693706, 0.014335763107444492, 0.016242676609826666, 0.08941762164355287, 0.017500299952864166, 0.050620937329386516, 0.11279415879999438, 0.02259059989404294, 0.07387916752768141, 0.009059126642833074, 0.06774680989403879, 0.07617265857275456, 0.026878282923491734, 0.05285811325114581, 0.016545677790418267, 0.019566866178666393, 0.012083601548276361, 0.008630194014028437, 0.0303756888024509, 0.053018685280075, 0.1362607342701766, 0.102003435003421, 0.019328151266240788, 0.023656971302003633, 0.03205105606015892, 0.043850003276020295, 0.0419945766278092, 0.041065438380164486, 0.03539955551405588, 0.029790202275879925, 0.025914506010350682, 0.04651664042725198, 0.05696887210492165, 0.02908576719252573, 0.024555115547451763, 0.02979608391591859, 0.020873875379742637, 0.06682424851122402, 0.060229755998138464, 0.046696127167031656, 0.02105408032695132, 0.051637129978306835, 0.1019675131406515, 0.14481576069468452, 0.14615145031242602, 0.08633875258026585, 0.22357402729891965, 0.11681419752177694, 0.14368127640937606, 0.08375807049413843, 0.18440016725611302, 0.11953143478040734, 0.16461021627389616, 0.0971303497170729, 0.17012750489577172, 0.23585921243554164, 0.12605379245454265, 0.1603729533211839, 0.1665440213776404, 0.3284423630083761, 0.1339896666186471, 0.22349764833286886, 0.08419417370591434, 0.16448393434045777, 0.09911702254847174, 0.13472238375294593, 0.104295501124955, 0.149076251433261, 0.15259719153325405, 0.07817679820882698, 0.14087555599549126, 0.1840947433224609, 0.05280162575804899, 0.1400430176046587, 0.09366938664067177, 0.1641145420651282, 0.12525678522163822, 0.13133432926429858, 0.14183327315315125, 0.11300232787165912, 0.16504411315245016, 0.1789102432948928, 0.1793709226072796, 0.17064740280470542, 0.09887028861069873, 0.07334570986248794, 0.1651318761850557, 0.15451516926048264, 0.1295040839261586, 0.24462934102742906, 0.1735915706282662, 0.13965922287635266, 0.21543654943666152, 0.07364629212045863, 0.17067369494226672, 0.12878028405529837, 0.1410537480466789, 0.09312283653285235, 0.08730012397732466, 0.2609922130021357, 0.29098032643237426, 0.101346782739124, 0.1807772914969152, 0.1264688205875216, 0.15827448527899482, 0.212464404082106, 0.07805690544867709, 0.1576926415005038, 0.08573397979020111, 0.0813191683001576, 0.22110294941211903, 0.14060788487474765, 0.08873777223690864, 0.10418719927509947, 0.14673254332475125, 0.12393762778130271, 0.0712126912549138, 0.07144890680548645, 0.08494802720604405, 0.10550166059645916, 0.12549963509363513, 0.1802106775463589, 0.14184222106010685, 0.12255032682010245, 0.10324069764465095, 0.08054946444087452, 0.08792661536004275, 0.14424330915414518, 0.09502517074466714, 0.11827687387384715, 0.13858752715731823, 0.1708202169186646, 0.10221940285015492, 0.1971934831911518, 0.12113259684654976, 0.13154892581364802, 0.11809345710301593, 0.21784663140293092, 0.1672690776326964, 0.10961017481261685, 0.15370611912540852, 0.19187572983003434, 0.17338173914580576, 0.09649571481971972, 0.06541439392153295, 0.11723238959788315, 0.15574464844840188, 0.11670354378199387, 0.14931945370570307, 0.141607292537247, 0.09338963431336227, 0.22146377682445512, 0.1690490982465206, 0.1317994978519217, 0.2524891426606525, 0.12903185200787362, 0.08435421713417576, 0.18317594343135435, 0.11877396534527503, 0.11001697516128903, 0.20083992381490048, 0.13332353784672676, 0.12984883881384326, 0.12253898871882309, 0.11860160322319116, 0.0979354391775785, 0.13850851284880794, 0.18273345104628996, 0.14915811558884962, 0.1312658256821094, 0.10671918881275963, 0.1805185682831272, 0.13104680114455763, 0.12323206846391964, 0.11190288444800724, 0.16056902586452423, 0.2690237562262243, 0.19816643017674648, 0.0936938401672148, 0.19409127142881194, 0.07604710442284424, 0.18825452414251145, 0.21535739723232486, 0.16342256548664263, 0.13956766004764265, 0.12661812346308463, 0.17099084002116036, 0.1489995660320405, 0.11632635273159513, 0.24194262471170197, 0.05974726616254738, 0.1517130954251174, 0.12462139189724, 0.14347028047327073, 0.14201586254902426, 0.2732383429763779, 0.2618661661061549, 0.18207948775060717, 0.09965317684315866, 0.13657846157589268, 0.1306857898711197, 0.19604212964975065, 0.16281999136892059, 0.10066380003286947, 0.09117128883278178, 0.17534028888950426, 0.09918503583438935, 0.10315335596040373, 0.1329028330022289, 0.10521724279369078, 0.14052637311960423, 0.12098006874082551, 0.0892879459406099, 0.1480391216013701, 0.19465289048610196, 0.09558183321308705, 0.16451272392465224, 0.20252571561403815], [0.026338077938905167, 0.01960457877195891, 0.08627350487175488, 0.024458167120634068, 0.013594160310833926, 0.06223551974061036, 0.062020965326096744, 0.040848206488355514, 0.03518995768841236, 0.05329944501300493, 0.03171112369595757, 0.02242633340609891, 0.024341133783661553, 0.06639137052960935, 0.06171382535549422, 0.05488969415666596, 0.05710990123090245, 0.09501341129502944, 0.09079435059139807, 0.043765653165117394, 0.07827534009852717, 0.12800793719267653, 0.025332237053061687, 0.07296662657491623, 0.035869067820209655, 0.026986596264666127, 0.07716537828767493, 0.007889345335218335, 0.05501199626333772, 0.015895954791396376, 0.03076532495117957, 0.05535970441997052, 0.039399683610686374, 0.03075000510791377, 0.009500824211676036, 0.06221796866626509, 0.02591171553508649, 0.007193322376077695, 0.017593136402748285, 0.058289534908028386, 0.024428381622138045, 0.04626160209637977, 0.02945293972809469, 0.04490281492772122, 0.015546127444043037, 0.07088580153762333, 0.03461201712789555, 0.03126539267419327, 0.03818088751887122, 0.039311403468731916, 0.021815859006657716, 0.03161810913063105, 0.02780746330597228, 0.04369038885699646, 0.022024838216302377, 0.020449412873976176, 0.01264724882334591, 0.042744772058100476, 0.02980212260398173, 0.022573112021951426, 0.0467921371361421, 0.035818276190829855, 0.021920303603814497, 0.05532436861446308, 0.0629890897882081, 0.036003156189596465, 0.07026805121812128, 0.06455069873481989, 0.056320026276573065, 0.05085983035725452, 0.05366368917748333, 0.02649698755703867, 0.02856045687240699, 0.0350950547163525, 0.009184028660397857, 0.07934106033175223, 0.021604995220719327, 0.04640418638084685, 0.03007182577294448, 0.035032101441174746, 0.019117601576351353, 0.09928046740711698, 0.09551336793529411, 0.028628106266560576, 0.05010283206619563, 0.009929675443638718, 0.04334384132356894, 0.030094147659838203, 0.015203875748650923, 0.021409796017612663, 0.01490713829445022, 0.056925883081050656, 0.01778781658128625, 0.035369486563027866, 0.04326624810815819, 0.07125304876676491, 0.0601994265772162, 0.024025739215674902, 0.015998444906736336, 0.11005648997642341, 0.05443406336370015, 0.02363685766355165, 0.046029538742356726, 0.04109683649374112, 0.038076898744029385, 0.027145507798019438, 0.07780935179682509, 0.03670500764142602, 0.04445676406424853, 0.09399379423308758, 0.050995167449957905, 0.017502636521033222, 0.06475525187148203, 0.08070288886947018, 0.0847696359719961, 0.05570486150381546, 0.07288537528966704, 0.05258528635867181, 0.020323379919113174, 0.10350338919388671, 0.022001698530549486, 0.10675362446495604, 0.03583175550785757, 0.044318745663810166, 0.05109369784833924, 0.04037049704141194, 0.05650834601011969, 0.02243005084775148, 0.05941995509689855, 0.043361629885170734, 0.06267890844854616, 0.03202302298778969, 0.023308650275031408, 0.04030178278504361, 0.05564924735095232, 0.024676333639710665, 0.01556035656962664, 0.02727306718307157, 0.04346558035561635, 0.09042275198284658, 0.06588559928199937, 0.03597153974096141, 0.058751807683297706, 0.06549412835269205, 0.04189862794573269, 0.008454517604062154, 0.013218952470549173, 0.015014569676901787, 0.06945117932534026, 0.018798947304246888, 0.02205242695767553, 0.07011523199898582, 0.045734066290840994, 0.051407924132241364, 0.09492326572897936, 0.03748562059275085, 0.039520311815243576, 0.009866640771619015, 0.024803272493544127, 0.030126026493587324, 0.015490406996480402, 0.04504488210283941, 0.0318661913831508, 0.026570547319528078, 0.08871001687141196, 0.0019162455306110545, 0.05642559702297854, 0.06006780501094557, 0.04960712721391071, 0.011229483418226724, 0.08218006726594702, 0.041255880177261374, 0.009501567316962587, 0.03830059641791928, 0.037511908899872534, 0.0297670032183129, 0.03284503150010302, 0.021851581686566916, 0.06604745067776212, 0.04482357845371289, 0.04354894221309693, 0.04217373394978143, 0.02522293354324516, 0.060111820592635104, 0.04592019501292417, 0.04684268361738613, 0.02752375796497349, 0.05222167038629132, 0.03184270504261217, 0.04790307570909781, 0.026794206689021764, 0.006368020164494914, 0.11262647747512787, 0.04191960726353911, 0.10009003082110036, 0.029529335931123748, 0.06194935908781425, 0.04058576774813476, 0.010563098964461637, 0.07605240575128025, 0.013712774661760177, 0.021572269859813878, 0.003289980870190888, 0.04278744698592252, 0.05458468774093255, 0.017132459005581278, 0.02978322513010954, 0.006394267773195621, 0.10414970693208518, 0.01996714328866332, 0.01258965912124803, 0.07885882330517616, 0.05852539039727661, 0.023376360956218936, 0.009375619589381162, 0.04246744439907132, 0.0861474757473315, 0.02380153400853517, 0.018786894825978145, 0.031445086257712494, 0.049856301141722556, 0.03145970513052758, 0.024097611669511087, 0.048075292274476066, 0.00627718368289812, 0.07199960910985548, 0.010179125163103304, 0.027669705375428164, 0.023739666662990086, 0.06228154247266151, 0.012382357644157545, 0.008150762784475041, 0.05679818771539196, 0.03479970100846502, 0.027435958543191516, 0.03244406108053462, 0.035844169962670536, 0.026449633747219082, 0.013814109899554283, 0.04399520375074879, 0.018292835147510615, 0.034084320443892674, 0.07788086610455668, 0.02935423312949077, 0.09817844992803951, 0.022502448071815798, 0.039543060796155084, 0.018737501307060162, 0.02802130525871631, 0.007749312123539107, 0.011798795913496326, 0.039554448693149516, 0.049148600608591116, 0.041311199386273666, 0.07812171648707121, 0.07164155493580526, 0.02595342519212394, 0.05445302403982609, 0.07857858068159512, 0.027787650357030576, 0.03552557314716039, 0.03396504821496145, 0.08068761307626002, 0.0487609792711033, 0.02714538139351193, 0.020037569751542424, 0.04889126018350644, 0.048896431276995334, 0.03573720110580325, 0.11963026012263953, 0.040526981991265094, 0.05234556595584559, 0.061475139171365774, 0.039554096292704344, 0.018890724637575688, 0.036503258386566755, 0.05006131393113925, 0.013427270929359142, 0.035973546891323024, 0.060691484850981546, 0.04624991542509487, 0.06543993529292845, 0.04666868206714431, 0.08275027416886822, 0.025067467490331303, 0.0912495217316093, 0.04807203640079787, 0.047908411511490424, 0.08732439364276587, 0.019482146430340026, 0.028782434678906878, 0.02391530189573044, 0.06655742008719714, 0.0238013788757305, 0.019174512333026337, 0.015553173537726606, 0.01688778392910477, 0.023660999009265535, 0.044033151916078025, 0.004474998230204708, 0.049552367249083136, 0.02084154455411819, 0.032282041145428535, 0.058249713657724286, 0.05348328696263414, 0.05461073473035809, 0.008082739922458367, 0.028426247844172102, 0.06652368157501183, 0.02247645853898458, 0.03619748971334869, 0.07196387876906703, 0.009576599883486428, 0.010118349492850323, 0.057739736587410016, 0.06153674030135717, 0.02494439163485602, 0.03779243880642518, 0.004349145784808864, 0.04832749991046806, 0.022237356752157215, 0.016664130305270516, 0.05761687906699316, 0.039566380512570186, 0.02993593901215542, 0.02018175132933163, 0.02890609467642442, 0.0534363717381512, 0.08345053981869452, 0.14477964730993395, 0.036142434804670276, 0.043002913045066024, 0.02345421847196356, 0.06575695013687496, 0.023510633186707576, 0.0359040473948323, 0.05104279513621042, 0.04049244291719891, 0.006955521023501793, 0.04310992020632952, 0.011181687192630865, 0.03863850247956092, 0.034842950502230276, 0.08474714363053923, 0.030361770900086533, 0.031497327708488995, 0.038018392609252084, 0.025308185722678903, 0.018843192712313706, 0.05402353216683673, 0.03391500352130782, 0.05313438370883946, 0.09096698850513467, 0.09806133040617551, 0.14876351902081122, 0.11667791048004744, 0.16757568134175194, 0.1297201820078396, 0.13175319549777817, 0.19198301278295057, 0.13251736820224794, 0.14314542854985884, 0.10529163759201766, 0.15321352459009618, 0.12699300858883128, 0.1886030635045421, 0.1499273751171366, 0.24105693514068283, 0.23440784354123378, 0.3068656191950844, 0.26035354082142154, 0.09666281391776378, 0.1684900992099316, 0.17348750524463194, 0.08758927620346509, 0.19933785522176375, 0.0759264532356493, 0.13579764944170752, 0.19365665442760915, 0.10487762835597801, 0.2187790216938142, 0.1220037537296453, 0.1282101001350149, 0.15197803927285058, 0.11436037193503111, 0.1240037028647719, 0.14217238963371323, 0.30226847877906216, 0.09371799491946736, 0.08568259827311962, 0.12482134850635646, 0.15523061877296818, 0.15872367327251743, 0.10459117275933105, 0.18727478961790764, 0.15530685984319256, 0.14333374828340548, 0.17605788344817777, 0.13699034108750283, 0.16978422089690165, 0.12372758945510273, 0.17269164714361393, 0.08811398514456327, 0.187204661929319, 0.1258468721061945, 0.27588940556010894, 0.1350124552845955, 0.09493805888679721, 0.16647274455716535, 0.2236962030010839, 0.14073516272248762, 0.18860724634460865, 0.17786652510685308, 0.09208187626134004, 0.0840565000450419, 0.18767576003747602, 0.24842576634499336, 0.14618687421804474, 0.19935297779738906, 0.12547338126047006, 0.27600928299850036, 0.2536450620860823, 0.1264688359092801, 0.15472863199970416, 0.20688156897742904, 0.11510251961167782, 0.12782385392535117, 0.18259291987745993, 0.11733330636014862, 0.1057037469300051, 0.14535470354941585, 0.09916771458642137, 0.11131369388632237, 0.18798576517691537, 0.18983113309068067, 0.1162643532358831, 0.09626509171099433, 0.12230386867398217, 0.1918572671110592, 0.1130849734369305, 0.11187833133003405, 0.08815679413777205, 0.10619187517271889, 0.11931417224508141, 0.11795159294119767, 0.24700180807661629, 0.1430917104646083, 0.21841172849939716, 0.14907312579452991, 0.13157799118949523, 0.047851023865082574, 0.16833706548617733, 0.1974930695348209, 0.15454402013171106, 0.14533743592760257, 0.1210614655827803, 0.20637518485947964, 0.1909354028682555, 0.20175581257189476, 0.14599437164443155, 0.15207139474730338, 0.33525211856730525, 0.14053230264013813, 0.16033058865897118, 0.12409760226165095, 0.1451092183349594, 0.14215829361590648, 0.16190805562561558, 0.19614640953800372, 0.20894825969251896, 0.11382480752804588, 0.15465979133882832, 0.09539437149801562, 0.1700747214377888, 0.28259442157803044, 0.08711330577610962, 0.09288203211561327, 0.11297892388557235, 0.11851046174283951, 0.25237876471252213, 0.10227050091470442, 0.1485200409567164, 0.1624047563922021, 0.13095539153343247, 0.14251956535923865, 0.08354568793889015, 0.16159500145623762, 0.1470301838050927, 0.07749042939394712, 0.23260629585673734, 0.14852039335716158, 0.12957801141085165, 0.1284280904538689, 0.08796630637539972, 0.26638133511427914, 0.1405891003988443, 0.153767375515834, 0.17608434412508242, 0.18195395658333458, 0.1044523346448137, 0.1663553798871656, 0.11871054092602384, 0.0890594678780725, 0.15771012362693587, 0.16473836746186982, 0.19911739043891433, 0.14028294102078484, 0.1949176657944918, 0.16673134519688546, 0.17714326149753987, 0.1615112374025968, 0.1365580070283144, 0.1288322248165646, 0.20456338691855633, 0.14732650661420438, 0.13130273579830123, 0.3522912010310158, 0.0969004926962718, 0.1284776793252076, 0.19425351352941608, 0.12012556660920383, 0.17989823624732035, 0.18846381936342488, 0.10208403511393456, 0.11166244009209257, 0.11282379108090555, 0.20506728891163103, 0.1281345715265601], [0.02849020469453066, 0.031140564392591198, 0.04760924268574004, 0.040026983216164574, 0.039193027562672095, 0.01954784613072632, 0.0875850014328476, 0.05711638233474186, 0.027165140716298938, 0.06782450653131931, 0.05080553770606076, 0.013844848219906131, 0.04474554090730606, 0.023140024746798223, 0.03365893480217746, 0.06221751284395015, 0.03251598907574531, 0.06806557907933189, 0.06540482548335869, 0.041202514492455995, 0.04085531961473246, 0.04601668761742692, 0.056605623854744824, 0.04682249720058134, 0.04908444457537225, 0.07790610870166172, 0.08858797906507408, 0.0958959752273175, 0.04900084140019552, 0.027078658965746724, 0.0552784837782383, 0.07160990784365324, 0.06942300261148522, 0.04411985008646885, 0.08255223277956247, 0.03219597499757525, 0.030257954495027665, 0.010526696381519639, 0.0411886099966303, 0.015981726953008726, 0.05700161087236578, 0.05565245725935506, 0.08595899513532078, 0.033858791819863746, 0.11379450875064058, 0.03239547961481637, 0.00746472099337787, 0.030205017819459883, 0.031100867631574793, 0.06866911846783853, 0.017476170098469142, 0.045002877501951116, 0.05442076790777426, 0.035811791256550825, 0.021234065023881775, 0.0150849262342578, 0.07097067641875437, 0.11911911093780111, 0.07175321991164839, 0.012517198694929963, 0.012572981387136445, 0.022638240986834132, 0.01698171779994042, 0.017799003380200556, 0.0647237120316394, 0.026762779847147967, 0.1085398197474499, 0.025131688641023733, 0.013826100133179177, 0.07584638938668274, 0.025123514482871662, 0.01992068963215476, 0.07547185666138127, 0.006867453949751273, 0.030131216739274325, 0.012876280384408611, 0.06532865336104747, 0.027044217567890886, 0.06029396565751203, 0.05681687643030479, 0.054177875900941516, 0.06064297233317649, 0.0420829716829523, 0.04501780472515572, 0.03222377249790776, 0.06603118663112964, 0.003930182353923879, 0.014373263111338021, 0.07786931349865853, 0.01942283398802242, 0.0731961694996684, 0.04601086534920239, 0.03467100206762552, 0.012527345529487057, 0.07095137866394174, 0.06202601384551776, 0.03200493756711724, 0.05628920655937926, 0.07794337887917796, 0.0821109431525392, 0.03725201357156038, 0.009867893325375214, 0.04803177464993731, 0.03821660253790118, 0.016355479226237344, 0.024440801822610443, 0.04877497952791953, 0.02744492943278484, 0.06873265013939912, 0.035099256708617174, 0.06020022713909707, 0.05020834535600678, 0.030224915038073258, 0.02946739580722586, 0.010171649102572232, 0.0557960910842784, 0.01987744779926875, 0.057978832628577955, 0.0305564874678009, 0.013039530848243065, 0.0675807067102963, 0.053186711344507434, 0.04833365925737927, 0.03460619869011064, 0.05812987835416871, 0.01241115871967087, 0.04864950964768087, 0.04560519498021853, 0.02435967119620933, 0.03430423364343663, 0.03607221518553073, 0.039538023768052946, 0.12043961669288336, 0.02815222393931641, 0.043076208507221554, 0.03700601507819468, 0.023034628285395525, 0.02882106274726891, 0.011631541682647602, 0.04437737820309497, 0.06627646500184652, 0.015890235945041624, 0.10311770222840771, 0.01799053876780935, 0.04088631553214885, 0.030457292488145254, 0.024843421246435855, 0.06699349265545607, 0.060713896753206376, 0.06666619691156572, 0.02882139216507635, 0.040989438627636245, 0.06293243758620755, 0.07587708652980867, 0.04128370832111086, 0.012591301422235707, 0.0839583718428208, 0.05180914736082477, 0.048798287753015764, 0.03176878138835872, 0.010969597666013626, 0.05191772117189342, 0.015712109968937453, 0.043025424538721005, 0.020285763086811192, 0.04187501711590637, 0.05703158406240325, 0.038121255234845226, 0.0343454108693667, 0.04067829584762935, 0.04713601102271388, 0.03834193835275308, 0.07388771706891638, 0.06006608514355556, 0.0662478975831501, 0.021668007867711208, 0.0036016359714971437, 0.01372387144534338, 0.08683003710522767, 0.03207888803444803, 0.03774628200898728, 0.0234509855809231, 0.019397706304106022, 0.04002606008021582, 0.032418734213757905, 0.011338028500998213, 0.05481224649796083, 0.03464510829578485, 0.12890219928756838, 0.04579045419250766, 0.04427025995908245, 0.05002351132251563, 0.04630914934340023, 0.020709390556740186, 0.025267445166865667, 0.041795171601998235, 0.025046599255273902, 0.08361721756838023, 0.044703409901910254, 0.03006783445485898, 0.01328256936939133, 0.011214049619382188, 0.057101577685605136, 0.05403298186138273, 0.0860999936177846, 0.007499100625394814, 0.03626865928151435, 0.03220748163819794, 0.04376818891614676, 0.008132782700892177, 0.045836722072694576, 0.07697914231328234, 0.047098848097507036, 0.030425011458235885, 0.07440624368046561, 0.01409108228530855, 0.04452495355038874, 0.007980093716703838, 0.025321048338927572, 0.0321552497635205, 0.038951977997297244, 0.02882930776855398, 0.040995774174770044, 0.018929682123745163, 0.01941635479940282, 0.05584431631911186, 0.045388058849400094, 0.030071050108921145, 0.05853146547451616, 0.02523790481650541, 0.06292710178381493, 0.016325136398776405, 0.051626255360221675, 0.08381505211394641, 0.056095903423885186, 0.011255999636505882, 0.03125584338821712, 0.03701269919533403, 0.010100265029787777, 0.034763051362167445, 0.039763146365482005, 0.03559438316451927, 0.07352613122953523, 0.09000398534079714, 0.03410105563459858, 0.1305752587054045, 0.048150863017766714, 0.09227159027490886, 0.008854913457687344, 0.04134064397564338, 0.06855963684257961, 0.04405701172447974, 0.019839120420416998, 0.05094640978401707, 0.021554538754806406, 0.07791540134818324, 0.07646000283139368, 0.028299946758535602, 0.020281103357011755, 0.05766374066532139, 0.02511225490560455, 0.0781870024999784, 0.021996935378880273, 0.01900809122279527, 0.15103458667234068, 0.035190298597538666, 0.011585244116553617, 0.030744226889744885, 0.04948146581169098, 0.029201431147333597, 0.013238601668197061, 0.018444131766896577, 0.03631647082886869, 0.026702672588608922, 0.05055223839477666, 0.00762768991990015, 0.029918115976597034, 0.03687787538153991, 0.026081721936803193, 0.04327615362501914, 0.0778436801967121, 0.04236406083368967, 0.05217541016698365, 0.026279916543693795, 0.04350167841860845, 0.06575932500944023, 0.032713432916470116, 0.03349622155749991, 0.02550694914985328, 0.028305736468023354, 0.047993707740979816, 0.05343309288183528, 0.017922939169370843, 0.023400040733958447, 0.022782524071273305, 0.0638431858932299, 0.03256207692527002, 0.01612143936536966, 0.002628726811493717, 0.034120548741831895, 0.03764482898517482, 0.020848966030884656, 0.056408563057982156, 0.05976399752281367, 0.034281147583838434, 0.0583311488040753, 0.04587279715304894, 0.04569653947387011, 0.07310691259561047, 0.04820231348276139, 0.08097907122705253, 0.09862387642985392, 0.04380776501831509, 0.05126733167637741, 0.02826090500269446, 0.02603795150324943, 0.06061304510841447, 0.09332516801453407, 0.05335434670409849, 0.03205246949237922, 0.02934819252620782, 0.02149978645085808, 0.01861387769871902, 0.031054490583858667, 0.1145776421312363, 0.035350418634592526, 0.07169989253123922, 0.023169559351499044, 0.0017713653763958945, 0.05930391575900778, 0.01956319278706947, 0.007808473263491667, 0.02117000283643363, 0.0643161379341637, 0.04226829601271499, 0.06663902377289149, 0.009730809552204466, 0.051416829904361125, 0.02100513113902942, 0.0541366373879775, 0.05117807860275911, 0.04599594961731665, 0.008838604403389318, 0.030086620845982147, 0.02450151046017005, 0.013363752664337236, 0.033403237635690364, 0.060461244786218296, 0.09522147311438477, 0.015895422360289003, 0.052714521561058304, 0.02805676172307182, 0.12580542674949094, 0.17781403276228136, 0.2180276579794384, 0.11345487899116932, 0.16593439925101497, 0.0772963103748137, 0.13179988089588382, 0.09666187162961691, 0.09704301569370494, 0.18207012615617246, 0.1501522525664299, 0.1633009873330593, 0.2066860173738772, 0.12001086026430131, 0.13838170997558102, 0.13256771550063165, 0.11096970508656195, 0.15320512826644606, 0.1659565085485097, 0.13257107096574, 0.1887387989629661, 0.2097267582411728, 0.1397242330976071, 0.13043901762895047, 0.19001422810458368, 0.137327664922322, 0.1726458810510174, 0.15572862188902595, 0.22149665731816526, 0.13109894108868417, 0.09831015576398182, 0.14359032645100547, 0.21036846413006707, 0.17347319472220638, 0.14837382541548821, 0.15952993484754718, 0.17587432878152018, 0.12039557429811648, 0.21637658528502912, 0.11726069654668532, 0.18473396708648052, 0.10492524838135128, 0.1232063432314223, 0.17658748003023286, 0.22770370086354597, 0.11471295624130196, 0.07672567446265491, 0.11713905710606806, 0.13741173541113255, 0.2238842009777023, 0.11873731569897746, 0.09159328070499244, 0.09126914124335013, 0.1348627770259496, 0.1767978477742403, 0.0925740954135695, 0.14882336580945602, 0.14206622516916645, 0.163316217160994, 0.12078643235708438, 0.21348480255373065, 0.1518521557051328, 0.1074195387322576, 0.2499478298329538, 0.132521566364073, 0.1007803526496695, 0.2655899356449804, 0.1854972970942336, 0.09470452464395955, 0.21033817301354102, 0.14535468822765737, 0.15476250840771585, 0.11530439910148421, 0.110796645824467, 0.14515665449923085, 0.14620397330051468, 0.10340367518966237, 0.09920365943182861, 0.12432369779074386, 0.1561426311250656, 0.1361832981027903, 0.1622814468799099, 0.12362189996506899, 0.17134420573711398, 0.14769121043143735, 0.21424793337862338, 0.2633533266282851, 0.080896326070351, 0.15924758548217435, 0.07897558276571574, 0.13345145920832313, 0.12346115173591722, 0.1416866898897194, 0.11402483308507551, 0.11297808884973488, 0.15468703342541573, 0.08030623918579471, 0.17358164212876753, 0.1833659485583344, 0.18856852826091552, 0.11419286681038719, 0.10806594840100697, 0.094041797302423, 0.16020795330405235, 0.1363050141522, 0.1768642829190339, 0.12128773731209579, 0.11639210605813612, 0.07469424677471961, 0.13050462539878585, 0.09654627662272224, 0.17468882304045463, 0.06486160019713064, 0.10442045006540515, 0.11519982043894068, 0.14581178224855854, 0.12633979605931428, 0.09785666235632474, 0.11499682246076484, 0.17732928296731365, 0.1387193555673284, 0.1794665303802298, 0.18988468263658786, 0.09665082464174879, 0.14286563791815313, 0.15536382614124208, 0.12043771679483115, 0.11641327306748399, 0.18258168902848998, 0.0768596325970946, 0.10141767651563692, 0.17304155014214978, 0.2862828897853052, 0.16679905204763337, 0.21043280019394814, 0.17473820506805376, 0.10289579720026064, 0.1273821506108488, 0.07273137629512819, 0.09711883541557098, 0.18208995251165283, 0.14076543851725518, 0.1686881329383581, 0.10020793941352638, 0.24450762497801937, 0.17250988512269913, 0.06833404693151675, 0.23398649518287953, 0.2247090325240166, 0.2330517146976725, 0.19212167469724534, 0.1410484160747259, 0.09931087343683166, 0.21674853629402577, 0.0830413339539401, 0.12682873635522782, 0.19844102673232558, 0.17294490048962255, 0.14264819152172536, 0.15134086862446802, 0.10901054247252404, 0.20059453053099496, 0.08742034615528199, 0.18008315455048315, 0.08335672469148714, 0.1262596172971591, 0.16565609482988236, 0.1579132441791796, 0.09804256125203065, 0.09012649812164808, 0.11584514992371683, 0.1984588765809613, 0.20324586890637877, 0.15687447491913073, 0.15647880582799836, 0.1245916983292949], [0.030659013014707356, 0.06366114041978313, 0.035830882167623895, 0.005856050786772563, 0.03657334394031956, 0.06974051541258251, 0.027686565055421768, 0.04416935085769623, 0.027340515479145032, 0.06682636291389504, 0.07104497928653034, 0.04910062435233305, 0.027510441441629684, 0.04159669354257565, 0.06849837279127491, 0.037203087366276213, 0.016783731952009183, 0.01396286597986135, 0.03784294698327299, 0.024973050984103354, 0.039351274514751095, 0.04413493435769793, 0.017998584606234106, 0.033902757605838205, 0.03671751019635028, 0.009775767422040865, 0.04206637055763314, 0.053653017572698095, 0.061156170803212354, 0.02934915205133298, 0.027617910170867562, 0.04788276671822514, 0.03301642069052304, 0.05217138054450193, 0.0436954258850986, 0.03187966112407946, 0.029391811657396537, 0.03505494618307679, 0.08214617553617685, 0.010298115854722359, 0.0347979428366788, 0.03376654717290113, 0.020220373652034232, 0.05972883408708919, 0.030916491335618402, 0.03719232766137969, 0.03591151292165441, 0.039686529912174716, 0.017088587065377546, 0.04135913350769589, 0.01570849594915466, 0.08424513387463747, 0.03077254532986591, 0.04448177683497629, 0.03670560902044658, 0.029237251503453143, 0.027767259011706038, 0.034734215812697526, 0.03624058598952909, 0.037118005641405626, 0.02404838285949682, 0.08391779216547167, 0.005401595459965569, 0.07704213772329592, 0.026576402146489393, 0.03377844834880483, 0.00975977533662151, 0.044292767622297814, 0.029947646750858235, 0.08629513153385732, 0.021988912523093245, 0.052240060326913675, 0.05059967838948773, 0.06540609718931299, 0.08676675058180287, 0.06362153367409784, 0.080992937418482, 0.042563841242583535, 0.025996937071003264, 0.038870860777434804, 0.054782001346710234, 0.010801583092900054, 0.0638945674103114, 0.005759085601781525, 0.0366047075799396, 0.015156736443450135, 0.04327875066308245, 0.04953655136388637, 0.029171546057407415, 0.03679003574014191, 0.035424426558517644, 0.0492521871872727, 0.058846982616570696, 0.02168529655694241, 0.057452112706678535, 0.03169828406234663, 0.02940378752687285, 0.046790336829520045, 0.035784813470297286, 0.04224192343592163, 0.0619048034141381, 0.08010047563021222, 0.03836693963216197, 0.03389701960728534, 0.031230476301824375, 0.03962437719887784, 0.021046204943089716, 0.03996746201488761, 0.05741879554285158, 0.01376921235914192, 0.029898567327989206, 0.03144065060863092, 0.03212206666508029, 0.030837482772767547, 0.03820185151491915, 0.008683779949112045, 0.03599060383895713, 0.0313774177113608, 0.030958509343045375, 0.0432054168965307, 0.11937860790039263, 0.012788963598018933, 0.002149101187129535, 0.10306981407226094, 0.02602694856543695, 0.033130433725854086, 0.0678041362534127, 0.032559759509299076, 0.05923147831532744, 0.036016283106179006, 0.02495626982812199, 0.04007235860391971, 0.06576695524516606, 0.02199775126251963, 0.01880091423499248, 0.15197687481920566, 0.03656900022178888, 0.06707338030420004, 0.017233370022187312, 0.050629709036119526, 0.0651741334267201, 0.04559319421288468, 0.027776344814488006, 0.07151745635295106, 0.07709664487910849, 0.019837515466215632, 0.12139052332889651, 0.026960221772652962, 0.03996650057454263, 0.08245582061429178, 0.03190784549881374, 0.007017811153820086, 0.1075552741906816, 0.07268554125461849, 0.016694582300260663, 0.03719051969387839, 0.03133375644533625, 0.030131036708612117, 0.06809138092062167, 0.019779428764576876, 0.00017814327293308454, 0.03626257271295594, 0.02213404596512837, 0.016290716068338484, 0.03180858157124491, 0.016411765621254043, 0.044296126917845784, 0.01847109423139163, 0.04819033186762564, 0.04028193727736512, 0.06288023635504708, 0.03912665753535206, 0.07748027872895041, 0.05689118312852037, 0.006712905287126741, 0.1276435244888548, 0.03413476350326692, 0.06013719342468728, 0.06307214138007934, 0.04762333487310717, 0.013606958767218937, 0.059605961244913845, 0.018593089902893673, 0.007565464907055421, 0.02104817378905512, 0.029879951391429193, 0.03954722448402355, 0.07377087333870512, 0.0024234099809320704, 0.03999646993414049, 0.05019306956279663, 0.0686864014114103, 0.042259374918836745, 0.0691605332277475, 0.041974405532762896, 0.024013190695475188, 0.024756338116863084, 0.053259298175333016, 0.029044210753073136, 0.08600623977761115, 0.06472709047938548, 0.058625223145129225, 0.03147355600019857, 0.06192258431486065, 0.051389361821836045, 0.03711047499710995, 0.027802692493423823, 0.06084547235420155, 0.11709827824585861, 0.04542526390944277, 0.07560265085269367, 0.047261565172624205, 0.00766850469048105, 0.051824361867000984, 0.09104364326283818, 0.033440622726395246, 0.032402351423497164, 0.013104052688445778, 0.039066554107252634, 0.035941539737846584, 0.03834932344034314, 0.04844831963700633, 0.037557360896420096, 0.0971396730071114, 0.04069814901618708, 0.09582867440316947, 0.03305750215546258, 0.06300899658292052, 0.05299195264195723, 0.07421754090295685, 0.04748929629943544, 0.06070853413773641, 0.03567599068065325, 0.03314796181756162, 0.015994561798570138, 0.03508782667678691, 0.02033017128856192, 0.06843305613485075, 0.04905971142673685, 0.08324941109505393, 0.029073379550790115, 0.057812698801318486, 0.06458310425401696, 0.0664843046557038, 0.03581573277892124, 0.0825076004970939, 0.019395808321273616, 0.019459430008165298, 0.08044727597265475, 0.03505657795035551, 0.011412706751857075, 0.055242711302614024, 0.012331712529093269, 0.010181279785390343, 0.011066608337475168, 0.05079927110684015, 0.06589577292963382, 0.03304455143910262, 0.016186083779640256, 0.047536039154135415, 0.030137638471299605, 0.010624476013735179, 0.032317112650602095, 0.04814004585627587, 0.020953165479905663, 0.025165042194027095, 0.08652855086350635, 0.02914773795994059, 0.004289931497506557, 0.023327011487356598, 0.046709135339985934, 0.016339764847690542, 0.03303583335852431, 0.07221975979665596, 0.04878285108134151, 0.02951915845304968, 0.03345784821337269, 0.035105071315962466, 0.034445362360847574, 0.06779760152341859, 0.036550173611049695, 0.021974795437868566, 0.04326635153002797, 0.05216209555885965, 0.01440044869894102, 0.025045061333765908, 0.08255288395429812, 0.05881774104050091, 0.07204692270005904, 0.023383726891610893, 0.044104083996987155, 0.03799223070663791, 0.03815573302187747, 0.04331254280142246, 0.08432421713106095, 0.008001285145104292, 0.0794672120302435, 0.040412218189768256, 0.09924854452331221, 0.04883581073954702, 0.060598619672800266, 0.0380881219321201, 0.06103364653104256, 0.022644988306227232, 0.027002339371510094, 0.06618360748454448, 0.03866842970432293, 0.044308920586181265, 0.045707789475038174, 0.030095112930622794, 0.023865419995760726, 0.029483081457475503, 0.088490923385947, 0.03488063819766526, 0.013881727692580993, 0.08483884435507559, 0.0735168922091684, 0.053793154206247105, 0.02790415509333534, 0.006711726469333254, 0.08662847171147024, 0.02716542608405073, 0.08234975574117515, 0.022537624914078944, 0.028282818947768504, 0.05938083098660554, 0.034329541358015234, 0.06770948609036785, 0.025569157404524666, 0.04999892756102547, 0.017550628099049774, 0.023399544692027475, 0.03359169526506336, 0.024820174308373563, 0.0938853238438887, 0.008414817970216034, 0.03165788824609932, 0.008468757263354717, 0.044597540381214315, 0.025817302859298168, 0.012629087751490936, 0.026113430315989162, 0.04456713818193925, 0.01788147849090878, 0.0388090604645831, 0.05461922681499874, 0.10042101144790651, 0.04642004823131908, 0.058546469306513194, 0.06374865064337369, 0.03736500770995214, 0.04744659455853605, 0.10755498307727038, 0.23531760359483384, 0.11468023662605595, 0.12796887436941748, 0.12437522486453095, 0.1442392795316635, 0.10641510553297498, 0.104717125274962, 0.11962688933577269, 0.20811121670469163, 0.1730753959066445, 0.23962565307174963, 0.17148603925541525, 0.09350157508085813, 0.11684233593123576, 0.14009630668067163, 0.15520287106835073, 0.18762527484326594, 0.22535047794301666, 0.16915253543805692, 0.11662165664376752, 0.21591998156039946, 0.14430975962069728, 0.18838770086726836, 0.12255664704547775, 0.11906477998221114, 0.08996487655226262, 0.16641649838176467, 0.19390583218586063, 0.17768051895883777, 0.14619697125688677, 0.2121666257059382, 0.13526144918174515, 0.20388898439705375, 0.2158484136265132, 0.13206690850277103, 0.08258677568406829, 0.13979953954056387, 0.22331472185830917, 0.19542579659290854, 0.14242411080387332, 0.1526750567098779, 0.3049967630255607, 0.11467020087424787, 0.10331759755049022, 0.21366869429907492, 0.15352121614400419, 0.23961060710491675, 0.08325898719410743, 0.2132453081468421, 0.06876215218536316, 0.1547013286260828, 0.17235121299182216, 0.11446508849340101, 0.14520456563801537, 0.10860430136803659, 0.17190980845161025, 0.09883304907669944, 0.0863865488058617, 0.23788140876398933, 0.11400617884411929, 0.17207915984815167, 0.15224457658346624, 0.1989443771420948, 0.05974167755113975, 0.13087171941034256, 0.09490337042558579, 0.14048610753830404, 0.16560842883923363, 0.14416443274146126, 0.14633486708325727, 0.09340385290523691, 0.1591820696428899, 0.11830289788063496, 0.1632330659776926, 0.1546863286245254, 0.14971319225526628, 0.11927252770551752, 0.06699228989741496, 0.2227039659215558, 0.19570025525266127, 0.1153660691793888, 0.09107066318392755, 0.07742531958126253, 0.26306613558723085, 0.06674704217021504, 0.14421301803761913, 0.11213075730108446, 0.1552229425719669, 0.1240311211515819, 0.11593755544914354, 0.14357630704199115, 0.12852685450906717, 0.07798605763743963, 0.2059785351758042, 0.09874680289818395, 0.20831148740985703, 0.1443309342909244, 0.1950946014614836, 0.12021522187898237, 0.12991040163943846, 0.12389420591775449, 0.14743100100707623, 0.14960192564514377, 0.15698448514505742, 0.1704153088071654, 0.12343151179412681, 0.13961728722337755, 0.12153195848147716, 0.09938340664150254, 0.1619283722773675, 0.19599807959410454, 0.10399959200332243, 0.12042869993996237, 0.22073274508358973, 0.1405219144878849, 0.14664830429659736, 0.11476082907569025, 0.08868262156723969, 0.1360676954350164, 0.17681919098381074, 0.2063933411432851, 0.12946470700685056, 0.3173636284566695, 0.20427916829864826, 0.16228308630806787, 0.162775359086452, 0.14910995930192933, 0.21138775943508073, 0.14702181812495957, 0.10978354050988152, 0.1462690294870446, 0.2000838409989111, 0.09672895794914615, 0.1745009323161456, 0.23544682730590147, 0.15876922486049516, 0.17879978873797003, 0.16073900545316358, 0.22064366437975438, 0.17123522206900582, 0.13525484550383784, 0.11037683730284054, 0.08539416616962803, 0.18615225630421794, 0.09015854357952073, 0.2485445406167738, 0.09228837526132984, 0.13081594820945494, 0.12304250000705644, 0.19333138881671816, 0.14943402981565845, 0.13804403374031668, 0.12467761509000294, 0.12187436914011357, 0.15867092045805148, 0.09881359810430197, 0.16225898518197, 0.1510226663442389, 0.12441449453152957, 0.18204504443753153, 0.14619985174748207, 0.0950273311126136, 0.15022913715051067, 0.11768454235167274, 0.13396400267318373, 0.25879737109907214, 0.08176814178906142, 0.14966298285270893, 0.1244498111848389, 0.13450509057410304, 0.25121682383600746, 0.09889909351665167, 0.12962529435753822, 0.12953192356132692, 0.27753747518985505], [0.053272007573996825, 0.07994705120161658, 0.02872806350370088, 0.06939980546913802, 0.035487889282165036, 0.05332766769213542, 0.028114540074321053, 0.04252250696862898, 0.06756140129460443, 0.0339513122584791, 0.0431553760333167, 0.07907729625942246, 0.05506183028281216, 0.04443313025178448, 0.015268595814104042, 0.03909658858432405, 0.035230276895867246, 0.030951652856123064, 0.038422366093483665, 0.05747009662070102, 0.00971891029152058, 0.06509933260179336, 0.0413367445881088, 0.05194816550600433, 0.036212198601494876, 0.08665220511536445, 0.06752453714368806, 0.06874201939471307, 0.04055639210667822, 0.020901130872868726, 0.03801063596901875, 0.07775520470233695, 0.02053166581918636, 0.006496893869142139, 0.016587481293226444, 0.07022126622858547, 0.01596683037332109, 0.017493008711044828, 0.05144039859935161, 0.03294506726125556, 0.03962746453321269, 0.09071925099218085, 0.024440773094313282, 0.04657222010615853, 0.06869528803133196, 0.016235465807239377, 0.0838191660060998, 0.044471411665360776, 0.08931225391044732, 0.10148140737005781, 0.06601608703814207, 0.07968525597525221, 0.02597095519905129, 0.07908804447300012, 0.027082137004922957, 0.033019894899259654, 0.021769252132564303, 0.08236377515018949, 0.01648283176754992, 0.015497065258152304, 0.04370594810273859, 0.03249466501837296, 0.043031438328926606, 0.04017090815449915, 0.0228914636893258, 0.035641597163292675, 0.0319559462443595, 0.03887726910292141, 0.025074325892473423, 0.02082389771878239, 0.020312455505312934, 0.048236147755937236, 0.019994061703102726, 0.041400632490554166, 0.04709174646244896, 0.03257204755960453, 0.03028854247062437, 0.026060039733326244, 0.019825610459872314, 0.07416767623996542, 0.04356323741376401, 0.010317901990586712, 0.026198814645589843, 0.08647396709890136, 0.029995228471835295, 0.06696169234571919, 0.09243924861713763, 0.034853112658545855, 0.06033619242389837, 0.0007661982289714469, 0.07005411350438673, 0.033432280028899836, 0.03469359017007294, 0.056776530409772555, 0.013319573331353887, 0.022496269572706475, 0.027006504974598368, 0.01447618127830567, 0.06552988933699747, 0.05516083565570655, 0.05268474755388114, 0.06428210830856716, 0.03827471413739747, 0.09006968504118343, 0.029444522337026657, 0.02048769428755247, 0.01684130154429905, 0.07340371804011446, 0.07032056654533071, 0.03508446355079932, 0.054468556472490874, 0.06913758889441529, 0.014130925560640472, 0.040614067036057674, 0.07458078149225443, 0.07739256932249955, 0.035797729712700656, 0.028563555698060704, 0.02523749687468573, 0.0290480699209917, 0.03116952443134881, 0.03173573044008546, 0.014158321822422647, 0.08730114287426395, 0.010359370329928015, 0.021829861178693753, 0.07532939495098206, 0.023336668025642153, 0.048306076261665554, 0.03635451858562808, 0.043871472890098254, 0.09373348521729631, 0.030748375255854863, 0.016448262049966765, 0.047302972224931565, 0.07994592505236787, 0.0423114305932916, 0.07689540890315849, 0.03405042488368289, 0.02891818737430919, 0.04808591791398583, 0.028303769537277763, 0.06868850049232283, 0.02140636968937132, 0.03946128474067777, 0.07037694295567852, 0.04553997791522453, 0.027485413349143444, 0.05409013585097367, 0.03715029241697442, 0.02401037915279308, 0.06597824229468262, 0.06738298707791875, 0.007104119576979429, 0.025021674584657438, 0.061279725463640314, 0.06120070349425078, 0.0029849102945938228, 0.030628832980930328, 0.01584607193381676, 0.028861278532854015, 0.03449056154838012, 0.010675070375474471, 0.02640263042262485, 0.026586702198631344, 0.07894560574523865, 0.03933594892582586, 0.032909298616070906, 0.014878301787370396, 0.08386214353865193, 0.07471109304817454, 0.05002921867755152, 0.005902190347232166, 0.01897286458481704, 0.034991111906786124, 0.06128016213375715, 0.003670765830564403, 0.04121176117370206, 0.07029598278384055, 0.02699610533102626, 0.03709483914257538, 0.024322448899188352, 0.11662782365155798, 0.035063530198268356, 0.06160532049233876, 0.055115375998279745, 0.0608230566215371, 0.09357727222865628, 0.016035944910629863, 0.018132257372921994, 0.062304728123689854, 0.044382491839989546, 0.02672359444982102, 0.012558405606767103, 0.032804528431546305, 0.03693836185360148, 0.024298068150998126, 0.03451825179640324, 0.04757076208930343, 0.03202429086330437, 0.029466344351549784, 0.07874681358976711, 0.05899355055824403, 0.06853786462377157, 0.05334415007382632, 0.018901143433345903, 0.0852142044553353, 0.0635002389730465, 0.07659931592042409, 0.016875233493685242, 0.03982183253092151, 0.028526873493026343, 0.02154316043391103, 0.03578956704586744, 0.0530992049513565, 0.014779149900160491, 0.03995097580275709, 0.04871751144227963, 0.050115365264636856, 0.02089894177662509, 0.05852635183762159, 0.05047755248303856, 0.017659858830513495, 0.04001718495161303, 0.07421063078987984, 0.04483289408287214, 0.032585002106404116, 0.039489951750804345, 0.014553062989556742, 0.08330178086555774, 0.06178426714013181, 0.08445141070912923, 0.024229608618864612, 0.0550220511673439, 0.036796294678483284, 0.09208328586312071, 0.019733070869058855, 0.05252345540230313, 0.06045219345739292, 0.03759023372925097, 0.033646972339239814, 0.0016093515460529637, 0.04867039703493638, 0.06632190933751483, 0.029699083778166005, 0.04023583410608192, 0.007015472670431219, 0.007676802380310913, 0.07314943047540803, 0.0676108982353922, 0.021244874524493373, 0.05002680167015042, 0.0654244449950995, 0.01984660318421741, 0.05128554158633755, 0.06943421813869669, 0.03629280637288767, 0.019989122351210926, 0.04302592249587179, 0.041456863344196355, 0.07506364671092841, 0.11324038203325003, 0.03572355707987182, 0.05728515916534009, 0.013486690623986145, 0.039610740833825646, 0.02137744603979011, 0.055687452155736186, 0.019128847747079788, 0.09744624607264997, 0.04223288359841512, 0.013938823267967712, 0.06563440671250706, 0.014544831374810349, 0.03523659712124256, 0.0105530699159229, 0.018439604187264078, 0.031693970987332926, 0.06649959577067245, 0.05638765651852854, 0.072412951849401, 0.03288640024801416, 0.027772364987721367, 0.024082973644497897, 0.08220596103778771, 0.032216103957785715, 0.05421066829454034, 0.03531616684349795, 0.02659423475814683, 0.04830936660930034, 0.05913411237059101, 0.03960075870817227, 0.047015026587271885, 0.03204452516060443, 0.0681121648860074, 0.06332123486865913, 0.07351752806214557, 0.041356249186660976, 0.05805139264632618, 0.017730057382235126, 0.01490260496915829, 0.05042907826962972, 0.01706918780391495, 0.025791784470540383, 0.032422353979200125, 0.010699919394908414, 0.05290620825103214, 0.04800981857002743, 0.09799373846861625, 0.0559449955941208, 0.009073164246435608, 0.03877119656892554, 0.024479812934934616, 0.06926059963241701, 0.022955608231225805, 0.024065729005322344, 0.022508209053006385, 0.06032200064510108, 0.0653786099545898, 0.02167244160157298, 0.055208237346021406, 0.025212344292911793, 0.03287021281017411, 0.030405397692154494, 0.06002105066492673, 0.03528250494010506, 0.016774567625214978, 0.04701396938593638, 0.025138412977779107, 0.05278093372321418, 0.0571978404637306, 0.02194208731394141, 0.043239917666200674, 0.026852454269124616, 0.003022871866461731, 0.026872791988294453, 0.06320854333499748, 0.016730280082312324, 0.04274098375331491, 0.008569954605322451, 0.04636797340466611, 0.13782945251272571, 0.01444166805970693, 0.034754252842357086, 0.04167528267228796, 0.047958417900747834, 0.045320976360310475, 0.044382568448781974, 0.01616830287891771, 0.03758011370777123, 0.04381282119861534, 0.010487956272798681, 0.07623343232778773, 0.10324896373335393, 0.11730313781769046, 0.2056663696684184, 0.0909081835960669, 0.1156775375467635, 0.2171511921070276, 0.10613779702614393, 0.21279889339160538, 0.09535409059495696, 0.165851830294536, 0.26106915887325044, 0.09883583763674383, 0.12050247420707058, 0.10364991883116384, 0.12094866679680925, 0.1783885220966993, 0.08342199538263582, 0.1781148908119048, 0.13712030024297778, 0.1366849018320922, 0.18531312955723656, 0.11088889813230884, 0.1828048504408329, 0.1253106182200774, 0.16595087014138699, 0.09643558457854295, 0.27315373622602035, 0.1546723551807865, 0.11863103632124201, 0.1285421992501905, 0.17054514538857246, 0.15036547015751564, 0.09059067079496962, 0.12980969172091256, 0.14911780404227395, 0.1408985079897027, 0.09832388405958492, 0.17693272521418912, 0.08757380122739462, 0.1485064199134227, 0.2779812239591153, 0.12507835568319406, 0.14206581148168734, 0.19987022504210475, 0.11383271355542446, 0.10449840717257992, 0.10681273580919351, 0.3017312366395228, 0.10137977048514352, 0.22989967657673746, 0.1720791445263932, 0.10363631310962862, 0.1707236438749298, 0.21237975136647302, 0.11934775753968185, 0.11761145756369638, 0.12809320277864897, 0.12800674209551466, 0.17694021755408856, 0.1302082566243987, 0.20525232978886176, 0.20798513395411355, 0.13986857938430003, 0.13062505442048275, 0.10922026670267505, 0.1559568241599106, 0.1685599511068675, 0.1297990890640405, 0.10608540427300239, 0.09639023983430478, 0.13951081632366105, 0.2149239293630085, 0.20353725810925807, 0.15482839196920395, 0.2780692321398566, 0.11701830632744298, 0.1451151018902179, 0.12320950717454958, 0.16533030827920284, 0.1392625731926772, 0.11370966451302653, 0.14485408041265704, 0.12142430780635727, 0.28147329786612146, 0.19365144502972403, 0.20578918888443903, 0.17439752576812623, 0.21218694235769012, 0.10993375503007444, 0.16278858176402508, 0.12936166818103484, 0.1260826126822541, 0.22013816892379717, 0.06984105679176508, 0.09360536467283966, 0.13304511085152626, 0.09719666994867787, 0.14488374333708517, 0.09987568708076593, 0.15586161475268104, 0.16152790747582912, 0.15039986750531584, 0.23341099461240156, 0.15957902576173508, 0.16164151831499993, 0.08073354004732064, 0.10847472525652378, 0.1885489623753294, 0.20748066505597484, 0.12211020164672406, 0.10094592723274425, 0.135285550307843, 0.13268164809673064, 0.14199609748057782, 0.1509699441732899, 0.1194545578572058, 0.08697711832581029, 0.15182080738727124, 0.153716262129526, 0.20033822815504768, 0.16630195291532626, 0.11731331912620414, 0.1427212916314602, 0.0698550378963832, 0.13847581621619964, 0.13908343119246347, 0.13992796652019024, 0.11405068089164073, 0.13062652530929736, 0.11402477179804157, 0.14306235397534986, 0.18409235312813715, 0.13697708776641276, 0.2208018768578768, 0.19439441242044975, 0.1559619416272448, 0.15496086389307054, 0.10891254450525008, 0.09804929516488507, 0.15446227855019032, 0.1368202236030371, 0.15861453638682443, 0.09609152683086934, 0.13800359961967315, 0.1586925241375162, 0.10357745457440616, 0.11041691136215964, 0.21171725385131376, 0.15737427068093132, 0.11677594675171761, 0.12671080478016408, 0.1499322934016105, 0.10066333271923567, 0.11954925398552611, 0.22351536028567823, 0.14646963727089668, 0.09640203758833871, 0.0992102784314944, 0.1382724964810956, 0.1361231448789758, 0.06539593120255778, 0.06311307728831327, 0.09261578591840883, 0.1476717671199191, 0.24753140465867138, 0.1312125059625795, 0.06794603105874793, 0.18545410505706267, 0.2194225508719683, 0.13848816555353904, 0.18776818088466124, 0.15168044475778458, 0.27673286836474176, 0.15421682397925085, 0.17361841434913297], [0.01571232255833644, 0.036965431570405924, 0.0276337203104049, 0.04516999575219328, 0.007556095172936518, 0.018382689600149472, 0.05384988301704007, 0.012511996957924099, 0.08685010860884383, 0.03324394880403434, 0.0325371062893781, 0.01340926786313855, 0.005279799928933743, 0.04295890512425573, 0.02807146295033876, 0.034951424721868775, 0.029429380609203252, 0.08811108167133025, 0.07455886371674077, 0.058411963419207645, 0.03522125621055884, 0.01917080638269263, 0.03896918050163696, 0.049709373138724804, 0.0523375679979161, 0.027430027107437773, 0.00709783430436566, 0.0494218526798631, 0.0578298821534601, 0.0642453016142451, 0.032129350246020386, 0.12647365460232382, 0.035097862428594986, 0.014466546765047938, 0.040548708244797685, 0.04013939512773387, 0.0379713433193824, 0.10280303927438875, 0.02340537079069163, 0.022325558370099436, 0.021016827386413372, 0.03181541890596911, 0.03299485531545455, 0.05918713714627009, 0.060501989172471154, 0.0332715394606273, 0.054426839154574184, 0.03947672524279164, 0.03180344686693242, 0.0131361287898354, 0.04134449356746289, 0.05824080022472528, 0.05231068980309272, 0.032984329267374934, 0.04454939558561291, 0.039919796024238875, 0.05898070709419347, 0.05110003722591266, 0.03775899523809072, 0.041963818197649334, 0.057218701037908756, 0.013502013340081661, 0.08348059344796405, 0.017074550419384917, 0.014215910566910623, 0.04989409608946693, 0.044488805691681566, 0.0866708440345622, 0.02530064167184455, 0.020430461773949287, 0.03642370015563023, 0.045774393159175114, 0.12973406352102757, 0.012785381179363018, 0.030892643018535552, 0.04609327342721724, 0.03778856240152832, 0.07840104746602236, 0.048385860488539746, 0.02302615152251336, 0.05847010949266054, 0.04220287210398144, 0.025372925897940032, 0.02955982240007049, 0.030142493553519733, 0.03389021291607811, 0.023318664959421562, 0.03475809094285773, 0.020614820832927382, 0.02950494560683447, 0.05423707917572991, 0.026310676889073466, 0.023494374885734533, 0.018180134037749904, 0.06648773672960459, 0.029421131757478562, 0.023911000312035604, 0.03598244883300316, 0.007786147546158323, 0.022200879475642598, 0.022722684943507758, 0.0731137537607743, 0.05039837346562455, 0.05429342877300036, 0.0013911943636729473, 0.04332719423297433, 0.007443509455169401, 0.04798510457359014, 0.030128740360059088, 0.014140827247061798, 0.02067889259647458, 0.02621577008657398, 0.032506087389323986, 0.03431561004911219, 0.05100267894205548, 0.013986327422542438, 0.06775465463438342, 0.024405037007865407, 0.09962006652307126, 0.03421333348078113, 0.08621189608088425, 0.042486083318269065, 0.09926536015325016, 0.01262801810122666, 0.028441556196119037, 0.01861665476744454, 0.03765408332730013, 0.007706463389519243, 0.015728756101922165, 0.03995397503698065, 0.037488558539940466, 0.07167589865745076, 0.03685844739178016, 0.038995595213266156, 0.007410455155261462, 0.01612993145001031, 0.013445743224433353, 0.013757109127548194, 0.03961451764729235, 0.03735686036487741, 0.022462117373042052, 0.025641464613257878, 0.0983688380989817, 0.030496456818054282, 0.0688465980572566, 0.06238020310598997, 0.009164806556767754, 0.03902742999695963, 0.030571606212986574, 0.02940257136229306, 0.011622831262948533, 0.03352630966072602, 0.09026944246743956, 0.048756842396312186, 0.025487948254111315, 0.085143456235528, 0.04108840952657404, 0.01708436400569495, 0.027155388417022846, 0.0301092702354635, 0.03850263678618977, 0.03884050071299557, 0.04451039787982741, 0.045376981218015, 0.07838310568683571, 0.01385753367832231, 0.07648142264975656, 0.08696737368741343, 0.05789431397833171, 0.03710475232031557, 0.03930475382554916, 0.048849562017787854, 0.03294736169458878, 0.0831478738015698, 0.012872101374781661, 0.040613511622312574, 0.027536191571984562, 0.03338595852255821, 0.010850665388598798, 0.018592092073372295, 0.052910659221872214, 0.029288991166639234, 0.0629615297751321, 0.03369589088364475, 0.033982250719301166, 0.01774859096434328, 0.02579944534978319, 0.045348421460197824, 0.06240707747037373, 0.05682654062946958, 0.012160708297855191, 0.02743389202101577, 0.04418732328039985, 0.02482392813920254, 0.07562751040583657, 0.03088414518823547, 0.021155878090329712, 0.00910534568491482, 0.058036626301585674, 0.08834838506675537, 0.029327831824400255, 0.08643495790179699, 0.04087314648073047, 0.053487236145883806, 0.012258468777872624, 0.019851651703638416, 0.049486024034840446, 0.025574192517407, 0.06900186109687052, 0.005352523697975783, 0.02861542368097411, 0.029305088589148178, 0.009764237798780445, 0.044315991577722376, 0.0748431666063205, 0.02774551935163477, 0.05402993283144409, 0.017806344417734973, 0.03939480363060871, 0.03574761990157347, 0.009747360881808545, 0.03767764053097175, 0.023402273880257722, 0.00978464350825356, 0.017001657153389627, 0.027210209668884357, 0.0793538693218462, 0.04640307555335664, 0.03737642242002391, 0.04473788385850288, 0.008754557854826412, 0.022944342908299258, 0.05836652674441857, 0.061217492311111385, 0.14336082183064955, 0.031773944820968375, 0.02141914995116813, 0.011391135631129147, 0.0462478623094578, 0.05467490991577507, 0.09963354200965936, 0.0396151535002695, 0.017081791865489176, 0.005815546281800996, 0.021066569475336902, 0.056255073511912945, 0.06630302527018132, 0.044949542460662704, 0.04632399229693317, 0.01728392607953039, 0.029680111610721198, 0.02418961308355774, 0.03780393778616863, 0.08328399230395594, 0.027151646077512737, 0.05813591129657242, 0.018761156186942133, 0.0720835876681151, 0.02837480887049629, 0.05233916912167784, 0.041805356740951545, 0.02687526836750969, 0.04203569639714495, 0.026988423384365537, 0.03667052602395415, 0.05886340371122765, 0.030534016193761945, 0.01603185974677364, 0.012363886306693238, 0.03170954555483355, 0.027155325214769092, 0.022664874033521742, 0.03480638512560437, 0.04233276231154319, 0.01006146076120316, 0.05084904766972027, 0.05621165547880435, 0.09015108954401747, 0.046449025507054986, 0.03318743449786017, 0.0449240202414653, 0.04282145745932095, 0.030730538813757802, 0.06663073470155079, 0.05292031959059739, 0.01610723034959407, 0.025250842126326698, 0.037271973992427515, 0.02590818770019518, 0.029985315294095108, 0.02880887620361342, 0.021779172971183737, 0.04455972245083221, 0.04059989823989811, 0.019920837104080186, 0.010236580799814435, 0.02129779779352248, 0.0402313563221645, 0.04583066997809276, 0.001148331085137362, 0.04501437265125494, 0.0344287229311322, 0.04767077103737862, 0.1214338532618938, 0.05444465835969295, 0.06777430478964122, 0.0371456346023948, 0.044365614923017646, 0.025126113436154784, 0.009091991814784706, 0.042753620373625914, 0.01920986729073188, 0.028301049925146565, 0.05233273015267426, 0.04576027415873063, 0.08545036637975324, 0.030259396655545123, 0.03102596146955846, 0.08535504205933503, 0.038673995333092834, 0.05284743398548134, 0.05922241166474358, 0.0177211937449512, 0.016038742089163394, 0.04666536873687179, 0.006816373600985014, 0.06026355579735772, 0.055357950078623916, 0.0439510349514744, 0.042993267998099334, 0.05243766121566296, 0.07717643293642229, 0.0851455323338028, 0.05062081858575825, 0.01846858529343961, 0.036113177906842, 0.031167670498572053, 0.06351456098679094, 0.05490656341275862, 0.04101419475890937, 0.01982145060244347, 0.02163930638362804, 0.0632603423699977, 0.04087946287566616, 0.021381580999361414, 0.026781501120797573, 0.03397865776693629, 0.03653084138228047, 0.043751606943025705, 0.013036312321351181, 0.0308404092286383, 0.0182324291146811, 0.08131068004595657, 0.09941827896381579, 0.14418381476594558, 0.11048241954056487, 0.15082388184964657, 0.08078908908271021, 0.13004713301216403, 0.16346139082264516, 0.12908869573185522, 0.252992661609765, 0.17440917030457528, 0.10550198235338736, 0.10918403840473584, 0.12593342471987973, 0.11108532307609437, 0.1780737978556464, 0.2319309893514841, 0.13964687353901326, 0.17413693329980298, 0.13887583668674194, 0.10266766387728915, 0.0732628727752355, 0.11078350741656558, 0.23494053511850296, 0.09542955791637783, 0.16990742315688442, 0.1163285667256963, 0.08671585170011367, 0.14078377866216246, 0.15524448496439766, 0.13467670959090033, 0.21504654939616882, 0.19125026500513478, 0.1356949476945785, 0.1215037587849844, 0.17106135075371112, 0.15834639029156777, 0.11699144728481771, 0.12365457361503956, 0.19244911599784129, 0.17738058021472347, 0.06945112569918556, 0.13224988094260617, 0.1737439301946471, 0.1034156185004019, 0.13698874762462032, 0.09835560776052937, 0.0999928908723016, 0.08124065960967734, 0.11586489967040478, 0.20131739577458752, 0.10344336620501934, 0.248343626397752, 0.1191820373999015, 0.10138859581803122, 0.15965972546367876, 0.16458680462693015, 0.09594443028852825, 0.3713761979053098, 0.1446128393253011, 0.15438438273004948, 0.1413025427609682, 0.17594977312030333, 0.16377245316342, 0.11309612001622878, 0.12113535476307716, 0.18370733265915226, 0.23774182754418544, 0.13625800699716614, 0.09308469301510243, 0.13474486077264433, 0.12094091398701554, 0.1724270710180844, 0.11907027283262824, 0.15390848891148645, 0.16007758046109832, 0.19046439669064938, 0.207268106300504, 0.1553317270572147, 0.08256854279147041, 0.12256652191882172, 0.1992391218100825, 0.1112934231998459, 0.1282527482497596, 0.15446229387194882, 0.1900403210592847, 0.12928087654854023, 0.1911385693857747, 0.08859643667575814, 0.2241133378758546, 0.14248659293497765, 0.10801639017318526, 0.11343439380007406, 0.0882799504324794, 0.1495670839663475, 0.13772094381913064, 0.10224171133050997, 0.10787871651231282, 0.1662721827385887, 0.16555138593239171, 0.13655794574128044, 0.313169174497166, 0.1260923343380132, 0.09636593186446736, 0.1405327929364097, 0.19730522477578735, 0.07920873396459126, 0.14245450917270877, 0.20097676243993545, 0.10561602220179574, 0.10927534076355158, 0.1277987109196763, 0.1838516789458452, 0.11829754292604425, 0.14145090334838437, 0.09576580922810302, 0.1112053843755876, 0.22509504890730306, 0.10856561392786042, 0.13896120952502375, 0.13049713305888638, 0.11386891887072595, 0.1983763535897578, 0.17019686649643606, 0.16701747903660422, 0.09968629482412532, 0.17432402729267077, 0.22375493130135923, 0.11996559212885557, 0.15120484205263277, 0.17278638157633044, 0.12178548761913854, 0.12925954866072825, 0.20216318748651013, 0.15076314639900962, 0.09289350045183975, 0.11286361233120966, 0.20411203855708723, 0.09468570952453921, 0.15255376966970582, 0.15367428051127544, 0.15281043976785677, 0.16958209625895948, 0.10239934924268916, 0.14882278358263357, 0.1591840767932515, 0.18773433512016652, 0.06042877797998729, 0.1529140761422534, 0.12951188270122777, 0.12015851605082713, 0.08314190597663965, 0.1474150970217682, 0.10073024283854232, 0.11774748413553161, 0.23212465637874222, 0.1387499224755072, 0.1318504886641618, 0.1957158528027996, 0.10143983943928635, 0.14288880441698337, 0.22690021252680212, 0.14026654673920524, 0.19770412675796017, 0.18318216406529952, 0.13896546897388276, 0.21015354582378942, 0.12783136924788838, 0.16840702463542262, 0.09765837581888323, 0.11041673516193706, 0.18511299674789752, 0.09033403134033566, 0.18948973366810432, 0.15269829981750058, 0.17359227542915653], [0.018552312957904032, 0.019948557995620276, 0.043168407188908714, 0.03574806423256955, 0.033533020590942715, 0.0769383634530729, 0.04654383271812432, 0.06195541884329531, 0.019838480737000223, 0.013521140640331133, 0.03501042115291761, 0.04183759755124489, 0.024090881587096283, 0.054901292727839564, 0.018757607284632903, 0.0235779493326141, 0.06021155374905756, 0.030988721935559186, 0.07072797976434231, 0.0404764048665041, 0.033825528282191486, 0.04880970629352716, 0.04711293262399493, 0.03962402479843267, 0.042332720176707354, 0.03627817026309429, 0.027516143051006144, 0.05338104486825967, 0.04222171786691874, 0.026426407876574708, 0.013816228132664919, 0.0489622880254061, 0.07765611122933128, 0.032487662974745035, 0.0500974579594068, 0.05067993376043536, 0.07128769892358011, 0.07329411384078764, 0.012269057070596084, 0.03762056315017324, 0.0055045299063016095, 0.02975525525999406, 0.028986187253688133, 0.061615264313595916, 0.06794615363281581, 0.04317231423732254, 0.05090853822748027, 0.03914057735293623, 0.10913107108565108, 0.03688123467708788, 0.018682222317663894, 0.0499289186160651, 0.011370574788851364, 0.08407496276401705, 0.05546714825135085, 0.05058776572226517, 0.035118998794425885, 0.06529825499221202, 0.023724971181382577, 0.040454797356599764, 0.03050819520027407, 0.027455072436902313, 0.05407684805592703, 0.024828507429769924, 0.04675242696858702, 0.04420431894100001, 0.0221286641974603, 0.04114217357710004, 0.035552719472757274, 0.018345132139661623, 0.02586068258801055, 0.0757448674149571, 0.035556879330186114, 0.02346360496425581, 0.015138945009018627, 0.03111129025778463, 0.08005490872047602, 0.04650332964956761, 0.04258491249094087, 0.07370768640671047, 0.039371499235952095, 0.004718559606361293, 0.03407255333337573, 0.0656292969060521, 0.03180460557491789, 0.009867718082762534, 0.02965317978974312, 0.04415337409403536, 0.04562496004866497, 0.007203512303080531, 0.02349270289883979, 0.008548859416717484, 0.01660049712705997, 0.02961065616428612, 0.016269420739263296, 0.02315606279749303, 0.004856524380644964, 0.08785028235926744, 0.0234629231460032, 0.05062898125259146, 0.006891595295465161, 0.05517767809872186, 0.028131349958599578, 0.05400541801786712, 0.040798418434156526, 0.04481720460218288, 0.060041068542388186, 0.05088886125914512, 0.07064688935755722, 0.03455508913424227, 0.03473979293278629, 0.052141855515900164, 0.01590440474120119, 0.010553291123811035, 0.0499827362927458, 0.04251172811153435, 0.04078304304951622, 0.032933698516459234, 0.08328612968926469, 0.06388734703162505, 0.021923601612328522, 0.03774076234549284, 0.01729230516620221, 0.09441560990507565, 0.029447144272947506, 0.030237139886124965, 0.036006293319646394, 0.06175782561542527, 0.02377963538521961, 0.023324546599460226, 0.01762821939924071, 0.038132363509747295, 0.03036616058389266, 0.011331296503363598, 0.10337998009016437, 0.03230570560140956, 0.02079842529530006, 0.008546359097254614, 0.026279472212697712, 0.022955962546890783, 0.014496585072558976, 0.042808089225042256, 0.01677747301366781, 0.06324392893622, 0.03128298588337437, 0.016369791663882714, 0.05079999889036821, 0.046783779116888205, 0.07326227522665456, 0.04760109151022569, 0.05342078950977134, 0.023892012822832313, 0.01228623563468817, 0.06037812807687348, 0.024987307880374215, 0.03296907262636289, 0.06040661888677747, 0.022177500387413368, 0.06484958027759868, 0.0709986922541453, 0.04414804595252199, 0.02601214200108042, 0.027395154785124526, 0.0197695002650782, 0.02623510423056301, 0.1165041387561829, 0.03794209025199375, 0.03639263145986103, 0.034861711995495905, 0.020550770136798104, 0.03438435877943712, 0.014932610717932544, 0.019181112180494012, 0.009456786604958677, 0.024936567961929307, 0.006211203881614512, 0.016039389433459412, 0.04582214341949552, 0.023041161100169825, 0.04409113328062719, 0.06725736398009524, 0.03904106636201182, 0.07513178257091392, 0.0707367284884376, 0.0776938793639983, 0.05878731968902773, 0.05806301036969789, 0.03471452735304352, 0.008847204697949272, 0.04551599936319455, 0.04676798238388954, 0.030723034982539477, 0.06295627058153191, 0.012682790514982998, 0.05993233002241581, 0.07383398366190734, 0.03676935902706558, 0.045632199579549414, 0.04501267576650266, 0.03366356197324011, 0.04622623947779498, 0.01124323661168737, 0.010498363577250031, 0.019130956404091373, 0.028397132672609824, 0.031828946103492094, 0.06520110738253401, 0.011532666544700343, 0.032487919614199674, 0.024114000205431255, 0.05223509224672472, 0.007915564215621881, 0.06465560681517087, 0.024458368218714194, 0.02580684575913174, 0.013492996485212879, 0.03087583887991646, 0.01806794812211827, 0.010568621500785793, 0.09547193023946979, 0.0378337845716986, 0.018900540139105533, 0.09452562779188158, 0.0493336376553822, 0.039978968655510295, 0.025581522063622554, 0.029249985799974496, 0.06862755819794632, 0.05396632072065146, 0.060816077560546904, 0.03710108275915827, 0.08070691083107265, 0.03965737643621622, 0.040733699326313315, 0.05064428002843934, 0.021950514281108495, 0.02186483309243716, 0.027177756269192024, 0.07153622550709594, 0.03516361575513598, 0.03791963238449347, 0.05861179745425621, 0.024208453100835605, 0.0565479719080031, 0.049850892560977134, 0.03432757634248945, 0.024937586858868602, 0.08252957189876227, 0.13472089754237285, 0.01969275166160397, 0.04470000847152645, 0.009995818517411189, 0.021910855824488307, 0.03558484536986198, 0.016498961748795647, 0.05522539388508566, 0.03167310849793496, 0.04820178871253326, 0.0390015094120416, 0.01657280687903685, 0.031628142967219317, 0.05764024857912333, 0.04357712275739159, 0.028297468464100556, 0.019503912903488647, 0.045365742708165804, 0.042057062589353135, 0.03392296700528072, 0.02640888170008698, 0.021059201624725136, 0.0014701109959728896, 0.007344611334584414, 0.026092429930764823, 0.09325995861041932, 0.02260685627979617, 0.04048799194635884, 0.04267633359338488, 0.05387639732009942, 0.03644047365073235, 0.0409284541984239, 0.10956297613560192, 0.052614290447485064, 0.01276394795446146, 0.014808274647821824, 0.07699022760554668, 0.025897431825738282, 0.023761320138169874, 0.02640186433470057, 0.12587032205755674, 0.03622736714239563, 0.022559155815190846, 0.03188464069558728, 0.05183403755748465, 0.01982997333060109, 0.06750988954257581, 0.014925108801934027, 0.024785692690901702, 0.014826943252926633, 0.022108521830711155, 0.0516820457133074, 0.027302094254522558, 0.02877859274796661, 0.05330409899714494, 0.05216940403765729, 0.003958470150527935, 0.02725802313145851, 0.026850393492608305, 0.04393545655353416, 0.09833358273270631, 0.051357316363963394, 0.016324621204647328, 0.020376148055337613, 0.04191817467912071, 0.012075583480538861, 0.08464624219003224, 0.04224210729702346, 0.03627071239715142, 0.025507496902719144, 0.0328691364566405, 0.035799970519879175, 0.04290597994000681, 0.03322451698383497, 0.010517467894861776, 0.01441295221147518, 0.04635261717222391, 0.03302241915897016, 0.009601691178226424, 0.020554598661199696, 0.018196886465434107, 0.023464261884650877, 0.0853565052872704, 0.07212312546588721, 0.03470726866996096, 0.021620267183489857, 0.031494916446747324, 0.08931305830276783, 0.04355866003841643, 0.031047228070336486, 0.040693966176120505, 0.06105373335641719, 0.028538548672992377, 0.0687481097937111, 0.034644116211922905, 0.05851709749549628, 0.018302529990192384, 0.007214390272800361, 0.008198496765427051, 0.04891528087037225, 0.030719620145616994, 0.03227978501649153, 0.05728688286316972, 0.014454947236264426, 0.11798792083056704, 0.11225166895817365, 0.10579933938119682, 0.09831425433437671, 0.12911691841098571, 0.21542459846504275, 0.13167675524469347, 0.18952523418251546, 0.16812579375841927, 0.1679922493114587, 0.15939732502785423, 0.1490234373317611, 0.09418944542806956, 0.10231392277825264, 0.16142489929353038, 0.12481495933306795, 0.13590701615377782, 0.08052586127192744, 0.27668359358945205, 0.1335476185645788, 0.13802138818127496, 0.10829811134646017, 0.10969429126670284, 0.09953931319497286, 0.12164841150684703, 0.10465539391002349, 0.10591563152810259, 0.16745555875522478, 0.13188680123177268, 0.11802051787174518, 0.12321279369174473, 0.19882586334020863, 0.1461316852439796, 0.09883697144687177, 0.14219667462091293, 0.10304202040236804, 0.1759419283799587, 0.1611159053901511, 0.07746864951425984, 0.0554723116839605, 0.12096787262107096, 0.17356311812275843, 0.17229341931881445, 0.19408580156103258, 0.26489346979125855, 0.11210886250820853, 0.19866961204717237, 0.17783962009895235, 0.22584281200843476, 0.1168042230570028, 0.13550543286386998, 0.1654072235068006, 0.1305540687134189, 0.28140107109662027, 0.11171761374439924, 0.11729628899164739, 0.13786530542758205, 0.10978807575039326, 0.27514718893554907, 0.11343924313663475, 0.12930536071860022, 0.07731308770035544, 0.3026939946557245, 0.11254764702771941, 0.14895478053198707, 0.14484131738783854, 0.11162089514395884, 0.11753780587065606, 0.15388530709089773, 0.08179411216969452, 0.07298897335966749, 0.3058758029533971, 0.24288407016185024, 0.10411580754143578, 0.1323586807496125, 0.12606547529538795, 0.1953602347883486, 0.14851173656361719, 0.14929319221165874, 0.14015200127276684, 0.13309887490205227, 0.09655077355883776, 0.09324464451281295, 0.26798552322772246, 0.07854019967658867, 0.08736976136964175, 0.10856438052630234, 0.08814682733387717, 0.15509364225210684, 0.0666531274515775, 0.0953634751720294, 0.11924108745710504, 0.07343642999448123, 0.09122220303622947, 0.11102328527598612, 0.06866406994841753, 0.08038277136943034, 0.14249819150615123, 0.07056968301654824, 0.14992084804802172, 0.11236722566067212, 0.14349556137477198, 0.13214707194316772, 0.11628627867227602, 0.1971534321144704, 0.173527357138453, 0.140331219881773, 0.12860825135102197, 0.16531999673574202, 0.15466230410721996, 0.08789524405954346, 0.10961852517099151, 0.17622329715278842, 0.12293828906671656, 0.12245089626841008, 0.08202896408376195, 0.12633461730494616, 0.14992667031624626, 0.24685366199381892, 0.19096898816285596, 0.07201865405565308, 0.12206630480866279, 0.11321825741399681, 0.19112522413413371, 0.09959939747087418, 0.15537084350662847, 0.18342443171047396, 0.1591974986536849, 0.0512886289206724, 0.07616892772456331, 0.08885024160507227, 0.10171202281790395, 0.15571166070238238, 0.10192976032774295, 0.2260862287854956, 0.08885545100295737, 0.09503796441300262, 0.16287488922957452, 0.15180001576100627, 0.146582665883245, 0.1408653057390644, 0.12044205285248258, 0.1816352486850754, 0.09411879679969243, 0.22512336351698448, 0.11970400374623076, 0.10098485216017693, 0.1077583181341329, 0.12039952731180577, 0.15669507244902273, 0.12005034443591872, 0.09287680739596968, 0.07565842971446053, 0.11784467771048508, 0.18740340045863585, 0.12108583483965167, 0.09231351826700473, 0.14607620515650319, 0.2166025199356579, 0.23055115774754556, 0.11957308698085048, 0.16863357215639085, 0.0777220867213703, 0.0798353785648942, 0.12473870294108508, 0.22092127932175515, 0.0737439530090459, 0.1386092840543678, 0.12277407812014704, 0.08002312373249762, 0.15694634928818674, 0.1779546405399038, 0.10511736791100233, 0.06313144041585826, 0.2394490238399275, 0.07988720441297179], [0.0179462339879284, 0.02500641411320577, 0.026024642640784867, 0.050944693747066686, 0.029552929523971774, 0.06286912041926576, 0.04261262189116209, 0.046460578112953135, 0.12182376903271484, 0.03920561821770765, 0.030763511238018834, 0.02357569894933653, 0.011997791082267801, 0.025035879769993406, 0.02521246686697968, 0.02374060129025771, 0.07363478547983593, 0.04295851058897473, 0.05960051435977221, 0.06670718261551473, 0.08426492192572163, 0.02317692337167119, 0.05679437642796867, 0.034125899865982995, 0.026101850897013664, 0.033204943437369606, 0.06393232405365956, 0.05376215062795147, 0.1047356646027296, 0.06288524657007187, 0.050396963863843874, 0.007116627877563119, 0.06831648053541299, 0.06369477934053829, 0.0502096017402026, 0.05397394712593767, 0.0507561135436258, 0.04956205443088567, 0.01583126919989985, 0.03600809745670807, 0.03115974340377556, 0.005970668552758834, 0.039999400220450856, 0.04984200594105548, 0.012595888373682336, 0.03551816890737222, 0.037074668047529076, 0.08220469699271264, 0.01685706188812131, 0.09593514530288597, 0.03655436411199551, 0.006783323131516697, 0.054751602977874785, 0.049988190838766676, 0.024348066879376292, 0.06947377125822729, 0.06343925454383416, 0.06130620529274307, 0.03516677586782364, 0.0399062707419357, 0.020246012699640086, 0.03561996667075061, 0.012103237339385576, 0.021284201648086313, 0.017642491617270054, 0.044111564845567754, 0.05042133695115486, 0.021631869585103086, 0.016208256279388746, 0.01541328396753318, 0.04427184576108571, 0.05030556957447722, 0.040940033617399396, 0.11859259402920162, 0.02079893474376971, 0.06781266281200994, 0.0033632538285136467, 0.059374085582432255, 0.01481443590995285, 0.04013527740514086, 0.020130831380224517, 0.021030191790252444, 0.033974612822696086, 0.035313094830921585, 0.007093363702522532, 0.04723023600696076, 0.046159605150141066, 0.06810972872640818, 0.024252095214662053, 0.005252599498377212, 0.03719102148146879, 0.023784965441952792, 0.004971412192624544, 0.03260637595949154, 0.01790250568921047, 0.0394578718189751, 0.10268894579982567, 0.04779367835351056, 0.08833101785351193, 0.0608408107091823, 0.022541277238257953, 0.019804891611960147, 0.016294621201532505, 0.044082480317522446, 0.03373881095960256, 0.04355738067158288, 0.07403241575605447, 0.023895477455469872, 0.034577481884268985, 0.057843564483787746, 0.044961152523155176, 0.04287863443154962, 0.02207413980466945, 0.07420077123829434, 0.01513745113756628, 0.02102475065077024, 0.02616403425382751, 0.0562443636027315, 0.0898453898187126, 0.0927794146381559, 0.01843698416656304, 0.08252401010043199, 0.013788987961297315, 0.024645054269762292, 0.03312001109964425, 0.030517934093011484, 0.04916861082517332, 0.01665444695390761, 0.012983304782650404, 0.07955600928154685, 0.012058512168756176, 0.06525257316928718, 0.04368380050084764, 0.007713177192565655, 0.07319695090935116, 0.030456336793459715, 0.044060340376510736, 0.041173556368918195, 0.0365887614597957, 0.0864217505459824, 0.014053299786492944, 0.012449375015773602, 0.03070213035830567, 0.008723089835726687, 0.05816805251543561, 0.053446901616670435, 0.03356558698860388, 0.040550389807791486, 0.029552218977422006, 0.027131892500385165, 0.039091233629733324, 0.03774174676847555, 0.07925598626776088, 0.050764391123647654, 0.037660817240154555, 0.03849518275068652, 0.10691991150980035, 0.03355747794792537, 0.05642004671596712, 0.020514346486438188, 0.010458156410154077, 0.004780315869157353, 0.015585565650384995, 0.04964345893371971, 0.022197822784824718, 0.06349307222051487, 0.043712486663172324, 0.03300016047433019, 0.024846623493959347, 0.020675996784120798, 0.03853804920048964, 0.10131874392109533, 0.017411295857821262, 0.05953958738715418, 0.05527093398174452, 0.00594378269705621, 0.03405127141083922, 0.03131953593824179, 0.027072212335863904, 0.041134378632470485, 0.054662430343488534, 0.012271614846653275, 0.010125152353617934, 0.0188389141112566, 0.04288688902893374, 0.03618793276649329, 0.038577537202546676, 0.007377696278009324, 0.034154474945558656, 0.10717691102575873, 0.034656630258166024, 0.031085459688197703, 0.05238869287554295, 0.020353592511626984, 0.020590298358471166, 0.04155295758297847, 0.07693480114422499, 0.04123087889785248, 0.029729790497390978, 0.019345564444759683, 0.020717112723016934, 0.04215367393748414, 0.04723289816249763, 0.025119226305715503, 0.03807984052165862, 0.025187542196363214, 0.07973715077124297, 0.02057227997049209, 0.0921052955691853, 0.049917519227751804, 0.04586180379133552, 0.03091637833764957, 0.028765111515719085, 0.03141520882866556, 0.031130674197488738, 0.01767129077756357, 0.04053685303416945, 0.0610310763060566, 0.021820930508716453, 0.019970567701684854, 0.0036362775098232013, 0.043272809651229656, 0.051498169289721604, 0.024011346338797483, 0.037445477585518555, 0.04243259888983542, 0.019067373021595904, 0.03713342699132139, 0.013053361608106042, 0.019378670934407462, 0.029814531313135263, 0.0294495057389741, 0.027315449082262577, 0.0720896014583207, 0.027794610265822663, 0.01421108517059756, 0.03756224087649777, 0.06259563469117688, 0.014068537275306882, 0.06173377045460286, 0.03269601207707198, 0.04029459304987423, 0.02370241946811157, 0.020338088807259357, 0.04307649579019316, 0.014208045716757977, 0.0376096578885711, 0.03131504857822532, 0.08182998806718858, 0.036478172837486195, 0.01991164213376901, 0.03511596891668535, 0.0018464112297571717, 0.07291386609957104, 0.022874295658942674, 0.06298474223923779, 0.035835436560333736, 0.026845205162141113, 0.06743262191453288, 0.02571161145404462, 0.021427933149220004, 0.016601221080148415, 0.04301279940972886, 0.039404379729662216, 0.05626997009160058, 0.031495581028021635, 0.04698710651287148, 0.013080962798407963, 0.026191092479313095, 0.019313965233102925, 0.11501438119598936, 0.05498072455426859, 0.07033957318673212, 0.10016304666116353, 0.03071567479280695, 0.08141900487844983, 0.04224303426341184, 0.04731435246104675, 0.006402429003613971, 0.01511707319878042, 0.05240353965951551, 0.028972434060227488, 0.041537639654932484, 0.015531102544628085, 0.038513591843506986, 0.0430063987451215, 0.005953260162289465, 0.05851274228564674, 0.03175882990622232, 0.010637406620287128, 0.032399677776641427, 0.041551095989322474, 0.09772609033051038, 0.0483458515466942, 0.05584994706535532, 0.033580740207746144, 0.1036445255721769, 0.05963701461892455, 0.04813100984920898, 0.03778747072623622, 0.051853492360321746, 0.008482173378128679, 0.046934154515545216, 0.0052337551718547705, 0.014200519860511827, 0.02967508990437754, 0.03952980364462541, 0.03442301557609632, 0.0039030228611908013, 0.057174712269296574, 0.05788513624499883, 0.020848933472147873, 0.05027895951042733, 0.03182438213468319, 0.06551429178685912, 0.0499752554441652, 0.062324715357634335, 0.01724391522246503, 0.02718962488635894, 0.06633792823601155, 0.06656839812715208, 0.0633816332406094, 0.02951694445894851, 0.01750262502971436, 0.01550030581007201, 0.027412297917650114, 0.018365048510473103, 0.021107786920883005, 0.0510738063753853, 0.05467371481861319, 0.03145380050785119, 0.0061945223170633045, 0.033283884967527086, 0.10946608133493893, 0.012703529472703175, 0.04598680252750074, 0.04375681251047119, 0.018637513426402887, 0.030613204787275007, 0.03072452119311258, 0.03692697012616742, 0.031111441560149677, 0.03375135564936265, 0.05078589904212183, 0.042425114210815205, 0.03617403210110722, 0.0021647727126330738, 0.07530625143478956, 0.05966850849349172, 0.013363702868622158, 0.05762237191741025, 0.029844967986366926, 0.12164700956594561, 0.15036786035183938, 0.09236222613723048, 0.1214671780866, 0.1529665991303421, 0.18305485557404258, 0.10888281263290875, 0.11074140322424712, 0.14783166499147493, 0.20662663023798697, 0.08806475633454901, 0.1187170833168972, 0.15822150263815157, 0.24154401384294036, 0.08053882347960627, 0.13206482474361697, 0.16121978691268354, 0.12675689262968878, 0.12911454353842045, 0.21775779584723137, 0.23489530528745345, 0.15318116503617457, 0.09349014504902786, 0.09428414155638988, 0.09858453015406286, 0.16807817373304598, 0.14985841188219287, 0.13725096419934305, 0.17494765350655203, 0.1838780630139574, 0.17581817453667042, 0.08754554024386792, 0.2528655829448854, 0.21144466444609628, 0.17492663205390976, 0.10609348650060355, 0.15627632878961104, 0.19494146048541994, 0.12171817147323202, 0.2469948826417808, 0.1543892703710064, 0.15664843301619255, 0.1096620313042114, 0.2139106248655627, 0.12476422899072209, 0.1620164570669013, 0.14035950384793744, 0.09060944760999373, 0.1279770025622941, 0.13302021299398717, 0.15409895369122106, 0.09668889921158554, 0.08534668404008112, 0.10589215093322339, 0.11477007575693632, 0.12971843532737226, 0.17178052345350867, 0.1486606793778558, 0.13095145384150167, 0.12290285750021859, 0.15980722803261974, 0.1586093576324563, 0.09674758154658541, 0.11338040758405002, 0.12155270414246667, 0.10929290715965534, 0.14326236421062102, 0.16315647250702306, 0.10590919638953863, 0.10597015400567364, 0.18566724603935597, 0.10346250308136787, 0.13369096893697016, 0.25215877490418576, 0.1449866749105915, 0.22128648875701815, 0.0916049941893547, 0.13974980511251958, 0.12144721383529326, 0.19061451928029138, 0.15975488890563289, 0.06600447314520998, 0.21976050289888538, 0.15227284522787218, 0.18514282821166902, 0.18729823190839062, 0.1718751659556743, 0.16943980308790363, 0.2002294130262829, 0.21378749921437235, 0.10955281014884673, 0.12873188262024235, 0.13412314977857376, 0.17503327149296963, 0.2095110125599369, 0.2059024932884401, 0.20575304485617146, 0.17531249521961137, 0.17855157625050316, 0.15239115984689805, 0.09169570666046874, 0.1726390781902498, 0.11431983822295744, 0.1528174264897262, 0.12134050544832023, 0.12420309256882438, 0.15178748256256505, 0.1480283504051547, 0.1520713794255449, 0.12712932627407775, 0.09593370505758832, 0.13320992700755596, 0.1322146868633647, 0.11874148321728553, 0.13978453953900646, 0.09412736166268589, 0.16457551249092625, 0.25453343296483644, 0.13853834431257941, 0.17611572308646095, 0.1314184150748676, 0.18459265450796775, 0.13398741432014974, 0.18625095907238223, 0.1770674341147946, 0.14017262435968847, 0.19008936600819712, 0.06509822177430315, 0.2092941330685731, 0.11154629350189241, 0.10451519981988015, 0.14034310956635784, 0.1700603496283293, 0.13985373260032746, 0.17481433888596876, 0.08907806849287403, 0.12265562560529479, 0.11113919437892976, 0.13745658219821993, 0.20262398937296486, 0.23565410005469478, 0.12287527067406524, 0.1628223202762104, 0.21682162108200215, 0.1098728816836111, 0.13594764945728166, 0.09968836326152088, 0.16364070136220227, 0.10848033302012952, 0.12171804889916413, 0.11095194716847713, 0.09123177913528296, 0.15573689563860818, 0.11352516755822206, 0.1351783439637192, 0.07155843439602083, 0.1500536417288165, 0.19191332942535802, 0.13181348661741904, 0.1346868679167763, 0.08550466669182624, 0.07737221436635142, 0.1828098606558577, 0.11946006602938138, 0.07547020191146482, 0.11170293549977003, 0.1640560895565056, 0.1517466500762009, 0.1940424409845183, 0.1475439070453567, 0.10119975514469609, 0.1789820104116394, 0.12417686937917626, 0.1055454271995733, 0.1769348702603771, 0.11502920499732418], [0.08357394126153762, 0.0700744224952594, 0.02962513905649464, 0.02232978142978203, 0.010679255130760854, 0.0186405586259019, 0.015685971048961005, 0.019383924382348216, 0.03685238380585948, 0.013044888675663502, 0.08256552440504875, 0.007760338043989314, 0.05200020968914033, 0.009803520872317737, 0.03784359049712939, 0.05890554620794231, 0.028644213265168573, 0.059447626192723556, 0.040610328526987184, 0.043727517308246706, 0.001398592139594257, 0.022583283754366062, 0.043986711666108146, 0.038460107415073344, 0.021810781758939548, 0.019542908694054333, 0.03117397157174926, 0.04651413531973959, 0.042186473991962216, 0.047476437513626395, 0.023460209279531435, 0.11613997120049693, 0.045389322894475156, 0.050909633733211994, 0.059481874153378515, 0.02696775624738826, 0.024149345587037747, 0.03272061116032062, 0.054238783721361435, 0.00613350437150427, 0.014851699384199757, 0.015265002861739168, 0.005195308570569802, 0.06169745022611273, 0.020662802834844878, 0.026820362845976508, 0.02476712080439733, 0.011402159636359543, 0.02549433168174038, 0.01234239562519736, 0.09455070951052251, 0.03603176191268909, 0.02900665903824472, 0.08599901556848519, 0.0740112487467066, 0.040760416642672596, 0.036019653893045844, 0.018419634190297896, 0.028799545252695683, 0.03010607756403906, 0.021623153419744585, 0.010115993772483161, 0.05928891575745037, 0.029084821073939244, 0.016899493583027395, 0.03442193539212308, 0.023972568883290215, 0.07926173192719299, 0.008630209335786922, 0.0380880146798107, 0.05221739944611346, 0.024575221525024504, 0.041413491276363214, 0.028971853748624845, 0.03380806530795751, 0.06997372789849197, 0.05540434053287872, 0.0492136184907248, 0.017545139079072306, 0.03261430113906822, 0.08414800924759719, 0.010849499019734081, 0.09508533162936088, 0.016290821405428074, 0.03436845479412906, 0.047075601159444744, 0.054977951315982695, 0.029906645725150744, 0.04956911393110791, 0.0578452383859023, 0.0395323240738963, 0.017191170068878322, 0.07988099143990586, 0.060169583622125856, 0.040775079565543326, 0.03778231495450582, 0.029975549588280342, 0.04215378118979354, 0.008512227007398203, 0.029408322767384594, 0.05456577303008207, 0.014620412651809954, 0.010339344791587322, 0.028925932523223664, 0.08426590251826471, 0.10764149738655937, 0.039207050802126046, 0.01609319753404106, 0.02768935553068596, 0.12131710146223346, 0.019079936863554102, 0.013100248104291818, 0.018696253217997092, 0.01081760582183638, 0.01584134708654376, 0.014627965321133455, 0.042396979631796, 0.07471153737917062, 0.06259904761287956, 0.04319397537338157, 0.0785912134714665, 0.05619849791870483, 0.04598650375321027, 0.04742094593483114, 0.02865307498723269, 0.03188681447007243, 0.020827247438231306, 0.031026620305173343, 0.06466344389463625, 0.026875143878221996, 0.02409493993787516, 0.0175307308804364, 0.05745734508720137, 0.03768216428016463, 0.02621995101142074, 0.05379854746523404, 0.08856300459874254, 0.03048456330302983, 0.017622571416018952, 0.028668852568033244, 0.012844383356071288, 0.03268583842943753, 0.0304530770893419, 0.01592644317556293, 0.05069352416021209, 0.03642039065579734, 0.03172490561771537, 0.028068668644634948, 0.041139925109042276, 0.03673591162829149, 0.0064602432652346555, 0.08610938585573628, 0.04160966724157334, 0.08122241905620022, 0.05309890234662641, 0.05166789989978556, 0.02643149470039193, 0.04158980641213637, 0.027622315176432172, 0.01799427536166003, 0.0236665225031996, 0.03942960700500877, 0.030136299732651924, 0.030318105803622358, 0.034349593709433274, 0.019709467700111772, 0.02411103544516429, 0.05857597135247723, 0.06196081593272187, 0.04229173830319797, 0.07184018621281271, 0.03353346875237842, 0.049482752839403774, 0.056482459899158254, 0.02158613222080373, 0.03955672014384501, 0.05170772498052928, 0.013157263240446488, 0.04123072568026762, 0.029524961569076105, 0.0035755355953193844, 0.037567817996586525, 0.10896913542021668, 0.015465950597107652, 0.0069869138702239484, 0.12314865681072398, 0.08511394652868472, 0.02015809644944966, 0.06127469226597779, 0.08801623998630433, 0.04948337720106206, 0.04189498136721311, 0.03879696393625871, 0.041562575816867814, 0.021776010943276268, 0.04392272800267224, 0.056876466579494946, 0.025832808478885604, 0.047905630612325285, 0.013155882366962973, 0.02709973404454368, 0.058785477247569835, 0.04489760552983611, 0.028079081694745732, 0.035497028711101705, 0.07148403193681471, 0.04917833248093244, 0.020627009291802684, 0.027572345176351168, 0.03006436407656199, 0.010138759990372967, 0.02777135758210094, 0.040829835699931274, 0.044459724994075876, 0.08228081548886915, 0.02915123132087531, 0.024321452984886787, 0.019746021585418813, 0.057984172261410186, 0.07494932340998804, 0.04617110412988452, 0.0889297998360088, 0.010672035709684415, 0.028251715778042714, 0.023186721636222738, 0.025175087521934224, 0.061473453777932355, 0.047133969398395675, 0.04165236132159349, 0.045524004982003284, 0.013494519084962386, 0.057966494782557415, 0.06383680055038103, 0.002565531021607439, 0.024191792603702317, 0.03000884568468938, 0.016325009994268898, 0.027687924861487363, 0.052959290483305534, 0.032219459422894066, 0.010168695833624132, 0.028774990219502684, 0.07093981839716434, 0.04327040796558704, 0.02259262428138285, 0.04000018546057325, 0.06434278247217018, 0.02346407419310943, 0.04081382829275343, 0.00893337426767234, 0.0376029278061563, 0.1013378884583231, 0.03591123329956205, 0.08744296107080676, 0.046687581456236305, 0.023447204937016772, 0.0316108159735919, 0.11349136009812356, 0.017806512957078316, 0.07055312019562529, 0.011764918547874738, 0.04764464360872104, 0.025158861779697964, 0.026613492293343432, 0.02184757887716255, 0.03735439739220085, 0.06410359833089095, 0.03198432405629466, 0.0359032966286665, 0.035609268252888036, 0.03703138407980723, 0.021995983514634353, 0.0016232251589592068, 0.023275762120442047, 0.04565942251393872, 0.03667014681043164, 0.021856463581864393, 0.07618413456986028, 0.025575397190667933, 0.04281191200378441, 0.029874408745297024, 0.028991547953938285, 0.004560927918646485, 0.024342415065714912, 0.026736177443977327, 0.04486383254369421, 0.00396446215510819, 0.06520514466589497, 0.019660131637788108, 0.052526194166632435, 0.05061781935153469, 0.07608861106658175, 0.04186667824885057, 0.04821983391358968, 0.0646428514512316, 0.04218225284749943, 0.04174743283299669, 0.046377898073725166, 0.038131700843692794, 0.03816324834441466, 0.028312596785385283, 0.029658492609498002, 0.036127270094209143, 0.03360057805454539, 0.0625590731449906, 0.03726533967100325, 0.02779020334503824, 0.02602487246716215, 0.10416815432930186, 0.047853754968532634, 0.06829085489434582, 0.08063033268216156, 0.041885861090474555, 0.08928263695129464, 0.009353979520740048, 0.01868986021426897, 0.0530917777289306, 0.07094521165615128, 0.025261984875185356, 0.009224414900546114, 0.055547323183066426, 0.02540482005344764, 0.029144690845221765, 0.027106722681632927, 0.08014541434785051, 0.01922231813472125, 0.039587961209397164, 0.03347947870591476, 0.03737080316509932, 0.05530688265759138, 0.0186925855720596, 0.08262560102007083, 0.09623235677398982, 0.04010445385750744, 0.016660793992360274, 0.05290635763817737, 0.008096700917268473, 0.02563898248838321, 0.029091813541468114, 0.010922882582000908, 0.026062489299464132, 0.03391944683126865, 0.049196764556390625, 0.02192050278667481, 0.0423449162964619, 0.03781777333408114, 0.012341675502548536, 0.031041516884860974, 0.02670889896821351, 0.04416085877305558, 0.05498008870129144, 0.06878962409832785, 0.16536164127530592, 0.14340470334695232, 0.1854826954583968, 0.08899831107907719, 0.07959362419862902, 0.12768095554483513, 0.18068863980231747, 0.15235817210087854, 0.12045748186327758, 0.17974652019479584, 0.12855972734189805, 0.150175541639328, 0.15273432127170025, 0.13301678092008637, 0.11670140639668512, 0.16038992982958594, 0.13010439042362476, 0.17530134097943384, 0.1044059786645155, 0.21869769379977258, 0.1017451561206291, 0.11921906242928199, 0.16120276443900602, 0.16443594659288086, 0.15149594014210088, 0.13485963606546003, 0.12404487242982273, 0.18930780310784617, 0.15882822895242324, 0.14712306430503247, 0.0908334287364156, 0.15806503684049653, 0.1204496294620537, 0.27477094783417644, 0.15920998588685067, 0.14177261431130672, 0.17433374128755064, 0.1139587350189686, 0.149624555882427, 0.07238650649425483, 0.15413132856690115, 0.07034308953030456, 0.17118257650684926, 0.23239315487444404, 0.0798707794878752, 0.13029042721515702, 0.1002121682188684, 0.09173709839101761, 0.08319651272388236, 0.1455725942768397, 0.23490809895578893, 0.1439653877769747, 0.09289725428266872, 0.1597998276232712, 0.18052120362558674, 0.17843019727978016, 0.14693762506208113, 0.18352250628654035, 0.12372887648281553, 0.12648768167221738, 0.11070027196359251, 0.1745789507103543, 0.1942679772694265, 0.09815280896521385, 0.11071239913543386, 0.1471001582760965, 0.15668016437801624, 0.17240333761419022, 0.1014523956203653, 0.09007193733968082, 0.1334037778959159, 0.1104323327120754, 0.1441900660434077, 0.07575660388195708, 0.13574003962980163, 0.20663052196464232, 0.2008650361770584, 0.202923545073117, 0.15117759996604535, 0.10202918321855607, 0.12263771446962511, 0.20594706428387474, 0.16418676883462938, 0.118885530729688, 0.09165884250955236, 0.2520380394473191, 0.10559878522349943, 0.1422579310113384, 0.17681460977802355, 0.1635944449733342, 0.18551661783168394, 0.10091230363374758, 0.13922143427114334, 0.0820849574501476, 0.12085575565335252, 0.13416295570711936, 0.13643187831246084, 0.1127293554224795, 0.10525360898745638, 0.1941351989103902, 0.13612499881175258, 0.1646288168886977, 0.16878329638031223, 0.16815367935886308, 0.12802583300658774, 0.14028637309468564, 0.13901466714038005, 0.10299702805857505, 0.13413102516243536, 0.3468425998524312, 0.0825638696551323, 0.12777463277621617, 0.07861382072611202, 0.08809465674623367, 0.092243229699952, 0.11783193000742506, 0.13412687296588577, 0.12229901167654222, 0.16299090558482757, 0.23363510597377057, 0.10948951596454268, 0.12943562630924488, 0.11237854844019299, 0.1170542281902125, 0.09885649902806168, 0.19774122073525385, 0.1798979604556676, 0.1868872563805311, 0.10457420391180824, 0.12605913974825414, 0.14243269098862527, 0.11378985093606096, 0.13489136742728372, 0.10358605774179583, 0.17529960962072497, 0.25880080317297294, 0.1503893567789947, 0.16096091048131067, 0.11377716452003488, 0.1737158300895845, 0.11652535173080622, 0.12820917316862654, 0.14526496400996564, 0.12478025555009804, 0.166546059171519, 0.11062755489781981, 0.19323225703931626, 0.06789789009358614, 0.1532162518631066, 0.1301575722473283, 0.15048393799412638, 0.18146045806427158, 0.1433183805596444, 0.15441868814729875, 0.14836849344353523, 0.17789490100356842, 0.20114606787120143, 0.10695292989933684, 0.15214875430589722, 0.12111293136953347, 0.10830665322681589, 0.16791646789398887, 0.16452646754201383, 0.10731283034528456, 0.12606048040212164, 0.09631407537287283, 0.12214069194611042, 0.12467325604971378, 0.13788894690092535, 0.08685091300116432, 0.1547424215823412, 0.09668560503351112, 0.1132726803001377, 0.12663094777493708, 0.1441515011772994, 0.12033316111492535], [0.05936449799205988, 0.006165017398269547, 0.0850171359976934, 0.12258568177780799, 0.1042256109236229, 0.060324781544266216, 0.06853983346973697, 0.03947341574295875, 0.03316196207437785, 0.051457574290613976, 0.056943303920448794, 0.009597741037366853, 0.011751421036258822, 0.07176472655227108, 0.04892661131077236, 0.03166334853777963, 0.08910377074273364, 0.029148002260274468, 0.009839193756511856, 0.02401117779945414, 0.06294778232733089, 0.01147101178855425, 0.03549646946691698, 0.019374526398737105, 0.03932710061030042, 0.010283070845499395, 0.1414079717811077, 0.044794329216763865, 0.01779532998860363, 0.0638583429428118, 0.0235781638372329, 0.06199944208586409, 0.035346752903874845, 0.023915146762925773, 0.03853072156949389, 0.060978469048296256, 0.024230269369699305, 0.026266852829365, 0.034378969350889806, 0.053268391638994224, 0.02419688325795916, 0.02088831422189551, 0.01373534169678967, 0.05595305866952385, 0.08120467645987388, 0.05305833799103576, 0.047997262388948476, 0.04693444562895645, 0.03010014995872494, 0.07451430038218537, 0.03639920449425136, 0.031007841574929418, 0.06646918208007851, 0.03823903742276373, 0.10650681391839059, 0.012442392124343785, 0.039782524559526675, 0.057443218425877636, 0.03954815528085155, 0.03025529808515022, 0.055240631373899604, 0.02414777319157316, 0.03945296502582008, 0.03244373549316679, 0.018539641863636432, 0.04839847795665265, 0.007085131608971185, 0.10212439262578565, 0.05439359476910003, 0.03678415601532306, 0.05215433508818669, 0.048264914357493964, 0.02490672117639934, 0.06727667705666635, 0.043907505835616784, 0.030675524124695413, 0.061245071476385485, 0.03254397426761928, 0.041437745620045936, 0.027565080747609178, 0.04751930013298989, 0.030404058953506813, 0.047490537361872774, 0.0440397517635457, 0.04034689387246486, 0.07098913913772953, 0.006716582509163287, 0.03852057090449718, 0.03780928507988011, 0.04685173877665112, 0.006991424691683103, 0.08675758817022847, 0.07003703740455451, 0.03565287397753808, 0.027834632614206885, 0.037121341954315865, 0.035859706225774945, 0.03558019521616159, 0.039492230862379074, 0.07754031703957627, 0.04151695528097692, 0.04035560046172431, 0.028356108664264603, 0.030418777417752053, 0.031679271675285794, 0.060764730517422004, 0.07737560813585598, 0.027654232314577507, 0.00710651791098738, 0.046326401643455035, 0.04822882395538111, 0.035815384208915696, 0.062222231945563714, 0.06696605904688759, 0.05435058659303093, 0.008351048811398929, 0.04715854166856697, 0.022294889955270677, 0.0512745788681411, 0.0065150391404336745, 0.02713658670414119, 0.028371273374725735, 0.04224774570414617, 0.07960015892862313, 0.029666833391773607, 0.06309824199565957, 0.045849285914652774, 0.015361009958019901, 0.024576998849008835, 0.09625728527504591, 0.044881391278918714, 0.014967391109694878, 0.03207120991822693, 0.016815312011467836, 0.012590092918535155, 0.017129367840806806, 0.030855256012610854, 0.03336280734548646, 0.04596586151409053, 0.028254061922310825, 0.049601190032497536, 0.020297158644684864, 0.055038441618483876, 0.04982166630666583, 0.06687687109074285, 0.035834547898341576, 0.030710683729980263, 0.027859762213343096, 0.09757135589156421, 0.03177491200697278, 0.07191632769160694, 0.038500993527592196, 0.07732228075544681, 0.05881645784322774, 0.055064224307575536, 0.01886171863354262, 0.0339836718124007, 0.06336528109386563, 0.018833564902325312, 0.03415073643648817, 0.034827981144189835, 0.09258266027656295, 0.08588777960187967, 0.02216682686740833, 0.046845150420502316, 0.09517646544883329, 0.017267732896030914, 0.10256590441830697, 0.03968895458045506, 0.003658035843287625, 0.03752095256781867, 0.013377864003902482, 0.02536848641841883, 0.012630524166348963, 0.057111885398626334, 0.10239734209232754, 0.032440728598063996, 0.007199713464586005, 0.027683278538226604, 0.07982161196489489, 0.03549057825077926, 0.010440846653504959, 0.06874972623923133, 0.028692834950502843, 0.0722735315080612, 0.05316736379397973, 0.021717412877948056, 0.015735527361562897, 0.008124940833377262, 0.047777962059743946, 0.008923136460174237, 0.03839469499765866, 0.04267623783239434, 0.043297378090961326, 0.006151491637161423, 0.03057672751076039, 0.0473913902627124, 0.09663984660179385, 0.06138942542395765, 0.04240034658822321, 0.03516972913677174, 0.05144943843685812, 0.022952695181893728, 0.03223042597153014, 0.04005716324994161, 0.009902918865273317, 0.0020744691409486076, 0.10472936735999201, 0.037832635439812176, 0.07399470124754214, 0.01721995773785297, 0.051282756856732795, 0.024984601674781694, 0.07403161136373397, 0.04522085632948626, 0.02782671701072926, 0.0108111840898111, 0.029657872078279336, 0.05211341067127163, 0.029271374974820404, 0.0732131383471912, 0.03150264244346369, 0.0608818845132426, 0.04263365866556283, 0.01676768240999551, 0.05113688988551017, 0.05124688095923874, 0.05749476465186285, 0.0159774454791219, 0.019803826749745398, 0.047070828431676474, 0.010141109007470792, 0.020752425545886643, 0.03777265458578064, 0.012062687347943505, 0.047435976579905524, 0.022187346532460184, 0.03210164467623878, 0.00996749816207035, 0.018652607273731022, 0.015710074090278678, 0.014950755510419128, 0.02419584520882176, 0.13329104039697878, 0.019834395573144, 0.042885778201443535, 0.01576456209389313, 0.028917687501938596, 0.024296512992511836, 0.047818840511383555, 0.00259233141062601, 0.023267871414821957, 0.06224036907717105, 0.0343073784343658, 0.03829955070790264, 0.035877900813976606, 0.020459814432768092, 0.01457713442974754, 0.042828635703171455, 0.04984842192742133, 0.09887482385121046, 0.03681185392422542, 0.012431546234555784, 0.057839347169764584, 0.056204147817146395, 0.04379345066544991, 0.0259556372710053, 0.03279117934946572, 0.05910815348127677, 0.03365878924547184, 0.08918848474540057, 0.030349019366586884, 0.040911075493861596, 0.08319699535927466, 0.04742291478079654, 0.04402151121006858, 0.05976045053572424, 0.022459918700699365, 0.06377793818471894, 0.02360771376369221, 0.04468214713157185, 0.018179482863014264, 0.02547211704715606, 0.023020315847750154, 0.0650094245229998, 0.05679999185245364, 0.01944028547093753, 0.020312263983331864, 0.06312796237668203, 0.06331700989375673, 0.03897186180937194, 0.011517884878201351, 0.05748895004451756, 0.053494265002589074, 0.05720534812538855, 0.026396879017533317, 0.021699718162116986, 0.03189710494611533, 0.11901467017108396, 0.06755521130417624, 0.030667372949181065, 0.04352591744053268, 0.045950834699455774, 0.0371501085558726, 0.015868434040326507, 0.011732139560814587, 0.034180272956408804, 0.038944117935194124, 0.0038950332823479853, 0.020193093261050604, 0.02702071782081358, 0.02457294049822996, 0.02048148706014599, 0.03996902100381352, 0.02497113001863322, 0.035768331088606393, 0.03853472437889826, 0.03722701995303074, 0.0371974834331101, 0.08448960785303386, 0.05234004246191152, 0.05042822408159414, 0.042161342477606195, 0.08300273844431486, 0.07493155017014473, 0.08278700808483748, 0.05288375421397148, 0.013621764373965563, 0.08863602043880571, 0.020153771883117098, 0.011026755486044192, 0.05173965552521329, 0.01141542636398827, 0.041553639401231086, 0.06773622255892524, 0.018858322948818246, 0.027048944330383694, 0.04454121759702121, 0.06561088781323164, 0.04075165642725845, 0.05120670347804985, 0.05800171184443659, 0.01982686301362851, 0.09819625381139979, 0.06710588541482726, 0.044046562285192555, 0.025384926665273887, 0.04967888283933844, 0.027332670738800403, 0.017915946701841972, 0.05764715869220034, 0.17694859855598022, 0.14778948419036406, 0.11280364296849697, 0.20788080810058504, 0.232394794302602, 0.3347026496644943, 0.12921601954487064, 0.1671731634245765, 0.13551519282402533, 0.17345629482259675, 0.12849031977595823, 0.17062330167860756, 0.12677293451082322, 0.12804564404030963, 0.1452368792266615, 0.1482411696305198, 0.1602323149000445, 0.15395831527008166, 0.13315046326287333, 0.07126026531501163, 0.10583374438987625, 0.16974432303780512, 0.15107741098730795, 0.11940054865854403, 0.14481180768099525, 0.13292978397540509, 0.12769906586336513, 0.2523756237520326, 0.1431744173169136, 0.15302171149561483, 0.10689752642065288, 0.1334359382669772, 0.23774840057857577, 0.10500259261818663, 0.28510467720127874, 0.11302367874210882, 0.17230716293617604, 0.14530553602643553, 0.1604638726360375, 0.14258909549924637, 0.12469440773730317, 0.1591860226565792, 0.09373993567761876, 0.14962204311403537, 0.15443941848652978, 0.15921882654149688, 0.1892010104512015, 0.12212723944216006, 0.24599204290538068, 0.09188028022406564, 0.23503041255377957, 0.19010746100496864, 0.10502037351890918, 0.11281665114145126, 0.09990788575622345, 0.16640523688927775, 0.1076008411004178, 0.16123029763900465, 0.12312701482686306, 0.16907788783071503, 0.19136605153401054, 0.12233753057737505, 0.15664993454852413, 0.11900987446067796, 0.08899153120094731, 0.15446256966360156, 0.16734305108266492, 0.15596733488623174, 0.2669676988115234, 0.13282493718208807, 0.18692024412655062, 0.16885844960568414, 0.14532985165715218, 0.07978844801865279, 0.18631161791422676, 0.10128004882003992, 0.09751396058427711, 0.23803602062886764, 0.18961304318039648, 0.14891515846454328, 0.18775560172094455, 0.1696194353843889, 0.15592955142980622, 0.12676924962790745, 0.10694417351436232, 0.21640496118174446, 0.11237133955282551, 0.10393260527522334, 0.13027620862328237, 0.1404855865985155, 0.2102861403217239, 0.07621861618733214, 0.18691552502493705, 0.16567219799805075, 0.08698392884745713, 0.12162169802092737, 0.11192464134505681, 0.10378278912075105, 0.1796556315234592, 0.15878523609811263, 0.18565037678326332, 0.14764204290845703, 0.09255557140756039, 0.11998874330592733, 0.09357095966416021, 0.09589533937434036, 0.09757998970247085, 0.18045256214757122, 0.1583257978481631, 0.12337225489318372, 0.1254198240536836, 0.18718410012943132, 0.08787931709159767, 0.18450692926924075, 0.15882707982053682, 0.14523939199505315, 0.091233610085422, 0.1264617879003767, 0.1334502028241273, 0.18525965662012178, 0.08816407197305272, 0.10065719635496218, 0.13589831339495798, 0.16721845454265996, 0.15742553728482417, 0.15545745740734762, 0.1280948575285654, 0.10410189538473084, 0.16981463458749557, 0.10412735248645467, 0.15272209450842875, 0.09917105472977124, 0.11735249686265185, 0.15822890304750012, 0.16340902105214136, 0.21240866352473536, 0.10755142076842247, 0.15297174724119325, 0.0998876916785394, 0.13278493207068215, 0.10090681844420972, 0.14136522407493285, 0.1211091239125498, 0.12151050035871806, 0.12768598108161844, 0.12910610124949487, 0.13005690829407784, 0.07768771235620783, 0.11421309153158819, 0.26018469504291014, 0.12143041352711378, 0.2873908061413996, 0.12079011724000016, 0.11822144741252547, 0.08376979163937992, 0.16365721821784973, 0.1209728368708203, 0.09478398328346592, 0.14447367179297632, 0.19030575520328938, 0.1781661114505222, 0.13121745489057035, 0.17225761236923356, 0.18536531546663854, 0.11296907965574535, 0.1261154931759642, 0.10242295241163624, 0.14150930989173152, 0.26107605366456893, 0.1410580074955379, 0.10090554673825541, 0.10634122401355736, 0.17148839880622205, 0.11522795884839951, 0.17332941534057741, 0.13147774092372388, 0.33841600040754966], [0.07377879468784218, 0.039987077696188804, 0.024574110697534297, 0.03257053453595408, 0.008669619771441626, 0.016353408873621977, 0.05589412735594858, 0.01800316006636187, 0.02045702204228409, 0.043609708307250854, 0.08417536624737325, 0.04904910110898557, 0.012319569077883518, 0.021364213786117976, 0.0480957736351317, 0.031120580989086342, 0.035884018026051984, 0.00870705082742197, 0.08291354282729088, 0.040872326766651486, 0.019059139491629698, 0.04416105029503665, 0.047395013858594244, 0.04113467740676096, 0.08021625449820872, 0.04256085733011846, 0.03849915491657392, 0.04959294692643228, 0.08069393330163534, 0.031086091710735234, 0.029739590677162333, 0.06858792846962329, 0.032732500844905456, 0.008452925098789556, 0.050337285614542426, 0.04869468585257569, 0.046834229837141694, 0.026839612720293865, 0.03582394907190915, 0.03883619912930074, 0.011562305528880849, 0.007685753638901178, 0.03714359680851621, 0.01641301817501024, 0.06072705814374551, 0.012283462396402274, 0.045665876804700786, 0.05449700131711941, 0.08342274614880163, 0.0437599458100815, 0.04300589695753109, 0.03278336142219844, 0.05407447701380138, 0.026771687534487536, 0.028702502980107264, 0.051781074068839514, 0.020652320836820913, 0.056699557725580475, 0.03774443573708977, 0.0629257343168701, 0.02933408118664257, 0.0812305242664391, 0.04440719051466835, 0.04734277049259794, 0.0548018085499925, 0.08846486107476297, 0.0341542681018191, 0.03849523637684123, 0.09150667446515254, 0.06685023421361562, 0.057684796591920245, 0.026320159142356248, 0.022722646639111544, 0.0188511734332649, 0.05562937119975687, 0.0401996249603408, 0.04732208228820274, 0.027929979917262832, 0.05317957906593239, 0.06847949638482063, 0.03268314179994407, 0.012826826536066592, 0.044342245410887465, 0.02017361164513615, 0.017032668392564503, 0.03569865539189308, 0.03979911419352697, 0.011509237660756035, 0.026532196958038597, 0.036844749739694024, 0.060169043530139237, 0.03760885732669023, 0.04093535665062167, 0.06988869213889684, 0.023475992605991425, 0.024019539649147662, 0.01889078400938982, 0.07670622349025742, 0.012626591262467688, 0.06737832160245988, 0.035712690122665904, 0.09965877694588515, 0.01736862476043884, 0.05660597242475037, 0.014475684278764793, 0.01720602259851031, 0.08550264421970614, 0.030632083108949087, 0.05793669013186328, 0.020894739784360416, 0.029809080597554004, 0.016612992021104982, 0.02706288138494617, 0.04884329924900686, 0.03917737255593942, 0.09572472393272385, 0.02126276267752532, 0.04505121381953359, 0.025971979841650016, 0.10232316179861946, 0.02485591805570068, 0.030315474291602452, 0.04698400768721777, 0.04515862317695733, 0.017405025428161025, 0.04097397131244502, 0.06164286263106812, 0.02663285325040981, 0.010953219663802414, 0.07492975752440191, 0.015957284917784555, 0.01762773293340879, 0.08515595112957301, 0.11102978170158402, 0.03276823501613352, 0.023816635516742547, 0.044361336321960536, 0.02652474675297497, 0.04040713519639066, 0.07697863669525232, 0.06744820414291275, 0.07235944060789001, 0.01771666041965927, 0.0396842010048849, 0.023740474885750203, 0.012676817902003326, 0.04454875590219613, 0.09394587543342384, 0.040742003719412515, 0.020814199045660998, 0.055193333105454524, 0.04241589817308611, 0.0508296694756756, 0.09463962933589375, 0.06100978289220122, 0.009172500952357247, 0.06397628217875477, 0.09477652924796266, 0.07692612902892214, 0.030347552308211886, 0.06680465964300018, 0.02698941163778786, 0.03619764293093355, 0.02032421687017045, 0.018992424724743735, 0.05536896642297507, 0.09193782874893758, 0.06064386865604789, 0.0919951551083115, 0.045613081855398994, 0.02380918722689873, 0.06507199092377579, 0.03126295076893463, 0.02397425236150382, 0.0359330591445248, 0.06029349834387822, 0.06094898998496994, 0.02175397633935415, 0.016793647044969183, 0.014482820387779465, 0.05187314634601917, 0.010159168572675799, 0.043122361474219835, 0.05058136888809743, 0.01519071531572169, 0.03704464506177652, 0.02902621917817141, 0.06631790269767085, 0.07315492332582513, 0.037301426242676475, 0.034161243332369674, 0.007253233324586144, 0.05042960303985784, 0.025118121223884727, 0.03242010934158199, 0.11892368190831716, 0.0506944932614363, 0.01896583572811177, 0.034358250502977646, 0.05864976860222317, 0.016071115049623674, 0.0259443259828033, 0.010015623805473649, 0.00559264725457216, 0.03762760732863699, 0.09642016322862718, 0.02311125623002168, 0.02277703888173546, 0.03451756231727139, 0.006677974071804315, 0.06584975402802229, 0.026630055114266374, 0.021388380029689402, 0.04112538092979982, 0.06865609497312578, 0.02275396048301651, 0.03848040874506678, 0.033164570603760025, 0.02829510316763434, 0.016363163088117878, 0.027096336444599495, 0.033325713368192796, 0.040487811915696635, 0.0334393969857164, 0.04269508359533164, 0.06102103289336928, 0.01859644536800202, 0.0698785567956586, 0.05280572049800427, 0.026504117920393908, 0.04251406467970341, 0.006298509655490277, 0.011163434190224978, 0.04711053093835231, 0.06970964973011325, 0.014727857440800197, 0.05116469887716155, 0.026748544018295024, 0.03867237505713298, 0.035871798923659715, 0.011149489474783262, 0.026170005909197276, 0.03514311524228223, 0.021597705894119797, 0.046206853622871066, 0.06465662571211016, 0.029192092535536618, 0.009389034746545217, 0.04810297103118032, 0.04432509270226283, 0.0402587746089745, 0.027614999036755294, 0.05634831407317712, 0.03964719895814215, 0.02109382113802337, 0.01896076039561341, 0.0904721340104457, 0.021321196033949816, 0.07202197121636522, 0.024556722416872942, 0.00364874535138839, 0.04581316103858333, 0.05210475004728764, 0.055381794565267144, 0.040599484552419, 0.0944724612899365, 0.010910533244661506, 0.02944499348110009, 0.06907850819369478, 0.04607716642860924, 0.04604072362605122, 0.013017270248383285, 0.015229265817681388, 0.03263016681998007, 0.06297669831603285, 0.046895478566687916, 0.03622635590633558, 0.05442870457866981, 0.02639104334277011, 0.025315461642739755, 0.029796330979274168, 0.028398768270328164, 0.0508462246357193, 0.03020829093011637, 0.015174866871788137, 0.01380742482480503, 0.041260469043927814, 0.027673773302306092, 0.10223777363857917, 0.022836023821465434, 0.027583962899722883, 0.05673833326586793, 0.032656696444797906, 0.06627440422533021, 0.01379042054571572, 0.05800626240670682, 0.008716636502574529, 0.06781640132108042, 0.044632857034523646, 0.06462078811901231, 0.010930732110395067, 0.02724882050026809, 0.011055233847019414, 0.041575009423878886, 0.017389435538901918, 0.02703363980887638, 0.04138161052739428, 0.05182187974212631, 0.04209693363537231, 0.037908091269914186, 0.047977765451275536, 0.019510681290299665, 0.05492080498727099, 0.04564220851828014, 0.03114474914787758, 0.06927340862251098, 0.011781940063942346, 0.04268740739433035, 0.0595304096538213, 0.027409107161445484, 0.03699374618008733, 0.005348588400069745, 0.06722815304754243, 0.035483177841430714, 0.05673547575791037, 0.04216650591021584, 0.03913974614753839, 0.06142519789958193, 0.08707396716119782, 0.07566153237055387, 0.07217324293789364, 0.05190159885152694, 0.039177782412978916, 0.06955541324831786, 0.04596151013468062, 0.0024890057806436334, 0.04471926409150324, 0.02374453323652908, 0.05993346000210412, 0.03378248180172617, 0.03333544651527078, 0.026786187663674358, 0.046921939243592566, 0.025392509020504453, 0.06185241449143618, 0.0375308197802834, 0.06683035423198054, 0.1338079505630078, 0.030499530745850458, 0.02172688172469216, 0.04770865791567391, 0.019642038556236415, 0.17686953828219446, 0.11821509654363317, 0.127876223695855, 0.1359149068593979, 0.15589999575768748, 0.088569424415548, 0.13454060641027268, 0.1405626856872151, 0.08955063748984568, 0.129064962327961, 0.1266198931261897, 0.15080505140846776, 0.17878966105561103, 0.1369550244341935, 0.12384939743506333, 0.06909001483431748, 0.15811657923604214, 0.1318099166476919, 0.21080357142754141, 0.2261860193985124, 0.21380133476228486, 0.1115994293603205, 0.13515307838397642, 0.12169350344207018, 0.2222676635269196, 0.08414944949289484, 0.10673026644414473, 0.07325917257056122, 0.16022030264139175, 0.1317189820110798, 0.08796668941936187, 0.20031876952177097, 0.23983304839461084, 0.08857281818505257, 0.20956195740690156, 0.08982445263574201, 0.13789443209046318, 0.12293954545091237, 0.1494001074423713, 0.1346403357362555, 0.10196181344649485, 0.08573155895236038, 0.14942630764938172, 0.08617277963147049, 0.14642046974791637, 0.12436214008278425, 0.21989519647773237, 0.15999559373144182, 0.14632945850251183, 0.10941437806092924, 0.16205482275014924, 0.11999671828121909, 0.12091935627282628, 0.0761783582669112, 0.2371061277846175, 0.115529008420004, 0.09979899401866621, 0.1709542669836552, 0.2051489845278763, 0.14676311023293004, 0.1155994502046416, 0.13954063246567405, 0.10118504625654991, 0.12153979556094255, 0.1572861552478806, 0.14128846206491993, 0.21464321942579365, 0.15562510808869717, 0.1936636258277201, 0.16148316794105116, 0.14386142964564985, 0.0976127859265093, 0.14889841178251853, 0.08233973531112557, 0.14277196068677211, 0.16093858667919714, 0.19973425975730344, 0.1659159671755568, 0.1412643302953051, 0.17910646905581798, 0.18968542316748252, 0.06642386031847808, 0.12013106712050016, 0.17398664217081763, 0.09179614844822115, 0.08746664084854626, 0.14089325262654212, 0.12799390246190373, 0.14850317170062374, 0.13764096423983574, 0.08491190616041423, 0.11905316608927904, 0.14187683291252584, 0.21569197847237512, 0.18864420242607596, 0.11933560738520277, 0.08243517454473243, 0.17966145379168375, 0.10590542723695118, 0.23966224143101325, 0.16648624302639117, 0.20021743141114715, 0.15918783062408048, 0.11036320859866758, 0.12587566169038897, 0.15434492920194903, 0.253426052870289, 0.08836945248467308, 0.1615023048173997, 0.14730635850179583, 0.21718819415377033, 0.11717318632309476, 0.1491418438813379, 0.11167999882731708, 0.09372751739236618, 0.214607167328077, 0.24605146068478786, 0.13655863522041228, 0.11802233350012573, 0.16914896546832978, 0.13478475863174086, 0.15573796816170216, 0.11848352609142182, 0.14390741024286519, 0.08577911002982049, 0.10836401022970678, 0.13345293009713774, 0.1211451683493872, 0.19973628222942355, 0.14513163406762386, 0.14647784973344496, 0.09608866932291178, 0.1686847161862158, 0.21161530287035052, 0.22354470145317817, 0.0990394484852591, 0.1606410228076481, 0.21507950649867136, 0.14286180747853172, 0.21353404668550338, 0.12822733711331122, 0.17702726046404532, 0.15051528631198793, 0.12028990012984123, 0.16564474140684451, 0.09393753273592842, 0.1923623488795373, 0.16093452641319844, 0.13756522878764138, 0.14491340626151333, 0.23731671003324373, 0.10969917890765976, 0.1999815376175027, 0.2399819299218155, 0.11949889136538391, 0.26183733055668496, 0.15228019967194528, 0.24836956613486816, 0.1509601688913761, 0.13497081074503162, 0.11837308685625754, 0.07380668028828598, 0.2887397950455066, 0.08287723025967998, 0.10330494943886034, 0.08101404314079592, 0.13310348675135644, 0.12979691337433555, 0.11797618436356706, 0.1467210979711625, 0.10830353524896408, 0.2392900912391563, 0.1314469441891678, 0.08781426856594701, 0.23989372255821384, 0.13189758774974655], [0.044057080672392925, 0.057663491686746005, 0.03334170162317253, 0.03450884423669308, 0.05388578189717186, 0.08255550397499915, 0.024338567389115214, 0.02677297264698052, 0.04848041489059406, 0.02865690159641447, 0.035882271345584624, 0.06855191467630287, 0.03529627537054401, 0.05649953599899046, 0.04388680613990273, 0.01071648796149079, 0.016508516780431234, 0.060692419478249174, 0.019633569454233495, 0.04681362973285779, 0.06294674810863311, 0.011214376164359913, 0.03863440007872639, 0.06164220762589286, 0.03140335744847694, 0.049157916237750364, 0.044888979379808715, 0.0405758967052304, 0.06450644949631346, 0.03704246554163195, 0.03915987127730924, 0.020368213299661875, 0.019746435272897926, 0.07983972994430412, 0.03289984892152491, 0.011435166534577167, 0.02868120956625189, 0.043777305362445694, 0.039369890451311104, 0.05244252587398214, 0.007177611827970513, 0.016826326440599178, 0.017357932088235696, 0.003395666050980048, 0.08606940372696809, 0.033826095187255455, 0.09619027556430909, 0.01850085100159049, 0.05634251861802994, 0.03158982324924681, 0.05507173579967311, 0.04242997886913438, 0.03290428840104611, 0.047321683922482115, 0.031985275920540575, 0.04278332543288989, 0.05087295344339744, 0.052427464585390784, 0.06839821445605448, 0.057449665055760456, 0.0505150180129755, 0.08073362431699231, 0.027672419241899927, 0.046513143235877644, 0.04018752077113717, 0.03508571993499514, 0.021386506944714535, 0.04806064467336382, 0.0721683859404537, 0.025756937046084675, 0.0787969234008943, 0.0499183236200723, 0.07271010203347092, 0.040050597876430526, 0.052432298600192995, 0.0548803057491539, 0.013372062803095868, 0.047808743472541534, 0.033186679901254755, 0.05313157982703659, 0.04019798936262246, 0.025520133523030147, 0.05154481638343104, 0.059245807989951105, 0.02015621570359555, 0.022308263935208805, 0.09458893729794411, 0.02719514646507319, 0.03128468468334646, 0.0021481179611592166, 0.024468315870410973, 0.020336150604810928, 0.04819461429912237, 0.035846406939409436, 0.0407502161819608, 0.028951500707696524, 0.013396944381266594, 0.04333112426402588, 0.0530380136784046, 0.062571958743877, 0.07881935445531722, 0.07004835252319613, 0.032324095542031916, 0.08045769476842496, 0.04351716488599778, 0.019286658029041944, 0.030034015503441615, 0.012662536107874926, 0.019177364095324473, 0.04131208038738659, 0.04638628290605642, 0.007250810571525607, 0.04810482496395708, 0.058724845218802654, 0.09791585797023389, 0.016541877994313836, 0.03415107351517485, 0.038362163073954084, 0.049168518894622405, 0.04525279453504951, 0.01714358260224183, 0.053501642429299896, 0.014208174994095199, 0.016783624699699785, 0.05812333213285573, 0.03900487253802919, 0.03440580158043773, 0.024376048240810636, 0.07113944558847336, 0.007599165593649471, 0.018970803808300726, 0.061255835011721625, 0.05476412085455753, 0.025557022571804065, 0.048234454701624574, 0.054120465271895936, 0.03987881415072949, 0.051528088853604374, 0.07207933588013535, 0.022047008800831054, 0.02205320645213848, 0.04203881054455715, 0.01766733776387428, 0.04433722753498343, 0.030135200396480582, 0.22832679081588025, 0.025515119477565733, 0.04276000188603517, 0.04645051937850733, 0.07315868481753335, 0.048342266255208564, 0.04937530517758382, 0.033508184020437544, 0.040691507033883564, 0.024150331925240257, 0.036037603333111734, 0.010409596011853747, 0.05260664489000075, 0.028611955217896935, 0.04760861449364213, 0.05788806270086958, 0.045488749615727894, 0.05106732144110626, 0.04279962012303933, 0.05291145212287384, 0.02650685859994302, 0.05000099982886065, 0.06297946772387912, 0.03408492948379248, 0.042442695928677436, 0.029034672958415844, 0.023310695729789235, 0.03874894171472519, 0.051729550825492035, 0.059992950559864124, 0.04874275020894505, 0.04038956880028691, 0.0262761952716016, 0.06410537182443565, 0.06285783977458073, 0.018050293625903227, 0.06333804283771785, 0.023936191198205756, 0.016936938045546412, 0.04737192396855643, 0.014775931373268608, 0.043731194530283256, 0.07044439699741141, 0.07142949413748519, 0.049465037056154786, 0.04671968437070328, 0.04402107837039136, 0.008736966560865122, 0.08282970982573687, 0.017877220957269593, 0.03235649340034973, 0.044362347558020584, 0.02954529354258651, 0.039412121048137065, 0.0587624907794018, 0.12024844711225842, 0.010655176029690813, 0.036623097520561955, 0.01916003710169706, 0.007013548353326417, 0.025029940673360423, 0.03888765342473503, 0.056537350098932945, 0.019282592017383828, 0.01458624034233752, 0.08498117583052767, 0.01061123801440361, 0.007824573080025373, 0.02726951253510291, 0.060593011909194534, 0.07139940220381945, 0.0194692014596395, 0.029506927859338544, 0.04508047454780148, 0.016984950690980882, 0.04554321463670462, 0.09589495633037821, 0.03937585827624125, 0.05334667433353682, 0.027877464590053407, 0.036474897811609897, 0.026086125027147994, 0.039073858755610646, 0.05549187756954663, 0.05379410032483359, 0.04869856608791217, 0.04287679965097097, 0.04306008618685507, 0.004955744736963102, 0.0336527333204304, 0.01910300951661362, 0.030462567003503926, 0.02839136211532018, 0.0011601153129313683, 0.05701029830942712, 0.049623234212518706, 0.03625638272252776, 0.058979623079780615, 0.0336639182041249, 0.08041404307849946, 0.05561313396620174, 0.039213803867178584, 0.020515687140305678, 0.030990263687506802, 0.07111383526916466, 0.016088735071882125, 0.05164049310429443, 0.026422064158044038, 0.05805728386246389, 0.0697018356332856, 0.049491892268340436, 0.04797480452144819, 0.019738395180132602, 0.021861954517061674, 0.04009567832033481, 0.017023425541758057, 0.08186683689634647, 0.07218485683082573, 0.028079210014473048, 0.03276438925475363, 0.043263808118119355, 0.06547755787088987, 0.06674267546904665, 0.026476954357818733, 0.03182009395752703, 0.09882437696139659, 0.041533211666730144, 0.012105154474416088, 0.02027128210982248, 0.059748809829714804, 0.04589447744130608, 0.02429251018310747, 0.10603196197940458, 0.020460821838388522, 0.020987796484522765, 0.0866970289198141, 0.030852249117508054, 0.05282633592404666, 0.054220811298657814, 0.056735280405489676, 0.056438137882299004, 0.09425485401504463, 0.012425585112894976, 0.05567682651622642, 0.011041367655589936, 0.028935870598821394, 0.004745975499146528, 0.06059215006027972, 0.08167949009446368, 0.05458397144872335, 0.06287715285115185, 0.026319576915533795, 0.055214392862492995, 0.05623413632894236, 0.05842344324675299, 0.02590237309284989, 0.014418063933149943, 0.06586004258884538, 0.05106705331033276, 0.08301236050864381, 0.024925683767745094, 0.006076145932198533, 0.030998767263466315, 0.03158031226766687, 0.04287659663767104, 0.026498920013827663, 0.012845693366421808, 0.07702663210370848, 0.05518315179694084, 0.04986734429915106, 0.004561808919759407, 0.025976813856452226, 0.05679957433453491, 0.04508259278091212, 0.04967047885480908, 0.04920024259556686, 0.07220239258341252, 0.082629140346281, 0.01892345382892076, 0.025768049151426362, 0.014604171587815209, 0.07026682547744244, 0.06560721059119509, 0.012253083179764932, 0.014907147870549272, 0.036944184121826006, 0.014526704776911967, 0.02121182166100029, 0.025237615618313995, 0.04760310249102693, 0.010704374196188105, 0.09480867429726547, 0.051020065307497024, 0.03556523734944002, 0.05138263556986086, 0.01192109227450865, 0.02331830489809715, 0.031933201093887614, 0.059456865213090376, 0.04225517675701169, 0.007095810395830702, 0.0025393602611016365, 0.01138278910319411, 0.057342221224380124, 0.03283721740327535, 0.03280666198641543, 0.023675832386699416, 0.1826884510416177, 0.17832766407199446, 0.14440340620856132, 0.1243984449895159, 0.171353230252862, 0.19973818212747577, 0.08382766958205931, 0.17958391037198806, 0.1431259086295482, 0.18736482027076906, 0.09550648080485483, 0.11376910527507145, 0.14372929480046998, 0.156946609758081, 0.11058420198218477, 0.14146116892656974, 0.05929722398098919, 0.10221934156312097, 0.11687536964253073, 0.08707391353504312, 0.18769230753664048, 0.11066129341000512, 0.2101979789233977, 0.15827434738316845, 0.21446660551573002, 0.08059644861327064, 0.21345550735150615, 0.13573484555367502, 0.1039552738169028, 0.17701627476321113, 0.07950479630380869, 0.1176479003662544, 0.13234412507905116, 0.10854797092296424, 0.21216351538896563, 0.1155666080153277, 0.19780722687080984, 0.10427108590280819, 0.17416373105539432, 0.10147685680778758, 0.13051541191675972, 0.19399808449370248, 0.16953539553909533, 0.07964213288599446, 0.1613232087824614, 0.14116812497377396, 0.1746566167041179, 0.1287641042783376, 0.10323234728627628, 0.10167499778852349, 0.09281564293609512, 0.1403608061974087, 0.16540547682633325, 0.1290662646774323, 0.14719653213697095, 0.15518425513179074, 0.1428986716294481, 0.1488778959479063, 0.15614109894921704, 0.18989897783725493, 0.08481735558879953, 0.23306147465782784, 0.09447526517173938, 0.08959983565634297, 0.1395217254157028, 0.11229801727759262, 0.26417202947120516, 0.1221649539506724, 0.29998299335279777, 0.20628426554462603, 0.18503569847633763, 0.23967296666195317, 0.15789318799732194, 0.12415818449470306, 0.1304354783027403, 0.19364320192365878, 0.12191530887878711, 0.11366632691914998, 0.10545121370664529, 0.16495167698350646, 0.2830177311214709, 0.2157241541651949, 0.15202172160629304, 0.14006543333732313, 0.1149680175548119, 0.17654085591916116, 0.19398723668869466, 0.09319266544715052, 0.08179347631671736, 0.11787696831649351, 0.14919573050593177, 0.1267720918141065, 0.09179971075706905, 0.11510944504651333, 0.13741386513556206, 0.11894562266646855, 0.12041512486194411, 0.2111782803530655, 0.12376349599611376, 0.22026871030609455, 0.2038840354690629, 0.1458337689719854, 0.09304494837359076, 0.2277155752263723, 0.1602374017238617, 0.12324556693314545, 0.20507977614479683, 0.14000911055313003, 0.21401302017752202, 0.17732073342607868, 0.1946798108157612, 0.10324067466201321, 0.11966923101534767, 0.1940068945048317, 0.1938872009275421, 0.06925496888617355, 0.13671277211077754, 0.23772161814474294, 0.17332393015103956, 0.25819681945347017, 0.10204691049312392, 0.14622767606089193, 0.133158246716184, 0.09813033194551546, 0.19751124114038485, 0.13988069889526214, 0.335070341224632, 0.09611901406559253, 0.2877301218048219, 0.08397408430614779, 0.10132441297173501, 0.21761184077589743, 0.13312656131963577, 0.10871794285072435, 0.15238394329865135, 0.08610350996135704, 0.09397821966558696, 0.11265548922482038, 0.15480755437766353, 0.1176983166125513, 0.10373087134212257, 0.16343637039103817, 0.1834471845218251, 0.16824337293303784, 0.17801361398831492, 0.37156796503451567, 0.17730297550799387, 0.11482636789761244, 0.1437283142079269, 0.1414215928244014, 0.10281237022530648, 0.19741606237667222, 0.13449925298412002, 0.16947513506297143, 0.11650420770409609, 0.2998949238850225, 0.08323349944886663, 0.17258162159592877, 0.120994724002817, 0.14735900406395236, 0.2477382330764686, 0.21539118170978563, 0.11764708831305466, 0.1930430180002605, 0.09297030076624886, 0.22610055462967968, 0.09328958323045124, 0.1599266151747396, 0.15293681363184608, 0.20774548632964013, 0.06117042003860397, 0.13745598464963898, 0.1254006182294219, 0.12617818981168732, 0.11179760864545261, 0.14336405472169], [0.05608760286122561, 0.02423895297632102, 0.025222948865003647, 0.06762472612242545, 0.03629939089859686, 0.04128236383680375, 0.01016957970756677, 0.02096282393341103, 0.03620350733399391, 0.03679233017347513, 0.02761878159588143, 0.017371315644272876, 0.026289885262808493, 0.03023871611202917, 0.04285423836160091, 0.015326503442690499, 0.03468619359116401, 0.08145894870282182, 0.011152065445428655, 0.020848854948135636, 0.033042502153905175, 0.018692621961236, 0.06623812996211552, 0.029696092204821688, 0.013466577943144067, 0.03174506139100319, 0.030089650723722675, 0.0462901541933177, 0.022241955194922707, 0.02880562607559466, 0.03542865153342005, 0.012510154516466204, 0.037490404811837984, 0.037470746995700945, 0.027631971714717728, 0.034198329648784095, 0.05072493759554721, 0.013069204306380163, 0.11915597508871749, 0.0300973690595598, 0.043276613277773705, 0.03706142238731827, 0.08233822611791473, 0.034352320982443715, 0.033195597164693384, 0.021016021078873067, 0.04689734016034392, 0.1347607647579524, 0.014693747375971608, 0.03717296861953313, 0.05858435235436886, 0.03377267587629538, 0.08992933773345525, 0.04848554767968674, 0.01712249986256563, 0.032694426275068716, 0.07113997418914111, 0.09401619464399354, 0.018546086578299443, 0.040306218434125185, 0.008753367545714062, 0.022038733136029016, 0.01920809188196736, 0.07934482182346045, 0.04412477603182197, 0.012132478915455361, 0.00874526329308508, 0.024223004940957315, 0.03837605224802129, 0.03744215276392718, 0.023886232689443617, 0.03789956471131694, 0.02493310141407194, 0.01069749376901816, 0.04437514122635607, 0.05353293329056713, 0.02142393800069488, 0.01732532930139813, 0.0767967444393904, 0.025336576941152735, 0.017997060091264786, 0.016437776221503175, 0.04841206835642938, 0.04937680287947578, 0.022677298064433762, 0.044487120298248146, 0.0038637661219259067, 0.07942601948255494, 0.018648052881021174, 0.09893416502182523, 0.034822970929165045, 0.06291461838108879, 0.03227151509734892, 0.03646125761611808, 0.03915374257391499, 0.033136141080889976, 0.0357992772103077, 0.03240056643863359, 0.04210364839602863, 0.042721318276298624, 0.11263985337028581, 0.049436550076690414, 0.012323953973640119, 0.012502335631589015, 0.04931818183150984, 0.0319514531386836, 0.0044747372815055, 0.06489350775917692, 0.008259005262516439, 0.030251511695584467, 0.04628827344746359, 0.09041994044016446, 0.0332728456405382, 0.06687694769953528, 0.03160965918082624, 0.057874774905822934, 0.028377553380485025, 0.018231544283128554, 0.030576551310537808, 0.06392169075327055, 0.036113970807843634, 0.05980726233833741, 0.01597314772586669, 0.02264659134520879, 0.06769994829571055, 0.039135712694617054, 0.01704516903226895, 0.014584147007084422, 0.08198581801186647, 0.07058721876913501, 0.02444497125613834, 0.07726331496791494, 0.037497448990301746, 0.03350315465321464, 0.01120135362725705, 0.03449844076268135, 0.011906194737211112, 0.03896048157325676, 0.02211643168852935, 0.03332615003830964, 0.011426661043397842, 0.059209414983108166, 0.06018552591183013, 0.06501989694492472, 0.03895489679228875, 0.04254995206851633, 0.026355313001981667, 0.043671841868349624, 0.06158894919339688, 0.018684363533412258, 0.011793846985505474, 0.020061780045169498, 0.040106572090618076, 0.03328400754159497, 0.06781533645886569, 0.04527086654918329, 0.038969900624285785, 0.033098675550953034, 0.018431071883007404, 0.07798795753549184, 0.03638589371656699, 0.04365175121253537, 0.03971023267255195, 0.012794077234913506, 0.0680833523191752, 0.014488617758146458, 0.028855278149187088, 0.04316630044711694, 0.021124150558945634, 0.08321073897663625, 0.06023240283191685, 0.016416109339784712, 0.015815163158901756, 0.012716048306995823, 0.02941757519429009, 0.05651124565291309, 0.0778358584390052, 0.0431505611707126, 0.010356049338776258, 0.028118023859156717, 0.014342294006998983, 0.07237293907711584, 0.020005836474498915, 0.042964715901161396, 0.04018112776740905, 0.0629323571469755, 0.009393833329780929, 0.0269032976094393, 0.023355626786548286, 0.027479062480251157, 0.0447817730356849, 0.03827592072587821, 0.03681380744843233, 0.09556647315020524, 0.026156867501295866, 0.02945037716398797, 0.014944237059793405, 0.01445321013189612, 0.05611074637741812, 0.019761678507371296, 0.009937407186014519, 0.081939990632236, 0.036190843900605556, 0.03645703264121567, 0.026174903126253236, 0.07068585258938613, 0.034012231570217884, 0.059982673490359906, 0.0773378323403097, 0.019511893624439836, 0.06344060668902052, 0.0742082252737976, 0.0650089955137622, 0.03349207702182955, 0.03628881122436255, 0.0817958971545581, 0.017548680320502292, 0.03614837581652307, 0.06545220802147543, 0.03841562835018962, 0.05796277159524541, 0.028987005052547303, 0.04140260516695919, 0.025395927687866554, 0.0686049662650593, 0.007200813758367252, 0.021624735391308225, 0.07257768373575903, 0.007265801954593871, 0.08563759060756815, 0.0330746318814495, 0.06499319878076354, 0.018885086230452985, 0.10055510747817256, 0.04698538281504185, 0.011913576951971459, 0.06696826538010951, 0.001040623073124387, 0.022602652372311682, 0.03865692689413986, 0.03162200851816564, 0.026127254372582804, 0.01261923586078469, 0.009602008147105094, 0.008298417613390953, 0.03984460449447075, 0.04505825799799735, 0.03565075957486707, 0.0403608788075226, 0.03549719342000542, 0.1220709932667594, 0.02296598297694037, 0.062432615011329615, 0.01944951683042511, 0.06916009655763065, 0.028116403583196864, 0.007916357595428464, 0.03564525906357073, 0.033813263214523756, 0.0163913551237314, 0.011469276599405755, 0.09406111803987334, 0.04105397004393801, 0.06478628609329462, 0.04035232543584801, 0.11657124805834987, 0.09695983386688656, 0.009429359699659532, 0.11561209065539223, 0.044770071042641524, 0.04087427262997916, 0.03380508139549244, 0.024652385731197657, 0.008378165451088741, 0.058019182479549805, 0.03348360025894738, 0.052892047115751815, 0.03791831088282409, 0.044616608309649655, 0.06132426198511835, 0.043408537448774424, 0.014923435857429381, 0.037230432874733405, 0.012420391036768355, 0.06514872229027172, 0.0887433493569974, 0.029380578893206777, 0.0560091937621755, 0.03045356355517382, 0.06371821780058165, 0.020037431855716055, 0.06195989279677311, 0.0228663360054094, 0.023887322449515906, 0.05185214787601464, 0.018943623008747256, 0.01880697782091316, 0.0273989258529318, 0.04270903405643279, 0.03130059632953377, 0.035439189072818525, 0.024361310624367288, 0.029671315006130648, 0.034088794397370475, 0.02340109410485433, 0.028107333102173386, 0.06505306089116682, 0.04983911395914132, 0.02201410723970302, 0.028504507556076975, 0.05830115646183972, 0.06876531612849043, 0.0312990986276418, 0.02021974737515613, 0.027557312616056977, 0.05862493969259724, 0.026349563512109944, 0.016359443731245496, 0.018151327216577147, 0.03424463966380685, 0.060230997060575796, 0.015878128883008276, 0.040928090306659864, 0.009705098683855707, 0.04706837695031878, 0.048128374506749456, 0.03796186681175905, 0.027982832323158943, 0.0997487539725919, 0.03111373982392252, 0.026329650971738082, 0.005538986625915935, 0.07277483646307262, 0.05723189307196487, 0.010489769985959416, 0.05263873631314886, 0.09002818605832516, 0.047073371843585086, 0.03617344604384515, 0.02849313498084103, 0.02125204893790426, 0.016576283002993273, 0.02905222403276111, 0.007424132218734632, 0.05932258915216212, 0.006551215727438009, 0.012578896543521796, 0.06742196563150614, 0.031159128618216327, 0.028513252449732636, 0.01987121758922454, 0.01848789837001072, 0.1425593406442673, 0.09763207602044267, 0.221204103661641, 0.1623983672189136, 0.0889227671488639, 0.2029094950205857, 0.07486331471872908, 0.1430299637779113, 0.13108470717505102, 0.13034003906913344, 0.12423324578952406, 0.1195444199707239, 0.12276180539160006, 0.13519532047212124, 0.10925332339660776, 0.103881606802104, 0.09052685567087705, 0.16344226926805513, 0.11720403668380554, 0.10914975597012429, 0.11706550500445789, 0.12109695077543298, 0.17540355243029135, 0.16104697279872435, 0.08710344622452414, 0.13255208730697632, 0.07998075140940566, 0.1483504290902807, 0.10280683907049318, 0.12080105697555889, 0.16094264694519583, 0.11081674797160011, 0.1541659097758032, 0.12996131584288614, 0.15782183456805446, 0.2062664156959903, 0.1481171553173373, 0.10236915005671401, 0.14473662381210636, 0.10040735976109583, 0.20647220223421053, 0.08447083103800974, 0.1558804911591353, 0.1462395351019598, 0.1377075679239727, 0.12794190041360357, 0.15729931663841973, 0.27464144833145604, 0.24628972935099758, 0.1369025167678633, 0.12828531464742077, 0.15676556785981502, 0.0958359982037256, 0.22288077901447975, 0.09613183837744499, 0.25013294731897695, 0.42714972770021814, 0.2653972492102654, 0.09461740512521037, 0.08577357887500718, 0.09998503847107773, 0.13872340051156862, 0.08567561155125018, 0.1959607404686751, 0.156668167441122, 0.14529828883467183, 0.116179823094318, 0.1167390059920088, 0.08987707521526084, 0.11397605626693658, 0.14007013711717822, 0.1347142325774316, 0.1630096900607309, 0.11859252508128844, 0.18185375228283868, 0.15823814206786696, 0.24112295659799732, 0.09609775512569374, 0.2505353733056015, 0.0940165087400425, 0.07936987289858442, 0.16031929652296728, 0.14287490758203691, 0.11232600246946658, 0.08966493014726909, 0.2803709279865988, 0.11513199867500414, 0.201914714529149, 0.10846655875925096, 0.13927087758577641, 0.09741701981833867, 0.19472903962577545, 0.20006586857620748, 0.13600168929946038, 0.18285092296859912, 0.1760131285916413, 0.18390582604033334, 0.17139945599821307, 0.17235827632248404, 0.1864184871796639, 0.23119549897889938, 0.11043972546054472, 0.12313741830087478, 0.09186776234738289, 0.2918173234549261, 0.13954190417162834, 0.11350923292939702, 0.11663621231432884, 0.10091104724955174, 0.19795938725433043, 0.1366106985557464, 0.2798915101635841, 0.11179307340494088, 0.1045789766395765, 0.07057340620386024, 0.25647961804943703, 0.09830428753048183, 0.10674148963223543, 0.266115288099935, 0.11883568138845506, 0.21296614570723427, 0.2287026641950492, 0.12390977282437587, 0.12398207620266946, 0.09840614658089415, 0.1023631669100254, 0.15853467938159743, 0.08691239921796708, 0.1815814846345494, 0.16401124276941823, 0.20983007285864125, 0.1156844093554443, 0.11119166374086373, 0.14159937118810995, 0.11379931978280507, 0.15944843841416223, 0.1661021725064324, 0.18268386983583051, 0.11512902625385793, 0.1851523123801716, 0.11683010916796424, 0.1288657641458896, 0.1106237780843531, 0.1518936010618364, 0.20230532743998114, 0.10657661985005103, 0.19053735890455786, 0.054527575886177446, 0.14592081188194214, 0.0849080374163966, 0.1287581134707697, 0.12203022206742918, 0.2982521862272294, 0.2270456466583475, 0.09332791827018223, 0.12121183332055809, 0.19670248211872196, 0.11328741983180085, 0.07910649187021679, 0.16303988924670607, 0.24906555701407695, 0.1186621011865716, 0.14931269681021092, 0.09367910829643089, 0.10809920427779998, 0.15351721716503944, 0.11785665166474159, 0.1508102454845944, 0.2016654754838636, 0.12466174174821186, 0.13224762864410877, 0.14867883566166126, 0.13393031012627388, 0.09845482380760294, 0.12408188979832396, 0.14695648614677692], [0.03134037927544165, 0.035524918141985135, 0.05588282372862582, 0.04053196156277292, 0.02012561815189979, 0.01335267503295214, 0.02159223985678006, 0.07692961472897761, 0.006234754382016799, 0.052111100916179924, 0.009694731599020382, 0.056188906497892835, 0.05975057566238027, 0.029452301959897724, 0.021064763423055414, 0.05341563756848055, 0.04085589418067567, 0.04040682493078132, 0.06174169563417954, 0.06709561217576265, 0.04715551179082644, 0.0504280019160961, 0.03511582719041936, 0.04993612750343258, 0.11069395939909643, 0.057627880089585824, 0.01914296674752428, 0.0267730052057173, 0.009330070874233161, 0.04211029803921138, 0.027908925905883796, 0.05040334920669275, 0.044903297563113516, 0.0660994757087, 0.018879057118488897, 0.06330893915747443, 0.063878353159394, 0.04641341007945519, 0.0354325087861188, 0.010747610283414684, 0.06532283875370218, 0.036974421612197356, 0.04463717010953734, 0.015946177600492394, 0.010818576838280405, 0.04806836683964057, 0.03342379943557805, 0.0675819247900959, 0.018035236167751493, 0.03980777481751096, 0.03521760197116002, 0.010247396046085464, 0.03616345242687291, 0.017135239904746413, 0.015224381049554196, 0.03418636718584645, 0.007190838814788168, 0.08002090973839646, 0.049935330771991325, 0.05729781876828882, 0.13488860951075632, 0.04589206043390497, 0.029326778453504367, 0.00583649399848054, 0.03299919903398522, 0.027610000313049363, 0.020116453825105584, 0.03382137608564189, 0.019029463160662882, 0.04221477711032476, 0.030939140725099755, 0.06321518531730098, 0.058387345183760896, 0.022056002673062108, 0.0417140007559811, 0.03264513234758089, 0.00763687483530732, 0.04174072956365924, 0.022172246939472617, 0.09929213492620377, 0.03797929148159681, 0.017774546023217902, 0.08988701137563876, 0.04287404939532281, 0.00252892590417046, 0.03312707059986649, 0.052175931106772155, 0.07550067688909269, 0.05364812993174119, 0.11285127831562874, 0.061698522749206716, 0.012784494432590663, 0.03560928740508614, 0.03656493229491096, 0.07522154509300187, 0.04786565614443633, 0.02028201500164165, 0.05135807479100843, 0.014268800319593041, 0.025857524390542702, 0.05675782254266162, 0.05228391886057873, 0.05674484884366394, 0.033130743991463416, 0.06050136864125248, 0.07941064409791462, 0.016809112444940596, 0.06260901441677444, 0.022699769338472717, 0.022157932586607434, 0.0114679962749623, 0.043192209540716106, 0.05395431612287799, 0.05585961892539936, 0.030315123806377093, 0.029881050727600535, 0.03398570577583967, 0.04492614230501556, 0.034064195314121824, 0.05706711138989176, 0.0744888202978238, 0.04151605129722626, 0.04676250102479131, 0.07588847059636347, 0.023319980715431517, 0.07584279643431788, 0.029941738297742222, 0.034447599337586475, 0.019268976719749552, 0.11531732300476683, 0.08559130357518312, 0.016430808651831844, 0.04409129415909129, 0.011933414798770702, 0.03928475510028582, 0.01376189621946504, 0.028814842113323753, 0.01799687048450353, 0.054522768684452584, 0.05602456914681581, 0.04744995768452364, 0.05510412599711169, 0.028434389443587393, 0.06483915382094922, 0.006859819883585818, 0.02144672145556298, 0.02636458266586546, 0.05226150695835391, 0.015565737379684806, 0.023528586457213087, 0.02682435799450163, 0.01067598297771427, 0.031264910038800976, 0.04173919738781068, 0.0514677441078088, 0.06664348240461081, 0.012276910429429865, 0.029345857873258573, 0.04814337450830687, 0.04861271061423806, 0.042676697485148914, 0.02251480890047406, 0.06888048212614752, 0.08947799703286541, 0.02797907849232997, 0.05968928479799821, 0.0569337124996368, 0.13699193455038533, 0.005300229578654492, 0.020355482833580147, 0.02100911096579606, 0.014160200653056947, 0.03430552833202866, 0.06483323196129454, 0.03825379993706461, 0.05901282149997931, 0.01251037763957415, 0.07736634613285143, 0.012072823648791642, 0.022720085990224636, 0.012142346127920095, 0.062032636675623164, 0.04482504168164827, 0.0460220885372931, 0.05325446033009118, 0.05196994538569162, 0.03076276621751247, 0.058157047662403316, 0.046129501725156466, 0.06640208043879078, 0.03820720263907025, 0.022312893021491267, 0.026058538200994654, 0.03691141854130453, 0.04827890695343095, 0.028319884196765004, 0.049494006671011455, 0.011628541490814139, 0.030878169702426083, 0.05244318854003664, 0.06335861229848477, 0.03207850307526608, 0.03959502454005903, 0.01291906352214996, 0.012957303758500325, 0.08567216415559092, 0.02759505010720703, 0.03374852878492206, 0.09428338312934484, 0.031463930105429985, 0.023703038084110426, 0.07442439996427105, 0.025143700899676453, 0.02324059485427795, 0.05650718155647478, 0.0513434463420943, 0.015674770843508025, 0.10654044517826651, 0.03816990947891628, 0.017800920515231067, 0.04978267626175958, 0.03616935896476911, 0.04607309084085207, 0.023892372884156726, 0.04987686677204986, 0.041227239980212146, 0.08563676323260992, 0.05192118388931117, 0.06316285002075377, 0.07350775278023175, 0.022303573561892397, 0.08010083569153663, 0.07285813320307963, 0.05034878076384625, 0.027246935923974362, 0.0664159159867033, 0.06567006810538231, 0.008011541147190597, 0.0332113862368128, 0.028928035434575814, 0.03679165218566214, 0.020989635095541036, 0.01669970551325429, 0.034997926258872596, 0.037255993398327025, 0.07231013518908332, 0.033576974885598306, 0.07240126900855573, 0.035674565757114085, 0.04119994043703041, 0.030265716880920435, 0.0479433604425961, 0.07555903746716439, 0.019994935043336406, 0.012815954790811145, 0.06700995588494886, 0.022126222292201656, 0.013863356904156748, 0.033653637304181055, 0.02928818677431874, 0.02278589868857976, 0.08471555782542114, 0.05406862410205988, 0.017213177859723088, 0.009923789973160433, 0.02156349049220162, 0.013546298010154598, 0.005176845851594643, 0.12076319691034094, 0.0749338714165553, 0.06458262927950391, 0.04479547068777104, 0.01550933319864975, 0.06381094125249694, 0.037834504694347425, 0.019804602413768732, 0.057076718132462234, 0.0695801885317891, 0.0021502196754989845, 0.028210777954588977, 0.03470350334781312, 0.04820877543440269, 0.031251369434739315, 0.04927896579066592, 0.06783994320299357, 0.004589531726519307, 0.012450934004699512, 0.01179553046371908, 0.04688960267230869, 0.06732471843039797, 0.016427156327652837, 0.028530265347311096, 0.02753151268998702, 0.024414421584937843, 0.05467936471705476, 0.0382319089746283, 0.007818972019688978, 0.023199827485387365, 0.016286954576630267, 0.01121982017667183, 0.029129064566786253, 0.04635546318886261, 0.021319976038930398, 0.014328255445786543, 0.015783834950848213, 0.06651323979660388, 0.07961071562021971, 0.04675685878722899, 0.038249820110297976, 0.027959129562781706, 0.040377334376136144, 0.030750633300011678, 0.037359771498989676, 0.011019408702850344, 0.03333124069256648, 0.04373279948448462, 0.02326620900402627, 0.1042090557635792, 0.021287179814891952, 0.0049041985109778904, 0.014924118633291896, 0.019155747009321086, 0.0671780202537775, 0.017261326485764117, 0.03438836158884149, 0.012489630063364824, 0.03580932445343464, 0.021801893223798084, 0.039015781630070946, 0.055743705992016106, 0.024500522206747727, 0.04191008862107993, 0.07271685892896307, 0.022189148754302054, 0.009918559507857408, 0.04353493046496184, 0.019782274781215577, 0.03555347406936269, 0.041970360588522694, 0.01809907810492141, 0.02176574153465129, 0.04122922031749641, 0.022198646329343322, 0.07700695896581297, 0.04822718069678353, 0.004901722610567607, 0.021229453174577608, 0.12658689771929096, 0.03122305099461829, 0.051752311297722405, 0.049993258510385795, 0.07814528135162208, 0.06750069648748444, 0.11603962900417468, 0.12910731166841524, 0.13309185753666586, 0.11259872210963119, 0.12040857481019152, 0.07273319958438797, 0.1553141836437487, 0.1269848344306792, 0.11222146211131928, 0.10699216126193924, 0.11252737634124295, 0.1339118627290572, 0.14317591884924522, 0.08956061195461981, 0.12719807500440267, 0.1514857971379834, 0.1351105145389034, 0.24283689446747306, 0.12665301110715638, 0.2967516344881827, 0.20107491362479427, 0.1527851895098725, 0.12575839661181937, 0.2729545533657074, 0.21196192701257047, 0.15766408174268662, 0.054850286593840974, 0.16643172820969937, 0.16188744786045245, 0.1669315699367754, 0.13190512605492147, 0.24713109307471784, 0.08207364233150598, 0.11192321642151765, 0.14419565848525495, 0.20641351989921064, 0.17325208642550055, 0.14764530644301446, 0.14731253317046553, 0.13703495804821292, 0.20663807559157574, 0.07654812592532366, 0.10920656905058893, 0.11803053830179477, 0.12923469676846458, 0.10750239114126853, 0.14981499001864465, 0.13531213355881555, 0.11510155434089323, 0.17555866991319966, 0.13946904921002928, 0.16906434339621376, 0.19107332933814297, 0.09869526050263837, 0.22802611662735864, 0.2298322148741253, 0.19992234966447278, 0.2629113551830092, 0.19443023469178908, 0.20197514354461626, 0.10053434649542456, 0.13725274152332737, 0.12148433845610389, 0.09552973157335674, 0.11711688652153938, 0.1761818977613603, 0.16299027739272964, 0.1278529576055946, 0.283552123413932, 0.12097793135551677, 0.26322131435717305, 0.18394846649419877, 0.23370975358111246, 0.15620604788343753, 0.23602762920481546, 0.16234060418942284, 0.1653145881549966, 0.11462368401548556, 0.20161822318069397, 0.1659292664619223, 0.09556982095443434, 0.12458327902300705, 0.1225776148719653, 0.047305025340568636, 0.16935790828879804, 0.17509187721917707, 0.2338411989471605, 0.10188631548155701, 0.26885043649423507, 0.16294789740875845, 0.1257287336873912, 0.3530883921250221, 0.16159638041450133, 0.15218511283878358, 0.20777994496447427, 0.10689985532794269, 0.1761535984734374, 0.10942200829665508, 0.10794569557953267, 0.12182330937996028, 0.11198843348651163, 0.16966440474554417, 0.11902086016151214, 0.1512794436946992, 0.16036012900933144, 0.09737572767921994, 0.12446431322924553, 0.16793563541385437, 0.07448577126788516, 0.1839739006132849, 0.19501161881752554, 0.17129022718196915, 0.200218657151826, 0.1451427729860429, 0.10538662483374919, 0.14501779340207577, 0.12602754628225682, 0.10341201022627855, 0.13163451315654864, 0.11096857893731325, 0.0874919523935645, 0.08716372968328577, 0.08988318093601735, 0.22020376137187406, 0.2423648464102899, 0.10465999043756917, 0.11849351587795443, 0.12024781892016051, 0.24369411621122594, 0.17448481382621875, 0.09779205816167016, 0.144122144688041, 0.14471328877393277, 0.15163550604014628, 0.07271632266741607, 0.18427719482250754, 0.12295992338969824, 0.17973838434103998, 0.20976006774412048, 0.11880655472557392, 0.1530499494965038, 0.1330960863420079, 0.16485329597227036, 0.12877009508590545, 0.11941223916026855, 0.21849789806912023, 0.15830981725406262, 0.16179962354081293, 0.09208163111320428, 0.14592199165734554, 0.05521789005386734, 0.144223804555593, 0.12392248222303968, 0.14127986655840952, 0.15338813134979817, 0.30093876464713004, 0.14810126665378773, 0.09812591161819235, 0.1290098346409298, 0.10457952056200275, 0.1841445543592976, 0.17541021739523258, 0.23101936004334883, 0.08496422996564258, 0.08433622938971366, 0.14624621538865953, 0.2623144501159268, 0.22820945678939744, 0.06564497872586213, 0.09008152109961357, 0.15203770220039353, 0.16203044583239865, 0.15653292227896953, 0.08766118887691729, 0.19332886072656802], [0.024411613872695356, 0.05035720773101334, 0.10010180559249655, 0.06578664370482007, 0.05358862022178308, 0.037836940853946635, 0.04073138957122161, 0.017621023918411905, 0.09606351865635765, 0.049444161160218145, 0.03523270539458721, 0.00017193549190837546, 0.03239679345560651, 0.04948084911091193, 0.053600513736807534, 0.01305179495830089, 0.07599760748205647, 0.02149636778349598, 0.060941428697157296, 0.04453818005840144, 0.12500222186527907, 0.048075158209089315, 0.033494206746259046, 0.0472766877482495, 0.07234942017784042, 0.052796868352039214, 0.046669808216393, 0.015229878688020813, 0.02004132549759121, 0.06988077845063902, 0.06563644450638564, 0.041126503248608885, 0.024797367870867736, 0.03787683871304316, 0.03823855861781105, 0.024840981256397023, 0.05489119185855793, 0.06276368373824705, 0.025001673944174282, 0.09283373793286663, 0.019390349944813118, 0.01581263794158135, 0.020937248088058927, 0.0014746889698266563, 0.012426143399469796, 0.05336109976915102, 0.013498386871370097, 0.040416427842912175, 0.06030843705840169, 0.01778830687755779, 0.028057604419788527, 0.016163838501538963, 0.00925196342230324, 0.04224426000409069, 0.012911063649000661, 0.009366159361126202, 0.09766508674909992, 0.04857928236766208, 0.04913435520363912, 0.018541775418505557, 0.05690658532623803, 0.03761888924805868, 0.027438714544499115, 0.03148065188959722, 0.05110214779814405, 0.09268991258596221, 0.025108179317847378, 0.040861674314064365, 0.043466832909372546, 0.01888621812536111, 0.04764347149419689, 0.05308934923021063, 0.008587543026454026, 0.08735269293068879, 0.05651898697138794, 0.11818613842009537, 0.043972014269280824, 0.013861449345225289, 0.012059698647428906, 0.01568384419736122, 0.06760270875548163, 0.04559199145484356, 0.03357977493696156, 0.04355497898594026, 0.037291804178347515, 0.040598710803615476, 0.09428177434470385, 0.008478863878295788, 0.01641807052487087, 0.05011354963625631, 0.09039654411495694, 0.06217322530104749, 0.004835709292937311, 0.09999514317079898, 0.06538917430706563, 0.04366540289934605, 0.037300146875842925, 0.04079992379692774, 0.02478890834496387, 0.024320820962349256, 0.016117283338380438, 0.029614846665231936, 0.06637045632927649, 0.051572138909250505, 0.0347938978924386, 0.044733091978536504, 0.026506603875708197, 0.05482463030925682, 0.0014490061115676298, 0.03739703018518706, 0.03958072167851272, 0.019055837652676048, 0.019807184130073558, 0.036108351552919034, 0.06746036195827108, 0.016843961784616113, 0.07424416245832559, 0.018322555528533076, 0.049133937685720386, 0.08206706929711566, 0.03183873096150497, 0.024437063313539953, 0.053222506802769444, 0.0033740750598465845, 0.042705854791547024, 0.038701440432980176, 0.038500824988248854, 0.021315603592102567, 0.031330579095670295, 0.0647984515695322, 0.06017843576809091, 0.04654832965423984, 0.037171187465109175, 0.007231692368570235, 0.02765783867348106, 0.024604150920265147, 0.058244868151603214, 0.019039079479332414, 0.05918262105795646, 0.019440406129785606, 0.006645527375381321, 0.06583956505862937, 0.025625282921077266, 0.1110641943711427, 0.014434494603905949, 0.031826027308500586, 0.037919647706251954, 0.03553011221811175, 0.042521871115651824, 0.032978411238159866, 0.012146209126278278, 0.027764319149296612, 0.02682990447107342, 0.07843264859289893, 0.058434352338794744, 0.04994309890354353, 0.007217708869927353, 0.039458296997773076, 0.05179818847306794, 0.0072619466171149295, 0.0342598963048189, 0.010092475830817656, 0.0582090535411431, 0.014024190360590095, 0.023205697634107163, 0.04322679458005775, 0.0775470509524307, 0.024772674941848365, 0.06314914470778839, 0.029242918638873006, 0.021725927945226434, 0.017105576980318275, 0.07274228538716994, 0.07269242072417852, 0.018744863412012498, 0.08151866525651948, 0.045971442464618914, 0.02860361635084114, 0.04122766515901012, 0.06920629932034401, 0.10481614213917526, 0.05318403386721208, 0.03436997930909838, 0.008781365186516798, 0.052922885985143726, 0.028635181088541305, 0.05969970742420805, 0.007493956823788224, 0.01460958208378044, 0.04442435471461185, 0.11021475608070051, 0.02013441858692996, 0.022652593644095526, 0.0398649096549038, 0.06554993785797589, 0.0025847715592282198, 0.07544430813962415, 0.019523992067984035, 0.053584617412378716, 0.03241547834007971, 0.0641896223439084, 0.09412017575795613, 0.07495252565751154, 0.027366633331703565, 0.0626757828098151, 0.01985308428805682, 0.01976155593330341, 0.06195328911886581, 0.06639913866116155, 0.059609764871457895, 0.02761285399056731, 0.012728494362935666, 0.02122624135095506, 0.029871606778713967, 0.03727037286866577, 0.0705676528835489, 0.02518447401422647, 0.028342861088833986, 0.05547319651551305, 0.011066609295085074, 0.01301287386130782, 0.034569315386996154, 0.018940240730561556, 0.03018531212282758, 0.037617012332644195, 0.014945975121771617, 0.042318153014827165, 0.029277406002004302, 0.024504073024276766, 0.037410111136494145, 0.016426830740285017, 0.0720867745938801, 0.03539837573865249, 0.06852513990334927, 0.05010072149396424, 0.08740047383452616, 0.1640612070238398, 0.06702851819535417, 0.03944252324741214, 0.03215221222490072, 0.06627457276467355, 0.03865925197099005, 0.0376088343440525, 0.0309733503813585, 0.08045563399190865, 0.06325621315608583, 0.036611587049499635, 0.0619810636365606, 0.027477936331002463, 0.034012733357808286, 0.07969806496534618, 0.02504192037327636, 0.04745680651056671, 0.04206340579736618, 0.02513498281909814, 0.04549197484588912, 0.05796593553837269, 0.04581174377592341, 0.012332783136967451, 0.03122313143385034, 0.031789458101435054, 0.03355536354525435, 0.059561198727498134, 0.034723107537795464, 0.05216386905240436, 0.09830054902141133, 0.05053169574708708, 0.029618066149733724, 0.0036755677654347835, 0.03469984910841431, 0.13079132614356856, 0.06456259608028397, 0.027567775461882837, 0.04002191937498508, 0.035489819823734226, 0.05678770763258781, 0.020728096508631305, 0.07444991835302885, 0.05931345738410469, 0.029347171714048714, 0.04207262949597451, 0.04067233568357845, 0.016214126428108544, 0.05660302298624189, 0.03314614235874146, 0.012047738099711077, 0.05011336577515449, 0.06659040783321665, 0.02354571426798019, 0.048324845415810426, 0.014441570383496584, 0.02844934731030897, 0.07736337371170521, 0.026912073146611936, 0.043868691990933115, 0.04872051067650319, 0.06684949110832906, 0.008394603782723989, 0.03407443790966946, 0.03925298160362629, 0.023014587425296346, 0.05826008265777942, 0.06653391650968021, 0.022662468517439503, 0.04205677147594191, 0.04819136991676304, 0.04659770402095972, 0.031004059015803283, 0.026865698014115615, 0.03526061397766875, 0.0461608998387331, 0.054838688022667365, 0.07039481578695198, 0.0203845041593717, 0.016192605103095694, 0.0051071888282744875, 0.009421570500689409, 0.024146535959575447, 0.06138274513725793, 0.0688691670075059, 0.11276212866388022, 0.03786739284893678, 0.005146240639019637, 0.020709024749756343, 0.033485304804578904, 0.06678167700527177, 0.04540722636926559, 0.042602226078029604, 0.05733628787340657, 0.09063662074866796, 0.06091848053338547, 0.05012006521405232, 0.025057154031650677, 0.05331485870204145, 0.05958709632977844, 0.011923735277847418, 0.0705207453199452, 0.049940030721406785, 0.07569304156687952, 0.03204600179507848, 0.02389437428885891, 0.0409461546599144, 0.035145493945287126, 0.01676343062201575, 0.06348577906347572, 0.03267006850951622, 0.0059832783599924905, 0.09424018343129466, 0.045020313663107735, 0.04134483830702882, 0.03566647586863368, 0.04615614243272332, 0.13836612774720117, 0.11343525947942851, 0.1546681263754445, 0.18816610227429098, 0.20257555729439183, 0.1248018132642873, 0.17293514052946724, 0.13505871167346356, 0.140467522245261, 0.11415696026937616, 0.17402462481010347, 0.11803758631069815, 0.16594690180593924, 0.17871320548076786, 0.20784972025261772, 0.0893346006951986, 0.13718544836005858, 0.16099000650067485, 0.11253895192977884, 0.08298660463262951, 0.1635519424152951, 0.06377785008460765, 0.09996301344325466, 0.1770629448395583, 0.18621738909954028, 0.11888768343675522, 0.17802507466366216, 0.15674172720361143, 0.14475887100542748, 0.15127789619709217, 0.10050418561384564, 0.15892959770656404, 0.2971414506675736, 0.1320228278036079, 0.13281559090941183, 0.12452636635111225, 0.12149029095927555, 0.12574003348427434, 0.13464680151833644, 0.182219160900962, 0.10445686988532545, 0.11948651904540679, 0.12499061563322622, 0.10362448471207773, 0.0995917595742691, 0.13668837987126845, 0.10406772786330792, 0.1190556099097575, 0.10227833033329058, 0.10633570818050254, 0.11423418959302288, 0.11645965969129918, 0.15043616475116822, 0.14239139884950655, 0.09531822235834214, 0.1762682665139437, 0.16234782073766957, 0.11343645457659038, 0.15565189052253, 0.10873421455823606, 0.22497920109139335, 0.15754120123963203, 0.10088591190475611, 0.12164263520389797, 0.21970076336254998, 0.17813154556337865, 0.1317201311429662, 0.16972408299484562, 0.27882480933781595, 0.19220343160052455, 0.14557300796431882, 0.12948752110523562, 0.09097794356245188, 0.15691834111367503, 0.09568477244747263, 0.16481505286309028, 0.10434051645138573, 0.1680539040676048, 0.1531396277489201, 0.08676734046950456, 0.1124362348608913, 0.16087084918493227, 0.12245494887352952, 0.16828965996542286, 0.1927142130631593, 0.1232982814432152, 0.27021293918932643, 0.11396304809398229, 0.13410848685570304, 0.2342778077769664, 0.09769327878471344, 0.10182721945907801, 0.10374045510205532, 0.17231361339649848, 0.27243119273935595, 0.10123821275849497, 0.08662955955632272, 0.15990833631686627, 0.1161938731468493, 0.1711214273687332, 0.0863670212246718, 0.10101482918065402, 0.20580565977481105, 0.2170185210003007, 0.2415384214010931, 0.11771432785016876, 0.18672821652745047, 0.15598212038317036, 0.06218870410755758, 0.1071022940619338, 0.1216176760593249, 0.10790890803740871, 0.11201708517487972, 0.17514038590654252, 0.20951717190684813, 0.09936793932631131, 0.15398151241242886, 0.18810628612916316, 0.19898894813752946, 0.15196786562521614, 0.15680005713816614, 0.05283352948965565, 0.11445241739913342, 0.11401991480060163, 0.08605891598328468, 0.12162487728581314, 0.26424232569913714, 0.1162405125796795, 0.18411694455050653, 0.15824537393787216, 0.10070996449118662, 0.16147616589742322, 0.12494160132783076, 0.1393726753491548, 0.17001098292248865, 0.11537778266375104, 0.16203833653801875, 0.17994459988849779, 0.14968549051592428, 0.12957554460773546, 0.15388536837793168, 0.08233316227673523, 0.1412486867798913, 0.2824014287081457, 0.14881866202960092, 0.11358627073106267, 0.0819433537582236, 0.11551492772395573, 0.0982423952870792, 0.20354090468777766, 0.178370748856856, 0.11710632216906357, 0.12275833501330308, 0.21083131913215886, 0.12072588842842849, 0.1348851161498216, 0.137223323747035, 0.16906123307924117, 0.13587163821343454, 0.14205678696593932, 0.1571221817885676, 0.09726010202880829, 0.18447276174781785, 0.08028292713025886, 0.16911185616927762, 0.170700553984892, 0.17682173439571935, 0.08800609698218685, 0.17694066188508467, 0.12523368000984192, 0.07069457833084368, 0.1492417111031471, 0.2189121218097787, 0.17389014573587527, 0.118884458206594, 0.1499667673582031], [0.014999051608385579, 0.04540666712508087, 0.03859787683693632, 0.04952196888024769, 0.05840929360279153, 0.02412554515045016, 0.030713246294086984, 0.00827313862710951, 0.052833119632616166, 0.05554943758573744, 0.12470754614520459, 0.033915283143400185, 0.05460226945879479, 0.0084431967397611, 0.08986483313023083, 0.031318156979978085, 0.040013166820450176, 0.02659009022247647, 0.026130148269716772, 0.042276535288340626, 0.032457341214702014, 0.03028902893645629, 0.05587656862072407, 0.007695575843700358, 0.03022047172811243, 0.02885763386955425, 0.05238040763464186, 0.0536992279962907, 0.02503291500972644, 0.031664212301914255, 0.023829059547654564, 0.05048838496628789, 0.017024971124145295, 0.051529896821105675, 0.05747727869499115, 0.07091460644357628, 0.045352876261477514, 0.02321953509723948, 0.021281392020624013, 0.03683822267057915, 0.02864877340353785, 0.016366210202836705, 0.02515510794886899, 0.01673400710006395, 0.08205658155343226, 0.012534616661498384, 0.03389947108864304, 0.03385331429120514, 0.061167114369210705, 0.027451983187347654, 0.01706691252277984, 0.011059177284609648, 0.05956462314051967, 0.05506779810774231, 0.047194532479249665, 0.03299639898262197, 0.09657971636061707, 0.028713371852532994, 0.011981358496291984, 0.031481948493409066, 0.0029252148083140778, 0.07964084585828167, 0.057363257998780864, 0.022604784011960994, 0.05457754014059902, 0.04558339977877275, 0.045408639801485885, 0.06272942428627322, 0.06121101886815122, 0.021650163764734904, 0.02683626108562514, 0.0261881047364084, 0.02186363416483566, 0.056642725492917725, 0.019268304477595997, 0.029136453484815937, 0.017886184185983676, 0.05224720026636797, 0.04623707962192355, 0.011833364673469578, 0.03275333077556664, 0.06393005260296407, 0.03251804985226162, 0.048883683573935306, 0.06304394934446582, 0.08220006216077075, 0.01520388245192026, 0.04516879682459178, 0.006817428408295758, 0.008598894534272053, 0.04084093631395409, 0.06517049450907977, 0.0439393482801895, 0.05661094433537895, 0.08272144628027756, 0.061145403437436595, 0.032510626460275346, 0.04313938011745772, 0.01611532981417352, 0.08292194681182023, 0.04843270293466988, 0.03446695454899342, 0.02949058720391364, 0.08753052492055201, 0.03844657064145131, 0.05475492013858692, 0.020692266576412707, 0.05542918859470276, 0.046899266871473486, 0.027262981635548418, 0.05721672836150374, 0.06466319108562124, 0.07478957875601708, 0.04494650492204293, 0.07332794428352388, 0.014115061794948435, 0.026063697803164684, 0.02900065482413817, 0.019838237504084266, 0.02322341533257596, 0.060894141920031085, 0.060490708527786125, 0.05342303414738948, 0.060998352860370954, 0.040429834381587086, 0.015692832323932843, 0.05928189456162434, 0.05587728874337289, 0.007053686572509188, 0.040244341512481054, 0.03544820592768731, 0.01959936171319456, 0.03612695982859981, 0.04206858072129469, 0.03170374243880712, 0.053630881462126016, 0.027902515665177378, 0.026905783564753594, 0.039267709643970576, 0.040708801468774196, 0.010124338385198387, 0.05677309067499253, 0.04114213527270383, 0.04817977900646868, 0.01735403461592092, 0.06796151369569764, 0.029944777751581806, 0.027373658357969215, 0.017708235367711996, 0.037272058262099186, 0.041269374816047574, 0.05653987435864345, 0.07234818677628234, 0.06091144401580096, 0.02669335504422986, 0.039821384369485804, 0.019444784322272868, 0.04507827204501918, 0.10498321825458158, 0.06253599857671127, 0.010305461680306303, 0.0210087968697471, 0.02118300526372848, 0.07051584235722981, 0.01502725226248825, 0.020411531741340316, 0.009915865751193657, 0.037029951495388826, 0.10287063121194802, 0.015822757005451188, 0.014196943187515342, 0.027244783216907133, 0.040328718436461304, 0.0626628780587306, 0.043987922085028504, 0.04325187629869869, 0.027073914966275616, 0.059502470427222794, 0.07956396893508012, 0.0370787168222089, 0.14934827393341452, 0.060761754265836174, 0.11785534165439107, 0.05731125212004108, 0.011018172428462534, 0.023946341863202474, 0.08099639247502051, 0.04273334585670983, 0.021930977123819535, 0.020069394959136844, 0.02717634475219154, 0.031179699994203065, 0.06859889884869899, 0.026703647435492566, 0.06437667420194035, 0.03927435545671371, 0.019946148649098414, 0.039067239755944866, 0.021398358324903156, 0.015213556227184113, 0.02681924052716744, 0.048927335263860804, 0.06539839800567397, 0.03243730035460284, 0.05204432103182039, 0.04112361892757397, 0.02693028114135227, 0.04771805015362559, 0.03660219098110834, 0.05113791261288909, 0.02877228784434978, 0.06079861841675255, 0.03314188290988246, 0.0030927809805894693, 0.026946112348307526, 0.01548995213177536, 0.016739963433675228, 0.054438560299815676, 0.04527226849008472, 0.010910342680290343, 0.008907807040809384, 0.05950268110140197, 0.028529361363560445, 0.0697776859986686, 0.10143049316661013, 0.028377164590863452, 0.059024561797418905, 0.010221734973451784, 0.03952968490099715, 0.020030655808025793, 0.017613805454945373, 0.04717532282454833, 0.07005567632375226, 0.07888664761858602, 0.021217184276470256, 0.023608435801560843, 0.04053249399388029, 0.05724429220501935, 0.0027950844800685563, 0.060497055566238786, 0.024932547915546645, 0.05490417321843486, 0.08557471777162245, 0.08833449589268816, 0.03408143612285776, 0.01673887175838313, 0.0631800027293784, 0.019393006354690562, 0.014319748996997313, 0.03571278588365644, 0.05528819394267856, 0.021209996456520695, 0.07492506140542608, 0.0679614370869052, 0.04550566483709601, 0.04882657938005944, 0.04710772705654945, 0.034321581704481956, 0.06360013300793306, 0.027734169759036555, 0.01652470996393071, 0.11687501724208556, 0.0546570907106563, 0.04897451861911724, 0.02294962316931736, 0.04810235049996165, 0.026351585984230045, 0.023256768885579322, 0.009346878843291873, 0.027004235439122688, 0.01973114990358872, 0.053825716773468646, 0.05636328343121756, 0.025468300014073332, 0.022595996983469497, 0.11600028272838363, 0.016345803535753683, 0.019391625481207046, 0.06342816159069058, 0.03277067883661197, 0.017894314294080102, 0.05967131237529459, 0.047191847341075066, 0.048845658799813646, 0.01990120993146012, 0.05778831422268864, 0.016366108696186737, 0.017003304242426832, 0.03944830721124046, 0.023013221873571316, 0.0617188508922775, 0.02991108903511157, 0.058951844731646205, 0.010752414612309828, 0.011994014268801098, 0.04842753567162061, 0.07556831479192742, 0.049463535523823196, 0.07024135305396012, 0.058281862537466714, 0.036064922028491576, 0.009567380972927617, 0.04294102846254264, 0.032254002327399875, 0.03369253924897602, 0.0757971988810647, 0.06285498609706279, 0.07523618503323487, 0.0600984140539602, 0.022747699629455324, 0.06087057705548021, 0.01803896510072293, 0.038601711106997345, 0.08125397421780133, 0.07594116212379548, 0.022751769471553066, 0.010398027126587207, 0.04331656476302494, 0.04487321329032702, 0.05349557118249997, 0.07757816178303573, 0.022521318732610634, 0.005987807854844799, 0.06953315839411751, 0.01304310752123955, 0.04225309299785764, 0.050597414599671486, 0.07077615903390032, 0.0629972716072394, 0.08512571363920167, 0.019635764296136556, 0.023408647731787736, 0.04689670047692714, 0.09678367960957751, 0.04573039289924406, 0.09609171835285041, 0.02142465237768427, 0.10194108310726382, 0.05704956031554649, 0.028029402808075952, 0.004302709844083556, 0.059707793482248826, 0.02453166751130935, 0.01592448199047677, 0.06186584401274882, 0.048387499916697704, 0.04194507202614219, 0.016547213796706452, 0.03356739112566556, 0.03513262366815921, 0.029619994776083097, 0.08236411222887617, 0.1248053219469805, 0.15101730372876893, 0.15713347392457147, 0.1904694988362251, 0.17284861855929898, 0.0919245524452098, 0.2865586201510122, 0.13749657198786736, 0.15775483251819689, 0.13463932450019545, 0.2796759636652085, 0.1737013203842986, 0.09645749469317737, 0.15052017395294484, 0.15660583852760254, 0.10615314176726727, 0.13905594395774026, 0.1146742688011258, 0.11571955746941029, 0.1364730019122362, 0.1620811761747445, 0.1627096900295827, 0.1341203305750124, 0.12773931612290684, 0.26599727991607885, 0.1483145455319074, 0.1730188739395911, 0.13019094303730996, 0.11440662832389917, 0.15584931138061708, 0.10548918868505186, 0.16726198365851758, 0.18101629560753224, 0.09925199191897147, 0.1613527184893047, 0.1954447802516722, 0.10145104730561857, 0.1267162133609095, 0.06103649254768126, 0.20718434224686316, 0.21934067139462118, 0.1968583963330715, 0.15161511277960193, 0.11852930750577681, 0.25317581791070204, 0.1343306983190198, 0.11829902913661734, 0.2673893229615304, 0.23339142872681543, 0.12230226755022042, 0.1691288173559212, 0.11915149347436045, 0.18529462087298595, 0.1599837959774079, 0.10396750058017432, 0.10475312374652394, 0.18422635722785227, 0.20699913283028912, 0.09779431046016755, 0.0839186195404299, 0.15942294300804216, 0.08981787194047244, 0.13381276159517227, 0.12237971137848594, 0.12825032741191889, 0.20617060874017978, 0.2837695391668428, 0.16829278560415392, 0.1465668078632124, 0.11247797133100611, 0.17057816377810894, 0.101997313960906, 0.10601470967934978, 0.12290546986004039, 0.12133390943129217, 0.12899826671327316, 0.31023205468250864, 0.15787893876193032, 0.10242868274930986, 0.08495150524522029, 0.1764377558063115, 0.11193607137688708, 0.07945452561421741, 0.09208847993924733, 0.09588025510311128, 0.21690327073297194, 0.10321181612990557, 0.1487852605961023, 0.15541952073333726, 0.09971293936213178, 0.1683183576190664, 0.13168646923957333, 0.14813071507359707, 0.1260828425086314, 0.24815929032141165, 0.14354310479135285, 0.2552641735922906, 0.0993694025542467, 0.08655606108086725, 0.22972572865265034, 0.23866971323807395, 0.1474621501420775, 0.15372686478639805, 0.1844673991323479, 0.07306527571692582, 0.18779795106139877, 0.1600866509421218, 0.14379684843363302, 0.14694494886263726, 0.09241295647957633, 0.14512804877613822, 0.15993360189660905, 0.16401870446580072, 0.09394839586269471, 0.23094567770679153, 0.0966488941001796, 0.17204073287786978, 0.21078233547028036, 0.20878165089074643, 0.12063674643755921, 0.18025557029872172, 0.1891803260772459, 0.15514173725199315, 0.17717680082686488, 0.10364421913700719, 0.10094843234025663, 0.23953096460430856, 0.12745461486760648, 0.13035085623062428, 0.17226029367696855, 0.1123839723426969, 0.10838525384784707, 0.12343192548160592, 0.12220693556892297, 0.09369475947272393, 0.08849791776869567, 0.14251343665584443, 0.1814422251716737, 0.1565737547653337, 0.09971103946407957, 0.0775745228653954, 0.0966055641671823, 0.122850242581579, 0.22332658089937704, 0.10529338427248502, 0.15636576189389154, 0.11115751154119931, 0.11589493797791582, 0.11375038974708128, 0.1414879207168856, 0.17020432819281855, 0.1315699319445318, 0.22628148927563624, 0.20444303450565185, 0.12625476029971916, 0.06531651852832687, 0.11958919780989809, 0.16914718814434546, 0.17022488999270624, 0.18005548345465816, 0.07692373883459838, 0.18682117363618267, 0.1352512602123522, 0.17577769445075145, 0.07194981339477724, 0.08786181198252786, 0.1163972924733835, 0.1823525368085792, 0.12401982901557801, 0.11081578270081552, 0.1442589679913175, 0.10088513049507335, 0.09961727796302688, 0.1184918994324342, 0.13174179610946488, 0.15585735530382203], [0.05602169248666014, 0.015323622952095203, 0.049966246250175664, 0.00022076596612732242, 0.0499342161140615, 0.052016653766435, 0.04873696241467711, 0.008582058794526084, 0.06988392707200781, 0.05302283364618498, 0.02086001301875278, 0.05042143654258502, 0.018825701009782574, 0.009421453672280956, 0.07925864459285814, 0.05217456747026694, 0.04843195982938332, 0.03101625513555783, 0.082249574423317, 0.03596258417312657, 0.00974361758468853, 0.09813118996399064, 0.06770786198396837, 0.015022968873381616, 0.05063876802582414, 0.08366656129158313, 0.052354330001699353, 0.015100589859479619, 0.057037241621724064, 0.020203021760549278, 0.09858354190064055, 0.04864442665430327, 0.03369132116917641, 0.03709819843812335, 0.027686398431298234, 0.011846091309111687, 0.04966601639265015, 0.019541376518205773, 0.016919695321590673, 0.05391788098119921, 0.07855727577642088, 0.08318679106812324, 0.07640839914881414, 0.06072072259661171, 0.03990747349997682, 0.038784637581557035, 0.006863179179133788, 0.07711519186775531, 0.11259221802315406, 0.025002549199627775, 0.05715724546462298, 0.03792150929990796, 0.014466359073506489, 0.04431847370259705, 0.03459469971036719, 0.010522138158370171, 0.04266078583896161, 0.008049504155473364, 0.04542188929213632, 0.06540815030495006, 0.04064617761140389, 0.03387878671468746, 0.022006310379853653, 0.01509111526707608, 0.04964026434707546, 0.05180162820784796, 0.060184644910717205, 0.02350644077054195, 0.02968139480799437, 0.0517979663075699, 0.024940252844845096, 0.05019454811249049, 0.0333926503005768, 0.03344862451476436, 0.00498820819155944, 0.04893552091333175, 0.02237874785468223, 0.0323000748551661, 0.05148417669378462, 0.03727131515681263, 0.01746872755428476, 0.011268712865609315, 0.06406930057452091, 0.043533141649658644, 0.07034909565963092, 0.0746682763940865, 0.03877152598673298, 0.05964954398692616, 0.04163586744858373, 0.01360270506401937, 0.012958947017097907, 0.04411808425380338, 0.06752013213812344, 0.03327998174955288, 0.019330575934521133, 0.03316627514939154, 0.07723209688500052, 0.03627704794428522, 0.06009844852791679, 0.06483772889741006, 0.03287277154384121, 0.0422956261994137, 0.013483778532263974, 0.05486051769806974, 0.014751533388100086, 0.041091186595299554, 0.03406666977811725, 0.017778786319878795, 0.09731516076792633, 0.03249305623373197, 0.03025422173161661, 0.040568894661602475, 0.05069507548825876, 0.05427136544078108, 0.02032476462303631, 0.09164434812602498, 0.02034708267949041, 0.03717587209276615, 0.014212936230544603, 0.014794412286831968, 0.03242919897480357, 0.05734607464663925, 0.03394053340138447, 0.03117172884935093, 0.01770515569425639, 0.033662320910802776, 0.008905736688194017, 0.020597480432761293, 0.05524985507250794, 0.009295620857888173, 0.03585477261954258, 0.04365718277591852, 0.0473780565023903, 0.05620576809310625, 0.027024423771147287, 0.1144291283262353, 0.03843619398051693, 0.03689798518955227, 0.019251333714853373, 0.04777395541989996, 0.03618900528958729, 0.031803649880232356, 0.02551961258324164, 0.04325871746386251, 0.06702143954293382, 0.03975075106286714, 0.015865867645780168, 0.09050230255290385, 0.006356792188354678, 0.04925632023162419, 0.03826221541291283, 0.04103225528172428, 0.035588231478487296, 0.004172539056819534, 0.018692443845793605, 0.033958739480905, 0.03815001417552272, 0.0298506906631613, 0.01434705620105829, 0.10477150219582743, 0.020945676970445824, 0.025957883823843255, 0.027552746732028264, 0.022795857831595406, 0.027312470915456934, 0.06494888059434391, 0.01713970428212516, 0.026849139023632295, 0.017285601896864754, 0.018064661604923107, 0.028023555641993884, 0.019352374966406537, 0.010729016371882491, 0.03266996508764644, 0.026271332528502233, 0.048411512942684275, 0.0043754431892246495, 0.019390213964206558, 0.07680484198875005, 0.03524345360816487, 0.0006764487543184641, 0.055660508843439246, 0.03292246766748928, 0.0072956731591764246, 0.020368347365048625, 0.020897085928628524, 0.08814512661868527, 0.05614914270418306, 0.01866245916443727, 0.05875547724445501, 0.10176900443771195, 0.04871574944005378, 0.015336487483563683, 0.03359447233378887, 0.05656370735396782, 0.01544033548974943, 0.014822345767771045, 0.02870519003350168, 0.03086906666266582, 0.04082882446387122, 0.06979997149638592, 0.013490656086604201, 0.04991013797060136, 0.03445074412851565, 0.08202986040663335, 0.05633927423567061, 0.009591992505105033, 0.045770601023949926, 0.019294667478290298, 0.02652463950066557, 0.0686899790420167, 0.029622633948982246, 0.036308687375558, 0.04657713456019279, 0.015041012159218232, 0.034279852895246404, 0.04447514634399165, 0.027135523757146254, 0.06285415872210456, 0.024227453996577573, 0.037278075882744406, 0.02206608247492583, 0.015963125380597288, 0.06600486385005136, 0.03286124575102041, 0.01677645411672852, 0.017745526612646157, 0.11414440408829721, 0.053203883205330184, 0.037458593010782235, 0.03216556130698131, 0.030991370684557387, 0.020661402809163256, 0.02945637946287471, 0.03739103937761919, 0.019480118212560495, 0.07610122853469464, 0.02571649909500153, 0.011554977897885106, 0.005192162822030726, 0.020739128174740943, 0.016612668348956975, 0.0024124396018563744, 0.012524958207993018, 0.05937459886134152, 0.04410647419131091, 0.033416226656446536, 0.08109491904296222, 0.08450955678258212, 0.019622886358129404, 0.036291323992754185, 0.057308195429223205, 0.009296987367223107, 0.033731016014973005, 0.04256801642177086, 0.0016469051761011926, 0.030046811086996913, 0.03405415190143451, 0.0671330968578977, 0.07430351895069884, 0.0016258259077609007, 0.10891163286062018, 0.08880923291848553, 0.05256229606006415, 0.07991074629488491, 0.03256484633311629, 0.037461825901822704, 0.039751191563423605, 0.05633658143661677, 0.05381650839661879, 0.02954911632132867, 0.06542423815135995, 0.030744991062449354, 0.057511235542234876, 0.021157942697285645, 0.014607997239387084, 0.01192360121246067, 0.0220676701921489, 0.02676844315212821, 0.047063837879367416, 0.05064356756666976, 0.03790875393596869, 0.041645769135005055, 0.0695735312277271, 0.035578858392733725, 0.04279152257367969, 0.007195533497349149, 0.03562482749863017, 0.004597558412745956, 0.06195577890461972, 0.044596126948994015, 0.056703901444111145, 0.012901304646455234, 0.03498288795291897, 0.04623386588308119, 0.009905091682148558, 0.03639674535201442, 0.05384749665315594, 0.019718796735809698, 0.057846012134705825, 0.05061248354914208, 0.04079029407171954, 0.04878465138796357, 0.013851582132760557, 0.035933342597056786, 0.02065859701214058, 0.018287939845674464, 0.03277088951079115, 0.020482113337024085, 0.014884223647025085, 0.017079277181877725, 0.06037781015038491, 0.01481171725543156, 0.019704453654647357, 0.006413369217977649, 0.04206068618523498, 0.025958128971979025, 0.042459722232794574, 0.05795350959224086, 0.03581096005115298, 0.05783812908996498, 0.006435491443206106, 0.022395437080112678, 0.02418846395167132, 0.064007856492554, 0.03640161384077322, 0.02675800520415989, 0.017771351436573653, 0.05431754139041709, 0.03261572606260738, 0.0804437596290823, 0.03198451749349554, 0.0035332262350787082, 0.0838418958348132, 0.03448061006624372, 0.10299026350220365, 0.023392257280647758, 0.013061240822407267, 0.039670453557083686, 0.018299090255412365, 0.04894850993408792, 0.04030315025198845, 0.017908201552927494, 0.045686358165356426, 0.043465453951108846, 0.037022374885817694, 0.03918728573367961, 0.009777329283796493, 0.03943182099910994, 0.024040109109914592, 0.07121673619915402, 0.0628526073940579, 0.1597002668366317, 0.08495180401951076, 0.15725810110809343, 0.05002757541895394, 0.13950972847880858, 0.15749235547357993, 0.1813415918619402, 0.12538662180304527, 0.1267246403280766, 0.10291442079769988, 0.1839709128703802, 0.1402132729849508, 0.12315776559614366, 0.1194631303810785, 0.17843221975190027, 0.11849058942208368, 0.1354436708554145, 0.14636618475760185, 0.13909159768973628, 0.10522409161973385, 0.11637617142931109, 0.17693643307974263, 0.1484902248147034, 0.1524363896779476, 0.1556972735711644, 0.09672735682538441, 0.2264832921566502, 0.0964911106312948, 0.19694450461576063, 0.16451954210717834, 0.1580295056825684, 0.09004110996160777, 0.09050319121489603, 0.1327569851832044, 0.2331447484151971, 0.05706795408660847, 0.09675986959689087, 0.1212138787753159, 0.12533651965279735, 0.12799800869317787, 0.13536212845675408, 0.15877100218447948, 0.175677030497501, 0.09515571978784378, 0.11932344956984443, 0.10715454125836973, 0.12186226495090993, 0.10824716649949552, 0.18764442704137296, 0.14846693574180528, 0.1689088581911018, 0.18423185773914863, 0.0937658217885802, 0.4174638329254043, 0.15949118612033708, 0.17972370609641078, 0.13115154068556525, 0.14836794186022975, 0.0798075465906051, 0.22058438449617357, 0.12997106048128299, 0.08502918656074232, 0.10567897164653386, 0.20995465407688774, 0.12215767611539173, 0.13211463578045368, 0.14045851305127144, 0.10545453852823666, 0.11376289230200554, 0.10938347407406378, 0.11666225930375439, 0.1564861296285545, 0.18352517227251686, 0.11761947850426359, 0.12506252064579917, 0.20131567973763714, 0.10538547570186277, 0.14796822782485716, 0.11079239403648723, 0.10115261009383587, 0.10681597636111322, 0.15749390297118696, 0.2263329550623894, 0.12969615749053418, 0.19244451947029562, 0.19689432585672026, 0.16496626329758476, 0.14543627659159322, 0.16650893455070837, 0.14149555095261143, 0.17347042148392047, 0.14385101084987964, 0.18403492717733308, 0.162743397898251, 0.1209829109270246, 0.18090861428889538, 0.11672054327303365, 0.100085633476415, 0.21369889348505006, 0.19546882009073613, 0.09960104455991138, 0.10641777151895147, 0.12916243935544647, 0.13247144889206658, 0.12047861056822924, 0.19144661334012786, 0.254143693394238, 0.19627863631373454, 0.18083805759106913, 0.1019807051747076, 0.06932053835161271, 0.2425372315150115, 0.20499662496149543, 0.13350828761054626, 0.08494766714471964, 0.14782719103799713, 0.11924428970462854, 0.13086462543616373, 0.15225320273349363, 0.12374033715816275, 0.10662489871103918, 0.2524011651234281, 0.11611729499793823, 0.133105555188752, 0.1769986394191942, 0.08059719937943643, 0.12464028362545276, 0.15875405631959438, 0.13660522868796704, 0.14227567360766474, 0.12926048328799586, 0.1370484105521633, 0.10539287611121133, 0.15370682392629886, 0.18042260810973185, 0.22518549324764361, 0.09741935638650771, 0.10537523310631515, 0.28407428894312153, 0.1312530779790494, 0.10478928309654999, 0.08877181718426366, 0.16699146269069565, 0.1438476707065298, 0.09699341150060778, 0.06205609045742501, 0.12384672378820759, 0.12437275806141478, 0.1160910335038939, 0.0887231246357964, 0.14054339559328172, 0.12081594206392766, 0.14628280374792316, 0.1488983198519676, 0.18510852279441972, 0.13533215909715623, 0.08149287107610896, 0.1042366349288533, 0.12420424936159004, 0.2666300991850515, 0.12359710935983928, 0.1509881464223708, 0.14380392708605336, 0.0787787058300549, 0.1481465424501127, 0.12064374082030789, 0.09801008678492039, 0.18381282296632567, 0.13374059611270506, 0.10852844334177433, 0.17563650444630655, 0.10607903808235161, 0.1016367546793434, 0.07702446407488278, 0.23470923785240422, 0.1405732423788117], [0.026021947926511208, 0.021455931747632644, 0.032777696201998385, 0.026878970487403776, 0.03228229012400393, 0.038372382686863986, 0.05905433963503569, 0.02618922322477785, 0.05735375467808016, 0.02838738994943279, 0.03649025787449172, 0.03794705067130347, 0.0569624905925124, 0.022330338758746945, 0.06246696256341473, 0.05378336743301442, 0.01989683173897286, 0.012861467116782743, 0.02933355450119463, 0.027702022794513937, 0.031182095934186253, 0.03540226746530783, 0.03170640267912419, 0.018089756730102727, 0.04873986971834975, 0.048466537207845724, 0.03298685735752506, 0.06636182251836985, 0.03758924930626827, 0.012752909585082484, 0.025347614352921807, 0.03134366579263682, 0.02876051115773378, 0.05608820040980655, 0.03150759711711398, 0.03450078882216927, 0.013071831987960445, 0.07099568918948213, 0.020519795286799633, 0.030558992575313297, 0.0396430735746699, 0.07457335810026816, 0.028347072657197717, 0.07972385914575669, 0.04980251410855882, 0.010026108676327333, 0.0906268914320296, 0.030532198650161588, 0.05351592230820849, 0.07104428214651924, 0.027617779935920433, 0.019174240371813218, 0.04524596486120455, 0.045678252955117536, 0.040365977122658686, 0.033181796090737466, 0.05621449766500343, 0.05620639245476454, 0.015251835725540596, 0.036478391172544616, 0.00634662141354995, 0.04380919760273349, 0.03329517710353098, 0.0088048467390059, 0.017357794192409324, 0.04844364650066822, 0.05791184207003924, 0.013645546615964944, 0.05962020664986584, 0.08439335656622726, 0.029950013962544264, 0.052664293006302855, 0.0803974419531803, 0.0341383028294771, 0.0035542591790398287, 0.0430795984462865, 0.03985872732535486, 0.0410749072269086, 0.05166385878598498, 0.06469928148773409, 0.07318868482064816, 0.046904617995624585, 0.01916326424707809, 0.007421519380107883, 0.03997528760303413, 0.04219569386013093, 0.01878733724175442, 0.02980161315551208, 0.04191250945892065, 0.025112308531759248, 0.11687725421882446, 0.057649027946735584, 0.04358625452544901, 0.08715403101016438, 0.036779685892284884, 0.022476332134477073, 0.03443589351410347, 0.012872866505096036, 0.05311013702603598, 0.030937114422540032, 0.06252992349947173, 0.04319648431133359, 0.012818143887054777, 0.01350873384639741, 0.043758459599508394, 0.06509361758587823, 0.023967351824525866, 0.038321713631552075, 0.021140399283819625, 0.018768405293925636, 0.09091970555844808, 0.07469544953276074, 0.0688154948875308, 0.03376707577356889, 0.043705078592944535, 0.037011511759051395, 0.007889633575799845, 0.020674144766563853, 0.05856476348614501, 0.02422471140180865, 0.030457572110237616, 0.034062188163760214, 0.02161521291840942, 0.07687735987166244, 0.07017507112675136, 0.036394217261864294, 0.14608807951932953, 0.030107489081039548, 0.058783998697875976, 0.03365341130824339, 0.010567592070137542, 0.05009940382273448, 0.037589532758800254, 0.027063419561712976, 0.032588694650199146, 0.02464949949494293, 0.09433425136751707, 0.0034540678062776648, 0.07506860329979852, 0.05097740953187308, 0.027355400567513802, 0.03147555932012056, 0.07024937399452733, 0.01673292117043128, 0.02596543553555685, 0.05927833991365568, 0.04965181695297361, 0.019891390599490657, 0.061864066688764485, 0.019095111150114287, 0.0338558845161911, 0.08492414058456499, 0.05046782699683982, 0.03316508005222967, 0.028797798572228323, 0.017846694268706827, 0.09191814795016282, 0.0297497681552364, 0.050805300218804236, 0.03816076238910037, 0.03373116157167862, 0.05249482286613315, 0.12272399895253683, 0.046995763306415854, 0.036682871530853936, 0.00525033522975601, 0.047608001623302705, 0.028788571043180364, 0.037389518693089485, 0.01786049342744293, 0.013874541787851243, 0.03545043524354696, 0.018075450038116787, 0.011418400700354289, 0.026633983230098125, 0.022042040720642097, 0.04988873730443659, 0.025070966596925454, 0.03466186646912848, 0.04467962287186135, 0.012118511217375918, 0.055288864269612305, 0.04353408393780551, 0.03316564695729363, 0.06320431836009507, 0.05964732616238537, 0.022514307112883658, 0.019889391110008283, 0.026400207669564316, 0.031474090346525756, 0.045698155919390346, 0.051297186122786616, 0.07453645564495556, 0.042519247264511166, 0.02288132451564795, 0.023241449042313525, 0.05818925782917969, 0.04513552562604028, 0.06207749112358978, 0.005982198654824207, 0.04623323386054366, 0.031430319912971995, 0.024734188599752325, 0.06350600378467672, 0.0180632998836377, 0.027964352367205486, 0.04748668777005327, 0.028781034653225256, 0.03797269929500838, 0.04803578895066054, 0.014511842671180926, 0.06469209558300434, 0.04456375207331392, 0.010505605980964198, 0.03754896840320961, 0.013678791959049, 0.03238355545627494, 0.05669731308796233, 0.006012448594124327, 0.0437367869721305, 0.04361640391570907, 0.052545445956169605, 0.04576635306640979, 0.1109324502308042, 0.016436144454224456, 0.032322352692004175, 0.046984371578981804, 0.025645159072272723, 0.04105986126007573, 0.03841549428480287, 0.009500091640098442, 0.01134974007014065, 0.0340466327484577, 0.07733152743669287, 0.053693486167298216, 0.050065098405485196, 0.015877654866105127, 0.03460708352166318, 0.046448546702102314, 0.02456474910309959, 0.0453846229450597, 0.05049192046205844, 0.03673357506012244, 0.05924393107453662, 0.0339122073003842, 0.06372763302117106, 0.03504126768318876, 0.05746291071597127, 0.054811844301800576, 0.022422736623294415, 0.0656170548210221, 0.028603250543857296, 0.010710321911310237, 0.0826716122608031, 0.03226713690486166, 0.024118152401980855, 0.08192475314342207, 0.03217646273814383, 0.039835036056296486, 0.0643870470324351, 0.021192322808107542, 0.022958092271320285, 0.03251695817696952, 0.01002624944498342, 0.0703580052621903, 0.021631938533016273, 0.07622051608538435, 0.007542851427945519, 0.045064447988425536, 0.016997056795404326, 0.03137585872243489, 0.023729847331020622, 0.020445643721388716, 0.013456026997206914, 0.062031974009568655, 0.050952641909281095, 0.11192121693203527, 0.03884863656675143, 0.0056602674416236344, 0.03940784244707996, 0.012200592750413044, 0.05506003380662972, 0.03833241971029389, 0.08515715388761413, 0.02807552321633745, 0.03261124827868996, 0.07004803842714719, 0.023993984871213476, 0.01858243361986693, 0.07296035997569561, 0.03666706713697603, 0.050133544531080036, 0.01351096028942735, 0.01862132598856284, 0.06477564513202637, 0.0688684698674948, 0.024583870657689633, 0.02718831487600842, 0.03414302959196991, 0.04120062608572264, 0.0574593905419592, 0.028439932089719563, 0.11294177628212398, 0.027433384487765933, 0.0265190968545334, 0.01642083610227752, 0.011305597126333704, 0.022662746224312053, 0.038717248657297705, 0.02856570457468831, 0.008132602670229971, 0.08835679671216397, 0.03533127409736476, 0.010949103856429217, 0.07473344749380505, 0.03823339135476178, 0.00830830876610332, 0.05140125916730012, 0.03861632040371338, 0.01411974642260541, 0.06351532324427558, 0.025495013499992992, 0.06396266496590068, 0.007876646949068434, 0.0726461336917935, 0.022978937523739956, 0.04167431357106374, 0.06894246630010105, 0.02843500422914663, 0.06706500696318765, 0.046206830640233336, 0.0070972123367321355, 0.10911643880629733, 0.037169800845966224, 0.024484731219408494, 0.06876979008196824, 0.053806518610086174, 0.09321868945393832, 0.045617115308320334, 0.047981580569138454, 0.036386847496032715, 0.03654592948394918, 0.03524951336364593, 0.04788007008873167, 0.03470184859789668, 0.11562820148443985, 0.05018632415862334, 0.031292347477809075, 0.02048393279584425, 0.037743968423455954, 0.012722609850067287, 0.04772877538456552, 0.1205727780958818, 0.10557060084876516, 0.12769888966314255, 0.1014544870403986, 0.10724296312659018, 0.12264142233517863, 0.1689188632993929, 0.10026579437356803, 0.16808600315163214, 0.13136057543658441, 0.06798979766186207, 0.1579199551093963, 0.09624483634627636, 0.13461821111700228, 0.14384759409773734, 0.11287513429359083, 0.1652019732301274, 0.0908011764348034, 0.09676968318320091, 0.1164938655171183, 0.1471327170128784, 0.14461673105195647, 0.15060281951821622, 0.1477851787762296, 0.17823833822002336, 0.1573802614884992, 0.23879484603962592, 0.12871377230171235, 0.1306489410419618, 0.12346279116407519, 0.12287059753772714, 0.1511736163088391, 0.13015121371755678, 0.1724380567189186, 0.10400008229959397, 0.08778924047346078, 0.12810938255560975, 0.19635610312463778, 0.1644684593643873, 0.11334937336223741, 0.14441563297183285, 0.20196778910054317, 0.1431924357048927, 0.14565231338624032, 0.11486350784018157, 0.11317357150537354, 0.24025655712091157, 0.12677691050715026, 0.11412110735451984, 0.18429403343508322, 0.17587276596215465, 0.16016146708880702, 0.08990529023351208, 0.22735395108259496, 0.1556498833721684, 0.15461174230421745, 0.1641314726082548, 0.134535442977663, 0.1102226467863206, 0.17975620354615873, 0.11954006859131398, 0.1452784318356745, 0.12851774572364746, 0.17467656563366615, 0.13974139346711098, 0.10366465070194776, 0.13909064774071017, 0.10553466366423715, 0.3122733725655464, 0.16582368422419796, 0.18721313486176153, 0.1666986025990017, 0.2562281267056542, 0.15188863681208703, 0.11365437594753121, 0.1362068476455827, 0.12275124103912424, 0.1305868725983366, 0.13484668917953968, 0.13876872227316903, 0.1919031404559651, 0.10804960008470282, 0.13714478441303776, 0.2969084680080414, 0.17136913423817005, 0.15738720224509317, 0.13548278730482827, 0.12516579695887145, 0.16898031887267867, 0.21396140117318402, 0.2593954712633164, 0.16565672302198026, 0.1815298656302114, 0.24776089395726883, 0.19290291584066807, 0.09907235196160694, 0.11661793345645552, 0.13283143360768596, 0.19641313070972122, 0.11912107212288726, 0.1560485095626885, 0.22986324143505868, 0.09687277563517133, 0.15239679825402078, 0.0817162546539499, 0.22424936444768984, 0.15720007760870844, 0.20683171197531686, 0.10378021506532546, 0.06766404941557877, 0.12859113694679353, 0.17271767881128097, 0.19814517889772693, 0.2504454958703249, 0.1497825844994476, 0.21861982862314872, 0.1730234091801028, 0.25655855574915487, 0.09315737943735816, 0.10273157093193262, 0.101670723017906, 0.1503403577953577, 0.20301959717706328, 0.2069148325151013, 0.2603829892412309, 0.2410175582213748, 0.22736780195226594, 0.11813538509511179, 0.21721021152071415, 0.14415775245476153, 0.12425299553621201, 0.12451003335656659, 0.08721149526536466, 0.17324971155293528, 0.18023416580211732, 0.19160260416326985, 0.27110671864882596, 0.09629364380793226, 0.22981289413667497, 0.19158735901357668, 0.18380415085102284, 0.10718778181340426, 0.2262676690494822, 0.1089639490049693, 0.12490015597112718, 0.12767268179525293, 0.13332036624272026, 0.07951271765294575, 0.13680159234471861, 0.1332090383455638, 0.08335211284218297, 0.24155585756224973, 0.18130250605604342, 0.14374743576251692, 0.08629287157448069, 0.09780023998070149, 0.1826895542082287, 0.08625683479852254, 0.13617485581386474, 0.17722239838011805, 0.16903487965464595, 0.25088728345449895, 0.17444084037936505, 0.15262818745067044, 0.1123102900061396, 0.17836302669057924, 0.09754911635912235, 0.0994089403520188, 0.12114485425333824, 0.1288441451446664, 0.1732430925532695, 0.06588434289780355, 0.18454014684163755, 0.09451954505376278, 0.07948502357448302, 0.1434527523815632], [0.05691347628711693, 0.024825303267026623, 0.06550129127478407, 0.08275150757042632, 0.048027465405363234, 0.14722818689000222, 0.0854641023362356, 0.0427126155174788, 0.029372360684999058, 0.044431935154622605, 0.02134355622523975, 0.0962098184672575, 0.04230343263536211, 0.03331584998616769, 0.007573315871864438, 0.027234343353719003, 0.05659111031901933, 0.0183842696564933, 0.02167235350146169, 0.02992463346961285, 0.020877104440343477, 0.019466786367458203, 0.04024098604737271, 0.01921791504437645, 0.02180601094639109, 0.016972089989952022, 0.0055924509445415636, 0.030390600703897017, 0.05788291075957879, 0.03185200151957331, 0.0015986522902817196, 0.04976240940572274, 0.036403525230144305, 0.06691790275996731, 0.03987795230181467, 0.028149565614219156, 0.047465685469609116, 0.05106177113409485, 0.03440201327565216, 0.03288593293438035, 0.021551727212124297, 0.042354002099243865, 0.05756635939882648, 0.015898912848394006, 0.017721348877755866, 0.03859990696993567, 0.03259780343561884, 0.0528690108518687, 0.04108870447042488, 0.02387932257636661, 0.008073966300505544, 0.03796945874308867, 0.07098297979081832, 0.03621115672191785, 0.10137862901413634, 0.04188356282670171, 0.021631882991641763, 0.02351572384096442, 0.08408586419517956, 0.06505637805187894, 0.029127158923074607, 0.01974044446533005, 0.0449616389889871, 0.05185351151251986, 0.00808905631739406, 0.04089658877121345, 0.050958816577950795, 0.022062275017942154, 0.053064688859928044, 0.04368031097035255, 0.03861392254851038, 0.04951494768442166, 0.025895687060490735, 0.03087548073381186, 0.026924037524769386, 0.09936557977550453, 0.035301975064700654, 0.02246787260857321, 0.03617497821969371, 0.10591027657351187, 0.0498414735099481, 0.0362369011066133, 0.014348033920771653, 0.042118276844942765, 0.04037072303734961, 0.03368320446761866, 0.02677376746320196, 0.04073381423950195, 0.031590392069530585, 0.01820984101223369, 0.023939012316986922, 0.032803295029988216, 0.0014338964636760555, 0.0299365078324392, 0.0645214035325954, 0.03251719566422605, 0.03037427153979098, 0.07897762822047358, 0.05951941246166826, 0.04448402913347368, 0.016123195621936072, 0.0357125637181584, 0.1175251424372677, 0.02606690962678723, 0.02385130674097567, 0.054297439243283965, 0.037134836593102065, 0.04561179865812583, 0.05891364375730196, 0.029814646226323904, 0.010939370709351234, 0.04259181111269901, 0.04130890495294044, 0.1201849460842148, 0.017959253652201548, 0.023811571675563054, 0.05026275292038918, 0.08966828561237744, 0.043513997112430876, 0.009999893147558456, 0.06851330384491913, 0.0261819836938934, 0.00986678824354444, 0.1732770608918321, 0.03921473466400658, 0.09129609221652632, 0.015088179235106275, 0.0065285333004149225, 0.043698425119322155, 0.03079810202301991, 0.0603487256223396, 0.039354446118757616, 0.015989170454803015, 0.03447503677659458, 0.01728733708601325, 0.01789286064224378, 0.025943324322842305, 0.011673551071585428, 0.060742092619259516, 0.042037577142999064, 0.03545004070826596, 0.04065138317884938, 0.05016846281866874, 0.0799418647863692, 0.09308865368967095, 0.022068855713211724, 0.024805040241429405, 0.01923917781471485, 0.04114897260742803, 0.05030377309829478, 0.039722539875055515, 0.006195945804187608, 0.03831203411062879, 0.025234361659855615, 0.033423868383491234, 0.027468927137012926, 0.021562006196848327, 0.057126965839415796, 0.027612202815831672, 0.043269021346444086, 0.04221029549596771, 0.04291238060461418, 0.008220553394376991, 0.06358128341455614, 0.05281497484012958, 0.036139041035165714, 0.054520945395192796, 0.08446646433684134, 0.02659141555458548, 0.032695927807400306, 0.0703909010776589, 0.009263912478702204, 0.0712102167909184, 0.03072406345557782, 0.019526642732202046, 0.0139611212146138, 0.08830654134433116, 0.060303503452169324, 0.03390029463316164, 0.05903372037855368, 0.08770231247669266, 0.12061591650689803, 0.04665330285206438, 0.053344793587682716, 0.014037915783363485, 0.06320157576532615, 0.03640504208423438, 0.04183979622358757, 0.012978424802572738, 0.08123872906810815, 0.06915614354394137, 0.014380466253046068, 0.02002403680836001, 0.12038721627886258, 0.09694431292554063, 0.018878404028533448, 0.04599128414185778, 0.05781469062992162, 0.09777555662778117, 0.03970964278485026, 0.05988179503249065, 0.02903288605833246, 0.06957076565032044, 0.020784373327548948, 0.055022893864060604, 0.020411089325564045, 0.036229803301994844, 0.06468625799302133, 0.058332998906412435, 0.00524827158040998, 0.01116193840355282, 0.05692969436847395, 0.05867362074974564, 0.04582264520708592, 0.06462359966169443, 0.06414624644563564, 0.059534806998506676, 0.02389217561651622, 0.025904054655843688, 0.045561619899085457, 0.036450532385178154, 0.049964399978278146, 0.029141563291270888, 0.03609022591263056, 0.11656883488138838, 0.04373301398910342, 0.03021951603342689, 0.007469713971424367, 0.05234269695656915, 0.03632452241295288, 0.0677612200078945, 0.021626943639749964, 0.04595826958276091, 0.07676158866454517, 0.007082565214424845, 0.017588260253110242, 0.03432328241967386, 0.021982822124095216, 0.07900755161479597, 0.035543530248105526, 0.019306384793092168, 0.012633439130900849, 0.025130876587823998, 0.10231419090902615, 0.026109703298237537, 0.046258694792707125, 0.038931492806201985, 0.06956555625243534, 0.02059056457402485, 0.03383384799704917, 0.04240443366729925, 0.0934866440272139, 0.0444622875581826, 0.01117401386445929, 0.089501332071039, 0.058351538234180024, 0.08257136965591101, 0.07340056941874566, 0.015807304054408545, 0.03217918618071464, 0.027863918240332318, 0.044884700778751604, 0.04137648156874123, 0.03177807978053968, 0.017614981399909142, 0.0433211229861744, 0.019456980442027413, 0.0408608929043816, 0.02495164648749896, 0.04831951344385744, 0.059529927018429005, 0.0691473258719329, 0.04460528553012879, 0.018966996351317055, 0.029011510290025227, 0.03427564324210248, 0.0818334814281233, 0.011373152674716568, 0.09816405513594229, 0.033766466733669086, 0.02023722567114859, 0.07338651936621436, 0.04985322146826694, 0.10917085403155898, 0.028925765899100134, 0.07528441792894756, 0.04498623424179612, 0.057035529415213296, 0.02552289143955756, 0.07445637647423052, 0.034716584299120216, 0.007516933715857206, 0.012260890573323255, 0.0714358143628605, 0.04692274363591306, 0.03664233398834064, 0.08592179390571772, 0.057427716636729825, 0.023644503221035968, 0.0711265676504662, 0.03553652437403798, 0.052957850238007885, 0.06198327763066177, 0.03944760241035012, 0.05284870569143565, 0.03159396203925773, 0.00727389136426932, 0.02890182565146637, 0.05597890647608907, 0.0237407430165237, 0.028359801208059636, 0.04288668984607343, 0.04957404753734028, 0.05124640981516531, 0.04713013512833465, 0.026474171543433785, 0.08122847115080203, 0.018906749281731826, 0.02922613365245202, 0.0934999586353379, 0.09507306656169315, 0.017515022247549028, 0.009150955687096764, 0.06247712855016994, 0.025339604903673454, 0.013016151760013835, 0.010689892261589487, 0.04423141164044219, 0.029438219348629637, 0.026301319125078382, 0.03918979850207125, 0.0059627519916713, 0.029182684975826455, 0.015427000771817422, 0.0057381297454177855, 0.04017115713307454, 0.06678350029453155, 0.05039495288304264, 0.011447762935272148, 0.1109494727044817, 0.09441571715738505, 0.025832205184645234, 0.026400512189514218, 0.09206497636173042, 0.048718917213620684, 0.02856396555510019, 0.03586547103740516, 0.05892167618918804, 0.031637937401331244, 0.011424198070721281, 0.006799199346137504, 0.022904289916398066, 0.14619496410652516, 0.14904318707844905, 0.10824554239309604, 0.15401030199662333, 0.12353663437909658, 0.2599290974678532, 0.14441667485140985, 0.13231582579112824, 0.11421644699669654, 0.13044788892711365, 0.12619707387902085, 0.23634917162839444, 0.10253547540595455, 0.21899093693542868, 0.1554028813036219, 0.1306814231699513, 0.17019101358469457, 0.12725456632793913, 0.13788657202836008, 0.20004294722551302, 0.15793726869648503, 0.11088880620175794, 0.16381576777465884, 0.08679075977734982, 0.13623405908865316, 0.10168129503126107, 0.12114564332390025, 0.17085648352100005, 0.15309055215649067, 0.1330647686676633, 0.14440732857873365, 0.15247967364566942, 0.2928167924044594, 0.11266454438408537, 0.10615340989804077, 0.06973971868114126, 0.13000993178256098, 0.12346290607726383, 0.17910930358113783, 0.13893131677421833, 0.10361965069727552, 0.10503192612480734, 0.08833278751661701, 0.13773018283949745, 0.10881369618038017, 0.19058625063588544, 0.1750746862061562, 0.08190546304948869, 0.1712357736523113, 0.10087265858366605, 0.13413346132203458, 0.08092395886177979, 0.15308865225843846, 0.21494654427853324, 0.23145664303052813, 0.12219987223826109, 0.14481956049078895, 0.14612022456863236, 0.16379293835451528, 0.1441564194617733, 0.1142729229984745, 0.2130860997544181, 0.1834606063822585, 0.2977097959768388, 0.11646810198022474, 0.1263790657263129, 0.16535565046773804, 0.17269840403910608, 0.11920459868927157, 0.13645319087851432, 0.18539818063859018, 0.12337970126780773, 0.1210043537280252, 0.09023361253522097, 0.19298623556331282, 0.2324604786812298, 0.09749863116491227, 0.17420130000720102, 0.2502229473283214, 0.2397031658479283, 0.14430438168346882, 0.1788238745423094, 0.06746526492098648, 0.16141460307182806, 0.07204434864463345, 0.14197124558831417, 0.12045735162833046, 0.1100601748593392, 0.07826541925990775, 0.13928489699479074, 0.06900016038167862, 0.2890473640253467, 0.1699337459379627, 0.11660377615161481, 0.2364425117810888, 0.18329039696724186, 0.1719864172440383, 0.23262022333520077, 0.18081761836524934, 0.1981276508060194, 0.17906007477112357, 0.1506873496597813, 0.22306942050495457, 0.10283154540605123, 0.303387641305885, 0.1181541236057397, 0.09885411649461716, 0.19717446888887113, 0.2214805235064799, 0.15116037830950754, 0.18957415655736, 0.1563241633196031, 0.0978964759457496, 0.22997135176293312, 0.15237042950766702, 0.09039864319586947, 0.1907334314478982, 0.1705862230230724, 0.15989016471130235, 0.20841878568453176, 0.21161154903952153, 0.10437357314531842, 0.11638123527049057, 0.2630162172980847, 0.10064261004088387, 0.18079068271383164, 0.18768628608555565, 0.12031703496411925, 0.15195190035287412, 0.17549882312455486, 0.0861582852479431, 0.1471886107878339, 0.13630164336533318, 0.11209301980993441, 0.10739645650309902, 0.16013653858775095, 0.11960381476749336, 0.1297917346199674, 0.3671241341339004, 0.11335723342434054, 0.14773287029275972, 0.1263349467227536, 0.11315058120676588, 0.264864235876068, 0.14661787528424494, 0.09774271443846727, 0.11200361734917087, 0.20671897447637974, 0.08620074950158597, 0.10732260562719838, 0.10322799590686638, 0.1344043959773356, 0.14895573048101318, 0.10803894380167609, 0.10345488816740052, 0.07728789106852586, 0.12556613152546267, 0.16644816845655444, 0.16697817872608864, 0.22476808258122016, 0.15618360150725613, 0.17170828136224903, 0.09169341605757514, 0.2612278616476444, 0.2980817776293524, 0.15683727368952768, 0.1639266206973022, 0.21529768833950644, 0.15227782479938, 0.13157645901364665, 0.1618871567470412, 0.10479563396544227, 0.14579931033715127, 0.13668606628573712, 0.05440146632252201, 0.1328112548517604], [0.043729608728279995, 0.016166136765311805, 0.01702957339735041, 0.08338218945409022, 0.016447128239838828, 0.050798233057702744, 0.04570764774877218, 0.0059929597961355845, 0.03845410894662623, 0.07296863372527784, 0.01726251583726656, 0.07969619571081094, 0.08228968678703232, 0.009016238168002138, 0.07817086868829305, 0.019182316853754947, 0.0242989759651884, 0.00408978145118923, 0.005878822271516848, 0.02309388901677824, 0.016134598840688987, 0.020722224444691694, 0.019204906871422164, 0.04383401119060094, 0.12119901666958487, 0.022281881782316396, 0.05633000840222644, 0.015061710897322386, 0.06332426857683929, 0.05037726008243138, 0.06263872713691766, 0.09690433079677244, 0.05137651452734586, 0.008996740272719293, 0.013157920160841559, 0.022405400053567948, 0.04063100907050314, 0.03734799672759349, 0.056023125071078546, 0.009898416183498359, 0.08503077236274559, 0.02024580202546091, 0.025128158890912612, 0.12061055389142807, 0.043271197036149046, 0.032256683635134856, 0.06976322991953743, 0.033936687640004584, 0.06684188385524097, 0.00965726511147354, 0.031254121605607296, 0.010895183715488642, 0.027479552776522698, 0.05372888709027922, 0.05014585556402322, 0.05449123267504958, 0.06202570357990842, 0.03547498836152015, 0.03022459328114506, 0.0163801874770152, 0.03478847015949507, 0.03697194714820193, 0.019368707960952195, 0.034279174907433416, 0.054583128752006646, 0.019459422347286058, 0.03867997847978146, 0.019544088469457724, 0.11526562739163639, 0.008999674389469288, 0.03890476016808422, 0.0449182209558785, 0.029621536528030713, 0.06307959541558258, 0.025641183075945706, 0.02055752894751007, 0.07275723942345189, 0.06681426638557066, 0.03643775786904078, 0.07050837299996807, 0.008520225922937595, 0.08981948072511343, 0.01936151248012339, 0.04561836403163691, 0.020773092682863918, 0.08257406628540448, 0.013715823691698813, 0.027037468333277973, 0.030790358789325244, 0.008989878997747457, 0.029427802468079235, 0.006758341483110863, 0.029529709398986834, 0.021923028961605123, 0.02268406836646459, 0.02678860850151508, 0.03599521951870092, 0.03404953622169072, 0.058651634026318795, 0.006944712480500101, 0.06575423818562301, 0.03396118713182307, 0.04234690429462541, 0.03657004976224515, 0.04226693620664939, 0.030443700173148708, 0.0331608627382065, 0.02595779763895177, 0.037733063161853826, 0.03220256718416368, 0.08988846694269488, 0.03905641493357478, 0.06363235849646792, 0.01581866609593553, 0.029166409437875115, 0.1065314589669147, 0.10288509495195844, 0.034471926459622, 0.04249338413618746, 0.045972028521880995, 0.043685087528560436, 0.040870825234319896, 0.04710967675031674, 0.03048268255717572, 0.026551065703613624, 0.06451591068217832, 0.024010063141524315, 0.00953393165893372, 0.0171829690976489, 0.013366874472628678, 0.018737972451133594, 0.10204255911371402, 0.05894763124806266, 0.07674487262603737, 0.04382410184330037, 0.05791484896514205, 0.01741216536761532, 0.04898929262473699, 0.030044616245093848, 0.03205111734719286, 0.027088654497938774, 0.054528943353122285, 0.025992217969389695, 0.020043372867568847, 0.056245443786704735, 0.018934336107885166, 0.014229620667925526, 0.012391732645130927, 0.021580269732963175, 0.016101224220267708, 0.05466735245840204, 0.0053446655510924765, 0.02145026461221278, 0.043022015447457956, 0.12698986762834172, 0.030446915827210874, 0.0319924388426326, 0.09174766274349344, 0.029526133683600256, 0.008271797015632113, 0.03625138399882182, 0.011777465152854641, 0.042376988567411907, 0.0672124712277324, 0.01704318294932525, 0.06552526216593481, 0.05122018279507757, 0.03867842715173479, 0.031670584238224456, 0.009354263930881937, 0.023188734532243783, 0.00764647487460846, 0.021174436570295406, 0.03172713493357503, 0.007965200488650872, 0.017416627829774253, 0.03362804230663084, 0.035637157683771466, 0.042459243427841895, 0.10675455143134441, 0.021741364616900686, 0.020485897811370033, 0.04550319420354021, 0.05364006685633814, 0.09343700919059977, 0.07519409616267489, 0.02346374860574161, 0.10792796064408557, 0.010659752447428483, 0.026911586680780017, 0.06332047644161409, 0.07171967292144414, 0.047837529226296374, 0.037593761564142285, 0.017446095401781703, 0.01983497013908721, 0.02614917980897571, 0.04106197183230712, 0.0641346593657809, 0.046271488461042606, 0.06525967480434526, 0.026151815151435234, 0.047885072642877224, 0.03197873352966722, 0.03905764067425363, 0.028718705739705797, 0.012862193942700904, 0.04906000254014808, 0.032497331004349456, 0.028806825003196156, 0.030885989544913176, 0.028623793191546877, 0.05514761297813347, 0.014524463969733448, 0.06886776506660447, 0.04551101596124711, 0.05354123385322671, 0.04242499163674732, 0.060477953163846854, 0.05791777925145242, 0.04707885703312294, 0.08424155624403108, 0.07799174967071704, 0.06309717713344483, 0.04194665016726621, 0.021912736570342414, 0.029921088397743243, 0.0127804207600533, 0.004355792555161902, 0.051474661881765055, 0.0578566569264137, 0.05228588770654413, 0.024626534094192812, 0.019620030765391646, 0.08167511573241604, 0.05878330921874412, 0.015129169727104808, 0.022769433543867162, 0.058985824561527664, 0.08236409690711768, 0.015401736149684557, 0.028783221834249077, 0.07460730345619303, 0.04174949743995263, 0.058253049970634525, 0.04542810226520223, 0.1248340119397448, 0.05806365771399391, 0.04325466485874307, 0.059454678032066555, 0.025403647938923492, 0.03235155213323813, 0.026923665972126108, 0.06907728245301593, 0.03768243624137775, 0.024036016285179124, 0.037589111410441904, 0.04632557809893643, 0.0878530326149156, 0.06193084657312401, 0.043419913854449994, 0.059257984957507545, 0.023271221134270874, 0.043942722897495956, 0.02929225470119667, 0.035393166340767376, 0.023128598545407577, 0.04996926846703695, 0.021866595094663002, 0.03918109191281181, 0.03469114251915486, 0.01575704389852622, 0.018479890835982178, 0.06285339263418029, 0.05612547058732279, 0.007887821777858923, 0.012631007759351165, 0.029772536288346016, 0.0773073880061988, 0.009782529105582546, 0.055069675023156794, 0.04088202543977288, 0.040620513665940494, 0.012328158838734513, 0.0029793844066349972, 0.0421852903861192, 0.057496067001334125, 0.015563350058190767, 0.03557938316296186, 0.05730973143551139, 0.026566883504030206, 0.08925724879748399, 0.05838326959600372, 0.025205171794720718, 0.0051585320409597655, 0.05247383205700786, 0.030908284618729548, 0.02818898849880263, 0.019044271640239224, 0.08149271019764485, 0.045813115073307875, 0.014363372916235559, 0.023881582535743236, 0.05453167828701196, 0.013638262077414942, 0.048658809955081636, 0.05524611273299783, 0.019098573867532036, 0.047446261310288985, 0.034498984685107585, 0.05248147378405256, 0.07983193883011419, 0.0194961371110572, 0.05470992013391468, 0.07099015803466882, 0.05820956682005237, 0.04499821202649225, 0.019594397463445223, 0.04874255485652436, 0.0628768042811463, 0.041280693765128815, 0.05657955388268156, 0.042418426263236234, 0.01812491825060739, 0.031215562485158447, 0.020314261557594426, 0.061513792137585344, 0.017150910233237573, 0.011185019675101484, 0.055743299965416236, 0.12569628986379794, 0.060391051980156096, 0.03137300312969714, 0.045658093351390094, 0.051332529589173295, 0.02204196411184967, 0.11877362826658834, 0.06768049732331308, 0.008934212176339522, 0.07480508437560451, 0.019375970474474372, 0.018144353901246385, 0.0566646624206295, 0.04396999945803996, 0.04289682901975128, 0.042402012829458526, 0.04814172741926966, 0.01395135646640894, 0.017014458482604355, 0.0581277639514977, 0.028318233277288177, 0.019572818681838054, 0.07784951778669512, 0.22474027358956877, 0.09870364150453, 0.21475594160297226, 0.1599850676833622, 0.15273923955617413, 0.11580912846951716, 0.0946348949125217, 0.16849449655461698, 0.11649451669185393, 0.20669908683386543, 0.26454394983668483, 0.1730773111264552, 0.1119399247991462, 0.18224100972856247, 0.13688708775706832, 0.2295358001344627, 0.11745748921267449, 0.18693948825520856, 0.13447878311478323, 0.1775903044448745, 0.12454266870214094, 0.15397749811170564, 0.12007715751326854, 0.18135273078035924, 0.12129642474915713, 0.12097774749441494, 0.09076707020041444, 0.15003036797767685, 0.14282868183668584, 0.19310372280738047, 0.20582225323925096, 0.11139232515087051, 0.13634662804824693, 0.11031382657106846, 0.1213486796064723, 0.10507781479147174, 0.1342109434546963, 0.1308117347258714, 0.19566739008070963, 0.20452223267526398, 0.1291973116777597, 0.20910932201771967, 0.18328838981688025, 0.1745486595938283, 0.17684379772793862, 0.16191541006968868, 0.27964152035213286, 0.1379383902155584, 0.09626018108739968, 0.14224018841501207, 0.09982971414442986, 0.18173755206648382, 0.13198576446983123, 0.10934291737935237, 0.16181943457453482, 0.2240401151920519, 0.13757544840055128, 0.17540911422862163, 0.20267980653912793, 0.13477476884520825, 0.11843714712848587, 0.1256800181562862, 0.20277333055292407, 0.1836319342856446, 0.09543508141031189, 0.20323088422657984, 0.1121399273735381, 0.17312136118210134, 0.11591622756133158, 0.17046489001762483, 0.11360533865949801, 0.13140529964960393, 0.16708230539675684, 0.1158579052876561, 0.09163379143442839, 0.17752411444821667, 0.22696350671110616, 0.16860397051899664, 0.17943645376832257, 0.1698435927110334, 0.1516791577300718, 0.15875008798414664, 0.12455969117581846, 0.12286831459571278, 0.240437614340936, 0.13438423254316853, 0.11641318879781232, 0.0988158580636786, 0.10577736797952846, 0.07326567665703836, 0.13461537659168243, 0.15829048119485378, 0.09163426640894144, 0.14476722136380213, 0.09390108227249115, 0.11534744558194954, 0.3192320556169556, 0.1489314148502965, 0.0853125854665714, 0.11972475706809953, 0.12129294670998089, 0.2119364316064504, 0.11877120742874762, 0.1515968492434871, 0.10923355832816133, 0.07923870332418911, 0.08573489909571025, 0.12285358272492887, 0.15282951535717135, 0.25663154860658033, 0.1111216433045845, 0.20810141077926084, 0.09126349517534818, 0.09673838083061481, 0.23811434545824606, 0.26791590115716385, 0.12494857272794171, 0.11412181981628942, 0.1635846390479034, 0.12105136088305905, 0.10911814718236847, 0.10863600208634332, 0.10478467124724582, 0.1182471190188681, 0.15307524571976355, 0.1265566066027649, 0.14341329885346277, 0.06477560682763016, 0.11075432712752974, 0.14255802297303755, 0.267905083995673, 0.13968533115281215, 0.20488430115003742, 0.08854096424916098, 0.1411043098496814, 0.12080755340115679, 0.12224517867810304, 0.17264175949798477, 0.19897096039306736, 0.16999973675176022, 0.16645342381971498, 0.09301892436680295, 0.14069005546550598, 0.16931114628189997, 0.1620513600327315, 0.1116897741092309, 0.10239204076389152, 0.14714361078316165, 0.14687652188924052, 0.12092514789753384, 0.12056401405002802, 0.0963936259429301, 0.10859520024349613, 0.2782704068287727, 0.1326783079533808, 0.11594337771736807, 0.09802486462097976, 0.17669248004113475, 0.09459126620523392, 0.14343790559759065, 0.19267673604190352, 0.09608712182530472, 0.21939846506762892, 0.16005170201101612, 0.17045039563409745, 0.14721635849245135, 0.10250277877334626, 0.11874826309541542, 0.1383984566576058, 0.13509726121781335, 0.1395040441064104, 0.12228155253274788, 0.1622653590335, 0.12766895860794092, 0.08633542775867448], [0.015560380509874273, 0.05676131973403597, 0.010594685727189626, 0.02004097118192623, 0.046924563094733224, 0.02255823842490152, 0.06837697849879343, 0.02355442851811888, 0.04766330551055651, 0.013632332556881012, 0.03895663964231649, 0.00876991504487852, 0.0727117108181119, 0.015089088006906453, 0.038624927401542664, 0.03838384336221122, 0.06671903399570335, 0.06209654756070626, 0.13550207739876163, 0.027862309455691327, 0.012947145432624365, 0.04925421348983242, 0.051606141721769694, 0.032998486572215636, 0.012374090597844653, 0.027538652629441315, 0.04119942332768152, 0.10752428593414445, 0.02150008330992874, 0.09311209598015394, 0.062161684186468204, 0.07267655504326667, 0.0861459359106037, 0.03924145581080549, 0.02532945806911636, 0.05634376351090689, 0.02605475755708833, 0.02965754840613133, 0.011965596237249914, 0.007477622392827706, 0.04912818819584866, 0.03418558194572407, 0.041793558986917625, 0.014105041364898846, 0.08627238638338544, 0.03145751794950376, 0.06137954672017406, 0.0040553457989928226, 0.053466892681054534, 0.03376659313817659, 0.04325382599246599, 0.028593931084258423, 0.027304783223136782, 0.08116603498497317, 0.06507732289572878, 0.041038253750171394, 0.035102972235049934, 0.06469904400047756, 0.030704150915205963, 0.05978301565553393, 0.032463661440077334, 0.012842960347751937, 0.05374518561086828, 0.026659555245010604, 0.02360410932000847, 0.05878097265057507, 0.07502881269301138, 0.03247805240173494, 0.03944579827328844, 0.0683663068940082, 0.013508782684502584, 0.015061125797670216, 0.09013651089081842, 0.03813769931213991, 0.027917578868988543, 0.03346232599729011, 0.0731550612216515, 0.04665191240248181, 0.06139407940809766, 0.05695592138856169, 0.012493135873228313, 0.017979970584893902, 0.0331395999678681, 0.030346016301923705, 0.05116870168656592, 0.08275398203442175, 0.0678130841603683, 0.07415145049772917, 0.03960576892319707, 0.019889613275506327, 0.022174459018353975, 0.03922265601314364, 0.04009203940269448, 0.03495605955381067, 0.06787279305318672, 0.014132122573022161, 0.06541262425842785, 0.018023053454535625, 0.07970106803000936, 0.027282798414929744, 0.012812445150508035, 0.03605587836054545, 0.006694484702987417, 0.036719222402861046, 0.06614459828744013, 0.0500431576473338, 0.06948714715338523, 0.03352775756690291, 0.06247042145039286, 0.07336016594161911, 0.03720164329053895, 0.019724986726237882, 0.012336507281889359, 0.0241841834353944, 0.002040531445902983, 0.03381637353149634, 0.04421663380438282, 0.021525285687417756, 0.028775884627154278, 0.011078802542009903, 0.039800274816732255, 0.056586555926309484, 0.010554203726050836, 0.059484076656160824, 0.05189773776838857, 0.03317196335222933, 0.021335477828078216, 0.030746710929839365, 0.01836167963882608, 0.05821773714776482, 0.04202069256514792, 0.07314808982154054, 0.04556624323970849, 0.04772253559842225, 0.05614945680023201, 0.08912646226705083, 0.06805745854733453, 0.018433209268316146, 0.02810890549763797, 0.038054655381147905, 0.07453554400032567, 0.020915655899913083, 0.045793480239808566, 0.04514235146944562, 0.050629513683698835, 0.030744826353545633, 0.06182043032059747, 0.08111166572498699, 0.004715625968416252, 0.07684541400521994, 0.013733173667963956, 0.03245229269528101, 0.04980746303654967, 0.03426689834844682, 0.038639781846394466, 0.04456136570942979, 0.03186867350802547, 0.066955502355291, 0.03062485123894388, 0.0326541721850874, 0.1367872205352591, 0.021618844175170508, 0.029912354995406447, 0.0547523575744802, 0.020025030807441762, 0.016386867763714928, 0.06932262211076676, 0.008405044603522026, 0.015000557928766697, 0.02562458386584636, 0.04382751093456342, 0.05402758477195617, 0.025994677111626636, 0.05115127318628854, 0.02101801865313563, 0.040847785139997164, 0.05618257861163828, 0.049782297048237056, 0.022243263290053415, 0.031092297022921905, 0.018305012115067052, 0.009896142817583057, 0.13476424279712862, 0.03136897733765504, 0.010673474997372158, 0.015686452726743395, 0.03743232385585866, 0.03322490768867635, 0.031094827028291843, 0.04500029578564629, 0.02552298337010847, 0.03028610439580535, 0.019909389835271626, 0.02674546817527904, 0.06756428178519973, 0.043143647227195964, 0.03469385830084643, 0.04138975404202938, 0.01210248274278016, 0.02591089773622732, 0.025908693318225207, 0.007023843617418842, 0.0683915801346302, 0.06291770571542364, 0.016035526435101227, 0.050176158171868136, 0.032025612364973755, 0.022015400013075243, 0.06344993380949863, 0.03830372588708997, 0.04832251650852062, 0.031141154280292894, 0.0562669861791355, 0.04358423588376853, 0.011066958822700526, 0.05137418945049567, 0.057145026362230705, 0.04880730077744492, 0.09756786253062949, 0.03974035524973466, 0.009660835081200686, 0.05917163535712227, 0.07580339653237213, 0.03105267304025831, 0.012896126849697003, 0.05367243790157861, 0.05813873433057339, 0.055597191676497466, 0.03202813853990407, 0.018260469847929575, 0.011781936233502724, 0.07579513044366915, 0.030545302584106405, 0.06424255518903656, 0.035518421716387236, 0.023775414240756826, 0.039726228588410926, 0.05778557928879896, 0.045903609209363504, 0.018011904960017533, 0.001167726635861571, 0.1150778362587575, 0.019475701715677016, 0.03022682642744434, 0.05382032734492133, 0.029110902537321372, 0.06098332221529657, 0.04710565861915389, 0.061271581949005206, 0.08445907158837204, 0.036465635808605346, 0.011738406160035202, 0.0564610630634331, 0.0631622141677766, 0.010694568270757314, 0.03767589385050439, 0.04879588606737314, 0.05217072936976629, 0.018451863509272377, 0.03856350630221348, 0.043760447597671906, 0.04806972664570616, 0.07926231415401544, 0.028748669353644216, 0.02639098971661541, 0.0285171116176512, 0.04931928116768118, 0.043046721783016, 0.029620523376750852, 0.006634775331364044, 0.032036473576520244, 0.036942031414758776, 0.08119697727623486, 0.017451595913078037, 0.029595705958443786, 0.04571661480792588, 0.07005467274857145, 0.1102759282014543, 0.058249246344090476, 0.0230527002995293, 0.03034996931561299, 0.051858805180076635, 0.09559766058960269, 0.044828209455215165, 0.0993421451459008, 0.05910741420642984, 0.010428193753825562, 0.030339757363582333, 0.05249733180408517, 0.05768910583649432, 0.01640843505400323, 0.039517852673006636, 0.0670964089072039, 0.010356518567629881, 0.029781491856180856, 0.0453851783588048, 0.04082939902981443, 0.06933747655561856, 0.027380535912309444, 0.03651722416942639, 0.040891762417290485, 0.030351884535423694, 0.07024182036759392, 0.0661059185081432, 0.022764519089832905, 0.05206319360783504, 0.018412921344861388, 0.059659549095217264, 0.017316032824436986, 0.04116667306891853, 0.08273807804911368, 0.04462858609434578, 0.06944243060124498, 0.017588624144874273, 0.021893940603120193, 0.051366888632577275, 0.02095522242598236, 0.07943749547966066, 0.055364890835217895, 0.02976170188987688, 0.029896190540204128, 0.01616376955362578, 0.03908499001315044, 0.05294222204435257, 0.029807755265445, 0.06699445792624066, 0.035613301705809376, 0.007993314000252154, 0.03807983286077938, 0.03440014785155654, 0.03606214112932644, 0.049754779169996904, 0.05448514610649117, 0.05517378637206651, 0.005690217170218427, 0.023600382302256844, 0.07489933617292874, 0.05411088151196319, 0.03564653459996466, 0.008060407501855686, 0.007460380147676916, 0.06996366916404617, 0.04338792202273204, 0.019931016497374065, 0.15540694156962057, 0.051561953770297195, 0.05696264764053687, 0.05667611926553711, 0.019770243370364753, 0.06842312763535208, 0.02309965574362826, 0.04526185735519375, 0.13556747066397823, 0.10223031194219667, 0.12002893993931434, 0.13741905921168868, 0.11783391417514895, 0.14449049508379352, 0.22970135173489972, 0.14334880957199683, 0.17534304680603166, 0.1143674199439345, 0.1987270992850104, 0.10112034247046518, 0.10980284592557339, 0.09905647861981585, 0.1068443062925531, 0.13923151598822686, 0.2723688025388026, 0.10460438011514564, 0.2851879049933726, 0.11081257279241279, 0.11576125563512887, 0.20126337125416727, 0.12407717835758963, 0.1090967273640056, 0.10733927570043073, 0.060892912348912615, 0.11303196781344953, 0.15716374971933905, 0.07266209130325625, 0.20569327467631912, 0.11852773702553204, 0.13473220500013522, 0.13257389016930135, 0.08490285866202847, 0.11648873272802561, 0.07839975277743033, 0.15391821822812482, 0.05669981053459549, 0.11091606361010384, 0.14713847799406898, 0.14381097509495674, 0.12062874081875048, 0.1808372608596279, 0.1557651949265311, 0.11631974905368783, 0.14266493820375012, 0.15912698792113414, 0.07208631494112554, 0.09376719308596465, 0.1625012987924199, 0.1842085686662505, 0.180405922714741, 0.17171926706308321, 0.1895417970034384, 0.1234396170043657, 0.15586553712285336, 0.1244482177219564, 0.14659913677361705, 0.10625500847855884, 0.1260450437304474, 0.23006728129281154, 0.17991792470697435, 0.11117480980652956, 0.13940892662973176, 0.14512110801954425, 0.18100523329790563, 0.17209157047252502, 0.1148586278601039, 0.10258558521708173, 0.11730231810361148, 0.14569889153203658, 0.09972780912874207, 0.14844565381926877, 0.1637576829882399, 0.09197931241003737, 0.11799289274119562, 0.16995784706406056, 0.1374390234629954, 0.15486053701850677, 0.17847049350459732, 0.17690166800973878, 0.14078082156277474, 0.1521669105897027, 0.2098534232185733, 0.10083954060269941, 0.1363420621642182, 0.23184437545076494, 0.16723250459519126, 0.1544034123540886, 0.049214675692060304, 0.15073627203462586, 0.20687001637153088, 0.20748489386131688, 0.18694584678498008, 0.1735564378360587, 0.05388668971136213, 0.2343403052298292, 0.05597241771137042, 0.26533295911165977, 0.10978822130709888, 0.1614178666063855, 0.14782591933204284, 0.21445404167377183, 0.16101865818904293, 0.1818423375727669, 0.20264867272588516, 0.2545093931257725, 0.17950538635974933, 0.14840523502038372, 0.22314161663093876, 0.09854372065033644, 0.11086015451338985, 0.09115117902476942, 0.14896533722358365, 0.11068547114489541, 0.12748522008018148, 0.10973365286425238, 0.18712924823405283, 0.18726944232419615, 0.15140376444305145, 0.16116865820461707, 0.12913922689134075, 0.12505888172815885, 0.08964975394548909, 0.19368454002805296, 0.144983503306585, 0.2562281573491712, 0.1352905452011093, 0.2205595479256684, 0.12786762818934458, 0.1538993724651875, 0.17484481386359663, 0.08831217209057463, 0.10476751853862118, 0.10804862715303899, 0.2297564334566555, 0.10464334334697455, 0.10570655081180796, 0.1651133675008051, 0.16366722332614084, 0.12297790347328111, 0.1448629517108202, 0.23446580575358486, 0.1715056970715523, 0.09489256092497418, 0.15601457186764286, 0.14253602092785222, 0.14869302361001893, 0.1381627314033047, 0.129738935840226, 0.20070941307612006, 0.15660370880317304, 0.09938530653955475, 0.08934665891912677, 0.11495612787022708, 0.18996159786418562, 0.10919739131725605, 0.14818506135094553, 0.10739016692124068, 0.12456890721354755, 0.2349179508464952, 0.17283792397187603, 0.1391082830847271, 0.14790481106648523, 0.21385497623874297, 0.1921173539613524, 0.09842578141439347, 0.11309470275356887, 0.2751594463423375, 0.1841968321992505, 0.11416391634772863, 0.14726796217503088, 0.09565825814441328, 0.13259754696440312, 0.11728926396538174, 0.1209759165442759], [0.01952088558145108, 0.0660644501688019, 0.024166032897248387, 0.06955725185933613, 0.06117124358312257, 0.05364362533474642, 0.044565862645545316, 0.05180545481702974, 0.026145663465403264, 0.04561853257098025, 0.06778655453555046, 0.03001965327008117, 0.023306049406528476, 0.028719956378242182, 0.03983719642424295, 0.01656035028938805, 0.049679909397156975, 0.07060001243747051, 0.036544282394911975, 0.02580012908325561, 0.035316021286792336, 0.040354340247088866, 0.03371372158008237, 0.03600873714012485, 0.05767175394500937, 0.0561162545495937, 0.03187512013790829, 0.026636260426453045, 0.056734334286903186, 0.07100776273516879, 0.02701423863219398, 0.026614047707088535, 0.04732379449471351, 0.03755627688200724, 0.0389399619082049, 0.07273760458995258, 0.02153978007094514, 0.048796981573104865, 0.035772326237131516, 0.09729442276781607, 0.0855032264465286, 0.05540939671317897, 0.04514224421713622, 0.005295933261814137, 0.06396058120674665, 0.06781214953310068, 0.0712621039260299, 0.044712832783378904, 0.03883781940526059, 0.007376400153002432, 0.022834112432094354, 0.03621920447556242, 0.07213965764329319, 0.03995943724388077, 0.05899854545151034, 0.028306450845012744, 0.09183572455038948, 0.06454254755930555, 0.058729418763710614, 0.02652264192640301, 0.04020833538003987, 0.07453593470516705, 0.037940040966796304, 0.055642402355348876, 0.027660211630826517, 0.0021427654005932596, 0.10103077913123755, 0.023779233189059362, 0.03127642625552272, 0.014733786961334127, 0.06994866150160951, 0.0826877537333677, 0.044904442864560315, 0.018444629724047357, 0.012501018917969158, 0.019671293538844874, 0.036750777564462156, 0.10578774847090246, 0.128655044001437, 0.021076214522303596, 0.01333949161738518, 0.022893796427055232, 0.05662476073109335, 0.09293530586986773, 0.044250820478003834, 0.019830703029348966, 0.0165110697684389, 0.032718450792374155, 0.014849177997318969, 0.06320256401874846, 0.026428826799195622, 0.06616716723768942, 0.018639704437866327, 0.04160456892643725, 0.10364345304908291, 0.05668594434316601, 0.05815925399562525, 0.02329106472672955, 0.030330604528106993, 0.035880432734566356, 0.039363489786703745, 0.0933645296120836, 0.02988947577954781, 0.04406576810945426, 0.05918787642111702, 0.024719110074182673, 0.015503020634153679, 0.050967055853576436, 0.017085055400046612, 0.026118785270579883, 0.047918462585056984, 0.03235345203129034, 0.024975921898599596, 0.04365299993585195, 0.02180534828033659, 0.017098289568938555, 0.012738081953308035, 0.050012770769817215, 0.05715521916206326, 0.04747280242642568, 0.06008708361356009, 0.05697567879612889, 0.023961895363285177, 0.007862060634990134, 0.007225253878371611, 0.057656171716629505, 0.04091819628111778, 0.041845595509174376, 0.03445696859290043, 0.06195383687173167, 0.03683734933034547, 0.02542721088825455, 0.06500792299066821, 0.06880905974896685, 0.040646920716690446, 0.01853824183795481, 0.02985446556140819, 0.051113053059746186, 0.021046628206667882, 0.02282530433618494, 0.06705041298823011, 0.03663356228160762, 0.025346244970757156, 0.04465750591348737, 0.05193757051001153, 0.04922417518232138, 0.06101658192252921, 0.019831628080517538, 0.019675985827381094, 0.06080498460740332, 0.020659815091940186, 0.06288182598748995, 0.015583304733398463, 0.03701107508893456, 0.023595684268061193, 0.0391348087108664, 0.02246148918094414, 0.04892154746959287, 0.02916705486695132, 0.011570590769781942, 0.02802857543311773, 0.09907910119621985, 0.05627054848798341, 0.02539478813207919, 0.032114984182220314, 0.015412892305081891, 0.02853639405070534, 0.04658833859608539, 0.030597392732517856, 0.015795741872411343, 0.05026275292038918, 0.07515750014253202, 0.00840856190470438, 0.01910923589621821, 0.022585562865940795, 0.017386348204567068, 0.050962371225919456, 0.054007130224377885, 0.011954078105308357, 0.047153703823325135, 0.0691088835798925, 0.11280249383661056, 0.002202683770578475, 0.011973882435760912, 0.012859097989876906, 0.059849190330433275, 0.04677855822768423, 0.0653184031046206, 0.04445218285846134, 0.009602515680354931, 0.03894006149963506, 0.021093832629342234, 0.02916860619499799, 0.045469900022350976, 0.02993881184187147, 0.02228296579672925, 0.03881690520492773, 0.060119738111332546, 0.034479889943594896, 0.08005531474707589, 0.011456853526103641, 0.009805827754579726, 0.042056227553515665, 0.009526189382848962, 0.007322368929312835, 0.009609058071228286, 0.009046871151264397, 0.019791578919055964, 0.03267665686566503, 0.09362555108964445, 0.023780591079905152, 0.1052372913146692, 0.07684102432141382, 0.052925467701448556, 0.06944013233747214, 0.006978312618054089, 0.028766689656843102, 0.06563970804094307, 0.04710500361397863, 0.010423560837103475, 0.10971875245412512, 0.09227891407546499, 0.06787548968268019, 0.02987833494590896, 0.05079717585636724, 0.04244685578610628, 0.038930891427181424, 0.02109504879392203, 0.03570900140931049, 0.013850392781258112, 0.037047368504347346, 0.019554438317314755, 0.04789910737365004, 0.033281464129686356, 0.04203939277137961, 0.07276752032339573, 0.021308109336983294, 0.025128607052348317, 0.047407596852750554, 0.008545442664575194, 0.021841557426077705, 0.09319287995176931, 0.07001455272397689, 0.035638521320276687, 0.031763007000629465, 0.03661293153380675, 0.10417600673052574, 0.06290991843167333, 0.0756947729255884, 0.035743506009420084, 0.01864500193586273, 0.0018652232369453076, 0.03424994099224287, 0.0899546186349565, 0.04294216227267058, 0.033427396218382546, 0.04101777621995538, 0.04602648205153885, 0.020483427177814227, 0.020175513458408175, 0.015758204521731507, 0.05287389849282561, 0.01563187566540775, 0.037230000035056186, 0.023114912384640307, 0.006152780580094025, 0.01559813236517291, 0.02013012083367475, 0.05378125303034341, 0.038323100250695026, 0.03320918756447012, 0.03979576255885824, 0.043012224843785654, 0.05229527611405619, 0.039552395577512445, 0.0419549162559692, 0.07508291382222407, 0.025137346200344544, 0.07160616933458275, 0.05159693717535946, 0.013892901084956624, 0.039164253300236124, 0.059890842530876405, 0.03600196109243459, 0.042893565485193845, 0.011714412286246737, 0.03191718985627015, 0.0356437498703599, 0.09621396300292785, 0.031724589606446606, 0.03372086151953667, 0.011984810680000773, 0.008123832878716772, 0.03908898899211519, 0.029723543050368468, 0.008548148870167714, 0.10630944668645821, 0.06742604121926331, 0.02509772221768095, 0.033257317038313035, 0.021711625083680117, 0.026381827305041017, 0.03414111820259883, 0.0641184451148635, 0.08456626261073737, 0.01010577415957326, 0.007476505340873114, 0.03257239612961008, 0.031018833021423033, 0.04756513900393921, 0.031320014743194464, 0.025206880170791864, 0.06702106415985093, 0.08433142601842843, 0.036155845173784805, 0.05880654849592717, 0.023040530992852106, 0.02401595052722241, 0.034824610357323, 0.03451788407419959, 0.017551436321809888, 0.08721496564366164, 0.041060183017003926, 0.0576879030784532, 0.053346406202763326, 0.030699577370298006, 0.0318691274151206, 0.018634236485306776, 0.04611709493122274, 0.03660227525078001, 0.056170045413197055, 0.04181231664974363, 0.027299715551517667, 0.03585811659333206, 0.028755439655675043, 0.05231953428817853, 0.012309170391921316, 0.03106908455881621, 0.024594946373854915, 0.04395998668886962, 0.040028469426737684, 0.06187338997880298, 0.04285229632871286, 0.10036131021596732, 0.01630203884785935, 0.07356962204099664, 0.03290027026988326, 0.08341293256249159, 0.06995705782525963, 0.025812792516643965, 0.03498413284579593, 0.04846510462342732, 0.10467370341141378, 0.16752223904815414, 0.09523690212517978, 0.16377606909842263, 0.14759759448709028, 0.21673410319753234, 0.16041960807577257, 0.1765742573526598, 0.1489726303806228, 0.0946694378170275, 0.1977001737442709, 0.1049008025156875, 0.13625866583278104, 0.1294815762629432, 0.1636587810372153, 0.14312929473817348, 0.12478554921765482, 0.2110174018889666, 0.11852251230588845, 0.1297502126544714, 0.12180226494468029, 0.14540759425970817, 0.1256781335799925, 0.19827933621502694, 0.18267895155135663, 0.1006461417062148, 0.12886648426853842, 0.12404438979443043, 0.15172478592684194, 0.17389538577727734, 0.08197235784703687, 0.15509555747191753, 0.10646088694732998, 0.13702521340981608, 0.1281506976773662, 0.22823715852873944, 0.11306520070760481, 0.1463868691315574, 0.14497737460319074, 0.21081467970244347, 0.16033392880232106, 0.3291448962784583, 0.11654633487905226, 0.1090110557514333, 0.13189548866883402, 0.18313284332473434, 0.15651174760874242, 0.1833474245523253, 0.23800382961428937, 0.14492745631404463, 0.12512480359404318, 0.14165345699556414, 0.15444455127562248, 0.12719880278793075, 0.19262027536188403, 0.06715578838221489, 0.1178761792459315, 0.16377830607516153, 0.1879769858093031, 0.09963552617738325, 0.15389204866463138, 0.13644663316588249, 0.15038054676786547, 0.11853687645446871, 0.10140986241880925, 0.1332876236448365, 0.1936079618791419, 0.09134692981118157, 0.07241931804005178, 0.11462575245288112, 0.21357438887559602, 0.1738746554380463, 0.1505151024508861, 0.07684394311640533, 0.12914177030324936, 0.15950051707125482, 0.16787696840061297, 0.20893053241795112, 0.18160754694573342, 0.11684187627848118, 0.11336170737781834, 0.14073908509265992, 0.15606848913575375, 0.17965518719246312, 0.11611363309766017, 0.13628301210701466, 0.12156283948570491, 0.18822057112570734, 0.10312153266802912, 0.11566575511448807, 0.15003444356543405, 0.1986698112300327, 0.06004915076998934, 0.0876012884621178, 0.14074928938381134, 0.21359660542540013, 0.1917913375842956, 0.2366720470449617, 0.11298751939208278, 0.11921821207168604, 0.16969265806819164, 0.2097462168744495, 0.20748638007189, 0.11431051493291894, 0.11074638279575495, 0.10053386386003225, 0.13128358360019424, 0.1111748174674088, 0.15862592045337925, 0.16048988898194608, 0.1903224405982802, 0.17486470150611094, 0.1580132186532982, 0.17172200965785211, 0.15269417826446796, 0.1104243117715082, 0.13448538679269054, 0.08938839538924157, 0.15186383088509883, 0.21028658465272, 0.20599615519806264, 0.19634674153020307, 0.09029742765931353, 0.06961032643073028, 0.23396838486434954, 0.13121170923113823, 0.13083085628046145, 0.11332938612829294, 0.17715976303142889, 0.12393096281636147, 0.11821115885170237, 0.12237162149000554, 0.22902904829430967, 0.11549402884538136, 0.14278909041275903, 0.17109830683517843, 0.16584680475775274, 0.2055709304348115, 0.09800752039037405, 0.15342976056760357, 0.17228966548798547, 0.056597319461645625, 0.11159270310834532, 0.08956233565244945, 0.08337499588848123, 0.12472231632038472, 0.19708947909455146, 0.1073952537450579, 0.1717393998537333, 0.1413206530794982, 0.17876054971448838, 0.11116433738460464, 0.1012276407451399, 0.12089539304255478, 0.17797249038853954, 0.11358765735020561, 0.1239510496417361, 0.2316042528517785, 0.14671993351751758, 0.14430608239866075, 0.16020539457038527, 0.15243677272190972, 0.10139433381658408, 0.1599515283540372, 0.08552517486555923, 0.1235076992381965, 0.16610739722607598, 0.19879376425618128, 0.07597408092190182, 0.1378112809071618, 0.11557092875122063, 0.1866433493071987, 0.17544508971754583, 0.1891613883837577, 0.08243216381919, 0.12084345228128857], [0.04873552599981908, 0.04447432279947304, 0.056387365405117316, 0.05332759491378262, 0.054923493955885215, 0.055443928126365914, 0.042080585319068164, 0.0408499033731078, 0.11792679467508871, 0.03714091933122085, 0.03464381360719281, 0.03692639172978459, 0.08393695968533717, 0.07435556696427446, 0.016341419597606988, 0.039475445875958096, 0.05168432865532176, 0.014343424944297202, 0.007604832250264384, 0.025620805137159846, 0.01782241502716657, 0.008311303212277351, 0.027102649009095568, 0.03317299757092711, 0.028084503682029825, 0.022673726179486802, 0.024549733779783693, 0.042531516162618514, 0.060115643371377266, 0.027609600032108928, 0.07039260945373005, 0.02228118847274492, 0.036850828647373185, 0.011527000366890383, 0.11688320672199612, 0.03288200673376841, 0.0789477278087889, 0.01060411626953752, 0.02661425263560828, 0.05785356959207885, 0.08767186814258177, 0.0960898720809529, 0.06492696281883024, 0.03242443773835417, 0.055952625829846635, 0.06217901309531543, 0.094718421478906, 0.05736517321859157, 0.019403905870633262, 0.022325529641802275, 0.0113943129807951, 0.05855994479310128, 0.011576314404186223, 0.044963826170010913, 0.042455282753273364, 0.024003589698564143, 0.014709794045155569, 0.01036646238888704, 0.06512346437140819, 0.02914285223420349, 0.039315364143300446, 0.05902097267549365, 0.09515718301577915, 0.027440974503875743, 0.03233481694253222, 0.02696445057799499, 0.08745305044876953, 0.0834858641328831, 0.026749124329897667, 0.04838425553433838, 0.030845155143329216, 0.017580128229794004, 0.06823375836134919, 0.07243472406820906, 0.08673861983322328, 0.06651671017490088, 0.023186135578960664, 0.013205827469186438, 0.01834098377355164, 0.042564691600179484, 0.08973365589495629, 0.025586616548319018, 0.03227391295255192, 0.05806945699958071, 0.03352069806668066, 0.030297643595164826, 0.0418989343809024, 0.07910272271762933, 0.07239565358407075, 0.03310698760493148, 0.040172570565294836, 0.04032747737402397, 0.0018309871267129278, 0.019259346994541345, 0.03578635330702509, 0.03023622441105545, 0.05635741902815719, 0.035799675576028325, 0.012006085899267948, 0.020299600549943505, 0.06542816818241151, 0.04098148280454259, 0.021324394451033686, 0.03316674629346498, 0.06059577365616157, 0.03704689736027391, 0.042756646420926823, 0.02167850135705404, 0.04502426667679702, 0.025396548219085224, 0.05386509369277666, 0.056939320263242534, 0.041987271979451186, 0.022440601793688633, 0.006957567435869527, 0.03828607905175417, 0.047476437513626395, 0.022649617392509695, 0.044976933934395356, 0.050298437295902165, 0.07195214230206705, 0.007122666565626259, 0.024698433361106345, 0.009140924723338216, 0.01812153980286131, 0.044267586312226714, 0.05260253099784736, 0.026979046468172344, 0.04678996144643715, 0.014717824561821838, 0.05199807996471083, 0.02411532745276007, 0.04173056357690404, 0.0574120348169198, 0.0393361519391258, 0.018083116663019025, 0.06543330863238343, 0.12290792134139808, 0.0516872359589944, 0.033892878902054606, 0.04894534599096064, 0.032115809641958724, 0.03680241572099828, 0.03824549554396541, 0.040541319326768, 0.03997404271015718, 0.03745553631996436, 0.04761989130788753, 0.028235819453613895, 0.03911482147692193, 0.010490345509512531, 0.05734354655648913, 0.06036844089507096, 0.04493179603389675, 0.017261632920933828, 0.0753671094594944, 0.023120761465942188, 0.02329431102430869, 0.10618604524361511, 0.050475595128392024, 0.0022073681588329736, 0.0582560338830996, 0.13246518229284596, 0.10050896600249315, 0.008135960050558132, 0.03211724031115732, 0.03904896089807153, 0.03232237184420228, 0.05786992939970186, 0.02714187845647816, 0.043140985071659095, 0.0294318589036383, 0.07395318694292538, 0.040394835654766335, 0.04468272169751506, 0.039659038847011906, 0.008932632119995693, 0.009171774126439085, 0.13734612764129717, 0.010313704786371562, 0.030275375334425803, 0.07560368507139145, 0.009985471542383875, 0.04110553542212133, 0.03016130675772025, 0.03556705680826018, 0.06009539183709891, 0.046193730536728136, 0.061956476044630816, 0.07596351656942599, 0.04329006578172407, 0.07384032686992038, 0.05431256564934889, 0.01970290615704031, 0.03820858542777358, 0.04593963066356317, 0.010092835892142068, 0.050042502642158544, 0.060464431711983305, 0.04382641925927132, 0.02606833263510658, 0.06690615097120886, 0.014585973169173927, 0.0758268005184589, 0.04017827025945148, 0.054223331727928696, 0.058623836525986274, 0.021840437022488446, 0.018852016129981608, 0.01821777002224999, 0.06125874614583389, 0.023544959671374772, 0.0327135018643833, 0.040086274591064265, 0.02307895030225477, 0.023373246808806737, 0.0542091399491314, 0.06443507308440824, 0.038847399334753716, 0.05569150476085563, 0.033362075731518774, 0.027105694208594582, 0.021261056216673988, 0.07269524758861912, 0.02480274006243675, 0.0295942944414433, 0.010712149031009647, 0.0780588053467293, 0.05417884117172611, 0.036514611809604594, 0.04170170887523601, 0.057037770222391815, 0.01808908831838879, 0.046890422386387666, 0.008021727243753812, 0.02594131525726088, 0.0289683910312071, 0.047322124423038577, 0.013832315021464902, 0.032316289106083494, 0.07544497463611827, 0.04312426520271167, 0.12759177524956966, 0.1207750559514088, 0.0064855916782342385, 0.03811844369216311, 0.027170564618802844, 0.023100699538425095, 0.02080106638341902, 0.021905726865835248, 0.03762673398840331, 0.04824842431492383, 0.04893228802229128, 0.10819599182615358, 0.0404659362750188, 0.05843669273740342, 0.04699914175416193, 0.010010903746250176, 0.016749570176245707, 0.02324029799520729, 0.035437243209490855, 0.017845932011222167, 0.020722084633645513, 0.07601464527749247, 0.013487554388120772, 0.08157661214711205, 0.07267702235690049, 0.024872530672338702, 0.005812324882079397, 0.0619766433092375, 0.1104469343479122, 0.013831795039286297, 0.13064281233856756, 0.010858968824088093, 0.014196906798338939, 0.023300970243590496, 0.13417892097946138, 0.030951627958265525, 0.04865027956604477, 0.07626799055405202, 0.006605201464657102, 0.06100802855085462, 0.046723748467141585, 0.05268735608326332, 0.05793723405428952, 0.04751469211412534, 0.07019831423437403, 0.06143429136324314, 0.034082646541778124, 0.051118699127748135, 0.035684517239250486, 0.02566973134244402, 0.016722985010053364, 0.06904945047872682, 0.024143356694689682, 0.054322375405219295, 0.1162890136061657, 0.02751591705506848, 0.04255137316161587, 0.054429030166037624, 0.06360947545016966, 0.06298512528319994, 0.012641750227269388, 0.02404758229761595, 0.09057527242769157, 0.016086733667179942, 0.09915553378842532, 0.02683360850618732, 0.006662036091344612, 0.031113919854584723, 0.013423626266059377, 0.05463849392629439, 0.04272560453823498, 0.03354590235938949, 0.016846336657181382, 0.039007603641479247, 0.10094476277909933, 0.037975824933739445, 0.03505195077929286, 0.025556183705526977, 0.03372328618781702, 0.03849265849097602, 0.03536593957593845, 0.0063590875792978035, 0.01185487067672394, 0.013310852377945858, 0.016322150571091522, 0.021466963413742282, 0.018620241974149982, 0.0318097249574719, 0.012050937474404853, 0.025671828508136735, 0.024626922883814382, 0.0061328187228120385, 0.06601736640497562, 0.10814608885876595, 0.0041981115505369685, 0.0017003135942485967, 0.09063957784805568, 0.06920004804288188, 0.046555867959414764, 0.06375611233975619, 0.027639169110766346, 0.04151120962154481, 0.06216996559692968, 0.03259257488553563, 0.07904599390683636, 0.028420429406387192, 0.03321149731956182, 0.050143549639371135, 0.08186194159451031, 0.01773029103905203, 0.12483968865126373, 0.1043690225830482, 0.2595815999853996, 0.12488483421264157, 0.13501072392588662, 0.20049087883483982, 0.1665833063663975, 0.19987446916920526, 0.26177239694422294, 0.11953033927467563, 0.18633938094060268, 0.1151300221681595, 0.21402622753333664, 0.16857807674715597, 0.10530741900325784, 0.13706200095194002, 0.1332112753223027, 0.06943214970130114, 0.13511727143439556, 0.17810355271062545, 0.13333495255679856, 0.11265598718197116, 0.1320555244362162, 0.12570595789340236, 0.23292668914842993, 0.1517749493641238, 0.11158380882754443, 0.18860234338189327, 0.19493209889098523, 0.20935508302382885, 0.16167493507025704, 0.1375521286841362, 0.15536145126867681, 0.19673406026296078, 0.1324636501169974, 0.10551216366190104, 0.14761124617390095, 0.20108209952952402, 0.14599545948928402, 0.12035412128053366, 0.19471664432316058, 0.22164339379918194, 0.22178839892148974, 0.13932686329128283, 0.24847710955767865, 0.11840263486749704, 0.11358660780974936, 0.18230404344297227, 0.12606231135226068, 0.21643920531195981, 0.03684918921921523, 0.13835436063668421, 0.10340702299389148, 0.2009521250522906, 0.14849531163852062, 0.15579263619597883, 0.08176280215622918, 0.2088552719402698, 0.11783457301076382, 0.1234111798206164, 0.06070582601692408, 0.2527714920260253, 0.14020227196235813, 0.12445062323803864, 0.13526580056115506, 0.11639474906147489, 0.22615768946707251, 0.1504350309410403, 0.10828851992564817, 0.15309718647791495, 0.1069044748381261, 0.12544526583364896, 0.09214317095616172, 0.168966130924321, 0.17135125374601734, 0.203100833140554, 0.14094989716766343, 0.2377986253028916, 0.11019054770229325, 0.126102423715976, 0.15723335646813916, 0.1598768960684538, 0.11380111242854789, 0.22475786296831024, 0.10453227591971237, 0.1057473449937759, 0.06519546131453206, 0.16387322436897986, 0.1375825576964886, 0.1609276622653969, 0.1980372524309543, 0.10119295994480772, 0.1381601879913961, 0.14073094923890409, 0.21021363776056998, 0.13545939097962073, 0.18684435545677142, 0.06352350889374653, 0.1159905227682283, 0.06257622202317561, 0.2842234922272544, 0.13411783312837924, 0.13996544354144605, 0.13272791980735718, 0.1656467792007231, 0.11713376343851128, 0.11708789009360537, 0.09696006369326385, 0.1685995578525528, 0.22658865988975574, 0.19809930555282101, 0.1469810928909048, 0.1199790905980814, 0.22946625467269655, 0.12586819999400647, 0.10873446736725108, 0.14166344678209675, 0.1155962096527219, 0.14683028082213095, 0.1680885005982653, 0.28124779222473023, 0.14248953471260686, 0.07230684101100891, 0.11933556908080656, 0.13521290985086273, 0.16484626328512547, 0.1496287080789766, 0.12394701235837514, 0.2223957534278593, 0.049641873131716446, 0.16266986877927858, 0.13256984522506116, 0.13559351765340374, 0.08972414108293672, 0.16800603889409574, 0.09259144730505445, 0.2098419472214676, 0.13725458013434566, 0.09857296222640623, 0.09865596019212278, 0.14221673080277059, 0.13153769496467807, 0.1400601626524041, 0.11968350323337702, 0.0893918198022631, 0.08555473819855722, 0.12774379773726388, 0.12305602911979922, 0.11867165430298737, 0.14992143027484417, 0.0877077057356796, 0.14568209888473635, 0.13620166889121457, 0.16895119220979754, 0.08680700084134456, 0.12263016850357095, 0.10730942125402151, 0.07742064644492443, 0.17466942569421184, 0.13559169436414398, 0.11403824728462966, 0.14381108234726614, 0.20308630811350964, 0.2071840970987274, 0.09489195571551401, 0.19325166970731752, 0.11984023716180556, 0.11262817052944053, 0.12634705857283648, 0.1212751198439829, 0.1971106384430201, 0.12675057240431348, 0.19381627650751224, 0.08061601449885676, 0.24921089921507145, 0.17206809753852506], [0.05767448887889905, 0.030175230405744047, 0.05117580715206362, 0.027630322710460717, 0.053673449137638655, 0.034165767081562555, 0.03525578762374578, 0.04355550758660801, 0.023901786189526323, 0.03119991705452483, 0.04801035100113481, 0.0403372718081359, 0.020182201405987144, 0.029264832583947048, 0.03744563080310341, 0.014082316324234971, 0.08504561914671814, 0.03251780853456548, 0.049240818442476374, 0.05846167103417459, 0.01265956368672872, 0.03392013631040051, 0.06901995609364203, 0.016351838393377203, 0.012039441367491119, 0.021620041187552196, 0.04871694453721566, 0.06077119629950293, 0.03348234387475156, 0.03609153592298108, 0.0014329390931731812, 0.052171809553739526, 0.008138031360783405, 0.01825751083332204, 0.014363705206872716, 0.031063223986195463, 0.05503026362989218, 0.06668707280750237, 0.04658067388640297, 0.03942643540100225, 0.039381033200169765, 0.039126082969408844, 0.03390568023126933, 0.055869099263462334, 0.08323801936761988, 0.020832359159906066, 0.05520533004234876, 0.035380012611107486, 0.0345269966900589, 0.02568325470952738, 0.10328384371654642, 0.040856679420798056, 0.03792325598037532, 0.021065910639722022, 0.07336654745402836, 0.034920708426544746, 0.035941601024880525, 0.03720340912320441, 0.011224192623499663, 0.05864392718180053, 0.04990975875707884, 0.015317735566397109, 0.04951337337373726, 0.02780987073727433, 0.02757783611154845, 0.056328480056817495, 0.011580731858679605, 0.011948166779362628, 0.07153224184988968, 0.040559272597273516, 0.0382276495257693, 0.036009196792879415, 0.028095552585117763, 0.07679672145675268, 0.08050374431355346, 0.02389460028479657, 0.03396346624339781, 0.0684159187479846, 0.031943315369707924, 0.05119995424343694, 0.07257333235634912, 0.031417378772711085, 0.016222135877356898, 0.06503098223718905, 0.05129134470236398, 0.07645909884764303, 0.004670752368251523, 0.03918118767380234, 0.040791803264930364, 0.09480447613544042, 0.05287891253829003, 0.0456273464125491, 0.02663466504835073, 0.03408738862602942, 0.06239610326085841, 0.01805691262556901, 0.12102509938901472, 0.025314651504759828, 0.023274593836357518, 0.018677060800274054, 0.08570610951151579, 0.03531037521879039, 0.023294305278649254, 0.013688081732740807, 0.024522441897481203, 0.03420391059931248, 0.05143972061153862, 0.03504217166693942, 0.005531654206870665, 0.02189747992933037, 0.01073697315258605, 0.017791016913589933, 0.03867145575162384, 0.010606261315725504, 0.0272267724898073, 0.01649254959286942, 0.0577654158546319, 0.10378383866120731, 0.09953659358284167, 0.020470991655583345, 0.04178973237773584, 0.039326832479526924, 0.07313270677602099, 0.043588039510312586, 0.0388077351324741, 0.051822170855537544, 0.03913051861849043, 0.04123755918455221, 0.008090189169912089, 0.05455717369313202, 0.022524568860629396, 0.04126255280308185, 0.05698238972634558, 0.06825884774086938, 0.05062709667629773, 0.05275107927680497, 0.05211983814895634, 0.07834880026958643, 0.06241530142424088, 0.08155667087844304, 0.07383699438744977, 0.09374772679180869, 0.013811730238939486, 0.05018491072640304, 0.04651316621851537, 0.04311258619230601, 0.077134144883002, 0.05787197102402007, 0.054781315698018, 0.03803634204931798, 0.025426923605282942, 0.019748760349748117, 0.03057982059075467, 0.04439982840971601, 0.03858032576259106, 0.04922164326173164, 0.03360908546094452, 0.00653431199738876, 0.03423668001027357, 0.05703964713780631, 0.07231901414812573, 0.041253926653054454, 0.00800090880441149, 0.03171413059106037, 0.05343090953125108, 0.0880425091412279, 0.054082735441625125, 0.03166468919164712, 0.045096003150026646, 0.0847028254441196, 0.027239068200992003, 0.033928877373616544, 0.038050805789328394, 0.05969175926199364, 0.04483469055905458, 0.0407428234334915, 0.05377695910752781, 0.027008801323151397, 0.019291080271584854, 0.05466024699290434, 0.011953150181310072, 0.021491418855505127, 0.06719110503552422, 0.015591928010596143, 0.05649112435358186, 0.07054382754910378, 0.03786772226674422, 0.10411121101389009, 0.025020527367990826, 0.030961973975682934, 0.03087286454355044, 0.015167009682514736, 0.0518004177889276, 0.006732010083543438, 0.060508841828953844, 0.03424274742663388, 0.018866998894560724, 0.05499939794742292, 0.0089735823923782, 0.06902708837221708, 0.05042303383590714, 0.03408088453955228, 0.06057214367413714, 0.04618297466227124, 0.03468003041381317, 0.0800744133190282, 0.005313894672003845, 0.021709196584960146, 0.054293011255081625, 0.02206070645291719, 0.012336111788998448, 0.0465679185224637, 0.07957426515678245, 0.07597300073792858, 0.012149128878879692, 0.02844760062984161, 0.05686014124582853, 0.03592844346478101, 0.07249691508590214, 0.029037748801431833, 0.030524593312293295, 0.020025134229311542, 0.0435393967575604, 0.023444969875497684, 0.055432019289582975, 0.06847402651704128, 0.054456954070877646, 0.0387415872706521, 0.06795618938462389, 0.019215231821421656, 0.03990497988378329, 0.0297183049241862, 0.053089992744067026, 0.06558207524639946, 0.07832514347448465, 0.05525735124284702, 0.06758327310484263, 0.06555507830794781, 0.035037207417190075, 0.04225341475478584, 0.037496085353796525, 0.047971073673256946, 0.055787169990400155, 0.0199652606275894, 0.05461177660993511, 0.06826817869178711, 0.028959669120189165, 0.06950214715494264, 0.037515287347618616, 0.04796713215088652, 0.06647799209120774, 0.06467004757254355, 0.013857396740105846, 0.024868135242873145, 0.1091316303298358, 0.026220079331148057, 0.022558939395352237, 0.04166111387612839, 0.006017149022344741, 0.06405729597674743, 0.04715886725593479, 0.015875268502220992, 0.017545301872756214, 0.013716330267338744, 0.025237586890016834, 0.06450711599280758, 0.03975416398456982, 0.038311712353700594, 0.013914037450787523, 0.03694845506200387, 0.06679717496397995, 0.02462601506962411, 0.06470714154983721, 0.0352498312901345, 0.039129928730788736, 0.015524317878448676, 0.062372385178722685, 0.05540614083950078, 0.03818010227874883, 0.02023505955754269, 0.014747178178250551, 0.04506183562860374, 0.04693403577191695, 0.04550407137421351, 0.04353993301910739, 0.012971963808541338, 0.0654879077187469, 0.03025564857037558, 0.04254809813573957, 0.0404105787616103, 0.0187055611862771, 0.047835644650002646, 0.06116610313315065, 0.010784989628460138, 0.026959292891044772, 0.04274335096500093, 0.02473188842075967, 0.09738399376792294, 0.04217208686074422, 0.027648708820643447, 0.04142659521030803, 0.06990924627790529, 0.04461601459150834, 0.026457673839984402, 0.020205143824099533, 0.10760090238745175, 0.07663830979576997, 0.033242443441263134, 0.05963320333150126, 0.06962555625866498, 0.05342843123681603, 0.026969290338456634, 0.011613748332996283, 0.08201017960785859, 0.10366211495091839, 0.024410271303608053, 0.035955723855764635, 0.059939385692198435, 0.032401612148650234, 0.08956755271121379, 0.06448311445813987, 0.01719181741317434, 0.03816369267541074, 0.03003835922197229, 0.037765123941484964, 0.020870673132219145, 0.014982511770100364, 0.077876805838558, 0.0775521684197649, 0.09437546689784336, 0.033483136775753194, 0.021313554306905118, 0.03592153718214362, 0.013993345745538753, 0.03301880705440718, 0.01809957606207219, 0.0859082418103372, 0.020770704403759974, 0.053116648773392366, 0.0418550145602034, 0.05633725559399013, 0.01048155082014179, 0.06418452785921193, 0.03874136893559368, 0.024585199820238258, 0.04416889120494166, 0.04425166317472055, 0.006916132134069959, 0.025373621122731317, 0.0058826445714540545, 0.049539979607347524, 0.04085096823532255, 0.15722859140125015, 0.1286787007965388, 0.16122344881296158, 0.11889359763553066, 0.1412361076161746, 0.08799072159754653, 0.12730579462743577, 0.18335099452205245, 0.1658044860608155, 0.15582878022424637, 0.17952493692357696, 0.23014209743949676, 0.0737442747659741, 0.11011181684631495, 0.13147660711359593, 0.1055919976844903, 0.1511627531820728, 0.13652577004846067, 0.06563485104350314, 0.12531814120349385, 0.09386879932736197, 0.16006086442259052, 0.17727622371767798, 0.09332839324469529, 0.22705997250253157, 0.1430732783891501, 0.12937924223801783, 0.18317563699618464, 0.09046550734990066, 0.17441638685282201, 0.12229891208511208, 0.1482801481841072, 0.11182106625769409, 0.12854757718741894, 0.11114572910892387, 0.1691233015228664, 0.19644293152997572, 0.18036689819587817, 0.12788317211332823, 0.08916467473271394, 0.09262732320254849, 0.15349832543682668, 0.09583485673271841, 0.1372196924902739, 0.11280578801468497, 0.058088812210987655, 0.14976505640774004, 0.14239149078005744, 0.16528520102222122, 0.12813041933001051, 0.18489481490706244, 0.14325847248396567, 0.09520940722957735, 0.11934200421937051, 0.12033588838793578, 0.1918745960199064, 0.14757641981686317, 0.21004565000053377, 0.204030848558872, 0.1693586896984808, 0.1408587786699495, 0.263698403272898, 0.10257017918892446, 0.16856566612278262, 0.11463886021726555, 0.1171424278929349, 0.12452505634076173, 0.09278905202424334, 0.1430940393718981, 0.10531674229329634, 0.124969280084535, 0.12617790635915535, 0.09840394790855148, 0.19897894302923835, 0.1076702256837199, 0.18419062688706384, 0.10931977386315984, 0.1866013064019142, 0.18185523849341179, 0.159960261756374, 0.21348391389173849, 0.14223773693365438, 0.07777690031235257, 0.08375846119897981, 0.16745629419963207, 0.2346702746205753, 0.14407460127146016, 0.1388410716167381, 0.1590897560480141, 0.17008860295097675, 0.14804765582084656, 0.1489866804331541, 0.07937381825139446, 0.2188618511201874, 0.12907888980642443, 0.07080855689221813, 0.20057114952754593, 0.09791533703044539, 0.10499945931857634, 0.17691965575420088, 0.19547484154182096, 0.16898914420556638, 0.10247249531769946, 0.13548842571195097, 0.12739475275720322, 0.1488470992133502, 0.11935383261692141, 0.14562695587594665, 0.11009831071620989, 0.15154449479474177, 0.1332124550977061, 0.12651601926453654, 0.21609388351921113, 0.12760762560872302, 0.07631725000758326, 0.13442765440671675, 0.25759884186329385, 0.25234062885565145, 0.10629841502034858, 0.16093040486016583, 0.10218656066084102, 0.21810970599612883, 0.1273692113858077, 0.1273744361054513, 0.11143465916956626, 0.10420632849056875, 0.16594973633125906, 0.1443471140678852, 0.12966560590411388, 0.24823491852129662, 0.11657278789507768, 0.10858721760732513, 0.1757165146691184, 0.14394919267825543, 0.12393354453266629, 0.15604460251427468, 0.1798702893598426, 0.2313799882728246, 0.21555653412736234, 0.2268314484747187, 0.13038301660168555, 0.17322830705633088, 0.09220379915448929, 0.16646748919400478, 0.16814978763220773, 0.11086285114288331, 0.170708000359516, 0.13439114265624555, 0.11651707798122399, 0.1230200689526335, 0.15288266653735794, 0.1438849025796498, 0.25471772307590135, 0.24884366730768837, 0.18068027412218435, 0.15217683908920135, 0.12131404477141558, 0.08876653883846537, 0.14246479007265261, 0.1667529182328332, 0.19883425966385873, 0.11185035379903932, 0.167900349404062, 0.15578791709436526, 0.1558741019858468, 0.12960891539771713, 0.16143642125591157, 0.0999446043504342, 0.22914109631411492, 0.2788264334442154, 0.13162286862009956, 0.19324269115684495, 0.08056772031611012, 0.17747736776307707, 0.11034809368392152, 0.12206940746475613], [0.027779458961900205, 0.046119894982585986, 0.019695141855927727, 0.04035066685549194, 0.04003776590369883, 0.03729919692681682, 0.037989430655274666, 0.03616853542025051, 0.03370814062955399, 0.07474172124338728, 0.04978218979592766, 0.04500142193489498, 0.05532155324134135, 0.0400832562046426, 0.05372574612978966, 0.030849096665699637, 0.07513699196879903, 0.03317243066586314, 0.03952262923121452, 0.03481165964096304, 0.04502837290807117, 0.033292472813158266, 0.033508352559780887, 0.05217776205691119, 0.07470245157638866, 0.03098367341613818, 0.03618180789353867, 0.09349412870623412, 0.02693967337930395, 0.00820992009398798, 0.026775613735099475, 0.05453754652051195, 0.09562407530123189, 0.05323394066503933, 0.018956414761862928, 0.028902141662735133, 0.005113538739556868, 0.04724758406800609, 0.03460099695310478, 0.055849809169528954, 0.012824519653804602, 0.032225170608369574, 0.038579678418295044, 0.03700275920451649, 0.06182620662354654, 0.04577052058471788, 0.029886461223565766, 0.05619433423083636, 0.04398712535358725, 0.053257417429478905, 0.03320625727815974, 0.02403710221481179, 0.13128324652150755, 0.05242569875272532, 0.018992516655294646, 0.08403988359796424, 0.022735762064375227, 0.02949353664242212, 0.009482996388068123, 0.043270756535592585, 0.025188093779668696, 0.08757611481292595, 0.02501061993591007, 0.01680008026831333, 0.04106623894204536, 0.029124676798199935, 0.005946144163082805, 0.027282886515041033, 0.019262081928431027, 0.03555718959579545, 0.03767179911054912, 0.014247080769329784, 0.02915973489683482, 0.046896723459564874, 0.06510489440012364, 0.12872910938195645, 0.0738524463808825, 0.018754303530459444, 0.03612475349537788, 0.028502213122743755, 0.017389732397972577, 0.037364482939724004, 0.05287021744034944, 0.0064335977696182755, 0.025297780333447362, 0.07146484143431149, 0.009753385205723105, 0.041321388355666594, 0.059391567708864335, 0.03633668405875083, 0.02794521166041734, 0.015439817422790634, 0.018286848170382362, 0.02730729407630861, 0.019877648897348874, 0.016770899979277484, 0.0044666924006906495, 0.00828443555116293, 0.057673519777674834, 0.032730102989702456, 0.02770069363196531, 0.04151920374903468, 0.01378353533049625, 0.03699972549633634, 0.02006542470846926, 0.08490157163431568, 0.057315354520875605, 0.10218010253963933, 0.018139841643372373, 0.0843094086514846, 0.08536757525777625, 0.013200714789901771, 0.06873186872971636, 0.05170728831041244, 0.058709443021084995, 0.05180210318236102, 0.06064368479494607, 0.09861287540726124, 0.06603238172829151, 0.01098658279290483, 0.01409206096263182, 0.09951937958718308, 0.07101932300194617, 0.0298539484520593, 0.07833642028873006, 0.12886901235868856, 0.0936192615077861, 0.0357950177614487, 0.030650687554190238, 0.024976011913930698, 0.05720642064848254, 0.048097746311536724, 0.02821534383861769, 0.02054117488554649, 0.01825927858120732, 0.08632379088310466, 0.05100276321172715, 0.0512634820845579, 0.022003581191623406, 0.06321968991429576, 0.034144791594195756, 0.033285570360960505, 0.019236389254670472, 0.061438026041874004, 0.037264899170446786, 0.026460820546133385, 0.029189409312581825, 0.03400314959787554, 0.032048937827048284, 0.024215826697106806, 0.031936424408829024, 0.09007468759532898, 0.05607325020396421, 0.031543963310879566, 0.04794628306802723, 0.038907257614717375, 0.06707812238845133, 0.007878099164489897, 0.0474783527334371, 0.032696789656315124, 0.02776256097751039, 0.06350447160882816, 0.055521636254965305, 0.06021668653815024, 0.07730241609557022, 0.013701635743341139, 0.03907047647742495, 0.006253615466712584, 0.03087814288934873, 0.0839974423269591, 0.02006452072471861, 0.03819028741770214, 0.07029213702246066, 0.020849418022759983, 0.04792878561983666, 0.04901350866402349, 0.033883214702889804, 0.01459763398499138, 0.017062900137276422, 0.00851510079472416, 0.02633395830109235, 0.04803733644826759, 0.019578775015449332, 0.011201025167059515, 0.024006198227946317, 0.0184263278835363, 0.028997326172107173, 0.06078581708753782, 0.019101553949557485, 0.04010430063992258, 0.03725381004774282, 0.05936969972906574, 0.04460306004470876, 0.0174319917230957, 0.01391377219284374, 0.03775597302122943, 0.05416382584841021, 0.043027638532822175, 0.07411663180157062, 0.07964472226317852, 0.015753199094756237, 0.0772952531734782, 0.053841402423718286, 0.03729791372954365, 0.0361319508914265, 0.010370143441363208, 0.03715356744285073, 0.032159957373815204, 0.10870930903981771, 0.03171294315477773, 0.06714520870798057, 0.026487263986059738, 0.030011906205946882, 0.022616047419667728, 0.0044377993946264115, 0.06776658262336446, 0.056149575543860276, 0.05046402720073539, 0.02625148893604356, 0.04103745701873014, 0.010420926452253856, 0.03794174934286745, 0.03632776679531221, 0.002098690447089593, 0.057494787634500576, 0.05682264124193499, 0.07724316685550636, 0.018607413831857905, 0.013287159193667674, 0.03478764661497647, 0.0255166171794577, 0.025820411261050932, 0.013187588830929131, 0.04847822387913062, 0.07697643802290963, 0.0649650220669085, 0.03174752819411938, 0.09257763473977966, 0.00417253666279477, 0.020975941273894523, 0.05337046519402535, 0.003466696765709428, 0.028401740691474373, 0.06712309941048585, 0.030238972751483805, 0.06571950375913613, 0.06735313263150954, 0.05306722461095741, 0.0219401165527562, 0.05011260351766983, 0.026628067116102865, 0.044049450436667095, 0.027739710489948912, 0.04745997045369399, 0.08911796635197056, 0.02803941366202649, 0.05842137480935743, 0.09987102926618631, 0.03992931083625844, 0.02502061546810212, 0.03680017108338014, 0.07240990281946237, 0.051743918804511915, 0.012110188629688516, 0.013750861680525688, 0.05033084664553885, 0.055459207750015685, 0.030073668214402376, 0.03922073696289332, 0.0400693325566188, 0.0851767810602342, 0.023994172562754924, 0.1034396353568281, 0.01649493404153374, 0.044124726236106894, 0.055061347647419864, 0.05571559439563463, 0.05687155212546068, 0.03139043737563395, 0.023000924247166803, 0.060751381435341416, 0.04513804605531116, 0.03641386358668247, 0.05788190335395837, 0.04973761880049302, 0.05046735968320601, 0.023326841032793446, 0.05890894763832612, 0.06359710696063216, 0.021890280618061943, 0.05813435613808613, 0.07055213194220297, 0.056014085233572035, 0.13652793041640712, 0.009423670539211844, 0.07198715252020667, 0.051494296715264364, 0.062299756213061275, 0.026267113299259258, 0.020075406834122636, 0.03974859069492068, 0.014575446163484407, 0.052913635473458044, 0.10962839238345624, 0.06120011743698871, 0.1115717965688917, 0.02821835647937992, 0.02194260825372992, 0.11310161286664587, 0.014504005591715536, 0.02996224072581578, 0.005039112340103114, 0.03869112122864012, 0.0329570488763913, 0.014073896060337224, 0.04895699818828895, 0.05029199832689859, 0.02082998620256061, 0.04002464664799552, 0.04810787399389571, 0.0187424119306548, 0.03713012132192812, 0.022247965154688687, 0.037993862473916624, 0.06872821449031753, 0.03047337458889571, 0.015433718405303457, 0.0581067003640196, 0.026119804167519176, 0.027941408033873287, 0.05597208446312336, 0.028260673261097366, 0.026254620320434054, 0.04235184556173702, 0.04040345797435411, 0.02778133013165526, 0.045829823450936426, 0.014213437060525101, 0.010269653773115528, 0.03253456670790911, 0.044018757123980796, 0.03670782684498737, 0.11261101015993666, 0.012667514721772844, 0.032236891753611066, 0.027545669994827722, 0.030551414050522353, 0.022949676795472062, 0.06550670751640875, 0.0292478752277431, 0.03345995112472484, 0.057925026443216114, 0.2340873583189903, 0.07379592441382908, 0.13973354872676635, 0.12725051372281967, 0.13483023361092614, 0.11604292318224908, 0.12854095818775316, 0.1582209663766046, 0.11659433794838768, 0.20830505227129306, 0.20423085879414313, 0.13962516260723914, 0.0749203423038125, 0.1367280325822292, 0.13477882911120692, 0.21297725398213635, 0.19436595991494196, 0.11927980554079819, 0.1432538606346615, 0.07834522263898004, 0.18128408930234371, 0.13928911047837428, 0.15990560904385584, 0.18294328252875036, 0.1612846592381116, 0.18978380417871862, 0.24170095461510846, 0.1532065991552607, 0.13188149990333667, 0.1752746504761519, 0.07058272949389874, 0.12151826082939103, 0.18225976356094886, 0.15058271737108309, 0.1846110099746335, 0.12357510731465395, 0.11960156246899598, 0.15106359076115394, 0.11103347424537906, 0.17234632535086525, 0.14688686407621832, 0.10044849868262969, 0.1229170531094555, 0.1623235051069529, 0.11818256845036823, 0.12781603216764428, 0.07790605507550702, 0.10492398433627621, 0.2318985378670116, 0.1659922848545736, 0.21891788279096927, 0.16686666696783037, 0.18584304789621986, 0.21881070709036243, 0.09785450964925752, 0.28119315483397056, 0.17181965522468093, 0.15711410722184568, 0.15941229438589466, 0.18059165307110359, 0.15478740626525495, 0.1768710091710091, 0.07954240356001162, 0.1016623113724974, 0.1641130558545551, 0.07298798510624517, 0.21636535443605917, 0.1446083040847894, 0.15220817208530443, 0.15366851953008484, 0.17135724455358523, 0.10165340943081726, 0.10268719911935831, 0.17363908340133008, 0.17869374684749112, 0.21292096184146023, 0.18785503993351615, 0.14374037243185506, 0.22583524305974284, 0.21368257581226288, 0.18122830277969762, 0.19681750255967342, 0.11088067800888132, 0.10773182681371128, 0.12803406845177376, 0.18759142907877124, 0.16071807593107224, 0.11683186350931084, 0.12770384625201264, 0.13804758838828535, 0.12479301091403731, 0.08310470474703659, 0.15263534271188323, 0.14435885053488517, 0.13973301246521935, 0.1165929819727617, 0.14558416220449633, 0.09821017362898397, 0.13670917149753342, 0.19606451473889813, 0.19503752791112472, 0.1241523392438408, 0.11780148567331415, 0.17109818426111054, 0.17023023728641773, 0.15432226832114881, 0.12923918604370088, 0.19705368746672908, 0.1005240809172392, 0.11829172065781972, 0.1786190379531153, 0.1329199780499743, 0.15909904103365638, 0.10934857110823355, 0.14849676720557675, 0.23220458999276164, 0.19261353378815038, 0.20757991940744464, 0.16051725364260136, 0.1701568920285471, 0.11683772408193159, 0.15218499026471569, 0.16823834739625457, 0.09133025973794923, 0.16870524734258655, 0.2032409353001464, 0.19601448919744263, 0.11589786443378657, 0.13701217459334483, 0.20115991874087244, 0.13916285918845286, 0.1179827037718027, 0.2448850458547954, 0.12201847793954997, 0.1434852191877942, 0.1282736547892132, 0.21847980307234874, 0.10900255217547379, 0.1565621255506431, 0.1696368102585116, 0.11340083148811134, 0.0920442307007409, 0.11870238975050951, 0.18672438608782907, 0.10909536372750037, 0.0890390286522527, 0.13884427386426157, 0.1267684375747077, 0.215843296159179, 0.11645219799491668, 0.18367549404501918, 0.18410522340526506, 0.14605146051654894, 0.16605476698567792, 0.13608513159617303, 0.09277320932596923, 0.2159056863597324, 0.13086903810260758, 0.12170423633388935, 0.18029551412309372, 0.11481781835637747, 0.12773536310921754, 0.09830581204545114, 0.14104138338758102, 0.14269587283413257, 0.12406846027701132, 0.26283345936286834, 0.11015113247858901, 0.10973543784911595, 0.151035322116748, 0.1540610016954522, 0.11782265268266202, 0.1487601329121859, 0.13307555518563718, 0.14896962731595964, 0.15370708439619313], [0.05572333188366987, 0.05447401101851175, 0.030256675128194115, 0.03701035113584611, 0.036981814360666665, 0.037930618085327654, 0.06336358420911335, 0.02471585037006486, 0.011842035831162527, 0.013979166415670227, 0.06138318563781439, 0.05372995961337321, 0.04954728808614516, 0.02863980059872472, 0.03347767073841345, 0.014157952184999182, 0.05069456987022873, 0.01385358545268255, 0.04544574527009841, 0.021002882670971657, 0.04539886835001169, 0.02875157282687724, 0.029804836470453493, 0.013373187994734656, 0.0263325180557947, 0.039702671384739305, 0.06490751184643277, 0.03368626881931578, 0.019463461545866825, 0.05844002905031366, 0.02613554727436314, 0.024251591511851838, 0.023588504108990875, 0.021743034688575615, 0.023980405962755604, 0.026120708151269826, 0.025239442738013405, 0.019706449313690106, 0.045535197526577025, 0.053914644259719126, 0.018487733661106998, 0.06061390695732929, 0.0036115855384137364, 0.006175019154925981, 0.02145438999568503, 0.03135979768910235, 0.03868263297443909, 0.021448510270866177, 0.025847153475267753, 0.015966709714473015, 0.01703476555825722, 0.05641454620467079, 0.036321427417738784, 0.0299682219572846, 0.011000030508805669, 0.030693069453381246, 0.04300604634467633, 0.07126558962608538, 0.04354046161977514, 0.03770863644838814, 0.021785998814589074, 0.03160047378661412, 0.02014337606998461, 0.10474730147829941, 0.05730076054591806, 0.05357810183458271, 0.04092547411639844, 0.0549935412052418, 0.07257513266297118, 0.0470031100896097, 0.03856878081757215, 0.03953222831290576, 0.06832703722700958, 0.04262403277079425, 0.07372608783865169, 0.04276388595181127, 0.053090004235385894, 0.023824694761705976, 0.0325386461261059, 0.03703549031108137, 0.06804307907699578, 0.07238266073287496, 0.01484260975097817, 0.08098965090128683, 0.0466410837496721, 0.07702506928434295, 0.01772199430683207, 0.04836481605325976, 0.043415631422953266, 0.010997859607150239, 0.0261150122875528, 0.00045613027630738107, 0.016087497839884415, 0.05929034451142915, 0.05790898073164206, 0.06887878907183487, 0.029597508180285656, 0.01599180388204273, 0.012576402927328263, 0.01826815945546954, 0.0525197628585081, 0.04135157221988325, 0.0863260355207228, 0.04747329655313685, 0.04656767337432793, 0.05352647516936545, 0.0608810264947674, 0.03158150353438912, 0.03996883714271169, 0.006177454835720241, 0.05131950992490015, 0.07204474701035408, 0.03626388272330646, 0.025517151525784886, 0.024691571128524603, 0.02911403392171187, 0.05802973917114639, 0.019230618697380828, 0.023511420342049772, 0.041215430734859365, 0.040001652518948244, 0.03809539976740076, 0.017485479981968963, 0.03387505586649622, 0.02456368041044522, 0.054788938272864594, 0.038386359961042484, 0.04876080690132034, 0.016519885525227557, 0.07284536251738187, 0.009277816974527894, 0.03846479204273032, 0.07629022242561465, 0.041817326864768425, 0.00218536731066002, 0.1543813643436278, 0.05611371113768509, 0.021905541089513612, 0.1054252126824952, 0.03175794315944997, 0.04670558069201727, 0.01772105584912483, 0.03234874825143526, 0.01952358795660398, 0.04216829855595866, 0.09833015065880553, 0.08779995804352146, 0.016148382677666603, 0.033201687563691414, 0.03683851761443, 0.049808834333934134, 0.0179968475018658, 0.015010444293429535, 0.056461549529265014, 0.05305636531463074, 0.05525887958825596, 0.09220385278064398, 0.11526756559408481, 0.05108933114717084, 0.06895588816053445, 0.024140187005902973, 0.027236808241615375, 0.012075278002979055, 0.07733993142122224, 0.048009883687501, 0.04402154568402518, 0.050550461070792335, 0.056845688997136976, 0.028033888252872615, 0.026917497049115842, 0.02669221165800287, 0.029945350402305206, 0.027246947415293227, 0.015297983904489347, 0.022520809284140988, 0.0353924002528431, 0.05923816626290641, 0.01380060951510865, 0.011910974168248717, 0.039650313105554356, 0.048338523915698456, 0.0009388126812653707, 0.10291312610910786, 0.06549937605497337, 0.01403658853603467, 0.043949732602003126, 0.023766841716884125, 0.04854070984067456, 0.04071085075397165, 0.05084578413516284, 0.07867979621815105, 0.018807140614597068, 0.028602455727635857, 0.01805656214034365, 0.07771297027507136, 0.039736578436267954, 0.023492306448338975, 0.017127489010172508, 0.02693885366522497, 0.026901311526495605, 0.03222160446908205, 0.09519591642123076, 0.0344478904509977, 0.032324911425671274, 0.029508762639917197, 0.019740888796326135, 0.0526903055217718, 0.015021336148492994, 0.048550642170612855, 0.040329591776694984, 0.06630522394252401, 0.03203800766758862, 0.022544280302921132, 0.08599426582335465, 0.057423438035672715, 0.08843613277760246, 0.09576794661341176, 0.025976593606173996, 0.036131537203947385, 0.0206048731812306, 0.013061849862307072, 0.04593199276695809, 0.0532497220762795, 0.017408432604204264, 0.039904531722347585, 0.04434835113164398, 0.08522565746980329, 0.028535237257939675, 0.03271998296822271, 0.02720243770689253, 0.034823993656543956, 0.04500986039338093, 0.05249067833046279, 0.06924702455439875, 0.010718407011741113, 0.033449137793673624, 0.015997096591989602, 0.006507490780354748, 0.044231208627142256, 0.05828405737936978, 0.035191627760087295, 0.007647522499844913, 0.03073796412096389, 0.054493312603764, 0.05476734225427913, 0.03302506599274855, 0.04199735369653471, 0.07308074303211705, 0.03004850031086995, 0.1075320234221797, 0.027608853096382755, 0.08287267203653052, 0.010262600018552715, 0.0586835645710028, 0.049289001542473995, 0.052360849409934976, 0.09430549242683957, 0.026816915450317245, 0.023946738313703288, 0.026842784324300387, 0.029539894537940144, 0.03632775147355372, 0.020442370610732227, 0.04678608504154029, 0.041561610546083226, 0.031526877634948304, 0.01026623414814352, 0.08295533292356037, 0.041725227774511424, 0.015965689859923818, 0.014899330900891896, 0.04469222884865538, 0.016285062339457295, 0.027968224941662727, 0.02130194999007208, 0.04102171391188618, 0.027650805986336166, 0.026309713533508684, 0.03953025563650074, 0.04299802157366949, 0.06409417927986191, 0.02107923673916488, 0.029034895123913888, 0.07928371865061984, 0.11299295861634517, 0.034663222444754456, 0.11666807391109968, 0.03210281487554312, 0.05552632088262228, 0.02763063872172948, 0.04397162356443944, 0.009004984336394456, 0.053207238670438535, 0.062462630336202925, 0.007760442423468997, 0.049160030640421376, 0.03599503948803871, 0.058383089565341516, 0.041326574770913976, 0.020463834479150754, 0.034410792643264417, 0.09034343890004581, 0.025829106358991518, 0.028395340026867007, 0.021107078289553043, 0.049791907621247154, 0.031997498853372476, 0.016970285852890343, 0.03246142063289881, 0.06858841876589483, 0.030074495589360598, 0.009699676696571612, 0.038555837762091434, 0.0390651176923946, 0.030648073279148633, 0.08907752457044779, 0.07906375948580043, 0.04050401084485554, 0.03527146178267656, 0.004309654431117158, 0.011547429059001227, 0.03840400296593866, 0.03198631396967798, 0.017513652865384376, 0.04945824568670604, 0.009839947395507368, 0.07183697630440997, 0.052532839979375565, 0.02462904494736464, 0.04791142606747247, 0.043563624288165764, 0.036261887064263705, 0.03612288041040301, 0.04111495830358998, 0.034427635086279725, 0.017841613190549038, 0.03422725712880492, 0.047162866234899535, 0.020003543956385508, 0.028230127420336492, 0.0637271388944599, 0.02269387620711519, 0.0210797768311515, 0.017502837619113348, 0.014329916898972325, 0.055355870149909496, 0.009685546204808259, 0.08066951041860927, 0.024898648524897236, 0.027297357915930694, 0.06196513283817519, 0.06939866399813084, 0.18207132125333433, 0.10487950527139249, 0.12294189734083992, 0.12682287578260706, 0.13552017239553316, 0.06821749431471671, 0.2412604234151302, 0.1093209996038387, 0.08737040488349815, 0.17801269468280578, 0.125015597760437, 0.1687198643001818, 0.1352510763512504, 0.1162801193253648, 0.16036916884683794, 0.11550944253441789, 0.12199627671150431, 0.12112335016530369, 0.21467597734543586, 0.12425790615980664, 0.14291419257079402, 0.1186192921933628, 0.13485697007948352, 0.1978889684523306, 0.15637513881008472, 0.20620587942821367, 0.13780545863893726, 0.14667691001969, 0.05177107662142766, 0.10896207975043405, 0.23687205728023286, 0.18395597415585674, 0.12878779171695634, 0.10972824428350696, 0.13096052432252517, 0.11865971865312708, 0.0887542661099184, 0.15668427060929038, 0.19644981099953576, 0.15954685006891528, 0.18207230184587742, 0.13891426365702383, 0.11145507541274834, 0.1465959038825766, 0.11493338271975519, 0.11260159493934725, 0.12935747001920977, 0.2852975474970956, 0.14234869710860715, 0.15503264633157562, 0.2034514256182217, 0.1596306294443146, 0.12056700945381196, 0.18156942641062124, 0.11412789489352897, 0.10092638432979585, 0.13266015166957534, 0.16116976137122802, 0.08830480232474305, 0.0592005628371431, 0.09615266830810616, 0.08648917394419832, 0.10805124717374003, 0.24877288078348486, 0.25490189061289836, 0.17944144866158887, 0.11373176614964202, 0.14555929499047418, 0.13422738370155135, 0.07446447402359017, 0.12544742620159544, 0.1489312463109532, 0.2140088833027309, 0.1857943400259941, 0.13733049944764184, 0.16305723347731177, 0.11824957816110504, 0.1859202848807458, 0.24869737515766777, 0.10613762848680058, 0.2084056396157511, 0.11505817844262047, 0.11125863514720433, 0.17449684140662994, 0.16169002700236537, 0.07721839923291438, 0.13029957430497294, 0.1980054444603382, 0.10773441619089535, 0.04951997705164456, 0.13403976876889506, 0.12537640219013538, 0.08816355869414345, 0.11383929425069403, 0.12935367022310534, 0.19917363661431498, 0.08260819550243118, 0.07298510461564987, 0.12548739300860515, 0.1269595765118157, 0.10795848158698891, 0.10709808057835025, 0.12222855457014616, 0.1636299148442284, 0.12131440483273999, 0.08991872741570396, 0.1666057527425789, 0.11850456286582256, 0.1497059297417441, 0.13651293041484971, 0.14664568427589633, 0.11756447339130026, 0.20845765698580973, 0.239079064659534, 0.07176697885076846, 0.10629384147544062, 0.1901168685646788, 0.14057146505482737, 0.12526878215853246, 0.1226647726951107, 0.16154100757933434, 0.10568664018665591, 0.07289662146039548, 0.09596003549954585, 0.12579010499100532, 0.15739147701571066, 0.12170134818241482, 0.1449345196447065, 0.13869441174451383, 0.11255468737574355, 0.11758578595735374, 0.2003089329528232, 0.19897747214042372, 0.1427323692628453, 0.11005806045666819, 0.28205910998006023, 0.15787248830160788, 0.1939442897996595, 0.13344762876870173, 0.1456802296302011, 0.3021053326947074, 0.0619831397348354, 0.10925132390712539, 0.0630658173242644, 0.11542891137181752, 0.16436398029327393, 0.1093341380117401, 0.17805732696527438, 0.1480537845242408, 0.10781477115327313, 0.17958446195529354, 0.14114823733125964, 0.05989108001813293, 0.1941132581522388, 0.10037532196410241, 0.1543532795603237, 0.1238217952871515, 0.17698445147083652, 0.1051029884406636, 0.13657550447650496, 0.16225362256650003, 0.2636450529098511, 0.09723990795112426, 0.20344330508622432, 0.09509552825963306, 0.11819352350768544, 0.12423849349180538, 0.14824302356329658, 0.11345497858259948, 0.0999481666592821, 0.08579181176760504, 0.24081690447224727, 0.0988153218021316, 0.08681512137334194, 0.10270095805847838, 0.23784915646237714], [0.007142241069701531, 0.04981499751128497, 0.02988636546257523, 0.008975905554008581, 0.009374369908454678, 0.014522731653414668, 0.027991376118734482, 0.0429693698853014, 0.08237988597923711, 0.008107492223291868, 0.06950095971866001, 0.0031915821431715403, 0.014467399995473605, 0.04614362072560095, 0.04582771670914466, 0.025322750969339284, 0.05827895140335445, 0.039095991035743106, 0.02038428390909347, 0.07191759939756125, 0.010686496576865115, 0.015817109979839337, 0.029385416738448605, 0.036716901156450474, 0.052994407953754555, 0.04031102946628967, 0.04103873255512407, 0.045622489415109165, 0.025764580688349185, 0.07197119490874392, 0.0384756704912551, 0.04320860765273533, 0.03526773476492494, 0.05469455624059324, 0.024249603513688333, 0.02575356625921784, 0.04534542988685351, 0.009105107240048389, 0.04251883357703205, 0.052872707226103356, 0.06027369880147519, 0.05306907088285493, 0.03058887958045929, 0.08299798103830508, 0.040007765900584004, 0.04786042759435312, 0.025402763107370947, 0.05399939273634265, 0.08142069027188324, 0.04967074315514296, 0.07418561801915208, 0.009128572513169099, 0.03562219215617065, 0.011871098334180012, 0.03750260859247177, 0.03280790304885276, 0.039457894801612825, 0.08580526427155541, 0.05882322623003876, 0.036048956756149574, 0.02626199200148544, 0.011409307236693079, 0.007548455361111631, 0.017462374770172664, 0.03616330303972767, 0.06595030306808411, 0.03221361417203181, 0.007610296372384314, 0.04331389111616919, 0.06501457263385096, 0.0742482074025658, 0.07325380995509125, 0.016316741990346103, 0.03886631021516458, 0.030578137112541065, 0.009384134656659538, 0.059681700527547836, 0.04818297742355255, 0.02025074903823195, 0.07014156244094334, 0.05643515396983393, 0.00970981682785937, 0.01222128861568748, 0.05739145769527363, 0.03081407687146097, 0.07847403266256855, 0.04002125670893058, 0.015547358930381316, 0.028478316925165635, 0.018154596496794014, 0.08628118107275617, 0.02645801474911071, 0.05073890337840684, 0.04180793845725637, 0.049511638184588765, 0.009541685426337345, 0.03864008828156418, 0.03080534538434398, 0.005090397617389118, 0.023403731362533667, 0.04445800129624625, 0.04007289869590633, 0.013530450523830952, 0.03849590287333535, 0.0006681414285389287, 0.027481351167924946, 0.02371290529657516, 0.010764791720336484, 0.019185070939842733, 0.12664620824638875, 0.06902907253994096, 0.03790796486540668, 0.023255568042758013, 0.026213739953574636, 0.06690337773292296, 0.03056079671237498, 0.029555695101378426, 0.06261027846184951, 0.11288423541813128, 0.014488976861860965, 0.06438248880928563, 0.017211578651181152, 0.03210550192893753, 0.07623956103118197, 0.01762480456231823, 0.08005185202965814, 0.01101569796446711, 0.07225680780867416, 0.012402701108986813, 0.02986763461282657, 0.03763849343804102, 0.0221605392007698, 0.03031879719797402, 0.10225252849200081, 0.0074838406327481, 0.022038947640647812, 0.11061687563215533, 0.016978036747464252, 0.02815225266761357, 0.019857510361039353, 0.03228906617169419, 0.07949049344226237, 0.03936418692671484, 0.008077541058282218, 0.025141988693165685, 0.056156772939908894, 0.04022877077542005, 0.015217186526335297, 0.04825118989233048, 0.033957452453192205, 0.03927806715270685, 0.069560592002686, 0.05465014995406232, 0.011317702273147242, 0.07814060055440472, 0.023647669079383055, 0.03896376809045192, 0.12175132009771564, 0.04942774772644044, 0.08917544592892931, 0.07833563887904729, 0.0625954048647996, 0.0128232489054602, 0.07902981412987556, 0.0434349138560074, 0.04490869082210045, 0.01369663893485502, 0.025782991696389455, 0.011212477223917602, 0.027045278599666014, 0.017516100516302452, 0.044211884059252284, 0.036317156477560925, 0.0274862292327828, 0.021213878607076984, 0.03599819193984713, 0.06012367197282373, 0.03442125740431009, 0.018799590818103284, 0.028476698564425595, 0.014233092003832421, 0.06382151326585202, 0.03854326625925399, 0.02923438250417671, 0.06212664332481162, 0.018932315550984877, 0.027288597700516545, 0.01910442677927354, 0.04830659720145407, 0.053521805863466956, 0.03699333249260822, 0.031015944869948492, 0.01294065283746609, 0.044591082260012634, 0.02269466719289701, 0.04327579739413435, 0.01602532693199934, 0.03075265768735159, 0.033784711117585825, 0.028490909495420998, 0.026677497024197253, 0.09289735387409888, 0.0803157233542973, 0.030013112794427626, 0.03845691282842909, 0.038128061926052455, 0.015970034536064392, 0.031128737910260117, 0.03762669185356748, 0.03436144125918227, 0.026287462509747957, 0.009394261381408621, 0.06009585915073272, 0.0433754232982474, 0.02202570006521719, 0.04172091852993735, 0.05600903671415103, 0.05952218186951453, 0.06362405793380833, 0.06513513189049498, 0.025733992712752476, 0.05749624703199633, 0.02578327897936106, 0.025052651349875717, 0.04262821561086082, 0.09261852851317776, 0.0823008333663306, 0.005542998532614401, 0.045685400555451075, 0.03919228062694592, 0.0642661506971044, 0.019643815880220745, 0.100708493602372, 0.03322431780097466, 0.040599806309347196, 0.025213681116339662, 0.004616210259677422, 0.022169040861509504, 0.025530828110453103, 0.03238220714152821, 0.04337671798683944, 0.020523671691696492, 0.03421434471684118, 0.059099638413998394, 0.0539301920141424, 0.03427919405963152, 0.03390794402108558, 0.05288459691068819, 0.08468109152970776, 0.04502851080389754, 0.034720598599843444, 0.047771381364474376, 0.037039079433006626, 0.04264225034163364, 0.03194859371550622, 0.05033249756501568, 0.017061299013514674, 0.03878299432295946, 0.021345505919007045, 0.0038964771186827773, 0.05874552959275823, 0.01596233056437585, 0.06604899817536916, 0.03196345390601745, 0.06393513176590204, 0.07315940494018217, 0.03679380106228975, 0.046439545168992014, 0.030337652537010373, 0.02025009211783688, 0.05162149795421189, 0.019223128272701177, 0.05109110081027593, 0.08936025697978274, 0.021514353612738273, 0.03396428978791641, 0.009590941049428958, 0.04716311904391454, 0.080646910824843, 0.09337684830590602, 0.03402622799659449, 0.03777448936635929, 0.05453562363982201, 0.07091206303166767, 0.0622903639751096, 0.03273700927233985, 0.03453481461732619, 0.07817759494026823, 0.09139623522998826, 0.01568774933055524, 0.046724706077046936, 0.011171224346805004, 0.057172532749151996, 0.016851312398249586, 0.052933909990374124, 0.10219750805727898, 0.043553213153274796, 0.0283633022298736, 0.01423376999164541, 0.03218475947036378, 0.013633242286291095, 0.1066305754225581, 0.04951222041141122, 0.06411965170334424, 0.03913842847630863, 0.024050493431728215, 0.01357571770166678, 0.037287219142120694, 0.0457215216010809, 0.07324487736989414, 0.035130229643395836, 0.017296468854070674, 0.05891275892574942, 0.05115799943826372, 0.014919307601127415, 0.04324431501088604, 0.07621614172333672, 0.05505326925025833, 0.04423801531834949, 0.0943715904929465, 0.06938236164710215, 0.035476819311659184, 0.034217240529194955, 0.040623968722479004, 0.03474893236172295, 0.021500924091425636, 0.06534887042136923, 0.020216884121539134, 0.05680695559168535, 0.010580735266088478, 0.07407076611754394, 0.04178305975191536, 0.031005160267194434, 0.05858862329454673, 0.02647675709017823, 0.06053254075889146, 0.03995404781533345, 0.06888893973683158, 0.05779193015769125, 0.017587365845458645, 0.011913196780839035, 0.03138410757415958, 0.05010692297571129, 0.05243686831466133, 0.024424099190641316, 0.018150804361568827, 0.023902749545091105, 0.06576160029057534, 0.07060881478772049, 0.05773044777132812, 0.05219038335546371, 0.03720580697840741, 0.17084477769751705, 0.12927467123635356, 0.11682960354993421, 0.09264118173309872, 0.1416984263567194, 0.14437450937205745, 0.13358630600475496, 0.0885225321737028, 0.19450367188021062, 0.14378629174203644, 0.1556450876617624, 0.08761647998565629, 0.13550652070872246, 0.14970407580896733, 0.11567246604470477, 0.13380172992906264, 0.09310801273151752, 0.11453104100280231, 0.10456884895721752, 0.12166711937395797, 0.07246966533843549, 0.10598800385430937, 0.11035177856683732, 0.16815836781695967, 0.11999269631961662, 0.14710702242389803, 0.1131506578155583, 0.10342576150451938, 0.24584207353332352, 0.24704604199336422, 0.17384228056236622, 0.15325287086588724, 0.1141136379972581, 0.07450611090227481, 0.14866562830584665, 0.10772801169584836, 0.14000034650727627, 0.125058981319589, 0.16638576293424254, 0.1840381141030981, 0.2169389704302434, 0.2505399391896302, 0.0928442026939123, 0.19023752741275296, 0.08425438055588354, 0.12113739255695574, 0.08558660745620729, 0.09464493066432977, 0.20724153837128995, 0.18406835925434867, 0.16096293295343078, 0.09623370508873656, 0.1278145153135542, 0.12206878693353747, 0.12984387456409394, 0.10617204115635927, 0.2351697486254477, 0.1812240433308386, 0.1366716178674852, 0.1236361645222191, 0.08657045587296448, 0.14202784416416, 0.11876242040025613, 0.114010744728148, 0.14048397781387453, 0.12118941758789363, 0.10030348589944263, 0.10710021030277976, 0.09418124062640053, 0.16050076743047084, 0.11154023374641135, 0.22706502868283182, 0.13355842040431115, 0.11921104148871477, 0.161457258847452, 0.16238761134445667, 0.09970720136357893, 0.14809716042251359, 0.11577054062077116, 0.15975197777152061, 0.20414729392336262, 0.0665538347957115, 0.07948329221577415, 0.1883516640913102, 0.18479811928925977, 0.11483918454858566, 0.12331325080125563, 0.1229541011214737, 0.20498862700356593, 0.14763062819838524, 0.15976448032644489, 0.14228589322057464, 0.19289455016053494, 0.1273519744075114, 0.1187371624813926, 0.1123391945035227, 0.1274453835081189, 0.21815089088293815, 0.08625476636112699, 0.0727756944815478, 0.1672994147144979, 0.14845470897853374, 0.22602252091371247, 0.14673720113933086, 0.10529674739847261, 0.14106632721039558, 0.1508184119818672, 0.19679326353774917, 0.15390703334443032, 0.2864245547642631, 0.1322957236439951, 0.19002397274298055, 0.25118126203456237, 0.15533233992755413, 0.15001055694395496, 0.16674001731218832, 0.11142564997557672, 0.2890765672970203, 0.26435049731404553, 0.27265700481591687, 0.1532423601395661, 0.10057803648974627, 0.10236253871792748, 0.13100969184550548, 0.0793800159027019, 0.2974682944195886, 0.08843725892685114, 0.16624544627003132, 0.11507589039542984, 0.07306758164157791, 0.16648328592700345, 0.15366617530103654, 0.12236268890480842, 0.19880825863970866, 0.07561196648185292, 0.16589224909342107, 0.15063380011387412, 0.16461237664184264, 0.09594321986960788, 0.11807056639583842, 0.1603290718048811, 0.24022326293972232, 0.24814925456960357, 0.1889439726308469, 0.13111712801600658, 0.1655001806155328, 0.13051602478709914, 0.08799291260900997, 0.14631911631553404, 0.09358937641785992, 0.1925394990511479, 0.16195316288259723, 0.1944446984317995, 0.0655984235627036, 0.19854328414845854, 0.11726340849793727, 0.28755101044812514, 0.3388723130187681, 0.13897982546158377, 0.21155289734803864, 0.2672096293780112, 0.19748982132202197, 0.15373017428623093, 0.1132975398532806, 0.08442326463879117, 0.15462907121306466, 0.11086249874243814, 0.10343418847168646, 0.12408667018697148, 0.16835748939023865, 0.05425856028112674, 0.15366133362535508, 0.18539977410147268, 0.19102606171321487, 0.15551813157095065, 0.14892799809815424], [0.04822258416923785, 0.03191959345713258, 0.03381099942470751, 0.06304209158124943, 0.020590721622049328, 0.026042787433271448, 0.03166734177108494, 0.024738643401032014, 0.022017282674149163, 0.010901916670733163, 0.008330618204068272, 0.013011622265161527, 0.046300753019750125, 0.04530484254862513, 0.045026553449251, 0.0451940892174119, 0.05431489072619908, 0.058593078095826416, 0.008383835459338322, 0.022001918780827717, 0.048561899832660155, 0.0342893562159471, 0.07641249771920905, 0.06511597203150873, 0.023010186250171354, 0.06283899784208306, 0.05837622158710034, 0.08043712530765804, 0.09310847238427208, 0.010447028025443996, 0.013745454057390171, 0.020837369374930862, 0.02749695254850292, 0.05035162295004533, 0.011929135240103689, 0.02668811308760797, 0.026897571102205305, 0.05553323865657853, 0.04041592605532177, 0.010140275886853137, 0.04820634693568272, 0.012475842395947586, 0.11317487385484482, 0.06735540791264466, 0.009762982372194529, 0.07535097564780906, 0.0774594258156515, 0.045747622216661135, 0.010772918955603195, 0.050701135243739814, 0.022112026682964737, 0.036862722162397644, 0.019319879431878368, 0.04692927836590717, 0.06161015450714096, 0.013385311336136393, 0.08662639561319545, 0.014726488058635545, 0.01628141576093772, 0.07813245703976962, 0.05641939554123148, 0.026828895150233182, 0.03668222801699754, 0.03334164033613859, 0.02631161917722033, 0.05687273956174332, 0.06961944287702923, 0.0426351563674548, 0.05513349397768898, 0.04207966601355903, 0.049647568995433475, 0.03736867344066982, 0.036848032426449566, 0.0151350207236265, 0.03559278204075752, 0.005156690557111776, 0.07241937932708571, 0.04193941829726101, 0.018540923145689794, 0.009818582160909091, 0.04093930583387133, 0.04172597087979798, 0.03137136944719861, 0.04155585339533226, 0.034113389650179494, 0.01981956411092993, 0.003315561742994995, 0.03708601380968767, 0.06257185149156759, 0.05556910306275372, 0.06000264923298552, 0.035318285076608585, 0.048440838788425734, 0.037655937260076884, 0.08629623470046828, 0.06949316860447008, 0.014658598304395715, 0.03137265455969159, 0.0805760017265716, 0.014350735338314647, 0.03058803305330296, 0.1048907820856379, 0.042067220915229096, 0.012820387567063014, 0.024075701554876663, 0.05520753254513106, 0.016187127574437087, 0.05466640633981555, 0.041956253079397064, 0.04178964044718493, 0.05277988418275791, 0.05278276467335321, 0.08405060116802493, 0.05890890933392991, 0.0360067414810821, 0.05008096025595742, 0.04261740611024922, 0.06373828164331856, 0.0450004949685066, 0.11887169518177548, 0.08439124216355624, 0.040315982224720145, 0.021739604529894648, 0.030480043384276574, 0.05406094790105859, 0.1720666726149859, 0.07113543894862936, 0.01860561735567547, 0.04439648826636615, 0.07754645340384976, 0.04244933408054133, 0.04559539288522736, 0.06556463908524283, 0.038227235838290186, 0.027443004636875084, 0.032964943412451014, 0.05309130275441755, 0.04683869229930063, 0.02494670713560716, 0.0196637992837256, 0.03046711373533453, 0.040624807588756084, 0.008704969941097642, 0.021477050876485246, 0.027438364059273756, 0.05698520509946731, 0.11539305079608195, 0.04677053728711702, 0.07062402163301745, 0.011575862412310896, 0.0884979790557296, 0.06114886232441472, 0.10456039134653346, 0.03466821350758115, 0.017510638309402332, 0.014120913749080033, 0.061143254560808984, 0.04539513367138082, 0.04184589428346484, 0.06573157730482279, 0.020353150095850713, 0.013644720198616627, 0.0354473632309706, 0.019597885078720508, 0.041222099530240225, 0.03419742183459382, 0.05790176035295572, 0.04779520286847988, 0.07889839174646525, 0.06096285617639942, 0.0893177620826229, 0.06278088241214715, 0.04377298845699237, 0.023616931716641112, 0.08122087921947241, 0.027897342656468673, 0.009905473768500792, 0.044325437441828756, 0.058212183010313785, 0.08823792284895336, 0.05154233042811675, 0.024767425324347232, 0.03233981949667777, 0.007231525265641752, 0.03712804905409294, 0.13109386958662542, 0.009604720098357047, 0.012260160874575378, 0.044055801305559375, 0.011528286436993268, 0.044646340181990984, 0.05321127978423911, 0.05919778576841759, 0.026425174475016616, 0.009715509818746679, 0.028132989386757536, 0.010331881179985021, 0.04922319458977831, 0.06008642477794521, 0.04780046972295931, 0.06267902719217443, 0.06250312191344078, 0.03537073145590482, 0.036132276478794315, 0.01645505533463532, 0.021305056476605036, 0.07303425681687171, 0.04235538488794719, 0.01499946529586469, 0.09148573728218194, 0.07073426934620065, 0.018625901448690606, 0.010809940154544048, 0.05568682013319866, 0.05164163840574123, 0.0755658939540867, 0.021946653197970123, 0.030768697653266213, 0.05707352737625761, 0.0013019485918301789, 0.020938203782744465, 0.06596487406040392, 0.023167875873285438, 0.024662743239933928, 0.031982728678192344, 0.0763386468433084, 0.015458482197455823, 0.033258029500082616, 0.004922162793997315, 0.008731734180342286, 0.04499870615320341, 0.020711935883868608, 0.04892923516191302, 0.005999354236278564, 0.06164935905666602, 0.016822961399391774, 0.030353608233253324, 0.06084953262020023, 0.026949599963582815, 0.022132157558395017, 0.04945513153929384, 0.012801824299047792, 0.041406366658667405, 0.05233449981577935, 0.017084195466351607, 0.002656427593225794, 0.06016473428556516, 0.0065429434142706385, 0.017665893688137015, 0.03169177231499024, 0.012717344910807669, 0.0436357744488745, 0.013955939587415948, 0.0611579864315929, 0.09015580864563104, 0.003205744475464247, 0.03789386501716029, 0.06031463854014874, 0.049503847070398836, 0.05371352319695777, 0.04969032819292719, 0.010701270582484863, 0.07352413174005286, 0.05363756174882574, 0.0463060466873069, 0.01896242663684872, 0.057065054443815065, 0.0681536179035902, 0.057592977123755607, 0.07121471372703392, 0.12388499754090464, 0.05655230030477528, 0.0314035470552382, 0.027740122262208212, 0.0649594909120952, 0.09873138920914742, 0.029738552628024936, 0.03100238511368873, 0.01948854517972758, 0.057692783058530865, 0.05443631566219753, 0.03774790611538676, 0.01667462762505297, 0.008961996270133363, 0.0439828735656075, 0.0060212107247582854, 0.055854187362016215, 0.04340902008416672, 0.052569819043480584, 0.013232607987799473, 0.022648035420946056, 0.05668607457811314, 0.05009547762212254, 0.06397627834831515, 0.03244720970190341, 0.04339988448566968, 0.049884010541943774, 0.01794027765431712, 0.02377043083880938, 0.014513179494608796, 0.03096782880264425, 0.07147308454037675, 0.08056049610698417, 0.06490728202005548, 0.033621603337627266, 0.01535227942851282, 0.05599386434281065, 0.019580452748003508, 0.03901284751332095, 0.018084583721394022, 0.05110682093448216, 0.04136116364069524, 0.022069131504864465, 0.0685262890352357, 0.04388503647679764, 0.0387248176059896, 0.03893756788344153, 0.04254898679773173, 0.01802547620759616, 0.03947850639721559, 0.013574425885904462, 0.015432005241182784, 0.05847886587763506, 0.023666486114023194, 0.0071487135550517954, 0.024034104895808046, 0.054420124393917864, 0.06248063723286314, 0.04108763960821014, 0.025365789788925362, 0.07226947890294176, 0.05545399452169096, 0.020859312048302065, 0.004938240106698247, 0.053458783640376026, 0.013745735594702345, 0.047688260824689944, 0.024477625753910794, 0.01549907623895354, 0.023940046535684698, 0.03670298899974554, 0.02411871164616558, 0.05697416194203881, 0.014801885474533325, 0.08465029479515168, 0.017945274462803237, 0.020904009448244207, 0.017097492837497306, 0.014959288772285707, 0.03961373623760958, 0.0657099429818411, 0.003629607996234911, 0.13098546814533973, 0.12721380278948816, 0.12027532913752141, 0.2910857401307552, 0.11662069903386217, 0.15681737072525487, 0.0868897459980461, 0.08580656662102669, 0.11182409996587424, 0.2463071501903957, 0.09309948617292028, 0.1425339984557321, 0.13102593290950024, 0.1937917157286598, 0.17419681073196475, 0.11448938880235919, 0.15325731417584806, 0.12466592458827842, 0.09317054848877654, 0.15937918406580726, 0.12040195581052573, 0.19327794652312033, 0.217301958210526, 0.21973920565459037, 0.23493609180854214, 0.1398380277978797, 0.18509264945262865, 0.10408510273743062, 0.22949414027314033, 0.0656500042626454, 0.13121043752518394, 0.14552748701985807, 0.12372466299923197, 0.203134341826362, 0.14117546409608858, 0.11215716435183441, 0.11962931017361342, 0.20843824431780847, 0.17020394514885642, 0.1831547840828857, 0.14853127180568634, 0.09813709650188686, 0.21967319951903438, 0.17830826672575167, 0.08723835430798993, 0.12017563045505555, 0.12591952788493327, 0.12734482680717785, 0.12383709406299938, 0.1831393703938492, 0.1275071148730574, 0.10529377497732641, 0.0872543119194527, 0.08460453636343442, 0.11802274718760483, 0.10480301139215309, 0.1268435524956834, 0.14421346236861524, 0.13697272106524438, 0.1694441085020381, 0.1152692816310352, 0.13150070823969381, 0.06272187832021905, 0.19638573540554893, 0.1170875913193149, 0.1899623945956269, 0.16949748950860194, 0.07773648917434678, 0.09425381979634685, 0.160585266928519, 0.1220789069550172, 0.16702351580944755, 0.13679265975952148, 0.11713256068047016, 0.15837082849635234, 0.09425592653813863, 0.14662809489715486, 0.09004941435470697, 0.1774022605029806, 0.13025006970330594, 0.07145698137220836, 0.0901903975154123, 0.19902078675166254, 0.17721064659135957, 0.21608651375337956, 0.09337729263690212, 0.19958945381785595, 0.14309060729799733, 0.13432820087238667, 0.15096430576616718, 0.1792417908267629, 0.13600550441732331, 0.10985611201894861, 0.08307879565343743, 0.21720141683134342, 0.14610988238165457, 0.09653902943095855, 0.10301646370921405, 0.23903522910850666, 0.30554503683120976, 0.07791592994885099, 0.22065894017296456, 0.11758790036002476, 0.1494168388026376, 0.134418890360863, 0.07866159396907015, 0.10959771056208881, 0.12235733395021771, 0.16008416881724713, 0.13001719429608316, 0.1651702265465452, 0.18957899823304147, 0.21826854666634915, 0.0985245454695917, 0.09879869003329547, 0.1671515444233533, 0.20343040416557945, 0.18647313989218206, 0.15876254457379543, 0.22724360377798158, 0.2205558400601149, 0.19467789559595047, 0.12074202990099309, 0.15236733451245293, 0.1285636037467949, 0.2439088966216772, 0.21889873059286227, 0.2505367062985897, 0.14770806436577152, 0.14269496885038194, 0.273285074339759, 0.07669875413299569, 0.15863774885093013, 0.1348140997992408, 0.14125628637210016, 0.10959082343164953, 0.0970970402141252, 0.16409727444331493, 0.11608252226705514, 0.10250134618892785, 0.14595919288694859, 0.20699741679333872, 0.09555102881765175, 0.19103758367559603, 0.0802030241597564, 0.11309890857627315, 0.19809754355059517, 0.07297522208142666, 0.13399239389165757, 0.1006225691807847, 0.1566689335290463, 0.14230550507143622, 0.21958657029655673, 0.15260312105378798, 0.18035813415002439, 0.13690982524666095, 0.12688112144749011, 0.1339877667205949, 0.1846168782081335, 0.17692131050411733, 0.1947353828337885, 0.10665086143079305, 0.27797892569534244, 0.14267595454810128, 0.12394348835392345, 0.1281265505859929, 0.14062345178136904, 0.08893154651647614, 0.17655386409211546, 0.11903714719078234, 0.12974232194885132, 0.1251045252466875, 0.22825375199317935, 0.1059194083415693, 0.14230155205774692, 0.173403327503512], [0.03610596901947453, 0.034058487959085934, 0.018795409893256523, 0.028952617280846162, 0.05185326636438409, 0.044079396813627214, 0.05475150721688425, 0.006448716035998997, 0.03610744373872876, 0.04245697197714641, 0.06323589650433391, 0.06039297103040642, 0.05265092860246378, 0.153864806578044, 0.09774297490836152, 0.025329099923011758, 0.016528488692617225, 0.03764670973102893, 0.014308940453995622, 0.04421685980032048, 0.09739649632284719, 0.01667338273217601, 0.07598623873726015, 0.02553974920433135, 0.026654230933936856, 0.07296319450101546, 0.029697352419457132, 0.08157252889847563, 0.03683329672522603, 0.04575684591526947, 0.019036754402482224, 0.00428632035055348, 0.017992051791459802, 0.029162253410885894, 0.027527216851951617, 0.029502865678120046, 0.05691192878950989, 0.050529711579363194, 0.03699551584319242, 0.05252444365572545, 0.04530796052647695, 0.04577940337419991, 0.042802408683083715, 0.04132148411665713, 0.041744946877682404, 0.047272439790709365, 0.06511905170496433, 0.028944807014458125, 0.07688181084250251, 0.03831367353878675, 0.06850316084080166, 0.022772120597261577, 0.04754556928791347, 0.004562831647138322, 0.06188038436155166, 0.03632344988985889, 0.03020869887193605, 0.044277932329644124, 0.08930145207071498, 0.033874305100330425, 0.023916947069547834, 0.027833759273973205, 0.010322605770441794, 0.01707319635897875, 0.056569717313733794, 0.04340393709078912, 0.07237701466487301, 0.02222735547430573, 0.07380673391444069, 0.012670208478436596, 0.046439123820633664, 0.01218513405371097, 0.05683316729001461, 0.02320696359440204, 0.019756340789758874, 0.018590310918948343, 0.02658263044131379, 0.05129432861482905, 0.033512795869741714, 0.0623316178098321, 0.024269519884499813, 0.08966861503018488, 0.0010124099700929477, 0.11766519097070541, 0.047420980408787734, 0.005991107299773684, 0.06900003780761073, 0.037793381094572046, 0.021552732702524915, 0.025960237628990607, 0.04387753264557931, 0.035337732218566446, 0.057585143874729836, 0.04545959997020903, 0.029701020065394622, 0.040676618115075176, 0.01779084454380697, 0.10638043239352205, 0.04793261222901845, 0.023483176595501365, 0.03422282531016296, 0.04980577764311626, 0.043102297631482926, 0.06923458328650844, 0.02889273410302497, 0.020242785554259055, 0.023356306689581083, 0.027784783272973956, 0.011198637845565476, 0.047542152535771175, 0.04202585982819719, 0.02574757928208959, 0.041352855417156414, 0.002078095849062647, 0.03034078775184049, 0.03987593749057382, 0.02534683485845885, 0.037823580280547185, 0.009482023456404287, 0.029455337583297686, 0.05727099036918052, 0.019977970026253213, 0.015407300820844549, 0.0479908770460996, 0.06519611248926771, 0.029100797837600115, 0.04113750427120155, 0.03121284287302725, 0.04887734419636188, 0.08619308862234316, 0.03364865390223361, 0.08536285615616268, 0.017790155064675118, 0.030806837340576515, 0.07682279908969518, 0.015306323729155046, 0.025358040809571266, 0.057298094559941566, 0.018473109042632486, 0.037943017218382134, 0.019188164019837015, 0.01112584704383006, 0.07643164991731606, 0.025296638862440185, 0.04896734420570636, 0.013450109925601753, 0.03724284732954637, 0.017423574332027666, 0.06550343632097207, 0.04978883560867079, 0.028123723553313364, 0.035185686748234496, 0.05442978093220342, 0.0453186551138999, 0.06347775429246888, 0.02730647244700982, 0.08666645435075607, 0.024943462753247832, 0.10437089183758344, 0.036630723925848166, 0.0629037207803659, 0.010542233602233953, 0.0137517053348523, 0.07501973455110866, 0.06895914403421265, 0.03271532515364309, 0.09829795964422727, 0.09618115145713092, 0.05149272623501959, 0.023084098413105936, 0.01800411193060779, 0.06982119979276773, 0.05231589154009858, 0.03300125214962229, 0.07687034250627603, 0.058942260971713456, 0.011089446376107875, 0.02235737208637499, 0.009770706453691087, 0.02249161367334666, 0.07342835542775931, 0.03427809089302056, 0.0419761254001529, 0.010940445147665038, 0.03680386362717517, 0.04013715049011573, 0.01670488809806205, 0.018714836595820326, 0.07222993344429039, 0.09735344984238187, 0.020207442087872375, 0.01884970062923047, 0.03179015141100653, 0.05225593749914439, 0.02932399946955904, 0.02571376799155147, 0.032339091713149706, 0.048958281385562116, 0.08941969008094842, 0.08607197778239366, 0.026792844967736353, 0.08049144860236876, 0.014079120779980817, 0.04082204841618096, 0.03640025786514725, 0.028592870052483295, 0.0705387330644073, 0.05797988599947384, 0.03882752318355826, 0.07317029871046543, 0.0364229072546286, 0.02695578803879119, 0.10962084641740208, 0.03192720454066031, 0.033895046930880315, 0.05387317592037782, 0.02313593192206275, 0.03076702758159128, 0.03862637913815918, 0.08462008028741806, 0.027150500776065935, 0.07767971439827835, 0.029681758699758403, 0.03723350105687015, 0.07913094539675983, 0.04836154485782308, 0.027685308671225945, 0.05583942867815495, 0.04491169005632401, 0.02614385932834158, 0.010335039377452867, 0.06490894443085117, 0.03190664848643205, 0.056869273013885946, 0.05651741266070355, 0.025447606064018705, 0.036519200676271034, 0.0740167415971237, 0.01087514572821918, 0.019062429839264483, 0.044601638951609214, 0.07741228842567052, 0.03718545202225928, 0.022370384089768897, 0.0006306564471507896, 0.032811197226927165, 0.042723084108964096, 0.049160536258451404, 0.023236046207227537, 0.04072499656749349, 0.035151071065375884, 0.014698823666079872, 0.031586345210070574, 0.021187061699287548, 0.013349531199632874, 0.06348890087176716, 0.014624737218142518, 0.0222243792227199, 0.027935520648175192, 0.020749328635452736, 0.03565013138276916, 0.015193528773623611, 0.02619962478356977, 0.014271915424615146, 0.04977165225652918, 0.01883229511159082, 0.029683118505824, 0.021937917880413514, 0.08002305478458444, 0.048332988930445527, 0.054652153273984316, 0.07641507943551387, 0.011810702835059455, 0.059589980650813355, 0.004046805355051954, 0.02147818468661318, 0.052209600671044284, 0.03209569983394637, 0.045750380133188544, 0.08181302688054501, 0.02754779205837798, 0.03416646805201327, 0.035855328033287684, 0.08594271576692981, 0.053230516252017794, 0.013955992255960743, 0.037376368793869214, 0.05188998495859485, 0.021270615078749198, 0.04523656496237363, 0.03353784694486568, 0.015984171731097084, 0.09507565593887722, 0.08552200326155271, 0.0743343463287719, 0.07090353647307043, 0.022426082512303706, 0.03062613252099724, 0.04575289290158018, 0.08336167361947798, 0.037010500522991346, 0.018220382382071788, 0.024740945495244478, 0.05253765484197967, 0.009557709112883577, 0.024204348784781272, 0.021989868217778784, 0.09117081385826872, 0.045232562152969266, 0.03239120101375926, 0.041220881450440616, 0.01951978624527974, 0.05115746700715634, 0.057437020774570205, 0.02756442574243392, 0.05096530151222983, 0.03134219681904201, 0.028016295043691516, 0.08733636759702237, 0.03631644018535172, 0.012253620398921833, 0.01259066461164865, 0.014491990460233103, 0.0645074071062188, 0.053902490274800416, 0.04192221579292128, 0.019167071704061765, 0.04118651857659702, 0.05019437574270753, 0.05229491605273178, 0.06259689490581233, 0.02361690107312414, 0.014923205073442192, 0.023724544087364793, 0.07161121019312451, 0.035961036675519524, 0.10124017394358113, 0.023555114166811112, 0.02125639648687455, 0.03445446731582765, 0.026498741898385268, 0.03131548716356197, 0.022495277488844532, 0.0689771930657087, 0.02578935022616098, 0.02414463606152323, 0.050317593324448795, 0.07417591168515145, 0.037178630009293556, 0.05838654845231964, 0.029463226373697964, 0.05204166270672314, 0.13115449778495297, 0.1347968628209445, 0.09920973450906816, 0.1304625058847089, 0.1823546971765257, 0.12222515313976234, 0.1772865505828973, 0.11279732274312167, 0.12887990612897182, 0.15732260571131784, 0.12327363639469109, 0.15138683389992486, 0.19394798234345453, 0.27297474744339145, 0.2525832182577541, 0.12448584796079706, 0.13150188801509718, 0.22347040624628145, 0.2053147812764491, 0.08030987810343504, 0.17473598341307334, 0.14907367737783542, 0.1474072063161481, 0.13193431400483654, 0.1289485935722628, 0.17296627434270997, 0.11867755318000434, 0.21612956789472412, 0.10270673436142745, 0.12473579946785204, 0.13122177562646328, 0.1034236700844861, 0.13383199040207172, 0.13573067803536693, 0.11191099731912536, 0.15196921393996285, 0.18562091304169548, 0.10922732237245768, 0.1391631349801056, 0.13788146988278435, 0.11056705693443937, 0.1359703716251158, 0.09200491506846682, 0.15540081286622634, 0.13315921198696862, 0.14388530094537044, 0.12266894021341879, 0.20953972553533895, 0.12711334567997726, 0.139777047199107, 0.09706140180388767, 0.14440314573866708, 0.16151307601361506, 0.0707487024426941, 0.09554029592583257, 0.14999140474584796, 0.14247753777571265, 0.20848701347506818, 0.17311417527737158, 0.11989514268333874, 0.11446793834047933, 0.12032009165493712, 0.18447987104375518, 0.11242516489038545, 0.21861428214657694, 0.17712538100538716, 0.1617434539742047, 0.12866956902848137, 0.1237293208138116, 0.09532070448321682, 0.15326350416627624, 0.1361534972825358, 0.19591569449872742, 0.1382301011753659, 0.18097356322311586, 0.12404741584173135, 0.07865780183384496, 0.08125189811952653, 0.11867444286303175, 0.20016729861738222, 0.15125713521434417, 0.19155296166577648, 0.13262495759033388, 0.19035181240929713, 0.126771034612771, 0.07528518401687184, 0.21802885307660028, 0.14555253809498203, 0.1130751292071035, 0.07925943366342014, 0.14095639359326134, 0.13335114765551784, 0.32384491615718414, 0.18741582640476767, 0.1684657376139395, 0.13912170494516052, 0.0976395606994629, 0.19632195092497334, 0.083180662364729, 0.108193954032275, 0.18551030526718787, 0.13614715407452277, 0.15354007722869997, 0.20067139979331725, 0.14685971392018182, 0.12160200956127337, 0.13140890026284804, 0.10449083822388804, 0.12030303853774264, 0.19313966765278773, 0.15489378523442054, 0.14325580649798916, 0.2073537242869216, 0.12012081686407329, 0.1352478587819684, 0.14010320147199018, 0.10140436190751292, 0.16993527811381126, 0.09997491078871874, 0.1774127252640263, 0.2019234479314858, 0.10992488373191127, 0.11939053588937368, 0.11680557137174953, 0.17168441006252844, 0.13130963058961978, 0.10814970479376855, 0.20288706396616277, 0.11021100224987154, 0.16422251449717631, 0.15074842218910495, 0.1847225983416842, 0.21173472065598736, 0.12801459449673855, 0.2336855145591882, 0.06443563232859296, 0.1733779699932183, 0.12190847537450253, 0.13205399226036765, 0.12853797044484847, 0.12759789629208465, 0.09416106187047497, 0.22736489081815367, 0.10426445158138391, 0.09678430014079618, 0.12211436916503215, 0.0897695241315711, 0.1023196071506508, 0.21065769296499992, 0.14506987205916835, 0.14475986691972903, 0.24891618519060074, 0.0988795199701863, 0.09249333442459184, 0.13430298125791934, 0.08118743182069833, 0.1831001926574015, 0.11663546154816305, 0.2566074934457579, 0.07508706601877367, 0.21718183562399881, 0.08116002885564681, 0.08848988916724922, 0.22881817493227222, 0.17243520687184027, 0.22505078434703812, 0.19623913682035862, 0.23380644919891513, 0.15015235981873928, 0.12714922923835056, 0.10801878036750902, 0.16397728975261414, 0.18183536617265594, 0.11860185603220617, 0.153640664573158, 0.11883175135740351], [0.030334415815530286, 0.050802500167440985, 0.056295645528382836, 0.019734742855953596, 0.04232818876663524, 0.11848570178112677, 0.012557866472390392, 0.05014692425667759, 0.059496380028224764, 0.08050408139224015, 0.050582062197668906, 0.08846836209657694, 0.03945088892754528, 0.028926694780708324, 0.05183973342120167, 0.014203558356741504, 0.07405103935349373, 0.027793853753997434, 0.013103257872224336, 0.02583788764182358, 0.05615887968170066, 0.05435313383537916, 0.03406352498718808, 0.011518668203103927, 0.06546497104629394, 0.02904221892447001, 0.0256834730445858, 0.09004818861402812, 0.04880260082802946, 0.02322008093488553, 0.016455880794373733, 0.00808596898305921, 0.029304759171340736, 0.044412438216949665, 0.027139921101831624, 0.017743889099708008, 0.008582327882909488, 0.03270352356916955, 0.033027938822464596, 0.12295747956921979, 0.04789898096914253, 0.0233158974667951, 0.013520399450264392, 0.009912255561850485, 0.034528655270414974, 0.020784254583920685, 0.023056804615583633, 0.0364451889219063, 0.036760177463293076, 0.02025288259310107, 0.06129364528122449, 0.03675512511343245, 0.027532508604288585, 0.07050184593085321, 0.009231968527479519, 0.01853739339557867, 0.07964582542978949, 0.042010392513005965, 0.08469652054050276, 0.060272258556177544, 0.10674178074564665, 0.06675928425524505, 0.03537607108873706, 0.05038476774408933, 0.03082119191305772, 0.020744971510383393, 0.031755037770997134, 0.02729221938117858, 0.013432465005485762, 0.008425751002505422, 0.016099268780840982, 0.06206893392147557, 0.06549088780077235, 0.0727335443239539, 0.03989720409135184, 0.08283938551622053, 0.015421529946428154, 0.0035649908738466162, 0.011720284350186348, 0.03309102999346872, 0.052896352529886274, 0.027302835444589297, 0.03754159863737803, 0.013387234216826338, 0.05951542497402238, 0.048376870446748314, 0.020959937697156303, 0.04899305794688483, 0.02573829429644731, 0.043320418185284065, 0.008639349722333493, 0.021481059431549043, 0.05814521926485243, 0.10942497305692205, 0.02984408123959457, 0.039688586858251405, 0.04747685886198475, 0.022689955752162684, 0.04037924576550722, 0.05626119838486757, 0.08483636989108018, 0.03129444081306217, 0.06050116945839217, 0.06333336587094011, 0.025516306913848368, 0.03604138397701806, 0.04939316268709879, 0.009291429399332453, 0.10228049836211628, 0.03549411757698944, 0.04878799919219268, 0.010488435077751357, 0.026254407731035066, 0.048006083891396566, 0.07083401399394197, 0.04772296460765985, 0.05591807526446158, 0.013771694484016588, 0.028245648361682415, 0.04885572136469907, 0.00782956414285206, 0.028309578398963618, 0.04984664077299738, 0.05632245477529303, 0.008720435341069055, 0.03515794287405668, 0.03768611346341429, 0.06017373581867545, 0.05233791273748202, 0.05364335720397292, 0.07271143502645916, 0.02299640049797393, 0.1500758889221376, 0.09806978035598032, 0.06073032550874257, 0.01573443281344108, 0.04314873405101319, 0.004635095763425794, 0.03527308588907604, 0.051789252057431207, 0.08368536108924497, 0.06160690629434201, 0.06461700364466637, 0.06672104880694421, 0.06760175114557629, 0.02028682411858632, 0.051724287801452225, 0.056107015529226874, 0.03842421236538118, 0.005062403807026004, 0.04050059026227363, 0.08069217129940949, 0.06213264179325873, 0.051092820677665934, 0.012620709622429024, 0.03991980368511812, 0.007373241476729633, 0.03108637707848703, 0.09974719881410561, 0.029779902223737973, 0.03435982481366204, 0.014817776053302712, 0.11591575258681852, 0.04281215332148056, 0.0672313169906697, 0.07179384555427298, 0.06641648289176726, 0.023052983752061284, 0.052764899502958984, 0.02490571568599872, 0.04342454868639189, 0.0273948636717133, 0.013302285599732592, 0.018604320751863624, 0.05638308297362059, 0.04500491912626932, 0.0061552153032783784, 0.05211378988479415, 0.03956401713132378, 0.018929142031758543, 0.01152294584655113, 0.006471663242160914, 0.05499017807925421, 0.014434860410889792, 0.06589704463558813, 0.07771349121485988, 0.021382467746133768, 0.004185246061458583, 0.054216065383966894, 0.014051795381331637, 0.04987223194010797, 0.052183396633594274, 0.02318178611477056, 0.07987958949900444, 0.0457910708932867, 0.02742113091141707, 0.021884762869787314, 0.052636112462008194, 0.036109224893152714, 0.03348937656189646, 0.009343228434332678, 0.04041847712810963, 0.0771377225136084, 0.0509168656032172, 0.059592688771625685, 0.01149836400028078, 0.03254767447229355, 0.041013869171541546, 0.013800545355244992, 0.034016943010952205, 0.06651571426059931, 0.024748510613496748, 0.026043028750967596, 0.04152748132905653, 0.0264016364235431, 0.046481660852629336, 0.011155349089794103, 0.012522854339030963, 0.012156307122730201, 0.03973699595418669, 0.034112650375332565, 0.023255267353247733, 0.022825051527169925, 0.05205301612976098, 0.042107379244219874, 0.012844062556752996, 0.044208180024138385, 0.06005571614350042, 0.054892655086493304, 0.045635110713661685, 0.03290866276309375, 0.020974941529153336, 0.01641929435032991, 0.0729678216720781, 0.047585122407444065, 0.0283153202279561, 0.04286890128447164, 0.054888399468073924, 0.048896492564029274, 0.14507215500118273, 0.04834366436567038, 0.03434903063480893, 0.03282733869949176, 0.02377534146240402, 0.036124351299217636, 0.020320712017916867, 0.05593437761549027, 0.0506659641471361, 0.08036029434973195, 0.04404971856744059, 0.03113187695552986, 0.03178772099706675, 0.06318245421073611, 0.006014129199508217, 0.005001130179622241, 0.06401658606445117, 0.07548186176967236, 0.06425316550678785, 0.022443143290377433, 0.03178312829996069, 0.03165736922153062, 0.06656713408207701, 0.04786931804471439, 0.06266424935611506, 0.0688940265606488, 0.08459450827250559, 0.03667362868004749, 0.08850201633909056, 0.03310807928022358, 0.08545379845365401, 0.02011076179182818, 0.0405448088572631, 0.029871710200583743, 0.01963793040974246, 0.04167236770773607, 0.04147714552199168, 0.02533134647584971, 0.07854455871687782, 0.02382458559417677, 0.04292978995269345, 0.039311162151035764, 0.058270443996955315, 0.03553516073753277, 0.021434487031412222, 0.08693222557344744, 0.028274135341146783, 0.042453041946094845, 0.08436252152727497, 0.05267955730819414, 0.08715819852847247, 0.032494404548478704, 0.04706996275232204, 0.03594377288414586, 0.012964751090734236, 0.010247022578222378, 0.03019296342597133, 0.041301864604916305, 0.03135445997148993, 0.03191674552527407, 0.051520067913037156, 0.019795972433301712, 0.05123856124438105, 0.07242108770315686, 0.05579233342300981, 0.04374383881147351, 0.04431779188434443, 0.03156914270573086, 0.022153077504387306, 0.03308976211795404, 0.06942191476663274, 0.05004505754538602, 0.036629138123844905, 0.03529837828189616, 0.03519522837333141, 0.07013522689380954, 0.04788630604443531, 0.029872478203727838, 0.029004569533431244, 0.016484930848462448, 0.020834573154007236, 0.11276546880723008, 0.09108478218437203, 0.028634512676827373, 0.04913551965728403, 0.025840168668618126, 0.012670464160281324, 0.03551227769123451, 0.10557063915316137, 0.06264768653519212, 0.08165237058194415, 0.04347278924298383, 0.03492817012292724, 0.023071371777463826, 0.031061348986000787, 0.02713212232676245, 0.04515302690467046, 0.013513747891861827, 0.02854868401623061, 0.06033875498800509, 0.06753800496939691, 0.035517218958346114, 0.06419102045437021, 0.013421673699462367, 0.03085661007301702, 0.026693950677590988, 0.025336868054563963, 0.015567163260833872, 0.0825761117401623, 0.027077297244461316, 0.052134707915566625, 0.04708113231425805, 0.013716923985480061, 0.10947466151969087, 0.14935568966452153, 0.09460498683995779, 0.10799520784207892, 0.07118761719715211, 0.2009109248437228, 0.12419050574422845, 0.2142080048760099, 0.20474594567091237, 0.2646448282945541, 0.1635835818465679, 0.2438935748631916, 0.09547587559227982, 0.06112010338373723, 0.12214908826976054, 0.06563007065485563, 0.1489094894139036, 0.126953654652161, 0.19837449965698106, 0.10436123146885827, 0.16156293301572724, 0.14065921276567445, 0.10110109834180725, 0.1827007084484062, 0.13483856864754232, 0.21934712185494362, 0.18424400789362771, 0.19556294165311322, 0.19614083241791497, 0.09303830639128724, 0.11973827851996308, 0.08412586164570625, 0.15447802931791352, 0.14187500962326605, 0.11482151090017251, 0.09097451914943035, 0.18809439644457834, 0.148914423020136, 0.14307672578480937, 0.2003765325512617, 0.11254641362616133, 0.08739185534537801, 0.15611436248065966, 0.18593229713939852, 0.14230420272196495, 0.12011846497414574, 0.12073756360839452, 0.16477644203170655, 0.13189585639103768, 0.0919465315077574, 0.22845282760118285, 0.11371811446283134, 0.21342824994316026, 0.13659421234361588, 0.12318356743743344, 0.09249868171830332, 0.1302409685787655, 0.1143827417024201, 0.10230556475899874, 0.0988229443769782, 0.15521017954714839, 0.13555380365540906, 0.17322147355204628, 0.3220253654064671, 0.17567260250929864, 0.06980557159911241, 0.16968046194843708, 0.15013363662986987, 0.16532370460129556, 0.09678767092766301, 0.15842840766474126, 0.1860625474082847, 0.20219543978812235, 0.17722760777800314, 0.15870131882688693, 0.1407714752900985, 0.18310906395556467, 0.11170045337489537, 0.14609405500513895, 0.12795476302985223, 0.1717736746274656, 0.23380269536808615, 0.07914747757416579, 0.17763754142628563, 0.1723647880698404, 0.17533478837820793, 0.10393820537794983, 0.2087622075792282, 0.1599684588971638, 0.1517118543626801, 0.0813528685079467, 0.14891200218229525, 0.1790273474949983, 0.214203622853083, 0.1420950453968779, 0.1271307511976169, 0.23720129122657163, 0.13418508032637258, 0.11006317026312314, 0.0870246387597534, 0.22535944117173073, 0.22819148436669381, 0.15659494475731928, 0.10903695718415322, 0.15147505658528498, 0.11156483282966, 0.1513139482948088, 0.18350281782688635, 0.20975108919364793, 0.16481728983982918, 0.1480037589827853, 0.13847247607284977, 0.10896917372461289, 0.2732553807718139, 0.12506816671380114, 0.22504896105777836, 0.13130509534910803, 0.1197558219334291, 0.1352966126174696, 0.18649880383764544, 0.1135628667449759, 0.16010669180222098, 0.1195071038279322, 0.1462788200907169, 0.13146672457937272, 0.137030070407256, 0.12512002320539567, 0.12999955895206622, 0.14526632764647085, 0.11008704156284371, 0.14184739981447497, 0.19572881501047842, 0.2860148509423579, 0.2162309672923819, 0.14301692496144003, 0.1284638974034498, 0.1712754110415136, 0.13461997311922813, 0.10133152992855157, 0.13888935047772624, 0.12015654720486173, 0.16573578329576602, 0.14307651128019058, 0.25293070041844923, 0.22921988079624794, 0.16544914383801723, 0.2012776051678004, 0.1593974782454391, 0.13470120908271882, 0.0827199677305837, 0.1283864229316673, 0.2336606320234076, 0.14963397876389567, 0.207845185012106, 0.15566195691785506, 0.19291786987695003, 0.1402750196716478, 0.16863553334147702, 0.17816660174679372, 0.10826959755391845, 0.15525712541514827, 0.06764244573611407, 0.2687134906168907, 0.1614330964343202, 0.265131447344057, 0.13968088784285132, 0.3131400018690094, 0.12251884826729376, 0.12640263825174303, 0.11162604325481, 0.12082828374038782, 0.15005698187216637, 0.11500760897873871, 0.2668070348520433, 0.11292736616826828, 0.24465742581073316], [0.04399180998124423, 0.04836336431664325, 0.03418670043409352, 0.07606461719279328, 0.026675999322305285, 0.04149992514642016, 0.017177545195144993, 0.050950807128702445, 0.02411969606914828, 0.041705014544629285, 0.05376132325299325, 0.015233289694503672, 0.01103401225390694, 0.029990089937083186, 0.011992621903998718, 0.05598799610931066, 0.036296292072943145, 0.0955506457736896, 0.031187512175810915, 0.11525736896381264, 0.04765811143442989, 0.004227027539238935, 0.03433717542418069, 0.03948904393661407, 0.06544823968602766, 0.06282643400012486, 0.07963616506106432, 0.044435378719842246, 0.15289929064531482, 0.09183275212924327, 0.027188328282547095, 0.0311980152412528, 0.05660973008601897, 0.02439657748196154, 0.04935888025248724, 0.04209012694416508, 0.020805239647386536, 0.041521459877971685, 0.014230442297224317, 0.04558149605028091, 0.07531424939271904, 0.06319293046310064, 0.04845058342682258, 0.012148532287908659, 0.038589875048567215, 0.07456871560744702, 0.018113597386306333, 0.06723386040257831, 0.07592668306202659, 0.020630866544501438, 0.04976554653577266, 0.038100762382870725, 0.07034402415757218, 0.010472690055687583, 0.04986380497294088, 0.02711890731006861, 0.04324218145601692, 0.021484677281771457, 0.010406226182596819, 0.02639951244477303, 0.03394631736521279, 0.05307963140489114, 0.0193575230772577, 0.013091672707589404, 0.013331879576247548, 0.015720043767003283, 0.07777390490856864, 0.0352233974263072, 0.015040767011082461, 0.020701541985955932, 0.04656909829786709, 0.03405761844929188, 0.026975436278829173, 0.04153960850089789, 0.04323146005551662, 0.04415808170433006, 0.014787327888752184, 0.05326892790054122, 0.016306231264024973, 0.015824289181299748, 0.051185816090794346, 0.037234014335779414, 0.09654279092266675, 0.007772658174226602, 0.1093790231032237, 0.022884015399481983, 0.04157104108843111, 0.057298860647865844, 0.02762945894632609, 0.07383687947426112, 0.02535338299499164, 0.04061151596326982, 0.02075345784936461, 0.04185308401863422, 0.10890162009144984, 0.05040747075972538, 0.030894565899225495, 0.05516827436945131, 0.02073092528829171, 0.028890830374533133, 0.03268700671352206, 0.014650274759098409, 0.03350132370307561, 0.03097035497757456, 0.02388970881340004, 0.0427657169019503, 0.02622812133913319, 0.07799696672948138, 0.06938641425222158, 0.022358913838322607, 0.04267080243857157, 0.021988583105285803, 0.11314341062379461, 0.05444900207822362, 0.029143426800146702, 0.010689168308501043, 0.0009703231943046464, 0.03641573667165734, 0.12483183625003985, 0.03573717812316553, 0.07502751800441936, 0.050825463652971296, 0.09314840854776484, 0.08256213829642342, 0.03228676790792135, 0.018969244819374818, 0.03420115268278507, 0.026325454725132837, 0.03709900666088347, 0.02397364906726345, 0.08069438529351065, 0.03773926081316125, 0.04391838428414157, 0.028065606208157637, 0.08964756293402565, 0.08672502177256732, 0.012266527065226148, 0.058791897064375306, 0.01470198569398734, 0.0324111269606698, 0.022248750394811074, 0.0589963008138922, 0.05008400928589606, 0.021926671709685076, 0.041887879732155034, 0.03191298403356585, 0.00898635403568586, 0.024263050271979263, 0.05681542469368828, 0.02653654833744851, 0.07440579168859028, 0.05874334624217403, 0.06503138826378892, 0.02600900295581068, 0.045228957709285526, 0.02610460689832126, 0.019057842887817852, 0.014605889539985407, 0.019325086914543665, 0.14915905021611722, 0.05293101417802034, 0.03606062427523636, 0.05999406138735433, 0.01328956758257963, 0.03164951682030674, 0.0645648560396606, 0.048104867098792914, 0.1245477095606827, 0.025693489644195766, 0.039168953249651584, 0.055068100712472395, 0.038493926366490704, 0.01821872188649591, 0.013433079791044997, 0.049429609320096435, 0.03965844129843097, 0.09069617642390151, 0.04434259781133264, 0.059314008967410174, 0.02391295575146233, 0.03372312147891329, 0.031245616114427967, 0.040320789426445, 0.0903527238856881, 0.02590988458494746, 0.06279740309823426, 0.03601874607885557, 0.033267191911657015, 0.021699612825027397, 0.008159700157721678, 0.035059558032380964, 0.01701534905981633, 0.04955175437874371, 0.06612621217725739, 0.04620889524718927, 0.05075962605675863, 0.03888411409852486, 0.012503995169554988, 0.03581918783545975, 0.041716896568334876, 0.021940564714191903, 0.02217764019845955, 0.09087207021131631, 0.06892113841228908, 0.07409679012433176, 0.020221065046385895, 0.025378508763688228, 0.040891957769711176, 0.028919932139556737, 0.06104578136376316, 0.018344630352071217, 0.0158302579638398, 0.04227921659607561, 0.033150401807600455, 0.01111919452781759, 0.017110004968520616, 0.058511225431556665, 0.050381366313705524, 0.07280850602734475, 0.027816338434575066, 0.026471802416527947, 0.03298538263827082, 0.04079112144667776, 0.04533323759753858, 0.034106291845561035, 0.009367905083983656, 0.029724263173017292, 0.02855215630974741, 0.007742845383848274, 0.004092074448107592, 0.04858411255202467, 0.05901015934444243, 0.04793666100369827, 0.02296871024995081, 0.04076616996298394, 0.08701670208885785, 0.038511787706445304, 0.09537780867709268, 0.026771905869545958, 0.019174943257483746, 0.035515656138980584, 0.0038734387001773765, 0.07674066680333308, 0.04426239989697934, 0.024353237972865184, 0.062552917628519, 0.019543270670598554, 0.031518255315360524, 0.03847211967372606, 0.09164905190588006, 0.0365812806112151, 0.0374757687020446, 0.06709741248238472, 0.027025749103256294, 0.03346195061420722, 0.03328792991176729, 0.04135657860446842, 0.09969852924827607, 0.08377751380565666, 0.07412350361025141, 0.04621740648402803, 0.02242089801227614, 0.025424226975789475, 0.06869862817468182, 0.0373063521880296, 0.054657546532971245, 0.01854616318709187, 0.015663263245275425, 0.05997758666654268, 0.01282050152264175, 0.03024308472841738, 0.038027700577532096, 0.02049771854804168, 0.005217452820826082, 0.05726429093028269, 0.012609371521149673, 0.007520889123571256, 0.09698402692353535, 0.06709043342139452, 0.054913553965067675, 0.035866953417538636, 0.03076104060446303, 0.02346014416205787, 0.030473357351917415, 0.03198479136992847, 0.03218839455756449, 0.085240351036191, 0.02537550569902505, 0.10019115442710538, 0.01860234424501898, 0.08012837655241452, 0.015457237304578868, 0.010826562347281124, 0.029808642012217355, 0.03834211455297567, 0.06376813992016739, 0.06840665674498005, 0.018074239619196426, 0.03137931186375359, 0.022918485525634982, 0.021119649792390487, 0.030620189593924634, 0.029714214014670545, 0.05063384208047102, 0.07515407572951048, 0.06516533107647011, 0.05408176250996129, 0.036816289573307, 0.0169779026820775, 0.01424996700558451, 0.03982254499269109, 0.0049661697571977016, 0.043836795920205694, 0.02710462551594021, 0.05207126434411734, 0.05436469027171693, 0.0489992632590715, 0.03834996312375992, 0.1045272503829291, 0.04413127628785949, 0.06247240178767712, 0.020658374846642538, 0.018431123593942295, 0.14286785957313355, 0.02623382677894927, 0.013399646756419492, 0.03938113662203954, 0.042125286549449935, 0.04882315879747753, 0.04674974949129167, 0.029422495393983783, 0.05589313910252625, 0.04746642857489567, 0.02823562218597339, 0.03380538400022253, 0.03590770546467074, 0.025454269113740133, 0.04172261924512925, 0.053787335768462195, 0.07943094542790806, 0.038968104148103345, 0.02001308749670223, 0.027191363905947057, 0.07738273275355179, 0.02849253551704028, 0.023744550473507375, 0.04343802034254036, 0.0411886099966303, 0.0467959484235654, 0.044786174210809895, 0.03615498332486999, 0.058075769564076785, 0.16694748924384195, 0.15147845801566878, 0.1416209289022992, 0.1361699988164248, 0.0652572309838668, 0.13926323202829208, 0.13921760383152193, 0.14118030577177001, 0.13582047886185108, 0.17025524239626624, 0.13380281777391512, 0.16088125265894399, 0.08069828468104524, 0.14046563766896725, 0.06519752975192762, 0.12470451243702443, 0.10886284072072276, 0.30763170711936494, 0.1213541188307347, 0.20527394879008495, 0.14137887576174352, 0.06978214463038791, 0.12643226287177495, 0.10432999806418534, 0.21305643682998998, 0.24888806976377967, 0.20585573128154203, 0.2758454014697383, 0.2622395267169322, 0.17235910369744226, 0.14454730816425818, 0.14370740000759402, 0.1711324130695674, 0.13380056547541774, 0.16982594204525794, 0.10076591955317606, 0.13397270543200357, 0.14382215997865125, 0.12584956873568798, 0.14999560290767303, 0.1571367527808874, 0.1550560120132662, 0.15762187029805877, 0.11879359251789509, 0.09148577558657817, 0.1287738642384929, 0.10910505473974252, 0.21118707504243622, 0.11314891113509094, 0.25664861704553327, 0.09806571242910239, 0.10475248023266755, 0.12209397590448781, 0.12555402733625906, 0.1665239039087488, 0.1847905196970509, 0.19570796209717953, 0.13232964601728225, 0.13653159231668519, 0.14609434611855016, 0.11616093136610524, 0.23954052538160356, 0.19611884569448812, 0.10647987060609365, 0.15424602725092443, 0.08006119830233437, 0.20825783061164044, 0.13282409448537136, 0.13682422258200186, 0.1581879633088266, 0.13233624969518956, 0.1282726129096362, 0.1435329311437184, 0.20688572117397863, 0.10535536078555931, 0.18094402287275563, 0.21536979253493974, 0.16495469536992813, 0.1343137830976517, 0.09980428768622299, 0.24868090426729572, 0.19298640410265616, 0.20679222780369944, 0.09852387131221833, 0.15553546047979788, 0.060995039530098445, 0.1830347227833925, 0.14830317678711108, 0.10774515674359376, 0.15890413294396094, 0.08425736063790899, 0.08274903310643089, 0.1491807764696498, 0.11715720572899427, 0.2849760357170336, 0.1555328864243723, 0.10874843315011072, 0.08044336126336167, 0.21156414351876707, 0.13241782273736694, 0.07337591670934232, 0.1737609833118416, 0.1593389031627486, 0.13450847668272836, 0.15997365297329041, 0.12842016144385263, 0.10911440867329798, 0.13538443693710914, 0.1221885264761025, 0.079545728381603, 0.15114507187278042, 0.08962556854971955, 0.2465893156946667, 0.10346002861737244, 0.189389989020363, 0.12991513606281052, 0.051465729296567946, 0.15372859614510692, 0.30914344374210606, 0.2923129823419356, 0.19581020419155398, 0.09646616680848022, 0.1805829962775592, 0.14017849259318846, 0.14163710867926, 0.08278806528617298, 0.14516391701275302, 0.10094840935761891, 0.3535438467177653, 0.16400132959167804, 0.14870293678775912, 0.10703400498436344, 0.0852714771885545, 0.13717363528426618, 0.18671816545388392, 0.2060650724677309, 0.15829699294221017, 0.13108904323270246, 0.16473223875847556, 0.12520188736098428, 0.23057479922088886, 0.16694430231807694, 0.1741878168597337, 0.11352791781387023, 0.1884916896421102, 0.10912405372026468, 0.11575174848398856, 0.1886616232654741, 0.12614066682515607, 0.11101294308900835, 0.2288520360185254, 0.17442351147051782, 0.16163296877376496, 0.14872184383773035, 0.11821487437813513, 0.09139707792670497, 0.10157852433621885, 0.11022940368181276, 0.15128748761790414, 0.24304347773713453, 0.14676611329759323, 0.18203127017665297, 0.18402695986292056, 0.13347209761700324, 0.12056214479549278, 0.1874308110845666, 0.1583475394234542, 0.22732203585966942, 0.13655621438257157, 0.12013591645706086, 0.11595668466461283, 0.21014795338194217, 0.17345862372988657, 0.1530075695125326, 0.1787125006798775, 0.12178772459587744], [0.0031760908877326837, 0.03674640320241451, 0.009845994702059655, 0.003006544378173027, 0.060427402852163206, 0.016857431525544777, 0.030260932661833304, 0.03138643265100977, 0.04466888231916293, 0.05216535526297746, 0.046747125640151, 0.012661170556149896, 0.036009001440458724, 0.0936475761174675, 0.024343663789031487, 0.025672106215009288, 0.07862627731576081, 0.04498693521224684, 0.1282806338502034, 0.073929637400133, 0.019116663118644107, 0.012702235741721047, 0.04126811460141213, 0.015659817764835975, 0.02457204034491893, 0.01911732003903918, 0.00734166285368584, 0.05613981558370495, 0.010399718265680057, 0.03878467588595325, 0.06626553292716704, 0.037302433648296905, 0.07631123621737765, 0.07533714009989655, 0.03554427335339208, 0.026571428320641, 0.02457173390974922, 0.059344920615154895, 0.035326727365534154, 0.0513086199850565, 0.028549953806965102, 0.06609352320552835, 0.05475010527598281, 0.050936354880010894, 0.0153380474300995, 0.04438188280008974, 0.1112897153342924, 0.04511130575631415, 0.010002480609522713, 0.04786053484666252, 0.08804768023471679, 0.011349368517497375, 0.026806284065148043, 0.004983166854212722, 0.07892882841969691, 0.04426750970343429, 0.037523863701930935, 0.026870194950231144, 0.05756078610917734, 0.016062826935892865, 0.03920833399939922, 0.1110242122423745, 0.03692373723512696, 0.04808618987519895, 0.04458894487470389, 0.02141137990439611, 0.032759382870168455, 0.03381447746388374, 0.07701541657649702, 0.01659083101267536, 0.0357496117301766, 0.06831892435589144, 0.07088240010723953, 0.07571262277422414, 0.021558079996236393, 0.050725021865218885, 0.04696520022867669, 0.034599798025503274, 0.047701950815896836, 0.042351895357452096, 0.046357366917354446, 0.026772547468182542, 0.012338268326505298, 0.024839043053948594, 0.011617566323688915, 0.011989537442493583, 0.038790578593409834, 0.046576916225134365, 0.00472152819706788, 0.03131505623910456, 0.013990760198794307, 0.03709608403545234, 0.060517230491724715, 0.01401779831447188, 0.06208266221707868, 0.09834935648306724, 0.022431994795859344, 0.004250125568960944, 0.08130219945263478, 0.01868062310912196, 0.05934898854203283, 0.08190663516401284, 0.08952971562863359, 0.023390064353964502, 0.014622692720994595, 0.03152944402949464, 0.00621763231690913, 0.020525975701128765, 0.03121652584072323, 0.06552052774256276, 0.03272610018029809, 0.045149774861431895, 0.05146925330101963, 0.05046796106222657, 0.03247444412761158, 0.10384673447979074, 0.01966182660732058, 0.015951575647528856, 0.014022826724084876, 0.06218748602775797, 0.06770172561969488, 0.02055167220532894, 0.10371546531396528, 0.05211718365429871, 0.0059236274025733435, 0.03149673399034768, 0.05120095781861775, 0.020889379084110263, 0.04806608389762621, 0.10091677758722536, 0.025386006849247123, 0.03795140205071338, 0.015013824656395423, 0.02203413852370314, 0.07646959425220567, 0.05552975295652306, 0.03159838236658083, 0.03265807157262199, 0.029070035577000632, 0.04915313584910286, 0.058210129894676714, 0.06115040216114252, 0.019958252838302045, 0.052144203575388084, 0.0035266311756605587, 0.0380311020079159, 0.017075335659507303, 0.11029182452588313, 0.010059868255930563, 0.037521465846727935, 0.09447792349683662, 0.03708966038820725, 0.032085189107625235, 0.05627421804914071, 0.040964196030531204, 0.051929246964714224, 0.04044730118626068, 0.04423383630872254, 0.027898290690274972, 0.0264142902808324, 0.025361099415608955, 0.045096370872230306, 0.01134570565960941, 0.03950876687022467, 0.04652792107193701, 0.01100608739145701, 0.029757262410355673, 0.012675283810934954, 0.04236314918905978, 0.03093719103133246, 0.016318503992571946, 0.037633693897195404, 0.026954841920204704, 0.0475776645415012, 0.021038794957642114, 0.014196352342203742, 0.04541694802502471, 0.030287452710552082, 0.013882510059873664, 0.04167698338747986, 0.06555788985062992, 0.07687768928946988, 0.04757473425519082, 0.020074916537851095, 0.10303481917587981, 0.010232465950051143, 0.02001360269083131, 0.0432798691514519, 0.07027724427321265, 0.03202791828962584, 0.023775879639170827, 0.04537831038056363, 0.004518725092507779, 0.034684025562338294, 0.047822042758907043, 0.006697833464826428, 0.04434945812869457, 0.011724914394078717, 0.06386370938872138, 0.040633023881743995, 0.04669755209057082, 0.023135916600304268, 0.053717254045149015, 0.02215726609011331, 0.09068312228567178, 0.03410699664645138, 0.04191525971456882, 0.0503880734134826, 0.07004561758930646, 0.06000028202129949, 0.07088112840128523, 0.0701245169846281, 0.022449254756793383, 0.009148071366061848, 0.021039915361231374, 0.04714426178965838, 0.03436464350670576, 0.02425457159387729, 0.016036061739038317, 0.0687624816031706, 0.03329110534621343, 0.07087553595943798, 0.033899769862933506, 0.07759834819984052, 0.024800516492236527, 0.0474167324512476, 0.03212908977612613, 0.022099380486554677, 0.058619182541846275, 0.018900212636517904, 0.15265159909763645, 0.04165956637852135, 0.035712885475086595, 0.12111411114493686, 0.060738993793605804, 0.036913452504743496, 0.05570586890943589, 0.024833529136113586, 0.0248319031144943, 0.03664426452990982, 0.030254679469151363, 0.020983678761929758, 0.004240902827962512, 0.03852764955691753, 0.12181600090116264, 0.00835520483838815, 0.03709046861096736, 0.018616078286281517, 0.06850745859405688, 0.027902810609028227, 0.05887787894255692, 0.08371988101111305, 0.029341305395768538, 0.03133495728815756, 0.006238819914869965, 0.06492180704709984, 0.10926486834162667, 0.07185923881948957, 0.017977417596886237, 0.0690869045173449, 0.015722964477214604, 0.015834933973007625, 0.036279342377618436, 0.022376796245695125, 0.03808316534325, 0.027179612117188594, 0.02190832007345894, 0.0700767667243077, 0.021169326763840455, 0.009648327738226903, 0.02211555834829567, 0.04662539426898284, 0.0588264016644849, 0.026988766208711653, 0.07427774009204681, 0.047965393131298405, 0.08601596909424952, 0.05074498611652563, 0.05294681091101901, 0.024476601111312068, 0.02711175013363602, 0.05410302144986007, 0.06642059678392065, 0.04688946860692194, 0.004149622494174589, 0.041643371279802055, 0.027702873152109887, 0.02652269746777752, 0.023893793977256265, 0.04649599818813224, 0.048437012179243955, 0.06494953942995879, 0.05143919584131049, 0.030712189092751474, 0.020999416123114286, 0.006562140620043201, 0.03728873216577115, 0.04357552546406946, 0.031134408876119606, 0.04843039701001779, 0.02966796720190154, 0.01311516766661718, 0.0369401200253877, 0.044812512313646656, 0.03772408078094164, 0.04845188960673348, 0.014551336418897396, 0.08549188834524925, 0.09814953776977717, 0.08466783054773847, 0.02313246154376576, 0.04179439019231547, 0.021807303719763315, 0.024040082296837243, 0.04454862183680938, 0.03304239490159577, 0.019664379595328244, 0.01849024068383921, 0.017294509584204327, 0.01774790723087086, 0.02426686155940256, 0.03924805948871278, 0.014782339698755214, 0.02806613289360558, 0.027484689396054997, 0.03395353391345951, 0.09114531079126943, 0.036347221598149314, 0.026527903035223007, 0.01855588101241137, 0.07062766821153703, 0.07417723701726045, 0.003064962173436558, 0.00818176444755086, 0.03326209742696055, 0.033533916913814125, 0.0076467803521682665, 0.03615870651218199, 0.015474897546453342, 0.02326110302801094, 0.020836888654758374, 0.03872108292735873, 0.03079950396392134, 0.07904942598073714, 0.05649602348585764, 0.06708957540291934, 0.01594684792742614, 0.04170491878363875, 0.05449596326798201, 0.010860155302760823, 0.008746500525082792, 0.03945351660912556, 0.08116251098052149, 0.12445771721221748, 0.21147474105800354, 0.1855221030212218, 0.22090798003538964, 0.2168538120965804, 0.12160952488381056, 0.1285138539969921, 0.17069911373959434, 0.18829466714974374, 0.21797305123219568, 0.14047201152049726, 0.1199396983570149, 0.2682848491014973, 0.11723913117161683, 0.18138577981341272, 0.11723360001680352, 0.07072987966239452, 0.13601483536824105, 0.19762328916019012, 0.1335610251032537, 0.12975422695519465, 0.14396091382349693, 0.2742823982431043, 0.10266148154774021, 0.1744550436494812, 0.2050288006543152, 0.11184990946804324, 0.14917000527343444, 0.10295545246692435, 0.1548051182180643, 0.1176671751384293, 0.18763668955333773, 0.2804550444406848, 0.1811155652807605, 0.08035514623888078, 0.12658641508389867, 0.13674074964177224, 0.20855816772147534, 0.11097099211427475, 0.263917718923861, 0.18148698002821018, 0.11751724407076837, 0.10926266966928398, 0.10802828751864935, 0.18144994733795045, 0.18232995253657142, 0.17845353231795374, 0.12048500740239698, 0.1087098606231232, 0.18856040772891816, 0.10451281728643565, 0.12258916747786346, 0.07349009445357708, 0.25929364285642104, 0.1740005236840056, 0.09170829348506467, 0.21952554373250854, 0.3109003897876509, 0.1370663982966254, 0.13523494253956503, 0.2377818020120744, 0.1611455223493038, 0.09624662899201918, 0.19149794123105465, 0.19736481109453788, 0.12080946096008825, 0.13277402297864038, 0.27136918037168445, 0.13773743003126115, 0.10104620814203255, 0.17015260193617116, 0.1583909919305194, 0.1349282162564416, 0.09889473447636252, 0.26334857688315455, 0.14533391192315087, 0.27852434965391315, 0.2345938496892491, 0.08776878592588248, 0.16253843873498902, 0.13143199015288584, 0.1073320055260293, 0.11113178630870198, 0.1175329641949746, 0.1847627413489165, 0.1405360871144841, 0.20685484783063013, 0.13127196970726215, 0.10134930316839488, 0.1433623540064981, 0.13236104030041926, 0.09622198394349507, 0.06765447331652527, 0.1725915807389444, 0.25027395346232, 0.13915005019835888, 0.11386842091357517, 0.23521612758838364, 0.1464722572915977, 0.1398385640594267, 0.18060101466553827, 0.20349022031070726, 0.14518593437969685, 0.11255837991953858, 0.21503303560518452, 0.18120325170457366, 0.14446046443716173, 0.18092814953096453, 0.16819169264166586, 0.11938464467323597, 0.12513469378914566, 0.18020752126411085, 0.10914458487663539, 0.14030175614020518, 0.1803185274043391, 0.07749809793406919, 0.13091261318374064, 0.082429765963987, 0.11518501962024359, 0.15142944371027334, 0.14171739469372457, 0.1959157251422444, 0.11914689694681477, 0.09454959868303231, 0.12097439202930658, 0.2027390251356748, 0.14846474473034182, 0.13957363553345203, 0.17852860893453323, 0.10664486296234593, 0.1863042481483952, 0.1671356864033207, 0.16127367353727742, 0.30937566031371394, 0.19967551613526963, 0.15125332009648124, 0.09931179274234081, 0.16225962869582639, 0.1504170431965782, 0.1569682134375457, 0.1301739971724249, 0.1388390338228595, 0.08556022338809506, 0.22348338377571877, 0.1502015426634781, 0.18361091283300232, 0.1492126304055414, 0.12373119006834685, 0.1943537791169459, 0.15175002086306774, 0.10543630563563879, 0.1561021816826636, 0.14346907005435036, 0.21006504734677656, 0.131343461032356, 0.14764775792437215, 0.1229747165475161, 0.12100216271656176, 0.0889975066867567, 0.08748652849106059, 0.22241423146859293, 0.15615750855255514, 0.12741166031769208, 0.15076112392688953, 0.13018279186179563, 0.06962577842416302, 0.12623969135024857, 0.1157352009848241, 0.10462437500996936, 0.11200999120070089, 0.07087791849288248, 0.15313359097607676, 0.13067754676505444, 0.11111688589857471, 0.18383194452091572], [0.04300998403660713, 0.042437911709590305, 0.06865390396166234, 0.06267870543524623, 0.02652837417929644, 0.1262237337387858, 0.04880086563888097, 0.0338213607638834, 0.05983988236215326, 0.0248537021463797, 0.03459631615588742, 0.024503165210086494, 0.05467084964977638, 0.061214071728529475, 0.016542475542894775, 0.021446192854895227, 0.021565989854054588, 0.030785856107550285, 0.1035626077904336, 0.03558920824059075, 0.13575277201110317, 0.026004322158593326, 0.00331142750163112, 0.024575640958163048, 0.06984805117451376, 0.03666260850525672, 0.05597463553591121, 0.029529362744201097, 0.041159632720894394, 0.0013408633446576254, 0.02036406684877171, 0.012282578522459635, 0.020542119088913166, 0.027183927107422103, 0.03543219852050947, 0.00829691512344946, 0.0745619663728341, 0.014941074074276034, 0.03116427481384768, 0.025464488726650036, 0.020694675922934568, 0.04343057396791635, 0.03249900107602439, 0.11350520330691531, 0.0716141979360292, 0.02714592340071836, 0.030221101835430152, 0.011228879166376448, 0.020167770224713513, 0.057557231461208676, 0.0494603332762997, 0.03972519436971315, 0.07062463450335688, 0.03940712615487076, 0.018003792088899403, 0.05696506464793798, 0.060776945789374655, 0.011688191969428333, 0.08643449058816319, 0.03192799552644213, 0.00960718307103361, 0.02131268671233087, 0.10547815701894223, 0.04427802042975541, 0.00956446792359554, 0.021227294721850948, 0.03832475883105109, 0.08395747551994939, 0.07983727846294641, 0.03630779871356584, 0.010464160624260624, 0.019458300028476986, 0.08138546554912483, 0.06209264817317167, 0.07610940269284672, 0.02784472582260928, 0.04350319527269852, 0.06095493099682274, 0.0158904466192208, 0.026989308215918082, 0.010467635790607142, 0.014166599402444498, 0.02537435656713863, 0.0083477508028849, 0.03006975158988949, 0.049284742093615, 0.025750837070987593, 0.0262208741473695, 0.01428664921061887, 0.013959635004040696, 0.02712840680032969, 0.10893984787887144, 0.042454428565237796, 0.0437525185876556, 0.08071615751231871, 0.033728445789987044, 0.023859216598793868, 0.03946235343333214, 0.04258244951826431, 0.04928108402377656, 0.021090691668852683, 0.017917904056488507, 0.037272908619695136, 0.05906208478395016, 0.10757115519335193, 0.0323755651592247, 0.07452175441768862, 0.07612892261315739, 0.0806930139961262, 0.021662712284934618, 0.08481495773359653, 0.051452889662957, 0.08060191848105, 0.043066291499041745, 0.04357786586267814, 0.06729202945866893, 0.06959836779823227, 0.04215141397810752, 0.048686906229704625, 0.04037025189327617, 0.018642027599496708, 0.048684178956694184, 0.02445117848354482, 0.017151599712369424, 0.041076351302645864, 0.06748348249182587, 0.0319541210398799, 0.09743398866586148, 0.04936799669878618, 0.04792457979713236, 0.024769093480802355, 0.0600994712552957, 0.0659322616974673, 0.021133521729479396, 0.020657080158050505, 0.05189889456115423, 0.06288730351614856, 0.019359244859867522, 0.03569152694375765, 0.10805163787858141, 0.024513038168210658, 0.05422265757055533, 0.07440907820578545, 0.0316924273201655, 0.03967701510015515, 0.025804267873266534, 0.07282416486451704, 0.06052134821431772, 0.07900415018441216, 0.040900200875776435, 0.05845208344380221, 0.06827076040809194, 0.06617274435777819, 0.019576055403318138, 0.009181908512067412, 0.02565203662661295, 0.019739714766582175, 0.021445484223565268, 0.032796986295931765, 0.03071924859297372, 0.06877731306538468, 0.027952472258719708, 0.0483042223288888, 0.04294510405029982, 0.02175260504196969, 0.03443682431093147, 0.06820672311850133, 0.027722668864073294, 0.054115654239731456, 0.013219709939984305, 0.0775112746463668, 0.038291361227992086, 0.0011850128113667692, 0.05828184721570823, 0.026382729373571855, 0.08069070041059487, 0.0699335695695012, 0.02179991480173363, 0.04477719566033733, 0.021493297686139425, 0.043062959016571124, 0.04241133994993664, 0.025527507119301348, 0.07347229823109604, 0.12542468105112353, 0.003916715246422457, 0.015707154337677266, 0.05256368650964672, 0.010662288198457852, 0.043778776251260317, 0.012923757725905989, 0.050198164047493096, 0.007874309423289472, 0.04462138486785754, 0.03604609158731276, 0.042963287147182616, 0.11368819106850894, 0.03222635804465221, 0.06534808135080723, 0.040672523375119896, 0.03594119116784104, 0.06775044115079988, 0.04359635922517027, 0.04828575960991364, 0.028363895948014917, 0.0669204231892382, 0.01002156769015616, 0.017715792825085022, 0.11500004769092607, 0.03021183600198598, 0.009651664051137144, 0.02773714026496295, 0.02303884942985831, 0.0420664701490633, 0.01110427879593185, 0.028919089442840027, 0.034688097319655845, 0.004001627234937323, 0.05292027362532193, 0.07045680762178476, 0.007618965614857453, 0.05783944676119474, 0.033946305873893926, 0.03708522856956528, 0.020715283688097712, 0.03692871297619516, 0.017127324301268787, 0.01399668110083909, 0.021571890646291357, 0.024716516866558985, 0.02619452263799406, 0.06287058747764077, 0.024893774290479002, 0.015614349488920022, 0.005933714386511354, 0.03144641733548093, 0.05627532121575168, 0.06681284912291073, 0.09806645553438895, 0.02461366956272433, 0.03481799135765722, 0.08361423748635477, 0.029884228077266487, 0.0468488889295728, 0.022019423889897523, 0.04165459829833239, 0.014161767302862099, 0.03143662481658882, 0.05728767959461097, 0.08574743229415148, 0.08402682179885526, 0.04267314666761987, 0.05526563648374812, 0.05378970298014822, 0.04331685587643616, 0.0332147148888438, 0.013749254811104509, 0.049888473004102714, 0.039945555730692806, 0.02442571755138136, 0.008610809116714425, 0.010744979729004686, 0.050960318110282385, 0.03415236820376689, 0.04377841235949628, 0.04257579987508155, 0.022381136133786173, 0.00836630832524069, 0.03783332874938365, 0.05709631849200495, 0.04316243553353895, 0.02328683783660733, 0.034045962421523954, 0.04088138958679573, 0.0204242717835211, 0.0644690184403331, 0.036333872516068726, 0.04317544753693285, 0.009064284329783292, 0.017130091793895248, 0.08109095070751444, 0.045112378279408144, 0.04083194244172304, 0.03152325786950608, 0.04971443314946467, 0.025784962457574667, 0.024125612183143536, 0.05857516312971712, 0.039574773005780675, 0.020908854954365282, 0.024517234414815906, 0.04640777167233248, 0.06217235196081381, 0.02819235162479022, 0.11067545837572507, 0.04674992186107463, 0.02608048662002529, 0.024278917868110924, 0.06561904664962523, 0.03533214360715882, 0.029471364142673633, 0.0200130817510428, 0.08281631860882044, 0.1654669783648945, 0.0508236748376681, 0.0536385040369726, 0.01875492023123849, 0.03512679756949506, 0.04597418888982746, 0.04179134116237683, 0.008081103367130122, 0.04275368549109947, 0.03387738860422566, 0.06418397627590645, 0.012312350614416984, 0.04361689421198061, 0.026401762828050603, 0.01195526171115137, 0.05691491653241458, 0.045230080028094595, 0.030596247431071057, 0.03911253470446795, 0.05254987011393232, 0.02131946276002113, 0.1053900798902877, 0.028984881073777235, 0.049352563857551546, 0.04526271920410856, 0.025526407783130006, 0.04587475450769548, 0.0275424983908212, 0.02804665319291094, 0.0487123518401096, 0.09643482615149791, 0.024714404379107782, 0.07756140744013172, 0.06813720063937288, 0.05173426226622636, 0.003507052841145666, 0.07199840635181436, 0.060616507825832215, 0.03928538712282335, 0.017939808425463496, 0.04828967048876709, 0.05422440808146231, 0.0424141246795414, 0.06729139360569178, 0.06647600026260461, 0.03490703758753596, 0.026925732494301857, 0.05439359093866041, 0.015233352896757426, 0.08359280234623341, 0.20252229886189585, 0.20018928534080907, 0.17597378231585029, 0.1782722605933105, 0.277695074797638, 0.14584008153648148, 0.10186095797126332, 0.22568881301389587, 0.06142440116814068, 0.13616186296266897, 0.12237885336001074, 0.11179989158746698, 0.11221213882128078, 0.0745509959937584, 0.17526830726813886, 0.11705715464608324, 0.19418623568790574, 0.14506996398971927, 0.08683579808641827, 0.23753588778838036, 0.09576344201641698, 0.1513187440052148, 0.12859792448580265, 0.24224279328219353, 0.250694505089233, 0.2135821723289067, 0.1122068987798787, 0.18656087228127066, 0.21088624763632977, 0.06411944869004431, 0.1240912207492417, 0.16402677903252263, 0.11857400107527934, 0.13755929926710744, 0.12886844545362458, 0.1213106663236695, 0.08729680681661253, 0.06725520361214876, 0.10326368028237935, 0.10860074672006792, 0.07571184902542061, 0.09589096501229272, 0.19334312528371814, 0.14312989228675443, 0.18336178104002632, 0.148760546599665, 0.10964207471378389, 0.13347503939463248, 0.2741179651310367, 0.1019963103857252, 0.14434749711184733, 0.157565746696726, 0.1422408012853515, 0.12481828415465933, 0.1487262565041742, 0.10536383371800186, 0.20545001111684308, 0.17426172902266826, 0.14494339094286965, 0.11952114621958426, 0.1289684046059847, 0.24147840607310497, 0.11497819120244634, 0.19612725733989672, 0.09461011962905046, 0.10826871655280552, 0.15826846382791, 0.11243963629127511, 0.12053281128887208, 0.10416420897649181, 0.12626215304818847, 0.18423121422529223, 0.11896689692812583, 0.15392816204938198, 0.09804182580762333, 0.1509180800208161, 0.1592444598434433, 0.1163351704036036, 0.1345561273516186, 0.20090294220755178, 0.17758877226902595, 0.2586166969230098, 0.09417298985945602, 0.09793469607229195, 0.09845624107026285, 0.11338837489846254, 0.10886628045550278, 0.08529174787503097, 0.12218149378895761, 0.12124142729707303, 0.30116068499703563, 0.18498319081000744, 0.15672654334095218, 0.24852214020586785, 0.07543350629989179, 0.1834234511179309, 0.11180739924912492, 0.10462897153751505, 0.16292497605806397, 0.1396337581137496, 0.12214924148734539, 0.12647380015902943, 0.15556840226054192, 0.1934352550174921, 0.11468208289795345, 0.15358858591606542, 0.1470351940201175, 0.15499247268082636, 0.10899968700663698, 0.1586217222915542, 0.20646883144734368, 0.1338919444430259, 0.15118961222469807, 0.10200600139796735, 0.11905469060424836, 0.28217144911327674, 0.1070252102949927, 0.16086072150257327, 0.1140697718027138, 0.06715553557319988, 0.08672230216043611, 0.2406546010846092, 0.16939152422691547, 0.1921794224049776, 0.18378073920405683, 0.15061975006134282, 0.21831520142093783, 0.1120163267478347, 0.1686416160795958, 0.1435729668986413, 0.1802396203481382, 0.15485802425011513, 0.1303610298782587, 0.05326362274166557, 0.17282119261160975, 0.18354388013962777, 0.15186666541041868, 0.14736349333918866, 0.2008709963411093, 0.07046604664215157, 0.15822786116792312, 0.15631615003991514, 0.11126930675198955, 0.1593011043845646, 0.18333233262021698, 0.17870727596023392, 0.1922419198578404, 0.22760902771786337, 0.08715473581105472, 0.21247483819963472, 0.20490351463517836, 0.1499938102619302, 0.26681552310624435, 0.0838769903226245, 0.08889475131347295, 0.11599501204346457, 0.11048576734479397, 0.07672632563739054, 0.1194862355928748, 0.17982493695472518, 0.14323777278825162, 0.12256469862956194, 0.15505506206424008, 0.16969814325772947, 0.11613065557133768, 0.10950623200305047, 0.11909863340758509, 0.20289057264885596, 0.1939612356645446, 0.18370797617300866, 0.09490118707500159, 0.11347030800196434, 0.11003665596006379, 0.1428767308712967, 0.12810476304542634], [0.05337357551099793, 0.045732047649160515, 0.054313469633099534, 0.0326227089540372, 0.03501413284891075, 0.03351380327536214, 0.1137795853578756, 0.0756321145942615, 0.007457637074103038, 0.03683099463101357, 0.04934315629784138, 0.053417242522681915, 0.026974342688317263, 0.045670381401695555, 0.04928666114386532, 0.03856064496381629, 0.058391600802180275, 0.0915911816240799, 0.06111947519163932, 0.04164629007479356, 0.02662930626332039, 0.02133939636781091, 0.0961333628924143, 0.0283483941588671, 0.05448326153019744, 0.025416387981104276, 0.07624654009217217, 0.011343139265063069, 0.0464194085479023, 0.015155074032654446, 0.03615941514351195, 0.014531391319788754, 0.030330035707823215, 0.09691910097195257, 0.02083071015564905, 0.020343541438060424, 0.001197069000373895, 0.03198678894419103, 0.009328564553852043, 0.0639828015869904, 0.017511624647604845, 0.03970614942391554, 0.03338716511103896, 0.044942084594719836, 0.0329985516896892, 0.023448220003516446, 0.06662773929776684, 0.05747887598831327, 0.025718046592608578, 0.004262304930542146, 0.08383867826553122, 0.026581414276733998, 0.0716960237872216, 0.03399648846337392, 0.06108836053059467, 0.019711453783055468, 0.03457135701131436, 0.0493539696288926, 0.05578163883558685, 0.024356716012041417, 0.0511414404477804, 0.01610520787747397, 0.0248089051550074, 0.062267327711226485, 0.026202511019824494, 0.023733223863546888, 0.00806416324790447, 0.06568103848445801, 0.043938160843906865, 0.08627400282890567, 0.0021185869474955386, 0.04389334853077608, 0.06779153410705828, 0.02760425082317764, 0.0016737852861443837, 0.015823694505548526, 0.10007440262744505, 0.03150324190726444, 0.02878088526608002, 0.021477299855060635, 0.06615663352873057, 0.06498727692110885, 0.027709145496989933, 0.11294139323816185, 0.01802811729571512, 0.012916787283404941, 0.04801966279985444, 0.06485692706079253, 0.032429562866567604, 0.05722174623740777, 0.10528786077855096, 0.03393270398279832, 0.06621795120618998, 0.021472534788171613, 0.02710656946404807, 0.08512297870531198, 0.030010148034160657, 0.037189983432331396, 0.017825996488212578, 0.018195137869746938, 0.06823263987297974, 0.033910272928375396, 0.02521877560103613, 0.09193628125133053, 0.026877876896891865, 0.04884904873887858, 0.02774604029142328, 0.024454581829148437, 0.01836220440905421, 0.03827084922381947, 0.0018242445953693543, 0.03954323316593805, 0.11969084235569162, 0.12652885123726823, 0.02030321648494611, 0.013401880860328676, 0.06714974394849232, 0.10969887247249004, 0.02737397053879836, 0.029762973595831185, 0.006068972476397551, 0.0501912577648557, 0.010941205489929887, 0.00859263368071087, 0.014799232895095504, 0.024224994854340633, 0.053737869471191406, 0.02544324893894936, 0.018254703121079553, 0.023506036659161893, 0.058211003234910394, 0.0403904268187621, 0.02668277920043517, 0.039699756420187415, 0.031663559211958806, 0.0999251686997952, 0.03143390520445762, 0.05538090590327498, 0.014600151541432547, 0.04495864741564278, 0.023651208405593233, 0.018305255347983013, 0.02691528113979486, 0.025667375622076855, 0.029326054500415925, 0.02896569631693344, 0.1647108802271466, 0.07022630708712725, 0.028036697880334915, 0.06518888061926251, 0.057113030700073134, 0.04103042050114563, 0.05172328422627142, 0.04864928748218283, 0.03536628431550438, 0.03440076838277521, 0.01764528783819368, 0.027469499787736325, 0.0902186201945428, 0.02957905120696993, 0.031588225955924684, 0.05842202598409307, 0.030644892099043055, 0.013708886765544454, 0.04323616766581132, 0.051543464238244685, 0.028413572919464884, 0.036330271902824604, 0.06886758886638188, 0.023942009635990667, 0.019861457629069205, 0.01946003330240567, 0.02278382642074458, 0.03461364506473465, 0.04679451200870737, 0.05993209636559891, 0.024131371249114315, 0.023891610626672066, 0.00960364853287296, 0.012624047850559076, 0.053927981850480845, 0.054076131763717825, 0.12883539642057112, 0.020725828888375434, 0.014819109046290961, 0.041178761936363675, 0.039992735255509615, 0.04287981803739264, 0.020569587171438242, 0.06024310124977943, 0.07369842440370591, 0.02253487465843078, 0.05085192049943632, 0.05042134078159448, 0.10598003653989685, 0.04150710722071029, 0.020394639502609932, 0.07445838362459214, 0.08065253391020721, 0.020719322886678482, 0.029730575737513365, 0.04215911316174654, 0.07260175421833992, 0.07652539609661026, 0.026297829594583284, 0.020416300638668963, 0.032494048317593914, 0.032974473546229066, 0.05923448137999062, 0.04748700952698146, 0.028330783712707704, 0.08344330794868932, 0.044589262801192464, 0.07815173181194453, 0.02983116691241101, 0.016690424358051632, 0.027999881609913804, 0.016719173722630067, 0.008066834979540399, 0.021352705230275472, 0.0829775111689683, 0.06750171538442373, 0.06930581414170804, 0.012127407413396624, 0.03257598142109571, 0.04097489061795416, 0.05730430370256786, 0.08975990972812138, 0.016553237163011107, 0.0197349228866158, 0.08602857890148317, 0.03399709750327372, 0.03964175207300052, 0.045501489657908685, 0.0455741914019229, 0.03464782790791604, 0.013776590743462646, 0.018829960458641572, 0.07622600127492221, 0.059652807521483595, 0.03283236423627504, 0.016160906300008777, 0.04244775976985694, 0.054741172690785704, 0.033284869390509786, 0.058813305391419324, 0.034445136364909916, 0.056832910650559974, 0.0393112042858716, 0.036141990473674196, 0.10005846799862, 0.036337258624694044, 0.11284154133811114, 0.046937479337136594, 0.030203746113505577, 0.05943219718192855, 0.10068956356976302, 0.05157224233112028, 0.051147611286010475, 0.12165575062916165, 0.060168085920233885, 0.025667574804937168, 0.04130485617826062, 0.017861272921905886, 0.03564230579462263, 0.01386764891175253, 0.05252551234837982, 0.03544513391511094, 0.04101131809875369, 0.04892609037098385, 0.01851433797949745, 0.011760449382446468, 0.0206381616167604, 0.010212061198187933, 0.04368638987803171, 0.010950801698791405, 0.03399149740054723, 0.03901941671727165, 0.020413437385051962, 0.019807498226122513, 0.008603255489781018, 0.13451198536542155, 0.02559860773955382, 0.0685100403103617, 0.023686459941428997, 0.09190079605867786, 0.05170446144597185, 0.040461217173405235, 0.0746511313463411, 0.02297622174204838, 0.019033617272432295, 0.006765687308694807, 0.04007836856368569, 0.10095675971599356, 0.03855178515697199, 0.059836898449688196, 0.08017251853861156, 0.07281928488443937, 0.05169790373334, 0.05537312628040391, 0.026938453384284532, 0.045456301961695, 0.04417744074617663, 0.013632005054293381, 0.014585405306500054, 0.014299110588317197, 0.10727569040271545, 0.034476335295626236, 0.04373112558237007, 0.04437889505718504, 0.033881586766050714, 0.021293003998336293, 0.02924475916511109, 0.054455525316898866, 0.018018690583806847, 0.041371245357778766, 0.046304372785192345, 0.030347215229525205, 0.013603840789367116, 0.07811990085869067, 0.02085916649159645, 0.013043839135207238, 0.0365539695767145, 0.027564881564748865, 0.05906791854349356, 0.10560908910608101, 0.030893426343438127, 0.04612746393127788, 0.05164590934591909, 0.07734405297425485, 0.07499199450737046, 0.030029141269023382, 0.01366515942443643, 0.06213020946409914, 0.07807750555296099, 0.03134864536414464, 0.011341088064645809, 0.02096910968482975, 0.02438460735814466, 0.01179479310409196, 0.03212544319760655, 0.03954612514785221, 0.02860653897627227, 0.021748062140578707, 0.04361979385477401, 0.021787368196753726, 0.049315435406301296, 0.03684008426423516, 0.013366128494512412, 0.05052246055715988, 0.07959973758026477, 0.04887095885351301, 0.14145781346146138, 0.10020565647151201, 0.20337287096246598, 0.20616173744201663, 0.1675123718356894, 0.12700190286963217, 0.2290886346130602, 0.19776622584510237, 0.09626530621561313, 0.11870710119124382, 0.22682406338712863, 0.13636139822342705, 0.08393341269824775, 0.09571608246093798, 0.22971711782438142, 0.15164210971805359, 0.14067588283890678, 0.13342844592707773, 0.18522124497159836, 0.1199313939639157, 0.0904294322695463, 0.16421718252522333, 0.15967135467836935, 0.13253270528249203, 0.1005584629432809, 0.24180298220486413, 0.2367379612499668, 0.13403051442676975, 0.11585500181442308, 0.11361097706662071, 0.11274912049092593, 0.14479346753608796, 0.15773275386421912, 0.16868463957742338, 0.1269115274772048, 0.1347097586239538, 0.1727956818837312, 0.16648017561003087, 0.13008445681583497, 0.16498576789613695, 0.08042548843208822, 0.09787365418648529, 0.0968340039253235, 0.1649893378658641, 0.15113332008402194, 0.14424442764251463, 0.14204986153110383, 0.16502889864627393, 0.10722634667951254, 0.1443283755572573, 0.19943557739738496, 0.19854785003248723, 0.08480005732346928, 0.083022020877369, 0.16548104373918426, 0.1360166893010178, 0.13278071858709858, 0.15380692097448534, 0.2653047364325293, 0.14684518889313744, 0.1646289241410071, 0.17181481354899947, 0.16719096730793678, 0.18456729699767407, 0.07390113892934977, 0.11517077038485198, 0.15511921426701933, 0.10508385156431507, 0.13161684716901473, 0.20963694209293013, 0.0758812463872375, 0.11911138877152436, 0.14994513303522142, 0.11490922796750262, 0.2050194390598805, 0.09452777283806955, 0.4341939061639771, 0.16256865324272265, 0.09383964968184311, 0.13629805807384754, 0.21492224396957507, 0.1550049752357506, 0.10294036053481603, 0.34931740092654384, 0.1343433847350459, 0.07626384601838167, 0.130347945096512, 0.11394075493538573, 0.11750436613276122, 0.11456919218143148, 0.15387600678349697, 0.11335208531348936, 0.18461078014825621, 0.09212709843151032, 0.15463717642330355, 0.2132078158038278, 0.13529552477261714, 0.14856717068581812, 0.10374135908580596, 0.07896278143650101, 0.14279693515310365, 0.15350520490638672, 0.1473209601376326, 0.16932078366798742, 0.16137591563165188, 0.2750490990377242, 0.10776483754236853, 0.11432771360681904, 0.08812391364406194, 0.1467598466983726, 0.17753176000570098, 0.11237340032934182, 0.21588251986090215, 0.18536071893909287, 0.10927236834240538, 0.12477819477358174, 0.26044752448797226, 0.2650384136265324, 0.14429969322537223, 0.17216977272783557, 0.13417579534073032, 0.1353719190604264, 0.23589376300092668, 0.12641723222670057, 0.08172358611538526, 0.1546912315872408, 0.13834748116712417, 0.12451886635033355, 0.1762386648765495, 0.06884262206092959, 0.21862871524307037, 0.1370951419155444, 0.12785341725834917, 0.15221454593683445, 0.07160051560570156, 0.3208024745746967, 0.06588561460375786, 0.13269433451275672, 0.13740782836271873, 0.14581670053303242, 0.14533104675431407, 0.09946334025552196, 0.09572407275798822, 0.15000458145814557, 0.11318153881978606, 0.09833552093515474, 0.23185886983429235, 0.16122810662754122, 0.1635587759195797, 0.17244982382943555, 0.18379249099281528, 0.0924901934641023, 0.14734273235644066, 0.2550659866462792, 0.14460548488122804, 0.18651795603575247, 0.15245761031345015, 0.11302548670961012, 0.15300145613089686, 0.12539466572625022, 0.14499974437057972, 0.11563226175043853, 0.17905572339171366, 0.079729926562117, 0.1825377002598778, 0.19667640448577944, 0.10455685202032329, 0.09759668275834092, 0.20117706378861783, 0.10053855231812886, 0.15409746748064795, 0.1225344458174321, 0.15590758002813787, 0.11574317596011585, 0.11467365593078638, 0.17778913490474227], [0.03749430802981219, 0.007698530549063318, 0.040267699533292366, 0.08288507500002462, 0.021341083676464135, 0.024643190760886478, 0.01911819529449267, 0.03614614267022379, 0.03983450745562873, 0.14798495918512344, 0.005140580685674063, 0.010506477405978067, 0.03394630204345431, 0.02799305959694809, 0.03599405506505601, 0.03295939693587922, 0.04310884768323552, 0.07795426498858199, 0.020619335006021207, 0.03323586657643318, 0.013261689643015065, 0.03993185424816705, 0.04628301425386341, 0.048780928200651566, 0.03703991063840447, 0.02971805786083062, 0.10880093315556165, 0.029818302380942532, 0.00588483797694226, 0.030673612735324332, 0.06923341883286353, 0.013268579646284062, 0.016102662550345544, 0.03657962969173828, 0.027443789876997474, 0.014105291301084143, 0.023443778608775428, 0.014901894422608518, 0.027771323108144348, 0.04783302079886199, 0.05262618779294914, 0.014332275492169205, 0.05347203696146608, 0.006563361572672523, 0.07051520650425265, 0.03567270033301846, 0.051755693575908104, 0.04445766804799919, 0.056395585528544845, 0.04249343010146291, 0.034058131728201144, 0.04500974931063191, 0.01043792402807383, 0.06440056082341941, 0.03122721468248675, 0.04737976104802182, 0.045590049421955506, 0.009408303773060683, 0.08350043512520292, 0.04293102718469116, 0.03382796827223032, 0.0193005203900318, 0.017405322287231684, 0.025217839058548696, 0.019955094640834198, 0.026733323766459382, 0.014961062265830416, 0.03460775767903655, 0.0907332397576782, 0.06414234322766144, 0.015096048873308447, 0.02418023999780417, 0.02666732337656281, 0.01233420231484718, 0.04739957974262295, 0.04713975336222399, 0.0463102525100112, 0.007435597203326442, 0.07419427481269644, 0.048466131181245854, 0.039452076363827915, 0.030865368373211355, 0.033074386733313726, 0.07045213448544664, 0.018253201588747964, 0.029756096041490956, 0.029559912415401592, 0.004908490039768719, 0.05963107743751138, 0.022858100560223384, 0.06839551782656102, 0.008458864195422541, 0.05798573508077572, 0.04935347933262106, 0.02803502397822036, 0.11216032063408245, 0.07056041335266444, 0.03259112697935874, 0.06590832144983354, 0.007103707325915176, 0.04889665727293299, 0.08394004701967202, 0.021204518927862088, 0.052623537128731135, 0.042135843241046515, 0.03415799895001035, 0.06649369689365549, 0.05342144068450697, 0.05086330456599113, 0.03241921301871058, 0.027043805795631586, 0.026074124259814143, 0.05082824072169681, 0.04078231909642777, 0.054516149684786804, 0.056415304631715825, 0.03378507500934986, 0.0374388815684905, 0.03571278205321681, 0.0069287299711797996, 0.0883319601416588, 0.0266855409474022, 0.040062361156507846, 0.04706726612282857, 0.02586885866138243, 0.05716979781526232, 0.03090028474558025, 0.02978805722969194, 0.04085652237277358, 0.03917323568114831, 0.002308888454741288, 0.06394760367730934, 0.061613506141809694, 0.03897664602845907, 0.056871954321620934, 0.008204815075582555, 0.00814412463261115, 0.012708894961002856, 0.017105774247958776, 0.03505981084139597, 0.026928329532365167, 0.04426745607727959, 0.032403481403185476, 0.053868958606354655, 0.019625927727188797, 0.04842036125820972, 0.055401180420191064, 0.033575569114257256, 0.062454076964528336, 0.03366061636517125, 0.04263039896144502, 0.021119950481900768, 0.040310987331453836, 0.054581102449446924, 0.01869160497951652, 0.12132078634514926, 0.06088535106109996, 0.05406717236544337, 0.03487607231363654, 0.05454112798155797, 0.04633660593460645, 0.03295924371829437, 0.04969959785681098, 0.02587028358492159, 0.01764094028922339, 0.04052870951953434, 0.05082486993482998, 0.08753631654525958, 0.062004479113966234, 0.027039165218030254, 0.05065281807835545, 0.02149410399367973, 0.06228045462780903, 0.013863041850497887, 0.034686680056995926, 0.11857562518167881, 0.06228756775418597, 0.09209228739623102, 0.03222075794192572, 0.046285883253139835, 0.03674988124159075, 0.04211029420877176, 0.06918654191277682, 0.10443544240608331, 0.07293211431392739, 0.07888452555503576, 0.005161852074501616, 0.04880524383136823, 0.021058659617518707, 0.09636381746179636, 0.032346587883488785, 0.034403729312602556, 0.02021843161914618, 0.02989218773079976, 0.0347932352263841, 0.011473469973181286, 0.03550372814999954, 0.03691472804113742, 0.04598343940151315, 0.06609504772049767, 0.0242221794812189, 0.016529260526200937, 0.06431829064123093, 0.039830650202929974, 0.05770389899431218, 0.04335052544070829, 0.02824058835094254, 0.014169684821559538, 0.06849057401620573, 0.009026725911685537, 0.04977658203232193, 0.01739432892551826, 0.037074985974017656, 0.08439109660685064, 0.02532431953436425, 0.027359280802850282, 0.0370586721316701, 0.024925557363237587, 0.032228870813043854, 0.024461325318101915, 0.0737625842673644, 0.03796822151109096, 0.008966000037147634, 0.03737281414590055, 0.08404225080965028, 0.06277996693707763, 0.07099243331580393, 0.0509793094299253, 0.03513013771284492, 0.07089950685058871, 0.05261364310318905, 0.03822006525531892, 0.060277877811102144, 0.019364737710284612, 0.09314543612661863, 0.014344231251837506, 0.010796939642469009, 0.03349568912639253, 0.06107848948769032, 0.029667882932229873, 0.021622161335882642, 0.07048116155689763, 0.05267705603112137, 0.025840048009770054, 0.07372916751210729, 0.06318795089159282, 0.03392472517706695, 0.007135214607021021, 0.022602171652139198, 0.02825683899103634, 0.02077689439418816, 0.02637129934174159, 0.024953056089279634, 0.010906951783615495, 0.03554235430314176, 0.02840998571275944, 0.016882534311603636, 0.04507851719315495, 0.046208715216527065, 0.06078009824118307, 0.036660976737978, 0.07738095542956745, 0.02063838186703863, 0.027968799507605936, 0.019846426983994823, 0.015075845219525359, 0.0397241295074984, 0.03555411758321909, 0.06901342136364791, 0.019759332363103187, 0.013499293727950465, 0.0547716859728098, 0.05818297207776097, 0.010614958328885898, 0.025805068435147408, 0.025757107500647827, 0.022175937568047838, 0.034227153706935146, 0.03831126036182527, 0.05511876210690506, 0.033312686043040406, 0.032909620372999104, 0.0331186244805013, 0.04138593892416647, 0.03877234953125158, 0.022034998457398147, 0.057537389783969814, 0.026901621792104938, 0.04514342782297923, 0.028531807099258708, 0.04183262947105593, 0.029706871061916315, 0.05812894372690109, 0.08293000605678366, 0.06564168454778772, 0.06681489457766857, 0.014343992806971075, 0.06733223375293516, 0.036115223361599835, 0.05529466738563873, 0.020265860122538382, 0.04870403978613116, 0.04872981098390395, 0.02426079031260264, 0.029902087502001278, 0.10464534283645692, 0.057388523578523636, 0.01895707551269762, 0.018833082266933015, 0.031390609745416916, 0.03226204242016519, 0.020835050043740103, 0.01195466224735062, 0.04522454121240205, 0.06197966169565917, 0.0117781737841846, 0.07063752776312252, 0.02664624255210642, 0.04996600110203989, 0.02822040001891794, 0.03723232511190638, 0.04453034297893605, 0.03196573110237237, 0.0664373587877039, 0.037722521792015726, 0.01978222690072031, 0.07824867257788297, 0.04088020598095271, 0.03957802887945887, 0.02808248695556916, 0.052771859411751075, 0.033211577758793874, 0.022578834698745803, 0.017424734955232953, 0.03385907910283535, 0.012188440680714145, 0.025808941009604645, 0.043163228434540575, 0.05365656839022714, 0.045293642343172145, 0.02027573499588236, 0.019988415635100776, 0.04210302786480996, 0.03697235700524142, 0.01262822398735631, 0.043190340286180864, 0.025996481248688315, 0.00859164925772817, 0.004032493396211536, 0.009203671154776409, 0.018896115981342814, 0.023419409351904067, 0.12042438686494866, 0.12975566720049228, 0.12073624593716477, 0.12196763268401548, 0.11818571707173703, 0.11999533166207614, 0.13494499358198336, 0.17682746473339297, 0.18848563754750838, 0.23141527428261696, 0.050810988421642014, 0.11230769296807629, 0.20225263591254913, 0.11887076821538711, 0.1451603317212674, 0.16405478720703434, 0.10971519014527721, 0.10502562888206975, 0.12880562624383357, 0.11128973065605087, 0.11386229221018092, 0.20268251849037988, 0.19480449928631707, 0.1597306958489841, 0.16504481795334047, 0.07138481588974115, 0.14014305336581123, 0.11289887535836428, 0.08096966366734236, 0.13096922708134498, 0.18031262852732213, 0.1434125021220215, 0.10922769775554057, 0.06626275968888114, 0.08032934439759101, 0.10537048336118461, 0.09763914701198378, 0.12329979063642603, 0.09342306639037787, 0.1252717086144032, 0.2280330727057111, 0.14746454033640125, 0.1317718727213721, 0.0807136677265648, 0.15590791710682456, 0.15903565491880142, 0.108415950990973, 0.19516163415485815, 0.232602940391629, 0.17700734217801403, 0.142848217078755, 0.14865461196149551, 0.1217187766826922, 0.18435363507559224, 0.10194555706074161, 0.20061670111552363, 0.1200303648628535, 0.0986899515133231, 0.24615295201299653, 0.18105548866573842, 0.115620318439699, 0.10551580257954137, 0.12175881243761509, 0.1450622724669595, 0.1245469204901207, 0.11549481791594338, 0.13269951326712487, 0.11422503484232772, 0.28107998832579584, 0.19554254839256888, 0.13670200091456214, 0.0958195886003875, 0.19075616893749084, 0.09779748206417407, 0.09185017296864141, 0.18669714400124165, 0.12373291376617648, 0.10423308028088463, 0.27545549335979647, 0.07650077403072389, 0.1247305824090877, 0.18684581102382752, 0.11799430234297631, 0.23369797114883703, 0.10128797783005623, 0.10636224546619963, 0.1244392851367593, 0.12370571764486453, 0.13805144947142373, 0.1332425776748888, 0.14503268615132378, 0.10869116807777075, 0.1518037083048013, 0.1022829345217155, 0.09528102878961833, 0.13671018273359345, 0.19427920811839644, 0.1497360369971683, 0.13894873761361645, 0.07800106529987628, 0.17223135087518923, 0.23273735817882324, 0.09067681738205495, 0.11754584213298176, 0.18303057058684288, 0.22278396082260918, 0.20039130272644184, 0.15309493417941755, 0.13284752145409584, 0.11863706543320611, 0.188338594631322, 0.11022529745053862, 0.14672828387589226, 0.10662826183702677, 0.16010967954512567, 0.1552146075353507, 0.12259557963378968, 0.2958667416486048, 0.11624745333627348, 0.13539367595747595, 0.2145226218647534, 0.1431438963740103, 0.141419371169421, 0.10173318216637259, 0.07287108008899996, 0.12191721643771856, 0.14043569895288638, 0.12395988263550306, 0.15164224761387995, 0.13873046384223048, 0.16699446575535884, 0.1846215819879886, 0.1486261747777462, 0.15640631858860293, 0.1404974303178249, 0.09658802075371628, 0.10035744913282896, 0.08379157917994647, 0.10369130290083348, 0.09130461877512355, 0.1911483446676885, 0.1726129852355488, 0.284675300241478, 0.13465414064065104, 0.14057452940652448, 0.11900101848427327, 0.16819126363242828, 0.18895000940369022, 0.12724647643945872, 0.12724961739994828, 0.20359013349779193, 0.1348107902994079, 0.1813541557038984, 0.0850033923803318, 0.16194439883674347, 0.1856927567672345, 0.11880506085412157, 0.14819036267938154, 0.25438237574792677, 0.10576299617006894, 0.12176661887356352, 0.1232059142221847, 0.25297251349735644, 0.1241814582458427, 0.08301915570853219, 0.11221488141604971, 0.18633060157299045, 0.2479110318686693, 0.14187713934769555, 0.1903454692012841, 0.09271140901311752, 0.1033163947924491, 0.20764641583927218, 0.13173586658893094, 0.1092205424943278, 0.1954118844362036], [0.018957374286988092, 0.0069529263794632454, 0.021491947456172878, 0.02189955985804479, 0.05394063379255034, 0.12508068459048388, 0.04886731610543305, 0.007210568930473059, 0.02061831036342248, 0.0417891156769568, 0.041813561542620586, 0.0637781833328547, 0.007779225941762449, 0.03184949449684111, 0.06380614554209095, 0.03692508938031332, 0.06657484092659528, 0.014142465717609853, 0.04466615121571287, 0.041524757886485714, 0.0283888780752257, 0.032205022495961, 0.056059292081983826, 0.01813724077486944, 0.03762961064855899, 0.12078504573794142, 0.05313080224779345, 0.06146912538116017, 0.07582784239803592, 0.06219206340310555, 0.03660990165606622, 0.01746894588934318, 0.03147669696068812, 0.04406979007105674, 0.01456999161746353, 0.028260024001581535, 0.06025623582724122, 0.05121660133403155, 0.06790656986976824, 0.0059587089626509104, 0.03048143191863933, 0.025083386797397852, 0.009386634018512504, 0.026208553538327257, 0.02923404542549003, 0.021541111148713578, 0.1028599596071628, 0.00991700817981074, 0.07784281451735767, 0.0437494580663981, 0.022373117108438766, 0.07795827162842597, 0.015350614144887417, 0.05380738045900099, 0.10197071538817498, 0.06040147843680555, 0.0346448861302868, 0.03971823829136068, 0.029865855373622432, 0.05834458215582756, 0.08922134225647296, 0.04747746024100531, 0.017619526216519937, 0.031101658617356615, 0.024585086822269425, 0.08025006195830722, 0.029051743312588627, 0.012891674921247027, 0.02982455365840466, 0.018001055239789912, 0.047855907675599864, 0.05344562991071613, 0.028801814788171363, 0.048151862762507894, 0.056327679494936625, 0.05522497636716693, 0.036498558437151295, 0.0344071728778222, 0.031640237580323895, 0.01951316533039414, 0.018433695734148065, 0.06935969310542268, 0.02815784702468063, 0.01141105774760006, 0.011185436235410313, 0.052044412962371306, 0.06994598785475378, 0.031191702676756732, 0.13181762349221016, 0.05975848552019847, 0.101425314412242, 0.06182219615326293, 0.06073981350768478, 0.025608700947956215, 0.05860319811730616, 0.04624091389198457, 0.06200585041135069, 0.09490566868935862, 0.03799150675354946, 0.06566676626642866, 0.0782247476520077, 0.012165135328447627, 0.021684486418962482, 0.03788365689556926, 0.06387408604965576, 0.029147259154987913, 0.03396516695858971, 0.01914217384652265, 0.018467593209577665, 0.026574440961403233, 0.08466334127250218, 0.034397003060627374, 0.02872628234927693, 0.03692300562115927, 0.07338953009175678, 0.03555956829880034, 0.05154832123568462, 0.032254128731907375, 0.03286736679353541, 0.02693732915025565, 0.0032412382866060666, 0.02239804177905523, 0.09040933778329242, 0.04475903171565264, 0.037561172183843396, 0.02836030491086985, 0.04008034890096995, 0.00935507311125196, 0.03447043641860928, 0.02271092166343043, 0.05514848631836715, 0.030938658089707458, 0.01701036948830851, 0.04948008685342727, 0.05445837899441681, 0.12992713299970474, 0.0657677136722111, 0.026363902762832663, 0.015861917504920595, 0.02534666823433532, 0.07574276067316532, 0.020378291186305787, 0.008750462157261229, 0.023632621197330377, 0.03747105726131028, 0.09577877143578184, 0.11765691722112319, 0.038915956543097575, 0.055603186314504956, 0.0369305094523776, 0.01961987371736717, 0.02847647065326812, 0.009945866711918386, 0.05327748127221581, 0.01608338394773103, 0.09272884517427414, 0.008907142459535071, 0.01681499408497926, 0.06465220538478705, 0.02793813683843661, 0.06840972875755641, 0.00037502370985514005, 0.030108113442697836, 0.03182523440749895, 0.014221343087903677, 0.08112169381591582, 0.027537840576241576, 0.060893823993542505, 0.03830384080027861, 0.01139144398151867, 0.033866912351861116, 0.024816537305953044, 0.039140853144588976, 0.026492934951919223, 0.005326583960859646, 0.07184462186189429, 0.04674802579346203, 0.028394047253494783, 0.03218620354610105, 0.07726424193430333, 0.015194091848247956, 0.07429441016527914, 0.02378020803594301, 0.010593615119315444, 0.04423142696220068, 0.09330223900296035, 0.034981183407287446, 0.07718479861655543, 0.07460172633610426, 0.06080015059260111, 0.014538471887428916, 0.0713485109830095, 0.03301368575663336, 0.01868556629145338, 0.01630495955807067, 0.02772035719376178, 0.021197827149843498, 0.034470896071363846, 0.09587308452014001, 0.046149714955038605, 0.06165507024214153, 0.06793251726776361, 0.058125101795960823, 0.034114201703379234, 0.09055422033153235, 0.059021202501870935, 0.1296985936501334, 0.005168813419708562, 0.019823367737473983, 0.06030760968344347, 0.01917908396271448, 0.03507264281412767, 0.022881558172464855, 0.03988826384527549, 0.01500201541104264, 0.08077599664008425, 0.027028395937034683, 0.09749315363625366, 0.02397036829572772, 0.010257312096655369, 0.0693605894282941, 0.031197195527173822, 0.0074740318344875935, 0.0032669029502768914, 0.015941081200576118, 0.03740306695803039, 0.035183606819520076, 0.103194854943262, 0.04594911483206576, 0.05103598078412395, 0.04138300863785609, 0.03779305550720423, 0.02962945596194796, 0.057209094295338284, 0.07333848565336197, 0.01309969173293681, 0.05676355671077486, 0.01907561995810078, 0.021024484435216557, 0.03439564325456177, 0.05245754119729804, 0.054796292716937686, 0.02447728867522411, 0.0184234110037646, 0.01328238167784988, 0.045400074938492435, 0.02564473963913418, 0.06212941656309751, 0.03419171447955793, 0.10197070006641651, 0.02824922024662937, 0.03091080313278062, 0.05301806857929595, 0.024941122354639154, 0.005711751422964998, 0.10053382555563604, 0.0540434121484718, 0.011695552159160858, 0.0058695123880170294, 0.04943841167034642, 0.009312221025597424, 0.009487923291031151, 0.06726825775037851, 0.030755781410862843, 0.030312007743745085, 0.026157311832291946, 0.025244573611886274, 0.10356018695259288, 0.016875300526378617, 0.04162303930629165, 0.010947382073819397, 0.027864707310894327, 0.08212925265392951, 0.06248754734594015, 0.0885924376967934, 0.0511856283992529, 0.07865226301815241, 0.039090655233350494, 0.025446887856589693, 0.051440662899685484, 0.03200839070843593, 0.013952624341923625, 0.07430964765409309, 0.06240811551951113, 0.012123751258777996, 0.038460191684745015, 0.01712397075138025, 0.08538188578020181, 0.01922665610759249, 0.17696620325648016, 0.05405799080167086, 0.010157950492876192, 0.03483761469983766, 0.052706339742026986, 0.06369462995339306, 0.033315156676596215, 0.015223187867612129, 0.03996968366986802, 0.04101529409508071, 0.029240409700920986, 0.040591911773287484, 0.09631613614938914, 0.03522732362691914, 0.03776254988605938, 0.08108676020656863, 0.03426234395573697, 0.058766815345734365, 0.013027261950135713, 0.032341393807362166, 0.058015689118615085, 0.016092496563590342, 0.04285143831023767, 0.029257202348221215, 0.034939715067946145, 0.06853508372460643, 0.027789425765795094, 0.06839759392483581, 0.01929907439907472, 0.0458299077206081, 0.031000042799860242, 0.03343136455383032, 0.0612012972123921, 0.0419670510886898, 0.01603533204029044, 0.037234332262267994, 0.021374804951671152, 0.013071450859218115, 0.0668587684330921, 0.03787073682272627, 0.07698528633843507, 0.018005820306678934, 0.058441951931003606, 0.044942517434397054, 0.08318554234480666, 0.02434760148096229, 0.1074228865364867, 0.044524087871034304, 0.013386835851105712, 0.03516901284456253, 0.025350559960990667, 0.03223873419506896, 0.05390809803840615, 0.030595965893758886, 0.03299002896153158, 0.02269614765781068, 0.04276228482804952, 0.06056251011848931, 0.03653460287398869, 0.021432893568529718, 0.028472500402600538, 0.05006453150042123, 0.07642922907947533, 0.2574671666708685, 0.27674497255394537, 0.12445291384093224, 0.2454143053581638, 0.18200559090943108, 0.39953400471037437, 0.17820271513154431, 0.15510021528649717, 0.1489285650032182, 0.1942549844182307, 0.12110154730297866, 0.18343914059862015, 0.2580706600940997, 0.12716452801419845, 0.20049857035759958, 0.11274654643550036, 0.18360910486550103, 0.0631257560434601, 0.13008183679513394, 0.13254885441593586, 0.10377429320567078, 0.3017580190733556, 0.18685252195404423, 0.12467472693852841, 0.15003401455619644, 0.20870315752202467, 0.1682167896820653, 0.2413152753105087, 0.15685809595930963, 0.10926868345948959, 0.3320884512316796, 0.09024773153566545, 0.14063258354942645, 0.12008409060898328, 0.1373591664577684, 0.12501291645270202, 0.144713610530861, 0.10568994202560957, 0.14405056143239622, 0.15269538868338833, 0.14196430483172018, 0.18419202116708602, 0.08163023830181168, 0.15501364735105347, 0.13361984533407997, 0.10390909403682717, 0.21337768814015776, 0.20441876484021065, 0.17048480830365614, 0.10597357075781592, 0.24661068954775411, 0.2857133493788781, 0.15014604725424321, 0.20640262612892737, 0.1198002243895204, 0.21432930723794047, 0.08944426618155935, 0.26948736199448187, 0.18158612712737054, 0.14669688959275523, 0.184457179519438, 0.1445937943795035, 0.12288420325926236, 0.0918837276197249, 0.11371005521786791, 0.16266280544861672, 0.1226446399044606, 0.11750358472307844, 0.0789535424161342, 0.12321300819636354, 0.1366261275665414, 0.17386365441545365, 0.1325443191754241, 0.14648946362637705, 0.15508777401860685, 0.16626574760002477, 0.15292074110719467, 0.17634792433631036, 0.1344675216222963, 0.26792564579556066, 0.10456251341008371, 0.25902011882393594, 0.07143782917410135, 0.10184976542668958, 0.08522876778677588, 0.07918238820087525, 0.18130740901875883, 0.1228960929438472, 0.28239511614364965, 0.08924843112547552, 0.14244246627053908, 0.18463612233679141, 0.14232505563526385, 0.14298654191436308, 0.17212912410257325, 0.1357912143031436, 0.20621901017523583, 0.24456284459560151, 0.15063468877586628, 0.1875209796332544, 0.23112334881819066, 0.2119844653193028, 0.2355042839002225, 0.12238203262489651, 0.17053676438668083, 0.13024187256251613, 0.11360312466539683, 0.15928325453592887, 0.09403117932379247, 0.12874007976103213, 0.1970099285244942, 0.17678425737446357, 0.20165462767885578, 0.23744041791125653, 0.19522836041306296, 0.10573160954781118, 0.10392866758329254, 0.10181022762891748, 0.1577244647928784, 0.1400840033086077, 0.20993827511706661, 0.08617543795656774, 0.15572148194957167, 0.13231965623074962, 0.23199750110507014, 0.13606631647675269, 0.09438416965666319, 0.11956151139231459, 0.12265676707630196, 0.0894632651620815, 0.2156774994106062, 0.12655586349747835, 0.10515577955952576, 0.13012524333692368, 0.13323376766375958, 0.20545165054500106, 0.09449026517329678, 0.10025668558814835, 0.09138112797612145, 0.12374070488036641, 0.11177379863276599, 0.1287489663809538, 0.17132061022904613, 0.15459876477478013, 0.09846164965100827, 0.26631842397393723, 0.245415163376639, 0.13241308831399487, 0.14877586835815063, 0.09876484426880076, 0.15193323845103865, 0.15654246773450606, 0.10303708679613569, 0.144848809727738, 0.08869834935232516, 0.18209389020358363, 0.10775138503841816, 0.13522510597061727, 0.18985528018205397, 0.1898466387102681, 0.13314222015680807, 0.0984917569064325, 0.08331489629082142, 0.09807572519827275, 0.0865579839615572, 0.2625858903892579, 0.19590712963573395, 0.2537460018309855, 0.09271946059720171, 0.1076280065782128, 0.1370936250614543, 0.10292107810176189, 0.10734558060404756, 0.06731530320980857, 0.11825496375921274, 0.1314966786172121], [0.0556380931107748, 0.039028157780487696, 0.038656379141274004, 0.009430298157366774, 0.03316463955167321, 0.021697362441749826, 0.04550001110821482, 0.03343996772121999, 0.027376793572799336, 0.07312714497769073, 0.008945891186745178, 0.02845764978818836, 0.05967546840228381, 0.06593674331182434, 0.10500965594884851, 0.04540891942357825, 0.050056736555791674, 0.04110447822078582, 0.02468481614825226, 0.017331471411331047, 0.09429638364141989, 0.04084046900032028, 0.03940501941307899, 0.04567724171905749, 0.03443321220636849, 0.06218339894868194, 0.050718602048413414, 0.012777541227067911, 0.023884510906833797, 0.0761662770603453, 0.060629090819988525, 0.027326557357164643, 0.10315258987247945, 0.06289002312827977, 0.03009075197511383, 0.06796668478918653, 0.023238036120610855, 0.03731304013560857, 0.020105424074215755, 0.0663681121002282, 0.03235417981481841, 0.11053155642002822, 0.03694152196628913, 0.03729555034829724, 0.05116987380109007, 0.04192193617082892, 0.023909198090193734, 0.037081742869509805, 0.08670783075954645, 0.02738607089756237, 0.03820054533500825, 0.044226830434654994, 0.06869574768408652, 0.1015215503772901, 0.05518456905960076, 0.054827679339195454, 0.014253537932921563, 0.06572399303437242, 0.07235796971907539, 0.03407611947266325, 0.021221912954182878, 0.055217936019142794, 0.030358168371622602, 0.020206315938623685, 0.04686565476379568, 0.031487270889263, 0.04313041305830402, 0.025432975699884758, 0.014223719875688755, 0.043934701956928744, 0.044996350432836243, 0.028394047253494783, 0.04376859877318625, 0.028885322202357556, 0.10201967606741576, 0.020444439048127785, 0.09955131779274634, 0.031718968436302196, 0.020770654608044895, 0.060145991944497636, 0.01854558670592885, 0.020916374107342095, 0.017803699499176397, 0.02078677692841138, 0.017905525990851948, 0.031228608962508942, 0.02957359283050943, 0.056064156740303, 0.04375841746467256, 0.050786726417080055, 0.014643844408583979, 0.08753334412411337, 0.060931454232383164, 0.060321586957621964, 0.08718646717287841, 0.07088050020918732, 0.07254575319107502, 0.01204970886089629, 0.052396514633249854, 0.018111440848799485, 0.05101539217115891, 0.02909175033921436, 0.08252984002953576, 0.03303756088679356, 0.0060457585758769946, 0.05936922475455269, 0.012229025146112809, 0.029948133216690154, 0.03834420214256933, 0.04093655174778354, 0.13009162739880625, 0.04659185493965784, 0.05547045392074412, 0.02894998002316683, 0.026868919413837216, 0.09667874088570957, 0.04945762515548737, 0.04212214175852076, 0.039146786495562524, 0.005925017852155913, 0.06283259717747569, 0.024237380580856435, 0.037231398145518, 0.02365525143461362, 0.0677737991716112, 0.034773692323435704, 0.03512793521006261, 0.116672532542819, 0.08532043786779528, 0.03515328888991668, 0.04325752619714026, 0.019773256011126984, 0.04231368289178899, 0.01378889220030678, 0.03976049187082437, 0.025762770805628072, 0.01533569745539177, 0.02040883894228647, 0.04714854422115511, 0.09318213173819166, 0.011909334740090755, 0.024800616083666686, 0.03844174045708872, 0.011041444264382366, 0.024444818038553483, 0.03994794975545618, 0.026104009349740324, 0.030409894628270023, 0.023615679162884914, 0.03956217085942626, 0.08505448278400206, 0.01861269792331563, 0.036597609775321144, 0.07030329126263819, 0.06263169444977276, 0.03766885733291988, 0.024796481124095382, 0.046261808940119324, 0.022454613541823723, 0.03399984775892189, 0.03320408924933403, 0.061628601904357636, 0.021846523591046853, 0.008416623064887621, 0.048246773395447, 0.05042067428510036, 0.06975763747769018, 0.04117970039407092, 0.10016434134975558, 0.0599907978527969, 0.04554808695590304, 0.045517887769927906, 0.026081969000158772, 0.03146421164274216, 0.03499484275497737, 0.01906627560064437, 0.06811355916602958, 0.02102392519103183, 0.011879418049037698, 0.041653357235895055, 0.03206194600000257, 0.041901703788748676, 0.05821847259217213, 0.03642853417043244, 0.0114982960099775, 0.14809590403831777, 0.006186922724854442, 0.03373833981552913, 0.0649035971371397, 0.07732432621020464, 0.06741815051364322, 0.012796343897559471, 0.053632459603250034, 0.013287406257023255, 0.016729119459107038, 0.024626011239184488, 0.04119386535979087, 0.048125930686271, 0.07399942034915571, 0.0527924824986727, 0.035549065233358455, 0.033685904927551746, 0.06900205261885159, 0.11243643404375162, 0.12939218912393818, 0.04653119992825293, 0.062099864721418395, 0.05490860503707683, 0.10880717677214455, 0.03872092204889463, 0.026511941593320622, 0.035963273652258425, 0.059715768457540584, 0.05192091958897729, 0.060604598989049276, 0.04615867818375269, 0.06541951138886713, 0.00296324341287536, 0.07534690006005187, 0.05530882469047943, 0.04442312131305376, 0.09579875100884708, 0.04000154909707847, 0.009312347430104931, 0.06283511760674658, 0.02895970550936557, 0.04015649804064343, 0.03520972658729842, 0.02256557946243594, 0.029569831338801214, 0.09412992805723222, 0.01799711754785911, 0.025178561730670835, 0.06176914073406689, 0.04363158777836831, 0.017224506384903387, 0.031290830623719006, 0.05105493379937065, 0.05363227957258782, 0.03925163328887955, 0.046947059266629725, 0.03389990009788064, 0.05338247362223845, 0.058624706035780336, 0.013402578957949676, 0.06113442539748165, 0.018909028393306562, 0.023009450805764046, 0.03177880947928756, 0.012055576136786372, 0.05730297454001923, 0.02701795032818712, 0.003422685014459515, 0.0528911316406823, 0.012923332547108013, 0.04016251183084903, 0.05626732325782219, 0.08755112502483592, 0.07216625621602421, 0.03719382536327166, 0.04343708571527274, 0.04766113748173079, 0.020978599598991777, 0.03140682399633431, 0.07518201495610899, 0.06264605859835302, 0.05259645592060782, 0.128561903031603, 0.014646294932331771, 0.09253647283560808, 0.0646223969036533, 0.06108053111200852, 0.02094971233858697, 0.02379321046323786, 0.013760757621287579, 0.12384336066222, 0.050139094838091446, 0.030007403524171923, 0.06500682748493648, 0.04649990140610645, 0.02673869978846802, 0.039545876169276815, 0.04402161080149874, 0.03070673263151079, 0.02780582196259451, 0.07697446917694423, 0.03402291083588235, 0.040520780509518045, 0.06209811038007179, 0.03954504113343935, 0.022613634242706245, 0.02273841655903286, 0.04146802907569274, 0.04447552172707454, 0.01891809312867061, 0.017981736417559367, 0.03238686495610783, 0.036421769614061045, 0.02582573174168506, 0.02940031140291643, 0.06311207754357208, 0.05448189789369222, 0.054216578662876165, 0.11793234881253974, 0.021422721836115086, 0.016067481877642776, 0.023329108653049317, 0.06477569109730183, 0.06248616455723682, 0.026532825150136507, 0.022688892805167747, 0.033248089509265076, 0.10516632859024311, 0.04847734670845732, 0.03655753571600203, 0.04035424448609833, 0.02383365799042006, 0.041334748929066044, 0.019893815267771002, 0.037084485464278734, 0.036112814015077974, 0.024478943425140554, 0.019992881927699335, 0.028045569178498084, 0.033240646965080695, 0.09188720565890113, 0.06682510652969922, 0.01845602719714084, 0.025138118033928257, 0.0430427840910852, 0.058673973150190815, 0.02081502833583903, 0.029387044675287702, 0.029248618333029653, 0.06015037396742452, 0.030459470093070023, 0.04722743212515789, 0.048144787940527164, 0.035097804972000664, 0.04050165129404876, 0.03933937716928702, 0.026347435702900254, 0.03185898249578332, 0.026828326329949404, 0.05964775900206259, 0.03302990383799038, 0.04264518828882326, 0.08510934234025978, 0.011131057399325075, 0.03336589851026093, 0.05234458153286288, 0.12726110871881247, 0.19200711390904843, 0.1721808043939452, 0.07395366957831769, 0.15357807518974428, 0.11025294556372589, 0.08411534325850588, 0.17593757700054877, 0.08620638790870867, 0.11539769328890309, 0.4146722698163602, 0.10001165236556724, 0.123680712535016, 0.1416242230803736, 0.11548721066285526, 0.26162916914589945, 0.21045962859305645, 0.17342886887490752, 0.12221199941010245, 0.09728475473821165, 0.10556261821259415, 0.1145810971877748, 0.23524487120730264, 0.09175770615618076, 0.23389962081226612, 0.11033293280390002, 0.11950369473666915, 0.09268801268790999, 0.25328544509266654, 0.17626101932218, 0.11391629374796346, 0.22222408844578653, 0.16040980215034178, 0.2607709974531205, 0.15119393296059103, 0.11692966995460373, 0.1240163739590395, 0.08907102814484989, 0.14383021922361466, 0.13572736853553405, 0.14161833952511513, 0.3481465734301075, 0.2121678208031001, 0.13630237880974047, 0.13043969178632384, 0.1341060813396208, 0.18285921203993982, 0.15806833101857096, 0.1437605511877806, 0.244950944738042, 0.0787379882568794, 0.12993683167282613, 0.1630477186652922, 0.1710025152011264, 0.24834004110626637, 0.18640241465501248, 0.13183847640550908, 0.15602344316580605, 0.16332266762131648, 0.10437014107141765, 0.08129262335358128, 0.14423241538386192, 0.19266303838981738, 0.16594964440070814, 0.16269718747465842, 0.10251627724257209, 0.151695444759342, 0.19946969895353242, 0.14099264487383828, 0.14751277323211395, 0.22321332246065143, 0.15604317759073552, 0.16163951116463832, 0.12209164699719799, 0.06872404697200946, 0.16610767301772872, 0.14331692499258827, 0.17690012051213175, 0.16104449067384968, 0.09355337794629798, 0.15764672219032244, 0.08943315790665728, 0.1444715880338223, 0.14145690947771072, 0.144703452204985, 0.17554581495783023, 0.1254224364135054, 0.1709145529856605, 0.13823881925594422, 0.14015020862702401, 0.14411120495248225, 0.13741718995715343, 0.25341312130612714, 0.08530611968449048, 0.2243871989870264, 0.20650074667026921, 0.22484292937142236, 0.15378980657025693, 0.06314823689359812, 0.13025097368705657, 0.19749283970844364, 0.16733865373797957, 0.12247353416657257, 0.14659582727378415, 0.09075728725762137, 0.09565673362944396, 0.11633054323254094, 0.2136949098278438, 0.12130762495461012, 0.10914512879906163, 0.16366962884222308, 0.32493898164360757, 0.08935467985969398, 0.21440403145407477, 0.2061950775884813, 0.09632874595662279, 0.13627270056355384, 0.06933765275584114, 0.18817463649376748, 0.13485205179500964, 0.11288094124005688, 0.17167264295201148, 0.16510201407776726, 0.1865245290701428, 0.08061634391666421, 0.14390140411353883, 0.12295449948719434, 0.11109919692840307, 0.20329964827866326, 0.20789504201421816, 0.20979417397850947, 0.08529657422895394, 0.14389133771821377, 0.11844736674139578, 0.11317760112785524, 0.1292183944174359, 0.18651017258244176, 0.2949789070313977, 0.09565514016656146, 0.19884628724426995, 0.14111371740939158, 0.061982568999331814, 0.14995029646783106, 0.10702951570912715, 0.11878787750197996, 0.167901421927156, 0.12238999993930902, 0.09000693477930562, 0.12212074301656216, 0.1378784361746042, 0.19634370782202293, 0.10673847124581376, 0.1271185780605001, 0.10963671975919317, 0.200905914628698, 0.2057497047128216, 0.16704452194033131, 0.10982566002395847, 0.16714103369703218, 0.08078640011409599, 0.09947300062424715, 0.10217847077236061, 0.12221622055456524, 0.10213134104325887, 0.0874495570878348, 0.15992892876027093, 0.09841446629575185, 0.16182228442161314, 0.13656154635452455, 0.1288847171611363, 0.178939278027223, 0.13419788931646656, 0.14463566874544467, 0.20271700776873097, 0.10248939521730908, 0.15978901046178035, 0.2898078135425045], [0.04351510027904184, 0.04178389861819245, 0.017228135726444663, 0.058352679705187205, 0.046588541609385324, 0.04583767968259993, 0.027199026700409672, 0.036651232099581155, 0.048317084945137465, 0.024894992370278608, 0.025222157879221826, 0.04293393448836381, 0.03062523428290602, 0.03336877133997698, 0.012989566593821491, 0.035282746257801215, 0.006640166675131167, 0.031162591335634073, 0.02946458043410413, 0.0614054519833336, 0.018208184347097433, 0.04444972754666402, 0.06807592126630968, 0.05872529338023836, 0.021689222757554343, 0.029940786433496305, 0.04278650086733603, 0.02398153785766373, 0.019088543861383395, 0.02896809991779587, 0.06942907002784553, 0.05945738615287889, 0.031084833411319606, 0.044800434937520374, 0.018792311067602808, 0.028617967092882723, 0.03504272708068452, 0.02038277854632226, 0.022359427117231875, 0.11236961585499587, 0.05326982422341263, 0.03713402837034195, 0.024002335229588133, 0.01813603993204813, 0.05995217169965467, 0.036894706333236355, 0.03482932945893657, 0.05148698440602711, 0.09776633292917283, 0.037984929888719515, 0.005597706307702128, 0.13591196508176867, 0.03403475072475211, 0.0725512613632506, 0.00823005288463807, 0.06448280802297016, 0.0399157204364817, 0.01960137652443542, 0.038885067877990585, 0.04058097586816838, 0.061516668797741016, 0.02948946296988476, 0.016247374644022317, 0.027929681142972364, 0.0729591572176545, 0.057649947252244725, 0.020182467621540832, 0.06632585469032488, 0.07505320493252048, 0.03196337538200521, 0.03103510855937437, 0.053240935047788006, 0.1266404012999227, 0.04117726423447171, 0.01285683994572009, 0.02314769520214008, 0.06767462908981309, 0.03351759158014771, 0.04868895551490207, 0.018380925682703816, 0.038828047953786395, 0.017103636862650033, 0.0119233206327584, 0.03159308295336462, 0.080605388859347, 0.0369580541436951, 0.016259275819926013, 0.012093181477769489, 0.027391188364896565, 0.06123344992257415, 0.03444845352562205, 0.05865415445558968, 0.04768663671829047, 0.005313610740666909, 0.03097742788433548, 0.04404561233616645, 0.059266645581491535, 0.046325616403332645, 0.05559041179836758, 0.032241986238307534, 0.06361866850526103, 0.07638218362004527, 0.04665784575345536, 0.03220868056579944, 0.04028210198626884, 0.08070222237297604, 0.03290505831941001, 0.03187180680763577, 0.042886624728599866, 0.060925969042845314, 0.042154788595413974, 0.02618851076300827, 0.027280398644506935, 0.03599295572888467, 0.06625365856434069, 0.05202577021273394, 0.0608120326163067, 0.03993891757882891, 0.03576181551081038, 0.052139074616735025, 0.032296861116323745, 0.02743069934959133, 0.0302212359008169, 0.019871466567799933, 0.12188176954946212, 0.03346761583440727, 0.06325757296215143, 0.09008827033422648, 0.015368580821931604, 0.06961737443963367, 0.06185182077329486, 0.06783723125174161, 0.0125279258410897, 0.07012361300087745, 0.04988657693649012, 0.02381436981170649, 0.023793095550049218, 0.022334816542664365, 0.011939903563489358, 0.044903630811360576, 0.019514155499036276, 0.01839866444859053, 0.04028206368187263, 0.028611798169872457, 0.04329355531221917, 0.004487276704411113, 0.014067231095395984, 0.01181261518204044, 0.05270138698359651, 0.04601212939427746, 0.03518276795324299, 0.06709590328917389, 0.05338662581878805, 0.0821416709391821, 0.028929113703329238, 0.032917557043894645, 0.01321426113962286, 0.017205382915093534, 0.10931688571168531, 0.03760679271973429, 0.04153135773395339, 0.04351694272049973, 0.010814827795500958, 0.023367520301572742, 0.05744707950901601, 0.0349730858579278, 0.02015637658205965, 0.05728649981920758, 0.01520860346875364, 0.045099140280076576, 0.016195391747920264, 0.02507385474839999, 0.0331775596245162, 0.038326704694378766, 0.05699288896134785, 0.01008728271230094, 0.022416161673684275, 0.026703959616321712, 0.04008096943218862, 0.0763876305051869, 0.0654043275262079, 0.06671836749920923, 0.04664780234076804, 0.005966806990815508, 0.028483170092165954, 0.004756170214198891, 0.06428915631747054, 0.031954618997030684, 0.015202876003909738, 0.043969773462102305, 0.024363982356003216, 0.04306831397116185, 0.012284075266741698, 0.015883702172657416, 0.02318725406733011, 0.04912598952350598, 0.04459033915472608, 0.03865295855869209, 0.045608159740485495, 0.06397509091203252, 0.04129397389929622, 0.007392468847214215, 0.03485662134123906, 0.01403537524428459, 0.03254877380846489, 0.010081469062565556, 0.07961480652973538, 0.11781408781966857, 0.053644602096849875, 0.06535731271029481, 0.08354083860232946, 0.01878250705739183, 0.059339764843424486, 0.05005577894588632, 0.040941646232480006, 0.026405344289096615, 0.07707548553063985, 0.024688171613360607, 0.05135414475995687, 0.03640717180866388, 0.04529961016810229, 0.04263593777713757, 0.027476492255265196, 0.022362209931616823, 0.04370391796973925, 0.03306894367861171, 0.03734765198802756, 0.012623959750447784, 0.0654471211976582, 0.03651378826508599, 0.03185196513039691, 0.05360840444242763, 0.029260839350641738, 0.018526817551783977, 0.06245626031511253, 0.04473768467564256, 0.06858170017479889, 0.06439663079236785, 0.006806541341281827, 0.025313703470953533, 0.08659924545715894, 0.05272086476907135, 0.009734682126661703, 0.06166841549378249, 0.022915652915534955, 0.04399197469014795, 0.03108083060191524, 0.03389635694123084, 0.010047551477327943, 0.01742759437841033, 0.04124986255661615, 0.013090672005238313, 0.04570219703319092, 0.02909581635087248, 0.02355104049427375, 0.041482561763616345, 0.05161161158954905, 0.015985750829831006, 0.005490305089962579, 0.03912619788259749, 0.05141448950575245, 0.03069977080749889, 0.012965416629618455, 0.022750842505164688, 0.0401058787810466, 0.040918495055408254, 0.05003520182424015, 0.04213415401717348, 0.018197156511427417, 0.020627300405213912, 0.04339527646680513, 0.03641232758039429, 0.029097997786236868, 0.018299795056302703, 0.03658658193965112, 0.01374524051038128, 0.014805712083715105, 0.05745878916293864, 0.02201858693884025, 0.05465458177270428, 0.038368203677237034, 0.04408604262637035, 0.05724566733284343, 0.026134206620495648, 0.027932465872577125, 0.03260293622471152, 0.0558946866001333, 0.03332953231649534, 0.04220230519891747, 0.004671915385481572, 0.07872486517073647, 0.04380469300573872, 0.06644858197579462, 0.08080781993245886, 0.03306032135902393, 0.006213587372668929, 0.03189732902683318, 0.048273483050927046, 0.024250214468807946, 0.05679236544716743, 0.05035968985588801, 0.015252116305242865, 0.009984958263474607, 0.046529579652293075, 0.0334432274253378, 0.03929673671542157, 0.11479347208214384, 0.047412247006450935, 0.03933786414563656, 0.0022435521673140747, 0.05177018795943549, 0.030992816675514467, 0.018611736482970657, 0.04483679730084635, 0.014842079235090604, 0.038850264503590526, 0.015980425561147354, 0.010843214225925265, 0.04194139480410565, 0.0386587233703223, 0.03621805917411562, 0.042091639967815536, 0.04793783694866204, 0.01952716941764999, 0.07125446602942483, 0.029621957876389066, 0.0698687125658316, 0.02680212229249939, 0.07581864168206531, 0.02471186288241898, 0.04633628800811787, 0.11322967212406859, 0.13187339469309778, 0.006198665895123756, 0.032555392808130676, 0.05845311766249999, 0.10826285598018479, 0.04829323662805462, 0.019610280381335367, 0.035195565452018095, 0.01606874592271784, 0.013141698249044919, 0.03761380625468108, 0.03210183811343966, 0.032881658163762865, 0.025023484467378548, 0.025274542971484126, 0.02902482872858884, 0.04249279424848576, 0.058358965456605925, 0.030473261590926882, 0.08382285854989484, 0.16128766230277478, 0.24580700202814995, 0.11723937631975259, 0.12245654999729126, 0.2115636838660125, 0.24969027107281072, 0.09788745909088081, 0.12029883271503834, 0.14284153679205527, 0.08093832301036005, 0.1470467925912911, 0.16088116072839306, 0.1658003032207489, 0.18622031555541102, 0.07105768868519415, 0.16385427135373318, 0.15330006188202291, 0.12723186714274268, 0.14255076045951537, 0.17178809240220055, 0.1208991162298668, 0.1732802324958386, 0.13481411512099928, 0.1493598878263466, 0.1487724822495253, 0.10899997045916897, 0.09506735154577801, 0.142100254794763, 0.11969859516548535, 0.13283196986923296, 0.27962016182080396, 0.162797192592294, 0.13870112267473053, 0.15368298327009525, 0.1312903098521694, 0.11623315047472717, 0.11179346410978226, 0.15123456626409484, 0.19281424882431186, 0.2436884011953108, 0.15029894308217112, 0.1227257839374004, 0.10496985768118214, 0.15534332562838832, 0.12723380534519113, 0.1357739466813303, 0.18650707758722768, 0.14197951933789638, 0.19321820698678496, 0.1252402607051115, 0.0927936255691513, 0.26919428739816914, 0.12439050831862035, 0.10147458152665247, 0.18896127089617715, 0.21403292314179484, 0.21518674348631214, 0.08681299930979168, 0.18105460000374626, 0.08704016736197857, 0.14961283473718553, 0.1379238192232386, 0.09517866412117597, 0.1252186417038883, 0.17356458901157304, 0.1692852218665423, 0.11992696597571335, 0.24899480113339043, 0.16262264711962593, 0.10946285610477771, 0.10713443911123662, 0.12346042395238915, 0.18117460001620556, 0.11041727142348406, 0.0905360104215722, 0.12467283470135544, 0.12971098895274824, 0.12363123091598674, 0.14858557211775936, 0.16355946539871155, 0.13759426351997162, 0.07565800836610218, 0.11710219295515169, 0.16636369960202327, 0.11257750913500787, 0.10959596388162145, 0.20911344357075232, 0.09114235369188171, 0.17237330696755843, 0.1768367037537598, 0.08333169659900089, 0.17219598825660445, 0.1470567823778237, 0.2240706514567137, 0.15437336638569832, 0.1151266054160172, 0.15179719655744492, 0.17982954880402935, 0.12707989828120317, 0.13719556072065908, 0.2152480151984961, 0.1418975326082399, 0.09593056409709877, 0.18768679170358568, 0.10162082005051837, 0.16227924054668796, 0.125426305157523, 0.1490116242559687, 0.14002119942057517, 0.18664874256618563, 0.26097483812801303, 0.13974537712431725, 0.14465954004516526, 0.14113408002641895, 0.1597511657183209, 0.15318511804986387, 0.13487796088860882, 0.17823463035446985, 0.1828959995820638, 0.15300191578365144, 0.22395786799250111, 0.10291239066470055, 0.09779899891826416, 0.14900143528657575, 0.16646368939790035, 0.10966370137588632, 0.10672388493173546, 0.11769271650982481, 0.14699273742735386, 0.16709218793098005, 0.23281559107765076, 0.11914220848871816, 0.13109517193609668, 0.19606138910016707, 0.0705958602409209, 0.26154036423371685, 0.12224776039440786, 0.19394355435525218, 0.0997384807335273, 0.13479148488371603, 0.10143767141046063, 0.11776236156302115, 0.10923084637690937, 0.133793915832235, 0.1706203752227368, 0.11616561216332259, 0.09390260678746047, 0.133294012818125, 0.2722837054921735, 0.16181515980391734, 0.17055891964945102, 0.15721040447392773, 0.19817876419232738, 0.1391390644975247, 0.13352906391505273, 0.1907895397274725, 0.20811308595922687, 0.22129853165918784, 0.2216537513079182, 0.17527222963831118, 0.18466103551608903, 0.20619909188920454, 0.07883853729694121, 0.08495636224266022, 0.2379565160240858, 0.18333590258994412, 0.11609228222721046, 0.11334603321888756, 0.10725895904244916, 0.15242960213893844, 0.1285960705530259, 0.07628122089250435, 0.14172753769784205, 0.12021745119484202, 0.26450046668610266, 0.1272908405911538], [0.01715683783855169, 0.03841149530583813, 0.024601203396976478, 0.03389464473472007, 0.058646826824593934, 0.012089567457986696, 0.03134932335195763, 0.07191565353423357, 0.07102031891624774, 0.02942584702865251, 0.05713405981359463, 0.09892032181303348, 0.03349548228265297, 0.04465188282812315, 0.06773027771663281, 0.008921868584659553, 0.048635448103830706, 0.005159701761459151, 0.042909446487864183, 0.06517974119032584, 0.027188431704416875, 0.05500453456695523, 0.018798516379789482, 0.03355404970446422, 0.013596191401443174, 0.011122924418398931, 0.053167677890028686, 0.022575992512546723, 0.030438421827350414, 0.09916238261446839, 0.0401039635612359, 0.04465137721009312, 0.0464918383307034, 0.03823953921035413, 0.020977251284245043, 0.026859354806102576, 0.05903722140036764, 0.018329107495505485, 0.020204218772930965, 0.005932967929590133, 0.0317560164483204, 0.030466698132635608, 0.013587124750859315, 0.028974117538441094, 0.016598214185045614, 0.039423141222927845, 0.07309231095977368, 0.023977186478253816, 0.008924932936356674, 0.029933797796407056, 0.03567993986390291, 0.0664505661435185, 0.03376222260656857, 0.06206063718925561, 0.0365893704996955, 0.059960334366487886, 0.01988574836192833, 0.034837453821373564, 0.03048123656621864, 0.12855185195803642, 0.07641802887402235, 0.06613943485483047, 0.026425551773319324, 0.03664241825801231, 0.042579500079755826, 0.0102002251397578, 0.037404319511786584, 0.04699112847447396, 0.08803715418663718, 0.006739601536068104, 0.0602350956309707, 0.02280727637210681, 0.11691312245543926, 0.008039982640184462, 0.08414912773596664, 0.02848092162410819, 0.019923060674280412, 0.05897047598996471, 0.02042282962300364, 0.03870895192507775, 0.08647821122600187, 0.007831894965361684, 0.057853822401093866, 0.023983882086712028, 0.03278688542665013, 0.041764236971615784, 0.029343641963937593, 0.03679716418827734, 0.08060480663252455, 0.030344746511189208, 0.03024002995281931, 0.03645589883108774, 0.05041432341620807, 0.06157332483018118, 0.037264864696490194, 0.034804385636121996, 0.04316591357271518, 0.055922832670471365, 0.09161401870510272, 0.026920019393606533, 0.005715692945335422, 0.07914553937171737, 0.055400563719412016, 0.029833798424430916, 0.0670235462847256, 0.041616738233114445, 0.05168190015660179, 0.028004437917843465, 0.04478141680480011, 0.0929831940260145, 0.03936435163561856, 0.02564933233624024, 0.031766475463706645, 0.030758347805409186, 0.06464062979625118, 0.020005771357025352, 0.024141159937566808, 0.04467233737570144, 0.00447374232481384, 0.014023643565334141, 0.0320485643591852, 0.03382238349126231, 0.03192792083286951, 0.052781711302457325, 0.017950953089541966, 0.03850550195502658, 0.022304307091079896, 0.05753361297050311, 0.03583583875649399, 0.05655796169453571, 0.0305117804917597, 0.0317249286003531, 0.09636985423463969, 0.022962005065393545, 0.0436081952836004, 0.01791086370846437, 0.04058730758486256, 0.018101887732383706, 0.015664239049768977, 0.028523351403794465, 0.03502609914228801, 0.015861999859372457, 0.014242468920025616, 0.011392307745653295, 0.02932678036872418, 0.027470484210719025, 0.012876347417101986, 0.047839904098861644, 0.09325884012204987, 0.018560672892377745, 0.01267585741926826, 0.052678166858611576, 0.03690458120658033, 0.017782848501097293, 0.058579165939121484, 0.04355626984409267, 0.01826911323493527, 0.02188953368233577, 0.00812375914275406, 0.029883348991373376, 0.08812372212208087, 0.049912597112838304, 0.056505059492924524, 0.020849178620283643, 0.058823122808168975, 0.0502382189546141, 0.07366950458456432, 0.062289325925972194, 0.04854525657250516, 0.03745205061990888, 0.032124135102475845, 0.02568318001595476, 0.07128914682975701, 0.0458404490904462, 0.00613388741546641, 0.025022434926922285, 0.04872195092180083, 0.054935881597620834, 0.037025113650147, 0.03684100356974429, 0.05356633089362614, 0.055019802699286136, 0.022123083246931918, 0.024405188310230454, 0.04743129961312779, 0.05051524783935278, 0.07219714488113119, 0.040618728681076924, 0.01564733915015935, 0.07581129489887146, 0.07876545250896486, 0.05019717579407077, 0.01840658196728797, 0.031782925286660754, 0.04280278023572699, 0.046793006645936164, 0.03723693313077092, 0.03179637779061112, 0.01003094939439888, 0.016108816151597326, 0.03406140675407744, 0.06919292342518607, 0.0539681171968339, 0.10952126264812485, 0.05097703031835057, 0.06425176356588641, 0.07168454779011589, 0.07100760185670468, 0.06716398552300469, 0.03982579320549004, 0.05485999675828123, 0.010654118828355305, 0.04686861952406265, 0.042573708455048265, 0.025690492325192018, 0.01584597329999651, 0.020038197943640333, 0.023907635270828204, 0.03608310895581399, 0.06627842618693268, 0.006371999991261551, 0.06336992358668678, 0.05728766810329211, 0.04452986034354375, 0.04849554895753822, 0.05881925023371174, 0.024221970722259536, 0.024466655374835097, 0.04161616749761086, 0.03511371661818797, 0.057745692921021295, 0.027939069550484422, 0.030076889614123973, 0.05301997613822741, 0.012544133388737758, 0.03804360456284016, 0.03767724982613037, 0.09010038984518859, 0.04057835967790696, 0.023394555544420596, 0.07332683345603366, 0.051886204314688524, 0.030212831916287545, 0.05138512152517515, 0.05872018740422303, 0.01629690797398648, 0.108153757398888, 0.011428524552273655, 0.017450316546244488, 0.02893193290689059, 0.09787843457513279, 0.044935921417369, 0.03503226998051809, 0.04823363881798522, 0.063563468039877, 0.04485427559683881, 0.02034153620291862, 0.048979578629857114, 0.025943100242124453, 0.015242300803713022, 0.018557290614192045, 0.0730418793917183, 0.019470511469990015, 0.032509557767620975, 0.024354364122113874, 0.007032168599131007, 0.03251219694052012, 0.03128071443267888, 0.03198891675340072, 0.03316319930637556, 0.032251359324061105, 0.049540852947581204, 0.0301558751943371, 0.05262050342055098, 0.12911135661265544, 0.05928703118115664, 0.0072363520983696715, 0.04556065462830086, 0.047594273327699596, 0.08361151787422358, 0.03194423275999725, 0.07776522513238654, 0.09481988982447694, 0.02104020264420298, 0.024957989695512002, 0.041700176699387456, 0.03924588379900783, 0.041864100362985365, 0.0440414869526942, 0.06251082875795903, 0.027447108952929417, 0.03391262098786331, 0.09631599825356277, 0.0597724513030581, 0.020096757704572334, 0.04155025712304539, 0.07925858330582419, 0.04182290781529681, 0.0352288558027677, 0.05783059461522968, 0.051323336534081936, 0.02271768813502164, 0.053173090301213734, 0.005342313661164935, 0.053793069936575434, 0.06120590906169626, 0.09041496852953589, 0.02781399420552677, 0.06141457226007216, 0.0294745434075594, 0.019314604916519696, 0.030211824510667114, 0.05008653737604619, 0.08920056595196647, 0.013839603390454525, 0.008065278863444204, 0.024602371681061004, 0.06713102842050214, 0.04746914818702687, 0.013221616541305858, 0.03251534556188891, 0.05711936624720693, 0.023705104606286175, 0.05285119164674994, 0.04631004566627164, 0.06495802002328058, 0.02626968926990465, 0.03068658643432202, 0.06700094669095932, 0.05797158926725388, 0.053772194040638786, 0.06219159225903212, 0.02031050964198526, 0.025462579252498767, 0.03966176228958272, 0.01848467505506931, 0.08236412755063466, 0.07260838087888495, 0.009751894207100474, 0.013663360075424276, 0.027891658284070513, 0.0563569900189196, 0.0461723720053992, 0.04156927908620527, 0.046225101837227424, 0.061997059552419576, 0.03765026437899759, 0.04177404289704658, 0.03287797328084707, 0.08682594619571202, 0.01817059241265299, 0.033691627604346124, 0.18356457983534183, 0.14552411623299122, 0.11756170015301436, 0.16240156946643708, 0.15614197228945073, 0.13819954958894562, 0.11649388849975602, 0.09062396497615884, 0.11995228518161083, 0.15225560824957587, 0.21546035944934816, 0.18057504428490517, 0.09758378949857528, 0.21594691721181716, 0.2805108462850894, 0.09200219545633563, 0.11962081425853315, 0.17471038075464387, 0.248216946098593, 0.15256460215295517, 0.13293920685687374, 0.12727757194830527, 0.18386621929464803, 0.12995972238000364, 0.21498069647819767, 0.19171941724996414, 0.1458430386358692, 0.10053200226637626, 0.13097616783793897, 0.13835146482433044, 0.1369077414875069, 0.13635660251302106, 0.17837313905117974, 0.12855209710617221, 0.15049726792400883, 0.11345019053307273, 0.2433282172968311, 0.15342370847300177, 0.15172100145249598, 0.08348337434712919, 0.1076170745035333, 0.16578527257567452, 0.06986367936816908, 0.14319808943377388, 0.0736919969260212, 0.18180556535240144, 0.1479232584637019, 0.1220286669089429, 0.12087901408273367, 0.12731148666071315, 0.1043142396355829, 0.2077669214697615, 0.12981318508184728, 0.30771980723065717, 0.13896117888150677, 0.1546435196313166, 0.11518676630071095, 0.16578282109431683, 0.1574105832485422, 0.24698509203810848, 0.19103775221493938, 0.18317595875311285, 0.11483964420134023, 0.10298963531010574, 0.2054057005913027, 0.1268530519859445, 0.06464036166547768, 0.13039139760357718, 0.16604004277577325, 0.09135114329476511, 0.24056515265857023, 0.08164952839574507, 0.20925812693613194, 0.10174115714166435, 0.20313959718952257, 0.23353068818969114, 0.06016483387699532, 0.13287556027212452, 0.17419305690113576, 0.08485461044455729, 0.12454069985617554, 0.09632096250331211, 0.1045104117703534, 0.06217648883560493, 0.13903541280136955, 0.1521790147789063, 0.10627770000287604, 0.16575513467673333, 0.150508820529907, 0.14259162358939648, 0.16078175315933843, 0.13732653111219406, 0.16521551766462866, 0.14541776790734262, 0.16397692203041048, 0.13294080031975625, 0.10312446678477911, 0.155071119267133, 0.1957811388157068, 0.1221981178969145, 0.12686665004660047, 0.14918407064772424, 0.10833066242236285, 0.2064996741471752, 0.1813771536633853, 0.23911998907644905, 0.14851317680891485, 0.09733229815479248, 0.15433876985503783, 0.27750698489046866, 0.2125556757974048, 0.12020846498349022, 0.1422083038356035, 0.15491186490943357, 0.10000799046528917, 0.19603701218241648, 0.2169494198695306, 0.19356385053646183, 0.08044996494126898, 0.08899352302955044, 0.16609175371066218, 0.12518101146504765, 0.1921775071851669, 0.18813205732693597, 0.1571764667788821, 0.14954989295332663, 0.17368348585742135, 0.0901171978142473, 0.14055042828042663, 0.18014499316773108, 0.16033411266342287, 0.10443495977069102, 0.24640508687063573, 0.07896936213177058, 0.12387303890840662, 0.16715897547621883, 0.1291003249465458, 0.20750631367967975, 0.13059772040334441, 0.12267667004057478, 0.09202065051443155, 0.17783047300913643, 0.13152399731259193, 0.1313390943311876, 0.08020983468140326, 0.14190834976973074, 0.10164135886776833, 0.13577206210503656, 0.1345140384810586, 0.21219277994767313, 0.14186865109349453, 0.15850633412839907, 0.11117851001120384, 0.1239848571018346, 0.21196577277395034, 0.1518643824684043, 0.13583269030336412, 0.1067005345718034, 0.10992083112679182, 0.08949537956786734, 0.17868273050313999, 0.14635829405198175, 0.18113896160596804, 0.1061466146981524, 0.15432704870979633, 0.23102090754095586, 0.20171684934006584, 0.20298366765341452, 0.1630682498216629, 0.10725319806125858, 0.10476575653639533, 0.18146802701296347, 0.14452218048034177, 0.147340755849596, 0.14919163959641613, 0.12429198941155789], [0.061385445597191016, 0.01648400388207407, 0.04936459909884199, 0.029796080085478967, 0.07923801384505727, 0.04623173998909132, 0.041211041051053235, 0.03257770511892534, 0.06234896587087743, 0.047559374192309, 0.03083730082688553, 0.04532859510471744, 0.08235632877556548, 0.0361776786796268, 0.056447717811792135, 0.05211170995607973, 0.0727494023439865, 0.04225465581722317, 0.03550713341082296, 0.05702853503246462, 0.04243300874687491, 0.043516862281267686, 0.03041876401121338, 0.08890518543100165, 0.10938663801719105, 0.03888976399696643, 0.012167443168319523, 0.005960372809861457, 0.04782820593625788, 0.06195328528842619, 0.017184049281622135, 0.04858145039648779, 0.030094731801880464, 0.03066456715215839, 0.043328971556958654, 0.0808778403687381, 0.01914117601700127, 0.013690631847918756, 0.027021686922037796, 0.027441062603987036, 0.045061954372232, 0.04900037025612208, 0.05110858676714763, 0.032890479666210955, 0.08404589738816985, 0.025072531331510797, 0.09673435886901233, 0.04172197190083323, 0.06272361350936756, 0.07227627410283012, 0.04717118978019684, 0.04510416964729948, 0.06361857657471011, 0.04967761879426338, 0.06178178501525714, 0.06631714427062581, 0.015896057255656248, 0.06022776799997496, 0.04392953469387947, 0.08826452142168438, 0.01402937773344738, 0.03954591447367303, 0.040830364300599026, 0.05324856911395347, 0.05906032661216394, 0.05773631217438848, 0.0379771770789258, 0.08946058385434652, 0.041742031913130515, 0.043043569331207586, 0.019468347271603924, 0.03484914815353771, 0.04367625453479348, 0.016123440770071842, 0.03692748723551631, 0.05641469559181602, 0.0461880499947696, 0.044815208943140124, 0.046114999680749835, 0.08250262092558608, 0.04068116484690578, 0.025291755051922896, 0.014699233523119363, 0.04843941386488657, 0.03987294208678988, 0.03867394170693813, 0.031808240662118605, 0.031271247501154585, 0.0034342687426795887, 0.031743734143674374, 0.018213221375199578, 0.071717964545373, 0.00914912760978745, 0.0188877560468691, 0.04335244449095861, 0.04612448001881281, 0.11171522355007549, 0.10284471445746961, 0.030403166461075028, 0.02617635486286975, 0.0246640628263835, 0.032839822102217905, 0.0374708465871311, 0.035806639315260035, 0.042553384142417106, 0.020515763749098106, 0.02772003543683358, 0.08199793752282858, 0.03635076858523873, 0.09165998398055954, 0.042010783217847354, 0.028031024999255617, 0.04130700888532785, 0.013654303958549375, 0.026905724192939462, 0.06143491955534105, 0.03469807944530922, 0.013791004687757983, 0.010709874707484439, 0.03476549135220628, 0.03370945830078375, 0.029534658326977686, 0.04216544870888034, 0.07854237536629362, 0.034480039330740134, 0.08452058844869176, 0.06095853544050648, 0.04818369371576175, 0.08017877747695293, 0.03184682468042499, 0.023960623657330874, 0.05290723097841105, 0.007758288279986911, 0.0371030209616067, 0.023924108076420043, 0.05458275719936337, 0.06613057121754655, 0.005408256115662235, 0.027127560273173357, 0.04530578100633237, 0.03312550778050096, 0.02126859643706872, 0.10865857869747186, 0.04939948674291373, 0.06012698913353586, 0.03167688722662147, 0.026873640430670594, 0.009499746900532515, 0.057853305291744976, 0.022696722223753893, 0.012284871040573044, 0.022587066313492197, 0.02463958823242255, 0.01261959400688929, 0.04224360499891543, 0.014222573616632051, 0.03727054906888835, 0.07154286748939945, 0.01328838780717624, 0.08483126008462522, 0.052323797567477154, 0.04068140999504155, 0.05429210727133098, 0.016530103222917647, 0.06340374253810414, 0.061999407611907496, 0.06017495772891468, 0.105843864411356, 0.03347261072767358, 0.04612647184741594, 0.008264815081812201, 0.07833739322039389, 0.06801173075913422, 0.03222500206902623, 0.038051395677030087, 0.06721784150408161, 0.03430372036452736, 0.06359500404928001, 0.07539916257824629, 0.020396535570222526, 0.04130299841504424, 0.010326292568577394, 0.07961187241298538, 0.028504241340523286, 0.04090900705646604, 0.07180144514648185, 0.020545039799124486, 0.0781250259869041, 0.09572748184925127, 0.009682310440938079, 0.04299528663977981, 0.036094420244016, 0.04354952060947976, 0.0927794146381559, 0.052387911465860186, 0.05926356207759631, 0.0402061750120934, 0.023564391491574146, 0.04068618272280982, 0.07256326596102408, 0.05652302042430928, 0.023262405377482216, 0.05343880406731079, 0.048357373509075374, 0.012567475130180679, 0.05295833670383981, 0.04047188494775084, 0.04889193051044018, 0.05760606956638156, 0.03529041862836288, 0.014686857372702611, 0.11315622727476782, 0.04460728501961116, 0.016295004245494644, 0.03127831466225607, 0.011925196590562983, 0.059644790411356, 0.01712383285555388, 0.01754408762339623, 0.05876218817467171, 0.022364307097309542, 0.013538162156398739, 0.05375105384436827, 0.02783199918696717, 0.028783135649357593, 0.04600916080357087, 0.10267274304022712, 0.05535520365341537, 0.06675308660393761, 0.0832708845395715, 0.029403523226538976, 0.08496470494015564, 0.04405031994646115, 0.049435477553596424, 0.019566462067286336, 0.02884004449081277, 0.015956805155221975, 0.08103408400089511, 0.0348648606168647, 0.03594561532560376, 0.03532060249257953, 0.07735153765327508, 0.013298555709151252, 0.010695718360253641, 0.09114143438637258, 0.030380568782528563, 0.027293108043170748, 0.02836298238816521, 0.057766040216290185, 0.01816075392848542, 0.05809795930080357, 0.05143231637175045, 0.04511880192665323, 0.0703550175192856, 0.023686360349998842, 0.01474865289750479, 0.006909386251091718, 0.021761547203265855, 0.013403908120498303, 0.033514442958778916, 0.03182711706857287, 0.06755850548225065, 0.01596911427294535, 0.036077014726376345, 0.04530476977027232, 0.032723778933887525, 0.06793011175168139, 0.046235126097716635, 0.08391419921310679, 0.032743781489590486, 0.022125042516798265, 0.02280715188281911, 0.01050468667545506, 0.042659992937959974, 0.01677361576096906, 0.08810579566465271, 0.024574246678140857, 0.0444958996658604, 0.04464016168288166, 0.06471155421628107, 0.007779452895310017, 0.031453338939876806, 0.10804310365910492, 0.06073614394652748, 0.05852030740389901, 0.028868705755279913, 0.05103853568735142, 0.04716392726667466, 0.040184169136468446, 0.014904308557179908, 0.016216129748030536, 0.012972200338187958, 0.01648872872934707, 0.03908889706156427, 0.0222554306815108, 0.07132095480037313, 0.018738493390922106, 0.0033929473964587576, 0.0315464569270731, 0.026264219402125286, 0.055278667639340126, 0.017262444974133567, 0.046698923387955275, 0.03910800712483545, 0.06591124024482505, 0.05277446028025401, 0.005221454672620542, 0.025801789578831485, 0.027815905594897848, 0.06423542674090113, 0.061547002049102906, 0.09283017562401873, 0.031047088259290305, 0.07082367946784343, 0.04300441840783723, 0.011143186486386245, 0.0047272954027228545, 0.03019856735913744, 0.05816789929785075, 0.02160675530772536, 0.02832277234823954, 0.027885081419240565, 0.030413725067891424, 0.024769694859822913, 0.05270830475755277, 0.03467369103623975, 0.01670636856297572, 0.027093408073508934, 0.06307500271847652, 0.06956992295360373, 0.022399422652538747, 0.024842986491538828, 0.04057392402882538, 0.07439912672364905, 0.03120465339311669, 0.026571106563712803, 0.007846054185422198, 0.05178852044346352, 0.059068784222847996, 0.01453948408109887, 0.077820360480297, 0.013847088069474746, 0.025987301600135626, 0.014739795005880298, 0.05160424182371748, 0.0796425542343528, 0.046655214241435455, 0.05391802653790482, 0.09333781612616393, 0.026109563487191356, 0.025974992482412248, 0.012781776735679278, 0.1888542177696382, 0.20782626264037626, 0.22408266371536642, 0.13380712318804958, 0.19534305909708624, 0.10776115265945274, 0.11984923869491586, 0.16983518106562479, 0.16964192772584577, 0.23253642863804297, 0.13428951343221052, 0.26715045674673976, 0.17694196423455594, 0.1077400622588973, 0.17623336354811348, 0.12762770477321841, 0.145489243910678, 0.19863493890771944, 0.1257742622927312, 0.15853006753229326, 0.11895476975628447, 0.13692908469707737, 0.08517511864943851, 0.14324531109342653, 0.15590276899597338, 0.16159702392835773, 0.09148471072436341, 0.12939733723478933, 0.10329688253301768, 0.19636358014277874, 0.2315902794080396, 0.09359289276143236, 0.1124390617253319, 0.1519358431499812, 0.0867473379138016, 0.2048574727509291, 0.144471358207445, 0.11440845161315896, 0.0790827278228056, 0.09144208559225644, 0.1564922583319487, 0.13733814500512617, 0.15838988876390844, 0.10534794505445227, 0.16037819336258596, 0.09365332177689961, 0.1300674956291914, 0.10259998000917897, 0.14091700135219482, 0.2210440985377758, 0.2160741031290062, 0.1689240880190365, 0.15057330981137293, 0.1749899568817308, 0.13596989665060275, 0.23164333865767528, 0.08981288470808538, 0.08792481505342069, 0.16137544065713882, 0.20432430619914688, 0.09189023170620204, 0.21321225911378863, 0.19312046948940526, 0.1250675155390655, 0.23437608153589312, 0.16376407216152838, 0.15957124230842437, 0.14254525994821904, 0.208843351612168, 0.1188005026309721, 0.07293986712372111, 0.17851871107855152, 0.10744595344388679, 0.053988272970121716, 0.193450270340808, 0.11457023406100851, 0.18467962080913206, 0.1508141831765252, 0.1519406388603872, 0.14849722685833133, 0.09537594708343668, 0.15195945397980753, 0.10593534297039432, 0.1331235429332141, 0.16243962871451534, 0.17592374145263628, 0.15419267688787755, 0.2005914968228148, 0.21129163072234203, 0.14855364157307535, 0.23501686811927827, 0.177196872330481, 0.19156776248447357, 0.1155300273169433, 0.08330436258186256, 0.09943962217338624, 0.34615627700282686, 0.21292610995231137, 0.09120516524079347, 0.14741652194530735, 0.09385286469853694, 0.09223790538887824, 0.12891741379374458, 0.13457616821171778, 0.10230034003935515, 0.11297500151540003, 0.24095337537507858, 0.18224989634848413, 0.12357651691643462, 0.16892586534302081, 0.13987302269426086, 0.1285931134536382, 0.1236701864869364, 0.183373823942196, 0.0915296111376055, 0.15091774294212942, 0.2016890097048975, 0.06564495574322439, 0.09322640395933583, 0.12139173374781687, 0.08005093272414901, 0.10606072092008208, 0.2253723420923756, 0.14484818153564008, 0.09150630674294888, 0.1407062199207083, 0.14834310528972458, 0.14193315569671894, 0.19462365657091144, 0.21477195284058972, 0.06449312722731022, 0.16714979774288594, 0.12561871580058528, 0.1633239086837538, 0.20429960752446807, 0.15318747760067064, 0.13813334427052928, 0.15389022537537161, 0.17745939534037344, 0.12662719394410812, 0.10986830813870316, 0.1291339715281802, 0.19064851826237095, 0.2177715854298684, 0.21167715680935692, 0.15094343753110978, 0.09013324735626098, 0.14094119440884362, 0.14160358467169348, 0.17191530896290658, 0.15170482167553517, 0.10662263875166256, 0.244873202135486, 0.12333948931266224, 0.1268658533151592, 0.10561496500046023, 0.08434638771558962, 0.19262556136856157, 0.11529490727210238, 0.18380186790900846, 0.2068955730646849, 0.10825557814490412, 0.1187788989515074, 0.07777534515386628, 0.2450380182915157, 0.1465800305407855, 0.1140975654726067, 0.1631194857820388, 0.15601218167331912, 0.2204076020467666, 0.13750018792286997, 0.18277255217394522, 0.21629924104819376, 0.1299601820327582, 0.1059268010900386, 0.12606568980000674], [0.03723217189432152, 0.08379369358261747, 0.022227428252658537, 0.07176920050574888, 0.014213574956351472, 0.048342511403344335, 0.1061660503487914, 0.018100545163296403, 0.03397937788958511, 0.06338983421183883, 0.014065357052811213, 0.11689824502794974, 0.0869694957509637, 0.008629763089571028, 0.025500584874422322, 0.05138471932901491, 0.01064720775766839, 0.04063402745692481, 0.07474798018172865, 0.035281600956354416, 0.0979938380600464, 0.06132996934015424, 0.026720304102186235, 0.019116948486395904, 0.06955430242082766, 0.04525181011206681, 0.05554670265184776, 0.006394962519181953, 0.08045579487037274, 0.06460930446102735, 0.038537581886855826, 0.0374229354483466, 0.02749657716542002, 0.006394610597541737, 0.05968105701369144, 0.025451967019527674, 0.06215344108040295, 0.034092525245561715, 0.0741815577531534, 0.03799685404726094, 0.05911724311449836, 0.03629932961156292, 0.03602241180957325, 0.05100149150577284, 0.04832684873573242, 0.017621539112540986, 0.010635886893367336, 0.025586819561618953, 0.010481370789479586, 0.043118845130647385, 0.06698378632145544, 0.03819880248498052, 0.042941208493204854, 0.056263956301394975, 0.04667035213881924, 0.09124795891224377, 0.022224078533209624, 0.01553962814561542, 0.022692600670721264, 0.032668153289705515, 0.013998740919745498, 0.06973026515615564, 0.026575651380323598, 0.07999289390300551, 0.036807759184270136, 0.05973996917506861, 0.006767714568864435, 0.06347232655952535, 0.031062275952389164, 0.062340745747449904, 0.09193270362072414, 0.037621045785565535, 0.03823977669761066, 0.09436555372010316, 0.03795169699456423, 0.010005008699672838, 0.04678596629791203, 0.04556881346469445, 0.024551888402070732, 0.05235150696769838, 0.07159924389974726, 0.06903181513470989, 0.03963951509626162, 0.06549372232609219, 0.08396738869768959, 0.05082691155914819, 0.03366297974641766, 0.017741918338522795, 0.05958464484842074, 0.02066146026575758, 0.10530440827771541, 0.044084364893816175, 0.016037956849041007, 0.06246919187927439, 0.0494000191740211, 0.016671724151819944, 0.019212661596435695, 0.04196500563393197, 0.024571979057884986, 0.10670071077202598, 0.021887160724990314, 0.025945515334305745, 0.04652476478968898, 0.02664951949320253, 0.09950601901378363, 0.02568196576659478, 0.0345190140538879, 0.019996436575667995, 0.0224213921389873, 0.06959051539700839, 0.05712637212127448, 0.008374553346525758, 0.04039965434781006, 0.03270397556104487, 0.038823731048333074, 0.049828576419742844, 0.05723607591203144, 0.05434674849253028, 0.047007043951100884, 0.027443707522545612, 0.03020113183846397, 0.07242206063482069, 0.05019661271944643, 0.03436606843024492, 0.04411474411045352, 0.062461963839708805, 0.02444667005611043, 0.06799946569146649, 0.014013753370231679, 0.06489982798455224, 0.03179129479723352, 0.025152206390855775, 0.027783695428121476, 0.017477353704312158, 0.06947309710085392, 0.010824737142801527, 0.0060149326342188066, 0.056860953299028266, 0.03204361543119435, 0.01615222269338706, 0.05912223034688543, 0.012779618282952617, 0.09143232563210112, 0.024576502807077863, 0.04614131480094887, 0.052840776681419344, 0.057618529986469984, 0.032557043727607496, 0.10452530451960142, 0.01551271930727507, 0.038247851264332576, 0.02971804828473157, 0.013822035079130964, 0.012491851718345237, 0.02085976212495758, 0.050897579339723435, 0.0719871755028444, 0.01652800988766455, 0.07386177733180023, 0.049685103473283594, 0.03681587971626751, 0.03231168874809819, 0.04542745492090622, 0.08082933934225191, 0.05580817995172355, 0.010896604808588183, 0.04025171510875225, 0.02785734329072218, 0.02952606090524745, 0.08395598164849705, 0.05427638331668512, 0.05879296192659005, 0.059018716546556646, 0.11676414899768368, 0.044220468074443846, 0.06418586085220018, 0.05149675202706168, 0.039486565642179026, 0.035289146922408574, 0.07330640189109311, 0.0315409085352815, 0.052429613462018396, 0.07415614661670501, 0.022506874144798326, 0.028496141875943834, 0.025905630881747892, 0.007061200458631521, 0.04946203016105199, 0.04088893938328951, 0.0351930603445057, 0.054468407085345644, 0.03151865176586134, 0.017054664692090406, 0.02338707852627962, 0.027185135611122655, 0.030687944325167808, 0.03554930272061498, 0.08081116773668798, 0.018807265103884765, 0.03332339212178223, 0.09423708077520133, 0.022046794296212254, 0.019694502172510953, 0.023181690353780024, 0.022263114543391332, 0.08919770844400891, 0.03903720910931307, 0.05964679756171762, 0.0700345476188006, 0.024558449945142193, 0.02792969454951104, 0.021070645063094074, 0.058887248197870876, 0.03212961454635426, 0.07165741295583787, 0.013759747342837435, 0.030280500462639238, 0.04279718779387974, 0.04287199244924611, 0.03179812064063886, 0.05020829939073132, 0.009267323485185063, 0.025527175786274097, 0.049563448710907856, 0.012135798948997212, 0.024105421935899124, 0.04547544649892277, 0.061092298222525473, 0.012842697005027966, 0.044457411408544555, 0.07952564155622836, 0.051127309956017046, 0.0253984596084563, 0.023743866740034956, 0.04842706069710755, 0.07398012259434308, 0.049132658318886836, 0.04340786712184068, 0.05171471936327796, 0.019065825523988857, 0.027453929050675327, 0.02196385953274946, 0.03386301296432653, 0.07855562868738368, 0.03638575965118024, 0.04060619548263569, 0.01568366512430892, 0.01462340422515427, 0.014670270611532034, 0.09312509649222897, 0.0813230523659337, 0.05587012582128087, 0.009068163607509868, 0.030808386753403375, 0.10996289701471407, 0.021489806240424517, 0.04271984355704438, 0.005060883122496307, 0.06742619443684816, 0.04139700889467232, 0.09998221926751638, 0.046197373284808094, 0.05694144232679279, 0.030205488963533315, 0.02277469848312678, 0.04373222108810179, 0.10546297315628299, 0.026222582523440643, 0.046425552573055036, 0.0728641776368022, 0.044382445874714085, 0.02408025594758651, 0.02350335726664672, 0.05558994448473377, 0.02878918008308017, 0.026848522322853247, 0.029612603942833604, 0.011273748936101554, 0.0033154106800324257, 0.01315516607475377, 0.1090162651493184, 0.02420163108786989, 0.020611850327000986, 0.07129309218256705, 0.04066586990149752, 0.04213311596803608, 0.021852644633561857, 0.04876355715696851, 0.09833967313170434, 0.07400405518109761, 0.06120506253453994, 0.006909501643085312, 0.08925161039036128, 0.007963205308413074, 0.038482741482796214, 0.05100793047477642, 0.046377258390308394, 0.014278108287873048, 0.011356661674536524, 0.07088354923912595, 0.04966467190834303, 0.06133633553080502, 0.014826691401521526, 0.024637113768427123, 0.07144431027794076, 0.0794995179580104, 0.03203730478191809, 0.017382015977355263, 0.013063475883926355, 0.011597384694933651, 0.07883961748091445, 0.005176234896475029, 0.02352056360142606, 0.06075361841208032, 0.058595429985753955, 0.0681669861378689, 0.03895518024482074, 0.04820337068409689, 0.09749122309468447, 0.026812071859415983, 0.03748013923365263, 0.047878108903645515, 0.019866827905418414, 0.028651832009575544, 0.037387239581514756, 0.028191198662464178, 0.07992712525470604, 0.03329171438611323, 0.02882452737990647, 0.034915947190095345, 0.02925852959555003, 0.07285067150669713, 0.02869396493019116, 0.05614768713712693, 0.011095565503403064, 0.0149035913073608, 0.041144479501752124, 0.0848213392460058, 0.032143114930799896, 0.0551457207409605, 0.05414630924802154, 0.02606093414097784, 0.026269384749954747, 0.06256832365667628, 0.04529676798190321, 0.06065577749283083, 0.07401017622361261, 0.020879096268946608, 0.030204339831646894, 0.028434464137160012, 0.04181124795708926, 0.015589596230476616, 0.12857472734345546, 0.15645878028965768, 0.07066960386451214, 0.2853215413708841, 0.11926778562126622, 0.150823989101956, 0.20079383596537576, 0.11591353859271734, 0.09569134548186295, 0.16465164630884127, 0.14707357502512394, 0.18708738918987014, 0.15522164022249563, 0.12981811868807963, 0.06295838881464255, 0.12532017899737244, 0.07589214015752077, 0.17268668289386457, 0.17291650927114874, 0.14241717004727933, 0.261399679847302, 0.1760183686330434, 0.07522361353039742, 0.0726902526953528, 0.17261673906637778, 0.07029021414177072, 0.11606287977267658, 0.2028535859238717, 0.11082254725718692, 0.20091150707054525, 0.08129510547845595, 0.12585005137108027, 0.1528976052518814, 0.09221076289372099, 0.143347583831318, 0.12234366694164854, 0.09903310527724606, 0.11466957268214996, 0.13899516254182787, 0.10350205620089847, 0.10886445716624299, 0.15617961785004986, 0.1072201107238089, 0.1411857603177909, 0.18836344652358564, 0.21002694213342285, 0.11538678419686134, 0.11087575206352819, 0.1010308940444262, 0.09562879440284545, 0.18220863485288236, 0.12338506388327769, 0.1493362463530033, 0.1752904165656336, 0.15066994414214166, 0.1902536765461968, 0.09317220323869298, 0.09292965214098654, 0.1682625864181788, 0.2032512621653657, 0.2094461861997843, 0.22243586579157462, 0.18998096456691144, 0.17375761252497474, 0.10161641504495375, 0.15156197692117385, 0.10371641526299138, 0.2122806502325881, 0.1588840461185863, 0.23541370166405556, 0.1939765574230302, 0.10451098633629662, 0.08714021078401035, 0.19286934586782611, 0.13489614781593123, 0.11981803593375992, 0.13479707732556329, 0.16068859686774595, 0.18037429860522672, 0.13798576509279592, 0.22401066677224254, 0.15050174187748663, 0.3642294862337651, 0.16314890355833117, 0.2322421129792929, 0.09935211961067493, 0.1779016425773021, 0.10150347070227708, 0.1632576727218205, 0.10098689761493476, 0.15866981729144053, 0.21830015545410497, 0.11498894707690324, 0.17795395106077197, 0.1192691415968922, 0.07328690495342016, 0.1156608368300142, 0.11046213353232992, 0.15691041976453798, 0.17482700998023634, 0.12355702763964092, 0.13475285873057383, 0.1860198303456268, 0.10506154308396001, 0.2817092223032829, 0.09003860485409537, 0.122538544387827, 0.13604290482978668, 0.14997036797144722, 0.10003776830290595, 0.1334339157948571, 0.10267370065013248, 0.2096101596590973, 0.13324879830883396, 0.15839249346285098, 0.08437215891336242, 0.19152283908859377, 0.14102166428441001, 0.14840586321248164, 0.0959812025088937, 0.16314179426239384, 0.24723203281962106, 0.1594824220744833, 0.12779342491299878, 0.11987137097504832, 0.274481795608036, 0.09447770133133858, 0.1136204612351233, 0.11129405905282307, 0.1424954642331408, 0.1417978798910495, 0.09612574797844696, 0.09391392956698134, 0.07308983649577826, 0.13401986580462227, 0.09522404716981035, 0.16570101822576216, 0.1599056703308898, 0.17200751530547298, 0.17228479316878706, 0.11745355152074369, 0.19689899899305838, 0.16309651846606887, 0.08798151322069668, 0.15899997054328843, 0.22969707696428224, 0.110006625313432, 0.12712833802065543, 0.20765654352163115, 0.11826206539427081, 0.11648915407638397, 0.14415500985999263, 0.12374599854792319, 0.07893765375258462, 0.12015382759273054, 0.26281559419247413, 0.21923570202723627, 0.1477678345456239, 0.20111367767376287, 0.1794033128047182, 0.13583865046741503, 0.18673393154336562, 0.18520884966898352, 0.16710953216158575, 0.16954230565217235, 0.12774860876942837, 0.09159325006147546, 0.08930582643276261, 0.26941997690066216, 0.19991940788684354, 0.14840423910608216, 0.13442273612224287, 0.16099593602120876, 0.1655452265854805, 0.13149378280485832, 0.1264457153757253], [0.03421372418562251, 0.027326155161004395, 0.025790690880028472, 0.014835677612873336, 0.002088225207238969, 0.046374316612679156, 0.06171581718409735, 0.04035386527257581, 0.01690620068280447, 0.05392138583345279, 0.06655745839159335, 0.06636055847329479, 0.023947054324972055, 0.06019104940576419, 0.013389572700215204, 0.0346945324582198, 0.03590707344213321, 0.07512068961777034, 0.037625994713556384, 0.06301073177206902, 0.07237924398073266, 0.0014683037466790168, 0.03561949552667718, 0.03302031624761801, 0.04329404943893033, 0.03850791896242769, 0.03317305885796105, 0.024030803056854396, 0.07698039869747816, 0.03122131580546979, 0.02211041789832375, 0.04433247012897365, 0.03572112092027261, 0.03020328071509158, 0.00959559120312934, 0.027787629289612658, 0.04792242709006514, 0.02396706454155426, 0.06712612545778675, 0.04622361562665432, 0.017095081575755632, 0.08479087192925715, 0.0466465421261326, 0.04231347987848905, 0.03949738663410948, 0.025248291053538843, 0.07941499547732454, 0.026468952569449623, 0.022862095708748507, 0.10984999863731285, 0.06618938378749356, 0.06334533216431737, 0.12061946349398744, 0.05700693901387915, 0.01584500707160201, 0.07946489078383293, 0.04344171671677501, 0.02718624260817324, 0.04353959210998109, 0.013479776680469515, 0.04567181015567434, 0.03959102939153391, 0.030593269264265418, 0.03333472256218234, 0.03770164206563946, 0.03591879841781432, 0.044185890695981445, 0.062375533800091476, 0.06558945267311027, 0.05192114175447533, 0.06379485723652667, 0.017922793612665227, 0.06944481313468949, 0.05144910518861106, 0.055632489177608685, 0.03704265706361302, 0.032610505173403415, 0.0375296744788366, 0.036898693820882233, 0.04030411935321266, 0.04451461902429019, 0.04206566958718243, 0.002183333107818579, 0.019952235217656822, 0.06211969873777801, 0.05927879573597063, 0.034055534690137834, 0.04624262226805572, 0.039706360098094716, 0.016406527495071772, 0.033703260649476326, 0.024724149017504627, 0.03095625129888856, 0.017783476693195202, 0.01100268308824349, 0.029597674804409186, 0.060988163890978025, 0.020802778589929787, 0.050961053554689696, 0.0639748381030175, 0.08904159504679904, 0.1120407036655853, 0.04241628887792749, 0.033841914902891845, 0.04516054605764728, 0.06916827837666197, 0.05037056830441279, 0.061121830912006486, 0.06732533896161665, 0.08580393127856717, 0.07201862341213612, 0.008387962758030382, 0.06547338269170254, 0.07808966336831932, 0.04252990737797753, 0.022586315547326402, 0.012937548266152942, 0.08905872477278595, 0.025199924092439395, 0.033976704242729375, 0.058077470279268684, 0.04626994479387518, 0.025029044350489013, 0.043087784095757434, 0.0466869187901818, 0.057675875498042, 0.030665609031735413, 0.03166638990683902, 0.034139088069599484, 0.009545599178020513, 0.027926126495003704, 0.022363177117621227, 0.02235070137577432, 0.08456268498013098, 0.06379150560185795, 0.011272363274568513, 0.02134336278803887, 0.043456069374036406, 0.029445539318746137, 0.061209900379781766, 0.06558669475658287, 0.013252861437297637, 0.026346566193106196, 0.022916848012696833, 0.06264656038594342, 0.0552371418434045, 0.03420345094655791, 0.04690829521766113, 0.0424477176350211, 0.0853913163225497, 0.07562634595219167, 0.002150173949626004, 0.0477705616503954, 0.07652633838475713, 0.039744055454408934, 0.0302909096823104, 0.05497120208136978, 0.006053411315435605, 0.07423097042426949, 0.040479438574684244, 0.025806874487428896, 0.03834499504357096, 0.04690772448215754, 0.05925755594826995, 0.013618374434900622, 0.12747442590132838, 0.01766116309520458, 0.02909199165691051, 0.03897527856151423, 0.055471522613398494, 0.026686289798348185, 0.06147862487142125, 0.1185194785977083, 0.05838886203785097, 0.050852567843732335, 0.028733016262131355, 0.01951968090819015, 0.06878040039971953, 0.021926964738316113, 0.04903207480486843, 0.017536970666579662, 0.027642783130549138, 0.014790098254208364, 0.01994477160605452, 0.04908615295144339, 0.06626138073061744, 0.051962989307339155, 0.055381461317020084, 0.0032817212453547626, 0.07973319775755368, 0.04868436281779601, 0.0863126672864441, 0.04591657524748195, 0.03425683195312177, 0.01746570150698385, 0.031861173507246765, 0.02963785420081789, 0.04164686081029716, 0.028273152833383892, 0.02721065591510025, 0.026332655951621074, 0.08838016239385452, 0.021780088446253253, 0.04558643731739252, 0.1409847388464597, 0.059257850892120795, 0.015485259843239141, 0.08416031261966114, 0.04821481603768565, 0.059597595564780705, 0.10647410196402382, 0.01943678827956319, 0.04053520594513224, 0.06186571760824131, 0.10244677774608137, 0.02729661864108376, 0.05083724225480711, 0.02963277886831953, 0.048989307946495475, 0.09637933840314228, 0.049894685977168625, 0.03250239101508933, 0.03637869249007875, 0.04252308153457219, 0.047816530756291845, 0.04529480679681705, 0.05831479665733153, 0.030497730439228397, 0.06809253771338733, 0.07415880494180226, 0.012357872516487636, 0.011405825367077224, 0.05705368186857912, 0.08363521297372158, 0.06429722322331322, 0.02423921344621528, 0.051569584006023024, 0.04043976671152538, 0.03807329813078527, 0.028285184244234717, 0.0452918803409463, 0.01765321684820998, 0.04784227131054767, 0.06338994146414823, 0.0754779470603793, 0.03688519152121679, 0.014652729113285821, 0.042986036128094124, 0.028347643392701304, 0.07010302821835203, 0.06757545134713573, 0.029425259056170622, 0.060034648725582715, 0.024158657385757374, 0.007330400403589011, 0.02985246607192582, 0.013639820108730948, 0.027217577519496123, 0.047896092817668, 0.020413705515825463, 0.05988705039565122, 0.024124463051257115, 0.028882909025396072, 0.06508915895415891, 0.04145277626512032, 0.04428393845897048, 0.043628416174361785, 0.07414355979210908, 0.08222640792448675, 0.021988018115441647, 0.033087302975717096, 0.020987886499853867, 0.0997796426376989, 0.12446440515979645, 0.09177943240971335, 0.029575977279173753, 0.14789474467116018, 0.009984615439128493, 0.06492757568916967, 0.04598251626556439, 0.026891697123045885, 0.040014116769476284, 0.014170545712864448, 0.01132527792510847, 0.07250177208334208, 0.02224879252964691, 0.01725789249664353, 0.016967995249996745, 0.0796901053118129, 0.0655483290733349, 0.0323034035071971, 0.010933942976407708, 0.03403175149052855, 0.04183793079949195, 0.0582651081945627, 0.06534117889860946, 0.025534660465294318, 0.07698537060810674, 0.011805677298276175, 0.05682267954633121, 0.0367567262371942, 0.018142838962376118, 0.0337921881357268, 0.03924152475871867, 0.025382440709959597, 0.0047576248236451185, 0.027211019806864283, 0.021488823732661626, 0.03544283182089848, 0.03215861671994771, 0.00620811271684004, 0.025500548485245918, 0.021218030803626584, 0.01896100554374918, 0.05031248351799385, 0.05730439946355839, 0.05020107518160536, 0.015087695642104073, 0.08271473535006085, 0.05832844834414221, 0.04337648049958291, 0.12073127402653619, 0.05395269201647851, 0.028484074075916604, 0.11662436859501947, 0.03880788451961933, 0.030586058461678126, 0.03994605368784359, 0.042207066435366876, 0.10537963811187975, 0.06935944029640767, 0.10753192383074954, 0.05087700604851689, 0.01906056824560848, 0.04089439392931039, 0.03296061501567883, 0.020769605067588633, 0.05147126428182087, 0.05572535818622959, 0.052492241149828325, 0.01669454782630407, 0.03792512523491056, 0.011610664829101053, 0.0365314006264652, 0.03284339207194505, 0.0772827812620709, 0.05066712860078101, 0.040297446727392175, 0.09808310262498357, 0.033560331625443314, 0.04795236963658564, 0.04716936649093705, 0.11065633682113503, 0.24555917258464524, 0.10430294749957901, 0.0894867840613569, 0.10588181640712485, 0.13561334400888414, 0.16011190120010607, 0.09807348822153385, 0.113057287019347, 0.14043956003602476, 0.14893696132686832, 0.11302804544327721, 0.11482588526222015, 0.19571546975883747, 0.09719634053087044, 0.12723461739839087, 0.113303768148105, 0.17884828210357698, 0.2255753094270345, 0.2232051559633786, 0.16949201964082258, 0.15902394909531842, 0.06947617677430953, 0.13195228642754017, 0.23234208745341148, 0.1716922241593561, 0.15201308013450715, 0.1118184922022685, 0.30418725323773205, 0.11590590835699152, 0.05863939960216803, 0.17144609543104328, 0.17151418532575333, 0.2739599671575331, 0.15944382656485806, 0.13735999383272665, 0.13925368657275555, 0.09319334726540313, 0.17949803191567623, 0.1456667158392168, 0.07104129440361454, 0.14012927910493267, 0.13456692919135094, 0.21361375047314554, 0.10134230112476696, 0.11609628886705446, 0.2006012721047286, 0.1004442775381669, 0.09392726715774306, 0.23419697017919636, 0.16723774463659333, 0.18930982557996628, 0.19590041870551725, 0.22585603468600782, 0.11097836188010632, 0.13526446756816682, 0.15359693627444007, 0.16645503260435598, 0.11961352876237324, 0.15181892281097753, 0.09347106179883403, 0.08176102483224484, 0.16592194266136617, 0.1646755482520788, 0.19015086754675836, 0.13526034601513418, 0.18882403390542155, 0.10685054224825676, 0.16348602821029004, 0.13880360991724078, 0.08886540248509377, 0.10998589497420097, 0.163023985261398, 0.13661405402085475, 0.1374959897610449, 0.15975154876228304, 0.09931423656281926, 0.12575553144298254, 0.08358799897494816, 0.12511504363388787, 0.12015286998282518, 0.10545976324788026, 0.12296370020316494, 0.12057336032270424, 0.2325098760305874, 0.19255658281185936, 0.17053057439625266, 0.15625504686707453, 0.2341463470891599, 0.21622332173489758, 0.13890726161339592, 0.2715405695621045, 0.11126864791637468, 0.11528986641356062, 0.09173345947337729, 0.046097100036399025, 0.15686341260950412, 0.21577601831766868, 0.1566830755121285, 0.12790843003219174, 0.28111991682840937, 0.2234770712112227, 0.13079276638886622, 0.17945672445479902, 0.10084468871355058, 0.21915696351037872, 0.12077839609475867, 0.11812700409322016, 0.18002485525944542, 0.24175697096413185, 0.16302606902055203, 0.08643414584859725, 0.11617600797645508, 0.14824807974359683, 0.16057968980843024, 0.11899622277386727, 0.13092975823148606, 0.17394649916358534, 0.16716320428156084, 0.10015258956099711, 0.16454632454101117, 0.2060178048428028, 0.13181515668909397, 0.13013943128528135, 0.0679866337187348, 0.1024672399545389, 0.14878961197551221, 0.12498439499928106, 0.10720819039570709, 0.11173185531891162, 0.08078617794859795, 0.16088523631615026, 0.1027686495874678, 0.23410911521603986, 0.1639041743211208, 0.0804359914975301, 0.12636932108791607, 0.13767929927956674, 0.14394554609973587, 0.22306742867635143, 0.2830397638101732, 0.17419414474598824, 0.1293183688915545, 0.21658830134378326, 0.12456277084927406, 0.15344898937450302, 0.12669215053920785, 0.10371148931763827, 0.11468851037563817, 0.23569300199948975, 0.20582260563969615, 0.08356351480488816, 0.1713193538448503, 0.14879443832943517, 0.24465125114206346, 0.18790615331982413, 0.19551700702117336, 0.09343648058993202, 0.10651501105918039, 0.274853378894829, 0.08939328303019847, 0.10861678094032312, 0.1616565489600743, 0.17074469597108904, 0.18035542219877246, 0.17709656077767574, 0.11093602020053134, 0.09387374825535283, 0.10408021509647371, 0.14728098566974365, 0.14517165450078828, 0.09966700473019194, 0.17829378766398277, 0.10083512027537632, 0.1749218056999868, 0.10620473012808831], [0.05649633375146697, 0.019688390706095005, 0.08686121688374589, 0.02762037314354412, 0.002382062539841319, 0.03538473171272105, 0.07176104166935529, 0.022125917772251754, 0.09409382999424012, 0.012673903895061345, 0.052703547351542986, 0.0299044719506656, 0.020350765647186388, 0.046682475480220975, 0.038556477445508205, 0.01827583565647083, 0.07154051559947192, 0.019687103678382212, 0.044863935965563984, 0.022191764944563472, 0.028856886933828076, 0.01710433400266113, 0.03678702501459949, 0.004329733595612549, 0.01789187621926108, 0.04531910327533561, 0.03160694531435448, 0.03901340675750568, 0.06071017356589437, 0.0510622997347626, 0.038148187055823304, 0.026810708222910765, 0.022035076981410388, 0.050264101235135916, 0.0841145771705816, 0.03849198433360265, 0.026602198242119728, 0.0233951645843204, 0.045144879559595744, 0.04276537216238437, 0.06990966762626363, 0.08469531778246166, 0.036461012467982314, 0.019200909807677233, 0.04022740330847521, 0.02897467103696639, 0.016699284164895935, 0.03551597789590878, 0.06378607403847479, 0.018035870105508837, 0.0505121375223802, 0.025190248401955734, 0.0541721991894226, 0.06221347556058919, 0.05744286985587209, 0.02950615602575483, 0.0664841054728435, 0.06528924579822248, 0.05067742482248334, 0.05856014014552197, 0.0311410661801816, 0.0059421988102727604, 0.026234495190663204, 0.004173194540799746, 0.053945866173073176, 0.03822861479655389, 0.06773898047545264, 0.015833082913060584, 0.03276787878524873, 0.014082648614872129, 0.03273808179543384, 0.027078477019864707, 0.06599164883335752, 0.08153350437961279, 0.04211052020470943, 0.023121811006398454, 0.07182363871364825, 0.07675912186142898, 0.034524250264850356, 0.01883169947822969, 0.02425656533770023, 0.01759194130558641, 0.1388679919463973, 0.058890695593530135, 0.03312836528845853, 0.035343998817787055, 0.05502685836906876, 0.028597838132672256, 0.03456019127981798, 0.04155871473372944, 0.022668897910344026, 0.016338349500250433, 0.043824354652315385, 0.049785840204886855, 0.07232364131918839, 0.027173397228902867, 0.0532507945993735, 0.01403215192934318, 0.025384041833721345, 0.05293124783483725, 0.030110767937355468, 0.05934966269940619, 0.03338373303713818, 0.03646457094639059, 0.03199260929719575, 0.021736978763534177, 0.08233652540272282, 0.05480487290168962, 0.018965671019208048, 0.04269898681330585, 0.026273582911779805, 0.02011745165462696, 0.03163385606791464, 0.03138301589886748, 0.011521252792238468, 0.009859129279521445, 0.021989048503699805, 0.03371588960890809, 0.047673471497311715, 0.024880017266578736, 0.06984638876371807, 0.07372709907471173, 0.0597813111099024, 0.09145477200828253, 0.033320105604587064, 0.002243523199614438, 0.008484436210335023, 0.021586281607948968, 0.09912459149716363, 0.025892163056039044, 0.06712284660147083, 0.016268677633976745, 0.08104112434891925, 0.050497206468735976, 0.03464736059428223, 0.017905434060301033, 0.027817502888219974, 0.04252402765315868, 0.06450232028240158, 0.04441408913642649, 0.0555115238943648, 0.06020258668990386, 0.05754109764952333, 0.02062664348481884, 0.011961182613196153, 0.013227520206372344, 0.05110262660309673, 0.03293534177505682, 0.06693174596875906, 0.07021425652407831, 0.053839510186545314, 0.024803952396576925, 0.03080392812168406, 0.013976693866894612, 0.007254729590063254, 0.05441461622174229, 0.1151966718175719, 0.04394856048747898, 0.05148194354748534, 0.028870050239587025, 0.03243815071219879, 0.050025932160356355, 0.029853881419365926, 0.04758875749464478, 0.010525858472852458, 0.027061720761740883, 0.041752079156257456, 0.02867419028564567, 0.07167348548048927, 0.05886925662296915, 0.0296018289161786, 0.07638787565332267, 0.06099731098079394, 0.03151049484468756, 0.011676315691382175, 0.05211269820950205, 0.02525688656004927, 0.012282342950422919, 0.04922549668399077, 0.00551355202802487, 0.014349990317808285, 0.04181446935681086, 0.05732519492026299, 0.018845803156915693, 0.035034637192204114, 0.025861224595216975, 0.040070960493457895, 0.009847521132248785, 0.037458416810559655, 0.05450058277816542, 0.03152672441736345, 0.04908995274754782, 0.05703528043663791, 0.05726415303445632, 0.022241214004855965, 0.06518586989372008, 0.04852191387345234, 0.03353565593340224, 0.10125096812243424, 0.08642373471370629, 0.02591548468767395, 0.038917680240927205, 0.010706534564134576, 0.052962151821702726, 0.015338317476092808, 0.07602445120292325, 0.048718277530203906, 0.05980722403394119, 0.06208972554774054, 0.03171634650038135, 0.13018931893091049, 0.13195380328163026, 0.008617293093383552, 0.004919613636429272, 0.05609854259678433, 0.06322221417400627, 0.10524424739302167, 0.06074951984168542, 0.07138388126247353, 0.05544754789180814, 0.021858024486010114, 0.04534899219570141, 0.031422076806906736, 0.03709170201252546, 0.06962729527825309, 0.009531936957500875, 0.03136787991670351, 0.051131883500925, 0.029793655417198618, 0.01572644347400074, 0.04967366961101371, 0.027638655831857074, 0.01656700567823024, 0.02964099707652725, 0.030334932924879175, 0.03355300399444757, 0.08279442381594451, 0.06377475508939355, 0.023977623148370656, 0.02714330338001732, 0.03649353673080764, 0.012599356836759517, 0.04197002350983601, 0.014681439215858138, 0.058947033699481725, 0.030352030092129306, 0.036388617159137805, 0.0370180273368474, 0.03302790817894763, 0.026810216011419415, 0.01577008941826681, 0.023437159609109647, 0.04451559195595403, 0.027157125521391153, 0.03012429130443883, 0.016062146075250163, 0.04725845868609125, 0.026493576550555807, 0.14570572503632115, 0.047306672429605845, 0.010876012365183523, 0.03721816014618643, 0.01842452566169443, 0.031977400536678975, 0.04753420054311714, 0.06899694281239664, 0.06853413377558032, 0.014352783665902192, 0.058615773450583226, 0.07660598854624456, 0.07443546993477691, 0.01856355338297304, 0.014324809007737187, 0.038717715970931516, 0.009896967319711562, 0.027766556126035513, 0.06449490455129454, 0.047413231429433635, 0.08174820818127164, 0.05576720573909341, 0.06295866460629529, 0.07722368523959192, 0.07131728523921582, 0.027111556696435137, 0.02452669943112039, 0.03316019241127276, 0.029104383129085747, 0.04169997368608752, 0.0550721992828673, 0.059646878000949664, 0.011729289713736263, 0.028539519689436403, 0.02579496756586577, 0.06560904920221337, 0.030166449122911984, 0.03016020742154891, 0.06105423131356798, 0.020462296557642763, 0.037952566504358284, 0.06274423659628918, 0.05482771764359167, 0.06304795215387018, 0.022156536391365434, 0.038123116828501225, 0.08191580523646648, 0.05315014596788153, 0.08058464319835748, 0.006397833433678194, 0.07575375403487876, 0.05362116363680652, 0.0061454524702933295, 0.04985694848601857, 0.016283239050197507, 0.08850279774877334, 0.04019326643056927, 0.018222389532433405, 0.024452612983183037, 0.02434396256332196, 0.02711057418867225, 0.038600604109946764, 0.024063116645500548, 0.006286372428744912, 0.03407588964628597, 0.028158021309683402, 0.09631944564922203, 0.0434843456793216, 0.010427060901307532, 0.015709627844062785, 0.010678010237883898, 0.045023692110853816, 0.02557389374311653, 0.040745347693202, 0.05345884109697035, 0.04444916064160005, 0.02247236188380949, 0.023747794855866703, 0.028778960470170267, 0.057302277400008136, 0.04609274099610987, 0.03627051704473073, 0.038067793789049315, 0.02704767070920958, 0.06610121472828812, 0.02365631629682837, 0.017322510097836776, 0.07402048010619418, 0.04832366947084666, 0.13745653623294446, 0.042465663244647366, 0.048009799417829326, 0.02935349768508346, 0.04027593114803876, 0.13267715882149436, 0.1486729214628858, 0.16329989948820683, 0.10693942376923178, 0.08082030716562465, 0.13183585638480802, 0.17502443083832342, 0.14057031592294095, 0.1851962858270253, 0.0747306282902437, 0.1647466871767275, 0.17770042192311059, 0.0952682274604036, 0.18126418633807093, 0.09245150602392613, 0.15191263068587552, 0.236648298319309, 0.148263861154837, 0.13060565707423996, 0.10333570786902022, 0.17899097364035346, 0.12775685953637286, 0.20342695676992018, 0.1821876440437571, 0.14524106206672807, 0.12099040326692405, 0.11196650038923948, 0.13877923299949016, 0.14638674655748954, 0.10503223255997705, 0.14724556176412493, 0.1297611677117886, 0.23254580555423615, 0.10413189538784566, 0.30428399482081014, 0.20413802425947883, 0.1346790997852241, 0.14298232843077954, 0.20059266127645972, 0.129523312733058, 0.16476888840477313, 0.2851028692337775, 0.17385162683504243, 0.08942103073481592, 0.19664678752662676, 0.11266902599844242, 0.21445280061133448, 0.14908378973843592, 0.19554271693191222, 0.11860867421473227, 0.12852105522348037, 0.12044988993194797, 0.08856164096223731, 0.16243372983749838, 0.16341444495464527, 0.10054116467795066, 0.16119248353906218, 0.12414266355335714, 0.17254213742431135, 0.18125263373217276, 0.19504969338736228, 0.30127844803275605, 0.1579748070047748, 0.15647191103667984, 0.22288247972967165, 0.2465153116011812, 0.11945677951218621, 0.14470233371661556, 0.17286295972524152, 0.08756853054247557, 0.17688531969343463, 0.14024267543948468, 0.26193008848255683, 0.16107881141285743, 0.08190234507163686, 0.12238708880519676, 0.1366748047932502, 0.15611256983491684, 0.116607032025293, 0.13812145458594446, 0.10551691340703158, 0.14116976440193194, 0.2641641847308605, 0.21609517054692393, 0.1134307855259507, 0.11321732278672919, 0.11392946279938183, 0.1381608927922864, 0.30073608842588245, 0.12728122618770407, 0.1061479936564161, 0.09344243309310368, 0.12200596006286722, 0.1498479471211472, 0.18110549888543545, 0.1906659391017691, 0.11849382997400339, 0.1383592789211581, 0.09401710628862343, 0.15127216585941855, 0.09123518056566678, 0.166691891668785, 0.20969510348814152, 0.17153597286631986, 0.08805655153287996, 0.13319910984606514, 0.17434238275933653, 0.09394490250176, 0.09857801840670648, 0.10965812425579756, 0.10908551183679413, 0.11582723112716792, 0.13551390579631253, 0.16783221354407651, 0.11701789263996387, 0.08436958485793683, 0.1565689437331692, 0.1390760307831149, 0.12847748014234728, 0.08449556801708476, 0.11794151888499338, 0.17943665295118288, 0.21150515474859746, 0.1905661638105108, 0.10746386457955646, 0.14913409107154416, 0.15408936227040906, 0.12429205069859182, 0.16441909265854668, 0.19170354390817304, 0.16110905656410804, 0.07927915276659113, 0.11531603597705403, 0.21622205002894326, 0.15075922402883732, 0.08185198245149466, 0.09460133260055896, 0.16897587556271784, 0.12308833504756614, 0.1598047152642281, 0.12692347078794433, 0.14883142505441943, 0.19992250288205765, 0.124995120230221, 0.20057375422648846, 0.11718430225887608, 0.12586662185288247, 0.09313370732049789, 0.16275686572395986, 0.16502129905406507, 0.12458543173007428, 0.15951927090364118, 0.12131317909206114, 0.1123522409808732, 0.06214413311212294, 0.13287742952665976, 0.24323582709316285, 0.12804471707392123, 0.2099969574520665, 0.12881670387521868, 0.17072283182173006, 0.14961910133640613, 0.11193840028417688, 0.12884367017015336, 0.16210526197908387, 0.09276164905919183, 0.23424146456583855, 0.1553716555598282, 0.14321506594217595, 0.16859083977197448, 0.10178603457226869, 0.17273676972235405, 0.17790554962571592, 0.17981104011977875, 0.10364191321235511, 0.16892718301425058], [0.019087618810214826, 0.017030467805002007, 0.02847453245081969, 0.05550022792792129, 0.0680832986930205, 0.04481528938237218, 0.05994255346576533, 0.015805288285557783, 0.05936336801237157, 0.042988874483853586, 0.014636554124374545, 0.04308762704773296, 0.023162279600998568, 0.03879365443642582, 0.043042584908224886, 0.029522994638330517, 0.06580953441199756, 0.0230947049004176, 0.011244696009183123, 0.02215466713683019, 0.017129168657946493, 0.04706815861526036, 0.10184692324049051, 0.019694163178604458, 0.041483140159999175, 0.11906215230063086, 0.021319342101173058, 0.04923120403902666, 0.05307047282375636, 0.04968691910166414, 0.07117712945346871, 0.007017370174458672, 0.00454344674982431, 0.08374847907332644, 0.08630573419072936, 0.03164124881638394, 0.015997464314193254, 0.0920504053694106, 0.03586084769678212, 0.035955608942575996, 0.012921478614331254, 0.040169349165573236, 0.029486333500714074, 0.02272066630182728, 0.01392938027669105, 0.03221783531649459, 0.011275551157943424, 0.08680569083099404, 0.009382317113059183, 0.030987513431858633, 0.01892254984517011, 0.012767259369514162, 0.02838520659884859, 0.028787282100247762, 0.06950698883062409, 0.008058565060397791, 0.03032395871536386, 0.032680085109126185, 0.05930257127470067, 0.01911098640712519, 0.05140606253858536, 0.0460451401229347, 0.06079233266533383, 0.02275787136186996, 0.04252016273958068, 0.02281905880438224, 0.024822560672257698, 0.018144229411958687, 0.039991390771202506, 0.025091626073023485, 0.018345005735154116, 0.021151400306412292, 0.03211445941199218, 0.029053447858220147, 0.03611939471034754, 0.10434786323457958, 0.0482733681377384, 0.027197280019942312, 0.025947842326375748, 0.021656629546815832, 0.06915127122474295, 0.07537766615109098, 0.06600209061176547, 0.04292700139264907, 0.006788620150708143, 0.059034367722849694, 0.04085040133025858, 0.04007006034014687, 0.019494591528669964, 0.07417043415649284, 0.048243632434957454, 0.0960288072125085, 0.01319399236836621, 0.013812116155731342, 0.03785061552339504, 0.07502723455188737, 0.02965504521383874, 0.0439627216227593, 0.04568905096441027, 0.04927172242934185, 0.009181612610606658, 0.047791935503482826, 0.036031509103674086, 0.017617779536052577, 0.029679152085596038, 0.0643814086253124, 0.029739100380890796, 0.014500077475883789, 0.034151437406938885, 0.09634439713291584, 0.028545807356074936, 0.019163143588230014, 0.012037140230888562, 0.05678656999202025, 0.02647606761104638, 0.05103272108000614, 0.008961296257292552, 0.016754913639517564, 0.04674748187103579, 0.03631944708045452, 0.01837091482875328, 0.04200553934600565, 0.06051984285154651, 0.10864232231171862, 0.014069891335713047, 0.027470486125938838, 0.010029903684382238, 0.021398961619143526, 0.03856093990766714, 0.05285663470145195, 0.04320943502769355, 0.05039055553835727, 0.05338325886236084, 0.05382387433201075, 0.006329180464343799, 0.03966314124784643, 0.022708158001243588, 0.12206033698373264, 0.05293241228848215, 0.07135288534505714, 0.08311546828237273, 0.029967078571057612, 0.08277480430420368, 0.018834013063761017, 0.042419851186775395, 0.03696474592171369, 0.041942149400711067, 0.015496504098747768, 0.03974044718028557, 0.03732114151540784, 0.06185838997724557, 0.020906378575150045, 0.05382203189055285, 0.02506418480357576, 0.032457214810194514, 0.13039613202694925, 0.03338804228171226, 0.045988047420377695, 0.007296551287459631, 0.06280507929923554, 0.03989769821806301, 0.03961722193766506, 0.01663309033779848, 0.05671176916709351, 0.06364330589290589, 0.038181879602733164, 0.009062115343347674, 0.023838947827537215, 0.051018908514731356, 0.031129013701912858, 0.04262105651920842, 0.022180723702354778, 0.03770699702023018, 0.026003182602805958, 0.022407750028275678, 0.052913378834003405, 0.036078271110572165, 0.04419256332180193, 0.03184535570683018, 0.05075250909994206, 0.010095188739679514, 0.016501499415044824, 0.018858437862006888, 0.07415911903785122, 0.06681710091089049, 0.07903880034122737, 0.03195518590209465, 0.064946927070137, 0.03579562297090888, 0.03100505876054447, 0.07107165446805377, 0.01586523466563273, 0.03336311378065617, 0.07050602877091977, 0.06641952426082666, 0.026397859610076395, 0.06069028209294043, 0.03470116677964407, 0.04671584627020263, 0.02672919072210789, 0.028754351810822566, 0.011507022709044959, 0.03230382868599507, 0.026999240545856378, 0.05291668450339668, 0.007444870218844905, 0.035395184982447855, 0.030191588298147245, 0.03639462711890379, 0.03019842754809126, 0.06651170762075533, 0.04009629119067423, 0.031253052912952925, 0.014346104336812372, 0.0023626240163726075, 0.06367445885834676, 0.08231420926148854, 0.04937691013178518, 0.006548249051951233, 0.021515171411597443, 0.007188705738724, 0.027692716741453738, 0.00888537024072702, 0.09895274265398903, 0.042725213833393595, 0.07740063622834222, 0.03570439339044594, 0.05619038887802632, 0.07507778869401063, 0.00731232934706514, 0.009812782875322288, 0.03434821092072995, 0.08024590976175763, 0.03326315462829606, 0.08180431646084593, 0.01586548172898831, 0.03388842027033529, 0.07297439470646844, 0.03217125717069834, 0.06148798646585596, 0.07161537005055336, 0.035853002956437494, 0.011675247956337708, 0.0685832400115267, 0.026340109987124324, 0.06886053319659925, 0.03253893340907751, 0.07797736253949904, 0.013151191993646566, 0.04975185271412615, 0.04197339046626322, 0.014546925667673351, 0.018899871727391597, 0.02579319981798049, 0.01259626854481476, 0.05349799585078032, 0.04095252468100479, 0.07376083758689704, 0.10210357801688295, 0.07915321557271866, 0.04468217011420958, 0.08670006262799425, 0.03257839076761757, 0.01220675784298369, 0.02786603072778352, 0.0672772746052473, 0.06892120736020227, 0.06704007846213157, 0.03399368075113143, 0.04386442871163449, 0.03246622783462367, 0.05823381350285584, 0.017847918094165863, 0.04567354534482283, 0.055000133391830235, 0.03737980086776999, 0.025838994638874166, 0.0445249650417076, 0.10080337359179413, 0.048066857646429734, 0.10886060374398386, 0.024089010417341225, 0.03605446875876477, 0.054661135654896505, 0.02497872003474303, 0.010559577832839662, 0.0671747797018578, 0.0322001540072022, 0.034304861835534536, 0.03508424138530128, 0.009052019262115562, 0.019311274349268888, 0.01347282826299629, 0.07783581247372974, 0.03240376868615708, 0.06722849012622911, 0.03557826467459241, 0.08290115518555527, 0.07700334303081036, 0.051013814030034896, 0.09695190485687026, 0.03401950557505892, 0.017847646132952744, 0.05587286075517055, 0.007705044690444465, 0.009751366564042626, 0.028618834687456973, 0.038358604595545805, 0.04866829795402385, 0.05130246446858491, 0.0041489325362377835, 0.05184436825314357, 0.09707260200934065, 0.027413671130254388, 0.008149598330830135, 0.020924728296156374, 0.024362494230210304, 0.029538159348791646, 0.05961331185854732, 0.06613801759217056, 0.016428466338003357, 0.0507699299393402, 0.06598335210113757, 0.0746629061177373, 0.034682497216929356, 0.013602347875524674, 0.04372093278253752, 0.004250490418334882, 0.013365685121126234, 0.01507767616966439, 0.015903540977066564, 0.11641348757210279, 0.030527931540423346, 0.02694281050935388, 0.03520314589202885, 0.029627621181369312, 0.043242265725688595, 0.01808264168850597, 0.03790239540619716, 0.04465441857915252, 0.009851488510086652, 0.06283700601347993, 0.015656694998934625, 0.02761140033873099, 0.06946384275872862, 0.043081728170716, 0.02909416926183528, 0.08844086720097451, 0.017918248796054435, 0.05473476819573872, 0.048057898248155276, 0.04750701208268443, 0.08438607107006735, 0.14582692014594234, 0.11063587461267749, 0.18484583124518397, 0.15686508268117905, 0.09751789827620792, 0.19308044905624083, 0.14790933098523848, 0.09481848022269626, 0.12335558481995137, 0.14235090344182907, 0.11791964707475518, 0.24289022950876146, 0.136490821117355, 0.17963863969329866, 0.11283099996827303, 0.12370718853367914, 0.13320917624139017, 0.2042461192655948, 0.14423624582348332, 0.1900313578305706, 0.1457240038941945, 0.25587344331847084, 0.15529867802416125, 0.08612155133197386, 0.23473614286030495, 0.17131808213889602, 0.11438034384721711, 0.10422001082089641, 0.11347886520407854, 0.19895508705127626, 0.1796815099735414, 0.16842741789596696, 0.17257298012414288, 0.12650691813999607, 0.1157348792278959, 0.16291241221610578, 0.1196689475628157, 0.167301467830135, 0.14791849339681287, 0.16034387262357822, 0.08923278761006172, 0.11206626035873929, 0.09244217507300839, 0.08130672703226728, 0.11665505041638691, 0.11198622715328971, 0.2423754950324374, 0.11556060188600134, 0.15787155367434025, 0.12476790621275864, 0.14354987700860347, 0.09044646240410306, 0.06679716730310072, 0.12747303928218542, 0.13229288911867526, 0.18878366107181196, 0.1403459287699192, 0.22104060517684107, 0.07441580445776064, 0.17022712696944514, 0.21099742231590135, 0.11579094920307399, 0.11932862832421258, 0.14299325284457978, 0.1041401155112732, 0.14646455044707946, 0.2118296542715642, 0.21215726411150349, 0.18629140851478423, 0.16232972574089805, 0.17613916537694393, 0.11695390131564871, 0.10868565224471594, 0.1340496359813598, 0.1578892809489081, 0.08282303719991639, 0.12790499795829097, 0.08435782540829913, 0.12515729338291193, 0.15629534309189166, 0.18652325736418848, 0.1465473492299357, 0.17080803612066855, 0.08720870670532027, 0.12436885101300095, 0.10027795218892636, 0.10415619569680384, 0.10782883652756292, 0.21556995598779571, 0.12662666534344036, 0.18408925813292304, 0.09757828898727895, 0.09588842926126334, 0.10923217170901837, 0.1434926962059352, 0.10241392023500898, 0.21085503721429458, 0.15171167050157824, 0.15892883161863974, 0.07357749742485824, 0.17743180085334087, 0.1550009302915104, 0.17476973724701714, 0.2036740507690176, 0.19270141939482383, 0.1000513433809242, 0.12920276622378057, 0.15952483270197146, 0.16492616625562792, 0.1495598061310668, 0.10065170350454508, 0.19369537251130228, 0.16753788256356794, 0.13602514691170187, 0.08480101493337462, 0.12338497961360602, 0.15578851464294619, 0.2192172699517781, 0.21661770379831716, 0.14643654227256775, 0.18266065737172482, 0.177999134926546, 0.22454227050465925, 0.16771134019138353, 0.1364169242761789, 0.17034489000516553, 0.14641965769471663, 0.10826836415236035, 0.14309356439738505, 0.110285036986874, 0.13133740893775417, 0.20761908182213384, 0.11863152661751356, 0.06847599536300668, 0.12832903528525946, 0.21826752010853062, 0.1796844823946876, 0.21226116095579442, 0.1717600382624134, 0.1584344137940676, 0.09339416189299476, 0.14652694064763286, 0.12929503385338093, 0.1554336320729025, 0.16617064544510457, 0.21675449645807668, 0.29765402477595115, 0.11326851278182962, 0.09125489200795851, 0.15771081310606774, 0.14477123566452535, 0.14034310956635784, 0.09909295972677008, 0.09282553313119758, 0.24902757437479114, 0.18318619368778122, 0.12097439202930658, 0.08760446006612432, 0.16012723828035016, 0.1333927155862893, 0.07461106494790123, 0.09045239192463699, 0.11272495041691488, 0.15114033744940836, 0.17899138732783257, 0.13833845665137615, 0.12274012510334292, 0.2596298328811123, 0.09404666196074217, 0.11845931005213531, 0.14122086246648144, 0.13739094378486758, 0.15100279402348304, 0.101460715335223, 0.18895094403095786], [0.01920398373547341, 0.03131760922711223, 0.05948691501192028, 0.03311361426547651, 0.04550773710493119, 0.04902192413987172, 0.060726927908798384, 0.025862302863970402, 0.014854021588220231, 0.04451520125111265, 0.044506115448330684, 0.04773983386375251, 0.03994000159324177, 0.05447427148840601, 0.019575126521709948, 0.05084656171440598, 0.0402572002982901, 0.06373969890597848, 0.04611981454335394, 0.015171273919423262, 0.05179692442799288, 0.03851317815602787, 0.03317485916458311, 0.08212356828153133, 0.059615410939459844, 0.09149060194050113, 0.07190747171520226, 0.04478704372060396, 0.059335604985995646, 0.03449897319378872, 0.01313379509449606, 0.07415998471720565, 0.06478899038366734, 0.049682123391258146, 0.087387343087504, 0.008549689664505422, 0.04066791918669497, 0.04607604410980017, 0.023101467541569186, 0.03455113229011336, 0.0071672078751538314, 0.01920685656518946, 0.017293553889518785, 0.04998613006225036, 0.01990159297542226, 0.04722540199215855, 0.004740578888524925, 0.04682248570926247, 0.03224053833213064, 0.1386517559688899, 0.006127584905874345, 0.10429450521065343, 0.02943978408321498, 0.03874591566742428, 0.04186952043504965, 0.02707072995573042, 0.04874629719603447, 0.038384559654420426, 0.013418876520928838, 0.07301865160585412, 0.059142435915888324, 0.09822955565346826, 0.06015626135312262, 0.03320227362095349, 0.08860747600274702, 0.019581314596918323, 0.06052997436434512, 0.09026271621546439, 0.028498420987518567, 0.06283779125360232, 0.03006628695725193, 0.05269269188565593, 0.07049479026107058, 0.04198802274561698, 0.009812825967768028, 0.03409408040404801, 0.020252804069088835, 0.03534135964488791, 0.12154255347746996, 0.013513382084877982, 0.03586269779911926, 0.02097658861819054, 0.040524967180024234, 0.08522365798032092, 0.07565842971446053, 0.034135368712727106, 0.05641320938124292, 0.018282132899208416, 0.06964621764998283, 0.10752984773247473, 0.07428784479176806, 0.01526895683303836, 0.06456295614160838, 0.02145925656922402, 0.0607850433387343, 0.0315460987809685, 0.057614960016742836, 0.009506710639764226, 0.009489304164514668, 0.035116244708338094, 0.03247710245270883, 0.057899645950284705, 0.0707921549497593, 0.03451095863936409, 0.07014716254366983, 0.06113599587772643, 0.05591666566268091, 0.0641830876139143, 0.05629602474190536, 0.0320732994230404, 0.05013743242729576, 0.05260452282645049, 0.02096036479117409, 0.049516778634560686, 0.01504846044906205, 0.030178633751347664, 0.03223561621721714, 0.08133697984439713, 0.020199811852146542, 0.054387523522300106, 0.07287676446139812, 0.0237632928145749, 0.01572178948986074, 0.09342246884179693, 0.013549431309764905, 0.030900409234867945, 0.039766789113561955, 0.06568949609514206, 0.07589619276264022, 0.033860404434944355, 0.04247079603374005, 0.032019374494050304, 0.032607111403898846, 0.014702011549454785, 0.037482985250291326, 0.04156843638948856, 0.006775894472675939, 0.044256301837102066, 0.059943813680400776, 0.030720464757553516, 0.10502425758468528, 0.10249399174485477, 0.015302229946809671, 0.10254142790912621, 0.013092903236317779, 0.009192768766003992, 0.05557412093865776, 0.08925482795964326, 0.03803773249890055, 0.054975576443417426, 0.05142649793396554, 0.02333367645229784, 0.028501263173717647, 0.1157158725864945, 0.037490109867987134, 0.05043305809639635, 0.06822995856524476, 0.027257818202938766, 0.047265020229162714, 0.015574798284609233, 0.06117361845568784, 0.04664168512869266, 0.03054302155731186, 0.07642097065165158, 0.032610876726046685, 0.021301421389404326, 0.04083462757989764, 0.05343087505729449, 0.01364421075014698, 0.06115606738134258, 0.013724940137997752, 0.09413030344031512, 0.030966807990485144, 0.028414450090138182, 0.06037903972150338, 0.03488155750317439, 0.033026893112447955, 0.029234665956708695, 0.019441580159529563, 0.037355370323864684, 0.019186114734639565, 0.05107572542563562, 0.02764874329460004, 0.045148300142177654, 0.06561171518818987, 0.06749211630273251, 0.043150335174774936, 0.06355355103169719, 0.009086979684540102, 0.06187262772131832, 0.02956062104673155, 0.04757873323415557, 0.014519533236330796, 0.08223723274685683, 0.04547521667254548, 0.017897081786706563, 0.06092495397634565, 0.05039300701971497, 0.04169350790400659, 0.07887174720845877, 0.05032662933151569, 0.04487956415921931, 0.036822985181765217, 0.015099087369538125, 0.030081149062982974, 0.05672270507221261, 0.0593246269460407, 0.02930589106624886, 0.058751095221528125, 0.02861167751102438, 0.034516244646041624, 0.040761565774559014, 0.013705963182503418, 0.054901093544979254, 0.034247523984841766, 0.017029065864100572, 0.008207483934388768, 0.05007966173692577, 0.04975306696348614, 0.05542339313955558, 0.03190105221414518, 0.044268988253128146, 0.05299674452192361, 0.07111724436042771, 0.057183679328450275, 0.026936034461663618, 0.04607129819510926, 0.03640522977577583, 0.01053796266205609, 0.030200216363394455, 0.05420951150177468, 0.011135864601049934, 0.07178980061003278, 0.02684459037658188, 0.07218045948614037, 0.0446416364021359, 0.046684065112663854, 0.05163173288888028, 0.018076838572479544, 0.06577149814655704, 0.06316855354535003, 0.04467629421983035, 0.04339659796847452, 0.05129298796096156, 0.0190324547340072, 0.02796476796990441, 0.01974108606396664, 0.022089350480406035, 0.04229276869145613, 0.03725463742270105, 0.010803234969986784, 0.02577065959602835, 0.04042891124563833, 0.06726189155972774, 0.08482251136052994, 0.005624538537250051, 0.051743968600226994, 0.012539332890282235, 0.041478911354657144, 0.05048212219750689, 0.050778598224203435, 0.06584436076903535, 0.004361687122934288, 0.059546309808689746, 0.05564539775913281, 0.04514890918207746, 0.0700268867395578, 0.052206084327471834, 0.05156482276957362, 0.017721327810337948, 0.045980850024329084, 0.05652206281440393, 0.05535426902614775, 0.040775083395982945, 0.07185739254759205, 0.014223653800605286, 0.031150881681711446, 0.03048364208230088, 0.0585684483690608, 0.009399063795083954, 0.04358751090964483, 0.0032285240998927264, 0.05799968171143725, 0.061282824289294026, 0.0723742414265871, 0.010208628166677251, 0.021675429344477675, 0.04404294635018995, 0.080772012982878, 0.03784473196813657, 0.05896781766486745, 0.0398637107273023, 0.026307122241104805, 0.028221386357120452, 0.03894971803792062, 0.038906315326570504, 0.05159538201687317, 0.051281301289676666, 0.03988649035173078, 0.04166449998475371, 0.03562075574131262, 0.044742809803856, 0.03066539069667699, 0.012149871984166245, 0.021064382294313084, 0.028616055703511643, 0.05931777811999764, 0.029519022472443122, 0.08884247347352006, 0.01879231298282262, 0.016932624970532714, 0.04298296794595738, 0.05692477225356045, 0.05334316565084362, 0.06428032332370359, 0.025507288143759774, 0.03165091110032893, 0.04338345573013348, 0.034568844242922725, 0.03850333775664049, 0.022426794974073287, 0.03826907956071439, 0.04520122149598695, 0.05450913998027963, 0.044509424948163574, 0.01759830749623718, 0.053422149315836935, 0.054657240097801534, 0.08537546596339635, 0.04568861046385381, 0.045037190580079635, 0.040317322878587636, 0.04415555744461956, 0.07799548817978752, 0.07154294409819188, 0.03791456854331397, 0.12750530690555612, 0.061312134813277, 0.04054005528169294, 0.06029311529991608, 0.021284184411108013, 0.022412386775437384, 0.05523499679721652, 0.05710846481604442, 0.06775619447111123, 0.0903739675038284, 0.047329409919198484, 0.007369447905089587, 0.008518453387002791, 0.06752705757295893, 0.04419420274995989, 0.025839329802341042, 0.12329031412880267, 0.1137548330570421, 0.11152428379582782, 0.18413005997577023, 0.13695286406624702, 0.11561952936913698, 0.12897605016346902, 0.24310943790741507, 0.11876202969541473, 0.1709030616667963, 0.20550647179686254, 0.11735342382904022, 0.10138640480656778, 0.17350791382693476, 0.17279425696019204, 0.09449257109794887, 0.11381807361519146, 0.1391257345676422, 0.1307002536111301, 0.0980524667688916, 0.13633173529899892, 0.10574591240935749, 0.12801941318978227, 0.15398652262745366, 0.11141055804346839, 0.1842528638700324, 0.14559882512736708, 0.11830374057735167, 0.15767747295960305, 0.19627380995981156, 0.16781575797546297, 0.09116458556344433, 0.21773936377177316, 0.19197792595913335, 0.1994159502247649, 0.07452069721635311, 0.19424502527521503, 0.17654035030113113, 0.14265744586385068, 0.18594709795809564, 0.17719826661050322, 0.10113674441292402, 0.09025472591841414, 0.1265778655426637, 0.0981000944551441, 0.0846615562876386, 0.1683506252424371, 0.17930283271256955, 0.13891950369842593, 0.2149318047468701, 0.13873035658992108, 0.14079343137000838, 0.08779582882960958, 0.11924137857051627, 0.12597580470385092, 0.10865536878906912, 0.17638541667932467, 0.12198241818095408, 0.18904008602182712, 0.17350409870907185, 0.14741276811447837, 0.26151827025798063, 0.12405810276827506, 0.0846724883623181, 0.24201984637446944, 0.13976396241736028, 0.11856984887872973, 0.1584569827443169, 0.14504112844024936, 0.11551553293341592, 0.11689323481292495, 0.18338818042989702, 0.10483353233505642, 0.0815976335997543, 0.07433420077206628, 0.13554611213264928, 0.1357672357511136, 0.1276345919036577, 0.20020681343251662, 0.12024780359840202, 0.16911985412720712, 0.15838051184771523, 0.09247578335024657, 0.1665240111610582, 0.22879891548185582, 0.13344479424338188, 0.1244801635883989, 0.2132380303115614, 0.20852867333639055, 0.2137806197448123, 0.2012638768721973, 0.15783026153522153, 0.16770228503211854, 0.14936347311783224, 0.14885037806966614, 0.1383977978219909, 0.21514816329844538, 0.11363680955142745, 0.1643929537385702, 0.0928347874733229, 0.09833606485758098, 0.20875088479970733, 0.1549133204764897, 0.10325937486824491, 0.12619260758642228, 0.15502961262339546, 0.1915220730006695, 0.21304312222186597, 0.26383718776126064, 0.08138263868468423, 0.1415404437049743, 0.12234350606318443, 0.1440014858399668, 0.17374219883593822, 0.12663919854188158, 0.1151563679318755, 0.10492893326426707, 0.12535611618190043, 0.12451451497092364, 0.20924882662873115, 0.3313916176557541, 0.11701691204742079, 0.10381704091184563, 0.21238523655601088, 0.13907449860726634, 0.09421536984342722, 0.273934533038447, 0.16277178911672485, 0.1261126126853689, 0.08541930917530291, 0.10659093803335583, 0.1278404320680326, 0.20618522569777506, 0.07532677493028103, 0.1582078509513409, 0.15754052708225866, 0.18226092801459376, 0.11490998639454765, 0.14147566331009712, 0.1029876204988649, 0.09639073013057632, 0.210931783902549, 0.12228570472929748, 0.19975627712424726, 0.1649708291816135, 0.08291088450219362, 0.14377319163853122, 0.1766032307979561, 0.15228942337055362, 0.13741397238787145, 0.13650202132280798, 0.12283656025125135, 0.1861109794868577, 0.13944237402850582, 0.10959975601684664, 0.11014942410251788, 0.10094049566936109, 0.1144870828777071, 0.16227191674613184, 0.14386388112700757, 0.16251841319664834, 0.1216958859755147, 0.15598061885083878, 0.17654765877992878, 0.07489578918583932, 0.18530418165028098, 0.1414920729134352, 0.16149370931088924, 0.12680265106140606, 0.1513714508544053, 0.10158960196760394, 0.2372769194264566, 0.16415137557252762, 0.15533690581158285, 0.15036245177109397, 0.09033906453799817]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03494608508903654, 0.03705290732003989, 0.04456460243090988, 0.015522859438562827, 0.0649079485165496, 0.025946147356843276, 0.05352189779401787, 0.02978538166761639, 0.021880252527133114, 0.06245879223570228, 0.07309309236945645, 0.010021990953734326, 0.05237581876797542, 0.020825253694408366, 0.052366606560685945, 0.04352572974899123, 0.12836563130540232, 0.03276105677228301, 0.03229670789873889, 0.06258506650826143, 0.03351024096651423, 0.03867206862196326, 0.061748640221213145, 0.03688365168448898, 0.07154965502840858, 0.018996199622990626, 0.07109350329565425, 0.03844915235775613, 0.032568420133283066, 0.01886865555969698, 0.015537711010584909, 0.048128585180928635, 0.03383454130662065, 0.030057999801131028, 0.05777041457833783, 0.08567675302225737, 0.026449911454091632, 0.018868783879424297, 0.028952481300239603, 0.007217388549414013, 0.008475593640469015, 0.01756921913775225, 0.04852816132047484, 0.028016017336818962, 0.02109561761420581, 0.03542659841778298, 0.058507448618089965, 0.003756234908641707, 0.046705530896302194, 0.05229840175278726, 0.06923170279591315, 0.05860754949671607, 0.017867943632506558, 0.04743333740700637, 0.06062511865410113, 0.01598989057745184, 0.04291607314840921, 0.035311482215840975, 0.03832928258024397, 0.01504536641145786, 0.033293890075818185, 0.0329647787035473, 0.022354188991049607, 0.026237559542360327, 0.01705372623438316, 0.024160572605568077, 0.018865330738105604, 0.10783278188037296, 0.060379824961625764, 0.00706233857800403, 0.0372572421216436, 0.0027811165425866364, 0.06122952755240183, 0.03726336699459822, 0.054977461019711155, 0.09025612019843633, 0.033517913337075905, 0.07009584231362229, 0.036312333954077576, 0.055740101548332366, 0.02482371938024317, 0.020939511877875176, 0.06968931775660285, 0.031104117759593555, 0.07009984129258702, 0.07869645096962491, 0.01889540160435342, 0.0860005017790583, 0.04731781134802488, 0.011768167718283594, 0.06557112018908225, 0.02843232675185127, 0.07342127677533897, 0.0458546063952869, 0.014070144144728059, 0.06868261693706436, 0.04499939563233526, 0.02390932066426162, 0.05417491114067455, 0.02263378235511482, 0.03461624593323758, 0.08848232787943656, 0.06298037936850902, 0.031183608957836707, 0.061707099103519035, 0.026194386657387502, 0.017908086639738852, 0.05539880937806541, 0.042011093483456684, 0.05546389620811228, 0.028486188478587617, 0.051943837109232144, 0.02579972305665574, 0.03191326365565821, 0.05494925749277877, 0.033356946772865714, 0.06899372524311466, 0.028215684747743993, 0.02193121078063644, 0.012868333179804107, 0.016900753797662836, 0.02276276091804668, 0.03890386001477319, 0.029767403499253338, 0.054366509730537096, 0.04692696478037585, 0.010169203366873967, 0.08729119139212756, 0.012011944556668883, 0.003217985602884343, 0.036366795144614675, 0.09718745391094878, 0.009195475929206418, 0.021580181632851882, 0.05179056589822135, 0.0422447273177245, 0.05506507466517149, 0.0525023496799892, 0.011832689558486304, 0.028541593872491392, 0.05113567180571057, 0.07649073061803657, 0.01543529750403738, 0.04574422078627733, 0.049815338420411276, 0.03593612732666154, 0.06044724452940207, 0.024223449271953395, 0.02120921696205774, 0.015995699439137694, 0.00612077055378787, 0.017252671607439558, 0.053745300524056926, 0.052419788384389494, 0.0454275238688194, 0.031552648832721096, 0.09385122527037898, 0.04583468427881599, 0.01825969226868643, 0.059613886424490524, 0.04839074046861741, 0.06318452264813167, 0.013821141629089272, 0.03804099220301836, 0.044584440277709116, 0.031085407977262815, 0.031004539735975768, 0.0483959460360629, 0.01950791571289301, 0.030485758400191704, 0.033440251173751975, 0.04827152569628051, 0.02850055262716788, 0.050028218932810335, 0.06758765512776953, 0.009486353768396282, 0.010100835765291367, 0.00917064223153096, 0.02687275368389824, 0.03846822028619148, 0.06733690688927328, 0.010375881439916069, 0.06039670570903729, 0.03838394295364138, 0.021711293750652866, 0.0356122674871116, 0.07214095999276446, 0.06823839319329109, 0.06313386125369899, 0.06469007311088425, 0.08235548607884877, 0.05969861191847633, 0.03790786527397652, 0.1547306085065488, 0.04136242002489106, 0.042157174959298105, 0.03387513630572827, 0.028192365031328895, 0.040596807075123635, 0.014792812120680128, 0.0912442587075695, 0.015506948749985427, 0.024895618647156705, 0.025194703203235424, 0.062403875222850236, 0.024678827255904198, 0.08780813220167354, 0.038588867642946785, 0.0502360892301846, 0.03646099714622383, 0.016588289515986558, 0.015243339810460327, 0.028380801593283975, 0.04573368707731847, 0.05418611517656715, 0.03597046338742779, 0.014812046673239, 0.02548159930043884, 0.024183760171816237, 0.05925777428332837, 0.03555100726624651, 0.017908743560133923, 0.023427028096311038, 0.041384460374472604, 0.03988880010682248, 0.054174248474620046, 0.04436952197143147, 0.055579529519403176, 0.009699956318663975, 0.03829507292398522, 0.028106432948862354, 0.01179233396185502, 0.06060224326868212, 0.04331672181104941, 0.03429658042507307, 0.006975238690257914, 0.037461078966096524, 0.032201916009428046, 0.10500155839948885, 0.04932611084152614, 0.02038971738769643, 0.04588351472310963, 0.018634924049218817, 0.10514795014093961, 0.031907661637711915, 0.0384711965377773, 0.011466225654247307, 0.011793712920118726, 0.030022713791338668, 0.04539116150549343, 0.023562081736482443, 0.038868754035643036, 0.05129978699128955, 0.05625598132610322, 0.033685598492382035, 0.06706787213202446, 0.06485570898099292, 0.049155736717605786, 0.03230416193424213, 0.012446761698341899, 0.029356236449412765, 0.044932462530390876, 0.03972847705646869, 0.004853062620837121, 0.046138189162217805, 0.02147812531479905, 0.027373761779838995, 0.02128307549883762, 0.030904477161745873, 0.02235849057474444, 0.02902157093969084, 0.11510608958140497, 0.08195137469879082, 0.010445243998190329, 0.14885076111362827, 0.03995494030776524, 0.02074942056600365, 0.0770757613222926, 0.02917221063868173, 0.03920865575632742, 0.002508764624625685, 0.05522981038196914, 0.031161181733853398, 0.018978499161500125, 0.034816769447417996, 0.05165442058275785, 0.0550636995373474, 0.05670640655162354, 0.06677629140716407, 0.011300195248857623, 0.10280673947906303, 0.03690972931743149, 0.1038394260009931, 0.04611316106973156, 0.037500218398148016, 0.020932590273479303, 0.01779057258259385, 0.01809836564315183, 0.06019429378812352, 0.021417675231913888, 0.08011069524312213, 0.04068207649153568, 0.05948041475588276, 0.06148931179796496, 0.024160247018200257, 0.03886911792740707, 0.021596328851075906, 0.07904737286510007, 0.02931789949446196, 0.030805548397643916, 0.036876661132179925, 0.08102325917852503, 0.05697539151315728, 0.040187593549489975, 0.041756334774676836, 0.038977527029571996, 0.016813360402480732, 0.08097882607891675, 0.0518418325021142, 0.02839586671231495, 0.02340807699628415, 0.04390691977835471, 0.011593242074483106, 0.05420277758892025, 0.050502028992219325, 0.030105056751879956, 0.07094963964435362, 0.038245258056708885, 0.012393669889969452, 0.022656362796682986, 0.030767770686877832, 0.05723174368481963, 0.027527732046080694, 0.045164227110123446, 0.01988331603276874, 0.041321717773474036, 0.020530405604550918, 0.006947888872556149, 0.027812019613901937, 0.018286767731150313, 0.018582075473762328, 0.03822494140495697, 0.01892001026370112, 0.025414461269974712, 0.030152531220547618, 0.03795190766874341, 0.02773505842102872, 0.08263503922329796, 0.00784316220350804, 0.05488625442188594, 0.06618473363379318, 0.060372857391954436, 0.08522924276128893, 0.1528224520265095, 0.11616368928263265, 0.1227751276606033, 0.15873096642955659, 0.0787196098075759, 0.1712916674272668, 0.10617774085051591, 0.10276825888262642, 0.09350087794084704, 0.2190237101768294, 0.12477552878760523, 0.1351827106648876, 0.12242078901298585, 0.16571931240539398, 0.20126286563613724, 0.17892197976189275, 0.17022868978881067, 0.16451673822537546, 0.11515725659386766, 0.15853454148577106, 0.10016922899071248, 0.21636503267913096, 0.07863729366011198, 0.19279741021173616, 0.17013983891135262, 0.20999105857504954, 0.17002206055387376, 0.12730339677223276, 0.12536197675452118, 0.19056869190066092, 0.13038827196484612, 0.16277793314187758, 0.11562825511059455, 0.11295670733576822, 0.18121367050034387, 0.17230019153606507, 0.14498169533908367, 0.188523298429866, 0.14626559741314382, 0.12891801134232553, 0.09749857753875757, 0.12043246143167058, 0.14358283411110603, 0.13579418672428978, 0.056298449410185705, 0.11538152883370077, 0.1390666538669217, 0.1290973372036411, 0.15531058303050457, 0.10899270028476754, 0.197878381117217, 0.1326989616838194, 0.17141718327278094, 0.0840276874782097, 0.19172346219420436, 0.1839119241002106, 0.15234674206904827, 0.19547891712957816, 0.0699587891839685, 0.20501588441191182, 0.19404231841045042, 0.1714997215857429, 0.08732880630920972, 0.17137670318686193, 0.14625669547146367, 0.09038869171373307, 0.3680598952116505, 0.16193276962205289, 0.14342888108184262, 0.1645925196428453, 0.09087982302111003, 0.1769342114247622, 0.14324025491312628, 0.17689791417890982, 0.16070578788076678, 0.1387408673162422, 0.15667875477623555, 0.10237545496033085, 0.30406161481815003, 0.10497161968340797, 0.1334528688101038, 0.187186015349242, 0.1195526707376684, 0.11082670711461576, 0.12278686412760328, 0.21692827584282046, 0.08360175791406825, 0.10576534039911725, 0.0754241676880948, 0.12645699218997072, 0.10941782545658851, 0.14916254357705194, 0.07269638139874705, 0.12364656799623083, 0.17242520176354917, 0.20087838142869935, 0.06744770618576197, 0.23905539254267372, 0.12082296709019331, 0.12745370322297658, 0.19413375866509255, 0.3016332693157658, 0.2092704915952298, 0.08871310420574681, 0.144536322463424, 0.0976268359790406, 0.10784136972600415, 0.15188646112238208, 0.1008213919797732, 0.17476630517311637, 0.13696276192222873, 0.14185587274691752, 0.08917892396810556, 0.20096962250048117, 0.10691772815921616, 0.1473803625952813, 0.14611481598788692, 0.08688971535452912, 0.14802061291711946, 0.10500791692926038, 0.10250954332971766, 0.1084983514081086, 0.20113603211939338, 0.1519037134224369, 0.13770879366465155, 0.21752052309532321, 0.15847952105104923, 0.10043185159203508, 0.13601972300919796, 0.09971008185417422, 0.310025119012402, 0.1820278227809937, 0.11384987392492833, 0.11626559429832044, 0.27417768934561365, 0.13951179691620413, 0.1877403106059759, 0.12382625391887081, 0.14914970394344101, 0.14235432019397137, 0.1715037971735001, 0.17479826636131734, 0.1577499295554815, 0.09118203704635944, 0.12351591936162404, 0.12532687460583064, 0.21987673375875721, 0.07921247247366175, 0.11965003285196521, 0.21448241757048717, 0.23996475423055313, 0.11910300010875349, 0.19102733341916917, 0.16512159528511186, 0.10814752144318436, 0.17000116167529938, 0.15615396922634495, 0.09028681734156224, 0.20999997583848817, 0.17457015602098358, 0.12549882304043541, 0.11035377039544045, 0.06865371243968126, 0.10366702557451303, 0.11700877619366493, 0.19164643971429718, 0.16104468985671, 0.23815292564611282, 0.11829208838002336, 0.16294299444604307, 0.1740355339021452, 0.1260091984764703, 0.18789291532049257, 0.21317274429865424, 0.09078639859874403], [0.014395669267903415, 0.07441699189404327, 0.04570231194637957, 0.027808652657474724, 0.037620233732365796, 0.03603555404791429, 0.020655421577694438, 0.019364278057530042, 0.03165329937943288, 0.010534571765381242, 0.019935681972832933, 0.059558869820208325, 0.07451314358941971, 0.025192824372601126, 0.056342959118586396, 0.0921781198872674, 0.033301259841649763, 0.028135458105093533, 0.03971243134489463, 0.07775173432403996, 0.05355483957476193, 0.04716341398776539, 0.025530318661983457, 0.04218483073336463, 0.06247580704850055, 0.04858836434000442, 0.03727045330789782, 0.029320755087199713, 0.08380211288890532, 0.030138272409056945, 0.04018835963741426, 0.04637227498836095, 0.03397854668418727, 0.010203649552779333, 0.03620845626198477, 0.025810971142603986, 0.09043205229024734, 0.07081519887452165, 0.040196660200073835, 0.03963331744495419, 0.03315013750726658, 0.045844980500518315, 0.043604625313873255, 0.041511765035289916, 0.03391613350099614, 0.007276776642914141, 0.04726018238392088, 0.01735403461592092, 0.03759754603848823, 0.04078136531696205, 0.02128086533517607, 0.04397052805870772, 0.06502368141927066, 0.050609844376242934, 0.04744148858252072, 0.04559613599051391, 0.013130611999170675, 0.018080536861934008, 0.04469849161743637, 0.018803091839917244, 0.03820272102471321, 0.03298806011556618, 0.01805691262556901, 0.024791193202198036, 0.04641880716888174, 0.017116805914068417, 0.033247978426516056, 0.040975660536318056, 0.06318780916532682, 0.024520296851293217, 0.11730986406966565, 0.0693977446926217, 0.035253447225137104, 0.058894089363034696, 0.01885694207533473, 0.03345062400424673, 0.018752857539502364, 0.016716381332146067, 0.06089605713984179, 0.015946440943216365, 0.07648296248648437, 0.06625489962677802, 0.05552676138317874, 0.10094149158366265, 0.02861487592810825, 0.08164978886563933, 0.06799867662090449, 0.012162295057468358, 0.030443661868752494, 0.021000004095596173, 0.03276464972464788, 0.02984503884949992, 0.027061399004812685, 0.018134743328236284, 0.11535319890226088, 0.04005190788678104, 0.071087121783245, 0.010088968105734357, 0.09034851040210455, 0.11969776779052713, 0.07444246431752559, 0.050828198586860975, 0.08945488416018987, 0.006278036434518835, 0.0012244649030523555, 0.028158005987924915, 0.08902130903856409, 0.049066073786948, 0.03150316529847201, 0.04206841601239097, 0.05968832718809286, 0.06148225229774272, 0.06501163085622173, 0.04578481578538495, 0.027433989697226116, 0.03729642751897055, 0.10757450299758105, 0.036501534688737125, 0.004214615957255686, 0.08069535056429525, 0.05043398123234511, 0.040048027651444565, 0.0642388932887585, 0.09471908797540012, 0.04588539163852411, 0.07062222898727463, 0.07453774267266836, 0.06568790263225956, 0.02896356659250394, 0.012693867188758187, 0.06510250420579988, 0.08031868811456427, 0.0726266444149998, 0.08799344120967774, 0.021578490493759032, 0.024632996045834115, 0.03736126920088165, 0.0165360902000459, 0.04789809996802961, 0.07248103408323181, 0.003556376693943035, 0.009183374612832503, 0.052424116781161684, 0.03423560365673996, 0.019993684404800018, 0.025722440106854327, 0.07155321733725649, 0.06134801454121067, 0.02753432806310875, 0.04044759996055115, 0.04528847124968325, 0.02895752215878137, 0.04397017565826255, 0.029335192014132778, 0.02404990545924633, 0.12478677495833367, 0.06955955778398822, 0.02230623954786889, 0.03936408350484506, 0.03986294846981764, 0.029884454073204152, 0.10378203835458526, 0.05105287685329395, 0.07790783239949135, 0.021225682106770335, 0.04996792781316946, 0.062070600162710876, 0.04095629383359225, 0.008090375903843632, 0.02490507791780176, 0.011154595450798591, 0.03806842581158684, 0.05017923784532374, 0.03581985433195387, 0.04708048880040165, 0.05050267633651534, 0.033968733097877235, 0.05530999680500358, 0.016391131043013547, 0.03792142119979666, 0.01844362806408636, 0.06589347466586098, 0.01686561142935628, 0.0488585367378208, 0.0956981713252683, 0.03132544247613799, 0.04873233141317483, 0.037547826932202426, 0.036500856700924136, 0.045264301175672206, 0.01862780326196263, 0.047597398966430664, 0.020522796436243003, 0.05175336466861829, 0.06272808363240573, 0.18276466146832515, 0.022426228069009322, 0.03371419655459543, 0.022313040493416692, 0.02423900851769553, 0.02927520732966162, 0.07597307734672101, 0.0322903034036919, 0.026081294842785405, 0.060191175810271697, 0.013994514987233185, 0.040255028439024766, 0.04496508638464636, 0.07617899411988836, 0.038407503987752625, 0.03485811138225179, 0.012872188517283048, 0.006324559996550482, 0.048506772145628936, 0.03897467718249367, 0.0313560840778894, 0.06084354181263236, 0.028672525959630168, 0.059434288601961836, 0.026596291704223524, 0.015594339272337816, 0.057798587461753245, 0.06055374607263554, 0.015744672536158997, 0.0768773905151794, 0.04385679847590866, 0.014932809900792857, 0.029921661048466643, 0.029892088139369607, 0.050986016529702374, 0.015457239219798677, 0.04642112458485269, 0.09905162162237591, 0.02925944698583936, 0.051150744585620786, 0.011865853504728407, 0.06571086994822949, 0.07810231147994919, 0.04735893494780025, 0.03833788191719401, 0.021715342525332686, 0.04976493366543324, 0.05997764795357662, 0.10984737095573258, 0.06856309189911812, 0.09507813806375189, 0.0734990653431704, 0.08072503647136112, 0.03815487117296265, 0.04997091555607416, 0.03658660492228885, 0.03879405663258607, 0.02164793061843563, 0.12767236003832472, 0.021129541902712757, 0.03519639282697632, 0.012818087388070361, 0.033076838214671424, 0.05495888338754735, 0.03584911889066139, 0.024783047772343123, 0.23105939579827173, 0.03105341231510524, 0.006659507043584581, 0.010972876522329547, 0.00524743223532794, 0.04540955144611578, 0.056238579638903184, 0.04200144460605037, 0.004940704994594618, 0.09821965779748656, 0.03385627522103248, 0.0643805506068372, 0.02365082153119147, 0.033512022120938185, 0.03201013355846367, 0.03879728569318691, 0.07031554866942667, 0.033676202423990734, 0.07325511230456253, 0.03666186923040979, 0.04565454636430068, 0.03409146421378659, 0.04815949299823373, 0.012590313168813386, 0.031048723857008645, 0.010980083494477216, 0.06459536932168469, 0.042661011834899266, 0.05971007259382356, 0.02753515352284716, 0.015775666538355573, 0.027226261126117843, 0.029642489032759785, 0.03731081848062816, 0.027147112752220807, 0.03121339254111292, 0.03828121056299537, 0.04399229644707615, 0.05542763343621647, 0.03573346259673277, 0.03570599834464731, 0.14474863607075908, 0.035956532078524756, 0.04884395808462174, 0.045167724301497784, 0.044047730569277084, 0.0261373839701616, 0.06324214395135641, 0.007069096909911042, 0.06271974859578956, 0.03589700704680816, 0.01715719023899686, 0.05955170306767668, 0.0410874174427121, 0.082152143361107, 0.0632381871072275, 0.014652908186338123, 0.12163658310929615, 0.06769453205408589, 0.019357122796317263, 0.0695662457315672, 0.05999983002942416, 0.04167794099738521, 0.019750721534834276, 0.01350370447917451, 0.031735611696457194, 0.07547753337290018, 0.02020832691942492, 0.027980815596698273, 0.05226352176959476, 0.08187035323991891, 0.02862181476948242, 0.03702777963612349, 0.0233543589110336, 0.07689678020054296, 0.06445872221863078, 0.014651382713758898, 0.01853731295634662, 0.04702382510708225, 0.050357154104858644, 0.047885566769588384, 0.03658403086686327, 0.0516978845811419, 0.046869814621224526, 0.05289503102821689, 0.035425778703703996, 0.026144780549070528, 0.004697438083483928, 0.05575358852623932, 0.010032281429777223, 0.06227395054133189, 0.10754030483264117, 0.15301467880846994, 0.08828921243548395, 0.21031344369534524, 0.11371208535086726, 0.179261892973896, 0.08834084676158044, 0.09249409285163687, 0.15641842277780657, 0.11248191668381614, 0.18225931922995275, 0.14260627119050873, 0.17662317972750435, 0.08324695961369623, 0.13959044350251076, 0.15044135882729484, 0.09877364661905075, 0.1115262296591555, 0.20321580761623, 0.30132003128528595, 0.11480490211397411, 0.1232440730616931, 0.1270564942951164, 0.1051461574951968, 0.10796474818620952, 0.14805971404477475, 0.08134025870071304, 0.10110344257085555, 0.23690421765129413, 0.10034891491335246, 0.13597248602778683, 0.15137788599296925, 0.09244321695258541, 0.12463416258293776, 0.14503636337336034, 0.09724897843214775, 0.15378160942946711, 0.20496233486600463, 0.20243073603318584, 0.11376836216978489, 0.15387545520019147, 0.21001727410381843, 0.12610871329783432, 0.14294514252293494, 0.18159623948797105, 0.19555122050787174, 0.1157817867914996, 0.10291053673192378, 0.13582406415333673, 0.1630842457375219, 0.12287360826326955, 0.1305445998666748, 0.23848517797887328, 0.11682817862639505, 0.1447799384233452, 0.20420484244823459, 0.24274658802295887, 0.11634771892380331, 0.12877519723148118, 0.2030368494771181, 0.18780619416746402, 0.18929727705976657, 0.082397835419303, 0.11079106104349899, 0.1456674666053826, 0.10421533002367905, 0.1339551007315036, 0.20396332556922592, 0.14793680289820318, 0.21419858199454125, 0.1952222623531857, 0.13878704709631784, 0.15908503694640053, 0.18125552954452653, 0.10181805704750362, 0.19634707860888975, 0.21715082438482394, 0.19799122586846354, 0.12777763584087934, 0.09466833465041653, 0.08499166357421106, 0.23936332924471748, 0.17046167244834287, 0.20462286598499746, 0.17485319486548825, 0.33652762431771527, 0.13939303796618216, 0.12598963259088417, 0.09442278814892616, 0.06822972107798823, 0.18678314503162138, 0.11922521411531395, 0.1554440968339482, 0.11792531612539485, 0.212112539898484, 0.14094487163088015, 0.17710023799971228, 0.11420765996820505, 0.15486375458778875, 0.26240386789844883, 0.16760595713651952, 0.17665161691125364, 0.11078778218718306, 0.18590393656444165, 0.16285083406875211, 0.13128251107710023, 0.2532836677686822, 0.16269207000732422, 0.15319642550762624, 0.2028959812296014, 0.13406276672838197, 0.24122608735436396, 0.16650317356951777, 0.18778437598338052, 0.122257734859182, 0.07713112649658034, 0.12675817965740158, 0.11979426422546949, 0.09402060731043739, 0.15118663980355188, 0.08345109140200001, 0.12860026871485095, 0.13968712379855497, 0.24071173592200204, 0.16824239234049476, 0.19459284451459685, 0.23028255199953435, 0.15559736038407973, 0.14066934044803345, 0.12742695909353996, 0.1448444430265696, 0.15574487827477917, 0.25567275892582636, 0.17274017115273785, 0.18504355853844076, 0.10812128293177775, 0.1460542490765933, 0.09725196617505244, 0.13113906877415796, 0.1801706571131945, 0.18727607664562043, 0.14643274247646332, 0.15938214116519497, 0.16719131970838194, 0.10695816227985967, 0.15178343761832486, 0.21955620257123826, 0.128227835070462, 0.0942003698418698, 0.09284387327610485, 0.1051352407422758, 0.1794678327297011, 0.11983976984817175, 0.07570241082219348, 0.12847387186822393, 0.18808531064179637, 0.177878828478917, 0.10874325439574258, 0.12638409892397542, 0.1365991765933652, 0.14247275738706514, 0.15384153282690435, 0.0962709905880113, 0.11985931275112015, 0.11563196297614806, 0.14215150607689736, 0.18916748644363499, 0.17005719334608124, 0.1380992840014158, 0.10455660687218751, 0.11288645707311169, 0.13382629070791507, 0.07641340936383895, 0.13805938614231927, 0.07970807007363728, 0.15999642110640006], [0.052413341754506675, 0.04928088867135587, 0.007087175627314156, 0.04366447976339729, 0.06193335551107603, 0.03716248853672897, 0.009823989784044605, 0.07890704087913036, 0.022332744274829185, 0.06122742464104968, 0.019579512375076453, 0.04578024990135624, 0.04010285273374569, 0.019996080344783205, 0.019639242335312793, 0.023799806480265917, 0.05298457521524641, 0.07284111839028136, 0.046943025813708385, 0.027801863203245788, 0.04446310344182196, 0.048096367353273016, 0.003070013805089759, 0.06077606478826173, 0.025290332043603547, 0.021903388382446383, 0.009630161878322403, 0.043354309915054234, 0.009551027868573946, 0.010729707766234154, 0.0211186136584729, 0.08725822662874576, 0.12248112609790218, 0.02991025591449392, 0.023726712116190506, 0.045189519502943566, 0.05826503924664952, 0.04112983190063988, 0.01761488563891861, 0.04499495232237443, 0.03971588640143314, 0.00893435869065504, 0.040201023070802616, 0.026418147533531153, 0.07072255586183841, 0.029327255343237234, 0.08511171721282505, 0.017083714746179122, 0.03940064888147097, 0.055949833439362634, 0.009906394989229739, 0.02157236562080441, 0.04479729780747045, 0.010170860032010223, 0.016008164647275645, 0.103161315613937, 0.023304691515682686, 0.014242223771889845, 0.03279891300706133, 0.05471196941911213, 0.10649617295712234, 0.011625644720850453, 0.0610237218619835, 0.03484151408737225, 0.101379785806902, 0.031315828072688276, 0.030092044748486053, 0.04803460534481753, 0.04082621593448905, 0.03392917614790701, 0.11044285109927578, 0.05794062016291484, 0.020119862916368633, 0.056925048045213186, 0.04554073634226957, 0.05923525895923377, 0.029163189953373327, 0.02043063031329263, 0.06602684291259897, 0.04281831266839178, 0.019535299525746418, 0.06088684110211269, 0.07765546771547488, 0.06545457523316145, 0.08871282841409407, 0.04221486521043605, 0.045288229931987105, 0.03444514402578916, 0.044921679842856624, 0.06277515207447353, 0.052005269699880195, 0.03573449298499092, 0.053613575535916516, 0.027172282570973042, 0.01724355324592081, 0.02792628545824799, 0.1132228539415425, 0.0019795143382526155, 0.02719236173546843, 0.0839169571296342, 0.07134506358735024, 0.03882160898478281, 0.02129714853400665, 0.0549851831859879, 0.06283727414425343, 0.05453499927816372, 0.01749983838488979, 0.0637352096307422, 0.026952739008852554, 0.022626667313518065, 0.0448516249326208, 0.03294765280800001, 0.056746587863252054, 0.04239123014192428, 0.03395914550750487, 0.03932227425637745, 0.061801576896780924, 0.03619959262470084, 0.03194055170752108, 0.06510044342928356, 0.08024219423532486, 0.04433893208061496, 0.04219247629084895, 0.019428164044755603, 0.04376838426856745, 0.03943713381886482, 0.03095319460807068, 0.015420617344188354, 0.04586651523206984, 0.010810485034580193, 0.06742790281291931, 0.09030898792609092, 0.05270536297992353, 0.024478926188162258, 0.1688408295834257, 0.04417508502580947, 0.03380598537924309, 0.033342862246377815, 0.04319233211478399, 0.0837895643687056, 0.007405508142490421, 0.041804414452804674, 0.04441435343676037, 0.008330456367994269, 0.026330554955488732, 0.027155177742843668, 0.06629556357379883, 0.07444247963928408, 0.06425519947022681, 0.026720246645591916, 0.0238545875125114, 0.05456163232485133, 0.12346980086858235, 0.044189361074278434, 0.0794346379717031, 0.010053232976896389, 0.03397401910455477, 0.07015257878529449, 0.012117788221897378, 0.04535311374873404, 0.020494156239193775, 0.016366185304979165, 0.01806892871466135, 0.053096538965380004, 0.032311022251604066, 0.04875570092530501, 0.053080619658313455, 0.05625533781224682, 0.0848175471107806, 0.038578916160810384, 0.02965654291573071, 0.013434391716615328, 0.06828630433207558, 0.06389793436673862, 0.02139141373786955, 0.033988107461482286, 0.03713330058681388, 0.1099785098866109, 0.028379198554302418, 0.05617546931570096, 0.041515706557660334, 0.05286205860395586, 0.048306049448588205, 0.11480636534190948, 0.056633754603324406, 0.048999948907763734, 0.06130315626280443, 0.019512705677639575, 0.11512403902147086, 0.007992641758098598, 0.044694638195177244, 0.028842970946683522, 0.06252041251789178, 0.022159242596957954, 0.021539107828791586, 0.07573631021284288, 0.029063376357718825, 0.027398753483148835, 0.06610483066329072, 0.034642285261783874, 0.0687862150070648, 0.031942576094860994, 0.02393382207129992, 0.03948871834924625, 0.005566978521059238, 0.04796810508255036, 0.06487939641961167, 0.07227186909726552, 0.035531364771867954, 0.028610852051285968, 0.04078890745257659, 0.09939732645908672, 0.07550821519426762, 0.07133640679380587, 0.050121995755621505, 0.020293644216332226, 0.020422207176565163, 0.05430623776309433, 0.05914776405740169, 0.04190831895797484, 0.013058483863489763, 0.09886699443262431, 0.03703842442783137, 0.01821938072211079, 0.03790858156618573, 0.02466916880239883, 0.03560253434003361, 0.022417519564530062, 0.008719903867571585, 0.051158642952120116, 0.05459961879457678, 0.04281055602815844, 0.07753398915332171, 0.029513646450434482, 0.04263273552961407, 0.05366501834003195, 0.07654876177830082, 0.04735996916649803, 0.059667397666001515, 0.004948915541923095, 0.030832891990881295, 0.07744231141142308, 0.01969463240745808, 0.019386661231457707, 0.02324406906301456, 0.0035905257813752664, 0.12827147909950826, 0.04290182008257797, 0.04193312871540266, 0.09880099595794756, 0.07153248699802546, 0.05473903530547696, 0.03744445102770002, 0.04528743320054585, 0.04627519632659612, 0.03770241964488261, 0.009019041092195099, 0.030896345138429638, 0.05140993894348222, 0.02193276976956235, 0.08590694712174517, 0.06555796645942234, 0.06331761893365653, 0.037384213534213846, 0.05211066424606308, 0.053599969814381296, 0.057322329751426176, 0.034103411354965744, 0.02100147498441079, 0.0708861539380685, 0.012165133413227816, 0.026956297487260836, 0.07022197869035506, 0.03629305918190268, 0.014368880130801231, 0.028686524301226583, 0.0883145852675361, 0.09631039048995703, 0.024319216008147886, 0.048254664101067095, 0.031286416042055336, 0.04136127472344426, 0.017477767391791268, 0.03353999965193291, 0.04561945570692901, 0.03299428457995096, 0.023150968312796567, 0.09141184044100585, 0.06612474894932201, 0.01888564164419809, 0.061410910359794096, 0.025467641178458452, 0.009754647335578358, 0.09075789246708156, 0.013232071726252476, 0.02468392365582047, 0.036439853119513685, 0.05860896675937599, 0.10360959196282972, 0.02165887035399435, 0.028573505264977296, 0.029462649892534942, 0.07537662427151397, 0.08685677357378506, 0.031450607836426746, 0.0265861755131834, 0.03801350496829518, 0.02373814597846039, 0.0354540396872307, 0.01095328669649579, 0.019010533128053914, 0.07357214247026751, 0.05301297792503911, 0.038868570174541206, 0.07524252058036866, 0.11599105902977529, 0.02638956287785644, 0.04248582667881443, 0.033875228236279184, 0.014786675756406641, 0.05274734842861372, 0.08364213840855707, 0.059503784268012935, 0.020305420902948228, 0.03915714783473842, 0.02177466837418897, 0.041306097240697955, 0.009428286218955632, 0.04746638260962022, 0.08049201550743273, 0.04682128295122136, 0.03311571717682866, 0.018595472436338183, 0.059778170149412856, 0.08094959982460545, 0.05191350768830988, 0.08526532550252254, 0.018195731587888255, 0.027447921006129156, 0.03837196899938487, 0.032907938810005304, 0.02067711335727044, 0.03744436292758873, 0.043329864049390446, 0.04257001208081361, 0.04442310982173489, 0.01949723261678892, 0.06403447038704349, 0.03360978643139524, 0.0338043038162493, 0.07073885055198785, 0.05671888995434969, 0.1963628906636469, 0.17426313862444895, 0.17159391975691243, 0.16558527766216188, 0.22292423152154495, 0.12372947403139646, 0.18242542241369525, 0.18235949288693168, 0.1387401318718349, 0.17277127432246364, 0.1261727965527004, 0.09375187132747904, 0.23870924337496682, 0.0873539110104884, 0.17815530961078985, 0.10381638207623076, 0.3574481372150683, 0.20290252362047473, 0.18192329774460486, 0.10687140282243492, 0.12074766064723655, 0.11504415903360614, 0.0993021093909779, 0.2064161092763947, 0.20341479129368262, 0.13914634233280537, 0.16608344931756297, 0.1808809125495534, 0.10791257759856601, 0.09558171829989842, 0.2462400715317457, 0.18884554565433534, 0.19283015280961993, 0.11041908705186461, 0.10731370368551825, 0.1928582835581995, 0.27259133575904754, 0.1243923086252424, 0.11627030573905477, 0.11219928386591135, 0.13990519838708063, 0.13918702160158467, 0.07760508977357419, 0.0954839961242772, 0.12483808752750197, 0.18512661779119124, 0.16556284660773893, 0.08238563929954845, 0.1588351850307757, 0.13752952909036992, 0.06320241080116361, 0.09569476989488448, 0.1407106785524276, 0.13472026935027492, 0.18049013109937792, 0.13745791519120817, 0.15069131799522908, 0.08643566270268734, 0.19989653250142453, 0.1532089280625505, 0.24610812054766765, 0.12092557690677144, 0.13121483486986932, 0.13470864013558434, 0.1340443040094068, 0.17000191244146517, 0.15777943926232477, 0.07819483957944379, 0.12304506640160277, 0.12424669829347443, 0.31714520146769865, 0.21222012928656994, 0.09557032657246436, 0.201286522431239, 0.14800454039246808, 0.17032325568218387, 0.1270399391350727, 0.1206735033361662, 0.13599652586685074, 0.112227069874925, 0.11209012399758063, 0.20583961279161517, 0.16531924596957623, 0.09857983403508702, 0.18088630580854032, 0.17257247450611285, 0.15146903513420015, 0.09914132285742991, 0.18060279198952262, 0.14960931073273384, 0.12720301627151429, 0.21693852609924733, 0.30041889738171335, 0.1979691165709688, 0.19777616966635952, 0.2092332597221098, 0.17501206617922554, 0.11009709263641028, 0.13157474297669627, 0.27244611613212094, 0.2512294642867581, 0.16932594710059706, 0.07758432112994694, 0.19879875914944758, 0.1398116437297675, 0.18913000942237918, 0.06136447777070346, 0.1470808681821631, 0.10392505164828994, 0.1606864058562825, 0.1434414755673178, 0.17116100347090155, 0.17892202572716823, 0.0988387334490976, 0.11634462392858921, 0.18528783333397683, 0.2004458635084091, 0.13571514177226252, 0.06866890396321974, 0.1327286552517645, 0.1809417092872243, 0.16211974104085278, 0.16377053794360932, 0.12004556404727122, 0.14628045951887486, 0.15597828994354895, 0.12090058711868142, 0.21114616594727964, 0.1338878841770272, 0.12809995201326188, 0.11035184751475051, 0.1175084263987599, 0.15101745694635377, 0.10016011254441354, 0.2166722645802844, 0.13324734274177782, 0.1445867923358756, 0.2179846498033693, 0.10414294237571378, 0.15207294224491044, 0.13425867073237896, 0.12263605971970867, 0.150194188219405, 0.13428926828407473, 0.10505498537132818, 0.20199648675418672, 0.16384418963664965, 0.1496970890870979, 0.20326785562980562, 0.22308532449026264, 0.10674397941798934, 0.11013841541904597, 0.21089367868919529, 0.18576820110601766, 0.1914197542975026, 0.19921071526985015, 0.11602099008497693, 0.20765346384817557, 0.16268007307043, 0.1037612160848033, 0.14612529607069108, 0.1328777053183125, 0.12404119520778618, 0.173254246793447, 0.15668367306070943, 0.1534135807906428, 0.13556371683314924, 0.14097140891657722, 0.16698564042247113, 0.14767958121674676, 0.12501096292849512, 0.15038299824922316, 0.11802598773952454, 0.1580834995594717, 0.07626566164676221, 0.1095964924822892], [0.008641569462094096, 0.05837138374185851, 0.04078699989364513, 0.02657084992425817, 0.05807662375211235, 0.008727975561463786, 0.06322931197862472, 0.0653812223144116, 0.06020858898879059, 0.015449872326796815, 0.08427823653384563, 0.02270597273543958, 0.021446966603698752, 0.07254353153609461, 0.007079247096102806, 0.034116362071325707, 0.05966983382560073, 0.06399140475438007, 0.058000210312105, 0.03853375910811367, 0.08127935471073275, 0.029196706300060597, 0.04438070685512597, 0.04168159906722365, 0.033489989432235884, 0.01547660975296411, 0.04047643167958145, 0.10561974538910775, 0.013126896472737916, 0.06186334273567604, 0.04355861407314097, 0.03788505117559145, 0.023677017907762242, 0.014649515374443464, 0.02716345532286552, 0.030496213585138324, 0.044620446410150304, 0.03364948510763145, 0.035647660749213356, 0.03580197000936155, 0.03651915471099558, 0.04932202376245011, 0.08427133408164786, 0.053222851542335366, 0.06837748411682344, 0.138145892790729, 0.060837987675181324, 0.1254862591984772, 0.04219371735328629, 0.08353516955168978, 0.035567060638699806, 0.06422834042760153, 0.02414299280292565, 0.052371245223067464, 0.022232752563732288, 0.07621902987481126, 0.02617594692105007, 0.04192991880699993, 0.024542450198843598, 0.06702544618277781, 0.019040150087206595, 0.043723951168959184, 0.010804283552833143, 0.030874080708130237, 0.028997414272218466, 0.032927657913176284, 0.018836680964957324, 0.026695013624585928, 0.015798999661309345, 0.05142826376663101, 0.05795417608873499, 0.03149942678940152, 0.018019238336672707, 0.05118957375206294, 0.05978209251958517, 0.033908602856700464, 0.05364791925756201, 0.039742040643168074, 0.021440087134138714, 0.007218078507350819, 0.08940025443030943, 0.023078990521870797, 0.03153922314184808, 0.034934436722147855, 0.031204040522777268, 0.02625977800738427, 0.02003286214124772, 0.0387195392601913, 0.04007838388544418, 0.032906655612732136, 0.07199061523762441, 0.053928410859718445, 0.005547401622959203, 0.0746578422765578, 0.01433635012231647, 0.059944047337217685, 0.021467817601777857, 0.03794987370530444, 0.017948492032085216, 0.03937074463934668, 0.05168009218910048, 0.04810741051070152, 0.02517153095874575, 0.05832839088754789, 0.061124232597649104, 0.08960505271510733, 0.014900988523638057, 0.05834230304425282, 0.054392162184681625, 0.014369121448497378, 0.04971780776677113, 0.009118215962042733, 0.0157032051544276, 0.040478695469397696, 0.010982676702100905, 0.015973605463401448, 0.028092917242658236, 0.02420786321313391, 0.02534371305016741, 0.055515093864091945, 0.03189603050780152, 0.07951253379184393, 0.07177227251832524, 0.04206245584834007, 0.0699588428101232, 0.02080584868728634, 0.06289526700012146, 0.01598812474478637, 0.01146488021233029, 0.013666162999617237, 0.04966444208196575, 0.02719199401326478, 0.02875807499813457, 0.045239119865601106, 0.03673871551009436, 0.020635618204851786, 0.021188674314368158, 0.01238447587726818, 0.029630344623940128, 0.01790420257396275, 0.1208139272526868, 0.05792676929324385, 0.0216539750521582, 0.0034380821847251708, 0.020142087127052007, 0.03607263270344946, 0.010478784285125234, 0.018487467445553313, 0.02118849811414557, 0.021220622096030463, 0.04924962462316598, 0.061944639986200686, 0.04466690198187867, 0.057491344069280935, 0.069765014904401, 0.08641900795121348, 0.05079432217884929, 0.022665063640283003, 0.0765463792448563, 0.014879008503480545, 0.04466774467859538, 0.06704682769674448, 0.03676817925166219, 0.049509102433559396, 0.04943463485687972, 0.05765914030733609, 0.030624893373779716, 0.051187884528189904, 0.06297421619115819, 0.04603091003974119, 0.05170457252872087, 0.03856326498451733, 0.029786649543131073, 0.07117092414128204, 0.04588228132155153, 0.028011351861360095, 0.06214034480733737, 0.02810895720857286, 0.052871699820482926, 0.01964426021121683, 0.04680838586101609, 0.03532393114461053, 0.0715517541093211, 0.09386591883676668, 0.008445660670047567, 0.02796389271445092, 0.01685935440623472, 0.041300213685439485, 0.033091083619623415, 0.06060372947925522, 0.03169972430764428, 0.08165704371828227, 0.07366522981394684, 0.02295196548314585, 0.045725616341036175, 0.011241399915888907, 0.044757821296732274, 0.014545249850338986, 0.03528157414327707, 0.0021493595024015036, 0.04879248846742896, 0.04668532915773892, 0.0620740398974909, 0.1007839302802759, 0.018363546978141514, 0.01928732644075588, 0.03126447719912375, 0.057893241455237714, 0.04258944773145261, 0.07264072511104808, 0.036256091609116525, 0.061913249533503294, 0.010681135876614962, 0.0433371763586277, 0.03247067880546374, 0.028763989196910013, 0.013254518102433895, 0.0665143506240941, 0.010376709772484198, 0.052591235031403845, 0.01405974067071633, 0.020629008781285058, 0.037584250582562345, 0.045016670915027784, 0.02618496186069904, 0.06073332857340575, 0.02249850080378594, 0.053859317389827584, 0.042387506954612277, 0.018469479701091206, 0.034091747666318575, 0.09780204028732355, 0.04433964454238454, 0.015152465503272271, 0.019518819059275334, 0.029943446673813368, 0.0597570069705046, 0.12628351924039666, 0.040359273853321234, 0.04655737332218597, 0.04260056749767354, 0.0746273979424469, 0.029362522200831485, 0.07396321503385421, 0.04708317010813663, 0.027541519713497935, 0.06042922997186261, 0.038287427366500905, 0.08006312884390354, 0.05192005390962286, 0.06072418914446908, 0.11865249444400111, 0.027095156669196103, 0.029946526347268975, 0.030879410764863415, 0.02063294455799605, 0.03477016448854439, 0.027848899086576798, 0.02392141910780582, 0.059827808816466606, 0.00028844329555736736, 0.05146820759100299, 0.02724692826309512, 0.01756801637971113, 0.05212785908952356, 0.04908133808883929, 0.027039306944296248, 0.01336235168104571, 0.07214197122882451, 0.05145512280925628, 0.015675995626576966, 0.07836808270264058, 0.03592057191135903, 0.03355214214553276, 0.04355842638159952, 0.09425372786579594, 0.005723114422101889, 0.03050036003602849, 0.04364237046590255, 0.04757700953632594, 0.010245407090312051, 0.07216925161980814, 0.03437774361021096, 0.04682217544365314, 0.11600728477201155, 0.005102474035905494, 0.03045029044451733, 0.03225522040719948, 0.03596286379521893, 0.03169043357634256, 0.036800676701410164, 0.05283184792666186, 0.03756324062123895, 0.019861386765936212, 0.03691187436361948, 0.02593005951043339, 0.034885353468839204, 0.06305776190974059, 0.0366630528362528, 0.04531742937322106, 0.02957170633899589, 0.03513838847978942, 0.05198023394651471, 0.0074270682507044375, 0.028021326326134226, 0.021874993333532926, 0.050922293336160725, 0.01783481416022105, 0.06903415170287894, 0.05110558370248445, 0.011071107188810506, 0.009979668426357452, 0.018011008637146126, 0.05426402248802686, 0.0640323598148121, 0.02793773081183674, 0.09333780080440546, 0.043401512422508774, 0.022983327207546082, 0.02424432325267023, 0.00640103280837197, 0.04543705017215783, 0.01531484549970276, 0.052334867537983006, 0.006246011565259148, 0.003434253420921103, 0.029683055303570245, 0.011028555792666251, 0.013439643249336271, 0.05238584302846463, 0.04038407594986981, 0.03978750796147412, 0.014797563781030478, 0.011964448062973398, 0.057529771039562846, 0.03862514956704071, 0.04253283383384828, 0.021572859747515574, 0.034622577649931756, 0.02634360143283923, 0.09560035721909615, 0.03815914977401976, 0.014170527518276247, 0.020348796801220988, 0.07696221177015575, 0.009834525408223271, 0.04154139348576146, 0.04764743982964466, 0.08920477177467077, 0.036531243578440724, 0.01700076274573803, 0.01796637252423792, 0.24280831938789738, 0.17368979842191742, 0.11533633730704747, 0.09042813758095426, 0.145129335803851, 0.08555619376561335, 0.23401811929239383, 0.11317452911527888, 0.1362764850378998, 0.09924605473755829, 0.18102927313696954, 0.19951555697667986, 0.14735158833284534, 0.18461614276372618, 0.11977325809458572, 0.1239357815094052, 0.25858194717476446, 0.1520053732899889, 0.17801338416193763, 0.14463614371995773, 0.2510864509930534, 0.1169068098909432, 0.18553451364559514, 0.13558152071650953, 0.12871976310928024, 0.09298549228978735, 0.125207242315575, 0.2361650194131559, 0.21204861752208204, 0.2499899953123062, 0.18135496775709814, 0.17459684652426552, 0.11192876289808944, 0.12395897099087316, 0.13933823203607915, 0.12513195119437673, 0.11522625813320761, 0.22784129025474673, 0.14500427961109147, 0.1355667352195709, 0.16350674322776257, 0.13523203140545276, 0.2210290832144599, 0.19667415218728204, 0.10677488340485482, 0.18399240929753552, 0.20066105760633948, 0.15249966854049316, 0.08148420662168535, 0.17098389926456636, 0.1393656426620099, 0.17880884389723503, 0.07575081225724951, 0.17228876150423483, 0.21855193791129898, 0.22327500786031448, 0.15710027167393317, 0.10027187711168682, 0.1566820029890345, 0.12613289869360386, 0.13739339526622527, 0.12220427724382571, 0.10428887446440997, 0.1712796398468556, 0.18654311436318582, 0.21906153959853036, 0.10294972212925073, 0.1119113420586913, 0.16290965429957838, 0.16486553805730036, 0.13631071384635665, 0.18513746559619906, 0.18736740964795315, 0.16814329120660984, 0.21556327570109599, 0.2353951470145295, 0.14000025457672535, 0.09879778604954483, 0.1453856381797983, 0.14446092408991631, 0.15836086935333668, 0.09479988726877397, 0.16394989444844185, 0.162141865660106, 0.17339442556183185, 0.11934352107346059, 0.22915684708183814, 0.1265427480722147, 0.1470392389643577, 0.19075016280816448, 0.1680088274541401, 0.1018069028073261, 0.20579361687264136, 0.1676357732785325, 0.04551224553236558, 0.155086548277928, 0.19544263520548422, 0.23178603019445176, 0.09956473965317973, 0.1449003368015251, 0.09471781626944581, 0.1345678484968601, 0.08738203409818873, 0.09807632274685368, 0.13120020259051554, 0.28982028545391175, 0.11622194260839494, 0.12357743622194375, 0.2978012362314809, 0.10484289392949113, 0.19901553138850198, 0.12276513021319144, 0.19326124580637102, 0.12239169299362168, 0.10387108075402438, 0.1533924827292081, 0.11237930686723803, 0.22032586046524588, 0.10739842534906442, 0.15418074123801725, 0.1119126137646456, 0.2504603732978144, 0.242682037454459, 0.08071500838043229, 0.10218754125338408, 0.1352861784999409, 0.3368809747119104, 0.1373340540956105, 0.11307283094333065, 0.11149744007496104, 0.1818360403300293, 0.17552280167658485, 0.12701501063401663, 0.2154124176670467, 0.12205103667633188, 0.126977855369689, 0.10340560573123156, 0.14255463686441222, 0.19870955587154437, 0.1042251129664721, 0.19331288013246753, 0.0957206330232082, 0.1311812802187858, 0.15975640575972297, 0.09561089858893426, 0.20004492373235766, 0.17365786787723342, 0.19460127148176395, 0.09636831439791188, 0.08312357349261161, 0.0968716954511981, 0.19574562297953715, 0.11704079866889985, 0.1206249486835253, 0.19889664986441213, 0.1897846468754353, 0.18068644879085405, 0.13980623514902207, 0.13960832399466347, 0.12508336589821886, 0.11422131165501573, 0.13458116310498408, 0.12377264308592967, 0.18999106160575346, 0.21412799465319804, 0.259105185227048, 0.11962513499442609, 0.1472540959836014, 0.21687282639886105, 0.16061906672773824, 0.23881459578631387, 0.2969825946755948, 0.1511131413280964, 0.13310860421869064, 0.1486208581275517, 0.13936558137497596], [0.08074257988482714, 0.021269048428944042, 0.08166396149223851, 0.030288896786289352, 0.047670805511335214, 0.10853018236136246, 0.08741106883051895, 0.04349710487370049, 0.03702396451826057, 0.028863272276676954, 0.03417018740888565, 0.006708121068039609, 0.05991246536253922, 0.05532484358897614, 0.012298740104832237, 0.05272099500401847, 0.04630153442943289, 0.07179509427758955, 0.1048612877005531, 0.0273089928762807, 0.0744884985408956, 0.02748327787905451, 0.009745508864251597, 0.016371653257538716, 0.03483866040985431, 0.02242800156255403, 0.012511119787250797, 0.050599383445636886, 0.025731343963754275, 0.07779064392971416, 0.13496275150006817, 0.042704464341964454, 0.052510362959677176, 0.03586406909650372, 0.03898257554899301, 0.054990894371463414, 0.02929672865467447, 0.027438444498505805, 0.13072803195926452, 0.014820042715948677, 0.05156060928599008, 0.0381688752602185, 0.1407379359607735, 0.038609448595032576, 0.04180922931540878, 0.0645439878046032, 0.05321991359514575, 0.08780556580712719, 0.008485650459695007, 0.026826449414534916, 0.07777512298836824, 0.03930915117023453, 0.03371917229566363, 0.025495503796264533, 0.008690013989595877, 0.051775535253146966, 0.021158544076306206, 0.03464326585432695, 0.033662481789266875, 0.049508140993214426, 0.0235378771885148, 0.03630035616938145, 0.04834030123968278, 0.09578343691124071, 0.06132451862457299, 0.05450719794739158, 0.0784083023186653, 0.06853197340763385, 0.09407230292356784, 0.021071428387996652, 0.005323213173992812, 0.01938063020427381, 0.0433155382052064, 0.02167948578003674, 0.046213656483638677, 0.028554964021989898, 0.08478866559603522, 0.009007092035796133, 0.032373761022163015, 0.020028202411448284, 0.0344260914191123, 0.019998907209223798, 0.05443696300649355, 0.026159190662926244, 0.08468830041707524, 0.040996647515003724, 0.01994299811250981, 0.029780861748863133, 0.09065432504059807, 0.04889793663976654, 0.049032917501585144, 0.06041859284103398, 0.021457486906118935, 0.032689197724985505, 0.0437042856919429, 0.03869680560103828, 0.02250041027793721, 0.026439921667559013, 0.04035692196339369, 0.03289997532603241, 0.018662173796685475, 0.03548128177381812, 0.012419707303295934, 0.08121430618508209, 0.014201648882590236, 0.030677671086103208, 0.020276615996995283, 0.03469249466434121, 0.023989817352905392, 0.04253340839979149, 0.04576574785694961, 0.03258714332215248, 0.05961290966238707, 0.05308775959776775, 0.09504983877582897, 0.06636821169165835, 0.062116756960148775, 0.07271722665116673, 0.09227650089850349, 0.0261128289369686, 0.06423235472832477, 0.03050123146104236, 0.042369082540033326, 0.034589907830400814, 0.07609849360080496, 0.09831196373148311, 0.02990242841112758, 0.02823449412150489, 0.03103382727732101, 0.06739791813156298, 0.02791773400179321, 0.015720273593380567, 0.0571755396442548, 0.04540991150744019, 0.09628402940448254, 0.03695834908754595, 0.03265610655709621, 0.012518655219596001, 0.022733214822026993, 0.014726849077569862, 0.08674697019159795, 0.04718729677880484, 0.012164955297785421, 0.03659771702763054, 0.03402872544322764, 0.02902376003593447, 0.08181041452072321, 0.016162176090743274, 0.005793320634702762, 0.015697570577744516, 0.0317863880040785, 0.044730445144758116, 0.04897874742445927, 0.05229637928066715, 0.009786051194814425, 0.055619178399924314, 0.04597145395593778, 0.0450121816397915, 0.020450722884326693, 0.012209693874953496, 0.0816089793619129, 0.044814737799066695, 0.017523012544599273, 0.0418806785056668, 0.05992701720266093, 0.045794001179597074, 0.0698618943833055, 0.06539738676961392, 0.05320659515658214, 0.014204680675550575, 0.09013254255537065, 0.0798343749897134, 0.06058590644369684, 0.0781351383475046, 0.007923210251911153, 0.08441989385192433, 0.037453682387187597, 0.07335216798368963, 0.04153802269889463, 0.06392216189734398, 0.03376705662137078, 0.06058504459478202, 0.03335536480130207, 0.04605377776428096, 0.017266214126721025, 0.046098279811802416, 0.01950076045168023, 0.02870121020673504, 0.03499682309226163, 0.019933644178954345, 0.011810146463704447, 0.059614648681975184, 0.026978849200531844, 0.027603300874151533, 0.034074713701322194, 0.019586209898754474, 0.06639935316578036, 0.07597054925657089, 0.04053958796805913, 0.05194954829470766, 0.033872202188978275, 0.04973030266081614, 0.018793207390474218, 0.013733668752285022, 0.07456464768056908, 0.05064654764869521, 0.09127287975242061, 0.04544030987627564, 0.060903825271393985, 0.03592740924608323, 0.02925180142835504, 0.10424208947487416, 0.04526655347416959, 0.04547007239213394, 0.09393495868050283, 0.03832665489866369, 0.13554857893576547, 0.006966287431667649, 0.02736882817360663, 0.08319051425543525, 0.011381189894652175, 0.018627073563214754, 0.047504288640113614, 0.037287686455754504, 0.006214821731836926, 0.05093666897605985, 0.06504223606879674, 0.030388570570897673, 0.039692620311172745, 0.04594531503596133, 0.04380704106522664, 0.04152367004163323, 0.06664394205736537, 0.006944210692909697, 0.01919254412754409, 0.022424354984034455, 0.08188726846128702, 0.0658402698595197, 0.05503000315999793, 0.015168062095800716, 0.028969643584963296, 0.06174105978120239, 0.04139025582961979, 0.05042191917797731, 0.06866843664958593, 0.02873133661435737, 0.028384480730540333, 0.033207318309934876, 0.012342877302979751, 0.02904430076840424, 0.0298805968205054, 0.0824954656643733, 0.035422691369369146, 0.024985480760674805, 0.04229790148054881, 0.039701208156803926, 0.03766854706731054, 0.04189520353271116, 0.03704520813640087, 0.03598510715810042, 0.006890694184544226, 0.021712490763034553, 0.016457876453416485, 0.02760449980175303, 0.11646863824177174, 0.001475141201104458, 0.05141628598193488, 0.1405532015187125, 0.06669713154194817, 0.06230946637750153, 0.06063062299583709, 0.03389969325414108, 0.030743734678253535, 0.04547707443576186, 0.06339290239397558, 0.05575830762785289, 0.007686456045766752, 0.06943310731120649, 0.02139957065904333, 0.05245408997119916, 0.04865806684979508, 0.04030128482789282, 0.061502902197741696, 0.010630291578690372, 0.025891320359322335, 0.0575285989250387, 0.03688530643440543, 0.1132771542536155, 0.0790619132139029, 0.038984329890339606, 0.017733228986241648, 0.07412911137385715, 0.038463750163153294, 0.06347284749931385, 0.04578574275177333, 0.04165108578519956, 0.028243978290007483, 0.052874308349865104, 0.015217342616749868, 0.052873986592936906, 0.036952308484263, 0.032059783716836286, 0.06275536402338935, 0.025319184830051758, 0.018126034823757027, 0.023887598241168647, 0.050250055013044234, 0.07447473194089628, 0.04441420021917551, 0.041536000226774526, 0.012306902771665445, 0.05219896737065527, 0.04623829387128354, 0.05062523891308135, 0.06641214683411584, 0.02874228975645477, 0.04794786503959087, 0.05020831471248981, 0.07504729073374503, 0.04334924607387474, 0.025717935509859555, 0.04262083435371038, 0.07566914728452122, 0.02226518298078689, 0.014193601128945669, 0.04356540927302934, 0.03891748871894614, 0.03472894512777848, 0.09349490245503765, 0.04686223801165339, 0.03137123729703167, 0.08593751402992396, 0.11304316035802327, 0.04981081850165802, 0.03174707237180443, 0.008060261945150072, 0.07823702038055466, 0.09057246088500946, 0.03276514768179867, 0.04008253225155416, 0.009483028946804905, 0.0613842083651933, 0.042645536858828804, 0.07053907780397324, 0.03315902029674861, 0.026346211877441215, 0.02025343034596693, 0.0555006071414438, 0.06602809929679479, 0.05539988190115941, 0.048989985934308464, 0.008641802161301096, 0.22219439487784143, 0.11061143640789295, 0.12002776782479017, 0.12503276579082012, 0.12707828183568295, 0.14222479004773403, 0.16366251954628577, 0.13257965115049195, 0.08438233256099686, 0.1660344656556845, 0.10531531736975717, 0.10511210488696253, 0.2200395274426668, 0.154968892494517, 0.10569523569316634, 0.13251099435071792, 0.19353984134091487, 0.14648745647601544, 0.2835600907283445, 0.1227156715767999, 0.1881786507944907, 0.16112172765837562, 0.09534771674342694, 0.10781103264420264, 0.09883963743284827, 0.19828826880022404, 0.12556024030932497, 0.15168554690336028, 0.11580460088988466, 0.15415644092905909, 0.35569057829918405, 0.14582892729630395, 0.13379636731359268, 0.08888477684869882, 0.18399947262819738, 0.3810394164775649, 0.1432454489892529, 0.21942305648999832, 0.16650416948381933, 0.13887505527705918, 0.18303004964705438, 0.19834361099187406, 0.3225384604546332, 0.18529760861589065, 0.07291197386239806, 0.2141167791259866, 0.16513166168043691, 0.18358659720228565, 0.054902541451156146, 0.15604354531293915, 0.10390218392375017, 0.17846427287065214, 0.18580299681953846, 0.11314726404605374, 0.09197457798666532, 0.12856562621891499, 0.16134378590410756, 0.10047313607027454, 0.1327300495317867, 0.11815911849900601, 0.15167483699417886, 0.10355910676861964, 0.14724096523657923, 0.15590698247955692, 0.16211191162226662, 0.23038476345039186, 0.15617865257926528, 0.15011954061206312, 0.211492866698292, 0.11583296912572077, 0.079743241170241, 0.07420329166756523, 0.11008704156284371, 0.1424907757750442, 0.11008678109294946, 0.11829873802320612, 0.17619928795724146, 0.1290121635482196, 0.13003371115173065, 0.10422423962623843, 0.1256122193749874, 0.17032730062642407, 0.1547273143284744, 0.1303997939272273, 0.10976014418467399, 0.1993061698252155, 0.10058379747093686, 0.26266154923265983, 0.1668969887278734, 0.10916293268242191, 0.17692419099471263, 0.3450318437910849, 0.12474353695588729, 0.11295453164606326, 0.13823232283034634, 0.13197765925959234, 0.09420157259991092, 0.11250345141536768, 0.1808570565715913, 0.12449661915701245, 0.11425060685724021, 0.17647187736245895, 0.06752137320056077, 0.14161605658310075, 0.13647674042130672, 0.10315040652189525, 0.15420789139405375, 0.09585849054518247, 0.10808431918943122, 0.2793999268643318, 0.10367644079510244, 0.2661293841177418, 0.15741324923451872, 0.18088129559351554, 0.34481099596427334, 0.210518142388713, 0.11957674888112854, 0.1023031592429165, 0.14789816142330248, 0.1413566438901809, 0.18296779734232735, 0.10819251378697735, 0.187227537314738, 0.32194226018844113, 0.12060905235909647, 0.24005395750845634, 0.12704019960496696, 0.08327075430462438, 0.11027230460557247, 0.25991680941754775, 0.09812637893182617, 0.1336264030467118, 0.16002493489894176, 0.20088064904895522, 0.11581484348543229, 0.16143020062196642, 0.15808587443203698, 0.17250724978023962, 0.2841998354321526, 0.17159752037015655, 0.1976611185818911, 0.1268647961138237, 0.22680226052480362, 0.17413420602679255, 0.1716793232387112, 0.14523019893996178, 0.21263769317057826, 0.10022120039549567, 0.1830813468944642, 0.06359273259858451, 0.18461750640023142, 0.13040239862616987, 0.21076013424223472, 0.1710938482034591, 0.09963350370526315, 0.1487197754003348, 0.2364480429359021, 0.1885265926079404, 0.13289167876205138, 0.15857207979406082, 0.15184189012694746, 0.14097695539314903, 0.09881536776740706, 0.12902820542935403, 0.0907707857268472, 0.16678414397662686, 0.22054581963006528, 0.1820849882619035, 0.15334855524762986, 0.12008743075233315, 0.31188711103412414, 0.14031318617203545, 0.20088846314578288, 0.2278875313218563, 0.13933703693891727, 0.23378217953347394], [0.07358855973448485, 0.04544006472813987, 0.023652660142209743, 0.04630120118118582, 0.03765570360325998, 0.06058007268415344, 0.04682512871260124, 0.022398099235649553, 0.061905037070955, 0.06374651325806495, 0.046939900174977324, 0.05511004402632675, 0.0730420938963371, 0.03879996317048227, 0.08757935536484565, 0.05304184794846562, 0.042623098143526626, 0.029085613974940874, 0.00905452628484777, 0.026148595666933446, 0.017696466341975237, 0.007450149522253102, 0.07117422598023569, 0.0384438663510786, 0.05950171583061738, 0.03668411259329127, 0.04557471617215103, 0.03589881118386984, 0.022619806996156133, 0.029242801810464555, 0.030053410934464588, 0.038827691722901604, 0.022239000010754795, 0.034188389657966556, 0.035132999051242106, 0.04605354793790368, 0.04578282395678182, 0.048607746364488724, 0.037578570040603804, 0.059015407046723756, 0.04493413260206581, 0.019095904051115917, 0.04635065598713775, 0.015877599324730617, 0.05696034554632441, 0.0478029748304717, 0.07507032699762814, 0.05349297797487629, 0.04701970355404962, 0.012787957150008411, 0.04499880191419394, 0.05100194349764817, 0.07716837369145886, 0.04288646768057539, 0.07027590361934516, 0.07513457879183755, 0.0166023644663754, 0.03126223639194523, 0.024236625984251022, 0.06238845770337409, 0.04986292014138834, 0.06690851052201564, 0.020416061236192624, 0.018197240781099088, 0.07042866155144668, 0.03929764452961184, 0.06579605892540948, 0.054936766429173375, 0.05191709681023514, 0.04430972497850176, 0.04670363099824998, 0.022273054534208872, 0.06905596988696246, 0.0588211577926432, 0.0446687865581724, 0.013233071470993662, 0.027781885545400363, 0.02562859816656959, 0.0853640589142038, 0.049469537822709936, 0.008143405467572232, 0.05048921617168573, 0.010324103472333764, 0.04662028829296751, 0.036588248180886435, 0.01599764913290499, 0.04661679110159317, 0.027005166235950687, 0.04987870155262852, 0.016429996598632108, 0.017154635335769386, 0.03194441470587927, 0.025907542271118973, 0.0073915533721447, 0.02919040522688339, 0.0910637837143675, 0.06825504794476495, 0.04221542445462077, 0.0464084190166285, 0.0194919140513746, 0.03453407151203963, 0.024274382627599185, 0.08240898965948051, 0.06649516012159086, 0.13663175065190564, 0.04266111525676904, 0.031323839437156435, 0.037112141238345255, 0.06552979740644656, 0.046157172820981474, 0.02717634666741135, 0.032096268654230146, 0.024155999060660124, 0.03587078002672042, 0.05353157731494116, 0.028307467826732227, 0.020813325705427318, 0.09825096015007266, 0.04183184040049392, 0.12119092678110446, 0.022641939276288596, 0.045020915042128296, 0.044936227852538715, 0.08493279737810935, 0.02308558079323942, 0.012692837758109936, 0.08611988126029892, 0.020444906361761595, 0.027291987639581485, 0.04597450681631604, 0.03561676442322712, 0.06970041070974643, 0.03955654777406205, 0.06133554262980338, 0.03696730465538079, 0.05852104667874594, 0.08139339455914113, 0.0030191261753169524, 0.0037278683486229353, 0.012362731429147384, 0.04715194948197854, 0.05000879860392982, 0.07492648632896524, 0.013150598275505248, 0.03756852279747686, 0.016738281870681434, 0.11717907753923248, 0.010029016937609884, 0.03130418545145902, 0.04154322060546087, 0.045130894624538, 0.07547692816344, 0.1255187413264667, 0.008805089014311953, 0.022034088727988062, 0.03724137644073175, 0.07126857736899007, 0.08842297904794255, 0.01737701916886914, 0.025561584625393156, 0.03098490873291608, 0.03010735884609242, 0.02005381081553717, 0.035016749039172165, 0.141881981023377, 0.07702021228690302, 0.0172579231401605, 0.026795058961837526, 0.028794663357398206, 0.020039766508665298, 0.042291604237811226, 0.051067524454406196, 0.06586468508166653, 0.03853534107967731, 0.03689452630257414, 0.03104108979084319, 0.017746059043753534, 0.028519969125608766, 0.025486988728986155, 0.03289448630605494, 0.015152443478244449, 0.012153633475874462, 0.038072014933512095, 0.027731881071362766, 0.028783934296018658, 0.057346147424992056, 0.028112082847303925, 0.025656891708833077, 0.04330595061483403, 0.02117470278584909, 0.04062210329838338, 0.025065513966124386, 0.020991203660566, 0.03409052575607935, 0.01550970187846331, 0.00873075933345864, 0.0122827690868308, 0.008215677244738947, 0.014949848653838761, 0.02620615185268464, 0.002016940725884671, 0.017528829067164374, 0.04924607763607656, 0.08270173483798582, 0.029833172147552815, 0.07005091891774247, 0.03571496923424063, 0.01797961626922892, 0.12935517175543693, 0.046392695061982646, 0.03266737954090199, 0.06064827749205213, 0.04355696315366415, 0.08844545606764094, 0.0663028797134757, 0.0759753832713731, 0.0417683010680541, 0.04379263478181055, 0.054930358103686766, 0.03904895706763191, 0.021187492623744954, 0.02555965599904378, 0.0877075448572155, 0.023164819182467558, 0.08692082618513415, 0.02266825822692725, 0.0807473143081992, 0.028635309408268625, 0.10135883330217293, 0.07499826110659108, 0.04663077986709053, 0.12423354456381452, 0.02977203067031599, 0.019797586963602135, 0.060601829581203005, 0.05054330580957955, 0.06279613522271957, 0.05039211452728318, 0.030168963806523435, 0.026773782784960447, 0.01838836631166839, 0.04125048308783481, 0.0633663306343219, 0.08215433437257044, 0.04476293110318723, 0.04719542497168145, 0.0437624509175939, 0.030153885280953783, 0.06666646504233922, 0.021314691947472673, 0.024282886203558698, 0.07908553170460848, 0.04052749143973474, 0.011121604831949359, 0.08755174555605458, 0.06209143009337206, 0.05171981384797443, 0.04143434418966213, 0.006195727947934141, 0.00902715970897266, 0.009493218873807741, 0.03086412156511459, 0.050997603609557116, 0.033873493047130686, 0.025219972613417817, 0.030145912220881834, 0.057362806006905534, 0.018243401408976605, 0.015927836497975214, 0.06694519081183019, 0.029170063677273934, 0.031018405927405245, 0.06625756561275452, 0.034800815666394855, 0.013125223528233268, 0.026742783037104437, 0.013749834165097246, 0.020066631296950004, 0.1866795546225002, 0.05200417036370886, 0.01980846924256654, 0.015947501974991493, 0.03475439456862307, 0.022033684616608006, 0.03318354660164445, 0.011278071587214307, 0.08136257484194734, 0.06133971014811147, 0.04030005525677435, 0.006986411603828593, 0.052323575401979114, 0.006030563221898892, 0.08009613957256079, 0.14263815576991729, 0.04677598800269827, 0.07365427475662963, 0.05624017310178569, 0.020236674087843107, 0.07270318425951466, 0.023110534192153045, 0.02658243317367329, 0.04904610953564125, 0.012143008793974596, 0.03763450595039514, 0.01393895158769503, 0.03035737547062097, 0.01926378072840312, 0.03912849997680995, 0.04412877884122633, 0.05875378035970273, 0.02329087128952867, 0.056958962757621086, 0.07756218884981449, 0.03163908461799785, 0.047232607049086404, 0.03847545215619668, 0.05095218991740577, 0.04227950770948683, 0.03979725259987097, 0.03902405537965317, 0.01351033018210963, 0.05178814122994101, 0.07316585540050462, 0.045680122209652785, 0.07613194099957905, 0.035500548885113774, 0.11570330108365706, 0.06853238709511296, 0.0281949965433488, 0.05706988462817766, 0.04529582569375635, 0.03913875789411607, 0.02540028672815571, 0.05699791449813112, 0.059858540433549115, 0.037913775642312346, 0.04023186194019453, 0.06962203991509254, 0.03109968211051197, 0.01860633173266486, 0.04171642159382182, 0.08331275124463343, 0.04255464435705254, 0.11487555074235124, 0.026756825428756497, 0.021558265772558028, 0.020023094520213145, 0.029279757891931844, 0.007309525944067226, 0.04862410617211173, 0.08424248321041947, 0.03309501365067498, 0.14173529050763578, 0.11953775500578266, 0.10999907934737783, 0.14833630242895696, 0.19085933033737446, 0.10781989628148657, 0.1882441513120167, 0.15600078228500583, 0.1218546883413388, 0.24950628739691552, 0.07241782416859943, 0.2025571865059676, 0.16708717771595524, 0.11179105859370002, 0.22251442044733033, 0.13151671947731128, 0.09551118458470992, 0.06790336762224475, 0.13760345657506298, 0.17518722452223304, 0.13462760335495397, 0.0926069912290381, 0.06565724379352986, 0.12527455846148153, 0.18266860936437884, 0.13720463120168255, 0.10951071361740751, 0.22686259760971994, 0.125433498723132, 0.1240913816277058, 0.17815382340021674, 0.11226352033836227, 0.24656938208687693, 0.12406028611885926, 0.1321697634674849, 0.12936310842633247, 0.2220981589127933, 0.2612955531766338, 0.18279443164506268, 0.13341375236069003, 0.122808720616083, 0.14427876370328088, 0.2242778322749561, 0.1618819626709146, 0.13326958993509894, 0.10746609389541611, 0.24014331400394442, 0.2174766415790204, 0.2626910282959861, 0.14287964200540898, 0.15230112919403663, 0.14001139349514438, 0.32210313865254003, 0.13006577959224103, 0.2649437864461253, 0.25113523547207156, 0.12492153748509385, 0.07644295737507843, 0.11374550210612436, 0.17638092740408837, 0.1960674258730104, 0.17206189222633841, 0.0947235389462402, 0.12598063105777388, 0.13743051988703592, 0.2767173933886713, 0.10958481730232317, 0.13648703664300904, 0.14656729815948397, 0.1408216387273804, 0.1216714554316094, 0.18950919230138102, 0.14425576574379398, 0.15293342752322076, 0.19119656224164272, 0.19159506585809494, 0.1070624728116297, 0.25150920895318835, 0.1780465404473005, 0.2707290373021557, 0.13125713824504806, 0.1610490259143614, 0.09714485176147954, 0.16016345891741016, 0.14607465765889616, 0.16126143145224742, 0.13577771583391776, 0.14708653723280277, 0.13776344637716972, 0.12214192534766852, 0.11385969517211761, 0.1736989914770088, 0.07895286825876083, 0.13529963100389128, 0.0846818499567528, 0.1372522052617804, 0.2023781977233387, 0.1405509645419736, 0.11769687636725365, 0.11553906715444981, 0.17214251531948968, 0.1340421896067358, 0.3051706343408554, 0.11518354873142897, 0.25036490342069057, 0.1176616822880122, 0.2032464664549597, 0.11853135296053464, 0.19963874391490416, 0.14480085262367803, 0.09655098806345656, 0.09813500508185356, 0.11395448323098883, 0.09367782892959733, 0.19079546924800644, 0.11212546363352768, 0.16078236602967785, 0.2086810788680469, 0.14193343148837168, 0.19250261957847303, 0.12608879501180303, 0.11247604845031617, 0.16160142127304308, 0.1531200465415755, 0.0952479491130479, 0.1238767237913224, 0.10803517464908863, 0.1378974198333679, 0.15625417352684084, 0.14631189976728734, 0.16567503252337057, 0.14069437620139894, 0.11662728739001098, 0.19294828356754398, 0.11582815043267705, 0.1309182209473464, 0.16741795915990107, 0.15086031699132535, 0.18225679113980264, 0.11689216228983096, 0.12037669789166221, 0.15039729344989025, 0.18020271023194637, 0.15233675228251567, 0.13699656172144797, 0.14979396856600238, 0.22105670834500946, 0.12686518681866507, 0.20030534766133756, 0.08908824214050848, 0.1844369394764785, 0.11765132477927594, 0.21158323442984014, 0.19210741014009525, 0.19340687912077675, 0.08359130847478106, 0.20539957188790847, 0.17885528414720492, 0.07408090146078218, 0.11215584668060465, 0.13780378856726233, 0.10685754429188468, 0.11297382173999665, 0.08868299695032258, 0.24496090388105762, 0.13670572410187415, 0.11038116569961272, 0.2608021619098802, 0.16544421023178488, 0.09165095180393228, 0.10868275643236215, 0.11134947785326552, 0.10933295057545747, 0.1764006771507763, 0.14119435582430134, 0.13823702661020143], [0.027774917975729032, 0.050058751367032535, 0.02169570960705319, 0.029383181676929517, 0.021712544389189254, 0.01464858745044518, 0.07832777115606493, 0.027552101302952058, 0.03130068059920544, 0.027149349728959705, 0.03414251248262102, 0.03731494003366079, 0.03563003689651528, 0.027209033723920587, 0.04161764604730472, 0.0394910357652172, 0.03642190750988741, 0.019454546197648012, 0.04269079350295567, 0.020943914968219977, 0.051257426159516464, 0.01853004469716501, 0.024597206333231543, 0.01817370464484538, 0.027814848393562342, 0.06006404351923735, 0.011640889870543635, 0.022138485444649574, 0.022874243948007786, 0.008204342016289312, 0.08461965127818047, 0.011303102552530267, 0.05779608618468047, 0.07443389945453213, 0.08121656614445871, 0.017697291801713647, 0.06914321964065875, 0.06940611803363408, 0.0862040666622981, 0.05455918850437288, 0.05020352283252343, 0.02231787067777928, 0.031913074048896956, 0.04634578366793933, 0.03378623180211552, 0.14610842681459843, 0.05420940424946528, 0.03714113000540003, 0.10147457386577323, 0.060140958746835116, 0.018300616685601494, 0.05114637405401276, 0.02719662309954724, 0.03735291884250699, 0.06280465028999795, 0.010496832359011376, 0.03668519277726451, 0.03884703927342931, 0.04725043391508441, 0.04420405081022651, 0.0651250961386869, 0.02283136792210562, 0.041501292613365, 0.03367771161720157, 0.058736750225145976, 0.051498697890389356, 0.06878382481274105, 0.05662782125235085, 0.01936689041735184, 0.025940304021200827, 0.02999245331832959, 0.03251540684892285, 0.025791732759605494, 0.013586242792136488, 0.0728616342248936, 0.04545419521990322, 0.026415385786564122, 0.06262365052656782, 0.02145091770216823, 0.009955139248631895, 0.03555813954482156, 0.023168848804949273, 0.04794852004476613, 0.07585552115474017, 0.056798306459020224, 0.05947912772816997, 0.02998909593800143, 0.011870642511865065, 0.015184302202185557, 0.01420874572959879, 0.030650995904579762, 0.04607428593801395, 0.03602924148341821, 0.03321638496051873, 0.025164764487154545, 0.048741512976947336, 0.11515990725808567, 0.055756365594964837, 0.03875626168484169, 0.04560644370353511, 0.037151958658209736, 0.06638814529944813, 0.03904985339050332, 0.03105199505244532, 0.02158309851262358, 0.060527591830900604, 0.051234903174542615, 0.03958474747055481, 0.0634787080719346, 0.04973672630806124, 0.04599164803362182, 0.05949344208103515, 0.07294067917692085, 0.012023293191657193, 0.0015690543636259053, 0.048192369661504225, 0.013358444632631878, 0.03037378698917887, 0.1197856380754421, 0.017836557010248784, 0.047053196918099165, 0.011062261746114781, 0.03684325203780205, 0.061605128970357685, 0.09264471339842967, 0.03993114944727671, 0.021555117151189237, 0.11284098209392641, 0.02560096154470117, 0.05067819474084724, 0.047643655355298714, 0.07134483376097295, 0.033433130386495785, 0.06292050576678689, 0.011380790571321645, 0.04424853370554986, 0.01277326358362071, 0.07849241877275129, 0.021907077095801794, 0.039345873594884916, 0.059754750841567596, 0.0201972090684238, 0.02969131181617418, 0.0335833449066887, 0.03133777649171891, 0.023219347405698032, 0.05581672949295852, 0.06310253591847516, 0.02441435838268409, 0.019448599440135786, 0.022904552301512133, 0.03550016967159125, 0.01643809414799175, 0.07008246641846434, 0.04749794543210057, 0.01210059816648643, 0.09106158504202481, 0.037496441584681316, 0.02666352932611781, 0.029390850217051567, 0.025930072916972063, 0.1125338268015654, 0.038743831908270236, 0.022986870364195878, 0.018814677004552176, 0.0689984749882452, 0.03967193976765679, 0.03896890470998422, 0.05154457889617451, 0.02272927521487638, 0.018831569243282564, 0.04245742779946135, 0.03684718972973285, 0.026438044752144528, 0.01934839322442009, 0.04154732683673502, 0.01924580639047969, 0.03445691879718535, 0.039736980632428205, 0.0629772269167006, 0.04097184158801552, 0.1268628655722545, 0.031960684498171174, 0.042631092271016496, 0.02219385827981657, 0.01908498729819492, 0.01917501795105636, 0.010506808739005318, 0.048243299186710394, 0.03110571696813549, 0.023411781031398043, 0.031430877241936904, 0.02879648473143818, 0.012424406295101489, 0.035643148491339344, 0.01623900321822974, 0.025491627391367674, 0.05561260536553399, 0.021294532343745235, 0.03183109881055932, 0.043365134737424316, 0.08551200581414085, 0.03803339644124912, 0.06033246923658637, 0.00979574891032591, 0.02125120432596774, 0.0167829831010632, 0.028874637191033656, 0.05068890465002868, 0.05476499419479121, 0.009335631714953531, 0.022641876074034843, 0.06881570939214961, 0.019534604300955133, 0.037391127477730476, 0.009707283949659718, 0.08470719980616724, 0.019176034932775844, 0.028804442469751643, 0.022058421595683022, 0.003956759380432026, 0.047096388955270095, 0.05095833011211888, 0.04661749207204388, 0.024215437907485232, 0.08955038468083067, 0.004369063592035203, 0.05614661844447256, 0.04354555610447161, 0.01688469659476992, 0.02248298560809945, 0.02451884128423708, 0.041504399099897955, 0.031216378368797804, 0.09925529375792512, 0.05861769250083355, 0.02183364182260008, 0.022583323973982085, 0.11545744814699697, 0.04377472364614087, 0.03280024600004958, 0.08734441918110655, 0.041511899100676666, 0.02921733896308128, 0.045769509348657825, 0.03378493711352348, 0.02750378988322712, 0.03290657900393971, 0.03609982882476142, 0.004963868141790191, 0.04280027512821459, 0.033024974062197635, 0.011621047235694865, 0.07285275526585118, 0.020801183211827473, 0.02287736575629923, 0.019236130699996027, 0.046236784678072705, 0.021781729789631023, 0.02355008671480802, 0.029160949146194808, 0.046289399596712286, 0.029292813945381396, 0.04445360395156088, 0.03698752554614217, 0.010826133338043527, 0.03452849822239049, 0.08191656366351151, 0.0517765618109655, 0.07622020965021464, 0.004166348587586395, 0.02779157081198308, 0.05140866723752791, 0.05067666256499868, 0.01187596586532891, 0.0066382126721192996, 0.03597366180451166, 0.00794832309287402, 0.016050831914218446, 0.07716154018717428, 0.02688720593258979, 0.0925063042931499, 0.011878737188394994, 0.06723357695004634, 0.0032669568158340675, 0.04085961353754805, 0.07247892734144004, 0.052358524333084785, 0.038432390353972876, 0.07604326632234358, 0.060374251671976624, 0.063644114115666, 0.03511620640394188, 0.04014733945950866, 0.015781919731037514, 0.06528442710517876, 0.04419512588590865, 0.04908587332935103, 0.03629939472903648, 0.026787830922271938, 0.04831156911208265, 0.020346105917386954, 0.09796399127451644, 0.017102104686801473, 0.030860813980501507, 0.04843297106544337, 0.070464797918835, 0.046098440690266515, 0.04633757886627028, 0.033328934767914396, 0.034752950492885806, 0.025952703154255307, 0.06733918983128763, 0.07100158806649909, 0.011614522081799807, 0.017539397250079823, 0.009014215695882037, 0.01242375128992623, 0.03477099186350261, 0.020346305100247264, 0.07330493866315774, 0.06846506328832719, 0.02380069131181846, 0.07762790387195927, 0.06234852537032097, 0.05953918519099394, 0.061423569962742834, 0.023333875635158152, 0.07132795684400105, 0.026645156622473753, 0.09149035679236536, 0.06860999180184257, 0.026997229565055143, 0.05347285284510544, 0.054446213518179236, 0.019397731201963562, 0.02168339091323076, 0.009762779358894596, 0.008451531776377271, 0.061926778646246086, 0.03750155139113626, 0.052486150750830296, 0.00030502975747484956, 0.01730697574995218, 0.07330205817256244, 0.043126161270324266, 0.0064274863032023274, 0.008298547848338082, 0.04098769960804813, 0.009353669255130715, 0.0338903546423441, 0.03219913511026291, 0.08227475573338809, 0.1284523907628271, 0.11956322742926499, 0.14485883015778758, 0.11027796599533289, 0.19183963176704225, 0.16522054320141194, 0.1375756629051701, 0.14464647058517704, 0.057320058300730684, 0.1743795533454226, 0.14740466290423948, 0.18733383967511116, 0.1636000833804569, 0.0681313324058729, 0.18468377300568167, 0.09594303600850607, 0.08505036123096944, 0.13805399288333234, 0.09427819671409746, 0.22170057460185022, 0.11082826993398129, 0.15894361711557836, 0.13371833359762547, 0.18132539676322093, 0.16966483375478178, 0.09095189657302634, 0.13390141328977, 0.07819803416608803, 0.12021797979550979, 0.1646719323170762, 0.1015129242272627, 0.1628571313114897, 0.14340142449063642, 0.18616820625480146, 0.12465925962333718, 0.17069143753859306, 0.30057190046195065, 0.1582829122461619, 0.16551786192482518, 0.20710675286189204, 0.11765597493297632, 0.09971306959707892, 0.15393496491014957, 0.14419075552253954, 0.22457793955841374, 0.1387556528131808, 0.12783435699079307, 0.2066156292153943, 0.18319105068522115, 0.1321271996224119, 0.10212096821276412, 0.1140434260389978, 0.08201759533896562, 0.08304152547592118, 0.17113115668537157, 0.12892472227254223, 0.16818361807494395, 0.14253713941622165, 0.1888361074511082, 0.13212767459692495, 0.11114090275500091, 0.19748016861417603, 0.18421390063820348, 0.1755323164886044, 0.10454685457291142, 0.11261242742259657, 0.1265451306056592, 0.1986975895781671, 0.14096380932436836, 0.1063095539387676, 0.12529238532747955, 0.1046717728698446, 0.12469682091426466, 0.10988927596519071, 0.18729516755669348, 0.14190845702204014, 0.20482350441236652, 0.08789000401814138, 0.12650016890538315, 0.08854085699685159, 0.12970456913594278, 0.09483215489214468, 0.17619364955011876, 0.16907902164084299, 0.12435712986775946, 0.0833180602339487, 0.15940633422184378, 0.11553749667420504, 0.06866809191002, 0.13287670940401095, 0.15488171168873388, 0.08421624469901286, 0.19903269175800586, 0.10159033741201125, 0.13789342085440315, 0.1657816872841889, 0.1464582378825834, 0.14441149609704174, 0.19519263007227453, 0.16800973143789077, 0.15581477613699052, 0.10261488041930622, 0.15365402514655746, 0.13909375805768276, 0.19941726789599468, 0.14811585296786603, 0.15752917365922084, 0.18248090250117166, 0.18935352323516724, 0.17974811365767834, 0.1264328450985974, 0.17224553882354693, 0.16923130459843144, 0.11351189891537351, 0.1403741514490497, 0.1614072333059965, 0.1565661704948833, 0.13247601477609527, 0.15458759521284413, 0.09237131960089169, 0.11487555074235124, 0.24366437667800536, 0.2123691333878425, 0.21366593638254752, 0.10308832275651156, 0.14294868184914514, 0.23733880400897997, 0.16115462347384424, 0.15280138460859177, 0.2168053646962489, 0.17714574362241453, 0.12126178225322116, 0.12075425666426459, 0.14467441747265478, 0.1045529526327887, 0.16258216703370695, 0.15926126781250202, 0.07608033731699952, 0.14054005544993187, 0.17142086049481747, 0.08412111956145495, 0.15386848380008053, 0.10161154272575533, 0.11844888359548585, 0.20097978082635712, 0.13574886496268934, 0.13988791544350887, 0.09753587835979077, 0.1523310679101175, 0.16868284693168056, 0.12431638165106698, 0.07815513324232833, 0.10415367526753296, 0.26448434819617583, 0.11849982844245051, 0.18895800736161972, 0.09266250196003145, 0.19004045895511107, 0.11493381938987202, 0.1451559803418575, 0.21719862827129904, 0.12019393229556662, 0.11322605618906599, 0.12816021248938578, 0.15257439275662746, 0.09001186838553799, 0.15224607811579782, 0.1588124935064585, 0.09860867724543619, 0.09859779113603216, 0.1477364096189699, 0.2404731761423811, 0.15624438292316853, 0.0955556023625597, 0.17063888390698742], [0.10157815661401519, 0.08123928831229288, 0.07418493620089947, 0.03837515209471026, 0.030260009525884545, 0.022298492483734604, 0.035185713561311845, 0.01814702180244269, 0.07147268617465612, 0.06760863061513632, 0.05817969322144505, 0.09001828054146421, 0.045227375737721884, 0.04597868199550337, 0.039497382803669864, 0.0023195207975203955, 0.08298923997508903, 0.022120400023977124, 0.047753926051119645, 0.06322382295864724, 0.030291112695610335, 0.03867633573170151, 0.030398539290012374, 0.02490765388844715, 0.07090579643244706, 0.09874357766802273, 0.029859416404618856, 0.015985453970760347, 0.04726343059671983, 0.020243932770925666, 0.028412408465819976, 0.06067666871052596, 0.03849207626415357, 0.0702865599023719, 0.027932743579449675, 0.011978007819233163, 0.06266455196084515, 0.06941346481682793, 0.07957938262411664, 0.05697086776396441, 0.05733702331781388, 0.014658785995937165, 0.03462870252288638, 0.052917500387036034, 0.02659726463588736, 0.024182879170703313, 0.021459957539674737, 0.019623167895441575, 0.07023647307388245, 0.03997274419112552, 0.030547102890728466, 0.03888171241288224, 0.04349206018471911, 0.032358987016543266, 0.027938450934485565, 0.025452528178932208, 0.0378283798213928, 0.027093243364605214, 0.024632764304237022, 0.02789891505193326, 0.020477106952438914, 0.03997550210765293, 0.018322201212868094, 0.026305691571906212, 0.03556956191577258, 0.03450016063007136, 0.07345283193694008, 0.047306515381581364, 0.0018253691885019505, 0.025448942887446573, 0.03467411621503773, 0.044649427516325835, 0.05182230109048467, 0.028207196493542967, 0.015768180901725447, 0.02809858246285829, 0.018502729832224788, 0.05725885936689954, 0.06108087585157445, 0.03162506712420333, 0.05321540133727174, 0.026407768957376964, 0.024749537171315283, 0.02897123321740618, 0.026809181792721636, 0.05717933944035923, 0.017883395625939293, 0.039226218321991545, 0.05005271076374958, 0.023032699659046148, 0.03605449557184212, 0.024558448029922384, 0.07310360309577758, 0.006378881854846353, 0.03953280287884897, 0.04000105880080693, 0.05994958615291023, 0.06562307627210695, 0.017234429138742628, 0.04016703941048153, 0.07979872891859663, 0.041353950922888134, 0.017572365843901233, 0.047820636987565994, 0.02024124571753125, 0.05412713023683718, 0.07725188493608467, 0.031432079999978026, 0.04313404431506511, 0.017284556186848113, 0.21355411818911954, 0.07465762011105977, 0.023812335848267523, 0.030687377420103842, 0.014700207412393104, 0.021982513773705692, 0.06923469053881784, 0.011193433235729895, 0.04260327561848587, 0.020323762963075313, 0.043672527517041856, 0.039642690530707764, 0.06338033855201737, 0.03811528357947546, 0.09135015504134279, 0.05689565708199817, 0.026890140049339786, 0.057221259771575855, 0.043935920036728346, 0.08778254486500256, 0.0072186090232383825, 0.027862213694700794, 0.020632094200400096, 0.03264346610634558, 0.11506823717706627, 0.0358999488244374, 0.03594615541759037, 0.0612430336825069, 0.023700848987866795, 0.04077846950460826, 0.0037521875703767425, 0.023245741049909306, 0.03465406386361968, 0.01855424158425341, 0.025839877555206902, 0.01202489814585856, 0.020176059296054226, 0.07188192268292751, 0.01844372957073633, 0.049132018635470065, 0.031669245499576774, 0.028730631813467033, 0.0794569234694204, 0.08859545608321506, 0.015395098955430573, 0.027386158997673663, 0.01947663634294464, 0.030559515430321618, 0.028405339389498678, 0.04217211367382158, 0.03213769485873561, 0.017553477946128097, 0.042111094770652634, 0.029153602363000956, 0.043045882916738915, 0.05542536198552098, 0.05826080278042824, 0.08638750641576706, 0.05331315415640993, 0.003221723393747403, 0.04585446849946053, 0.06451781058023054, 0.021824672848226565, 0.056094218030451774, 0.03393167742497979, 0.046775478554228624, 0.04949038690556923, 0.05999950827249597, 0.05635605156121235, 0.03634356352831087, 0.060064162262865615, 0.06654208300695305, 0.10825099693911691, 0.0076631746337478684, 0.02184721690061833, 0.024049980152818947, 0.06353904898729056, 0.04629183192587188, 0.029801804677493153, 0.049792102973667846, 0.03848378336237323, 0.05635013353199728, 0.02659859954409542, 0.022909166066036112, 0.020726842039655295, 0.023052935871566017, 0.04710602251091792, 0.01745622882980012, 0.08862841318571761, 0.052010708924142585, 0.07274023227153287, 0.06276685917269319, 0.04235796660425202, 0.08843488405428587, 0.0447226923349644, 0.028019296193134882, 0.013563833762741378, 0.009903570997618861, 0.06078183726077119, 0.07711754375768286, 0.03375458087952387, 0.00759236608451653, 0.06700588029719169, 0.03618650401251451, 0.13290992697640774, 0.0493811197849291, 0.0646204280576879, 0.0391614762315106, 0.06379604084236969, 0.03995986625311836, 0.11427180451010505, 0.03277334482258847, 0.07472122073053353, 0.03269222760272603, 0.05927120380464101, 0.038750623277718985, 0.02811491354218414, 0.03926056204363704, 0.05024536272450801, 0.02555143970605587, 0.048327798684758526, 0.07091953238892941, 0.033646110490325, 0.05300824350166706, 0.027720081402109038, 0.033978228757698695, 0.03557778203920011, 0.024519967433485775, 0.04309350677255181, 0.0271957382679947, 0.014300766295843549, 0.011823037808250276, 0.022140957993425192, 0.035044818500717806, 0.031985817927747004, 0.010133215429020986, 0.09406220588472583, 0.046703891468144236, 0.01423925901162288, 0.005211612836818301, 0.026379360501924833, 0.0071158756749824656, 0.0680631812241289, 0.049451565400006316, 0.035696008558114695, 0.02925483896697481, 0.040470394906738115, 0.05987834763683139, 0.024273235410932573, 0.0806866784489924, 0.06824144988410896, 0.01571864661415138, 0.047951366061404835, 0.05094032321545867, 0.043877264514805815, 0.01624512043030512, 0.04588020139283711, 0.05383621983891053, 0.05085643658774996, 0.016653855150986104, 0.07198246406211008, 0.004389445361260686, 0.06908692749998263, 0.0363199795115619, 0.010017680751550342, 0.05091421876943881, 0.02639473971700476, 0.03130491898064652, 0.10082369024354605, 0.07993245722665902, 0.019095461635339647, 0.02921359470835136, 0.04991425952363399, 0.01577556981975513, 0.05820025502133274, 0.021538931628569, 0.021946390812856056, 0.013585252623494356, 0.047552667092531926, 0.028807728986946807, 0.024081632990630406, 0.02366358072557036, 0.05150444738026108, 0.03140315443517701, 0.03361764649349836, 0.0665354333637703, 0.0591139757495013, 0.009446034560941402, 0.08126998545541879, 0.019293510685524633, 0.0287561655239833, 0.06231936806392285, 0.02582320748197456, 0.06525525447702216, 0.016967200433775302, 0.06908440707071174, 0.03990515225356625, 0.024015559822381027, 0.019677567798944733, 0.018729386520722223, 0.01637258980002615, 0.04965139943505487, 0.008231950867470474, 0.027227764573669242, 0.05104236612697283, 0.03237774084892965, 0.018762176999101238, 0.03365308955131519, 0.020690550539462317, 0.02637886445999386, 0.06347092461862391, 0.0744643361277638, 0.07639591957652762, 0.06445159760093497, 0.04977151053026319, 0.044181091155135827, 0.02332433975572067, 0.009927397289673888, 0.03524122429230521, 0.050078558570314805, 0.04054967351558228, 0.009346183618500589, 0.00961863225506198, 0.030315332565336462, 0.01466014197156314, 0.029917217738505815, 0.026479585869838635, 0.03720056693700533, 0.03520117321562383, 0.028837077815325993, 0.044842899191163244, 0.07132122293114662, 0.04473356312260993, 0.0924227777267656, 0.0635706079793313, 0.03814949706617383, 0.027741436102998354, 0.018299850597677213, 0.017575016508119243, 0.06791293606041901, 0.021896047344911965, 0.05434237796092226, 0.17403369529112694, 0.1470525382507232, 0.22265619267859768, 0.14887933619320393, 0.2423379107588722, 0.1650726882320258, 0.1603120340094451, 0.07367693563742984, 0.10333093514125194, 0.19277968293716832, 0.1770692267605374, 0.11752554080298833, 0.09246519601513302, 0.1358470774345821, 0.08926239690833515, 0.19609361075826232, 0.12012175915222015, 0.09832452757344132, 0.17724038612458015, 0.17165724458473344, 0.10722654586237286, 0.10291774561929126, 0.17634683649145788, 0.10264180840984469, 0.12463977034654349, 0.23780645472147774, 0.08327705154736197, 0.21674210115546183, 0.12477809518215158, 0.1131681782463866, 0.1599029737013963, 0.1784885118925764, 0.1925701578898776, 0.11498281071262975, 0.10348465068325882, 0.13076006975625792, 0.20894611464633098, 0.145464192835554, 0.18402124484700544, 0.16197208525432696, 0.1584625445426472, 0.14747063839627852, 0.173207929117545, 0.16021573675736306, 0.2042298322363246, 0.10824027936905624, 0.12818481157263442, 0.17209791368053806, 0.12939263345493426, 0.13346170946475, 0.12087284707494321, 0.23867054061303217, 0.18206045812656804, 0.12298020939793318, 0.09759210155255373, 0.11290092081312211, 0.1407092995941639, 0.15677266183399385, 0.06408898903417491, 0.1404506683109268, 0.16326256036277742, 0.2212331996810052, 0.07203848041113346, 0.09490672589069414, 0.1649516463399895, 0.1787868112085327, 0.18889693483229608, 0.17414378212584605, 0.08972490717086101, 0.13388687294096718, 0.218420967519764, 0.0853519240814832, 0.14146602592400967, 0.13598564741832597, 0.12807509246011897, 0.12969664778680573, 0.1458026964457766, 0.1700161769986153, 0.18341911506027947, 0.08221334612537777, 0.13235553978912293, 0.22150514557236628, 0.07239473427856162, 0.16441656456839654, 0.08128055746877387, 0.11117582870346886, 0.08937167168985452, 0.14399135815760783, 0.10678814438682412, 0.14974503086939936, 0.1497764098307779, 0.14474972391561156, 0.14477385568522638, 0.08871046886328729, 0.1197346855675982, 0.09966993884694192, 0.1829572100072138, 0.2514842344868568, 0.09446373554847895, 0.12165573530740316, 0.1454361999828008, 0.1265944053809489, 0.1746193235439639, 0.19387937150895598, 0.10200518934476761, 0.10514011306147422, 0.16742819409456947, 0.09231230784808436, 0.11733459338786141, 0.10691465614663978, 0.26104727940213296, 0.2572966354989237, 0.11902103636173472, 0.17653541669489878, 0.07860139477998018, 0.19119932015817012, 0.16912411357606613, 0.1604605784579631, 0.11301509089647763, 0.18600551982320127, 0.12660588137805462, 0.1273460908522529, 0.1269851025614527, 0.1570774269320311, 0.1452721499146954, 0.13165447740785538, 0.09240038497673889, 0.12008700174309554, 0.09876390964153314, 0.14448085769770608, 0.10157682362102693, 0.22948891555349674, 0.1020838818963497, 0.10296277626748047, 0.16075504733429802, 0.12004182553820072, 0.09931550826877357, 0.16703393460521776, 0.15181728338281955, 0.13833554551726387, 0.1198851835403231, 0.1128999325596998, 0.1246113331627942, 0.12308907049197344, 0.21499517553996658, 0.1261899645830835, 0.15276712515661794, 0.22310256146855895, 0.08831444737170974, 0.20419499055752832, 0.12588175975026625, 0.08895801485426004, 0.222104333581463, 0.24724379993013798, 0.16468179952954093, 0.11379739690211513, 0.047332520236171065, 0.13255852244554028, 0.11215327262517907, 0.10596913510873433, 0.09008705225442687, 0.19185843156470408, 0.17305930806023462, 0.10995727392934984, 0.20480065967046446, 0.16512159528511186, 0.2513095204748454, 0.2354404994196469, 0.24254913652135482, 0.10931235813205281, 0.10484461762732077, 0.17681079466016064, 0.08175100440219527, 0.1744439813398546, 0.12117533689184536, 0.12922631576657295], [0.03745787288813341, 0.022862940320685025, 0.027529882837928114, 0.013408883861566504, 0.0333493739937342, 0.026546340856340625, 0.05028614541515709, 0.07034045418784504, 0.009052668521631389, 0.07062334747564408, 0.05018363519000912, 0.07790520471791107, 0.04500701054630261, 0.03311254557282214, 0.052432348395908074, 0.03788599346373831, 0.02332379583329443, 0.049170399640476516, 0.008575403405683897, 0.04832447386316715, 0.02204142785030267, 0.027896823631899974, 0.014539459183241331, 0.05926874466240407, 0.09548749714609116, 0.05263831879523012, 0.06122077116742731, 0.01110440041238983, 0.02166312405719392, 0.03267846483316633, 0.09164050236464509, 0.006259196417240967, 0.050800014212126696, 0.027924082955465685, 0.010845284578540634, 0.07380348570164173, 0.04228477456396626, 0.043415275192068475, 0.01634285026680558, 0.045317260833877715, 0.05492252868510062, 0.018043452460739403, 0.027702884643428752, 0.056344606207623604, 0.055046696215868, 0.04557259793904039, 0.04497737060451219, 0.04216372501105071, 0.014766377299242925, 0.026361794105821082, 0.03511139920221702, 0.024698473580722368, 0.04774286374149304, 0.008491001583846107, 0.025253644092909755, 0.08701238135296492, 0.0371683644311082, 0.0719587000146989, 0.018178161361344883, 0.08369487590126454, 0.06814009645172665, 0.016725373289157307, 0.034744071533843394, 0.039024741028345404, 0.024615241958188917, 0.02868206183906765, 0.02096685930155218, 0.048434430462939125, 0.0539845114784135, 0.05571308162724299, 0.13212690850900066, 0.04444241906786638, 0.025373033150249434, 0.10064080973426182, 0.04567702721443869, 0.0366243768873955, 0.0680669044114409, 0.0474470159068944, 0.03720291116605363, 0.05534014236482401, 0.004452411085367203, 0.00828341186617411, 0.04865362737027388, 0.08199120360997417, 0.03660011488283354, 0.062337604786960356, 0.011590151867318538, 0.011068249680852939, 0.04644236820299299, 0.05954761215816102, 0.015135671898362138, 0.055659589537930106, 0.007308303555023046, 0.0867963752018348, 0.05129171625500725, 0.02887394962712161, 0.029716609954653733, 0.0360874411830258, 0.03162395629671312, 0.08688024650778502, 0.06252210557220444, 0.019270382491090608, 0.020784606984365853, 0.0331271433782193, 0.00892093395739193, 0.043788957559774, 0.02806455092204194, 0.05397887690173042, 0.017280499751289046, 0.0040769782067546926, 0.07011910074300344, 0.05097604206492824, 0.022394753346640258, 0.020812262758432377, 0.010448587971979813, 0.031178110361760183, 0.04158575763745655, 0.06671695789742856, 0.031030318594627807, 0.04877153596269989, 0.09184079605244821, 0.024761212351281318, 0.06708297172501203, 0.04700705161198013, 0.01633748765133562, 0.02674779325212923, 0.06949672325243873, 0.031838476237270145, 0.04968981874445754, 0.042827049901168195, 0.03393320960082835, 0.030188552674747286, 0.019561618476385073, 0.06234388287749983, 0.021256716328582937, 0.03787716046997136, 0.04397886692576351, 0.039917287086286855, 0.07455345513599534, 0.0061285549647084655, 0.045654312707483775, 0.03756288822079378, 0.036807414444704215, 0.022328310540967414, 0.01598920875919923, 0.015144806539249277, 0.03246745740574214, 0.03046353801994795, 0.02499488640516516, 0.04547634282179418, 0.02446931561515216, 0.03883639448172143, 0.052788740159162593, 0.01589653510299902, 0.03734718084395413, 0.03973073701584532, 0.0532385525143435, 0.04051213903773216, 0.13227085642997297, 0.01002382094626345, 0.019495326973077272, 0.036065132702670755, 0.03766589257265291, 0.05040957367107753, 0.033404306328344735, 0.0573971075937152, 0.06629689656678708, 0.00683567853787193, 0.032766388744236, 0.05322922539386538, 0.04678343054688266, 0.046349836273058775, 0.003985213322354661, 0.03184444980785972, 0.07991598633628699, 0.04888696626069085, 0.023224717682047237, 0.022403706999255285, 0.06485380142206146, 0.0717422878369689, 0.006391305406953419, 0.04171852450517397, 0.013442006630582676, 0.04201550614990054, 0.02494665542467227, 0.05344774431338715, 0.03255542345164764, 0.05510492272855294, 0.049842293224027084, 0.07661144309226545, 0.08251556015062718, 0.01061249248337962, 0.031411177290964036, 0.04667400637821806, 0.07502964006796961, 0.014940730292320013, 0.06808647029702702, 0.014648044485628847, 0.03229854650975716, 0.023097776912993962, 0.019739216809431394, 0.020701496020680474, 0.03390181914813096, 0.04493408280635073, 0.05721333076155955, 0.019834272999076114, 0.012570890924713064, 0.04680905618794984, 0.019730563846326644, 0.026138458408475406, 0.04898580309424189, 0.06420368771819819, 0.03207566471950662, 0.03563953638677636, 0.04563768859952689, 0.03915702526067053, 0.0007465972709225401, 0.04552194420548697, 0.02418428685726418, 0.04732238872337246, 0.04860775402536796, 0.029583494516930757, 0.08913229985703384, 0.07512926214164303, 0.02705273071994945, 0.0481596308940601, 0.061609262014709176, 0.015187618405287786, 0.025869452379523747, 0.05829755967903522, 0.06443358687383514, 0.0665670421515261, 0.06297468350479199, 0.03825086965075424, 0.050835319374117165, 0.047348474017194206, 0.03183884204425399, 0.05147371193273895, 0.08603640832006933, 0.06710932514960728, 0.05875988225001962, 0.040389461547977505, 0.029575628709168206, 0.028951470064179554, 0.005028489094618107, 0.03432228650537229, 0.06964146024397305, 0.03979272118979885, 0.02353659016080201, 0.05276309153545768, 0.01303932591972332, 0.043382643676933744, 0.05657373927533627, 0.023147193414549676, 0.01583013060172239, 0.013073561431449509, 0.01750174785904106, 0.022974775751091303, 0.018736683508200992, 0.02233430900941453, 0.05132753852634661, 0.022426749008797833, 0.04479663897185557, 0.02078967274076516, 0.025635104168266542, 0.10080757941449843, 0.0532706247852935, 0.07712474498417109, 0.06155550945550204, 0.01827927347603104, 0.010209197944570935, 0.039777920371101755, 0.026197125421716805, 0.06590757834454698, 0.03404197493387807, 0.051931606515521006, 0.033633719018149766, 0.00794715959683902, 0.054098260213410666, 0.037439057768713084, 0.06575458292518893, 0.024865936570530458, 0.06042623456807868, 0.08744490693413443, 0.011598136418709352, 0.012962554333611362, 0.08892804549466218, 0.0859319752142314, 0.07980322585471215, 0.013689264380973915, 0.017750795382345398, 0.03762609813542616, 0.08785313220634576, 0.023979614976973786, 0.05039645441537423, 0.022007725727293762, 0.01931936040730967, 0.02594844370539631, 0.0243852949220567, 0.03788923401565802, 0.025992472693624518, 0.05204186188958345, 0.039544558498047055, 0.08002352209821825, 0.06409573826878782, 0.032664376476238814, 0.03471713205198607, 0.0569959762956827, 0.0441649611738901, 0.02584727604933564, 0.04312154559058048, 0.06354428902869264, 0.028424934003381964, 0.050901585979567426, 0.022026138650553844, 0.03158236729852375, 0.07521690260018073, 0.04165268690896131, 0.0470997367594992, 0.0023922558184788236, 0.025198583438571905, 0.018354846134541497, 0.022983371257601727, 0.04693937923518881, 0.060483193205248933, 0.03863420089586608, 0.0347192847590533, 0.06416797652960786, 0.030496315091788292, 0.00839128757962176, 0.03940447932109237, 0.046277712925427386, 0.01954945874580693, 0.036681335524565754, 0.11004455432656313, 0.054700589182996945, 0.0138645117817026, 0.05188842980010856, 0.05621631712382359, 0.07818735490042357, 0.014192946123770409, 0.057969543812496055, 0.02877558010720438, 0.021143030795839526, 0.0720742796998351, 0.02082070504735795, 0.057771820349678885, 0.054828797827564904, 0.02199487843280358, 0.05463307768466973, 0.04759959763877335, 0.036529443271818667, 0.11441558389173401, 0.18405772595395967, 0.17953114223576364, 0.15596063927777354, 0.11015340775972414, 0.1954819508377583, 0.11505731276326603, 0.1516023803983004, 0.09370846478568931, 0.1622761149079569, 0.12741321547617837, 0.15153266639719087, 0.23278971262756856, 0.263216074315771, 0.2559788416950934, 0.13363574931938804, 0.11570399822366816, 0.1425068789432126, 0.14921845267376593, 0.11176666635419093, 0.10470174989032169, 0.07672257946744081, 0.11088266983748445, 0.1482641675900067, 0.20187495456587887, 0.0864606601516566, 0.12265332734152196, 0.12943152007797074, 0.16226211082070105, 0.13723319095949973, 0.19553949936263024, 0.10631070307065403, 0.17841061607243555, 0.12609215047691139, 0.1415456377811009, 0.14051135779628832, 0.10925709254919522, 0.15565215099242427, 0.11782818383747533, 0.10242940287195867, 0.22817407884905416, 0.10401166554900909, 0.1869258059248809, 0.15278278399379025, 0.1381739009652407, 0.14997116470288846, 0.21961753557045616, 0.20380154312137636, 0.07509268144325865, 0.12033764272928239, 0.13803382944916526, 0.15443615495197235, 0.1423176705476738, 0.20829498587596804, 0.11243944476929404, 0.18968683276926318, 0.19538401415751827, 0.1344477259103329, 0.1133163319900632, 0.23866228218520844, 0.1539696380496025, 0.16225028242315018, 0.1980505517173198, 0.12176440487946234, 0.08477135966982573, 0.13703547898800145, 0.11762028289658409, 0.1380217559034786, 0.12876707669948378, 0.12258584265627208, 0.1913689626681228, 0.14093724139515432, 0.1557569824639828, 0.2699136746025855, 0.14074415659471867, 0.25009494935793264, 0.21333745320237454, 0.08747637016518463, 0.17012174391458112, 0.2302899524088829, 0.23342705181529447, 0.06876793614919148, 0.12692343248354812, 0.11886073246357903, 0.10299635390120168, 0.13946399302972903, 0.11923004813011616, 0.05722129041509283, 0.22968128023128356, 0.23463305806921375, 0.20873894914984706, 0.22644074363333566, 0.1557672173986512, 0.09037293328513062, 0.15851465384325675, 0.14222947850583062, 0.16478204979531227, 0.13596586702812102, 0.10342704853223217, 0.2897749943358283, 0.12879520744806336, 0.10098331232344913, 0.1269772961255043, 0.23979243041286546, 0.18345170444057834, 0.12886934943737524, 0.1316685121386282, 0.19521360555964132, 0.1628022947378697, 0.141600351780653, 0.1964007047635894, 0.24761383571932394, 0.10238395853629036, 0.13443568300816322, 0.12654499270983283, 0.3729594258531448, 0.15361470951428338, 0.2839482828013359, 0.08599604314733898, 0.13953410539655917, 0.11886340611043478, 0.1374103870963858, 0.14151450396785814, 0.10760421954816389, 0.20027278892455563, 0.2078917938014192, 0.13912806347493203, 0.15823239640843484, 0.20495114998231012, 0.12932307267140958, 0.18889814525121645, 0.21221628352519006, 0.15021269690365563, 0.1336646155123749, 0.09537553339595757, 0.14887248736716088, 0.18175670426459084, 0.1421590290603138, 0.15932693686937133, 0.10174569238217608, 0.13181857344123626, 0.1264732255930862, 0.12288153727328587, 0.06748273938653931, 0.12505752575253287, 0.10526512328895832, 0.16057550696836365, 0.12608421380601584, 0.10383600924885082, 0.11443615335250094, 0.14800412670498894, 0.14452907527166028, 0.17606424197794932, 0.10128896608347855, 0.19957212490900872, 0.1190096139907837, 0.11460568861014421, 0.20568020521633087, 0.17372168300132598, 0.2221209423676614, 0.10849624466631683, 0.09124301764513217, 0.12439659105673914, 0.14158110765199508, 0.12443133314410526, 0.17475691293516468, 0.32559634636967416, 0.09636258406023826, 0.11850093926994071, 0.1062703915240784, 0.13213908930699672, 0.1155006401841679, 0.10919162267518621, 0.1257827965122077, 0.17553749524297255, 0.15369574629491375], [0.02547902524501326, 0.04632866543327128, 0.051575758674692725, 0.026390980140516357, 0.051667635599451686, 0.03470979292967147, 0.047828991176380266, 0.0076511748240239204, 0.10152303658786321, 0.09105113560273763, 0.03619210028480138, 0.051964831748797055, 0.01123160165133736, 0.051177588306487574, 0.06236033844611338, 0.032269438999074126, 0.08121748544996785, 0.0749142902092107, 0.009458150241463896, 0.0375697293859576, 0.017700011413844845, 0.04768666353136782, 0.08040963041205561, 0.0902777162170218, 0.035160026633210724, 0.014713683856591104, 0.059491185952098145, 0.012727830739271258, 0.11713662094646886, 0.030535488997796373, 0.0622451379744997, 0.023569794326660135, 0.03744918545107207, 0.08715049934483345, 0.012369307336367428, 0.04150123515677068, 0.06044480836980286, 0.03511020793549476, 0.02628563730526836, 0.010516298653167343, 0.0546903082830531, 0.039189890432622165, 0.05422012564996558, 0.06649087769009414, 0.028897443628539483, 0.010363840452966191, 0.04616745372092532, 0.051024864848342635, 0.019017345564920577, 0.013582389369877356, 0.0494258631501467, 0.019136749944018743, 0.03358784950368347, 0.005602953531178496, 0.06016595236536476, 0.05913097524054109, 0.02094976021908224, 0.04577132114659875, 0.03781362113753154, 0.03715025411257821, 0.02909753430304268, 0.07748558005738644, 0.03517522964806807, 0.04647928598006407, 0.02919793395595926, 0.07094432299415912, 0.03775722557498563, 0.10212850651793903, 0.06636704723801344, 0.0363443028031578, 0.013674651253818264, 0.04770027308334266, 0.05558027262468973, 0.03949304674601844, 0.03561653842728946, 0.05676115885557187, 0.07362591418167276, 0.014193309057924538, 0.019842337989698977, 0.02326976173677512, 0.057383639768006346, 0.08084636947680866, 0.04456582051070948, 0.01332302455745277, 0.01592244515420809, 0.02291665457549595, 0.03521530370738718, 0.02178257631678735, 0.023472248351261504, 0.031220971065903866, 0.03248532640657598, 0.04933354955527091, 0.056753720141827106, 0.052210113949953556, 0.012028446090557884, 0.03939648902404212, 0.04276579351074273, 0.014839710108184767, 0.06552147769158886, 0.09672083741714878, 0.011188097433337282, 0.04164011540612386, 0.08296454896128948, 0.10386501333766407, 0.021616268204525117, 0.07392088867603772, 0.0628705759863219, 0.02360326853851157, 0.08050225044210112, 0.041293694277203856, 0.010914011283837741, 0.03199431384282728, 0.049602350655702815, 0.037221071280298695, 0.03372713577963653, 0.04077868017878744, 0.024690084917951497, 0.05757203994078502, 0.018250775005247806, 0.037185593748525266, 0.013679463243592652, 0.019113730917113925, 0.012507291262849204, 0.13791732279764068, 0.04114321545667706, 0.03909724741993893, 0.06934905980503367, 0.042130725773712324, 0.040680249371836265, 0.022703222479791414, 0.026408268829747557, 0.025446328612404968, 0.08225967912303825, 0.019816875142315706, 0.09483606960143774, 0.06281632163952436, 0.05930707204125582, 0.026255489830228112, 0.009081231152278282, 0.05430683531167527, 0.032498744436569756, 0.04813914570296484, 0.004245568782226333, 0.048472233071562745, 0.06311884209994348, 0.05920097269418259, 0.07336090138602643, 0.05772960507461141, 0.033343513421113455, 0.0337313377719012, 0.08699706725535855, 0.04636769378257375, 0.029460152445901788, 0.01645847208677761, 0.013429981923001188, 0.12556937973826163, 0.018161269122614496, 0.021834614754263914, 0.07312965008520311, 0.024176928582751465, 0.07257295697326623, 0.03542369111411033, 0.0022125268033930975, 0.05795466638500652, 0.03871676602190541, 0.0700494556898071, 0.07124803855174011, 0.02331579404492532, 0.039628222960257725, 0.046979353703077764, 0.049106975221225334, 0.01219425816088915, 0.020893152067137342, 0.035208431898706385, 0.025771305025104555, 0.021074201626282547, 0.05577127366597134, 0.11089892622323767, 0.02793701260440773, 0.01992241141476458, 0.11989505075278784, 0.027441903385483933, 0.05297944242615373, 0.015029084170237185, 0.04950145687607508, 0.06664604879915714, 0.012168458234819194, 0.045054634402115504, 0.017945169125713648, 0.04514056265414242, 0.033101107880112626, 0.04804318552956947, 0.10542798592078109, 0.08339032530784608, 0.031057964792595278, 0.03244953094831398, 0.03832759718681055, 0.06797624556648155, 0.10674921179851217, 0.03572397842823017, 0.026215727951738144, 0.02996095752854261, 0.10329430847759209, 0.07086520909421867, 0.10125780928759806, 0.021110962355329145, 0.018068061120087103, 0.01054016420722849, 0.06836860515778104, 0.029746450994524266, 0.03791343090274642, 0.02225964033465472, 0.02572370415192939, 0.020058118144891435, 0.0347657633134194, 0.043739904949982325, 0.06416209297434938, 0.055891940174924756, 0.10364933660434139, 0.02239831182504854, 0.028186770674261837, 0.05463916808366776, 0.03630568431089482, 0.012687379381649438, 0.030136152260726502, 0.03873760361344584, 0.012707914368459776, 0.040952352311221824, 0.009626855251319226, 0.03765809379758374, 0.0186329877619902, 0.034131151398703936, 0.03953209424751901, 0.040507680406012846, 0.042033110850400505, 0.023360759575640964, 0.023804152114016396, 0.08554510847334901, 0.045848435557056824, 0.012061130274237405, 0.07309507653718034, 0.03555143244504448, 0.05779055119942754, 0.07596570758088943, 0.02112214532380383, 0.034277455040043404, 0.05185460318781195, 0.053039702902277636, 0.019836509975815014, 0.0020547452497281017, 0.01835689733495876, 0.0487986171708232, 0.04685825052400751, 0.008836918052345996, 0.024095759651954138, 0.01395254294508167, 0.04975958254128214, 0.041796182838058284, 0.057809328014451655, 0.05124007426803151, 0.046489425153741916, 0.004098364029965934, 0.026228134745671868, 0.043114463107720505, 0.06525820391553064, 0.03740345383243215, 0.06030046974398917, 0.03262763872982995, 0.045695183498244134, 0.06821932526485575, 0.03871547899419262, 0.08254091766092085, 0.05977361575670301, 0.015787400132525834, 0.0952862841527789, 0.0753772218200949, 0.012151341915370957, 0.021235646995445414, 0.03163609495987335, 0.07644655032744331, 0.019284537880711498, 0.06787604126598566, 0.06222441146570829, 0.07279195852818028, 0.04195937871812813, 0.02856450756230662, 0.025120708685848984, 0.015110819048488574, 0.014341480038579435, 0.005130408474454476, 0.04432216241595246, 0.028949319272332137, 0.049852466871661526, 0.006936637913778185, 0.04635676170789427, 0.0304350184817468, 0.016838984128328103, 0.0522681451102178, 0.04103955993008229, 0.12911514108700137, 0.025881949188788573, 0.030253038125773592, 0.050769382186474345, 0.027923809079032753, 0.020270159791013407, 0.0018231137777723733, 0.027822315835604267, 0.022891888868123777, 0.04518513748001668, 0.0022355434362731517, 0.05552766919736901, 0.016476984601467848, 0.10006878720296007, 0.025353620482248165, 0.06770056116604997, 0.10890085400352556, 0.03732843467244699, 0.05093684134584281, 0.03556660481638486, 0.021856162892354113, 0.07000461656359896, 0.03663224077993824, 0.06480685555406156, 0.03276964461791419, 0.021792223278973854, 0.03799816788805108, 0.02986431936733425, 0.05105280790538077, 0.03463316498504531, 0.0262074158977597, 0.07889208684284842, 0.06657729240795297, 0.028983209086882494, 0.10801676555626816, 0.013651643718232312, 0.03331410713613995, 0.08937502715496287, 0.005425455747172237, 0.024927621970193523, 0.03810091560045558, 0.05661965475507802, 0.061534089637139154, 0.03677446883352053, 0.022418145841408162, 0.08290275630931701, 0.02150855815759109, 0.03716804650461963, 0.01194941646028911, 0.03759457744778164, 0.028012711667425694, 0.06828279564938239, 0.01349358541530467, 0.1874931859633615, 0.25965915872685374, 0.11751932016904316, 0.1920164295382077, 0.20029806982605688, 0.12806212259156088, 0.18213836926846735, 0.12337827634426857, 0.2035845257341862, 0.19562926954559742, 0.10698764134318599, 0.22782177033443607, 0.08405622425338916, 0.18830988165591994, 0.13454114267181966, 0.17884417587230284, 0.2662336946495118, 0.18349134182978064, 0.1484134628046905, 0.206171436115138, 0.07375849335784875, 0.28581199086000847, 0.24699459152836956, 0.16750409808610717, 0.12071508658869613, 0.07290009949957171, 0.19256170027919356, 0.1320702180026039, 0.16695211641490462, 0.10679920669645072, 0.16620148814493613, 0.08755997334036135, 0.12546243386403208, 0.15755407151675996, 0.14191755814658058, 0.16270523139786336, 0.1528730291512705, 0.09806419557501232, 0.16970519126663286, 0.14376936119890985, 0.19666321245172333, 0.0927415622338172, 0.2448668129621975, 0.13165801673406555, 0.08666359684279851, 0.14822646074237364, 0.12411421104784935, 0.12652539618072972, 0.15445178314562769, 0.11982296953999227, 0.1304688950579974, 0.06983086782237215, 0.16599542581506316, 0.0583218599879934, 0.14504433068777287, 0.14748914708052913, 0.0996570838915725, 0.16502387310949065, 0.1495336518893319, 0.05603715597141174, 0.10570887205821854, 0.17537038082317, 0.1913133906500955, 0.11815138101097077, 0.1692795987811781, 0.11111349212907015, 0.1688460083377938, 0.23193932438810028, 0.207137135908969, 0.09798336563812149, 0.10728831553170759, 0.2179069378443303, 0.16035930163437323, 0.13002828724922674, 0.1454366289920384, 0.1683235670169515, 0.16050620665473325, 0.12745297543944853, 0.1377141869236385, 0.07377464249129258, 0.13930170496384944, 0.23971689414353142, 0.16653945549361168, 0.18662062713936453, 0.11702396005632416, 0.08616619893620092, 0.07731520210302646, 0.1387338499508558, 0.11027378315526633, 0.08686071892659511, 0.1359499170775375, 0.19398311513566202, 0.153037492906855, 0.13452047361962258, 0.12837035806789515, 0.12768916034650418, 0.15720392337008832, 0.09835448927215992, 0.2617614878521812, 0.20202429574583808, 0.12657975011895742, 0.22991653051107164, 0.19396371778941926, 0.31154090057938333, 0.13502281279333178, 0.28612044850184076, 0.23183490660402084, 0.13258934982361334, 0.16423163094347523, 0.12088066883265011, 0.1500837643059992, 0.09259232830616737, 0.11446751699212099, 0.13203407397433636, 0.12547075357888976, 0.08547352521770424, 0.20152037843100487, 0.19572625627681134, 0.12079334247016138, 0.13786881411027524, 0.1092489260519224, 0.09400536216074422, 0.10492378515341591, 0.2301975315616977, 0.12126838593112847, 0.1799517245061936, 0.139226567060236, 0.11105636495255655, 0.11327644945272516, 0.0897120905198878, 0.11357342343657248, 0.12734367001441219, 0.1676612073976186, 0.12880876720432313, 0.12197449683181702, 0.134339569617183, 0.21468333178950896, 0.11646685325690817, 0.11234942943819108, 0.17857492661043523, 0.13159075421431374, 0.17548589156039301, 0.10760460259212602, 0.14570681288117363, 0.159118591597484, 0.10904818803312318, 0.21506922559872751, 0.08294312148204736, 0.1388883085981492, 0.16991854675354498, 0.1162549380152937, 0.15590863722947337, 0.11501995065519888, 0.1525401792699291, 0.16849579890408825, 0.14007235877215862, 0.10016434901063481, 0.15357836630315552, 0.11580034910190491, 0.07529871312961464, 0.3049837701743649, 0.1542989639264922, 0.13312265427122194, 0.1544770793688874, 0.10258324098803344, 0.1898496264531728, 0.14440241029425976, 0.13193580021540965, 0.1767951664665053, 0.19293034178835733, 0.12473361611726785, 0.14123483591022032, 0.12789127732356712, 0.22071802087368506, 0.12386476515882439, 0.20626762611491067], [0.0539839024385137, 0.0510773150580785, 0.029463588350242185, 0.03692870531531592, 0.044352158588627656, 0.024111426150005673, 0.09675408563306255, 0.041280965726341934, 0.01653896302976195, 0.051239281367029876, 0.05314135510895041, 0.04241901998137755, 0.14960843739250015, 0.10623741909981736, 0.026182701901322412, 0.0635695354562373, 0.051484368215765686, 0.03867948818350992, 0.033946328856531656, 0.009919238453280303, 0.013125040624741346, 0.11764826042757881, 0.04472612440886517, 0.0401359822060312, 0.06065103923901916, 0.022531362145297953, 0.03174151248869396, 0.01733480772424129, 0.04625660337267384, 0.027489690034980738, 0.061679799560337305, 0.04016514717330856, 0.025883762901949308, 0.057833498088462706, 0.04379029055276225, 0.020127678928416104, 0.054863375206027305, 0.04545507239057653, 0.02307913607857641, 0.07297047999717536, 0.021802502263697888, 0.04706810498910566, 0.08335487075871037, 0.05632485263049603, 0.023805140367438717, 0.01218523268753122, 0.06341568201840406, 0.03196643590326271, 0.00917933828708145, 0.030909483546331048, 0.0646569015037629, 0.018794655296651107, 0.06983507364507645, 0.02717123494573659, 0.026578861288726333, 0.040866052506551634, 0.02664339462024791, 0.023472466686319922, 0.038688918725857814, 0.021592425633101694, 0.06688403401283488, 0.010446435264912585, 0.030124312371856747, 0.03357227876662247, 0.024843444229073586, 0.05399580744485702, 0.009264404690193554, 0.02325847726165047, 0.03387054360862221, 0.03340069422378175, 0.044758805719714974, 0.02737036609511462, 0.080250307106443, 0.041609169284422556, 0.013299624401805623, 0.00814584450000116, 0.03147163503472844, 0.020205831388011575, 0.02632477673731985, 0.0939832222197325, 0.04739180011975189, 0.055048982988321976, 0.028277728293511658, 0.04538021027861584, 0.06295140975365235, 0.0424168634438707, 0.019658181944020817, 0.046185081404063015, 0.038575127856024814, 0.014677841475443735, 0.05414410291479961, 0.12367384072633521, 0.069139504114226, 0.014651178742849059, 0.017098193807948022, 0.048155857911033016, 0.04621721879248658, 0.03997586216897734, 0.06311296237512462, 0.023172648601053704, 0.06135265320359219, 0.059318394820776686, 0.0726982889576785, 0.01642328566841541, 0.01684376643219542, 0.01840962142112755, 0.031160662709284696, 0.027168630246794032, 0.08053200529708017, 0.05289487014975279, 0.03966720917472436, 0.024454085787217465, 0.12244504335666857, 0.043033483783684434, 0.03995481390325774, 0.030571744108812946, 0.05031030399784927, 0.03931118896411311, 0.049702915017523115, 0.034293113877215696, 0.007672613315779957, 0.041814929009565426, 0.05157293564069176, 0.1025034835742366, 0.03393486052030518, 0.03399531251841015, 0.01639585972072617, 0.028086551052007466, 0.057944442941657, 0.008804993253321418, 0.031193522135576898, 0.07004356447366938, 0.09410083969874729, 0.013688842075005656, 0.03127150414060922, 0.017982489098944975, 0.028064116167144913, 0.015061703236443142, 0.04093521875479529, 0.06141619253603201, 0.023724224245656404, 0.016313118394464254, 0.07866005413234234, 0.02093933376243278, 0.019529783692691597, 0.04020757312255521, 0.029155967659467173, 0.10350188766155513, 0.03342593682088679, 0.026223817840218547, 0.015012561568930266, 0.05235525313764811, 0.058058153372257955, 0.03304252130610328, 0.052609096371358445, 0.031419707680000894, 0.04049601288692605, 0.0365728153396518, 0.02929902308800769, 0.01406018978976194, 0.03742763539776206, 0.06344191286893142, 0.03337254049256444, 0.03402069301134156, 0.06466866861427985, 0.058678822486751506, 0.07174924391532136, 0.11957527799231392, 0.10305214808472704, 0.03717927352314995, 0.017168369377031922, 0.049371972695113196, 0.028208579282246293, 0.04143236768281749, 0.03577200448020332, 0.02020341821105009, 0.09282348001556051, 0.04186865858613484, 0.010322522458380029, 0.06615818102633761, 0.03491134300167042, 0.05191770968057456, 0.10301067974538573, 0.02640019426302564, 0.05716480292199601, 0.04398059062359314, 0.010982030315414794, 0.04832317917457512, 0.03290838697144101, 0.07140900128551068, 0.036652266318278934, 0.06431062210110888, 0.06518010125165025, 0.028278153472309633, 0.035638743485774727, 0.07907407869014048, 0.038026697002351284, 0.09811823541719107, 0.039305623335343216, 0.0483819687618844, 0.049051085276709455, 0.04138192079300362, 0.04805137500948003, 0.056754658599534345, 0.07829544990653954, 0.035509960275263555, 0.02905776859411309, 0.03589188574903435, 0.08541448282137995, 0.07721910403380472, 0.030673132015151844, 0.018440935265032515, 0.011024123016414384, 0.06405408223790508, 0.009753349774156608, 0.0334456252805408, 0.008465633539843464, 0.028763447189703587, 0.030261181640408696, 0.05985745258869664, 0.13455209772913687, 0.09010132447245622, 0.08438319057947205, 0.038372371195545124, 0.06514272382182461, 0.009479889901535166, 0.11055646193844658, 0.030962791774542104, 0.05117275046124574, 0.022170735831041972, 0.0658089675069336, 0.08301767715883833, 0.02149538336051328, 0.018777161678900162, 0.02719284245564092, 0.031058397632272496, 0.06366426988895382, 0.025946281422230027, 0.034464702250496033, 0.05884308322903611, 0.019244345077764125, 0.009469447165517317, 0.016539937876645597, 0.026059842465685743, 0.06226990559709169, 0.027161700981518915, 0.05047830707964398, 0.026183697815623977, 0.07742688240062806, 0.010224101227527906, 0.017270971532730807, 0.05318372743204237, 0.020637667490049236, 0.034736150184706334, 0.06035625626663528, 0.03371699277551905, 0.023387561161671917, 0.060462282835355693, 0.08982848225822372, 0.030004992262430252, 0.026638468674894784, 0.05293739952086922, 0.02070413136314, 0.015309964562015188, 0.02387203516498689, 0.03418442132251878, 0.020111970295528733, 0.0759715911361479, 0.029501804646344918, 0.06804100297872098, 0.009311040292584128, 0.01364124694748992, 0.0767678399420073, 0.08282312146958806, 0.014766329418747656, 0.020911752681938872, 0.060755637053760796, 0.06504547662071644, 0.023199400391369578, 0.03169322405160675, 0.059871801415518414, 0.11330546120241766, 0.0167966750074899, 0.029215977241795872, 0.05989792501373638, 0.06700352840726415, 0.031703309599129904, 0.007173535282603435, 0.04836638270306492, 0.05435000819664809, 0.013819547208596863, 0.04861491694745999, 0.04417959345324386, 0.07860195402416491, 0.02397102330090298, 0.04924705822861964, 0.03590593580156565, 0.037128795989819115, 0.01067605288323736, 0.005414574425817738, 0.02390997375421707, 0.03110356043062864, 0.04320274324967496, 0.014004827488303907, 0.016075996944921154, 0.0915406198210774, 0.030816361728695132, 0.04676050919618818, 0.06567094144561599, 0.031069955983830076, 0.058495788759882414, 0.022017535483164173, 0.03853940900655524, 0.0110224433686404, 0.030825903353792046, 0.030779164329531695, 0.027392387292498065, 0.07199455292955523, 0.02909108192750043, 0.04921473314865463, 0.07428234428047173, 0.027530105003426154, 0.10398549598551567, 0.009457687715879612, 0.019007420895861524, 0.06377637153491378, 0.032897531505553954, 0.04184410546816165, 0.04153547545654639, 0.024107655082198403, 0.0306603096185192, 0.025953902081856807, 0.03331390795327964, 0.0059756021589911995, 0.022808900478506283, 0.030853438469010497, 0.10520462532557788, 0.010860304689906057, 0.014243526121361122, 0.0053882277044918275, 0.09565054363901578, 0.04162040779427175, 0.09728930530048187, 0.07542107269288072, 0.04678323136402234, 0.028113754834198666, 0.03804511758649061, 0.0040937191431200315, 0.017145538041668556, 0.044343168546836224, 0.046259434067554055, 0.07906304702403084, 0.2251764687318956, 0.11891278047715464, 0.07090334495108935, 0.11597245075409451, 0.14586577612546184, 0.05766831037978973, 0.29344841657627013, 0.15173114445661345, 0.2387890237714014, 0.1401258470310319, 0.20082611891050495, 0.12575249007392314, 0.18102168886651918, 0.18181279722240665, 0.11302190907900372, 0.15764332075993862, 0.2123586992703138, 0.12798290143931104, 0.21560243811578522, 0.16398121212278643, 0.09719768884561716, 0.1577520439581525, 0.10913385198481622, 0.17274691272647152, 0.16491249924705875, 0.14670205302536488, 0.10848643108000679, 0.12339270177988276, 0.16400941948015846, 0.09527920550035854, 0.17013778579571556, 0.11485996085309214, 0.19177264503894315, 0.14564197119926253, 0.16416518047692316, 0.12657254123158995, 0.07459998731651614, 0.1799076438070305, 0.14382223658744367, 0.1826202385728398, 0.09718982878351405, 0.15374060840375964, 0.1772125464894118, 0.1963855668662056, 0.2384805508078106, 0.19542325318099993, 0.24439580678459139, 0.10446852974353299, 0.11617223116298837, 0.15175311585828183, 0.1989069154425975, 0.1390165363949153, 0.1923284877932841, 0.15662911227874218, 0.1526437696790503, 0.11919516048604444, 0.18488867088190972, 0.07246257902513589, 0.18488775157640058, 0.11447130912734617, 0.11006423512533789, 0.10247087887217922, 0.14141793092412336, 0.10445896896623796, 0.06420458021062998, 0.13623062701475236, 0.07205574803294675, 0.1624874938880244, 0.11996595219017998, 0.09677552843406316, 0.15966349461626622, 0.12419682596960377, 0.17076063059991406, 0.09853664199791609, 0.11522162330126572, 0.13996859982369408, 0.1565393574175335, 0.11659208564989029, 0.14610222150241176, 0.16484572702357847, 0.13603285375622012, 0.19762163441027367, 0.14034971324426515, 0.12877573349302815, 0.10347496733189591, 0.1329541455713972, 0.10434882850536417, 0.13484270552233343, 0.12812128756195307, 0.09675351106711934, 0.14164749683151323, 0.26383470563638595, 0.08421538668053766, 0.11371832130657089, 0.08203887726150214, 0.1024955009380656, 0.09462871258297274, 0.15778337695425557, 0.0994832662024325, 0.1036033406853676, 0.1349275114555513, 0.10572318258064409, 0.13252423235004948, 0.1258772628141507, 0.17214115168298447, 0.34549486733252005, 0.0789070102356134, 0.11449046898633243, 0.1884350451009889, 0.1819503253265735, 0.15122692070661053, 0.08235209997022346, 0.2170365240665213, 0.1587144495739091, 0.13847284379505342, 0.14117460607761337, 0.1449706177076986, 0.2100395519406565, 0.11998151909680137, 0.15050589407403625, 0.13526583120467203, 0.16408035922194683, 0.1403701065048095, 0.12503202268553357, 0.13238950812768552, 0.11508489958941938, 0.1796613771828913, 0.1549484532686972, 0.18095652542767987, 0.21194980750160836, 0.15364708438996347, 0.14030730261677696, 0.15204559290601363, 0.16459330105252806, 0.11543087255690368, 0.07277072257091922, 0.11875553326981685, 0.08174370358427686, 0.08917817320193976, 0.17740285805156156, 0.11363172272761023, 0.19530927461962547, 0.14483800788800563, 0.15141111888712452, 0.09767033445138125, 0.2162321317460268, 0.17754444642172706, 0.1653909517992889, 0.15599518984315858, 0.22329719376660165, 0.09624060754093433, 0.1746018873828073, 0.13877790000650192, 0.11475800987212889, 0.1873124198567483, 0.12166239261146515, 0.08567620909983113, 0.1764064381319669, 0.10487407370800934, 0.15259035802896947, 0.2559101236082854, 0.15600323376636352, 0.110817406807215, 0.20645292746203564, 0.16376986378623595, 0.1571109815831146, 0.20366612941988055, 0.18749346175501425, 0.24528250759167058, 0.17794627485977066, 0.19197567366063598, 0.12188427465697452, 0.14340202203921734, 0.08764858673056287, 0.10212586351460028, 0.10179631547221255], [0.03560782417715077, 0.0241722458703143, 0.012937317482165754, 0.10564910953924542, 0.038342574205730236, 0.03474257383195143, 0.04079766383755111, 0.04757861832096692, 0.024715917402758233, 0.025639922861310265, 0.026781606457887158, 0.03058038175015921, 0.02757666208180449, 0.08625295839362568, 0.026589354778069164, 0.04586497539534204, 0.0360027693151947, 0.0253248653720103, 0.01687467807994014, 0.10872280750904353, 0.022683317600298795, 0.0471978496399618, 0.04734138004301537, 0.04629811384685097, 0.01850537666600318, 0.009181835733714604, 0.04603768608743145, 0.013290724375345295, 0.049142448922559145, 0.052616504441586234, 0.028813601050886418, 0.016241718999921315, 0.01777402508342939, 0.0423353057234518, 0.035656286899240754, 0.05068372972610016, 0.06978018344530175, 0.03943272881330021, 0.03287268727416954, 0.019355738092394128, 0.014895859564984999, 0.026740149609864722, 0.0519162847570354, 0.011346406630060125, 0.021804210639769034, 0.03340377006679773, 0.07582600378701765, 0.02007983673754479, 0.04313971719614441, 0.057656455169161486, 0.02513455189464073, 0.020130329592634114, 0.03397136460989714, 0.00902679964764825, 0.07846422673713777, 0.017397420090292732, 0.03583879585588171, 0.06010473427933551, 0.022957737955655304, 0.01819993358015293, 0.050878105384688226, 0.06606562994420528, 0.09367438153393808, 0.08250870366370486, 0.05768418755202044, 0.019403400252603235, 0.02827342096415739, 0.013013862114730141, 0.03874077521745236, 0.1144902851252306, 0.04938904113406616, 0.06762340079031645, 0.05048214518014462, 0.021268098479917934, 0.018369510972632036, 0.05251658359362234, 0.05737485656995447, 0.014188015390367759, 0.0019343651858376222, 0.05963203887785635, 0.03680349973541114, 0.10147943086321316, 0.07156233378355542, 0.07577833013548967, 0.052276422690239646, 0.024709509077271628, 0.025263570677188617, 0.07552726780094447, 0.02368239201455107, 0.02316421971866681, 0.04019419339695766, 0.0422613361039229, 0.06467412316030072, 0.09524739752974241, 0.01660664689787213, 0.039347624105791894, 0.042629460503737775, 0.0639595699706866, 0.040758585692533565, 0.040890211089243816, 0.032116456986254746, 0.017667916160257115, 0.10341217876562189, 0.024432700442811175, 0.04319685203353724, 0.012744917372812428, 0.011493117255609364, 0.05760169903477354, 0.04164316060562288, 0.027609425747106155, 0.013039780784428362, 0.06873483348998331, 0.030331456800922755, 0.13239723029396228, 0.022771486659504236, 0.05642549360110875, 0.031196959955137105, 0.0546140289084325, 0.09200352844932387, 0.0239412282263079, 0.025716171592413902, 0.03242977737118641, 0.07979914260607573, 0.019059668092297453, 0.02266085973279851, 0.035697264942310514, 0.02585651315448265, 0.013760316163121213, 0.04389779567117653, 0.025114853858887672, 0.09132140376154455, 0.03272768215186173, 0.0308474074418266, 0.07442631518408176, 0.07724525827553964, 0.05085300451384918, 0.03313852744477411, 0.028830966348910046, 0.01970693003386259, 0.04360206274976654, 0.041213549989005255, 0.05524848377512348, 0.06670458557745142, 0.02525245857184693, 0.0459935249490363, 0.05373070654909938, 0.046762585294462984, 0.004308263502729636, 0.03484131107407232, 0.04579855557230692, 0.01998828348493384, 0.044487714016389464, 0.07246569700298772, 0.03458611186473601, 0.04536734383192755, 0.02095976341215353, 0.06405475639527844, 0.02554169315243921, 0.03199931831219264, 0.04126023921755053, 0.03623789319047525, 0.032974734016123323, 0.03225969053023765, 0.07844476810386104, 0.07757630785025897, 0.039237288292497396, 0.044572420358177156, 0.07733941814231296, 0.08250648200872444, 0.031378877108856555, 0.0677179973272066, 0.038240067811021884, 0.0552029206958269, 0.025626190735267538, 0.07147269383553537, 0.047516036598432454, 0.05033764567586684, 0.04308886811017029, 0.014101193688299148, 0.035282022304712765, 0.0536341373358042, 0.0405214163624952, 0.06041611837703855, 0.0746610445240813, 0.09281155202657947, 0.08431328505638146, 0.00938252778723836, 0.021590230791198633, 0.03941067314196018, 0.018872765621410745, 0.016416586229517575, 0.015799897899400565, 0.044151152439054944, 0.029162362578415105, 0.05541433798029058, 0.04687593566373952, 0.08562957732788018, 0.03045523554206856, 0.020150606024770007, 0.035168219943560904, 0.023369695991277698, 0.009096460022603073, 0.026242230763478626, 0.03155076617164718, 0.04513418497217279, 0.12603195894870067, 0.0333038798623508, 0.0752181513234973, 0.06012581701901171, 0.04102977698728923, 0.02743378476870637, 0.05211195893465512, 0.05595070677959631, 0.049386922900955525, 0.026143889971858552, 0.0421318672447195, 0.05738337546767247, 0.06465835707081903, 0.0299951039825476, 0.02110575870310347, 0.04276548324513339, 0.014954747786114534, 0.04838617075414908, 0.030512473801331177, 0.03917804288287317, 0.020504398834741405, 0.016364429048412753, 0.018308698913202654, 0.047162364447309126, 0.01902290736325085, 0.07605639706936575, 0.029771722319926468, 0.08487882648384379, 0.02300402115760071, 0.046164638347803585, 0.060605629377307436, 0.05642035315113683, 0.02269693481315288, 0.01259209145040762, 0.03431816878277929, 0.029942337761542974, 0.013061702390381647, 0.019707351382220947, 0.04023870310535835, 0.01416780790614505, 0.11117824188043034, 0.041012551500311786, 0.02351559743645691, 0.014121751657747214, 0.0550802891713477, 0.07746743143446023, 0.06443410015274441, 0.034060836018573855, 0.06276405529089032, 0.05903693028695642, 0.018674620810235222, 0.02954475345059989, 0.021659285956693274, 0.08518810383975507, 0.01667858638440169, 0.02922369749285281, 0.012489267129210696, 0.11710390133122284, 0.07080793636099947, 0.02496833762814922, 0.08905055827551311, 0.009996008124172447, 0.05585542842445355, 0.0661789573308441, 0.06450473345936307, 0.06682996352713916, 0.023075799765666167, 0.010193104352501613, 0.056497528848628846, 0.003118124126734573, 0.06895165169431318, 0.03588682190785485, 0.03931220786105241, 0.004585471939325574, 0.0628006704632313, 0.06961337546066892, 0.035092748791700414, 0.009826543729662175, 0.05660138355808393, 0.03952154521680167, 0.05743054350117042, 0.03579433977363571, 0.009706830042564582, 0.030920622464750084, 0.06564609721423158, 0.061430273232080286, 0.05373978852144173, 0.06657839557456394, 0.06957169261670883, 0.06410302759538736, 0.04155715191436391, 0.03174156803006847, 0.059027415474936853, 0.07637397115749699, 0.019851452520778103, 0.0457121983110424, 0.05167372216801009, 0.04028857542922901, 0.0471099027462544, 0.06837298718070792, 0.0351292758639301, 0.12183843961646482, 0.08952560939735944, 0.0674570524584382, 0.03819198430245442, 0.013178710829496626, 0.030582032669636033, 0.029991970682937293, 0.02662343228416097, 0.0290695644329272, 0.04866034979180944, 0.058950101881618464, 0.11563872753251946, 0.0385812105941436, 0.037181702021869927, 0.03599219347140001, 0.022580841849107417, 0.06068364394107654, 0.063838298252273, 0.052639529214150486, 0.027366625670824322, 0.031164050733129826, 0.036985790356993675, 0.1256058148799404, 0.017680838148319916, 0.011927937270112097, 0.04324850934227148, 0.028652249527494275, 0.05048775677418998, 0.04433507865835582, 0.027931427823439724, 0.0568924050387596, 0.027279716826254324, 0.038915684581884456, 0.07645317698798834, 0.08377751380565666, 0.0478945185069836, 0.05869495246799723, 0.058577568645799355, 0.03702027963534479, 0.05008590535350865, 0.029780430824405728, 0.058325862797397765, 0.07840363684320643, 0.03621167766170637, 0.05453983329296593, 0.029860287829632723, 0.14603733385522522, 0.09719846259442069, 0.11905482850007473, 0.1293030471330689, 0.17596006934200564, 0.15487386694838925, 0.21870639655859242, 0.19567190999946288, 0.18559656676746186, 0.18074988087098445, 0.12268270681341811, 0.0734235214129571, 0.10667306265883869, 0.1591700267407202, 0.0960978010909692, 0.15229291673148834, 0.1932585032116021, 0.08200533027129789, 0.21618552295671356, 0.16216523134179656, 0.17561191302393714, 0.14334600569019396, 0.0990436543079634, 0.187039615946912, 0.06315137019320842, 0.0710509854158567, 0.10723013881473772, 0.2064681572899703, 0.19266146024869335, 0.29026617926936, 0.1400743199572448, 0.14728048005171362, 0.24777407066956644, 0.21100990954906712, 0.13299730696505116, 0.1743930824581654, 0.14848912164809244, 0.22616233195989366, 0.14846575596640188, 0.09534725709067238, 0.2465816394936654, 0.16005006258285817, 0.13247218433647387, 0.13805929421176835, 0.15423954614708502, 0.10387203070305048, 0.16163799431054823, 0.07650094257006723, 0.13095251104283717, 0.2077291226915775, 0.11893043880380931, 0.06952089332644978, 0.1834604838081906, 0.0796135578064188, 0.2245672296492323, 0.10045212227851154, 0.13848232796355603, 0.19752703787338352, 0.13692955967159043, 0.16643632473724504, 0.18699475383806616, 0.19197556640832655, 0.24324892719666807, 0.19093220062073202, 0.10744704128873926, 0.1398611483314345, 0.1468299130999273, 0.09109677912126626, 0.08901503477846423, 0.20524209485419337, 0.12419206090271474, 0.12209915465885594, 0.1456488353470641, 0.19489183330968504, 0.16014023113154596, 0.1432238146662712, 0.17261488513360101, 0.11679519088037553, 0.17552016633412532, 0.17032443545758727, 0.10683176543323264, 0.15580190585986262, 0.25467722766822387, 0.19229735398004133, 0.15066547018866386, 0.05505833692187744, 0.2266489510093966, 0.187519294239821, 0.10755279972668617, 0.1539066196569512, 0.15694624203587734, 0.20521568014256417, 0.1703738940939788, 0.1611364671900388, 0.1843401672498834, 0.1739419639230736, 0.10097614174047786, 0.2120362988282596, 0.17668328698604338, 0.24749188984353698, 0.19518271689453434, 0.16288389842356407, 0.2684711310411653, 0.13190281246939015, 0.15433130815865534, 0.10322834830731155, 0.08464829530566932, 0.1418132016495351, 0.13037895633568689, 0.12272200712393369, 0.21113763172780314, 0.102612980521254, 0.2196007735666729, 0.18046161730683621, 0.22272488012188868, 0.12953477340840525, 0.16795776003310758, 0.13766779263894405, 0.25596796324656856, 0.1497117673317271, 0.1475460520915447, 0.1738875716804497, 0.2795126950067859, 0.10895683970903197, 0.1617349350764867, 0.15275243159023025, 0.10129319488882058, 0.1514620484123307, 0.1878198458542747, 0.18943537206899738, 0.29959290138175415, 0.12941509515287417, 0.16800138107951612, 0.19275051030901172, 0.17721899694973425, 0.11799846986128439, 0.16724727477037138, 0.13375672992439042, 0.15586705397694342, 0.13756293052386853, 0.1330674499753983, 0.23320646445837714, 0.17546819492934213, 0.1894018020961554, 0.0759682433319188, 0.10061257173337283, 0.21018417401900216, 0.1311547735766057, 0.1824584867685072, 0.11148594875609684, 0.15123710967600346, 0.09351886568530914, 0.15976028216461982, 0.11004784850463753, 0.11219078795083108, 0.14340896279581133, 0.15033588384187993, 0.11377356390679076, 0.1263730136317111, 0.1670874381858495, 0.18980856414043135, 0.08591379594778822, 0.08609103038907052, 0.1958821704911609, 0.228593236195945, 0.11472566563996578, 0.10775089474214662, 0.16910099304251133, 0.21412845430595262, 0.13241771548505754, 0.10135504116694774, 0.12334816908884434, 0.2352138293246108, 0.15345801389025104, 0.15966743230819702, 0.21919859272818412], [0.021530136939198263, 0.05445362541884665, 0.04877246292908827, 0.0022060655699592206, 0.025253981171596437, 0.0471361565794195, 0.08833182990671166, 0.02967598814246876, 0.03413238096982241, 0.027377864180673516, 0.020160932889989307, 0.033549208028782765, 0.037360411182406454, 0.050990678174721624, 0.06568953439953827, 0.05302139340088733, 0.054561532733421174, 0.037788891819335764, 0.014445963897742333, 0.07410778348604519, 0.027635271638451565, 0.0547454321396447, 0.014879808107751512, 0.047995358660456636, 0.017072545184243112, 0.04462650233519174, 0.012063077095174983, 0.04836073663506297, 0.05106346418840751, 0.046294789025259596, 0.023510818963029215, 0.04425259397154854, 0.06218590788663395, 0.1013293312562089, 0.0366795543701418, 0.018721034247127753, 0.08714798657644181, 0.07555267127651362, 0.028857130166744033, 0.031637799505504875, 0.024008915924857703, 0.038008058083153544, 0.028124288543157523, 0.009366748291217994, 0.03639971011228139, 0.08742146464365144, 0.05094468991662707, 0.014153214888797413, 0.01876253897564546, 0.029589125263174216, 0.046792282692847714, 0.0066687283481681545, 0.06408480236366873, 0.03690162793763223, 0.055392780266101324, 0.15307184428937975, 0.07722596052072703, 0.022821701807721008, 0.048604536456085985, 0.07089537763667685, 0.06956040048070493, 0.08158238078918188, 0.07208825314357396, 0.018162981329125263, 0.02972797486901043, 0.044948408650534774, 0.00685712660572702, 0.029248968818255013, 0.04011922786312719, 0.05844859774374674, 0.01049823621513262, 0.019174784294239456, 0.03824793553400425, 0.028616961602482106, 0.03193367223796104, 0.0330044582275854, 0.007005039031707472, 0.010994127801349087, 0.040151070307699904, 0.07573008957889772, 0.01773876014105495, 0.07628030924787445, 0.027327899926251946, 0.02197458284846958, 0.006874945332040831, 0.03832105096549757, 0.07519981117859002, 0.059217880254671465, 0.04519837547934825, 0.03647043151901134, 0.01152474998361281, 0.023631742111437266, 0.022695385400326024, 0.044940636688542944, 0.04447057662952331, 0.06279159998220783, 0.04274516659338148, 0.025401121763993176, 0.015791790773941865, 0.06412411416550318, 0.06803663627755258, 0.03614826473377405, 0.05752938416516108, 0.0900634490854798, 0.024387547220554084, 0.017199518512033166, 0.021500899193568096, 0.020238108587481325, 0.08797316286232203, 0.0023872027504107645, 0.034069397051127694, 0.05661803830955779, 0.007842074837460513, 0.02294726361851058, 0.04099424199892148, 0.0393178615899336, 0.016178999381560474, 0.04166178037262252, 0.02478140451374554, 0.040266581044922915, 0.04641128035502569, 0.006869605220403643, 0.05555365106932098, 0.03336364621176355, 0.027180002822029977, 0.040594593081022465, 0.05328368658440248, 0.05395449998397982, 0.06286345902950534, 0.047446617541173776, 0.06062993351670523, 0.011897629874217655, 0.0608170428313315, 0.02562218409542355, 0.013807397054117775, 0.018185803088389577, 0.018945283504323136, 0.05701278426474141, 0.011662995337598748, 0.028515016367178292, 0.03726311035514359, 0.012652219776364585, 0.06652400333194003, 0.01953369840198467, 0.02703341764337834, 0.015330150978819979, 0.022307430814591148, 0.06151807456908207, 0.05632708194635569, 0.038654054064423814, 0.06950164153691261, 0.063018997860772, 0.029965119301191265, 0.03293451056965897, 0.060470338249879504, 0.020397734497824026, 0.018810622484212922, 0.02616222820154602, 0.07553632296020947, 0.04459853629551588, 0.0850161707269088, 0.0621771285190217, 0.12108498448205572, 0.170957668414039, 0.03003948345600117, 0.10631970460376433, 0.039948225547108925, 0.0508287578310457, 0.013998820401367643, 0.02549771395992608, 0.003404167232914798, 0.04347490747609446, 0.0481903433589445, 0.06044474325232929, 0.10018514063689979, 0.040407828505962126, 0.006195344425167048, 0.020838141208514575, 0.06281204686890687, 0.04375771266378222, 0.014878141866516204, 0.03193229902535677, 0.02742927442605217, 0.032663146905120344, 0.02588710113007936, 0.013412113879777253, 0.07998940820295004, 0.019162076810795455, 0.008527754652013463, 0.0552080036892045, 0.03936177374975335, 0.04100070778100241, 0.018031851974345984, 0.020888999870587743, 0.03903316033463325, 0.03330893987309068, 0.06874972623923133, 0.0699671088988262, 0.06712054833769798, 0.0476652360521257, 0.014330166835157622, 0.037009408847699245, 0.019605513399226532, 0.04254160937102091, 0.03512135834523267, 0.0575535121043363, 0.058135876822615826, 0.04765821102586004, 0.026135227432654753, 0.03454861952172172, 0.029619406803601214, 0.019393609648930932, 0.013421440042645462, 0.0517975372983323, 0.02482275027901896, 0.023898045765236024, 0.024992478973863107, 0.006492379696048316, 0.07067415442678236, 0.06086807194796782, 0.037116235978300535, 0.042774764400336056, 0.04050203816845052, 0.026420336629774784, 0.02079424820089292, 0.013659459730279783, 0.034350819450112126, 0.03824821515609661, 0.0950853699337571, 0.04958513282960461, 0.020515679479426435, 0.07931973244394026, 0.07037167227075947, 0.040776657706667344, 0.020184078321401632, 0.0716706815986864, 0.0700360491511322, 0.05853487839621883, 0.05507642425776971, 0.0378021604621843, 0.018492494897556402, 0.011096323930448102, 0.034038565842615026, 0.044026326072672685, 0.03838708774457055, 0.09071723618093999, 0.040896967984735966, 0.03236854013295905, 0.015155171708864792, 0.03949854342687515, 0.02559477729993242, 0.016011385089387337, 0.030199312379643805, 0.016364626316053253, 0.07234300036103496, 0.03505750108630427, 0.04745263899225862, 0.0417559708829128, 0.0733886031253684, 0.0187449534273436, 0.03337388114643193, 0.04062220288981353, 0.022734884893701925, 0.059932804996928865, 0.06534704713210945, 0.02322581893343839, 0.02351211748206087, 0.05982248833583248, 0.03878723845005997, 0.05656405975441298, 0.06843596726896302, 0.018083312015439716, 0.015952957478622277, 0.053668197604917714, 0.024149883763804555, 0.012274594928678727, 0.03985659760092536, 0.035560556552222664, 0.0657175655566877, 0.08744009590196995, 0.020310002108735424, 0.01053451909683645, 0.036418559705658306, 0.018482064610467325, 0.03926197930629696, 0.04381720322154222, 0.005980434737378551, 0.06401595404191364, 0.009793078136299888, 0.033850138856759, 0.03067204800073899, 0.024113919766199206, 0.013953283177538505, 0.07334546471435217, 0.06595995577593004, 0.014599379707848834, 0.08059339192245277, 0.04951286392526762, 0.007705817481638083, 0.053099622469275236, 0.022103567157060872, 0.03096034795406365, 0.03230160703101466, 0.061906530942407355, 0.03871113910610157, 0.05002598961695068, 0.048651378902216116, 0.01952834536261376, 0.053438620206208966, 0.05624671166221942, 0.06422428399204247, 0.023106653956816565, 0.018378269272826372, 0.0361906906830207, 0.012951935397370929, 0.01635811073825725, 0.00451774258474489, 0.04061310942615232, 0.09238425116505354, 0.026496263603950222, 0.06738896256372814, 0.0036997127021858173, 0.009777126270496558, 0.054248807981850646, 0.022874017952070124, 0.11634459328507224, 0.050545335942578894, 0.05919660599301419, 0.030570945462151885, 0.020104665647170717, 0.0336287317857627, 0.05405113814518817, 0.03732287670455633, 0.030718066902350516, 0.04404961514557081, 0.011144382541158028, 0.07708453302902561, 0.03148362239552362, 0.04958781796777922, 0.060320085425290375, 0.045094562904729, 0.010199571092192446, 0.01597630305050482, 0.015819398667513123, 0.014520785790086995, 0.006180749971404552, 0.07184207844998568, 0.03926880898014192, 0.005035577323137513, 0.029155864237597393, 0.018816027234518723, 0.012663974437952764, 0.12019229286740865, 0.18051839974378386, 0.18943889607344905, 0.1280029193167725, 0.11695694268470812, 0.14763617467495704, 0.1639356758565672, 0.14257613329156754, 0.0881239596093374, 0.2095384844729016, 0.11158115050244717, 0.08266417354705834, 0.18190474309507879, 0.18616512658134585, 0.08898350259950084, 0.12211829153520447, 0.11674328842350554, 0.1583567937655795, 0.13481452880847838, 0.17426226528421526, 0.11767568637526805, 0.1547520283249117, 0.12346662926457583, 0.1672506608789967, 0.09197422558622015, 0.17680480385259276, 0.056891351667863715, 0.22235185658979803, 0.17389115697193533, 0.11190829302875266, 0.15413647667775232, 0.15310688515103635, 0.15849061400419281, 0.2043610018107199, 0.08471198785569399, 0.12834725285609885, 0.1186017717625345, 0.16516641142868227, 0.13602194466417836, 0.11151816275331283, 0.12639883079475936, 0.1719290985455436, 0.1934922059937831, 0.11156403609821874, 0.1503568746510052, 0.11093399772841124, 0.11868282386492338, 0.07622185673925184, 0.12956950783489213, 0.09055357681767595, 0.16161170217298693, 0.13754541775391949, 0.18993184300920657, 0.13684417151155012, 0.16577833181908055, 0.2145391233986424, 0.20352662480886907, 0.12430008696091753, 0.07641589148871361, 0.14124971333770983, 0.30754091037857917, 0.18644180689607898, 0.2215253396500503, 0.20566531246708286, 0.13342463080921482, 0.09731247946019135, 0.2193123567849398, 0.0970217107885307, 0.1872610919658215, 0.19778882543886864, 0.12829567215615703, 0.11869734889196774, 0.2485280544046433, 0.10650138235500745, 0.10173716582357885, 0.11697002746645482, 0.1372894371349004, 0.0790748141345478, 0.2593570136495175, 0.15222424460995584, 0.05519114975487033, 0.22632365475498864, 0.09170844670264952, 0.06688424851745367, 0.1427201424995738, 0.1543223908952167, 0.2509564611940615, 0.21522982827117368, 0.188668625309102, 0.10668734253774728, 0.16309110988532344, 0.14205145499398633, 0.20275281471831186, 0.26096460319334464, 0.2167369070793352, 0.10833217161557368, 0.17199954799106046, 0.11001915851187323, 0.07679776333632969, 0.2085379889655498, 0.1407836407663361, 0.12019339603401961, 0.1642469067366854, 0.2944833707184561, 0.07651279395025584, 0.1029689739187879, 0.06938261445611715, 0.10142629500478507, 0.1886124250989768, 0.09334077322555166, 0.17618684668935117, 0.1590679225421721, 0.04060617249999796, 0.14123583182452187, 0.09324439170379793, 0.1508817827749637, 0.11065744764862523, 0.17550821536250655, 0.15569921943449205, 0.15597553202702155, 0.20122483703157595, 0.10831505721134525, 0.13990158245207804, 0.17520744924343404, 0.12090733635329431, 0.14662697640878541, 0.10590955645086304, 0.14900849861723764, 0.1976275639308076, 0.10218937220352312, 0.14003518818607255, 0.07513676980330099, 0.16225083400645565, 0.15103709944073232, 0.1374713983386755, 0.15717300406146437, 0.070330640601535, 0.25081116495834244, 0.08416742191559846, 0.1589773249842467, 0.1515940760052012, 0.09299254029869072, 0.1445398158243587, 0.1068214845332888, 0.11735954487155523, 0.11765387585206379, 0.08032087912602771, 0.09823923900483117, 0.11388272377512149, 0.19288921818858196, 0.20772739133286863, 0.1789796661825911, 0.12349039331198701, 0.12383488006889821, 0.15353753381679136, 0.1295098142638322, 0.08910909505380739, 0.11031656916583739, 0.13946270600201624, 0.23051092280976235, 0.23060210259451022, 0.22118119763270502, 0.21743245362754793, 0.318296815478994, 0.16544255548186843, 0.1609583057823681, 0.11501316311618975, 0.11379806339860925, 0.154937467567863, 0.10829105567667754, 0.10050514322375098, 0.22779727084261758, 0.10863332843948757, 0.10715629559971633, 0.1860308313682195, 0.07741818730268749], [0.0051811531809489095, 0.04231500822389799, 0.03552003050102823, 0.03283750085580734, 0.009614294282190744, 0.07220626898830937, 0.049920556766371575, 0.021204155036098054, 0.07830473489218182, 0.032539232183367975, 0.08209996511258426, 0.043046534091474555, 0.030417574659710934, 0.05122734954760921, 0.041329099030624476, 0.014112869825875087, 0.024248373942569863, 0.02473169306833898, 0.0548198843945659, 0.05914691753024536, 0.04403265395892724, 0.03093391217501654, 0.05538983082759285, 0.021635839835770672, 0.005840439351290585, 0.05336478465206681, 0.031255071554633404, 0.04634177702809534, 0.09025775962659428, 0.05010226899157128, 0.039372866702896935, 0.045875263956165126, 0.07486617988756589, 0.05192250922142018, 0.009322539272327578, 0.019001579475438884, 0.03419637612457718, 0.0031616424694807543, 0.036381274206383575, 0.022600175993096445, 0.022690993801300085, 0.04195243413109453, 0.04805484155733739, 0.013303766064646264, 0.040542200327880924, 0.03257001359616557, 0.0851570772788217, 0.043490378621725306, 0.03311759026180352, 0.05006222940620877, 0.0256992410492873, 0.030368217529969353, 0.06553839291295697, 0.06230366326147511, 0.07621296245845095, 0.038566540010393634, 0.11806679724325096, 0.08896272629499437, 0.15194292180240154, 0.014192576486346944, 0.03581310126690134, 0.0551408177782451, 0.03235826689389444, 0.0088842929295835, 0.03087545775117413, 0.051619429516816334, 0.05744198502431955, 0.02581442045348306, 0.02086681013386096, 0.07171436393212888, 0.05746139386188119, 0.026599038129432068, 0.09804802345893077, 0.047826332851283015, 0.01559246427214314, 0.04982280011679377, 0.056314161873512694, 0.07444860834267832, 0.022581621343570373, 0.026494162607817884, 0.08527196748482604, 0.030438712940761642, 0.05186411799983152, 0.009780566962886482, 0.008063093597640195, 0.04295224015931449, 0.062125896389085444, 0.0733210571530846, 0.04793331319946916, 0.048189983297620094, 0.012632804235533602, 0.03702581462059771, 0.017175428877254168, 0.046544338336154345, 0.02854150385716029, 0.04115683266953115, 0.05151657455210244, 0.010855550156725992, 0.030747612998370203, 0.06255707365550822, 0.07823671394538495, 0.018276663031429052, 0.022549330737561952, 0.030981898007373658, 0.01101694189973416, 0.020622803469098384, 0.04456793874382012, 0.01742696810153223, 0.033238923267251065, 0.078590156270131, 0.024105772421124484, 0.0705331482834393, 0.007430518519193415, 0.010342230070232144, 0.06006119367215903, 0.07579866210900008, 0.03966429037973285, 0.025994577520196478, 0.019317364748266917, 0.029846446536060785, 0.08563919173132989, 0.03324113343091261, 0.030730896959862405, 0.004143778200922234, 0.037865370376816684, 0.05957106593996287, 0.05226727176998412, 0.013472720053076986, 0.015210836615052917, 0.09034702419153146, 0.009949519036097393, 0.014411809782858097, 0.0297257857727668, 0.08017464060216181, 0.02356898610390002, 0.02672556329578642, 0.04506107337111908, 0.07614470402439756, 0.018013766553673535, 0.01934971472608947, 0.06304568836405393, 0.03540872175606989, 0.02743744475376462, 0.03897900557926586, 0.04539226084166477, 0.05514282492860671, 0.03505465506966557, 0.08490015437165577, 0.03813518654374826, 0.047581345593977364, 0.04834005609154702, 0.010451266406885078, 0.07509971413040355, 0.03412277805769155, 0.014038740285491992, 0.00819383799323752, 0.04011345922105736, 0.02927818741168707, 0.04472965607419611, 0.008498108964563619, 0.04658290320226262, 0.051237657260630405, 0.029553536648651766, 0.03967499262803505, 0.014085772338383382, 0.0041486581809999, 0.03142995985164758, 0.01432599835923963, 0.012432507674900756, 0.038689336243776545, 0.011082411773743169, 0.0874010177569524, 0.06921615121105025, 0.005987699166120541, 0.019337570317269816, 0.02551546230191185, 0.06500929428805267, 0.028622289743995475, 0.02625114228125782, 0.019288400879069682, 0.03144872900579245, 0.019195129674288536, 0.06330921877956679, 0.02215786363869425, 0.03811291253734981, 0.020349511178210378, 0.0541353848342213, 0.027359426359555898, 0.08791593609437828, 0.0029762585285014564, 0.015474966494366528, 0.023625021605121515, 0.014037715642893267, 0.019551898735845764, 0.029940190800135175, 0.017957384397666303, 0.0725278343945261, 0.08329498566566937, 0.023223532160984415, 0.021589284672612147, 0.03257872401586464, 0.029545467827589284, 0.07385559500225129, 0.03314440716959296, 0.07949197965283548, 0.08654004984324978, 0.05234960706964616, 0.01865347869874489, 0.05509997763100171, 0.05108681071789996, 0.07712666020398179, 0.022152516344982772, 0.02587418488767599, 0.04386856175598599, 0.03337605683613689, 0.05527029812876737, 0.011672416303847587, 0.06909640400760597, 0.025195080501538132, 0.05834936637491469, 0.08319023080290326, 0.02719828359512312, 0.062066244952861345, 0.030472972392735463, 0.02093529456385201, 0.021345046266252478, 0.061712829441192656, 0.05774351340087672, 0.057108771251214135, 0.02633937071227739, 0.04467122271777161, 0.05461874034916682, 0.05848223283406227, 0.013691165236636035, 0.030490360673396822, 0.03900442054615386, 0.04546280987861176, 0.06248793422034191, 0.027547809295356277, 0.04864701220104772, 0.04725399622393232, 0.038120358911973816, 0.026680944419856516, 0.04661200688250604, 0.056436992580852205, 0.05006050953881876, 0.02693220785248184, 0.05169827528598328, 0.03627482245886519, 0.12580510499256273, 0.0418005533696663, 0.0748574847896253, 0.08774262402326831, 0.03326166458728333, 0.02616376995349363, 0.04952713997373658, 0.02637957692176344, 0.02868866360175514, 0.037609336131642905, 0.04960878579426677, 0.02532683996363513, 0.06238104197226706, 0.03368027418130829, 0.07632429801648663, 0.027248468099822922, 0.022278545469406153, 0.051738636628274, 0.019598944195275827, 0.08431980446461709, 0.02024667345047478, 0.05072525169159617, 0.051583630228114706, 0.0588257581506285, 0.01622118592833079, 0.013417293591755293, 0.059713355280579104, 0.021177937592109366, 0.03236642573028803, 0.04836990287707699, 0.055438109688581004, 0.10447628255332671, 0.0443312980144495, 0.06988145260801239, 0.05706288258454973, 0.0129486191942687, 0.031413665161498135, 0.03256727483183627, 0.05254092986785597, 0.017077164694426522, 0.03983401332891757, 0.030897507676854733, 0.08206198247329843, 0.047199205615587776, 0.07366909855796445, 0.028695820778187726, 0.03947377963472278, 0.07737551620530506, 0.0447383894765329, 0.022123138788306428, 0.042071453551010746, 0.020990663568579385, 0.041429973658054106, 0.04997882541389235, 0.08036870599514054, 0.0072496896891313944, 0.0538520357241073, 0.03419704645151093, 0.03323749451327228, 0.021022651569857713, 0.010429168600709209, 0.044895399196614186, 0.039484267378406185, 0.0815790176631943, 0.09678115151942739, 0.01805641658363804, 0.033129253950450695, 0.06399849489811929, 0.024793790240261345, 0.005578487076901741, 0.05051833134324801, 0.029012421934655117, 0.05466056491939291, 0.036407796170322165, 0.0735087103901371, 0.040991518556350665, 0.02301058078545236, 0.039231236197895585, 0.032990048113729686, 0.11978941488890879, 0.03433344457598944, 0.0483905949119118, 0.04530919392803504, 0.03603091921597239, 0.05877200176098174, 0.04690710012049926, 0.05547835611768308, 0.04960885857261958, 0.07987189797624465, 0.025415836397798795, 0.05400728727240236, 0.04091155429881427, 0.06232911653275933, 0.024250275755841887, 0.019625632783337947, 0.009211772534575675, 0.016793572351396564, 0.061891354740627354, 0.046726808988399086, 0.013757924053577647, 0.06601608703814207, 0.029544332102241538, 0.035305307547171275, 0.10999643634403906, 0.18308559102156471, 0.09544133268777402, 0.08680671738881258, 0.08040927801161044, 0.24242008134963053, 0.10325644841237415, 0.16943502269925612, 0.10287829975207007, 0.15240116495518916, 0.15958919940936953, 0.12315784986581534, 0.13796996835979725, 0.14692175172029004, 0.17479492621796747, 0.08515141588906128, 0.13930371211421105, 0.10291836615050994, 0.16377311199903488, 0.09240153410862531, 0.1500093618467931, 0.1788995946727453, 0.1933872213046397, 0.10746473791979014, 0.1945103981321858, 0.12130849829484379, 0.15889463345369986, 0.13321818543537972, 0.20321807523648586, 0.15621232980441663, 0.16452856662292636, 0.09030780048980828, 0.20346550631426996, 0.11932066867067931, 0.18486263921424267, 0.1657598691001054, 0.12441482394933702, 0.16629450654070224, 0.12512427499337545, 0.11076787156203102, 0.08202857337892056, 0.13912420239179366, 0.11199026443665067, 0.16816232083064897, 0.14258452961521764, 0.09654630726623921, 0.21360317845979046, 0.1703176938838536, 0.07761133339015708, 0.09985376930525226, 0.19132151118209287, 0.12671588394310207, 0.1658107679817946, 0.11203488905824001, 0.13530157686721894, 0.1291142677467677, 0.150226118764089, 0.2484046529618002, 0.28368153098610144, 0.13103250594389054, 0.17686091213216706, 0.13964046904396626, 0.13811420739418076, 0.14874910124607627, 0.10079569739079285, 0.1342184970816297, 0.1991426253751401, 0.1787962953770353, 0.0685222823953917, 0.14545582715542088, 0.1080592068272733, 0.14924471416781027, 0.09646277303897566, 0.1632486482060725, 0.11610670766282467, 0.13514321117151168, 0.2103937756750853, 0.13734842590507002, 0.08456359662476086, 0.10121838640301459, 0.1408772107454077, 0.14862727794435718, 0.1358329048079829, 0.08010154815330621, 0.1366968374819525, 0.1459537536626862, 0.14155624043797294, 0.09234147281536172, 0.1952370631718828, 0.13132230168388737, 0.15805835655379682, 0.07798952035485737, 0.15192193099327628, 0.13602366070112876, 0.10446236273574253, 0.2561546435519572, 0.14201406990328144, 0.1337067809917273, 0.13876242503043146, 0.17332366968114532, 0.10430521511983487, 0.18488706209726874, 0.11736041821178891, 0.10821378804863462, 0.22561759748045476, 0.15397843273897327, 0.1265324058852369, 0.16253563485318617, 0.08955784637721316, 0.08050863961538962, 0.09173687622551957, 0.20084876446954666, 0.08964809919557265, 0.17786280191954107, 0.1743343081926146, 0.12259068433195354, 0.11135246559617021, 0.13756645452832023, 0.07753264083857499, 0.2150460284563803, 0.28890465716681174, 0.14733664961832185, 0.16906417485687042, 0.19743830956999334, 0.13450076983821008, 0.20094671647154516, 0.1554659150180317, 0.2132696697428342, 0.1700379798609403, 0.15101330474980418, 0.062446967668591015, 0.15743483759222493, 0.11954039800912143, 0.19654992336948074, 0.20804813702500638, 0.1793978582586973, 0.26860430776592226, 0.24629424926975083, 0.08365913023871761, 0.08959500164154077, 0.18004854269806417, 0.10455705120318359, 0.08684031800517152, 0.15616619598961648, 0.11069514683537907, 0.186196367646898, 0.12338332486368957, 0.21014626798850877, 0.14434245625330558, 0.1414072056931834, 0.1345220364389881, 0.146563513685138, 0.3244507384877051, 0.10107876687881448, 0.13733717973434156, 0.10848309093665694, 0.14119699116676085, 0.1285907539028314, 0.2824765053247252, 0.10929744240016707, 0.13360849191104213, 0.2729788230311486, 0.13935056605166005, 0.11394569620249734, 0.1159627827244901, 0.14710743611137714, 0.10408462010203831, 0.10175554427288233, 0.04186156078151638, 0.15371879021967613, 0.13213702086960116, 0.12439758697104071, 0.1237595123389075, 0.07387463228716966, 0.094703781538673, 0.08870001176312085], [0.08609157431149676, 0.06233257158929783, 0.026541993307370334, 0.014934286535266909, 0.030139113190553846, 0.05246617500820468, 0.04862138272954091, 0.04723191373951493, 0.02863431349396706, 0.050857807885134415, 0.014998214657328304, 0.05584320932206127, 0.049760275850853616, 0.04815660101631957, 0.04521426797333745, 0.06619140625961366, 0.04227815173386086, 0.03689264938715966, 0.013442967113317742, 0.0293084210716188, 0.05014613518611558, 0.060731218001174356, 0.026300024436486345, 0.03190062320490759, 0.061909606785423336, 0.04461071709351194, 0.1132972180963524, 0.016848278690069433, 0.06561461866142289, 0.06684173829853535, 0.058506019864111185, 0.025210678051676483, 0.00720254751110089, 0.040272376500070095, 0.031330259253961906, 0.055090416853706685, 0.047639890033150875, 0.04231811471043095, 0.018360840772548993, 0.10527666823397722, 0.009950269802263188, 0.04028259228254038, 0.04093729485307009, 0.011138837022196141, 0.02506793097352549, 0.012999358155103702, 0.04984265711579112, 0.039908220435702996, 0.0306107341537192, 0.047752275131642825, 0.07532382549177255, 0.06982300009938978, 0.040059013352278745, 0.022054575834303133, 0.039489411658817725, 0.024263025374121727, 0.015992099783503484, 0.04728143366294042, 0.014381451633638673, 0.08474410992235908, 0.044627544214768756, 0.02448332161762782, 0.08802436817918094, 0.0038276218542558776, 0.03668840268566724, 0.07804644834851066, 0.028174609028463884, 0.1569803482702663, 0.026404028533086665, 0.034497938975090944, 0.09748339367609832, 0.040005785563299735, 0.013299529598424993, 0.04716405750162179, 0.07527730863301024, 0.0705695681033596, 0.03692519280218309, 0.018124144501803864, 0.06525619676516903, 0.030952246574264382, 0.007421107607848583, 0.03748605343242807, 0.031100844648937066, 0.024803728315859072, 0.021149912180619377, 0.0392808327301135, 0.022240821384794773, 0.0487192428009885, 0.08038939036909612, 0.01648051052113935, 0.03970416908663127, 0.027341275821409883, 0.05894804876598139, 0.03698585164402762, 0.010020186816672645, 0.019340594449350913, 0.04054606524145892, 0.06642161568085994, 0.038834643970814445, 0.11667500700681441, 0.050434099975973375, 0.06578986127410205, 0.03189690576325501, 0.038104454926665754, 0.05937260320229877, 0.07163387873480398, 0.03188570938824165, 0.031437996113973285, 0.06961339078242741, 0.057475252392431425, 0.05172152222404557, 0.018517846662190654, 0.0064661809254527814, 0.010212590756465592, 0.02434304325781282, 0.05865444939944053, 0.0681849355779348, 0.06493419468883546, 0.015911938258326583, 0.07775417814451842, 0.02551150162734332, 0.03275529962153204, 0.024181385299250967, 0.0070091629787648645, 0.022045241052945776, 0.021656648699013938, 0.044395350625798594, 0.03367329895075771, 0.011046293600943061, 0.09880772987080198, 0.028762876454199997, 0.07997850677178753, 0.043215387530865214, 0.04218781081539008, 0.030206195679643465, 0.05370245322645192, 0.019303213189085646, 0.07983932391770425, 0.05504688773784907, 0.03817586964296718, 0.024977260637247277, 0.03978923548974338, 0.024318777422811237, 0.0759946427217895, 0.04334835358144295, 0.02095036925898204, 0.07663027353344426, 0.016577949244228583, 0.01793945794023814, 0.07168449416396118, 0.013610647480574348, 0.04126832144515168, 0.023189581059400114, 0.04533770389013714, 0.056840203807599125, 0.03366607857207137, 0.05773324782269136, 0.05010464003369693, 0.04388703979671963, 0.024361896681629365, 0.015809304501500823, 0.10324566189440028, 0.02829925727940375, 0.039635002838387605, 0.005671117161851256, 0.03881808881077074, 0.10945395416309757, 0.02703898901780767, 0.02449115869709321, 0.05545686352096739, 0.10629623166976437, 0.07573706097900867, 0.07779790644323634, 0.05087839266765983, 0.03612075451641314, 0.0374562602730528, 0.06592739703914811, 0.040179055499573874, 0.08241064440939697, 0.009310925379395485, 0.04958442036783503, 0.031653927571530786, 0.04148965190735556, 0.03321599808611697, 0.025024558905692353, 0.06693106415050645, 0.01521961406744536, 0.030035555340169422, 0.046376936633380196, 0.07144049516007786, 0.03572818042049485, 0.08608889300376178, 0.05486718266301098, 0.036497056904819705, 0.031101547534607595, 0.005824494188756592, 0.0399499569058178, 0.07010930247845189, 0.08049742408817814, 0.06515040768370514, 0.034526452767632665, 0.03533380601795451, 0.03220407254693489, 0.02093892390539329, 0.06016984409202011, 0.053152448062093995, 0.012276516851758765, 0.03446590117809754, 0.07273477006463275, 0.002044394444261167, 0.022971918243133736, 0.05371146625088108, 0.03899726145450146, 0.037846612713990674, 0.045056526639288476, 0.01586549226269727, 0.03765710937460104, 0.04569426802317462, 0.04554555120487367, 0.06726457286746272, 0.07311708624324492, 0.00501383526904148, 0.008976704200669643, 0.05531072075809202, 0.04885580946481036, 0.02830469458844633, 0.0639744244155384, 0.06674456770621962, 0.11570493285093578, 0.030419170037813248, 0.0391338242878837, 0.05405041802253935, 0.021249350393190983, 0.02114421440168254, 0.018540082364192894, 0.09284932016124649, 0.039377195099669124, 0.020156288481948358, 0.04716706822716421, 0.08703456725925209, 0.05934982740830991, 0.03750545460911047, 0.03345329765110247, 0.07187978529761876, 0.027402936323215405, 0.061898448714806195, 0.05915693029941571, 0.019067152771317673, 0.05435670380510631, 0.011871697797980762, 0.06650308913160717, 0.023703325367082032, 0.028135799014219837, 0.02534940125300519, 0.11115103809823913, 0.021426387566832766, 0.03101281731599762, 0.03300617043409617, 0.08267605557076393, 0.038448026208507444, 0.09799052089933427, 0.047202476811024456, 0.071046672340843, 0.0802151743142355, 0.07285227263045889, 0.012174735367748768, 0.046385758135828285, 0.05161259218209213, 0.07039348279396374, 0.02125884988345206, 0.03183059702296892, 0.02631860589908977, 0.07819292435963308, 0.02783565342636599, 0.033677075764224414, 0.022237879607165535, 0.020415659040032376, 0.026202708287464998, 0.03198417658436924, 0.042211314392907005, 0.021352272390598254, 0.029635630630617662, 0.06019666099980955, 0.027420818730587923, 0.017844911199063063, 0.070109179904384, 0.023091613735643127, 0.08511210791766645, 0.09533916720219197, 0.031506162617475755, 0.019267207056644465, 0.017392344757794373, 0.02304669417020294, 0.0591314425541749, 0.06787512196047653, 0.009080220873828137, 0.05144577270614044, 0.0033151547587852207, 0.040350563433622165, 0.05961245384007212, 0.013484878826045222, 0.05512783258792855, 0.012780088469416145, 0.11397481520449924, 0.014190837466758827, 0.038259465157264666, 0.022189506900406653, 0.04105684670409368, 0.0374265858573058, 0.08043694910743544, 0.035568010587725914, 0.002171832452257795, 0.007902601529138104, 0.0633461059131209, 0.054601032226797075, 0.04032156700568815, 0.03410808066086423, 0.07250638393264625, 0.03204373417482261, 0.06525502465064488, 0.015331836372253396, 0.031099345031825286, 0.05710466118950037, 0.054657351180550554, 0.024703326747722687, 0.0654195420323841, 0.07549271723555942, 0.012534311183938577, 0.03792271205794908, 0.03613416871596729, 0.019095046032640724, 0.04787392989401856, 0.03983242369647469, 0.06834246623780459, 0.03335613088922636, 0.025325144994102662, 0.04738362596159981, 0.06506737141359238, 0.04099776983381279, 0.06049903207308343, 0.035717895690111384, 0.022994921948280067, 0.032231973469137185, 0.04172963661051566, 0.036969905523883725, 0.030868210559410435, 0.09976623609902398, 0.06070022591419759, 0.018129574149967204, 0.02283136792210562, 0.04644678086943684, 0.02733078233206705, 0.17475302120850933, 0.165512744457491, 0.2341984870332864, 0.17538910401203942, 0.1760679804870198, 0.11219708519356866, 0.17628501319596845, 0.14995222700940025, 0.15767702862860697, 0.12236429768944941, 0.1793639205636517, 0.11289700610382904, 0.1476801940870862, 0.16915504820644858, 0.12622334303394442, 0.3025972224291294, 0.12270418025793568, 0.0823022812725075, 0.1030022987434941, 0.18935490219343096, 0.1428927114653972, 0.1508236520232693, 0.10809714350128367, 0.19132699637163073, 0.1469880336474988, 0.17828986529381047, 0.23216234790461682, 0.11632911830900178, 0.13465884442050613, 0.16202566544375113, 0.13602238899517444, 0.14231612305006675, 0.1434651017189026, 0.1375831246015526, 0.11224098969250919, 0.1574621256440878, 0.1234887615447083, 0.10064655539369392, 0.08133340221379073, 0.18564063214486648, 0.09410058688973227, 0.09756168786195979, 0.15385818757837819, 0.2094970850814735, 0.13852608690579093, 0.07128348543999657, 0.1531432283621642, 0.21781563548551452, 0.1415846163346883, 0.23048320574866188, 0.10967907676052664, 0.16299697300118787, 0.2093870135685129, 0.0999516906637338, 0.24623077122434495, 0.11377095154696897, 0.12297451736465578, 0.1055772658137064, 0.2003292496045751, 0.22892556513749787, 0.1439124051361315, 0.12151310505766062, 0.1870956322959354, 0.23406298140123968, 0.09679922353356116, 0.17573526850150478, 0.0911592459306121, 0.22583878238595304, 0.11682629405010132, 0.11038761615993516, 0.15770194180790456, 0.1129929279728282, 0.10135877201513899, 0.08721924807515838, 0.18480646964763442, 0.17181207095423054, 0.14185466232799715, 0.08487159461383859, 0.23197900774257801, 0.09411486676864086, 0.14077591860005934, 0.10640771278450567, 0.19235709351637673, 0.22297061048448089, 0.1450427831901658, 0.11591948343500977, 0.19090716486736653, 0.1259984962281681, 0.1408046928624953, 0.14314789535297504, 0.10743302187972492, 0.1479999132214054, 0.12644163978796813, 0.12157994622905409, 0.14259732328355312, 0.07694897377082417, 0.1114255044188711, 0.11682977208927756, 0.1603000370725509, 0.14128837013436904, 0.13147285328276698, 0.1661442307334754, 0.1538193315988587, 0.1661783982548983, 0.1747562387777913, 0.13378476874241907, 0.1392914240639056, 0.12587266628660504, 0.1279025158334163, 0.13001909419413538, 0.22342217335056877, 0.09550130971136594, 0.10954518757400014, 0.11051881637784744, 0.0926499457789525, 0.08905406695820632, 0.11112165862634299, 0.16618379151388524, 0.19446421835211017, 0.21690956797570954, 0.16872855173724313, 0.18052172456537524, 0.11587529548353727, 0.13260189834381306, 0.09343862563612, 0.08007331015241724, 0.08773204434903399, 0.17078578892734744, 0.08241017709576315, 0.13666323686559356, 0.09054306609135482, 0.1675807528438107, 0.146879724136764, 0.20954475107212223, 0.1320323426156275, 0.123140643531036, 0.0630246898940494, 0.14082390634763625, 0.18248727635270168, 0.12909511554866068, 0.1218408910978225, 0.12343515071176714, 0.15821016453687223, 0.11829478500951683, 0.12991225557221522, 0.09475010687545424, 0.18034901770372547, 0.08545095626745494, 0.1004643030765076, 0.10960981475129243, 0.22793397157182618, 0.12352374111933094, 0.07550096034162468, 0.13768185801323385, 0.19143909035671144, 0.1376702900855772, 0.24412029092350315, 0.15792323396571223, 0.11843180749565364, 0.23135597907727767, 0.13469351755995906, 0.2549691071673747, 0.21477000697726206, 0.18702645455637287, 0.11255184518954447, 0.0952554644355851, 0.19813102159288623, 0.15344512829136464, 0.12047864121174622, 0.15142306985874332, 0.22294318453679163, 0.1635180047202495, 0.17695213788219039, 0.17421524280742293, 0.08717208004166042, 0.25097489326951966], [0.04544600573999267, 0.071022440979798, 0.05366454719595852, 0.02422881571786298, 0.029287074031608722, 0.029931286943235227, 0.01606431506168578, 0.07576574331089374, 0.05221622733158931, 0.047334355016749714, 0.027552555210047194, 0.07112473670032717, 0.020103254130170233, 0.014572299457335425, 0.02359760906397095, 0.03131728938540384, 0.053593599793290904, 0.031224315039693352, 0.02964597664803507, 0.05843652036762046, 0.04884685772741514, 0.0504072945595028, 0.049083575065578186, 0.026906070847725196, 0.0042547173084571, 0.03747257411540036, 0.02906424012185345, 0.023150447373008056, 0.07604780156285533, 0.07717650188433547, 0.033446218998682116, 0.05832611560641278, 0.041797113634886286, 0.029110197736431035, 0.05816794143268659, 0.058194076522223415, 0.028954331402576743, 0.041135841860405864, 0.03223873419506896, 0.055614612515895605, 0.0354444635881772, 0.019029572328192093, 0.013697391616240626, 0.037511548838548125, 0.02921343191466745, 0.033761081135561394, 0.033020457973884, 0.06973165177529858, 0.02369458047342637, 0.053926997427498145, 0.06533229227868781, 0.07032664162257025, 0.03168240114445648, 0.02708428013589113, 0.019644206585062128, 0.05666738203276069, 0.038376749388032386, 0.0691358345530687, 0.044835491120935454, 0.02819776403597526, 0.03436895658171946, 0.05029025930731047, 0.007274459705748145, 0.054128658582246116, 0.026262938120071928, 0.04356029946657439, 0.06785338038518544, 0.1157773128380218, 0.025277291311912482, 0.06674807638891282, 0.025645766196952715, 0.07051550527854313, 0.026123847196539565, 0.03319271667409809, 0.049943229138490655, 0.01620840758175379, 0.003527115726272666, 0.01735357304794654, 0.07576145321851777, 0.03358843556094555, 0.03135254858211885, 0.07762581245192597, 0.039759384873773784, 0.047345103230327375, 0.04074496464923986, 0.033167278724572355, 0.0738816190090391, 0.03390523973071287, 0.033752776742462194, 0.051257154198303345, 0.0894788014251859, 0.03503862851028962, 0.0659672489329692, 0.04463386060970445, 0.030199015520573146, 0.04765390561172559, 0.012721909837226474, 0.02789261014831643, 0.019707067929688963, 0.06887472114495694, 0.02512313526934914, 0.0551923984781869, 0.048247949340410774, 0.058047022114718155, 0.03127896009133228, 0.007203079942208265, 0.05595239983390897, 0.02633474928687417, 0.06099475607756646, 0.02731944614600751, 0.12402724474668504, 0.04413164784050277, 0.06441058125346899, 0.03870445881940184, 0.06250381905345187, 0.022158945737887296, 0.10977884439090568, 0.02741665312749965, 0.019680793029105952, 0.0669138731374856, 0.0768242699785098, 0.034580936940807494, 0.0516003079622263, 0.05264581879600883, 0.04339289776380024, 0.009797519531040903, 0.03000526422364337, 0.13787921758428698, 0.0640079101187087, 0.02814258463800915, 0.05549091612920166, 0.06252603943369563, 0.06634369687808138, 0.0724274309111699, 0.03480518236756325, 0.055355418158034166, 0.04531620746298183, 0.028330387262206887, 0.030795972298590407, 0.05176817314819463, 0.028566853706574732, 0.020560229407443155, 0.031154189266324527, 0.05457365607482292, 0.042071001559135415, 0.01638447373895155, 0.005928439871152683, 0.09770629461854698, 0.01738981858286406, 0.021761114363588636, 0.05634485901663861, 0.06951287238588257, 0.09695247942281347, 0.020973384455447237, 0.03304980297182356, 0.05874271038919688, 0.04683518361660742, 0.08306278441581996, 0.026110783482210773, 0.03553966150408791, 0.052845656661497015, 0.00861593232970805, 0.08346954646009593, 0.05196306974657121, 0.02241565797087406, 0.03607532550250331, 0.07614878727303398, 0.06590695781332832, 0.02960257202146515, 0.07553578669866247, 0.039477364926208416, 0.04157327806517001, 0.040333820582037015, 0.02786665700466162, 0.028194688192959276, 0.007312129206594921, 0.043825044131447236, 0.07525666256345089, 0.07639284756395125, 0.051714826615587364, 0.05462663105478691, 0.06268272356640908, 0.034466016091286175, 0.027053615551501996, 0.09341709856544772, 0.04154838403807052, 0.05330964930415635, 0.04970608279109002, 0.041711066639231104, 0.03163151949974558, 0.05131560287648632, 0.04463253527759545, 0.004794486101731779, 0.032991511341665065, 0.04049516635976973, 0.062337830782898014, 0.07980180859205224, 0.016298089664609685, 0.022770988702353452, 0.028908963675700852, 0.024256500220226667, 0.03569408184698513, 0.0752845481638947, 0.01206995656473502, 0.022936279832896207, 0.017861320802401152, 0.06475335963430905, 0.023284667892561808, 0.054907107335184856, 0.05669325665240327, 0.017873154945611473, 0.036670449415161725, 0.0378745902449854, 0.02913847404171623, 0.06423742239994389, 0.04204089047327157, 0.014501037958618856, 0.05667416191089058, 0.009516590301157727, 0.03335180632289379, 0.056111294130283984, 0.04053287703784243, 0.029166551164141106, 0.060096464360192905, 0.07969657109389383, 0.026789901274887305, 0.034828739571234876, 0.01206567700606801, 0.002820414937882414, 0.03636292640059706, 0.011615153146727432, 0.0628757126058542, 0.028463721034988284, 0.02542030077517754, 0.07005357724283973, 0.030667602775558352, 0.09878051842773154, 0.08073681890363656, 0.00767727065155463, 0.031421624815031406, 0.07581824331634468, 0.02100360279362048, 0.07448590916371153, 0.10401219414967684, 0.03337411863368846, 0.009457666648461694, 0.02355457024438487, 0.0918605151556192, 0.051182583199753884, 0.008553337200634904, 0.039114147319548556, 0.04249549087797923, 0.055473437833209197, 0.05195087745725628, 0.053119096424310445, 0.014108713798885866, 0.030357708718868035, 0.09055731532674643, 0.0459549562524884, 0.06956853633446079, 0.007869549144449975, 0.07529580199550237, 0.03840185408931106, 0.01651251575939598, 0.04238037850647684, 0.0236013226751839, 0.03396496394528978, 0.02442066328630092, 0.0163294667107684, 0.008365945391086562, 0.02335410227157897, 0.03738366961178761, 0.02711634091552227, 0.1383020827967313, 0.011905872980282914, 0.05396980259026732, 0.018443804264308947, 0.03841399275247128, 0.06816536969234867, 0.05374143178003931, 0.03377134288330713, 0.04493577203022377, 0.03203556767754978, 0.07366040346002387, 0.05491465713167864, 0.04574519371794117, 0.043102948806218566, 0.0414604333139235, 0.03281636448997644, 0.02736599939394622, 0.03040909981204858, 0.023472146844611536, 0.025302995476991903, 0.05826756733679964, 0.033891588043902195, 0.07947500314443343, 0.029630118628002466, 0.005287385156994025, 0.06086890698380529, 0.03937839402727062, 0.0308961957512844, 0.04614591898937379, 0.059887375983019034, 0.058921522971603184, 0.041446839083707145, 0.024805938479520624, 0.039486002567554676, 0.02992733392954594, 0.0069767488410786525, 0.03077731805763418, 0.07486226517827281, 0.019210100947548787, 0.04048062218052726, 0.0426472912001754, 0.05438113434901161, 0.03766364793503477, 0.06576410539808773, 0.04195696171072703, 0.049427146347419876, 0.04580617048627427, 0.0753641217165897, 0.014615580552227557, 0.013704015403955936, 0.08483347407872639, 0.0680667435329768, 0.05781399348991052, 0.03789530526245794, 0.031374179074660904, 0.05157941674453117, 0.046419305126032526, 0.017286775926608714, 0.03867301474054975, 0.029677889955740784, 0.037897641830627, 0.03587642992516199, 0.018765992116964152, 0.03749775159503183, 0.013786140029438803, 0.03518353787160689, 0.04394122136516437, 0.03450600971137324, 0.012165820019529953, 0.05403968130028056, 0.036887290602129315, 0.03212087156791841, 0.01503003890731282, 0.04081569754728868, 0.03844259464512429, 0.09311283908544049, 0.08138164277038268, 0.043400527999526074, 0.03045908321866826, 0.1533316859915372, 0.2113096491103211, 0.14836115432122063, 0.14716562815010548, 0.08611556818528522, 0.23618884474760105, 0.1298111319662102, 0.09068610236769722, 0.12378174421047011, 0.12333857766803234, 0.1439345297553847, 0.12581857281827158, 0.12320533965624149, 0.1419780331273233, 0.10990632142150596, 0.1552810426801443, 0.07680983688201636, 0.19830942814869268, 0.1056464052488727, 0.19094868683286254, 0.1558039589754997, 0.12442481373586964, 0.09937573044050126, 0.16086102793774298, 0.1011075334803712, 0.08635492469634741, 0.10822160980634152, 0.17212124871871165, 0.10216720161899444, 0.09571808195042034, 0.10888224572784479, 0.13160074400084634, 0.20946273369894874, 0.1579374219140699, 0.15815287648189455, 0.215409429924142, 0.17480197422687085, 0.11388588771824876, 0.11611862799092648, 0.13825208789879276, 0.15406034285983733, 0.09379149339492283, 0.10571238840179098, 0.08522465389462248, 0.16411970549773786, 0.1670204667795089, 0.13507544303372984, 0.1385385588171982, 0.13919292047860163, 0.1226779264247706, 0.17291756647248424, 0.14084619950623284, 0.13368287904848977, 0.11739980279197616, 0.14890858543015298, 0.1439698004434186, 0.1249029521920508, 0.1296721789385042, 0.17606249529748194, 0.1665033421088611, 0.1490110879944217, 0.16628702952256127, 0.09751242840842855, 0.11021513146378341, 0.18196408426569355, 0.13232187788573005, 0.13084044770127343, 0.2213194152160037, 0.12657926748356513, 0.1956631612753676, 0.10645592269758064, 0.22691476819736345, 0.11676532111220783, 0.08509841026558031, 0.08448869620840396, 0.1101946386118089, 0.13232622926513996, 0.152634484693408, 0.13822748115466488, 0.16419773921370506, 0.07313027827730102, 0.171132305817258, 0.20491739614836632, 0.18776185299840667, 0.2547544646527498, 0.19644267106008148, 0.11863048473793654, 0.07323895551023946, 0.12445840669134933, 0.10356279165153542, 0.21500715715510232, 0.15764074670451303, 0.34714630774913297, 0.07698730881055517, 0.11641108971689978, 0.1454646524883086, 0.10692478382899877, 0.2866343402814481, 0.08881641116233603, 0.14681935640833071, 0.13196846620450098, 0.13261954900958847, 0.1062517449440014, 0.1455758884549141, 0.12373018649316604, 0.11729369195358408, 0.17483690783621805, 0.20761659969725918, 0.1677058396800872, 0.09014213397618263, 0.2580470032989979, 0.08596080310282209, 0.09993527339951647, 0.1219799513778379, 0.11937642454980843, 0.1696569124056447, 0.32034423142190904, 0.1920327931762703, 0.13259025380736397, 0.18069610149869997, 0.20350001091437958, 0.14645445340823743, 0.1109949859880632, 0.323397888531608, 0.1399760308765596, 0.13456852265423344, 0.17235449184813809, 0.24686705321073535, 0.14648065361524784, 0.09489674376504076, 0.1333079402965884, 0.10085566675350552, 0.10441435200552787, 0.13361725595689591, 0.1296731288875303, 0.08825492233999314, 0.11712539009749891, 0.19685743106228693, 0.10113852173690835, 0.10272752598769243, 0.16332384739671985, 0.11345044334208775, 0.09435277537352617, 0.1500503475507421, 0.1962332226215832, 0.1342489720592576, 0.09829022981707128, 0.21220401079664308, 0.12184431551084404, 0.17002556923656695, 0.12754819250755733, 0.18736923293721292, 0.22044576854715425, 0.06876658783444474, 0.11235397233958207, 0.08372414045997205, 0.10503087658435108, 0.1669174432754517, 0.2347532266210164, 0.10128265351898248, 0.23223269009782424, 0.12515436692704118, 0.25603534834038827, 0.13077470203561167, 0.1425963120474931, 0.12924603486974395, 0.17222447140562921, 0.15619028179395586, 0.13704260360569726, 0.17871959465405635, 0.10509276116687445, 0.14297837541709024, 0.223732301064076, 0.09466084997139632, 0.10028184391558172, 0.14674982626832303], [0.017518262799468734, 0.05780173225268241, 0.03646420705462656, 0.04336138090659534, 0.01766852711537673, 0.035650185008923856, 0.04838220624914093, 0.03610490798769939, 0.029564484045089736, 0.03988279014705651, 0.08677680931624868, 0.026253155177278865, 0.04296484613610853, 0.032231509985943, 0.04722878427034424, 0.09502248177605291, 0.1344135430671515, 0.025899484941375353, 0.046045615097447756, 0.03840058238335675, 0.06755842887345823, 0.026159077664957415, 0.02100616344250739, 0.10098210956540801, 0.010360614265195064, 0.08894273140017064, 0.035429137999251965, 0.05841367562571841, 0.04221596454660739, 0.020212567216085813, 0.08253842787516695, 0.03719322781469073, 0.029672540746809497, 0.11697273941770678, 0.029816339280636563, 0.041417758386101455, 0.06560404664806782, 0.08889611494997818, 0.05611125582588777, 0.03606572642081207, 0.041302538762289676, 0.05346454462156661, 0.05764319801763181, 0.027734412991952513, 0.05443748777672168, 0.011056661643388291, 0.057328964072850444, 0.011227928259740434, 0.055836793335695425, 0.057431604532945546, 0.03361303464419419, 0.012643434663092899, 0.047499010294315316, 0.05622734495949361, 0.06861095707262717, 0.05455250438723353, 0.029124554224132054, 0.003966071179151655, 0.013103777854402941, 0.08315938044219248, 0.04159938634162949, 0.02817886273166345, 0.060081483510833596, 0.0008518088537628853, 0.03416767847093363, 0.029253613226295962, 0.05739737572448869, 0.07374952246825542, 0.08249268476520816, 0.07998968399460278, 0.05711432538866516, 0.08846324462924274, 0.012563329636900416, 0.007312292000278831, 0.05370277881381973, 0.02815905744360099, 0.045539430162358674, 0.03974137031623433, 0.014409044205451445, 0.04698946606367827, 0.05788148583603963, 0.01657160412099573, 0.018437526173769467, 0.018790493524002454, 0.026636827331517014, 0.027561445660408468, 0.00798779529436762, 0.05483277382389192, 0.03464895788760435, 0.027372252586628162, 0.06845105920107135, 0.026789123695644162, 0.03346567763195884, 0.041912655015626264, 0.08921227177544948, 0.051157057150116855, 0.016001470954037242, 0.044929823357491724, 0.026427413366975325, 0.025515408675757148, 0.05038161912272054, 0.03623995779743118, 0.010250136725634578, 0.021235509099619045, 0.06983712676071352, 0.06918400616174744, 0.060211756762357495, 0.03362913781236257, 0.04236517932205912, 0.037857889528236086, 0.05002709661400126, 0.04677843565361635, 0.047576434970382726, 0.056168164667342944, 0.051520879966236895, 0.046511323777057474, 0.022849284803434726, 0.08654364279561466, 0.06543074223783708, 0.05631033909477054, 0.03415838965485173, 0.049074056423119, 0.04096285920710333, 0.026607271659398274, 0.021063757932654793, 0.005749106348957867, 0.07591267897477073, 0.040900645206772515, 0.02221739058563065, 0.02614568070238156, 0.02087603766290892, 0.028072504829915784, 0.027507103213499633, 0.028399103433795037, 0.07705827153498128, 0.007453285215888173, 0.01918983792195157, 0.07339834776376525, 0.024541791363228715, 0.04848360181635907, 0.059098447147276134, 0.03596923381630932, 0.020412479775146614, 0.030707749613230268, 0.035851022619153225, 0.01767934810730719, 0.03914018281765523, 0.009718863368635217, 0.013183646350948802, 0.017685333169215632, 0.015793123766930116, 0.024120305109048085, 0.05904777043108499, 0.060555948575417844, 0.00629491622432045, 0.07476106496347536, 0.04888553750671206, 0.09368189685647527, 0.022852035059082895, 0.011964241219233843, 0.025817580566170718, 0.06847661589422534, 0.048137245804912625, 0.03127163246033653, 0.03674620784999382, 0.00960808705478426, 0.05414344407918473, 0.024703707876465014, 0.022467156316364006, 0.04215261673614864, 0.051304774223676616, 0.050006373935649474, 0.0682802752201115, 0.01847880490634951, 0.03882886000698613, 0.01642767726744135, 0.008593265703248401, 0.025072393435684424, 0.09046049713487588, 0.043491569888447566, 0.06951270384653922, 0.02632030469906186, 0.050839057883187655, 0.03665965523630862, 0.037108226529052185, 0.01828055858852402, 0.00690007301595723, 0.020460611164209344, 0.0632603423699977, 0.08416795817714545, 0.024894743391703215, 0.07262600856202264, 0.05667023954071826, 0.013967665520706966, 0.04360949763307168, 0.0408126063825142, 0.050146403316889084, 0.028712211229327708, 0.045026181896607724, 0.021351680587676745, 0.026540788634109403, 0.016566421536187974, 0.013227430191041242, 0.03507128683850169, 0.11477970548214451, 0.0688534162397827, 0.015812010707093344, 0.027950419143082637, 0.02848883531236601, 0.05899606332663567, 0.02940173249601597, 0.01994452837313856, 0.06168759450496686, 0.07705618011494798, 0.0005313814472174272, 0.056223039545359156, 0.02873442586391203, 0.011924838444458382, 0.07157664430598099, 0.06448506798234678, 0.018803804301686825, 0.041977358801710996, 0.016602006320270802, 0.056905895847106175, 0.0312567895068036, 0.03024982821737086, 0.024730976776129777, 0.03934655924357715, 0.058640931778016596, 0.06492651848783416, 0.005725473015298767, 0.003648356082961865, 0.0426714344611091, 0.015772986188230496, 0.03804784485950105, 0.02801398911903943, 0.04524075163287982, 0.025185464182868603, 0.0770850156644179, 0.051966459685636145, 0.027727924227233858, 0.019188985649135806, 0.05475333050614404, 0.018935293717790517, 0.009456733936413882, 0.05006649651594701, 0.0363693232347648, 0.03725470637061423, 0.011667422368191184, 0.03686757532939796, 0.021816433572600928, 0.007552707149091387, 0.019841594884412426, 0.031416555228192485, 0.011155726388096811, 0.023117875229687463, 0.05069337477306685, 0.01186828296105828, 0.021924406004649018, 0.0369030183872148, 0.04751773731362435, 0.027279234190862027, 0.08591308348601864, 0.01431886608066458, 0.03249421302649764, 0.07559342715408533, 0.04908038430937356, 0.0143385210239719, 0.018861477315846472, 0.07577802370031995, 0.04021627205093542, 0.0241394400701768, 0.032340547280205835, 0.023455290995057554, 0.04920966930747513, 0.05773603255229612, 0.02868673689062557, 0.024876418568554427, 0.029545033072692253, 0.035445520789512706, 0.07554124124468335, 0.05043912168231703, 0.03694764300880413, 0.027310689761032982, 0.054416405037045486, 0.07763271490412374, 0.07058240007609129, 0.0472642656325573, 0.03200126417552031, 0.024743998355622736, 0.01970571769972242, 0.03721537158614205, 0.12297519152202915, 0.026891854171070362, 0.0320236511798876, 0.037840028188281485, 0.0555079271115603, 0.005228881416241489, 0.05900702604483213, 0.049610210717805935, 0.05241829451293715, 0.042520549613982446, 0.07790748765992542, 0.013814625093683362, 0.08089116263774135, 0.02566468473824282, 0.006950845014333966, 0.04764907159692338, 0.060615780042304154, 0.04382348514252132, 0.08347407403972842, 0.030954824460129586, 0.05689708966641657, 0.07314705560284276, 0.04085437349614598, 0.03254826819043487, 0.06015400522418561, 0.002280300447431904, 0.020959608279348865, 0.0472795682388448, 0.017205844483067913, 0.04736120256805613, 0.035944673037456895, 0.01926580128530341, 0.04902997189351628, 0.013022972815369648, 0.03770948680598409, 0.03206784870745915, 0.09931149396805034, 0.06667244818902786, 0.020410803957812248, 0.026854076460304282, 0.008413337505302362, 0.05476473372489695, 0.04723887747874664, 0.09515455533419886, 0.02929446869529784, 0.09560359777101586, 0.007646101406745373, 0.04704868466022515, 0.029037871375499718, 0.02602566536816378, 0.01751614073591848, 0.09770016591515272, 0.027038967950389754, 0.022725157492283373, 0.06825213681065267, 0.04631217922114077, 0.0699594326978249, 0.05417965705536547, 0.08579372698741575, 0.06729436602683798, 0.13631923274407465, 0.16616237169552237, 0.10143017140968193, 0.23096957965002907, 0.15146803921989857, 0.15738410724987908, 0.08535743991453802, 0.13300188817083836, 0.2143753797657067, 0.12586030928838637, 0.1298648806949777, 0.11540140115445661, 0.12048044917924751, 0.09843898110932882, 0.12418694343538055, 0.21856952729004048, 0.2427401682061534, 0.12051591138926246, 0.11424290001272194, 0.13380790459773234, 0.24110440194847124, 0.09399686624566395, 0.19933872856199744, 0.19317708338700956, 0.13572831848456016, 0.21393635009806003, 0.12885597354221728, 0.18921743537629807, 0.2507168135695881, 0.1774871124014739, 0.11518816824161238, 0.10740990134617014, 0.08193661984536918, 0.1851293144206847, 0.0891393631876957, 0.25227142047257195, 0.11810899336612034, 0.2717196196317673, 0.10500901243499211, 0.1875060562404894, 0.157773325880689, 0.17368975245664198, 0.13187051420250248, 0.08279209490865469, 0.15591885684238327, 0.18502575465508048, 0.14424608239243109, 0.19413781893109122, 0.06385045989807095, 0.17304553379935605, 0.17045701463376323, 0.125952837387881, 0.16256925079130358, 0.1803934967686092, 0.16445373515448264, 0.14287886059572621, 0.17521575363653322, 0.10072083527883215, 0.06551688116404318, 0.32414301629028014, 0.08745157189907567, 0.07752171642477475, 0.17912415036511037, 0.13561424799263477, 0.07372873850286969, 0.10696028434340993, 0.16092784612649874, 0.1424568993670325, 0.16260936315501892, 0.2950655975409093, 0.1173122006378347, 0.1253016320087256, 0.11501724636482616, 0.1720428166370238, 0.10132508712910837, 0.12137923119289261, 0.10455610891503674, 0.11022624739956473, 0.09626060243575804, 0.22469617756864718, 0.23137321605557398, 0.13398111707741214, 0.16684475685319594, 0.08000557265815236, 0.11179786145446763, 0.16497959322746725, 0.12995083576008198, 0.12184403205831205, 0.10739818020092864, 0.18285801694277795, 0.1282446047351245, 0.11071998340588425, 0.1526495306602409, 0.20821629332438593, 0.22402456360718898, 0.1084831752063286, 0.09657728786189711, 0.192855617572223, 0.11130757284380736, 0.18921518307780066, 0.1189181584143831, 0.1699859165256062, 0.08118919382292418, 0.22237640204689196, 0.2639900069803961, 0.11030713096261026, 0.09186901107069947, 0.09821816392603422, 0.1705541392608035, 0.1986782228754413, 0.21266157979205733, 0.12838649954045975, 0.20930853552154957, 0.1106346948372741, 0.15895509311268408, 0.18872565289418544, 0.20236856033725126, 0.20602532782621924, 0.17791138721569894, 0.12190623073688439, 0.14837240049194905, 0.10871477890759708, 0.17243467061029327, 0.09177688133692549, 0.11797240755010037, 0.12287597547495559, 0.19774014821215985, 0.11062523365140924, 0.11744202189748326, 0.09286940698662112, 0.09467803332353793, 0.19856235973777311, 0.11630067346437324, 0.12533249769119487, 0.11765931507632618, 0.10361521504819395, 0.13829687339884622, 0.1579801083332108, 0.1300636805113285, 0.14882834538096382, 0.20562046567999548, 0.1386761328866405, 0.1511351586950402, 0.1552016453276719, 0.2000556183197806, 0.11340637796468313, 0.1592962167436077, 0.07060899098794307, 0.24926244161061703, 0.1068214845332888, 0.13854744543711986, 0.10787909955627496, 0.1302850186344116, 0.27109679014932725, 0.11159353814418278, 0.20128119045928602, 0.14425919781769478, 0.15341722736916236, 0.14490772188911516, 0.17932670401229014, 0.09333410059973117, 0.22693179067104097, 0.13717849228170612, 0.09969575600999017, 0.16381445010342907, 0.07833735491599768, 0.103168509179546, 0.1404876397141526, 0.11865358994973284, 0.1438890700979579, 0.16424545116962927, 0.11941059973211059, 0.14946312583502264, 0.18016121890996734, 0.16897584491920087, 0.11164225367528778], [0.018243753809421774, 0.012643555321940973, 0.05539117914233958, 0.058136110479432734, 0.04387134648559075, 0.03668861335984642, 0.037143788330497286, 0.02478757343675581, 0.07486513800798886, 0.07531879229411002, 0.04198434169314081, 0.021157222574636824, 0.02121877390891314, 0.06613891391504197, 0.00658233757055695, 0.052747283311140154, 0.05462219540570533, 0.04191288101156393, 0.019711379089482853, 0.011460939647569772, 0.029544029497511448, 0.06151954928833631, 0.06639310188831822, 0.04085779407872789, 0.023053150376184814, 0.09429661346779716, 0.0317767774310684, 0.03142731301786919, 0.06949624061704644, 0.011454669217909537, 0.02848578819764718, 0.04709498318392904, 0.013833853900582801, 0.051096398308272326, 0.039113139913928126, 0.03859165237255154, 0.07695023015501999, 0.06921245866725523, 0.023038949021288467, 0.019722579294935833, 0.056311576326768246, 0.011339654522617499, 0.05937372552110784, 0.0562045423524274, 0.03950291778892279, 0.019541451211778388, 0.010633433496789827, 0.02588469944443674, 0.032967747294253884, 0.006935177558672525, 0.03278520003321671, 0.015594601657451882, 0.025941545083638162, 0.038618837002544634, 0.026942230197751237, 0.09719100855891744, 0.015570348271379068, 0.03461280236801794, 0.02601427938638916, 0.03400291211061901, 0.03816852669021295, 0.0264568139062894, 0.05475213923942178, 0.01383449454160948, 0.011572155504367285, 0.014515986249241379, 0.02281588528515591, 0.025140603989242546, 0.014538477633088348, 0.019912563354497956, 0.08054002623764739, 0.03280208844150747, 0.018052823631273165, 0.026015849866633935, 0.02050654962658882, 0.04562426673909349, 0.02272635258944525, 0.03739084019475887, 0.04787377284599408, 0.010717727108708313, 0.007523995610104213, 0.022657743670166503, 0.03155167398583745, 0.006509782340858253, 0.029469948795233524, 0.0839834459005825, 0.0939606532694832, 0.06371979977214529, 0.0202964672503332, 0.08060930356864007, 0.014578324738859892, 0.0012517630098192324, 0.03143948232454639, 0.021005958513987642, 0.006064709197098931, 0.041628080164833416, 0.015160006681276907, 0.01727045825382154, 0.03653293280231376, 0.11235270063362776, 0.04335216486886625, 0.04151194506595212, 0.050977156722858075, 0.013234491606483297, 0.04551439057855357, 0.06132259191344343, 0.03658954669991809, 0.05631723771652868, 0.09218726697708331, 0.04409508629431648, 0.029112195310693596, 0.034785528381865834, 0.057347365504791664, 0.06829141413853054, 0.12260815879750638, 0.025934631140121532, 0.03547751645167028, 0.046481687665706685, 0.037584128008494457, 0.023961263340747645, 0.008811137278474147, 0.052267662474825505, 0.0490761133691957, 0.030127284793002956, 0.06911742546024822, 0.05282346309433061, 0.08028552416832217, 0.04444698878233472, 0.012078742635616613, 0.1042869975489955, 0.0075786191155202695, 0.05391403521981932, 0.018284069186437036, 0.02437134446095555, 0.018777230626813347, 0.039492472180075226, 0.00883495878247965, 0.04967206082637272, 0.022681819898406827, 0.054085972163105206, 0.05032822279439819, 0.025947689108790892, 0.024653638284953854, 0.06752580884964236, 0.02520689740777016, 0.00835089176337445, 0.014757371935693007, 0.010007380699408392, 0.0340904644690454, 0.026690173864124284, 0.03281521535809002, 0.028529472446309465, 0.02885935565216407, 0.039989781986561515, 0.019133241261325536, 0.029909576011461117, 0.023044872796162966, 0.0697235465650597, 0.1509184017777443, 0.02208575178238173, 0.035060170902720386, 0.06637873773973796, 0.02142087364899776, 0.03831438983099596, 0.06189075719204642, 0.03896551477091928, 0.04174498518207862, 0.008611550306781166, 0.021463659659568823, 0.037076414727996436, 0.010035857145163802, 0.003936374977779305, 0.041891568445510445, 0.02863051369786263, 0.04552907648406202, 0.02985825961185319, 0.04059073199788409, 0.0695381686091423, 0.05815066614999406, 0.02017702456683882, 0.02379913423811236, 0.03183519929617403, 0.019438908427893635, 0.012481188732049158, 0.023877813383155776, 0.05198971045413806, 0.007963913939743033, 0.03435231715200409, 0.03978617113804625, 0.06916891422963913, 0.02472360317985858, 0.08094995988592987, 0.026211269320018833, 0.018832720290388794, 0.11729549226020614, 0.015147022448570259, 0.03372742689304775, 0.059697263603729595, 0.060362587983329455, 0.056946908364132534, 0.04600965876072165, 0.01704432250511262, 0.02400305918267658, 0.04556743833687037, 0.07809737787371682, 0.078662819709749, 0.016773330393217264, 0.010747103707774753, 0.03896122084810369, 0.02718380644857403, 0.10905325953518191, 0.05819021926952466, 0.0005712631466468016, 0.06408002963590045, 0.06686213921995894, 0.02206349118252195, 0.04219569386013093, 0.05029785506907971, 0.043047162283572464, 0.0316858945053912, 0.03747335552508312, 0.02948340129918389, 0.006362219921298206, 0.05903323774316138, 0.014212597236638109, 0.04135014346590446, 0.06075392867768965, 0.025923846537367474, 0.04242715583513341, 0.04334972487882741, 0.017620851548628944, 0.07467374626186586, 0.007992003989901634, 0.02235234080393228, 0.06665893439804355, 0.053482294878772194, 0.03992393672946961, 0.07096402677557162, 0.048662602090306824, 0.030148045775750955, 0.029766907457322366, 0.024495172997816436, 0.07698890993431692, 0.0407928298227489, 0.01676586103595553, 0.019883561180904508, 0.036905236211755586, 0.026649423732211994, 0.045484750636763153, 0.01651088399211726, 0.02065832696614727, 0.023074681277296717, 0.04200648929503176, 0.01495045194807913, 0.07153156003163708, 0.029447881632574627, 0.009049897198565304, 0.05519856165553774, 0.026660888237998854, 0.02160574598688512, 0.07687206620410567, 0.03630008420816833, 0.0372385572371704, 0.03137007284338676, 0.036860523490054954, 0.028758339298468445, 0.016395691181382826, 0.009480797715725438, 0.04803535611098332, 0.04157282607329469, 0.031729335521137526, 0.010955215322845166, 0.009427299880753122, 0.00956113735634473, 0.031648270012209975, 0.04576731450675477, 0.04224172808350094, 0.02209406000592055, 0.04436292595440342, 0.0066683429101812505, 0.06259664592723693, 0.0022152643707100184, 0.01146630130542983, 0.0527394347403559, 0.027915479788076014, 0.06723961372288965, 0.09425247914247936, 0.089058127224205, 0.0767102837562561, 0.02810185557351478, 0.06570577546353303, 0.08580468204473296, 0.01524752648096652, 0.07638222958532072, 0.01664437481292313, 0.04422309575602413, 0.018811988035937952, 0.04161008858993169, 0.12655340435524143, 0.0107454834318149, 0.050176705924734, 0.03273416708614076, 0.19662087843302758, 0.07422729320223294, 0.0428943085904804, 0.02949828638755266, 0.00670689532736076, 0.020655691623687744, 0.04432522293720995, 0.020281246998497558, 0.017903551399227113, 0.048909998694134336, 0.0982872267524081, 0.07708609584839114, 0.02243712183929259, 0.03389079514290056, 0.041264491005530285, 0.07239127156114386, 0.05244239180859539, 0.0603018525326925, 0.08010183926671743, 0.10811605055125491, 0.08188203608076419, 0.03666753062017022, 0.03465610165749827, 0.06000726108228969, 0.07776017661296553, 0.04069602695263682, 0.05924154088021286, 0.03701566012516137, 0.048016962339921344, 0.0017251555513094871, 0.021650602350071557, 0.0206658135603873, 0.0838614387377616, 0.019777789336418914, 0.033787848247635754, 0.029004793614149097, 0.00816048252501435, 0.08681961064857822, 0.08380946733297841, 0.035647331331405914, 0.11755035439085577, 0.05791386454215935, 0.023840612153552716, 0.07724875929735361, 0.04623064065291997, 0.038296114803562244, 0.01760918211432234, 0.030455846497188174, 0.016522511291588028, 0.03923527348125654, 0.13738712866700467, 0.19194153678273002, 0.1386552799733416, 0.10475704611669626, 0.1281789739826514, 0.16626308161404826, 0.1120313267493921, 0.1201608909233924, 0.12315306181628859, 0.16458096703694713, 0.10743925017454933, 0.11986013246519912, 0.08258057803276085, 0.17635858828021636, 0.18899004515861312, 0.11286956483438132, 0.12167052846522101, 0.11147327766182924, 0.1535338719165133, 0.05397765116105157, 0.11929558695203836, 0.13826264459038937, 0.13818194488844565, 0.1126879943354476, 0.12654300854210893, 0.1486995660008923, 0.10569279953356712, 0.12166738750473147, 0.22055392484030417, 0.17658409392160757, 0.07548766871613842, 0.17772680599122279, 0.10923413289410454, 0.18058049883092606, 0.19514511729921066, 0.15140382573008537, 0.16041220766642403, 0.08976226927892816, 0.1385177978344502, 0.11924574527168467, 0.1935382938433078, 0.11915099551720966, 0.07149929240826638, 0.19844085819298224, 0.12791114964432296, 0.07404766090574764, 0.13321706694701027, 0.10080364938344687, 0.10113089916206176, 0.0784987006937304, 0.13984492258919826, 0.1285992881223079, 0.1064012393415455, 0.20652254953259425, 0.11964441742748023, 0.23703832900331867, 0.12132649370018514, 0.15610029710636986, 0.14034484092506672, 0.17208905770413338, 0.10668341250669573, 0.09289377624349249, 0.1353174961742855, 0.09846804648517601, 0.11596995330746136, 0.10033185413527874, 0.13555518261367275, 0.18373045319270703, 0.08382202351405736, 0.118957657907759, 0.16835801033002717, 0.11663380679824661, 0.07634850639489389, 0.10131422400234208, 0.1222187026794399, 0.0864887755784777, 0.12894347610492862, 0.16895790314001424, 0.10837669664573286, 0.12377998986912352, 0.11177405910266024, 0.1160220932515879, 0.11660199116675124, 0.13203496263632852, 0.1678182707438546, 0.23947025979718856, 0.20998491454989682, 0.06622237919439232, 0.16622785689128985, 0.18311917631616517, 0.08960080858800681, 0.08498792506514058, 0.10295942080237212, 0.11557701148933942, 0.10461099911481143, 0.1254908557260229, 0.1140801522940878, 0.09715485686977064, 0.1255882025185612, 0.12271798516233122, 0.08383713076792418, 0.12482887148977288, 0.12313880492001773, 0.09119436340106112, 0.09583333221774909, 0.11297366086153254, 0.1406281708829826, 0.19973966833804885, 0.1702444252347754, 0.1026232154559224, 0.15380972485628822, 0.17518722452223304, 0.2080143372257871, 0.13575245025417498, 0.14809933611221854, 0.1414343864927369, 0.144323886282021, 0.1762099978664229, 0.09664222913523836, 0.07264950447866032, 0.22463144313904548, 0.17931934956821705, 0.23254790463514868, 0.13658580069820728, 0.14756724208353028, 0.20413100689409241, 0.26373686088669684, 0.1594255630287432, 0.15515355032778558, 0.2042502867839029, 0.11923604659856328, 0.09298860260675992, 0.09697312549237283, 0.04576477492528577, 0.12422193067088244, 0.14763566905692702, 0.19702690503289624, 0.16224285137028466, 0.09281736663392476, 0.20435254420003585, 0.13984699102659381, 0.23108248568830952, 0.13880408489175383, 0.19879466823993192, 0.14392427949895784, 0.12551594510554306, 0.17560966072543976, 0.17039523730354925, 0.11451683007180692, 0.18072518219630565, 0.19211865631082367, 0.15087661934235405, 0.13741294583005292, 0.22586810823169448, 0.09161650082997738, 0.10270481914161675, 0.18072463061300018, 0.14646785994691236, 0.2383285436418749, 0.1122836071637369, 0.10395879016047525, 0.12910486018705752, 0.10018170090211977, 0.18115785333418077, 0.13423783314083854, 0.1442663224353906, 0.21876564579865626, 0.14708888146185106, 0.10201082775189031, 0.12675477822701778, 0.12226269910893134, 0.1745870712423517, 0.11413462114550414, 0.09375107459603779, 0.09176428685145033, 0.13690383443909307], [0.0411155711739294, 0.02107327082945455, 0.07161298751710884, 0.052899550946970145, 0.04524948886565624, 0.1151749455640393, 0.03488298625715318, 0.029985368920249805, 0.06645954469399107, 0.07556885871435366, 0.04009270206874898, 0.0739716420010213, 0.02428562688310781, 0.029776270966976884, 0.03844809515642063, 0.045151766690035025, 0.0485761720506895, 0.010653558626560675, 0.03751555164795249, 0.019354970089250037, 0.02484337911160002, 0.02273448844320111, 0.0784211189696385, 0.014650741115122315, 0.019612616949504422, 0.05028616456735519, 0.0657628107094957, 0.018106388498938853, 0.0332313045228441, 0.003613399490976947, 0.03453394893797175, 0.049648319761599266, 0.061963868793100126, 0.0075796442369239474, 0.01580335295593907, 0.037262968628877596, 0.022194396456583373, 0.0337454222983891, 0.019699742213913032, 0.034892673438955704, 0.05283001697652283, 0.0574710772132441, 0.015634980236720896, 0.06595263963625317, 0.003518133584762954, 0.03038872761892215, 0.04387018586238546, 0.03653321625484574, 0.03305197100064928, 0.04299113444323021, 0.07641827402215812, 0.028527471041607282, 0.010749347387782989, 0.015721964732473417, 0.028330619003803983, 0.010794178853111883, 0.05070629101547022, 0.027012926706623648, 0.02720399478059863, 0.02702645007370701, 0.012124612150082906, 0.06749579352476905, 0.022416272756433295, 0.141304902311775, 0.01892268582577667, 0.03517990278440618, 0.06401375153913133, 0.06320657065859245, 0.09704351365085571, 0.049252267626504746, 0.027958032141830173, 0.06611072187942844, 0.03446222778650061, 0.04483640659600497, 0.06354231252184799, 0.040491837707738725, 0.013286566433136263, 0.004672553153678535, 0.06501731522861989, 0.026936926954095403, 0.03754788055835712, 0.03403699919280987, 0.02046551412692474, 0.06992474423661348, 0.058250157988720366, 0.01698523797395249, 0.017489281693293203, 0.12428219880788557, 0.07811268431044395, 0.014773321886276527, 0.05156231766206123, 0.026836433455408103, 0.025387839714605964, 0.034408172622563384, 0.008113130630414573, 0.07760112143812642, 0.01830461949500586, 0.05714342140802934, 0.045381941637324716, 0.06355389577126311, 0.1054608970580082, 0.03400537508329557, 0.04099328438901613, 0.03020839243676634, 0.035966016247027346, 0.06936969821371379, 0.049932760547005364, 0.04738071865792717, 0.0096592981173026, 0.008850369598686455, 0.06181038690791015, 0.04554289671021604, 0.09389891424366544, 0.02540104707042056, 0.06826117664815919, 0.01892724021848652, 0.08530206707937103, 0.04536215741668017, 0.03916540243212254, 0.06691869183052933, 0.054533015110439835, 0.0617675319494259, 0.037167249773178375, 0.04432960496013684, 0.09700697125686754, 0.047957023620725646, 0.027007064218783093, 0.025431081547491977, 0.021017784996318723, 0.05401359600645881, 0.026380559429526333, 0.034512391223782496, 0.024491371286492196, 0.06874912869065039, 0.0799419030907654, 0.020470645000797608, 0.06455194745813647, 0.04716652430473797, 0.006975039507397601, 0.02826005464509851, 0.04103500936781207, 0.09010192202103716, 0.05338190671717448, 0.016534833815850077, 0.03699204546489543, 0.034791369802288474, 0.02597024656772133, 0.01872381323107308, 0.04174401991129403, 0.0447852089400253, 0.030341934968507102, 0.058583877379855806, 0.04046621589711116, 0.03183338941345292, 0.06562434797806126, 0.09641286241070879, 0.04063328052119863, 0.037691659939986084, 0.039690494417182864, 0.08391463588322363, 0.02002179217074187, 0.01148430245643061, 0.03182778739550662, 0.03450680261237487, 0.023458569851373474, 0.04816768630858391, 0.04479864229177756, 0.04321986148434301, 0.016351030170617085, 0.011886592462448584, 0.03752533459074555, 0.04764424907344003, 0.042028843740662264, 0.04545642453576288, 0.022389695251120195, 0.039758423433428815, 0.03064295964225406, 0.026473688908041488, 0.03515881238385074, 0.08024267687071716, 0.019686536773318247, 0.03356772820435224, 0.026876268112250877, 0.039134249466681675, 0.0132851951357518, 0.025834298519898328, 0.05149095274147488, 0.043724617665453304, 0.07583716568807441, 0.034726011011028485, 0.050072862706597776, 0.04565300652757288, 0.026338570150396517, 0.03352909439033078, 0.0077284721379739145, 0.017525485093374888, 0.013711537429762465, 0.07560524022987775, 0.07251949169703069, 0.00668969952629038, 0.020043955094391303, 0.024301994351610064, 0.09539447108944578, 0.0351560851108403, 0.03139670589007437, 0.0450921114233713, 0.07175793135238272, 0.049895252882232594, 0.07102476222620857, 0.024955294981238343, 0.0443021253862929, 0.05154535647541766, 0.01791492972012249, 0.005488290278721722, 0.04061996591307464, 0.03247269744714422, 0.05966874598074825, 0.025142971200928576, 0.03420809343937905, 0.03205829367582356, 0.051695191782088055, 0.03965436954111342, 0.06601852319774128, 0.022472484457877376, 0.0362274514120673, 0.009666654476595503, 0.02631314943784908, 0.018885905944531965, 0.09875898369618001, 0.0982975536176274, 0.03731262644812946, 0.03319948889134872, 0.035226316221298716, 0.018720949977456082, 0.04246513847441923, 0.052930117855148937, 0.041066629646886746, 0.055790575251223586, 0.0906421595643605, 0.10035535005191643, 0.014425739176541328, 0.0034956967846805896, 0.052219218904933626, 0.03321345467420836, 0.07903916040255178, 0.06377362510970523, 0.03817438343239408, 0.04234601180219362, 0.03553454786719334, 0.023084552320201072, 0.026030101017245365, 0.08522184235194037, 0.012637845094075367, 0.033024184991635626, 0.018221960523195805, 0.05522879531546947, 0.005700800196087409, 0.01856907113124767, 0.040995540517953136, 0.027708657115938205, 0.08658622962332542, 0.02869897706043576, 0.03768106111355367, 0.06949712161815937, 0.022608415268722083, 0.05193386647489764, 0.028926426649934826, 0.057776298133596304, 0.028072880212998683, 0.023511450985566746, 0.005823549506584964, 0.018654068586446585, 0.044427782958073, 0.03955186314640507, 0.0666688782193007, 0.041370628656999725, 0.07819587379814157, 0.019698054905259804, 0.015507327963507947, 0.044513764836254625, 0.03482240019366145, 0.07660549058909379, 0.013352912520208668, 0.026310864580614914, 0.03178423338179146, 0.03475024237207348, 0.006829672408545571, 0.08485512372346656, 0.03587748712649749, 0.030125924986937357, 0.037827173232912056, 0.035403895402146925, 0.04952960294641314, 0.02813217158789837, 0.047428522544402274, 0.1506080442378598, 0.04413451300933958, 0.01638840568522292, 0.02403583050885749, 0.035460126255789114, 0.08223506471803112, 0.02749917037304371, 0.01497994824838374, 0.05132208781076535, 0.03788396333073897, 0.006143700044166538, 0.05492072071759932, 0.07797122617522556, 0.06890644484590139, 0.020117298437042103, 0.04725572375220157, 0.07972132339472733, 0.004141431099044219, 0.04178732303121398, 0.013819377711643616, 0.09440938927113049, 0.024734410765250365, 0.04261103991959845, 0.04614668124685845, 0.04396773566822371, 0.04351362172934798, 0.015729424513636098, 0.028176606602726445, 0.029368984152472792, 0.0430204487976528, 0.0914668455539692, 0.02522432399282773, 0.020078735486153635, 0.057730497567043196, 0.029914703054894364, 0.05099268915552286, 0.07242198402602827, 0.02019407002315406, 0.022179406031125018, 0.05215827278011749, 0.07905555468413138, 0.04760072378802204, 0.025612190478451313, 0.013101024725925059, 0.009477422140809077, 0.03323489364476935, 0.02235004828581887, 0.03756195359352616, 0.01914641222796373, 0.048400193993603034, 0.08962987396385401, 0.061494203269361496, 0.028278812307924516, 0.06492318600536355, 0.08471647713093028, 0.035424016701478156, 0.05601493942160761, 0.1766939049646739, 0.13865865076020842, 0.13116281749981065, 0.24739016868895103, 0.09599185879192046, 0.1742450895929529, 0.09608176687071401, 0.13727757809383256, 0.21469508357826741, 0.16060158460130616, 0.10277422670755657, 0.16073243241877327, 0.2054539181652569, 0.15006102681640657, 0.11853863079581531, 0.19938279393940203, 0.08567614781279718, 0.1268571352345809, 0.1644062989902112, 0.12644607543704972, 0.12055983120996146, 0.18825613292715243, 0.21688378145617826, 0.10902870641720873, 0.1536894030869007, 0.10575533529082615, 0.14362737446302368, 0.09502757626074938, 0.13034674999935011, 0.14025700128366872, 0.14582753301628176, 0.14281930492049263, 0.11557463661677415, 0.11805067109244487, 0.16403868403886596, 0.19247718545938694, 0.14536233378514168, 0.144189759608238, 0.17737561596497414, 0.1828397840501801, 0.11967447105674975, 0.13444948791255876, 0.06126029747388056, 0.1566483717291586, 0.16037739663114473, 0.06737838288949383, 0.18126352750245603, 0.23571952396342832, 0.0739772267819893, 0.12360221916629423, 0.1105800727682729, 0.17695025330589664, 0.16167930177142545, 0.20620336665982203, 0.18095387476346186, 0.10207274297793066, 0.09537420040296932, 0.12297036516810618, 0.20377276885894038, 0.11927339338487196, 0.1804564079089511, 0.12405289337038995, 0.16062464384782701, 0.2781889257171462, 0.08436274369277301, 0.10332828447703393, 0.1355263930294783, 0.12775718129330105, 0.20790559870581474, 0.11661869188350056, 0.21118376554260332, 0.10071596295963373, 0.10494974021229053, 0.10582370097718893, 0.1221750663112729, 0.17888454870591242, 0.10744850451667463, 0.09634379958433491, 0.10949267990766995, 0.14737044941754113, 0.0904187300212441, 0.12771608833704265, 0.11676584205199635, 0.14655671082437038, 0.26580686110161966, 0.07895448470428106, 0.12334178757643509, 0.2645695678168728, 0.18445832865132442, 0.21338904156319558, 0.1399046008384997, 0.13368366045817254, 0.1278116501447174, 0.09077827040586742, 0.12046244611302692, 0.16182039984531943, 0.08123652273488623, 0.09755504587965627, 0.10722617047928995, 0.1267740759818304, 0.21494430730179434, 0.15867603792538568, 0.12827770739433267, 0.1542788464576006, 0.1327659943771939, 0.22318359824918935, 0.1964807303081597, 0.12643931088067834, 0.07572376935352242, 0.19198523443793097, 0.1275843212140664, 0.21610427167146437, 0.14593866173057787, 0.13246774102651304, 0.21939682563947094, 0.09441916455304432, 0.12484456863134138, 0.1670555076411655, 0.18381066259837922, 0.17354428768157962, 0.18294936526686917, 0.16574051771913806, 0.17507111623642907, 0.09973387654510238, 0.1944619660536128, 0.16447190676004658, 0.0973587511708179, 0.14482320706930854, 0.11704589315359631, 0.16019710549904456, 0.15264455108873307, 0.2793804069440211, 0.19889026069112364, 0.15261600665267439, 0.18698494791263537, 0.12483313859951113, 0.10974355838111333, 0.08074923718888914, 0.1359426852075323, 0.1612885049994915, 0.08675273117278853, 0.1735115144401789, 0.19287841634884959, 0.14497930514475993, 0.10271414243165525, 0.13950261918287124, 0.12848200006110053, 0.08871608428777226, 0.11822815834274215, 0.16940603393220133, 0.1387630072572539, 0.16107381651959113, 0.11887747148472456, 0.1388826701910265, 0.2031789587870721, 0.3071143219788229, 0.18582801725114548, 0.12657859332619176, 0.1869433799818639, 0.16128576240472256, 0.14411630709805798, 0.20135655818927675, 0.18990804831827843, 0.12285720632081071, 0.1155229410036437, 0.14156198609740506, 0.16222359191986824, 0.1946347648458135, 0.08486063189564214, 0.2201398389954721, 0.09329129160652239, 0.1582746384965797, 0.09198112803841792, 0.16890521161258223, 0.10948611453415887, 0.09251945036193056], [0.019968062594172456, 0.0919297235386987, 0.1369725984911765, 0.02731765350026469, 0.034570506653718414, 0.03158741964838438, 0.0272883391458421, 0.03662776299602082, 0.03721555544724388, 0.032193703546879754, 0.06653447575386494, 0.027800740884436716, 0.0837275495512351, 0.07192117702816764, 0.03883268278572829, 0.05623513607368354, 0.014863118882321063, 0.025170703583787528, 0.06363819608645094, 0.06712339052389707, 0.04993965533832389, 0.045701986359011744, 0.041880042652689645, 0.04818457088643505, 0.03783425188533241, 0.05295143425164204, 0.09310992029044898, 0.014115354823579472, 0.02887363744629247, 0.033158878570482615, 0.018668425074147604, 0.050745051233999194, 0.06040726240063387, 0.04299059052080397, 0.058368392168514194, 0.03761776309880999, 0.01954186681447731, 0.01080574869598833, 0.024336263379682938, 0.017769725414954366, 0.04726776665437126, 0.04763274626325696, 0.033797248146466674, 0.013358121918093775, 0.09148155444211538, 0.01559805001072105, 0.021843675659188343, 0.06740334969494613, 0.020190333429303382, 0.01814724013750111, 0.05314083799960152, 0.029206144503287734, 0.052564464088889866, 0.015439205510061116, 0.018763243776535796, 0.02103717468168226, 0.07973136680741465, 0.04270283257468574, 0.06597911563491629, 0.056828873367199016, 0.055956295391003934, 0.08398520790280835, 0.021258457263390866, 0.09930456087233559, 0.03393604029570857, 0.06573316310682605, 0.058823007894980336, 0.10066535519135576, 0.03735872961941265, 0.019541487600954793, 0.06110534469987597, 0.03762106876820326, 0.03942322166215989, 0.012963962977782134, 0.054708349653669906, 0.08389876254143254, 0.02386668212561598, 0.0465871779728801, 0.021537035560956406, 0.06875944789499044, 0.07314960667563063, 0.016642882856690598, 0.0697212023360114, 0.08062969682918442, 0.054846670658838366, 0.057140927791835806, 0.07084794147240539, 0.011976602047892108, 0.05221526972168396, 0.015446547505205438, 0.03286697608869403, 0.03651368101277659, 0.011901478508427259, 0.04640701324528745, 0.013166559717407631, 0.060932963425594, 0.04016613159629126, 0.02892715443346289, 0.02358256118191827, 0.041972030660197626, 0.08107447215626318, 0.010642690711744852, 0.016215978445665493, 0.13384970235488108, 0.010232368273840798, 0.02554573426623979, 0.01661764600524499, 0.05308327415297109, 0.10654124190970775, 0.04806570468410369, 0.041063381434087796, 0.03737672885519363, 0.03788354581282024, 0.037778323636420315, 0.01391601491524207, 0.026013333267802675, 0.071454445621179, 0.05377882070118382, 0.022995561631696842, 0.011939715871947908, 0.03723885984190049, 0.0235000247841761, 0.045361460276669076, 0.013214377968031312, 0.03073844675635619, 0.08283204639390593, 0.035172670914400975, 0.022583099893264236, 0.039445323298775384, 0.022451907336231203, 0.030666472795870037, 0.04770364770064912, 0.08345420937985183, 0.04971897605085566, 0.04987273755813799, 0.033642467742245045, 0.053025323431938894, 0.03101372513018789, 0.01899984811673001, 0.03066307136548623, 0.015769542623010856, 0.04323187757343535, 0.013609301081047425, 0.0758955262661461, 0.01673464103782129, 0.005003717641586499, 0.002571828503747501, 0.031021054676403443, 0.11887072991099089, 0.014284338497917258, 0.0929123385538978, 0.09356851584368175, 0.017806897916260268, 0.10838258020099133, 0.0654081579658293, 0.06127251274583321, 0.027877839973136306, 0.05090497591863236, 0.007315338636192704, 0.043982149612519054, 0.06105756762647822, 0.07216814079231794, 0.0428714715094576, 0.012975345129117131, 0.09455907519065565, 0.010923369047832827, 0.05595907629016907, 0.07149352376619655, 0.07169453757664851, 0.09558100583812884, 0.05369737023307432, 0.10242718121697826, 0.0567688427174524, 0.034363333496355244, 0.03334871898855894, 0.037896343311595346, 0.03886422645601054, 0.03734222042464441, 0.09829735443476709, 0.06485748630497726, 0.02948659588582814, 0.07116628164846091, 0.020786773097971757, 0.03990900184538576, 0.039741151981175914, 0.045600188595633355, 0.027410327156464902, 0.017598315157116424, 0.02404214690379318, 0.05207078170872504, 0.01809252805316881, 0.011897891301721817, 0.01957806255367975, 0.03099091486224244, 0.0692264857371488, 0.034194886083564455, 0.057450837170284604, 0.024246265285558278, 0.037897683965462836, 0.032816188289753856, 0.08515930659468136, 0.06818692740653792, 0.05530279557851534, 0.01565321312931877, 0.0449788568150853, 0.03364955405554464, 0.04773174014483248, 0.05651619841134357, 0.064046049806019, 0.04539327973860406, 0.01603180420539913, 0.05874946345424941, 0.034631778365902366, 0.03346526011404011, 0.022768025857306296, 0.02779190214501033, 0.06211022989103391, 0.03795014566651756, 0.022172130111064163, 0.05362892410747948, 0.017307071510942715, 0.08462730449654403, 0.020463054984687798, 0.0686846087656675, 0.026221161430341103, 0.0702934317110527, 0.05821435870001874, 0.1160591948897608, 0.048401350786368695, 0.07781235486148827, 0.017553142782661225, 0.04911079033908825, 0.017293025288851033, 0.04083053667038199, 0.028325652838834835, 0.018233570585688277, 0.06729570668070547, 0.014984134918889933, 0.029599362113062414, 0.06852723132338255, 0.054435388695809155, 0.07486552871283024, 0.035673435777425766, 0.06879902399715877, 0.01726431614388862, 0.04987681697633478, 0.031728341522055774, 0.055363228424422206, 0.029550742342947956, 0.03280794135324898, 0.03802501543935749, 0.014853335939528001, 0.02692249577282177, 0.011267574267431853, 0.04867440367478037, 0.026483374174624204, 0.045842789489054875, 0.03549526287843624, 0.10703274860016762, 0.059732239347912615, 0.022212918547372666, 0.059774213305283944, 0.046211607198441224, 0.05759408412080619, 0.06577664625740821, 0.04823394525315493, 0.03314889644482925, 0.027271584802938086, 0.07173674902127636, 0.04778903969112904, 0.04614408803923477, 0.006350680721938731, 0.059717047824374134, 0.07087624076032831, 0.03208433300436985, 0.07626235980780856, 0.03425910340381726, 0.017091465640753027, 0.035071650730265726, 0.1004157331021082, 0.03613752418107564, 0.029868214924429214, 0.015453304400697592, 0.07005619726354076, 0.12202735689859237, 0.023621612513858466, 0.010156859775193998, 0.030778779370349743, 0.04427114862107462, 0.04762082976559478, 0.029237038914054155, 0.01393040587689968, 0.03698439990741111, 0.014710530447172783, 0.03800954046328703, 0.0771247296624126, 0.04781408310537377, 0.03901431457169595, 0.059556740095778826, 0.047261205111299796, 0.07066343685672169, 0.007068750255125305, 0.060885029304171764, 0.006046020960991061, 0.042837518492653485, 0.02777608242937394, 0.03132951614867536, 0.03977736112691703, 0.032233509475425366, 0.05981802587367355, 0.025164067347143448, 0.04869514933576988, 0.006826601353579111, 0.03879807476374892, 0.0590860556751009, 0.01688844276471965, 0.025649085272884658, 0.053868407023049174, 0.015251206575832782, 0.08127550894935286, 0.03644544173092131, 0.014142990487837985, 0.045139589722478585, 0.04077707905502569, 0.06789988958306852, 0.06892575792247249, 0.04672151915128193, 0.09783677471381041, 0.04585439955154735, 0.05802202083530927, 0.04125604871660471, 0.04800441765016125, 0.024996234719911893, 0.048426466978966236, 0.01672433715523972, 0.09428845463140358, 0.058216833164014166, 0.006740831585991527, 0.02830442454245302, 0.05479818112367103, 0.0603045912970218, 0.04078290132325023, 0.01816742080864647, 0.08281228132545948, 0.07856535800402203, 0.03457005466184309, 0.020321277007761023, 0.017709489836688005, 0.038143372193219206, 0.02011106439655827, 0.044553264329630526, 0.06019817019302038, 0.2067957824516681, 0.21968646816188292, 0.18102775628287948, 0.13968214422704714, 0.26644602357860536, 0.15421198230356942, 0.1406174150085257, 0.16358466969142038, 0.14844894799734318, 0.1979600614117038, 0.12844168085364566, 0.0749634730539495, 0.1612297154121822, 0.26494596213583027, 0.08218453355854557, 0.13555656157193646, 0.1620800117210996, 0.12193861327344373, 0.17155207603448824, 0.16204078801937644, 0.1397262402479687, 0.18085394625461873, 0.10598098648892296, 0.14171310460134862, 0.25189747763497217, 0.15245014861706765, 0.2132540262274204, 0.10443489848365707, 0.14603656776730092, 0.1989590707084825, 0.0882996771965296, 0.15742107865310487, 0.16194602294314295, 0.14795304396219794, 0.15681009288997422, 0.12412886630984084, 0.09594128166715946, 0.11322650052006207, 0.1440547595942213, 0.10340605772310689, 0.16065528736479823, 0.1163912097352647, 0.16428539499400124, 0.10532952063987333, 0.1997763639496219, 0.13944396749138832, 0.10158123628747079, 0.29111813032819384, 0.12169274501502515, 0.10236329714497251, 0.1923839372372435, 0.15149119039697034, 0.12329884834827916, 0.10629299111784467, 0.15195154795242896, 0.13803341576168615, 0.23048263884359793, 0.15339773809236867, 0.1130450985604717, 0.12433919574945204, 0.2817395287415674, 0.1780386497416804, 0.12209516334077045, 0.2034754961008026, 0.21053711072571818, 0.1513574927324249, 0.141455561162964, 0.2648343584470211, 0.1274935244732807, 0.11772049485795921, 0.1283656083227646, 0.08684908971190454, 0.14667228284862735, 0.13532120403983902, 0.18305226619685852, 0.14999201761618738, 0.13001324128239386, 0.09618396299981302, 0.11607873779270919, 0.2103384028399183, 0.149486139116268, 0.11757100046041513, 0.19245175134030082, 0.23463232262480646, 0.11258389830829636, 0.22013485942396427, 0.14799923906403203, 0.25533577216969383, 0.21379401096172873, 0.1359453511935088, 0.12234492332584436, 0.18200378294192976, 0.1473279928247775, 0.14734689987474872, 0.19224411086930385, 0.21589030331421286, 0.11082715910649109, 0.1327127665882149, 0.18581344625882565, 0.15743782533512962, 0.2526321865978741, 0.10829004444061749, 0.06894454239837586, 0.2108399912474617, 0.12440812067999957, 0.12481862123334601, 0.09642790071666242, 0.17851806756469513, 0.22167722424191816, 0.09641565863163241, 0.11430554302229036, 0.10009764573506771, 0.19245424878693398, 0.15202310056455676, 0.11108407435277778, 0.07493513546163037, 0.43067636749436783, 0.1522582435920354, 0.09927562573143553, 0.15463737560616386, 0.13941306350452287, 0.08635037413407719, 0.07574475250176846, 0.11060592057483812, 0.14485843179206695, 0.1669449917972088, 0.19855615442558644, 0.07629754622617076, 0.11986319681689625, 0.13207058572480757, 0.16380064519903353, 0.11650226950164765, 0.1790988081765752, 0.1670620193885219, 0.13914223610153123, 0.09251355914579285, 0.1621469831274402, 0.08167112441433054, 0.10080708145734765, 0.10810556280757151, 0.08204537368710003, 0.11726451932542747, 0.13700296621649496, 0.13551919180299007, 0.09221456268982542, 0.0671850146365262, 0.11993725453653645, 0.10798729415382109, 0.2702135827031828, 0.19370756863105684, 0.16029913308880023, 0.1884070369264772, 0.19270000979304316, 0.16303218240218778, 0.1457890447589659, 0.1662934799828837, 0.21604220322783918, 0.11960651905786608, 0.19352726217719818, 0.2520590915434784, 0.1752465656928478, 0.12246771189834803, 0.2026320179744113, 0.17622318990047903, 0.3251052533666934, 0.10373518441713626, 0.0832798860726818, 0.215969440196791, 0.1710880259352346, 0.2572514669549081, 0.15305802406322572, 0.1199270272627473, 0.1327991506625568, 0.10187548299830768, 0.08698420463910989, 0.11126892370802742], [0.042275309547661774, 0.084386722244803, 0.04899003573002354, 0.05879698771863215, 0.01861999108035478, 0.04990931825652238, 0.030916259594021306, 0.021845824535815947, 0.02826497676001201, 0.01426119210889503, 0.02634168429780872, 0.07494285762790712, 0.04330235383202953, 0.03853652851595994, 0.05379075252060449, 0.07999459461819741, 0.09719064083671379, 0.01559683097331154, 0.01662109531612406, 0.04692619103157232, 0.03285091505536149, 0.03639190367633297, 0.0738122497474955, 0.07063362071470869, 0.036355981813563455, 0.021715154833791238, 0.01332660218805916, 0.10268978849654237, 0.02204909830564453, 0.026158813364623536, 0.0159464830780522, 0.004509401323664333, 0.06874158272459623, 0.04897519277649061, 0.02333473939929278, 0.029105574395808003, 0.03427087051433421, 0.03291222507194166, 0.04153433781597884, 0.04878562048918778, 0.021837543125354478, 0.008210963888784811, 0.0027477495830446003, 0.11528557632118465, 0.03772660887109176, 0.020447783021917267, 0.046392855940446745, 0.04348010155222109, 0.062458554748445756, 0.07399729828560546, 0.04898878700670697, 0.02496344998719231, 0.030962529389428037, 0.01677910669616634, 0.07305127929054922, 0.02176623949180207, 0.045790197553053025, 0.06630220555610235, 0.06475575748951205, 0.02588917914357397, 0.03377513501853232, 0.026361096965809985, 0.049978595587515065, 0.03469514915899884, 0.01633481591969969, 0.03870831224166098, 0.025919018268224694, 0.08538075197007387, 0.022462149931778832, 0.04415216750555462, 0.020828668531330845, 0.012867062431459707, 0.034947774312909574, 0.05392963276995767, 0.07357473950833082, 0.04148943357229714, 0.007822455804524644, 0.021232856520181222, 0.03234281490046171, 0.014366190204577101, 0.05647921934723855, 0.021777746132424763, 0.03347719959434002, 0.015009027988379522, 0.04063970799888334, 0.018124891437530037, 0.042405123146431106, 0.033667783117702896, 0.0644267074042751, 0.047455412230544516, 0.07111627142876387, 0.06814934313297272, 0.010189841775554083, 0.016171238910887512, 0.023853064912761894, 0.08393271555823666, 0.020264668855816126, 0.01797488184585687, 0.020668140552457304, 0.08681724343689219, 0.016270148522791364, 0.11573295634720596, 0.014207727790269402, 0.03766668164321492, 0.044380821768314614, 0.034242935118175326, 0.05512022533484044, 0.020765540971150322, 0.05697787363803195, 0.02747510372090244, 0.01748387119732797, 0.07435377431853164, 0.07701056723993632, 0.07599560033169485, 0.03125331912850661, 0.021341845933948795, 0.06008295056920859, 0.02895443290922671, 0.029307199161379572, 0.039638764330095826, 0.07368563073537043, 0.04323018451912269, 0.015569197224272836, 0.044813236266735106, 0.017864932906964136, 0.025149680215925462, 0.05344470294432775, 0.02511397668821437, 0.037255070262378266, 0.047889772592292684, 0.025915825596800255, 0.01896084658050489, 0.02397566387850431, 0.031865360177752954, 0.03746695486047576, 0.03522043649647986, 0.04505589461675094, 0.06054626905449456, 0.04702377148092755, 0.020444768465935223, 0.023072101476211703, 0.03399851093549402, 0.04892245528378314, 0.04085312860326902, 0.010710194549192826, 0.02720839595572362, 0.05446926127338121, 0.023489730477693583, 0.02019078542117871, 0.03778776183964745, 0.06124838863709762, 0.02462221335829987, 0.044693335845705964, 0.045788439381266796, 0.03341377900552846, 0.04262124421074987, 0.10924156394697006, 0.012433325473759926, 0.014385617236726949, 0.08004989084457198, 0.057618342294928536, 0.021642380311424216, 0.026612057793705214, 0.08616475103002402, 0.00694482499966398, 0.03621460794801674, 0.05951077865076162, 0.021039622332600337, 0.039311981865114747, 0.05969131493099755, 0.029597446893251715, 0.06989560225197385, 0.02874067331093454, 0.05459680342145505, 0.08265260561940171, 0.03666867975205664, 0.020743944952564857, 0.022890270507383733, 0.01460129205482982, 0.0437458421313955, 0.06862817872916499, 0.015871182380754863, 0.029283783683973937, 0.06618120196846224, 0.01333518045759129, 0.033706424592603604, 0.016365986122118852, 0.012397552040525743, 0.03670112357564992, 0.03887692819379511, 0.02903971381695761, 0.03603637759243289, 0.004855556237030654, 0.035089205635050615, 0.023099697878464096, 0.030257408657381614, 0.008350901339473504, 0.0069983276226858225, 0.022573481659374894, 0.044597452281103026, 0.046882451241535526, 0.07205816887078748, 0.03362624966088803, 0.07858097087591887, 0.03707482126511393, 0.00786061943208258, 0.014235490816645326, 0.07808437736164178, 0.04677643233369436, 0.00822699236338057, 0.01369894581711701, 0.06777762195035335, 0.01559905741634148, 0.027852957437355674, 0.027628608588730137, 0.02036973015375195, 0.06940303836017847, 0.040725850755529064, 0.03304015792485687, 0.0582099307118164, 0.02849676432238231, 0.03896130894821498, 0.04716920944291258, 0.012641977180816956, 0.05146784752967858, 0.03489280367390283, 0.03772431443775854, 0.022884268208496997, 0.046233157251751235, 0.1341331242433479, 0.023773723101663976, 0.04202766779569849, 0.03479128936305642, 0.10431936476379634, 0.02635837543845898, 0.02691998491964994, 0.036894093462896925, 0.025914862241235473, 0.030506898596462224, 0.04995293164205167, 0.045908098484599785, 0.049243105214930354, 0.008951283488122207, 0.06468828812602066, 0.051136537485065005, 0.007380582035459098, 0.03354597130730268, 0.005633320777692022, 0.031723926940392104, 0.033376443710538654, 0.05856464857295637, 0.0789578937955441, 0.057152518702130166, 0.011997666592980105, 0.09738699683258611, 0.06685837772825072, 0.02917519263592699, 0.03597299530801754, 0.031027426612713647, 0.03738256261473702, 0.030467289935557113, 0.014650986263258083, 0.06876308681263078, 0.10851006489247085, 0.04478432410847276, 0.018707779010817892, 0.07146788280337088, 0.05853182553584057, 0.03151905970768102, 0.017938433297639413, 0.05343778133993188, 0.07166992317164136, 0.04035466583445668, 0.008906421379276342, 0.06054196364036011, 0.14555177200705777, 0.07597387407816227, 0.06451958024333562, 0.016201757938571034, 0.02398063387391308, 0.053486512192795356, 0.07480225751116391, 0.029254365907681566, 0.010967850985546267, 0.05007289718055437, 0.03615451218079656, 0.014007689784311, 0.1531674980276054, 0.010700050587465447, 0.025920081215219635, 0.04278808666933929, 0.06315688602626324, 0.06733279299711989, 0.025665920055020722, 0.052703796330118374, 0.017422877192016573, 0.022082476756505428, 0.014918988717028932, 0.006339989486150444, 0.031226620964345433, 0.05954234147324197, 0.04784720491678004, 0.019799609435722232, 0.014688149188464929, 0.04036820643851834, 0.028689919985950958, 0.03641921854127319, 0.06328401831729759, 0.1268026740440438, 0.02615895892132915, 0.03321204124198806, 0.024790723973344413, 0.02631707563846102, 0.037736131343990564, 0.01357674713231503, 0.07312226499761305, 0.008877970788988375, 0.06423358812988286, 0.05082465159977156, 0.03376347516032477, 0.046322440968886505, 0.02309250048241548, 0.017318187446724025, 0.0378711007144903, 0.019220150105895537, 0.02647822989421266, 0.025437344316272967, 0.01984895507414495, 0.028022418001426325, 0.019224760039979895, 0.026870558841995178, 0.049733179320971814, 0.07607230105467382, 0.03210687897198143, 0.027393164871741208, 0.09772042894074995, 0.01071641997118751, 0.06666477964890581, 0.022057879588476593, 0.02629967395126099, 0.0882089187601401, 0.025428352359261726, 0.04517996638652779, 0.047713193156185656, 0.02234234335652042, 0.028665899299085144, 0.12241353416034292, 0.044858152001735666, 0.023721383974677133, 0.005709590576213575, 0.0961671550307543, 0.05137346549740723, 0.10628931389580812, 0.18717479982203056, 0.1522949851688839, 0.10620369590939054, 0.18089632623858992, 0.1960099233134139, 0.15054982155561447, 0.1800178532158175, 0.09554891441498073, 0.16969452732272688, 0.0684718661490948, 0.12304326609498072, 0.07618268666368339, 0.1106237780843531, 0.18219191881437458, 0.16802560477968187, 0.21710970078504857, 0.10195445134154252, 0.17689170886672315, 0.08916564000349853, 0.12241597031994213, 0.2319631497225454, 0.18408032554772594, 0.14324440710967587, 0.18202232226969736, 0.2211845224542964, 0.1504728450409828, 0.21574373537253952, 0.2253028425958849, 0.07901188001156816, 0.14902516869046997, 0.17283800058066848, 0.25417098144610084, 0.0833856598323872, 0.08818463377294042, 0.17273402712758512, 0.2907778647157454, 0.1448616800048659, 0.166399123507642, 0.14224657758830056, 0.12403135863883842, 0.09021132703750365, 0.16226356638775719, 0.18015559582460314, 0.10217114697180449, 0.1299542065469488, 0.10608777914556766, 0.13592296610436133, 0.09598209117088588, 0.16400036432089346, 0.13590439613307678, 0.08296823384420526, 0.15543591501491685, 0.21822852623318473, 0.29901334054527745, 0.17457294458102796, 0.11706511429961651, 0.22578598360621163, 0.09804809240684395, 0.13583075976179493, 0.1772923115640879, 0.17507741347916667, 0.18125522310935682, 0.15888271312559807, 0.08677892371891968, 0.1628463907587913, 0.14784891729152974, 0.1899050912188907, 0.0781102404899655, 0.09967935406753134, 0.11987778313097455, 0.10616048088958187, 0.08638109425984083, 0.1722107277882676, 0.11635943240816556, 0.1376676240996007, 0.13309473802726116, 0.08355403063638557, 0.16415552776907721, 0.1953639579756606, 0.13638136247473379, 0.14576684353092026, 0.08387165068979226, 0.19586596007068313, 0.10755438552868944, 0.06940498422350615, 0.2581990564302091, 0.1372876598109161, 0.23906619438240606, 0.15189214549478025, 0.21010186553241747, 0.17942352220416072, 0.09697447380711956, 0.09087640626896774, 0.11765235133709447, 0.20120922415967912, 0.17588252592231, 0.09250542329203698, 0.17213860827107585, 0.23454284355525049, 0.21751462421830625, 0.27881362445412144, 0.11578505798693627, 0.19158277780778948, 0.15485192619023785, 0.12207450961033184, 0.18349075960295816, 0.10033353952871216, 0.230642260923501, 0.11815007100062025, 0.07441628709315293, 0.22442130522141535, 0.1088348019026941, 0.17009064074485533, 0.08348589477640006, 0.10843454394489528, 0.17289701999435503, 0.13719174560279618, 0.09159095179770263, 0.09664971381425859, 0.12922224017881578, 0.1826399270324938, 0.1480113126097187, 0.21248482798616733, 0.19435915705417434, 0.10910404350368247, 0.0994252427030475, 0.10973066512134769, 0.10401112162658285, 0.1114544625424089, 0.1356720416656425, 0.1273143748121877, 0.26871005854298996, 0.1255798444993073, 0.10018540110679404, 0.1270037108371335, 0.11413776976687294, 0.10255751575553611, 0.12626206877851678, 0.08377133913698696, 0.17752766909618534, 0.14948779386618447, 0.11431112780325836, 0.14274756844726302, 0.09942724219252987, 0.1626149096315907, 0.17340775549171433, 0.06996484893944956, 0.08668624240184024, 0.1252261187220293, 0.17389423664539091, 0.10169583538006391, 0.1292002840989059, 0.1232812972739339, 0.0841861680871056, 0.15286406592255639, 0.2796305499730572, 0.14201279819732712, 0.09666316631820895, 0.1839739925438358, 0.15343489335669627, 0.11861086522619571, 0.07699121585896901, 0.18875421265200262, 0.11548241495244926, 0.13193581553716816, 0.11526329082346733, 0.1591067938434501, 0.1212377500750365, 0.10454909154965032, 0.2357229713590876, 0.10972753948261661, 0.20840324942142735, 0.1128939570738904, 0.23037262861767124, 0.12076613102709094], [0.06672790529386652, 0.05532569394657209, 0.02636236484132467, 0.025147688387322332, 0.03449592799428971, 0.051855066671006145, 0.04736122555069385, 0.010335517224795636, 0.06494656700881259, 0.03665114782990948, 0.03806827259400199, 0.0767199824293775, 0.0804963592259634, 0.03632024764233539, 0.04205782867727741, 0.08948160530698877, 0.031160498000380975, 0.05068791256616673, 0.04044678024647217, 0.1325279555373615, 0.03925530668047648, 0.048141612506081025, 0.02765680445478328, 0.03274231443121549, 0.06519422791297398, 0.05444053680666032, 0.06961060988326227, 0.044156993859477585, 0.041797201734997576, 0.04024066812088413, 0.050772887038727926, 0.035813193197452256, 0.0035244741593487565, 0.03361079383701567, 0.057458559336561355, 0.02030564115322646, 0.039069407784770575, 0.02766991413438753, 0.055474066025307106, 0.02067678202424319, 0.0524070828161653, 0.03791788953446573, 0.044015474437225255, 0.060937567614018924, 0.019791303127403223, 0.07339740547561839, 0.01442947098234248, 0.021955928607513348, 0.11034145170161802, 0.019731519541012186, 0.03548158820898783, 0.07096935108664536, 0.010714024988814227, 0.015465009266570693, 0.045407460026082494, 0.015185060629230595, 0.008308751181879593, 0.013030539848841729, 0.012052441879566158, 0.0166313934530462, 0.01823829734818109, 0.030502533810513637, 0.03408384163894, 0.06308085946065765, 0.04512450162080988, 0.04947606872226443, 0.043457988424286734, 0.034422333757843704, 0.06284391995699656, 0.08752476393936143, 0.009264306056373304, 0.0353880871778294, 0.0725486490034288, 0.01961886439652693, 0.05336445140381975, 0.03098996299799652, 0.06756874807779828, 0.026297278011277802, 0.05405800229298973, 0.08171746507287025, 0.09019625808803305, 0.0295521825882456, 0.013122968356906167, 0.057646848426591006, 0.04766669161918183, 0.023063774100474776, 0.05478810706746675, 0.037966417374029275, 0.10136454065720882, 0.06751359740812933, 0.06437653630611397, 0.02607372972453314, 0.03651665726436242, 0.03294633130633062, 0.027992021547810688, 0.0393670252824743, 0.023850808783824888, 0.0415688730596054, 0.054430753863867254, 0.04230141782412126, 0.028283653983605966, 0.032516804959384665, 0.04318839825329281, 0.03187233923874315, 0.060841159279187845, 0.07629553141492991, 0.01065288638440712, 0.05305834948235462, 0.00902794016104552, 0.01419611581255712, 0.02771443341888728, 0.03311976212106886, 0.03805406932388583, 0.030630958874920206, 0.032296125671916434, 0.020434387974561225, 0.027473343633896405, 0.04903278343619839, 0.06351956354093648, 0.06236328788462186, 0.06615833424392246, 0.045188178849076076, 0.05948570459299992, 0.03791211323151666, 0.0362536171451211, 0.04027393931943563, 0.03820968476394492, 0.030721883935433243, 0.01778642421648387, 0.048619421544454755, 0.017597367123310125, 0.060582983818265705, 0.03642893636659269, 0.03818110202349002, 0.022083959136638912, 0.033942590347461166, 0.06798369194110555, 0.05695482205239035, 0.08226263622242598, 0.016111440002737988, 0.029271049387452584, 0.040009478107094765, 0.006391757398828745, 0.017468313866805647, 0.009447709420665858, 0.04141703826345263, 0.052117386667598645, 0.022418674442075917, 0.028846860758119056, 0.03322682673892668, 0.11165266481017876, 0.0198543157743951, 0.012141136666609636, 0.05398233578870854, 0.02523134327343395, 0.06643179698937363, 0.06715640125255432, 0.034138149611892245, 0.023900866884017186, 0.054922486550264785, 0.02836959181173194, 0.02173425532096336, 0.0038969159434219043, 0.04007786677609529, 0.0934391082715123, 0.03037217054365864, 0.02517810590835589, 0.05281340819032443, 0.052063653260589614, 0.005540878384283954, 0.04792208618093883, 0.030968976019310857, 0.02447124807194116, 0.02562242924355932, 0.09533823257492435, 0.034591654510868174, 0.041962366461032824, 0.051952248754640745, 0.02324562039106123, 0.014685944770462813, 0.07823483702997047, 0.011170518588304762, 0.038884872525569894, 0.06574932756202836, 0.0029984073274047867, 0.014150280772047419, 0.030832811551649245, 0.025138127610027313, 0.018996764612834782, 0.056635148883346594, 0.004547279104665523, 0.0268147416758321, 0.08501184999101585, 0.015023226470446155, 0.1037440863588164, 0.11830032382520939, 0.06921946837176239, 0.030182259262449322, 0.02427496868486126, 0.017041066631434426, 0.020930437566412073, 0.015519784553156746, 0.02171761397602818, 0.05374435823591006, 0.04819560638298431, 0.04766112215997231, 0.057053735494733825, 0.040818547394367, 0.044800787337965546, 0.02637750082348864, 0.035063568502664566, 0.04731917881496972, 0.04230065173619697, 0.028405544318018422, 0.06594878621399403, 0.06780209845953411, 0.022000036119753798, 0.0211898636658706, 0.014386803715399677, 0.09423793879367652, 0.015932375568926575, 0.0674718379553768, 0.023456466940021323, 0.04496978633406182, 0.023117697114245068, 0.051379912127290046, 0.046431275249849406, 0.02004635678003392, 0.008104028548264216, 0.04482006977101968, 0.0360037001120227, 0.01651399239387003, 0.018004590735560464, 0.038055406147313696, 0.0407234069350506, 0.035471759300919316, 0.011852909491637783, 0.046176213936339465, 0.013131627065670348, 0.027051707992570537, 0.010245620637320945, 0.05234585706925681, 0.05468672299156747, 0.05080903872787472, 0.11194310406403196, 0.005254886270831189, 0.01940057530338245, 0.02184711347874855, 0.03476637618375882, 0.0338896383501349, 0.07336872314373333, 0.06966394492455068, 0.001559482214713259, 0.01813368421168097, 0.031069929170752728, 0.020692820074937997, 0.0515765056104189, 0.011770455448347475, 0.0374640628785616, 0.04160096065231389, 0.03295451312536194, 0.01399606535766995, 0.03777513288021569, 0.03350244219144506, 0.015796303989425782, 0.0496964339136837, 0.027043639171508052, 0.06022286886769918, 0.040426747047252236, 0.013680108672668858, 0.06501032850675045, 0.09358464199448786, 0.016654031351208687, 0.0774741193820392, 0.10131119795504118, 0.030913518914472193, 0.05566443121361156, 0.045720671243484945, 0.03286476592503248, 0.09628160090576257, 0.020431268081489592, 0.04711746020362743, 0.03112428885463986, 0.056723463499257644, 0.021066783979955702, 0.05898679366275188, 0.02095832125163607, 0.047113170111251455, 0.024009272155742493, 0.05908749208995893, 0.013211026333362587, 0.05817634158677632, 0.061765704829726494, 0.024728486990375866, 0.04075716459943403, 0.04365756965032028, 0.045872126826115196, 0.036329693506441774, 0.019373879054441087, 0.039541386894040534, 0.02336181294653685, 0.06639196807819028, 0.026662962421053843, 0.08370202350159807, 0.022927780087376316, 0.028269806944374597, 0.01636521620375495, 0.013812669654256635, 0.04962552864585192, 0.005539168571797951, 0.032136338883109634, 0.026808630209416155, 0.062300380574719566, 0.05407059294802528, 0.08631138025873131, 0.014991624385959681, 0.05988514666715938, 0.028117546969423854, 0.01814778789036697, 0.03626074942369615, 0.0629221375340656, 0.029016554979006612, 0.06494290510853452, 0.0571626004192137, 0.08566195986443952, 0.04275069391775516, 0.0352275304706587, 0.03731772093282592, 0.038005449553771366, 0.054326359062425555, 0.01508676771810579, 0.016911289421841502, 0.06147441521827733, 0.02249295241199434, 0.04146622876907068, 0.09376157766147968, 0.021571601448099942, 0.0417734568397845, 0.039442293421034856, 0.026009077649383296, 0.006515230183609792, 0.028239423897297635, 0.0064989723614417025, 0.053566200658679015, 0.019857983420332594, 0.06149129979612847, 0.031578948631161646, 0.05968642345960102, 0.03916411540440975, 0.011110563589740666, 0.11551051505751188, 0.032329868014541366, 0.1622641945798551, 0.12568367239568504, 0.11391998629175848, 0.0880342583742834, 0.22773586123460726, 0.12402909101858256, 0.14306862057457048, 0.17716103473738318, 0.1129688191858511, 0.16511327557025418, 0.21305142661496518, 0.13329563692452448, 0.12127194057909713, 0.12479293430524489, 0.09471250728013055, 0.2554247915864952, 0.13759496832086196, 0.20109449483213887, 0.23569617360349626, 0.25014558776972756, 0.218585477240624, 0.20218203324944745, 0.12175367964852242, 0.09723253052441344, 0.20932834655527147, 0.12227861075511864, 0.17996094820480193, 0.13465781786268757, 0.16367715182563952, 0.11481833163528674, 0.15149967865117137, 0.14927511253664572, 0.07424857512476944, 0.10723663524033562, 0.14414200168703833, 0.12212011482446425, 0.15920381121818097, 0.13013583067203724, 0.13799155671750346, 0.15314210987379476, 0.10931055782543075, 0.10575341241013621, 0.1769404014151904, 0.17017141705559147, 0.07565178007127778, 0.1842968373168861, 0.17596921643182156, 0.08770751421369853, 0.2771475670799133, 0.10001143786094843, 0.15398928054398106, 0.1416038911068632, 0.08940095157032052, 0.0797870537386306, 0.17775486013100994, 0.13913201648862134, 0.05920907024354224, 0.12624631801079358, 0.226853481163421, 0.08002157623489058, 0.08666806313539706, 0.11276651834768635, 0.09230077822482394, 0.16028166628412663, 0.16563131954641114, 0.1027257486637081, 0.2196756203568751, 0.08387239379507881, 0.1894601320307101, 0.20647454646325883, 0.04271723119722259, 0.1327548248152579, 0.1311510657110522, 0.10934626518358147, 0.14819929526457865, 0.20981211575769612, 0.11243471034592199, 0.15108185429726878, 0.18101808825327506, 0.20432482713893538, 0.23478996819786488, 0.14780278347672957, 0.10579767697040113, 0.19779723708427724, 0.1883766845229172, 0.1040695664743262, 0.17768687748860928, 0.13530268003382992, 0.1710981382958351, 0.2220317084462412, 0.14560679244177957, 0.10494579485948048, 0.17628556477927393, 0.10161645334934997, 0.10310690038867536, 0.2856470980951863, 0.09151307129932028, 0.16743387846696764, 0.16042372962880522, 0.10145549827645864, 0.2053799447152884, 0.1359622817366354, 0.11680248403741468, 0.1537092141206226, 0.11240259594013614, 0.17809822073867246, 0.10602064686076296, 0.12447028871505492, 0.13758845657350557, 0.1958095759994561, 0.07971835863446036, 0.17166599330882873, 0.10034102420773237, 0.21142762665066028, 0.11587934042777746, 0.16571016531557808, 0.126548532036043, 0.086181819468977, 0.0827373119611894, 0.12096522961773219, 0.20800997052461873, 0.1633707626212028, 0.17971817494159747, 0.09233829355047596, 0.10201271232818404, 0.12777049590142506, 0.1917304489160738, 0.3122246800170791, 0.0919544222133775, 0.14217464193221063, 0.10433408131282176, 0.1038736624703292, 0.16899890416572172, 0.09503331425930224, 0.11815110521931803, 0.07301630737680583, 0.13663297639258448, 0.1983488969985516, 0.27481455355882645, 0.06951772938332251, 0.22763729636226931, 0.15172959695900642, 0.06534386020634445, 0.08432977126851197, 0.17212561541988006, 0.140422782710483, 0.15307671660857816, 0.16684687125586695, 0.15027550079168814, 0.16501397525350894, 0.22304029384207344, 0.09861811544866332, 0.08033250067983905, 0.18847717993682434, 0.1018614023022594, 0.16066651821376818, 0.12419591432497387, 0.20492341759945118, 0.1329679045105173, 0.26470010919917014, 0.09405092140960117, 0.10461883619427682, 0.16298119158994767, 0.14542041857156063, 0.1710716163318965, 0.23050009032651303, 0.09758316896735661, 0.17574723479488205, 0.12450995674777417, 0.09782903722577518, 0.15232875432458617, 0.1037824213985474, 0.18335313956824043, 0.11723831911841709, 0.21031519037581262, 0.14705952497259264], [0.0497954775909743, 0.014001514158031393, 0.02208441304373405, 0.048893761460579215, 0.033888044887252396, 0.11344455978682927, 0.04159405820011612, 0.03708665349310444, 0.0683684749228339, 0.03962934910950642, 0.026015736868665106, 0.03599878182754882, 0.02293480702886178, 0.010460193246422757, 0.052356490369645826, 0.0508969817911425, 0.021893879316086252, 0.06625008859461354, 0.015073943406253334, 0.06048109029389678, 0.030922836458851254, 0.03116763602461546, 0.06061381885721799, 0.049107304639032776, 0.05504819774819959, 0.02317129262542773, 0.04715808967669164, 0.02347544485312556, 0.004585217693895703, 0.031667828236916856, 0.03560962065333321, 0.018935661439994173, 0.0464748541614221, 0.048298484330335935, 0.021819212556546255, 0.024215640920785167, 0.03309946845195467, 0.02595825346126672, 0.04903442286435635, 0.045756060675147085, 0.0231883974535571, 0.013129217719148486, 0.04130693993741467, 0.05029938341448865, 0.01685471382863339, 0.04649206049620144, 0.014516827988348182, 0.05497472225538185, 0.04306898046765597, 0.005034009236917501, 0.09903855216238769, 0.04841697898002402, 0.03101003641683248, 0.027360027738576456, 0.03460677708649347, 0.050252330294179345, 0.028996778419241313, 0.05280788852682999, 0.07961423196379216, 0.03957183505859106, 0.02719416012687068, 0.045034187515416456, 0.04361124048309942, 0.04053676493405815, 0.026452728742433172, 0.06348657579491697, 0.0930621930127663, 0.042310967110097415, 0.0519130633573138, 0.04872101629453321, 0.01866956846037459, 0.029634132928725694, 0.03670894533335682, 0.06660805849899208, 0.014888996374793352, 0.04529705526487482, 0.08037186993826782, 0.025177366633508957, 0.02939080999743554, 0.025870883048722343, 0.037008140972184564, 0.06659683531090137, 0.039923350672207536, 0.05149002194464688, 0.031718932047125795, 0.048392050478967934, 0.04510434967796168, 0.04957577123516991, 0.050735812213632374, 0.0027683726699662308, 0.01304991229722697, 0.083911586853285, 0.02372915976710858, 0.01831148364280741, 0.04704119998120493, 0.032296543189835165, 0.052713487342360525, 0.015965902449322805, 0.045755080082604004, 0.03348799760363275, 0.05182601278647781, 0.030123825906024828, 0.08772341053812735, 0.0477801722234055, 0.009606155555605168, 0.03612818939971828, 0.007177546710496949, 0.023105941495046984, 0.027378544083706317, 0.07195807948348022, 0.0311188017498822, 0.1352842939236472, 0.08149814942190725, 0.026861321736848163, 0.023281442662400585, 0.04134625173924912, 0.03178436936239802, 0.06632169483289604, 0.026528617412212397, 0.01007035216917434, 0.05784948634344244, 0.04801817275884171, 0.05898696220209522, 0.03142788183815297, 0.01289427387453015, 0.024856559654337265, 0.04561893093670088, 0.02606177683769455, 0.024473391202909332, 0.047605201571939454, 0.035957922528107325, 0.00634535258042536, 0.048458861006844434, 0.05197987005475068, 0.0852932034420871, 0.06782145750138067, 0.017487672908652215, 0.07408431055204523, 0.02529654310144965, 0.04209625947799894, 0.04359615621187034, 0.04187107176309632, 0.06476217730631752, 0.02020120421694892, 0.07304429256867978, 0.08192050901632156, 0.05027871053185194, 0.022653099262125553, 0.06033905759273518, 0.03703766983122595, 0.02034492422676375, 0.05099699456965731, 0.035226860143724954, 0.032603629534282995, 0.039600678268940225, 0.026535845451777982, 0.004752027114943391, 0.02361929701310733, 0.0723657761550238, 0.0872562807654181, 0.020264982951865084, 0.04732780496499712, 0.033079412270097, 0.05461558789735841, 0.09558949409232986, 0.059567825388043165, 0.028425380249597856, 0.01832988698996844, 0.03528575698334364, 0.036211352074338544, 0.04503236039571705, 0.07828439525779217, 0.05178969255798767, 0.03802791508215089, 0.053398109476773016, 0.0336635236688439, 0.05666026507594413, 0.0666609492092844, 0.033252774136922056, 0.05257040127030304, 0.011169808999364896, 0.05162050203991033, 0.03502354806950016, 0.008144431067780863, 0.07869561593378745, 0.01575800342365138, 0.038960550521169944, 0.06275679660780777, 0.03663493740943171, 0.036069388321090134, 0.06700101563887251, 0.0458313211528284, 0.0128042240694706, 0.05574077187526611, 0.03964886136893784, 0.045052343799221906, 0.023416774009444544, 0.059261317439978166, 0.09192505040236058, 0.04597608112700043, 0.02908456634970442, 0.012806260905739282, 0.048290317833063104, 0.06031193424977603, 0.06690435832546604, 0.03838781935853824, 0.05782432801600906, 0.037529854509498806, 0.034726206363449176, 0.019174914529186585, 0.046677725735090436, 0.03731972042230829, 0.05380670630162763, 0.025733967814894936, 0.13165463062544025, 0.033227926075098016, 0.07379656792768548, 0.0695402600291756, 0.05150773389745624, 0.0340629197777279, 0.04965965786287862, 0.02347180593548523, 0.04624633779448848, 0.05738594952309805, 0.04755566249631586, 0.05023891609462519, 0.09967602924593996, 0.0732355081145802, 0.06789172308579569, 0.028661616867588415, 0.02473472294607951, 0.060138560891632116, 0.036741025265186064, 0.07980684178971476, 0.040668363517691056, 0.05274036170674428, 0.05489853864175178, 0.017781821943278757, 0.03630369248229169, 0.06670814022542008, 0.013319210397199759, 0.04911269023714047, 0.016975556537809394, 0.047867605838203625, 0.05485793215132529, 0.024016456145252434, 0.03798434383145744, 0.02089811248644706, 0.05686023700681906, 0.00249876813482373, 0.039293074815143506, 0.03234527787313827, 0.06739335990841351, 0.017646768303107352, 0.06791040030938965, 0.06648670251090681, 0.020794160100781632, 0.11090529241388845, 0.04858783573933667, 0.01568014686551666, 0.0328032030994373, 0.03385757374006414, 0.010523767052819172, 0.026103432868577303, 0.03707789710812992, 0.008957927385645529, 0.060741341853093725, 0.05789773456091362, 0.03691764683612893, 0.016329123886422287, 0.016862129559740424, 0.025068677909251665, 0.1005802428229682, 0.0099493591152432, 0.061584314361454985, 0.08836327781600338, 0.08166216118561645, 0.03528703635017719, 0.06895426405413498, 0.039548139959093065, 0.02817378165350566, 0.06897062003131836, 0.02384469540218913, 0.031026744794461037, 0.07236502538885801, 0.09165852075262416, 0.05312083544389856, 0.06433693722130791, 0.05952254959171819, 0.012637500354509442, 0.0639040171048574, 0.03166890650567028, 0.05603385030201847, 0.06943201946635401, 0.019830618759677298, 0.01617205479452687, 0.09502442763938058, 0.032415574101070245, 0.04730071609599456, 0.03749643392380207, 0.02913924779051975, 0.06429795866772052, 0.07140168514583381, 0.02090084550511693, 0.03723361597005879, 0.06779772409748647, 0.020586372157859228, 0.0223322635546567, 0.04952541244546733, 0.03707031666811916, 0.0562508600283294, 0.08019277390332953, 0.04176435571524405, 0.024020194654322924, 0.015790975847912413, 0.054272564368382584, 0.012437278487449212, 0.03786419826229254, 0.05064819090729279, 0.0415342765289449, 0.06091691388358032, 0.11298015728713044, 0.10227329713562805, 0.018085665820587068, 0.025311288378772237, 0.02651852611902981, 0.057351548344858234, 0.08146472500577089, 0.08663445485815888, 0.041063346960131204, 0.051035367913784525, 0.0409760435802802, 0.06282700090518882, 0.05175240322827332, 0.04657186770571336, 0.0325092053671758, 0.04629044147628931, 0.03681923135093624, 0.04162387817256874, 0.02755764969474366, 0.00533254268849569, 0.06718703710864629, 0.07716402231204895, 0.10892659455778138, 0.006203408936984958, 0.014659600921966618, 0.03924774156222421, 0.030583809993620363, 0.04974694975141076, 0.05038374884715004, 0.04635111947033194, 0.05052784615526757, 0.22024232623798234, 0.10080109064977977, 0.105277702452675, 0.1458064043113301, 0.11636996611712441, 0.24611716038517414, 0.13334765429458312, 0.19337548483763972, 0.1324550086452115, 0.07736112907408707, 0.11906185352634038, 0.0601291801449993, 0.09640052839512787, 0.08788292536572104, 0.20505837164819243, 0.1343039924939794, 0.1269670075646812, 0.18861020344399637, 0.06871361285448074, 0.22700309813503297, 0.12179611325864831, 0.09674109278186675, 0.23420282309093785, 0.28671579074955755, 0.1970743105536507, 0.1151018531151837, 0.15660047591213258, 0.15046095535639795, 0.1311821535590195, 0.16246693208813667, 0.23259742455857418, 0.09502224428879638, 0.12162647840957488, 0.17539127970174437, 0.14342541836442488, 0.09812813327317277, 0.10556268716050733, 0.16973655490625292, 0.25041882068880145, 0.17363643273711207, 0.17171269402869288, 0.16068668164793523, 0.21019212601165618, 0.12940746491714833, 0.1576875240331696, 0.14246685851004817, 0.2215761312794301, 0.15198352446238841, 0.07780703821129377, 0.09682438952187378, 0.19366908037374098, 0.0694158933155479, 0.14968896855510053, 0.13412209257723826, 0.08363971757071634, 0.19524150648184363, 0.20554261582513011, 0.27762882351394624, 0.13308551432865282, 0.15767312158019314, 0.18941910036148565, 0.0972254518719931, 0.10890922734453794, 0.13274563176016654, 0.13929470292022153, 0.1361907751209313, 0.1705135672443336, 0.13060276126188616, 0.10855079012652559, 0.17904997773228154, 0.1300772096240713, 0.12512033730144465, 0.2163811971343333, 0.19639506635646667, 0.09126356412326136, 0.07545417535208887, 0.22451582514951307, 0.0792314331497877, 0.14554833993315697, 0.1974602656499032, 0.18727353323371182, 0.278312602951642, 0.09237623788536557, 0.12291557455976164, 0.08964423811243427, 0.16209706483829409, 0.12173856473377637, 0.08953786680414792, 0.1009023598124904, 0.07956963032484055, 0.18216968694281194, 0.19938565910823886, 0.11165901567907104, 0.11917717274158232, 0.1709547266364098, 0.10439444138037582, 0.17862219423536332, 0.08176840991983492, 0.1723172293315011, 0.17703660673672156, 0.2815519904177035, 0.10649305497927052, 0.22853017183801821, 0.13959002981503166, 0.07579951246659603, 0.11629878122720028, 0.11739643200510934, 0.10764794784688181, 0.10039558498969964, 0.19947182867796193, 0.14366094443586566, 0.2334865462034941, 0.1627501547937432, 0.19369145014112998, 0.1903843251808036, 0.15725840754326315, 0.12941716359026972, 0.14387210891131433, 0.10645210757971772, 0.08556574688202913, 0.1569951644107219, 0.14722547493875027, 0.17627310818962513, 0.12977063655853271, 0.13989068868179477, 0.2312787574145102, 0.1787810961926176, 0.09411950926146201, 0.10498490364801501, 0.18896173054893173, 0.10895749088376762, 0.07804481658123194, 0.18028313414223734, 0.16312561448543303, 0.16551259123990614, 0.198913304615886, 0.08794934518875615, 0.15276922423753048, 0.1506063282009094, 0.1405210564694097, 0.10938495262375764, 0.11980678976303148, 0.12815972985399346, 0.06370869149724323, 0.15004262538446536, 0.2437610110087741, 0.1775536854420939, 0.12257504081653973, 0.3406476145309787, 0.07662787567824125, 0.14869823300790402, 0.22685057002930875, 0.15595774346541974, 0.16036503197204682, 0.11570428933707938, 0.23142573904366265, 0.11003495524487189, 0.141436945226404, 0.17119802083940278, 0.09704234919721082, 0.19547105706747503, 0.12585167547747975, 0.13558050948044947, 0.21345938375640303, 0.11965519628457486, 0.21919126892762802, 0.16582903151790943, 0.12067558709532024, 0.15370501595879757, 0.134318241729371, 0.12602809020468306, 0.16465567593132296, 0.17894229641364467, 0.09166419746414309, 0.12423203537060369, 0.0957840804250971], [0.03569377541181541, 0.012680182943210728, 0.05773494470744364, 0.011437045365211465, 0.011424038149867088, 0.023586594634839607, 0.037585985771710836, 0.03506933331429478, 0.06360536155801627, 0.05331776983615372, 0.03955425717116844, 0.0726119508486121, 0.038216016480639096, 0.02024776129532726, 0.0729779340326786, 0.053589524205533735, 0.04750665585179964, 0.05229817958728922, 0.07490694342601685, 0.008063168291212812, 0.04979239408707908, 0.050832561457589756, 0.013876163021421, 0.00735769898916084, 0.08559576986778168, 0.028616107414446534, 0.03481683073445194, 0.0828136602837232, 0.03958566294562432, 0.02104372664865467, 0.10918029989566534, 0.04396431891608142, 0.05925397065678432, 0.022490719265695062, 0.04294426901446235, 0.028279978676789233, 0.049645776349690654, 0.04154713914519356, 0.05094455585124032, 0.03182695619010877, 0.055597390859357776, 0.050738727178184256, 0.08598051454511382, 0.03155658269421228, 0.08813702906932562, 0.02473035241447149, 0.08896567573350284, 0.09362170532826455, 0.02565714068740847, 0.04152003495443252, 0.00751885851176696, 0.1093049117574288, 0.023405428247285948, 0.023032443019591516, 0.053560493303643125, 0.032925428597316626, 0.03465737336345258, 0.024921064257561684, 0.10429197712050331, 0.03551785864176289, 0.03850680813493748, 0.023740647255533168, 0.06400765347925406, 0.04210387439196629, 0.009370485842678576, 0.10439152258538431, 0.031302716477864215, 0.01227837365736524, 0.059046556181724996, 0.02423782682707233, 0.05739706162843974, 0.02548591429067235, 0.03704207866723019, 0.014281277976659758, 0.006556262331639207, 0.04248774189862513, 0.030698265444727677, 0.03593232753055711, 0.0187022325342461, 0.06594125556969835, 0.0030973068844046326, 0.012689019767417303, 0.016703687255240737, 0.05318468504194772, 0.037982692911980614, 0.10548159675372225, 0.023187763515799757, 0.07243250241322864, 0.09540374841420882, 0.02611350500956178, 0.04698252913752391, 0.016422228467079903, 0.01702681165038338, 0.09592492568997607, 0.05532946692959917, 0.06485648272979645, 0.07624836338143196, 0.02415162086817286, 0.03146637392590844, 0.005107126104825687, 0.07641599108014377, 0.03556663545990183, 0.056627177738494454, 0.008633763983755583, 0.03268096611023911, 0.03634932450950146, 0.039238985177249684, 0.03209100371497053, 0.03483343569021072, 0.056165261194109924, 0.036260040792366194, 0.06923993058021992, 0.03780065892985271, 0.01002262872193129, 0.04513661730133238, 0.01719158375635743, 0.008175405917779334, 0.059302529139864835, 0.009456788520178488, 0.07197801309127001, 0.04294199756376686, 0.052547464597850084, 0.033651756558326945, 0.02508322208849413, 0.05534210354991018, 0.04342094041226853, 0.018223862336467833, 0.014660946363883634, 0.02208247867172524, 0.10881537391293435, 0.04890720247321072, 0.012380914526030183, 0.010534039334273868, 0.006572538348395498, 0.005882951964233672, 0.05300992506466085, 0.027560024567308928, 0.032124407063688964, 0.06729051260457886, 0.01869003066883212, 0.03776407057058908, 0.02423181878252616, 0.025747761227971604, 0.06258436553781072, 0.05207419846086733, 0.042532374181093714, 0.0575604030652152, 0.028563611239435214, 0.015337255486707776, 0.037259195645850514, 0.03537189207911011, 0.05689437771516462, 0.027404437855546995, 0.041138795129353964, 0.007745405553930229, 0.013586414204309545, 0.05906583861477914, 0.020483796815237692, 0.03444232865266743, 0.06102681302675798, 0.0021111848623296546, 0.02747062593698502, 0.07064204002099653, 0.025230416307045568, 0.04667775637860741, 0.050331589750825405, 0.012045018487579882, 0.03818890845943843, 0.035245387980173674, 0.016765215606879325, 0.06918414405757381, 0.03783502563413593, 0.019116846979745937, 0.02319555079955007, 0.03270869466265844, 0.07071547720941805, 0.05497688645376794, 0.022721363441838373, 0.039783865213394165, 0.04809251393101389, 0.017613477952357744, 0.014544785409534891, 0.06906578347327248, 0.023063906250641714, 0.03457597652149778, 0.01415360080558927, 0.03503381747812514, 0.01365038158837706, 0.04303921029091843, 0.011751605854970554, 0.050278139796348355, 0.010869987083659058, 0.07416532435003789, 0.03277289666115277, 0.04736063566299216, 0.02529604897473849, 0.033340805300301125, 0.04279069136828185, 0.027827439048597892, 0.004323600104168779, 0.040217865513817924, 0.05402416418937426, 0.012736695334165087, 0.0016510762854464232, 0.04573319678104693, 0.024232615513967413, 0.015778228144852385, 0.01513325584857094, 0.00811492327615739, 0.08511102773369321, 0.051221998423458114, 0.024207667860713218, 0.033502809913648714, 0.033631321162946766, 0.02909037329617047, 0.03292250980232512, 0.032448320529393615, 0.044911601956212716, 0.042846631108512806, 0.06095690367322776, 0.054548084059910434, 0.06981241276427623, 0.025014779793338913, 0.04827611456294695, 0.027090113895434528, 0.06413074465648783, 0.01606087341168595, 0.01906083446116217, 0.06606803546028753, 0.030651015056777867, 0.04255525339695235, 0.02653900364924583, 0.0065900697917377045, 0.014418487196728108, 0.1091246129644494, 0.041218690438977176, 0.013055585178306267, 0.04529064310894859, 0.025058088658918298, 0.03612990543666867, 0.019433628166875532, 0.00470326035170846, 0.05037377055193629, 0.026904398860830455, 0.015200324931121884, 0.014170598381409242, 0.015241512690760918, 0.010740518224455658, 0.05167202528325781, 0.050641200354983734, 0.07150371273558948, 0.019009801514086225, 0.017253707741357146, 0.02874261917426221, 0.0466434816048751, 0.11356094386428596, 0.07928708177660743, 0.04673796322857661, 0.05552996746114185, 0.037009247969235146, 0.062250289915790485, 0.050462506516205693, 0.03230650233285081, 0.05554283007739052, 0.10379321557740051, 0.03328815973814457, 0.04692980696657493, 0.02766125159518373, 0.052599317259005005, 0.07996849400261719, 0.014288349925810772, 0.004271250922277931, 0.02306873260456468, 0.04893876912613069, 0.051216302559741085, 0.04021859712778561, 0.031224142669910387, 0.08306115264854125, 0.045908554306914734, 0.10309740089841428, 0.04510552945336507, 0.0452730882041637, 0.03673696499918738, 0.03554230450742668, 0.020181676635759014, 0.04745648092319889, 0.0452388325826295, 0.08222743448230528, 0.03196060597415894, 0.018479245406905973, 0.048358269831946785, 0.042564147677753246, 0.054857901507808324, 0.0074751943729126896, 0.03858216054316971, 0.00710691340387829, 0.05328469782046253, 0.06086296214151287, 0.039872214303261815, 0.02711853192698571, 0.024321424256589626, 0.03774041760592692, 0.028918848125143882, 0.039686759738552, 0.015836985173424887, 0.039891220944663214, 0.01419727739337231, 0.037060166003122445, 0.09329556637713987, 0.04489090226049866, 0.02507210806793263, 0.052091194121467496, 0.01992368695115851, 0.026714725066877665, 0.011105651050926217, 0.027485880662777254, 0.01880717317333385, 0.005919152491485641, 0.030318672708686323, 0.05146183373947298, 0.06816406734287739, 0.05730563286511649, 0.04637758014723659, 0.011875007297813654, 0.02730354599113907, 0.02690733106236064, 0.06455757820437993, 0.037727359637257554, 0.021525030963182933, 0.04855228925965006, 0.01015805199952616, 0.05152664477786711, 0.07869987538264644, 0.045760576763460716, 0.024450270669354547, 0.08477803229564622, 0.030790695868011926, 0.052723660989994967, 0.06676728221317453, 0.03630026040839092, 0.08646013155098885, 0.05681008506085604, 0.0677168864997164, 0.02842282534637038, 0.016886611814580618, 0.020798377414804795, 0.02629345523253564, 0.0219084560540655, 0.024455778841530124, 0.021024315895873214, 0.06040418655761789, 0.09066373260030824, 0.16207939885076017, 0.11132048142533149, 0.11572416931871446, 0.15802893877750443, 0.1229600766072831, 0.1644624072697855, 0.20879540982986652, 0.13775676609047, 0.10899057056033805, 0.2104002567789247, 0.12070962438179601, 0.19931828933617762, 0.11685554328705035, 0.12681652491371478, 0.18735126051450932, 0.157476834532234, 0.17123925169148754, 0.10763683957197975, 0.11943996388224826, 0.0997043515165006, 0.1710334651532673, 0.29189120497434373, 0.08468962574918425, 0.0910564292702944, 0.22024084002740923, 0.1564047557692374, 0.1708047879078696, 0.19789223198688802, 0.16324494034051895, 0.05994975086181395, 0.1841378434290809, 0.09326495350368562, 0.14243783909947644, 0.10979162273748268, 0.1818300801659784, 0.18989873268911917, 0.14844087343062126, 0.1030476511486115, 0.09673740023807173, 0.07773052134941663, 0.19327512731955898, 0.15576920922725432, 0.17658685183813497, 0.14834184890552876, 0.1663729079788731, 0.1205315625655555, 0.27654079480036614, 0.21486140126662873, 0.13178451317212275, 0.13494467182505515, 0.11178569597823006, 0.15989843846088456, 0.12904248530826262, 0.10952994242430696, 0.1917366235847435, 0.0744518259119603, 0.09807959394229036, 0.1341461170945437, 0.18571167913896425, 0.15932131378400713, 0.1450522673586684, 0.14264791573007263, 0.17551688747780939, 0.15397325398460512, 0.0715287025236795, 0.1300522811230152, 0.09694464234334808, 0.12835971710662689, 0.13693550451388284, 0.10955093323343223, 0.1712071526074602, 0.077323675035469, 0.19724835040828875, 0.11516713146721164, 0.1831311885748179, 0.09928268140121814, 0.10844997295569028, 0.12173985176148916, 0.12165117708425369, 0.2527414000923595, 0.12133957848193185, 0.11206255249318578, 0.08736217709919138, 0.18956710854845663, 0.14180134260846725, 0.251086313097227, 0.14611365153424202, 0.17573054939989122, 0.31137147257404946, 0.0867862092150796, 0.22251897100960055, 0.10655459482222797, 0.18578856372304503, 0.17865047820152777, 0.23130682687605583, 0.12538938738045194, 0.1881878285278236, 0.0664589241627724, 0.16497263714911478, 0.18726605621557083, 0.24139920790349287, 0.1355615258216858, 0.08644930672861877, 0.17144879206053673, 0.13964656710384354, 0.16702189170304807, 0.21117552243653806, 0.21112859189029665, 0.13230715367582538, 0.06245127691316509, 0.1497360369971683, 0.1859034615899286, 0.09083976428354941, 0.08150910447922446, 0.21863374077985365, 0.08682567806493852, 0.08952678151188359, 0.14007571423726697, 0.18451855848393134, 0.08840685289713646, 0.1065538134125452, 0.17759663233112905, 0.14365576568149752, 0.10452996233418103, 0.14062110755232074, 0.11371059914029415, 0.10286437227360665, 0.06855617412516186, 0.08940987649463839, 0.12494228314608337, 0.14687253823203428, 0.15322771253845385, 0.14574157795117748, 0.10823031256516134, 0.11334191932673417, 0.13627112242242984, 0.07088845986272059, 0.09884802609561913, 0.13643497330767496, 0.11942730810973914, 0.1146929000594443, 0.12745445398914237, 0.14607666480925777, 0.09464446335069596, 0.20943808098954542, 0.14108566326960442, 0.1248974210372375, 0.06474678659991873, 0.11456959054715211, 0.20266623146110968, 0.13124705652796453, 0.06662348750978708, 0.11357045101542627, 0.12177221131541076, 0.1298110093921423, 0.15758177325610193, 0.20284416304240305, 0.16701997648323738, 0.16625811736429894, 0.1633900067498607, 0.13929629638310403, 0.1389921441554062, 0.17008369998826137, 0.20645684983220794, 0.2085387244099571, 0.16297779015956387, 0.09848411900982743, 0.20271601185442942, 0.1763344565106015, 0.08493286632602254, 0.08312581813022976, 0.12675903001499753, 0.11568310700597302, 0.07435003580946116, 0.10716001112614909, 0.2521735144358489], [0.02535162865364504, 0.02686347061347577, 0.05092571774918226, 0.009864316652378729, 0.08416171456056257, 0.05221481006892939, 0.03700624107413235, 0.05258905168081965, 0.05697533022612334, 0.025288367028077765, 0.07285368223223956, 0.07210700697596036, 0.07040439954688472, 0.005047438758230138, 0.017357909105597966, 0.05102453926097482, 0.06232649268161866, 0.034294615409547285, 0.08717617095117608, 0.02496886622881697, 0.02749936764068421, 0.061901428796831644, 0.02464494127179346, 0.04226363053725612, 0.04797550166145929, 0.030131865998790152, 0.016261005263415076, 0.013987904606056551, 0.05782680248000449, 0.041225386047435385, 0.021058851139499776, 0.031201045118993333, 0.03866009083726714, 0.03287114743744174, 0.004847193429727228, 0.04149215318442833, 0.04805204916685339, 0.016707008246392492, 0.004577087585799276, 0.013794925142710489, 0.04546176416859512, 0.04293088162798555, 0.040658906162265813, 0.028423338625279647, 0.020691151918482878, 0.015351620592897939, 0.07326501782142347, 0.06004338978879875, 0.051722747964724425, 0.05128699332295407, 0.06499169724843194, 0.03994586982674176, 0.0418923843291498, 0.0833062854625525, 0.039014345215212916, 0.026757198896619584, 0.03354384924375242, 0.024427136729261088, 0.0372784512658273, 0.06159658325956233, 0.039515182856590524, 0.04780370644443939, 0.05263155806929835, 0.034902613429773244, 0.026841187030978264, 0.09990839137425346, 0.060705167181309194, 0.017367906553009828, 0.03725949442014098, 0.041298915166407824, 0.017702709958558122, 0.021926290580942746, 0.02708536415030399, 0.019128317231192224, 0.016030058482541673, 0.04945932587067928, 0.05854422083845543, 0.03719528859120704, 0.007179702769198846, 0.01980104968101988, 0.012991438721186452, 0.05699562006479791, 0.1031561445204481, 0.08547100478843336, 0.022648954726455194, 0.05573352851394204, 0.045682022107705, 0.017162819070020513, 0.04345917586056937, 0.013506266085671322, 0.062355531244388515, 0.0629432011215437, 0.017708943999041955, 0.04568650755250166, 0.061235326837988636, 0.06574889855279077, 0.026021367614908565, 0.02353910675963327, 0.012895322457376509, 0.02891994554609541, 0.05061087859494071, 0.06100322517956938, 0.035465760832472194, 0.003805379209581823, 0.044996112945579717, 0.11186974348440287, 0.0412962261977936, 0.1360449273019068, 0.06621409778393085, 0.01694760773511183, 0.01419653620330557, 0.04389994454780414, 0.007306999290331959, 0.024249015541206446, 0.03258882105470665, 0.015531376421061015, 0.0578351796514565, 0.096490107056114, 0.0258221770937164, 0.06563210078785497, 0.0850222917694238, 0.0786399826287262, 0.010115362707555536, 0.04978690123666198, 0.030843619137041034, 0.01947685850844268, 0.062164610642338955, 0.08104719942615879, 0.04333999939262868, 0.03067244062080018, 0.054558690547222094, 0.010611761827021839, 0.03175174933858216, 0.03228840350563968, 0.040028239600360394, 0.07233345490549842, 0.0814255319475647, 0.009977747460887318, 0.06295154764947873, 0.006128119731006483, 0.026913415715699236, 0.05849704514407824, 0.05435075130193465, 0.039579495937833865, 0.02647457757003365, 0.01913308612852087, 0.06736106930240508, 0.023644474492738807, 0.08262714851767787, 0.08191807285672234, 0.0399118363707056, 0.048837871516063336, 0.01626374594296419, 0.057359159428385965, 0.061160617943612806, 0.07418744130841187, 0.07960445668187835, 0.03747882156242286, 0.04811103793702299, 0.05176158479204582, 0.03537506368311663, 0.046520447884235656, 0.06692989969686156, 0.046718876147943164, 0.020351430228460702, 0.0493011363751946, 0.08121629801368521, 0.07890108071507947, 0.06193138666511063, 0.02817574283859182, 0.04805060892155574, 0.017056323272446473, 0.06289140208654347, 0.02659975059120165, 0.09437640918599022, 0.060493451122555046, 0.06130742337254267, 0.006762957641659606, 0.030200658779170726, 0.06866258373784442, 0.02072234127310015, 0.023955770490330555, 0.019797793807341688, 0.041444046693223144, 0.07122562281907567, 0.04767677716670498, 0.04981520818546415, 0.03850497335435883, 0.05900070198901719, 0.04659781127326912, 0.03680230080780964, 0.0427618328361742, 0.022646562616911628, 0.06449621456164507, 0.07862995453779736, 0.009513747157348741, 0.015644179037471694, 0.021461051130186648, 0.01467380993774221, 0.06655576533728069, 0.053400817597585346, 0.020304537986615495, 0.040725394933214115, 0.02942395862191916, 0.009395554154780845, 0.058001098974097165, 0.06245738646436123, 0.0504422128470915, 0.03669312561772043, 0.018285293011896072, 0.023936767679368778, 0.10592564429727294, 0.031440493560606436, 0.02890188693850031, 0.055988720062399105, 0.020511477487161756, 0.06234441913904683, 0.025433925648910866, 0.040127313921167966, 0.048725130186686595, 0.023914924597427733, 0.0876413778431954, 0.06370899793241294, 0.01060663095314897, 0.049848149966208205, 0.05121826757526687, 0.028412077132792726, 0.019525411245863766, 0.02656953991390765, 0.033811482060099804, 0.017484702402725816, 0.04030460198860496, 0.0370329890340086, 0.005433434074098666, 0.02882597911652298, 0.08414934990146468, 0.03550499602551422, 0.060978541826649066, 0.04552330784199219, 0.003259106090427527, 0.047551108103606014, 0.08473321615207581, 0.05421014352431221, 0.009545826131568081, 0.031310394594085314, 0.0402615133733038, 0.08448381622832629, 0.06975011449427375, 0.011214068771580295, 0.05606301909973545, 0.06725669748360111, 0.018250884172777017, 0.05185146605776203, 0.1681554566828474, 0.020684806795250026, 0.01947314298200992, 0.034234389407379974, 0.01879067163944485, 0.03543889412896768, 0.03459494485850296, 0.03709941651792296, 0.033289190126402725, 0.017981182919034076, 0.03812499374391572, 0.008034382537457972, 0.022881039147896153, 0.04866829795402385, 0.0030200303984700794, 0.007291702908508841, 0.007341907523016656, 0.05490868547630887, 0.024450757135186466, 0.03361934720869026, 0.05046627183835353, 0.020677957969206958, 0.01396852353918216, 0.06793804076169768, 0.04138901093674283, 0.017737488435100646, 0.02933060506268615, 0.06036187935199949, 0.019621019018813968, 0.01974617863344329, 0.07571098334606617, 0.028249168535694483, 0.05170621961775807, 0.04164741622404226, 0.0245350057394394, 0.012117637877142238, 0.020974288439197887, 0.08773992739377484, 0.002958243731559525, 0.0633352772603112, 0.05688042342362385, 0.04301853740828172, 0.07741251059116856, 0.02958688828643532, 0.07245436656258761, 0.054897389509865356, 0.028569648012278542, 0.06679149059158179, 0.0346881432849313, 0.022217285248541066, 0.06736260147825365, 0.06237254988762641, 0.018784795745065617, 0.025229090974936565, 0.04949042520996544, 0.055783910286282344, 0.08515602773836545, 0.03795528611648948, 0.055840424592456514, 0.05812238601426925, 0.04637837687867784, 0.027002266593157288, 0.08008592762053013, 0.016801742679109017, 0.03855614036682152, 0.030921850120648745, 0.01715931613298674, 0.021908117060159004, 0.01272342669131655, 0.02901029412544543, 0.016553560835159114, 0.08065115495194351, 0.04404749308202056, 0.027039056050501047, 0.07325151169131841, 0.003824353052843963, 0.0794874903775992, 0.016667510668236404, 0.07190646814002145, 0.018628494656314293, 0.02916641709875436, 0.03958671631652021, 0.04307690181679303, 0.03157723833987069, 0.011918967338128677, 0.055617098471209894, 0.028005175277470585, 0.026031447416772286, 0.03334598405466926, 0.053556053824121916, 0.01676460082132009, 0.011449340118786261, 0.0075810854398315, 0.0460785721999503, 0.030258475434816176, 0.0467519021983589, 0.10325021245667051, 0.03410924894494876, 0.044789522015039, 0.07649947934213185, 0.10536061614871987, 0.15469379032090788, 0.13194755200416813, 0.09019431222470538, 0.11504636536682807, 0.1322620923841192, 0.21289315284980884, 0.11468716972177068, 0.11118252431192707, 0.1682535312589138, 0.16891423612833026, 0.19364703236328018, 0.13096004934801211, 0.11892332184699275, 0.11705642686255517, 0.18462801712655252, 0.2340169854822659, 0.2077722534417145, 0.1016489967643734, 0.156307784359782, 0.15754737590830173, 0.09631940734482582, 0.2020154550911919, 0.1758658864925946, 0.15103997993132762, 0.16870685612722752, 0.07976019469600532, 0.07624504622071981, 0.14581904476208074, 0.15338908129882428, 0.10538493177943653, 0.11845661342264184, 0.10730932166259136, 0.16054250390058564, 0.18220311901982755, 0.19128311485532792, 0.08010614468085189, 0.11337623240486269, 0.21068245292671267, 0.22547679051997202, 0.20756285096849167, 0.1527316093204483, 0.12626127204707555, 0.1092289541397364, 0.15080509737374323, 0.13017025866335438, 0.1362743706352288, 0.13883526467027205, 0.09131456259638072, 0.11094466933319647, 0.21666558429358468, 0.09503457064349806, 0.18324003434709965, 0.18047324652152677, 0.19127605152466606, 0.0722513226191363, 0.08271920930353865, 0.11609186853973136, 0.15573608358540844, 0.12829004907079283, 0.11596639099861346, 0.1304913720776958, 0.10158726539943488, 0.16048098704026592, 0.2550367374093302, 0.0851017197654132, 0.09106265756511882, 0.1204718919771333, 0.17693675483667082, 0.1370675627502703, 0.08100114988103028, 0.12531889963053888, 0.16685952702837606, 0.09896909097029317, 0.1838125012093975, 0.1722469484253276, 0.23090934981742214, 0.13659051979982084, 0.17216902196166978, 0.12397352666143449, 0.13554796606542605, 0.21436341347232943, 0.17357140719409914, 0.07790620063221262, 0.13391875752037571, 0.13545894664862465, 0.1847268424687847, 0.12696811073129216, 0.10974255480593252, 0.18329969727464263, 0.0946403188150256, 0.14735083756667955, 0.12694194116779875, 0.11085555032496491, 0.25167866760203916, 0.09138418466693933, 0.18876633216296473, 0.1090100904806487, 0.1328785480150292, 0.12938091230969276, 0.12664369547799711, 0.07580456098601704, 0.149406282111041, 0.19668130744849482, 0.17156968073498818, 0.1552471049850987, 0.17438453291693043, 0.2226475665285703, 0.12624532975737127, 0.14740302347608153, 0.19532432058645835, 0.08403534835745251, 0.11200721030153575, 0.1222278114648596, 0.09957859052285072, 0.13535419178585853, 0.17437419072995264, 0.1464749539210912, 0.24902325363889818, 0.12969087148385663, 0.2509909657941711, 0.13843959557913965, 0.1458570886884005, 0.16438380664875432, 0.19653647086553036, 0.1419275785766302, 0.22218370029041845, 0.12064616165814862, 0.08404252660130301, 0.13518891597707428, 0.14857680807190557, 0.19285791583599585, 0.13439111201272858, 0.12448747206719653, 0.24309702728304172, 0.16197868893223424, 0.09187445029496186, 0.10009786023968652, 0.14310111802431846, 0.11047525661847285, 0.12116751513413845, 0.07802280687516736, 0.13570838487677037, 0.1358953103302948, 0.09175088797365466, 0.12110758407582199, 0.15235189017989945, 0.2596605070416005, 0.19066754788641008, 0.21074510359716034, 0.18845975909742618, 0.11021713861414503, 0.17765263335839396, 0.08985451392589078, 0.14074898294864163, 0.12174598812576264, 0.09821011234195003, 0.115568668791844, 0.24195967782889646, 0.12620294977340007, 0.06951380701315019, 0.23424949316728502, 0.11090876279218544, 0.10346103219255325, 0.08210831547095891, 0.1343352948465655, 0.17226489020451424, 0.12275910876210659, 0.12872062112775542, 0.16213020580189844, 0.16573342374495922, 0.13628740945170004, 0.1531969004821393, 0.21059891869944913, 0.19572169039278262], [0.008658674290223468, 0.022801886943559495, 0.02621310027015786, 0.03503701589520901, 0.04927125894614766, 0.0677515902826863, 0.04045418831669996, 0.03743259198663216, 0.0535971237977426, 0.019651359931055098, 0.06285487501431378, 0.05412647523166192, 0.02653933115183346, 0.07035271925551277, 0.012251557707185707, 0.033570355885932525, 0.02067853636558979, 0.038024161251321915, 0.02652463950066557, 0.10319291674081357, 0.031871559744280194, 0.06315636891691435, 0.0037143784978862612, 0.01622783365629373, 0.06213458382614678, 0.05956639663406438, 0.04172239324919159, 0.03111945483983765, 0.02011213308921264, 0.057148102205246694, 0.04664582200348378, 0.03714628577713044, 0.09933887395046412, 0.049056413418222825, 0.023040854665000114, 0.04304942224294909, 0.048816405732424996, 0.038497293322917917, 0.022153320737303268, 0.02585410189274098, 0.04714043901091622, 0.06315887402442676, 0.041038993025018324, 0.03764147352006647, 0.021833886970735846, 0.026272452932091492, 0.03491085270539888, 0.05295630274040084, 0.02696316929594163, 0.030135319140108845, 0.0866931984801927, 0.027757466492813923, 0.04787381498082992, 0.04838871799649731, 0.10148366732943444, 0.027697351573395635, 0.03802522994397629, 0.0499987360390444, 0.033185251147275975, 0.04026773017680934, 0.0372284448765699, 0.013879905360931111, 0.02977144844349354, 0.024992141895176425, 0.054459463008829666, 0.021960586422092972, 0.03286254810049169, 0.08404264151449166, 0.04386124178586949, 0.042240456377546635, 0.025967674427515557, 0.032121516996994615, 0.008455222404952492, 0.08555468457240252, 0.07436943315570393, 0.06972487189716871, 0.08330786360367652, 0.027523254262163278, 0.054523431350507086, 0.057699007522915645, 0.0204313944859971, 0.07194220614168914, 0.02795097072638812, 0.03792171231320789, 0.07511212475477688, 0.006536909993061977, 0.0443815533822823, 0.020918534475288564, 0.07036426420053167, 0.03567990922038594, 0.017510871966219237, 0.008389210523737055, 0.007955646414625189, 0.03442472395216746, 0.008792890021727692, 0.026672663009395043, 0.08590002934778891, 0.10329163483073635, 0.0467706062350302, 0.03918255514074718, 0.015837442910959645, 0.04847907423672657, 0.10403903020966439, 0.01475739204550102, 0.039203925163394986, 0.04145578699066274, 0.056253376627160664, 0.02346014799249749, 0.035531054506258625, 0.04623520653694869, 0.017079112472974004, 0.04653780360616023, 0.006214084372209806, 0.037803321085389585, 0.0340523784078898, 0.03441249718889594, 0.02980641652679732, 0.03069425880488369, 0.022986642453038407, 0.03193902910777158, 0.07769354994619086, 0.038540213398875735, 0.03740918417010577, 0.052268267684285684, 0.031932279873158664, 0.05778877004500359, 0.07579246445769265, 0.03819281933829188, 0.03462163536178489, 0.045259605056696364, 0.028328828273280978, 0.04886066263181068, 0.014931192497662721, 0.00887195604117287, 0.054590291674098665, 0.11447153895372346, 0.04236044106824745, 0.041015493277941024, 0.028988215471467668, 0.08578936794712659, 0.050548653103291034, 0.09127327811814125, 0.023260854049435547, 0.04773006624271793, 0.035652399003025026, 0.005609388669742452, 0.030317010297890634, 0.004992518393743423, 0.003956066789067981, 0.05596906990714132, 0.042542042210698135, 0.008716114605176113, 0.032153388169864495, 0.05358608447075371, 0.027406077283704956, 0.0551494439282725, 0.03728764049047905, 0.026392636805652615, 0.016996593312210134, 0.022599078572144913, 0.07526145827385687, 0.02562857326871205, 0.04526689055285627, 0.0342016774530132, 0.023162808201666323, 0.0349047354933235, 0.05571799225083763, 0.05166011261603525, 0.0623279674008729, 0.052767714876080715, 0.016875748687814322, 0.044296571248841864, 0.03743027840110083, 0.02194134612387467, 0.025294704490431377, 0.026730163653771725, 0.02556261884409093, 0.026198822306469086, 0.06387610086089661, 0.0596468665096308, 0.018012864485142693, 0.032185284240591916, 0.06709512954037036, 0.021284981142549265, 0.017967925767504403, 0.03605055787991132, 0.04284688391752782, 0.07875039888125274, 0.015262723750164433, 0.02385231989225553, 0.030682420831233747, 0.05118168687688247, 0.02905541287374593, 0.008572025915547725, 0.03587719218264665, 0.04845521442832486, 0.04835676446917558, 0.06884972369598766, 0.029302432179270737, 0.03918365830735814, 0.0333234763914539, 0.09067615854644007, 0.06847799485248905, 0.014789393453318027, 0.06849937636645571, 0.027735135029821147, 0.04368611791681859, 0.0068256150153766, 0.03325330273758981, 0.10366459707579306, 0.008349539618188096, 0.03693766088315076, 0.04951520815431591, 0.0806343469828848, 0.07563536280706044, 0.038390025691760164, 0.060293980979270516, 0.03504823142242047, 0.02507420714884516, 0.03200767058578711, 0.03035897467916291, 0.033342555811208104, 0.017936768971623916, 0.10578452324074124, 0.03765009583965425, 0.04889520170587686, 0.04896951989541131, 0.03181229326723805, 0.04347479639334544, 0.030235720708245234, 0.023436445232120254, 0.040755632423585465, 0.05702139892344994, 0.03341226215143839, 0.035947676102120074, 0.024092419508604274, 0.0032465005924384445, 0.02116101662508182, 0.06318135487456476, 0.029884708797438975, 0.07001049245797819, 0.031643374710373824, 0.05693208839323732, 0.01796611588478329, 0.10359243159332585, 0.05451882333164254, 0.014476505908063583, 0.04216600795306506, 0.0669976678346434, 0.04555167990826792, 0.04204269844077287, 0.0559193316486574, 0.024422404221108845, 0.026812305516232888, 0.07005991278997353, 0.048993969591514724, 0.03100530582390005, 0.05476975543124061, 0.024206819418337078, 0.027932789544725133, 0.02489873662500853, 0.07215840381480033, 0.015460828341723932, 0.012438448686753551, 0.02608018018485558, 0.04361156607046724, 0.022091530000550613, 0.045597909484058625, 0.06237655652747039, 0.03121493812350016, 0.09581957327862901, 0.019129596598025773, 0.04458072092083674, 0.029229293765139677, 0.07617103446635508, 0.0038552328600593277, 0.020343859364549, 0.11798331664214212, 0.07822276348428381, 0.10305419353948486, 0.03849708647917836, 0.0193165737624851, 0.07075554360785792, 0.03205367608085996, 0.0328072288914794, 0.03926019049099377, 0.012211746990590567, 0.0309374304338088, 0.03580866178738014, 0.020159331766227563, 0.05789663522474228, 0.041687746922816, 0.05123499893553315, 0.08213777921252674, 0.03546552334521567, 0.030367577846552578, 0.0354515690536749, 0.02514844872958718, 0.047239888714806694, 0.07349515063387733, 0.1076835249700854, 0.009034418392055219, 0.03220590732751354, 0.09146801000761409, 0.05611132094336133, 0.06821115876758291, 0.010273992703596671, 0.04867305919047325, 0.0435823513074748, 0.011974853452204937, 0.05956270025982972, 0.08193138746484634, 0.012337241768686762, 0.0330254337149522, 0.02579544062515901, 0.05285882571291539, 0.03928049565142682, 0.14796655775318224, 0.058668733108788736, 0.05717180113518431, 0.04487672963389947, 0.04222235371989589, 0.014916184835226066, 0.040276459748706514, 0.0313116624696, 0.061679860847371246, 0.03752082999375078, 0.042494548589832364, 0.08222050904746979, 0.06642588279059818, 0.04340093019568632, 0.015983827949141063, 0.06819762199396087, 0.021653691599626216, 0.03014663617397028, 0.021211453938796636, 0.038845453471426046, 0.014852737433337157, 0.008685204872651207, 0.022112013276426062, 0.023664411930968205, 0.012552923290058972, 0.038969762728459416, 0.02254460780550876, 0.04149302652466201, 0.02277551819720576, 0.024532075453129028, 0.10510727853303957, 0.018858012683208913, 0.02292741811083209, 0.0693625582742595, 0.0018985477025477938, 0.13211144885468867, 0.061249648851733056, 0.2017674724301023, 0.20321415286631356, 0.10091862385912288, 0.16620983850331078, 0.19885094505884957, 0.19252408536211138, 0.18581822664747316, 0.1349429251445878, 0.18582247077457367, 0.16508649313642135, 0.1611217736236511, 0.14430156247990747, 0.10796081815515796, 0.13719454948459903, 0.16650135028025798, 0.08540178874447461, 0.16034391858885366, 0.1627569423327523, 0.15797739638195885, 0.17830904813543444, 0.10368668339065007, 0.08045350426747915, 0.10660824395956532, 0.2303061475076022, 0.15180027623090053, 0.1743435778564984, 0.15945006252056168, 0.11261774407279108, 0.17927422698947693, 0.10833548877628581, 0.26641945564939135, 0.23153473803352928, 0.13881906957155274, 0.17642292434409743, 0.13688989163887116, 0.2275012391469171, 0.11744013732118953, 0.126928350768022, 0.10117626688893765, 0.0923259518740158, 0.1354742224418348, 0.10268080228519055, 0.07619963252856847, 0.1054914486444285, 0.20284659920200226, 0.1964174054803387, 0.17177581967365357, 0.2324984919640326, 0.1588292401884833, 0.1411413578616996, 0.1064274778529521, 0.09466487959387804, 0.22840621881186965, 0.13107572862457845, 0.27943351215893225, 0.20443866780448347, 0.11714633494134873, 0.14870754863706329, 0.1365838395131211, 0.22805812378083506, 0.1600366254006663, 0.1183149484436839, 0.09454586017396181, 0.09918662929727186, 0.1936013428794761, 0.2052519467448996, 0.1325515970107048, 0.1818748963095488, 0.12320095763331461, 0.1399322719343247, 0.12530835059982154, 0.20062400959432128, 0.17259037032002406, 0.1454562408429, 0.16117752950278022, 0.10769926041605012, 0.19103716998811693, 0.07706576387488073, 0.11430992504521725, 0.13996478470583118, 0.09176256315362069, 0.12338694845957142, 0.12509186947417836, 0.09277668736514547, 0.1324676950612376, 0.10089969382651391, 0.1264566474504048, 0.19589470368960213, 0.09997731630480099, 0.15578981699241748, 0.1160270345186995, 0.16076865305583324, 0.19980198192980983, 0.08811006277439096, 0.1466470019471261, 0.15087056724775225, 0.12978309314818154, 0.1024192062416865, 0.05865533040055345, 0.18376662786449158, 0.15799126257338833, 0.2087724425138966, 0.15567825926888376, 0.17540600391164904, 0.17437791391726465, 0.13592049930124514, 0.06638714938514656, 0.14760827375275476, 0.06413549440161836, 0.11756210617961423, 0.10413865994421706, 0.07743698710034932, 0.15568835630772576, 0.1448518894011936, 0.14051442214798543, 0.19723849851758252, 0.1419160412924905, 0.14985548542632213, 0.09333200151881865, 0.1568900877910276, 0.1269558916288999, 0.21359478213614036, 0.28954967255553893, 0.11688516790708227, 0.16932246906142082, 0.16665637583261536, 0.11007366566768578, 0.1235039760508845, 0.3194014836222895, 0.13049460496873627, 0.12235445345962241, 0.11570600537402977, 0.1823906879872084, 0.20778060380008914, 0.13411600983911945, 0.09171105906247132, 0.10471576163845678, 0.25187282492556884, 0.1784632922781091, 0.24257594959870463, 0.08113553702470758, 0.17248895560060779, 0.14598283436029189, 0.17903997262399043, 0.10393464306910193, 0.15612309588299644, 0.128295702799674, 0.1098343474610198, 0.127110717998397, 0.14282964710747043, 0.19728124622375737, 0.16031889815724668, 0.10155171125886903, 0.13669101521372795, 0.16378466460493304, 0.1373324759544865, 0.2014519054923327, 0.09861943311989309, 0.19901425968254768, 0.11478252468570588, 0.15006562334395226, 0.10792906381069653, 0.07991803945192406, 0.08172419898572468, 0.11434620696931116, 0.1743311059450911, 0.27706869066722933, 0.17919395629677082, 0.11589414124647457, 0.23543375784591322, 0.13052311876127798, 0.15162062861265677, 0.13596482514854402, 0.06984458079621678], [0.030278742290853016, 0.046354195313347925, 0.03721891474279185, 0.15800679883649274, 0.03655496549101607, 0.024256609387755878, 0.04408978113544084, 0.03566087193546757, 0.06792293350783087, 0.05427193234584505, 0.03718357893728441, 0.004435422128036378, 0.05746785198308288, 0.028034436005738475, 0.017548574983412703, 0.036118988683747674, 0.05787164160621263, 0.052509550906477444, 0.07658729600089212, 0.011759697658670767, 0.020034055323189786, 0.039784627470878825, 0.043557238945316885, 0.04597613092271551, 0.016002994511396657, 0.04051107800595703, 0.051721223449755105, 0.02498697463212715, 0.019932830210534797, 0.10278351935407809, 0.02643185284649653, 0.038166921736011584, 0.035350713578443375, 0.041413575546034885, 0.007556776991189128, 0.03890598590876307, 0.04289078458602871, 0.04532053969019363, 0.052204839434594884, 0.01892251920165314, 0.029213491286481583, 0.05844179871341875, 0.050511290995223876, 0.10238512298993527, 0.041524930256268675, 0.058422960611360694, 0.011656542962056496, 0.04997653098055913, 0.04642788531078447, 0.037415600156471614, 0.021970288925653985, 0.015251840513590124, 0.022030786889034416, 0.01591675024810097, 0.0636568196838902, 0.025657349446367834, 0.05180085828948406, 0.08818179158674133, 0.02835467224940658, 0.03407528443682579, 0.058090137543096665, 0.04436175000943965, 0.03749585169697962, 0.021362440292573264, 0.006041241051148504, 0.03879294963553548, 0.04962789202709833, 0.058184197818439816, 0.046045101818538485, 0.06238515969486006, 0.030920346673097343, 0.02503089062238653, 0.0336589424630567, 0.0808840686635625, 0.0282063078315508, 0.03763177101650546, 0.044230040343057726, 0.028503814246505502, 0.02946673122595155, 0.03947501303628087, 0.015077990265713345, 0.021995686655563694, 0.03333714723046268, 0.07034885051149516, 0.050807943222143, 0.04860539064412156, 0.0333123451339141, 0.04547535839881148, 0.030118978484683943, 0.03378708982059071, 0.04673670684438079, 0.016878221236589937, 0.06508683770774834, 0.023402139814870975, 0.1036921839019464, 0.06733260913601807, 0.04122938885683975, 0.03786394928371714, 0.01655742957917673, 0.03737973191985681, 0.06112329030950224, 0.14734504594197198, 0.028055758147891012, 0.039009335000188126, 0.04615001372932907, 0.05163239555493478, 0.04342378259846761, 0.012416381524094652, 0.030559122810260426, 0.040657515712683244, 0.02788044467207886, 0.01126999510527258, 0.020509757619771748, 0.034691046758164326, 0.02704059588722885, 0.015779056477420512, 0.027081171734138366, 0.04276805730055898, 0.04867250377672815, 0.046366100319691246, 0.07806734722708503, 0.043747826299119386, 0.03601466666065878, 0.03627210284673399, 0.018355552850651647, 0.029511683350128513, 0.05144660391153828, 0.04929764301425988, 0.03277435988908814, 0.06854536462455027, 0.04400436233188357, 0.05082576625770138, 0.03088493617401729, 0.08512825705111028, 0.07251316381077613, 0.03968922271122856, 0.021197601153905836, 0.06073592944190868, 0.0647775297083201, 0.08512468708138313, 0.011714780008450392, 0.16216938353834615, 0.030832208257408875, 0.018905847213200985, 0.038034725603797746, 0.036193820152191386, 0.04478195689678673, 0.03005024699133731, 0.13998180717950867, 0.02673803903763333, 0.033127327239321123, 0.04657645274194018, 0.03316188546558542, 0.012380237495827099, 0.01883598957060566, 0.03995345026675252, 0.039052515546040195, 0.025193431497281118, 0.01294423046807248, 0.03390702088513682, 0.022664205621807806, 0.03543220618138871, 0.023093846881942406, 0.06975468037830246, 0.045995463151484735, 0.011104147603374817, 0.07910032486242634, 0.06209187825480777, 0.01763701600383126, 0.014905728692669543, 0.043596776743089004, 0.015357537664503101, 0.05336242127082041, 0.03765436677983211, 0.016955481203753623, 0.01835824373448568, 0.021086344119882392, 0.03529745131550777, 0.052406289915163676, 0.19873477548601168, 0.09321825278382148, 0.033016979934707764, 0.04867885847606006, 0.006678434682168788, 0.05965742703166701, 0.049878904565928445, 0.050757572941121556, 0.05349505407315108, 0.04549385942218285, 0.10490325399704518, 0.0142301349044447, 0.024529442025889314, 0.07647044460980162, 0.049496714791823784, 0.018085476213825807, 0.05328254128295568, 0.02190026082849551, 0.06424009987723923, 0.03426163149396739, 0.07918093263381913, 0.0254410904862227, 0.020168411823350097, 0.06740850546667654, 0.008906474047821135, 0.02705270007643248, 0.05052016612382666, 0.04335140644182121, 0.03731887772559159, 0.006340541548260878, 0.021961362086116307, 0.02505356299450561, 0.04718741169199348, 0.033490495050265905, 0.05435900589931877, 0.024443257134407762, 0.027041494125320066, 0.026577198877930645, 0.016688129924718412, 0.04098414112963984, 0.028138271562995452, 0.027997359265423113, 0.05400739452471176, 0.05253483563841832, 0.034637711716875914, 0.04803967684687627, 0.06143499233369386, 0.023271713345762224, 0.03458612335605487, 0.04245991375477564, 0.0017281521521058055, 0.03759823551762008, 0.006742317796564631, 0.0026146951929530912, 0.042402334586386724, 0.028386568320133997, 0.06406939633551144, 0.07424035500134192, 0.05683889379724861, 0.04706001893106488, 0.02689528816019095, 0.04249841733384998, 0.020768438698723916, 0.0404071964834246, 0.10409649446486466, 0.04163551887857818, 0.06562975655880667, 0.06113919046437068, 0.05419710087740133, 0.01899072592477164, 0.04568981322189493, 0.10617863717338732, 0.06027696233603263, 0.02814444048600572, 0.018685531817496787, 0.02179628162975273, 0.06667234093671845, 0.04423048084361419, 0.027686176265800194, 0.07350755359737143, 0.10702072868063565, 0.036756596002247066, 0.018451122319205635, 0.03486440862498937, 0.021892383529414094, 0.05907361440721059, 0.03052319137139186, 0.10169254886286874, 0.04939412795788339, 0.05553639493882657, 0.027199718094761335, 0.03876592971444611, 0.06609174588154401, 0.05576026115205981, 0.04953090912632404, 0.04144745578448619, 0.023263219345901764, 0.03230390146434788, 0.04801588215594811, 0.019569363625299548, 0.06149086695645125, 0.053889244614589604, 0.008359486312274973, 0.0419737620189065, 0.06830750198494043, 0.07747258720619064, 0.03172230091877282, 0.05617076553584588, 0.02849681794853701, 0.05427596962920601, 0.0510710331370994, 0.02830584180511294, 0.03551531522985428, 0.023465763416982467, 0.03864399916041763, 0.03257821073695537, 0.026517685337532914, 0.009276652520882988, 0.01590776212152935, 0.029468608141366034, 0.04078863549136347, 0.04566239493508493, 0.15638937272371786, 0.05174817442293129, 0.0630859501149145, 0.025949334282608285, 0.031492089582306725, 0.07604512025512035, 0.010378400911577048, 0.03701282559984154, 0.028399157059949734, 0.023669793698636275, 0.038130888790493055, 0.03502334505620022, 0.07446172376794201, 0.09444531879477924, 0.03203075856060511, 0.04380336767362972, 0.1047498065858118, 0.0275808698197286, 0.012513441033661367, 0.023332839501240564, 0.03368285589761311, 0.07665452787712698, 0.057935878078663544, 0.11180627309987623, 0.01471337550620158, 0.054796319530015035, 0.009547958728827296, 0.047514546557419726, 0.028718380152337977, 0.005400193040259183, 0.006695725765424751, 0.024560198540829366, 0.017039126513766188, 0.03147672568898528, 0.0295876007482049, 0.013507232314065821, 0.06153105592895901, 0.018415165982479532, 0.027890219953992677, 0.04692645916234582, 0.04015775059439963, 0.05423678423187906, 0.0561026526584981, 0.010504836062600297, 0.06372471805661917, 0.026757853901794842, 0.015369771131043954, 0.02977293656928645, 0.019727591425180435, 0.027575442086785074, 0.04807985049762553, 0.13874975393616384, 0.17732526866659043, 0.1549020283404858, 0.26401783129380596, 0.16602047689018712, 0.1392962350960701, 0.17405614166730837, 0.07108876121140296, 0.13810876816991838, 0.16556794875331465, 0.1414227725998048, 0.12442672895568034, 0.11008453645533132, 0.2720433990320852, 0.09457189184162887, 0.11480196799722411, 0.17815946180733944, 0.19194519868300808, 0.14321878912948793, 0.08168132870548195, 0.18426901300347623, 0.08536310130429846, 0.12114458612256473, 0.24900325874407447, 0.24481471898334645, 0.14966525047296478, 0.2044415176515618, 0.10547102474036718, 0.10000958392817168, 0.2802304274612858, 0.08209864744135449, 0.14364857977676776, 0.17904156608687294, 0.15298582793724153, 0.06459394439814553, 0.13100385425552247, 0.10225159386473318, 0.18828985611757926, 0.17381923663760387, 0.1516197399506646, 0.11763066338795809, 0.14518129188687573, 0.10997847924309392, 0.16804555370923013, 0.16068144160653317, 0.11881946330709804, 0.09115215195643325, 0.17117077875281536, 0.11871073244800491, 0.14481065854910882, 0.06018987729124004, 0.11724492279632438, 0.14949786026150952, 0.08919006288652459, 0.14230256329380697, 0.19699848317090543, 0.1505002863104305, 0.14015676633965585, 0.062653535616494, 0.16367989442040845, 0.23738352822199946, 0.19683173647330654, 0.1464199028428524, 0.10275105254784708, 0.14472165445406593, 0.09518323766608393, 0.1407160105243806, 0.17522370562918727, 0.09827741316609806, 0.11295376555813898, 0.09173457796174674, 0.09661452739589638, 0.14680110819397435, 0.1579379581756169, 0.25526775888377623, 0.17539276591231748, 0.13375401797313846, 0.11087504726263786, 0.1859576852932092, 0.09365318388107324, 0.11856565837778392, 0.11577780313429334, 0.16961695325951423, 0.22103757146866093, 0.19171014758608035, 0.11685136044698378, 0.17871990108922606, 0.19581406527469236, 0.11675995083585863, 0.08063351960792657, 0.15446174228864332, 0.12980797568396216, 0.2618417125796118, 0.14104643956788127, 0.23002081039932468, 0.23919120460989016, 0.2098308389465655, 0.11750772159786955, 0.1462513481777522, 0.09319480283245926, 0.16990834246239356, 0.2095166662888181, 0.09202504019823768, 0.12775492899480367, 0.15790493978608042, 0.15106880015903904, 0.1501630850496792, 0.16729661083269506, 0.17665489576756957, 0.17989013103708146, 0.13034655081648983, 0.10522711000615552, 0.15828183972306792, 0.16192065011109077, 0.12316006385991651, 0.10281361894862306, 0.11459807369617686, 0.098955707414256, 0.1457499742748276, 0.1429905562150863, 0.10569238584608802, 0.13080745995525392, 0.10716464595809098, 0.21029004737013773, 0.12331317419246321, 0.20529590486999483, 0.15113246206554676, 0.14787592955173987, 0.0969078318185864, 0.13691175578823014, 0.15192185438448383, 0.1977115578108257, 0.06554168709103139, 0.1125743298701221, 0.09715476493921973, 0.11601295382265123, 0.1729543233710912, 0.26516285694895253, 0.26538033398889727, 0.12499063861586394, 0.1216836821948809, 0.3002892753049251, 0.1383913167181515, 0.11767407759062706, 0.1351769343619385, 0.1568040254736139, 0.18449909985065463, 0.13298719460445066, 0.2827776085224844, 0.1435746676138332, 0.11652801771678271, 0.11258409749115668, 0.10255504895241992, 0.23291464624626024, 0.09915093726087963, 0.06674685830911321, 0.0694512942385289, 0.12821163997174273, 0.17644849635900992, 0.12489316924925774, 0.16315550723623845, 0.1137426445981668, 0.08827698567221243, 0.19385022952431635, 0.11141042014764202, 0.14468924893486887, 0.18979278272919117, 0.1985725027418906, 0.11637155191912768, 0.13494159215159957, 0.08497205172334948, 0.09634388385400658, 0.12004577855189001, 0.15204131813539615, 0.18641416644377096, 0.1591355221406106], [0.08280120369407439, 0.03481942394207563, 0.01840740742702638, 0.056893852944936485, 0.06633655693862708, 0.020130310440436006, 0.059611718395664814, 0.04941260982905665, 0.028589014715004354, 0.022777575143282453, 0.027742364984606544, 0.05116266108328297, 0.03917374129917833, 0.04404677295937173, 0.049481362389821204, 0.009159855713557092, 0.0264950608459091, 0.06863984624825178, 0.06696130164087781, 0.04240872375967522, 0.046515506617124044, 0.03924044457474544, 0.06176782306283713, 0.026072132431211013, 0.03848975884818262, 0.027830043747540445, 0.013172210573459105, 0.06860421549889349, 0.0579623042816116, 0.0253195506370356, 0.02306154478461512, 0.055985226701464386, 0.05205011265652795, 0.008908663144064768, 0.017120270546705976, 0.08693573425614065, 0.05850354540011576, 0.05000149778601143, 0.07430403222960812, 0.01704574934387159, 0.020432671937610836, 0.026351434681865, 0.006359216377830074, 0.0524069564116578, 0.09486757113688415, 0.04636656380288544, 0.037068983675130916, 0.01619685497585564, 0.025658822250402263, 0.049388631277026675, 0.026658319928232702, 0.012820319576759734, 0.09530860029401318, 0.018405430920181737, 0.02402996610579712, 0.08477466150877938, 0.015702619097165523, 0.06061342815237661, 0.01842010341915152, 0.021936257384837638, 0.06063965134202473, 0.010016096864766892, 0.0458898464398038, 0.020042472714257818, 0.013046792404155337, 0.05529693883633422, 0.07290078897870357, 0.03945440527111773, 0.028535920991412098, 0.05830493327530642, 0.03946346426082235, 0.049430371577581095, 0.06338316924689759, 0.02328510839311827, 0.04805206065817226, 0.14042492775667098, 0.04699422346968805, 0.010979984860656964, 0.057245207680088867, 0.0690789755073286, 0.008779227801208055, 0.06833856685027, 0.028522610213727723, 0.023379409986157573, 0.04744764409899231, 0.05161545352048932, 0.0363988712460043, 0.10318575381872155, 0.04915669432751114, 0.03168825980185742, 0.04354918353079308, 0.03787236092912574, 0.035174210751128775, 0.010950597727881565, 0.09204237676796415, 0.005035241202060735, 0.053218201388634985, 0.10647936498806362, 0.018626037429297165, 0.06860084471202667, 0.028609769952092922, 0.05045457750618939, 0.058068104854394356, 0.04626159443550053, 0.047902838221841285, 0.09044142154556128, 0.03398711537762034, 0.08687336703822499, 0.08440556034686104, 0.041638361064777266, 0.014598538926351937, 0.04516885045074648, 0.030299826945749023, 0.0625463484245683, 0.03662051963469675, 0.029419201215909376, 0.04792003306530176, 0.03274211524835518, 0.02652515661001446, 0.01996668172068894, 0.04496227101152463, 0.025407315584860986, 0.017034258025007385, 0.04890013531210923, 0.013984181418744548, 0.01962440895787891, 0.054485789620347565, 0.03432970606691895, 0.08794713885553422, 0.0301577540249714, 0.06615498643969336, 0.08030133622307932, 0.03921666903601539, 0.05845081173784791, 0.054662093264801856, 0.09839710674338764, 0.03355031885627297, 0.03648160108094735, 0.08926738414072222, 0.030243643972602104, 0.02103659628529943, 0.09357832176911254, 0.014249078343592346, 0.023261689085273013, 0.030544392854696324, 0.07658271479510492, 0.02923855959858385, 0.04871795577327571, 0.004474723874966825, 0.04189136926265013, 0.0540325298695074, 0.0964174282947375, 0.0016399182148292783, 0.025400880446297028, 0.037161515605065136, 0.021158750920045762, 0.07219345233733616, 0.030960884215610645, 0.0188093833369954, 0.04419606051317627, 0.041807708630879084, 0.046056049214976455, 0.010345173763081191, 0.02802329708731944, 0.04191160547517, 0.04913755362072299, 0.10127433380412479, 0.0439888337296584, 0.04420665933960869, 0.029364981343068426, 0.04391438913561645, 0.02168246586206219, 0.040123525616382404, 0.05531476570233222, 0.07507818705973125, 0.05459620587287411, 0.05970628428903799, 0.03078425498378854, 0.04949621300423338, 0.03446126251571602, 0.0689747262625925, 0.031283918595422185, 0.0008046693091596207, 0.017946921551840442, 0.02665754234898956, 0.09843184883075376, 0.02678639450741391, 0.038670697324578805, 0.01821489144687451, 0.06051685893908144, 0.05877699282380843, 0.018495268135842298, 0.026489420523566586, 0.044118635837108865, 0.03836083391140546, 0.06165299414386673, 0.03712211187267977, 0.021826295039406227, 0.054629216601531354, 0.031976785751119736, 0.07820024049930996, 0.0734858733091143, 0.02602779700781309, 0.05813828233869807, 0.0851800752383086, 0.032857484259312196, 0.03798594495521919, 0.06876107200138992, 0.040112233480378505, 0.05987934355113295, 0.024267978132552197, 0.02937649372935055, 0.022657322321808147, 0.03082894472285144, 0.10139448703416895, 0.05116490955134073, 0.00889487739186734, 0.04100759874188131, 0.06123089118890705, 0.00646367486033048, 0.043941026012743675, 0.018248197119382602, 0.033712587769954436, 0.06554236124840475, 0.04550325549057415, 0.01943060978045387, 0.02016915492863665, 0.0583751758770837, 0.012279554390378538, 0.07775335076956019, 0.02216783427302876, 0.05930492316462821, 0.022857443639828313, 0.02274022835697378, 0.0327765892049478, 0.0575429171083435, 0.03929517006561641, 0.012305499873154107, 0.025898234302838965, 0.04452714073141256, 0.015466605602282912, 0.04866883038513122, 0.034087492047899196, 0.02610679024890546, 0.037000821002068064, 0.045707617105255206, 0.02574428318879537, 0.05733988082577145, 0.08955967732735219, 0.033037250621184226, 0.03655025405028174, 0.051188007102257786, 0.039790959187573006, 0.016870545035588647, 0.07934109863614844, 0.03663022213825776, 0.01577793511622135, 0.020939433353862936, 0.03605042764496419, 0.016681417079281904, 0.023362810776058226, 0.038600910545116475, 0.01864402325853946, 0.07303120778693308, 0.0468007096600148, 0.051379349052665696, 0.03770518522228926, 0.06971621510362433, 0.04902564732718372, 0.048817010941885175, 0.014416000283803913, 0.020920610573563366, 0.020100557500676765, 0.07664501306510742, 0.018735430954444795, 0.03897086589507038, 0.02761216834187508, 0.04267935964068578, 0.057291540677749345, 0.10503712020093396, 0.02482632790962535, 0.028317624237388376, 0.07275417507175477, 0.07085982349611099, 0.041225815056672985, 0.030817493623603257, 0.0330444403563536, 0.026992213604370915, 0.00175217020554438, 0.04288297048920105, 0.008430215379884167, 0.017644479615433563, 0.026088327529930302, 0.006263814491009521, 0.03695923774953812, 0.03800149270964246, 0.017817490997033256, 0.009125380799354566, 0.02317015498486017, 0.07907634631039635, 0.018552939234782132, 0.03006493672728539, 0.020422230159202893, 0.029834097198721383, 0.061036078860202146, 0.1127257931136316, 0.12227481861989345, 0.023233420440867063, 0.04365559697391526, 0.06672117904189133, 0.04140483448281884, 0.08731752183408507, 0.0602328586542318, 0.05733266810796434, 0.07688070001501231, 0.02053584674403312, 0.006308179600314508, 0.07260073532140063, 0.013810719002879435, 0.040593141344405954, 0.07560579181318322, 0.062041668852250424, 0.06887186363699936, 0.03324189568839727, 0.024920723348435377, 0.031119167556866046, 0.04395236028358341, 0.05184867749771765, 0.030897329561412338, 0.03223266677870866, 0.0658001421740459, 0.029168295929388657, 0.112157340552057, 0.051138885544552926, 0.04304282622592103, 0.029969725404836, 0.029430608265101913, 0.02448086056017107, 0.07805420881918362, 0.06220552739837478, 0.0829018599864456, 0.031927482247532855, 0.01892298651528695, 0.04298353102058173, 0.05009103048172209, 0.022433331619287213, 0.011185987818715794, 0.035085390517187696, 0.043073657434433706, 0.0889503846185342, 0.007556637180142946, 0.048086281805749864, 0.16738080389557347, 0.10930802973528063, 0.16125308109387276, 0.09615169537644233, 0.19536391201038517, 0.10794769506901504, 0.12374750008025479, 0.1494420890606219, 0.12393385862871525, 0.10366521760701172, 0.13682909490120027, 0.16104666636355464, 0.13457644400337052, 0.3158044556696569, 0.09092094662088542, 0.06101130740717054, 0.11799138354798479, 0.1227714044732913, 0.23003115258630247, 0.3214750997722149, 0.16209009343818312, 0.06303038575776643, 0.15772083353611732, 0.13450158189140982, 0.2290462393073305, 0.08665589765915949, 0.17917690317957632, 0.11832866907840776, 0.08294022566969357, 0.1458232276021473, 0.07586423923531849, 0.13463701091466412, 0.15346257977427977, 0.10863460014544188, 0.07908958430972793, 0.18685434524330402, 0.17020785219727025, 0.15302639995371142, 0.13862624524101136, 0.10808918384775039, 0.07119265039481464, 0.11595557383712261, 0.12299118743788813, 0.19472767598927024, 0.1582931471808303, 0.11500340315603441, 0.209823944155247, 0.1993533608413512, 0.164945793428248, 0.19424150127076334, 0.1025320663146915, 0.25113676764792014, 0.2282680778373634, 0.15198960720050722, 0.10335277630797318, 0.1709554467590586, 0.12330511494749978, 0.15246251327616556, 0.07777442584835714, 0.15878977133862435, 0.1683429643631943, 0.12912755171137472, 0.12409407825719927, 0.11885168496519329, 0.07718589412228716, 0.13254280232133406, 0.1120569906948555, 0.13321663793777266, 0.06490053278544257, 0.14295183813139317, 0.1372505045465885, 0.14162051521482008, 0.16753563026507057, 0.14109372251456784, 0.22461373118623612, 0.20704754958710364, 0.11715345955904453, 0.12269440497602187, 0.12968621366927702, 0.10286837891345063, 0.09376571453627079, 0.11392408486215339, 0.10350209450529468, 0.07960235760096582, 0.15675894886014924, 0.14009129646564686, 0.14114923324556122, 0.17343167275671037, 0.11132111727830865, 0.17448312843278532, 0.15724325432412087, 0.11126247324770498, 0.13759538200834107, 0.09045557118952276, 0.1657383420294331, 0.11327279521332634, 0.11576459577847874, 0.23079587687407774, 0.08074216619734803, 0.1417380331024047, 0.10857099952596812, 0.16576040536165237, 0.12197879458507224, 0.28551162310665656, 0.07705562087076326, 0.173644507303834, 0.14440441744462137, 0.22177442547775086, 0.1955170836299658, 0.12486916771459004, 0.12215559235623769, 0.07399787285154866, 0.15974416367469296, 0.17557163212087848, 0.10528105791778335, 0.17806958437206286, 0.1758093645255412, 0.11141051973907218, 0.21647602349760073, 0.12232102904348605, 0.21365963913980993, 0.14330710374539898, 0.11066474846654362, 0.23582916646715135, 0.16641516538877643, 0.1321261424210764, 0.12446714009368613, 0.13299920686310338, 0.17933810340060344, 0.24153557155401478, 0.2459050306389409, 0.17116337834346682, 0.1245748750384777, 0.15862253434475393, 0.10240011533061344, 0.19339672079490078, 0.14269518335500073, 0.13295206181224317, 0.2193118052016343, 0.20882942413370456, 0.13698275681705246, 0.17516332257899547, 0.09224073225331884, 0.09827825586281477, 0.1499191932981053, 0.1662864626174973, 0.12622190278864678, 0.15062287570007388, 0.1578151849248717, 0.11642321688874115, 0.1799801463681844, 0.11032707223127927, 0.10267347848463444, 0.17942744457433302, 0.16506325002879868, 0.14605726746301498, 0.20244478608571714, 0.20653557302730702, 0.14582108255595932, 0.15465465854973565, 0.06862493817724528, 0.0976406715269531, 0.21057543044369068, 0.22131291879040582, 0.10846616039353033, 0.2573977897484457, 0.1502961851656437, 0.16399399046936344, 0.21227545615646148, 0.24425285477792066, 0.1620159054835958, 0.09106990475688251, 0.0679041107275313, 0.2612206910646731, 0.14186296672109636, 0.12326415988706774], [0.03724465529704767, 0.03527154222190861, 0.046529786496032635, 0.03521788925413163, 0.05623912739176905, 0.031608904584220825, 0.022027881500581582, 0.0730820223989506, 0.018742268289168997, 0.028929764878064878, 0.032492458685151035, 0.01053659902555087, 0.020560225577003533, 0.015764175219491364, 0.057864831084565777, 0.008126061236966521, 0.052688846124276045, 0.04065865718369042, 0.0361349041603746, 0.0357740959002366, 0.05715055368660439, 0.012130274497453245, 0.14474066875634656, 0.060505336976700255, 0.04821041103212103, 0.06458265992302088, 0.02442970503902724, 0.04436018719007412, 0.06657084194763054, 0.054090415473066034, 0.07660049569582747, 0.04986456723042554, 0.035225396915789575, 0.053737379174919865, 0.024947316175506964, 0.019533876517427065, 0.05126222186992246, 0.023968667580535816, 0.0669172209417147, 0.05958231594113093, 0.036131449103836095, 0.04343467253831126, 0.05255956495661409, 0.05524273045481213, 0.026070255515796524, 0.010973375437090234, 0.03994857411711447, 0.008093269800977602, 0.04952633941185571, 0.025273005049976132, 0.01241128225134866, 0.027771890013208313, 0.033752861012133865, 0.051402638125563824, 0.027786533783880935, 0.09282031607243324, 0.05542092633643939, 0.04158620962933187, 0.04797440232528795, 0.03659320860019615, 0.051528383797455224, 0.003537907989905967, 0.02837128103560498, 0.06576455738996306, 0.020286239976544055, 0.05197142393538549, 0.06107645935469097, 0.034220791346724, 0.027932622920601603, 0.004805806008422928, 0.06600225149022956, 0.02043077012433881, 0.06565800988145414, 0.046320487444679585, 0.04581349045639077, 0.052141595046005906, 0.016396629639090072, 0.07434230598230517, 0.03060494635945126, 0.029548700718629747, 0.0525461430961807, 0.02167609967141142, 0.03674632276318247, 0.04668759677799479, 0.020825087070284833, 0.03254320817969499, 0.03152156864563304, 0.01814196945258206, 0.0367692019790411, 0.01545618201846317, 0.025945561299581203, 0.02793557235911008, 0.0707139450335695, 0.03505309608073966, 0.02195839732584934, 0.02816924066733449, 0.03933948825203604, 0.063471510675886, 0.02085066483085675, 0.04596566616166984, 0.07280022461688326, 0.07732814132806755, 0.06792496364083021, 0.07365636617666291, 0.07232699678429673, 0.016387304433831767, 0.04255437622627905, 0.03876558880531981, 0.02941781459676643, 0.07648929803361816, 0.033614298689269254, 0.03322968807732386, 0.027916627004742626, 0.07912060320978204, 0.04767759305034434, 0.04922647727653385, 0.10410749548745733, 0.031434552548753644, 0.05008386755963007, 0.02824244036849949, 0.046444302575001796, 0.07220536500455872, 0.02696802629338157, 0.025624306158973806, 0.011944208020013908, 0.03567533567547798, 0.04605639395454238, 0.12265659087607939, 0.0902713270437333, 0.027580251203729745, 0.06139234038850954, 0.04816948278476635, 0.04214200258795773, 0.05556631833314896, 0.054792297568412564, 0.01809088479457123, 0.04203422167789071, 0.014652797103589101, 0.019139165036200036, 0.029481530129428835, 0.015679011140168918, 0.05365281072895854, 0.015132928345983308, 0.0174508911121877, 0.02084397496805797, 0.011330968043166063, 0.06424119921341058, 0.029691085820236517, 0.03163280078179894, 0.014799334401745471, 0.08572972800222137, 0.04757954145691568, 0.00821116785969465, 0.07860252859010812, 0.009382420534928961, 0.06879566853205044, 0.015010038266829668, 0.07173717803051395, 0.05935913920702954, 0.06888195301496214, 0.058457871238070155, 0.03027580625888321, 0.07611279646235128, 0.022494689516362645, 0.013577394476611049, 0.05308927645185783, 0.024606610062502088, 0.04760089998824462, 0.0414246033817049, 0.015893141333494457, 0.07170797475884039, 0.0785397400238341, 0.028236936026763533, 0.048997030112772226, 0.013179911672317935, 0.03283727102943006, 0.03910138429473004, 0.01693088978138422, 0.06135013277432131, 0.014982195758831598, 0.009707037843914043, 0.018707221681852976, 0.03230488205689096, 0.017337826110662955, 0.045579347173653306, 0.0010689831692762973, 0.008244802950010186, 0.059128351389400424, 0.010061658028843663, 0.04365044120218485, 0.06061894398543143, 0.03439271679869102, 0.032504183660832145, 0.019202204496269266, 0.010622016871498238, 0.008002918348797869, 0.047643885181676, 0.06825497133597251, 0.045170907396823175, 0.023063697491682345, 0.07007689695925483, 0.0729866674350154, 0.04200823980593874, 0.02814015422406937, 0.020038046641275287, 0.09317519098159768, 0.05339659645312256, 0.054722510788950234, 0.024276136968945785, 0.06450271098724296, 0.016710921040465756, 0.05990621791551671, 0.02590242480378478, 0.07277295188677889, 0.06655638586849937, 0.035483288924179734, 0.01537760916811925, 0.036202024953860434, 0.06760881447623815, 0.0431415060114476, 0.023257264927510294, 0.03933109192838592, 0.04914028855461267, 0.0846092401432895, 0.015260554763728814, 0.03920874002599909, 0.1041335654595206, 0.009601368463688321, 0.06208076231902646, 0.022411090171625538, 0.10437459970313696, 0.0012016014877571574, 0.032520325133396734, 0.06207635348302223, 0.0693376987211166, 0.06550905940633628, 0.03682046858293395, 0.013823340301431957, 0.02903471317803187, 0.04134500301593254, 0.010432181241471442, 0.023991996873049967, 0.030558575057394566, 0.04856410233544246, 0.0653579715459097, 0.020750991046248425, 0.06409308760456982, 0.018725521607144226, 0.04912672113747366, 0.05479942601654799, 0.03394119606743898, 0.02669810861980002, 0.023052495371009556, 0.03404965496531898, 0.05210718237644723, 0.026455346847914403, 0.03516539690955993, 0.08124024592219822, 0.03401890419603836, 0.04273620719510702, 0.056364091653977676, 0.0035083425022856968, 0.06903959858802057, 0.048419863301058935, 0.04342566334432171, 0.06119316518907586, 0.018857616232708097, 0.07044775246251976, 0.057029354746543595, 0.013128054223113484, 0.07946643062056073, 0.029028942620742227, 0.06722787725588969, 0.013445359222861308, 0.03912891749472868, 0.043798817111359495, 0.026066484447989254, 0.020412240372670275, 0.023074815342683467, 0.1354019190635412, 0.027379993905103015, 0.09018991488002001, 0.012834097668077919, 0.027605746609849796, 0.03534496408857165, 0.02595535956413275, 0.10066138685590799, 0.019390909188997843, 0.01407559773313903, 0.06855314807786096, 0.008523958686348653, 0.02370623841641411, 0.039391980596607735, 0.07776619040317113, 0.02004785831236551, 0.049588568733945015, 0.04143859214720227, 0.01343490020747507, 0.04234043085166524, 0.045917693735851396, 0.03350103258966439, 0.024854447166886062, 0.03406683448702097, 0.02323488749924206, 0.04029317961765393, 0.0186055330860038, 0.06915750718044658, 0.023637449466473153, 0.009351291509735729, 0.018973559809608326, 0.14140270109618866, 0.025003997105804664, 0.057859717447671204, 0.06217458127667347, 0.04372463298721179, 0.017899981429499966, 0.013196037823124038, 0.05640104007456572, 0.022271441919128263, 0.028407178000516953, 0.027757093024950837, 0.03510302586120463, 0.05209734963793909, 0.06241394161817528, 0.03933805949805726, 0.02468594229750095, 0.041646642475238735, 0.03929370683768103, 0.05412618028781107, 0.00883276298296668, 0.08496062169151922, 0.031470596985591036, 0.07594596549508072, 0.0795714459532211, 0.02126966129928347, 0.02000901765460449, 0.03721727531463389, 0.04497012724318812, 0.01498973789444614, 0.03510811651546148, 0.07936422683058247, 0.028513706356827772, 0.01867912157679037, 0.013881570644556515, 0.030395400244742635, 0.03292879172330422, 0.05915783045272674, 0.06405755644664168, 0.1147748714673423, 0.010034348909562875, 0.019004071176412608, 0.019778940383525147, 0.16801812776154088, 0.10314448466224056, 0.17498202021083525, 0.14012117389469378, 0.1430464653118003, 0.07755958415087193, 0.07502780145695133, 0.14616954530919754, 0.1315078481791481, 0.1986063485063853, 0.13646756268797383, 0.09724127158762948, 0.10964615030154105, 0.13032445684075356, 0.14905785000131977, 0.12465717586418315, 0.1067715356006257, 0.10709016689009244, 0.1278514177688668, 0.12336853936675096, 0.12572105748638993, 0.07945950518572524, 0.2984359860420227, 0.1751827658905137, 0.24083768077675374, 0.18179169916097196, 0.13234222518099895, 0.12292764044456905, 0.11903391429974187, 0.17144401167188922, 0.23298946239294546, 0.11433902106458142, 0.10226309284447663, 0.11220918172189306, 0.18300645413898653, 0.17505413972802703, 0.13261490651676733, 0.18712592341246145, 0.1490031053582507, 0.1356654379877352, 0.14887506142258644, 0.17905894096099562, 0.17092700957530932, 0.1539614562305712, 0.16177743763452576, 0.1348393347354666, 0.13481717947269642, 0.17195650917147437, 0.20429369332569264, 0.15967336182873096, 0.13993113812419677, 0.11548620708767446, 0.16500099772407165, 0.18070298096826, 0.18348345112416053, 0.1329718422024481, 0.1627089239416584, 0.13175835893038781, 0.284319774157578, 0.15262104751121613, 0.13867170489843816, 0.10884641579562619, 0.13145601467019127, 0.22634512053862696, 0.15816842806675743, 0.11541267030782278, 0.14536705288675525, 0.11066706205207495, 0.16221818333912283, 0.08718792273993455, 0.1502166652391034, 0.10047393280171579, 0.1342880118998789, 0.18098595852573074, 0.0690158345406094, 0.131818312971342, 0.06884618436977749, 0.12875826668835458, 0.18829900320739518, 0.08957099244599381, 0.14660371797940425, 0.16061047122122782, 0.15751156895872087, 0.1689110951678407, 0.11142916631914916, 0.09631304881505429, 0.21014275930581555, 0.06364240190915524, 0.14748068946984508, 0.13767537690939444, 0.10524538886402884, 0.18239434988748643, 0.20350353491883125, 0.11082609424427634, 0.20614840751213415, 0.1279324009233425, 0.19211134783202605, 0.17612638703036695, 0.08341477883438911, 0.2323318525187431, 0.19300410073370705, 0.16274496071761654, 0.13325848166019688, 0.1794533536679322, 0.15934458753514677, 0.20131298310814366, 0.11560932507798558, 0.12771120835696498, 0.13185634157590329, 0.20055227312109164, 0.16090964387741782, 0.19525549524734098, 0.09855011748450418, 0.1752399620149405, 0.06879066597790488, 0.08479534588273495, 0.17249839380383494, 0.1429047543675669, 0.1369801521181099, 0.17447087102599684, 0.22883303703800326, 0.13042283785198966, 0.10539069276062712, 0.17382052366531667, 0.0948098770553066, 0.0794213769897338, 0.17066770413469884, 0.2180915497123234, 0.14918497463147487, 0.11694344421548229, 0.16606601315640634, 0.11954271159465275, 0.1994231820947701, 0.13459345115528953, 0.1896704231659251, 0.102813427426642, 0.19548553612924394, 0.1176294299864, 0.12089289559592163, 0.10935409460216762, 0.15664679358803457, 0.12162745134123873, 0.10904374472316235, 0.22626685699628246, 0.10984007013781417, 0.16872484387168962, 0.14675330430749925, 0.13148681140474736, 0.14121363059647624, 0.12637027103694218, 0.25094244178504715, 0.11790591877915206, 0.1829388085752726, 0.1550830089517178, 0.10727044270043412, 0.23172665838032003, 0.1329979045136321, 0.17504505392524505, 0.12875388466542767, 0.13522708247746193, 0.1548841478483331, 0.13235049893058118, 0.1557179119798445, 0.151913718530728, 0.1443405257117364, 0.1804527919739485, 0.07635279648726986, 0.1355377924177916, 0.1476666956178604, 0.14730684879806735, 0.21067264700128188, 0.21106843866648214, 0.1723211517016734, 0.13357767985472757, 0.14672515823716117, 0.08278073382473762], [0.021713264511838075, 0.06031288036836251, 0.0627024311782612, 0.09136054319359603, 0.03266485528119149, 0.045863086988608685, 0.01788267550329047, 0.014246497584897426, 0.02180466646208398, 0.03558761477770825, 0.05021011501911187, 0.029766687207044135, 0.049909325917401624, 0.06454542804990085, 0.04530350189475764, 0.0421927176085451, 0.026725841002658974, 0.05774824399380915, 0.023765859209121238, 0.050681523392878236, 0.019997472709585584, 0.014932565710266993, 0.07448046993944915, 0.012392267949068019, 0.05770099552107915, 0.016003066332139555, 0.00890833085342761, 0.025686711681285695, 0.026329771630586158, 0.017644642409117475, 0.014690706006912215, 0.039317175941241365, 0.03834943452309217, 0.057641658180904005, 0.0922685718884872, 0.027024391212410508, 0.05422787079888006, 0.024665108536400145, 0.0364616904557953, 0.046600940742439804, 0.010035662750353017, 0.024398967676285296, 0.09850347039079475, 0.08000720442543108, 0.05182686314407376, 0.04958316398363921, 0.09429500468315617, 0.02775690533340939, 0.07922052405774593, 0.03004041233760936, 0.024178759532890493, 0.04619239371330027, 0.044413173661356976, 0.0354344584798861, 0.06275426468721802, 0.05006446638294766, 0.061851039363612095, 0.029116251746252663, 0.10017915749021115, 0.09679721638319955, 0.035468675797024084, 0.029879183388285102, 0.019850586841423667, 0.0397715580108906, 0.10694185226795175, 0.0640322334103046, 0.03461339608615926, 0.030541211674590747, 0.03684542772750701, 0.026674612703162338, 0.008975432494715338, 0.01479112672724671, 0.03237478374954193, 0.02050648642433507, 0.04774228151467058, 0.0238811113916698, 0.05283908362710669, 0.039284280125772765, 0.018114415185165503, 0.024688142885063446, 0.05275787830713296, 0.08047610386124543, 0.030965001938203653, 0.02460277004678163, 0.04845251013795215, 0.046090274192993684, 0.07142653703809747, 0.05619454490501554, 0.06454326768195437, 0.11650740995161957, 0.04015035018505108, 0.02502569654625991, 0.05807733621388193, 0.07490388673519896, 0.021435856413576874, 0.04513970846610685, 0.05223322299218947, 0.04774415076920583, 0.04671974565773722, 0.016712819023298162, 0.023444803251374154, 0.033315918934080875, 0.06981714718764828, 0.03439573135467307, 0.0143458227995002, 0.02350671656219469, 0.02395373078123216, 0.08060609366023734, 0.04408164528168498, 0.024668002433534113, 0.019891821523948063, 0.021882229033977758, 0.04358250069462004, 0.036576695574988285, 0.014744215333203395, 0.03358044909433492, 0.05709868187325136, 0.0297226716253546, 0.05487120079417383, 0.01568363448079195, 0.049310199195338834, 0.05636871116416109, 0.009643462122297816, 0.04614380075626316, 0.0223508948129752, 0.06809137325974242, 0.09080754262545417, 0.058381982568290934, 0.027138867730935736, 0.009145775017508817, 0.02780970794359042, 0.04000342218205333, 0.01454307607585384, 0.0812819977140715, 0.03866739165518553, 0.05035461069295003, 0.00964507856781805, 0.08614181435757107, 0.07784829204601627, 0.052577851475366665, 0.031219764477423126, 0.029102094441411958, 0.041603795177633726, 0.03472824415732776, 0.029663684770404816, 0.03747264306331354, 0.05043166381637416, 0.03492694821268801, 0.03532377026614643, 0.05595413502305747, 0.06637139095654411, 0.05607533779355788, 0.04322725423281232, 0.04083583799881801, 0.057736859927254344, 0.020536145518323588, 0.03624168149526081, 0.009058786691316675, 0.02477664710773576, 0.01693214425036023, 0.03004481159751454, 0.04900300942902123, 0.13694037683308125, 0.07529462988097822, 0.06324746060155093, 0.09482914416660225, 0.04092964546514615, 0.05903506103242117, 0.024016942611084353, 0.05350065417587758, 0.07529915746061072, 0.06322418301997167, 0.01410729174817642, 0.0803387902616974, 0.030901035511746045, 0.09199282620102169, 0.12882487037249152, 0.0868477950233125, 0.027355375669656262, 0.05488341223568686, 0.02804613416834224, 0.0526640325364086, 0.03237639253418292, 0.013325803541398097, 0.03639746930510287, 0.016393285665300586, 0.033145468201368086, 0.021714208715204752, 0.05315173176988479, 0.024879168824202595, 0.009951019610819078, 0.06073551575442957, 0.018226440222333037, 0.05084445114217458, 0.02051247148624351, 0.01228188138244854, 0.02672673541031057, 0.016297055445911906, 0.044884478613253564, 0.03927336720329139, 0.01106781684117572, 0.041805172879849715, 0.04254671534703624, 0.018536117859184742, 0.021034290360647346, 0.04974503836203968, 0.04015166402584122, 0.048452870199276556, 0.012917897153285243, 0.04758286627850706, 0.012930379598401489, 0.05566381068239289, 0.038297918940623926, 0.07999846336221503, 0.026203302005606315, 0.02517010411998678, 0.02874406324999948, 0.032661913503562255, 0.022147866191282388, 0.08107717644663588, 0.07815203058623499, 0.05377899307096678, 0.027933597767485246, 0.05254028635399957, 0.024061260797503977, 0.05499139232861419, 0.0013839951721057598, 0.056556517618798444, 0.06872515779949966, 0.01323844557778249, 0.04206474262079404, 0.03788311297314302, 0.034269200442659284, 0.037515781474329775, 0.04299488827405919, 0.027976546571740223, 0.05079540619326215, 0.04200303040805363, 0.011850164024039142, 0.05797721618305772, 0.03903640471699257, 0.04903779748166281, 0.04056515232209237, 0.046848168806923975, 0.04001233561505233, 0.03578919932366379, 0.03500965123455371, 0.11904380449484434, 0.031252646886353055, 0.06520480758720829, 0.08190267448944431, 0.10217259487798137, 0.024155001231138746, 0.08488389798590253, 0.025624867318378344, 0.06308477800039035, 0.03719864022587577, 0.06967283920535157, 0.07487779378049797, 0.014166856999509038, 0.1031295306259586, 0.05442771632524748, 0.04489783918665302, 0.03174661463426967, 0.11268111486588755, 0.04986975747611254, 0.07893280441602392, 0.04901718205562042, 0.04313576801289474, 0.04739569184640723, 0.06848217003167638, 0.03902708142695408, 0.039628701765210404, 0.01652612722659063, 0.0369923442391859, 0.031177012940808654, 0.07618713763452346, 0.04386281609655388, 0.0034830754861280688, 0.07311556938915484, 0.022200806697289792, 0.03096376279098613, 0.062840920722773, 0.026917774755988392, 0.03434274871382983, 0.04629872288675078, 0.04880596778445667, 0.024827408093598582, 0.0835472354364972, 0.03223373164092341, 0.03626538808607767, 0.04954810780022414, 0.015342752167564488, 0.030211475940661568, 0.046367578869385105, 0.019626473564834847, 0.04742953378046232, 0.07808764855707846, 0.041727552851361614, 0.045675349481884515, 0.07543272489020902, 0.03325098532161886, 0.03049846588363571, 0.01995496823632669, 0.013176596426825612, 0.040440295312193134, 0.05516868039605118, 0.021033497459645716, 0.051921000028209346, 0.04250608970441165, 0.08027645368729869, 0.05491243930713785, 0.06182401944252272, 0.06812212402902304, 0.10988218199101188, 0.019777731879824595, 0.057590924008118535, 0.05669373545735594, 0.022876588177056085, 0.03540991302279215, 0.03800054659105597, 0.012947610831038367, 0.032029264689152764, 0.05276650445716036, 0.04174978472292424, 0.031028667675150983, 0.04400220962481634, 0.061731679034569574, 0.06613456253563205, 0.058918849324747447, 0.07588674689853385, 0.028926708187246998, 0.09682365407746646, 0.06528098737039874, 0.03584273737825213, 0.045500700587346676, 0.01464419010575981, 0.04990548015602174, 0.03529167118211908, 0.020333787223564524, 0.04733570333149645, 0.025480549759982575, 0.050319818809868834, 0.1916581302160217, 0.032137752315329934, 0.03813112627774958, 0.06955322223685442, 0.0757494486207443, 0.02875438436955935, 0.11053009319209284, 0.038293134721536795, 0.06670375054161395, 0.25286748284293764, 0.16340745823277583, 0.12306197396209165, 0.1960163124867024, 0.15955858653591526, 0.20963340276671996, 0.09312728750369242, 0.12357382028694115, 0.10251460717089715, 0.11155991454518611, 0.15428698231135646, 0.09278971085985822, 0.15500803958744774, 0.2862470981574828, 0.07659483430606705, 0.11351632690357585, 0.129549941949306, 0.18862633725568173, 0.18806640359182514, 0.11182305042541797, 0.0932265418551622, 0.14002158246453733, 0.16991442520051234, 0.12798254137798665, 0.14040505543591517, 0.17311299550196818, 0.08031049863465371, 0.15572653812987192, 0.12883453840209594, 0.09264952443059414, 0.12334950974271183, 0.24020536712581114, 0.13817013181265325, 0.106546834351555, 0.1773687364954141, 0.18013786855003527, 0.09995373611849162, 0.12215440491995505, 0.16313114564024633, 0.086207628971146, 0.1246579036477112, 0.08036876728217449, 0.1629927595176043, 0.15607032774677201, 0.17457084550011545, 0.13927234847459102, 0.14402062271631536, 0.10362695151519391, 0.0860321105668141, 0.11210762910665044, 0.14998872343811298, 0.12805977070163335, 0.19285661348652458, 0.11751682272241001, 0.1493511391022513, 0.2435644634909207, 0.20319305480487887, 0.10352170635615626, 0.1839893143023214, 0.1341530272076207, 0.1399735793952019, 0.08528261610697355, 0.12645944367132841, 0.14433301805007842, 0.2069640153598401, 0.202921966931993, 0.14426209363004855, 0.12783161439602414, 0.1466459294240321, 0.13324328247577916, 0.09187517807848992, 0.19318384028250174, 0.1016008174948154, 0.15610673224493382, 0.30142682394193065, 0.18258441630150044, 0.17999028937230188, 0.14051785422188623, 0.11070961057538949, 0.07403465273279337, 0.11994815596769895, 0.16283074724337748, 0.18466581590473655, 0.12275947648431025, 0.12818682638387527, 0.13522768002604285, 0.1808160402241253, 0.0814675901746077, 0.1724507278131862, 0.22920892573893073, 0.1876685741327463, 0.13606642372906208, 0.12152517860334729, 0.18272002918585656, 0.25091827937191535, 0.09798999995954576, 0.2978368439982015, 0.16718606434522137, 0.1501855620693776, 0.11662540281371725, 0.15465168612858943, 0.13154200037881253, 0.10918874984547015, 0.24788340673811976, 0.1458882531451602, 0.10259827163310782, 0.14142045901427347, 0.1904173282485816, 0.14792627685012358, 0.1557303685694933, 0.13105285323915944, 0.09172807387526959, 0.24941800342452145, 0.15657046058725926, 0.1252681846099515, 0.16929214730137782, 0.15668632372492747, 0.11958768861668727, 0.12722711739761214, 0.10320675994960532, 0.13494459521626273, 0.16743807662879268, 0.12736702803522348, 0.1818336041704301, 0.2150784033320604, 0.12256838351247773, 0.19592277315114776, 0.14918800833965504, 0.16012950590060604, 0.06681131694706217, 0.15383572588043828, 0.12385641480044973, 0.10724130071579449, 0.16922802574211554, 0.13060360395860288, 0.11705599019243834, 0.13782557610782886, 0.1606486070780985, 0.1692044149122892, 0.1542277483930511, 0.1462673287718527, 0.10514128517599837, 0.12032503292204873, 0.12294834780116236, 0.14967072034074416, 0.1329743702925982, 0.22930897682184176, 0.1879884924499258, 0.11154941914062347, 0.17480367494206275, 0.11176599219681756, 0.18161517718145925, 0.14919456605228687, 0.16942544660020262, 0.1559032746140034, 0.14184507090718518, 0.20738004706799987, 0.09299565827654255, 0.14589824293169285, 0.06769157495469817, 0.10945036887161194, 0.12261639424269238, 0.17438971167129858, 0.15031925973392304, 0.1334023070071013, 0.11239536407013094, 0.11958676931117812, 0.25470488344229036, 0.08947896230365, 0.1334448708521743, 0.16410970038944678, 0.15739333094848743, 0.1162278414854119, 0.14322623550411195, 0.06145905515539551, 0.284506086740763], [0.052784346644916845, 0.05028514950085552, 0.03339144754253569, 0.01621908876263807, 0.01673411626759316, 0.022316363399788257, 0.07373457609285271, 0.03468067775810919, 0.07302739266907016, 0.02328137562970721, 0.03885445117409672, 0.06872864349955513, 0.03152280013197132, 0.08721383949441296, 0.033344436557062214, 0.005460954346363583, 0.048901659827078545, 0.059780755696157296, 0.0365659243787729, 0.07596150941906438, 0.04153234598737571, 0.06406542033918443, 0.03861998613443106, 0.04157906202899833, 0.08255640029787056, 0.024083297316645904, 0.04273166429371603, 0.08864150562834355, 0.008879767265170813, 0.03303211400165193, 0.007441691432764093, 0.1059300569637168, 0.021147594764648427, 0.09517484134243381, 0.04128918968020909, 0.005088011253504984, 0.04653429492346702, 0.07037475960509432, 0.010239486188267269, 0.11343719768187693, 0.01196991601553295, 0.042097374135928775, 0.06984530857974483, 0.05800414034315656, 0.03915065523958014, 0.02660188797651039, 0.04591261457291342, 0.09377635549753906, 0.0156763949499075, 0.03681271194270061, 0.0648898535197781, 0.06447910781829588, 0.02970649567883342, 0.05557088804761729, 0.03836750653722594, 0.04679081563447272, 0.06394097318632469, 0.09204108974025135, 0.06202635475464406, 0.021080403108029597, 0.013036807405672247, 0.03070591483265162, 0.022484900827910152, 0.021681303323637095, 0.06007185378562539, 0.05400622624062723, 0.01856954419054091, 0.09598586798435259, 0.03501721252236636, 0.04554706805896375, 0.06894498672937194, 0.002209981955069628, 0.05006722046903545, 0.015917493353387522, 0.020623395272019892, 0.06802528285451474, 0.023812558013765563, 0.052197891017121655, 0.03588222538030917, 0.01663221316712518, 0.03593486328158648, 0.027236700989305977, 0.06847584214542182, 0.019745542780466138, 0.030848208003707474, 0.0417282308391746, 0.09487553079041744, 0.012715337760446054, 0.04541230936264319, 0.04117005917754385, 0.05942624850919651, 0.010692984383973864, 0.056224269116477626, 0.07249406523882382, 0.023829988429262757, 0.0454080690659823, 0.023712175597827283, 0.0036680912260987587, 0.06417319741881182, 0.018107179484720674, 0.05088080584462132, 0.022711065304916234, 0.05326245445758105, 0.04821084004135863, 0.03250350184257954, 0.04287892171452123, 0.014430733112197731, 0.030769934885263927, 0.0934818483168079, 0.05070358289465789, 0.04230715965311374, 0.03446010572295036, 0.05094988016231407, 0.038264728181304476, 0.03160685338380356, 0.05053167276444936, 0.049249747197233865, 0.01798035362885604, 0.012516666263822588, 0.057371857335730914, 0.007201188662645197, 0.022629187742788947, 0.05907159959596973, 0.0289620554840733, 0.041379519107361, 0.03572391331075661, 0.02858040197151563, 0.05149318588777416, 0.038857657252059835, 0.0813851361313174, 0.001919725006202146, 0.04803901035038214, 0.0008619944116705278, 0.10609626739976868, 0.0734024386732809, 0.054817000073530985, 0.051779361862328746, 0.05445184043398308, 0.024631563461415713, 0.032958569560921004, 0.027196063855362516, 0.06643260138169413, 0.021975383410350453, 0.05824391437213748, 0.045385094089133125, 0.022685947197098887, 0.08477150522653135, 0.030039632843146404, 0.048081849987107905, 0.005515313551445762, 0.030483140294710477, 0.050432663561115344, 0.035582662019277775, 0.014404270520073273, 0.02816656127481932, 0.01876316525252356, 0.06528133210996467, 0.0509702351184622, 0.049303641482706995, 0.02822094585656399, 0.12698811328699514, 0.0360215078258226, 0.048168084674304536, 0.03912395707541897, 0.030146404432373184, 0.04885972417410343, 0.024690481368452314, 0.022827949254743518, 0.056899410912827145, 0.03065320606824131, 0.035103573614070495, 0.08996631679756027, 0.02618868121757142, 0.03953915757818088, 0.020954234172560034, 0.029844506418392546, 0.024489898482457768, 0.08037183929475085, 0.03512567142024636, 0.03477902812582832, 0.026154906316209706, 0.05168118769483221, 0.04655150508868598, 0.0575588823806855, 0.031897834644863204, 0.043784464454098095, 0.06763107699131773, 0.0933633651584387, 0.05215498626292233, 0.05287733439716601, 0.03500965889543295, 0.05121908728934584, 0.05850241158998782, 0.11829549747128641, 0.04254938516345236, 0.05720003530563367, 0.053994891969787503, 0.05705832819183988, 0.031117608567940134, 0.011907060416565548, 0.02637209224274322, 0.056413385581465504, 0.025099945787881172, 0.03483938436294275, 0.08896121710178354, 0.020194705876131213, 0.048276240967454455, 0.047741649492133054, 0.03994323831472186, 0.04536314183966287, 0.05542158134161465, 0.043482909264463576, 0.02739879561798467, 0.024875949339700804, 0.05660990245580193, 0.11147883946015952, 0.005544473730673593, 0.05635540421691634, 0.025457132367357135, 0.02737269117196481, 0.02134642713973599, 0.01353030879756496, 0.025529215495372494, 0.04710691883378933, 0.07253202489547192, 0.10619584350816666, 0.049823248278229475, 0.03833886634017672, 0.02963185573237077, 0.009990382165978513, 0.05251258461465759, 0.033983530086134715, 0.03069409409597997, 0.055232426572230556, 0.05664149209135964, 0.036716456825454394, 0.04354865876056495, 0.053004903358317194, 0.06862486156845285, 0.057826871427917675, 0.04763666097255004, 0.020456292343536214, 0.027058794305870132, 0.041442112321214336, 0.06344653237911482, 0.03433920172674041, 0.02424102141371658, 0.02154990966852394, 0.017342340283756776, 0.06871756586817003, 0.020158923824407884, 0.05118201246425029, 0.05649997266910731, 0.0412569412090365, 0.06191476638759337, 0.04650917490042987, 0.05383262688654566, 0.0049896086960460155, 0.013962032859243695, 0.018926663737323497, 0.03835507293021487, 0.04632099306270961, 0.07513349094698507, 0.0018954610864203726, 0.04600131223278661, 0.03702554265938459, 0.045363808336157, 0.028390031037551743, 0.014893243374723582, 0.0652400859361214, 0.04876039704428085, 0.029811725516112584, 0.010046434904178305, 0.0329391147580839, 0.06359452524432732, 0.030672542127450148, 0.027247286409199722, 0.013368721702136101, 0.0577274025718291, 0.05269682493000742, 0.0497485853491291, 0.04486219694597587, 0.013502390638384367, 0.008269952658954407, 0.053465904427632216, 0.03486865658252951, 0.03426621653019421, 0.03306361936753796, 0.04397262330918063, 0.038697579349841804, 0.02925451337960699, 0.05358733319407029, 0.01754955366073597, 0.036105900071561337, 0.01322725973647809, 0.016419868916273117, 0.012379526949277329, 0.06481000417543036, 0.024376894767966964, 0.035481297095576604, 0.03341071848427096, 0.020609492691414013, 0.04035153253484638, 0.021985309994629314, 0.06596097467286934, 0.01985900997815113, 0.02643815966533317, 0.06587815290737538, 0.12437402210648983, 0.07008822739965494, 0.036528129431028525, 0.03190162103442896, 0.06892974157967875, 0.0879409412042268, 0.0036946759134861493, 0.042775614757932005, 0.0029583406895624417, 0.050319634948767004, 0.05608289908137053, 0.02518651563854468, 0.018633539345295682, 0.03690513662032543, 0.022132232251967636, 0.008573256444276102, 0.07283791614275786, 0.08534381887124431, 0.06233704937321525, 0.014423733941399524, 0.030032559936385483, 0.017059142476007823, 0.03269752510072243, 0.023263121669691418, 0.024633679779306538, 0.02236279790409871, 0.03137391285910722, 0.04454228628967558, 0.05437509757616828, 0.06424116090901437, 0.06957325543607436, 0.027825673215932427, 0.03641347288184109, 0.0065080758800069175, 0.03425541852090148, 0.025502335385329304, 0.051618824307356155, 0.024824523772563667, 0.017381035384812185, 0.08523073663274128, 0.004661363003129561, 0.05080229715414105, 0.07566085055230126, 0.006253921901882296, 0.12212719347688461, 0.1938376043953242, 0.10783233754937688, 0.14588865151088085, 0.10766607348717029, 0.1606228358803257, 0.15799604296203584, 0.19375022440668077, 0.20194664507383303, 0.10757574406001838, 0.15199817206350066, 0.23655978452053764, 0.17159978799041242, 0.24326970350117455, 0.13187616793138365, 0.14441773205274536, 0.21866076836182227, 0.10899591019317027, 0.23893392164139982, 0.1494604904925631, 0.1461197342723608, 0.12940319014653084, 0.10679511578693505, 0.13293646426210481, 0.15617545033174177, 0.19993417806202368, 0.08329716901625357, 0.13231738861049377, 0.21769335253104088, 0.09281184313999069, 0.20371404055866504, 0.11599291296255206, 0.07604684395294997, 0.221430360069198, 0.10619528426398193, 0.10907110938381766, 0.21960227509900448, 0.1392791819788756, 0.1387925169640972, 0.31805071739419816, 0.06670542827416813, 0.1551687495122033, 0.2153956863067804, 0.10332508222951044, 0.18169815982541732, 0.15352595056737625, 0.15752716650885923, 0.1397298868264883, 0.12324478552346269, 0.24091493308303819, 0.13883973862374985, 0.1312993803331929, 0.1381729356944561, 0.09908899905220156, 0.15312856543929348, 0.11954237451596607, 0.17134912402158783, 0.19713120024290778, 0.14985481126894876, 0.08119529188280145, 0.13449346135941245, 0.11022417130128992, 0.10535225046858673, 0.08816419454712061, 0.18024343546600113, 0.16459543077695757, 0.09787582987619024, 0.20538843296948942, 0.215310420720808, 0.16915555382447858, 0.12791872625389408, 0.07058934849356452, 0.1763284197377582, 0.16934961921745734, 0.08987180453034178, 0.14735541877246675, 0.12995068254249711, 0.17644121852372924, 0.1291580420107611, 0.16094419444280286, 0.13632494775998977, 0.14539129190867947, 0.14402938676216911, 0.11980103644272012, 0.14768356487395304, 0.1350605656062403, 0.2227414735863286, 0.15241578191278443, 0.2039822939062311, 0.09842971144544502, 0.15369502617226494, 0.13948130661681776, 0.16757758123980415, 0.14174577059043994, 0.10039555434618266, 0.2069602002419772, 0.17613458417115674, 0.10503600171256451, 0.14535562285492498, 0.08668344618091661, 0.17912056507362475, 0.10659515917781862, 0.10756407654093159, 0.1304354629809818, 0.23585440140337716, 0.24767139956595438, 0.07911359350527487, 0.13888852310276803, 0.25014912709593773, 0.09015075246533079, 0.1046938591847016, 0.1704973874673728, 0.09985303386084496, 0.09876036265444371, 0.14393374834570194, 0.1343767402032691, 0.10610216627678565, 0.1443599843450131, 0.24154292599808788, 0.16403828567314535, 0.17181249996346815, 0.17493749518067608, 0.16731729520665062, 0.13671890081417176, 0.11619667702865218, 0.07554324073416573, 0.1369816230069245, 0.09029633981446106, 0.13107914537672075, 0.15035615452835638, 0.11357661802321674, 0.2131525348992117, 0.22635895608653947, 0.1805873783004861, 0.1668966363274282, 0.16127289212759466, 0.1191217386193814, 0.29999001071818415, 0.2218627707371789, 0.12270984930857537, 0.16226647752186946, 0.270127137341807, 0.21288929176667046, 0.19874266619163178, 0.1973490143615392, 0.08770923791152817, 0.1526872221861155, 0.10191825368712026, 0.1584041839645755, 0.15925996546303073, 0.32271622349658324, 0.06419006667490448, 0.09855942545278419, 0.07452491069993666, 0.13125015152317862, 0.16187732017809348, 0.13934014725588983, 0.19753092960003885, 0.12302634321273336, 0.2079050318007508, 0.33567098480078483, 0.121125947203367, 0.10869204907888368, 0.17601659130905906, 0.12107229806602963, 0.17142941003605244, 0.08454496536644236, 0.12433128972207347, 0.14680743608022892, 0.19193425894744937, 0.09968192812295691, 0.1683052728373197, 0.05281188750579473, 0.08619492723336143, 0.2795840024707779, 0.10108521733913692], [0.015405343466198013, 0.01880823420510898, 0.014513465819970496, 0.03040798515411875, 0.013966367001675311, 0.034095712171326724, 0.00738775740647989, 0.04089719015023401, 0.054655945409209504, 0.03040861334621666, 0.01791821815253746, 0.012294902004331592, 0.06192140836989688, 0.028763255667722518, 0.010658640662328371, 0.029391170058759953, 0.023679544082692554, 0.01555690055547823, 0.018199242185801268, 0.0703720016885669, 0.05314645725452612, 0.011935729341911934, 0.039907814409103126, 0.044539413459959536, 0.02668382874089143, 0.0315528288633833, 0.06367279644755107, 0.03251977738053088, 0.05729655472321376, 0.042436521260007735, 0.05195924313738943, 0.024730407955846, 0.03452452988694272, 0.030240039528918364, 0.06599898795567213, 0.019837957881991903, 0.05941592164397721, 0.08994160280112298, 0.025046752472858758, 0.036420723904044404, 0.06390513559322684, 0.038640704982343226, 0.018712352555725845, 0.03676078650319288, 0.027298012921105952, 0.03598910230662554, 0.03764695870960432, 0.0392222729691815, 0.032560525597223354, 0.033071464107882594, 0.08866241216779717, 0.09144982308029168, 0.04320110765195662, 0.05589728746863623, 0.04977162544345183, 0.08085392310374206, 0.03631862353593592, 0.04416717133755165, 0.038110530003905296, 0.03649097416670092, 0.05218152354861941, 0.041107596198637644, 0.06393155030485603, 0.030014373009063067, 0.06326196647639717, 0.06237257287026413, 0.049321564109695536, 0.08460107364601667, 0.08321518994747631, 0.04210561341155441, 0.0720320069681733, 0.08077804975572132, 0.03915696014319697, 0.022020653461015994, 0.0849687422235166, 0.00809652854748551, 0.03489743084496549, 0.09073392923681006, 0.01589547407122389, 0.02126654906709108, 0.01619734718734699, 0.02985533315598244, 0.05281184537095889, 0.06289915489633718, 0.03447861057676135, 0.021665575538551616, 0.03892656303040924, 0.06317047259560035, 0.008435803991291792, 0.05439084834389148, 0.027627124293376843, 0.007116444495266244, 0.052766975601233786, 0.04215997118022173, 0.00970606203942049, 0.047865330557068514, 0.02910509942129495, 0.02613784170769636, 0.05591109237303177, 0.03149530140592927, 0.05022084791093104, 0.07209416734234941, 0.011072609678752, 0.09938473963449079, 0.02047551923521584, 0.06945071967258569, 0.07153918260648366, 0.01835714822875396, 0.02368531272476239, 0.04375750582004267, 0.03776770182735017, 0.03757819082708128, 0.07183020408715933, 0.04571354279534952, 0.07118345733972327, 0.013558438588534633, 0.057198169881538044, 0.04476182027569702, 0.01828905450360429, 0.050991367653853474, 0.029861967477406708, 0.03219223265806514, 0.06319994399804743, 0.03175191213226607, 0.07935814409246368, 0.021447744182941895, 0.027514101426687934, 0.059971814194033225, 0.00603737278593584, 0.12635382312920787, 0.021971156520228234, 0.04803855069762757, 0.020374353494374983, 0.01571092061743501, 0.018196670045595498, 0.06262855731972283, 0.026908675546667753, 0.005348474444491008, 0.04992105855396198, 0.023079781507652615, 0.03218258761109845, 0.07740513316445774, 0.07466062317572295, 0.026781311514036312, 0.03761905778740202, 0.049976170919234716, 0.01621671005963318, 0.03770409354699716, 0.038362025178127715, 0.06856004286917948, 0.03730994514039448, 0.03833611991496817, 0.06969795156750949, 0.008268436762474237, 0.03968122475329907, 0.03590372180746448, 0.025846791498723532, 0.04739840379765919, 0.08356113993232289, 0.03116408712230623, 0.03935343105225794, 0.01536241094131143, 0.013868233053794792, 0.054760018453723004, 0.05074225501307557, 0.07292475220897505, 0.03582795188131352, 0.04932226891058588, 0.012168871922298305, 0.0370216777458066, 0.02954105707636524, 0.015331519403374724, 0.09473403435080283, 0.049620836357315706, 0.04435443386976277, 0.06535480760278241, 0.050743032592318715, 0.06332348333671689, 0.03821581346733916, 0.024831079569975698, 0.026249075759082075, 0.01749793274117814, 0.01999609375132188, 0.0633428308872446, 0.0504281627945602, 0.05369561206128809, 0.051658438713920694, 0.02185276337719012, 0.04957770177673909, 0.014645872626363512, 0.024463644649292675, 0.02709080337456638, 0.022758106933906678, 0.018051984764996077, 0.008649103936829395, 0.04496372657858076, 0.009833779430107005, 0.03421005079402559, 0.017039825568997094, 0.019745201871339834, 0.03965216320789149, 0.024313933831909974, 0.09466743832754512, 0.04505898578152542, 0.00831232306682655, 0.017420621063079567, 0.025713130223354506, 0.032107122204897386, 0.036033171514469775, 0.02361328705334135, 0.0797027227799258, 0.028096711293103236, 0.01399003050004643, 0.0628916050998434, 0.029021287487158855, 0.03115485576281865, 0.07122136337021667, 0.022229420081261667, 0.04346769858872698, 0.009657028581826918, 0.0163657984305774, 0.030039711367158644, 0.027587360499667066, 0.038647595943222125, 0.032795300902498346, 0.034527965791283116, 0.029077441732008612, 0.06279609691832336, 0.01083698497349096, 0.08832831356313922, 0.05041995799289115, 0.048981348292962204, 0.057381785835229585, 0.029243734522512364, 0.04534483999915181, 0.051189263486453605, 0.04278879147022963, 0.015273560063853381, 0.015608482213029939, 0.005003024332015025, 0.02962250754447474, 0.06570490978417859, 0.01828064094297588, 0.05406338023021818, 0.05250663211148593, 0.028737258474012057, 0.027068561926904707, 0.04540400879998361, 0.057736185769880974, 0.014450382309845619, 0.05696835882601239, 0.036074287453365904, 0.02910719658698767, 0.029709525556573947, 0.03165578341952736, 0.014158913625344155, 0.027605815557762984, 0.03771777204688519, 0.017507363283526034, 0.05722288770841495, 0.040068857582105745, 0.015951284534117628, 0.006700052725782077, 0.007201056033673306, 0.0395002709551444, 0.0622603333284778, 0.033796325010517915, 0.07220162649548824, 0.03790545209701504, 0.03275912623071382, 0.03925304289066023, 0.021557266027816845, 0.038048695217097, 0.006375938161997306, 0.03792424040335802, 0.027394457645113432, 0.0035674832930277676, 0.0610353357549156, 0.05964760578447773, 0.03911264578721697, 0.034149629439437584, 0.06162568310936613, 0.057230510283261544, 0.01718010009837247, 0.03521876259436531, 0.05603076296768362, 0.004161001293874917, 0.01597284033308707, 0.0713064527559665, 0.08278163014760903, 0.04361284543730078, 0.05597716362606134, 0.06303033596205135, 0.05949372936400676, 0.02892300223691329, 0.03448834755427895, 0.036242964692533984, 0.032427888964453054, 0.020822516845298872, 0.025606550156108798, 0.0403650846302269, 0.030902517891879526, 0.040377089228000373, 0.030083504783350135, 0.07451442295625325, 0.025639863489496133, 0.07277521950703475, 0.035514487854896054, 0.06473148016319161, 0.0472731790655563, 0.02132068658548017, 0.04397409802843486, 0.030790695868011926, 0.007093615075122686, 0.0771633328329171, 0.10870915582223285, 0.03819148251486402, 0.06929018594805272, 0.04449272423141426, 0.04903798900364388, 0.04403580258029603, 0.07801244936643109, 0.040847984322857474, 0.0567492806623059, 0.043009064731097994, 0.04198569766876679, 0.05901682813982329, 0.03022159213170169, 0.010302464361302555, 0.0176693813034123, 0.01698934420522663, 0.06685518314160648, 0.027654718780409426, 0.055295372186529065, 0.06323336841418378, 0.027757460747154492, 0.060372723326567686, 0.049474337363555554, 0.020470447733157107, 0.07859063124464405, 0.05113575607538224, 0.06641210852971961, 0.04330174862256935, 0.030087218394563086, 0.03715102020050249, 0.04245565813635627, 0.03486501000400993, 0.030573391197850148, 0.0705021676877814, 0.046729762257347186, 0.05643854773933849, 0.030220814552458546, 0.19817775295626736, 0.1972410572512496, 0.1653112173681298, 0.14565822758501576, 0.15230207914306274, 0.15514843286045138, 0.12506681073817516, 0.14773345251958217, 0.11100023369034452, 0.15442573615620214, 0.13129600954632606, 0.11533316570304095, 0.13791807356380648, 0.15785986317261574, 0.1974396272412231, 0.1419046419041772, 0.13980401349404167, 0.08243967914172719, 0.08902847196065611, 0.11873914664911649, 0.14591315100269933, 0.07311571494586046, 0.09716003562413877, 0.11911907263340489, 0.17550381801782117, 0.09661166988793882, 0.1239066471856448, 0.16904307679543573, 0.18563678638348657, 0.11057655642470045, 0.1788226181581136, 0.15039502582963438, 0.17120701471163383, 0.08731785891277176, 0.22473943089285206, 0.09072946294421151, 0.13755597444551607, 0.22715698987726243, 0.11657276491243994, 0.14403186888704378, 0.16214684523161382, 0.16254298929725924, 0.20937910754113429, 0.08278495496920041, 0.10142974240044433, 0.05684745866024206, 0.0928199330284711, 0.12169836810038936, 0.15159485741488396, 0.10734464597677994, 0.2707435010421661, 0.26748358241973386, 0.11102218977025441, 0.1260262515936648, 0.1354733644233596, 0.1426504744637397, 0.15404111405293788, 0.1435915981569598, 0.16698271396660036, 0.15668186509320814, 0.14503794151448435, 0.20254681367547284, 0.17335673403595725, 0.06557486635903198, 0.12706466845326847, 0.1317288798670615, 0.15456672697778673, 0.16037684504783925, 0.26690981320796475, 0.16843097254393563, 0.1419996214850295, 0.13647572918524667, 0.16336653381586075, 0.0917412659093257, 0.23632565272911904, 0.1000629955782525, 0.10051808244879208, 0.13724489678298274, 0.14282406998738167, 0.08995182241403288, 0.09045223870705213, 0.1143219449647492, 0.20602425530312524, 0.11124280777068869, 0.12087343696264491, 0.10080480617621254, 0.11464660536618003, 0.15651372411558706, 0.20194128245836307, 0.2196340983913791, 0.12064843693928373, 0.1346142427815545, 0.1471803063947347, 0.10606478884696, 0.10173823068579359, 0.1368600601750997, 0.20616691619638475, 0.10935063954562911, 0.1598854149661718, 0.13305811902448056, 0.12795923698333003, 0.1382505557229442, 0.13692387529919225, 0.21069656426627792, 0.10143878223795084, 0.15490804979157063, 0.15371106805339937, 0.10539008755116694, 0.14167647027680952, 0.08914182232993265, 0.12865414001768635, 0.0754751738220934, 0.11835563537334243, 0.17000630978615056, 0.14666014801590674, 0.10947210278602378, 0.30857800956695314, 0.12697269193707936, 0.07882750563083157, 0.12083694819481143, 0.1359454431240597, 0.11182385481773846, 0.10907148476690055, 0.09406146277943928, 0.14842509201938106, 0.1519321352844277, 0.14986437204624378, 0.09738079918127868, 0.23772077544802622, 0.23394480467804019, 0.11994006607921855, 0.22773946184785138, 0.17455771475309328, 0.1913960055718499, 0.08188189052405857, 0.16022459273376774, 0.1558172582618652, 0.11267617359877595, 0.22985864490751298, 0.24748854970018713, 0.15134348864516906, 0.16287282079217896, 0.2082302667681248, 0.15944327498155256, 0.14290944282566348, 0.23808957017477483, 0.11047279747623591, 0.15208662457523808, 0.13411397204524086, 0.1530035398900509, 0.12203973687944875, 0.1034986777531524, 0.10720098150833961, 0.20556245750236898, 0.10909722532115637, 0.14460536230716015, 0.17402297006018702, 0.14724085798426984, 0.2038295972611635, 0.10080268411266227, 0.1108606294879029, 0.19805974477241117, 0.12054654724535444, 0.195333743467927, 0.11488351039588453, 0.11981272694444466, 0.10280507706826734, 0.28082224570455094, 0.11469575756740187, 0.08395199033041155, 0.12398120286243579, 0.07355701223376297, 0.1713828012467392, 0.1375876751638228, 0.1464459651540364, 0.22917481950454174], [0.026094952275255517, 0.019638491569146998, 0.013602849663115077, 0.01639611444496099, 0.03528655754522451, 0.04682765297231175, 0.030533474186555516, 0.016837252769619226, 0.023312758421525363, 0.007083728710459846, 0.03318389134121037, 0.05046753971386821, 0.021364273157932108, 0.06333426602425114, 0.016532267421303738, 0.04289023683316285, 0.03956599746860805, 0.04374161332605347, 0.07477798784572272, 0.019653851632028818, 0.0487634843786157, 0.043189984055296074, 0.041758882017025066, 0.04904023364126202, 0.03649337585234354, 0.0932556072310094, 0.08122493182459185, 0.04667366929953137, 0.028701932244603674, 0.024911107029765848, 0.024730942302173185, 0.008819028941704141, 0.04030051873996854, 0.055482554279508135, 0.04975952891512744, 0.039832799079557585, 0.0096258842348752, 0.030644740796678012, 0.04832422105415214, 0.062330694673883344, 0.05082932856654929, 0.0335234789658458, 0.06658735114239878, 0.0381698596832012, 0.04364989727975861, 0.039832553931421814, 0.05917233632757299, 0.06110756252441676, 0.03231873675700157, 0.02465299860153708, 0.021651286083543976, 0.0344101989251231, 0.027170376927261392, 0.08161592011850688, 0.06857572468898951, 0.036138657991203575, 0.028438124122218262, 0.054503455607881474, 0.0245520799240518, 0.04600460641086102, 0.03082094101926252, 0.012941467763495543, 0.014053286379954268, 0.032367881297344164, 0.034081872792974595, 0.005715864836313432, 0.0464127320916422, 0.062285238846896164, 0.06880362052470446, 0.03554035098321977, 0.03688296603579675, 0.07749496463445887, 0.036371135032705726, 0.02459317671074983, 0.01734453704087965, 0.07114348287183432, 0.05507377359355169, 0.03688797242038193, 0.009583128867821108, 0.019944953551936536, 0.02836229865469279, 0.02358887183119453, 0.06183924927045742, 0.08288390288550047, 0.04264858205832782, 0.014135534537114925, 0.015268959705868076, 0.012235849074298337, 0.03991410016052185, 0.06439589534796054, 0.014315643723333075, 0.0293394552934314, 0.14549952481062184, 0.08915210322987649, 0.02480287029738388, 0.05568154178740037, 0.04907407940575673, 0.044551628731912186, 0.03468021810535462, 0.047673437023355116, 0.018735536291534384, 0.0711349256697201, 0.00920586216623985, 0.049886109622856306, 0.05294415258592176, 0.01643175860085795, 0.0196655172358958, 0.04704170176879533, 0.05511232313790149, 0.08556765444096058, 0.05710415557147034, 0.027277209803522117, 0.04059674961852931, 0.009577627398914868, 0.010470221337351588, 0.031410037735176664, 0.039788699228196375, 0.029400374605170185, 0.010912256942491138, 0.07192260961258604, 0.020892303624761202, 0.0411044207641915, 0.04197614455235101, 0.04861380228953016, 0.05808401267014204, 0.09498806910649424, 0.03593252671341743, 0.0338337637273775, 0.06455070639569914, 0.06467932489730659, 0.005748673030475696, 0.06948711650986826, 0.028715786944714286, 0.005070878175883404, 0.034769383078861626, 0.012027367821804458, 0.07254245135212138, 0.047926655895407164, 0.058404865614589185, 0.03195960431419794, 0.02651877126716558, 0.041753151679351445, 0.04477326179884615, 0.03213570303013248, 0.01596511050593108, 0.04576963192272571, 0.06792414392675124, 0.04971731364005997, 0.037257111886696476, 0.02634015403717997, 0.017715547676949252, 0.03476908430457115, 0.02446808604403369, 0.04846199813689436, 0.006531957234631503, 0.031078097583245368, 0.04804297102495067, 0.04035410275983234, 0.04046095287307136, 0.04262957924736604, 0.029205642715697328, 0.04421281485608028, 0.013873255717748357, 0.08807650812330746, 0.009529556339276175, 0.009875250642278023, 0.08477000369419975, 0.09783860566394945, 0.06302741716705984, 0.07754613164692156, 0.03662430027860307, 0.05968286498119274, 0.02804486054716812, 0.007079972964411061, 0.03012306747897979, 0.013858690471087974, 0.009509391947499207, 0.01409695626446797, 0.009356231819237433, 0.06310191921769612, 0.04875944326481512, 0.023470348453209288, 0.01086999665975811, 0.00873594957914564, 0.005834121041135082, 0.0595531739564913, 0.12219147591461098, 0.02611500654189337, 0.019968505009948727, 0.054993219448313604, 0.008103828407793997, 0.052125013072884856, 0.0389257509772095, 0.0489971871607967, 0.03319944675651289, 0.027929529840607318, 0.04628217538758632, 0.01580560046638693, 0.024705508183087074, 0.016816654580555136, 0.01904838553239261, 0.029608591557330186, 0.002406273072870869, 0.016124429023494164, 0.025182874805684534, 0.03793913698304565, 0.058372686091329784, 0.0764041856652306, 0.03568912525811503, 0.06586630152718675, 0.07307826090724238, 0.03344945955060182, 0.054518892279555725, 0.04941721401748158, 0.09718047484995858, 0.0415297681015105, 0.0591111297328626, 0.03877449457743957, 0.018123686764269106, 0.08229671947417722, 0.07075995627430177, 0.06094645423394057, 0.08982763956150702, 0.019627182196164807, 0.025701206064813083, 0.03916591571103181, 0.030710938454215086, 0.0387920226691471, 0.016083437573885726, 0.024616471529307387, 0.08463665076922025, 0.05580781605995952, 0.04226881312206388, 0.0516742967339533, 0.027575321427936998, 0.10161866734345114, 0.04341861533541833, 0.012286877233324753, 0.046918323308589964, 0.022581648156647722, 0.06851269097457971, 0.012613861753995861, 0.08644907690224149, 0.07642192826155694, 0.06547536685942643, 0.09579312026260361, 0.017814321308246544, 0.02475569268778688, 0.020094327290632555, 0.037267940539506175, 0.02316662523474905, 0.03643858141355938, 0.047373076930882475, 0.11333765221699593, 0.01649971251496144, 0.050096454384226, 0.04243926768521628, 0.06546304050472475, 0.042233469655677196, 0.0416370433935475, 0.058455140134620096, 0.03949228448853378, 0.01463734798298608, 0.013063126356310904, 0.03400395782063565, 0.05515245465381492, 0.016629112426251653, 0.01058937099221493, 0.08731209027070193, 0.11760042589758674, 0.055646305573323084, 0.04903170325222516, 0.037692445180108475, 0.0924863093983262, 0.034746247223548354, 0.03445882252567718, 0.005594710425113238, 0.037212766887199496, 0.05029918040118871, 0.05201817062052508, 0.017928546932976575, 0.0392796874286667, 0.06593243023681064, 0.044992918358935464, 0.029636354583706108, 0.06004833871678961, 0.010562372138543476, 0.018500860577689546, 0.06008203126369946, 0.05779908541890402, 0.0191921170335263, 0.03479358762682926, 0.02283451079781498, 0.0296911547681497, 0.06883246373505363, 0.061081730039610024, 0.03710125129850161, 0.06262073939245555, 0.031762405621608904, 0.04281653534440745, 0.017905859239099008, 0.10828724821969386, 0.06308226140155908, 0.03601587324913952, 0.031523110397580656, 0.06312154255987656, 0.013691900681043345, 0.032335046768909505, 0.01942094558128907, 0.0075419771301019345, 0.06150110572155926, 0.01985056577400575, 0.04808585279651227, 0.03715499619682951, 0.06952352100803007, 0.08014790413360443, 0.007000097764595863, 0.055973145494898485, 0.021477349650775714, 0.0587108028271506, 0.055292556813407334, 0.022367647240659403, 0.0943195271576124, 0.019316342020888003, 0.02395739459673003, 0.044432846799252496, 0.06179431821369837, 0.005713208905240942, 0.03675298389768408, 0.011976899864572671, 0.01986545086237452, 0.048692073492753896, 0.05956685245637933, 0.037871338201746825, 0.03228507102316907, 0.056307933578688296, 0.012420121948384951, 0.038347929160320954, 0.007084323386211069, 0.017219051838882508, 0.047630980430591496, 0.025692668014896974, 0.05204199212453058, 0.025804352142938206, 0.0764520048734642, 0.04478377252516728, 0.10012036024202263, 0.061712155283819285, 0.009744075322223288, 0.03515419670410695, 0.020157426122515913, 0.0347425508493137, 0.09977621822467736, 0.1036232972757951, 0.07444055675859414, 0.16342204454685413, 0.1512475284717737, 0.17452382302332312, 0.09410435604231973, 0.11728559440422444, 0.10780068279634561, 0.16156654895072983, 0.2688362485458774, 0.19214683302467872, 0.11310625535946701, 0.18934486644162288, 0.1322339769572981, 0.1519934529618871, 0.14550107230822887, 0.13682642891522379, 0.15103431088068794, 0.058667036224036455, 0.10807157148637118, 0.14070177661074748, 0.15839784075656246, 0.16308101284648144, 0.10873224571227066, 0.25728897461968087, 0.1676609162842074, 0.11041620656126931, 0.23841901862573242, 0.13993119941123072, 0.11527858193843596, 0.2145051550600798, 0.09672413925610243, 0.24328917745620976, 0.1751294308492253, 0.06301081221130106, 0.12275485697412684, 0.16496427146898163, 0.1296201002814116, 0.16123628844657253, 0.24306088325477418, 0.19939367238792682, 0.12216311533965411, 0.20420828984389383, 0.09513207065362124, 0.15781303987868373, 0.2682855845459046, 0.12881910939130092, 0.09544157783590979, 0.08877878092349538, 0.12843372886099164, 0.12663486248423017, 0.09529124840252823, 0.14281636314286342, 0.22317178517339692, 0.11542889605005903, 0.11665438391989279, 0.29421330940338875, 0.10553833322539445, 0.23699728201233575, 0.10124573574191141, 0.18318705170625643, 0.16329806087718857, 0.0848365001260273, 0.17935160186982926, 0.08497430402184687, 0.2597233875384254, 0.11491607679354568, 0.21802284694727392, 0.14364548478155367, 0.2205461413869935, 0.2113307471717558, 0.1573266046902826, 0.19618810004284307, 0.11430546641349794, 0.16992986953306585, 0.12295117466560296, 0.17534934404876926, 0.13565164840509816, 0.17645954334687802, 0.1809339411556721, 0.11330626559473815, 0.11880890661550146, 0.19497984149042638, 0.09784335540907999, 0.108220299795991, 0.12735775071046046, 0.13614355346127865, 0.09748140950837443, 0.1479594637790034, 0.20707938820123675, 0.09732373329179902, 0.22217006392536626, 0.2335626646996506, 0.13529710291374114, 0.110345458341462, 0.17337688214836583, 0.15723648210687025, 0.1321713569303674, 0.11204964391166165, 0.17316813851075788, 0.24721468858901532, 0.12826515121325371, 0.17378525297728278, 0.0984174310560188, 0.10481853999437825, 0.16281645204271042, 0.09543365648677272, 0.10494010282620307, 0.16760580391893465, 0.11657798963208353, 0.21148226404141998, 0.1566774371050058, 0.23707608181622722, 0.13387620899706118, 0.12968062122742977, 0.19446815604404097, 0.13962505535492975, 0.14360498937387622, 0.1472541113053599, 0.13546826227778389, 0.11805911338137043, 0.14038504521933295, 0.17686121856733678, 0.13398131626027246, 0.2653936639187798, 0.13553057586954487, 0.22488507952901626, 0.1388639623239156, 0.26403765764928633, 0.13665739927561055, 0.15182004129934698, 0.17286813847960966, 0.0723071244635409, 0.10675332569066556, 0.1565080550649474, 0.2031273397827341, 0.1051264000876296, 0.29320480061634896, 0.1621699657651686, 0.16039155393598542, 0.16377986889452706, 0.10058201248607329, 0.13216282271089094, 0.1420367767493571, 0.18629595907705446, 0.16628931246457562, 0.16564281086527533, 0.07289037018293336, 0.0837189234012077, 0.1451079772725221, 0.1410568277201345, 0.06783415923916525, 0.1295338694246546, 0.1304952178390757, 0.1589152565406215, 0.16249792800555307, 0.2097273711115122, 0.19597684363684348, 0.1290835016557286, 0.11596780060039413, 0.1909958931707567, 0.04553707061155189, 0.21360679439479308, 0.09059539755746242, 0.09846343463587184, 0.1557038772490717, 0.3179350687611488, 0.13972340572264888, 0.15646849428453755, 0.13482148488683088, 0.17246441014351385, 0.09383597245980656, 0.36498518600579233, 0.11673673837175293, 0.11368699597134707], [0.029762791649949168, 0.01920404310728754, 0.04463933430792344, 0.05528163623004671, 0.03829192813305605, 0.06215289715797671, 0.05052453665543468, 0.07843319251532517, 0.057020694122559605, 0.026028844633049546, 0.011893402026485533, 0.013385006816186493, 0.019925309142338175, 0.08296534569273073, 0.06815567101922727, 0.021984204912798542, 0.07093259418803839, 0.03196936044391365, 0.10235395853317554, 0.024177752127270066, 0.031200093254747412, 0.04106199864538447, 0.014410135880743545, 0.08517866563652793, 0.029960940291564313, 0.03623929130093705, 0.01370256845538895, 0.05138839272061183, 0.05167278371030285, 0.01924567807075237, 0.04793499093202334, 0.03877123104288213, 0.039169554628672144, 0.03884725760848772, 0.024031450401150414, 0.013496315561144823, 0.06000781266559517, 0.0290142260717168, 0.034689192825387564, 0.02891029092302967, 0.06756284153990208, 0.014833058549782202, 0.035550206704365636, 0.01808441518205068, 0.10118829446934885, 0.04799717428883718, 0.009743341793035789, 0.10608226331251283, 0.03648733524906059, 0.02492493683201892, 0.09850897090209108, 0.02164641567956536, 0.06290464008587503, 0.05546945034556332, 0.06069225476934545, 0.048606601063041925, 0.025668484534347252, 0.033707983581529516, 0.042823384170450514, 0.05133992999852185, 0.04446123418728671, 0.06654716216989102, 0.08114506715848561, 0.038471962625701586, 0.030194378773411436, 0.06163039071966083, 0.09652452738655191, 0.0421843595892912, 0.053325128110666434, 0.019335794908505295, 0.04166318231352395, 0.012633272506777319, 0.05150063609283778, 0.024081006713752306, 0.07944561601165803, 0.029042569409695365, 0.04870065367750583, 0.052348438785561634, 0.08473169929798573, 0.027745431251523477, 0.09988203794965822, 0.02415258422373764, 0.013653768654612285, 0.08043213807527097, 0.03575496668476732, 0.04445020635161669, 0.06323543302113972, 0.03250544770590721, 0.022631129775676998, 0.01515496390751533, 0.04759226617733798, 0.07466372583181628, 0.054109579162491914, 0.04321554457888969, 0.014173700079892673, 0.025534574280402837, 0.04613726219582943, 0.043956179231885946, 0.060465871957280946, 0.025523130842033896, 0.03691051072711426, 0.016092010097758427, 0.05314132446543344, 0.01555209335375337, 0.08814188606676557, 0.020654132634761836, 0.02115008646562215, 0.03934435291035522, 0.01799179323678536, 0.028037195837485696, 0.046128371745468154, 0.03574710279222458, 0.07102332964179016, 0.05614673718810082, 0.10283690036064196, 0.020915150281883055, 0.016776473268926624, 0.017434571524180712, 0.042214673688454975, 0.041347722628063736, 0.05055894166411412, 0.045884418706860275, 0.022749042198542627, 0.030545273855809244, 0.01149107467368125, 0.03759744261661845, 0.046824105985222325, 0.057919430170929244, 0.022427771736176747, 0.06061262376005612, 0.060696058395889506, 0.03509706952759335, 0.026398844033059095, 0.04350046033880884, 0.038259737118477785, 0.024233636326126518, 0.0914362786457904, 0.0743548391807464, 0.02899696611078276, 0.07297860052917274, 0.03562332213585896, 0.05876714093310218, 0.0752089352857682, 0.0060304301141220484, 0.022411835192131902, 0.0391891626490941, 0.03703996809499879, 0.039925568496748325, 0.023669412569893945, 0.06492068855873039, 0.023455053507801027, 0.05413422804145564, 0.060769376840682766, 0.07390562054370681, 0.02950415270583284, 0.016739917468399774, 0.07647220661202747, 0.04864254590844916, 0.0547480444994665, 0.0393525462207054, 0.036671391703308596, 0.03064320479038983, 0.08944219774416379, 0.0377454086687536, 0.02284167563512681, 0.02793348859995604, 0.09164642422429978, 0.04897817285851606, 0.04359235258532628, 0.03887386384209798, 0.06200335296471754, 0.0200590776700166, 0.04290734357651203, 0.07519942047374864, 0.03705863765771351, 0.01633454204326676, 0.009437879554987436, 0.04952883685848886, 0.022488252462578878, 0.05988344595196748, 0.02033096227434374, 0.004504355677073041, 0.08891606387952644, 0.028955348384296222, 0.10107508965677793, 0.022266427873663848, 0.022875655465008273, 0.07505965539284291, 0.02518374048503897, 0.045559394413665424, 0.06899572473259703, 0.012765335531214313, 0.041942804405886325, 0.04081294346120089, 0.09120143439260223, 0.04481984760552164, 0.00737038636279683, 0.05566728106068988, 0.023235065614684455, 0.09941696129258602, 0.07549141488608814, 0.05594380049695892, 0.04387899204307506, 0.03596132395849113, 0.01740645609735962, 0.054138537286029714, 0.03982385883348123, 0.03335313931588204, 0.08024534285669366, 0.05322845547550148, 0.03695141216139159, 0.06738538493312175, 0.09733294932952813, 0.022007622305423986, 0.028802036953669403, 0.03951884092642896, 0.062428478136538505, 0.03022787213746098, 0.026844477378613046, 0.018333313318209785, 0.0518626471110169, 0.02601888740525371, 0.03428702347821767, 0.08532910232221888, 0.0444911920555657, 0.0374230963268107, 0.040039604514717095, 0.05632212152704597, 0.02569391482299374, 0.02856478335395936, 0.08811681200900386, 0.017381642509492177, 0.052322652266030355, 0.05510233718180849, 0.011760871688414727, 0.05295199732626638, 0.02359370393077693, 0.011004683535335767, 0.086816921679964, 0.04514417092826578, 0.03577403078276304, 0.027590895995437622, 0.037895040962124066, 0.004187458619144896, 0.0109154180127887, 0.04174173696927967, 0.022824925122662418, 0.0431033126979826, 0.06257048402462276, 0.021854939066895077, 0.06669307893682873, 0.03636164703376351, 0.037512632852960984, 0.03444540066524379, 0.022478084560603868, 0.04155268945220498, 0.006864978049340989, 0.040968275448728, 0.0447137980541635, 0.02687556522658035, 0.036849844224390485, 0.014873676531527553, 0.014222781417981513, 0.03231763359039061, 0.02509578401523252, 0.02886462442186331, 0.040136503145819714, 0.04413382353020772, 0.056697493118624535, 0.03658784981516581, 0.05947300285521535, 0.15860624731548373, 0.07902822066699305, 0.050443649261949525, 0.028158274118698416, 0.031134069882213112, 0.035682130875366355, 0.02540826361866728, 0.01994490950188089, 0.031218781969660235, 0.07284556170024219, 0.03666516723892382, 0.03321107597120347, 0.04702727633318113, 0.09983168299039526, 0.03492561138926014, 0.05025016226535363, 0.01289729321856172, 0.04257232949678456, 0.0370312002187054, 0.08182444925149603, 0.05794014901884141, 0.03969078553059409, 0.08539486330963912, 0.024019487938212774, 0.06784843911807384, 0.0033616977124174517, 0.027580831515332385, 0.009135397398964533, 0.06861238199616633, 0.06573144706987566, 0.02634140850615598, 0.037772777159848524, 0.03991248371500162, 0.02284172543084189, 0.01014973515749819, 0.05701744974020028, 0.04227891782178514, 0.0633636646483454, 0.021492757594152805, 0.08797773640722999, 0.03276181519932805, 0.029578530267181418, 0.013565693441177569, 0.0606882366381826, 0.05128350762289859, 0.06040394907036136, 0.014237365816840002, 0.07273517609123262, 0.011162645119662968, 0.06710279808049241, 0.03300255449909357, 0.04731120767011758, 0.06908184833704464, 0.024786523896299546, 0.02801521485971828, 0.06981622788213915, 0.11425334179112989, 0.06314083265380994, 0.12073041600806099, 0.032936916085741216, 0.04220865223737013, 0.03626212455152023, 0.016430050224786805, 0.029800831745829315, 0.026473024326767174, 0.013193773075697884, 0.03290828354957123, 0.03817297000017378, 0.05854943023634054, 0.04422261695107145, 0.01852851635175607, 0.12910656090224945, 0.06108073029486884, 0.00806938030666882, 0.018087895136446725, 0.02856557242452137, 0.030230352347115838, 0.03828158977651789, 0.03300512855451915, 0.02049320820538748, 0.04193047039030541, 0.1002911135794655, 0.13312925794912925, 0.14154387577887506, 0.15734184983997576, 0.10969723304433208, 0.2798555959616938, 0.11377474368219415, 0.20620552702776848, 0.23596796627727248, 0.1675416670379139, 0.08033974787160274, 0.29526830440567386, 0.14423816104329404, 0.17392123358384257, 0.1637426829866825, 0.12554558504733349, 0.22674108074317056, 0.19938602683044251, 0.292092134515124, 0.1777816425648428, 0.13637468218803406, 0.1294027917808102, 0.1615409462923004, 0.15106014336549467, 0.17183752039507513, 0.09153610756320339, 0.13555774134733986, 0.17217914964402878, 0.10190211987543492, 0.228779012517583, 0.11437663598166359, 0.08705687573960713, 0.18781969263668985, 0.16121008823956215, 0.1297014741407287, 0.1473111542122018, 0.2365110766503119, 0.13201228643376983, 0.2771263924096861, 0.10150127969081364, 0.13093441604606568, 0.11696264237886476, 0.10914089233284036, 0.1786633178351387, 0.2683164732110116, 0.11365257564090914, 0.0984684908161721, 0.20670451073636933, 0.10434723504248167, 0.12604084556862233, 0.18382501908608023, 0.07008907009637164, 0.13637796104435, 0.1435745603615238, 0.28270535110946626, 0.12484111357480289, 0.1124793119848736, 0.12840343774446558, 0.09974359053998225, 0.15976647215504802, 0.09996053897925924, 0.2180528009851133, 0.1581519571763854, 0.11164471281752472, 0.06290735203712698, 0.1270687363801464, 0.22455799062886547, 0.12819939788671272, 0.10313490856318705, 0.13367147966017648, 0.08477318295908552, 0.1486505670172553, 0.23012277670204642, 0.09813302857500893, 0.14559787517834097, 0.12845109607423508, 0.09049434289937058, 0.14203522925175008, 0.22431293442364664, 0.14246794635490065, 0.14554818671557213, 0.1493083607525595, 0.11496004257952014, 0.12798719153168703, 0.1395308725055187, 0.12531855489097296, 0.13260948261426342, 0.16786454245448115, 0.16429624279900906, 0.09804602396944839, 0.19972998498668595, 0.1874138652196815, 0.26080868897899506, 0.16326881164023954, 0.12002776782479017, 0.21787269371411494, 0.164166406217602, 0.1400423740908023, 0.09424791325845065, 0.08711548146581458, 0.13811114304248365, 0.06523014977574348, 0.12977846597711887, 0.11953231578152027, 0.1703467439379423, 0.11740228491685084, 0.08144954114311165, 0.14414912630473414, 0.18108602493040024, 0.10008080712249202, 0.1339781906215414, 0.09959339134154782, 0.16247707509225415, 0.20043607290473678, 0.22323126423983808, 0.16584326543154257, 0.09802564603066254, 0.1478034882776199, 0.11052309114846492, 0.17196657556679942, 0.13875667937099934, 0.11470505021392338, 0.17252399646226438, 0.1110005707690312, 0.17225888407518788, 0.07032995112240314, 0.1538495767501093, 0.12844165021012868, 0.09107831640229111, 0.12670417811961907, 0.19519069953070534, 0.10579157124964461, 0.2098079635611465, 0.1787478632984623, 0.20484020512911583, 0.2333110661035584, 0.186554666969084, 0.1572132083557306, 0.1921392640759868, 0.08957244801304995, 0.07314884058770633, 0.08844485085818077, 0.11777389118628157, 0.11607309172470724, 0.11731249175124592, 0.1223873109706948, 0.1689230154959425, 0.13596051973440956, 0.1529556287512664, 0.1555936678402847, 0.16615227465668034, 0.15979250382271507, 0.14535012234362865, 0.5127404413876996, 0.13894052515106817, 0.1808624804740952, 0.16408215186768965, 0.08235136452581614, 0.13311465631329245, 0.1359607955260623, 0.1116479840129614, 0.14521991804001794, 0.15778187542192398, 0.09325209854831619, 0.14198921801101777, 0.10088658606212947, 0.3098630454511412, 0.14575958101739808, 0.10810585392098274, 0.07985554965994052, 0.1548269670456648, 0.10721141562586832, 0.18060487574867665, 0.1900450861261737, 0.06993649602537194, 0.07579781941228336], [0.14645757904696852, 0.02244671326010458, 0.091153216818648, 0.018356889674079516, 0.021908940604677605, 0.02638347439407822, 0.04054557494518738, 0.05682703858662037, 0.018660402218360576, 0.004837055213659281, 0.04397359624084446, 0.02673709483426665, 0.0214425903264313, 0.016183458013279785, 0.027914208082121708, 0.0586045119580963, 0.02867766640960209, 0.035021989080574245, 0.023884572193867738, 0.06545177901223784, 0.03060669303991862, 0.023067273207068927, 0.04131450122522731, 0.01739430211244091, 0.07910419360644395, 0.05160025816651122, 0.018588834284474293, 0.03249479142288047, 0.018787572813791134, 0.0732614784952133, 0.03443370250264003, 0.05450113819191053, 0.025241530327607068, 0.013518041814677419, 0.016261602811996016, 0.0709407760070697, 0.014337859315527304, 0.014882699132055767, 0.033428162306306825, 0.054827185212484295, 0.012687500040497512, 0.037974928610868035, 0.1243655491740473, 0.020820848688843752, 0.0501830069979112, 0.05138816289423455, 0.051565447131231915, 0.005550608658532222, 0.02349560062641338, 0.03199988138681698, 0.04580708596134379, 0.04134629387408495, 0.021683651383125016, 0.01500109897836322, 0.033010360935041984, 0.030719346269184065, 0.017234643643361428, 0.08792079309181822, 0.08388105058862318, 0.005900014178722256, 0.0535359516769888, 0.01913827445898806, 0.013211734964692546, 0.0983599438181808, 0.023978582673495816, 0.027337715427781788, 0.04332262451850599, 0.12245029105894989, 0.03891212227303655, 0.11692192480568925, 0.07650537821914881, 0.08462623197345004, 0.01810924600689642, 0.06025182699123698, 0.03822116459149026, 0.05073983034479523, 0.04866938962931595, 0.03537514029190906, 0.028152287141570163, 0.05410362665932025, 0.018630130254032633, 0.03339546950413816, 0.04880023361634343, 0.03362053847541252, 0.0392298419178734, 0.05113399407315639, 0.0036576207193936556, 0.042476300375476, 0.03675617465388872, 0.02429526043875564, 0.023636599108877204, 0.12717140748375846, 0.11687786708916388, 0.027821467393228126, 0.03304496129614211, 0.03545263391588965, 0.02085422522448484, 0.05723575415510324, 0.04185657354912931, 0.06269351391482257, 0.02396050682892242, 0.013714118188457384, 0.03739684632408523, 0.06861916953517545, 0.06160446247386356, 0.017101233261787606, 0.04643491416748974, 0.04204167954383358, 0.010694005196132969, 0.03279030600923204, 0.07484927998795625, 0.018458716165755066, 0.04718051307023533, 0.08090025610140256, 0.08442010069566389, 0.027108323805394675, 0.04199205619853832, 0.020868300174873684, 0.02282915967366388, 0.08669146712148383, 0.03061655259150411, 0.10039882554161934, 0.05311682497361495, 0.049958604523130966, 0.06009121665791158, 0.04498303582471225, 0.060961201426482974, 0.08215073375932633, 0.02250347271441452, 0.01788292448186586, 0.013657533019150217, 0.03325789543469587, 0.017668701400379502, 0.009158571558674018, 0.013469766784128884, 0.04841023357585073, 0.044590515354948665, 0.02434612676170805, 0.020096548945612965, 0.022255961197398366, 0.009473944101632844, 0.022005555783248237, 0.03302430373526389, 0.01698357939359642, 0.028474164728616035, 0.0015180008279369966, 0.015184083867127137, 0.03221553322228213, 0.06754381191586295, 0.09291421546931229, 0.06877700663021497, 0.0339811475526902, 0.07170829651576859, 0.05078409873549977, 0.011642468011667653, 0.02096530797350551, 0.02323644840338778, 0.04793090002250768, 0.04066061836877658, 0.002106944326266286, 0.04349156222756832, 0.041885983664542444, 0.015535374442415853, 0.0178199156653136, 0.04593481963139869, 0.04324207803414714, 0.021281914875632333, 0.006160039741981534, 0.008097121308016922, 0.05584738067080898, 0.06716704221382257, 0.015660188359869345, 0.055599325231366584, 0.040154919899519415, 0.05453860755228708, 0.0752577044430279, 0.020397186744958162, 0.014564684543368078, 0.04435585879330193, 0.019963354983877753, 0.014184558418609444, 0.06236060274644725, 0.04911786516106898, 0.039784834314618385, 0.04085054688696419, 0.02777026207636922, 0.036882207608751716, 0.0585900328963274, 0.0163145758767402, 0.06275427234809726, 0.01574716998279215, 0.05060795596950958, 0.030765075972604177, 0.047030696915763046, 0.08017680863098753, 0.07356241315362916, 0.10432311093374606, 0.05407811210100209, 0.027851976844812595, 0.0065996913772617145, 0.008585962970110198, 0.039275351371015274, 0.0645812503212402, 0.010312808463500153, 0.013466689025893087, 0.026711045929621306, 0.04817679126356398, 0.03000681172125042, 0.017409832629885887, 0.046245862819975427, 0.06047119243791508, 0.03242651383662897, 0.05172398902716176, 0.042843141578017704, 0.023792708675647457, 0.09399603120982648, 0.03911928776952048, 0.05480881059362043, 0.01530685424504261, 0.05335898919691963, 0.06850893714375074, 0.017703646501045556, 0.061183267333094156, 0.0033786735026120783, 0.020592303593612967, 0.025089456128977963, 0.04023461219584269, 0.01693094723797854, 0.027640973247828025, 0.018023225824318586, 0.05168581103545524, 0.024958771105194767, 0.022165618363707777, 0.04980531799036169, 0.0996039480331444, 0.04515219952971224, 0.031338636425413915, 0.018995466093803128, 0.026625037238362338, 0.038008058083153544, 0.1019102787118285, 0.06996743065575439, 0.04989295844889937, 0.037511977847785725, 0.034991774572840625, 0.032801441097211455, 0.03151347109627339, 0.07347543153070635, 0.0024268288876966486, 0.04648356075068155, 0.10426517170403274, 0.032779638234886437, 0.024572350610528263, 0.03504274623288262, 0.038191965150256316, 0.03984791016386401, 0.020365147032744942, 0.0542456325474045, 0.07623161669940719, 0.03620806172670376, 0.021121994021438786, 0.029041219179728822, 0.05116502446452937, 0.07532854459338612, 0.035489953889120976, 0.05638684063488918, 0.01108205745807819, 0.023064130331359567, 0.0139781235784833, 0.047114315412698254, 0.004794168654048155, 0.05139190140330503, 0.04990004476219897, 0.0853993679066339, 0.05675690323715249, 0.07561206607328308, 0.06990134025052672, 0.03715012004719146, 0.04108976167176039, 0.0448544709492595, 0.036289443246900074, 0.05692986290781729, 0.05413755669348663, 0.01969638100314525, 0.03698457610763369, 0.04950358660050458, 0.08570706712142115, 0.03244734376729016, 0.0451123169923742, 0.058631508896547946, 0.06772441714401208, 0.0516855543960006, 0.09754654230369676, 0.029337275773286823, 0.04671796067287365, 0.03356243836723509, 0.01579155328668534, 0.017992304600474816, 0.06294285255153814, 0.05923278832567796, 0.03312388367410148, 0.026514801016498, 0.009350320493291703, 0.08855119152295013, 0.029394598302221107, 0.034661326377141866, 0.013486248208209874, 0.003170546086978228, 0.04500212673578532, 0.07452291121045429, 0.021047369396734624, 0.07897630288836457, 0.028901507724977793, 0.013563939099830967, 0.09451190715715771, 0.025545362713596514, 0.009250057778591591, 0.0013041702468105923, 0.015594036667607726, 0.03213840349006557, 0.04755312674528649, 0.045601736093240405, 0.04058864440829043, 0.0483508809139171, 0.016409421392205744, 0.013826782909041692, 0.015628130453067924, 0.014385051289272886, 0.038566222083905054, 0.04946691014112965, 0.015714786488622907, 0.039571551606059074, 0.060250386745939334, 0.07929980649702972, 0.0542769885261453, 0.04394298719782983, 0.03720620534412804, 0.04891353418990489, 0.02764817064387664, 0.02937261540923388, 0.011287951248607809, 0.014027017225030691, 0.02148916847222755, 0.039370698674071225, 0.060182948025964925, 0.07459483920566498, 0.02142920485517431, 0.05972776922487444, 0.025156498398451556, 0.022044360051832853, 0.035684850487497546, 0.06316427494429293, 0.2438043562635299, 0.15402211507241573, 0.27255290878876565, 0.10350504394380317, 0.12030948899806508, 0.13813786418928256, 0.200469367085926, 0.10204733950236153, 0.13241304234871942, 0.0978488176159801, 0.16856532904409594, 0.16912867946009483, 0.1127329713574821, 0.1186548539948079, 0.08651759580618913, 0.24335219584886106, 0.1344735890386566, 0.13807792547008685, 0.13411296080918084, 0.12577675973936436, 0.2243794002119572, 0.08667105087830175, 0.07200599828314397, 0.12510235721786178, 0.20302134385753065, 0.1391582320173902, 0.14645537271374656, 0.10433960480675583, 0.09806515318491767, 0.15974819329717468, 0.18113307805070955, 0.10705551673327723, 0.0954065369742532, 0.15603804480164282, 0.16120068067985197, 0.11231742994559389, 0.12204494627733385, 0.08461014412704014, 0.11029234546567164, 0.19636422365663514, 0.07569494912581098, 0.13603282311270315, 0.2240262490006224, 0.12117761983385972, 0.12489893023044833, 0.1424222109058211, 0.1270257282040773, 0.10150492626933322, 0.08719502437499263, 0.1599585457194236, 0.18181154083821083, 0.08364835904250223, 0.10563422445087664, 0.07533909362410346, 0.1504519614841669, 0.12245940750524884, 0.06318378720372435, 0.186635565853888, 0.2214529443412058, 0.08167542982846498, 0.09218389619021647, 0.09844910113080856, 0.1373687732003389, 0.1911550862414222, 0.2769931237543783, 0.10713691357523204, 0.17684722980183942, 0.21255068090413848, 0.11796047956111932, 0.22717321561949871, 0.21304755021006833, 0.12807778908961243, 0.0990984755598249, 0.15824839232429383, 0.23004170927789905, 0.169632627418445, 0.09048076782135234, 0.14107158257355615, 0.145441853711682, 0.1579136731884172, 0.23128258785413158, 0.1303792474490981, 0.147762379999603, 0.09045406965719116, 0.07036845470147748, 0.1316512751603319, 0.11383901845904128, 0.2610518452861617, 0.12003496139039917, 0.14642091407891245, 0.11585949875053861, 0.22383242875577944, 0.17478142774874167, 0.1471914912784292, 0.1533868290003269, 0.15152874402701855, 0.1043504985770391, 0.21447255035802243, 0.15399556246496018, 0.1474327476875436, 0.17357735203639155, 0.17974201559780106, 0.0820896459082442, 0.18061435991717925, 0.14414837553856835, 0.11654863314282511, 0.10763882373970364, 0.08983631167680987, 0.16828985914828318, 0.09923018139576721, 0.14322770639292656, 0.14261763993530505, 0.14048874288076355, 0.13186561123978707, 0.19229369207976327, 0.06675432766637494, 0.15455551145057525, 0.0842528713626727, 0.13007488071678147, 0.2500462414877069, 0.12081592674216918, 0.12240820218838992, 0.16656821443428918, 0.17975015145155693, 0.17572469648814973, 0.08690109176020469, 0.24700991328685518, 0.12863193878964072, 0.1269929932670728, 0.15633125729378194, 0.05692112567504087, 0.16063771330781523, 0.15172287070703122, 0.09897257667034866, 0.11512926374111446, 0.14837203276974542, 0.2007090606756749, 0.14792958634995645, 0.19797500012622726, 0.09676177715582233, 0.13115414538450781, 0.08498802465657074, 0.23501954942701325, 0.0971298824034391, 0.09199225163507847, 0.1441324409097433, 0.14184824251119169, 0.2044213695391532, 0.138784212570998, 0.24406438182678916, 0.15947165087826792, 0.11411655679224961, 0.13589054526340577, 0.11850934325447006, 0.14027129648433578, 0.10723170163410325, 0.12162176696884057, 0.09451757620779738, 0.13229367052835803, 0.11256397236138584, 0.08583713352920548, 0.24084701172767148, 0.12989760797110297, 0.1561482848539468, 0.11968053847311005, 0.12434861097004145, 0.09460749960834942, 0.2450045096057077, 0.19402374843916587, 0.13326007512307939, 0.2050679783907629, 0.13206519246582063, 0.11870687902574578, 0.11308711082223924, 0.10773174254403961, 0.1716704979058235], [0.022780386685964563, 0.0181354615356653, 0.018123451192232392, 0.02625729396728979, 0.02873489126232603, 0.02335252413045495, 0.005300870698486125, 0.03431905361433183, 0.024081433807770093, 0.034606045472525784, 0.07830163989696773, 0.017948537997360674, 0.05100804155752544, 0.038481439133324934, 0.019964086597845442, 0.010447398620477368, 0.1064473961389834, 0.029096925263142878, 0.01626795751132792, 0.017893065570763523, 0.019310450804750287, 0.05176593617145574, 0.03963145585129819, 0.040057921676986644, 0.0379341344289001, 0.04911570862356213, 0.11262508319510568, 0.025645025006885973, 0.09385731566937701, 0.04533265537071613, 0.042278822060794606, 0.07030853130404027, 0.053373265245388594, 0.05670057279208014, 0.03267598270829166, 0.04347382729212123, 0.05897690729808904, 0.01704258157030469, 0.05425738050572334, 0.031122733696153572, 0.008985496974820572, 0.040394751385094664, 0.007921728829387575, 0.11293993001022648, 0.026259105765230717, 0.018777303405166156, 0.07191922350396072, 0.032823106063710104, 0.0546382257955209, 0.029586985962645664, 0.020882097418389974, 0.04139653008971964, 0.02287239576089046, 0.01716469790065481, 0.05163307737318739, 0.036502603381391496, 0.036632792363243724, 0.024544474586183508, 0.056411861066496184, 0.048544084457981015, 0.02758486305303391, 0.06055226369250206, 0.04584644755889331, 0.05644002245859273, 0.035742314742697824, 0.04019907720747494, 0.01653473613963973, 0.020577022054743384, 0.058256014730901494, 0.08905523141185123, 0.023225060506393353, 0.015169968697122269, 0.02855524364408226, 0.02637844885729494, 0.04193875180076688, 0.014700417128962376, 0.03899539219996622, 0.05345288859379869, 0.054042006377130754, 0.023300587199628357, 0.09386087797822491, 0.027005221777325197, 0.05259714156930005, 0.03780484176991928, 0.039006990771139824, 0.06578399304060206, 0.0549706504980643, 0.054039976244131406, 0.04231517293280171, 0.019775858794849728, 0.08862705721009163, 0.027252463248348045, 0.011886954438992807, 0.025156655446476033, 0.09639438436997515, 0.09823729314150349, 0.03536733002552102, 0.021515560201219013, 0.048658970833545735, 0.05579202315740048, 0.017466502068864725, 0.07824606021806117, 0.029652942302486593, 0.06193149774785965, 0.04246489715672309, 0.030181315059082645, 0.030187740621547547, 0.029322453887171807, 0.08589887255502325, 0.03826634845726433, 0.050913399055359826, 0.050186075180047945, 0.021746882365175316, 0.013827917676779532, 0.055224800166944345, 0.08675513668887078, 0.010229353717858753, 0.04415674105046257, 0.05011664080103079, 0.04608802572493592, 0.022919266935317748, 0.06223199190571905, 0.02028074138046753, 0.0796417268593946, 0.020348385028961687, 0.09263814802491858, 0.045479533577998804, 0.02733699147469334, 0.02970749159313498, 0.02808776530136745, 0.04498718036038261, 0.013535555542236375, 0.028224349202167605, 0.012967947592598297, 0.03201028869126833, 0.043267458527078556, 0.07642457892577495, 0.011863580138813104, 0.07513093221331797, 0.043887108744632815, 0.044685433648767016, 0.04192967365886416, 0.049185173646096265, 0.0464900303632021, 0.023456953405853243, 0.06192696250734791, 0.028559411162390348, 0.04274502486711548, 0.045289570585854595, 0.013865502907954639, 0.13054338944775443, 0.020879033066692854, 0.03401188300021234, 0.10277202803521387, 0.04149279286784511, 0.04455345585161159, 0.02865693415515125, 0.07204486192354272, 0.04688589863719479, 0.00667677945344739, 0.054156927226652066, 0.01585646008607, 0.011730915735355549, 0.012071104739011537, 0.016726769484399308, 0.08769199327235261, 0.013052875142274125, 0.07118315090455356, 0.05790037756425239, 0.05416738049637887, 0.012353047120174574, 0.05690468159774619, 0.0901421263153034, 0.014980584101360894, 0.0378959602676332, 0.02149790570500397, 0.05644695938474709, 0.13390556548631963, 0.007539291034317426, 0.05168239811375257, 0.03927303395504433, 0.08301621393090294, 0.03575704278304212, 0.02864750935846279, 0.024705996564138803, 0.02980016141889557, 0.012922089569450868, 0.011069465845432735, 0.05102077393882698, 0.0272370457288719, 0.03302489745340521, 0.034784566941520864, 0.03142072274650057, 0.03777372710887463, 0.03927774156533903, 0.008003853454870443, 0.0336941825075736, 0.0543697311302587, 0.023155490146769632, 0.03594958749149115, 0.014780589187848232, 0.06049215260352339, 0.03604978413110779, 0.054125548265273535, 0.11023334137374356, 0.005899730726190273, 0.026350630289544503, 0.06428288205737068, 0.04832754587574352, 0.05432882586554174, 0.015776998573733915, 0.03589840132683035, 0.020814143504286488, 0.04336335741343998, 0.05286199731692191, 0.024257250986392462, 0.02316605832968508, 0.08491886989964594, 0.02429363441713635, 0.06202941910634118, 0.02302839041447207, 0.06426412056410505, 0.04321702312858355, 0.06643918207696368, 0.015879282802944223, 0.022260471540052566, 0.024293199662239324, 0.059993084625250874, 0.03904912943741487, 0.034712600641913956, 0.006365798988319453, 0.055473736607499664, 0.034072051545785326, 0.036662462948551106, 0.061695079183987075, 0.04557432546730965, 0.01797663810242328, 0.010102766306860553, 0.04074598354617915, 0.002277500396068659, 0.06467150313959968, 0.05068476394479794, 0.0895384337092119, 0.017075174781043204, 0.04288679709838283, 0.09238084207379049, 0.02084354212838075, 0.020873963479853926, 0.0035624362100216173, 0.03749897350527106, 0.001495221562612231, 0.0322380064115409, 0.09177111269485566, 0.04564679738494658, 0.029922563116997484, 0.033670200125104, 0.030417440594324184, 0.04159279415504106, 0.04499657642877391, 0.06613574997191468, 0.04581147564514991, 0.059078417778495824, 0.09715747689047168, 0.052516859385275075, 0.011425349117827513, 0.015995137322123255, 0.05941261980502356, 0.024059336001594222, 0.05249437470469744, 0.052260219930641116, 0.010642147746928518, 0.005838669688185497, 0.03993644694527311, 0.022976568396834117, 0.03229859247503262, 0.022898059706353856, 0.02363497500247773, 0.09805722417490137, 0.03766264435985396, 0.019690733019923492, 0.01557724785074712, 0.020452714712929823, 0.01707486260021406, 0.026721181272859537, 0.038636338281174826, 0.08323881609906113, 0.021478833946129008, 0.03497954397912949, 0.037728167860017675, 0.027935093554157405, 0.06646797166115816, 0.04805913931059261, 0.0837093473021542, 0.008628198354985685, 0.028521549181952596, 0.038986566867078506, 0.032113124503784125, 0.045178679358815, 0.01919809634977531, 0.02862003744549809, 0.016990418643540433, 0.07625088381070284, 0.02718981066268058, 0.005314345227464313, 0.014215586894762614, 0.05679723010548661, 0.05115560158306072, 0.052787656144749735, 0.02216550919617857, 0.04642053086671137, 0.0668967280897402, 0.02040282323686106, 0.03967937082052231, 0.034381907298079425, 0.07952273808299534, 0.007294090708807832, 0.039622109578621965, 0.010105350895995095, 0.03479265299956164, 0.009285011497746793, 0.014176084528556995, 0.018182656382240595, 0.017504203170838378, 0.07172760959233969, 0.018852309158612645, 0.03926304033807209, 0.06488637548060187, 0.02466787794424642, 0.05694767828249643, 0.14263657762879325, 0.06588609723915016, 0.05669744332290946, 0.05154354084703711, 0.031873662655632344, 0.053932543904069936, 0.01199224460569601, 0.029178423611747644, 0.03556986069006305, 0.019112503261215264, 0.036116468254476786, 0.02708367109599133, 0.029320412262853597, 0.04440054853236483, 0.04071710969231302, 0.0322988031492118, 0.029817842728187962, 0.011690349464545087, 0.012898266150225556, 0.0670634747873391, 0.037779668120727423, 0.09455667733545266, 0.13334477380398782, 0.19200035701355628, 0.1829464388109984, 0.2224022498534572, 0.21915279599207066, 0.21920038537392694, 0.1269920663006844, 0.09050622492307618, 0.12198411889614598, 0.10183327155367983, 0.10864706439596993, 0.1351680017767414, 0.16067574191237652, 0.19819924938342265, 0.09122760395609564, 0.1265497118114464, 0.07845062101560255, 0.19287352870789268, 0.18599127058780965, 0.13414676060840008, 0.14061127098337298, 0.0905515466846766, 0.1282145357840965, 0.07838937994693557, 0.14563277814417117, 0.19731075593060066, 0.1273578656236491, 0.15019647116141935, 0.15514513868237698, 0.23854908503351674, 0.2476796733155366, 0.0793123473563502, 0.17660727574219628, 0.07874739581658956, 0.2891233293039184, 0.19059905962597942, 0.14761150664379522, 0.15201229872482439, 0.10345307253901997, 0.40575485316015064, 0.10300527882551956, 0.14986155284268243, 0.1174984212904688, 0.10628581287399416, 0.233062899581367, 0.14939574074120293, 0.12882398171049933, 0.14002691443649032, 0.11699094932766692, 0.18562428382856233, 0.09898092702872331, 0.08820170987277262, 0.2273702840771406, 0.15104488289404303, 0.16655355151141846, 0.10864878809379955, 0.23838791545600663, 0.09012850527200969, 0.17941506459347664, 0.2162025147868741, 0.15188482169422413, 0.1490586620545195, 0.11640616377154667, 0.12163590895192278, 0.14426754817606943, 0.14990569482887947, 0.08624192672751604, 0.1585480399549969, 0.12136308205944878, 0.1279649749818829, 0.20122549586719085, 0.07610616980180626, 0.17281892499135387, 0.17083976748249224, 0.23961440690102118, 0.11512554055380245, 0.09905491580045032, 0.3298288902207729, 0.14943168558661016, 0.2079143933951855, 0.0938629157721035, 0.20528309587990085, 0.12636097072954142, 0.12759335339069366, 0.1330636042140184, 0.19291397815029468, 0.1463540039596058, 0.2016840148116312, 0.16404718761482548, 0.11812284423579132, 0.04865218712497623, 0.12199226241078108, 0.2044124369539561, 0.0852849526751426, 0.12867646381979989, 0.1619126215096443, 0.2560060378164053, 0.14307326306739163, 0.13669636250743944, 0.08110270249627291, 0.1570256853536252, 0.11660846460971142, 0.25360367801641265, 0.09448324780791037, 0.14022393692885676, 0.17270352150644028, 0.12346858278878274, 0.101528046802888, 0.14814337084610618, 0.14541804369899536, 0.20417732456999443, 0.0992166139786282, 0.14361438161182788, 0.07090376629944771, 0.12304597804623267, 0.15776970994568643, 0.1290489051250681, 0.1653930815237184, 0.12771056484310858, 0.12586967088282108, 0.1698236591032436, 0.18738748115156928, 0.1170392664930513, 0.11199597179168656, 0.09257745087867783, 0.08879211085337786, 0.20154978088553877, 0.1263955289558057, 0.10275043201662841, 0.20575008775678374, 0.15229953573115412, 0.1913321291607234, 0.257681671289667, 0.06792501726698491, 0.1538733101540035, 0.14634646565443085, 0.12084666218969131, 0.19993569491611374, 0.13275672471331013, 0.21993342426515397, 0.09635265556073959, 0.13736650558008304, 0.06961839333657296, 0.08946444493748489, 0.10017744145326077, 0.09463041329816466, 0.2094930401372333, 0.18352963090423616, 0.19296755833971888, 0.17930303189542987, 0.18650602038589217, 0.17009241806883968, 0.14076991247073298, 0.20302394855647318, 0.22057586559845557, 0.29237819174605034, 0.20214100158022297, 0.1342652590885278, 0.16494357177326757, 0.12702167559895786, 0.10329885137898308, 0.13815359963524726, 0.14776872320761605, 0.1747766933253696, 0.10231978335087338, 0.10109581233512971, 0.14124180731033126, 0.16179876552233774, 0.13837853837157452, 0.13430768503777443, 0.10757308573492112, 0.1187737814841732, 0.1202786386373543, 0.1809410504516094, 0.1434127166266403, 0.16561360759360177, 0.22409430825181548], [0.015179738233376656, 0.05532971590817456, 0.0185736944718707, 0.040608405646297245, 0.052897555287927396, 0.07174485423151525, 0.009909370283205664, 0.03723869513299677, 0.00909079863284264, 0.04025375673307046, 0.047287826666668545, 0.01417766554251073, 0.012491167027262912, 0.03609124480956986, 0.05831181274486646, 0.0427701372292734, 0.014637324042738447, 0.028980236665736285, 0.05172588509477435, 0.05453681107610465, 0.031561912750945456, 0.03543859918511683, 0.039374981105567954, 0.02897636217605924, 0.043263425074157216, 0.10652806519741014, 0.05724068776133561, 0.023162047859401475, 0.02984164316477555, 0.03313111937454632, 0.028009478776385228, 0.02475344038928949, 0.03781914846190522, 0.02360097218995854, 0.009486779904804163, 0.01916542269980475, 0.031708497929597096, 0.016500873138166724, 0.027520929185313084, 0.09592381486248586, 0.046492094970158035, 0.001399200461286631, 0.07823008728483993, 0.019054847484033917, 0.017516745945378658, 0.016003358403160688, 0.019768128967693737, 0.1163514574328738, 0.06188040734418939, 0.030675970370911305, 0.037735196716722944, 0.053184187084796934, 0.07138411874973005, 0.073714834007044, 0.027881886832596316, 0.043128539973329154, 0.029097258511389938, 0.010709510815720405, 0.02474520494410348, 0.04476599162444473, 0.056532761232266505, 0.02754446532156679, 0.05553094805368493, 0.062498414303146066, 0.041288036717883045, 0.05353368788717255, 0.08010888727562082, 0.06342867103916022, 0.02512826039756258, 0.02159322427976276, 0.013712221163234884, 0.021909022959129467, 0.0065191683543455465, 0.0748350767178401, 0.051208821711160486, 0.029817105368560845, 0.06721912087091515, 0.0819101361858268, 0.11592970304791966, 0.0061398164571953885, 0.03295633641462172, 0.05385402755271043, 0.05284083796845329, 0.024978294855945056, 0.016665938272771817, 0.037117109318534215, 0.018497476384284037, 0.034185501506492015, 0.09618253807627386, 0.07661680570773541, 0.07653930059243595, 0.06259322917509465, 0.033889239984414274, 0.06906362310532602, 0.044153044676227916, 0.03832355990344959, 0.05691085626641589, 0.03102882855361508, 0.09276190186820685, 0.018892161052433715, 0.026077908734160087, 0.03593070725459726, 0.07381945097398374, 0.019672220505233255, 0.010943719215931432, 0.03494655240267035, 0.055013294782369375, 0.09701954275970498, 0.07427495919288167, 0.03999888694154159, 0.04893137254722176, 0.05710020638822068, 0.025086985495422157, 0.06989269877874082, 0.027803763101298003, 0.03785568702545378, 0.014943141554061685, 0.04213513460971656, 0.01591524871576938, 0.051429255850492954, 0.055077106076022314, 0.03765717832251422, 0.041462264264062534, 0.04212458174855959, 0.028397538699209694, 0.03061477143708016, 0.05944025259645236, 0.04547395645791004, 0.04075531832753651, 0.025446483745209636, 0.03221386698104682, 0.06874881459460144, 0.05048181576233718, 0.07009444803360008, 0.04573257241938864, 0.0192236338907312, 0.042447675500185265, 0.053010020825651386, 0.1245682024126572, 0.00963190855878976, 0.05039798659122279, 0.043669662348205046, 0.06356142258511917, 0.02259049072651373, 0.015591175329210538, 0.04685593310803656, 0.046160371238065344, 0.051118699127748135, 0.017444542158515226, 0.025348173597106533, 0.07708851668623186, 0.03951676099771454, 0.0489544854198973, 0.03807266227780812, 0.059809468671559333, 0.07934077687922024, 0.024230051034640883, 0.05392264604808823, 0.019513082975942283, 0.043350816554119515, 0.09795113631914701, 0.010585230286984194, 0.011046527257759967, 0.023949241505995877, 0.0420032219300347, 0.008445169416166121, 0.021850583857045542, 0.01973639952108985, 0.017343922255320415, 0.05883086029620421, 0.10633552431940071, 0.013572982767777098, 0.06266311937642675, 0.024673292270651268, 0.08506165336697333, 0.03908325099356232, 0.059100032949279395, 0.07652668312432305, 0.021167200869850574, 0.03404676681384444, 0.06716721075316591, 0.021250486118538726, 0.016474785929125164, 0.014337467653076015, 0.033364105864518115, 0.03303227871055565, 0.015328235759009278, 0.027129898756562222, 0.024561724971018495, 0.07198459378653957, 0.02452095951734772, 0.04580544653318582, 0.022045857753724824, 0.045144063675956386, 0.039160020664454474, 0.049732658381183306, 0.0392801164379043, 0.04496645002115158, 0.050577883188041954, 0.051607853928280455, 0.05202302761796502, 0.03779186041004235, 0.04541541967961577, 0.012548539351912276, 0.01575646167170377, 0.014419340427153775, 0.03912488021136772, 0.03216671426930735, 0.05184876559782894, 0.049728594284745, 0.04341965338455574, 0.0671341540592332, 0.05743035580962897, 0.023071170679383704, 0.02396233777906145, 0.08747791000191243, 0.031089270975621, 0.056282200685311715, 0.015755550027073875, 0.07825405817599067, 0.02990220624562954, 0.028468156684069868, 0.03729799799921532, 0.04388021012287467, 0.06762524706221397, 0.025344053959293712, 0.04367565315577292, 0.035772192171744766, 0.019047816712108832, 0.06428891883021401, 0.01968783337713009, 0.011928948506172146, 0.09881161393657809, 0.03692543028943962, 0.00981712180580343, 0.03619714880422239, 0.038002005988551725, 0.03918831612193777, 0.03453887105288525, 0.055429966173945903, 0.0273421740595011, 0.009251204995258201, 0.07995541688174972, 0.07503953026307207, 0.0552316643147459, 0.04610458854585887, 0.06415634348447766, 0.021618223643951842, 0.040791171242392836, 0.09261605404918233, 0.05537063649465, 0.04035015357658267, 0.01871600104946523, 0.05822747795572204, 0.018173149231100277, 0.04146223362054556, 0.0015462384697222603, 0.001157142173577731, 0.07539581477401719, 0.0141370331966168, 0.10278580995697169, 0.08191465610458006, 0.10545764118433, 0.07094372544557818, 0.08112636695225393, 0.07462486219141753, 0.04030464029300117, 0.014317341565695262, 0.0284921984383536, 0.051750832748028545, 0.059185133826348095, 0.018709789991619128, 0.021634344049098513, 0.0700465751992118, 0.07639019689973324, 0.02115770904046874, 0.048990487721898866, 0.061506395558676416, 0.09124317086271702, 0.08509845623085577, 0.003961594352844142, 0.047429801911235824, 0.0050603344120205415, 0.041563713457435376, 0.02327434485778213, 0.04203706769452941, 0.006297223585387392, 0.053004459027321114, 0.012329616321010456, 0.016223208400450887, 0.038704834202484745, 0.0341994404762743, 0.016803730677272526, 0.03553695338327558, 0.0435240060511616, 0.07572590673883116, 0.011132909416882022, 0.05712025490919909, 0.027797517569495306, 0.029652647358635743, 0.014943119529033861, 0.04405331918068471, 0.007311522560719882, 0.044940609875465595, 0.0391382637674049, 0.05633750457256552, 0.015835575571644212, 0.05814527289100713, 0.06872507352982798, 0.06000511220566208, 0.01919988708029832, 0.02781730562057947, 0.03337100448627626, 0.07216401157840606, 0.07177263257964965, 0.014851482964361147, 0.037126091699446404, 0.024975088777981942, 0.05578962147175785, 0.016801185350144104, 0.044993975560270974, 0.016954012230158817, 0.032007959783978523, 0.030997616216360085, 0.029495057326951818, 0.011379267013962231, 0.05796297077810573, 0.059269683120111306, 0.033236831847217777, 0.040775746062037446, 0.06117623081550964, 0.04684022447514919, 0.04754285733666151, 0.08365872421211774, 0.016654152010056763, 0.06984469570940541, 0.01703845427161263, 0.019151610134529973, 0.05257452282333567, 0.07737896360096432, 0.025017530048987078, 0.035209860652685165, 0.06833975428655263, 0.04045839413940426, 0.025596167749514984, 0.09062398795879657, 0.03842570623683353, 0.030421738347579396, 0.023120311389286673, 0.030553019004723722, 0.13707094885889562, 0.1008283710407634, 0.16488832151216848, 0.111304500831231, 0.10636248295345616, 0.1644678311722894, 0.117067527476578, 0.13785350767354812, 0.1435605103089925, 0.12018651656445958, 0.08187272045160494, 0.09187215203118902, 0.25042818228323616, 0.19410444814110958, 0.13500870145376653, 0.16358834691345692, 0.13759386515425098, 0.21554864342174224, 0.09722840897138081, 0.11506710336693834, 0.10163044211484733, 0.17525687723630862, 0.17075919035461642, 0.11155305805826381, 0.25385005189286125, 0.10796822622538575, 0.15928592052190535, 0.23587310927048807, 0.14737605718114685, 0.07367007148962829, 0.11044984548202447, 0.211131947355405, 0.14979623618625826, 0.0928207910469463, 0.10527835362741064, 0.08464726874785078, 0.09495771670293424, 0.16061413312150588, 0.11616742779170314, 0.09996745675321549, 0.16894448127958084, 0.1304335324394126, 0.11534283373264537, 0.11548965448333372, 0.14409128666645096, 0.2172954617849281, 0.06553664623248963, 0.11627742269587134, 0.12586601664342228, 0.2665770859006913, 0.18509647989225003, 0.15320197198419802, 0.1538460374238991, 0.1481865628832771, 0.18026726080044625, 0.14612600087158142, 0.10058282453927303, 0.15119338137728555, 0.29225282911812106, 0.1248096350219942, 0.0588792885443376, 0.15495162487270372, 0.15303119566411744, 0.14596316122239636, 0.35130892309450334, 0.1269027404487133, 0.12351539076095629, 0.14642423890050382, 0.14292298726016475, 0.15613372918338547, 0.14283793617881116, 0.20948773880879726, 0.07227776797428247, 0.11677629149128353, 0.13355031519407226, 0.2232749772167975, 0.17848927798050065, 0.14980343741274652, 0.10311380284087313, 0.2028338821424592, 0.24078164910597188, 0.126172153038844, 0.15108871844507035, 0.17180387381344073, 0.1688431584907155, 0.07549742101541451, 0.21118854593125083, 0.1525999188062645, 0.26650574779318226, 0.1224600280364675, 0.15778438819031562, 0.18680761387992292, 0.12661259996915056, 0.057184269216151974, 0.1782660706028823, 0.194136455294586, 0.257101436295817, 0.10590157381469205, 0.17699704595631172, 0.22312269425920903, 0.21693212160420036, 0.16321858691592372, 0.11148019543578548, 0.18624542791756893, 0.16891389904964357, 0.11950010944518352, 0.04850022209387633, 0.16941315854989714, 0.19172674105052026, 0.19165698108413529, 0.18001814432922872, 0.15291183916551454, 0.15894320342809926, 0.1951781969757811, 0.11723697080367035, 0.19732128197868026, 0.14241960620687855, 0.13186190337423356, 0.14745082736255663, 0.14834302868093216, 0.12206989010014843, 0.15325356034501908, 0.17130790849126157, 0.08638320866251185, 0.2199420963804568, 0.1214356076032404, 0.11470328821169753, 0.16593041559380872, 0.14731930538771615, 0.16489628882658097, 0.17717865475964162, 0.1440334470281678, 0.09861419307849101, 0.17705722982364316, 0.12775140499035198, 0.17069453253380715, 0.16462929186321076, 0.16652611024197073, 0.08889452914797491, 0.24978990846824264, 0.20460041960881603, 0.0898326114721356, 0.13661861990488347, 0.13985767029225826, 0.1307363516741222, 0.14422778821279927, 0.15724660978922922, 0.13464536127303878, 0.10910965892816744, 0.131848665374902, 0.1706054671517303, 0.14730517872639243, 0.15481624181472486, 0.12609706876138527, 0.07097957069955527, 0.14845875392277397, 0.16031637006709654, 0.14866486221792238, 0.07543015083478344, 0.16825826568228586, 0.09192665918700157, 0.19418545427822298, 0.19571444320101894, 0.10992538168906205, 0.20037826390997057, 0.16524562492005287, 0.10286719913804725, 0.1758594973193061, 0.10414200008756692, 0.07408948164553412, 0.10630634403036487, 0.28107977382117705, 0.1386044730222033, 0.10182354989792071, 0.15469647162864286, 0.13836750670546485, 0.25918804529693823, 0.1980235241353512], [0.008800464716079015, 0.10174642016570415, 0.04224732435578781, 0.05322687733437746, 0.028056997295108535, 0.024952286170915734, 0.08764593606634487, 0.03556736324342989, 0.03700336058353705, 0.07700584813832276, 0.02076043116469537, 0.021153466828588038, 0.07898142801657801, 0.01989983863407566, 0.02442384063596687, 0.046949679287330764, 0.007446014083876846, 0.010101748367531166, 0.020559756348149914, 0.025032215954495535, 0.11936447357818966, 0.02409404361500375, 0.04998988006263972, 0.04130851041765944, 0.06923278297988639, 0.018648707886196433, 0.019831271849632747, 0.06231649140376718, 0.038390044843958276, 0.036557202467754964, 0.04574188421810827, 0.04832400271909372, 0.026917755603790287, 0.03255366527986142, 0.062121246235385064, 0.02797304363470645, 0.06676796403142714, 0.023955797303407907, 0.0576395629304311, 0.04142126323835504, 0.09721074298384691, 0.05822914036651773, 0.09912027842214993, 0.02718760241423884, 0.03849216819470448, 0.013074581285998707, 0.05140958271259743, 0.08668147733495121, 0.02629787364463893, 0.09488348278307146, 0.11305405412830653, 0.03317874706079883, 0.023052056785672907, 0.01919896202912975, 0.05993384304606627, 0.03104428437748744, 0.034442566139923955, 0.08004661198825606, 0.06824387838282893, 0.055537816031926104, 0.04718053605287306, 0.009095511988796776, 0.033329340794514266, 0.045323144389136184, 0.031515250335477536, 0.02055830078109378, 0.045591734815388925, 0.030250383631115964, 0.01063096765128355, 0.033837054075012286, 0.021409495328102383, 0.03174917528315658, 0.05624229899577557, 0.04158190038475779, 0.02555708960449744, 0.057773409982121764, 0.01355252822019881, 0.05936069819595545, 0.024885638436723142, 0.012278113187470985, 0.01710575701098048, 0.017641451652912844, 0.03170094047222407, 0.04497576181987121, 0.039263120777304136, 0.07397376406457155, 0.015981517236439452, 0.020447580008617332, 0.017867355660024672, 0.06389491981075657, 0.020138844659912492, 0.04467145254414889, 0.05940108252088389, 0.0242460182222027, 0.053043257550246296, 0.07757253103679226, 0.056173197865005464, 0.052714199804130106, 0.04135817206735092, 0.03135102981280896, 0.0651855711194296, 0.0429489498116797, 0.06644966215976784, 0.041503487455268065, 0.07229207083582878, 0.0017637558489842643, 0.017185696370659337, 0.013496355780760848, 0.02753823511152258, 0.023098625355370106, 0.07469177997160344, 0.06673326024845724, 0.016400931222784906, 0.01691108257810195, 0.041021717742325804, 0.029647315386682752, 0.033432207250547026, 0.04183544101373803, 0.03963751943721887, 0.029729382555571296, 0.06128476632218208, 0.007208140910558043, 0.008684987495202691, 0.03580380862037982, 0.03098482829368403, 0.060169598943884336, 0.03694242211960016, 0.04453036213113416, 0.021721551667958982, 0.05281737269533258, 0.05895814963526303, 0.005053864799499993, 0.06333882807784023, 0.0387444869134455, 0.04297424220449982, 0.017207112358582598, 0.039403054397553205, 0.07365791367426996, 0.05444032613248114, 0.01590308515475162, 0.02623393211603886, 0.017146719732291756, 0.10963030760326695, 0.035303499579669974, 0.06104287406009051, 0.02398148806194865, 0.0028429618631038937, 0.05164137027496773, 0.018125450681714762, 0.054408521992304636, 0.01614949350515681, 0.024186349549000303, 0.043674140132122466, 0.04260147914230343, 0.07919564918284455, 0.05263795107302647, 0.04991507540727335, 0.03358468173011657, 0.0537645714657922, 0.05846335259716838, 0.030285717521403587, 0.021548011685691534, 0.02902125109798245, 0.020419882099714973, 0.10053840676142324, 0.09029302265374892, 0.047039958918767596, 0.028179037016666228, 0.05025854709768488, 0.11013823921882337, 0.031865492327919895, 0.01863356807359284, 0.03020268891217007, 0.04825782038331513, 0.06478358946380115, 0.062255713818294395, 0.011590816448592852, 0.04805759947386481, 0.0717739655726379, 0.02342821170215405, 0.030591545566435785, 0.07581198437800331, 0.003901661139905393, 0.0662942688852068, 0.02557571894759613, 0.03411995502369058, 0.05563014494856039, 0.03667444839412647, 0.05989165458407614, 0.050647815524209897, 0.021884284064834638, 0.014408423674232779, 0.03819968348609344, 0.0027124369995773683, 0.037087400428830616, 0.04405182147879274, 0.023624745813468774, 0.027851344822275064, 0.048381321417588385, 0.07141490016252765, 0.05732870743339581, 0.02168101412544568, 0.03525507133153658, 0.03535538671478149, 0.07444955063082519, 0.007786451587303272, 0.016642444271353946, 0.05144869916201119, 0.050548247076691165, 0.04744830676504681, 0.017124474454190464, 0.009388440070793995, 0.057629952357421, 0.006651477963333169, 0.020533333975641478, 0.0255214492790401, 0.07256943296881453, 0.10640033535779485, 0.016599250318963202, 0.028755793971340024, 0.02386348753897173, 0.07616159626312795, 0.06570651090794033, 0.07174736699990689, 0.04519807670505778, 0.018526897991016027, 0.07801379002029858, 0.031778397707028255, 0.01594157532728728, 0.02499470062884352, 0.025907117092321, 0.027234192051353957, 0.06601291543413555, 0.044667104995178605, 0.0278411501072227, 0.07370263022641022, 0.03733875004634742, 0.06140776556886493, 0.04640409445029594, 0.08426855318248273, 0.015373763406739361, 0.036021867887147015, 0.03050387829482075, 0.05323124786598548, 0.03657213735183881, 0.034496743877929066, 0.019545955808773156, 0.017495680442680756, 0.0068764042507316325, 0.022229498605273908, 0.04989543674333442, 0.044762004136798844, 0.055801338786559726, 0.04773536757115395, 0.03675001913741712, 0.031032036546798005, 0.029533731360589306, 0.02111523329550701, 0.008285836534454458, 0.031430902139794444, 0.05213387671016878, 0.0394932727419561, 0.021267091074297508, 0.015106824857573357, 0.017980671555344618, 0.04083296899954158, 0.022783577442169193, 0.038215756010744846, 0.06326604206415434, 0.018533147353258346, 0.058175770851272735, 0.0537737530295647, 0.02737838895090165, 0.012493145449327366, 0.03456909705193774, 0.03545234663291805, 0.029826583791404005, 0.033148816005597194, 0.05197722705141191, 0.02529255944424339, 0.05845597134001794, 0.028658485483197917, 0.04911428753046259, 0.04850633547551209, 0.03237988206467802, 0.006879933043232849, 0.15787552200978802, 0.035941156693884445, 0.04295418985308178, 0.03404831048101187, 0.0372799527981589, 0.037011561554766474, 0.006254661176729227, 0.024513566768878413, 0.042605604525775685, 0.02731788332664198, 0.04929065246195082, 0.019347054485772407, 0.05139296243508017, 0.01868400921774728, 0.03281317373377181, 0.008637996619537232, 0.023509323176357056, 0.02540498093191174, 0.03423793256402977, 0.05022372457108671, 0.07751338904903782, 0.05978111575748171, 0.03568354813802627, 0.051258965996244264, 0.024966449221415866, 0.04287160174440473, 0.020900780387643366, 0.059440382831399484, 0.17131176957439992, 0.0444323986378168, 0.04472869463385113, 0.00844168084328093, 0.05403391648865035, 0.06784913625808493, 0.05473223627514897, 0.03538304631928763, 0.061480846526401664, 0.016272450617003827, 0.023825753878261295, 0.03000335283427229, 0.015894071172712552, 0.022248949577671387, 0.01780046660813593, 0.011590166231467119, 0.053340698847727436, 0.0754182075240439, 0.06610540522923393, 0.040021026882553296, 0.027326591831121235, 0.07728482671682874, 0.023178742830491355, 0.08837493767421092, 0.01854547753839964, 0.031157839675283724, 0.0557611919488878, 0.04938955824341505, 0.017796120974385453, 0.07844388710274812, 0.0055675775060550345, 0.054470904531978795, 0.03686040091598707, 0.02052686053268131, 0.05934063052277892, 0.04313067352819828, 0.05653064682959549, 0.07945949752484599, 0.07534588882399183, 0.18482511622771142, 0.0949720808515145, 0.11445245570352963, 0.22422947680517552, 0.20944229447312895, 0.13818808891359838, 0.20444683430175628, 0.09513569424950308, 0.16239156435814597, 0.11438856397064463, 0.17030753555797762, 0.13564332869024048, 0.1568194698061674, 0.12074335523310209, 0.07554199967172838, 0.11623357182308552, 0.08818722315012448, 0.18430592311966806, 0.10551105283441083, 0.2087135456742779, 0.08489702873292469, 0.13842557617012533, 0.1387723841734471, 0.21219284123470708, 0.10827496016938841, 0.17462185163411403, 0.15355870848701847, 0.338327287425918, 0.15215056227339854, 0.1027713155734443, 0.0957721600969953, 0.13442635205724549, 0.10524473768929321, 0.1884173637916965, 0.11320621451182712, 0.22203209149020336, 0.1817702486990921, 0.18523774650548736, 0.15063851921548768, 0.1395015006945018, 0.27893632109607425, 0.1726095684834065, 0.14689063322880577, 0.08650671735766434, 0.1317904426926567, 0.1565518140071823, 0.15238708425914088, 0.11894975954125966, 0.2399086765944958, 0.21059662043567628, 0.1077626848353013, 0.11829483863567153, 0.16494274439830936, 0.21112218739524966, 0.09638925158088246, 0.11263942436104822, 0.12155357748270036, 0.23365493232925094, 0.26608948625864526, 0.1675173820507142, 0.11030523106455804, 0.14166963677252495, 0.1308057745618205, 0.10800132122371467, 0.12474276320708376, 0.15563739613900263, 0.15882237604068172, 0.10588269740823777, 0.14266913636557518, 0.20523006727378215, 0.16851217786390937, 0.12104606721550228, 0.1638063295714317, 0.11671303561137569, 0.1877645802714171, 0.17521953811087917, 0.16663788247012323, 0.11736264752764856, 0.11136512136867932, 0.10848697500243303, 0.1406120064277803, 0.058293411312925245, 0.09808254338079885, 0.1993815835204817, 0.1614637552730499, 0.12212137120866007, 0.08474228663309928, 0.1157408547137053, 0.195587134709762, 0.11315138559908637, 0.08656085679127325, 0.11533136539641889, 0.21971824548898206, 0.16711307148779594, 0.19894413199395905, 0.2243478067459599, 0.20297850422080488, 0.12982581021083942, 0.07426334529994957, 0.22829060082233724, 0.1823279453862098, 0.1807975162181162, 0.10828575434824152, 0.18232068287268763, 0.15378160942946711, 0.1487891829662746, 0.14913712477972432, 0.0911531785142518, 0.11815865884625143, 0.19768561807370957, 0.11051547623449758, 0.17642920626507652, 0.17081422611109673, 0.17241784731947607, 0.2427762662691455, 0.14853971409461192, 0.15475673210476676, 0.1620262170270566, 0.10703780478046787, 0.16139117610310355, 0.17301738772901798, 0.11030120910295557, 0.11349547399027694, 0.1240938331090635, 0.1672204463712631, 0.08186378786640783, 0.10162546254333951, 0.11719487427223114, 0.1010553782144862, 0.21265675343813437, 0.1305364946564359, 0.18684852297507948, 0.11443911811276791, 0.1600032852542016, 0.13287352247824594, 0.1658523971996, 0.12904109102824043, 0.235975397330138, 0.17137786764050686, 0.11630181493538043, 0.08339475329604842, 0.2175797263701116, 0.20399395376443866, 0.17759290914381706, 0.16725678958239096, 0.1421553978035527, 0.1298820410644816, 0.10071794712735761, 0.1821778381183263, 0.13480073922584135, 0.15336070540210894, 0.14570923371901437, 0.120381708106687, 0.1846457444011204, 0.2093362066173746, 0.14058041296178295, 0.15974906663740837, 0.13976998386844514, 0.22152723954810252, 0.08389450309257354, 0.16313390355677376, 0.09516662887988553, 0.16427016516606655, 0.16863712680435952, 0.1814723477488564, 0.10101361876173366, 0.33268213872948005, 0.16543730011870786, 0.2469419612879715, 0.17627180584015387, 0.21139721296006636, 0.14484065855222364, 0.1144510384408697, 0.1572362982457684, 0.11795946066418003], [0.04932577759327908, 0.044895253639908574, 0.012904493487440051, 0.03467835651169862, 0.04866935898579898, 0.01709245580939516, 0.0485783554012737, 0.060035288408999486, 0.04089973739258224, 0.02384128248048646, 0.06550820138786109, 0.05668860266826326, 0.025996199711376143, 0.12201892227054605, 0.009493849938735366, 0.027155991711263216, 0.060256741445271246, 0.06797152646486798, 0.016418744682244236, 0.02685554926433871, 0.017659634749795643, 0.02639478951271984, 0.05781291330593729, 0.032192244149384, 0.03502506109315061, 0.023592213889764204, 0.024720670978328394, 0.03886852420926575, 0.11257440647891453, 0.08481059869330737, 0.03834738140745509, 0.03952087488986793, 0.034173826326525984, 0.015480120350877124, 0.03246824647630415, 0.03373642459571843, 0.033286926336586475, 0.04411772419247897, 0.020541963956108498, 0.038951977997297244, 0.07724583284148286, 0.0545177776216259, 0.030663375885436134, 0.05661028933020369, 0.09743756629646787, 0.09052637303548475, 0.0167529333022333, 0.01664430969544957, 0.01978417276404798, 0.02259040262640244, 0.03317326187126098, 0.02783024484562057, 0.03171916187350308, 0.0649345241066429, 0.035312799887070735, 0.08030650731656822, 0.01595874431528031, 0.03216189557626363, 0.07736767146496043, 0.02561890523910763, 0.09623251765245393, 0.03360650757507932, 0.04535011451451048, 0.018592360204145796, 0.06453959045991783, 0.04501695053712015, 0.03657796728094259, 0.03946822549727175, 0.01631731655628931, 0.020145542183590513, 0.021907682305261977, 0.0906807091087103, 0.06237226643509442, 0.03967113920577592, 0.027319919205300754, 0.040618851255144806, 0.04689297728961514, 0.06914940197020769, 0.04185720557166685, 0.040599070864939885, 0.0974595683416532, 0.05756546307595507, 0.06993642707745876, 0.03955367111390637, 0.0952944812935687, 0.02972225602265568, 0.029310351613187985, 0.006873097623728457, 0.03687311414509051, 0.09021272897840509, 0.055950289261677576, 0.034164920554406224, 0.037050620547585914, 0.03883326118211112, 0.0780927736852919, 0.027198141868857127, 0.03365192892810991, 0.013788374133347986, 0.011445577669468139, 0.04107279282423758, 0.04270367144096283, 0.06222241580666554, 0.09423230038655382, 0.025593886722720442, 0.026106675335716818, 0.033418678137804234, 0.01722869305540958, 0.04450556769546482, 0.020792254457069982, 0.027937631220406586, 0.02600716626001222, 0.045873383210311015, 0.007930282201062167, 0.04658418256909617, 0.012462849544751789, 0.021208437467594782, 0.07401979062706232, 0.0753557253929396, 0.03351201829049857, 0.018407830690604546, 0.008268974939241044, 0.036879564605412946, 0.03775851260269842, 0.07213130728491852, 0.0869306244496857, 0.04948734936694946, 0.023655144182304223, 0.031634932421448256, 0.036508471614891486, 0.008763319027850465, 0.026720853770271908, 0.02846286110129328, 0.03737394029514925, 0.04696839864576056, 0.023646006668587367, 0.05865573642715331, 0.05435231412130018, 0.033865927928878416, 0.049915450790356246, 0.12402380501190502, 0.039330548005959684, 0.00376035358884462, 0.06572892664060478, 0.057292352730949084, 0.089152624169665, 0.028488473335821784, 0.06133601760431644, 0.05212892778217793, 0.017451448441152612, 0.08102447725832462, 0.011707716677788527, 0.06594153902223034, 0.029051779701765028, 0.04841735819354654, 0.01855479891321832, 0.04380583830718552, 0.013934514981003539, 0.022355058500843666, 0.015463078725001505, 0.05938974441960455, 0.015499173915163885, 0.09338716751024609, 0.014456294593401255, 0.02697100446018721, 0.02375425680750801, 0.04487998933801728, 0.062024592752418214, 0.0628845187865438, 0.10696332571246933, 0.07823689780648678, 0.027559794740931644, 0.0361728293430661, 0.03514113490499797, 0.04328260408534158, 0.019902403113402186, 0.11971121263359824, 0.012966390518892198, 0.0446304515184414, 0.028710993149528102, 0.1422741414318162, 0.03998373372239932, 0.04741480190967841, 0.026885899752678893, 0.05090008444723584, 0.05638119839732686, 0.040724559897376646, 0.013213016246745904, 0.02387555725421877, 0.05408553932342799, 0.055660623756627885, 0.12291234166872118, 0.04492880829099206, 0.06824400095689682, 0.024688326746165275, 0.05200158864740403, 0.04247922300090713, 0.014873043551380116, 0.04627654847178248, 0.05319116614578713, 0.04062558133755961, 0.028606060171319593, 0.04470274723585575, 0.022405128092354825, 0.031581398197299534, 0.030572115661456224, 0.02055797136328634, 0.022194806313622865, 0.07216714487801637, 0.08445325698102675, 0.03215660190870685, 0.06348435030949694, 0.05107598206509025, 0.05902452732346231, 0.009759280252300445, 0.021171349235960556, 0.05547949758869025, 0.06635240729778044, 0.046722403982834476, 0.026113384350713705, 0.05931034706713212, 0.035431336671594656, 0.05056441153189348, 0.031998127045470386, 0.03251840608314641, 0.016900744221563783, 0.02174634801884813, 0.04100802392067929, 0.0066778151085600266, 0.049247483407417615, 0.06089205816087704, 0.06791537988089746, 0.07773745444513137, 0.031935156533314336, 0.037270166024926214, 0.07479098835779775, 0.04309155324834489, 0.04833081707118019, 0.0580308499986366, 0.040103044255726764, 0.027454854101843895, 0.05343341080832386, 0.05391773925493321, 0.028671694754232323, 0.12741059545547734, 0.037359909394816045, 0.060340651055617686, 0.047943594099413005, 0.018910865089105024, 0.04852989267918372, 0.05079430302665119, 0.030436970090733904, 0.058204774940085996, 0.00659579438375189, 0.06009820337978102, 0.02785774740210224, 0.04712386852911404, 0.04289577947929502, 0.07792542943911207, 0.06821359492718213, 0.012071299133822324, 0.058248560695398244, 0.0200944249668429, 0.07398473444364725, 0.04759500877210691, 0.01000107866862128, 0.09902446380546016, 0.0800446508031699, 0.0054568897711203225, 0.011371616668428385, 0.0239628299905528, 0.03141848960020129, 0.017475687463076848, 0.021463554322479234, 0.03364585768130999, 0.03613923255714678, 0.04089023407188155, 0.04172974386282506, 0.02224636211570713, 0.026552163124565157, 0.0434030024635215, 0.011104708762779351, 0.03297438161567815, 0.02468282815008875, 0.014882117862843219, 0.0755430951774601, 0.026307781076719685, 0.04849017868118902, 0.06195145816872678, 0.05580269093174608, 0.027249856634185683, 0.021859780742576527, 0.028798622116746924, 0.028364958895009854, 0.028672876444855527, 0.02368605008438951, 0.07354654747271731, 0.022351907964255062, 0.006855534100454422, 0.041405052817877264, 0.06666615094629026, 0.00853538393012939, 0.07182061266634734, 0.008653347106320004, 0.048248634989103006, 0.044821601946868246, 0.05438764992680761, 0.03502675031702365, 0.029622339005131396, 0.057198610382094506, 0.030662785997734438, 0.03667654364459938, 0.016551643700128602, 0.005859866862245385, 0.032583837652759205, 0.06290914085243018, 0.019474633023022644, 0.02816440856775209, 0.0182977189580279, 0.042778613992155566, 0.0483259332606629, 0.04184088406844005, 0.0169862779383097, 0.03154702191691726, 0.018500902712525382, 0.0714467694201777, 0.018128267970056306, 0.003565751694916417, 0.0549411024868248, 0.04311409155507723, 0.028601063362833475, 0.030971071269783764, 0.01802096969538158, 0.008653618109923218, 0.05478559046863549, 0.021235654656324657, 0.053809824279479446, 0.012471554218791427, 0.042119755394636624, 0.028750121090260726, 0.03853757422597658, 0.011626599457926087, 0.04496060860072894, 0.0438758127781893, 0.035843641362002784, 0.027672225804699045, 0.024646735832756086, 0.0037137890889895183, 0.015212074804660535, 0.06329821392653451, 0.011277836015177591, 0.02808555130726628, 0.051449898089612686, 0.19211055110058478, 0.09923978047745843, 0.16568574243255202, 0.2233593234972608, 0.23854770607525305, 0.22952308307491967, 0.11746290545429915, 0.1620754305153124, 0.16224845913389038, 0.11549029799719011, 0.17132050297673673, 0.10008932602021003, 0.17893406862933792, 0.1285158228429575, 0.20438019997410237, 0.1068930754498128, 0.1683275200306408, 0.1381870010687459, 0.15243205362029616, 0.1473892951804784, 0.08294198001104017, 0.1828714847684868, 0.15252992901350224, 0.14510048493262262, 0.10271273282987457, 0.12989082043209385, 0.1275597068090593, 0.12470358547063605, 0.16997971121341954, 0.10191005654633047, 0.1509170228194806, 0.1971975128136335, 0.168966130924321, 0.08233387473850481, 0.11031546599922643, 0.11794004033529952, 0.10748588194650029, 0.1620192149834287, 0.1788503045756971, 0.20162775331447202, 0.20777347918239333, 0.1053654348417636, 0.0985405260636922, 0.15405744704748356, 0.17589743399331648, 0.2784589257451796, 0.11998955535912707, 0.10875600975968185, 0.126725283841933, 0.10043525302241887, 0.14639373327935898, 0.11624910808618992, 0.10928135455375719, 0.1584555118555023, 0.15374279941522306, 0.12290491061585566, 0.09628829651422079, 0.08074269479801578, 0.14651566383338746, 0.1573934535225553, 0.23505109692773513, 0.13143032008121092, 0.07391943310898158, 0.08680212852214614, 0.15970809625521784, 0.1305625876111369, 0.13957116873033587, 0.28124770029417934, 0.09021529537295142, 0.06714854885133044, 0.21934966526685223, 0.1529591680774766, 0.1968965475117007, 0.17233514046717077, 0.0890629765607657, 0.12797032993647361, 0.08960389592234166, 0.17142364905486185, 0.14343312520894314, 0.14089751207540113, 0.14468725710626573, 0.19475675668687592, 0.12817723496306327, 0.10795242183150784, 0.1911318431337995, 0.11943702976549826, 0.12103367957376665, 0.1940293562027716, 0.10014188731269491, 0.18481224595058351, 0.17019116680227941, 0.1677905843262711, 0.07775743401819661, 0.12157532671887068, 0.2675125098997547, 0.12672840948066405, 0.14742186923901882, 0.15321976054579983, 0.11419851287838914, 0.19757605217877897, 0.16101545594151945, 0.1205854491901494, 0.15219577678268956, 0.1620401598272785, 0.11041793025909893, 0.09176715202028714, 0.11669398300469884, 0.16945081943225476, 0.1822809995182099, 0.23996876853127636, 0.111607143865718, 0.1424230689242963, 0.1209762919273588, 0.1421240954509666, 0.13286702605264802, 0.06643971067763145, 0.15416846850947027, 0.18966513715924757, 0.1043554934703054, 0.18322500370202527, 0.1002326074446882, 0.12401102666532803, 0.1756960754432986, 0.12097131235585099, 0.1447984624293543, 0.09148522400327268, 0.11548138839463074, 0.1962058273174109, 0.10029397874830231, 0.14925050579251783, 0.15109002079454162, 0.09044855382413634, 0.1436910363695314, 0.10565366776239489, 0.11924104149182958, 0.14641994880812784, 0.10343130798109117, 0.1167998563558344, 0.14408250729883873, 0.22125248977493858, 0.1504903731326903, 0.09209027258499015, 0.1047750951481923, 0.22904564175874959, 0.2376834210008383, 0.1388959847991505, 0.2005097245977771, 0.1601823659673814, 0.1536938157533446, 0.138944968461029, 0.13476960541259858, 0.10832611952097186, 0.1953049845272495, 0.12927799605794493, 0.1056265405889961, 0.15363403025173372, 0.1439844633662893, 0.16833066099113034, 0.12133087572311202, 0.1543216707725679, 0.0888464724524848, 0.22176373089032791, 0.09714508924873606, 0.11008390060235416, 0.0721715345618225, 0.17891248027163167, 0.22084197389983365, 0.21922637107631854, 0.17568049321491874, 0.20733717678775712, 0.11112205699206361, 0.22903445687505508, 0.14769356998224414, 0.1150046901837472, 0.09877568441292933, 0.23443674037773765], [0.05065194856856139, 0.08209135428431534, 0.0067643974081523, 0.07619663712478454, 0.0740526098337385, 0.06821252240408814, 0.055346240424701286, 0.04975281415447112, 0.06271847688983526, 0.02272380726231683, 0.026609160066131624, 0.0433603351965787, 0.04309790411723718, 0.022774874683349364, 0.03122879665405039, 0.011683797497572678, 0.0412962261977936, 0.02500957997155286, 0.014223450787305353, 0.04326199248973881, 0.05007820616986963, 0.02523333510203708, 0.10130926741347199, 0.01992483608304493, 0.046861046744931134, 0.02949290270466478, 0.04642893102080111, 0.0718104390187129, 0.08102483731964905, 0.10693804481096807, 0.027023002678047747, 0.039768474506995374, 0.07899971453533058, 0.008510424785556333, 0.0556000070496192, 0.013775642709656349, 0.016821814182725166, 0.004989003965390786, 0.04433633121211202, 0.11140377816533852, 0.03859641743944057, 0.021244663850314194, 0.09609441498234388, 0.05680441217977674, 0.04709435116139151, 0.017787412469906193, 0.015649205531864878, 0.015785558648677846, 0.1135854356952252, 0.023028648969146515, 0.014300271211522482, 0.05812157013062989, 0.1501293312157354, 0.014128072840732434, 0.006840189359331083, 0.023010216893688328, 0.06539769320478363, 0.03944153882442944, 0.03339074657208497, 0.05693679983397165, 0.013731704694369148, 0.04127893559334259, 0.0948412330340474, 0.08305002905188069, 0.021854479414140506, 0.03429872164082143, 0.03154645309663348, 0.048115029255108493, 0.047296793725822246, 0.02326332085255173, 0.011145524012165205, 0.04730879832359572, 0.034303682060131145, 0.02893392282027391, 0.016503523802384734, 0.0418348434651571, 0.014710596522256253, 0.03940644433661815, 0.07824000812345937, 0.0591052768211211, 0.04944162157874915, 0.0630643502658894, 0.09802897085225391, 0.0481603816602259, 0.007340367207483899, 0.05750521026071041, 0.06501353075427395, 0.023034710639847383, 0.022180298523556803, 0.10238081757580081, 0.01147763557626956, 0.02892802202803714, 0.011046361591246341, 0.033713487923265464, 0.018113675910318573, 0.036229592627815665, 0.12228775784493455, 0.011771955065459255, 0.03411397570744157, 0.038911700924678196, 0.07278212195923252, 0.03593908442604927, 0.0574323131642755, 0.028722593635921518, 0.036467336523797245, 0.03720288052253666, 0.014820171035675993, 0.06796791052986538, 0.08134821835424631, 0.0173057442636139, 0.026491354895575393, 0.038897873037644935, 0.048671431253634156, 0.01000468885796445, 0.033124163296193845, 0.02934152947648639, 0.06324040876220792, 0.056950918834416143, 0.04981879347694978, 0.04053005017340183, 0.09119336748675955, 0.02148105560110942, 0.09535488732639821, 0.045919589803463993, 0.027164807468051874, 0.048724379420520804, 0.034113033419294704, 0.06223669568557413, 0.03536771689992278, 0.0600448836602511, 0.031206989961285746, 0.011741003198098513, 0.019713824825181116, 0.052544990133854656, 0.015626845340574944, 0.09543566363713435, 0.024831682864216068, 0.03945356640484064, 0.008727237244226761, 0.07399713740714135, 0.043826200924212896, 0.04024781189077804, 0.061377190999806895, 0.07317781403300262, 0.05680512464154632, 0.028606355115170443, 0.017979047448945143, 0.019627639933699564, 0.06111862866448299, 0.05942145662923014, 0.0221814074358272, 0.0221793313375524, 0.07278128692339506, 0.030239869074355212, 0.031016804803643497, 0.020283598888425097, 0.03825096924218439, 0.05017187957081103, 0.0469354760172146, 0.060846226950806964, 0.04320168987877908, 0.04736473423338706, 0.02513456530117941, 0.03470291346011143, 0.010172424766595566, 0.05645852348196411, 0.03351684847486115, 0.07319436153216709, 0.03828620545626168, 0.037365199231933204, 0.08263118580103883, 0.0364493947446106, 0.025104678296033415, 0.02245369998197402, 0.021346252854733218, 0.018887577931426706, 0.11252726908893355, 0.026472968785392664, 0.0698342769136352, 0.062341580783287366, 0.15580241147789264, 0.01092340735222904, 0.09001246593411892, 0.011684566458326676, 0.04149880665805071, 0.032181955588560913, 0.04001771355228078, 0.003176188085138077, 0.07656082000222898, 0.030963554032026764, 0.022424303273099567, 0.01842049029355328, 0.03907038837731366, 0.031429065443995985, 0.07974019214030235, 0.03281689692108381, 0.025180118804376934, 0.018656006788895018, 0.01319411398482419, 0.018166501503137332, 0.06832768840174522, 0.09127898547317713, 0.0561303927022363, 0.03180576236768356, 0.05172568208147442, 0.021098727931178386, 0.007895853252135097, 0.033423512152606444, 0.05849595346878614, 0.03737532308385257, 0.06661903653894702, 0.013158723595552148, 0.029408035484412988, 0.046493841650625395, 0.029715165878916462, 0.09942049295791697, 0.04355659160102087, 0.012260051707046167, 0.09304492539095302, 0.04072681602631365, 0.04534235404383752, 0.04518735913499709, 0.07590442054694699, 0.010630729206417118, 0.14562937671378737, 0.0474181114095113, 0.012085689137870026, 0.06444163079704009, 0.06357225123792887, 0.033444227170078986, 0.04222975029880482, 0.01744073661675136, 0.011042652768082918, 0.05584169629841082, 0.04488030343406624, 0.016197613402900678, 0.03593263779616645, 0.08384952607053904, 0.009739330365142275, 0.005813958085772972, 0.06310631273194187, 0.06768650345263943, 0.04428328728423484, 0.08360217160154736, 0.07945362163046676, 0.013772388751197968, 0.0366134601344745, 0.03083486658250613, 0.01457881311991162, 0.11263986103116505, 0.02156730944050416, 0.03436098926730695, 0.04006598092195007, 0.05901877783359059, 0.04431903294678177, 0.017101175805193283, 0.04363509263062189, 0.038068127037296375, 0.022576934800693588, 0.07132849310554805, 0.14121530066815116, 0.03781374754203904, 0.08883766244135557, 0.02360357305846147, 0.021528374936972416, 0.08318810107847376, 0.045567587724015604, 0.06144827629830088, 0.03535072123932262, 0.04331222104449426, 0.04010024803480314, 0.0557992933318019, 0.046364725191867164, 0.017516083279324156, 0.020725049393912478, 0.022081915597100894, 0.023860164632600163, 0.05602533140430047, 0.10016718353595465, 0.02895132642269375, 0.007500113297869722, 0.07235718064851339, 0.037242230628767324, 0.05758143600917632, 0.015941529362011823, 0.05918570456185168, 0.023665340812576395, 0.07485347814978131, 0.029566401180120248, 0.012611918763497905, 0.08317854796205798, 0.042151613160967834, 0.011597357881856302, 0.05338744553286703, 0.01531569202685909, 0.03680473696740885, 0.024163952968533964, 0.06313288066115591, 0.09389100821628686, 0.029929934798048872, 0.07715735734710771, 0.04420384779692658, 0.10968145929397115, 0.028337349086218787, 0.04118838783113226, 0.044580529398855664, 0.03520709890571814, 0.048143313221272924, 0.05773472637238522, 0.03414451197210339, 0.07845459701192957, 0.02985459771157513, 0.04504638746561063, 0.03390103390800857, 0.07190465251164091, 0.03271183945358761, 0.044752822573026346, 0.07078488477535787, 0.04467771531292989, 0.05592781607241881, 0.04728816757579485, 0.0162977161967466, 0.011975088066631749, 0.0226097789052273, 0.10379655572075037, 0.04945943312298867, 0.005748872213336009, 0.019089612554037766, 0.04465093287909704, 0.09195279044609878, 0.03439812920987606, 0.016851063419674194, 0.010266577930099541, 0.008044410628386804, 0.017096676953857946, 0.051344312021448735, 0.08714371946670356, 0.02181496651422593, 0.027196213242507754, 0.03879608676558541, 0.04324233467360178, 0.06324781683243572, 0.037605436744108316, 0.013719544006181101, 0.03659646830431396, 0.032161914728461735, 0.08212453355231593, 0.07322037787807566, 0.02524216043492479, 0.07272046720308643, 0.0521516882544083, 0.006981105487343045, 0.1526721149322487, 0.17152498716548567, 0.1459421704132711, 0.1354743450159027, 0.281307669656892, 0.13264266954314324, 0.17109394013401003, 0.1379306220840062, 0.25483681910461, 0.10359331259443876, 0.13534041752497997, 0.10705714083967671, 0.2307237113916105, 0.19058785942052642, 0.08915928147372701, 0.10274360617322308, 0.11799500714386664, 0.10779095347970725, 0.23278752161610514, 0.1252592520247544, 0.2033995767875064, 0.13211540186837797, 0.21555451165524223, 0.07180640939623117, 0.1059888848554223, 0.14188809440501277, 0.12409547253722146, 0.18618824711490065, 0.15204640495921337, 0.17704970684022675, 0.0839277130040911, 0.17999670918910735, 0.12973927291891268, 0.07216149881001442, 0.22136772472050883, 0.1121660203282391, 0.1008359782938515, 0.14327071456899568, 0.13446208239803392, 0.25474640540778637, 0.11469059413479221, 0.08666617089822408, 0.23279473816435184, 0.20284138980411714, 0.12214623076180298, 0.08068755945010532, 0.13477944198154634, 0.11025934239789364, 0.22561609594812318, 0.10231953054185837, 0.16298238668710957, 0.19883648131883916, 0.24102999948926512, 0.1489104853282052, 0.1875502748354789, 0.06916375845790872, 0.13663813982519413, 0.17642761280219402, 0.11838640912526077, 0.10054494149141735, 0.11659993805111417, 0.2407236868936208, 0.12898700522078624, 0.17019876639448828, 0.19811968349160688, 0.1196497800429502, 0.08390086928322431, 0.22113560007945185, 0.11492684032888183, 0.12949070803100063, 0.14464542870560002, 0.10931293269799602, 0.1432193560345519, 0.25589150767172536, 0.09559269633985336, 0.18351515184246725, 0.13153182673117808, 0.10081396092690768, 0.13477001910007771, 0.14385525497698015, 0.19110028031131915, 0.13853230753973608, 0.1878459234872172, 0.21024644164548767, 0.2256964585713802, 0.15122215563972152, 0.11862850057021265, 0.06296501547518758, 0.13616527971481124, 0.18150404846716314, 0.1452842694256575, 0.14040671018583162, 0.1419377522242646, 0.13358256749568448, 0.11501794350483727, 0.13459351244232348, 0.21676322986041346, 0.18917568358442477, 0.08101716111864775, 0.1830967912270177, 0.14831788567525728, 0.11294521601690401, 0.1885761125313659, 0.13608836448721348, 0.21563242279714157, 0.16551321943200406, 0.10565793487213312, 0.1301187315895673, 0.12464812070491815, 0.11646378124433181, 0.1384378335769138, 0.20137560313507435, 0.1440554797168701, 0.1231565704989818, 0.12003554361722163, 0.1163726474248594, 0.13130520260141743, 0.14221924357116222, 0.13647113265770097, 0.0849506319049866, 0.12682337373975786, 0.1020621709645756, 0.2934069865413251, 0.12128317142806708, 0.061644004102075295, 0.16515830621844338, 0.2089026314957488, 0.11728672821435238, 0.13212179104166646, 0.2005111188777993, 0.09583495632414857, 0.2515108024160708, 0.2730872091506758, 0.21329879640571534, 0.21328390365646732, 0.12157532671887068, 0.09462062269449235, 0.1399009849034971, 0.17163191771795674, 0.14409877900635043, 0.12557435164889022, 0.20196614967238521, 0.1683514832609123, 0.16529013462845357, 0.14650895290317076, 0.08840876811694715, 0.0733877604286517, 0.09176565814883479, 0.1699201095729105, 0.2008261648757804, 0.09962533720799031, 0.18169621396208965, 0.13762772624050418, 0.18481460550139028, 0.12330468593826219, 0.09428221867569993, 0.09858293669118036, 0.11969671825007086, 0.1382446262024103, 0.16747592137225215, 0.1714126480322692, 0.2670847264028365, 0.0844275317485294, 0.13425120903599647, 0.22887310343644313, 0.16312166147174376, 0.13641352284579508, 0.1770563564834095, 0.11916911349661889, 0.15331161448792105, 0.16676151373934361, 0.1512602914965922, 0.16028348957338642, 0.30248166572663093, 0.11305620683537376, 0.10300511028617622], [0.031361394982424476, 0.11277292284273333, 0.038695116377165245, 0.02985090708299991, 0.11197374758100319, 0.07439279883739448, 0.04576760562016599, 0.02392063003724381, 0.024064535823380275, 0.09044015750048623, 0.011081129534079904, 0.006311401957646013, 0.025889056569506085, 0.031184568482961868, 0.006628330616701034, 0.06489788212122456, 0.03257931007312671, 0.04969059249326106, 0.04495360655710102, 0.04676306026897604, 0.026629622274589156, 0.0613244841506164, 0.023616468233446923, 0.030198193891274355, 0.040064609624565616, 0.017350964518564365, 0.030742348059110587, 0.00988216554340456, 0.013930401088850153, 0.0280879893820853, 0.06601011921321193, 0.05550261429180542, 0.03678961056134394, 0.04313836122051843, 0.01636164048836837, 0.030684761229842424, 0.05815981707024959, 0.04008100007570559, 0.03830045086121367, 0.041455744855826905, 0.0656096620725528, 0.06702117141216032, 0.033952128142118454, 0.015358654237652739, 0.01708890882230574, 0.023474657697783365, 0.016203801478109053, 0.020464711649824056, 0.03671981995144198, 0.07687865456025447, 0.019983662059530616, 0.06673248649965371, 0.017161397976920973, 0.09563223413762548, 0.08047819528127871, 0.0486065972326023, 0.022545375808652852, 0.007903373362721816, 0.03983292548406509, 0.01462871800251906, 0.026739745498484662, 0.027813431130902424, 0.01900366706503255, 0.031002023137144508, 0.07006453996103618, 0.04963287159860615, 0.05498097353284398, 0.05400689273712136, 0.025805729185982097, 0.04075444498730283, 0.03470272193813036, 0.04471880060830905, 0.04073106398385379, 0.053272685561809814, 0.012349800822595436, 0.059234060031632264, 0.0312052988221929, 0.07161166984587908, 0.025633968442918795, 0.04656003930816247, 0.07640845277496884, 0.0781177941168989, 0.0369433414251093, 0.053036508315633384, 0.07547524277000658, 0.004988010445113985, 0.04106173051461097, 0.023349256765457894, 0.006264238233392638, 0.0049244141348847945, 0.03805035762789269, 0.11759533141289027, 0.04923886108782984, 0.011172424232016408, 0.0032495426797052667, 0.03465938051381419, 0.060813518826879805, 0.04545291585306968, 0.02882884045492017, 0.034544597560119246, 0.012553634794218647, 0.04499780599989238, 0.012664630400737929, 0.0462652410140201, 0.07867014351030512, 0.05769089465179752, 0.029399828767524134, 0.030011946425562906, 0.05117163197287629, 0.015177620000266021, 0.04683237590436493, 0.004073434571299943, 0.03420205666653572, 0.0336147545115842, 0.124543679938201, 0.017180255231177135, 0.03368694297668915, 0.032578053688930894, 0.020979765967856494, 0.01057899050084093, 0.09372947091657309, 0.0699653392357211, 0.054746067992621855, 0.04907285366507788, 0.08594466929113673, 0.039376222168005286, 0.037741015154507854, 0.05096537046014302, 0.032262207129068916, 0.03344206680213252, 0.07487485966374798, 0.04819523099990142, 0.0825586449354887, 0.03697085930334945, 0.030665080431067658, 0.030098876337550824, 0.04672480183803747, 0.04270845182961033, 0.019945930314039993, 0.03978726664377798, 0.04674455158472542, 0.04009929425533741, 0.015046912951455002, 0.04607174635654496, 0.06351356507248937, 0.050317505224337505, 0.032947794534265995, 0.07013800013209544, 0.012937141281943168, 0.04000939766786272, 0.024948850266575336, 0.05321468887550216, 0.030710053622662544, 0.07697228582636004, 0.010602162745330605, 0.049087574044542934, 0.008651795778273335, 0.02067620937351979, 0.07903401995257986, 0.04584621773251603, 0.057328987055488174, 0.051857931839842955, 0.04275995975119933, 0.025851307587037166, 0.025695943040773276, 0.022179540096511765, 0.06406136390362537, 0.08409534836368215, 0.02761850580422869, 0.087699830351818, 0.05688200922562711, 0.049482925209186734, 0.01218351282014121, 0.010135470600348088, 0.022333270960277127, 0.054335119277839704, 0.03754484301973735, 0.028618850009215456, 0.11050809880778675, 0.07608602168939768, 0.05805449147197989, 0.02769679232921091, 0.06486114054437607, 0.034590444091947815, 0.010161560682219364, 0.04797923634009016, 0.07288441001888245, 0.008268584234399662, 0.013280498059166056, 0.04278737037713009, 0.009195046919968822, 0.019410168639414253, 0.0364253778881844, 0.05810383902562242, 0.03355713703879907, 0.0873494217352521, 0.08236736044167511, 0.10398790916247715, 0.03684330183351713, 0.030772742597506415, 0.01870289136986098, 0.07338470373783382, 0.02947135073613496, 0.026693918118854205, 0.03209580134059633, 0.012640350201587765, 0.013229614499235346, 0.06602983065550366, 0.08582738122992939, 0.047490878270999085, 0.029873104480605935, 0.041248414650439255, 0.005258524709666569, 0.05278953306016423, 0.02589384653425265, 0.055315658194764014, 0.10575905847813814, 0.043184131143554565, 0.07137304877922421, 0.045084056008847496, 0.07210202740445253, 0.0069709605680057605, 0.05806885179012053, 0.07844682121949811, 0.001598484469145807, 0.011390411678040701, 0.08231485277534493, 0.10466202823144775, 0.0506689710422389, 0.05257168063713659, 0.020607594708581606, 0.05484297045416409, 0.030250875842607314, 0.018046947736893932, 0.03205229712259625, 0.021142860341276375, 0.020480190456334143, 0.014973291901931649, 0.032968838969545985, 0.016175942690742594, 0.033285409482496406, 0.03960795227378126, 0.029602141097007744, 0.06490525188705613, 0.006458128862563642, 0.07016659053342958, 0.04899164834510415, 0.022429782716977983, 0.014225433039809427, 0.09485093170716878, 0.028445080200570728, 0.033190847419562845, 0.006442173645125643, 0.0006562620981111972, 0.018230973547624967, 0.04810980836590452, 0.005233426232852283, 0.06803027774778105, 0.054667176258179455, 0.08974713138154439, 0.04182313381123447, 0.010014012148002944, 0.014114227716720874, 0.03059382467801052, 0.0560752343716881, 0.05309825500233039, 0.021242346434343248, 0.038681303811890465, 0.018017807667474114, 0.013781422843045045, 0.06499043320335689, 0.06288620417997723, 0.08047686994916971, 0.04410158271991438, 0.08257307037110291, 0.058055667416943665, 0.013467161127576425, 0.007378545199190417, 0.05240869926168554, 0.003877115922213923, 0.01518730047879921, 0.05470523550625771, 0.030924807220036467, 0.031624862195683584, 0.02864772386308159, 0.0461168727657247, 0.009472304673474884, 0.016742188919095263, 0.07440694848135596, 0.04122987149223205, 0.13051109118086676, 0.043365885503590114, 0.04433529699341424, 0.030067416936940247, 0.041853497706113324, 0.033659861768565835, 0.08005134641162812, 0.057623674266881524, 0.06701393188127587, 0.029660227798646497, 0.05342068991834118, 0.053523158008653315, 0.05401000688453356, 0.03883855101922828, 0.04646417489575763, 0.007952807101255824, 0.07593781431956638, 0.03947724235214053, 0.03238082435282488, 0.019362671188108863, 0.047060061065900716, 0.08149939814522382, 0.013548767686100497, 0.05844618073634564, 0.046268401126707756, 0.05894136847928167, 0.017297524140186368, 0.04238608586151273, 0.02603504036913716, 0.011376279271057537, 0.011376452598450406, 0.09058493279641675, 0.03910091698109623, 0.02766923040091511, 0.00833202972106876, 0.04502124829037536, 0.0330438504686519, 0.0404117968414099, 0.03755840277599712, 0.0023151828246491574, 0.018115874582661257, 0.07373453012757725, 0.05974181544696612, 0.02275675670394013, 0.03187340218573809, 0.09787835796634037, 0.018257564459476742, 0.015946158448294286, 0.04521987190650356, 0.011667032620959706, 0.022872215730228254, 0.0012162046797100396, 0.02815910532409626, 0.0380083721792025, 0.039365462463108764, 0.05042723582817182, 0.07951520743869966, 0.048074579812706485, 0.035539642351889805, 0.024156202073960055, 0.051294098788451765, 0.03705102274374616, 0.14062009631626068, 0.14653628692030907, 0.2318547482812597, 0.16776125848052964, 0.22959708716840516, 0.20800155887921012, 0.19008401871448566, 0.10847068031228359, 0.06105219735012901, 0.1767879192747416, 0.1359217403636825, 0.09993937963079061, 0.09863532178344266, 0.14116581138824263, 0.07085108243289494, 0.15230446933738648, 0.193236256018281, 0.1190729005142085, 0.14623083234313997, 0.16110490436755842, 0.19336031629673897, 0.12555273264766703, 0.15307228862037583, 0.14442266565897774, 0.18315075446040402, 0.15230834574228333, 0.11434265232134251, 0.08659785117713675, 0.10458767939839633, 0.1215368691050718, 0.15703297851066436, 0.16199712100769245, 0.2724762999963376, 0.14581840124822434, 0.24115228244373876, 0.1904172209962722, 0.20149866749923076, 0.11160062445748238, 0.12251054387419455, 0.13477643891688318, 0.22199364919816295, 0.19759106750209487, 0.1464115678062362, 0.13395801186561584, 0.09742199172896725, 0.18519996304906186, 0.1886213576841739, 0.24689536782041674, 0.12627490841212774, 0.08962966712011446, 0.18547007032940466, 0.16432181481392155, 0.1263094436557543, 0.3433502501537723, 0.12300887640805976, 0.22161855722867677, 0.1215733425511468, 0.08899704703400213, 0.1617121516216186, 0.16211549691375227, 0.14416126113745475, 0.11695896515682822, 0.134451357167094, 0.20349745218071247, 0.10039753851390655, 0.12889496741756318, 0.14562012237166205, 0.16393123254660638, 0.09283556888300566, 0.15368564925607175, 0.13007299614048776, 0.09494159055212814, 0.09276681249180148, 0.1613413191009914, 0.11591633481364097, 0.17837817990972152, 0.12367217065466028, 0.125302558975114, 0.12368064358710282, 0.1766759325419703, 0.14196830381068493, 0.16681929209059285, 0.1649125605340927, 0.16598097739681122, 0.16507448087776863, 0.07243645542691793, 0.12589529652388828, 0.2093467479872127, 0.16346661554228875, 0.12773526351778738, 0.14913828923336922, 0.2621331630695251, 0.10447704864125099, 0.11377200874830447, 0.1666905280322798, 0.2238356616468199, 0.16226086975826373, 0.11346659247553158, 0.23077785848609864, 0.11035883423661995, 0.15479344303809828, 0.15519562387658706, 0.09663761728593419, 0.09139611265592038, 0.18948954980700247, 0.15583132363615498, 0.1470370785964112, 0.11328246324293076, 0.1211798721323571, 0.10978794551544613, 0.11628372759948816, 0.130756285281912, 0.18666823184297932, 0.16426037456239426, 0.291849376573678, 0.14224106175524576, 0.1347500088834955, 0.13522671475525827, 0.22478116736296685, 0.15361749807432776, 0.2583086070033812, 0.15503647677119703, 0.1975812309331471, 0.11757556634444384, 0.260251896275628, 0.11621222861351506, 0.11162179146683025, 0.11776308168566997, 0.07477298529157717, 0.3022831263801744, 0.26907097788587697, 0.09694516328313658, 0.18920753752031635, 0.10354617520445779, 0.2180436232517804, 0.26555935341504316, 0.1204677934067384, 0.16936371523526408, 0.16798901642041822, 0.1403560411305197, 0.160571416058848, 0.10523654820938265, 0.2582255630723892, 0.17211816904525604, 0.1594941432197248, 0.25505303976035887, 0.19197838561188793, 0.20498090483728917, 0.12444615694544009, 0.18611030532948433, 0.16927527804528514, 0.1012164558614454, 0.13313468185163316, 0.2690393537763627, 0.11449029278610984, 0.12838004908013728, 0.15903550170121655, 0.1059484047695033, 0.11164663569821466, 0.25766726883669056, 0.08703442170254647, 0.14410792609616635, 0.10767054744064809, 0.14215916695614017, 0.16658082424152285, 0.15088377460356683, 0.1797168419486092, 0.1196197493963184, 0.10891040711994134, 0.1938032223692825, 0.22715982440258228, 0.1257564890528879, 0.11118365046117576, 0.21762783669175642, 0.17459041138570155, 0.0836611680325962], [0.026661049116462953, 0.04272706776617035, 0.054398003605104266, 0.01761876970469471, 0.06149316522022409, 0.024129362183532888, 0.09338503778581658, 0.014379245300416746, 0.05010853176035228, 0.00958570100802688, 0.04838738117306944, 0.03154964576805792, 0.01486573124214286, 0.11686196310385583, 0.054683957414160815, 0.09375775488273752, 0.05564080889246637, 0.02691636898464734, 0.03901149536813459, 0.07118019380516584, 0.031438256583867535, 0.06805607192819157, 0.018034952715219512, 0.006349354911024773, 0.018621605610655203, 0.039859455108882925, 0.01927194531045614, 0.008550447133940556, 0.05182361493127481, 0.03852629741173118, 0.056602241576559124, 0.017013970101552627, 0.04045440665175838, 0.01991961710906077, 0.05672850052735979, 0.03418341008645873, 0.0331566913894588, 0.045520572908102505, 0.052781983263670444, 0.040535309367002025, 0.014809415161219096, 0.029668118504266587, 0.030102260530956333, 0.02266145728137945, 0.09561685109210592, 0.06802731298751409, 0.01276525796481198, 0.04284175112843514, 0.015215334508778348, 0.004359656032325039, 0.031239581256804448, 0.05243905166524553, 0.07384645557331462, 0.009842036900320842, 0.05661724923899578, 0.06418098087212251, 0.04561040437810364, 0.025949631141678944, 0.020134481789183714, 0.06785066843393349, 0.01000710107731603, 0.05466006696224213, 0.08751771593045804, 0.07898448470739589, 0.01114732910683679, 0.1091219469784729, 0.028900990615628903, 0.01897810654143893, 0.024807443842291835, 0.06366104848923222, 0.016686858218764106, 0.03954559654718445, 0.020251580243629795, 0.03011708624751097, 0.05725840737502422, 0.043488999663461606, 0.030253114734566024, 0.04543606957961475, 0.042722743199837786, 0.0445461014075385, 0.025221043221291997, 0.10161249267478144, 0.021510092248659463, 0.02661625595553027, 0.06469288465356635, 0.03571416484192014, 0.04679509423552983, 0.038907897298134146, 0.01137882842862558, 0.001138311732398917, 0.029280878295521104, 0.027876945565484708, 0.04945478296928829, 0.03057497699985341, 0.051177710880555456, 0.06581916413720577, 0.04666424641806272, 0.06654297166894521, 0.02412256698364452, 0.037062184644802924, 0.031988167902454734, 0.04095900961528382, 0.014112631381008656, 0.03677744125466674, 0.03199959601906519, 0.0362376710249772, 0.03150685401182742, 0.04188285036493213, 0.015241048249956823, 0.032513273294053735, 0.025977348202779412, 0.01452436054786367, 0.05795343298344843, 0.030527345483161272, 0.0774827991582213, 0.014276366395455216, 0.02169658294728687, 0.03273379553349749, 0.018024828863300143, 0.036502614872710365, 0.11926664415025905, 0.01902120856327876, 0.06509659766790367, 0.07761192327785878, 0.02769465685912198, 0.04768720362335444, 0.07980826671325392, 0.014239821128637321, 0.061754079445475535, 0.05730993827925094, 0.03534471510999626, 0.02089876557640251, 0.03160577894548976, 0.015466578789205562, 0.0536933406105926, 0.042142450749393434, 0.018783005014542612, 0.04892980589741661, 0.09376536979670487, 0.052760617071462255, 0.018078397561405456, 0.024582403599314635, 0.029300576331274166, 0.07101474179615898, 0.06494957773435502, 0.07338540853872415, 0.025473578359871626, 0.0771247296624126, 0.037865814707812764, 0.029153874324214075, 0.010313630092798943, 0.031143347206976146, 0.0647241793452732, 0.05536025983371562, 0.05762316481841188, 0.06533144192109186, 0.032093430298470685, 0.0158406920813685, 0.027830263997818676, 0.006118186922263235, 0.021416487795631253, 0.06444608176788015, 0.012016397442728763, 0.02639890723531285, 0.007416762452903054, 0.04294720696165197, 0.0654163551066191, 0.01164098754675398, 0.03895166007080867, 0.03419550661478312, 0.002897447951498532, 0.08046408394171346, 0.03879693329274174, 0.011866787174386124, 0.021031699068243467, 0.07791232933560688, 0.016284185168783993, 0.04089531323481952, 0.039008365898963906, 0.06410033096589389, 0.031302766273579294, 0.033602880148757855, 0.03131612876219855, 0.029475093075645067, 0.12008312533819869, 0.10713762603700162, 0.031090274550801808, 0.028050167621263576, 0.022679109862374685, 0.09520800528867591, 0.04635819046187305, 0.05824069297241588, 0.055105497294496146, 0.0179490972415454, 0.031189835337441296, 0.05612223769628233, 0.015986272727229422, 0.12439984693041733, 0.0608919432476884, 0.024919187342147195, 0.031666071980350444, 0.04101979103119623, 0.020402325279710275, 0.0504660688250536, 0.05060884846194137, 0.0103051389657682, 0.032327458668019504, 0.052825937558326035, 0.03304491916130627, 0.01752067980686984, 0.037687289408378066, 0.011506987277478462, 0.03573032546668284, 0.07605907837710074, 0.014847669761718042, 0.04883195348684827, 0.045409130097757426, 0.028283452885525844, 0.03961863536988536, 0.053796268353659304, 0.1331599627531344, 0.054463312600649176, 0.046010830875245795, 0.055830212640425855, 0.03593878948219842, 0.02085089082679441, 0.01673636665087073, 0.04879305537249293, 0.056334187411853386, 0.033002290198759686, 0.042700810102565635, 0.05080319347701246, 0.07849663991721408, 0.014681548383387347, 0.053191012928202275, 0.01913005433556053, 0.03287107465908893, 0.07471095515234817, 0.04417070300288258, 0.09033647516081411, 0.06274008823017921, 0.017129427212620937, 0.04105046136124481, 0.04154533117769226, 0.019777716558066108, 0.05091982653304454, 0.016423084570335287, 0.10024086587251195, 0.024961733950241923, 0.07498606498683653, 0.050209375744264935, 0.03056973504323152, 0.04164145605999135, 0.03258629296455653, 0.023707563748523116, 0.03828347052237199, 0.030388222000892126, 0.053775407779481144, 0.009181888402259399, 0.051787899912244854, 0.08785293302348546, 0.04293890639899239, 0.02620921811960157, 0.02697717529841729, 0.07704422148244996, 0.024525757142973524, 0.06766006575837251, 0.032030262518674135, 0.08868381666440157, 0.0997222473304118, 0.056147104910304474, 0.06958786473279038, 0.023499601520597938, 0.06714615865700668, 0.04893821371238559, 0.025953683746798385, 0.08751587731943977, 0.015130876187956142, 0.021354315930136272, 0.041460973405910116, 0.028982010159280994, 0.02692823185615482, 0.04979280777455819, 0.04956791500350641, 0.03552476492440028, 0.07704745437349043, 0.013985596766184657, 0.02141710641163011, 0.05317138575558221, 0.01904890647218112, 0.026724525246649023, 0.026783992821771293, 0.0902282652415095, 0.08613458248756586, 0.03662021319952704, 0.04779365537087283, 0.08433466657034813, 0.04109938756652898, 0.03259352483456174, 0.022980848913111036, 0.05489487674147372, 0.014390160138117931, 0.045341162777115265, 0.03687948799662052, 0.05465479244688346, 0.01801414193675643, 0.009008364699360345, 0.016601828204828407, 0.07735556727575679, 0.04006300850080387, 0.016089629479533723, 0.029042136570018147, 0.025781882784119057, 0.029117184458300475, 0.08009020239114761, 0.0391904152028503, 0.025433316609011065, 0.053093340548296133, 0.0028077819086085526, 0.054595715576602574, 0.09771081453730023, 0.0946501630448526, 0.049357681324885744, 0.08892774672037171, 0.015184660348290158, 0.017841011811528477, 0.03790298529389886, 0.02089508260870653, 0.10439834076791041, 0.07608214528450082, 0.018910248388325977, 0.04312929456993457, 0.06022533184037574, 0.04536799883710281, 0.028836022529210296, 0.0639090273198822, 0.038534923561758576, 0.01210423325368714, 0.01021291059817398, 0.07798500809698336, 0.02543999115005136, 0.04235308662417435, 0.043035858656249704, 0.05113828799597198, 0.03200180235228712, 0.023550833650534193, 0.0017204171777965742, 0.044788798061950554, 0.021750138238853505, 0.08422981211615187, 0.043279455463972785, 0.04228935193931384, 0.10836468438708013, 0.17747977327915931, 0.18590352287696255, 0.17283407821049615, 0.08795240187957402, 0.11044851248903621, 0.14910493376514605, 0.14067782870223447, 0.18115829766517688, 0.22233949193070013, 0.20022814132032857, 0.12412365691195573, 0.09878446378054158, 0.2031026257862968, 0.09970167786964487, 0.17002596760228758, 0.1854286249727011, 0.08555600990451152, 0.1373360612459721, 0.11079858402691542, 0.10967397461495093, 0.2888784263162844, 0.12042909830568299, 0.1284846430644393, 0.15674135948140777, 0.10896881366328848, 0.10982365287359684, 0.11828392954362978, 0.11518504260288132, 0.12879627997115736, 0.2633291488933948, 0.13379233769111096, 0.23489686810681898, 0.07368644278857016, 0.09813405513282746, 0.11221087477620571, 0.07863148671364592, 0.22329757681056378, 0.15139192072374208, 0.1296565047795734, 0.12794479622595734, 0.1890892841883244, 0.09835734678011748, 0.08922469772158131, 0.15359851441556407, 0.1602782954972598, 0.2783836652674983, 0.09223355400946834, 0.10919189080595972, 0.1427511077734732, 0.17054738236531136, 0.1885857192739364, 0.2622387606290079, 0.14348376362073806, 0.19279537241785757, 0.20910711568449775, 0.11607764228697746, 0.14204143456393672, 0.1798909277685227, 0.12486542920551955, 0.11190117607193609, 0.16387665644288063, 0.16858564569584786, 0.19943013817312258, 0.1526409964407644, 0.23279722028922653, 0.09692979555937553, 0.14303891168486688, 0.14766778346271286, 0.12729533752726932, 0.11432087244165522, 0.14678996927555532, 0.13047629546734596, 0.16224444483316716, 0.09011471568937264, 0.16179329565455838, 0.17883305227564228, 0.08663097681898264, 0.09335067874241261, 0.11590521887785966, 0.11658300750798757, 0.19844021467912584, 0.15777882639198534, 0.18406904873348054, 0.16810238211145326, 0.11933690207379481, 0.16204043561893125, 0.10608054727556245, 0.14519269127518902, 0.13488870144130724, 0.17821871104740328, 0.2589889543671762, 0.16677648309738408, 0.2577702004101969, 0.13058992162827524, 0.18106103514231023, 0.15593598656837018, 0.20839364267885688, 0.13155972765338037, 0.23832765497988273, 0.1773404218857327, 0.1334152845365386, 0.11259065520378853, 0.1387753565945933, 0.08814519556659846, 0.11595876842376687, 0.12475426984770645, 0.17307277588594347, 0.1277836572919642, 0.2846496516177731, 0.13030162742061, 0.0799455726519227, 0.10220097843557598, 0.04000265609412905, 0.1831615409783779, 0.13804823190214174, 0.2414394121977591, 0.1617716613315767, 0.10492023050544724, 0.2083883873156963, 0.22357038072040006, 0.20554799376235855, 0.17736934936575352, 0.12471938986451396, 0.19646874869302397, 0.1266409682049867, 0.20558836659596813, 0.14298050514151975, 0.10584842263450546, 0.1763117036992504, 0.13779819612541508, 0.10766818022896206, 0.17343492096950933, 0.1073257772312049, 0.13800320125395252, 0.07852648670274405, 0.10485599403299632, 0.19403422852197003, 0.2288723833137943, 0.15518302939111187, 0.10538941339379358, 0.06548682753477367, 0.12482968354297262, 0.13812744539351235, 0.1940941978846827, 0.34223703246924186, 0.14946856505928502, 0.1762813512956904, 0.11153406673862089, 0.11583699874820248, 0.08506248840281079, 0.13139370107843032, 0.1570624422522322, 0.15966802985677797, 0.12174114645008119, 0.14312239994685497, 0.12935898687329986, 0.14727553112372277, 0.16215536412933182, 0.2156864473175618, 0.13922276726413157, 0.11854758636365015, 0.07544152724045901, 0.1823433897187633, 0.1517797757180468, 0.1960402757169739, 0.16387860230620832, 0.16287920996546745, 0.1834535736951136, 0.1551991938463142, 0.08566101757629264, 0.12485097312638838, 0.10823677068636303, 0.1012302531049617, 0.16646591105288075, 0.17488265860705607], [0.04228381312362129, 0.003643890747973215, 0.02251365785336783, 0.1478779060585845, 0.02341616496954474, 0.08100680360991148, 0.031065336473646666, 0.04359445932711806, 0.04631969837411758, 0.05437665273465457, 0.018218208607586644, 0.07182091910151706, 0.037635122651174184, 0.013709550389208862, 0.05384984854308348, 0.01779671660774658, 0.03851392126131443, 0.023148082076541843, 0.048571123531268495, 0.0429778887830194, 0.05879208858635637, 0.0165884580553299, 0.01920439742295252, 0.045602525163802414, 0.04539793755318369, 0.023020698891712293, 0.008114271143811845, 0.020635855692108313, 0.030168850808554602, 0.003827258441296797, 0.038199863516755646, 0.027976927700482553, 0.04262269211692676, 0.01719654609088696, 0.012097237913328554, 0.019613551576772047, 0.03856159108240278, 0.10282722467015828, 0.05204075106209324, 0.043232498104654016, 0.0464234343399444, 0.008948630908684386, 0.03941168820845985, 0.040647418673841224, 0.03160179145784388, 0.033267195742096634, 0.026254610744335, 0.07630468616562505, 0.06556663857472521, 0.01395646052720446, 0.039724830477949113, 0.05951694182811245, 0.049364717842470256, 0.025850945610492945, 0.08797798155536575, 0.03879758446747738, 0.01929677805052169, 0.07510884589846097, 0.05753701440088692, 0.02750957384705544, 0.07115807684679186, 0.07413585294759081, 0.04431658529586369, 0.027557756947053057, 0.03505735169915903, 0.02389825835463501, 0.08830317055746432, 0.030556776665992318, 0.01773793276609673, 0.012007132566894495, 0.03909685671509754, 0.011195161721609052, 0.03669387638388622, 0.009229288177354442, 0.007987288239922735, 0.055356142111122615, 0.09352358478692271, 0.022014080426625667, 0.01835443819272182, 0.07171888385088214, 0.031035918697354295, 0.018701943336054683, 0.020347034798995144, 0.010581482201814653, 0.036397545913895296, 0.07561358292737315, 0.0255054667697198, 0.0291306120643933, 0.040229318528285915, 0.0535597731809943, 0.012525804735149347, 0.0401557396135984, 0.027551792952562534, 0.053821070450207883, 0.03647122825045259, 0.018601919066221006, 0.06210086063571996, 0.025790614271236044, 0.01866470380205541, 0.060525634476254066, 0.04241711625288572, 0.0798062595628923, 0.09125532867807536, 0.01638733890778836, 0.008600273492535757, 0.0526914699754167, 0.04065502592692933, 0.15290764100368948, 0.018569254992349495, 0.030449614371924155, 0.036754052590338454, 0.021423968644211852, 0.05930889150007598, 0.057332101202900373, 0.09024336483449706, 0.04302062116743576, 0.0281541372439073, 0.02740417738565274, 0.019643936539068818, 0.02035666260898354, 0.04287863060111, 0.018593934514830192, 0.07204625620356492, 0.04433826175368121, 0.01623768746221979, 0.08260110918913158, 0.026106309528732975, 0.02566560978941139, 0.028932042074419802, 0.020301862424539945, 0.018241844335270506, 0.0697628315538168, 0.08599067287098977, 0.029818246839568022, 0.032043249624210506, 0.03494331185075064, 0.09343745352159585, 0.035933564762554826, 0.04742114128725183, 0.05341878235940972, 0.005831966418848043, 0.006805645976020324, 0.027408996078696464, 0.024592831971183903, 0.016837243193520174, 0.027793867160536112, 0.03218832944009093, 0.02167361946175656, 0.03817675447451972, 0.010189471180520712, 0.06203872707462119, 0.029468265317019918, 0.034908837894158024, 0.0217721326231596, 0.07738257953596693, 0.010079107596538961, 0.032697356561379086, 0.031822497558389465, 0.024505681808917754, 0.012884010211564602, 0.017610562987805858, 0.022255576238216414, 0.04812087833641037, 0.03480170815882664, 0.025004010512343338, 0.031203923694368814, 0.05377313249834603, 0.057167426773136666, 0.05344893941054902, 0.048769452203545845, 0.07974597610413067, 0.03457930517352877, 0.030918061815863176, 0.04538487575407471, 0.04341582294493433, 0.012269547366867624, 0.05444537848234177, 0.01429196107276385, 0.022078182833689838, 0.08834444737482457, 0.047237341472458456, 0.07940877484337938, 0.053387522141659455, 0.04855852138491408, 0.015573414538296, 0.023888822066627687, 0.04159275585064485, 0.05573478489813786, 0.036185898803054325, 0.03353800782332978, 0.02199556599671562, 0.05579355916368866, 0.014666505289384195, 0.03594034081024509, 0.055470649273164814, 0.02733308059583989, 0.05663339071156037, 0.03829809514084651, 0.01351499948800812, 0.05048104584397328, 0.030267005823853037, 0.002882497745656198, 0.015732821155970377, 0.016970259039812995, 0.061197133524523634, 0.05191251943488756, 0.01568154401836857, 0.013503821307582962, 0.06308566666238251, 0.0011517250940444009, 0.029518357891168807, 0.025698917377139294, 0.034515666249658794, 0.061770351152987256, 0.030742064606578603, 0.013723158025963893, 0.017088830298293504, 0.03253608739243881, 0.05375258602021683, 0.03948745813461081, 0.031534381466166626, 0.01603042620474533, 0.08920595921095341, 0.04364741515488394, 0.03688522599517338, 0.0219150424949945, 0.06742793345643629, 0.038514652875282114, 0.06159568693669093, 0.02403572708698771, 0.04212357051249954, 0.02785644313741115, 0.042739941873737884, 0.005423547230630873, 0.06593606149357173, 0.11325830082979896, 0.012137525519656559, 0.03425931407799644, 0.0370451774928839, 0.035287986299203294, 0.03594664571386191, 0.08111196449927746, 0.07732211987698272, 0.02462147982911237, 0.03316896794844539, 0.009059753877321079, 0.008689981430859096, 0.026723366538663546, 0.0219410109604078, 0.04011488414459652, 0.03778976899000906, 0.050174549387227145, 0.026975062810966087, 0.016970396935639363, 0.0871680504191787, 0.07470406802190889, 0.07876660164085128, 0.08599521577238076, 0.024033503516787486, 0.0074680917802447035, 0.018218509297096924, 0.034716254881312775, 0.07083281123590085, 0.07773805965459155, 0.033342168936806346, 0.02529389052201183, 0.062150759772667964, 0.10707538905403308, 0.07587421370009262, 0.0551443264609383, 0.028963152905024832, 0.013421708173418959, 0.015050306720959564, 0.08159189560120145, 0.03148313784491151, 0.06500339541103571, 0.02665677817628509, 0.022728901747013294, 0.05776564185056956, 0.024981389851159146, 0.04784884051449838, 0.06403892518832319, 0.0288758801686908, 0.03707399005971609, 0.019528086807939316, 0.04196906206949104, 0.034761611116869796, 0.02799525060841153, 0.0970782480773426, 0.015675719834924225, 0.021145319483513315, 0.0439045563971083, 0.028447834286658515, 0.005763885621432095, 0.022152614021193118, 0.03349357855416114, 0.04689153321387787, 0.014255073939209745, 0.04664155489374553, 0.03429917746313638, 0.047501408149518316, 0.035060557777122144, 0.048370691947638995, 0.03646097033314648, 0.029188884542353695, 0.04394301018046756, 0.026514933166664936, 0.031320911066065875, 0.06804687887310021, 0.058870099319685856, 0.028874089438167792, 0.04009724497013996, 0.017357776955431028, 0.029198064190906384, 0.061640755889276345, 0.028601557489544637, 0.055889726180823586, 0.04537280220838805, 0.031211523286577676, 0.017171885720604373, 0.04025610479255838, 0.040372339482869835, 0.0473999627865851, 0.09891134326256092, 0.01283635858506445, 0.04356269349133776, 0.04107420625645788, 0.022321262532064033, 0.05642623670639531, 0.052425580009097056, 0.04312329227104784, 0.05839627010807876, 0.023057685616696556, 0.029433082729097337, 0.041612578375685605, 0.06809613066575221, 0.07076068405782984, 0.06827327317648357, 0.013195184592698372, 0.02256303988096695, 0.0509137706080031, 0.044797922169128736, 0.10237592227396466, 0.06466358179046262, 0.028326135474227132, 0.03804661528838258, 0.05739303583639765, 0.03365499711024665, 0.051185329624962424, 0.003986705278587198, 0.019008223372962207, 0.02886172860950953, 0.18442091291710255, 0.11583510651102952, 0.18677736872867232, 0.25357122653194014, 0.11946526776638725, 0.18156227114940846, 0.12371583000546503, 0.18726680698173662, 0.11436506039312772, 0.27400633079871056, 0.14029679189045585, 0.15391650219117442, 0.15074834558031253, 0.1680539040676048, 0.1136494193586611, 0.12472261509467518, 0.08322357861024719, 0.09493654969358638, 0.19757392245434946, 0.1120083287899052, 0.15521698240791598, 0.16821108998790865, 0.15214771242632022, 0.1844073378390843, 0.11327477938105023, 0.17004826076088414, 0.06213004858563505, 0.10816354034168106, 0.20609974560718383, 0.21165391370173425, 0.1039207692167932, 0.1967811133832701, 0.11489160028436493, 0.10881665327976789, 0.14617510710752782, 0.17483057994996348, 0.15830828507821407, 0.11299897240655077, 0.11303936056191884, 0.11159105601930812, 0.10982477902284554, 0.16550131442566074, 0.1176463988339228, 0.2454388814587747, 0.2022514101718703, 0.1094495568184122, 0.17414742870436561, 0.1518846225113638, 0.10366078195793015, 0.0826199779347066, 0.12032377653785291, 0.12935581526929332, 0.11360055060997126, 0.1642677596499843, 0.25987167151704915, 0.15628440335633295, 0.14025117901544418, 0.24553804387969358, 0.15650028693339518, 0.16238635496026085, 0.1877805761872761, 0.2341833951011781, 0.18797283361275352, 0.14395504558999694, 0.09669014027402287, 0.12632137164473534, 0.1467338763177395, 0.12958069271858663, 0.1186725736084965, 0.09467198122893611, 0.11017812941704067, 0.13788352299842144, 0.1215567873911031, 0.09067046651316267, 0.1655046698907691, 0.23254133160075835, 0.1351808873756278, 0.09152641655096123, 0.16296815277347643, 0.2017142293193648, 0.20159681868408957, 0.21154463892021488, 0.08956405168939983, 0.2048551438436393, 0.07139354163119871, 0.16121967966037412, 0.13867265484746427, 0.14377768091376752, 0.1198176222462808, 0.11262050198931849, 0.1873468938133409, 0.19641843203815723, 0.15610273326596907, 0.12295548007973742, 0.17385161151328396, 0.15012067442219104, 0.21541768835196573, 0.11932178715904874, 0.09733261991172068, 0.10160601923182126, 0.10300617514839096, 0.17431134087664468, 0.1650776831252921, 0.1259242393256676, 0.16366305580783277, 0.24659339128242386, 0.13420746541552006, 0.1728614888364269, 0.12500445118113873, 0.13357050927175632, 0.12172375625420002, 0.1050640098870762, 0.19459338077614385, 0.15284036316217917, 0.149830587568783, 0.16358270850633422, 0.1115682878861985, 0.11775788760954335, 0.14877861095291955, 0.11139284609065903, 0.10850652556626067, 0.08333581049115428, 0.09724664952485793, 0.16774432793740304, 0.14948567946351346, 0.16370906704856505, 0.09839295454683805, 0.1092343780422403, 0.09999891998426569, 0.17763130547058198, 0.10041728059971526, 0.14536329905592626, 0.23734700114976978, 0.13147790946306723, 0.08276158928750985, 0.16036184504628181, 0.20486275875760665, 0.07723244162456644, 0.1508929523368997, 0.14694997439942054, 0.16385609464299294, 0.14867191022682577, 0.16203959292221456, 0.1869297589385702, 0.19560329916496433, 0.15104851415080411, 0.1394899940538791, 0.14141143449852545, 0.13646393143121274, 0.12817579471776563, 0.14313027533071657, 0.16616894472991267, 0.10198093500108489, 0.0815421841557949, 0.1851361479249693, 0.12488146342577473, 0.14091824241463216, 0.09686212701302382, 0.1573705474936193, 0.12846906083605944, 0.1992038664438071, 0.10618096608067713, 0.11720837274145697, 0.18875611255005484, 0.17566252079221512, 0.0841324040365796, 0.19225619973674898, 0.16995758659416632, 0.1572304453340269, 0.22119435902324416, 0.19164837025586637, 0.16577419494428944, 0.13010331790053076, 0.12364855216395472, 0.10154185936816278, 0.11461356399400581], [0.033392363017605196, 0.011009586498051161, 0.013638518716869576, 0.017883409032477968, 0.07756464799205143, 0.03174221920480411, 0.06569146494110746, 0.1340860404795216, 0.0487978472524593, 0.03943937462604335, 0.006282288222498591, 0.014542137618146598, 0.04612510821091072, 0.04487300644658747, 0.027432380912585125, 0.019015185196974108, 0.09437252512021412, 0.008095795018298012, 0.0732304978995554, 0.015989530516127427, 0.03886603442351184, 0.08263847129719873, 0.01503371325651965, 0.01268391666423169, 0.024169373040598248, 0.025850451483781782, 0.02777613222508902, 0.05550984616181063, 0.0782228707365932, 0.03982600004922959, 0.04067420110767407, 0.07561111612425697, 0.021591898947653752, 0.06841308422266476, 0.019482902942165252, 0.04119895218360809, 0.08026248024355981, 0.05047554150223733, 0.014611206190179915, 0.007118812185757223, 0.041738278082301544, 0.023773527749243285, 0.05743709738336264, 0.06315476013227336, 0.02293328251389246, 0.054434649420962225, 0.01901219170840998, 0.01824004402864845, 0.06004913927867048, 0.037339608064822616, 0.08345610927790405, 0.01954339132944663, 0.062336302437489076, 0.09693755603004849, 0.10789419148838329, 0.0850323121994734, 0.03843145189626563, 0.03289559330310553, 0.03929122854324599, 0.056376739765607545, 0.08691230728741615, 0.024218712933361534, 0.00776356614698025, 0.05461364586447036, 0.028637073325714277, 0.03238100438348709, 0.049621453058094754, 0.061691807988550396, 0.0074928215772454305, 0.020759205424016523, 0.021425424211267984, 0.012087798752491514, 0.01753491372050297, 0.020644792107745044, 0.008103388864847441, 0.02781760439486994, 0.03049540919281783, 0.042287999794127486, 0.03844762401234719, 0.12426307725329554, 0.03529475085557469, 0.06956638362739356, 0.016161028874076663, 0.09450187906622888, 0.058000865317280256, 0.050653572674960866, 0.029941795754336545, 0.037999014415207415, 0.04185434806370928, 0.01237300179538227, 0.038736672816617836, 0.12274610058915232, 0.03010763463774516, 0.1121677746695857, 0.05075411022370381, 0.007240336234380882, 0.046855879481881864, 0.011442907853052022, 0.04001805829184671, 0.04023160147030027, 0.05222661931428218, 0.03359263755321022, 0.020479841886328596, 0.16699595196593195, 0.01690180716855872, 0.03122144029475749, 0.049239473958169265, 0.013347718444082045, 0.028493033474191066, 0.04781356599602488, 0.05008219365751551, 0.06745969546177695, 0.026380729884089484, 0.015666874392228504, 0.06237158078640219, 0.13248698515517096, 0.0069775853133309754, 0.04334051650197756, 0.08610212334221409, 0.029341544798244874, 0.03788402078733329, 0.03964904139960005, 0.03872346163036362, 0.06723921535716904, 0.04019005652216654, 0.07179893237809021, 0.028441745802880298, 0.12056426685904303, 0.05638861412843389, 0.049565750805120316, 0.04061858695481093, 0.03830775550957169, 0.04571307548171571, 0.01618904853990722, 0.06387631919595503, 0.12679443093797854, 0.050593618634006673, 0.04947644410534732, 0.025335950664274638, 0.05224635373921164, 0.01053102573590173, 0.023305421214430563, 0.05008909227927366, 0.023966286962311116, 0.07810466336987673, 0.02568404952574882, 0.04757823910744441, 0.03238118441414929, 0.05621242922760787, 0.02346547421879105, 0.021243051235233585, 0.07348915982630945, 0.026896958231865883, 0.038844312000418865, 0.027597919106483463, 0.02497347424768152, 0.04100608571823086, 0.046135174606235764, 0.06297559514942189, 0.02075725189980961, 0.07167232868772361, 0.026433930859991142, 0.02625081094823057, 0.004049013603493691, 0.07162367444365256, 0.022206056314790924, 0.025867445229162133, 0.03235047194926489, 0.06615533117925929, 0.02371852838193938, 0.019540407416981556, 0.016444150073033188, 0.08240527413304775, 0.03873713629981203, 0.05991665969392466, 0.028148912524263707, 0.05657373544489665, 0.017842137960777167, 0.06260288954381982, 0.03011561727391616, 0.013273762231091819, 0.04018691173123737, 0.09098214938515618, 0.042705789674073465, 0.012333212146205048, 0.05527835354329117, 0.009625145917638175, 0.036140554058816166, 0.08487916356253047, 0.00595537121332581, 0.0839651900253469, 0.07491924679808079, 0.04369215852010154, 0.035687953143590884, 0.054756586379822225, 0.017531901079740737, 0.045903888831455866, 0.03094754854006873, 0.040321950049650286, 0.0570180626105397, 0.007408833442886751, 0.012396786910211368, 0.026477979000417456, 0.05245126310675856, 0.010452539070449289, 0.024418771049127947, 0.021415698725069245, 0.06519014466433756, 0.0988617850347392, 0.052846813454262676, 0.059804228630157254, 0.03664500380475675, 0.04400791697985223, 0.06626059932093467, 0.055880437364741686, 0.12589800847514024, 0.05250191684031198, 0.07412289840079124, 0.014815934569454722, 0.008556457093706536, 0.10055215803966408, 0.0277219180979075, 0.018525997837704998, 0.03224378654492959, 0.04442943387754983, 0.126956588768911, 0.07763713523144684, 0.011796602029203167, 0.06802283903403629, 0.14300623037401708, 0.07113121780416659, 0.026220100398565975, 0.027019660619478074, 0.0151697417435747, 0.029117326184566465, 0.05653649208045775, 0.041281023182936256, 0.08472989899136367, 0.011002812365580712, 0.005989446325392853, 0.02712448251493756, 0.08842150049824869, 0.0572674433820911, 0.04622607859933088, 0.01355475274800894, 0.051682965018816536, 0.03644956328395394, 0.07173228272867781, 0.07032782139797365, 0.031824700061171766, 0.0264920539508063, 0.06254976134627097, 0.07269715514755057, 0.01100576850735853, 0.047443480411123846, 0.0583868089222139, 0.056705046745557944, 0.10278843763855197, 0.05666358223665626, 0.11881698118222338, 0.05832680891598425, 0.016794353761079333, 0.022043412018026558, 0.04375781991609162, 0.048732067112840956, 0.030826479834955067, 0.0303659709771314, 0.06449689637989768, 0.043601583944813865, 0.04730202227590546, 0.1129346899688244, 0.04888800814026787, 0.048776389129700205, 0.022223195616876888, 0.10694606575153529, 0.03279877894167458, 0.021791920674243764, 0.01448255608744559, 0.03777348196073886, 0.113424074595734, 0.07065363859217014, 0.06731898043184512, 0.07742738801865809, 0.01767224838746892, 0.033880824508566054, 0.052218985248116724, 0.009047446674817513, 0.05155627322833865, 0.007129738035972321, 0.03864628593287161, 0.06267033209423385, 0.11024489397964171, 0.05590755687726121, 0.032345871591279586, 0.06340224100577255, 0.016455306228430524, 0.03715509195782004, 0.05590656096295965, 0.05785826954149431, 0.026143895717517986, 0.015610465423143921, 0.03219566473196591, 0.01463486202767179, 0.11863173346125311, 0.029498238507057392, 0.037486995720574935, 0.04367063144942926, 0.04043090307424146, 0.049238623600573315, 0.031494290169869224, 0.0453848566018766, 0.0720386489504768, 0.04060501953767192, 0.08900449340862614, 0.010970335983250652, 0.040740693709062, 0.03130937569714602, 0.06814175886252234, 0.04741019006037424, 0.08202900238815816, 0.03530459125496207, 0.04520466123076697, 0.04227997885356027, 0.0566251629272536, 0.08940991479903461, 0.01246907783957619, 0.029501829544202458, 0.05434088408946992, 0.01977403359037013, 0.047463471475507946, 0.03395948641663117, 0.02227542557633452, 0.03692950204675717, 0.04920716036952311, 0.030324297709270354, 0.019230754677987388, 0.051850117743015296, 0.05740601336583496, 0.03851074582686828, 0.03354512861058597, 0.02252529472893765, 0.052595800915432554, 0.07405719870040495, 0.03709787285075553, 0.017483683505786524, 0.010405831647315815, 0.08547151040646338, 0.06528107930094966, 0.0647541563657503, 0.04181441573065616, 0.010527028672156796, 0.050593997847529194, 0.1729292110089333, 0.10819386210172408, 0.21761559460672641, 0.11260866593088835, 0.1088542758577293, 0.12251717819561883, 0.1597996131186524, 0.34652749256741616, 0.15181737531337047, 0.18665393664231225, 0.1708984651392506, 0.089886229965956, 0.125010802050031, 0.14970594506350257, 0.33096953385299255, 0.22808648435579193, 0.2033023908734322, 0.1258349134736965, 0.11780739221121035, 0.175134027376771, 0.10595593541379898, 0.2095696948949368, 0.14785382025424512, 0.13427495776164916, 0.12048116930189634, 0.06558128617583744, 0.07517734948065012, 0.10332233963474151, 0.1686349204711376, 0.09616828884088224, 0.17942646398178994, 0.16894840364975316, 0.22083353161090807, 0.16826168243442813, 0.10438445925472245, 0.14901557726965797, 0.1318235376909856, 0.18983560704415847, 0.1619106143592827, 0.10944255477478428, 0.20045481141536467, 0.2155604871410516, 0.19596853924374427, 0.15009551609475769, 0.20033335583584927, 0.1497740656017296, 0.17749973753046605, 0.10918363237813597, 0.1467105719230829, 0.3221611161866496, 0.21363469531699536, 0.10518494452680312, 0.23112036107528597, 0.20800324427264355, 0.23206721510617967, 0.1729592416555651, 0.07736672917681356, 0.061237912384733084, 0.10300690293191903, 0.1479849285416065, 0.2214040679316367, 0.1637004715420546, 0.15767938817941374, 0.10290332018367707, 0.07877521246912018, 0.18402332860615947, 0.19960618517812223, 0.10784353009395062, 0.06677208558445977, 0.0898323433413621, 0.07789970420661473, 0.16934494608111922, 0.18436734804943686, 0.1563758282892166, 0.14510544918237195, 0.13360623961254475, 0.11819802044380097, 0.13530974336449178, 0.23092571345548477, 0.18994926384860472, 0.20168373901997844, 0.2434488455013883, 0.21155913330374226, 0.18060081548267798, 0.25230022537852487, 0.09461491533945646, 0.09792605460050607, 0.15348816711095073, 0.1371582982040221, 0.11130882922800318, 0.1668865392885862, 0.20360009264080756, 0.09770431045082309, 0.18953778270271518, 0.3049955679283988, 0.08099378011519871, 0.1581758131543475, 0.14814358535072497, 0.1670112277591421, 0.11042675559198666, 0.08668811931725472, 0.123798368318427, 0.0977476786882166, 0.30198845832097915, 0.15563840737506268, 0.23274845113196682, 0.30017770225963286, 0.07594717591400109, 0.11339412055789463, 0.09872598062840202, 0.10846748572563934, 0.20173949489910759, 0.1069883614658348, 0.14743435647218459, 0.13799034629858312, 0.41985224992517506, 0.12089593696498102, 0.07201019644496903, 0.18941920761379505, 0.09358249694829987, 0.20640869354528768, 0.16015376024428876, 0.10945770799392655, 0.13429800168641154, 0.155223356259446, 0.15757279470562935, 0.09673193037029236, 0.27827843543021913, 0.139304845924339, 0.16774111036812106, 0.17302579937442658, 0.11634925109965187, 0.17222401175287463, 0.06180156540546206, 0.1278070689389302, 0.19766104197309864, 0.14119328330120734, 0.13150124450124082, 0.126182533530218, 0.13082743952831916, 0.11364751946060889, 0.16093158463556922, 0.12761354746837772, 0.13539333887878927, 0.13480126016562985, 0.10293725021784345, 0.16687425123828073, 0.13230185234738936, 0.2668566160625027, 0.12759973490310292, 0.07484535761778394, 0.28325273625312314, 0.08822735849647753, 0.06979489233344793, 0.13892894190165306, 0.09340654953473038, 0.11890069160970951, 0.08344395912342495, 0.15533454626077609, 0.1671432400302541, 0.31334828585386276, 0.10286718381628876, 0.1605657623299668, 0.1014286085903164, 0.14139101059446413, 0.2768779041305665, 0.1357480529094896, 0.11683226187503147, 0.1415106122412028, 0.13506742975404187, 0.13283603013523165, 0.18283161755290725, 0.16342949092147813, 0.08665187569755702, 0.1544183357468536, 0.09574758399638439], [0.009011229868197154, 0.0883868886458297, 0.016756616269929275, 0.06296156807952831, 0.05222611752669177, 0.055972946312038176, 0.03299354913554365, 0.02393557641264652, 0.04306332673877478, 0.0634254994351537, 0.017413626680330887, 0.0277093006297946, 0.02917437483706782, 0.01865812119156603, 0.04598318276205852, 0.01805557197170152, 0.04911406153452493, 0.040048966109151804, 0.007459051942738194, 0.032346377209309614, 0.018783797915544242, 0.04676212181126879, 0.043967375606899305, 0.0050325737796693805, 0.06183095636867708, 0.042819201330383944, 0.04722928988837427, 0.04311710228061965, 0.023297174277925686, 0.0328224242454575, 0.04412997393838821, 0.010956107815276953, 0.02645487953428059, 0.05368430077308609, 0.06469320641049454, 0.05899070071116571, 0.013094457437194163, 0.028823339943623835, 0.04763449294372432, 0.0906163500621915, 0.0804710170374282, 0.028903095442200863, 0.06990035965798364, 0.029666733800343452, 0.035532923760793866, 0.01120430689620515, 0.006690877386473961, 0.03797947151225902, 0.004951720381335866, 0.03849322539603999, 0.04859459263482883, 0.04987759455557793, 0.04430884397738884, 0.023176069183635618, 0.012436135101222224, 0.0256912584131163, 0.019415387613398415, 0.03619675043850176, 0.048788336270879355, 0.08492562679513808, 0.02083340678514252, 0.013783123558236948, 0.022579146879574945, 0.05986433971913592, 0.04406771780322156, 0.0891236124199725, 0.04021441428771904, 0.0634250321215199, 0.029389325702082247, 0.030138975294727473, 0.029968838658063646, 0.009959700344611081, 0.0054270999633797236, 0.027877642705495802, 0.01955516993128244, 0.03828734692726885, 0.05475465200781342, 0.06989765536761092, 0.0700989602914741, 0.013373723298671746, 0.04164241750033633, 0.0033235778955126847, 0.01518131541689077, 0.031189969402828047, 0.04723986956260858, 0.0471953981586041, 0.05477050236696678, 0.08372143616959934, 0.04160186080562492, 0.004623366478500107, 0.04801538036835771, 0.052080863425808574, 0.015165606784003397, 0.04903746423341575, 0.04300624169709702, 0.04489315455899604, 0.04384388223350529, 0.011663894533299872, 0.019484772196700497, 0.04125642793012723, 0.0377836900823299, 0.010226248188935702, 0.015394578973251968, 0.031577535198941346, 0.07240994878473782, 0.009263742024139052, 0.05168930822682958, 0.04419471985930878, 0.058328099774136666, 0.05340308904828084, 0.05752137854635235, 0.049865923206051516, 0.03773783205918247, 0.0439388656447972, 0.04241073091003684, 0.024341580029877446, 0.10074540371856383, 0.043657990998678634, 0.09514736176858987, 0.041623947120481924, 0.07013040053988658, 0.06997659306732879, 0.024752758571036884, 0.07380036772378991, 0.0853200854673501, 0.06558671773922059, 0.019915150816462213, 0.021280421004179987, 0.049196492595177506, 0.0543239688681018, 0.054361208402101076, 0.011090840656130065, 0.07531620291692596, 0.04204144588701668, 0.03838092456721971, 0.026701895009365775, 0.017975801151366006, 0.033722071938457034, 0.00926385981015741, 0.06519021361225075, 0.021391030693907413, 0.09187966735372621, 0.06305737886577845, 0.021939605189066742, 0.028204779486141862, 0.04337846083686717, 0.0296218027435844, 0.05319545240772348, 0.06526559666399995, 0.014989072355561921, 0.017497624390788617, 0.038395449594264074, 0.021048995418353908, 0.07262582470092081, 0.03383197108163469, 0.027199528488000075, 0.09189789258544484, 0.05695098778232933, 0.05337307755384715, 0.013744974294827591, 0.06539367124318116, 0.07688041656248032, 0.03778360581265823, 0.06581515749736179, 0.053739041585715554, 0.019925060163762782, 0.03500194822047507, 0.04673736184955605, 0.03894545092818238, 0.010205125229643478, 0.04162193997012031, 0.05220776972090525, 0.07459325340366171, 0.10200369547331527, 0.07901050105330445, 0.04295401748329882, 0.08263933697655317, 0.018185412383548195, 0.010136174443628519, 0.019012331519456162, 0.010992231733736493, 0.0946687943031711, 0.02116022372408019, 0.0303169681630548, 0.05734399088748521, 0.04891415855156318, 0.025522288145317186, 0.04400577193366424, 0.07413392240602164, 0.016607652388272748, 0.09901739281391907, 0.00915877074153433, 0.05061551725732223, 0.0804176819961398, 0.051615465011808186, 0.047796769518285036, 0.0332624115230095, 0.0126078374300813, 0.022108387765324405, 0.02486804331232223, 0.0281644641091266, 0.05717450925599664, 0.03547133795256096, 0.011563469982525755, 0.032037076870760614, 0.011047586374315283, 0.01637671135305878, 0.0261219741115647, 0.002993780874549562, 0.04504987699610572, 0.04414728369503733, 0.02276445397235934, 0.06809509644705443, 0.04289870593516577, 0.04494632106094111, 0.01731293399878327, 0.02760743966416246, 0.023833205998544733, 0.060680192714977654, 0.04184441190333136, 0.024164163642713142, 0.01679080294355029, 0.043297856895914005, 0.12734668840083385, 0.0713922699252444, 0.013577279563422405, 0.013173856704886402, 0.06402862130574162, 0.07415669820001049, 0.05402543206488895, 0.031811354809530804, 0.07845147903407775, 0.06322589522648243, 0.013968258281238379, 0.019246714204669963, 0.027836333329398787, 0.00610375909262427, 0.02830528830658765, 0.02777545615249584, 0.017666832145844257, 0.0676185054884803, 0.03955989174785153, 0.013810787950792621, 0.04939050819244116, 0.01800577625662329, 0.014325993571190104, 0.09902566656350129, 0.007176330545917154, 0.006298069633738769, 0.10118543696139129, 0.046985823315598314, 0.03518063822881349, 0.005276167714562748, 0.03437201327253734, 0.029142325548755548, 0.010664621893797192, 0.07027844703125377, 0.03403394633243161, 0.08894719003188996, 0.03443283299284597, 0.024097261184285727, 0.09098195020229587, 0.027037115932832805, 0.029601595259361693, 0.032206864937418894, 0.07045845471082196, 0.07705324599819799, 0.028001362074827476, 0.06220999752141296, 0.01182514838048167, 0.030295157639850533, 0.04336173713748013, 0.14241363072106916, 0.03868998358807257, 0.03202296361597556, 0.02818961860612035, 0.024788494657484755, 0.039995129280273, 0.07406734170452242, 0.08829914859586185, 0.037591608857075055, 0.025675402308303504, 0.023162785219028596, 0.10895010579617755, 0.026285512815980662, 0.014723777064993499, 0.020866040215497057, 0.021589813273279898, 0.042584077455103404, 0.02544959023174259, 0.06432724620906577, 0.01435127447269136, 0.02892957335608381, 0.055907457285831054, 0.06738445796673337, 0.07398663434169947, 0.05086251549542912, 0.013102307923198228, 0.026571878397296515, 0.04667908554115603, 0.07239962958039776, 0.061088077078062686, 0.024722817939736193, 0.029686654001594554, 0.05262784637330521, 0.055954924093619476, 0.03711671095281359, 0.047166214039128636, 0.05289144956717088, 0.08274223024566328, 0.015477254224430411, 0.036040418706233465, 0.03930707124152011, 0.04218105775033755, 0.052926318059044505, 0.0499552643797811, 0.08230405859649181, 0.05895304748968733, 0.11651546919658301, 0.036233557132823814, 0.06707077560525748, 0.031977067288431915, 0.03788437318777846, 0.025466045800356135, 0.031453264246304194, 0.009819353994492803, 0.06213175696170619, 0.026644398195428715, 0.05640140779676938, 0.008998470673818261, 0.032479270481534546, 0.009394860845209371, 0.03604688448831439, 0.09538496393830546, 0.02263733891830329, 0.061571394288612, 0.017678731406528144, 0.07949880549624082, 0.004978843245490064, 0.05668420149313827, 0.033197309371204145, 0.004820759087094977, 0.020920039838059776, 0.03486554626555693, 0.015513494013688497, 0.01386901829391718, 0.03680215908154365, 0.03858979460933516, 0.05522789133171882, 0.015612035903388695, 0.026177322048874154, 0.027438821796808514, 0.11441260380970855, 0.14277075026785174, 0.07756051877813955, 0.1615340208574649, 0.0760959578497756, 0.2379933495314852, 0.09386791832624905, 0.08724253714805649, 0.15143076138150308, 0.10057344762307983, 0.1099103740266254, 0.1708254416383082, 0.11352938870268484, 0.09820814349598463, 0.12417990308735641, 0.11783162357225535, 0.2657710694737973, 0.16360927643554826, 0.1549720947420405, 0.16926326578663242, 0.17044688695140425, 0.1240093412718946, 0.1260122398455297, 0.09947144546576085, 0.17950406868851956, 0.10121908354302568, 0.11894017578132692, 0.11694611786233804, 0.10046010491468253, 0.1373373482736849, 0.1569686424467833, 0.10439461758059841, 0.19332959617097534, 0.18457095889795214, 0.14378108234415132, 0.11613003504011901, 0.10309956892724, 0.08346122674523823, 0.16983596247530755, 0.11406159764456172, 0.1032361087779845, 0.14468071471539237, 0.13938284899678924, 0.1565210172726262, 0.19540904991088376, 0.1552274012036862, 0.11771627371349644, 0.18140222006026777, 0.1527548371063125, 0.16733388867109053, 0.11780316340586833, 0.12343726511443816, 0.15685038911479135, 0.09811594481429747, 0.0951260492025364, 0.1132930658998028, 0.11669006063452653, 0.07283105965583556, 0.13698837990241666, 0.18332897715510862, 0.08712675828005999, 0.11941230044730249, 0.1096648428468935, 0.16521099774587542, 0.11776576299340495, 0.1766677354011805, 0.10533392564543795, 0.13283909448692877, 0.1318323783456318, 0.11183906166303544, 0.11534759113865516, 0.14553119488541158, 0.190283814445138, 0.18081651519863837, 0.15076339154714538, 0.18883790009685103, 0.12364836830285289, 0.23435766478219341, 0.1150299940678862, 0.07731301109156302, 0.18124835896155528, 0.15976153854881564, 0.17993392062283334, 0.12674022255645645, 0.10322315423118492, 0.1739651457436623, 0.15344453074278372, 0.16195443458855152, 0.09505238984861682, 0.11631764231189606, 0.13278174514491714, 0.12597985730897035, 0.12416982903115212, 0.14323253274684952, 0.20748120131752185, 0.12873068752308048, 0.19941250282910564, 0.14235956023537344, 0.13029042721515702, 0.08666152840540295, 0.12722373128898684, 0.10473025602198417, 0.17280024776775993, 0.11742178185452377, 0.13016932403608678, 0.149329642675096, 0.10651120360219672, 0.143117573592932, 0.1461810672715787, 0.15819585401444666, 0.20655691623687747, 0.13311582076693737, 0.1385667814963287, 0.105965779643626, 0.17889979385560562, 0.050918217748403556, 0.1809226336979097, 0.18322350216969369, 0.18325034589056047, 0.1292052023833798, 0.16261156948824085, 0.11270667155904156, 0.13230134672935934, 0.1315010453183805, 0.22211544185636506, 0.13946353337697445, 0.046993204572748755, 0.09198230015294206, 0.169188127883019, 0.13031518717686977, 0.0997677606139933, 0.07876380541992765, 0.1303105906493241, 0.1654517485369598, 0.1284667625722866, 0.14671818683705024, 0.17592844523249135, 0.13973347211797393, 0.07139269127360276, 0.29437345242308033, 0.11408882440939067, 0.24055658779557676, 0.16817431776754319, 0.14105051515563843, 0.16188210056674096, 0.19355654205766418, 0.06876043614841278, 0.24776639446856516, 0.14807586317821858, 0.10148355241624579, 0.10809250866934177, 0.10106630262828643, 0.14775182330800643, 0.08036103745501849, 0.1988800870434892, 0.2805515715191441, 0.13235754693948454, 0.19600869757273506, 0.17780338414013389, 0.17319780143518604, 0.13002255691155312, 0.21027028230169129, 0.10388992651696168, 0.1624583825469017, 0.15800615532263634, 0.127375531611183, 0.08371919919286044, 0.11537386795445798, 0.18208246017175336, 0.15494869841683298, 0.11715946568837089, 0.16764764764135884, 0.1730745532099278, 0.1593393321719862, 0.21858946089783024, 0.1290531645739271], [0.1644408955208717, 0.06295867226717454, 0.04240238821254142, 0.0280412771709023, 0.03743720383593633, 0.009835919688245463, 0.0325545386200951, 0.04257188133534886, 0.01879522986259432, 0.02595497843539042, 0.0743606384663332, 0.07442615430561766, 0.06412777223534162, 0.03867385743726646, 0.06607873770858973, 0.04963210934112149, 0.02988688065670431, 0.04186921783031956, 0.07167854166078953, 0.051198602098250584, 0.020490653302160003, 0.03168321702809584, 0.017527038336641366, 0.022721587522556225, 0.04188002350049154, 0.06337023002185649, 0.04135683524392305, 0.017475854087200378, 0.029985910927456234, 0.039426132796272155, 0.030859379480863293, 0.07835470680748263, 0.027874651132151488, 0.014667302020825447, 0.04493532386878806, 0.014345076821383931, 0.05737392577312647, 0.050167547343599225, 0.026019841184719436, 0.05869101860650605, 0.03952709169337346, 0.0575442960666072, 0.025541126247375243, 0.040626956465383696, 0.013398692976953763, 0.028400491968157793, 0.05357260898416562, 0.09349550766449782, 0.03448634040391734, 0.030066622120718804, 0.04007441171955678, 0.004863719861473768, 0.12876379784316788, 0.02099737258357627, 0.04115667179106705, 0.023081468816305843, 0.013674989290114854, 0.07456141478952862, 0.05844139268681888, 0.03306343167599651, 0.06323253337834632, 0.05040912550964183, 0.018582360841514125, 0.02466337526247146, 0.05212098345040314, 0.04149686462516266, 0.03340191230358135, 0.0402885562770309, 0.01362125396788601, 0.03482721122582594, 0.07151720354393606, 0.0226034969842482, 0.04047344776711637, 0.045311576461479555, 0.034660112127781875, 0.07778905046683166, 0.06107847799637145, 0.037096049561495745, 0.059682443632834384, 0.014355465931247079, 0.020818427851003025, 0.0331579630954131, 0.016519481413847497, 0.08165579499496568, 0.044325192293692986, 0.014856334216141654, 0.06744220567446563, 0.0940812967957989, 0.016728127375245094, 0.03104818951068146, 0.03321653051722435, 0.03210781359924905, 0.03511236447300162, 0.052585489371971744, 0.07637559526389645, 0.03561324807965467, 0.023350704671634782, 0.018573591050000924, 0.053801274738244476, 0.03994679296269052, 0.05955020153534509, 0.03526866556175294, 0.06350068330404258, 0.028079859273988875, 0.005884725936583334, 0.047609970469268105, 0.01642115785920572, 0.018945620583009817, 0.016757901382422256, 0.010272037264169946, 0.018815412448959488, 0.045380271565649784, 0.010830819880920313, 0.03177146652653333, 0.07885421911675124, 0.01640643364930105, 0.012662701774388553, 0.05373958550814179, 0.009579669023233076, 0.04664526658973867, 0.06117847162268816, 0.0323842104614502, 0.04451906233425102, 0.07044690210492381, 0.029400539314073902, 0.07404223700324375, 0.03183721793785451, 0.07091352625960304, 0.03183215792711464, 0.012482114740827633, 0.04394808934340554, 0.034838162452703526, 0.017434544711103363, 0.052789092559607766, 0.06391974105950325, 0.045878956499960155, 0.01577113608589336, 0.042981313196040934, 0.06747378381870447, 0.021341443737788547, 0.008335856330250541, 0.04496391427012221, 0.03952536799554383, 0.05204473854973913, 0.007449216810205291, 0.012351490046468475, 0.04664370377037314, 0.04705310498754825, 0.026321045889128602, 0.009286774457582544, 0.054391740836323275, 0.025123761546227242, 0.034223625872043834, 0.05282011145966188, 0.047914325710265875, 0.05028599985845147, 0.06478306852401265, 0.02381771378549597, 0.03843092329559788, 0.040890237902321165, 0.08062216618488874, 0.036266659792031974, 0.030213454362726024, 0.02526712724037709, 0.021137809906635555, 0.0286956369170859, 0.039928211500087095, 0.050222487339088996, 0.009406716055837611, 0.020969937059787974, 0.03767188721066041, 0.014684852137560806, 0.0466115893645873, 0.016801514767951543, 0.01791304514382876, 0.03325988343285938, 0.03557439593057479, 0.05216988284260996, 0.022460573705874627, 0.050184179112435355, 0.08604826736113719, 0.02318998134034055, 0.0703843510259063, 0.03671270682506504, 0.03065618040460733, 0.0725648441021481, 0.03725985065102577, 0.01454480647695281, 0.031126575627093835, 0.034677617236851685, 0.03687901685254709, 0.044681622361343716, 0.12064177963522174, 0.023880525334407727, 0.0690249433260291, 0.07094591645704162, 0.026868229934705362, 0.04834741436605973, 0.06451525950744268, 0.02272817587870504, 0.03755518520671514, 0.03149533013422643, 0.03151667717423651, 0.05400442976444479, 0.00563475048928071, 0.041116268313940496, 0.056396665712518085, 0.036675440477988416, 0.08027297564812245, 0.035483166350111846, 0.018651036793486248, 0.03609045573900785, 0.07080572236689829, 0.08965837243463724, 0.03814335687146072, 0.036892909857053915, 0.02077541775971411, 0.011822961199457848, 0.022625883988615487, 0.048972637873263135, 0.019871332502413182, 0.081507196920293, 0.030947010363301927, 0.02759201831424669, 0.044288757152014205, 0.0506038957035109, 0.05281506677068049, 0.06043529355778329, 0.11913129939667641, 0.02034812072862781, 0.002443686173665488, 0.03001622119618039, 0.061218748695307204, 0.04831212452582775, 0.0559443520802644, 0.05050139696968179, 0.07233366174923797, 0.04559818910615099, 0.04660651786252857, 0.04835271569449575, 0.04768807696358812, 0.03980665249870189, 0.047196685186316895, 0.04729342676939503, 0.05500622762126788, 0.024446980321719766, 0.0008396384697745465, 0.03451125741365456, 0.08638429650736433, 0.0180072816193945, 0.05525645491997561, 0.057967651575323076, 0.07596416008328238, 0.019242336012182698, 0.08958004760525881, 0.01329030302698694, 0.029309531899109006, 0.020747001643382737, 0.06614028521242642, 0.06078353797596309, 0.08082046804408874, 0.02583432724819549, 0.10570883375382233, 0.05138246703051752, 0.06901815578701996, 0.024453574423528007, 0.06160802861315109, 0.012248427280405117, 0.04127155433619215, 0.0730643410896582, 0.020605890162950082, 0.02835915194854381, 0.023102587945158445, 0.03340443273285224, 0.05553310459119178, 0.03531876771200088, 0.011632401616342608, 0.06221864665407808, 0.0603312396654679, 0.05988814590138294, 0.034243406262248755, 0.09257437120522223, 0.036098334953309066, 0.008127914212133375, 0.018763431468077244, 0.019567291357464368, 0.044881054200232036, 0.015398939928760933, 0.018076706422312606, 0.022178779754246918, 0.09225541049794805, 0.025667580550596602, 0.020581065083763773, 0.02283090826935105, 0.013201735602060874, 0.021475143317553787, 0.022018351366803534, 0.0228917682092757, 0.032241492111596375, 0.09219671284118969, 0.009272644923429095, 0.0778493186038348, 0.06455065276954444, 0.03338186378260294, 0.02795728712132381, 0.029736126044524774, 0.025346457560156143, 0.0749299873507792, 0.03539211680031112, 0.06026597663519844, 0.03335548737536996, 0.027747744837054805, 0.01348132034763694, 0.03688042262388814, 0.0386799669884626, 0.01723639798470803, 0.01776139803921744, 0.019417524998707157, 0.05153667286879594, 0.057697605582014214, 0.03722217061647004, 0.027769811999713703, 0.026350572832950184, 0.024888710449299505, 0.03127313782310775, 0.044105562546681014, 0.03777257031610897, 0.04114667051321557, 0.03195434129015813, 0.019370862583239234, 0.030032895099852356, 0.03172920911663002, 0.07330040342264599, 0.012138792437561339, 0.0864439441131488, 0.03714393771764252, 0.05134086462578947, 0.023107425790400277, 0.020464851460870237, 0.044025674897937045, 0.0502519817241738, 0.022848359752266158, 0.061079726719688025, 0.05747545540573136, 0.04807301699334095, 0.03150709724474338, 0.04291777769404073, 0.08092398950529676, 0.013793934016458452, 0.0818772250485997, 0.043446274939924485, 0.019475265045560176, 0.20891046091433496, 0.1929849945008755, 0.13877842094629042, 0.11203354840437252, 0.163545124232769, 0.10923085403778862, 0.15712469455695924, 0.09995912937747856, 0.2094429992740193, 0.17337142760234495, 0.17299975238500104, 0.1406725580173154, 0.23458899269180916, 0.12924669370535882, 0.11739866132096899, 0.14735186412449808, 0.2095645774276026, 0.21848518100957717, 0.1150766181789579, 0.13540432457962345, 0.14462428467888988, 0.22656445151134846, 0.13674792022474352, 0.088430218578827, 0.1402745753406517, 0.1521597553284899, 0.09072676631471804, 0.12253113631759921, 0.1711006817077437, 0.17246863894885586, 0.09730016842724816, 0.12395144800745672, 0.14056340580986393, 0.13343373193375527, 0.180847265967919, 0.12604611625354137, 0.13216784824767422, 0.2416461793285224, 0.144219039488704, 0.12671185432062035, 0.09884656286768376, 0.17644149431538197, 0.07968821307463993, 0.14470716007053852, 0.1140998024493456, 0.14501875867286038, 0.16912681020555959, 0.1980358734726906, 0.13260361438076343, 0.15033551611967627, 0.10686168882755503, 0.1344966942504529, 0.37567104002641094, 0.09256701676114913, 0.12299307201418186, 0.0871101877982578, 0.16771202967051538, 0.18557392120842012, 0.21213590558017456, 0.13029454876818966, 0.15633177823357045, 0.18827965182642784, 0.12479985974008038, 0.10329678294158752, 0.20018763059089262, 0.16634869960046586, 0.1321204886921952, 0.10974474581739596, 0.13490042258654872, 0.1479706486626979, 0.08426462315143117, 0.10533890521694576, 0.21871992567133522, 0.23990411071046708, 0.16922234136971737, 0.17366522232130652, 0.13371615790792052, 0.10462206908531728, 0.2612052773756366, 0.13976846701435505, 0.17825853229770738, 0.12656003101578644, 0.1548920232321947, 0.1537355215799424, 0.19433703243492112, 0.06186670586166363, 0.1936531917101914, 0.27797457431593253, 0.09704562805352673, 0.14576143495017482, 0.13303513638675213, 0.0820953379415216, 0.17107487986645392, 0.14972119021319574, 0.19448016830269368, 0.1620581782152576, 0.11993668763147247, 0.14418894755503825, 0.11707344933623269, 0.21140447547358854, 0.17480156053939175, 0.1404266131501044, 0.1287374750620896, 0.1546515022674876, 0.13871745566927618, 0.2409247236867105, 0.1713983681533606, 0.1382265005621218, 0.08112792977161946, 0.17621221952140334, 0.12871067730649827, 0.23930031085206618, 0.19782423402272886, 0.12050944560718153, 0.23858152119623077, 0.15357513341211504, 0.11515036180254914, 0.16427943482995033, 0.17118426190028269, 0.12460626166073546, 0.13554640324606052, 0.09846757151066296, 0.1318723987787962, 0.18969037209547338, 0.09841538560126098, 0.13031688789206167, 0.11045750636126726, 0.2022332845315818, 0.19437939709713384, 0.12822368287391242, 0.1410213731709988, 0.1300868929754342, 0.13078686751184926, 0.1230192798820715, 0.1474219918130867, 0.10146928785909569, 0.12343138155917968, 0.12498459418214138, 0.1958770530238267, 0.1959421245321151, 0.12812817469239235, 0.08963414107359226, 0.1629783110993524, 0.28495063224146444, 0.11848247655096555, 0.11754702190838515, 0.13439678106336825, 0.16239996068179607, 0.09692277819398912, 0.13938894705666652, 0.1191823208524335, 0.20576125731871975, 0.10748523077176464, 0.10358462515737742, 0.0700435491519109, 0.13774293054255748, 0.22574222466397673, 0.140933319024982, 0.14563408049364246, 0.21787237195718676, 0.22253259205289427, 0.15157581246908636, 0.09537717282411554, 0.17446095784825666, 0.13500621932889187, 0.08292455917164203, 0.08697388543476982, 0.1779694413586009, 0.11352111495310262, 0.11775578086775158, 0.22474816429518887, 0.16513449620575676, 0.19308564313236745, 0.16877013498977309, 0.12047346245737807, 0.12308309500616406], [0.034797188240073385, 0.029029070940469543, 0.024603197140799418, 0.025381998294183326, 0.018437648747837352, 0.02705709933633766, 0.0343115842570701, 0.050418046603520075, 0.022810951678923542, 0.02219850268785752, 0.019984939511144356, 0.03781365944192775, 0.02029232079944303, 0.021123062714093158, 0.019913704825505134, 0.06382735085583503, 0.056723482651455756, 0.015185514536325731, 0.08378703627855548, 0.0295868135928627, 0.032325577922165394, 0.036106984085974195, 0.049932890781952496, 0.03032942092226398, 0.045278017979956446, 0.040592942161545645, 0.05695092266485576, 0.027883242808222294, 0.09996272232984343, 0.04996927995835582, 0.026867484914199, 0.039625403756696376, 0.02084684971299383, 0.046848459920335206, 0.015816385069140987, 0.09419271662350624, 0.010702896604104149, 0.08931701897733635, 0.01881113193268257, 0.024757805175238082, 0.06376338251415761, 0.07454649139676364, 0.024602268259191228, 0.0185062212779397, 0.03272404706466102, 0.001983622843850284, 0.04262790151481186, 0.04826247053701551, 0.02721944868925118, 0.10016208139037895, 0.019274061628346963, 0.009226554201074667, 0.060621081370740175, 0.024095376607992, 0.07744483184069395, 0.046158264496273575, 0.04261623016528545, 0.05379262560557935, 0.06139088865189303, 0.02048053902633969, 0.04866491950627777, 0.027097253834888823, 0.04820330173618371, 0.0699826987880853, 0.02153901015258124, 0.042276722979882074, 0.0361150203482999, 0.12681306985717627, 0.012955573357401357, 0.10074620045000508, 0.0168967739708962, 0.01940177231576414, 0.0013195054118348766, 0.07310516591514311, 0.015576134150427197, 0.025365684451835773, 0.0475015651975428, 0.022747607698904413, 0.0443780102256325, 0.008883377454513985, 0.07027834743982361, 0.023301952751353387, 0.04904940754415528, 0.02996191130800834, 0.021853950813472755, 0.04395174358280436, 0.07740771488076256, 0.028234896317665136, 0.026061217593509826, 0.048991192522789204, 0.06474749906168831, 0.041277407247933655, 0.02312284330987642, 0.019555757903764327, 0.03067958247547429, 0.04435726839508261, 0.03700223060384874, 0.08525054766646317, 0.05285809792938733, 0.06945547707859548, 0.013102928454416895, 0.07239514030516148, 0.08761806578765954, 0.026662495107420033, 0.033326169190507744, 0.02299828315904785, 0.02190610990979739, 0.055765076014663906, 0.0662561483500946, 0.02223101354414417, 0.05973816503800693, 0.06794980787221463, 0.07140985164310663, 0.014959109699233405, 0.0515954586256656, 0.006239872328155945, 0.07231555143070799, 0.07875476558242114, 0.033404425071973, 0.022632556614435972, 0.02238924134402506, 0.038004269778367974, 0.08999058646300147, 0.02570489477816849, 0.04514400238892244, 0.008764686494795306, 0.051636835034455986, 0.016676611792776855, 0.052983387778963775, 0.012097342292808238, 0.0467121001002529, 0.025232825653567433, 0.017682946805331497, 0.019212573496324402, 0.05737703225965943, 0.029243489374376597, 0.07623211465655796, 0.04088679816754114, 0.027841682538330078, 0.023531985972377083, 0.016029090338927365, 0.02529446317273523, 0.011993453109396562, 0.04043568346288897, 0.016520400719356634, 0.13859220029365632, 0.07469890458929924, 0.047663163784290516, 0.09489394754411713, 0.06400966829049491, 0.020614284571380388, 0.01743311212668496, 0.02291754132226831, 0.04589450425438343, 0.006275490149780507, 0.036965443061724786, 0.06801631196492142, 0.027663438776207548, 0.01646087760285985, 0.01803166619802435, 0.05471497631421494, 0.07753658619138502, 0.05763269495218993, 0.035682008301298467, 0.025228774963667797, 0.033259799163187706, 0.10251414751814258, 0.016220406433867834, 0.03991387416458419, 0.03180049742842394, 0.027497237916254712, 0.008753939238827555, 0.11920396283629442, 0.018738956874116294, 0.0548232666727516, 0.0525742776751999, 0.021977396306371497, 0.05914293004259948, 0.00889466097202873, 0.021557710358812925, 0.02676959611445425, 0.06732974396718126, 0.021354365725851348, 0.059520553932675434, 0.020099659262585546, 0.0302755898390446, 0.03560145415606038, 0.062409965621848265, 0.03519762239809479, 0.03714613255954558, 0.03191989797708248, 0.02633497145237221, 0.05622042718553736, 0.035012761551526286, 0.03550441379869177, 0.006761109454542279, 0.048145462097900535, 0.04262989334341499, 0.011145939614864127, 0.06361365445979661, 0.05441927786676153, 0.032232490578486074, 0.02689837357930599, 0.012345548077005775, 0.07134990526303168, 0.020025256803379427, 0.01594022222449102, 0.011406056151064414, 0.034600138934629585, 0.03515454910455212, 0.03257647171736725, 0.07607894303697733, 0.044844484993166504, 0.0833390357213155, 0.08248719191479106, 0.030778417393805522, 0.028638777871345802, 0.05290248889415976, 0.027666729123842333, 0.012191495456312214, 0.01350628906830905, 0.011179810277216378, 0.08524127034170013, 0.03861354716542748, 0.03168660888238059, 0.07150120762807709, 0.07394600103819564, 0.005676176214981224, 0.033202350229745915, 0.012437713242346242, 0.05001390841038478, 0.03915171627135527, 0.017601954074756756, 0.04087046134255586, 0.055142798115529364, 0.009652564204448174, 0.04668234907571347, 0.06272057214030816, 0.04702895789617493, 0.0555013579076096, 0.038637839813506415, 0.057432075677018975, 0.01720226110680209, 0.09234105912788261, 0.04160770605648718, 0.02717222894481834, 0.03498589101758215, 0.009795826476728244, 0.014109094927628196, 0.033238199314162616, 0.06037649247915514, 0.05550461378128779, 0.06056807957769883, 0.03178444405597064, 0.013607863708579493, 0.04708657919939968, 0.10043843228730465, 0.008971165384977095, 0.03246319795688314, 0.07766775576578033, 0.011655103674368754, 0.08808714908457572, 0.02249992381210529, 0.06468962877988815, 0.03427105437543604, 0.03533720744833831, 0.04156010901375164, 0.02723756283822079, 0.05121849740164415, 0.054728275600580446, 0.02227747103109235, 0.012653334434294413, 0.046217912102058056, 0.04472965224375648, 0.009904298781146927, 0.06291792022004243, 0.052819850989767624, 0.06316190007172766, 0.019322982087971705, 0.06618233577859017, 0.045486313456128684, 0.007949432005144415, 0.027576842112466696, 0.10993544042350785, 0.052962488900389404, 0.04324939417382402, 0.03584285995232002, 0.0291543799422441, 0.0318039275871049, 0.11542820657092719, 0.06276123608732898, 0.046119033133671175, 0.025229826419343872, 0.044682407601466106, 0.030337039666670947, 0.04313102975908307, 0.047334485251696846, 0.02869121275932318, 0.07477942043014112, 0.01606346278887002, 0.05809065848288517, 0.03624614778785937, 0.03461428857859104, 0.02707332316335411, 0.07398094996930131, 0.013209674188176231, 0.04762212062374719, 0.010362081323570062, 0.015477576938968514, 0.057064414760398294, 0.036744924652720654, 0.035259472506661574, 0.028686367253202106, 0.018695508197490728, 0.04927659091810065, 0.0681670933901783, 0.05500710479194119, 0.013228411741194226, 0.10258455099838396, 0.015808859212894835, 0.01912934378901076, 0.0679014600633133, 0.07486476262490596, 0.053239939133486444, 0.046514311519962166, 0.05327642024044068, 0.02015074392059638, 0.04069604610483493, 0.01693020796313161, 0.08051489089285174, 0.04086905557121481, 0.01821470184011325, 0.034906413225877675, 0.01496687783078561, 0.030394576700224035, 0.05646319661830222, 0.020563937272996675, 0.04292481804206487, 0.019855409364907012, 0.06694308407003842, 0.043743053571351116, 0.037450112417460456, 0.1139360434946514, 0.052035262042115775, 0.03944261134752343, 0.013258717221868856, 0.02926147137317927, 0.023223417247795773, 0.045746971041925495, 0.014552457780096562, 0.0585235441253791, 0.017085505476702127, 0.13705055559835128, 0.1641130558545551, 0.06900631972858984, 0.09171936345557052, 0.1344628638077167, 0.20233417831120953, 0.06383971551493292, 0.1064504375080428, 0.1376504024430629, 0.1837054787263755, 0.12389056700011417, 0.18650784367515197, 0.13673350245000856, 0.15526337669261042, 0.12419996693009332, 0.2469441982647104, 0.15745748315126668, 0.11199994778801357, 0.19071525984233428, 0.07703976285073065, 0.11688115360635905, 0.13591473832005455, 0.20953937313489376, 0.11845796173738858, 0.10902728149366957, 0.10948146438045848, 0.12221157040086486, 0.08450224830378449, 0.2736124390315625, 0.17611538600777427, 0.12619802382804696, 0.07515568451415147, 0.13531443182258837, 0.15129004635157126, 0.12666401212974904, 0.27100014049680005, 0.12557666523442154, 0.22078123844919667, 0.13507211821213846, 0.14193995855748653, 0.13751489681101617, 0.28911916178561026, 0.15080909635270798, 0.1834977463248276, 0.12232351882923996, 0.18452099464353056, 0.17290144798255738, 0.16289145205049746, 0.08092728368337117, 0.17385109057349546, 0.17093088598020617, 0.07237335276459494, 0.11041154874668968, 0.10354208429494213, 0.17163246930126222, 0.1168834901745281, 0.2773941554609807, 0.1502694640188448, 0.17179498719351907, 0.09092398032906557, 0.08795653875436514, 0.12780174462785646, 0.14929283981121358, 0.2207485264948299, 0.1369063472074847, 0.09807594736377079, 0.04936151176450714, 0.24385281898561986, 0.08464430398758381, 0.1888435691474907, 0.10452247765516082, 0.16465216724862977, 0.1513397194925816, 0.15128043960900078, 0.12508062330344993, 0.11967978770694426, 0.15649903054919936, 0.11500138834479356, 0.17857811353620023, 0.17653520219028, 0.24414796201932817, 0.08988970800513223, 0.19466609784191657, 0.13007745477220706, 0.10033251297089363, 0.12721861382165264, 0.14224587278741022, 0.10703294012214869, 0.11260171751341513, 0.17138971135981623, 0.17088620773246213, 0.10294389220014696, 0.15278296785489207, 0.10578512078932217, 0.142446817649949, 0.12039062537012563, 0.096785020263445, 0.13640118883021418, 0.08431671713028224, 0.20461123677030688, 0.11720649582604248, 0.16704971601645793, 0.19936897371324802, 0.14276881972628255, 0.17964980925523466, 0.10681626747452444, 0.08669072401619728, 0.13204227111512615, 0.12474550580185269, 0.08030274582486, 0.1217004671813019, 0.10295176758400856, 0.1690792055019448, 0.17386039088089622, 0.15637978130290586, 0.13629389055553945, 0.06988376619354372, 0.15396568503591324, 0.08480361197143794, 0.11568198851760357, 0.12764071294617269, 0.12238472925438998, 0.14782025028140316, 0.1090830373727987, 0.13096458458852384, 0.20071996976771664, 0.11110139560074576, 0.10903470488565584, 0.19225823753062757, 0.07277945597325602, 0.16228549182415009, 0.0979683886192018, 0.07267037271371773, 0.12324245661617288, 0.1893491871775158, 0.13475261358243806, 0.18472305799443878, 0.08667235322777303, 0.1526457768294119, 0.10342465833790841, 0.21247598733152115, 0.08160386189457872, 0.13546668413665988, 0.11517167436860262, 0.11397177383543984, 0.16663000708626163, 0.1648228976034349, 0.1969434627361836, 0.12620176233711744, 0.20360816720752947, 0.14309834478603256, 0.16300153888521657, 0.1661781837502795, 0.14108229248273757, 0.0988132993300115, 0.14632265564174424, 0.24591230847422155, 0.07822444121683798, 0.10278610107038291, 0.1737322243711641, 0.16928752013031514, 0.14574459633759915, 0.07742145083724492, 0.13342596380220306, 0.17060816378122376, 0.13919716460570214, 0.20286172177762757, 0.26704685101586007, 0.15042635882573743, 0.07842193102283825, 0.22708908384365423, 0.1688924485877637, 0.2544212317274463, 0.1172844069679418, 0.17317628968627224, 0.1861373788767284], [0.031665110540005474, 0.07342234163755372, 0.013061474479224174, 0.0225066902836965, 0.03036280128834469, 0.059216516618166244, 0.010756443277181638, 0.0997137820588485, 0.04499718163823409, 0.028152448020034262, 0.009103485048868725, 0.024861684782550703, 0.026784404594030593, 0.13567997833653805, 0.044634473480043874, 0.05369445909896205, 0.030997677503394026, 0.008997920048122686, 0.04083489954111077, 0.039621040885967594, 0.05907881997465607, 0.055886148550217195, 0.04751123322714721, 0.020455016807142287, 0.034000115889695384, 0.04528266047277758, 0.0356880450741418, 0.08634867341888529, 0.04164052143272373, 0.062089074373004906, 0.052139725791470665, 0.030901493249280803, 0.003226651014917861, 0.01885074059358768, 0.07153375870397977, 0.03817722178815353, 0.0361338661112372, 0.03152588363586655, 0.006607155946473922, 0.019875126552858183, 0.02140487198747935, 0.03151877817036885, 0.05127370552790742, 0.09288585489435543, 0.03627304513488085, 0.035354145652344154, 0.04051457902777099, 0.026018879744374467, 0.03222911213074, 0.04115606275116725, 0.03439548237609767, 0.053493035431470604, 0.06237951362685812, 0.011245864293267651, 0.0743163432625513, 0.013517489273762031, 0.043843311498001705, 0.04787709766758546, 0.009089908055630664, 0.039966864466306665, 0.019110099660352837, 0.012913847420995515, 0.03681442414921138, 0.01750448853859017, 0.03001902507798326, 0.012690316371229148, 0.03474021428114465, 0.05703285576835756, 0.029469678749240218, 0.0038271200666654738, 0.14008692976447845, 0.047330490103171724, 0.041718482370338136, 0.03686014427653244, 0.04701642852817332, 0.001322449463787639, 0.023723950369223475, 0.04665703753069524, 0.06080227265615137, 0.03229452837859431, 0.032290284251493793, 0.00813469983592269, 0.02753710513183427, 0.02813198198113711, 0.0304555113337213, 0.04334021006680785, 0.02216761210753072, 0.0899029306827053, 0.02371687171680312, 0.12675274809401843, 0.02126631157983455, 0.014707935324329284, 0.017225080950846596, 0.025687169418820453, 0.03595309617418436, 0.024868104599356174, 0.018174501376286633, 0.0766411443210898, 0.07479756905306732, 0.023762199224062988, 0.02355929892209749, 0.0637332063108202, 0.017679449613957156, 0.06509170236606752, 0.03145910375150702, 0.05391028904986959, 0.04277472226550022, 0.016012442290722843, 0.03535546715401354, 0.01059990182834407, 0.13776392135168278, 0.07012267837360983, 0.05875232862308622, 0.06714727714537613, 0.08190134915733531, 0.01742164379045848, 0.0092593657468716, 0.014207795780572682, 0.07643371069383237, 0.13831564255299109, 0.0303589019008101, 0.02923172609429927, 0.059261823058008194, 0.04866719478741289, 0.0556780943917411, 0.03437976225189144, 0.04478456925660853, 0.03977582512062885, 0.03217090477025317, 0.037879489377261176, 0.028714902113161744, 0.019905352551910668, 0.023533636891853907, 0.033584562986488306, 0.10010679282488362, 0.02919728086600381, 0.016063504923705854, 0.02339499987541668, 0.01617155683737609, 0.042680585381364634, 0.05309500295909182, 0.042336274824676015, 0.04052937218558885, 0.03152042334418624, 0.010201515040300306, 0.053530454996132085, 0.04461311877915456, 0.019974043825641274, 0.017903154948726296, 0.018806929940417893, 0.032430225532622106, 0.051009880168543714, 0.02898991618665957, 0.03360943020051045, 0.029250077730525407, 0.08150432409057695, 0.022992047203344204, 0.03908796626473627, 0.01637546071452239, 0.02789388376949055, 0.0299383157999405, 0.003900168704867904, 0.02293809546127675, 0.020973208255224654, 0.015035151586597486, 0.030143336250236442, 0.0481232991742511, 0.03378754947334528, 0.09663178735683042, 0.07740498760775213, 0.03587328130379319, 0.06933124059991491, 0.02734864750246127, 0.043178136505547075, 0.05375103852260978, 0.04252476692800561, 0.06040605581215313, 0.08314929872510896, 0.011960545802609095, 0.013274536937505249, 0.012641919724222635, 0.05291019573867802, 0.054144750259095625, 0.04493783280674008, 0.05145989170658493, 0.01951028292457904, 0.03387094197434283, 0.017930293613443934, 0.0091768772296247, 0.02507893199611816, 0.02988666040642608, 0.09191362037053032, 0.03600403719070939, 0.007896251617855723, 0.020675033428556016, 0.011662332671544245, 0.06393507813974734, 0.0228781126920254, 0.03677760596357046, 0.02549796293850147, 0.04293912473405081, 0.049108779358287016, 0.025088542569128257, 0.02474356934638514, 0.01918011626619245, 0.025921069468641957, 0.024403110296735843, 0.023863769076283903, 0.03633769146437126, 0.012724029027947016, 0.020796661377854405, 0.021927001127492518, 0.07173976740769802, 0.03449231972016635, 0.05863623948948038, 0.024279739497409716, 0.024994051369327693, 0.05169591190473688, 0.051237595973596464, 0.047903317026793964, 0.007391039135625527, 0.041835498470332355, 0.0326906111572058, 0.02594431640670425, 0.015119988163332305, 0.02239481846411382, 0.03362821467641381, 0.04687305134270461, 0.10314489068884043, 0.045505415858520616, 0.07469561041122483, 0.04538058949213836, 0.05977195717634694, 0.029852810811491746, 0.01815634126204156, 0.026457269728604346, 0.0300463610103414, 0.006613620292139992, 0.05375214551966037, 0.014884710112857002, 0.050659211082083565, 0.09783119759372166, 0.07345526043566004, 0.07288064086629499, 0.04610232092560299, 0.03441582584092694, 0.06903220583955127, 0.02597934960748159, 0.004793073148316434, 0.046217778036671306, 0.07793353464935096, 0.03126555738309699, 0.020628070323577812, 0.027748819275368607, 0.04038671129232934, 0.05040970390602466, 0.05622838300863101, 0.03210517251113009, 0.039286517102511666, 0.028886873530404224, 0.022895740375163096, 0.08247108874662269, 0.03726214125391938, 0.09403278810843345, 0.06529808645286868, 0.0620610470462951, 0.031488998417532256, 0.03682805668382395, 0.050051580784061266, 0.047241401738457145, 0.09584089350556174, 0.03427300789964295, 0.03779514309679789, 0.0876163037854337, 0.0441225084115661, 0.024140918619870663, 0.014452236242622379, 0.03438569177242537, 0.041770078392038425, 0.0030563496693503116, 0.039634964533991394, 0.037879198263849945, 0.04326427543175317, 0.06485161041059802, 0.0683241950408105, 0.010695939568141776, 0.03820728690874192, 0.04098624787143162, 0.01663472018985739, 0.012724995256341513, 0.012051658554663582, 0.0104679862758325, 0.01791347798350598, 0.018500287926966147, 0.017202898874999057, 0.011227061622776093, 0.014643573404980764, 0.043491397518664605, 0.011405407849158491, 0.06731612292388756, 0.02295310695415303, 0.010758912953127538, 0.01922999050528292, 0.03399719326426426, 0.06307498356627841, 0.04235898550119131, 0.04588942892188507, 0.03597234796372152, 0.046492006870046745, 0.0416687211292165, 0.004903072361729198, 0.06547888320299887, 0.11131716426461936, 0.028032197113779765, 0.037136740321593906, 0.038053916106300975, 0.08638334655833822, 0.017917842769454566, 0.04809665846668425, 0.027649080373286724, 0.021684911597760457, 0.07509417531471099, 0.021490798324286457, 0.0346583616168749, 0.04150613045860683, 0.016270311316475272, 0.034313645033586415, 0.011193822982961373, 0.03114026178786111, 0.05361612277826475, 0.06657863306182046, 0.046823722941260186, 0.07857127220279748, 0.026602014381017898, 0.06893244587005147, 0.03208937577813143, 0.016370963778406862, 0.02006866717560878, 0.017865884771210053, 0.028725780561686527, 0.009540814001323476, 0.0045239191686344, 0.01347934096796258, 0.046927968355556654, 0.016862596873374238, 0.07455358537094248, 0.04932198928849352, 0.012325306118826472, 0.0290717841726878, 0.07092879439193396, 0.06373946141872196, 0.00730811634228655, 0.07928649954978498, 0.11814188152070969, 0.13731739934413664, 0.0733285571538633, 0.10109660906657096, 0.11338272883046059, 0.188593564014281, 0.14471627651683747, 0.1159408955924934, 0.12475931836712746, 0.10811543002003625, 0.18116267968810376, 0.13635393652704456, 0.32550885912872135, 0.1520264560296651, 0.22104414450305127, 0.14095830881307203, 0.1005191243283691, 0.1050678556484561, 0.13412537143355416, 0.14670324812252677, 0.198214310672014, 0.1638866155858963, 0.10800670682182235, 0.2308663876066285, 0.13432754203677177, 0.11938321208881757, 0.21766663138424197, 0.16939322494210737, 0.21650407763738788, 0.11127625516946278, 0.14114403916943458, 0.12322462208929563, 0.23077220475721746, 0.14347890662329812, 0.11188175574305559, 0.16210061948626273, 0.15241109345468784, 0.19319574528884506, 0.11029828264708481, 0.11425010123921019, 0.10165949982981529, 0.14935299303502808, 0.17344068195069992, 0.05975570462103333, 0.09801487483444715, 0.10428420132807187, 0.2745908558849366, 0.11071141088201154, 0.12041527041864973, 0.11991571980498492, 0.13938706248037278, 0.17517482921961816, 0.14920000527654925, 0.36617029338113727, 0.09661304884620252, 0.13007408398534023, 0.10088503090364319, 0.09355294127618113, 0.11755640648545758, 0.09694298759343163, 0.08015253130466708, 0.19195408530292973, 0.09746430276502525, 0.1956788047907814, 0.16532018059684386, 0.12014623566140091, 0.24369973929659014, 0.14506624080240726, 0.17583430834835576, 0.191913896330422, 0.11195121693515009, 0.11517957273510196, 0.08736038445344857, 0.1828911732281408, 0.10651043751427244, 0.09201927155616785, 0.2241727556552618, 0.1502221963939167, 0.1878382626079744, 0.09960312065818619, 0.14916383060476474, 0.1251676662134067, 0.10296782478690149, 0.16395073714515856, 0.1028398804426674, 0.0783740658493292, 0.19754232898835214, 0.12875874166286763, 0.2679679951360149, 0.13899994293047538, 0.10181870056136001, 0.15107404020044113, 0.10929462319660573, 0.22162626407319502, 0.2822897943758196, 0.14554069437567266, 0.16844874578377894, 0.13908182240782246, 0.0740901941073037, 0.07195696865599002, 0.11866823755084507, 0.10243299582432355, 0.09893159862727889, 0.08087046294202728, 0.14140472356830874, 0.17243765835319796, 0.12880300622313254, 0.20800206449724015, 0.13428678615920006, 0.219062443582281, 0.18408188836709147, 0.12270585032961062, 0.15403328463435173, 0.1294711727889315, 0.163840068083617, 0.11924589848926953, 0.10147212238441553, 0.1445679312511798, 0.3005753325358514, 0.08939777230543476, 0.15122915768334944, 0.20731008791875458, 0.15209233959115323, 0.12856774062158602, 0.07996876213339069, 0.14133634256018748, 0.12158268882382302, 0.23587382939313692, 0.15367484741633938, 0.12208644526019213, 0.2985139431491975, 0.1698336642115347, 0.1657696750255362, 0.20678220737364986, 0.08161330775868508, 0.1777059377561654, 0.20265420388069846, 0.1475853217585433, 0.08246877516109137, 0.13090294515413622, 0.171351621468221, 0.13227724560326146, 0.11583125308877039, 0.07286046977124869, 0.1317258155153644, 0.15811529220832934, 0.1335193192766559, 0.14855148120512887, 0.10023153492159421, 0.13910684283942948, 0.12373561039566995, 0.07541515083322603, 0.1505712107304604, 0.1526731568118257, 0.13836027483545965, 0.14653791102670854, 0.1312699012698666, 0.10915309611347415, 0.12077812796398518, 0.1124627031986752, 0.12939076420039902, 0.14451698640421515, 0.11994214983837259, 0.11076398749625492, 0.15132447434288843, 0.11259128339588644, 0.16077259074776404, 0.1560704349990814, 0.1478039172868575, 0.15869583363734907, 0.1346896258333037, 0.12569699466468828, 0.21233332643826164, 0.135239263275458, 0.10263705866471415], [0.055659501437818816, 0.02669682542252685, 0.011966523203638293, 0.0239967274659824, 0.06130990549741734, 0.04231492778466594, 0.04237252227481335, 0.0754173495055687, 0.04023476924386717, 0.02973558403731835, 0.02205559473124243, 0.04041519444135409, 0.07497175446441097, 0.042344050617107463, 0.037796862964187904, 0.022901553067288572, 0.030636647077757987, 0.012996621305994209, 0.05247609584682411, 0.007773534387289997, 0.0288367924475742, 0.015152498062009053, 0.035297865002986886, 0.007030328072892923, 0.0521512937191273, 0.03054911578674951, 0.05034662805677903, 0.01809894403953466, 0.0552565774940435, 0.08350064196894247, 0.012580624071791047, 0.03938758325192236, 0.01743155505297886, 0.056837717852284836, 0.01565864469270192, 0.04712594079694921, 0.017306391607909914, 0.03914167668910758, 0.015919582858200998, 0.07175430009562163, 0.020231391911605195, 0.029155121132310842, 0.08310462047736492, 0.03499975720901163, 0.07135238738790636, 0.03949587361045903, 0.0538275707062454, 0.02863814584880827, 0.043304303525796825, 0.04299364721162185, 0.01606129571765421, 0.024066094812306187, 0.05766015154339614, 0.041310414146151275, 0.012175841407189447, 0.010957487731150562, 0.041158598502196615, 0.023394714507664886, 0.017038339358423988, 0.029483175303246227, 0.06696233585957559, 0.025139016272019477, 0.0015308478830247038, 0.04199892034633987, 0.005361413190727153, 0.024987147001910116, 0.00838207920277191, 0.03141282629522105, 0.032153978057566195, 0.05941743466762766, 0.05571233469151682, 0.02664552434467741, 0.05882573133755115, 0.03321740385745803, 0.0899486201665094, 0.05496060325493736, 0.0700748898088932, 0.04770719468773854, 0.02498459401390245, 0.0563313260734562, 0.016689692744083943, 0.04141695399378096, 0.08893397501519612, 0.026571495353334376, 0.11197963113626165, 0.027451914239434466, 0.012724875555103345, 0.020368159673507177, 0.04761891071534446, 0.029504884319800525, 0.03674228547982151, 0.03828309130884948, 0.0353715320177857, 0.04297003638179552, 0.07724962497670805, 0.03760583894026857, 0.06972374574792001, 0.012467963181646361, 0.018908024818125754, 0.030444431787116394, 0.02324439081994276, 0.07292306681554164, 0.019497958485097177, 0.0676688144824678, 0.04852287148335769, 0.07154733378199801, 0.046824105985222325, 0.05116680561895332, 0.02204686132890563, 0.043158122458525246, 0.024677839002481872, 0.0468793677376403, 0.019958965300071626, 0.049564149681358576, 0.019292989745736122, 0.032447853215759805, 0.07713124907064824, 0.05473653785884381, 0.030701783703519937, 0.03418202346731578, 0.07082482859972986, 0.023952024320380825, 0.06123217438618022, 0.008210103955089806, 0.0439551335218693, 0.04586065848988872, 0.09626431030131156, 0.029449429130181674, 0.03416941749052175, 0.030719453521493464, 0.012344833700016383, 0.02784767334589795, 0.050077746517115065, 0.05305841843026781, 0.01868817290561574, 0.03023752101486729, 0.09784054386639789, 0.033477073189832514, 0.0472190932581021, 0.07745895084113845, 0.05525268959782778, 0.019756725748940822, 0.05239368010793002, 0.040518911254982796, 0.008042409223684622, 0.06333063093705044, 0.01463355010210146, 0.06065675042449467, 0.021578084467159166, 0.03521982745658006, 0.006841709565055827, 0.07149581436909015, 0.0319015386799771, 0.0474482684606506, 0.002898066328094912, 0.03485667113695414, 0.05356833804398776, 0.05969151794429749, 0.05711930112973337, 0.06604413351704998, 0.04658055131233508, 0.022435792676743962, 0.019878520322362744, 0.027852392447511518, 0.07942693878806407, 0.0092344707621622, 0.05030037549835059, 0.056757661664197524, 0.016748509144470576, 0.06846448872238398, 0.02982498649808188, 0.06502859970374454, 0.04437442110370725, 0.021902382892045765, 0.015621397497823403, 0.04582231195883886, 0.018685805693929716, 0.024650798013974583, 0.04416021142875956, 0.070258513423464, 0.06580292307321103, 0.024876244283551653, 0.05766299372959522, 0.038373439888199495, 0.06170791881759802, 0.0682933600018582, 0.020788711300420187, 0.04302560839982283, 0.09958177744861572, 0.055823225918556416, 0.019538488366731235, 0.04665361311767371, 0.020792700703285878, 0.05970677075486991, 0.02324853535561312, 0.048050911526285836, 0.021882464606014472, 0.04765030116804185, 0.020554184973720583, 0.007284017131408497, 0.03290944034233689, 0.03648679132663435, 0.03477172730790992, 0.05484924854470357, 0.02903400454670191, 0.06447824979982068, 0.020787309359518752, 0.04223787849168143, 0.023857196041893576, 0.03513310630355151, 0.044104110810064504, 0.03991521481845168, 0.0343074512127186, 0.018329977005299543, 0.030115780067600073, 0.010944400076574136, 0.007182983540734577, 0.04539323377332861, 0.03157542654192977, 0.0458524766708574, 0.09168055344132647, 0.07570965035307793, 0.07617516368026696, 0.04668013125117268, 0.04478253529316956, 0.02219948711084022, 0.027810248035577037, 0.005385709190440755, 0.04396520757807359, 0.05377205997525204, 0.015339882210678151, 0.025382812262602875, 0.03920977424469687, 0.07121343436020036, 0.040159213822335005, 0.08743687067180873, 0.07702288593375876, 0.01818621486064888, 0.01656947631178604, 0.07162034196118194, 0.005199671920103532, 0.062812571639135, 0.01379720904233475, 0.024322456560067596, 0.045127056524037354, 0.028631247227050127, 0.043653792836853576, 0.0075653241383993345, 0.028071916857433897, 0.08928064512269152, 0.06095114269203717, 0.06905744077577707, 0.037088867487205614, 0.035740774905970024, 0.026820052580367175, 0.06230522608084064, 0.04911419176947206, 0.03991264076302609, 0.05813092789462498, 0.04014936576206838, 0.027086034477237734, 0.035867566287878065, 0.006572253938253609, 0.04699449926134079, 0.014208647095778537, 0.04977889561785325, 0.011830731246229863, 0.05770462294740062, 0.03890748361065503, 0.029278097396355965, 0.06309084158631102, 0.0014330379663959087, 0.02379315875230297, 0.02121105174263639, 0.048412275200168935, 0.00725562734934952, 0.02366513779927646, 0.049860192868377895, 0.026139067448375207, 0.031214223746510766, 0.01921882285856672, 0.03514316503799731, 0.06522679431063515, 0.048682899589860634, 0.0122601828996032, 0.04376079999811707, 0.0030274928130600005, 0.06969269620434893, 0.032015513410911925, 0.009772824686801723, 0.008624679138583523, 0.02176500417502417, 0.04640595604395194, 0.02140812594593773, 0.0161889010679818, 0.03157456469301495, 0.028086719591350808, 0.03837122972453794, 0.08544570090429437, 0.04391605920729138, 0.016092785761781758, 0.03762605983102995, 0.05536323225486183, 0.032323137932126565, 0.0034898778680907266, 0.06511622484052373, 0.05129972953469523, 0.009666706187530391, 0.0092262918159606, 0.02596076814487817, 0.028063909323405356, 0.015450040866140158, 0.031054293316218163, 0.02364104433405784, 0.043630764233849706, 0.05034071385800358, 0.01153190907526521, 0.041992466055577805, 0.1037254014743432, 0.02475957292312336, 0.04933040476434174, 0.0129288426345034, 0.047579365256693096, 0.03246643467836323, 0.015754526342085053, 0.09892564612410723, 0.03397557426304106, 0.05714320307297092, 0.053181406185631795, 0.0319448858499527, 0.025432067885694486, 0.03283121893482824, 0.13084469182837394, 0.05390093894675375, 0.047963669433468775, 0.08543845371253068, 0.010011664088515025, 0.024707431063777017, 0.02544674229988408, 0.04618542997406856, 0.019002969925021453, 0.029043576815315796, 0.02770437659966129, 0.030949002191905054, 0.04409380692748293, 0.017966292085005872, 0.02610445942639584, 0.019774790102195357, 0.04468680494615147, 0.014249737179207226, 0.04766373835023373, 0.0349346052614912, 0.12481259978226117, 0.12371674931097416, 0.17879062632639564, 0.10828857355180288, 0.23887756821368974, 0.2180830308146054, 0.1444763531007113, 0.14674329919920814, 0.1555888568081202, 0.17475737258791926, 0.11310430183526009, 0.07927637952830523, 0.21654512462837083, 0.20231468903441585, 0.09798004847740936, 0.07475536526931871, 0.08640554012550462, 0.13557474849925888, 0.1028936598149519, 0.1339336962348992, 0.09080576530146985, 0.09167627867070899, 0.07722952282957493, 0.07891133097150634, 0.2359389009014253, 0.17308883308883638, 0.22809777649179583, 0.07671031439977308, 0.12650122610671868, 0.1113854150377935, 0.12050835010144981, 0.13632733795431354, 0.09298576042056085, 0.1685340879785438, 0.18256345613589212, 0.15549804474557602, 0.13176575933973636, 0.19392409572197547, 0.13946952418454234, 0.15245207915863684, 0.10277661690188032, 0.23936372761043812, 0.195068646402609, 0.14983837102209369, 0.19111390135461287, 0.1447168893871769, 0.15780303477039262, 0.13278488610540667, 0.15432902521664096, 0.19848552111896778, 0.1609189288630601, 0.08086205895749793, 0.1647627443796204, 0.12582901459667953, 0.14354718037911002, 0.05923343566997398, 0.1727814479700981, 0.22482546256674876, 0.20383754925381756, 0.1574817374949494, 0.23950910045494958, 0.07883664505976824, 0.12190422358652278, 0.17649138196101113, 0.08118500332197837, 0.09133068874718682, 0.12507847059638272, 0.2120716614468444, 0.18476050437217761, 0.1316359227583293, 0.1605775754057592, 0.11008597670062897, 0.14878961197551221, 0.14700989779685775, 0.17290233664454954, 0.13861263951947614, 0.1690148081510298, 0.11805247139906692, 0.11177716941963281, 0.13412359410956984, 0.12840082538464379, 0.1664969682573311, 0.23432250134646895, 0.16662683548225513, 0.1711624283944407, 0.088118520385075, 0.137338865127775, 0.06746243039566664, 0.10686789413974171, 0.11911993831275933, 0.12312345251801515, 0.14114174090566176, 0.19711261494986473, 0.12340227787893628, 0.2974515630593223, 0.18829655172603746, 0.14812104704399265, 0.12111531390297799, 0.1250442111444089, 0.12366360579166683, 0.07614783732400787, 0.22122290345930287, 0.0708269123588839, 0.16005262131652526, 0.1860551929642116, 0.15640245750546455, 0.14962746701653928, 0.1233505056570134, 0.15273858072055926, 0.13831014204169476, 0.14156141919234108, 0.13620707747195998, 0.1095002948216373, 0.16929867437049267, 0.12517130513104702, 0.1101516304357398, 0.18206451839256674, 0.26786028317386107, 0.09082628879696132, 0.16008720252542727, 0.15815424011839976, 0.08965073453803217, 0.21840976731431103, 0.17821204608246205, 0.11941823762871566, 0.08885605621241754, 0.15563448500489035, 0.11962439188913954, 0.14556565352024572, 0.20941785626834442, 0.11978447362179719, 0.06878593921541207, 0.08264312145089911, 0.18426058603630913, 0.2339224349106512, 0.12262427728743323, 0.16127632420149543, 0.12385821510707179, 0.16833577845846454, 0.204886338943916, 0.13713318584186418, 0.13704459543430036, 0.21431058404907105, 0.18775485095477876, 0.1419439268929343, 0.13681584158011023, 0.14901516358217887, 0.10373801128157686, 0.1329877768312731, 0.15158233953820122, 0.09139245075564231, 0.18971902378384145, 0.18108869091637675, 0.14570220103186948, 0.07302448919583714, 0.09668149880223698, 0.1324950444001344, 0.19693880492160398, 0.12530176224367273, 0.23279168913441323, 0.10967667890532364, 0.13786810930938492, 0.09487102619342266, 0.17754623906746989, 0.1429963171962769, 0.17686527883333547, 0.13397282800607144, 0.158254582314722, 0.19095772667036903, 0.1126597333519209, 0.15296784019277943, 0.2069972329322369, 0.15193929054564045, 0.10824129826599553, 0.11878459864566404, 0.07060447106918982], [0.021152168309556383, 0.09508684848345096, 0.011543333361436044, 0.07577187201428799, 0.025206269215672247, 0.01783957922711007, 0.0034362878631650205, 0.02563788123699206, 0.040743260103608334, 0.05109893788974132, 0.06976478507802372, 0.04070073839337115, 0.054371259475667635, 0.049946657381951816, 0.05831989497246762, 0.00734430633582956, 0.06454968749875985, 0.011820118055648863, 0.02763689382963123, 0.04255200901459302, 0.09927510479164701, 0.03228371504754309, 0.024546117844781088, 0.05883732224784552, 0.018603918555703376, 0.036509348785564784, 0.06895542850777989, 0.025319611924069545, 0.037462798833486535, 0.07327327624924722, 0.009404742421822683, 0.032831594317911134, 0.04269093905966129, 0.0132051762944508, 0.10502041948418464, 0.04495927560774069, 0.05211462492063161, 0.02805644188136343, 0.032044297249446956, 0.053558769605813496, 0.05153803650530116, 0.012810533761136956, 0.060946806634385745, 0.0051566268760530705, 0.012380912610810372, 0.04798237730057971, 0.01736147141444587, 0.051018146257246696, 0.03996900568205503, 0.03936977170768284, 0.01564202920323418, 0.06341153748273369, 0.06934715224610222, 0.029694500657158996, 0.032471460215146505, 0.03186348134711866, 0.10716694422186383, 0.011849784810516623, 0.025871844489067316, 0.041542496652372425, 0.08434540712304654, 0.07572908600371692, 0.02301950954020985, 0.03741817038145758, 0.033047696230031794, 0.04038781062850068, 0.062379528948616605, 0.05903469331021752, 0.0616731231040772, 0.03253550516561635, 0.059471305970463066, 0.02115320444347397, 0.08094714834324776, 0.01703200955694962, 0.0055980591869522495, 0.017820174219988046, 0.0249527094344939, 0.07546720650768088, 0.006412969894647118, 0.05499113951959918, 0.05607727599600631, 0.03370180508242019, 0.0346760812305635, 0.052768281781144684, 0.022735955501576106, 0.02562364923857874, 0.05779940717583222, 0.03272456034357029, 0.08216282262677148, 0.027919331295115334, 0.023524282958298445, 0.05509171537273834, 0.03755071125323734, 0.013000876924413587, 0.029911592737921787, 0.047221916292103074, 0.037008079685150616, 0.017477263688981053, 0.010983030060155979, 0.02566000585624528, 0.006122710192651158, 0.034505787545875195, 0.03849576497750898, 0.0365015653322541, 0.11812786211169536, 0.02974796976383415, 0.016146936686709523, 0.06851393203701704, 0.05377484853529642, 0.027675552541510235, 0.033361642891841556, 0.017353864161357764, 0.07618172905377804, 0.05288541279432755, 0.03396475710155022, 0.046021077301233046, 0.05731665687034688, 0.038375251686140414, 0.0658219067319747, 0.05240397632963235, 0.011683708439851481, 0.012725382130743276, 0.036851813070355885, 0.04539859255835895, 0.012275931752106596, 0.020217542957154014, 0.044077734402831525, 0.031471629289069006, 0.05788630835952298, 0.021903129827771938, 0.031632182165800084, 0.10234629765393273, 0.025120469283372648, 0.023642689507875233, 0.09022427392342398, 0.062365655096307884, 0.10814772828692391, 0.016847914798305403, 0.05182802376727905, 0.05239106774810822, 0.057286718154266, 0.08433867321019212, 0.02555368051323439, 0.07611060545088784, 0.012116528964871842, 0.1356319905889611, 0.04254193878882835, 0.0253439620287428, 0.032391082270130996, 0.03257407386216425, 0.03207764314157108, 0.02427128763238509, 0.018366890951930996, 0.005699119590703519, 0.027732047695486296, 0.025619985423080867, 0.07483043422501895, 0.0763324721746387, 0.04077869550054593, 0.01678481596642204, 0.03708979062315437, 0.02855174070704849, 0.020334712274733092, 0.03819650039076805, 0.009151633674909752, 0.05478560195995435, 0.048309182748198516, 0.048777940457746874, 0.10584315961046566, 0.0510642494285299, 0.02747199914958929, 0.031409591488960775, 0.10922710786783889, 0.031612302184165005, 0.07624722957130402, 0.040392732743414185, 0.039655775312454476, 0.03747828913131549, 0.023724293193569588, 0.039455324576626864, 0.063736607741204, 0.046857319727179506, 0.032941865013732065, 0.009200978355722563, 0.01613806538854636, 0.07263960662267863, 0.14933970907042105, 0.02359834642359807, 0.04356259389990761, 0.045706732273702665, 0.03398620373299045, 0.012792162015102805, 0.06163480721654431, 0.029828966324848515, 0.013963361064182415, 0.031572025111545964, 0.039730706372328346, 0.005578712594034451, 0.024853863024843798, 0.05246977945188842, 0.015470195681818072, 0.03529472787293696, 0.019320285458478238, 0.0463012509769009, 0.05449885908033579, 0.06515146488504064, 0.025370112440038114, 0.03727668160272222, 0.02602664596070686, 0.029772838893076106, 0.036679807179156816, 0.04515122276760879, 0.038014899248317364, 0.026673379301604246, 0.009261675501963305, 0.03308724168868315, 0.06798075016347632, 0.026798743844753312, 0.003726682588157635, 0.048858084745945475, 0.04310099145157203, 0.02879303542055911, 0.01445342655173473, 0.029373122942483718, 0.019842269041785793, 0.00408347798398726, 0.0333626349757035, 0.05128070757153535, 0.04915548390859077, 0.06245681572885764, 0.03267664537434617, 0.0666213041592029, 0.019936708530651468, 0.06738026746578755, 0.017529215941566135, 0.10479370342387308, 0.08176337672217239, 0.08995513191386577, 0.012897053816085382, 0.04365848895582942, 0.0036351140137882007, 0.012681330159877338, 0.024695742477272308, 0.04976111088669108, 0.06950301283429708, 0.011017786511670678, 0.052659079777978124, 0.04236766527737341, 0.023514946261721275, 0.06792009898251103, 0.018049253661546017, 0.022153565885439035, 0.04981191400738974, 0.01639786304064816, 0.02829463585400053, 0.04635951196354243, 0.0333012483503309, 0.029020492670937415, 0.03949764710400374, 0.04096880787983537, 0.038474804811900666, 0.044893051137126265, 0.009585598543767006, 0.03354247411592834, 0.034546148888165915, 0.09587425663466416, 0.009314352665246736, 0.04701964992789492, 0.053025357905895486, 0.014343576246662246, 0.07581106507249417, 0.015564580586919141, 0.018493515709715507, 0.022603236514353947, 0.018143829131018252, 0.04734804117751699, 0.04257157490017914, 0.024556961819349278, 0.02539637584930226, 0.017572325624285207, 0.05945162900212792, 0.06096274126321078, 0.03501216783338497, 0.04986280139776007, 0.08295299635539133, 0.02713229469654541, 0.02225722524247343, 0.03619290084668225, 0.030472252270086642, 0.03185159549297344, 0.017453639452616056, 0.0457925034777051, 0.042832803221479546, 0.032153610335362535, 0.06328173154484361, 0.024715948046275207, 0.02973171912374035, 0.030075914767240326, 0.012993959150457335, 0.014104633423079167, 0.06707842882362104, 0.05651621373310205, 0.06112219480377051, 0.014055261929189006, 0.01522571500015235, 0.026609686751579566, 0.03004019783299056, 0.02124819934608475, 0.01768721391506974, 0.023705077793208823, 0.06428416142420423, 0.03804926595260059, 0.018180951836609074, 0.053539923842876196, 0.08227763622398339, 0.03424920554783556, 0.044317293927193656, 0.019923648646762295, 0.05635003011012751, 0.08062356046491093, 0.018540134075127782, 0.08358238355046319, 0.021357929949919065, 0.04751590636348532, 0.03761600109658415, 0.04007180702061423, 0.014603354746565945, 0.03082225486005266, 0.026843724697227442, 0.038500614314069675, 0.026112265862344254, 0.023024665311940258, 0.03341390924047559, 0.042138191300534436, 0.030217104771685217, 0.05330030686191974, 0.03326552950086133, 0.03788261501599224, 0.014955512916428909, 0.03206958198138783, 0.04024353712016056, 0.06525258083016643, 0.03069218079138908, 0.026519464576737057, 0.0442454808451716, 0.015001640027959742, 0.038662948345224706, 0.01909948742738174, 0.06307836201402449, 0.059077812569035645, 0.05600737430335534, 0.04093398152279758, 0.16095625266673105, 0.2500052557837579, 0.13204204128874888, 0.21558863321138969, 0.13545076482959334, 0.11708267303484103, 0.09093822190357793, 0.10369258992854627, 0.13847108179282758, 0.11333351534220482, 0.2337550600209544, 0.13371919161610066, 0.1322152384466702, 0.152374183338496, 0.20080615465919818, 0.10750805253102895, 0.15729217669896542, 0.1500938153795658, 0.1578782186392815, 0.08891895969188021, 0.2646632756917708, 0.11980096749480694, 0.14393109768148393, 0.16597615104288826, 0.09171965456898175, 0.12177202745430893, 0.0805788132692537, 0.19911579697603182, 0.08466973044579068, 0.2042236575676549, 0.10167561831974214, 0.14638153715960442, 0.09514512479185097, 0.11870402151778822, 0.23546855355943405, 0.19323694549741285, 0.1512939227564681, 0.13694402341160083, 0.10562041954648112, 0.16555301003879117, 0.254382161243308, 0.15131005656815347, 0.165297688255387, 0.18534489156257722, 0.10302464552824536, 0.27212944602774036, 0.0966031126858246, 0.16571370464178825, 0.13198699021051008, 0.13197909950488998, 0.11937925141424903, 0.14301917725993743, 0.14670125629392364, 0.2071254147637275, 0.12008415955689647, 0.23057564191760557, 0.30510956181153176, 0.11339673291771643, 0.11073410240632874, 0.154436553317693, 0.1926587482974414, 0.14987793180250353, 0.06109437815123989, 0.17908298080005955, 0.16539833688687894, 0.1532556594259316, 0.14923239547398784, 0.17399853185540246, 0.17208557966495716, 0.1263943491804023, 0.1844624961696325, 0.0867655937890372, 0.11699267302549655, 0.13967088273456021, 0.11949876879131603, 0.09251072462047301, 0.13999535161400997, 0.1436846471962429, 0.10766767461093203, 0.13511760851308224, 0.11281881917027697, 0.20400936745347517, 0.16262497602691575, 0.15145498508166882, 0.12668376187643698, 0.09013801242315, 0.19605533700556527, 0.10930214618002215, 0.1938672060327184, 0.14889105733844543, 0.16588924602875788, 0.13654124502453113, 0.26078656435974185, 0.09856546222562752, 0.11897114871610558, 0.07858637179578505, 0.22828036588766884, 0.10571873927068327, 0.14645644523684057, 0.12681417302378725, 0.06934162109128891, 0.15118280936393047, 0.0979963967937135, 0.1694995579459975, 0.17530881799757483, 0.15437911204513044, 0.07182967548649158, 0.10517065698701529, 0.14517432048676476, 0.19140866134435902, 0.1573598988714718, 0.11682211121003475, 0.1416100657755329, 0.1556854451736135, 0.1569100673640928, 0.11553974897270242, 0.14075086752493537, 0.12937594805994343, 0.129842771397483, 0.13467041234816277, 0.09501452212251964, 0.07185812033112011, 0.12096023472446589, 0.19224104651760673, 0.1071632516780688, 0.10552487306056485, 0.18911242004363768, 0.16464274436716111, 0.1467340755005998, 0.0988794816657901, 0.10462665795198373, 0.12467020701977516, 0.10697748301731003, 0.10744459746826081, 0.20488987827012617, 0.14168359489450533, 0.10355863945498582, 0.12005863350725944, 0.17024987978079628, 0.09907013030662652, 0.15338037854000447, 0.12334885090709695, 0.09551121522822688, 0.22858244967797112, 0.08672157437690804, 0.2534205217154757, 0.08877449083111941, 0.1216428726911545, 0.148383631340919, 0.1386067099989422, 0.15427922950156275, 0.13370109661932916, 0.1476546527156907, 0.197409397411731, 0.1669725862842414, 0.1485196272692373, 0.1398285742728941, 0.1953800458220705, 0.2386897694199316, 0.11131692677736284, 0.11678136299334227, 0.1238470302233773, 0.12981695423443473, 0.16515226944560008, 0.11935831423127845, 0.16411207526201205, 0.16936123311038942, 0.16114276443277636, 0.3009812059181352, 0.14461375863081025, 0.11492834952209266, 0.09698034204061955, 0.15555585374034223, 0.1330397482360563, 0.27671423710642323, 0.1247974465631189], [0.1785694260991389, 0.0243025555110146, 0.013083485142898657, 0.03981711342930794, 0.04975351895536146, 0.05312330224701474, 0.07035661864304735, 0.021302624147445447, 0.06982459356227229, 0.02461861082983594, 0.048396761919702255, 0.030163015133791396, 0.06189008686511267, 0.06901193515307481, 0.0535838628157733, 0.05711547069011196, 0.07952008741877734, 0.01869506961215408, 0.04018278634776512, 0.02944565040149516, 0.02948277310708598, 0.037700366529245535, 0.08152169896469963, 0.07424747961903773, 0.07124033936810109, 0.043756084726943124, 0.01089700700474843, 0.03229772296523856, 0.010489218402653934, 0.007831070463233178, 0.11656855908973564, 0.032618303948472586, 0.01011061200481509, 0.04464792598399424, 0.05872578750694952, 0.022538412069421143, 0.027938282395142223, 0.02424948477006007, 0.054586491877994234, 0.018021107591207952, 0.05554822716681708, 0.02376081835057947, 0.03323243450253241, 0.03200581090735092, 0.015875483006839792, 0.031101913341591438, 0.018681875662878156, 0.03810433618303749, 0.06365408091956089, 0.012678506168266459, 0.08141093031172791, 0.06332991464484124, 0.08277162503931793, 0.031025704830103827, 0.009097079596211834, 0.06184392623723515, 0.04581753157019135, 0.061832461731448296, 0.012084941244533947, 0.05865231967501103, 0.03289661986092406, 0.08032761303888214, 0.00913007787594031, 0.04242434812289092, 0.00320272225860296, 0.05620516288364607, 0.02457029366445157, 0.047237192085313226, 0.05536757980383212, 0.043675641664454055, 0.04956107383834259, 0.02846757062680779, 0.04288996104151011, 0.04742909327990586, 0.01668765878064498, 0.04399164144190089, 0.04641227626932725, 0.015908824110914384, 0.043229437583396514, 0.005086746729624969, 0.059594163490879926, 0.06939738463129728, 0.03640501910159665, 0.03406403826609735, 0.02725280415747435, 0.051136993307379947, 0.01334809669999466, 0.04041471563640141, 0.04476080520919735, 0.0466326184781088, 0.031223305718853112, 0.04786565231399671, 0.02659237507971064, 0.007295161795486967, 0.029194612964807503, 0.02516131517627547, 0.07666699978853427, 0.02044877127533959, 0.03405712815302034, 0.05751431904613011, 0.04067664109771291, 0.06899408530443907, 0.055900872760121866, 0.07451971662381003, 0.020706720740324067, 0.06554809924695762, 0.024148163896414544, 0.056936907086281054, 0.0177072700969274, 0.02500256260616645, 0.017162918661450668, 0.022112566774951357, 0.008678011307042212, 0.05599591745844772, 0.1062225876376033, 0.037746607596355106, 0.05465740097626563, 0.10374630035291757, 0.03120557461384564, 0.07316436918993151, 0.025668681801987753, 0.03281574012831815, 0.028755058526932716, 0.02200141699323731, 0.07366727526870466, 0.052005648913402716, 0.037717270259294784, 0.04031780934441955, 0.043613220820383686, 0.013958301053442543, 0.04973528989320321, 0.08904868902097787, 0.043253852805543336, 0.0030691859513265834, 0.09387996888929799, 0.04931704036050266, 0.06703673065790246, 0.07574600122508503, 0.029538015707305847, 0.045296373446622205, 0.12223338092406913, 0.03953587872186496, 0.018625100886809732, 0.05298996464379373, 0.042735215111245076, 0.05423919740884055, 0.07591810287727464, 0.010313277692353774, 0.05632012586800322, 0.005893057142759884, 0.024884081363017042, 0.04458896019646237, 0.045746392645542665, 0.04574661864148033, 0.010452861784987394, 0.017775727713841106, 0.04508931520244768, 0.06077158700434431, 0.009829285366821193, 0.009729421017841708, 0.023628426865944942, 0.01626230378244673, 0.06355965292201408, 0.03328033414999804, 0.05258044085255074, 0.04947875002999941, 0.0603055220938498, 0.07787856784078383, 0.022321544069376205, 0.0321007540990268, 0.05112251807605067, 0.02259013258040913, 0.035400229671429244, 0.0169476556156071, 0.01835332736523161, 0.018707767519499027, 0.09053461614155, 0.07856846832099461, 0.012671973353492157, 0.05822211534025208, 0.012112861318934348, 0.04805304891159458, 0.07655312847946921, 0.02444697074562071, 0.07774092482342836, 0.013164524796358762, 0.026597904319304134, 0.029661526317678155, 0.031222357685046814, 0.060457667155611905, 0.031319187368236245, 0.037467115738939856, 0.0381808300622769, 0.034215451713891766, 0.018115001242427577, 0.1076372072941834, 0.02067036795309715, 0.051299633773704695, 0.05376112790057256, 0.023037359388845585, 0.029772551610104503, 0.037234887676013094, 0.005646856593704152, 0.04095746211767678, 0.03134934441937554, 0.025409960503419562, 0.061794613157549215, 0.11741933037316608, 0.0327145399135207, 0.026159100647595142, 0.020789301188121882, 0.01215488219919104, 0.08182875466563048, 0.06107441773037277, 0.0655142534824629, 0.05497203328676763, 0.07589796242574531, 0.054362181333764914, 0.03954683377918217, 0.023714180832969087, 0.08544057577608094, 0.021508018065604474, 0.02500384580343962, 0.0635314876994779, 0.038151653603680676, 0.02779957834601162, 0.04572564698455315, 0.024463864899570906, 0.03867662301467311, 0.02751146033856898, 0.051353022441147804, 0.037442206390081875, 0.07396431053958594, 0.02080806268138751, 0.0485211018202526, 0.05667790041996106, 0.0489875765877866, 0.009593585967987536, 0.035046002106560815, 0.0388541792128836, 0.11822314812771736, 0.036994435659219185, 0.05719616273117643, 0.029021787359529448, 0.03858125655941906, 0.07103459113427708, 0.06965632234970409, 0.05328162197744655, 0.07680551614612341, 0.04767370898456824, 0.05733757873155898, 0.03802509587858954, 0.05227626181177555, 0.034419453267248414, 0.02148020715873328, 0.04457413639512755, 0.04387476323773304, 0.06963727740390648, 0.060563264715094725, 0.02107172141662769, 0.05689156234204289, 0.027628275340483077, 0.013386014221806922, 0.040101665297463056, 0.06205284224462606, 0.03555795185328011, 0.029524206972470688, 0.04315917199898151, 0.030564671202052026, 0.02141175145703939, 0.03195345454338578, 0.009604150320463365, 0.029268965628298543, 0.04230781848872862, 0.08277472003453201, 0.06929115121883732, 0.04980870409898701, 0.04979907054333918, 0.01897231300151156, 0.09272861534789686, 0.10991437300559014, 0.013575686100539903, 0.004685501954818686, 0.04235925363196481, 0.042370790916104475, 0.027430611249480038, 0.04942075717413137, 0.01929292845870218, 0.13249086156006784, 0.050018819033979416, 0.01400408342540745, 0.04447871248327917, 0.05796953615161681, 0.007711754663051257, 0.013724264065404574, 0.033915528291535955, 0.0778502838746194, 0.06831419759339864, 0.04480205521348023, 0.036818377162900665, 0.036167409271001816, 0.009446034560941402, 0.06907072474038409, 0.0625628499584573, 0.042703207957768635, 0.016228668692131198, 0.053651883762570164, 0.07361545708150634, 0.05230251181450102, 0.009168581455014646, 0.05748721868580869, 0.06651107942865742, 0.12604616221881684, 0.06770314288235481, 0.03944737258397284, 0.0739156945999111, 0.04675415449685628, 0.10038195628552668, 0.04627909571413071, 0.04749180523738746, 0.062320486552292303, 0.02254694820411744, 0.017710374668240547, 0.06261649143491542, 0.05822877264431408, 0.05824077724208755, 0.014487392017467609, 0.014175388346155806, 0.06648294101919859, 0.06221542142391686, 0.05258768421387481, 0.036785764799964045, 0.034048053841557235, 0.048381099252090345, 0.022344972953320514, 0.040553959777518626, 0.03367191233161477, 0.03560983898839162, 0.02238771108339631, 0.026193312219073697, 0.027266553520495375, 0.01921627944665811, 0.04014557745728282, 0.07401306437508715, 0.06477841837031227, 0.03241880699211071, 0.03862449073142583, 0.04960026689654878, 0.013787671247677458, 0.02206609013580507, 0.050450314226890766, 0.01577512931919867, 0.27740883370560987, 0.13035799617007857, 0.0751671605112572, 0.15198799841586622, 0.08605112486909475, 0.14225074510660865, 0.23972735890457708, 0.10411675749046188, 0.10579068258765245, 0.15684819810332792, 0.10717512604089514, 0.0964338762024718, 0.14009912588423298, 0.17779501846000073, 0.1307007745509186, 0.2036801181853779, 0.10154257182993236, 0.13335818034266272, 0.10473591741174461, 0.2802537165341839, 0.177309226785456, 0.09704522202692686, 0.1933698923957925, 0.12176517862826587, 0.18028998296828042, 0.18331639799139193, 0.11269050710383924, 0.09529077342801517, 0.1330707288317142, 0.13503730717685916, 0.3096401138651756, 0.19565841153023705, 0.1499166039209212, 0.11746440698663074, 0.13659431959592527, 0.1333416941305322, 0.16077643650914394, 0.1287353300159016, 0.17359792915803773, 0.10370569769293071, 0.15349153789781755, 0.13594830829289653, 0.09755549021065237, 0.1107421693121714, 0.08049770754071013, 0.1265389789196272, 0.07270382011249181, 0.16995646810579687, 0.17626509490993716, 0.17422313351304303, 0.14183742534970084, 0.11953812272798632, 0.11310886771928881, 0.10212021744659833, 0.2195136846914407, 0.16737049235211265, 0.19302601084834148, 0.12900039643770264, 0.1049757412364406, 0.11849373038257323, 0.1140994270662627, 0.12109328121427568, 0.10372090453822767, 0.1242789812386036, 0.22059327111609522, 0.14653971899420987, 0.18239223548481542, 0.1513601587184014, 0.26576567621481034, 0.11148024906194019, 0.19967280418401767, 0.16995052326350443, 0.18400805281294932, 0.10741083597343777, 0.1352269752251525, 0.1547839588695957, 0.12863995206932868, 0.11093376024115471, 0.10717135688830769, 0.2205820096236083, 0.16725018590448365, 0.12852241119910635, 0.1030768774029228, 0.08548792767068071, 0.1537901436489436, 0.10293498259758758, 0.10183640485329014, 0.12062223673227335, 0.15728278446101374, 0.1991498725669038, 0.0745467365448994, 0.14903244652575062, 0.07637881283317843, 0.09358805108575091, 0.08602871679730954, 0.12083519385346483, 0.19413719073899333, 0.11258418176082835, 0.1714096602893645, 0.19237154193462866, 0.15390873405962222, 0.18194765934059698, 0.14151502490764664, 0.17271305164021833, 0.20561059846753077, 0.152902263066461, 0.1428618381220487, 0.17322574832266377, 0.16152023127482784, 0.142275903434042, 0.14960249255020774, 0.11093752939374217, 0.17581356268736625, 0.17058568676152538, 0.20927203909283687, 0.08385466652051096, 0.15402335613485307, 0.1184204540726158, 0.13472155637798772, 0.15309324878598415, 0.1843209997300179, 0.22051549787002228, 0.1420005867558141, 0.11584426892260391, 0.15645012349611329, 0.08176329245250072, 0.17000065605726936, 0.2722960548295129, 0.15723494993102166, 0.0910537786060764, 0.11322867620976702, 0.16781759658648124, 0.12090968058234262, 0.17161969095468524, 0.1285766885285416, 0.1337132927390837, 0.2125035052097613, 0.1485219408547686, 0.17063811781906313, 0.1010312541057506, 0.2751829192763375, 0.22680402252702947, 0.15899738116610437, 0.1286286292898078, 0.1559252460156718, 0.17865418606708128, 0.21192507818341258, 0.1909266541441602, 0.1930960466063792, 0.1594583362701439, 0.09369619971802158, 0.15001769688340927, 0.1890634210600007, 0.3057936783279142, 0.22078730586555698, 0.10678051415109828, 0.11631084711200769, 0.09279007858206188, 0.08055356301126942, 0.1007665017799985, 0.10235824096467226, 0.11860717268240069, 0.10070564375529367, 0.16071829043569105, 0.11479226932410272, 0.12751722723365794, 0.1252748725575305, 0.09314193510480466, 0.15765308072009396, 0.11728612300489219, 0.1279284632314117, 0.17845714825295633, 0.150101583511118, 0.10908725085638224, 0.10735589980838761, 0.06866035442198477], [0.013774296310129426, 0.05517250700523296, 0.014560576396874123, 0.08331499588225158, 0.011150996752774284, 0.026805623314313354, 0.01853416816541745, 0.02212618207258563, 0.054809664781656, 0.008130010420216188, 0.03897367360731287, 0.0163564195991644, 0.05055660509594506, 0.08097649717162694, 0.06568083164071845, 0.038582509113175255, 0.037398746222137444, 0.023025584617449392, 0.01600146712359762, 0.070462936325179, 0.0683503952478209, 0.020333444399218407, 0.0911266029241585, 0.028320573675896854, 0.022824398437214476, 0.05068004101274475, 0.021313556222124927, 0.03558134051760839, 0.03863751805657822, 0.04130123258237878, 0.05652272548045843, 0.027515170119342305, 0.010636260361230422, 0.08854570633341229, 0.03232925131376232, 0.00816884245948806, 0.007901708557901364, 0.007804780719696635, 0.054711241635584065, 0.029553666883598895, 0.06752727973845697, 0.07219591914045234, 0.07877221706533626, 0.019298338954667413, 0.030813984940910054, 0.03792919699222811, 0.02182572047346302, 0.012548991343787601, 0.045872877592280994, 0.019076474146136356, 0.031208190804107055, 0.12928181117580784, 0.031016167035446535, 0.005145640217608983, 0.04666630719457904, 0.02803368332435287, 0.05864134546549571, 0.0359128535755219, 0.012587696978551968, 0.055267080559485385, 0.0063148488745003225, 0.005033589803778957, 0.009905094554978273, 0.022890843158107133, 0.04554708721116186, 0.06204933356193285, 0.04018351413129319, 0.06778816332019146, 0.029770981129859726, 0.024855764838115826, 0.0382885535157496, 0.031489243565668026, 0.03186702067332883, 0.01677997237552078, 0.023948697583569635, 0.022320358548313383, 0.08786447030762512, 0.05761346997573011, 0.05168359704135407, 0.04107846187487726, 0.01553465431976703, 0.00855977425441867, 0.018026929859432484, 0.016629828718460856, 0.055937323223559134, 0.04375132732093335, 0.013012264821408017, 0.012756843446573664, 0.054401251817903215, 0.01082276542400641, 0.028355216171832818, 0.0892636915969272, 0.022318399278447035, 0.05925287132061297, 0.05026253841577038, 0.03245660960073433, 0.03128421545449284, 0.03340948891315249, 0.02043962227030387, 0.046563666734483936, 0.04315206653348381, 0.09502838831394912, 0.013649600178694293, 0.03626644145697355, 0.02558683871381706, 0.006343960694427933, 0.02389954346712799, 0.060968582683633414, 0.049153733397683794, 0.07617473467102936, 0.06169368107352526, 0.10444706395989466, 0.1009241396921777, 0.06125800687098696, 0.06276411657792426, 0.11905483616095398, 0.057404542477020336, 0.05494528532689137, 0.0603828203654097, 0.008732822025194764, 0.04222180596703003, 0.08473511605012803, 0.07693812596581637, 0.021596596981849403, 0.03467685880980665, 0.007517284679887517, 0.052935779244909366, 0.049322131014759504, 0.05099632041228395, 0.020760392860299157, 0.04314021898373481, 0.05533287219042259, 0.05086470267645294, 0.036782650652551846, 0.011206221158405947, 0.03062379403760837, 0.034477024774758086, 0.027274281432431553, 0.056841755135645794, 0.05463663999351764, 0.029243184854426695, 0.017492972321868423, 0.026301719406018817, 0.022026908568917744, 0.040954623761917316, 0.022205387903076988, 0.06810761432373716, 0.02047933818351838, 0.019518248323771744, 0.03577221132394287, 0.06318661406816495, 0.011700182203053227, 0.03475747424207869, 0.03263387085509396, 0.03971894309225102, 0.04754576464033416, 0.021225810426497654, 0.09639174136663638, 0.012701988678365465, 0.04798367965005098, 0.013045880759525444, 0.019706255876489227, 0.013179251879093148, 0.03280653941234754, 0.024500681169992013, 0.025291668867031415, 0.05167289479305187, 0.013746906751616588, 0.04754897454873689, 0.08902663334963784, 0.031092229990228534, 0.01292857258851009, 0.023853375178371227, 0.10263171903188191, 0.024901797146266027, 0.03302190204962127, 0.045856445006305174, 0.07734642784682012, 0.018498807462052475, 0.08679783076889093, 0.033699499157768105, 0.02438417451846744, 0.05543848890210352, 0.04093283622135078, 0.05056203665932821, 0.018260109786605163, 0.059741819277405746, 0.02140807231978303, 0.07287134055889423, 0.06799724403648608, 0.03590038166411462, 0.07048983367220049, 0.15382164518439, 0.03887272620153043, 0.025612696096481338, 0.034491113131685604, 0.018429759957437074, 0.030316623423488873, 0.02387272655933855, 0.06824984620775908, 0.034284480066309055, 0.02720326125141113, 0.04103300604789008, 0.02399061025390702, 0.03173188084826595, 0.03892962738210636, 0.04840534976533344, 0.0382844204713981, 0.04336320802629475, 0.08056497006046195, 0.015105312791532807, 0.04039963902605157, 0.020516518345703522, 0.03533554886798224, 0.0877917685636109, 0.02100362577625821, 0.07302806682644353, 0.03486116041219042, 0.042205074606763746, 0.06273977030369063, 0.005560162253752952, 0.011987932488292217, 0.01606972843048073, 0.07307881249054786, 0.0696742564680115, 0.07675130010372208, 0.058023353828297514, 0.09121672550757086, 0.024884707639895143, 0.004104085270345452, 0.0060327460936781385, 0.08526430660558325, 0.014412530863116828, 0.07172794667102637, 0.06304355863962444, 0.012988576425179359, 0.026914779352204456, 0.04724539688698227, 0.08837593358851249, 0.10412952817615964, 0.01595236567570077, 0.021104490827588786, 0.04922488764409096, 0.035386735032643044, 0.04523537369565137, 0.015114419661732692, 0.020013305831760652, 0.02731365069086033, 0.03857121697717136, 0.01223660845895328, 0.045236342796875585, 0.027390280550706293, 0.021428381310655706, 0.04389934316878358, 0.0657375221471152, 0.04172879391379895, 0.03398505460110403, 0.06783572971941003, 0.07018088573409666, 0.016445768433773232, 0.04352844936112243, 0.10330966087959467, 0.03287462164617835, 0.03931160648203185, 0.07044324020464575, 0.010597602606961324, 0.044091623576898734, 0.03797143908037293, 0.029373611323535446, 0.03576570723746573, 0.03509495512492234, 0.028593530803317987, 0.006967905792407692, 0.023077004438927098, 0.03137989600579585, 0.025334602349527904, 0.016135144678335038, 0.03507564587879085, 0.010079532775336937, 0.02064804989664305, 0.07095723157568325, 0.029648887782147335, 0.06465702407783078, 0.032202582505922166, 0.03489415964952881, 0.02934032671844527, 0.12606185936038533, 0.060306763156287135, 0.06765639619721521, 0.0802383331521865, 0.08677455701775129, 0.05149757557158029, 0.04533757748562963, 0.11140488133194948, 0.05460663615996319, 0.014714013274398544, 0.04115030176997666, 0.018669269686084122, 0.033551337753212264, 0.021922178604009173, 0.07854832020858604, 0.05141971422539604, 0.011517008665137956, 0.012504498872365202, 0.044742802142976754, 0.03720052097172987, 0.01699371282161484, 0.010513051397978299, 0.02952065615494165, 0.018732703681434357, 0.047913134443543615, 0.026461555990540696, 0.039072345731960195, 0.028994708066625945, 0.005743491403277843, 0.03202108861578088, 0.06290315387530193, 0.015647822743161552, 0.039245642481311675, 0.050923522907279195, 0.01538022248555095, 0.045194112200049624, 0.036549978258629004, 0.061343548248612115, 0.032219804162459995, 0.03277799114584923, 0.08090162739878701, 0.01918560528616992, 0.040449940359159824, 0.04657886591890166, 0.01940491327625369, 0.08389402045718125, 0.045699561690731395, 0.014347200800154, 0.020342934313380433, 0.061938258473791426, 0.0010374675090837804, 0.006733659087800451, 0.022979921946722656, 0.027785938150519808, 0.03226649722144489, 0.011427793895915873, 0.011542931165275796, 0.09316173081676807, 0.07068831173162307, 0.006128123561446105, 0.03825905530022518, 0.02178152677633109, 0.030523126253918297, 0.07532905787229538, 0.01758101689178617, 0.030088666300739975, 0.13679682727782957, 0.12481549559461495, 0.10227736506250598, 0.1381796466246728, 0.16989793898838182, 0.09887925950029204, 0.13406446744357386, 0.15549547069015043, 0.20852839754473781, 0.1293138796163182, 0.15512353500291226, 0.12526709676509903, 0.17510427252179192, 0.18788399805705394, 0.18699947293967972, 0.15474383118412188, 0.2663137355158406, 0.12131511729450957, 0.09177939410531714, 0.08722785890342728, 0.22526323585019958, 0.10879923244036975, 0.113639161441355, 0.10039927753349466, 0.1611297562598221, 0.1586999705121402, 0.11509528774167262, 0.09518120753308458, 0.17205320478927705, 0.06678183022285662, 0.17700550356699576, 0.11206151061360875, 0.2399392435026746, 0.273870641305562, 0.08803074203071096, 0.06590048437036815, 0.08008165284991264, 0.11280688352041668, 0.19107683802083616, 0.10913136985994155, 0.1808336296028668, 0.10863273855178587, 0.24469485686671352, 0.09628811265311896, 0.08990943476918245, 0.11248753210830112, 0.08478865793515598, 0.15964385212188767, 0.12720970421909325, 0.1977087998942983, 0.16628232574270618, 0.18173166851122535, 0.057744313962757594, 0.11975147055401919, 0.13627355858202905, 0.10133329959165666, 0.09548719071092145, 0.09862292648082781, 0.08814644428991503, 0.1239940578178052, 0.11245139574091281, 0.20501525621981392, 0.07439895818430571, 0.17727467622007095, 0.10200254634142884, 0.11820139889154704, 0.13766495811362423, 0.1466417772274825, 0.13506946754792046, 0.06477325493770261, 0.26082278499680184, 0.14656538293967325, 0.13633737370612162, 0.19435961670692892, 0.09746919040598216, 0.12249226501632123, 0.1892900145462444, 0.09545681532472373, 0.11177814235129666, 0.1352755451995519, 0.23831470809396238, 0.11166342068463565, 0.1700777857894859, 0.1264245407054982, 0.1676204361982884, 0.21149156434882074, 0.13438201088818813, 0.06738676389138545, 0.1292173372161004, 0.053742619216321945, 0.20620759546516404, 0.18845203693114942, 0.10638653045339931, 0.15542264637206832, 0.14020328319841815, 0.16453026733811826, 0.11853208074406271, 0.15624113471036957, 0.15107921895480927, 0.2343818731606007, 0.12140182312577964, 0.22519324605743732, 0.11483639598854127, 0.17241565630801264, 0.1349154685533816, 0.09489422333576987, 0.17721774056553843, 0.11888379937097912, 0.13471875249618484, 0.1521189688074012, 0.22611685698070835, 0.11093683991461031, 0.3258101768310993, 0.17718341982653066, 0.20097979614811562, 0.17591451775402794, 0.15330225289348634, 0.2585922127529498, 0.14919323305929863, 0.13514344099788897, 0.13682187835295356, 0.24582189477739796, 0.1104882418087894, 0.13991561718285084, 0.08198941096423135, 0.12677161683959345, 0.13253143357653774, 0.1508461137212092, 0.14808090403676033, 0.13951444758042214, 0.14262360009935596, 0.12043423109477568, 0.23836974385044268, 0.20707820842583335, 0.09455679990952054, 0.09168493546425335, 0.08800361485731217, 0.10659834610358362, 0.14506944304993077, 0.14538645023299804, 0.11908050010641737, 0.11864596737488625, 0.2026310680253852, 0.13261119865121382, 0.19529439719213595, 0.1459142388475518, 0.1163370856234143, 0.1618159412136001, 0.1613222435116768, 0.0716778215381407, 0.18039535070138593, 0.11228117100413769, 0.11802558937380392, 0.18567725114764708, 0.14883214517706825, 0.27148924167117766, 0.1318728277880338, 0.19209757357114748, 0.08323071088882224, 0.12352377942372715, 0.14134385022184542, 0.14385121003273996, 0.13367999855789447, 0.25148351436420796, 0.17835607061222677, 0.19456100590046377, 0.1463965678046788, 0.21735129427284966, 0.18082805248277803, 0.17408935923970517, 0.09897814612955817, 0.12855320027278316, 0.06918135549752943, 0.22438925210266347, 0.15843093575489137, 0.23319072901241242], [0.05314156961356921, 0.03183191469419868, 0.056919417298969724, 0.004899519150175395, 0.025103002478699052, 0.03750203402652856, 0.04966186802654017, 0.058772266061315616, 0.015144587246580951, 0.031994610701897935, 0.027171807596459988, 0.03452641063279683, 0.05387119175265393, 0.04170919355425624, 0.010783849115062867, 0.02850307305643876, 0.02100581295728203, 0.023242019777817112, 0.11901150622795667, 0.07153604930687336, 0.010355760140584843, 0.04142689015415888, 0.04117469783992537, 0.04205434297722194, 0.07604630003052373, 0.07364038558256242, 0.03401333090638922, 0.012004603519134465, 0.004881244601546637, 0.05465975286619318, 0.044397514824184685, 0.03987385373141977, 0.052226320539991704, 0.041251061484217644, 0.026811246399677573, 0.05814144628182535, 0.03309934587788678, 0.01193009285000904, 0.026163729733877608, 0.03724164840194487, 0.032059280014026074, 0.013444315428064476, 0.06492782849818468, 0.052873117083142844, 0.06548968504273123, 0.047405999559428424, 0.03473007510746679, 0.03573905503858001, 0.0304544368954075, 0.07896779931240505, 0.08653710040474132, 0.059178319474261616, 0.029687609696280093, 0.024431524497847405, 0.05558420265574129, 0.033612031069013386, 0.04352796289529051, 0.05155267261509454, 0.028645913980360475, 0.05326168453921715, 0.0449819173363428, 0.05039695620296463, 0.07906596581902235, 0.07152217545456464, 0.03079491126681528, 0.036154527502555045, 0.03870463118918481, 0.039834656842773965, 0.04112779027632168, 0.021044854713123173, 0.015863534908050734, 0.07452085043393797, 0.003537135677517302, 0.042769708220035806, 0.03939528626600101, 0.031841138392807014, 0.09139700897879179, 0.03316772688600806, 0.048419951401170225, 0.03678090014164487, 0.024683040739487738, 0.031502607969507095, 0.0403976395365692, 0.06397317569222181, 0.029975610875314283, 0.04558924119919539, 0.02375747437678999, 0.04586222130925425, 0.06931463181371651, 0.05587085360480894, 0.03385691490444926, 0.06503825241159047, 0.009711078957714623, 0.05108823564143912, 0.03911996192689385, 0.03978036802201983, 0.017439087612494346, 0.024811460058234876, 0.04334222487804871, 0.020984038823254166, 0.03322836274521486, 0.0700685695835179, 0.034641779643753846, 0.046126686352034735, 0.016036059823818505, 0.0659928975566741, 0.029618125521547856, 0.022588567845823786, 0.022774332676142938, 0.02950549719013995, 0.016781634786316467, 0.05440936085858172, 0.0567821228516198, 0.05405504136316238, 0.03209289403692369, 0.021619351708420345, 0.011835387145589677, 0.018548258437564778, 0.04923410368182006, 0.02870620701522116, 0.012671128741555638, 0.040067823363407966, 0.017373621568924958, 0.01319822883458748, 0.01541948161884061, 0.029679860716925997, 0.02049457375711251, 0.13580189356880804, 0.018502791119258732, 0.08787768532431896, 0.032317985990835775, 0.058935435128308115, 0.07554485717968595, 0.03475896045265179, 0.03650790854026714, 0.010774953876652065, 0.12475258445427304, 0.04309703460744312, 0.0134078630494074, 0.024560018510167158, 0.010432159216443618, 0.03519690993632521, 0.03648654617849858, 0.05718602355749858, 0.051555261992278605, 0.04454029446107246, 0.025625041603381117, 0.027241776321804332, 0.026252415902431936, 0.05195820891869165, 0.022987161477607106, 0.028771529417304743, 0.039653760501213615, 0.06820905968667039, 0.05907837181322037, 0.019410553598596204, 0.043775091368344524, 0.013287309538422814, 0.015315240034983765, 0.0635089723753833, 0.04669619611494484, 0.07090512993595294, 0.06706354373525228, 0.026387892806181507, 0.029760219509743398, 0.020139430717174566, 0.020545702465178988, 0.01835777642085187, 0.03659248847754733, 0.026472365491152294, 0.04234020102528795, 0.04000451002690581, 0.06511257826200416, 0.021084823435352697, 0.04579261839089375, 0.021717223271186796, 0.03194137333681987, 0.0294496666174382, 0.02695060353876362, 0.04031134356233863, 0.042797279724430655, 0.053441868419007915, 0.028253837841592973, 0.011635694836807108, 0.027153997967440276, 0.06148739274771464, 0.055852168720335736, 0.07650000794279961, 0.024702997329915245, 0.016428979616912625, 0.027610661063884056, 0.06738701670040047, 0.04179658503421853, 0.05829443787074378, 0.02670644174119638, 0.061765666525330276, 0.03807867223757409, 0.029870641507929372, 0.033374758317105235, 0.054054600862605925, 0.034898576146412286, 0.012436227031773137, 0.0443946190118309, 0.02421362993998393, 0.0027693587687662655, 0.015250973876625782, 0.04077988676726818, 0.024692666634256323, 0.0527494206964489, 0.05565191716736844, 0.04474885806801819, 0.03308131216814922, 0.04178390244863207, 0.038314983549137274, 0.007693600773270573, 0.04883009189319226, 0.011276887023761388, 0.048827651903153434, 0.03768338619040386, 0.009181276489529879, 0.047565207951852394, 0.05483575007547775, 0.015096214539822073, 0.028191462962798057, 0.03133444975490772, 0.02137701128489308, 0.06611542565928352, 0.06972913900690694, 0.04156335339611096, 0.05119870168968074, 0.012663001506288928, 0.005601417046085361, 0.026646003149630084, 0.039325036003344485, 0.02639954500350981, 0.07883843004463181, 0.03005606734434203, 0.02973810255136942, 0.0719065294270554, 0.06962553327602726, 0.022579844019586043, 0.027822423087913665, 0.05708961139222788, 0.030036932383213314, 0.029900743017694163, 0.052216510784121296, 0.0704104439806073, 0.07932146380264914, 0.02428402001368663, 0.022254302617042296, 0.026269760133037647, 0.023417869515176264, 0.05745453354451926, 0.0562625466996143, 0.008582912982561657, 0.10510456658178761, 0.02957635457747646, 0.027378260631174333, 0.05660565066782217, 0.04171871219671542, 0.028932846466740294, 0.04563570060136338, 0.06729347736484582, 0.008971419151602014, 0.12765351427538743, 0.056967316946435365, 0.012251629527928609, 0.066446574825433, 0.030505446859845714, 0.03762105344644478, 0.01966154890044803, 0.019093726446191152, 0.031143780046653365, 0.017863668861889073, 0.023462549678140113, 0.043539032865796364, 0.020713378044386065, 0.013866240267581759, 0.03482713844747313, 0.06825263476780347, 0.016359336478936098, 0.030358779326742216, 0.021753388366872267, 0.046621866434091525, 0.01897416884950813, 0.005079921843829535, 0.03502976870344531, 0.041121424085670905, 0.06622194252427548, 0.01739845622421032, 0.03954143285931599, 0.09534125862222526, 0.05319067584951559, 0.051238702970647046, 0.04370494069711816, 0.05322907983715977, 0.04388942233016414, 0.004229761994323664, 0.05803361940648287, 0.0031794662232465685, 0.03369166590874234, 0.04771918779419315, 0.031197703060423656, 0.08001557010556422, 0.043654742785879684, 0.08637192418738719, 0.028307193950299295, 0.03896096037820943, 0.13410395161519129, 0.024287869605506142, 0.017291962341856093, 0.056579902452687104, 0.013584543992164395, 0.016909822363466505, 0.030326848782058206, 0.01932444531590708, 0.03358216130084569, 0.03237349289138952, 0.0472253751790812, 0.06506714158721509, 0.021643473901936126, 0.004288262383441531, 0.05518936477000675, 0.03859440645863933, 0.016857192123068437, 0.059628790665057406, 0.017218461951180812, 0.022405924823796077, 0.012334878387440358, 0.06590296649524281, 0.02210856013510737, 0.029685324839045926, 0.011805296169533845, 0.04613399483083237, 0.03282381469504007, 0.06819004538438975, 0.020065194882091977, 0.05658518462892502, 0.02499107128730224, 0.005837876787183867, 0.058397289005018053, 0.039070097263902426, 0.05739048859404941, 0.03258743826600333, 0.01881719934904287, 0.10724432676309541, 0.040541304005009514, 0.02209348927041696, 0.039538678773228204, 0.08474191125001639, 0.059109835044270566, 0.01782791745368271, 0.11706343656706235, 0.10369055979554692, 0.1979265220823788, 0.08927111498891346, 0.18644245040993537, 0.12026679491804493, 0.1874092074051019, 0.09317038761031243, 0.08703727154962479, 0.11214372716964253, 0.14779063332225048, 0.2148082654082006, 0.15206600148831645, 0.19709724722610367, 0.11758243815312464, 0.16476346450226922, 0.0894571441195665, 0.18435280770063403, 0.24528508164709617, 0.19239990250958552, 0.12961931887172884, 0.2541762368092614, 0.1535510016425002, 0.21101882681250575, 0.17193847546173682, 0.12570146095728682, 0.0885576266615141, 0.16758560984125062, 0.11029736334157568, 0.1596223250512154, 0.2379588602531341, 0.12210854689680761, 0.09991937707508765, 0.12463460691393384, 0.12629104988469234, 0.11173978432892792, 0.11017311154113663, 0.08390766448311268, 0.1426679412684133, 0.12516657070767495, 0.08931066810844407, 0.13140709229534672, 0.14132967759524623, 0.08078635414882053, 0.14771793157823626, 0.17020671838714233, 0.09676112598108669, 0.10603743950806319, 0.08530150017430706, 0.10706933695943126, 0.15283771249796116, 0.13237597901494275, 0.13792836978550882, 0.11584073725727298, 0.16196561947224603, 0.11757408779474998, 0.2180094557303575, 0.15302751844208087, 0.07388597038844902, 0.15177804435933792, 0.09004936838943152, 0.13426875244946251, 0.12156320720790856, 0.12914745467564753, 0.08585414068112451, 0.08218091762354297, 0.09724686402947673, 0.11620080624256404, 0.12970715851312684, 0.15770954140011342, 0.1999825794970797, 0.24490902440682535, 0.15997648749861026, 0.13333912007510662, 0.14089620972592987, 0.10205561325194375, 0.1781524904072285, 0.1526960475190032, 0.128474852460767, 0.1751589252343101, 0.16928637099842872, 0.14314542854985884, 0.13288237845465062, 0.18928946296293891, 0.1463098926169257, 0.16215744788848585, 0.25759038425260977, 0.17735154548239324, 0.22478479861972794, 0.16360887806982766, 0.12098229805668517, 0.13346348678873432, 0.19773622584198752, 0.23439472811597012, 0.07988385660874267, 0.18651145961015456, 0.12471346800485927, 0.14898459667400007, 0.08193151769979347, 0.13605382924358692, 0.11370945000840772, 0.23370918667604848, 0.08662478682855446, 0.19582259949416886, 0.09892091170073518, 0.18029151514412897, 0.15869961811169503, 0.12403585557495395, 0.08817161027822765, 0.10127716066856539, 0.07138399617566217, 0.15925244247961431, 0.1848184512627702, 0.14248702194421523, 0.14822744133491672, 0.1665033421088611, 0.1497271044119712, 0.13629756777757598, 0.1490039480549674, 0.14505193027998173, 0.10478609617078498, 0.073866281928795, 0.12741751322943357, 0.07183730572221741, 0.10877209760609174, 0.13302307816282397, 0.08187827458905597, 0.2660798335507993, 0.1641352264390838, 0.27637672941050223, 0.18329517735588938, 0.09369312004456598, 0.23332598949632338, 0.11769052549836137, 0.17809972227100404, 0.14072475924847588, 0.2516301589146737, 0.0952499179590133, 0.14857063340323587, 0.12366876922427647, 0.11985008139163257, 0.12558902223264018, 0.11385110732648643, 0.10175783487577593, 0.11653313518411691, 0.13446237351144516, 0.11848437644901777, 0.06865210365504026, 0.121938054029259, 0.18010321073234084, 0.11107056056179347, 0.18089908415511732, 0.12067169536866489, 0.1612419574972122, 0.1640717483936779, 0.1428310873527681, 0.1736651303907556, 0.14324407003098918, 0.0752211926925567, 0.19514281903543781, 0.11602763972815969, 0.16221726403361367, 0.15454538376821628, 0.1213190396646819, 0.19020525978938227, 0.14030613816313206, 0.12706413985260073, 0.17900739856545003, 0.14775349337968136, 0.16896433827857818, 0.18481603042492944, 0.08717535889797634, 0.1362265667487537, 0.159286288244109, 0.18024571840801548, 0.12359032182083016], [0.009744876841714066, 0.011042251529532575, 0.016599706141278148, 0.016090286399928794, 0.04815743988259666, 0.026028298795403495, 0.05815415568048916, 0.041743284466886715, 0.018551518141682592, 0.023157457077515223, 0.034539323044760574, 0.06491058385900914, 0.052661757255273486, 0.03081091675877331, 0.03639293789503075, 0.05152043180480119, 0.012180993348480234, 0.003458751236922258, 0.043564091601799575, 0.08898711853450345, 0.04614743201302425, 0.08244513368774807, 0.02836833351231631, 0.03431261847576788, 0.024041817485985738, 0.06473970794749838, 0.0349516085829706, 0.007804241585319923, 0.03917385621236698, 0.024941177896013664, 0.017944466240043123, 0.042948451854528925, 0.04581187784131016, 0.024531548767681086, 0.018060455782218807, 0.07222957338296598, 0.07729005909735158, 0.06961000467380209, 0.03983828043865581, 0.017939607327383374, 0.01752054574148309, 0.0389044345807164, 0.04499501360940837, 0.08994597716317063, 0.06688829346169388, 0.017732796146564426, 0.043763600049480315, 0.009580705157150666, 0.032539733970958384, 0.0874822000942884, 0.00830031559622336, 0.019319601725005818, 0.02959000434906733, 0.029757835061079072, 0.042061662947338437, 0.01735630989705603, 0.08306072363930364, 0.03879147874672086, 0.045144335637169505, 0.04130181097876161, 0.10212199477058265, 0.0017515222627421721, 0.024144486674377998, 0.015292032358927593, 0.058359015252321005, 0.08207990126984735, 0.06509826007869936, 0.023829170630403587, 0.015813811013715404, 0.020769804250448946, 0.10172499268646203, 0.028401660252242323, 0.015344849333257206, 0.013046568323437487, 0.03522319824344689, 0.07035818912329213, 0.09200135275961892, 0.04968514177767981, 0.036790158314209793, 0.043250658218899084, 0.05939203885293776, 0.03894486870135992, 0.0468403508796567, 0.024420376003329313, 0.03204738075334219, 0.022049335792901057, 0.06997221104440189, 0.05314858697895562, 0.02200335519568574, 0.030645602645592827, 0.08329562917952577, 0.040050352728294755, 0.024016189929698745, 0.01779614970268261, 0.09000292813946163, 0.029598029120074167, 0.052310425502758835, 0.06949257105588913, 0.09380565836064278, 0.02355547231291571, 0.007532538448069846, 0.040319536872688806, 0.11318246578617443, 0.0435672823580042, 0.028951832040723775, 0.046387393733546625, 0.018687581102694237, 0.03915812076640226, 0.018253339484574336, 0.02714966957066809, 0.021344255280470657, 0.04080399555424529, 0.023685094389703967, 0.02441981484392478, 0.04747533051657581, 0.02491827761273711, 0.031010697167667172, 0.022550223229993737, 0.029250820835811958, 0.06251780781894922, 0.014295274403036363, 0.019419788788523407, 0.02195421448578277, 0.07420884580501626, 0.020224945281722376, 0.07738763571626718, 0.03376965748987371, 0.04667528191461198, 0.02472556628016455, 0.009611326649094061, 0.03585603283417802, 0.07621342977208477, 0.02754956555192269, 0.042485160182320306, 0.02527316592844023, 0.017953709090849566, 0.03117615683755327, 0.08317598922839088, 0.026313927017092228, 0.04056190410929342, 0.04946668031475237, 0.04287438264356987, 0.08412341016434854, 0.03237749570079389, 0.02514692229939805, 0.0447665240555521, 0.05333002724294221, 0.049260349854105906, 0.05215405546609433, 0.017009567011207823, 0.035163221219854976, 0.03824735330718179, 0.07494807468667146, 0.05247777357937829, 0.04235420128210418, 0.04070233185625365, 0.027598315556984276, 0.05601832553023293, 0.02914956316442019, 0.026425591992935347, 0.027292242363816308, 0.08345035595759269, 0.017834697331812595, 0.06506734843095464, 0.037173179293712305, 0.030603262881237655, 0.04673026404493759, 0.03670104696685749, 0.02370096773149506, 0.058258362790389415, 0.027957379051874724, 0.02660691159807386, 0.04077039110744673, 0.056042120221161076, 0.014339314882583437, 0.018927688379922224, 0.0422905623582342, 0.043038294815848914, 0.020580088321660316, 0.020971898244874134, 0.025223435330835563, 0.0587286641671052, 0.05358819121254548, 0.04267552537062476, 0.09985643529122877, 0.03744090787105022, 0.0673796852389651, 0.039761683137546626, 0.025402923985835046, 0.04097666411149887, 0.04804393246529564, 0.06236811806898444, 0.0557395346432684, 0.026990348180275292, 0.03347998432394478, 0.04431025357916952, 0.0482630412725191, 0.1197226962915832, 0.06687439662674743, 0.03185444150961215, 0.026444725038844253, 0.0017680107491962133, 0.043387906700973554, 0.04938230722121174, 0.0465695119853462, 0.030420382371953422, 0.02355046784355035, 0.03341423865828303, 0.029992627603332364, 0.048371369935451984, 0.05285506422120718, 0.03128440697647391, 0.030526834119471814, 0.10627648958395566, 0.030465390037504897, 0.03157245795122318, 0.041625153708962664, 0.047365128768668066, 0.009331415358540273, 0.07601936437910603, 0.018928437230868206, 0.05307287450939898, 0.10081746194872165, 0.019260388874118368, 0.01621328947705127, 0.03465955288359716, 0.028456514062840613, 0.06476506545779205, 0.012896648747095419, 0.031099810430239287, 0.01692283628208022, 0.013469383740166744, 0.06258521972584628, 0.010983520356427518, 0.049391963759497295, 0.05661448749202875, 0.05193491218491428, 0.009521973984045608, 0.01563853871512918, 0.0095249435323621, 0.023073003544742544, 0.1175292946338173, 0.05449351944750356, 0.039465950216136636, 0.054682873399747964, 0.06625669993340008, 0.0584497353843143, 0.047259374161160765, 0.011577627287366459, 0.015938712073670282, 0.02507800502972978, 0.027224152469106262, 0.024329140677206942, 0.05093878337873086, 0.09434239488215217, 0.030892070367812153, 0.03572318935766816, 0.012949906221981491, 0.05006566148010954, 0.022580261537504774, 0.10512936484789658, 0.049927237053071304, 0.007628701634765153, 0.05003585682941541, 0.029514004596539085, 0.02690781944341237, 0.03919285136244951, 0.03379982220189225, 0.04972027840032693, 0.03338673610180136, 0.028018219839601267, 0.03794043933251693, 0.1116276903438472, 0.04357331913084753, 0.011525674077171472, 0.07851899436284458, 0.02712964594754721, 0.04863757399782058, 0.033001271301820394, 0.07453115431651955, 0.026916001262443683, 0.02124281566319687, 0.07508747204537354, 0.07697571023938156, 0.07661503604463032, 0.03176845197055129, 0.0729521781566643, 0.035437476866307764, 0.013389435761998738, 0.019191431384834073, 0.052784503692941326, 0.08262429867059955, 0.02940989707806899, 0.022977391941352718, 0.017172437303909854, 0.020740058971568942, 0.039839295505155484, 0.03404011334022207, 0.02467998213345005, 0.0680829386316961, 0.024469183464985222, 0.011529294800223603, 0.034155876886460095, 0.0245032379884393, 0.03556242963719753, 0.031532044897997574, 0.026631183178734877, 0.02964017736244827, 0.07376196373614573, 0.09461706804652369, 0.014668865797800884, 0.03405170042007681, 0.06639181486060543, 0.07471683870760665, 0.017723400078173128, 0.04519334228168573, 0.0565877931583072, 0.022807483215846365, 0.0249794842074475, 0.015554755509290245, 0.03438820071037739, 0.03443435750781529, 0.03961628347995781, 0.014291014954177363, 0.03845187196988733, 0.06827459084771334, 0.019939261518659133, 0.05062025934157353, 0.012156980322493662, 0.07576229591523448, 0.004646490842494513, 0.06549769832241921, 0.021205583790076837, 0.02472912092813321, 0.027654096333970948, 0.10966124223364938, 0.03164257223327314, 0.0237314542004418, 0.023371605465428966, 0.04460160447765262, 0.054974618833512075, 0.021813968684704556, 0.05597699125627837, 0.029082681773410692, 0.006165796892732503, 0.042820898215136224, 0.03887559137036724, 0.02412446879691655, 0.05725872147107317, 0.0398652850379867, 0.02522869835487537, 0.036385062511169144, 0.10948814466715821, 0.13329019770026207, 0.08957452411132474, 0.10082206613714657, 0.10112832510663618, 0.256336405572872, 0.19466016832138264, 0.14378235405010564, 0.14954836077747807, 0.11374949342420987, 0.13417873711835954, 0.1458539783714279, 0.11158582363878528, 0.14127853356542128, 0.22784806247199738, 0.17174978800598653, 0.18097399223235347, 0.06593032349501887, 0.11869244592925234, 0.10681325674898202, 0.15450378519392785, 0.166638158261776, 0.20423703346281283, 0.10585563918275219, 0.10105055186056322, 0.11987366923882116, 0.1451835441853731, 0.11064266981256586, 0.2711301915828259, 0.17387922132207503, 0.0944592692558804, 0.2110079023987055, 0.11487107678887346, 0.21930867956290323, 0.12266558474831044, 0.15396678820252419, 0.12124014793023949, 0.20650549641539975, 0.12192437169893135, 0.14327258382353092, 0.15840165587442537, 0.20511783539287506, 0.10477805990845927, 0.35939660524168326, 0.11709000449627639, 0.10594652019320958, 0.22234667783542988, 0.0868030861320515, 0.13096194924606433, 0.2046437801853303, 0.07362583757288034, 0.11207502440459306, 0.18567962602021235, 0.1905049380636023, 0.11259095397807899, 0.09676028328436999, 0.15324389231541466, 0.15034818721394386, 0.0673948461189866, 0.15457087917433632, 0.22667058533237827, 0.06927179217699074, 0.06537186838085614, 0.055712905427020405, 0.1573870643492668, 0.2585801085637462, 0.2028387697834161, 0.12035104160707806, 0.11671107442628954, 0.1300495078847293, 0.20732468955459135, 0.09965626417749351, 0.1283365429469174, 0.059746408144072186, 0.13044041190897265, 0.12543699208406672, 0.19497809480995903, 0.1265103425530176, 0.172259297762667, 0.2951369050049013, 0.13625362497423926, 0.07308307960028611, 0.18529195488700945, 0.11984303338272918, 0.16233089019454297, 0.20351393839284299, 0.17954326174672575, 0.1501311698267537, 0.10440557263791563, 0.21187744283628082, 0.16418502215416203, 0.14763144025158498, 0.17152979819765016, 0.10325971194693159, 0.13127181648967728, 0.1427000863177161, 0.17627364445117213, 0.14569366681239299, 0.2752608457399953, 0.17150106990048963, 0.13032700025266217, 0.14364873299435263, 0.20690876509874098, 0.15244935188562642, 0.17014929243633825, 0.10573448237752724, 0.15328331519999813, 0.19296703739993035, 0.2050620335484705, 0.13432426318045587, 0.16612320928083313, 0.13552758812664017, 0.04745699803254778, 0.09730961429135454, 0.11327253474343209, 0.16191171752589364, 0.09245662349126033, 0.10427062625005361, 0.11773593919051271, 0.13109468163982516, 0.07553669068241313, 0.15521040937352568, 0.19468848293106403, 0.17895775606795666, 0.09207662855905872, 0.14433148587422986, 0.1978277120619051, 0.23617911543096268, 0.13059318516283266, 0.07538060792872021, 0.11679779557931809, 0.169889236229562, 0.17621451778517616, 0.20668211032546338, 0.132955968860657, 0.07049819169145438, 0.14648871286021126, 0.20867196242174796, 0.17575564644029065, 0.16303877075833662, 0.19403998950316062, 0.19296386579592384, 0.15770270789582885, 0.09432326566668288, 0.18661603061181886, 0.11865119209452984, 0.20882954670777246, 0.17395817434355137, 0.14525494357991606, 0.10121663206166799, 0.09588911107951596, 0.10698847637902345, 0.14686394272552383, 0.17865838422890634, 0.17648894580141192, 0.12528158348774718, 0.16051996559385331, 0.09172390635696151, 0.08722788954694426, 0.1706943793162223, 0.07822663988918066, 0.20046849374569234, 0.07027651648968458, 0.11920795415437992, 0.09904014562527019, 0.07870587385109357, 0.11546602067086967, 0.14684103669658785, 0.18996510654687884, 0.1497870584529254, 0.1311424242392663, 0.09829530898000925, 0.08239481703288133, 0.1963730030242474, 0.11534009879875569, 0.2436020477644859], [0.024317547851692767, 0.021273148914558754, 0.07207120768725872, 0.05572812376363624, 0.03746651052947968, 0.03643733652068242, 0.031381765260331096, 0.0038700999932423717, 0.016708375713337335, 0.0183431058371019, 0.04695440988026319, 0.030885799938151916, 0.06211252815480675, 0.025114869180646156, 0.05247882695027417, 0.024826165115941438, 0.025757241566034577, 0.011178032953232046, 0.03021077305499104, 0.05405854621541597, 0.025235955122738116, 0.03149998986402587, 0.006523450785842274, 0.043676380939300985, 0.04969470638541445, 0.034922738559544086, 0.019760653864772573, 0.007855860110852987, 0.025341594817056775, 0.03008431109089044, 0.06917876612034536, 0.015481203407680076, 0.0347050202019032, 0.029305766576961167, 0.034224499212277514, 0.040232543758447134, 0.022535715439927675, 0.01858144728166442, 0.044916512579807354, 0.034801037831892895, 0.05900781128495451, 0.052935534096773595, 0.009158977585273885, 0.03859591182141054, 0.022899229905658194, 0.018002300132666866, 0.013344890622031546, 0.009991755378582786, 0.018835539493950147, 0.014701852586210496, 0.06544327543627831, 0.022404817826745492, 0.04202814660065117, 0.047152114190882256, 0.09338741265838185, 0.029726883193718332, 0.03181520631657012, 0.03945845404579755, 0.03873405662635642, 0.040238002134907636, 0.05690003144404581, 0.033897778034330375, 0.030903833647889477, 0.0329588376916945, 0.033728357689875754, 0.040517202878911654, 0.0783642216195022, 0.02924117961928489, 0.006200786043454203, 0.03044704223171838, 0.013124393280445328, 0.05101364549069155, 0.08616393131594505, 0.046464527296202804, 0.06752424603027683, 0.040138717139920885, 0.015830417884693995, 0.041482270650205114, 0.08361270531050621, 0.08233664797679072, 0.0512119741629689, 0.1091615537241582, 0.03509509302074871, 0.0570489168016901, 0.09001703181814763, 0.003129790448808983, 0.007541669258517364, 0.007561744113768181, 0.015900875948699975, 0.05367312738071046, 0.03283288900650317, 0.021677947858528748, 0.03626300938307278, 0.019901773006084467, 0.05761886706515666, 0.023453352792609124, 0.023779528132910212, 0.0791976256896892, 0.03057084970116135, 0.04768684739246965, 0.061454175175317836, 0.053679206288389625, 0.046363687142729766, 0.025174771510665456, 0.044247878700374596, 0.0034222646237110662, 0.039031923102635535, 0.08502060637599038, 0.018368254588436217, 0.011785606752269933, 0.025613096377421773, 0.14557257895508122, 0.06467334175061795, 0.07271662910258578, 0.030936085949501688, 0.07856340447981512, 0.02569101709542015, 0.06353840547343416, 0.08181878020085635, 0.07519467838949735, 0.05600522159628811, 0.04764057568184311, 0.05062616970990935, 0.039960157366529594, 0.06500387804642802, 0.044733754644591006, 0.0573946561123575, 0.021584611536274036, 0.017431219889511986, 0.038926731569752585, 0.054488470928082545, 0.021055488013512185, 0.04446970711972925, 0.057309804213864196, 0.027366108561475432, 0.09952560022112825, 0.0866111044982268, 0.012345053950294614, 0.03594864520334429, 0.04019081111877196, 0.053605186873145645, 0.06802121492763681, 0.029782330722457943, 0.05296345034073438, 0.028662815795189915, 0.020251256571481788, 0.03967586979870835, 0.06216701998886082, 0.03254991527947207, 0.03072509192861617, 0.03818658338258824, 0.020626191492943514, 0.010817050408091276, 0.028718939396522702, 0.013253730947091697, 0.0330570041983118, 0.01930605729050454, 0.037852588199800065, 0.022830107707470175, 0.10048670348741355, 0.03376005074730323, 0.06029021565712268, 0.06709394210408773, 0.02088281945625861, 0.04614796444413163, 0.07205796202704792, 0.030266098009662765, 0.07101840369643704, 0.03685146833078996, 0.04972819208858475, 0.027260434393200184, 0.039940315689290726, 0.030709046217042114, 0.06340567307967333, 0.028998299103771007, 0.01451218166508742, 0.0353614732833399, 0.04740076334846597, 0.07219742833366317, 0.015381838931071182, 0.03996234454755341, 0.049764018190363725, 0.017184581712729508, 0.020347320166746938, 0.0732324667455208, 0.0514529432891117, 0.017595296770694758, 0.01804740547442869, 0.04784121027877254, 0.056998194120223486, 0.015369282749992226, 0.022932589204320987, 0.0507063216589872, 0.035228656619907386, 0.057652739642728726, 0.03858995165735964, 0.01988673086969122, 0.03482621148108475, 0.0556639907130551, 0.02728983684773407, 0.04475306772116212, 0.021817052188599785, 0.010345507011328255, 0.02954569573874676, 0.007558006562307598, 0.06581942460710002, 0.047427867539227016, 0.04760094595352008, 0.04002590686263096, 0.039843934167537, 0.02800174894922924, 0.027673673710875937, 0.020864605715858842, 0.0207304943638343, 0.0946677907279903, 0.04538000343487628, 0.05324683392480497, 0.024029299609302997, 0.011208775104023518, 0.05725543878431763, 0.053057763425092545, 0.037361874410341826, 0.03405085389292048, 0.031217234472053188, 0.05870025762687287, 0.03325549757949287, 0.044638457137250134, 0.0094694260980994, 0.05634238455264319, 0.05980834635275026, 0.015045485155086124, 0.03795235583017911, 0.04262109865404425, 0.05429966089826438, 0.04490438540796599, 0.06453683254339042, 0.06355686053153008, 0.032828698505557356, 0.03223914788254807, 0.029584153352545637, 0.02173244926868187, 0.0157419529240278, 0.03759898245334625, 0.06792979765563242, 0.10613730672987239, 0.01100126582558357, 0.01839429774742213, 0.04524921690444312, 0.026763182043308215, 0.1041750721032581, 0.04974635986370906, 0.01570587018279419, 0.044181830429982756, 0.018438600612083272, 0.06852493305960972, 0.04375325403206291, 0.10800736565743724, 0.0815563797650318, 0.07020186122146345, 0.14039570916323893, 0.021795800909580245, 0.03610018888608583, 0.0012314275649729215, 0.036790721388834144, 0.028397534868770072, 0.056228662630723375, 0.04753316249397974, 0.021758569036460212, 0.013731548603954575, 0.08074032758632976, 0.06346079693626493, 0.03611247310595166, 0.08695508563710798, 0.011314439696199712, 0.013128301286469064, 0.016008118682000187, 0.0375303907710458, 0.07790512810911863, 0.059926224301659295, 0.0676681173424567, 0.09055444249703039, 0.023818813121667313, 0.08321889015215059, 0.11290272878062342, 0.048488998905785625, 0.03473444563907481, 0.04261324242238076, 0.07134332456776211, 0.07266871796380128, 0.04251704093128924, 0.03159871178438827, 0.04230384249240161, 0.01313362655515272, 0.04740169797573359, 0.02596685662865639, 0.022073120907730153, 0.027526358833476424, 0.03376090493533881, 0.04492692754513795, 0.0313310636462824, 0.06403607151080525, 0.07711703813965283, 0.009906762711433394, 0.032411674713535656, 0.055636055316896214, 0.025205441840714025, 0.04655482224939812, 0.07527892507853047, 0.048074200599183964, 0.04722207334012755, 0.07485106497281983, 0.058450233341465076, 0.016132298661696336, 0.02628193327015446, 0.017731886417154345, 0.07371841929852962, 0.034494824827678745, 0.0074158110674620885, 0.046560579400149085, 0.05443581387460713, 0.05860028315275427, 0.02543464577155969, 0.05248029400864917, 0.02299315803083441, 0.07005905477149833, 0.04001975134615937, 0.020976494772419817, 0.047629704894197565, 0.02902416797775415, 0.11126555292116058, 0.03433360545445354, 0.022083449688169266, 0.03453242825344205, 0.04569831296741482, 0.06096087200867553, 0.05945861572399736, 0.038331554030939456, 0.0060410643721209665, 0.0018331303773823405, 0.03968899671529089, 0.08536682449161045, 0.029651442685374813, 0.02549713939398287, 0.005126790624232062, 0.006344595110990228, 0.026871928224159826, 0.02108562016679395, 0.024255533034222263, 0.028930816333740953, 0.04542996385885824, 0.06350202778834971, 0.02814894125256087, 0.08222510557501547, 0.17619144321689684, 0.1443258168235902, 0.18257110169337643, 0.12283599334618739, 0.11252748359355236, 0.178524058372263, 0.147084177681996, 0.19059018832781624, 0.16964833222089276, 0.17252664712648239, 0.12716675733005808, 0.152638774785784, 0.2147764574375845, 0.2090313802323034, 0.09316055104136468, 0.10042618254139539, 0.1775286650104869, 0.1367908517920202, 0.15228946933582907, 0.04805971770697544, 0.07830277370709567, 0.12484246955042887, 0.10657002383302297, 0.1654061663054651, 0.09083012689746196, 0.11594471837123556, 0.17037470614717853, 0.0995766369986438, 0.1571416404218443, 0.16724470071494582, 0.18842723100416123, 0.19013033639038765, 0.15684829003387885, 0.18820998379059378, 0.10501567739993335, 0.10449804711125552, 0.05542247766448606, 0.1487059398524223, 0.11541694507844026, 0.1437831354597884, 0.14474665956391444, 0.1563733461643419, 0.10714074401485343, 0.13769269049648317, 0.17459943590144958, 0.25410017960013886, 0.13144807799929573, 0.0857488112524152, 0.11166884458713955, 0.19127971342494413, 0.1145112452908389, 0.1232018156517898, 0.1849286300280402, 0.20847201347351077, 0.1474995199110239, 0.220633965706633, 0.17926581534406832, 0.16382568095239902, 0.2665991798764275, 0.22382207124704318, 0.1320425469067789, 0.11285249639542834, 0.15902286125046594, 0.16249705466531938, 0.11266528748937192, 0.1544067218539215, 0.09357339582375943, 0.17387824072953195, 0.19160375329515628, 0.12627535274312382, 0.16279210576847677, 0.20239669108583083, 0.1628407523516686, 0.10639507233375504, 0.14571641962374413, 0.08102164273300479, 0.12108382768929006, 0.24147312006642743, 0.27378456366638987, 0.14664226752375403, 0.23063433957436394, 0.15254013330465363, 0.22725940051098026, 0.17211698926985267, 0.09717974706643051, 0.10578979392566028, 0.1049957131486266, 0.12119294159234532, 0.16723846475924217, 0.24242712935853392, 0.08972165895806206, 0.15369617530415136, 0.20914940373791804, 0.14247998925707034, 0.15580726847533258, 0.1709876990606708, 0.16476393947678228, 0.1459941111745373, 0.14364455015428607, 0.10277266388819103, 0.15840341787665121, 0.10493078719704382, 0.14223861027388804, 0.16327723860740662, 0.13073307281780627, 0.11824842902921862, 0.20217582793726077, 0.12900090205573267, 0.13058777658208726, 0.19628954540577628, 0.28612029528425587, 0.2420391671119198, 0.2199124181342702, 0.11684546923084606, 0.14263061746474237, 0.08391747806942271, 0.12244885847453149, 0.21460807131182766, 0.10880860169568371, 0.13316097398919444, 0.25063913225406603, 0.18489587210839797, 0.16653600809795244, 0.2529314971498905, 0.2257886649139466, 0.11833786213349913, 0.11795095708822051, 0.15848614005071504, 0.1057036933038504, 0.15674733496721716, 0.13360115278872753, 0.15795315736003462, 0.1431991313133509, 0.11686295135727814, 0.18730604600521827, 0.187375009240162, 0.06950141171053534, 0.14775275793527404, 0.19029213415999569, 0.11881273705512287, 0.18223124976840713, 0.1283172298703463, 0.1507368542614483, 0.17248717827662347, 0.13752755258352528, 0.10546957683419028, 0.186532802819725, 0.2219367441871474, 0.18158130077344758, 0.13094915557772885, 0.16479419994979136, 0.15945677345077838, 0.18882735872701292, 0.08192928838393382, 0.19522969340605123, 0.14151272664387382, 0.10416045514566284, 0.12209496415791013, 0.23273766461399295, 0.11878119721528023, 0.26549564554326, 0.1768554422643877, 0.10714947741719023, 0.19945785523422305, 0.14578526028461997, 0.12164989771742014, 0.17447312332449422, 0.16564745335809647, 0.19780215536875112, 0.1357208261446607, 0.1478156231103405, 0.16068423016657754, 0.14119401874561466, 0.12278553113461503, 0.11602887312971777], [0.04609199022994407, 0.04656831688818432, 0.04962216168942471, 0.03039707989251662, 0.034647831738355665, 0.0966796218868225, 0.03699287283985365, 0.0433749751368117, 0.02866258788403244, 0.05085715287995916, 0.10242947948075111, 0.05693510294921937, 0.020558197359224, 0.04014741989874071, 0.0628610535134231, 0.0194341950719395, 0.002929879086760564, 0.02430758679345731, 0.016882524735504584, 0.025756774252400767, 0.035832632678530874, 0.010948080171440399, 0.03791436169957442, 0.008770259784444446, 0.052857266723989486, 0.046596842172044906, 0.018617152724595323, 0.014338058498387617, 0.03768185018411568, 0.0543522106994304, 0.036834985949099064, 0.05868030103644537, 0.03610537913177283, 0.01712405693627173, 0.06515987653044925, 0.05782573378735012, 0.06146924029434882, 0.04164952296583403, 0.030375958848444205, 0.06216710808897211, 0.09649955292022037, 0.029738587101981528, 0.023595881535701697, 0.07573589652536378, 0.03670872316785878, 0.03007693174895981, 0.02836582457436429, 0.03408122161823896, 0.014559333419216978, 0.026118842727174203, 0.046450576835101655, 0.025113854114146485, 0.057707890312397675, 0.07884772269115334, 0.02464810904536036, 0.03243181516506499, 0.07749941560529894, 0.041197634512378324, 0.00974954710522246, 0.06502558897820211, 0.10722497538212808, 0.09153533381439986, 0.06086755483861893, 0.039004389902636896, 0.013225790762883282, 0.03376604538531073, 0.024904386523450096, 0.04516660964356796, 0.05258939642038557, 0.03217599159407039, 0.07192876895949726, 0.02475641089521589, 0.10781274868115302, 0.0687273488109631, 0.05032662550107606, 0.15026004113737615, 0.17715317467528005, 0.4682607942771527, 0.4378925786624032, 0.6176870712830175, 0.4137791338707171, 0.23329007529443313, 1.173242695869938, 0.8719830936001194, 1.6509499977673254, 0.8847835647963709, 0.3415754695813502, 0.16828074270198423, 0.0725698389954144, 0.03429165064928032, 0.08177985527342366, 0.06569501192819688, 0.008778072923662202, 0.04380789142282259, 0.06619791800697004, 0.04169656842526409, 0.041391098526336496, 0.04425981435023489, 0.03681459268855472, 0.08061833574526733, 0.07763809284135219, 0.015505610011337746, 0.03463129956094969, 0.015732753165667097, 0.13005220451422278, 0.014260559128747593, 0.03795320235733544, 0.07667267650005317, 0.015725339349779873, 0.05493422301726476, 0.037197636650694955, 0.019848939752386465, 0.06586385004582905, 0.09731611837783168, 0.04841181554741437, 0.045233646167382124, 0.06739014233913153, 0.06782711889114111, 0.0367432507506061, 0.03174058360708577, 0.07690234965975247, 0.05229439128250365, 0.09042589294333613, 0.050210149493068464, 0.042755022314527345, 0.016271226791544788, 0.05075005378814475, 0.01973756780517438, 0.04981181441595958, 0.04534517707783849, 0.015171709631930198, 0.047555130065208485, 0.04505381468803652, 0.020211458303815415, 0.04128216082350381, 0.010715026648775225, 0.020447110779763713, 0.03083698098517714, 0.03832753973021623, 0.022253456089885968, 0.03736473574873902, 0.02632892893386945, 0.06252646844293322, 0.04857766592214185, 0.04258765125527017, 0.04300698863282319, 0.03171420145419336, 0.007879713215985367, 0.015502984244977275, 0.05946284835977901, 0.028960324125364426, 0.053482134000308094, 0.12539285009786968, 0.06605570144470661, 0.06707462136663737, 0.006956719951103292, 0.06195591680044609, 0.04367434697586202, 0.020782377668506196, 0.062392460512778455, 0.008983915960866838, 0.07576046496509545, 0.018865010896397215, 0.020683134808355284, 0.058469780074853095, 0.12045025765415161, 0.04302840845118608, 0.008096563021442103, 0.09326090089856617, 0.02672072353532478, 0.0013185523505765766, 0.04826615158949168, 0.0630308645627191, 0.045319267984239325, 0.061951469660045645, 0.02862076331380635, 0.031086382824146462, 0.032605736276074763, 0.05621617922799722, 0.010757143290022449, 0.006476524548845427, 0.030879435662720955, 0.09374301535107436, 0.12493180306327921, 0.031380819141744606, 0.03726750769982896, 0.08517456706613304, 0.020149376453651537, 0.04406306764952118, 0.01801692666636119, 0.0705086641133793, 0.03659178750709661, 0.038508895724531145, 0.014280468796289737, 0.08279648459246082, 0.04280001465832034, 0.01944544698832737, 0.07567139192213936, 0.06024397075957349, 0.07590013811545027, 0.005036637876107688, 0.041030845679943605, 0.022787995854272478, 0.04463523956796816, 0.06148801327893331, 0.05474028785923316, 0.030466472136697946, 0.0622920646903015, 0.027914319164870728, 0.03282357337734392, 0.05324168964439342, 0.021940105061437336, 0.031170189012623126, 0.020964608918274605, 0.03342040949651311, 0.04953121556149376, 0.08258207190421321, 0.0286771129110768, 0.042057422650677544, 0.04774407032997378, 0.02124622666967973, 0.04106613168973596, 0.04267184048770897, 0.05694206668845108, 0.08085550124486608, 0.042844309862102234, 0.024520047872717825, 0.057136181877144886, 0.04965346021157119, 0.04050039874029256, 0.045857586477312355, 0.013214740902185442, 0.011448169919481922, 0.008112320492434646, 0.03356392074736857, 0.02168975518866172, 0.008132890910811482, 0.04260853864252568, 0.03212130440759563, 0.04253806238393149, 0.00800656780014716, 0.10809442388915247, 0.03084598826394687, 0.065485134480461, 0.024774745294463732, 0.1045716375172619, 0.030764635472047715, 0.040092093028849175, 0.07385408580904046, 0.13988082146933004, 0.024461650905469735, 0.12134714743062375, 0.5291380937541685, 0.47639643352839256, 1.046547197526501, 1.1553853702160621, 1.0961266919489832, 0.9916587137887556, 1.571640040605299, 1.2815606642153956, 2.462166629491314, 1.4818649546753977, 0.38996535203149246, 0.3146365393073328, 0.03586364774814537, 0.029390873199689294, 0.09712687167789667, 0.08014026623699935, 0.008429501002894775, 0.05562338805306823, 0.009466798416519118, 0.03341527287698081, 0.09228288241091276, 0.026714945317155896, 0.10239808519761409, 0.046591590639323964, 0.028253548643401558, 0.08736539466847336, 0.018353721900512616, 0.008514768504087002, 0.025320586770953193, 0.03826922894785962, 0.015549873613992767, 0.053441841605930566, 0.06691552788740204, 0.035274909178335825, 0.022924574009413203, 0.04999920335267821, 0.026236785793556806, 0.03917399027775373, 0.028880237293760144, 0.01952301530588058, 0.04887175558495426, 0.07215514794112214, 0.0645772590031547, 0.05648468921501791, 0.04087472079141487, 0.01903177674619421, 0.02025806326268902, 0.02344966024881409, 0.02424145233817399, 0.038745134257741516, 0.02408325901224969, 0.0403048433063011, 0.13653248097867737, 0.050588056835676395, 0.01865302096121013, 0.033571769318152825, 0.02023703797960714, 0.044470477038093155, 0.05630501478369679, 0.0601644738156709, 0.0037556282627666674, 0.043020341545343406, 0.03784886501248806, 0.014146606422840588, 0.020085473229447683, 0.04319689033793346, 0.0643918963689958, 0.028007329899757624, 0.018241779217796943, 0.061442883039313945, 0.08825944991962564, 0.05855290827551677, 0.07612372087615152, 0.029800659376046354, 0.027943288779727397, 0.03850016998307359, 0.05256369800096559, 0.037256882060319185, 0.048372948076576, 0.03738704039865444, 0.017135590389971773, 0.03108181694011775, 0.03315702463770586, 0.024414950185605598, 0.06180286775493334, 0.03170651376187321, 0.02195649934301694, 0.022000553229102687, 0.08508232241917042, 0.030807814102679975, 0.021321487147361044, 0.10153235221702246, 0.02141620434309927, 0.025157260655936216, 0.02040339971802408, 0.014471535912654815, 0.06430735856655144, 0.09378314303654818, 0.050390295068463015, 0.05520237677340066, 0.15827097659630163, 0.11008588477007805, 0.1451022162913315, 0.14257245606953098, 0.11852507103955555, 0.26018818840384483, 0.16794006340205672, 0.257210006276446, 0.14657595495302833, 0.10702189313428057, 0.21518436861374687, 0.1312611525457713, 0.10268731403254694, 0.21897981333876812, 0.13285921195582037, 0.15722168128817313, 0.27559225537603904, 0.29380712958593524, 0.1411051525463981, 0.10398688260465862, 0.1795826999530677, 0.21437363308523932, 0.11549663354432392, 0.21809455277698658, 0.08254532266648547, 0.1476040755909297, 0.08019626726426425, 0.08243174247083165, 0.15909458240193708, 0.11843935346170781, 0.15885277440951717, 0.132011566311121, 0.11229876804375842, 0.06451663080482714, 0.15391072588822535, 0.14836421867291774, 0.1280695153400302, 0.1561233410311322, 0.07542772233606347, 0.143069647132389, 0.2204722292240589, 0.13676865056397455, 0.1868646108214894, 0.14005608706464692, 0.14902932088701956, 0.09636660602184073, 0.20992897480966585, 0.1273340249674455, 0.23004118833811055, 0.13239989627993878, 0.17478763306092832, 0.12112184097209286, 0.12758619046860165, 0.17893851193929874, 0.17811815434646222, 0.11458024683017885, 0.13261243971365114, 0.31859418016768276, 0.07259135840520745, 0.09859228296385658, 0.19046687881552404, 0.18007788386556411, 0.1459529109659695, 0.09606046962641901, 0.09783407808431695, 0.2558515791691119, 0.1694405691758279, 0.22579447186041265, 0.15569037877984587, 0.13802615324816397, 0.13545199057027218, 0.13642061681997392, 0.22452023781595692, 0.2542086729719754, 0.17248206080928927, 0.29218369734383404, 0.5443275948205303, 0.98330449433096, 1.1753651884294327, 1.420273201600198, 1.2474999048056141, 1.362215504050255, 2.209743477644459, 2.041901213026816, 2.71013617515564, 1.9645329516741539, 0.5143114119287461, 0.513839838846076, 0.14744434625871722, 0.0725083987438871, 0.20536459231328583, 0.1761188946904675, 0.20528456676871548, 0.16246805057650612, 0.1320677818430047, 0.08302087940636181, 0.25369580775018663, 0.15583520004105184, 0.22105537535202122, 0.24055277267771386, 0.2512717676619368, 0.1318112802841971, 0.09245615617762651, 0.1033489152248348, 0.18172488097221623, 0.19175025994979567, 0.1711485775247697, 0.09252922564384439, 0.09436373043084338, 0.12585999519233743, 0.13353811907431773, 0.11348893926028283, 0.0827630678372037, 0.19508461167495098, 0.09766338603390802, 0.20411879545257938, 0.1448777831730343, 0.13569818058561894, 0.10055716059380963, 0.19312843680381778, 0.14352199140815966, 0.2016511189961626, 0.2186879798048927, 0.1486617519009498, 0.16996512489934124, 0.16455018562414955, 0.18006083074836962, 0.16318328558437287, 0.221229690998312, 0.18334561658482398, 0.10072830463609389, 0.22816369069680092, 0.15333176260032963, 0.1306361626953848, 0.2809527257998144, 0.22044910869050413, 0.14006115856670565, 0.1504679267565089, 0.13225542741917795, 0.07604380258389058, 0.07673928018419013, 0.16169512914794107, 0.11414225904210923, 0.2271749316564491, 0.08458547609587831, 0.10611926535925559, 0.14088130165492335, 0.1601144292902562, 0.18110710767007646, 0.10083398646524838, 0.0876988650810334, 0.12564893796919815, 0.19621440750216285, 0.1506602148255033, 0.15136167557249147, 0.1716839197662569, 0.09904058229538704, 0.1341251262854184, 0.09562579133818228, 0.1315787572774195, 0.11496933522604166, 0.10607723777572955, 0.09662513771364767, 0.060939459851191896, 0.2217010189328463, 0.22096237227801355, 0.15586271791929202, 0.17386762275090142, 0.16717674871606214, 0.08639501407742502, 0.2021915633832255, 0.14990048543099435, 0.13913782343508738, 0.1604823966420466, 0.11324253474031726, 0.10964110944299929], [0.04565224043964859, 0.0430623461462317, 0.03462722780363214, 0.04199039378774263, 0.03469302709544859, 0.0627155159600079, 0.09854932075306293, 0.030262683172740286, 0.07562000274417863, 0.10771458217453574, 0.03947048162620875, 0.07544102928330822, 0.0480317899716958, 0.03429905488906849, 0.053765869984823855, 0.030008227068690524, 0.05367983831092716, 0.033143844094968615, 0.021857698898642294, 0.032457360366900126, 0.02480593081864138, 0.022626236389060656, 0.043766599283703876, 0.033792992528047294, 0.026261045882898956, 0.0341379810725489, 0.0505689429419656, 0.06848084469956738, 0.07730234714765703, 0.08139384655101646, 0.053496590079439264, 0.05178058377256797, 0.019021909533729477, 0.025788995910496004, 0.04985019925140566, 0.03737953656743612, 0.03466070584592319, 0.09242872256905803, 0.04341453591722154, 0.031013370814522913, 0.026807437027474085, 0.018663794072645328, 0.047031363412257166, 0.029578911395923748, 0.0568907234757658, 0.022328214779976877, 0.02631363973412062, 0.055376757537165, 0.00481586282764892, 0.023280295445733977, 0.022699302024838906, 0.033942613330098896, 0.03930525178269994, 0.02503189994322677, 0.048247815275024024, 0.0293984268266227, 0.02430352461223881, 0.023326473310589794, 0.07216836295781598, 0.06909582944166276, 0.04580085383607976, 0.06974214717986123, 0.032102671234057314, 0.09939887395669376, 0.021505913239032514, 0.14550813563889073, 0.04236333305016161, 0.03512035860049148, 0.006623146595478419, 0.03135121175869098, 0.07315011229366064, 0.05810321466396413, 0.3067509511545781, 0.33271845129709093, 1.9481135424106353, 5.580636003325063, 7.1872300005728205, 4.692076973376736, 9.397593948148913, 11.289001049533969, 16.258182198770587, 16.415011305962842, 15.502764101951355, 12.731460525143532, 8.03939139650714, 9.53881888620315, 5.869689189618634, 3.8987832444329418, 3.2759723932512346, 1.7527856365326913, 0.7053288168484165, 0.1559668292682017, 0.34216765554681905, 0.17850846082212465, 0.1655333675444126, 0.07254297995278913, 0.3424373797831997, 0.2182800073416964, 0.55712150830415, 0.8305178798975483, 0.2891927062263412, 0.6374803930521011, 0.2788991811535051, 0.14342108230677345, 0.08616026941566698, 0.06436135244345473, 0.080476027252453, 0.03445572753046309, 0.03001214560842322, 0.043595068367017854, 0.04904494125155672, 0.017772240098565817, 0.04124815035010538, 0.0812468112957093, 0.024988834310563344, 0.02171357477744741, 0.0945384137993378, 0.027020970629828594, 0.05056635356478153, 0.019074239084617268, 0.0142589139549302, 0.024621182970041712, 0.04236125312144718, 0.020038333924246893, 0.019365394630679683, 0.043429313753280914, 0.046101861272848425, 0.021094265469019453, 0.036748513774645906, 0.055424959789360725, 0.028896212142201203, 0.025502498179013212, 0.0727579212417045, 0.012876440305262806, 0.01574304076888028, 0.02617432664509022, 0.0397259911011544, 0.012987730855632935, 0.040485659208629406, 0.03682619509016795, 0.04662955029597206, 0.04481834990362968, 0.019897498235466982, 0.030656885205497666, 0.04939782816255766, 0.012202896759845318, 0.03237756464870707, 0.03285915433098713, 0.06439677634907347, 0.05610799229133034, 0.05878401785007408, 0.04136769454024973, 0.032643339701838074, 0.026550255565633698, 0.07052061508499807, 0.01758910103460714, 0.054523197693690184, 0.05620270757184875, 0.031279122885016185, 0.023208537905086434, 0.04111426882445812, 0.0392273904365157, 0.03338469447748315, 0.0815523884469463, 0.020057133721908735, 0.039821679313336654, 0.06411970149905932, 0.03508170946471153, 0.07786883086326622, 0.027162491967300736, 0.02880994489626779, 0.03288588313866527, 0.02472855019262962, 0.06451555828173315, 0.009971409998533708, 0.06257775036858455, 0.02698466189265732, 0.07497054404549061, 0.015440395819173466, 0.03951571911813752, 0.03408914679781564, 0.05356981659368162, 0.05875098796921873, 0.014240401440239964, 0.06391615576801762, 0.05240774548221981, 0.0372194433434596, 0.09671899114525127, 0.01761336112394929, 0.060241726121955344, 0.03368945574508079, 0.028091875363081217, 0.02123419334360909, 0.0661993429305092, 0.024798875148858757, 0.02477626789421324, 0.01655737786824184, 0.02224057432143919, 0.04079228206988304, 0.009644307691844241, 0.03960550462286319, 0.02952232239617696, 0.019563847792244727, 0.05490125825388297, 0.06090909978675266, 0.042783095606512604, 0.036459166196084795, 0.04674749719279428, 0.0314998883573759, 0.08108197215704188, 0.05117811307671571, 0.04857681173410627, 0.024571155513366385, 0.03463096631270263, 0.039095056408475486, 0.03587145035365417, 0.012778438507549226, 0.06757859230762528, 0.004144621376443895, 0.00410062015890294, 0.0450225085050108, 0.01975657444657578, 0.034602146084991195, 0.06061721645716218, 0.024564078776165846, 0.0646018121211279, 0.04538698249586648, 0.022135214249212897, 0.015100208730737289, 0.030043668211287552, 0.04066700371162545, 0.0239315276379667, 0.02622076497984029, 0.03605841028113519, 0.01429047390458084, 0.017266047502597495, 0.012375068317558016, 0.05255016122734355, 0.035683103807030186, 0.058262361769354155, 0.06741122507880773, 0.09420221611376732, 0.12351311547982118, 0.02593350690609265, 0.042107647374993375, 0.04823419806216994, 0.0702745323219607, 0.12902639746185274, 0.3124621059865721, 0.9832403268064223, 3.8820077575022176, 8.555633656440243, 11.288153817576747, 8.082079531684998, 14.678120093960917, 16.222673962193152, 23.478772447955226, 26.139982938766483, 24.638805581677346, 21.567452453797866, 13.516609207276376, 14.749466046210259, 9.696498167130256, 7.454634154996565, 5.467189781127438, 2.927091539867463, 1.1564868207900756, 0.24383262490793584, 0.335579238110973, 0.16195227422060507, 0.18666394175060336, 0.10933353280227993, 0.3380677061936548, 0.22460921126748287, 0.815981759900047, 1.1790833502046525, 0.4026844646901854, 1.014723230994517, 0.5954449647857297, 0.31803499726999196, 0.06823463936246212, 0.04671442900754271, 0.050527528228779, 0.050971426385184454, 0.016132375270488764, 0.04969679397500811, 0.05665499439102508, 0.04935691523696146, 0.07084105434196611, 0.0432758433594098, 0.05051123736906917, 0.026193902106775392, 0.0927664217869601, 0.0636311021122721, 0.08548651806890004, 0.05057031423935006, 0.035617978672587106, 0.026941107878942164, 0.010134960194268535, 0.06564379128957949, 0.03022106736147356, 0.052031753359422575, 0.04807024758549468, 0.01302046579263744, 0.036137466724481315, 0.03798789081854686, 0.08030142815363023, 0.03944503218536416, 0.02595833390049877, 0.048911216773933945, 0.06894442748518721, 0.04780850598528501, 0.04130987022372504, 0.07386361594281851, 0.06810962147409878, 0.042278236003532525, 0.017318547508048437, 0.05046518016306143, 0.026592118440256007, 0.05484272530602832, 0.07970685965471691, 0.018300614770381682, 0.06344002063175844, 0.026471631961964795, 0.0576761091548589, 0.009613667047702739, 0.11034201094580275, 0.012392901886825361, 0.12569731642161647, 0.0415485947122497, 0.03441939964109371, 0.04397644608792278, 0.0710870681570903, 0.09925813594412419, 0.06337398385268546, 0.03136982769525099, 0.03163127052117019, 0.05391045758921293, 0.009643462122297816, 0.034607313348040465, 0.03600072769087649, 0.013258935556927276, 0.05950119489082887, 0.0822116683928236, 0.15030335574861498, 0.10043638683254681, 0.03407721114795535, 0.06305493887573962, 0.03793164847358581, 0.04587133392511357, 0.01814073988146359, 0.08166467395400809, 0.23523377825415906, 0.17953727093915786, 0.11654488697287538, 0.13714757297308217, 0.1103288495552636, 0.2218223825818108, 0.22633692339783718, 0.21440130418106434, 0.24376478016136155, 0.2265273422122963, 0.21041629866005915, 0.1671797671024838, 0.2413266593770635, 0.18784416148499136, 0.14329801794261704, 0.11614593902542708, 0.09700258923394066, 0.1786829143642418, 0.12401556190583976, 0.14114457543098158, 0.09281817102624525, 0.15741988355594297, 0.1484477375784228, 0.32000025794390713, 0.1305927101883196, 0.08431592039884099, 0.13786657713353634, 0.15359163494600406, 0.13766175586610072, 0.13101908408345717, 0.18861245574249377, 0.1419848359880909, 0.07696460962535874, 0.23583920221895943, 0.10915694187485403, 0.14171282880969588, 0.15584114488334427, 0.21844833218041929, 0.14869506140389752, 0.10933285098402731, 0.08299464089495522, 0.13309145917094525, 0.1838709383962616, 0.19457035217313998, 0.19150501988347501, 0.1997034170574719, 0.11332966191994567, 0.13524465653444492, 0.07767751572593566, 0.14051842112695018, 0.11241006529739789, 0.08534522081214575, 0.11278350251696764, 0.1507391984904966, 0.16677665163672742, 0.12530027603309962, 0.12003224943914723, 0.12687599631927668, 0.17712358835964434, 0.14035590323469332, 0.1667370448910421, 0.2036891733446429, 0.05724463694458527, 0.2860421543159793, 0.15005347318947315, 0.2685754415729354, 0.18689102553311857, 0.1117006908621519, 0.1617174529500546, 0.12886369570849404, 0.17142585538808378, 0.2802742476905546, 0.5032999092532743, 1.2165818219223332, 4.024123563881844, 9.333698538041885, 13.655069854951675, 10.295297003561451, 17.66621405078519, 18.977158415702082, 25.950693276620683, 28.427530796297138, 27.806790221122007, 26.502225591290383, 15.942164678727428, 17.716793014157204, 11.97300749440347, 9.16253120668473, 5.979720007988715, 4.026764299600355, 1.5575032056339326, 0.6177767955007092, 0.7072090417627366, 0.3364233750729792, 0.6147305847656342, 0.42791360929127664, 0.7169271428738871, 0.6603199255562598, 1.3811827378888286, 1.6459755743703537, 1.01530343534485, 1.212042904188556, 0.8810251987268849, 0.6447448677593662, 0.28689245062489666, 0.14965538326050007, 0.1388604383194639, 0.12262411640896914, 0.12978370601852096, 0.12049714989599683, 0.11915644240235129, 0.08330247034468959, 0.15129994420755297, 0.2010665632664196, 0.07918634887544379, 0.13809240453185576, 0.21489414386451247, 0.14726394787430763, 0.20643342286348346, 0.15402124173218204, 0.10711078997701408, 0.07520141230235178, 0.17799260785743115, 0.11188415359825858, 0.1772147987879092, 0.18552787932417086, 0.16198308627691962, 0.08860900817859559, 0.13233079514916868, 0.24137406489781796, 0.13201089215374764, 0.10096617493658297, 0.11102482511271393, 0.11973824021556687, 0.15468378521261678, 0.09803783448953783, 0.279306004484815, 0.15667942893360892, 0.1437919761144346, 0.11267821139265453, 0.20111255918539342, 0.20954522604663528, 0.090624064567589, 0.09708512754690263, 0.10986658444087352, 0.10855069053509545, 0.12349011752033427, 0.1575910429199857, 0.10767132118945161, 0.14279419255833473, 0.23243075446976771, 0.10418369825328551, 0.26689899604647394, 0.09359427171969607, 0.10697867045359266, 0.18212646426212403, 0.17610622359619987, 0.14405598533490013, 0.1449469762343553, 0.14434285461902618, 0.13359067270592337, 0.18853647514216362, 0.17873494705605894, 0.1388341461819026, 0.09400172324310388, 0.13315947245686285, 0.1667111664409599, 0.21069192177345678, 0.25950719752619344, 0.2138332499852104, 0.18641808881394326, 0.16479314274845586, 0.12111509939835918, 0.14721903980018633, 0.07450763541724413, 0.21277212627953102], [0.10423982951549754, 0.01952227603103365, 0.029757771858825322, 0.02159642652728625, 0.016143334158245596, 0.05862320067300912, 0.009807199051964187, 0.07529923406940314, 0.12848027636327092, 0.025350801278686812, 0.04679481078299784, 0.038751879661914804, 0.016980691242121884, 0.029739533220568014, 0.037554285053404114, 0.04167384625742993, 0.05249867245795266, 0.03274641683205001, 0.03402052830243784, 0.01043150995692779, 0.01542221463751048, 0.07345260211056279, 0.030591784968912124, 0.05640390141296291, 0.04144193612099175, 0.04159080998731717, 0.006637915813048641, 0.03621464242197333, 0.060785801765779336, 0.0329127345204113, 0.01882809311932614, 0.0300386120309873, 0.08523648995305262, 0.02421908640122462, 0.040597186288646156, 0.059522545761278564, 0.010084787180887596, 0.026065088252747254, 0.020009881418739116, 0.062463549641712066, 0.029684436177053762, 0.050954549468212554, 0.0341192961880757, 0.12382339641091325, 0.02323739069153465, 0.11213925321616473, 0.08371182176614962, 0.02949831511584982, 0.02669902984052897, 0.04674727119685662, 0.050873367130876555, 0.08552090775582098, 0.0031447277269175938, 0.025926253968669523, 0.05108455458896295, 0.013167897498445406, 0.028923103743563258, 0.0174556523486371, 0.03727505749632274, 0.04411278292536736, 0.09091582149267198, 0.08181603760608742, 0.03756096150966422, 0.08093194915883004, 0.04259401361548132, 0.034576298278425975, 0.047859975602477796, 0.046848053893735336, 0.3167343638356655, 1.0599150027959579, 1.1526656967978324, 4.955522966000342, 7.2559067799199015, 14.078248489287592, 30.201028508524743, 41.376118044699396, 43.4567432249746, 39.5374011224316, 43.45954771964781, 46.59547482767413, 53.782971059122396, 53.494567025092344, 56.58388068599086, 52.08078792018276, 49.348774725391024, 49.33754105721751, 43.73883224302723, 36.63910296655471, 33.43013348117952, 15.955362473764728, 11.560150577176003, 7.570735821800848, 5.873896421924715, 2.986889789181371, 2.9780365094061825, 3.8919867575168614, 7.21552646929218, 2.833394451487449, 5.4203184381608045, 7.284198345676546, 5.47231484805384, 8.613073825836182, 7.960754738700006, 5.824232351395392, 3.084616622617168, 1.523856991721738, 0.24744728820458536, 0.13318388001813045, 0.051216275746663736, 0.06344991465730053, 0.030478352245183724, 0.0362186107574211, 0.07433207870851602, 0.034412956841650515, 0.02880811203090895, 0.07706027868534289, 0.030121908770994316, 0.043510013455224615, 0.010852656259592022, 0.07005642708991805, 0.05653268462347408, 0.04207838664672548, 0.058261427142086535, 0.04645816110555203, 0.04798800804682317, 0.05274037319806315, 0.03897726272923812, 0.02612593478613323, 0.0427150133726818, 0.08979901085577666, 0.03329381346702576, 0.08531256248393367, 0.052641953882430835, 0.034854993404399966, 0.05624001605376121, 0.018929843002209262, 0.027635072455591256, 0.020308286071785038, 0.038390784118805206, 0.07897937490094094, 0.026527207810431722, 0.04054532979705161, 0.024035819017538623, 0.06399079571448027, 0.015390927606682866, 0.07863274309784174, 0.06331968737105209, 0.07432050311998015, 0.017918063019732797, 0.09462065333800931, 0.053379018565699946, 0.08305283293368355, 0.010934289631193445, 0.026722765159642985, 0.04568543502940767, 0.02895511855791894, 0.04192365986865856, 0.006592936875794324, 0.11544931995412035, 0.030943547645884178, 0.028677490209379507, 0.044151914696539604, 0.15523906106189375, 0.025729440235262437, 0.009337808362268394, 0.0344589144562281, 0.05935239763329587, 0.08715214643387065, 0.013649409614323128, 0.08944997353659523, 0.03230403936017425, 0.03215453730175092, 0.02280809991662541, 0.04267044237724716, 0.03595535996400061, 0.02908644709555853, 0.030968604466667583, 0.04219605392145534, 0.033295632925845926, 0.09829924667194005, 0.047277147401004076, 0.04780321231772823, 0.037076958650422674, 0.0260725058990741, 0.056647471407608646, 0.051719009455653935, 0.02892728658362983, 0.032913558064929904, 0.021771772561835188, 0.02633176920484872, 0.030907733035424066, 0.04451661468333295, 0.045164326701553605, 0.027240489294091542, 0.026797677067318754, 0.05064194729070991, 0.005299811103125854, 0.11270051221213034, 0.04260080115449044, 0.05845602879661226, 0.05414460470239001, 0.044803212006245895, 0.03928881536628451, 0.020998816659313538, 0.027466410538181666, 0.044089371278401346, 0.023301232628704562, 0.020762809867700262, 0.02821187537554051, 0.02366824428580942, 0.03328124962506756, 0.09763994374342504, 0.031531479908153415, 0.0497493207935364, 0.04188829341963415, 0.03429677960793338, 0.014395102362839446, 0.03780984815450446, 0.02255639981388325, 0.03120880558966629, 0.011585588856119544, 0.05736916836711669, 0.021461949368277868, 0.033212600486172784, 0.005596890424062769, 0.03152495858469798, 0.06895087028463041, 0.035153369329148726, 0.04542403050788468, 0.01823311284815352, 0.006216137009041925, 0.050471017753044446, 0.008441371535281501, 0.02444648236456898, 0.027385348859693737, 0.01481133612668923, 0.08038645625234613, 0.15091493906032655, 0.017880530457102486, 0.1307774599521391, 0.008780352035236937, 0.07891281718207944, 0.03298606828696305, 0.1402491412215656, 0.5372105154298967, 1.9736545460839428, 3.0169162682948576, 7.234359729674555, 12.085615800273034, 21.474078470660796, 38.71123229303668, 50.94163356288787, 55.122185907056256, 51.72314620787098, 56.49955757202641, 61.35079206958894, 66.43607831770375, 65.48675490963844, 71.32145312524611, 69.60510238524407, 68.12782795198503, 65.97315234522667, 55.85171145777549, 47.6085328286694, 43.4216772356341, 22.469562292099003, 14.227532917453399, 10.033769049952108, 7.895654180357534, 3.8056029283231307, 3.9027291488262916, 4.427768549611492, 8.718090384237229, 3.51646859799662, 7.650200590010613, 9.848612585375387, 7.042097891530684, 13.274391082025344, 11.22222661972046, 7.646860691808886, 4.141146742528485, 2.19600782759728, 0.3702217340469361, 0.08503905377320706, 0.055417107388136856, 0.031219165013622374, 0.028450180430926626, 0.029424475731268048, 0.06450204449074884, 0.034654094507136655, 0.05787434972702496, 0.04954397475587265, 0.010537432146168525, 0.012255041492021373, 0.019377002777952342, 0.013943376703067653, 0.0737756690491111, 0.03029426897785837, 0.039805955358690796, 0.0367239568262331, 0.027417378995807904, 0.0892776880233038, 0.04728608764708043, 0.05510108845849192, 0.02653563860803843, 0.022394538842021458, 0.04415970581072954, 0.07897311596259957, 0.03369776779905923, 0.06925414151121533, 0.09015923305865257, 0.0385423201406675, 0.021745348274106943, 0.06862896013884776, 0.02474578525570612, 0.0674837582834786, 0.0187315660408668, 0.048167176860114264, 0.10192383846808827, 0.05753981445225016, 0.05204876434178122, 0.11495517792120097, 0.043929255071787104, 0.013422094090210815, 0.011631543597867413, 0.03034813836547396, 0.008319717730515668, 0.08454621408975894, 0.032169947160347816, 0.07447736728335581, 0.07010182546031091, 0.054409728580785376, 0.018099397946629795, 0.015537207307774695, 0.051501995898903384, 0.029001949512730205, 0.040076116265188304, 0.02639401576391632, 0.07876194382627165, 0.07034596236002061, 0.03426856458968213, 0.1008596197671948, 0.04654844073698886, 0.06548939392932, 0.07207925161046368, 0.011538816315512504, 0.019234244208482486, 0.05406185954568848, 0.04377769223684746, 0.04868264678084562, 0.03173942298388049, 0.10745255712179408, 0.16031382665518792, 0.2142545523782892, 0.2016523753803584, 0.15336525596437917, 0.06833980025182809, 0.17331844496150173, 0.12123181289362332, 0.21861435875536936, 0.21887181026320304, 0.18856411559447167, 0.12648604224405943, 0.14403062782460643, 0.18257470230662054, 0.15303540914770097, 0.15899091538402343, 0.1493627529951834, 0.16557228481096609, 0.13226408421272232, 0.13389533055165123, 0.2005264712798019, 0.1823892783854277, 0.16825821971701038, 0.1372255607237739, 0.17133891973043644, 0.09260739725563796, 0.15305494438977013, 0.19718680290445206, 0.11127087723223433, 0.0964488915257877, 0.11686037730185256, 0.10655572863235589, 0.09828303625146229, 0.20892995019112864, 0.1625376113600308, 0.20294340207211434, 0.2165990418964817, 0.08854365321777521, 0.170538725571767, 0.1571649754600179, 0.15944817794426797, 0.10955294038379386, 0.19763694084700079, 0.11425141891043995, 0.22815907884749675, 0.12139317399311451, 0.19377051041491572, 0.18545545337180938, 0.12866535554489783, 0.09430715483763526, 0.13205178592714573, 0.1587926977944951, 0.1518597399755832, 0.12091391704856388, 0.12312325333515484, 0.13851124012181837, 0.15001377451323694, 0.20259035811308893, 0.0873410100898435, 0.148380444415154, 0.13098701564294676, 0.19571337067792494, 0.23046006989334863, 0.13836795103646096, 0.23347159216721214, 0.15399209974754244, 0.17986311877687133, 0.1579677589958714, 0.2921851988761656, 0.9578682301986603, 3.1035822629928593, 4.855130391736185, 9.180748654950051, 14.222032773879267, 25.96224073440798, 45.46521248355989, 59.96900381580476, 62.46440787469188, 60.850329014562796, 66.28307450202205, 71.47467659365746, 77.08970639013475, 79.16252213139688, 83.31079729141729, 78.66858590033748, 80.90683937072754, 77.75183385418308, 63.23419655522993, 58.393509311060754, 50.78734320978965, 29.083296175925966, 18.12245238211847, 13.383208417123365, 9.679463313471887, 5.23324687634745, 5.247193844087663, 6.515632954335983, 11.141480707353162, 5.847255193418072, 10.603862020277209, 12.247007604568237, 10.051262820920638, 15.839493697689427, 13.426965398173179, 9.278314671208783, 5.778748056580944, 3.146890868102351, 0.5699173829728558, 0.19091504025122813, 0.18490696506154153, 0.1625245419000426, 0.18096876751270988, 0.11253024151007976, 0.19043841098825778, 0.2529569006254596, 0.1778789357312264, 0.0808076820366325, 0.11504019835903762, 0.14193084211118762, 0.12695697947375237, 0.0894359541275809, 0.1594759256488854, 0.14230942744160854, 0.14247317107454424, 0.16657610513990925, 0.1206044558315508, 0.1672414984674223, 0.13949307372733472, 0.12889841481322242, 0.0891556655387244, 0.12129953506612971, 0.12625149676516173, 0.36159319382521415, 0.12156459382705151, 0.19761621050776976, 0.19594207856683962, 0.10098538076084468, 0.1108112321385453, 0.13776865577505482, 0.2303578737642496, 0.23205478916004782, 0.12812756182205293, 0.11029191645643405, 0.26456353104402947, 0.14314581159382098, 0.18564078536245132, 0.21992735684879366, 0.1233240909453842, 0.08934396995051254, 0.08258890540849778, 0.19106068888739233, 0.2022727687031992, 0.27482233701213715, 0.15071848347302408, 0.10367075642270428, 0.157648254366171, 0.12446593733564501, 0.16882179995938656, 0.13211086662786622, 0.3085279993472561, 0.2275719490623282, 0.21000469494010174, 0.17196274512717802, 0.20382443382855386, 0.15762456692755222, 0.14248863072885623, 0.22298361865743516, 0.1668898181449021, 0.15457766671334544, 0.2225141599774361, 0.1712688839723987, 0.14796632792680495, 0.09318781611058982, 0.2063855423682159, 0.18047041199620695, 0.10701958720962848, 0.31247516012480187], [0.06949932795138129, 0.002316181611780438, 0.056233412375853914, 0.035890127577248125, 0.024498742967543584, 0.09284915162190314, 0.022191312952688145, 0.05296910790005519, 0.08019393069609519, 0.12499502829967007, 0.06029820595417292, 0.04880092692591491, 0.046336590612847964, 0.04179653523850345, 0.0430865430333201, 0.07224526286365525, 0.03195203728072586, 0.059755635673120144, 0.02223332904489531, 0.028646777744495103, 0.12706345037346886, 0.024784170091152195, 0.03991699597287563, 0.050997538492083556, 0.009504315657390943, 0.05783677694477862, 0.04406099921212562, 0.0050742436958957585, 0.02447193372063339, 0.04519456036148533, 0.03548265307120258, 0.044246794685961745, 0.10493258750366588, 0.092821350291131, 0.04906958246964121, 0.01992718988819228, 0.051105870985456055, 0.030622725344954, 0.04715067777602423, 0.07804589676520518, 0.09406994337276106, 0.014689432385738098, 0.03535032287360199, 0.036107746343458855, 0.03731457231145713, 0.0791288463158473, 0.013003578341956581, 0.014489786999840892, 0.05137128214682302, 0.038639636289688854, 0.04184675613237966, 0.04249565175644333, 0.017557586092622052, 0.0513105160526691, 0.053963057186094024, 0.04551170927081858, 0.03174732326559963, 0.032538814665449244, 0.054131979573397875, 0.019644574307265784, 0.02194096116469272, 0.08919040762609051, 0.05059650295504159, 0.013647138163627637, 0.0710090727455193, 0.8592598440666354, 2.9202337659174398, 5.553766787052155, 9.31567132472992, 20.881979042483916, 25.873797170577514, 34.66531530503304, 52.851682709109404, 63.08980234207646, 71.91675124629852, 72.87990493159141, 74.09037974572952, 72.69514560699463, 72.80092408580165, 68.20882489604335, 76.979017103872, 77.21402983511649, 76.27713249575707, 84.47411737134381, 74.95887879402407, 77.24990383271249, 71.32700720141011, 67.81173198453843, 62.15744318500642, 48.41750598722889, 31.12088707185561, 29.677007698243667, 29.562721598532896, 22.94460838840854, 19.68322034805052, 10.28444282470211, 15.413290915950654, 24.136185223056426, 33.11918366339899, 31.62342506070291, 24.00594488266976, 30.074883122597974, 25.56186479906882, 22.346899970885246, 19.49985738723509, 11.107871878531672, 5.816645997185861, 1.9198833862620017, 0.5352098002068458, 0.07597195885835156, 0.033148210796137015, 0.04670787129491087, 0.006826984397541251, 0.05904094075724002, 0.04749210018123831, 0.05233108689407668, 0.0365854136555666, 0.031912470754656586, 0.05778213955401894, 0.05231407208127841, 0.04311131065591209, 0.08581434241345814, 0.04718262747290635, 0.034200459373213594, 0.09678737981425178, 0.046193313018809405, 0.0351788149395537, 0.03786446639306603, 0.0769545432300337, 0.03012156786186801, 0.02275934799634401, 0.010906879962872594, 0.025305730410881584, 0.08144893593365148, 0.037692996763413956, 0.11508707527912433, 0.02098406946677114, 0.03400458218229394, 0.053291370446283015, 0.026033220910316995, 0.04680050281627525, 0.021233988415089347, 0.016399621212434386, 0.02851397831804089, 0.053920930011137846, 0.05158712741948905, 0.04906265703480571, 0.12221550043191641, 0.0696696216360696, 0.039002769626677036, 0.02266508662292073, 0.00951226860765488, 0.02133230047841226, 0.07402797244609365, 0.009277920396397672, 0.03598420317434976, 0.04325477211105247, 0.03554357621338099, 0.040214862449154745, 0.00750628748773447, 0.05151269048632634, 0.018146468303917397, 0.01311179017648101, 0.04667796705278658, 0.04722121915209198, 0.02867919667023084, 0.0864532674031873, 0.06929125847114671, 0.019227652021894054, 0.041452312781926126, 0.088009383499382, 0.025218710483562563, 0.02702361363316736, 0.010945615283544026, 0.05181683505314493, 0.020852078263077046, 0.008453393370033273, 0.03353229663785427, 0.04634850711051015, 0.03658767744538285, 0.0037175038972148493, 0.03069449820736003, 0.06117397468657263, 0.0278367470168779, 0.10186340945262103, 0.12296139427851285, 0.09079483322679036, 0.018647790495907108, 0.07346492846526446, 0.05406780821842052, 0.04437117672134792, 0.03412428342046277, 0.019847825094456636, 0.07271613880631424, 0.03698788560746658, 0.017589796259398424, 0.0847787447574158, 0.006086105075214179, 0.051575475222160744, 0.04133721190174261, 0.07128848799414213, 0.018172662765268358, 0.09809342949020286, 0.05530524705987304, 0.05368363044615235, 0.027851296941779798, 0.11874968035807533, 0.048206871705910856, 0.08657109172594163, 0.05210447808607452, 0.018616539854255897, 0.015198950760907706, 0.04544487576030436, 0.036120118663435986, 0.04828672488069823, 0.036701165710485754, 0.043006084649072546, 0.01375727670928163, 0.11035559368470024, 0.03586867711536827, 0.042164360864027854, 0.04190751839609396, 0.00825594665647875, 0.03230239993201629, 0.0714905436841711, 0.02154248436131785, 0.08521371415906376, 0.06796044117260365, 0.020425794383270607, 0.054363698187854984, 0.033826367148468574, 0.07059398332550641, 0.01584533265896983, 0.05571250706129978, 0.08028242151222884, 0.0858834895095037, 0.005301690891370057, 0.024465487090750568, 0.015407240491420513, 0.04451523189462962, 0.6475587393487654, 1.5515434093052343, 5.076105940726496, 8.59890720536632, 14.116066021303977, 25.895997785752822, 33.68126715383222, 43.27220747547765, 66.24512949297505, 77.10174022182342, 81.59467404888522, 85.43159146462718, 85.34080428461876, 85.09777422874205, 86.11087537580921, 82.25023546526509, 90.6523681456043, 90.9626825394169, 89.13229280902495, 94.95665950159874, 86.78620553785755, 88.33931507602816, 83.13446321795064, 79.47686872174664, 74.79788903267153, 60.93958254783385, 42.861472560513405, 41.119928436894575, 37.808530176839525, 30.454001772788267, 27.365986416416785, 15.53546097970778, 22.232362839483446, 33.35794618052821, 40.768695877444365, 39.4308695485515, 33.13541443117204, 39.82979028455673, 36.13527451792071, 29.254413497063425, 25.399006028329175, 14.165544759842659, 7.828344347015505, 3.685395520540976, 0.7898845151066781, 0.23893592879176143, 0.03913821397168983, 0.02255230698914778, 0.04864729948401932, 0.011323974618027288, 0.05407753753505888, 0.03701991191314113, 0.026382116503232432, 0.048281703174354575, 0.03361021927107246, 0.03258340481308199, 0.08249918119080606, 0.035717761624724634, 0.09213815308025769, 0.03184491520627372, 0.07393617979100636, 0.05726423730412799, 0.06158143387085969, 0.046407901907279614, 0.0608183490112424, 0.02396769081843236, 0.032030963489124854, 0.0631944090127945, 0.013117886321138472, 0.026066702783047676, 0.03804870670841586, 0.06947353377097076, 0.06285109053996783, 0.049250126410756385, 0.06892884525680734, 0.03770099089090382, 0.057169284536353046, 0.07369813329029469, 0.027716524838920564, 0.030970933373957395, 0.0514742941595614, 0.03450466905750575, 0.007397172627069297, 0.07344443561328996, 0.011288233743529889, 0.021363116365166444, 0.09400166961694918, 0.05075229076488365, 0.028834024954947735, 0.04217825003809506, 0.032863708723696976, 0.0461510019827514, 0.05985593573460656, 0.0375484129894645, 0.006502517912116263, 0.022017273098050107, 0.04027876950379822, 0.10464324375554439, 0.05230318597187439, 0.019953719513010115, 0.07852603471086872, 0.03656517744304673, 0.04947249875253728, 0.050372123462899085, 0.017765672809834925, 0.017055382899519418, 0.0289636661839341, 0.021069767892420776, 0.03773146203809208, 0.04134538605989468, 0.06078259951825585, 0.010516803313587463, 0.2401563374986572, 0.09575850074930538, 0.20101074610025654, 0.14319890148697362, 0.17628510512651938, 0.13701985079434612, 0.14356864616274834, 0.15925461816931927, 0.1816810454211889, 0.23876552019388447, 0.27426477822084583, 0.24631424416457456, 0.17640536560887293, 0.198466123772725, 0.15513824389105843, 0.3431037843467728, 0.17646231658516393, 0.12545594509931343, 0.08895780801052049, 0.13045982457697392, 0.21282851035075806, 0.11508992512620266, 0.14223353877182932, 0.15474939298245216, 0.22455814384645034, 0.13647030528274276, 0.18709505006911295, 0.16810368446092452, 0.1409339625388384, 0.14526695583856877, 0.21130371958978716, 0.1306446815931028, 0.17364406297283788, 0.17170484928834825, 0.1027172833921448, 0.13945256299789877, 0.2518951946929578, 0.10804006229004554, 0.12026082709311478, 0.12404030654579402, 0.17320089643040013, 0.1372108824791447, 0.16686659035903795, 0.20361912226484669, 0.20341281478683795, 0.16216965932999888, 0.07321261740740269, 0.1532741681101822, 0.2416264908688684, 0.22295032447624594, 0.18289702613988232, 0.17004844462198598, 0.21787565081350266, 0.204781997768629, 0.12101245127738484, 0.206743213498304, 0.10533749561516509, 0.1641310589207757, 0.25353296810100157, 0.09811795196465908, 0.15385847869178942, 0.1831889975695841, 0.19925075102477305, 0.14033682764537875, 0.7750353409397988, 2.140896810639289, 6.297381001134073, 12.001755525988917, 18.925098757590018, 30.56413016011638, 41.01722901867282, 50.62079152753277, 78.08509411350374, 88.80369232546899, 94.68609440711238, 95.57830810546876, 95.85274065694502, 95.45290993105982, 99.8246660540181, 97.79942866294616, 103.64604303913733, 104.67393152175411, 101.25323249447732, 109.87901087730162, 98.87413455593972, 101.40600096794867, 96.83865977871804, 93.97071684560468, 88.70348361230667, 73.164974950975, 53.959473794506444, 52.62798993818222, 44.858080571697606, 37.35119358185799, 32.29255787787899, 22.836970706139844, 28.001398617221465, 41.03043563904301, 48.29988195050148, 45.58253842015421, 41.11972839601579, 49.69180953118109, 43.73032069975331, 36.069096288373395, 31.712535427462672, 17.53813885873364, 10.60493871088951, 5.022948018966183, 1.1168665919573078, 0.36326908776837014, 0.13523132660456244, 0.08359252655458066, 0.14063702685938728, 0.1385362145881499, 0.15954301962929388, 0.18518672504973027, 0.13790149542112506, 0.13605836448409867, 0.17077365409462683, 0.1467768998155671, 0.23161546837898994, 0.19168063787923706, 0.1858575882450227, 0.10087173161727768, 0.1703878522159592, 0.2855337783694267, 0.20388769736934095, 0.21943975720674763, 0.2047242960261722, 0.11674282110987172, 0.18127028439794818, 0.14825201743552763, 0.10114178527146579, 0.19872397364627933, 0.18195472267125884, 0.30965405666539747, 0.10932898990088895, 0.12977082041963456, 0.13964478977985922, 0.16905075299643701, 0.12492493125459841, 0.16719824514321743, 0.1044926768349063, 0.18743304806130548, 0.12810979624308888, 0.21035835176946657, 0.12604965557975154, 0.17904020245036772, 0.14057140376779342, 0.2501136265815266, 0.14402434590362734, 0.1715163150501828, 0.14999045479682185, 0.3161009929833874, 0.15693868840894393, 0.1447538301468857, 0.23054400248633278, 0.09168849777310126, 0.13062911468648142, 0.13999930462769924, 0.16335931726761405, 0.2773262800708894, 0.1082651312613199, 0.1507454957332342, 0.29990264605129924, 0.16912366924507005, 0.23677663336838448, 0.19732365685124553, 0.14087285936599778, 0.14682487224138555, 0.22034986966079284, 0.1539662519409772, 0.18616786917611478, 0.11996823513219435, 0.16479239198229007, 0.13536119382948647], [0.08283820574081714, 0.04709777557441304, 0.030959989807959047, 0.03700670838776616, 0.025488930761874206, 0.051869235467165715, 0.06831404437581379, 0.036399246629087195, 0.03153137840150345, 0.025354817494629853, 0.07401780645933843, 0.03464144256506716, 0.05308719652314341, 0.018325008925110586, 0.020560355811950662, 0.06394772625137722, 0.13221744477989214, 0.007079494159458386, 0.07220069186822062, 0.025707882521073186, 0.01842646769458248, 0.03779196766235175, 0.020738162903956348, 0.0563901539651617, 0.06324669451362665, 0.012350517114804638, 0.029386964236055652, 0.0759804317907941, 0.08213905091848105, 0.025370937899776527, 0.10175834049380596, 0.02164491031679415, 0.03771579554004054, 0.010108619218602056, 0.011443022766240664, 0.060291740172092, 0.04321554074845007, 0.03726925821073594, 0.1495153423879416, 0.059502049078864444, 0.04418642312708882, 0.004153965255095354, 0.04175010264941281, 0.09465149603784086, 0.014776854509217365, 0.009374562388045654, 0.0984752553725435, 0.01555879949592054, 0.06493059407559133, 0.029996074998991627, 0.029935500426818768, 0.0699705486336062, 0.00414539368883256, 0.05543617148613257, 0.07467045974467071, 0.09062917437404396, 0.029995881561790744, 0.003247409603641098, 0.05572822718550602, 0.009760570152842951, 0.07331304387339661, 0.16794263745748228, 0.6537980658392752, 4.034952002186929, 7.47067419751998, 18.40980718212743, 26.171477610065093, 34.80862302164878, 46.83850096118066, 57.50909328460694, 61.39280065413445, 74.9282293934976, 77.37407038288733, 76.46371180011381, 78.90013125634964, 78.16529089404692, 75.7308247781569, 75.93294451313635, 77.9007270259242, 72.35049478469357, 70.91063976287842, 62.019199248283144, 73.02906482450425, 62.70648087224653, 64.01150049701815, 70.8952719165433, 79.20864135988298, 77.22195302286457, 78.89500864090459, 82.174023812817, 81.81719010876071, 64.93414394317135, 60.314399888438565, 59.72491864235171, 56.010096765333614, 55.235718911693944, 58.2059415694206, 56.58037408705681, 51.00580353890696, 48.63742543805031, 58.40321717723724, 62.12893147622386, 68.98029235101515, 50.174429724293375, 49.41587078955866, 36.01475184963596, 32.632539118489916, 25.052335185389367, 11.74109245500257, 3.600354857983128, 0.9872118491799602, 0.15452666057934686, 0.06879467261774887, 0.11906128662127642, 0.03702843464129875, 0.03954331743560972, 0.015720738034184664, 0.03285738466788204, 0.12363279373535227, 0.043038700842448784, 0.023854296399100174, 0.021697994464287357, 0.04803046847002641, 0.04293015767489711, 0.0034298627795050704, 0.11072713100621778, 0.02796182044661574, 0.0703088760436062, 0.014537773789807916, 0.056105648062282035, 0.046784495409097404, 0.07400775538577188, 0.04459443772512098, 0.04161316443294768, 0.08532974583607528, 0.010895314908045675, 0.021416334578046398, 0.08165427814087561, 0.025228568119928244, 0.10070770453180998, 0.027506155179693337, 0.025917959151669376, 0.03035665534797215, 0.0432894988766601, 0.011799088942127363, 0.004935379247106011, 0.014374115384153783, 0.0149333902123955, 0.07944096585795765, 0.07096136078959511, 0.01612370890084534, 0.058709155738113396, 0.03134813017001556, 0.059481000813144835, 0.02914654286277871, 0.036429752250232046, 0.03160567169318036, 0.03677834906885701, 0.030297672323461984, 0.05432399568117915, 0.06060752161448041, 0.06927494845923877, 0.025975963498856273, 0.02141561254017776, 0.03703938586817634, 0.02340049272583377, 0.05965548116833933, 0.08674460297991192, 0.025589033555720123, 0.05675778040782579, 0.045267576201548504, 0.06435189891846911, 0.08266903820537752, 0.04588851727725518, 0.07624757431086994, 0.09525032398561317, 0.0628512092835961, 0.06262647739100842, 0.03629895805891964, 0.04038443601119422, 0.036705643494403174, 0.07278359284804714, 0.1262429165804098, 0.030727315498816393, 0.03286181265608438, 0.019090438013776176, 0.019018908384286107, 0.03685159473529747, 0.01790234864118599, 0.040805899282737125, 0.042144932874268105, 0.04745227893093421, 0.052678147706413464, 0.036204032104222045, 0.028764535034556064, 0.014092243866123741, 0.06357993126936978, 0.043521585213320876, 0.0371521501801908, 0.04643552703782917, 0.03833332369404455, 0.018471142111886895, 0.04593225323685235, 0.04337625067320563, 0.079841714112028, 0.01008950915533088, 0.10390331007299886, 0.04680676558505624, 0.028731351936115857, 0.041236739470473224, 0.006761232507415117, 0.02514286969427861, 0.03429362332568534, 0.09102481282165936, 0.050493077254824104, 0.006608754676210905, 0.043547973111872716, 0.04524497660778223, 0.08279074659390796, 0.012348548268839236, 0.05080689751212636, 0.011211766677367832, 0.09858633812156417, 0.045501547114503, 0.036268452437774795, 0.10240908622020677, 0.05519453969393527, 0.013183419397401233, 0.06623482812316188, 0.08496664314260406, 0.014355769493587077, 0.01651495000377538, 0.026264192589047938, 0.03759417142118177, 0.030145226572189602, 0.05981276284963374, 0.02721118260054819, 0.184826081498496, 1.6247996784025625, 6.761981825674734, 11.732063158865898, 24.544733416649606, 33.85989973621984, 43.9320795766769, 55.38178405454082, 65.46507204732588, 72.21369820256388, 84.42806874552082, 85.65314262144028, 87.80883804444345, 86.36320929373466, 87.1368654312626, 85.15107139464348, 87.83166623884632, 87.33670234680177, 81.52001565502536, 81.77260060464182, 72.24452803211828, 82.8724253562189, 73.6359182480843, 76.11866089605516, 79.51249953239196, 87.97189097250663, 86.55797066227083, 89.59116305074384, 92.4933090517598, 97.19332048969885, 82.58607664415914, 72.26987438817179, 72.05682692989227, 67.95179197865149, 72.8323579603626, 74.4251932636384, 70.68551924920851, 64.68020969821562, 62.13636829007057, 74.701704671306, 72.76493241710048, 83.41700723094326, 64.05002601685064, 62.41078515206615, 46.17523208741219, 43.396797641631096, 31.853879997807166, 16.205999966590635, 5.195456310626, 1.8188434983453445, 0.31960998211176167, 0.11118718978738594, 0.035178845583070675, 0.02413908383929201, 0.006472228710810024, 0.02470727210053273, 0.030950501809016834, 0.06022535099257385, 0.06334946520866887, 0.016896030865609646, 0.0591985748389796, 0.10536081533158019, 0.05688676280119727, 0.0319962328930776, 0.08240259282531277, 0.04891546473147408, 0.041730996416581255, 0.04668532149685968, 0.004050216361534812, 0.06537219779866357, 0.08471750368874881, 0.032394510513592156, 0.033100552466367526, 0.07288656272594968, 0.021738878661586393, 0.036662106717666315, 0.08808054540666842, 0.007022656181136207, 0.03197503140977314, 0.02348652823017009, 0.02774070831947029, 0.04370403671336751, 0.08897538206750348, 0.08318490649182951, 0.019849083393872268, 0.04169267286816913, 0.0405412120744586, 0.01590097937056975, 0.03650217054171428, 0.07575208396320382, 0.022016428486113588, 0.04761648987750373, 0.02603866396501901, 0.04590549761609686, 0.06641799208497809, 0.10404965584917415, 0.01535560999576363, 0.019805540871475975, 0.06299019678525868, 0.06528700882148358, 0.04180253753739019, 0.03708300691458487, 0.012924168540555383, 0.017021832078875556, 0.052549421952496615, 0.06117100992630567, 0.019070688267088225, 0.030511903065827586, 0.035175574387633995, 0.030389030223652243, 0.029296450947801915, 0.09738644524928063, 0.04617261332309535, 0.05500730780524112, 0.009561311641347506, 0.2248565044494406, 0.18287839488156382, 0.10011982398047563, 0.13208465109909737, 0.10634743698662329, 0.15201554693762334, 0.20047241611586464, 0.12318214251389428, 0.1764495688821039, 0.14193793608536645, 0.1304665661507076, 0.1473050867958415, 0.11307707507043116, 0.15865996540073427, 0.18065729148445592, 0.29664407574361373, 0.3567596999627929, 0.14834483664843345, 0.18075116789869725, 0.25237162477306785, 0.10788258525633043, 0.09515419527287446, 0.16887833724819845, 0.116017711228661, 0.18254736828948223, 0.10681747023256556, 0.19229424366306877, 0.12911849655210972, 0.22672451792224763, 0.15525821326000078, 0.1827262498198017, 0.09526393736802763, 0.10238804178492678, 0.12460050067954487, 0.0842436170205474, 0.09712363112597697, 0.11437223097609897, 0.19190945302046117, 0.23580672009096992, 0.14628643500468425, 0.09990443069968494, 0.13566588231873128, 0.15866105324558674, 0.17895987047062767, 0.1755772398844842, 0.08048404053214096, 0.23932824241778544, 0.09559625864870126, 0.13845609711302867, 0.20190633352725737, 0.18638775173214175, 0.16385344397877494, 0.23784976933271657, 0.16043802482947228, 0.32214061567379587, 0.15189983701754003, 0.21998951722296978, 0.15674512863399523, 0.10353377990184293, 0.1132183646663062, 0.15893849964824416, 0.6000049039721489, 2.235051835736921, 8.632252254793721, 16.25826652972929, 31.42733204749323, 42.80752820353354, 54.134058490876235, 64.36502372064899, 77.44380227981075, 83.26372884934949, 98.60827630566013, 97.80042494496992, 101.38174503080307, 101.04081261542537, 99.84493686306863, 98.12239662293466, 99.41693567460584, 99.26375927463656, 93.59717384461435, 94.66012831657164, 84.57260808637066, 98.04804417394824, 86.99063947123867, 88.69953770791331, 91.84820467425932, 99.68922661196802, 97.87337318543466, 103.86608800580426, 106.55963451631608, 111.6898750489758, 100.29491901397706, 83.61718931505757, 80.8431871475712, 80.85274988605131, 84.61595027677475, 87.26162033696329, 84.9272923315725, 79.62689153609738, 75.71126784047773, 87.8991388505505, 84.52425310688635, 93.76794599717664, 76.59739402032669, 73.82041869624969, 55.61982877792851, 51.57623383306688, 37.47309300207323, 19.88326514920881, 6.482368313497113, 2.551659917639148, 0.581764166633929, 0.29040655722060515, 0.2795118063447937, 0.15806310629892736, 0.09566093945214826, 0.07677443595903535, 0.10504042970076685, 0.23695842603281622, 0.1740519435054833, 0.09143773421284654, 0.10261537071557776, 0.16537264229789858, 0.1124712604007894, 0.14847934636617863, 0.2510047553768081, 0.1608427031145942, 0.12987123922474925, 0.10867712568611869, 0.1724400791910387, 0.1386828438168572, 0.1721037359487626, 0.19650426452919362, 0.1765546761453152, 0.1419972772559812, 0.13355088209913624, 0.16936982861689984, 0.18028026897340052, 0.10917175801530962, 0.17958073876798156, 0.08429432438025553, 0.12527567694985098, 0.15796061905641712, 0.23834012689129, 0.23019644371684522, 0.14572444822519057, 0.09549836027285746, 0.15859670185994718, 0.19600457601970245, 0.17995613717263748, 0.2544860580875989, 0.21931166730580792, 0.1355326749504574, 0.14440988731240073, 0.11188688087126902, 0.1392822769740897, 0.1782062238142375, 0.12508694352882524, 0.18492571889392792, 0.12029293383802138, 0.14350190458278503, 0.15707353520537579, 0.1509771607215366, 0.15001994918190664, 0.20563234004282183, 0.16631036456073486, 0.3967098062557559, 0.10500345063666183, 0.10297506431778593, 0.14742341673662587, 0.09764728286573965, 0.1603293935618093, 0.22826476833753048, 0.14324957054228554, 0.12485501040974933, 0.14514887104592017], [0.04949808225876862, 0.029895169728045023, 0.09662385834681411, 0.00942266409120132, 0.09347203473049788, 0.06539360229526797, 0.046286779576011246, 0.02416637955203412, 0.028398986605386582, 0.045580825723347165, 0.07341174664156092, 0.04144550226027927, 0.03427914426391644, 0.03533535734600118, 0.060603564770351497, 0.03440596245890183, 0.01967575983144343, 0.011967340044887557, 0.02836660981448668, 0.028014693919929768, 0.04155522137279472, 0.011923144432535816, 0.026752778569296486, 0.03313929736313801, 0.07033677696580849, 0.04723978146249729, 0.013235269185726442, 0.021686171812395898, 0.025055106661673036, 0.0863789415527736, 0.03766064103993197, 0.03951861110005168, 0.117734307423234, 0.049930163508942055, 0.014849458577021237, 0.029386127284998377, 0.020754066889264414, 0.0208909074295192, 0.04609190212983278, 0.031919899892302296, 0.05027429403496846, 0.10574447216405984, 0.009533666400989939, 0.01383727544077462, 0.04059482290739975, 0.04991886754249854, 0.05233302126608549, 0.03496053350728846, 0.029472222161148826, 0.073498958090861, 0.04055485993082966, 0.0164129568879763, 0.05215050464856529, 0.04232292574259543, 0.045221691365323724, 0.023817721446375215, 0.06232322914706123, 0.08007401495330757, 0.058804545176005175, 1.3501602218997095, 5.075151333885809, 10.844552382346123, 21.217879056930542, 36.29009831336237, 47.301909385188935, 52.72056571898922, 56.21782548965947, 65.2171507958443, 75.09959774632608, 78.67193560446464, 72.64970887091853, 69.50918474505025, 73.13401176083472, 74.03778076171875, 60.929827613215295, 58.20503157954062, 43.894114955779045, 45.324603357622706, 56.69803734748595, 43.233136746191214, 40.21453949712938, 37.09953823397237, 42.11635558835922, 64.3074982397018, 54.78146529966786, 56.37209230853666, 61.82838770651049, 53.81520509719849, 53.5243691936616, 60.51033796802644, 67.24171746161677, 72.4548690549789, 74.38205503648328, 71.02522788509246, 63.61584317299628, 73.76676851703276, 62.185676405506754, 65.7464942624492, 67.46270379712506, 67.62701972838371, 74.03182660379719, 68.18565153306531, 69.16658139997914, 69.11174666497016, 70.71372109074747, 69.71434039454307, 59.36720240500666, 58.24884053199523, 39.4533839533406, 23.569755746472268, 14.164645556480655, 6.855179302154049, 2.3957461935858575, 0.8644840734139566, 0.2057520336201114, 0.06775667710650353, 0.02463265705192762, 0.09748412912050564, 0.04614149483161108, 0.037882936772920435, 0.017563693728598378, 0.010396471968100918, 0.04728632130389733, 0.01703468703424498, 0.008513469027445443, 0.04369054207458131, 0.013899699157674708, 0.006479578366833589, 0.05140188735939803, 0.0076054250107957955, 0.05154948568932953, 0.05709076818499354, 0.061972908630606637, 0.040801827525419575, 0.05968641579872178, 0.036064653897718076, 0.06073895548920959, 0.03987315659140868, 0.026372295256043156, 0.023666070511324272, 0.05442390503782419, 0.048274743265562484, 0.03865759339063399, 0.03797972432127403, 0.06462122478912916, 0.0217949697041824, 0.007770357037624045, 0.06724003507124801, 0.0740684831755296, 0.056612533967821836, 0.017309251031087294, 0.03959838766604662, 0.03252682538943426, 0.04931885215844359, 0.012572412566852667, 0.05237322172991211, 0.056917950240594734, 0.05268868141537232, 0.00557548018179894, 0.06754766533812208, 0.040528238375460914, 0.025855239533308535, 0.06089845499504478, 0.020625919531730395, 0.06566537964728571, 0.056329023979243734, 0.03334871898855894, 0.05638598261641399, 0.043606257081151976, 0.02427909789877313, 0.06356291645657151, 0.04821497308571012, 0.034467663180323384, 0.04818215004859432, 0.027775544252607132, 0.030462266313993645, 0.038363710571561134, 0.05132710951710901, 0.09588952476699507, 0.02617865121142278, 0.06647651354151388, 0.02099103320600285, 0.06379089656195815, 0.026471093785197988, 0.04436972881517103, 0.058279020351267634, 0.07875249796216527, 0.0031302608746749862, 0.05039523633557463, 0.13599585170947737, 0.12107960654482727, 0.043115397734988126, 0.018009487952616428, 0.03938205592754868, 0.0558159748963531, 0.03548891200954395, 0.027154649142175916, 0.029727731636094473, 0.03195028102415944, 0.0733139172136303, 0.014905655914316735, 0.026028444352109107, 0.006890865117912331, 0.022011879839063175, 0.03446924515188702, 0.03994351793681422, 0.012385215152115112, 0.045518221018174966, 0.038572641900710525, 0.06130783706002178, 0.07011982086565226, 0.03941172268241644, 0.040667222046683875, 0.009513969322846783, 0.0270953347846385, 0.018613033086782502, 0.018843886021885182, 0.06270976263969656, 0.021493910556478847, 0.05716552304464483, 0.12910472229123116, 0.016806651387483846, 0.022838519352878776, 0.010659587738524762, 0.08948352052679948, 0.07859777118409834, 0.10553092515516667, 0.06008213851600886, 0.009278828210587944, 0.037281190030156605, 0.03880621061750478, 0.0477483336092724, 0.0482943436251052, 0.08531099966456814, 0.15544841756984112, 2.17615720245146, 6.730898512947944, 15.023928996055359, 26.483700236966534, 44.935880784065496, 56.416238584826075, 60.66039608370874, 62.976245803217736, 75.1967627002347, 84.3733673710977, 89.4787008531632, 81.38360346517256, 79.85610700422718, 82.51909825109666, 83.93422665134554, 72.4879660144929, 70.60493023164811, 53.6816248586101, 54.89933644571612, 66.36955491958126, 52.205503602181714, 50.8559964549157, 51.568451850645005, 52.23138732294883, 73.61046991040631, 68.13007939246394, 69.17177461808728, 73.39222138927829, 59.89045050836379, 61.166868209838874, 71.27389830927696, 76.80331060963293, 83.70285387962096, 86.88424125794442, 84.28108184568345, 79.39881355531755, 85.17157754590436, 73.96225944642099, 78.77247379672143, 81.33017293868527, 82.54711181886735, 86.50533245455834, 78.32213863249748, 78.51093799837174, 80.47238980570148, 82.60175828010806, 81.74498711862873, 73.32530575413858, 67.98584599648753, 49.62986746141988, 31.811047715525476, 18.64459437708701, 9.41845311272529, 3.3271970768128676, 1.1955957931856955, 0.22103679005897817, 0.001930287443458163, 0.025006404537106716, 0.041920465282014305, 0.053438053301145, 0.0719121678341781, 0.012201305212182625, 0.02924625495178325, 0.04757496791200773, 0.041917056190751256, 0.024080587280613762, 0.05048580708042268, 0.03795026824058544, 0.0276866608164123, 0.08416348422366766, 0.04974329934245156, 0.014286245099238813, 0.051882707123314185, 0.007661975706146369, 0.026611646021445914, 0.01593298269360657, 0.01765954664968435, 0.04231780061438199, 0.08673972299983425, 0.04072433007099936, 0.035028642554196625, 0.05396669227329474, 0.10541474792144953, 0.026638189052802422, 0.018945270097784458, 0.06046792890335764, 0.06289519805220828, 0.014334538324375548, 0.03704133939238326, 0.022608825125761574, 0.035617760337528684, 0.009482368195970214, 0.05737469569149037, 0.06527015488714942, 0.03647937176508769, 0.050114817511771, 0.02561613966170098, 0.030266369970875884, 0.010108285970354994, 0.06998128152542538, 0.07407803629194537, 0.03385545167651388, 0.06630297164402663, 0.029478440879874175, 0.05183273137757375, 0.039597529647571426, 0.053413216730639826, 0.01643785474551541, 0.08949291276475115, 0.05533935712470163, 0.021735412113729025, 0.0259388848433211, 0.030460550277043256, 0.02360779420292426, 0.030463195195601835, 0.07963737547998467, 0.03279366147434039, 0.15193683906428276, 0.08472992963488064, 0.19334387604988393, 0.14229680231261638, 0.16694811743593987, 0.13467071878333248, 0.20262579734046615, 0.07569181582620067, 0.1090199500322342, 0.17270137646025227, 0.14187056631330522, 0.092226444713531, 0.14719006635489004, 0.16496897524883672, 0.19679295710257946, 0.10100046503207377, 0.08748194728527339, 0.14531390170656866, 0.15846012370480647, 0.10411465840954935, 0.13871397763009996, 0.14178511686623096, 0.20523443397495056, 0.11613189663377502, 0.1436311129720942, 0.32709490628011767, 0.12167431293956696, 0.11000377546635368, 0.13391351747897365, 0.21876759166198395, 0.09536473155622521, 0.16453336233333235, 0.28526874259114265, 0.18480316014780154, 0.18549159740007695, 0.10265050350778526, 0.22556099890460893, 0.12606709174090816, 0.17860782242590384, 0.10535918356430148, 0.15411985256979543, 0.17520905802807502, 0.11277973336438019, 0.1981013586684581, 0.21548922564233505, 0.10898700825149014, 0.10697086401764425, 0.09919759967634756, 0.16342708540539588, 0.18796650572649895, 0.18092919141054156, 0.12469673664459299, 0.15844408182367203, 0.21268820900830532, 0.1136463396852055, 0.08156188793720738, 0.15471769226414545, 0.14947011255689208, 0.33153021828301493, 2.8715426883389874, 9.511332877220648, 19.11462180076107, 33.66459315822971, 54.00295719023674, 69.2772549967612, 73.71586399693643, 77.23929774376654, 86.62658860606533, 98.097183627467, 100.92470261358447, 94.96805006457915, 89.38812548114409, 93.39268499805083, 95.01555781210624, 82.92366720015004, 79.22824536600422, 64.15252147182342, 65.0041151046753, 78.61106826413062, 64.22675624970468, 63.5890337728685, 57.68958899282641, 61.77385499400478, 85.03124298587923, 73.35730445000434, 76.6276825627973, 82.80408197833647, 74.27005567858296, 75.12605805550852, 83.9782670236403, 89.69345846483785, 97.53712408004269, 101.56808114820912, 98.59348112537016, 92.34873048720821, 99.94260388035929, 87.98270102470153, 92.58729688582882, 96.86898754489039, 98.31776988121771, 98.79337295409172, 91.56649220374324, 90.7396879503804, 92.42487153699322, 93.45905934610676, 94.27601845033708, 88.35302768215057, 81.49135097380608, 59.692496330507346, 39.99620076148741, 23.96861960811, 13.042088708569928, 4.571324846436901, 1.9961940785569532, 0.5156743742765919, 0.1375260357294352, 0.27007663682583843, 0.17995808303596514, 0.2475851533874389, 0.1328103202244928, 0.17560242885543456, 0.08545774380646406, 0.13951924329082813, 0.148246287097854, 0.10180473477850038, 0.27975557552229974, 0.07885791166054626, 0.08193507234776214, 0.17359428257951814, 0.07695190022669493, 0.07652698189861352, 0.14332757361473578, 0.19573223176262072, 0.10989327494415546, 0.13843824726439294, 0.1648905278453904, 0.13945959568504365, 0.15224990855541923, 0.08235480426059616, 0.14078036191002016, 0.18406298131712023, 0.20532769751885246, 0.0830915510173767, 0.08023264877978833, 0.1339985225950518, 0.15214139986182415, 0.06432283354262192, 0.13087420153521723, 0.1730837002997437, 0.14962800327808629, 0.0993290986685503, 0.22077331710005962, 0.12192902185263173, 0.08582291493733084, 0.172943368313774, 0.13560790478462173, 0.17147355202224948, 0.14017385010036731, 0.09831984677622396, 0.16236409244518127, 0.12250342691737799, 0.17227944587507557, 0.14019818105284246, 0.13238259801460853, 0.19551291611165772, 0.15228864196087086, 0.09660059225655372, 0.14537506616644322, 0.09519702724872098, 0.1051225160218535, 0.08316802957485761, 0.16885621262894523, 0.1154328643855068, 0.19077997895017748, 0.17079151926502106, 0.13822516756913356], [0.07537297003211514, 0.0601652245818367, 0.03307070568083756, 0.010737911610293293, 0.010308654351730742, 0.06352589525763067, 0.08229770772759953, 0.025547624588192954, 0.00225931610217348, 0.04334966742223309, 0.06049340132683997, 0.0097140102016349, 0.04266099651314078, 0.028177539314774257, 0.046219969048134746, 0.049854259517404347, 0.02487164201034654, 0.05482886294503847, 0.04720560244975552, 0.024256812401055813, 0.03810854200574179, 0.07731114183702777, 0.06703681492757413, 0.043265344124407544, 0.033639296138238524, 0.02917999217677261, 0.09169391401472593, 0.04437393463787533, 0.03448350970903712, 0.0510933148043771, 0.04557565462985828, 0.040513548639512835, 0.11748346725418685, 0.003012472701694576, 0.048894830153233586, 0.05904901532396194, 0.02344721451311583, 0.054302579693255894, 0.030937022491989118, 0.013896118654238602, 0.028877402768440308, 0.016325988671592167, 0.01408141042526451, 0.05686081157276227, 0.04032834305337841, 0.040919295617289124, 0.02128551548887645, 0.019918492875031887, 0.04422015780883451, 0.03086046349527615, 0.04096487784878381, 0.03501376895714672, 0.12715217867685905, 0.13579787926808481, 0.061195643483510906, 0.07403848317241477, 0.038393162821810094, 1.5210118024579942, 6.462128883407963, 14.924605757959428, 26.440934634977772, 29.439404241500366, 44.66709252326719, 50.68555378144788, 58.044645863194624, 63.35478590380762, 64.80421935358356, 69.31185030168103, 62.39396602876725, 60.44819193501627, 60.434683292142815, 68.98522669269194, 45.892076184672696, 44.027251966537975, 42.4193351499496, 54.698134545357, 51.48319913494972, 29.83327296472365, 39.00176225170013, 40.98731310136857, 30.262699934744067, 24.011036119153424, 40.03067055056172, 33.29783585763747, 19.91941959627213, 21.31042738114634, 28.111887862605435, 29.668878586061542, 36.706752084916644, 49.111663526104344, 52.630484565611816, 58.227204738124726, 51.8051080549917, 63.87634738799065, 50.68656575295233, 60.9790062904358, 55.58196221628497, 63.5538108887211, 59.51693888633483, 53.3231359143411, 53.27789137440344, 59.48851739206622, 53.2220015218181, 50.286797784989886, 58.55208289238715, 55.71773898216986, 60.46113183421474, 61.7053625660558, 63.3688711350964, 57.700991322917325, 38.486947244213475, 36.30299114411877, 24.863684869581654, 10.038864208805947, 3.6254251772357575, 1.2515655640632877, 0.41208755044687184, 0.31881040082343165, 0.1294404833066848, 0.009410770576176865, 0.030417247157123302, 0.03971545739219554, 0.024495829918211507, 0.0432922184887913, 0.026810800153461677, 0.022531628360851638, 0.019692569715721954, 0.028050504699950258, 0.035806417149761995, 0.01253534444502645, 0.02565432722950655, 0.012443885995796131, 0.023374225486130006, 0.09214909281581642, 0.08738479967559538, 0.03991452916975945, 0.015101847201285344, 0.07332953774640638, 0.017817247764117295, 0.041651859534003084, 0.05191696657528801, 0.025863681822234107, 0.021953456058737733, 0.051053696567372936, 0.08597788686353354, 0.0411163755662499, 0.008293844068483, 0.03598354050829526, 0.03400473156943917, 0.07568702011579469, 0.05105930050053904, 0.04646808577461108, 0.0629007675114178, 0.0360838252480232, 0.03368208214880959, 0.0243892326139875, 0.07031747921099586, 0.06931036470397826, 0.022422667675381227, 0.054589441316502715, 0.07364518129296842, 0.014698935706438798, 0.01938445489823578, 0.05530644215703492, 0.051988959687972264, 0.08950306342974787, 0.017716076277617007, 0.06815686611638916, 0.023213607491925362, 0.10770416337876551, 0.06792541563270554, 0.01963479327969253, 0.04730676819059638, 0.08391910217582219, 0.038022399249096075, 0.036469060221626874, 0.021884948646108952, 0.03804238648304055, 0.03653765573436695, 0.056256931275129325, 0.022838787483652274, 0.036865035747928966, 0.06688047936486621, 0.0037633334314675945, 0.05093220268346129, 0.011199964135284386, 0.08250173992447316, 0.04724373064574696, 0.05696446709935704, 0.05547742149041546, 0.12197521695446585, 0.030055908381097743, 0.03539705806742272, 0.011512989576365198, 0.0326566428186432, 0.06955846993913574, 0.007204524017945533, 0.05111476909669657, 0.0405226880684495, 0.0245577891943075, 0.026312806613502965, 0.10657385427264437, 0.052205774061862505, 0.044115613620247573, 0.052469706673535614, 0.03810892504970393, 0.03552784076741627, 0.028549854215534947, 0.13610558614375132, 0.025675699167374163, 0.028138687165694374, 0.033648113810246995, 0.059720713555091814, 0.0028008981298039397, 0.04372031608175847, 0.03204687896575178, 0.08496017736052314, 0.017187295579201272, 0.07660608813767472, 0.04579076062767737, 0.044015945581298684, 0.06095491567506425, 0.033731433532891736, 0.026334733965115684, 0.055074286872460965, 0.01294176079212658, 0.08875024414831593, 0.09020620190929021, 0.02333354238691109, 0.03650178366731252, 0.0239635098935856, 0.10152163464696178, 0.3044117169995462, 2.443891081117815, 9.60262800416639, 19.308514364304084, 33.96712556962044, 42.44287329335367, 57.1837366011835, 61.090119192677165, 71.83137693712789, 75.39118674493606, 77.6427213607296, 78.96071618603122, 75.99385107717207, 70.42647023354807, 71.52329044957315, 78.23390099310106, 57.45592947929137, 55.52487996316726, 53.77442029214675, 62.08026270712576, 66.38897849667457, 41.897361816898474, 48.63171054470924, 49.91221927827405, 38.07730274815714, 27.527650825438965, 52.29915019004576, 50.929737014155236, 32.840244308594734, 33.9435129011831, 39.24705551516625, 42.19110419673305, 50.27404615955968, 63.526852438526774, 60.64710317119476, 69.13648113127678, 62.11442262895646, 73.10846928627261, 59.64665559030349, 73.26787441007554, 66.23718277100595, 75.10550483580559, 70.87371457007625, 62.35956291998587, 61.42343828755041, 73.25429516453897, 65.29704947625437, 61.664358108274406, 67.51089403706213, 66.06365711458268, 69.77773374126804, 70.34872101199242, 74.63059994482225, 68.1519897522465, 49.63255820735809, 45.8783753456608, 30.88865726224838, 15.354596568692116, 5.973300558905448, 2.25579553554135, 0.8364089734611974, 0.5713846558524717, 0.1965344024281348, 0.011293439310975375, 0.08196764640630254, 0.04774175674444245, 0.08015639238780545, 0.007837568804050886, 0.011556347280049757, 0.116481140796696, 0.037931479934242465, 0.10133910653812271, 0.020385161079766772, 0.07623706358454882, 0.046475919023636854, 0.02302604618542377, 0.022001629582636302, 0.0348085378326716, 0.10375682640099719, 0.05489907873373839, 0.029988257071724343, 0.05855945449682975, 0.021388278523039435, 0.08303705918332262, 0.09419690712445206, 0.0638603309409753, 0.017783530319349903, 0.038333940394823594, 0.041041881176492864, 0.005139963027285112, 0.035741782311590455, 0.0681937609108225, 0.1002279879345048, 0.06728331903896986, 0.03235495739406155, 0.013562643453629028, 0.015651259605111857, 0.03826460943767621, 0.04419314554862438, 0.03755816911918022, 0.022181587466489405, 0.07632170863930257, 0.046090335480027625, 0.06591680204315532, 0.07331449177957351, 0.03511043393143243, 0.0880939979106188, 0.018527928379274184, 0.01441387534742394, 0.1393164751390296, 0.031445400353761456, 0.06313379230578581, 0.03758604705874478, 0.10661034304047785, 0.11376954194518829, 0.008042095127635667, 0.05284073071614389, 0.05631996881997874, 0.04199679062191037, 0.06541304560678621, 0.18210083096017762, 0.1367798814129445, 0.08049340212657567, 0.1430536971818055, 0.08533041999344865, 0.11958770393844574, 0.20842102266127066, 0.12737537839359817, 0.14653129202704276, 0.14892890208190487, 0.20008103711710823, 0.12120848551632897, 0.14480512739429552, 0.1280542318859408, 0.27103504346263024, 0.14384175650775433, 0.11110161010536457, 0.18995615863992324, 0.1679752115160227, 0.11441477949941352, 0.09724054380410141, 0.21282610483467582, 0.13772198569870767, 0.13692068837342725, 0.13296456436716741, 0.16233899540478186, 0.24512876906702596, 0.161646788999919, 0.1269412363669084, 0.2188520605165151, 0.12032710902032354, 0.09774997695198945, 0.19415908553186925, 0.09690751772253745, 0.23335969736499174, 0.10260800094974619, 0.07717477818650585, 0.15516018464920983, 0.2101402465374239, 0.09795679770890744, 0.1659438527760006, 0.08162807793386521, 0.239494284314494, 0.1977530797763217, 0.16502226432484968, 0.15643919908231305, 0.09705207851384917, 0.24015495854039348, 0.17662615214865054, 0.12367187188036981, 0.16785289791803207, 0.18103246006273455, 0.2284306570166542, 0.2109003742976535, 0.2647574738629403, 0.24300195577163852, 0.6495830500798842, 3.703855420312574, 13.022422925118478, 25.606281718900128, 42.63973705230221, 56.09394135013704, 73.07766299093925, 77.49494998685776, 86.68365909207253, 90.82344624304002, 89.31855832376789, 90.98232576923986, 84.7059686722294, 80.64221274468207, 79.44021025011617, 88.26861043130198, 65.93182625309115, 62.902618992713194, 63.87668471182547, 71.11744280784362, 71.11108856816446, 48.757465654803866, 57.53266280697238, 57.486731852254565, 46.851534997263265, 37.76406226619598, 60.832305723621005, 51.07016178869432, 33.17973721411921, 37.74360710574735, 47.46679798249276, 46.886691201117735, 57.6790770407646, 70.99738690160936, 73.27675465614566, 80.05357480818226, 74.07453337023335, 85.23905015760853, 71.90541559650053, 85.12643890996134, 78.00842746611565, 88.02275626890122, 81.34183022283739, 74.71315799220916, 76.11088675837364, 81.61086559295654, 75.80577342740952, 73.42982122975012, 81.07060617016208, 77.49466757620536, 80.1227105048395, 81.92787155028313, 85.94382163017028, 79.05779484779605, 58.97374945302164, 52.86486187288838, 37.01177912373697, 19.023042301977835, 8.302847685352448, 3.3171653699490333, 1.2444793120507271, 0.821111484641029, 0.3844916231689915, 0.19489707335108714, 0.14133591355094988, 0.11975674889981748, 0.20749014922447745, 0.1317043037664506, 0.14015675101789737, 0.15873868859583334, 0.08966718244576648, 0.15841045056379613, 0.2199021065908094, 0.14875556702815718, 0.12303629469486976, 0.12137857235727773, 0.11957442763471797, 0.20457941347793226, 0.16558454221775457, 0.2056778303437656, 0.16651756070073576, 0.16834419010387314, 0.19783643014248342, 0.21611551784219282, 0.10845977122024184, 0.1614216817242484, 0.13829492753551853, 0.15063116477141458, 0.2356124401933724, 0.096202356770875, 0.17657336869066761, 0.1501158327465096, 0.15803152815468852, 0.14445865646966044, 0.14216115878474328, 0.1066645820655169, 0.1699369635072447, 0.15933672747304364, 0.16274664611104997, 0.1478958018724957, 0.1282357104543236, 0.1434658371633099, 0.165975890572994, 0.1521427175330539, 0.12176405247901717, 0.16830872023297896, 0.1649274686050992, 0.16943827091205507, 0.1613848328950905, 0.333463670986314, 0.12594791144252787, 0.16812801541339967, 0.07553475247996469, 0.23814940164166115, 0.1741958914264556, 0.15385916817092127, 0.23590137791489404, 0.18097383901476863, 0.11409655423654665, 0.17377602927867444], [0.025430091378849842, 0.05191826509431966, 0.059400266637244535, 0.039252564085707556, 0.07076901143356677, 0.045909684286603046, 0.019330413140837225, 0.043135522864758975, 0.03552282289151223, 0.014482163467384396, 0.08141263102691981, 0.06680688895885983, 0.03901107785021586, 0.03289767323181995, 0.027541958298834584, 0.06904432535051339, 0.04467379294275757, 0.06251066404905531, 0.026794867439856453, 0.05709263743952878, 0.012642653253410133, 0.08961556344142846, 0.05074657191852889, 0.03684460801342803, 0.04083928922491689, 0.018503898116309318, 0.019250335885332, 0.044026165194208586, 0.043056378321301554, 0.019432456052351384, 0.04361372643841371, 0.02930861259359987, 0.06632853599805986, 0.06684464177176838, 0.06473649803909563, 0.07826774816719756, 0.0193983287505445, 0.04015878481309741, 0.05098673282191158, 0.022427218237651453, 0.06221904885023833, 0.03937387027807775, 0.03304061374717182, 0.018750563106169144, 0.06341092078195465, 0.036240133997653766, 0.028065382127439784, 0.027272293434268045, 0.044049561519416115, 0.026103245177035852, 0.0204798246493503, 0.0786797502528756, 0.01497603066626095, 0.19649654236291686, 1.874444321278603, 4.146961166012672, 9.296847870272975, 22.24404169667152, 39.628839415888635, 47.75562563250142, 51.79452157789662, 56.192573270490094, 66.36440876991519, 55.10574333129391, 54.524197040065644, 53.01096231706681, 61.79033287109868, 50.945175463153475, 48.820655038279874, 52.072841198213645, 36.60749258533601, 23.45260435535062, 28.924765740671468, 22.931329204190163, 24.571699711584277, 28.401764746635195, 19.314633261772897, 23.708982236923713, 36.10402891712804, 23.405067190047234, 25.386556425402244, 38.136569761460834, 22.19120737045042, 19.06873595330023, 18.456761875460227, 21.874980003603046, 19.862368722115797, 21.56580701951058, 19.907458328431655, 24.918956948864846, 31.295828703911077, 32.64421209212273, 32.572611185812185, 31.840671416251894, 33.686146582326586, 38.163363472107925, 39.84902951025194, 34.41122416527041, 43.80581455845987, 40.78549538889239, 36.34829451960903, 37.64633624784408, 38.77651622218471, 43.579074105908795, 52.22329939565351, 45.857849582549065, 57.03184281626056, 60.43034515073223, 62.90043423252722, 60.392360917983524, 64.13405103068199, 59.98232418490995, 52.36030778577251, 41.341193260685095, 28.454387264866984, 16.496769189834595, 8.36243143004756, 3.3392546878707026, 2.177321901244502, 0.42036341443177194, 0.062281833586072734, 0.058435604892550945, 0.07878016139711104, 0.04479451307786569, 0.04369447210563287, 0.040755525171276064, 0.040605184246575644, 0.01843616636770387, 0.026952526419453567, 0.055743242508821914, 0.0032459087895169375, 0.014115165216818213, 0.009461688610064167, 0.03468935753429129, 0.0908762377296244, 0.033701674847473065, 0.06388362001387343, 0.04398670783566852, 0.05308896235580887, 0.017275139051038894, 0.07380493360781863, 0.08638710038916719, 0.12250514295432838, 0.02215829456315166, 0.06659219281808024, 0.007902610147627252, 0.03187048147552677, 0.02639295090170157, 0.04755138772569838, 0.061151038014119675, 0.08904859709042696, 0.03273084609498901, 0.04086614826754217, 0.04564805759958202, 0.07484910378773367, 0.022716429835606008, 0.021938383278827515, 0.03615712071017873, 0.08573040982047397, 0.03493759300439589, 0.013086386700911869, 0.027166661400828632, 0.014842526438916403, 0.04709163154926031, 0.05001247582596637, 0.06847976451559414, 0.05151179416345493, 0.06871094686850425, 0.03523425672263388, 0.03546955296769738, 0.06079435513745393, 0.04317347869096745, 0.03745938208134424, 0.02488524198622233, 0.05089191028908376, 0.06676444002697546, 0.041733627928601164, 0.02328734728507698, 0.03772162929958394, 0.043406836733582525, 0.053867372804351395, 0.0509850014632027, 0.01241477561228338, 0.026992068047665303, 0.021941376767391642, 0.055388792778455445, 0.082991668473809, 0.02838165769653936, 0.04803812934926922, 0.06647125051747407, 0.010477419691010108, 0.04723232742699404, 0.009489547397430626, 0.010688142708292412, 0.07455312571818791, 0.07430974724552325, 0.025614762618657083, 0.04685092672345139, 0.08440830294162997, 0.029786381412357576, 0.06719169492322592, 0.04573192124465301, 0.04130640750630729, 0.03776533844610376, 0.017886368047085502, 0.04355100682005287, 0.053676881211539434, 0.04398426018475045, 0.011731174290029994, 0.09527250223102109, 0.022829527395867535, 0.07014897051117114, 0.005090988941505672, 0.07288965006028453, 0.05153650815989222, 0.0350019175769581, 0.013975933524629763, 0.006904193611379954, 0.05657876098167993, 0.005839256703057477, 0.039273022463725465, 0.06654083428363647, 0.03884115571817083, 0.09818667005146704, 0.05540798711139829, 0.07478273759085326, 0.012066889340208184, 0.01916561996744525, 0.03957826253627578, 0.25073483195756713, 2.667113412772456, 5.5733305888791245, 11.35217180175166, 27.49497748190357, 46.90651093759845, 55.64400234530049, 61.3424099645307, 66.05651055612873, 76.91424308284637, 69.09910878827496, 68.29427765261742, 64.71100030406829, 71.30286109062934, 62.12299300778297, 58.7108172908906, 65.34195276998705, 45.15488632263676, 34.681157758159024, 42.30527654770882, 35.18690032343711, 38.0927372747852, 42.59388062261766, 32.58974213753977, 33.78063647977768, 44.53975277562296, 38.07029739502938, 40.20278415372295, 46.289573100305375, 35.303983073080744, 31.07257327725811, 27.125666718329153, 31.0772781602798, 31.443970741764193, 31.826382221714145, 35.012115586188536, 37.02846096407983, 44.83552302083662, 45.32098300995366, 40.32196537140877, 46.91098243959489, 44.93286448140299, 46.89506153906546, 53.34012762192757, 45.96578536495086, 54.267340629331535, 55.34918523603871, 48.50661831517374, 48.0985035434846, 48.67091855695171, 54.331396856615626, 60.95433458205193, 56.13764832096716, 65.54606506901403, 68.64700855747347, 71.33007449488487, 68.48060592528313, 75.6652976620582, 69.63681082571708, 61.96139135668355, 51.544666597920084, 37.29582540450558, 23.048627684193274, 12.198105454444887, 4.911182532387396, 3.039142869172558, 0.6960364154750301, 0.032981019767542044, 0.059278883836081916, 0.013051180172741655, 0.03419137357043163, 0.02498185908001277, 0.018558213750140804, 0.004827398675373726, 0.01074418778561296, 0.033344934514213, 0.0894374939643087, 0.025877875516251213, 0.023496345646919745, 0.016813178456598715, 0.04451292213953791, 0.07172721122661907, 0.061367300804704435, 0.0315287200764062, 0.033107949045276454, 0.043308486365863395, 0.07298131248042469, 0.02402464562516299, 0.057062556997181914, 0.02108854853788451, 0.02665162048933487, 0.03291117170104577, 0.07526977798871456, 0.05567198101010534, 0.009441506981308903, 0.01689516518625521, 0.05182507049833095, 0.04914562052656566, 0.04412005309976878, 0.04625250480227894, 0.05936082460046296, 0.010682843295076202, 0.024367485293036988, 0.07833152498689391, 0.05712371379617722, 0.02763569490202973, 0.058086046633581, 0.04407354007144609, 0.03681377297447574, 0.025374314432302793, 0.060205076475657766, 0.03209959922148095, 0.043924218043684966, 0.03829463242342876, 0.05448731030487726, 0.059386116993283077, 0.0030166150827426468, 0.04265331648169987, 0.0789527380238137, 0.10730064188640927, 0.07343086819615095, 0.05762104275486162, 0.026512715342124144, 0.1606026264808832, 0.26462840336945753, 0.17113491051620053, 0.20105142536903584, 0.22676703580204519, 0.21537368426159506, 0.2078695772516151, 0.10048458908474255, 0.1449180181108175, 0.09990726522500477, 0.248747707134293, 0.12616834558186032, 0.21545799989854136, 0.2003015785087501, 0.12477509977836763, 0.1919023743680408, 0.13886112779859575, 0.15252928549964584, 0.2272581900920599, 0.2928869660583235, 0.11300151581845938, 0.2441355820384718, 0.1584402820275676, 0.11670209587581697, 0.16055163566864308, 0.0777188461694506, 0.19941896861118658, 0.15384824375712103, 0.1456298670100589, 0.16226113022815797, 0.2007652608858001, 0.2226201865461565, 0.1554798424964951, 0.1462008936270591, 0.1519659963706809, 0.18501968723872017, 0.04550539287588289, 0.19418015294978697, 0.15895812682086424, 0.21397064019355083, 0.10464821566617298, 0.09286350044872492, 0.2123418759794966, 0.1422819095633684, 0.13252034062339416, 0.20095102188567962, 0.10132867242059401, 0.25542142079962843, 0.12651238800777545, 0.10674100699684314, 0.09693302078953675, 0.16489900077783293, 0.13994065293621633, 0.4067077133203707, 3.6670680007626935, 7.577362666206976, 16.659363200587613, 33.84327673142956, 55.4379641625189, 66.67804148889357, 73.55652163105627, 78.10460398274084, 87.88320618291056, 79.45629981256302, 77.36887716477918, 73.04920227296891, 81.57234007312407, 72.49189622940557, 67.66580412464758, 72.41387244193785, 53.937543822873025, 41.526999858117875, 46.097294592088275, 38.50209151544879, 39.73484146979548, 43.626138625606416, 33.655967866220784, 35.049001555288996, 52.41285185660086, 38.087955905545144, 40.946983291256814, 54.49063331850114, 36.13312898143646, 31.087531235910234, 28.646665773084088, 34.49001281492172, 34.02840083645236, 34.72512752779069, 34.77394534695533, 41.618995128139375, 47.90587594432216, 50.675167345231586, 49.85658045737974, 51.688131209342714, 51.28424475269934, 55.67008218457622, 60.52700019651844, 52.61716027413645, 64.24589741614558, 61.315039665468284, 55.711741678176395, 55.32963222072971, 54.52960598853327, 61.44107326384514, 71.12605633274202, 64.65690297465171, 79.69368950013192, 79.26324859742196, 82.94775055300805, 80.00646714241275, 86.86206417699015, 79.46454463466522, 71.48861669724988, 61.02004212717856, 46.769914396347545, 27.989706031737793, 16.156333934876226, 6.863171621676415, 3.9646158151088224, 1.1037875711917877, 0.1988337540458287, 0.17481518158268544, 0.13575431950871023, 0.1859391612872001, 0.09754541615444808, 0.16238990960822952, 0.07064669783557616, 0.1832047636590658, 0.13047842519177547, 0.19833150680267042, 0.12338769156485797, 0.11190998608306532, 0.15947292258422222, 0.28300274644167195, 0.17919308295653713, 0.13112013108066975, 0.09669670564753395, 0.1312451872734293, 0.11143442168230973, 0.17629351677192798, 0.1501379880092798, 0.182683348896042, 0.2590921617323353, 0.15257566446258178, 0.2225180823476084, 0.14729374869456216, 0.10489117279047928, 0.1695588378295783, 0.1354821131474549, 0.12864384379598404, 0.2461521552815553, 0.14391520901793434, 0.14518564326628564, 0.099715911783278, 0.13835121967619465, 0.05947412900446404, 0.11345304804103029, 0.12245481097770315, 0.17498099365301673, 0.12569160140570135, 0.13837741988320507, 0.0838313544649751, 0.1600309563500266, 0.17184087586018348, 0.1349246156431975, 0.2533331876921077, 0.12141594978710338, 0.19680703779862774, 0.14838743113702343, 0.1080461067237681, 0.15577832567355326, 0.11813389122365944, 0.2332394215608797, 0.15428944911447265, 0.19754252817121246, 0.17990703093669108], [0.01853137769015326, 0.03787200852868058, 0.051200727992240465, 0.014516071476522955, 0.010261576333563897, 0.07480718345651705, 0.03756870282813907, 0.07184747170897261, 0.045945889601904544, 0.026703431015653957, 0.04265912342816592, 0.052986130373732704, 0.05295729099382317, 0.020428847243648865, 0.0811478020923753, 0.0491677298240604, 0.07017950677583296, 0.014650339876571971, 0.040911531316176544, 0.0907633393522232, 0.06666572193705267, 0.05154960826339741, 0.05147568460914397, 0.06176406157112891, 0.03112333507517413, 0.01948046869778585, 0.05744925136828134, 0.032530567728944366, 0.05346490851333065, 0.04919404111381981, 0.005838659154476539, 0.07522216562422053, 0.01690007772506966, 0.03303682161194663, 0.0990421527756318, 0.09306397799762989, 0.04467799110458263, 0.012555843042660386, 0.020874850226626284, 0.08815349229881841, 0.04501236167045371, 0.05785409053186736, 0.09354657508553037, 0.009092735877681163, 0.04337735767025621, 0.0566834009312574, 0.09271207550961165, 0.016268101152813724, 0.015373832354652546, 0.07447787290138584, 0.06473871969407605, 0.18577327260807638, 0.9742530735750353, 10.63180204360716, 14.910362651271207, 26.74530075442407, 36.14954017823742, 43.658160855693204, 58.25797965449672, 62.54385156016197, 66.81204534346058, 67.61489175981092, 71.23665932686099, 68.51537381449054, 54.71127448543426, 49.73707760533979, 47.03626294289866, 45.299825745244185, 41.23901551769626, 29.60000372702076, 36.44048198576897, 20.064466884059293, 11.24329366991597, 20.04371362347757, 12.794159612348004, 18.26758792323451, 32.26085924333142, 26.801778962535245, 29.169727563858036, 21.998262059304025, 17.107388088780066, 22.216985187222882, 26.93683008993826, 31.811314436697195, 29.742260248430316, 27.839220377706713, 23.874212080432525, 26.6975910048331, 22.775069821265436, 23.007003491924657, 16.151456467566952, 20.146638577984227, 22.377814131398356, 10.08168766575475, 22.942276539341098, 18.810751861141576, 25.219900800335793, 26.202230953401138, 23.43217076793794, 31.754673450223862, 21.45007552639131, 34.78277067984305, 40.109361140958725, 25.592920164908133, 38.05833416600382, 34.88602315225909, 39.9563887042384, 57.19685692940989, 51.98838080129316, 55.67878592398859, 61.148633110907774, 62.494064915564756, 65.68989838323286, 59.8845551859948, 55.09313683356009, 49.09303619015602, 44.8325224076548, 21.034465105302875, 13.697172576381316, 9.066337039393764, 1.987271912155613, 0.14998924437790148, 0.08030075399625687, 0.0467864451028647, 0.032852110152523366, 0.0187935080799845, 0.06286049043879875, 0.06814589573731346, 0.08982183261504097, 0.06220222938986075, 0.022475725009797082, 0.09207199372711683, 0.013104773768704506, 0.025548089986606955, 0.06375786285066316, 0.05571487044254619, 0.062010381821422815, 0.023819981405751842, 0.040534524126879634, 0.03515056927778548, 0.01902519605092464, 0.03821740309978205, 0.028658043067421646, 0.05480382719167298, 0.055607001432367874, 0.02754189509658083, 0.06344541389074537, 0.093482545456819, 0.0593951951351858, 0.011563383797634275, 0.04172726173795039, 0.12017382248755425, 0.030667095242308515, 0.03828307598709099, 0.00996382381286352, 0.033267253198690956, 0.039674896867044514, 0.00500587992475278, 0.0415002009380729, 0.03761754859419119, 0.01877123407358604, 0.04168968895570405, 0.03807990946957181, 0.0684785234531568, 0.05410266138853566, 0.024373918516381134, 0.09470018858630812, 0.034253836549337835, 0.034561451494453416, 0.028898726825812654, 0.04210632204288437, 0.047433260798213944, 0.031204910032571326, 0.03608111712721086, 0.024910155165519927, 0.03638632272580459, 0.05501956521202961, 0.012474650171615425, 0.06563681988946854, 0.10561434446924156, 0.08965706242428673, 0.04458900233129821, 0.02896946163908128, 0.07316791617702093, 0.06102046215786569, 0.02933850342918548, 0.016234992747946132, 0.0359668129784686, 0.04168672419543709, 0.01685290969157171, 0.02129905992337773, 0.029480635721777237, 0.04986703403354172, 0.050911119943785096, 0.02265047349576508, 0.05665652273643402, 0.022866021909360445, 0.01460916169303199, 0.028296028218802907, 0.03295898324840012, 0.007198118086483691, 0.024314866543957786, 0.025875510219784997, 0.04954491321357989, 0.03720124875525794, 0.043065134706276084, 0.02548009776810725, 0.047578281242280245, 0.022267617225166292, 0.03542324295267463, 0.0815649139845083, 0.08210655346873307, 0.061354606727799105, 0.02260696161688576, 0.014083969158931606, 0.05065271082604605, 0.056153907771072084, 0.045491821628304265, 0.04260249037836348, 0.05132222570659173, 0.02970122690913418, 0.027219668939529408, 0.02282878429058098, 0.04954943696277277, 0.06315021723088238, 0.06781748150505366, 0.09335142184769915, 0.23023908417071068, 1.9275880244470414, 14.177963964400755, 20.769524689643614, 35.43087959289551, 46.95412066675002, 55.684041900019494, 70.3917964812248, 73.14021695044734, 76.81223792414512, 79.64609546046104, 79.85888404230919, 78.8289951509045, 63.89898338625508, 56.190235537867395, 57.86769597761093, 53.07074708323325, 50.087572759197606, 46.07755330301101, 41.872423387342884, 24.185556096415368, 16.783716063345633, 25.97119550551138, 18.699733095784342, 23.334966590327603, 28.754838858881307, 23.900031082091793, 39.238065442731305, 30.658727922747214, 27.109892906681186, 35.05055089150706, 30.13871381359716, 35.33330279011881, 32.956570040795114, 34.08453387598838, 31.50048621239201, 32.762828488503736, 30.171793122445386, 32.94257894639046, 23.448364273194347, 35.68420979284471, 37.422733691430864, 20.7176846842612, 33.69740378472113, 32.8955909129112, 37.47344993775891, 39.9992758997025, 37.69643668205508, 38.735260732712284, 30.325130339591738, 48.903228775147475, 50.77110067490609, 32.63196449125967, 45.525620906583725, 39.50739891298356, 46.41583419615223, 64.96608380348452, 60.169201589399776, 64.95743889962473, 70.80249217248732, 72.528531166815, 74.36645184793781, 70.42476792489329, 67.55301244797246, 61.76059738282235, 57.50781066956059, 30.51719115626428, 19.11758319024117, 11.818562207683442, 3.619105258295613, 1.2335249901779237, 0.14363262982618424, 0.06903698622819877, 0.01158969029934416, 0.01000730696344568, 0.0935115035803568, 0.03163342705867704, 0.038329680945964596, 0.020735826335787293, 0.056220469320373195, 0.07255524502045686, 0.02475749490962875, 0.056707728053292925, 0.053028579305617086, 0.054680425748829885, 0.01518914579308682, 0.03903661539117175, 0.08027156604634178, 0.03087512833336669, 0.053837614118932724, 0.016101266355103543, 0.05644554978296642, 0.05810816359195498, 0.015069028952219074, 0.024072051145917466, 0.11626091350110308, 0.0404697475624421, 0.03453187283969695, 0.0193880018853252, 0.04654279849942654, 0.10479850679515831, 0.025398396406202547, 0.01764905316034152, 0.03727679268547124, 0.034166529339047215, 0.011790113264484512, 0.12415265333988976, 0.04989054527193789, 0.020366047186055974, 0.02204393678825469, 0.007747106269122132, 0.14975215548709517, 0.012468916003502185, 0.027340360346340367, 0.03871757424466553, 0.017125684873110825, 0.056013778798402324, 0.015769878744087633, 0.045533650028969974, 0.015701740968882317, 0.030134522408667593, 0.030775500514033823, 0.048520098245071794, 0.034598181579983046, 0.026871926308940017, 0.20414364734484305, 0.23741648532450202, 0.2177916262899676, 0.13762458528001464, 0.25436418882060435, 0.21400031843973746, 0.10038418560138634, 0.2178093995298109, 0.13024282251154223, 0.1406159287979526, 0.18084496770414615, 0.24196513237491732, 0.12929167838827257, 0.12801056487425683, 0.1758847475772904, 0.1787060195760381, 0.24807759470516638, 0.06857281355487724, 0.1858356781303883, 0.23728877846752447, 0.21980035479270646, 0.18960830875702445, 0.21634543615002788, 0.13850923297145676, 0.15915292765825026, 0.15834567016891896, 0.14205024457506596, 0.1196534496041075, 0.18465607126633968, 0.12919191841877278, 0.16900667229727392, 0.20193052658390617, 0.14963662942811368, 0.11277723591774703, 0.17345404252409938, 0.1949895095200308, 0.2364089724517638, 0.12044704774574888, 0.11266694223928837, 0.1962747445870792, 0.18568973838081285, 0.09895716298131213, 0.10567190065499275, 0.19076766025635505, 0.12345651690397533, 0.11648333946903867, 0.18646521854304499, 0.13913368656029626, 0.23750035663045224, 0.3206900741544462, 0.1862320367006525, 0.46302700415253645, 3.0032850513535165, 19.31946954419536, 28.537996507460072, 46.359195170863984, 59.525344525614095, 68.78535839819139, 83.91124156213577, 86.12090879871, 86.3550978322183, 89.49273509363975, 90.4970265972999, 88.10830316235943, 72.37815533914875, 68.3306380241148, 64.1068454711668, 63.987472057342536, 57.574675313888065, 47.66673295728622, 52.96016762333532, 35.01942296181956, 23.382664572808054, 30.935566848324193, 27.57064392489772, 32.7318476476977, 46.582511394254624, 42.060952109675256, 45.581797092191636, 34.912597210176536, 28.32827521908668, 32.997943201372706, 41.07510359056535, 46.07310141286543, 42.86859950711651, 40.79628975160661, 35.40055182672317, 38.37086077659361, 36.923490493528305, 36.37580210162748, 28.139770030975345, 36.74776438743838, 37.539435971167784, 21.35532871369393, 36.660060190385394, 33.209103999599336, 40.24837386223578, 41.215916679751494, 39.3657660484314, 46.32566675063103, 37.10183674289335, 51.036652980312226, 56.463899304789884, 41.52995340285763, 54.19007385930708, 50.38429221799297, 56.70439943190544, 71.34086885759908, 72.00134892617503, 74.71379341617708, 80.59421077851327, 81.15809071448543, 86.71159421243976, 80.17849445343018, 79.5615291595459, 75.84933527054326, 66.25774383544922, 37.75756289882045, 23.942680974160474, 14.872700052876628, 5.12119701793117, 2.0559844831305165, 0.3129286841759759, 0.20238290150319377, 0.09398140659135196, 0.13663015718902313, 0.19965259478457514, 0.20018848860936783, 0.19135359494436174, 0.16330141634229692, 0.19561797740959352, 0.19376188426488833, 0.17061947123898616, 0.1068010836118652, 0.09677538287735755, 0.10685224296344865, 0.12286218589231854, 0.09160454219747936, 0.18408945731578336, 0.10571835622672113, 0.14331214460394076, 0.1196859164103385, 0.1669574330650991, 0.16189351527681275, 0.1291669745959582, 0.11589247883567888, 0.16731046170236605, 0.30929466949835904, 0.10754350708016466, 0.19093649071310798, 0.1327258820134786, 0.2549898528283642, 0.0942761972246151, 0.18508314996236758, 0.07860038354392014, 0.19219535703380264, 0.10168574600210113, 0.25839468464255333, 0.21451267804349625, 0.1200917361664676, 0.18664638301537884, 0.08141476075134932, 0.19184500970427068, 0.20657291215273643, 0.15044194105411732, 0.11221655148772464, 0.18005104014469733, 0.20011502077742932, 0.18227361443061985, 0.10874847911538617, 0.1323734509247926, 0.16114204431012755, 0.12859168853009903, 0.19378727241869897, 0.10097197422216977, 0.1272284120862042], [0.012413983668891654, 0.07250927974500003, 0.05891602246030685, 0.026325215322656498, 0.05796025499641415, 0.026273797416398605, 0.013960191375395704, 0.010000014764016435, 0.01980279636148724, 0.03811089389566933, 0.03709342571035509, 0.022460108307460626, 0.007742806600647108, 0.031421268584146615, 0.038841358731470765, 0.04299829736532223, 0.027237570499100035, 0.06000841404461573, 0.0353461362030958, 0.011132149074617173, 0.036289604125364174, 0.04884182452975262, 0.05221548422630276, 0.05143275304186729, 0.04808858389996233, 0.0589595400848456, 0.06154582993457876, 0.027071047882218997, 0.011507120385255304, 0.03244944667864231, 0.07020167736036163, 0.021516625063433763, 0.0465965548890733, 0.05790493578740186, 0.029327577100165432, 0.04815457088332023, 0.014819616579540796, 0.03864609824133016, 0.01768762377210923, 0.043597933535854665, 0.022682026742146384, 0.014665907740803256, 0.04426576685340655, 0.0382704431972196, 0.04982910118997098, 0.037100845271901745, 0.041830576355418855, 0.09011790261513765, 0.028161738751335975, 0.16867510944364533, 0.4355489318409274, 2.4406747375765154, 16.169469952583313, 24.929794457650956, 34.66411505976031, 34.74190350501768, 45.11479577710552, 56.790401320303644, 60.68895486093337, 66.42511137070196, 62.967691113871915, 59.02518741546139, 53.52523995983986, 49.58846684425108, 50.098237683696134, 50.40857953409995, 41.32213446401781, 35.59911397195632, 18.06399533825536, 21.753366916410386, 35.07240633810721, 24.890766874436412, 32.63861094751666, 42.72138510980914, 28.294523223753902, 34.870969095537745, 39.09382027964438, 45.551947855180316, 32.36312523964913, 49.11746078921903, 50.34741409363286, 40.171970013649236, 45.27469119717998, 44.95332356422178, 47.053505682176166, 35.45764976932157, 35.03513989910003, 30.69968923445671, 41.67915251947219, 27.328112010032903, 29.40425588238624, 27.535489682228338, 18.25739368315666, 21.480138532577023, 17.400285197842507, 16.875346552941107, 21.095050034984467, 12.667357229417371, 22.712147158961145, 36.20066042869322, 28.886948208655085, 12.635125152526363, 32.96223002095377, 45.074552259137555, 38.82758155945809, 29.01144619910948, 29.762585970663256, 29.911845884015484, 34.07878760368594, 49.5375152557127, 44.84277548328523, 62.47963843807098, 48.507571451125614, 55.33607275255265, 58.106489873701534, 64.32774943690147, 65.18920783073672, 63.516458157570135, 48.532474579349646, 34.987071252638295, 23.14039545674478, 10.554098909901036, 6.247056011230716, 1.2085810447892835, 0.4883666799193429, 0.10070770453180998, 0.08678678378102281, 0.05247408103558326, 0.010349391077104355, 0.055762996085949486, 0.04178230132487032, 0.02466509704508128, 0.030437136714857434, 0.051184942750560666, 0.07752565411670555, 0.0485040103986619, 0.0566485017958668, 0.03457930517352877, 0.05859998820890343, 0.0643745368166316, 0.06679643951957265, 0.022733435072305224, 0.027662036835306117, 0.03950584807523316, 0.025681688059722225, 0.016133664213421366, 0.03434750611983961, 0.04043217094975614, 0.03718294308430726, 0.014971739616275076, 0.05555652006859741, 0.004318630587564962, 0.021176215809499545, 0.059083964255067616, 0.08206205142121162, 0.04180541419754586, 0.03830576368096856, 0.021161106640412923, 0.09220668730596382, 0.02035043622937895, 0.035448937541655, 0.02282905433657429, 0.07188755342917097, 0.05298543323372161, 0.023075361180329518, 0.03219748419078608, 0.040666777715687795, 0.05941538155199059, 0.08044545268339497, 0.030280215094887444, 0.07027917481478184, 0.07577468355697009, 0.02735392010260013, 0.016493576150687955, 0.04343572973964676, 0.006677185480047258, 0.06041965004236949, 0.05811200935333487, 0.024121205262359113, 0.008379114442504942, 0.043576096199573054, 0.04826920061943032, 0.03630792128763372, 0.03492633534234858, 0.020569273075389288, 0.060481668690279614, 0.07304505865660406, 0.043337911803035006, 0.030209930358274333, 0.02944721130564088, 0.053584789782161676, 0.05931030110185666, 0.056536020936384324, 0.014739876402722252, 0.10627100439441782, 0.07305909338737689, 0.02181462943553925, 0.03274650876260093, 0.03199196386811955, 0.04343444654237359, 0.01792732885317697, 0.04091112145913705, 0.014210144797670505, 0.03064710609314423, 0.04473235270368957, 0.11250609441870645, 0.017266781031784993, 0.11820979521519716, 0.06194573166149278, 0.020502058436132727, 0.0626429942466559, 0.0669130687451651, 0.037386170888860384, 0.028010654721349, 0.05426710982236171, 0.009998155085580244, 0.04876590521645643, 0.022866297701013186, 0.045066872656705885, 0.038516621721247514, 0.037721158155510505, 0.043528330617494164, 0.01955566022755398, 0.025710203767483755, 0.09244182267256322, 0.2812602028491036, 0.5455856337662667, 3.568363516561447, 19.206803383365756, 34.34763077766665, 47.64102574317686, 48.14312442656487, 61.00141871360041, 69.10371365085726, 72.31768023583197, 75.75230367722051, 72.84178733825684, 68.44269229519752, 63.80554076164, 59.059033547678304, 59.7597885131836, 60.280918536647675, 45.281622025274466, 47.46871209913685, 29.5908449926684, 31.199928714383034, 41.65741474397721, 36.66745778053038, 26.449152000488777, 37.73826875994283, 29.96930664585483, 43.532668544400124, 47.80144676085442, 46.395433948886016, 44.69408627479307, 40.518370213047156, 43.94293669731387, 36.48558532038043, 36.84813784014794, 35.018230561287176, 41.43822877637802, 29.376240353430475, 29.009630141719697, 28.96557604112933, 31.12744723596881, 27.295354335538804, 27.938397507513724, 31.584787753320512, 26.761407967536684, 24.959753521027107, 29.9246092765562, 25.436907891304266, 25.23922435698971, 19.049086839922015, 24.422728092439716, 46.64987417959398, 33.02563121241908, 24.545578687421738, 39.993902252566436, 47.40986477944159, 49.712166632375414, 36.98853515809582, 41.3452725256643, 42.06616101726409, 45.92380031462639, 63.44043477889031, 55.87830120517362, 68.34155005793419, 58.43639258415469, 63.236196964017815, 67.07263977296891, 71.29777769888602, 74.16470866049491, 74.64064905720373, 62.559568497442434, 47.53494916423675, 32.115578574519006, 14.987246009611315, 9.359064505946252, 2.603297430661417, 0.6788622563885105, 0.1334407186556247, 0.025267494962580746, 0.07322499738825906, 0.03539482109068382, 0.015341701669498317, 0.013148028050519288, 0.028607917934535976, 0.05134597443224442, 0.03830665234296072, 0.06367730487498545, 0.045906229230064544, 0.031523395765332446, 0.017577483311235424, 0.017470795991680315, 0.042827658941068, 0.0820393369142567, 0.011384934149382096, 0.04607933828787458, 0.04724151665164579, 0.024222288648748112, 0.08370201584071883, 0.016443529541814522, 0.03771123731689107, 0.05538560585269044, 0.07579280919725857, 0.08465541992336513, 0.08469613749654063, 0.06259568448689196, 0.07618568206746733, 0.023060748053173867, 0.023941536576697425, 0.035106465595984654, 0.04633948642520174, 0.07097364117902133, 0.026088685676034902, 0.05555953079413983, 0.017217328141052878, 0.021746742554129134, 0.044315106746169834, 0.017248682204573866, 0.05773420543259671, 0.004966847266205737, 0.043021957990863634, 0.0454371344418295, 0.042864764409680525, 0.0557684391406515, 0.039172484914982514, 0.10174661168768522, 0.008201709546659502, 0.06196817037679496, 0.021323955865697037, 0.11737275988824906, 0.1596510839918929, 0.11985349048289562, 0.12782540908383747, 0.19064372255196496, 0.11284613020477757, 0.18560678638037176, 0.07761886403445276, 0.11823925129588574, 0.11471106400412899, 0.1811105703874942, 0.11702596720668579, 0.11038158704797107, 0.08476327744222457, 0.1304155446949505, 0.12940607063712614, 0.212436763629798, 0.1985723801678227, 0.19389665445252774, 0.15847409714854535, 0.12733660668375033, 0.1776532309069749, 0.18778501949723692, 0.17012169794930568, 0.14373928458700258, 0.24800749766009472, 0.16174657961293576, 0.10154220410772871, 0.15622038904938007, 0.22133161133575827, 0.13439391589453145, 0.15999472039120813, 0.241614677793076, 0.1586672892012904, 0.09330242286406218, 0.16985004317135582, 0.17407059008556028, 0.1632417074494785, 0.16526468518760898, 0.10290229362585854, 0.09569497673862404, 0.1520267931083518, 0.13309142852742828, 0.14519826839527777, 0.12893831267231895, 0.12687756679952145, 0.08573494506098571, 0.1702736131846905, 0.23321984035353507, 0.6982637088625663, 1.0028243533545926, 5.940973364537762, 24.959992785607618, 43.230226347523356, 64.48613474445959, 64.16961908340454, 73.21814660103091, 78.55858695122504, 80.37545234926286, 86.53012183404739, 80.70442153561501, 75.61930394941761, 70.62724851792859, 69.14634196988999, 67.95405126387074, 66.4189846284928, 55.89154312687536, 52.35170210561445, 32.09921248497502, 33.53967743535196, 49.36211862871724, 37.85200572782947, 48.09778182737289, 57.53691073386901, 49.16894582010085, 54.35122051546651, 58.16190511949601, 66.60869398424703, 50.11548434534381, 64.95687407831993, 68.25322612639397, 58.13293449340328, 63.87143658053491, 62.3643756681873, 63.71154116046045, 52.22939868127146, 53.86729809545702, 47.49542344001032, 59.667416695625555, 41.988925626201016, 45.327513756290564, 43.18748427975563, 31.597598214303297, 33.078136059545706, 31.313012607635994, 26.801727971723004, 35.37493874949794, 23.150862301549605, 37.95749002887357, 53.25797357866841, 45.910652529808786, 23.82834976719272, 45.81846898601901, 58.84955544625559, 54.40894603729249, 44.40463104555684, 46.96879425356465, 47.89516395138156, 50.837600538807536, 70.0151155840966, 61.784292421033314, 80.41580569359564, 66.5401231088946, 73.30268936772501, 76.28431827791276, 80.84732917047317, 85.42749651016729, 85.00627317736226, 71.63737650840514, 57.517185134272424, 38.14859574840915, 20.086077182523667, 11.33892301590212, 3.8944693726878015, 1.0917707772985583, 0.3148873258502253, 0.2696658911243562, 0.1667053441727354, 0.12499236997457282, 0.18667981509239445, 0.20156637434997868, 0.1430240802226528, 0.10563106050774937, 0.1582896231763786, 0.14527775767830112, 0.1612678359472944, 0.09641119233903386, 0.1495367315627875, 0.1748239762720562, 0.14758070990923913, 0.2303757542564023, 0.09260136814367387, 0.15563917346298695, 0.11076571119408454, 0.1103454200370658, 0.1946731918160954, 0.15430115493795565, 0.11585264992449554, 0.12228113884526877, 0.16949462433976514, 0.23396325207525687, 0.12200243605841553, 0.08508715643397263, 0.14586592934304668, 0.17136841411552123, 0.1133443937907296, 0.16741458837303425, 0.1564044493340677, 0.21137168691042932, 0.27388060044857765, 0.2760460552188658, 0.0855457136828092, 0.1040560909877381, 0.1501358429630918, 0.12968992153483053, 0.14711555664337453, 0.08922681212425233, 0.15322599650150345, 0.19056008107239203, 0.1322512139355944, 0.13877442196732567, 0.14676998970249008, 0.15118239567645136, 0.10342595302650046, 0.22257457367114483, 0.18706694996405035], [0.0517959438354498, 0.011455822180235579, 0.02124008072930719, 0.040018728618780454, 0.046250367416970195, 0.08628584654821504, 0.028827063130935835, 0.012407056318836348, 0.026981718199808272, 0.036220625568661964, 0.0192845206437332, 0.024819599742430355, 0.03348687145438406, 0.09197804070408307, 0.017943872521901806, 0.03817603052143128, 0.03736418416543353, 0.06174905007825263, 0.030654935511730375, 0.04986089766926823, 0.04353629410146706, 0.0818294211621246, 0.00839253151488881, 0.08844167925417425, 0.029699250402289535, 0.029187059337874095, 0.005588669343025334, 0.056355258660210725, 0.08667854321820122, 0.019533035735930168, 0.016806218547806624, 0.03634807578618488, 0.031079775315799543, 0.03895762406529919, 0.07637020200490952, 0.0808604961381324, 0.02553919953624568, 0.03336278053240911, 0.02480240681418969, 0.022601897775706266, 0.0028106659902409925, 0.08018766409687458, 0.05183213382899281, 0.05041988521453835, 0.024066673208689018, 0.07188330930207046, 0.029401692276399945, 0.056498340901828585, 0.38758496363316813, 1.9516941760816884, 6.91445416019809, 20.324831854912546, 29.54978366051951, 42.768265278108665, 52.116736442812034, 57.560950940655125, 59.50460303214289, 61.17399515644197, 68.71307696065595, 63.325199465597834, 43.815275315315496, 46.788992804865686, 56.936603746106556, 43.96197588213029, 29.10766390062148, 23.82365272891137, 37.75040457325597, 16.55511836851797, 17.04131184085723, 23.322381665629727, 23.424073034717193, 17.843546367460682, 28.834007978439335, 35.77178062931184, 26.39733945169757, 27.973889074017926, 24.94995936270683, 20.33484566596247, 37.83326856551632, 49.359863265868164, 45.231278404112786, 40.07756248597176, 30.36877847486927, 37.01712923665201, 34.65363056428971, 33.96349737721105, 31.328857021947062, 36.69788752832721, 32.56853976557332, 45.12982629960583, 31.32179871682198, 40.089392354411466, 35.06680911587131, 31.81768632704212, 29.80523978510211, 29.84374373189865, 32.95221228753367, 50.37726725301435, 46.54359755977508, 35.75798173104563, 58.2917316498295, 42.83093690872193, 65.79799498281172, 42.273395522948235, 19.87006441239388, 22.366156847246234, 11.888855003541517, 18.432684406157463, 20.040499241121356, 31.271184452118415, 45.3516794789222, 39.93693374818371, 32.4649578140628, 44.85695092908798, 48.833947950793856, 60.68942162298388, 61.812282454582956, 63.65726732438611, 62.760813543873454, 62.14694300005513, 52.856534681012555, 46.2570958752786, 31.381673697502386, 19.03143225177642, 4.658238685900166, 1.8687446271219563, 0.09364856437088982, 0.09485323763182087, 0.07909914508702294, 0.016370645851918286, 0.03586693426534053, 0.06246476389107205, 0.058975340648283886, 0.029685642765534502, 0.02322732046576998, 0.07256854430682237, 0.05123205332746429, 0.06805677672908192, 0.017445369533473448, 0.03772776949429705, 0.007682619860485918, 0.011729695740336133, 0.07220552588302283, 0.03139242728901727, 0.02070374640395805, 0.03815002566684158, 0.04343190313046498, 0.021285241612443523, 0.03651880231055041, 0.007900033698176906, 0.05337699226314022, 0.05819681528655272, 0.07476849601634088, 0.009084794418736091, 0.047016957128841075, 0.06800942483448214, 0.06207619260455813, 0.07206176948403159, 0.019663354952729518, 0.05178922524435386, 0.10073021219502534, 0.048475749415135196, 0.03138724470420951, 0.056396681034276565, 0.011671133106574418, 0.05913713841789192, 0.0526637644056351, 0.01775826090916751, 0.03198538891850941, 0.038943106699134075, 0.06000990408562845, 0.030060608330513203, 0.0405892840917072, 0.009078828509025758, 0.004916968239065741, 0.048949069178272644, 0.0540958317146907, 0.01700284075923264, 0.07105256355698071, 0.06559411814856915, 0.03825104585097682, 0.012415089708332334, 0.036702590634024916, 0.023551549942743395, 0.10048812075007348, 0.019772717834360177, 0.05287721948397737, 0.06484409508806083, 0.05967775134429817, 0.013112315904319048, 0.00791869416359752, 0.047738512362083124, 0.0669426703825593, 0.047553027153856335, 0.020666206180448496, 0.03660813582340076, 0.02111829956242394, 0.07508977030914638, 0.04432151124121682, 0.04668597267159531, 0.016432365725537943, 0.0814871177557976, 0.011403734904653844, 0.04690554496201296, 0.04239206517776174, 0.023426779117735646, 0.06477799702195391, 0.04575342916312718, 0.04071571924273045, 0.0254567684755931, 0.11129968213818728, 0.037419717879064625, 0.002600524481573713, 0.05406082149655108, 0.04129983064147734, 0.05288788342788335, 0.05232187851722683, 0.07614714018399678, 0.011944306653834159, 0.05731927689104792, 0.12438975755245456, 0.0601999283648066, 0.013519968525806983, 0.07471564361044476, 0.44141115921158947, 2.4310443382109366, 9.772376418113708, 27.096998114739698, 35.85684507123886, 52.006360946163056, 66.7939789064469, 68.73451663601783, 68.21418285369873, 71.3284270994125, 79.16551097746819, 72.07814893414898, 57.26754588465537, 54.60054597546978, 62.59820384363975, 51.0206183310478, 35.36185764497326, 31.96686387062073, 50.25580713825841, 23.478037003547918, 22.615423471696918, 19.500457509871453, 33.65514024611443, 27.247289611447243, 36.1805582815601, 49.14958892330047, 32.86617313661883, 26.511882466654626, 27.097647267003214, 28.199933305863414, 32.500849462324574, 37.61379626489455, 38.08268816240373, 31.216130064379787, 28.332448620950025, 29.189819905065722, 23.585172622434555, 22.856484497747115, 20.55222538209731, 26.978218939996538, 27.985881720819783, 31.124136755543372, 25.980773933472175, 29.44634879789045, 31.392946589377623, 27.40365685955171, 21.851620328041818, 24.65747998606774, 39.05956229855938, 41.42501431126749, 51.54208960071687, 50.589844026873195, 61.39851946984569, 34.31023097807361, 61.294855148561545, 56.51376439679054, 27.663827673081432, 34.288293161699855, 20.129974388307144, 28.977472589861964, 33.97282869585099, 38.2649254029797, 52.192395041065836, 51.757498325840125, 39.07983702998008, 53.6805618962934, 57.9013930597613, 69.80237407069053, 70.84253172720634, 73.90274924616661, 72.80490136915638, 72.92591433371268, 64.32901244009695, 58.10473265186433, 39.71212310175742, 25.361741550507087, 7.394799378610427, 2.536416361408849, 0.4510608639928603, 0.07222399626287722, 0.029522128958976077, 0.05611414014692268, 0.029380523351832267, 0.03493006619053983, 0.07084312277936167, 0.03373288909994787, 0.08079796804175263, 0.016597568755969405, 0.09457356957418304, 0.05965899751191178, 0.03883080970075342, 0.03700339505749364, 0.04784024117754833, 0.03146560400754454, 0.06239391607983459, 0.006293322761437946, 0.04852878951257275, 0.1425514499386472, 0.007093368969377011, 0.0467087178220672, 0.03445948902217131, 0.034231236955571565, 0.05685819538250085, 0.07172757128794348, 0.048879416464197065, 0.09967585304571737, 0.02769077853900531, 0.07055380201387791, 0.05463718008550425, 0.04155400712343474, 0.025670978150540785, 0.05507941966155364, 0.048658587789583596, 0.06456130905257118, 0.05900659703559453, 0.02434519596488005, 0.01985761569812894, 0.049492187212191285, 0.022768780453911713, 0.07511145059740351, 0.04641388505396824, 0.020934777454503124, 0.045543134197472565, 0.04398404184969203, 0.031638600067385746, 0.0636230313759898, 0.023548621571652835, 0.010565768780877755, 0.12445069984683108, 0.1011023777086408, 0.16089085940151446, 0.16365121208852337, 0.14436825809459533, 0.23103685749153938, 0.12675068731750214, 0.11706024964129734, 0.2372351829563418, 0.11778799486496758, 0.08072280715550147, 0.15317534276795003, 0.1687776886167065, 0.13110035069046483, 0.11685303817953795, 0.19449372805895346, 0.14600482108371873, 0.14841053634881973, 0.12141951209595128, 0.13161949783323273, 0.12608090430618296, 0.2776603863364266, 0.16795431263744834, 0.11055024130450142, 0.2543977741152048, 0.11865905215663296, 0.12867045769047353, 0.12435062578128231, 0.19446928985416892, 0.09533425657859734, 0.16471860239342337, 0.21340960336308326, 0.1282634121936656, 0.12424436172530537, 0.24740757420659068, 0.4716301408986892, 0.0937171062574752, 0.1862154279144541, 0.13349580037738049, 0.14480485160264278, 0.08166895638550482, 0.1990328602973492, 0.12996523821305844, 0.1254357356998709, 0.2036371253310673, 0.11939784436817132, 0.09730199937738719, 0.13969032604607845, 0.6132386132113395, 3.5379793663178725, 13.625393202227931, 36.31826485356977, 49.04096280374835, 67.04911339667537, 78.66041168089836, 85.50914456767421, 80.96904816166048, 82.14844211455315, 88.54068171593451, 81.57515633490779, 61.05137402011503, 63.2420922863868, 72.50556176708591, 57.47263877622543, 41.48288888316001, 37.507951105794604, 53.03984665101575, 29.6147184987222, 28.28725311063951, 35.78538733143961, 38.089948469592684, 30.642865857770367, 45.32264217253655, 52.540222983206476, 42.231853700453236, 41.12871454608056, 40.601826483203524, 34.760060156545336, 51.64054109204201, 64.20697181455552, 58.18003823680263, 55.699139102812744, 47.398913521920484, 52.51404116230627, 50.461033390414336, 49.95160771954445, 46.14057402456961, 51.80700255978493, 48.92239347580941, 59.45022721444408, 46.076043190494666, 55.921776756163574, 50.23932141642417, 46.25553477195002, 43.47858298209406, 46.514548486278905, 48.04303338450771, 67.62234426313832, 65.1486466007848, 49.33518371274395, 74.36421609693959, 58.71973676066245, 81.00867194514122, 54.73548335413779, 31.647579016224032, 36.19621246091781, 23.274654265372988, 30.210932493209842, 34.997516524407175, 45.64602198139314, 60.30029504529892, 56.04718277531286, 49.60885532440678, 62.34793701479512, 65.97205408157842, 81.96387106372465, 79.13961548959055, 84.4687201899867, 82.14481784451394, 85.7495701697565, 77.33643131871378, 69.10742421304026, 48.87039853680519, 30.936939677884503, 9.38179660227991, 3.7085492716681574, 0.9478213854374425, 0.20530137473777418, 0.16465158502180732, 0.11700364340457226, 0.26871401155667923, 0.15713523592679732, 0.19356066361069682, 0.099261001112961, 0.11966176165808594, 0.1297445895691072, 0.19350035716929745, 0.19386242564407088, 0.269970640900635, 0.14662245649003214, 0.09932546741178921, 0.08293870881560349, 0.20248086882695077, 0.10212483695678173, 0.146763171519964, 0.2861609285877597, 0.1286363208125676, 0.13254105564086668, 0.08360720479920988, 0.11846225182976454, 0.1446902601709289, 0.16966045173185487, 0.12873079477538987, 0.15964982760769708, 0.18740592854878596, 0.11900366148761204, 0.22126974207499336, 0.18692882431130256, 0.17613717354834083, 0.17753680086424276, 0.24235894753327294, 0.1634458085942653, 0.1849996617003795, 0.23784076013872701, 0.10354484987234878, 0.18988016271783462, 0.14830078659278734, 0.21936483380775298, 0.1812793089136962, 0.1491118132347061, 0.13916241485745678, 0.10247513832103822, 0.1041089587153927, 0.18627712863587564, 0.0814650314409406, 0.16186636512077626], [0.040877704703879934, 0.029310769131106716, 0.010147164932512229, 0.027735420397572944, 0.05382897264714684, 0.018600666512464805, 0.03226563537253007, 0.08780389573545226, 0.05055083262343561, 0.06013870644833773, 0.08722695491967664, 0.15296782487102095, 0.050611725122097044, 0.012485650236598186, 0.007496934990593864, 0.04035292298442895, 0.03705077376517077, 0.046837734689395276, 0.03458430006679508, 0.03907540625321769, 0.03037829541661326, 0.08582095375224467, 0.009049443291470168, 0.09205847993613252, 0.11824032381897974, 0.018164214730683356, 0.018085788394654953, 0.04519263748079539, 0.04321542966570105, 0.07429095510874065, 0.027206651190476074, 0.05973936396560842, 0.009598726417959459, 0.03091724976266344, 0.015229470746201134, 0.03400195067027404, 0.040767568073445754, 0.07514137399172591, 0.03587927977224031, 0.05569786329062716, 0.02184767846859271, 0.0453295182406662, 0.06620773159328007, 0.04970295332191933, 0.01719886733729753, 0.0049920529953294225, 0.14440000477817752, 0.5599719069657788, 4.076600464120988, 13.315170003521828, 33.24239707762195, 44.04585184589509, 53.65509394676455, 65.05377231105682, 67.19299377933626, 72.66047969941171, 69.47669183054279, 59.54534861349291, 57.84016093900127, 58.90113069165138, 25.78974470015495, 43.96605514710949, 35.38300314257222, 21.422089415211833, 22.786838892967474, 20.747233859954342, 14.568679102005499, 21.421099016743323, 28.267860912507583, 42.24378555051742, 27.42640268418097, 46.024930784779215, 22.318207833074755, 23.996095811167073, 32.01972369224795, 39.76240004262617, 34.643302963626006, 24.1930321339638, 37.37217826227988, 24.2317831900812, 26.400271423401374, 25.887235210787868, 18.601232574832057, 21.445335342038064, 27.89804808555111, 21.095648196435747, 21.948124362576394, 22.16234657072252, 21.201758115522324, 25.975939612234793, 21.65337589479262, 28.694718730065134, 34.4952021106597, 26.750319427059544, 41.932996549913966, 35.94815000411003, 27.29754694046513, 32.75644090867812, 20.256457098068733, 32.38668103371897, 36.83619814534342, 78.90460275834607, 83.53986370948054, 32.25189074393242, 35.637564966755534, 25.865111081830918, 22.460652628252586, 21.52056836312817, 10.930538581263635, 31.10630173836985, 24.60018396377564, 18.910817407792617, 22.884252917382028, 21.025935911363174, 30.80398701852368, 31.58468184932586, 51.08909899188627, 51.155496874163234, 63.247089385986335, 61.04741242624099, 60.51042818254041, 59.33157159436134, 52.34121761014385, 47.74054411918887, 35.76337891240274, 18.459144715339907, 7.7588571079315685, 0.8765728182850346, 0.18694917160657146, 0.04086924709319588, 0.031939933091522224, 0.05028513034865741, 0.07415463742349418, 0.05280365206060871, 0.02758662505525976, 0.056109842393667474, 0.060483694992839336, 0.044795731157665296, 0.02222388509600874, 0.013431837770997757, 0.06557637555224281, 0.026376453198252187, 0.05476350415377848, 0.018244876128230846, 0.04047134485576422, 0.041570125613361604, 0.008811723335736222, 0.0675901755570404, 0.11424662320003395, 0.04742207974495907, 0.0833445132499741, 0.017477512667556445, 0.050861274432991786, 0.03918505258738034, 0.05832164165293498, 0.059207963246491656, 0.055219583108179995, 0.033059421205712904, 0.04888457223592747, 0.040473616306459716, 0.08265658927660796, 0.021627640779761058, 0.044660056986275225, 0.045105230679074605, 0.04491972248821009, 0.01732508798370198, 0.03379069809471408, 0.016554190942476836, 0.04768015944489068, 0.01647187671023271, 0.05172141497173617, 0.017625003745178544, 0.04581788780107614, 0.035623245527066534, 0.05860722007890863, 0.0756577785397249, 0.01918774458669847, 0.050120521036367265, 0.09325960620997414, 0.03870857271155523, 0.01605078307611327, 0.047008388435408, 0.02078216507910721, 0.04138994939445008, 0.022666304702720335, 0.13507597929527684, 0.030998732789509723, 0.09439887854480937, 0.009145323983243397, 0.13055714838687452, 0.0184634295217092, 0.05685339584165523, 0.07488815895011348, 0.04009180574587757, 0.02389364267489122, 0.061928284009017294, 0.035768480475751624, 0.08168672962534813, 0.01047586453252382, 0.06437236112692664, 0.08804870679253533, 0.1027697067888033, 0.03841192431507572, 0.010343793847207582, 0.03219701687715227, 0.03765514052863564, 0.017352395187762958, 0.019320229917103728, 0.029890741739842682, 0.02326195147038708, 0.026938403588569453, 0.06521516509594456, 0.07501539849345723, 0.01849229379947628, 0.018151599177790266, 0.017537794211098266, 0.05570799863386539, 0.07583548795552024, 0.09757468837403482, 0.028106980701728214, 0.039473680043292624, 0.05892168001962766, 0.028796107433135473, 0.8603658298811606, 5.772783112141394, 16.962340800992905, 38.199253159184615, 51.45277330952307, 63.713031661125925, 77.09446814752395, 79.63988242610809, 82.7302315927321, 81.09605450784007, 68.63746150847405, 69.18361233126733, 66.21362501575102, 31.006736293915782, 48.36208681906424, 46.65997820515787, 35.945223915961485, 32.96752129831622, 30.815991432436054, 18.752371303496822, 25.171708599213634, 25.979691359304613, 38.42757040454496, 35.27221579705515, 38.19307150379304, 23.44736210761532, 25.20201479235003, 30.116711278115552, 33.03528416541315, 30.385197516410585, 21.85121044035881, 26.395062515812537, 21.576517051266087, 20.875138428903398, 19.539641987892892, 17.62994977735704, 15.642957456650274, 18.388877414887954, 16.688555440595074, 15.4613576012273, 14.39816092291186, 13.899946366586994, 21.699012671747518, 21.58202798135819, 25.66990452428018, 29.457402037036037, 25.659106239195793, 36.41920704995432, 33.694512997904134, 34.09094695122012, 44.56473042888027, 29.57233140545507, 34.177721546542266, 48.0070181815855, 72.81863750949984, 84.51144264590356, 38.69204798052388, 38.28496479219006, 36.676804788651005, 25.76447286913472, 28.285256624221805, 16.47083643944033, 41.59252305184641, 33.50169320260325, 30.220344220438314, 33.483230606202156, 31.41144644829535, 43.038967655551055, 45.0007293301244, 62.370478876175426, 61.0361473791061, 69.91664840329078, 69.86571250423309, 69.14332958959764, 70.29438834036551, 60.86197060923423, 57.05851101106214, 43.78488871359056, 23.96897654379568, 10.115278843910465, 1.171592603768072, 0.17064245387671456, 0.03573727005371644, 0.05268363672639093, 0.04333578973948475, 0.09732455300587801, 0.04357253772116477, 0.02737542227541487, 0.09280322465084254, 0.0382096273073506, 0.06528296387724339, 0.0733278600138522, 0.019431586542557326, 0.043047135470495115, 0.03538573145746224, 0.09813374869765774, 0.027268495553383426, 0.05464518953475261, 0.03799640971626486, 0.09138173318558163, 0.021245550597086552, 0.03730086699849175, 0.01134617297324322, 0.03387373053438721, 0.06523806346400131, 0.04228632206157331, 0.010354359157293314, 0.02014638296508741, 0.018334659717736707, 0.018419517361889445, 0.06393958273674212, 0.007385177126589923, 0.018762881799991575, 0.033436110468521234, 0.03908964016685083, 0.03197308746166527, 0.03153558996986718, 0.028342299929429448, 0.03493800286143538, 0.06299567048347766, 0.020360104258983366, 0.02110403500527384, 0.01413916675148592, 0.07018743578584925, 0.0562659826039547, 0.004609347548290727, 0.030714749741638382, 0.022013163036336342, 0.0287744386361972, 0.10096376175962149, 0.15792720230116, 0.17147583496426383, 0.21240123247186984, 0.13298986059042717, 0.14259315576524506, 0.13799488153909484, 0.1800216683336804, 0.20448922960748597, 0.2783224088770728, 0.1600525600294913, 0.3033886525419451, 0.15917463859002437, 0.23221513136259972, 0.124432145197305, 0.23417579550896925, 0.12265499741319688, 0.17673637687919602, 0.17432254108209766, 0.11475838525521179, 0.0926990213713819, 0.19919805949734104, 0.17913340470723568, 0.21143220785644748, 0.2630556248609097, 0.18961011672452574, 0.1820631547560615, 0.13349984532162068, 0.26041645196176344, 0.12797160930330717, 0.09504602365796605, 0.11255325479132515, 0.1002315502433527, 0.09530138374576647, 0.08933381928551583, 0.1575835046148108, 0.11903560735405454, 0.10252299583366803, 0.15836592553363693, 0.126960817574253, 0.1690218255164162, 0.10886479424492967, 0.09906705063317092, 0.11237916897141165, 0.12639373631006287, 0.14733862612516652, 0.25603380084278127, 1.643838250348645, 8.354418027785517, 23.547935601203676, 47.64166116714478, 62.045263398078184, 78.12882069618472, 87.44465381868424, 89.54500459855603, 89.38241451017319, 89.74371971622591, 75.53071329670568, 73.28730583190918, 72.59936917212703, 39.67692767420123, 56.66813319729221, 48.08498313350063, 34.65873749025407, 36.910848694462935, 33.9872081049027, 26.125525082311324, 34.02018739331153, 43.7420799655299, 58.561465201839326, 40.05342029756115, 61.39450688515941, 37.97687438226516, 36.517615395207564, 48.16893754466888, 54.180773919628514, 46.093070199412686, 33.871596244073686, 45.56440922521776, 31.431177931447184, 33.68841763465635, 33.221259424763346, 25.985108152512584, 27.702208065217544, 35.246881208112164, 28.39319044543851, 29.371963008757564, 27.616929854116133, 27.73272998871342, 33.80553568563154, 30.82232802144943, 39.80402423489479, 45.20286475458453, 39.26849126815796, 56.109062087151315, 48.56042538919757, 39.0657086526194, 44.517560005187995, 31.84159513442747, 46.76602732750678, 55.282783431391564, 91.30585855053317, 94.81832535036149, 42.74689620540988, 49.08537580120949, 39.041044788975874, 35.94954636789138, 33.37743251554428, 18.318541472957982, 48.086077474778705, 37.15462400067238, 33.23156349120602, 37.21695438508065, 36.465055634898526, 45.696734305351015, 45.555662339733495, 68.7800318194974, 68.77052399419969, 79.48536457553988, 79.1545440304664, 79.45142038406865, 81.84841217533236, 71.51265298166584, 70.17789394624772, 54.74565798236478, 30.89468202283306, 13.287559459286353, 3.014516022897536, 0.35264856572593417, 0.1331489004435078, 0.20003917807292557, 0.172784190564867, 0.16498402121566957, 0.1816371792266446, 0.14318315071925042, 0.21829008905877992, 0.1069106495067958, 0.09528109773753152, 0.13149991150825255, 0.1681800481052168, 0.14539832459582439, 0.11209328794070791, 0.1398548510886969, 0.1061240457479031, 0.1670896904843469, 0.19483422349777915, 0.1032051281823266, 0.11120022094297795, 0.26072297906202657, 0.1398200553751761, 0.16637923586512768, 0.12990318509119173, 0.13362407413942198, 0.12752460466036875, 0.2156392716231846, 0.13952895728570802, 0.1540430292727486, 0.13686582115629028, 0.1394123893471495, 0.10191288341077105, 0.16161966948739945, 0.181049543823446, 0.11122917906651575, 0.17301282184498926, 0.13232815980670914, 0.155100935409146, 0.1770479448380009, 0.1868117967199895, 0.13808318083324742, 0.11216116333079916, 0.18563700088810536, 0.12080697117433434, 0.14128463162529853, 0.15773666091263294, 0.19988781442084622, 0.18369251651869667], [0.06502040256295474, 0.1324954580876135, 0.028136524882528092, 0.06537971312120076, 0.12914598378683292, 0.041348067367629665, 0.01628966844310203, 0.056396052842178655, 0.07300319961242138, 0.054286549303440325, 0.04967922757890436, 0.01784369694970308, 0.10595562897862927, 0.05767649219882104, 0.06873134778992784, 0.04458876101360206, 0.023236486707784, 0.013053462157146105, 0.03563057315806228, 0.047017608303576715, 0.00270352452418827, 0.03920379875888748, 0.04244363438638468, 0.10690989874063, 0.04639009802391933, 0.03851098331412481, 0.05469680087821138, 0.025034334187606172, 0.04960223191207455, 0.0208359272144134, 0.03557703510347394, 0.05156397624241729, 0.061368679762968135, 0.009631474761502638, 0.07902168593699894, 0.028615385376577897, 0.017584590691952937, 0.029812085577436996, 0.054021141972512975, 0.04636278315897911, 0.06600878622022367, 0.030711474715762084, 0.10171258206208868, 0.015108759229582165, 0.04116747746123903, 0.052093741363815727, 0.6146955898692531, 9.213602427513369, 19.56293890553136, 31.199897335421657, 61.696274434366536, 69.57657890935099, 76.8797811385124, 69.99176179209064, 60.88292783306491, 60.35838534755092, 55.32780439622941, 54.70429658889771, 48.284823971409956, 37.03595269110895, 45.45257068449452, 32.33246211082705, 23.90213739487433, 18.9149849261007, 23.651419493459887, 18.542406828172748, 27.627039763235278, 23.327839643724506, 28.26991427329279, 26.78513438470902, 36.0004783445789, 39.188682802261845, 32.32234435696756, 28.753307173329016, 20.75858323804794, 11.533166631575554, 7.968091041811052, 9.069267049912485, 8.755905955068528, 5.25011650016231, 6.830512496732897, 6.7490179019589585, 5.778302867566386, 6.494138856087962, 6.392799519723462, 6.607829736125085, 7.686966926820817, 8.184507816068589, 8.301420923202269, 10.630288989313188, 9.474169400430496, 11.009745943930842, 15.279792066543335, 12.3621379944586, 8.961586221571892, 14.093864425536125, 19.70976891056184, 16.49870291832955, 29.29567683127619, 39.930654033537834, 20.809497564069687, 36.142099442020545, 41.13109542477516, 47.33607322938981, 39.16110069521012, 31.628710454510106, 28.11005807692005, 36.90571823427754, 43.5893311039094, 23.67144319318956, 23.430611625794445, 15.531064002744614, 13.938666043743012, 23.32263465850584, 22.737362115613877, 29.396766116542203, 31.370804809754897, 35.433091809672696, 42.47415419547789, 47.18831362262849, 54.31961013424782, 54.45273145552605, 57.97461194376792, 57.00006769549463, 60.00794510687552, 37.15971523715604, 23.32845545584156, 12.152049964474095, 3.354407539290767, 0.7125320658087732, 0.04389607963422614, 0.038240558107293425, 0.03853815262235942, 0.017585151851357474, 0.02320420184743501, 0.07201292371797947, 0.014353643599597198, 0.032290858817437006, 0.09490073508312626, 0.029833712239539432, 0.02076910711043785, 0.024709874884255474, 0.05552138727638991, 0.021634508758002234, 0.015395295265461168, 0.026619818264378176, 0.06200819847083861, 0.0202425787105195, 0.010099495111423875, 0.03095740234599479, 0.03889563989134566, 0.03140200913373021, 0.02925286629056979, 0.01871248087545316, 0.10580774336572617, 0.05054985586133215, 0.04380584596806476, 0.0885296721131571, 0.03977839534561481, 0.001765285870210538, 0.02278281326946472, 0.07317155509466126, 0.04538007621322909, 0.024910607157395254, 0.035411939325351874, 0.09011989444374077, 0.049516924191266305, 0.03861397234422546, 0.050291010073476264, 0.06488998375472523, 0.0504133083497084, 0.06521697306344587, 0.02873231529168064, 0.03872541132413092, 0.032931407913565636, 0.03541904096040995, 0.12567425717509564, 0.05331806861044419, 0.035178960496259314, 0.03925917542449409, 0.06342578288768569, 0.02509351639497665, 0.014325147044033775, 0.080876890419712, 0.028755813123538133, 0.02979745329808324, 0.07714234202379182, 0.06126029364344093, 0.05010066786780954, 0.05638142822370414, 0.014589563248709086, 0.06254129224426805, 0.006727669237842483, 0.0399012413747128, 0.052441748294739, 0.02720642902497803, 0.018347562553601402, 0.051099336255461945, 0.008080046165794616, 0.10134840684552347, 0.05109323436514505, 0.032320567707140604, 0.05575240108995669, 0.03253229525721362, 0.05620892820579391, 0.022900961264367067, 0.05091348715547112, 0.011533760135212253, 0.09166000696319727, 0.01915548845464664, 0.003917530411854386, 0.013109160579680918, 0.0181761963458191, 0.03728939100138603, 0.02604639953783443, 0.07021774988501303, 0.09411059199802338, 0.06737449116283847, 0.0392273904365157, 0.01574685875957291, 0.06521748634235514, 0.05473026359874395, 1.2301823953467033, 10.853352219827714, 24.415030440976544, 38.15439301152384, 74.5822371205976, 80.8122867153537, 86.55543681113951, 78.31980874461513, 71.96373339622252, 69.84181742514335, 64.72299098968506, 63.75185528109151, 55.83485703314505, 50.7757604506708, 47.6332712173462, 41.35899297652706, 33.93129079572616, 18.19215093889544, 25.539515133826967, 17.773569322401478, 27.285001239468976, 28.31070103952962, 34.21016739260766, 37.61221947208528, 33.03327198951475, 33.48838852297875, 31.443368657942745, 20.691216530338412, 19.94003753508291, 11.517991961971408, 7.204192290383001, 7.288408519760256, 7.202667959274785, 5.221771001815796, 5.708851420110272, 6.346271384146906, 5.794937149170907, 6.330751055671323, 5.411678437263736, 4.324507251862557, 5.945349258761253, 5.055655683240583, 6.492321327809365, 8.269528131331167, 8.488387561613514, 10.054650768156975, 12.63202844127532, 11.516801522624109, 11.845740310607418, 14.938849845240194, 16.429298539315504, 11.945966674435525, 22.6635842938577, 30.825760095350205, 23.35469218992418, 38.13404767744003, 48.13563662190592, 42.57059351090462, 38.3916611056174, 29.55080347676431, 32.83064430759799, 32.64593205144329, 31.65531393020384, 33.76618646806286, 35.69069739310972, 25.209930135357766, 24.36431811701867, 37.36345883338682, 30.994586752307033, 40.940970297782656, 43.521470177558164, 48.98869329883207, 55.444443918043575, 59.02821940760459, 62.81518936157227, 65.99732199022847, 68.80458585677609, 69.02718036405503, 70.02023035480131, 44.8906127099068, 28.295158647721816, 14.490099318565862, 4.40152544167734, 1.068332409185748, 0.03197285380484837, 0.07506341688455113, 0.027289901965207634, 0.043854496381696195, 0.058458143199283275, 0.004988619485013788, 0.037966402052270795, 0.031209496984017954, 0.11658112293169384, 0.019600060768425465, 0.06734467502082549, 0.03247560092037724, 0.0684290724776445, 0.015347294111345566, 0.007964136105241075, 0.008341553151577471, 0.045502991190240274, 0.02766442702962987, 0.10036358549710243, 0.020350916949551434, 0.07148793898522854, 0.022295514316928965, 0.03730501153416211, 0.018209523085745114, 0.03888099229023342, 0.015360067669873037, 0.029326914434110927, 0.08022210740995023, 0.024779450989538626, 0.01986889825803378, 0.009303397607929524, 0.017372372845608382, 0.04854191259871568, 0.02811163468586822, 0.014883673978939414, 0.02532759647546036, 0.052020717862873316, 0.038568091338440295, 0.036327835743225394, 0.05129442820625921, 0.04979375389314467, 0.04734402687679376, 0.03681229442478188, 0.009995701689002736, 0.007747096693023078, 0.09407320690731849, 0.18853834439669886, 0.4105562019732691, 0.10751837173536902, 0.13986188377584183, 0.19260216504335406, 0.1523596123461762, 0.15747455159021964, 0.17710500306660132, 0.16390276471934012, 0.1509481259892064, 0.17756487032578838, 0.19892982147153349, 0.23986871744836533, 0.16476265244906949, 0.19941290119482627, 0.12123998705177538, 0.10590772550072401, 0.23485813470136738, 0.14085053556388424, 0.28247393126929965, 0.1801105651764139, 0.09883668033346053, 0.13024176531020673, 0.15606023070793, 0.12101571481194227, 0.17853231680008674, 0.12422229839308609, 0.08950431215306444, 0.19794572024576126, 0.11226076242183486, 0.15320970947223325, 0.14474503545751496, 0.18766975390814966, 0.08516066257030734, 0.18547681190313833, 0.1655238986976685, 0.11887489742929898, 0.14253735392084046, 0.16594590589163766, 0.270344338590099, 0.15898492457645555, 0.16142373483988548, 0.2306693038272281, 0.15558700287534347, 0.12394113646399592, 0.1495184067396387, 1.8067617401961358, 14.554056506003104, 31.935849689668228, 48.871461499121885, 86.1995287864439, 91.2589156243109, 95.15919500781645, 89.5332217985584, 80.6998872756958, 78.56267406094459, 73.19679321781283, 69.09478633634507, 62.89923790962466, 50.303307041045166, 58.37028495727047, 45.328317842175885, 36.01485383126044, 30.03329619284599, 36.20224898861301, 29.969853816493867, 41.97118082354146, 33.63407711828909, 39.320894133660104, 38.824643704199026, 48.61549546641689, 52.356146151019686, 42.179317474365234, 39.87370514100598, 29.236454925229474, 17.6172040354821, 11.224922268621384, 13.449342520006242, 10.989554562876302, 7.788641625835051, 8.98619419144046, 9.07025646778845, 9.062248949081667, 9.880406337399638, 8.965665486551101, 9.191874457943825, 10.734380848946111, 10.766106940084889, 11.133472208053837, 13.884183341457, 12.716457459234423, 14.932817239915172, 20.03024028193566, 16.7652593504998, 13.64225939396889, 20.6735501750823, 27.341189192187404, 23.63598300564674, 39.700363835980816, 48.161547799264234, 32.91349849393291, 46.32563537166965, 53.73864435380506, 61.783468723297126, 52.94922421055456, 44.30743471268685, 42.19859592376217, 50.08066546532416, 58.8838565734125, 35.51803465812437, 35.787124941425944, 27.1133053687311, 26.92974825059214, 39.01574157899426, 35.36831778864707, 43.34605001634167, 45.5258797830151, 50.24832717833981, 59.59191891454882, 65.62755623171407, 72.95501832039126, 74.56264880395706, 77.82855541475358, 77.50281041668308, 83.20523062059956, 57.23778686215801, 38.892732128020256, 20.926003725297992, 7.649449946418886, 1.9416503343851337, 0.2570799245469032, 0.22909894615652102, 0.10593282254112345, 0.22149331717481538, 0.14589523986702965, 0.2243305391241466, 0.07797524047594878, 0.16238048672676086, 0.21752455271780494, 0.10492979128274227, 0.17239533965626072, 0.1395541002913829, 0.2023128197798806, 0.1535983765197377, 0.12067300537901542, 0.12591623370685887, 0.26761470602885373, 0.08959857927214715, 0.1631453489103625, 0.20006090432645815, 0.1971287487615501, 0.09630819181761435, 0.1967765321774829, 0.21298094652593139, 0.2642316004681972, 0.14552263002241814, 0.15626419395689042, 0.28714679181575775, 0.08598682710960989, 0.08591351249525625, 0.06611911054219931, 0.09679797481024459, 0.23874903398175396, 0.10387474265430244, 0.12898392554733062, 0.19567566383029186, 0.16195716186156198, 0.2230323418494194, 0.17749748523196868, 0.22573696930081616, 0.096975339486474, 0.13664066791534424, 0.1515638461757091, 0.20340202826886408, 0.13150162754520295, 0.22283617737552813], [0.03184904250496578, 0.06065963091508997, 0.03384315213488956, 0.07596502576263682, 0.006723017647727243, 0.038731233592355446, 0.058361256059499524, 0.08950498631043781, 0.10736790440616109, 0.04530534433621553, 0.10127915249716851, 0.034891727320369215, 0.12923613701376224, 0.045342331061199795, 0.007330428653081218, 0.036481371254570065, 0.03502382769159252, 0.04476598013312586, 0.017627771237805005, 0.025602572244561972, 0.045796372221722725, 0.04874008422296855, 0.05362479106312799, 0.06062146824514193, 0.061723481893779776, 0.13344160731761687, 0.03312035583921018, 0.050985495589913866, 0.05926881744075687, 0.0339775316176876, 0.09253771389804541, 0.04293727846215329, 0.037290340950412136, 0.05643986541056826, 0.018807743908837438, 0.03469983761709544, 0.01942146843629739, 0.03253431772933372, 0.036944563335348526, 0.01077940580510204, 0.04515776515848214, 0.027949545802848957, 0.028103562034366113, 0.03546596384577213, 0.05225515608946162, 2.8276673007395963, 9.952497539981719, 33.44499534176242, 52.88504246742495, 63.701550883631555, 71.83328320903163, 76.08152389526367, 64.0353798866272, 68.96289271693077, 60.67347326586324, 53.53591272907873, 47.6353108498358, 23.0535404528341, 25.255427668171546, 25.393583351565947, 30.78519298184303, 25.43837485774871, 27.885718114914436, 33.399829249228205, 31.078798078721572, 43.87933546496976, 25.598182024494296, 37.55049313268354, 32.07443095022632, 29.534037305462746, 28.45055118683846, 21.55279847883409, 10.862184416863228, 12.262489199638368, 7.950316821375202, 8.877765170989498, 5.044408286771467, 2.6696489799407224, 1.2731493865289998, 0.8114490321566983, 0.499167018119366, 0.9094406255791265, 1.0329067875300686, 0.4891110722336077, 0.50022425009839, 0.7448839588511376, 1.1315708222889131, 1.2593656874472097, 0.6454739996021794, 1.6708046678573856, 3.1720035979824686, 3.1708609625216457, 3.789247870445252, 5.863034398325029, 4.112021673110224, 5.065138013132158, 9.033768619260481, 16.98174476623535, 11.45781691997282, 14.715737585098514, 17.400593103901034, 17.753592691113873, 22.31787443161011, 31.56711551450914, 28.734522942573797, 45.95225711022654, 30.994076844184633, 35.56002363081902, 49.03921734902167, 28.680286369016095, 24.927068410381196, 26.415951098165205, 21.49842462232036, 13.107585426299805, 17.60258536184988, 22.48791310095018, 18.410499480462846, 24.856420640022527, 39.456584607401204, 32.012720300305276, 46.19496945411929, 42.93805683812788, 45.21445143607355, 47.617871992049686, 52.29304305968746, 49.702160666065836, 52.477504284151145, 35.7966523785745, 12.72625553992487, 3.8126151455986887, 0.8795435846813264, 0.25921602282793293, 0.04263968011664768, 0.055892350031964244, 0.06308349097267756, 0.03715693439927794, 0.031948528598032655, 0.03363161227635799, 0.03347788524303225, 0.04292772917617713, 0.03158777396404936, 0.05067848202381885, 0.016069521586741173, 0.030933521470175158, 0.027073095252196637, 0.023829197443480936, 0.01850982572162344, 0.01926474025352828, 0.030345981827967113, 0.040502402060214555, 0.09647978019089469, 0.016073026438994754, 0.050312337961288235, 0.024720297510465308, 0.03609806299209595, 0.05487810707681122, 0.06646045633862097, 0.04932678499889951, 0.08635321632027627, 0.023997123916483214, 0.09967363139073696, 0.08543984799255287, 0.03877937072707761, 0.02704500089279346, 0.06719973118555161, 0.05195341320828565, 0.09018039240712121, 0.007549657161542846, 0.052328091490292744, 0.02427306687158923, 0.06133291111778348, 0.04430944918684902, 0.03721481234195732, 0.07873897651030172, 0.018387996674244924, 0.022662658124200763, 0.02169800595560622, 0.023273709004804976, 0.043618119952659455, 0.03488244616516656, 0.07195466273133794, 0.06376639707013965, 0.025642293903435913, 0.047043973219490824, 0.052274051648114, 0.08184741656746596, 0.034576704305025845, 0.08624576482801669, 0.0296332212840958, 0.0269115656133621, 0.03561078127653849, 0.024421636217964754, 0.01910257284649678, 0.07153176687537663, 0.04595041718153704, 0.046605234665255395, 0.05948655495059587, 0.03478218823851597, 0.033792326031553174, 0.008763297960432547, 0.056060977475417245, 0.03986479474171516, 0.07128586031256184, 0.029650462092831734, 0.04641718689292189, 0.021161225384041187, 0.05909707201945205, 0.0756017085645468, 0.05531696820511453, 0.03818545340289993, 0.052849667131780624, 0.06292240949527872, 0.015371349272167972, 0.04380407630495968, 0.029936392919250557, 0.12439718094444084, 0.09636281388661555, 0.030077247760228576, 0.05282652744602773, 0.014049633098165355, 0.18357423254318778, 4.18667761548873, 12.540571516559972, 38.935203552246094, 61.72038916618594, 79.10816592554893, 82.1247039302703, 86.1352332945793, 73.91095484456709, 78.04311690791961, 71.91307206307688, 62.69321933869393, 56.479565251258116, 35.99876819118377, 37.25834323513893, 30.829251004803567, 46.26231654997795, 35.68457457327074, 31.674613952636722, 29.252595478488555, 33.707382294439505, 37.44527555281116, 33.749045710409845, 38.127654214059156, 30.32142762214907, 22.476930464467696, 23.491212244956728, 19.099289255757487, 10.594617974373604, 8.500310586344812, 5.331161002958975, 5.395043665362943, 3.340257588894137, 1.6643140032406778, 0.9918694798984836, 0.6259651109576225, 0.5467533356239719, 0.5255269391402122, 0.8783657091759867, 0.585719631804574, 0.41133549725336416, 0.832412384690777, 0.7707472097489142, 1.0787567207890174, 0.6238995540526606, 1.496254414800675, 2.464545056704552, 2.899172599277189, 3.170601840942137, 3.6497730449322736, 2.7492255357003983, 4.010259211063385, 5.702147599189512, 11.641062209683081, 10.440014812254137, 10.854237694894115, 13.925515317147779, 17.791969160879813, 23.714546119013143, 26.906235602594194, 25.200636079234464, 34.97835574611541, 28.999508465490035, 32.88525546750715, 49.75802698443013, 33.802907697616085, 32.16002295094152, 31.499542882365567, 27.174380594684234, 19.213020340088878, 22.664325621820268, 33.90838415391984, 29.714976241511685, 32.951933799251435, 48.19847299206642, 44.15716478901525, 55.10883808135987, 50.403951137296616, 53.83139664126981, 56.846275483408284, 64.44353780438824, 60.41482825433055, 60.659019331778254, 42.83411010619133, 14.651573492634682, 4.957409135756954, 1.1608829397347666, 0.22998305758641613, 0.07285873841253981, 0.04557177822496142, 0.012126608766735563, 0.014423517521560915, 0.0247338438601864, 0.017805149320573095, 0.052289350423961885, 0.00758241172955041, 0.03214283147826791, 0.06849738453785259, 0.04918590526006395, 0.04703309094052642, 0.04887056048779238, 0.040880408994252646, 0.03224154956819069, 0.009648143877125075, 0.039993803948163986, 0.027521471192519513, 0.04003516886563551, 0.006289876323388589, 0.072309146935661, 0.022119743103582053, 0.050863994045122984, 0.04292884000366734, 0.0728626378000744, 0.03778880754966409, 0.027993620756352623, 0.03402322493193131, 0.061401809235253645, 0.05547033517711586, 0.014260449003608478, 0.03013374865986407, 0.046660002290962205, 0.03574054507959274, 0.03250580010635238, 0.05399910162293142, 0.033073651288906415, 0.04903297495817946, 0.04540838699247088, 0.031201939526644927, 0.05753562395130435, 0.005302121337022512, 0.030420524098219413, 0.022145713484215162, 0.1410144477361633, 0.14690597030904987, 0.16707069150382475, 0.16710625330526985, 0.17060702997109584, 0.18057898197683597, 0.23583661284177537, 0.23778837504646472, 0.16948702474755628, 0.22858781229344108, 0.16822012982541518, 0.21435720816014275, 0.19277252767595554, 0.12226943302178576, 0.12031564068409706, 0.1315547174383556, 0.12833108840089652, 0.1784229194444995, 0.14292759910946892, 0.15795865787133095, 0.1371100346647924, 0.1285928683055024, 0.25229239595993874, 0.14873376416583217, 0.22781035562436427, 0.16536924086751478, 0.2143362173510175, 0.14266300766218093, 0.15729585392100198, 0.18831204202386642, 0.18790480500507742, 0.17610807752897664, 0.11784062510536564, 0.11358362006684465, 0.15197203314352423, 0.24051763988550634, 0.16177317818566678, 0.16168408216007296, 0.11609433534284753, 0.22315373614190087, 0.24626987235200024, 0.14753926455253555, 0.11533595426308534, 0.07785211482475843, 0.40309499588704883, 5.604177578803032, 17.69605544305617, 49.43936578689083, 76.58969048530825, 97.48931038764216, 96.32358197242984, 95.57394642983714, 81.99812904480966, 87.606945806934, 80.77029382028888, 68.6163434674663, 62.67712977624709, 34.01125615642917, 37.78711795806885, 36.54726851371027, 45.58668828779652, 36.17966005879064, 39.29062912541051, 48.93655323213147, 46.16095465998496, 60.763899587815814, 36.39195834436725, 51.06879288150419, 46.08023620420887, 40.22583200085548, 37.24458748294462, 26.502992414659072, 14.703772394887864, 15.538461592889602, 9.8201891299217, 10.61472894683961, 6.68680714984094, 3.354617876391257, 1.5762482126874309, 1.448571141208372, 0.9226433848661761, 1.4063348140447371, 1.5344921307217692, 0.9731993656004629, 0.8800832783022235, 1.2960077341525786, 1.6621369652209745, 1.5418232857219636, 1.1513298846060231, 2.139493827858279, 4.578080148466172, 4.229236802747173, 5.408704790376849, 7.70066237257373, 6.0680081479011045, 7.105805518165712, 11.010091112506005, 19.98031243201225, 14.251608425571074, 18.81296603910385, 21.46648083963702, 23.337767162630637, 29.177336961992328, 40.54699959293489, 38.88799782722227, 57.54435539245606, 45.83578625032979, 54.20624186915737, 64.59945594110798, 40.7360892142019, 36.473684849277625, 37.09544327951247, 31.242574684081543, 21.931991654057658, 28.35733605969337, 32.68991554937055, 29.65333619425374, 35.08725250920942, 53.14566043115432, 45.640911133058616, 61.29343525055916, 58.98727770774596, 62.80411258820565, 66.5904784971668, 75.16238704804452, 72.24857591813611, 73.08151475844845, 54.387184727576475, 21.804979424322806, 9.568186652275825, 2.669801216933035, 0.6979045668436635, 0.16664467000913236, 0.11294556841734918, 0.14828658332267117, 0.1402775477617979, 0.12096709887226745, 0.11013505995393762, 0.15060277355294074, 0.12877680601612215, 0.1944190498080946, 0.12794501073057615, 0.12976070805903406, 0.11950204764763195, 0.12468019680630778, 0.13264769507992652, 0.12751728852069186, 0.16526632461576693, 0.17502492113459497, 0.10879638259329143, 0.10945330298836194, 0.11424446283208747, 0.19213465222668266, 0.12950540159738835, 0.1866708058984049, 0.20449310601238282, 0.16193332120535836, 0.17140616692842978, 0.20373732963156319, 0.10583714582026006, 0.19201957049869722, 0.19316062781839602, 0.09377909809230797, 0.13070305749293298, 0.14582373322017733, 0.15347091481089592, 0.23195780242883393, 0.17863652007954736, 0.1491974158993652, 0.06059537146000132, 0.18509214383459863, 0.1673691900026414, 0.17224350102966832, 0.15915542510488342, 0.16919194300088192, 0.16450540012409612], [0.034012070691753785, 0.04286616252014234, 0.03493583100217004, 0.07573470142820189, 0.07258914441110627, 0.017896553186038812, 0.03920482914714564, 0.05865021293321925, 0.14500038788443612, 0.06123163046375398, 0.036251747890585856, 0.07107662637868235, 0.013796583723066556, 0.0980952451185834, 0.01276116514007651, 0.024616151687598998, 0.1704355335283664, 0.18819780299259772, 0.01766760589464778, 0.027240337991726496, 0.008922588707308375, 0.029993445402191534, 0.01248799159281677, 0.040048851195963166, 0.052147057252906026, 0.018392970500093316, 0.012846880802704443, 0.04496785962293225, 0.017496417802307877, 0.022963619595693967, 0.11617033126493616, 0.06126032045651829, 0.022685094924283125, 0.04062940794674139, 0.0021400331001308177, 0.02370113435561859, 0.05063323304057122, 0.09980942047531567, 0.02250497041630649, 0.0693062891162211, 0.016270705851756277, 0.027903595849150614, 0.09406861804065206, 0.1138275501228148, 3.8225684050590765, 19.386965690120576, 36.80518788676108, 59.98800377691946, 87.83452172433176, 79.11509283127324, 81.19505513098933, 67.4021267121838, 59.783828719969726, 44.171912900863155, 40.707102898628484, 36.14803006572109, 41.4493683076674, 34.362155314414736, 29.809532819255708, 40.9964757580911, 25.551788230096143, 23.889003338352328, 37.294315291989236, 39.218739924892304, 30.494843452207505, 26.137233357275687, 32.08655107405878, 25.246996533486154, 21.956990880350915, 20.356981562029933, 13.25682572780117, 6.7434393109813815, 5.133603965082477, 2.6728930252213634, 1.3732387125492098, 0.36832738247129226, 0.2158871776754818, 0.07697842219063351, 0.13309881361501832, 0.09129431489254199, 0.04813857113702163, 0.09945235455468779, 0.0576716696753377, 0.13930533622061053, 0.10004938985671728, 0.05726986038949221, 0.0785485270523256, 0.11655833947682574, 0.32084850113718744, 0.23725390614521122, 0.30012245199853377, 0.30671785615624925, 0.8629312438349571, 0.4716086904368093, 1.0773338810090096, 0.9934088263300158, 1.1270814244785616, 0.1317184304277743, 1.5126072663453318, 3.357126967560861, 2.781353424633703, 4.785952039303319, 7.529323437521535, 12.194691031209885, 16.00840860797513, 22.374493845047493, 26.599569013041837, 22.098200128924464, 29.549187460253318, 43.77629872291319, 42.63196291462068, 40.83770605825609, 40.104618995420395, 43.46784745493243, 42.530597102257516, 43.48459205319805, 37.4369679727862, 38.78357648849487, 37.103076211867794, 22.221795974239228, 31.942776595392537, 38.20593295558807, 35.1159603365006, 43.61671709245251, 49.40049902085335, 56.20475615224531, 58.057264128038966, 45.57381899126115, 33.05316625102874, 11.745099156133591, 4.738464884219631, 1.1375979117808805, 0.06374096678149316, 0.06542748636415889, 0.01916159609062297, 0.07269849580141806, 0.042674801417536316, 0.04272598758219712, 0.02386545446971732, 0.005752418242815522, 0.014539829778274702, 0.01321749881871285, 0.02360140311441595, 0.10985429639056807, 0.0488999514510074, 0.04083019576125568, 0.08741654635917756, 0.08132370354066934, 0.0382674707760734, 0.010792419723715755, 0.09832578395763714, 0.06910957305902435, 0.0443660898975307, 0.07994556499104347, 0.06597078825917936, 0.05608400224798149, 0.03328939313970266, 0.10003101906829304, 0.005359145570471282, 0.04598164292533071, 0.08526096646223338, 0.03682622573368492, 0.017925947979693452, 0.08089575150440778, 0.060974596473839016, 0.03404283295235327, 0.03050731611438096, 0.05640184446688622, 0.05402398798915167, 0.039287478542856635, 0.02548484368279817, 0.013912796388350189, 0.04129656710691991, 0.01302280140319659, 0.008299846367369737, 0.05695380315545106, 0.041287251477760654, 0.016694540165424827, 0.07278520929356737, 0.04647127270037609, 0.050946689406109434, 0.02819996653875757, 0.019647134956152692, 0.07371406025824047, 0.020508483998597633, 0.05009872583492149, 0.06045451087336387, 0.03709624874435606, 0.03712394665325842, 0.03948497600973614, 0.028480477293112108, 0.0280875412206496, 0.024741430045856584, 0.04178924591190392, 0.007977958246614904, 0.02340895033651783, 0.07222533691674471, 0.04298500957027559, 0.04049701263166724, 0.03604499225114142, 0.029805177379579797, 0.142964800339072, 0.058092129371699795, 0.010053112318048315, 0.04905022342779464, 0.08920977432881633, 0.03185502182121479, 0.03531212956013699, 0.04577348534498484, 0.017990452582917867, 0.016294429679551435, 0.021170487387045737, 0.05908061262039889, 0.1195744352955972, 0.01869469997473061, 0.05073930940500671, 0.03012085156965881, 0.06934473140826149, 0.18272657157672992, 0.21567982831789603, 5.495558323398714, 25.793474874188824, 44.38103014423002, 73.02653881811327, 98.47347228757798, 90.79483647500315, 93.77362558918615, 81.9977838762345, 68.01086287344656, 56.83378273440946, 52.541595812766786, 46.91721900816887, 48.76653809701243, 34.22576665878296, 32.96153576143327, 49.91897752208095, 30.747275429387248, 27.36823001215535, 28.0424815224063, 43.2325013222233, 39.89912209972259, 33.02017519550939, 28.458352781111195, 20.51376654255775, 19.134394468799716, 16.711422858699677, 9.275828869112077, 5.246752087147006, 4.6819410785552, 2.3168062875347757, 1.584960777432688, 0.47537698500579406, 0.1845635431668451, 0.09778535489233271, 0.14446392715457948, 0.030913105226993084, 0.031266007459752505, 0.08273122156219137, 0.042342583558732466, 0.05380977448376437, 0.125623534493629, 0.07020706295846932, 0.11214435536174044, 0.08821448821934962, 0.20327334081934345, 0.2640860744061009, 0.36147313252572094, 0.3437209754220901, 0.6206610858921082, 0.5114458140826995, 0.9620811009118635, 0.5334142739734342, 0.806135262452787, 0.263653694381637, 1.2994328213314856, 2.8124492399154173, 2.7265456559196597, 4.368437307496225, 7.548664154544954, 9.796617646371166, 14.10485294557387, 17.53639732637713, 22.268274099596088, 21.32518137654951, 26.8512047490766, 33.36904648811587, 30.36365193705405, 34.96632583679692, 27.443021766601074, 30.71296253511983, 34.53115455565914, 29.65350485617115, 30.014917927403605, 37.88256883621216, 47.62375162493798, 29.074323754156794, 43.051499628251605, 48.54176275191769, 46.165881156921394, 55.59025410682925, 62.311113803617424, 67.30608355614447, 70.10993496064218, 54.19833829326015, 37.74057903597432, 14.429335921041428, 5.737086111499417, 1.0901069569010888, 0.009929837279712722, 0.06289213370051115, 0.052234337650119304, 0.03460049899595399, 0.03618161254111798, 0.06348009086063792, 0.06663569895130012, 0.12366486217586264, 0.0315815169409278, 0.028802663230547504, 0.003175001127660395, 0.08449026668864874, 0.0514818286342967, 0.04897217822050856, 0.0438417180351192, 0.06119402703799068, 0.035893720529612996, 0.04571585255044122, 0.09395913641539314, 0.017807028151207396, 0.005468766049166481, 0.06318358419042441, 0.016849067760631442, 0.060440261637972253, 0.018687276582744335, 0.03469161749366791, 0.011926868577457726, 0.07750175983434723, 0.0360131498065687, 0.0317974120093089, 0.062493135957347776, 0.03742024264929276, 0.024507074173720136, 0.03895458652667942, 0.017587756550300027, 0.043722828850150115, 0.009127508608564254, 0.04486102483145172, 0.009829384000641445, 0.018908133985654964, 0.029034309066651814, 0.025531247543591647, 0.06652658504824485, 0.05721884276417475, 0.1400580022844576, 0.10074238533214216, 0.11038514169593973, 0.16082558871036576, 0.17093686146601555, 0.13343938566263647, 0.06979938160868422, 0.12176262755547801, 0.208573428192927, 0.15221609343444148, 0.11777339322913079, 0.26267368406538044, 0.17231056436655984, 0.23779836483299735, 0.14868568448770433, 0.13851762929510686, 0.29623265588475817, 0.2928855871000598, 0.1769568110185285, 0.2085301289034467, 0.14005904416403464, 0.18654112253458272, 0.06163955696167485, 0.09438220847157702, 0.08748250652945812, 0.3014045461050926, 0.09888678248370848, 0.10458728869355495, 0.33120836942426624, 0.19586560767023795, 0.1689305538011174, 0.15618260559295455, 0.14472962176847845, 0.08536710028326319, 0.052788146441021276, 0.1059200365336672, 0.15048003094571252, 0.2443913175093551, 0.23725833413341355, 0.32314520209066333, 0.11894780601705275, 0.2336727515343697, 0.20604170678604036, 0.40501444450309204, 7.952208874687073, 33.911533817168205, 55.180872409574455, 80.76735204265964, 111.07142709916639, 100.73763693532636, 102.07590256967853, 86.1832352607481, 74.07494914147162, 58.37676079042497, 54.70980751898981, 50.81497238528345, 55.12732813435217, 46.82087775199644, 42.13766190313524, 56.09709493575558, 38.52342920918619, 34.97139353905955, 55.205653944323146, 54.3410772662009, 41.55597832895095, 36.70493994989703, 41.709950970065215, 34.86639561191682, 28.70840584078143, 26.164132971917432, 16.957049523630452, 9.031012173621885, 6.6263805858550535, 3.7795652545267537, 2.0345596392308516, 0.7420686163729238, 0.46504025257402853, 0.35336807550441834, 0.163202315208412, 0.1796293393858979, 0.1344544215187911, 0.1556189027765105, 0.16445853086488862, 0.31678017589353746, 0.3145293789284845, 0.21859566621001691, 0.28171167378464057, 0.26898293906161863, 0.5193328424807518, 0.44193513270828033, 0.5505018344809932, 0.5757669852145257, 1.0285932835071319, 0.634395019902337, 1.5601256778163295, 1.2585573114695088, 1.9469825514862615, 0.3369471340650513, 2.2380691189919752, 3.8572526987521885, 4.067309594923451, 6.685114647111585, 9.83278484113755, 15.263960399935323, 20.509583334768973, 27.99422852454647, 34.66486423246322, 32.281908642861154, 38.85699933575046, 55.425298829232496, 56.800540647199085, 55.94114542007447, 57.59329872746622, 59.33766303523895, 56.164630305382516, 56.43057877017606, 47.248674977210264, 51.65392814144012, 49.014906498693655, 34.75810681619952, 47.72000266659645, 52.88045329432334, 50.07601353429979, 61.13597562236171, 71.05462997190415, 77.38430776903706, 81.2428923576109, 65.56455512200633, 49.054859761268865, 21.364193270283362, 9.74233792674157, 2.207738656190134, 0.2204437001097587, 0.20163570530712607, 0.19912246194097305, 0.1466333655820739, 0.0929981557231757, 0.13904316561116328, 0.0715011386801639, 0.1816785786180727, 0.11173408463477127, 0.13063099926277516, 0.11702011429494429, 0.17220971655220757, 0.158416410727847, 0.1832808668334638, 0.10389870588457394, 0.18316330298060374, 0.17040763260616412, 0.11244532832455252, 0.1640170343941258, 0.10546166314593247, 0.19585014801592598, 0.2209343181382264, 0.17902783779126985, 0.13611001413195364, 0.1442604542018906, 0.2521309046255004, 0.09326727475009619, 0.2406229769750949, 0.12008847263191016, 0.1291287621302951, 0.14045871223413176, 0.18157169403087708, 0.17711100919592768, 0.16624670265422714, 0.10737167355874855, 0.15230639987895567, 0.08735705963185719, 0.11181724347895193, 0.07504772740386187, 0.175220258233528, 0.12962512581819488, 0.18756637800364725, 0.1497710625370664, 0.166974057173056], [0.02437811093254676, 0.0692259494756018, 0.027344669590914444, 0.03235369334898649, 0.0698127651647214, 0.029341931672646638, 0.0034931916771681923, 0.04851100095097096, 0.06724627102695166, 0.11315030541511313, 0.027817399466350198, 0.06026927464371247, 0.044554804166358326, 0.10499605022731329, 0.04467710244259046, 0.03443523467848859, 0.027887894877142487, 0.06141451097303822, 0.03209211071202111, 0.03764500135495778, 0.09107532099850717, 0.03789259714164561, 0.021240073068427946, 0.023374725358500596, 0.07267725984415702, 0.08367656639987424, 0.08478671207182831, 0.05951323779299856, 0.01527160558203656, 0.09348421552849394, 0.037379268436662616, 0.04047634357947015, 0.022192804908920682, 0.026464419244157694, 0.024056781098366748, 0.04806797996523881, 0.05796199784644189, 0.02291567015251325, 0.05331834057165731, 0.0227655207497939, 0.0313651756263308, 0.048435449359878424, 0.4252865099378171, 5.439448818083733, 26.47651053244068, 54.91057011388964, 71.23038353458529, 83.43666615024691, 78.83121521242204, 71.5374658953759, 60.98483101014168, 45.47385738741967, 41.99635851767756, 33.26192263633975, 37.27547222568143, 38.54179374633297, 31.419355907747825, 44.152085319642104, 37.59378040990522, 34.69376425589285, 43.10167458749587, 60.17126475611041, 48.39727832425026, 37.78564706925423, 35.40325433977189, 25.026398512624926, 21.237353624836093, 18.368377147182343, 11.577005982398989, 3.8349103879544044, 2.6937046310594006, 1.506261361702796, 0.2487891371692381, 0.27552229622679375, 0.3324323021356137, 0.14520159321686915, 0.0685992052838687, 0.06749817605821357, 0.1152063015427801, 0.020075749658468752, 0.09541257374709654, 0.14021076021655915, 0.023646571658431523, 0.016001625129232006, 0.05623715854580364, 0.056454792633772864, 0.04568352747047621, 0.024354984653332544, 0.03220993311955564, 0.11195363777299082, 0.14260570428544475, 0.1960487792929334, 0.10168219901501171, 0.11711815822749369, 0.032074852666306886, 0.04364348129339276, 0.13594723576980253, 0.3841858621566527, 0.18793791532516482, 0.22198804143455722, 0.5383727014545472, 1.1579007126631276, 1.3555868210331088, 1.8185123032139194, 2.909340363356375, 7.929118862075191, 8.151343685965385, 16.221725729203996, 27.113740751820227, 38.17820179846979, 50.269488365419456, 49.03859369216427, 71.25656143311532, 83.39965466530093, 95.23554002085041, 117.687634037387, 113.1079452268539, 74.41758386550411, 37.960780897448146, 30.06893877060183, 28.742091155821278, 22.49884278543534, 29.622714250318467, 40.17033046291721, 46.42255713862758, 51.36773240181708, 61.10667159480434, 55.786960970970895, 45.66645360762074, 32.79669423257151, 15.376587337063206, 4.506398343270825, 1.4768171094117628, 0.13137597380386246, 0.018773746841977683, 0.042586023318431074, 0.073401810481183, 0.03593693554942166, 0.032928577218685424, 0.09263332167099561, 0.06175313715732867, 0.03149595449588472, 0.022158020686718728, 0.06672454216787893, 0.011796986030775213, 0.0805460247060945, 0.012325400922207103, 0.03009198346145211, 0.04757684865786184, 0.049265934635073914, 0.04579777416262416, 0.06495595924676427, 0.010914809930498802, 0.05833219451409194, 0.013853302957760471, 0.02224060304973635, 0.05881745758796892, 0.09960227030059023, 0.015724725521830542, 0.01589476735511374, 0.022061439982104688, 0.08577930921268079, 0.018632099099998033, 0.025688218959276716, 0.03726495279660148, 0.04194451278195747, 0.0456009661748765, 0.04638646676715824, 0.021838171317452387, 0.044230228034599174, 0.04073017532186162, 0.02972365413311749, 0.038101478675079924, 0.021590701935272065, 0.03468768363217673, 0.011948468426482813, 0.027006911001198237, 0.09629752021282913, 0.05666577324811971, 0.025186101951065566, 0.05488330881381708, 0.053258424835099336, 0.05330046390994422, 0.023901927915792313, 0.04857307322503579, 0.07808862914962154, 0.04066835202637219, 0.052393657125292294, 0.04949031412721642, 0.0803494388838449, 0.07051051804615606, 0.015445050760923375, 0.09432479784253145, 0.05247202408950656, 0.03550189719986051, 0.026780221753964023, 0.04125288860391706, 0.014384785073719198, 0.08203418880340554, 0.03760155267833221, 0.017395370805095282, 0.08350878548357757, 0.02007473267674927, 0.09818804900973074, 0.02681826184984417, 0.028462160130842563, 0.02513181313031143, 0.0405290236155833, 0.053740861044535716, 0.01477469318366099, 0.04298158898769368, 0.01247325493398333, 0.03656565241755978, 0.04350626728527489, 0.0663180559152557, 0.018115750093373562, 0.07666391245419941, 0.00638963054722896, 0.4205649568428917, 6.863186820860832, 31.52996870779222, 59.51024732282085, 81.63893407390964, 90.83821004436862, 86.36378980452015, 80.50403548825173, 71.07967822782456, 55.53493692028908, 53.58273798419584, 41.061096806680005, 41.03660944969424, 46.87124882974933, 44.596736969486365, 54.54234584685295, 40.15060878569081, 32.82900279568088, 28.81557676099962, 36.090026055612874, 49.17535497296242, 45.825937178827104, 26.46478460681054, 19.92692897396703, 17.765854020272535, 11.67651161070793, 6.127840472805885, 3.143662267154263, 1.9592393454044097, 1.4412686685400626, 0.44845202817551555, 0.4068442914755114, 0.40358366805218887, 0.15607037371204746, 0.1764597731732553, 0.10409189027643974, 0.11595159017991637, 0.14109412088028847, 0.10115930570229408, 0.09312958576746526, 0.0893924096899648, 0.1145609260927285, 0.0571355575154866, 0.19863196648657325, 0.22185224468909928, 0.06714621994404063, 0.03811167913579172, 0.1185932145604203, 0.3159758448600769, 0.3457672881983942, 0.1301459889979132, 0.425584763288498, 0.19064968271601587, 0.09822106739926724, 0.12358699699923878, 0.3430052041526764, 0.17255732128697057, 0.24397145536157394, 0.6076118506250844, 1.1720750552992667, 1.2893197252865762, 2.138257790957728, 2.9314593442024726, 5.94780074011895, 7.341935634613038, 13.809837756618379, 21.55399480173665, 27.354499755367158, 34.61363807801278, 33.504105460259225, 54.851965981145064, 74.5643981810539, 88.91010622824393, 102.52757133976107, 96.75652534730973, 69.45083556636688, 42.75907124242475, 34.424034626253196, 36.33800614264704, 32.647740264092725, 37.57601207302463, 45.85351928587883, 55.54495465370917, 60.023207049216, 69.0991872356784, 64.53493687414354, 53.78306519600653, 36.93809740005001, 16.767455877796298, 5.031017805299451, 1.2111640481218215, 0.1006659527399367, 0.01224800880487648, 0.020392810467690713, 0.06782485127088524, 0.04735086421151796, 0.01959539912340622, 0.044148333235493595, 0.019375771291614063, 0.017660000556779486, 0.04610129053734484, 0.028737359980662024, 0.08758267252555779, 0.045949555332622224, 0.011373763629836182, 0.06400476915821915, 0.017246822526137677, 0.017778979757079677, 0.1510123088355026, 0.08475878050610905, 0.04678780873936992, 0.08225283795787443, 0.01976471604599107, 0.045356465383402766, 0.05204685678284976, 0.033612368147700064, 0.02779489946401408, 0.024257471236670693, 0.04474822604548066, 0.08764938346200413, 0.06366097571087942, 0.045332429374778466, 0.08132479138552182, 0.019254472760123112, 0.04429479009441791, 0.020136747494219773, 0.06985763493444651, 0.0229792324675908, 0.023585958781862454, 0.02281206633685337, 0.06531261147991305, 0.034461450207257466, 0.03837849223806012, 0.06079024890617979, 0.05235748245350776, 0.24607709398673427, 0.0966354875615047, 0.13206755201662743, 0.15133201264806334, 0.1105440819575902, 0.12408331472186312, 0.1727462998561321, 0.1094866048304304, 0.2229591957744091, 0.11210294830943308, 0.15390084335400214, 0.20263158896517372, 0.23068733753696566, 0.12685710459106392, 0.054457566941217075, 0.27088112107688384, 0.1850372459739447, 0.24020630175307875, 0.18070239874143756, 0.18029131596126866, 0.14754468845503946, 0.12828956643540051, 0.1840217964303109, 0.15477326428217275, 0.2574718551289651, 0.12673774043158179, 0.18808261401230292, 0.14809466297588042, 0.13355429885127854, 0.21282529278147608, 0.18897055588181944, 0.28940200144725464, 0.09023038730505975, 0.1686847161862158, 0.2264607232064009, 0.11483886279165746, 0.12316855211411754, 0.16446718765843302, 0.13390509051180657, 0.12969531479381746, 0.07558329947172635, 1.0940689184973318, 10.65358296517403, 41.24900187215498, 71.22883027599704, 97.15774459223594, 104.53435790154242, 96.89568319628316, 87.67682675392398, 79.76600231662874, 61.2776477106156, 57.051384064459036, 46.49920417416481, 50.83279563534645, 50.49921374167166, 44.9499777824648, 56.28745148258825, 48.03626337359029, 47.53255651843163, 60.248853160489, 78.38524172382971, 65.03367408629387, 50.57460561875374, 45.3961395448254, 33.5103577183139, 27.756942779787128, 22.87438423402848, 14.497896009875884, 5.1787906500601, 4.114967373109633, 2.1058700450005072, 0.7247734153943678, 0.3978700310953202, 0.40957328052290026, 0.2823949629260648, 0.20457136955472732, 0.19304176161606468, 0.25474164034089736, 0.2336992734983083, 0.21779813803732398, 0.27630165279392277, 0.2091381575671896, 0.2223658300335369, 0.28512600508909075, 0.36339491004905394, 0.3003010117719251, 0.3430551224418225, 0.13014739859969388, 0.30537545560829105, 0.44360088364731887, 0.5110065392669171, 0.2292400289086565, 0.38675001972625334, 0.24403600593007382, 0.0956401861302795, 0.29843347327363107, 0.6090832910230083, 0.26130762672232044, 0.6349204336443256, 0.9305847135763016, 1.6710614605296044, 2.3030779919316693, 2.5268764217053694, 3.939934055651388, 9.788717992844122, 11.99118277718944, 21.93128170505647, 33.43327137731737, 49.569470805506555, 62.21199943173317, 61.65772538031302, 87.21608161926271, 92.88146680401218, 103.18804356359668, 122.78407158390169, 120.05478443637972, 83.18094330449259, 50.07846893802766, 43.27368228666244, 43.28983460703204, 36.86764378701487, 44.46075231798234, 55.65755805661602, 64.49567394871866, 68.78048681443738, 79.67160655606179, 76.55558939903014, 65.76482742063462, 49.65289177433137, 24.433620514408236, 7.208853537036527, 2.5541327268846574, 0.5116524126741194, 0.10732115772102149, 0.09178408256341374, 0.2261352277691326, 0.13419119370800836, 0.11357409759394585, 0.15264450512345762, 0.24780036280712775, 0.13199475834206228, 0.19617313068480263, 0.15842744239395665, 0.20563627773475265, 0.23999807905525933, 0.07393943566468454, 0.16940419532118306, 0.16131441409309066, 0.11622732054562339, 0.18441951863708037, 0.22886052427272643, 0.11715991768024622, 0.21033025166440397, 0.13100428326476005, 0.15612085890625754, 0.13496947775204338, 0.19857889191517908, 0.13290637232843908, 0.12675676239474168, 0.11188949323109082, 0.1650613960960219, 0.1254025181274741, 0.09794652446984284, 0.13122641811928443, 0.13571357895289698, 0.103935907114177, 0.13315492189459263, 0.1653178057242786, 0.09102894203557123, 0.15848102258338084, 0.1986688306374896, 0.16000607381424597, 0.09855050052846633, 0.13866361500995775, 0.14133549986347077], [0.09500036481767894, 0.03427162894137925, 0.04165757454991822, 0.02232986186901408, 0.016897172336616827, 0.02004037171812548, 0.018217580415488734, 0.03541671588355976, 0.016655745472939267, 0.034340822002700264, 0.035793179150430426, 0.017259321250622312, 0.07381109295472985, 0.015004932290814338, 0.1028995127266934, 0.08896555315943495, 0.024531175299818, 0.0453866109432232, 0.03665130104749434, 0.03846739291123325, 0.07167943798366093, 0.07817521240682372, 0.09599447115174226, 0.0930159825891737, 0.08772709542104314, 0.04294459460183017, 0.06238432082858297, 0.11797066086963301, 0.02018634019599807, 0.07327689984512907, 0.08956007569307282, 0.06563210844873421, 0.008132506909239437, 0.07145916472279257, 0.09661602126734872, 0.023634067188287457, 0.015046951255851216, 0.08493639799135347, 0.08161822604315896, 0.05220999520632529, 0.12048794151914698, 1.3068446300683485, 12.408085619249652, 34.55540657043457, 62.270964422533595, 77.76767238493889, 80.78997627381356, 75.09583227096066, 63.42999735186177, 54.90303524078862, 51.22150644179314, 39.96824210689914, 33.36523394430838, 43.09974085900092, 36.865961090210945, 28.69036489917386, 27.11810438863693, 33.151201971115604, 57.27748909304219, 71.58411072146508, 56.247211886990456, 56.56973661914949, 38.61941745204311, 21.376040789388842, 22.159036090297086, 9.978001771434661, 5.866363510008782, 3.8170042778215105, 2.06845308503797, 1.2294726914936498, 0.4512110785130532, 0.11207070366870012, 0.35261969953294725, 0.1512372935371053, 0.22872498799716273, 0.03455370251509932, 0.034613181581540454, 0.11853190454384012, 0.13469235310631414, 0.07282450194320372, 0.06779744830583373, 0.042266131814328894, 0.02300984342582524, 0.0432888362106056, 0.016221387026410912, 0.21647174872698324, 0.07120827092759072, 0.07073698129745261, 0.06478804043464123, 0.030360409178801125, 0.15104793192398164, 0.2510766144241056, 0.41017116618252575, 0.23905087262392047, 0.20946330060401272, 0.20328803438573115, 0.14418530097651866, 0.08403342547676257, 0.126717806823792, 0.1347081345175543, 0.18604868121685522, 0.16547229501508898, 0.2806999474283188, 0.47473065194583713, 0.5276251620342655, 1.0944214415165687, 3.0278447270393376, 4.056763567270772, 6.148004887565491, 12.369955278212025, 18.639197195729903, 27.960621656910067, 37.78762394382108, 54.63130912473125, 59.78252649307252, 61.105789061515566, 62.60363240395824, 52.640847467607074, 41.2903554208817, 22.249744822902066, 21.033582572014105, 28.971763580076157, 26.87052634454543, 32.07883773311492, 34.84315164627568, 47.8410783890755, 62.86217151149627, 58.752115926434925, 61.23931830929172, 49.37676868131084, 28.516511724841212, 14.890101648146107, 3.397731588732812, 0.547097094597355, 0.1376409335963188, 0.012899962077367932, 0.02508917267644598, 0.07213733639688262, 0.07808971699447402, 0.01948917911748492, 0.015478678190359666, 0.04452841626780649, 0.09587236439749118, 0.052093729872496865, 0.05507603738336794, 0.06512324220591015, 0.06335656301328732, 0.0122190190802118, 0.027380407592582128, 0.060025241165872545, 0.059934884925643285, 0.10307227321449788, 0.06095755867840302, 0.05465792191605415, 0.03409110415246218, 0.17616985485919062, 0.0415682640197056, 0.017991130570730856, 0.03677495529935245, 0.03998244669468653, 0.03453284577136079, 0.010210517531020508, 0.050533400292718605, 0.014231810721779063, 0.05689664150498087, 0.027890070566847443, 0.008718593857221065, 0.053848316367234916, 0.08605749872062476, 0.07301396314775752, 0.067288497793338, 0.010930197764067881, 0.09627314329507852, 0.03242328094558851, 0.01474592179405473, 0.0354666380031455, 0.09430808180402364, 0.004359297886220438, 0.027821873419827996, 0.03956601662080615, 0.02423998336457918, 0.08790574712498535, 0.06228052357572222, 0.04233006568204972, 0.0056503609671527824, 0.0033943589134592445, 0.03208772868909423, 0.038023533059224006, 0.01667176628665578, 0.07173120254470457, 0.015141420430623958, 0.07992327949332614, 0.03433182046958997, 0.05285053281113506, 0.018994309301037463, 0.05745523451496998, 0.027281800585408366, 0.048242487133510654, 0.05563509770699086, 0.09342028549121273, 0.06165266855649891, 0.02272189587294575, 0.06124154747193379, 0.11565169740107753, 0.05767434715263306, 0.08943345668094774, 0.03465710140223946, 0.032394564139746854, 0.05533331652141868, 0.03776012521777903, 0.029190782525186098, 0.07165932051476932, 0.011631323347589182, 0.08285653822484516, 0.03527850979157994, 0.10442693116924456, 0.12328228552735622, 1.2138077256179627, 15.376988399413326, 38.367177671001805, 68.55799428878292, 89.82181410635673, 93.56970156392744, 87.99096938102477, 76.81678787354501, 65.38276110925983, 66.66366207984187, 49.865095923023844, 41.83669059507309, 48.124410798472745, 44.73696170314666, 34.25013242229339, 31.148816308667584, 30.875786004527924, 42.764648852809785, 57.628180365408625, 63.07984736657912, 70.03999125572943, 40.260152739863244, 21.829078466661517, 17.438473393840177, 9.792117707190975, 4.982746666477573, 2.8125661755761793, 1.7890321367209958, 0.8812581507429, 0.35797946515583223, 0.1798511371617356, 0.2828992939283771, 0.17402231122457212, 0.42389186219342295, 0.08660880623445397, 0.20832207474497058, 0.07481960174176963, 0.540735561761164, 0.4650699767854906, 0.2461781103404299, 0.42632229145496126, 0.026581421937613238, 0.08441117577134602, 0.04234813003530426, 0.0722295580612075, 0.2195931892962225, 0.410196477727544, 0.28858225672475757, 0.5120934954574031, 0.3861035947357455, 0.5748854938053316, 1.167995912894126, 0.6557288525565979, 0.9440149090463116, 0.5307693707366143, 0.31224594661785715, 0.1465302041821903, 0.08798137532487031, 0.19238956032260773, 0.1622788728244843, 0.21895709117093395, 0.18082998302434722, 0.1037623039296558, 0.25417502639034106, 1.0462222536725383, 2.6107582690254336, 4.292734092281711, 6.506891462110705, 11.932633557627279, 17.287342509915753, 27.624080334940267, 44.00978565216065, 61.53367650124335, 71.51637138858919, 75.72679258161976, 75.94313483084403, 67.52374372174664, 50.365551133309644, 30.5592115079203, 31.23877194619948, 33.02472906727945, 33.16160017444242, 41.83645133049258, 42.77184640207599, 56.001793107678814, 71.16518589758104, 67.38529189940422, 68.29004933757167, 57.231950375341604, 32.83460394028695, 17.742812056695264, 4.125634258793247, 0.6304436609629662, 0.11791399334587398, 0.05740393726756016, 0.037067236994663556, 0.08567347416594144, 0.05882822112330507, 0.07279520674097924, 0.059684764879244956, 0.05596833063229438, 0.04514567246059737, 0.028579319872322585, 0.019996633843308496, 0.06461710323609653, 0.05922029726207257, 0.01714368985455123, 0.03461468694431167, 0.06168913434169466, 0.0775316219416357, 0.01855389109902805, 0.024887944361375227, 0.044389792657907934, 0.0537909708556629, 0.10337039633023162, 0.030105688774417487, 0.05186125666143433, 0.10195880272095242, 0.01746239583759058, 0.09836729826225389, 0.1319309738614867, 0.07485205322624215, 0.07338172365580836, 0.028966878007556644, 0.05988350340856179, 0.027934787118987694, 0.048889505842159835, 0.034507951744261293, 0.04223382205612237, 0.03693747319160931, 0.05647742670149573, 0.009828049092433386, 0.048715803066208485, 0.06005463212908757, 0.032883987071052674, 0.21070214138636667, 0.17547885887324813, 0.1299802075710989, 0.13920648023486137, 0.13800381412429197, 0.19393028571240364, 0.13819800209133856, 0.13018173466046012, 0.12867427280833646, 0.09244265004752145, 0.13307878807667764, 0.08047000580136815, 0.19391769122692848, 0.14951120551315047, 0.15936827497376552, 0.30443200300778117, 0.1113492250442505, 0.24434522965983038, 0.16153884721138786, 0.19268177690044527, 0.17330338367291037, 0.16787709097468084, 0.16255225896114306, 0.18883074483563825, 0.18162032529231042, 0.22234257160415574, 0.18585743502743785, 0.20598248818949347, 0.1492666242824447, 0.15888829024568682, 0.18096711276279343, 0.12879787343403987, 0.11390088771980618, 0.28686107166351815, 0.16833708080793583, 0.14994720147261698, 0.08626286391048663, 0.30898339265296537, 0.15704047085056383, 0.27573064149868104, 0.3124399813673189, 2.9775763663553425, 20.59705807316688, 49.097774413324174, 82.07692161683114, 102.81486142066218, 102.39148862900274, 94.82848428910779, 81.66206821318596, 69.86579879637688, 66.43457997229793, 53.26843453991798, 45.23955460517637, 56.249082857562655, 48.06619498037523, 41.592621111100726, 36.98285164371614, 44.442026922779704, 78.45041582661291, 91.510786702556, 69.5074353679534, 65.59051336780672, 46.598534276408536, 29.289299057376002, 28.435224525390137, 13.548316667156836, 7.663330233866169, 5.396264503079077, 2.4959039159359473, 2.0063788804315754, 0.7612244917019722, 0.3958421963597498, 0.5318013831011711, 0.3228109426075413, 0.5505572379596773, 0.1622102007029518, 0.21719384788265153, 0.7871815117616808, 0.3116591232678583, 0.44323910628595664, 0.27344215300775343, 0.36863948669164415, 0.2184955998053474, 0.3228471632446012, 0.1004296375979339, 0.28854070411574456, 0.3648224382871582, 0.5327169501012372, 0.3726475667809287, 0.47519854780647064, 0.4146083474399582, 0.6337407808150015, 1.326246266403506, 0.6852133704289314, 0.7847066187570173, 0.5954863948206748, 0.329758440775256, 0.2172973616829803, 0.3748211114396972, 0.3192666827911331, 0.46320669773605566, 0.36339904692384506, 0.5229318622619875, 0.6953712672956529, 0.8200966939330102, 1.42239177178952, 4.0154107539884505, 4.971437982974514, 8.856265679482492, 15.056922012759795, 23.782560017801103, 34.74294685548352, 45.50473820778632, 63.41005209953555, 69.89219634763657, 72.80672134891634, 72.95128422398722, 64.7623166730327, 54.67732637159286, 34.210261529491795, 34.400025798428445, 42.571676085072184, 40.767009258270264, 48.185862571962424, 49.48548501537692, 65.13467119586083, 81.00326691904377, 76.38425242516303, 79.83472224204772, 67.97187451393374, 43.17441886471164, 24.686956597912697, 5.847097318018637, 1.0406962469700844, 0.3124407168117262, 0.209447565158048, 0.09685591403995791, 0.16638547182083133, 0.13056562131931707, 0.1091289796656178, 0.11526170502146406, 0.11974184848969022, 0.22263377694593323, 0.14126619954984035, 0.11077883428022747, 0.22845719430235126, 0.1358943450595102, 0.20493693139043548, 0.11390497862932183, 0.1782025312704425, 0.17070291353569877, 0.21567970574382814, 0.13930103080647607, 0.19738828402853784, 0.1400195906359342, 0.27384168318202423, 0.17481898137878987, 0.12389999754246205, 0.27119849598215473, 0.09318478240240967, 0.1090528611694613, 0.2959551175515498, 0.1484800052017935, 0.20968983280322245, 0.18846585715730346, 0.1726950638957562, 0.1042286905970785, 0.11445157470241671, 0.21014349475022287, 0.18092059590403112, 0.12278840396433108, 0.22699600416085414, 0.209828203604106, 0.10960974580337925, 0.11825391421875647, 0.22327416516359777], [0.1104297356740121, 0.07166891193558132, 0.057864528479835683, 0.0528000514473646, 0.034013250467157176, 0.014416073062156719, 0.06567975145674522, 0.016554137316322135, 0.025291069403230667, 0.06746570159110331, 0.047032753861839735, 0.060107082338823434, 0.05022281675689644, 0.04698542111943807, 0.009848921157930408, 0.03710524261658711, 0.024250687528101188, 0.011320654584485437, 0.011917614235332417, 0.042043985468485666, 0.04886594480804859, 0.048306811706072865, 0.015753928793504113, 0.0638867111786479, 0.06353536027393515, 0.045716844634303165, 0.055295521573674296, 0.014833320934896269, 0.01397884657396184, 0.06286903231915447, 0.040160405089057265, 0.03905212867163843, 0.05404204851196659, 0.06593021624270948, 0.06714982821816398, 0.0382175371651688, 0.08962189898856225, 0.019425747037354498, 0.0638714277245585, 0.19536208872112537, 2.4525242178670825, 6.578638476710166, 31.413352720199097, 69.6803020661877, 72.6510581662578, 74.37944273794852, 62.91544906554684, 59.959582282650864, 52.5251297027834, 46.21780549326251, 32.27158888693779, 36.94067047488305, 47.20651342022804, 48.01482762059858, 52.970169667274725, 74.39479489480296, 78.53126372060468, 84.8590587800549, 71.37546416251891, 49.54162982202346, 29.933287520562452, 14.278778683754707, 15.36056249372421, 10.972102957387126, 4.194166400740224, 1.9402931943055124, 1.4087178990725548, 0.5617374025525586, 0.20629318280806466, 0.08481088214583936, 0.04771009433053194, 0.3412459598433587, 0.056598882281011155, 0.0837183871396607, 0.3236350693529652, 0.21567883240359448, 0.253875348116121, 0.3424173695666175, 1.0233465005313198, 0.6139715448502572, 0.45094996510494145, 0.18350959004413697, 0.08941086474806072, 0.06530708032509973, 0.023171987850219015, 0.3066868755605913, 0.24467496922419918, 0.21024498607843153, 0.2057873043081453, 0.37567343022073474, 0.7129349667699106, 0.881990775946648, 0.5797082930803299, 1.0144202891857395, 1.0977507983484576, 0.49193710929924445, 0.5020985301704176, 0.29894883594205307, 0.18769757822155955, 0.19425849310092388, 0.20365615495510642, 0.3369606784995525, 0.09788109290023005, 0.06472095411511199, 0.08118307278040918, 0.03890403238455615, 0.17075119239668693, 0.46743329674486195, 1.587918612264818, 2.149593685903857, 4.6648964189714, 8.91885886269231, 17.42838505775698, 27.15070712950922, 30.172371672045802, 33.81933458389775, 29.48375055866857, 24.18728586166136, 25.349352744317827, 22.445898632849417, 24.761711089841782, 29.118095444094752, 23.61896384146906, 18.870367965390606, 33.43258888490739, 47.21569568880143, 50.71425376399871, 53.8033595392781, 64.12782622921851, 66.39588971291819, 45.541683012439364, 27.382444681659823, 7.651112541075676, 2.5597951585246674, 0.12572905544431942, 0.0332517973748186, 0.09656257131287167, 0.04002323704621485, 0.025386839969864777, 0.059974372927700324, 0.019447459884348418, 0.06332077904634419, 0.050660268283419074, 0.025846900666252743, 0.018123225196294727, 0.021798683315395348, 0.03437290576496913, 0.054760658137139775, 0.015701517845774372, 0.014606451656999848, 0.034740562851150195, 0.03423973287065183, 0.09411068392857429, 0.034434767364854776, 0.020999711066965136, 0.029189447616978042, 0.025330896399194197, 0.0654192739016106, 0.015919603925618916, 0.031339421665536306, 0.015717176682946664, 0.027937910842498945, 0.06419725257963424, 0.015124986887038236, 0.07017241280165411, 0.048247072169737476, 0.01738317851578036, 0.06263101263152016, 0.050208797347882105, 0.035438545558962135, 0.016440553290228692, 0.009918262648786749, 0.03515837188329428, 0.07099829388842469, 0.02708907776151694, 0.006319392254696258, 0.05656169637316658, 0.024071254414476217, 0.023703308130103736, 0.09862198419268094, 0.012531640409912555, 0.04427710112424628, 0.06660304828396728, 0.17786401233846144, 0.14044224134375974, 0.07941285043113655, 0.027218236355111006, 0.0109852172411798, 0.010437117720533524, 0.03925529135871799, 0.05630671549888869, 0.007231021562831537, 0.02467463675495838, 0.06058117968120402, 0.03227735651777156, 0.0588444966612564, 0.07532156553239593, 0.03576767608343113, 0.04389558550751498, 0.04250417448460095, 0.030968970273651426, 0.038879839327907374, 0.06321649149721188, 0.029639302106994777, 0.03084385279385794, 0.020747007389042168, 0.021258405552455978, 0.10879491936535605, 0.05954241425159478, 0.02679548605585531, 0.05581001090186258, 0.05137973592706746, 0.06803875834110283, 0.024985452032377644, 0.04682715118472134, 0.2276454015725082, 2.304745979847447, 8.59606642876902, 37.98807274910712, 75.7134251440725, 82.11206605357509, 83.28410948476484, 74.41312020824802, 70.1030158996582, 62.203931116288715, 52.94229338246008, 38.06983455534905, 39.6482551482416, 51.47187917463241, 47.47698437783026, 48.042433261871345, 59.9777977697311, 50.178387395797245, 63.538101796180975, 76.09544046463506, 62.572790807293316, 36.30653304438437, 21.71737132533904, 19.806733823591664, 11.407772379536784, 5.120852829948549, 2.1137461643065176, 1.0120843951740572, 0.4849379768054332, 0.15972870402038097, 0.12199147334021908, 0.5794112961138449, 0.5815883954205822, 0.4829574863035833, 0.6352662150898288, 0.83801377444498, 0.7460626310879185, 0.7272141102340914, 0.7899147909014457, 1.603628317675283, 1.816927420516168, 1.2184822102708202, 1.753201162622821, 0.16990742315688442, 0.08362723799842982, 0.014971440841984606, 0.15264822831076963, 0.598901798648219, 1.026823681689078, 1.1047019737382089, 0.9238840182942729, 2.3775917483914286, 2.4112706895797484, 2.024319924173817, 1.999775815394617, 2.4638451587769294, 2.4333401505024206, 2.697972414955016, 2.2312750835572523, 0.8979654864918802, 1.0055733832620806, 0.9254334770864057, 0.6634619892124207, 0.4027820030047048, 0.26580110012042907, 0.06500022380702919, 0.04854493864601658, 0.3500768085641246, 0.7270581347327079, 1.6452970043305428, 2.469031512737274, 5.365212569313665, 10.698891243626996, 20.953260275625414, 32.966430879408314, 35.72592419962729, 40.20259195758451, 40.72585182805216, 33.211045572834635, 27.393654815612305, 25.87359909088381, 29.375377431992565, 34.78736377531482, 26.418892875794445, 23.779120099159982, 39.38774308850689, 55.29308357546407, 58.966340095766135, 62.602318409950506, 73.94959803550475, 72.5439460815922, 50.91701676768642, 31.170403072910926, 8.022202589819509, 2.1871822495614333, 0.020289953587757006, 0.023508380888210192, 0.027537168334088022, 0.03579509437024113, 0.00890160843189205, 0.030168959976083813, 0.03178451491910363, 0.0042556753971674036, 0.03102199696455031, 0.04734304245381106, 0.0358495325781405, 0.03941680950623366, 0.03496025005475648, 0.06389058375310513, 0.021344992640097777, 0.016131651317400318, 0.05563629280415274, 0.07507068705895255, 0.041579514020873655, 0.03271270896338167, 0.059551281719318325, 0.07536882549644479, 0.03266968546555408, 0.03458649107825852, 0.03689647216590182, 0.049456866728442336, 0.040065548082272855, 0.04821286251347873, 0.04143248642644575, 0.029496198797958995, 0.09084808399840709, 0.0362208285819619, 0.024039398563364824, 0.06079607883528356, 0.01908643137393219, 0.020335300247214978, 0.07843788097342176, 0.037079735719148195, 0.06601562738538751, 0.05472024316869436, 0.060627589287656936, 0.04153649052304607, 0.14010937614065988, 0.1518076459967321, 0.15382664007765634, 0.2318493397005143, 0.12703646109589647, 0.17753605009807696, 0.1496028449506529, 0.3497904142545116, 0.2709681486650821, 0.1482126405162196, 0.1538054654074292, 0.08981034129617677, 0.07983020747140532, 0.13349434481032435, 0.07901441576259752, 0.18305837957849427, 0.23115325689075455, 0.10737509031089083, 0.1126466868745704, 0.22245127948061114, 0.1814001516228722, 0.14656040336816542, 0.17728340962240774, 0.17938311872703416, 0.11293351785430025, 0.09539952726974603, 0.15978421475137436, 0.07934987034288146, 0.08969263954749031, 0.12955574889577207, 0.14751638916711654, 0.19526536245980572, 0.23599188354226852, 0.15024807484399888, 0.21281913343456485, 0.13704749124665416, 0.1813851516213148, 0.07813767409853398, 0.16518890377013914, 0.7240480220606251, 3.7876627425993648, 13.848108322389665, 51.54761229791949, 90.97852891491306, 94.17543318963821, 95.20659292897871, 85.35487774879702, 79.52883228178948, 69.86164108399423, 58.73827388209682, 44.750129099815126, 48.41886704967868, 58.988344592432824, 62.13294406091014, 65.42587187982375, 89.05606546709615, 94.89649818789576, 100.2963310672391, 82.01211621684413, 59.726926895879934, 38.35371217420025, 19.74969275536076, 20.12962333617672, 15.536706332237491, 6.789678171757729, 3.0542567420390347, 1.9697535037994387, 0.8027169168476136, 0.4302219241376846, 0.19768033206703203, 0.3729699059359489, 0.5702297629848604, 0.4714883839891803, 0.7803535845971877, 1.2049240474739384, 0.9102521884825923, 1.0804173542607216, 1.012911892706348, 1.683082421941142, 2.1539085382415406, 1.9763195514678957, 1.6407341846535284, 0.22791733214211082, 0.3480685550358988, 0.18214992187436552, 0.833605949676806, 1.4692301423318925, 0.9048063452205352, 1.365667189801893, 1.1739441872604433, 3.461043546276708, 2.539246596636311, 1.7800010019733061, 2.4453330424524125, 2.427183500220699, 3.5444772628045853, 2.4897781543193327, 1.8555034408646247, 1.1275563989916155, 0.9687353406221637, 0.6104684392771413, 0.8598045632243158, 0.6001975904068639, 0.3713178526489966, 0.2546478711789654, 0.31727623314626757, 0.46445888377005057, 1.2179547740567116, 2.1676380595853253, 3.087387041699502, 6.3699154315456274, 10.879008443124834, 21.714939455832205, 34.18908465293146, 42.43271435460737, 47.18915300984537, 45.640342389383626, 37.22428137256254, 38.30947568339687, 31.37651578072579, 37.06710023264731, 41.60351353306925, 35.005914318946104, 32.315199759698686, 49.48162540312737, 62.11440693947577, 66.80467128753662, 71.13298323846632, 81.51825058844783, 84.77563781123008, 63.893025305963334, 39.614432550245716, 14.587483925204124, 4.1602006362330535, 0.44869757467700594, 0.140906184190704, 0.1411939421368222, 0.2213197522946904, 0.1028760168100557, 0.11793035698393661, 0.09212110762394245, 0.14142113317164684, 0.08051787863575643, 0.08057411715027787, 0.17949387971912661, 0.0870747332491221, 0.12024955793974862, 0.22347343995446162, 0.13539004470071486, 0.06902488203899515, 0.10340244944898352, 0.21065351012493336, 0.14881860074256698, 0.06624242771537074, 0.06519253485866132, 0.1531718647287738, 0.10005672131815266, 0.12653972202491376, 0.11952064060155423, 0.15542036343005397, 0.192685806522927, 0.15439739090300378, 0.2767415404800446, 0.1337712089861593, 0.1630469832208849, 0.17011471122743624, 0.12718027878192165, 0.18576928895087014, 0.23593710825568248, 0.06591219019385115, 0.16088843856367374, 0.2441930845980683, 0.14078813004157237, 0.15607011324215322, 0.15699350966080544, 0.11232771850641697], [0.023386682075778806, 0.0854911835443589, 0.025459294650523413, 0.028029600075716456, 0.022493781702172373, 0.0317384941022723, 0.09067713147810391, 0.03912862255087784, 0.006890372906420981, 0.029110142195056525, 0.07765067966594812, 0.09387536470087306, 0.06572413859107802, 0.053525153667696064, 0.025074910034515688, 0.016220090422599066, 0.08656064228665444, 0.023726135635027484, 0.035249053710891355, 0.02302645221202364, 0.06022207596669755, 0.0301221922235263, 0.01589971341027488, 0.008650097935911148, 0.016811427945691734, 0.017684821805526173, 0.06723305601025782, 0.044894686734844605, 0.0409732167158396, 0.038627987922800165, 0.047611812910726, 0.06533306602749132, 0.03431848670926786, 0.03775644799574249, 0.14224195041723792, 0.08340658169359931, 0.047466635418635224, 0.06871328343667331, 0.46994110088675256, 1.4198095039013894, 9.478607562280471, 32.8562181611215, 65.54459810256958, 69.40873284493723, 77.3785811085855, 61.94562735096101, 66.39625057097405, 50.849367649324485, 46.79684538995066, 42.46746263196392, 46.27783344637963, 58.37504279228949, 82.59370173177412, 91.8403991576164, 96.06018697061847, 101.02871602581394, 117.90221906477406, 82.7996575447821, 38.65995907014416, 28.680474642784368, 23.566276604129424, 25.525482854535504, 5.903631910201042, 1.513775152064139, 1.120196806807672, 0.6265373479935431, 0.15637512348832625, 0.07389510215650644, 0.252877717777606, 0.40694538443799944, 0.6018805936459573, 0.2833778230893997, 0.4567602210708203, 0.2808714285492897, 0.5431280237051749, 0.11241371187591746, 0.6900676712393762, 0.14990146602353743, 1.936831089758104, 1.458679456864634, 0.5309005249892512, 1.384406313300133, 0.23200436525287169, 0.16798587545992869, 0.023811937482546897, 0.1919044121619194, 0.18299707722279335, 1.0005053745642787, 1.3037334550772945, 1.8695865883942575, 1.308883894835749, 1.4102494620507764, 2.972050972523228, 1.6188328953519946, 2.3815440266363086, 1.0851711443355008, 1.0780026451233895, 1.4044085625679263, 0.41706479304740507, 0.9927589386220902, 1.0818938814824628, 0.29551811035602327, 0.5051692557190696, 0.07282303871526834, 0.09965076366619718, 0.1016897679637036, 0.1853797332413735, 0.04486061880485185, 0.13158050395788687, 0.2693555642279887, 0.603739797107635, 1.7388614675691052, 5.6148013184147505, 11.105000703565537, 19.76776899829988, 26.74935256281207, 32.21976653222115, 43.275847434997566, 44.565342318627145, 45.397900689032774, 39.91414869985273, 39.72274880255423, 38.82397297889956, 28.40928000788535, 27.862444731496996, 35.29611479851508, 51.588118614689, 57.6770648648662, 55.99395621207453, 59.45170594799904, 61.19889043992566, 45.03151993597708, 27.540247517247355, 6.685678978120127, 1.6475826429743923, 0.16422499662205098, 0.07703754119575024, 0.018037312266026295, 0.01834444074530996, 0.02251684669435265, 0.0633165042757267, 0.0753073316187628, 0.029213504693020257, 0.010550998605697626, 0.053305137046282335, 0.022562647260905757, 0.011669106804014695, 0.018189980182796717, 0.025535863223335436, 0.007337801291742513, 0.12317442034761752, 0.025130346071936434, 0.049661998261487296, 0.0678586510701045, 0.012589956937928595, 0.03443477885617364, 0.10015232143022361, 0.006432774703904626, 0.054265577646513144, 0.07850761795716901, 0.02415304387649221, 0.10284061588707472, 0.00872185356133888, 0.023441951489076022, 0.12076806922953938, 0.04793888265867868, 0.04430280720454551, 0.08606021833275596, 0.0418382985216956, 0.012342909861716532, 0.043959833471284765, 0.03622647464996384, 0.05306281577495318, 0.07556102163488827, 0.019374851986104925, 0.012861205689278583, 0.02824495888255056, 0.061744273520044746, 0.012505573310679006, 0.04499120998286432, 0.08540764931709537, 0.024440261730623823, 0.06028701340959919, 0.026784682300903147, 0.09547113350802854, 0.006594417340707996, 0.09565908551937151, 0.019854141489392328, 0.0517874785638865, 0.01693621792289759, 0.07461355473365515, 0.04034649933718386, 0.01832357825591199, 0.03735422885285751, 0.027512733959743095, 0.027127301718498913, 0.03129540033818733, 0.03091096784168434, 0.06310702519371145, 0.037075549048642, 0.06153465654220312, 0.02136753094683011, 0.05132958015066482, 0.018443137767814824, 0.039788906071935935, 0.0614047893172791, 0.01210747763604647, 0.014846136628259576, 0.01899593915309637, 0.05016450214410021, 0.03290834483660517, 0.06657963663700127, 0.02658300965483631, 0.04908809115389182, 0.48827919267839004, 1.822079821459709, 10.749018153836651, 34.02132880303168, 71.31211003949566, 81.80668600143926, 88.27401545739944, 76.12231654505577, 78.25574075022053, 63.89595923885223, 60.052060004203554, 53.688073235173384, 57.30529085282357, 65.7264901745704, 78.74164396716704, 89.56922915674026, 98.13040610282653, 104.28062761983564, 109.09904756853658, 80.43965370424333, 44.100027622715125, 28.748841554887836, 20.289646233281783, 16.697023837797104, 6.386474697820603, 2.053761234687221, 1.1139275109575641, 0.7191186446336009, 0.30421872412966144, 0.6056282957715373, 0.6761004174909284, 0.8033751395921555, 1.0657425417054085, 1.1112085729837418, 2.062531286670316, 1.8323435610340488, 2.664969102028878, 2.0040344062351414, 2.6334739404339946, 2.2924329244321395, 1.8595952083987577, 2.640295432459924, 0.9757841462569853, 2.961689296268648, 0.043788474924381704, 0.23324306813939927, 0.03918744661214371, 0.23887254267690644, 1.2938086328006562, 2.124051456489871, 2.684437050934761, 1.8017077662291068, 2.7228130304044296, 2.9869851518061856, 4.446133086758276, 4.131768845742749, 5.538013077551319, 3.349119939150349, 3.8485313086740436, 2.925804267006536, 2.759797549055469, 2.173374035666066, 1.8718599696313183, 1.1817019000168771, 1.6910395627060246, 0.679750734519574, 0.35338505201282044, 0.2581334793038907, 0.30614350471765767, 0.1473465168307866, 0.14908150679642154, 0.4775012242457559, 1.1176625879541522, 2.815349832657845, 6.419196580686878, 11.38936665750319, 19.97656068494243, 26.058403522737567, 31.59032221763365, 38.33878755569458, 37.2686904476535, 34.89906503308204, 31.690762350636145, 39.43585880341069, 38.259904769159135, 30.874270008456325, 35.560545306051935, 43.181839989077666, 58.09291455053515, 66.09509098914363, 65.70228130586686, 71.32162570953369, 69.20254953445928, 50.098967244548184, 30.40594489343705, 8.052054278312191, 1.6585535123463602, 0.28165777183828816, 0.029034169255605632, 0.05086963628268531, 0.01686517092879982, 0.03636063579770346, 0.03385028441346461, 0.019489357232927315, 0.025973646082885327, 0.016515015121248942, 0.05733691606550448, 0.011575442021562448, 0.08003463803399956, 0.03747957232858866, 0.01925227791822005, 0.002322955744250888, 0.08200572097613927, 0.023509530020096613, 0.13017529952189616, 0.02813056280325738, 0.0253699668833325, 0.03561984792712235, 0.11098828271872575, 0.021631848517685168, 0.02938864005339002, 0.06702054322006241, 0.0333632440156033, 0.13257828751398673, 0.020988242730738658, 0.023140668260654616, 0.057519919148856596, 0.06120152320832976, 0.0339630180819621, 0.06613630155522017, 0.04507386320901494, 0.00790249714965842, 0.046487643999317964, 0.05917069689941503, 0.0817835861216149, 0.05430523418791352, 0.0033163544045941486, 0.037752958465247385, 0.11590611520073107, 0.21205390352875958, 0.09299658524293093, 0.07355403215173753, 0.16985797984225137, 0.1194002039189781, 0.13755458016549388, 0.08731936810598259, 0.2180638632947399, 0.12012558193096232, 0.183162490927404, 0.1321788339485084, 0.1654396903130316, 0.1433723591147892, 0.2602156143515341, 0.1415127419656323, 0.13835912570357323, 0.1470198569398734, 0.1475049284917693, 0.1550509711547244, 0.1647598792107836, 0.10718351470366602, 0.15319279425086516, 0.15339433666198485, 0.1316037777090265, 0.07905028399921234, 0.18299041225785212, 0.10619827200688663, 0.12761093510855592, 0.12706185691058636, 0.10781241926334559, 0.22190976257045425, 0.1885638551245774, 0.14400553078420703, 0.31753140171208694, 0.1664786281124238, 0.1796446917879005, 0.21493801005905677, 0.833042660547841, 3.0452473029013607, 16.759836673736572, 46.1283479967425, 83.90705247079173, 93.73152286775651, 99.45033857899328, 84.17411096634405, 85.21152296373921, 66.66807082391554, 63.38804368049868, 58.86631965637208, 61.506263056109034, 73.28302260368102, 94.50914059915851, 102.44748438558271, 105.03275778985794, 108.92165445512342, 122.62146580603816, 92.55967555507537, 49.4535529998041, 39.46399396465671, 32.24542667788844, 30.97464934472115, 8.023160138437825, 2.2231511194859785, 1.3983150379311655, 1.02180874756267, 0.4019395207926151, 0.4422129774766584, 0.7065502061478554, 0.9693027972694367, 1.8644975582438132, 1.2851648321074824, 2.4423358613444917, 2.029399516121034, 3.2305287930273243, 2.2366661362109648, 3.7813521392883795, 3.006406767714408, 7.0265030380218265, 5.18551016046155, 1.8501353095616064, 4.665267082952685, 0.7543383418552337, 0.6003682135093598, 0.16972192262689914, 0.8286900553972492, 2.184054894793418, 6.006433800343545, 5.759169055569557, 4.405679721986094, 5.305696485504027, 4.178290607467774, 8.111479657311595, 5.57364781056681, 9.927980765219658, 6.3878671392317745, 5.068407308670783, 3.8145375972793953, 2.460290755956404, 3.1735431282751025, 2.9526950563153918, 1.8301556139223039, 1.715617992224232, 0.9941830654298106, 0.3562465129840759, 0.1788554220430313, 0.35161177297272994, 0.3272454885225142, 0.497085434655028, 0.31292742779178007, 1.236106522621647, 2.694593293051566, 7.60603323098152, 15.179373506576786, 25.595577570699877, 36.09870626080421, 41.984967954697154, 58.55970405763196, 59.68752668749902, 62.21767117900234, 53.04234912318569, 52.96491761361399, 53.06789159774781, 43.38093557665425, 41.81504303409208, 49.15180114007766, 68.50182594791536, 74.4439265035814, 74.1241591976535, 76.94749693716727, 78.72631534453362, 62.03246470420592, 38.65177308359454, 11.041889767492972, 3.432825524960795, 0.4486473499526901, 0.14869193576516646, 0.17886654563969184, 0.10859856336948373, 0.10895034328343407, 0.10780583856807602, 0.11368883458236534, 0.1404309032424804, 0.06948442754125403, 0.14733422878048114, 0.1329696971562601, 0.22769417072976791, 0.23646678144653, 0.09040778262480613, 0.13273691367958823, 0.2660957068925904, 0.16645285691465103, 0.1451039936153158, 0.11144933741419547, 0.1521028809609913, 0.18038795029203739, 0.28748558653939155, 0.07140854163275612, 0.11380806850690035, 0.27838602481830504, 0.08339224052765677, 0.21376042566712827, 0.11371993009121188, 0.09287542077682673, 0.2371352084822232, 0.13825130648911, 0.1183236818460207, 0.2524624061920951, 0.1312824344683078, 0.09992935153986178, 0.16791202458402804, 0.11588221325749352, 0.17924965088886602, 0.20930536391754306, 0.16526889867119252, 0.0817324344309107], [0.023793528389726436, 0.020468888744231195, 0.01986924874325914, 0.03908547647898236, 0.037620413763028, 0.049406910134900006, 0.04294633362141829, 0.009618880276027466, 0.02852101866606503, 0.06181322526366961, 0.012980320870185332, 0.0660542152341335, 0.045179250094318585, 0.043495450123784044, 0.019486917242888483, 0.05187606897145029, 0.04791509562862977, 0.05091061049531545, 0.01732401354538818, 0.05291300345092051, 0.05442385524210911, 0.04564053078572597, 0.03047449307726516, 0.05135108423869937, 0.07813811076865082, 0.04633559852898602, 0.14511681792716827, 0.024017501855269078, 0.12561553653569954, 0.08065359877242197, 0.024076000329167135, 0.01714497496704421, 0.07679293698240673, 0.04163141647774366, 0.07717556725706785, 0.06492791276785635, 0.16741354649345722, 0.03679926326918987, 1.3233069402556266, 7.642426452329082, 19.48691160448136, 58.013231600484545, 62.2019071732798, 62.182981737198375, 63.753659571370775, 48.34319276194419, 48.37849017112486, 44.69542772539201, 36.99418337114396, 32.719258800629646, 25.836736656004383, 20.007215969024166, 39.165289786554155, 36.69374550542524, 33.48903963642736, 39.41981238703574, 43.90617232168875, 46.20140606357206, 34.35471457819785, 20.616767983282767, 7.547761028812778, 3.6662246911756458, 1.7092550497862602, 0.9173471432539725, 0.14288226202611, 0.09889275796951787, 0.17999153043473923, 0.5082719118124055, 0.27931403308626146, 0.8406177379431263, 0.951001140619478, 0.7070186229482774, 1.0773922262653228, 1.4421395572923845, 1.2683547792896148, 2.786614303627322, 2.163569335975955, 1.9499839001124906, 2.478481237926791, 1.935641876151485, 1.4887308185139012, 3.203333039437571, 0.4175074999370883, 0.05140557224231382, 0.03894788708778159, 0.12240008165639256, 0.4039945976147729, 2.0029841916215037, 0.7530364213931946, 0.5552694141384095, 2.3755589800496257, 4.751093935581946, 2.4489707956391, 1.9903855386280247, 4.551752709573315, 2.0630497749774688, 4.2043483834112845, 3.935463534247491, 2.5066411591345266, 1.2687926138600996, 1.1733365876059378, 1.0121788384933625, 0.930265837138699, 0.516672004615107, 0.4998131673182211, 0.0202397154569025, 0.1920064091081581, 0.2320321282792476, 0.005639813372850298, 0.05497452690296116, 0.08857324719429018, 0.36942478810106555, 1.326509187779119, 2.9859790638569863, 7.555770018408376, 16.3209528692307, 30.896133299796816, 38.12315525547151, 56.64001764789705, 73.97334406452795, 82.88905620574951, 74.30687888976067, 34.886160435215125, 22.418663655557943, 22.29539925052274, 33.51909675905782, 41.44961541698825, 46.13810685373122, 49.326503507552616, 61.94914571700558, 58.81714882389192, 54.794236536948915, 35.12958272810906, 19.83447870900554, 5.4416394618249715, 0.1773121838848437, 0.08000501341396764, 0.050033792222459475, 0.04435636441133196, 0.029601874881454056, 0.10342491114692343, 0.09916211448369489, 0.1183422594781845, 0.045854916660896236, 0.09889347043128745, 0.03150176144235077, 0.031996765324184974, 0.04469731184203298, 0.03272289027189536, 0.045389483772939256, 0.04700790963045532, 0.07126078625480015, 0.03902267642138947, 0.09655002279267197, 0.12242780637837226, 0.021368911820313623, 0.048565722611402316, 0.0048694789274445465, 0.04786216278350161, 0.028176252287061467, 0.022723908768966797, 0.0291199634422458, 0.06505761911431629, 0.061763008200233026, 0.02156173806607483, 0.01903160629163106, 0.07018230299675657, 0.042032670349844044, 0.0144633004674688, 0.01777653019094179, 0.02363643056953386, 0.008939103647736053, 0.0369318884106413, 0.05360052905856602, 0.04575771542506353, 0.04363144988254194, 0.02221552324631522, 0.024801541134835254, 0.03174281675338505, 0.017096726749573025, 0.014603873771134646, 0.06689337262463185, 0.031813543905774434, 0.13484129592055275, 0.041402861806413824, 0.07374754596141077, 0.017035338208980618, 0.03754964256058297, 0.012565449785230862, 0.045091153813465956, 0.024056744709190343, 0.01138256885291588, 0.0338670885520837, 0.010545666633744635, 0.06707354884354338, 0.026991060642044873, 0.04663767465840905, 0.02344238049831362, 0.02486157178458187, 0.03225217903814009, 0.02124699275760401, 0.05917559220125118, 0.07457937189047376, 0.013604119453849572, 0.08034566207037819, 0.09020512938619622, 0.050928985114179315, 0.008634216933240815, 0.057758252932539875, 0.011754060209157967, 0.03949908351886176, 0.06269133822511762, 0.10004302366606652, 0.11604301511279999, 1.8664596013484465, 7.484841308286113, 22.28718384619682, 63.18806555963332, 73.48235745583811, 77.18052494910457, 78.05281300698557, 59.75323423262566, 58.11686846517748, 52.31806385901667, 42.17190419473956, 38.42069056726272, 34.083718022992535, 33.52433704560803, 52.51383327668714, 60.80637101204165, 48.12253198316021, 55.40120763163413, 64.73146723162743, 52.305535808686294, 32.43857202991363, 22.71098613739014, 9.5665608298394, 4.175159575477723, 1.5246801991616528, 1.24599690158521, 0.47317589182526837, 0.49189279877370407, 0.318029604011005, 0.8575675251983828, 1.0116394513076352, 1.9954419640764116, 2.119926348809273, 3.3105664724303834, 2.4289323870212804, 2.870834210226613, 4.270476602738904, 3.9720337525490796, 4.730094546271909, 3.475000074794216, 2.7647051695854437, 2.229884603331166, 2.5221357470558536, 2.64320828260914, 0.43232287430474836, 0.20892135468461823, 0.10748295549062953, 0.05127359827559802, 1.2784255872811041, 1.9530469034948659, 2.735359221696854, 4.910431888795668, 5.72622653938109, 4.79277107984789, 5.48036257105489, 4.865221669597011, 4.239579112299027, 3.8135812744017574, 7.450458791948135, 7.583174638209805, 5.393092286202216, 4.287476155065722, 5.435381810511313, 4.086299014668311, 3.07171888889805, 2.8007615573944586, 2.417840414470242, 1.356085942637536, 0.9882757920892009, 0.7345101477638368, 0.4499864103572984, 0.38059128568537776, 0.17071233641716743, 0.1997289737506259, 1.237072283702512, 3.1444658627433166, 7.597742321029787, 15.057598621614519, 26.95230187908296, 33.76510389389531, 45.354648713142645, 61.03313107644359, 71.8966059530935, 66.4296377858808, 40.490313499204575, 30.718006703161425, 29.570999760781568, 36.303536353572724, 53.73368255553707, 57.531031100980705, 60.4151185097233, 67.0804060659101, 68.32271483636671, 64.26397954263996, 43.05742632958197, 20.105792976194813, 6.777554615851372, 0.4686360547859823, 0.03472951969372169, 0.08321013376717606, 0.12396340663995474, 0.0407941704766164, 0.015494647293141293, 0.05319549837299893, 0.009279666119255126, 0.0422681006602943, 0.0679112506669856, 0.055148022835172957, 0.04128150964876817, 0.025976160766496777, 0.03658526043798174, 0.03729042522008381, 0.03775381265328296, 0.013804605621243677, 0.041585022193049236, 0.06858671805070293, 0.07588597314973032, 0.01115267831576808, 0.02557848260978297, 0.027751094556503722, 0.053179709300879514, 0.008766753974580958, 0.011122583509272626, 0.07244695849235981, 0.008715421295604639, 0.025615551689219092, 0.026088271988555792, 0.05645787613766809, 0.08294188041961001, 0.012878913811648325, 0.028712157603173007, 0.014843069403732737, 0.02813401019891664, 0.03522827357594525, 0.04606810360846501, 0.05155496321798814, 0.04207856284694807, 0.01861752810767822, 0.13504360441959676, 0.077043654577386, 0.2002416551113129, 0.15687370883120647, 0.16475181996582017, 0.09769609798827479, 0.10848389532897743, 0.15067527611409465, 0.1655721622368982, 0.2218064479529858, 0.1484346221531591, 0.20632531253560898, 0.12634902741880188, 0.12064115910400307, 0.16533948601253573, 0.1916063733158573, 0.15682849432191542, 0.11911723402238662, 0.14506015806428849, 0.18010894107001443, 0.2550490407813942, 0.22689178555963502, 0.10705824400628768, 0.13394938571558845, 0.14472211410682048, 0.11970086278574121, 0.25824486848808104, 0.13366493726930312, 0.19355920804364068, 0.23840886029985645, 0.0979410775847012, 0.1983003270241522, 0.16308899548265243, 0.12353899392990336, 0.26693114109577676, 0.19370108752721743, 0.336460852094235, 0.33247538692047524, 3.105027411253222, 12.745239811558879, 31.65562968100271, 76.7968543883293, 88.35711479187013, 89.1111747680172, 88.8676348040181, 67.8252955405943, 66.82535786782542, 61.36642271472562, 51.00786278324743, 46.433673135695926, 40.00106450050108, 31.087268437108687, 51.38534384389078, 48.522174435277144, 45.31621733019429, 50.77552118609029, 54.73014893070344, 52.93862596634896, 40.17886946278234, 24.648076103579616, 9.815843143770772, 4.101718096963821, 2.087288796901703, 1.6760037695207906, 0.6370824563407129, 0.41192422050141525, 0.6654074848178895, 1.81303066832404, 1.358351724282388, 2.177066702035166, 3.623949140310288, 4.515701224727016, 4.6174465264043505, 5.040776171991903, 6.490023309184659, 7.673972604736206, 6.716112648287128, 5.644805979344153, 6.3747075873036545, 5.117347211607042, 4.4407427695489705, 5.714982084689602, 1.2856216656584896, 0.37906309349402306, 0.43553097473998226, 0.18059333846453698, 2.566356058082273, 4.950228256563987, 6.162499516241013, 6.06785076279794, 6.84144365210687, 10.800415911982137, 10.3569439149672, 10.854276918595838, 10.874222170922065, 9.210047779544707, 9.527862725719329, 9.579639973178987, 6.7955259353883815, 6.421788286778235, 6.529980494130043, 5.323612401562353, 3.7749969190166848, 2.7369056161372893, 1.9991112187985454, 1.6494424593064094, 1.1716629612830378, 1.014465396442721, 0.3667670452306348, 0.5053324630904583, 0.2823827974498272, 0.6975605627221446, 1.6245302606013514, 4.014349507708704, 8.873399572987712, 19.476693830182477, 39.05458481081071, 48.09917034641389, 68.54506615669497, 86.75458338952835, 90.72311201403218, 83.59137227458339, 48.53771094352969, 34.783433560402166, 33.53921459567162, 45.65468257473361, 55.578275188323, 62.223542967150294, 65.66991390720491, 80.5246828448388, 77.15380576349075, 74.7342368095152, 52.412965605335856, 30.43049304716049, 11.35754054592502, 1.240511344325158, 0.19328136327526263, 0.17380694858729842, 0.22832915036668702, 0.11214289213380507, 0.22247115180136698, 0.23284677085616898, 0.16934586538662835, 0.14584426437654804, 0.1541204194748594, 0.1735002069824165, 0.16910980305364057, 0.09219932520101148, 0.15786111955681156, 0.07770520214351916, 0.15321438260857137, 0.1413536867907932, 0.22070066132132085, 0.1775985935162152, 0.23430858918976402, 0.1474374361456402, 0.19638604184071864, 0.1328407645586037, 0.05738761193389374, 0.1319986653904761, 0.1413382424582397, 0.19704852403411943, 0.11229229460079825, 0.17219267875677155, 0.0970730769838537, 0.16659164140301366, 0.20826576728253596, 0.06049027185766928, 0.08514688830942878, 0.261911794302925, 0.12085094462118803, 0.16508192725239262, 0.15800463846854626, 0.13874316558001504, 0.15274824875016368, 0.10506685207327528], [0.05990960785458165, 0.036941996940802184, 0.04924567927035594, 0.028803094155004913, 0.01088859535933983, 0.01665504833292817, 0.07498942811282412, 0.036346670014843825, 0.059504347342637286, 0.08952609969363098, 0.060490256535910794, 0.07864265627558194, 0.017476334807372863, 0.05227041656091329, 0.03783386118049103, 0.02941266265547564, 0.03409613351968508, 0.04886421727977934, 0.00812697192398651, 0.05996047609275388, 0.045187711535442265, 0.01988006781996979, 0.01833398939080296, 0.043992445834221384, 0.05510525980723962, 0.0343025827239598, 0.04986617601506653, 0.027945092916789076, 0.031982567799728245, 0.018092344192066984, 0.012306661453969296, 0.05571120088138888, 0.036813949174698324, 0.04800501136830257, 0.05564970700370689, 0.05620476834836507, 0.08586730973254289, 0.08388586162078766, 2.643658864882685, 16.21387706648919, 44.4360766872283, 69.63038598337482, 65.63538920494818, 55.24884316229052, 53.11964727217152, 51.40706200753489, 52.308940425995864, 35.24835994166713, 33.9005825596471, 26.671605302441506, 38.96141282973751, 37.172070703198834, 32.81898113989061, 39.54218249167166, 43.06422771946077, 40.82408758901781, 17.358296225147864, 15.216990997714383, 7.724144131906572, 3.2232834398746495, 1.1863647401332855, 0.5389088404274757, 0.19473777302811224, 0.19297292095518884, 0.3117769782341296, 0.6151169995146414, 0.3140616975724697, 1.20160682547477, 0.8482408643730226, 2.12369452080419, 1.9504804476614923, 2.5191238570597867, 2.7488104999065404, 3.2164871981067047, 2.8061153475315344, 2.6427116124860706, 2.7809857024300486, 1.8566622561024082, 0.9240263267870873, 1.92533842257915, 0.622505457891572, 1.0128962645126929, 0.5731967908720816, 0.05363484213669455, 0.11176921742697878, 0.019433528575445377, 0.7925467625741036, 0.7748108465344675, 2.5464689058642236, 3.741198345538109, 1.726603570484346, 1.852607138214573, 3.7671308507842407, 4.639210777897989, 3.0711221983355865, 1.6164051933634667, 6.204329632943677, 4.381644908458957, 5.965237636719981, 2.887383180279886, 3.778943313706306, 2.031196697104362, 2.2003096870837675, 2.8734646497234224, 1.535150353466311, 1.207457285734915, 1.147970864849706, 0.3740693340378423, 0.0949736206882423, 0.36961870027645943, 0.07015814824450402, 0.18640694989552423, 0.18267487596359946, 0.4913587129164127, 0.9314047953774853, 3.5346926652616073, 9.552556007139145, 21.645995955313406, 46.10038934215423, 51.09523357883577, 58.671036612602975, 57.56079796821841, 28.43153553624307, 20.969734230349143, 22.098684541640743, 28.196685583360736, 29.98654546276216, 34.03692806920698, 52.487004264708496, 57.938388855226584, 59.90325312460623, 61.78836776364235, 50.110467633893414, 39.229899068032545, 16.759503272271928, 4.6163477724598305, 0.20878511360816418, 0.02718274350157909, 0.07262194829602396, 0.03387662251630137, 0.040379004447811076, 0.04100363806731278, 0.06281647485710921, 0.03960917035358087, 0.02773819746629846, 0.07726329964615646, 0.06926885039936151, 0.05732705268347937, 0.042644935479808244, 0.06916470074605557, 0.07760223992649587, 0.022102136487862276, 0.024999802774419228, 0.055934331650214816, 0.029596585044336897, 0.10459120340284803, 0.031133562348963275, 0.05186362004268074, 0.013316438116523768, 0.044436941539207776, 0.11542644456870134, 0.05787225447655205, 0.023947598247398293, 0.03870366208796059, 0.04990333894027337, 0.004469251134357746, 0.09392311496119346, 0.08752685535939471, 0.04772994749908967, 0.05274122738609872, 0.031966895556017276, 0.08423030241242341, 0.062306091760195075, 0.042612568265007394, 0.017846259513809797, 0.011422543320804836, 0.04842301575286735, 0.049358949200400425, 0.012210301957243394, 0.0030872153518195717, 0.029947213911181016, 0.03253845077368521, 0.05158563737847632, 0.06833458319306374, 0.04058922280467326, 0.019660964758405765, 0.01998490312196795, 0.045020531998166156, 0.060364985838532455, 0.017247669053294005, 0.0597347061510288, 0.023849414503802697, 0.03234094181548684, 0.005763742937556198, 0.024053519479029124, 0.028725428161241358, 0.02982682319388034, 0.017146882525975668, 0.009426514640630735, 0.0074430881068110475, 0.05618298080779853, 0.06318274915458695, 0.05344807373119458, 0.011638123335527077, 0.01345914401744883, 0.05031008183235123, 0.07208551820968429, 0.012986907311114333, 0.01435688510912681, 0.014903558748624018, 0.04926940118293128, 0.0961838327648659, 0.12168434869137504, 0.23993055606561325, 3.1165508445232146, 19.505907643225886, 45.224449557642785, 78.04041831724106, 77.0948839187622, 70.48807497947448, 65.62709339203374, 62.72625746265535, 60.003708947089414, 45.88916186363467, 45.02488720801569, 38.19483657037058, 45.18828138228386, 36.24491260897729, 32.942445585804606, 34.191791088350364, 38.9638093979128, 40.214778761709894, 22.837627703143706, 21.84828435221026, 12.074278189289956, 5.549092792695569, 1.7765060475757046, 0.5473009965592815, 0.3925490295214038, 0.46444641185864327, 0.613135896142452, 0.890294433601441, 2.209539024099227, 2.7365837366350236, 3.930274238509517, 5.256599687760876, 5.539810013386512, 5.495333277410077, 6.492399775212811, 6.330346070951031, 7.877796609555522, 8.358684585940454, 5.8103716757989705, 6.230409962515678, 3.9240484564535083, 5.068329351563608, 2.718675910465179, 3.045825852501777, 0.2666618765121506, 0.05781708082424537, 0.028073816755486113, 0.06706227969017721, 0.2912428187987497, 0.6066453540998121, 2.6879662034973024, 4.777492467434176, 6.179749119666315, 8.463530521239004, 6.2735692724104855, 8.172073412326075, 7.955863543095128, 7.820680035698799, 5.216585138151723, 10.484151282618123, 8.855255669163121, 4.326190929259024, 4.778153386808211, 4.502806432785527, 4.042990899855091, 5.666692804905677, 4.729324290829321, 3.203331323400621, 3.2601895111222423, 1.5898861712025059, 1.5109520261326146, 0.5559470035856771, 0.48275830344327036, 0.32903641822838015, 0.6174704829050649, 0.5406074105731903, 1.2630930422775208, 3.454167631364638, 10.161120564706865, 20.41103574537462, 48.760517258797925, 62.17887501562796, 72.67988758702433, 69.53338576901344, 34.930251798322125, 27.8793187679783, 26.93974441097629, 37.8943084901379, 38.43942380720569, 38.90036898274576, 57.49710259899017, 68.83887521682247, 66.71364876531786, 68.90835608205488, 56.865471563031605, 44.78009208556145, 20.049610907031646, 5.173307666855474, 0.4092960179813447, 0.021437068747717048, 0.0594659969811478, 0.030379890794715578, 0.04456843287053128, 0.06765786708602983, 0.07491426722657296, 0.056392793138060844, 0.021359410414832736, 0.042779418384476055, 0.030311582564947107, 0.05698738461961189, 0.079630381097236, 0.06802391155713028, 0.0413415594507129, 0.06384429672072012, 0.07283827620408229, 0.06063902698036644, 0.004625310426607969, 0.08411543518905679, 0.05516449755598461, 0.03042922494181943, 0.022291228054992618, 0.06852927677814039, 0.055751029792572224, 0.08603965653286827, 0.04416929340110191, 0.020811682446829734, 0.07006367428168174, 0.04674233759062425, 0.05122219760631842, 0.04489788132148885, 0.028603625926940192, 0.1447309394397082, 0.03965140095040683, 0.02868957141594541, 0.07975523810713522, 0.014202090340756602, 0.011925315334191246, 0.05197703169899122, 0.14800591935073176, 0.1547579731672041, 0.15012683376910227, 0.0980812486922068, 0.15093134866366464, 0.1641989955979009, 0.11317256026931348, 0.16881400118431739, 0.1768308508420183, 0.1253199415101159, 0.10642343290871191, 0.14441995370772578, 0.22330689243972304, 0.1227198773995042, 0.13590507029045013, 0.1498777479414017, 0.1457151632395483, 0.10190935174544012, 0.09413542090764931, 0.2620631732767628, 0.07886830747367875, 0.13619986092371328, 0.06315956733399822, 0.11997048743069173, 0.1322410249662015, 0.16042175312196055, 0.169368602876221, 0.1060720360387237, 0.10731574914027607, 0.1335252641189483, 0.08874105109322457, 0.12656277361055537, 0.26020148769021034, 0.11906524729584494, 0.15947500634337627, 0.17378963500020966, 0.27596414509800177, 0.5645247981432946, 5.54807395704331, 25.98256841782601, 60.185059732006444, 89.67163439719909, 89.26859517251292, 80.98541229001938, 74.25571549323298, 69.91146302992298, 67.48015049965151, 51.651633554889315, 51.02959271400206, 40.8216517971408, 55.302587478391594, 49.0641910799088, 46.03792167478993, 51.99799453058551, 55.28843556680987, 53.376491915795114, 26.770315670198013, 21.45543936760195, 10.867861067095111, 4.882112376151547, 2.2315069936936904, 0.8418483202976565, 0.7267539671832516, 0.4356805151028018, 0.5675266370657952, 1.2206081349042155, 1.50156591688433, 1.8324106090491818, 3.423454982619132, 5.187356616220167, 5.662499300895199, 7.692452851803073, 9.040398405444238, 9.122306319975085, 7.395264669772118, 11.555503549114352, 7.878078039615386, 10.692486013135603, 5.808350184271413, 4.146883208905497, 3.742922717525113, 6.124888889251217, 1.2044553242383467, 0.17520899674104107, 0.3779893140158346, 0.1493832228645202, 3.82697249131818, 7.942485809326173, 9.565400788860938, 12.442879984455725, 9.70986266289988, 9.646094729823451, 11.652237042304009, 10.940777928598466, 14.138500017504539, 10.273425867480617, 17.736889277735067, 11.017586761905301, 13.63849784097364, 12.052023641524777, 7.210651453464263, 7.618923119960293, 9.75251647733873, 9.743026302706811, 6.916946826442596, 5.779127545895116, 4.889706084805151, 1.2774856893285629, 1.495527060281846, 0.6110739551724926, 0.25574789682943977, 0.42583040172053926, 0.5750328891219632, 0.8787556785729624, 1.3984474179244812, 4.600674961843799, 11.095494839452929, 26.712270475202992, 50.85798509659306, 60.19735244012649, 69.10389407988518, 67.30634243257585, 41.166353610254106, 30.107993810407578, 32.44372602432005, 40.758376121520996, 42.46614471558602, 48.48927359427176, 67.49081150177987, 74.34352951665079, 75.84535014244818, 80.17085367633452, 67.12214792928388, 52.41124368483021, 26.114683651155044, 9.9292996621901, 0.9238268374916047, 0.11804992032627906, 0.16315710069912095, 0.19686762003167985, 0.10834689582547835, 0.12489922900473881, 0.14782466294784702, 0.133670391815324, 0.10019543685860212, 0.1958572573118633, 0.20379821829978498, 0.16019073164751454, 0.20056601673845323, 0.20634133909498492, 0.107120978946407, 0.15480044508172622, 0.20798085918349607, 0.24196205270146173, 0.10026585566060198, 0.21366605895661542, 0.13661903359236258, 0.13305631105697927, 0.09389728247638672, 0.16673823998820397, 0.23089986564891957, 0.15436153798814745, 0.11639557643643311, 0.0865476954007341, 0.15259109347337677, 0.14340278812714163, 0.3046240152851228, 0.14655577619710278, 0.17029975210466694, 0.29778465808879945, 0.1680041696395605, 0.24482092429553312, 0.19429134295111705, 0.09131692214718751, 0.13592901819896314, 0.24533647082505688], [0.037635858095581495, 0.024995443734130072, 0.011325788331188021, 0.016484137947460818, 0.10068348849252348, 0.03362549506428261, 0.02881559670992917, 0.043272269559243036, 0.006124665153272931, 0.08628544818249442, 0.02056182287032566, 0.04465109375756114, 0.020534151774500648, 0.03949059909510036, 0.008651342828788103, 0.043884385302062, 0.023431304782148332, 0.012974557016165027, 0.05026695491265386, 0.051208155214666366, 0.04840250757913436, 0.0591063148702585, 0.03005584517884399, 0.03251534556188891, 0.048048980984716654, 0.00850591252768232, 0.08895794590634686, 0.04033929044981638, 0.017673985491837227, 0.0495790807350028, 0.020765931675991705, 0.06077217306160639, 0.03809511248442916, 0.04067961734929874, 0.03620886228858464, 0.0671119068659121, 0.19059081651991416, 1.2544838074714908, 11.672155818631573, 26.956789070560088, 54.70918778450259, 61.51123269911736, 59.19235490983533, 55.73879818762503, 49.11888853196175, 37.986260614087506, 32.604790310705866, 33.53759465679046, 26.703511822608213, 35.8878827864124, 29.49940081565611, 42.94268915730138, 49.14359946404734, 54.236750064357636, 42.66962943538543, 32.52676456205307, 21.051380326670987, 8.711013447853828, 3.3950594740529216, 1.5522341141777656, 0.17310355729874105, 0.1317021740420211, 0.2559027844859708, 0.7487670440346964, 0.5388389732087813, 0.8972359256398295, 1.5133340079938213, 3.1116780350285196, 3.4540565792591345, 4.072855336050834, 3.520549579012779, 3.259687692888322, 4.068696152779364, 2.037191672190543, 5.771074429635079, 5.023223075174517, 4.21381208204454, 4.279551496428828, 2.2302694859043246, 3.9917762673670247, 2.440740437276902, 2.574017182473214, 0.1509303527493631, 0.12188172358418665, 0.06777680989715361, 0.03761199828717978, 0.42455771517369056, 0.11368070638948873, 0.8372149592445743, 4.4126880168914795, 7.6173536815950955, 5.103781204069815, 3.3490711546713308, 4.065634497711736, 3.13837613790266, 4.23628677283564, 6.015761196613313, 11.153137010912742, 7.190683647509545, 2.7679558338657504, 5.973405482307558, 4.109736157040443, 4.679136583881994, 4.642203546339466, 3.7777180633237286, 2.6035903826836617, 1.533027125462409, 0.9441810581953296, 2.2612495912659556, 0.4638450634816001, 0.567127535900762, 0.29095093929959887, 0.179890085071806, 0.020803705556318167, 0.3882642078303522, 0.22441862391368037, 2.091323935216473, 6.322277755506578, 15.032377781406527, 19.268472848399995, 24.943924796196725, 26.51270224202064, 30.887153033287298, 32.248874441269905, 38.93232061016945, 18.920052628363333, 28.185355817118, 40.8279001328253, 37.64209616568781, 43.7554983938894, 59.84435481409873, 56.64792122379426, 56.45968275685465, 48.242572199913766, 37.89029590545162, 12.75999870992476, 2.718407963552783, 0.17004184094407868, 0.04412744967867771, 0.07792100145090973, 0.042009270194196896, 0.04693530747787126, 0.0410967254109921, 0.060151944447669296, 0.08332159956015887, 0.05146486361721351, 0.056506289064042994, 0.03345195699723498, 0.03148236218088817, 0.01758036571705053, 0.02647569031274367, 0.009423973143941933, 0.04483564816895993, 0.036971602408636006, 0.0644688728836275, 0.04043456880495914, 0.049400157069847475, 0.03434159192106417, 0.031194362917073795, 0.020321039520504496, 0.05372383090997896, 0.08963120695684226, 0.09216888086690057, 0.08163002379719289, 0.011064751531868693, 0.049216556437914415, 0.11129865558036875, 0.02796309981344929, 0.03270765661352104, 0.02766494222375895, 0.07195526794079812, 0.031064869160012856, 0.032427528903128645, 0.00017633500617868719, 0.04058597076143469, 0.020978168674534368, 0.11118772604893293, 0.01638124467835071, 0.015516482714203098, 0.024142008379942948, 0.021309329332002712, 0.04215950386658792, 0.02988221326602563, 0.08781583138531254, 0.06086861203995444, 0.005919658588320618, 0.021472948475650722, 0.018707706232465083, 0.036202147527928316, 0.05283035022476989, 0.09969786275178195, 0.01830150726281347, 0.015267293464632766, 0.025799024001424833, 0.0631402887313837, 0.0704731023119342, 0.028764117516637332, 0.016230141496165626, 0.036001658487704494, 0.05344926882835646, 0.054551232681279226, 0.05652745607339087, 0.061120172331650416, 0.03665937178377663, 0.07287437426707438, 0.09715918526654282, 0.062071163237335227, 0.04582291333785942, 0.05665597881400778, 0.05359647262300696, 0.04080956501345481, 0.11508611766921897, 0.29192993837979536, 0.8961262626032677, 11.184777790500272, 30.04050943159288, 64.36118764262046, 74.17936263545867, 71.88279921008696, 70.4883966138286, 59.37294475493893, 46.88658921949325, 44.95338239977437, 39.558813341202274, 30.951813305577925, 35.12256168550061, 35.7160908176053, 44.177937661447835, 55.77930842676471, 54.71702860247705, 40.71693628065048, 30.222579971436534, 16.683515194923647, 9.094458472344185, 2.9042604036869544, 1.743279159549744, 0.42264966594596065, 0.3712222755195633, 0.6779243809080894, 0.8011526878803008, 1.2251062354733868, 3.117119343050065, 2.9483446574980214, 6.266036850790824, 4.945527295912466, 8.120944336537393, 8.632537607223757, 9.900230976843066, 7.487157958169138, 9.966700442375677, 10.818605903656254, 7.8197852450032395, 9.738579315523948, 8.583476601108428, 4.132677364733912, 6.24868820751867, 2.585041739286915, 1.2517198848147548, 0.3540519162291481, 0.132700968834181, 0.07445087596293419, 0.23828312994972353, 0.19123046929317136, 0.888854923748201, 3.6052732650310766, 6.308161145256412, 5.5002078029417225, 6.7139465193594665, 9.74949429112096, 8.183863566767785, 8.768679153534675, 7.276777221310524, 4.466842220675561, 11.153420402157693, 11.341753005981447, 7.443415686007469, 11.097736474006407, 7.662697261379612, 5.4422694925338995, 6.595992022945035, 8.636330539180387, 4.546242269777483, 3.9664343239799624, 4.419177578341577, 3.516845390681298, 2.25672391153151, 1.1636987112222181, 0.3481165734269927, 0.2882674558749122, 0.1492973903734838, 0.4767184049612092, 0.5854610618083709, 2.227565011670513, 7.919445316637717, 18.637975377421228, 24.240877205325713, 31.29085906090275, 33.63486551469372, 35.49428862910117, 30.01215461761721, 36.22342586517334, 22.846172586564098, 30.105932604882028, 43.93266400983257, 48.58189252115066, 53.08238867790469, 65.24789041088474, 66.39765477949574, 64.82324284891929, 54.12381325998614, 41.46409680766445, 16.602726136484456, 3.357271359812829, 0.1599056703308898, 0.0874597383963485, 0.05105636638378905, 0.04907067797537293, 0.03786675699595963, 0.022912826051094362, 0.024701961195997657, 0.0638248572396415, 0.0532290491936428, 0.07793640747906701, 0.058874554120965546, 0.047405198997547554, 0.03342394882272328, 0.025699057188185475, 0.02803955155785286, 0.03809796233150748, 0.02390967689514641, 0.057456590490595955, 0.02482305671418867, 0.032918997289192294, 0.01814900597016658, 0.02936291673611249, 0.029438378311873927, 0.016259990196915406, 0.0715057735121058, 0.04323438651138737, 0.009197710033115602, 0.023872512054719755, 0.10769752905734124, 0.08118582303605734, 0.023454639820321917, 0.048495250183247754, 0.03979788079196888, 0.058269999665959235, 0.05438551254149887, 0.029118042476775668, 0.015286881375246713, 0.03472941244141229, 0.05216204576314457, 0.2050804349804117, 0.07517443068565861, 0.15383019472562498, 0.11035339501235755, 0.1565048528174239, 0.13522352782949326, 0.10502519221195292, 0.18454911007035166, 0.14391753792522416, 0.11948654968892375, 0.09424671816128878, 0.11102239661399396, 0.1440386564260529, 0.16889108495125849, 0.10627645127955945, 0.1903087123026771, 0.06656896503221604, 0.18244696480612602, 0.16978742314442513, 0.20007109329585107, 0.15046460193491754, 0.1972723442820772, 0.16967825561521516, 0.14908443325229231, 0.13407499349165347, 0.1412105662447791, 0.22738890001370063, 0.1630317380711917, 0.1811924192213243, 0.20490706928314703, 0.13550152581545616, 0.14796096531133499, 0.10703115513728512, 0.11229215670497188, 0.21237898527854876, 0.29760052119531943, 0.5098723920602952, 3.412328934477222, 17.20972272657579, 41.33556858185799, 73.89955643684634, 85.94693599208709, 86.41400398746615, 80.74395902695196, 70.03614733296057, 52.67720391673427, 48.46948131438225, 49.60406218805621, 38.633851774277225, 49.99125503724622, 42.207782114705736, 56.88263585490566, 65.83637145257765, 70.10676568554294, 55.84947962914744, 41.82933222862982, 26.79037859362941, 11.67363259100145, 4.869451945827854, 2.3594547087146394, 0.762909088403948, 0.6050892150209797, 0.5256096153490005, 2.374073382346861, 2.0129916288198966, 4.707548762521436, 5.412717375063128, 11.34026054413088, 7.559514411034123, 12.77693550432882, 11.266032630397428, 12.468627402859351, 10.278657328697944, 13.724120240057669, 16.91896330925726, 12.44304080163279, 15.68950520407769, 13.77774884623866, 8.333180354487512, 14.045043664593852, 9.134860846304125, 5.494064880955604, 1.484795700638525, 0.27815935472326897, 0.2984363231207094, 0.3968397347677139, 1.0029411664412868, 3.4561923098179603, 9.041572174718304, 11.067409688426602, 16.067050983828885, 15.44994350402586, 18.227416969114735, 16.3851571659888, 13.761719099936949, 13.377658263329538, 14.583391912521856, 24.185477649011922, 17.67878132481729, 13.430951506860795, 18.18406497278521, 15.001264560607174, 10.28157066914343, 14.544750682769285, 13.0599658912228, 5.764758433065107, 7.155883398748214, 6.47802330793873, 5.2619733348969495, 2.1799577340002987, 1.7757361598553199, 0.4272073987991579, 0.8609568207494674, 0.2340475370686862, 0.965948557901767, 0.5450875540414165, 2.873320012323318, 7.401151166808221, 18.394823728069184, 26.62723937342244, 36.6466849080978, 39.345585453894834, 42.75952623736474, 44.14045941445136, 52.88480320284444, 28.683639995513428, 38.75208377838135, 54.82865925758116, 51.07053441386069, 57.38649568250103, 75.37959221870669, 73.1128623408656, 75.5753420245263, 64.53315611808532, 54.06720169128911, 23.25840976930434, 5.30011103037865, 0.4548152157616231, 0.269893970821173, 0.22958904324520021, 0.10713790182865436, 0.2055798783417671, 0.10777819045488873, 0.08148342521200258, 0.17423811819284193, 0.1194507810437391, 0.2354743758276586, 0.12437518656013474, 0.1405815314501524, 0.11549582149112418, 0.24474411632024476, 0.13109904834099356, 0.12423041892508346, 0.15669847387940655, 0.18177942643242498, 0.16599767811356053, 0.14986032710200356, 0.08998844907769273, 0.15226103215207978, 0.14332132233727363, 0.19527775776242057, 0.17845661199140936, 0.22214539589420443, 0.16441184546678297, 0.13786795609180005, 0.2324848555989804, 0.21393293334591776, 0.13256814450986926, 0.1844142632739198, 0.16980792365727887, 0.20911955695238807, 0.20899180413013507, 0.1424789626992518, 0.08110280208770307, 0.2057175596635188, 0.18797468754553026], [0.04166217490790352, 0.018986776741521976, 0.032274767140587496, 0.11795678701732429, 0.07732294725194093, 0.018186182301912098, 0.0597673146835258, 0.04710633277652725, 0.13098133127054862, 0.03446988483530379, 0.013463964625712366, 0.055071827730224024, 0.040219217659004276, 0.07544130507496095, 0.02668983870065741, 0.056207821208743326, 0.02891690800747564, 0.060154246541881756, 0.013836752585766297, 0.031909741566426335, 0.039176330676362406, 0.04891123209569243, 0.0334089181776489, 0.030220186360360637, 0.01627765618444931, 0.0957557658154157, 0.046035383993218985, 0.051743405525602644, 0.09550227498215053, 0.03659774767114751, 0.058937419296032, 0.02665689308947373, 0.04286124423566846, 0.09396782385245447, 0.057759716160475254, 0.07495080962056115, 0.2041528557216929, 8.601195908361866, 20.006988471554173, 35.910012798924605, 57.19045562128867, 62.80404590791272, 59.37178373336793, 54.90935810150639, 53.62614293252268, 54.76477561458465, 34.94669829645465, 30.801892472851662, 33.03345241854268, 78.14839332334458, 80.01639858368905, 66.94604919802758, 48.30537719111289, 27.008878146448446, 22.75520105515757, 16.200139945553197, 5.842486081584807, 2.0496654222088475, 0.5076945879526678, 0.14571130215640993, 0.1790643955070165, 0.4556204661005928, 0.733605980152084, 0.1874151522473943, 1.292140522310811, 1.2652460557799186, 2.6250852163760894, 4.011855615723518, 7.132622272737565, 7.12813949392688, 10.232323350444918, 7.537797718278824, 7.841286207399062, 7.621178482809375, 12.743790495780207, 7.477730541459977, 6.936493467900061, 7.012896335894062, 2.513140526510054, 5.381328117462897, 1.0438277692564073, 1.188196854725961, 0.10797879823874082, 0.07705259482346236, 0.050773591839618264, 0.03908514706117492, 0.12082410090032125, 0.16099731497947248, 1.4307716705145375, 2.787768461050526, 3.5937787592411046, 7.781408775237299, 5.842316929371127, 8.168624178055795, 8.417763325475878, 8.445997526568751, 1.9067961530339335, 8.348042215070418, 7.242410394453234, 3.546294055638775, 4.385678085588641, 2.6042022724305434, 3.3987288513491234, 2.8981236104042303, 5.387403868859814, 3.8572764781213578, 3.3987560627921938, 4.122858691600062, 1.650053123312612, 1.9518014283910876, 0.9793261078096206, 1.0249128132577867, 0.6004438417092447, 0.21068067560272835, 0.04633502013260319, 0.08340660467623703, 0.0883157114167848, 1.0053958960117833, 5.872713827317761, 17.516703105741932, 32.90070960598607, 47.28418027201007, 42.39724828350929, 49.80889228082473, 30.32952339418473, 27.81966147884246, 28.3287400199521, 24.00532710936762, 29.686439037323, 45.93073506509104, 52.16240067635813, 58.0160713964893, 66.26593374436902, 58.21022872001895, 48.0606879726533, 29.911492870699977, 6.937747645762659, 1.7195060416575403, 0.07528085562009966, 0.03196642058150422, 0.0622490756664305, 0.07105945834829923, 0.04573321210280542, 0.057678844088748585, 0.05296446540723405, 0.022903353373910633, 0.059464146878810666, 0.026041502320778467, 0.04787756498121927, 0.04803503818449475, 0.042208483698026794, 0.03893978953842194, 0.019634306813860615, 0.05449354243014128, 0.020510592655609214, 0.06918438920570959, 0.028414157061507146, 0.018605720777545246, 0.0691695194390993, 0.05787086402696948, 0.0512965924046453, 0.011932281946252671, 0.06232034099558669, 0.07098111053628307, 0.06953547197964884, 0.1007169971783315, 0.026131550210618207, 0.05533270365107925, 0.019038407237178857, 0.1063575340254653, 0.06381636898544046, 0.06293651700440435, 0.03722677480489497, 0.03695073800401823, 0.015961080883449365, 0.06600238938605593, 0.029472513274560054, 0.09228137321770193, 0.08740303256819326, 0.11858582947283022, 0.07687795742024338, 0.0349185518890379, 0.09593578881674236, 0.04250142039851316, 0.07078931276356021, 0.04307811606615301, 0.03894563095884458, 0.02704212231741798, 0.024957683260342287, 0.014191327763030366, 0.06626841341776234, 0.034425604953280384, 0.2276727968766805, 0.03796710302272151, 0.015463383244951407, 0.025525835132406607, 0.034196249720069676, 0.010216973737002382, 0.019602491182365248, 0.022696128505612576, 0.035584347412711194, 0.035877127065173084, 0.010986003438912092, 0.05292431856956213, 0.03758635349391449, 0.03838329177890574, 0.021804250859385057, 0.09200834714236761, 0.018893273795143734, 0.07957217373674916, 0.036928636367402734, 0.16464070657328253, 0.44569821787937997, 8.563628427443966, 22.093150077327607, 40.69227633937713, 66.44633139333418, 74.87194338152486, 74.76056375811177, 65.96733939263129, 62.348093909602014, 57.481507255185036, 43.203432636876265, 39.166678305595156, 40.32878637313843, 82.04573877396123, 69.60423161906581, 57.94114235908755, 44.41724931040118, 28.928278223160778, 27.475022423651914, 17.518978080441876, 6.8572571777528335, 2.264284525186785, 0.9608569536958972, 0.3262186242688087, 0.47767500363049975, 0.9808532581213982, 1.9810661096726696, 2.6852894310028326, 4.1102313562746975, 5.2341088171928165, 7.042437176550589, 8.248846454005088, 10.249694547345563, 11.515191389668374, 9.954994128596399, 8.328159720666948, 8.619995828597776, 8.877375875749896, 12.826419145830217, 8.585983976241081, 8.838259058613932, 6.250998973846436, 5.5152868647729205, 6.519360676888497, 3.465656253599352, 0.8174740991765453, 0.14248423338417085, 0.07483100113008292, 0.0688657655771221, 0.14615826849495211, 0.1361640692958909, 0.6628564733170694, 3.132900509142107, 3.9082949921008083, 3.856272596505381, 7.830894377923782, 9.545696762300308, 8.448011663652236, 6.04855417243896, 4.961817879830638, 5.49886929412042, 6.842116338591422, 7.1940916968930155, 7.612984651519407, 8.95394838625385, 9.411725267287224, 7.209534558557696, 7.299864292144776, 8.290095079329706, 7.045224510854291, 6.681247680417954, 5.358221925074055, 4.556282556826069, 3.384048890682959, 3.750420818405767, 2.3766023305154618, 1.3871658232904251, 0.48538540279673, 0.35264758513339106, 0.14851660888281562, 0.21230421509713898, 1.3797780390708678, 6.675887761577484, 16.198546482670693, 30.51430036944728, 37.69356942945911, 38.43519941453011, 45.496740495004964, 33.05462929510301, 29.08860118158402, 35.88645896603985, 34.803720058933386, 37.131529085097775, 51.90796044565017, 62.520003549514286, 65.30983640301612, 75.0121759599255, 67.105101308515, 56.58828943006454, 33.2348818163718, 8.643627128293438, 1.5870458849014777, 0.09452859255214853, 0.029490899384742784, 0.0954231457604516, 0.0582278456779257, 0.02943699169273098, 0.010631281747332504, 0.04636651783760998, 0.051463488489389426, 0.0468351606339697, 0.03060089566955163, 0.037020467326886235, 0.01648856976610278, 0.01884598701801752, 0.02788859393237339, 0.03489457333700792, 0.06882293360127557, 0.04408847112509032, 0.05816021543597022, 0.017401392256180127, 0.07041354663670063, 0.08280897948650584, 0.02826342543196534, 0.039366910369285656, 0.019191090475707766, 0.018462029496027578, 0.013803044717097956, 0.07639478576639969, 0.013548831845964155, 0.021972462700139132, 0.038980802055448294, 0.035797473073246024, 0.05537350932436605, 0.057215257472689116, 0.05810588064994063, 0.06493855372912462, 0.09091106408666219, 0.02465625255999546, 0.04846091795292112, 0.1564205218587191, 0.17460649923211144, 0.17093057954503646, 0.24343766061769379, 0.267029874507458, 0.15593908156358427, 0.22731511042483393, 0.10635959480198161, 0.1646112581534732, 0.09629436393058109, 0.07692174700599524, 0.23644042802193474, 0.15305993928303643, 0.21047239161787495, 0.09246488957996331, 0.25359261570678604, 0.26200246846964287, 0.14232323234600408, 0.13842654144090993, 0.08469013136721427, 0.12878295004127488, 0.09888151179878943, 0.08627539710892786, 0.10116768670418572, 0.0959648235490726, 0.21081244272570457, 0.10510321826704087, 0.2749906618508601, 0.11792929212172186, 0.14619858004152775, 0.12153666992221149, 0.18283265943248428, 0.13476272594303856, 0.16444065037273592, 0.13866418191502172, 0.3527918241677746, 0.8780746570517941, 13.069048139356799, 30.285384962635657, 54.71811902138495, 79.25079114975469, 86.04107287622269, 84.22184621134113, 77.4634611991144, 70.91220871094735, 72.7644774221605, 50.31387390628938, 46.54950464925459, 47.200053276554236, 87.60730666498985, 91.34143444799608, 80.11510110670521, 61.81733054499473, 38.914928820825395, 30.789509550217662, 22.42360584197506, 7.720926317476458, 2.957042023058861, 0.9639263922168363, 0.48283322684226504, 0.33765818623285143, 1.4327793111724239, 2.8107101590402666, 2.0441645431903104, 6.1997772320624325, 5.7613758790877565, 10.261848011324483, 13.506217868097368, 17.719717141120665, 20.082127355760147, 22.217695136224073, 19.158948506078413, 18.900646701935802, 19.20245739721483, 25.702581790185747, 18.90048784594382, 18.53539166911956, 19.888489746278335, 9.9483064874526, 16.00166605364892, 11.579120139921866, 2.818828239556282, 0.6752878127078856, 0.19007222096045173, 0.3081659768377581, 0.6949072018746407, 0.45954798438376, 0.9588079442900996, 6.210385772489733, 12.84909240661129, 12.329638215803332, 16.82409490308454, 16.633575577889722, 19.282124657784742, 19.799712780983217, 20.367652370083718, 13.030549095522973, 23.794580121194166, 22.915312205591512, 12.43541963638798, 14.796723742638866, 13.038791956440097, 14.348572358008354, 13.64998842439344, 17.369353386663622, 16.76231953405565, 9.150094351460858, 11.395734625477946, 8.104999901786927, 4.515032950908908, 4.785556860508458, 3.787346991800493, 1.9502919287450853, 0.7853905207687809, 0.3104869781001922, 0.333591454452084, 0.20436256463008545, 1.7807178151222969, 7.326170158001685, 22.452858878720193, 40.6174139822683, 58.15980272908365, 56.94110662706437, 68.55958677107289, 44.63239915909306, 40.346652769273334, 41.31457997906593, 36.131101116057366, 41.76225577631305, 59.60374093824818, 67.94040141567108, 73.97808228769611, 86.13517053665655, 76.27967419162874, 65.51353685317501, 44.59758812381376, 13.219278839326675, 2.703541200007162, 0.3145157425634323, 0.15960488889005878, 0.1688700941421332, 0.179807577402361, 0.13274166342471877, 0.08270284566547602, 0.13230238860893634, 0.16037329039987058, 0.13047937514080157, 0.1447190191116064, 0.1808320361399843, 0.25170307516330676, 0.1335160250985815, 0.11901169774993775, 0.1359577311743652, 0.16296294337559133, 0.10107838383485233, 0.13440729178968938, 0.1200502678271263, 0.10374865224284512, 0.20474827457820216, 0.18403388529775605, 0.1204894124079616, 0.14947351398727587, 0.13118295029046076, 0.12590088130485627, 0.18526793036970401, 0.2070383412102538, 0.18308096385050207, 0.19608668532342682, 0.16562776489844247, 0.2062459764701705, 0.17257180034873948, 0.25068289119630094, 0.09302741262100397, 0.2026852610851488, 0.11686583184787344, 0.16265493006475512], [0.04295035175258114, 0.03770401310776511, 0.049904932403155876, 0.050101759543101636, 0.03103082421265783, 0.11258955203717756, 0.08923313234962764, 0.05813444423819742, 0.09551555128587831, 0.051062249939047524, 0.055470599477449735, 0.06054212068838458, 0.061652664726059285, 0.07043172590314381, 0.023327810134017662, 0.06103858396771455, 0.05563047436636783, 0.02643283918469904, 0.044081400133549206, 0.07531375909644751, 0.07499670594810479, 0.08075237048849945, 0.05506956010996815, 0.03256104653701186, 0.0027263151611306618, 0.03054160046421232, 0.0589841659811716, 0.01849702439240871, 0.04795939466285129, 0.014295631591531058, 0.01015714993099532, 0.09848466293225366, 0.049516161933781645, 0.014744546666230648, 0.06883313023154775, 0.10454057265193233, 1.7543343598804169, 15.120358505556661, 26.423691895700273, 53.623158008821555, 69.28545275042134, 58.69229585893693, 52.9615875213377, 55.635584938910704, 43.92630584778325, 36.18933262363557, 32.34170321495303, 19.548022131766043, 18.90663420000384, 26.359119876738518, 32.68341029843977, 51.01631549096877, 58.71041720913303, 34.434542655944824, 9.540730061069612, 4.581701476727763, 1.5460693740075635, 0.351658534979628, 0.3527633869840253, 0.1476865832603747, 0.6966370896947, 0.42596670408402726, 1.4992242618914575, 1.6442702013638713, 2.1290943987907904, 5.456398360190853, 3.003078636623198, 6.075612152776411, 4.021528916012857, 7.622816072356317, 6.907563046101601, 7.155481355805551, 6.290126087204103, 9.711189404610666, 7.841862795814392, 6.088701592337701, 7.235688922866699, 5.480676850964946, 2.710031987197938, 2.266581072922676, 1.306801361422385, 0.27689714825922446, 0.19909040882222115, 0.050500186550761425, 0.04284595312069982, 0.2231744818028904, 0.22830776119184112, 0.804102800546154, 2.519033152249552, 4.249925834517326, 1.971304433480386, 3.908879670404619, 7.519937695995455, 3.571521759994569, 4.254155620451897, 3.9206109892937446, 2.8865165816199396, 4.883338607126667, 5.372079168596576, 7.1529783933393425, 9.389302057604636, 8.114292977317687, 3.6440022578162536, 3.505060139202303, 7.435274806714828, 3.732593400824455, 4.4484855282691225, 0.8865200716160959, 4.491764470454186, 2.5121861648175026, 1.8548377411019419, 1.29780994067269, 0.764541284691903, 0.5119943943235182, 0.9640595076545593, 0.023972892555438226, 0.08501551955217317, 0.20702602251643137, 1.4409183518540476, 4.242936170870259, 13.544936564660842, 26.079315639311268, 43.43849243656282, 33.85307873449018, 31.233176685148674, 24.906411247868693, 17.620483136946156, 21.77251200522146, 29.107228517532352, 36.73060009556432, 39.87129680572018, 46.57457643939603, 54.99441469869306, 54.314020756752264, 55.93700731954267, 48.330095967938824, 19.860509518654116, 4.263610984048536, 0.8833414196006714, 0.05951622553590325, 0.06576964421378029, 0.02412950582501869, 0.044564460704643885, 0.036788871286497, 0.07276486965917772, 0.1298773372846265, 0.11569747881543253, 0.02252851804387906, 0.039958249807598135, 0.07422376153690201, 0.05272600904948289, 0.031115942326704824, 0.03136142754116126, 0.0746926686335956, 0.0662723281270554, 0.013065624760553963, 0.01458206133271057, 0.026599660575870546, 0.06627834957814024, 0.05315735102480939, 0.05390379262427169, 0.07737042938148783, 0.025312123414609703, 0.07164191499712967, 0.02816443729604925, 0.04514312138780952, 0.047359731679241505, 0.07262134308656377, 0.03145273181519682, 0.037297599633494695, 0.055816779288673596, 0.022716774575171933, 0.12893319520498478, 0.06225345768935739, 0.037127072291989485, 0.012320786200073219, 0.066170813816209, 0.024135218925714016, 0.022133902323642568, 0.059587054194942604, 0.07040601599240495, 0.052752619113532774, 0.05186475002236905, 0.025270446316309036, 0.021776177567399798, 0.04703724696751564, 0.019997357796396942, 0.05663672702447061, 0.025117837771352743, 0.1001727759778019, 0.011667792005614649, 0.058470530841018886, 0.06477682490742977, 0.031961444840436025, 0.1195970731937597, 0.02355088536146908, 0.041389351845869136, 0.009460052054735922, 0.07547181069610581, 0.011839004995812093, 0.05558001215479547, 0.02159268418777614, 0.07519341434442228, 0.039887321557128624, 0.10774005459801805, 0.06535833926811334, 0.055602542800648566, 0.033278020564466715, 0.015611628919178921, 0.060372428382716836, 0.04346548842506544, 0.11811885291770582, 1.5043202787637713, 16.662859993596232, 30.789950816862046, 57.99092115894441, 77.02785845725768, 72.45440621529856, 65.45783919672813, 69.4454070060484, 57.12987853634743, 47.141492289881555, 36.06520921953263, 27.356074586991344, 29.636958337599236, 42.08092874096286, 49.90580620304231, 59.46083330339002, 56.40736618349629, 30.98589085763501, 11.59779650549735, 5.9042403678740225, 2.032812836189424, 0.44587732923607676, 0.3369311075056753, 0.6993643014181046, 0.9169348653766417, 1.8006494617269886, 3.100110475094088, 3.9930753073384686, 5.723333791379006, 4.579355409068446, 8.167894126907472, 6.4556903127701055, 8.05235335903783, 10.642612095802061, 10.57916775826485, 11.694712388900019, 6.772625177137314, 8.59568399767722, 7.482201553160145, 7.5356507109057524, 8.28612171834515, 8.67169855102416, 7.813779605973152, 5.237150615261448, 1.2003103595587516, 0.7944128914706169, 0.42710584618391534, 0.05936462439656739, 0.06789166179876174, 0.22266071259735093, 0.04736738106716545, 0.6908807663186904, 1.5583682108309962, 2.0076333034423093, 1.708370555312403, 4.918229560698233, 5.608799601754835, 7.22682926923998, 6.514976447628391, 5.833825488244334, 5.648817093141618, 7.575806956137381, 9.58703266036126, 9.559063219255018, 11.517858601385548, 9.505252222861014, 9.095516531698166, 9.4028450212171, 9.510146360243521, 9.441940265317118, 9.866702556610107, 8.97508898089009, 7.037194928815288, 7.354377392799624, 4.780946604667172, 3.867382955166602, 2.6884207081410194, 1.9958573675924733, 1.4616495491035524, 0.4896625023215048, 0.35788781039657136, 0.37515543220985326, 1.549940385645436, 5.258559892254492, 14.628683520901589, 28.602211590736147, 40.86218164813134, 35.825528867783085, 30.609498254714477, 30.608001870493737, 24.31956583453763, 26.212160433492354, 31.299978571553385, 40.50901143781601, 46.354166692303075, 54.18996403294226, 64.78088909579863, 62.3541735833691, 63.89728499997047, 55.06601364381852, 24.017105986995084, 5.672055665523776, 0.9557448796206905, 0.06768142428970145, 0.11083468208990752, 0.0048015853427650955, 0.0515494627066918, 0.01508689316500339, 0.038175582359995575, 0.03581423124658965, 0.04760349702630793, 0.029184705532726743, 0.044805992905411034, 0.06649413356377233, 0.03220730160753573, 0.029716740189600858, 0.06082514038069114, 0.06206729832375723, 0.043870316097332586, 0.028623990459187378, 0.02995264738978398, 0.020259612675515876, 0.10232899172772324, 0.029703699457909793, 0.02526420461494596, 0.010455538304672848, 0.06450840302052037, 0.06104050301796487, 0.08294139012333848, 0.01343071066413916, 0.05189818209938465, 0.20819007779561705, 0.025949903102892063, 0.02819073326405018, 0.08422411242199522, 0.022471850520120035, 0.06668311979381308, 0.06355472697666095, 0.02487023049334605, 0.034423992338199774, 0.21036947536612713, 0.09137977966137471, 0.13648322152514614, 0.2660823769627079, 0.17569921640378816, 0.22080883293622927, 0.153225414274681, 0.09848185138957155, 0.12404147866031817, 0.19222831413630517, 0.1873192380392744, 0.29445710922441176, 0.13234911997231746, 0.15350837651039326, 0.10431881318049085, 0.11584641396879189, 0.19145315573100122, 0.123741133889604, 0.21253439387486828, 0.21983325060817505, 0.13583849724983016, 0.12629892526855394, 0.16804707056332022, 0.36465631978165725, 0.20666400000693338, 0.12516313097289494, 0.20425345838790943, 0.2295997837978986, 0.3153583473495899, 0.0955921830609441, 0.20816902569945783, 0.17194112612595483, 0.10932885966594182, 0.16999509425893908, 0.09018938627935226, 0.3004356593854966, 3.5134388121866413, 21.87956133196431, 38.56676747722011, 73.07209322529455, 88.2568354760447, 83.81328428945234, 75.81664623752718, 77.71107258335238, 61.2525406191426, 52.003815327921224, 46.418348435432684, 33.7530465279856, 29.710345883523267, 38.661214228599306, 45.97428906348444, 63.20932480596728, 66.29659098963585, 40.966928543583045, 14.29204119789985, 6.338985581551829, 2.2162587796488116, 0.869877393687925, 0.440979422700982, 0.9260599531473653, 1.6697333705040718, 1.7570047585233566, 4.393242376465952, 8.688826560974121, 9.69306020967422, 14.056601908899124, 12.249201190087105, 15.757777979297025, 14.394688644716817, 20.653140121890655, 18.558604255799327, 18.85523546126581, 18.025224670287102, 16.62386771171324, 19.010359318025653, 23.016372073081232, 19.268619937281457, 18.707954383665516, 13.575145679135478, 13.211123251145887, 4.206466953600607, 1.375352870072088, 0.8959793575829076, 0.18376492714929968, 0.19993526590687616, 0.907111595715246, 0.6055939750325295, 1.7750463130012637, 6.095782941387546, 10.136327262847654, 7.745217555953611, 12.003002839703715, 20.412022221472956, 14.601464233090802, 13.178676424487946, 14.686391392061788, 9.935308733294088, 11.022890786970816, 12.74749517440796, 16.9515876231655, 23.498256821786207, 16.936827744207076, 15.029804706573488, 17.582806810255974, 19.22404612264326, 14.532939445587898, 17.22706940866286, 11.840518655315524, 11.524363852316334, 11.417568499042142, 7.47047366634492, 3.2448390703047476, 2.4327473823101293, 2.161861634062183, 2.076435108338633, 0.7096099000303977, 0.6725357797357344, 0.5886099896123332, 2.1980810453814845, 5.599519764223407, 16.796067607018255, 31.53258885106733, 54.15047753241755, 46.5539094709581, 42.762558229507945, 36.62953630570443, 26.604899514106016, 33.25627050092144, 40.653703751102576, 51.6299428478364, 53.45284477356942, 60.918754762218846, 70.22617832306894, 71.8681844588249, 75.19409548851752, 65.34135656972086, 33.4383116229888, 7.774753983943694, 1.5238522113330903, 0.16186630383374231, 0.2013867267317349, 0.12041140167463212, 0.15361038877839042, 0.13036927298432396, 0.15686332067895323, 0.1428609034947811, 0.2308369085433022, 0.13904198583575988, 0.12909058030814896, 0.1974429214192975, 0.10826759040355684, 0.15556903045263984, 0.18075841509046095, 0.24192175647664457, 0.11339872474631957, 0.09795047748353213, 0.1788448500296762, 0.14542723675408673, 0.26093169205611755, 0.10285952293704595, 0.14438155738096084, 0.17084995645188517, 0.10778489372422619, 0.18194419662317923, 0.19035086246027103, 0.14859312574469274, 0.09053581123871189, 0.38866257355097805, 0.10973356859458071, 0.2136092152326338, 0.14290738971002642, 0.14717816134854672, 0.2956785598108846, 0.16142747334895596, 0.19817864161825952, 0.09290881454944612], [0.013319180711292693, 0.041451600320156545, 0.004979742919996141, 0.05368755281632466, 0.07232457594645601, 0.029462523488027435, 0.045177798357702074, 0.026185630272412976, 0.05034163316351272, 0.11297058118807693, 0.008380951138303406, 0.03492793646611033, 0.03131943826203144, 0.04254087775705322, 0.022113706330738725, 0.04540499322296632, 0.10459934691748313, 0.05965525900284129, 0.03747801333966275, 0.029804974366279862, 0.08344171448580681, 0.02081270708942846, 0.08229920925993113, 0.07348404235897527, 0.08441436269711103, 0.033419352295177604, 0.011211203602743487, 0.016479489708980246, 0.019606283317590435, 0.023170903835806157, 0.049915795529922175, 0.05721380956651223, 0.025589656002158602, 0.07540214266027175, 0.1556575442514112, 0.8230839465414325, 5.011606485612932, 12.486918395565404, 35.15236385406987, 64.21427134544619, 58.21775967074979, 55.82628665431854, 50.947579876069106, 41.002265176465436, 37.184281041545255, 36.9848128288023, 35.10705655620944, 22.691995982200872, 31.57665079639804, 37.52372295625749, 38.26943612867786, 29.532925313518895, 17.815111144896477, 9.076240043486319, 4.470017869626322, 1.3524670658573028, 0.059091774521455656, 0.10243006936845281, 0.43576558150591393, 0.3529435095767821, 0.9442927231711726, 1.2767718179572014, 2.6568402349948887, 5.380075900785385, 3.8836732939366376, 2.7253042257601217, 9.397845960432484, 4.264037051508504, 9.336936454619131, 8.882871116361311, 6.014014761294089, 5.5658501386642465, 4.086111721492583, 5.407117211049603, 7.912311505886817, 5.064650168341975, 4.040192533885279, 2.905501588698357, 3.7586239653248943, 2.856360664290767, 0.4086266716401423, 0.7007370084043473, 0.15028965809652883, 0.010094778882640024, 0.07961328201476606, 0.9790691312762999, 2.511979259790913, 4.760583129621321, 7.306018000648868, 1.4816495920381239, 0.6934261394123877, 3.8925530497104894, 2.729175850268333, 3.2691205028564703, 1.9832431476923729, 1.131032109260559, 2.1657641472355014, 3.560119675051782, 6.05752561361559, 5.558589831475289, 6.3364169193852335, 9.28265771558208, 5.130946068994461, 5.948697001703325, 5.414602564227197, 4.395862029444787, 7.0058846089147755, 5.971075594425202, 2.954851624465758, 2.123136808795314, 4.815553676697516, 4.754898634649092, 2.0760105117674796, 1.267133206129074, 0.8155788589389095, 0.3991363131471219, 0.31733258657397767, 0.05332139726247519, 0.4013085094911437, 1.4782699798384022, 4.612331265403379, 11.518125322557266, 30.151906705671745, 46.714773716465125, 42.136367520978375, 37.19133346311508, 40.11435824055826, 28.82754195121027, 30.67467235749768, 35.59149280671151, 38.74609039675805, 41.83862432356804, 44.375581972060665, 58.01008193723617, 53.62006325875559, 52.07864630606867, 32.35967943745275, 10.063598675112571, 1.888080073460456, 0.2718524286343206, 0.03936011899983691, 0.045376866304826353, 0.04237304704504148, 0.06965771662972628, 0.07738183643068038, 0.027296519049653606, 0.07973121358982979, 0.05057519804986735, 0.04569831296741482, 0.0253950945672489, 0.007585280250021888, 0.007368015799476135, 0.052379902016611836, 0.02562931828921841, 0.09854168285645785, 0.035672868872361804, 0.07243182059497603, 0.06931798727882486, 0.024460641584629496, 0.051813188474625356, 0.03372381095804515, 0.03465321733646336, 0.038606238686629844, 0.08317106328303776, 0.04463613589083956, 0.012599539740251438, 0.02970355198598437, 0.0583531623405795, 0.07333468585725754, 0.08014981935341513, 0.021561795522669153, 0.068686455037565, 0.027770124180542848, 0.03376705279093116, 0.09121623521129932, 0.01836170645190343, 0.033005216654630444, 0.05766079122681291, 0.05873898337144525, 0.05006382286909127, 0.04734761982915863, 0.03756606748567955, 0.07179371531932585, 0.050318489647320205, 0.01267598095094605, 0.0829918293522731, 0.052330929846052206, 0.049283566148651224, 0.03751220767416301, 0.06276751800830807, 0.08034184695251527, 0.01810006252790411, 0.04100137810793616, 0.0622262922115624, 0.025333079749778397, 0.017824364720933863, 0.056877401206762566, 0.028512070759109436, 0.11182274399024826, 0.07603332250108642, 0.011967691487722821, 0.021745087804212686, 0.016530589688749566, 0.03551078765022178, 0.015375288879318584, 0.08254464084823286, 0.061456220630075664, 0.040011404818224336, 0.053974039056488586, 0.02015623102535404, 0.019172811617834434, 0.5945070893053086, 5.524063658329749, 17.684423654310166, 40.333995280727265, 73.04626049533968, 73.68930955086985, 71.43715520058909, 62.2259787590273, 51.8167104259614, 43.10563618136991, 41.329069214482466, 40.21030725971345, 30.50256071552154, 30.039207204695675, 35.62762568073888, 26.021019412625222, 29.743301637711067, 27.029721621544134, 11.727680890790879, 4.4145119190216064, 1.3055435063377505, 0.3272050084365953, 0.09326471601642909, 1.0460848481424394, 0.6605537355907503, 2.2902812592444883, 4.641067529878309, 5.163526256238261, 7.657576116823382, 8.69088678590713, 8.783959727133475, 6.534928073806148, 9.722628997218225, 11.40916285976287, 6.947882559991653, 9.702979883840008, 8.285373526234782, 8.641933644971541, 6.959011304763056, 5.354405949192663, 8.190162893264525, 5.597971898894157, 7.396283505424377, 7.492397264126809, 4.617348467150043, 2.1428003859135414, 1.464712307337792, 0.4239638131712714, 0.08194938287018769, 0.19661367720653936, 0.4979220026683423, 1.5619986095736105, 2.9589769772944914, 3.9259657600233635, 1.2989601757257216, 1.5058124954662018, 2.6112929371095475, 5.551285397621894, 6.891426905508965, 5.770919986309544, 5.4093681612322415, 6.2251314328562835, 7.470983574467321, 8.313342967341024, 9.818477995934026, 10.39247666635821, 9.66585563075158, 8.006556745498411, 7.433103284528179, 9.974018604524675, 10.021261592065136, 10.56493151572443, 7.9011812902265985, 9.745726854570451, 9.110156778366335, 7.534912815017085, 8.788468491646553, 6.588752308199483, 3.1101066354782354, 2.5647089077580363, 1.0663463415638095, 1.2167265818965052, 0.36184159017378287, 0.4038897048561804, 1.492898214247919, 5.055991045890316, 13.412099615220102, 29.466919668259163, 40.741309888901256, 45.770486631701075, 32.76019461693303, 29.230753760184015, 33.385728328458725, 34.73986779489825, 45.48637367063954, 46.22769771083709, 49.32455408957697, 51.312226941508634, 64.51938859878048, 65.41677198102398, 62.72366869834162, 37.92452642994542, 11.849012547923673, 2.3085639169139247, 0.041212442991954666, 0.02422419620767957, 0.10699675778948492, 0.04706016831821011, 0.04444636825111605, 0.038365901583024574, 0.010318827999365187, 0.1654888884795289, 0.03738996685452519, 0.04657486693993692, 0.073215750707013, 0.010579559321124709, 0.06940679219100745, 0.052828289448253574, 0.01746496031691711, 0.009346110840147782, 0.02024536727056388, 0.06368482402796227, 0.07324651679805211, 0.0730146756095271, 0.04233125311833236, 0.05290213266327497, 0.08176319286107056, 0.027149322915882356, 0.0077260790708204435, 0.013590242728711137, 0.052116402244615945, 0.03151971088241666, 0.02056212739027556, 0.051980299063988274, 0.002814551492431952, 0.04204310829781237, 0.014566429308615627, 0.03989846047554766, 0.025360505697467638, 0.054530628746555704, 0.015285655634567864, 0.12285667005926372, 0.1404081963964047, 0.1898576090893438, 0.1647266616383868, 0.14410368196906584, 0.12538354979046892, 0.15405476573974858, 0.23305591285949756, 0.14200800248692114, 0.19875939755189806, 0.2247275718517842, 0.20295291688413392, 0.09915639180690052, 0.104977710082406, 0.12280929518202621, 0.0986493948186117, 0.371605932352043, 0.33649973871727146, 0.04730869873216556, 0.06386758962405786, 0.2575397611625733, 0.17990690836262319, 0.24552414704474712, 0.21533240744423485, 0.1438387074778157, 0.17944621372847788, 0.24080008118143006, 0.16513365350904005, 0.10307686974204357, 0.16635392432010945, 0.1669145474630979, 0.1354199221297618, 0.14396269114748125, 0.16440013964329997, 0.3344366332936672, 1.286495373614373, 8.04593930321355, 21.50376492930997, 53.8524519243548, 86.26161990627166, 81.67929526298278, 80.26091129549089, 71.24091902086812, 58.1701813205596, 51.76884574274863, 52.49810064992597, 48.48615530998477, 36.79760986758817, 48.53200389492897, 53.72580643623106, 54.27815852626678, 39.83062182703326, 24.583686474830877, 12.480349406119316, 5.478836278761587, 2.048653818426594, 0.4919607967378632, 0.3871204692029184, 1.0987852009073382, 1.2048805336798392, 2.477054720924747, 7.599520135310389, 7.586440011378258, 13.688261931942357, 14.155574094864631, 14.250893573607168, 19.918580209055257, 15.691289882506094, 18.39030319644559, 20.32598307055812, 20.415081670207364, 16.995694675753196, 16.73272328992044, 15.730371398310508, 18.315344741267545, 13.229458370516378, 13.265275493744882, 11.266319944012551, 14.265646588417793, 9.163779500992067, 2.3588643920037056, 1.6641810103770227, 0.5980909711891605, 0.15333225289660116, 0.4096482039218949, 0.5549160331006974, 1.305989063074512, 3.342003533917089, 6.654062223049903, 2.5383292523122605, 4.473420035454535, 11.379968658570322, 11.392804614959225, 13.544981671917824, 9.52757933447438, 9.538415862667946, 11.995750377255103, 13.695358480176619, 15.297299565807467, 17.138678796829716, 16.07595476412004, 18.603540889678463, 15.93641056168464, 17.681591703045754, 18.8129444660679, 14.255153267614304, 16.871484979506462, 16.201318617789976, 13.28970499577061, 14.507706838269389, 15.620038067140888, 13.760931684124856, 8.156635943920381, 4.629988305030331, 4.0516968456006826, 1.342255297687746, 1.2652600292236575, 0.28421871183860686, 0.7680648601343556, 2.2508241764960752, 5.837648818569799, 15.311163183181518, 37.51794530499367, 57.51271755464616, 55.52714709312686, 48.88040842548494, 53.18773177362258, 41.61275071482505, 44.554802909974136, 48.27030335703204, 51.008627645431034, 56.32556123118247, 59.479009566768525, 73.37613967157179, 72.99490098030337, 72.37431926112022, 48.04038970701156, 16.98248805538301, 3.646099990414035, 0.5938136878032839, 0.21124483807192695, 0.1778940583068517, 0.22006899118423465, 0.12052626889799872, 0.23216326721012595, 0.18621941157166036, 0.27218791385812147, 0.22789407371272966, 0.08133730160132532, 0.1123221567080867, 0.09461446334758113, 0.2306881649119239, 0.21682543619986505, 0.13301555517940752, 0.17589865973399532, 0.11532644711194501, 0.1663021061329111, 0.23709359458617627, 0.27567303168677515, 0.17311740816841203, 0.21525281090890208, 0.20103109339552544, 0.1226016853545462, 0.1468849641781661, 0.22670340453905446, 0.11222563729050661, 0.1090082442087512, 0.13402804762365358, 0.12493503595431968, 0.18535668931661115, 0.09847371553581569, 0.17690231152359517, 0.17762986522528434, 0.10205218117804297, 0.19771806955818208, 0.1910153824475504], [0.07156326841082304, 0.05347884365267331, 0.08258184207783592, 0.025381473523955193, 0.02638913578383865, 0.027266310287579417, 0.054085972163105206, 0.02449894598084352, 0.04727859147674134, 0.030770858021212683, 0.06617530309144529, 0.02219369931657228, 0.029699441924270605, 0.005714281428334934, 0.006982984796782295, 0.0018369908620145233, 0.0247433835700635, 0.05089162683655178, 0.06384647624086469, 0.07037760179129339, 0.01586665767395208, 0.019179593411184127, 0.11349531311181285, 0.013567493747799628, 0.060056156644056884, 0.07238773989581293, 0.1253545150581387, 0.04367349661826607, 0.054160914714297945, 0.10092394817019663, 0.08934216198301123, 0.05051594114892426, 0.019658235570175514, 0.06040381883541423, 0.13882222585380077, 0.8026770189885171, 7.068973481655122, 22.33334622075481, 44.130747625904704, 50.57652365776801, 47.92991615110829, 49.15492334673482, 43.08440439162716, 47.99268584097586, 46.32477637260191, 30.98151545370779, 25.487331921054473, 32.27779603773548, 43.882916588937086, 42.64276512207524, 44.98857782733056, 23.208709416850922, 13.888587182567967, 7.3935221568230665, 0.8481412116558322, 0.22012011989230112, 0.06749544112432389, 0.25284158907109694, 0.1286618621839631, 0.3930774463280555, 1.469053022803799, 1.9047912090055406, 2.670628837039394, 2.0261386781930923, 4.834725731803525, 4.787871058910124, 2.239289221263701, 4.123434299422849, 8.425843408030849, 4.560220126182803, 6.418224323180414, 9.541136026382446, 3.9045650632150717, 5.473027248536387, 2.3213908028218055, 5.943684702919376, 4.046376395610071, 7.388726078694867, 5.14664682649797, 1.9827529739949012, 1.2172564695919714, 1.4690088961393604, 0.1850470059341, 0.32651454871219976, 3.1672599815553237, 5.965435226117411, 17.099935585452666, 19.731069341782604, 14.055343808666354, 5.048562567080221, 1.4117987982688414, 2.4176479731836626, 3.138050090882086, 4.984311201880056, 4.859303793599529, 3.733660040363189, 3.930856220183834, 8.168400602955973, 8.340061172362297, 9.930987261956739, 10.868065030344072, 7.745062622331805, 7.162146933617131, 4.903089702129364, 6.13369559088061, 8.308050709386027, 7.189624117266748, 8.138312101364136, 8.210760729928172, 7.40536428266956, 4.75149009496935, 6.489022124198176, 6.529984416500215, 3.456825282304518, 1.9452043694834558, 0.8378579215176645, 0.5520137856083532, 0.33766033127903944, 0.10628802686809533, 0.032210837103306286, 1.2840106746842785, 4.45503588645689, 11.669167953152812, 24.4851565361023, 32.52467393875122, 47.25360931888704, 44.69674171939973, 33.045905943839784, 21.59978847349844, 21.80586587998175, 25.567381612716186, 37.42990770647603, 49.08866666978406, 55.50797454772457, 55.02539357831402, 51.63925455462549, 43.76056609615203, 26.223896165047925, 6.666990355137856, 0.22899282765724968, 0.011404671447141277, 0.030624824425866528, 0.03148220896330332, 0.09819712715163346, 0.07579663963687998, 0.058280717236019915, 0.018539101771649816, 0.06785161072208036, 0.0763528730960623, 0.027702306247045918, 0.06382807097848385, 0.08270767201939899, 0.019196966370087, 0.059984485288300825, 0.09551077855811005, 0.0248299706577053, 0.015816084379630706, 0.03256091247162512, 0.013803630774360032, 0.05043432980235066, 0.029925225272534356, 0.08965842606079194, 0.018582230606566996, 0.04627140802181056, 0.021972684865637172, 0.01637710205790016, 0.038915849290788174, 0.016311932873401432, 0.001661962394850449, 0.03847476650750445, 0.10333921655171341, 0.007339441198705426, 0.0038439742404021205, 0.10357835855815681, 0.07694827663081308, 0.0345605360193839, 0.06723572199623432, 0.019314377005362225, 0.03701652580451581, 0.030262459092022433, 0.019549529608939926, 0.015506432598246443, 0.07337132018179664, 0.0453853928634236, 0.0770414176006471, 0.017829076161668185, 0.08106485775281345, 0.061372000754119894, 0.046464305130704764, 0.07968118804837428, 0.061423546980105104, 0.0356940052381927, 0.05593075018916881, 0.0498783951174588, 0.04029463518471007, 0.02573786145677009, 0.06616269328421162, 0.03826563216505512, 0.023181602253668734, 0.05323826906181151, 0.012124684928435714, 0.06347621062530145, 0.0837962752989223, 0.03583041102355046, 0.09804211692103455, 0.06302982268314208, 0.038781634516893856, 0.036186021377122214, 0.054897818519102956, 0.050549947791883064, 0.10932840767406649, 1.0098794102668762, 8.248169845150363, 22.448254016137895, 53.839629696261504, 65.64164930774321, 62.792973056916274, 59.7654837946738, 52.26815954331429, 53.36437571433283, 49.64289757513231, 40.69653603338426, 34.51728113235966, 36.169610946409165, 45.90938560424313, 44.12805687996649, 42.22696250484836, 26.216806480961463, 11.688892572156846, 5.723819674984102, 1.0490849710279897, 0.3306692273866746, 0.3965138716082419, 0.838112875578865, 1.8601885894613883, 4.299688944893499, 5.187011937941275, 7.4799608991992095, 8.706320331942651, 9.611755359557367, 10.156684364041975, 7.861911500653914, 9.667399083414386, 9.17803535538335, 9.574199645749985, 8.778700809324942, 8.272631706730012, 8.758833023809618, 7.497614016455989, 6.979918028077772, 7.063686616959111, 9.245640347080847, 4.8458069178365895, 6.689171848758575, 5.141029011818671, 4.327238692391304, 2.929405983417265, 2.00120760308158, 0.7100919838393889, 0.3385708420988052, 3.2470910010799288, 6.666732949595298, 14.284735783453911, 17.46293721660491, 11.748947001272633, 4.332857977959418, 1.5088729247931512, 1.169154482983774, 3.245918212398406, 5.102048497046194, 6.162399005505347, 5.332134731354253, 7.05709066121809, 12.752014725439011, 10.568338094219085, 9.575063547780438, 8.484805457053646, 7.816028104674432, 10.884632141359392, 8.95693232936244, 11.587845452370184, 8.234406248215707, 11.497769201955489, 9.414662141953746, 11.679286687604844, 9.196444019194573, 8.269504597110133, 10.072810361462256, 7.759036556366952, 6.316846253410463, 3.981281230526586, 3.4319170059696322, 1.8333568808532532, 0.7208497581943389, 0.23136590757677633, 0.28442708775401115, 1.6932673463898322, 5.093815932350775, 14.268669755228105, 27.239688058053297, 29.32857963346666, 37.49087702843451, 40.378294529453406, 29.801433124849876, 27.39335475429412, 27.377072995708836, 31.80324612125274, 42.89955877488659, 55.30587050222582, 62.79931552948491, 62.12644077116444, 62.714156950673754, 53.1225537484692, 30.25028563314869, 7.144464398584059, 0.3197931996997326, 0.025737461175829656, 0.01924100110397464, 0.03925403880496179, 0.08360921961045073, 0.07634077656773791, 0.02149221558694638, 0.03245123932438512, 0.03464277172761579, 0.11152733282576646, 0.04019463772795374, 0.026882088465255596, 0.0999471094579466, 0.05401689401497284, 0.03920367235437997, 0.011719916627982692, 0.04293106548908738, 0.08218567502955276, 0.04985043290822257, 0.014019354430568075, 0.020388183296628056, 0.07943294491739043, 0.064452639480512, 0.07050209873986822, 0.04161264732359879, 0.02904490023220499, 0.052841021829555114, 0.07597339144276996, 0.02043858230594666, 0.04559079635768168, 0.05171743897540916, 0.021282144702009616, 0.02468145302226467, 0.02973381820465288, 0.03706614914981108, 0.11229899020925646, 0.036416973903655045, 0.17963542212401667, 0.17795505422738292, 0.15094190535526122, 0.09119227964190707, 0.1238365961058486, 0.1331781803239738, 0.24355546961868965, 0.13059531488726217, 0.1435778545395982, 0.1471590244721982, 0.23926631186998662, 0.1321823579529601, 0.11420093371622986, 0.18039299115057916, 0.11598573471870154, 0.11022551961603666, 0.18299981981756228, 0.21531809692180928, 0.17859717380375634, 0.1273467113834716, 0.13221753671044303, 0.19683916752617206, 0.16694054848724799, 0.12361827636918715, 0.08679685783722708, 0.1829232416686512, 0.11281193203983769, 0.09460114873945714, 0.30962663071770824, 0.36975009967723205, 0.248124847008336, 0.17389226013854628, 0.13278637231597978, 0.12198918273732548, 0.39095149105114324, 1.7737014303284309, 11.671362519264223, 34.32920740496728, 65.06086787869855, 72.64646899315619, 75.2316011921052, 71.20979109118062, 61.54403548086844, 64.49197907601634, 61.42722729713687, 45.295118901037405, 37.44114137464954, 50.257654574609575, 59.980923898758434, 58.177645590997514, 58.4797465416693, 30.456282631043468, 17.13158126800291, 8.8197454714006, 1.357524226750097, 0.6110441083869627, 0.6341713835154811, 0.45555087467355115, 2.7283778930864027, 4.304307045475129, 7.791063689416456, 8.9878817912071, 14.151896872828084, 12.815923863841643, 17.967081416037775, 15.90072483785691, 18.172415533373435, 16.609796208720056, 19.980330082678027, 12.59884617021007, 17.126731257284842, 17.91804982769874, 15.182711443593426, 17.693919712497344, 13.005009562738481, 17.61811402536208, 15.76786337360259, 18.384860907831502, 13.52450886080342, 8.832255871065202, 3.9711774501108357, 4.392822682857513, 1.7753594897447096, 0.9288159084896889, 5.254184978623544, 5.770335062857598, 11.674684766800175, 13.532500690029515, 9.302025398900433, 3.4954196887631572, 2.5937893602155873, 5.93680682682222, 8.423365450674488, 13.661802603352456, 11.67261963890445, 11.75285368196426, 10.555617847750264, 14.070568488490197, 21.47355483424279, 19.517292322651034, 20.003980013632006, 19.041787309031335, 17.549299963058964, 15.977523865238314, 18.323995528682588, 19.510104579310266, 20.08379044071321, 18.359469444521014, 16.089770332459484, 17.314783411641276, 12.240908318950284, 15.01927020088319, 11.977979098596881, 8.944699437387529, 5.317117937149541, 3.081156601828914, 2.564915812784626, 0.9591979136870754, 0.43311059655201056, 0.7021164569643237, 1.8305614566610706, 6.269298791885377, 14.626566421601082, 30.51004263662523, 41.88629681064237, 62.42923598135672, 60.133602157715835, 46.049535812870154, 30.73890313025444, 31.8092591147269, 38.49150896072388, 49.47684795625749, 63.0056361229189, 72.73225907356509, 72.71160387223767, 72.87926166288315, 62.83143974119618, 37.94041987388365, 9.882921557272635, 0.9745739724847579, 0.12842051384429778, 0.14660872819442905, 0.09913718598263879, 0.2066869520011448, 0.18616304282219182, 0.2104986684336778, 0.16632974658521915, 0.14906322793854823, 0.21443642165151336, 0.12113423627470771, 0.16584999168351774, 0.2684345733254187, 0.17798134636494423, 0.1709287256122597, 0.17149595243315544, 0.21544520623020588, 0.2275524597855345, 0.14579963209407945, 0.1552794645390203, 0.18625647490543706, 0.2271731083671893, 0.22379280668833565, 0.15831893370036157, 0.20330357064883556, 0.13136727104504264, 0.12532576377834045, 0.21864840370272437, 0.14117889616998935, 0.1741456360586228, 0.1602057776143474, 0.16779040046516927, 0.1204528853357319, 0.20987666632619598, 0.15612450548477713, 0.21964151412248614, 0.1998564048159507], [0.08461963595642198, 0.1010623419537179, 0.0556456812116648, 0.03636713605374098, 0.04242265123813864, 0.014749760852165282, 0.07603676223586645, 0.011974976026272822, 0.0134932866410142, 0.08666406415643231, 0.030228967643192703, 0.02489978616546479, 0.04015179043034873, 0.022896213434456338, 0.010976743351127352, 0.07742906575121226, 0.04004371840687048, 0.06057715771960155, 0.09452156752588288, 0.031497168745244705, 0.06536580862537508, 0.1707161821785473, 0.22415651459126706, 0.10368528144974863, 0.15062250797787022, 0.06046374223285145, 0.007387925945823231, 0.06689806108272846, 0.07918199749603387, 0.011741636178245949, 0.0718877909164275, 0.04885728035362498, 0.11043833118052253, 0.01489606736633446, 0.4189753856870436, 4.233319499800283, 13.451866565212129, 29.313447129341867, 35.701048527994466, 49.96791693472093, 53.182840578017704, 54.95938401068411, 48.34449106647123, 38.57702055285054, 27.83656689428514, 22.486589301017023, 22.947136355984597, 35.11902762997535, 36.21503199300459, 41.4331022385628, 23.384308045910252, 9.610214848672191, 5.7391620259131155, 0.7779964852717616, 0.5555509667723411, 0.19393102115681096, 0.09719128435057017, 0.575721939244578, 1.7773439639037656, 2.1411745634771164, 3.09405212921481, 4.988734654841885, 7.449931233159958, 9.731167997083357, 6.857811702835945, 5.580493817406317, 4.032431389054945, 8.069081287230215, 8.53715438996592, 3.8299851167586545, 5.891446576964471, 4.9812140003327405, 5.822539848666038, 3.820356433430026, 4.1092105594373525, 5.419725669968513, 2.66725167632103, 5.349782945648317, 4.0052942258696405, 4.80522656633008, 4.700913583078693, 3.584162823615536, 1.7665697033366852, 3.5185070047455453, 13.098419827799644, 23.038203985460346, 44.05933695454752, 43.06762449202999, 34.48685530693301, 21.684005683468236, 5.166730832669043, 1.513833865042656, 4.13093141971096, 4.174790872681526, 4.519416199576471, 4.20476415464955, 4.840713229871565, 7.7007403296809045, 5.626142851768002, 7.274361531580649, 6.086139794318907, 6.724245682839425, 8.107390586406954, 5.134829215465054, 8.614597666648127, 6.260168985013039, 7.92716944409955, 5.961507462686108, 9.396603549680403, 5.16116302820944, 8.634749824000943, 7.881067375982962, 8.498407256218696, 4.015878741779636, 2.8881409331675503, 2.5012179920750284, 2.3855176327690004, 1.184708887050229, 0.2449213277788893, 0.23729401850892654, 0.3936737078812815, 0.7550809568455144, 4.6418691642822765, 10.87468206882477, 32.56286605711907, 37.88708740665067, 38.259587057175175, 41.82880663102673, 35.486471345347745, 30.145407338296216, 26.27617939825981, 29.73392913418432, 38.6634539019677, 48.23218968606765, 51.706405531975534, 62.3482939504808, 63.05719175646382, 40.19663387729276, 12.842806808410153, 3.076134006823263, 0.21851970093144527, 0.11319674566508302, 0.07366562817966746, 0.07700773271461649, 0.09372936366426368, 0.11780343919752106, 0.05956675286494917, 0.06355433244137995, 0.03820616842037247, 0.07826561844276805, 0.06295570367646795, 0.0706148668823223, 0.23252899758517745, 0.1894476754410613, 0.1027233508085051, 0.07501320748199379, 0.10504132602363826, 0.13277077476584143, 0.0290053490278942, 0.050880591340002515, 0.027609243801224138, 0.04890991825490229, 0.06043668783780548, 0.0408073433584744, 0.05001755498890435, 0.037958790968743064, 0.022302008827307054, 0.07174881490608377, 0.024778679155954914, 0.027033164834363327, 0.01911735451299577, 0.06648513969154128, 0.08651397221030728, 0.1106757877935325, 0.06820404181076635, 0.08470640307472599, 0.11867098780649325, 0.09815986463499647, 0.04778823912924817, 0.036127293076846874, 0.016659769349761547, 0.035108752368438634, 0.023632910395521792, 0.0702683040271363, 0.013912918004808168, 0.00996047505102451, 0.02935306101496662, 0.06007848044617042, 0.028264411770167853, 0.039449257160266565, 0.018427953905155583, 0.033350343094958414, 0.05565199377616087, 0.028392057340111465, 0.05365466849217492, 0.09404263233826046, 0.025161987418429028, 0.09868051331009596, 0.08027951803899581, 0.03352956936484383, 0.07207690738141537, 0.036916015068850214, 0.016931173233916203, 0.04907142874153872, 0.07856665269261406, 0.028480199586239555, 0.03597691001731061, 0.017016909963962053, 0.03248703095220751, 0.05402198466922968, 0.5475721916844768, 4.699186269314059, 15.453001972167725, 37.11551404768421, 47.636507172738355, 60.043622985962905, 62.68503727451448, 63.614850813342684, 55.65311401121078, 48.377407596957305, 38.606038247385335, 33.11417871905912, 27.381065968544256, 43.897460737536036, 42.29707879404868, 37.4857073445474, 24.77266234736289, 9.804608495004716, 5.894355995039787, 1.1078797064481245, 0.5272090230737964, 0.30699809111895104, 1.0445529174420143, 2.825325400598588, 3.1761208609227216, 5.078511334234669, 8.705078901783112, 8.7819230364215, 7.3586174749558975, 6.260162611161509, 11.959238013913556, 10.880592100081905, 8.401090310465905, 8.80025423342182, 9.011933765103741, 7.343034878853829, 7.226355152745401, 6.411711717805555, 6.694518039303442, 5.111048375406574, 5.475469414264926, 7.316364722867166, 4.282907574407516, 3.8331801324121417, 3.4710056310699833, 2.9895797996751727, 2.9584739333198917, 2.3684781212960524, 2.3259603640725537, 3.4599678362569506, 12.567833950442653, 23.9550462461287, 40.79006495014314, 39.79847800347113, 33.0017125991083, 20.423887391244214, 5.159093977943544, 1.4208295652943275, 2.805164908209155, 3.612011161542708, 5.61242877475677, 5.348471403121949, 5.464016093361763, 7.821162487229994, 6.016603035311546, 15.010635102948836, 11.546992986432969, 6.523193322843121, 8.979972331754624, 8.595086816818483, 10.688167483575883, 9.035817077082973, 13.985110828953406, 13.389468519918381, 7.723420944906051, 14.080614659094042, 10.374074866694789, 12.076101110827539, 9.739234351342725, 8.367952166065093, 7.077124657169466, 5.676081488209387, 3.2614895316862293, 3.8276907753559852, 1.2754255869696218, 0.20975809123727585, 0.5373052038973378, 1.354678302041946, 5.0853867588504675, 12.062078637461509, 30.032668613618423, 35.68603369497484, 34.46017142265074, 38.275025506173414, 31.48669319768106, 27.370275528200214, 28.262569635145127, 36.30521905037665, 48.097005198078776, 58.963347327324655, 61.77682030585505, 68.96467347298899, 71.36230068822061, 47.188215563374186, 16.169193425486167, 3.234230284729312, 0.3459161237603234, 0.09109264224647515, 0.014594954592476209, 0.06829819401666042, 0.02178696791581329, 0.07213358256605364, 0.07752270467819707, 0.007299793275794195, 0.05212778631117075, 0.11876178454727897, 0.05103483548267715, 0.048703063024027694, 0.12466559517047099, 0.0391394090688517, 0.043185628845446536, 0.07818874918044576, 0.06587532604293478, 0.06574044860298596, 0.02663531813830618, 0.03275388618931174, 0.09608814072224403, 0.03478851995521015, 0.015978206778996657, 0.04137120322294293, 0.07176026792055176, 0.014932594438564154, 0.024854401201610605, 0.027574664507541927, 0.060981740243732936, 0.023414167395282178, 0.023484601519040527, 0.0373106307890867, 0.026122839790919138, 0.03123677354456196, 0.07134321731545272, 0.0261151731660169, 0.2510084019553277, 0.13399685252337687, 0.15204266645014286, 0.12325107510532103, 0.1519077277231601, 0.13046328729439166, 0.15812572632585803, 0.11635319645246191, 0.10680123682945006, 0.19267172582687872, 0.10822350970439373, 0.13903245570198183, 0.12967781734562692, 0.08834369660865876, 0.16059619134231923, 0.2506138207090478, 0.11522939909369716, 0.10340002095026356, 0.20393836642465285, 0.20769022074678253, 0.20483605293256624, 0.24872467853128913, 0.3993008075462234, 0.22679561088162087, 0.2984351586670645, 0.1948985902051772, 0.08377542238562338, 0.14985951504880382, 0.3378283496825926, 0.14916576114633393, 0.1055988694931711, 0.2175507682465738, 0.24946281956809185, 0.11351575233763266, 0.9678802026375648, 7.133187094042379, 21.095255959418513, 45.44676949900966, 59.54730195383872, 73.89822283098775, 75.51208988312753, 75.82587165217247, 64.0924072265625, 53.42777690579815, 40.216504604585715, 37.26986715870519, 36.83257779767437, 48.59331446309244, 51.475319093273534, 55.2755662702745, 30.874791683689242, 13.026103088932654, 7.8848809003829965, 1.0742615619974754, 0.9964779584157852, 0.3581305989815343, 1.3081105750414634, 2.3230244699985754, 5.422985159581708, 7.598766549941033, 12.118136171371708, 18.239382159325388, 18.424812209221628, 23.19293756638804, 22.007826758969216, 19.769188896302257, 15.994719536073747, 18.682333461699947, 20.29349211723574, 15.731413768183803, 12.9709320106814, 17.164935142763202, 18.451564734981908, 12.769413378930862, 12.217404496285225, 13.421617246443226, 10.502658986276197, 13.469897700894265, 12.038009012899092, 11.43274905220155, 10.731139990591235, 10.616350846905863, 4.400791958455117, 5.809129755343161, 17.046814926208988, 24.8084500528151, 36.181358445075254, 34.24821438327913, 28.485054316059237, 18.617512372232255, 6.2076768855894775, 3.2533368852830704, 7.7822481624541755, 12.388113890924762, 13.37172567844391, 10.214713869556304, 13.211376244022002, 17.082412396707845, 14.624728791175352, 18.370714879805043, 14.53596555417584, 18.3398340594384, 19.708003843984297, 15.1830340585401, 16.97523755411948, 20.95099706803599, 18.78057118385069, 15.44197815079843, 21.946608366504794, 20.560434902867964, 20.203709063991425, 19.5890599296939, 18.94529308042219, 12.105790511254343, 12.395209458566482, 7.675879366936223, 4.711158813968782, 5.1123246166013905, 1.4407034795130453, 0.6973696536114139, 1.0744692024684723, 1.321658441616643, 6.140903926664784, 14.168105086972638, 41.069118053682395, 48.39111628070955, 53.30238657612955, 53.85238916643205, 48.973282306425034, 41.801785422909646, 37.481027956931825, 41.067443201618815, 51.043481826782234, 65.33329217664658, 69.24760972299885, 81.0437693134431, 81.19526693897863, 58.41475286791402, 23.04573493619119, 5.6422986042115, 0.5194598905021145, 0.25461966382159346, 0.1805050544921429, 0.2137967995217731, 0.2271207385966855, 0.21748310736110135, 0.24642724213340592, 0.15232961234306136, 0.37695537110970867, 0.22932825159401665, 0.29610444340975056, 0.15898702365736808, 0.3936216445459474, 0.21773714211679276, 0.18119059593206455, 0.14351745616764794, 0.24461541354896563, 0.22125641214511088, 0.21863849052498419, 0.13962209825554203, 0.26205747358260617, 0.20473053198187582, 0.19120779309061267, 0.1267579651527828, 0.2941556689479659, 0.09702302079888121, 0.08887541525426412, 0.09574017592615659, 0.2063012267312696, 0.08929065023098262, 0.1387141308476848, 0.20242966351009187, 0.16576840331958187, 0.2944531562107225, 0.21848389398186438, 0.2135767177828858], [0.13309625488135124, 0.017546487393819036, 0.10299130538178068, 0.02074568205693316, 0.06029046846613769, 0.04873430025914023, 0.05292750932576676, 0.0140977845970361, 0.051258939183166916, 0.039349171603398944, 0.03454672345410913, 0.033676148797836036, 0.011827762655523277, 0.0852504633967915, 0.07792576651779876, 0.10667334611137068, 0.033345700602137276, 0.12377209916350343, 0.129753292327927, 0.11531500175835625, 0.0860807724717644, 0.05473056237303442, 0.16741426661610606, 0.11859198881974144, 0.20714148728837892, 0.12415652974478661, 0.14378731829985497, 0.0684275709453129, 0.011953831041952776, 0.03580919038804789, 0.10464055478693017, 0.08088197724352922, 0.1097457034273013, 0.09306688913174214, 1.514526776248409, 4.270236847862121, 16.217773941255388, 37.125374886297415, 50.93784455330142, 62.9761948124055, 58.23810500483359, 50.28576227926439, 41.939346867222945, 38.26652573001, 33.6216353601025, 27.287548818895896, 32.81442530693547, 28.624463196723696, 35.161604958195845, 30.010517028070268, 11.810164413144513, 9.42932003928769, 1.3093741911072887, 0.7202899011392748, 0.1407635999062369, 0.05317555327389029, 1.0167808818721003, 4.192271895946996, 2.849538681968566, 7.7792019517191004, 7.531233631795453, 6.280168660225407, 4.342016712311776, 3.7465692960446884, 8.532576983974826, 6.616801667597986, 6.7066548332091305, 4.846696805569434, 4.051006508450355, 8.202895887436407, 7.064756933719882, 3.837102502584458, 4.170507154157085, 3.6893269611943156, 6.566605135317772, 8.578097070417098, 4.762029503622363, 5.1877513047187565, 5.823761666974714, 6.561666871270826, 10.48600656370963, 8.737684584433033, 11.99120140844776, 16.727345720414196, 30.699487232392837, 51.22305970038138, 67.77718374806066, 62.91401347806377, 58.406374685225956, 43.785182891353486, 19.97493878487618, 5.278975829001396, 4.727858304977417, 5.833266550494779, 6.370454267148049, 5.779754634826414, 6.870564308858688, 13.83561557339084, 5.398608119257036, 12.898801584397594, 8.695793670992698, 2.7530964247642027, 7.3421950013406825, 7.524938227668886, 11.663158882048823, 6.046753804529867, 8.843137506515749, 6.319716447784055, 6.46983830198165, 10.71020826216667, 3.806780619967369, 9.047391991461478, 4.733722738681301, 5.9627704658815945, 4.008394124046449, 5.902048743540242, 0.7474012011962553, 2.193976284996156, 1.3007936386331436, 0.22217455320060256, 0.27308129495190037, 0.3919767618419663, 1.0881641579251136, 4.615439743764939, 10.187174908576473, 27.4551458128037, 51.25310897827149, 40.78306351938556, 30.431887449756747, 31.359859435789048, 24.67917657667591, 19.58652803974767, 28.030533982861428, 27.793481619127338, 48.1509966235007, 53.87224028187414, 53.62138117513349, 44.519756532484486, 26.71394728845166, 9.5018397608111, 0.3123421059741128, 0.09054930204705847, 0.05743013747457055, 0.017665757707530455, 0.11316719765384352, 0.023602707379107035, 0.08329259547134561, 0.08453509815397763, 0.05157571270941727, 0.10032455331736034, 0.06521180196995698, 0.0908795855338535, 0.29115812011784126, 0.2035173091797098, 0.1198566391042644, 0.04849158445253007, 0.06399026711381252, 0.04502204119137699, 0.08469925547439246, 0.07341286512993037, 0.0633568617875778, 0.08051598639858347, 0.03590869371809306, 0.03262068265147748, 0.062370462298032746, 0.02717127133491299, 0.0985802247399284, 0.08312928084764751, 0.06479753226402306, 0.03164752116126399, 0.06751337524263129, 0.05336889088334096, 0.05827109134125133, 0.10392609352786696, 0.1263703859501308, 0.16001836186455143, 0.08701879350889115, 0.1256637464487745, 0.07137276532669222, 0.027644384254310882, 0.004141908467582037, 0.07540232652137357, 0.03602621543611731, 0.056733338372601624, 0.040188612446429274, 0.03100380812200808, 0.053315387302709204, 0.08574138019954966, 0.014223384712221883, 0.06836328084670729, 0.046639972922181895, 0.0825514666916382, 0.02503856107772839, 0.05524592121101676, 0.05243045998917473, 0.0025591545366501858, 0.07376960163275081, 0.026161462113621737, 0.17616349632941908, 0.06106294173326704, 0.13629729198592325, 0.12297109295163425, 0.09649115659657026, 0.019664980974348805, 0.008386699670565226, 0.0185909295349472, 0.05108292282168424, 0.07533648126428166, 0.09222666687902906, 0.028688937478188067, 1.1978375503132421, 6.717127071272943, 19.99969482421875, 39.178143393608835, 53.71448255354359, 73.11806340371409, 67.29309266613376, 59.70773473862679, 49.16800052888932, 42.839989739079634, 35.12154186925581, 29.941724538803104, 32.52603892357119, 27.152523186899003, 33.039594850232525, 27.163227335099254, 15.802979373162794, 8.253725882499449, 1.6218672164024848, 0.45642672767562253, 0.4054324527180964, 0.6433025999895988, 2.194351116495748, 6.551057840547254, 5.945278165801879, 8.19594495719479, 9.111519802001215, 8.347759804418011, 12.212223045287594, 10.471760515243778, 11.238728031035393, 7.3749963122029465, 9.01675533863806, 8.008197767119254, 8.185259440252858, 5.282265226687155, 7.193615128917079, 7.457360692562596, 5.5406126283830215, 4.93756341357385, 7.483237549181908, 7.3744663019334125, 4.821079805974038, 5.580929690791715, 7.294132238434208, 9.236967986629857, 9.358168244361877, 9.270835691882718, 10.349707141999277, 16.689102611234112, 29.169154897812877, 51.80692803475165, 66.37980015047135, 65.29406455255324, 57.821368863505704, 42.99210317673222, 19.80126407838637, 5.49886929412042, 3.4308297739874933, 4.287601180614964, 6.082269885847646, 5.961477554613545, 9.023575359775174, 10.929323627102761, 9.50021295778213, 14.832526156979224, 14.108049677264306, 6.760744808181641, 9.241860162827278, 13.73191006721989, 13.095455496541916, 8.908118432567967, 13.188845169159675, 13.50404683620699, 9.395115990792553, 12.938121384189976, 13.978757569866797, 10.785169659122344, 10.139511246835033, 12.039771137699006, 9.31978883281831, 7.761590999941673, 7.104475834677297, 4.407462929525684, 1.9786464975726221, 1.0697659129096617, 1.0101558147899568, 0.5064075295963596, 1.6090675419376743, 5.238411166975576, 12.56875962980332, 25.71376250636193, 47.01466637272989, 36.37908512546171, 31.859659610256074, 36.743728268531065, 26.01571832933734, 22.750523628727084, 32.97749588566442, 34.42581145994125, 55.15377275405392, 64.436430469636, 64.60049144683346, 52.62423230755714, 30.803755598683512, 12.27671955862353, 0.47690621907672576, 0.04686437539696213, 0.026638275237693906, 0.01944454300457672, 0.013930689329431664, 0.07195029603016954, 0.03600571109282394, 0.052501641048659245, 0.08039558035952431, 0.036468481825244044, 0.09909064614123876, 0.07899986009203619, 0.1855908823950637, 0.042327552913658084, 0.1791368061376195, 0.036152918717914054, 0.07700118266286389, 0.017256030902987527, 0.07467166250271183, 0.03135178249419457, 0.02869509107943985, 0.027969320447394447, 0.018242438053411823, 0.06338848589709209, 0.04368881837675168, 0.022673040530794573, 0.04142994301453714, 0.09538913911749279, 0.03780192297492777, 0.033322108924509056, 0.045526303245776126, 0.04957754472871462, 0.08612366573464486, 0.1163534799049939, 0.09240365617217557, 0.11548810698572667, 0.32248268925374557, 0.23089879312582556, 0.1853800549983017, 0.09784939984280257, 0.10380004142080584, 0.21391687614302482, 0.1326149371602843, 0.1973979980234177, 0.10590752631786371, 0.1890925936881573, 0.137062031595457, 0.21369837254526156, 0.09354528039693834, 0.20626319812670832, 0.16833622278946062, 0.3280750391704421, 0.1399767816427254, 0.2147147107508875, 0.23017062655379697, 0.19040366124001243, 0.2172137968121998, 0.12435044192018048, 0.4387185746623624, 0.41228216742315604, 0.4023836679275959, 0.35401195708301764, 0.264446901818437, 0.1396962402448539, 0.1412610361172307, 0.1981509705224345, 0.22288099351909854, 0.269028322110253, 0.22508184155148847, 0.14745091929310752, 2.669091267931846, 9.703582948254002, 27.159787416458133, 52.08535355906333, 68.6229173598751, 85.8976161095404, 77.4645123943206, 65.46835899353027, 57.36514622165311, 52.89075343839584, 46.1911137642399, 39.51791870978571, 46.746027161998136, 44.569370592794115, 47.526794556648504, 40.2810001373291, 16.03539941772338, 12.107478111020981, 2.101138440832015, 1.184615975906772, 0.3941023800401919, 0.7499300267907881, 3.0166086073844665, 9.155134597132284, 8.385220400748715, 17.633727019832982, 14.56264453549539, 17.673521426416215, 16.268968716744457, 15.237201990619784, 18.8058743938323, 17.076052273473433, 26.21885003582124, 17.89858506571862, 14.047399047882328, 16.317253093565665, 14.553362246482605, 12.90868595723183, 11.90563392254614, 13.537423264595771, 14.397161699110463, 16.306456769666365, 10.577341894949637, 10.066096244319793, 10.200796319592385, 13.29792824483687, 14.982862760943753, 12.119655109220936, 15.857563076480744, 21.303131772625832, 39.56017440365207, 53.911405148044715, 63.716828515452725, 59.933675027662716, 55.12684568282097, 41.51027487170312, 22.50776617757736, 7.414567633982628, 7.606900565085873, 10.893908546816919, 10.983213070900211, 9.772049880796864, 15.338701163568805, 23.986354604844127, 10.99278953767592, 20.863471338825843, 19.53090883070423, 12.075678475441473, 20.09709119796753, 20.09647342466539, 26.746310764743438, 10.64282194260628, 19.596402606656476, 16.37568464202266, 17.511584412667062, 20.74815365575975, 14.630151467938578, 22.294785399590772, 18.137116163007676, 17.616099888278594, 12.635001597865937, 14.884464221615946, 8.768462442582655, 4.329369029691143, 1.9697023904131306, 0.768451887753702, 0.8835264451561436, 0.9589671067172482, 1.469476638782409, 5.921230604571681, 13.81654893198321, 34.85660537596672, 65.14436729492681, 55.577373043183364, 44.91271918819797, 46.74445036918887, 35.03527718205606, 31.488409234631447, 39.95388623206846, 39.86628401663996, 67.26217654443556, 72.87577075342979, 73.67248258283063, 65.71789233915268, 40.93495338193832, 15.953746457253734, 1.5428319477265882, 0.215636222593246, 0.19396315088435528, 0.1504820687395911, 0.19151234368403114, 0.19147843663250247, 0.21178561953767655, 0.16968697369579347, 0.2596134998865666, 0.16990746912215987, 0.29306920305375134, 0.28764873262374635, 0.4889672315649448, 0.2674199051914677, 0.27774692362835335, 0.1768238181548734, 0.1872727977893045, 0.2585480554449943, 0.2204513609890015, 0.23088252141831384, 0.13490721012555784, 0.14880234435681375, 0.08776032831519844, 0.26208272384059045, 0.2073423095768498, 0.2765848295342538, 0.2360888089864485, 0.21248121205116474, 0.15435905586327278, 0.15333151745219387, 0.2102281015005804, 0.16432008345521268, 0.16810992041662817, 0.29159675141976726, 0.22529239315659771, 0.2376621237565433], [0.07956641275555858, 0.07068601346785022, 0.05191209042564996, 0.020466211266935836, 0.0657466309325349, 0.03223881846474063, 0.005510254019510843, 0.06050215771181449, 0.04097993913737517, 0.07899292699632146, 0.03809816151436779, 0.0646600884295279, 0.09460483362237293, 0.024548517615203897, 0.08777626294402346, 0.11605011674785808, 0.041995886638159716, 0.14330718035419143, 0.04275306879032043, 0.03256411088870899, 0.2083910686234313, 0.2323287728452875, 0.20424971987883891, 0.2160548590003483, 0.17173419045584817, 0.1307091249092933, 0.13863456495586904, 0.12115803862651511, 0.0013767145836966173, 0.08101190575548718, 0.010246696990854558, 0.14516145020963686, 0.09816476759771187, 0.23117927323666312, 3.3725774288177495, 11.260253998541064, 27.599620434545702, 44.57565422981016, 67.738540557123, 62.802386745329834, 52.53728120557724, 57.51099955651068, 51.260824280400435, 36.432515651949, 32.05920430921739, 38.01946347759616, 34.410898608546105, 41.11721415673533, 43.14163177244125, 21.1450739829771, 5.860589781115133, 1.4128947330097998, 0.3068545568854578, 0.10430572839874415, 0.758096646637686, 0.7732596717053845, 1.1415180756199745, 5.893751459736978, 3.6461093060431944, 3.8461026260929727, 9.15300278894363, 4.541586906679215, 6.506095220965724, 4.7141608980394185, 8.206746674353077, 5.538630850853459, 5.8067758429435, 6.5782717350990545, 6.151399208653358, 2.542781142457839, 4.29661919993739, 3.0249240321497766, 4.159067561549525, 7.117885928000174, 10.209929558538622, 18.254600955593972, 11.757534050172376, 12.877052041792101, 14.057732532101294, 15.934497425633094, 16.518873706940685, 22.507713225580034, 30.456039444092784, 41.621595659563624, 48.960993520675174, 66.59329475895052, 80.025161158654, 69.7324852789602, 75.86736248385522, 63.086138848335516, 36.24118243494342, 22.744947979527137, 15.078849042615584, 9.251917119949095, 7.237489781072063, 7.896128296852113, 6.015385629669313, 9.853892095627325, 12.35888929136338, 24.97465656649682, 19.184736128776304, 3.79357228356023, 5.860807472659696, 9.432575606530714, 4.164173506921338, 8.756243278903346, 17.320959183477587, 15.987318023558586, 3.5182093949087205, 12.646907952524002, 14.119776583486988, 8.721595021986193, 5.687828496579201, 7.5316342038493005, 5.575954654524404, 5.890184064065257, 5.60829802866905, 3.1714071525681407, 3.377214896102106, 0.8618110394285572, 0.4688512335621542, 0.03896223208416374, 0.12718138960941186, 0.7992939134278606, 6.089225228755705, 15.807592080485438, 25.221026520575247, 44.03455541979882, 38.22487015878001, 28.78148351946185, 24.637758308841338, 27.916985288743053, 27.882880280094763, 41.73274778550671, 45.862497591203265, 40.3921091172003, 51.64876237992318, 54.688693400352236, 41.10681203103835, 16.042356721816525, 2.7626569569110875, 0.14947876935043644, 0.09936485965285571, 0.041491842918819, 0.06458286676676044, 0.14523972907373983, 0.1004778168674919, 0.11998995372484769, 0.10759170167148115, 0.10335526609372708, 0.17815486527979377, 0.27145231623322735, 0.2658924178010033, 0.4251089001134519, 0.17110596771442121, 0.046391281629762346, 0.03838299300461527, 0.204880470710416, 0.130861668336776, 0.10316737536941806, 0.06563070650783277, 0.04923911389684485, 0.03314339976397253, 0.07914666552096605, 0.04896233399068156, 0.07603427245011253, 0.056469911378958536, 0.05047534231937701, 0.07542141743244664, 0.14693282935167515, 0.03788984688599745, 0.009302029183374779, 0.11254442945843744, 0.1549759251816619, 0.10430807262779244, 0.10385100925040823, 0.019034758743439472, 0.14003275202647333, 0.0571216338674628, 0.016556950774224057, 0.03030109865170333, 0.022213950850850633, 0.03227327709957477, 0.02584089453692638, 0.042084764328695116, 0.012629597199960582, 0.02897396432085624, 0.015366636873823742, 0.08221662498169369, 0.0161099920965611, 0.10600856565419706, 0.05519951543500347, 0.09062033371939775, 0.08181102739106264, 0.03516786371267611, 0.046385034182739836, 0.02114410331893352, 0.0875234692507694, 0.08359777425686199, 0.01833072585624553, 0.1209427525980338, 0.10035165750812139, 0.060716555078303626, 0.03876417154265988, 0.034709513307579105, 0.05901958222591108, 0.06892576558335174, 0.03328750090252969, 0.06560154154055542, 0.23898529549760206, 4.0231125729699295, 12.529028961735388, 30.227004404990907, 54.139196795801965, 75.86124358638641, 73.38056410512617, 61.92327768571916, 59.8473632720209, 53.94092098359139, 41.2241615018537, 38.73075785175447, 37.93965501170005, 36.15992661445372, 36.495383401070875, 34.30479065064461, 21.035357444517075, 6.852938157896842, 2.306248002475308, 0.42299434422485294, 0.3994608279918471, 0.7219409125466502, 2.0272767784134036, 4.407374676196806, 6.796328060088619, 7.3958937198885035, 7.930187217650875, 10.33086113391384, 9.235388252042956, 9.111510976668328, 11.695682194925125, 11.451623497470734, 10.79575711680997, 10.501228301755845, 8.826647862311333, 8.180535435676575, 6.523241371877733, 7.363327260940307, 5.989086627960206, 5.620778520261088, 7.408878236047684, 8.140788097535411, 14.09481461971037, 11.665044561509164, 13.613362312316896, 14.467215230388028, 16.076838278001357, 18.03278503879424, 23.55149515213505, 30.939359780280824, 42.67622686201527, 49.21946202555011, 71.80803883460261, 82.824352787387, 75.68782775632798, 76.34605638442501, 64.62761463657503, 37.851872367243615, 21.714727647842903, 13.241441211392804, 9.03383235777578, 7.446872765018095, 9.673050238240151, 9.83956563857294, 12.025443700052078, 13.666771265768237, 18.33293264912021, 18.09639019350852, 7.61924034164798, 7.247413377608023, 10.114837577266078, 10.812516423963732, 8.517866134643555, 9.955617785453796, 18.091271500433646, 8.010490392484973, 11.35518712382163, 14.15648506533715, 13.726465817420715, 11.729135109532265, 11.823608336910127, 10.114709119642935, 8.404188982902035, 8.638327025598096, 8.022713968830725, 5.904828233103599, 1.6468796806950725, 0.6647944306173633, 0.1242265425201866, 0.3251735271225053, 0.9960569164926006, 6.186650529984505, 17.40967535203503, 30.534704539083666, 43.13394000453334, 34.614838323285504, 33.05798292160034, 26.81254782984334, 30.12603279083006, 31.574291490739395, 41.46441844201858, 54.8478239582431, 48.569948903975956, 60.52758462967412, 63.05565810972645, 47.647415284187566, 19.069626331329346, 3.104129678780033, 0.17733273036297292, 0.02380490096496238, 0.011192673851074952, 0.07042604153074565, 0.04176398416260078, 0.03434631485311735, 0.036812754077536446, 0.030999510368752866, 0.06345156174633773, 0.10924912523478271, 0.05905046323013883, 0.09284359748445212, 0.12330187439558007, 0.059161982649276336, 0.06838709852027317, 0.021503865869054874, 0.10112906821192273, 0.01102115155287808, 0.016447886666883866, 0.0711415293476274, 0.04921479060524895, 0.03015049342666903, 0.004128021208734642, 0.03520300033532324, 0.02700001812509952, 0.05562975424371901, 0.07145020915495773, 0.10142100899810753, 0.12037443793228558, 0.13599105599907138, 0.038647465708275, 0.06178844998019838, 0.12748731916109401, 0.07688571789091633, 0.014274916574058515, 0.28027081561665385, 0.33777576540747, 0.1726478115925866, 0.08715161017232365, 0.13128192885027778, 0.1354407750430607, 0.11427833924009917, 0.09996334286106211, 0.16615478742507198, 0.1862250040135076, 0.11998698130370149, 0.15658484771847725, 0.2593433159974314, 0.09431760427692244, 0.24588111337394486, 0.25216206908226013, 0.30153116511721767, 0.33666331381086384, 0.15012398392202395, 0.16550517550879912, 0.3862417050667348, 0.33477643925336104, 0.3435793717301661, 0.23941511678839886, 0.4448895354665095, 0.32071081981543575, 0.32844702082295574, 0.25802509318436345, 0.13038629545800148, 0.22762667838363881, 0.1976593719014237, 0.295724923452062, 0.1821516379113159, 0.5221332309226836, 5.371856574089297, 18.67564974292632, 40.74560096186977, 62.576913218344416, 85.9568674333634, 80.64621356225784, 69.2906302790488, 71.7305249552573, 62.83112595158239, 48.26063079218711, 43.180043543538744, 52.46346612130442, 48.6304553862541, 56.15921743454472, 55.529394611235595, 28.44572274915634, 8.055749641310785, 2.796232935882384, 0.6323501167278136, 0.30215620093287965, 0.7902040657016539, 3.772971014822683, 5.473567064731352, 11.112877803464091, 11.330738990537583, 14.98195473224886, 21.108268422465173, 18.552314735228016, 21.557468060524236, 16.490852294429658, 20.4865982455592, 16.72189166468959, 12.119926733355369, 16.084859525003743, 13.914259095345775, 11.514530470294337, 12.736970474643092, 8.779471555063802, 10.929545241017497, 13.723514233866046, 17.067430903834683, 25.980344433938306, 16.260095334822132, 18.908173730296475, 20.020259811032204, 19.78501762113264, 20.758585199233025, 30.867486269243305, 38.25950860977173, 48.97788324663716, 61.721946347144346, 75.66715686551987, 82.48343606148997, 73.81729648959252, 78.4434183182255, 64.9682254175986, 44.31369481548187, 25.92231885079415, 18.880701449609575, 14.561820837759203, 12.470928853557957, 13.405029542984503, 13.829977166268135, 13.609993976931419, 23.49707030480908, 33.915879803319136, 30.173416983696725, 9.583399564989152, 11.992291827355663, 18.849277380974062, 11.025707048754539, 20.365922604837728, 30.850418075438473, 31.304959981672226, 13.089007119978628, 26.820237636566166, 23.946989697794763, 19.996062709439187, 16.05299222853876, 17.547191689091346, 17.37068699252221, 13.97505779420176, 13.885238459033351, 9.632943022635676, 9.204299546057179, 3.557037427540749, 1.1495505994366062, 0.45956943484563983, 0.4844354537706222, 1.4155015157115076, 7.854928210858376, 20.85485781392744, 33.87590692889306, 57.63683311400875, 50.60953824750839, 41.26874708360241, 39.78167456965293, 40.071423976652085, 41.169656245939194, 58.75969002323767, 63.345627169455256, 56.14885845491963, 71.41093807835733, 73.84448635962703, 57.108132916112105, 24.556171048072077, 5.150864845322025, 0.313105282764281, 0.22721372634893466, 0.1282940020844821, 0.18144121393561366, 0.1944739017034731, 0.14436897821724415, 0.17141721391629788, 0.2562340102609127, 0.27203864928695465, 0.26221648279216986, 0.5041278357948027, 0.3721105085024911, 0.5775786912248981, 0.3469760523688409, 0.27147627946349884, 0.22364021729557748, 0.5079277544733017, 0.2666074229824928, 0.19059434052436583, 0.1834079148548265, 0.12553392518912593, 0.10061989553392896, 0.2046853021508263, 0.12167041355203237, 0.17397498231261008, 0.22035622819056436, 0.18455951354436337, 0.23664921762481814, 0.20696133405210512, 0.17597110100811528, 0.1488923750096752, 0.261646697237607, 0.29893268680860924, 0.3531868497450506, 0.27266898643105264], [0.08361648212397292, 0.16387688626925792, 0.04932596145438091, 0.06361857274427049, 0.043923371516528635, 0.01607762871219987, 0.019307953358117132, 0.0322010503300736, 0.07025778563993593, 0.01700955551988896, 0.021747163902487487, 0.039181314078309847, 0.03723390708347002, 0.02201490014070465, 0.09960295211884285, 0.14187228235025562, 0.05596577955950653, 0.1496215987830393, 0.04324890387755248, 0.12792623391555202, 0.15390651240464182, 0.193298538966525, 0.3521468087790474, 0.23309657680651835, 0.12277058475921232, 0.20019697686356885, 0.13885132187316496, 0.07172776280992454, 0.0769413895003738, 0.032198889962127136, 0.16985710650201769, 0.13796891115846174, 0.07945497760609274, 0.8375792493743281, 3.1998678705384656, 18.314444557313, 31.933358984608805, 42.73284627545265, 60.49492305324924, 55.685022492562574, 51.27143429171655, 40.30805664677774, 42.85074487809212, 35.31123161315918, 27.222223704861058, 24.617901309843987, 32.54970650519095, 37.81375477390905, 24.213716753067512, 8.925516105467274, 3.744174198758218, 0.5085855788521229, 0.3577798839297987, 0.4797249016982894, 0.8657617242105546, 1.4124576338837225, 3.651341747853064, 7.233742446668687, 5.569116492425242, 6.114617672658736, 5.207860315999677, 7.348507075540482, 9.825462756618377, 9.696412855579007, 5.856140832747183, 4.579003866641752, 5.217570633657518, 3.466389981969711, 5.745718267656142, 3.759930850036683, 6.168686564891569, 12.05240999498675, 13.048511589727095, 13.927739301035482, 22.51872920220898, 21.72019543186311, 25.481528774384532, 25.31731874712052, 28.716640856958207, 28.394335777528827, 27.128304512270038, 32.97427954212312, 51.18315742861841, 57.40957883096511, 55.61877758272233, 67.72583207776471, 70.05291154307704, 68.26045113225138, 74.88923318924444, 76.90402923091766, 53.76500660373319, 34.50393330666327, 31.498070032365863, 19.820307185572965, 13.534272620754859, 14.013324437602876, 15.534904003143312, 22.54246542530675, 24.079002949499316, 29.46147934083016, 26.702207634525916, 17.776124746568744, 10.02292565761074, 14.262223339849903, 14.243240048808438, 6.030845651703497, 5.29315568747059, 12.759410354398913, 7.842427617119205, 8.46472684414156, 11.933327817147779, 5.398820417542612, 8.887123946220644, 10.238965884331735, 8.506646194765645, 4.082389147050919, 7.195920501985858, 5.335557979922141, 2.08066513942134, 1.9920458043775253, 1.6247369204798054, 0.11612769847194995, 0.24338130718998371, 0.23663823192398395, 1.2893172738052185, 6.425801852057058, 18.408440236122377, 32.4909278269737, 44.3220494639489, 34.56771889040547, 21.667953383538034, 21.54193155227169, 41.74985716419835, 51.375259430177756, 48.43795722530734, 37.500212269444624, 44.1911050581163, 51.24975927414433, 48.934035070480846, 29.472314888431182, 5.3230014924080145, 0.3680533374990187, 0.03314754813008251, 0.025858217700114174, 0.08309284570596873, 0.05379174460446643, 0.06833342640029808, 0.22378172905695057, 0.1890459695770856, 0.08689833384367728, 0.21892557431372905, 0.33289722557510104, 0.2635989344168094, 0.2923698260659172, 0.09203728994414692, 0.1374342430743479, 0.09594031639637486, 0.02962530376539836, 0.13365199038338277, 0.16439797927535352, 0.0522963869415464, 0.018474528220512213, 0.070045571624031, 0.07736281446752048, 0.0466830347244057, 0.021690119080425754, 0.03464520022633576, 0.03645890189575092, 0.042273804184890566, 0.08500022077632528, 0.048909849306989106, 0.015584247979155232, 0.12003634034866288, 0.13301193924440494, 0.11517635516581998, 0.14314348268653118, 0.023581674435145916, 0.0914071596437885, 0.03594593325209233, 0.06251509586769728, 0.0706944021306211, 0.044209754334822784, 0.027508340445497347, 0.01653614574142041, 0.04248622121409543, 0.01728922740796641, 0.0484235443535351, 0.07139238483843303, 0.04945309757585487, 0.07250252284950788, 0.13811584682233874, 0.037318977317021745, 0.03401967028396265, 0.09469795160956922, 0.023538491974074035, 0.13011997265200462, 0.09146850796476488, 0.037023508695945624, 0.08446508537857764, 0.07230972150160421, 0.11585743797402229, 0.12302895557255515, 0.026652241020553538, 0.11869968546013679, 0.05251828047837462, 0.05061509207852426, 0.09890966553000674, 0.11650855908350599, 0.05874381738624746, 0.9381107000573989, 5.239808511349463, 22.560829962453536, 40.06177494602819, 50.21448889086324, 73.10139333048176, 65.37239036252423, 59.31260693457819, 53.093339935425796, 50.7528498864943, 40.18230938142346, 31.18528062297452, 33.8309447996078, 34.05529260635376, 29.487845513128466, 24.559930639882243, 9.884896470654397, 4.495162713912226, 0.9377016091058332, 0.4854813782918838, 0.6038071515579378, 2.597707562869595, 5.005419436962375, 4.953315161889599, 7.427412906000692, 10.883699597850924, 8.615414500236511, 13.977339633049505, 9.276099512653968, 14.828985237306165, 13.897504691154728, 12.391181184399514, 11.070138677473992, 10.86980656270058, 10.112776371740527, 6.152573468223696, 7.5501776991351965, 8.273229868181291, 10.652467050860006, 12.062943520084506, 13.889832535097677, 20.014056582604688, 24.06418619617339, 24.439423661078177, 26.66955586402647, 28.276201832679014, 30.7848850757845, 30.008585260760402, 40.31850976328696, 55.70720349588702, 63.26461061354607, 64.43528513754568, 75.35382224667457, 79.68806482130482, 76.27981539695494, 79.86684645375898, 79.83245511208811, 57.17570750944076, 37.9849152411184, 30.60275373920318, 20.46541940781378, 16.038202931804044, 17.072459382395593, 16.668059095259636, 20.812411885107718, 21.9647571732921, 23.7863294155367, 18.490678610340243, 10.281520658923734, 9.061248744687727, 9.664561248594715, 7.60701431382087, 11.122613126231778, 6.310728826830465, 7.136565235353286, 9.406456543553261, 9.756936007930387, 14.805309810946065, 14.91001061854824, 11.392489844752896, 14.429499679996123, 9.215445941494359, 10.170987286875325, 11.604025229330986, 7.80719296586129, 5.699189151487043, 4.642232964115759, 2.0811696542847544, 0.40227227874340554, 0.2690505999470911, 0.3782542885070847, 1.4468433371474667, 6.900815098516404, 17.742462965749926, 37.65027822986726, 48.08496352164976, 41.54741187249461, 27.958740880412442, 22.427708641175304, 40.591749914230846, 56.80996218035298, 53.1936506302126, 45.19875411064395, 53.6504969289226, 60.39122735300372, 57.19990461103378, 33.18803694940383, 7.691122187722114, 0.40207588444313697, 0.0710511309725623, 0.04980523755112964, 0.03329090616335312, 0.05129038709245863, 0.05085008571885767, 0.04468572093173862, 0.1291462136132102, 0.045117074398383986, 0.13011687765679053, 0.30055752865249113, 0.12574655289250997, 0.07383915475539624, 0.02156651653950253, 0.04239518315561357, 0.10334254137330479, 0.041377052304244814, 0.0974553625189489, 0.06701133484321256, 0.06763248659309841, 0.09829093461796161, 0.029080075159248327, 0.09801732631580484, 0.023179334633412863, 0.0716667439067556, 0.05859582452103496, 0.03679631383068139, 0.03376695702994063, 0.07030299248834772, 0.03457462820675104, 0.015915401933354237, 0.05737039793823516, 0.0792627355023738, 0.08106611413700927, 0.0707789475939447, 0.2777833281265151, 0.23369801711411248, 0.1929317667118965, 0.20714232998509563, 0.13909728206213445, 0.1731042467778729, 0.13274321092232583, 0.1322651873793333, 0.13018231688728257, 0.13874702666315342, 0.10725813166749094, 0.17425409878694242, 0.17797783768225103, 0.16434170245643587, 0.21337511408473217, 0.19522639922797683, 0.254130884404144, 0.3710141447522948, 0.24477981601751622, 0.2291476080614713, 0.4924670889252617, 0.3604750118909344, 0.493611317848967, 0.3042143114632176, 0.31918164703153795, 0.32283616222200856, 0.20390763097713072, 0.1990457458962356, 0.19142237431820364, 0.23688923297149522, 0.32000212719844234, 0.19471860550824674, 0.2356147997441792, 1.706084426372282, 7.5257663380715165, 27.177104680768906, 47.91817649718254, 62.78538327063284, 79.27128945627521, 73.20630888785087, 65.92081223764728, 53.46892256890574, 57.65712745728032, 48.40303244129304, 38.75171507558515, 34.161180911525605, 46.98767654357418, 49.40822216772264, 31.64216418420115, 12.07110106945038, 5.369579638204267, 0.9385677174695077, 0.7941676820478132, 1.075837619362339, 3.5052832240058533, 5.935287398676719, 10.93179177853369, 18.42086826601336, 17.509791889498313, 18.888173564787834, 23.627600900588497, 19.169729140497026, 20.707972895714548, 22.40298986434937, 16.32272185817842, 14.535984185434158, 16.715221674211566, 11.832800411408948, 13.032433794390771, 9.529586607410062, 11.893719723147731, 17.451409370668475, 19.054813500373594, 20.420851476730842, 29.26920279379814, 30.524227888353412, 29.242650308916648, 32.70424592879511, 33.42946275588005, 34.495049138222974, 29.31088778280443, 43.307355834591775, 59.03559346352855, 69.7463155561878, 74.26662752705236, 79.9651881187193, 78.0636073696998, 76.80955502294725, 81.32153587956583, 83.3181635026009, 64.99173610441147, 43.68909266687209, 34.59653262169131, 27.846025689955685, 17.60629984640306, 20.72325444990589, 22.62688659852551, 31.450330864998605, 36.3770454929721, 41.25341453859883, 38.30813815516811, 27.246252144536665, 19.328859698387888, 22.416339651230846, 22.98652087488482, 19.35173103886266, 15.494887002052801, 20.390045181397472, 18.38146217407719, 19.046274500508463, 25.350170558498753, 19.952883297397246, 23.363297870082242, 21.089978410351662, 22.3497829129619, 18.336686357375115, 20.650200305446504, 15.70411014941431, 9.278910871474974, 6.041750821375079, 4.934797162009824, 0.5340354793494748, 0.7383979520490094, 0.5472140915451512, 1.9194607508759347, 8.449435484024788, 22.765277624130253, 43.02109733704598, 56.866934607105875, 48.60424610876268, 35.72801482292914, 34.320652715621456, 56.990465733312796, 66.71859095173498, 62.945529722398334, 53.598772633460264, 62.201844415357044, 71.24164858172017, 68.42257053621354, 42.61535952168126, 11.950041036452017, 0.8149272551940334, 0.2225614122806057, 0.114974835737338, 0.2530718597793772, 0.16388690669930753, 0.24660351896478286, 0.41999278109400506, 0.3867884160530183, 0.2969382535065374, 0.559299833351566, 0.47881521825348183, 0.3561198939719508, 0.4151256100064324, 0.3158321267654819, 0.28634209306009356, 0.2943722573259185, 0.26588175385709734, 0.23645669972944647, 0.21556629408751765, 0.22162220380719633, 0.15349126210616482, 0.2016820689483035, 0.3099617175757885, 0.07038289545885018, 0.21291872486472133, 0.12375016606623128, 0.09384852864088551, 0.10116572551909955, 0.09038502215257577, 0.1315330831153739, 0.11358706746250392, 0.2398211740317845, 0.3079965181889073, 0.28514877322220034, 0.4022682337991653], [0.19206118439474415, 0.05916589352812979, 0.05896314452852934, 0.051224629935478015, 0.024336688558480913, 0.03416927193381614, 0.11614231542954523, 0.04027753993267975, 0.04541006472502505, 0.09786992333829404, 0.0675103874997266, 0.006429986622665198, 0.0111517695439679, 0.047626690338215524, 0.03542909203397651, 0.010215018297575656, 0.0628529827771408, 0.13975259367256396, 0.12227692536168522, 0.06594564525350448, 0.16273572169724973, 0.1800802434163709, 0.2592222434618781, 0.24897995434941786, 0.18458016727480198, 0.17916715854117948, 0.1159498971256037, 0.020479838055888974, 0.10157880778875082, 0.09541059724025189, 0.19483266067841362, 0.10905836934163686, 0.27067510471228634, 1.5871334027859474, 7.830765430004367, 25.292803933543546, 37.55690228554511, 50.80368380392752, 55.312448317004794, 51.23040237734395, 45.43102118276781, 35.17084998469199, 37.412406090767156, 32.8699033106527, 38.45336391079811, 43.976300377999586, 49.823573712379705, 33.830505494148504, 10.485644725061233, 4.050480175402857, 1.3465528670818576, 0.04304959461273205, 0.33278703148807254, 0.6075954869870217, 1.3210892076453855, 3.0109829479648225, 4.161832832521008, 4.1272929310798645, 5.951204376835977, 3.852206324377368, 6.777833594429878, 4.085623386406129, 10.0144798140372, 11.4899254422034, 9.3593979074109, 11.46620588917886, 14.602077103430226, 11.005438200889095, 5.62584279044982, 12.69149745664289, 15.368898510932924, 21.19694340613581, 25.677149141988448, 30.790721562600908, 34.33864854997204, 43.946831610894975, 39.41101058836907, 43.496829848135675, 40.245349714832926, 43.53861485758136, 45.48109023801742, 50.173107885545306, 56.09707532390472, 59.45307877755935, 48.63069072846444, 56.16760346197314, 64.33111483050932, 63.524871641589755, 66.45392510198778, 79.43269498886602, 54.2665796895181, 41.712751542368245, 50.120908983292125, 43.00002244211013, 26.87461345426498, 26.18928909301758, 22.23834445399623, 26.097772352157104, 24.21455810146947, 32.77240299409436, 28.184538002937074, 18.458248453755534, 17.251317501068115, 10.245759429470187, 13.267595575701806, 8.402835765192586, 2.7009683703222587, 8.426739669615223, 5.453853232245292, 5.816086078843763, 9.198702323821283, 13.82175293660933, 10.426418896644346, 11.597288558560034, 5.698658650921238, 8.91972472590785, 7.841775032781786, 8.115614816065758, 4.825528754341987, 2.3304132348106754, 0.23372004980281477, 0.10901404349433799, 0.1097784536860643, 0.07697436192463483, 1.0440128560989135, 3.2456968436318063, 10.71158403350461, 19.941580987745716, 29.898545126761164, 32.75167719010384, 32.42283155841212, 58.918651919211115, 77.54971411920364, 71.65771007537842, 46.555925569226666, 36.9862013478433, 44.190485323629076, 49.32589554017591, 54.6485871653403, 43.60184346475909, 12.184666433641988, 1.548825329349887, 0.015586459100426686, 0.010542099536847203, 0.1323220311033149, 0.03734947910772697, 0.08233040436020783, 0.13870852308407908, 0.10220925984603745, 0.14511225204313957, 0.05315399939014066, 0.166069567804375, 0.11338127326340446, 0.17034594720650106, 0.018636496444683404, 0.1355516126439456, 0.1727960342841764, 0.16600723889085556, 0.11922158285855286, 0.09969462986074148, 0.1526187339256848, 0.12990732196598284, 0.036772894522836136, 0.040395456185985, 0.06075264548041648, 0.010763218367261993, 0.049782530705053965, 0.045684688093681494, 0.05847126245498658, 0.05749954121007074, 0.06250165485506577, 0.06027259563486423, 0.05540075524139309, 0.09625632766514056, 0.1210093103168953, 0.1409211841922614, 0.059220676475595084, 0.03376134926633489, 0.05000534737783094, 0.017266221787600268, 0.05863347391207373, 0.037857594584385236, 0.10866883661477797, 0.04397825405542408, 0.05716791323896858, 0.11323161798739627, 0.06645078830901655, 0.10869702098951226, 0.01470013176121058, 0.047271034019368316, 0.008368678409756433, 0.043896470339067524, 0.044207896571606405, 0.03720535115609246, 0.021755129301680193, 0.0914509185860234, 0.15888252926449623, 0.14760951481519208, 0.20783954660498327, 0.0714270809605237, 0.0932519912960068, 0.06727743548371139, 0.09177316581049273, 0.0686811383873705, 0.07313666745058953, 0.03518097913793979, 0.033561917427446575, 0.11564854877970873, 0.37769669907227643, 1.7033920869711907, 8.09479340430229, 29.315616200047156, 42.97764924264724, 59.81188151144213, 65.1971035618936, 59.31190090794718, 52.52127009053385, 37.88451040944746, 40.88697494999055, 40.961692179403, 37.72550928977228, 31.014520237522742, 40.841153821637555, 33.05247591387841, 12.815459062976222, 4.376472282794214, 1.352134767559267, 0.08887630391625628, 0.4169157123373401, 1.792489093157553, 2.325348229177537, 4.101460446273127, 6.8757114391173095, 8.315831711215358, 12.817909563741377, 12.62825414057701, 14.163692420528783, 11.63389898115589, 7.929691037824077, 11.666780210310414, 11.792582388847105, 11.653733426524747, 14.562006169749846, 8.965150675465985, 9.924999763888698, 11.107044258425313, 14.310176276391553, 18.65919932242363, 24.401447273069813, 29.67180467421009, 35.26474760424706, 40.73641869329637, 41.03631134956114, 44.06812698610368, 41.70002737352925, 45.44977011219148, 48.83443432469522, 54.606504055761526, 59.12653753834387, 65.31165638277608, 56.95092039723551, 67.35104960779991, 72.4886328174222, 72.07594456211214, 72.9925318687193, 84.03573759140508, 61.5411643059023, 46.97583490802396, 52.69907113044493, 43.30822267839986, 29.407719335248395, 26.446971162672966, 25.369915769946193, 27.174017775443296, 27.82399962025304, 32.89040946191357, 26.102681198427756, 20.477755262005715, 14.91885164091664, 11.242669032466027, 11.598348579099103, 5.4144446888277615, 7.402433291558297, 6.272291560326853, 10.505793940636421, 9.13204066215023, 8.07278988822814, 10.209233337833036, 12.42905657137594, 11.006063818931581, 10.10361175383291, 17.872209087494884, 11.017829948855985, 9.691727584408177, 8.207414457874915, 5.995681603108683, 2.644037618752449, 0.34989460221221375, 0.4286770618730976, 0.14638299272666055, 0.8540669323936586, 3.1782489918893386, 11.0108853924659, 20.50363309921757, 30.254074642735144, 32.3434074847929, 30.541225479495143, 48.56430461329799, 73.62591620414489, 78.50500737467121, 54.68502598424112, 43.71048135142173, 52.50740843434488, 58.600202529661125, 62.22365671588529, 49.844542703320904, 14.565362738024804, 1.947473092905937, 0.0313380063180962, 0.06643722089187754, 0.08192729655533068, 0.02463199821631274, 0.0045942517857427805, 0.17567016634969942, 0.07772014851892188, 0.11003933726779877, 0.08393532791805845, 0.15723168639646423, 0.007624244439460698, 0.129572311716695, 0.048613131962596416, 0.08390144384916752, 0.047910403340093555, 0.09379120994239085, 0.07584157835451827, 0.07957473247041626, 0.01810290471410319, 0.07690058765752662, 0.04484521277669457, 0.047135536048200824, 0.03084855848893283, 0.033849100807621595, 0.06915305620960652, 0.03131478619311125, 0.06430542036410301, 0.02519376091508856, 0.13571566271205104, 0.12536689503899506, 0.03467845610312877, 0.07556207117534454, 0.06239467833731925, 0.07500098837960152, 0.2214001455614644, 0.19464542878971947, 0.16975746910658576, 0.09408150363953845, 0.13103434455490884, 0.22262708133747502, 0.34511304911105867, 0.2368939214295918, 0.14039601559840864, 0.2477340962016775, 0.17342822536105112, 0.11114326996668694, 0.15697752906670495, 0.26061171245190407, 0.13578137773419582, 0.20596168124147002, 0.17407049815500938, 0.21848424638230957, 0.3239779703078732, 0.21022732009089765, 0.432591587305069, 0.36067180455692355, 0.44825091477363344, 0.38141541243080174, 0.3697303958958195, 0.33202063712862234, 0.4053750880543263, 0.1785443903457734, 0.2279175466467296, 0.20801323405917616, 0.20106991873152796, 0.23995297179827768, 0.6226926897802662, 3.042697762289355, 13.557304778406698, 38.33784226448306, 55.68521076633085, 71.32303776279574, 73.0313947123866, 66.23183265809091, 58.71740295040993, 46.91596384971373, 50.186287049324285, 44.784489062524614, 50.53325599239719, 58.0519885401572, 63.0318061767086, 43.54283925025694, 15.920996627499981, 6.513519287109376, 1.8182128547660767, 0.1911847798093673, 0.5638321933727111, 2.0076030276475416, 5.7207813089893715, 10.50629992638865, 11.29127602423391, 11.500597230849728, 16.28231458125576, 17.03630885770244, 22.164086141893943, 18.52956694941367, 21.525222255337624, 29.231767692873557, 21.948185159314065, 22.110814471398633, 21.18769837963966, 18.980082542665546, 12.678178068130249, 18.73240447813465, 20.757155495305216, 25.929347738142937, 33.82093883329822, 35.38395235615392, 43.31114484417824, 51.22643686109974, 45.80184598122874, 44.85154590299053, 44.12127510193856, 46.63266281927786, 49.31220646827452, 56.40786824687835, 63.769886416773645, 71.84990621382191, 65.47239119006743, 69.1334452167634, 76.58386968797254, 72.7334200951361, 75.77967397628292, 86.10928289351925, 66.86780575783023, 54.01366133843699, 58.319772674191384, 49.207043801584554, 36.7655994046119, 28.709264839849165, 29.183055777703565, 31.90486884886219, 36.991127844779726, 49.983171032321074, 36.80822380127446, 25.407486192641723, 24.051887604498095, 17.2243433613931, 20.96318583334646, 17.655353007778047, 9.980703303890845, 19.59699292336741, 16.26961100486017, 16.367146622750067, 20.903632487020186, 26.107197807681178, 20.80211958577556, 21.919575391277192, 14.296405815309095, 18.515956324915734, 15.188645009071598, 19.47663107225972, 11.276623029862682, 8.439682510591323, 2.7046428957293114, 0.342942813952123, 0.7478872073754188, 0.4625183217708142, 1.3891032290074135, 4.194900374258719, 14.00568267991466, 28.39480842313459, 42.102442941358014, 44.63176373512515, 43.774451286562034, 74.27073817099296, 89.7766911598944, 80.93255442957725, 60.177246370623195, 52.38791342704527, 60.45421669560095, 69.05795528042701, 72.17823997620614, 60.42419095193187, 19.5036816981531, 2.6340350845167717, 0.1530099137415809, 0.15347315178763482, 0.2632424890274002, 0.3018112468623346, 0.24936387165179177, 0.281903869923084, 0.27760829235757556, 0.3967385805181919, 0.2663939602432713, 0.3301913417395084, 0.41473564060945667, 0.42763315982395605, 0.1471771347907282, 0.2644334493144866, 0.3436361541671138, 0.38536781324974956, 0.35134048591698375, 0.2015762568842019, 0.2416573488904584, 0.24894408611280305, 0.25350350435943375, 0.15352008233387626, 0.12747490853672067, 0.10148059531685807, 0.1494192902839953, 0.127463371252581, 0.2039377841978304, 0.12273992592048262, 0.20354510284960273, 0.20587007244748456, 0.250959632798068, 0.21839064575972097, 0.2378836917060037, 0.43718557143884323], [0.03352511073312452, 0.08856300459874254, 0.09260345956370716, 0.13558496811216877, 0.02693901071324945, 0.0812618266190252, 0.09637459631889098, 0.08528744246089652, 0.042454221721498236, 0.05795093553681528, 0.0158292199147024, 0.06645574489788664, 0.06520949604530489, 0.014862554850086812, 0.06982057160066982, 0.128935095103037, 0.053543689165024035, 0.21740652921219028, 0.17689679569054037, 0.041638472147526286, 0.2252230928429673, 0.17773593775928023, 0.2318829709603902, 0.11045796601402183, 0.2378338653474085, 0.09314091620786537, 0.10908456954864726, 0.11176708004167003, 0.045710103060569496, 0.07404530901582011, 0.0978047522385755, 0.06672429701974315, 0.026282343127193953, 3.9131731948544903, 14.244465789487286, 29.974576350181337, 45.715753878316576, 51.986180351626494, 61.76564939560429, 46.88307869818903, 43.9078079500506, 39.40207542911653, 37.77129511679373, 33.18513047310614, 33.032997423602694, 46.114698148542836, 34.05007977639475, 9.356058989801715, 7.779245097790995, 2.1750312370638696, 0.5506516199919486, 0.14011574999218987, 0.5514372584800566, 1.4839527587736807, 2.529167821330409, 3.5045921514111185, 3.7672129754097234, 5.199911142549207, 13.898775539090558, 9.445177201301822, 14.261894841347972, 6.731969320004986, 12.381225228309633, 8.689102107478726, 12.938525388317725, 8.494369176126296, 10.084340168583779, 10.307157270369991, 10.509334860309478, 17.454963038044593, 27.273885242400635, 32.23968628914126, 38.860482400463475, 45.88263503966793, 50.079622114858324, 56.99438025874477, 53.680244184309444, 57.085614588952836, 55.00424808071506, 55.7252150197183, 58.47311773607808, 57.17578203447404, 67.9906391328381, 59.62351360628682, 51.98270905402399, 46.31952039657101, 53.64634313891011, 60.073181967581476, 61.140662854717625, 74.49826701994866, 49.801733955260254, 60.66135706440095, 64.04486810007404, 58.040633278508345, 47.76287025020969, 36.494328283494525, 34.89060840299053, 39.46604144188666, 34.780652599949995, 35.02025058192592, 29.66804704358501, 28.541936528298166, 23.603972542670466, 21.54465171598619, 14.493739278085771, 11.852047481844503, 9.360862912670258, 4.770778350291714, 10.689216717596977, 8.104242884343671, 7.024253558728003, 9.629455054959944, 9.05681940817064, 11.394541244353018, 6.746281068171225, 11.021090419061723, 8.135106544340811, 2.850259417487729, 8.111026623556691, 7.405511371551022, 2.6383114485971393, 0.31954495656874876, 0.14749909090178628, 0.38872560726538785, 0.08395859400831884, 0.7162670815183271, 4.919612196183974, 13.015431300286325, 31.36131463512298, 47.895281622486735, 56.959071082453576, 44.235737708307084, 43.360088179188395, 24.1327178478241, 22.361663772213845, 29.305151316427416, 41.86818330518661, 48.15939441803963, 53.89843779225504, 43.36325353191745, 17.56752721724972, 2.176344740775324, 0.10009066667407752, 0.06713418470275018, 0.09266341360466135, 0.09579515039560296, 0.028902279558561506, 0.1418259799961121, 0.06859161335253908, 0.14314905980661993, 0.1358276188013054, 0.09751396824515636, 0.10205994930959518, 0.20252099651242458, 0.08601226888957524, 0.0833003252985016, 0.06833550249857288, 0.13617189871447702, 0.17148318940833693, 0.12926697971359377, 0.042722498051702015, 0.08527366820001796, 0.009910780842596245, 0.0428679283528078, 0.011577125499776054, 0.07970338161554068, 0.036035879635282105, 0.11094958761767035, 0.02281581059158329, 0.02734589150115367, 0.0646417789281376, 0.05401869049115528, 0.10713404840639523, 0.11136695997969759, 0.1585875088048558, 0.0778736955215854, 0.04638971497995719, 0.127244055601618, 0.09155709071144943, 0.034829478846081806, 0.04247242014013952, 0.13533448800444603, 0.09708423122403123, 0.06676511418434881, 0.04822389801002799, 0.07337123591212497, 0.06242144927983323, 0.05053842582950189, 0.05465306491861421, 0.09458287754246304, 0.046692955563025135, 0.07659540121113101, 0.1140898892716054, 0.06222468342692141, 0.0818949599840468, 0.029132243831672018, 0.2347104329495661, 0.08173188284760521, 0.07750433388977282, 0.08638480212539436, 0.08550381633423029, 0.16876429739979007, 0.08508359412512473, 0.049971865505100264, 0.03365884287162654, 0.14165344167380564, 0.05643996117155879, 0.04965704933349645, 0.07383714760503463, 3.5490286830932867, 17.938048032022294, 38.459223931835545, 54.04490693922966, 60.735940933227546, 68.05514643269201, 54.45911315179641, 50.83731028341478, 44.457963512789824, 45.476324558258064, 33.80243309082524, 37.74574479749126, 42.86579109007313, 36.138730126042525, 14.234883439156318, 6.0152355990102215, 2.285521953336654, 0.6808230124654309, 0.47736323648883455, 1.2132085835741413, 3.238912614122514, 3.1902698307268085, 6.498503963793478, 10.008214808279469, 10.95126340466161, 16.710969824944776, 15.590536940482357, 11.749606940054125, 7.52633753322786, 16.595053980427405, 15.14245713910749, 12.569719629902995, 16.372404559966057, 17.200542419187485, 10.12522989703763, 13.73550590007536, 22.091018269138953, 24.865228322244462, 34.43945346340057, 37.61916598966045, 46.17997031058035, 50.291775272738555, 56.283584025598344, 53.7956089358176, 58.01899748463785, 56.432802754063765, 57.983849125523726, 60.02059867305141, 60.363017666724424, 67.64272489855367, 65.93654878677862, 57.547332471416844, 58.372093169919914, 62.061250978900546, 67.42373897183326, 67.4459788107103, 79.2361528642716, 58.83150077635243, 63.039003725974794, 65.6725379728502, 57.158319642466886, 50.25513641295895, 38.789134487029045, 39.70128559297131, 37.8813450567184, 37.59878927661527, 36.76897264296009, 29.582633510712657, 27.4391072411691, 24.678898088393677, 21.011481977278187, 15.493581833377963, 13.270411837485529, 8.859841900487101, 6.946289097109149, 9.178335416701533, 7.540112897273033, 9.491774958948936, 9.769549369812012, 14.008493058143126, 10.798348822901326, 11.237847458931709, 17.87523323489774, 16.58882917896394, 10.738270859564505, 10.858964150951756, 7.926016267268889, 6.42093321008067, 1.2940790311944101, 0.4277295643283475, 0.8962933923448286, 0.3645982196734798, 0.8390905876313487, 5.672272376475796, 12.660748035677019, 26.337954767288704, 37.44615024135959, 46.50725680012857, 51.11528865752682, 59.481304153319336, 38.175365924835205, 29.139754772186283, 34.675309504232104, 47.18601119133734, 58.17392326170399, 62.90364273132817, 52.06121137065273, 21.53478499381773, 2.7846487058747202, 0.23112023850121807, 0.03156209469682748, 0.04758268241740523, 0.0152935367640889, 0.0419539318329865, 0.060773743541851166, 0.07065544655967144, 0.12955328209265587, 0.09258023943872222, 0.032495791167621656, 0.05248005269095302, 0.04811613242171946, 0.08641688588766322, 0.03750669567154781, 0.035924697294831276, 0.051762619010743596, 0.08053869324465913, 0.12432303129424974, 0.1018558175212914, 0.09710639414768066, 0.0368393220067505, 0.02285718316993406, 0.0408476663963689, 0.039904171661023176, 0.037761090488563624, 0.06645609729833181, 0.0247069445979451, 0.03474000743740509, 0.01734966216909309, 0.05199798037328067, 0.041658011220035054, 0.06825814293997903, 0.13686151574215583, 0.041188541048717116, 0.31362098251138965, 0.42870405881154927, 0.21566966999202006, 0.19741848321451297, 0.12345689994793747, 0.24227826315308773, 0.3227161622095493, 0.1501556233532967, 0.20965077764084264, 0.13980177651730277, 0.09291550249702508, 0.30865915359989293, 0.14518363611592403, 0.27345689253941663, 0.16982581947119008, 0.32583656089921154, 0.20521053203171302, 0.32663424228948934, 0.25902925059199333, 0.1884222667544119, 0.5768578944187011, 0.3798794061426194, 0.5402131510838386, 0.24809351401223292, 0.27201416511689464, 0.23728672535188738, 0.3850882830879381, 0.26130391885676696, 0.16387402110042112, 0.34003649087202165, 0.21558400604032704, 0.2143021111166285, 0.26240981274074127, 7.401791984035124, 23.36238984138735, 45.827235483354144, 63.708536624908454, 73.30003000074818, 78.94006882944416, 61.27203087652884, 57.62180259150844, 52.28460211907664, 51.84477498454433, 46.2599866620956, 47.346443976125414, 61.24253465283302, 47.98087166201684, 16.20585778067189, 9.81099803601542, 2.6520652396063653, 0.9951438009738923, 0.6330618430529872, 2.0365363912236307, 5.130482248721584, 7.792120277881623, 11.665032794398646, 14.885146714025929, 14.972319429920567, 28.53212275812703, 21.35086113406766, 22.780227738042033, 19.82776165008545, 30.438382894762103, 20.10337091261341, 21.229952112320934, 16.952715304590043, 20.62912541051065, 18.45147648165303, 15.530466821885879, 25.261415166239587, 33.17404585499918, 35.845705539949485, 47.20088874140094, 52.3923731619312, 57.19886518293812, 61.38689748702511, 58.06176308662661, 60.70997876505698, 57.755065118112874, 58.165556846126435, 58.51278858800089, 61.66367169349425, 72.0864486694336, 73.2539656854445, 68.0201667354953, 59.4146042485391, 64.97603093424152, 70.44445822315832, 72.33384040094191, 82.40946800478044, 65.66310075021559, 70.62555405401415, 67.83565059784921, 59.489152816034135, 54.21994663053944, 46.44499309601323, 42.52993029932822, 44.04214520608225, 41.63923455822853, 42.64148250702889, 34.64073773353331, 34.053621676660356, 28.536664862786573, 27.773320636441632, 20.46274631254135, 16.827405383509976, 14.706389596385343, 10.470612241375832, 18.677707026081702, 17.396105912423906, 16.876813519385554, 18.624843282084314, 18.65906596183777, 23.028341185662057, 15.735392032131074, 23.28024168168345, 20.40690548958317, 14.143853072197208, 20.103002209817213, 15.944125863813586, 8.232135195885936, 0.8203105856814693, 0.584866822727265, 1.335974357301189, 0.3992694592283618, 1.4446487710360558, 6.410757110964868, 18.92615975872163, 38.67225962300455, 59.536664485931404, 70.94887502731817, 54.82860042202858, 51.911482734064904, 34.13358703736336, 34.776663549484745, 43.75522382797734, 56.32143489776119, 66.88176155090332, 73.17743239864227, 65.30369004895611, 29.860035296409364, 4.787415573673864, 0.5056702465780321, 0.19526660352224307, 0.2786532362862941, 0.2603088319301605, 0.13859316556444093, 0.18825346694117595, 0.25831133427639164, 0.43116298654387075, 0.2893299891823723, 0.3517875135425599, 0.18629988144722678, 0.25151185961740635, 0.26521194786314045, 0.31999979829115255, 0.2445319559304945, 0.3343210459476517, 0.2486322730058624, 0.30778284094506697, 0.20526838699175468, 0.16510481795957013, 0.11826171299382565, 0.16315955218047867, 0.14876252310650964, 0.13684702135862845, 0.22760440054680073, 0.29338308459808754, 0.19353389649862246, 0.12940104510034287, 0.20605160464202205, 0.2832751366640291, 0.19875021981856517, 0.26046471550099315, 0.3810738904341575, 0.29372267605316255], [0.08697946255485858, 0.1330426287266516, 0.04486569413735021, 0.033545308641248175, 0.045113090741177725, 0.009402611739783278, 0.04064380656927824, 0.07359597546559188, 0.029674687708217292, 0.05983095360739578, 0.012992797569642145, 0.012042253867783135, 0.131999324226091, 0.035942654395776416, 0.026732553848095482, 0.08292419911031762, 0.16653184057964435, 0.1447278597662526, 0.0855316636302779, 0.08532459006434487, 0.14774442289865788, 0.06329889574478711, 0.17091613112678453, 0.1361903461116937, 0.16303319363824784, 0.11872375594271768, 0.06305594628136005, 0.03865238399274888, 0.014999237384707218, 0.024345699667690263, 0.058966683854739514, 0.1450243817582246, 0.7942810017735729, 7.575403442305904, 21.404472089582875, 36.363450557954856, 52.13621101071758, 56.06307621925108, 56.51340746110486, 47.52784967422486, 41.22052938707414, 24.61273358714196, 17.517819020055956, 43.342064888246604, 35.48585945560087, 34.70560981381324, 24.91602497716104, 12.350248309873766, 4.453625794379942, 0.5421500052175214, 0.2795160964371697, 0.20431682918100588, 0.7253234052369673, 1.6441488530366652, 1.4180722616372572, 2.7270119276738938, 5.613232370345823, 12.256942968214712, 12.332343670629687, 9.543784606841303, 11.11307196078762, 6.903254812763584, 5.580474695851726, 7.232218115560471, 6.191318150489561, 13.123340606689455, 19.876336282299413, 9.427901121877856, 28.425414677589174, 28.40934276580811, 37.560632459578976, 50.49800172928841, 51.927042776538485, 61.06725569694274, 62.89510373146304, 65.25333858305409, 67.92131516241258, 61.01979501785771, 67.74509091531077, 66.25448042346586, 66.33880353743031, 67.97660489236155, 68.29116329070061, 57.89432102634061, 46.68698764616444, 38.79703806292626, 45.764763893619666, 58.2004306393285, 57.88913957534298, 65.12952112382459, 53.28211968944919, 65.58377865822085, 70.91479747526108, 69.61897188617338, 58.01716573776738, 47.840121330753455, 40.109969108335434, 44.35700562692458, 46.05172057305613, 43.53749305971208, 41.31284236907959, 43.83732295805409, 36.74300263004918, 30.5730535522584, 29.9340602274864, 20.28721828614512, 17.96756386756897, 7.264736525474056, 9.354979357411786, 6.294383329729881, 5.154325846702823, 4.868519892615657, 14.815278514739006, 6.79871040967203, 11.264767666016857, 20.380149041452718, 12.949449189247625, 11.10751788462362, 7.3949445063068024, 5.3139746477527, 3.3936878702332898, 2.9928794935826333, 0.3760573934883841, 0.26998728033035035, 0.5939854753594245, 0.5583403848351971, 2.022680128293653, 8.572104669386341, 15.81776866989751, 26.639226136669038, 40.8486141697053, 33.218906002659956, 19.070889334524832, 26.5338045935477, 26.120773130847564, 32.0764882333817, 37.35358230529293, 50.14747911883939, 51.99130296707154, 44.92087771815639, 28.310240161034372, 5.530531156447626, 0.4293263060671668, 0.1701983373852507, 0.07415182588081207, 0.11380854348141341, 0.06987090357729504, 0.09920329170962496, 0.03565246029005897, 0.07106276018725288, 0.10163647888769066, 0.0957534215863674, 0.09118051253139012, 0.1471083247733693, 0.05019428381215661, 0.04707883788092483, 0.13761870172475615, 0.09069579337993938, 0.2054822480966968, 0.09536156761309794, 0.06737354887469162, 0.04086738549953988, 0.04334817738122037, 0.04895995911811629, 0.08384723546764544, 0.039937228354955875, 0.02986554893845272, 0.06609672545305183, 0.05191734578881053, 0.07085343432282248, 0.1317595387057912, 0.022715949115433523, 0.06083404232237128, 0.07560053645002265, 0.11501239702826548, 0.06251988008678441, 0.034458853169194156, 0.08885824722388098, 0.03513676820382957, 0.03727769283878227, 0.030010841343732133, 0.052309736023626985, 0.09178658001004689, 0.07824678034071, 0.0685907936384601, 0.0631487348507489, 0.05089244655063076, 0.06831039013641496, 0.05136184394359589, 0.025898565635866216, 0.045273517213401296, 0.06349710950387583, 0.06824763987453715, 0.08711817043442881, 0.05487379400179752, 0.023554281046193455, 0.1891853669357877, 0.023073409571342414, 0.10705848915442344, 0.017053159329319195, 0.13083136189849148, 0.043227763681281964, 0.007384372255464475, 0.024809368638201587, 0.05621469301742412, 0.05292572434090319, 0.05005481367510173, 0.0345975112530493, 0.3968101331303197, 10.079390137426316, 23.87494360246966, 41.010572756490404, 60.418174036087535, 65.92911981767224, 67.71175076884609, 54.675004328450854, 42.00497988731631, 27.81551161120015, 25.19335419900956, 44.70011495774792, 33.3669166411123, 31.618828042860958, 28.421407976458152, 12.094660785890396, 4.758175284631791, 0.7484337038570835, 0.3975399084869893, 0.6155329546140087, 2.1509579352794157, 5.607647895812989, 4.409021581372907, 9.453558325767517, 13.274834309854816, 7.899583904973923, 15.033313266692625, 11.093938639087062, 14.792355202859449, 14.419332896509479, 11.029659817295691, 13.823954366868543, 12.217262310366477, 16.611249446868896, 16.862683180839785, 12.925971842581227, 25.04930711561634, 29.97990489006043, 39.140508251805464, 49.36318159103394, 52.873789187400575, 62.05317089634558, 63.22743831142303, 67.51531062587615, 67.69330778429585, 64.8608583788718, 70.1779253252091, 66.63870796080559, 67.90128754031274, 69.9161777188701, 68.1297734475905, 63.299598155483125, 53.531135282208844, 48.46968135526104, 54.98584824223673, 62.53734434804609, 63.18394707095239, 69.00835298722791, 60.382966841420824, 69.63721090747465, 74.05104621764153, 68.95579322691887, 61.809054343931145, 53.77216885166784, 43.02168177020165, 45.49312406970609, 46.39830904622232, 43.94334462381179, 40.40958327631797, 41.60436860976681, 33.91543265311949, 30.052437359286895, 28.809840294622607, 21.216976911790912, 15.75065201328647, 10.084906951073679, 11.356928656178138, 8.87735136093632, 7.968891695622475, 10.045978407705984, 11.81293752885634, 12.756667637055921, 17.64942042289242, 15.759692095941114, 16.868298053741455, 12.168826922293633, 14.230570793151857, 7.724440761150853, 8.396119686865038, 6.099747967335486, 1.226157062957364, 1.195217529612203, 0.632518043200816, 0.6965488976528568, 2.142443940524132, 7.5220675429990225, 15.49459086310479, 28.45594640701048, 40.265961770088445, 38.055823849093535, 29.397831040043986, 26.911462160848803, 31.976850225079446, 36.01422625203287, 45.28917651022635, 57.9400009493674, 61.56839732200869, 55.20138640557566, 35.033064965278875, 6.869221877667212, 0.5698826332246104, 0.15853797355967184, 0.02176533742327123, 0.1600915385830787, 0.043328990709156766, 0.015871741624939588, 0.07148804623753795, 0.0434594861261787, 0.009155704474617398, 0.09756762504337296, 0.015931142167368486, 0.05248403251771966, 0.01991382739957302, 0.031074313108899423, 0.10964052721617684, 0.07815461996341906, 0.0835017221529157, 0.10054116467795066, 0.06126691264310672, 0.025941853434027686, 0.016803244211440607, 0.060679158496279875, 0.03599826854863956, 0.05343374788701054, 0.056468187681128906, 0.051763036528662335, 0.04090447564639392, 0.03884749126530463, 0.07762458671124713, 0.009325710876334098, 0.046245977733164065, 0.022151420839251052, 0.09365696069453994, 0.16397555839390526, 0.19485313054775039, 0.17676086104925604, 0.16091568065026116, 0.15960665089228462, 0.2156235361772199, 0.1506431923518258, 0.14489264527876533, 0.24281420294315587, 0.16477000689314258, 0.31986937948292304, 0.22070052342549448, 0.11298683757383017, 0.24790036792476333, 0.10152705088858643, 0.1854788803405339, 0.19868399917839036, 0.2063261552323257, 0.22477015101861572, 0.25529720730358557, 0.15768586928325315, 0.40109415808993004, 0.13898206243832267, 0.2992999187159923, 0.47541354272154074, 0.36243316326891223, 0.25405493444733085, 0.1594111758975252, 0.1457904237172296, 0.18499223064751397, 0.12275312561541797, 0.21336855637210034, 0.25552858117847677, 1.502941810796338, 13.630600148631682, 32.39445124903033, 50.252602561827636, 70.64026294216033, 73.76068884326567, 72.68326082537251, 62.06322000872705, 52.73556094015799, 35.87004776923887, 27.053461767012074, 57.59520107699979, 49.25038991435882, 47.962299239250925, 35.66797902507167, 17.619402523963682, 6.1568008026769085, 1.1993084391278606, 0.6811932474374772, 0.785425515665162, 1.8769184788388593, 7.629171292628012, 8.127686890863604, 12.749175910026798, 19.724626848774573, 25.829829362130937, 19.94171827070175, 24.86256503289746, 22.021349130138276, 19.09299777400109, 14.184547662734987, 17.953100127558557, 14.184878122422004, 22.620157772494903, 26.17278572051756, 14.44295439027971, 34.21712175492318, 39.65831995010376, 46.75535848063808, 54.87741431882305, 59.440762535218276, 64.75216165665658, 66.95623951573526, 70.5963873094128, 69.62526336792978, 64.4657148853425, 68.76699386104461, 64.96284784809237, 67.49827969458796, 70.20477787140878, 73.14476689984723, 67.20832240196967, 62.50638115790583, 50.75404620939686, 57.66125379070159, 67.49874253426829, 66.72299185106831, 74.36643615845712, 63.27201212606123, 74.34355305087182, 75.12519513407062, 71.52343165489935, 61.84997643193891, 55.79579022622878, 50.62080721701346, 49.73038996419599, 50.87254101230253, 48.039209073589696, 48.00368808930921, 52.255651104834776, 42.672614359086566, 38.794127664258404, 39.183846519839385, 27.610830568498184, 23.752555847167972, 13.626408115510019, 14.223305583000185, 14.31907025075728, 12.299527160583004, 11.661082967635124, 23.66634607315064, 17.893672297077796, 20.1900964783084, 39.41179506240353, 25.657335289062996, 21.383952210026404, 20.707768932465587, 12.192289560071885, 13.239606522744703, 9.573551474079009, 0.988902697159398, 1.3049801559217515, 1.2339025183070091, 1.0502370446920395, 3.158024270688334, 10.517871898989524, 21.467435936773978, 35.36202630689068, 51.74137738443191, 41.91132937708209, 31.768956761206354, 39.498495132692405, 39.45803196199479, 45.02492250934724, 52.114186902200025, 66.28498077392578, 70.19565443838798, 66.23453909350981, 45.874680472958474, 10.239465986528705, 1.5043291040966589, 0.2837817659301143, 0.23796468252135863, 0.3668858195024152, 0.26992118226424344, 0.19775911654916503, 0.2626002315552004, 0.1497244384259947, 0.1927173080583734, 0.25058254899997867, 0.14551653196254086, 0.3809194471086226, 0.17495571275151547, 0.14844116454403247, 0.34641392769352086, 0.23561253212392333, 0.28877978483515404, 0.1694551708116647, 0.16615490999913987, 0.11866862059480722, 0.07835465318132794, 0.13268195453190035, 0.14622746155627314, 0.12853925747256126, 0.18355671977323873, 0.1089437625881645, 0.18945761926231847, 0.1817079810726066, 0.1759525616803477, 0.08835138813141855, 0.1847161019160863, 0.13034363968237755, 0.2881371902842676, 0.32175168815639715], [0.08061360898277453, 0.15079717602460616, 0.09073455742890797, 0.03941701634997322, 0.10569300637730669, 0.06462720793581779, 0.08062696955617397, 0.02574605093668065, 0.055144901026881514, 0.05092494783081836, 0.052972819596048326, 0.03631596904127829, 0.021439493415997397, 0.09367749185091065, 0.012773781650579505, 0.14192831402103748, 0.07942706136213196, 0.1859723328943214, 0.10564547062160508, 0.118590870331372, 0.1621010638172588, 0.11395737138246337, 0.13729461588926856, 0.014353154260935563, 0.07875489581736826, 0.14342328863999537, 0.043499410798352574, 0.11296186310749863, 0.03683054646957786, 0.07135123825601994, 0.03499676180522769, 0.15397031220697588, 1.3784050869364894, 14.854161950849718, 35.122314576179754, 52.384140106939505, 55.77997915206417, 52.99187606380832, 39.297587410096206, 45.76884315859887, 76.49217251808413, 43.88914139040055, 36.05123381460867, 27.533330417448475, 52.76835587716872, 39.00742615422895, 13.757099528466503, 7.514822434994483, 1.0472338574547921, 0.8548518354373594, 0.28264020299238546, 0.8623833377515117, 2.5921314233733765, 4.982804521437615, 1.6883022386220194, 5.418933841489977, 11.250769707464404, 6.685153380517037, 14.232924215255247, 13.352678648887142, 9.138455698567054, 4.978110915230167, 14.398529625708058, 18.73534821694897, 11.814343698563116, 24.11368846893311, 28.584745276358824, 32.40529071900153, 36.03314384337395, 47.259190851642245, 56.01998113816785, 66.24501182186988, 66.6669019576042, 70.11341802535519, 70.72920660818778, 69.30844568437146, 69.11503361117455, 65.99802017211914, 64.84059149219145, 71.53337878565635, 68.38715937829787, 71.10479708640807, 68.34131471572384, 58.43457652676491, 56.67001593497492, 35.669567584991455, 37.709227531187, 56.30956972798994, 54.62767308758151, 62.77934282056747, 49.8666178026507, 70.5497189491026, 71.20535096814557, 67.99600493523383, 65.12461423873901, 53.364760106609715, 53.46539243575066, 46.25123585424116, 52.01246415415118, 52.67125368118287, 54.17525514479607, 53.18167563407652, 48.6349465001014, 43.40968262764716, 39.70672592040032, 38.412422210939475, 25.76653407466027, 19.057514052237234, 17.874927290024296, 8.180546712490822, 9.579530146814163, 6.956764767246862, 6.140204273885296, 7.830513908017067, 14.608104805792532, 13.17477954972175, 19.982644281079693, 8.859794832045033, 9.307023479092507, 6.6604429387277175, 9.127144563582636, 4.805481030095009, 2.3320368509138785, 1.7892408803586037, 0.2126567381163759, 0.2245983174971996, 0.9778629411612788, 2.4186418037260733, 11.235073362627338, 26.22105440785808, 25.920012497132827, 38.10589290434314, 46.44265144102035, 38.00155393538937, 27.534271786289832, 25.896131146338682, 41.33482333152525, 44.673913524996856, 48.089164380104314, 48.89798456622709, 39.017816512815415, 17.035255701311176, 1.7695910315359793, 0.11952529841613387, 0.1192471472125861, 0.05581109108583582, 0.04512928200945739, 0.07103284445380972, 0.07980259766261424, 0.041947921873220516, 0.11884704247237214, 0.152574346791352, 0.06184674927123612, 0.0928353620392661, 0.0878801980927106, 0.02909967168835142, 0.07717470157771342, 0.1259584757950037, 0.12220616182011944, 0.06704313515294945, 0.030497188432021972, 0.09685444315114329, 0.0695272135518251, 0.018601294704562715, 0.03439496909718841, 0.07236985940366022, 0.045796659504694325, 0.055285742461320855, 0.013470895806207292, 0.003195989782163393, 0.06599979234799262, 0.0758609297354856, 0.058592032385809775, 0.057165802666737195, 0.03580850090891604, 0.09641569693602862, 0.06772696821679992, 0.19190093412274317, 0.017159205050237717, 0.021672238588273045, 0.021181563103211024, 0.03966781438418454, 0.035999957772512595, 0.011925910009942468, 0.07623432098977989, 0.012994436997800105, 0.033226719486617276, 0.027936152670712724, 0.04692845099094895, 0.019208679854449247, 0.011028108588840452, 0.04083075883588003, 0.054756597871141094, 0.05670718030042707, 0.0206609986977832, 0.08583619124105862, 0.05939408430769559, 0.09231800754224101, 0.08640686545761363, 0.09635876894237534, 0.036543857216114, 0.05643807276482544, 0.021214640864561644, 0.07298012504414206, 0.027543840959908503, 0.02160543380605598, 0.06805594169324444, 0.06919345202585382, 1.9637381814179884, 15.649353861808779, 40.31514436967912, 60.050008604603434, 65.58834429710143, 61.06956597297423, 48.35994912732033, 49.25253152847291, 74.78778500710764, 44.81653482683244, 32.04089664643811, 34.046902656555176, 44.64474285802534, 39.908633847390455, 18.680217342991984, 7.598892065786547, 1.5132265105362863, 0.39914149190149, 0.9628365861792719, 2.8595382744266145, 4.189425726090708, 8.125573713933269, 8.381533372786738, 13.614738083654835, 8.86302980684465, 9.133666484586655, 14.267004709089957, 12.240024805068972, 15.197709606539819, 13.382569070785278, 11.17609856590148, 13.936183183423935, 10.90368309328633, 18.31755695804473, 13.48725320831422, 24.1229982145371, 32.64849335916581, 47.64006868485482, 52.3770131603364, 63.077152698270744, 67.2771756879745, 70.90129667712797, 73.01172794834261, 70.71240317436957, 70.22319732173797, 68.31438372212072, 68.39763210665795, 72.96034489908527, 70.69157538875457, 72.03145703961773, 68.97753100241385, 62.922368126530806, 62.98267064555999, 46.483114611717966, 48.293241377799745, 62.64298946626725, 60.844143436801055, 66.89856498472153, 59.41106627064367, 71.0797409857473, 72.14696299645209, 68.54536425682807, 67.59010238032188, 57.10056666404971, 58.23531227727091, 52.19073195611277, 53.36268125041839, 52.64467570089525, 53.398578782235425, 51.96255199370846, 47.68401492026545, 44.254761203642815, 38.7987325268407, 33.57018563055223, 25.20878088089728, 18.698011175278697, 13.328200117234262, 8.503342578488013, 9.937973983826177, 8.366582278282412, 7.376323053913732, 13.516205203148628, 19.37593794638111, 15.334892542131486, 21.30284151723308, 12.513254169494877, 13.083328508561658, 9.566652024945906, 6.728548522918456, 8.399160504341125, 3.579063987539661, 3.2203566162816943, 1.0927201134543265, 0.3748699265622324, 1.0763513272808445, 2.6389294670474146, 10.63317193138984, 20.038394889523907, 29.21773933595227, 43.19209698707827, 39.05900924436508, 34.46551369082543, 27.629391224153583, 32.272157630612774, 44.6979223528216, 49.55425200923797, 54.70681867291851, 57.15399326816682, 44.323755694973855, 19.04930845383675, 2.2456302229435217, 0.2282720921380866, 0.16181543559557007, 0.07015804099219461, 0.07841554184954974, 0.062377525628694606, 0.04654531892869742, 0.010454252234569961, 0.03674677092461817, 0.08046602214416189, 0.06570747617872492, 0.0756929649580871, 0.05541000575307877, 0.09894877431854125, 0.07865151225198662, 0.006140284728439104, 0.07602370043675746, 0.018484391602537325, 0.06049655377864838, 0.09421048986334955, 0.013699848843257756, 0.07927955113231175, 0.11291690906810184, 0.02006702583223101, 0.08460714872325621, 0.006363879459264178, 0.00499845605396155, 0.053317524688017946, 0.06893249949620617, 0.07612895325667436, 0.02221880593307076, 0.02378350987489666, 0.12172793909426659, 0.030467427831383485, 0.14046577556479362, 0.34700246708047006, 0.1666680663343399, 0.1530603070052401, 0.17496205595952852, 0.20873196242797762, 0.16661489983239483, 0.0992341880356112, 0.18978267036859067, 0.16977533427698, 0.11033074179243658, 0.1335126083464392, 0.1245347167094869, 0.15692993968484864, 0.26527933295696016, 0.3490578196942807, 0.23824321676886853, 0.2765427559854523, 0.18992493289612955, 0.31633578361042086, 0.2999722068348239, 0.30176267688793523, 0.27771836387053617, 0.30304765148508933, 0.2511429576383483, 0.1926090138693971, 0.13873775699926963, 0.18406062176631344, 0.1578782186392815, 0.17020884811157183, 0.19220638869991227, 0.2981396325893941, 2.4982904330376656, 21.965551453251994, 48.47242309201149, 71.7297326364825, 72.24035463025494, 71.64154206552814, 53.26491225150324, 59.723592881233465, 85.76043513513382, 57.63988864037299, 49.24014076109856, 40.65506873592254, 66.62646232112762, 48.75227635906589, 19.534407584897934, 9.86471881789546, 1.4595655448013738, 1.1274690036812136, 1.101863403474131, 3.4120644196387264, 9.752887141320015, 11.51533357558712, 11.026792564699727, 17.92837546717736, 25.670983176077566, 19.889444843415294, 32.817310210197206, 23.673243561098655, 23.33448806116658, 17.798144932716124, 26.439436289571947, 30.616487918361543, 26.06730338065855, 32.936389446258545, 39.73067983504265, 39.20310535738545, 42.354404234117084, 60.66485189622449, 61.71818087177893, 72.843521025873, 70.63806641486384, 73.10812411769744, 76.03119204121252, 72.09610554479784, 69.38864246491464, 66.928053363677, 66.39229682184035, 69.69759971864762, 68.39866761238345, 73.54864551175025, 71.16729613273375, 67.92362151607391, 69.10939324286677, 46.84642807129891, 49.73741885154478, 67.34006697131743, 64.80974597315635, 70.85502055383498, 62.10325956344605, 76.29106475460914, 72.77919415504702, 68.39873037030621, 66.71887336238738, 56.530712958305116, 61.19896104258876, 57.787495274697584, 59.18774612488286, 58.316324910809925, 60.5458354180859, 56.61539300795525, 53.067922976709184, 50.84069136650332, 44.69218000288933, 39.99040349837273, 33.58447874746015, 29.99368613766086, 24.541905387755364, 12.52260902235585, 17.335354282009988, 13.411196489487926, 15.389131076874273, 14.202369932205448, 25.403018613015455, 19.13707148644232, 29.936496019363407, 24.366298913955692, 21.130116024324973, 19.493897345758256, 16.352374976681126, 12.483516720033462, 3.236911960186497, 4.6573105550581415, 1.0208136299925468, 0.4854525427424139, 1.2498984341659856, 3.6679860805311515, 14.61491600159676, 32.89499471264501, 34.106055921123875, 49.59876698832358, 59.41314904920517, 51.80485702330067, 39.757877549817486, 40.078817644426906, 54.86818498180759, 58.58808632819884, 65.39133148808634, 66.7141665181806, 51.87251398640295, 24.50110097085276, 3.216482540292125, 0.3024392244556258, 0.2392133139073849, 0.15435786076611088, 0.2511740761298326, 0.1801164487316724, 0.35640049665685625, 0.13173330785526385, 0.21961393495721204, 0.3071718092166609, 0.2713145429809248, 0.2698754927804393, 0.2738661979956012, 0.22192315378737068, 0.12569505646223986, 0.2710402222169984, 0.20087383086642913, 0.26152654400756287, 0.17907139755064444, 0.24317643995727264, 0.15741531767191427, 0.17739553425100543, 0.12011183065272148, 0.15578014896281306, 0.1646929997349939, 0.1602279328771176, 0.1431141568407897, 0.11814047957980826, 0.1838897688374404, 0.21627714707245752, 0.19102105149819007, 0.18829806858012754, 0.2738792521338309, 0.31508191218299253], [0.12594099366857162, 0.12892309816614275, 0.015447310720300002, 0.04523526261290235, 0.058066768030966484, 0.025631101358862176, 0.019084372512635686, 0.03467573649099758, 0.04391030588698003, 0.01711670632263826, 0.04549953230326215, 0.10208480886273807, 0.025354436365887526, 0.053463805346719684, 0.054659649444323395, 0.03853574327583756, 0.16848459869863527, 0.07237551313254141, 0.07840075635261114, 0.02909272710131782, 0.0623885304817269, 0.07870994177797148, 0.07935107310092257, 0.08960433259245851, 0.059519492900900306, 0.08477516712680941, 0.12245956838371293, 0.08685673526938885, 0.07145709628539701, 0.042194019958016374, 0.03668299410492182, 0.591938549712781, 4.593410732284669, 20.072376343511767, 31.56335984506915, 44.069617486769154, 52.12114126451554, 47.72689034861904, 43.74520217218707, 49.68154076606997, 33.47272257651053, 27.501265041289795, 33.61336308140909, 38.35821897752824, 54.428012678700114, 21.071917856893233, 13.088892390651088, 4.218907240898379, 0.8207272762252439, 0.0691415112645876, 0.9513990160438323, 1.4533071580433077, 2.0413368820182742, 6.997289715274689, 5.968485359222659, 13.409477510759908, 6.7046245163486855, 3.940207886119043, 7.638280016760673, 4.230292410619797, 15.691376174649886, 17.264288779227964, 8.01536197623899, 11.661217308813526, 8.088193035894825, 21.986098789399673, 25.10914679496519, 32.24137486950044, 46.9377016252087, 55.114035221838186, 59.06991028016614, 68.2924262938961, 68.73425775958647, 70.74310748807846, 70.9727701064079, 75.95164637411796, 69.92803112153085, 68.96728577152376, 67.88479005136799, 64.77878278301608, 70.9516049969581, 67.20523941901423, 68.15122096769272, 61.31941703058059, 54.706218550282145, 39.19489975898497, 33.27421534445978, 54.93251577500374, 50.61727708385837, 61.68930046020016, 51.88983125071372, 76.08816839033558, 71.87889252939533, 69.12284697255781, 61.52267033053983, 55.66674032518941, 60.68036879262617, 56.84168631030668, 56.449111969240256, 57.825789374689904, 60.456613263776234, 57.2903113211355, 55.35911667731501, 51.33851074403333, 51.339052031117106, 45.42256063030612, 39.87976520292221, 29.171374959330407, 25.691204955500943, 20.61387131291051, 15.45441108365213, 16.762496040713405, 9.212136441661466, 15.424812878331831, 24.465883970260624, 13.068194043251777, 14.669351635440705, 11.00467529989058, 14.91638348948571, 4.315830478745123, 3.4333861787473006, 6.057340281624948, 4.833235231138045, 1.8124219655029237, 1.0573698748503964, 0.41432982851420685, 0.6525435815415075, 2.165053217641769, 6.169454368852801, 16.929334055992864, 15.715608577574454, 34.63263019438713, 52.97586102639475, 52.5044588119753, 41.79981639308315, 28.41213353218571, 36.33052226035826, 43.110374404538064, 54.260535317082564, 57.02592003730036, 39.867649001459924, 20.06385107194224, 4.189414449276463, 0.16308718751515114, 0.0849959460057078, 0.10590394868725732, 0.09284858471683918, 0.04048303535748874, 0.07506333261487946, 0.06590007068288904, 0.04786023990281167, 0.024988811327925613, 0.016072808103936336, 0.08210715867819325, 0.050536587218483614, 0.1704398849077763, 0.058594568136839144, 0.09782273232215837, 0.17074915460280835, 0.13368819569868426, 0.11000078772344898, 0.026519048974038135, 0.08989322434870467, 0.04544971743598581, 0.053760028564401215, 0.01772985245371538, 0.011399186257603429, 0.029717981252038193, 0.05913536492434721, 0.023932877867933244, 0.09462242300111441, 0.006584984883140292, 0.05925450691833131, 0.07879121604585841, 0.09873628451098358, 0.04671109652507209, 0.17445294456856866, 0.06836089831326278, 0.021322559670455033, 0.014817473448572621, 0.0418337173159084, 0.021535032241034414, 0.06433513691468586, 0.04737942013889552, 0.06817112301266001, 0.03657015701455455, 0.053454087521400184, 0.05234217218634102, 0.011082338037780456, 0.04520191480555842, 0.09272329869770235, 0.08090509011620477, 0.029827713771092317, 0.04173638584512857, 0.05028763545616981, 0.046134079100504044, 0.04979664204461921, 0.028246573412850983, 0.15267902504532568, 0.11900265791243124, 0.04242481160608511, 0.06287505377023932, 0.05783868833414971, 0.05785376877493917, 0.09478944549036604, 0.009073283947673778, 0.07830519454493638, 0.6161719945169265, 4.878852886538352, 25.1838699079329, 39.715872887642156, 54.666696748425885, 60.13757551870039, 58.26946435436126, 46.189466368767526, 48.925872618152255, 45.44949554627942, 33.876271709319084, 30.785928426250337, 36.673466851634366, 57.037800896552305, 26.311637624617546, 10.911104217652353, 4.214795616365248, 0.6791568631606718, 0.6133950790089946, 2.3735759767793843, 4.785956942266034, 7.231340975530687, 11.888398047416441, 10.703840294191915, 11.573237565255935, 11.51573169615961, 8.88803981965588, 11.721933637895892, 14.572181778569377, 9.954342034555252, 15.00613026080593, 13.026394324917948, 14.664195679849195, 14.604561924934389, 18.122628888776227, 27.07273433285375, 31.794526692359682, 43.31905626481579, 51.040555738633685, 61.119960584948146, 69.50214801296111, 70.96272883876678, 73.40373746810421, 74.5991974492227, 77.06545045298915, 71.29223931220271, 70.87242018791937, 68.31861203716647, 69.59247235328921, 73.60519824489471, 68.71146878888531, 67.44994824932468, 63.47788556929558, 62.739985758258456, 48.104975454268924, 43.30042892886747, 62.090613842010505, 56.28438026674333, 65.80604368640532, 60.59309997866231, 76.5302901114187, 72.98535393130395, 70.59189227319533, 63.599106419471006, 58.44429223768173, 61.85757406296269, 60.2484844576928, 59.51638583214053, 61.35193740167926, 61.535104243986076, 58.38628430520335, 56.89442257727347, 54.50546772249284, 52.242138539591146, 48.479153879227184, 40.78979822897142, 30.815720788894165, 23.612034974559663, 19.392417784660093, 13.67385212452181, 9.367881994093619, 4.446643975473219, 11.204386699584223, 14.168186476153714, 12.909464547711035, 19.531860005471017, 6.040454968329399, 14.92101384747413, 14.90251693033403, 12.15513785039225, 10.376074294890127, 5.911495772100264, 5.7396640892951725, 5.568053039812273, 1.5408403642715947, 0.9534462481256455, 1.7370074122182786, 6.109143024490726, 16.341945394392937, 22.26357117775948, 40.46811288402927, 49.18727113354591, 47.152294497336115, 41.853788206654215, 32.208177889547045, 44.150124134555945, 48.387033093360166, 58.88131095517067, 63.31562103763704, 48.13178093202653, 25.28514942815227, 5.597385504553396, 0.2990123293092174, 0.09035136791006212, 0.08215705398470163, 0.05768213443638337, 0.03943094765887626, 0.04285575138525136, 0.07336495399114586, 0.01918676016371577, 0.04640561896526525, 0.06537368400923668, 0.057837696250287764, 0.0389272716617392, 0.041313708324225686, 0.054369451508166335, 0.15086180320189846, 0.07663815657818511, 0.04018518803340774, 0.022524329458153056, 0.0307336165719936, 0.028511804543555747, 0.048428485620646715, 0.050961218263593414, 0.007999208089219587, 0.05235716452701919, 0.021272873122906013, 0.03795709408399078, 0.06588470295912797, 0.07036639392496118, 0.05702480801471299, 0.07993899961753238, 0.01914652331071275, 0.11589335217591255, 0.011888707822729504, 0.275807372865177, 0.22028285228917677, 0.16476778523816218, 0.17800282747034105, 0.20367815700029174, 0.12882951286531266, 0.2205762639641762, 0.2128206043233795, 0.1833241201576687, 0.1195852447962088, 0.17252709145747847, 0.2656198437175443, 0.080958609018595, 0.12868758741646044, 0.19201995354265938, 0.2080554608255625, 0.3512072785487098, 0.1997812669123373, 0.2748563819594922, 0.1271123344439172, 0.26613609504795843, 0.13131520770970853, 0.596822390873586, 0.23814310439892356, 0.31443361793794944, 0.1431029872788537, 0.18032272556616416, 0.13883704199425637, 0.1268158124519452, 0.1258316576000183, 0.1661035361429376, 1.0800579670936832, 8.705998697588521, 30.569054695867724, 48.842031955719, 62.53090773859332, 68.76486793641122, 66.44058119866156, 58.35186550694128, 62.80056284319971, 44.1708303266956, 38.83961539114676, 45.10297375340616, 51.619172019343225, 69.19552849185082, 29.277118136805875, 18.040368941522416, 6.0709759112327335, 1.613061617939703, 0.8099323006406908, 3.345748171690972, 5.343711116621572, 6.143647624600319, 21.738724708557132, 16.245206998240565, 22.287948708380423, 19.444265634782855, 12.230566989990974, 22.592132437613703, 16.419220009157737, 28.218350795007524, 30.33130611142805, 16.588582069643085, 24.963005165899954, 18.287407659715225, 28.528255301137126, 33.181341463519686, 35.646527582599276, 50.195288888869754, 55.90107056402392, 62.92366250868767, 71.89691189796694, 73.94821736120409, 75.88610356853854, 75.23586088611235, 78.05287576490834, 71.12374213434035, 68.44830128454393, 67.08656418708064, 66.2234466306625, 71.32763478063768, 69.13574372568439, 67.70728711158999, 68.07580163401943, 66.46125208946967, 49.52449690911078, 44.65219536135274, 66.61061594563147, 60.997394361803615, 69.18962140237132, 64.5322657400562, 79.78069551529424, 74.57108189982753, 70.16533451695597, 64.83522176742554, 57.70984019002607, 61.342864959470695, 60.22346365836359, 60.8107287653031, 63.66618287178778, 66.78949955971011, 61.718275008663056, 60.497723625552275, 56.60074687773182, 58.07371062617148, 56.482259919566495, 45.987119136318086, 36.61618063526769, 30.656215644651848, 27.592760209114324, 20.96587069572941, 25.496196477643906, 17.131534199560843, 27.79830809562437, 41.65568497873122, 26.704888574538696, 29.171508319916267, 21.222344675371726, 24.62416337382409, 14.717076093919816, 16.27215760369455, 18.482882899622766, 9.754587488789713, 6.091813993069434, 3.7251097636838115, 1.638114409100625, 1.706379462153681, 2.5345279853190146, 8.233540385000168, 20.873879348078084, 23.214487068114742, 45.782112536891816, 70.79202728886759, 66.0132154341667, 53.395174164925855, 40.136299979302194, 48.93888312001383, 57.63299703598023, 69.7458605612478, 72.52266330103721, 58.76214150459536, 31.6273513532454, 8.346108486575465, 0.32712003396403405, 0.19486563310267466, 0.16066634967442484, 0.22399615706695666, 0.0831295643001795, 0.18806519317290477, 0.22791374685062518, 0.2178426171022077, 0.23154785345879295, 0.27530472725629807, 0.2295427408910567, 0.17148675937806407, 0.26972163168172686, 0.16217811694068296, 0.2968876917035349, 0.3280085120950976, 0.20367815700029174, 0.3192171322241906, 0.1862420571307021, 0.2469937028663774, 0.11780046677637486, 0.3168384292192998, 0.24144929473198232, 0.14563536752135525, 0.1234451098547828, 0.09181289513024593, 0.13991443740744747, 0.10648861166930969, 0.19531934101495052, 0.15970425049383796, 0.11332626048956188, 0.2587901392290669, 0.2350808211391972], [0.03182999564394836, 0.044401180554902366, 0.06942561497130702, 0.010708680567932467, 0.035806256271297895, 0.08722432723809635, 0.08365022829703747, 0.005373785989509235, 0.01727786249360971, 0.07395518643240775, 0.03065356038390629, 0.02432842821543736, 0.019030754018815297, 0.13987127601379348, 0.010604150743494111, 0.09875512261304165, 0.02880544221449283, 0.09048911051884775, 0.0360827335727311, 0.08858712870747813, 0.1298742422894124, 0.09734891460187013, 0.013539938522773165, 0.0776668900864259, 0.0536432997473786, 0.02293312546586798, 0.04976964510616757, 0.04509704502960367, 0.047851786122567234, 0.027619976693043308, 0.05232727560665339, 0.5744705805855413, 4.0425334534337445, 13.711203875080233, 35.238212770031346, 52.9257841264048, 50.769072809527, 49.410155896217596, 44.85027897742487, 34.083255183312204, 28.30132265244761, 23.67214725863549, 24.694738580334572, 37.27133804751981, 26.630928362569502, 23.367588943050755, 11.00874868131453, 0.891472063958645, 0.2351179917252833, 0.3685315602248715, 1.2905175190779472, 4.560180412184808, 6.835340934415018, 7.265134646046547, 9.539475883207015, 11.793252133554029, 5.706089090916419, 10.093651875372856, 9.239065474079503, 16.98403935278616, 7.075185045119255, 9.640826006089489, 10.914766730800753, 13.664726730315918, 21.975724120293897, 27.23894084653547, 33.317031937260786, 42.08216428756714, 55.02129862385412, 64.18313164864817, 71.04510645712577, 71.42731005145659, 70.05561797849595, 67.81518367029005, 68.68259229967671, 68.7823381731587, 70.12264344000047, 66.6780807125953, 66.21156969378072, 63.150038180812714, 66.12263387249362, 67.5491528357229, 67.23227239424183, 68.14359588007774, 52.94470564011605, 39.88209116843439, 30.450100975651896, 47.941032148176625, 48.549430985604566, 55.950696391444055, 50.181564515636815, 66.6879258617278, 69.52176770856305, 69.75670199240409, 65.55168974784114, 62.75199997809626, 61.225040881864494, 62.75697354347476, 69.49294613253686, 67.77614824233517, 65.98885751539662, 63.78079060585269, 61.91523682686591, 61.20769223859234, 59.21253942674207, 58.89069326462285, 50.38993258630076, 39.39868650128765, 30.380818190113192, 24.862786646812197, 23.43212369949587, 10.797095625631272, 4.673204489292638, 13.291170981622512, 11.190278914666946, 9.271965334492346, 21.37176344471593, 5.011602563242759, 11.053563721718328, 12.939322610055248, 8.24048690257534, 7.693930604765493, 5.254558584382457, 4.82133525033151, 7.0279758880215315, 0.5119411665345392, 0.6319335487581069, 0.40433590510679834, 3.8094549409804808, 9.391482895420445, 17.262321710586548, 25.761882143635905, 49.82175765498992, 33.51651191711426, 22.23943683408922, 25.606399390005297, 23.699056679202666, 36.74914113936886, 42.12118402604134, 51.68162399722684, 48.76947987464167, 30.07469681001479, 9.13394791464652, 0.3956783148309877, 0.09345277528008146, 0.03289877256799129, 0.04790788291082267, 0.07930283254433064, 0.037327431097266175, 0.03847891870405405, 0.07399195865277322, 0.08972509869284208, 0.04439361160621048, 0.0383410650125194, 0.06832523692038751, 0.05517894597423654, 0.02392825644253002, 0.1010640579906683, 0.07254148608133679, 0.1126446644024503, 0.05307699989287123, 0.06821328849201241, 0.01765995459150403, 0.012184951150219047, 0.07684403504695624, 0.0350596001672168, 0.01249332164954995, 0.04084850909308561, 0.03373006223550728, 0.06861617413139151, 0.05136391621143107, 0.04694802836785394, 0.03333244728104722, 0.03845611609698784, 0.013921739507256257, 0.06979475443762156, 0.05903339862162548, 0.14032340578494534, 0.06855942999884006, 0.028840712902526704, 0.0756093847655481, 0.03788281419885255, 0.031717430514794205, 0.053765157523054274, 0.06425608047133972, 0.0914641795679927, 0.049114291360902215, 0.049730065173559615, 0.04928265833446095, 0.024772948818281296, 0.08822158219352846, 0.04240837902010929, 0.0495550447263785, 0.05228864562307155, 0.01627589801266309, 0.03435161235111375, 0.05401976684468889, 0.1190880767159885, 0.057346959478191795, 0.06777161582102699, 0.017054032669552875, 0.04140691824197289, 0.026593485907200846, 0.00919176423321328, 0.020268619954285604, 0.1316381750568267, 0.0477935787620804, 0.8294087071572581, 6.230313374150184, 19.473954054617113, 40.42388031559606, 58.830543718030384, 58.52089220477689, 54.848988902184274, 46.73009841672836, 42.3995703266513, 31.501466804935088, 35.15416814434913, 32.558333758384954, 39.383467705019065, 36.81522915440221, 23.36319196608759, 11.91178321838379, 1.5552045741388876, 0.4609454206881985, 1.14472130373601, 4.456491576087091, 6.680063124625914, 7.298221309338847, 13.10950150412898, 10.240513259364713, 9.999129618367842, 14.766003739449287, 11.984047985845997, 11.489752857915818, 12.990350684811993, 13.446597841478164, 12.995721390170436, 14.215896225744679, 12.186576627915906, 19.17336517764676, 26.118339300155643, 30.764367157413115, 40.64498039983934, 52.7798641112543, 62.7944988589133, 69.1750301853303, 73.3428152145878, 72.80843934705182, 69.57882250508955, 70.37773870652723, 71.9077297949022, 70.00419570553687, 66.47533339838829, 67.563108628796, 66.02699864295222, 69.67854484435051, 67.43789088341498, 68.88155060429727, 66.7116169775686, 59.28165551154845, 49.74998220320671, 41.63191149311681, 55.25661729997205, 55.01268902132588, 61.185464166825824, 58.32601708750571, 71.4853140615648, 70.66575050354004, 70.61834473763743, 67.75459874060847, 64.78365044439992, 63.638400723857266, 62.06442417636995, 68.81279145517658, 66.55802480636105, 66.06016620512932, 64.9070050639491, 63.01821908643169, 64.05421510819467, 61.257278842310754, 59.23586183978666, 50.95918224703882, 42.01177343245476, 32.16093686319167, 26.403983946769472, 23.11796538291439, 13.7251429980801, 6.589734861927648, 7.249111273596364, 8.923296043949744, 11.703353370389632, 14.051852899212992, 9.368906713301136, 15.333760938336773, 13.835910731746306, 13.206403659236047, 12.789608682355574, 9.571837398313708, 6.762414266986232, 7.342097432382646, 1.7241915579765075, 1.0815218691864321, 1.0453003741079763, 3.6342735540482307, 10.61989470835655, 21.12236345967939, 27.96717985983818, 49.135797869774606, 50.2039808611716, 31.041135480326993, 30.234323547732448, 29.715950950499508, 42.99683747753021, 50.142019179559526, 57.819313541535415, 56.49706294459682, 34.688680864149525, 11.715258744455154, 0.6005408590839756, 0.13639536656198964, 0.03979817956625935, 0.02827923174106306, 0.08854402093997887, 0.04695036110558337, 0.06281907572561214, 0.05052519932148918, 0.05503742655198421, 0.03699469229867382, 0.05312225270655848, 0.02371061086324194, 0.029725035006601005, 0.08769665874781148, 0.060565145460948835, 0.07783804945046864, 0.04829862605660193, 0.02366966346368915, 0.034137008140885064, 0.020018321792444876, 0.0448454502639511, 0.03302971614644893, 0.06480585963975999, 0.09040062736359336, 0.052242209203541286, 0.026440793092572884, 0.04733630471051701, 0.02134352558172278, 0.09687906521702967, 0.07980318755031594, 0.03921100381581534, 0.030521787515270616, 0.09160224393370653, 0.18878166924320883, 0.35087124174160345, 0.19528480577132395, 0.13012741902662864, 0.12672844012418102, 0.20082565925775037, 0.18888288477976478, 0.1531266348977243, 0.1250622754976634, 0.18704844127979972, 0.09921184125085993, 0.15231458169798698, 0.16222124769081994, 0.2856256169897895, 0.24081747137731124, 0.23002798098229596, 0.08738418680525596, 0.1503649492177271, 0.18275335401056275, 0.21234809661344176, 0.23286531018393658, 0.22895562642764664, 0.09618550283654083, 0.11465817329383667, 0.2882642995926642, 0.25287436231249766, 0.16294898525361093, 0.1671267384963651, 0.1044479143174906, 0.2990802046993087, 0.13309976356404443, 1.343585103750229, 8.676248500424048, 24.481579334505145, 50.779463168113466, 71.26783432499056, 67.9410211501583, 64.9763447238553, 57.384507040823664, 47.25335436482584, 40.81832562723468, 37.42018415081886, 35.66027156768307, 53.53923497661468, 38.520534499999016, 31.06259868990991, 15.250680235124404, 1.5825860274414865, 0.6794009081298306, 0.8758564341452815, 4.561163456209244, 11.319973065007119, 13.248734858728225, 19.671580714564172, 21.35441872381395, 24.74285625642346, 19.81953251746393, 20.701236224943592, 20.69087136176325, 24.774894175990937, 18.040017889391994, 21.512011712597264, 19.049832090254753, 19.972157824424006, 31.24570081310888, 37.83644960772607, 35.79662099961312, 47.38906052804763, 55.45675623801447, 64.00800174282443, 69.30705716533046, 76.07866840977823, 75.48154246422553, 73.41727748993905, 72.67455316358998, 73.81451160677018, 70.77686340578141, 65.6760367270439, 65.69540539095479, 64.22042946661672, 67.20524726375457, 67.07220046750962, 69.48534457914292, 70.86161013572448, 64.29671172172793, 50.50790179160334, 41.28682921009679, 59.009733276982466, 59.36134630633939, 64.91527342027234, 63.57852574317687, 76.63867304402014, 70.8083600382651, 71.06701681690832, 65.95788648051601, 66.73859503961378, 64.91430851720995, 66.04470422191005, 71.05796398655062, 71.34283004268524, 68.10712568221554, 68.82364857581355, 66.27175454170474, 69.52128917940202, 63.720731273774184, 62.73168994534401, 53.02811484183035, 47.051207173255186, 36.699464321136475, 34.841825885157434, 33.40701895375406, 16.954570585681548, 9.92688250157141, 23.25558566278027, 18.373133021016276, 22.354124976742654, 39.679810616277884, 21.9002341839575, 25.149421691894535, 23.440927459347634, 18.05796665530051, 18.363421232469623, 10.628169928827594, 11.17525133394426, 11.048543087897762, 2.5645358331741828, 1.4181143045425417, 1.7641216540528883, 4.532584576837478, 12.339577501819981, 23.903123870972667, 36.41713996087351, 66.56600290729155, 47.59135284731465, 33.604121977283114, 37.999314262020974, 35.88468997709213, 50.09762187157908, 55.83413923940351, 67.18963623046875, 68.12289361030825, 41.24016084978658, 14.816138494399288, 1.2280997393592712, 0.19263879936789313, 0.0904240083670424, 0.2106649708002806, 0.18647430434582696, 0.20703595101593003, 0.1894795293769529, 0.16767121250590972, 0.17923419123455403, 0.15006703294573293, 0.15204617513283608, 0.1710787409495923, 0.2678354006380804, 0.16066817296368463, 0.16443378622493438, 0.18412408448996084, 0.18052765408590918, 0.09055795884060283, 0.15981755489783903, 0.18910397775471213, 0.13277108120101114, 0.13825038718360086, 0.12254304132394253, 0.12222847796135372, 0.10628428069814559, 0.15071612392221728, 0.1469968589803865, 0.08715298913058736, 0.1910178339289081, 0.21127943460258747, 0.13322658175902982, 0.09137152889443022, 0.17765840966134303], [0.06422210064145827, 0.04978672120599978, 0.011648648425996786, 0.04189268310344027, 0.08251460254072182, 0.03055104249787908, 0.04237973882306007, 0.0240329155443056, 0.06560303541200777, 0.039836330744888515, 0.07579513810454838, 0.061323901923793944, 0.03840297257768051, 0.04017348987080398, 0.06115867974116437, 0.034169532403710394, 0.020476708586718288, 0.13516646960089285, 0.04915971654437242, 0.13264973287380513, 0.09711636095157555, 0.07089781379627605, 0.040748829562817855, 0.08340451325620375, 0.061314341146498925, 0.03941150817779764, 0.056223334489210006, 0.10821918130762155, 0.030920672260465163, 0.04399497392437151, 0.02411987993025011, 1.1830032688956107, 6.223459032274062, 22.308888281545332, 41.469556746944306, 61.66447577937957, 54.768242989816976, 52.27217212800057, 41.1429762840271, 29.659158952774543, 25.3398351130947, 17.30750741497163, 28.198325134092762, 41.033283279788115, 28.413928016539547, 14.240615983163158, 4.697991417300317, 0.65943383761952, 0.2890838298105425, 0.44687373383391293, 4.531663310143256, 7.016239175873419, 10.739506406168784, 9.942527855596236, 7.540290384523331, 6.697302431829515, 13.410374752936827, 9.986743753956212, 9.572718951009936, 14.106810208289856, 7.529924050454171, 12.058656369486163, 22.205294562924294, 20.94625492249766, 28.32440187854152, 31.218483486483176, 47.0286770789854, 51.47901004360568, 63.61538033331595, 64.04201653695876, 70.85284756075951, 70.67644288462978, 68.34335434821345, 64.00294188530215, 64.91757977393367, 68.45802091783094, 69.6521786720522, 68.15309586063509, 67.2285775215395, 64.06011043056365, 62.74778735253119, 67.6149937414354, 67.16604709625244, 57.47298786717077, 54.75260057756978, 43.708269134644546, 33.073986191903394, 44.192022892736624, 46.618055912756155, 51.17288866350728, 52.34258651733399, 67.2729552176691, 62.75509865053239, 67.46297836303711, 60.804617712574625, 61.38937642497402, 65.75046762343376, 66.8411728643602, 68.82534303972798, 68.83106970017957, 70.92477598497945, 70.44066921357187, 68.31552120947069, 62.714333457331506, 63.033583010396654, 59.962127900892696, 54.75039228316277, 51.77257983915268, 44.7697566401574, 35.30767402341289, 28.91137476890318, 21.17920448703151, 10.65933512103173, 7.259855626090881, 6.2049876105400825, 10.039185843160077, 9.598243774906281, 4.507938363859731, 12.05134311029988, 17.58783725000197, 14.805956021431955, 10.874355531507923, 8.603906266150936, 7.368589120526468, 12.704432452878645, 3.1911913425691667, 0.9158770511707953, 0.5629714782680235, 1.5275903526813754, 7.097401349775254, 17.707446006036577, 47.98789662699546, 38.7354568512209, 16.842169184838575, 22.623632992467574, 23.982897035537228, 33.48046925760085, 37.52957905492475, 41.65765008618755, 48.986469314944365, 56.050497178108465, 36.604417447120916, 8.531572857210714, 1.4948494708345783, 0.12006854668499962, 0.028940492024224614, 0.05088072157494965, 0.007446914237187876, 0.029822653760352445, 0.04460249313964479, 0.06909810472279787, 0.06312805813767257, 0.021060592074307705, 0.02199436706911412, 0.0646523739241304, 0.00441779540250859, 0.010536356750244816, 0.05772018219314276, 0.021118092718684388, 0.017467452017890833, 0.06741115613089455, 0.028240684111933076, 0.06885320173516389, 0.052297225807823484, 0.036075785155257875, 0.03225981310430554, 0.013054996248214476, 0.06446377073805179, 0.010749088833108546, 0.050668277732667424, 0.07765217353740046, 0.012816282293398776, 0.020339630559206973, 0.05847018227101334, 0.016238489939320474, 0.03421865779185488, 0.038394143414353175, 0.074583639000212, 0.08004547817812813, 0.04650975712725232, 0.05342027240042245, 0.09034408241390221, 0.037254162448187994, 0.0742953141490298, 0.035905185035399856, 0.08014265643132311, 0.04795888904482127, 0.019389401911006823, 0.026670343678204284, 0.03856478949948665, 0.06176282816957082, 0.05095780534189075, 0.02975211812994413, 0.06229592577343988, 0.0765486162215952, 0.07161619742551158, 0.006286241714992831, 0.09229267301458506, 0.020979607004612204, 0.050188044026013345, 0.10049892258980583, 0.04855595115992812, 0.03295458590371474, 0.14102233844178338, 0.013100914600785944, 0.030331244211523768, 0.1027968722665983, 1.417525090998219, 7.481971113912522, 24.552297707526918, 48.10685819195163, 69.81356067042198, 60.49068689346314, 58.18827913653467, 48.51099175791587, 36.661115307961744, 33.97998702141547, 23.747511679126372, 30.7361457040233, 37.732408738905384, 31.161216881967363, 16.67231878926677, 6.367083480281215, 1.1973206554689717, 0.771116893137655, 2.4025262555768414, 4.093467146158218, 5.485163552145805, 10.395227228441547, 10.580679831966277, 8.990075376725967, 11.11829165489443, 14.375795568189314, 14.07297388199837, 15.422330998605299, 16.456115784183627, 10.82795879533214, 9.219956667192521, 15.586504743945216, 17.304948068434193, 24.637560229147635, 31.125311505409982, 45.19008175019295, 52.41691935446955, 63.61405064982753, 65.53509812201223, 70.87300069870489, 72.23550658072196, 71.02332945792907, 66.82739750031503, 67.2561360943702, 69.23807836348011, 73.13854602075392, 69.70299690000473, 67.33299886026691, 66.80932321856099, 65.0407971105268, 68.29030821400305, 67.75585389906361, 58.71605757744082, 59.10253655525946, 51.98374848211966, 42.551887727552845, 51.05222478989632, 52.03347629116428, 57.83492457482123, 60.352976399083296, 69.84134674072266, 66.32076063463765, 67.84249905617007, 61.78225278854371, 64.24978056261617, 67.28024298144926, 68.43033682915473, 70.74935974613314, 70.20951609457694, 69.96508183017855, 68.88242137047553, 67.6316559699274, 65.83723437401557, 64.85028366888723, 63.346482246152824, 57.85800772328531, 53.398221846549745, 43.50446670286117, 34.60751525817379, 26.222962640946914, 18.567641396676343, 9.31094486867228, 7.699313077234454, 8.686822229816068, 10.529355618261523, 18.57700409427766, 14.673778030180163, 14.211267828941347, 15.012298187901898, 13.513525243728393, 14.997300024955505, 8.59795210822936, 6.7215108102367775, 6.809082627296449, 1.6678653417095062, 0.4767110505171361, 0.8963901645714237, 1.8321373914518666, 7.64841296980458, 16.329507558576523, 40.689930762014086, 43.93801804511778, 19.239855235622777, 26.0180756738109, 30.409716252357732, 39.34258484071301, 42.347057634784335, 45.990649269473174, 55.784878192409394, 63.84308961129958, 43.56968395171627, 12.614036529294907, 2.2433763309832546, 0.03010635527091161, 0.07431507921747624, 0.06907028040938801, 0.009628744615662483, 0.002221775878663926, 0.03250977227223977, 0.039691245183348656, 0.017325545721236738, 0.01984969434899188, 0.037823875224398035, 0.06586449355968545, 0.08422903836734834, 0.010885426628163025, 0.016910329896716342, 0.044098893751300154, 0.16064473067320165, 0.014372611936602383, 0.04430778294561371, 0.07220532670016251, 0.06631440933673613, 0.0781388768565751, 0.0068575436448407995, 0.08493408440582215, 0.08614826481789352, 0.07859426250140514, 0.032041815124572284, 0.04197640502224526, 0.008144354458988435, 0.02900624918120523, 0.03401555639180926, 0.01545924062450086, 0.14724520936367974, 0.16690247391741123, 0.22527955352298676, 0.15730313175628263, 0.11822703985437272, 0.2344182776587625, 0.13377275648376635, 0.23940901872852158, 0.25692496028157974, 0.0647975552466608, 0.24003413115297598, 0.16671826041513876, 0.11824235395197907, 0.09020296901824976, 0.17135850093778104, 0.18665928393602374, 0.13812914610870425, 0.18828294600450224, 0.18820993782531834, 0.16399232039768852, 0.27998892590403557, 0.30235431127009854, 0.21597380689795942, 0.23029732217471446, 0.1673090061353099, 0.2389324201090682, 0.1570349703392675, 0.22757797051341305, 0.3310136605174311, 0.17097435380902984, 0.11237398255616428, 0.30515788663779536, 2.6072671144239368, 10.995330252955037, 32.67810137041154, 56.569469897977775, 77.65011110613423, 70.0339194267027, 67.7243023533975, 53.481427085015085, 41.98305383805306, 34.985749413890225, 25.98815779532156, 40.79270470526911, 55.73844517430952, 37.853864931291156, 19.900821678100094, 6.849394296446155, 1.6007990630403643, 1.0561342056720489, 3.8817175021094665, 10.92475308525947, 11.108809325002856, 19.113766724063506, 22.201587923111457, 17.021829428211337, 19.482342043230613, 24.528722301606212, 20.398552802301225, 20.747488814015544, 29.569213121168076, 13.832624766134447, 22.754559747634396, 30.758605195629983, 28.36388053432588, 36.10019283909952, 35.700032634119836, 49.578629539858916, 54.06807245746736, 66.70272104201779, 64.78567830977902, 72.49489292021721, 74.64439884308847, 73.14758316163095, 69.56872632426601, 69.9286194770567, 72.15559221083119, 73.68030378895422, 71.52176856994629, 67.42963821657243, 64.16046427142236, 64.19639318220078, 66.31595965354674, 68.72154928022816, 62.48474928640551, 63.160981593593476, 52.81867596410936, 43.42796871739049, 57.54464564784881, 57.83561491197156, 61.2224325056999, 64.3866281355581, 75.78031724499118, 69.2608202657392, 71.31032928343743, 63.821532264832534, 66.38465604474469, 68.65771662804389, 70.35941339308216, 72.97845840454102, 73.13356461063509, 72.72969384347239, 71.97984649289039, 70.1449695710213, 68.7657779262912, 72.20622216501545, 71.92980489423199, 65.9182156285932, 65.06617092317151, 51.79707111850862, 43.49607283069242, 36.374362591774236, 29.11099595408286, 14.742157689986692, 12.315574557550493, 15.461107550128816, 16.557336468850416, 16.8239164352417, 13.633839045801471, 24.773001632382794, 35.74212358843896, 27.023365420679895, 25.250350159983483, 22.89204078335916, 15.10313439753748, 19.958729590139082, 7.3418429686177165, 1.6547622964266808, 1.2617748807514868, 2.449283359512206, 9.586498237425282, 23.72250460809277, 58.012462815930775, 46.560844221422755, 29.133873178112893, 36.07396787212741, 38.147234685959354, 48.3482486970963, 51.18226705058929, 56.584374904632575, 65.95579193484399, 71.27324719582835, 53.08454205912929, 17.463645204421013, 2.9092984430251585, 0.26662066098182435, 0.25740808597014797, 0.20350451551137433, 0.2288832617623191, 0.06308451753049608, 0.15478239605023017, 0.15168067458416187, 0.2620980149555591, 0.10993863501015211, 0.12723097081987128, 0.18643276705857248, 0.15344099141657352, 0.18790704198181632, 0.16531616629612061, 0.1815773324379998, 0.29460671087426527, 0.28277071373116586, 0.19197012718406417, 0.19398244097828868, 0.17848981424204766, 0.22983560098275063, 0.1764921480489354, 0.1034226511875468, 0.1955042899616303, 0.12196956322558465, 0.25547812662778363, 0.17754193365333543, 0.18127992178403562, 0.09270233853209404, 0.15837269775088758, 0.0759625359768829, 0.3399080638923953], [0.03370303465353866, 0.03963943082658995, 0.06261250394726954, 0.02629134849074387, 0.013758531178257639, 0.038984406499132034, 0.12199231603693579, 0.050057426034923524, 0.07896457408224383, 0.015330783958967416, 0.04309514620070977, 0.04627406634690781, 0.049455932101174715, 0.08033718913793564, 0.07831016645556496, 0.03059595440244002, 0.11403895974639924, 0.01630389852629554, 0.03200541637206991, 0.03245881976439588, 0.08259244473470796, 0.04136752600090639, 0.00879472959035587, 0.043498311462181236, 0.0562558702433542, 0.053848933068013964, 0.08010370852125269, 0.026281423821684816, 0.037172723471397356, 0.03677536515639194, 0.1897090799625843, 2.71001041416199, 11.426288908527745, 31.209077642809962, 49.53920579725697, 60.15379059699274, 56.53872636056716, 41.676595134119836, 28.91908418747687, 26.637551284605458, 26.234572856656968, 31.71639111734206, 33.46880412870838, 49.06734466552735, 24.848579822048066, 7.7374865643439765, 2.0567705506278626, 0.4344312708464361, 0.5033639235602272, 2.722769884332534, 3.3231202633150163, 4.726490378379822, 5.213655617929274, 8.749392859397396, 5.611306486591216, 7.473067333621364, 13.160973787307741, 11.31444840661941, 11.691740212901948, 9.32326405279098, 14.920300956695312, 9.412294991554754, 20.820380180112778, 23.77829444023871, 35.07148850348688, 41.39034055894421, 54.29983746620917, 60.646126501021854, 65.48864941443166, 65.84046640703755, 71.06816214899864, 70.21450534943612, 68.99060818456834, 63.314377646292414, 61.79099967402797, 66.12141009299987, 66.19717459524831, 68.10752576397311, 65.49686677994268, 68.14437250937185, 66.13849593747047, 66.02700648769256, 66.24334089217648, 54.92075650922714, 62.04517318356422, 48.61570727440619, 38.92951611549624, 42.50659611917312, 44.849969110181256, 50.814587993006555, 55.9274406586924, 61.31964060568041, 62.058685748807854, 61.51828904305736, 65.32243505600961, 63.39715534640897, 67.0342319242416, 64.07759635679184, 65.1819436011776, 65.92724492472988, 70.85407918499362, 64.71595817996611, 60.171951170890566, 54.9740497527584, 55.22998048413185, 54.71267869395595, 53.2476185214135, 44.731160517661806, 37.94856271436138, 31.780670919725974, 26.223241129229148, 22.939219051791778, 14.87600661093189, 9.671551892834326, 9.758033290986093, 8.480651667041164, 13.31802745019236, 9.17563388424535, 10.835125946229505, 10.012961856780514, 12.19495383001143, 11.652713610279946, 7.360864993064635, 4.852173905218802, 2.3945729146080637, 0.7007359665247702, 1.1973848842805432, 0.6099203493325942, 2.1082827929527532, 5.014082481784206, 22.13218746646758, 31.102606865667532, 22.902497822238555, 37.69864497646209, 20.718074960093347, 20.88543268942064, 21.57796440585967, 25.05108198811931, 40.032447384249785, 47.33902285175939, 53.32516770209036, 37.765564533971975, 12.959281590677078, 2.989134365512479, 0.311621094663297, 0.037679295280888196, 0.10036830459871601, 0.067520591790878, 0.03993291527994218, 0.046490371272328405, 0.011764775863998841, 0.06165197907736706, 0.12063449413906183, 0.017871205251844182, 0.06336906556821158, 0.024166120997359677, 0.08547465902783218, 0.07435282436950554, 0.06861466493818068, 0.04396572468742248, 0.047653078236767364, 0.05566489852724537, 0.020856506251279387, 0.05325881553994072, 0.04696575564242179, 0.05826168761198079, 0.026801281511002494, 0.07604991596552634, 0.11032809112821856, 0.03555224449824422, 0.03337299631487939, 0.0626278525188325, 0.10025681582309547, 0.10038361869632237, 0.08120554213922831, 0.02696330527654819, 0.08306245499801251, 0.04057649808425096, 0.04768645668762827, 0.022917579626664523, 0.06296589647630049, 0.06462605114305212, 0.032631247003953305, 0.012277314540809922, 0.02055784112833921, 0.009164457029152301, 0.01005991422120602, 0.06392541777102217, 0.0216312988495995, 0.041309475688444036, 0.07324436409098488, 0.06328359696893923, 0.06839089065549836, 0.02606172129632004, 0.0338113020294376, 0.032854864238611156, 0.06269080579401025, 0.02597568004632429, 0.07155840375250386, 0.06947889638644072, 0.018015042090067462, 0.08343907148246804, 0.08324144378064141, 0.06080792638503256, 0.06208357003126895, 0.02624021786745758, 0.15012108810967015, 2.3587771192673714, 14.078688775339435, 35.75498896260416, 58.25491628339214, 68.46643832422072, 62.37783724261869, 49.02736002399076, 35.68795957872945, 29.944091689202097, 27.096286204553422, 28.665426469618275, 30.421912862408547, 43.06965627977925, 28.838816804270593, 10.232503779472845, 2.869378765744548, 0.501389102109017, 0.7938289486112133, 2.1242041837784553, 4.415641071334962, 5.959812998771668, 11.62136406667771, 11.207802103411767, 14.314202589373435, 8.257084411959495, 12.262948116948529, 14.031608566161125, 13.444993592077687, 9.829098793768114, 16.38122989285377, 11.588703470845378, 13.242200190021148, 25.079905525330577, 30.546008809920284, 42.463834439554525, 52.56560071822136, 60.37483184568344, 65.07314489733788, 68.11579412029636, 70.23579597473145, 72.84732572494015, 70.04359983628797, 65.95268541766752, 63.77234574287169, 68.66639291086506, 67.28073720009097, 69.30167567345404, 68.4457282097109, 68.72700921950802, 66.51986798932477, 68.55754713858329, 66.55731877973004, 56.903585233996, 64.23658178698632, 55.38662033696329, 46.35408040015928, 50.24931953799341, 51.317090680522305, 55.593827386056226, 61.37821728183378, 65.64478720388105, 64.18000551962083, 62.9566849431684, 65.584692570471, 66.75226057729414, 67.94981510408464, 67.22335292446998, 66.87973760789441, 67.26193335748488, 71.077207134616, 65.99792603523501, 63.30398728770595, 60.08676905785838, 62.342724184836115, 62.44059516537575, 58.21647705570344, 49.30294967466786, 42.479323879365005, 34.67869843206098, 26.928593112576394, 22.183880382968535, 16.590241232225974, 10.526025525985226, 9.346625689537296, 11.706442236900331, 13.21247156589262, 13.488683892834572, 11.910440787192314, 19.027284345319195, 9.576792332433886, 12.357309556776478, 14.451561051030314, 5.772065318399861, 3.0465909598335146, 3.4847145599703637, 1.8086985330427847, 0.5760267809514077, 2.0573596415981172, 5.30195503465591, 20.21492115912899, 35.478606993152255, 26.312879054777085, 39.11920978176979, 28.25657036996657, 27.519562898143647, 25.98652412814479, 31.56005720938406, 46.11283502271099, 54.00936634309831, 59.35863594855032, 44.5514492834768, 17.037261993654315, 3.5664878881746724, 0.3148387558758259, 0.02573537358623599, 0.08404700821566005, 0.0652368453842017, 0.05635992413566959, 0.07620746960803386, 0.049821601189192266, 0.0642456233711733, 0.1208093077425034, 0.033365852544985475, 0.01739189659635867, 0.04094051242235207, 0.09917404247267593, 0.08231915052860014, 0.04116190034115026, 0.04236303810631076, 0.0665640161042252, 0.006127164515125896, 0.05333457014433319, 0.07597578163709372, 0.01894166756932053, 0.059049030645720424, 0.028904836377008792, 0.0982182865001021, 0.06300486353856903, 0.0806778914205009, 0.0634518796728263, 0.052436826179825494, 0.0743387513343365, 0.08279377264120887, 0.020404202195124763, 0.08004278154863466, 0.09302761180386429, 0.11275558627300686, 0.22919046301995555, 0.13349989128689613, 0.1840405502626973, 0.1826035991431244, 0.18453300690218327, 0.2604383007893639, 0.22221677996698888, 0.13716873232155077, 0.2447282889437291, 0.13720403365310163, 0.08362461797772877, 0.30345331036275436, 0.28657835457594166, 0.23580413071378586, 0.33399956481110665, 0.18365361457390172, 0.1376430326772313, 0.09410430241616503, 0.2983276305660125, 0.14504872803245822, 0.22115303624060847, 0.19080429458089415, 0.14758611848998457, 0.18460751661369879, 0.1535935042005393, 0.21333541540849596, 0.12906853229768817, 0.07271474452629205, 0.48268871201622876, 3.8846997291811056, 18.870311091023108, 45.2097838155685, 67.60727451693627, 74.49510558958977, 70.76875978900541, 53.50487501390519, 40.202297779821585, 37.232898819831114, 36.96699742347964, 44.10429123909243, 47.94456228133171, 59.878428443785644, 32.358524299437, 11.447062761552873, 3.380024538886163, 0.925659932676823, 0.9081721065505859, 4.354457980202091, 6.519870094714626, 11.55107323200472, 17.395719558961932, 23.290826197593447, 19.11933845089328, 18.779521949829597, 25.072535391776796, 24.88831147070854, 26.081129735515965, 17.164101639101585, 22.613817261111354, 17.702274360964378, 30.305851890194802, 30.133114630176177, 38.86462834573562, 46.61166244937528, 56.83824246929538, 62.53363378586308, 65.97428983257663, 66.83747014691754, 71.40774526903706, 76.13231858899518, 74.07765557689052, 67.92366858451598, 65.1148122356784, 70.26978723464474, 70.5855929466986, 71.35889607091104, 69.53562936475201, 67.77240630119078, 66.79724231843026, 66.1275525246897, 69.07783385246032, 61.16539732102425, 67.27815628051758, 58.99992342918151, 47.091713490024695, 55.18913292115735, 57.03597307205201, 60.4376172250317, 69.61707345900997, 71.34914505866267, 66.85780371389082, 65.18110813633089, 67.34871971991755, 66.65158117971113, 70.70236190672844, 71.30501054948377, 70.07778721470987, 68.31869048456993, 72.83955158725863, 69.69788212930003, 69.51060464305263, 66.97833814928609, 67.32713883922946, 65.79898342009514, 62.14183215172061, 53.90150116335962, 49.050388259272424, 41.71048441240865, 31.45138990494513, 28.95196737781648, 19.91865473408853, 15.592830546440618, 14.948196853360823, 15.809425788540995, 20.274449010049146, 18.392164361092355, 20.167140806874922, 14.137415482151894, 19.746690180993852, 22.88532372443907, 18.825382301884314, 11.764942426835338, 8.937900989286362, 4.149394506408322, 1.9011543138373284, 1.5923226985239214, 2.7209423049803707, 6.37455314397812, 25.510938705936557, 33.32677902713899, 33.44504241020449, 52.261856294447384, 31.92717144566198, 32.6106934778152, 34.95033825597456, 37.558887004852295, 55.12667309853339, 62.15988682162378, 68.43904449093726, 53.74308447684012, 23.13254483284489, 5.510810459813764, 0.7317126398125003, 0.16284036930770646, 0.1582598223561241, 0.16715479263615224, 0.1254802837126678, 0.18757319618617335, 0.13757727168981107, 0.14704745142690598, 0.257020001149466, 0.2492653527447293, 0.15412975042577715, 0.18214075946279112, 0.23310426832927814, 0.1338318984715208, 0.14159351827636843, 0.0763079497001825, 0.20228222222818484, 0.14842222685054426, 0.13053680109160562, 0.12428378460988884, 0.14891050064996367, 0.16848633005734415, 0.16006428117473281, 0.23288388015522113, 0.16144288703799248, 0.15912482755318766, 0.18027545794123606, 0.14331609761763003, 0.2124579229782666, 0.20118991874398726, 0.22529280684407682, 0.10021982909811121], [0.022141289326452443, 0.033272680931634484, 0.07415302097797394, 0.01596573103714975, 0.045792472834188136, 0.08754655147992796, 0.0563937699001643, 0.015085797659271668, 0.09078878879306779, 0.049166167004694866, 0.0512755632911238, 0.04770743217499507, 0.009155514867856138, 0.045284602505665635, 0.047734367826412764, 0.07102227244045466, 0.0637964009036941, 0.07766676751235801, 0.029027628779952085, 0.025606563562647473, 0.04056887167896475, 0.08176222759028597, 0.008762668810724732, 0.02405072517332531, 0.09264187121223058, 0.013140146920998252, 0.024506036124582735, 0.044189629205051935, 0.06626480514363897, 0.07340613887795518, 0.45558026180632655, 3.756176651485505, 14.281257621703611, 39.42402501260081, 50.499456928622344, 56.02106763470558, 51.86481437375469, 33.289614569756296, 26.264826097796043, 26.61594294732617, 37.640429158364576, 36.22107244306995, 43.26163276549309, 27.06321866281571, 11.562502038094307, 4.593707361528951, 1.618347992339442, 0.6951424827979458, 1.0230559999904325, 0.9672746867422135, 1.3124227307496534, 2.0161066036070547, 9.550793882339232, 8.124334735255088, 7.9282108333803, 8.791515192677899, 7.918979535179754, 12.291218599965497, 13.246735430532887, 13.634490159250076, 23.289086626422023, 13.092097947674414, 17.07197496967931, 33.19071985060169, 37.08167183783747, 50.1033289201798, 56.31436286434051, 63.41133863695207, 62.81403226237144, 66.27485321414086, 66.93774161800262, 66.14344596862793, 64.02970421698787, 61.52805966715659, 59.315042726455204, 63.318511824454035, 63.93704606640724, 65.5480811672826, 64.54940257533904, 68.24617370482414, 64.82367430963825, 67.28746798730666, 62.23497275383242, 62.647959109275575, 59.76907668575164, 52.642416415675996, 47.34885623378139, 45.11765126259097, 41.93413795963411, 49.523045632147024, 53.02045445288382, 67.22828726614675, 61.4215124037958, 61.4614107531886, 66.54475935043828, 65.62220611879903, 62.18715906143189, 60.21058651708788, 63.16470000051684, 66.98423739402526, 62.84813727101972, 53.51909360577984, 51.541564003113784, 59.805033053121264, 62.72283715586509, 62.6747057514806, 58.135248691804954, 51.31061092499764, 44.81186328395721, 35.944561035402366, 27.93299444260136, 17.6353822600457, 13.84729443057891, 11.549996541392419, 7.2715879255725495, 13.282295638515105, 24.799718856811527, 23.556766817646643, 10.285671507158588, 19.463138118866954, 6.3359202492621645, 11.002418956448956, 7.4519237972074945, 4.8903013044787995, 3.2798592169438643, 2.635101724055506, 1.057701315129957, 0.9763854333469946, 0.8535803133441556, 4.375644662687856, 10.863862210704434, 17.212358559331587, 26.176651216322377, 21.901789403730824, 27.939419284943614, 26.406141250364243, 34.35590697873023, 31.74497538997281, 42.6430396879873, 48.712523137369466, 51.73423867071829, 47.687654879785356, 21.295202701322495, 6.088188252141399, 0.6672160651895308, 0.09995939750825206, 0.04064900830628411, 0.051347426168860934, 0.016019543925780925, 0.06799239469992538, 0.029922151344738183, 0.05224302508718064, 0.05213642012207739, 0.03690150153312472, 0.05619930614146495, 0.08276279970643022, 0.024526101882539453, 0.028064485804568377, 0.06918120227994458, 0.05046094369684016, 0.019453243848176736, 0.01008776055964371, 0.046362890411288514, 0.07331053110500498, 0.016647148051209027, 0.0382442583119677, 0.0495162078990571, 0.03483316755943722, 0.02681143409121902, 0.06145112997581882, 0.05873166340132875, 0.02170032720201679, 0.03730466679459618, 0.0707148413564409, 0.08429658433963215, 0.02218269063310037, 0.03166985645469639, 0.05563769857549379, 0.07908690300199293, 0.033939663891590414, 0.05634211259143007, 0.0718209650667925, 0.0650887452666798, 0.0865336606699613, 0.06450480240727625, 0.03878859442568595, 0.01164848658992278, 0.03208891995581648, 0.06977200162627044, 0.027995296573686986, 0.05966090507084324, 0.07433626920946183, 0.040723487374282656, 0.07262997689747042, 0.03215886952896272, 0.029814085066919366, 0.041715640184139056, 0.05776658413871642, 0.014988843486794542, 0.06064233264975971, 0.020367087150413184, 0.02990952238530642, 0.037323788349186225, 0.010742588577071025, 0.09157962901818176, 0.01986998418766645, 0.43640002488128604, 4.6991656768706545, 17.172654367262318, 44.25437288899576, 57.88831979997697, 63.66497478177471, 59.155712127685554, 39.775383087896536, 28.565515856589045, 29.603441684476792, 36.84348590912358, 30.403650306886245, 39.288907204904866, 37.165277158060384, 14.081617805265612, 5.730103312000152, 1.4181694628730899, 0.604870542883873, 1.485967999023776, 3.910307658295478, 4.804692633690373, 8.283511380995474, 9.816473664775971, 10.007520548758968, 10.836898857547391, 8.904993284133173, 13.924721037187885, 15.097789187585155, 12.454008729227128, 9.586191311959299, 14.365407170787936, 14.21048237431434, 18.557237309794274, 28.93939814259929, 39.05850325861285, 48.93350555050758, 59.00202581959387, 63.39691608182846, 64.19347101642241, 66.21445655822754, 69.37707147290631, 70.12743657635104, 67.1213399210284, 64.42224325672274, 62.80599140351819, 67.32755461046773, 66.40807259467341, 67.52157857341152, 67.0478896171816, 70.39301241597822, 66.41588595605666, 68.29223802012783, 64.86688706182665, 65.2246739018348, 62.139251232147224, 55.96698207239951, 54.128626008187574, 50.764185536292295, 47.550215028947406, 54.632893762280865, 58.63729246201054, 70.71545477836364, 65.96550372339064, 64.40165473568824, 68.14501577808012, 66.88761372720042, 64.36086600826633, 63.764642207853264, 66.37339884235014, 68.44801887389153, 64.89308457220754, 59.3584398300417, 58.817956832147416, 64.89561450096869, 67.63825339655723, 66.01512170607045, 62.086444362517334, 57.136283766838815, 49.27156679091915, 39.89459176217356, 28.927746742002427, 18.703145557834258, 14.408001169081658, 10.103733347308252, 7.9487875873042695, 8.887428910501542, 10.122188098969, 8.383744608971382, 10.18317016863054, 15.423033102866142, 9.446036200369559, 8.528610487138073, 10.404290845317226, 7.6837956905365, 5.337368153756665, 4.830925445402823, 1.970277998235918, 1.1988357935220966, 1.44017469498419, 4.645925875632994, 14.389719001708494, 19.606692944803548, 24.939063018368138, 22.770272762544696, 25.027532077604725, 26.738720978460005, 35.00236065156999, 31.95288846569677, 47.659829585782944, 55.20127657921084, 59.58432912826539, 54.66786561473724, 24.6915751887906, 7.167202378472975, 1.1218793810375276, 0.09896548269616981, 0.13218081045535304, 0.09460217529727567, 0.026459290285504637, 0.040860000411949815, 0.011750934570426903, 0.0652662325169771, 0.02460574821358727, 0.0301165365794253, 0.018721400054111596, 0.013233901718781601, 0.06563511151339739, 0.03302829122290977, 0.06574006555902381, 0.015723678854203994, 0.036513688673655835, 0.09009404663717555, 0.050724002968279586, 0.10919074933495253, 0.009673363491592389, 0.01608470544940041, 0.07854668844130733, 0.05951155623000476, 0.03019670001982201, 0.03473816882638681, 0.03127078401796039, 0.0494366534985602, 0.03116758814412019, 0.07513391995622266, 0.02044584864990846, 0.041728644526653716, 0.12544266879558563, 0.11246159237118498, 0.11881938669830562, 0.21816556912756738, 0.09233836249838914, 0.22088003314791188, 0.15158540388989836, 0.19385517845230718, 0.14062377353829725, 0.13448224583220098, 0.14863392758753993, 0.1457785187108863, 0.13690073944387898, 0.1398105712066735, 0.18249801690540007, 0.24004451930522921, 0.1727672753434989, 0.2135114470917371, 0.15836306036480013, 0.09437112317931268, 0.09304063529857705, 0.15933018508217028, 0.22178001791959812, 0.16291176870224938, 0.21980018625336312, 0.08404050412918292, 0.22019236198356076, 0.11938079125097684, 0.22009177463910273, 0.14150531091276677, 0.782281490823915, 6.629268430894421, 24.209002064120387, 52.282338911487216, 68.74759381817233, 72.51544613992014, 64.61233700475385, 44.49295497709706, 38.25899870164933, 37.710333639575595, 49.069105809734715, 48.52392773474417, 55.4095152116591, 35.3523458973054, 16.697792622350878, 6.260295971747368, 2.494555356041078, 1.8964233225391758, 2.8857428941034504, 3.7939049495804698, 5.036751329898834, 10.941412371973838, 20.218833723375877, 16.99481410364951, 18.535526990890503, 19.702324251974783, 18.06976318359375, 22.307760600120794, 24.2517460930732, 24.361421446646414, 35.52418101218439, 19.451014072664325, 22.16672001346465, 38.856681623766505, 42.43287517178444, 51.98951828864313, 59.02333997911023, 63.510806022151826, 61.56267458392728, 66.09435358355123, 69.66132563929405, 71.42667462748867, 68.71209636811288, 66.23372324051397, 63.9969838050104, 68.17262141935288, 67.83271666496032, 69.6010466544859, 66.8462170324018, 71.29084294842136, 66.29859139842372, 66.9558943471601, 67.34205169062461, 67.83126538799655, 64.12733593294698, 58.5002330810793, 54.35728449975291, 53.02151741520051, 54.68609286892799, 59.62049338125414, 64.32443111173569, 78.08525885305097, 69.79534518334174, 67.71098198429232, 70.45147142102643, 70.37926843089443, 65.985884358806, 65.43499923521473, 68.93050962878813, 72.43588478334489, 68.12861242601949, 64.9938581066747, 62.06655402337352, 68.28074547552293, 68.40107594766926, 67.15800623739919, 63.394954896742306, 60.60202337080433, 56.14734834240329, 46.84593777502737, 38.857415106988725, 24.687170367087088, 17.020440909170336, 17.145778286841608, 10.183456501653119, 18.633023385078676, 34.5049923466098, 32.67135097134498, 18.067041058694166, 30.881216526031498, 21.409210312751032, 21.4458687843815, 15.876132557469031, 15.205816165093454, 9.708357453346252, 8.983323016474325, 4.579405909584415, 2.0510008666784536, 1.7175528238857947, 5.660916624530669, 13.160184410310562, 22.69551434824544, 33.892545623164025, 32.80196001452784, 41.90948978547127, 40.38894768684141, 48.81543436358052, 42.91908825597456, 56.753460438020774, 61.00977336206744, 66.84586401908629, 62.52587926003241, 31.726563784383963, 9.699818453481122, 1.531355705472731, 0.22295285256639605, 0.188081449558658, 0.20267358590518275, 0.06978099549850149, 0.16287717217158887, 0.07094331175809906, 0.17826158132764602, 0.1556759763268694, 0.11473685052366027, 0.14599504580180492, 0.2959095199982966, 0.13110200544038128, 0.09565735416066262, 0.18628593864700488, 0.09194857696251524, 0.10118686954580969, 0.20335658393319578, 0.08859072165984301, 0.3231823113897155, 0.15440227854396069, 0.09953318449157862, 0.12862959456059242, 0.14125889107104272, 0.12159855450473486, 0.2569893729542532, 0.127604185873943, 0.12774424206825996, 0.12845134888325008, 0.1723702579376198, 0.23056533037414476, 0.15580009789236132], [0.021779743706687324, 0.08192306774998866, 0.04525135812019149, 0.004713214706674579, 0.04229268442178446, 0.045733388303028005, 0.0639624887656781, 0.021144266112617428, 0.023907570153354638, 0.03479512746355707, 0.049183024769468654, 0.04762648732491559, 0.030455812023231582, 0.019885158474226634, 0.034920413482693896, 0.1129017252054426, 0.09154770613437699, 0.050295154609146624, 0.02324670823591371, 0.04805407929985274, 0.01900007028222805, 0.011215296427478955, 0.09884467829139003, 0.04137854617569716, 0.059695172183696306, 0.023682604603950056, 0.07755162449733866, 0.025502701192313147, 0.03217795660959617, 0.0947119786794628, 0.42888804248744444, 6.937121047127632, 21.023300078607377, 40.91425111216884, 55.08586083689044, 58.29899195701846, 43.70659036021079, 32.90468100578555, 33.59488087315714, 30.544353569707564, 35.09883919069844, 53.301056892641135, 34.63511697707638, 16.660677194595337, 11.914043484195588, 1.5914390620685395, 0.5929738102901367, 0.1152612989948642, 1.5171069603773857, 3.5477254756035346, 7.054527882606753, 5.779350140402395, 7.651338567656856, 5.330892810898443, 12.828211668998966, 3.122055155615653, 14.12117785023105, 16.138105700092932, 10.772006184824052, 6.903354342906707, 18.17657324575609, 29.117936588102772, 27.546174218577725, 39.719065696962424, 51.998535817669286, 54.466447984018636, 63.821030201450476, 64.2286939005698, 65.58746568618282, 65.88329868931925, 67.93811075149044, 67.83170469345586, 63.347960979707786, 59.27834110875284, 59.01051775101693, 60.06768280459989, 61.51994428327007, 61.55110359191895, 64.32273272545108, 67.03023895140618, 66.96183281560099, 65.37245704281715, 64.25583277979206, 63.54782927420832, 59.76123194540701, 54.70104102165469, 52.59316321342222, 48.8318024143096, 47.500730406853464, 47.90700166456161, 56.539079373882664, 63.87788103472803, 57.01526687991235, 63.13037926150907, 65.89465002859792, 62.57464608838482, 60.50570957122311, 58.77918812536425, 63.923792377594985, 62.73339617636896, 60.812744863571666, 56.77470007250386, 63.04991575979418, 66.49178381889098, 64.09005380445912, 64.66746983989593, 62.03165277358025, 59.49356548247799, 52.31491811813847, 47.20288130544847, 39.05751482132943, 30.367780231660415, 27.51408923056818, 17.900567823840728, 17.865913683368316, 11.37355754452367, 7.551447566478484, 8.083693587010908, 8.157085545601385, 21.58357927876134, 3.7180122348570057, 6.370614594028843, 10.165942138241185, 6.066751518557149, 3.545578468230463, 3.321908005783635, 2.0396647265841885, 0.518927061029019, 1.038485501081713, 2.1457110297295356, 7.674341307532403, 16.767461761351555, 24.41159836707577, 45.996199423267, 46.10158566505679, 34.4150798551498, 17.573948137221798, 21.41603131448069, 31.18382542364059, 37.668960478998, 49.67000899776336, 49.83766286603866, 30.35050415223645, 9.570540074379215, 0.521185243081662, 0.07680726282659077, 0.0256597951820661, 0.024317434853723934, 0.024456901160339196, 0.0167150272717399, 0.028258386488643386, 0.07393508428527464, 0.07398150155260678, 0.059146986478158546, 0.08949980755606968, 0.16037865301534054, 0.028961036587134007, 0.09334208323590218, 0.027505331635174733, 0.012419016866554177, 0.04724682181052143, 0.10570861158832427, 0.023386157305550673, 0.07621843998710956, 0.12519704568530285, 0.07743655043023248, 0.009165548704444401, 0.030827129094470895, 0.07206840380545586, 0.10074938737577009, 0.05941174646478988, 0.06169754215666364, 0.003546258108878148, 0.002860352537790013, 0.059324906568133065, 0.03758128582229538, 0.0322647275583398, 0.09457987447779986, 0.049109411380824544, 0.032641926269617774, 0.0586182211015013, 0.03308431140237278, 0.021398772012382265, 0.03505628300650466, 0.030962933500808094, 0.032717382099719784, 0.05633845452159163, 0.05894437154394485, 0.03213676789234723, 0.01569986405346783, 0.05049337219867495, 0.040756237633045644, 0.09265815058062155, 0.08769615312978145, 0.04021617245950526, 0.046422825300044594, 0.05685651381950706, 0.05408481153989992, 0.016150811176386573, 0.02623808431258846, 0.04210657102145976, 0.025411437137893615, 0.017521738923425158, 0.044644949732408415, 0.02365677786480275, 0.11227708009462203, 0.6497626210893355, 9.31016823937816, 23.92706209613431, 48.48859110186177, 63.761182677361276, 66.30208230787709, 49.82310302795903, 33.62518510510845, 37.78841234022571, 33.42508931313792, 36.7380839778531, 49.73915646153112, 38.783588255605395, 16.804279088974, 11.591233399606521, 2.662217314204862, 0.41974239291683324, 0.6944282437043806, 2.1499253713315536, 6.2024944539993045, 10.242555833631947, 11.02623558813526, 10.59249303033275, 13.262179763086381, 9.97177500878611, 13.451894021803334, 12.127855804658706, 11.23129023659614, 9.50138476587111, 11.041075875682216, 18.221154905134632, 23.235220716845607, 30.79588536293276, 39.70834193691131, 50.72789184508785, 55.375418047751154, 63.37168739688013, 63.4427450549218, 65.2501065500321, 64.76052807223412, 68.37044223662346, 68.65391192897674, 66.29597125514861, 62.20284069738081, 62.160753665431855, 62.641236166800226, 63.79212233328051, 65.71937891744798, 67.91119544736802, 68.24447924090971, 68.51136515217443, 65.36891122018137, 65.22556820223409, 64.24080617966192, 60.97429944622902, 57.26837350476173, 56.10236660126717, 53.65513317046627, 52.99948153957244, 53.354189318995324, 60.721145752937566, 66.53034071768484, 59.4428845374815, 64.30079883144748, 68.44612044672813, 65.56160157726657, 63.60400545981623, 60.93066700043217, 65.09718510412401, 64.97275183277746, 63.909636543643096, 60.49995545418032, 64.83214662921044, 67.78101982608919, 66.42264027749339, 67.69534741678547, 63.95692856081071, 62.480462135807166, 58.15789253480973, 52.16396962442706, 44.98076446594731, 35.2557889107735, 26.509738891355454, 17.518652523717574, 11.064868973147485, 8.906924070850495, 8.165550020433242, 10.039447661369078, 5.942647236008798, 15.32518957891772, 9.389320688862956, 12.125855395870826, 16.27981112849328, 10.280692058224833, 8.114883784324892, 3.9255928897088577, 2.5671287650062196, 1.340567820495175, 1.0160605753621748, 2.741194482772581, 7.559775738946854, 18.103032727395338, 26.656670878010413, 43.629507941584436, 45.25567162421442, 36.631732833000925, 26.06435375828897, 29.07417078172007, 38.20473271031534, 44.706327992100874, 56.84500071310229, 59.36220530540713, 35.07997651253977, 11.648090116439327, 0.8776098561863747, 0.13967894197952363, 0.06828661842812454, 0.03497615787050417, 0.023044958981054447, 0.013092877380850335, 0.04602732091781594, 0.0316951833214731, 0.06431174058947833, 0.053416196812665274, 0.009943158591106054, 0.08872663331848961, 0.08974437346501697, 0.06879715474262353, 0.0584584343126945, 0.03430949666747644, 0.009525325618714336, 0.005323148056519248, 0.023841627220052387, 0.06129998465879791, 0.08183823117325384, 0.08123430107990581, 0.030129726698261597, 0.036907205057720986, 0.04342457166902962, 0.0908443071849404, 0.10301339169663769, 0.07238472150939126, 0.014665414571702002, 0.008548497440173261, 0.09749905251327062, 0.007366693819001798, 0.11067108401367742, 0.21986819953928072, 0.1898454436131062, 0.11998026271260555, 0.13103825160332266, 0.13337146430726976, 0.18495080061256888, 0.18113574403668606, 0.17019148855920763, 0.0738516956147167, 0.1748399415443982, 0.12817642290986356, 0.27845059070856343, 0.11007452368616097, 0.1161774788652697, 0.22348384342847333, 0.18225657663518385, 0.20181530696009436, 0.13481016210731, 0.10507730917344171, 0.11348064252806288, 0.164049286695738, 0.17933753649553946, 0.16720947599218738, 0.18326782801699254, 0.1449331100429258, 0.11200597689997767, 0.11287338761312347, 0.12367121304475492, 0.36274707545676543, 1.0050070297814186, 13.271964115481223, 29.004093716221472, 55.75921412437193, 74.78728294372559, 76.3710811061244, 56.62483023058984, 44.36726262492519, 45.30296756375221, 41.81707482184134, 47.48557829087781, 68.8460688437185, 46.342631001626295, 23.74930027992495, 16.500248332177442, 2.7539993053482426, 1.3223577266739261, 0.6347684418001484, 3.9561559980915444, 10.024515198123071, 19.14235688024952, 18.257760424767774, 17.723000164954893, 18.817684650421143, 22.72438495389877, 15.13948888547959, 25.73030706374876, 27.400960230058242, 16.249400992547315, 11.032171114798516, 23.706734718814975, 35.161765775372906, 33.482124497813565, 42.994166343442856, 54.56865318359868, 57.53792270537346, 64.62961504536291, 66.38949624953732, 65.67336559295654, 65.9689240301809, 69.45404406516784, 72.86907918991582, 69.12230568547403, 64.54916331075853, 64.43711296204599, 65.03851036871633, 66.10621483095231, 67.47024259259625, 69.7773571937315, 70.02802802670386, 69.32043244761806, 65.46527601057484, 68.15626513573432, 66.8164776217553, 63.34964367651171, 58.20114843307003, 56.38025868323542, 56.17610323813654, 58.57839022913287, 58.95906802146666, 66.12603064506285, 70.40396367349933, 63.784716898395175, 65.53699654917564, 70.94081847898423, 67.80333026762932, 65.48522126290106, 62.745979139881754, 68.45220796523556, 68.2110292680802, 68.63097390820904, 63.2628494693387, 66.67833958902668, 68.51362443739369, 64.52400915084347, 66.9821350036129, 64.52145961023146, 62.265116168606674, 60.549196889323575, 54.282998731059415, 48.43657655100669, 41.45375351752005, 34.0380734012973, 22.274190995001025, 24.251126358585974, 17.773437923000706, 16.163842331978582, 17.46672034263611, 19.034426981402984, 39.786565765257805, 18.899585700804188, 17.484563204549975, 22.15930477265389, 19.116563373996367, 9.108391711788794, 9.092039350540407, 5.487440488030834, 1.2919533517091506, 2.032294593030407, 3.3211833478942996, 11.094165155964514, 21.675505907304828, 33.13128809775076, 60.332223138501575, 61.27717702619491, 47.750448103873964, 31.87237593435472, 35.66438613399383, 43.88281852968278, 51.98272474350468, 62.86232056156282, 65.23638609916934, 45.37136193244688, 15.517653419125466, 1.6935051400815289, 0.2406060770754853, 0.19058709333260215, 0.11712051777830047, 0.14048338026529358, 0.10900753174698162, 0.12485248231959921, 0.16805264768340897, 0.1820813876486594, 0.1260179855049618, 0.17723143821762455, 0.2379450247052216, 0.16968349565661725, 0.17238338868464195, 0.1159482500365665, 0.134951765799234, 0.12905394598360986, 0.16858250473535832, 0.1682888785557401, 0.0867341458797455, 0.21894337819708934, 0.22697361907170666, 0.09709212192965132, 0.1258506795631782, 0.14346933052424463, 0.2849414391863731, 0.13173695443378342, 0.19331128666958503, 0.15340308538608013, 0.10694434205370565, 0.2355587833951558, 0.17578958413533627], [0.018294553099680814, 0.0354104224712618, 0.047345608848357396, 0.08601062180053803, 0.0045939927522633825, 0.022454178786926696, 0.02426560709042655, 0.02116005518473685, 0.07252621028812663, 0.03022271062007114, 0.03963738920227174, 0.06461400058000319, 0.06121135977727752, 0.054515448714336084, 0.05263468753846903, 0.0469396626877208, 0.05538328843671949, 0.06199577252470678, 0.04273317731736649, 0.10007416514018852, 0.10406846330771524, 0.05350029411455316, 0.0265685286778476, 0.055433225878063715, 0.027014257784392086, 0.03848977416994111, 0.012273175750798997, 0.07577859826626317, 0.07655408608937457, 0.025900578531887264, 2.1650483146790536, 10.885929465293886, 27.268380195863788, 49.826495878158084, 52.790050506591804, 50.03017279409593, 46.806106105927505, 35.82974149334815, 22.189081445817028, 27.977283885402066, 43.39334987824963, 29.223040419240153, 19.1261927927694, 21.19800244608233, 5.278905226338295, 1.2922833210998967, 0.05469719541349238, 0.562261835702004, 1.1511590163553915, 8.093186703420455, 4.82910595593914, 10.901951366855252, 7.344416043450756, 10.522078640999334, 5.884891315813988, 9.49456964769671, 8.285476488451804, 8.190296253850384, 11.802747211148663, 19.786666977790095, 27.50143566439229, 30.72041503844723, 42.88203362495669, 45.096996061263546, 53.9561084008986, 59.46222574480119, 63.31793523603871, 61.67739998909735, 65.84171372075235, 63.62651594223515, 64.29722947459068, 63.39254263908633, 60.075107851336085, 57.69696304875036, 58.514949813965835, 59.75884714434224, 62.82635634945285, 63.09399535579067, 65.32165058197515, 65.98370352099019, 69.29438006493353, 64.3735234968124, 56.218617808434274, 62.98511035980717, 57.56591666129328, 55.93404985243275, 52.561117449114406, 49.03774253783688, 44.13884732031053, 44.97870129923667, 55.28144982553298, 54.62211901141752, 59.3172392537517, 65.33658304522115, 60.21731730430358, 61.28030315522225, 56.63298483817809, 57.876238899846236, 58.723074697679095, 58.22954247074743, 58.67526492764873, 62.986710686837476, 64.41106450173163, 66.11940183947164, 67.46545730098602, 68.77392861150926, 67.68136024475098, 65.05528634594333, 57.03563574821719, 53.49949744439895, 46.23777427980977, 37.54573137529435, 31.887475098333052, 26.070855086849583, 14.043051100546315, 11.519578560706108, 9.421113460294663, 6.573632551777748, 5.206383053333529, 8.84934759909107, 8.351316413571759, 6.6328681861200645, 13.375935362231347, 5.036900870261654, 7.316414242790592, 3.828724810192662, 1.0694113061312707, 1.8024014128792671, 0.6803484056745807, 2.416342559360689, 7.144561967542095, 13.96604516813832, 14.689345917394085, 17.43646906268212, 30.35553066961227, 26.414701823265325, 22.75845858358568, 21.681605192922778, 29.251365815439534, 38.790220983566776, 46.7123261574776, 49.6373317318578, 43.131818002270116, 21.095752139245313, 3.712734195493883, 0.05246249395572851, 0.036710044669528166, 0.04029063620574532, 0.07399914455750296, 0.07245880987254844, 0.04338251727242624, 0.031820950060782414, 0.033439538711982394, 0.017810228483511076, 0.017616647641144453, 0.04040383718787663, 0.028245836053223863, 0.06166866447235789, 0.04173322956288054, 0.03490948906889366, 0.017864582421738776, 0.072658896716612, 0.025293898182891073, 0.062499804752728635, 0.08897292292526654, 0.01525662569028716, 0.060323751156008056, 0.011204682279288048, 0.047073716583151015, 0.037540361405380314, 0.047452240626537995, 0.039608454061371666, 0.04864683217038551, 0.008355630017186125, 0.08942453941750912, 0.13056252632410298, 0.010364608456110282, 0.057815824440049554, 0.07107546192503746, 0.08628167136902772, 0.019034264616728313, 0.010740965428281455, 0.037517750320295175, 0.03627414064061257, 0.04624925275904037, 0.02591660126082359, 0.005892062664873177, 0.049872990367153, 0.016238219893327164, 0.08267603258812621, 0.02626013423826906, 0.0480383591756465, 0.07536114163456425, 0.04393292463294441, 0.04907477654576783, 0.11409489948663021, 0.027824399594758308, 0.06645562998469799, 0.07193157284130013, 0.07505138164326068, 0.09353968029421184, 0.02374223688797605, 0.01933610708933444, 0.09831430796053141, 0.02067539540510024, 0.012564333212081225, 2.5739505021802844, 13.659082439637954, 31.28696414732164, 58.49280018960276, 60.29046166327692, 55.10967746857674, 49.64310938312162, 38.2350016409351, 26.37416412753444, 31.284869601649625, 39.24860877375449, 37.26227345005159, 21.16094389269429, 20.04457066136022, 5.625741789417883, 1.6242759194104903, 0.17737232178689974, 1.7356925601920776, 2.199520310086589, 8.626546186785545, 7.707411300751471, 10.649994977058904, 10.623019856791343, 10.707822480509359, 8.837926637741829, 8.47408365818762, 9.996622243235189, 10.202415277881007, 10.198206574686113, 14.102687797238751, 23.5239875701166, 31.766519008144257, 43.64167905622914, 48.026355466535016, 56.673734341898275, 60.79558449406778, 65.30371750554731, 64.5175176282083, 64.41606160133117, 64.4103741645813, 68.24812704516997, 66.58686991660826, 63.038093736094815, 61.119552658450225, 60.15513204759168, 61.77402757829236, 63.353377772915756, 65.1146004276891, 67.06186894447573, 69.26100853950747, 70.13026068287512, 65.84622444645052, 59.402895973574736, 63.405835551600305, 58.3512104711225, 58.77979217037078, 55.28897685389365, 52.52538073447443, 49.83017898374989, 49.572714605639064, 58.79987470565304, 56.67084355508128, 61.375424554271085, 68.53192621661772, 63.87336638665969, 62.57397144071518, 58.64048919370098, 60.41465567004297, 61.07675175512991, 62.64406027332429, 63.41250750326342, 65.98557841393256, 66.90164012293663, 70.73781228834584, 68.93987624875962, 69.1372577605709, 65.84703245470601, 64.22150419604394, 57.94242105176372, 56.12170780858686, 48.167768678357525, 40.945892872348914, 34.659141494381814, 29.392216167142315, 17.584913123038508, 10.559353905339396, 9.097471833229065, 5.801994473703447, 5.749356756287237, 8.338788363241381, 11.210470295721485, 14.295861586447685, 16.675409616962558, 8.570989735664861, 9.171822321030403, 4.51216765949803, 2.773142432974231, 2.931603001010034, 1.2633538798939798, 2.8139005168791744, 7.521906725821957, 13.3017211767935, 18.991276987137336, 23.087061028326712, 35.92846362821518, 28.574943273298203, 27.588353426225726, 26.043443602900354, 35.39331113138507, 43.25014806562855, 54.28002949683897, 56.42142395819388, 49.2988625649483, 24.379317260557606, 4.944079941318882, 0.04721506746606, 0.03231502506100843, 0.05840461280557418, 0.05095334671017143, 0.05146340038927813, 0.01676545500935566, 0.048261505266230915, 0.025885289332138437, 0.011536767987924959, 0.03170711131045415, 0.06519991994625138, 0.03595406527540857, 0.05784924502574629, 0.0608386273585981, 0.10566030208381916, 0.038963293115938866, 0.01773700388448854, 0.01549958089937366, 0.04081738294072209, 0.05276730501904123, 0.07881111134925196, 0.020034834817652742, 0.03922719125365538, 0.0382195060111342, 0.09183269084220932, 0.033139048384562615, 0.04106716590843374, 0.015984816202563385, 0.021152689249344894, 0.0664852699264884, 0.15868713087852926, 0.1527704806217263, 0.17015508406104582, 0.19631447390683238, 0.11936073506911916, 0.09279166438406514, 0.08060607833847885, 0.12543927502608107, 0.1122264953089818, 0.12354719873157241, 0.14748243615031242, 0.08816630128891238, 0.19829190005698513, 0.12041437409577832, 0.17218555413907574, 0.10554522801671298, 0.2616928770176826, 0.15588756981155566, 0.1469073186237966, 0.15011065399214146, 0.25805794303455665, 0.2530723500756487, 0.22397861365349064, 0.1821393805045274, 0.2722081998663564, 0.2555590867996216, 0.14100047429242443, 0.13032865500257862, 0.1768556567690065, 0.25147481160538815, 0.11396198323176754, 3.9317635134343183, 17.796921153222364, 39.275998684667776, 67.10849023634388, 69.51424460257255, 61.73060301811465, 59.58272487886491, 47.26859277294528, 32.55175202123581, 38.68684691767539, 59.00213172358852, 43.494158714048325, 28.114692357278642, 25.662418680806315, 7.060004491959849, 2.0296612117559683, 0.2118590107608226, 1.5358705986892025, 3.183584641064367, 19.006011370689638, 16.084118197041175, 22.368023895448257, 20.849903860399802, 21.940948386346143, 18.354033039462184, 16.689469352845226, 20.353314145918816, 18.52379910407528, 19.72111632747035, 30.74441209916146, 39.58288100457961, 41.60159157168481, 48.121217989152484, 49.401350175180745, 56.75913610766011, 61.26614732127036, 63.530613991522024, 62.74406502323767, 63.423945134685894, 66.00093841552734, 68.6507583433582, 70.42031995711788, 65.6382211562126, 63.654180419060495, 61.73160322250859, 64.87318246595322, 66.15962182321857, 67.2045490818639, 67.66989123436713, 70.16259670257568, 70.99759086485832, 68.98216724395752, 62.01215859382384, 62.8789710229443, 60.24702925835887, 60.72646448689123, 57.233711519548976, 55.855865247787975, 56.151580579819225, 55.573446750640876, 64.64210779436173, 62.88147741748441, 67.50667356675672, 71.10333796470397, 66.48756334858557, 65.44478947116484, 61.68319332984186, 64.25131420935354, 63.56097705902592, 65.8720414869247, 65.95395626560335, 65.72332874421151, 66.90433086887484, 68.40675553967877, 69.63870925288047, 71.41648430978098, 70.07756756198022, 69.57396661081623, 62.23798121175459, 59.4258536061933, 51.80772427589663, 43.58767586369669, 36.90310201337261, 32.40815404922732, 18.50441278949861, 15.719231867021131, 15.666536784941151, 11.686601907976213, 11.992180039805751, 14.730775952339174, 16.315524308912217, 15.046731695052117, 19.825737707076534, 14.569733238989308, 15.794738473430758, 10.475558350163123, 4.008668689958511, 4.539932156762769, 1.8463361263275149, 3.9715981243118166, 8.980631289943572, 16.555685151007868, 20.219227921578195, 26.70189972846739, 44.11521111765216, 39.02100932213568, 37.42350639835481, 36.28200646369688, 43.50827140192832, 52.63850189024403, 62.33002747258833, 64.68574024015858, 55.58879106275497, 30.031886100769047, 7.446921794645249, 0.27488218380078194, 0.15103901466054304, 0.20067213523772456, 0.14233377371584216, 0.17561396613957422, 0.12197766843582354, 0.11526089296826433, 0.09065758857515552, 0.12364629986545733, 0.0988784627688508, 0.10059983169119205, 0.11781090089390356, 0.1444550711781748, 0.1564277690504828, 0.10756239114749817, 0.14047620968232233, 0.22144955823258047, 0.16864391434336864, 0.128804660973049, 0.22177845510023259, 0.11366323958481513, 0.12509302626694405, 0.11121874494898705, 0.13580701103614223, 0.2099561862527363, 0.1495564506659585, 0.13456723562652065, 0.19880163964004288, 0.13595399266529468, 0.23318211818414353, 0.3346878488457972], [0.0502043578683609, 0.08801880638085066, 0.011626761294000093, 0.018353965133428574, 0.047055165764064565, 0.016733966880447922, 0.05195439763126835, 0.047575094316515236, 0.0321736665172202, 0.02388432896095178, 0.005932804657101271, 0.0703708908610767, 0.013948624405348975, 0.12966992664000682, 0.12620910145943204, 0.026640027663820696, 0.029409253564212593, 0.025993617995071317, 0.018816778000684518, 0.06123040089263551, 0.05571801523347536, 0.039413657054425254, 0.06353131149925532, 0.04761917501567833, 0.0543943225526281, 0.04519496255764558, 0.02281460017266293, 0.03216051661799992, 0.06651185317746093, 0.21380931739845585, 4.459462281196348, 18.904743617580785, 32.62753809652021, 53.99449663777506, 59.379240159065496, 57.8077543166376, 36.064620864006784, 34.039999285051906, 30.875409456991385, 29.47482128297129, 37.84703216245098, 29.997251572147494, 26.401512853560913, 9.328622991038907, 2.3688590814990382, 0.7954754860651109, 0.4620235821893139, 1.680093821017973, 1.4671054434391761, 4.581004275429634, 7.006851963458523, 7.722791404493394, 9.083350320016185, 9.655912422364759, 7.388578499517134, 12.664138924690986, 11.086743051005948, 10.996674645331598, 12.786409008887507, 21.41797681008616, 35.67413322387203, 39.61492676888743, 51.40122944308866, 55.87368065311063, 59.72539324914256, 62.24174668712001, 64.31420549269646, 64.30056741160732, 63.04525990639964, 66.06016620512932, 64.55973409837293, 62.514371025946836, 61.032248543154815, 52.21893379765173, 56.974560522264056, 56.05323107011857, 63.09331286338068, 61.59724635462607, 65.73769246378254, 64.81099328687115, 66.73589644893524, 55.40994275000788, 55.81550013634467, 65.71502900892689, 59.13028340185843, 56.2399947258734, 47.81180181810933, 46.572324998917125, 40.12476821099558, 45.38565897172498, 47.404636260001894, 59.3221696730583, 67.07980202090356, 62.20972053466305, 61.4574295474637, 57.23064030370405, 56.27184044930243, 57.23768488053353, 56.20499933919599, 55.94763302033948, 63.217298984527595, 65.29490786214029, 65.45288132083031, 62.83908836303219, 64.99477594129502, 64.2687059986976, 63.3030733754558, 61.71128142264582, 64.06821012496948, 60.97964563677388, 56.65447158198203, 47.416238630971606, 38.82155287650324, 27.874810003465225, 25.601814139273863, 18.661999894726662, 6.666826105886891, 8.458252972172152, 4.428489285130655, 7.072119712829591, 8.36997316729638, 14.458185934251356, 20.965496109377955, 9.113866359956804, 7.746745809431999, 2.190571667686586, 2.904785756141909, 1.565626556834867, 1.1567662896648532, 1.6383610281252092, 3.5877971447283223, 7.859723308394033, 15.15600206390504, 22.205278873443607, 27.493914519586873, 23.322607201914636, 16.022788997619383, 16.24956965446472, 28.7564548753923, 38.62327314192249, 44.41800240547427, 53.90075983539705, 43.80154701971239, 28.553809542809766, 6.8404105978627365, 0.2929228189731798, 0.052059286559421214, 0.07259325830325966, 0.01886499748985854, 0.0218716053096878, 0.023385425691582987, 0.03769112367843909, 0.04652381484066287, 0.04392472366171499, 0.059224817180825826, 0.04679561900575796, 0.055214059614245935, 0.03252517830039705, 0.0320042691554033, 0.09062832401644799, 0.0169789943573696, 0.056263783931612014, 0.022411879242187547, 0.0569437520818845, 0.0466415663850644, 0.013466232245968235, 0.09753429255778752, 0.01749749224062168, 0.0431669554522922, 0.03917716188176025, 0.031471305616921, 0.007325755037938155, 0.050562864034286434, 0.06635431485671191, 0.04225983457159131, 0.058363604118987444, 0.07283778590781075, 0.04430134397661013, 0.08041912990231669, 0.044723569505637696, 0.0243212767846642, 0.011076318501915422, 0.03484798753033242, 0.066927294997919, 0.040818371194144415, 0.03372640799610846, 0.013634849155712272, 0.07848056739256268, 0.045626293041653214, 0.1592521360444446, 0.11756749177772192, 0.045758389582436894, 0.05311698968251867, 0.048857988984954935, 0.060528928654328476, 0.0320236511798876, 0.015370180988083444, 0.05383998899149799, 0.06505231012500103, 0.08533703133223519, 0.05424319638780529, 0.032164239805311926, 0.006951280726840901, 0.07332636614239986, 0.06419938230406373, 0.25398315200882576, 5.960809280795436, 19.90988627556832, 37.99904754084926, 59.86462562314926, 66.39234389028242, 63.109939790541134, 42.90184159432688, 38.64020209158621, 32.6734592453126, 32.32010860596934, 48.50787347362888, 31.017873864020075, 24.01816502694161, 9.597477932130138, 2.605627318543773, 0.9714380988190252, 0.47174658626317983, 2.793672608752405, 4.623843912155398, 6.271385002520777, 12.376032990794029, 12.5437339275114, 11.929361320311024, 9.629248149933355, 10.552216172218323, 7.939016963205031, 7.12689757347107, 7.614565366698851, 15.25473596588258, 23.50909236938723, 32.60961482601781, 40.11370320473948, 46.29982225356564, 54.25702479577834, 59.07190676658385, 63.60350731880435, 63.00826018856418, 63.204531669616706, 63.256875699566265, 66.50140147055349, 66.5091363845333, 62.868741481534904, 62.625154449093735, 56.58837572220833, 59.12521569959579, 59.25302220929054, 64.5308340749433, 65.64015488470754, 66.86379709551412, 67.21526499717467, 68.14620033387216, 58.09795871857674, 59.81911828441005, 65.17117277268441, 59.99437762844948, 59.779074807320875, 53.04098806073589, 50.64883255189466, 46.860948685676824, 50.84589635172198, 52.69613719755604, 60.266029219473566, 69.99593519395398, 64.95390092172931, 65.06717504993563, 61.941520629390595, 58.06253187118038, 58.263910278197265, 60.77297203002438, 59.23450862207721, 65.30146998743858, 67.44358616490518, 68.26017656633931, 65.11314915072533, 65.63169040987569, 64.93428907086773, 64.61631428810858, 63.239087750834805, 66.04326863442698, 61.38595219581359, 59.01627579042989, 50.32308755382415, 41.22290242102839, 30.45687883130966, 25.621835877818448, 17.79626807858867, 6.946018943863531, 6.767750161309396, 5.962571895891621, 12.284036740179985, 17.081059178998395, 21.569258705262218, 22.622834790137507, 8.790291413184136, 12.610845681159729, 7.132803192061763, 2.8441030123541435, 2.876571902344304, 0.9874410626869049, 1.6257004752274484, 4.613846280882436, 9.356600276885494, 15.88083940167581, 21.6942685650241, 28.806231714064076, 29.397095595636678, 23.987131234138246, 23.794670335708126, 34.577003140603345, 46.82841654746763, 50.21013113760179, 61.68383659855012, 51.41190221232753, 32.2084249988679, 8.70505536756208, 0.32706784805463207, 0.0943611563754178, 0.022979996640295274, 0.03391351731073472, 0.02787998310410448, 0.016282765990904263, 0.022631909270139954, 0.007281564213635941, 0.04379011435253967, 0.03021328773860249, 0.031128123124700882, 0.01820247316162192, 0.020016352946479476, 0.0667417561635375, 0.009814097673722334, 0.029920136533497326, 0.015505697153839133, 0.12439173405929921, 0.040331169917819, 0.04903979697114518, 0.010508689484859427, 0.038404083405170715, 0.03715375130395255, 0.09894220894503017, 0.07298537274642337, 0.06627779033395552, 0.020727985425882285, 0.08479056549408744, 0.025984547514047836, 0.03169991008396591, 0.01016544379038556, 0.19633181813743808, 0.15407621620162842, 0.09926578150160852, 0.14156762450452776, 0.10541910696173869, 0.08187644363891694, 0.11889722889229176, 0.1364398149833564, 0.18893612789050226, 0.07037580148467133, 0.12730666796766943, 0.15896194193872715, 0.14134605655506735, 0.15400516920753066, 0.1774916936072611, 0.1929160772312072, 0.15496588942985381, 0.220596166928449, 0.15392754917904256, 0.1539388872803219, 0.12316963995897001, 0.14341711397132567, 0.2712100179445359, 0.1669606659561396, 0.2279615200935833, 0.19709504089288174, 0.09690132007123002, 0.16454208041391066, 0.25754037403291274, 0.6241092169957777, 8.119436675502408, 25.59741520112561, 45.46142347397343, 69.07902625299269, 74.82612225317186, 72.44436494765743, 47.052046560472064, 47.48199324454031, 42.52186590625394, 43.61200240350539, 51.82832064167146, 41.34582165748843, 34.40749791360671, 12.981987211012072, 3.6692664892442766, 1.9396055537846781, 0.611936018591927, 6.512489664939142, 7.115621739818204, 11.6343294612823, 21.899820373904323, 20.281273934148974, 18.387630101173155, 23.158663895822343, 17.24414348602295, 25.36129047793727, 17.816558499490064, 17.531500247216997, 20.964817539338146, 27.730992378727084, 40.54451281024564, 44.1927485312185, 53.46900493867936, 58.82192234839163, 62.82465796316824, 65.317504636703, 65.24613318904754, 63.72188445060485, 64.38761265047135, 68.14666317355248, 69.00053962584465, 66.89749025529431, 65.61189812998619, 58.1620345577117, 60.92534434410834, 60.7010083044729, 67.82116920717301, 65.33028371872442, 69.57865776554232, 69.57602193278652, 67.16959291888823, 62.104185242806714, 58.80085529819612, 65.13172157349126, 62.732894112986905, 62.0811217061935, 58.63582941793627, 59.133786078422304, 52.710022387966035, 56.47397587376257, 56.87071184958182, 64.86030140230733, 72.1952473732733, 66.93796911547261, 68.3223775125319, 64.559098674405, 61.019434159801854, 62.845815227877715, 63.921368352828495, 62.566326741249334, 66.86252624757829, 68.76592697635775, 69.30344074003159, 66.2014264445151, 68.54301083472468, 66.60811347346153, 66.1303295627717, 65.51446645490586, 68.3701676707114, 65.58928566594278, 63.00427506046911, 51.67257116686914, 41.390277801021455, 30.831492639357048, 30.652228555371686, 21.02576921063085, 10.091605378735451, 13.66990622012846, 11.731768000510431, 18.036830963626986, 15.239844687523382, 23.075160557223906, 37.129426694685414, 16.841004240897394, 19.355425911564982, 10.215774870687916, 8.135155573967966, 4.509426413043853, 2.548757854007906, 2.787736591792876, 5.201332511440401, 10.50916619839207, 20.15930587245572, 31.715100657555368, 40.81084566731607, 37.68285743651852, 26.831594859400106, 26.68324689711294, 42.5530134477923, 53.54629916529502, 57.37551304601855, 70.13354762907952, 59.52163788580126, 37.647203091652166, 11.463766174931681, 0.7167764380574227, 0.2201653650451091, 0.15854566508243162, 0.11892006597331456, 0.1376325985597026, 0.1409102291349442, 0.2548904759028266, 0.23138879828395384, 0.13094679602692205, 0.1089967375681285, 0.20714963846389325, 0.21439381184116488, 0.07234101619331107, 0.1414426602423191, 0.09695983386688656, 0.12656983694121723, 0.13570159733776124, 0.3194793794424303, 0.113484495950322, 0.12573382817208767, 0.08210932670701897, 0.1956374820081457, 0.060406615056337855, 0.1675969326207715, 0.15192963783779453, 0.13701908470642182, 0.1714108400647679, 0.23169733253457855, 0.20021658871443043, 0.1734989352764622, 0.15524557280925014], [0.08857894688844682, 0.06816047439051252, 0.07815825122018015, 0.033456047906750636, 0.09681372557796779, 0.03268069797946561, 0.014445292613198681, 0.023848370709005865, 0.09318939425171384, 0.03143312379477486, 0.012777676250064566, 0.09701308463850329, 0.039647401971442085, 0.014706140763366656, 0.07874628498909936, 0.042793365015137586, 0.05394411183172657, 0.0775104855758048, 0.047947677348049424, 0.012044916023320008, 0.06956056902004827, 0.05501988696895781, 0.05611458447791877, 0.07790427775152269, 0.019605385079499216, 0.06814198102802038, 0.006323671334558317, 0.03189197790268208, 0.06918735396597656, 0.5584934798459853, 5.282308863055322, 21.12118870981278, 38.464358314391106, 58.00053096586659, 45.53730564732706, 39.34746819157755, 33.19371654141334, 26.165568559400498, 22.58889452103646, 31.985020522148382, 20.37833102287785, 23.75641545941753, 17.22374716112691, 6.903523985416659, 0.8084373873087668, 0.21168625793389736, 1.2355591068344733, 2.389027908925087, 3.964031627101283, 4.455185917115981, 4.1195786095434626, 7.7342393321375695, 8.865338121691059, 5.3383310956339685, 7.209152617762166, 2.5822085622818243, 8.034033929148029, 8.835434952089864, 19.073195688186154, 30.200771593278457, 39.43052830234651, 45.57439557967648, 53.259766101837165, 59.63941489496539, 63.21748333592569, 64.28088103571247, 63.829698639531294, 63.226873490118216, 65.10237047749182, 66.16825888233801, 62.88314050243747, 58.26065863332441, 52.7909997201735, 54.1345174081864, 56.50574314978815, 62.728430455730816, 64.38648300786173, 64.80274454239877, 65.61087046900104, 67.71322558003088, 58.49081547029557, 55.82194459053778, 56.17054523960237, 59.63568472093152, 58.63162071474137, 54.592312920478086, 49.812324354725504, 40.43170544408983, 41.48713288768646, 33.12628707578106, 52.10635000659574, 64.04060056132656, 63.74243374793761, 60.686189589961884, 57.656652850489465, 56.065684595415675, 57.08180596751552, 54.927930524272305, 55.320669604885964, 54.25471844211702, 57.30589489783011, 57.032364491493475, 57.72205445074267, 58.533475168289684, 61.91888463112616, 61.62016868591309, 59.89368254138578, 60.566808331397276, 60.92078262759794, 59.177748003313624, 55.73530727817167, 51.383068869190836, 45.95587745789559, 33.89221222169938, 26.872516947407878, 17.40433700623051, 10.572607594151652, 5.444151249624068, 7.80231696944083, 8.630887269973755, 16.042140010864504, 25.38490314637461, 15.625227362878862, 5.646713231840442, 8.94725682273988, 4.887331089665813, 2.362458508822226, 3.082538501870248, 0.5532113342515884, 0.6101044555825572, 2.305280893079696, 5.546447644310613, 12.737352905734895, 12.37922481952175, 16.763925744641213, 29.15216907378166, 24.16460671732503, 24.269465400326638, 16.414462174138716, 21.47450012545432, 41.47140418329547, 49.608741575671786, 42.75472525627383, 27.18953859421515, 11.324084689540248, 1.5818722786441928, 0.11345642648877637, 0.020954640199159904, 0.014509808707741961, 0.04286397150867889, 0.034815183645414735, 0.04243299725555605, 0.030582961551244223, 0.03533872813286801, 0.035666004724560246, 0.03782310530603413, 0.021391331383417693, 0.04473521404208676, 0.01875612298927961, 0.02482799606608047, 0.021220836600649263, 0.04109197566586156, 0.017080974066630006, 0.05069460817462495, 0.07213939717339893, 0.023432902075470458, 0.036783734666964704, 0.03243424366378496, 0.035445463332918384, 0.04839760461641897, 0.0662572744993433, 0.009142461687236304, 0.07224523222013828, 0.02767548359359705, 0.06592941185038897, 0.051119181763140426, 0.12403083003817067, 0.023588944609547337, 0.00946385663888988, 0.04114764727531903, 0.06587616107877224, 0.011399914041131495, 0.014178220956255833, 0.051658212717983036, 0.031857729942027124, 0.028585465812695124, 0.09926076362570448, 0.027553533887370463, 0.03268304220851391, 0.02598029189562846, 0.05568400476007693, 0.10003162427775322, 0.019371479284018278, 0.027065851890872565, 0.046123687117811174, 0.03716441524785854, 0.05158833017753017, 0.04762497047082551, 0.039641483942227024, 0.11038870400478763, 0.0530917241027759, 0.03961447168201689, 0.029710688094999042, 0.05198718236398794, 0.05616759010139973, 0.692186547863868, 7.047713254728626, 24.00442888659816, 44.404874232507524, 65.23080064404395, 53.92023832567277, 47.40192982458299, 38.87517559912897, 33.11173116007159, 29.92604486403927, 37.81215444687874, 25.242825092807895, 28.113703919995217, 16.363606683669552, 6.7504127948514885, 1.5595837778622106, 0.6855147800618603, 1.0527444198246927, 2.344605595834794, 5.839434967887017, 8.177862830700414, 11.918425752270608, 14.275003402463852, 15.411770997508881, 9.016266022959064, 14.630065175794787, 10.11363439021572, 13.051920129406838, 9.85384306600017, 15.682950923519751, 28.236960480290076, 37.169411336222005, 46.10224462324574, 53.72989354595062, 59.0261640856343, 63.759115588280466, 63.56247932680192, 65.58460627832721, 64.00025898410429, 64.84614949072561, 68.01692685773297, 63.9986272781126, 61.06632217284172, 56.025468534038914, 56.45948663834603, 58.715037761196015, 64.70717991552046, 65.98080096706268, 68.28194572079566, 68.27283013251521, 68.36124820093956, 60.79571785465364, 57.6361466992286, 59.65075446713356, 61.204507274012414, 60.38143711705362, 59.318961174257346, 54.28473634104575, 46.802521059590006, 45.52895884360037, 39.231926933411636, 54.152760351857836, 66.47210921010664, 66.62882358797135, 64.40915038508754, 60.51082041955764, 58.70833050820136, 58.73447702777002, 58.09488750273182, 59.2085111525751, 59.2703277064908, 60.549110597179784, 60.08961277623331, 60.96645470588439, 61.414860063983554, 63.85607265656995, 63.89260953472507, 62.15636845557921, 62.02970727797478, 64.29422493903868, 62.99210002345424, 58.145462543733665, 53.89439382860738, 46.555121483341345, 35.94900900317777, 30.921815018500055, 22.840687151878114, 12.02753040098375, 6.291857813635181, 7.060380058903848, 9.454567355494346, 16.40229105949402, 23.78269926194222, 16.103793786418056, 12.171378424090724, 10.744118132898885, 8.725169281805716, 5.057700708989175, 4.24029347396666, 1.347788658834273, 0.8146282970424622, 3.4730256517087263, 5.869183694162677, 13.30453351620705, 17.92381375066696, 22.92311772223442, 31.14505083330216, 24.532976112058087, 22.60123625878365, 21.02082898539882, 29.36058225170259, 48.59965693566107, 56.371598089894945, 49.5025904716984, 33.77274859336115, 14.066263687226082, 1.6859301852603115, 0.033497738411589977, 0.029151564569122372, 0.053780548229453065, 0.008956970733350084, 0.018038361806482557, 0.016838888367337566, 0.03348198764386677, 0.04410404186215132, 0.01846421476183159, 0.015120946730847563, 0.03070119764625786, 0.02268652367826191, 0.012241011549298082, 0.06729723885655403, 0.039931260530025735, 0.0242541081106831, 0.013547901049136155, 0.02527109366060505, 0.03404262227817409, 0.039926510784895196, 0.044535540885502295, 0.07072392715922288, 0.05258686449979583, 0.03671011744788097, 0.013409213279373946, 0.06323175579910317, 0.010994146953547194, 0.041323908784937476, 0.03221725308967214, 0.026747211025306777, 0.29178842661842225, 0.21131585442250778, 0.17286257668127938, 0.11299812204895482, 0.32850751112545695, 0.1305857081446917, 0.11095095125417556, 0.14786716550588608, 0.21823906760302283, 0.1660037761734378, 0.2209716725854143, 0.19475162389778322, 0.17971374695339512, 0.10162399165452489, 0.2409160975366831, 0.1251610472137409, 0.15400657880931132, 0.13852213389210163, 0.1963653574667631, 0.11761680485740786, 0.18187276658511933, 0.15270216090063896, 0.143200648167441, 0.1778754270485332, 0.10512197209942727, 0.17992656617876024, 0.1679028162071782, 0.23261769524505063, 0.20505228891007363, 1.2992701655434025, 8.385646958504955, 29.43724301553542, 57.007739851551676, 73.8984424837174, 58.7381915123232, 51.28883000343077, 44.8868433121712, 38.708976930187596, 34.187652987818566, 45.369765527786754, 34.47314662318076, 35.566146450658, 21.174358398683612, 9.471876775064777, 1.6938257938431156, 1.178857078475337, 1.3211148256255736, 6.761092918534433, 6.8802128491863135, 16.427562890514253, 16.113734053027247, 21.825307107740834, 17.030305670153712, 13.377252298016703, 17.970950834212765, 9.701159904080054, 15.340445637702944, 13.758122286488934, 23.708811613821215, 37.363984430989916, 44.19894587609076, 48.43648633649273, 56.67487575161842, 61.89092597653789, 66.69295434028872, 62.992358899885616, 65.53065799897718, 62.564702879997995, 66.17452682987337, 69.37932291338521, 67.51205505863314, 62.843814819089836, 57.37395586506013, 57.78474961557696, 62.10393028874552, 67.05411834101524, 69.43398506410661, 70.10035653268137, 71.5164419912523, 67.46291560511436, 63.432699864910504, 59.73438724394768, 60.30615506633636, 62.59290472153695, 62.55799170463317, 62.87180485263948, 60.76628438888058, 50.15291160152805, 51.4995240396069, 46.038074647226644, 58.23537895756384, 69.72536225472727, 70.35259631372267, 66.5148473555042, 63.17273693699991, 60.481394798524924, 61.28060125535535, 60.37266277497815, 62.817111322956706, 60.12676938887566, 61.68055749708607, 62.2141057445157, 63.00925254821778, 60.70324797784129, 65.78394113048431, 65.99157964029621, 66.58315150968491, 64.98105549043225, 67.12719209732549, 65.32104653696861, 61.93615482699487, 56.85582253240771, 49.45981702496929, 37.40291787732033, 32.21299652130374, 21.22603954807405, 15.837239315432889, 7.635849618142651, 12.76558808742031, 12.218169358468826, 22.52767808975712, 37.78730230946695, 21.41549591095217, 15.340377976817472, 20.377428877738215, 13.543038137497442, 7.749708179504641, 5.212533820059992, 2.297807061864484, 1.8490846046516973, 3.9103890474765537, 7.811932169621992, 15.987691629317501, 17.994600765166744, 28.181494243683357, 40.102995134169056, 36.37122077326621, 37.171372521308164, 28.546382534888487, 34.06875025841498, 56.00209905255226, 63.24388480955555, 60.230798490585826, 40.90876371629777, 18.975532593265658, 2.6048818230628967, 0.1836438392919879, 0.09928579937906996, 0.12615058000289625, 0.11481299200245451, 0.10380182640566941, 0.0704024613444363, 0.16261196785396145, 0.12199299019430915, 0.06716416938410652, 0.17094335789161344, 0.12235630739239917, 0.15733064963452278, 0.09993101395065747, 0.1842950140276263, 0.10173046255424138, 0.09600361058067891, 0.11976947362023978, 0.2292445028621343, 0.11006822644342339, 0.0889318606125251, 0.17977602990163913, 0.13026045785555918, 0.15527843798120178, 0.11329799950603517, 0.09421371509351077, 0.14313073498347115, 0.12956074378903837, 0.09367347755018743, 0.1420121853269877, 0.11789177679606985], [0.05238950875918231, 0.013408985368216471, 0.04815337961659797, 0.036303454995035164, 0.09983592711749578, 0.1085847967694844, 0.0382120787887083, 0.08718431446581118, 0.02693137473186418, 0.01110299751387849, 0.037082171878747405, 0.044996017184589183, 0.022490546895912098, 0.031165659517770818, 0.021893622676631617, 0.04013566044910301, 0.045791492241645054, 0.06498958284576094, 0.060675159517315135, 0.014461592091397654, 0.027460272258688367, 0.024495607752713467, 0.0647809847648586, 0.013981761538513727, 0.03245321200079015, 0.04232155827565059, 0.03087384513609352, 0.02251332843556039, 0.0090926707602076, 0.49804638470372853, 6.415779705970518, 29.786322193761027, 53.67581975075507, 52.484654764975275, 48.69948125654652, 41.495569905927105, 32.1492285882273, 28.272212782213767, 28.083568349961315, 31.902752730154226, 35.585632785674065, 24.990610807172715, 10.765906899206101, 2.655803013232447, 0.5461548064504901, 0.43158911529087257, 1.1044829338788986, 1.032415510665986, 6.3714441753202875, 3.6206690582536885, 12.731964549710675, 15.098130433790146, 16.771184090645082, 3.4472157205304796, 13.77540817183833, 8.649018426095287, 8.303029094972919, 9.842680000489759, 11.915990940986141, 17.67242708513814, 28.458515559473348, 51.84597522981706, 60.97628808790638, 65.7073764647207, 68.39097192210536, 67.70987587590372, 64.14736355504682, 60.63786206706878, 61.86691322634297, 61.349646737498624, 59.89403555470129, 55.783521052329775, 51.77836925752702, 52.16637795971286, 61.283711694901996, 61.84838002727878, 60.78020488062213, 67.06441848508774, 64.22937639297979, 62.635999802620184, 62.59197511980611, 63.356358774246715, 55.66379854756018, 55.16074280585013, 58.19314679791851, 55.67142755754533, 41.849371617840184, 31.604123077084942, 41.84650044287405, 34.33897018432617, 59.61751237992318, 62.656086260272616, 62.36335977431267, 58.07843708222913, 58.08345379367952, 60.25121050496256, 58.671660269460375, 55.43785825852425, 56.27220130735829, 57.255696404364805, 56.813429555585316, 56.2512440835276, 55.98366391274237, 56.013842628848174, 52.68075366174021, 53.660059667402706, 53.34647793923655, 59.17862269186205, 59.401884002070275, 61.53436683839368, 60.218556773278024, 55.03223026952436, 49.5253872871399, 41.33868686614498, 32.53607823002723, 27.857932044613747, 13.094054229797857, 12.609201227464984, 4.875058973989179, 13.742535768016694, 26.30582663320726, 25.620674856247444, 25.12509515208583, 7.511702189522405, 9.06408756009994, 6.964199129612216, 3.0175690977804126, 3.599214428855527, 1.1802335852576842, 0.65403365319775, 1.5337732338136243, 3.134608211055879, 10.922736006398356, 15.207561619820135, 26.555936567244995, 33.91045516537082, 24.64547557215537, 21.1060542445029, 18.070924205164758, 26.620416410507698, 32.89899945259094, 48.51753034899312, 52.66378548837478, 35.259397491332024, 18.515224802878596, 2.965341513195346, 0.10535759776229821, 0.07179871021259217, 0.03670809497576087, 0.02560164527817359, 0.036745882262626005, 0.059391897126671776, 0.03771873731766978, 0.003360410684704661, 0.026877541733424992, 0.07228575061045348, 0.0034994434334352734, 0.04032604478960557, 0.06698652125534511, 0.12626714794145477, 0.005190149447204726, 0.03221265273168683, 0.06301612886149557, 0.0652446671419086, 0.07299559235933327, 0.033753106160269636, 0.062359813675885244, 0.0675807067102963, 0.016847060610269828, 0.07195303862493846, 0.07824543202596326, 0.010668637152130326, 0.058952495906381845, 0.03069515704297491, 0.05680295661272061, 0.04559645774744211, 0.03685293921960458, 0.0642141601401231, 0.01852725996756025, 0.02840023341348335, 0.13640788443867238, 0.08199760810502114, 0.03609481860973662, 0.07042906757804655, 0.03966673036977168, 0.04071215693388255, 0.02035587736886115, 0.0074432379727612345, 0.11206634462841096, 0.06156253065132807, 0.015824157988742715, 0.05047191407591586, 0.07698576131294813, 0.06848755562978406, 0.05332959057282537, 0.02331865538332251, 0.015425067357418519, 0.018268331825252504, 0.0965935902129258, 0.07261291611939669, 0.03728985831501984, 0.044304232128084674, 0.06091371929693607, 0.04140907860991936, 0.08396765682846309, 0.5282999322779718, 7.6471533986829945, 34.7929923765121, 62.550366617018184, 59.66353354915496, 52.53081713953326, 44.344273613345244, 39.90605685018724, 34.57270422289449, 28.893896687415342, 30.964778700182517, 37.37233515708677, 24.169770517656882, 10.346754577852066, 3.4379375990360015, 0.7456097811941178, 0.9057073259065229, 1.1315841828623125, 2.6891647327330808, 8.91184566482421, 8.479767172567307, 14.412168687389745, 13.33869637981538, 15.340597629547121, 10.489202314807523, 11.773081344942893, 11.94049692923023, 14.610399392343338, 9.370282484639077, 15.224864175242764, 20.698170892653927, 32.78635486479729, 53.06789552011798, 63.90880500116656, 66.9023383048273, 68.32483291625977, 65.72249327936481, 63.385027377836174, 60.44328897230087, 64.18223342587872, 64.87311970803046, 62.576811236719934, 58.47776966710245, 53.519650582344305, 53.717592993090236, 63.934272950695416, 65.18978834152222, 62.83657412375174, 67.73802280426025, 64.63065447345858, 62.048789608863096, 63.531523981402, 64.13753801776518, 57.10758378428798, 57.59301631681381, 60.577273215017016, 60.37113697298112, 48.436882495880134, 38.24586268394224, 46.81299771032026, 38.95861225743448, 60.18218855704031, 64.82394103080996, 63.10251082143476, 59.720203953404585, 58.7695743960719, 63.11670980145855, 61.348215072385734, 57.67313072758337, 58.837925618694676, 60.33420001306842, 58.70984454308787, 58.63770038850846, 58.423778241680516, 57.4695832498612, 55.736432998411125, 55.374861071186686, 55.866475259104085, 61.98545509769071, 61.90606240303286, 63.109704448330795, 62.915096052231334, 56.143720149993904, 50.968568478861165, 41.43754236159786, 34.42250097951582, 26.139957443360363, 16.40165073256339, 10.136802850231048, 5.688304083962595, 6.657900262263514, 15.601393080526783, 14.674584077250573, 13.074445320713906, 10.822209581252068, 11.480229343137434, 12.40611658942315, 8.8806765502499, 5.575281968039851, 1.4368024372285413, 1.0299550814013327, 1.3527476378986913, 4.05215012450372, 10.487454898895757, 14.762019591946757, 24.231392914249053, 34.447160920789166, 26.31656608273906, 29.816799009999922, 23.239770666245494, 29.240412596733343, 40.35474069656865, 52.730006863993985, 60.082238720309356, 41.38819502245995, 22.362965999111054, 4.2900619776018205, 0.06807029818094547, 0.0551697567495848, 0.03188770313206459, 0.049278349089886875, 0.07877169612554774, 0.03880965035228479, 0.033804924347467964, 0.008557746994249042, 0.024058912738016056, 0.06720360759044848, 0.04022087623936035, 0.026442074374626243, 0.04804875115833936, 0.04236936216212569, 0.08421597656823936, 0.01735641714936543, 0.022331292538212675, 0.1006119205586372, 0.03229468159617917, 0.022414491602009343, 0.0072140493636740554, 0.07179863360379973, 0.05339037964961702, 0.04807532291799303, 0.027990096751900933, 0.05334635257660862, 0.03506755215987083, 0.08595976888412431, 0.028292283964072986, 0.03886976910214271, 0.1931801477387067, 0.15253360623553877, 0.17004648343689982, 0.09358590603956292, 0.2295036397634014, 0.1617825091365845, 0.1211373465916803, 0.21630566086499922, 0.1386711533151327, 0.10205292428332953, 0.17837439543537556, 0.09565799767451902, 0.22951159175605546, 0.16633201420547503, 0.204803831274471, 0.15872836173061403, 0.1831669495591233, 0.16130966434796012, 0.07955971714710036, 0.10568408911386806, 0.08508650525923699, 0.18048423222236096, 0.18507538183081537, 0.21635688150361662, 0.1327064999889943, 0.14942426985550314, 0.16681540036393752, 0.14520234398303494, 0.24965530681994655, 1.1443441433291281, 11.887191918588455, 42.341264294039824, 71.46075217954575, 66.28542007938509, 61.831360863101104, 53.29165104896792, 43.86677211330783, 39.62429338885892, 42.1548967976724, 45.61615705490113, 50.26291839538082, 33.54738881511073, 14.684505712601448, 3.6450389892824235, 1.0849916959001173, 0.8462133054291049, 1.5486468615070468, 3.9204665970417762, 14.985579982880624, 14.643507138375314, 22.926673350795625, 25.785486967332904, 35.12924148190406, 14.483142014472717, 27.071179113080426, 16.020866055642408, 15.014361354612536, 14.513598238268207, 18.076458669477894, 22.908377455126857, 36.389244064208, 63.06292233928558, 67.64441936246811, 66.77895622868692, 66.54792862553751, 66.11346337103075, 64.82558450391217, 60.57302921049057, 63.447106730553415, 66.65299323297316, 65.19444811728694, 61.900014108227154, 55.242473233130674, 56.64357916001351, 65.06104046298613, 67.71080940000473, 64.48751541876024, 69.43040786250945, 65.56982286514776, 62.4362374121143, 63.89308021914575, 63.22300211075814, 60.0684751233747, 60.417373872572384, 64.55693744844007, 64.8268122057761, 49.842401089206824, 41.05888066753265, 55.26485819970408, 46.0647310749177, 62.71169370220554, 67.08095519773423, 66.30383168497394, 63.4576932076485, 61.68064378922986, 65.36139203656104, 64.73407168542185, 59.9549578082177, 61.67960043876403, 61.1516337240896, 62.25177618765063, 61.173481325949396, 59.770551496936434, 60.31345851959721, 56.775406099134884, 57.759163994942945, 57.20077145484186, 63.732639589617335, 63.953104249892704, 65.04670812237647, 65.03969492450838, 59.93651482366747, 55.17369447215911, 45.0804397367662, 36.83997146544918, 30.0533434267967, 17.75330439690621, 18.30394829473188, 8.996016786944482, 22.75153560023154, 39.69975194623394, 38.2664982734188, 39.07481247378934, 19.277288375362275, 18.11994206520819, 17.756783539249053, 13.952148210617805, 8.467457794374036, 2.5070132940046252, 1.473920684187643, 2.7533349539003065, 4.5662473382488376, 13.702340299083343, 20.929922173100135, 37.412300186772505, 46.50355800505608, 36.6873755762654, 33.31819688120196, 30.75698329556373, 38.713699463875066, 46.436658059397054, 60.86044872960737, 68.9007859076223, 50.7448168723814, 27.858973433894498, 6.520464824092004, 0.22874754162565356, 0.1989924108549472, 0.15767258531864614, 0.15312537851352848, 0.1781448142062272, 0.16929265291940782, 0.11710204739844608, 0.06802804077104216, 0.10551106049529008, 0.18445721016295497, 0.14280363076156186, 0.14634170058754184, 0.18692258835559894, 0.2335258158704927, 0.2115766613954498, 0.1322082210812838, 0.16434358703272958, 0.17289006391600256, 0.22642510011792186, 0.11054518512420117, 0.2093060533966749, 0.20553470979775154, 0.14225183295146113, 0.12763161182163224, 0.157293172613267, 0.19444483632762588, 0.17083048249684996, 0.15499143080124933, 0.18919410033812448, 0.21903320966709047], [0.02699525497343031, 0.09967684129913969, 0.039799428289575924, 0.05967835655375835, 0.08944163083909981, 0.019429154213397734, 0.02767095218352493, 0.05375787202689437, 0.04046931472276488, 0.04740006237801525, 0.04479157896111569, 0.05332462632307603, 0.034021934073778896, 0.07076672849155242, 0.03545614259858285, 0.02660671816087298, 0.05652450280444277, 0.01986652530068832, 0.029412716281630343, 0.09097091087530698, 0.007652631348689959, 0.057995330332027334, 0.026872811140492562, 0.044102697377844204, 0.047971479699856816, 0.06066936023172833, 0.005012579363650613, 0.0590029044917995, 0.14642750243506125, 1.1825042698652515, 13.950150743607553, 39.37925900182417, 52.373035876981675, 55.48574255358789, 55.44647178342266, 33.632861183535674, 24.659745154842255, 23.321220644058723, 31.999419543050955, 36.18980330805625, 28.656699195984874, 23.19646377717295, 7.348123663856137, 2.101654722805946, 0.5161302272350557, 0.9664687622458705, 3.412114675006559, 2.7100535602338853, 5.968146564499025, 7.225207859469998, 13.997780084609987, 14.05198920157648, 14.18984776543033, 10.604514114318356, 11.738545856168194, 17.72583996095965, 25.754635564742554, 20.75934417786137, 19.71468364038775, 22.970852967231508, 19.697470318886545, 28.03533692513743, 49.87756513780164, 64.03367365560224, 66.98455118363904, 65.00944952810964, 62.64535857785133, 62.37253812051589, 62.8082428439971, 56.92753914863833, 53.96874235522363, 50.544473971090014, 50.8907368875319, 61.12337696936823, 63.5436244933836, 68.92835232519334, 69.27955350568219, 61.06154472597184, 62.33226714595672, 65.44442076836863, 66.68359556505757, 62.97311182945006, 62.018179432038345, 59.54541529378584, 56.264591909223995, 55.17232948733915, 36.60624134925104, 33.83348257310929, 42.82667721471479, 44.2791191224129, 61.3338670422954, 63.007550239562995, 61.10178039919946, 59.9867799974257, 60.14587917635518, 60.61894055335753, 56.45158698481899, 58.34862562917895, 58.626662838843565, 57.66131262625418, 57.08111170799502, 57.684662495889974, 58.692931282904844, 61.37992351285873, 57.6510517058834, 52.292078156625074, 51.646942400163226, 55.90227865403699, 59.225812727405184, 63.16866943913122, 63.29010209729595, 57.10045291531471, 48.505339622497566, 35.51236683322538, 33.27550972661665, 30.64484665470739, 24.694544423011042, 15.27301323029303, 5.127490951168922, 4.585284071583902, 4.758550361279519, 9.479656796301565, 9.575038052374317, 13.601047050568367, 10.162180585245933, 9.201784326184182, 6.680294054169809, 5.84355051479032, 1.253956616405518, 0.4604310692558366, 0.9236016689289002, 1.9165235084872094, 5.752945724994906, 11.640870994137181, 16.987577330681585, 28.86822085226736, 30.067177626394457, 21.837101674848988, 20.916546890812537, 20.49712392591661, 35.32795659957394, 45.93881514764602, 53.48282344879643, 44.83296563548427, 24.50226003123868, 6.6764030629588715, 0.0951260875069326, 0.055047381864560235, 0.0671726499774283, 0.07793207142141559, 0.0760251560038136, 0.060708978468732494, 0.05253654401448946, 0.03166929912573147, 0.10509079232090905, 0.035054735508897615, 0.043259893408826286, 0.0753574261081315, 0.024445285352187294, 0.0832848426615519, 0.025997766361181295, 0.052854845886148756, 0.04121322057119781, 0.06558546135502477, 0.025562297087162737, 0.07540541385570843, 0.014299847947944318, 0.0484804033992752, 0.03404265675213068, 0.06059285486117006, 0.0788853376082355, 0.019279311245848096, 0.05933775003218363, 0.052969893140177575, 0.05596662991710248, 0.02006929345248688, 0.04524010045814418, 0.03980426996525738, 0.054154774519584836, 0.03608331962999317, 0.03911752576729463, 0.018535242603731253, 0.07264990284438096, 0.046611213981504404, 0.0509066115163507, 0.048030085426064274, 0.06369337356919724, 0.08944503993036286, 0.021562919756698034, 0.05141510620653149, 0.06405407840746545, 0.06352212227460358, 0.02855100717786099, 0.016589808285296444, 0.11448348226446299, 0.17075650904688144, 0.06833001730903503, 0.011964145458243307, 0.046983115194785985, 0.038423151333606055, 0.028543160522296548, 0.0832990535925473, 0.015344855078916638, 0.03762316784911579, 0.06919954242485185, 2.058587343462052, 18.358808525146976, 45.36460761101016, 58.739548652402824, 60.903080971010276, 60.220886661160385, 41.20004284766413, 28.141476262000303, 27.345203738058768, 34.807254114458644, 37.863584564578154, 30.47636124395555, 19.395636089386482, 8.765862891750952, 2.1501832671703833, 0.9056898591018493, 0.5291843654647951, 3.2458456485502185, 4.639830022088943, 7.941533163670571, 10.115986831726568, 10.583328412425134, 13.79313434323957, 15.733396526305908, 11.527767489033362, 10.050253791193809, 11.48303677958827, 16.741054404166437, 20.494172342361946, 21.418712254493467, 21.594528575097364, 22.799782714536114, 33.44984731366558, 56.02959878983037, 65.22026123539095, 68.8319012426561, 65.44917075864731, 64.37807344621228, 62.32357909602504, 63.812185256711906, 58.52470867095455, 57.586728757427586, 52.03881071459863, 52.152053463843565, 63.06492667044363, 65.8475580523091, 67.80090624286284, 70.15359878540039, 61.52319592814292, 62.05375925187142, 64.88020743093183, 67.2508095156762, 65.11658514699629, 63.423874532022786, 60.636285274259514, 59.8512307290108, 58.501096002517215, 44.431314929839104, 39.42527232631561, 48.359760853552054, 48.687710223659394, 61.56943282773418, 66.13374986956197, 62.74736373655258, 61.771026965110536, 62.02747152697656, 61.678549243557846, 59.17703805431243, 60.21122978579614, 60.46607402063186, 60.46111614473405, 60.694991388628566, 60.86538307128414, 61.377381816987075, 61.591178447969504, 61.24592750303207, 54.12824161591069, 53.511091970628314, 57.0808449868233, 60.47542887349283, 63.18063659052696, 65.80845986643146, 59.04281454701578, 52.79791878115747, 44.378433535175944, 39.76811493596723, 29.495311744751472, 24.475509466663485, 14.120408085084732, 7.13089790075056, 5.623438867830462, 10.71519261406314, 12.729282629105354, 15.158156425722185, 13.898172474676564, 10.662575979386608, 13.139147758483888, 8.439043164253235, 7.365489467497795, 2.931042592371664, 1.1918500522452018, 1.038087257935155, 2.339666106047169, 7.3893497355522655, 12.594552155463928, 22.264659635482296, 32.1988465709071, 31.96806411589346, 22.142432697357673, 25.98834999146, 27.807331508205785, 40.849139767308394, 53.02508284968715, 60.28867698484852, 51.17004102276218, 29.110144799755467, 8.098770197360746, 0.12247066133685651, 0.05832751371687459, 0.03267026386193691, 0.12215529358194721, 0.034267319696805174, 0.03660963735573235, 0.04682531640414269, 0.08973912576273566, 0.08056922950932095, 0.1644859261690609, 0.03167627244106224, 0.08703825980304711, 0.03577236071108811, 0.04467198114481665, 0.03598471262281941, 0.02718345596334867, 0.02697021347440539, 0.11430649297131647, 0.011124677802135628, 0.03135960616712128, 0.10038858294607171, 0.05892348032624972, 0.046643661635537306, 0.06685142164989825, 0.03180497329712155, 0.10626819285173571, 0.0419507832116177, 0.03977192956353388, 0.06333517766888104, 0.025722514800426942, 0.24291405484320658, 0.24827924436859547, 0.13311562158407705, 0.16916765801368222, 0.1371200704166005, 0.1534763693569168, 0.1428062814257799, 0.16693621242959655, 0.10238691563567809, 0.17977376228138325, 0.20323926522847147, 0.15369049093175322, 0.11277953418151987, 0.19444616932061412, 0.1467816955259731, 0.21223250926742632, 0.1731601252310699, 0.10573377757663689, 0.2453068538659042, 0.23902252737072208, 0.1080854070342837, 0.15829395923403003, 0.15585170157494085, 0.23216008028436094, 0.1873305148535198, 0.19107886049295628, 0.08158345331227587, 0.11668783131866686, 0.19987413209051857, 2.8451985793728984, 24.76908906813591, 53.761719657528786, 67.49693824398902, 66.44015758268296, 68.40417462010538, 45.0138339688701, 35.5988903968565, 35.60395417674896, 45.21320804472893, 48.68568235828031, 39.88792373288063, 30.27253527795115, 9.408315747014939, 2.706934295354351, 0.9737283952774541, 1.9872504616937332, 8.438857832262594, 6.429139298777427, 15.45293038891208, 14.324308576122409, 25.290450511440156, 25.46441939569289, 26.573959858186786, 26.06948814084453, 20.184967979308098, 21.518248281171246, 30.117925251683882, 23.115280520531442, 23.13586904156593, 29.2885910695599, 25.737889005291848, 35.3954174441676, 60.278439598698775, 70.14194150124827, 68.19805406755017, 64.03364619901105, 62.283833719068966, 62.08486364733789, 65.37923097610474, 60.7898578336162, 58.60218724896831, 54.42567102370724, 54.50315352409117, 66.42413077815887, 68.6626745039417, 69.34308805773335, 73.19687950995662, 62.6486925924978, 60.6560657870385, 65.25469572313371, 68.74738201018303, 67.67638667937248, 66.06750103735155, 63.07305382144067, 62.63309724869267, 65.99830258277156, 49.06408909828433, 42.076037545357984, 54.378998741026855, 52.47699829839891, 63.1275276983938, 68.29868639669111, 66.60860769210323, 65.04536274940737, 64.40771871997465, 63.57334036980907, 61.316624303017896, 61.76804596377958, 60.31006959176833, 62.62136936187745, 61.84801524685275, 62.8526754533091, 62.191501125212646, 64.46657780678042, 63.17919708067372, 57.976275028720984, 55.86522010064895, 60.23856870589718, 64.02427957903954, 66.42673523195329, 68.4230019969325, 60.0780104052636, 52.01693565614762, 41.443304323381, 40.994385134789255, 35.867796328759965, 31.20259200373004, 21.00765766636018, 11.170493498925241, 11.303779559750712, 12.84618789149869, 22.30127888341104, 14.970468071199234, 20.791766489705733, 22.851685477841286, 20.797514723193263, 12.032290197187855, 13.925946777866734, 3.42240501315363, 1.2702555353603056, 1.4188046416928692, 2.8303864838615542, 7.973094024965841, 15.444736557622111, 25.715572680196455, 39.42882991606189, 41.399048220726755, 34.108746667062086, 33.90071984260313, 33.51002039447908, 47.78860099854008, 59.736426876437285, 68.02048052510908, 58.993671171126834, 36.815127172777736, 11.490869752822384, 0.691779847106626, 0.14854106240935866, 0.2501473497719534, 0.28898898812551654, 0.18565811427129855, 0.15297232946801573, 0.17637689778160665, 0.17898744963590177, 0.2754781389188382, 0.22457663720894247, 0.18443934499256073, 0.18377729180839755, 0.17054323016876177, 0.15119348862959495, 0.12726119298848415, 0.1007626177142224, 0.11655943498255746, 0.2338596157008602, 0.09431522940435717, 0.11611934045269606, 0.18344390566550917, 0.19657552602791017, 0.16013290733098984, 0.20481967397274511, 0.15028219640014634, 0.2069629428367461, 0.13603686805694334, 0.12117804884309731, 0.19253303326906698, 0.16298615583969703], [0.04278097737340197, 0.011526001579759103, 0.02708774859896831, 0.02189944686007596, 0.03993337493269675, 0.01219789133287005, 0.021460392294571768, 0.003334618419513948, 0.06479875034382267, 0.1017592444775566, 0.016955982991344026, 0.04422532124144416, 0.09103884755243218, 0.050378164066182035, 0.06504771359745534, 0.06546557625575412, 0.08805567819264629, 0.03412498056047386, 0.08226085889844165, 0.032934456943504276, 0.10518665290287427, 0.02600093988040763, 0.04330656348517345, 0.03252755317296232, 0.03391964601412897, 0.018623633828434735, 0.03606228668603205, 0.03752008305802461, 0.16710135034255444, 1.7884896238965375, 15.414556860923769, 37.185316547270745, 47.95903974963773, 58.83684304452712, 39.830794411320845, 35.186406104795395, 33.12633414422312, 29.57988589040695, 30.043541423736084, 41.21814850837954, 38.50566871704594, 15.919958179996861, 5.015003258182157, 0.47694798619035755, 0.27213686175884744, 0.6271171846216725, 1.0166275417131763, 3.83954270712791, 6.722057980875816, 11.25404880892846, 9.35641102252468, 6.769650059361612, 8.668352769267175, 11.703987813765004, 6.267234644582195, 9.275402311355839, 20.856220837562315, 26.85315808942241, 36.808945517386164, 44.510185949264034, 55.05059088430097, 48.645313324466834, 45.32168903658467, 51.68721337472239, 62.29338076806838, 66.06642630792433, 64.57796919730403, 63.61543524649836, 62.69426268915977, 57.98604957519039, 50.86508850897513, 43.54021518461166, 56.74735723003265, 60.417766109589614, 66.30119585221814, 62.9304874327875, 50.670676231384284, 63.162781961502574, 67.20942066561791, 61.387619203136815, 58.076385682629, 56.87040982707855, 58.08724672563615, 62.52019574565273, 54.74799179261731, 46.71538952858218, 41.8065667921497, 39.71969719856016, 34.78625374455606, 50.67419851979902, 60.64814652166059, 62.668139703812145, 59.67837579788701, 60.88453208246539, 63.64930099056613, 59.55085954358501, 57.251966230330936, 60.271363642907914, 62.4541038082492, 58.54903128839309, 55.978651123662154, 61.698270920784246, 63.49967041323262, 62.71311360020792, 60.884987077405384, 57.419357299804695, 57.117781946736, 51.023316921726355, 55.175530141399754, 58.15260517981745, 62.57285748758624, 58.08372051485124, 51.89647182341545, 45.97270442593483, 46.08381340580602, 35.25109775604741, 25.749738485582416, 15.183784211835555, 8.431141549541104, 4.0003069321955405, 7.415543813859263, 6.149800352511868, 12.479377638909126, 8.161021153773032, 7.991771371133867, 13.596914833591832, 10.979629005155257, 4.562912833306098, 1.2785892236617304, 0.6238804937851045, 0.05978084762670821, 0.6802036457004086, 2.72659198891732, 6.371119108892257, 13.742108229667911, 24.14554399828757, 32.111473814133674, 32.612413437135764, 31.38095198139068, 33.15919183915661, 28.89491650366014, 36.78829031605875, 48.55520079212804, 42.65918024124638, 22.940597764907345, 8.0710351178723, 0.9182578072913232, 0.04322431245518308, 0.010403507528075529, 0.06044474325232929, 0.032318932109422265, 0.07838990854760332, 0.06298793682588205, 0.06092339881785935, 0.03348880582639287, 0.007224266582559194, 0.03195340666289051, 0.006123923005596285, 0.049582076138786735, 0.027597539892960942, 0.05035353050897679, 0.08686022863032357, 0.06312451881146239, 0.05399949615821243, 0.019113912862995942, 0.04507026642621045, 0.019115994706930175, 0.05275253867430072, 0.0648614316577873, 0.037406357305665175, 0.024313941492789218, 0.05155449590435432, 0.02425364079704929, 0.09230751213767836, 0.09597107482653472, 0.05408690295993321, 0.006032163388050732, 0.07662182358363945, 0.05304365591596692, 0.06188889942883004, 0.13252533551666046, 0.053771960383821885, 0.03486304881892378, 0.03965089150193719, 0.10250384363556102, 0.07409297500646884, 0.021230659763058348, 0.042900391328599186, 0.06784173584873639, 0.04610701321413921, 0.04038364694063221, 0.016622483850486817, 0.06776836760822805, 0.06472494543319748, 0.0459008168188795, 0.001408627651999855, 0.06912942239714247, 0.023970247636879646, 0.08873263944781597, 0.014933762722648682, 0.03625319196632312, 0.03603118734674589, 0.014090311409334743, 0.01799195986090889, 0.1330957492633212, 2.1570846774885735, 19.678033013497632, 44.43588056871968, 56.05371352164976, 64.13707910045501, 47.387703387968, 38.02249546973936, 35.09336356193789, 29.184583540885683, 33.423065370129, 36.17855395040205, 27.59641193574475, 17.282343449131137, 6.330533854423031, 0.6872351071046245, 0.3611910589520009, 1.5078756621768399, 2.732233092669518, 7.215182281309559, 7.707296571423931, 9.935595066316667, 12.856418413500633, 12.479233491805292, 16.116998445603155, 13.40342039062131, 6.334396408450219, 8.38733063590142, 20.326583193194484, 29.925358449259114, 37.73225968883884, 49.00245297339655, 53.289042672803326, 49.29186897893106, 49.83932595099173, 56.0350626514804, 62.55838001928022, 65.51853395277455, 63.85933999092349, 62.69168961432673, 65.07917750266292, 59.60284663784889, 52.39724082331504, 47.62574811135569, 58.34835106326688, 63.43213504360568, 66.36461273316415, 65.72874945978965, 53.80733682263283, 62.479701195993734, 67.03205108642578, 64.69885272364463, 60.5580065327306, 60.46181432662472, 59.41531811991046, 64.91935660762172, 55.78292485206358, 51.64639719070927, 48.02136621167583, 44.10113765347389, 40.8126695694462, 52.82366521896855, 61.335804693160526, 64.12330765878, 63.05997663928617, 62.495618174152995, 65.56490029058149, 62.408043415315696, 58.50253159000028, 61.29036011234407, 62.187763106438425, 59.574032906563055, 58.45227818335257, 62.50616150517618, 64.83737907102032, 63.86810256588844, 61.816953997458185, 60.08136010939076, 57.500691567697835, 52.43515837577082, 58.30018435755084, 62.01165260807161, 66.02026001099618, 58.99322402092719, 54.83959874799175, 45.72885459469211, 42.7840998864943, 32.56099312536178, 25.88828052243879, 13.632776083484774, 11.419448294947225, 6.256529515789402, 12.46401567612925, 13.474939907750777, 17.078958749771118, 17.273716195937126, 13.225975305803361, 12.24126329345088, 13.625291220603453, 8.342572469865123, 3.447237538714563, 1.2912013598026768, 0.47261802659880736, 1.004640226883273, 3.0006717722262106, 7.371127384324228, 14.927727964616592, 27.09137147472751, 31.138561271852065, 35.071017819066206, 31.27468320631212, 31.333087298177908, 34.3320668128229, 45.02235335688437, 54.903199980335856, 50.643309854692035, 28.30326226449782, 10.341684914404347, 1.3368863083662526, 0.0344794073082026, 0.043998781381355184, 0.11763232579875378, 0.02155657080302556, 0.15103922916516183, 0.009577544086853103, 0.01766059044448118, 0.07948796535211225, 0.03853752826070113, 0.08695917654662363, 0.03368362198553739, 0.06487931981081925, 0.04618630714474186, 0.05896677578529043, 0.07843465574326054, 0.02398822963568232, 0.027844195306721716, 0.02614043491532005, 0.05880943281696208, 0.032262034759285955, 0.009031067714996396, 0.03270742678714376, 0.04634659572113906, 0.013968412456433139, 0.011684080950104663, 0.01403788418223661, 0.024003153028447303, 0.10052738275619284, 0.07257623582958214, 0.1355556729099443, 0.13528306818296834, 0.19197630185273387, 0.14760494893116338, 0.12418148888935968, 0.16028313717294126, 0.1267853144916796, 0.13651754226415388, 0.22489627973446924, 0.2885298563107368, 0.08249898200794574, 0.2143019272555267, 0.1551450007865506, 0.2475265936265069, 0.16857119727759592, 0.11651681751132974, 0.19650562816569883, 0.1441411896338386, 0.28087703631289546, 0.07995881065125428, 0.23958667451816223, 0.25023345805464253, 0.21022984818104776, 0.12438673916603289, 0.22830507988410614, 0.12209520164516666, 0.12145834509283306, 0.15244621092513685, 0.4772723784610149, 4.427686179837873, 25.760556382517663, 51.85090957149383, 62.27424744636782, 71.27294125095491, 50.00197095255698, 45.17951880731891, 44.99522624477264, 42.51690410798596, 41.88242543128229, 51.76999107483895, 48.61997481315367, 20.770654332253244, 7.020063977087698, 0.9079183782300643, 0.9277496366731582, 1.750032745542065, 2.3011141102160177, 12.61654978798282, 14.74763822170996, 22.27120214892972, 23.46908223244452, 15.36644212661251, 19.66942733333957, 21.05812091981211, 17.70878157308025, 15.246677456363557, 24.497439438296905, 28.800106933040006, 43.27992669997677, 49.74256107884069, 58.12404640259282, 54.64609646028089, 55.63523192559519, 61.0060667222546, 67.89230531261813, 65.7091062299667, 64.79157363214802, 62.85273428886168, 66.25048745063044, 63.18580627441407, 55.70735254595357, 48.66982029330347, 63.383850666784475, 66.32300423037621, 69.20283194511168, 66.4140110631143, 57.33134715787826, 61.19386196136475, 68.06637225612518, 65.51789852880663, 64.18184118886148, 60.72423265826318, 63.65448636393394, 68.13124825877529, 57.34367124495968, 56.6946719538781, 51.3414329098117, 49.083402849012806, 46.78907517463931, 52.33897009203511, 62.97151542478993, 66.50332343193793, 66.13331056410267, 65.7319579585906, 68.40353135139712, 62.19689830656975, 59.48251616570258, 61.88854902021347, 62.86506622068344, 61.22832782806889, 59.92088810090096, 63.90723605309764, 68.24283184543734, 65.75455473315331, 65.62909772319179, 62.47790867282499, 62.36042976379395, 54.33770010548254, 60.28813177539457, 62.85670372747607, 68.62276830980855, 64.24326158338978, 57.49069736849878, 52.84339866330547, 50.5363154411316, 38.95148531083138, 29.568381578691547, 19.04446432667394, 11.996608395730297, 8.156465811114158, 15.852693453911813, 15.632119947864165, 22.9221430132466, 19.169789937234697, 20.442699078590643, 20.741826872671805, 23.397561734722508, 11.663376573593387, 5.492603798066416, 3.0224590676446117, 0.6433755928470243, 1.2253979617549529, 4.084718789785139, 9.047463574717122, 19.37327857940428, 33.565682749594416, 43.353510364409416, 47.31117794590612, 43.41064360833938, 44.77417322897142, 40.63389578173238, 50.45371424767279, 63.164900041395626, 57.86032584405715, 33.213257789611816, 13.461298884884005, 2.165624412798113, 0.21973105447907604, 0.1110062398196709, 0.1956091980419813, 0.1330484663166346, 0.18957195022413809, 0.13444259312124024, 0.12787061593224927, 0.2123653182699796, 0.11523136793966256, 0.2894512149355104, 0.12535462997132732, 0.2062559815784616, 0.2731059016960283, 0.19061208312069217, 0.25329620096712346, 0.17759088667169695, 0.1973601839234752, 0.06656483581830418, 0.11323478959140279, 0.15324056749382328, 0.15609167095634247, 0.10707903563255265, 0.18912971830896794, 0.09909114409838954, 0.2667607631414168, 0.17114577364296685, 0.1527802559036401, 0.29919315670286456, 0.1103887346483046], [0.06514231013434549, 0.05249570769768569, 0.0316620021382527, 0.06833829105861726, 0.04210354497415885, 0.026511679208206556, 0.06675166168039845, 0.03189636758648821, 0.043469318864686836, 0.020031536809138713, 0.021753049372965773, 0.0060647235612475104, 0.09771173384280936, 0.03308904199530521, 0.03498064714574045, 0.02868301561853338, 0.002032968961077953, 0.01713803612567004, 0.02505670012455554, 0.04901918154510279, 0.04118912327553957, 0.06657799720884332, 0.060692258599785075, 0.028632338902342225, 0.05389215574870187, 0.052050082013010986, 0.0296107595861559, 0.022513138828799132, 0.9021399302348014, 6.2365175831702455, 29.58681671850143, 42.820699522572184, 52.17895700085548, 44.857688334680375, 33.4409749123358, 25.867439008528187, 24.53837133223011, 23.8804780667828, 42.73975749169627, 44.54187477788618, 25.09889764170493, 9.778479626101833, 1.6218971244750486, 0.6003819418049628, 0.297949121844384, 0.869649651069795, 0.5075556502467202, 4.6304178045642, 6.184122072112176, 6.75554080355552, 6.818409533269945, 11.867885032007772, 18.58198158202633, 7.128267461253751, 6.433698073510201, 14.082867080165496, 24.28611586170812, 38.45110462557885, 40.7192857803837, 52.13864288022442, 63.03157475686843, 73.51838834824102, 70.10265504160236, 59.577115889518495, 55.247556624873994, 58.32946485088718, 61.13191204686319, 62.538905451374674, 62.86955341216057, 59.80663730252174, 51.00767450947916, 48.126760298205966, 59.0786297090592, 63.47749333227835, 67.29503031699889, 56.42532279414516, 54.438030412120206, 64.52465241955173, 62.485867161904615, 58.208789210165705, 54.36885156939107, 52.822445361844956, 54.79066718009211, 63.05745455526537, 59.92026052167339, 47.432838101540845, 41.62018360630159, 43.750920987898304, 27.500966941156697, 48.64093203698435, 62.23993847447058, 63.79372658268098, 60.56305854551254, 65.79265271463703, 62.06234924254879, 56.98078532372752, 56.32765577685449, 59.48957250964258, 58.653295732313595, 57.00623366140551, 54.45643809533889, 57.80144322303034, 57.97312536547261, 60.355655377910985, 62.10119247436524, 59.412042940816576, 57.181159603980284, 55.05162639002646, 52.66544072858749, 55.06365237697479, 58.01960152964438, 58.20401568566599, 60.819467806047015, 61.8773663428522, 51.95900617107269, 41.131801451406176, 30.8269936807694, 10.083812609795602, 9.982774315341826, 5.539874242198083, 12.789236057189203, 14.428540660488991, 20.226347023440947, 16.698422162763535, 5.86256028183045, 9.827484738442207, 3.94731693690823, 6.764691202871262, 4.723261287135463, 1.124649432397658, 0.6349982681774324, 0.5389472061107236, 2.110079973936081, 4.6421368660465365, 14.757635362686651, 24.025609685528664, 40.40468815834292, 21.182273741691343, 26.892677930093583, 25.527926491152858, 25.329946817890292, 40.5031749509996, 41.43408283110588, 54.68954455467963, 30.112733994760823, 11.941428492146155, 1.0731382932393783, 0.0021502194360965084, 0.14365956547760195, 0.019956933251852473, 0.03969584171089434, 0.05313498891829964, 0.09521067127465241, 0.0865880529125852, 0.029604138671270305, 0.023193777306005362, 0.05114509851761884, 0.017048164436052886, 0.0577231967491248, 0.03396078110522321, 0.042795605822316105, 0.0015012715025917599, 0.011742638795816851, 0.030945941670647556, 0.026597379549076, 0.06298827390456874, 0.05467646890470097, 0.025023440417322903, 0.128997347407764, 0.02923443613033141, 0.013940071033674383, 0.026247861509722088, 0.014582273922109557, 0.008760747845254598, 0.06584603084071029, 0.02011975374883942, 0.08975931984041968, 0.010087754813984278, 0.046388060230040745, 0.03555692146502195, 0.040531632144965475, 0.03609137504451698, 0.07243111579408569, 0.05106684263615359, 0.09460328612476589, 0.0769894078914677, 0.024092503778275945, 0.11435805834949979, 0.034801972459160516, 0.03573975217859111, 0.018880171776418726, 0.03222321708416266, 0.02162472198476955, 0.03618124481891433, 0.004819839302780888, 0.07453843215180021, 0.020826063832388293, 0.01963071769193536, 0.03369349302844175, 0.09258875833644022, 0.04399582428196746, 0.04288079096905647, 0.06642520863322482, 0.022263987883625012, 0.8172705649368225, 7.356467525805197, 33.49383277277793, 49.70172920534688, 57.075636079234464, 52.071217336962306, 38.53548265272571, 33.93819416722944, 30.510225026838242, 26.012807930669478, 39.660339970742505, 39.22194450132309, 28.076402179656494, 12.338903834742885, 2.142218404239224, 0.7175617088233271, 0.43858864615040444, 2.042121601200873, 3.3403642283331965, 8.154748303274955, 9.55278350460914, 8.835351601723703, 12.31708663125192, 10.441344495742552, 14.666555966100386, 10.708285320189692, 8.583717826874025, 5.498711418720984, 22.588023754858202, 30.794465464930383, 39.5961582276129, 52.93011442307503, 67.45168193694084, 75.17335399504631, 73.17053687187934, 65.38669524654266, 60.501026261237364, 60.41095687497047, 61.13386146483883, 62.45626895658432, 65.69933560586745, 61.31741269942253, 54.178063561839444, 47.73624912385018, 59.147043689604736, 64.86133690803283, 67.78133361570298, 58.08339888049711, 57.15526411610266, 65.19487957800588, 63.54611912081319, 60.96103399030624, 56.51725138387373, 56.52289959692187, 58.15668836716683, 64.27428360908263, 61.68620963250438, 50.20807189326133, 47.270746154169885, 47.04717105434787, 33.11652037405199, 50.32846904570057, 64.95418725475189, 63.16637485258041, 64.44854274872812, 66.4446133951987, 64.25233402559834, 56.4938779800169, 56.70896899315619, 60.28215800562213, 60.57262520636282, 58.933572615346606, 56.22492105730119, 57.90793165083855, 59.919683933258064, 61.09519473968014, 65.23838258558705, 60.678058516594675, 60.6995491827688, 56.32095244623, 55.860285758972175, 56.566069203038374, 60.60826778411866, 59.32603320767803, 61.019449849282545, 56.13230605279246, 52.814459416174124, 40.4420526566044, 32.94901163347306, 19.71549557101342, 18.569288792148715, 12.867852122552934, 15.543951930538302, 19.201478765856837, 20.845083267458026, 18.009211594058623, 12.043449340328095, 13.548979547715957, 10.46280280236275, 8.535040232443041, 5.264854315788516, 2.1189175642305806, 0.8266862758225011, 0.6727725315478541, 2.084222238871359, 4.899423266610792, 14.540683184900592, 25.16743909928107, 38.76727119568856, 25.547346145875995, 32.63420024225789, 34.38405390708677, 31.546878045605077, 43.85419307216522, 48.1996379360076, 61.31946802139283, 37.6286659702178, 13.807858920866444, 1.5997064377992385, 0.02831084052881887, 0.03824502056945236, 0.023015343937121575, 0.04144835593779722, 0.03844283213238082, 0.14688107245151075, 0.02027851972548712, 0.012078548240805826, 0.0243051506338581, 0.017719052529202837, 0.032069995668866945, 0.05758713187289335, 0.028457550196758205, 0.05900294279619571, 0.027229915365516662, 0.006309890849215369, 0.03320575549056934, 0.05418528014072969, 0.07434431313266678, 0.02063480232121243, 0.06628093895532432, 0.028466005892222448, 0.05959132896556009, 0.04726635322215096, 0.031722808452022654, 0.03673411898254868, 0.016965269892206116, 0.047325878253867554, 0.012422004609458871, 0.13328503426765242, 0.17774974266367574, 0.12188444319631785, 0.14392322229762233, 0.0820885197589955, 0.07496073812005982, 0.16829094699313565, 0.11774845706719546, 0.1962849641999891, 0.11908439949395196, 0.14817592958288808, 0.13623012139672233, 0.14348549497944696, 0.08974911554926827, 0.09566695324235386, 0.1586892299594418, 0.0940858090536729, 0.13004210747538075, 0.17808173452654194, 0.13666159743743558, 0.2603171976102937, 0.11959428463371531, 0.15286516908916736, 0.22358663710615329, 0.14878144547823938, 0.24143907511907242, 0.13045476839667366, 0.09409989741060043, 1.4347667271091094, 10.003201038606706, 40.23426117435579, 58.624364329922585, 65.82758534339168, 56.75309957996492, 44.53842309213454, 36.17116812736758, 35.154081852205344, 34.50438830160326, 57.41491325439946, 56.729961518318426, 31.95358664758744, 11.934004426002504, 2.575809950790098, 0.960686759602639, 1.0378938360560326, 2.6860327201504863, 5.715483167479116, 11.448945499235585, 15.858350492292836, 18.162992039034446, 14.467891839242752, 22.023855524678385, 33.96158718293713, 15.685372006508613, 18.66751866955911, 21.95895206543707, 30.741329116206018, 42.06053241606682, 43.76370791466006, 56.85662661829303, 64.95441082985171, 70.87052960549632, 72.0194467421501, 66.45517241570258, 61.328014865998306, 62.28491629323652, 60.298745709080855, 61.56658126461891, 66.72746335306476, 65.48264034332769, 55.823133068699995, 52.56613808293497, 62.90800440695978, 67.53478911615187, 69.63161760760893, 59.843495815031, 58.17746908433976, 66.65446804415795, 67.52776807354343, 63.51292017967471, 60.37707544142201, 58.859177020288286, 60.907430879531375, 66.84654651149627, 63.26913310635475, 56.16854875318466, 50.36455877365605, 52.12399675000099, 40.19712025119413, 52.376350279777284, 65.94383655055877, 67.56821555476036, 65.95384643923852, 67.86448001861572, 66.43915345591884, 58.2880053981658, 56.92102016941194, 60.52095190171273, 59.78627235658708, 59.06760784887499, 55.80325057429653, 59.40155844534598, 61.7394793418146, 61.895483770678126, 65.75517054527037, 63.83036544246059, 63.10574285445675, 60.60196061288158, 57.044825861530924, 59.62622396407589, 64.61297242872178, 65.0408402565987, 67.18483524937784, 66.66155184468916, 56.43756843382313, 44.64025566654821, 33.6987687695411, 14.865477988796851, 16.25626906271904, 12.341162139369596, 22.994067515096358, 24.354319995449437, 30.68539219517862, 23.864894490088187, 17.351747828145182, 23.509998436897035, 14.605280699268466, 16.31680790455111, 7.683302942783603, 2.483406754270677, 1.617683640891506, 1.2786907149899391, 2.3922170410233163, 6.182024094366259, 18.68833664924868, 31.041568902231035, 50.35022643304641, 34.33422411641767, 41.38046403085032, 37.58873231949345, 37.06028315328783, 53.313267230987556, 54.479925247930716, 70.7608836696994, 47.250369441124704, 19.384041563157115, 2.7924485841105064, 0.15745135444787242, 0.2928521550230442, 0.10169056469514486, 0.20646843308162308, 0.1744462183165935, 0.25759881121977685, 0.1819339157232354, 0.13321236316715518, 0.14531137361641855, 0.11197459027771989, 0.14288033148454082, 0.1163703031958111, 0.1665676628509837, 0.11312139325685079, 0.13836857922855886, 0.11090624236291456, 0.09524817127854594, 0.18060266941545472, 0.2621320905464311, 0.2002358788083638, 0.17294094747593328, 0.20797617072539948, 0.14344633256475772, 0.1381467814527212, 0.17060347532312717, 0.11724948868035309, 0.1625220750969264, 0.17292766351132624, 0.14371527539145562], [0.03437351097442931, 0.04648274869748181, 0.044052602888475505, 0.05086952136949666, 0.021923140044354146, 0.0546526167571785, 0.05373870450702887, 0.03318938036118785, 0.027859492167349786, 0.030250280209246184, 0.05990220361479348, 0.030050783252884305, 0.023429556186461163, 0.028775430720059142, 0.057184169624721816, 0.028025689196863005, 0.05667829878568169, 0.051659848315701376, 0.05239128608316664, 0.03155233282145233, 0.03707431564708391, 0.04493846482927761, 0.062125708697543996, 0.03842041639971637, 0.02000710243479379, 0.01976624822183963, 0.025062466851405563, 0.06828492537381188, 0.36791188702467953, 6.58406311465848, 27.798859188633582, 49.44890499114991, 48.55721689039662, 40.42450005008329, 29.864291068046327, 24.53769668456047, 19.756152899034564, 34.32679906968148, 49.11205968549175, 32.199729104195875, 20.831990395822835, 6.18111361419001, 1.1459814877279344, 0.09603604674339296, 0.33014706185748505, 2.284081953187143, 2.7319183224631898, 7.080269907751392, 6.058885205176569, 5.654266245903508, 12.479435493869167, 9.914763358331497, 12.26715289777325, 15.916241734258591, 4.236268141577321, 10.12587316574589, 34.63718014378702, 39.91524304113081, 46.304548709623276, 54.972841662745324, 61.9182413624179, 64.4116920809592, 65.97690997585174, 69.23043758638444, 63.34366990673927, 57.36296146146713, 58.75313966504989, 58.66034815388342, 61.29174863138507, 60.22946880709741, 57.144736474560155, 48.391351622919885, 58.881193284065496, 65.38609120153612, 62.94783999842983, 63.09796479440505, 65.25604894084316, 57.50865397914764, 57.27237432233749, 55.57977353372882, 52.05202517970916, 48.38098479855446, 52.218690610701046, 53.799460703326815, 60.27883575808618, 51.765805905865086, 47.30779294044741, 35.674945154497706, 32.78179510947197, 48.27606531881517, 57.45971456650765, 59.666149770059896, 64.04693911152502, 61.29860885681645, 61.128374068967766, 58.58309707333965, 57.96333120715234, 59.24287896002493, 60.378295298545595, 58.20330573666481, 58.3949762775052, 57.860588642858694, 61.83019199678975, 58.17731611190304, 58.55447161582209, 59.79176367482832, 57.57439682560583, 54.76240650300057, 54.39308004994547, 52.837295455317346, 57.157841113305864, 61.04932262051491, 61.16311057921379, 56.939623971139234, 53.696251376982666, 37.95115147867511, 34.52252534128005, 22.881544520778043, 21.073622126733106, 14.581650380165348, 15.1786772858712, 17.072529985058694, 16.936945415312245, 26.824789547151138, 13.660075779884094, 10.208590069124776, 12.61790986984007, 6.939163621394866, 3.770978450775147, 1.5460796702292658, 0.5450809963287846, 0.31429979769933614, 0.32896094324608005, 2.996495918881509, 8.805759279958664, 18.93861524520382, 24.00887489318848, 38.32409043465891, 18.040125754571733, 13.669647343697088, 19.943530405721358, 39.50341378488849, 49.830951690673835, 51.250802624610166, 38.92561335717478, 17.20146025380781, 3.0955784215081126, 0.10980604817309689, 0.06896570940772373, 0.03095092124215538, 0.07125556919603579, 0.036019355118755376, 0.05399084319510768, 0.009714181613807958, 0.04839796467774338, 0.010569408656127993, 0.04099506554344008, 0.03879960693959748, 0.08377420430582377, 0.03663326350731715, 0.04406563787450714, 0.01959954940473601, 0.021001218344956156, 0.006602031775870391, 0.030951536027714614, 0.02230538727505313, 0.09853985190631882, 0.08118534040066504, 0.06808630941856293, 0.03439017721722203, 0.04448948750993417, 0.058078676867749424, 0.03192355796214073, 0.032391856018934524, 0.06059931298237174, 0.02137985538631197, 0.04550058567415803, 0.0614184448345294, 0.03889806072918638, 0.03689275663946906, 0.05431487540444059, 0.019877156685857524, 0.07392838867681642, 0.04386753136772783, 0.016081876669740005, 0.014903709093379158, 0.027367211728086396, 0.036989379478918935, 0.07355199435785895, 0.04470895254804243, 0.025919384075208537, 0.03286371638457621, 0.019208407893236128, 0.06239804146330684, 0.014422196019891531, 0.08214632109288247, 0.011385696406866755, 0.09436613594692561, 0.06980949396928472, 0.11803430745438223, 0.07564598844657022, 0.07404953782116214, 0.031548404705620585, 0.030402992176072254, 0.6037788369482564, 8.432836994048088, 34.70462529889999, 56.37571265620571, 56.80602804307015, 45.395919892095755, 34.05061714110836, 27.25868998035308, 24.243873896137362, 30.794137947020996, 42.45154173143449, 32.46494408576719, 23.020284637328118, 7.179080786243563, 1.2128450288887949, 0.2012011495929572, 0.5776653510908927, 1.9230287594179956, 5.6137520843936555, 6.0081454246274895, 8.375570389532275, 8.723233592125679, 15.631340376792418, 12.810685538476514, 13.020272485671505, 7.839440732232987, 5.3052454129342115, 10.863439575318369, 25.019279410762174, 41.518425556921194, 47.26780829891082, 56.375736190426736, 61.76064052889424, 66.01939708955827, 67.03898583689045, 71.53799933771934, 64.79914380658057, 61.45909263241676, 58.26953495702436, 58.92261743545533, 63.26712485282653, 63.112505020633826, 56.77753594613845, 50.033730383842226, 61.441669464111335, 68.14015988380679, 63.64826940721082, 65.393759435223, 65.12768153221377, 59.79976530997985, 58.075467848008685, 57.56459874491538, 53.371534039897305, 52.31696167299825, 55.446593376898, 55.931692507959184, 64.25580140083068, 55.533924948784616, 49.94817956801384, 41.551710790203465, 37.881396047530636, 48.70210924456197, 56.46529174620106, 60.80229566943262, 64.14462966303672, 62.58238884710497, 60.1821767899298, 59.334132902083866, 58.36351102398288, 60.52494879691832, 60.24013373159594, 58.47812268041796, 59.76708019933393, 59.55410334371752, 62.28089194143973, 58.869163374747004, 60.38548892544162, 62.363371541423184, 60.73115564161732, 57.67044390401533, 56.23159693133447, 56.74155604454779, 58.507924848987216, 63.59366216967183, 62.61963959663146, 59.09039681957614, 52.402445808533706, 42.17681107982513, 35.14116940959808, 24.040328379600282, 19.60264309760063, 18.58250717962942, 10.22732723143793, 13.17093562695288, 17.59568395153169, 25.62975710438144, 18.165247401883526, 10.059938123149257, 10.255593792084726, 10.200526656643039, 8.314382395436688, 2.1528034104454905, 0.8105106663800056, 0.3814102030329166, 0.703496947403877, 3.3273919695808045, 9.594907799074727, 18.988050837670606, 30.60528955151958, 39.73322153091431, 23.866934122577792, 17.543130074777913, 26.045922540849258, 45.80829435779203, 55.566872858232074, 58.70606337824176, 46.30301114051573, 21.354118662495768, 4.023926219632549, 0.1989545201462123, 0.04945515452193157, 0.05449258098979631, 0.032289617754999674, 0.05261172405293873, 0.05101919962814258, 0.07748980120184921, 0.021061501803717787, 0.029741431203400417, 0.02233209310009355, 0.06654781334462666, 0.005772669298288923, 0.02296767220081341, 0.004429261823515258, 0.044582716579879486, 0.06810116386341472, 0.03958047269993732, 0.05599621240229857, 0.030128522025000666, 0.042711914547028086, 0.057883263160023964, 0.06615751452984349, 0.04380809060568291, 0.0684489218157626, 0.044914432651092934, 0.07895403271240574, 0.040455816253539056, 0.014778001725883975, 0.015100863735912549, 0.12908071309568422, 0.29839452536356065, 0.06720343139022589, 0.10504694144812324, 0.2480473342321573, 0.18523514180654482, 0.1946004900720812, 0.09937523248335046, 0.16171985846613685, 0.14646257394023482, 0.10112121581069886, 0.14226242028657468, 0.16896461407023092, 0.11262142895570687, 0.1405573690370206, 0.18568236861498127, 0.15162962248488782, 0.08345468435436489, 0.12732233446572097, 0.21533335739326095, 0.15737667619701357, 0.17598201010015704, 0.10891878046095373, 0.17567954326589263, 0.1524978912165088, 0.1991951330414703, 0.19226553068766672, 0.26450631959784415, 0.8928558026109973, 11.736698419817033, 40.84637057396674, 64.53860429025465, 63.032814225842884, 51.95780592579996, 41.146906498939764, 33.68785281335154, 29.60245324719337, 48.43287775593419, 65.27398986201133, 39.209949893336145, 24.977376730211322, 8.42437546099386, 1.8727231362173635, 0.36333221341333083, 0.8973222177836203, 5.7177130349220775, 10.030115362136595, 12.862972694058573, 12.903462340754848, 16.470640320931714, 20.894312935490763, 22.09473079250705, 24.56076414354386, 23.8617330597293, 8.395995151612068, 15.627268956553554, 42.13273540619881, 46.2749622714135, 50.39660846033404, 57.03263905740554, 67.58982781440982, 67.09826069493448, 64.08758663362073, 68.34454674874583, 64.73906094028105, 62.37266755873158, 59.75687419214557, 59.365194151478434, 65.47675286569904, 64.72469722071003, 61.30497878597629, 52.1049104967425, 63.63600415568199, 68.86022860004057, 65.81937974499118, 66.04493956412038, 69.0001630783081, 62.76682261497744, 60.39744823209701, 60.63865830821376, 57.522974552646765, 54.01221006147323, 57.97847547838765, 57.01805568510487, 65.95042613244826, 59.610275606955256, 55.44414974028065, 47.20006112129458, 45.29165544817525, 51.589860147045506, 58.103548096072295, 62.30939580548195, 68.11679824706047, 64.10315452083465, 63.666375067926225, 62.000654282108435, 60.311866037307254, 62.166864718160326, 62.93861850615471, 59.43139983761696, 62.54718557480843, 62.258538353827696, 64.4843892897329, 59.569216235991455, 60.18252195850496, 63.48647948234313, 63.826650957907404, 59.04737626352618, 60.301224647029755, 57.468175118969334, 62.11890197569325, 67.16804750504033, 65.05409394541095, 63.317746962270434, 59.8963144517714, 41.3125011228746, 38.04916366454094, 26.27742671197461, 26.415046991840487, 19.386410674741192, 24.28913804792589, 24.469884787836385, 29.895377812847016, 43.38840376946234, 22.741227611418694, 18.413421646241222, 22.420171806889197, 17.621816742804743, 12.100526690483095, 6.539125009890526, 1.110076601466825, 0.47228814913861217, 0.9132082459907379, 3.840540214892357, 11.220584127210802, 24.378577893780125, 33.564223627890314, 51.67327327112998, 28.847228327105125, 22.607380651658584, 32.50025914561364, 52.697682611403934, 62.82144946436729, 65.1733849894616, 55.96843727173344, 26.860802788888257, 5.368333795378286, 0.5045690411521543, 0.10139821788236018, 0.12248731608833037, 0.17909483984112742, 0.1687555333539363, 0.12228082474921981, 0.1776317038363026, 0.15978994508904798, 0.10429678049178855, 0.1538329373203939, 0.14987460698091215, 0.14016680209146393, 0.10614835371774052, 0.1404900758737518, 0.15549692625720657, 0.14987163455976596, 0.10568443385343398, 0.1253903296685988, 0.12209842687532788, 0.24825439247633183, 0.18149401271535506, 0.1845171182386337, 0.12963701550277973, 0.14666888141824355, 0.28136730194091797, 0.11932318143907095, 0.14487170043491548, 0.1400684517237448, 0.053308607424579324], [0.01189146669686682, 0.06291960178303622, 0.02256699864031567, 0.04298454225664178, 0.06012364515974637, 0.05450819769213277, 0.03313030732134658, 0.014441845217539419, 0.005404113016406736, 0.010952762883877563, 0.04914196245672722, 0.020448832562373533, 0.06720014487303073, 0.04635822110539002, 0.02548389564899187, 0.0600836668614178, 0.016204354976634347, 0.04963585551107123, 0.09950515333442919, 0.057495599687700315, 0.001999475836430887, 0.06684733840126185, 0.01939868115098967, 0.023993977210334232, 0.08914659505770092, 0.01479586593866829, 0.0452238517332702, 0.05777030349558881, 0.4255466733969027, 10.306253164045273, 40.14099505639846, 54.37569610534176, 45.41429619635306, 42.42785846033404, 28.669305693718698, 26.0365225807313, 26.18419589534883, 45.57346597794564, 57.06766974541449, 40.0769898199266, 17.379959475609567, 4.168208645236108, 0.6139100739552129, 0.5735855345283786, 0.736216685223964, 0.8775479562820927, 3.1468187945504345, 5.535278204948672, 7.614981137937115, 4.81742758904734, 13.947520794407016, 4.875096726802088, 7.59174648792513, 3.8924017933107193, 7.905537572599227, 9.881623252745598, 24.133553312670802, 42.058496705947384, 52.77568678702078, 58.33683106207079, 66.091184308452, 64.8600935166882, 60.95950034356887, 60.17994496130175, 66.78148223507789, 61.45847682029971, 58.40288769814276, 58.162438561839444, 61.910549594509995, 57.997718626453036, 56.48431131916662, 49.08212807870681, 45.792200872975016, 58.50877208094443, 63.62839083517752, 59.17329219079787, 54.53160247495098, 56.49411724459741, 55.01293613064674, 49.26163927201302, 44.222915480213786, 44.98987220948742, 50.213959370889974, 53.21025010078184, 60.24746856381817, 59.65715969762495, 43.13913714501166, 45.538011673958074, 35.870416472035075, 63.59728251734088, 59.32443288064773, 57.815375481882405, 61.54250183413106, 61.9129147837239, 59.35983227145288, 54.408796987225934, 55.80247786737258, 58.1236659326861, 59.23074314671179, 56.56114270610195, 53.86356399905298, 55.11334880705803, 58.24314917287519, 58.77111588754962, 58.10715667663082, 57.455313667174316, 59.71219447351272, 58.316434737174745, 56.276559060619725, 55.40742851072743, 55.049625981238584, 56.60660297639909, 60.1097619918085, 55.848451968162294, 57.801219647930516, 53.150626151792466, 44.011421280522505, 35.99365734284924, 28.89544406244832, 29.15500298623116, 12.337458441334388, 20.847491602743826, 18.909652463851437, 15.844265261004049, 12.496609591668653, 6.553507851016137, 7.228871353210942, 6.737041925230335, 5.2110026248039745, 1.7415812635614027, 0.9665936652210452, 0.5273342324841408, 0.6776558824123875, 1.5274806488906185, 6.7820594579942775, 18.549290587825162, 30.368596084656257, 28.74282660022859, 28.4919027743801, 24.684911081867835, 23.035115118949648, 32.68100196315397, 44.88916143294304, 46.744705323250066, 40.73158633324408, 19.994715375284997, 4.201035941800764, 0.2031479781914142, 0.030291804089961998, 0.020321119959736546, 0.07295929511348087, 0.04035566174875825, 0.03051440051246074, 0.04294957800377761, 0.010924538289527259, 0.018505928249308662, 0.02933046716685978, 0.02220273915407879, 0.041525642718038255, 0.04898635850798699, 0.051384589094067776, 0.042821415324485114, 0.04303882341651667, 0.03023622632627526, 0.045880136275363546, 0.03196194471280662, 0.033024273091746915, 0.05165880643612435, 0.042878531009679845, 0.0653658316080128, 0.006025148416689087, 0.02438739783340885, 0.049453538076411334, 0.03169519481279197, 0.053055032321642485, 0.06274970263362893, 0.03439060239602001, 0.017850545775746147, 0.031975692160607826, 0.07879766650618085, 0.09118664889566361, 0.062174818763929995, 0.090263398033717, 0.020860047492709373, 0.029103580651985064, 0.06512001697574893, 0.016233516113472082, 0.029316955291095282, 0.119697354103048, 0.025439305501359127, 0.05331268684277612, 0.09139670254362207, 0.021648436236465653, 0.08518668657709515, 0.022724425878315684, 0.047510831030986966, 0.052046554178119674, 0.046673987226019946, 0.03242655597146481, 0.017481113280800563, 0.05399411822098398, 0.04087026215969555, 0.09476891433399531, 0.09096756307107788, 0.5702998753516906, 12.417976856231691, 45.072018408006244, 60.697917476777114, 51.54115999898603, 47.1922948283534, 31.27973718027915, 29.749689217536684, 23.344548940658573, 42.59573590370917, 55.352346666397594, 42.145243844678326, 20.386581728535315, 4.198333428752038, 0.5569065746761138, 0.25959823941511495, 1.3080085934169832, 2.008315060407885, 6.1887092840286995, 9.382127061966928, 12.925158931363015, 8.973216049132809, 13.615728482123345, 13.130105714644156, 9.752637090221528, 9.382441832173257, 7.689365456181188, 12.936795623071733, 30.233211555788596, 45.835472460716005, 54.60682961248583, 59.77134773808142, 65.69388743369811, 65.09653791304558, 63.20131140370523, 63.10841791091427, 68.94235518670851, 63.576431197504846, 60.873914226408935, 58.84733146236789, 62.233917636256066, 60.723052024841316, 59.0845799446106, 51.25598799797797, 47.687615656083636, 61.239659555496715, 65.06977558135986, 61.35774250953429, 57.85997283074164, 58.300509914275146, 57.89337965749926, 51.77904390519666, 46.54183249319754, 46.99336790269422, 52.840237232946585, 57.37485016545942, 61.27542764909806, 61.79880911304105, 47.89046495191513, 48.7690366468122, 39.55354559806086, 62.68763388356855, 59.22664034751154, 58.897792754634736, 62.92922835196219, 61.9705657805166, 61.30826180981052, 56.229541609364176, 56.24489768858879, 60.24992396754604, 59.95058436547557, 59.384821691820704, 56.01521153603831, 57.46935183002103, 61.91551531514814, 61.010408786035356, 56.99740440614762, 58.313065421196725, 61.73807121092274, 58.95709114689981, 59.49598166250414, 57.78129792982533, 58.03782486146497, 59.536750778075195, 62.15642336876162, 59.042504679772165, 58.29497937233218, 50.33972624809512, 42.10144665933425, 32.835427638023134, 25.380321818013346, 22.211313439953713, 12.961631090410295, 13.985708009812141, 16.084825204264735, 19.316782720627327, 20.712087462025305, 10.769469391915107, 9.09646672587241, 9.915097740388687, 7.687088029999887, 4.22377735376358, 2.025181252148844, 0.9113167442621724, 0.468547985318207, 2.04075759697345, 8.227889230174403, 18.181525238098637, 26.080307998964866, 32.12769477598129, 26.259060213642737, 23.89975259380956, 25.880494617646743, 38.82374940379974, 50.746338752008256, 52.47354269027711, 45.86263095178912, 22.485457697222312, 5.597754207349593, 0.3755380165192389, 0.022818547440692786, 0.09648225465489012, 0.013502866570507328, 0.020185315553399346, 0.02367078578249822, 0.03532407287087652, 0.022566843507511, 0.01336432435745073, 0.005669326431328251, 0.015783152174985698, 0.08027715848818903, 0.03204130950654226, 0.040022394349498135, 0.048180759599011753, 0.014820555994857945, 0.031895214624162165, 0.011268597952420674, 0.07056076575310961, 0.01635909516123995, 0.02608368695232897, 0.028091706823737874, 0.04708260703351229, 0.03325047204270959, 0.020031758974636757, 0.016225006791853135, 0.0200071943653447, 0.02852976164450088, 0.034791408106684685, 0.08743713114170298, 0.16127269294473434, 0.17974777657899166, 0.2798578635819497, 0.21068639061864347, 0.2178790216003695, 0.11203001673904159, 0.19948163460339272, 0.14301522424624813, 0.12797773034582216, 0.17333323045844035, 0.10285678800315627, 0.2281206212336979, 0.09348564811291234, 0.19081229253882365, 0.207947381141205, 0.07898792444217591, 0.199313095260051, 0.13195640798057282, 0.1753960294468749, 0.11070276174934641, 0.13085673473054363, 0.11743790800532988, 0.12823655315104032, 0.1718563048709785, 0.24009054586771997, 0.13265886464186255, 0.26301640115918656, 1.2594040531304576, 17.67313115058407, 53.101561223306966, 70.0507071710402, 58.809292316436775, 54.91276271881596, 38.11825229275612, 35.27273747228807, 36.76116320394701, 60.765609741210945, 62.79314171883368, 45.58229915557369, 20.6710143627659, 5.438804078486658, 0.8942787649650729, 0.8924269159474681, 2.2039342022711232, 4.518243410894948, 8.619685961354165, 16.29381399000845, 20.951765852589762, 16.760987889382147, 27.777229278318345, 13.890606222614167, 18.95884879173771, 13.637524112578362, 16.919316322572772, 13.070241520481726, 26.00659097394636, 44.912844704043486, 58.26267080922281, 61.62778592878773, 69.20316142420616, 66.66825909768382, 65.35255101419264, 60.72489161645213, 66.04241355772942, 62.71674179261731, 60.50363071503178, 59.396141652138006, 63.76192792769402, 62.892224711756555, 60.998018018661014, 52.72872424894764, 49.44174666558543, 63.63802025395056, 67.14783945391255, 64.76748635691982, 60.127451881285644, 60.85486327448199, 59.46855252788913, 52.910584941987075, 48.99298829417075, 48.31638336181641, 55.00959427125993, 59.828151502916896, 65.60833269549956, 63.34094385946951, 51.48339917582851, 54.5583922632279, 45.75930003196963, 63.09564667363321, 59.33323075694423, 59.402115421910445, 64.60728106960174, 63.388235876637125, 62.60322055509014, 58.21228011961907, 57.41559966917961, 61.1472838155685, 61.95534306187784, 61.046827993085316, 57.92424478838521, 59.813195505449855, 66.05940526531589, 61.63319095488518, 58.4228604070602, 59.47740923973822, 64.2489254859186, 63.156541470558416, 60.42629334234423, 60.373498239824855, 59.9510903512278, 62.266473308686294, 63.432574349064986, 60.51049486283333, 63.191485866423584, 58.27110390509329, 48.43363085100728, 40.975734264619895, 34.01095021155573, 33.799714888295824, 19.155488975586433, 29.499194891222064, 28.381452752697854, 19.71897275217118, 23.013153768354847, 15.229137597545503, 18.437958032854144, 16.24253684474576, 14.404573017551055, 6.352837922111635, 3.457758806405529, 1.6687172314813061, 1.0153311983712259, 2.329541733188014, 9.401146634932488, 23.27121630791695, 37.177134483091294, 39.03722832279821, 42.50735313661637, 36.03795659157538, 34.14740162511026, 45.85827319852768, 56.117816817375925, 61.02334476286366, 52.832871021762976, 30.120410073188047, 7.568540765393165, 0.6645158810480949, 0.179504650915342, 0.17872534031348844, 0.15780841270762105, 0.14217453467990124, 0.1362695442813058, 0.17192370528655668, 0.1257660498301829, 0.1223814044327986, 0.11810369203768431, 0.15279876458789074, 0.327393772501138, 0.09403427431900656, 0.16167865825756905, 0.1086234535661436, 0.1333406522509552, 0.13370681163524428, 0.059958074407111255, 0.16602098250821715, 0.11435447305801416, 0.20238824879690526, 0.11065570096815787, 0.2423598515170236, 0.11777464195244736, 0.13572275668622988, 0.17939943639982134, 0.07166037005522559, 0.13027625458855785, 0.20484081799945525], [0.03336489876551974, 0.11813097242866794, 0.05248249651143148, 0.07197144771775893, 0.039309105204959074, 0.10231494933607117, 0.06613377346507003, 0.027016923770368583, 0.08844624513820296, 0.052701471253268184, 0.0292793384587933, 0.03795044444080803, 0.02831179047784498, 0.06256805552590279, 0.05209922655335358, 0.007271919645474203, 0.018232195457864194, 0.08035946697477372, 0.013723266235883198, 0.11715678438063591, 0.023272130863680955, 0.1019760703427657, 0.042101606771710424, 0.029154847255877914, 0.029761498876576944, 0.023779838398519545, 0.1862852644896315, 0.09058194505351205, 3.1402728490291105, 17.791771081186113, 41.20878188840805, 44.53595199892598, 45.15181510679184, 43.21181866430467, 25.61526590777982, 22.751961177395238, 56.0291830185921, 63.17916962408251, 48.09332209248697, 27.203204131895497, 11.619154791678152, 2.4043636408544358, 0.18261817013544424, 0.1803484507986615, 1.0137040276200542, 1.241977575325197, 5.47267472551715, 5.558649647620417, 8.367131410106536, 6.645059402911894, 12.812845783848918, 16.741399572741603, 9.024022509974818, 10.010254440769073, 6.284141530913692, 14.655764545163802, 26.149310335036247, 48.000448211546875, 50.526254561639604, 63.1355607125067, 60.27415637047061, 63.567747069943344, 60.26710394890078, 61.43850803375245, 59.55667641855056, 63.85070685417422, 57.97591024829496, 60.26755109910042, 57.532337250248084, 61.89067886721704, 56.109615141345614, 58.490297717432824, 50.63235467480075, 46.69745252978417, 50.63574360262964, 53.660047900292184, 53.52188633334253, 50.52899237601988, 47.50187573894378, 46.10155036372524, 42.74191087292087, 44.339853102161044, 44.8069760107225, 49.345279893567486, 55.13043465152864, 62.44483916990219, 45.89749297788067, 50.63810879184354, 36.09623124522548, 44.231101466763405, 51.68189071839856, 52.64622895948349, 58.65143260648174, 58.395148861792784, 58.464908215307425, 59.22740128732497, 57.862228193590724, 58.380012435297814, 55.91418696988014, 54.069876747746626, 50.58512541555589, 50.37316837618428, 54.77404809767201, 59.27713301873977, 57.57556569191718, 57.50931685970676, 56.7895854673078, 58.78064724706835, 58.601241957756784, 57.47132085984754, 56.60264138252505, 58.363075640893754, 60.405234136889064, 60.53384081009896, 58.50484971077212, 51.644169284451394, 40.33178698632025, 31.248509230152255, 27.758954955685525, 26.980946948451383, 9.604340118746604, 9.015392315003181, 14.538703368556115, 33.66693873559275, 25.929845879154822, 9.446906966547813, 7.548553347587586, 7.321913405772179, 6.371541253982052, 1.3794289481255317, 2.1472485988370837, 0.6757763316554408, 0.22506590692266343, 1.2437093017562744, 4.424499744369138, 12.260457411889108, 25.30506330151712, 37.195420572834635, 25.57566369733503, 23.46908223244452, 23.693071142319713, 27.8321385383606, 42.10098774202409, 51.10057976938064, 47.80898947869578, 29.417209509880315, 6.428846101607046, 0.8439586167373966, 0.054545169095358545, 0.015314989141188564, 0.04150699996840089, 0.02553081470391443, 0.04684104035878855, 0.036410577069487304, 0.06476033869529925, 0.022103322008925102, 0.03676314988443929, 0.031027168058039203, 0.061352971130080765, 0.03540740025440051, 0.018096452338560935, 0.014941022363341144, 0.05559246491400465, 0.030149376853519393, 0.06818650605817957, 0.046777604448218504, 0.07491877948444697, 0.0975418232020832, 0.05828276652121737, 0.10896960273385049, 0.10925443422409797, 0.0323237891068622, 0.01981918872784703, 0.05060327134185261, 0.034366286765303344, 0.0584908819667274, 0.044861089948925285, 0.05887949155763753, 0.009158323537708532, 0.038307418430885004, 0.010507756772811615, 0.06010486068384302, 0.04102862402496319, 0.062029855776458025, 0.0536519795235607, 0.043019717183685115, 0.0772758175228392, 0.055687842860577576, 0.07246323019987153, 0.052236478865867665, 0.044558163461906296, 0.05487867398187519, 0.04856693303032268, 0.034158669276944095, 0.04861407425074328, 0.09222957801314131, 0.05602663758421137, 0.14040951406763447, 0.024527206964370225, 0.0243955317719449, 0.04452474287620956, 0.030178001728810133, 0.07323929258892614, 0.015677384160939726, 3.981152772903443, 20.15835665887402, 47.497823930555775, 53.74344925726614, 52.818844626026774, 46.74407382165232, 30.122804680178245, 23.636061453050186, 42.585420070155976, 59.23805444471298, 56.96659026607391, 33.13836797591179, 13.2421217426177, 2.930310825186391, 0.3275243138834354, 0.12030948899806508, 1.4305831515981307, 4.02147890579316, 6.9257500959980876, 6.558598106907261, 10.332043728520794, 12.712223260633408, 11.393600856104205, 14.043807137397028, 17.18741228503566, 18.055817196446082, 9.717145523717328, 20.132598453952422, 30.173209098077592, 45.31851976148544, 55.04417388669906, 65.12141358467841, 64.49414422435146, 63.83515857881116, 61.86446174498528, 62.44640419560095, 60.04820431432417, 64.21220817873555, 58.728475801406375, 59.58512536941036, 59.12288188934327, 62.08793486318281, 59.67731283557031, 59.06696065779656, 51.025725257012155, 48.85422660458473, 52.47003216897288, 56.72124993416571, 56.18583463853406, 52.003791793700195, 49.65314672839258, 47.63986864397603, 46.29282082280805, 46.51164985472157, 46.46686815446424, 52.30516710589009, 56.70312073922927, 64.67651874788346, 47.75081288429999, 54.00874268624091, 40.50492825046663, 46.87530063813733, 54.07304602284586, 53.4738019974001, 60.51498989905081, 59.59602171374906, 59.533350083135794, 60.077123949604655, 59.13332323874197, 60.37632626871909, 57.232985881067094, 54.434982730496316, 52.406481927441014, 53.48902863840903, 57.6831013925614, 60.61029564949774, 57.48759869606265, 56.5316504047763, 58.95414152453023, 61.87310664884506, 60.1512606682316, 60.16476146636471, 60.19829380896784, 60.07901453202771, 63.549849294847064, 62.484243300653276, 60.13915623387983, 53.00257236726823, 43.3659952686679, 33.81536122291319, 29.72178351494574, 23.04738429284865, 10.231100551543697, 13.630658003591723, 12.464301028559285, 16.40327459381473, 18.585756863317183, 13.968646680155109, 9.252599612359079, 10.950341647671117, 8.191888736140344, 5.380961866148057, 2.0553256475156356, 0.8002178767515767, 0.2222759679200188, 1.4307173702024645, 5.440327919298603, 14.941317016078582, 29.347693343316358, 40.42467655674104, 31.150065583567468, 25.444866380383893, 25.93182275372167, 33.475778102874756, 47.499337965442294, 57.57857807220952, 53.68319380667902, 32.84370187790164, 8.254004370781685, 1.0023451500361966, 0.044035997932716724, 0.02632074519961832, 0.02603110076198655, 0.003421200000898793, 0.014276874886314957, 0.11842639891490822, 0.056330854929382765, 0.012386709981177364, 0.022887035701123458, 0.043242553008660194, 0.06364774154198748, 0.05031212728710906, 0.06891572983154366, 0.011554406204771613, 0.04900369124727384, 0.028612834303790045, 0.07447384327890412, 0.050005067755738576, 0.06265153229657201, 0.05791979023225366, 0.02864876191221899, 0.04141725659851105, 0.0774404191742501, 0.008879478066979397, 0.06120569072663785, 0.04423630311183872, 0.04774446103481516, 0.027828898446093646, 0.17219755107596998, 0.24853223724470985, 0.12335608277710215, 0.10358302403361568, 0.09011402621024078, 0.20501810606689225, 0.1594406856043685, 0.20365733473050981, 0.1530995919939972, 0.1838066329758975, 0.2620277493711441, 0.11607342114251469, 0.18872222082028467, 0.16011845891273793, 0.14011938124895096, 0.10244626446717209, 0.24960088393380567, 0.18262725593822618, 0.12972943634996492, 0.24443644008809523, 0.2294651361843271, 0.19222468287954408, 0.12153635582616254, 0.2022990914842775, 0.13659649528563023, 0.23654358942181836, 0.2924034113605177, 0.2037594389290579, 5.368294571676563, 25.464340948289443, 54.702225577446725, 60.44348116843932, 58.59061625695998, 54.62314275003249, 35.280052692659446, 33.891455204256125, 70.58943686946746, 70.32847373716294, 55.46166312310004, 32.26024735358454, 14.705362915992739, 3.456941237372737, 0.8617119382946723, 0.4893687842113357, 2.483327816570959, 4.350720451724145, 12.110188468810051, 13.267153328464879, 17.37321888246844, 14.91628444963886, 24.814266927780647, 26.892846592010994, 16.291520384050187, 15.97196194433397, 10.68676523623928, 19.181551164196385, 30.098617384510657, 51.57526893000449, 54.72490864415323, 66.57697769903368, 64.5407380596284, 65.97893391886066, 61.19796476056499, 63.29867247612246, 59.24279659025131, 63.57008088019587, 57.54856409565095, 61.069063909592174, 56.69296180048297, 63.74237883475519, 61.0620467893539, 62.56719750742759, 55.116584762450195, 51.320930680921, 53.868423815696474, 57.827801550588305, 58.19763791176581, 55.52830419232769, 51.38528893070837, 51.48367374174057, 47.26084609185496, 48.23143266862439, 49.289621460822325, 53.2571969493743, 59.960507962011526, 67.33092784881592, 51.3767263966222, 57.08528903222854, 45.261531645251864, 51.59224887048045, 59.502237842928984, 54.35727665501257, 61.74694753462269, 59.33468595627816, 60.33035216792938, 59.43843656970609, 59.190119158837106, 60.766233398068344, 58.826589968896684, 57.09220024847216, 56.13586756490893, 54.68534761859525, 60.323025180447495, 63.36723942910472, 58.14665102189588, 56.887974200710175, 57.78844841064946, 63.776534834215724, 61.984345066931944, 61.592570889380674, 62.269485688978634, 63.56501710030341, 65.69471113143429, 66.60914113444667, 63.078898152997425, 55.872551010501006, 43.16817837376749, 37.19533820306101, 33.3344001923838, 30.58724468754184, 15.475005488241873, 17.00285888487293, 23.22019607790055, 43.5934692044412, 42.47525638149631, 20.10326304743367, 16.484609842300415, 18.302218529485888, 15.77689168914672, 6.844980649409756, 3.891186594001709, 1.1202393400092279, 0.6613895068726232, 2.0432729394205156, 6.153123090344091, 16.40032595203769, 33.11746174289335, 48.81256711098456, 37.22495994260235, 34.82137072470881, 34.48842817737211, 39.46089136985041, 54.727399349212654, 64.68054702205043, 61.55526522667178, 40.89609838301136, 11.914310205367304, 1.4078108509702068, 0.18716234323238173, 0.08357542747211072, 0.13424866562408788, 0.10595875461736035, 0.1578306292574252, 0.2109688319145672, 0.18275261856615546, 0.131168823629137, 0.12018561258070892, 0.12129696867158338, 0.17062305653047177, 0.11494431479443466, 0.19402540318908232, 0.12507450226093494, 0.15847947508577379, 0.112084140850892, 0.17355210177840727, 0.17968549363074765, 0.19487766068308585, 0.22699427280214526, 0.20448138486714135, 0.10716111429276005, 0.1489321962599793, 0.11728361023650055, 0.13879700623933347, 0.2269667702456636, 0.18272058076916203, 0.1524750311528483], [0.042251652752559994, 0.03184853114127632, 0.03304362830315386, 0.0406592087669959, 0.01540831397212441, 0.01564332293421631, 0.08811540240722318, 0.025158137826609518, 0.048489699876236345, 0.04265757593055887, 0.027777769738027168, 0.052402562897412054, 0.06047492328610632, 0.02699492747084268, 0.06394601021442683, 0.042834389023482806, 0.03289008130049033, 0.03063662601034007, 0.026777875609695915, 0.040286438043920264, 0.06852970578737798, 0.08881643414497377, 0.05475084838126937, 0.02905847722544305, 0.04300123531251185, 0.006036174337139294, 0.056562060264930616, 0.07899186979498594, 3.9940402104008585, 23.71554828459217, 37.379513094502116, 41.94896844125564, 41.62877359697896, 34.48417632810531, 24.69285192028169, 35.44125426200129, 46.7060778217931, 44.08486766199912, 27.244440009517056, 19.20614834754698, 7.306270993524983, 1.2556912846142247, 0.17162039575557556, 0.14202959084462735, 1.3641303561387526, 3.964853853948655, 5.433048000258784, 7.101604659711161, 9.240389274012658, 10.773347635422985, 5.586011611646222, 10.772275847773399, 13.410524783595918, 19.98181862215842, 7.685161165652737, 18.400030674472934, 35.98904855789677, 40.779964846949426, 53.31229840555499, 59.52743122654577, 63.933276668671645, 61.507565283006244, 60.529565426611136, 61.01721017591415, 62.29234526234289, 60.80339001071069, 59.8719447658908, 56.37279049042733, 58.09449918808476, 56.76907147130659, 58.518570161634884, 57.623744164743734, 57.77390426205051, 56.2634858008354, 48.23619442601358, 42.810909286622085, 43.685633136380105, 43.98684763139294, 44.60917480530278, 41.45694632684031, 43.24936359159408, 43.160184583356305, 43.706492300956484, 44.7985468372222, 51.76150698815623, 56.28114431135116, 59.085199679097826, 39.85274791717529, 35.28726985377651, 45.6038486573004, 50.052930385835715, 59.55697844105383, 59.75992579613963, 57.58731319058327, 59.76248710386215, 60.90253183918615, 59.029576547684215, 59.38936379648025, 56.19867647847822, 57.3322767596091, 51.716850803744414, 44.196160993268414, 51.817789077758796, 56.980804935578384, 59.87062292714273, 56.221449759698686, 55.67549113304385, 57.07303947018039, 59.211656893453295, 59.720953126107496, 57.73193490120673, 56.559381561894575, 59.08624695193384, 58.714308200343964, 61.0498050720461, 51.562011318822066, 47.626061900969475, 41.64072113652384, 35.22780279959402, 24.286215882147513, 16.66750604106534, 18.26960990505834, 8.583612903471916, 11.1444224849824, 15.316181855816996, 11.170316011674943, 4.998799456704048, 10.093138044880284, 4.829827181754574, 6.228900830591879, 1.6426663196855977, 0.5618114372895611, 0.09145978988418657, 0.6125203904605682, 4.030070612507482, 10.234908192388474, 17.314487272693267, 24.360960568151167, 31.30327924605339, 34.07082126986596, 24.115171124858243, 28.904802837679465, 37.10762616126768, 39.77852882877473, 48.78330230712891, 32.70180033099267, 12.046837287564433, 1.2280163889931095, 0.067817397235382, 0.03073866700663442, 0.10458351954096749, 0.030015650460676804, 0.052648733760560715, 0.04055344649860936, 0.01836468844914869, 0.0682075045281841, 0.06958702203607367, 0.02955992965237989, 0.07449095768313255, 0.05635042081496889, 0.019128403416083708, 0.07085773207607769, 0.02165539231481812, 0.043676637578755624, 0.11873039026414195, 0.031517623292823, 0.021534132087723385, 0.044674842483213836, 0.021675550003325748, 0.007077476954192765, 0.06191594616299676, 0.05235876182034131, 0.010907254388345586, 0.0451525327779593, 0.04932509577502647, 0.0759981667262412, 0.056006715467740456, 0.006886970518427271, 0.03840997079086881, 0.09834230081328461, 0.05317677518412952, 0.11183519291901782, 0.0735687027354875, 0.03395912252486714, 0.045720276708203944, 0.049091779867247234, 0.04927905772121684, 0.060335993241038055, 0.04884201222129407, 0.03999666145612155, 0.04776552079185363, 0.06595036435511804, 0.023585587229219176, 0.042160101415168856, 0.019457800156106392, 0.05685338435033637, 0.048956979036090836, 0.08397458226329858, 0.02042041453082235, 0.03538046843342243, 0.035499330805314165, 0.04045657085014447, 0.013678514252176449, 0.18813176621352473, 5.083212785182461, 26.573969664112216, 43.809838910256666, 48.6176331581608, 45.36387020541776, 40.99225921015586, 24.85197659461729, 35.17012042383994, 54.09946710832658, 56.50419381357009, 37.65156476728378, 22.07918251714399, 9.607340731928426, 1.4320218034328953, 0.28728937610022487, 0.27481669860501445, 2.04549103975296, 4.809528916112838, 8.620438075834706, 11.264902987787801, 12.827947889604877, 10.586902672244657, 10.80840087706043, 12.610894710786882, 18.73289869677636, 18.7754269953697, 13.348121835339455, 21.43518817040228, 40.85542732669462, 45.08652725527364, 54.48590294007332, 60.164514357043856, 64.29639793211415, 62.18041258473551, 62.263617823200846, 60.37911507391161, 61.30826965455086, 60.93567586714222, 60.47008660531814, 57.61786453185543, 56.92011017953196, 57.811590394666126, 60.70632311605639, 60.20327129671651, 60.26914358139039, 55.54517038406865, 49.237155837397424, 46.06670794948455, 45.791137910658314, 46.0074919269931, 46.31746899697089, 44.327744745439105, 44.09215150340911, 43.92705502048616, 44.14420135559575, 47.973834929927705, 53.175960740735455, 60.067267033361624, 59.75486986098751, 47.46950441791166, 41.749598287766986, 49.93236457147906, 52.74823411818474, 57.3411609280494, 61.40636421019032, 55.87154296136672, 60.611072278791866, 61.17104553407239, 61.39969618089738, 59.00171202998008, 59.192794215294626, 59.63993657019831, 54.218620869421194, 45.63532960030341, 55.24270857534101, 58.49960157948156, 61.055229709994414, 56.94702940602457, 57.623814767406834, 57.336222664002456, 61.34146859568935, 60.400688109859345, 60.34855196552893, 58.763565324967914, 60.96448959842805, 62.431024582155295, 63.467428530416186, 53.843422628218136, 50.35843203144689, 40.32231446235411, 33.862437509721325, 24.681890856835153, 14.937097526365712, 14.906201997110921, 15.355206497253912, 13.022348400085205, 10.704260968392896, 13.36927027471604, 11.369389045623041, 11.104681030396494, 10.564351004938926, 8.499699677190474, 4.556358552748158, 1.7728343413722132, 0.16872269882550164, 1.2809184986737467, 4.730973647486779, 12.067315001641552, 19.474846393831317, 30.521429277235466, 33.88690917722641, 35.78071578856438, 25.632490996391546, 33.06402337166571, 42.65668561381679, 46.00682904643398, 55.54217761562717, 38.79291957424533, 15.464530798696703, 1.5772301535452566, 0.06736723631019555, 0.04060947050851199, 0.11849077328318551, 0.032104709027935906, 0.05572793990253441, 0.04443244843353187, 0.0691187814358742, 0.062278914791081226, 0.032066638288538785, 0.03907101656941157, 0.061725232404686754, 0.02229036046041837, 0.02768253351772024, 0.025807554390461698, 0.09111800741764808, 0.055088421194663936, 0.033190123466474396, 0.011082480721656355, 0.042365439791953376, 0.031111790130155224, 0.03674814222200263, 0.012371748284016167, 0.07992398429421649, 0.06967753532432741, 0.021760292734289845, 0.05430772780410705, 0.05094079052909248, 0.053292772387184446, 0.17695249028263554, 0.19069307393604712, 0.1515567981668057, 0.20146932633173084, 0.16899495115203245, 0.11455423048427028, 0.2839636964903724, 0.14241428955668403, 0.11731374813544175, 0.10905625493896585, 0.18188336924199136, 0.17280605471422597, 0.15378272791783656, 0.13806421249624223, 0.3009558024425661, 0.15722333603808958, 0.11025520552310253, 0.09573939451647383, 0.16965784703291234, 0.15262287080047593, 0.14055082664614724, 0.23863831895493695, 0.13492443178209568, 0.12380961448915544, 0.0890765056735085, 0.15209091466761407, 0.15996807585320166, 0.37406985497763084, 6.8087580511646895, 31.987448469285045, 53.08324767697243, 59.1664868785489, 53.16953589839321, 46.003934337246804, 33.70497003678353, 45.453841532430346, 57.86014933739939, 55.85006798467329, 37.51508981950822, 26.1887478059338, 10.2841398216063, 1.8497042165648554, 0.3432967465731406, 0.36178817852370204, 2.538954625206609, 8.592093067784464, 14.201093200714359, 17.052217991121356, 20.930585053659257, 23.552116847807362, 16.299554378755634, 22.43409229863075, 23.696897414422807, 29.968267217759166, 17.1896166570725, 23.04961416029161, 42.17985483907884, 46.310142009489, 56.34543195847542, 62.580870889848285, 64.77956333468038, 62.55697581075854, 62.08252983708536, 60.40445358522477, 62.127907737608886, 61.03670043330039, 60.5512482889237, 57.232362224209695, 57.37345772404825, 57.003609595760224, 59.80316600491924, 62.87098507727347, 63.68823443689654, 60.90727006235431, 53.134846456589244, 48.1498356019297, 47.46365616398473, 49.001413545300885, 47.250400820086085, 45.190273946331395, 45.809192580561486, 47.52899892868535, 47.45797657197522, 50.005116693435184, 55.33068341593589, 62.4227640705724, 62.35806065220987, 50.5247954399355, 46.10837136545489, 49.60714517101165, 53.1256288866843, 60.307017987774266, 61.857170058834946, 57.268463719275694, 60.68425586146694, 59.82516265684559, 60.649495816999874, 60.19628163306945, 61.453185542937256, 61.72071080054007, 56.088987396609404, 47.86000382515692, 56.66596804895709, 62.02247050500686, 62.60026308798022, 56.970092942637784, 56.234228841720096, 59.840663863766586, 62.36921195060977, 62.23571408179499, 61.893350001304384, 61.534464897647986, 62.916151169807684, 63.94063895748508, 65.30707113204464, 57.39219880873158, 52.92776884571199, 44.778601584895966, 36.820230176371915, 28.3595561212109, 24.84169214002548, 28.269039584744363, 14.871220338729122, 19.466085780051447, 21.53594405420365, 23.140122852017804, 16.42798258412269, 18.826539401085146, 14.342367168395752, 15.452864689211692, 5.36854854514522, 2.2990117198036564, 0.5107149662029359, 1.3515069431835607, 5.36872701298806, 14.02807156885824, 23.202188476439446, 35.30231214338733, 44.172140398333156, 47.65238100482572, 35.149857459529755, 41.03182023571384, 48.92197770457114, 54.34699220042075, 63.37521753003521, 44.87134994999055, 18.527207643755023, 2.3644608787951933, 0.14385864108560548, 0.18176422724800725, 0.1860963931727794, 0.0840588825784864, 0.17007895024313083, 0.10081950740347947, 0.1602178205165171, 0.2346849835087215, 0.2802833181715781, 0.12832045510050752, 0.2166914474219084, 0.07166293644977194, 0.12051031894741521, 0.1616356807250169, 0.21561740747382566, 0.20737522071407688, 0.23450806316348816, 0.14356009662151337, 0.1281736956368531, 0.12272140957535276, 0.14435236943104576, 0.06819779819418346, 0.17855117788478253, 0.1290768979778213, 0.21480415917692647, 0.18983436598172113, 0.11765363070392802, 0.22339894556470458], [0.056442627157535286, 0.020147298440156926, 0.015508889825263572, 0.024594534601595615, 0.011047726185361465, 0.044085954526259054, 0.06571573460654867, 0.019745759200304747, 0.08943907210543271, 0.033614716207187985, 0.024857781564576492, 0.011461961417338781, 0.022230159356108597, 0.04425845071372967, 0.06553519832631273, 0.02691388877499248, 0.03607507652392791, 0.06665404675708664, 0.1565412879591027, 0.030175709210696722, 0.06746613060034092, 0.01312983250470772, 0.0302495313583002, 0.04638284700171602, 0.03613737096349078, 0.059575206645193605, 0.07463917271384309, 0.27851944669119777, 6.705757591032214, 23.074587891178748, 34.56492224047261, 52.39972760600429, 46.18407703215077, 32.55061257270075, 30.9785815208189, 43.90474457894602, 42.926258348649554, 22.278089830952307, 25.79238641646601, 16.93938709074451, 5.776858454750431, 1.4537719589087272, 0.31359193245730094, 0.269743817588014, 1.8339431526199466, 5.227996293575534, 4.676685592820568, 4.974033611436044, 8.708368789765144, 11.2023853102038, 8.628701529195233, 10.250434894715587, 28.66043133120383, 22.795254338172175, 17.028764178675992, 28.58123867742477, 34.80343372591081, 44.945008139456476, 56.00436618251186, 61.05589651292371, 61.810678205182484, 62.64935547305692, 61.55342955743114, 59.56059094398253, 60.23737238299463, 59.63825779576456, 59.61778302346507, 60.809736405649495, 58.587674479330744, 56.858807456108835, 54.86285055837324, 59.90719902899958, 60.81865195305117, 57.99304316120764, 57.438345493808875, 53.14936707096716, 46.56696704126174, 41.09961840414232, 44.135579985956994, 42.036798154154134, 47.39598351140177, 50.500629717303866, 54.03332418011081, 49.50241004267047, 53.96627126201507, 54.50638555711316, 60.11415896877166, 33.438448905944824, 40.094777768658055, 65.68172416379376, 58.61932800662134, 60.530848041657485, 58.32769978430964, 59.89218419597995, 58.911466137055434, 60.87559692321285, 59.50238297062536, 61.20861007321266, 57.660198673125244, 56.908527420413115, 52.63001388119113, 43.14130621571695, 51.2969296978366, 57.6625285610076, 60.25297164916993, 57.43366218382313, 56.63931162126603, 56.58617527254167, 57.75988178868448, 59.736693597609005, 61.84354374485632, 60.78439397196616, 59.868336185332275, 58.15764542548888, 60.007647006742424, 55.56974795556838, 52.21852587115381, 41.40505336946057, 38.616699249513694, 30.467784981573786, 15.25598131841229, 13.19782739685428, 13.443024562251184, 9.456276528296932, 9.097845438987978, 14.84892656726222, 10.164534987941867, 6.687858835343392, 8.855303718197732, 5.728008276031864, 1.0961708186134216, 1.8872897158707342, 0.22609353726429327, 0.6937826460888309, 1.4386751238376865, 9.501625011044165, 22.506273715726792, 29.34047029864404, 23.75801774763292, 29.942132465301025, 24.93524459100539, 32.33900462427447, 37.28420342168501, 42.247025428279755, 48.90324054225799, 43.5634316936616, 14.325168555782689, 1.2267091365591174, 0.11038412279900044, 0.08026775092847886, 0.024779504615693324, 0.01853813075520579, 0.034115898588131514, 0.023814030817799994, 0.03777188849785636, 0.05412639096199025, 0.08020470189231058, 0.011116768901927337, 0.04953234554118207, 0.01608216586793142, 0.041378036727227514, 0.06933124826079415, 0.03804492606450954, 0.09916727791630453, 0.03038238824134873, 0.04454769103998139, 0.06603824230091226, 0.02128133456402969, 0.009312184636421021, 0.022777906476309704, 0.026203447562311927, 0.030572201846347704, 0.049642895859095364, 0.02054055243910801, 0.061822682619094856, 0.030662885589164593, 0.030892359566003568, 0.023783253235442024, 0.025338836900529363, 0.026256391898758953, 0.06865816341052133, 0.017161825070938757, 0.016726122140103293, 0.0030068189728133863, 0.04604530866227804, 0.012423936108637963, 0.0206750659872928, 0.052950319593712214, 0.022431065914251154, 0.02942428995494641, 0.005784730395046814, 0.021402968258987513, 0.021277036810774478, 0.04506126106266053, 0.058862698910337304, 0.032267857027510484, 0.055884451665464914, 0.0502551686499388, 0.03391621777066781, 0.08036156605568626, 0.05563551905534922, 0.07854726300725053, 0.043425180708929416, 0.28705118404280755, 8.00121839969389, 27.533361796409856, 42.24814722614904, 59.52619567994149, 52.07158211738833, 34.62191820144653, 32.86238608821746, 43.33937806467856, 44.90383894212785, 28.362947010224868, 25.062192101632398, 18.957613245133434, 6.561808566893301, 1.824547605168435, 0.10751627265445649, 0.34098582702779, 3.4642294914491716, 5.932595181849695, 7.68530874483047, 12.338795969563147, 10.681063090601276, 14.834148057045477, 9.659503352257515, 11.017362206212937, 14.024936614498017, 19.594714026297293, 18.78964166487417, 20.474844863337857, 37.136961567786436, 44.58999441516015, 57.240438384394494, 62.22013050510038, 65.40501663761755, 62.80362229193411, 60.889784136126124, 60.555594275074625, 61.51930885930216, 60.25093593905049, 60.804527498060665, 60.36552013889436, 59.544152290590354, 56.53006968959686, 55.84446291769705, 59.89316478852303, 63.11928679866176, 59.57035372334143, 59.57428786062426, 54.11208537317092, 48.75187235493814, 43.32026435482887, 46.27479753186626, 43.17452084633612, 47.808401123169936, 51.78649640852406, 55.753193286157426, 52.005592161609286, 56.65044330781507, 57.34018033550632, 60.767445410451586, 39.78885642943844, 43.61066095290646, 64.25692319869995, 57.77757167816163, 62.209383210828236, 61.48049700644709, 62.179612421220355, 61.39320073589202, 62.16765311456496, 61.720467613589385, 61.80685389426447, 59.30045935415453, 59.333332738568714, 55.30683932765838, 45.28848225070585, 53.47035815638881, 58.92783811015468, 62.37734694634715, 56.99362716367168, 56.83718735171903, 56.21002389538673, 59.15327633580854, 61.27741629077543, 63.94487903964136, 62.79653064666256, 61.656266258608916, 61.46341116197648, 61.37439297091577, 58.81430118314682, 52.472440504258685, 41.58008521603, 34.41271466593589, 26.34509151981723, 17.897755484427176, 16.92698847862982, 14.11389793119123, 14.929738179329904, 13.00294247365767, 12.502682401287942, 6.651005225796854, 11.358581935205768, 11.212667803610525, 9.983616644336331, 4.565359901997351, 1.8320940002318353, 0.371175819947835, 0.4164188583531688, 2.4839438738361483, 10.005602509744707, 22.736644321872344, 31.987448469285045, 29.592690467834476, 33.37573020688949, 27.032900702568796, 36.470013510796335, 43.65636048778411, 47.56793237501576, 56.66101409542946, 49.038350505213586, 17.778103582320675, 1.5078967449165162, 0.12104360807326534, 0.021054363779483304, 0.04876756379681249, 0.024539795704185966, 0.033176211309769464, 0.029015312001349467, 0.017506183508122643, 0.042197436710158666, 0.045251633911844225, 0.022912896914227356, 0.05621676145481968, 0.08691403098524579, 0.030655799275865, 0.0771034860442723, 0.026441373404175527, 0.07995135661575102, 0.029986950891813444, 0.07300009695632804, 0.06683580111712217, 0.02500502749406282, 0.05287075370189644, 0.02931476044919222, 0.04276264105893431, 0.05993360555880974, 0.05996146051573658, 0.01669767921069457, 0.04034736118609867, 0.02250417943052467, 0.15536021020623947, 0.14081906467195482, 0.14608579657731519, 0.13529676583505448, 0.13674444218556728, 0.11457086991398566, 0.14633839108770894, 0.1551871509441445, 0.15356753381990618, 0.09590799514684947, 0.16107605349633003, 0.11469391895638359, 0.10240111124491501, 0.1162069732503545, 0.20356500581387552, 0.10981076727471045, 0.12367096789661916, 0.12856790916092936, 0.18667207760435922, 0.18299310888734557, 0.18053729147199662, 0.12422148633988635, 0.11452907215683691, 0.1265701357155077, 0.24034537735485265, 0.18054688289280862, 0.1711393231826444, 0.4514931214432563, 10.438276221675258, 33.43631513657109, 51.07438618136991, 67.33379117904171, 60.51890050211261, 44.23524348966537, 43.78646158402966, 56.383686834766024, 52.69159901526667, 33.60943286649643, 36.137361218852384, 22.70220591175941, 7.9304456037859765, 2.5160590150663933, 0.7722853304397675, 0.7635180976602339, 5.433588797046292, 12.010518100953872, 15.087636132394115, 16.798277862610355, 18.509898224184592, 20.407413436520486, 14.303099340008153, 23.4316804716664, 41.36088355895012, 32.028223468411355, 24.857254143684145, 33.06680433211788, 41.08084986286779, 49.660893409482895, 58.96523006500737, 62.182412993523386, 66.6590807514806, 63.49669333427184, 60.21645438286566, 61.551048678736535, 60.29241892599291, 61.4725189055166, 63.25050184803625, 63.86549026735368, 60.73391699021863, 56.72120286572365, 54.74626594974149, 61.571727414284986, 63.01496351918867, 61.681600847551906, 62.2395815387849, 57.75013469880628, 50.99856284356887, 45.37369182032924, 48.91612945064422, 45.58437016702468, 50.1785913590462, 55.00806062452255, 59.156371085874504, 54.91174682494133, 59.64751458937123, 59.84167191290087, 63.14302498294462, 42.20936675225535, 47.60725413599322, 62.84414429818431, 59.76671149653774, 62.417386501066154, 61.681636148883456, 63.62699447139617, 64.0341051163212, 64.70533640153947, 63.766803433818204, 64.0160818253794, 61.044906031700876, 61.096959806257686, 59.07991232410554, 45.89378633806783, 57.346067813134965, 62.485223893196356, 64.65360818370696, 57.731687791885875, 57.26734584377658, 55.89760711116176, 58.38282869708154, 60.95505629816363, 66.44052628547915, 63.41832045585879, 63.82994182648198, 62.48582009346255, 64.82328991736135, 58.88066768646241, 59.21832100037606, 44.59467380277572, 43.56476137715001, 36.053744131518954, 21.229634400336973, 23.024907150576194, 22.898497004662794, 22.939879971165812, 25.363712541518677, 34.540399582155295, 19.623984713708204, 16.616864319770567, 18.28061607576186, 14.949325515377907, 7.307603618791027, 4.131429560722844, 0.8826352091085528, 1.0888636881305327, 2.6199873608927575, 12.390913482635254, 27.77912770548175, 38.37741897952172, 35.66697882067773, 40.76742502950853, 36.054854162277714, 41.92304157441662, 49.74782489961194, 54.49926645525041, 64.39589669627529, 55.75680578908613, 22.166439563997333, 2.1838656404326042, 0.30882683492475943, 0.19983812595807737, 0.06332115442942708, 0.12305137130521959, 0.1838234562667147, 0.08731740692089643, 0.11271908984429414, 0.15123545492608703, 0.13714873742672706, 0.12578699467403273, 0.17980728628894976, 0.19779504607281378, 0.15539195688982166, 0.2059160377229414, 0.19395538275280308, 0.23908211368947263, 0.18085126494688375, 0.1521017471508634, 0.14139124042084142, 0.11247823946177961, 0.12512858806838914, 0.092533094387862, 0.13167877771681355, 0.1399766897121745, 0.12360787289517543, 0.10433375955589357, 0.2208096296676705, 0.09789239269711318], [0.04438556385256591, 0.008821376043582156, 0.036608162636478106, 0.08120633887066957, 0.04622245883388866, 0.014877846922665356, 0.06370658858589108, 0.02597988012336916, 0.08052085871778189, 0.05079078668307874, 0.010707948953964779, 0.05236319363898328, 0.016105418551653143, 0.020281381063884305, 0.03393473411579767, 0.12664011784739074, 0.02270212505883988, 0.035206895892418204, 0.04241125568026497, 0.03911989680942028, 0.0020197702237525054, 0.10896427076189749, 0.043306896733420516, 0.13865059151524498, 0.03478131106784267, 0.009869833443043454, 0.028896089568133318, 0.4003054552501248, 6.980038150664299, 28.371425213352328, 36.864086197268584, 41.2703787895941, 39.2769871219512, 34.844869644411155, 31.262484635076216, 56.591399869611195, 45.4600388773026, 29.160910075710667, 26.682140788724347, 12.99468784563003, 4.442385752354899, 0.9428356239391912, 0.2702923671853158, 0.3850839623520452, 3.15240032730564, 2.8920235893418713, 6.071692234085453, 14.575492258994812, 9.741467160563316, 5.531932423191686, 13.845950038202348, 8.481180206421884, 8.912224173545837, 16.668355234207645, 19.626608779353482, 17.650332373957482, 43.172928364046165, 42.24398559139621, 56.871072707637666, 59.10853385925294, 61.89124761089202, 60.70902170673494, 61.76413536071778, 57.89928674697877, 59.70023124448715, 58.1289650547889, 61.71510573356383, 57.48882247555641, 60.662863254547126, 59.22716202274446, 60.55304865683279, 55.45550107955933, 57.9810760098119, 58.1497222377408, 61.52502767501339, 58.81324606557047, 55.92884094484391, 46.79417425586332, 42.239486632808564, 42.35605162958945, 52.765147378367764, 55.27353840489542, 57.57326326062603, 53.416692287691184, 57.158904075622566, 54.76927065080213, 61.831823702781435, 32.4206958278533, 43.901139920757664, 60.79394494333575, 54.18107986450196, 56.15141191790181, 54.29859015249438, 54.634050861481704, 56.18894115571053, 57.808154398395175, 53.973711998231956, 54.07304602284586, 55.94136899517429, 54.81444851044686, 51.45676628235848, 39.73269985568139, 48.61548369930637, 54.17509040524883, 56.99474111680062, 58.886900332666215, 60.04257963549707, 57.04399824142457, 57.44657070406022, 60.78629632149974, 59.0275526046753, 57.49991886077389, 59.424543534555745, 60.56929511408652, 61.9621209175356, 57.62263805635514, 55.29176958145634, 46.57321145457607, 39.468226202072636, 24.79889515907534, 21.49004447844721, 17.70709691509124, 18.86783019188912, 12.465437535316715, 6.8337106993121495, 5.582900191507032, 6.162109240408867, 11.505837517399943, 11.035611033439638, 8.180052003552838, 7.321240228991355, 1.098768408260038, 0.26942353154863086, 0.33482920738958544, 1.7672059853230755, 6.234533844455597, 18.355827523816018, 33.9536012372663, 45.23960951835879, 42.91003150324668, 33.18729562144126, 31.10966124842244, 31.886922044138757, 36.67475731142106, 44.06420461593136, 41.59873608619937, 18.46406532872108, 3.4465511239344075, 0.032858568273725054, 0.04788516457342813, 0.016100115307997313, 0.020948651306811842, 0.04246572453168131, 0.10654020769100998, 0.03501566885519893, 0.03621309109392666, 0.10652228889446105, 0.04514877511669071, 0.05120988657337524, 0.05748684330272579, 0.025070752092306654, 0.05151838251960374, 0.09726215514444536, 0.0039697261367579026, 0.03035302217599125, 0.09939538059575904, 0.05573614853464308, 0.01501180697232485, 0.018800525445370905, 0.030457246522869796, 0.03024228991219594, 0.03697633300156843, 0.08136017698674433, 0.009856980402893838, 0.03232553578732956, 0.051727624114362464, 0.025581715500823436, 0.04764181291384082, 0.07565395576098273, 0.02105724618529841, 0.027887230295868173, 0.02225064454720386, 0.04448194920475926, 0.032735308557147944, 0.0729527144182113, 0.01708527181988522, 0.058968943814116145, 0.03316224169647021, 0.06842031609266996, 0.028058881871402267, 0.045131752643013195, 0.06265991712890326, 0.02099340807856812, 0.050223027431075616, 0.036419850563810724, 0.07295054638938558, 0.02063915561584215, 0.08708478432268867, 0.01555862233808805, 0.04478354652922961, 0.06068409593295186, 0.028264465396322554, 0.07599020707270793, 0.4710461367522517, 9.359097846092718, 31.703647336652203, 43.75380000760479, 49.97197266547911, 45.8008457768348, 40.34427581294891, 34.69262676854288, 58.13156558621315, 55.408985691685835, 29.736721861747007, 29.380696165946226, 15.49241198647407, 5.458638033559246, 1.0267049687043315, 0.7550495165971018, 1.2235649891438023, 2.3359570147529727, 5.494860631804313, 7.200227264435061, 12.194668477581395, 16.273834416943213, 12.438150586620456, 10.001367330551147, 12.679432245992846, 14.173363024188628, 16.3549078472199, 19.229421730964415, 23.080204725265506, 38.084190430179724, 47.16790553062193, 54.89240953999182, 60.7803656977992, 62.2425703848562, 60.2848252173393, 60.73464655107068, 59.83186990984025, 60.406783473107126, 60.14021135145619, 62.269485688978634, 59.24455381208851, 61.108766140476355, 59.97560516480477, 62.00207418011081, 55.90728752074703, 58.161081421759825, 59.476903253985995, 62.22758300842778, 60.14689507022981, 57.877556816224136, 48.33862712306362, 43.77145851812055, 45.492367052262836, 55.47404604573404, 57.202854233403365, 60.649068278651086, 56.02481349822014, 59.03513062384821, 57.82934304206603, 62.93020502213509, 35.33083954165059, 45.73787996845861, 59.07617430533133, 56.168482072891734, 57.489830524690696, 56.966413759416156, 57.15287539266772, 58.56099059504848, 58.548737110630164, 57.0215505169284, 56.71815518409976, 59.11630407456429, 58.44097783488613, 53.68530404183173, 42.448639177506976, 51.13578696404734, 58.7622356414795, 59.155425794662975, 59.280188545104004, 58.19071492841167, 56.55376865017799, 56.63170222313174, 61.88741545523367, 58.96565760335615, 60.076339475570194, 61.48657275784401, 63.21069371315741, 65.12401019373249, 58.982955255816066, 56.72494480686804, 47.08821473583099, 37.67728767087383, 26.07482844783414, 22.32466797674856, 17.18128162045633, 20.099585825397124, 18.34719438706675, 13.883825425178776, 8.373289531277072, 14.103065325367837, 12.613663904128536, 12.44811732922831, 8.350184809777046, 4.229259846671935, 2.7890665204294267, 0.5734940942737364, 0.5152332914933082, 1.9916153242511137, 6.612323791750017, 18.216665752472416, 31.520658962188232, 37.00070627274052, 41.658607144509595, 35.46895796252836, 33.086906479251006, 37.766596117327296, 43.122192505867254, 51.29281120915567, 46.82715746664232, 23.966103407644457, 4.684907370998014, 0.07941479629446423, 0.0018330397635450467, 0.034010940712065466, 0.010051279452689474, 0.08540314472010059, 0.0284994647823154, 0.006719357662668993, 0.02712245812759765, 0.03160495923141078, 0.06244718600364943, 0.054773536075146935, 0.034833516129442764, 0.04113088527153577, 0.1020226025232865, 0.04578497283340943, 0.0326869071220919, 0.04668251761505681, 0.07416286520780095, 0.08753613268415775, 0.005885907148401584, 0.11402137802853701, 0.08002749809454526, 0.02192785340030828, 0.008227796755701063, 0.03546039821700223, 0.03390077343811432, 0.023963990613758087, 0.02769876500561593, 0.16218249896360984, 0.12922358849356252, 0.1320716276043846, 0.1689040624806958, 0.11599553298325309, 0.09052407477171191, 0.10523491644210393, 0.16678307145353288, 0.14337384532536232, 0.12604040889850548, 0.14526304879015492, 0.10506199507583534, 0.194752405307466, 0.11357863283445759, 0.15447447466994488, 0.23642536673334338, 0.1300407744823925, 0.11815020889644662, 0.20401693640216706, 0.1411262506078328, 0.12780333042985972, 0.1547067678503452, 0.2141638169245374, 0.19998991861939433, 0.1938348158352798, 0.15555847376104326, 0.21580394988338794, 0.8230297075163934, 10.973921956554538, 39.17378171797722, 53.11342247070805, 57.18023784698979, 53.530362575284904, 48.222054281542384, 43.70812008457799, 67.00754411758916, 56.42016095499839, 41.39037978264594, 34.587542549256355, 17.588998271572976, 6.32762247516263, 1.5348498018518573, 0.9360300665420871, 2.336041836007949, 4.975127952714121, 8.046281039714813, 17.64960869666069, 25.653605115029123, 18.90957597763308, 15.30750753418092, 30.74459448937447, 16.003641947623223, 14.61533667579774, 21.05632055190302, 24.940730025691373, 23.597692828024588, 46.77784542883597, 44.26464165410688, 56.99255635661464, 60.106361296869096, 61.64160051653462, 61.359233010199766, 63.27733086001489, 58.90393910869476, 61.87167890610234, 60.15571648074735, 66.33329652970838, 60.711465343352295, 65.39050386797997, 62.261193798434356, 62.79384382309453, 56.530179515961684, 57.523402090995546, 60.648193590102665, 65.73122839773855, 63.35686475999894, 60.55630422407582, 51.29106967679916, 47.25037728586505, 46.868185458644746, 58.52829371729205, 59.83505879679034, 63.51346538912866, 57.923962377732806, 61.222259921412316, 59.81365050038984, 65.34416498676424, 40.7374071305798, 49.72082330334572, 60.60833838678176, 60.10842446357974, 61.27939708771245, 60.22427166661909, 57.640441694567286, 61.63363810508483, 60.895683380865286, 60.48300297029557, 57.71462155926613, 60.84666159845168, 59.80351117349441, 58.15759443467664, 42.90274766183669, 53.65713357925416, 61.09765406577819, 61.67697637311874, 61.46432115185646, 60.74062424321329, 56.636024675061634, 56.947449099633005, 61.990762064533854, 60.92416371068647, 61.20373456708847, 62.656015657609515, 66.43238344500142, 68.0164404838316, 61.468784809112556, 60.529812535931995, 53.52072923414169, 46.356174945831306, 31.20427666171905, 29.653047900046076, 22.532186854270197, 27.624843235938783, 24.06750648252426, 14.840596433608765, 17.673741079145863, 20.855367722049838, 23.663771037132513, 20.500195141761534, 18.104886047301754, 12.422207132462534, 4.185861272196616, 0.4832836865417419, 0.9846054954874901, 2.9513906230849605, 8.273466190984173, 24.086426035050426, 43.26411562581217, 56.5080887271512, 54.85448806516586, 47.38129423510644, 43.20839051277407, 42.52954198468117, 49.8887203585717, 58.19173866702665, 54.42286652903403, 29.127226721855905, 6.353277227570934, 0.24355629699364786, 0.15693038401584472, 0.13729858422471633, 0.09229727720300998, 0.143675500106427, 0.1253460497865754, 0.11594969794274339, 0.15331362163828266, 0.18457730210596518, 0.14215778799787646, 0.12277439987707524, 0.10025802624201584, 0.11095683480943404, 0.20002937214749478, 0.2765480573138883, 0.10117787567357864, 0.19896317693975665, 0.2162856659701755, 0.2053827026318158, 0.08076376987681275, 0.1836014593080167, 0.1717379902519526, 0.10006955329088435, 0.13529092824507144, 0.17728681105279154, 0.09811610569276157, 0.10554808552467054, 0.10009675707307555], [0.029161223022627736, 0.02744694998968513, 0.020889059242401874, 0.019091169627743865, 0.05372313376996787, 0.0730745760243266, 0.18448120403674342, 0.07401396835883779, 0.038671091859859806, 0.09330812255821883, 0.010743241667026475, 0.040998949609216184, 0.04400895885942925, 0.02530247262198358, 0.05061559769655428, 0.1172757808179144, 0.03497348039320881, 0.002929496042798424, 0.04894952883102721, 0.00701094652721358, 0.042819507765553655, 0.011018879144572684, 0.03440394764766097, 0.08599654876536901, 0.012148467170435094, 0.010971597155495998, 0.03462959884575779, 0.7052402570843698, 7.176978395831201, 24.977614033606745, 45.022459260879025, 44.864587783813484, 44.20377823614305, 29.402098578791467, 44.93546109045706, 31.65254669804727, 23.328977131074478, 31.98780344378564, 15.703883632536858, 9.466303087049916, 2.874855865393916, 0.41333587539772837, 0.6240915663300023, 0.4832047181985071, 4.175137021849233, 4.237645383804075, 5.361767747709829, 7.921633018601326, 15.74074802860137, 17.257652128896407, 1.2551167799580483, 6.180133021646931, 12.439897021939679, 19.10076406694228, 22.806009477184666, 26.97165289232808, 37.37092702619491, 47.318450020205596, 58.07975499860702, 62.24174276474984, 59.47582852455878, 58.30338893398162, 59.614429396967736, 57.21355053686327, 57.22869088572841, 58.19029523480324, 55.56898701575495, 51.68594644915674, 53.51412788514168, 56.616773682255904, 58.92229972347137, 58.61669217386554, 59.97147883138349, 58.365052515460604, 57.95621995002993, 57.775033904660134, 57.716194429705226, 48.11520107330815, 43.08882098044119, 47.334088510082616, 58.07300459954047, 58.0377777930229, 59.04842745873236, 56.7185317316363, 60.90849384184807, 56.07359209368306, 62.32250044422766, 40.21681447182932, 46.5965848584329, 63.041745462725245, 52.539371828879084, 52.04350186932472, 50.783671871308364, 53.164401515837646, 53.95277046388196, 54.62462540595762, 52.43066726192352, 52.49707298894083, 51.874518317561, 49.982888621668664, 45.18526900199152, 42.048686858146425, 47.059836387634284, 53.97344919943041, 55.437744509789255, 58.2578972847231, 57.84551497428649, 55.66226882319297, 56.96728844796458, 57.67379360814249, 57.82618161170714, 56.27963419883483, 59.013604656342544, 60.24196940083658, 60.39608324727705, 59.40333920140421, 52.12518130579303, 44.97316683492353, 36.52108277043989, 29.765211997493623, 22.4727217612728, 18.332973834007017, 14.03533285663974, 16.19861218237108, 14.537782592158164, 5.334367050278572, 5.99541929460341, 9.752606691852693, 8.151355453075903, 7.544795226666236, 1.2183058261871338, 2.3981660508340408, 0.794999408385446, 0.059828574904390884, 1.1027678775210534, 5.070652865594433, 17.091569169875115, 34.563439584547474, 66.94133450908046, 67.03795817590529, 56.928209873937796, 42.25181464226016, 34.720965893037864, 36.48827998868881, 42.76560591113183, 39.77450447697794, 18.93654815612301, 6.831684795118148, 0.15423073613595578, 0.06325941923404894, 0.06897332432169108, 0.0886771823429773, 0.040129121888669274, 0.09860604190297666, 0.03152147096942269, 0.03654346651127262, 0.0018358030666281741, 0.06978190714313139, 0.05697841756045819, 0.06030413547470685, 0.021132487510781617, 0.005925997487089087, 0.035006552408899994, 0.004142577836905877, 0.05155349999005276, 0.032390515365067034, 0.04202672550755163, 0.03527611193637695, 0.05761283795319258, 0.03254660577963918, 0.08901531057011697, 0.03495705546811223, 0.012478459543818909, 0.043545406717326374, 0.024888737262376857, 0.031128571286136587, 0.0698558959148584, 0.020460254933324554, 0.03268458970612095, 0.026096359961816383, 0.08018188013304627, 0.07947629783302546, 0.08545879334692033, 0.08793511127512302, 0.013940955865226928, 0.016473862793176405, 0.0679822516958079, 0.0693589270174984, 0.09858039327927175, 0.04419907123871869, 0.0936746726473493, 0.08248564441718402, 0.030334373680694453, 0.020424168361651323, 0.07168640938377188, 0.03968305953387772, 0.07676430827667637, 0.025158666427277272, 0.04158237535927085, 0.05997323528713277, 0.062115466101996364, 0.04525228891701949, 0.04372218916673334, 0.9982956092684501, 8.750182236394576, 29.067394887247396, 50.31743541840584, 52.23427026502548, 53.276012559090894, 34.7635510659987, 48.22430572202129, 42.95922979231804, 28.032967813553352, 35.019783819875414, 21.854348336496663, 12.311955190473988, 3.837064994919685, 0.6547650526608191, 0.24910809021563302, 0.5123518509489875, 7.006681830652299, 5.97247931265062, 11.419860143815319, 11.258241822642665, 15.967159002057969, 12.47987283814338, 10.410505840855262, 11.561418483334204, 14.374247212563793, 17.171279576516923, 17.95121346750567, 29.920502554985788, 38.970908887924686, 48.63589179131293, 58.37190881852181, 62.81897052641838, 60.020520225647964, 60.62654210675148, 59.955679524329405, 58.232178303503225, 58.93559655835552, 59.47484008727535, 57.34308681180401, 53.6937528271829, 56.10439446664626, 59.794030804787916, 59.72345952064761, 59.833270195991766, 58.13817870232367, 59.620618897099654, 58.279709585251354, 59.99081219396284, 59.306468425258515, 51.639831143040816, 45.95395157414098, 48.52812074845838, 59.088412100268954, 58.350626037966826, 59.19720295936831, 58.527626914362756, 61.881049448444, 58.65347223897135, 61.004505618926025, 42.29960480043965, 48.6963237485578, 64.80426249965545, 56.16242985571585, 53.93621413938461, 53.21085806815855, 55.459599956389404, 56.9824170297192, 56.42865288642145, 55.85124077335481, 54.83097345598283, 53.62369145116499, 53.42427422923427, 46.76017515120968, 44.64833574910318, 49.176410090538766, 56.668901981845984, 57.63166735249182, 61.2313872768033, 59.007254339033565, 57.19109888999694, 56.91710564397997, 57.95997758065501, 58.63627264576574, 58.88125996435843, 59.79750210239042, 63.75709164527155, 62.13989842322565, 62.4917781737543, 54.56921408253332, 48.40856298323601, 34.42509758856989, 28.57237804320551, 21.37370109558106, 19.329238207109515, 17.423405608823224, 13.651845666670031, 12.397061797880358, 12.722413578341085, 13.318200034479942, 15.112169577229409, 9.211350006441917, 11.87669957837751, 5.2537951930876705, 2.6273636231499338, 0.7696564231188067, 0.22896736289464661, 1.6640449531616706, 6.527874181347509, 20.463862226855372, 32.75011412559017, 61.06935416498492, 60.768516217508626, 55.17339244965584, 44.39384452758297, 38.766776977046845, 41.79690599441528, 48.38032191799533, 45.227375645791334, 23.53851406804977, 8.24846500350583, 0.15700893867160046, 0.037813839472589955, 0.07419380749906264, 0.008129236671412665, 0.06631299207407622, 0.06608079848510605, 0.05913059602701857, 0.03547693805528745, 0.038988658287111795, 0.08814815266598618, 0.040760711586523446, 0.10297718638133618, 0.05641255437606766, 0.014914278233904513, 0.03344705020407996, 0.04151639986723181, 0.018528409099446672, 0.02960402375808166, 0.05688326560982293, 0.040548964884252324, 0.026665389004554, 0.028924101573084633, 0.004679800345442228, 0.03494005214663283, 0.07635645072666869, 0.0468495515956273, 0.04287674602481627, 0.08108489861291263, 0.11915582187113263, 0.13746392132053453, 0.12956245982598874, 0.17276143775351588, 0.169538950187064, 0.17488406820883676, 0.3147040469752204, 0.22927088693024653, 0.26030604337011615, 0.1845800293789756, 0.1504553782363092, 0.15771076714079227, 0.1393212402059186, 0.12316364915140214, 0.1743734859290623, 0.15567433689871144, 0.1460276658256208, 0.0947432120841357, 0.1284826742184739, 0.10755011075807196, 0.17233972167295797, 0.12355174929384263, 0.14894180300254978, 0.1540310936228883, 0.19705350360562726, 0.21435550744495085, 0.1747271734019441, 1.2688981501325485, 11.446277306925866, 33.80642998603083, 58.81866285877844, 61.40599158502395, 59.97194951580417, 41.75778819668678, 56.862922022419596, 43.598113290725216, 35.018089355960974, 44.25512598406884, 24.40846831567826, 14.07362597603952, 4.258024058034343, 0.9760365262627603, 0.7303638347694952, 1.8931369892051144, 9.96814779696926, 11.865112896888487, 13.017440534407093, 16.690769618557347, 29.839089839689194, 31.691895915615945, 12.787784780225447, 15.817160702520802, 19.85618510553914, 27.470227326116255, 30.22080706011865, 34.89595459353539, 43.136328727968284, 51.8529256697624, 59.207522715291674, 61.67042993730115, 60.79295650605233, 59.71123741519067, 61.311882157479566, 58.95336881760628, 60.03677452764204, 61.9500360950347, 61.466737331882605, 57.03397266326412, 58.82671940711237, 62.30039004356631, 62.253117638249556, 61.332792312868186, 59.400154236824285, 59.54312855197538, 62.26201749617054, 62.069723298472745, 62.62937884176932, 54.24015075929704, 47.958216051901545, 49.96382198026104, 61.61332807233257, 60.83824026969172, 60.71138297357867, 60.8108699706293, 64.19143922867315, 61.67598401346515, 61.97967744642689, 48.03794214802404, 51.39812684828236, 65.89674457426995, 58.513792714765, 55.909491892783876, 55.157165604252974, 57.20463106709143, 60.224240287657715, 58.806617259979255, 57.97677709210304, 57.831457199588904, 56.655173686242875, 53.736636100276826, 49.491596068105395, 48.328346590841974, 52.737365230437256, 59.57683740123626, 61.11566951197963, 64.43815631251182, 61.376012909796934, 57.13336552343061, 57.839231337270434, 57.44878292083741, 57.32175696280695, 58.12297951790595, 59.777341119704715, 63.0170855214519, 63.39954406984391, 63.33724506439702, 56.750714778900154, 52.069883731103715, 40.258458275948804, 33.73210499363561, 27.867433986356183, 22.876802375239713, 18.928179779360374, 24.191110172579368, 24.696474229135823, 20.530777861995084, 16.749611054697347, 20.894511015184467, 16.848478317260742, 13.485580317435728, 7.552499742277208, 4.903479487665238, 1.881952718380959, 0.6006912574652703, 1.9441355236114997, 7.902684538595139, 20.341017515428607, 40.70668320502005, 74.45291657601634, 72.7740401606406, 64.6413350874378, 50.43489079321585, 48.14551314999981, 49.141897155392556, 56.950834105091715, 53.460724815245605, 28.555356917842744, 10.156156805253799, 0.3396633141223462, 0.15185454589945657, 0.1872702696991544, 0.20254555729127702, 0.11666737677108859, 0.21837648845488028, 0.184869212248633, 0.2006170535159688, 0.08427201589990048, 0.25114301892538227, 0.11333031309468132, 0.11415702155641011, 0.16032242216169834, 0.17989675003674724, 0.15993681946589103, 0.09185734355161268, 0.12403314362370199, 0.08635534604470577, 0.23032854791850815, 0.10131035525832446, 0.1594262218643581, 0.16198636513323555, 0.15352467886142193, 0.23296038169533978, 0.19364303338431543, 0.19723192548319218, 0.15961651810474936, 0.15501842773970098], [0.04756430396810175, 0.0018347513715496228, 0.0341997622332025, 0.030495773084581863, 0.03304708719013199, 0.05365327038171311, 0.03298186629469837, 0.02856551688314686, 0.030510068285248937, 0.03718745917262089, 0.053096711335162965, 0.04699082203930424, 0.026407803431333556, 0.03319967275245055, 0.00844908316784929, 0.07952415534565527, 0.07644563868281341, 0.034580373866183144, 0.008608310712471364, 0.039697714795869206, 0.040548869123261784, 0.04716558967747035, 0.050195559348550536, 0.0601772521622479, 0.07327070219382163, 0.054391890223468506, 0.03751568571333924, 0.8165617803892782, 5.013063155835675, 23.326829633405133, 52.43524466791461, 41.815866731828265, 33.008125674340036, 29.457188267861646, 19.269376954724713, 16.03835100127805, 32.66906422953452, 22.683429525744533, 23.349863752242058, 10.109915983292366, 2.5688553433264456, 0.08672460042420896, 0.22300388934391163, 0.49506939767349156, 2.7410643091124873, 5.065748922286495, 8.704876899719238, 10.710874084503422, 13.26159925230088, 7.4591198755848795, 9.046152522487025, 16.702268046717492, 20.566708733958585, 18.024504915360485, 23.266444744602328, 38.217652997662945, 44.243955073818086, 55.37226053976244, 56.42348712490451, 60.10318025465935, 59.643596141569084, 58.854325048385135, 57.32253751447124, 59.14154844899332, 58.225384758364775, 58.18392530564339, 54.5890808874561, 50.663368855753255, 47.2957081179465, 51.107592967248735, 52.51723397162653, 54.96368685076314, 56.92634282573577, 57.643728640771684, 56.46615466763897, 57.52440621775966, 54.63738487612817, 48.56288471529561, 44.45848911039291, 50.60937743033133, 57.08830533489105, 54.12855540552447, 54.42951494647611, 54.63665531527612, 59.006811111204094, 53.59580339923982, 60.046227439757324, 42.303809581264375, 47.30182701541532, 57.30863663458056, 49.20118770291729, 48.48033451264905, 47.19989245937717, 49.29208470929054, 47.57326287607993, 47.397219058006044, 41.43186276958835, 43.90059471130372, 43.05924238697175, 43.098250358335434, 40.155029296875, 41.05595065701393, 41.992240028996626, 44.82430504214379, 52.47735131171442, 53.68021672771823, 57.403495234827844, 59.101230405992084, 57.7690326782965, 57.51026215091829, 56.28270149230958, 56.54333514551963, 56.2189119861972, 58.638375036178104, 59.6785326926939, 58.89428615570069, 54.04305558050833, 49.80343626391504, 36.44740104675293, 29.024439050305276, 23.979965063833422, 24.049163518413422, 25.41872182200032, 13.477588488209634, 11.302854860982588, 9.610962060190017, 17.256040034755586, 13.68522797861407, 8.349475841368399, 10.694198127715818, 5.981571366710048, 1.8963882663557607, 1.1555786695211165, 0.2215218462891156, 1.1119066323003461, 3.4342486098889387, 12.985118243002123, 29.382486727929887, 51.75749440346995, 48.87226950737738, 33.059347906420314, 30.714327519939793, 33.175355926636726, 36.89702626197569, 50.62987965922202, 48.40242839628651, 25.760485779854562, 5.915350971683379, 0.08681704425403187, 0.02225595162129931, 0.10106264838888761, 0.06199339765214151, 0.04591875476762653, 0.028570119156351978, 0.07739132059918297, 0.06407032713233944, 0.051568599583040324, 0.012195206194695447, 0.08968657979200925, 0.0602011809185628, 0.01192665120000921, 0.041930784486354365, 0.02748882627084611, 0.048158443457777464, 0.01565879503745706, 0.04779203509491298, 0.047520215608059406, 0.04022023655594357, 0.08642551203769061, 0.0042020310478795685, 0.03368468301731252, 0.04113206121649954, 0.06277263547564227, 0.009332292529213573, 0.074006307479595, 0.021989320464912924, 0.08184724802812261, 0.02585028102921863, 0.011827491651920062, 0.024084283654848417, 0.017933654824211713, 0.04492460246828776, 0.08593212077093702, 0.028334365173753713, 0.006945505381501731, 0.044986444915975296, 0.04243324623413144, 0.008823457887516388, 0.05149490575516417, 0.03947832253611377, 0.013879908233760826, 0.013562571632886126, 0.060457150046263015, 0.030481000994181925, 0.03588194192777719, 0.03480049390946666, 0.027186171745040247, 0.006595839391417441, 0.03830449580545387, 0.020087451651512135, 0.031650152673283895, 0.052371329492739135, 0.050316252670581305, 1.0195687677591079, 7.15384082448098, 27.198726746343798, 57.81841531876595, 51.28189133059595, 38.38995487459245, 34.9524014226852, 30.299576097919097, 23.322756251981183, 39.65946135982391, 30.103565454483036, 23.884361213253392, 11.494878415138492, 3.267322586428735, 0.17835282239942782, 0.5477726002854686, 0.7351272469086032, 5.373542702967121, 7.79722132029072, 11.864797146089616, 10.022391234674762, 20.179200133969708, 15.113180568141324, 11.081200741952467, 14.025933877114328, 15.52068639186121, 18.77223418604943, 24.196721123110866, 37.530771455457135, 44.262907966490715, 54.91528088046659, 57.462040532019834, 59.700415595885254, 59.452157020568855, 58.640889275458555, 58.78286338621571, 58.92346858978272, 59.22844071542064, 59.32961825401553, 57.09101961505029, 53.61452879444246, 50.00841148437993, 53.73910327111521, 55.77698246125252, 58.698599107803844, 58.4586206559212, 58.47800500931279, 58.91412942640243, 60.1688015076422, 56.234248453570956, 48.922891616821296, 45.629096954099595, 51.59826970869496, 57.51201545038531, 57.33885457438808, 57.30964468371484, 56.68259497611754, 59.388567555335264, 57.16522693634034, 61.0087731576735, 45.65101908099267, 50.31773744090911, 59.71757596538913, 52.84336728434409, 52.36568143290859, 49.835748749394575, 51.108628472974225, 49.17098937496063, 49.34924148744153, 45.122114919847064, 47.03922433237876, 45.91835998719739, 45.989347042575965, 42.62511445629982, 41.32571166561496, 45.332075472800966, 48.23844978886266, 54.81585664133872, 55.716789768588164, 58.76289067729827, 60.48307357295867, 57.074365231298636, 57.55292969365274, 55.89457511901856, 56.75842615865893, 57.86920609012727, 59.160238542864406, 61.298957947761785, 59.80074590252292, 56.31664960615097, 48.67127941500757, 37.96768034658125, 31.94976822022469, 23.219484167714274, 14.929873501100849, 21.596987901195405, 16.309661346097148, 14.89158038170107, 12.85334719765571, 13.396895527839662, 15.330451438503882, 10.417547475907112, 14.406886235360178, 6.537667849371511, 4.376153590217713, 1.626692099436637, 0.39811481150888633, 1.090513535084263, 3.9686855193107364, 14.065390959862741, 29.984095942589548, 56.17489514812347, 59.36525298703102, 45.39250350767567, 39.00342925902336, 38.07863243164555, 42.999838090712025, 56.682912688101496, 55.484805107116706, 28.086257134714437, 7.1964009923319665, 0.24938458666926433, 0.05332078056169614, 0.047936630360181295, 0.04073002593471639, 0.0622513662693241, 0.05299199094635345, 0.048366658494717656, 0.08339963327612608, 0.03199571003806928, 0.029145104532700875, 0.03092495277674208, 0.02303475277468322, 0.026278091339214195, 0.04509130703105081, 0.015352222929528404, 0.04980147605942142, 0.07141624081639514, 0.07102588837545726, 0.03003325707639658, 0.026645034048405868, 0.1726767697161244, 0.01383622877314807, 0.11319721297871684, 0.02194678534813706, 0.01776773358635124, 0.05674585624928436, 0.07615913712089101, 0.03308986937026343, 0.2127862835843717, 0.11974740262714126, 0.10767217154704756, 0.11750157757271683, 0.07229710403349131, 0.11274280792642986, 0.19781081216229549, 0.10855663537738786, 0.17122834259944578, 0.11347957766584812, 0.15153756935990628, 0.1583965230853327, 0.12856289894590456, 0.20529046564573245, 0.09009172539076499, 0.18333829278426786, 0.1370610663246724, 0.16670368942281893, 0.12018033423491063, 0.10297704848550981, 0.26133833152632563, 0.20957844361903208, 0.08990028767936653, 0.13060663766678304, 0.15136291663492882, 0.11130932718515398, 0.12937412477068364, 1.4562409683581323, 8.841042960843733, 32.279355179878976, 64.82807520897158, 57.79653633794477, 46.24613285064698, 40.95686766409105, 30.284775034073864, 27.059894454094675, 47.82143123688237, 35.67912640110139, 30.115565946025235, 14.785892117408016, 3.773121535778046, 0.2770009991382399, 0.6151554877719572, 1.5112457135992667, 6.0244678778033105, 13.310996601658484, 19.31726517215852, 21.89506450007039, 24.12958191287133, 21.137843093564435, 21.157600072122392, 29.218017824234504, 30.58140427835526, 24.013520940657585, 30.132116386967322, 44.894539002449285, 50.17152324799569, 58.405719649407175, 57.42935149900375, 61.462960089406664, 60.43889984007805, 57.739512920379646, 58.151291185809725, 59.35450569275887, 59.947568062813055, 61.23889861568328, 59.875059127807624, 56.92263618592293, 51.72498972185197, 55.89088416868641, 57.58989018778647, 60.29661193970711, 59.34852800061626, 60.48904734273111, 60.09640632137176, 61.16655834259526, 59.151060196661184, 52.657960768668886, 48.244513773149066, 54.36765524648852, 61.127699421298125, 60.066690444946296, 56.95912991800616, 57.65334629243421, 61.87704470849807, 60.046851096614716, 61.35855051778979, 48.651640107554776, 51.81680456284554, 62.13689388767366, 56.01854555068478, 53.59713700509841, 52.941501063685266, 53.32674449489963, 51.10399223143055, 51.27286987919962, 45.8780772455277, 50.070565362130445, 48.68315635188934, 47.972101242311545, 44.131245766916585, 44.495669257256296, 46.30698450150029, 49.8288022318194, 56.83390825025497, 57.466445353723344, 60.29078722000123, 62.25956209244267, 57.11028237496653, 59.199089619421194, 55.993556130316954, 56.38294158443328, 57.24989521887995, 61.19709791675691, 60.92581895089919, 61.24004787014377, 58.0863759594579, 52.362747500019694, 39.88782175125615, 34.99985817940005, 28.411958986713042, 32.59637290431608, 32.52509363235966, 24.574139425831458, 27.631560294858872, 17.87188745314075, 30.548901557922367, 24.644461639465828, 23.013471480338808, 22.51311040693714, 10.829666987542184, 5.124704597457763, 2.4155112620322936, 0.5289849987433803, 1.8599922258046366, 4.791784603749552, 16.708204553973292, 33.54014419740246, 58.595530986785896, 58.230574054102746, 46.671878676260675, 40.16612960446266, 45.5960705972487, 49.64216016953992, 66.72500794933688, 62.26233128578433, 36.162134908860736, 8.972104057188957, 0.4810235739475297, 0.12782838916586292, 0.18772644441454642, 0.1563354401338485, 0.17200039068777717, 0.12982427803499083, 0.2634388220406348, 0.1919615776428292, 0.14363840612913334, 0.10282816695830516, 0.22082452241691852, 0.11901570438978173, 0.08661608406973463, 0.1538712876818834, 0.13418855836554883, 0.1345871079472765, 0.14120025470131828, 0.22774899198162943, 0.11248871954458375, 0.14401628665866392, 0.2993806643832115, 0.0982151378787333, 0.20118472466786064, 0.19369252266422396, 0.13225810872691293, 0.25385953606136386, 0.16218211591964768, 0.12350778350786817], [0.018052030730271534, 0.04406074257267099, 0.03641255357633195, 0.04477702712099399, 0.023286855073585626, 0.006813769859652366, 0.05301821030556195, 0.017954120863108866, 0.05218548422318794, 0.06800960103470473, 0.01672605893784954, 0.13107932923782256, 0.0418368314633206, 0.034435962462016655, 0.06753427412120566, 0.07292826089166826, 0.053623369970028444, 0.06325556964222943, 0.0378156014748158, 0.027703823101135994, 0.017243244895531286, 0.03168524333065556, 0.047138891513309175, 0.05553666306960006, 0.025071742260948788, 0.040344388764952464, 0.01766314534770866, 0.6881305719575574, 4.881225430196332, 23.72966685602742, 46.6052415294032, 37.01874133079283, 40.24646366796186, 22.843107254274432, 16.69729252015391, 25.636999760904622, 22.65151123846731, 28.5686812093181, 21.299470240069976, 7.672823350275717, 2.5593913995450546, 0.04583615133719099, 0.8457828865897271, 0.2900126654534571, 6.792031103564847, 4.9512966121396715, 12.365200384970635, 7.12453434544225, 17.88489991618741, 12.769232949902936, 8.152868507369872, 9.454468315647496, 15.396985623144335, 36.008530970542665, 30.883866087082897, 42.29033623972247, 45.67690672412996, 54.75791538915327, 58.35919641679334, 57.75801474048246, 57.26887556814379, 59.185004388132405, 57.01702802411972, 57.535239804175596, 56.772946773036836, 58.97928783970495, 54.6090300621525, 51.18638553927022, 44.42010479588663, 44.391000809208045, 45.41613971033404, 49.8859864665616, 51.91267905696746, 52.350980389502745, 52.46528610106438, 48.77673233709028, 46.13606329887144, 46.379885673522956, 49.679681562608295, 52.58620885110671, 53.10948441105505, 54.73092163762739, 57.311197942303075, 53.28766199850267, 56.83845427728469, 52.449816273104766, 60.93824501960509, 45.29723698093046, 48.34677388591152, 58.55449907241329, 49.42022069807976, 47.18860387802125, 41.19644211184594, 43.475633359724476, 41.355600126328014, 43.84481076271304, 41.52376782509589, 42.60049373872819, 40.99704842413626, 39.459985302340606, 44.51761099600023, 48.890410469424346, 41.614551082734145, 43.355702969335745, 46.51166554420225, 52.7349215938199, 54.55135945350894, 56.07161521911622, 56.735221416719504, 58.293398657152736, 56.10368844001524, 56.73892413416217, 59.09232270333075, 58.00175866773052, 59.047121309464984, 61.668049058606556, 56.01248941113872, 49.01709518124981, 34.15612105400332, 31.217179298400882, 18.754795328263317, 11.550626081805076, 18.57245610606286, 15.737713094680542, 10.327438865938495, 14.692629921820856, 9.464175201231434, 13.96335736397774, 6.6680185064192745, 13.215358430339446, 4.2986225505029, 3.173958654365232, 0.754666104912758, 0.3860280891099284, 0.75386103843489, 2.9063880443573002, 13.617336653893995, 31.554712980024277, 42.008109938713815, 25.470057802815592, 15.858220073484606, 20.09953679576997, 29.979971570353356, 43.79039572131249, 48.73921878876225, 46.14921892842939, 22.160124548019905, 3.923384595301844, 0.03261026768614689, 0.03995779015484356, 0.06363374511561086, 0.013030396207355925, 0.03925711464797778, 0.043199422258523204, 0.040396398474131866, 0.05406506179321197, 0.024980951265822497, 0.014223327255627562, 0.07250500497438254, 0.02326448530619664, 0.018540241327437184, 0.00897584618219445, 0.01164590008556843, 0.02667191990410849, 0.009714797356977098, 0.09814209139515316, 0.022222527205162955, 0.01855796094112579, 0.022741387064959255, 0.036125017795711756, 0.010758103772757516, 0.035751492476030704, 0.042832868338953105, 0.056377513514411066, 0.018070987575957854, 0.036702506364353245, 0.02691719252916594, 0.07730060046718967, 0.024215462805342772, 0.031414708956294966, 0.06494762421014809, 0.03174597878129252, 0.009372429790786438, 0.018069587550276232, 0.058022342592237465, 0.07299975987764136, 0.028508531432899258, 0.08569961308591789, 0.057752055281232444, 0.07768835587006423, 0.06553580353577292, 0.007862607909051042, 0.05016706470820693, 0.08860868642166739, 0.04780033565757256, 0.02063379300037219, 0.0363962397339844, 0.05766403943961186, 0.09131699109510069, 0.05686640784504914, 0.03989899290665504, 0.04853457347640107, 0.06190305673367074, 1.0934067733826176, 5.936697000457395, 28.502728516055694, 51.994452630319905, 43.51593571324503, 44.698302822728316, 28.595963255051647, 19.304093853119884, 28.09520406107749, 28.84833443549372, 27.81489972145327, 22.570569207591397, 8.928860906631716, 2.9850421076820743, 0.17846168349346808, 0.635504437790763, 0.8275043351515647, 4.294664878999034, 9.880584805242478, 13.86529124552204, 7.975495986400112, 18.741410240050286, 15.483371903819425, 15.026109833871166, 9.326615718103225, 16.10781127406705, 26.641126525017526, 28.764731076455888, 41.586153122686575, 45.831420652328006, 53.841108429816465, 58.14758846836706, 59.105737209320075, 57.94005194017964, 58.95501621307866, 57.39106916612195, 58.011482223387695, 57.639657220532825, 59.96430481633833, 55.718605825977946, 52.36423800068518, 47.034415506547504, 46.82351750712241, 47.88823312328708, 52.74730843882407, 54.58798654617802, 55.265434788119414, 55.67216104076755, 51.711230047287486, 48.4361215560667, 49.039637042630105, 51.344437445363695, 55.23318113819246, 56.48397791770197, 54.1589576967301, 58.159618377685554, 56.44489542130501, 58.84393861216884, 55.10342521052207, 61.87408724138814, 47.21545642422092, 51.32288794363699, 60.41955471038819, 52.01622178477626, 48.346585612143244, 43.15814102849653, 45.466353893280036, 44.22715163999989, 45.94692268679219, 42.8849361788842, 44.01250385469006, 42.84846598102201, 41.106078547816125, 45.69992711467128, 49.15169915845318, 42.882672971294774, 45.23947223540276, 48.18923581031061, 54.5833699164852, 57.14652115298856, 57.63621337952153, 54.679205186905406, 57.531066402312256, 57.25922261514972, 56.904071607897365, 59.66184692998087, 56.885781595783854, 58.533612451245716, 61.807450094530665, 56.862545474883056, 50.73927848569809, 36.61332907215242, 30.683754605631677, 21.4037601793966, 18.308937549591064, 21.735384810355402, 13.679911205845496, 13.66933943763856, 15.161752258577655, 12.297208059218622, 12.945524857890222, 12.134732700163319, 12.754365205764772, 9.704957738999399, 3.46672902184148, 2.2490343499568204, 0.39242136862970173, 0.6274185329675674, 3.4964608328957714, 12.65633438864062, 31.88856551724096, 49.590804576873786, 33.777753537701024, 22.30799201996096, 25.212452219378566, 36.42397272971369, 47.068822537699056, 55.38341183816233, 51.8884741106341, 28.058892719207275, 5.338628705470793, 0.14714236972072434, 0.042341782996851596, 0.1496320175788095, 0.03186250075457558, 0.12738031966070976, 0.07771767405492645, 0.07598110594816747, 0.03785237369518127, 0.026126135884213354, 0.052123289375055226, 0.07609034242529063, 0.01795781723734352, 0.028032131996306203, 0.04646936514144463, 0.04433823111016424, 0.021626729135131164, 0.03231132868677378, 0.029118339335846326, 0.030752701737407236, 0.044101192015072996, 0.022890356692275213, 0.03751875006503636, 0.02918515943982188, 0.012907730208920136, 0.03136464894088286, 0.018906864194920468, 0.035208577455412, 0.018765886779874563, 0.12674875677593295, 0.1969719918504838, 0.1253795891159004, 0.16665309697629946, 0.14446268609214213, 0.1142058443398245, 0.0913908189883636, 0.10853165325017707, 0.1321285479371586, 0.27251163197140543, 0.17088020160313577, 0.2573041738040986, 0.23644735345677023, 0.09513213194065517, 0.11097809374933282, 0.1312403762412648, 0.12859571815258072, 0.277139323973848, 0.14908470904394505, 0.13383258795065264, 0.21501602845326548, 0.1777042370409735, 0.10761539677097913, 0.15081684916250168, 0.13666581092101915, 0.1255453552209562, 0.11205751163464402, 1.3241486563797922, 8.827082264807917, 34.64837458825881, 57.05448273689517, 52.982733018936656, 54.06486395866641, 33.30659058786208, 26.23940129433909, 37.74567419482816, 33.463120614328695, 39.743741327716464, 27.976709258171823, 10.970864469005216, 3.8137629291703625, 0.3488856950594533, 1.1955061915420717, 0.8459095668888862, 9.943788897606636, 8.71888662538221, 23.047196019080378, 17.615227160915254, 31.11467992105792, 25.8505061364943, 19.46869807858621, 18.2206920654543, 21.973543282478087, 43.34146476561024, 36.86375279580393, 44.113971648677705, 49.28635020409861, 54.98560113291587, 57.96541006334367, 58.67742615361368, 57.0067592590086, 58.2738377971034, 56.80755384506718, 57.31949375521753, 57.21625697228217, 62.25926399230958, 58.63596277852213, 55.08725327830161, 49.5930834739439, 48.85479927062989, 50.071255699280776, 54.14988525452153, 56.4135713731089, 57.759163994942945, 58.268279798569225, 54.15428223148469, 49.88562560850575, 50.95562073492235, 53.44752603961576, 57.08482227017803, 58.489654448724565, 58.40916349041847, 58.319039190969164, 58.16139128900344, 60.49210679146552, 56.22511325343963, 64.13077192921793, 51.42408117171257, 55.090559836356874, 62.504694538731734, 54.02092556799612, 50.85776152149324, 45.32166942473381, 46.94538947074644, 46.65594600862073, 49.90675149425384, 46.05765119675667, 47.963381813418486, 44.9625450564969, 43.19211659892913, 49.26822493153234, 52.396103335965066, 45.1261471163842, 48.11028242111207, 50.67128419876099, 56.9482571078885, 59.73423427151096, 58.956549859816036, 55.06841413436398, 57.46064024586832, 56.53526683007517, 57.28191744896674, 59.24115311714911, 55.51115166756415, 60.74220103602256, 62.025435816857126, 58.477903027688306, 52.517316341400154, 37.27132235803912, 37.130579871516076, 23.880240763387373, 19.45310861833634, 29.07980722765769, 26.141083163599816, 19.05761407267663, 27.449366200354795, 22.025338180603523, 26.064973492776197, 16.002117126218735, 25.977082983140026, 12.087440682995705, 8.95753441318389, 2.8188951649973473, 1.0290634776315382, 1.2661895083804287, 4.261518399561606, 16.311450927488266, 34.55477506883683, 51.011196797893895, 37.08933614915417, 28.138397201415035, 31.593591513172274, 43.433824816057765, 55.43363386584867, 62.46432158254809, 58.56687022793678, 32.27411685451385, 7.656574931836898, 0.43580250694386424, 0.10572767951675963, 0.19160389119098264, 0.130476801085376, 0.24000595443912093, 0.14144157239746663, 0.13619592323178245, 0.13277848161035968, 0.1304623986323995, 0.17123722921936743, 0.17443446652783504, 0.19620409595870203, 0.16609346974761258, 0.10490300884890942, 0.13666024912268887, 0.1071180984558117, 0.08102055488815231, 0.1402950145664715, 0.0756697524939814, 0.18075748046319332, 0.11123279500151835, 0.1469307455925211, 0.09890512262861575, 0.12504353698703552, 0.09271848766553788, 0.11195956729352476, 0.10822799131875077, 0.198307482285365], [0.029631779123578342, 0.025910729196883982, 0.05567171670977147, 0.024539144529450326, 0.02890857488607928, 0.1134260970678541, 0.012802855644915855, 0.04369750581381302, 0.025931561042764978, 0.024487052465819066, 0.025934318959292386, 0.020435473904193893, 0.007268992231993546, 0.04713021173712708, 0.05908901660492825, 0.035580938321448145, 0.06697954219435492, 0.0690863146296432, 0.00518559170286021, 0.038919009403475834, 0.054082283449749795, 0.055290515189089125, 0.0696554107050742, 0.05677094945924417, 0.04999877434344061, 0.06976473145186901, 0.03198461325448607, 0.4113467434240926, 4.616804728584905, 20.832098261002574, 37.90980577468872, 46.057521758540986, 39.688455520137666, 34.85589150459536, 29.39184354197595, 20.998318502979895, 28.91468917169879, 29.77551018038104, 19.861827435032016, 9.23688659744878, 1.687004792113458, 0.04548851978935061, 0.6965741479108412, 1.251787790848363, 3.9808220680682895, 14.050637945052117, 10.268242455297901, 3.134780795343461, 19.062062040452037, 14.002185886906041, 12.510491840301022, 11.537452801581352, 22.613505432682654, 30.00957173685874, 34.290595592991004, 50.264408896046305, 52.752042739622055, 60.92132783705189, 57.36634254455567, 59.27238302846109, 60.24109863465833, 57.84852735457882, 58.26458100349673, 56.12797183375205, 56.3669147799092, 55.410040809262185, 54.4258749869562, 51.184094875089585, 42.547286787340724, 40.97378092427408, 39.99243920849216, 40.05562859196817, 42.26183237568025, 41.755003313864435, 41.03652707992062, 40.504536013449396, 42.60024662940733, 44.06712285933956, 52.85590317941482, 55.2593158906506, 57.601508248236875, 57.04893650547151, 59.72335753902313, 53.26618309943907, 54.26302209977181, 50.326566696167, 59.27078662380096, 47.54841073866814, 52.384210709602606, 58.27805434503863, 48.589494074544604, 44.5414472395374, 38.968343657831994, 41.00978828245594, 39.72147010987805, 39.853355884552, 37.76633724089592, 40.984861620010875, 39.393026521128995, 41.91323957135601, 43.21190887881864, 46.975172027464836, 42.66325166148525, 41.78521340893161, 41.07865333557129, 51.065247058868415, 53.50179595331992, 56.81805795238864, 58.86745714372205, 56.47632537349578, 53.668830087108, 56.01394068810248, 54.97684248032109, 56.29831644796557, 61.090099580826305, 59.28570339756628, 55.45172383708339, 46.90076858766618, 43.28281748679377, 30.968199006972778, 27.182956857066003, 17.63724930824772, 25.20662553848759, 10.596534052202779, 15.02490076326555, 9.992895991571489, 8.94853453482351, 10.73154301412644, 9.098993712855924, 10.39161668669793, 7.601612229501048, 4.61946556645055, 2.0819563346524395, 0.7428475745743321, 0.2789756060848313, 2.8622704503997682, 10.603508026369157, 22.54787633495946, 29.773945154682284, 39.85082203342069, 35.20743785365936, 30.952948831742813, 30.470740487498624, 40.24911911256852, 47.39608157065607, 42.144741781296275, 15.680206244991673, 4.8548053253081545, 0.18332287909523134, 0.08349858119242615, 0.023539807730083986, 0.0374923583360449, 0.018813807494758118, 0.030103424984601238, 0.008548379654154904, 0.03828172767234426, 0.0842125827987348, 0.019301242427900434, 0.02834121208457697, 0.06176488128520789, 0.04315357955713426, 0.04596380839845346, 0.05545066586965996, 0.0628123571345162, 0.0453400404583062, 0.10851384170593754, 0.058519464707182306, 0.06098336435013241, 0.09026974124173004, 0.052910402582417575, 0.025864825208461093, 0.049181684115601164, 0.008819296114867734, 0.04491897555248392, 0.038263946771621704, 0.04716305392644098, 0.005479075198602533, 0.08825649282023793, 0.010324844662400504, 0.055701073199029894, 0.07539892509098976, 0.03891047518399935, 0.053133529520803885, 0.024893067574368852, 0.0719590600760233, 0.032339930579426794, 0.037419189278396874, 0.03059166239484424, 0.019251335630073182, 0.05075195751663658, 0.007843836360881406, 0.06221272479442339, 0.05661239224155584, 0.01663557054745334, 0.06886154443265931, 0.03460624848582572, 0.06364478827303936, 0.014612922227130303, 0.06434070637389537, 0.036347838298928355, 0.03970771990416031, 0.051235592653674465, 0.029124816609246117, 0.5096795830515124, 6.125897918978046, 24.88543833455732, 44.80803505066903, 52.52534543314288, 45.79804128216159, 37.9216395654986, 33.35775398438977, 27.85705343369515, 29.071048575062907, 35.60264802748157, 24.229651381892545, 10.513128772858652, 1.9844593275939266, 0.0823791352130713, 0.4641648898682287, 1.7776462315551698, 6.795648019159994, 10.930379725271656, 11.139196907320331, 13.999760881547006, 19.035215377807617, 13.4602084659761, 10.935988714618068, 8.026024449256159, 18.18504556532829, 25.6205395344765, 31.802206693157075, 49.1778652898727, 54.46648720772036, 59.01815460574243, 57.7179124278407, 57.03361964994862, 59.6078045137467, 58.01728340887255, 58.84321297368696, 56.449810151130926, 58.54905090024395, 56.99794177086123, 58.655633464936294, 53.79731516684256, 44.91406848353725, 42.67934906867243, 41.6882328064211, 41.92965861289732, 44.995712618674006, 44.92471379618491, 44.51866219120641, 44.166060724566066, 44.81964918874925, 46.866259574890144, 54.949750669540904, 55.69603258563627, 59.316270428319136, 59.47400462242865, 60.398016975772, 55.27580553485502, 56.18581894905337, 53.03232354502524, 60.141144875557195, 50.31729421307964, 55.073442612924886, 59.59118543132659, 51.52242675904305, 46.239225556773526, 42.349520883252545, 44.815060015647646, 41.706656179120465, 41.58843986449703, 39.54321799739715, 42.399868426784394, 40.637802462424006, 42.90142974545879, 44.275224208831794, 49.20940506842829, 44.830161140811065, 44.8233401390814, 43.86570522862096, 54.60412317706693, 54.517705517430464, 58.50044881143878, 58.884774408032825, 56.01615290487967, 55.06702169295281, 57.02868138590167, 55.863368741927616, 56.97319945981426, 61.19160659851567, 58.65360952192738, 56.29955983931019, 48.658610159350985, 42.88713662855087, 33.87856237349972, 25.446292161941532, 18.960802132083526, 22.544369736025413, 14.8221936533528, 14.236977984828336, 19.785953106418734, 13.574301388955886, 13.683877702682251, 14.319851783014114, 10.543365343924492, 7.92169185415391, 3.62228581020909, 2.50037934030256, 0.6707710195933619, 0.41467649862170225, 2.7545082328781008, 11.41770774318326, 26.46624568969973, 35.32357138972129, 40.65562179011684, 35.361214376265, 29.948849524221114, 35.193482060586255, 45.26970978706114, 52.68312277332429, 49.04451647112447, 18.62886175032585, 6.001887283017559, 0.47613115260197275, 0.022776188524139505, 0.0399150769226253, 0.057464239878519896, 0.03136210361375444, 0.04078167175213176, 0.04064624272887746, 0.06977557159599758, 0.02493586124581916, 0.03418670426453314, 0.04616067767323506, 0.018057937268167734, 0.09251652390605981, 0.11242060666723598, 0.03541811782446119, 0.020023552257747903, 0.038239734562774824, 0.016779457181391698, 0.017315004351398638, 0.05119640725634752, 0.025080895096424128, 0.010046879235174387, 0.016180399407242096, 0.03578962067202215, 0.04271465714179701, 0.07367395555540439, 0.0755639097863628, 0.09543462175755732, 0.21046401061598333, 0.2334189159615386, 0.2059207108592795, 0.1416707552608944, 0.14183106681992932, 0.15142293196291695, 0.11744494835335402, 0.19878222697204162, 0.1685172646877266, 0.15368214057337853, 0.1945305156010774, 0.09833434115975134, 0.08532633674481223, 0.10239728846617284, 0.1556878813332127, 0.16278950106953421, 0.11857228503832895, 0.19016078072449855, 0.13898812985468295, 0.08011958952392302, 0.11619900593594198, 0.12256391721987918, 0.23358915602007221, 0.1527988105531662, 0.15224661437734482, 0.24532574559411696, 0.200077022816385, 0.7617818972756787, 8.19405339417919, 30.4741019587363, 53.05731296539307, 58.79572091564056, 52.00947923045005, 45.52544439992597, 41.10152075367589, 30.99919357607442, 44.69138376174435, 40.65241329131588, 27.1848415559338, 13.086022196277497, 2.388151749487846, 0.12718629257212724, 1.351983756307633, 3.2390445038195583, 10.119289467411658, 27.677777582599273, 21.028675686928537, 15.994295920095137, 33.544345055857015, 28.4480094909668, 24.172873112463183, 20.646717240733487, 27.10675697172842, 36.237624845197125, 38.374661553290586, 57.055145617454286, 59.361020749615086, 62.551241305566606, 58.56991790956067, 58.90523349085162, 60.76549991484612, 57.80005078161917, 58.15771602815198, 56.96034193038941, 58.73366117477418, 58.217920487926854, 59.76340493848247, 56.12201767583048, 48.59163568865869, 44.87910447582122, 43.88803920438213, 44.70830486666772, 46.15889933801467, 44.66165611820836, 44.8454152384112, 45.83480173541654, 47.18045711517335, 48.127438868245775, 56.8312410385378, 58.414490069112475, 59.49299673880301, 59.11035383901289, 65.3485894203186, 56.54373914964738, 58.79665836211174, 55.89295518013739, 62.85386000910113, 53.968671752560525, 57.69297792065529, 61.53897170097598, 54.41549247311008, 48.05692249728788, 43.86310861956689, 46.44473421958185, 43.40902366945821, 43.856762224628085, 41.64266270975913, 45.40072087318667, 43.90479949212844, 45.61595701402234, 47.65207898232245, 51.01840611427061, 47.63145123758624, 46.065899941229056, 46.345874801758804, 57.44534300219629, 58.23636739484726, 60.07329963868665, 59.64591818471109, 56.97804358697707, 55.620213170205396, 55.27062800622756, 55.57965978499382, 56.81791674706244, 62.92855762666272, 61.83227869772143, 58.28045091321392, 50.51802150664791, 46.25034547621205, 34.38560716567501, 30.304361389529323, 22.542981216984412, 36.13126977797478, 16.613849978293143, 28.248882524428833, 22.35439758146963, 20.812811966865294, 26.424531282917147, 24.398799673203502, 20.812019648090487, 14.855630878479252, 7.733717166608381, 3.8817782988471374, 1.7517545434736437, 0.7201553760997711, 3.7588580817945547, 12.103480235222849, 28.12777150061823, 39.83950207310338, 51.52594904745779, 47.847981760578776, 43.050828902952134, 42.35265093465006, 51.03245212185768, 61.227504130332704, 56.65391068304739, 25.81976652145386, 7.887950155042834, 0.8323270731395291, 0.2261610142886639, 0.10338954852833863, 0.14638409589327153, 0.14285122014341817, 0.12591175209250183, 0.18051551925318857, 0.24054466746747497, 0.18841131169709469, 0.08202570821008376, 0.06926708839713566, 0.12624493139165063, 0.23651066296283277, 0.20384131840640501, 0.14457628160955446, 0.1777815199907749, 0.21051492481943102, 0.26332847473602145, 0.1525501690564617, 0.11852410576877095, 0.17801419621513737, 0.17615701522557967, 0.13194565210611592, 0.1757530417413481, 0.15174755405995155, 0.12048616419516264, 0.14127027513759752, 0.2537860222641499], [0.062185815956083045, 0.032567129275130655, 0.010958524822678057, 0.04045601543639937, 0.00887941390711574, 0.041393917729897846, 0.05945558967669645, 0.05936163282322307, 0.03634370142413724, 0.05511830628459012, 0.06361567310147709, 0.06714862546012287, 0.03804303765777619, 0.05279585711597916, 0.01866142494573949, 0.054089086310517405, 0.025757023230976155, 0.0200362769781702, 0.03777054018310962, 0.05893766444416777, 0.06375422393302284, 0.11614911829031284, 0.01878070483554996, 0.02909507899124536, 0.045214838708841035, 0.03653610440632028, 0.01942602665944686, 0.34868966848138844, 5.233843566909914, 18.80179120648292, 39.44750039808212, 47.396163940429695, 46.117373205000355, 37.34711431687878, 28.76862991240717, 19.91384002470201, 19.505036877047633, 16.176148768394224, 16.741519205031857, 8.259282900441079, 1.4879447510165553, 0.33104482497419085, 0.33762962647503425, 0.8923496329976667, 2.301514191973594, 4.822839479292593, 8.750497987193446, 10.377173539130919, 12.11209866308397, 13.854738108573423, 11.086155676072645, 5.739300779757961, 23.03575054291756, 28.38918766667766, 32.67800331115723, 48.40929646645823, 51.637995473800174, 55.36228203004407, 60.17146087461903, 58.64788286147579, 57.94963036814044, 58.84447597688245, 57.74176043848838, 57.49042672495688, 60.75044585812477, 56.6792844956921, 53.54476159618747, 49.081214166456654, 42.47801380772745, 38.58932895045127, 40.49716195752544, 40.79559156971593, 42.385708670462336, 39.77116653996129, 42.35945624689902, 43.53943463294737, 47.29765361355197, 51.911141487859915, 53.83340881716821, 57.86685266802388, 56.895281576341205, 55.68780737538492, 53.85009065751107, 50.867300725752315, 51.332282020199685, 50.98431679510301, 57.340611796225275, 47.84192954340289, 49.31391662166965, 60.422312136619325, 46.83986594600063, 43.09879164541922, 39.63356979431645, 40.88824187555621, 41.71583844769386, 46.95148483399422, 45.056599570858864, 48.988838426528446, 43.807967939684474, 42.283872173678496, 39.82618954873855, 38.919706267695275, 39.859211983219275, 40.33239495369696, 38.022111077462476, 46.50143208042268, 49.66325467632663, 54.97295541148032, 56.386663913726814, 50.75010422737368, 55.30503503737911, 56.480828254453606, 53.92215244231686, 54.568747320482814, 55.66401427791965, 53.95869324284216, 50.060276985168464, 48.87020634066675, 39.55286702802105, 34.25982067661901, 24.671949609633415, 25.987936181406823, 25.81501849236027, 18.376406238925075, 10.140442809750958, 18.103983902162124, 9.733867568354453, 7.070908190742617, 10.478807053258343, 9.050289642426277, 8.678011605816504, 2.559897630445419, 2.7098035091354005, 0.2205305744803721, 0.33202170965171635, 2.046339987747131, 8.020593927752588, 20.9623582132401, 28.59118776936685, 28.50145962930495, 28.02309520782963, 24.114112084911717, 24.955303592066613, 42.0903463517466, 47.90442074498823, 41.97324791262227, 25.561703981891757, 3.4022158384323125, 0.29412346261162914, 0.04743602254518098, 0.017178209776419307, 0.04755358639804106, 0.03767358409541269, 0.05633126861686188, 0.049022582975486596, 0.05659625076899125, 0.02550082619211847, 0.02538313210431126, 0.11148046356655898, 0.0268114666499558, 0.07531904510312504, 0.011387986052150448, 0.14031275716279784, 0.06512118909027308, 0.030727574053490837, 0.00753885149137087, 0.05143345401231801, 0.04698901024136332, 0.03463340630274146, 0.03399014142492125, 0.05366026476446179, 0.04184710087194558, 0.03943021221446895, 0.0244739581079733, 0.043343446788287936, 0.016638805353713614, 0.06181687950306843, 0.0171863513758346, 0.054354838381010684, 0.03481850463656649, 0.013757786157751277, 0.0015563570547871472, 0.02640751040270252, 0.07588265598901818, 0.08719232008461991, 0.016706000840772065, 0.05894036490410086, 0.08802648258185194, 0.01907634774162885, 0.06757492274646798, 0.047995113512320865, 0.0067248471614514155, 0.016516066576925018, 0.029288280620089466, 0.0819523399695754, 0.01863855722119972, 0.03636736204967864, 0.053975663162888064, 0.07264460151594493, 0.08510165081750001, 0.022064919936500733, 0.04304625446938219, 0.007768942647793842, 0.4750364436016929, 6.018328878187365, 23.625057243531753, 44.737149976914935, 53.465612088480306, 49.009776038508264, 40.915886740530695, 29.21211857949534, 20.89256355839391, 26.65378009119342, 22.56945917683263, 18.778186382785922, 9.965329574000451, 1.5931852522396273, 0.2427816901716494, 0.5340056938509787, 1.8875174584888645, 3.676256888335751, 9.470664762681531, 13.156672908413796, 13.527292763033222, 13.8105712398406, 11.593011213887124, 18.30239111377347, 10.342437028884888, 18.61079139094199, 26.273629857647805, 34.413534441301906, 47.9120340654927, 54.65069347812284, 57.70748676792268, 60.502912921290246, 61.30699096187469, 58.4445511141131, 57.8147675145057, 55.93610125203287, 57.629886596433586, 59.96162191514046, 58.022056933372255, 55.932829995309156, 50.035730792630105, 44.08469115534137, 41.62622405636696, 41.95482846229307, 41.925120430607954, 43.08159989695395, 40.8915445112413, 43.27704375790012, 45.63956576008951, 47.89397547321935, 54.205084769956535, 55.97772936667166, 60.020951686366914, 57.26799303485502, 58.591522324469786, 58.450748458985366, 55.10481372956307, 53.14275395485663, 53.762590423707046, 59.47066668541201, 50.06684695520709, 52.0454316754495, 61.430898635618156, 49.273382848308934, 45.58821016742338, 41.250574742594075, 41.99367953884987, 43.3517570649424, 47.59912698499618, 46.74266176839029, 48.86584466503513, 45.753957763794936, 42.40265723197691, 41.496209252265196, 41.56028509140015, 41.89976230744393, 42.65388896388393, 40.15182079807405, 48.812912279559725, 52.57089591795399, 56.657095647627315, 59.977107432580766, 54.85226408127816, 56.30309781720562, 57.15164376843361, 55.41905441591817, 56.21718222095121, 57.762462708257864, 55.02483660174955, 56.327189014803984, 49.773834136224565, 46.08701405986663, 35.97577133486348, 25.817840637699252, 22.797582264869447, 15.31191235588443, 10.728706159899312, 9.746525056900518, 18.982237885075232, 18.296650725026286, 14.524265123951821, 16.078895561156735, 11.383853766226, 8.220497033288403, 5.63068985939026, 1.5754436365058346, 0.9355045302260308, 0.4693218873393151, 3.0207847058773045, 9.843730215103397, 23.369089249641668, 32.880701595737094, 34.695203765746086, 35.59973762881371, 32.47433620114481, 29.372029689050493, 47.94920244524556, 53.231779990657685, 48.38876678097633, 29.60004883427774, 4.88301795336508, 0.30188607833077835, 0.12086694053704701, 0.014039478602729017, 0.027918827592305122, 0.01994043363318328, 0.07552775043633676, 0.027019093714414105, 0.03592455556856529, 0.03532136091962457, 0.05715273320674897, 0.11700199631553505, 0.04880332095067828, 0.039846895097364346, 0.06497318856418133, 0.09658371533958182, 0.049551271743351416, 0.025110847219043685, 0.032635380048304796, 0.03549660353230373, 0.05238061064794179, 0.04989041886743038, 0.06894101839392416, 0.013537221783471685, 0.06734817604263944, 0.051120043612055244, 0.0452297582711664, 0.03820033466082908, 0.07324081710389546, 0.1251095048181953, 0.131479732752327, 0.11995493584582884, 0.1489811646000993, 0.13117697480465138, 0.16093801977413316, 0.15259461747782846, 0.18037730166988988, 0.1263298598989364, 0.10839106845519236, 0.17695412971079352, 0.1659100836202983, 0.11456543835060251, 0.16394094654148625, 0.09254874556415504, 0.0904381120457284, 0.07070150376567919, 0.07355338097700188, 0.21244874524493373, 0.09902996431675651, 0.15825211551160584, 0.25350670660695723, 0.1614075397411662, 0.19565989774081016, 0.1669125096692193, 0.1399907244429473, 0.12362108025099001, 0.8140576534694242, 8.361679315567017, 27.92313360398816, 53.34527769396382, 60.301954207881806, 56.70381499874977, 48.6669098946356, 37.54859470552014, 31.23788352935545, 33.11249209988502, 25.802372770924723, 23.83807332284989, 11.43408069687505, 2.701614825956283, 0.40935739694583806, 1.60144024798947, 3.010913080746128, 6.117796753683399, 14.008745070426697, 19.6157673481972, 19.644963510574836, 16.76042502926242, 22.4578736289855, 23.951696542001542, 11.504081276155288, 26.368498263820527, 31.935022069561867, 36.540541648864746, 53.94683591781124, 54.681809640699825, 61.50855764265984, 62.622251895166215, 61.587793442510794, 58.2768972458378, 59.50563069312804, 55.300430174796816, 57.314794755751095, 60.42431254540721, 60.583643144176854, 57.78194904327393, 54.84484295691214, 45.30048078106296, 42.90252016436669, 44.07618353443761, 43.65133985396355, 46.5455352106402, 43.29036020463513, 47.446833118315666, 48.64231271128501, 51.35744010248492, 57.71677494049073, 57.85976494512251, 60.413361287886104, 59.571624571277255, 60.26874742200298, 58.07647589714297, 58.79736438874276, 54.602173759091286, 56.70836102577948, 62.36565828323365, 52.47462134207449, 53.86202642994543, 65.3905705482729, 51.13166847536641, 45.89653199718845, 43.76870109188942, 43.36052748464769, 46.32596485076412, 51.56155632388208, 49.05185914808705, 53.10204759720833, 49.07203582025344, 46.44232980666622, 44.118764785028276, 43.88034351410405, 43.99791656001922, 44.402375682707756, 42.799055883961344, 50.83694942535893, 53.829925752455196, 59.00896057005852, 60.747386409390366, 54.64778700182515, 55.72609755300707, 58.80010220312304, 56.72936531805224, 56.609568288249356, 56.68778427185551, 56.33818341839699, 55.15296474579842, 53.75144304767732, 46.58801055723622, 43.33938198704874, 29.869605879629816, 32.480227601143625, 33.926756535806966, 28.674759749443304, 20.492264109273112, 28.00218309125593, 20.279559858383674, 18.341403007507324, 22.27649538747726, 21.597748841008833, 19.37102713892537, 8.153204850612148, 5.297362429480399, 0.9656985680903158, 0.8703163314250209, 3.4660909012440717, 10.319196005021373, 25.132243671724876, 37.595451339598625, 40.615731285464385, 38.58235497628489, 37.212000431553015, 36.79608798796131, 55.63146645022977, 61.75341944540701, 55.44875460286295, 35.326426875206735, 7.223703630508916, 0.509894026383277, 0.2778052075976326, 0.17966503908316936, 0.16147777468206423, 0.23298733266851596, 0.1909314804980832, 0.183663405177574, 0.17364444601680004, 0.11422257570009078, 0.07737572304904461, 0.19655513276736583, 0.20161738048397726, 0.15715693153681295, 0.16154514445412546, 0.2018203937839116, 0.10034603442275718, 0.12369738260824835, 0.10519869580504396, 0.18138875223455891, 0.19096161839702439, 0.19454183838059827, 0.29712775301548744, 0.14074221073139098, 0.11244615569951073, 0.20639010825224463, 0.10157480880978609, 0.1216093869879842, 0.1910013323950191], [0.052866999871067466, 0.05700819156763535, 0.05476620844415119, 0.013678580327259918, 0.04150609981508986, 0.029234522315222892, 0.00833806649391209, 0.060984118946737824, 0.04275564667618564, 0.022202133944618608, 0.046459643485685514, 0.04766860683899253, 0.05518349270606714, 0.03198020058804222, 0.10838121656448611, 0.05790853257020635, 0.07502016356034626, 0.008922043827272231, 0.02506883112683652, 0.056511663170831825, 0.06593683524237526, 0.02039884341009442, 0.07548236738770239, 0.16458950125642363, 0.08849928140520089, 0.027952267330199964, 0.010369881056249142, 0.1319974243280388, 3.645511144591916, 15.569597367317447, 34.632179121817316, 49.303400747237674, 48.95352925023725, 31.647461345118863, 24.364524041452718, 31.181472001537202, 30.094944084844283, 17.489171989502445, 16.908527843413815, 7.104860717250455, 1.0982532294527179, 0.10553673976251196, 0.1560748170220083, 3.0043029064132325, 6.0049658533065555, 7.1110614941966155, 10.031614688134963, 18.993802993528305, 19.571574003465717, 5.454444529548769, 11.236150053239639, 10.884065358869492, 16.784092610882176, 24.292650530415198, 37.749859363802024, 45.29945704244798, 52.16090233095231, 55.30587050222582, 57.506288789933734, 58.62684326787149, 60.40985468895205, 58.265589052631015, 57.99446698158019, 55.42637748102988, 59.60508238884711, 57.706765051810976, 53.935025661222404, 46.939498070747625, 40.801075043216834, 42.72241669316446, 47.670380761546475, 53.12162414673836, 53.102153501202984, 49.608012014819735, 50.57058126695695, 51.950451481726866, 55.74657624767673, 56.65260453378001, 58.52110793513637, 56.5862419528346, 59.05112997178109, 54.07363830074188, 51.772152300803896, 47.13910748881679, 48.72155243350614, 49.9738867821232, 59.07409937151017, 52.04931874429026, 50.71969409142771, 56.75040491165654, 45.780045447811005, 42.053468227386475, 41.08931433769965, 49.07322429841565, 51.40737971951885, 54.341936265268636, 55.6845518081419, 54.551610485199966, 56.15399675984537, 54.612124812218454, 49.60014766262424, 46.137906812852435, 42.30513926475279, 40.92956796769173, 38.92650765757407, 39.5197190776948, 46.8591247835467, 53.484851314175515, 52.71357213297198, 56.67309499556019, 58.43525117443454, 54.867831968492084, 55.78759639493881, 56.94191855769004, 59.18471021036948, 56.44447965006675, 59.67604983237482, 52.59838388812158, 47.98071084483978, 36.87757915066135, 26.547124962652884, 21.71317635043975, 16.29321582855717, 9.76756759228245, 8.660272686712204, 23.753450147567257, 15.518321202647304, 14.526238076148497, 16.37375875826805, 5.39742797613144, 5.31679924457304, 5.368652978251058, 0.31060661039044785, 0.7951519518129287, 0.45455079285367844, 1.6070829452045503, 5.85658553146547, 16.1120052683738, 25.043386297841227, 37.76218345088344, 26.90838113907845, 18.168453939499393, 24.934179667503606, 37.09115612891413, 46.666116714477546, 37.14853648216494, 20.36293571995151, 1.8931668972776783, 0.2990228093920216, 0.10893184226006271, 0.034866132322819, 0.026721526012425462, 0.03325213062306566, 0.10728515924945956, 0.0312740609590565, 0.048797900878614, 0.024243084105452704, 0.016180920347030607, 0.056863014075544574, 0.026361073983172258, 0.02859580991489272, 0.029359350596824964, 0.07822359852012127, 0.05473158510041334, 0.02430117080709146, 0.10862295560899282, 0.08407954396980424, 0.008782973971157786, 0.05892287894722916, 0.043109851258416335, 0.043988389398662314, 0.08682300441808279, 0.05244757822384277, 0.05143833016195605, 0.045983592619098006, 0.011603922297757481, 0.052311283521234035, 0.0804811830241834, 0.06836725684303431, 0.0182885546312337, 0.05555733978267639, 0.021468618163658727, 0.06958303071798817, 0.03084451545991244, 0.03701734551859479, 0.03786896715962118, 0.029215599943493164, 0.015569338950538828, 0.078019987671606, 0.04010275314231554, 0.10676860148387571, 0.06141585545734533, 0.04082737272725471, 0.04618759417245465, 0.09397777533459087, 0.02672061628301538, 0.04982689485674904, 0.032295030166184714, 0.09595830414083698, 0.033851655710849075, 0.08273030991756147, 0.05284519317830282, 0.051070960358746594, 0.18841633723387796, 4.536522146194212, 19.526629524846232, 42.21759588487687, 55.48407162389448, 55.35461379635719, 37.855210304260254, 28.03320315576369, 36.256754244527514, 36.82539593788886, 21.84793722245001, 17.330967110972253, 9.21302289732041, 1.6712264452249774, 0.12339748982940951, 0.19680673136345803, 2.849348447015209, 6.899678591758975, 8.73923784302127, 9.127339701498709, 9.230868701011904, 13.330349576088691, 13.375982430673416, 17.995989284207745, 8.997526899460825, 20.184014843356227, 27.163552891823556, 40.076554436837476, 48.96343323492235, 54.994877538373395, 57.720905196282175, 59.39331362324377, 59.852042659636474, 61.08034072383758, 57.12430877070273, 58.338792247156945, 54.43800687789918, 60.258576716146166, 57.709797043954175, 56.17460881510089, 48.054310198753114, 43.71515681666713, 42.53440180132466, 50.740863123247706, 53.94393336388373, 54.39033046845467, 50.65291181687386, 51.76182470014019, 53.577215286993216, 59.311171347095126, 58.731543094881125, 58.232394033862704, 57.21004786029939, 61.37427137744043, 56.824290598592455, 55.572062153970045, 48.96400197859734, 51.75545477098035, 51.87055280131679, 60.91036481242026, 53.48014446996874, 52.56688725563788, 59.6563595341098, 48.63453465123331, 43.86608177615751, 43.82302591877599, 48.44251894181775, 52.9990343893728, 54.83990077049502, 57.932615126332934, 57.54507318619759, 57.90079685949511, 56.26947133771835, 51.240584850311286, 47.92857470050935, 43.72741030108544, 42.14306300686252, 39.21705330571821, 41.43634996106548, 48.497228160981216, 56.26331713891799, 54.70688535321144, 56.95326205222838, 59.41311767024379, 57.75696746764645, 57.84496584246236, 55.7616695280998, 58.5533655074335, 56.85182171483194, 58.984900751421534, 52.910196627340014, 46.794319383559696, 39.28158021742298, 26.91319584846497, 20.049967842717326, 12.331609206814921, 9.94231604760693, 3.8137207636910104, 10.890780456604498, 15.195784703377756, 15.762994731626204, 15.366858878443319, 13.11704912493306, 11.057111505539188, 6.142362558072613, 2.811251446124046, 0.8467975547236781, 0.2951724208410709, 2.0589864446270854, 7.003126692387366, 18.552652059062837, 28.107239853951242, 36.25022349819061, 28.164102454339307, 22.875162824507683, 29.148421249082013, 42.90151603760258, 52.80737561564292, 44.51678729826405, 24.16399678876323, 3.0663562734280867, 0.3861340237480979, 0.09783144274185743, 0.06414927632337616, 0.06813526243692444, 0.010457370212421784, 0.06282824579806578, 0.07993469420339792, 0.01318951458444879, 0.02841785918140123, 0.05203943339086348, 0.03730913308719474, 0.020652035469069116, 0.035776152846313296, 0.036310085486019814, 0.056461584003221606, 0.060352264948549776, 0.026525049357705062, 0.056000628899182045, 0.0673501372277256, 0.03362390926227935, 0.04117994171176707, 0.04741707719081352, 0.031232249795369087, 0.06150068437320091, 0.01718750816860026, 0.045672300451945876, 0.06478676106780767, 0.017450919840484858, 0.12911791432528727, 0.2455787997572653, 0.1495232177718032, 0.1173245499751741, 0.23780050987918533, 0.10781057299144807, 0.1561144237676936, 0.1413307807618572, 0.12915552924236945, 0.12614816682593477, 0.11083824439875542, 0.12607870563384027, 0.16350559409587614, 0.11906752257698006, 0.2246582715381538, 0.14340885554350194, 0.11258405152588122, 0.11355185806150399, 0.2289380983359391, 0.16390104868238972, 0.14323723652670461, 0.11202518272423938, 0.14634311018932253, 0.1979088560948449, 0.1583783208362518, 0.15831499600843077, 0.20579609899751602, 0.5644527858784122, 6.193179805432597, 25.138947002349365, 48.64027307879541, 64.04369923376268, 61.922477522204005, 44.6491398349885, 35.67116006728142, 44.92381949578562, 43.28649274764523, 28.50106150873246, 21.25214292157081, 11.022021981977648, 1.6757060371098982, 0.5000130856229413, 0.2920784981500718, 6.3877058317584385, 10.929381482062801, 13.487839602654981, 18.42709110629174, 26.580374894603608, 35.72468080828267, 14.988922822859982, 23.75248916687504, 17.93430805206299, 20.34681477854329, 27.982496715361073, 42.66549525722381, 51.163714239674235, 59.303632551623934, 58.96994083158432, 60.91547173838462, 60.868673939858716, 61.897076252968084, 57.197186408504365, 58.90400578898769, 55.411892167983524, 61.4060543429467, 61.58475360562725, 59.607620162348596, 50.79271685692572, 46.3276828488996, 47.133074883491766, 53.70140144901892, 57.4660413495956, 57.18476033979847, 53.76810527616932, 56.19665645783948, 56.60143721488215, 61.58354159324401, 60.08324676944364, 59.571334315884506, 58.1193866268281, 62.248932469275694, 59.461249074628284, 58.005885001151796, 51.559340184734715, 53.536834486069225, 55.422160933094645, 63.76019816244803, 56.2448545425169, 55.73862168096728, 61.423861903529016, 52.328105126657796, 46.40818165194604, 46.24005709925006, 53.411310795814764, 55.32901248624248, 57.90897892367456, 62.390392749540275, 58.49849939346314, 62.20447632574267, 60.75943200818954, 54.459599525697776, 50.76588392257691, 47.618107334260024, 44.49516719387424, 44.13476805533133, 44.222511476086034, 50.54250494126351, 58.37078309828236, 57.70361931093278, 59.36187190394248, 61.4748566381393, 59.19288442980859, 59.74162009454543, 58.39530967896985, 59.28499737093526, 56.975278316005586, 60.763632866644095, 54.11726290179838, 52.51151907828547, 45.1149409048019, 34.11410854708764, 28.205287341148626, 24.930571086945076, 19.222220259328044, 17.607702093739665, 39.67567643811626, 27.973534099517334, 30.77140781187242, 27.692023631065126, 17.20995806878613, 14.952648743506401, 14.18631959346033, 4.732047886617722, 2.227496370192497, 1.3546238791558052, 2.4125376151454065, 8.649362614077907, 19.885991196478567, 35.62686081855528, 48.4325796558011, 38.67853541528025, 29.384361620872255, 37.31805347627209, 49.13712363089285, 61.0916449946742, 52.21716480870401, 30.278010906711703, 5.444161545845771, 0.5452208533402413, 0.20424486288139898, 0.14932709926318738, 0.2474062718571194, 0.07686832769503517, 0.25977177365172294, 0.2324966533530143, 0.10634605802835957, 0.08420883662878506, 0.1662369580158303, 0.1273818518365583, 0.08887786673562181, 0.13844457515064748, 0.13317159196782496, 0.1477402553803498, 0.160737503920832, 0.14951168048766353, 0.21918184604615937, 0.23359903855429542, 0.12963529946582933, 0.0699336615000521, 0.21502180475621455, 0.15191842231058306, 0.1820662344295171, 0.11306064248445535, 0.22032397588895214, 0.17872429843391144, 0.05135457759963409], [0.11289388046509798, 0.04528916838969435, 0.10153411421924831, 0.02622812133913319, 0.05513741251742167, 0.022161335932211052, 0.020719843826466994, 0.06387599743902683, 0.012541272050340571, 0.03325050268622656, 0.05185994665108381, 0.0694353825923416, 0.05282075497351828, 0.02532666759385217, 0.07405542903729985, 0.040050980920392665, 0.0398907000048747, 0.03604580047390154, 0.04801016330959336, 0.06534840310773542, 0.0322768623910604, 0.02162600326682291, 0.010300663097070591, 0.024794970015664736, 0.006151173231867893, 0.05907506231338747, 0.008939073961828987, 0.03450390296958147, 3.296804591532677, 11.041582842026989, 30.305381205774125, 49.78769187004336, 39.67626871601228, 31.699056202365508, 26.1086824247914, 20.72821036461861, 20.140303950155936, 22.151771860737956, 15.294490168171546, 8.601950964620038, 1.9102968684127255, 0.9211112703046492, 2.5304492106360774, 2.229878474627772, 3.317682142219236, 7.976969326696089, 9.694457554048109, 4.462947797390723, 4.343336099578488, 11.404066720316488, 22.42405495335979, 9.985470944835294, 23.96945115058653, 31.247234459846254, 37.32916555097027, 46.04647636413575, 55.58194652680428, 54.12145199314241, 57.844185290798066, 57.01650242651663, 58.43639650652486, 57.45124224693545, 58.88221702268047, 57.6204336843183, 58.50775226469963, 55.37495128570065, 50.462943584688254, 46.62279413592431, 40.317019262621486, 44.31866445849019, 56.42491879001741, 58.4286694372854, 57.694162476447325, 54.28336743385562, 56.10303732656664, 55.66028802625595, 57.06551636418989, 56.968484770867136, 58.64594521061067, 59.44968200499012, 56.75613941684846, 50.124705837618926, 50.021159187439956, 43.472832787421446, 48.87752940577846, 48.414936834766024, 57.92921835376371, 53.718910909468136, 50.01293005481843, 55.236750495049264, 45.23943301170103, 46.375665203217544, 49.59864931721842, 53.287548249767674, 55.55550975184287, 55.47305368608045, 56.03516071073471, 57.55480850896528, 55.90634615190568, 55.715079615193034, 55.15820895471881, 54.313875629055886, 51.722412724648755, 52.9994736948321, 46.98902976128363, 42.462049761126124, 38.62164143593081, 45.970931514616936, 54.75540899461316, 55.538239555974165, 53.661048104686124, 55.27549174524123, 56.865220531340576, 55.77893580159834, 56.74589810832855, 56.14203745318998, 56.79160548794655, 51.08383909348519, 48.16900814733198, 37.93194755431145, 32.36305071461585, 23.040612320746146, 10.637116855190648, 6.521878838539124, 2.1372747469332913, 8.218602038198902, 16.73072680350273, 14.659949714137664, 11.34867500874304, 9.624769783789112, 7.548837719425079, 2.816726584588328, 2.2727894494610448, 1.2729788860005717, 0.2219215296809712, 1.4745966801720283, 5.030822177087107, 17.145397816934896, 28.41701884423533, 32.09308574276586, 30.389184605690744, 25.517720483964492, 26.617590342798543, 43.71031268950432, 47.41060218503399, 36.510731635555146, 19.66210230704277, 3.9675855396255373, 0.0230970855186423, 0.08034900221372805, 0.013757871385032852, 0.0821112112833127, 0.05671841497983664, 0.04810529610803051, 0.011858085373176203, 0.04542155221344964, 0.015403052863304414, 0.0007674871120534298, 0.06902171809586786, 0.03224107842411726, 0.028736323846744436, 0.047818105066976244, 0.001354539570222128, 0.04602025758715407, 0.024710422637121334, 0.07520736480552344, 0.06169685650797141, 0.027039555922871637, 0.06003433462953376, 0.0567814601855653, 0.11388254757489889, 0.05897463584739355, 0.037790282268918333, 0.022821134902657043, 0.011063447267177605, 0.03549358131544244, 0.027790438917074955, 0.07623867236918981, 0.02314923120842826, 0.01677719722201507, 0.04686543259829764, 0.08368058836147671, 0.02392658445563528, 0.02463868999433133, 0.07694995436336725, 0.13222524355496132, 0.023432930803767616, 0.0060315624878351255, 0.026992916490041444, 0.04210929063359096, 0.04674031511850415, 0.038690098501261205, 0.03638655638262149, 0.08368103269247279, 0.044289936927417596, 0.06589075505372978, 0.02759114497401301, 0.023022853513999332, 0.0018436870689789255, 0.05496955499233258, 0.05877655615369159, 0.03016679577769772, 0.036672502530798796, 0.2226125256669137, 4.073233109328055, 14.95764780429102, 35.6340269888601, 54.62852816427908, 45.88640051503336, 34.731858315006384, 29.181875144281697, 26.541590498339747, 27.164968867455762, 22.381601179799727, 18.42657139224391, 8.454986618411157, 2.0783139236511725, 0.647008626932098, 1.3781778346146307, 0.4403472775893827, 4.338147294136786, 10.044330031641069, 12.355535664866048, 11.18500626856281, 13.112680585153642, 12.442598554395861, 19.279075014975763, 12.581639712856663, 18.372407382534398, 27.764550216736335, 40.27723858433385, 50.22275332481631, 56.03403106812508, 56.92306372427172, 58.04823875427247, 60.80426862162929, 59.31353653630903, 57.321337269198516, 58.54595222780782, 58.3972434074648, 57.97181529383506, 57.526967525482185, 53.87441719731977, 49.972972869873054, 41.49590330739176, 46.43036657764066, 57.61077288658389, 61.17052385883947, 57.9914899026194, 56.320485684179495, 56.66705062312465, 57.32740909822526, 57.017082937302135, 58.88863402028238, 58.45522388335198, 60.210049152374275, 58.0198682508161, 53.1162779561935, 52.53932868280719, 46.77393874814434, 50.3572553203952, 51.69570922851563, 59.13717892862136, 55.47729376823672, 52.61833698518815, 56.220971230537664, 48.17313840312343, 46.404886861001295, 52.33955844756096, 56.183798928414625, 58.29551673704579, 58.829312093796275, 56.62473217133553, 58.82798633267803, 57.703878187364154, 57.914140762821326, 56.45826678122244, 54.94469865675896, 54.111010643743704, 54.607092411287375, 49.818490320636386, 42.61668136042934, 42.0475140694649, 49.474376863048924, 57.5448731453188, 58.99997834236392, 57.01746340720885, 57.8567760990512, 59.4617707498612, 58.68440012778006, 56.60452412020776, 55.751388995878166, 57.76671455752466, 52.98534531747141, 49.05417334648871, 39.2548845660302, 30.88721775239514, 21.133477495562648, 10.256064476505404, 6.215862381842829, 5.271913601506141, 11.121306976964398, 16.237388733894594, 17.661197339334798, 16.263752945007816, 10.684689321825582, 8.04529897628292, 3.88878561315998, 2.7036419558909635, 1.2937815439316536, 0.37906520789669407, 1.553369762916719, 4.998006157336697, 16.418556148006072, 28.76259730708215, 41.76558979095952, 32.82065991432437, 27.278070411374493, 33.052322941441695, 47.20721160211871, 55.955685646303245, 41.79163040653352, 22.97662473494007, 5.118046864386528, 0.14911241078328702, 0.03611615415842783, 0.02294832656550552, 0.0209178430809369, 0.06297569474085205, 0.02699070058072046, 0.040357450564061446, 0.05879863480766935, 0.024236244855508692, 0.05728125594736588, 0.027196408594928445, 0.0886200704882222, 0.02196841584067912, 0.029747157710634416, 0.056268227241572835, 0.023390891728922728, 0.03070961503732589, 0.14826487239089706, 0.03738090020394133, 0.02046103825822713, 0.006969504522144675, 0.028654566943465222, 0.1111693935649049, 0.05307672793165811, 0.019214823879601977, 0.048668416697652116, 0.03599241946733767, 0.1105288521296555, 0.20308085356748876, 0.18409212330175986, 0.12952740364257367, 0.12314529368473638, 0.08441468445403923, 0.1265655545097205, 0.1385711328757386, 0.1326190893568339, 0.18156843049631965, 0.3129640161510437, 0.1325016480780417, 0.0969176760484134, 0.1541190558383542, 0.26777650379846174, 0.11726874813076951, 0.09830105463944136, 0.10233350398559725, 0.16455475150817828, 0.15894934745325198, 0.1690334240875898, 0.10802451836606188, 0.16419553288048314, 0.2112132905712051, 0.11067121424862456, 0.08117272293255215, 0.15178760513663292, 0.16806170284267397, 0.3267577663064003, 5.598092021480684, 18.32735307755009, 42.40757196180282, 62.60364417106875, 51.74191082677534, 43.090295791625984, 37.77897511759112, 32.6231901491842, 33.19430097456902, 31.94538497155713, 22.675775020353257, 10.199112642195917, 3.0365158617496495, 1.5058064893368752, 6.074352091358555, 5.088972295484235, 9.978736235249428, 19.235742630497104, 22.690982049511327, 14.672437560173774, 15.564271769215985, 22.86061083116839, 33.200208064048525, 14.761435158791082, 29.06558471341287, 34.186248779296875, 44.307811260223396, 52.56738539664976, 58.73880340207008, 58.87842016835367, 60.95569564450172, 63.0446284048019, 60.653579004349254, 58.78271825851933, 58.984257482713275, 58.3623186234505, 58.43494915193128, 60.73335609128399, 55.152117513841205, 52.971538574464866, 44.342398720402876, 49.027207051554036, 59.81399174659484, 64.21897034491262, 60.23086909324893, 58.72935833469514, 58.16598830684539, 59.41033670979162, 58.384986000676314, 59.192362754575676, 59.64480423158216, 61.718863364188906, 61.233222946043945, 54.71960559968026, 55.12151125938662, 48.755076931368926, 54.00281990728071, 55.222892761230476, 62.17143820178125, 58.747416926968484, 56.12504966797368, 59.28448746281286, 49.98654819303944, 50.13148761564686, 55.024966039965236, 56.85655601562993, 60.28595093757876, 62.87437008273218, 59.98559151926349, 58.85753746955626, 60.48432480904364, 60.39315323675833, 59.73894896045808, 58.90188770909464, 58.28980576607489, 56.69509556985671, 52.93013795729607, 46.32651790495842, 42.874200651722575, 49.83217154779742, 60.87233351122949, 62.17595284984958, 59.765252374833636, 60.50026532142394, 61.64880983291134, 60.10648289034444, 57.26923642619964, 56.08489636451968, 59.049561023712165, 53.24832847041469, 52.38785851386286, 44.841343818172334, 39.29480252727386, 31.182878171243978, 16.839437254013554, 12.079708710793527, 10.005286758945836, 14.89645294604763, 28.65522634598517, 20.834694870056648, 20.669647416760846, 20.71391724771069, 16.987340027286162, 11.028256589366544, 3.174875753541147, 2.6409396817607265, 0.6827004794632235, 2.900156378746033, 6.599897723044119, 21.913580048468805, 37.55276026264314, 45.78725084181755, 42.42590511998823, 38.778614690226895, 38.89957274160078, 54.92444745955929, 61.84099420424431, 51.66429496580555, 27.777199860542055, 6.887644760070309, 0.42393421153387717, 0.13578825720375584, 0.13280295045866122, 0.16952562025718151, 0.1329086859139704, 0.16006543030661924, 0.12378285503796033, 0.17325421614993006, 0.10791135185788717, 0.18026042729616168, 0.13478339499523564, 0.13816020331315457, 0.14305873804034727, 0.19024327307218508, 0.11887825289440733, 0.20402677297111482, 0.09163094924822932, 0.18073140283025083, 0.10044615445358139, 0.12616627714446477, 0.11492946034958286, 0.11761128136347379, 0.18052149473899798, 0.12633731393443962, 0.19038156726427619, 0.15912966922886912, 0.06725795386779694, 0.15601216635156065], [0.05158505515165387, 0.021906494868979342, 0.035781791253436, 0.04063744420906709, 0.018581387909850287, 0.07308649635242839, 0.10584427043795587, 0.04166074998436436, 0.013476245972748487, 0.05153265856807271, 0.0894825399342564, 0.07554876422809978, 0.0443309226313666, 0.08788148512042339, 0.07122141699637137, 0.06832511434631963, 0.0395623393987696, 0.044001658041510856, 0.022985355425325614, 0.04143072825465952, 0.08987212628726998, 0.05126935031805789, 0.019066281346303803, 0.08434101743924041, 0.0760280747988051, 0.026563865117608543, 0.026367863437401193, 0.07673473728279914, 1.8582459130594808, 10.279673222572574, 31.042696583655577, 46.93914897980229, 40.82997898901663, 31.848180793946792, 23.058639534058113, 28.355953424207627, 32.05818057060242, 19.373362910362985, 13.137454275161991, 6.258165634447529, 1.9941290732352965, 1.540001957647262, 6.829257828574027, 12.544651762131723, 3.818078026656182, 7.147721927012167, 5.298337628764491, 9.508526421362355, 13.258723174372028, 11.018395750753342, 13.663292123425393, 9.658873811844858, 17.79060221487476, 25.112594558346657, 40.03347112286476, 46.61967585163732, 54.635494293705115, 57.640441694567286, 56.717355020584606, 55.538886747052594, 57.49261148514287, 56.849676178347686, 58.07382045253631, 56.024378115131015, 58.15488407688757, 55.436442282892045, 54.09435625999205, 46.40218827032274, 40.72135286946451, 44.84736857875701, 53.54892715331047, 56.04135805560697, 56.02729635853922, 57.485057000190984, 57.59107474357852, 56.46560161344467, 58.3472292653976, 56.80483564253777, 57.4115910068635, 54.751196369048095, 52.669265039505504, 49.29693668119369, 46.232008395656464, 42.11815987863849, 46.51429353221771, 51.1909511781508, 57.87509356775592, 52.810768465841974, 50.61753988265992, 52.0866047951483, 46.3369631767273, 47.42806457704114, 51.942696955896196, 56.2080587879304, 56.05999323629565, 51.5786539354632, 54.51937644712387, 55.19491449479134, 56.52269955604308, 57.550964586196415, 55.38847954042497, 54.54962576589277, 56.30533749057401, 55.366216167326904, 56.37822689548616, 53.62917492466589, 43.556661682744185, 38.6322122235452, 40.58272061809417, 44.69567483471286, 47.36547531620149, 48.467422070041785, 54.790443604992284, 57.51275285597771, 56.149533102589274, 57.49327828807216, 55.45743480805428, 51.86622642701673, 45.097564804938536, 37.2525381272839, 31.853601509524932, 21.920654043074578, 13.25784456345343, 6.926232547529283, 1.4726770476948832, 5.51512114463314, 9.012991824457723, 15.858887857006444, 16.074575070411928, 12.549448820852465, 8.709986767461224, 3.1523054549770975, 3.80116623736197, 0.3802883438766003, 0.2137666769445904, 1.4031655389455058, 4.054434659980958, 13.4041372037703, 19.74976335802386, 27.69612054671011, 26.617529546060872, 26.70387660303424, 30.789942972121704, 38.336100732126546, 50.78571542616814, 43.10421236099736, 16.835714924720026, 2.586121371676845, 0.17558592732154554, 0.04317305351216947, 0.024391075055445396, 0.01806038108864619, 0.04810086428938855, 0.038386417417636806, 0.06122218843008723, 0.07939893061355238, 0.05022217324304004, 0.03382313425742811, 0.0468092821838875, 0.01151385429810973, 0.04537995746960083, 0.05771885686103375, 0.05878716647144287, 0.042109838386456815, 0.02019188667256986, 0.028073357102731546, 0.03395126246276402, 0.05422149694735005, 0.08027719679258524, 0.04289252743605645, 0.0786042446270585, 0.059654125192713355, 0.01934478878073635, 0.03575809998437762, 0.05192112643271685, 0.015581262151470349, 0.021879063175630667, 0.011071387768512773, 0.03400057171201033, 0.04019214794219982, 0.0668598409561861, 0.03869345013592993, 0.04239712518850162, 0.04777152309074037, 0.028823502737307743, 0.02692694099800241, 0.05273823581275441, 0.04570063038338577, 0.023417687569294247, 0.018596075730578556, 0.09530352113107521, 0.034622543175975164, 0.05865595859265136, 0.059670090465055364, 0.03866181836553639, 0.04094706247410467, 0.05704427813930858, 0.1159284543246031, 0.021898142595384872, 0.07219723681168211, 0.06841550506050549, 0.02483813523975832, 0.05626670655704314, 0.05561680735779866, 2.6876548653648746, 11.88432466599249, 35.22654371876871, 53.882752233935946, 45.841928682019635, 38.45297167378087, 27.214565277099613, 32.19268648855148, 32.85879908069488, 25.060787893110707, 15.180135426982758, 7.441204940119098, 2.95884435215304, 2.433696105595558, 7.57944691565729, 10.136958764445398, 3.0899503106071107, 4.05839674415127, 8.018066450472801, 12.674847975853952, 12.957067412714805, 14.470662993769492, 13.259808690317216, 12.815614977190572, 25.681677518352387, 29.67851781076001, 40.002982539515344, 48.32131378112301, 57.502527236938484, 59.592091498836396, 58.298799760880016, 57.1238459310224, 59.61661807952389, 58.418859589484434, 59.16731057628509, 56.9265938574268, 58.55233000170801, 57.200536112631525, 55.506382065434615, 48.590278548579064, 43.383853820062455, 46.905981417625185, 57.33204533976894, 57.3542812562758, 57.37637204508628, 58.535079417690156, 57.73846956991381, 56.38296119628414, 58.30884495089131, 58.56976493712395, 59.55391114757907, 57.81237094633041, 54.52514233127717, 51.47853935918501, 47.31090730236423, 44.913189872618645, 49.20537287189115, 53.54923702055409, 59.39092489980883, 55.03588199615479, 52.76062880792926, 55.68467732398741, 48.37426185607911, 50.457240458457704, 53.54757393560102, 58.78684459194061, 56.3963992364945, 54.02220033830213, 56.33111922971664, 57.01159946380123, 56.51791818680302, 57.88680968746063, 57.12382631917154, 57.07120380093975, 57.52144875064973, 57.15879424925774, 58.87997342694191, 54.65895006733557, 46.19504005678239, 40.771394468122914, 43.0980856187882, 48.48368813914638, 50.98082588564966, 51.48426601963659, 55.595380644644464, 58.911179804032855, 56.7851649561236, 56.569383605833984, 54.00917022458969, 52.97369980042981, 45.827914053393954, 39.0126193723371, 32.365955229728456, 25.179233666389223, 19.38155674165295, 8.696229054081826, 7.904161801261287, 14.445506872669345, 13.237562967884926, 16.914199590682983, 14.221952365290734, 18.928852465844926, 10.04610098177387, 6.965408690514104, 5.000754758234947, 1.3946119527662955, 0.5120785720646381, 1.4484898746013644, 5.317789152745278, 14.540144839594442, 25.591490460980324, 31.85011256125666, 32.25132592262761, 31.560625953059045, 33.36886605908794, 44.27321987767374, 55.53115575544296, 47.42007470900013, 20.38358699890875, 4.166820616491379, 0.14293096989633577, 0.05372215700786441, 0.015994160560019795, 0.05266180322054894, 0.10818551940422867, 0.044067756107617775, 0.0741090934963957, 0.051971527357255264, 0.07104835007339716, 0.060516387795008, 0.023573180435285456, 0.06615140114820774, 0.049354226268347234, 0.04931558862388615, 0.1050917499308144, 0.030530015299577388, 0.0167786700260495, 0.059560187491438085, 0.011088085612432371, 0.029157394498226144, 0.05032783591999643, 0.06022294930693123, 0.0875857368772549, 0.011865504934722859, 0.03541709126664266, 0.022945099420124487, 0.06364273515740229, 0.03692048902232801, 0.17983347117420168, 0.1078824703431418, 0.270180334487269, 0.17005051305938154, 0.2276393494779064, 0.27161635097957426, 0.1353079353969905, 0.11114990428811121, 0.07922835347633209, 0.1188318049835582, 0.11560980005249863, 0.25342597626149654, 0.1541317116108633, 0.1289439051141662, 0.24024146518880324, 0.11081515450871761, 0.22342175966308964, 0.12260822008454031, 0.20718573652688535, 0.10035992359682437, 0.11571744306673927, 0.21329832143120228, 0.12513860083755948, 0.2063836577919222, 0.14934786024593538, 0.12566314890019356, 0.18090787884448806, 0.2592624171126274, 3.409211140486502, 16.026745688530706, 45.0740933418274, 60.76212275412775, 52.97156603105607, 42.72959070820963, 34.03384900862171, 41.28559366349251, 45.78998081145748, 29.74263679596686, 19.23961989341244, 8.380767530010592, 3.3570455783797852, 2.5342083121499708, 9.202608023920368, 17.842965856675182, 15.077524262089884, 15.472579502290296, 13.734651803970339, 21.039436709496286, 26.04958995696037, 20.103847480589344, 23.364735418750396, 15.206460414394257, 23.405122103229647, 28.81331159222511, 44.371816496695246, 50.51554256869901, 58.43672990798951, 60.70011792644378, 60.846226215362556, 60.6254909115453, 61.5206777664923, 59.8326700733554, 61.02956564195695, 57.63112998777821, 58.71754023336596, 59.71342217537665, 60.12628301497429, 51.21654464352516, 46.01832943577921, 49.22896200610746, 59.936530513148156, 58.22463166329169, 56.78654563042426, 57.8513357716222, 57.04435909948042, 56.613741690112704, 60.397836546744074, 59.088533693744296, 61.70143627351331, 60.24404041228756, 57.89555265057472, 54.42092495579874, 50.19636754066714, 47.22071240025182, 51.11313135393205, 55.645116298429436, 62.795844231882405, 58.003370761871345, 56.18571304505872, 55.389624872515284, 51.750312543684444, 54.05543065840199, 56.749522378367764, 60.68613859914965, 59.917722748171904, 57.39091619368523, 57.99197235415059, 57.384875743619865, 57.260132605029696, 58.26417307699881, 56.90687610257057, 57.32949972152711, 58.561123955634336, 59.20341599372126, 60.077798597274295, 57.781105733686886, 48.8092174068574, 42.569424644593276, 43.873750009844386, 49.626035305761526, 54.09183809834143, 53.29992332766133, 59.59163258152624, 61.086479233157256, 58.760603935487815, 57.20792585803617, 55.74046127257809, 56.27198165462863, 48.6312908511008, 40.78368717624296, 36.546601710780976, 25.997893118089248, 18.454239791439427, 11.510837558777103, 6.71925986005414, 13.126614805190796, 18.32959863447374, 25.931283427822976, 26.782214180115734, 18.443164979257894, 16.530260347550918, 6.323890830239942, 8.497159942503899, 2.3058717000869016, 0.5765132161398088, 2.51680328480659, 5.388273654445525, 17.46824614463314, 28.107251621061756, 37.84158006791146, 39.12876859787972, 39.8118572081289, 43.548836554250414, 51.720898689762244, 64.62221745521792, 56.17243582202543, 25.10361429183714, 6.387697496721822, 0.3674753088383906, 0.12299646578368642, 0.11646456265401457, 0.1069698374598257, 0.20323128259230047, 0.20783361708444936, 0.10253249532392911, 0.17754521250965136, 0.21797924122262388, 0.11831723138569825, 0.13848937597245942, 0.12957886942932684, 0.0951686283693679, 0.11250863016973581, 0.17868968658149245, 0.10370477838742156, 0.07140953754705769, 0.0735187691245829, 0.17174741313342126, 0.19529130219692187, 0.16333723861363628, 0.13639289975887345, 0.19108835998321735, 0.19701633301954116, 0.07784220930789748, 0.08246408670299477, 0.15114058259754412, 0.1279929142084814], [0.034953776611796314, 0.014202262710539565, 0.032514617778360844, 0.017065476107921813, 0.0502995711060301, 0.03299795031066864, 0.05331147642385575, 0.015339889871557395, 0.036291013727144855, 0.03756066656581337, 0.03849256272998549, 0.055009529460221536, 0.019152387713773117, 0.09862668797253601, 0.024557325711113312, 0.018248970868186127, 0.01677123705796417, 0.028734138580940427, 0.03219941856279489, 0.029798857154204484, 0.016395470931104595, 0.01407522522288585, 0.048293477945750764, 0.05808140031032025, 0.09601335521907577, 0.02183805065860431, 0.06122222673448344, 0.10523758242808043, 1.3689194475450825, 8.224802815145063, 33.937170428614465, 45.484345805260446, 32.56999300372216, 27.393917614413848, 24.93718028068543, 24.627636632611676, 18.442876685050226, 12.25266170117163, 19.12223708245062, 6.550960271589219, 1.3976422288725454, 0.04596476600835881, 0.093286105191275, 2.0527393346832645, 7.116180187271488, 4.48646632894393, 10.251621411692712, 9.508693122094678, 10.418342736459548, 12.030079941595755, 14.017085990598126, 14.639687730420022, 18.82082450774408, 24.032454221479355, 35.257593201052764, 46.79717879141531, 52.321935238376746, 56.30362733717888, 55.12571211784117, 54.051547511931396, 54.55243418293615, 55.130524866042606, 56.06628471805204, 56.71831207890665, 54.76998059980331, 55.11529822503367, 53.88494483886227, 48.187698241203066, 41.041665384846354, 44.500038777628255, 52.25018332081457, 56.975419521331794, 57.5195973919284, 56.619554642708074, 59.024155832106075, 55.84717719785629, 54.26628158938501, 51.652045403757405, 51.80575132369996, 50.04555632991176, 48.34277306833575, 44.05700706666516, 42.33059152480095, 40.904868802716656, 48.14445018768311, 49.87039504512664, 56.56621825310492, 47.83080177922403, 49.565775932804236, 55.27913954950149, 46.12655939594392, 47.21420518813595, 48.352680975391024, 53.35422854269705, 54.53408141289988, 58.57945711381974, 55.817426020099276, 55.12210745965281, 56.0581144209831, 57.65931613983647, 55.71456970707063, 53.681440507211995, 52.25883214704452, 56.305666969668486, 55.32232876746885, 53.58057675823089, 53.843779563903816, 47.642641759687855, 41.28333437827326, 42.545913957780414, 46.02180465575188, 50.68553416959701, 51.0989559081293, 56.58251177880072, 51.6131825600901, 56.266411888983946, 56.49545869519634, 53.71667908084009, 49.74836226432554, 42.43960595900013, 26.755083145633822, 21.121731958081646, 13.540829843090428, 5.5007770369129805, 11.167110454651619, 18.53488568336733, 15.304406900559703, 17.085059996574156, 15.455195557686592, 16.152633178618647, 6.805310287783223, 6.3624688117734856, 1.9166832224976633, 0.6467693623515868, 0.5370337023369728, 0.8088314629370167, 3.8406203783327535, 11.49603747552441, 20.17743898976234, 37.86266280758766, 26.230534776564568, 25.10827406760185, 33.4327144007529, 37.41578717385569, 45.67998186234505, 35.64088721429148, 19.803952863139493, 4.311731601915052, 0.05262964667992727, 0.08029526880671901, 0.007092639749434086, 0.08578461820199605, 0.0342986986581837, 0.045584196510214, 0.044001661871950475, 0.07256249987309979, 0.009567769762549189, 0.03154647990971083, 0.01291809729375546, 0.019071693757488843, 0.03942768795475845, 0.038952246128070744, 0.11819089582610516, 0.01552779974806453, 0.013029116840522378, 0.06025526289557738, 0.03501905113338463, 0.042250890495075334, 0.041143552535363746, 0.011906609382300128, 0.03744696762653128, 0.04912455310864795, 0.028591366604931896, 0.01520946436005855, 0.027920668118543206, 0.03391101986410157, 0.06487870694047983, 0.03307625215740935, 0.02192113480921234, 0.013229142397552008, 0.04541825420493561, 0.07926100414366492, 0.09020434797651346, 0.01746731412206446, 0.0796430521915036, 0.03772136499925006, 0.010414286385170154, 0.02044128851153918, 0.04556268476130021, 0.040012810589565385, 0.030471465114744443, 0.03617191769843621, 0.016640205379395236, 0.021701600823190906, 0.02946856983696982, 0.017342874630083962, 0.07714137675300722, 0.05518884766065786, 0.016112443577918797, 0.021599146139417446, 0.06096698922075092, 0.05135807479100843, 0.1063962291265207, 0.11623085987183357, 1.7669917258524128, 11.091243970778681, 39.7417526860391, 50.33154418391567, 39.18642743941277, 29.143412382371967, 26.941195687940045, 32.03569362240453, 27.07554863345239, 15.7565983264677, 18.552856022311797, 7.4759502756980165, 1.8691326966208799, 0.09314064041621263, 0.23088175533038957, 5.526854915003623, 11.420556364520905, 5.095587372779846, 9.180747674357507, 13.302017315741509, 17.455865183184226, 11.186148658875497, 13.406196448110766, 16.404264992283238, 20.463375852954005, 28.965042598785896, 37.58217411656534, 50.06432094881612, 53.29015270356209, 57.96823809223791, 58.01881313323975, 57.50765769712387, 56.6357030407075, 58.65081679436469, 56.46136545365857, 55.72692125074325, 54.58844154111801, 57.26769885709209, 56.142896452257716, 50.045658311536236, 41.94813297640893, 46.18233942216443, 54.4237922083947, 57.617801773932676, 56.8280246949965, 57.36102773297218, 57.676241167130016, 58.055914832699685, 56.65287125495173, 53.88101854631978, 55.14357066923573, 52.49677096643756, 51.595151424407966, 46.91420270550636, 44.37942589482954, 43.685578223197695, 49.02478694915772, 53.37491120061567, 58.875003783933586, 50.50879216963246, 52.88710955650576, 56.10115066651375, 49.384338855743415, 49.396964965328095, 50.124619545475134, 55.457674072634795, 56.86517738526868, 61.02495293463431, 56.816532150391616, 57.72072084488408, 57.98359417146253, 56.82205484759424, 56.52132280411259, 54.36239534808744, 53.00875794502997, 58.736214637756355, 56.30313311853717, 57.16501120598086, 55.498556936940844, 48.95365868845294, 42.25257165970341, 43.601663035731164, 47.49866724014283, 51.54089327781431, 54.317884291371996, 58.869214365559245, 54.134525252926736, 55.97058673058787, 57.06070361598846, 54.249960607098, 50.92273558339765, 43.35714247918899, 30.422220768467074, 27.774593445562548, 17.625225282484486, 4.737369072052741, 11.961102120337948, 14.046238026311322, 14.404492608962522, 16.260636621905913, 13.650507157848729, 13.26898213355772, 10.329652063308224, 10.246590971946716, 4.292057973723258, 0.8804000096936381, 0.6727697123442927, 1.887117744453492, 3.948516201588416, 14.263278457426257, 24.167577912730557, 38.85930961178195, 29.06313519324026, 33.72347577925652, 40.75475185148178, 43.1064167330342, 53.75757371225665, 42.41628354595554, 22.45040543617741, 4.9139370168409044, 0.05344970166803368, 0.06691283125790858, 0.04112070396302208, 0.03075957163086822, 0.046537673371213104, 0.052619415575698505, 0.030664940620021477, 0.024538238630479863, 0.011114860385385974, 0.023706215433776382, 0.11181633183432203, 0.048842525500203335, 0.017802060071018436, 0.016888132499110316, 0.04348326166490874, 0.01502087745334833, 0.02505852341381533, 0.03841579688953296, 0.02850321095226513, 0.03817380120557162, 0.04240688131821733, 0.03655935517482219, 0.05111776067004089, 0.05870549000739571, 0.035087949250854795, 0.0484550420585419, 0.018206315092562188, 0.026085339787025607, 0.14961214525805366, 0.2318127053759752, 0.12567256412078298, 0.13681899786235827, 0.07767787578726008, 0.20838215135999266, 0.16932752524172107, 0.16102109434864215, 0.20643020529420147, 0.10850451841589906, 0.0943776579093068, 0.1507784068704613, 0.13242657146146222, 0.2706831333137328, 0.11152235325425865, 0.22676481414706479, 0.1514492547439952, 0.1187834265311399, 0.11791723389779368, 0.17655055459228255, 0.1836121232519227, 0.0889752441716771, 0.09720437679319613, 0.14035034143636305, 0.11867622018701608, 0.127441284937724, 0.21866072239654682, 0.28026312409389403, 2.3758384489244033, 14.465033411979677, 43.43683327397993, 58.0994099955405, 45.28751342527328, 38.569399387605735, 33.857852258989894, 36.97470095849807, 30.595969999990157, 22.26242192329899, 25.080474269005563, 9.12053733102737, 3.150047150350386, 0.13377223554397785, 0.43406030042998256, 4.701776504516602, 13.473505300860252, 14.59635534594136, 22.133579907878755, 22.11740209210304, 22.717067772342315, 21.46508839822585, 23.255732751661732, 19.980832146060084, 24.69511905024129, 26.86800426052463, 38.418360679380356, 49.753045574311294, 54.68016616759762, 59.73741531372071, 59.68115283596901, 58.24860518978488, 58.364056233436834, 59.51750370763964, 56.497070789337165, 58.46582997229792, 54.57206564564859, 57.741548630499075, 58.64949495561662, 52.97071487672868, 45.57197547728016, 49.28167081648304, 56.507214038602775, 58.8267154847422, 57.69204439655427, 59.11758668961064, 59.832772054979884, 59.04062586445963, 59.75756060692572, 56.08087985746322, 57.89360323259908, 54.701864719390876, 52.93309542440599, 49.53912342748335, 46.738539357339185, 45.91308439931562, 51.649762584317116, 56.150690201790106, 61.542544980202955, 52.94392901082193, 55.69763683503675, 58.44333910172986, 52.84482640604819, 51.7906266643155, 53.657765080851895, 57.84122390131797, 60.03589199435327, 62.49245674379411, 59.382162324843875, 59.974836380251, 58.48161751224149, 59.10765132596416, 56.59198822513704, 55.693808601748565, 53.579874653970045, 59.50497173493909, 57.37379504788307, 58.669573568528705, 58.67588466213596, 51.799146052329775, 45.37142076799947, 46.792679832827666, 52.220640028676684, 54.976638517072125, 57.32283561460434, 59.91462799810595, 54.42693402690273, 56.09430613056306, 59.0461132603307, 55.01184963410901, 50.401774221850985, 43.686276405088364, 29.524058795744377, 24.09925610788407, 17.231829204866965, 8.989422302092276, 16.3718387580687, 24.651061027280747, 20.6570154236209, 25.82105305887038, 21.6549232698256, 26.654095841992287, 14.972961718036284, 14.2426360038019, 6.366047484259452, 2.09517962509586, 1.169649314495825, 2.013805398056584, 4.892767494724644, 15.29246622516263, 27.09413282332882, 48.791680489816976, 37.94581705524076, 37.92475784978559, 46.8174692123167, 50.09813962444183, 58.96007607060095, 48.92371923692765, 28.08720634829614, 6.804359603312708, 0.3764336345897567, 0.121905303770496, 0.08571042258652949, 0.1961028804221461, 0.14953113912094027, 0.14724102652361318, 0.17463332763121975, 0.11705270367524317, 0.08141997014923442, 0.12488812839071597, 0.2114630658780375, 0.19937706360172844, 0.10013587352248932, 0.1116012909539765, 0.3993542191963042, 0.09898766860245697, 0.11839870483644548, 0.13303561136126518, 0.13013635161182574, 0.09266946569926317, 0.12169708107267657, 0.1336451415573397, 0.2730496401988691, 0.09040057373743865, 0.06657398290812008, 0.08934440662062938, 0.14160528538688538, 0.14213406991574074], [0.08650499365983472, 0.035672194714988434, 0.023918404551823775, 0.03144362686021674, 0.022411653246249885, 0.08468008795452696, 0.05331775068395561, 0.04437552810075783, 0.01898482896297449, 0.025035682502352906, 0.05918650895417218, 0.030355540690042322, 0.03387793635709151, 0.07584892513771212, 0.028846343648770166, 0.033210826992628076, 0.03151486154585596, 0.0162658239564588, 0.019599024634507876, 0.013076789534440445, 0.03546409076079726, 0.08171572605328215, 0.04079718503259844, 0.048682700407000325, 0.09339670530490338, 0.005936478048698196, 0.008614902899059798, 0.02983217623325125, 1.0817279161945468, 8.070473728641387, 30.634075826214207, 49.18957748720723, 47.572145000580825, 39.16377575166764, 21.50592811646, 16.861577072451194, 22.440995670134022, 26.664423442655995, 11.798671868539627, 8.063410030257318, 1.737807698307499, 0.11245577010296046, 0.4173897369013679, 1.4941634237766268, 2.62504403148928, 1.778500940530531, 6.436367736708734, 14.733712827005695, 13.290786589345625, 14.069051511826055, 9.499392201823573, 12.935554192912194, 25.59926263747677, 26.761688417004002, 34.16616624401462, 42.93525626582485, 50.640407300764515, 55.73020427457748, 55.225230493853175, 55.45159047649753, 53.84873743980162, 55.04538589908231, 54.159789239206624, 57.55418485210788, 54.37244446046891, 56.3143785538212, 56.03210910674065, 48.790915627633375, 44.40741200600901, 47.40942547398229, 50.94197873146304, 57.25672406534995, 57.515773081010394, 57.378796069852775, 54.69905630234749, 51.416428627506384, 48.52351588587607, 47.32056810009865, 50.192029399256555, 45.221056707443736, 42.00931802872689, 40.46492791944935, 42.005434882256296, 39.99009755349929, 47.76800463276525, 50.29369331175282, 55.05466622691001, 48.1542992591858, 47.17548354979485, 54.601691307560095, 46.5391456696295, 45.54538572988203, 45.60569609365156, 48.52745394552908, 50.69858389516031, 52.99087978178456, 52.78404928022816, 52.9788302606152, 53.887851315159956, 54.982251428788715, 56.28654933744862, 54.69777368730115, 52.67690973897135, 53.15541928814304, 54.75450292710335, 55.01093179948869, 56.6990218623992, 53.6940783839072, 47.93109286215998, 47.093090241955174, 48.5738673517781, 48.47249369467459, 56.29803011494299, 57.49611808407692, 52.833584893134336, 56.795535702859205, 54.014308529515425, 55.905216509296054, 48.94814775836084, 40.37302678631198, 33.40886246773505, 36.960392152109456, 23.790420447626424, 9.549225914862848, 14.545741081237795, 17.370622273414366, 17.7961366791879, 14.92696898598825, 11.291694737249806, 18.10903395375898, 9.76320101368812, 12.998561186175193, 4.48781660487575, 0.9543588733480823, 1.038760066993775, 1.0181340995815493, 3.670067878500108, 11.654341393901456, 22.577001894673995, 29.91756077735655, 31.822497114058468, 21.936875004922193, 22.22528688369259, 35.9729354612289, 45.94777776348976, 40.07917065774241, 15.83948193057891, 4.563529626015694, 0.21237932235723544, 0.0973524539280803, 0.0780614713327058, 0.04551403434766878, 0.050689628603117126, 0.02246566436013147, 0.03362885052939096, 0.05181499644212666, 0.0653300169975527, 0.007786510001507498, 0.05161805055855263, 0.03470919155065091, 0.009663188886348038, 0.047227144842186285, 0.01474800842603849, 0.04084631425118254, 0.010905136155234951, 0.018203063049323617, 0.0406547884396728, 0.0202326099914048, 0.06696893953748288, 0.021692273702712792, 0.07502015589946702, 0.03215897678127212, 0.023169641705950903, 0.06812324251739249, 0.04475975949918071, 0.04966236981413057, 0.0232403535365818, 0.04367345831386986, 0.03312720466525324, 0.018549045592906977, 0.06099865546510105, 0.03181405335424408, 0.02577912486759165, 0.022468380141823042, 0.03077398557516356, 0.09749930532228562, 0.03571877286078469, 0.03223018465383399, 0.061584092195956945, 0.048093525167073936, 0.07608232148472341, 0.0664799532762939, 0.05386561846300479, 0.03221651381482521, 0.017094593194703904, 0.018223264787886894, 0.04626041082965751, 0.07280002543402296, 0.052518851213878205, 0.06141076863352811, 0.05967593954635724, 0.12904084588010467, 0.042730158930944825, 0.11172600240717012, 1.3046914939918828, 10.733397314625403, 35.24483373088222, 56.42829595073577, 49.04807406087076, 41.393556902485514, 27.348239652572143, 21.809511723056918, 22.779664877922308, 29.52015015386766, 16.170798655479185, 8.436329864686536, 1.8476344308545514, 0.03264497146911679, 0.30887908212119536, 1.2063081538484943, 4.377826971392478, 4.987384378910065, 8.172788264289979, 12.97873164376905, 13.8425846445945, 13.466990244004036, 12.485445545565698, 13.452457862515605, 18.85090320341049, 32.523289342080396, 34.845618817114065, 45.3129146945092, 52.228606362496656, 55.99463478211434, 58.768731086484856, 56.78513357716223, 55.66698351214009, 56.554498211030044, 57.15056119426605, 58.67955992298742, 55.413923955732784, 56.61701686920659, 56.54553951755647, 51.98834942233179, 47.189855114106216, 49.435113937624045, 54.51387728414228, 58.19072669552219, 55.81791239400064, 56.702100922984464, 56.7292711811681, 53.76231978016516, 51.33851858877367, 50.30993976900655, 51.213493039531095, 47.41920394282187, 44.374224831981046, 44.29272974691084, 43.14257706365278, 42.028435660946755, 49.190189376954116, 52.463564180558734, 56.56456693526238, 50.294450329196074, 50.42866206938221, 57.86082790743921, 48.80841332097208, 47.976172662550404, 47.277076859628, 52.53955618027718, 53.306014768538944, 55.49761556809949, 54.21283145104685, 56.93059467500257, 55.732463559796734, 57.97475314909413, 57.090627378033055, 55.994928959877264, 53.39066736159786, 54.20604182827858, 55.67880553583945, 55.51913761323499, 56.945397700032885, 54.03854877718034, 50.33970663624425, 50.35924788444273, 49.48415140951834, 51.96264220822243, 56.2714482122852, 58.258795507492565, 55.05084976073235, 56.42994726857832, 55.29370723232147, 55.42721686824676, 50.29223026767854, 41.65048391588273, 34.472134651676306, 30.300064433005552, 18.942818064843458, 14.507580341831332, 16.825485383310628, 13.709310350879548, 8.593548267118393, 13.880100154107618, 13.684022830378625, 13.172769335008438, 9.557117723649549, 9.232390580638763, 4.118896607429751, 1.7740112975720437, 0.4448461748899952, 1.168939242920568, 3.6734001771096265, 13.424810055763492, 23.799577220793694, 35.821422146212676, 36.02519712140484, 24.78378618917158, 26.45253308357731, 41.24435778587095, 51.39203540740475, 45.62393511495283, 19.730971282528294, 5.7797565960115005, 0.20960389305987667, 0.08408597144748896, 0.00803335119158991, 0.038058566260001356, 0.09640080418678061, 0.053551982066804366, 0.040437843830835436, 0.0437411000471442, 0.012860126462915253, 0.012246338733201547, 0.008577279363488479, 0.03404121650683303, 0.04479943902321881, 0.028892485124449578, 0.05788542352797044, 0.06356899153381106, 0.03564510201554626, 0.07290002289077929, 0.03654277320170114, 0.027311316037911083, 0.05352265622106291, 0.045676988910042474, 0.036815090645705505, 0.012436002951055285, 0.007487648089731774, 0.03898733678544241, 0.02539173718692074, 0.019694446631136443, 0.1735230210808016, 0.22163763281799134, 0.1027995229308163, 0.1053036345289119, 0.10896391070057308, 0.12763490599970664, 0.1648772285590249, 0.09528754053697472, 0.1549020283404858, 0.24281794145222635, 0.1590326978194137, 0.17542665764208765, 0.13071647935336636, 0.1658422541954825, 0.17742299084221164, 0.12640813110216012, 0.13061530978208588, 0.10123574595537879, 0.08856917160653299, 0.14787357000093307, 0.11476447565420983, 0.15402763090547056, 0.15279749288193642, 0.18167563684044347, 0.15812037903214657, 0.1791239205387331, 0.10726490388474158, 0.21167435292755404, 1.8796832595140704, 14.99047313967059, 42.955495695913996, 61.65561514516031, 59.59853203065934, 51.14468289959816, 32.02068663412525, 29.02718863179607, 35.19878510505923, 37.77283268590128, 18.17112703477183, 11.603826169044742, 2.6745931275429267, 0.4954940555316787, 1.2265597187703656, 2.580381718374068, 4.241962932771252, 6.192213921777665, 9.343899642267536, 21.87701375253739, 18.049133477672456, 21.792822037973714, 16.894001345480643, 17.371134142721854, 31.193460725968887, 33.32322928213304, 37.2387666856089, 45.48622854294316, 52.65071615096062, 56.16188072389173, 59.8431977148979, 61.22713542753651, 57.678810319592884, 58.253108070742705, 57.71063250880088, 61.44155571537634, 56.956215596968136, 57.9873949481595, 60.146887225489465, 54.513712544595045, 49.14765127243535, 52.88717623679869, 55.83830087415634, 59.95169047386416, 57.98234685774773, 59.3723681665236, 58.473768849526685, 55.92883310010357, 53.45100125958843, 52.228072920153224, 54.41514338216474, 49.13460939161239, 44.87499383188064, 46.059855568793516, 46.851942923761186, 44.49199399640484, 52.21374057954358, 54.79654289061024, 59.619085250362275, 53.93685740809287, 52.36643845035184, 59.4829946948636, 50.97014527167044, 50.49115719333772, 49.506783485412605, 53.51500257369011, 54.89540230843329, 57.394701280901515, 57.634989600027765, 58.26007027779856, 57.264180491047526, 59.64213701986498, 59.63834801027852, 56.868311359036355, 54.53056304685531, 54.20078585224768, 56.06044823123563, 56.04286816812331, 59.75852943235829, 58.27730909470589, 53.05368869535385, 53.59359510483281, 52.449463259789255, 54.00631473910425, 59.48566190658077, 59.85294872714628, 56.1944716976535, 56.863690806973366, 55.03349327271985, 55.85009936363467, 52.7606091960784, 42.3413231295924, 40.3139284349257, 40.15534308648879, 26.53407915945976, 16.026447588397613, 23.282397024093136, 28.946534895127822, 31.28898612914547, 19.689168622416837, 22.34727651842179, 27.296744815764892, 17.443894109418316, 22.79907472672001, 9.012275991901275, 1.7497417547049063, 1.5922739140449034, 2.2714193165302277, 4.387363233873922, 16.20237961892159, 29.35415348699016, 41.62219578219999, 43.26890091742239, 33.12031722837879, 31.32515822687457, 48.076416677044286, 58.697030159734915, 54.03496373084284, 23.96298904572764, 7.359880478151384, 0.46141895495595475, 0.24755654766434626, 0.1548185554002562, 0.17709890500672404, 0.21428521121701888, 0.1393057805516066, 0.2431882070677896, 0.19810459155949856, 0.10908769518737832, 0.09953418806675943, 0.10499973511022907, 0.11608064535164064, 0.1303247479541648, 0.08873710574041452, 0.17876582039940744, 0.1128120239703886, 0.1254455416253017, 0.14360313544109946, 0.15418864726539583, 0.11998097517437513, 0.19804338113434855, 0.17069508411711262, 0.16102608924190845, 0.10953165846125734, 0.09761727520174558, 0.14475998949379693, 0.1692571217614797, 0.12687652491994444], [0.03267719695765165, 0.06014460532535469, 0.07299487223668445, 0.059923899224809105, 0.03031579796375046, 0.039716434154299, 0.055833790271032246, 0.022207674675530965, 0.06973060223484231, 0.0729315244262257, 0.04946345508459115, 0.05261593370608265, 0.03262660451113217, 0.016161092076330416, 0.060197587966197924, 0.030048597987080296, 0.06425759349499019, 0.037930817268187964, 0.03009197580057287, 0.04219084835400985, 0.054491470162306106, 0.05275839541648185, 0.09584221117679151, 0.01965652910932418, 0.04157564527685604, 0.043590391400240125, 0.034331437425627824, 0.03812187959650352, 1.1383389945953124, 8.265154688589035, 31.49862897011542, 47.160103936349195, 44.30006457913307, 25.10053719243696, 21.932783972832468, 18.10149515828779, 22.86106582610838, 15.53418326762415, 12.592735117481602, 5.703370888387004, 0.8512224785743222, 0.20157503114352304, 0.24383820202802461, 2.400729564889785, 3.3231437975360505, 4.058131493868367, 8.838298282315655, 8.932242970312796, 18.002186629080004, 8.557461480940542, 10.700604338799755, 11.307105729656836, 9.512209526954159, 26.99657955477315, 27.86800861358643, 45.14940677150604, 49.040723539167836, 58.206274970885254, 54.983573267536784, 57.328758393564534, 54.272463244776574, 55.54282088433543, 53.54001552827897, 54.621644404626664, 55.97468560741794, 56.31765765528525, 53.424144791018584, 50.03830778983332, 46.01381871008104, 48.72551010501001, 54.96464783145536, 55.36904419622114, 57.617331089512, 56.9276136736716, 50.56874559771631, 49.295363810754594, 47.62278279950542, 44.67849485335812, 42.314984413885306, 42.29766322720436, 41.216383441801995, 39.90365243727162, 39.02271555316064, 42.59294709851665, 48.197468865302305, 48.615589603301025, 55.42247472270843, 50.270080643315474, 45.80958873994889, 55.44335349913567, 48.448469177369155, 49.11317363862069, 44.0475227755885, 47.32534554696853, 47.98379382779522, 50.28818238166071, 50.68026250408542, 52.20643320391255, 48.35162585781467, 51.27390538492511, 50.244530324013006, 53.34298702978319, 53.34026882725378, 54.35811604222944, 51.70910804502426, 53.67139139483052, 56.58198225882746, 57.98178988118326, 53.91814770237092, 52.60624824031707, 52.35260817312425, 56.661873094497196, 59.02468142970916, 52.80026043615034, 54.75917839234876, 56.39745827644103, 55.397061686361994, 54.97844672972157, 50.89806387501379, 44.10105528370027, 35.021976424801736, 31.591585220829135, 22.25654621278086, 9.962726100798577, 16.345496119991427, 8.473881656123746, 7.1612550846992, 17.55503446825089, 14.111822016777532, 7.527049933710407, 8.363216884674566, 4.8914618357535335, 3.146873217436575, 2.4684740458765337, 0.08245756729475914, 1.1614133177265045, 2.895076664224748, 10.290798044973805, 19.99481147335422, 31.380859805691628, 29.548969768708755, 27.165196364925755, 31.88977949080929, 43.81514587709981, 49.25594791289299, 37.173800468444824, 17.928336243475638, 2.9424557089805607, 0.1554030958082407, 0.09691590638530832, 0.026843157792163473, 0.06120487484299849, 0.08238370109710001, 0.08958891890342198, 0.045417189342720855, 0.06476338772523789, 0.08412380086918993, 0.009133582728193894, 0.05371482171598942, 0.060588852051765694, 0.04407428317673264, 0.04339827570102869, 0.01689710147348383, 0.07554931581140527, 0.033726783379191355, 0.09093732558070652, 0.02414820603125038, 0.08760704178242915, 0.04708439201837586, 0.020835961688369996, 0.06949399597942829, 0.04274629657306979, 0.06376250917392393, 0.0887912068696272, 0.03968312848179091, 0.0622266139684906, 0.02794821472508052, 0.039460541635391214, 0.07803891004333574, 0.06264169955806387, 0.014806442740072888, 0.06551518810973053, 0.04345513091632917, 0.04082903896849002, 0.03182587409091573, 0.030110381062953707, 0.07633890731320267, 0.016111987755603848, 0.033260044311323476, 0.007710184661611434, 0.11138046610980265, 0.03608305149921968, 0.07028282905418066, 0.02038635809214846, 0.03563088725411123, 0.1397842790691122, 0.015622700804904585, 0.012140668395365919, 0.07735940537625745, 0.04481951052683496, 0.012893558539930853, 0.0847092682435628, 0.09331956025092833, 0.013346005279961373, 1.5113882672402168, 11.159015663208502, 37.35766549264231, 52.09618714547927, 51.362335220459975, 33.02154410269953, 25.99821867481355, 19.484024740034535, 31.995528551840017, 23.80744745654445, 14.53990851679156, 8.397290514361474, 1.2639797430846, 0.2962187743715702, 0.3083248941167709, 3.591345418845454, 6.876836669060492, 7.7002495431130935, 12.422225763720851, 13.147236666371747, 12.67177087645377, 11.642610565308603, 12.853922805478497, 15.254431982194225, 17.252527552266276, 28.289934050652292, 31.5617654015941, 42.68575037679365, 50.911317563826046, 58.028744574516054, 58.13285604599984, 60.233206825871626, 56.92659777979697, 54.478768148729884, 54.08202825054046, 55.30141861208024, 57.10008421251851, 55.968503952026374, 55.823423324092744, 52.89212626795615, 48.385715176982266, 51.53507640284877, 56.596695069343816, 57.05966418789279, 58.03438102045367, 58.00981913843463, 52.79805998648367, 51.37269420008506, 49.817333221435554, 47.57928763666461, 45.54447574000205, 44.50780507056944, 43.20558209573069, 41.329269255361254, 42.107341981703236, 43.377668242300714, 50.38181720241424, 51.10674965766169, 56.363219907206876, 52.980975797099454, 49.92893641994846, 57.10695228269024, 49.44296652270902, 49.085720969784646, 45.83217766977126, 49.53786826902821, 49.6605678527586, 52.280895479263805, 52.6124926536314, 53.13067697709607, 52.15978053308303, 54.34738051506781, 52.35658545647898, 56.62451251860588, 54.99108460641677, 53.52085867235738, 53.13958075738723, 54.2461912093624, 57.57393790829567, 58.76012148395662, 54.797409734418316, 54.75906464361376, 55.03713323223976, 60.43219258708339, 60.69111216452814, 55.4298605457429, 54.030958990896906, 56.40758975859612, 55.783073902130134, 55.93854096628005, 52.34800723291213, 44.836672275297104, 36.77832357345089, 31.23722653235159, 20.311948830081572, 14.117279994872309, 10.944943485721465, 12.666292305915588, 13.149622448029058, 14.091807142380746, 8.167601420033364, 11.372379852879433, 10.900846239059202, 8.208103814432699, 5.195425912257164, 1.2449707114888777, 0.39203332977429517, 0.9542791389169233, 3.438651715555499, 10.92658483212994, 23.68145896542457, 33.59204107715238, 31.86650218502168, 32.15273714834644, 37.16984279694096, 47.01313664836269, 55.37693992737801, 42.89445184892224, 20.155356045692198, 3.625266076095643, 0.13006443127749429, 0.10068574079102087, 0.02143300465127874, 0.044291561033817074, 0.043708732832343354, 0.07242902437405241, 0.05437774440994667, 0.04007107540664654, 0.018205999081293424, 0.04664435494510878, 0.024079713940380082, 0.034949210727767605, 0.08674581339883228, 0.04363072592945349, 0.04949603297357117, 0.015110980884562579, 0.06738510148058977, 0.04898153981494327, 0.06177808481058287, 0.03919645580613325, 0.03822179278358817, 0.03236125463679914, 0.05914016446519283, 0.02551894225630789, 0.07187944055805284, 0.06117658321595481, 0.04108806478700811, 0.027409440409692547, 0.10605657638441171, 0.11062299667467033, 0.17117874606722788, 0.19277808947428582, 0.12915264875177415, 0.15240455106381448, 0.1719156153980763, 0.15297433661837734, 0.10794619353668344, 0.25330730924202555, 0.1495289481094768, 0.08783290748514476, 0.1407149533230451, 0.12091715760048359, 0.20397670146438385, 0.10207383082278314, 0.18202488100336445, 0.14439721621813315, 0.10012344757635748, 0.21374444507302778, 0.1451102755362949, 0.19507284456443405, 0.12841921915570575, 0.12853118290583934, 0.18229316499444748, 0.18643310413725916, 0.19610815110706514, 0.12634232414946442, 2.4403222145572787, 14.084956722874796, 43.87792341170773, 61.18994743593278, 56.14371230525356, 36.80467797863868, 33.11608499096286, 30.37252433838383, 34.25175236117455, 24.673551897848807, 18.346119657639537, 9.132283849100913, 1.6842340053089204, 0.7043664265544184, 0.3065616967937639, 4.617103319014273, 7.240823305422261, 7.657070621367424, 14.500887797724817, 15.49351711427012, 26.83531522750855, 15.836885321524838, 20.618321241871005, 18.526909543621926, 13.317713660578574, 31.19900891857763, 32.47026085853577, 46.202661222027196, 50.52692528693907, 58.649930338705744, 57.32756207066198, 61.335451679845015, 58.72903277797084, 58.050811829105506, 56.87151985783731, 57.021146512800655, 60.299832205618586, 59.97936671780002, 57.22807899598153, 55.74667430693104, 50.85902060231855, 55.41351995160503, 59.32023986693352, 57.19094983993038, 57.57502832720357, 60.65633643058039, 56.17152190977528, 54.88129354292347, 52.746194485695135, 49.1410695352862, 47.31224483059299, 47.21960236949306, 46.490280782022786, 44.18680221803727, 44.15199118275797, 46.679456695433586, 53.130104311050914, 54.79407964214202, 58.25668527233986, 55.83853229399651, 52.77888744108139, 60.361997850479625, 53.383034429242535, 52.39756245766917, 48.637951035653394, 51.45673098102693, 52.79709900579145, 54.397916332367934, 56.22585850377237, 56.99628260827834, 54.83706489686043, 56.977184587909335, 55.450327473302046, 59.17994453061012, 57.823200610376176, 55.124876652994466, 52.9794813740638, 52.90391299032396, 58.60351301008656, 60.62194508890952, 58.66496086120606, 57.37426180993357, 58.98540673717376, 60.963018709613436, 62.55943513685658, 55.09658851931172, 54.708536671053984, 56.603578828996234, 56.89146511016354, 55.57403118379655, 53.05840730667115, 46.228293911103286, 39.83030803741948, 35.256185070160896, 25.583512360049834, 12.460441416309727, 24.09575539250528, 15.882835888093519, 17.856190127711145, 28.500235849811187, 26.526407003402714, 12.48073870135892, 21.9718409738233, 11.923322831430744, 6.169232264641793, 5.102536341836376, 0.6888597650874047, 1.9278189539909365, 3.850363055544515, 13.504758746393266, 27.759447213142153, 42.719984823657626, 40.508960447003766, 41.04735282159621, 45.04428332851779, 55.383560888228885, 62.65301112205752, 50.526874296126834, 26.213115530629313, 5.716332850917693, 0.34755199727031494, 0.20457297833936833, 0.19331934591454847, 0.16030095637806002, 0.17631516641666814, 0.13432542763410077, 0.16936749970961004, 0.21479608461020455, 0.14462486690571233, 0.13271963073601648, 0.1863604636802789, 0.11936717020768313, 0.2067481011392609, 0.16520538998226966, 0.13805151075845765, 0.20991006775969462, 0.15870521055354228, 0.16273526204449518, 0.2211126787287574, 0.14853828917107276, 0.18403632145735527, 0.12922461505138105, 0.10037056455809264, 0.16599522663220284, 0.24650038820841622, 0.21018279506073845, 0.14084521891368976, 0.10884490660241536], [0.017587842735191508, 0.05259869289734671, 0.08339669149849685, 0.020619040062170357, 0.07409990044130434, 0.03518652944495121, 0.03655356355011463, 0.03192218857997608, 0.02558706279453491, 0.04929304265627458, 0.055137822374461166, 0.04187392544061427, 0.04774406649953416, 0.035682552223724705, 0.039911491631139676, 0.0544538131103881, 0.04636163019665307, 0.047367051649358005, 0.038644803552738125, 0.13730599995582335, 0.03701402835788266, 0.024038710999452782, 0.028962088042810082, 0.04454861034549052, 0.05325210844016364, 0.06922256336697648, 0.028843444005976764, 0.0753191983207099, 0.5481511090070971, 7.13799346839228, 27.063703075531993, 49.95334925190095, 42.97267959963891, 30.053394417608942, 20.994923691595755, 15.107770639081156, 12.762838505929517, 16.970473835545203, 10.911354268750838, 6.47729080530905, 1.7464876583506985, 0.22836788377213865, 0.9447955832846704, 2.2332053799783034, 7.3891545976361925, 7.111437551436886, 12.2337794111621, 17.186555247153006, 11.530879889765094, 12.481906587077725, 9.869048133973154, 10.172258134811155, 15.44606722170307, 27.66447094178969, 28.770224355882217, 40.89913821989491, 50.625129668943345, 55.26464639171478, 56.60717564244425, 57.54419457527899, 57.94231514776907, 56.044076258136386, 53.7346984494117, 53.948342107957416, 54.7627281373547, 52.48781227296399, 51.88230422235305, 51.149487803059245, 52.68690393817041, 54.289717751164595, 58.912913491649014, 56.07501199168544, 55.45002152842861, 52.565894895984286, 48.826495447466456, 46.693840026855476, 42.97135383852067, 42.09946586239723, 40.46874438562701, 39.45840850953133, 40.89710250977547, 41.136441615320024, 41.82365655899048, 45.24053519771945, 47.28466272354127, 49.47672244041197, 55.757064665517504, 51.64672274743357, 47.31100928398871, 55.48467174653084, 47.10233134608115, 49.608674895378854, 42.68893534137357, 45.920172122217, 44.631344041516705, 47.823008029691636, 48.203458324555434, 49.456651672240234, 47.546798644527314, 49.72491825780561, 47.259441883333274, 49.284145832061775, 48.8928109599698, 56.09678899088214, 54.65468252858808, 54.180773919628514, 54.723186723647586, 56.92310294797344, 54.98533048937398, 55.88096057215045, 57.001518972458385, 58.85596459911716, 51.61603804557554, 55.625814314811464, 55.219511678141934, 54.04527171965569, 55.31781411940052, 56.12513596011747, 50.43278055806314, 43.775879029304754, 34.28825393799813, 27.185835876772483, 24.477484380045247, 27.07423071707449, 14.166743043930301, 14.524956441694691, 7.821528738544834, 9.401469249879161, 5.268364346796467, 16.329542859908074, 5.592198660296779, 5.27964263193069, 5.200164135425322, 1.6141788805684738, 0.4887320425721907, 0.4799584052976101, 3.3821732622961846, 10.337461502321306, 24.62292390484964, 34.37463237393287, 39.96624169811126, 23.422880634184807, 25.973754852048813, 43.99706148332165, 42.958100149708415, 36.57064976230745, 17.64261118827328, 4.692718771196181, 0.11678599782528416, 0.03468051304920547, 0.017267531797950788, 0.046022123011249694, 0.029737596933339393, 0.030514844843456825, 0.020928168030936393, 0.0780763794037123, 0.022931570307381695, 0.04799904354337243, 0.05626611666934145, 0.03018283957405196, 0.03675541239640406, 0.042057234959136096, 0.03236474799773386, 0.03153968854026208, 0.009998699965616389, 0.03896436946947248, 0.06062966155549211, 0.02797281763876879, 0.047236728602119034, 0.013767663903924969, 0.04466643466824486, 0.055623261648560726, 0.02632612696728639, 0.12039585775064847, 0.046163673077019, 0.06929124314938823, 0.033910223132660317, 0.05281595926311228, 0.041530097519317945, 0.02701465806533252, 0.06413898776255308, 0.05937898854514765, 0.07143078116519798, 0.056306998951420675, 0.0742335138361781, 0.09567808449989366, 0.04142896625243368, 0.028758030948078925, 0.009273963552268763, 0.06011429505663053, 0.009527036867615198, 0.06222249241545797, 0.03136520052418834, 0.054508868019066514, 0.03177275738468574, 0.08545650274402673, 0.006953321393549203, 0.079776497047034, 0.05815532396457369, 0.03955041140978856, 0.027659905195656805, 0.05522217248536407, 0.02759534696627769, 0.12415080706799224, 0.981282512507131, 9.274050074238932, 30.541005826765495, 55.034093395356216, 47.715609612003455, 33.611680384605165, 25.930145940473004, 20.135551998692176, 21.60682716677266, 21.673591790660737, 15.805811324427205, 7.53936029249622, 1.5630555657609817, 0.1335627411402041, 0.4667953600085551, 1.7038084710797958, 6.131802556976196, 8.249030805403187, 13.038612508004713, 12.013937427151589, 11.105276250070142, 12.607074322239047, 16.174730831576934, 11.9339269591916, 17.25153911498285, 30.179757495080274, 32.52958670739205, 40.14736106318813, 50.160952460381296, 56.67848040980678, 56.69924543749902, 58.642619040704545, 58.09602106771162, 57.473144761977665, 55.32660807332685, 55.29432696680869, 54.66060922991846, 54.40944810067454, 53.852196970293605, 52.08178027983635, 53.18417810624646, 55.608269553030695, 59.09626468535393, 56.2730485393155, 57.797407104123025, 54.4694995880127, 51.257043115554325, 49.13018888042819, 44.159910448135875, 42.513307294537945, 41.66247852386967, 42.26937509352162, 42.258023754242934, 43.37154542246173, 43.62271047407582, 46.848075466771284, 49.41246617224909, 51.12042304008238, 58.15153437276041, 53.7249082134616, 49.60745111588509, 57.769593577231134, 50.503751923961026, 51.1354810191739, 45.699464274990945, 46.06202463949881, 46.74594871459469, 49.80779009480631, 50.381683841828384, 50.50920009613038, 50.9515336252028, 51.93769201155632, 51.113300015849454, 52.621592552431174, 51.69561116926132, 58.46582604992775, 53.43838299474409, 54.753981251870435, 54.76934909820557, 56.69611930847169, 56.83593611563406, 57.56918399564682, 58.570894579733576, 59.28684088491625, 54.070433724311094, 55.82572967775407, 53.51252363574121, 55.21761325097854, 54.91462192227764, 55.58136993838895, 50.5720756899926, 47.088057841024096, 35.67671022107525, 28.50118898576306, 20.170857252613192, 13.91749603133048, 10.293635879793475, 10.87372991346544, 10.878693672918505, 14.513171680511968, 10.10455116148918, 15.393653569682954, 8.692622434708381, 8.200150718612056, 6.614407550904059, 1.5563036958056113, 0.539260873150441, 0.5386210978031158, 3.5104019170807255, 11.00902226663405, 24.342590147449126, 38.39125710148966, 43.946455063358435, 29.110927312604844, 34.231187374361106, 52.742060307533514, 49.46036615679341, 42.99635110362884, 23.041865518016202, 5.1476627203726, 0.2692902016062891, 0.02242463269090701, 0.0318734577271126, 0.04145405180151424, 0.048633555866657734, 0.05149707378398988, 0.0640587592046828, 0.01178530031710022, 0.024924408231351166, 0.04185160929937998, 0.006974175264458022, 0.028829987671586777, 0.03535447123971197, 0.053355070657186934, 0.050749908231439135, 0.0380866012475904, 0.037984083361563184, 0.04171641010250296, 0.02505388858187343, 0.03846334413655343, 0.022949787878221082, 0.011793778037592288, 0.01916075147868645, 0.0811867116980495, 0.04880740802975432, 0.0575155524476882, 0.0711626503916998, 0.06399603958632197, 0.07626976787803635, 0.17417071777726376, 0.13974058141391124, 0.15917747311534422, 0.17054635580749283, 0.13965974381614116, 0.12540594254049564, 0.09941449448946985, 0.19632198156849032, 0.16303411294375697, 0.1554481111346714, 0.09284003517560421, 0.14426221620411644, 0.12088075310232178, 0.10970010587404813, 0.08924041784578755, 0.18344986582956008, 0.19201318132540873, 0.07011936121289769, 0.19400041340099228, 0.20080754893922037, 0.1640367381755383, 0.15393499555366655, 0.17130452238263624, 0.1285316578803524, 0.25248298331374125, 0.1501855620693776, 0.2483135191423278, 1.5386271669018654, 11.913548284961331, 38.584088663901056, 63.44825206264373, 56.883408561829604, 40.672087900100216, 32.82826931245866, 27.297452803580995, 23.04470531402096, 26.327431048116377, 16.792453142904467, 9.354924444229374, 2.385005518313377, 0.47265703579591173, 1.3761797547340395, 4.22665637347006, 11.891858558500967, 14.068978947977866, 22.496048096687566, 27.97487751130135, 18.508707784837295, 24.703509000039872, 18.511592688099032, 16.015352183772674, 20.558144238687333, 32.1891269376201, 32.999661199508175, 40.52554815046249, 52.27261143345987, 54.85118542948077, 57.025500343691924, 59.43685977689682, 59.804656505584724, 58.13497412589289, 57.899894714355476, 58.02652059062835, 58.574263895711596, 55.83025217056275, 56.60941923818281, 54.651073948029556, 57.40840996465376, 60.41458898975004, 60.24448364011703, 57.141292633548865, 58.48930143540906, 56.505252853516616, 53.41518609754501, 51.049989038898104, 44.8795751602419, 44.135721191283196, 44.19950285265523, 43.78182926485616, 45.00904083251954, 45.99718001581008, 46.96628785902455, 49.96353564723846, 52.34961540468278, 54.80806289180633, 61.83228654246177, 56.50902225125221, 53.102788925170906, 59.59176201974193, 52.36242978803573, 55.09517646604969, 47.31218991741058, 48.84584842189666, 48.70623950035342, 51.68765268018169, 54.25703656288886, 54.88870290017898, 53.35787242458713, 54.42150546658424, 53.501301734678215, 54.060357155338416, 55.44734647197109, 61.06829904740857, 55.95252421594436, 55.0858098460782, 54.05822338596467, 57.35015884522469, 59.666612609740234, 59.50413234772221, 60.029063147883264, 58.93702430109824, 54.76900785200058, 56.75475874254781, 54.41772037936796, 55.55937720883278, 55.57549422787082, 56.28672584410637, 52.09429264068604, 48.83492462096676, 39.57515393534015, 32.17900133902027, 29.279618647790727, 32.4169127018221, 26.11329709329913, 25.818703559137163, 18.311800879816857, 20.709669320814072, 16.50400007924726, 25.642506768626554, 12.473606851793106, 14.878953291523842, 9.944884219477254, 4.05883482386989, 0.8691521842152843, 1.1366100873677962, 4.556383067561734, 13.827447237506991, 31.266928680481453, 45.80155572583599, 50.6228978403153, 35.7128470174728, 39.77637544755013, 57.69506462158696, 57.12264960811984, 51.99391134323613, 27.39447262979323, 7.008135068801142, 0.4991486932962172, 0.1150609057156309, 0.11790526760441643, 0.13954518302794428, 0.2200331535911368, 0.1813017859333946, 0.10947569573838865, 0.22505633082360993, 0.10015818200284436, 0.11101938588845153, 0.16164153363675843, 0.1023692190046272, 0.14397514773713005, 0.13090876742236077, 0.09992798790335657, 0.1767159682968932, 0.11028350481102545, 0.1981916651129723, 0.19546269138734187, 0.13313532536548953, 0.12752890241362397, 0.07730299832239267, 0.11685396514592633, 0.3183626377534482, 0.1484483810922792, 0.2557436220588223, 0.185953104087422, 0.2587785253361348], [0.04574288013240984, 0.07272335535456097, 0.06693918468250383, 0.06460737391945816, 0.009480388816295853, 0.04880793663042207, 0.008115752566335423, 0.06694389612323816, 0.1274910346875268, 0.052025823838888645, 0.05160537180340579, 0.03309794010654573, 0.027659349781911702, 0.05745715739565992, 0.04556072740665367, 0.05116213248261521, 0.010488271326457542, 0.014991548734777158, 0.04419907506915831, 0.05617022544385926, 0.030864251800061717, 0.026464750577184944, 0.1302303965654104, 0.03738231746660125, 0.06070706707936141, 0.06925768849830474, 0.05035361860908809, 0.030869353945637425, 0.5721669848407469, 7.7544503250429715, 32.081634383047785, 46.2844975533024, 46.00994733072097, 35.7662893110706, 24.94008283461294, 26.591290850793165, 25.689406548776937, 25.690851942185436, 13.433544193544696, 5.746092854007598, 1.549891233444214, 0.2750446250842464, 0.5937351178257697, 2.372735854118101, 7.737540006637574, 10.16758757252847, 10.586252539388596, 7.715894406841648, 8.330053244867633, 9.724711775779724, 12.429608644977694, 10.29256409214389, 18.9956602358049, 25.8170973485516, 29.017502338655536, 36.41746551759782, 46.60872067174604, 53.0581013617977, 58.83041035744452, 54.14695524400281, 52.394302968055975, 53.90941650636735, 52.25161890829764, 55.95784687226819, 53.50966815025576, 50.52896884179885, 54.158538003121656, 54.438226530628825, 55.68113934609198, 55.830565960176536, 54.29655052000477, 59.309978946562744, 56.35162145860734, 49.11789617230816, 48.41218725327523, 44.749062215128255, 41.87261166111116, 41.40830893670359, 38.91502295770953, 39.23313110105453, 41.28035729931247, 39.30569102687221, 37.94432655457528, 41.88842665764594, 49.12940048402356, 48.12626607956425, 56.07763605733072, 51.97303256680889, 42.49685687403525, 56.21281662294942, 49.828292323697, 50.05844916066816, 44.74817575946931, 44.851020305387436, 41.46303776771792, 44.29024688659176, 45.54160064266574, 46.282136286458666, 43.58686785544119, 44.50376895166213, 46.01281458331693, 47.57946806569254, 47.53976583480836, 52.33585180774812, 52.18899826849661, 54.75884891325428, 52.390643396685206, 53.91640224764424, 54.260727513221006, 56.76344679247949, 56.38929582411244, 55.20843098240515, 55.98368744696341, 54.46110963821412, 52.62051390063379, 56.42293407071022, 53.823940215572236, 55.25373043552522, 50.52807454139956, 45.27555411861789, 34.92708644559307, 35.43176997092463, 20.6212551747599, 13.051063091524187, 5.799385116946313, 11.805987088910996, 12.199046823286242, 14.172586394894509, 3.278491045198133, 8.688263700854394, 7.539659373221859, 7.691593362439064, 6.291698957643201, 0.2688502219896163, 0.8617735317637845, 0.5075932804855608, 3.1914249687425555, 8.025173785225038, 21.453191849493212, 22.90100928275816, 26.73373172360082, 32.58813200458404, 29.270481486474317, 35.95526518360261, 49.24620082301479, 36.66574762713525, 21.934137190541914, 4.004856391299156, 0.09434125341114499, 0.07707315662335004, 0.036506391686177066, 0.03169018076732755, 0.03219482969612845, 0.003288532485209045, 0.03575788931019845, 0.061962344278130806, 0.0205641211340985, 0.03602710409810947, 0.03610745906048725, 0.14867189490506727, 0.08196871892939653, 0.041490287760332714, 0.0265696203531397, 0.06371372469490574, 0.02662515789721041, 0.034465682843039115, 0.10268559033471732, 0.017742789763536666, 0.07017351596826507, 0.015426270115459639, 0.05057976776433568, 0.05750142961680409, 0.05514340332498955, 0.017254791755770004, 0.08167410449635598, 0.016361893297383384, 0.021116753980036707, 0.09942829173298613, 0.04870225097082796, 0.073667980069595, 0.01611120251548146, 0.046933342462345484, 0.05952994617062712, 0.02619104459881783, 0.035468897962522124, 0.021690073115150296, 0.046962277603245554, 0.04544125982530175, 0.02625406299146914, 0.06711216733580636, 0.012420984754909672, 0.04638547085285668, 0.01844453204783701, 0.060833977204897714, 0.09638336036474475, 0.06845064551359223, 0.06385833911237217, 0.10140823065153054, 0.09828253063343226, 0.033517917167515524, 0.024299328365633567, 0.08744540489128522, 0.02109890413140097, 0.016127489544751666, 0.8071930766586335, 9.034692337436061, 36.80372484268681, 51.793976368442664, 53.61088491255238, 39.96186041062878, 29.132219899085264, 29.903404943404663, 29.575461456852576, 24.25720210998289, 12.031788133805799, 7.7601348200152005, 1.936518158162794, 0.2590188930832571, 0.5266992375254631, 2.194751198253324, 4.591185277508152, 7.848884819015381, 6.7248070720703375, 7.626823754079881, 8.518257391068245, 13.477039356385509, 18.699393810764438, 17.845711515795802, 19.2288569096596, 28.85427486511969, 30.480322837829593, 39.12407744315363, 46.29755120123587, 54.59533314551077, 59.4958600690288, 54.36248164023123, 53.6772043474259, 55.05077915806925, 54.66516702405868, 57.40571529634538, 56.40309080000847, 53.742911892552534, 54.305030684317316, 58.052576895683046, 56.85259049938571, 56.56459831422376, 55.93975297866329, 59.69086462451566, 57.79441433568155, 51.860864546991166, 50.354905820661976, 45.690207481384284, 42.75088525587513, 42.31889893931728, 40.7032040626772, 40.628710408364576, 42.82926205665835, 40.58348940264794, 41.44009190220987, 44.24371580923758, 50.1845141380064, 50.932039445446385, 57.573412310692575, 54.26285736022457, 47.63808396554763, 57.36021187997634, 52.33135677153065, 51.65689737566056, 48.19684913081508, 44.218173334675456, 43.814173129297075, 47.01286992719097, 47.69124384849302, 48.03420805162, 47.661233794304636, 46.137161562519694, 48.403561961266306, 49.87993032701554, 50.453533818644864, 53.92321540463356, 54.83022820565009, 56.44419723941434, 52.33075272652411, 53.53940756090226, 55.12602982982513, 55.720068870052216, 55.8364652049157, 55.85857168320687, 54.5386980425927, 55.570756004702666, 53.42709441338816, 55.302159940042806, 54.933225724004934, 56.10883458968132, 52.260640359693966, 46.01454042619275, 37.55941652482556, 34.172002730831025, 18.261112090080015, 15.755007805362826, 9.860019818429025, 11.581294113589871, 12.057765991457048, 11.591865881796807, 11.845797184974918, 12.328441892900775, 13.07475518795752, 7.278615832328797, 4.788435880214938, 0.9150495536385045, 0.6320909338612711, 0.15925998078478923, 3.7549803285829486, 10.170666633113738, 26.11546616400442, 31.441705572989683, 34.80528116226196, 38.83159414414437, 33.43227117292343, 42.16622460273005, 55.7283882171877, 43.345218473865145, 24.648597778812533, 5.326323739943966, 0.18244224570451245, 0.11168845643800114, 0.02249634043583947, 0.03356743709094102, 0.05447475029335869, 0.048316924066673365, 0.077157050911938, 0.02337328511320295, 0.01942791506618021, 0.02426234738630874, 0.06748757340134152, 0.046870641996182745, 0.036136214170725114, 0.035417730950059435, 0.034064758388746175, 0.027291529902046727, 0.014256559192172944, 0.016123113267484213, 0.02344056295471326, 0.016316324472427368, 0.06420576381647299, 0.058795034194425236, 0.025282573488150394, 0.028846470053277673, 0.08984139083974785, 0.04070418961947003, 0.09236352848670176, 0.01687933014886033, 0.09973393783213631, 0.19623179769804402, 0.1086904249724842, 0.2585166151965818, 0.10056400175897345, 0.09263337529715031, 0.22429485474863362, 0.2139549200693446, 0.19993194108528478, 0.11949146797339763, 0.13730705715715885, 0.11970851600410477, 0.15875364263211528, 0.20611768738637049, 0.09805759189710503, 0.15421106299806028, 0.07995797561541682, 0.11293876555658157, 0.233925836341035, 0.13627863008408778, 0.1014299875485801, 0.17185834266485708, 0.23665579065920847, 0.13082851205141316, 0.11985507628489887, 0.1871644116697773, 0.11361582640318141, 0.10197597075133555, 1.1723548918962479, 12.420876468381575, 43.72995984169745, 60.83308235291512, 57.74972677230836, 47.122453105065134, 35.95910518400131, 37.10418624262656, 36.89213506637081, 35.21977370785129, 19.390958662955992, 8.337258638874177, 2.5690080706150304, 0.8086657427972364, 0.9004694908376664, 4.950524395511997, 13.12005267989251, 17.48902686180607, 18.924165233489006, 15.632308221632435, 17.31114149093628, 18.060120036525113, 21.040085861759803, 18.517760615194998, 22.544665874973422, 32.605096255579305, 30.130474875050208, 37.817371199207926, 46.641464617944536, 55.27098886428341, 59.431282166511785, 54.765085481828265, 53.84436399705949, 57.59868806408298, 56.19616223919777, 60.22396964411582, 58.74399662017823, 54.49899973407869, 56.135059556653424, 60.234081514420055, 57.67860635634392, 56.93409735156644, 54.589445667882124, 61.02231710187851, 60.24088290429885, 54.48471838428129, 52.746939736027876, 48.488724462447635, 45.14950875313052, 45.44248234841132, 41.46437529594668, 43.12809567297659, 45.10200100560343, 43.13348500959335, 41.599096944255216, 47.79940712836481, 53.570029504837535, 54.97844672972157, 59.76268322237077, 57.69431937125422, 49.61569986035747, 60.62574194323633, 54.8046386626459, 53.67729848431003, 50.14780859793387, 47.66427363118818, 45.60863394891062, 49.221552648851954, 51.24715874272009, 50.49394992090041, 48.57786424698369, 47.95459962660267, 50.510078707048976, 52.90388945610293, 52.82637949912779, 57.876913547515876, 56.82453378554314, 59.090459577498905, 55.24146518399639, 55.2502905168841, 55.27689203139275, 56.90154560150639, 55.052422631171446, 60.03744133057133, 55.190270408507324, 56.7274433566678, 53.11150050932362, 56.623618218206595, 54.035967857606956, 57.04401393090525, 53.13491313688217, 49.28053332913307, 39.30278455057452, 39.51733035425986, 26.491301790360485, 21.12340877133031, 10.675696307613004, 23.60547677163155, 23.869685665253673, 26.102492924659487, 15.617851345769822, 19.804756949024817, 17.754918452232115, 12.906983648577045, 11.71126381043465, 1.8267733050930886, 1.308259012237672, 1.433998555425675, 4.521012113940332, 11.259760760491895, 28.291805021224487, 32.600195254049, 38.645920907297445, 44.518619045134514, 41.17388456098495, 49.48286487210182, 62.97714794835737, 51.68412646939678, 29.81380428037336, 6.784274616549093, 0.4337887988696176, 0.268150998219367, 0.09827759702719989, 0.10713646158335671, 0.1797641248952958, 0.1567196025843582, 0.17053739257877873, 0.21369546141114928, 0.08875153883690796, 0.13728972824831165, 0.1176348692106624, 0.27316458403102817, 0.15709362203075042, 0.10924633667473832, 0.2149178466248897, 0.23078106073362215, 0.1066250442677448, 0.13069262337540427, 0.180816377302812, 0.11780831917759874, 0.14355404452691156, 0.07214396305742764, 0.10114517904097035, 0.12746323335675463, 0.17998550898365437, 0.11435222842039601, 0.23958443754142333, 0.10333698723585376], [0.025840379342797305, 0.040123242163850416, 0.026989651040264198, 0.03078430669472343, 0.03675732761621475, 0.04691702861999793, 0.022061819195627205, 0.07294742841153376, 0.012713483827669295, 0.033246047884946874, 0.057807408964201334, 0.0040131104141173345, 0.03031988887326612, 0.043697980788326075, 0.0501410368709795, 0.025444643218971552, 0.044199412147844994, 0.05621421038203182, 0.05704441603513495, 0.03640553621094554, 0.017902551654485926, 0.01935623796476472, 0.1733517851079664, 0.047911721011323315, 0.03699878320818947, 0.08605949821010714, 0.020022523784709555, 0.07407039073446105, 0.526003078106911, 9.823209354954383, 25.902271616843443, 46.76662745014314, 44.727700987169825, 36.91333939952236, 27.808494490961877, 21.39444847260752, 26.300853067828765, 32.94238282788184, 12.188676076550639, 4.723318651799233, 2.6123311394645325, 0.384947813206142, 0.4265742424514986, 1.075275372112951, 2.0468952482746494, 4.7872272999055925, 6.56052153918051, 5.305622450767025, 7.662111357335122, 10.02473779263035, 24.756064837978734, 13.322610739738712, 12.654964500857938, 27.676624405768614, 30.9832001116968, 35.96348647148379, 45.93555565803282, 52.92799242081181, 55.34956962831559, 54.1522700555863, 58.38260904435189, 55.032363630110225, 57.553404300443596, 58.63155011207827, 57.61247519523867, 56.242595257297644, 57.71068349961312, 57.13214174393685, 58.37524283316828, 56.35013095794186, 54.81066342323057, 54.40279183849212, 50.19800316902899, 47.62840355596235, 43.335020311417125, 40.75594032964399, 42.16327498036046, 40.273273068089644, 41.349002699698175, 39.80463612464167, 40.77400676665768, 39.63533093852382, 38.64359494178526, 41.38457859716108, 47.007527659016276, 49.92823039331744, 54.5956979259368, 52.904171866755334, 42.36259414303688, 58.13597433028683, 50.06690579075968, 50.76365601631903, 45.958293637921734, 42.244954416828776, 41.8810918254237, 41.996684074401855, 43.96308199051888, 43.86507372702322, 40.730903840834095, 42.50761593541792, 43.28880302367672, 45.26449695710213, 47.3572422612098, 47.917996068154615, 49.828778697598366, 52.63432456601051, 54.87400577914331, 56.25662949777419, 55.821152271762976, 53.31338490209272, 51.817349772299494, 53.192485686271425, 55.74210082331012, 54.785215085552586, 57.17688814286263, 55.643429679255334, 55.95179073272213, 54.233259154904275, 50.08061447451192, 42.848956277293546, 35.930036498654275, 30.820815947748002, 17.108354953027543, 10.055304823383208, 10.997485595364726, 7.1208017199270195, 7.064642204392341, 10.596469333094936, 13.38673560850082, 13.149919567569611, 13.153948822329122, 3.9360881716974325, 3.3484693159980163, 0.8581490778634626, 0.6747889975386282, 0.2329156421605618, 3.2392857295851556, 9.795221282589821, 23.623329439470847, 29.90412665951637, 26.054916535654378, 17.57716840313327, 29.477806206672426, 42.249594580742624, 43.4860158735706, 37.992234383859945, 19.63129993407957, 4.1845002097468225, 0.2200974436897424, 0.017965485777465567, 0.012583302506696314, 0.07276955811727433, 0.03333184590202666, 0.05907023212902489, 0.07754050856155735, 0.03536055397783076, 0.019659355973764774, 0.035086830762485345, 0.030328038133560654, 0.009930318957495113, 0.11501963655914992, 0.052776693426553285, 0.04153961999221675, 0.019830697283689535, 0.020517401262036255, 0.0814760018200163, 0.05525033387746062, 0.04693786621153836, 0.04570293630803785, 0.06399407074035657, 0.03512853658908317, 0.02361916486294039, 0.07621347573736022, 0.007544276351484681, 0.061564399905863314, 0.11137453658926873, 0.06318024021663493, 0.02656616338138138, 0.028129260453786102, 0.08800224355992772, 0.08294713578277058, 0.0357014860867733, 0.026227665516818245, 0.028160928613356048, 0.06590435311438576, 0.03213007228388902, 0.029612711195143002, 0.028530859065452413, 0.0847843295383838, 0.11828618184212716, 0.038949492041982954, 0.031028070126570044, 0.011481393237538155, 0.0399205889252405, 0.039190480320323864, 0.03657979057020238, 0.02655453991235024, 0.08182212034420622, 0.0584318931965578, 0.031168635769356644, 0.0190469337957761, 0.022102559751440442, 0.031904365544417695, 0.06193656924991839, 0.6506121206668116, 10.812761572099502, 28.917713319101644, 52.208857228679044, 49.88949306549565, 41.41918566919143, 34.32061349191974, 29.580909629021924, 28.91554620958144, 32.70890570455982, 17.42515302473499, 6.334924947830939, 2.859625056866677, 0.4178606358266646, 0.1729853192885076, 1.2084938946270174, 4.15296043119123, 6.35825373472706, 7.7539095282554635, 10.307303378658911, 15.76963040136522, 14.900586143616708, 15.465013250227898, 14.91766316275443, 16.410840845877125, 25.64140066023796, 32.012071148041755, 36.65587502141153, 46.75901805200885, 52.965137266343646, 55.38013665906845, 53.17145393740747, 58.25076641574983, 56.61041944257675, 57.43786304227768, 59.945144038046564, 58.571839870945105, 55.549080987130445, 57.27661832686394, 58.28820936141476, 57.1142400464704, 57.08489679521131, 56.78835384307369, 57.237225963223366, 52.652740093969534, 50.05373839409121, 45.247799427278586, 43.9704325122218, 43.706939451156124, 41.91122347308744, 42.209707998460345, 42.11610847903837, 41.745213077914336, 41.118218283499445, 40.39472926047541, 42.980226239850445, 49.65114239723452, 52.39246729881533, 56.51190127095869, 54.343183578983435, 44.06371431965982, 58.51672664765389, 52.78121732896375, 52.71075587118826, 48.22126196276758, 45.186834027690274, 43.749187300282145, 44.524926216371604, 45.75042370826968, 46.31715128498693, 44.41528812531502, 44.40920060680759, 45.44937395280408, 48.087524829372285, 48.19616271603493, 51.395640065593106, 51.14653818068966, 54.94095671561457, 56.439843408523075, 58.44655936764133, 56.96391520961639, 55.15867179439914, 52.831768835744555, 54.30498753824542, 54.578714063090665, 55.54498995504072, 55.84083472528766, 56.65240057053105, 55.69663270827263, 56.40353795020812, 52.06774996172998, 46.84827943002024, 36.915861483543154, 33.102776388968195, 19.630242855318134, 18.70493611981792, 14.04423467574581, 5.869734296875616, 7.5706397237316265, 11.723089756504184, 14.414389729499819, 10.646415814276665, 8.270261614553391, 7.580987916838739, 5.078813847034208, 0.35889031305428476, 0.6944137186773363, 0.30574529221461666, 3.4421541469712413, 10.217440897418607, 26.373122738253688, 32.05253431873937, 33.07440196314166, 24.02781209638042, 37.4517317741148, 48.67640203045261, 50.30829629590435, 43.469141837089296, 23.745379870937718, 4.9876236434905765, 0.3627707628953842, 0.10464948737212729, 0.030534893364435246, 0.03752115941155822, 0.026727528311312202, 0.053095550711957686, 0.06502158999923738, 0.07203249726444483, 0.044060118211012696, 0.031746708480040395, 0.01820408386148272, 0.015314080369388385, 0.012605927955930032, 0.024224996769560442, 0.06125512638039166, 0.039865078194247144, 0.07966525341954925, 0.04771262625112169, 0.09545623309790127, 0.0296056057296453, 0.07120972649464685, 0.04928614403451643, 0.06200903350667608, 0.010566121181322923, 0.05905053983893126, 0.017731281207694162, 0.04913859166986039, 0.03872819988417529, 0.1668255280462965, 0.12800891012434037, 0.11068852783571329, 0.3246370204273732, 0.13826071404882018, 0.09722913675490888, 0.10708570825837313, 0.18052477359531388, 0.2172136895598904, 0.1308213108249249, 0.20046890743317144, 0.1101745211429173, 0.20677283045745667, 0.18384329794395357, 0.2625810793570934, 0.14793271198868752, 0.18039728124295512, 0.1241709168760046, 0.14105315049809797, 0.07797345549108521, 0.10247355251903496, 0.1501438562427798, 0.2212231639291971, 0.17537637163073788, 0.18457071374981635, 0.15521145125310268, 0.11313835444349436, 0.10600627505130346, 1.0057723209742577, 13.312633210612884, 36.19016024374193, 59.722129837159194, 58.90586499244937, 48.99273334010955, 39.79398688962383, 32.89292370119403, 37.78590202331543, 43.61225343519642, 20.662997038133685, 7.596002749858364, 4.2794460827304475, 0.7651167086535885, 0.8771000093510075, 2.069797722562667, 8.415851170016873, 10.760261627935595, 13.075690673243615, 16.441835414978765, 22.171721035434356, 17.94815597995635, 35.23804410811394, 21.483670626917196, 16.806281458946966, 31.19915208508892, 33.651292400975386, 38.43261065021638, 46.609301182531546, 53.58790766808295, 56.30701626500776, 55.279676914215095, 58.98759934210009, 57.05455726192844, 56.7236739589322, 60.00317550474598, 57.908723969613355, 58.067783924841116, 58.34764503663587, 58.314293123060665, 58.786260158784934, 58.28554607206776, 58.01297664642335, 57.47634541603827, 55.116976999467425, 52.652100747631444, 46.917089569953184, 46.34317621108025, 45.33157340941891, 43.447447207666215, 45.210117217033144, 44.43055791239585, 45.649469744774606, 44.22207217062674, 42.262785511632124, 45.96202381195561, 51.23597998772898, 55.37388832338395, 59.6316642915049, 57.07601654914118, 49.386143146022675, 61.912973619276485, 56.16028431923159, 54.67802455348354, 50.56607838599913, 47.60478696515484, 46.689545031516786, 46.83365683401785, 48.85905111989668, 48.436364743017386, 46.09589822830693, 48.27628104917465, 47.39558735201436, 49.22827166895713, 51.99667269183744, 55.093886006263, 52.8572367852734, 58.74943302523706, 59.19590857721145, 61.573617996708045, 60.06774164015248, 55.63049762479721, 53.353083210606734, 54.560102416623025, 55.821407225824174, 56.19815088087513, 56.76892634361022, 58.86114212774462, 56.640178465074115, 56.05617677011798, 53.03177049083095, 48.83016678594774, 39.77055072784424, 35.85538594953476, 22.508605564794234, 18.06146344830913, 19.0321147441864, 15.43790182759685, 18.473267209145334, 23.675826441857126, 24.99610016422887, 24.36421613539419, 27.441939192433512, 10.15660003308327, 8.329464889341786, 4.317470519773422, 1.43132901480121, 0.727382772151501, 4.1613219438060645, 13.30425306673973, 32.087055098625925, 41.07404455061882, 40.5474938115766, 29.697119651302216, 43.055622039302705, 55.63828352958926, 57.22753770889775, 52.2635115346601, 30.18526646398729, 7.084231501625431, 0.5805965260632577, 0.20609992946828568, 0.059971281762925856, 0.12139145795616413, 0.14544873318124205, 0.23907212390294, 0.23772811457034082, 0.2571013137217491, 0.13980571420923357, 0.106462717897469, 0.14564319693994138, 0.05688874313848154, 0.21158631410329573, 0.16123455708786366, 0.14894301342147012, 0.103842735500826, 0.2159103901395875, 0.20899119125979565, 0.1866058876077014, 0.14356204248484106, 0.1504173343099894, 0.1358558261586774, 0.15751250358598848, 0.09389886061751074, 0.1676742002488144, 0.09528883522556675, 0.11947377900322599, 0.22771012068035143], [0.03861209159837135, 0.046775007410155195, 0.019376474177284587, 0.07951439538549993, 0.048387090059658217, 0.02269289944501173, 0.07248963725062148, 0.05608383753907777, 0.01765768697124816, 0.030079770104719267, 0.036783439723113855, 0.028186153973482793, 0.01648247362144532, 0.059305589661122336, 0.026738000733237115, 0.04496327458670543, 0.07385023238678133, 0.05555937374611536, 0.04462202838171394, 0.04248945793557552, 0.031570387598607814, 0.025744537913030194, 0.020269445414024017, 0.03347697742884198, 0.03517665457160723, 0.049758900723029534, 0.06132950585696006, 0.0812483664541956, 0.21971173374162567, 7.802768042010646, 28.53712574128182, 38.155683471310525, 47.8337670910743, 43.24448416309972, 25.440194837508667, 20.23864757630133, 30.186662827768636, 21.11368521567314, 9.173816846263025, 7.6872017787348845, 3.002604765276755, 0.6023565487515542, 0.4486944796817918, 1.4847011960321859, 2.759160899346875, 6.42960213845776, 4.103801610969728, 5.8756565855395415, 9.484350892805285, 12.569856912859025, 12.86711863933071, 22.290627687208115, 19.552876064854285, 23.398773747105754, 29.223283606190837, 37.52011829806913, 46.070359676114975, 53.0247925942944, 59.82001258480934, 58.695653407804436, 54.57435238745905, 54.770470896074855, 55.44127464294434, 55.77832783422163, 55.878866026478434, 56.50534699040075, 55.013379358476215, 53.998795555483916, 54.62860661168253, 54.1487987579838, 51.89874287574522, 49.2797488550986, 49.373524881178334, 45.858202595864576, 40.53860179839596, 40.46609286339053, 41.242800604912546, 41.58754948646792, 40.54043746763661, 39.722258506282685, 39.47470987996748, 38.773139061466345, 39.91104610504643, 40.70542020182456, 45.67079959377166, 46.93489320816533, 52.370196080976925, 51.656057988443685, 42.826508552797385, 56.57217633339667, 51.16434966364215, 50.569875240325935, 47.3417842003607, 43.67539182786019, 41.843609656057055, 41.071797032510084, 39.68827509110974, 40.510870641277684, 39.212268014107984, 38.21849238487982, 39.41236380607852, 39.058817048226636, 42.799479499939956, 46.65333371008597, 46.22390477888046, 49.33041018824424, 49.32129459996378, 52.80765018155498, 53.46903631764074, 55.079879222377656, 56.58560260649651, 56.41583458069832, 55.64668524649836, 55.78937322862687, 54.046577868923066, 55.63662828937654, 52.810144808984575, 54.73873107664047, 50.43134889295025, 44.69693783790835, 37.11030514009538, 33.02855337819746, 17.241858705397576, 20.89372850233509, 10.412634707266285, 3.495420179059429, 7.013743567851282, 4.5282523189821555, 10.060176407137225, 5.185912203404212, 6.866712541349473, 7.468047190097071, 4.644762892876902, 0.7278100040651138, 0.8273622105198523, 0.2557899856999997, 3.72793730228178, 9.276963414684419, 25.43698633870771, 27.439407302487282, 23.753871802360784, 28.219182337484053, 33.41301625774753, 42.820307285554954, 49.06829387910905, 43.78601835620019, 21.819723613800544, 6.082920508999979, 0.5235953556914483, 0.0567613082427171, 0.05922927964298476, 0.037574632348673004, 0.043257878597585425, 0.03531273093915755, 0.04844906274229289, 0.009771563514556375, 0.04316203716781832, 0.037028488267453454, 0.07305270421408838, 0.02410045768614979, 0.026527278673564716, 0.013811778119434754, 0.027739174228401917, 0.047526099163317875, 0.08506825704488062, 0.028627016506488287, 0.018349136864285798, 0.008150976331483933, 0.11111730724693307, 0.06000631113326358, 0.01412061976283909, 0.030014484091812087, 0.012168137435500902, 0.024207392069060477, 0.01851802477763305, 0.031119058389336835, 0.035483311906817465, 0.011432472777913415, 0.04199438893626775, 0.03224129292873606, 0.05809223662400919, 0.01500506348337137, 0.07779818989576832, 0.0773748420479317, 0.015277198023883807, 0.019304515538556923, 0.04557578869524502, 0.014135411005437136, 0.011363692446461609, 0.08492451596764788, 0.029063893467067715, 0.011231929153924989, 0.022754795518853975, 0.03416445324077241, 0.02631524851876161, 0.017529078045739763, 0.036026357162383296, 0.04855912276393464, 0.10560343537719981, 0.043606123015765226, 0.07246033438751776, 0.09734933595022849, 0.019860844758729783, 0.02757067701989605, 0.3267680012410687, 9.540985995723355, 30.755341783646617, 47.254699737794944, 53.43322507796749, 49.40635119715045, 31.089851317867158, 26.621687258443526, 34.17543872710198, 29.799815147153794, 14.070785199442218, 7.8993627813554586, 3.1219909268040813, 0.5039471616187404, 0.2862092534140233, 0.7656171785727625, 2.3232247560254993, 7.222861301514411, 7.257698812792379, 10.901658169684872, 10.683443969295872, 17.64550001390519, 15.111445899932617, 13.31204681627212, 13.29397939866589, 23.656838247852942, 29.257520014239898, 35.20887344114242, 48.35923525594896, 52.74521781552223, 60.59675562766291, 60.13963476304085, 56.8976624550358, 56.33459837205949, 56.26515673052881, 56.84959773094424, 58.07129052377517, 56.75358987623646, 57.76204301464943, 55.880999795852176, 57.59447543851791, 57.143665667503114, 52.51983450305078, 51.606993059958185, 50.883100032806404, 48.278661927869244, 42.3468928952371, 42.3561300769929, 42.424861769522394, 41.889073848724365, 42.312885945843114, 40.938887519221154, 41.723216425987985, 40.34118106288295, 42.63837598985241, 42.33274098365538, 49.01179998151718, 49.57805687381376, 56.834010231879454, 54.25809952520556, 45.34832977479505, 59.599096851964156, 52.11207274467715, 51.509275051855276, 48.813324128427816, 45.705469423724765, 43.02608659190517, 42.32120921534877, 42.2581414253481, 43.63056698153096, 40.66339985016854, 41.32116563858525, 40.77199066838911, 42.38019774037023, 45.54168693480953, 49.29725047080748, 48.15689979061004, 50.7646522983428, 52.11627752550187, 55.373472552145685, 55.71749187284901, 56.72681577744023, 58.175613803248254, 57.393685387026885, 55.30775323990853, 55.72178294581752, 54.95424962812855, 55.298645496368415, 54.264634193912634, 55.30354845908381, 52.10266297863376, 45.692007849293375, 39.24497665897493, 33.637489580339, 21.14496219542719, 14.85962385131467, 19.88948210593193, 16.49820673850275, 9.050601470854975, 9.62801064214399, 12.896556027473943, 9.78649204777133, 8.19086499752537, 7.412417194535656, 5.694080264337602, 0.955182325936133, 0.20280809562292793, 0.3983249953917919, 3.8149251764820473, 10.465386663713764, 27.90706365339218, 32.431449005680705, 29.57290211031514, 29.59323371610334, 33.588644304583156, 49.36967703603929, 52.77744793122815, 50.20159213773666, 24.303550797124064, 6.863671723873385, 0.40027147158980375, 0.014521820966394679, 0.031025486495045405, 0.023604019304677367, 0.02676445374926252, 0.06859653929789221, 0.024555799280924183, 0.028294358147127975, 0.0393532625129146, 0.04672936389162656, 0.011083066778918429, 0.003950658687127514, 0.04019281443869395, 0.1291090736706411, 0.01622734336002219, 0.05639412613104909, 0.030848006905627348, 0.02564245669711982, 0.03895314628138177, 0.043388791532526096, 0.07885879266165918, 0.052998012397438295, 0.030048596071860487, 0.026824264148730907, 0.0054346282136506375, 0.05971848423923216, 0.031033873242596467, 0.04972166501946988, 0.15197077675932838, 0.09092840065638866, 0.13302433454701978, 0.1161369604749545, 0.14719028085950883, 0.0865980733426348, 0.15258162462663266, 0.11011189345510737, 0.14024388585840503, 0.15651079765971632, 0.15469944404978908, 0.14688657296280708, 0.1357760457622428, 0.18484200080556257, 0.14989438737111707, 0.10167649932085507, 0.11492301755013967, 0.13789766498150366, 0.07021240259130156, 0.16222305565832124, 0.08792286152921377, 0.11192823429742169, 0.2092490870986254, 0.14402986173668217, 0.12434065131650818, 0.2191500840408187, 0.1593015180720437, 0.18767592857681936, 0.6078341386971936, 10.726058560033, 38.242003071692686, 51.94416392234064, 60.739223957061775, 57.728981356466974, 39.69909691041516, 32.42792279489579, 41.838851821038034, 31.373619110353534, 17.309939284478467, 11.096603889619152, 4.442931452105123, 0.8571783525328484, 0.988665332476939, 2.603770321415317, 6.8951835555415, 11.82091857156446, 12.4492803119844, 16.090169433624514, 17.56080231358928, 21.205739321247226, 18.85529625800348, 33.1234472797763, 26.027895327537294, 26.38900245389631, 28.33815763073583, 39.61868439951251, 46.685516757349816, 55.40119978689379, 61.31493376147363, 62.61824323285011, 57.896780352438654, 59.390901365587794, 59.805884207448656, 61.16231433806881, 59.95256516241259, 59.41782843682074, 60.19362226609261, 60.41057248269359, 60.28674325635357, 61.39407934681062, 55.17405533021497, 53.73138796898627, 53.124240367643296, 49.81581134180869, 43.97235055123606, 45.11827491944836, 44.11714484614711, 45.64149556621429, 44.5511237267525, 42.729524027916696, 42.56523555324924, 43.306355630197835, 45.02461264210363, 45.36194432166315, 49.82448762462985, 53.507542225622366, 58.30327126287646, 57.60741141534621, 48.79254341125489, 61.833141619159335, 55.57290546355709, 54.53376370091593, 52.31349037539575, 48.0687641328381, 45.16263692609726, 45.115854817052046, 44.57635241170084, 46.49544262116956, 42.41525980734056, 44.28689326009443, 43.94667863845826, 43.88609370877666, 46.629909315416896, 52.33996637405888, 50.95513043865081, 53.685806105213786, 53.85935137348791, 59.00050786233718, 57.64305791547222, 60.17684236649544, 58.67908531619657, 59.23515581315564, 55.5420324879308, 57.385220912195024, 54.229438766356445, 56.27844179830244, 53.408047383831395, 57.24120716894827, 51.9831758160745, 49.24452204858103, 41.41306284935244, 37.53604312096873, 21.066293178066132, 26.997148298448135, 15.667455600154018, 14.510354438135701, 23.454128196162564, 11.004518405083688, 22.7426435870509, 12.297147262480951, 12.453812610718513, 15.475412434147252, 8.441183797774777, 1.5763901534580416, 1.338571334077466, 0.6029230860933181, 5.21199498445757, 12.779967496472022, 32.52777457237244, 36.42748717338809, 36.78459544335642, 38.97927530350224, 46.15549864307527, 55.702633934636275, 62.424552671370975, 59.0662036403533, 30.71390586514627, 8.290502025235085, 0.6593161665143505, 0.1781538540437337, 0.15093041403639704, 0.07554043685236285, 0.13362025902155908, 0.14489859012105774, 0.10111881795549586, 0.228993563101657, 0.09460781370439837, 0.15911784083131822, 0.21253718243491268, 0.12964211764835543, 0.1959237843872078, 0.17978877760469916, 0.13671485586993157, 0.14513776277101811, 0.11704178692232217, 0.10993195472345238, 0.2430366901981254, 0.17053992066892887, 0.17487489047550386, 0.1758639559510254, 0.08565421471552503, 0.10836216395780926, 0.07598737254738808, 0.14287742035042855, 0.13455202112034445, 0.12909462525238916], [0.06901960369319686, 0.05073222692214674, 0.03507361191535189, 0.004772652595889785, 0.004999468726436458, 0.04921217058454791, 0.05272852947875377, 0.030127577821633993, 0.10100981896562923, 0.03461278321581983, 0.041299455258394444, 0.036599839091180794, 0.029682689496586402, 0.04532649602380492, 0.02195196984816463, 0.01982677491351722, 0.04382337022933268, 0.039572409624534274, 0.021737026644029447, 0.031911538042608774, 0.03487546710417636, 0.041578368719426856, 0.10552255947503353, 0.06007599832129575, 0.08547940111208348, 0.030259896527915716, 0.028784282866024205, 0.03920215166985028, 0.12619512035481392, 4.817501133488071, 19.033446388859904, 39.729373685775265, 47.62659926568308, 41.52670568035495, 25.475600111869078, 20.558550204000166, 23.46206903457642, 24.22961215819082, 22.602142326293453, 11.190077893195614, 4.193021068649908, 1.114857235262471, 0.3531463696591316, 0.41171933794694565, 0.9155597681960753, 6.500896609598591, 7.3385408232288984, 12.986164535245589, 16.82602078683915, 19.557700580166234, 12.265419210157088, 5.146626234054565, 11.950573498202909, 21.194664509065692, 30.82007658097052, 30.923668338406472, 46.16992904293922, 54.20523382002308, 57.934019334854625, 51.9612144654797, 52.909608271814164, 47.894748180143296, 49.724376970721835, 48.75484943389893, 49.99532253511491, 48.48352339959914, 50.3324894751272, 49.10470916378883, 51.56109740657192, 47.61597356488628, 47.7860906816298, 44.52949969999252, 42.96222648312969, 38.64582284804314, 39.49820095492948, 38.737841652285674, 39.870426039541925, 40.23439845731182, 42.80766940885975, 39.857541053525864, 40.408838025985226, 39.92915568813201, 40.6463179280681, 41.099249701346125, 45.70898778976933, 48.43529001359017, 52.90806678033645, 52.51231531943045, 40.79097494002312, 53.808874391740375, 54.31971211587229, 50.631617269208355, 46.43312792624197, 43.19855713075207, 41.71313201227496, 39.996345889183786, 40.580841802781634, 39.37720760222405, 39.8384940239691, 41.98532096801266, 39.682626878061605, 37.78456449508667, 39.150882920911236, 40.49716980226579, 44.8564527880761, 45.50846053707985, 46.563715396388886, 49.39121869302566, 48.521727285077496, 50.55287176562894, 49.61626075929212, 54.535371872686575, 57.07043893875615, 54.880877771685206, 54.16641412242767, 52.89009840257707, 52.56663230157668, 54.765034491016024, 51.24815894711403, 41.22123149133498, 33.80894422531128, 30.33483232221296, 20.051085718216438, 17.293263327690866, 23.73222424137977, 10.87168831979075, 3.5914660317282525, 11.645547439975124, 11.813679837411451, 11.482281723330098, 3.988997268099939, 7.513084334711875, 6.725321883155454, 0.5026084995798527, 0.3169401656956442, 0.44123076082717994, 3.420745115126333, 10.853883700986064, 18.644715970562352, 33.35849923472251, 35.62436619112569, 24.639480229346987, 29.184693367250507, 45.9662756612224, 45.7162324074776, 42.85477707462926, 21.470848398823893, 5.103342388906787, 0.24411105190313634, 0.04455445559635278, 0.06951923857653333, 0.006818302706139343, 0.04611908292938625, 0.039964857315945054, 0.010238004765743691, 0.059937566233378266, 0.05887101479475537, 0.04996611984566816, 0.03585019141375538, 0.034399205563409675, 0.06665855901496065, 0.054907536344422456, 0.10251076907039651, 0.029272715628687895, 0.033937239223310066, 0.042899096640007156, 0.05049757036050001, 0.031296580113590725, 0.11535375048556637, 0.037344173948851325, 0.015010053588588153, 0.014393348979102749, 0.02258339100667546, 0.009766392421067483, 0.08685736346148676, 0.042372782744707606, 0.05994644519242068, 0.04344503770792677, 0.03654916237498965, 0.08205694161475667, 0.03486506363016463, 0.04206357433670952, 0.03402069684178118, 0.008339153381154664, 0.0494648072297775, 0.03915777602683633, 0.03999053275272731, 0.08643870407174672, 0.027824847756194013, 0.040404208740519906, 0.01791528595100728, 0.05120389193536774, 0.008121049106721918, 0.025498872667911555, 0.05629486411870007, 0.07052357984526504, 0.13014327704666123, 0.005217012799074573, 0.06865371243968126, 0.04768595106959824, 0.0348399474375671, 0.0559283331817677, 0.032811764131991134, 0.09583137103266294, 0.3272774497107152, 6.363384685208721, 24.572001734087547, 44.46483942770189, 53.63385823465163, 48.359525511341715, 33.44642308450515, 25.20298557896768, 30.121263188700524, 27.206916655263594, 20.786541892636208, 12.16650095678145, 4.193987932897383, 1.087110756385711, 0.27604676001975614, 0.7247611579875792, 2.1422218363131247, 3.9461054148212558, 8.554300050581656, 9.654486640807121, 12.772296321007515, 13.711737317423667, 12.046974570520463, 11.317322523363176, 15.474779951956966, 18.042037910030736, 27.945773524622766, 34.74713202445738, 47.230561471754505, 55.77299341078728, 58.193935194323146, 56.14429281603906, 55.33762601114089, 51.146459733286214, 52.24938707966959, 52.15744280046033, 52.30739893451814, 51.95437777426935, 53.53974488473708, 51.871223526616255, 53.49217045691706, 49.99204343365085, 51.23892176535822, 47.17004714473602, 44.89893597941245, 41.485889496341834, 41.298517873210294, 40.32742138831846, 42.349791526794434, 42.244330759971376, 45.06668398457189, 41.71823109349897, 41.70494994809551, 40.72456921300581, 41.74591910454535, 42.72899450794343, 48.40136543396981, 49.87711406523182, 55.15372176324168, 54.24464187314434, 43.46687078475953, 55.31072639649915, 57.196586285868, 52.86916863533759, 47.620292094446, 45.507260291807114, 43.02842040215769, 42.31291340243432, 42.503752400798184, 40.85513314893169, 41.301581244314875, 42.442834069651944, 41.74780968696841, 40.20503167183169, 41.29681556455551, 44.373440357946585, 47.275700107697524, 47.83953689759778, 48.23400574345743, 51.983756326860004, 52.35899771413496, 52.05206048104071, 53.17894566443659, 56.55073273566462, 57.746326077368956, 55.073834849942116, 54.857155276883034, 53.407635534963305, 54.3884987215842, 56.19578569166122, 51.55666120590703, 43.62607979005383, 34.97190736955212, 30.127856692960187, 22.140208713469967, 19.045333131667107, 21.20640612417652, 12.920102015618356, 12.294228038480206, 10.174733150389887, 9.217193357406124, 12.751095910226146, 7.726151404842255, 7.928707013207098, 6.573404073715211, 1.7978775717558402, 0.3038875596417535, 0.6186584094839712, 3.828245790735368, 12.039865274583141, 24.09213504483623, 34.52169772117369, 36.065421027521936, 31.22074277170243, 36.85320554241058, 53.41244436079457, 52.38464609269173, 49.31767425229473, 26.408033793972386, 5.822875701612042, 0.2941767210441251, 0.03154667334691171, 0.06910148317054396, 0.02807662255250879, 0.03393015674045009, 0.0753147779933868, 0.05536045135569669, 0.03778305422935275, 0.009509366092031762, 0.03617445344946558, 0.04591984261247901, 0.06040040974415118, 0.025216833568148078, 0.06401377452176905, 0.051707629219538746, 0.04403058935197131, 0.06823892945483809, 0.014452393290646856, 0.02168552446809988, 0.03759112239124314, 0.04510041581647051, 0.015716684471455314, 0.05124706098990095, 0.05278600139483329, 0.04671109269463247, 0.012329186354162953, 0.04939521963317548, 0.09228630682393428, 0.15020099108017262, 0.25045372365463164, 0.11938020902415437, 0.17689054441307822, 0.1442447953647183, 0.1813299013602157, 0.08800521598107393, 0.10455192607497016, 0.13833033611937878, 0.12751125174784853, 0.16858371515427867, 0.24126284425297093, 0.10644299879429803, 0.0945406124716805, 0.1749699466651486, 0.21576507858210997, 0.12079695074428475, 0.12822512311921005, 0.11122121941298248, 0.1629793683006879, 0.21527035432236813, 0.12171029608937041, 0.2685217541312018, 0.22037807701816484, 0.19033477461386114, 0.1494144945735893, 0.08237527412993294, 0.13686971288294564, 0.4202209527213728, 8.24345515620324, 28.35454921568594, 53.325038263874674, 61.386242451206336, 53.17591759466356, 38.381262902290594, 32.14249387864144, 34.519046198937204, 35.95211552035424, 32.26794696623279, 15.559277611394084, 5.717326191163832, 1.7439909471619515, 1.0193602079826019, 1.3866864361109272, 4.530306170063635, 11.792515708554177, 17.665445266231416, 22.66598282321807, 22.008730865293934, 31.56598194952934, 21.310715675354007, 11.809530950361683, 17.424376395440873, 25.99019938899625, 34.99757535995976, 33.87909189347298, 49.663815575261275, 58.5520044449837, 61.493193718694876, 58.597837340447214, 57.70210919841644, 54.406204300542036, 54.60287586335213, 54.414994332098196, 56.02201684828728, 54.90714980709938, 56.24738054890787, 53.91517846815048, 57.732366361925685, 52.506529823426284, 53.434413556129705, 48.86789998700542, 47.02067544383388, 42.95299714611423, 43.56691868074479, 42.6560462674787, 42.609060195184526, 43.3300075223369, 47.30906378838324, 42.91137687621578, 43.371353226323286, 43.14895875992314, 43.9888794191422, 46.22102183680381, 49.936887064287745, 54.99941964303294, 59.1809682692251, 56.24147345942836, 48.12902350579539, 58.50497914898781, 59.897738272143954, 55.232733987992816, 50.34190316354075, 46.63549869291244, 45.78709394701066, 44.840610334950114, 44.75753453470046, 44.0113938239313, 43.77358444275395, 45.231207801449685, 43.870847455916866, 41.6094990699522, 44.96935036874587, 45.64662602639968, 48.64788639929987, 49.71950146459764, 50.6775874476279, 55.32762004483131, 54.81799825545281, 57.69582948377056, 55.43236301791284, 60.53110691808886, 60.233728501104544, 57.591580729330744, 54.813581666638775, 53.96684000569006, 53.35890008557228, 57.286824334052305, 52.727633830039736, 44.659616485718765, 37.679064504561886, 34.22738659766413, 23.39975041727866, 21.68968527547775, 28.804078332839477, 19.575308099869762, 10.022602062071524, 19.582670388683198, 23.881578291616133, 24.11622035887934, 15.843644545924281, 10.485597656619165, 11.22579009302201, 2.7438940540436776, 0.9358856130030848, 1.5514834705860385, 4.23037919305986, 14.966472156586187, 25.426093916739188, 45.78893353862148, 47.59857785317206, 37.80397238269929, 42.740651792095555, 60.303503544099875, 57.090219451535134, 57.524206176880874, 31.802234149748283, 7.664733952091587, 0.38884263485670095, 0.11765286461600374, 0.230938246653926, 0.11533465957449329, 0.0952312330745401, 0.20098169604616783, 0.0893760000866267, 0.07916920382769839, 0.1867642992686841, 0.12245566899617835, 0.10637293239274334, 0.107755544895847, 0.1593673097029809, 0.14863060276594856, 0.24767245676728988, 0.19390353392208778, 0.18954326789225304, 0.15469677806381257, 0.1540067013833792, 0.21831975198320805, 0.12862789384540052, 0.11291250406253724, 0.09495623049236114, 0.1607480299689116, 0.09446172839811734, 0.1276253758659286, 0.16184108421927498, 0.21673831668111587], [0.07908813640355103, 0.10312072061482938, 0.0606404863778622, 0.05814402416769055, 0.051996781445679166, 0.08176218162501052, 0.05622072212938821, 0.035638597929069114, 0.04939086825376557, 0.07926338667710943, 0.1283042753235467, 0.03221822219089635, 0.0020913807712795757, 0.05440893951022337, 0.027008334009517587, 0.041033220552508874, 0.048083991202856266, 0.009328462089592171, 0.0950851554291383, 0.018620881657566757, 0.043387290000194506, 0.02036452841674609, 0.07846064910653137, 0.04564423099040024, 0.07975997253050728, 0.0693392232360859, 0.03251054602104329, 0.04222813385328458, 0.03444302962311814, 5.2651916396233345, 15.707583408201895, 34.526565382557536, 49.28427919264763, 44.92652985357469, 32.90827781923356, 25.625860229615245, 30.368674532059703, 25.44560378597629, 21.14926895787639, 9.751896742851505, 4.074803773433932, 0.8251944268422743, 0.45092621637928876, 0.35412711541979547, 0.9532953594480792, 3.758982862195661, 3.331023103767826, 5.128925067763175, 8.880976611568082, 13.655929834611955, 13.651747607415723, 12.579125473576209, 9.472462188812996, 11.62323699843499, 24.761195298164125, 31.7980097570727, 47.81806192090435, 51.89291423366916, 53.49167231590518, 48.463107462852236, 49.03649130175191, 44.13480727903305, 43.33400049517232, 41.033930470866544, 42.461532008263376, 42.270253704440215, 43.22879468241046, 41.642701933460856, 43.06137223397532, 41.21108824206937, 42.75853780008132, 36.48151782251174, 39.67366033984769, 38.5095989319586, 44.10098860340734, 46.253436303907826, 39.40804527651879, 38.72665113018405, 38.86798197223295, 40.31706633106355, 40.23939163454118, 38.34410236727807, 40.356635201361875, 42.31481182959772, 46.795107779964326, 48.85941982269288, 54.0996632268352, 49.28581676175518, 42.59579081689158, 48.54660295671033, 51.93159272593837, 51.74659805913126, 47.311609406625074, 46.061942269725186, 40.047925056949744, 39.28943280250796, 39.52975642296576, 40.81605849727508, 38.95502328872681, 44.1287785960782, 42.806453474106334, 36.87184072309925, 39.84066309467439, 39.059338723459554, 39.76468678443663, 40.97296899364841, 42.20572287036527, 43.05521803517496, 44.38413273903632, 45.64106802786551, 47.59800910949708, 47.01171282799014, 54.53035516123618, 55.92002737906672, 58.38185202690863, 51.918539078004905, 53.00814605528309, 52.658141197696814, 48.57459691263015, 43.12423213835686, 34.945062668092795, 28.01459150929605, 22.265438225961503, 11.097513879499129, 24.869556657729614, 21.256610501197077, 13.923807124937735, 7.891531279010158, 4.621401256130588, 8.05231511592865, 8.566328979307606, 8.30617875822129, 5.477004041594844, 1.2629509789328421, 0.40185810096802255, 0.47305849651175164, 3.3010179525421512, 9.376039543459493, 16.90489572863425, 26.745275259017948, 33.45774304482245, 27.60624924013692, 29.294847249984745, 42.95296968952302, 53.004255064072154, 37.26462294978481, 20.55833839601086, 5.115826802868997, 0.4481311905528269, 0.04236337901543706, 0.04073702414790469, 0.06429602812615133, 0.07549661662309401, 0.036655303856898705, 0.016904871520255844, 0.051309439699135484, 0.03910226912628259, 0.02358846197415504, 0.04944390835120313, 0.03970214278407155, 0.05854993968481018, 0.03931162180379033, 0.06748879148114113, 0.06693386037143008, 0.0019273284288506296, 0.019580198023768685, 0.014303121058600805, 0.02518783139455463, 0.0392960625580482, 0.006040764161415639, 0.10710526648308001, 0.009028868085043806, 0.008809877063838706, 0.03818102924513721, 0.08163848140787694, 0.017752157103630806, 0.04047132187312649, 0.08154504166375245, 0.03875130892641122, 0.1077343702256199, 0.07378693054159803, 0.017116984029510812, 0.03312009536931592, 0.03500909199036899, 0.03737941399336823, 0.17337484435448725, 0.11152643650289505, 0.022999673608630415, 0.08940774677020889, 0.05144836974420375, 0.04554214594405025, 0.04376582936533997, 0.04799219854776898, 0.05779993577649998, 0.06041271311621513, 0.08264836915318044, 0.022477485096803116, 0.05169627962694053, 0.09280789778718064, 0.05354523283219146, 0.10202464031716509, 0.02814160213024626, 0.0445229961957422, 0.06743395490752113, 0.033441407966517636, 6.137120800633585, 18.52117111605983, 42.45073372317899, 55.124162781623106, 48.21549607861427, 34.555218296666304, 28.692355502036314, 32.48005697804113, 32.99353445729902, 25.164028598416238, 11.739828471214542, 5.417839009915629, 1.1034459572645927, 0.4374981353119497, 0.39184689461704225, 1.6585373325693993, 3.272659461344442, 5.6386993392821285, 13.062576228572478, 15.781778962381425, 9.562007938661884, 7.9756259149120705, 9.672671729518521, 14.206698267690598, 14.230796329436766, 26.627221722756666, 32.50889032117782, 49.43070127118019, 54.009350653617616, 56.18471676303495, 50.44839159134896, 50.19877195358277, 46.652890482256495, 45.87727315964238, 43.319440657092684, 44.43937540054322, 44.47912862223964, 46.55196005298246, 43.93508411222889, 45.8497969565853, 45.69664016846688, 45.1337133684466, 40.13033013189993, 41.69431248018819, 39.7190970759238, 44.35590736327633, 46.37317449815812, 41.6502328841917, 41.72203579256612, 41.49580917050762, 42.519669378957445, 41.82100895912417, 41.77208523596487, 42.595833962963475, 44.30192378259475, 49.51825249579645, 49.58687436196112, 57.90134599131923, 53.665770638373594, 47.03812999110068, 51.566718163028845, 54.20933269685315, 55.40434160540181, 50.135174643608835, 46.83978749859718, 41.57660607368716, 40.87915374386696, 40.2362851173647, 43.62297327287736, 40.34568394384077, 45.86771042116227, 44.69383524310204, 39.24402352302305, 42.697635158415764, 41.00343012040661, 42.693853993569654, 43.3313960413779, 45.20561433607533, 45.33054967080393, 46.75731966572423, 48.92996365024198, 50.17472782442647, 50.83024217236427, 56.87878408739644, 58.66680829755722, 58.93096423918202, 52.85228283174577, 52.531346659506525, 53.129927804393155, 51.26220887707126, 44.39933976819439, 35.80672894754718, 27.77537399722684, 20.2666768335527, 16.552125600076494, 21.66391138107546, 15.047548528640503, 8.557357538130976, 14.345373665132831, 11.448072771872244, 10.069859758500131, 6.825068246933722, 5.388465850583969, 3.775760800607743, 1.467988344450151, 0.8394481361873689, 0.7946237801544128, 3.7778389213546633, 11.777852908257517, 21.62586635158908, 32.86711646664527, 38.04849293924148, 30.34449508113246, 33.592480382611676, 48.13660936970865, 58.90121698379517, 43.226821730213786, 23.78827883351234, 5.768875941153496, 0.5160659371364502, 0.07037314315957409, 0.03762740048489744, 0.02937406140019096, 0.01984064876582594, 0.0258241095505054, 0.038922537238367146, 0.007025210126753777, 0.056604405774945216, 0.049682272778403376, 0.08171832309134545, 0.04839106988642485, 0.006817958445378369, 0.0502911058344668, 0.05504156725721494, 0.04073319370828329, 0.026395007847778262, 0.0220427934020277, 0.011681287602010754, 0.05543894855485809, 0.013107588184216331, 0.053006194216469606, 0.010921834956764454, 0.019296471615351977, 0.027973329002458244, 0.040550282555482084, 0.07918357563715789, 0.05707636956245669, 0.18704667927757387, 0.17544283741904845, 0.12424824579108147, 0.20779957213709432, 0.1687295629733032, 0.12489363656289156, 0.1148765619784113, 0.15408091998148352, 0.1463630591188708, 0.34022951438542337, 0.2318969137606121, 0.07554355483021467, 0.15313786574669425, 0.12250063069645437, 0.11794642184770877, 0.12162854684697044, 0.16986343438827223, 0.13083577456493534, 0.13287827222337648, 0.16311058384035865, 0.10289149178612618, 0.21579978236507988, 0.2695355336031606, 0.14148724655951225, 0.175061080484621, 0.14921704307198524, 0.13665405913226067, 0.14746014299171586, 0.2167501144351498, 7.500180717437499, 22.900813164249545, 49.692892105348655, 61.36230814841486, 56.278822268209154, 43.718467297092566, 37.97752941808393, 41.48449705493066, 36.66444932260821, 28.005568096714637, 13.170189396027597, 5.29693587172416, 1.6460059727391891, 0.640650281021672, 1.6769282231407783, 3.603966380319288, 10.602247964951301, 11.22421722258291, 14.443790835718955, 18.867934134698686, 19.593300011850175, 25.223454467711914, 19.805478665136523, 15.233430631699102, 15.349681838866204, 28.759124048294563, 33.88661892183366, 51.46120248302337, 56.40601296578684, 60.39589497350878, 52.58794646109305, 54.36346615514448, 49.16788285778415, 47.95549784937213, 45.11705506232477, 46.4842011082557, 46.5145916323508, 47.76212107750678, 45.535030672627116, 47.55097596876083, 46.04065556680003, 47.52514323880596, 40.325522961155066, 43.619325468617106, 41.37014427492696, 46.88744821856099, 49.50267284147201, 45.285348276938166, 42.93518174079157, 43.72278974902245, 45.34399163338446, 43.23508224179668, 42.93646435583792, 45.163495925164995, 48.28792264384609, 52.00335641061106, 54.69347869196246, 59.45166672429731, 54.793436373433764, 51.106969310391335, 53.746300820381414, 56.35752854808685, 56.737327729502034, 53.379716104076756, 49.537860424287864, 43.67959268631474, 42.14112927836757, 44.679549970934474, 45.97838009557417, 42.409352717861054, 47.653353752628455, 46.95630150456583, 41.05772356833182, 45.08686065673829, 43.53442576623733, 44.48761663129253, 45.23125094752158, 47.58788154971215, 47.48344452150407, 49.275771571743874, 50.117986817513746, 53.16496633714246, 53.251584037657715, 60.80610429086993, 59.418405025236076, 59.54426996169552, 51.389434875980506, 52.418566749941924, 55.13922076071463, 51.571228888727006, 44.483047070041785, 38.30599654105402, 31.878914525431973, 25.947686779883604, 14.809924479453796, 35.89820646470593, 27.917271621765632, 23.622527314770608, 20.13648748397827, 10.947574415514547, 16.754290442312918, 18.985250265367572, 14.001958389436046, 11.948912374434933, 1.987919103234045, 1.2030402066246157, 1.1059918206545616, 5.004289794352747, 12.843532446892032, 24.34514557161639, 37.47975318662582, 44.06034108131163, 39.40475440794422, 41.39925610634589, 54.55115549025997, 69.27003783564415, 50.629157943110314, 28.634241665563277, 7.927787707697961, 0.6898233811220815, 0.1515997144123239, 0.14758067926572216, 0.19107755814348498, 0.12497524790946515, 0.09075580870792752, 0.09440156751342359, 0.09840825332268592, 0.23151304242351364, 0.1791754476125202, 0.1995598062151863, 0.13368586679139446, 0.15861196233139885, 0.1399335589620375, 0.08686138542308923, 0.15792013897049814, 0.14190312505008715, 0.054023306170899066, 0.10078714018867863, 0.12408565895091142, 0.09293408012918888, 0.11729277264807494, 0.18721682740555656, 0.10778254183429865, 0.10415852460409365, 0.14327581671457137, 0.15580474038518247, 0.21042363778237375], [0.10529517691822783, 0.0418704244188003, 0.049569611888258695, 0.044787798317209374, 0.05129842335478433, 0.0551983394900397, 0.05204588385118593, 0.026443639109211586, 0.03530394008022643, 0.0746137615773947, 0.02965760777794546, 0.06802912861589464, 0.08702823171211828, 0.03352987963045317, 0.039418173142738884, 0.05274686962366105, 0.055784327804201075, 0.01055396815401412, 0.023027304484839403, 0.017903802293022315, 0.10136615710272905, 0.06051942533362777, 0.053144526712956934, 0.023800455739781744, 0.042002972951459314, 0.10132344770095042, 0.02433825520828607, 0.059362448706862435, 0.10502996493972118, 4.336121880239056, 18.125015651026082, 34.79972316372779, 46.59998163100212, 44.9038036407963, 37.312534701439645, 23.022026169684626, 29.64983940124512, 22.154982320723995, 21.717445850372318, 13.244338862357601, 6.208336334074698, 1.8797746997687126, 0.6092462532462612, 0.7036415235169473, 1.1704731348060793, 1.37127299222254, 5.487851846602656, 13.1138200336887, 15.783230239345183, 5.995080499879776, 3.780682884877728, 7.228624243890086, 11.570383060363032, 11.383635094088893, 20.681292933802453, 30.594852124491048, 46.6817081359125, 51.88510087228591, 48.2253961409292, 47.53078360711375, 45.723833960871545, 45.57596060537523, 45.65765180895406, 43.372031796363096, 43.55141355145363, 37.619519002975956, 36.53126524340722, 37.88707563954015, 38.15576584108415, 37.69639745835335, 37.773252379509714, 39.05482799776139, 39.991176205296675, 42.020641911414366, 49.503508306318714, 43.626621077137614, 37.88570280997984, 39.75925430174797, 38.66441096028974, 40.499389863783314, 40.52346144953082, 42.95345606342439, 43.82767784980036, 46.364270717866965, 47.261705090922696, 50.252324073545395, 51.78234261851157, 49.58313242081673, 32.02048855443155, 44.238589271422356, 52.21482315371114, 50.19051536437004, 48.15335789034444, 45.06540921426589, 40.83836109407487, 37.646508832131666, 37.68959214610439, 38.40462453903691, 40.377580658082046, 39.83082579028222, 40.14531750832835, 38.06875590355166, 38.189890461583296, 37.504722995142785, 37.82640834008494, 37.71351860415551, 39.12563462411204, 39.70100318231891, 39.89157938188122, 41.912266823553274, 44.46453740519863, 49.1342406888162, 49.979142758154104, 54.01650113444175, 58.03180010088029, 57.79053511158113, 55.6478698022904, 55.40880918502808, 49.18610226723456, 42.10216053070561, 34.538795332754816, 26.011084048978745, 18.349316389329974, 27.968336959039014, 15.434669794574862, 8.299178308056247, 8.347924543965249, 7.850241959095002, 12.169483919297496, 10.809884513578108, 1.3132577053000851, 4.385546195891596, 3.400905521646623, 1.8429812740895057, 0.629383395275762, 0.4762157593523303, 3.8424531057957685, 11.760428759359545, 21.757552085384248, 22.26312794993001, 36.16064833056542, 30.284331806244392, 39.45883997025029, 43.710308767134144, 51.70012973969983, 44.11667023935626, 18.92822292543227, 3.6801733749528087, 0.3119594910212102, 0.03051242209039629, 0.10784091773412882, 0.035192121886798454, 0.014781667456601658, 0.019226975949300874, 0.07376904238856609, 0.05227071150476414, 0.010594412808366602, 0.011173329173376965, 0.05656434320694497, 0.02537259456491278, 0.05987895667673119, 0.028517259089576624, 0.026697553206054915, 0.06771772919643311, 0.06011897202340826, 0.05330782984533618, 0.029969191058508815, 0.007924545638924165, 0.025441419904030142, 0.04338839316680547, 0.0927022236189054, 0.04903036259835766, 0.0615170058764277, 0.0759933173896805, 0.11949779585965219, 0.009558164935198524, 0.03930978702321168, 0.06334075095853017, 0.0855950574060121, 0.05686547704822114, 0.08218012089210172, 0.040057082810709556, 0.06387209422105262, 0.03886588503636661, 0.05669424107538597, 0.051080712658022685, 0.048491998140009186, 0.016704501223660285, 0.02523227023982233, 0.027926810228476123, 0.011031749421700595, 0.07438786523116213, 0.06986183309627157, 0.01790572708893207, 0.07331124356677456, 0.04904876403029888, 0.04245779552166501, 0.020194330493048317, 0.026765903570659222, 0.0879474912559794, 0.03441587563664202, 0.04984073423510117, 0.026798148211392186, 0.04705618083056423, 0.0054994675015369735, 5.237927244555566, 21.49307647059041, 38.877811431884766, 52.885897544122514, 50.6953832410997, 46.02248714816186, 33.4855055809021, 36.88292534120622, 29.218745423901467, 27.418818781452796, 14.720750374178733, 6.083389232235571, 1.9028804018612833, 0.5476578096708944, 0.2750332256959331, 1.1685532571807986, 2.518361201209407, 4.378249606778545, 9.23600406416001, 12.146435091572425, 9.16585051244305, 5.423848081019617, 10.101260292914606, 14.288443403859294, 13.223703272881048, 22.253467152195594, 31.637967248116773, 48.3800434297131, 53.82638777455976, 51.376491054411865, 50.14890293921194, 48.57682481888802, 47.6046222256076, 47.9438131086288, 45.63894602560228, 43.580945076480994, 39.59582874851842, 38.474125016120176, 40.347472544639345, 39.51361979207685, 38.47096750813146, 40.045999173195135, 41.64723227100988, 41.891101714103456, 42.935205275012606, 51.1717237195661, 46.69536975122268, 40.211731080086004, 40.933376589129054, 40.65669651954405, 43.13532460120417, 42.811874189684474, 44.104185335097775, 45.46239229940599, 48.70349776360297, 49.14672559307468, 53.228622482668975, 55.78547831504576, 51.43520501352126, 38.4310064008159, 47.23124396416449, 54.34081838976953, 52.5147589560478, 50.76572310539984, 48.17158122216502, 43.224362404115745, 41.04296368937339, 38.94002414518787, 40.497695399868874, 41.24055700917398, 41.8553493099828, 41.02925108325097, 39.57637771483391, 39.9674968565664, 39.903566145127826, 39.83001385965655, 40.21299016091132, 40.781427891023704, 41.13655144168485, 41.11931262477752, 44.28282576222574, 46.31279745409566, 51.66328691667127, 52.48580401943576, 55.78944383128997, 59.656571342099106, 56.48748451663602, 54.6325642831864, 54.967381723465465, 49.4840572726342, 42.4789277199776, 35.137215660464385, 26.67261923513105, 21.99297470431174, 14.682665140398088, 13.887297703373818, 10.440715935922439, 11.637719369703724, 14.936844533489598, 6.810245119756268, 9.66090658018666, 9.091624559894685, 5.433148020698178, 0.9252068989219205, 0.697662360485523, 0.29174561762521345, 0.8012292966727288, 3.565629379403207, 13.316838972030148, 21.696690628605506, 29.6981139721409, 38.6022884615006, 36.8008928914224, 42.196054227890514, 48.6273096453759, 58.374540728907434, 50.2198507708888, 22.771259238643033, 5.151874855641396, 0.400624638122897, 0.01874394027606374, 0.08924352050188089, 0.044078052329320105, 0.03804496819934538, 0.06491046894582049, 0.036859845502241965, 0.10339092748660235, 0.03949142263961896, 0.017761683406969233, 0.05756823631424097, 0.01970350370562125, 0.02916647264012887, 0.0546828082822744, 0.05387108066990491, 0.026678106064097058, 0.06693493289452407, 0.024571360441886132, 0.008013353902741426, 0.05454411572446266, 0.024316417872004455, 0.03357740006439629, 0.049518192066780986, 0.020868056941957727, 0.03402316364489737, 0.06551431476949685, 0.07247973173376053, 0.04485477355398959, 0.24768451499121807, 0.1719479749519979, 0.2040069772591514, 0.1709923875187674, 0.18082984512852085, 0.14346327842964282, 0.1517850617247243, 0.12012640164504129, 0.11171813468418776, 0.17735056488985018, 0.1244156819678122, 0.09995550578159672, 0.14155397281771706, 0.12950115747028781, 0.06669633481050692, 0.1552384788350713, 0.1429273079960577, 0.24677567424312716, 0.16591003765502285, 0.17731780697020794, 0.3400202498080269, 0.15298688513857706, 0.12693296261732617, 0.1851453103365437, 0.15111200751796847, 0.22053203004742825, 0.22870879289844345, 0.17759900720369431, 0.31442467003099384, 6.319149174997884, 25.768801204619873, 48.425260513059555, 61.201742003040934, 59.441299899931884, 51.68118076939737, 35.64691589724633, 42.10729491326117, 32.959719704043486, 31.235249657784742, 18.038978461296328, 8.053995851547487, 2.999740699606557, 1.2212301982987313, 1.4736873031623903, 3.136601510547823, 5.5068464144583675, 12.194162491829166, 23.196601060128984, 27.268821462508175, 12.227249645417738, 11.36721016899232, 12.73831976998237, 19.106759409750662, 15.64106491304213, 22.696749894849717, 32.30892396742298, 52.2366197647587, 57.10502247656546, 53.10942557550246, 51.79813408082532, 50.75392461592152, 50.60518833898729, 50.69928599942116, 47.801611500401656, 47.61906047021189, 41.557131505781605, 40.34853158458587, 42.27734534971176, 40.8366274064587, 41.4111134313768, 42.29750633239746, 43.12031369055472, 43.92246584738455, 45.01447331520819, 53.1810833561805, 47.48057726890811, 40.919240367028024, 41.97453445003879, 42.060846205680605, 45.37562554882419, 45.76263012424592, 47.30298019224598, 48.53756973820348, 51.10991501039075, 53.09495202956661, 55.964440376527854, 57.267059510754, 53.276079239383826, 44.27276096036358, 48.48695939587009, 56.84956635198286, 55.956630937514774, 52.95536271987423, 49.97435746654388, 45.8317187524611, 43.3186169593565, 39.938475239661436, 43.34780723817887, 43.445054561861106, 43.887713647657826, 44.43949699401856, 42.14318852270804, 41.764063988962484, 41.23978037987986, 40.74826817358694, 43.56436914013278, 42.20777819233556, 44.13447779993857, 42.80833228941887, 47.32507882579681, 48.54170783873528, 54.186226014168035, 54.674819977052756, 58.9953617126711, 63.13829068214663, 60.65930566480083, 55.825737522494414, 56.31723403930665, 51.70866481719479, 45.71982922092561, 37.57720055118684, 30.306061736999023, 21.804946084176343, 36.17519640153454, 17.948497226161344, 11.595462695244821, 22.36915942161314, 22.828131644956528, 19.875171338358236, 23.88820513602226, 11.291462336817096, 14.284955436183562, 9.86141618221037, 3.3745310143116987, 1.229012303294674, 1.093497968489124, 5.6007376601619105, 15.215346544019638, 27.816274512198667, 34.250375609244074, 48.35151603144985, 43.12584815486785, 52.19980047595117, 56.14629714719711, 65.43414415851717, 57.33828975308327, 27.938438692400535, 6.604474148442669, 0.6128917285992254, 0.16919188171384797, 0.14788127684545133, 0.2736532561961682, 0.14329386574606742, 0.16561671791057433, 0.11992842154276949, 0.29098191989525674, 0.1139064954834119, 0.08907026205692561, 0.1233749362009187, 0.12355954040803256, 0.1817073222369917, 0.22837041186228876, 0.16464911821869113, 0.12712224762165739, 0.11711622002504526, 0.16057063464916524, 0.08507541996697265, 0.1326339974278404, 0.07996844037646249, 0.12439730351850872, 0.159425241271815, 0.22312100886577563, 0.11657306368673041, 0.20365537354542365, 0.2862934924421772, 0.0776281413592158], [0.008016942067056774, 0.032103504354674975, 0.057051866240198576, 0.025469763242008708, 0.025304945170759194, 0.015294705048173428, 0.013548502428156715, 0.02180250609413751, 0.029465599331043424, 0.029631587601597273, 0.038924862315217336, 0.022070774763462045, 0.05046160253245504, 0.04505956417790825, 0.006391776551026852, 0.06105216670661204, 0.027693555607730826, 0.02072980105426283, 0.02273277049103091, 0.017274493621962688, 0.08933202663977301, 0.03389048487729123, 0.05933750105360824, 0.004958067898593483, 0.0465336092747748, 0.09452555884396839, 0.03084487169079723, 0.028492455077808232, 0.06792410562235503, 2.198970933114329, 12.114475619408394, 33.04315636234899, 48.79989001058763, 39.17755896045316, 23.434481043969434, 20.664511073020197, 23.721047447573756, 28.998804400044104, 21.411261712351155, 12.402070664590406, 7.4729883959216465, 2.0649854646575068, 0.8284504230945342, 0.062141666309006756, 0.959647637942145, 2.4206941839187377, 2.7223805890929316, 9.01693674825853, 10.100092407195799, 8.632870028095862, 3.408456329376467, 7.909997797781422, 11.847718165766809, 9.89035935171189, 18.934939984352358, 29.916295812975978, 44.44779280693301, 46.85256265824842, 49.526132537472634, 46.59179956682267, 46.989931906423266, 48.5161026062504, 51.78111099427747, 50.140611048667665, 50.155837689676595, 48.2826784349257, 43.36797606560492, 39.494541383558705, 38.303227347712365, 39.16217934700751, 38.890806244265654, 39.099915642892164, 42.672265268141224, 44.29883687726913, 41.28131828000469, 38.28363903107182, 40.01951925216183, 38.19272241284771, 40.522708354457734, 45.42649084521879, 46.84084653854371, 46.89966640164776, 48.16383454107469, 48.86096915891094, 49.00439846900202, 53.459108798734604, 55.83985413274458, 54.133505436681936, 33.32422948652698, 49.733986777644006, 55.149909219434186, 50.61624157813288, 47.51354086783625, 45.60959885197301, 41.169777839414536, 37.81755947297619, 40.01197261195029, 38.70032418158747, 40.28902138433149, 39.89357586829893, 38.09104281087076, 37.81579440639865, 38.8280483215086, 38.84123140765775, 39.9450687439211, 42.46870994567871, 40.463500176706624, 40.547768377488666, 38.98985785822715, 39.394434652020855, 40.435874923583, 42.586279069223714, 49.92419035203996, 49.50538712163126, 52.44692940865794, 56.61436926934027, 56.72920842324534, 50.83202685079267, 48.34098838990735, 37.48143588342975, 29.841578583563532, 20.67155368866459, 18.514487397286203, 8.545135432674039, 13.178115525553304, 11.624855956723614, 7.126901986137514, 14.950835627894248, 9.138551796636275, 3.227399231926088, 9.759217846778132, 2.91123217152011, 0.4607257679585488, 0.7487732953121586, 0.596880981278035, 1.5905086023192254, 3.1567529324562322, 10.408935912193792, 29.179494265587103, 35.34143386348602, 24.21141039940619, 26.97376704985096, 34.238839918567294, 51.04299545288087, 54.2110114712869, 35.842391137153875, 16.27524058664999, 2.912529005158332, 0.35980640099413935, 0.08190933945438555, 0.06582053543459024, 0.0652819832847003, 0.06131360953253123, 0.1082454811060621, 0.08177031747876637, 0.024753771722316745, 0.05219564254906389, 0.030912488526214036, 0.048797414412782084, 0.03934290500417833, 0.005427089908475718, 0.04547260048228406, 0.04075636403755315, 0.04527224167700737, 0.12348872324031208, 0.03906897877553298, 0.03280849293655446, 0.07289729561776885, 0.052066177520300114, 0.03492437032682281, 0.07980304199361032, 0.05671083453982588, 0.03662158832735112, 0.09264594679998775, 0.10146306722515053, 0.08886681208687444, 0.04396485517762842, 0.020839663808264082, 0.02444833629734574, 0.03395721496593568, 0.14366786987070115, 0.04447216626196619, 0.050352293276979085, 0.03682811030997865, 0.09126698087540366, 0.05555399963932653, 0.08555855331642014, 0.03144246049135203, 0.02865018875097796, 0.03575942148604701, 0.06328655406832695, 0.02795979797449564, 0.048152866337688706, 0.03565151034103286, 0.03094822461266191, 0.059146507673205874, 0.016983238484470115, 0.061815006418093565, 0.06768346208358003, 0.06165919179517416, 0.0811836856507486, 0.09804214756455153, 0.008929475837747657, 0.02788304362536198, 0.050330854306418094, 3.1887224556938296, 15.343172665565247, 41.57309555238293, 54.061604469053215, 46.26802359857867, 30.162269607667003, 23.770035889840898, 28.00656830110858, 27.623876371691306, 25.57778569959825, 15.566225109561799, 8.870943188667297, 2.5839341600095076, 0.5850096215163508, 0.4722197834522494, 1.089283749461174, 2.8578175796616465, 4.63380035854155, 5.462236808192346, 9.082793343451716, 10.67524915741336, 5.505149008766298, 6.3915791723036, 9.634812032022785, 13.4302778397837, 19.838306942293723, 31.315654323947047, 46.85662231137676, 50.25696423745925, 51.16929185005927, 50.159952255987356, 49.329308002225815, 50.53348348986719, 52.8049986593185, 53.525726333741225, 52.03452356400029, 50.2134886864693, 43.920057512098744, 40.67480218025946, 40.53108261477563, 41.018488099498136, 40.44482577231623, 41.322973851234686, 44.001583976130334, 45.60317400963076, 44.539246789870724, 40.449760113993, 39.92738277681413, 41.55277375252017, 41.944038021949034, 45.66244102293446, 48.10767796731765, 48.52499461943104, 50.496299420633626, 50.31321102573026, 50.58801620237289, 54.647743855753255, 57.038106841425744, 54.1812014579773, 37.798245722247714, 50.483767447933076, 57.57361235157136, 52.50921664699432, 51.61079383665516, 47.172530005055094, 42.82496706131966, 40.293665470615515, 41.07519380507931, 40.436255393489716, 41.78329929228752, 41.63409625330279, 40.28055690949963, 40.125136913791785, 41.29607031422277, 40.01580476760864, 41.11102465660342, 44.429953867389315, 41.853148860316125, 41.671072436917214, 40.5670311374049, 40.94823844971196, 41.43882497664421, 45.33658619849913, 51.224063827145486, 52.038665586902255, 54.45835613435315, 59.353623159470104, 57.17793541569864, 51.34997583204701, 48.62914923698672, 39.71773993584418, 31.746852244100264, 27.418926646632535, 20.23625296931113, 13.149058607316787, 15.94460831534478, 15.826941132545473, 10.69713794415997, 15.543492032635598, 12.320476539673345, 11.728592841855942, 13.036239474050461, 3.7270824707323507, 2.423748239394157, 1.333441486762416, 0.33620375298684646, 1.2271166953348345, 3.9065372799673392, 13.795042576328402, 27.81637845500823, 31.80737637704419, 32.86230567962893, 33.22771172369681, 39.59364006596227, 53.678624245428274, 61.52964430470621, 41.94472051435902, 19.81211139309791, 3.9685805959086267, 0.31827125878584, 0.10047125915486006, 0.06802669245629542, 0.05242846049969235, 0.02976252351917567, 0.1289025823315305, 0.07423551332566046, 0.04719967292922159, 0.02223562347822853, 0.03611995778497189, 0.0862724170269024, 0.029966132452471123, 0.019758740560181683, 0.043958986944128434, 0.025791629337735718, 0.04896267106936825, 0.038879345201196215, 0.04720433074380121, 0.02708124068205155, 0.0930892359164934, 0.0181219668968791, 0.048699837793866475, 0.05066866843750881, 0.059678839189150644, 0.039740351419295036, 0.08557154616761593, 0.06524762424129633, 0.058115173296462146, 0.1039458432745549, 0.11192290998634793, 0.1948604543483065, 0.16863452210541696, 0.22225652460850057, 0.1433163580875243, 0.0929994810552847, 0.17652225530435964, 0.23058540187776091, 0.10141327917095154, 0.20630404593483095, 0.07067791591849058, 0.13164511581342067, 0.1023643160419118, 0.14922812070337035, 0.11314066802902568, 0.09205610506356725, 0.2373992330244472, 0.1437402345360287, 0.13755459548725238, 0.28651424833843786, 0.13291173494390904, 0.14699393252451576, 0.19194694536347545, 0.13273475331164178, 0.19342593938833286, 0.1069811832219843, 0.15570720207066308, 0.16563953200895942, 3.682900647963247, 17.981900130548787, 46.225603165165076, 60.991083268196356, 54.04170628516905, 35.194195931957616, 32.43854653450751, 37.05658435821533, 39.975647541784475, 30.56752497150052, 17.99129028474131, 10.305821703326318, 3.0678710437590078, 1.3378171358377704, 1.0146204526385953, 3.3939820479962135, 6.583345811213217, 8.931544788422125, 17.97337485897926, 15.102754908223307, 15.322160528552148, 8.82749999723127, 14.8867803812027, 15.757876038551332, 13.310431780353671, 22.819975076183198, 34.016716095709036, 48.837693814308416, 52.42015530986171, 53.64300520189347, 52.16947270977882, 52.540866251914736, 54.41404119614632, 56.64904694403372, 57.880984967754735, 55.159605318500155, 52.73338402471235, 48.11101982670446, 44.14810019154703, 42.237450922689135, 42.33100337366904, 42.03058904217136, 41.94184933939288, 46.25914727487872, 47.645308971405036, 47.21571922302247, 42.67446179543772, 43.97842630263298, 41.78049479761432, 43.831286430358894, 49.16905956883585, 51.703659872854914, 51.12318438868369, 52.349125108411236, 54.123311196604085, 53.140800614510816, 59.093601396006925, 58.539750960565385, 55.40776191219207, 45.93918385044221, 53.58110627820415, 58.71280593256797, 54.839233967565725, 52.81385929353776, 49.38813178770004, 44.48671840852307, 42.538265335944395, 43.332258962815814, 42.72653518184539, 43.812208021840746, 43.99237032859556, 42.821158439882346, 42.31175630323349, 43.87780966297273, 44.281052850907855, 45.07554069642098, 47.228792482806796, 45.80622334634104, 43.30294316814792, 42.96391702467396, 43.27294095869988, 43.384089162272794, 46.779418299275065, 56.13870343854351, 55.03716853357131, 58.0292348707876, 60.07323295839372, 59.202082387862674, 51.068741890691946, 50.108875151603456, 39.71371166167721, 33.78304873743365, 24.3373655503796, 24.796657446892034, 12.896535435030538, 18.692486516890988, 22.62695327881844, 13.707776704142171, 22.757736867473973, 18.22884863422763, 15.121950007254078, 15.022589506641513, 7.698399164984304, 2.4113194740587667, 1.8169098924244604, 0.7905923803487133, 2.7430774656034287, 4.271239503737419, 15.231377270913894, 37.164316177368164, 46.75178912378127, 35.1905285158465, 38.95620784451885, 48.34206704170474, 63.731964941947695, 68.52701540916198, 49.12302271012337, 23.592334870369207, 5.136498183973375, 0.5682956054806709, 0.2804173835583272, 0.2816692631571524, 0.13224791975752, 0.13832986114486573, 0.23413055035616123, 0.20508069545030597, 0.23568734827060855, 0.10805879313979419, 0.23432665354301854, 0.12890310327131904, 0.11040511360812573, 0.09305233346118082, 0.15744206946223013, 0.11435998123018973, 0.12162181293411602, 0.191746735945344, 0.1941817157691525, 0.10544508500325103, 0.18874353338633815, 0.12292935648151945, 0.13352587698928772, 0.16923600837828653, 0.11798489478326614, 0.12743076655052363, 0.22724740357408602, 0.1388476752946454, 0.1718575918986913], [0.023502414978499857, 0.05324677263777103, 0.03855138296081174, 0.04326829356291602, 0.057057274820944, 0.05456793339802854, 0.04022496331843638, 0.04507525748903713, 0.03659617336046311, 0.06942554602339383, 0.025077723492417606, 0.04142265751837723, 0.04345359107960136, 0.037932242191727125, 0.0635153423964737, 0.020447472756307934, 0.01293187059702412, 0.03051376848992321, 0.031849193807330825, 0.018127716386750824, 0.06159896196256723, 0.022643733837251222, 0.018018117933083447, 0.10500680610177018, 0.06886632482130682, 0.030684175172580347, 0.02658293113082407, 0.06672085728496313, 0.008024573739197466, 1.042477125602384, 10.67661218104824, 27.547115587419082, 44.773055353472316, 39.94117383033999, 38.14808976265692, 32.412702037442116, 33.45457769209339, 31.444712069726762, 23.900833206792033, 15.670224793495672, 7.1675215613457475, 2.7643656394174023, 0.7468625494549352, 0.3627810284735695, 0.6807492228765643, 1.554028721105668, 1.8282368394636341, 2.2979906778181753, 8.290712852631847, 8.799467798202269, 4.293728903416665, 4.430530878805346, 9.077946274511277, 10.730222155970912, 15.390545091321393, 25.70007931801581, 43.06761664728965, 50.5018142730959, 47.376646226452245, 45.58398185237762, 47.469402436287176, 51.040006606809555, 54.70465744695356, 55.31706886906778, 52.776698758525235, 51.13010344966766, 49.25800715723346, 47.32447478079027, 42.17058627836166, 39.88892785964474, 41.36303694017472, 43.49976378102457, 45.710799924788944, 47.105692817318825, 43.18124771118165, 40.41982458483788, 36.67397675975677, 41.20556554486675, 44.25866788433444, 48.92405656076247, 51.416816942153446, 50.94630902813327, 51.06469400467412, 53.84695276137322, 50.57073816176384, 57.55546746715423, 50.005026478921216, 38.94233834358954, 34.80483793443249, 47.82695785645516, 54.09125366518575, 48.92300928792646, 48.42663726499004, 44.53936053860573, 39.38185561087824, 40.05839386293965, 40.28931163972424, 39.71604939429991, 39.51669100792178, 39.6616304305292, 38.13443599208709, 41.64753429351315, 39.42715898636849, 40.64747110489876, 46.377606776452836, 47.553180340797674, 47.52975986849877, 43.39216924482777, 40.61390346096408, 40.985132263552764, 41.27438352954003, 40.39487046580161, 44.77828387291201, 47.851943354452814, 50.91309831988428, 52.957351361551595, 55.73218114914433, 52.39788801439347, 44.38115173770536, 36.84073632763278, 27.61382333693966, 23.906867773302142, 19.440021630256407, 9.034882572389419, 14.981117306217072, 9.289554222937554, 11.773348066114611, 14.134825737245622, 5.380206809889886, 10.224571766391879, 12.391583227342176, 1.2358315889873814, 2.429160865083818, 1.2917045263513443, 0.47727121400737, 0.8511644397531787, 4.131306006062416, 12.453711609686575, 20.1586429918966, 38.304851208963704, 30.804832289295813, 27.58514492742477, 32.514191404465706, 42.95582909737864, 51.252461787193056, 38.19230664160944, 17.02857002135246, 4.2348688360183475, 0.12566602172990962, 0.08848040499874661, 0.007315979756024336, 0.004513761321563394, 0.02311647903444546, 0.013441055723946663, 0.026013609059455416, 0.09352456537946578, 0.035112835617075046, 0.0165255488302078, 0.03600686405514998, 0.02823151978513887, 0.02932090830478457, 0.09048256046709516, 0.05551962527416407, 0.033249797885336226, 0.07039460894321242, 0.033043720233704776, 0.07809726296052819, 0.025614500233543017, 0.034445396834804166, 0.03235483865043329, 0.07444222683026906, 0.13925057625578297, 0.020239767167837392, 0.00790875752441465, 0.07835409393714321, 0.02848990783546, 0.04654357224823006, 0.06109456201234172, 0.026236322310362614, 0.03712367086160568, 0.02532159417657362, 0.036495666455237136, 0.022681078708340085, 0.04607395652020651, 0.03220776892116955, 0.07371242849096175, 0.039435923399944464, 0.06182054523378611, 0.033876507603112734, 0.018068865512407595, 0.07470151694912104, 0.012422345518585176, 0.04094400578328679, 0.05570253259652565, 0.025011054690807097, 0.07283885077002548, 0.10466840208297777, 0.03943903371691704, 0.04321102849057606, 0.125172377654141, 0.06503459817219166, 0.02968883543695894, 0.09598194561418026, 0.07478407824472075, 0.053658698114656636, 1.568588559185305, 12.799300859051367, 32.860491583424235, 52.60271810716199, 46.360615068866366, 39.244070591465125, 37.274597537133005, 37.759845718260735, 37.97468177733883, 28.73638802959073, 17.72387485350332, 8.536470916963394, 2.8311775768956835, 0.8324190036904427, 0.18830401342241995, 0.7753892122737823, 1.8706239327307672, 5.8840190787469195, 5.301691745558093, 5.296072459989979, 9.579330105935375, 6.622913210622727, 6.580810979489358, 7.758040764639455, 11.89112703646383, 18.118504516540035, 29.89954140878493, 46.1438335141828, 52.5072358500573, 51.074982381636104, 47.92256955177554, 49.92016992261333, 54.05571699142457, 56.06410388023623, 57.08323763262842, 54.64522569410263, 52.97247209856587, 49.30266726401545, 48.603096854302194, 43.825598993609034, 42.42998830733761, 42.19586987649241, 44.081827825115575, 47.212228313569106, 49.28160805856028, 44.74707749582107, 41.24974320011754, 39.16651748841809, 42.87834659699471, 46.12883829301404, 51.49300506038051, 54.11164606771162, 51.00832954529793, 52.80000940445931, 57.899325970680486, 51.17048425059165, 59.04844707058322, 51.71333243769985, 42.572491938068026, 38.91641147675053, 51.132962857523275, 56.05811834335328, 52.71620012098744, 51.17767787748768, 47.41306151113203, 41.45944095426991, 42.67588561581027, 39.99719312114101, 41.03141623158609, 40.90202508434173, 40.597260844322946, 38.88996293467861, 43.069632745558216, 40.08212420248216, 41.23953327055901, 47.94515848159791, 48.703003544961255, 49.37772966200306, 45.4975994940727, 42.27996157061669, 42.67989427812638, 43.60473425157609, 43.0139821575534, 48.8446520989941, 51.402002150012606, 52.94490960336501, 53.58287526715187, 58.054949929637296, 53.855640811304895, 45.72032343956732, 40.2810001373291, 29.57040552170046, 21.881283252469956, 18.410668142380253, 11.997129090370672, 14.533067903211041, 13.059505993320098, 16.964235305786133, 10.69793418530495, 9.935878457561616, 8.485175140442388, 11.469901742473727, 4.6742409756106715, 2.8165356141905633, 0.6833226041447732, 0.0930835975093707, 1.0733559847839418, 5.107134830567145, 11.869770711468114, 25.607793792601555, 43.12269849161948, 33.23913366563859, 31.356350875669914, 40.339631726664884, 49.97911137919272, 60.961845920931914, 43.777534269517474, 20.87342631432318, 5.050389901284249, 0.2610929688859371, 0.11144926846628228, 0.06027698914910998, 0.01656947056612661, 0.007369310488068169, 0.13801052505450864, 0.017458278114997575, 0.02092346425108131, 0.03421222648373054, 0.0474451006870837, 0.042014805179449825, 0.03279068522275456, 0.042632609125106566, 0.01902360450326195, 0.07119497930210444, 0.026639209864961527, 0.11401416914116953, 0.04927068054976483, 0.02717031372500764, 0.03613228797011318, 0.02916079975904957, 0.05728728888976959, 0.03126006261746009, 0.007560950255156645, 0.03390552318324486, 0.048275677892830104, 0.04394693255063988, 0.008187438286240063, 0.14346608231144567, 0.24659722172204526, 0.10747996774772484, 0.1261983379240959, 0.12622754885664872, 0.17306903737687296, 0.1552405166289499, 0.11209855096474772, 0.11351330085627495, 0.22521748507936157, 0.15197073079405293, 0.17100703511987964, 0.11931948123439667, 0.14389582699345005, 0.22609621857202825, 0.10116243134102515, 0.12781862920570758, 0.1379301777530101, 0.1324229555264596, 0.16012115554223139, 0.11726513219576691, 0.1328103202244928, 0.17472712743666866, 0.21234887802312452, 0.17473831232036316, 0.14224024970204602, 0.23765726675910337, 0.23092704644847303, 0.18496365556793828, 2.0900788278348985, 15.406971977603051, 38.92128698287472, 59.07433079135034, 53.79752305246169, 51.80231140505884, 47.63964114650604, 47.70946325794343, 42.39130197032806, 33.70220476581205, 22.23334147084144, 11.228872095384906, 4.112107720105879, 1.5227915779236825, 1.274360663467838, 2.91069211017701, 6.0195531479773985, 9.729757905006409, 7.757079783947238, 16.73129946954789, 15.966851095999441, 11.934589839750721, 12.600299408358913, 13.83084204889113, 16.02326850737295, 18.46506553311502, 30.865601570375507, 49.44815581844699, 57.19634309891732, 53.55211996263074, 51.60621250829389, 51.89037646016767, 56.63383599250548, 58.20354892361549, 59.13700242196361, 57.389963057733354, 54.976595371000236, 52.15680737649241, 52.23630205277474, 46.95235952254265, 43.88663107349027, 45.2028686769547, 46.39736767738096, 50.50439127029912, 52.14610715066233, 46.179558461712254, 42.90217107342136, 40.56856478414228, 44.51602243608044, 48.47438427709764, 53.6027773734062, 57.2533743612228, 53.3879844604, 55.78516844780215, 59.2777370637463, 53.702978241828184, 58.22182324624831, 53.024023809740626, 46.147822564648045, 43.1087976117288, 51.73863957005163, 58.949548429058446, 54.801987140409416, 54.3652626006834, 50.10927915573121, 42.41716607924431, 45.060376813334805, 41.98001792353969, 42.99391531175183, 42.860401753456365, 43.33180396787582, 41.66413768645256, 44.80641903415803, 43.451083244815955, 45.67660862399686, 50.87426685517835, 52.209888812034364, 52.91070261309224, 47.596142061295055, 45.329349425531205, 44.94166235769949, 46.31236991574688, 44.28158237088112, 51.09356657151253, 54.82530170871366, 56.1276815783593, 58.47369040212324, 60.897734780465406, 56.12975651218046, 45.976579727665076, 41.51585248208816, 30.802984852944654, 26.145786085436423, 22.526781828172748, 10.807553645103209, 22.13596667012861, 15.65950103344456, 21.032160712826638, 26.706541853566325, 15.65810957262593, 19.53959688063591, 18.481437506214267, 8.364889775553058, 7.150331283769301, 2.534511560393918, 1.4703208063879323, 1.4518741446156658, 5.838652945333912, 16.910845964185654, 29.659331537062126, 48.68461939596361, 43.22870054552632, 38.928817933605565, 46.39152334582421, 57.176417458441954, 68.6019640584146, 53.04498103357131, 23.788284717067597, 6.77725455453319, 0.4751201616900583, 0.4069339544061692, 0.1293464996401341, 0.07242196870426978, 0.14818435655005519, 0.2672931636052747, 0.08162516679975294, 0.18384694452247313, 0.14810751793124985, 0.15104482160700908, 0.1528285960516622, 0.10637418111605991, 0.09540923360374667, 0.1851137781575803, 0.1862232879765572, 0.16406111509328888, 0.22040266844053424, 0.13733380894747474, 0.1026432792986593, 0.2198969891234752, 0.17701629008496964, 0.09919894799109429, 0.25278132859497304, 0.24158821711617134, 0.06933803579980327, 0.10725296823488129, 0.15464731942742102, 0.12640022507478155], [0.07595698183943188, 0.018221973929734483, 0.059187792151445345, 0.04531239617555853, 0.06672566831712762, 0.007957537694188256, 0.058863051310782476, 0.011276790305160949, 0.04095002723437163, 0.06487881419278922, 0.03147337405431656, 0.04381319275125862, 0.04308674221618041, 0.026330723494832075, 0.07155415196452411, 0.05303897894918919, 0.054398470918738076, 0.058581847246856465, 0.06887492032781725, 0.02094056333355125, 0.025627267088801153, 0.04140880664870624, 0.0323598335436996, 0.055516373230925495, 0.034041779581457376, 0.06803357192585546, 0.046719477526963725, 0.10255558521396692, 0.07800990595452248, 1.0923025036050429, 7.252665431268754, 24.24934756371283, 37.808247766187115, 49.727463876047445, 33.790320811733125, 28.86039572377359, 27.109239832047496, 27.525215033561956, 22.41931280782146, 14.246964339287052, 10.78636205965473, 4.432493534780318, 1.5922388578614883, 0.1407170677257161, 0.7416858175589193, 1.1411539080642885, 4.088979464384818, 4.364097204900557, 3.247190531223051, 10.271896143113414, 3.590567073514385, 3.3138821009666692, 5.387981437867688, 6.596645587874997, 15.301445511079605, 26.31696224212647, 43.79236082876883, 49.70976614182996, 48.69145608717396, 45.50099626664193, 45.76174366858698, 49.574197261564194, 52.600984419545824, 55.005569919463134, 56.30975800175821, 54.837880749856275, 51.05459782385057, 50.22559312082107, 49.00592819336922, 47.328652105023785, 46.094297901276626, 45.301983048838956, 46.03267746586954, 47.8902139202241, 42.26476238619897, 37.89825439453125, 39.12687801545666, 42.85761687063402, 48.93570992254442, 53.58958252014653, 51.2708459361907, 53.631092963680146, 52.91242845596806, 53.041160645023474, 57.21821423499816, 51.391666704608554, 47.8085893969382, 43.03881860548451, 36.7721732970207, 46.685748177189986, 56.335002376187234, 48.24032075943486, 46.4797374509996, 42.697933258548865, 38.45737649548439, 38.17002365666051, 37.577886965967, 39.01616911734305, 40.14328572057909, 38.07717330994145, 37.773605392825225, 37.886887365771884, 39.21186008761006, 47.620123432528594, 50.146620119771654, 50.95240831375123, 51.18509507948353, 45.70175101680141, 42.22981014559346, 41.91068610837383, 42.09091509542158, 43.22804550970755, 42.853557217505674, 47.174663774428836, 47.66128086274671, 51.9363348714767, 52.3800882985515, 53.385066216991795, 45.320830037516934, 38.85622662882651, 24.688831490855065, 21.37004544658046, 13.379934218622024, 14.885044732401449, 15.483117930350767, 20.276476875428234, 13.669315903417527, 9.3092700166087, 12.425732362654902, 8.80037876867479, 16.542884495950517, 2.902157277830186, 3.9094393435985815, 0.6572724890805061, 0.3605895880008898, 1.379701185130304, 4.217949692280063, 12.61509753042652, 19.486113402151293, 24.29842229812376, 28.483010761199463, 29.796069283639234, 34.061254609015684, 47.47180292683263, 46.59467858652915, 37.408609236440356, 20.244380120308172, 4.936512218367669, 0.20136369812873103, 0.03238211904141692, 0.020610710771213618, 0.014910221798345448, 0.04228613820047148, 0.022122152450103915, 0.07912743671406662, 0.0624713943820567, 0.0579450864555134, 0.02681727934208128, 0.0930159979109322, 0.0453207120599766, 0.09111482815276231, 0.013880641762948325, 0.04261096331080602, 0.012232148869624062, 0.041780485696489775, 0.10202195134855087, 0.034892930078410336, 0.043403442964077964, 0.08484954660337779, 0.05430446426954962, 0.09135881949576641, 0.035675094357781836, 0.02586492671511106, 0.011582978411517557, 0.09477570187300445, 0.049129371801691676, 0.0734122292769532, 0.060325225875262296, 0.12252506890123892, 0.034518259457282485, 0.05576535563675627, 0.08160119590860221, 0.08340208475748379, 0.060437024916492166, 0.07410690248493226, 0.017083067401883104, 0.09380568900415975, 0.048138919707027175, 0.050507146459553516, 0.014828174739264914, 0.06309933367095168, 0.1290434659008057, 0.08254270264578444, 0.08026288627015968, 0.02928534841855928, 0.05092991591100732, 0.047578514899097146, 0.01168450995934226, 0.013852723603767735, 0.036774997434188286, 0.05357051373369271, 0.01052806576368429, 0.05705066731259708, 0.10528010796875724, 0.006256675509165132, 1.176474238595655, 9.806922693406383, 30.2670165031187, 45.49189636784215, 53.944121637652, 42.63257088199739, 34.013884144444624, 35.52975077782908, 33.7734075515501, 28.044360337718842, 18.904004250803304, 12.138125550362373, 5.315679898185115, 1.7257761955261233, 0.3055942809629825, 0.6280314645940258, 2.4626463843930155, 3.317519118708949, 7.164205687661325, 6.878403655944332, 9.012637830549671, 9.130397189048029, 5.515486415355436, 7.368596474970541, 9.328546504820547, 19.087192666146066, 29.44931999329598, 47.27636298825664, 52.06116822458083, 50.52281856536866, 46.49196347882671, 49.68056801826724, 53.136258509851274, 54.00631473910425, 54.940944948504054, 55.396151696482015, 55.537564908304525, 53.146880288277906, 52.38235150614093, 51.17540290278774, 48.46445675819151, 48.182206922961825, 47.54562977821597, 48.316563790844334, 51.13763832276868, 44.07487346280006, 40.55875101397115, 39.27481805124591, 44.300805907095636, 50.71490487744732, 55.77629604647237, 53.31673852859005, 55.880631093055975, 54.79851976517708, 54.46666763674829, 58.67260163830173, 52.23214826276226, 48.45313287550404, 43.779922992952415, 41.479252846010276, 49.05842127338533, 59.77644681930543, 51.697721404414025, 48.20948700751028, 45.70248450002363, 40.243714086471066, 38.862549489544286, 39.42419367451822, 40.31525027367377, 40.36126359816521, 40.17906165892079, 39.2280359422007, 40.446885016656694, 41.39116033431023, 47.516023728155325, 52.48721999506797, 52.83170215545162, 52.43057312503938, 48.56734445018154, 44.86520751830071, 43.39527183963407, 43.26564142780919, 44.26123311442714, 46.57350563233899, 50.03280078211139, 50.50941190411968, 54.05844303869433, 53.93160143206197, 53.70757918204031, 45.97709355815765, 38.41177109749087, 27.569282862447924, 21.073008275801136, 14.46872240112674, 11.571038096181809, 7.127594774769199, 9.247656445349417, 10.998822143000941, 11.436514527566972, 10.095009996045022, 9.177001810842945, 5.906069172966865, 2.8838081850159556, 2.656897109362387, 0.5251840381853042, 0.20712933713389983, 1.276553023246027, 5.2479994008618025, 16.262714497504696, 24.953440466234763, 32.78318558969806, 38.31457476462088, 34.61055117268717, 38.48038119654502, 51.370446681976325, 53.5671583298714, 42.347057634784335, 21.767614926061324, 5.48372257140375, 0.2219943693208118, 0.04152814399511103, 0.04593905226718034, 0.11477969782126528, 0.013225320576419754, 0.09118411314463423, 0.028816240223785563, 0.029885463394044392, 0.018605094500667146, 0.013707259786315264, 0.08764877825254395, 0.032445099129672014, 0.03373563552515642, 0.025220085611386646, 0.0765017776059047, 0.027829785192866, 0.01148255003030382, 0.06966622786656504, 0.014983403304922245, 0.044125860046234824, 0.02082914542106371, 0.005927544027086228, 0.06552701650728142, 0.04556328997076039, 0.08808491210783682, 0.02881252086691318, 0.06875585494262558, 0.08860019050658711, 0.15517405084063932, 0.1632336022392396, 0.3246287773213079, 0.13206940594940417, 0.26702564570211595, 0.14215948871306835, 0.19287328355975691, 0.06388006153546515, 0.20323437758751456, 0.18371962070945771, 0.1387587478083949, 0.18795253228276007, 0.1176416184452753, 0.23614571399746404, 0.19851003593254476, 0.15118291661623987, 0.12537304672502703, 0.19279947864913172, 0.14223649587121703, 0.15614270773385802, 0.10635181134867092, 0.10522832808595513, 0.14774911135675448, 0.12464309516813486, 0.1933648821807677, 0.1779762748628855, 0.15071944874380866, 0.20067000551329506, 0.15728903573847589, 1.6279872170379086, 11.984170559913883, 36.814079899941724, 52.940304740782715, 63.657498744226274, 46.72306168463923, 40.859424221900206, 39.95189366802093, 38.71193047492735, 34.27210161762853, 23.08084995515885, 15.863860441792397, 6.6995205321619595, 2.5673596945501145, 0.44674699224771997, 1.6167346724579412, 4.840710288093937, 10.537036599651461, 13.460136882720457, 12.276169446206863, 20.42362851481284, 11.666866502454205, 8.501842271897102, 9.22337010983498, 10.93183002164287, 19.208780257932602, 30.655601793719878, 47.9438837112919, 56.11092129061299, 54.597502216216064, 48.96362150869062, 51.89079223140594, 56.22721956622217, 55.593062523872625, 56.319112854619185, 54.87084042641425, 57.836611193995324, 56.231145858764656, 56.52373898413874, 53.873820997053585, 51.050055719191036, 50.12078738981678, 49.99811918504777, 49.4513996185795, 52.27240747021091, 45.42085047691099, 42.306841573407574, 41.39755772006127, 47.06675937098842, 52.78957982217112, 57.97291355748331, 56.58472791794808, 57.63565640295706, 56.65344784336706, 56.37269243117302, 59.09470750439552, 53.704507966195386, 50.99237334343695, 45.72465373623756, 45.28366165776407, 50.442747300670995, 61.046153345415675, 53.37361289608864, 50.6439805799915, 48.84691530658353, 40.75339863377233, 41.78956331745271, 41.938276060165904, 43.34337888225433, 43.61193572321246, 42.760526441758685, 40.972525765818936, 43.75672217338316, 43.697788561544115, 51.3637904197939, 54.70958002151982, 54.857402386203894, 56.69257348583591, 50.27595243146343, 47.20927869119952, 46.454575446344194, 46.19905656383884, 47.40087470700664, 48.12411269833965, 51.799844234220444, 51.9772255805231, 56.69403260754001, 55.80781229080693, 58.811359405517585, 47.01250122439477, 41.12297219614829, 28.153921942557062, 26.83350113130385, 15.642377926457314, 19.212959543351207, 22.93575756011471, 26.85437402417583, 23.154721913799165, 21.66145597734759, 24.43565426334258, 19.698878449778405, 24.449814019664643, 8.322773325827814, 6.075585186481477, 1.6328803738278728, 0.7047464674518955, 2.564707927165493, 5.887871826848676, 16.836915169992757, 27.70124512334024, 34.38753304942962, 40.85880840978315, 45.40445496959072, 47.17364003581386, 59.106988445405044, 62.229065664352916, 49.71657929881927, 25.81847410048208, 6.607449756514642, 0.3266044567909933, 0.24287467792389855, 0.19337835000647655, 0.3238608201424922, 0.1322390944246323, 0.16057020563992763, 0.16314093624391865, 0.12693169091137188, 0.16968199412428564, 0.0760863664289636, 0.17808289898018684, 0.11614733330544927, 0.2503797961699386, 0.1152515620173466, 0.2147990263878338, 0.13654931959125305, 0.11918786732900528, 0.1799725008107001, 0.16023544053877556, 0.1905641413383907, 0.190191715354881, 0.1499970278312122, 0.22717836373034986, 0.19001710859517898, 0.12388888160668074, 0.09394716246113663, 0.19958467342920844, 0.19414258399798026], [0.016834152028745702, 0.054363426226641864, 0.036680178731800094, 0.10697829507050977, 0.02840208926147992, 0.019790184639033773, 0.05282742376889914, 0.04148641135543585, 0.053799083726781036, 0.08910118902642881, 0.01334778356155561, 0.014291202645718813, 0.053460235376992536, 0.023680063107261257, 0.06502221819133529, 0.03111188206070614, 0.024778087353033405, 0.03610495778341447, 0.014572963080999833, 0.04734084378146837, 0.02710631473981325, 0.03274302689298507, 0.05046192045894362, 0.06979736679744336, 0.044836464052599286, 0.03892524152873986, 0.04582816104014074, 0.04330416179953083, 0.019298940333687974, 0.4647238582613007, 7.587627018651656, 17.189991243423954, 35.02296486208516, 50.70632665388046, 36.37390759683425, 47.50562552482852, 36.91597915464832, 30.032143016015333, 32.06963389150558, 23.94788399819405, 13.900487653670774, 6.933530117234876, 2.146209906185827, 0.4871013784600843, 0.4671592517725883, 2.067419050201293, 2.7804252937916787, 4.932988459064115, 3.135717751518373, 6.857908291201438, 7.213167653929803, 3.903863694398634, 4.6474031382991425, 6.59822287098054, 15.829721112405101, 24.22700378202623, 38.481044077104144, 51.350317078252, 51.29827507080571, 47.818854239679155, 46.97204589843751, 48.578738935532115, 49.446006359592566, 54.19402760844077, 55.75529959893996, 52.85672295478083, 53.71516504595357, 52.15099442389704, 50.781549869045136, 49.28447923352642, 49.173221203588675, 49.92179378386467, 46.98966126288138, 45.99228097546486, 39.91377999705654, 37.7651644522144, 38.541679997597974, 45.2547106435222, 51.354298283976895, 55.32438016706898, 53.27740892287224, 53.49109964986002, 52.60273771901285, 53.510448701920055, 49.21087987961308, 47.98245237719628, 56.87545399512015, 50.812160045869895, 39.12117488922612, 46.26610555956441, 54.7090583462869, 49.30739372007309, 48.18308553388042, 40.968089565154045, 38.55113290971325, 39.531760754123816, 39.80714251918178, 37.268804196388494, 38.61423207867531, 37.74259513424289, 37.96426396216116, 35.669159658493534, 41.09649227511498, 46.61259597347629, 53.91815554711127, 53.97004850449101, 52.21649016103437, 48.813394731090916, 48.28281571788173, 44.482513627698346, 44.517916940873675, 42.63893296641689, 42.918201800315614, 44.38543496593353, 50.44359453262822, 48.795999019376694, 56.34153312252414, 52.79454946517945, 43.605973720550544, 32.09391336287222, 26.68557482381021, 12.996906926555019, 12.644402538576434, 8.352764748757886, 5.445411801338197, 5.685865840604229, 11.971173786347913, 5.935254548826526, 5.254867961329799, 4.779187421644888, 3.205078984460523, 2.646141725201761, 1.8462618464423766, 0.3298524857288407, 0.7449271662100669, 1.3654153000923896, 4.468196909273825, 11.727086651709772, 26.027436410227132, 36.08863753657187, 28.837194904204342, 34.84407732563634, 45.73032548350673, 54.71312584415559, 46.78001057717108, 36.83066760340045, 14.021426093193794, 3.2538107566295134, 0.10296601681940018, 0.0688505893753421, 0.014544952991268328, 0.04718160474552743, 0.08093780207057154, 0.01194305218485815, 0.03541637114399383, 0.04188192722898337, 0.027727389880906672, 0.06002690740710786, 0.06212673525536253, 0.057181932647982915, 0.03329524988188379, 0.03728458763010079, 0.02974758097421258, 0.04242271252517258, 0.04645782785730497, 0.03399912380583344, 0.0631981322001065, 0.05641703982086432, 0.03959896606242946, 0.03931736746322244, 0.052344141032306425, 0.04997039461628564, 0.07707763057682784, 0.02576115436010784, 0.03767251923319794, 0.023336623975586508, 0.036628057939871665, 0.06573479487410476, 0.018976262184761224, 0.0567620590088829, 0.05269827666662393, 0.03799002437341598, 0.030002536950632933, 0.0254025217896748, 0.03241175515276771, 0.09242372001491247, 0.02206384358296712, 0.03144355408186394, 0.019626603799781973, 0.024371543643815864, 0.11635513465491035, 0.043817145764947905, 0.03657554644310186, 0.005435469952757441, 0.0073508520783375835, 0.018226595355137702, 0.05842982858960187, 0.045802010628845424, 0.12740255919315163, 0.030471162510014353, 0.07675254882703866, 0.01601992409691335, 0.023979590079116247, 0.012219541935220122, 0.026532162484082005, 0.667375534051849, 8.352984401487536, 24.117106814538282, 41.94664639811362, 55.590458070078206, 38.57911117615239, 49.11734311811386, 38.22825124186855, 31.666312256167014, 33.023658260222405, 24.582186168239964, 16.30456618724331, 7.294959368244295, 2.054945913053328, 0.085997085026916, 0.5124444863007915, 0.5572653489728128, 3.9663225364300514, 5.498671704722989, 7.260155687409063, 8.95916513858303, 8.51580394852546, 5.243856887663565, 6.856454562756324, 7.4492291288991135, 16.210768588127628, 27.018250649975194, 43.006219786982385, 54.40668282970306, 53.05905449774958, 50.185679081947576, 49.072726157403764, 50.696457970526914, 52.54749113513578, 56.7959475517273, 54.335111341168805, 54.14748868634624, 55.11380380199802, 53.78499500213131, 53.300311642308394, 51.87164714259487, 51.27559984883955, 52.21355230577531, 48.892834494190836, 47.18993748387983, 41.727531033177534, 40.509262469507036, 39.100700116926625, 46.918874248381584, 54.12874367929275, 56.47519180851599, 54.439956295874815, 55.03668608204011, 54.75215734974031, 53.228018437662435, 49.60820421095818, 48.8960273035111, 55.76655287896433, 51.343637281848544, 41.95429501994964, 48.41761581359371, 57.88486026948499, 52.92984770190332, 49.040990260339555, 43.958653634594334, 39.66325429178054, 39.74396098044611, 41.804676209726644, 39.03891494197231, 40.408657596957305, 39.84034538269043, 39.542445290473204, 38.4027692579454, 42.55098558241322, 51.35888745707851, 55.836578953650694, 55.92895077120874, 52.836244260111165, 51.08895386418989, 49.43363912643925, 47.60914864078645, 44.23676536929223, 44.28766596701838, 45.37650415974279, 48.43848282291044, 51.72236565620669, 51.54455284918509, 56.58273143153037, 56.57563194151848, 43.90858065697455, 35.56617782961938, 26.2510742679719, 18.217811084562733, 14.631697862379013, 12.506049756080875, 6.264808168334346, 8.765568713988028, 11.938824038351736, 9.430467332563094, 10.881927667125579, 5.115110480016278, 5.706303350387081, 2.0539371284746357, 0.9245107395033684, 0.665146095618125, 0.6431552659600013, 1.4335276258568612, 4.566406194240817, 13.753881223740118, 27.329763327875447, 33.092115386839836, 29.83747970673346, 41.31888281914496, 48.17663715731714, 60.54094422248102, 52.17081416037775, 40.99726415449574, 18.11973417958906, 4.050303178448831, 0.14797225744733888, 0.016924355051390106, 0.04326118809741832, 0.04162310059332559, 0.0859523225095003, 0.044864253892052564, 0.020913284857787436, 0.05480301513847324, 0.04244103734832137, 0.03976453298462495, 0.04620977624830219, 0.045241533042562586, 0.0380732138611136, 0.02212437218986452, 0.031187945015488133, 0.027702859745571212, 0.004040148050989956, 0.07344548515374623, 0.015235395478685538, 0.018578624247663447, 0.015121437984729006, 0.0886539162527169, 0.03695133555259916, 0.01761139036276408, 0.0495746604076797, 0.04938072908008772, 0.09433773706757254, 0.010925217234950152, 0.10664274855967491, 0.17594333798173936, 0.2354407292460242, 0.19899835569723962, 0.2507276613745959, 0.09051294351417212, 0.14097358460628218, 0.10959420954027485, 0.16993962949322117, 0.2595086684150081, 0.07852158374002866, 0.1264063767608135, 0.1431834724761786, 0.16334857671491562, 0.23651720535370613, 0.08722909230498538, 0.13500507019700544, 0.09134193491791526, 0.1438386155472648, 0.11983411611929057, 0.12127700442027663, 0.12975666311479386, 0.1905886255084507, 0.10827951839253788, 0.22253738776330026, 0.11890707312211876, 0.2098001954295943, 0.2078561247476647, 0.12837000566744997, 0.8307548155707698, 10.098207708328001, 26.539284144678426, 50.64726360382573, 64.17373757208547, 48.16572904586793, 61.09943482183642, 48.35763100654849, 41.78313063037011, 42.77073244894705, 33.25755311596778, 20.096671504359094, 9.606251293613065, 3.2988013230985214, 1.358725452615369, 1.4532222142142635, 5.286573950321444, 8.076762268620154, 10.55865474285618, 9.504348116536296, 16.08559398881851, 15.084744364984575, 10.07583745064274, 11.549852394288587, 11.448567971106499, 21.0263006917892, 31.38568824337375, 44.20892046343896, 58.21282925144319, 54.885282593388716, 53.0777681258417, 50.46054309414279, 52.39598958723007, 54.1236210638477, 58.045481328041326, 55.37430017225204, 53.354903190366684, 56.0297360727864, 56.32408249762751, 55.99768246373823, 54.011688386240316, 53.80654842622819, 55.32341918637676, 51.614284746108524, 49.75753276578842, 43.06391785221715, 41.2696845300736, 41.344582188513975, 48.6533228043587, 56.313637225858635, 58.53368305390882, 57.071548969514915, 54.306493728391594, 55.46117674919867, 54.292000570604884, 50.98330090122839, 50.386265170189645, 55.17637345098681, 53.762468830231704, 46.49111624686949, 50.407822516656694, 60.040947929505386, 54.73892327277891, 51.58361181136101, 46.25101620151151, 41.43007809115995, 42.938900147714925, 43.199118029686716, 41.63965032946679, 41.89266281743204, 41.99620946761101, 41.31790614897206, 40.25783854146158, 45.892166399186664, 52.47422126031692, 60.76122060898812, 58.92700264530798, 55.8949516665551, 53.00836570801274, 53.90420759877851, 50.75082594348539, 48.0601506079397, 45.50540893308578, 47.640484456093084, 50.107200299539876, 55.94685639104536, 53.822673290006584, 60.24440127034342, 58.478012854053134, 46.73323631286622, 37.26056721902663, 31.993143750775246, 17.629977233948246, 16.100927514414636, 16.665584079680904, 12.019505231611191, 13.639617677657837, 26.115315152752785, 11.380542305208023, 15.235870345946282, 12.974005187711409, 7.441134337455996, 5.235194823434276, 5.650589514163233, 1.1348469819753402, 1.6248848673797425, 2.2333475658970494, 6.373171979381192, 16.75582605023538, 35.01182140842561, 47.35651270035775, 39.86620949160668, 48.09300830287319, 57.818403551655436, 69.57952853172057, 61.380449110461825, 47.28353700330181, 20.724517453101374, 4.628075659275055, 0.30927113527732514, 0.1910451832678049, 0.12950688780796143, 0.13598190890925546, 0.27672018194871567, 0.16254760114656341, 0.0800875134225334, 0.08205399217624819, 0.1270719233059114, 0.1454703675042237, 0.16984040578526838, 0.3190867440594781, 0.09543960132906515, 0.11876421304599893, 0.0924328517829699, 0.15590112956781543, 0.1515394539362, 0.2751455341856326, 0.18077563674699876, 0.14763350868898054, 0.11446472077119736, 0.17247948675386368, 0.20740463849036925, 0.15642747793707157, 0.15358078714099624, 0.15940418917565577, 0.17111497690841077, 0.09039277496236948], [0.04017661167909542, 0.057765028980230136, 0.046229280846854376, 0.06754026492877353, 0.018447506384203033, 0.041512592410248135, 0.07351174409831725, 0.07031026266274915, 0.02762332066683279, 0.027427862909051682, 0.0963048899786607, 0.027614596840595047, 0.057081958173864314, 0.027009396956512527, 0.09387613844967659, 0.06290195877814005, 0.08302773589328413, 0.04502484507317986, 0.06530727950796004, 0.028007425660748157, 0.032787969441062985, 0.07421328145409785, 0.06586206506096548, 0.0579135159721538, 0.0541734172692222, 0.023723394955478372, 0.08111807022003398, 0.03906096166540538, 0.08376717927955812, 0.12373267627891996, 4.2167832774500695, 13.39524813236729, 27.657128264827115, 47.395877607407115, 47.84439279187111, 38.19983759234029, 29.396705319804532, 30.76123122246035, 24.920125815176196, 26.475855496621904, 11.188666820526125, 6.550328769991475, 2.6017287277406265, 0.9711435533338978, 0.3132708803299935, 0.6586931225272917, 1.6334820899271196, 5.008535760064279, 7.775736537671859, 6.343622313391778, 6.195414085542002, 2.2573112864648146, 4.899354134836505, 6.128067479979608, 12.072613143151807, 24.884200826767955, 37.71658589763027, 47.51320354400143, 51.70206346819478, 49.09060824301935, 46.269200309630364, 48.68557253191548, 51.64550681268015, 55.235840505169286, 54.98361641360868, 54.37241700387771, 53.122773401198856, 55.161029138872706, 53.718310786831765, 52.755639553070075, 51.40231593962639, 51.917613398644235, 47.85764255831319, 44.32100219111289, 38.902106592732096, 37.93217897415161, 36.67616936468309, 45.06748022571687, 51.501434233880815, 54.18406478820309, 55.413033577703665, 56.915269974739324, 55.029782710536836, 55.82986777828586, 53.38259512378324, 53.79061575858824, 51.27144213645689, 56.08066412710375, 38.28437643666422, 45.19682822688934, 56.05447838383337, 49.47611055066509, 46.191109841869725, 41.97302041515228, 41.535503556651456, 41.83287020652525, 42.49946525019985, 42.41391835674163, 40.68037194590415, 38.495968695609804, 38.05676521793489, 36.63595330330634, 41.11922241026356, 49.23969361089891, 52.97645330429078, 54.744034121113444, 55.396100705669774, 51.98782382472869, 50.88890121829126, 48.1202099400182, 45.183570615706905, 43.62241629631289, 43.268026228873964, 46.11881663722377, 49.118202117181596, 52.09414359061949, 53.430204852934814, 52.11444970100157, 43.243738912766986, 33.51138537929904, 19.9154285846218, 15.483535662774118, 10.055157734501748, 8.205738625218792, 3.494719300539263, 5.627294557709848, 6.926462006184363, 9.760302382130778, 8.045510784272226, 3.4048006803758684, 4.023604585278419, 1.347860854960257, 0.42094953298088045, 0.7401331718410216, 0.44271332482176445, 1.1937074170958613, 5.68497448198257, 17.15965759369635, 24.365639955766742, 31.590196701788138, 39.379223700492616, 36.80481133922454, 41.8847906204962, 53.24895604964226, 48.979820897502286, 31.566778190674324, 9.458901574534755, 2.236620293509576, 0.09517568403915053, 0.09565069685660063, 0.07449269670272067, 0.05041908465265747, 0.0539455673987827, 0.050389038684267196, 0.061477682583274386, 0.03584760586701093, 0.05794974427009302, 0.02985644781391227, 0.01421190296945673, 0.02250928923697962, 0.042753041977243084, 0.07230802844729155, 0.01983944983822444, 0.029954141261236324, 0.05219143289591997, 0.029307400259459694, 0.03375745753967955, 0.014337716631651407, 0.04851549022620724, 0.011101798586276992, 0.03295948886643014, 0.036566537249112324, 0.01622523470301061, 0.0204401106513556, 0.07495988010158462, 0.05676204751756403, 0.07172671326946828, 0.009333650420059361, 0.03793603432695231, 0.0724866341859583, 0.010414083371870221, 0.06456307871567626, 0.08586907173476874, 0.05484158383502115, 0.040002648433249806, 0.022010966279213468, 0.047834254200420076, 0.02871594016229914, 0.022508239696523356, 0.028700890365026654, 0.07253548761288967, 0.0321892372542812, 0.026835378169292406, 0.04702924134870691, 0.031287402380257845, 0.05987262879047663, 0.008551621163684514, 0.03286846229926713, 0.014120313327669377, 0.03468275385638399, 0.01635792687715542, 0.008815526004670369, 0.0630142749287188, 0.008597701352329986, 0.02161920998215435, 0.13879219520716898, 5.369683581013834, 18.35586674751774, 38.036623847100046, 54.69763248197494, 51.24156152048419, 48.048567848820845, 35.69711439071163, 32.81302109841378, 31.38761216594327, 31.263398547326368, 16.262481116479446, 8.68573671387088, 3.2460785392791998, 0.8016778564741536, 0.5017905934683738, 0.8731544113928272, 2.868179010768091, 5.893452869307611, 8.80533468338751, 8.490594875427986, 10.5799610576322, 7.200957315583383, 5.441169757996836, 8.173812002904954, 16.096515828563323, 25.875046445477395, 39.87478771517354, 50.50213590745003, 53.371483049085064, 51.61908964956961, 49.84784926137617, 50.16251356370988, 52.80421418528403, 57.16112021476992, 56.194887468891764, 54.4165240564654, 53.96333340675601, 56.10307655026836, 54.698248294092, 54.80947494506837, 54.06069055680306, 53.9495345084898, 50.67377098145024, 46.19021554147044, 40.87820845265543, 39.0940595442249, 37.9283978093055, 46.1592915750319, 53.68449603357623, 56.653479222328436, 56.213444202176994, 58.44917951091644, 55.952457535651426, 56.33949349003454, 53.41773563815702, 53.78462237696494, 52.5616705033087, 56.76942056225192, 43.51727324147379, 48.1137066502725, 58.23524951934815, 52.04561994921777, 49.22482390557566, 43.63598377473893, 41.42111155294603, 44.281001860095614, 43.012726999098255, 43.11772492624099, 40.79154760606828, 39.59960599099436, 39.59279675637522, 37.65192170296946, 42.33342347606536, 51.876946264697665, 54.991786710677616, 55.834668759376775, 55.45067656424738, 53.79394192849436, 52.31938177539457, 49.98842700835198, 48.71660240234868, 46.347428060347035, 47.44131434348322, 49.578225535731164, 52.183946255714666, 54.511390501453036, 55.779739887483665, 54.42294497643748, 44.05077834283152, 36.27392638114191, 22.83268943909676, 21.181589288096276, 12.031209584205383, 7.93916012971632, 7.496578510730498, 10.45589845026693, 14.332482795561514, 11.739019482366501, 10.835387764438506, 6.016981544033174, 4.868771904899228, 2.8156239082736354, 1.1927876212904531, 0.5443503323101229, 0.8377900767710902, 1.4598035836412062, 6.2332090639298965, 17.11139478991109, 29.19146926172318, 40.23015837515555, 42.152590444011075, 39.604826665693714, 48.125779705662886, 59.22466739531487, 55.681021674986816, 38.05118368517968, 11.606375709656747, 3.025947035320344, 0.11620698857211298, 0.06629704212349269, 0.035144134139221524, 0.09060773923392258, 0.07145659066736698, 0.02634882423726301, 0.031042531951360648, 0.07012611810838984, 0.045288536367156816, 0.040702661274061094, 0.046902626167021455, 0.03999888694154159, 0.050265139284273314, 0.06816516284860911, 0.03054965396351632, 0.05994398605018374, 0.07494863393085618, 0.04718486828008487, 0.03413901529124668, 0.029376376900942098, 0.0177471449733862, 0.04892226759224169, 0.022084223436972788, 0.02402168852577527, 0.025279917078272953, 0.049056547483609575, 0.06269216176963623, 0.09679116428859773, 0.19468888129678466, 0.10708937781953043, 0.1511289227393366, 0.15514253398343442, 0.17228906793940454, 0.08550337966411345, 0.21998467554728832, 0.26138589026466497, 0.25661910733869003, 0.12241043150424959, 0.2555465536011804, 0.1224854774773121, 0.11138399011425434, 0.08471122176776971, 0.20629103776187668, 0.1691282964161327, 0.1503875334897349, 0.1207876351151255, 0.1446639833551261, 0.14048992265616694, 0.16934499204639467, 0.2121928105911901, 0.23382816013068924, 0.08600267746876325, 0.1231609908263049, 0.10175707644873089, 0.33176212841945313, 0.08788793558074583, 0.1343524552160694, 0.17555609585777407, 6.249081915424717, 22.88447060892659, 43.5823610521132, 63.191697674412886, 59.23137072593936, 50.959064575933645, 39.64056730270386, 42.72441317958217, 38.02548823818084, 35.84374043249315, 18.328412117496615, 10.279587911021325, 4.229723666944812, 1.3351008944934415, 1.7043588286445988, 3.122463082113574, 6.124458409124806, 11.551470371984667, 17.949358186414166, 14.143445145699287, 15.371541207836522, 9.859850175919073, 9.028646003815437, 12.3953555668554, 17.19922842517976, 29.73510584523601, 44.08708772351665, 53.98764817945419, 57.72145825047647, 55.61620450788929, 53.35574649995374, 53.86814532741424, 55.33716317146055, 59.79019080438922, 57.51453361203594, 54.97967050921533, 53.12762929547218, 57.48795563174833, 57.30004272153301, 57.4862454783532, 54.53556014645485, 55.1827786814782, 52.76593185240223, 48.60565816202472, 41.911015587468306, 41.26604457055369, 39.73433156167307, 48.714417642162694, 56.07891867237707, 59.66038780827677, 58.45101518015708, 59.06807853329567, 56.19893927727976, 59.12839281943537, 54.79611927463163, 53.034029776050204, 52.58901726815009, 56.48245996044528, 47.08578286632415, 50.24609534971176, 59.75860003502139, 54.50036864126883, 50.48953333208638, 44.939732551574714, 45.11024582770563, 46.65114110515964, 46.202127779683764, 46.54587645684519, 42.89335750764416, 42.012087222068544, 41.04130060442033, 39.80253373422931, 44.411738380309075, 54.75620523575814, 57.25879115443076, 56.739838046412316, 57.30620476507372, 57.74635745633034, 56.188646977947606, 52.666323261876265, 50.71355165973787, 49.197951747525124, 49.99692286214521, 52.39817826978622, 55.118530258055664, 57.89217156748618, 58.73799147144441, 56.41203772637152, 45.5820010554406, 37.60583385344475, 23.304017128482943, 18.23036463029923, 14.527531477712817, 15.5272190993832, 9.811115707120589, 12.355028698521277, 12.974844574928285, 18.670589885404034, 20.45581940681704, 9.739093146016522, 8.309788319372363, 4.6637089214017315, 1.237532304179284, 1.3612023068051184, 1.335778729088845, 1.628907748287724, 7.7116523635002885, 22.46871113777161, 34.13543055134435, 42.41267496539701, 50.737121182103316, 46.558530023021085, 52.785877104728456, 65.7478278683078, 64.12783407395887, 44.783543771313084, 15.133059140174622, 3.884040035547749, 0.421150186730008, 0.29713648641782425, 0.18093375729457026, 0.15932724330454104, 0.2560611501816781, 0.11700144473222956, 0.15503632355361216, 0.1302416887014143, 0.11999576067131375, 0.1826760097737274, 0.1325905295990167, 0.07314669554151836, 0.20704316756417676, 0.14427435103683703, 0.1046062876740771, 0.09594073774473322, 0.19219855928132612, 0.23268537145228158, 0.09339815321108026, 0.13325304243593447, 0.10795468945176372, 0.14668935128758032, 0.08513214877776562, 0.11042179134223731, 0.07861209702828238, 0.1580247252939209, 0.17317907824631662, 0.22887944664445617], [0.016860543757737163, 0.053788385308918454, 0.012870008997138471, 0.08128043489470597, 0.03684792900457978, 0.019768973579630256, 0.0039412439453430596, 0.0071822753882095705, 0.024609796988267093, 0.019304772178011558, 0.04790555017309324, 0.029377813315800125, 0.05390709063278572, 0.01609715437816997, 0.05871457581017768, 0.1384044321434152, 0.031170545243507916, 0.03704082228303437, 0.031212683909782962, 0.018217724056974537, 0.036663336288784786, 0.05403359090128253, 0.003607475716102448, 0.04826737733017053, 0.027003161000808882, 0.04377817104180013, 0.052828013656600836, 0.0443500901512321, 0.023064354412077416, 0.025147380036932808, 2.323236768284152, 11.374042937832495, 22.330884933471683, 44.431342386430316, 45.155470755792436, 41.13288010320356, 27.54186353375835, 25.26609063148499, 27.858188959860033, 25.82494797245149, 14.160878119930146, 8.906631854272659, 3.0045585959188403, 1.245220640013295, 0.33890485643379153, 0.15390825908510916, 3.4456472627578245, 6.044824978997631, 6.761288546746777, 8.288405518377981, 6.707974220475843, 5.484934583786996, 2.6486834210734216, 4.093599035855263, 13.796168296567856, 22.719485913553548, 37.8689895906756, 46.85464543680991, 49.559770784070416, 51.377208848153394, 47.986884655491004, 44.68437056387625, 43.85953534033991, 49.62312882946384, 52.99811655475248, 56.60467317027431, 55.49325389246787, 53.339335303152765, 55.68922335101713, 56.078216568116225, 50.71865858570222, 51.13785405312815, 46.588908780005674, 41.903884718495036, 38.13496943443052, 38.98065205543272, 38.0369847051559, 43.522144825227805, 51.204075428747366, 56.18156709978658, 53.2545179705466, 55.3652944103364, 53.63612536461123, 56.570081787724654, 56.02571956572994, 55.09623158362604, 52.509699098525516, 55.244289290520456, 36.81333857197916, 45.19413748095113, 53.27650677773261, 50.51809603168119, 49.124728941148334, 45.375900114736254, 46.01600347026702, 47.20965916110624, 49.454106053998395, 47.561342793126265, 45.174364812912486, 39.120715971915956, 36.731215907681374, 38.13763272377753, 38.76894604775214, 47.00326012026879, 50.273214617083156, 55.38273326812252, 53.91943423978744, 56.45885905911846, 52.7280927473499, 52.8342556184338, 49.27798378852106, 48.54882301822786, 46.66659524363857, 49.405715773182536, 51.49543300751717, 55.09579227816675, 60.102560520172126, 55.26170461408554, 42.71331679436469, 29.249118297330796, 18.098531807622603, 16.956976959782263, 9.72904501422759, 4.802004339233522, 4.208773797558201, 8.159440438593588, 15.771912240212965, 12.484312961178443, 11.496226729885226, 5.205844217731107, 4.843954578522713, 2.272947079712345, 0.48291201132439804, 0.07788396109977076, 0.6179786749905156, 1.821846440434456, 5.7388168573379525, 13.651426953654136, 30.988801256302867, 30.201452124503355, 37.320414743115826, 43.168594145005756, 42.81040330086985, 49.915921995716715, 45.29934721608316, 32.74672323657621, 12.668983051853797, 1.8264761855525358, 0.038972987958620635, 0.02736107536381291, 0.024752622590430325, 0.03918381918582224, 0.055123741678412885, 0.09214170006734711, 0.03896998872439708, 0.026438280324181242, 0.040713045595874714, 0.07239100343037037, 0.003855255842697056, 0.024396746021304882, 0.046328125341284665, 0.009024887300667264, 0.07775277620361698, 0.06206454040722982, 0.15172653260730928, 0.026896529222628283, 0.03345657267697877, 0.054457015357911594, 0.08130915553098725, 0.02845680709147165, 0.012648393167182805, 0.050296039440699165, 0.0600318180307025, 0.016185084034899072, 0.07391232381304426, 0.03351347002711508, 0.10899031009044378, 0.05732634405214941, 0.02311571294652118, 0.10649283281377248, 0.051951153248909025, 0.01795942793720432, 0.03147974599062676, 0.052228423451343854, 0.05947013768637854, 0.06364077397231614, 0.034495981620444406, 0.013927260128360604, 0.016145730098228783, 0.06086692664652102, 0.03905413582200005, 0.09439662624631198, 0.03177367094453545, 0.014721166620391512, 0.04274631955570752, 0.06335648257405528, 0.06618065038515676, 0.02422684878711739, 0.0342723184205111, 0.06955332182828458, 0.024244235152558937, 0.04378180995944046, 0.03395015163527381, 0.028107308204315846, 0.03456160471203827, 0.10905120641954484, 3.1781840276333595, 14.296624487446202, 28.359273710558494, 50.099179052537494, 52.31113695329236, 43.68516245195943, 31.902793915041034, 34.66697054524576, 28.49228716665699, 32.134174531505955, 16.867490045485958, 9.679828093897912, 3.5410998569380854, 1.2977611561936717, 0.25417130320302905, 0.8064883370553294, 2.247996883046243, 4.224703523420518, 6.505771625426508, 8.43059535949461, 7.790209593311434, 9.097228646278381, 7.805270514180584, 5.7500010055880395, 13.802698062312219, 27.152134872251942, 39.674582096838186, 50.75283811938379, 52.13266911045198, 53.6515167451674, 49.772802552869244, 47.71565668044552, 48.59391066335863, 52.46840830772154, 55.63183515302597, 56.17921760005336, 54.8090591738301, 53.48416489939536, 55.34307026094007, 57.16414828454295, 53.08684056805026, 52.4073762278403, 49.29074718106178, 43.96256031528596, 39.316308882928666, 41.04186934809531, 39.73651239948888, 45.42126232577909, 54.77713108062745, 56.16462246064217, 57.44204428888137, 57.09179232197424, 56.58399443472586, 57.428876892212905, 57.07023889787736, 56.227690250642844, 52.82383388088596, 54.72576372085079, 41.584152713898696, 49.17511178601173, 55.488088130950935, 53.43088734534479, 50.62020317200692, 47.71422501533262, 48.32173739710162, 49.17140122382872, 50.37902055248138, 48.8378232525241, 47.38016459249681, 40.947320615091634, 40.23941124639204, 39.26616922501595, 40.41769866020449, 50.04062198823499, 53.85067116829657, 56.551230876676506, 56.385181257801676, 57.00527660308346, 54.01577941833004, 53.313557486380304, 50.504285366304465, 49.50840342429377, 47.74706702078543, 51.934224636324, 54.47866224473523, 56.583343321277255, 60.781954257718986, 56.13370633894398, 44.9521311636894, 34.51055034514397, 21.727877393845592, 19.267574625630534, 11.232815058000627, 8.324417779522559, 7.213296111552947, 8.11416304880573, 14.505246531578804, 7.163894349528897, 10.181012865035765, 6.291715627716434, 8.231086942457384, 4.317440611700858, 2.8305632356674444, 0.11881767066135523, 0.6355269914192538, 1.6471693232174844, 7.44678843405939, 15.53751139871536, 30.578852776558172, 31.573324626491917, 39.91586277561803, 45.991931884519516, 48.66880047705866, 57.53546730164559, 52.1120374433456, 34.91790417701968, 14.163355096693962, 2.1393050637937363, 0.07494148633052265, 0.04352304844125625, 0.03940798034290633, 0.02478817864621599, 0.04821893376027865, 0.04296240997650931, 0.07903575131128873, 0.07315049533762279, 0.04230565812078215, 0.031686723795569235, 0.02431403342334013, 0.08282061636207566, 0.008733477030370024, 0.04395916697479064, 0.02973592111600503, 0.06161180159617817, 0.055714993016614076, 0.04344282754426522, 0.0035902021092272577, 0.04231822196274035, 0.02396913680938944, 0.028597072044747974, 0.029938373256534822, 0.04037774040273601, 0.05374769837925992, 0.011419795937986385, 0.035671110700575576, 0.01831160813209511, 0.18026618827735225, 0.16366970545101553, 0.10308006432868781, 0.13649045339515134, 0.2984715325217093, 0.1585938060475934, 0.1425445551473287, 0.11661043345567682, 0.20887462332123713, 0.07973138212917313, 0.1274531133352749, 0.07791082014239605, 0.14641942786833934, 0.1511176152815742, 0.15895823407317364, 0.18202595352645845, 0.09156550235685804, 0.10574171424753244, 0.08303096878432459, 0.07254213725607242, 0.18629324712580253, 0.13613054528832436, 0.12774181356953998, 0.18651829311443915, 0.24378004063281322, 0.14643317148570092, 0.13875445771601894, 0.11110282818516416, 0.1558534635771667, 0.17782958434714427, 3.545211481471216, 17.413984075669322, 35.03774435289445, 57.0283793633984, 59.402754768248535, 53.40166960993121, 37.93898820877075, 35.87358182476413, 39.032949016940215, 37.32791039251512, 22.03152571955035, 13.537859628277442, 5.261966470749148, 2.1652905210371944, 0.689842134954468, 1.3606675161469368, 6.885818896755096, 14.148402041004552, 13.00565577322437, 16.805679375125518, 14.996692057578796, 11.180768147591623, 10.39659809681677, 10.27602836008995, 20.062315464019775, 27.769951320463612, 40.13997916252383, 50.998621679121456, 55.62453562213529, 58.32939817059425, 52.710646044823434, 49.781729867381436, 49.87465866150395, 53.798695841143214, 57.123716492806714, 58.45162314753379, 55.387306751743445, 52.87377742029006, 56.62147268172234, 59.145745385077696, 55.52494664346018, 55.0714853502089, 51.55584927528135, 44.64401329717329, 41.872435154453406, 42.009820092108946, 43.34067244683543, 48.256747645716516, 56.33430811666674, 58.30913128391389, 56.94465637207032, 59.203576810898326, 57.96013055309173, 59.80661769067088, 58.59779027200515, 57.28991516174809, 53.87471529745287, 54.914347356365575, 44.329690241044574, 51.24047502394646, 56.63895860795052, 55.802595538477746, 54.161322885944, 50.98118282133534, 51.83552211330783, 51.11106426485124, 53.83596620252056, 53.298366146702925, 50.504218686011534, 43.27714181715443, 40.86975182256391, 42.645075398106734, 43.167240927296305, 52.76097005413425, 56.289287151828894, 59.980264940569484, 57.58476364997126, 59.07783739028439, 57.59561684823806, 56.84444765890799, 53.24783425177298, 53.16006337442706, 51.43050601405483, 54.86991082468341, 58.44193881557834, 60.205091276476466, 62.66974787558279, 55.870397629276404, 48.92813582574168, 35.16879858509187, 25.143412620790546, 21.82988255254684, 14.533746473250853, 10.105351325004332, 9.866421126550245, 17.582006646740822, 30.132681208272135, 21.06919377080856, 16.152905783345624, 15.64144636354139, 12.834956184510263, 7.442391457096224, 3.3758447631712887, 0.5305253870544896, 1.0908381112160221, 2.9071556031703953, 8.008953803969968, 19.995660666496526, 41.87078383661086, 39.83574836484848, 48.605540490919545, 56.72798856612175, 54.489268333681174, 64.22273974264822, 58.623203308351584, 42.70961407692202, 17.387564951373687, 2.9680462325772936, 0.18897886027491864, 0.0810845155689505, 0.10394788872931274, 0.14545743594006186, 0.13515433476817224, 0.14120857441617599, 0.12628453047645669, 0.1677472543932738, 0.1058695283568194, 0.12342784989384875, 0.08261816996720531, 0.1134492712275636, 0.13157190845137642, 0.22584918585996475, 0.17301185657420468, 0.2348804585034809, 0.14718176196179084, 0.13271422215527104, 0.09454131727257083, 0.18435519789495777, 0.20987406162725342, 0.14220024459064007, 0.09437530601937925, 0.12611319491219136, 0.16715182021500605, 0.11851153426593351, 0.149901389414745, 0.1285646609481304], [0.18494336955970336, 0.03127247515705324, 0.02159852752341859, 0.019669370658154932, 0.05909904086541745, 0.023966166303463043, 0.005335107167822219, 0.08962281829407139, 0.01780761037802985, 0.04858451857862454, 0.08725166891611393, 0.07001868193788875, 0.04497257872454582, 0.013071730481310478, 0.013486879273137499, 0.026221988805299325, 0.030176101830757918, 0.04023023783379505, 0.03077267939525266, 0.045846999142198794, 0.04092663090916411, 0.025334054596662044, 0.04343443505105473, 0.041602998446192474, 0.02906642155721784, 0.0531631158364396, 0.03714189226288469, 0.15877052720996643, 0.01995499313418423, 0.06572539497527384, 1.0459742863332073, 8.786589676334012, 23.796427557545325, 45.08688026858915, 52.24850846875099, 44.15774137743058, 25.957649600121286, 20.426627166809578, 33.6448714810033, 28.798234001282726, 26.72685580868875, 13.235551772579072, 3.2664231379185957, 1.0851672219653283, 0.32139968607694874, 0.7005316968406401, 0.7231275520978436, 1.6392241947112547, 5.4393350693487355, 6.145228830076033, 8.29265050349697, 9.461497202996286, 5.4090161285092755, 3.8881259195266233, 11.503943993199258, 22.035979570881015, 29.987973205504883, 45.2222373408656, 53.74153514062205, 52.06638497691001, 49.98646190089565, 46.561573782274806, 46.65522429250902, 48.262776328671364, 50.01298496800084, 56.49490564100204, 54.51188079772457, 53.739522964723655, 53.75454172011345, 54.967507239310976, 54.378410385501006, 48.37329695301671, 46.982855950632405, 40.31485019191619, 39.12044140600389, 38.00807683698593, 36.33091449737549, 39.841298518642304, 44.217228043463926, 50.16017583108718, 50.48922738721294, 50.41904441771969, 51.35417669050155, 53.86531337614983, 51.423343766120176, 54.682868680646344, 52.98099933132049, 57.2273180561681, 40.373148379787324, 40.60104593153923, 59.369991210199174, 54.64067966707292, 51.99047534696518, 48.45068531651651, 50.23034703346991, 49.208859858974336, 52.83708756969821, 53.05965854275612, 51.27505856175577, 43.49319773335611, 36.89932477089667, 36.674737699570194, 36.32404250483359, 45.76213198323404, 50.15795184719948, 55.36707908876481, 54.865690354377996, 57.29669301740585, 57.546901010697894, 54.4209445676496, 51.29237190369637, 50.421652793884284, 47.48535079340781, 49.94720682021111, 52.68950054722448, 58.593946349236276, 53.386811671718476, 47.7419836290421, 39.77918778696368, 36.71257680462253, 17.57814311212109, 15.73212371718499, 3.8478522483379614, 3.0873534564049017, 6.735860801512196, 9.544088590529658, 14.31569112885383, 6.75803150861494, 8.138112060485348, 2.7435089263223835, 5.200556862738825, 3.0121557366463447, 2.208470423375407, 0.3718609170567605, 0.5343854896003201, 2.05160086674075, 7.415001055886669, 18.2215706763729, 37.24725861703196, 39.45509410673572, 35.88541561557401, 34.795220282769975, 50.835874695931714, 50.19762269912228, 45.21525552195888, 24.543619463520667, 10.038685740963107, 1.0014490723129243, 0.04694043643652432, 0.07298561789455914, 0.014154633109067238, 0.03273198756599619, 0.08489562679202327, 0.0356439643749787, 0.039874834323962854, 0.026592794512849183, 0.05601550632667157, 0.09805276554318205, 0.06150195224871559, 0.07577890470143288, 0.018311581319017757, 0.04154034011486558, 0.046905307474756436, 0.0807018010246177, 0.034465460677541075, 0.04769682951812302, 0.0513706156503289, 0.030091531469576785, 0.04012027357314383, 0.030149328973024126, 0.028620541148308306, 0.02180545936308561, 0.01838360890565861, 0.07157015554126232, 0.04317850422775073, 0.048221760624719244, 0.07196852126188817, 0.039148506362952536, 0.02534409417890974, 0.035118753646290114, 0.05830247413306948, 0.005851537092483693, 0.023387375385350278, 0.06539848993622488, 0.03732323293544112, 0.05360912073463683, 0.06554611507923373, 0.0765090094759099, 0.037528425755520026, 0.022781135536910548, 0.03654819327376543, 0.02989067662236912, 0.007117913947666005, 0.024765738015694004, 0.054440644058969714, 0.05911590629107049, 0.010410304643183706, 0.07767946925014257, 0.032498572066786795, 0.032467633605964726, 0.08923429680327255, 0.014703714179866498, 0.05711654704364558, 0.10455718143813073, 0.053637305109371106, 0.03319518730765389, 1.3561652480594575, 10.417587680201377, 27.861803423973825, 52.46483895086473, 57.55848376981674, 50.05284801606209, 31.431417196027695, 24.98899479066172, 36.465251753407145, 30.844536481365083, 28.99277767827434, 15.947328479059282, 5.057970862234793, 1.6496818464609886, 0.3213396554272021, 0.7014532086829985, 2.075634454527209, 3.90862520663969, 6.664970334499113, 8.481820533352515, 7.392209143407884, 8.684654139703321, 6.289528906345368, 6.483584248250531, 13.631923948564838, 24.5027248321041, 33.09260960548155, 47.72647849975094, 55.238135091720096, 55.55288176382742, 53.62835907167005, 48.634613098636756, 48.30175292107367, 49.75479887377832, 51.454526608990086, 58.04377901938654, 56.83218632974933, 52.84234354572912, 54.0645384019421, 57.2335938484438, 54.719021166524584, 52.36406933876776, 49.37301105068576, 42.156708932692005, 40.290888432533514, 39.53052128514936, 37.73760195701353, 41.79876519787697, 47.17671125165878, 53.68886163157802, 53.02230188923498, 53.39660975240892, 54.28732118298931, 55.799116396134906, 53.200722663633286, 58.06806241312335, 53.446196356127345, 57.25231532127627, 41.62159173719345, 45.048091949955115, 59.70989596459174, 55.13449430465699, 53.49691260245539, 50.31360326274749, 52.06385897051904, 50.84158958927278, 55.522801106975926, 55.196028447920284, 51.646930633052705, 45.019442958216516, 37.9396197103685, 37.91641496842907, 38.31831278339509, 47.381400139101096, 53.700283573519805, 55.77629604647237, 55.8003637098497, 57.54393569884762, 58.9479402572878, 55.530539943325905, 52.98308603225216, 53.01034650494976, 50.32603325382356, 52.33297671041181, 54.450260362317486, 61.09193917243712, 57.17540156456732, 51.8098541229002, 43.16930409400694, 36.6504111597615, 21.802067064469863, 16.05362961369176, 6.681573727438527, 9.219688965428261, 9.754712024042684, 9.940231307860344, 12.305279316440707, 10.308467342007546, 9.884423825048632, 6.6570064521604975, 4.32008134741937, 2.2991737627214004, 2.941002961127989, 0.4156329440734079, 0.26271986384545604, 2.1384573415402444, 7.093250011244129, 20.274888315508445, 37.609618940661036, 39.10983531705795, 43.50798114653557, 44.834671866509225, 54.34238733783845, 58.78596205865183, 51.80562188548427, 31.75853502365851, 12.089842154133706, 1.4640759027773336, 0.06444769821340038, 0.034136602114285194, 0.012930191906860039, 0.03414689067510828, 0.06068314981436538, 0.002770042502238686, 0.03993468877348689, 0.01667083357460797, 0.04427470326904328, 0.08428590507396767, 0.04666346117794033, 0.056121896787156025, 0.00858170926691063, 0.12615297785809926, 0.04095329459936869, 0.036175296146182284, 0.06820416438483423, 0.03366856452738566, 0.06531973609760885, 0.07668752328402574, 0.04122552777370138, 0.02211487461482325, 0.016251549823209643, 0.055248185000833006, 0.059769513355868484, 0.11691760406979632, 0.01836397215693949, 0.024239251750611493, 0.27398362395263487, 0.12022511207408483, 0.0872849171320277, 0.0920595524592265, 0.16013853041635406, 0.14093319645091412, 0.09134935830990154, 0.1826920822983788, 0.09920640202659754, 0.11265632426065784, 0.1265425182458374, 0.18893222084208844, 0.09666034711464759, 0.17658934928476813, 0.12369743623440305, 0.11130017243445882, 0.0969504799333311, 0.1181822926587155, 0.16517347475934416, 0.1402324098612993, 0.10596660701858421, 0.1851490182020972, 0.10859855570860448, 0.1655941029950496, 0.11801668743212378, 0.09153419234339269, 0.19002585731927427, 0.3751261982946627, 0.13047994204586552, 0.15888878054195837, 1.7411495576943121, 12.113290083023811, 32.9603551280114, 58.51763663753387, 64.01524243816253, 54.689744595558416, 36.083656126453036, 32.9058341826162, 44.67296038904498, 39.015157145838586, 36.438916960070216, 18.832650453813617, 5.976266361051991, 1.82521722730129, 0.9970400830911053, 2.35842312535932, 5.077876890859296, 5.916506599995398, 12.635460515176097, 13.704427000015015, 14.955933728525716, 18.342801332473755, 11.653580454088027, 7.532794244827763, 15.582129340017996, 27.708419138385405, 34.549868183751265, 49.494608448397734, 56.46281673062233, 57.92574705616121, 55.939549015414336, 52.42700769055275, 51.86037425071963, 51.79068157749792, 53.75474176099224, 59.36009114788425, 57.36080808024253, 53.67168557259345, 53.797821152594786, 57.45061466770788, 58.063634057198804, 53.12060825286373, 51.36273530221755, 43.288614749908454, 42.9695495482414, 42.039830146297334, 39.49720467290571, 43.87061995844687, 48.45951457177439, 55.73502094514909, 56.11982114853398, 54.541184825281945, 56.31482570402084, 58.66915387492026, 56.581009511024725, 58.726514616320216, 55.6209348863171, 58.60827868984592, 46.36084648870653, 48.07803269355528, 58.77124532576531, 58.08949424374489, 56.837501141332815, 52.781848830561486, 53.814314719169374, 53.46710258914579, 57.41077515386767, 57.96820671327653, 55.710066826112815, 47.9887830826544, 40.26744442601358, 40.0967977892968, 40.023018006355535, 49.40271123763054, 54.43529259773993, 59.378494908732755, 55.67441640361663, 59.90735592380647, 62.15473674958753, 58.79417942416284, 55.21682877694407, 55.84446291769705, 51.868301360837876, 55.74214396938201, 56.956254820669855, 63.02670709548458, 56.66639950967605, 56.60381809357674, 46.59532969997775, 43.62928044411444, 22.975963815566033, 20.92968094733454, 7.28524757969764, 7.464789661668963, 13.287361379592651, 22.433405883850593, 26.557574156791937, 15.75410467963065, 21.016579097317113, 9.243035893286429, 11.806712727392874, 7.547871345473875, 4.906068251978967, 0.9335854493321912, 1.2534278318766625, 2.4654913285086235, 10.573822548312526, 24.760905042771373, 46.52695102076377, 49.26063906761908, 47.74705525367491, 46.924506771949034, 63.717758117183564, 64.09610994400518, 58.39073619534893, 33.63267683213757, 14.34806146929341, 1.814545806377165, 0.1730060802712556, 0.19093079101895133, 0.12512799818068743, 0.17480324593282517, 0.17948220453916058, 0.12445830709991917, 0.19357590876039, 0.1975346987526263, 0.20440281488962714, 0.24201587803902166, 0.1886926191828905, 0.1167558829089807, 0.11621438898146154, 0.1588183617399585, 0.09344570428854035, 0.1597331626521003, 0.21288492506550205, 0.18107753667619922, 0.22450022759937474, 0.11295382684517292, 0.13335914561344733, 0.12033066366829219, 0.06137485060119822, 0.14514056665282096, 0.14818683867492985, 0.20574702340508663, 0.16392614572278916, 0.18982460602156578], [0.07455347811863308, 0.031224033502381177, 0.02450211183919061, 0.0770598879805015, 0.06527613803383804, 0.04647778444773248, 0.05223774674138235, 0.019076562246247646, 0.06503488162472364, 0.01749768376260275, 0.030390150627241503, 0.06883453983332842, 0.08015376470622518, 0.009576100968725739, 0.052354647928187927, 0.04534244980482806, 0.028195647718084436, 0.04870080306465107, 0.01994258634025051, 0.011982058509132795, 0.05661888866715374, 0.02681910454656088, 0.026651302562846292, 0.0829393370077014, 0.03341226981231763, 0.00843326919787233, 0.04000655548166364, 0.022514906576684406, 0.0628673009604456, 0.06337851526275759, 0.2165006455634871, 4.878991150086926, 21.62675084606294, 38.047304461079264, 45.15455292117211, 40.91475317555089, 31.794012861867106, 27.297727369493057, 26.919697177025583, 29.095461407015403, 23.535678194415187, 10.384209290627512, 2.600184294485277, 2.5945206371045884, 0.45943104872299784, 0.7990191023676627, 1.132900015481057, 2.8842720052888318, 4.143142738649923, 5.59508454415106, 3.514158812261397, 6.372038904697665, 5.257214519285387, 5.15968527524702, 11.369986226481776, 18.266825022235995, 29.42617016453897, 40.31727813905285, 50.285715210822325, 52.12820153082571, 52.808481724031516, 48.873920825219926, 47.4170466392271, 47.34637729583248, 50.20203144319596, 52.82490861031317, 55.38718908063827, 52.813761234283454, 52.34473205381825, 53.96235281421293, 52.35818970587946, 51.250057374277425, 47.20411292968258, 43.882826374423125, 40.20256057862313, 38.19113777529809, 37.8214269299661, 40.214617944532826, 38.843510304727864, 42.15171183309248, 44.18257782536168, 48.692770081181685, 47.708498354881044, 50.911521527075, 48.883852266496234, 53.36573285441245, 50.87505132921281, 58.478460004252774, 41.40239008011357, 38.53471779054211, 52.8990061052384, 57.35830560807259, 56.41559139374764, 51.03972419615715, 54.438885488817775, 54.14779855358986, 59.17563384579074, 53.32447344256986, 52.30411983305409, 44.943282296580655, 38.58104882701751, 38.24075183560772, 37.79106778483237, 42.83720093388712, 50.201403863968395, 52.61780746521489, 54.279539200567434, 55.52260106609714, 55.25672712633687, 55.37821862005419, 53.89413887454618, 50.66838556720365, 47.75375073955905, 54.26237490869338, 55.776119539814616, 53.46246242523194, 49.45430609487718, 53.856189943129024, 47.09516125340616, 31.88233090985206, 14.80690033205094, 12.885610653508095, 6.3425642540377964, 13.53530812648035, 8.638701611949552, 2.7508824919500663, 7.117255406994974, 4.909516015360433, 4.068618931116597, 4.382613243595246, 5.4226502872282465, 3.0080115074111573, 4.438082912275869, 0.39357665986303364, 0.34531869775345253, 1.6522837261999808, 10.340459173725499, 16.35892435427635, 21.444276302091538, 24.981218691795107, 21.162610900017526, 26.4056941001646, 49.0156086029545, 49.16336820971582, 45.00559306913807, 20.777236069402388, 7.8794807772482605, 1.14716163085353, 0.004628713293406632, 0.03264579501363539, 0.031276194513925624, 0.018072491023509253, 0.015651577531600434, 0.06574888323103228, 0.0032307950717832654, 0.052366005181665384, 0.1149115492139132, 0.04615505841831046, 0.037198203555758924, 0.03454405746813263, 0.04567146541610841, 0.01638514981154473, 0.04576546823485725, 0.04850388782459402, 0.041546039809022224, 0.06508719010819351, 0.05524435456121161, 0.02675082504508957, 0.059518336108134645, 0.06243677869919808, 0.03819031423077949, 0.03856859695647032, 0.04914391598093414, 0.014193076358717537, 0.06417620048347501, 0.011577974899762101, 0.017660536818326484, 0.030594110045762315, 0.04131681481075864, 0.016300368776184418, 0.006986804223889786, 0.0694267564423142, 0.019427826966068918, 0.045107666838673816, 0.04334451548094231, 0.07258734410448421, 0.037569943890576406, 0.0617646859327872, 0.024326493843428554, 0.011771008946872767, 0.07886306743227667, 0.027760308679013003, 0.022677437875479944, 0.002667309393385245, 0.045724643409372344, 0.045583384457014264, 0.07039438677771438, 0.024534115162227425, 0.023942601438912175, 0.025270402266253388, 0.05536641151974759, 0.043683972870630604, 0.04416041827249912, 0.0030935355771948858, 0.05635577959999923, 0.05606192742444335, 0.34597973970155566, 6.693518325205773, 26.422107258150657, 45.26112371875394, 54.23846806249311, 46.51282656577326, 34.73801643617692, 27.980062884669152, 33.473067745085686, 33.545592369571814, 30.405074127258796, 14.839780580612922, 4.544083495293894, 2.47833929715618, 0.48082322663357185, 0.19535240536976248, 1.3167986249731434, 3.1953779824318427, 6.120852280047632, 7.940991876586792, 7.076919713327962, 6.404738724231721, 6.859200712173217, 7.199913965117547, 12.245023865853588, 22.847765068854056, 30.731870320535478, 44.35346372665898, 53.20584920144851, 55.41378667277675, 54.241739319216826, 50.46080197057417, 47.87324182448849, 50.53600949625815, 52.72045981499457, 55.33591585774576, 57.07742075766287, 54.093501183294485, 53.49551231630387, 54.340206500022646, 55.00925302505494, 53.77552640053534, 50.24807614664878, 44.03495157918623, 40.67794399876749, 39.53203924240605, 39.21022053687803, 41.648338379398474, 40.43908734475413, 45.255883432203724, 47.382384654014345, 50.130165776898785, 49.6768613784544, 52.98412153797766, 51.94912179823845, 55.49694092042985, 53.27581644058228, 59.33622744775588, 43.20138908201649, 42.041536377322295, 55.27525248066072, 57.54534382973948, 57.563218070614724, 55.09079125619704, 56.66267325801235, 54.58493101981379, 58.56807047320951, 56.53086200837166, 54.32448956274218, 47.11498491225704, 40.10713715707102, 40.927065495521795, 39.078785834773896, 44.53699142702165, 52.98199953571443, 53.77608337709981, 55.60234285170033, 54.86887531895792, 55.73520921891736, 56.5606249532392, 57.18305803114369, 52.55439058426888, 51.02790609482796, 55.64598706460769, 58.95665576381069, 57.449951787148755, 52.36492441546533, 54.52069436350177, 48.74703215014551, 36.49923909095026, 24.564268781292824, 18.01318299385809, 9.26749481308845, 12.083507526305414, 11.645643538044347, 10.39172161010004, 12.452482927230097, 9.789322037850658, 9.482042577958877, 6.91636533506455, 3.8925346636003066, 1.0959967634370251, 1.8085606372164142, 0.5449046735321322, 0.36756956829659404, 2.503684182320872, 8.89852725690411, 20.620959035811886, 27.065028836650235, 28.964214978679536, 25.958220304981356, 35.20811642369917, 55.11274868442167, 57.269671809288766, 49.666274901359316, 23.72132789704108, 9.557514863629496, 1.4688914701823266, 0.10713609386115305, 0.032708070301000154, 0.028628186705792626, 0.03029175429424692, 0.03576368476534563, 0.013660129099603624, 0.03049500125099815, 0.03301486553203675, 0.0174563322516699, 0.01105959671774819, 0.015065400568287701, 0.009612507382107359, 0.10308707403319498, 0.03076172050749583, 0.08186142831560105, 0.041197768577765075, 0.013659197345165717, 0.05769729148596526, 0.01095879008062184, 0.08275041206469459, 0.03594302211798007, 0.012174231664938553, 0.09737497691305415, 0.095250507846715, 0.02457158452260398, 0.04495281748653901, 0.03801024143373774, 0.07945616504237538, 0.13589002432361727, 0.22829835363213094, 0.1726365041348242, 0.1457042081822311, 0.179475371034876, 0.2105231372819793, 0.1357484053099348, 0.19218846224248412, 0.13542821120110252, 0.21572769349140508, 0.13748079057662718, 0.183225815755225, 0.12317212208384469, 0.16100083898392417, 0.24404017344838191, 0.11654853355139495, 0.13169668885248323, 0.15542123677028766, 0.13605084150068222, 0.17406797006485925, 0.1949071244246537, 0.12241898104548456, 0.1816535581864657, 0.09369513485580684, 0.16590970057633617, 0.1038892140551921, 0.22174778093974437, 0.08608084908055683, 0.1339267554783052, 0.14955657324002636, 0.5089754563185477, 7.814456705124148, 28.89894477782711, 51.74160880427207, 60.375867351408935, 54.29058851734285, 43.726421863802024, 38.97905565077259, 39.00678680789086, 40.20851473654471, 35.051786438111336, 17.61130479074294, 6.31329111514553, 3.9571331585607226, 1.1053253854474714, 2.392900023729571, 3.521766249210604, 6.730728870437992, 11.281898617744448, 14.968872647131644, 9.757407672943609, 13.207194997418313, 11.083456104801549, 10.09245849424793, 15.496086266732986, 21.967898991800126, 33.78712408004269, 44.08052952058854, 54.617827938449004, 57.58231609098373, 57.2373632461794, 52.126914993409194, 51.432796678235455, 51.76269546631844, 55.95300274510538, 57.66054776407058, 59.819365393730905, 54.34818852332331, 53.375374040296, 55.400199582499845, 56.84900545304822, 55.82543942236132, 52.990114919600956, 46.17418089220601, 42.90192788647067, 39.90684524659188, 42.76775536998626, 44.82328522589899, 42.07987754575668, 45.434963164790986, 48.13560132057437, 52.581729504369925, 52.0246744924976, 55.86760097934354, 54.74568543895599, 57.179586733541186, 55.311891340440326, 59.4119684157833, 45.545087629748934, 44.998301382987734, 55.284760305958415, 58.73005259421564, 59.57466833053097, 58.72211763935705, 58.396859015187914, 56.15254940525178, 62.306191229051166, 59.44512028847972, 56.72091261033089, 50.34985773025021, 42.40959590481174, 43.71020286313949, 41.67262961787563, 47.223214872421764, 54.272812335721916, 57.34680521872736, 57.53714215370917, 55.37440999861687, 56.466731256054295, 58.8795066648914, 60.096057230426425, 56.32949144609513, 54.22403374025899, 59.98274780088856, 61.637909566202474, 62.34868226512786, 57.84335767069171, 57.85781160477669, 47.81792071557815, 34.213599466508434, 18.45053707399676, 17.45218796114768, 10.236901737028553, 21.918977229825913, 18.398616660025812, 9.751557457831598, 17.343865825283913, 17.17833984282709, 16.27041312956041, 13.324641546895428, 11.978351723763252, 5.4206645873285115, 7.353585074024816, 1.0639291809451197, 0.5116547109378923, 3.18629254737208, 13.237851262092592, 22.6645335074394, 30.828421423512122, 36.530916152461884, 31.101553709276264, 40.36563704090734, 62.18874762135168, 64.6461360685287, 57.130223704922585, 29.37367512333778, 10.73757856122909, 1.7295578506685074, 0.2242228118402343, 0.214871758775365, 0.13928171006902573, 0.14221005051607086, 0.11067686797750574, 0.11974393224884426, 0.12788505668962194, 0.11863736420749657, 0.12991142819725698, 0.15887390311446883, 0.3189712180004966, 0.11409311450176662, 0.16588350036932578, 0.09519560998606105, 0.21258351543257314, 0.241065270177299, 0.11390313235742432, 0.1484773545375755, 0.18257310884373804, 0.16778822477546432, 0.26320038483508174, 0.1421027982066716, 0.20224931109095776, 0.1975956180643651, 0.17897018201408849, 0.07922712773565324, 0.07818778390966116, 0.1909918482265165], [0.05027732008226937, 0.029464561281906023, 0.02889412838304716, 0.0556135744667582, 0.05109502701088787, 0.019688863765388247, 0.06543985868413603, 0.07635249005210015, 0.012217632461068852, 0.02339734218924517, 0.021084164599737814, 0.0406985473819077, 0.03170990944659758, 0.05566210613676137, 0.02257805903472247, 0.039301417512638916, 0.02652875722325858, 0.0815936576034273, 0.05109659366069302, 0.09085489452005395, 0.04268670642387964, 0.06558042049648301, 0.015571776067747947, 0.03202482712485137, 0.05746052052164751, 0.013998516839027647, 0.037529571056966825, 0.023542178772209633, 0.061809865968121644, 0.03708058990718376, 0.04388543101207864, 4.206395370344962, 16.210945094785384, 38.686870451896425, 51.919574583730395, 56.19403631456437, 46.8354768137778, 36.474151611328125, 32.85170939660842, 29.08931701414047, 16.405599578734368, 13.297895885282948, 10.227137977077115, 3.549586149954027, 0.997169153584588, 0.16179821393903226, 1.4904603386117568, 4.105547065696409, 4.266623364340875, 6.359146073941262, 6.571541928475903, 3.3212762590377563, 5.195531816251817, 6.570575064228428, 9.565463546783695, 17.746332383924916, 24.191663226773663, 36.77479736266598, 49.05276913796702, 54.3687770443578, 51.19609732781687, 51.35489840661326, 46.81553548382175, 47.096424256601644, 50.79102239301128, 55.125394405857215, 53.206727812367106, 54.87866163253785, 52.5541473973182, 56.09251360739432, 52.46686681624382, 51.363708050020286, 49.40888112591159, 47.71054190974082, 43.53879136423911, 41.04639968564434, 38.81868562390728, 38.67480524124638, 37.81151902291083, 38.47114009241904, 38.85510090858706, 42.52955375179168, 44.09535215746972, 47.84258850159184, 47.96530769717309, 53.8380999718943, 51.55678672175254, 61.375675585962114, 42.73067328237718, 39.42535469608922, 58.503857351118526, 47.93681560024139, 58.28880556168095, 51.51731198833835, 56.13440059846448, 53.491660548794655, 54.54974735936811, 56.1334631519933, 53.00482773011731, 45.47693644800494, 38.81158613389538, 35.640004681002715, 38.529167636748284, 39.96792047254501, 48.228647785802046, 50.486724915043006, 55.801826753923976, 54.730286213659475, 55.28259907999347, 53.58306746329031, 56.213895274746804, 53.8262975600458, 53.54202770417737, 52.162839981817434, 52.30158598192277, 53.93876367999662, 60.230445477270315, 55.27438955922281, 44.267826618686804, 31.125625295023767, 24.926852680021717, 17.595185810519805, 8.426234664455537, 9.289474794941565, 10.834568969665035, 13.99919213787202, 13.694388674151513, 9.457869991179436, 8.435223756297942, 6.594475046280892, 1.7902572645295052, 0.7285296977046998, 0.5183938638337198, 0.9490104764699937, 0.32095471156700967, 3.086049023174471, 8.848602348758329, 19.03880826888546, 25.70510583539163, 37.81065610147292, 31.11312274009951, 32.538808199667166, 42.75159128250615, 49.350610394631666, 45.53302241909889, 20.335612489331155, 4.230034024484696, 0.785819468719344, 0.02922257325882393, 0.0428091349350589, 0.0735756664747192, 0.026378129015586553, 0.04679778320414405, 0.03811213878854629, 0.03359299761453464, 0.1028145382541322, 0.03455012488449293, 0.04571131730992948, 0.03689948289144424, 0.03523275519030229, 0.027945606195698344, 0.004606761043936375, 0.05399932378842946, 0.06897483351490191, 0.03735506388869497, 0.0202304266408206, 0.02818631293672708, 0.003043212458461283, 0.023864215322499795, 0.05181755134535413, 0.03399674127238893, 0.02466111721831464, 0.026813464224218365, 0.04643438173638237, 0.003069436366316833, 0.023429477662448923, 0.03363938423834982, 0.023850291674476, 0.09356964199293046, 0.016035212339052272, 0.052540121645095854, 0.043997367949134884, 0.01608246272700208, 0.010090802886313009, 0.012761348043568434, 0.01743027185570569, 0.045875229482208534, 0.04208356923153324, 0.01624118465359413, 0.059869660199770046, 0.0595544456624456, 0.07789240338869634, 0.05971785987757387, 0.04989131902074141, 0.034023401132153894, 0.010856618849380363, 0.04591277545137752, 0.01642626192000124, 0.022206766861340693, 0.02449065116384337, 0.032865838448126475, 0.03191180617338227, 0.015438034353146871, 0.01726026545398899, 0.08199236806361906, 0.051530816126614816, 0.11882107975261828, 4.949432015419006, 20.37374577214641, 44.488232443409586, 57.2199361555038, 57.6846311169286, 48.489422644338305, 37.07938901839718, 40.599865298117365, 35.24444541623516, 24.943887533680087, 17.448693129324145, 9.963480176464206, 4.3592241502577265, 0.9344444483999284, 0.4390321497715289, 0.9548903545064311, 2.8897461631605705, 4.668781036330808, 5.357747318283205, 7.255068863591841, 7.032782752667704, 7.055941897053873, 7.2146429554108655, 11.213397364462576, 20.20883167943647, 28.02485046848174, 41.09638637112033, 50.33150888258412, 56.839250518429665, 54.79610358515094, 53.79738969187583, 49.640069546238074, 49.523936010176136, 51.72854731159826, 55.52063595864081, 55.994654393965206, 54.937253998171904, 52.99219769816245, 57.47946370032526, 55.67667961120606, 52.84299465917772, 51.3127564614819, 48.64622331434681, 44.45983840573219, 41.98637216321884, 39.75393556779431, 40.3973650932312, 39.05449459629674, 41.13566106365573, 41.2640598512465, 44.72145265148532, 45.60217772760699, 49.122567715183386, 49.851618659111764, 55.62905811494397, 54.754283274373705, 60.56276436774962, 44.46233695553195, 41.52538384160688, 57.43075178515527, 51.18982545791134, 58.527124850980705, 52.31121147832563, 56.91074748193064, 54.62237788784889, 57.21676688040457, 57.053615893087084, 54.74794472417524, 47.592525635996175, 41.18608705459103, 38.67482485309724, 40.755826580908995, 41.23880370970696, 50.746358363859116, 51.96374439424085, 56.2364096795359, 55.74423851505403, 55.91528915589856, 55.80237980811827, 56.88307516036495, 54.813864077291186, 56.24381119205106, 54.81027510858352, 54.178757821359945, 56.634808740308216, 62.267257782720755, 56.6785196335085, 45.63578459524339, 35.45511984056042, 28.841180032299413, 19.09151904044613, 11.766269168546124, 11.400960203140013, 10.322460397597283, 10.657497490606001, 11.931888307294539, 10.585745573043823, 7.140521435968338, 8.176767018533523, 3.998536227210876, 1.3488619173726728, 0.8259587374425704, 0.36005856649529555, 0.621905948125547, 2.737827127979648, 10.707312572386957, 20.712956267018473, 29.344127908829723, 38.5619939527204, 31.697801043910367, 35.3315887143535, 50.46928997962706, 56.481887294400124, 51.94581916255336, 23.80049897778419, 6.820259911398734, 0.7799726243942016, 0.05086418173666443, 0.05485710860680669, 0.04872055664177864, 0.10455068501253283, 0.025312313021370964, 0.04873958243537815, 0.04337208315489754, 0.008184942754826719, 0.020734497173238668, 0.03140268329110357, 0.03217134144037001, 0.04542455144767319, 0.0172280706089711, 0.021674282127811063, 0.03118932397375184, 0.038298769298219876, 0.02069509727129292, 0.07837384368383116, 0.022289525424580903, 0.0443406404566861, 0.0229714643360386, 0.024065388096196037, 0.006257782506215717, 0.04859649636332066, 0.05845010693695757, 0.021240354605740117, 0.0459135415393018, 0.03933341700523611, 0.1779456160241558, 0.08679840533483414, 0.2589360943004008, 0.11061862997350194, 0.21396498646466963, 0.14556404473560472, 0.14162589315204852, 0.20988631903404192, 0.06134845121132751, 0.1678740572665007, 0.12487030918559722, 0.23416788948159065, 0.17879860896256664, 0.13810547399184397, 0.1429414653008984, 0.12728566183678566, 0.16520952685706078, 0.16795638107484387, 0.09957935661077501, 0.20823820343902036, 0.29989780437561775, 0.1266817240825584, 0.12472338884347871, 0.10484237298970261, 0.1353653919913115, 0.1476302451544231, 0.1402960104807731, 0.18784442195488563, 0.15506689046179095, 0.13873663851090018, 0.17351402720857054, 5.758805255736075, 23.40974069410755, 48.57875070264263, 64.38377657244283, 66.15119657208844, 58.6380494794538, 47.3920532964891, 44.395437009872936, 40.35277951148249, 27.925241877955777, 21.46302523151521, 14.334890150254774, 4.966190341980227, 1.4303660729239065, 0.9026661407082313, 3.545925843138849, 8.92577890426882, 12.984417119333822, 14.97886782692325, 14.988633548059772, 11.062101740990917, 11.946411863450082, 11.389058751444663, 13.783204863148352, 23.262606705388716, 28.336688703106297, 42.01198131807389, 53.90859673100134, 58.92311557646721, 56.72615681925128, 56.686568337102095, 51.61003289684173, 51.570734670085294, 55.144665010513805, 57.613667595771055, 58.98809748311197, 54.232200114957756, 53.406635330569365, 57.44591959061162, 55.71809199548537, 53.91191505616712, 53.7595937328954, 51.5021598723627, 47.901290693590724, 45.21012113940331, 42.00392476973995, 43.299542473208525, 41.02224180775304, 42.80500611951275, 42.96716866954681, 46.684857799160866, 48.96686530882313, 50.848653777953125, 53.10546005925825, 57.15440903940509, 57.18281092182283, 61.861947505704826, 47.763905755935184, 44.797554477568596, 58.44070326897406, 51.01130662425872, 56.55602401302707, 52.02958529995334, 57.557134474477465, 54.813934679954286, 59.8931844003739, 60.601858631257095, 57.983445121395974, 50.470090143142215, 44.267520673813365, 40.01543606481245, 42.974660396575935, 44.32823896408082, 54.64549633764452, 56.32611428537677, 59.52536805983513, 56.211090780073604, 56.277571032124186, 57.33510871087351, 59.40697131618377, 58.21622994638259, 58.528497680541015, 57.381137724845644, 59.360553987564586, 57.66333264689292, 62.080988345607636, 55.99418370954452, 49.66876952878891, 37.90896246510167, 29.757714386909242, 21.845572033236106, 13.407440820047933, 17.012413778612693, 18.616476866506762, 23.095299966873664, 22.78427170168969, 19.188601624581125, 16.626197599595596, 13.740432397011789, 8.074666252059322, 3.6262233795658236, 2.6046489323339155, 1.9288119265148718, 1.0493329383673207, 3.8361255872634152, 12.820083537409383, 26.85854938722426, 35.544734231887325, 50.32793952572731, 43.87064349266791, 45.698032609878055, 56.86216892734651, 65.05389782690233, 59.675810567794315, 28.19234940313524, 7.880693279927778, 1.3635108667996623, 0.12590971429862324, 0.0923170575932149, 0.19242555113329043, 0.16016371938730442, 0.22966578993345463, 0.16293671252506395, 0.1729049260217336, 0.18471627045542965, 0.13403521820662484, 0.15561441350127422, 0.17181174919730233, 0.08068786588527503, 0.12124898092400645, 0.07566379999080974, 0.08445901796221734, 0.13104687775335006, 0.10598980416093143, 0.18053580526142352, 0.13241172467748966, 0.13130455908756103, 0.11653531853470112, 0.144698687138096, 0.1158134492054101, 0.1647651958609781, 0.09161266272947674, 0.10936627540016368, 0.16285012926786177, 0.17680685696822984], [0.029562181950877273, 0.04101707141906504, 0.039310062814864426, 0.03592941256600522, 0.047780141579888524, 0.033037350212614384, 0.05815772181977669, 0.024630858660525373, 0.01330292432553946, 0.019188347880938844, 0.04513053073277397, 0.05529295900956758, 0.04275029172159491, 0.01820716161971852, 0.02225556857733717, 0.04006083664153853, 0.03196096028982392, 0.058458744578303835, 0.0432119669482833, 0.03692113636662403, 0.017858742916535948, 0.05723329884330592, 0.14852454555371117, 0.06859915931859324, 0.0360293640574861, 0.030446590239843054, 0.024413228402995778, 0.025136898038908843, 0.07874734219043486, 0.02621502698128743, 0.12521641238802864, 1.849425728282621, 10.351225099255963, 28.020751591651674, 47.82533399520382, 46.231349437467514, 43.51592002376434, 44.93719477807322, 26.281906058711392, 31.804081586099443, 21.89513510273349, 14.008005703649214, 8.509314387075364, 3.117979077562209, 1.8562531038638086, 0.15811486319909174, 1.2536354723476595, 1.968549949026877, 3.2372652186501414, 2.9126657978180917, 5.237666897235378, 4.8082139415125695, 5.847685673544484, 4.480853907523617, 8.728424849048737, 16.570703906397668, 24.294680356979374, 33.544274453193914, 44.10567583576326, 53.2948987714706, 52.573904375876154, 53.8797555431243, 49.46580648422242, 51.14735795605568, 51.63483404344129, 53.75675001452046, 53.322378896897845, 52.45512323994791, 54.78434824174451, 54.005126260942035, 54.29729969270768, 52.992919414274155, 50.822770057186005, 46.781791333229314, 46.98173807513329, 46.142884300601104, 43.4692398963436, 39.314261405698716, 41.35997749144032, 41.21387312489171, 40.68900900502359, 43.999316846170736, 44.00918160715411, 48.19347197009672, 48.780144799140196, 52.96630613265499, 52.60940967067596, 62.33822522624847, 44.59463850144417, 36.18600645372945, 45.8182454109192, 43.90148508933283, 56.80008957462927, 50.25842335916335, 50.6519155348501, 50.84634350192163, 55.00677016473586, 53.94576903312437, 52.76664572377359, 48.846036695664935, 40.61742182700865, 36.83240129101661, 36.60585695697416, 36.983891071811804, 46.26615655037665, 49.85357199945758, 52.3266734615449, 53.885160569221746, 54.48438890518681, 53.07190810480426, 56.196989859304125, 54.70073115441107, 53.971338964277706, 50.41085843117007, 57.21075388693041, 56.07803221671812, 54.419324628768436, 49.904033291724424, 43.63334009724279, 39.05360029589745, 37.22548554020543, 20.161780888034453, 10.874463396687663, 9.24485489245384, 8.826165410780138, 9.796502917043625, 9.854380430713777, 5.8203678361831175, 5.383417760172199, 4.784263458944136, 2.4383600488785775, 1.0882491017541578, 0.5614261257071649, 0.2572223249702685, 0.5785234308531207, 3.0864684716347726, 8.69739595920809, 20.37517939844439, 29.963925153978412, 30.65263059831435, 30.488901061396447, 38.3687936875128, 42.27094404159054, 49.39359957172025, 39.107187717191636, 12.286381336950488, 3.1075722940506476, 0.3358428642874764, 0.10896195717636617, 0.038282976395660834, 0.054579800099975644, 0.04048916023044337, 0.06270918424331373, 0.11097026433074668, 0.0440536754115695, 0.03202254035239739, 0.0348891111301078, 0.04107422923909561, 0.06091278466966845, 0.023840774947236625, 0.08238513368151842, 0.026398166045246106, 0.04111982296190916, 0.11463284642705995, 0.03339582573502295, 0.04594765160413039, 0.03879335949257497, 0.04805461939183935, 0.01812385721883226, 0.0941744530873914, 0.048042817807365815, 0.03214752376680413, 0.04322275346625717, 0.06029766586218631, 0.016963563431354783, 0.02564799551281237, 0.03582119881626099, 0.01961812895211962, 0.028076141832336306, 0.06086528721836306, 0.015866871220960973, 0.022127137767271172, 0.05585557015071954, 0.08748924044231254, 0.010217428601707422, 0.026085554291644407, 0.018490179396805265, 0.03866307858017184, 0.009196287024796251, 0.04927771706734935, 0.039106383018435976, 0.03850678515229975, 0.02848739506706836, 0.0350867503232533, 0.017574796257841013, 0.04160896627112262, 0.007125969362189814, 0.03164436487901596, 0.03555541993269036, 0.03588959514614075, 0.04545654710983077, 0.047403586382466945, 0.05342675733470148, 0.03635950581801515, 0.04603141565777121, 0.016120487501123743, 0.09268986662068675, 2.571786089289573, 13.489258520064817, 34.72633561780376, 55.56887718939013, 55.15591044579783, 49.000127007884366, 50.73024526719124, 33.05449201214698, 34.72949312579247, 27.0319789455783, 19.969319989604337, 11.820828357050496, 3.7171098445692374, 1.5496041649772276, 0.3262297785089862, 0.7135259576382176, 2.9870150598787495, 4.609204646079771, 7.110756529915718, 7.2323656947382045, 7.829010659648527, 8.101712465286255, 7.6708901120770365, 8.369392656510877, 16.4494889397775, 24.79743015381598, 36.334342648906095, 47.266357021947066, 55.792358152328006, 55.750392713854396, 55.130513098932084, 50.28704097194057, 52.863642015764796, 53.76916431611585, 56.68414823470577, 54.94903679816954, 54.49676398308047, 55.03528187351843, 54.85771617581768, 56.83625774998819, 55.027021361935525, 51.411988504471324, 49.487512880756015, 48.09575788436398, 47.21696261436709, 44.25323932401596, 40.506516810386415, 41.937989727143325, 42.91364400617538, 41.92572447561449, 44.74876411499516, 46.37431198550809, 49.20099158440867, 50.733645962130645, 55.68372418803554, 54.508966476686545, 62.120392476358724, 44.89784556050455, 37.2615909576416, 47.82624006271363, 47.150129349001, 55.686442390564956, 50.035001231778054, 50.77952592603622, 51.06249747737762, 55.645210435313565, 56.295453117739775, 53.99547330794796, 50.01389103551065, 42.24908075025005, 37.09687494462536, 39.44923016332811, 38.95893781415878, 48.11877435253513, 52.54788729452318, 53.68739858750374, 56.37230019415579, 56.13907998608005, 55.36506691286641, 58.824001204582956, 56.96044783438406, 55.10950488428916, 53.86115958613735, 58.96454365022721, 58.64490970488518, 57.659257304283884, 53.38372476639287, 46.361328940237726, 37.01285385316418, 27.28378922708573, 16.121220877093656, 9.24334870230767, 8.777427019611482, 11.026467988567969, 11.296259395537838, 11.553971863562062, 7.358694451470529, 6.280560897242639, 8.574224710464478, 5.6452653869505856, 1.743052520098225, 0.41597584502831586, 0.2942104289127935, 0.7647963613271714, 3.2367575168609624, 9.979716827792506, 22.15766718310695, 32.38538272919194, 38.33905035449613, 34.04863634417134, 43.72500981053999, 49.149173152062204, 56.270087149835405, 45.461384250271706, 16.450941197333798, 3.7776631501413163, 0.5432114353583706, 0.08890418185582084, 0.0716092030427629, 0.07140358504388603, 0.030890938472904028, 0.03419391698234024, 0.09519852112017332, 0.033259013923065316, 0.06878361030812226, 0.03506354552002684, 0.02996338794248239, 0.012865106034423075, 0.03134984620696595, 0.030323954884924238, 0.08858790245628165, 0.04400085747962998, 0.03383740647545746, 0.047592082316236156, 0.062470157150058984, 0.07803471188151068, 0.009518166527061934, 0.07490384843080275, 0.08225997789732872, 0.06449956236587417, 0.06420868644190413, 0.042824759298274596, 0.09959102412986179, 0.05166524540512793, 0.022654250309231783, 0.1254592545991463, 0.08007436735375274, 0.19165178700800867, 0.18309723555801377, 0.09891724980045712, 0.17679934930657187, 0.19746647096208989, 0.370650835215084, 0.05549833569074831, 0.16906941489827249, 0.18705533607111824, 0.10177034509157944, 0.12596385373223212, 0.14763537794351578, 0.12125784456129036, 0.11101074441666565, 0.09899223448648568, 0.20877749869419684, 0.11055928880288718, 0.13746122469104108, 0.09220365359778367, 0.0807015865199989, 0.2288676182469053, 0.14849836066845926, 0.12413965282781471, 0.12033972648843644, 0.08703573937377623, 0.10086259218834101, 0.18480619385598168, 0.14002420248523836, 0.3207568463779265, 2.856550899244124, 15.482223629951479, 39.85678011371244, 62.73863646291918, 60.529745855639064, 57.773994476564475, 56.985978541835664, 37.557835809646114, 42.53989704193608, 34.70836331767421, 22.220050519512547, 14.445939313980842, 4.934018081234348, 3.173186682885693, 0.5248252026015713, 2.976013792137946, 5.281038015119491, 9.824743001691758, 10.034968314632293, 13.244776206631816, 14.71082187468006, 11.460236041776596, 9.92585385999372, 11.429757264352615, 18.13454112698955, 25.95843799652592, 38.24560380751087, 46.15594187090474, 59.488011406313994, 55.22363801156321, 58.89002253932338, 51.94747048039591, 55.761128241016024, 56.70221467171946, 57.35322613869944, 56.15969988607592, 55.352111324187256, 54.688285473854314, 55.73430707377773, 57.99414926959623, 56.69578198463687, 54.19332550417993, 51.66429496580555, 50.02477169036866, 51.16215313634565, 47.028426047294374, 42.72694703071348, 44.80336743016397, 44.802814375969675, 44.3583627670042, 46.545264567098315, 48.0686503841031, 51.67690930827972, 53.1371057418085, 57.098397593344416, 58.59413854537472, 62.3864076214452, 47.265321516221576, 41.42262951020272, 52.04737717105497, 52.2616837101598, 55.624029636383064, 52.83780144106958, 51.11726553209367, 52.07928957477693, 57.26682809091384, 57.372524199947236, 55.78859267696258, 52.68196567412346, 43.563580743728146, 40.4979895776318, 41.458307389290106, 40.83166168582055, 50.39996600920155, 54.78315191884195, 56.05262310274186, 58.2235530114943, 56.53116795324511, 56.40085112664008, 60.892600397909845, 58.792104490341686, 57.75659484248008, 57.5810452430479, 60.89813093985281, 58.506199006111395, 58.455992667905754, 56.837434461039884, 49.15905752489644, 43.17306172463202, 42.88293969246649, 24.476945054146555, 15.395815776240442, 14.314517359579764, 20.23323078309336, 20.688070789460216, 14.815662907015893, 13.897596866853776, 15.082906734558845, 14.748326597675202, 7.480668887015312, 4.189693427854969, 0.7415652659631545, 0.7223436909337199, 1.18539321807123, 4.257749982418553, 11.961928759851764, 28.913045698596587, 41.14985612130935, 42.5888874453883, 42.81038761138917, 52.755819982098, 57.78038401757517, 66.75164868754726, 49.19342533234627, 18.910838980828565, 4.673246164475718, 0.7397499440177795, 0.17918327703110634, 0.15880991945103293, 0.2031043265014887, 0.09633952481371742, 0.16136817814361665, 0.15198127216389104, 0.17501326127638742, 0.16527767803880478, 0.09972413190670552, 0.11868644746080523, 0.13637374756076645, 0.19654722673998726, 0.18698304801458315, 0.24543413171364417, 0.11654743038478399, 0.16434502727802724, 0.1873340082144545, 0.20371160439906583, 0.1790328939715701, 0.13728873233401007, 0.1869422921370114, 0.21986138135675462, 0.17302275034448794, 0.1200704006177764, 0.15019804930254338, 0.11804678702666876, 0.20066182369426375, 0.16414207526512686], [0.06619911310413192, 0.06757487678119252, 0.03583630223968818, 0.041610352890265566, 0.08914431211568656, 0.021399201021619865, 0.09705358004618077, 0.025336134525376464, 0.08357916598118122, 0.043592984607863816, 0.06583751960387153, 0.022242882161311085, 0.05629315574262893, 0.04397280717028245, 0.021915471504232096, 0.011812144037967008, 0.037841085389616995, 0.029159361428971735, 0.03467811519400247, 0.04350660053352195, 0.04151633858019787, 0.03608864777150654, 0.06013109919524962, 0.03896575991905505, 0.07370295964421765, 0.027098713232384577, 0.0560935974992331, 0.055737642406095425, 0.03950448443872794, 0.10169540637082632, 0.06992531880255669, 0.3498331619606864, 6.7073392868042, 26.174287988293557, 46.65850731634325, 50.70340056573191, 49.206129889334406, 34.23939689513176, 26.947361653850926, 30.73361381407707, 29.758453753686723, 25.425550668470322, 17.5590568588626, 7.253456279154747, 1.8398366363779193, 0.7349734777404416, 0.19469641960195957, 3.2623730455675437, 2.758808376327638, 5.417023156919788, 4.183954509996599, 5.070110107621839, 5.163986644437236, 7.629927819774998, 7.302422658089669, 14.106828839548173, 19.07688271614813, 29.11094888564079, 41.71694847845262, 48.204815464635054, 54.01242579183271, 51.80983843341951, 51.974444620070926, 52.28958745156565, 52.74707701898391, 57.51015232455347, 54.90887957234537, 51.967709910485056, 54.205888855841856, 55.033312843691924, 50.99430314956173, 55.487570378088186, 52.70011448091077, 52.57401812461115, 49.48435929513747, 49.74077640041229, 50.34817895581646, 46.403851355275805, 43.926254856971006, 44.47644964341195, 41.47529517450641, 46.99852581947081, 45.18352354726484, 45.3824818518854, 48.71460591593097, 54.43878350719329, 49.609722168214866, 56.83768157036074, 46.43656000014275, 32.60484130151811, 42.51201683475126, 45.83050281770768, 55.1293206983997, 49.73046841159944, 52.12543233748406, 52.11131964960406, 55.7099413102673, 55.24605827946817, 52.71690614761845, 46.249247212563795, 41.54543107555759, 36.956308964760076, 36.166575031895796, 35.36348935096495, 40.372536490040446, 48.36021192612187, 50.587098367752574, 53.143903209317116, 56.14294744306996, 51.97374643818025, 53.67348201813237, 56.35942697525025, 56.74964004947294, 58.263376835853826, 57.470865864907545, 55.841568208509884, 56.5679637078316, 52.595901027802505, 43.7932002159857, 37.166077321575536, 24.334449268156483, 13.747209272077008, 7.850421407530385, 10.491081130120063, 8.475047580657467, 6.617885222358089, 11.465016430424107, 6.790387140166375, 3.62001818995322, 6.049083202115952, 4.469599646906699, 0.2846217047302954, 0.8229160813554641, 0.15575699778574129, 0.7424267777992833, 3.7784949377659833, 12.070061641354716, 25.718024161554155, 36.61153654898367, 31.281206107908684, 30.339231260361213, 43.388846997291814, 48.05854243616904, 47.74394873649844, 35.47902668676069, 13.444554286618388, 3.301863958758693, 0.17250657562286625, 0.06372412433847785, 0.04404643971112467, 0.04970753835814615, 0.028957125708280556, 0.07882228091118798, 0.03866411279886961, 0.04518071715269358, 0.004493955075891028, 0.08516034847425838, 0.0875876674188241, 0.027265661028063586, 0.04745512494757291, 0.011667473121516166, 0.0478277616052618, 0.07258697638228055, 0.06953055369517497, 0.05493447199584015, 0.028354766095177304, 0.0241264108298046, 0.0259650505763749, 0.025552267081014095, 0.019677738253507885, 0.02245870062089976, 0.030523827224369013, 0.055463570620744466, 0.05441913231005592, 0.04645283296403866, 0.029233244863609155, 0.030311500210495248, 0.04424021016025255, 0.015435715021956113, 0.05707608227948508, 0.0498496514985398, 0.017625691309090585, 0.05581148562111682, 0.02419784086786451, 0.01115487986094048, 0.09142093390466706, 0.018323149246674393, 0.033297295336641615, 0.03184685149350234, 0.017332720134647626, 0.029679889445223158, 0.048691521909448414, 0.07662579191908722, 0.02381661444932463, 0.06554516513020762, 0.10502473255919834, 0.047656694171769966, 0.02924150712187252, 0.07887281973155276, 0.06421889839393478, 0.0686578186709554, 0.023829028904137593, 0.07113435110377689, 0.04511261576666467, 0.02614701561058962, 0.06983515791474812, 0.17040184098145655, 0.682340172990676, 8.184983893748253, 30.877145105792632, 50.85605136809811, 54.86409787208804, 56.55760865057669, 43.84317121198101, 30.110192298889164, 40.00819144710418, 28.571501393471998, 26.319984428344238, 17.88646101951599, 8.04034011979257, 2.3034908213923058, 0.3460253066112918, 0.11362344131714876, 1.9307254302886225, 3.1700968357824513, 6.927624988940455, 8.2003429147505, 6.983527589228846, 6.47742122411728, 7.049549904561813, 8.725005522851022, 13.973556507018305, 21.711101416618597, 29.045884609222416, 43.27095231702251, 51.36695969489313, 57.23556287827031, 54.71457712111935, 53.78588538016043, 53.36585837025797, 54.628759584119244, 56.76894595546108, 57.10138251704555, 53.33386751913255, 54.63126205628919, 54.5366858666943, 52.082788328970636, 55.79995970572195, 54.378484910534276, 52.14267899913173, 50.40108780707083, 51.15881912169918, 49.376478425918094, 46.201806145329634, 44.375919295895486, 45.30064159824003, 42.20187502522623, 49.05558147738057, 46.7456074683897, 48.534529901319935, 51.55031481096822, 54.473418035814845, 52.246770858764656, 58.886492406168294, 48.293331592313706, 35.74372391546927, 46.1733179707681, 47.52412734493133, 56.30528649976177, 50.513346041402514, 52.35053716167327, 54.082663674508375, 57.679645784439586, 55.89129993992468, 54.41577880613266, 47.018796628521336, 42.79663578156502, 38.10598311885711, 38.61935861649052, 37.309683138324374, 43.115810809596894, 50.70564416147048, 52.74916764228575, 56.617299279859, 55.58783008206276, 51.84268828361265, 55.05192056778939, 57.780462464978626, 58.81456790431854, 57.98555535654868, 60.45220451970255, 58.17727688820132, 59.61295458578295, 55.42511840020457, 45.499482231755415, 35.85712748189127, 21.328660518892352, 14.78425648904616, 11.14429206617417, 8.308867542974411, 8.767804464986249, 7.3141794723849145, 10.65363395598627, 7.730925419638234, 6.20505380053674, 5.8019596626681675, 3.97873463169221, 1.1050630769421979, 0.5625391595305935, 0.16445678418442128, 0.8927328608209087, 3.5778166738248642, 12.861781274118732, 25.433795490572532, 41.011714166210545, 35.45814791033345, 36.33757075955791, 49.59728433239845, 54.73041565187516, 53.45623762376847, 42.18118844493743, 15.194487379443261, 4.448999849057967, 0.27158754607362134, 0.014791732894316798, 0.10309667311488621, 0.0462742425471304, 0.009429694863126404, 0.0255424247664069, 0.016085013799789934, 0.01798507273046961, 0.036934320739800894, 0.08290100962884965, 0.03723497577612439, 0.03817103562816497, 0.036718509941091465, 0.019292307927483515, 0.07211960912231477, 0.014033890948931297, 0.017965451303508975, 0.06298500653957168, 0.044437113908990744, 0.03551722661922536, 0.018193134549824942, 0.06614263710235396, 0.048259536420265516, 0.025316258374181007, 0.054139717061433106, 0.01811061538906107, 0.03603689087134215, 0.036590056148387735, 0.017023331695987333, 0.10326620071165024, 0.11630078071668265, 0.13426262374606826, 0.12371510222193696, 0.18599796619626785, 0.09414753275773219, 0.19997755396029643, 0.1628460536801046, 0.1961659141365559, 0.23636234834069209, 0.18889229233947494, 0.1293589255862659, 0.11053969993466332, 0.15700150761873494, 0.08880906437914218, 0.11850113845280102, 0.10473145111914604, 0.11459311710730677, 0.137435729284921, 0.17520456875283874, 0.1848246872184738, 0.09149673064389537, 0.15964759063095818, 0.1058192576672281, 0.20968168162770812, 0.10600065196593923, 0.3087871515702817, 0.1350293858277221, 0.16859281627881914, 0.29709453544309067, 0.2415974101712627, 1.116071086256735, 9.57351323096983, 34.89043189633277, 57.35666213497039, 63.95783070595034, 63.920834910485056, 49.373822981311434, 38.236856922026604, 44.042498219397764, 41.668362079128144, 34.79775021153112, 23.493606851946925, 10.532894576749495, 2.912112988771931, 1.776905884185145, 0.683391061761687, 6.09760586292513, 9.703520190331245, 11.599274258459769, 13.405201146679541, 11.4349308706099, 12.117729225466329, 12.998969112673114, 11.057939125645547, 18.99678203367418, 22.117919844965783, 32.126429811600715, 43.52723606171147, 52.528385270026426, 59.19759127401537, 56.45501513634959, 55.81836346657046, 55.241100403570364, 55.6324548875132, 58.300070608815844, 58.34888842798049, 58.91156811867991, 55.26612512526974, 56.01078318011377, 52.3615276428961, 56.1459598233623, 56.131435286614206, 55.96510325708697, 53.074767512659875, 53.88177164139287, 52.81771498341715, 50.59987744977398, 48.48010309280888, 47.497416004057854, 45.46326698795442, 48.58812124498429, 48.65933579783286, 49.971635341644294, 54.93426907447077, 57.17113010344967, 54.87162490044871, 59.77954156937138, 49.5812104594323, 39.763600287898896, 48.09030971219463, 52.38465393743208, 56.51646690983927, 52.6685433233938, 53.44675725506198, 53.90693756841845, 56.8474639615705, 57.25301350316694, 55.7959000525936, 49.30815465988652, 44.42919684994606, 40.647376968014626, 41.251143486269065, 40.28446359019126, 44.831498669039824, 54.4239765597928, 55.49401875465147, 57.59242796128797, 58.088344989284394, 52.48689836071384, 55.95557974230859, 59.831524741265085, 60.20141601562501, 60.85891900524017, 61.32180183164535, 59.79978099946053, 61.282805627392186, 57.7110404352988, 49.90903039132395, 41.71999616007651, 28.09152683904094, 18.383091918883785, 12.818230217502965, 17.040119440324847, 17.899481327302997, 14.197372832605916, 22.062343781994237, 18.892676445745654, 13.592900287720466, 13.20363348530185, 10.809010805622226, 3.410429281573142, 3.0890525781339218, 0.9129726586322632, 1.5545837364850508, 5.41681036833794, 16.84470303596989, 35.555128512843964, 47.645438409620716, 42.80316652790193, 43.6960195725964, 57.20783956589238, 63.29755460062335, 62.37609178789201, 47.85024104579803, 19.793874332981726, 5.212245035556055, 0.2528483612883476, 0.1353693296832423, 0.17518780674905549, 0.14228411589659032, 0.11089203143191916, 0.12161961426177334, 0.0808472887823178, 0.12991904311122435, 0.12842822068881604, 0.14829956085210846, 0.17963349158244749, 0.11224222309406727, 0.1400300247534629, 0.10386499035502635, 0.12231936663269036, 0.10673698503524066, 0.1412146418325363, 0.13064803705821115, 0.1280911343412534, 0.10350155824374768, 0.10874292497793514, 0.09831259958446027, 0.11603083431480393, 0.09002307625187021, 0.1117855963867999, 0.1202703878704098, 0.16055558868233236, 0.13910301239980807, 0.11087349210415157], [0.03862041514366865, 0.09102307380207124, 0.01323277939997253, 0.020276707927546194, 0.044763930847928415, 0.058283816061673634, 0.08130872652174966, 0.07220662904963379, 0.03146054016636505, 0.059440800349318215, 0.020608217155020085, 0.02532856174624495, 0.011067436670043297, 0.07173534708037492, 0.04836597284602542, 0.03589891843617924, 0.08554495525576415, 0.053026974351415714, 0.02782384992667264, 0.018714426738780834, 0.044109090381572326, 0.00949554203543812, 0.07187011726801434, 0.01961408400787942, 0.047573669392976074, 0.05093548920065646, 0.033389620422836275, 0.051907838637670206, 0.01106353728250871, 0.0364844202845087, 0.04324695035334557, 0.18937808401401968, 3.596271915781883, 17.544322475310295, 39.06217459709414, 48.67746891513948, 39.8727676945348, 35.69141518685126, 26.519213376506684, 27.028699844114243, 22.490860762134677, 18.9595018663714, 16.36200341486162, 7.788461196807123, 2.6084864812512554, 0.6673904880881311, 0.1763536393522255, 1.111118971340118, 1.9693040246925049, 7.319851219654084, 6.279907332312677, 6.199221236090507, 5.705977303366508, 5.050581607126421, 5.582060313993885, 9.349539029982783, 18.861013112529633, 24.847693366389123, 35.73671071760116, 47.42800181911838, 54.244716398177616, 53.15734124952748, 53.65959682772237, 52.83879772309334, 54.18595144825598, 55.87723039811658, 51.88093139279274, 51.815133633152136, 50.51728802342569, 51.57694770443825, 53.22483347308252, 50.45666387004238, 52.84857619193293, 54.232968899511526, 56.414332312922326, 52.58476934125347, 50.96019814091345, 49.062222050082305, 50.09065966452322, 48.183332643201275, 49.953878771874216, 49.41505493656282, 46.00954724896339, 46.9055970253483, 46.022616586377545, 50.76141634295064, 49.95246279624201, 56.11247454920123, 48.953560629198634, 34.82826232910156, 55.596682871541674, 46.098310485962905, 53.07090397804014, 52.46223841944049, 56.922844071542066, 51.92498353219802, 55.54878288699735, 55.66453987552274, 52.927223636258034, 48.675460661611254, 40.41077175448018, 37.41677953350929, 36.48838981505364, 36.18298230632659, 40.891069904450454, 46.98932001667638, 49.346762549492624, 52.062129205273045, 53.60109467660227, 51.4987160313514, 53.924796119813, 55.07171677004907, 56.950512470737586, 57.1269210692375, 56.268373074070105, 56.666156322725364, 56.05407437970562, 48.97362355263003, 42.26671964891496, 32.689468399170906, 19.823549024520382, 12.277263787484939, 9.628062613548773, 4.186306461211174, 6.15790298869533, 7.238331619770297, 9.49106599054029, 2.9178764214438777, 2.705369269655597, 4.583416533085608, 3.356971298494647, 1.0568359422106897, 0.3606595471501351, 0.1814041965671124, 0.9061520859118432, 4.552012566597232, 16.861839871252737, 23.443092607682754, 26.883085773837184, 32.53695487976074, 33.32467663672663, 34.48985592011483, 48.16651744227256, 41.95777808466266, 35.66589624651017, 11.518488141798205, 1.7467085368210271, 0.19309097510432044, 0.05133607657626272, 0.03338721490675404, 0.013057170980309528, 0.03901821395923053, 0.06763338291596982, 0.13068298598931682, 0.018470592443801222, 0.033770021381637746, 0.06899725690844559, 0.032124479842041774, 0.03237510933690975, 0.021663685216598456, 0.054507944883117755, 0.03125655010432726, 0.03678054008032045, 0.053224287957193396, 0.042570192111475814, 0.024666041248447956, 0.006664769110014483, 0.0933377012129753, 0.0632354636646567, 0.07419962976728717, 0.03542801185000328, 0.037178296761046496, 0.07962714054531629, 0.03245845204219222, 0.009593329328532902, 0.035400448006487666, 0.04799566892606597, 0.03180746116765565, 0.02472576163258524, 0.05247206239390278, 0.07712941045962995, 0.030003804826147618, 0.022143453524838534, 0.029921113295600783, 0.03572081448510289, 0.04721636215465204, 0.03279132490617133, 0.0469882364925598, 0.07678079448880688, 0.0678736510716619, 0.08522961814437183, 0.024224814823678425, 0.0510784067333706, 0.011413683513960531, 0.0936312890881973, 0.034312809997748946, 0.052558538398795554, 0.04910284217687384, 0.013289919025414895, 0.02566924870705172, 0.07606208144176392, 0.05599690571187004, 0.036666461927515846, 0.03464823393451591, 0.047150727571739305, 0.11888045922762926, 0.03709244894825163, 0.2957403984281325, 4.51111352251422, 22.438610869069255, 47.702363767931544, 57.30192938158589, 49.04689734981906, 42.95481320350401, 29.913989459314656, 33.54437251244822, 30.177541355932917, 21.90201101764556, 22.449303250158987, 9.091863824475197, 3.0584485300125617, 0.6023161605961862, 0.6690464637452557, 1.36173538142635, 4.814002379294365, 6.395372594556501, 7.725745929825691, 5.391092367710606, 6.728887807938361, 6.8843965472713595, 6.926772854020519, 11.615948254062284, 18.567519803201, 27.950807886738932, 38.173189009389574, 48.761160527506185, 55.11885973715014, 55.48932759992538, 54.02673067585115, 55.58249565862841, 54.76609353096255, 58.349096313599624, 53.08842520559988, 52.78586925998811, 52.12120010006813, 51.63411624969975, 53.46163088275541, 51.62416911894276, 53.64865733731178, 56.48926919506442, 56.4915402473942, 55.052959995885054, 53.06154912517917, 51.38856018743208, 50.712700505410474, 50.50064540678456, 50.344907699092744, 50.65706560688634, 47.87035103767149, 49.46888946717786, 47.04363699882261, 53.293980936850275, 52.71965572910925, 58.095754346539906, 49.73023699175928, 36.66744601341986, 56.78864802083662, 49.40014600753785, 53.49172722908759, 52.59006846335627, 57.72290952744023, 50.95378506568171, 57.28995438544982, 57.430516442944935, 55.198829020223315, 48.69861049036826, 41.14650249481201, 40.208663786611254, 38.06111120408581, 38.87450879619968, 42.232402832277366, 48.990591725995465, 51.621235186053866, 55.21878996203023, 55.00752325980894, 52.933299387654955, 55.093568294279045, 56.07912263562603, 58.544779439126295, 59.13911265711631, 58.992694500953924, 58.697347871718875, 57.62600344996299, 51.84608113381171, 44.441191457933, 33.84137045952582, 20.618152579953595, 13.790954486016306, 9.153778437645204, 7.681435404285309, 9.819901816306576, 9.299582742875623, 8.41321925963125, 4.654248164546106, 6.395372594556501, 3.0138099962665192, 4.599819394849963, 1.404694160146098, 0.31612422076925156, 0.36129806611326437, 0.8381755109275542, 4.569527910601709, 17.121024208684123, 29.1714612514742, 33.74343279869326, 35.471958575710175, 40.39411737072853, 43.79163126791678, 56.55953061196112, 50.76068285972842, 40.541421982549856, 14.776733383055657, 2.091636008793308, 0.1599911657432395, 0.06458507309998236, 0.01948343345805282, 0.021257988034537243, 0.08384330543659388, 0.019731555930188587, 0.048808951696921746, 0.03555413673541719, 0.02745083214024142, 0.029080864229810335, 0.05182782075397911, 0.06735343140580001, 0.02171649357243892, 0.029756007941379666, 0.11490995575103069, 0.07065859518104023, 0.03424940090025625, 0.012972057654312062, 0.042118161931754126, 0.07360094737622046, 0.03599199045810007, 0.05802654075406252, 0.09381318900493846, 0.04706916219044117, 0.06345466057199144, 0.05915396553914874, 0.019241788259316838, 0.059324228580320076, 0.04543957060142871, 0.15074917295527074, 0.14521504572081953, 0.2890194784249029, 0.1265535269293093, 0.20952650285776586, 0.18880782348494377, 0.17353664212409528, 0.1344552948590248, 0.18024179603784315, 0.21521412346872593, 0.13128033538739528, 0.1823700036132528, 0.17158578390315657, 0.23156456949730075, 0.2414423846189053, 0.09337983604881073, 0.1820464540393122, 0.2002374722712463, 0.19246252253651622, 0.14736473440162598, 0.11246484824486318, 0.1420592537690555, 0.1828781956987035, 0.09760185385182982, 0.21212960833743696, 0.22833399204236848, 0.09153945536743249, 0.15569653812675707, 0.1370919703115379, 0.1837073939461862, 0.16336311706371848, 0.34071175141199944, 5.182973367552604, 26.210020780563358, 53.26105656162385, 63.733639794011275, 54.343489523856874, 50.32648432639338, 38.67191837679955, 39.41597630900722, 35.42556085894185, 28.508792500342096, 24.33194091243129, 10.909088119383782, 4.2003544299833235, 0.9884756491068871, 1.1066591138801267, 3.662005201462777, 5.600907792968135, 15.738340673908112, 15.024748771421372, 12.865682071255101, 13.331941077786109, 11.589448721178117, 8.861956058009978, 10.28408588901643, 20.88348719381517, 29.187464521777247, 40.46714798096688, 52.33379648577783, 56.811044754520545, 56.520177472022276, 56.63499309170631, 56.56650850849768, 57.23836345057334, 59.25716815456268, 53.04035655913815, 52.2687243646191, 56.44680169320876, 52.11131964960406, 53.45867341564548, 52.476154988811864, 53.60716258325885, 57.87129671342912, 60.37483184568344, 56.42991981198711, 53.333557651888945, 52.475099871235514, 54.890636628673924, 53.78370061997445, 54.05668189448696, 53.28514775922222, 50.0527617239183, 51.13312367470034, 49.23100948333741, 54.96759353145477, 56.36932703756518, 59.33874560940651, 53.42024987743747, 41.18938576790595, 58.507909159506525, 49.35851397052888, 53.320707967204434, 52.57789734871157, 56.788777459052305, 51.8585228919983, 58.715033838825846, 60.61090361687445, 57.996953764269435, 52.67184595907889, 44.0045218313894, 43.855177587078465, 40.357274547699966, 40.81094764894055, 44.8715696027202, 51.90022160930019, 54.30271648591565, 57.3969134976787, 56.114055264380674, 52.885285654375636, 54.944761414681714, 56.72161079222157, 60.66153749342888, 60.35873051612609, 59.51842154225996, 58.166910063835886, 60.10822050033077, 53.80337522875879, 47.304529528464045, 36.749203897291615, 23.681125563959924, 16.015934655743262, 14.596446541047866, 9.064420961564588, 15.471249818801882, 19.986958888269243, 18.437489309618552, 11.854155755812123, 9.620318874236077, 9.608722386821624, 10.377961935535556, 4.593273449328638, 0.9785727063013662, 0.7019184385576557, 1.6705213991865036, 6.66059640146071, 21.37627809278427, 32.63372171309687, 38.41838029123122, 43.72922635847523, 47.52091100139003, 48.203195525753884, 63.21313342740459, 57.63168696434268, 47.820176078427224, 16.391577105368338, 3.3354134617313265, 0.3322972867998385, 0.24243382496699212, 0.16716914912385328, 0.1658288323350491, 0.1648444093523487, 0.17498827148829738, 0.2002540963792032, 0.10979235818189, 0.1439352805215505, 0.14872740563606063, 0.25297490369168024, 0.14347236423242476, 0.07826025582729809, 0.174536187682421, 0.23831624026981094, 0.21674338818317462, 0.10354997500056222, 0.2393442689771614, 0.14152024962729023, 0.12691476802912452, 0.1965552859849507, 0.15364593525807704, 0.15705609904421916, 0.1542654399189257, 0.23020442635301622, 0.12903891533853548, 0.06933438922128371, 0.15449407119904796, 0.2332760405636603], [0.05763837932458809, 0.07137429750254078, 0.04479296174981902, 0.03605777442815804, 0.005216682423657228, 0.010840483122475205, 0.06342101399035704, 0.042487251602353594, 0.017284199955963322, 0.02620284235285175, 0.06236619901873412, 0.04927985828309771, 0.03260294388559076, 0.05321136405391078, 0.03720163946009932, 0.05322002467789477, 0.033874910309790604, 0.028544878474466746, 0.001347020058141601, 0.05468396507504006, 0.03939297268046968, 0.05750637854479494, 0.056751486995527824, 0.021012031676007376, 0.05131687841288025, 0.04413766546114799, 0.05015157441037798, 0.05404526225080895, 0.04023841965282637, 0.05072142508241439, 0.0703207427455533, 0.014994547969000715, 1.679887283713587, 12.677645606379356, 26.71373744164744, 42.49449168482135, 42.00982793684929, 36.9070989085782, 34.00920083445887, 25.927298299727905, 21.094718594704908, 25.04130155809464, 22.865531444549564, 12.64686578704465, 3.8898017521827457, 0.7405796478832922, 0.19907560800352406, 1.2048268462381055, 4.185408238441714, 3.6653561313306136, 5.1498729759647, 3.424991325986001, 4.188960925225289, 3.877952026744043, 6.283389906729422, 8.010047164655502, 15.308414582283268, 20.939155432485766, 29.984592122416345, 41.7063973026891, 48.61169468971991, 52.371341413067235, 54.3810030721849, 55.42638532577023, 56.06752418702649, 56.745843195146136, 55.60335090083461, 50.228519208969615, 49.267958210360625, 55.705697305740856, 50.090243893284956, 52.161788786611254, 50.94584618845294, 55.045130945021114, 52.81536156131376, 55.781881501597745, 49.46017396065497, 52.695544919660016, 50.86917954106485, 51.0425796816426, 51.98751395748508, 52.327391255286436, 50.45979392143988, 53.13232045019827, 45.48123144334363, 49.02102931853264, 48.306879458888886, 55.829267655649495, 50.15055033468431, 34.17473662284113, 50.242780946916156, 52.47233067789386, 54.37806521692584, 52.41553083542855, 54.0638872884935, 54.691348844958895, 56.83905047755088, 54.05498350820234, 51.15386124580137, 46.48789990332819, 37.50868458901682, 39.41607044589135, 37.01654872586651, 39.03723616753855, 39.707781037976666, 46.455089276836766, 51.482426428025775, 52.02291334829023, 53.67725533823813, 53.999046587174945, 52.63036689450664, 55.47648968235139, 56.57947586428735, 56.89961971775178, 56.40332614221881, 58.30127477645875, 55.686767947289255, 47.53854205531459, 39.41748249915339, 30.651498994519635, 18.743559698904715, 14.900615561393002, 10.366968512535095, 7.008953373278342, 6.51635172867006, 4.306682530910739, 5.982952041010703, 4.529816364088367, 6.827148083717593, 3.545323023872991, 2.2965631802235884, 0.5235928429230567, 0.3128363246158246, 0.17631006427109244, 1.1662616124076228, 5.959082947623346, 11.559258237961801, 22.5301746783718, 40.617731694252264, 29.31847953027295, 32.383107754491995, 39.2060745916059, 50.79887497809626, 43.404426651616255, 29.676695869814967, 12.123390186217524, 1.502480687152955, 0.03463861570062657, 0.05265051874542429, 0.0073415062844663145, 0.01719748263337439, 0.02483592890653639, 0.03328537883897943, 0.10599825411073624, 0.049584451011352004, 0.021240655295250398, 0.06002436016475963, 0.0692506098458844, 0.05554754151812485, 0.089147828459259, 0.03294558437060445, 0.032012631005096825, 0.017830388087238518, 0.030254987819540887, 0.025912165611742005, 0.0404975603845331, 0.03461144639239196, 0.003739309632369588, 0.04115756045305922, 0.02408377420637877, 0.06845944786384221, 0.0028529293852062117, 0.05389328572839018, 0.0988704801326798, 0.06255927998873015, 0.020832851371397416, 0.03298908667338472, 0.057416819036006934, 0.020374606303389997, 0.009732220111595047, 0.03213003206427299, 0.04430073110627071, 0.04446134143959611, 0.019924625408865755, 0.031388767303959016, 0.052337977854955586, 0.1026328451811306, 0.03166349217926543, 0.0566721968953648, 0.02779948641546071, 0.018319267096118103, 0.01606288822292681, 0.05751183309081582, 0.018892164882873336, 0.03142322976923278, 0.1257703782269551, 0.010867079779986414, 0.06793271645062393, 0.04182488815258107, 0.022159217699100415, 0.0316443380659386, 0.05949659070240394, 0.0006408817458695041, 0.0722493154687747, 0.06416264838809449, 0.035800253972411156, 0.08383212821377863, 0.056705893272714275, 2.0669567008172316, 15.743017119746055, 33.56070133947557, 51.526431498988984, 46.80458422630064, 41.853419503858014, 35.886356984415364, 28.164118143819994, 27.252392615041426, 24.634208563835394, 27.371962147374308, 13.519961853181163, 4.289777115468056, 0.7065341489449625, 0.21668757101701153, 1.279757722250877, 3.1346650854233773, 4.828377865975903, 6.867206759991185, 7.6491175255467825, 7.69924835812661, 7.742553776310337, 6.643993989113839, 10.407108087693492, 16.83010397418853, 23.682774920617383, 32.76391302385638, 44.931119026676306, 51.92583860889558, 54.57993392021426, 57.74631431025844, 56.87286523080642, 57.244552950705256, 55.291232216742735, 53.187727851252404, 52.958618287117254, 51.2178704046434, 55.790381277761156, 50.68706781633439, 51.2542543103618, 51.17374374020485, 54.30504245142783, 54.52855479332709, 57.766243873103974, 52.11029198861892, 53.184107503583355, 53.31513820155975, 52.86244177049207, 53.1414831069208, 54.689246454546534, 53.463917624565866, 54.03820360860517, 46.81349585133214, 50.6904528217931, 50.50685059639716, 56.3078046614124, 51.48314814413748, 37.760755708140714, 53.08974312197778, 52.31932686221216, 54.940729218144575, 52.730716812995176, 55.773660213716575, 55.48259681270969, 58.743808346409956, 56.70838456000052, 53.25186252593995, 48.66490164110738, 39.48443735799482, 41.04206154423375, 40.44442176818848, 40.278423140125895, 42.16150599141275, 47.96285229344522, 52.93481342254147, 53.90684735390448, 55.1204796760313, 53.485137647198094, 53.736510584431315, 55.3730881598688, 57.7394344729762, 58.327327159143266, 59.40781462577082, 58.24011718073199, 59.13272311610561, 50.944496893113666, 42.866430436411214, 32.68869176987679, 20.51027563310439, 14.240207076072695, 10.26923873732167, 6.573975759167825, 9.015311906414649, 8.398446632969765, 8.157025239159985, 5.889769763715806, 6.096065842336224, 5.098880202539506, 2.8855266734477016, 1.4801006235422627, 0.18825939646170986, 0.09426385554815493, 1.2309408836787747, 5.854446859129014, 16.915772461122085, 25.541395910324592, 36.776178036966634, 32.306545049913474, 37.64482221295757, 42.290544125341604, 56.833135543331025, 50.348555503353, 35.79483632118472, 13.14362612462813, 1.7864333213337007, 0.10348492647491156, 0.03608990415570236, 0.021615911973640326, 0.06741303304630904, 0.03011526104303137, 0.014434946595781274, 0.015959829287303072, 0.01191580531022121, 0.00722269275067975, 0.009042831952683628, 0.006853349792260316, 0.03649775021439118, 0.007251255860131595, 0.07048029587754319, 0.04699033174303271, 0.020592156121687546, 0.0761521044337461, 0.062003383608234514, 0.025747221135984988, 0.01919226642067154, 0.038160206975355264, 0.015433111280623465, 0.028126619365667144, 0.04910562307603898, 0.023680074598580122, 0.026081268029708057, 0.08057975555740057, 0.03999389204827528, 0.014492527679390004, 0.1585780552798702, 0.10393963030148899, 0.1757421786145818, 0.1418906071734044, 0.11370283100874194, 0.11760026501912264, 0.16322681470023048, 0.14551902940917402, 0.07592226273470348, 0.12728155560551152, 0.311839368434683, 0.10011854461364209, 0.20797733517904438, 0.09141777762241902, 0.12356183867180541, 0.10480392303678299, 0.09917932081847422, 0.11439103843464006, 0.0889084872699553, 0.24162407003102765, 0.10451927540763732, 0.14317044898146583, 0.15037182868728716, 0.12445968605818288, 0.09209024194147318, 0.11517008090572012, 0.20951712594157268, 0.15237671142864614, 0.2178430307896868, 0.1258878195057473, 0.19490782922554403, 0.25861360192779576, 2.813382273720157, 17.08318510363179, 38.40674654130013, 59.73679557923348, 58.15329551696778, 49.53710340684461, 46.85223710152411, 35.81834700799758, 32.844554993414114, 34.1969568498673, 30.788134759472264, 16.237410306930542, 5.26811380540171, 0.9450918448067481, 0.8076420041822618, 1.8885632604360583, 7.215125406942061, 11.31760395342304, 14.64833067309472, 12.538118074017188, 7.322962639793274, 8.436871151770315, 11.604900898471957, 13.183234218628177, 18.7844660974318, 23.73770183132541, 33.6591959768726, 46.21823695398147, 51.80452362183602, 59.135868856983805, 57.957141707020426, 59.75553666391681, 56.69986517198625, 56.66510120514901, 53.396762724845644, 54.13249738754765, 54.071504531368134, 54.830961688872314, 50.343891805218114, 52.85390277062693, 49.58685475011026, 56.034380159070416, 54.464914337281265, 60.365692723181944, 53.515120244795284, 56.102680390880955, 54.78756066291563, 55.43273956544938, 57.935305872271144, 56.41604638868763, 55.527633467028224, 57.4505832887465, 48.99696165515531, 52.34167652745401, 52.659937643235736, 59.81423885591569, 52.52110142861643, 41.43472609981414, 54.46642444979761, 52.3342828596792, 54.48286310318978, 55.03930622531522, 56.82182735012424, 56.446625186551, 60.26870819830126, 59.94467727599606, 56.44439728029313, 50.758192154669, 41.377188851756436, 43.329980065745694, 42.263766104175204, 42.795098212457475, 44.27586355516988, 50.29292452719904, 57.41663909727528, 55.930029423006125, 56.76413320725965, 54.268713458891845, 54.77072977250623, 56.720104602075395, 57.15563281889885, 60.11070336064985, 60.27276000668926, 61.7791933398093, 60.625659573462706, 51.93716249158306, 45.59551362068423, 36.319147386858546, 23.847981229905162, 19.28090480066115, 16.67885345797385, 11.660603457881558, 13.591588254897827, 12.282323645007226, 14.313029800691913, 11.789629824699896, 16.538424761064594, 15.027612101647163, 6.531369503467314, 4.364766459311209, 1.4225795552615197, 0.6925151076528334, 1.7560316429984186, 7.719476021105244, 17.60359537216925, 31.587976640270604, 50.21790135291315, 42.90478729432629, 45.827431601862756, 54.51795654912149, 67.24582026081701, 57.852547784005445, 39.86849623341715, 15.95265898012346, 2.226282641772301, 0.15194506684858955, 0.21333935310042676, 0.0987172625478237, 0.18344349197803006, 0.12391105219120942, 0.14982275815019686, 0.13458883930598536, 0.14762797753416723, 0.11256725121770175, 0.14138213929630097, 0.1683461666107178, 0.09923521459342972, 0.12350283457987732, 0.10667374447709131, 0.11342602811994092, 0.21447028273776655, 0.0927013119742755, 0.14942543430914804, 0.11727603362692941, 0.12669085585061582, 0.13729456992399308, 0.11431229991778252, 0.13168410968876657, 0.2224512181935772, 0.14162667456173128, 0.16393221313914946, 0.2613744295893177, 0.11962760945842152, 0.18023523832521132], [0.008691246433544063, 0.012294074629373368, 0.059105207873207916, 0.04191006180800257, 0.03596791614507956, 0.04380853876711861, 0.041811140704779856, 0.05756203866293354, 0.029340539307844256, 0.08911415889498689, 0.05652091751295713, 0.04487321712076665, 0.04741712315608898, 0.03996520971639022, 0.07628495174069559, 0.04239528657748334, 0.05835821852087975, 0.02172537253148133, 0.0574272110186998, 0.010740589087588653, 0.04877946114227657, 0.046786399137589245, 0.035396437536204056, 0.10547988071677186, 0.07461055166899197, 0.029454768763013908, 0.01772312811696001, 0.01958766929625023, 0.05655988840566528, 0.031063913465327317, 0.017059902818272674, 0.023491952132673997, 0.5291234461530563, 6.636342915796465, 22.030403921681067, 38.23797871989589, 49.88983431170064, 46.744579807404556, 33.51078525666268, 28.21729567743117, 23.587957505256902, 25.371512174606327, 21.72803036628231, 16.885944797146706, 5.3378908095821265, 1.4662004790959822, 0.5567547666930384, 1.727708820854464, 3.143954238583965, 4.2349075694237985, 4.527936568183284, 4.453787101853279, 9.154793350927292, 8.045956463583055, 2.7044362358508574, 6.047338727981814, 8.678400901056106, 20.5403249109945, 26.20721236351998, 34.72175821181267, 43.15878429720479, 53.29400839344148, 56.327420434644154, 56.67014145082044, 55.25196929131785, 55.775429202664284, 55.09882427030995, 51.364049296225275, 54.61903602846208, 52.83431445398639, 52.29838925023233, 51.22040425577472, 52.81864066277781, 52.60827610569616, 53.95969736960627, 55.464879466641335, 54.30709385102796, 55.356410241896114, 54.249548758229906, 53.94318026881064, 53.98315314323672, 53.66816720654888, 54.20442188939741, 54.66851280581567, 50.530012192264685, 48.521476253386474, 50.26702119458107, 52.38764278350338, 53.735227969384965, 34.82049211379021, 58.176249227216175, 50.66895823324881, 53.243190165488954, 52.86611310897335, 52.25603941948184, 51.945011154297866, 53.85990835005238, 52.69742373497256, 49.75765435926376, 46.92169051016531, 39.78129802211639, 37.7224459186677, 40.58828646136869, 41.12313301332536, 41.98113972140897, 44.54702092755226, 48.9348626905872, 50.88977198446951, 55.23997860570108, 54.01613635401572, 53.35214576413555, 55.99411310688142, 55.30468594643378, 54.24556755250501, 55.72102200600409, 56.924126686588416, 52.85366742841659, 45.51769771883565, 35.646692322146514, 24.813186314798173, 17.707761756835446, 11.307686240442338, 7.85548028446013, 9.13965202146961, 9.506829996262828, 7.944827954615317, 6.263582917951769, 3.1108803229947246, 3.481826714930996, 1.6568662803019247, 2.7793535061420935, 0.5740879656326386, 0.08201764130424108, 0.5215471430170922, 0.8968055068004517, 5.798440806327328, 15.169324394195312, 29.46443092438483, 36.672647076268355, 34.14611116532357, 33.77167778630411, 53.69924022305397, 50.498994088942005, 40.529819611580145, 26.19121889914236, 8.0440693132339, 1.5215397289683743, 0.06271824323301835, 0.0006139795509478708, 0.01937931253304405, 0.020012788722411762, 0.013637521844958107, 0.03135131709578057, 0.07881400716160575, 0.023367512640693498, 0.02884854040589304, 0.06017648607432362, 0.03845828029537394, 0.031080363288281426, 0.0214040043929051, 0.015750728461200434, 0.08959677896552509, 0.036767742581545346, 0.06271200344687508, 0.056026695040805694, 0.06229086193226038, 0.024316967540090124, 0.05147593358771936, 0.07122759166504107, 0.0949405103681549, 0.04026229095254694, 0.032585706907294454, 0.044723791671135736, 0.12934139749455836, 0.04714801179004773, 0.049469353961608106, 0.014968973081258517, 0.0765718286857009, 0.023854154672834183, 0.017196490549512448, 0.06353618381845375, 0.05127996063580917, 0.03259178964541324, 0.018047886194601175, 0.006801128451291833, 0.011858344885460552, 0.01338701971220754, 0.06045396695093763, 0.016344311579521147, 0.042110761522405574, 0.12515296498613973, 0.03230927174069709, 0.04973993238602435, 0.06066651804552925, 0.03551387498455663, 0.05786540565050899, 0.013684054025478903, 0.03067893704639808, 0.019580144397613984, 0.04452716754448991, 0.03890278749167919, 0.03556604940263975, 0.03769070999095998, 0.05050025166823499, 0.028395935660228137, 0.019140913631887208, 0.036490671561970826, 0.008269037183884892, 0.78759967319427, 9.042147782541091, 27.99525618553162, 44.90289757328649, 56.65699366600283, 50.599810769481046, 40.699881815141254, 32.826290476706724, 27.992838044320386, 30.867409783024943, 25.140090373254594, 17.179561661135768, 6.189020622161127, 1.2937011353431211, 0.21434571684127857, 0.4336368989559912, 2.0392645222525445, 3.454213228917891, 5.5059594685031525, 5.265307349543418, 8.454324718444578, 6.662416871516935, 3.7314426754751517, 7.6122099834103745, 11.654310014940078, 22.2669404937375, 29.71063025536076, 37.35561801541237, 46.97879629750406, 55.32898502965128, 58.75077447583599, 59.3459157020815, 55.767721745275686, 55.57711416675199, 54.9506724265314, 52.373333977114775, 54.43401782743393, 52.300134704959014, 53.38611348982781, 53.10775856817923, 52.95297007406912, 51.80771643115629, 54.35515465274934, 56.26721989723944, 56.25678247021091, 56.48688439399966, 54.96896636101508, 55.8515114168967, 55.54345238593317, 56.599711372006325, 53.845352434342914, 55.99443866360573, 51.66178464889527, 50.275913207761704, 52.625762031924346, 53.71591029628631, 52.95140897074054, 37.15742065060524, 55.907354201039965, 51.92727811874882, 53.18869275431479, 55.26568974218061, 54.27432244823825, 53.84675272049443, 55.84525915884203, 54.67642422645323, 51.50081449939359, 49.19360183900403, 42.93773520377375, 40.59605275430987, 41.86102497962214, 43.73984029216152, 42.786292491420625, 47.50671594373642, 51.811678025030325, 52.893934480605594, 56.35553206166914, 56.016282343095355, 54.304246210282855, 57.00481376340313, 55.576765075806655, 56.601656867611794, 56.860121450116566, 59.00988232704901, 55.879187660832564, 49.77448524967317, 38.963244576607984, 28.869519156794397, 18.477615156481345, 13.153396748727369, 8.635129313315115, 4.876109188602817, 8.424165614189642, 7.333272589791206, 7.36205151004176, 5.525348724857454, 6.825475683135371, 2.88580957439638, 2.6654449345604068, 1.414752833304867, 0.2340300702640126, 0.24976848864987974, 1.221787297437268, 6.7217839052600254, 16.321552991867065, 30.63993584725165, 40.386762926655436, 37.98611156402096, 39.91053227455386, 57.23306432847054, 57.251346495843705, 50.50536401810185, 29.413387160147394, 11.085521232697273, 1.9331987298304036, 0.04715434733718153, 0.06511810941681748, 0.02629426920095519, 0.050269762624896346, 0.039964156345494335, 0.08145371632229897, 0.04421876352881232, 0.01785203007109944, 0.07846918332600787, 0.09732868221978988, 0.029217997798696164, 0.02537772352356584, 0.027805184194397543, 0.03455338458861074, 0.06273324706501539, 0.041559473160774484, 0.06012705425100942, 0.04420999565251893, 0.043545318617215084, 0.06648997370634349, 0.04123862404676695, 0.05674878653559474, 0.017357391996249076, 0.013381084446014177, 0.04323742788044676, 0.05333712504756066, 0.03935013687418353, 0.017835796667983937, 0.04811122945900406, 0.1603903128735481, 0.16380052262496564, 0.15444381583121516, 0.18712782331051367, 0.23386405901082102, 0.15253109346714713, 0.14977708398815126, 0.13828158228387757, 0.1707879646170524, 0.1387251931573114, 0.06720889359712601, 0.21111305562719224, 0.16786049751024093, 0.14575824802440984, 0.2080129889110404, 0.24667347811402815, 0.08299162250853355, 0.10913077997223986, 0.2030738821673778, 0.0862838164152157, 0.1284246660408474, 0.11793358221409783, 0.10002092202945102, 0.19272624064357052, 0.17401826628033193, 0.14311316092648815, 0.17996018211687767, 0.14598162394137154, 0.16796293878747573, 0.09878707614036338, 0.15185846826962887, 0.19896722188399685, 0.9814472520543683, 9.820235217771224, 32.59210340438351, 51.18581679559524, 65.40385953841671, 60.32464904169883, 47.16225339520363, 39.164579837552964, 35.89782599479922, 34.915970448524725, 29.327826538393577, 21.881034181964015, 7.746164808350225, 2.199325172170516, 0.9749180378933108, 3.2333136758496686, 6.866929742597765, 8.961283218476082, 11.67546041550175, 12.820903312775398, 17.852512905674597, 15.715510518320146, 6.0958334419035145, 10.194743121823958, 11.88984638260257, 23.08404080329403, 31.620871597720733, 39.417431508341146, 48.37727423637144, 55.98172233950708, 59.18849921995594, 59.244922514884706, 54.9656048897774, 54.66106030248827, 56.02449186386601, 53.76005657257573, 54.31734300428822, 53.95003264950168, 55.1502622327497, 52.07975633682744, 52.73008923376761, 51.44530511671498, 53.97156253937752, 55.53083019871866, 57.4505832887465, 58.79352831071424, 58.81937280777962, 58.94267251414638, 58.99214929149997, 58.00047605268417, 58.03024291992188, 58.936565383788086, 54.535713118891564, 52.57856415164087, 54.011602094096524, 55.537953222951586, 54.82275216810165, 42.00480730302873, 57.579044834260024, 53.38296774894961, 55.59406665063674, 56.89910980962939, 57.210608759234034, 55.045860505873165, 57.95736920449042, 57.88235779731505, 53.25688708213068, 51.8920591569716, 44.96245091961276, 42.881366822027395, 44.50399252676195, 46.64193922473539, 45.90057988320628, 49.85413289839222, 54.02360454682381, 55.66008798537716, 58.10232039420836, 57.109144887616566, 54.36805925061626, 58.96915243517969, 57.21750428599697, 56.64986279702956, 58.16727092189174, 61.512444711500606, 57.650930112408055, 53.15264617243121, 40.01647157053794, 28.94335581410316, 20.58638922629818, 15.33806868137852, 13.013271054913922, 17.524420369055964, 19.171492245889482, 14.949757956689405, 17.676539690263812, 11.797192154392121, 11.068561884664721, 7.810352435035091, 6.782650265001482, 2.896990780868838, 0.5433073495664905, 0.9651532360622961, 1.5835624524662573, 7.613824529032554, 21.30540870851086, 39.00835575595979, 48.509105097862985, 45.750843401878114, 49.52014700058968, 68.3033775514172, 67.4252373172391, 56.31152306833575, 33.679160841049686, 12.10237608801934, 2.170557038437936, 0.16794216248296923, 0.0972336873171791, 0.0955734292285577, 0.11424492248484205, 0.12755725532770157, 0.18963323725808054, 0.11324543821355028, 0.1330250699914271, 0.1535336574118945, 0.12626901719599, 0.08915788719370481, 0.10718815719648715, 0.1769343493205886, 0.12502396344057015, 0.1866030071171061, 0.1382644065926152, 0.13522749616494104, 0.18097160203802973, 0.1572449243957958, 0.15545347375014137, 0.10645828990926666, 0.1827880271500157, 0.18643960056285705, 0.22012246412134942, 0.1424750096855625, 0.16411048179912954, 0.2800317042537274, 0.1779705138816949, 0.17757438513780796], [0.0712087152585868, 0.04245576921910529, 0.021618838429511077, 0.0258662577928795, 0.020311700908707517, 0.04489652534586288, 0.021806784695194616, 0.07234300036103496, 0.011961947743510528, 0.03782152333447049, 0.016096895823495525, 0.11464681987079883, 0.015468779376768058, 0.08621460037125696, 0.01613523086322652, 0.04069840182520209, 0.0882487936365989, 0.01823969928908252, 0.01245905357908698, 0.012324269027298978, 0.04684519255533815, 0.0602615486469961, 0.009823763788106942, 0.01782474010401676, 0.02903362533317939, 0.04910321372951712, 0.029923235359151038, 0.016680718024050998, 0.004499114678061057, 0.04843394016666759, 0.02943246411309848, 0.039391869513858715, 0.18895900327592127, 4.714559018611908, 17.893125126438758, 34.73523155335457, 45.702759065935695, 41.76899440826909, 33.0491772005635, 20.379884281466087, 23.49460509515578, 26.06678955016598, 28.64073907175372, 19.803690064337946, 8.602737399839587, 2.7250245117372085, 0.18232504957385604, 0.8275580838803323, 0.5439137847673509, 1.5794372222115918, 4.188488279619525, 5.231001809720071, 7.595580114472297, 4.179654121398926, 1.995159430849937, 3.252765690126727, 5.9277535061682425, 10.50680689273342, 18.697387518421298, 27.958254506511075, 40.64845954218219, 49.29087661927747, 57.03840101918867, 56.7342016004747, 59.37249760473929, 60.40349652690273, 55.74096725833032, 53.29001542060606, 52.612622091847086, 51.17726995098976, 53.67096385648174, 53.45741825719034, 53.40074393057054, 52.98026584809827, 55.13342741997012, 51.53278966103831, 53.556999391125096, 55.38382368703043, 56.21056910484069, 56.08960713109663, 56.79169570246051, 57.20823180290961, 55.79843390372492, 54.995622788706136, 49.96743448318974, 48.654923131389005, 50.16321174560055, 54.20426891696069, 52.939006436255674, 35.38380330608737, 55.63163511214718, 54.828949512973914, 52.16211434333555, 48.649180781456735, 50.18611054266653, 50.994114875793464, 52.982646726792865, 50.89938571376186, 49.33395208850984, 41.98074748439174, 39.92764557561567, 39.7819765921562, 39.85395992955854, 40.91837352321994, 44.44321540094192, 48.007614381851695, 50.944512582594356, 50.26466777247768, 54.244704631067094, 54.315781900959635, 52.90417578912551, 54.406686752073234, 58.00587715641145, 57.95000299330681, 55.87117033620035, 56.854332031742224, 51.50125380485289, 45.38465092259069, 33.524701826034054, 27.883529432358284, 14.374770848981797, 13.631350301927137, 7.836685267186935, 2.434704154729843, 6.031674252402398, 6.455685409807391, 5.169352446832965, 3.28225455937847, 5.454676929981479, 1.856099273408613, 1.0251333240059115, 0.5781053307075654, 0.2126198739654595, 0.43530770607533, 2.2078649074800554, 6.375152776318212, 16.366491586931293, 27.14072861979085, 34.54502797895862, 28.190841251803985, 26.76732682412671, 42.67830179583642, 45.450115280766646, 37.46536593283377, 27.870864099071873, 7.036033416948012, 0.7573435515646012, 0.028719094529327367, 0.004840109510452397, 0.013169406691656239, 0.030728985570491325, 0.03208151188558869, 0.016986896554308555, 0.05866726988085336, 0.023551791260439544, 0.07742001825282652, 0.03806190640335122, 0.057804038177334496, 0.11817344434319005, 0.1349824246379637, 0.040479656909742666, 0.04647894124049814, 0.10563751096807181, 0.04252264486445535, 0.06084122439666141, 0.05671476074043782, 0.04572891817998983, 0.05887147444750994, 0.05845622031859333, 0.024690376031362725, 0.03402708601506968, 0.08166646659975091, 0.05541887705124194, 0.04659927067076487, 0.04247201794397928, 0.025676576338047465, 0.07013881218529518, 0.04272780704101728, 0.025969817558483734, 0.02512293800170864, 0.08370806793532065, 0.02772639588182492, 0.06665778526615712, 0.06956819159489486, 0.047849104814832254, 0.018268100083655408, 0.0979689248807488, 0.08176202840742566, 0.06825991260308413, 0.05310062604445604, 0.01968408529196055, 0.07780164495230683, 0.04157580615532014, 0.0170041392782643, 0.02449689861086588, 0.028232772338895068, 0.014475067577985747, 0.05689099926741854, 0.015040366730142026, 0.02488522857968365, 0.04509589972815687, 0.01858046285868172, 0.06858658015487656, 0.034400373847494205, 0.07989963035910361, 0.07683737774289424, 0.008066091874253847, 0.02471923647869018, 0.14853862624975944, 6.047254397023109, 21.443091746299498, 41.64232146355414, 54.16040505132368, 49.03374172026112, 38.680830001831055, 28.982075491259177, 29.977578924548244, 28.369236530796176, 26.44564344036964, 22.538754863123742, 9.551482258304473, 2.840836168296876, 0.4043683872347878, 0.4528348784773581, 1.0976804408334917, 2.5675592451326312, 5.086522285015353, 6.143100944257552, 7.528846379249328, 4.656296622368598, 4.055397601858262, 4.2464045266951285, 9.410793704371299, 15.15452431094262, 22.288382130284464, 33.81836968083536, 43.41205958397158, 51.31430187532979, 58.02210400181433, 58.44348030705606, 57.02795182504962, 59.37277217065135, 54.91677922587241, 55.93370076148741, 53.46223100539177, 52.27642397726736, 53.61598007140621, 52.98469420402281, 54.18999148953346, 52.592013958961736, 55.16255494086973, 52.36792502864715, 54.353970096957305, 55.278806148036836, 57.57443997167773, 57.7423527163844, 57.24493342061197, 57.23606101928219, 57.455556854125, 56.11022310872232, 53.31315348225256, 50.53497399053266, 53.60013761828023, 55.91469687800254, 55.22948234311996, 38.21740588834209, 54.73347510060957, 55.222857459898925, 55.221327735531716, 51.67080610029159, 52.77253712377241, 53.7898430516643, 54.580016289987874, 53.70455111226728, 50.5101453873419, 43.63377548033192, 41.85807143488238, 41.232975067630896, 42.382986545562744, 42.00664297226937, 46.26001019631663, 49.66643964090655, 52.568981801309896, 51.899284162829005, 58.61282079450546, 55.054756441423976, 53.613403074203006, 54.80929059367026, 58.27729340522521, 59.12047747642764, 57.147709631150775, 58.60009662566647, 53.84999652062693, 48.98002486075125, 36.455802763662035, 28.3058294557756, 18.645937788871027, 13.412404579500999, 8.752685689157056, 4.747301003625316, 8.956123340514399, 8.469468009087349, 6.91941939053997, 5.851641874159537, 5.421753045051329, 3.267998214690916, 1.6459821933700194, 1.188590685206075, 0.30794994004311105, 0.46041032359484707, 2.192349481967188, 7.6129743552977045, 19.364516004439324, 37.18608533182452, 37.916120790666156, 32.880556468040716, 33.16877026711741, 50.81257581710816, 53.26299029011881, 44.07109622032412, 31.423588145163755, 7.539746155661922, 1.09594258569902, 0.08276409439502225, 0.06589155944605028, 0.10224938753151125, 0.039477993118306326, 0.049758789640280514, 0.012786875050815364, 0.011327772498911908, 0.03933766879321587, 0.033598034642636776, 0.06001628942847733, 0.03343398840497098, 0.05975134175030455, 0.024987037834380905, 0.026612130572058024, 0.03136416247505094, 0.07742273020407847, 0.01985133186193003, 0.02489825590483604, 0.07082269121442111, 0.019271665688363776, 0.11101917904471198, 0.044524221936421055, 0.05299470672804502, 0.03818999247385129, 0.053171048676895524, 0.05016793804844061, 0.05259454070079712, 0.017771196303768985, 0.015711262484171217, 0.11431762422885626, 0.13127986041288223, 0.09999686686862862, 0.11543232812395982, 0.1860807496573656, 0.12080049007049493, 0.1739568566723216, 0.23990395749288224, 0.2012938002665197, 0.15648657395955057, 0.11146285886605901, 0.27426701519758473, 0.2893204590485942, 0.21914331182356805, 0.0839303789900676, 0.2967230440868486, 0.13327116807622294, 0.1497000615082441, 0.13394246028075296, 0.15074089920568853, 0.15217100149921833, 0.1554347965265474, 0.11815141165448774, 0.1439527473262241, 0.15983925050785466, 0.11104472807698673, 0.11943417991841994, 0.11824832943778847, 0.2122843887416586, 0.19565173124353732, 0.17080987473168682, 0.19898384599195373, 0.2998790198997144, 7.156692387596254, 24.675309119686005, 47.60253160230575, 62.96466304409889, 56.80861680738388, 46.46740551917784, 32.86312937736511, 35.34235954284668, 36.200311337747884, 40.35261869430542, 25.818678063731042, 11.527367407275785, 4.193385849075933, 0.7378943564911044, 1.6013534655494075, 3.2450866699218754, 4.277184346029836, 10.485383887444774, 13.147898566338325, 15.541957405305679, 11.121602135319865, 6.757724092852685, 6.825167286780573, 9.131858271937217, 13.65415103973881, 21.956806528952814, 32.37780471001902, 43.9106281342045, 52.29334900456091, 59.4517530164411, 58.209734501377234, 59.59535883318994, 61.88212025550104, 57.29989759383663, 55.84269785111951, 55.929354775336485, 54.399449979105306, 54.014524259874904, 55.269890600635165, 53.54908797048754, 52.61332419610793, 54.45244904487364, 52.84361439366495, 55.26444635083599, 55.780504749667266, 58.55375382208056, 57.995686838703776, 57.71091491945329, 58.2790231704712, 60.81919716250513, 58.42601791504891, 55.31342890954787, 53.03612039935205, 55.578086914554724, 59.02361846739247, 55.66324941573605, 42.516264761647875, 56.07159952963553, 57.68583920694167, 55.762214737553755, 54.487393440738806, 53.416103932165335, 56.90429910536736, 56.45884336963777, 56.72488597131545, 51.565364945319395, 46.845671053855654, 44.81965311111943, 43.82948998481997, 44.00453359849992, 44.423128943289484, 49.57676641402706, 52.89954739232218, 55.264222775736165, 55.0804401213123, 60.62566741820305, 56.379905669919914, 53.79691116271481, 56.768687079029704, 58.563065528869636, 59.79183035512125, 58.33054742505474, 63.46993100258612, 55.584664729333696, 52.8916242045741, 37.857206790677964, 31.436881057677734, 17.72488486382269, 18.399852206630094, 13.014723312470222, 8.886347316926527, 14.224547013159722, 15.999472468130051, 11.802933523731848, 13.39981181006278, 13.380641225845585, 6.851442263972375, 6.733924621535886, 1.8159453570842745, 1.1286694941020783, 1.0164708920544194, 3.2710309422785238, 9.400059157802213, 23.317147262634773, 38.553996239939046, 44.98529872586651, 39.488351883426795, 39.12727809721424, 58.57191439597838, 61.869956985596694, 50.80296993255616, 36.461168566057765, 9.587276827904487, 1.3849570385871397, 0.16726438917459982, 0.12233340136346318, 0.18344879330646607, 0.10309681867159183, 0.14986599615264326, 0.07397675180747625, 0.13710251168137597, 0.1703103394397805, 0.30898259592152416, 0.1123207624280645, 0.12095255852346459, 0.24968533746657834, 0.277237260654088, 0.19504728787128003, 0.09808300303355341, 0.2800842272418161, 0.14496678726807719, 0.11546494814777568, 0.17929072852336592, 0.1376682829352156, 0.16521783125015999, 0.22286778616328395, 0.19174091367711946, 0.23181328760279765, 0.20580349940686457, 0.09302739729924549, 0.14507889657491638, 0.12107546200915692, 0.13763296628190627], [0.067577826219701, 0.06839000199350619, 0.043923861812800176, 0.06271132928950172, 0.011405397315449532, 0.03026023169138259, 0.0531082064844668, 0.06032237985862359, 0.03879347057532399, 0.06132581714360465, 0.05516597610567847, 0.016661337914786512, 0.02528600939249079, 0.055232281015524944, 0.038857856434920145, 0.02051437904517497, 0.045891528002797596, 0.07231902946988422, 0.02134453298734321, 0.046961381280374144, 0.059236971165744536, 0.08348199538886548, 0.06076527443984824, 0.07596795987938681, 0.09581280872225763, 0.025398980548244812, 0.06815156478795313, 0.03152107643414169, 0.03523028838718611, 0.09809581968452662, 0.0688822671110111, 0.04909272981627334, 0.08602661771639701, 2.172838386989409, 15.326012296061363, 32.65083501415868, 44.71956599143244, 40.71399450302124, 37.25205959812288, 23.42144504670174, 27.955495119094852, 30.05431813578452, 28.056705997836207, 24.616795201455396, 11.369877380709495, 1.7563546256672953, 0.9881577532618278, 0.16675406736471962, 0.9103648340509785, 1.9847226166917433, 4.587853714343041, 1.7899112379358662, 4.182290444450994, 2.7913348761297043, 0.6956574164571301, 2.747132706065332, 5.23949864410585, 11.321897968169182, 15.7887960826197, 25.641312406909083, 34.66175771528675, 43.174924850463874, 48.47139150865617, 61.31490630488242, 63.96204725388558, 61.05688495020713, 54.70262173683413, 51.73669799681633, 52.225111530673125, 52.76764592816753, 51.88125302714687, 54.417281073908654, 53.21863612821026, 53.56574235423919, 56.57239206375615, 57.19629210810508, 58.77801533668273, 55.84056015937559, 56.964009346500525, 55.18862301303495, 54.096105637088904, 54.43914436524915, 53.38608995560677, 51.56847538486604, 47.2898716311301, 47.982981897169545, 52.384422517591915, 53.442164159590206, 51.960865374534364, 35.06074513158491, 54.740966827638694, 54.26314369324715, 51.08428232131466, 47.73476254555487, 46.434324249144524, 45.715377330780036, 45.63601601508356, 44.25815405384187, 42.687519365741366, 40.91130148979926, 40.757540656674294, 39.886437154585316, 42.2217143735578, 44.40088518204228, 48.809189950266195, 48.93459596941548, 50.192723658777055, 54.566123254837535, 55.68299462718349, 54.98602474889448, 56.58188027720298, 51.51271104812623, 58.95161944050943, 58.68701634868499, 56.074957078503026, 57.24712994790847, 49.516875743865974, 42.25243045437721, 31.627894601514264, 20.738577188984042, 14.322250312374486, 7.339943560861773, 4.94643924697753, 3.666637765784418, 7.226204631790039, 4.149683290912259, 4.659929227444434, 2.9469617768641445, 5.535880288770122, 1.964883268360169, 0.3984424213488256, 1.0048125047356853, 0.21115466952323916, 0.5141103904574148, 2.0690245253424493, 8.312869341142717, 16.307067678820705, 25.703305467482537, 30.871575340147945, 28.908060366107573, 28.335908151442005, 46.307741518943544, 53.75550662317584, 41.09526457325105, 23.09640411407717, 4.888246472804777, 0.22099745910494561, 0.04684785471087502, 0.05289396999644176, 0.09537361051526763, 0.07007275242358446, 0.016817573886064273, 0.08849958017949136, 0.046097973376632705, 0.009236950014207152, 0.02275833676028396, 0.025650389537575747, 0.021970488108514298, 0.09505149352574542, 0.14191927418353098, 0.01699493856229369, 0.0048993673690053965, 0.07463408589002586, 0.0798853121757988, 0.017213886491053047, 0.019371988732487928, 0.0837453381128369, 0.05567874556647674, 0.02088885048344251, 0.01938720898432357, 0.04368616388209405, 0.028854916172642863, 0.01445341410280596, 0.04478101460863987, 0.14226923846910078, 0.09357946324011973, 0.06953083714770694, 0.013048473967149133, 0.030244929085095084, 0.0930238732947938, 0.03377874329265568, 0.08850928651349199, 0.018131539165492983, 0.03647144275507139, 0.03743066910594221, 0.023949844800236247, 0.033763540277798335, 0.04103568352518543, 0.03705892877112474, 0.04529000342553181, 0.0063646421955537895, 0.030701099970047514, 0.029615486348648707, 0.09756170318371828, 0.047919604056064165, 0.015652534183895877, 0.02463578269065869, 0.018334690361253677, 0.059247133322060115, 0.05006742348233539, 0.13194836405736785, 0.014081377866527727, 0.09122686851168833, 0.0177746532755273, 0.05740084227234606, 0.09227486147034554, 0.04587039929784594, 0.06939181517208777, 0.03975331362697386, 3.140234851068066, 18.088012010820453, 38.332570598971465, 52.8219864445348, 47.91197522994011, 42.66367135509368, 27.133638935704386, 30.92290935977813, 34.86773314014558, 33.918292060975105, 26.507834580636796, 13.244664419081904, 2.7325934604290993, 0.24783836076817206, 0.32658956404174533, 1.0059965089444192, 1.6888429128354596, 4.299518812087275, 6.209922932809399, 5.983642868457302, 6.285023573906192, 6.123959287520378, 5.043721381695041, 8.66544040941423, 13.62051377373357, 19.968482563572547, 28.93611707995015, 36.80208136958461, 46.26642719391854, 51.55353899924986, 60.38830910959552, 60.813729378484915, 60.44032758282077, 56.105998716046734, 52.554418040860085, 52.81917018275107, 54.479191764708496, 54.25553429511286, 55.64883470535279, 54.76489720805999, 52.682295153217936, 54.92119973705661, 55.68018621014011, 58.87853391708867, 55.774017149402255, 57.07726778522615, 55.850801467895515, 53.95254296641196, 55.74339912783716, 55.26665856761318, 54.278578219875214, 49.957126494376894, 50.22940566462856, 55.487589989939046, 54.89487278846003, 53.6812836124051, 38.53716927189981, 55.09616098096294, 55.31069501753777, 53.813757742604906, 50.41678121013027, 49.5765349941869, 47.40664059115995, 47.84640104539933, 46.46283203555692, 46.318006361684496, 43.30693614098334, 42.678803859218476, 41.409195392362534, 41.66758544983403, 45.60447623652797, 48.791915832027314, 50.84595910964474, 52.100850843614154, 56.21617809418709, 57.671251912270826, 56.53002654352496, 56.86080786489672, 54.14328390552152, 60.01091434109596, 58.86909669445407, 55.69952349508963, 57.472909419767326, 51.698631394294004, 44.92961283653013, 34.27750272135581, 24.89576005166577, 14.43841032443508, 8.850065392832603, 6.969950795173646, 4.517553564040892, 7.058782673651173, 8.135948873335316, 7.770280030465896, 4.721050541247092, 5.1757689541386025, 2.4930207287111594, 1.9330603437077616, 0.14844033716907426, 0.33751740991588564, 0.2521842549885473, 2.511195766348993, 8.006147838407948, 18.670611458439982, 27.739027354025072, 33.74968113437776, 32.288109910103586, 32.31736883040398, 52.84058240152175, 60.66265536892799, 46.76259917597617, 27.373317326268843, 6.505792217869913, 0.27215022233224684, 0.03559339874153657, 0.04912030515110782, 0.05757625725480819, 0.04297932519787743, 0.04490551921809393, 0.019983129628423243, 0.05009925060514962, 0.019372076832599217, 0.0200404828008745, 0.0507842825966016, 0.0593002691804882, 0.03681212971587816, 0.033305082620391925, 0.05653919637083046, 0.025197156599812934, 0.08605297114099227, 0.04968446762030644, 0.03194956473195024, 0.014348522301823383, 0.06789081910204503, 0.02177729414054944, 0.02756239752465439, 0.02041143214991016, 0.02870510959426963, 0.04570418886179405, 0.04796097280397531, 0.040437782543801495, 0.029655889825775262, 0.03045834394382133, 0.20083045496815638, 0.1957587690483178, 0.07660777353110813, 0.1746204113888164, 0.1329657747860878, 0.16135829560939344, 0.19675846782422837, 0.14766511747673636, 0.15084370820512696, 0.2028922273987724, 0.13375083104737345, 0.10928362217401305, 0.08223616788464208, 0.1348824501638451, 0.09310369199562459, 0.1351527872705652, 0.12662363163526022, 0.2579874629455228, 0.13923594397642922, 0.16492060445729764, 0.09738721899808415, 0.21478224906229207, 0.12951612682832828, 0.155732820050851, 0.22834742922456036, 0.08797792792921105, 0.23828389603764782, 0.08996709820724304, 0.11323544842701767, 0.18784071408933212, 0.19010094925761226, 0.19295723147449956, 0.16299433765872834, 3.3205869024799717, 19.197213188294445, 45.08422090161232, 60.09476677063973, 55.05672939362065, 50.4078499732479, 36.940086041727376, 40.596225338597456, 42.89430672122587, 37.24470907641996, 30.149920025179465, 15.536539631505168, 2.9774344255847316, 1.3297859603358855, 0.49785415792176807, 2.105204712960028, 5.161233630872542, 11.658426542435924, 9.642959775463227, 12.723391229106536, 9.207360955976672, 6.290634034141418, 5.355815550973339, 8.36121843707177, 16.74252725416614, 20.345102663963072, 29.825671411329704, 37.595380736935525, 44.98752270975421, 50.34464097792103, 61.12722481450727, 62.3408845932253, 60.480555411308046, 56.610066429261245, 55.00485997046194, 54.14759851271107, 55.41086842936855, 55.54302876995456, 56.3169712405051, 57.465907989009736, 54.49495184806086, 55.023914844759055, 56.693310891428304, 59.644933669797844, 55.133203844870295, 57.52799518646733, 57.54124103053924, 55.66546947725358, 57.54109590284286, 57.42731971125449, 56.18275557794879, 52.09495944361533, 52.01455477745303, 57.805424428755245, 56.5778676925167, 55.49450512855284, 41.93722094258955, 55.6969347307759, 56.40779764421525, 56.97253657925514, 52.45748058442147, 50.25907447261196, 48.96786551321707, 49.3567685158022, 46.86935824732627, 46.171749022699174, 45.52773114173643, 46.816927925232925, 42.887109171959665, 45.86348995085686, 49.26552241848361, 52.26903030949255, 53.90776126615463, 55.13510619440387, 59.3911837762402, 59.40301756705008, 55.700688439030806, 57.41507014920635, 53.31182379876414, 60.47861776044292, 59.36732007611183, 57.9466179878481, 59.25685828731906, 53.98214117173226, 48.04635563204366, 37.6607862595589, 25.602165191404282, 17.80795870288726, 10.597195952169358, 8.042941141513086, 8.520312713038537, 12.833156797193713, 12.8214838235609, 14.246583869380338, 10.164654620232122, 12.372433235568385, 6.918007337277936, 4.289154929499473, 2.682165018012447, 0.7009451391716158, 0.6519909563564485, 3.117892785418418, 10.893036800046122, 23.503595167590728, 36.63480404884585, 42.750116471321356, 43.20056146191013, 41.864578646998254, 61.42659187316895, 69.7496574155746, 53.37279312072262, 29.907511664975075, 6.853745185559796, 0.5848169963686698, 0.17008351612715952, 0.16046618622156883, 0.17471670864089844, 0.11944896541535856, 0.30984257558180445, 0.16365412322263564, 0.1880350246304466, 0.12167464235737441, 0.08959114821928163, 0.12404527079554335, 0.0764928833251038, 0.10746566488617852, 0.15687698768752237, 0.08450684483133017, 0.09328928445616076, 0.20635158935141182, 0.14619451977552908, 0.10507265135886208, 0.11912458846645972, 0.21433531336726683, 0.1628749198730915, 0.13085972247344832, 0.141019549881739, 0.10948312679125417, 0.15974820861893316, 0.11030228162604956, 0.11780628904459939, 0.19851694604562176, 0.16244560420032472], [0.02598698367364705, 0.022831266415455652, 0.08383175283069573, 0.01312562476678361, 0.0406143581494689, 0.028778541037031723, 0.04856880994573717, 0.09352883248920403, 0.025889989281553897, 0.03868508445579679, 0.011798488520716709, 0.06348238529397116, 0.018292046076948607, 0.03748325338106483, 0.027540791929969867, 0.04129056480803317, 0.07568708140282862, 0.021920420432222948, 0.06144970505227966, 0.062280849163090034, 0.028873966864099907, 0.07770673431936773, 0.06351668688078081, 0.03496871149588016, 0.03949139199610199, 0.019653790344994877, 0.040998321417118275, 0.06982045668748117, 0.074701547592638, 0.053046582371837674, 0.031205769966266332, 0.007575382872845137, 0.040686201875007925, 1.0601646861722394, 10.411788455901608, 26.616013549989272, 37.221237613308816, 44.89920662295434, 35.95557505084623, 31.268611377285374, 28.755125191903886, 19.073246678998395, 28.966931220023866, 29.64769582594595, 7.878475179595332, 3.9195200800895695, 0.45368318295767235, 0.22091513529660242, 0.7667966475409846, 1.0707233389539104, 2.0240769823712688, 6.129933547589087, 3.854053515580393, 2.4122493209377414, 8.54680440118236, 3.3434011234391123, 7.189794250072972, 5.7718133061162895, 14.558760408432255, 20.632788904251594, 27.561218469373642, 38.01473702153852, 54.72805438503143, 67.02844250586726, 65.54855185170328, 58.57397756268902, 49.64331726874075, 51.40665408103697, 53.76918785033688, 56.75551575999106, 55.03806675634077, 55.607932229195875, 54.989115576590265, 55.44645609394197, 56.40483625473515, 55.94620919996693, 56.40003919601441, 55.364972775982274, 53.40721976372504, 52.762970462922134, 54.59692562780073, 54.01557153271091, 51.626232285653394, 49.572196852776315, 48.347597583647705, 49.26370243872366, 52.61783884417627, 53.935492423272905, 50.43795416432042, 33.91969234712663, 52.43324425912673, 52.8145339412074, 51.63206485009963, 49.777219141683275, 49.07228685194447, 48.73078961526194, 47.20736065218526, 43.42656843123898, 42.621862811426965, 41.95207103606194, 40.92897176742554, 43.6534579338566, 47.1134747997407, 49.27834072420674, 50.23205326449487, 49.72648720587454, 51.63032331774312, 55.3434899545485, 53.91952837667158, 56.28221511840821, 53.47219774799963, 52.42289704661216, 55.258692233793205, 63.66149171706169, 59.8297518299472, 53.20495882341939, 47.22707840704149, 38.26692581176758, 28.823760786364158, 18.9885901635693, 11.986333747063915, 5.088661937944351, 6.2331923938566645, 3.059120971348978, 6.026656560359463, 7.28997697753291, 6.942718759659798, 2.5541349332178793, 2.6512761077573224, 2.125661834593742, 1.1605116628831433, 0.2565279735192176, 0.38403258328476264, 0.9137046709656717, 3.821708915695068, 8.896181679541066, 22.877400536690992, 32.440274338568415, 29.58650489007273, 35.85951228295603, 47.87393216163882, 58.465229849661554, 47.368138605548495, 33.23496026377524, 16.2790786258636, 2.951932400465012, 0.1772689765259143, 0.09344772676066046, 0.021918995508683786, 0.04629987584907682, 0.026473438014246287, 0.015262552337991375, 0.03757152203170042, 0.04633806916254182, 0.08783732015158861, 0.02398874866025102, 0.02693890920659948, 0.02196131995128047, 0.0182272388689941, 0.052397828474039995, 0.06651587513906342, 0.09489756347911973, 0.06408827657240533, 0.008604138406113753, 0.08829471294678028, 0.01382103054634025, 0.04875776170182133, 0.02669466122414076, 0.034013254297596794, 0.08417577993485235, 0.05198501433516222, 0.04026163977781131, 0.0540614152146924, 0.06420426611458102, 0.027740947721946626, 0.03589288932421515, 0.019472911240412824, 0.01908266222134473, 0.04466587159362051, 0.03184177616100398, 0.009739076598517356, 0.02813026402896691, 0.08346074410984594, 0.07387208887526105, 0.03423831943843154, 0.053075724356477304, 0.007505553479742019, 0.016262366984700485, 0.0268229560536002, 0.10542891288716948, 0.027727290289476517, 0.08764983545387946, 0.0640708404112487, 0.03269459481441206, 0.029487067029901573, 0.03505786114762868, 0.06329271341523816, 0.14238062765329115, 0.04316423200972138, 0.06535958033055067, 0.04135883856384505, 0.026229157473050782, 0.1133981042151009, 0.040989944245666265, 0.021380948976823883, 0.02928392924067955, 0.035126652012789444, 0.09481812016137185, 0.03320405477537744, 1.3891615742637267, 13.631955327526217, 32.4704550158593, 46.216515033475815, 50.32105576607489, 43.80384552863337, 35.065867747029955, 33.14878186871929, 26.30042160710981, 29.80166062231987, 31.838104224974114, 11.248696734828334, 3.540527681189199, 0.4536927437349674, 0.20506938799254357, 0.1766107537813725, 2.022550199781695, 2.133579383934698, 5.224268080726747, 5.588454757967304, 10.18867717635247, 9.071971524146296, 5.999551021283673, 9.191372394561768, 7.88074181925866, 15.491384325488923, 25.539603387155843, 31.563142153524588, 39.14426196006037, 54.043655703144694, 63.46747167648808, 65.63374180947581, 61.4107023516009, 53.432703402734575, 54.32814521174277, 55.55990672880604, 58.315971897494414, 56.9846841596788, 57.8868136098308, 56.19704869485671, 55.843992233276374, 58.57081613233013, 57.71743782104985, 58.08800766544958, 58.14641960205571, 55.96467571873819, 55.620213170205396, 55.654992826523326, 55.72127696006529, 53.074139933432306, 51.71846682025541, 49.098041134495894, 52.09637149687737, 53.40789833376485, 54.17052868873843, 52.300954480325025, 38.67717435283046, 55.14424531690536, 52.69795325494582, 53.68114632944907, 51.904363632202156, 51.46582303508636, 49.3647740733239, 48.29468873239333, 45.3276510392466, 44.76502626172958, 42.40024889669111, 42.31342331055672, 45.655549418541696, 48.91799649884624, 50.12896553162606, 52.74298990926435, 50.94955282826578, 53.415797987291896, 55.94016874990156, 54.750964949207926, 57.00334679695868, 57.021221037833925, 53.89031456362817, 58.33718799775647, 63.89465308958485, 60.122227284216116, 55.06872007923742, 49.45609469567576, 41.27580734991258, 32.978943240258005, 21.065185108492454, 14.193584803612003, 8.661826925892985, 6.260297932932454, 4.967024335938116, 7.286518917929742, 6.891680388681351, 8.101407010709087, 5.859996032330298, 6.410721319337045, 4.24668840823635, 2.679257070825946, 0.6284918527930015, 0.27005944581281754, 0.7962341582582844, 3.2946029161253287, 10.84414347525566, 25.96273103067952, 31.26249247981656, 33.38593229170769, 41.72604445488223, 48.140865141345614, 63.64284869163268, 58.40410363289618, 42.578520621022875, 20.88157896072634, 4.055380196340622, 0.2615595777188578, 0.10991117075806665, 0.015063675912848164, 0.05843172082677484, 0.02126467023645678, 0.07297368224469886, 0.05061881526583626, 0.08002737552047738, 0.06264470262272705, 0.015070536230210096, 0.10589647932999557, 0.04236069004682284, 0.007000214114199363, 0.022483401210798372, 0.06572020089914722, 0.03552763009323709, 0.059689870855260285, 0.01412083809789751, 0.06364748107209321, 0.033028846636654875, 0.0630216829989466, 0.03393802063299283, 0.06242452895328884, 0.06626039247719512, 0.01509299984336981, 0.03288274600861534, 0.028595989945554928, 0.10505401243966435, 0.023451523757689906, 0.04882949434461133, 0.11413767783632202, 0.07683402993866513, 0.181323726691546, 0.1593662525016454, 0.1268234197050333, 0.1489052606085616, 0.2101450575695884, 0.20707229422705792, 0.11348435805449564, 0.09502196083626441, 0.08713801977254691, 0.14194712914045782, 0.136074498295784, 0.2477488816986161, 0.10555340217486506, 0.11727300757962851, 0.17057103916041313, 0.19249650619683728, 0.12845789893500267, 0.12589314381682104, 0.11127119898916253, 0.23143926815640545, 0.2253492522023378, 0.1638578719669773, 0.08613434500030934, 0.07295863627786599, 0.19001364587776123, 0.09274330891428456, 0.10379362160400038, 0.10851351228813011, 0.09717119752519554, 0.19593089368314515, 0.12141356725365886, 1.8710812565780457, 14.196979614996142, 35.377186267606675, 53.18053422435638, 57.37144162577968, 49.272402255765854, 45.10996341705323, 39.37570925681822, 30.59807827395778, 40.751884598885816, 36.48612268509404, 12.023303066530536, 5.87279325531375, 1.2038387766768857, 0.6093769784896605, 2.08302027756168, 4.843436335363696, 7.299626988749351, 12.155490863707758, 10.434696078300476, 10.139792676894896, 17.335303291197746, 7.540251651117879, 10.43406947966545, 7.897752158103451, 19.252236197071692, 24.831317470919704, 31.663484227272775, 40.51247489067816, 54.49612071437221, 66.96544924089986, 65.75153843049081, 62.59824698971164, 54.95311606314875, 54.29607983558409, 56.680755384506725, 61.56201562573833, 58.133997455719985, 59.932270819141024, 58.54960395443825, 57.214123202908425, 61.36191198902746, 58.331575086039884, 58.91438830283381, 59.87466296842022, 58.242341164619695, 58.01141946546493, 59.39971885373516, 59.39499632004769, 56.19384019605575, 53.284426043110514, 54.613187774535156, 54.55452872860817, 55.46091395039713, 57.2958497078188, 52.640294413412775, 42.82873253668509, 55.62412377326719, 55.1072181424787, 55.26061027280746, 55.45642283654983, 53.49355897595806, 53.173925030616026, 49.4873442188386, 47.450684885824884, 47.38611482804822, 45.77220462983655, 45.564005221090014, 48.67321706587269, 51.94160261461812, 54.41529243223129, 55.388683503673924, 52.654524772397934, 55.79745723355202, 59.01721715927125, 54.09321877264208, 56.31531992266255, 56.66111607705393, 56.652373113939845, 58.519338946188654, 66.45703946390461, 61.737761343679125, 57.495235550788145, 49.69449635474913, 41.91862106323242, 31.83003394834457, 21.682062149047855, 13.703038480974014, 9.105083192548445, 11.29233310299535, 7.847717913889117, 12.184990029181204, 16.668606265898674, 11.63468639696798, 12.952528249832893, 11.150772802291378, 8.155556311530452, 4.337476078541049, 1.2076888281491496, 1.0836916753361303, 1.8426098746638147, 5.09701511552257, 12.55442826978622, 30.449098810072872, 42.22818236197195, 42.5354020057186, 49.62262676608179, 61.49931653853386, 72.5731755841163, 63.419971773701334, 47.36674616413732, 22.644074424620598, 4.950991647858774, 0.418307387660588, 0.16232569611841635, 0.14416788013712054, 0.17342341432888664, 0.10651089716702701, 0.1327908156259406, 0.180004553929452, 0.20224886675996168, 0.19038742017601767, 0.111376375200287, 0.2210825255080577, 0.09331170784970445, 0.07715474498728592, 0.218678618210458, 0.21186572169103932, 0.22085769402403987, 0.2940836566830835, 0.11673072458154733, 0.12592298294147178, 0.11690506321047583, 0.2165534443432285, 0.10395395614567304, 0.191515147565834, 0.1664409365865492, 0.11002724073947438, 0.15367909154343992, 0.09972921873052275, 0.1531249188607739, 0.12448806961577748, 0.18514469746620427], [0.07865490602149118, 0.04066433389520934, 0.10063253598467958, 0.04545822101194532, 0.0209292252322719, 0.048849929739991506, 0.016905480560155648, 0.029800588512913357, 0.02057351911770961, 0.036704747171531764, 0.09068091595244986, 0.06527880401981455, 0.031871285867847265, 0.02424101949849677, 0.04107378490809952, 0.026431157621705247, 0.017675615343896132, 0.011071692288462675, 0.020137595936595913, 0.04627081430366924, 0.039229872561390364, 0.017986861545772805, 0.060652058135958455, 0.056402683333163305, 0.02211809601454485, 0.034838545496665665, 0.06899762463064925, 0.04329265898934776, 0.018966203450315425, 0.050354350223055774, 0.05393318358748671, 0.05075486865074885, 0.034320225728855985, 0.24790042921179728, 4.968830097106196, 21.198175030369914, 33.01418181388609, 40.367476632518155, 40.186502395137666, 33.5333388851535, 23.590069701594693, 23.41203724184344, 32.81338980120997, 21.957945977487874, 14.803903641239291, 7.1826114096949185, 1.1707713575132432, 0.331341699366608, 0.26528402141505675, 0.8684958000817607, 0.9003870597770138, 3.4005738362189266, 3.2469473442723675, 11.167894928686081, 6.2928771395837115, 5.065582221554172, 6.757405890572456, 6.253705899561606, 9.8532792252879, 17.041043158500425, 24.56437272410239, 35.38747856693883, 49.167498465507265, 55.56474301122851, 52.40841957830614, 45.67672237273186, 50.97884508871263, 57.59540111787858, 53.83690757136191, 54.17789097755186, 51.42271618689261, 53.33083944935953, 53.88033997627997, 52.86736042268815, 52.291807513083185, 53.96636147652903, 53.80508538215391, 52.467808185085175, 54.62769269943238, 51.73720006019839, 52.18368345691312, 50.671084157882206, 48.632546009555945, 46.460741412255075, 47.32978174763341, 49.260544930734945, 50.738819568387925, 52.410612183232466, 50.29768628458823, 32.00179061582012, 53.46678095479166, 50.92769345929546, 52.474405611715014, 50.99189089190576, 52.090185919115626, 51.94380306428479, 51.11956796338482, 51.25823159371653, 48.235264824282744, 49.72927208869688, 49.395662738430886, 48.5866464337995, 49.070655145952784, 51.656646343969534, 51.687362424788944, 54.403748896814164, 54.17514924080142, 56.13435353002241, 53.47901482735911, 57.0428882106658, 56.96560575116066, 54.238087592586396, 51.1636475593813, 50.9606296016324, 62.510166245122115, 59.25949412007486, 47.6807632753926, 36.75222019995413, 24.925511229422785, 15.653871451654743, 8.519262498424899, 5.764353938641087, 3.5801365106336536, 2.6692099196295587, 5.418646037578584, 4.672197911047167, 7.434079464404815, 2.2359645222463915, 4.422682706386813, 1.339488188105245, 2.9506750356766487, 0.2394340238383701, 0.268048832733785, 0.8799725939189235, 3.673741178166482, 7.979630654858005, 18.19892683336812, 31.15845749455114, 29.40711921261203, 35.94486305790563, 55.556423664093025, 58.33345390135243, 43.98606315735848, 32.029692396040886, 13.750103981264177, 1.941030232175704, 0.030950170475989584, 0.054372243898650335, 0.08494621923854274, 0.030039742010675614, 0.02302394327407162, 0.018943190169070038, 0.01834127488696287, 0.011164911782308932, 0.020615648207885605, 0.009692079977192467, 0.03114853936788296, 0.06048562553440852, 0.010923179441071566, 0.04791426059279231, 0.05815357728410633, 0.062494319563190785, 0.0073305382994153815, 0.0895628642531172, 0.102230227672525, 0.008921935617352926, 0.07726353713341298, 0.05848227496889811, 0.021147811184487036, 0.007756678537736017, 0.04606798869527636, 0.04094487912352047, 0.07462754349915252, 0.03363160844591837, 0.04104078184032152, 0.014901114928145564, 0.0698133550524231, 0.009516896736327439, 0.0477356088888501, 0.008829229402415937, 0.056325959627546614, 0.12326540094950508, 0.038508868911453796, 0.05534844675792321, 0.07353749231345232, 0.010100495813774967, 0.055573822164367286, 0.09001474887613328, 0.03878534238244738, 0.019785431063463612, 0.033724657485201474, 0.021746696588853677, 0.07115695069754316, 0.02766390417462155, 0.009795638785186795, 0.0136195877266507, 0.10283978085123724, 0.06403853065304219, 0.06076485692192951, 0.0749144357659163, 0.020233609736145988, 0.05186932739771662, 0.0922990698487528, 0.030656791359726942, 0.019421451199319095, 0.10940576723266034, 0.04471847119050161, 0.008641012133129181, 0.016936154720643838, 0.45576734047743583, 6.610288081630585, 25.395707315014256, 39.75986226912468, 51.274074046842514, 45.55181841696463, 39.147725412922526, 31.102438203750122, 24.901153310652703, 37.489515965984715, 25.238751711383944, 12.88467614881454, 6.820179993106473, 1.4421557370693454, 0.16275865836970269, 0.19644533704605796, 1.282386568284804, 2.363196404710893, 5.194871877470325, 8.41557268173464, 11.367329801282576, 10.757577746145188, 5.98356245986877, 7.270192542383748, 6.4549038775505565, 12.899674311760934, 18.747183968943936, 26.949309110641483, 38.9901912596918, 50.904543630538456, 59.74335770453177, 59.923833800900375, 52.66440130049183, 53.72763818310153, 58.19521388699932, 57.84396563806842, 56.48358175831457, 54.73489499861195, 55.56277790377217, 56.425671885090495, 54.812973699262066, 55.93312025070191, 57.47051677396221, 56.47000251277801, 55.767906096673784, 56.137409056386645, 54.94240014783798, 54.540788665894546, 52.675862466135335, 51.46916881684334, 48.09748764960997, 50.100426366252286, 51.296729656957815, 53.67584720734627, 53.2474341700154, 50.741329885298214, 36.88936979539933, 54.609736088783514, 53.784845952064764, 53.55025291442872, 52.01704548251245, 53.533288663433446, 53.43162867330736, 52.65561519130584, 52.256133556365974, 51.26915539464643, 49.91149363979217, 50.53617423580539, 50.20133718367546, 51.00963569456532, 53.06316906406034, 53.83214581397272, 55.06596265300628, 55.60804990030105, 56.02267580647623, 54.37730427711241, 57.46911256544052, 55.67960962172478, 57.078091482962336, 55.90046651901738, 56.26985965236541, 63.10382089307232, 59.59899487033967, 48.76356886279199, 38.892857643865774, 28.325290295385546, 20.467684576588294, 10.677367237306411, 6.543410199303781, 6.031833598690649, 3.9487562016133344, 6.332515141656322, 9.080783128738403, 10.578288166753708, 4.0567868563436695, 4.4929402009133375, 4.222363339316461, 2.1124785032964524, 0.577057138566048, 0.37006398122156825, 1.009301718684935, 4.154385232156323, 10.25261082956868, 22.76350275162728, 35.31757800809799, 34.39118869843022, 40.95229418047013, 61.68475051080028, 65.57894629816856, 50.43886023183023, 36.58852008081252, 16.902250089953025, 2.664536415569244, 0.12819152250285112, 0.07762017404480327, 0.0907592790862245, 0.059505687996504776, 0.034210839864587596, 0.13068957434546563, 0.030069546661369746, 0.06997280859298284, 0.03296327717121571, 0.03495973294540759, 0.0707600482048527, 0.03702569970740907, 0.02328079531810457, 0.034550783720107815, 0.08531891335282596, 0.028058090885620446, 0.026161318472135934, 0.06638812997768964, 0.02869648152902242, 0.022817944146452412, 0.04698873444971058, 0.007307030412653882, 0.02099939314047656, 0.03185073555927844, 0.03900386513240876, 0.028629745694718538, 0.021135797010614507, 0.046354574526870446, 0.006440509319110143, 0.01616888127530054, 0.17253534988530222, 0.15262064914549553, 0.16971277553708325, 0.13816326766485168, 0.3040559151239934, 0.18338145417792184, 0.1506229523088663, 0.12104648090298138, 0.1912331046356309, 0.07588577396687, 0.14190591361013152, 0.12694154280207812, 0.09911693827880007, 0.10289894582162942, 0.13204942637633893, 0.14183028541024656, 0.14226767564973525, 0.1678291185488624, 0.08435703633773713, 0.13657749630510807, 0.19331039800759287, 0.1804773527528009, 0.21535189672102853, 0.22177635601932005, 0.1344967095722114, 0.12671813624159944, 0.20803641587976487, 0.15271432637687654, 0.13934236891087026, 0.19228549493897348, 0.18060527411439728, 0.18077929864727682, 0.14495917235410985, 0.5760244520441179, 7.477994320854065, 28.29031059818883, 45.127002193081765, 58.23064073439568, 55.04488775807043, 48.76031329554897, 37.4274326908973, 34.60097274472637, 44.776357989157404, 31.332504826207316, 21.523433654539048, 9.74137890723444, 2.169941471469018, 0.6543138575169348, 0.9647256977135136, 2.84536944762353, 7.333999699161899, 10.23230177740897, 15.78475506074967, 21.69482554158857, 14.652057905350963, 10.592063530798882, 12.183859405979035, 10.711883114230249, 14.220198085231168, 22.145323484174668, 27.003671200044696, 39.56781518074774, 53.32995299370059, 60.647338513405096, 60.734018971843106, 55.06924567684051, 55.31196194310343, 60.883488731999556, 57.964864853889715, 57.47080310698479, 54.14236214853103, 56.569544423011045, 58.048764351875555, 57.19216185231363, 56.958235617606874, 59.16454138294343, 58.85860435424313, 58.26083906235234, 60.05259736891716, 57.72821649428337, 56.510748094128026, 55.15305888268256, 54.15219553055302, 49.952792275336485, 51.884128124483176, 53.847650943263886, 55.762038230896, 55.001204321461344, 52.54864823433661, 40.9741613941808, 55.8440157674974, 55.35205641100484, 56.91693698206256, 54.400752206002515, 56.610070351631414, 56.01039094309653, 56.022448309006236, 56.16223373720723, 53.24114661062918, 53.302398343240064, 55.09965973515665, 54.23802091229347, 54.391483645285334, 56.22571729844617, 56.14275132456134, 58.5815320476409, 56.96921040934902, 56.17999422934748, 54.474488842871885, 56.74765533016574, 55.88802476083079, 58.95127819430444, 60.32875968563942, 57.68625890055011, 65.8454478171564, 64.78568615451937, 53.85007104566021, 41.77275203889416, 29.478100384435347, 19.80199952279368, 11.42315101238989, 8.15647610733586, 7.940013245228799, 7.651669517640145, 10.82139470884877, 13.790610298033684, 18.424720033522576, 10.620328130260592, 14.21549516339456, 6.473491989797162, 5.365721006547251, 1.389335874588259, 1.107294415273974, 1.5030044461450272, 5.292942898888742, 12.424494854865536, 26.61758642042837, 41.871976237143244, 43.12574617324337, 50.66437690488754, 69.44118653574299, 71.18229527627268, 56.94349142812914, 43.12256120866345, 19.21000207624128, 3.7389991216121183, 0.2408108830211624, 0.3011192549620905, 0.2014158074293406, 0.1467324820377173, 0.053269965949678616, 0.19283690970511208, 0.12339110065612102, 0.10705815207573677, 0.12328500513948741, 0.11772908270359041, 0.09138832154173045, 0.2740768108877444, 0.1588280450913214, 0.07517774784637075, 0.14893253333866596, 0.13582714382679234, 0.2095470033706196, 0.14577462698423094, 0.22775334336103933, 0.1480408989253544, 0.1938274001041728, 0.17022927201563315, 0.10077930310921324, 0.15261468898144462, 0.15433424993628456, 0.12304395557411256, 0.15094625673467113, 0.17498298548161986, 0.2372702851050323, 0.10689948760573903], [0.017077388775144375, 0.009067651286210504, 0.010938437997303423, 0.04692445584242383, 0.06288983543673832, 0.03677567159156165, 0.02286499918198153, 0.03609211814980354, 0.08785369911140974, 0.047572478126253814, 0.011107350808508214, 0.01900876921060826, 0.06365780793731252, 0.06280080835905767, 0.024852598979768735, 0.05307040387584318, 0.05667883887766831, 0.1156938782021884, 0.03701759449717018, 0.0929828186429316, 0.12419013036114555, 0.0695237048691319, 0.06001310250271232, 0.05679105543681691, 0.0035063494766701857, 0.07285642482700848, 0.0234131868027391, 0.03844896849665431, 0.006192961412917582, 0.0606390729456419, 0.03859940135190564, 0.01798196049827722, 0.011188541764333364, 0.08863450358471564, 2.4782348640503424, 14.027827401315013, 26.461880091697942, 39.2809683276761, 42.704456160145426, 38.77198980700585, 34.20263251950664, 28.9569801668967, 31.897967438544, 28.002996983066684, 22.162748613665183, 9.582569983697708, 1.1149116581486118, 0.6057329740255111, 0.06226686422803229, 1.3032929238773163, 1.6580850342589042, 3.9117925205538353, 5.181483847479667, 11.675859516666783, 7.496220104156002, 3.340624330505248, 4.46026832826676, 3.8240939619079715, 7.25408778075249, 13.720975479772015, 20.618060404254546, 27.25283976524107, 38.310675928669596, 41.827673066046934, 42.25095172082224, 52.94388586475004, 60.693602869587565, 56.191930001781834, 54.48304745458788, 51.426732693949056, 50.77547411764822, 49.504873291138686, 49.99826823511432, 50.79663922709804, 52.33214909030546, 52.219981070487734, 50.90594783906014, 50.14905198927849, 48.89166955024966, 48.198861306713475, 47.12228052077755, 44.90283873773391, 46.651270543375325, 45.13374474740798, 48.5853285174216, 49.8095473166435, 52.799891733354144, 56.133129750528646, 50.00766231167702, 33.42487358277844, 52.910957567153446, 52.03619057132352, 52.03646121486541, 54.50689154286539, 53.875499771487334, 54.7413198409542, 53.31531078584733, 51.881762935269265, 52.704778179045654, 51.447285913651996, 51.17431248387983, 49.918220504637695, 50.88907772494901, 53.141459572699766, 54.70495946945683, 54.115733177431174, 53.187723928882235, 51.32850870009392, 54.110351685554754, 54.09534469727547, 57.82126688188123, 51.259043524342204, 43.06759703543879, 52.3258654532894, 49.177072971097886, 48.02435113537697, 46.96834710336501, 39.66261494544245, 27.130734420591786, 15.10179686930872, 9.540778110104224, 6.390177905559541, 4.698570457197005, 3.3875655406905762, 5.352789442385397, 6.881024289515711, 6.33827563255064, 3.434060581268803, 2.602635040398567, 4.358473996962271, 0.9660478428967538, 0.5456271863752796, 0.35428606334232515, 0.8631824593870872, 4.41684082631142, 17.607860949731645, 27.79301681826192, 32.7791278977548, 42.11545736558976, 39.62659974252024, 50.87107012348791, 45.71545970055365, 46.69678964922505, 26.341563347847234, 10.38553701293084, 1.5880326061479508, 0.042650604530447916, 0.010735982026334011, 0.022947874573630192, 0.014212650862792808, 0.03620626525052133, 0.024201512344241626, 0.07837353724866145, 0.04581004689117113, 0.034867898155484474, 0.01502539449927187, 0.05922489378961825, 0.055128047092547344, 0.03180516864954224, 0.0678122261418931, 0.01953187128228526, 0.050849285156976794, 0.00950945323453315, 0.018095747537670598, 0.0781814713451651, 0.01622130275673924, 0.09319781355800168, 0.06827952445394571, 0.023306011102132262, 0.044603607797574614, 0.10700664798458738, 0.09528617690046949, 0.02605436685224695, 0.003227279446418247, 0.06155910240786691, 0.027452530940213514, 0.021216693980198716, 0.009715161248741132, 0.05181362897518182, 0.007731127590241452, 0.03477453502015241, 0.05461557640603954, 0.009048323845490813, 0.021953875491876277, 0.07922653784795154, 0.07765655556032736, 0.002724945539563534, 0.031172291923975273, 0.05949600464514187, 0.05348890621755874, 0.11065682711740656, 0.029203095473349098, 0.06005648223142471, 0.020203060064945492, 0.034212230314170165, 0.02165102944408934, 0.0312535144809273, 0.05952819182928051, 0.026287870451567635, 0.10138913974045746, 0.016982012743791266, 0.012164321360028079, 0.05268137676701431, 0.046434546445286086, 0.02674932542797779, 0.034065715998651526, 0.013581065952988162, 0.023912335220243663, 0.029974952039699403, 0.07884116497852149, 3.4822542532797787, 18.450433131187193, 33.995343100640085, 46.334550919071326, 49.78756243182767, 43.461191192750015, 38.22872977102957, 28.942496815035422, 32.642692173680956, 30.26148792236082, 22.272527910047963, 11.08158415363681, 1.9493804679762934, 0.32496125948044563, 0.15170486764081065, 0.6432924876289984, 1.8571525523739478, 1.4317425797062537, 7.353362479517537, 11.490852102156609, 7.746603133216982, 7.293100655078889, 5.029655271960843, 6.058216441062189, 10.356388899587817, 15.948373790710205, 23.285831059179, 32.73688593218404, 42.3469203518283, 48.50579461743755, 48.14508561165103, 53.95418251714399, 59.702270876976755, 58.24178418805523, 56.34336094702444, 54.53275565178164, 52.445164342080396, 53.055783241025864, 51.85864448547364, 54.39566096951885, 54.33154982905234, 55.845008127151004, 52.66103198451381, 52.40322243782782, 50.41806382517661, 49.56625838433543, 48.349099851423695, 48.404852421053, 48.07859751486009, 47.33291572140109, 49.94354332647016, 52.772541046142585, 53.73008181971889, 57.60957264131116, 50.43938582943332, 36.99270855995917, 53.09296338788925, 54.480933297065, 52.985058984448834, 56.913218575139204, 55.987845159346065, 57.34961755814091, 55.63181161880494, 53.23831073699459, 55.14764208947459, 54.36807101772678, 52.74130329009026, 53.38179103789791, 52.92007707780408, 54.148249626159675, 55.88790708972562, 56.97481939869543, 53.138023576428814, 53.67784369376398, 53.958485357223026, 55.76836109161378, 59.06411693942163, 55.72679965726791, 50.31243439643614, 56.62575198758034, 54.86557268327283, 53.606950775269546, 49.99756613085347, 41.64911500869259, 29.607054187405495, 17.780166749031313, 10.427778978501598, 8.541730815364469, 6.193397987273432, 6.77637888539222, 9.130442296305011, 7.330342088976215, 7.309224538264736, 3.390422251916701, 4.589266257901346, 2.585521003892345, 0.9763248204704255, 0.43574054575254845, 0.14161550499979528, 0.9854510114077599, 5.254619381120128, 15.114613213846761, 27.228740722902362, 35.13281868350121, 42.08121507398544, 44.01259014683385, 58.142767875425285, 54.46643621690812, 53.70545717977709, 31.01529686681686, 12.806734731120448, 1.795229726741391, 0.028279112997434797, 0.05132093484843931, 0.03502070588330108, 0.07697483689914789, 0.0055441438340612, 0.015038363410220032, 0.021238778379835913, 0.06449780036364833, 0.025219970698198004, 0.04471889253885997, 0.07055084491449018, 0.015735739950961884, 0.03761447275117521, 0.042945019780628146, 0.10268710718880739, 0.06125001274349709, 0.06436607920594754, 0.018936456256215612, 0.06852048208876964, 0.053889022449091564, 0.056844543695690176, 0.04831611584391325, 0.023284198663708185, 0.022232582109169136, 0.0587859905264791, 0.04241274572127769, 0.0525713244062518, 0.06978861807334809, 0.049961925514282725, 0.02620519998843872, 0.11411084177633447, 0.06474187597632408, 0.1269914381085865, 0.1500623751311533, 0.282136025207658, 0.17408082502022867, 0.1848566637284333, 0.10490666308830823, 0.21314747871891146, 0.23291017229278244, 0.09643280367937782, 0.14721770680719806, 0.16064059379841053, 0.17811283769626773, 0.13761191418574703, 0.1290877457828291, 0.16077324958337894, 0.12965388475887238, 0.06731832159623023, 0.1821426900043603, 0.23949590842089347, 0.17788904809182693, 0.13817431465271982, 0.20102966847198628, 0.10902735810246199, 0.16949044149969855, 0.13958344145888282, 0.11660766787827016, 0.07607430820503543, 0.18024406365809903, 0.09087670504325822, 0.130497562068124, 0.11956905735836876, 0.28990332938490376, 3.7688775312516, 19.98740996083906, 39.36715848984257, 54.0851543795678, 58.176378665431855, 51.31206612433157, 47.140527386819166, 39.181959859786495, 45.343164013278106, 38.74446653550671, 28.57834592942269, 13.306129920867182, 2.0955301869300107, 0.9110341497486638, 0.6346906072670414, 3.6947199750331143, 4.151804312582939, 8.18277559934124, 12.557283755271667, 20.07767350442948, 18.893598202736147, 8.751930632898885, 10.036854974685177, 6.884884882357813, 12.630751709784231, 18.120297039708785, 26.807603682241133, 35.49306877197758, 45.473778940016224, 51.72905329735049, 51.868850492662006, 56.7344565545359, 60.73206955386747, 60.06287005639846, 59.37833801392586, 56.842615912037516, 53.615709427864324, 55.15282746284239, 53.94145050356465, 55.50602120737876, 57.65677052159464, 58.50192362262357, 54.74229258875693, 54.654839423394975, 51.83998184819376, 50.59243671355709, 50.880801523885424, 49.349876911409446, 50.87968757075649, 48.94830465316773, 53.6562628130759, 53.53317491469845, 54.87345272494901, 57.77331198415449, 50.5341895164982, 42.33001885875579, 54.34881610255088, 54.52179262715002, 55.697625067926225, 58.9714313322498, 57.227223919283965, 59.29160264230544, 58.49654605311733, 55.48969238035141, 57.44833184826759, 56.7598460566613, 55.80098344433693, 55.8390578915996, 55.60818718325708, 57.411567472642474, 58.11058090579126, 55.87115464671966, 54.808231553723736, 53.884481999181936, 54.571614573078776, 54.67638500275151, 60.318447774456395, 58.39399176259195, 51.840201500923406, 59.69901923210391, 58.41617668828657, 57.033698097352065, 53.74359830733269, 47.00365235728603, 36.80078698742774, 23.89290217430361, 14.831170978084689, 12.048010076245955, 11.78684494187755, 10.301489445470995, 13.728520158798466, 15.083586285191199, 14.730973051440332, 10.297180721836707, 8.156339804972372, 8.93672525882721, 3.0676153542534, 1.4030786339313754, 0.8314643968497554, 1.2736530433739386, 6.801618847154803, 21.574685304395615, 38.580738959773896, 44.10566406865274, 53.880700834335826, 51.695293457277366, 67.72704016777777, 59.630507192304066, 61.127091453921416, 34.55299823514877, 13.937797238749843, 2.2218932644013436, 0.20704693671676422, 0.10497501345291253, 0.14994182353538854, 0.14010533119641966, 0.14966571012571936, 0.09267396263537869, 0.17784078455259725, 0.14783920329664985, 0.12747480128441127, 0.0915855585387157, 0.2437340906791149, 0.10295660925969001, 0.1419505612143586, 0.19061402898401986, 0.15322719159866535, 0.10989465390241916, 0.0919622975972391, 0.08877381667374604, 0.09563160594552757, 0.20277754403650763, 0.13967714933378084, 0.1538971354884486, 0.18523092832296126, 0.16229797905731588, 0.22727280704965516, 0.08726058617955254, 0.15842230960486398, 0.11688091611910252, 0.21141181459590314, 0.09004260383306012], [0.013544856807247046, 0.023993349018236323, 0.03316460124727699, 0.002400498685141605, 0.020625362202765483, 0.02631401703242333, 0.05582816718566803, 0.07435061803628361, 0.031227668589581887, 0.010171064002920064, 0.05640099410929027, 0.030564975722001928, 0.066306296465618, 0.1220313711993156, 0.0168790735094057, 0.041828316396042224, 0.02782598348154176, 0.010033618253205093, 0.02975074683255967, 0.03423025636302848, 0.01179999388348792, 0.10491734235397271, 0.05244935171738748, 0.033540807874693025, 0.031371472869068384, 0.035845253977083394, 0.06614168715332785, 0.05059085305660002, 0.030997556844545953, 0.04521330270255285, 0.030007606537471858, 0.0464933590152331, 0.03049268191980739, 0.0203964953506065, 1.1193807086636944, 9.953918418576642, 23.25556605092941, 40.94657144238872, 43.65629380749118, 43.1580312021317, 35.92603568107852, 36.58542140837639, 33.16182767191241, 19.72269900383488, 17.79950599516592, 10.246148724709789, 3.9939870132553965, 0.43283128089481787, 0.13172230683267117, 0.057077809807754336, 0.628967133741225, 0.8101767133320532, 4.774244744931498, 5.9259129339648835, 4.256069737095987, 5.993512042107121, 4.83571465938322, 3.953324291975268, 9.691500086938182, 9.906000783366542, 17.513929990030107, 31.651118955304547, 36.183656953996234, 38.18252032802951, 47.726866814398, 57.738053798675544, 56.000612474256954, 54.70086059262676, 52.53818335071687, 49.48554385092951, 47.54488452788323, 48.75180959701539, 49.22815792022213, 48.26225073106828, 46.76252857331307, 46.94093365823069, 46.27556631642003, 45.116105848743075, 44.88037140138688, 44.07921944895099, 44.286187233463416, 45.02904884276852, 48.764514154003514, 50.081720582900516, 51.5476672111019, 51.724981877111624, 51.69740761480024, 53.731129092554895, 49.196241594129994, 32.30195195444169, 50.57311904045844, 54.859485164765395, 53.07281809468424, 51.88799165910291, 54.00198836480418, 54.59643140915902, 54.25081176142539, 54.891005331470126, 55.23596209864463, 54.486240263908144, 53.09092375539964, 53.72314706925423, 53.912424964289514, 52.89993178459906, 50.86970513866794, 52.58077244604788, 53.08564816751788, 54.0118609705279, 54.68339035587927, 53.914382227005504, 54.94048210882372, 52.95197771441553, 52.29165061827629, 54.78486207223708, 55.76561151012298, 43.27867938626198, 35.431307131244296, 29.07872465349013, 20.810703692897675, 15.66310961400309, 6.153239780856717, 4.062422076540609, 5.449271413587756, 2.872981707895956, 5.5135404294536965, 5.847985734862666, 6.062841896087893, 1.8398085669163735, 1.8789291838484428, 1.9198463688935004, 0.5206423625349998, 0.2846276495725878, 0.22046193300235659, 2.1706680905434395, 6.35005941314082, 17.056928757698305, 27.800775266462757, 46.7595358048716, 39.03005038538287, 41.036652595766135, 49.26099600330476, 44.9839533528974, 40.99215330616121, 27.221986401465635, 5.911289847666218, 0.7397761748683068, 0.07704321024638992, 0.04154799716366876, 0.027265745297735258, 0.07527341690635489, 0.03509487851612991, 0.03691679647853298, 0.04164435953322438, 0.017492621836643067, 0.04215442853408956, 0.03663385722545847, 0.04737202355998659, 0.07509456601955238, 0.0945664219738495, 0.051000135530146866, 0.029493182326757142, 0.035650862996736844, 0.03467340375326815, 0.05285499527329399, 0.05961570588331069, 0.07282692278104444, 0.030267434833090634, 0.0603608068289055, 0.02659370807269889, 0.0475354454359941, 0.0349665166539771, 0.04156176376366808, 0.03304362447271424, 0.08141528169113783, 0.034234818416617574, 0.13702801729161895, 0.015272014481466145, 0.030892698559910062, 0.12210990287243359, 0.05297788343722782, 0.027291706102269313, 0.048774535196923444, 0.03078169625012144, 0.06525942965620948, 0.03759894031851042, 0.031383661327943686, 0.030065210603718317, 0.062393100196195234, 0.07243496921634482, 0.06061856094146929, 0.009528441681346346, 0.010435439030369444, 0.06413796886561379, 0.011265929093614463, 0.054006318171178146, 0.03398883907544998, 0.04638115777784298, 0.12738499279704787, 0.055396514944732196, 0.03621170447478372, 0.02671013045455179, 0.06885684831368347, 0.07889984731352137, 0.012894786195829512, 0.012248675301370603, 0.05808117431438258, 0.022581657732746774, 0.07094021676288498, 0.021154573825638623, 0.014487053023561116, 1.5516509067627693, 11.698405300417255, 29.333798346980927, 47.29127191728162, 51.569856059166696, 49.16872224500103, 43.19230095032723, 37.0427187796562, 38.836485339749245, 29.132508193292928, 19.56293890553136, 11.84673757322373, 3.17048343439256, 0.43727498922136526, 0.11751092384539305, 0.3345255301364007, 0.6660516115446246, 3.0115855220825445, 8.015750290886048, 9.630415055059618, 9.273651953666441, 8.73120580950091, 8.042165983107783, 6.097555852705433, 6.608487713721491, 13.488452472994405, 22.121957925058183, 33.38948203671363, 40.93518480177849, 44.31265146501603, 50.94563045809346, 57.90781005736321, 56.69561332271945, 55.57428613785775, 55.8807134628296, 52.46895743954567, 51.676450390969556, 50.72971966958816, 52.0297186605392, 51.246005565889426, 49.84888476710166, 50.72442054748536, 49.90095815350933, 48.54648136323499, 47.036482595628314, 46.511853817970525, 45.305634775469386, 46.74786675360895, 50.67473588451263, 51.28784156614735, 52.639615843372965, 52.647476273198286, 54.352718860872336, 54.513104577218336, 49.021056775123846, 36.4314095435604, 52.452597233556936, 56.297539818671446, 54.237318808032626, 55.460811968772646, 55.403906222312685, 56.04344083416847, 55.15460821890063, 56.73802591139271, 56.037196420854144, 55.60885398618637, 55.594988407627234, 55.32670221021099, 55.91893696015882, 55.963836331521314, 53.892809191057765, 52.1468916246968, 53.38429351006785, 53.90179141875237, 55.620091576730054, 54.686108558408684, 54.901113279404186, 53.525675342928984, 52.913565943318034, 55.948578311551, 56.788063587680945, 49.83572129280337, 43.29220371861612, 35.42372911207138, 23.992899079476636, 16.18984568503595, 7.925566175291616, 6.414375497448829, 4.640205098736671, 7.922469464040573, 8.890222618656775, 6.472373133705509, 7.855318976986793, 4.320899651896569, 3.738221511725457, 1.9208632433606734, 0.46039769846585493, 0.14356044902195855, 0.2910938300192356, 2.0009137930408603, 6.526055672476369, 19.41992928904872, 32.12815761566162, 48.47460000745712, 43.28038169491676, 45.87935986057405, 57.76451803022816, 51.0775044656569, 47.46879446891047, 29.288593030744984, 8.298087889148343, 1.073857312721591, 0.0459504631468125, 0.035819938601625544, 0.06012315486347484, 0.1718125459287436, 0.03371699277551905, 0.07461292654155724, 0.06622094660997391, 0.026751857348567536, 0.03093822525003024, 0.0193114735321292, 0.051133208833034, 0.022430179167478796, 0.030103505423833287, 0.04550227106759145, 0.034612193328118136, 0.09410495359090068, 0.0681912174989139, 0.02614065708081809, 0.06078756759844481, 0.04262566453807297, 0.029423487477845726, 0.020467040557113868, 0.025155644210415985, 0.015179621404968204, 0.02616425641932555, 0.07685198703961027, 0.046558227510221546, 0.006067117107205935, 0.0737089274691478, 0.09556308704157991, 0.13472538681760912, 0.09865761494203922, 0.21847278570696232, 0.10457191330891465, 0.09134101561240612, 0.27132410375821975, 0.1632822947877069, 0.20563021031839235, 0.08599280259541928, 0.08050286331244054, 0.12265296728019753, 0.17311575341849558, 0.21177319359154473, 0.22765629534279147, 0.08199569288521044, 0.09504480557816644, 0.09354908019304277, 0.14287849287352256, 0.11447395213068494, 0.09832737742051964, 0.1291653658113172, 0.23899176127968297, 0.15539632359099004, 0.1953603573624165, 0.09671657796828978, 0.14128933540515362, 0.22740989082282592, 0.11284255257417118, 0.12237885336001074, 0.16373663089208065, 0.09463716253277757, 0.08048073103230807, 0.14812048013892867, 0.14020939658005394, 1.7577300292830316, 12.72809022857297, 33.16046660946262, 54.64300955495527, 58.19086005610805, 57.67623332238967, 51.10554941238896, 48.403295240094586, 45.333503215543686, 30.864705308791134, 26.552386822239047, 14.414041619147024, 5.920239225510628, 0.8740805810497654, 0.6453547963211614, 1.216488175334469, 3.640803319792594, 6.04806681794505, 13.785110154459554, 14.950534585983524, 14.651240091170035, 15.841422523221663, 9.982682139642778, 9.01868514476284, 15.311613275158791, 15.01546746300113, 25.423385520135206, 38.89696436543619, 46.855155344932314, 52.977708462745916, 56.16932930484895, 58.01201566573113, 57.809899853121856, 57.94481761993901, 57.09993516245196, 55.31381330182476, 53.35314596852949, 53.999725157214755, 54.367808218925234, 53.91195035749867, 50.91480455090923, 52.437958948073856, 51.428799783029866, 49.440283621511156, 48.53107429319813, 47.234036691727184, 48.271366319348736, 49.43674172124555, 52.72204053017401, 54.37298182518252, 55.11709074820242, 54.923117776070875, 55.23103167933803, 54.920034793115434, 51.12980927190473, 41.534664169434585, 53.480944633483894, 59.45218447716006, 55.62466506035098, 55.7363231720463, 55.438458381160615, 56.46624488215293, 56.232471619882894, 57.762639214915616, 59.78713920039516, 58.33059841586698, 56.36148229722054, 56.24895734171714, 59.001998363002656, 55.80509801064768, 53.071256991355654, 53.16776690944549, 56.00864941074003, 55.916093241783884, 57.051011439292665, 57.471167887410815, 56.72601561392508, 55.23072965683476, 55.88649111409342, 56.602347204762125, 58.86739046342912, 52.01821042645363, 46.33699847805885, 38.919008085804606, 28.978045255907123, 19.113980493237896, 10.570028635763354, 11.2006849627341, 11.457229545039516, 9.00350949456615, 13.996357244829978, 13.584931992715406, 13.209447418489765, 8.923070507664836, 7.271143226854264, 5.267941221114128, 2.574408684046038, 1.4582123270919247, 0.5583655738061475, 3.0894815873715187, 9.049670888531594, 24.14025664329529, 38.34739323585264, 58.548164444585005, 50.531369332344305, 56.28960094144268, 67.40975179979878, 60.00339515747563, 54.585821397842906, 31.480403677109752, 9.214715400049764, 1.3916852517474083, 0.15829230448411358, 0.19450172601688295, 0.09252528795191357, 0.16074893395266227, 0.1470720428492754, 0.14916998995167596, 0.20316584336180843, 0.10958785101050332, 0.08015714315397125, 0.06928336776552663, 0.1566612420062865, 0.18470517750228607, 0.21081846417678943, 0.11045456458363803, 0.11391783358469126, 0.1698921013983988, 0.1617537961611825, 0.0760198929797738, 0.2601048686812001, 0.15548235526488674, 0.18854378362096127, 0.15750963841715168, 0.1294661472521482, 0.12196438447121652, 0.08680598960528452, 0.2043616453245763, 0.13158508516367406, 0.15380106806274385, 0.16751516039573378, 0.18764488669412752], [0.03935139325837936, 0.01746670508216466, 0.04564946337092308, 0.05227175721478078, 0.1266115657504528, 0.01775493225713651, 0.03659933347315077, 0.07246881498083954, 0.07336481609531949, 0.04243277892049763, 0.10252029154329531, 0.033138787914668365, 0.04902012000281004, 0.04070228589097819, 0.00949616639709641, 0.02160494159456463, 0.07215074293555752, 0.040697532315408035, 0.03591135587362993, 0.031094336732020302, 0.0553274865923149, 0.03270359634752235, 0.04496772938798513, 0.11537186080409635, 0.05744286602543247, 0.011392544275299918, 0.046443567130594485, 0.04532243575780623, 0.062063747506228194, 0.029702088758048993, 0.016810905090683413, 0.04740688439098097, 0.025816559754011613, 0.05748216250550844, 0.2789136448935155, 6.071010231971742, 15.308806819300498, 32.367524177797385, 45.867812402786754, 53.073590801608184, 36.62480200490644, 30.923268256648896, 28.413135697764737, 25.82294168010835, 27.590869626691266, 14.069840888823233, 4.973328565397571, 0.8874455058286268, 0.21255104862634214, 0.13318352761768526, 0.15751457202338404, 1.5597784254820117, 8.013703794248643, 10.321579825493599, 5.69921366630062, 8.627566003030347, 5.132567969060713, 4.786052059742713, 4.915866332669412, 11.88952769002607, 20.560534923307358, 23.654751546921272, 30.989287630204235, 40.971654999640684, 55.66356712772001, 55.31953603990617, 57.02431186552971, 56.282850542376124, 52.671226224591656, 50.725001058270855, 49.0025314208, 48.24549044332197, 50.21586956516389, 46.49371285592356, 45.97869780755813, 46.006978096500525, 45.30119073006415, 45.7007743466285, 46.4522651703127, 45.82580774061142, 47.894673655110026, 48.67079696347637, 52.07737938050301, 49.42651610220633, 51.90743877041725, 53.063910392022905, 54.53526204632175, 54.20991320763865, 47.869339066167036, 31.23687351903608, 52.4914522324839, 53.840520074290616, 51.838381521163456, 51.23118292900824, 55.41554389461395, 56.26902418751871, 58.005461385173184, 55.06222463423207, 54.488272051657404, 50.26849992813603, 54.06309889208887, 54.016022605280725, 49.976663820205204, 50.69637167838312, 51.531471744660415, 52.42265778203165, 54.23664808273316, 54.42267433289559, 54.53608966642811, 53.36960031140236, 56.60982716468073, 56.71178525493991, 49.603309092983125, 55.264740528598914, 57.27800684590494, 53.37379332511656, 42.287853379403394, 33.51288764707504, 19.48619184955474, 13.385192155838014, 7.101614955932864, 3.6949075133569784, 1.5559413668609436, 8.49878478434778, 7.980201359718078, 4.574353896802472, 6.84505517444303, 3.2230789863294174, 3.1233458605504807, 1.3093321482020042, 0.1504551484099319, 0.3401867360357316, 0.3052468447675628, 2.3562881302449012, 7.373141031111441, 18.508237100416615, 26.12310890228518, 33.37653821514499, 40.09058475494385, 49.86864959039996, 36.63029724551786, 44.15437990619291, 33.20422457110497, 16.666507797856486, 4.923511032135257, 0.3417511488641462, 0.026817264020322796, 0.03380463323405674, 0.0827967297405966, 0.04769094979330417, 0.06978890918675931, 0.02210582903165731, 0.020113079207799128, 0.036504966762637904, 0.0323373373718031, 0.06706494567615372, 0.05455905443898613, 0.05510920516004967, 0.05081796748263221, 0.04636089475224576, 0.06466063235195414, 0.024929338007143913, 0.05285569241330509, 0.029091350058273926, 0.03756790609669782, 0.028973983473054347, 0.0808814179993445, 0.05234577279958514, 0.0736344024358738, 0.03191060150012134, 0.0699946727423418, 0.012706047986754248, 0.068506799758442, 0.04996890457527292, 0.0521194014788395, 0.012394369902810263, 0.03721260217829578, 0.01964560086508432, 0.028189739264968424, 0.021855245502064788, 0.047168144580697825, 0.0648956681271234, 0.023547413067952282, 0.04991995921779064, 0.04666126250559765, 0.06009703892613611, 0.053521250449721856, 0.07738990333652304, 0.0026666316449747334, 0.06107349459442401, 0.04272285811302643, 0.11573186850235348, 0.07379752553759084, 0.040532972798832965, 0.06986868958319388, 0.03941104469460346, 0.008683193891849971, 0.023465772993081523, 0.020985586320861213, 0.10768421444921725, 0.02038493699904892, 0.0370394318334518, 0.03493323013366711, 0.016525512441031395, 0.09674788032087589, 0.01742825704446483, 0.036666649619057294, 0.08088724026756902, 0.00941550691476873, 0.019674740934504137, 0.4181048033698913, 8.56369314655181, 21.9086790469385, 41.168032384687855, 50.27729388206236, 58.90222503292946, 42.33606323119133, 35.6662178808643, 34.09805428597235, 25.074455391976144, 29.976755226812056, 16.81271218484448, 6.164930405155306, 1.0797147597036054, 0.11681785176117575, 0.1696407326286839, 0.6125515242738109, 1.8759297964072998, 4.52027568894048, 8.38463596759304, 6.793063177216438, 6.9837830335863185, 8.177448530350963, 6.738536348265987, 8.346413450856364, 14.363198876380922, 21.82928046872539, 26.421293366339903, 34.10763271393315, 44.26471225676998, 56.954811388446444, 55.51712543733659, 57.88206361955213, 57.12099436790713, 55.28029664870232, 54.536317163898104, 52.46894959480532, 50.376051318260934, 52.235399907635106, 49.211177979746175, 48.216206027615456, 48.107364177703865, 49.05319275394563, 48.0189617987602, 47.04730049256356, 47.21653899838848, 48.80800931684433, 50.431195920513524, 53.77725224341116, 51.93243995789559, 53.70505709801951, 54.350012425453436, 56.657401592500754, 54.59498013219526, 49.742098239160356, 35.01761867154029, 53.54729152494862, 55.26455225483064, 54.26213956648304, 53.37261661406487, 57.56903886795045, 56.96683345302459, 58.05193754934496, 53.1681905254241, 55.50810398594026, 52.14549526091545, 55.67023123464277, 55.16592425684775, 51.08442744901104, 51.39164317038752, 51.42121391911661, 53.77287487829886, 53.671528677786554, 54.374205604676284, 54.092555892082956, 55.600550328531575, 57.37730556918729, 57.69535879934988, 51.57951685690111, 56.09318825506396, 57.98373537678873, 52.24342899937784, 45.739292021720644, 34.7574870817123, 21.646972625486313, 13.915719197642419, 6.605045343599012, 5.9113530958852465, 6.523917490436185, 6.575184829773442, 9.034384431377534, 6.152895102577825, 7.46128551421627, 4.166290115925574, 2.390459328889847, 1.6586529199154147, 0.3354330378915033, 0.31655500733083297, 0.26079079316508386, 2.8335189867404202, 8.901213099879604, 22.236544086087136, 30.859400303133075, 43.785422155934, 45.152368160986136, 52.31766377725909, 46.89693643200783, 50.7432440019423, 40.40305252998106, 22.012645390725908, 6.203559377501088, 0.3936841266770517, 0.008161909363773322, 0.046491861313341126, 0.014035503564011908, 0.02815899615656705, 0.00403408159223956, 0.006077161956308109, 0.025773057451231346, 0.049095112349717855, 0.020458261189501614, 0.027647507977822137, 0.06276138164403458, 0.068509986684207, 0.010192149615425979, 0.029790524032808123, 0.017920141033227407, 0.030068137059589068, 0.03722132408931371, 0.028525207251791033, 0.027633572838479475, 0.06490584943563708, 0.045938113809473095, 0.06949353632667372, 0.08714745797577404, 0.006612552557095525, 0.052161229879505215, 0.04026738543724341, 0.021087148512202888, 0.03601191257457099, 0.09500782651406142, 0.06383807991721457, 0.1312685989203953, 0.10340793463852137, 0.18460647473412176, 0.10394784276403728, 0.1324301261094309, 0.12749297288997521, 0.13152294011125643, 0.1697372903506602, 0.29687518914861066, 0.18510411012797587, 0.11119279755099166, 0.1866903871057495, 0.17867021262645724, 0.22093234163138176, 0.10358643312487872, 0.15407451548643653, 0.13814187849000578, 0.20600766183868532, 0.17815583055057835, 0.10207221437726291, 0.10466702312471406, 0.19650834011695079, 0.10990970753013127, 0.219954154604385, 0.12571142010030248, 0.10643185987587898, 0.09713245645886469, 0.1385823177594331, 0.17400983931316485, 0.10563160443017561, 0.10615888742669936, 0.326087378085621, 0.10406783511561733, 0.12268450712004017, 0.4562472792402391, 8.665161921131997, 24.44408932039815, 47.152647510651626, 58.82183213387766, 67.33132008583316, 49.757128761660674, 41.756415367126465, 40.647251452169115, 37.11283899122669, 37.595788663433446, 19.9536265865449, 7.34932832179531, 1.6722162308231479, 0.5512562778688247, 0.5085425247107783, 2.11253660340463, 4.793732550836379, 13.193262738566245, 18.05593094518108, 13.409122536259314, 17.3365996345397, 13.43544654307827, 9.660705558715328, 9.027057443895648, 15.150562717068581, 27.696332354699415, 32.55170887516391, 42.01063594510479, 49.61938688831945, 58.91508648472448, 56.30975800175821, 59.00974112172281, 59.55225590736636, 57.67313464995354, 56.02308765534432, 54.490460734213556, 52.1732577969951, 55.315248889307824, 50.13226032257081, 49.95389053898473, 49.556542673418605, 50.883566794856904, 50.01983342632171, 50.74296551366007, 50.969600062216486, 52.02696515667824, 51.7288257998805, 56.761803319377286, 54.356072487369666, 56.447280222369784, 56.582680440718136, 57.66559585448235, 55.34270548051404, 50.44192752530498, 38.7448509277836, 55.13996601104737, 54.5832993138221, 55.62114669430641, 54.491743349259906, 57.71533543063749, 57.53259612667946, 59.08429753395819, 54.891260285531324, 54.91072700869653, 50.9829439655427, 56.843561203249045, 54.9550929377156, 52.47455073941139, 54.67618888424289, 52.74593560926376, 54.314734628123624, 56.86063920297931, 56.867985802312056, 57.367660460933564, 56.03707874974897, 57.90053013832339, 58.811767332015506, 54.03424985947148, 58.87984398872622, 58.24488286049136, 55.22907441662204, 47.5509955806117, 39.42874362391811, 26.28450070658038, 18.1717546139994, 11.16344892209576, 9.400336665491904, 8.064892686182453, 15.786639759617469, 16.174523926550343, 14.655672369464753, 14.369648233536752, 8.676720165437269, 9.200590945059254, 4.788123561489967, 0.9325153777195562, 1.1223811992714483, 0.9887043723175604, 4.163348338296337, 10.798739098733472, 26.59748427329525, 36.34771008645335, 46.03617229769307, 52.75070128902313, 63.058341010924316, 51.3782992670613, 59.30273432885448, 46.3882952351724, 23.45911745102175, 7.096873790987077, 0.5977079272270203, 0.10775113222940315, 0.16864255070686343, 0.15802955164784388, 0.20623283040138984, 0.07654860856071596, 0.15309032233011338, 0.11773158015022356, 0.1511387899518013, 0.09437334483429309, 0.18058246001601222, 0.139244141117219, 0.1904001832008362, 0.12332497960737637, 0.19056916687517397, 0.16975846502088732, 0.11864923857032292, 0.14256931510904144, 0.25117096581286, 0.09052998897048736, 0.1568365995321543, 0.1976044587190113, 0.3193972854604644, 0.1876500501267372, 0.08932464155218295, 0.1613606858037172, 0.11227072922572975, 0.12247995398337803, 0.13186050909421138, 0.20955855597651776, 0.2020156389522937], [0.030494060878071095, 0.02277158242049477, 0.04273795387557438, 0.0464968140717716, 0.015164292943213257, 0.05467945281716605, 0.02459246807941987, 0.031626017073229436, 0.018044561373009797, 0.06711871738755895, 0.02164051297210878, 0.01416700255621465, 0.014501530170110206, 0.011723924225436584, 0.07123205029676039, 0.05568341487237523, 0.07789652494172897, 0.056975215312934695, 0.07689642780009778, 0.030354270899307825, 0.04009282847325649, 0.005713272586299648, 0.009500077275949861, 0.010687577718448256, 0.060425093097071496, 0.007471983506900049, 0.03437804238450143, 0.047788491938263185, 0.04649874078290117, 0.04835270803361651, 0.023490126928194396, 0.018631258318501136, 0.010427869124067648, 0.08892381668932016, 0.009365118439159086, 3.0813465916341354, 11.107838538385208, 28.034248467414614, 47.836112668437345, 49.01415340362057, 43.68447603717927, 30.4229679799849, 28.580262007251864, 37.29013796775572, 17.805632737375078, 20.105385049696892, 10.881022580208318, 2.2136121603750416, 0.4830659030666275, 0.16188104336540546, 0.33631345677760344, 1.225208217097867, 4.836320665574843, 4.636328326117608, 7.24450788190288, 3.103882324311041, 7.600384527637114, 5.179267708332309, 6.740506848981304, 14.80829179286957, 16.251449450369805, 22.360179155103623, 28.751424435646307, 41.06417586726528, 50.82971657476118, 55.6330785443706, 56.563143114889826, 53.51971334026706, 53.414338865587794, 50.88421006356516, 49.42786147517543, 48.16938469486852, 48.10143355400332, 46.68713277386081, 46.777653232697524, 48.69921845774497, 47.17267905512164, 47.39426943563646, 46.739912186899495, 47.90527189931562, 50.848190938272786, 51.388760228310865, 51.724785758603005, 51.92619946695144, 54.157879044932706, 54.25237286475397, 52.16942956370693, 52.20364047634987, 46.17699715398973, 28.543729051466915, 51.67623466061008, 51.68223588697372, 52.558697346718084, 52.81608327742546, 52.09404553136518, 53.15795706164453, 53.25214101422218, 53.698663634638635, 52.97994421374414, 53.86700784006427, 56.06051098915839, 54.34988298723775, 52.052303667991396, 52.37416551959131, 53.228249857502604, 52.53395895804129, 52.971848441708474, 52.83382808008502, 53.31275340049498, 54.378677106672725, 54.6959380180605, 55.327851464671475, 51.93944923339352, 55.547763070752545, 55.60849705050069, 49.26975073352937, 41.33667469024658, 32.841934850139005, 22.280178493069066, 13.137761200627974, 4.679862222363872, 3.7962365534997757, 4.681218872147222, 4.988859190094856, 6.339716122996423, 1.8466778628287779, 5.418254781153895, 0.7728119086354011, 1.0641113260099966, 0.32731281232930004, 0.5459939892734251, 0.10790544531999097, 0.5167907175998534, 2.624337269413856, 7.739302131437487, 15.63819177689091, 35.92441181982718, 22.616804145997573, 40.72545174629458, 44.01464546880415, 39.72701241893154, 44.54518918068179, 32.244765758514404, 12.798600715975608, 2.120986124200206, 0.094605561405901, 0.05468361650503451, 0.07419850361803848, 0.041674616175793835, 0.00913641342307411, 0.022582374024955977, 0.041247073996571765, 0.022439134735313636, 0.024603875128612406, 0.0156626676119143, 0.021185008583650477, 0.05914723545673394, 0.044839762061113314, 0.007503421840092709, 0.03751639051422958, 0.020002636142195235, 0.06594462635656519, 0.016617297435239438, 0.018859238423887762, 0.0692432937062075, 0.08689723833794556, 0.03227565197214004, 0.050805277236166506, 0.03110916244857494, 0.05473137059579453, 0.053973648351647203, 0.017042227254639712, 0.06610876069434228, 0.015203482170979825, 0.014656907165302865, 0.09506848535590595, 0.004946738894608233, 0.08087636947992348, 0.037498303178337314, 0.03761749496803649, 0.08437726105893813, 0.010412740802782918, 0.03599990031591827, 0.04623275888603061, 0.03674213226223665, 0.07393798009762842, 0.00391545407417711, 0.023324104183683955, 0.02893515239139238, 0.053556498155118, 0.04971239535558609, 0.02868053540887852, 0.02651128658814536, 0.040741486610063625, 0.025122102965871175, 0.034808740845971534, 0.05213856133782575, 0.03345526649706787, 0.039342307455597386, 0.03489209121213325, 0.06372265344966324, 0.04475906235916961, 0.04479277405827757, 0.041335262207975315, 0.09075506560264096, 0.02902495896353597, 0.008467923185127157, 0.07318254845637469, 0.05236926871622282, 0.04131473871248384, 0.020761289183170568, 3.5264961373421455, 14.372323289994272, 33.7236483635441, 53.691975993494836, 54.53491687774659, 48.039636611938484, 37.14568884141984, 33.952412759104085, 38.91570545011951, 24.50905553756222, 17.630685221764352, 11.313097150095048, 2.400397389165817, 0.3234527097834695, 0.1649772949636944, 0.5952558329989833, 1.8287620693445208, 4.058497500035071, 8.443252848040673, 9.550474209170188, 7.559296229193288, 6.88380721115297, 2.682931841381135, 6.623320156528104, 10.523171021092324, 19.628211067568873, 26.217092813984042, 34.59057846376973, 45.7493725130635, 53.0699037736462, 55.04667243649883, 57.91734141688193, 55.44169041418261, 56.154651795664144, 52.61855271554763, 51.72217346006825, 51.4807790325534, 49.74139613489951, 48.21690420950613, 50.12341930020241, 50.63262924071282, 50.669785853355165, 51.61112331574964, 49.11719406804731, 49.186427823958866, 53.82355582329535, 52.885540608436834, 53.74456321039508, 54.85038134359545, 54.59257571927963, 55.06375828096944, 53.82300276910105, 50.63624174364152, 48.67730809796242, 33.033428884321644, 53.12925707909369, 53.91387624125327, 55.269141427932254, 54.3567902811112, 55.529755469291445, 55.18513994832193, 55.74855312224358, 54.707697283837106, 55.23213778772662, 54.99972558790638, 56.62961944457024, 55.55899673892606, 53.70833619948357, 54.477481611313365, 56.33546521586757, 54.88274481988723, 54.35099694036669, 54.00265909010365, 54.6728156458947, 55.47116702602756, 55.55215220297537, 55.87070749652002, 53.45201715346306, 55.79921445538921, 57.21677080277474, 50.573817222349106, 44.01568489689981, 33.58882865598125, 25.9570808564463, 14.118774417907963, 6.47262808776671, 5.32653211585937, 3.707989843622331, 6.280702102568842, 9.142725198499619, 7.134815858256433, 6.834745224445098, 4.257498950727524, 1.9635506430941245, 1.2598519387745089, 0.43170985074773915, 0.03312925778089031, 0.6882582941362936, 2.90949309064496, 8.93064558506012, 20.590439073501095, 33.28480966629521, 28.585918065040346, 46.76293257744082, 51.51700604346491, 42.828987490746286, 52.03999919276084, 36.98755064318257, 14.904838973476043, 2.7458319500569375, 0.25792409215242634, 0.05809196083235645, 0.05052365948476138, 0.000711660489492539, 0.0394309361675574, 0.03990385756497422, 0.036287547179287484, 0.009537408740500049, 0.020918237616217906, 0.026172030296537186, 0.024569272852292465, 0.03736122706604581, 0.03931375918909907, 0.012295038942548056, 0.018739721046820767, 0.01606223704819117, 0.028241086308093324, 0.04689426814776756, 0.062440019251117786, 0.09128977965203025, 0.0657778260328116, 0.030924510360965808, 0.05759257109715574, 0.14197547439365618, 0.07048768096513326, 0.05468447835394933, 0.044328957615840825, 0.07342234929843296, 0.017236126023494912, 0.022930884658689463, 0.06672183787750621, 0.13301192392264644, 0.21593913375850649, 0.14197634773388987, 0.14280151635889085, 0.13337670434867183, 0.1902345090263313, 0.14439922336849476, 0.14799263538612475, 0.07773304943956676, 0.16806646790956298, 0.12011143228700084, 0.13551549925919504, 0.13396458490000618, 0.26335127351264803, 0.20070352952086157, 0.216953250309152, 0.12583810806034074, 0.07473926210115034, 0.1145078974866098, 0.1913548053632821, 0.21122924052178862, 0.12214730328489697, 0.14697413681255234, 0.12427561045173677, 0.2158898130179413, 0.18675521346590213, 0.16477558401323136, 0.23950661833007492, 0.18576437066639626, 0.11600774442476612, 0.13755643409827065, 0.087435775166077, 0.23091049894930857, 0.1193977677593789, 0.08874324210468801, 3.953575568814432, 16.29990739207114, 38.61868004645071, 59.97503249875961, 62.51750892208469, 56.947056862615774, 42.99662959191107, 40.46924644900907, 47.45655667397284, 27.118943775853804, 26.743331724597564, 14.740577955399791, 3.402764479960165, 0.628927787465434, 0.7170642419688164, 1.4102677255868914, 4.803837066696537, 11.11506844720533, 11.221445087463627, 16.112293562581463, 12.322960380584965, 15.749167396176247, 12.393410071249932, 12.963707985416537, 18.286787925227998, 24.15189627678164, 35.16582542850126, 41.13305660986131, 50.03795477651781, 54.597302175337276, 57.327491467998875, 57.93522350249752, 57.51888352055704, 57.88276964618314, 54.84081860511534, 54.212148958636874, 53.08495390799738, 52.46432119800199, 51.59569663386191, 51.55628073600031, 53.44517653988254, 52.84583445518248, 53.10638573861892, 51.91812722913681, 51.9691768769295, 55.75661751531786, 55.98229500555224, 56.42107486724854, 57.08017033915366, 56.3639533904291, 56.44801762796218, 53.60152613732123, 51.57498259698191, 50.64090936414657, 37.96928067361155, 53.83838630491688, 54.45474363142445, 56.71595865680326, 55.809228266439135, 57.72857735233923, 56.31992870761503, 57.46675522096696, 57.838658671225275, 55.954489323400686, 57.89917692061394, 58.454333505322865, 58.71417483975811, 56.070693462125725, 55.58837921388688, 57.69659042358399, 57.120696267774036, 56.04298191685831, 57.02579452145485, 55.13472572449715, 57.39148101499004, 54.60649228865101, 56.735648955068285, 54.93714809417725, 59.12428609786495, 57.05389438136932, 53.581141579535704, 44.86779236024426, 38.48437809175061, 27.07087512939207, 17.105079773933657, 7.677951358979748, 7.47419011208319, 11.461455898900187, 12.997217774391176, 16.406639987422576, 9.957913352597146, 14.269557191479592, 6.5260399829956794, 6.503169623113449, 2.017118207389309, 1.9045474091845176, 0.6603403341385626, 0.9652863515000191, 4.532301185592528, 12.200037221754751, 24.89644450526084, 46.99358363305369, 34.69987138625115, 51.967890339512984, 56.52128750278104, 54.37728466526155, 58.79919221324306, 41.31437601581697, 17.797103543435377, 3.177114691465132, 0.3390794631934935, 0.20610141567885878, 0.23990268578692792, 0.11054900790294332, 0.08508779228694978, 0.12120365916240601, 0.1394568837337917, 0.10563113711654179, 0.1343499884129532, 0.11820611799316061, 0.14199170013589246, 0.16720696322379575, 0.13939254766991063, 0.12368422887858846, 0.08611581333342098, 0.14191501473467197, 0.12210161380109288, 0.14929752826931017, 0.15179011790502459, 0.15785347399932725, 0.1969698927695713, 0.11070019535480008, 0.16905862838029864, 0.21772160585368835, 0.15115218116871773, 0.11499390366577333, 0.1857019191788089, 0.24889243646494805, 0.10130197425643284, 0.10105044460825383, 0.17103830682894877], [0.04884500379463838, 0.09052522390359834, 0.08997345673701457, 0.03349793376401067, 0.06922628655428849, 0.008004426105593843, 0.0518669065598759, 0.0652508418105783, 0.10312542439468446, 0.03805797254186004, 0.06084714242587648, 0.07097015547896586, 0.04504690074451989, 0.02488683353388502, 0.04071983696532346, 0.14430678719955106, 0.008978871271885451, 0.09270283648924482, 0.027003116950753237, 0.03942918565665041, 0.04641406125419083, 0.04354713807603525, 0.055417984558810154, 0.06784845443983233, 0.05956789433595635, 0.020400745223366448, 0.035374125225409385, 0.08281304741338377, 0.027146756521336017, 0.056324408299499945, 0.07258346003870811, 0.0429152304516925, 0.03704396707396354, 0.032156192051667365, 0.04462132741126322, 1.2903551084379996, 9.457137488549757, 23.35058939072394, 42.364798515073716, 48.983386331988925, 45.77081611079555, 33.16966064514653, 24.911457377095378, 31.656027801575203, 49.0238259684655, 41.31014770077121, 14.56851730423589, 4.153311483321652, 0.39402169566000667, 0.17032209122853895, 0.6225050901693683, 1.2189479917287827, 0.7730383642258183, 5.86940432748487, 5.347447174210703, 4.234117702130349, 3.7212584864708687, 2.7935037016868596, 7.163323154372554, 4.910583880639845, 9.520017985374698, 12.868737597619335, 22.201619302072835, 39.52802665771977, 52.006914000357355, 57.5768796859249, 57.095942189616544, 56.430343427965724, 52.844783259976296, 52.995112019200484, 50.262306505633944, 50.0587551055416, 48.42209908270067, 48.082174716457246, 48.49931093954271, 49.342459709413596, 49.20996596736293, 49.706188940232806, 51.1479502339517, 52.76222521258939, 51.11732044527608, 53.39245596239644, 53.248591269216234, 55.966562378791075, 54.26349670656266, 56.57172918319703, 58.631742308216715, 54.87871654572026, 48.13989239354288, 27.08825319044052, 50.398408828243134, 53.5770191684846, 53.74891704128635, 50.79877691884195, 52.49291527655817, 51.61664209058208, 52.10592639061713, 51.28927323126024, 52.6764194426998, 51.74386416712115, 52.5924022736088, 51.96179889863538, 51.402649341091035, 50.518280383079286, 50.59097759185299, 49.54233977102464, 50.55393080557547, 50.8099909751646, 53.11494435033491, 54.848365245326875, 55.90721691808393, 52.803013940011304, 51.77364280146938, 53.13142614979898, 54.31018860109391, 49.17180522795647, 43.47997542350523, 30.690861940383915, 19.474036424390732, 10.941701646774046, 6.1098465996403855, 5.930487888474619, 3.671302199363709, 3.2990172986061346, 8.351136965136375, 5.278926799374243, 4.632255434989929, 2.937417914790492, 1.137667533851439, 1.2771559650859525, 0.09903841426656132, 0.32596970698045147, 0.9477274937014427, 4.0138459734378324, 12.161136134978264, 23.23053740685986, 27.090573272397442, 38.878741033615604, 45.82091262263637, 42.35570646101429, 53.24783817414315, 42.699109969600556, 26.428198699028265, 8.023499913754003, 0.7599163199624708, 0.20007227307125447, 0.0076479596487667055, 0.1099329966030294, 0.06360035134299148, 0.025664251898565603, 0.04825577875899692, 0.08861253984392652, 0.023908960602937207, 0.012307483083268088, 0.025391112825262453, 0.05350264217404108, 0.04677786874855238, 0.007389010439041041, 0.031243584066208814, 0.061646585818380124, 0.040136698498240406, 0.035573212324731776, 0.08940737904800523, 0.05711298473479767, 0.049219348828398415, 0.026021668304418846, 0.03968701637800663, 0.048086978945760965, 0.03415877269881387, 0.04207453705490597, 0.03392786230711687, 0.028178104304618416, 0.0377242531507246, 0.06225702765908453, 0.03672615166813616, 0.07678600388669199, 0.02882087314050765, 0.05006680678155634, 0.008541646698910383, 0.10745802698957344, 0.07982436222054305, 0.030171018837380315, 0.03961064890327473, 0.04225076026012821, 0.048793354146783395, 0.05105847695602044, 0.031527932921064, 0.15322740610328414, 0.012180041484234315, 0.028821694769806443, 0.04333015899324129, 0.02802502461558869, 0.10033995934551763, 0.10658618828822529, 0.04306864721940891, 0.02206854927804201, 0.031453434700867346, 0.011169198044245283, 0.025468847766939192, 0.03312150880153621, 0.09380660064878965, 0.027024218842627543, 0.0229028822298372, 0.045071733484585444, 0.004105130980362095, 0.02555087088577209, 0.026458137323178595, 0.018044574779548475, 0.02450045708927416, 0.0535260193470505, 0.0141569888294344, 1.9869447619684282, 12.18513515687758, 29.51776339161781, 49.906367101976954, 53.24736748972247, 51.95307946974232, 35.60746469805318, 28.00596425610204, 32.51516022989827, 33.24787662875268, 37.237354632346864, 16.088894663318513, 4.460946408010298, 0.39264999990982397, 0.24269673102084668, 0.26645616658272286, 1.5016338229179385, 3.9144572807896525, 8.027472294146015, 5.5923643804365595, 4.9223833507107155, 6.029969982562527, 4.490632376363201, 7.459740590664649, 8.655248130521468, 13.746142387390138, 19.984740787936797, 30.711530870006932, 42.3003069047005, 54.57775308239845, 58.49709910731162, 59.702235575645204, 58.425578609589614, 54.88875389099122, 54.93050359910535, 53.886070559101725, 53.16728445791429, 50.23614037421442, 50.89384732707855, 50.391634894955544, 51.782299472439675, 51.994986072663345, 51.260216313023726, 51.56866758100448, 55.04173417245188, 53.66221697099748, 54.68992110221617, 55.25645256042481, 56.51457632741621, 54.556336941257605, 55.39253527118314, 60.44157881890575, 57.28551426241475, 50.49860577429495, 31.510223496344786, 51.877287510902654, 53.65042240388932, 54.276224797771825, 53.950766132723906, 54.17787528807118, 53.941211238984145, 55.33636693031558, 53.64436234197309, 53.5205723393348, 54.09474065226894, 56.0096025466919, 54.88094052960796, 54.149391035879816, 53.53607746862597, 52.681585204216745, 52.866568103913345, 53.82173976590557, 53.68431952691848, 54.224414210165705, 57.177825589333814, 57.926625667079804, 54.097639283826275, 54.70506537345148, 56.74092454295005, 55.39648117557649, 49.95397683112852, 43.01305255582256, 32.827367167319025, 21.784243814406857, 12.03048884868622, 8.05074126489701, 6.321666846352239, 6.5190503193486125, 6.2027062619886095, 5.565000945521939, 6.9093271320866005, 5.847854825758166, 4.806039967844564, 1.9996027408107637, 1.1520180154231288, 0.1928663734466799, 0.17547596306089433, 0.8862429929356422, 3.9615938740391887, 13.37619718044035, 25.56382598415498, 35.5065970267019, 35.94886779785156, 47.0777851535428, 48.71626115614369, 58.97911133304719, 50.88419437408448, 31.674427640053537, 10.949628756892297, 1.1391047147973892, 0.10749199532813604, 0.011405296766409471, 0.037377261286301, 0.018624928517026768, 0.026994990673096433, 0.029186480941491264, 0.059376276593895695, 0.04052623888597854, 0.06405017135905162, 0.08157625208578764, 0.047956916368416244, 0.01741634629246208, 0.08915261650878577, 0.0628288395162071, 0.018494197527968118, 0.06046139034292391, 0.027280191800767378, 0.02828458861087359, 0.07406849083640883, 0.08719454940047958, 0.06147038176535599, 0.023147597525929733, 0.021924969079273365, 0.0508979125879705, 0.08948649294794568, 0.025111071299761537, 0.027973784824773192, 0.07549527596922652, 0.04808396438977892, 0.04081894576008763, 0.07481581726742369, 0.09500830148857448, 0.1522995510529126, 0.17589349630138568, 0.12387158334135048, 0.1553893521908791, 0.11163740433872708, 0.089549511340597, 0.1453495401168062, 0.1372771031193195, 0.2049659508010072, 0.15127965819931802, 0.30836399524442615, 0.18755566809446583, 0.10021929283656421, 0.14664972922013653, 0.26608148830071576, 0.1724165449700048, 0.17444039604836897, 0.08618433989824788, 0.0870854354974243, 0.10860616296169259, 0.06369579823747759, 0.12826235499233007, 0.14406166970729828, 0.17661079974664798, 0.09633382511956078, 0.12934800117246567, 0.17349576367245567, 0.16015529242013732, 0.1290596456777665, 0.1549946330487728, 0.15164597080119196, 0.13863016761118366, 0.15802075695847312, 0.13233051935751594, 1.8918101249202606, 13.093362912054985, 33.0808424949646, 55.485844535212365, 61.02952641825522, 58.18511770617578, 42.564082376418575, 35.69763606594455, 43.232940627682595, 59.78118112010341, 47.627305292314105, 17.924896324834517, 5.8147451185411025, 0.7724671690694748, 0.7626272293348467, 1.6685724715071342, 2.9703462123870854, 4.8161351680755615, 13.260396065250522, 14.866038887731492, 10.315786484749088, 9.614446105495576, 8.947781439750425, 10.465256244905534, 10.21867742461543, 21.027051825677198, 31.213284384819772, 40.55815089133478, 48.58906653619582, 56.88441268859371, 58.71015833270166, 60.12489057356312, 60.2393884812632, 56.85658347222113, 57.78176076950566, 55.38753424921344, 55.67741701679846, 52.72240531060004, 53.718879530506754, 53.147684374163234, 55.699284230509114, 54.063389147481615, 53.24059747880506, 55.178554288802616, 57.13573463501469, 55.27745685269756, 56.65760555574971, 56.883785109366144, 58.50539884259624, 55.87140960078086, 56.86806032734533, 60.65450860608009, 58.784938320036865, 53.499293481149984, 35.58846865930865, 53.92918525203582, 55.09823199241392, 56.01151274096582, 55.87198618919619, 56.234785818284564, 56.15072942549183, 56.67946492472003, 54.84490963720507, 56.350044665798066, 55.5921878353242, 56.74692576931369, 56.5498149010443, 56.325510240370235, 54.97734062133297, 56.36495751719321, 54.6667948076802, 56.393292719318026, 54.76577581897859, 56.07835385107226, 59.57803372413882, 58.20200743213777, 54.16781440857918, 55.174204380281516, 58.955212331587276, 56.71089879928097, 52.098964183561264, 45.8389869043904, 34.69589018052624, 24.062925154162993, 14.363260653711135, 10.132551981556801, 10.88953608466733, 10.09755757547194, 11.628753812082353, 18.4506449391765, 13.433512814583318, 10.888607463529034, 10.694942397456016, 5.304710499701962, 2.633917413411602, 0.7493493934312175, 0.6330659492842613, 1.6333514259707544, 6.140138574184911, 16.82997453597284, 32.63927382807578, 39.72636915022327, 51.02733735115298, 56.75337806824715, 56.341486054082075, 68.23605398977956, 56.248419977003536, 34.962748635199766, 12.060488116356636, 1.5802359148379297, 0.25438476594225057, 0.09324631458448787, 0.20247751336184241, 0.11388212622654055, 0.16736011952161792, 0.13988877346198406, 0.17589436964161936, 0.12568064634838413, 0.15882852006583445, 0.21698482845339084, 0.1979902146324035, 0.13120553456246853, 0.1966253370647469, 0.10045847314740382, 0.17259067675519377, 0.2763193953902491, 0.11451306091921945, 0.1861384360780639, 0.13224269503787642, 0.247635607938132, 0.1493792698508309, 0.14132572458155696, 0.15122436197294345, 0.13697975375238927, 0.14857791123851655, 0.13932520854136637, 0.15679022056921837, 0.2900230842492273, 0.14607698656618595, 0.08981027234826358, 0.19120920269239336], [0.06481411806758373, 0.08798076245453089, 0.14050705238215386, 0.07415256132521937, 0.0552885769866407, 0.015488793423789886, 0.049680958937613234, 0.0774460729031313, 0.026204029789134383, 0.024412134812483867, 0.10115035779533849, 0.04474822604548066, 0.0465967885458902, 0.029502174283768383, 0.036683266066134944, 0.0070939521538093695, 0.05419329342041766, 0.04421199131156168, 0.05825065211543153, 0.08643514942377807, 0.031756585268604184, 0.032949656127922, 0.032992989891358925, 0.05204633201262163, 0.021528175754112103, 0.038860449642543836, 0.07415728042683295, 0.0737790474968572, 0.06453933765090282, 0.040754625017965035, 0.024431329145426714, 0.025185454606769547, 0.0016000902612558418, 0.030388700805844802, 0.07498138418961918, 0.47438235773194226, 5.368373999672552, 21.47709477332331, 37.75176955807594, 47.18075913767661, 44.13387375493204, 36.704080950829294, 45.495061720571215, 67.39950656890869, 74.98227180973177, 49.792084924636356, 27.102501200091456, 7.4723186512147235, 0.8802374151925888, 0.21509922560184233, 0.19126701168715957, 1.3075748037907386, 3.887990352607543, 8.192526611589617, 5.193284298143079, 4.7798360836121345, 4.894337913682384, 2.537640140902612, 5.566500271520307, 4.179667849694529, 15.770389379993563, 15.330170989036562, 32.94623459539106, 50.58465865350539, 55.262826411954826, 57.4548625946045, 59.2669270115514, 54.924561208294286, 56.83570861816407, 50.94560692387243, 52.6390863233997, 50.708044652015936, 49.814532649132516, 50.09642554867653, 51.657626936512614, 53.22328021449428, 54.32046128857521, 53.76488108788767, 51.29114812420261, 52.81835040738506, 53.81000403435, 54.53481489612211, 55.83384113927042, 55.77718250213131, 55.156596860577984, 54.847772967430856, 40.53803305472098, 30.638302180074877, 46.83934427076771, 28.048612186985633, 48.63840603059339, 56.37042922358359, 53.510519304583156, 53.82056697722405, 49.141061690545854, 49.285322543113466, 46.337567221733835, 48.946194418015025, 49.31208095242901, 50.40274304728354, 50.30414250589187, 50.355741285508685, 48.544888880945024, 47.214530744860255, 48.31639512892693, 48.35727014849263, 48.717210369725386, 51.54428612801337, 51.317769250562115, 55.479392236278905, 55.32894188357938, 55.39940726372504, 54.68629290980678, 47.37983119103217, 53.074763590289706, 47.15672285326066, 40.69859527772473, 28.396516615344634, 18.48144142858444, 9.617926228430964, 6.647411354126469, 5.254854233034196, 3.97055134177208, 4.154746580508448, 3.101120730561595, 4.834346732785625, 2.737681264838865, 3.6771391764763868, 1.0187364285511356, 0.9235508619777618, 0.08237486044245382, 0.09635550540781791, 1.5914652929190667, 4.326233585034648, 10.094154919347456, 17.40582750689599, 19.456040590040146, 45.58323660204488, 48.59562081675376, 40.38220905488537, 52.786732181426025, 42.10689090913342, 19.555984543215846, 4.435084260279133, 0.225462434032271, 0.055116406386537906, 0.05953003044029879, 0.14628196105120644, 0.04920430669200517, 0.03436904851227038, 0.05511185199382806, 0.05884557684522964, 0.049264141989331094, 0.09767984926340081, 0.018788109075338132, 0.014468499331644949, 0.043947334746800126, 0.08219486808464413, 0.050426462079368295, 0.05309762297979286, 0.025241524581947637, 0.02806006164680566, 0.1287949622999276, 0.009709348556615654, 0.06327371443471601, 0.011494134237328845, 0.03959644180271895, 0.04800589619985512, 0.06553071671195569, 0.05073830199938628, 0.0416163896631089, 0.004843190620322862, 0.11965911099386793, 0.013129344123655991, 0.03130203082917198, 0.03373663143945798, 0.035874323183370214, 0.01867469741902765, 0.06453582130733036, 0.05463659019780256, 0.04017162061626873, 0.022479475010186437, 0.04956325718892678, 0.03268940456872506, 0.026357580622237538, 0.037105127703398466, 0.0600214030653719, 0.014636269714232656, 0.02731671887299707, 0.006127980877570207, 0.05195920100255359, 0.05717429475137784, 0.014313227673541876, 0.015550114931688916, 0.003988585066831401, 0.03876017256369514, 0.03287833334217149, 0.013414487794732616, 0.011299904135446395, 0.049009911881219, 0.016789496763639392, 0.012337156541405186, 0.05276075879772825, 0.032673071574179396, 0.030530563052443248, 0.031027834554533326, 0.050616448054150234, 0.04438465220793601, 0.06902336518490507, 0.06696935322496199, 0.11077895685429535, 0.5689755238352284, 7.307466826131267, 25.72437055649296, 44.53813283674179, 54.046805366393066, 47.993493849231356, 38.60135493739959, 40.30854302067911, 51.874949778279955, 71.219314605959, 48.14525427356843, 25.874603217647923, 8.258508232332046, 1.307877929460618, 0.027521827423404303, 0.23748747103156584, 1.4340055421475442, 2.7282700279066643, 4.669218870901293, 5.351472996896313, 6.853644184527859, 2.1689282742238816, 2.286512842101436, 3.9247159948272095, 7.387852370738984, 18.072687310557214, 20.13168650288736, 36.05468157799014, 51.34662612791985, 54.48340831264373, 60.230072852103945, 60.79546290059244, 57.27986212699645, 59.00550496193671, 53.40014380793418, 53.47240955598893, 52.52635740464734, 53.527067784340154, 52.88192810550813, 53.25551817494055, 54.98584431986655, 55.915536265219416, 56.48643724380001, 53.63587825529037, 54.2516746828633, 56.824702447460545, 55.80272497669343, 57.72705939508254, 56.43551703422301, 56.86670710963588, 56.06186420686784, 44.050354726852916, 32.84340573895362, 49.19128371823219, 33.25824737548828, 50.10184626425467, 57.30840129237021, 56.34639293916764, 56.08145252350838, 52.03613173577094, 50.15501006957024, 48.472842785619925, 52.18638204759168, 52.551919491060325, 53.80453625032979, 52.97786535755281, 52.120654890614176, 51.99849267159739, 49.351143836975105, 51.60787167087678, 51.77873403795304, 50.41887967817245, 53.11910990745791, 53.55767796116491, 57.422801140815984, 56.08664181924636, 56.467978569769095, 55.15950725924585, 52.09804242657077, 54.68886990700999, 50.45831911025509, 41.00941957965974, 31.084881674858835, 20.626385634945287, 12.770340038884072, 7.052368127530621, 5.606795760893053, 4.96757346776224, 7.166558619468444, 5.624668530879482, 8.354001275954708, 7.634900404560951, 4.087299219062252, 2.363536670323341, 1.0065425764168463, 0.2534321662519248, 0.12608407591018947, 1.8206085649228867, 4.415558211265072, 13.581339101637564, 24.708274679799235, 23.82883025753883, 47.739732188563195, 54.13532933881206, 44.95758325822892, 59.1729627117034, 45.902843090795706, 23.938540912443592, 5.831929512562291, 0.44365708385744407, 0.1440815726715711, 0.014779840336902248, 0.09213861273301226, 0.05192768031490907, 0.1215011081207664, 0.07017196080977879, 0.037525277134151235, 0.016410078312600815, 0.04131252088794305, 0.01424534941062091, 0.020903703013074496, 0.050547151570959445, 0.12008314065995718, 0.0035173895218664963, 0.03906192310575036, 0.06628702935432235, 0.007342118197195833, 0.06522842607791386, 0.018524245411578207, 0.03983050081578474, 0.015481931191208142, 0.019051622253872694, 0.03556339873842174, 0.05429001585129769, 0.1071372659756772, 0.09598559985357909, 0.04734042626354964, 0.03207251226769821, 0.029740272495414943, 0.07646013306634081, 0.06416693848047046, 0.17890443634842673, 0.12868922684461842, 0.18790344136857218, 0.2744016321676393, 0.092691199613675, 0.13292420685531633, 0.1675210133074753, 0.14207537225898237, 0.13503268000579652, 0.15211742130979417, 0.17491253603610302, 0.17978833327370305, 0.19010667959528585, 0.22005247432858716, 0.17570356778319807, 0.11264395960155996, 0.09995030404459085, 0.1557774370115611, 0.1280279014439833, 0.21234684022924594, 0.12590557742383213, 0.11412523656843171, 0.09099536440185002, 0.14884893782436848, 0.1584145261515533, 0.17667651476879276, 0.20413819279882217, 0.2541696178095956, 0.15812957208723794, 0.1717722956692019, 0.12712099123746157, 0.1053085757960235, 0.17800045259777578, 0.2214777655899525, 0.18188640295017153, 0.7572652880222567, 8.186736702919006, 29.064949289444957, 49.901483751112416, 61.28067578038862, 55.65163135528565, 48.933697746646025, 54.82581553920623, 75.86252227906259, 81.85819456654211, 55.37752436053369, 31.792565507273522, 9.995305307449835, 1.446310752822507, 0.5622620195631058, 0.5740466581717615, 3.082035703043784, 7.042424428847529, 14.400359411393444, 14.335995278050824, 11.811056752358715, 11.353052373855345, 7.006758316870659, 9.758055844614583, 12.642149136912439, 26.054008506959487, 27.63500217468508, 42.21031988820722, 52.82470072469404, 56.49360733647501, 59.407822470511164, 62.09080996051912, 59.0888161043967, 59.79459562609273, 55.5444682798078, 56.46356198095507, 54.938913160754794, 54.23573024811284, 55.21552655004687, 55.06364845460462, 58.39957721771733, 58.43946379999961, 56.863176976480794, 54.92146645822833, 55.85602214259487, 58.29160613398398, 56.19508358740038, 57.83642684259723, 55.7477137350267, 57.26643977626678, 55.99624295388499, 48.33016657060193, 35.5158067518665, 50.52900806550057, 38.21942198661066, 52.63060223671698, 59.49821741350236, 57.7732962946738, 59.06314026924872, 53.615317190847094, 52.65688603924167, 48.993207946900405, 54.02616977691651, 55.23706428466305, 55.16296286736765, 55.70752905261133, 56.37030763010825, 54.22951721375989, 51.78977550998811, 52.894632662496264, 53.724386538228686, 52.85224753041422, 56.280069581923954, 55.399183688625214, 58.969854539440526, 58.12332468648111, 56.254487883660104, 57.32891136600126, 52.516069027685354, 53.98306292872275, 50.81640012802617, 44.61854927001461, 33.30891263100409, 24.465352489102273, 15.665415967664412, 8.965255598868094, 9.100312609826366, 7.686982616301506, 11.084486707564324, 10.52474683330905, 12.798911563811764, 12.840450444529134, 10.782620118510339, 4.320167639563161, 1.8755688157773789, 0.6632427654920087, 0.36489396025576903, 2.348921673913156, 6.237650167557502, 16.262284997970827, 26.789966744761315, 29.801948916527536, 54.957615021736395, 61.93637447972452, 53.318868375593624, 66.29736761892995, 53.80693674087525, 26.129235644494337, 6.593239989972885, 0.623389155633988, 0.27135649395565836, 0.18729754242925875, 0.19406592924027674, 0.12242199177102697, 0.2604757165235858, 0.18417231738567355, 0.18761566810069547, 0.3622679334254034, 0.23310736332449222, 0.10318117261293436, 0.15453157886382074, 0.11253539728181017, 0.2210604008888045, 0.11322624005016782, 0.1521929729008867, 0.13949494298186996, 0.09213411579689673, 0.26543117158355256, 0.11314372471984356, 0.0974875765161649, 0.06058546211270075, 0.14427766053666993, 0.14255999947988218, 0.1883883903464002, 0.1862092379240259, 0.20051487270862828, 0.1385301471717896, 0.2876579256788377, 0.13222099942786078, 0.1602278256248082, 0.10006498740685564], [0.08189937265049066, 0.04156013199638936, 0.0386753321565207, 0.03066418793863587, 0.09075173312017033, 0.05571930226118815, 0.02021119974914097, 0.057364682922320026, 0.06568638577816949, 0.04295644215157917, 0.06743783897329723, 0.04397072341112841, 0.0926475479237495, 0.01906818890523526, 0.009622344908665025, 0.04454483353202382, 0.03519237469581347, 0.03086948035014493, 0.06215600364450967, 0.04709692521681709, 0.0245876589624752, 0.05943619616089329, 0.03823179789187928, 0.030128838036269433, 0.03324285329830262, 0.05114579182719031, 0.03810833133156261, 0.03013808854795512, 0.008782923217832802, 0.05613130434686619, 0.02912378430576815, 0.013383624027483167, 0.05186376176894673, 0.07831387432111848, 0.018222609782711636, 0.2343653409831947, 3.0037988818460897, 17.42136009277836, 39.11768397977276, 46.93346154305243, 49.939330700905096, 53.48434532842329, 70.8290623080346, 83.56481782851681, 81.72306106936547, 60.03229910327543, 21.120115941570653, 6.0490748670793355, 1.3798890911763715, 0.20569387222490004, 0.1852265309782759, 0.9320586054555832, 2.3981824757591372, 3.3658618407864727, 2.6782333322109717, 3.1771779396841606, 2.0002363261676606, 2.4735645469157928, 3.2567567017770584, 6.721646132007723, 11.337314844131472, 18.035391453773745, 29.086618423461918, 42.67529726028443, 56.43460704434303, 56.87113546556043, 60.77938902762629, 58.31262611573743, 55.11388617177164, 52.721769886632124, 53.44057559967042, 51.95739799930204, 54.00272969276675, 53.188833959641, 52.76439036092451, 52.73187391219601, 54.21105069498862, 51.90017846322829, 54.70641859116093, 54.86757309206071, 56.02832009715419, 52.45778652929491, 54.61733371980729, 51.1475383850836, 54.07704291805145, 53.472550761315134, 48.264843417752175, 42.52729054420225, 53.7050021848371, 30.723902025530418, 41.50201436012022, 55.9556778015629, 52.5522489701548, 53.272031353365996, 51.85040750811177, 47.866165868697635, 43.57913294146138, 41.44786996226157, 43.379896148558586, 45.55801968420706, 45.91433171303042, 47.200414134610085, 48.29131157167497, 49.99596972619334, 48.67735908877466, 49.30088258558705, 49.7396977486149, 50.68560869463029, 52.2357411538401, 54.82997325158889, 54.66097793271465, 58.221627127739694, 53.29796998731552, 50.389916896820075, 48.982409661816014, 45.300178758559696, 35.07377916766752, 27.62036781157217, 18.086239099502563, 11.087152938688956, 8.77564626355325, 4.831136763095856, 3.3926960008759655, 7.125190361853569, 2.379268071343822, 7.112856468846721, 5.618843811173593, 3.042652164736102, 2.834378721252565, 0.8298889523552311, 0.09274559185629891, 0.34098720598605375, 2.1883690116866945, 6.425849901091668, 11.126362912116512, 19.15067034382974, 28.45853124895404, 41.86870498041953, 45.096176285897535, 45.97067263818557, 47.781270088688025, 32.83022265280447, 14.587367234691499, 1.3420458186057307, 0.07970165791771106, 0.05567422564772349, 0.034948191830828305, 0.06138431944794232, 0.02947144075146606, 0.06810216743859553, 0.027717492024924968, 0.053927380471460284, 0.02622404958181564, 0.030043239202049953, 0.07933627228222548, 0.05942562414753822, 0.051411432814934564, 0.017390339522652568, 0.04181808529181346, 0.04388417462788282, 0.028474212609111305, 0.01976569663853415, 0.04852912276081982, 0.0382506130112996, 0.020929730850301927, 0.03829795724502014, 0.10689748045537742, 0.06829149074732296, 0.028099224061494874, 0.027664135916218646, 0.026000413194959684, 0.02879997426193328, 0.1361715156705149, 0.06971708078297877, 0.02546365369081257, 0.05413577170862306, 0.0071922374040549325, 0.06771126341435217, 0.04815200065833427, 0.01338269227304526, 0.030211558295113426, 0.06281382802333083, 0.060507956997401295, 0.041670015817808534, 0.06536129636750107, 0.03773321637943868, 0.03588431296990283, 0.04820019908009037, 0.04475799366651524, 0.0439751245862534, 0.042744703110187285, 0.05111174304939566, 0.14063638334553089, 0.03792308361059235, 0.022353966825551564, 0.005850669497909446, 0.05502370591726034, 0.11611045383277441, 0.07894803424395862, 0.04870914193170686, 0.12356066655728126, 0.10011833776990253, 0.03233747143718985, 0.0033968235619531405, 0.023274641716852788, 0.06232611346809615, 0.07290096517892615, 0.022453634864500454, 0.032422549331620816, 0.03876262787549246, 0.05523441073995444, 0.4289883080749743, 4.363783415286772, 21.60129270245952, 45.8473886212995, 54.4925945035873, 54.336695978718424, 53.63174015475858, 65.51902424904608, 83.80885201115763, 84.05238413041639, 69.57356652905865, 33.22351478761242, 9.436134176869547, 1.3726521956343807, 0.1835072151715717, 0.12156721384775256, 0.6558371467455741, 1.7524446354758356, 3.333906290992614, 2.535877770954563, 3.3636263349363884, 3.142319100518381, 4.272961424243066, 3.909752642916095, 7.763674268799444, 14.26864622100707, 22.35618422108312, 31.7358382286564, 47.56811280404368, 57.72670245939686, 58.409979343414314, 60.70997876505698, 59.52761165557369, 56.255429252501465, 55.773142460853826, 55.20651686576105, 52.837934801655436, 55.429633048272905, 54.81830812269642, 54.96888791361163, 54.42958162676904, 55.622492067275516, 54.54025522355111, 56.51279557135798, 55.5949648734062, 55.811970003189586, 53.792671080558534, 54.88067380843624, 53.426015761590776, 54.298472481389204, 54.82872593787409, 49.47835414640365, 43.405513148153986, 53.607523441314704, 34.24835558860533, 44.08500494495515, 56.38491845900013, 55.682633769127634, 56.40664054501442, 54.37857120267807, 49.08806654714769, 46.611587924342004, 44.16009872190414, 46.35601805102441, 47.69579772026309, 48.954313724271714, 50.41230186339348, 50.0804615020752, 53.78987443062567, 51.169436977755645, 50.6952694923647, 52.04299588357249, 54.08402473695817, 53.935865048439275, 55.79604125791981, 56.80207429393646, 58.377051045817716, 54.79541717037078, 54.12626081897367, 51.12639680985482, 45.98201221035373, 37.589995322688935, 29.017865157896473, 21.136507526520763, 12.998386640702526, 3.833510101802888, 5.657131537314385, 6.766277311309692, 8.81000034270748, 7.1390485859686335, 6.181548506982866, 4.933637611327633, 3.863842525789815, 0.9030765799745437, 0.4082143631192946, 0.1019316832084329, 0.36899979316419174, 2.0213183303994517, 7.7137944679106445, 13.538619587498328, 20.398138992248043, 29.66697623652797, 46.21123160085371, 52.31223129457044, 49.89758883753131, 54.0764114164537, 38.835112510188935, 17.12044369789862, 2.198124436601516, 0.11205727414738749, 0.08041945165924488, 0.060621820645587104, 0.030347761067171252, 0.06086236842337155, 0.05407844917968877, 0.05843748180796543, 0.0464170451666559, 0.010926781969535495, 0.050565974351259015, 0.06565408751128182, 0.0871829584901852, 0.03489448906733625, 0.06519420493033624, 0.0043976089857038, 0.027501949356989037, 0.019710082485671007, 0.02131098791235878, 0.011096081655142049, 0.02690957186953916, 0.05137358807147511, 0.041573668770011396, 0.014193639433341882, 0.04076605888023492, 0.058913367965649215, 0.009150722987889763, 0.016638487427225037, 0.04077302261946663, 0.019750635349942793, 0.022739339694981615, 0.004352932653179573, 0.06655392672626242, 0.18269975849938008, 0.28288464632726484, 0.1598834997463611, 0.12334140453247294, 0.20766451083604368, 0.1594022433123281, 0.15204491874864026, 0.19130245091453676, 0.18371716922810002, 0.14406969830874475, 0.19614961178552723, 0.09537894248722062, 0.187652884652057, 0.1366822664896327, 0.1913489524515406, 0.148137686473708, 0.15168741615789552, 0.14576975466503253, 0.08652593850368455, 0.13200742943632987, 0.13461747567259497, 0.19587273228793375, 0.20062250806198967, 0.1968893922504879, 0.23888141397506962, 0.17114712195771356, 0.12906952821198972, 0.16235580337384056, 0.13289541727112186, 0.1639376063981364, 0.20649509294138801, 0.11586606412404969, 0.14937689497826562, 0.15849498070536122, 0.171071601010138, 0.5875368536480012, 4.87446669609316, 23.51076526026572, 53.91396253339706, 61.14041574539677, 63.316174091831336, 63.18274682567966, 81.70730883075346, 88.94958880639847, 88.9112437155939, 67.19239757907006, 27.41266654383752, 8.97442021677571, 2.228982948487805, 0.4564630402432334, 0.6174027607325585, 2.4902495741844177, 6.520262331731859, 10.43870670180167, 6.885038835387077, 7.799861075416689, 4.9515643139039325, 6.58183716958569, 5.752844723962969, 10.575426797713003, 15.324940508411778, 23.551455928433327, 31.769731429315385, 46.22638763919954, 55.88889552700905, 59.117041480156686, 62.43433506258073, 60.52256791822372, 57.60672500056606, 58.63484882539319, 57.53462399205854, 56.47665093022009, 58.36222840893654, 58.896435614555116, 58.16835741842947, 57.26188982686689, 57.69531173090781, 57.226706166421216, 58.09740174201227, 56.74368589155136, 56.597895314616544, 52.976159126527854, 56.035486267459014, 54.09215581032538, 55.32785930941182, 55.93446562367102, 51.65793288138605, 45.27467158532912, 53.97315502166749, 40.45692236192765, 47.14631288282333, 55.307510052957845, 57.12533250931771, 58.244961307894805, 58.457114465775035, 52.515814073624156, 48.58737207228138, 45.17180742756013, 47.71718640481272, 50.18142331031061, 50.42586934181952, 53.161318532882206, 51.95031419877083, 55.96530329796576, 53.240852432866255, 53.57399894345192, 56.115475162383056, 56.03980479701873, 57.84862149146296, 58.228397138657115, 56.71673920846755, 58.75940369021509, 57.87605454844814, 57.50089945331697, 51.647299335848906, 48.580437321816724, 40.14140298289638, 30.77609112185817, 23.720496354564546, 15.264595823903239, 12.938546961353673, 11.041944680675384, 11.987814441803964, 15.301648493736023, 12.004002063505112, 16.919820347139915, 9.460509746305405, 8.56287141000071, 5.804616087867368, 1.8403752268322053, 0.3110254153368935, 0.8277586150553919, 3.2851281858259633, 9.137950693407367, 17.924590379961078, 29.19597410386609, 39.555957855716834, 55.62227241454586, 57.53432589192545, 58.756916907525834, 61.82850929998583, 42.768014246417636, 19.095976814146965, 2.7483096622651626, 0.3041709508867033, 0.19037447329009735, 0.11690078077897911, 0.0811184149595999, 0.15502273315383544, 0.16766116143234316, 0.14606797737219643, 0.20112346827743516, 0.10040742870900901, 0.31070773399645285, 0.23717294597337324, 0.21035165616100837, 0.1106298071963172, 0.16899962428837054, 0.2894141975670092, 0.17622053923626102, 0.1480891624645841, 0.14451338579097103, 0.08510465388216319, 0.12076003296721367, 0.1083280424016618, 0.1492168745326419, 0.1507773343473673, 0.11776230793686644, 0.11698994575248611, 0.07361786259758858, 0.1349201416897197, 0.13184606067595944, 0.10940097918313359, 0.0970681740211383, 0.0816829834553984, 0.12454466053074408], [0.03877609570120131, 0.07420553630518337, 0.023183776028153878, 0.0701457452810099, 0.025157500058412555, 0.08245884666159269, 0.029833901846300692, 0.044526818974484364, 0.00673719171074129, 0.0431040289901918, 0.097972180754427, 0.015002419522422698, 0.0439787941474107, 0.029645298660222082, 0.01553741415151425, 0.04570177951527219, 0.05622805742126319, 0.03324144369652195, 0.01318962566719781, 0.02530670334254542, 0.02081655668124797, 0.03545889668467064, 0.03066079799957093, 0.05053911530863374, 0.02644737187262264, 0.04580736941387577, 0.0282013320904826, 0.002792485526785435, 0.012964599788369191, 0.019170984498135025, 0.06527599247713244, 0.03813190385699272, 0.07868772522816736, 0.04054118526138125, 0.06888672574273041, 0.10494312887350399, 1.8296700980394118, 10.89589326612411, 33.18551094301286, 46.28700787021268, 42.82457090193226, 50.73625826066541, 62.80105706184142, 78.42431637548631, 60.48086920092183, 24.036706070746146, 15.77433430379437, 10.259664231731046, 4.032218845621232, 0.4164736796050303, 0.20154705361252834, 0.5548896183890681, 1.2217306682179052, 1.6403746749124222, 3.0959478597487173, 3.4692763561202637, 3.220946687844492, 0.8413835194322371, 0.6723085887009098, 3.376401249439486, 7.921382477206569, 12.492419519732076, 23.212988722708918, 32.612940995923935, 45.269125353905466, 54.73972343629407, 58.321514206547896, 57.54291588260282, 58.72562031592093, 56.38595396472562, 55.19186681316745, 53.50144294000442, 54.53820382395099, 54.79800201231434, 57.56209235037527, 56.40979413063296, 55.43207668489026, 56.23989666661909, 55.73919042464226, 52.42966705752958, 55.30816116640645, 54.91349620203818, 56.081197569447184, 53.7092383446232, 54.781614349734404, 53.44774176997524, 57.01236824835501, 55.54143236529443, 55.840497401452836, 29.270044142200103, 39.91971062075707, 55.72981203756025, 52.382174999483176, 54.1983029919286, 49.635417615213704, 51.78950486644622, 47.075973018523186, 44.18808875545379, 39.266820338464555, 42.10582010207638, 44.480799551933046, 47.05580419109714, 48.50125251277801, 50.62203099650722, 52.009016390769716, 51.85477310611356, 50.93210220336915, 51.61251575716081, 52.85320458873626, 55.703343883637466, 55.49330880565029, 59.540210308567175, 56.16232787409137, 47.79373930346581, 48.490669958053104, 41.2740344385947, 31.570626035813365, 21.11849992505966, 14.317185551889482, 9.643987436448375, 2.2185835194203163, 2.3562677829496326, 3.2680271421709373, 5.573653203825797, 4.297580180629607, 5.285823797025989, 5.019993493633886, 2.1248856955958955, 0.560510436133031, 0.22800118812630255, 0.5720890890206061, 0.44680331503191306, 3.697493090744942, 7.347547075440807, 18.90489462883242, 26.862073636824086, 24.192912501673547, 46.61018371582032, 35.855691894408196, 43.68425246207945, 39.086399155278365, 23.78140684097044, 8.38398975710715, 0.8079718509989401, 0.028486161665510268, 0.0163066832559003, 0.04793863751054291, 0.027230827010146556, 0.02151937723430174, 0.01863334016243537, 0.03839407446643999, 0.04165019329276778, 0.031131673942229925, 0.01978492927587321, 0.017946356561996283, 0.026980936790125507, 0.11296888813376428, 0.049532636654593294, 0.016523486138471676, 0.04704116167680872, 0.04621473283717229, 0.03834757292943616, 0.03062550815933895, 0.06687712389975786, 0.07163904216741362, 0.060798128120481014, 0.015312609480573766, 0.03812127821748296, 0.007389637673529046, 0.024255414290594, 0.02025173154599484, 0.008734059257192478, 0.021040095391893582, 0.0391159093217744, 0.042064876686180794, 0.07506691024548585, 0.036801630480875897, 0.03906849230970106, 0.04113724763174692, 0.07928797809947884, 0.0485746858401164, 0.08722300190598735, 0.030513291600190347, 0.02881360679654585, 0.06020172101054942, 0.017958669510159283, 0.04443882228506189, 0.041175647788951476, 0.0223550470095248, 0.010829059793914278, 0.03554397457910161, 0.06375140089902186, 0.048229570891107285, 0.02950380413582729, 0.03517616044489607, 0.0337834011072353, 0.03707316268475787, 0.034873260770954435, 0.032163305178044305, 0.04328778667014934, 0.05720878786016857, 0.014176389048506897, 0.04280535429115257, 0.022083014933272235, 0.029412612859760563, 0.0659021927464393, 0.06951814307080162, 0.037893639021222635, 0.06980000980078213, 0.03442647063263482, 0.04370806250540961, 0.0976130004311281, 2.4556809904113894, 14.63589087609322, 39.89248544939103, 52.89681742268225, 49.87348587282243, 55.84752628880163, 69.01138105700093, 81.68095050319549, 73.25886080341955, 38.726325573459754, 17.141269522328532, 8.832231356251626, 3.4027277077397997, 0.2469710113420602, 0.05044686300079188, 0.060269772600863254, 0.6913596019148828, 1.7554464743983362, 2.9083413847031134, 4.438647243284411, 2.3130734168714095, 3.146863166363009, 1.9514030626704617, 4.147435282507251, 9.481612097832466, 15.282655396769124, 24.50658444435366, 35.765249882974935, 49.753202469118186, 55.47438336956886, 60.13856787835399, 59.19120565537484, 60.30107559696321, 56.73086366345806, 58.48238629679526, 56.38260426059846, 57.91759244857296, 56.63414585974909, 58.93038765076668, 57.69445665421025, 57.996314417931345, 57.13482856750489, 58.40694342890094, 53.54240425171391, 56.15287888434626, 56.10371981897662, 57.45530974480414, 54.25361233372843, 55.296884352161044, 53.67725533823813, 56.15379671896658, 56.19831954279254, 57.06882684461532, 34.78048786040276, 43.328960249500895, 56.40448716378982, 54.38813394115817, 55.708517489894746, 52.32559873211769, 53.406027363192656, 48.98752835489089, 44.912581905241936, 41.64089764318159, 44.620592824874386, 46.71837445228331, 49.4342980846282, 50.22367900417697, 53.56328695051132, 53.53096662029144, 53.288238586918006, 53.90974206309165, 54.637380953758, 55.0471156643283, 57.46060886690694, 57.10842709387503, 59.31750989729359, 57.61302040469263, 52.453083607458304, 51.100089473109094, 43.2170864074461, 34.10294548157723, 25.102163014873383, 18.10991060349249, 10.727072492722543, 5.083262795402158, 2.96868680465606, 7.251110211495431, 9.331294125126256, 7.220864815096702, 6.440987798475451, 4.509260202607801, 2.582741514328988, 0.968432705248556, 0.14843627690307556, 0.3243277047670657, 0.6371411080321958, 3.461132044753721, 9.113630037153921, 19.38791294251719, 28.426520785977765, 29.796285013998713, 52.15259082855717, 43.203542463241085, 50.34979104995728, 46.342701604289395, 27.573883802660053, 10.431367947209267, 1.1049743333170492, 0.08067345577141932, 0.05698265019623984, 0.04028011781854495, 0.04306119701434528, 0.0045077887085837225, 0.0785534146932825, 0.024081759395137913, 0.014516173940782827, 0.012854349202356272, 0.024051851322574, 0.07275465770714706, 0.029626759332454497, 0.09102885010502032, 0.023009874069342212, 0.04293096972809684, 0.03974936827416382, 0.06445273907194216, 0.054136779114243486, 0.015145158939694446, 0.0064431274245913715, 0.046690645807933424, 0.039332271703789314, 0.043620356929398356, 0.037365578445455724, 0.036686035473981214, 0.03449958989456777, 0.017176461180732135, 0.021196076638936516, 0.025646591656691125, 0.002320130316225151, 0.06123128572418805, 0.028047244995832447, 0.11792196832116573, 0.12199063830438162, 0.25944079302491685, 0.13807714406040408, 0.11125986088788319, 0.16752721861966197, 0.10401608587633218, 0.15700850966236285, 0.12480737506261758, 0.1575434688598879, 0.24684350366794297, 0.13317372169225447, 0.17453410392326696, 0.19983968877744293, 0.08168838437526457, 0.10292342233081019, 0.1600162781053974, 0.0973502322730999, 0.08466029224256355, 0.08970305834326053, 0.10187953560342712, 0.1693508143146192, 0.2337929507296893, 0.1714411771465694, 0.1399375885845192, 0.10470725040161803, 0.15340878508023678, 0.11380679680094605, 0.19174989222759203, 0.1124808518216014, 0.19011742014798427, 0.1471393206907857, 0.1671532451385452, 0.14201068379465612, 0.1131192482106628, 0.21030772867943012, 3.001774938837175, 17.22682818289726, 42.40340640467983, 60.05142065786547, 57.57570297487321, 64.37422952344342, 72.08662909846153, 85.9226094522784, 67.3765528586603, 32.643698261630156, 21.734670938984042, 14.086211881329938, 5.54558031020626, 0.7447369312567096, 0.76526845534963, 0.9940246384470695, 3.4561293067470675, 4.478781915480091, 10.096474020711838, 13.759613767746957, 9.015332498858053, 2.8416816842171455, 2.211327870045939, 4.811428814165054, 10.738381666521873, 15.996608157311718, 25.09218450515501, 37.16659115206811, 49.95509862899781, 55.871142879609145, 58.700717187696895, 60.887697435194454, 61.63721530668197, 60.96824330668296, 60.5025795198256, 58.68707910660775, 61.18160455457626, 58.56084938972228, 61.14022354925833, 60.53582160703598, 59.2322571815983, 60.486509569229625, 57.706568933302364, 52.30104861720916, 56.986974823859434, 58.34561324888661, 58.76374967636601, 56.69480923683413, 56.81155466264295, 56.04295053789693, 56.898399860628196, 54.55648599132415, 56.976474638908144, 40.25259433254119, 44.82864318355438, 56.26951840616042, 57.026943775915335, 58.016942162667554, 55.66239041666831, 56.268176955561486, 51.75736104288409, 48.81260241231611, 43.612339727340206, 46.204940119097316, 47.55765968753446, 50.699576254813906, 52.06491408809539, 54.89244091895319, 56.35643812917895, 55.53070860524332, 55.162350977620775, 57.049944554605794, 57.29724214922998, 58.967732537177305, 57.70558049601894, 60.24984552014259, 58.5206647073069, 54.2178403177569, 53.313361367871686, 43.376397394364886, 35.32572477094589, 25.51726156665433, 20.941402950594505, 12.440778574635907, 4.984502417425956, 6.54023160857539, 12.460923867840922, 14.446302133221781, 10.594144348175297, 11.294916964346363, 12.687323074187002, 4.521154299859078, 3.2363272818826863, 1.7923192054994646, 0.9510225910813579, 1.1780740753296883, 4.845040584764173, 10.995911744333084, 26.632044276883526, 38.412194713469475, 33.699376736917806, 60.315356946760616, 47.69815114236648, 57.243607659493726, 53.771058820909076, 32.23453425591992, 11.356421689833365, 1.1594647577693387, 0.2715688841717859, 0.17318013544765212, 0.18091442123536142, 0.0898982575463672, 0.1490142749201867, 0.19210581667721274, 0.12185556168157248, 0.11510310949937952, 0.13069936494913795, 0.09791545194363403, 0.18316558592261808, 0.1243107126004273, 0.23620595915182946, 0.2021349954508966, 0.15500437768716968, 0.14105318114161491, 0.19254562775454215, 0.177577541420056, 0.1887393352245131, 0.17889619324236147, 0.13594320614732083, 0.12989691849197113, 0.12179317914189831, 0.17777772019467047, 0.11220801726824815, 0.10052462483966544, 0.07627388943106898, 0.12377866453701451, 0.10916323911759163, 0.1048651717663292, 0.16283810168745058, 0.22238656037276794], [0.026630819286970843, 0.06221480472313781, 0.05052260228342587, 0.03939398008609011, 0.054308497722470955, 0.037736361170367855, 0.05954101997157259, 0.06623713404781396, 0.057661476875505144, 0.015479368627101425, 0.02916314781853749, 0.03248683176934719, 0.0856741636450733, 0.009757161061579903, 0.017721590195452015, 0.00540581037996397, 0.06691955750988376, 0.08835106637449035, 0.03059828522494964, 0.08379223801556133, 0.019447810369573777, 0.0792712007739371, 0.019614118481836012, 0.033469952402576324, 0.021093342333070694, 0.05426901738129316, 0.03460495762767331, 0.01523303880070847, 0.031557693521702485, 0.032394931861950506, 0.021489019085082318, 0.09572781892793794, 0.044483014066974004, 0.029432469858757915, 0.08814195501467875, 0.03783771460275016, 1.1260929871951382, 6.471864206175651, 28.791010956610407, 47.223073667095555, 47.694303297227435, 44.593281361364554, 40.97562836062524, 45.644908028264204, 40.36458584570116, 32.55123230718797, 30.68659047926626, 15.469003281285687, 3.9383280902139606, 1.1131264894239365, 0.0939941925988082, 0.18951556615291104, 1.9390764015336193, 6.291511174171202, 4.417593921384504, 1.7762898269199558, 3.5067450423394484, 7.462615688000956, 4.473803447138879, 2.900869514672987, 6.051458197255289, 9.315685053025524, 17.02998011342941, 31.18451576079092, 38.782360553741455, 44.05149613657306, 57.43895738355575, 60.71320295333863, 58.147835577687914, 57.336579599688136, 56.954254411881976, 55.04990054715065, 56.273115219608435, 54.37464098776541, 56.19375390391196, 55.55122260124453, 59.8723566147589, 57.099076163384225, 53.49117417489329, 55.187936598254794, 57.31666180395312, 54.92861693905246, 55.425263527900945, 53.12911195139731, 54.48194526856946, 52.8030570860832, 55.61079948179184, 50.720188310069425, 57.21726109904628, 28.689031293315274, 36.70093913232127, 59.092581579762125, 52.12125893562071, 53.41861424907562, 55.12839501903903, 51.563258632536865, 50.68415349529636, 49.069121499215406, 40.96966243559315, 41.70687583185012, 43.82887417270292, 50.92601860723188, 51.14026238841396, 55.41352779634538, 53.767764029964326, 56.096204557726466, 53.73196847977177, 51.95180077706614, 52.61142184657436, 54.52000010398127, 53.893523062429125, 57.24161509544619, 51.02250106873051, 50.10718068768902, 44.39735504888719, 37.530112497268185, 28.012481274143344, 19.879933095747425, 12.979079754121843, 6.795306772955003, 4.618520765535293, 3.648765976390531, 4.917372522815581, 7.600859134427964, 7.712046071406334, 4.724464964482093, 3.8504375805777893, 3.2409949023877425, 0.4570625500092584, 0.07820691312513045, 0.2636557168537571, 1.2317938766171856, 4.629624995493121, 10.061704170319343, 19.806463180049775, 30.796858110735496, 31.873434974301247, 38.46211471865254, 37.102785956475046, 48.23975201575987, 38.282595680605986, 22.243839694607644, 4.348419001025539, 0.3586104764573036, 0.035880026707966486, 0.03509916094762664, 0.04163520861296885, 0.017313334279723706, 0.0354829250324157, 0.04039527232488317, 0.03624145549932315, 0.005963023952884419, 0.05064129228553465, 0.03259098908353237, 0.0770522271012587, 0.028201266973009034, 0.039645865965153904, 0.09102515756122528, 0.04531556777956505, 0.0560381327335152, 0.0383932356001629, 0.06360646472462723, 0.03272784303032583, 0.09024472847100228, 0.011766404758447842, 0.04994947275507355, 0.10062108297021159, 0.051474612086049976, 0.0685074279505399, 0.06603428928722298, 0.05187889583589089, 0.036788411633742434, 0.03807660763061816, 0.002161366733602218, 0.04030289744297343, 0.04227301128388893, 0.09954835303247937, 0.07316054641118935, 0.024579819967789997, 0.1000010497086952, 0.026925092810885082, 0.09432603124408953, 0.00831500054412191, 0.04718171965871607, 0.0809568010510937, 0.026518621880020347, 0.04390892692871633, 0.08965409766401976, 0.015914030635969776, 0.06014937039224371, 0.056831899414499926, 0.00853258100593643, 0.14389803332667198, 0.021486280320753014, 0.03771419824671842, 0.08046773818111227, 0.07869488048938014, 0.011557497369546083, 0.010969313255871737, 0.06580740468756807, 0.040046974280548674, 0.0717561770110361, 0.022125701352413145, 0.0361613380242019, 0.0646193708563524, 0.033362014444484826, 0.045254817007169615, 0.09452385812877648, 0.05864846625275189, 0.017357717583616896, 0.08789905151652713, 0.07565861357556236, 1.4468476272398427, 9.096343171211982, 35.57823519552908, 53.74604194395004, 50.6395169227354, 48.497604708517756, 48.097275841620664, 62.3258658378355, 44.623585593315866, 28.027029345112464, 28.3841807611527, 16.183206092926763, 4.473869637135537, 1.1389029578816507, 0.0931168150817675, 0.2271349878320771, 1.454409834358, 5.260975581984367, 8.033877034341137, 5.528627336025239, 6.477124594872998, 8.131655839181716, 5.517568703620665, 4.866956828101989, 7.521951833078939, 11.843417286872866, 20.61963131350856, 32.35813794597503, 39.405146644961455, 48.75539072098271, 59.7157952093309, 60.51442115537582, 60.61791681474256, 60.84963867741247, 59.85454905417658, 57.70638065953409, 58.24676559817407, 56.02051458051128, 57.66782376074023, 57.33267684136668, 58.63971648677703, 57.84984527095672, 54.25884869790847, 56.28001074637137, 58.79064929100775, 56.561323135129875, 57.51937773919875, 56.63546377612699, 57.17739805098503, 55.70377142198625, 56.100880022971864, 51.885383282938314, 56.8888214326674, 33.37300808198991, 40.739564434174575, 58.05551082857194, 53.82900791783487, 56.44707233675065, 56.82433374466435, 54.06760569541685, 53.358339186637636, 50.61857538838541, 42.63453598945372, 44.71468656293808, 47.113180621977776, 53.54174529352496, 53.55282206689158, 56.04219352045367, 56.25205601415327, 56.33142125221991, 55.07721201066048, 55.06156175367294, 54.84649819712485, 58.35122223823302, 56.06712018289874, 57.86383636536137, 53.83500522182834, 52.771258431096236, 48.73262528450259, 39.162453912919574, 32.03247531767815, 20.72742000702889, 12.994768254218563, 8.560914147284723, 3.303706737295274, 3.157375853869223, 5.985258884968297, 7.024893885658634, 4.248757458502247, 5.440096989754708, 4.749335242855934, 0.8727199476092093, 0.8571845425232765, 0.1456449895856842, 0.0892180557392778, 1.0798636871960856, 4.916193850578801, 11.444186683624022, 24.001555750446936, 29.858758564918276, 28.665418624877933, 45.45668917317545, 40.82668419807188, 51.52729049805672, 42.774184134698686, 26.704180586722593, 5.813396803794369, 0.5144613200137692, 0.05443893951333819, 0.07142563305434681, 0.0210122864002422, 0.09896198167435585, 0.03493301179860869, 0.012937439098623733, 0.01096656491544338, 0.044747865984156254, 0.05888567388718648, 0.04464661980408334, 0.06966169262605329, 0.023473682850899718, 0.036290806883405295, 0.03201939556146822, 0.0809464588641159, 0.04441577836029953, 0.026101935166685332, 0.05101480611389683, 0.10459380044091134, 0.0583931980955024, 0.02496189674392583, 0.05115456353392332, 0.040114765400968255, 0.06676066321350875, 0.03896818841777502, 0.10396041426687472, 0.027482312608269915, 0.027627899957400177, 0.05739446075993681, 0.0598778305274825, 0.05540958823516004, 0.05265194749940307, 0.23829865089106947, 0.26481303055920913, 0.15020082254082928, 0.17943987052046484, 0.14777227785558472, 0.1865878692197223, 0.2793620208338384, 0.21321363807205232, 0.15836451593185627, 0.17783100927068343, 0.12648187472575134, 0.16586649321740674, 0.08112638227401242, 0.07542782958837287, 0.09660824547491728, 0.1493638101965189, 0.2383524762286294, 0.09701044929604377, 0.10910103277814005, 0.17187358781455025, 0.17004338844168573, 0.21294038983121996, 0.1107288163996512, 0.24629362107765293, 0.11954670291273825, 0.14539118465637008, 0.16435333167112645, 0.09374739737400124, 0.12232737991237834, 0.11086646707788592, 0.13035687768170912, 0.2813958004117012, 0.13863372225915233, 0.15420856555142712, 0.2419562304332372, 0.14482142974532422, 1.5521463511451599, 11.92836307710217, 40.900307086206254, 59.01312612718152, 60.94051214956469, 55.26364226495066, 52.927204024407175, 56.658397874524525, 48.24324292521323, 47.5269083053835, 40.28347515290783, 19.291146109181067, 5.7271463351864975, 2.0094284006664833, 0.2549016301430041, 0.9153382155683734, 3.696932682106572, 11.940091944509938, 8.869016324320148, 5.460508513835169, 8.321570138777457, 11.965416727527497, 9.393843181671636, 4.444119930267334, 8.251394033432007, 11.569778034763953, 19.61475537669274, 33.48568208755986, 41.59611594292426, 50.11596287450483, 60.72735486492034, 61.31676158597393, 62.692509389692745, 62.58754284151139, 59.682992427579826, 57.9035464409859, 59.11845353341872, 55.93699555243216, 58.21134267314788, 57.3496057910304, 60.63511640794816, 57.94381741554507, 53.97255097666095, 56.16223765957741, 60.01207928503714, 56.78588274986514, 59.393035134961536, 58.30417733038626, 57.715515859665416, 56.054172438959924, 57.35252795680877, 54.232149124145515, 56.56892861089399, 39.38630750102382, 42.981540233858176, 58.961723466073316, 54.01519890754454, 56.99636497805196, 59.975911109678215, 55.70248488456973, 55.63691462239912, 54.296762327994074, 45.63248588192848, 45.806125287086736, 48.73966201659172, 57.031113255408506, 56.058640018586196, 59.479260598459554, 57.84886860078382, 58.424774523704286, 56.93778045715825, 56.14439479766354, 56.866864004442775, 59.37691811592349, 55.24024924924297, 58.54499516948577, 56.00577431340372, 58.045034177841686, 49.23779910610568, 40.791378944150864, 33.46482684535365, 23.964563877351825, 16.099822386618584, 10.865378206776036, 8.380232126482072, 7.7025588385520445, 10.099652121143958, 16.21914480963061, 15.694618994189849, 14.34251327668467, 8.839356341669637, 7.041653192812397, 2.387403557377477, 0.7826068024000814, 0.5143290625945215, 1.7776413285924544, 6.561834552595693, 15.149898855916916, 27.981894631539625, 40.095170005675286, 42.17140997609785, 50.74627991645567, 49.41208962471255, 60.75786698249079, 48.45427820759435, 30.039287613284205, 6.810695211733542, 0.7385903320485546, 0.13763862001078744, 0.151269561160476, 0.16169178900459122, 0.17245258174596295, 0.1200626707906204, 0.09108993795610244, 0.13934986125076973, 0.11607938896744482, 0.12483357526962796, 0.147118222629351, 0.1960689120835835, 0.14033714940230693, 0.12168913674090179, 0.16205319864374979, 0.26548066086346106, 0.153653948537765, 0.18568388546907133, 0.22726249550619435, 0.1670383472716616, 0.1026821889043335, 0.16593082928128783, 0.20974767244150563, 0.17811227079120376, 0.16682214193767117, 0.12729987276778107, 0.17644164753296684, 0.1385864852777412, 0.10172349881500968, 0.08181834353073951, 0.12022829899984984, 0.13745673541580478, 0.13908660279646998], [0.024534555662783886, 0.02163996904968254, 0.13586716425995674, 0.04800242582155813, 0.04749018879186723, 0.03554727641805526, 0.030103821435102054, 0.0514270993129861, 0.01956598326233366, 0.13191477876276742, 0.09702800803126828, 0.022074750759789062, 0.024166034812468196, 0.007406691748333434, 0.019321643349324024, 0.04098563117065257, 0.1161442076667182, 0.08612634704237984, 0.03482063053055637, 0.017932423337873434, 0.028702638960713824, 0.019326799121054433, 0.009004901024332691, 0.10662577205127287, 0.008965827667364671, 0.11126683228799414, 0.05867940854401358, 0.018377809620071805, 0.08472332595697335, 0.07508472945060461, 0.04506341376972776, 0.023687534379742803, 0.004462402308314678, 0.04290267044017392, 0.04675282150386803, 0.03199151379146403, 0.13754675074690773, 4.951126479333447, 20.09124686641078, 41.75012388537007, 55.327565131648896, 44.99015854251, 34.77034068876697, 17.485747760342015, 31.889842248732048, 30.21379778462072, 15.793028320035628, 18.09803758898089, 6.4097569065709274, 1.5432641438899504, 0.42282102449286374, 0.06569978465596515, 0.2683450636123457, 2.1997007391145154, 2.6054591469226347, 4.687756972928201, 0.8331432325705406, 3.7756546514649547, 1.7082157442646644, 1.3830343417582975, 3.3021851028165514, 6.063728842043108, 14.427219802333465, 21.12697812818712, 33.7461902249244, 39.17337771384947, 48.85261058807374, 51.66118060388873, 60.822574323223485, 55.663323940769324, 55.3896366396258, 55.01864317924746, 54.66436686054353, 52.576736327140566, 56.88313007354737, 57.34471851779569, 60.121372207518554, 54.794232614578746, 56.843314093928186, 55.66078224489766, 56.73319355134041, 54.92203912427349, 53.44986769460863, 51.05846920321065, 54.20877572028868, 53.07932138442994, 58.3242206419668, 53.25552209731072, 60.130695681418146, 29.74181898178593, 36.34752181268508, 58.898322274608, 50.494212719701956, 55.060769434898134, 55.658240549026004, 56.19398924612231, 53.81480501544092, 50.015656102088194, 41.45946056612077, 42.188174186214326, 45.27159644711403, 50.645714267607666, 50.858655821892526, 53.491817443601555, 56.43558763688611, 55.87550847761093, 55.863925718492084, 54.48765623954035, 55.71546008509975, 56.24573707580567, 57.73524538163216, 54.87908524851645, 54.51330461809712, 45.86503536470475, 39.75562218696841, 33.95213034845168, 24.575914298334432, 16.87053772710985, 10.28591371351673, 4.36319358887211, 4.11420839448129, 2.0052737526355253, 5.332540206370815, 6.8065154360186675, 3.0038832128047948, 4.383711016947224, 2.27273061390846, 0.4192455082891449, 0.8368228448014107, 0.031103575752387126, 0.4220497578142151, 1.3191059592270082, 6.402660848632936, 9.917351142052683, 16.736578979799827, 28.056733454427413, 34.399257013874674, 41.800396903868645, 42.07971672857962, 51.30232687919371, 38.99697303771973, 14.253913798639852, 2.1077694527564512, 0.07527691026728961, 0.04106214037165046, 0.04101937734371713, 0.08454609151569106, 0.04164974896177169, 0.052046837630651654, 0.0848020491520724, 0.061045823498598994, 0.031113004379515207, 0.052034645341336734, 0.02535508371018354, 0.04206764992446669, 0.06932312006791753, 0.017050868726425597, 0.0223475297717678, 0.0337140663196483, 0.04688458096596503, 0.017468516880105582, 0.01821489527731413, 0.02540478749471086, 0.027960355303460555, 0.03018712009032888, 0.05594318379617988, 0.04728615659499361, 0.08303697491365095, 0.02561851836470587, 0.032503149442134366, 0.049903063148620634, 0.017615885383659796, 0.07348049537188585, 0.036274270875559705, 0.01457112255476175, 0.0576901936813468, 0.03636487992480397, 0.042267828699081175, 0.11646588798612358, 0.04677690730820741, 0.021644444918380152, 0.05115049177660577, 0.06990137089404368, 0.04309674349403189, 0.04672732226730836, 0.042651550649034406, 0.091378684155643, 0.06509478203952312, 0.03196138163818227, 0.04461832434660004, 0.10056088378112163, 0.020021886016512593, 0.008526038615063073, 0.04320522154411001, 0.05283655553695656, 0.022532511277184374, 0.034949555467333526, 0.027885460632763086, 0.025607796964205565, 0.02547736666465719, 0.017527063234498905, 0.05049480095265373, 0.059654037092602065, 0.04781616303408819, 0.07727186450914991, 0.06492913084765596, 0.06575729487644089, 0.031297537723496076, 0.007009435897587889, 0.03672586438516456, 0.06969271152610741, 0.04243989587731419, 0.29801892777604444, 6.542094244110969, 24.928150984548754, 51.37917395560972, 60.58222324617448, 50.83350950671781, 39.85858048162153, 22.328325586934245, 37.1598485977419, 34.67689021941155, 23.849879657068563, 18.3623053181556, 7.854806127086763, 1.5895349964980157, 0.34645161921939543, 0.10760562914994456, 0.527267858626381, 3.8948893114443752, 5.442079257580542, 4.166384252809709, 3.827953574157531, 3.240888753244954, 4.425375903806379, 2.8136232543376187, 4.379388565017331, 9.2849572050956, 17.166859065332723, 25.491956395487634, 36.249996000720614, 41.874043326224054, 51.152574708384854, 55.87441021396268, 58.65081679436469, 55.13239191424463, 56.14649326570573, 55.5013967329456, 55.817747654453406, 53.99279432912027, 56.03036365201397, 57.24611797640401, 61.43873945359261, 54.94531446887601, 56.348193307076734, 57.193052230342744, 56.6731930548145, 57.0341609370324, 54.9381326090905, 53.26808152660247, 55.1491718138418, 54.029621462668146, 59.22734245177239, 53.98012507346369, 59.02428919269193, 33.1757285518031, 39.36929225921631, 58.024943797819084, 52.032727118461366, 54.98210630109234, 56.85856819152833, 57.87909438533168, 55.576035514954604, 52.10365533828736, 42.814957172639915, 44.70670846200759, 47.40730347171907, 52.062929368788204, 52.96495683731572, 56.05532953816076, 58.098523539881555, 57.749856210524044, 57.6998185342358, 56.09785979793918, 56.98423308710898, 57.43637646398237, 58.12138311324581, 55.73649575633388, 53.72088778403498, 51.65663849922919, 41.89821297122587, 36.15256824801045, 27.195480985026208, 19.31645912508811, 13.81543399826173, 7.234014561099391, 3.756055303158299, 2.4664461804974467, 4.932409419167427, 4.267589247995808, 6.795820113151305, 3.53281139846771, 3.449905731024281, 1.2123598807281064, 1.3644301723087988, 0.07972595056578999, 0.406288908373925, 1.3555435523871453, 7.019156928985351, 11.600333298406294, 21.128429405150875, 33.10707922904722, 37.34452947493523, 46.20693268314485, 48.17998686144429, 58.54740742714175, 45.39437055587769, 16.96335473368245, 2.681418296790892, 0.33556462115337776, 0.017511113283915386, 0.014534020916588846, 0.06443015479993436, 0.05519507212504264, 0.03784022354070218, 0.08718929403731901, 0.08619884960353376, 0.07352763276186682, 0.033271573934583895, 0.10560064681715543, 0.06642272650835014, 0.052812013910302234, 0.04282927155614861, 0.03205752950311909, 0.05926115273107445, 0.008747954176919115, 0.030675162148151188, 0.024267731069196618, 0.011680434371585087, 0.03969907460193481, 0.020079532217594887, 0.06925283150086481, 0.04490727355944053, 0.06779289774356351, 0.025004654026199735, 0.051277712167751406, 0.13253184726401684, 0.08942496842674671, 0.010138167229841554, 0.08355903319053112, 0.010019441796166283, 0.02416833882190047, 0.0787664101188702, 0.08039552673336961, 0.22496282213157226, 0.23660922783517072, 0.10616763615079465, 0.1676505740972296, 0.18020113209082236, 0.13077272552876704, 0.08431598934675417, 0.15988952119744596, 0.20799978155522578, 0.17776319516762612, 0.13704497847826252, 0.14575915200816048, 0.23556042282331377, 0.1370003615175524, 0.2542797352878317, 0.1818407441098844, 0.24529113374169798, 0.09531496648466396, 0.11756532374889621, 0.20372891798615458, 0.11602085218915056, 0.3388524866632877, 0.1812796153488659, 0.10836753423415846, 0.12464276575032743, 0.1748499466526893, 0.2314244060506744, 0.20652602757177047, 0.11639246611946052, 0.11100385728622637, 0.04818242200980744, 0.13442966155707836, 0.14791509196642907, 0.138688390293429, 0.5457189943521255, 7.618025387487105, 29.523790113387573, 58.89951859751056, 68.51596217001638, 59.041061247548754, 46.66783863498319, 26.847823665988063, 43.43198522444695, 41.90958392235541, 25.054653306161207, 24.625742127818448, 8.708000086968946, 2.540693460933624, 0.6106712993594908, 0.3449996374547482, 0.8185932617033682, 5.445902097609736, 6.003445934864783, 12.454380373800955, 6.1743141854963, 6.9951127998290525, 3.8538343531470147, 2.7596764458763987, 5.425057641921505, 8.817993152526117, 19.920798309387703, 25.38861959211288, 37.82283506085796, 43.230799013568515, 52.810854757985766, 55.74379528722456, 59.016832766994355, 56.0561453911566, 57.548756291789395, 54.62857523272115, 54.59029289983935, 52.46859658148981, 56.57304709957492, 58.1314165361466, 61.710736213191865, 55.12953642875918, 57.131078781620154, 58.70994652471235, 57.917117841782115, 59.91026240010416, 57.557899336661066, 55.75323643222932, 57.478385048527876, 56.152133634013516, 60.793015341604914, 55.60825778592018, 58.81059062096381, 37.93727021063528, 41.97925698372626, 57.949928468273534, 52.524855136871345, 55.06083219282089, 56.870001900580625, 59.85753005550754, 56.71913577664284, 54.08913950766287, 44.87847297422348, 47.38422816799533, 50.0568998244501, 55.129438369504875, 55.32762788957166, 56.42702118042977, 58.47665179160334, 57.26088962247295, 58.48447299772694, 58.027426658138154, 59.44123321963895, 59.59657084557318, 59.565811618681884, 54.697644249085464, 55.837630148856874, 55.29575470955142, 47.40045109102803, 37.67129428925053, 28.975189770421675, 21.623220712907855, 14.290583056788291, 7.302274098319392, 7.181192001988811, 6.126856938485177, 15.117003898466788, 16.246171901302954, 11.011092297492489, 11.477432693204573, 8.11815357015979, 2.788568379417543, 1.610319023170779, 0.4348612300330593, 0.960164042490144, 2.047604706979567, 8.572045833833757, 15.107632375532582, 27.65835204432088, 39.34626794630481, 47.133353371774, 54.05914906532534, 57.098593711853034, 64.23934705795781, 49.945339772009085, 20.528453857667987, 3.5498923399756035, 0.5834001014309546, 0.18550428381610304, 0.11915506344408759, 0.1636870650033797, 0.14512374336200376, 0.11919571206934991, 0.1363244727854767, 0.21163925077886353, 0.13937002468493678, 0.11723302545086031, 0.2945704595936883, 0.2621465849299585, 0.2892327266595056, 0.08552023359844763, 0.13980713913277273, 0.16899674379777524, 0.08820072928022954, 0.10013058751581178, 0.17476964531646622, 0.10379875439309305, 0.13974347722626504, 0.1302047479417055, 0.29675252315017486, 0.17183391978183102, 0.1371120877804295, 0.082237868599834, 0.20454546046112815, 0.2327889465396443, 0.1707648594052561, 0.21727051796211352, 0.22231712216331115, 0.09238396005164232, 0.1569243472430014], [0.11049404875525545, 0.018940374795948307, 0.03772240687882708, 0.05196454446582545, 0.03830398252654461, 0.02718547843546877, 0.09720502796793178, 0.056905501311825174, 0.048517095180408615, 0.04135076016668351, 0.04890334905095158, 0.04842383929738595, 0.02437731994676494, 0.14866682340300855, 0.032421905817764426, 0.030140074630898815, 0.040467748072959726, 0.032590257469564676, 0.04577109898110071, 0.01735441765988306, 0.01124826406369046, 0.006003922514332038, 0.11446182495884358, 0.03286827077728606, 0.019926975383573485, 0.12855315430750772, 0.08943837496542162, 0.03999492243653344, 0.10559702322127358, 0.06362104720826592, 0.040290383396730314, 0.03665996550191795, 0.08699103048251522, 0.08178462034031268, 0.03302182927126846, 0.06686210857644197, 0.05530348888808682, 1.8055157747960862, 11.989118629886258, 33.78214266992385, 53.98163518598003, 42.196497455719985, 34.77971907584898, 33.69719982147217, 23.59069924200735, 30.674301693516394, 29.36615986208762, 24.25166960685484, 10.788918464414536, 3.027578251015756, 0.5978145053790462, 0.20586782014898716, 0.08771912810663063, 0.39691686449993047, 4.145002432407872, 1.900275212622458, 4.6009784552358814, 3.1050288821420367, 3.122420671486086, 3.885939443303693, 3.8966997304270348, 4.771430934629133, 9.214086840229651, 17.04346718326692, 23.95404604173476, 31.34910233559147, 44.65758077559933, 48.427504108798125, 54.829745754118896, 62.944247107351984, 56.65944514736053, 55.68544218617102, 55.22849782820671, 57.15189480012464, 54.791581092342255, 54.41212315713206, 53.68149934276458, 54.65748310089112, 58.085971955330145, 56.16993334985549, 55.18587343154415, 52.28055423305881, 56.613486736051506, 51.94657225762644, 52.33856608790737, 53.89599807800786, 57.112537737815614, 52.16027475172474, 57.82519317442372, 35.55458330339001, 33.90035898454728, 58.70797357251568, 55.0603497412897, 58.1321107956671, 53.738154057533514, 57.1525655254241, 54.30438349323889, 51.78319769520914, 41.57222478620468, 43.59621486356182, 48.28023479830835, 52.08146649022257, 54.37744156006844, 55.69898220800585, 56.87483033826275, 55.35977563550396, 54.85544512348791, 55.1621627038525, 55.28365027519965, 57.387931269984094, 55.09539611877934, 54.6676302725269, 49.806707520638746, 41.45327106598885, 32.96593273839643, 29.82889952198152, 19.879209418450635, 12.250041557896523, 7.183946486442321, 4.705507168846746, 0.9223536197696963, 2.9014826301605474, 4.28455840195379, 2.8172815999677105, 3.124352438795951, 1.423456817865372, 1.9859607373514485, 0.49542513826201046, 0.6068130354246786, 0.36724738235915866, 0.35660090525784804, 2.638926034973514, 5.92769516091193, 13.052421212196352, 25.15536016033542, 23.974789496391054, 27.497689800877726, 39.159763166981364, 42.32290760163338, 42.23261464026667, 23.972424307177146, 9.217470865095816, 0.7178603605397287, 0.2172919531022349, 0.00886608780767288, 0.07230881751785356, 0.02749961087360017, 0.058429422563002, 0.032343458414318106, 0.023833809292785103, 0.02347041931634228, 0.09621713460693437, 0.06278716050268662, 0.09866031923241193, 0.02982387758581148, 0.08120063151563368, 0.007962892169974024, 0.04086763064767565, 0.024885730367274057, 0.013746653942601576, 0.06058542763874416, 0.07792739828507747, 0.006960328704031606, 0.04927540731225764, 0.09215341355170935, 0.025064043077309767, 0.07116035978880621, 0.005339098485907721, 0.005890299705037427, 0.02513889369795159, 0.0394223827958828, 0.07752075115399015, 0.058899291100040566, 0.032995537133707155, 0.021379321039984786, 0.04664656510877033, 0.08388350206998088, 0.04620084366310508, 0.041024153901925015, 0.04151035926394886, 0.0390036391364711, 0.04268974779293903, 0.05689145125929387, 0.008883644627677578, 0.06225220513560119, 0.0018849170831550335, 0.04187655695263417, 0.028102108382529793, 0.03458551814659469, 0.019691280772789352, 0.0009335364900893653, 0.04919223697675813, 0.03011186918874662, 0.038194830319093126, 0.04976056313382522, 0.026043319864378824, 0.01990921171982923, 0.030032106029290347, 0.09000686583139243, 0.056149970079141284, 0.02074133450796287, 0.016114293680255933, 0.03367224174942221, 0.00962058482165899, 0.03085333313192091, 0.0313254788653144, 0.02657622786148662, 0.044678446926897576, 0.028506233169126417, 0.08185683944893461, 0.03904856636279053, 0.11690909283295756, 0.042346666807368885, 2.6834177249862305, 15.533038916126376, 39.96948942061394, 61.227825764686834, 48.75815206958402, 40.53332228814402, 32.773891533574755, 29.107375606413814, 31.038582017344815, 24.831566541425644, 29.57806787183208, 12.013437324954618, 3.6529822791776354, 0.5365344581584777, 0.20662163534472067, 0.14401112322605428, 0.19250767575877328, 2.912517483195951, 3.776688441153496, 4.7872998637537805, 3.403193979494034, 5.050799298670984, 4.553629563700769, 3.829641664220441, 6.163929220168821, 11.450472281825158, 18.579716413251816, 28.317690703176684, 34.23250136836883, 46.99962800548923, 50.9676427995005, 57.633330437444876, 61.4746722867412, 57.43492910938879, 55.0294767656634, 55.850519057243105, 57.469920573696015, 54.467605083219475, 54.27009805556267, 56.747737699939364, 55.12821459001111, 60.387975708130874, 59.135315802789506, 58.22194091735348, 54.58044382833666, 57.33026458371071, 53.9400972858552, 55.35128762645107, 55.24801946455433, 57.30588705308976, 51.87973899226035, 58.308001641304266, 38.95274831402687, 37.63419651216076, 58.12469751604142, 55.31860251580515, 58.82977493347661, 56.107955978762725, 59.14194068601055, 57.269067764282234, 54.14030290419056, 44.66898310569025, 46.327443584319084, 49.30001181940879, 54.432288062187936, 56.28539616061796, 57.965770921399525, 57.22191695244082, 57.065222186426965, 56.96926532253143, 57.36810761113321, 57.25539830423171, 58.28133344650269, 57.46399779473582, 55.7336441932186, 52.9086825924535, 46.37997588803692, 37.65726789351433, 31.572744115706417, 22.5353600517396, 14.57200134954145, 8.86741795847493, 6.530790953866898, 4.306098097755063, 5.222281400234469, 6.388395678612494, 3.6017811298370366, 5.242606632171139, 3.219981784782102, 1.826005133409654, 0.6563742050240118, 0.7898560166358949, 0.289510234349197, 0.4260405856034448, 2.2283092814107097, 7.045219117595304, 15.939882839879683, 26.443186075456683, 27.17543963463076, 33.865500880825905, 48.093941826974195, 49.8985105945218, 49.089980663791785, 31.090298468066802, 11.798423778626228, 1.0285701170083017, 0.1819686195062053, 0.0410244909806117, 0.013755930309754708, 0.02808957135364894, 0.051873494916024714, 0.013956978594163253, 0.021106088120910912, 0.0200779234329539, 0.06945897810040944, 0.041590951713583166, 0.029381427335582917, 0.05305795494707362, 0.07698361626676015, 0.025069601045200424, 0.021464349138700677, 0.037323692588195685, 0.028261686412377224, 0.04040161936333583, 0.02150793571115261, 0.018164354541729537, 0.029145782520513863, 0.0708529363656717, 0.02468708759894775, 0.05657762717155199, 0.03392442640277647, 0.007686994701338512, 0.05007073298216828, 0.03298375853187135, 0.07185380725610642, 0.04800956959145204, 0.06086969222392767, 0.024229943782331485, 0.06020705298250241, 0.2635031427827574, 0.23538010104769663, 0.10338441573924596, 0.11524659776759726, 0.1418733701951081, 0.15703504694805992, 0.16764053834542153, 0.18740559147009928, 0.09519767076257737, 0.1879751931635603, 0.1257675283798768, 0.20033551620379572, 0.11878258383442318, 0.28632551491741215, 0.1098194393900133, 0.10137207896238375, 0.11492891642715662, 0.1208502934464524, 0.17018004320561889, 0.1008767648149402, 0.11754211894566975, 0.07757417046495023, 0.25702959257027796, 0.1624444550684383, 0.10254660666349436, 0.17654588145594444, 0.12058623059983216, 0.11298239426386934, 0.20199748266848827, 0.12942200526595116, 0.13353476360920938, 0.14580297223742933, 0.21721747403423633, 0.19065620978513073, 0.10959236326837733, 0.1486849643650555, 0.2112847052875065, 2.9882895850366165, 19.410211616946807, 47.04375074755761, 66.73877546864172, 55.13631428441694, 49.2218429042447, 44.691921126457956, 34.64154966415898, 42.339656122269176, 39.42856711726035, 29.648599932270667, 15.200579800913411, 4.702575687439212, 0.8178756518229362, 0.411545466631651, 0.6863715115093416, 1.875281011865985, 8.798699013648495, 7.229928922268653, 11.278203745042125, 10.423107435626369, 9.472284701562698, 7.8049523119003545, 6.642805510951627, 7.946975942580932, 11.948926102730537, 20.25200716910824, 26.87947915446374, 35.07156302852016, 47.50770045864967, 52.762472321910245, 58.317376106016106, 62.82243790165071, 56.01561554016606, 56.00040458863782, 55.341956307811124, 57.8346735431302, 54.944690812018614, 54.24438691908314, 56.64123750502064, 57.19832781822451, 58.67317038197672, 61.0223327913592, 59.74309098336005, 57.10393598002773, 60.75188536797801, 56.13055667569561, 56.923361824404815, 58.37002215846893, 58.429002838750044, 53.13326966377997, 56.369581991626376, 43.416315355608546, 40.51527938535137, 58.21128775996547, 56.304937408816436, 60.74692356971003, 58.786275848265625, 62.14959452229162, 59.63750862306165, 56.53011675803893, 46.79666888329291, 47.42489137957173, 51.189119431280325, 57.128780272699174, 58.48035843141618, 58.950081871401885, 55.828267451255556, 56.564641460295654, 57.39396387530912, 57.922985707559896, 58.357996171520604, 59.81541164459721, 59.2046005495133, 56.24360330643193, 54.36152458190919, 51.120532866447206, 41.145941595877375, 34.43017705794304, 24.367826677137806, 15.847290388999449, 10.456548583122993, 7.664195116489165, 4.351614261827161, 8.589886734562537, 8.888274181273676, 9.95911555905496, 12.45535017982606, 8.840496770797238, 6.74213610349163, 2.4166455624565004, 2.6065083809437293, 0.5956934837083663, 0.7455100059028595, 3.7874528957951457, 8.768664444646529, 19.50965350674045, 32.954895188731534, 35.92345476150513, 40.21706942589053, 53.71908349375571, 56.013571985306285, 56.32487873877249, 34.83899001152285, 13.657784135110917, 1.4828813388462991, 0.3572997306623767, 0.18351643887018004, 0.14223969811874052, 0.11839849799270592, 0.11899634534793517, 0.13260606586212112, 0.07821104999992155, 0.09053572696904022, 0.21619606432655167, 0.1364284309168016, 0.15386725805940168, 0.13637907953271944, 0.18564885992917324, 0.14139424348550458, 0.1921605766420403, 0.08582591034111478, 0.13634564745570385, 0.1810214437183834, 0.2755749111454333, 0.07571112124189254, 0.13391895670323603, 0.17774738311286897, 0.11733737428702655, 0.2257308559191804, 0.14157977465900684, 0.10261654283010191, 0.14173507600301696, 0.12843280189460324, 0.1495810267665694, 0.1588953229328317, 0.16738420532595727, 0.09951113648111783, 0.12080201458546425], [0.02298621344380081, 0.023663831619365562, 0.03382641694418365, 0.008522609413992013, 0.029315568671952334, 0.047266092752256704, 0.08112308809593802, 0.04457904701872219, 0.030043658635188496, 0.05497108716818114, 0.07249254838473375, 0.036478372020346504, 0.02869585333692451, 0.05156068206434289, 0.03455481717302915, 0.01333619169365134, 0.04365686484942994, 0.06167429904904097, 0.058492100046527, 0.10048318714384111, 0.045389656142722216, 0.0976751761270627, 0.0842763519575519, 0.016724475051066088, 0.03653892360988163, 0.0973102501443317, 0.04701634808894127, 0.015241278076334106, 0.006232727121847172, 0.019106539266724742, 0.02412909022231977, 0.0109980856030879, 0.038082901042916124, 0.057329745482533216, 0.026438994701170636, 0.09947775803025692, 0.016207036284369328, 0.2643718558453745, 5.294141182976385, 21.438985024729085, 40.603968097317605, 44.00088187186949, 43.772364585630356, 23.3722016503734, 22.525097170183738, 22.238148335487615, 31.863017159123576, 17.62755124799667, 12.82184958457947, 5.364438391500904, 1.2548202732878349, 0.1601417020203606, 0.14059951919461453, 0.22882686236933356, 1.3530126430334584, 2.1764143628458825, 3.021641743759955, 2.004660637147965, 4.43307061349192, 2.170236384676349, 1.806286643109014, 3.4978324367154032, 5.349137715754971, 10.310641315675552, 21.948006691471225, 27.13967546339958, 34.96764375317481, 47.60784641388924, 51.15169609746626, 52.71991852791079, 60.189495932671335, 56.73218550220613, 57.83828996842908, 56.18758793800108, 58.27539105569163, 56.18946283094345, 59.73881167750205, 55.43751308994909, 55.3780185791754, 57.315547850824174, 54.73814272111463, 52.81502031510877, 52.66512693897371, 51.768626090018984, 54.919140492716146, 53.14554668241932, 56.630768699030725, 54.49934882502402, 58.03955854908113, 33.41391055814682, 35.576470128951534, 58.10238315213112, 53.26300205722932, 58.49858176323676, 50.43282762650521, 51.58484343559512, 49.05667189628848, 47.009277036113126, 43.8972959979888, 45.5108610276253, 49.71856009575629, 51.900409883068455, 54.23400048286685, 55.09298778349354, 57.254252972141394, 55.8288989528533, 55.84594949599236, 56.85599511669528, 59.22238457587458, 57.947928059485655, 54.86019511376658, 54.199954309771144, 47.95976931048978, 36.63971877867176, 28.181084356000348, 24.459210057412427, 15.92816181721226, 8.049828333239402, 5.560071997104153, 4.4197173945365416, 3.6454851588895245, 2.3569495399152083, 3.7333923385989283, 2.2134599233827283, 3.8505957011253606, 2.3257443885649405, 1.3732530537151522, 0.10763932169685442, 0.5536608133585222, 0.26511376603476466, 0.7792884159472682, 1.6796384583557806, 7.554139293009236, 12.216121881238877, 21.256367314246393, 25.920216460381788, 29.821356804140155, 35.648527991387155, 36.190250458255896, 41.45460467184744, 20.96753181949739, 5.634028286703172, 0.2509773294291189, 0.026721171696760485, 0.025285884903203097, 0.06521701136784208, 0.057505872926764914, 0.029343025263158545, 0.018657816671616128, 0.13791885497348924, 0.06034724324220612, 0.01129856826962843, 0.1162923077842401, 0.015633684590518955, 0.03186652080095824, 0.032358236250377474, 0.04788174782128585, 0.045040117035950386, 0.07040632242757468, 0.08720214133180919, 0.0178135437290034, 0.06909659552958704, 0.0170274245207228, 0.03293100188696577, 0.03160835683135496, 0.0227414311150149, 0.001901386776514682, 0.046708407556457866, 0.011615772720336193, 0.06115334393877176, 0.03109186992890412, 0.046446627651851986, 0.03636833498134248, 0.03221796938188134, 0.05473430088210491, 0.01462647911056035, 0.01898129729764356, 0.06400414479656086, 0.02729708020905814, 0.02055448374801105, 0.017578852693400076, 0.021162908862254793, 0.06319685666371258, 0.03274174752615152, 0.033666653138014584, 0.08671987366171614, 0.04595069297318978, 0.056941028639313676, 0.049971842522462534, 0.028344293673252387, 0.018226225717714237, 0.014920559197273708, 0.008988898405204377, 0.043307095916280826, 0.07622487512567351, 0.10503809313259779, 0.06925696837565593, 0.09415047453536142, 0.03818862883734607, 0.05416705490901105, 0.06549637299031019, 0.08903839279927554, 0.04902534472245363, 0.007191873991095852, 0.03361084363273075, 0.03508726360216256, 0.027717246876789198, 0.022826978238299492, 0.020194558404205788, 0.06556837759431332, 0.034102216257803866, 0.0630221656343389, 0.033739343390709935, 0.3555716814533357, 7.221497297286988, 26.270601787874778, 49.13825327350248, 51.2348581898597, 49.283490796242994, 28.05121664078005, 26.82703902644496, 33.450263084903845, 33.97833178120275, 21.23551207204019, 16.404366973907717, 6.293264473638227, 0.984757793766837, 0.2685223976450582, 0.05334552903209002, 0.1897120523837305, 1.0478866869403471, 2.3853489708515907, 2.298580013936566, 2.5792018203966083, 4.793359925670009, 3.2229799464825666, 3.9729672766500905, 4.351850584630044, 6.182021642884901, 14.126998647566765, 23.38248218259504, 28.08128356933594, 39.28774618333386, 49.56301066183275, 52.586201006366366, 55.41458291392173, 60.38051143769295, 56.03100692072223, 56.72605091525663, 59.163909881345695, 57.346691469992365, 56.78927167769402, 59.670158432376006, 57.25331552567021, 56.72254823869275, 58.91198781228835, 57.55689520989695, 54.49660708827358, 54.73351824668146, 53.928749868946696, 57.08598721411921, 54.472386452459524, 58.680450301016535, 55.7445405375573, 57.09357307803247, 37.91785840065249, 38.60866623540079, 58.219340385929236, 55.669505596160896, 58.81295188780754, 52.83475768181586, 54.30296751760668, 52.267433904832416, 49.69882665141937, 45.10919463249945, 47.67362063930881, 51.70651535834036, 54.20030340071648, 56.660217854284475, 56.42605627736738, 57.13746440026068, 56.1496429289541, 54.75124343749016, 57.476729808315156, 59.43852678422005, 58.99961356193789, 55.81595905365483, 54.93126846128895, 49.011074343035304, 42.05701012765208, 33.13270015101279, 27.18588294521455, 19.31059910405067, 11.48654926207758, 7.086563840989144, 5.342187275809627, 6.132282066729761, 6.539822701484927, 7.388910430092966, 5.541329441532012, 6.133473976965874, 2.627268015376983, 1.1681648199596715, 0.6084601857489156, 0.16134110459637258, 0.2996773549145268, 0.7438554398475156, 2.7209837350153157, 6.964424665897124, 14.555171439724585, 30.820757112195416, 28.996382336462702, 33.441206332175966, 42.57901876203476, 42.46166144647906, 46.59180741156302, 24.219406151002456, 7.254632499910171, 0.4316539263292667, 0.10924983769655229, 0.0235569202190926, 0.1116802363145736, 0.04792708107420514, 0.04242626334270162, 0.016580599908446594, 0.015030919908425741, 0.08921946534105847, 0.06770641407779149, 0.024873482536584623, 0.05143702781248478, 0.031171364957586895, 0.022645024695403637, 0.07262335789780464, 0.07177503043485266, 0.06046773355093695, 0.018608254613354802, 0.03402039040661147, 0.07959206137926349, 0.009292804527156537, 0.018879258216569023, 0.02665967781907849, 0.015879370903055516, 0.06972212164152054, 0.02648542154460184, 0.09999031681687602, 0.11253122976350208, 0.03892169454165044, 0.0066064573700479684, 0.07126137614250183, 0.07304237734886908, 0.07933642549981033, 0.027688355785944772, 0.1549599445875614, 0.1389272871517366, 0.1537934531487765, 0.09893345256005565, 0.16503591601166034, 0.09327478241175415, 0.22155860318772255, 0.13214322618178784, 0.16876964469350156, 0.17554515612221536, 0.1935078648309554, 0.15528131847179708, 0.08288613986223936, 0.1373867456230425, 0.1518225693894971, 0.07692594516782031, 0.18053133130794574, 0.12665769190437373, 0.13707697030998048, 0.153196134394215, 0.124677300993954, 0.2859078437810944, 0.21399756052321006, 0.09881916756351149, 0.1662971265614033, 0.2630327341537322, 0.16232493003049206, 0.0777647884622697, 0.14469277293932054, 0.1471444228363614, 0.157116957068924, 0.06424730876460671, 0.13258988608516034, 0.16977686645282855, 0.15766444946489028, 0.17788560069616766, 0.12280255360829255, 0.7981540971705992, 9.074441636762312, 31.142322824847316, 55.55960470630277, 59.66845612372122, 57.440322368375725, 35.670583478866085, 32.70005683745108, 34.30675183573077, 43.104345721583215, 26.432903582049956, 18.677112787000596, 7.789218214250381, 1.9623050454162785, 0.4881595910316514, 0.3105792457297925, 1.9065020978450777, 3.3374106835934425, 7.167129814624787, 8.190759583826988, 4.667330249663323, 13.468842583317912, 6.1004745864099075, 4.592384542188337, 7.103328541401894, 7.415460463493102, 12.91883901242287, 25.38946878525519, 29.611241317564446, 39.33732886468211, 49.95672249024915, 53.37710772791217, 57.11272601158389, 60.40830535273398, 57.231950375341604, 58.32546403331142, 58.47780104606383, 58.488920965502345, 57.40161641951531, 60.49000047868299, 55.55050872987317, 56.893571422946074, 60.84513579645465, 59.0131849627341, 57.13950403275029, 56.40493039161929, 56.1633712245572, 59.94168842992475, 55.8974737505759, 59.57976741175498, 56.59174503818635, 58.220995626141956, 43.06236459362892, 42.58578092821183, 57.46587661004836, 56.12128811497843, 61.391588641751206, 55.20541075737246, 55.46484808767996, 52.57568905430456, 50.169440469434186, 48.004264677724535, 48.97572594304239, 53.82945506803451, 56.46426016284574, 58.70142321432791, 54.83577051470357, 57.8996083813329, 56.75562558635589, 56.23292269245271, 58.94230381135018, 60.923018378596154, 60.31072854995728, 56.102017510321836, 55.200268530076556, 52.27609449817289, 45.997529106755415, 35.1262330239819, 29.881176871638147, 18.868924533167196, 12.506403749988927, 8.389644834303088, 7.680090521612476, 8.280619613585934, 5.701009621543269, 12.847857840599554, 9.071827377042464, 12.42135891991277, 5.369779679083056, 3.742290725631099, 2.114475234862297, 1.5001476123448343, 0.5876583245492751, 1.2615369644857224, 2.9854399831064287, 10.33172699712938, 18.131526785512126, 32.277580307376006, 37.87266877389724, 40.3397572425104, 50.069212144420995, 51.36754805041898, 54.12497820392732, 29.150800166591523, 8.349473880183313, 0.7828050659548852, 0.23576378852369326, 0.08507859923185841, 0.27948824148024287, 0.2525903428754499, 0.1590740972108418, 0.10928659459515926, 0.16248760114033378, 0.18533756776202112, 0.12618247224318405, 0.22819366005639877, 0.15207027625893393, 0.19274131725392035, 0.09395429473971167, 0.16222616597529382, 0.15283561341704863, 0.14584991810542924, 0.1672397977522304, 0.2208129238457449, 0.25674240152922373, 0.14775796733315916, 0.1477500153405051, 0.08027725807961919, 0.08250060611434522, 0.19954549569276073, 0.07603630258311188, 0.18037705652175412, 0.15299319770307312, 0.21537809692803891, 0.13768893666565418, 0.12588762032288697, 0.12060773468786672, 0.24577157812253123, 0.11085837718940551], [0.0061845066750632425, 0.025925058871507648, 0.13952025452688818, 0.03666717055884581, 0.08529815237007796, 0.013204189956248289, 0.10065958654928593, 0.012171161567581999, 0.05092572157962188, 0.060540986878256646, 0.05021992477498228, 0.04484310986534242, 0.06440275949576209, 0.004746235490235831, 0.05604724534937451, 0.035232521533485384, 0.009502021224057723, 0.09747052339897042, 0.04524672711868921, 0.014728048005171362, 0.012706996978170449, 0.019321344575033556, 0.03222947985294365, 0.09097944509478346, 0.0497846489381646, 0.001809337003167809, 0.016272393160409505, 0.041952005121856935, 0.029044882995226694, 0.009498343044411271, 0.03075311734010616, 0.08648561163535042, 0.012036498632251978, 0.027306380516458905, 0.08556147211141164, 0.02442189668785901, 0.03348674888031618, 0.040580631128602454, 1.8840401547570385, 12.403892605535447, 34.10645600288145, 44.218157645194765, 44.149873102864916, 36.706873678391986, 26.174344862661055, 16.64237149300114, 21.06328275895888, 30.520929175038493, 13.240313529968263, 8.354070898025267, 2.2907399314065136, 0.3009474674059499, 0.05355472083113367, 0.23201124472243173, 0.38350667924650256, 1.1026480000826622, 1.1322372574960033, 2.109845122022014, 3.8429882641761535, 1.941815196506439, 4.011417045708626, 1.4559139407450155, 3.792836839152921, 8.466777263149138, 15.456139868305577, 19.795111840771092, 31.73438891287773, 38.59525957415181, 48.48773602516421, 45.78171637750442, 51.0903266937502, 57.247177016350534, 58.87993812561036, 57.02596710574243, 57.86375399558776, 51.91445196828535, 50.255622786860314, 56.70907881952102, 57.00375080108643, 58.241184065418864, 55.54536650257727, 53.63789435355894, 52.38499910600724, 50.81266603162212, 54.24082540696668, 53.558250627210064, 57.42094978209465, 54.444733742744695, 56.654373522727724, 35.18150706445017, 37.80067366938437, 56.31997185368692, 55.62902281361242, 54.52698192288799, 50.21440652108962, 53.66306420295469, 49.8316224159733, 48.48220940559141, 47.12416718083043, 49.66305463544784, 50.99854715408818, 53.27132532673498, 55.93710145642681, 53.67037942332607, 55.5752000501079, 57.567669960760306, 56.162688732147224, 55.587943830797755, 59.430838938682314, 57.034411968723425, 56.040687330307506, 51.16887215645083, 43.69765520095826, 30.25048371284239, 24.30006184885579, 19.24220081298582, 14.29475743924418, 8.03313276460094, 3.9182242270438907, 3.238425014480468, 6.516640022877724, 8.543653757341447, 7.583797804770931, 4.039305587930064, 4.445221135693212, 1.0130836189754548, 0.7395357458341507, 0.36717123321948514, 0.21005389310659903, 0.6797458928438925, 0.8913931262589271, 3.857637581325347, 9.797304061151321, 19.07554714910446, 21.84214976526076, 18.722880963356264, 34.68262864697364, 40.770872792889996, 42.22780973680558, 35.21755364633376, 18.23598930912633, 3.0229064629923914, 0.050140397187562726, 0.038779052800589034, 0.09463404455492574, 0.04342309311933575, 0.020564580786853068, 0.06637118411280456, 0.04238293340970432, 0.11390080345013451, 0.0578991096887377, 0.12930753640830517, 0.07612460187726444, 0.08001700268998262, 0.08019683416932821, 0.03483523216639315, 0.037387354494703394, 0.07095265036989605, 0.08459996281852646, 0.14410208850618333, 0.03849241717327987, 0.039098994100406285, 0.045589716173708446, 0.05757616532425727, 0.030907568326520345, 0.03305823376943027, 0.04879058856937674, 0.06551413090839502, 0.07599317949385413, 0.030075974139054457, 0.09675783946389153, 0.017936165677383542, 0.06022223301472203, 0.046461072239664294, 0.027755534036024928, 0.020805835280747666, 0.01917209149518561, 0.03899458014676648, 0.01536084141867656, 0.01805737993920282, 0.051749752564055305, 0.013601566465841907, 0.05095889701718285, 0.012251843074937502, 0.012697237975625022, 0.07458956085986669, 0.021368346830469467, 0.05454144590804654, 0.09735520418372848, 0.09939705832831322, 0.017744967368461432, 0.038698303302930254, 0.041295529057782505, 0.022712224012901707, 0.06743613059722608, 0.08991675856973856, 0.05488639997859156, 0.002131570940799711, 0.03254773192888787, 0.03015316707352477, 0.02458963163888022, 0.031112717096543605, 0.02558107198696704, 0.05581959083135571, 0.06254168677954905, 0.03196275485078654, 0.08463436782720589, 0.05186911672353745, 0.07052285972261621, 0.0897055404681352, 0.03868797643771095, 0.02148383841549437, 0.07720189003814613, 0.02263664943917144, 2.6157654196985307, 15.134419222031871, 39.150773094546416, 50.25564239871118, 50.09505664148639, 37.32036767467376, 30.308601471685595, 21.083224088914935, 28.30438602355219, 27.608908607113747, 14.449320397069378, 9.836387538140821, 2.3281112938157977, 0.3759088643616246, 0.054628044487007206, 0.04750168394117106, 0.4767424907655486, 0.8332827831468275, 2.230042233582466, 2.5549103367713193, 3.3116483111535353, 4.102587392253261, 4.2199402951425125, 6.410714945485515, 3.132321224097283, 9.292146909621454, 16.609301990078343, 22.252521860984064, 31.792538050682317, 40.83779235039988, 50.00252792912145, 48.74503174135762, 53.010456331314586, 57.90923387773576, 57.198021873351074, 56.412139707996005, 57.79010757323235, 55.12743403834682, 54.32884339363345, 57.83879987655148, 59.60915773145614, 58.84583703933224, 58.84453481243503, 56.4212788304975, 54.09682343083044, 54.15842425438666, 55.58397439218337, 55.032206735303326, 58.74143531245571, 54.747242619914395, 56.65836649556314, 38.16513638342581, 40.820777108592374, 56.36675788510231, 57.50638292681787, 57.44457421764251, 53.326748417269805, 56.11047806278352, 50.62801261102, 49.667596740107385, 47.716664729579804, 50.506285775092344, 52.89354616595853, 56.21253028992684, 57.019475583107244, 54.523604762169626, 56.53300362248575, 57.12867436870452, 57.054004207734145, 56.74893794521209, 58.99253760614703, 56.96940260548746, 57.03898545234435, 53.28956827040642, 46.24663099165886, 35.010279916947894, 27.636290673286688, 21.68851052561114, 14.832917413403912, 7.127683518394348, 5.0260922889555655, 5.5020321953681215, 5.148682046321131, 7.516132506632037, 7.003835170499741, 5.495634809617074, 2.314961792961244, 2.341108557678038, 1.6148777979035533, 0.4478611598812765, 0.03138437187449346, 0.049249390966349074, 1.0443203944352366, 3.2907143763957487, 10.072120024311928, 17.98005073301254, 21.466669113405292, 25.230324499068725, 37.62978384571691, 46.573788042991396, 48.149062895005756, 41.37449418344806, 21.499622906408003, 4.176127910614014, 0.16411490978733187, 0.06645245838069147, 0.04510656750250248, 0.03875950989764064, 0.01441733519201197, 0.05947257767641737, 0.05288589159928022, 0.05554116000571559, 0.03630862225808444, 0.12195826342870152, 0.04341731681638668, 0.04803767735739389, 0.04736774112848986, 0.017434613659016548, 0.043232007808382475, 0.020073056859414906, 0.007890619914002356, 0.1177425045640238, 0.10706369855230856, 0.07124559473126166, 0.09388637338434497, 0.0902891002835766, 0.003755616053240374, 0.0640393044018457, 0.07646751815393087, 0.054859487309811585, 0.07119543895485901, 0.009598665130925516, 0.09861926458054975, 0.007824853659727642, 0.04788596896574863, 0.03963401075452566, 0.060453078288945465, 0.007535752665717156, 0.10095132049173118, 0.21563826038712458, 0.19953910651947224, 0.22269046745232998, 0.2837692020881561, 0.10989109159357126, 0.1522321659590929, 0.1194698259895367, 0.11330481002768202, 0.1553468955981155, 0.12742964040127494, 0.0913096749554238, 0.1744968720501469, 0.14747940244213228, 0.17767455879478686, 0.10364383609304506, 0.11160817808441578, 0.19193238969291412, 0.26669861808899914, 0.17219025791893083, 0.07437252815091804, 0.17164268891417211, 0.11443066050208385, 0.15107296767734713, 0.12604181850028615, 0.17440514068209356, 0.15817045053887754, 0.12189558977561614, 0.18592748610723406, 0.10711329508452647, 0.23369622446836966, 0.14992880004067577, 0.14666448407355817, 0.18461035113901864, 0.17456755132204102, 0.2584785253049866, 0.13603283843446162, 0.10182820005162109, 2.9382967708572267, 17.80488944822742, 46.58444120037941, 56.828718954517, 60.04920844108828, 50.42155865700015, 39.524527903526064, 27.396251424666378, 32.69930374237799, 39.31865446029171, 18.711855180801887, 12.188859447356194, 3.0359691814068825, 0.6506094240373181, 0.14492531126785665, 0.6882499590996773, 0.9614390579442825, 4.0373542087693375, 8.246052745849855, 7.048176094408959, 7.52523240543181, 8.125498698603723, 8.55596999968252, 6.648491476812671, 6.069004920221144, 9.896988157303104, 16.99802456363555, 21.93104244047596, 33.91161226457165, 41.72518937818466, 52.611861152033654, 50.233673203376036, 55.79186785605646, 58.74112152284192, 56.8224706188325, 57.515310241330056, 57.48115424186953, 55.488229336277136, 56.20640747008785, 58.50005657442155, 61.44314035292595, 59.19355515510806, 61.295572942303075, 57.693130893092004, 56.25844947753414, 54.79509553601665, 58.02311597331878, 57.90882595123784, 59.536876293920706, 56.61839754350724, 56.403137868450536, 42.34692427419847, 45.26221413766184, 56.78420789780156, 59.140199153654045, 58.57611133206276, 53.905399999310895, 58.86815140324255, 53.383312917524776, 52.32795215422108, 51.00426989216959, 53.32423810035952, 55.823384100391024, 59.01552269535681, 57.54247265477335, 55.23424017813898, 57.72407054901124, 56.606128369608236, 57.5457949023093, 56.71853957637664, 60.42569321970786, 58.274108440645286, 58.994451722791126, 55.25381672766901, 48.66084198797903, 36.511590634622884, 34.20360526730938, 22.7342281418462, 16.690730394855624, 9.304008157022539, 5.731707561400629, 6.879843656093844, 14.142719507217409, 16.885552560129476, 16.56793471305601, 10.053577019322304, 9.319081825594749, 6.258404408731769, 3.6836914958492404, 0.5972401845839717, 0.31680441491546174, 1.0627002533405059, 1.7526586497983627, 5.126294628266366, 15.026071590761985, 27.613229097858554, 30.909108500326838, 31.885147171635783, 46.60946984444895, 53.98357675921533, 56.488696529019265, 45.63878520842522, 23.336608102244718, 5.420599868220668, 0.28701183776701655, 0.09979628206741425, 0.2880428388955132, 0.12688951011026098, 0.16836677437588093, 0.18905773668760256, 0.15736403574626293, 0.25369160958836157, 0.2370078540256908, 0.2245768057482858, 0.1638938474559015, 0.16722294381789624, 0.17699776607896053, 0.07392640450909253, 0.10668391812472575, 0.16234599744840977, 0.1426921190033036, 0.2472350665278012, 0.1480995812603543, 0.11803370224492205, 0.2414516696045476, 0.2026050823229936, 0.09658806671899173, 0.21793900628484067, 0.17340553383673393, 0.13761485596337628, 0.19795325855093618, 0.13669524401907, 0.22784294500466318, 0.11715154433923385, 0.13993529032074636, 0.11880090099669273, 0.15089782465609813, 0.14918636891149706], [0.02124109579580686, 0.019369008650462476, 0.02555356560004575, 0.052340896649947094, 0.024013975935597575, 0.07291724454731711, 0.05161030924007778, 0.018194639912596153, 0.024969854482239293, 0.03914013302194015, 0.048725976713842926, 0.06559992509503519, 0.048085714900685896, 0.052967974089927254, 0.03716107893494829, 0.04216052276352721, 0.020141280819511703, 0.027895189949401447, 0.13247166339668537, 0.0700795935887483, 0.0232609172516893, 0.05066312196093702, 0.0633942507087223, 0.06012902309697482, 0.07302557704068961, 0.011231690709058557, 0.04407881075636514, 0.07256874348968267, 0.054127455824204994, 0.09680670055170214, 0.03043854823185792, 0.047819778969090794, 0.01678000684947737, 0.04733602125798503, 0.007500978019614254, 0.08796763936838797, 0.028943765134881103, 0.027502227063861587, 0.3324505963152455, 5.745068625096352, 21.299281966301706, 42.91072184039701, 51.63755616834087, 41.60732215450656, 25.29994853081242, 30.180889098874985, 42.049345816335375, 19.488915935639415, 26.137213745424827, 14.01569551037204, 4.299204041880946, 1.1629081084843607, 0.3779900801037589, 0.1217187230565375, 1.3169093093564435, 0.823535938416758, 1.4649073226797966, 1.4216836613993493, 1.930285266810848, 2.781323516561139, 3.3996976767816856, 4.065624691786305, 0.9546919070905255, 6.164763214126711, 11.310986914942342, 16.318079733079482, 23.77742171287537, 32.82153068050262, 36.43980733809933, 43.02469022812382, 49.67056205195766, 51.098375397343794, 55.36843230647426, 57.61167503172352, 59.31094384962513, 60.6878173735834, 57.56848581375615, 58.36757067711123, 59.71745044954362, 57.92707281727945, 56.879309684999534, 54.828412148260306, 53.893840774413086, 53.074390965123335, 54.29346753704933, 53.0263223186616, 56.35556344063052, 54.945953815214104, 57.49507081124091, 34.90567030445222, 36.6306306469825, 56.07079152138003, 54.288093889913256, 58.271668726398104, 53.11520714913645, 53.508059978485115, 50.92779151854977, 51.381339103944846, 50.2352225395941, 52.61086879238006, 51.016237043565326, 54.52987663207516, 53.97264903591525, 54.585821397842906, 54.10977117476925, 55.88595767174998, 53.696894645690925, 57.776081177496145, 58.251021369811035, 60.01793930607458, 56.01672164855465, 51.314631354424264, 43.185177926094305, 29.05005801108576, 18.790222175659675, 16.178455122055546, 11.449703497271384, 4.415958293022649, 4.020764298977391, 4.111299956998518, 3.4910339886142365, 6.387557762284433, 4.465338972307021, 4.095627881826894, 2.1566291922523133, 2.3295027546344267, 1.0771144734274958, 0.998749255893692, 0.1336499219459872, 0.1358096157350848, 1.8283713032161037, 5.395221642909512, 11.176233887672426, 19.413422076932846, 27.849963749608687, 24.374696708494618, 39.35468927506478, 42.1004189983491, 40.88120906583725, 34.37615425355973, 11.762370332594841, 1.0902278149320235, 0.07058950937202862, 0.03533492067588433, 0.0581604988885022, 0.01598837180814195, 0.08092376733979872, 0.03528636985368306, 0.01330764534237284, 0.09426217781560076, 0.012425641611879392, 0.012847071367075608, 0.0371130796960525, 0.06771384513065701, 0.043551677146986614, 0.03989623499012763, 0.03425060748873699, 0.04375799994675383, 0.08501354304532852, 0.02852882893245307, 0.04612792358403245, 0.027894067630592375, 0.010000870867271819, 0.02364385396152014, 0.03185793104010724, 0.036041426111853896, 0.011595063448523082, 0.028095803478912964, 0.021779586658662847, 0.014351887343030785, 0.056349834757706815, 0.04093948586453353, 0.030854166252538565, 0.02044939755221769, 0.022564480126264597, 0.019195644868417613, 0.04092947309536319, 0.06268749246373773, 0.042648333079752423, 0.054900354270132325, 0.09420488209974381, 0.05198398394690407, 0.03333613599440263, 0.13360636218661262, 0.01026856592826305, 0.006473108275508088, 0.05748199779660471, 0.1994109400097401, 0.039010752262848045, 0.032236918566688415, 0.06623207786751371, 0.04030747864876063, 0.03302789668762877, 0.04590657780007009, 0.1428735439455317, 0.09645987722662189, 0.0539175936982276, 0.04427588304444667, 0.05395605131202648, 0.09674065611174992, 0.038451668956587394, 0.020346337658984047, 0.03491034325692923, 0.09184775979167993, 0.013425767481807741, 0.009033052840330189, 0.05131988530798305, 0.04845637122109052, 0.024001433161057295, 0.03498212569543431, 0.02856996402354731, 0.03960846938313015, 0.004027494672505606, 0.0377273672981368, 0.5749750954489554, 7.6277965018826155, 27.04610340056881, 49.271076494647616, 58.24844437260782, 48.48314292969243, 32.05731372679434, 25.247808464111824, 41.25742320091494, 29.87794876098633, 22.132987629982736, 14.053407138393773, 4.242161502761226, 1.0534374536045137, 0.12998707171890045, 0.29307073522959987, 0.40432821358403853, 0.6832401117970867, 1.1518449408392752, 3.071736784711961, 4.602958271580358, 3.662103015568949, 5.720612647071962, 8.621212743943738, 3.7995798837754036, 7.861221163503586, 11.507706526787052, 18.283179344669467, 27.514142182565507, 35.64244047287972, 39.77548506952102, 44.854852461045795, 51.606953836256466, 54.128551483154304, 58.69263710514192, 56.84303560564595, 58.88409191562284, 58.67245258823518, 57.11579722742881, 58.181815070490686, 61.266935717675, 60.554511700907064, 57.827087679216945, 55.625849616143014, 56.744992040818744, 54.34001822625437, 56.0424876982166, 53.772757207193685, 58.96150381334367, 55.67146285887688, 57.23702199997441, 38.75311536173667, 39.63977498392905, 56.28270541467975, 56.13311798341813, 59.21615192967077, 54.11096749767181, 54.41510023609285, 53.11380686298494, 53.1937643789476, 52.406391712927054, 53.20479016150198, 52.315196606420706, 55.81405278175108, 54.14142077968967, 54.129661513913064, 53.91905376988073, 56.56080538226713, 55.75461318415981, 58.37506632651053, 57.47351346477386, 57.91598819917249, 56.20641139245803, 50.72791537930889, 43.979936415149325, 31.187620316782308, 23.352162261163038, 18.806401952620476, 12.209258714029867, 7.698512913719301, 6.957591406760677, 5.63619637681592, 4.654926244289645, 6.948597411955557, 4.796992040449574, 4.984026339746291, 3.790257880764623, 3.1712987970921303, 1.0930198070503052, 0.8936488568302124, 0.23202558588837427, 0.1917976041835162, 1.4040056616067889, 5.901473135717454, 13.535117891526992, 23.074252528529016, 26.827235144953576, 25.062315656292824, 43.280609192386756, 47.508661439341886, 47.50709641364313, 38.4234832948254, 13.900466080634827, 1.8256588616678793, 0.05135579950987332, 0.05246743905327974, 0.03156830192423396, 0.010321532289737896, 0.05261862267469687, 0.049223543159783854, 0.01691570208828536, 0.020640998057300047, 0.057733661510170474, 0.01744494818511509, 0.022685725031600847, 0.0380914697363492, 0.02616810601114506, 0.08247892582608808, 0.07244872049458566, 0.009571832901377593, 0.10188618524660988, 0.07932139485473595, 0.12904798581955895, 0.040880359198537566, 0.053159967215070804, 0.012589986623835661, 0.015632338190992034, 0.021515778536277435, 0.009545318598318244, 0.06964493062227003, 0.10586981180935137, 0.022947391938237895, 0.07704802893943365, 0.0465110594767236, 0.03631467435268625, 0.0719978777511466, 0.03619698792575829, 0.017794565815899163, 0.18467280262660596, 0.2176168969561977, 0.09397889382296032, 0.21184618644897016, 0.13747791008603188, 0.14070413616155425, 0.1990278500823244, 0.20919110956451586, 0.18166140292681035, 0.16109399527551668, 0.14872653229582697, 0.29551985703649064, 0.20211651741016298, 0.09953328408300878, 0.12984661715886286, 0.13903743527348966, 0.16479230005173914, 0.11971551038685346, 0.36545044652396635, 0.20156170121364056, 0.15509970966846715, 0.14124729249986911, 0.21872371014568115, 0.1848122765941005, 0.15894498075208358, 0.06867671039916816, 0.19637677217683486, 0.21736411858470212, 0.11388064001596744, 0.1697836233483207, 0.14056103093729866, 0.166622698607464, 0.07060331427642415, 0.16903573767312113, 0.09601562283933164, 0.1548508077018684, 0.07531778871892922, 0.14363158794660724, 0.6547956961777903, 8.850915566567453, 30.000836618484993, 58.46473170864967, 68.02153172031527, 55.48737425957957, 38.47030070520217, 41.439429021650746, 57.434529027631214, 31.5719106120448, 32.69311620343116, 17.68893438000833, 5.756430750893009, 1.6304347760254339, 0.8361466036688897, 0.7111981535150159, 2.430664848896765, 3.837925464876237, 3.2924419353085184, 5.311591807873019, 9.831102144333626, 8.449068742413676, 10.038407252680871, 9.729787322782702, 2.552695913660911, 8.834801489307035, 12.847062580047115, 19.46159270501906, 29.151784681504775, 38.14390459368306, 41.823699705062374, 46.79037347916634, 53.370196511668546, 56.88809187181535, 60.08069722883163, 57.34948027518488, 58.50294736123855, 61.55634780083934, 58.47518090278872, 59.98119846467049, 61.6202235990955, 61.82758362062516, 59.87595735057708, 57.43471337902931, 57.95930293298537, 56.782234945604884, 57.99027396786598, 56.63460085468908, 58.45285084939773, 56.06283695467057, 56.112003864780554, 42.39577739469467, 45.0312336029545, 55.32461550927932, 57.08556752051077, 61.26866548292099, 56.84305129512664, 56.76831445386333, 55.047751088296216, 56.00945349662535, 54.73518133163453, 57.5890939466415, 55.29704909170828, 57.18510550837363, 55.23996291622039, 54.691701858274406, 54.95504194690336, 57.95909896973641, 54.9301701976407, 60.92829004410775, 58.993777075121486, 62.260448548101614, 58.15543713108186, 53.03861894915181, 45.83100488108974, 34.63803129811441, 25.52232534654679, 21.046032174941033, 13.166159160675543, 9.082335406734098, 8.337018393701124, 9.549510286700341, 9.886537982571511, 16.37574347757524, 10.755768552903207, 9.415304430069463, 5.336668500977178, 4.784670895145786, 3.789504540543403, 2.226364521249648, 0.34458913690140175, 0.3976575183051248, 2.608163376008311, 8.577334169418581, 16.785028096168272, 29.20990832390324, 39.59497759419103, 34.19542320312993, 51.57852841961769, 54.612866140181026, 53.26573594923943, 43.67146161294753, 16.472360280252275, 2.259305566549301, 0.25728848432340934, 0.20132712509122588, 0.16145093096119745, 0.12853576411162654, 0.22604648414398396, 0.17579811835481277, 0.09829229059358759, 0.1582292401261868, 0.16896375605175573, 0.11771035951472099, 0.09247726956081968, 0.16103188086661602, 0.12533653497455582, 0.2342983695768541, 0.18314920696279696, 0.08253503410566239, 0.3188582659969407, 0.13651443194718133, 0.18721362515803308, 0.12875008486932324, 0.13407375242921615, 0.054192810785025365, 0.08688524140105133, 0.0852969955773123, 0.09515987964527262, 0.20274824883428313, 0.18684165882727793, 0.16402728465055266, 0.16538077815165445, 0.1645393837844172, 0.11977901907577632, 0.129813997135047, 0.21262575752071797, 0.1235221936217239], [0.06213307463293595, 0.04941285497719242, 0.0941078570641337, 0.07875507201759085, 0.06990892452097709, 0.07914707920844517, 0.025282818636286165, 0.10028424943166395, 0.04298422049971358, 0.008428371023206462, 0.1012318465678442, 0.06390788201843539, 0.07884425997373559, 0.1453739323563153, 0.03263302432793764, 0.024429130473084027, 0.026911881624630866, 0.03011563259567465, 0.017921901120233442, 0.03221649083218748, 0.033123546595414805, 0.07175781643919407, 0.008596577118301104, 0.04353542076123338, 0.025416186883024154, 0.0755016268381188, 0.03481852761920422, 0.09671668522059919, 0.050400434242140864, 0.049096234668526924, 0.020845135591263254, 0.04470294641871606, 0.032436361896895596, 0.04645534190199068, 0.04007613541738641, 0.04874042513209486, 0.04986359046832208, 0.07077849560206936, 0.19051848249810358, 2.0941181336679766, 13.013816264367874, 33.688413712286184, 45.73594623996366, 46.23731144012944, 32.98235962467809, 34.87142409047773, 29.09677540102313, 23.897581561919182, 16.227197435594377, 16.460506877591534, 7.84518700453543, 1.554357587329803, 0.1679715955810201, 0.085502261175744, 0.19145684827479625, 0.35705635985059125, 0.336506602865073, 1.8568725932028987, 3.109602120614821, 3.476283915581242, 4.523458202039042, 9.29724402966038, 3.247975740701922, 4.416568711880715, 4.7871831732411545, 9.015583530549081, 17.82020434256523, 23.030459265555105, 30.78372209302841, 36.12428011432771, 41.72122778431062, 46.93018636395855, 50.11938710366526, 53.496186963973514, 55.78783958188949, 59.32352289076775, 57.54342186835505, 55.98923367838706, 58.38189517298053, 57.7018738562061, 58.028846556140536, 54.98077661760392, 57.47336441470731, 52.74857536438973, 56.739049650007686, 56.32238803371307, 58.249417120410556, 50.356529681913315, 53.67795352012881, 35.96336880037862, 37.11510219881612, 56.58658319903959, 56.03478808556834, 58.861742250380985, 55.97832556693785, 56.64453621833556, 53.76747769694175, 52.942214935056626, 51.13584187722976, 50.95324377859793, 52.89754306116412, 52.22135782241822, 54.75683673735588, 54.11966339234383, 52.42938464687717, 51.40036652165075, 54.800943789943574, 55.701739634236986, 52.41015718829248, 52.9243956073638, 54.14902233308362, 46.798367269577525, 38.4225772273156, 27.016928811227125, 16.63066517922186, 9.872367439731475, 5.949068646277151, 3.8809952957014886, 3.874250780190191, 3.4980824878138885, 3.1353892530164416, 3.0229299972134256, 3.3956603321336933, 3.7799758776541683, 1.3670288651220261, 2.1752709919406525, 0.41280151374878427, 0.5623884547141291, 0.1383325271308422, 0.5506503329642358, 1.9740564664525373, 5.82468391426148, 12.215869868955306, 19.229092251869943, 20.07834422972895, 28.172961127373483, 46.548206344727554, 42.443045877641254, 44.950609284062544, 24.268196513575894, 5.806385076815083, 0.259303234277233, 0.06672059681506888, 0.0476337919732736, 0.004259492909055083, 0.05789278563292277, 0.015037724684413164, 0.044442204563247587, 0.04326390004867027, 0.05367940930168956, 0.027999944812167558, 0.03862474737088046, 0.058810329139833493, 0.0394722972545893, 0.02129897373848625, 0.07614252833469261, 0.03578386352127118, 0.04305686478713348, 0.026175113800432415, 0.02770276589980049, 0.037840924511152896, 0.05578311355484109, 0.03941032457195463, 0.015670672273113122, 0.06291590540880157, 0.04328309438161312, 0.047083112651542317, 0.01784568877830621, 0.10830737334946472, 0.029722160261665142, 0.02673227614122293, 0.03634637507099298, 0.07054216513830809, 0.04171103982615375, 0.028338239663430763, 0.07368686413692851, 0.014588394007014652, 0.03474389150318119, 0.032409682884932525, 0.08566784341969798, 0.11168878585580858, 0.03128365812552793, 0.05860159699354441, 0.026463982574040854, 0.04366926398248442, 0.06187812440217503, 0.02646869401477518, 0.032576418091212554, 0.07666164483394354, 0.008968713903619398, 0.03137732003515046, 0.10115192061470402, 0.05768279710243787, 0.10894064461031269, 0.019349099940530235, 0.024061463810803912, 0.07910173446420701, 0.014978338506132846, 0.04327598125523618, 0.048340741740239244, 0.04346674480926126, 0.06466144440515388, 0.0625028039869522, 0.01761978094075476, 0.0643071364010534, 0.049218165222555406, 0.048272058127387885, 0.017205112869100227, 0.10002145829099802, 0.037553511304600586, 0.06088980969281928, 0.0482127131263335, 0.005277216297409107, 0.03654126017805069, 0.08843280029513183, 3.1520833507660897, 15.329665003284333, 40.49571852530203, 51.99384858531337, 51.3746867641326, 35.951001567225305, 40.006402846305605, 39.67486058512042, 29.221122380225893, 28.26131839906016, 16.088019974770084, 8.146391203326564, 1.597354976880935, 0.22976040179210327, 0.10813973032899442, 0.29671688473993735, 0.9173716580675495, 3.090425162546097, 2.4474329813834164, 3.9279068429623885, 5.821143975180965, 5.3109696219044356, 6.18389408434591, 4.0930359305874, 4.684977973661115, 7.974735046586684, 14.529029823118641, 21.26955432276572, 26.054463501899477, 34.11983128516905, 39.41955743297454, 44.78168456785141, 48.163544285681944, 51.58982876808413, 55.37834805826987, 57.23540206109324, 61.0920411540616, 59.98562682059504, 57.22739650357155, 60.5554138460467, 58.29759167086694, 59.80798659786102, 56.52004803380659, 57.590957072473344, 54.91688120749689, 57.51121136449999, 58.173507490465724, 58.87622756342734, 51.74902600626792, 55.67745231813001, 41.12102670054282, 42.59463371769075, 56.77648867330244, 57.73997183768981, 59.08328556245374, 57.58813296594928, 58.32566799656038, 56.27979501601189, 53.86840028147544, 52.6837738867729, 52.98358417326405, 55.48793908088438, 53.08597372424219, 54.45686955605784, 53.7980604171753, 54.10935932590116, 52.77602803322577, 55.7829091625829, 57.00484514236451, 54.89614755876603, 55.02888841013755, 54.83358575451759, 50.32653923957579, 41.71131987725535, 29.932903128285563, 19.685075629142023, 12.967645064476999, 7.79895059524044, 8.029909066615566, 6.1508039889797095, 6.646538626763129, 2.923102734550353, 7.225175990212349, 3.3983687287376774, 3.3181758705646764, 3.2470880593022997, 2.9404785892655774, 0.9326218945845481, 0.3162884393767003, 0.21827449150864156, 0.45398247818793025, 1.9483805087304886, 6.732472854275858, 13.530144326148497, 20.806761710874497, 22.482796369060395, 29.40217898738, 50.77346586412, 47.38374571646414, 51.15010753754647, 31.20129958275826, 7.659536321316996, 0.5174558044921967, 0.046031603349312666, 0.004714873287030646, 0.06465939895039605, 0.02635031810871536, 0.03332161862823752, 0.008041379793036369, 0.02758439382418029, 0.03955701891813548, 0.0597157531357821, 0.03396385311779957, 0.023621317570007617, 0.025207023812277664, 0.025006398791447285, 0.057819651049231334, 0.03984099622034738, 0.053290696288909645, 0.059062375897361394, 0.03966406438379519, 0.028108103020537286, 0.03775782695400619, 0.021183771351652763, 0.04375560592199045, 0.003989062674771694, 0.02561928828306977, 0.027388288722103162, 0.011597838602028789, 0.059489994685375885, 0.05135892514860438, 0.05379169480875135, 0.03153141287546004, 0.07594224996864796, 0.03501704781346264, 0.044018711158705336, 0.03415492310699436, 0.19277899345803648, 0.11293075993777284, 0.15243907098568257, 0.13531394152631684, 0.30761534348130226, 0.1069073400069629, 0.21649612564473383, 0.15099859586165798, 0.13322184733565778, 0.2029889996253675, 0.11588272653640279, 0.21648803575625344, 0.16761040044648035, 0.1824196154672292, 0.14356000469096247, 0.126658457992298, 0.21431919487733997, 0.2971291013302342, 0.1699707173411885, 0.07906696939420316, 0.18591522870044555, 0.1915298258104632, 0.15990855082148508, 0.14012888073921204, 0.12798068744520988, 0.12582930571009077, 0.1389096364859612, 0.15606404582579292, 0.0828682287265697, 0.2199662894371056, 0.1877638448270098, 0.17054566632836096, 0.22193669822187195, 0.13305088715447536, 0.12073910344512233, 0.1505461749770949, 0.21267322432850638, 0.15725733502016914, 0.3529897200003747, 3.9579965702949034, 19.180996148817, 46.21827617768319, 59.403554931763686, 61.56689113186252, 44.62327180370208, 50.13791245798911, 41.59264856769193, 35.152344242219, 25.13230642964763, 22.056289603633267, 9.917638455667804, 2.1008082262931334, 0.3183237511304117, 0.6008516456330977, 0.6979439744064886, 1.295443157995901, 4.247609184634301, 4.709166249921245, 8.007197562725313, 11.105493941614705, 10.622117711651711, 15.28830655159489, 7.780464464618315, 6.655932213029554, 7.710990953829981, 12.104564770575493, 22.264126193138864, 26.865935210258733, 34.530950592410186, 39.730832807479366, 44.24854816928987, 48.87630170391452, 51.85944857135896, 54.543106786666385, 58.69608094615322, 58.37436422224968, 59.82846921490085, 57.46809274919572, 61.73876939281341, 60.99297777298958, 62.65101071326964, 58.68551800327917, 60.986611766199914, 57.732652694948264, 59.33394462831559, 59.88018958799301, 60.1714216509173, 53.87531542008924, 55.924632241649014, 45.16753596644248, 46.734350265995154, 58.772335744673214, 59.8891875051683, 59.66401600068616, 59.588702571007516, 59.62616512852331, 58.064398919382405, 56.96394658857777, 56.348777740232414, 54.57157534937705, 57.79555966777187, 54.40177986698767, 56.73069892391082, 54.23369061562323, 55.815770779886556, 55.10281332077519, 57.08596760226835, 57.059836772180375, 55.712777183901885, 58.00299029196463, 58.89818499165197, 55.36622401206724, 44.9633530647524, 32.56530184899607, 21.946392636145315, 14.069430020547683, 8.356704769595977, 7.6625339927211895, 8.01860381518641, 9.505364991003468, 10.405040998612682, 12.937812497538905, 11.62344096168395, 7.209486509523085, 5.801247752481892, 5.174970261512264, 1.908705734437512, 1.1699153002231353, 0.34722579703215634, 0.9066748643113721, 2.6731818097253, 8.644316484851222, 18.123978184115504, 28.79690039542414, 31.446663448887488, 40.30339294864286, 58.979429045031154, 55.221504242189475, 56.863067150115974, 33.670884639986106, 9.49534627699083, 0.8825466493445059, 0.1501000513352694, 0.11596141142710564, 0.15393833569701643, 0.1972026149592092, 0.10936202361218392, 0.15992445480679313, 0.19465278323379256, 0.1346603459528377, 0.1438294378139319, 0.16556748910056007, 0.10518207169708707, 0.11206123482195601, 0.13896208286525744, 0.21190751944818806, 0.21275522637992136, 0.14824421866045845, 0.16942851095189973, 0.12094274493715457, 0.10536659163452926, 0.13243035593580815, 0.09434839335059929, 0.11795454237970615, 0.1816546460313182, 0.11510481021457142, 0.23837055590364242, 0.08648255494453254, 0.13416067276510502, 0.12113297222963265, 0.17203705565583322, 0.12319439992068276, 0.1644468556849226, 0.12281406024891524, 0.16658923588693145, 0.09147899570844828], [0.008776396148717933, 0.05891092414517076, 0.05468469668900775, 0.04523008385853422, 0.09317907504737379, 0.04772574550682499, 0.05778774348718505, 0.03156808741961516, 0.030966539859711647, 0.06395801864263993, 0.03597343197813438, 0.027274555308864485, 0.060060898728308186, 0.07714365969502157, 0.029569048013898636, 0.056884169593573584, 0.1326095898665728, 0.0798206849985065, 0.14602146051343412, 0.06652365093149486, 0.050081485026185556, 0.04010574471565985, 0.05976628046482802, 0.051172026508157296, 0.047721930388962074, 0.021506031982660778, 0.014016487346511456, 0.007479257990546044, 0.05436858199837227, 0.07594065650576547, 0.04037726925866258, 0.03789039846930293, 0.04048007059722178, 0.055919818114489324, 0.0670123077748764, 0.027145693574341077, 0.027104809377042037, 0.046110349527049455, 0.010735652608526571, 0.8410754907996425, 8.901124846550728, 26.910720832886238, 44.52521647176435, 50.48545406710718, 40.581626276816095, 20.339472101580714, 24.856616758531143, 24.401600245506536, 20.24778081524757, 16.288826696334347, 9.207785552547826, 3.7253014695259834, 0.7621341138597458, 0.1887116641286881, 0.2732966575891741, 1.0632170256107085, 2.1071281452332777, 2.9358087624272997, 3.187264804878543, 1.79113379168895, 3.293818442090865, 7.739285461364254, 3.5242554833812103, 2.379942228717189, 2.6762581736810747, 5.644152904710462, 8.923433326905775, 14.01883536769498, 21.136811510209117, 28.150127049415346, 33.997661221411924, 39.58227695957307, 42.80166033775576, 47.97811815815587, 50.07399743603122, 50.06996916186426, 54.387949589760076, 55.32557648997153, 57.008920484973544, 57.382169308200965, 56.958694534917036, 57.612490884719364, 55.309788950027965, 55.27846097946168, 56.017745387169626, 54.20877572028868, 59.09027130373063, 62.83056113027758, 54.267430843845496, 36.49832125632994, 33.16910366858206, 53.95546513219034, 52.80950546264649, 57.048355994686005, 53.79531475805468, 53.14252253501646, 51.221926135401574, 53.55896449858143, 51.655218601226814, 50.490753189209975, 47.0357334229254, 47.32632221714143, 49.14947909693564, 52.09910931125764, 50.36946958111179, 51.14908379893149, 53.74412390493578, 50.77043779434697, 48.41581936805479, 47.98416645296159, 43.57554005038354, 37.45288887331563, 31.40113649829742, 26.626272509174964, 21.75233925542524, 11.824281023394677, 4.494570926312478, 4.539008928883461, 5.1606006583859845, 4.306430028330896, 0.5735944824353342, 6.051185102232042, 0.8547089753612396, 2.8333684657850577, 4.202628914386996, 2.166327742799636, 0.4630917232603797, 0.5129919940185163, 0.16320289743523445, 0.8039181427128854, 2.2173107102993996, 8.926594757264661, 18.925967562583185, 22.16105022738057, 22.491917840896114, 37.98538200316891, 44.04419660568238, 45.06138486246909, 36.92727950311477, 13.404234282432066, 3.4047815588212784, 0.06118510594411243, 0.04616433957351312, 0.100371238715466, 0.01925451297973914, 0.0617914070795861, 0.10168781443949669, 0.04984837596214587, 0.05011811552028503, 0.0743500434703404, 0.019710570866722735, 0.017521650823313865, 0.025576988738330624, 0.028808190554921186, 0.07257876391973227, 0.11676286963085014, 0.11404755525290967, 0.01870668350508617, 0.11336997346652132, 0.04662523722095836, 0.08664995281686706, 0.010790546638740888, 0.024469306039053108, 0.014749895875161935, 0.03732784095430567, 0.03089908198753913, 0.04760718573966334, 0.028285776047156225, 0.07863830489617202, 0.032442233960835204, 0.08964582391443754, 0.03416656381300381, 0.07416298778186883, 0.014646337067167607, 0.11013100734881817, 0.008340325495678811, 0.026990924661438313, 0.04233620587676283, 0.029246032786285205, 0.07480762012663388, 0.025930319980327642, 0.041916014311174234, 0.01734868349176982, 0.022360365574939117, 0.06455485859224874, 0.0682697338502734, 0.08013698738068342, 0.05399219150985441, 0.07282021185082775, 0.0821137163908251, 0.05723659685181995, 0.057237462531174385, 0.14988539349888602, 0.041019859979109424, 0.02604170150363878, 0.0830923400879387, 0.011790938724222924, 0.0546331083281867, 0.05926198776691191, 0.07191985169605863, 0.03242711521564953, 0.038716325521348946, 0.0038326200991568547, 0.026717086532904256, 0.03292201567561396, 0.08401727634331874, 0.04890033066452992, 0.024121705134729707, 0.02367423317815748, 0.08702535888240223, 0.04901835033970495, 0.07461304911562512, 0.055643053530084516, 0.031452971217673154, 0.02450905642622421, 0.9911901744142656, 11.052224232304482, 30.794775332173995, 51.84413563820624, 55.905306723810014, 46.22420680138373, 27.104140750823486, 28.226548548667665, 28.702879221208637, 21.41832393984641, 21.020930967023297, 9.392075173316464, 2.9860293192248193, 0.6147684601526107, 0.05013401950559309, 0.1507948930825918, 0.7957148119326561, 1.8000932206069271, 3.0215434393575116, 3.6177951866580598, 6.573835044137894, 6.338311424178462, 5.774811958113025, 4.423071021033872, 3.533215157447323, 3.0455091211103626, 5.900077752528652, 12.920019645844738, 16.352425967493367, 24.54652790100344, 30.144095305473577, 37.53152455053022, 41.05011809256769, 45.138616331162, 49.85246981343916, 51.02528987392303, 52.373730136502175, 55.78160693568569, 57.385503322847434, 59.835482412768954, 59.4151573027334, 59.9445439154102, 59.84931268999654, 57.96803805135912, 56.728910323112245, 58.335207200819454, 56.27500187966132, 60.91284767273934, 60.792477976891306, 53.96755387706142, 39.892430536208614, 39.7671421881645, 56.99221903277982, 56.14745032402777, 58.21351958859352, 57.61037280482631, 55.155451528487674, 52.870670903113584, 54.96200415395922, 54.15469408035279, 51.5496519304091, 48.79291995879143, 48.037016468663374, 51.488490412312174, 52.7567691956797, 52.76403342523883, 53.734188541289306, 54.58592337946738, 53.01668113277805, 50.13995993521906, 49.858121948857466, 48.4678731426116, 43.25571390890306, 37.71646038178475, 30.834985509995494, 22.234945720241917, 11.67284909755953, 5.1910593336628335, 5.363426910292718, 5.868713500038271, 7.205089532559918, 4.077576643997624, 5.307351725716745, 4.512128435796307, 5.631618480528555, 2.135795032785785, 4.019814840247554, 1.0057533219937356, 0.06339848717494358, 0.1757758098744577, 0.560936319731897, 2.6940360713389615, 9.261889746112208, 19.78568442406193, 25.03990911668347, 24.358889556700184, 39.34385176627867, 49.95240396068942, 47.92169094085694, 43.89623695804227, 15.9778445189999, 4.194011957414689, 0.10432383871727413, 0.12809530185956147, 0.00923601155649991, 0.026145397249849576, 0.08371089479976124, 0.011433396871472079, 0.03495421328191315, 0.032698229901612766, 0.0645551573665392, 0.020109331122629588, 0.03069391215009795, 0.0351303483870241, 0.03701021324001974, 0.04907445095840001, 0.1219830846774482, 0.020196374032586333, 0.0367566917632376, 0.023079363989733884, 0.07192284709984256, 0.0452474051065022, 0.0511711684896821, 0.04599503797268675, 0.027077264685724533, 0.025307237688872605, 0.031964275535316236, 0.022815868048177614, 0.04712593313606997, 0.012825258928651532, 0.03395213197255808, 0.015082972710050884, 0.03823674681987013, 0.020125625812779033, 0.07900827173744479, 0.10841228142981568, 0.02316593767083701, 0.16701959343927522, 0.14317311496744234, 0.19397891697383698, 0.11205899018433788, 0.11865570435240386, 0.1736656819740611, 0.13757615320144162, 0.16337367375531506, 0.20892887766803467, 0.18289083614945414, 0.14038835471916583, 0.26067774923097703, 0.11662273682774076, 0.1120903155195617, 0.12799908121627185, 0.13584626538138236, 0.24625908583402636, 0.17453364427051238, 0.36528861811084135, 0.28593530037230064, 0.108910774842145, 0.14823753837375872, 0.1960099386351724, 0.10502010538813569, 0.17998215351854602, 0.19155430998052322, 0.09908147606878512, 0.10806186515237055, 0.18689367619733657, 0.1507641423133112, 0.12412384077305756, 0.14545359017868198, 0.1588772279360602, 0.13397524884391215, 0.15667293250801104, 0.12584140223841514, 0.1763694054417072, 0.13376871153952616, 0.10077671373202916, 1.159334338961109, 13.008482821526067, 35.76199431573191, 59.478793836409054, 63.97776811353622, 52.364100717729144, 30.238791127358716, 36.88438446291032, 35.91328405564831, 30.923770320030954, 23.851170116855254, 12.650468484047922, 4.678451639990653, 1.05705093712576, 0.2726453909229848, 0.6810793148413782, 2.6107403732115224, 4.982042110735371, 6.898641615144669, 8.263254300240549, 9.24964802880441, 11.168874540636617, 14.909750761524325, 9.258046803935882, 5.794843012286771, 5.8221142715023415, 8.161679621665709, 12.027041085304754, 17.43466869477303, 23.817424005077733, 30.17597829141925, 37.483954045080374, 42.60049373872819, 45.404674622320364, 49.7304448773784, 51.82099757655975, 53.18133046550136, 56.89993350736557, 58.87546662361392, 60.954875869135705, 60.718619746546594, 61.82364948334233, 61.65602307165823, 58.48391994353264, 58.68123085268083, 59.69283365434217, 57.178429634340354, 61.7260060002727, 60.68783698543426, 53.023831613602184, 45.888957900385705, 45.509037125495176, 56.919278637055434, 55.60553566102059, 58.42384492197345, 56.819870087408255, 55.34872239635837, 53.52641667089155, 55.398203096082135, 55.28995744643673, 53.48494545105965, 49.93243909651234, 48.17395817848944, 53.204892143126465, 53.867047063765995, 52.99092685022662, 54.237946387260195, 55.38984844761511, 54.220421237330285, 53.55167673480127, 54.14551181177939, 51.48703913534842, 49.07944909987911, 46.01108481807094, 40.82930434134699, 28.528926026436594, 15.535870867390788, 7.571955188628166, 9.010066716901719, 11.49335555491909, 10.039269193526238, 7.762073451472868, 12.091062991849839, 7.58533537387848, 9.885299494189601, 7.845606698143867, 6.717661984505193, 1.3919766103067708, 1.245232284549744, 0.5590948282230286, 1.483423238800418, 3.524455524259998, 14.423182702833607, 26.285528367565526, 31.838820057530558, 34.89296574746409, 51.21216335604268, 57.67851614182996, 56.516255101849964, 50.586921861094815, 20.44636453351667, 5.338542413327002, 0.23916737927544504, 0.24864862132216656, 0.2023723448115972, 0.09042390877561224, 0.18700422268481026, 0.2981448419872792, 0.06967866147357611, 0.0905214777336486, 0.15222583807283832, 0.06427470789921862, 0.12951179077067684, 0.20828115032805553, 0.10385470179420325, 0.24277093429719251, 0.23259393119763946, 0.3527729784048373, 0.12992370092580396, 0.18156063172125048, 0.15638215617547113, 0.2021606747181185, 0.10676320822488879, 0.16115163573093955, 0.10360976050217306, 0.11298912051584452, 0.1252474236272035, 0.10437842248187912, 0.23116188304078197, 0.12504014321753096, 0.11243100248036847, 0.15744335648994293, 0.10102638944743142, 0.09606620762497188, 0.1386237477943782, 0.23567573437767647, 0.09684659841079866], [0.0542896059942582, 0.03657119123325233, 0.04408730284100579, 0.054176117729155295, 0.04104168582407217, 0.022076763655810107, 0.06334355100989342, 0.02112162821445494, 0.07062379946751941, 0.06088107629048248, 0.03624391847199971, 0.07094790062476551, 0.03858198817338675, 0.11930439696316758, 0.05514499295743243, 0.06440312721796575, 0.00813651833713295, 0.11315915373063858, 0.0724130207973142, 0.1011362924210487, 0.0678189370721098, 0.003973381333766625, 0.0685454948594974, 0.05423897141290288, 0.015200844913300489, 0.046348265792813995, 0.07372080183197414, 0.04811232113429616, 0.030578154349519365, 0.031343204224662434, 0.03975878349475322, 0.02098108746952588, 0.10355618797362813, 0.05587324762957231, 0.040260739624500275, 0.028452419322885336, 0.0369160840167634, 0.05827758393640961, 0.008089941148946603, 0.2439023848743208, 3.18286415069334, 16.792319782318607, 40.91239583107733, 45.221668597190614, 36.61075599731938, 32.28966120750674, 35.029071992443455, 30.38337165309537, 26.45642407478825, 22.987970190663493, 15.296363099928826, 4.517377057383138, 1.2249475020554759, 0.394903983800642, 0.31082442450907927, 1.0163214742656679, 1.5355135404294538, 2.7149908436882884, 3.3826981244548677, 5.252382159233093, 3.666355355132011, 1.4726673643435202, 2.3914678683204036, 1.6568216633412147, 2.6198765539353897, 6.390349999550851, 6.304938918159855, 6.4367741923178405, 13.182987109307321, 16.083456297074598, 21.02973080450489, 29.43240281074278, 33.84437891744798, 36.529005958187966, 40.76949211858934, 43.48037942763298, 48.524669062706735, 51.303770311417125, 54.433198052067915, 58.110980987548835, 58.65988531420308, 57.97887556014523, 58.727459907531745, 55.27590359410932, 55.67090980468258, 55.75038486911405, 52.793972876764116, 54.01566959196522, 63.26364571048368, 46.10955199887676, 39.27841094232375, 49.831775388410016, 59.291120190774244, 56.479404434081054, 54.77561704574093, 53.31383205229237, 54.16207598101709, 53.8866118461855, 50.04140646226945, 49.500154679821385, 47.844239819434385, 47.09235283636278, 46.296864786455714, 52.44036336098948, 49.34108295748311, 49.90379402714391, 52.27698095383183, 48.536130228350245, 46.097757431768606, 43.85814682129891, 35.59811768993255, 33.79872252864222, 27.76281064556491, 29.99495698559669, 24.345363263160955, 9.620282592311982, 3.1339958310127263, 5.119423616317011, 4.7174743202424825, 4.903958507122533, 1.4252244584983396, 3.2537254450782656, 4.050762586055264, 2.355969682816536, 1.0285991670623904, 2.1689880903690093, 1.4620860353592904, 0.08080557529484073, 0.4056267939027279, 1.4027082150982273, 5.326372279274849, 9.014088126920885, 15.215204358100893, 24.05718868778598, 32.46093542345109, 30.249048125359323, 40.3868099950975, 44.7678856695852, 32.56458405525454, 12.605268070774695, 1.3372812420129778, 0.00497948675934646, 0.12015111564147858, 0.032897420422804934, 0.057814679138602755, 0.02703342338903777, 0.0247357590799971, 0.07252792632507701, 0.12309932840927956, 0.055935921282657695, 0.09781551577391163, 0.060850754530439456, 0.05186609067623654, 0.008273456553598086, 0.11409146741272942, 0.023898867394534812, 0.09472654201090337, 0.08125104776193058, 0.023493204686430194, 0.04326872257215362, 0.040482008799670205, 0.04412430488774854, 0.015987760853022337, 0.03357112963473605, 0.024309377523980314, 0.07729492375567075, 0.06449701895396556, 0.02660008000900909, 0.028275403216661468, 0.0504710981922765, 0.08830943715668495, 0.09698179760767568, 0.06735592119155392, 0.039065761206251, 0.20683129828783775, 0.06811781095400934, 0.0590671026598542, 0.042859106850359714, 0.04092673050059427, 0.018193251378233397, 0.059511150203404896, 0.034073859513286626, 0.08144846095913842, 0.02571544189366602, 0.02162294466078522, 0.026313461618678227, 0.024278912122451493, 0.016771859504402648, 0.01642206184295637, 0.05128619659151282, 0.08056935208338885, 0.019048640256627433, 0.045076050390038765, 0.13779404392886546, 0.06035457470364148, 0.03567546974086473, 0.07587059776509002, 0.09309415420096728, 0.05017007926418897, 0.030620469216016993, 0.07010721871929784, 0.08677254220651043, 0.04280712778469728, 0.07675426486398905, 0.028078922731501442, 0.006012144074174426, 0.05314524683560576, 0.006242083928232352, 0.04241636548671992, 0.04896679262240087, 0.003184946145929937, 0.02915216403292312, 0.016211249767952872, 0.009283790545117472, 0.019706428246272188, 0.10023603951858898, 4.3280516036095165, 21.787889657482026, 46.45292020613148, 54.308741246500325, 42.87900555518366, 33.856353913584066, 36.48314168376308, 32.1689659549344, 30.657241344451908, 26.12303633843699, 16.870323957935458, 5.353770034928476, 0.9083134344508572, 0.22277279126067318, 0.17852218911772777, 0.6239689309750834, 1.3367806495197359, 2.3850033119801552, 2.827153225098887, 4.1943517327308655, 3.4461235855856254, 2.950019999857872, 3.8339891212601818, 3.8571492462388934, 5.475653765663024, 3.819356474184221, 6.17604346044602, 8.209377604146159, 15.712669741722847, 20.472283555615334, 23.496285830774617, 31.73333771767155, 35.766246164998705, 38.93483877182007, 43.60907239298667, 46.89588131443147, 51.77505485473141, 53.441866059457105, 56.86121579139464, 60.13655178008541, 61.70902605979674, 59.99282829223141, 58.81541905864593, 57.05501225686843, 58.1773788698258, 57.34216113244334, 54.4289069790994, 57.60866265143118, 61.67419541266657, 50.42532805473574, 42.8486660219008, 52.407921437294256, 58.26813467087285, 58.29815256980158, 54.87409599365727, 53.72892472051806, 53.700644431575654, 54.58708047866822, 51.42919986478744, 51.09284093303066, 48.733041055740856, 49.14265025046564, 48.70170916280439, 53.26577909531132, 50.1557945436047, 52.58058024990944, 54.00203543324625, 51.492679503656205, 49.07679365527246, 48.68355643364691, 42.858279751193145, 41.142960594546416, 35.009993583925315, 35.451958410201534, 26.535895216849546, 12.493607997894289, 5.151456142625501, 3.3837804534742912, 2.697216623252438, 3.467052617380696, 4.017660233282274, 5.617364587322359, 6.4828130122153995, 2.916528596993416, 1.2953465696304076, 0.6859193357729143, 0.2057157516960175, 0.1722402068515939, 0.23945599524003847, 1.2102220664101264, 4.969206154346466, 11.197988333240634, 19.00752344439107, 23.23184355612724, 35.22802637469384, 36.81501734641291, 46.42459677111718, 49.73675597098566, 37.40241973630844, 15.386615857001274, 2.1635332991999965, 0.06810586764326981, 0.053846730565231656, 0.05253405039829593, 0.0445283281676952, 0.04346542330759187, 0.022163310523835883, 0.06750481804051707, 0.12039666214296896, 0.01999571070735974, 0.04177588916894409, 0.0868697894076186, 0.036899551839357426, 0.0365857545646929, 0.09778394529055204, 0.02191261782671415, 0.12005280357815566, 0.11344999901109165, 0.050889753751576915, 0.06874355923144088, 0.008737324706969724, 0.1024149467928275, 0.04265891658442636, 0.03847905659988042, 0.02205961860806471, 0.08077836385177029, 0.027965269757494814, 0.019039353355765343, 0.07545902468864957, 0.08522438576384898, 0.06719852842751049, 0.07790977060193978, 0.01800976374426917, 0.02228813114455871, 0.06655710599114818, 0.03980249264127305, 0.15742820327080068, 0.14914717585329088, 0.09032004257483829, 0.1887499685249021, 0.2197469431426256, 0.1070030014060678, 0.18040074396037287, 0.07043875092940946, 0.128125891750378, 0.1497866141219293, 0.25267387710271344, 0.1338665256456983, 0.16809058435741933, 0.1741341447397586, 0.1527773754130448, 0.18914644966923422, 0.18817586223444632, 0.18458104061503566, 0.14286793618192598, 0.16346558898447022, 0.15731908170686615, 0.11668403918344168, 0.24898943851792046, 0.10766444171989158, 0.1489312309891947, 0.16992810753084, 0.1407746928593805, 0.21107643662441164, 0.1109314313338649, 0.1249706207384025, 0.1581531369517888, 0.07627827911487511, 0.17615482421411624, 0.20938630876762254, 0.14103251208941783, 0.21129395962963182, 0.14908418810415655, 0.12270769660150814, 0.08749341562149987, 0.4630852881218157, 6.0278597474098214, 23.88922102989689, 52.094610352669996, 61.04585524528258, 50.984752178192146, 44.395350717729144, 46.28229710363573, 42.11207628250122, 37.322964283727835, 31.314656080738192, 20.603763364976455, 6.551214245057876, 1.7469837156034287, 0.6098871930472313, 0.5412515372999254, 2.2617617057215784, 3.93031983606277, 4.804269508008034, 6.664146146466655, 15.705757544886684, 10.716905709235899, 8.182319133512436, 7.56295923263796, 6.053407124934658, 3.774295795348383, 8.584712147712708, 7.083133728273454, 8.350512327686433, 16.579642988020375, 18.86052869981335, 23.895371306327082, 32.221488452726796, 36.6097754047763, 39.9974637646829, 43.86402253181704, 47.85622658268098, 52.53731650690879, 54.89787340164185, 58.0526396536058, 61.912600994110115, 61.151390537138916, 59.84594337401852, 60.839095346389286, 56.43862747376966, 57.856168131674494, 58.405790252070275, 55.300681206487845, 59.4408292155112, 61.831462844725586, 53.22354693566599, 49.51713854266752, 55.51328935930806, 59.01960980507636, 58.51221199958556, 57.44286406424738, 55.04296579668599, 56.233267861027876, 55.85503370531144, 53.30379862939158, 53.50749907955047, 50.541190947255785, 50.212084477947606, 50.12011666451731, 54.83001247529061, 52.557767744987245, 54.56622523646201, 53.13923951118223, 52.07098199475197, 49.725161444756296, 49.83736868827574, 45.83937521903746, 47.69353059030349, 41.25041784778718, 42.96019077301026, 31.278519284340646, 16.276974274266152, 6.599193657598188, 10.365866326516675, 9.45220216628044, 14.570551053170236, 8.040979466130658, 8.806736930724114, 7.119064600236955, 7.488773974680132, 4.356237265371508, 3.8194074649964613, 2.211964764902669, 0.3961826151897831, 0.8286443352699281, 1.8517049930749403, 7.864670397773867, 13.105570308623776, 23.057454978266072, 34.44713346419796, 45.84967144073979, 42.48427391052246, 56.56577502527545, 55.63507895315848, 43.34867408198696, 17.662291680612874, 2.7628918088251546, 0.10427790408533427, 0.2255588998236964, 0.12346977022506538, 0.16092216175410057, 0.22258344496930801, 0.1395831809889886, 0.16306674828933132, 0.24635472425049354, 0.13019923210865067, 0.19542270159769445, 0.2256499417126179, 0.1712220300349497, 0.09546079132105074, 0.2081721513381889, 0.1413221699335883, 0.14152084717587118, 0.1446601529155047, 0.23768666921363724, 0.12059937666861281, 0.14126411579068632, 0.18647415112824212, 0.12979757220995042, 0.09442943013122967, 0.20816727901899046, 0.2548313798803476, 0.22664783252102716, 0.13988049971240182, 0.14457899356080642, 0.24314685364163693, 0.17825035047867607, 0.15102193089983157, 0.10313662460013744, 0.11263461332888373, 0.3404336002084517, 0.20082863167889659], [0.08503861710309021, 0.03467982357007361, 0.040640922248243325, 0.05200140861674182, 0.03588629713762672, 0.07950481928644643, 0.014790640261414793, 0.053822357477920676, 0.12675309283358435, 0.028979905332709034, 0.0880513344741156, 0.07966772022266543, 0.08122788126310033, 0.062375629561082016, 0.0336197302526524, 0.017186826350347652, 0.10865772067899666, 0.10513214574706171, 0.1867321388976228, 0.0385426418975957, 0.10741072106024913, 0.05718451053384812, 0.07384932840303068, 0.027552804188622583, 0.05966366298737065, 0.0585668204322217, 0.01591681153513491, 0.09741540337281843, 0.02682085888790748, 0.04972855598034878, 0.010386440046732465, 0.029861341200528607, 0.05433102453788442, 0.14102839053638522, 0.06409276967808124, 0.06101214627344763, 0.024425047224447615, 0.06618925355254643, 0.058033623236922495, 0.018909286947981007, 1.2263575941324234, 7.144294265777835, 28.339614791254846, 35.51495559753911, 43.17073183674967, 33.169366467383604, 21.8744053763728, 28.960112179479292, 22.76551296634059, 27.530549456996305, 14.519600445224395, 6.846478504519309, 2.506714213278986, 0.6498114668553876, 0.19514819697266628, 0.2563297406079308, 0.4001791733166864, 3.6835681863369483, 1.948495238058029, 2.8031189018680207, 2.250579763804713, 1.8355221517624396, 3.5137496600227975, 2.5687597355534955, 4.69006871984851, 0.740181711171904, 2.819687728920291, 2.60254678706969, 5.583330181337172, 10.15821801077935, 12.9964421256896, 18.450356644968835, 23.618400981349332, 28.008637351374475, 30.56006266224769, 33.23931017229634, 38.36232177672848, 42.8330942123167, 47.58921907794091, 49.83489759506718, 54.88953836502568, 56.09367070659515, 57.07785221838183, 55.69099626233501, 57.0017856936301, 58.04191197118452, 57.876062393188484, 50.0080467039539, 40.86253466144685, 50.47980193168887, 45.62610418565812, 57.342216045625754, 55.025970166729344, 53.82935308641004, 56.30583955395607, 55.924718533792806, 55.55892613626296, 52.35605593650572, 50.847084829884196, 50.40486504954677, 50.28882957273915, 49.25178235576999, 51.64572646540981, 51.282307101834206, 49.706906733974336, 52.163177305652255, 51.4586333305605, 45.53960415624803, 37.88483204380159, 31.958352327346805, 23.90958401464647, 20.55707343163029, 21.21962255047214, 20.637954665768532, 13.834937003351028, 9.348768284243922, 7.297816814914827, 3.1622280709205137, 0.9514629384202342, 1.483964158161994, 5.878024716531077, 4.187962191720163, 7.913740719518355, 2.7066060420005553, 1.2979502879804181, 1.319787716192584, 0.10734738857154885, 0.18604846671223643, 0.3357994730674452, 2.0096847030424305, 6.150629933803312, 10.170088083513322, 20.76168779403933, 33.4065600364439, 27.429262092036588, 33.83869932543847, 41.93341232115223, 41.9192054963881, 23.820259878712317, 6.026968879084434, 1.0027626373114125, 0.019715954549610615, 0.03047896703074296, 0.022822213171410467, 0.08258284565301673, 0.023407489023802262, 0.0946776349578173, 0.020406578982909842, 0.13068580519287817, 0.0880291409069492, 0.01811143127270043, 0.024696906930917216, 0.024198018983306906, 0.07133734908195273, 0.04180964683332751, 0.030041551893396728, 0.0624037794618597, 0.04211537720214936, 0.08394811392551468, 0.041933025293532884, 0.05997729172269183, 0.03902231252962544, 0.011304302437741671, 0.03944098724112396, 0.0526164086805957, 0.05388880028359352, 0.025372456669086413, 0.011598953259958616, 0.019392640547706716, 0.0673988527588306, 0.03716439226522081, 0.07879677784418868, 0.07401325589706821, 0.11468188371509315, 0.05520112805008408, 0.06293691920056459, 0.05399901352282013, 0.04777153841249886, 0.11287592336415284, 0.07457713491373485, 0.07866258988337171, 0.08313604540401891, 0.04509768088258082, 0.04100240083531507, 0.09153642932013159, 0.1142657294328655, 0.041557293640629905, 0.031256548189107454, 0.023617994663636052, 0.037890455925897244, 0.08407943671749485, 0.02039772492172497, 0.052152642033874035, 0.12903597356090624, 0.10295547544956209, 0.07981107825593603, 0.112595466235953, 0.05399294610645983, 0.10400824113598756, 0.06648727707685002, 0.07854490345644374, 0.020949486342649308, 0.021517333694763725, 0.05904199795857553, 0.019463453884987582, 0.01424395896103834, 0.026134767779900182, 0.04049906191686469, 0.01048428862686119, 0.02039958651538097, 0.02138990262943891, 0.11264188350328516, 0.039979742404313824, 0.1132283314702011, 0.07871714300445973, 0.06569113552330003, 1.8328456244161053, 10.479995531420554, 34.429902492030976, 43.80795617257395, 47.74557259774978, 39.092627879112, 26.34339313353262, 31.2302545193703, 25.81048227125599, 28.764258430850123, 17.138027683381114, 7.3639455245387175, 2.4089290345868757, 0.729206612994594, 0.12045425663311636, 0.13181181654574411, 0.39073704771937867, 0.8461680143110214, 1.636633346638372, 1.6741972729083032, 4.759140187694181, 3.942714525807289, 5.524419613422887, 5.672702366305936, 5.077568494504498, 3.1457433296788126, 3.707587555531533, 4.374338023124203, 8.737021703873912, 13.089523892248831, 17.92800284201099, 23.165422139629243, 27.2518160266261, 30.98150564778236, 34.4463489901635, 36.732373006882206, 40.23217055105394, 44.85000833388298, 48.00710447372929, 51.964269991843935, 55.78026940745693, 57.956004219670454, 59.07648025020477, 59.57095384597779, 57.35432047997752, 61.08833843661893, 57.8844758772081, 52.30411591068391, 44.05396722978161, 54.698377732307684, 48.69464497412405, 58.035675402610536, 58.89145420443628, 56.36863670041485, 57.304973140839614, 57.27544161581225, 55.737986256999356, 54.947522763283025, 52.43244409561158, 53.144154241008145, 50.920825389123735, 51.859938867630504, 52.18364815558157, 54.320418142503314, 51.679984446494814, 55.51043387382261, 51.074754884166104, 48.73628485587336, 41.7886729394236, 36.67127032433787, 28.94474041077399, 28.360915222475608, 28.71070827207258, 26.193229113855672, 20.545292592817738, 12.910800114754709, 7.472797180375746, 3.6270657085603286, 2.7690035969980302, 4.921940122881244, 4.402062806390948, 3.6771634461418277, 3.67146497772586, 0.7761141765982874, 0.8612861159828402, 0.36332286714065465, 0.1863227568326458, 0.07682534250160379, 0.745694786310196, 1.8065240690785072, 6.307208499600811, 12.079148792451429, 19.692912524746312, 33.86437123821628, 33.47561336332752, 36.80303058316631, 46.67830351860293, 48.18970649473129, 28.857059747942035, 8.000036295383207, 1.1092188281397666, 0.04921289836807598, 0.025061139604076747, 0.027071229828101014, 0.0737268615874552, 0.1419321138171419, 0.10551080768627506, 0.04193207151406715, 0.10949710789587229, 0.04733106466911493, 0.03063156791482001, 0.08244480426994064, 0.054816605538249984, 0.03426597521249806, 0.023085379695159294, 0.04003889588338714, 0.06607061717659235, 0.045689587225957264, 0.07205841401892324, 0.0302353204273048, 0.06449860475596882, 0.03617258036449071, 0.04923031154659487, 0.11865495358623805, 0.009731639799992404, 0.022571394069781228, 0.029254750866863518, 0.05759515281346056, 0.04704724058448788, 0.04280129402515389, 0.021118684521605893, 0.026284103214199987, 0.07128392211011342, 0.05593296418326998, 0.09454963698742852, 0.08081266926901956, 0.1550454399999111, 0.1291031901153826, 0.1496017877493174, 0.13675046363665214, 0.07817918840315073, 0.19217574518294106, 0.1480040807397135, 0.09386404958223143, 0.18967785421879063, 0.23607213891321616, 0.19247844184358276, 0.10396976053955094, 0.142947226282089, 0.15989877553957124, 0.2525028249909801, 0.12472587096835337, 0.13245073387459402, 0.24918387163310285, 0.1892986100527548, 0.0801636319186899, 0.13558040222814008, 0.17714338407160776, 0.1756484860614423, 0.15770031770150508, 0.12643031700844728, 0.19920732916122486, 0.10648723271104599, 0.19159443766599704, 0.19251814051981897, 0.07607457633580893, 0.09407090864354566, 0.10352509246478159, 0.11943743579209813, 0.37708830268632987, 0.1050256901691037, 0.22269641229462242, 0.13512408961692166, 0.4480444081127644, 0.24727619012757657, 0.15724538404855037, 2.0614872007600726, 12.32594040132338, 38.05542768970613, 51.42766621805007, 58.49369449000205, 47.10031917018276, 31.564030570368615, 40.62269349252024, 34.08115671527001, 37.1925062517966, 21.902354225035637, 10.35109369985519, 3.4781860199666794, 1.0276886868861415, 0.5198187260858474, 0.5384480845062964, 1.9748076003405357, 7.028082282312456, 6.665993092521545, 5.892943451481481, 8.961036109155225, 7.9472931642686175, 8.234306227776313, 6.706556773954823, 8.651230642872473, 1.5451465138504583, 5.058823487451, 4.574232793623402, 7.389471819323878, 13.179771746358565, 18.16662415381401, 23.409962308022287, 29.172300638691073, 32.76056135854414, 34.06570649916126, 36.56536632968534, 40.99565598272508, 44.28160198273198, 48.15859033215431, 54.3423951825788, 56.468868947798214, 58.960903690707305, 60.272073591909106, 61.12345149440151, 57.538891530806026, 61.19647033752934, 57.87079465004706, 54.11118322803129, 49.37031638237738, 56.0114303711922, 52.593014163355676, 59.96965885162354, 59.78623313288535, 56.77697896957398, 58.09469530659338, 59.24240043086391, 57.2923078075532, 56.05173272471274, 52.91609979444935, 53.78005281571419, 52.95984206661102, 52.29279987273678, 52.89035727900844, 53.545640207106075, 53.73617718296667, 54.70043305427798, 50.92635985343687, 48.75268428556381, 42.45209086325861, 38.36684819190733, 30.76153324496362, 28.47866869741871, 31.375543032923055, 29.579397555320497, 19.88164128795747, 13.951093093041452, 10.414412521546888, 5.665863713910503, 3.9130594461194934, 7.031361383776511, 13.080412226338542, 14.849640438633582, 16.785496819403864, 9.260585558029915, 3.1735539147930765, 2.7574615324697187, 0.7944130753317188, 0.5201815453267867, 0.8246820672385154, 2.5716654764067743, 8.951220377799004, 15.750348029598115, 29.92277360731556, 44.72086429595948, 39.64046532107938, 44.33574245822045, 55.21154142195179, 54.36085777897989, 33.97411915563768, 9.549380848484656, 1.5838476823222254, 0.1439092948191589, 0.17099031908137186, 0.15052418825366806, 0.18919433016450177, 0.24417123577046781, 0.17119687170751635, 0.08885860728520541, 0.24468777821429316, 0.19392999459899243, 0.1456974972520144, 0.24615180288111013, 0.11889594186457897, 0.17755066705567224, 0.13100144873944022, 0.07345041109909935, 0.12327961188050048, 0.13858325238670074, 0.1957600560760306, 0.23978412601976629, 0.2164626476024428, 0.21874960391752182, 0.11274765726299056, 0.1914301884150313, 0.19804250779411486, 0.09987268401610275, 0.13388580041787318, 0.14018186338005528, 0.0810602305817508, 0.20399789145636946, 0.11248714906433899, 0.11580077045026327, 0.20288484231118234, 0.17105463982349442, 0.20612092027741097, 0.21769309206114662], [0.05643859753505357, 0.028785765246157686, 0.017965497268784433, 0.04784211043208357, 0.008926391376242524, 0.018433998338878155, 0.01409647458668558, 0.034974790403559324, 0.0037075526544809224, 0.011439397255139006, 0.02606789596498974, 0.03199284678445228, 0.05456304192663201, 0.026664582697013696, 0.11266088248380732, 0.021759743066204172, 0.1228649897741214, 0.0903075859851895, 0.07073906505660665, 0.046514656259528095, 0.07151283684276766, 0.020058767404407263, 0.04945917265309442, 0.037159316932722446, 0.025421664411682757, 0.09411997657509581, 0.029800341449557777, 0.04857937429821299, 0.054478764594081915, 0.033852088550526294, 0.08200061883056357, 0.019337566486830195, 0.0734649361261437, 0.05340499277677267, 0.00724818193233542, 0.028057098801758502, 0.023618492620786833, 0.03584414314959319, 0.06811559695990817, 0.06493585709963115, 0.4632642769044446, 4.323096179193066, 18.444582916075184, 36.294867915491906, 44.56607972421954, 34.60329478786838, 30.23166418075562, 28.194955818114746, 27.543332461387884, 21.395401608559396, 17.99441837495373, 11.236234384198344, 3.6150409473526866, 1.2209893402553376, 0.20623358116755564, 0.23807921266603857, 0.6607178009806142, 0.710749777574693, 1.151171396336248, 0.9813719915766871, 3.465604037046433, 1.264911306000525, 3.1391422258269404, 4.329296465842955, 6.9088417387777765, 4.322881919722404, 2.3792945473424854, 1.2694890797138214, 3.4834677365518387, 5.303654401533065, 8.88767013626714, 11.260173589952531, 15.546062165691009, 18.31867483354384, 22.271610075427642, 26.651607098117953, 28.67353596994954, 33.09017773597471, 38.782321330039736, 45.2899766737415, 51.28539792952999, 54.71139215653943, 55.598459705229736, 58.06875275027368, 56.2953354466346, 56.51014797149166, 55.76094388961793, 54.95677563451952, 56.96872403544765, 53.45051488568706, 49.963206168143984, 53.52974676316785, 55.08053033582626, 56.082299755465606, 56.27742198205764, 54.94109007620043, 55.58879890749532, 54.8113969064528, 51.473404976629446, 52.27882446781282, 52.47397022862589, 53.62923376021847, 55.65112536953342, 52.95733959444108, 49.6382103427764, 51.96747456827472, 44.531056880950935, 37.7680826956226, 29.727951442041707, 24.590429029157086, 19.01574080990207, 14.59653675556183, 9.650323044869209, 7.5461607017824734, 6.253935848512958, 5.3131837998667075, 3.162673014786936, 1.7287812213743887, 2.0860544760381026, 0.9912330140509914, 1.3422845928899705, 3.6308912452190154, 3.8780206682220584, 1.231854183058585, 0.4928289582171748, 0.21147302502105314, 0.03994054551566801, 0.18457785368927065, 1.255161642066894, 3.8889670227804496, 5.19435461490385, 14.846908507808564, 22.08487975981928, 26.658477129474765, 28.224408895738666, 32.780594864199244, 38.29022861296131, 37.86284323661558, 17.51160010214775, 5.164646092922458, 0.08536226626846098, 0.045687396214493824, 0.06542269831463214, 0.039554793432715445, 0.10447760022455647, 0.020930667392789357, 0.03145328531372211, 0.013448070216503356, 0.09793919300840748, 0.08471183463810913, 0.09112445021709127, 0.05204440913193169, 0.03716757919098582, 0.07464062828089922, 0.0311117499105392, 0.06032433721327013, 0.022811913119268515, 0.06350140342669142, 0.03789046358677649, 0.007799544987539131, 0.03720109553767308, 0.02763702406457836, 0.047748697501036434, 0.036868088608307224, 0.11336058888944889, 0.0435834966089216, 0.024514878694448742, 0.06005742451957157, 0.042675138496223, 0.020843448282610026, 0.01851081397504576, 0.03178471793240357, 0.020889493997298905, 0.022488769571927768, 0.05207030673421199, 0.010789338135040336, 0.037991422483877796, 0.05904474438378408, 0.04340395624298723, 0.06984339335993414, 0.04164799462042509, 0.06685942726870699, 0.06387533477297233, 0.05098333905240701, 0.04863114268969625, 0.07156883787003256, 0.07044189188989901, 0.08025675756676544, 0.08181006212027804, 0.018536906929746754, 0.04185388075007547, 0.0663287581635579, 0.07682647631173173, 0.04893338735846262, 0.006850115464804995, 0.046195109494991844, 0.07379840653870376, 0.053461836500754284, 0.09858213229885987, 0.056740191029084314, 0.10533260797420818, 0.03044411577584763, 0.02342004712010103, 0.053124585444287914, 0.035153296550795916, 0.04862985949242308, 0.07533700986494941, 0.07139437666703617, 0.026263309672715205, 0.02977033953122314, 0.02963232113078477, 0.012641649678229325, 0.034102243070881215, 0.04149417948698805, 0.03601270930601224, 0.06624132454875978, 0.5375842437628777, 5.283608148174902, 24.42586991094774, 40.87352514266968, 50.875894638799856, 40.23319821203909, 32.72345573671403, 33.796722119854344, 28.162862985364853, 26.234723867908603, 18.69474776329533, 11.651538860413337, 3.2978163178889983, 0.9535535004350447, 0.15587941863604132, 0.11514858447856481, 0.4163530054351976, 0.870831571519375, 1.2062125460755442, 1.3409869012332734, 1.8647883039328361, 5.465418340698366, 3.7015841228346673, 3.166968745570029, 4.689681876090265, 6.692974096344364, 3.217234164476395, 2.098822036097127, 6.452480833376608, 7.3222458266442825, 11.022298509074796, 15.187666377713605, 19.094823637316306, 21.603571599529637, 24.613906375823486, 28.967166562234205, 30.824667715257217, 36.116678560933764, 42.35643994423651, 47.485943071303836, 53.596164257295676, 55.92203171022477, 56.29080903145575, 60.61856792819116, 57.51105839206327, 57.52671257142098, 56.31710852346113, 56.24417989484726, 56.712259861730764, 54.596917783060384, 52.46897312902635, 56.75722591338619, 55.23250256815265, 57.58978036142165, 57.26747528199227, 57.35911361632809, 58.4985896079771, 55.793770205590036, 53.372032180909194, 53.96209393778155, 53.59499539098432, 55.30468202406361, 57.76423169720558, 55.946240578928304, 53.32044124603272, 53.608598170741914, 47.94318160703106, 40.583516859239154, 33.40715231433992, 28.055986242909587, 22.866306112658595, 17.49507123424161, 13.772021205194536, 12.998884781714409, 8.701264396790537, 7.6632924810532606, 4.474825714865039, 4.370794651969787, 2.188871075068751, 5.5454547943607455, 5.606703094897732, 3.783111567458799, 4.490551477478397, 0.49615561841957034, 0.4452235498014958, 0.1842790334335258, 0.08246972511011748, 0.3283066428717106, 1.0913997455950708, 4.107584737000927, 6.5361763681134875, 16.335510746125255, 22.822232400217366, 31.46785601492851, 31.216804712049424, 38.33377476661436, 46.56861443673411, 43.04592594023674, 21.21735542051254, 5.987904033353252, 0.2055578303313063, 0.022248204557165023, 0.10606006974534643, 0.07726329964615646, 0.07317232118258554, 0.018224249210869594, 0.05873437152214109, 0.0919138655186661, 0.13454276677821914, 0.028357813209896127, 0.06713781595951127, 0.009727254904235804, 0.0989521297836496, 0.05426449746253991, 0.03790649780703168, 0.11869296686904085, 0.040238546057333874, 0.04892404491622602, 0.06224166759620271, 0.02121607536419986, 0.020588082449150183, 0.06013212575306816, 0.02710158989254025, 0.044182102391195875, 0.0910151218094172, 0.07026034437360303, 0.04152379261570112, 0.08553337200634903, 0.005434631565285306, 0.03344833340135313, 0.015661100962109143, 0.01469895198580719, 0.00619909059511678, 0.07987087141842612, 0.07336572007907015, 0.02554988263234977, 0.19039691966627875, 0.15876957726094032, 0.1541339485876022, 0.20551192634288343, 0.08539773613935517, 0.09255603106031496, 0.15310291681558857, 0.25272736536158674, 0.18844269065847322, 0.09033032347478213, 0.17180779618361305, 0.14273402401276175, 0.12255093969044187, 0.10995816259134202, 0.16929158039631384, 0.13496819072433058, 0.1870310204404016, 0.16416395473624432, 0.20449528170208778, 0.13981165905152598, 0.17414240316758234, 0.10399171661946083, 0.29667055174227686, 0.1839581498455617, 0.14388151647102448, 0.1963552451061626, 0.12763387944188812, 0.1926232018177548, 0.12326930033703967, 0.17395864931806443, 0.20773525139497173, 0.12363202764742798, 0.1275877915923634, 0.12927730657881306, 0.1364872817911448, 0.08271311124366137, 0.060181308597806966, 0.18673117362683822, 0.21383409268192707, 0.15198093508520436, 0.958949210903337, 7.208306366397489, 27.712023796573764, 50.06761181739069, 59.32376607771843, 47.229404372553674, 43.41133786785988, 42.82020530393047, 40.98615992453791, 33.495903784228915, 25.06427880256407, 14.449577312315665, 4.748408582902724, 1.7260879013807544, 0.522943016502165, 0.5711448396886549, 1.076997047470462, 1.4902774581024725, 2.579050563996838, 3.372011381772257, 8.141397535800934, 8.662595710446759, 10.184261568130987, 9.481202210149458, 16.26724973801644, 9.429574012756348, 3.8743152541498986, 3.448139683854196, 5.4918237366983975, 8.611442119844499, 12.091050244146778, 16.560339043217322, 17.519805700548236, 21.980652578415413, 23.880491795078402, 28.000429791788903, 30.259709127487678, 36.91565359792402, 42.27111270350795, 48.09706403363136, 55.87178222594723, 57.934003645373934, 56.43626620692592, 61.524521689261164, 56.281497324666674, 57.809009475092736, 55.67140010095412, 56.48952414912563, 58.078158593946895, 58.58700767640145, 53.32008823271721, 57.99976218131281, 59.51981006130096, 58.35807069655388, 59.35560395640712, 58.08922752257317, 60.057974938423406, 57.351841542028616, 53.44116003282609, 54.74079424335111, 54.33219702013078, 56.24654900643134, 58.491721537805375, 56.289377366342855, 55.09408212477162, 53.461776010451786, 46.757366734166304, 40.68715764630226, 32.70218276208447, 26.683748960495, 22.507519068256503, 16.43264824344266, 12.588265576670247, 10.4878383105801, 7.42421176164381, 7.2378883919408254, 5.611206466151822, 3.3588371209559904, 5.919520941472823, 7.116083108609723, 5.92652972667448, 8.553796026014513, 9.420181897378738, 6.812537745121987, 2.6197767786441313, 0.6134313609330886, 0.3099476522014987, 0.9549891492051463, 1.8456167391230984, 6.009750164324238, 8.303135979560114, 22.229293584823612, 29.14185324022847, 38.05645535069127, 39.93135613779868, 47.521016905384684, 53.23515322900588, 48.986363410949714, 24.765951171998058, 7.278873237871355, 0.4779544112182433, 0.19460094972483574, 0.19834684388291454, 0.18535581597637746, 0.26669965996857614, 0.19887470910626076, 0.13594924292016414, 0.21683107460698775, 0.19102181758611433, 0.10867294284605211, 0.13766612256726912, 0.19318935611555654, 0.2105865846838682, 0.18821798174852328, 0.14531198648675797, 0.340892119152892, 0.06778501469882266, 0.14519382508531695, 0.1843744420236157, 0.10880299393207797, 0.14244367668945945, 0.12151466021614692, 0.14890538318262947, 0.0874588420734771, 0.24224024987028492, 0.15815500620632403, 0.19554067913803364, 0.14780578654139273, 0.11487354359198963, 0.1992296069980629, 0.26741175401595335, 0.16223433247256666, 0.06750609740735063, 0.24417462187909314, 0.20873059879147238, 0.0962732658691464], [0.04601313679989788, 0.02110012412642039, 0.040876494284959576, 0.07809799074405625, 0.052489142324174606, 0.03263393214212791, 0.013004309955924269, 0.024042081786319617, 0.026154163210923155, 0.14942341183702793, 0.05186163970539647, 0.055638575746167096, 0.04749397326621318, 0.0334067884532194, 0.03441394892551246, 0.0279084432704915, 0.05473456135199917, 0.03308409689775398, 0.036781041867910855, 0.0915669272803972, 0.023147541984555223, 0.05852039933444993, 0.03718540605698382, 0.0937700812374392, 0.02031264511207419, 0.03694536006678978, 0.05811973535005124, 0.09630470611755887, 0.03251303580679721, 0.0314147510911308, 0.016176660898171605, 0.04832493351592172, 0.056084906231732144, 0.0328461384971536, 0.09874241321437782, 0.06049436659762456, 0.049161666238139716, 0.11750340852285586, 0.04814501776690445, 0.10405848118206186, 0.09022002213544424, 3.4875499433086765, 11.821688336710777, 29.487945533567864, 45.65294104237711, 41.84445688801427, 35.68804587087324, 19.204663730436756, 22.916141786882957, 20.577248142611598, 20.1830832804403, 12.249315919414645, 5.642099053628984, 2.4666582336348872, 0.5766609178916101, 0.21041364799584114, 0.6725398246799746, 0.5380678597477175, 0.5813108877308908, 1.300438664132549, 1.901397500788012, 6.420822893419574, 3.4933817723105034, 3.614265543799247, 1.232350485459451, 5.682483286626878, 1.0871684887716848, 0.9635198140336622, 5.180496390788786, 2.955443657213642, 5.243973578176191, 6.885697793576026, 10.135135842907815, 13.446774348135918, 15.27056469071296, 17.7814297522268, 22.06678782739947, 26.732356932855424, 33.08331358817316, 38.176719142544655, 44.47837160479638, 49.584748437327725, 54.300986720669655, 56.184834434140114, 56.583974822875, 57.653907191368845, 56.39252393476425, 52.918735627205145, 57.47847134067167, 57.2901975724005, 53.483086247597974, 60.310191185243674, 58.38214620467156, 54.43570052423785, 55.976756618868926, 55.44497736038701, 54.00645986680062, 56.0527878422891, 54.79761369766728, 56.28571387260192, 54.72020179994645, 56.43928643195861, 53.66169529576456, 51.498955295931914, 48.677566974393784, 44.68554335255777, 34.55763055432227, 26.35526614804422, 20.270218733818304, 14.12693000608875, 10.033197364499493, 7.241214561846949, 5.2177299799457675, 3.4583118605998258, 1.5076257336524226, 3.3380760156339218, 1.3869053533961697, 2.435462397913779, 2.765196691597662, 8.599836807097159, 5.891508844590956, 2.0886300023524993, 2.4713721871376038, 0.3788287625197442, 0.4697195176155337, 0.24355614377606302, 0.23676739434801766, 0.3262676232524457, 2.3889273981894217, 6.829457379156544, 12.941032763450378, 20.66025137901306, 33.520685318977606, 25.10472628378099, 30.929765662839337, 37.12642215913342, 38.264325280343336, 31.54570133455338, 10.15089592626018, 1.418647379163773, 0.1313937930089812, 0.03573171591626541, 0.04467853885744849, 0.020659872548534505, 0.09090372496434758, 0.03903784879272984, 0.041132505547495625, 0.05265742119762206, 0.11855124826392821, 0.036487212674992706, 0.03928443334335762, 0.049434194356323256, 0.03040125890214357, 0.03539073784204741, 0.04455316473820037, 0.059285874388390974, 0.02942158949501332, 0.03780696000302992, 0.03364264777290725, 0.01303024490499088, 0.06533928666143649, 0.07676090684629257, 0.03665869762640327, 0.04410042209670909, 0.14103378379537215, 0.030156867278199044, 0.044960440061385595, 0.04649486820844393, 0.03375151652782675, 0.03896798540447508, 0.04650593051807054, 0.027659292325317383, 0.05079420343522103, 0.05782510559525221, 0.07116480309876703, 0.04717684350907803, 0.07549028873683945, 0.04895382658428243, 0.030762965400372783, 0.05843239881458783, 0.035377645399421453, 0.045343464871327725, 0.032763255444625695, 0.06775048711607534, 0.05720757361080858, 0.0448723859153688, 0.029257311515750426, 0.05395343895220468, 0.08405026408933824, 0.05332423944867427, 0.020147949614892566, 0.034240391706266714, 0.01870610893914296, 0.009257762707890043, 0.046150182268672416, 0.035246724803601547, 0.04438120098183713, 0.030147057522328633, 0.0398066180247453, 0.04463998548265907, 0.06548302007778999, 0.009061777307051084, 0.04550654200776931, 0.0868210738765136, 0.035164971730761954, 0.04519204759309369, 0.030357023070175803, 0.04995306953787804, 0.02127721109577725, 0.022667097603721965, 0.13713278747614355, 0.06705289511310478, 0.030914394169925686, 0.04351986917637048, 0.021992126261935602, 0.0697738402372887, 0.047914586180160125, 4.393293367278192, 15.499701711439318, 35.91178571024249, 51.738584656869214, 48.013360654154134, 40.41752607591691, 24.553558749537316, 26.45756744569348, 22.873387952004713, 22.072351709488903, 13.850954982542223, 6.17786834316869, 2.4228603128463995, 0.4850874252377018, 0.07853512817452993, 0.07076364115721757, 0.9169297172657905, 0.9519845523661183, 2.840488548240354, 2.162213666785148, 4.551102576717254, 4.410327240344017, 0.7639346043429067, 2.2218008435541585, 6.057483448136238, 5.686365452504927, 1.854714186441514, 6.0534262464892485, 4.487879853094778, 4.77367845273787, 8.031514786904859, 15.486331332114437, 19.14070556240697, 15.895427676939196, 22.661274017826205, 25.01305853166888, 29.59145296004511, 35.65578045383577, 41.13047176791776, 45.59219921788862, 53.593261703368164, 56.84852300151702, 58.47289023860809, 58.214064798047474, 58.205757218022505, 56.77231134906892, 55.58511187953334, 58.372183384433875, 58.27585389537197, 56.171961215234575, 59.66854241586501, 59.456204906586684, 58.10346572629867, 58.452733178292554, 58.13791590352213, 57.1275721826861, 59.04146132930633, 57.01660833051128, 58.273037633588245, 57.929457618344216, 56.22953768699401, 54.588088527802505, 54.026216845358576, 51.039241744625954, 47.03431352492302, 37.34390581807783, 31.020735233060776, 24.00969074618432, 19.775580398498043, 13.901571208430877, 8.96808558894742, 6.68087407465904, 5.54999101546503, 4.36831473342834, 3.5000858383793987, 2.180257305022209, 3.3098658390583533, 1.9934484194363318, 4.914872992423273, 7.213324548736696, 2.7901174704874716, 4.501637566474177, 0.8404976153565992, 0.24263512222997605, 0.3042098681532568, 0.11985047209647395, 0.24350486185041167, 2.3042939266850873, 7.695544169795129, 12.519477990365798, 19.16675598390641, 28.818002746951198, 28.72774116454586, 34.857848767311346, 41.831611125699936, 43.885964270560976, 36.26062562388759, 13.438040210354714, 2.144893215548608, 0.07065413654932091, 0.008023755940338297, 0.04644686896954814, 0.041168044366302996, 0.13364411499952117, 0.020963438718970266, 0.02204330476571716, 0.038297807857874906, 0.014247634267855077, 0.06271491841142697, 0.018140734135804158, 0.036391076301374746, 0.055994772157000924, 0.10250358316566675, 0.07822865470042152, 0.07552306963911942, 0.023813952293787754, 0.030513887233551473, 0.01978302171694175, 0.04305264364267069, 0.061844841712304664, 0.03761724981990072, 0.044805069769462275, 0.03672700585617173, 0.08974545364899021, 0.02555772162703497, 0.053700047710369674, 0.034962042700499296, 0.08524107881971905, 0.055619584426524184, 0.026026222697128693, 0.0223760761230463, 0.0024140297131042088, 0.016001857828439003, 0.030340341505624598, 0.07495381268522433, 0.1825938238612106, 0.1512938001824002, 0.18502725618741206, 0.20031683898020178, 0.12827940810952457, 0.1327270464671235, 0.1377007344196881, 0.2339879047846602, 0.13143039669000334, 0.16759576816712657, 0.12321784221116575, 0.08957538979067918, 0.11851859759659537, 0.13643350241886032, 0.12186204278541189, 0.1392866436752581, 0.14844157823151158, 0.14180361022872312, 0.15720007760870844, 0.18599647998569474, 0.20474617549728966, 0.16700266289614862, 0.10274122363977856, 0.2523032131214296, 0.07314885590946482, 0.09685808206878363, 0.14921681324560798, 0.1353464696195818, 0.19266225698013462, 0.12939246491559092, 0.12047632762621488, 0.18980796659185042, 0.1488913024865812, 0.21181194231875483, 0.26972055915863286, 0.1962570479560283, 0.17117272461614302, 0.2540429834757121, 0.14412133263484125, 0.29748269687256507, 0.1555410682434036, 4.890802877564584, 17.806383871263076, 38.702485407552416, 59.01437736326649, 55.02541711253505, 49.01109787725633, 31.189485403799246, 34.19315215080015, 33.608613091130415, 28.795492264532275, 17.70322749691625, 8.584375804470433, 2.89658211892651, 0.9245092073275197, 0.5442593210647183, 0.9410742345836856, 2.1792345469997776, 2.6993724559583976, 3.2040606391045356, 5.567429382954875, 9.657935384781132, 8.729504481438669, 10.017769702019232, 3.6976607720698085, 8.741748159931554, 4.959560065500198, 2.4266591283582875, 7.78434859168145, 5.807273493659112, 7.464562164198968, 10.411103021713997, 16.744853219678326, 18.012512268558627, 15.181485702914578, 22.721190183393418, 26.3492472710148, 30.319260512628865, 37.24740766709851, 41.89395327721873, 45.269070440723056, 55.32766711327338, 56.28392919417351, 59.72267896898332, 58.1218106515946, 60.518653392791755, 56.94500938538582, 54.90025035796627, 59.69250809761786, 60.41802498602099, 56.81721856517177, 62.04440832138062, 60.72191061512117, 58.7618943952745, 59.77057503115747, 59.17410019905337, 57.19291494738672, 60.66707195774202, 57.0468262703188, 58.38351903423187, 56.487304087608095, 57.94803788585048, 53.02030932518744, 53.51721086809712, 50.503983343801195, 46.03931019383092, 35.28199426589474, 29.66949832054877, 22.57620957589919, 18.705357774611443, 13.026113875450628, 9.730498252376433, 6.802787223169881, 5.326995445835975, 3.8455684483051304, 4.6265287745383485, 2.1283797919750214, 6.728726990761296, 6.708313015199478, 15.775108971903402, 15.129043613710712, 4.9301315026898545, 4.41497475870194, 1.4745632174514955, 1.765746863618974, 0.7784873331266066, 0.52141310827386, 0.8013578768699401, 3.7229965867534762, 9.925676372743423, 18.592913227696574, 29.853124080165742, 45.43323732191517, 36.423286314933534, 44.67365857093565, 49.7857738310291, 53.051731432637865, 39.55763663015058, 15.670195375719379, 2.3630689276802928, 0.25694317785241916, 0.1010658506364111, 0.15668548102821075, 0.14982861106193837, 0.14936440774509985, 0.1614059309565252, 0.14719185900063286, 0.12554121834616508, 0.27309738279831025, 0.13912357419969576, 0.1259928041948907, 0.13079063666443672, 0.13509917643762406, 0.11640861525290436, 0.22528267916171785, 0.1372743298810336, 0.103556057738681, 0.2196974385409586, 0.10084698697732342, 0.20066366230528201, 0.13762734319654205, 0.26911675930023193, 0.1673069989849483, 0.11585006054731146, 0.26786248950708297, 0.12648243396993608, 0.2986669462294348, 0.20803031781988762, 0.14426209363004855, 0.1701603087806894, 0.1232478651969183, 0.12695880276301216, 0.1779636956991688, 0.1283929193572652, 0.13093619337005, 0.1493576508496077], [0.056259612582864306, 0.022558778516888138, 0.05327835844288911, 0.013753060352868371, 0.01489478225384148, 0.03755317422591391, 0.01576800948955239, 0.02861612465142483, 0.06920709605178527, 0.10321426761126327, 0.07016030095157123, 0.024780927624012676, 0.06317932474156542, 0.013946299328498784, 0.016122917915063522, 0.04545617555718749, 0.06638206256132934, 0.0728810545537741, 0.030587630857142712, 0.005277154052765259, 0.037907072372974894, 0.04562703997737939, 0.07400168030853234, 0.0496528358499129, 0.04554775370765598, 0.05448197450248465, 0.03880048411027078, 0.09568832709544128, 0.04927266854792834, 0.0346776363890498, 0.017173954157999927, 0.0323166300152098, 0.08348125994445817, 0.07233553866465246, 0.017455275050334392, 0.0704867769813826, 0.07684539102258221, 0.060049265683177984, 0.033756737417030724, 0.033874910309790604, 0.023542697796778336, 0.8740588241527159, 6.72503407924406, 19.97802176783162, 38.90431880950928, 45.408824489962676, 38.85487733348724, 36.793448232835345, 22.700640886060654, 25.946155094331314, 30.133185232839278, 21.58133372183769, 7.566160867291113, 3.908102795962365, 1.1513222850138143, 0.3265219950868238, 0.039443794953366446, 0.46960818971837726, 1.0538011308639281, 4.920137793787064, 0.6950820537824786, 3.908805390519481, 2.8150563903393286, 0.25272572593342874, 2.5839493591939253, 4.993434634900862, 6.666982510397512, 0.5814379357522534, 3.803305399994697, 1.2318567571140107, 1.1609291501583592, 2.0360414371375115, 5.148817858388347, 6.310584189430361, 6.432446837425233, 11.905786894982862, 16.12823603614684, 19.757270774533673, 24.048116245577415, 30.905650931019938, 36.5965138712237, 41.888948332878854, 51.06551378004013, 55.22127674471948, 55.832491843931145, 52.65738025788338, 56.30714178085328, 53.26355903379379, 60.383912132632354, 64.05456812151017, 61.5707625112226, 57.71538249907955, 54.508735056846376, 54.012629755081676, 54.859469475284705, 54.03659935920469, 54.78559947782948, 54.35127150627875, 57.80959390824842, 59.541920461962306, 58.58155165949176, 55.83974038400958, 53.37255385614211, 46.141636986886304, 39.264415925548924, 34.40851772985151, 25.925352804122436, 17.02608323866321, 11.880183623683068, 9.807978791575279, 6.383540274635439, 2.8085405980387046, 1.4725033602406903, 2.0183148980140686, 2.0147821908035586, 2.35323186843626, 0.711267285289303, 2.4505166997832637, 0.05652328472464316, 3.4531772328961283, 6.585848773679426, 2.894731250501448, 7.347011671912286, 0.5660496195477824, 0.13138389515299953, 0.26155366352008236, 0.20949362236405575, 1.2528040524451964, 3.871805182387752, 10.449656978730234, 18.408228428133075, 23.83218388403616, 27.91918573840972, 23.72431085955712, 29.25440565232308, 35.55632875811669, 37.95145350117838, 20.6585314196925, 6.260169475309311, 0.3755229092653721, 0.1517411342431461, 0.09724027567332792, 0.06523287704875393, 0.032750683941788254, 0.010887482616629814, 0.027988484136820323, 0.02381180533237996, 0.04334574122162115, 0.1264943389762794, 0.06971197863740307, 0.01356665105108292, 0.05739112827746619, 0.016898175911797632, 0.0022875107712142413, 0.063278115609841, 0.07576160643610262, 0.028735640113272017, 0.04880508295290413, 0.05720339077074201, 0.0536263155780973, 0.0015850013216784707, 0.01787358778528869, 0.07068880202789461, 0.027597151103339372, 0.022134394535133918, 0.047026690275919054, 0.11890825289752215, 0.02922591340217379, 0.010902332273432085, 0.08103321832154067, 0.047560971485631126, 0.0030771429714326177, 0.06459404398957569, 0.038295141871898405, 0.030743985572048736, 0.031413454487318956, 0.033868999941454786, 0.01826725930215851, 0.051549715515706813, 0.04615305892882809, 0.0750975767450948, 0.050390919430121306, 0.03222462285550372, 0.04733817013461263, 0.06396411287207758, 0.10641983995634703, 0.02127575935916074, 0.019352503286133853, 0.024970488419996637, 0.046287679729322274, 0.037780966639759085, 0.0630334769225409, 0.08530696238120718, 0.07376877425779259, 0.06422352173455781, 0.06601028775255527, 0.08859225383569157, 0.06635410801297234, 0.0197921937046152, 0.043752319404795285, 0.022104099588168245, 0.07999071055242131, 0.045148690847019037, 0.06765586759654746, 0.04028310556144964, 0.037320961484745625, 0.055655950620289774, 0.054666145869921294, 0.05317111762480871, 0.09278370473053187, 0.014703353160932181, 0.03046711756577415, 0.0819554885909442, 0.06076266974090569, 0.04685798239323401, 0.005115987348084849, 0.07823249280092218, 1.1371604449325994, 9.472369032521403, 23.91227476058468, 45.53916485078874, 49.449575716449374, 43.308693362820534, 35.62568410750359, 27.04877845702633, 26.638078843393636, 30.095330438306256, 21.517614818388417, 8.302149503461777, 3.6200944310234444, 1.0148597785061406, 0.11063554519487005, 0.04614251755898999, 0.23972571947641913, 0.20155460723946172, 0.4502118547116557, 1.3270239988642356, 1.9887171829900436, 3.229978435462521, 0.8091837408081178, 0.671257454781763, 2.4647171506958627, 7.481897569471791, 2.3768987146116074, 3.339204187354734, 2.316920526566044, 1.4609932875440967, 2.0362324075352762, 6.769882950090594, 8.385682259836505, 9.819477219735424, 12.67628356333702, 16.68167168094266, 22.30203393966921, 27.571461739078647, 32.6509311122279, 39.08420262798187, 45.17874610039496, 52.05857161552676, 56.92083581801384, 58.17123643813595, 55.63257648098854, 56.9702184584833, 55.346447421658425, 60.72759412950086, 64.15703219752159, 59.81271697628883, 60.51267962301932, 57.25333513752107, 56.25409956901305, 57.68944386513003, 57.38282434401974, 57.80212179307015, 57.92735915030203, 60.21594447474326, 59.35829470234533, 60.67244560487809, 57.50857945411437, 55.0945802657835, 49.909610902109456, 44.15979669940087, 35.55100217942269, 29.782903848155854, 21.203268228038667, 16.495202202950757, 11.171638831015557, 8.572055639759187, 5.957060475503245, 4.755435018770156, 3.3157631226124304, 1.1413614259612177, 1.5691493355458783, 0.3556651441800979, 0.17568921129549706, 0.6476509763348488, 1.8707450359098374, 6.636958727913519, 2.582027888105762, 3.127621489186441, 0.3311339976085771, 0.12237511485094026, 0.10092019433936766, 0.15928155382073697, 1.2082518108429448, 3.7674426792129396, 12.077035615521094, 20.604298768504975, 30.00937365716504, 36.19129380872173, 26.03033700296956, 33.53499020299604, 41.10260725021362, 44.3613673025562, 24.29708084752483, 8.136113122586282, 0.5257430985089272, 0.17008667240940756, 0.027060669306064808, 0.04578273585667053, 0.024975199860730962, 0.06372684395060906, 0.09493022180733182, 0.026473524199137767, 0.050923411824530175, 0.03545485174043044, 0.01742746222824339, 0.005684416927021718, 0.025808510085147236, 0.03322320697348445, 0.05097561688613027, 0.060096468190632524, 0.03411101860805385, 0.021456182641427846, 0.051688994130780624, 0.05441598368868713, 0.014380858873107262, 0.08086010543329102, 0.09754212197637367, 0.07317376142788319, 0.01248620565034329, 0.03950767136449295, 0.07360235697800115, 0.04888284470765822, 0.04964881005787081, 0.018004209606818134, 0.033147586434478724, 0.02678808564650676, 0.04414505437917767, 0.06158165220591811, 0.011709941205598656, 0.05843371265537797, 0.056892179042821935, 0.13652030018068131, 0.14265042849846427, 0.13648049425213568, 0.13556676586308788, 0.19909659881264935, 0.13930585716039906, 0.15948563964376528, 0.2667736947055786, 0.2050471101557055, 0.20400424998614097, 0.11886569671332838, 0.12049063814864044, 0.19564851367425537, 0.08386932944338168, 0.1165399150622468, 0.17320976772856328, 0.12822694640846985, 0.18877102062106135, 0.1323953763611855, 0.2144553287014846, 0.17955125970465524, 0.14513088330145807, 0.15179327418727262, 0.09035680713432451, 0.09732991562134798, 0.12760649945947433, 0.12232324303758722, 0.19062725166159292, 0.21631584983439217, 0.1057314333475886, 0.13310678092943085, 0.10896453123179176, 0.2382621084970813, 0.1667161919777432, 0.14705014805639946, 0.15647710511280646, 0.22697217882640902, 0.16756351586551438, 0.15840438314743582, 0.15995192671975783, 0.1347634154221704, 1.5037382970894537, 11.517873310273695, 28.39721283605022, 52.48867911677207, 58.76665223029352, 51.91307913872504, 47.314009897170536, 35.85316588801723, 37.236515245129986, 41.18009367296773, 28.379795551300052, 10.490863438575499, 4.796722377500227, 1.7845695826315113, 0.4536946436330196, 0.38585899818328123, 1.6197262151587395, 2.1958872147144812, 8.447784166182242, 3.902653398052339, 6.487709110782993, 6.8602416111576945, 0.9661049624123882, 7.083181287011794, 11.84481757302438, 12.169341733378749, 3.049454535207441, 6.817591719089016, 2.9694752010606953, 2.0536880579686936, 2.8063685855557843, 10.385413458270412, 12.006228008577901, 11.2687498523343, 15.66411276017466, 17.537162188560732, 23.630362249189808, 30.21778487390088, 35.35875112779679, 40.552890992933705, 46.68611687998618, 53.06340440627068, 57.90141267161216, 58.80304790312245, 56.388715313326934, 57.3127394337808, 56.091160389684866, 61.31213711154077, 65.73025564993581, 63.74266909014795, 63.32511709582422, 59.83762794925321, 58.79912553295013, 58.55513841875138, 56.86011752774639, 57.87942778679633, 57.565689163823286, 59.676649955011186, 59.72896652836954, 60.76793570672313, 58.43703585286295, 56.32557299829299, 49.85289735178794, 45.54582503534133, 36.39948537272792, 30.43369958477636, 20.36583827387902, 15.740115546411085, 12.543067124582107, 8.238307045352075, 5.62028234043429, 5.4207538212499315, 6.588601296947849, 5.273651701788749, 5.168746440641342, 3.9722583082414444, 5.114708927369887, 4.494773418672623, 7.954995228398231, 11.226973668221506, 7.50477675468691, 12.275130998703743, 1.4572502432330963, 0.29504711950017565, 0.4999567321952313, 0.5403028140144964, 1.950048619220334, 5.498120121417507, 13.802903006153723, 24.4681824791816, 33.910800333945986, 38.23652352056196, 35.69460407380135, 40.7510373669286, 47.88633469612368, 50.73629748436713, 29.557653896270264, 10.199350926183886, 0.8688524906193057, 0.37554396136153134, 0.22391415501554168, 0.14738626147229827, 0.1319949422031641, 0.14900305939297523, 0.20658532277710978, 0.10768181659401425, 0.0900091487734068, 0.28035300152917064, 0.115170203479788, 0.10166667807366579, 0.1579807518470672, 0.0875705070493202, 0.12272189221074506, 0.1502078245844572, 0.15557636957495444, 0.12917204609801694, 0.18788045873084377, 0.10730874709664814, 0.10075936184054422, 0.12773733195518294, 0.19343724684609523, 0.34048538775213305, 0.15002685929498366, 0.1076007491698669, 0.15854230961732327, 0.24474183337823038, 0.14524556666372285, 0.17292367985412, 0.1997074620017121, 0.15597419903403328, 0.1402577520498345, 0.18853266002430072, 0.15098620055904313, 0.1574379785527145, 0.2271530981506071], [0.05095577137845178, 0.0169520587059519, 0.08018904305513828, 0.04117415774793875, 0.025337128524458217, 0.07660696147790841, 0.059493143306744684, 0.07209111065153154, 0.02566741201125326, 0.06834995857770405, 0.0670134722285213, 0.074295099644411, 0.033220360956845746, 0.057782277449845314, 0.0024329465785769807, 0.03671358782617796, 0.06941527278432924, 0.04241622759089355, 0.04215522526553081, 0.0477365396856781, 0.040007176012882305, 0.04384775097752291, 0.07154834501805805, 0.10413509763536916, 0.052742250113477634, 0.019619913936983195, 0.08303562659890422, 0.07471861603159098, 0.05143094890480561, 0.02616187580110085, 0.0719994175878744, 0.06280150549906878, 0.03481451331848099, 0.03946497345403318, 0.13830985092828352, 0.030868367607434912, 0.04487075414809008, 0.0759864992071544, 0.03872274533815442, 0.1337542784430327, 0.0442457489759451, 0.025220267557268663, 3.0631482649234036, 17.24323937969823, 39.16101440306633, 43.96822029544462, 44.35941396221038, 40.265338113231046, 27.956248214167935, 28.728480531323342, 32.358979294376994, 22.101977371400405, 12.463187075430348, 6.1333994519326, 2.530200875574543, 0.5913387335115864, 0.19435627656357904, 0.3130497873550461, 0.30491022573363397, 0.1791513771299393, 1.4824471814978508, 1.9673658835311092, 3.2539605421404687, 0.17762687748237965, 0.3396921496718161, 1.8141937736541995, 6.557107606241781, 1.7506951358049148, 2.6048494635089754, 1.5385728665897924, 0.16640214189406366, 0.32066292399840973, 1.1189119854281027, 2.1871520963407334, 2.771448704504198, 3.7518426775932316, 5.792688650469627, 7.625290107342505, 11.299767955656975, 19.838601120056648, 25.744755114278487, 34.648264761893984, 39.1707379587235, 46.55422718294206, 49.82870025019492, 51.20260846230292, 54.60984983751851, 52.34938398484261, 52.683601302485314, 56.2397397718122, 55.96446391074888, 53.58628380683161, 55.34520010794363, 50.56430939705142, 55.41377490566623, 55.687069969792525, 57.21455858599756, 56.447954870039425, 56.31947763504521, 55.44181200765795, 52.70832007931125, 48.36486777951641, 40.79648194774505, 32.52438956691373, 25.573512277295514, 19.67813107275194, 15.091703630262806, 8.704326787302572, 6.842916992402847, 3.400625562475574, 2.385900309008937, 2.117086797952652, 1.7429016314206587, 1.2026240676641464, 0.081926959476644, 0.13697891105567256, 0.16194421497564163, 0.5201752940493246, 0.05547168349186259, 0.8881971912999308, 5.824047509701022, 1.6660617868746481, 1.9744927075601395, 0.33398648002936, 0.3234782664766235, 0.6180052122762126, 0.9156137007859446, 2.5356517443733835, 6.746098677958212, 12.679795065233785, 22.55069651911336, 16.78850135495586, 14.029743479144189, 29.583874940872196, 32.95234564811953, 38.87993343414799, 35.006004533460064, 14.360860163165679, 2.015936103078627, 0.05587756070458601, 0.0248855771496892, 0.013726150556918115, 0.03330096489779892, 0.05485987418421334, 0.06188457103205785, 0.056460044166493806, 0.08157327200376219, 0.09399362569374424, 0.021362539884003422, 0.03830880505002795, 0.02277734914734479, 0.028375262777591427, 0.0754011161024532, 0.05139426095411182, 0.026669332442144235, 0.047564307798541365, 0.04829728157229481, 0.04595913143167573, 0.0357141227070843, 0.041804582992148016, 0.057240316208692334, 0.046424162123472466, 0.06583031071650405, 0.03409486947461002, 0.03425781637610447, 0.0976101199405328, 0.026772522570325002, 0.027050549284585064, 0.016451897137167475, 0.013795416396591934, 0.01903917907076257, 0.06585580612262411, 0.05592889242595243, 0.09110985624213373, 0.04249855906011597, 0.014895139442336176, 0.0644791461226921, 0.015053284887765205, 0.054667003888396494, 0.08336910467234351, 0.052430536597967155, 0.047956989146769054, 0.10434080756479695, 0.034673020709306, 0.04554679609775063, 0.04079636148807984, 0.03456816242467012, 0.027918157265371377, 0.029827158357347214, 0.06550081630027102, 0.05895884294483451, 0.03594876394697255, 0.03370153695164669, 0.06300189877830206, 0.030940490955066298, 0.05782021029341606, 0.05889676684033006, 0.0444027970004226, 0.02788216645468868, 0.03345002262522617, 0.043742233857272134, 0.05982087572075187, 0.018982168722657428, 0.03470818414503048, 0.03253431772933372, 0.04616550785759765, 0.03671195988933887, 0.041191283643486044, 0.02454075905975075, 0.022932284684371085, 0.0645773126293094, 0.06665154931045349, 0.02968464302079332, 0.021449843263854424, 0.058227412838248484, 0.08040726320036957, 0.0619160074500307, 0.1916882834367214, 4.608773675657088, 20.70789052594093, 45.233290580011186, 50.64856583072294, 49.65468037512995, 46.945593433995406, 31.304752096053097, 33.35821290169993, 37.07617659722605, 27.411799700029437, 14.386510502907539, 7.368718558742154, 2.5024846724925505, 0.422102035654168, 0.10364805723750785, 0.0058450674799631445, 0.14735750253162078, 0.7492676978149723, 0.3419610569553991, 1.4384303434241204, 2.884385508875693, 0.4716747885029163, 0.4487736012426115, 0.6748420721100223, 0.8666210910004954, 1.8683002961258737, 0.8160718518399424, 0.5500731929655999, 0.3247073779423391, 0.5958146481744705, 1.5677611842270822, 2.6892015049534463, 3.052285751027446, 4.889307473936389, 6.833615091539199, 9.367702545658235, 13.639584337511371, 22.502598454875333, 27.82088721952131, 36.02922539557181, 43.86969820145638, 49.20951489479312, 51.554095975814334, 53.52924862215596, 57.58555989111624, 56.510853998122684, 55.67100394156672, 56.46324034660094, 58.42581787417012, 53.73297260653589, 56.18762323933264, 54.444000259522475, 58.87596084225563, 59.22150988732616, 59.0869882798964, 58.6150251665423, 59.171864448055146, 56.889182290723255, 55.58419012254285, 49.84577432755501, 45.277895773610766, 36.23267873640984, 29.89201830279443, 22.83171865247911, 19.260508475765107, 12.085446157763082, 7.924595878970239, 5.785749487338528, 3.003223519171438, 2.043430937394019, 2.1447625515922426, 0.24223226723411392, 0.4097033622524431, 0.3483886878576971, 0.15848344342122156, 0.30477441366641755, 0.03444676813218863, 0.8361939785461273, 1.6105900344348725, 2.1407484960171486, 1.571661245919043, 0.6281417812551222, 0.1733468974670095, 0.2537938057174606, 0.6516164925790603, 3.124163184435137, 10.157514925925963, 13.093237396209473, 22.260386213179558, 21.21707889341539, 17.671020915431363, 33.57190755105788, 37.09995008284046, 44.40266986047068, 39.98352366109049, 17.270909740078835, 2.7006050607850476, 0.1744892264926626, 0.06231561040265426, 0.035498664308820045, 0.07951923706118139, 0.04615021291218939, 0.02694082251119037, 0.03828447792799242, 0.10260495191980755, 0.006481826834891353, 0.02137521289349083, 0.028011922596863685, 0.025566276913929372, 0.05322871211495611, 0.019314116535467968, 0.0390597474160454, 0.020617889015064127, 0.0400940312312976, 0.0700371982830186, 0.024073707811053724, 0.05744409559655094, 0.04533360531974224, 0.022189233023973725, 0.029369466787865086, 0.043825270127384894, 0.04636234265842265, 0.027183302745763815, 0.09866904497386948, 0.06400883325465745, 0.03680770555811544, 0.03785117093714015, 0.07506504865182985, 0.0626927133529417, 0.055133654856153076, 0.005856593751588897, 0.0664474711483044, 0.06724807133357372, 0.04425928574956713, 0.13112739359419193, 0.16088607901286694, 0.1320333844952045, 0.1565032440327829, 0.10404355778929689, 0.3299302896184306, 0.1008080926934077, 0.13690919705456303, 0.1493789480939027, 0.1460026147504968, 0.20294304967166918, 0.197577094058356, 0.16701154951607028, 0.14010318615023168, 0.1378065618055482, 0.14308959606193727, 0.14310061240628844, 0.22972375214580568, 0.09876166500391499, 0.13871005525992763, 0.13994555589893173, 0.1951248619344927, 0.2994651485595011, 0.2612409157858741, 0.18161081048029085, 0.1778905496241585, 0.14973052116411348, 0.13516899769104299, 0.24183485146251418, 0.11823030338893015, 0.18917562229739082, 0.16242666650683651, 0.15266163484944453, 0.174861958911342, 0.2788288849255731, 0.19521041863387634, 0.13501044813423388, 0.20259466352722338, 0.11531412841812258, 0.29344066376647643, 0.16592065563365338, 0.4844961279342252, 5.219540644076563, 23.783828904551847, 51.1810903395376, 59.22470269664642, 59.155833721160896, 53.433311370111284, 39.5193660643793, 42.27375245863392, 42.60882877534436, 30.074118260414373, 18.519009890094882, 9.129764706857744, 3.5859749586351457, 0.8495388011778555, 0.41547853139138996, 0.5686408966299027, 1.2314903832251027, 1.7154520269363158, 3.400513774925663, 4.773045970547584, 8.3871139249494, 1.269818558808296, 0.9826834728160213, 4.166800024047975, 17.57548374514426, 6.868164308609502, 6.043635520242876, 4.709414339834645, 1.3760047189651, 1.305552699392842, 2.2593702856571447, 4.398638086934244, 4.532153116118524, 5.974461090180182, 7.999341545566437, 10.833549153420234, 14.887711944118625, 22.73407320822439, 28.719378671338482, 36.62282120796942, 43.41845304735246, 51.37942498730075, 53.308403491973884, 54.0178818087424, 57.719242111329116, 58.74597741711525, 55.53868278380364, 57.122327973765714, 60.16878974053168, 57.22301521608907, 59.9155419103561, 54.17463148793867, 58.83118698673864, 60.90823104304653, 58.9492581736657, 58.73889361658404, 59.88860307201263, 60.039900656669374, 55.702382902945246, 52.64194180888515, 44.20066387422624, 37.21971965605213, 30.005062972345662, 23.66709524585355, 20.116283355220673, 16.787252080055975, 11.321581236777767, 7.832497646731715, 4.514792215439582, 4.585821436297509, 5.273664449491809, 2.10927392686567, 1.739381304191005, 0.9016270190477372, 1.0744313270814958, 0.9219985226950339, 2.4622524313388334, 3.361643086518011, 12.337438829483526, 6.551998228796068, 3.3651288478605212, 1.548091723553596, 0.7402404241504208, 0.8411839688497206, 1.2668783746419416, 3.6118466671436065, 11.430329930397773, 17.064495009760705, 30.488610806003695, 25.307204915631203, 23.499566893423758, 43.60484800031109, 45.64213883492255, 51.963179572936035, 46.69539720781388, 21.846007416325232, 3.685021914782063, 0.3851921952539875, 0.3035517679827829, 0.12811728858298835, 0.13522487614424, 0.15718421958867582, 0.08117291445453322, 0.15037198190487203, 0.20622003673305436, 0.2578875957237136, 0.1561298527784886, 0.1687802320286151, 0.09047426373487519, 0.14067382972326972, 0.26070799438222764, 0.21128223848439034, 0.15520863204954133, 0.13751894175525636, 0.2496305621799923, 0.1131020648585212, 0.15884321363222215, 0.13724085183874254, 0.11891132491009852, 0.1966489938598487, 0.17990614227469892, 0.12772606280181678, 0.13523236848413944, 0.2359375066214031, 0.10368381822181326, 0.16085906675265682, 0.1512741270445047, 0.15390392302745773, 0.11044703393934235, 0.30180665033478893, 0.08621288433430657, 0.18615035640616573, 0.19268160836110193, 0.1209239068350965], [0.03916223848899526, 0.02314190357743252, 0.027466381809884505, 0.040271679360059, 0.04379384137029129, 0.056768915495805206, 0.04917881894676436, 0.10542247774860553, 0.05974746917584731, 0.045991180719988006, 0.011847385040093816, 0.017180860440637317, 0.04381891542805299, 0.06340533600098665, 0.049756119823864395, 0.10384401486765954, 0.07236491047566937, 0.021575359109368537, 0.04428661210582622, 0.027732562889615377, 0.018413382912835768, 0.02637482334619328, 0.034625664984266606, 0.11042129338508654, 0.0436957476420268, 0.027706718913489775, 0.041137783893293915, 0.02631142574001945, 0.008324900315323425, 0.04877473437978376, 0.049683663227985946, 0.05406154544963952, 0.013090509211554403, 0.08446364513327999, 0.03191959345713258, 0.031213566826115695, 0.02941025522417359, 0.03668100993719794, 0.055906063005808866, 0.054344810290081855, 0.04463269232561992, 0.10597991396582897, 1.0256222719627044, 9.014532335342901, 29.39691516660875, 41.30591938572545, 47.93128113592825, 37.575160918697236, 26.75921928498053, 22.73218458698642, 32.847049620843705, 29.27886555271764, 18.440521301761752, 11.583363163855768, 3.1715628216343545, 1.2975698180737034, 0.2497783252188275, 0.12723316949221397, 0.07373283707326458, 0.30029025589746816, 0.34733672656359216, 1.0554330820037474, 1.4185136508557106, 0.5196792980836284, 0.1896606325622528, 0.1550804808615677, 0.2531951233263939, 0.6602523259578214, 0.07557522490500443, 0.5364321088117938, 0.18610158724890602, 0.05262942451442923, 0.06459743775908025, 0.5756919698849802, 0.5131939960823906, 0.614151728730048, 0.9381624876010803, 2.5670115841973216, 4.39873565589228, 8.231803755606375, 14.223056512494242, 22.32159676090364, 30.5177265597928, 36.6976051176748, 44.25706755730414, 48.148458849999216, 52.71560784309141, 51.57047187128375, 49.10951014487974, 41.15235467110911, 48.61310674298195, 49.29730930636006, 53.0661775219825, 48.1951468221603, 52.45369549720518, 56.829283775821814, 56.48345624246905, 54.51318302462178, 54.50768778401037, 51.720753562065866, 43.40298714176301, 36.678460028863725, 29.67982984358265, 18.588529979029012, 10.125389733622152, 6.322086049664406, 3.694459382564791, 0.9686198758502161, 1.1185306575029128, 0.846355920357089, 1.763739835831427, 0.8665540429853624, 1.7141115569299268, 0.15626260049400792, 0.10482955633872941, 0.24808962228557757, 0.08634878833207392, 0.08364299642703227, 0.11883966504566132, 0.03396920807239029, 1.80815871684782, 0.9407110476205427, 0.8398561852593577, 0.2088205528355414, 0.25421342271710595, 0.251820960773095, 1.7685659446062583, 3.645508202814287, 6.280779079083474, 13.87904993949398, 21.794781261874785, 21.13531904835855, 23.316119601649625, 28.251043750393777, 43.33487126135057, 41.275552395851385, 28.51597043775743, 9.526924298655603, 0.21884617696125663, 0.009993634209217084, 0.07002487192831694, 0.05112847057922233, 0.01971790807381753, 0.059171206347884676, 0.04218891781244067, 0.0430703096302046, 0.07531762017958588, 0.06487854606201572, 0.03150926335834928, 0.020964562952999147, 0.08191219696234311, 0.06951798219233751, 0.055449478433377324, 0.061211118459581375, 0.06479478966925414, 0.06677324237722544, 0.03715747832170418, 0.04061303664779952, 0.06766778026377002, 0.027230779129651286, 0.04555258389201857, 0.0525442470285681, 0.05176538458815025, 0.05421391650733929, 0.05295289747957742, 0.013514528343934688, 0.004733609882438736, 0.03537564207949946, 0.02087806205024883, 0.04890681942924858, 0.014977189374246426, 0.052170223751736265, 0.03092544690345324, 0.015118303727508794, 0.07326995908853508, 0.04993558358100634, 0.03171069468671997, 0.008896705469176655, 0.108218438202335, 0.024696500904317346, 0.057388378021818016, 0.03165634840937152, 0.06738815817140764, 0.08454331827740516, 0.058387946562781456, 0.09075249154721537, 0.01544939543706395, 0.05108640852173971, 0.021637105796065544, 0.0711620221996019, 0.05895793896108385, 0.06464921764188236, 0.027430578690743255, 0.018623482526069688, 0.14161208824765298, 0.08337263633767444, 0.023973377106050332, 0.047417165290924816, 0.01461722572604495, 0.07754147383234195, 0.009699131816535467, 0.001193134540376524, 0.036489836526133364, 0.017121657165848923, 0.034686327656550754, 0.03470621529906508, 0.054803995731016325, 0.0809195232126982, 0.021495481036723624, 0.05481769338310246, 0.0434818941979639, 0.019555654481894547, 0.03210695558077386, 0.05417609857695718, 0.009266972999959704, 0.09952232136481232, 0.09405070690498238, 0.09164004271189052, 1.6390570036826597, 12.148085428822426, 36.27701328646752, 47.27764168093282, 53.85897874832154, 42.62267081968246, 32.03353239643958, 27.45499284036698, 37.17428684234619, 32.614862957308375, 21.856234996549546, 11.331363627987525, 3.7472110938641334, 0.9065691441778214, 0.19412594456826487, 0.07817875939391314, 0.1140746747654292, 0.25963807598717753, 0.24804302881802284, 0.3947710522240208, 0.25503517458996466, 0.29740510748759397, 0.1167746214196086, 0.1303589307973462, 0.3682613456922193, 0.0914908470886369, 0.23110287894885387, 0.07408164456606874, 0.2319037319431382, 0.1971010470222081, 0.6140924028811917, 1.094130328105342, 0.7951179375090908, 0.9347582993007476, 1.051044685225333, 3.0000123237409904, 5.444102219996914, 9.506240660144437, 16.437419806757283, 24.86466742330982, 31.780104137236076, 39.40483285534767, 45.200703528619584, 50.69990573390838, 54.71951146279612, 57.30587136360907, 50.58811033925703, 42.306912176070675, 51.35145064323179, 51.905810986795736, 54.86766330657467, 53.49979162216187, 56.02137750194919, 58.567364446578495, 59.501649487403135, 56.361454840629335, 56.74917328742243, 53.34009232059602, 47.810754545273326, 40.705765370399725, 31.71495749104408, 23.012043737596084, 14.787038430090874, 7.9429025611569815, 4.555144088883554, 1.7547627562476744, 1.8256021098744486, 1.0323746935013802, 0.7265658159890483, 1.032652814061411, 0.6826756582144768, 0.13318565734211477, 0.1562802818033003, 0.16613704482874564, 0.03698117850768951, 0.18051866021367813, 0.06025857239541027, 0.28059303219760623, 0.781630928958616, 0.4418328752921474, 0.346442518094855, 0.10722434719003017, 0.08731336197665623, 0.23364436031589586, 1.8674718180010397, 4.358902025607325, 7.28525052147527, 17.36390913686445, 27.63550423806714, 21.486206439233598, 25.237767196470692, 34.599270436071585, 46.75555852151687, 46.26214396569037, 33.832231337024325, 10.721337006938073, 0.7479319469101968, 0.08734860968205237, 0.04994186550198544, 0.023748650959122087, 0.07295655251871194, 0.03769931698878927, 0.045613131651114074, 0.08192305242823017, 0.045493028216785004, 0.03150759520189416, 0.024705291763248465, 0.04625908166710888, 0.03562369751894186, 0.03301499193654426, 0.05308874785119007, 0.029740690013333678, 0.056721084796252756, 0.046884569474646164, 0.03995327789696955, 0.07495604966196322, 0.08532524123908052, 0.05197247730628137, 0.034579718861007885, 0.04289499040873301, 0.004967217861239108, 0.07637189505922218, 0.08647749876423229, 0.025624377022106803, 0.019271663773143967, 0.05517612677067519, 0.03549017222417939, 0.015021144626511922, 0.03011484352511264, 0.012531157774520258, 0.058759778828149846, 0.040683532058591806, 0.028536223596142187, 0.029734837101592176, 0.1367194983627527, 0.1000298316320104, 0.1572736986582318, 0.2171426732093096, 0.14313709351324266, 0.14352631214405262, 0.13116556009457958, 0.1551300927155441, 0.2120244857524672, 0.16102555298036145, 0.10421134636647279, 0.2012494897409793, 0.16775519106416933, 0.1430735848243198, 0.12677576903614307, 0.2593301699286507, 0.21017522611204656, 0.1803427970697803, 0.2480264506753414, 0.30330652791646223, 0.07984786579805998, 0.14808559249485695, 0.09256377620922943, 0.24541810515426823, 0.1115476341557599, 0.08074614219367504, 0.1708555795372494, 0.16989004828276175, 0.16771726971191747, 0.1037386624563125, 0.17859061609112448, 0.27203665745835154, 0.10727973534695565, 0.2972000410720226, 0.08584949052742413, 0.15936991440192347, 0.2576467683238368, 0.20071943350616964, 0.15192502598849036, 0.202106359084287, 0.21289983313650857, 0.17459277093650835, 1.7321691686107268, 13.675092574088806, 39.122037810664025, 53.46743599061043, 60.85536533786405, 49.74692275447231, 42.34869718551636, 35.91938334126627, 45.599655643586196, 40.1540800832933, 25.166417321851178, 14.67922326057188, 5.211184524720715, 1.8016045588639475, 0.5483925799208303, 0.24984155811609762, 0.2507045408410411, 1.0993790722662404, 1.1826170380077055, 2.2923456516958054, 5.770388995447467, 2.308799259124264, 0.6807358623031647, 0.646691405244412, 1.9658112766281253, 2.19777706169313, 0.6654672396759833, 1.4507809065042006, 0.981993748536033, 0.3761988746062402, 1.0212813113485615, 1.6844211759105807, 1.2722466285190275, 1.0108132408030572, 1.3962307884808511, 3.356707273952423, 4.447601033795265, 8.952735393278061, 16.43122736484774, 25.180559427507465, 32.69289655070151, 39.12483838296706, 45.73999804835166, 51.2577687540362, 54.69412196067072, 59.02097478989632, 53.35766846133817, 45.80553693156089, 54.40100716006372, 55.63755396873721, 59.72531087936894, 56.41339094408097, 57.629231560614805, 61.15064920917634, 59.75008064700712, 56.97788669217018, 57.51243122162358, 55.44633057809646, 47.63020000150127, 41.031879071266424, 31.623780035203506, 23.155167102813724, 14.24208785257032, 7.735677861398267, 4.859729370763225, 2.898876215181043, 3.272362832100161, 2.3012072665076104, 2.9031827324821107, 2.698670106549417, 3.1319444314126046, 0.8118024744814443, 0.41588078883867113, 0.5407947037489184, 0.25656212571888204, 0.5840126653352092, 0.2415472620557393, 1.5106432620556125, 4.0198486706902905, 2.1405143795474886, 2.761794770917585, 0.9931026975954733, 0.7664371377998783, 0.32687816468458025, 2.573032177263691, 5.845587695798566, 9.369416621423538, 19.02244217934147, 31.67371572986726, 31.20366281078708, 33.670884639986106, 39.63888460589994, 55.22260250583772, 53.57899212068128, 37.70476779630108, 13.79037985878606, 1.2052742415858855, 0.1507677582483138, 0.1995684170434552, 0.14682058214900956, 0.13304468184228868, 0.1244774976024224, 0.11884713440292305, 0.22509774553679654, 0.22424325106605408, 0.24146844693008931, 0.09499877135479644, 0.08814161793599207, 0.14568476487071286, 0.2041061243583118, 0.3311385634926058, 0.14198229257618228, 0.19891454567832334, 0.16210192183573402, 0.1282130648952819, 0.13981817079888237, 0.19526758411478615, 0.18610578541073108, 0.15220037331023525, 0.21663933812129885, 0.12664667556002257, 0.15336412215425124, 0.23727387039651796, 0.14498442261209413, 0.14245673082768917, 0.17415248488466586, 0.1436047901910159, 0.14105964692369585, 0.13055880313679097, 0.1684291032894004, 0.14990966316432724, 0.16795608996143266, 0.13252962560903642, 0.11498914625976356], [0.03584390949277628, 0.05867551681735824, 0.01714268627937042, 0.04791150650670452, 0.00516136417225484, 0.026621181900883396, 0.09911534481591756, 0.08934832132992246, 0.026392837903732737, 0.0499570531950843, 0.00932533166281158, 0.06950214715494264, 0.08771497591008103, 0.048151809136353196, 0.020971310272392248, 0.06192166117891189, 0.06238611730476541, 0.08113958962982701, 0.02000627889027519, 0.02037054795261112, 0.049688976047740835, 0.0805092448248498, 0.03962298674929527, 0.022351291263476018, 0.02142021481338288, 0.08993505274937039, 0.046271354395655856, 0.031314106290078456, 0.01724813636692782, 0.02820442134003726, 0.062129834081016244, 0.11567612028410358, 0.06833911843357549, 0.09447087548793325, 0.07271328129835668, 0.03768921611950763, 0.06542192456582863, 0.14290385038381623, 0.03908738786835344, 0.07717784253820296, 0.021915023342796394, 0.0435116030876675, 0.5259726184510416, 4.683668882616105, 17.851049861600323, 36.99701924477854, 46.95911384397938, 44.47417859108218, 27.826207914660056, 22.47990950461357, 25.17714696545755, 34.054512054689475, 33.30409988280266, 18.869099078639863, 7.0599456564072645, 2.5495075170070898, 0.4493122223404146, 0.22723396639189414, 0.16739968030202776, 0.07621005898521793, 0.07456364410538828, 0.11388517525647918, 0.2667983014497065, 0.15948303494482272, 0.04782265945968609, 0.08535367076195056, 0.03541429121527941, 0.155677477859201, 0.10488495215653412, 0.006050454694852834, 0.06898457815329875, 0.026954470367561427, 0.1470834115940717, 0.2446827220339929, 0.01083952072452033, 0.09093157992127443, 0.27017285746912806, 0.6542938779438696, 1.732286104271489, 2.875226039078928, 6.970988262084223, 13.359009354345261, 20.182302728776012, 28.228890203660537, 34.39865689123831, 39.21804958774198, 43.180063155389604, 43.92112831915579, 41.85214081118184, 33.65784275916315, 36.891668304320305, 38.83870932363695, 44.284426089256044, 44.6158585240764, 46.02998671993133, 51.5387987321423, 50.94939985582906, 51.653010306819795, 47.48009089500674, 43.70952429309968, 35.98900541182488, 28.832291941488947, 18.155927850354104, 9.313891549264232, 4.8114101829067355, 1.112168573083416, 0.6814494885263905, 0.35586555278108967, 0.0229619073891832, 0.3573895468106193, 0.15823901540810065, 0.442326235915384, 0.29039046937419527, 0.102233950859837, 0.17228062565047897, 0.2300633589226392, 0.06444939126771304, 0.140178415984396, 0.03193931830596299, 0.10388364459598258, 0.26683985405871946, 0.22815579999118085, 0.3014980088318548, 0.22033183595105527, 0.46236099795468394, 0.6476784942130889, 2.5101176048478773, 8.4178594235451, 20.022995664227395, 21.323704604179632, 17.352271464563188, 25.774333707747925, 22.414472603028823, 26.482223464596657, 43.52009342562768, 39.236104257645145, 14.484141238274114, 2.977430258066424, 0.06571568098039397, 0.08928717985268562, 0.038728713163084565, 0.047131854995724656, 0.007335581551981911, 0.013536453780327595, 0.03871739804444294, 0.022713938134632284, 0.061489641215772405, 0.03355915568047955, 0.040516046086145986, 0.09614264021717733, 0.06099815750795026, 0.04046372228091763, 0.06870614349721901, 0.09073105640709402, 0.09537431531615796, 0.06314018530951393, 0.055541454949566436, 0.05291005018197241, 0.047764716399533134, 0.028201109924984556, 0.04760288415596851, 0.04132998769261664, 0.060642317328001225, 0.04714959759205099, 0.023848230897959684, 0.05380578699611849, 0.034608048792447776, 0.04506596867295523, 0.060056976358135866, 0.05126589526151938, 0.09271112556058554, 0.07016381729514369, 0.06468105625601546, 0.040854316039551655, 0.0122334981419807, 0.022375003599952308, 0.04982320614339364, 0.07834650200581358, 0.017608149810844374, 0.05093970651467962, 0.007296977902672464, 0.02724861748696816, 0.046087087267228675, 0.14853735454380512, 0.0012759874281924098, 0.04665333732602097, 0.021660620864901333, 0.0818024855107069, 0.07346917259236498, 0.03243676026261622, 0.0489236465505054, 0.026255449610612085, 0.0546465493408182, 0.06487626312000137, 0.03899710440647699, 0.03346017712066251, 0.012687108378046224, 0.042193008721956325, 0.07501199706307343, 0.08119733733755928, 0.02317220235483781, 0.08825414093031038, 0.05799374836046369, 0.030629162398737766, 0.04465434580079971, 0.0159730069572106, 0.046269297449579166, 0.032837964339001526, 0.055048565470403245, 0.045438478926136616, 0.043105201104715954, 0.013560244640816125, 0.033085088981615926, 0.12103692012568637, 0.10652830268466666, 0.03784564361276646, 0.02479454483686676, 0.055136814968840736, 0.5879743204962823, 6.646458218174597, 21.881834345479167, 44.450012868450536, 55.28198326787641, 48.448877103867076, 31.95080568713527, 30.030819216082175, 31.326146664157992, 35.81168682344499, 30.202022829363425, 21.219606860991448, 7.381811920673617, 2.6381609276417763, 0.460277330731192, 0.22578630536313982, 0.16434717232421522, 0.1565623553770204, 0.07305714752404921, 0.17663225020852782, 0.08715102028462195, 0.017699028906081955, 0.13350986575167026, 0.03991299699391088, 0.06000207083660269, 0.13165570314853423, 0.0771107868621907, 0.00943133907933389, 0.07221458104228781, 0.0862489900581779, 0.3295006675104941, 0.1754080723490446, 0.12335799799691285, 0.6072921774560406, 0.3604236533564906, 1.5279595457738446, 2.5490755659918634, 4.698514073125778, 8.420729617918692, 15.327217444296807, 22.595117361314838, 29.229047529159057, 35.67810658485659, 41.43693831659133, 48.46912830106674, 49.783585148472945, 46.641947069475734, 33.94753333060972, 39.50260577663299, 43.14922548109486, 48.58682686282743, 49.95949952833114, 50.838283031217514, 55.45000191657774, 54.89180941735545, 54.61137956188571, 50.58129325989754, 46.432963186694735, 39.03128593198715, 30.13321661180066, 21.373257867751583, 12.582263369714061, 6.846015664838976, 3.2772023014483915, 1.6560831545822083, 0.4239976436140076, 0.048596576802552714, 0.6626488328460725, 0.4175773365122657, 0.2274045741726314, 0.3010146379951508, 0.1802919135098496, 0.17157207092931195, 0.19373232859276956, 0.08413248830625127, 0.09366854394395506, 0.0769689150394932, 0.18118304230513113, 0.08905002967484536, 0.06139050560793089, 0.09684734917696446, 0.056520929004275994, 0.15170293709924146, 0.5856747084086942, 2.2773791128589265, 8.870056733008354, 16.299958382883382, 19.797922218999556, 21.78869962692261, 27.71573631994186, 25.28605941803225, 30.609753208775675, 49.55024334692186, 43.63825090469853, 18.04695263985665, 4.303521590848123, 0.22184864407585514, 0.09597714224289502, 0.029552797373804836, 0.03414839220743987, 0.0214197532454085, 0.017168752420994065, 0.0436821457509312, 0.051285338573037624, 0.059453406326112256, 0.05422917314835134, 0.04262433920596396, 0.031045232411293738, 0.06533562476115842, 0.019751928123315016, 0.045755769561735854, 0.03491798498397393, 0.04109449992557207, 0.03070935839787126, 0.021618690957585653, 0.029906925347243107, 0.01947243626589977, 0.027023111845576958, 0.06273113649278399, 0.04698542494987769, 0.08642737363134662, 0.02566678381915535, 0.08019629024690197, 0.07882123137073171, 0.055051924765951214, 0.0309116228468596, 0.0447696726769209, 0.01570031317251344, 0.02865258277574134, 0.053121069100715464, 0.06226456596425945, 0.086255019170142, 0.021428810319893306, 0.016243498239125458, 0.15180939267719948, 0.16884063040056538, 0.12559522754482685, 0.1274430239573121, 0.10545425507570468, 0.09353492288820206, 0.19694839634241598, 0.43672518323986764, 0.0884908544380338, 0.15602833080676295, 0.09744591665484252, 0.16289868392050266, 0.2534271407151415, 0.10789878801592898, 0.1370153002320759, 0.10146449214868969, 0.14193035181491606, 0.15749739633212168, 0.1136518325356226, 0.09400795153792828, 0.31006657969086404, 0.12847562620957054, 0.18057139770638558, 0.12370813082182601, 0.10542284547080917, 0.2126744807127022, 0.17473864939904984, 0.13844086728509397, 0.17781839946344977, 0.12008746905672936, 0.16589407238268083, 0.14500696091882645, 0.16896830661402595, 0.19551244113714467, 0.32228123877317677, 0.10351514864352443, 0.1823187982963939, 0.2913714602829949, 0.19141158780022977, 0.1415658471805434, 0.17263302609564798, 0.14652579151574643, 0.7599918868753218, 7.17906411617033, 25.39331074683897, 48.838643027890114, 62.29650297472554, 55.31717869543261, 42.219427631747344, 37.34976583911527, 39.36382055282593, 46.50155367389802, 40.79866278556086, 25.309179829012965, 9.26100819341598, 3.62622068293633, 0.8080343637735614, 0.6268667658009838, 0.5477927637196357, 0.44199464241823844, 0.33468928909109485, 0.6247752231936301, 0.5990682542324066, 0.6136093384796574, 0.2729803245634802, 0.22238196384522224, 0.19971296251300844, 0.5089595523332396, 0.25847340783765244, 0.16686401630361236, 0.5112997364372976, 0.44162857496450025, 0.7578788938060884, 0.9578764426612085, 0.2912764960239011, 0.6898429929729432, 1.3720553824978492, 1.6031409631813727, 2.9793588384505245, 4.4688190952424085, 7.794787979895069, 14.708842058335582, 22.030296056501328, 30.499705230036092, 37.616326193655695, 41.52734502669304, 49.2672247271384, 53.61044168472291, 48.80533033801664, 38.392508337574625, 43.79927596738262, 47.499353654922984, 53.154595590406856, 52.65491700941517, 51.46357551697762, 55.30929473138625, 54.76768601325251, 53.42685907117782, 51.15090770106162, 44.53799947615593, 39.42222072232155, 30.17839251026031, 19.499869154345607, 11.413521593616856, 6.6447897399625475, 2.3637112157960094, 2.2365759216970016, 1.2840154550729261, 0.3730801306664944, 0.9144694718622393, 0.6821575989165615, 1.0641256671759391, 1.067432715527473, 0.2550377946106657, 1.1339021810600836, 0.6892566599192158, 0.4884269250737083, 0.23337157172781808, 0.26124600260969133, 0.5874474971525131, 0.3930359243625595, 1.3884603280213572, 1.8482377404166808, 0.789116956293583, 0.6296233953006807, 0.648471548432304, 3.153318407074098, 10.755203731598394, 24.384514401035926, 28.141260531640825, 28.18296709368306, 36.20402974467124, 35.03550075715588, 40.11252649368779, 56.760034330429576, 49.355834991701194, 22.26910956444279, 6.070784205390561, 0.40351104291696704, 0.18395241950788807, 0.14419012733044165, 0.10723781501573902, 0.0682961485619026, 0.10813049896950684, 0.13381047865315793, 0.2241349568770778, 0.11733286202915254, 0.17221723953562398, 0.15242661439603375, 0.23827214424888934, 0.13872442706938715, 0.12886176516692485, 0.1215417184416325, 0.19175367670193796, 0.28538469765936175, 0.23221171461045745, 0.14462967793787682, 0.2330126135700172, 0.15315127228536915, 0.17303817935528296, 0.13302042749860596, 0.11335571657025045, 0.19620090903293705, 0.10114457383151017, 0.1840302387192365, 0.20895942925445496, 0.13124265918327918, 0.24612229317426684, 0.10358376713890223, 0.21995879709720614, 0.13530594356838735, 0.09380382741050375, 0.1652546647575594, 0.1826763315306556, 0.19523859534773136, 0.05594056377547884], [0.05145221933602326, 0.04534826441217334, 0.029726505895415624, 0.08246632367973367, 0.09882810780958784, 0.061186699406994935, 0.03136670588695955, 0.030649829535715045, 0.031003741089314706, 0.029972067718664487, 0.06582720039953148, 0.07124984651924142, 0.05828750860546866, 0.014631167568656948, 0.02718932994250809, 0.030315286600061005, 0.04583197998844328, 0.05116659877521377, 0.010311002411218661, 0.05967141579716437, 0.03917574078866071, 0.16489178422958622, 0.00930171987537535, 0.02232134105607627, 0.045430450324690154, 0.05712147681943833, 0.016103443960028312, 0.039984886684725364, 0.05285224501764583, 0.0763858761638403, 0.07507300830536312, 0.01486624164822241, 0.022492998377269795, 0.010330008095010154, 0.05069671491641672, 0.01528971590056655, 0.02888811650806137, 0.009752273420622994, 0.018167625737166213, 0.0608647394654972, 0.09711354940889344, 0.007259233708253071, 0.1259373241074143, 2.6461404994610818, 12.135805468405447, 28.953042107243693, 43.497704536684104, 48.35110026021158, 26.695590596045218, 20.116918779188588, 20.652987149453935, 32.28015534339413, 34.26953246516566, 16.72309583233249, 12.418071973708368, 5.308186700267177, 1.8883639550016773, 0.4638492922869421, 0.1691455487161875, 0.0680914958338103, 0.025610376765290578, 0.08627931947910017, 0.09863471657398248, 0.09841992850265197, 0.07351647086081005, 0.10531318764532767, 0.030831170208271474, 0.06816798971304971, 0.13736508065654388, 0.04541447739146891, 0.14757782941864384, 0.08450155882465263, 0.283496719935248, 0.2946782328428761, 0.3256201257388438, 0.2210976787272, 0.14085359991558138, 0.1705929186315306, 1.010599471628666, 2.168916997409636, 3.5591447209158256, 7.146834000464409, 13.394554853439333, 20.082525476332634, 24.671296534999726, 29.923163883147705, 33.26127544526131, 34.87418543907904, 32.49814302690568, 24.10694395342181, 26.936494727288526, 30.718963761483472, 40.14376032736994, 37.9931757527013, 41.73115922558693, 47.74742787884128, 44.289576161292295, 43.41648401752595, 35.49250395067277, 30.665082162426366, 22.039368498709894, 18.25219262030817, 11.11736499494122, 4.378272160407036, 1.0232002083812992, 1.1346463282262127, 0.17949455387649998, 0.05902745760977269, 0.24383473931060684, 0.22254403740648301, 0.09599620251045113, 0.17273231109063472, 0.12627211985208336, 0.10763329258489032, 0.12404662677116933, 0.11741189165942131, 0.09497543631662285, 0.038723312243218386, 0.06055268887130003, 0.04437615629285575, 0.07379439989885977, 0.05406172164986211, 0.18744918187299084, 0.27409593244233443, 0.17067576337966228, 2.4336095683036314, 4.365546520679228, 10.763777052202533, 16.884354276041833, 42.78066389022335, 44.06237679143106, 23.696120785128688, 40.95663624425089, 40.803926606332105, 37.55510976237636, 29.3538220467106, 9.469481187482035, 0.7491000777771397, 0.05496693497163154, 0.09842933606236212, 0.052665204650932745, 0.08277490389563384, 0.020407906230238658, 0.02449629723184532, 0.05188607024930177, 0.061842723479194034, 0.043069623981512366, 0.02611890784464777, 0.11187169700860979, 0.04080344780137943, 0.050728787187366724, 0.0524439316453232, 0.02693850317999961, 0.02699990129669107, 0.011195962283489926, 0.043646867402018084, 0.029702582884760156, 0.0577040100770612, 0.031687576068384994, 0.025742209005740382, 0.07608822036174036, 0.015132189071136377, 0.03296303968395918, 0.07396426457431048, 0.02670337738949926, 0.0051023447585682715, 0.04989651309686804, 0.01619179879555539, 0.03950090680812155, 0.10811093308392072, 0.019549052719207063, 0.043839117166616266, 0.07337987738391084, 0.06872881969977772, 0.01425346419695885, 0.02117901011520336, 0.02761698511969899, 0.12863563133343575, 0.0993354342156841, 0.027536499922374086, 0.05747920540612071, 0.029985740472893083, 0.05053287552249047, 0.030965476912716706, 0.0472229773238782, 0.042852277176514755, 0.03659828393269451, 0.024172288005150134, 0.07637469894102505, 0.03427481586714426, 0.02601116332375715, 0.035374983243884585, 0.04233572707181016, 0.11481724379043426, 0.011469951714389028, 0.04315607317332779, 0.01494676131950391, 0.11000214369907496, 0.05142242617664799, 0.027730502113099062, 0.06272393143585613, 0.026371508100700956, 0.04832987095259371, 0.02744481835003582, 0.05458529295039274, 0.03320307418283436, 0.02038542346488084, 0.04975556824055891, 0.03252959479728053, 0.039478648123481584, 0.05920585650469988, 0.016204046626244823, 0.011568915910057483, 0.06092055663166027, 0.03502204653716857, 0.07041905480887621, 0.07729229607409047, 0.021185336086238106, 0.0314791810007826, 3.3587155274806486, 15.230090733497375, 33.615049700583185, 50.40806570360738, 54.09498383921962, 33.32738307214553, 25.93582945485269, 25.9226659805544, 40.83013196145335, 41.73284192239085, 22.38499010762861, 13.872551552710997, 6.178767056234422, 2.1289686377971404, 0.5071197155742876, 0.07113844201329254, 0.14779902964590058, 0.09296138350281025, 0.03301065587889283, 0.04809596898755239, 0.0234494648963934, 0.061185481327195326, 0.04383747390801868, 0.0980957813801304, 0.07113546959214634, 0.24597373340399037, 0.07587384597788896, 0.3379186254835898, 0.142011342630271, 0.26311124284421245, 0.8341396371683767, 0.6703911625569867, 0.30974267771647823, 0.3733735729850108, 1.268659008126105, 2.086209164511773, 2.6836263460497705, 4.85238375202302, 9.177635273625775, 12.993702350124238, 21.118615634979744, 25.518630473844468, 31.533290955328177, 33.61532426649524, 38.58192351556594, 36.709591880921394, 26.76505969416711, 29.912793136412102, 34.23865164479902, 44.16897504560409, 44.46902851904593, 47.30063069251276, 50.82469986331079, 47.72649418923163, 45.7372013984188, 38.47352881585398, 32.6921473779986, 24.963364062770722, 21.27177438428325, 12.03940341549535, 6.945972856014007, 3.7768634769224354, 1.2949497973726642, 0.10607120100288622, 0.18579205708397975, 0.5739793650084927, 1.326982936551494, 0.4105019016611961, 0.47087039618242177, 0.10567571577285567, 0.2593414467428961, 0.2645458190912201, 0.33399533600576464, 0.06427597194429367, 0.24087359497864402, 0.06464208536330732, 0.02626656937683302, 0.005800639168404404, 0.041449853639689185, 0.06063426574391704, 0.23334987611780245, 0.24484015310243254, 2.536764471761642, 4.431695332450252, 10.955787858655377, 18.624568716172252, 43.783347222112845, 42.860617483815844, 28.754344640239594, 43.773843319185325, 43.790482013456284, 42.769677331370694, 34.13669747691001, 11.710281256706486, 1.0908471816970458, 0.05963059480211908, 0.11675683285800681, 0.041603235933449, 0.11613161318124303, 0.045922577546368686, 0.07370122062462954, 0.04782432953136102, 0.07953826668522052, 0.027507495833560828, 0.036770385584884116, 0.08479818806893404, 0.1372718937214344, 0.07764498763267072, 0.09489050014845787, 0.04382966364163064, 0.023783582653249466, 0.018288705933598742, 0.015770797091986866, 0.05808414673552879, 0.04442085752323751, 0.01912581403889964, 0.017980571963914463, 0.04402231177194946, 0.10738982218167475, 0.10383569515280186, 0.030801007411472743, 0.032170414473981626, 0.02556829172517023, 0.04499870232276378, 0.032707430617583376, 0.048929032148613084, 0.018846128744283513, 0.021246322430670265, 0.006259457365940175, 0.07332682579515443, 0.03187129544394632, 0.05653222497071951, 0.03901585057798413, 0.20124536818794667, 0.15133798813387273, 0.12641640485174235, 0.17249251024857645, 0.14221912099709436, 0.11477559158999114, 0.12213754332474164, 0.08448398476766963, 0.13228649994538677, 0.16597602846882037, 0.12344800566713657, 0.2205987103403576, 0.17744033507281737, 0.1508659094331726, 0.0958367336481329, 0.08817590037060362, 0.1867871746541031, 0.19855186433321048, 0.05771200037411144, 0.1118820621782253, 0.12482697159172067, 0.23309389549878337, 0.07376724208194403, 0.13862547915308707, 0.2211116828144558, 0.1370097537555041, 0.186348635282728, 0.12263256635877395, 0.14457648079241478, 0.17591879252464543, 0.10545960236941615, 0.1772664331140057, 0.13886123505090514, 0.18561885992605842, 0.1819894877412627, 0.11780513991271296, 0.13256465114893454, 0.10629224801255811, 0.12823786316139082, 0.1562536985523278, 0.17959975307026219, 0.11469872232766883, 0.23821602064755656, 3.6899403218300115, 17.07912152813327, 39.30678144578011, 54.79643698661558, 62.487522402117335, 41.04501508897351, 37.31684538625902, 35.44867930873748, 46.8573675617095, 43.46339948715703, 25.79681085002038, 17.445161034983975, 7.181281235910232, 2.9278159526086625, 1.051863357424736, 0.5674473316438737, 0.2535044236649429, 0.17203860315344027, 0.29535658837806794, 0.3275504221598948, 0.22118397087099093, 0.18839936072547592, 0.3542892196245732, 0.5251202383829702, 0.314232810971237, 0.34128438681364065, 0.19690011748142783, 0.7147713101679279, 0.4267675111130361, 0.9998074378217421, 1.7333104557568029, 1.144350639754726, 0.8398907511465011, 0.6380364503110609, 2.120829719689585, 1.723476460864467, 2.8989742744353513, 5.095636402407001, 8.233312887530174, 14.407016654168407, 21.538866219982026, 26.194076345812892, 32.60003051450176, 35.743567020662375, 41.61666131788685, 39.70994618631179, 31.10969654975399, 33.43302034562634, 38.62917238666166, 47.81137820213072, 47.208792317298155, 49.07569146925404, 51.40823871858659, 46.616757608229115, 46.75109486426077, 38.145481386492335, 33.51288372470487, 24.767822142570253, 21.91535492097178, 13.428535326834648, 9.252477038291193, 3.6871718639327637, 3.1335018575191502, 0.6214222095666394, 0.3067256702530769, 1.1094045278526123, 0.7043843223683296, 0.5008666914316916, 0.5860856992583121, 1.0508546954201115, 0.5662659627775992, 0.3882116235552296, 0.318290441627464, 0.2996429116014512, 0.5257223834914546, 0.35496463338213585, 0.1793324037064468, 0.31933799025512516, 0.14390869727057798, 0.3457129572428042, 0.6591056455527583, 0.22386817441832638, 2.9088924777123237, 6.8360371551206045, 14.253570591249774, 24.597236302591142, 52.77615747144146, 54.03470877678164, 35.22202122596003, 53.45254275106615, 54.188865769294004, 51.68119645887806, 38.34420434890255, 14.10759174054669, 2.0625413377438826, 0.17974874184977624, 0.17230313331369432, 0.1606718195422042, 0.24912451514072959, 0.09324382479873397, 0.1360666382336809, 0.20025997993446168, 0.15552395383917517, 0.13728004489694873, 0.17035354679870993, 0.1454223797566468, 0.19129829871798718, 0.13996597980299305, 0.1619804509344601, 0.07347235951812998, 0.18219674516829754, 0.12212727774655628, 0.16077922506918832, 0.16920233115313515, 0.14822730343909035, 0.14897947920666588, 0.173408659475465, 0.15083143547657998, 0.2682570860751214, 0.255920649656365, 0.09802326349721802, 0.09661842678343097, 0.10066288838823957, 0.2080475701199424, 0.18300187293319933, 0.2847683952460366, 0.1724533937991627, 0.08051171928884522, 0.11920976212188122, 0.18271457463983568, 0.14762829929109544, 0.2687920912379219, 0.15315482693333782], [0.04947180927340542, 0.10656240125817638, 0.006449474941848988, 0.0362686860945917, 0.04679127528722729, 0.08314405102282764, 0.03470332714759054, 0.03940552886154863, 0.013308225653975481, 0.08756850755983785, 0.02503960678774503, 0.013833819426626209, 0.025770021827831387, 0.05781719956787364, 0.03812566790128908, 0.035764987114816904, 0.0599450164384419, 0.017430997724013946, 0.04944581591013459, 0.03384880203333113, 0.06832054080141169, 0.02309110045673386, 0.03245104780240405, 0.05139333398772344, 0.07419934631475518, 0.01060601712519964, 0.07272825065639711, 0.062391966386067296, 0.04446848903992965, 0.017230794051541917, 0.058059704700304623, 0.07860123390151609, 0.16118983287484417, 0.05491141657975893, 0.02908907477713881, 0.05225576512936143, 0.07057796442700971, 0.053741427949599685, 0.039601934653136044, 0.012403802360377967, 0.012180936849495817, 0.018180702858033682, 0.06826882986652275, 0.4329420878521858, 6.539839371558159, 16.885638852273267, 31.909632567436468, 44.33216133425313, 29.664460036062426, 26.042294348439864, 20.25441550439404, 19.999967428945727, 28.551991524234897, 23.778504287042928, 17.513751522187267, 12.329592127953807, 4.693874889804471, 2.171310378659156, 0.6539411097764969, 0.18691049948815378, 0.08342271550528466, 0.04248932387018877, 0.07346319710655559, 0.0422057832380937, 0.09871975999445685, 0.08195999318793898, 0.053561255561127785, 0.03632138528290295, 0.07297735180585616, 0.16226635494780156, 0.1606824681643517, 0.10083387921293897, 0.24506576599613314, 0.5556767890530249, 0.4548341534551113, 0.5152887562590261, 0.10927203126371869, 0.5624938071254761, 1.1598878834516773, 0.678991633317163, 1.204480574496331, 4.6748548265426395, 7.8655622466917965, 11.803961184716995, 14.341906289900503, 18.010335353112993, 21.26865609999626, 22.641544495859456, 23.156275172387403, 17.93633983981225, 20.3919396861907, 23.716542605430853, 31.88997168694773, 33.5053135502723, 34.52805980559319, 35.52072932643276, 35.309525382134225, 32.340408832796165, 26.491735212264526, 21.115995491704634, 14.191720697187609, 9.617804634955622, 4.840142525011494, 1.613036245107651, 1.270418926592796, 1.0147041707269608, 0.18906357427758558, 0.36972635095157935, 0.35422508274355247, 1.3329771761932683, 0.3125163143680942, 0.27459186712099665, 0.07223178737706716, 0.25107456130846856, 0.3995654449587868, 0.4964884989444287, 0.02495953719311905, 0.09779722159427982, 0.01850502043511839, 0.1495986008235524, 0.11488757066188321, 0.09796727013083235, 0.09304148565617301, 0.4720154831246023, 1.7945066623149382, 4.360566581449201, 8.477872667774077, 15.3128586276885, 28.331773973280384, 21.91926552403358, 34.85000010459654, 31.611783466031476, 30.332971157566195, 42.67728197959162, 29.526871135157926, 16.204546728441795, 4.335945863877574, 0.09938434126877016, 0.009587328944865976, 0.00642020798911671, 0.018953689404072303, 0.05554913498100735, 0.08238007750121817, 0.06634577297635617, 0.05967319695158832, 0.043995889399441025, 0.018472212719761075, 0.047295158128103906, 0.013999193869230729, 0.05585617536017972, 0.05756477742726284, 0.06114901171155995, 0.06683750949319332, 0.013769410584392327, 0.06975798221725611, 0.046619131500201846, 0.04400302167801608, 0.06526010381358285, 0.03271239869777234, 0.13175106577334866, 0.03659978163458648, 0.0362944764445626, 0.008371294600017851, 0.02058017642177161, 0.0562191822926604, 0.07401089634626143, 0.12191416740777994, 0.037834654081492655, 0.12371334788059035, 0.02292440547006986, 0.010661051924070044, 0.05965252789939123, 0.07519323048332045, 0.05835023971514837, 0.053873191242136305, 0.06483511653758826, 0.037066218097724264, 0.03830625780767972, 0.06889969561128848, 0.023933433281678348, 0.04418386439342172, 0.10391176768368292, 0.03809642249477967, 0.030106401236187068, 0.05050361479422258, 0.04079318605363369, 0.017413816287092144, 0.05754474039760329, 0.007124022062447283, 0.002708513911197623, 0.02352746796884364, 0.06802073995312376, 0.06008681548278659, 0.03182130054600778, 0.03969340555129513, 0.08176724546619, 0.05869826196783012, 0.03501668009125898, 0.02389290340004429, 0.015390063842548238, 0.04212806744861507, 0.01891217318423573, 0.017817575266704928, 0.06810739981911837, 0.10561566214047133, 0.036436087797365846, 0.1097809587935767, 0.05236340048272283, 0.016562081648096923, 0.016073417143836137, 0.01777559939411379, 0.05352834059346107, 0.06179470125766051, 0.061028536724587606, 0.04802438573190763, 0.034883560823096384, 0.05885089349542415, 0.022033655888310844, 0.07555940518936805, 0.9160953555856982, 8.947237210889018, 22.261425641275224, 38.10947795068064, 51.966337080924745, 35.15868671478764, 31.973063176678075, 25.259818761579453, 27.11483117072813, 34.69626672806279, 27.417638148030928, 20.9557843208313, 12.857250936569708, 4.89419327628228, 1.9809969778983825, 0.47291113183863703, 0.23763708800317782, 0.16678722365008247, 0.08694004733115436, 0.03768655779441038, 0.0779974723475114, 0.09354505057056105, 0.09187441199056565, 0.054346212230983286, 0.07981679327185116, 0.016727412998255704, 0.10988175298177427, 0.045009634397443266, 0.07399203526156564, 0.3098019422783006, 0.482459529152801, 0.6570654614798485, 0.7158872857689859, 1.226285643154575, 2.013326256025222, 2.570508622354077, 1.5868029430989297, 1.8966608710827368, 6.990797702343234, 9.481551301094795, 12.221345497715859, 16.248980318346334, 18.45283362173265, 25.755435728257705, 25.496223934235115, 25.530395623176332, 19.70601324112185, 23.02374612900519, 27.417571467738, 35.88328184620027, 37.885659663907944, 39.45340748756163, 39.942346619021514, 37.47076703656105, 34.61876461582799, 28.116233848756362, 22.698332571214248, 16.591782723703695, 12.655892141403692, 5.9975074664238965, 4.502728475678352, 3.1449671906809655, 1.0557518971543158, 0.4552376979301053, 0.25145667064334115, 0.2532919108747475, 3.13665789461905, 0.5578999149222528, 0.1822144724428654, 0.38223497329219697, 0.19397954516593488, 0.33510711344499744, 0.37986485047205804, 0.06852503265103987, 0.06537385254858002, 0.06409380772721864, 0.13755428905208267, 0.037535500577500755, 0.08660384198470462, 0.030969023899806124, 0.5931988562787733, 2.151674012983999, 4.9044090893960774, 11.467264929125387, 15.857796457505996, 28.32199158207063, 33.22986902729158, 44.63174804564446, 35.082184806946785, 35.817503698410526, 47.70852581147225, 34.91822581137381, 19.57748697650048, 5.429497764956567, 0.3460238663659942, 0.06868260927618512, 0.039566074077400475, 0.034278393497750644, 0.013884657978891365, 0.03830928385498063, 0.026147523143839453, 0.028398850624780023, 0.049952567750287634, 0.03146571125985394, 0.006365152601633342, 0.09393417727082007, 0.041686720364997466, 0.05389877474836765, 0.03996860348589478, 0.019273718804000847, 0.06882717006749685, 0.031906495268847195, 0.025452468807118076, 0.04674774234093005, 0.12577577148594205, 0.07151282918188842, 0.04131371981554455, 0.015661611368188697, 0.04211625054238304, 0.0354504237522281, 0.022941184710831414, 0.061979025842682015, 0.03860497464155478, 0.0743793616552026, 0.01938478623126303, 0.07943922683836953, 0.008575053878068443, 0.11424894444644453, 0.06957330906222906, 0.027339297399345427, 0.011686096718955425, 0.06602796906184766, 0.02725080275277217, 0.2936960774804315, 0.15432547056867232, 0.134752138607925, 0.1103126161521481, 0.15930245269931134, 0.15820195207432394, 0.1958587588441949, 0.16941340369803293, 0.11460448585210309, 0.12963508496121054, 0.07039964980175419, 0.149632538518598, 0.07123291597611482, 0.13581413565383804, 0.13415221515442097, 0.11986132756236101, 0.28537556589130436, 0.1880985946064034, 0.13023764375717412, 0.19859084288679785, 0.24963117505033172, 0.11408333921985281, 0.11671141916585547, 0.10291230639502888, 0.18213498315984206, 0.08073981430742048, 0.092809644467648, 0.17571357289148917, 0.26273365342809313, 0.12055374081096343, 0.23666915123260793, 0.1585167222806523, 0.19386245628758786, 0.1626874275145031, 0.09067609725940613, 0.1982874567470243, 0.1747614634974349, 0.1463534676980588, 0.09088612792472686, 0.13913005530353517, 0.1380966180154393, 0.07588135363954691, 0.19818015847234957, 1.0451037653030888, 9.610240344078312, 24.062552528996623, 45.77537782730595, 58.32766840534826, 42.29340353319722, 46.17407891058153, 34.7328467522898, 33.380248777328, 42.30196998965356, 35.02745989830264, 24.69889629271723, 17.57517387790065, 6.220517744941096, 3.774418369416268, 0.7167808507238665, 0.4527772686654522, 0.27914325676618085, 0.22278656552155174, 0.25346049618336464, 0.23518621951581972, 0.26340275462115964, 0.270147362063008, 0.2305987318076434, 0.252912804604538, 0.20124074101688402, 0.6510602514589987, 0.33933821705079853, 0.3170007785722133, 1.2306902197099503, 0.9219031600702194, 1.1659041864256705, 1.8221804547694422, 1.3148617095524266, 2.074646507540057, 3.0475345350080922, 1.230865132904822, 1.7604184463139505, 5.595361561544481, 9.323375840340892, 13.322685264771986, 16.25489917493636, 19.22920600060494, 26.391024435720137, 28.43009210401966, 29.908390275893677, 23.5850392618487, 26.62128717668595, 30.987483339924967, 41.75497585727323, 41.5141031049913, 40.72108222592262, 40.51788776151596, 38.96659035836497, 34.417547025988185, 29.983827260232744, 22.72453792633549, 17.3867549819331, 12.583736219713765, 7.21781321110264, 3.6182903858923146, 4.762000576142342, 4.616637047260038, 0.6569887914003865, 0.6987894903267584, 1.771473891792759, 4.472908166147048, 2.900290474776299, 0.44093171074505777, 0.6046029636936804, 0.7983894393809381, 1.6369856245094732, 2.0266851133877233, 0.13443667892246478, 0.2516222528872952, 0.3198788176861502, 0.4202125257542057, 0.37325820014361416, 0.520214272602912, 0.37060471672204237, 0.65618654412608, 2.3652024519058967, 6.500463677990822, 11.505836536807399, 21.69301732893913, 38.579919184407885, 30.73546713398349, 46.09982059847924, 45.5558466911316, 43.10343180933307, 54.701421491561405, 40.8447467127154, 24.398799673203502, 6.494659550728337, 0.730608921618231, 0.18256331824006575, 0.14517189964892405, 0.24761679281871168, 0.295041419806019, 0.1979448315837691, 0.1374950398120188, 0.10400230395457438, 0.16769952711559113, 0.1449680589740315, 0.07712119799708167, 0.19517289564734508, 0.20960847426566387, 0.10777702600124384, 0.10199039618694976, 0.14879230860500567, 0.17459629494096005, 0.1225374871864915, 0.0856038444345036, 0.16182153365544735, 0.2673548796484547, 0.12408378969637618, 0.26713066103477634, 0.10741376242930852, 0.20695031770775396, 0.12992880307137966, 0.09792668279260398, 0.13531266982036252, 0.2245341193291449, 0.1674896037025798, 0.12674167812351259, 0.18674582122795044, 0.1350186452750237, 0.25653555778966797, 0.16483412845240486, 0.1647512683825147, 0.11814738203200603, 0.20104384109858545, 0.22409331233751392], [0.022707951157504035, 0.05002514308979435, 0.012890392681583764, 0.01669266516523015, 0.10119518926066738, 0.05595126985422066, 0.045691268788951064, 0.09204196308048503, 0.01954409996077659, 0.015744680197038237, 0.061497328908092556, 0.017302266224437667, 0.03306661860176152, 0.036588236689567566, 0.017107302593367717, 0.016533462518465616, 0.059613047558213436, 0.06526566561191313, 0.026200948200458964, 0.049311233414036613, 0.055173253940959135, 0.0687588120420133, 0.03668418154120445, 0.03974274161361879, 0.009715417888195766, 0.02893316247800906, 0.08208092782766589, 0.032145711968863205, 0.006387158477258298, 0.057833724084400365, 0.03415712560977667, 0.03014486076520576, 0.06991151389816115, 0.007746972203735383, 0.03986358049235517, 0.09126391652370654, 0.02719612514239646, 0.030310774342186993, 0.045314568034823866, 0.059011155258744, 0.006098852778274206, 0.0884140924280209, 0.0461658028014485, 0.10376807257172563, 1.265484217193819, 10.895312755338608, 29.644859952311364, 38.39380271973149, 38.47330131838399, 23.920211676628362, 18.586123604928297, 21.478042025719922, 31.02845837993007, 24.465948689368464, 25.710977623539588, 21.932615310915057, 14.728603939856253, 5.237346733770063, 0.9489472282509651, 0.5245264283111019, 0.05025231880286048, 0.19719616449888677, 0.06381195248855699, 0.0945362457705121, 0.03312916201989978, 0.08673619899538257, 0.12359893264909907, 0.11328756538850647, 0.08921063234729153, 0.15453360133594082, 0.24952508719457736, 0.13086160704974206, 0.3151316159675199, 0.7565347465776628, 0.47767028452888616, 0.2269372911823373, 0.7647696401803725, 1.7727946273742186, 1.7297475953255932, 0.9383604447207144, 0.3016982029282278, 2.9513692951971486, 2.018708360771979, 4.601365789290398, 8.496100902557373, 11.337869859510853, 13.441117309754896, 16.346466906609074, 15.324330579849983, 12.29113328841425, 14.36749779408978, 18.107949418406335, 21.948126323761482, 24.077216309885827, 26.4975618931555, 26.576470175097068, 25.20355824501284, 23.05132627487183, 17.926235814248365, 12.879763380173715, 6.848100894881833, 4.82406472967517, 1.229484090881963, 1.7358289851296334, 2.6741474482320973, 0.4007656595879986, 0.27169893525781175, 0.7860469049023044, 0.9239158262648891, 2.7095134988907845, 0.43016694966823826, 0.6681953094178631, 0.09457990512131684, 0.14658240541335077, 0.2805812038000553, 0.19349968301192408, 0.03601316895876681, 0.07962546281276212, 0.06708050492189585, 0.08101687000523652, 0.028512072674329245, 0.12415367989770829, 0.34850363168985615, 1.65044266370035, 3.700161037906524, 8.109006112621676, 10.696329935904473, 21.507116594622214, 22.844538919387325, 16.44763954224125, 18.949858719302764, 31.972390490193522, 42.38386907885152, 37.342058381726666, 23.015487578607377, 11.95504500019935, 1.2163128944173938, 0.022110073158757824, 0.012727367256077067, 0.03183634268240102, 0.04199889736370214, 0.005859978902604312, 0.029674756656130476, 0.011660058348019038, 0.0323669390091973, 0.03325986428066127, 0.02383089815867284, 0.060807972350308014, 0.04675113994087424, 0.08377568285551765, 0.04923596910591568, 0.044697392281265035, 0.008966040256763659, 0.04662907915189863, 0.01924192232470359, 0.040906735605770544, 0.06291502440768866, 0.048792258641051675, 0.016482624923810363, 0.007679910782063681, 0.07889937233900832, 0.0220614246603462, 0.03462736569945851, 0.021868596499365185, 0.08004630555308635, 0.10542400992445408, 0.029502833119383263, 0.06890918744067032, 0.014943345524971525, 0.004122409614689288, 0.013341046775871468, 0.07749560814831527, 0.05217506542741772, 0.076558674956041, 0.009680838594513555, 0.07806577674684026, 0.031059510374982512, 0.046289537492538654, 0.05395335468253302, 0.10631958969057569, 0.049568236760434606, 0.0391986659697948, 0.058774981843007196, 0.11350292036490095, 0.0474534587063376, 0.06977875086088335, 0.03631204284066635, 0.051015514745226795, 0.03849820879798743, 0.025805281024546396, 0.0200703889582186, 0.07833042948116219, 0.11556689146785967, 0.10493825655430557, 0.01725114517725043, 0.06173044180257186, 0.02652564499106619, 0.10434623146730085, 0.07392265067826356, 0.08506166868873181, 0.09915343470751278, 0.08686066530044041, 0.0439679118684463, 0.03166374307306063, 0.028909536326424252, 0.024666232770429026, 0.033012536624746944, 0.0349423197668887, 0.02037235017445299, 0.06565321417104814, 0.031741675282377875, 0.013259438302127585, 0.03322838955829221, 0.02348904291378154, 0.04711673242009936, 0.05919480951683176, 0.016288639970063683, 0.0271882401824358, 0.060999176404889555, 0.0844049781200386, 2.265624014600631, 13.54929529851483, 35.10897067285354, 43.75440013024115, 43.742699700017134, 31.40894985968067, 25.98301164565548, 25.59078247316422, 36.12239345427483, 28.608381479017197, 28.85562808282914, 24.514591963060443, 13.841859006112623, 6.514335630401489, 0.9010420343087566, 0.4192386747848603, 0.031803490916988066, 0.02455854953657235, 0.018476975871430292, 0.051622355972687085, 0.03739412288151441, 0.10256006682832396, 0.061679811051656167, 0.18726925846309433, 0.22458293445168004, 0.21519559946271682, 0.29602363645549745, 0.4506912725346704, 0.39217091916549596, 1.3485032656500417, 0.4346462351179892, 0.8284468684465656, 2.244703562990312, 1.8346424376772297, 2.5346444306835054, 3.0930048563788017, 2.245813103452806, 3.2770721277882977, 3.529637710702035, 6.914415426792638, 9.08579787900371, 12.892745444851538, 16.40818932364064, 19.730379004632276, 19.896995405997, 13.653121417568578, 16.599184236218854, 20.500063742360762, 25.411763537314634, 27.75388333105272, 28.30918504345802, 29.049448082523963, 27.393629320206184, 24.58153505479136, 19.161239170259048, 14.248946116816613, 8.625045880194634, 6.86206159091765, 3.295263345203092, 4.453363485874669, 2.971804108350508, 0.3374114139906822, 0.2038087443478646, 1.3687425731651246, 1.5903028004592465, 1.487473453725538, 0.860563419278591, 0.4637565343610702, 0.8086974894808185, 0.44784525589596846, 0.7533195062029747, 0.3542072175731582, 0.0677108573877523, 0.21646485393566472, 0.06841897543880247, 0.07624820250296786, 0.13973177140278203, 0.06605174077013809, 0.38150139813942296, 1.5351894545939662, 4.602125258215012, 9.721733716226394, 13.30390299520185, 24.042536674007295, 32.46769758962816, 17.344554201249156, 24.618475937074233, 39.60485019991475, 45.73910374795237, 41.697791622531035, 27.155413973716, 13.950626330990946, 2.0368016415065338, 0.056275014780581965, 0.07309441004068622, 0.032602200780304215, 0.02405528914213421, 0.05946550668487626, 0.028426906679786985, 0.023054104155650543, 0.10386272273477047, 0.03750096150343457, 0.05406134243633959, 0.01040101103905228, 0.01995088498769028, 0.02416200135954686, 0.07226233896348747, 0.080911502272131, 0.07096087049332357, 0.05343941310721059, 0.03873984059018474, 0.0256028461209949, 0.042311721706702825, 0.03251134658292417, 0.030433365647050164, 0.003872972583555947, 0.024631017623769663, 0.036798619755333474, 0.07342048770477695, 0.04741639537256091, 0.012972790225889656, 0.11595889865871399, 0.03117722169976802, 0.0543790390985387, 0.022124557966186155, 0.01435475921513693, 0.042458772283768466, 0.04128644708544016, 0.0664635589947143, 0.06066649506289152, 0.05385175610201494, 0.018771492628260486, 0.09630346505512154, 0.21671139635145667, 0.11395308895096665, 0.12697340439884894, 0.22741807264185723, 0.17261805673760755, 0.10081029902662962, 0.20219490352657535, 0.22533014596950626, 0.13836252713395705, 0.3080505427093275, 0.12857678045909252, 0.1580962932278072, 0.14779115426203898, 0.0838709612106604, 0.23095413531747558, 0.15311132846099718, 0.15795896430650067, 0.1816933794367698, 0.14049715452617215, 0.14620204275894552, 0.22418079957846673, 0.20027502590129453, 0.16541145231214263, 0.11320070633965154, 0.1478238202511303, 0.10039066670522576, 0.08746923788660958, 0.16211044073345202, 0.16085833130824953, 0.09412104143731057, 0.22934164281093308, 0.12864706136526602, 0.152285807435551, 0.12167826595325625, 0.19192417723036584, 0.11358442445916515, 0.13700944732033438, 0.1181003595552137, 0.15285465836284623, 0.08758530020713808, 0.1854727822806566, 0.16901663144028958, 0.32787836907852086, 2.7485469656605876, 15.244473084326714, 38.49698066711426, 51.5946219044347, 52.37509119895197, 39.79174329388527, 33.50853773855394, 36.85642973069222, 43.581729550515455, 36.559474929686516, 34.7983346446868, 28.29190504166388, 17.672336870624175, 6.86550150955877, 1.7606778130415948, 1.3128985632811825, 0.31549434327790815, 0.33249270050756397, 0.1651714982524995, 0.5359941516672412, 0.3036999600308557, 0.29742999002337456, 0.2817386400795752, 0.511558091928882, 0.3501639280828738, 0.4898575483070266, 0.4825647896335971, 0.439674039521525, 1.4929922285579866, 1.3680453718669954, 0.7006295109468123, 1.3035769279926055, 1.6608813164695617, 3.8311858523276547, 3.3759163464269335, 1.1376945001463736, 1.6971171527139604, 3.5462955265275897, 2.456977578901476, 5.704309315450731, 9.773765917747252, 13.624051751629, 17.401899253168416, 21.242256587551488, 22.75610908385246, 17.77852915948437, 20.00002234212814, 24.126600911540372, 28.98938875044546, 31.105354485973237, 31.046024714746785, 29.55642423322124, 28.07219739883177, 25.425937021932295, 20.64795082615268, 15.642494616969941, 8.645741285816316, 8.108241740734346, 2.2725565587320635, 2.929818077433494, 7.1131423115730295, 0.8690091402780625, 0.45275333607869767, 0.9723434308844229, 1.526827574256928, 10.335665056782386, 2.513458238494012, 1.7223568693284066, 1.9904102985897374, 1.3181388498313966, 0.5772824909898543, 1.7541138491322918, 0.1406461586274447, 0.36670073265990905, 0.2525261906726707, 0.3056494392935307, 0.27221564624098044, 0.1971059499849235, 0.5294400549704029, 2.3933697275577055, 5.272847615903424, 10.767838666515967, 15.085473925836625, 31.739023193236324, 30.40034571001607, 25.58768576191318, 31.521239472973733, 48.095957925242764, 54.36888294835245, 48.77453188742361, 32.473575261331376, 15.552536037660415, 2.7726126678528327, 0.2000021607044243, 0.19728884581596623, 0.2962849030811941, 0.08077008244130882, 0.10063628981550855, 0.10810314963061003, 0.08411050158282442, 0.23112056025814628, 0.140020877663647, 0.1118247204970929, 0.13722038196940578, 0.1080409892564339, 0.2166029489448955, 0.14997370811479707, 0.18710358428858942, 0.13611651055755156, 0.13971438120690086, 0.16036769795802333, 0.1537425695888458, 0.18709131156004247, 0.16377413855685344, 0.16630213677642808, 0.13618568829711408, 0.12147191250997207, 0.11683208567480888, 0.13893514721383973, 0.12374912418665425, 0.2034656901753718, 0.22311285769026126, 0.09844054392869435, 0.12816874670886225, 0.1386023432977738, 0.08314621905165334, 0.1509056081094088, 0.11357009095410187, 0.17357840923772705, 0.21558055864466777, 0.13187330276254686, 0.33362313984863223], [0.018967488562808405, 0.04902077117754568, 0.02530869517114855, 0.056259911357154774, 0.017664943739110907, 0.06799732064527851, 0.02786987648916341, 0.05538186351318033, 0.08580913301557304, 0.022214640329982487, 0.11635350288763163, 0.04828359158108792, 0.05568530710954821, 0.028034194688042326, 0.03830624248592123, 0.0116605170431637, 0.045398316766706207, 0.014615560442419543, 0.0396208455335469, 0.13397341023289389, 0.054195446127484885, 0.0425381160100862, 0.08779665620456781, 0.06100871802998647, 0.0429209033327718, 0.020372880690340555, 0.04511211780951389, 0.016301257438176585, 0.01928197148616516, 0.016027041053729915, 0.12323747704466506, 0.0534145190801111, 0.03219761059529359, 0.0447845462739708, 0.00695521075789246, 0.04489517320067652, 0.06545036174957791, 0.07837884623797671, 0.03300483744110792, 0.05159409498916038, 0.054955282774303234, 0.012656162256344914, 0.04177940551251654, 0.0537684019054136, 0.7214978685782802, 4.605869160544488, 17.351310483870968, 36.062012487842196, 37.214624497198294, 34.20828857729512, 17.767797554692915, 17.06101586741786, 24.835257491757794, 27.63804005038354, 35.93877553939819, 31.134332956806308, 18.146263130249515, 10.192296543428975, 3.5780422101097726, 1.623964336129927, 0.4069646285666574, 0.10817146935169736, 0.07612431076385322, 0.11861487952691895, 0.00955585039205729, 0.14149136811254487, 0.09676750749349596, 0.18510634710471477, 0.01419027056169486, 0.2158336128078161, 0.1942580487699278, 0.8259193298797455, 0.9561593025442093, 2.1087674508171697, 0.7513008951660126, 0.8681413771644716, 3.3109589545957507, 1.171517098142255, 2.19934233254002, 3.9379863537126973, 1.2115706263049957, 1.1504392614287715, 2.1946837825159875, 1.885240522603835, 3.3927506689102422, 4.098819955702751, 9.5921984218782, 10.27414954477741, 10.241548765090204, 8.304826521104383, 8.936480110691441, 10.308605605556119, 14.701731781805716, 14.785400840543932, 18.144090137174054, 17.62885347489388, 16.669133824686853, 14.349049906576834, 10.629962451996343, 6.585130979937892, 4.031943544264763, 2.6430790895415894, 1.5662871084866987, 8.902090730205659, 1.5021447116328825, 0.44793445917387165, 0.4694591396518292, 0.8147970815339397, 0.7437023448367274, 1.6430548794807929, 0.20043132315960624, 0.3109060281947736, 0.8036637402349903, 0.14110035683599212, 0.7670690684068588, 0.01032393301777061, 0.3252158458194425, 0.09017457779977592, 0.03594705174046178, 0.07641319485922014, 0.1336015971197236, 0.22130934882067868, 0.817590544541036, 2.7965857040497566, 6.530331055964194, 8.798493089214448, 16.7886798227987, 27.910525145069247, 16.33727385151771, 28.415930386512514, 28.538761369643677, 31.723106215077063, 37.60861089152675, 29.82109008296844, 14.73994351202442, 5.242779706754993, 0.35983146739102184, 0.13124710249324, 0.02057879171784847, 0.13043541701570635, 0.03627060897528164, 0.025646771687353333, 0.04747315865731047, 0.018866816948678707, 0.08344280233065929, 0.06247034484160043, 0.032636659415138346, 0.0612683413970855, 0.06647402375575996, 0.05454196301739543, 0.010836094396278985, 0.04194195021785075, 0.016586140639358954, 0.05870085900589343, 0.02604774019170192, 0.022301321263395013, 0.037776086659681414, 0.027898654582039006, 0.027028175686756452, 0.07197532412265578, 0.03857402468941385, 0.05324308392441562, 0.025821535495079817, 0.07252189721311293, 0.07701864946753749, 0.062766001154218, 0.057492707705786156, 0.014864931637871892, 0.018360319832760482, 0.06221917142430621, 0.03612861840895588, 0.07441416502960267, 0.05689208711227102, 0.028952180610729322, 0.0439856123299368, 0.03180793805738851, 0.030995293054729704, 0.022241279122329528, 0.0984262180845103, 0.01279438941574265, 0.05548075014244645, 0.05619224281080308, 0.028829767421308546, 0.02210916151412793, 0.11549235877370644, 0.03655369761550138, 0.045907558392613165, 0.04672955541360763, 0.054031116437287106, 0.05412342237128366, 0.06653256819493349, 0.0700616441486824, 0.04876390955741367, 0.029121859509858395, 0.012406385034292698, 0.03683706970825311, 0.02214893488393676, 0.07760682113228307, 0.06652501456800007, 0.028558158608634147, 0.015771730761644582, 0.04629621777923838, 0.04399880436399291, 0.008564660937765674, 0.05852366669944698, 0.0398356834005925, 0.041719049275402105, 0.03060371104267336, 0.03655513403035941, 0.1067501464257798, 0.035936299696444504, 0.03177360582706188, 0.038747325269204956, 0.020251436602143992, 0.05925657918616649, 0.06351005638979616, 0.08987802516428695, 0.0743898647206445, 0.024310224051136645, 0.08591084650927976, 0.9710806728370729, 7.031887961972145, 21.293610219032537, 41.10454882344892, 43.07962694475728, 41.730366906812115, 25.297077355846284, 22.855525478239983, 29.24729439520067, 29.890502306722826, 42.13892490633073, 36.66413161062425, 24.651229689198157, 10.500036881816003, 3.242215004659468, 2.160442961800483, 0.46983360342921754, 0.14060031592605576, 0.0759003756027068, 0.08462426312748464, 0.09180482056352401, 0.2227946860535491, 0.2695816827397193, 0.2625797003988297, 0.23524036661030787, 0.6101721164680297, 1.0322446424153544, 1.3480926425226274, 2.4624664456613603, 3.2619543325516487, 1.559853685959693, 2.305785898239382, 6.932956960893447, 5.585456596266839, 4.866852394996151, 6.667710110064476, 2.5586353626943406, 2.885243282202752, 3.9462517682583105, 1.9592109082206606, 4.888452887535095, 6.966784461852043, 12.003770643664945, 13.690258418360065, 14.588590033592718, 9.4783555499969, 10.964805387681531, 12.449580373302584, 18.8030404813828, 16.38431679817938, 19.951928200260287, 18.79376995948053, 18.49715248230965, 17.537185722781768, 12.301033350729174, 7.647521611182921, 6.651859812198147, 3.0391649325047774, 4.919724964326428, 6.9382232331460525, 2.3534096008346927, 0.5158112895104193, 0.4032614514712365, 1.2627661372384718, 6.053938606093007, 0.1748879446137336, 0.5300472256156706, 0.6082837403781953, 0.8297852546938005, 0.8828774154666932, 1.623004948900592, 0.08593578267121509, 0.07708878481700536, 0.43049799158207835, 0.10295206635829904, 0.11276983550839847, 0.02802283934978468, 0.22833791441254078, 0.9481078410340894, 5.013673574693742, 9.190174110474127, 13.284162686717126, 17.615211471434563, 34.07814825734785, 19.948451019102528, 29.963785909837295, 31.89124841843882, 37.446887646951986, 43.516084763311575, 34.29940523639802, 19.05356030310354, 6.302615404129029, 0.4133205229957258, 0.0556533957170623, 0.04058175727785115, 0.12959301141240906, 0.028123503303035136, 0.0046430884545008025, 0.0524253731653575, 0.011881669389925176, 0.052594149995955734, 0.024512733648260756, 0.032301921127063614, 0.026369290276160164, 0.0768564303495711, 0.051516965256943825, 0.03638373717906014, 0.015985603357905585, 0.03515255727594899, 0.10489455889910461, 0.0198223507557545, 0.0518140196800232, 0.021921607868505583, 0.05084401064161813, 0.06014169419124242, 0.06399682482644435, 0.06183555672666239, 0.03934861235921422, 0.007430708604759627, 0.03499206568625185, 0.0485670977392264, 0.046829924423007235, 0.04335375067086951, 0.038364668181466485, 0.037563918609051936, 0.04770275520821733, 0.01893576869230357, 0.056904972711157416, 0.055747203183390444, 0.05014853304131858, 0.11556038738138254, 0.05380740344163872, 0.14125334459447092, 0.09288077573141745, 0.19307021412157244, 0.1664852624338481, 0.1773057027810043, 0.17389077392797317, 0.10951489645747409, 0.12756205103810758, 0.32313006419327955, 0.1726081129163504, 0.2720977606311921, 0.17458852680940784, 0.1376954330912521, 0.11071799923816036, 0.1284460015895386, 0.11077612998985475, 0.24901193085937734, 0.14954817691637626, 0.12807208173457654, 0.29510555668703975, 0.10874107104515839, 0.21319018045981086, 0.1980273392532141, 0.1569594800352089, 0.1730939045908951, 0.12447389698917828, 0.14759292135075217, 0.12307551839659292, 0.18118244475655018, 0.13932621977742643, 0.2860602339909923, 0.20121676246485404, 0.184612603437516, 0.24038101576509016, 0.1398700809166316, 0.10960209258501569, 0.11947223150561895, 0.17629481912139924, 0.1299780625249109, 0.12358099853079166, 0.19028364590579466, 0.13445321109987077, 0.13868048426605042, 0.1579084484687736, 1.3539667595778744, 7.468191337200904, 25.08431230821917, 48.13055715253277, 50.15118575865223, 50.50042967642508, 32.06915143997439, 28.487674459334347, 37.82193291571833, 39.11226326419462, 46.985527084719756, 39.328734951634566, 24.706542953368157, 12.215172667657177, 4.198538372593542, 3.413844685400686, 0.7727699883041844, 0.4485280853846381, 0.1682063708862951, 0.34378354948374534, 0.31251125818779396, 1.0104734654868803, 0.6207160603615546, 0.30947834673908453, 0.34535185403881535, 0.8760972921886753, 1.1385215073823929, 2.4753244653824837, 5.402531960318166, 10.08616210952882, 1.079481133530217, 1.4722188658291295, 9.370284445824163, 4.476869269724816, 5.143317714814217, 7.77515112392364, 2.7051099029279526, 3.181089523338503, 4.252115987962292, 3.105931027281669, 4.415370427793072, 4.836774189626017, 12.744894642983715, 14.455091184185399, 15.8482749039127, 13.374328171053241, 13.879431389993238, 15.3179665342454, 20.286775058315648, 20.113061128124116, 22.52178865094339, 20.243340692212506, 19.990290941730624, 16.664803528016616, 13.056774062495078, 7.798705937400942, 5.763656247046686, 3.9906110782777113, 4.979181231990938, 14.762455955628427, 5.602382604152926, 1.2761891008384767, 0.5783806320640349, 1.968537323897885, 13.074508078636663, 5.490491111432353, 0.8851105924094878, 0.9613635523184654, 1.7753564253930123, 0.9475998940967745, 3.749752299439523, 0.177465186965081, 1.2268314654788663, 1.1688663113501765, 0.29005103113670505, 0.5225596048178212, 0.2161418253015126, 0.6187606362565872, 1.3999607173665878, 3.978196776682331, 9.46037736631209, 14.245504236990406, 27.606590486341908, 37.0738741659349, 26.405027297235307, 41.03963751946726, 39.17642539547336, 45.447765781033425, 49.31632103458528, 39.7033840610135, 21.75844050222828, 7.654358792689539, 0.5659662691816207, 0.2722305696337454, 0.2633465237675175, 0.26229630915387986, 0.11130027968676821, 0.12111991043052367, 0.1366346464642594, 0.10074916521027204, 0.2537231724108419, 0.21659490502169057, 0.139855295419693, 0.2027717217682831, 0.25535994990458416, 0.20582013883657996, 0.15884823916900545, 0.149139606904599, 0.167490431077538, 0.09834842951667887, 0.1691724690458467, 0.16605027771044165, 0.09307995859173038, 0.09055577549001864, 0.08001827439593692, 0.19033272149822406, 0.20125594020130175, 0.2164656353453475, 0.17316064617085844, 0.1658935667646508, 0.3022091529302059, 0.14410971874190917, 0.11531255027699856, 0.24731408083631148, 0.11433185814248939, 0.15487112435362033, 0.10229495444124746, 0.18155163784901943, 0.16525446557469908, 0.18079572357237342, 0.22911914023420504, 0.17682527372192952], [0.06854745604458355, 0.03032127932284869, 0.03469961162115778, 0.040018946953838876, 0.041368023958057165, 0.05841518864936887, 0.046338226210566304, 0.025297217258823015, 0.034881637942406445, 0.06002519137015747, 0.06181535115765949, 0.09117405441018844, 0.06464807617087519, 0.014219344556031209, 0.040806895197038694, 0.03258019873511887, 0.1186968585956962, 0.05358984213202231, 0.02483671414665878, 0.0700143228975996, 0.017348641356933984, 0.08297450810430512, 0.07060041846407038, 0.027457736507658998, 0.018513309506459102, 0.044792053935628746, 0.03332969319495944, 0.032085997330385356, 0.057596229166994174, 0.055419386499711586, 0.04069975397038845, 0.010873114637609933, 0.06092770423199381, 0.03622144145230132, 0.07248222151951444, 0.08595681944561583, 0.05782735406330997, 0.06380548287603645, 0.049688864964991815, 0.05363815929740668, 0.03733859682876257, 0.010827287257979474, 0.07014216765040351, 0.06841041057580902, 0.06279566024820651, 1.9702836366430407, 10.567821321948882, 22.733561338916903, 35.6084962814085, 35.35048277147355, 28.991924562761863, 23.02782735516948, 26.437116207615023, 18.876975197945875, 23.768423795700077, 24.03375448719148, 20.28918927715671, 16.365123660333698, 10.760245938454906, 5.542157061638371, 1.7855998176720835, 0.2905658728653385, 0.041079511415333524, 0.1574642706902758, 0.025241191333700574, 0.055889936855002764, 0.14271386057859467, 0.05945622936011322, 0.31228026735686487, 0.8450527741543709, 1.669933166234724, 0.8999969678059702, 0.760651825656814, 1.6824636680464593, 1.5020097575841413, 3.206391262431299, 4.511753849444851, 3.173673547083332, 3.4643844250709783, 9.979318707220017, 2.424082131155076, 1.9438708861989362, 0.7327835081565766, 0.49063236963364387, 1.6401572285159942, 3.7934278913082617, 3.6316749838090714, 5.568361436167072, 6.891469070988317, 4.810844871305651, 5.91256118589832, 7.00844346515594, 8.045249456359494, 9.641106455556809, 10.129387609420284, 9.976070984717339, 9.48032065745323, 7.917516981401752, 4.856016357098857, 3.628200989577078, 3.4339514903483854, 1.1381436115311039, 4.811575412750244, 4.7185671906317435, 0.7389629572149247, 0.19403016825597133, 0.36957736217206527, 2.1403878831094314, 3.589721802742251, 0.43788084219540324, 0.5858710107784117, 0.3048980602573964, 0.1987806641526761, 1.1399754809756433, 1.5034041601803996, 0.27398423682297435, 0.06752442989137865, 0.23441925825130558, 0.08470374474962873, 0.11960330914946334, 0.29885224757655976, 1.2128292168340375, 3.5204544615361, 5.165544805988189, 9.46917720379368, 16.99194488986846, 25.9234877171055, 15.323506882113797, 25.047461640450265, 24.678988302907637, 31.06671129503558, 35.75642062771705, 31.10201458777151, 20.466649070862804, 7.470096628512106, 1.5004145786646874, 0.027383081239437865, 0.028555936953653733, 0.05741733997579544, 0.06998127386454614, 0.011625467563017963, 0.08757992226990961, 0.03522691760031927, 0.030956245553229126, 0.03909440140330023, 0.012287564797236795, 0.07928898933553889, 0.030326182285564083, 0.020040775829505537, 0.022131073543982163, 0.06134514171149462, 0.0753408556263293, 0.07846327678811166, 0.03806486733317856, 0.04966331210227744, 0.08602582864583501, 0.023265914060175422, 0.052748512882258625, 0.04542405732096203, 0.058525076301227656, 0.08957568856496965, 0.059876650752079104, 0.0033315557436341603, 0.03539991557538029, 0.06590891133753524, 0.010689688290679648, 0.011686325587722804, 0.053763767073471705, 0.021902007508962866, 0.07410411392488787, 0.025486061762597774, 0.03352536354213953, 0.03779407823458314, 0.08593372955557801, 0.019821057982382276, 0.0480186898681906, 0.03850064495758664, 0.019513557950455337, 0.00288670931401993, 0.03474050156411625, 0.03862950477689024, 0.052091194121467496, 0.059115952256345944, 0.004458162969263692, 0.06860507351736869, 0.0641334795903775, 0.04023712113379471, 0.06058496032511035, 0.022856409421130534, 0.045091873936114774, 0.06216677101028543, 0.050325721517325415, 0.11328061697103324, 0.03804257034414238, 0.04822660613084032, 0.013564133494641754, 0.02503203209339371, 0.06040591791632676, 0.03304991788501221, 0.04643248183833015, 0.012304721336301056, 0.015256182316900983, 0.025185127104181918, 0.031397058290519544, 0.03457625614359014, 0.06479137291711184, 0.010695643666681024, 0.058245680204802947, 0.05304840183065784, 0.06498182237508797, 0.06324177239871313, 0.04247669491075701, 0.04292345440555965, 0.0525156106619585, 0.06705356160959891, 0.0247728243289936, 0.015875392033898785, 0.03290860913693905, 0.06323035385820173, 0.052922529754258936, 0.10103664736473754, 2.26319533201956, 12.98399252276267, 27.41784603365006, 42.40087255354851, 42.43017265873571, 32.24696032462582, 28.233414657654304, 31.33226360044172, 25.129647062670802, 30.083747679187407, 28.254466018369122, 22.338574740194506, 19.07135413539025, 11.718463320885936, 5.794825851917268, 1.7508914994616664, 0.38267951879289847, 0.05569114852997084, 0.06402081486979319, 0.11495512429504626, 0.036540199146275563, 0.37322093762697717, 0.23809677140126306, 0.515686999405584, 1.0454876672837043, 1.01082525306171, 2.9127351747405146, 3.090828186081302, 4.916963125428846, 6.328843803175035, 7.678602472428353, 10.910314840655174, 10.048633852312642, 5.8076882843048345, 5.937999227354604, 4.507216647748025, 5.058955867444316, 3.3489525029736185, 2.646631286028893, 2.459851940793376, 5.744739146001878, 6.521190952870154, 8.086661840638808, 10.650616672731216, 8.182341196844655, 8.956507732791286, 11.528275435970677, 13.224268094185861, 11.344399625255216, 10.583495113157458, 13.10802080938893, 12.701342605775404, 9.972186857654203, 7.661751970168083, 5.569386155374589, 4.270737930651634, 2.1437444513843906, 4.8288431571375945, 4.931524924693569, 4.702961550604913, 0.804199695346817, 0.40892235093539764, 1.8328809257476562, 3.042845586615224, 1.523819729205101, 1.2081521581257544, 0.7541536840219653, 0.6191469897185603, 1.2909135558912832, 0.38862672063612175, 0.08954958794938941, 0.21946581951793165, 0.17186742846763906, 0.059635930604511694, 0.11625544363332373, 0.35640638021211474, 1.1343835294246674, 3.8086385976883674, 6.149750832588443, 10.542706385735544, 18.220617540421024, 33.61985852641444, 23.984722898852443, 28.60002486936508, 31.425459115735947, 36.32627825583182, 41.4093287529484, 35.991864819680494, 25.279660071096114, 9.720275575114835, 2.2346860747183523, 0.092847190436817, 0.024023697591356696, 0.074053414226059, 0.07766564902398856, 0.07554684134740984, 0.026291718128167336, 0.030106179070689028, 0.03439837052757221, 0.04592257371592907, 0.08326549128058457, 0.043910160330274416, 0.03682553242411345, 0.08779739930985436, 0.04582292865961791, 0.06890982329364746, 0.08498760330821238, 0.015850130284595636, 0.008806963056896724, 0.07343061538713594, 0.04879338862073999, 0.05245232796897331, 0.02936780054662978, 0.009585179110628464, 0.03680872062461511, 0.024680472429721587, 0.006294224351163834, 0.051516635839136384, 0.0230431605896522, 0.011394937342453388, 0.019708523496745095, 0.03460784194870822, 0.02490813843905926, 0.025782315623796275, 0.06067173893473322, 0.06521351800690736, 0.0036607894505704605, 0.07892042443516754, 0.10157568215001976, 0.004614966324410372, 0.012087942393977317, 0.19539308463854177, 0.14504511209745563, 0.13200307805691996, 0.14944164472962582, 0.150367186194466, 0.1633390159376206, 0.16598352080871984, 0.09051431481155658, 0.2545093931257725, 0.1814407236393421, 0.14086506059092863, 0.17985539661059458, 0.16925428723615987, 0.14476296191494312, 0.19642146574633737, 0.18667558628705241, 0.28088175541450905, 0.10840669664884768, 0.14444754819475836, 0.21768081933259967, 0.11979838577850212, 0.2134176626080467, 0.1392269041389227, 0.0795643596399215, 0.16389220802774354, 0.07010399348913662, 0.11325880644782899, 0.16065802995956716, 0.13858708282632215, 0.2533649037321729, 0.12402993371529926, 0.12675424962635004, 0.11100752684738367, 0.12886590204171597, 0.14195376346188207, 0.35041603229699597, 0.1235162181359145, 0.18845894704422644, 0.19399526529014113, 0.22818322593887008, 0.17791305728737386, 0.11013420959634167, 0.10371112925631386, 0.3640442461736741, 0.32158495678055676, 2.83683902794315, 14.872440195852711, 31.998817459229503, 50.246726851309504, 51.92616024324971, 43.48496467836442, 38.853065198467625, 42.68501689357143, 32.46839773270392, 35.361210453894834, 35.70589657752745, 29.80667341140009, 23.19026250993052, 14.035869240760805, 7.126085642845401, 2.6392682617710483, 0.6117660083597707, 0.38497618910285736, 0.3475341933869547, 0.3061685711145401, 0.3615344808466973, 1.4004750381554327, 0.6908577836809621, 1.148378546199491, 2.815012753971162, 3.6329463220411733, 6.294009233674696, 5.922430359548138, 5.222817294059261, 5.44287157635535, 6.5230001461121345, 10.17343092349268, 8.321934919203482, 9.952127856592979, 18.19486129668451, 7.863870724554985, 6.777874779316687, 3.661260686574444, 2.198134977971354, 3.0662020752506876, 5.161580270336521, 7.0486997308269626, 9.8332663120762, 11.282787034588477, 8.799920831957172, 11.337672760409694, 12.626664600064679, 14.075090000706336, 16.14704772349327, 12.40850825463572, 11.684973143762159, 11.256974897077008, 10.312667219869553, 6.311716283521345, 6.066350946503301, 5.207201357810728, 2.5707594088969694, 8.815277891774333, 12.055256655139308, 4.501098730871755, 0.4250526079727758, 0.20619558320651132, 4.295011518463012, 11.516087651252748, 2.6668388468603936, 2.9478423489678294, 1.196911380656304, 1.1614748499085827, 3.3119996084320933, 4.861137991951359, 0.8892835039765605, 0.5008403686506133, 1.0674762293215723, 0.39716768168633987, 0.34344889163490266, 0.640340475065093, 1.4863881829284853, 3.8361839325197287, 8.451547680362578, 14.799236020734234, 25.691357927937663, 36.58920649559268, 24.116222320064423, 35.952460688929406, 36.12021653882919, 44.162746321770456, 49.69266853024883, 42.93170259844872, 27.594193835412305, 11.663961987341604, 2.6244431734085083, 0.19108760921705156, 0.15574575161501286, 0.24119786467523346, 0.23789588782575824, 0.21351601297576583, 0.15272358071900186, 0.16003199822960362, 0.1508935958507561, 0.25364221223900396, 0.17519120817943928, 0.16402156963463754, 0.10924534076043677, 0.1567769978916453, 0.12894634127376542, 0.19924638432360467, 0.12611910145008756, 0.19387601604384763, 0.19263821714107068, 0.174494098811861, 0.1705883374257434, 0.15119063878251662, 0.1305379042582166, 0.18723599492542206, 0.14890136888190625, 0.17917963045258678, 0.11420473351233429, 0.25262599660744595, 0.1024457282056251, 0.1259620381038516, 0.2923606023673089, 0.12941766920829975, 0.16285950618405498, 0.10711488854740897, 0.20222752355039122, 0.16962205540508996, 0.16641660563407407, 0.15497689045244648, 0.2540438108506703, 0.14097487163399497, 0.16783216757880104], [0.040570863507567875, 0.012030705092324605, 0.04950764303606364, 0.03709402325893602, 0.04132704974542703, 0.03681599845989578, 0.03509169925124415, 0.020981382413376725, 0.020564655480425686, 0.022203032182709827, 0.01912145116817086, 0.05016398503475132, 0.041508137608968446, 0.02474493489811017, 0.03410917233615633, 0.03899415496796851, 0.025314369967447656, 0.021755780476415833, 0.08990816306322814, 0.10040940521585365, 0.03239864355794365, 0.0637863613214464, 0.003727209513008054, 0.04572851598382958, 0.036303343912286144, 0.04522082568596929, 0.07488824321978516, 0.04984160757533485, 0.07168964993569159, 0.024960127080820745, 0.07158374594103906, 0.07886545762660042, 0.0030900640018855135, 0.044923537606073004, 0.04088068861634501, 0.04713915581364305, 0.012883622379552935, 0.08423175797947953, 0.010206804877417463, 0.04799573404353954, 0.04922505235299469, 0.07088505843233678, 0.10089208657342581, 0.057416252130942966, 0.032369650960449255, 0.5671724592966418, 2.6091773086978547, 13.893784323046285, 29.319701348581624, 39.65710401535034, 39.176821554860766, 35.398829906217514, 24.724809431260635, 19.41015474257931, 29.235576314310876, 28.014605237591653, 25.831074714660648, 22.241317610586844, 16.095624469941665, 10.031515648288112, 5.198949181264447, 2.2920688794505213, 0.7449286370988816, 0.14274752248198758, 0.029395649757897182, 0.11579778270735858, 0.02794592986784635, 0.16972700945071637, 0.2591463394703404, 0.24900143545481468, 0.43873788007805425, 2.3274319883315795, 2.7284318256762723, 3.9930549600432, 7.909032404422761, 10.234163922648277, 15.419299987054641, 21.428841775463475, 6.76484368501171, 2.9692288271842466, 2.914486513022454, 3.184906970108709, 5.739043374215403, 1.8787326976176233, 1.0105995329157, 5.584276943437515, 3.050919540466801, 2.2982235685471566, 3.731291173927246, 3.5826129971011995, 2.9086921916854, 5.137626355694187, 7.031608002801096, 4.845005283432623, 4.359270728403523, 4.370597062572356, 5.419529061163626, 4.709216750437214, 3.8952254095385155, 1.5761668235063555, 2.5305065752998477, 1.999481147335422, 4.216762194710394, 3.123333848291828, 3.814772939489734, 2.028723274988513, 1.8763219108504636, 1.5529409988272576, 1.514522731304169, 0.39874306489383027, 0.14526398341742255, 1.0561239094503465, 1.0545297111234357, 0.8890543517566497, 0.3303382161163515, 0.1767230775928305, 0.18380517740884136, 0.1585986936885503, 0.09302726706429836, 0.3536925903491436, 0.959549701261905, 3.0321718367838093, 8.920519986460286, 21.717696882063343, 27.28201827695293, 30.259338463506392, 20.091315507888794, 18.138845928253666, 19.572697762520082, 26.251966607186105, 37.375810377059445, 34.79197648263747, 22.783540179652555, 8.137751692725766, 2.8148114873516947, 0.47947377807671027, 0.10930153330968273, 0.13650428894306385, 0.05485435069027928, 0.0029978200731303303, 0.018859822565930027, 0.13527102528079865, 0.034293914439096566, 0.0530272578039477, 0.023923303684099548, 0.024458676569103718, 0.026681704762121363, 0.09741715005328579, 0.03534924652006838, 0.04934866447001696, 0.039361375384032726, 0.025796729568091613, 0.05846540954324508, 0.03873673027321216, 0.06293866588103195, 0.05802417354237649, 0.04214499799174167, 0.014421379178642266, 0.02633590224920021, 0.048361200118257154, 0.030127581652073614, 0.029060289023383975, 0.035758881394060395, 0.06785230020121222, 0.047127449990160046, 0.041527006354543476, 0.030025027376869996, 0.032989090503824335, 0.03765342066124563, 0.029789857536313996, 0.033987735908839016, 0.06701681237187117, 0.0313860074722118, 0.012786801314852651, 0.087638336474136, 0.09206958055015534, 0.02878090824871775, 0.036036726162438436, 0.01584394412460707, 0.03173458513863866, 0.013628456151984153, 0.05225994413898838, 0.02158960068388091, 0.023406276689662088, 0.04273426516221897, 0.03607644782131238, 0.025375902149525863, 0.042344602200412945, 0.11153337725948904, 0.018762148270804076, 0.02983310319963963, 0.036989774014199936, 0.022195294694674593, 0.015727200943435875, 0.04001162315328275, 0.01572761175808527, 0.02090893347837752, 0.02699848786447077, 0.03445924387403554, 0.0391052606996269, 0.06329810284378548, 0.027386930831257376, 0.0606895964442482, 0.06175196887324415, 0.030643821491168875, 0.005236578684660697, 0.03211998099070643, 0.019156281355648272, 0.036745882262626005, 0.05100923665468732, 0.010672190842489082, 0.022260486861811053, 0.02595191216847349, 0.07796343506103562, 0.0489274769901268, 0.009733583748100266, 0.020668424004989288, 0.02614467712720075, 0.03669804390219431, 0.03204526443545136, 0.038709511169262474, 0.9475588317840331, 4.610681418449649, 17.579765012187345, 34.30239016009916, 47.97714541035314, 46.29500166062386, 42.21801950085548, 29.663051905170565, 21.779923323662054, 30.676476647776944, 33.582674457180886, 32.21787202742792, 26.978613138198856, 18.929950729493175, 12.156854867935182, 6.127036877216832, 2.3877948138021656, 0.6422275028401806, 0.1329995286200316, 0.055935453969023885, 0.17449514069143804, 0.07713232159374223, 0.15164790134276115, 0.20202677787071277, 0.8265690950136032, 0.9367802198375426, 2.0685915937346797, 2.480527734564197, 7.336408524743973, 9.462009072303772, 8.547544748552385, 9.014502917566608, 7.608674947292575, 5.26357856488997, 7.675101757049561, 5.4132057101495805, 4.60039206089512, 2.8262594149958704, 1.5853832902446872, 3.3767518112736368, 3.4003757565252246, 4.951900166849937, 5.500058752875175, 5.6602096173071095, 5.759174448828544, 5.399386219439968, 7.814786674514894, 10.736667590756571, 8.086265681251403, 7.3801625640161586, 8.251596035495881, 6.8594831228256234, 7.6224856126692995, 4.429245812277641, 3.0753468361593064, 3.0410435026691807, 2.67829658043, 2.199904702363476, 3.8067139396744394, 4.872107880730783, 2.3688833511644796, 2.0078256221548205, 2.6215876879230624, 2.380098388079674, 1.2893908182459495, 0.8468399040641323, 1.3348493725061419, 0.9906447198121779, 0.38104557582447607, 0.3028080498258914, 0.14775093464601427, 0.18225159706367602, 0.0039194657414731, 0.06846803570947341, 0.4012005523808541, 1.2302836415267762, 3.636566914858357, 9.436945126902673, 18.555107462790705, 29.358307277002645, 33.92927861982776, 27.15526688483454, 19.426469841311057, 22.223763042880645, 30.723851034718177, 41.6621490447752, 40.63520585336993, 27.87612988102821, 11.153896970133628, 4.078011291642343, 0.5480600977616926, 0.11304428650727195, 0.08418978402210821, 0.04268844927390737, 0.01003876157600673, 0.007885298954563276, 0.05548587527065989, 0.031569638747661825, 0.03083569587268416, 0.06539018554312569, 0.02655801029064723, 0.07819225786313896, 0.08888948062855391, 0.01376971701956204, 0.04916877170363742, 0.03404934469970965, 0.026059198951829347, 0.011884615955603941, 0.03669268128672435, 0.06506740971798859, 0.05316245700082472, 0.05498241377814163, 0.005866852626504918, 0.049820888727422685, 0.02234343886225214, 0.0629088765520963, 0.01127463568287391, 0.023350080309976495, 0.08921570384935026, 0.01509224811959411, 0.027740472747433572, 0.042302049846658786, 0.013606082554155541, 0.05800943018027371, 0.03113841360074378, 0.055396158713847406, 0.0855064669984483, 0.0043590422043757095, 0.032876640287858826, 0.08948623247805143, 0.03053569584153593, 0.13786322166842802, 0.10067341443631919, 0.1632313652625007, 0.13412109666293667, 0.1084589974714383, 0.11319479980175534, 0.09519965493030126, 0.21792540056330545, 0.14202039778953598, 0.15960649767469975, 0.1362300601096884, 0.14682185385496388, 0.17430944097859247, 0.1107888623711563, 0.12024866161687721, 0.09088389860886721, 0.1791244414785216, 0.08631183991148587, 0.15208667054051353, 0.2088764619322554, 0.13884994291490124, 0.25434909688849605, 0.14255203216546966, 0.2754671072527286, 0.19039213927763124, 0.23706581623804188, 0.1927179515722298, 0.14783949441006108, 0.24866021989334017, 0.12931196439650752, 0.21720743828242828, 0.27174713751000745, 0.16351786682442312, 0.13409855835620435, 0.1254612923930249, 0.12494757681364015, 0.11055443946632648, 0.17159649381233802, 0.14757507150211643, 0.19288359510321773, 0.11882314052913459, 0.17828038112530786, 0.1955404033463809, 0.1113156320887708, 0.05964011727501789, 1.0204195543642969, 5.023647181449398, 20.052280079933908, 38.15889589248165, 54.55807062887377, 53.868510107840265, 50.95900181801089, 36.58928886536629, 31.015838153900642, 42.14525953415902, 40.88136596064414, 36.082553940434615, 32.90648137369464, 23.54721780746214, 15.195722926047543, 7.5678391514285925, 3.3562826773812695, 1.2493447671013496, 0.3769696203451003, 0.15198678799694584, 0.46325345974295373, 0.3576521311075457, 0.6808308572057755, 1.5502677809807563, 1.785674955575697, 3.2903598921914257, 3.348554627549264, 6.849794378203731, 9.699602723121643, 17.205178660731164, 17.369565194652928, 24.253597451794533, 31.65999135663433, 15.607677698135378, 10.65549414004049, 8.486887255022603, 8.37130775374751, 12.083488895047097, 3.6332230942864574, 4.449121932829581, 8.337349833980683, 6.800243566113134, 5.823893066375486, 5.895691071787189, 5.90383832493136, 6.043849289417268, 10.045034097087, 14.118370413780214, 9.780077991947051, 5.676017749694086, 6.530780167348924, 7.827759913859829, 6.822124998415671, 4.919687211513519, 2.3866573264521938, 3.5546920953258394, 3.075118358096769, 7.331595286246269, 8.686785947891975, 10.751684384961283, 6.980556884119588, 5.039890206629231, 7.621953641214679, 8.631720773635372, 2.47025627282358, 0.7335031405091287, 3.5405916648526348, 4.4104292219684975, 2.786715794955531, 1.369904820476809, 0.4680513458386545, 0.9322666749358178, 0.25051550098484565, 0.4370924151472507, 0.4379575735618992, 1.9125399738550188, 4.533796098924452, 11.753589126371569, 23.495679824582993, 34.23745924426664, 38.71718645095825, 28.892312049865726, 28.34414512880387, 29.50607276731922, 37.69759378125591, 51.602090097242794, 45.892201700518214, 32.70399097473391, 13.501748327286014, 4.5081692934036255, 0.7422715990293411, 0.3145542308207481, 0.19823910127724373, 0.16287541016936302, 0.26234889342900247, 0.11797768589589866, 0.2151782858756281, 0.1374667098805789, 0.1333390434663142, 0.13334616808401, 0.12504434137935602, 0.2293415202368652, 0.2514092651225867, 0.12188555402380806, 0.14276630695789091, 0.08956450368127516, 0.16656214701792887, 0.14390275242828554, 0.12423347561590134, 0.13141496767920832, 0.1986860982593029, 0.13628846665303554, 0.13557732255468447, 0.1898202393203974, 0.09405506594527153, 0.16305649803290445, 0.10582765399087822, 0.1372470724726877, 0.21825829640992228, 0.08366630848256812, 0.12544423927583043, 0.11047976121546761, 0.11323577018394587, 0.10514324636108453, 0.12377519415871752, 0.1625385919525739, 0.17182560006697334, 0.08323457963283985, 0.14495143486607462, 0.20517164540867652, 0.16873848023674182], [0.037227456623147574, 0.019762881265412417, 0.06063182958431783, 0.03659241952963414, 0.047431805231157816, 0.10255922413160724, 0.030674057066320416, 0.035297041458468285, 0.053959831955932805, 0.08539153082716851, 0.026295125304210572, 0.05501187751970946, 0.05714273575933711, 0.04042866992794218, 0.10821184984618619, 0.06239231878651246, 0.027997508652568347, 0.03332203231571663, 0.06827400862089089, 0.020170175740795753, 0.04012251821076197, 0.021953842933139494, 0.013111657068704166, 0.10101582509495559, 0.03713760600094834, 0.046622678487291264, 0.0365153817279685, 0.007195386504228678, 0.03959264966749376, 0.032915599689248114, 0.016431228084970387, 0.03520611831317506, 0.0655597667660444, 0.06773341867712236, 0.028463925963508028, 0.03947164991029328, 0.015627696655780798, 0.04665711796992729, 0.020468909811649113, 0.027649409791094162, 0.030401731961436813, 0.03620613118513458, 0.033253873473093394, 0.0459712777557152, 0.0405767010975509, 0.04877912789402951, 1.5913688271276414, 6.690922206447971, 19.39268058346164, 28.938288111840528, 33.25170093967069, 32.20700313968043, 26.193797857530658, 27.48271615274491, 25.098317130919426, 23.207795504600774, 24.515127366588963, 24.11907192199461, 25.056245788451164, 19.13474552093014, 12.785472543008867, 5.775688117550266, 2.422723275038504, 1.1925171003226311, 0.1604677337191759, 0.1447655512921272, 0.030752563841580868, 0.05838048486639896, 0.1466439988824629, 0.6513946948032225, 0.63790756367868, 2.4119225384727603, 1.8428895886867278, 10.514562399156633, 10.132035209286599, 10.000964307015943, 8.565949489993434, 5.71610241167007, 2.828675595022017, 5.968295124269301, 4.356805518750222, 5.090629496882039, 2.4010825782052936, 3.5277468831308427, 1.4864520440178535, 3.123752316159587, 2.96376962334879, 3.273396866936838, 3.3307232875977797, 2.8900783388845386, 1.7855678258403656, 3.542961266732985, 2.735408251324008, 2.2173045815960055, 3.0838081240653996, 4.850083281916957, 3.9396756695162867, 3.1858434359873495, 1.91589470351896, 1.5083978277060295, 0.810383495784575, 2.410188360560325, 0.47546995743628473, 2.446703665679501, 5.405523257870828, 1.9727722579433074, 2.3277972590538765, 1.1574550333522982, 0.32965501890547816, 1.2661382724200527, 0.8206066633424451, 0.7017267327154837, 0.27182625907082714, 0.020390598388809352, 0.05561177799057576, 0.19794155272745317, 0.06428231515230672, 0.1893615518366137, 0.4161788583282502, 1.2479003542853941, 2.7892297890878495, 6.580677618903499, 13.128948615443322, 18.88943852916841, 17.623454332351685, 23.806923820126443, 20.63766637156087, 30.37146333725222, 32.2374701499939, 35.69161130535987, 35.7483523122726, 27.960815814233598, 13.805953629555242, 3.545809397774358, 0.6222210247670451, 0.05174612130729422, 0.03211048724610479, 0.061389812298359415, 0.11561178422022252, 0.06250882160759742, 0.06900392953426608, 0.024046534672379497, 0.043715462914758155, 0.04961163181090548, 0.02765202215091596, 0.017408126169034553, 0.011914601594570183, 0.012754305780324484, 0.02145206300361503, 0.05578184567932641, 0.015028734642621732, 0.06038001265316721, 0.021896836415473974, 0.0687103646416818, 0.01095857174556342, 0.042909147713573716, 0.054970401519488905, 0.030828257158939398, 0.07392395302773484, 0.06047573916974568, 0.025329166955705133, 0.01602896106159014, 0.08314233498587724, 0.022123709523810015, 0.007606901166464894, 0.03079256512254717, 0.043671914646702434, 0.02939952616279404, 0.0194430357265857, 0.006309254038628312, 0.015372829737081645, 0.013630193256352459, 0.064759541963858, 0.08097862689605645, 0.018533494008044084, 0.05031529889111558, 0.007317898806274659, 0.016360809282970526, 0.11234071135761277, 0.07351814859336422, 0.06461864307282433, 0.020259965075961044, 0.027447133850786957, 0.07149645788294655, 0.0253525881787702, 0.014754792134607992, 0.05102227547115857, 0.015778772067278624, 0.03813718603323064, 0.038269393656763344, 0.04570158799329112, 0.050638764195384524, 0.025057916289135337, 0.006061654900305815, 0.040010791947884906, 0.0071661889782145384, 0.06883083962865415, 0.04769194187716611, 0.04225305469346143, 0.043855285452258204, 0.0688203442240915, 0.11704826802616158, 0.016123946388101867, 0.004905939924590771, 0.022809645499012644, 0.02064617298122856, 0.023796832143899896, 0.05276305706150109, 0.047681863990522204, 0.03789329045121709, 0.03318675651004718, 0.04927791241977004, 0.027597649060490153, 0.02442790090196556, 0.03526458614355615, 0.09168644465746419, 0.09293404182479267, 0.006482518708047968, 0.01910628454248992, 0.08471249347372402, 0.020532054608807932, 0.03909206100469155, 1.965483513570601, 8.551155290296002, 23.8355786954203, 35.428212381178334, 41.69861532026722, 42.25558796236592, 34.5423529225011, 34.00462342846778, 37.24590147695234, 32.33467824997441, 29.20814717969587, 31.731937431520034, 28.32873021402667, 20.638719527952134, 12.96006900648917, 6.954769751717968, 2.870723403269245, 1.0468164927536443, 0.2560741889981493, 0.12317491064388907, 0.018753564255612514, 0.09114973877947177, 0.11007383420702913, 0.39168518877798514, 0.5599963604923218, 0.7334537431597711, 0.3676512639128393, 3.6897169918783255, 4.471199483640732, 2.961024944820712, 5.5115547295539615, 3.631310448531182, 4.690611477821104, 4.022434002930119, 5.643275764680678, 8.360386894595239, 4.83645010379053, 4.174862946233442, 4.265326040406381, 3.422894328832627, 3.443589734454309, 4.1137151564321215, 2.5275799968550285, 4.1072802630163014, 4.228408202048271, 6.181129303670699, 6.385575984754871, 5.42722475144171, 4.727588642028071, 5.8831821430114015, 6.4457941728253525, 5.162816307237072, 2.879423220311442, 3.6736482670230255, 3.8613152936581647, 3.6226672607083477, 2.8661001545767633, 2.9882817402962716, 2.5818526071886865, 2.4422892831986953, 1.604725968453192, 2.244394676339242, 0.19979985220538032, 1.0785172110603702, 0.508119061949753, 0.6050549555690058, 0.422140370693899, 0.2429666391183292, 0.08793223844540697, 0.08051136688840005, 0.015897817342662286, 0.12129269390096589, 0.1934812356147074, 1.3020426683848905, 2.2370179237857943, 7.021555948641993, 16.855787654076856, 25.099776252623528, 27.044044156228345, 31.62721407028937, 26.061943461818082, 31.124646663665775, 34.32806599524714, 39.17105567070746, 42.519955711980025, 33.83416506551927, 17.622046201459824, 5.379554715848738, 0.8359134065047388, 0.18278240406465146, 0.03308425777621808, 0.035635598694845554, 0.05191721172342378, 0.06651528525136172, 0.0480272623920633, 0.07238465256147808, 0.029674750910471046, 0.034485352150495016, 0.07163580927637316, 0.04751188440188285, 0.04367700147051965, 0.08006210994696425, 0.01923941338675157, 0.03321566483786991, 0.02207822305330586, 0.020388346090311968, 0.04641739373666145, 0.040433982747697064, 0.028873555091840607, 0.020253627613607435, 0.09823832736020127, 0.019761483154950604, 0.02933551951672041, 0.07661417802615512, 0.07035371516981433, 0.061915279666502634, 0.04261846331158473, 0.042728508011468, 0.02634116718845983, 0.04024534125722224, 0.0657190517672608, 0.02652098526126675, 0.019067794369954257, 0.031031050208595493, 0.021791428462752414, 0.11150569084190554, 0.048880439191575975, 0.023862411185438116, 0.03637082476709639, 0.040786747084630114, 0.10083216317598859, 0.08959215945534169, 0.15555337161546753, 0.1411935284493431, 0.2245964022773889, 0.19665945862089435, 0.12745803928062802, 0.07634483683373659, 0.17065163161004746, 0.16741864863903294, 0.0912643378720649, 0.2015389943675649, 0.17856464571049138, 0.17513906823531275, 0.21076105354774385, 0.11624213668607897, 0.09854517621739257, 0.08542263399689429, 0.16583851568641203, 0.16012978169225878, 0.18026407387468124, 0.17518773014026304, 0.14301743057947006, 0.1246487565578953, 0.2059331521271698, 0.19087477466992794, 0.13166567761330836, 0.1128331603362195, 0.06846242794586767, 0.1347914389184406, 0.18114057039060902, 0.13719030535749852, 0.11786055105227618, 0.12199962451573342, 0.1586933668342329, 0.1442741671757352, 0.07780757447284076, 0.08552882910495804, 0.1382095700189952, 0.1776724903573913, 0.16680682017918558, 0.10245634618425563, 0.18966959579096687, 0.15089990841525217, 0.15448388222965503, 0.18465409475949504, 2.4680411142687646, 10.463084232422615, 27.247856393937145, 38.54238602422899, 48.028046008079286, 49.0344516692623, 43.538744295797045, 43.36034313324959, 42.282809211361794, 38.535117872299686, 37.12597893130395, 37.553411376091745, 35.50161169421288, 25.68155004132179, 17.25673821664626, 8.668190971497568, 4.2109928784831885, 1.85264440073121, 0.5519960123685099, 0.3138555586338043, 0.25377705903543585, 0.43500776733121566, 0.4823747691848586, 2.0308561863437777, 2.9959475225017917, 5.767005951173845, 5.442971596794744, 21.77335923717868, 20.052980223009666, 18.55545263136587, 22.375823528535907, 15.841878498754195, 10.180880485042449, 12.09226421771511, 13.528418483272677, 13.495063627919844, 5.225000093060156, 6.279473420112364, 7.089184964856795, 6.399050306889319, 4.666787491690728, 4.433967855668837, 6.233715539978397, 5.354950178054072, 4.560107358040349, 8.374208346489938, 5.766030261593481, 4.6793675134258885, 5.433977601989623, 6.989025281321618, 8.672876242668398, 5.462248575302863, 3.081133557904151, 6.442110576937276, 3.3906764705334944, 4.908307925347359, 3.988638371229172, 5.926352729720454, 11.773361794410214, 6.500690685164544, 6.336781699811259, 5.397992797436253, 5.160759514377964, 4.60965326716823, 2.2472111832711006, 2.0823512682991643, 1.1602025310839377, 1.2998288581448219, 0.5577416718006134, 0.6395766547610683, 0.7568638579499337, 0.7034403794715482, 0.7916069259085964, 1.7975254164588068, 4.038802543955465, 9.345676475955594, 17.749129033857777, 26.991598144654308, 27.649232533670244, 35.7873720507468, 33.91158088561028, 43.62229470283755, 41.8136937387528, 48.13293410885719, 46.88636172202326, 38.48342103342856, 20.0490794258733, 6.601827038872627, 1.2116070308031575, 0.24652278861932217, 0.18674687842928595, 0.13288913535014277, 0.15574360656882488, 0.2272259377904477, 0.17077405246034746, 0.1980623647931122, 0.14013029034099272, 0.12589420101815654, 0.19057250701852385, 0.13693055558589198, 0.10265372107706724, 0.11231216692155409, 0.1034688616111394, 0.22297206605153702, 0.0773732485850492, 0.21100062456342483, 0.16752849032561626, 0.2031229577598072, 0.1896269859806184, 0.12035756101531368, 0.164615195845404, 0.17932071320472226, 0.14886378460834104, 0.1734554061606046, 0.15189323333963273, 0.1796852484826119, 0.14730862612205167, 0.19808280401893202, 0.28279446245681855, 0.16992124338303843, 0.27503123386732997, 0.09371963434762533, 0.08367295046487162, 0.07655147372955277, 0.1128647844457338, 0.30613982749562113, 0.1653453848895527, 0.16001557330450705, 0.14258443768466675, 0.17076824551388142], [0.042465713040362445, 0.03037750251561163, 0.04510849038319242, 0.07076911868587618, 0.07715542680553852, 0.018664563991009228, 0.018816205349961118, 0.0605506242643441, 0.062213873926309816, 0.05381363556690274, 0.059556448982367595, 0.0254267186767632, 0.02344216599369482, 0.054386412694809906, 0.04057996846254795, 0.058588676920701424, 0.054460079709608714, 0.03694077886100258, 0.14845863134870607, 0.022032177338616985, 0.02231139723481911, 0.03089629534271456, 0.0361258490011096, 0.06213405905591865, 0.07294768888142801, 0.02190930641166145, 0.029066695433650768, 0.0322520564640722, 0.1552000365430309, 0.03253376614602824, 0.031686076451273214, 0.1557499804203549, 0.04086909770605065, 0.010828402873519207, 0.035078465082352205, 0.03948415246521754, 0.029212979922792124, 0.03171795528502234, 0.039944498529357296, 0.0770014354718789, 0.023044348025934833, 0.0445016797992491, 0.045193223538057464, 0.013302796005812145, 0.09468149604095567, 0.010233835332215795, 0.03520158690310294, 2.018197594631103, 9.457239470174237, 23.15907770587552, 29.48761605447339, 35.729701442103234, 42.85080763601488, 28.502971703006377, 21.996424428878292, 24.442826317202663, 35.59143004878875, 32.499557041352794, 30.50786375999451, 29.94254235298403, 21.94390585345607, 15.697691190627316, 8.120110832875776, 2.999465643398224, 1.0385366144680208, 0.3706382100860919, 0.08116767441313114, 0.1211350559887867, 0.10270190034662524, 0.27607510527295454, 0.033375692944372856, 0.3081633108517816, 0.3669155437138773, 1.2065351610222173, 2.741174625773584, 2.8424791511028045, 2.9892495851362906, 1.5496604264743867, 3.1139726215793244, 4.950632750988007, 4.212581928699247, 4.643613148120142, 3.5742377561907617, 1.5830688466948848, 2.8970888401231463, 0.9946291737498777, 1.9301157468749632, 2.7079582791174612, 1.3752387536148871, 2.0659192339066537, 1.908093476968427, 2.5589381206420163, 3.868144140128167, 2.739109252729724, 2.7739587762663445, 3.8060213961908897, 1.2539164121112516, 3.7980727130366914, 2.1605574459798875, 2.3434389358566654, 4.035721277036975, 2.6437047075840736, 1.518555785859785, 2.0588785794473465, 0.9893764459317731, 0.9006171925894676, 0.9401758279531234, 1.4762710419393357, 0.7132133324780773, 0.30577578251400306, 0.45465161002451376, 0.281404533814038, 0.3132056096388448, 0.21825857220157502, 0.09182142168884316, 0.018561475369478428, 0.1521555112013894, 0.7893376509028097, 1.4664957600255168, 3.6949305572817406, 7.284174811455512, 7.596123362741164, 15.976310872262525, 15.376730503574496, 20.608325081486857, 23.103568323196907, 23.27294803434803, 32.804711557203724, 33.60689901536511, 39.43480760820451, 28.17538319095489, 16.99538480850958, 7.822599055305605, 1.417146091980319, 0.07695083536448018, 0.05162461593206372, 0.08263476343164522, 0.02094624196028998, 0.06490080857709532, 0.02143038080013808, 0.029361533947409164, 0.048072427105639255, 0.06036612730953963, 0.018850535665067936, 0.04755768496843596, 0.08428703888409561, 0.026369868672542998, 0.02522244707741324, 0.031554037367083856, 0.09822852909564973, 0.097699606670968, 0.03156474536104548, 0.036143174079517205, 0.029018581281566334, 0.022115679007143747, 0.019542866559218497, 0.04441587412129006, 0.08984690667280266, 0.07282387375110581, 0.0475963685781725, 0.0559355995257295, 0.06299750909449593, 0.04200264353365187, 0.03425895018623241, 0.01185458243614243, 0.042341564661793174, 0.02983878374159817, 0.014056181234698144, 0.04032082773084122, 0.02917363173178127, 0.031496529061827934, 0.05036147484075158, 0.036166520609009656, 0.029961760005643292, 0.005117493189661013, 0.03049224333447074, 0.06125637510370824, 0.03845002569798981, 0.013474762635005098, 0.024284242179184675, 0.06917866652891522, 0.006902780179159657, 0.02260524366471556, 0.0530768696579241, 0.0763479701333469, 0.03237391040930825, 0.051719564869399035, 0.02176358691236425, 0.033707543080973054, 0.08160993697181826, 0.039296005101453875, 0.06314529511596888, 0.026941058083227085, 0.05958508917941682, 0.07939478607788202, 0.02190403189630278, 0.030885192813471924, 0.055829105643375274, 0.019921825357502507, 0.02178101924308125, 0.04023190790546998, 0.0084575149230659, 0.02790186066000212, 0.048871016310107325, 0.0853907800610027, 0.05549685714105445, 0.05891069048835386, 0.014950922134542658, 0.06499088519523222, 0.02384213283808241, 0.04472399468443567, 0.03912212995571956, 0.07395390706557421, 0.05660903677644749, 0.016900211790456407, 0.03239644105516134, 0.017710740475224394, 0.019386622927061493, 0.07814638451823304, 0.05985747940177399, 0.0449620871504228, 0.037570277138823466, 0.11423235864288385, 2.561869847197687, 12.134505202693324, 26.929479568235337, 34.659867132863695, 42.22496209606048, 46.58843417321482, 35.1228323290425, 26.59743916603827, 30.21799668189018, 34.77979752325243, 35.90992258441064, 34.25484318887034, 33.19896859507407, 26.903605653393655, 17.980660661574333, 9.320163419169765, 2.732366208107241, 1.0372975132157727, 0.3182245580659759, 0.15613596616012437, 0.09062681482323716, 0.036694830163351955, 0.23717663851716828, 0.19231046940530502, 0.21118428648239185, 0.5990236372716966, 1.737570149763938, 1.7861625552177431, 2.8978198718640114, 1.5886422895616101, 1.834291017824604, 4.239139316543456, 3.3582779380582997, 1.7879686841080267, 4.656691801163459, 4.62912489329615, 4.447560339204727, 4.57467504086033, 4.2139214181130935, 4.041093453284233, 4.33913916349411, 2.322678565979004, 2.218909811589026, 4.011030201950382, 3.989800128244585, 4.080714785283612, 4.973143233406929, 4.878155194943951, 4.574565214495506, 2.938644636061884, 2.8173296490023216, 2.6853664075174644, 2.2556320217347916, 2.9963132835203603, 2.525949516604024, 2.420192610832953, 3.065652207982156, 2.8822686547233216, 1.6222030693484892, 1.0152270104135237, 1.4890410534797178, 0.808330747869707, 0.7733265971464496, 0.3746699776139952, 0.8403193926618946, 0.17780434941091847, 0.14898027593810714, 0.1376506935564741, 0.04330331144193488, 0.14567836037566587, 0.6959295921748685, 1.654149916383528, 4.56206658194142, 7.745432796016817, 12.688644912935073, 18.88251946818444, 21.93406462669373, 25.761501673729192, 28.909862695201753, 29.60868589339718, 38.28312520057925, 38.610352854574884, 45.32497598278908, 33.839687762721894, 20.812376583776167, 10.244092422146952, 2.0571238090915065, 0.10128324340668418, 0.07577900429286304, 0.02791511398109217, 0.062250155850403735, 0.07913037083081662, 0.03403571982597632, 0.026903780244831598, 0.02948230770867198, 0.07185114127012991, 0.027587170892905806, 0.0743533912745695, 0.01646480188825198, 0.02468099528472991, 0.04823998585643788, 0.09028913858797281, 0.07130522701528764, 0.04177808018040754, 0.026436280834698872, 0.05241684660676026, 0.010312264541073913, 0.04067191433522009, 0.07046823765361501, 0.04164438634630173, 0.04269527511731271, 0.029878045747717543, 0.06316102673149397, 0.02501491385872566, 0.05042098455070969, 0.0453495820834031, 0.03685395045566463, 0.04373285311063932, 0.02045947352364179, 0.018431611974994024, 0.07963615740018506, 0.013468990162495646, 0.06445617880672216, 0.04733135578252616, 0.057100934171748746, 0.0661515926701888, 0.03897882171816403, 0.07435903734257145, 0.061705463505800695, 0.168040344311345, 0.0945220884656714, 0.08642964891248173, 0.26323954724977094, 0.19439735419807896, 0.1079390076319537, 0.10735922462997899, 0.1264147501018259, 0.19650912152663355, 0.14590169032735212, 0.1354367607423375, 0.09211501722494442, 0.11684299476685063, 0.09638345995617491, 0.14539909068374865, 0.126547459512949, 0.1302868266019129, 0.17892869069210945, 0.20422885164378152, 0.1783002534460637, 0.08101767439755701, 0.14241289527666184, 0.10406529170370872, 0.09963978562624225, 0.2278598449042728, 0.09773508420274143, 0.11387493266093154, 0.11991612583158479, 0.2133533418659241, 0.16314979222032333, 0.15892785102609666, 0.4050468653440476, 0.09966335049079311, 0.1328779351446898, 0.08880549440941504, 0.16046551206419546, 0.11079516727477313, 0.14552345739737635, 0.11444273404777051, 0.12389695617340266, 0.1484811849771969, 0.09093287460986646, 0.2539334788678154, 0.0962340881326987, 0.2533830140507029, 0.07261004328968064, 0.29482964246023086, 3.0184923256597216, 14.644164135379178, 30.938700822091874, 41.623749040788226, 50.3634173639359, 59.04313618136991, 44.076387497686575, 34.47266417164957, 37.84146631917646, 49.259219169616706, 48.1883454322815, 42.919570707505756, 42.0692479225897, 31.44432571626479, 22.14345447478756, 11.435381943179715, 4.599424216055102, 1.62418668548907, 0.7251105553680851, 0.33620693991261147, 0.24681425443099392, 0.2814131752858239, 0.618256121393173, 0.7784845752100792, 1.5924111970009345, 3.481085632116564, 4.642347203147027, 6.169169506719036, 6.553876553812335, 7.157675921916963, 5.600237557964941, 7.7123662348716495, 10.551719011798983, 12.95127897493301, 10.607099936854455, 13.056770140124907, 10.461974201663848, 8.951608692446063, 7.457108189982753, 7.2193841203566524, 7.089218305003259, 3.492080035709566, 4.639626058839983, 4.901635973684249, 5.845147409746724, 7.963778886102862, 6.999220501992011, 5.260514213192848, 5.2673562976621815, 2.7434111122162115, 5.597885116454094, 3.9863182892722473, 5.620389225021486, 7.68887221813202, 5.8997217974355145, 6.166939148979803, 5.461850945026645, 5.33841738777776, 4.091567738402275, 4.455505590285025, 5.341440064291801, 1.815649708432536, 3.908671294489215, 1.9994774701133853, 1.7704249029198003, 1.1648885376991764, 0.8528247667897133, 0.2576335916115392, 0.2940318384958852, 0.46711613634420984, 1.0618267905327583, 2.186237203498041, 5.004611428706877, 9.739609918286725, 13.080453411225351, 24.25935745239258, 25.1997241281694, 33.54187788501863, 35.06900172079764, 36.033512546170144, 45.011613907352576, 45.838237731687485, 52.55186457787791, 40.281078584732555, 24.94143605232239, 11.046384803710446, 2.6255760029439004, 0.250728580680105, 0.19329239494137226, 0.1551778966020192, 0.17838743425184683, 0.27017552345510454, 0.08024489086481833, 0.11669602845945667, 0.11668688136964075, 0.15187331505360144, 0.1180759673157046, 0.17183601886274355, 0.13777849234400258, 0.17862964060998734, 0.13933427902238985, 0.13405988623778667, 0.22151105977114172, 0.20452286086736188, 0.16249046630917058, 0.251759750347945, 0.1349697535436961, 0.15758125231631342, 0.1137376880092967, 0.1491341676803366, 0.23176684735282777, 0.15754968949383305, 0.2592987603237552, 0.10734794781573358, 0.14830964256919202, 0.10799138506333675, 0.1649975350066539, 0.19245107718292745, 0.11466688371353573, 0.13311764405619714, 0.12190313574167029, 0.2131411814761739, 0.1135100679652345, 0.1438253928696917, 0.18231182689628295, 0.18733823701979654, 0.1432595143635427, 0.09286971342179084, 0.2955964351854017], [0.016499777632435004, 0.06409628219121406, 0.027496284136788982, 0.01746980390781837, 0.020645556280449517, 0.012144832083234384, 0.010500594808329499, 0.04410150611112195, 0.10924341787974681, 0.01496702626032094, 0.028345454296457673, 0.03277610273911588, 0.008236430566607705, 0.01988905020088198, 0.017569776466717164, 0.04460877889106351, 0.041858661138722976, 0.04744695845030008, 0.037743313418280695, 0.018583701495381615, 0.012846350286816879, 0.03702458121903962, 0.06113901043370847, 0.09895461190852428, 0.017810502359944008, 0.05493057260830557, 0.05880520401162006, 0.011447819434256564, 0.059227352931855194, 0.08947948324343852, 0.0295160653730554, 0.027687356041203585, 0.027546683146107583, 0.038591058654410225, 0.007675015480227529, 0.016272695765139598, 0.100493406756751, 0.044615796256449916, 0.01931925123978046, 0.019866105867549777, 0.01846112359705712, 0.018549905526601983, 0.06107509571818575, 0.015593175776302816, 0.18088437526697115, 0.046913450989391536, 0.07490318959518787, 0.32095069726628644, 3.2744961111776294, 10.933232268979474, 22.410187413615567, 34.740507141236336, 39.51898951684275, 34.14954323922434, 30.87101640239839, 38.546900672297326, 35.525102769174886, 42.75095193616806, 41.2236084476594, 30.726824191308793, 22.1428112060793, 18.335354712701616, 14.249461908494274, 6.581565545451257, 2.8962597491279727, 1.5334980550312227, 1.0068851709365845, 0.3635708957670197, 0.26350544104653023, 0.029063232716233022, 0.16177244274125946, 0.2201253752554617, 0.14792485192658442, 1.3312190963375954, 0.8228652131172919, 0.7717246766532622, 0.6005727896286596, 1.9448983020359472, 4.203675696926733, 1.4929618301891512, 1.9056848965344892, 5.021664423327293, 3.344723942779726, 2.8190579433594984, 2.9650608185798895, 2.496961484993658, 2.603767134489552, 2.197213956425267, 0.37056959925159333, 1.8800218090895686, 2.6502153517738467, 2.5059138046156977, 1.543404000901407, 2.556671726126825, 2.0675038714562697, 2.832357474873143, 2.92962882307268, 1.6261134272621525, 2.4066094429262224, 1.2910095313864371, 2.5031205867567374, 2.399281719999929, 2.8956829155645067, 3.192518084279953, 1.8447806614060558, 0.9440867374500922, 0.39402457615060194, 0.6692467497721796, 0.011577771886462166, 0.3917693665191051, 0.23641765988882513, 0.49734795766492046, 0.07054473153285443, 0.05905308708127949, 0.28125030499312187, 0.5649298441506202, 0.9272065722653944, 1.638281477555152, 3.1869338548952535, 7.442242897325947, 15.353506149784213, 17.97102928161621, 22.756338542507542, 25.6975297774038, 21.283798410046487, 21.38358154604512, 33.81731848562918, 31.08818234935884, 38.62353201835386, 29.42433253411324, 17.937053711183612, 9.302828504193215, 1.4126919955015185, 0.059111175698138056, 0.03320502770704127, 0.012543711082769499, 0.019596680405459577, 0.06744455756439317, 0.046722346526240154, 0.014783268580363404, 0.030825244518177166, 0.04863231863466002, 0.053324683779670354, 0.06659310446271012, 0.029097143598201296, 0.009232482763998693, 0.06042757905238579, 0.07040350322401331, 0.06938243059501534, 0.06824960105962331, 0.03406897570276934, 0.046012772908133846, 0.03364478898865562, 0.03886966184983331, 0.019087258748890414, 0.026737734517683426, 0.022638737028765104, 0.013242413913230262, 0.1040115429749412, 0.02020983036697632, 0.043716332424552216, 0.05873960390266392, 0.0165448427545808, 0.02592376418291561, 0.07060758904704163, 0.020672765808300148, 0.04389115751931264, 0.01889951932694643, 0.0496486300272086, 0.05459993289062574, 0.04810892353435198, 0.0770219283238534, 0.001103491240721797, 0.04878293535101318, 0.04947245278726182, 0.05916166855322738, 0.015904384631393178, 0.056898476285559524, 0.007262420155213125, 0.032597159921762445, 0.06022368475133854, 0.028675869933419654, 0.02689539732772016, 0.053237269317070325, 0.0239449322614218, 0.04232994310798184, 0.027504270603399605, 0.02881535730745283, 0.04186508095552845, 0.10493616513427227, 0.021291171132977453, 0.03539272967065054, 0.05673647167221193, 0.05036445875321666, 0.034788516124770526, 0.009534234263663812, 0.03346637860240956, 0.048162660771800626, 0.08799339524440228, 0.04331994704121063, 0.059865634407727956, 0.06732432772555659, 0.010840546324728959, 0.04899234165467563, 0.04253927280285186, 0.09436302562995304, 0.0280547890466668, 0.04509636321135106, 0.04466958712005327, 0.05466236139557535, 0.05719483739906742, 0.05716912748832857, 0.03245491271598205, 0.025547302831264756, 0.05179294077078662, 0.05193626049966101, 0.04104867637638123, 0.03735549672837219, 0.07009164415179722, 0.03153709533263839, 0.21594567614937984, 0.010292502345457193, 0.04884367463208976, 0.5404185852216137, 4.555338246207084, 14.200319513197869, 26.121104571127123, 40.0164205797257, 47.478565093009706, 40.990407851434526, 36.711709960814446, 43.94938899624733, 45.135419599471554, 49.42292713349866, 48.65186760502477, 38.389515569133145, 29.245227306119858, 23.94604048421306, 14.482709573161218, 9.362488735106684, 4.222652123820398, 1.9851305431896642, 0.7211637316692261, 0.35984154910810534, 0.16122894932425794, 0.14588554119390829, 0.08629259578282795, 0.16545907233751592, 0.14009054569948104, 0.8531086483309347, 1.258137617861071, 0.4932219613223307, 1.4691346571330102, 1.4517469127332012, 1.5555244924560672, 0.806625068428055, 1.9150713735049771, 4.384239066031672, 2.0470794770986807, 2.980458082691316, 3.931959631942934, 3.2775678173188245, 4.499205696967341, 3.253985547250317, 3.2542780089762906, 2.415127605199814, 3.432406321648629, 3.755803536022863, 2.171966395070476, 3.9872900564824385, 2.7382019594792397, 3.1544691324234013, 3.3862164904994354, 2.5095616088759516, 2.831524951804069, 2.3511696823181647, 2.9460647798353627, 3.592896716248605, 3.4068623761976924, 2.207148829775472, 1.596769440558649, 1.575708273918398, 0.6246400239967531, 0.19251729782310226, 0.6289765106574182, 0.7068581734934162, 0.36249861782116277, 0.2514083611388361, 0.23661970791797485, 0.2256452379327628, 0.19657748721299634, 0.5569505174794506, 0.7480828355877631, 1.9070871438710921, 3.932203309189889, 8.2550791002089, 16.178798329445623, 20.466388233246345, 31.53313602170637, 26.944468905848844, 27.19421798183072, 27.872229083891842, 37.67405956022201, 37.39154300382061, 44.728077534706365, 34.59432432728429, 21.685607971683627, 11.293165626064425, 2.727268107475773, 0.15933481225323293, 0.030018791421166355, 0.017665631303022948, 0.018676030412015897, 0.020240493036145647, 0.0270336608762943, 0.04666931025924222, 0.027307035521634167, 0.08030345062575034, 0.0554780381911945, 0.054643324110656984, 0.04643756483170775, 0.06296695367763601, 0.026572397421865214, 0.01847749106555937, 0.034523388415935545, 0.02798902422880694, 0.08515625756474272, 0.016412265493624633, 0.039706658872385184, 0.04563066740370086, 0.05326458418201055, 0.035168955387968215, 0.038539094910506284, 0.03804100369433722, 0.0846654556751732, 0.03618460028402267, 0.049178531663792754, 0.09427252766345778, 0.02921193038233586, 0.011295215677349799, 0.01174038170926994, 0.02040066861457402, 0.04863241822609017, 0.01898785309505559, 0.043427701138200304, 0.021179042673940142, 0.05586046928299531, 0.04559425141422018, 0.027169863648352124, 0.025659559610029383, 0.019870191031406005, 0.020090724762168624, 0.10268534518658154, 0.15385641025439387, 0.08672751155832122, 0.08118825153477731, 0.1530523090473106, 0.17433605487308196, 0.09221891406923534, 0.12657552897449464, 0.19421583732529996, 0.1630950016119788, 0.19613102649248418, 0.1041883867113821, 0.09444774729349921, 0.1784468673530125, 0.11098447526174207, 0.21396256562682892, 0.22765326163461133, 0.12193965515302074, 0.12532182608640965, 0.11787057148232577, 0.10699398455119903, 0.12392886373544894, 0.14050660805115778, 0.1759146403280958, 0.12699503872183063, 0.1295596406224274, 0.11928937397897245, 0.19936174184324282, 0.20598484774030026, 0.21401409270061603, 0.09669346509561424, 0.07797193097611589, 0.09513089853909709, 0.08526388525722489, 0.12581258201070372, 0.0969440371338879, 0.24407864638393928, 0.17791108078052922, 0.1215893614496435, 0.1558295156686537, 0.1742824746836578, 0.10715693145269349, 0.21598508371220482, 0.08488041228584706, 0.28559837490320206, 0.12911796029056274, 0.11810651124124566, 0.63180472341276, 5.12212710995828, 16.364600023915692, 29.920514322096306, 46.35224865328881, 53.332577059345866, 50.395086580707186, 45.619522448508974, 54.8441957658337, 52.9036815704838, 57.11439301890712, 54.546852650180945, 44.26275107168382, 35.90511375857938, 29.01549016275714, 22.3047560645688, 12.351959443861439, 5.321301144938316, 2.591054242464804, 1.7628096212302486, 0.7461225698071142, 0.37360422673725313, 0.4556790258615248, 0.2996213692090204, 0.8360956741436836, 1.2552084653608262, 3.2154936127124296, 3.2598561096575955, 5.173187544268947, 4.688207064905475, 5.212779458492033, 9.239665596715867, 4.986254246004167, 6.001764708949674, 14.594164702200121, 10.644308520901589, 9.985459177724778, 12.450556062882947, 8.144728118373502, 8.025443448174386, 8.023201323324635, 3.241769325348639, 5.354965377238489, 6.624420381361439, 6.736389340892916, 4.909567986765216, 5.7096912976234195, 4.4033998443234355, 5.244505549630811, 7.43177556222485, 5.011486853322675, 5.247918501976998, 5.36985763619023, 7.827947697331829, 8.090413587708628, 8.788466530461466, 9.341217721662215, 7.381853595856698, 6.300575281343153, 4.131704126634906, 3.8089764118194585, 2.0781283465123948, 1.8318527744662378, 1.0919874882505787, 1.98188551731648, 0.8365740807306382, 0.4080268860824647, 0.9066395629798213, 1.093905649838909, 1.1914667631349256, 2.693680851690231, 5.266222732682382, 10.925120807463124, 20.863357590090846, 25.064863235719745, 32.81028524521859, 35.735514394698605, 31.180338436557403, 33.522026769576534, 45.70232760521674, 42.658285940847094, 52.03758693510487, 41.9821281586924, 25.580831420037057, 13.634645092871882, 3.1404986304621545, 0.3631656352550753, 0.19896340676613394, 0.07095529337323482, 0.18133546315854598, 0.18868786943775995, 0.21083108930578157, 0.11807188406706819, 0.11837994334317985, 0.1819674550525604, 0.13268005463384813, 0.1864415617479432, 0.15301653274124669, 0.1208199410428924, 0.311116457225815, 0.1325436143745338, 0.1422287430614233, 0.14484430513074323, 0.19797150676529254, 0.0932220142755297, 0.1528025337404782, 0.200173381355501, 0.11433926621271719, 0.09624746402785664, 0.14409879432810893, 0.15055336088182467, 0.2082136733036849, 0.11955065592642754, 0.1524181567853497, 0.1926787585140236, 0.10419387190091996, 0.16727656997259588, 0.10661994978304833, 0.07410951484475406, 0.13938666411465214, 0.15067291656328788, 0.1679122850539223, 0.14842031163073358, 0.1759109324625423, 0.15280883098321577, 0.12633878482325425, 0.17999064177274707, 0.19369895780278792, 0.19438387105061164], [0.07347587586170243, 0.02860072436892698, 0.09827201990711112, 0.05714292728131818, 0.04489272938019807, 0.02059215037602811, 0.02481229892451196, 0.07247358004772857, 0.027388667935625683, 0.03327599426190699, 0.18166662764645394, 0.016731388994582718, 0.022734649321665207, 0.03487367062799392, 0.03312802820977184, 0.03550607620948746, 0.019519211679336526, 0.10184560556926074, 0.06390898518504635, 0.10980140568027574, 0.03552559612979812, 0.055523153109055375, 0.04205668720627024, 0.031645747667719284, 0.0302389899884621, 0.005568750099384136, 0.03916279773317999, 0.04894720758461664, 0.05125428519902691, 0.06398633325232134, 0.03537662267204254, 0.0125347267866375, 0.03104362937231218, 0.0614393322217849, 0.01788624930345724, 0.0076255654623251295, 0.03191531868651509, 0.08207130576333693, 0.04865153211980097, 0.011493572120314405, 0.023068441491153453, 0.04246260272338987, 0.04204077172964331, 0.06489329325455813, 0.036763364389058084, 0.01645029409818592, 0.018362863244669094, 0.07190329653601493, 0.4404627730048472, 3.578752894555369, 12.533244529078084, 21.96406683614177, 33.11512793264082, 35.22501399440151, 39.2463691003861, 38.096722402880275, 33.695187645573775, 37.22149256737002, 33.16178452584052, 30.946039576684278, 35.91886951077369, 23.174094500080233, 14.508731557476906, 6.612292903084909, 4.777511098692495, 3.707558873199648, 2.109086633689942, 1.6836541073937572, 0.7860896219649623, 0.278480866503331, 0.09387088308651602, 0.07971671154542316, 0.13308686264339956, 0.557508964932734, 1.1636805702601711, 0.7362903522387628, 0.4604571468887791, 0.608029521761402, 0.3689421220652519, 1.5026771733837745, 0.5478252458476252, 1.3921756705930157, 1.0674202129725487, 2.5003712504140796, 3.5277108463548847, 2.56797133914886, 2.266548223072483, 1.9083730684172724, 3.3672128521627, 0.695085792291549, 1.2598912850503, 1.4458126118106227, 0.15531263614614166, 2.235015553812827, 2.698042037025575, 2.965878877908953, 1.877116558532561, 0.7067735360995416, 1.3848019823912652, 1.7654510923931677, 0.9240856526359436, 1.3535202222485698, 1.4631281600844477, 1.667839110858979, 1.1882598577968537, 0.4365590953778836, 0.26050412306381815, 0.8611712640812321, 0.7715542986989022, 0.12956728617991173, 0.16513109477537294, 0.3034406545902452, 0.13051430875014874, 0.18304071359096036, 0.47984625002549547, 1.2063851303631261, 3.4178550637537435, 6.3139687045927975, 8.3926748652612, 15.447325321935839, 24.117854026056108, 16.536734219520323, 13.907615580866414, 28.13412574029738, 20.495676571323028, 21.272917755188484, 35.918587100121286, 36.487220948742284, 28.41699923238447, 18.112593504690356, 10.953722730759653, 2.7219920292977364, 0.30515825435999905, 0.05747418753021667, 0.05658550638585322, 0.04256507847458125, 0.0029320236541435967, 0.025928067681830258, 0.02647587608906531, 0.03198135355036826, 0.009849420072691096, 0.05346869681811622, 0.10648534813475226, 0.04480806134280659, 0.023992339697396083, 0.07183925158554508, 0.03809781294436224, 0.04852364523216121, 0.03432478395200545, 0.05458625056029809, 0.11706007344107475, 0.025636580802740592, 0.03464632637558445, 0.04345523433819894, 0.04777777053776288, 0.03893381405261256, 0.04883292258807248, 0.040218417097123406, 0.0662305916569406, 0.14391796693446177, 0.027132880753807487, 0.07767040642999834, 0.03736746302174945, 0.05456360117081673, 0.09449661604218906, 0.04673017977526592, 0.02609324006874475, 0.07513690003824812, 0.05550259130916769, 0.05201797143766477, 0.04711585524942606, 0.024242955785725388, 0.037445638463982654, 0.04185322957533983, 0.07372264810387166, 0.020244179834281246, 0.0430502113135111, 0.022138240296513807, 0.02792129056498168, 0.01863490106658109, 0.04232368800008009, 0.10260406325781539, 0.01589849628808518, 0.024019302161891135, 0.014942643596910903, 0.04536198887733683, 0.11580129139005177, 0.05106723717143459, 0.03033933793044379, 0.048960660088567004, 0.00685296196024865, 0.03526151030054016, 0.033144372695636366, 0.03261680624658062, 0.04623197364590822, 0.030149386429618445, 0.02111636135997551, 0.016046833892863606, 0.02671365445900348, 0.015153428858837054, 0.06616518306996554, 0.06289678385421153, 0.017317478815394065, 0.07437623601647154, 0.012060172664332054, 0.04417429212480784, 0.07091923361463894, 0.05883531892792352, 0.058942115415007844, 0.08582032556014677, 0.013812612197662314, 0.014213199573268574, 0.06435697808140708, 0.031958738634843505, 0.03626143890282801, 0.01584472266146012, 0.03623481734745926, 0.04359601831604396, 0.036577718302367196, 0.05441038741640026, 0.0469934803644015, 0.036687778324008956, 0.004125276219940955, 0.09718858006019747, 0.7786608367196975, 4.763420964440992, 17.274989005058043, 27.106166655017486, 40.92736359565489, 41.75831379428987, 44.95302938645886, 44.655615668143, 39.79603828922395, 45.70332388724051, 41.204847751125214, 38.802537225907855, 37.864137618772446, 29.150396162463775, 23.71553259511148, 13.005846008177727, 7.257410518584713, 5.555827502281436, 2.7663204506520302, 1.3958155075388572, 0.8057013502524746, 0.33446093360262535, 0.05334062223893501, 0.10351074363795981, 0.09281932781901091, 0.30238713047677473, 0.2685510493334263, 0.25982435792684555, 0.6578136535902178, 0.6852890599158503, 1.0755283649890655, 1.3577176486292195, 0.9030353950877344, 2.7971375325033745, 1.87537171667622, 3.4385288963394784, 1.8826966203989524, 2.4805046906394344, 4.145271605060947, 2.0753819519473664, 2.6705449963769605, 1.9802858031565145, 3.4655469175307982, 2.302693844802918, 1.934020343807436, 3.039233083686521, 3.7737775521893657, 3.220643194452409, 3.147432400334266, 2.7416210405288206, 2.62117289727734, 3.0812857948964645, 1.4687093251174497, 2.250160070196275, 2.6767244454353087, 2.473112984049705, 2.013633181491206, 2.440330304445759, 0.8041496851271199, 0.6871605820713506, 0.25154919874283577, 0.28554603577621523, 0.09224012704385866, 0.11120727661276057, 0.08647978170624665, 0.2018145255504116, 0.29498653726712354, 1.1771932580778677, 3.264591391048124, 6.802340563266509, 10.31481275635381, 17.713329561295048, 27.935114483679495, 20.927692305657175, 20.80042512186112, 34.18290299753989, 22.444441472330404, 25.201244046611173, 41.88731662688717, 39.87350117775702, 35.26739128174321, 23.4996884868991, 14.215553998947145, 4.144990665297355, 0.6495280756104378, 0.029213571725713632, 0.0546514714557317, 0.08447384942443141, 0.011865374699775732, 0.06754971845375915, 0.036793747436135046, 0.011911084293387832, 0.031026604983414856, 0.04413153675775375, 0.051556874607359214, 0.020358970448855433, 0.007455493943134864, 0.01397192592717587, 0.06031445850948654, 0.0678254334977077, 0.06487673043363518, 0.043971608242680954, 0.018888912839634765, 0.01732479303985113, 0.010608375718396519, 0.0777428630258768, 0.07657000539644111, 0.04698614507252651, 0.11928068654191111, 0.05756027666070769, 0.040674587982075835, 0.04022887802772945, 0.03589424529984113, 0.07879143821135645, 0.01697294800842722, 0.03545692400826562, 0.014076929768517375, 0.05640793869632387, 0.010223381104879081, 0.1281092982859381, 0.042722030738068205, 0.03819730478308855, 0.03179109752959302, 0.05702946965973224, 0.04539903305891541, 0.036144476428988485, 0.06502227181748998, 0.00585932006698943, 0.24111422319566053, 0.12275245911892384, 0.15788065479888072, 0.15363101186531206, 0.15963645171253912, 0.15993485828080486, 0.13833419720251716, 0.1660393379748829, 0.12729287072415316, 0.10988419680225273, 0.2292200186920743, 0.09838596016408936, 0.1499331207765687, 0.11135285630101159, 0.07776402237434542, 0.11468998126445279, 0.14084160297868714, 0.2525361498156863, 0.15908765696710156, 0.17305491071554924, 0.12802793208750027, 0.23883978475726422, 0.17350497204930554, 0.16558052791703134, 0.17575163213956743, 0.17825058030505336, 0.11951299504406991, 0.14533830926783625, 0.11165391353349532, 0.1054207923551721, 0.11254862762026249, 0.15914800937377638, 0.13584533075411476, 0.14237649077850004, 0.10286205868807533, 0.16244790246409757, 0.16002920966955925, 0.2730384246716576, 0.1416601066387469, 0.1694519838858997, 0.17951661720871928, 0.18450208759355932, 0.08829423797226722, 0.15500385674738115, 0.23045896672673766, 0.168925681481919, 0.16199162049639612, 0.19962634861228928, 0.8398333864827311, 5.369752712788121, 18.807368816867953, 30.311700144121726, 47.82307863235474, 50.9589861285302, 55.65824839376635, 52.71836919169272, 47.8893353093055, 52.409168751009055, 48.225262780343336, 45.49363005545832, 48.60301840689875, 37.92099629679034, 28.202049424571378, 15.76121299497543, 9.704708668493456, 7.841914276922903, 3.932626189724092, 2.633009384716711, 1.2374494441093937, 0.6437061138210759, 0.5248867960706834, 0.6443827839628343, 0.3404134674178016, 1.7718451686443824, 2.349364411446356, 2.6852200540804096, 1.8876464064082794, 3.0241172496349584, 5.071395664445816, 3.913987086665246, 5.079577238328996, 5.6636740507618075, 5.553857982158662, 6.801306528429832, 8.617271742513104, 10.613942511620062, 10.935831819811176, 6.9301573691829566, 7.849487883429374, 3.695540976139807, 6.736470239777719, 3.8501434028148656, 3.940642533763763, 6.255851436045862, 7.378053799752267, 7.672256567785817, 5.567917227745057, 3.7117776274681096, 4.944032382580542, 6.2735143592280735, 6.5576258494007975, 5.58985504411882, 5.097766249410568, 6.151663478343718, 5.199451734942775, 3.673925039268309, 2.742525882297947, 2.419125726146083, 1.7644550555175351, 1.6104156115362722, 1.340076911353296, 0.885265832466464, 0.6348772875724301, 0.8144960396232144, 0.8215378585361666, 1.7961818821007207, 5.55334170018473, 8.305436449666178, 13.165094237173758, 19.41436148458912, 32.026795725668634, 25.25084633981028, 23.743706980059226, 40.052471083979455, 29.237757152126683, 31.09647031753294, 46.81135423721806, 49.90544534498646, 41.60609053027245, 28.23477375891901, 16.969079432948945, 5.306890356925226, 0.9409603019875865, 0.1764698089250634, 0.2710482814619618, 0.14010595938851758, 0.12001570960086201, 0.18588149018826025, 0.11705561480935543, 0.11029000123662334, 0.13011405845322918, 0.08151139508211806, 0.1688900124281645, 0.117108796633059, 0.16471075765307874, 0.20591216131804452, 0.10654990636413136, 0.13061026892354413, 0.20900308094438047, 0.14892476520711376, 0.14349320182396522, 0.13908815029407703, 0.2504090607286461, 0.18162243969498143, 0.23825253239802777, 0.1446704644589655, 0.24558164960434362, 0.14514004571303246, 0.10674818524069364, 0.21363518561326691, 0.21028385737970953, 0.1544770946906459, 0.11181590282508444, 0.2254819233090647, 0.18404978928306412, 0.14394306397486117, 0.12397348069615903, 0.21228146228578784, 0.08973989185065993, 0.12251424407886884, 0.16940488480031493, 0.15326358077506866, 0.1146109133297878, 0.17506013053559488, 0.12748644582086033, 0.11218822155628475], [0.00876757943431937, 0.04279786195125311, 0.0572803289809775, 0.016255349619314075, 0.01316647161729634, 0.02100706742625804, 0.06339349611211689, 0.05525975292848964, 0.06417287566188364, 0.03597350475648719, 0.033517039996842225, 0.03395672083922452, 0.09176748909897382, 0.021299804943884094, 0.07153346759056853, 0.029506820607029145, 0.07887069000712327, 0.03528288415362758, 0.012902155004051185, 0.08665840276667187, 0.0547076142092626, 0.012800752733563705, 0.0346419328613387, 0.0221004759922864, 0.04446471222646294, 0.031394204613001596, 0.026432584460464217, 0.03753349342713914, 0.03893879745456, 0.09089940422845465, 0.05910565986508324, 0.029452194707588326, 0.05282502208325652, 0.023678006161184564, 0.07438703019532465, 0.0655684465422265, 0.011583525206773512, 0.06872108987262172, 0.04776906394850343, 0.04687499337559266, 0.010902295884255682, 0.051426428986052354, 0.02550861156064897, 0.021973784201808517, 0.065471567063322, 0.04582604280703011, 0.08318472263072768, 0.06638857430868572, 0.09563480053217181, 0.964551765111185, 4.218943522822473, 13.150738362343082, 16.929622350200532, 33.899390159114716, 39.83021782290551, 42.96331297966742, 40.61834358399914, 36.069821926855276, 43.12291029960879, 33.30417440783593, 35.71555737526187, 25.64171248866666, 4.305282244759222, 6.712904149486173, 5.58734227572718, 8.82247151867036, 5.137117428164329, 4.368279922393061, 2.5582323391591353, 1.2994606456448956, 0.8072178979073802, 0.2040635451914803, 0.048863742305266286, 0.1401584364113308, 0.08820175583804808, 0.19460989763179135, 0.23104222010700937, 0.31600333209480014, 0.37504735252549576, 0.7980496027777273, 0.8078951196324441, 1.3350219567937236, 0.9310789935050473, 2.760749459266663, 0.5089641182172684, 1.4862241788256554, 2.2678445664144333, 1.1744857194923586, 2.6253078108833683, 1.8229681157296704, 2.650974575550326, 2.46313520977574, 0.5963210016489029, 2.4965285533858887, 1.2412051135493865, 0.9608446962891087, 2.329070068174793, 1.9730777125204764, 1.5578601413196134, 1.153874644829381, 0.756108801691763, 2.1875583068017037, 1.0809995810831747, 1.271072859244962, 0.9798496829405908, 1.8227141422610131, 0.2741807843408277, 0.5588732143082927, 0.07676770204618093, 0.09705083745141184, 0.12442348840376063, 0.08829545605206683, 0.07016955529369655, 0.8698053814230428, 1.579887436762933, 3.6077235206480953, 4.465088921208536, 11.707206118491388, 21.30120785005631, 14.26153104151449, 22.17599249655201, 18.918169890680623, 22.093483478792255, 18.753691181059807, 25.62712323281073, 28.317773072950303, 37.498713924038796, 37.29201678306826, 21.96225077875199, 9.309472999265118, 3.51186201937737, 0.6829706327088418, 0.02258437351443835, 0.014392936249233544, 0.024554100480952093, 0.005190373049117626, 0.016873048227881233, 0.041920526569048246, 0.023931814920938304, 0.05770521666554194, 0.09287872261578038, 0.022623269713573882, 0.018333631244698362, 0.036654602886447986, 0.021906508275518016, 0.056240900885313756, 0.016170478568622665, 0.025529391695595077, 0.03437063814471326, 0.10944178868686, 0.060368322151442694, 0.0312558414729973, 0.047365400729881185, 0.010429964374540555, 0.027476626320651946, 0.018933319126165683, 0.0757559450463422, 0.008801156110430678, 0.014932125209710531, 0.07043553336012749, 0.004983675345072463, 0.07263539313909508, 0.040310719200680335, 0.053523502748219244, 0.07802274558813342, 0.09731110050192765, 0.09387038512936524, 0.009846660240943874, 0.04305588036415078, 0.014872984179565984, 0.05755686756944465, 0.1012341907968925, 0.022959358231615157, 0.07235033182247032, 0.033515500160114425, 0.09436132491476114, 0.06501242758766299, 0.00835734892696623, 0.01683441824429939, 0.06757144470729175, 0.03151768266463713, 0.04450514634710647, 0.05847252650006164, 0.06994518346243328, 0.07032815847666034, 0.06507582902427643, 0.0343005602518397, 0.023280781911565893, 0.08370160215323971, 0.09533880714086757, 0.019004586370541685, 0.0069672852611890245, 0.0910772055748009, 0.057581907153249755, 0.02935316826727602, 0.03684114146557066, 0.04468224289256238, 0.01231953556153683, 0.077933756814849, 0.029008832812729864, 0.03810463495732796, 0.03694793795265498, 0.010803449474605582, 0.03728195994852051, 0.028805183659818386, 0.03239197476256279, 0.019531089872602495, 0.09541834238916637, 0.07190076078498556, 0.02420128060264453, 0.02468468782852494, 0.08936627843086759, 0.023985125064369173, 0.06439411036309696, 0.0425829857798113, 0.054107127681134216, 0.08719950598934967, 0.054672933408930424, 0.05924324159540477, 0.02765032718138349, 0.027278577270466956, 0.051457723677759214, 0.011350644053891303, 0.06580395729190881, 0.11908982339645587, 1.1795483962182076, 5.897927803377952, 17.216928120582335, 23.836625968256307, 40.06162589596164, 47.43973362830378, 47.545869042796475, 47.03515683451007, 43.30514361781459, 48.149404141210745, 39.39735289542906, 42.14123518236222, 36.33406808299404, 12.296030367574385, 10.361689982875701, 8.110015632644776, 9.592340607796947, 6.430833762691868, 4.7539631493629955, 2.706259402536577, 1.1151699217096454, 0.5936366908492581, 0.08250398456209129, 0.08672343597056405, 0.07376597037598973, 0.1585940205522122, 0.2426701171263572, 0.39830568997610005, 0.430782639211224, 0.4821331144100236, 0.3687031026328764, 0.8879975181433463, 0.9618883531901145, 1.8420885671531002, 1.8229784119513728, 2.457078334785277, 1.5598237778871291, 3.186099860937365, 3.212523397899443, 3.3548171818256383, 3.624162664336543, 2.6550930642312576, 3.212120374364238, 2.522508372222224, 2.8367615611322465, 4.0036100581769025, 2.3814991645274626, 2.0864057733166606, 1.618766582781269, 1.5415682090866951, 2.2277079330336664, 2.242453838548353, 0.6752794776712695, 2.078369817426128, 0.8404502404793617, 0.691571164756052, 0.9275807908946468, 0.5073372539012663, 0.235493068373011, 0.0702006891069393, 0.15474513353359315, 0.09341223390712854, 0.0792758739102752, 0.14389458593101273, 0.5628361564970786, 1.6623729203016528, 3.156321226589142, 5.105030969265969, 14.968241145533902, 20.579387795540597, 15.991909157845283, 26.157080550347608, 18.50256927551762, 19.518082680240756, 25.091043095434866, 29.935750769030665, 32.70272012679808, 42.630240994115034, 41.9378092981154, 25.665813492190455, 12.507283341500068, 4.945458164138179, 0.9195498605408977, 0.036919592699456605, 0.09117236135587578, 0.06650823724245833, 0.029949504514074618, 0.034226770662973006, 0.057816559884456865, 0.0032406668328950486, 0.03693724336523203, 0.022433988539682283, 0.12587661163941508, 0.05147353190207674, 0.02193891954037451, 0.04241127100202345, 0.047175380281142654, 0.07241377156347999, 0.019300993449325045, 0.03899542284348319, 0.04805252031092683, 0.03164351260620019, 0.07076965494742317, 0.06050072512739609, 0.06767605401335225, 0.05222108049858963, 0.0368990998474821, 0.018340367072772597, 0.12019822238794259, 0.04169514350172493, 0.04832623969583262, 0.023798458165519183, 0.06839517308699508, 0.02780539295335691, 0.04796853409178796, 0.025819453651145585, 0.020601791592555183, 0.03160488645305797, 0.06749501211508628, 0.04506103889716249, 0.04511489104779978, 0.06416078296399887, 0.040213598404079676, 0.0028339316016964375, 0.04317365106075041, 0.05142441800525112, 0.03982597706659187, 0.1443623285740614, 0.09438024728649086, 0.20708758534202654, 0.12934636174430772, 0.13917390617632097, 0.1288588387110541, 0.1564968548594944, 0.16973948136212366, 0.16069829554086731, 0.10419118293230573, 0.26810475715225746, 0.08869697039406146, 0.14226136308523918, 0.1708092465395889, 0.1684599766327489, 0.13696429409807728, 0.16605397025423665, 0.1753171377124325, 0.14665895291874487, 0.1645968710222552, 0.15538982716539215, 0.10511573614372362, 0.197774606846994, 0.09392047961873394, 0.11426323198623235, 0.10122784758887945, 0.1321548860399954, 0.16695525737539416, 0.16488389352396612, 0.1397753311621566, 0.15314921916973206, 0.19045995338068855, 0.1825121435667238, 0.07503481882233774, 0.23076432937335586, 0.2244500181968174, 0.07053705533185313, 0.28764052016119807, 0.2451420377098745, 0.19830829433856473, 0.1558076515192947, 0.09726072256002696, 0.11933802056216425, 0.14163292583919343, 0.12813842494881925, 0.11371812978458982, 0.11873245870153751, 0.175600896679586, 0.16928690725997572, 1.46050862967968, 6.0391395034328585, 19.357573409234327, 27.159548151877623, 46.14367661937591, 56.338756084442146, 57.07750704980666, 56.906248523342995, 51.70661341759467, 59.30908072379328, 46.65135291314895, 52.26089923612533, 39.01043853452129, 15.22747451259244, 19.691120001577563, 15.356791134803528, 16.030842604175692, 9.319141641739877, 6.549141762718079, 3.5384073949629262, 2.140847045567728, 1.4527031130367711, 0.7520222435555151, 0.39060341134186716, 0.6489160632894886, 0.6032850473157821, 1.2451808034412324, 1.6629693657159808, 1.2918268552710934, 2.7001400147714927, 3.710769088037553, 3.3260375261306767, 4.588375389575958, 4.292788515167852, 7.367549692430805, 5.734884681240206, 5.008178334082327, 9.18413758277893, 6.332249401077148, 6.877185760005829, 8.188946468214835, 6.965778864199116, 7.683746170613074, 4.728727600266857, 6.913409338843438, 7.311989318939948, 5.671581549029197, 8.303502721171226, 7.422333436627542, 5.479565349317366, 5.640624242444193, 6.185575800557291, 4.002411528941124, 5.949747706613233, 4.468432741780435, 4.951042148374743, 6.5837444220819785, 1.2852225644934563, 1.5873702158851009, 0.865808179782283, 0.6953888566743943, 0.32641321060157596, 0.40967103334203847, 0.32469548825775424, 1.2028679900592374, 2.3802653339601334, 4.950593036990012, 6.447386164819041, 15.90589059937385, 26.817678290028727, 21.25469638455299, 31.27511858940125, 29.532268316515033, 32.293485518424745, 30.194682113585937, 38.0031503400495, 39.16709407683342, 50.8901563767464, 48.495843564310384, 32.624804204510106, 15.745642165983877, 5.9299961213142645, 1.26985484073239, 0.14583288030999322, 0.16012372959765697, 0.1746675717614351, 0.11043076223183064, 0.1267152097857287, 0.12334236980325754, 0.11910966507369473, 0.11914480552678147, 0.1382205250763124, 0.16762216755699727, 0.11270995041535747, 0.2154070856950937, 0.1613606704819587, 0.13761349232687106, 0.13948981019277729, 0.13070832817785202, 0.1361069804237735, 0.2656547466833746, 0.12500846548186195, 0.12186750499231201, 0.20414799872425296, 0.12005620500853947, 0.17056461934360767, 0.09957102157415883, 0.12851880292498297, 0.1700163455379586, 0.15044364176930922, 0.10799029721848427, 0.13182635689454694, 0.20501589973367032, 0.20510796818041033, 0.21327538475874933, 0.2540082490492252, 0.16527236138861026, 0.15086852945387363, 0.1002245175562078, 0.14258944789969152, 0.22189514561285897, 0.14715344735210942, 0.1899933292260093, 0.11990039804649931, 0.1390698714362037, 0.16274722833787242, 0.1864749018944079], [0.05818220598983669, 0.04198293975223938, 0.05095889318674322, 0.013406915973211008, 0.09169527765123114, 0.04195126201657038, 0.06304268912983037, 0.08668008305492901, 0.01285615621224767, 0.024808100762686906, 0.001598522893243259, 0.04252953582533425, 0.054176745921253204, 0.01566591486710334, 0.02329491431854906, 0.03987897502919359, 0.05758227104501379, 0.01747326854045593, 0.012219091858564606, 0.038162405647697954, 0.052299462784562385, 0.047360566715078975, 0.05131177243686492, 0.030921434517949823, 0.03268885298541958, 0.05694650616797228, 0.019979931211339372, 0.006201338105564637, 0.005582890646051495, 0.07066029589623213, 0.0738422803941273, 0.03577917506317458, 0.03506350338519101, 0.016036079933626518, 0.0972038711751661, 0.03884281812896652, 0.08193258256200822, 0.06985304606778008, 0.01698099193163216, 0.0430550798022699, 0.04578646670486178, 0.06761921795024987, 0.03499812161129329, 0.0472134740031775, 0.056446304379571835, 0.06310736610283775, 0.041490915952430624, 0.09617525258011396, 0.029345974701667027, 0.13061506463395012, 0.7567223461885607, 4.764064233149252, 10.469014856123156, 21.10429898385079, 40.10104179382324, 46.69028635947935, 45.35898293218305, 43.01194644743397, 36.48861339015346, 23.919919460050522, 19.995358643993256, 21.589415765577748, 27.85298985819663, 17.82413651866298, 17.42060503652019, 12.009639490035273, 7.8798489897481865, 4.5365922585610425, 4.337237304256809, 3.928673176034805, 2.1568694374253674, 0.9746528488974419, 0.45655662554406357, 0.19873305944906128, 0.13525118360355978, 0.18437385979679324, 0.1530336624672336, 0.08984960330229613, 0.39083458603389803, 0.37718869084792755, 0.4432698110899618, 1.3468999968421076, 0.8667597222712733, 1.1806982635490357, 0.9835766700486984, 0.511556008169728, 1.0744573127838875, 1.980681472247647, 1.3231184213392198, 1.8782844442513682, 2.2874277349441283, 0.863262438966382, 1.4603219493742914, 1.5098022813758545, 3.42016117226693, 1.9173659600557822, 1.684925568199927, 2.392050830587264, 1.6058324445639889, 1.7783618189634818, 0.6353871344077973, 0.8042895421385766, 1.0046992462969597, 0.9453201390081837, 0.4544529174604724, 0.19026331393228424, 0.29349527051371915, 0.03605898867751803, 0.1511874365349931, 0.1855661837203849, 0.11488775452298504, 0.5614414474656505, 0.6039099299138593, 2.1223736626486627, 4.157026948467378, 5.6815644714140126, 7.533232079398248, 13.715786184034041, 28.773032772925596, 36.38362723012125, 33.3103560632275, 20.209094478238015, 23.294556371627316, 29.467945368059222, 31.26443993660712, 33.26306404605989, 34.921708876086825, 24.602880593269106, 13.428298023439224, 5.169858922881465, 0.9361518438785308, 0.2557659458609358, 0.04464814048861304, 0.07776592993327687, 0.012098228081970686, 0.029701895320848114, 0.023920857948401285, 0.018549292656262557, 0.01573013889062549, 0.0434503581885609, 0.03899667922767901, 0.008659278542073745, 0.040621643645628806, 0.09015639853333274, 0.10407384124494369, 0.0811504680783518, 0.030601504709451433, 0.05253617629228581, 0.09774882782010302, 0.021138168052740155, 0.00880986557251984, 0.09406988208572711, 0.036080151856426275, 0.047599000090192405, 0.02338781971634636, 0.06532821669093063, 0.005468687525154242, 0.02411278212563165, 0.037662759273042606, 0.09886917778320851, 0.04809432955939443, 0.05044510099856604, 0.07711287062134474, 0.08443192143233554, 0.05862660593383255, 0.09361736160973388, 0.0989034142525446, 0.05556969678089504, 0.04671044535033646, 0.04352355022884665, 0.01312035408186456, 0.04615738732560028, 0.03136227215309778, 0.0014738984628497895, 0.08882460064224659, 0.05597303058170984, 0.0360496768787984, 0.06079817408575647, 0.054350149922914086, 0.04820784846801431, 0.06418764200662413, 0.03641390572151831, 0.020725802075298085, 0.05013886501171416, 0.019827027722532233, 0.07302547744925945, 0.024418169670107386, 0.10996129589095233, 0.0288915045319065, 0.049173893001411235, 0.028885588417911244, 0.028766239580187588, 0.01879777135928312, 0.042190733440821214, 0.015145140745106245, 0.03759571125790958, 0.04362180483557525, 0.05435266652174535, 0.05033080834114263, 0.014871985392434704, 0.03673365166891487, 0.03509269516554571, 0.06781319907355694, 0.09607162386659654, 0.042921550677067814, 0.028438568453214345, 0.014016469151923254, 0.09209285430129498, 0.047161832016201756, 0.06998495108658268, 0.051827537301447124, 0.07643941804886827, 0.06085953006761209, 0.052770568553598664, 0.03704973954647299, 0.06361716314248982, 0.08174763361532843, 0.04039067196689787, 0.047753814968370625, 0.04613141311452754, 0.06644166420183836, 0.015572677178668882, 0.06869429977790964, 0.015854762243707816, 0.039184343956050374, 0.12062067391290782, 1.3933605941072589, 6.712702637718571, 13.722293396149913, 27.779559166200702, 43.69905940947994, 51.97738639770016, 51.56095620124571, 49.524771475022845, 44.81628771751158, 33.35334916268626, 29.449359216997703, 22.83630978676581, 22.33902777394941, 20.61750146650499, 20.04062475696687, 17.04457329165551, 9.65981125831604, 7.253957852240532, 4.8556368677846855, 4.093936359690082, 2.114612762966464, 0.7777399377476785, 0.324432750743243, 0.04135466721509734, 0.052152952299483364, 0.10882262876557727, 0.07082320449333038, 0.24947124653525893, 0.3752081697025607, 0.415506171843698, 0.41055178930682523, 0.803700328594254, 1.2053508503783135, 1.8180332837566253, 1.618657737008987, 1.5244314963779144, 2.084799317582961, 1.4714111027217682, 1.9841462734245487, 2.248471489837093, 2.6109894437174646, 3.9451368345368296, 3.407439945205566, 3.360148173186087, 1.5883172231335796, 2.361512972462562, 2.5511230432218124, 2.5776674382148252, 1.8868745575028083, 1.6063196764838312, 0.6003265383262789, 1.3638392427275259, 0.7755442071826227, 0.5725131340084538, 0.33749240480603715, 0.13995465702347218, 0.22710564666457717, 0.13487135721070154, 0.018880658242250645, 0.06001756879531088, 0.08095255692399318, 0.31667280101007034, 0.5210303094598555, 2.776731646830036, 4.494322836399078, 6.26448457279513, 9.75105147207937, 14.530484041860028, 37.75539775048533, 34.12507157171927, 36.04698196534188, 28.12703997858109, 26.049248710755382, 32.85128185825963, 34.96257605091218, 38.445028874181936, 39.54008794599964, 30.175637045214255, 17.341504558440178, 6.540322803681897, 1.566613645803544, 0.32173602931922485, 0.07746046769522852, 0.02854685881175101, 0.028976461767489393, 0.05483550109690236, 0.03561427080703359, 0.03957626687723302, 0.03402974434016693, 0.04353597617497848, 0.025272807782335628, 0.05505350673751486, 0.02918592552774616, 0.08665123218370062, 0.05329507448139691, 0.07948683154198431, 0.047303818752087896, 0.02001939623075868, 0.09650463974403758, 0.024974885764682007, 0.028976816083154375, 0.05857886716483101, 0.053484926390792095, 0.05989697506471027, 0.08946157210776884, 0.044701146112094005, 0.027895948376446485, 0.1054887137105388, 0.05849256736016082, 0.03287152665096425, 0.006597384973804677, 0.009840589951753858, 0.04824484285387782, 0.04005455472055943, 0.033101069575716416, 0.07140644255184359, 0.0230930405744021, 0.08679482770422775, 0.07496272228778371, 0.050397883169353015, 0.12314032943498705, 0.04826404484769991, 0.05239352305990554, 0.00474331621643937, 0.0170345836123752, 0.06064094220017714, 0.17054940483743147, 0.1231598110509015, 0.183945570681845, 0.1478474464027151, 0.20346299354587832, 0.21670316856714988, 0.17493489048173352, 0.22207051846048526, 0.12713986764391585, 0.2231367902770158, 0.08989655683117528, 0.18617058112736673, 0.1001810267447464, 0.15737256996573942, 0.27884092782774283, 0.1100841227678522, 0.25669062930730085, 0.13936190415293942, 0.11978087300855307, 0.16497038485061738, 0.1952178956520173, 0.16141469500237898, 0.1370640540675771, 0.1310726795946398, 0.09887473958153879, 0.16530994566217547, 0.17647791413530228, 0.16966261209980135, 0.1402277520467197, 0.1066560248634027, 0.15659911227562737, 0.21002597686263824, 0.11425580859424607, 0.12478504359962479, 0.1523301945698838, 0.17422074331871926, 0.1812067144219914, 0.3155948540135738, 0.11367132947329553, 0.19834299812153464, 0.14563297732703148, 0.10270746980583477, 0.1267669130597384, 0.11183439618757657, 0.1660245524779443, 0.17230045200595934, 0.15685167614250414, 0.13210320574862341, 0.15938903595651352, 0.3375257449525018, 1.5038585422500488, 6.64359292676372, 16.024429528943955, 32.37150930589245, 49.46781473775064, 60.41565587443691, 61.05696339761058, 58.62758459583406, 50.191029194862615, 36.241402087673066, 32.500851423509665, 33.555198254123816, 42.583494186401374, 33.328073409295854, 30.171702907931422, 23.831234670454457, 16.321810887705897, 10.0227471897679, 7.541229301883329, 5.569879393423758, 3.3105740720225922, 1.494582749662861, 0.815141698525798, 0.5093512684106827, 0.33344647997329313, 0.3797805808003872, 0.5129967744071637, 0.7767070060776127, 1.3788733198758096, 2.118150250565621, 2.0642757608044535, 3.7295741563843148, 4.243845180157693, 6.796756088733674, 4.396894103096378, 2.499093783478583, 7.441635420245509, 7.3391605577161245, 4.858677194964502, 4.6240851379209955, 6.7872698364719275, 6.984720970353773, 5.071207880973816, 5.101019855468504, 9.829107619101002, 4.7673124459482015, 5.794324769127754, 7.290768806011447, 4.955164559425847, 5.596088180618902, 4.373338799322806, 3.0819991759715544, 4.250624506704269, 3.0305614586799376, 1.527203263774995, 1.0027711562091306, 1.5541054524721638, 0.8829698363138784, 0.3632249304604146, 0.6229734456827564, 0.40177015407431516, 1.2186737935389242, 1.2244249688040827, 2.970004475885822, 5.792530775070191, 8.986435417206057, 11.720409797083947, 19.976339071027695, 35.59876488101098, 44.39301298510644, 43.49938331111785, 29.533109664916996, 34.68062823818576, 40.09280481646138, 43.232438564300544, 45.930923338859316, 45.42855401192942, 34.91759038740589, 21.29224523421257, 7.409586223863787, 1.8786682236579157, 0.3138094707842796, 0.25835919944990066, 0.17687560569855476, 0.09617324542975235, 0.13919227696474523, 0.11893656750720356, 0.1482188305066478, 0.15221040906204333, 0.11841842393961646, 0.14510624591381321, 0.1417774253434712, 0.2072524474633317, 0.30612937805633395, 0.20861243739003138, 0.2004583200980579, 0.1432701629856902, 0.16367073200883406, 0.27533022266241813, 0.0943097748583363, 0.12137630473702185, 0.3841479254826423, 0.22642203576622472, 0.20652497037043496, 0.24513137376596852, 0.23820357937966627, 0.12606585067847084, 0.18950413612108077, 0.18073040691594924, 0.15506923469083925, 0.17855523815078123, 0.2661841747260863, 0.2648670244361124, 0.23654820127112253, 0.13698563730764773, 0.27392199984000576, 0.1454750712840788, 0.18795873759494675, 0.12922449247731319, 0.1421953416279247, 0.15536034810206584, 0.09225184818910015, 0.09198818370820054, 0.10166683129125065, 0.1939990957297625, 0.12066569690021778], [0.046854412423506867, 0.05154474743551785, 0.0833612829146366, 0.026974733393158645, 0.03088605657760655, 0.027924904584764477, 0.044418528615947694, 0.0751488893142631, 0.0631696030858063, 0.02616982779375488, 0.013579949379838524, 0.0379350652257281, 0.017472868259515495, 0.07643560293100535, 0.030735305795866637, 0.001988361337064435, 0.047662144887351224, 0.03921761132416226, 0.0766892163383384, 0.04370845704069061, 0.049455882305459636, 0.04366879666885061, 0.059484111130117416, 0.06870351581563873, 0.015564267448480091, 0.020640482863170967, 0.09181021382251094, 0.0658119016236836, 0.013928855506462917, 0.05193300462598282, 0.054856526379984234, 0.10058103955440945, 0.0022999975255750603, 0.02456010661027845, 0.017859001471210393, 0.03553606855172304, 0.05990187419698604, 0.02172449536080803, 0.0247538713137469, 0.027652659919112924, 0.07816516133325715, 0.08407593569568089, 0.040333514146867304, 0.018204223672528903, 0.03526462827839198, 0.018237186520690882, 0.04742728531240456, 0.040159949266742316, 0.035142816467991764, 0.032711724540398966, 0.02343310317355058, 0.8046913399331032, 4.727705822836969, 11.325344750958106, 24.574119813980598, 39.174507356459095, 44.15820813948109, 37.622547072748986, 31.672382124008674, 27.161652503475068, 23.486691713333133, 31.340310342850227, 22.631913115901334, 22.072492914815104, 22.63568251363693, 17.214804157134026, 16.76903267060557, 17.070511925605036, 12.288198374932813, 7.113469339186146, 5.111163595030385, 3.037634962989438, 1.9148752549963615, 0.7546643275887736, 0.31070408741793326, 0.2041655268159605, 0.07772299070512095, 0.11309061950493245, 0.14629964236049883, 0.2264334504762965, 0.24956202795428617, 0.2498177327816525, 1.385761614768736, 1.1179261222001047, 1.1120983381425182, 1.1362921302357027, 1.7122551726718105, 1.2045180821611037, 1.0912871000266846, 1.3347562162145492, 1.5729491316503095, 3.232843972021534, 2.944194054411304, 2.8740042207702516, 1.2483633165397954, 1.6252313842696529, 0.755040752551248, 0.7556164216610693, 1.2703535946146136, 1.0129595740187554, 0.5336950911629585, 0.2772127151969941, 0.3023051897123937, 0.2974702862481917, 0.15683957195330053, 0.21918515554599224, 0.15580457184583912, 0.19043735378692228, 0.2810266686062659, 0.062032108074955405, 0.44295356999481883, 0.78267642447064, 2.053555923123514, 3.1595402667599344, 7.93866002751935, 10.056530564062058, 13.141002058982851, 17.31413818174793, 8.131598964814218, 28.621797946191606, 41.631064261159594, 16.80288468637774, 30.7060101339894, 35.34406969624181, 39.10558346779116, 33.54217598515172, 27.932382552854477, 15.53665828320288, 6.407724138229124, 1.510705529682098, 0.3403602396288226, 0.0050235128747449535, 0.05646959728290958, 0.048422058142962, 0.026529496498105508, 0.03295727487232897, 0.026845480953793854, 0.05671046298718261, 0.07982007978904633, 0.06443303529052966, 0.02393479691818357, 0.013731840674975708, 0.03210050895089104, 0.025541978520191005, 0.05093474992580953, 0.11103749620698153, 0.04549526136308428, 0.01571588007913482, 0.020276160174680334, 0.09623997168795717, 0.08684890585080271, 0.11032146446767355, 0.06286789850902653, 0.07616522751988904, 0.019643892489013173, 0.08119135419087065, 0.017042200441562363, 0.0633950014748881, 0.05794044779313188, 0.0480308055487131, 0.013730168688080966, 0.07293366181153445, 0.09912946381636205, 0.01061668202671553, 0.011827239800514954, 0.041478344449593176, 0.004552073378656661, 0.018754577406892375, 0.0225906286223401, 0.05909987973169454, 0.04124467997180839, 0.07762516127719034, 0.1405614293030193, 0.045000602220816, 0.038195297632726936, 0.07394537284609771, 0.05574697335701316, 0.03505206952292112, 0.034834205608574614, 0.04565882496535779, 0.0396418210209137, 0.0927133931808414, 0.07036828616213414, 0.05775918372936788, 0.07614394559735253, 0.10757163016786499, 0.016269468619758566, 0.03500280623895026, 0.021963972530718294, 0.031177656454665047, 0.005843164709081213, 0.059767176787699425, 0.03249696711258542, 0.024865304547992927, 0.05049571642772325, 0.0427800350852551, 0.04509565074958148, 0.02455617657922689, 0.00777743999928897, 0.05504871485754848, 0.03840765337489786, 0.028004255971961448, 0.018742318084884076, 0.045841609713651484, 0.10365757971040665, 0.10008315135154033, 0.009877467509208909, 0.09212830885043068, 0.02965810573509624, 0.026882768368288398, 0.0579133550936897, 0.031132254253832564, 0.025311330513608073, 0.03502277049025701, 0.03918312587625077, 0.04737865788141086, 0.07264748966741948, 0.03698862105187389, 0.03129262518468163, 0.05385215829817518, 0.0555342000969235, 0.04173207277011487, 0.05044026698376383, 0.0368374259391379, 0.03102473189843999, 0.027846112441752228, 0.08354273850038167, 1.3417598533053554, 6.926055550575257, 15.044594983900748, 32.26915309506078, 45.7555345566042, 49.805032668575166, 44.572418274418006, 36.207724617373565, 29.202289119843517, 26.75618729283733, 31.64571785157727, 27.0398001517019, 25.097211022530836, 26.51325333502985, 24.114541584445586, 24.645640311702607, 17.756854141912154, 13.91252148535944, 9.963134027296498, 4.66920514260569, 2.705655847826312, 1.7371119678981843, 0.7288247947731327, 0.26807356205198074, 0.22243909868261508, 0.07727804683869885, 0.07698049062802907, 0.10956655376620832, 0.13516504467735369, 0.20244667066201089, 0.03454615654904516, 0.8626037259255687, 0.3741933789945418, 0.8176275006225033, 1.4104908103904417, 1.7830636376334776, 1.0400939180004982, 0.4512521714693116, 0.6806154332814679, 0.9437871051411476, 1.4527881794398831, 2.335503245553663, 2.602428625668249, 1.5976216980526525, 1.5828234534109793, 0.5108648436444422, 0.9606323980035322, 0.6443998830453043, 1.0777300403964136, 0.40721706985946626, 0.9443063901797418, 0.44751721704679154, 0.8701142067870787, 0.19152711385921126, 0.12385255371731137, 0.13352794542668328, 0.10132626690451177, 0.1461101581733073, 0.0638718567337961, 0.29346196101077143, 1.162905534428935, 2.3607736056850803, 3.4089071567981475, 9.654358183183978, 11.709524239263228, 13.50486170861029, 22.409989333921864, 15.175936529713294, 37.211286560181655, 46.91280241935484, 19.938354838278986, 33.87591869600358, 39.74361188950078, 44.606189881601644, 39.25816366749425, 32.4130727014234, 19.75142840416201, 8.5353010700595, 2.3888827812287117, 0.3252860194733066, 0.07909886163449095, 0.011047089374774407, 0.1261202659037325, 0.011710774326216311, 0.04165967746127037, 0.02992818045670227, 0.018077792351945274, 0.05737311371992673, 0.0430973716861298, 0.011695442991631647, 0.016158927877944325, 0.024003001726082256, 0.014240970260523742, 0.0018310712766833606, 0.08276764138211166, 0.00597673501150923, 0.05362319376980586, 0.014556180009798659, 0.07334348820750752, 0.07711022761800597, 0.0381563114182603, 0.07473310275423913, 0.02394165915076531, 0.005804866058526622, 0.11976016565195977, 0.031270016014816306, 0.09617043388707024, 0.045352175291026794, 0.03128574379990178, 0.04687237335489162, 0.08937265994327684, 0.007092126949329771, 0.02768873499946729, 0.029157132113112078, 0.04710980315482424, 0.03432366163319638, 0.013660803256976991, 0.09278234109402665, 0.018201475332100547, 0.0431789294065487, 0.029006147674555262, 0.07043724939707788, 0.08803206736281996, 0.02819877144159569, 0.07161066627069827, 0.11283102295091076, 0.16648405201492772, 0.23965692478081874, 0.10735444424133148, 0.14140659282284399, 0.10632110654466576, 0.14151969804398476, 0.14566700695262802, 0.23685917168134646, 0.26295263200036945, 0.1003656386127395, 0.09506991794032436, 0.16339346946727845, 0.19555814594270723, 0.08186795538471592, 0.1574402921382458, 0.15466444915340793, 0.14867066916438842, 0.14978690523534052, 0.10987831324699426, 0.13620479452994563, 0.06982165178464306, 0.14047067852750902, 0.13794384476157928, 0.2591670544878129, 0.14600790075717435, 0.16173366337053238, 0.11880010426525148, 0.2323460098235838, 0.15516616013501922, 0.10352804190329007, 0.25858780008650595, 0.12414471666899421, 0.11360977430857959, 0.19204554087933035, 0.12750839423989097, 0.13852498373917996, 0.1663350172701382, 0.11926123556951362, 0.12932875704380775, 0.19734867728285252, 0.1982644741092959, 0.13086758253555145, 0.11924227489338768, 0.13620756776823154, 0.1647273051522432, 0.18674580590619197, 0.18650689372612586, 0.11657206777242884, 0.0873212833257933, 0.21522878639159665, 1.4357641122994886, 6.666012704372407, 16.935492177163404, 33.43488739382836, 49.200305169628514, 56.83266485891035, 51.108236235956994, 45.733177046622004, 38.599209400915335, 34.541486078693026, 43.664542551963564, 33.09335877818446, 33.22624867962253, 37.335104019411155, 32.84894804800711, 29.62145320830807, 27.148426271254017, 19.323387991997507, 11.219216200613207, 7.962153553962708, 4.965680433857826, 2.83210963010788, 0.9641071889669666, 0.6154509525625937, 0.580019140916486, 0.49496447427138207, 0.7061073460405873, 0.6354830486159171, 0.7022457113189082, 1.0251867050124754, 1.0605050743587556, 3.141141163726007, 2.9622413698704015, 4.996418578009452, 4.32500833465207, 6.546816287502167, 4.477454193176762, 5.437341034412385, 5.750452078157856, 5.696159120528929, 7.2227313730024525, 7.176518497928497, 7.15076764745097, 3.0951322519010116, 5.255229309681924, 4.905594135484388, 3.413872632288164, 3.2289421942926224, 3.5074839188206584, 2.8472892026747427, 3.043850939120016, 1.7879236994251129, 1.39098915361589, 0.7307009747432125, 0.4085710536568396, 0.5108440366964186, 0.29388404481353303, 0.6225919951834987, 0.4197449976157758, 0.6486793727644029, 1.3953831888014272, 3.05609927542748, 4.713812297390354, 11.921830369580178, 14.666631471726204, 21.101223845635694, 25.809413425384033, 16.155192525156085, 37.91079813434232, 51.25744711968207, 25.914789861248387, 42.16514595093266, 46.176522547198886, 52.31513384849795, 45.82230898641771, 36.90681649792579, 21.617413643867742, 9.66945146360705, 2.3375289045995284, 0.5264429351495159, 0.16201549179611668, 0.0999745277447566, 0.19654413174477317, 0.1307321075470217, 0.23796901857901007, 0.08169141808344473, 0.09337083451570043, 0.18646238401772516, 0.2784493649678846, 0.1070348400202009, 0.10550667847236318, 0.2263762849953867, 0.0964534727315749, 0.12831876204619486, 0.163664419444338, 0.10634406619975645, 0.19751910120248797, 0.10407774063247828, 0.1643764828481982, 0.15953365803485917, 0.25987577774832327, 0.2556947303274947, 0.18352129586762, 0.1444890548384959, 0.2273329449517112, 0.13783221042925312, 0.13947799711698486, 0.24138514252920307, 0.08468504454339705, 0.14990393282665362, 0.1903392792108559, 0.18100673483023721, 0.09086945785149451, 0.11996949151639016, 0.12352217829996541, 0.09846599336953894, 0.06690823473036289, 0.20136026605483026, 0.17587445135558807, 0.12765735237588807, 0.15397136940831138, 0.19143988708815268, 0.2016707155252657, 0.19986261012813739, 0.27817758761586686], [0.06492263442205806, 0.040534562431275845, 0.07164833481393515, 0.07135489249541875, 0.026397455498696338, 0.0921600631948921, 0.022710226438639146, 0.06537128615403368, 0.0510711940155635, 0.02597609564902321, 0.005607619485442317, 0.0617760508471439, 0.03057822712787217, 0.010786365713894127, 0.02766404207044792, 0.011178744457391723, 0.06228148118562757, 0.011045252678975945, 0.03671006382172627, 0.07435768902782472, 0.039338419559381665, 0.08094607582015377, 0.057271315956548344, 0.029147839466590556, 0.05057430938787518, 0.05283657085871505, 0.021565001600632266, 0.06363600124454787, 0.06123241953431599, 0.04698475462294394, 0.049065074042206815, 0.04595068148187092, 0.04227415658533574, 0.05016739412601437, 0.041291162356614106, 0.020763926440849904, 0.021483570284720872, 0.07062702469768063, 0.06749440690562611, 0.02962340578256596, 0.03978124519269313, 0.040899833153572776, 0.05855815980823771, 0.06458959301873561, 0.004583727174078025, 0.052474418114269936, 0.03478400769733614, 0.03406321855201837, 0.06318164215753637, 0.09101915143189893, 0.02008530660532415, 0.05070181706199243, 1.4387435201675662, 3.92048204137433, 9.65654000159233, 24.392231664349957, 36.86329780086395, 42.29923609764346, 45.45939953096452, 45.482494446539114, 33.39892710408857, 28.550875609920872, 26.97899753047574, 25.19396608875644, 22.157422034971177, 20.35128039698447, 15.326387863005362, 18.758347034454346, 15.295814948697245, 10.828874668767376, 8.816398709051072, 6.557914143608463, 4.4362462624426815, 2.6291201095427237, 1.1409360939456572, 0.6461544082530084, 0.28666461607621563, 0.11703508365298472, 0.13276003421314303, 0.06770236913355128, 0.18483863001869572, 0.1944596218245645, 0.4985549138678659, 0.2616906400409437, 0.3566629277361978, 0.5758928074952095, 0.5890768742369068, 0.2156321623272473, 0.48512275721276965, 0.24464936656576974, 0.5049617378221405, 1.5163097386398625, 2.7938194524857307, 2.5520918686543745, 0.6146917900731487, 2.3184321099712006, 0.7946402050795094, 0.7914982027103825, 0.1522171353140185, 1.1700237782732135, 0.13739707248826183, 0.4615819784662416, 0.12351375899367756, 0.39910756952820287, 0.04612450300145053, 0.07622854468683082, 0.07581544709542105, 0.033027161243221456, 0.351615971134555, 0.7303101473277616, 1.3589620205663866, 2.2290589444098936, 3.9799606175191946, 8.42370963865711, 14.400725172412011, 13.853034819326094, 12.43496464144799, 10.203045798886208, 15.043803645718484, 23.373327370612856, 49.501452984348425, 28.845751554735248, 30.568668342405754, 39.532047087146395, 35.11203796632829, 27.986660311298987, 16.95314872649408, 8.031424572390895, 2.3524910307699636, 0.27663110124488033, 0.1041472018245728, 0.05002443445846439, 0.04709874850607688, 0.029246207071287982, 0.051694318441854376, 0.1377821082790052, 0.06779070673210007, 0.039780272261029294, 0.07052420037648371, 0.04337953335996117, 0.01519089247355418, 0.05102039089486484, 0.0403208966787544, 0.015264322958706368, 0.08319269760601944, 0.009008234464413217, 0.10824359652976837, 0.02803543000482023, 0.07143505593581546, 0.03239931005443777, 0.06708081135706556, 0.06685672297833428, 0.08813692947789546, 0.07113417490355431, 0.02108483875711118, 0.08134280977350089, 0.05458620459502263, 0.05398684038570332, 0.032373971696342194, 0.04671060239836093, 0.04866055280510937, 0.025577335393116362, 0.04330047308617542, 0.024247807037505894, 0.036248721843284946, 0.05719544643896723, 0.0751017289416444, 0.0411559478379786, 0.03397501118841671, 0.052421086903421156, 0.0402308009084194, 0.028262776172449513, 0.01296613675226728, 0.05931757893713732, 0.01482961115412294, 0.030894734438568838, 0.022793668735351776, 0.014199703019262563, 0.06925072475907303, 0.061951998260713396, 0.00852624737402244, 0.06575675861489388, 0.007911805117938427, 0.015371847229318754, 0.05598734876501465, 0.011040860122340101, 0.030999730619031097, 0.03337197358750048, 0.04857878824095092, 0.035869106124605865, 0.017794307261224718, 0.00812193010783484, 0.06966109507747235, 0.09314885287876092, 0.07996587398191614, 0.033150673768813574, 0.07716939258839815, 0.006985874863476643, 0.18225901279478304, 0.02219430644125227, 0.05206614304634352, 0.013749797775920843, 0.022416757307045405, 0.029527213867573492, 0.026517926655229063, 0.0536279971410911, 0.02765726793797747, 0.07514534232717368, 0.037974978406583114, 0.06550749658697075, 0.02612218670096369, 0.04642336156159159, 0.011178413124364472, 0.01747618350500782, 0.06644645991224436, 0.08050481683664745, 0.05744137598441974, 0.03148770181372041, 0.03890732656263056, 0.025851116065056096, 0.014728175367288774, 0.08636133685227364, 0.047024116220493475, 0.035897129620876045, 0.029277574541347644, 0.01923466364162103, 0.0635997116595747, 0.035009417577736804, 2.1085115161634262, 6.529809380731275, 13.825839065736341, 30.434299707412723, 43.71830255754533, 47.40781337984147, 49.9251905564339, 46.64577530276391, 36.160820914853005, 33.04147758791524, 21.262211645803145, 28.256837091138287, 28.560226540411676, 26.965110378880656, 24.14438101553148, 29.00076754631535, 21.205429454003614, 16.309950620897357, 11.446208665447852, 7.3807420942091175, 5.4078727576040455, 2.23894969109566, 0.9361083913714656, 0.3302937217297093, 0.12412017121190026, 0.09284947337883134, 0.07452900927033156, 0.02415091415206271, 0.1705847214907408, 0.05377102192611464, 0.19885771727610022, 0.17546293956618156, 0.6872547189554861, 0.274637250169631, 1.2796453218306265, 0.6760098965417954, 0.6548285460279835, 0.8648514278954076, 1.0806593154707262, 1.4333590865135195, 0.43970891184383826, 2.223213141964328, 1.0543871574824857, 1.3639515205737085, 0.8531547974674933, 0.24568300303672594, 0.2592528869788493, 0.28963403415776073, 0.19393148080956554, 0.4450365937044544, 0.3232983583884855, 0.13654987117455852, 0.033258420204924, 0.04340837273987071, 0.048558808667885686, 0.12740326399404195, 0.3376627521168801, 0.7036299402675321, 1.3681422053806245, 3.628039436955606, 5.726808521055407, 9.659986784381251, 14.471498458616196, 17.17658458217498, 18.01084133886522, 15.722392316787476, 15.090775009124512, 24.868407403269124, 53.447176948670425, 27.528890294413415, 34.86019042230422, 43.624659892051454, 38.86296526078255, 32.49150441538903, 21.51864051818848, 10.280571445342034, 3.5755144876818505, 0.4481285858538843, 0.13925987656318373, 0.017921100558352568, 0.04100845292991689, 0.031092450240506764, 0.058266433526671706, 0.057695820597150636, 0.020281323607289986, 0.10888820589189568, 0.030110463417405565, 0.04248723245015548, 0.021390674463022622, 0.03872469503192171, 0.035113241643674915, 0.04189141905836521, 0.037622953344496994, 0.043684459336462526, 0.048530566836557085, 0.06570969783370534, 0.04822690873557041, 0.027786342261899865, 0.036103341337894244, 0.0385571745855193, 0.012822732753721217, 0.06991427181468857, 0.02362828897011857, 0.013771566164289272, 0.02569453152377279, 0.0827251771284688, 0.05042453919867835, 0.030319220461552183, 0.0468598593086485, 0.05070757038230377, 0.06269388929790547, 0.01974188088018808, 0.013749962484824562, 0.08881924568765587, 0.07111680769031087, 0.022480829070592602, 0.042700304484535614, 0.05573982192624, 0.0099581825329111, 0.029450697005696358, 0.04171460213500165, 0.01668430523075644, 0.06503393933657678, 0.01346677712600438, 0.13617410504769895, 0.11456500934136492, 0.1768140275512011, 0.226439839649585, 0.1350883745978917, 0.15821908180031086, 0.15644168120718774, 0.16342221308619748, 0.15528413767535842, 0.06898613331178505, 0.1263555468270375, 0.15261612922674225, 0.09013186839799728, 0.11289799435725136, 0.124211473570716, 0.09814710161017795, 0.16471287205574975, 0.17166916491283526, 0.12094802328295286, 0.16824423095151303, 0.17799475290361913, 0.22427951766838952, 0.18811822177902346, 0.0595885212533176, 0.24141912618952416, 0.18943023927990468, 0.09030960845730959, 0.14161620980068562, 0.13321450821334316, 0.1366294370663743, 0.18270346636493362, 0.1212967235234476, 0.1727508657401608, 0.20940267240568516, 0.13198156630800617, 0.16031471531718008, 0.15905656911913427, 0.1416753211449231, 0.1260959119686196, 0.1710297726094723, 0.13711928900691772, 0.14056637823101015, 0.10022462480851721, 0.13368358384938012, 0.1448800201497732, 0.12979427803187601, 0.16472204978908264, 0.16778060986149698, 0.19823576113389385, 0.1786399061881727, 0.15328308537362084, 0.2771065354106888, 2.4601078754471195, 6.169856902091734, 15.767182842377695, 33.00307758392827, 48.60690547573952, 55.21218861303022, 58.99334561440253, 57.48797524359919, 44.27961334105461, 39.542033441605106, 36.97099039631505, 36.03802719423848, 31.977709224147183, 30.217516191544075, 28.36357851182261, 30.488565698746715, 25.747390947034283, 20.10460057566243, 14.982472485111607, 10.000895665537927, 6.898920103426903, 3.9564430665585304, 1.659280744291121, 0.985766149336292, 0.6021245160410481, 0.4153959777566695, 0.7255936197696194, 0.20032928024809207, 0.611874241261713, 0.6138406970327901, 1.2883034636897426, 1.2035644559129592, 2.303604324979167, 2.2792973970213244, 2.9019641010991992, 1.884933842285987, 1.4270848877006963, 2.8718802573219424, 4.016332265830809, 5.85306961690226, 7.0485938268323105, 6.76484662678934, 2.419803070445215, 4.777579249874239, 3.6269208260120887, 4.309220304412227, 2.6156283818906356, 3.362731299092693, 1.60762423228833, 1.6120892378591722, 1.0164094824464092, 1.4335624368921405, 0.3699862692625292, 0.5487917423728974, 0.26574416446589655, 0.6321402086365608, 0.6469268700288189, 1.2323664200882758, 2.1130604849707697, 3.668024078492196, 6.978302501863049, 13.064076535163387, 19.719647399840817, 21.64117536237163, 22.138133779648815, 18.860210987829394, 24.81604572265379, 34.80945848649548, 59.25129636641472, 39.157774525304, 43.662208741711034, 53.19196401103851, 46.020898588242076, 37.606594793258175, 23.88529081498423, 10.887184623749027, 3.314276299168987, 0.5450664713017402, 0.21738515535910286, 0.13265956944275287, 0.14282869715844432, 0.0877014238147005, 0.12184284462202942, 0.26525601324054504, 0.2975240043334423, 0.1870391869376744, 0.2301366122499589, 0.11563590066807887, 0.12655705859464023, 0.19015596969233406, 0.10094960445478078, 0.11894104146068135, 0.11337950360029937, 0.11748195040009676, 0.32745414022957126, 0.18660443204064525, 0.1170043865098588, 0.19795128204409154, 0.14763361594128996, 0.20432775359480612, 0.31878524249599827, 0.23943512700498107, 0.10278345806704414, 0.19198880440765814, 0.10702743194997312, 0.1582291328738774, 0.10789709496161631, 0.177901734507853, 0.22078966541636377, 0.13503393638999234, 0.22699267933926276, 0.0850771819691985, 0.13821272630124323, 0.16656767817274218, 0.1863775934062658, 0.14847252818365253, 0.10601539149760239, 0.12417123097205356, 0.14901205326520628, 0.10924433718525595, 0.2344149681589296, 0.15297989841670762, 0.1421323845223073, 0.1479378294560217], [0.06753871743116649, 0.04426782379948324, 0.013078011444679672, 0.04647581177132745, 0.06158557840653005, 0.022389316037597678, 0.09829658834684281, 0.02169792360115436, 0.03373820575014238, 0.0159359053190377, 0.0414348766207695, 0.05705992548516201, 0.04908289324732558, 0.07558657832804226, 0.02651942052668141, 0.03882029514399268, 0.06167412284881838, 0.041394434839246735, 0.07742503612873054, 0.05544172945402323, 0.022477042681026845, 0.030768732127222805, 0.07840215829351256, 0.008227063226513565, 0.023510001164170045, 0.052442801665634885, 0.08234001876365754, 0.13415448277467681, 0.054462565664923, 0.13480168917486746, 0.03333575295044049, 0.022945566733758298, 0.030058451793006355, 0.013291413854477147, 0.04350962658082286, 0.00883568943883743, 0.05005478686202438, 0.06853172825949808, 0.012449830838088548, 0.008836241979752819, 0.07810615724132908, 0.012906560009615797, 0.004918409441973293, 0.06099643764056026, 0.034161377397756425, 0.05904813815328864, 0.05711188156818671, 0.08206552946038785, 0.0472929019991669, 0.025566702092727347, 0.04602343302160021, 0.024575414962225386, 0.07899750820210866, 0.5669667800107311, 4.671262916057341, 13.818428727888293, 25.653250140528527, 35.68929710695821, 42.27375638100409, 48.85975322415752, 38.00646866521528, 46.68821534802837, 36.77209092724708, 22.947891412242768, 18.87428249082258, 20.984462730346188, 21.22689070240144, 15.14294743537903, 22.233080633224983, 13.78268809087815, 17.04916246475712, 11.751359258928607, 7.381663851199612, 5.827788470252868, 2.46097422895893, 2.3988071132090787, 1.250321682422392, 0.5141239961789501, 0.17895653032727782, 0.07951822582512133, 0.0943371395189916, 0.13793685803970984, 0.1469234064702065, 0.28034478906662236, 0.020089933776386806, 0.2196781944123007, 0.8530412938806319, 0.40439176823823686, 0.29833728327385844, 0.23810340572268734, 0.2988730851681002, 0.520926489224357, 0.17370574837250097, 1.3458716004125535, 1.0701881805735252, 0.4990984379283844, 0.43697452953746246, 0.3411314450204373, 0.20279294240378565, 0.07479803636670113, 0.19656388149146112, 0.15643878539483394, 0.16660052802293532, 0.159933126922096, 0.1983204598148023, 0.1022813793632292, 0.41951612118751774, 0.33001921710468113, 1.0225953053562873, 1.875866793336407, 2.147412112643642, 3.7824511383810355, 6.209680726451259, 9.413047106035295, 13.943106166778074, 23.37278804471416, 18.748554837319162, 19.87608721179347, 16.400493633362554, 21.181171555672925, 35.21178383981028, 29.64970604065926, 37.54962628887546, 41.17439054673718, 28.669066429138187, 16.325877404982045, 7.962663952381381, 2.1093447746769076, 0.4701327454418906, 0.13309446223560842, 0.027952792100428094, 0.08825553521033257, 0.06775390386821763, 0.03085614850504264, 0.03147360962635327, 0.027411098990048614, 0.036497845975381714, 0.005048909168239804, 0.04228613820047148, 0.04020849625850397, 0.032645308547803474, 0.025897631008598595, 0.03864664982463564, 0.024489971260810574, 0.006091373366108465, 0.040896060170545694, 0.10920448529143488, 0.05552796797165948, 0.08331190854791673, 0.04474257231659947, 0.04616797849115345, 0.03092670328764906, 0.03861600630766442, 0.06825340851660698, 0.015347879210997735, 0.07256103664516442, 0.02975795955036677, 0.028488823821047143, 0.05919943668789441, 0.01715071296559707, 0.008338606585898708, 0.053021102287476106, 0.030818550824938767, 0.005703066379928421, 0.03048057964582357, 0.07981929837936357, 0.1200307402459364, 0.04268105652543806, 0.013214872094742475, 0.0802371533767831, 0.06280731244553482, 0.028792669613575263, 0.027234456351687832, 0.0020869527830772346, 0.08518249607614933, 0.07868617006968107, 0.03659836437192656, 0.0686103748458047, 0.02411707221800762, 0.06699176895762644, 0.04079443477695027, 0.07632578422705974, 0.0480702169419777, 0.021318646876381773, 0.035287641559637366, 0.018880962762200547, 0.03872657960821544, 0.03771008052412541, 0.04619782910712304, 0.010222989442427794, 0.04497973781619822, 0.06678144717889448, 0.033972521402662804, 0.05284720415910406, 0.05712971992550358, 0.03954569613861461, 0.061123558440275734, 0.020163102834034833, 0.05229462110888093, 0.04054952412843704, 0.06468179170042276, 0.024480561785880598, 0.044983679338568644, 0.0854474935500372, 0.019318588573725957, 0.0767837515881946, 0.04412412102664671, 0.041209788497297034, 0.02690626236970627, 0.0171449730518244, 0.02240709693832023, 0.009433263875243646, 0.05125066926402431, 0.0954098464740861, 0.060251394151559765, 0.06965015534191363, 0.053645598011151444, 0.030700333882123235, 0.059843517449353976, 0.03684894024063984, 0.0414971940429701, 0.08432210272838993, 0.05370649817069212, 0.04626504183115979, 0.045152099938282085, 0.04356023434910082, 0.08615804009980733, 0.08048083828461748, 0.17928620860461267, 1.1153702077365693, 7.018769104634562, 17.338503945258356, 30.508385435227428, 42.88515190924368, 48.482366300398304, 52.97235442746071, 41.41793835547663, 44.201613087807935, 39.84220850852228, 20.557320540951146, 17.333508806843913, 19.539643949077977, 22.612289497929236, 22.611707025958648, 25.62499534699225, 19.81348422265822, 22.74932534463944, 18.112656262613115, 9.402362569685906, 6.637430883223011, 2.867818888156645, 2.7050682277448717, 1.6597054634363422, 0.4504911397253314, 0.32757214841342747, 0.07873400459967314, 0.08442140304513517, 0.11278704950405706, 0.2024663437999064, 0.08554795832042733, 0.3028175186726355, 0.16030582869725843, 0.5316235281286702, 0.3449809142658788, 0.7884923801306756, 0.642395245452081, 0.8019912783657351, 0.7788540134506842, 0.696546630032601, 0.8969809715786289, 0.5800907241721308, 0.566281100674983, 0.2794171178773526, 0.5309471031350474, 0.21248652870135926, 0.19643995910882953, 0.2308546817831455, 0.21535630938747238, 0.10324283502995969, 0.06733728227235618, 0.11668774704899519, 0.14978094507128964, 0.4017988364062002, 0.5573487606260085, 0.9375626101128517, 2.2612169865638982, 3.1399725425627927, 5.52670439404826, 9.010007881349134, 15.274922443974404, 23.423096364544286, 26.1224401381708, 22.097731405688872, 18.349779229010306, 16.633793269434285, 24.686287833798318, 42.57193103913338, 33.45592698743267, 39.85083772290138, 45.967452372274096, 34.12722495294387, 20.51530803403547, 10.763180851936342, 2.9354378532978798, 0.6198895434218069, 0.02072572929694528, 0.02914101745362484, 0.01112579150245555, 0.025939078280521978, 0.1012461264467528, 0.07071657271514978, 0.019924175332210237, 0.017854437502401493, 0.06420610089515967, 0.06940644745144152, 0.026488709977016817, 0.06978474932933046, 0.010694539542460154, 0.016277826639012467, 0.10884066247531485, 0.03294505960037632, 0.051233826821009, 0.04594929869316759, 0.05125104847754683, 0.042262661436031905, 0.031155164113208175, 0.06625883731870882, 0.011687106039795664, 0.005047809353263508, 0.016555577561619784, 0.016711983987460696, 0.02404485885504513, 0.018377503184902094, 0.04318448354399974, 0.02188937280387167, 0.03473951714113355, 0.029183420420233763, 0.015294637057870148, 0.08883582383033731, 0.015104643422208968, 0.0669686024587962, 0.04057275957518047, 0.05953392982783337, 0.06142505234287632, 0.031373022281895244, 0.03026930408762588, 0.01834911388164807, 0.020500273451269157, 0.025398185732023373, 0.004017141951818861, 0.02738913141881987, 0.01746212196115765, 0.15347730398418444, 0.10077505898211273, 0.18011842523851704, 0.178949405709582, 0.14791791116999042, 0.10363839686878266, 0.20482267703740828, 0.11762387584894897, 0.15214834061841812, 0.0897562248452056, 0.18553831344169958, 0.15115559792086003, 0.18414093842429502, 0.15546934709193247, 0.13223630586458793, 0.13291331308503307, 0.14658582216549307, 0.1359806065597842, 0.20271743677796858, 0.17797003890718185, 0.21835384289583853, 0.11806133503635084, 0.19286735403922298, 0.07387609551510504, 0.09995644806974358, 0.18518833383437128, 0.23009973277728404, 0.18568802234386245, 0.16768429728765644, 0.3097821772098541, 0.13732529004975674, 0.18637526449897598, 0.07398513280936787, 0.13638435021763848, 0.18410329286369587, 0.09973567685172444, 0.2079661196518329, 0.2039072172896516, 0.15829276413686816, 0.10240552391135886, 0.175570544276026, 0.19742177739258737, 0.17194124870002273, 0.10693654327863648, 0.11723428949593537, 0.15625313164726382, 0.17237457867351272, 0.23804040265179452, 0.21752432289142765, 0.13241063683263718, 0.1510137950460757, 0.11873882489218829, 0.2873197744690603, 1.3046090016441962, 7.689335057812353, 18.60948916404478, 33.87790341531077, 46.71906871180381, 55.96865692446309, 61.426803681158255, 50.69805437518705, 56.468402185747706, 48.00546492299726, 32.70088641874252, 26.80142987158991, 32.43890347019319, 34.742409490769916, 26.886786530094763, 34.82786224734399, 25.25471771917036, 28.44084724303215, 19.84093689149426, 12.194704759505488, 8.840879201889038, 4.1198291509382186, 3.661700237181879, 1.9341192610802191, 0.8214499116424592, 0.5352772772312164, 0.5177004010446611, 0.4093526165571905, 0.3866489574072823, 0.8413789229046914, 0.6073750988129647, 0.9301818739021979, 0.8479395160271276, 2.1323575656260214, 1.1170478790037095, 2.3597491316256987, 1.804313813486407, 1.5813654348734887, 1.394318510447779, 1.7092345799169235, 3.6774787066444277, 2.924567004365306, 2.391503659948226, 1.6793641375918544, 1.1495268200674365, 1.2928274273872375, 0.5518666354398574, 0.49570666025242505, 0.6162093796076313, 0.5373050200362359, 0.4653883629268216, 0.5769297228224817, 0.8071681328358189, 0.7289450399337277, 0.9930055576466745, 1.7971074388873194, 3.11647117137909, 3.576305335567844, 6.9467033974586, 11.592927863520961, 17.18084035381194, 23.23536192217181, 33.92427367548789, 28.869534846275087, 29.456856827582087, 26.300368655112486, 34.7262022572179, 47.25189524312174, 41.51502878435197, 47.670345460214925, 52.84451261643441, 38.1484898444145, 24.055935490515925, 11.192915728015285, 3.352746415522791, 0.6876332276771147, 0.1850013317720544, 0.20734154348892553, 0.15505872396451814, 0.18031180115236392, 0.15916178363465494, 0.2086039797793473, 0.11329307356068205, 0.16410331121615826, 0.08415861190446923, 0.13877475904601236, 0.15952187560258374, 0.09835124872024022, 0.11309368385662956, 0.13652547893504943, 0.16217031816561378, 0.14479169021210364, 0.09391573753448264, 0.2553753023065867, 0.19411935621211607, 0.3006560475595536, 0.18607273637767763, 0.14856366200312493, 0.10284092998312366, 0.15184133854364196, 0.11621561472214038, 0.29309004064529176, 0.2603432752432362, 0.07556683624223356, 0.0882968656538475, 0.27536199998951727, 0.17710059040015746, 0.11373418698748274, 0.13151915563691047, 0.1680750787378319, 0.05847036613211517, 0.23432484557551725, 0.2568134944885969, 0.13468332859056611, 0.12186603410349739, 0.17593878741946914, 0.1163659901207974, 0.183227930157896, 0.2759433381499783, 0.18087133645049988, 0.13403667377368098, 0.28083128554205744, 0.24421401412015964], [0.03036750506819977, 0.01447861360746526, 0.035330282013502814, 0.02715234513274364, 0.03731730724534681, 0.043421070647215655, 0.011869804603197883, 0.02875678413998216, 0.02320811464150827, 0.05012189616419135, 0.04351788883908622, 0.022877076558107813, 0.04516032772258886, 0.045214149229709184, 0.059603391019927884, 0.06383165243952986, 0.057801134704101476, 0.03399971752397476, 0.013663686620402, 0.03794350751465367, 0.01952242350295907, 0.0036204003375924884, 0.05890773721940576, 0.04212294615084126, 0.06958748168882824, 0.012164297419780446, 0.07145318157610393, 0.022094674791479786, 0.05378710594208491, 0.023390336315177625, 0.054702826159735846, 0.029905822180632143, 0.04104247489463418, 0.02957861453685309, 0.08532549404809553, 0.03631159084879103, 0.007425355565388717, 0.013677686877218227, 0.06002374346398058, 0.06684352328339893, 0.03228368823446574, 0.020020861373913866, 0.10270762302341963, 0.011446772766630016, 0.03603660358837055, 0.06462599751689742, 0.03608390951769487, 0.08153838435969046, 0.025393621763214472, 0.029220248181973735, 0.06843523948543495, 0.023868013203384417, 0.09496811251606672, 0.05877011718468801, 0.540419259378987, 4.6355095313441375, 12.956821283986493, 21.978475662969775, 37.7829877022774, 42.68305963085544, 52.64932370954945, 46.72168493270875, 33.804190312662435, 45.50198078155518, 36.941658912166474, 34.21273262270036, 21.227271172308154, 31.068331233916748, 26.248654165575584, 26.392434527797086, 19.091444515412856, 11.93967813445676, 12.132626387380785, 7.75954548389681, 6.522455426954455, 4.283565552003922, 2.99646282388318, 1.6476824182656504, 1.299513352494086, 0.6793296313093555, 0.2871245139789197, 0.216530553636051, 0.029540015196788217, 0.05305886276126389, 0.16993445073885305, 0.04637021421184463, 0.027745827702024294, 0.12974610642319725, 0.2885385590695566, 0.8010467225986143, 0.8246926698953876, 0.8080802064749503, 0.19144672059243728, 0.5632021626637829, 0.2963601329153584, 0.2839826341838606, 0.09590409575931488, 0.5163406256225802, 0.03935289096027132, 0.07132840117499714, 0.1563897710894385, 0.1337888749736932, 0.09970889441789159, 0.1986928091895196, 0.3621120192110539, 0.4369275223824286, 0.8946129631611609, 2.0702544335396063, 2.8468847082507227, 3.0566523296217767, 3.760970032984211, 6.739627747766434, 12.257290097974963, 13.757545698073603, 13.282405464879929, 18.30819426044341, 22.046313055099983, 21.78721893218256, 27.62691228620468, 25.54849736152157, 33.67545027886668, 36.570151621295565, 39.30114499984249, 34.46259152504706, 17.20467463616402, 7.954568670641992, 2.1424809578926336, 0.4882950353766642, 0.032310849881821105, 0.0498384474626472, 0.017214154621826547, 0.04463499825027201, 0.06863729517546392, 0.04176107685892813, 0.007936634027564358, 0.011683007469400765, 0.01857420583556016, 0.024898845792537736, 0.024085587919539502, 0.013718579693006413, 0.0647615644359781, 0.09272913628768537, 0.013191090810352997, 0.021810247412612362, 0.060323567294906226, 0.047621500092528524, 0.011487973932807725, 0.03190109817942064, 0.029051804599622567, 0.10133931338186226, 0.028029923747864463, 0.0325108333040149, 0.029818911420842333, 0.005631709120221316, 0.037574287609107075, 0.05435010778807825, 0.07945419619640998, 0.00570986541025641, 0.05191696274484839, 0.0622676532985943, 0.03882727037454325, 0.036588707833641, 0.06378043946179171, 0.011525402115958353, 0.04433629673815543, 0.10415262572707669, 0.06416509986945218, 0.09026508342715041, 0.06197301588291603, 0.07913093007500134, 0.04672694305378584, 0.025207136810246496, 0.005090121346931424, 0.020736289818981485, 0.0995794102369297, 0.03240827328315185, 0.013684697539335298, 0.06381232787163989, 0.03957138689715536, 0.03932028242777433, 0.07414962720846938, 0.023289193556974494, 0.061688215036185524, 0.0495400830292173, 0.0315498392052588, 0.024021284414395213, 0.07982664516255741, 0.037294952799716306, 0.07299333239995665, 0.055500798663424875, 0.05876925916621282, 0.011009399764119618, 0.03870440902368676, 0.010544988645931647, 0.03701327376127724, 0.047410879539506096, 0.04432992671706504, 0.033039947250677694, 0.030420503030801495, 0.020535672459030346, 0.03524423884828726, 0.012539076250827601, 0.11514160541757462, 0.006608305557165296, 0.006555414846872972, 0.028259344098548737, 0.08034005430677245, 0.027282338762175173, 0.033468596426950346, 0.049539213519423246, 0.08527152315382996, 0.03491798115353431, 0.013208411100711073, 0.042759672468227726, 0.05108522108545707, 0.004467164981178939, 0.023660334427991224, 0.020022437599818074, 0.03886362124655036, 0.03957300717311521, 0.039649600643784776, 0.010277292627330509, 0.013061116333119573, 0.07470452767466346, 0.01295510700137745, 0.03155116836780743, 0.03747241706737588, 0.02220298621743437, 0.019993709302657557, 0.05773427055007028, 1.137070230418636, 6.911354016873145, 16.770472180458807, 28.195220578101377, 43.71485871653403, 50.37623174728886, 54.8256782562502, 51.50005355958016, 38.06761841620169, 40.92409233893118, 34.39103180362333, 33.9733660605646, 26.627896370426303, 27.660425016956946, 32.4607353825723, 25.978002778945434, 26.60288537702253, 18.23648548895313, 15.285868798532794, 13.073727526972371, 9.536620397721569, 5.81409155361114, 4.302241917579405, 2.455178191584926, 1.1335519869481365, 0.6798973943917983, 0.3373511994798338, 0.15955690114248186, 0.07914043722614165, 0.08235753919448584, 0.01913664269170934, 0.16670414907557352, 0.03628885335919838, 0.41839551841539724, 0.16422341848092695, 0.19463746147530694, 0.2275989919660553, 0.17701550867528687, 0.23879001968570296, 0.07252418015512728, 0.3587289749374313, 0.19316799758422762, 0.14872069470584393, 0.03372136330712707, 0.05720148704225018, 0.2945800816580173, 0.11613427150634029, 0.06206683101012342, 0.19982672656976408, 0.1745148751163675, 0.38887094946638234, 0.431124406356004, 0.9461244087546103, 1.9620623487618662, 4.049953352059088, 4.984327871953288, 7.277408232611995, 8.939624870977095, 13.950627311583489, 15.81334423634314, 13.826256798159692, 24.230788869242517, 26.415896184982795, 22.42588670023026, 25.039881660092263, 29.566989137280373, 39.84414223701724, 40.88424890272079, 44.86351305438627, 39.80631097670525, 21.486941883640906, 10.20039035427955, 3.6417312054864825, 0.7067642817574163, 0.0765454676002264, 0.020144285799394694, 0.1022153732276732, 0.09445988978709906, 0.04912949437575956, 0.0593990064226091, 0.05259334177319562, 0.012398012650890217, 0.004548133292701095, 0.030655849071580078, 0.08198254681642979, 0.02238486698197742, 0.012710446289049522, 0.05460229627187214, 0.012071077925934186, 0.040806699844618, 0.04296249807662061, 0.01849097995868614, 0.0299662531113192, 0.02392647911854569, 0.014657034527420279, 0.08771183494959148, 0.04042230756773103, 0.06359098208767754, 0.03325368961199157, 0.021923364125071995, 0.03494448013483517, 0.07122669534216966, 0.026455532624236038, 0.007947142359860724, 0.04655009165646569, 0.04741998066404655, 0.0552762468014994, 0.017636609977231394, 0.03272414665609118, 0.02066184714015934, 0.05031076748104346, 0.07872530950173255, 0.08260143094605978, 0.03429371525623626, 0.039254778079808726, 0.048157236869296724, 0.011749164907321816, 0.024040825402123794, 0.012242576283883425, 0.019171254544128335, 0.05101818839208253, 0.027411378612140977, 0.1124226674437523, 0.09042200887756002, 0.1070055065135802, 0.16077590024759694, 0.22282552875338063, 0.12861802663293578, 0.10023312838447672, 0.0929077037219559, 0.09365522167495183, 0.11994591899096005, 0.271849854578895, 0.14026622498227706, 0.1565323094086301, 0.08683366836198876, 0.14867073045142237, 0.09669564844619843, 0.17076490537053154, 0.11683423072099687, 0.16597682520026164, 0.15947111461672092, 0.18475918670094785, 0.14997694100583756, 0.20335385666018535, 0.10147098091340835, 0.11052383425375147, 0.09421196075216418, 0.16519437363791853, 0.20451683941627705, 0.09653227253546638, 0.13058212285320606, 0.15051694106190436, 0.13135498299473716, 0.1499351432486888, 0.13421341025781247, 0.20860178876788388, 0.14645762501224396, 0.19829747717707388, 0.08273604791611433, 0.13554442673921585, 0.2007976357614802, 0.15789534836526842, 0.20200312107561097, 0.18127815978180978, 0.19837397871719253, 0.18915207275459844, 0.18537982517192442, 0.0794765889464367, 0.2663039602339268, 0.18574881908153335, 0.1336909076499362, 0.18389303237199786, 0.12649767145875002, 0.11788882735756137, 0.2378473944601513, 1.1098656514959953, 7.254637893169158, 18.795572288574714, 30.67779652533993, 48.6977554136707, 56.78823617196853, 66.09729536118047, 59.144682422761, 45.84257979546824, 57.32329060954433, 47.285243234326764, 43.948522152439246, 30.977802930339692, 42.53573932955342, 39.267675415162124, 38.081146670926, 30.51509661059226, 22.90964830306269, 22.886571038153864, 15.513067187801486, 11.430117141815925, 6.825215335815185, 4.847112086511427, 2.4022931196997246, 1.782920593696256, 1.0088030260897454, 0.9317204236022888, 0.5891832685278309, 0.43361195513317663, 0.3077217990592603, 0.5567004050939315, 0.45983266265642264, 0.6440660525714198, 1.1444076366962925, 0.6965150059230867, 1.7666466798513167, 2.0530590078523083, 2.1042322103054296, 1.3674076189917903, 1.980554730661454, 0.9213287779881109, 0.5219463667561931, 0.8326796574458, 1.086188876821149, 0.7744528689692098, 0.6694680572517457, 0.6488699141529299, 0.5132858959897872, 0.8967325752300601, 0.5427108428651287, 0.6921044845254191, 0.9342441010859706, 1.5065381339480801, 2.9088449189739847, 5.049283302599385, 5.839674232467528, 8.55757228789791, 12.986423411676961, 19.61933082149875, 21.897215920109904, 22.607353195067375, 29.2190239121837, 33.63945076542516, 33.85013695686094, 40.349986783919796, 37.3736922971664, 46.100687442287324, 48.2909664030998, 50.77652139048423, 44.39971239336076, 25.586579653524584, 11.147924180953733, 3.9789363886079485, 0.704347672722032, 0.16600595186314276, 0.11104867342979678, 0.17308523247559227, 0.19206993311883944, 0.23432912034613473, 0.24949124143008264, 0.110175111030619, 0.10557360391342833, 0.12275702500295256, 0.12520734190700517, 0.13309345099954836, 0.0994038918325978, 0.20270712523450776, 0.18133091259627573, 0.0841498172150985, 0.10281630025635805, 0.1638191998485596, 0.11160551975931852, 0.13707854845110448, 0.12671985993942908, 0.18061722508601605, 0.2509393161463161, 0.11973951958240041, 0.16549946049288397, 0.11851429218246091, 0.05993585019642788, 0.1942350508104409, 0.09671978787669251, 0.15131731908167564, 0.12990404310966694, 0.18239447246155432, 0.15495828983764495, 0.14088574496488418, 0.11827397806149338, 0.18182277168718078, 0.14128363571099697, 0.14759368743867646, 0.1934644276456487, 0.16952070197270763, 0.21491256061821215, 0.11307802501945727, 0.1258141524909485, 0.1412749023086602, 0.09018706503294169, 0.18557738392583786, 0.10172030422836544, 0.22773213804729525, 0.10104347320814287], [0.07170406771042655, 0.03830179151508116, 0.01749036379248625, 0.02518275606205627, 0.060726165651313724, 0.065827437886788, 0.0028620771932295497, 0.01604206116509534, 0.04981964000410611, 0.02709448825748217, 0.02909330741292046, 0.015641911417215822, 0.05052281678804467, 0.03801527463140027, 0.007734817261206768, 0.05221773269436052, 0.018172002014433666, 0.038032254970241944, 0.034245604934591445, 0.09807477524924664, 0.07939424215545578, 0.03128643136381382, 0.027033323797607617, 0.0656800195875187, 0.020083810818651994, 0.08961781573992583, 0.08604432200832714, 0.056153953736347545, 0.043938995879744334, 0.04194755032057724, 0.010263286624854852, 0.08780080074023816, 0.0049611609785877656, 0.02676349039369774, 0.04419830515079441, 0.06729980525110038, 0.01894193761531384, 0.009399253401845213, 0.026849518237154812, 0.06326053006153914, 0.02907219211450748, 0.012203252033120202, 0.049903185722688516, 0.08656247323679347, 0.025715861326804566, 0.028176470622119885, 0.04790610175639872, 0.07544769424824946, 0.04038922406072098, 0.03309940716492073, 0.041354724671691656, 0.024887002073228363, 0.08285866794927467, 0.03800273377207979, 0.07429544438397692, 1.4405764927787166, 4.607722970747179, 9.74899418892399, 19.863092399412587, 33.00614095503284, 45.128908464985514, 42.956546891120176, 43.119160513724054, 43.706202045563735, 24.920319972499726, 28.992811018420806, 34.1476369673206, 29.852565142416186, 19.88661877570614, 31.830851762525498, 23.487129057607344, 21.068885864750033, 16.24823702919868, 14.838280274022011, 13.859034084504652, 9.592040546478765, 5.684768067252252, 4.064912046155622, 3.378216816532997, 1.8974551510426307, 1.3098620358974704, 0.6836463222580572, 0.429151515446363, 0.26570340858832486, 0.2402099789751153, 0.042844455418807846, 0.1022966091911639, 0.5273712498526419, 0.2655065852788187, 0.1114531372102999, 0.17238628449699572, 0.07818915520704563, 0.05493122761348083, 0.17137702494379015, 0.2083378101909353, 0.23154561648205405, 0.04004988158422132, 0.07454182592130477, 0.03568002413357458, 0.06879005310756546, 0.11190178128139627, 0.29090917218596707, 0.5144508399309651, 0.9738901317600281, 1.2077394512391861, 2.14813603508857, 2.3024835077024277, 4.317152317493193, 3.3800287064044707, 5.058866633522896, 7.0320085748549435, 17.74418684744066, 19.073138813818655, 22.270056816839404, 28.71469536135274, 25.69073230989518, 16.111157055824034, 23.445806887841997, 34.49385673769059, 32.85292925373201, 38.92384436822707, 32.55728648554894, 34.414966106414795, 24.00426022468075, 8.109905315983681, 2.414413488680317, 0.41533904210213696, 0.057438028180190635, 0.06844554336801653, 0.03597763397039906, 0.04419909422135642, 0.011901871128488454, 0.05437158506303545, 0.011947719575536829, 0.07597624128984828, 0.02402851628440042, 0.04695622933908336, 0.02880275899153804, 0.058696266308787375, 0.032239423674200816, 0.013999244622555713, 0.034100224429200736, 0.03276231698691845, 0.030502194816607143, 0.04672847906007402, 0.10384115735970198, 0.05085375144957535, 0.04454301407320365, 0.01765613181276187, 0.047490410957365274, 0.02964995839002152, 0.05871923745519692, 0.01111856250528006, 0.06623596193328982, 0.05671062769608633, 0.04229837645506186, 0.04835622054674933, 0.0740710802135929, 0.07323909340606582, 0.06286541638415187, 0.025449869853834954, 0.04885634572635736, 0.043973439192819985, 0.1276714790372118, 0.024355570710594618, 0.057761930154576424, 0.0146404477662497, 0.023539451499199195, 0.05813889903947712, 0.02761160143681111, 0.054753288371308204, 0.08225597125748474, 0.04762649498579483, 0.037942856339918035, 0.03650971267732882, 0.036734980831463496, 0.06419321529627328, 0.04614752011313554, 0.04484531619856435, 0.1307609277747331, 0.010712136582080877, 0.0788065531261025, 0.036871555156164595, 0.009392078030824421, 0.03514720615179789, 0.06929576306814147, 0.11804181511604017, 0.04291919112626103, 0.015465972622135475, 0.035093028413792776, 0.02634059070729681, 0.027468490466896086, 0.026780526273913925, 0.006970629234978509, 0.037051762018593094, 0.0667395881347118, 0.010727683378894244, 0.053545401371534795, 0.04301043602848246, 0.027158178892287037, 0.08636977148031996, 0.1387560665006599, 0.11034853801491762, 0.014897099669812428, 0.06947346482305758, 0.08182764383814028, 0.02461784091147204, 0.03204785764307505, 0.03416111309742255, 0.03307703739753173, 0.06073524379321645, 0.04396554848719989, 0.021272685431364565, 0.04021249906790834, 0.08097903292265632, 0.027722975299243006, 0.024402076078038064, 0.03870843481572886, 0.045194629309398514, 0.054133565375401135, 0.014981463187254004, 0.018995127099896633, 0.07529664469221908, 0.031197521114541642, 0.03467536110791468, 0.02702650944552114, 0.08186083842789935, 0.03471354676050044, 0.046536761726583206, 0.043986160082802664, 0.05759304224122917, 2.0012019646744577, 6.245628268487993, 14.053055105670808, 26.169332073580836, 39.560911809244466, 52.149146987545876, 49.04754846326767, 45.314750363749845, 50.01437740941202, 28.899709640010713, 36.67523191821191, 30.6484297398598, 29.008933921014112, 27.042716433925015, 36.30274403479792, 29.359285908360636, 24.318089062167754, 20.79336093318078, 18.91003881731341, 17.87082645200914, 11.868666564264606, 8.275193995045077, 4.415119396102044, 4.793299128932338, 2.636672143013247, 1.441589812597921, 0.611877366900444, 0.3752417856406781, 0.19858955585908508, 0.26878118214588015, 0.09416869210620081, 0.0976881153521038, 0.16198857146645748, 0.10894586932995629, 0.006085714370372796, 0.056899533486895026, 0.10901837955198942, 0.11595303808609325, 0.09654397835894939, 0.25537269760764414, 0.10884542754220386, 0.06511051748548785, 0.16299049189734846, 0.03361775757624738, 0.0966336642722449, 0.10323767159735003, 0.22338711716715368, 0.43392102564534835, 0.8237455400728411, 1.1339490043540155, 2.244579763181748, 3.1760742827769253, 6.076411825995292, 6.338702190306879, 8.105080800671733, 9.58730036212552, 17.488636585973925, 21.751709715012584, 20.92179306091801, 28.918133012710083, 24.677942991256717, 19.6779526049091, 26.740966535383656, 38.18592494533908, 38.1966055593183, 45.86530993061681, 39.466814148810606, 37.843043111985736, 30.029201238386094, 10.836386007647361, 3.4314372510679307, 0.814957530988801, 0.07828736001805914, 0.1001535165273855, 0.013459369055776587, 0.036713074547268694, 0.08335116289315686, 0.01816742080864647, 0.07640009475571495, 0.01185477587334331, 0.06520249400167696, 0.05002747582752378, 0.02228381232388558, 0.04580244346852264, 0.0550766923885432, 0.05237939256814219, 0.07169164176429473, 0.04599111560251444, 0.034267687419008826, 0.05415104367139359, 0.12373854451241995, 0.06628431740307039, 0.07616699718299412, 0.03991890353180709, 0.06212472044412167, 0.0273786666577742, 0.06086976500228048, 0.030675671596620834, 0.03141826168904382, 0.0394973176861963, 0.06200326486460625, 0.025053599383682016, 0.03643680792001467, 0.04342161840008151, 0.03874625274611097, 0.051587885846534086, 0.05760581675736655, 0.007677656568346486, 0.07836553929073196, 0.03523272454678532, 0.008272611941661566, 0.02144453427453916, 0.037154643796384335, 0.05320573330766732, 0.017624235742034453, 0.024535858012255163, 0.02583220326942542, 0.042493330510032755, 0.015780337759473875, 0.04122217613903265, 0.0710798362870851, 0.13823506542511527, 0.14414010178898612, 0.10524771011043942, 0.2266430061671042, 0.16602530324411008, 0.11391132183733488, 0.11879011447871886, 0.06988509152565273, 0.12532567184778953, 0.11907571205689062, 0.29752811056471645, 0.12912387448933818, 0.14231600047599885, 0.16023579293922072, 0.15732407660013245, 0.25651160988115496, 0.12825595815816235, 0.13155692377157752, 0.13467615800759486, 0.1977950307510553, 0.21858633525909918, 0.16966063559295672, 0.17060001260570942, 0.1168202955816542, 0.1387903872396677, 0.220358204697409, 0.19020386550936008, 0.21853399613211233, 0.1284485986276019, 0.1350052080928318, 0.07446730088803076, 0.1752716014462133, 0.10059250022975669, 0.08585439349013953, 0.14686322260287502, 0.15981211567357664, 0.1068875979211542, 0.09552331941743052, 0.24809611871117548, 0.09958546999241076, 0.14650322256549714, 0.1416994835580549, 0.15111522508725045, 0.18798855373695975, 0.1135211302748611, 0.08372368846809672, 0.1413414140622462, 0.22749226059644456, 0.10013179793473213, 0.20071860613121142, 0.14732249231348116, 0.08841579314321281, 0.10389837646676649, 0.19366941745242766, 0.2150523256991179, 2.3565644121939138, 6.2827515409838774, 14.37100733480146, 27.22209622783046, 45.52971193867345, 58.459503189209975, 58.59411501115369, 57.287773547634, 58.09185158821845, 35.90312903927219, 39.76726770401001, 43.54192926037697, 42.102835178375244, 31.605407653316377, 43.60939010497063, 34.40582306154313, 35.61359144026233, 28.347771360028176, 25.20866713216228, 21.33250051929105, 15.671213230779095, 10.349573781413417, 6.891551931058207, 5.62488426123896, 3.434593778464102, 1.6415473410198766, 1.2053074591582822, 0.9094959677707766, 0.5136377754951678, 0.594319367120343, 0.44186164955458335, 0.49730398421806676, 0.993938897886584, 0.555726554124586, 0.5689923777695626, 0.4927409500364335, 0.6363874613758057, 0.6362220476711951, 0.6026356499041281, 1.092056252302662, 0.8646054217411626, 0.2750027660400637, 0.482406301363822, 0.25953649272841794, 0.40461623200005103, 0.4589061559207978, 0.5524092095513498, 0.7989038214568169, 1.4414378207537437, 1.9322064927508755, 2.885737010548192, 3.99614260081322, 7.130772875201318, 8.218269127030528, 10.88388296865648, 14.022636144391953, 27.03422058013178, 27.8964340302252, 34.10150597172399, 40.85757678554904, 35.94099560091573, 27.668750247647687, 35.66158948406097, 47.426417181568766, 44.18367216663976, 53.724566967256614, 45.492924028827304, 44.085530542558246, 32.804319320186494, 13.078626567317595, 3.6266590078030867, 0.9497807319125823, 0.20208590453670872, 0.1537770588671969, 0.09518963450025167, 0.1400349277161783, 0.11595634758592614, 0.174832142769329, 0.21118247851489053, 0.20760510837839496, 0.19641619506141833, 0.2359616843562934, 0.08359447241790834, 0.15564225313644256, 0.22174725999995587, 0.15362538877994786, 0.20694320841181665, 0.1194950226213663, 0.0857102617080654, 0.24283243583575373, 0.22471430320893565, 0.1712950688576506, 0.17258929779693005, 0.14619369240057084, 0.15499506205801042, 0.13861305320695524, 0.18533343088723, 0.13840506033551309, 0.12857895614879747, 0.1497227377108028, 0.18677338507146607, 0.21471558409112118, 0.1647497515284246, 0.16274883712251342, 0.11708661838765107, 0.09410689945422834, 0.11050001658018559, 0.14099722607962548, 0.30303288130990924, 0.14988634344791213, 0.19822998483094478, 0.12698494934386786, 0.12999102473258972, 0.15915104308195654, 0.06485811449707517, 0.20502130831441573, 0.1444923336948118, 0.11238310666334246, 0.09885028605499575, 0.21110036921116615, 0.2710911210986876], [0.056488178745513005, 0.07984154557268466, 0.09095700637948129, 0.03350845598165066, 0.028260096779934345, 0.036860657555441705, 0.09715799016938095, 0.03947777861368753, 0.0481153165380801, 0.045727324717107325, 0.022798778541806727, 0.0532933546140069, 0.004894311188705145, 0.08231767963978552, 0.012089807818072939, 0.04818673891526076, 0.08038423459736571, 0.05530035941891613, 0.051755620797555295, 0.050955962900432854, 0.022973578738709612, 0.0363680170548539, 0.03242086776862702, 0.03461425793507407, 0.08132464582881621, 0.07615573569050721, 0.018335852899678776, 0.01751340963246842, 0.029236879950809865, 0.02818274296699993, 0.10311517413825759, 0.024879561444263787, 0.08137109373966533, 0.08606760342034601, 0.02206638316443611, 0.04536024985774871, 0.02354656654079595, 0.030339870361551165, 0.047013291398123394, 0.08219636961697571, 0.04641248694350643, 0.02790156954659089, 0.04569583850341939, 0.05040483924770548, 0.05271660532021234, 0.07115235416999749, 0.04594256094987354, 0.045479545069317666, 0.016989679368693503, 0.0689398079750038, 0.08030685205613414, 0.07062155482990128, 0.021593697339056, 0.032768139255142985, 0.014132609038854079, 0.10589832560189309, 0.38414737389933684, 3.0069367779839427, 8.131179271205779, 18.74117882021012, 30.585679661843088, 41.1515348957431, 40.75632864429105, 48.06634403044178, 41.756415367126465, 43.82251208828342, 44.54513818986955, 21.56396742789976, 24.26257379593388, 29.98779866003221, 22.329855311301447, 26.194380329501247, 25.28675171636766, 19.173496577047533, 20.522191793687885, 10.009360140369786, 11.001800202554273, 8.057981469938833, 5.8488628748924505, 5.0985512137413025, 2.5942257238972575, 2.481436988999767, 1.7199579722458318, 0.8049671315858442, 0.7667888028006401, 0.5089662326199393, 0.35705403094330146, 0.41348167725147744, 0.23882069384619115, 0.39205101108358753, 0.08038185206392119, 0.23666227176304788, 0.19645312049936867, 0.2882193455532674, 0.2232590119444555, 0.05584177290720325, 0.24968087883485904, 0.26761354157520884, 0.40779978697819097, 0.5579005890796261, 0.5988577945578484, 1.022922394256438, 1.542052744377044, 2.863443974525698, 4.50965783288402, 3.431785361420724, 5.193747628119684, 9.851156242432134, 14.220083355903627, 15.537657507004278, 24.22400316884441, 24.68521506555619, 13.723713294152292, 19.128901189373387, 11.74193282281199, 23.80882028610476, 24.178095748347623, 25.88086332044294, 39.75245291186918, 32.48303013463175, 38.54571611650529, 29.54322937996157, 21.51684407264956, 9.875605356308723, 3.403827197128727, 0.3882007451067048, 0.0379851597150968, 0.03409528316208913, 0.030951898004258835, 0.05802681271527564, 0.025349744077351306, 0.04263190432421623, 0.022901053194917982, 0.04481908917847661, 0.002783059772487069, 0.030461057810293093, 0.046973554417490966, 0.024461377029036804, 0.032011437823154756, 0.014901818771425997, 0.031186002982600085, 0.03178318767177482, 0.09747767099930395, 0.023971362294809475, 0.045413117585403305, 0.0366306588083746, 0.037490129020185246, 0.03560527693480253, 0.028293011747601054, 0.01926279822064023, 0.04875195092491565, 0.043881447354872385, 0.028227963221950397, 0.06359141492735475, 0.026911257262972575, 0.030796845638824087, 0.03860458776715302, 0.03971287567589072, 0.024396198268439022, 0.05558074376876316, 0.1254564966826189, 0.07211235426967183, 0.022032261608288656, 0.04615898844936202, 0.04743304629359515, 0.11191308107827941, 0.09717747944617465, 0.07377591419724688, 0.033318600241815856, 0.027771621882434816, 0.05759493064796252, 0.008514765631257287, 0.06100297237055437, 0.0417411700642157, 0.026853974953654314, 0.012413802680619543, 0.02910048565677097, 0.03914083782283049, 0.03161004222478838, 0.03615253950439153, 0.04366311229645245, 0.06518536427569005, 0.03248965863378779, 0.07126336031022572, 0.044346305676886154, 0.04264916428515027, 0.020818751523151033, 0.021303491742019693, 0.029268873697747628, 0.05021160889056422, 0.027973694809442087, 0.12486574330156851, 0.036433268593804496, 0.06419267137384703, 0.03970237261044883, 0.05209309784995933, 0.005484433504827922, 0.03345175015349542, 0.07823089933803967, 0.04816661761592954, 0.02165563746295389, 0.037234209688200105, 0.061835008973796526, 0.0019246879392378635, 0.04026095029867945, 0.009021314458110401, 0.03969686060783364, 0.010958976814553384, 0.034396390190287944, 0.0457965292697472, 0.05693797960937504, 0.053147698316963456, 0.0378446476984649, 0.03812245416244672, 0.034555977796234434, 0.0035927000346653646, 0.024601412155935844, 0.020188479496526624, 0.03404661742669921, 0.023738439007091428, 0.014884488904968867, 0.05014009458283263, 0.050922588280011574, 0.04814015693902489, 0.07129099310165452, 0.04215031464193617, 0.0593303534532747, 0.0397879331402721, 0.0494257022716826, 0.0537116501119829, 0.026543954492456494, 0.12128347786323679, 1.1033461819733343, 3.971516735130741, 11.361335439066734, 23.237172096006333, 35.86111653235651, 48.268499066752774, 48.12533255546324, 52.01593152938351, 42.05483321220645, 45.5192627445344, 49.69948168723814, 27.009864622546782, 25.30762068686947, 28.948086192530972, 22.77636028105213, 29.46655292664805, 28.287313907377182, 27.282537991000762, 25.66190092794357, 16.322029559843003, 14.508015724920458, 9.84983636486915, 7.3443091588635605, 7.34976762725461, 3.7483108284011966, 2.9936659288021827, 2.147151275027183, 1.1462018759019914, 0.6927953119720183, 0.3413100660808625, 0.22295194858264542, 0.30174168607880997, 0.17603407343549116, 0.15604431140086344, 0.21382742771698585, 0.26684432801219726, 0.1384787426720704, 0.2395100504039757, 0.10772931404531964, 0.07553671366505085, 0.45012792211867153, 0.29853732415264655, 0.2954115934910313, 0.8177494618200487, 1.0618193135146172, 1.2107925261220625, 1.9374276577464997, 2.8272125509477433, 5.147040534404017, 6.023633393549151, 8.06773248218721, 10.482288156786273, 15.686513416228758, 15.639300827057133, 21.688738023081136, 30.381849773468513, 19.516888318523286, 23.612480163574222, 17.064848023076213, 29.622645608840454, 26.49198820514064, 31.933447237937685, 43.509632464378114, 38.675028816346206, 43.34734832086871, 35.048899573664514, 26.513119974443992, 13.379093850812605, 4.651776090745003, 0.6050518299302747, 0.11457123763618932, 0.043984670041789936, 0.03211593796168605, 0.010680441609433582, 0.01086328860237113, 0.02972794231027365, 0.03921956867880879, 0.05474091605133107, 0.0351532390942016, 0.1517911751063601, 0.0709231636456905, 0.016667943507913622, 0.055034787379085064, 0.02267032666432281, 0.0257843246893777, 0.029936737658816482, 0.004851958496616252, 0.017122835026032502, 0.051016414898537824, 0.013105435477149104, 0.06305340286945144, 0.013087068519164479, 0.03233468670758509, 0.02072753917966639, 0.0194292557200477, 0.045518232509493835, 0.042329498776985754, 0.01575206336940849, 0.02109188676601456, 0.018608392509181174, 0.0363333860502368, 0.007730382569735089, 0.01612651852830764, 0.02906148795098547, 0.05402680719271303, 0.04284837395854054, 0.027091715019196275, 0.025104046273495884, 0.04895957607415415, 0.047197213786984646, 0.01708991239748655, 0.023075276910657846, 0.04998679655874449, 0.05263444239033326, 0.06051289826451291, 0.03433442516853252, 0.06287802619138552, 0.03229226841921768, 0.041938797766042334, 0.02240126509399664, 0.284694513726619, 0.19861419324672994, 0.20415043488385218, 0.10379581261546382, 0.08050325401728192, 0.14664638907678668, 0.195742083653327, 0.11625877611579434, 0.15958035875472332, 0.16474877093588153, 0.11183233541106025, 0.12592610858020284, 0.07154474440481394, 0.14013369177137652, 0.13513116826934202, 0.16900112582070215, 0.21655584985931076, 0.11667136042829483, 0.12753289373170945, 0.17334204046956955, 0.1767318263169258, 0.09980213497915577, 0.17850630045417817, 0.11109795586596574, 0.1773802278142783, 0.13204536611034026, 0.16207282581636984, 0.1241988024764484, 0.08603186541867834, 0.18309907416903204, 0.30905191155691303, 0.11971132754678689, 0.15526012847981147, 0.1560834278502772, 0.12928545775432743, 0.13241069811967113, 0.129935912367317, 0.13334667370204004, 0.17896886434285872, 0.14015909524694567, 0.08128637207611915, 0.1766916067009011, 0.21369241238121064, 0.1550693112996317, 0.11255325479132515, 0.1904002904531456, 0.15616726851271046, 0.16128121184245234, 0.10435417579907565, 0.12351811803396671, 0.22770209207890496, 0.14885771719198074, 0.1411087991249177, 0.1830738851980817, 0.09146250949631776, 0.21481918982200085, 1.1031033627448545, 4.1887574522726, 12.543066143989565, 23.87143700353561, 40.690523039910104, 54.567868709564216, 56.35618709748792, 60.589785575866706, 53.237020277207904, 55.883659162829005, 58.18278389592325, 34.359040952497914, 35.85845716537968, 41.72729176859702, 32.91040766623713, 38.23154603281329, 38.563092216368645, 31.908857899327433, 32.85516304354514, 20.129085971463113, 18.791522441371797, 14.252642950704022, 10.48691459240452, 8.410524591322869, 5.424941932001422, 3.957501125912513, 2.663744587090708, 1.6003271528790075, 1.3438278004046411, 0.7706276387456925, 0.6629836439125, 0.549145736280949, 0.49621852955991225, 1.1632927459093834, 0.6986955373037247, 0.6003928508970046, 0.3231451101601124, 0.5290454890458814, 0.5938189584882029, 0.43685397794169767, 1.1059017287146662, 0.692470858414327, 0.7037902058612916, 1.125141076983944, 1.340009863338163, 1.4996875918680623, 2.9025875128084615, 4.07650706268126, 6.2611515387412044, 6.686681143699154, 8.845684105350125, 15.253912268146394, 21.869906417785153, 23.034120798110965, 34.76026411979429, 32.43986052851523, 25.19236380054105, 30.328232934398038, 22.145458805945612, 37.338528248571585, 35.891095207583525, 37.93215936230075, 51.832611714639974, 43.606671902441214, 50.502253578555205, 41.08214816739483, 29.251171658116004, 15.03900952877537, 5.751721945501143, 0.8422062978629143, 0.1705040064670386, 0.1810481648651823, 0.07951562878705802, 0.1230249029674357, 0.15334503124317816, 0.16312818854085862, 0.127398721092651, 0.14930477546107385, 0.1074956572284141, 0.23870910547914045, 0.205731701646601, 0.07011132495057198, 0.09854129981249572, 0.2072564770858134, 0.20419787104812362, 0.17761515633713815, 0.18099273074298136, 0.12285480846560771, 0.17564318473300627, 0.14652205300667595, 0.16163240186870098, 0.09438875086245038, 0.17276894541517382, 0.05659395250521841, 0.11668908004198345, 0.11276660261735802, 0.12207000501333706, 0.134872445055554, 0.19133887073445707, 0.1891847081001728, 0.2575359613664689, 0.1282944310937197, 0.19126195550685932, 0.17147994119553797, 0.2582847357036606, 0.10906678098704546, 0.1532578044721196, 0.12644956879798444, 0.12109660603586705, 0.3082291331262358, 0.2097104712119026, 0.17699678548641745, 0.1443671242844674, 0.2351689978592819, 0.20172441828875773, 0.11733853107979221, 0.1870942226941547, 0.1781876998082284, 0.09664628940123705, 0.10345027631809635], [0.016114613521964322, 0.06567226677772499, 0.08153824646386408, 0.03458644128254345, 0.04021865841481955, 0.015265934616177073, 0.06406077018548405, 0.06521866611775852, 0.07471331470315495, 0.019673172369479172, 0.030861267887596643, 0.03639636996893152, 0.04659233374461051, 0.01038412167315161, 0.04284678432609766, 0.0574268892617716, 0.016678887073911967, 0.02575094049285737, 0.03738063973404708, 0.02391994438855158, 0.07072668507575028, 0.04086239443671319, 0.009028601869490118, 0.0415188858225461, 0.04117754768700369, 0.038147715911749876, 0.03249664918609685, 0.05956561905482124, 0.10633070562635699, 0.08101367541859228, 0.00686554208157524, 0.09099790781375863, 0.02247582651644705, 0.01376773763988768, 0.021618229389611273, 0.05136904900052375, 0.016562326796232693, 0.02960847664414154, 0.06208234812102972, 0.11139517499794883, 0.03662882785823557, 0.026054083399714965, 0.07076109774530896, 0.03158988070584113, 0.008409053158585825, 0.039597679034716664, 0.003271919868571023, 0.019603950579861, 0.01848210483008335, 0.06182349084185497, 0.035180948494422826, 0.039881610371653116, 0.01786252164522246, 0.005316654024946113, 0.052005051364821774, 0.033323438087057684, 0.06630304059193981, 0.2872641258422406, 1.6131102798446533, 6.281486086307034, 14.1178624668429, 20.667990215363044, 32.70201802253723, 45.91966613646477, 46.81787713881462, 42.95504462334418, 38.602402210235596, 30.715657203428208, 35.718644280587476, 41.79649806791737, 24.281277618100567, 27.279647204183764, 27.36202874491292, 17.98749343041451, 17.63226789812888, 13.609176162750492, 11.179185471227093, 14.305696929654768, 10.159155457250534, 7.137499249750569, 5.928326662509672, 4.6101533693652, 3.8987952566915944, 3.7319442485609366, 2.399340310404378, 1.2434288522889538, 1.5676468226217455, 1.353413460235442, 1.2224054384616114, 0.9369028551924614, 0.8992020749757368, 0.8952993779413162, 0.7054257729361135, 0.48359916154896065, 0.6990545567485594, 0.6828858727408994, 0.94789860710021, 1.4735827474824845, 1.5682614089981204, 1.2617599267152049, 2.36827195171387, 4.131054484075116, 6.552632181875168, 5.143510401248932, 7.588600747046932, 7.161752735414813, 12.134867041341721, 15.235543808629437, 15.500556788136883, 26.378804291448287, 19.050908780867054, 12.69459612907902, 15.567691095413702, 10.523487752483739, 25.316477398718558, 23.0044755243486, 25.443475900157807, 35.24297060505037, 33.600897789001465, 31.12411126013725, 24.918717684284335, 17.232231247809626, 9.558899460300323, 4.634621604796379, 0.44301121045024167, 0.06071492714146453, 0.021059226522582675, 0.09363259143766858, 0.06550599505463917, 0.02970327810955144, 0.03096633876163152, 0.014845496944842801, 0.020622226987935362, 0.030662508290861885, 0.02938296908753053, 0.019810292531826326, 0.0624768719107153, 0.01638706311613562, 0.04597037377196454, 0.08681728940216765, 0.029930706631632584, 0.010434081139523658, 0.04533953867071579, 0.11305248364806177, 0.05436427658423782, 0.054159129729434374, 0.04415052807739666, 0.0997199567275182, 0.058675118451637615, 0.018798692580012065, 0.02347098047574682, 0.024290458982690208, 0.07162221121571719, 0.0279351107911357, 0.013222883459210638, 0.06915097245045247, 0.043126678379673156, 0.05964187544680411, 0.044745797546760696, 0.027107312569334626, 0.035352889268148335, 0.016021759835101904, 0.06144906919930251, 0.02925738046366361, 0.03890457630698239, 0.06298474990011704, 0.009136808915965019, 0.03835565898747694, 0.03735162032347533, 0.00992764626824928, 0.033361730991952845, 0.07858369048805007, 0.02923159202891252, 0.05441090452574915, 0.018013147937674678, 0.024209962294046438, 0.01894437377491305, 0.04493900875170385, 0.05228579960643284, 0.007308037339469359, 0.02773148079042233, 0.041243098000244754, 0.014316225950155529, 0.015452952957862328, 0.023983165794502825, 0.04799157418611069, 0.03928318845048066, 0.04111104742473653, 0.03819250524224293, 0.06955406493357114, 0.04748763388863975, 0.022143166241866928, 0.045948593892277255, 0.04308273557633643, 0.05105603696598161, 0.0751400486596169, 0.035123859622305444, 0.04277889361424793, 0.017403483676213412, 0.010944223876351552, 0.013915749657298289, 0.031036795868027597, 0.06810618173931876, 0.040303560109027935, 0.0785460602492094, 0.023834404926146233, 0.060580118649428895, 0.09771151933819057, 0.03759352407688576, 0.044159897332710606, 0.0069687451374897316, 0.05163286669900821, 0.05613231175248662, 0.01930926145324784, 0.031061590303696936, 0.08541324941982185, 0.023421127304074266, 0.0668634722129472, 0.07137158555128882, 0.014218681889976707, 0.018500837595051816, 0.02481379279596431, 0.07640596298921494, 0.0719667362770246, 0.0625155287073745, 0.014066658444672584, 0.025162659660582582, 0.016017651688607953, 0.012872679771164493, 0.03249922324152243, 0.015095529848739747, 0.019624424279637395, 0.041941096029815175, 0.47525903810897185, 2.998580413479959, 8.824796503590001, 18.817657193829938, 26.850267302605417, 38.96502925503639, 52.42652131665138, 53.89970079545052, 48.297285341447406, 44.30730135210099, 31.543569526364728, 36.4051845765883, 45.45422200233706, 24.693359867219005, 25.38388333012981, 31.49320629335219, 21.53025661745379, 23.804560592097623, 16.381947686595304, 19.52100092364896, 22.516838619785926, 14.34559920141774, 9.522870529082514, 8.186373393381796, 6.834378482833986, 5.723178367460928, 3.6340119809873643, 3.1261282918914675, 2.0736972939583564, 1.4588259328757565, 1.4227690547704699, 1.6042771022165976, 1.327755030605101, 0.8237916892093997, 0.6811341667367566, 0.8325211691760248, 0.5581543786871819, 0.8596849309340601, 0.9310609138300343, 0.8916456901258039, 1.3049973162912554, 1.6636626446439375, 1.370294360864547, 2.7014010567818922, 4.13707189021572, 7.16582807802385, 6.857171866201586, 9.787280444175968, 7.652408884417627, 12.890372410897287, 20.621025716104818, 20.393002648507398, 27.845733473377845, 25.621847644928966, 16.882540179837136, 17.493476790766564, 17.951564519636094, 23.32530971496336, 27.516450497411913, 29.84259447743816, 38.533619526893865, 40.99368303052841, 37.526437236416726, 31.960184074217278, 22.014465370485862, 11.803176710682532, 5.646741178727919, 0.7627165245433009, 0.17762467114915773, 0.08999867635148187, 0.026050377449381257, 0.0476240013696013, 0.05310519192848475, 0.08391396938672951, 0.015646067444205044, 0.03044293983088386, 0.022643461876038103, 0.03900747340653212, 0.02514997899021593, 0.013855299574413128, 0.04901067030826404, 0.015815377663520556, 0.05050040488581985, 0.019576258416618073, 0.04775587574488694, 0.08311203620847195, 0.13196733239437305, 0.06317668173822664, 0.11755001731216909, 0.11124524393028791, 0.08219371129187845, 0.027261685031736572, 0.018428539962417657, 0.0043181575282717185, 0.036431414661027735, 0.0570153238462104, 0.025331984244046674, 0.023619293182667707, 0.13525087716839007, 0.035394717668814045, 0.022700464563264, 0.0737160137824474, 0.04379045143122635, 0.08165888232930053, 0.020196919870232383, 0.035516368600750164, 0.060558074469407724, 0.03545136987081459, 0.021743143856104825, 0.070639688131069, 0.05506618549266169, 0.04742453888719601, 0.019453347270046512, 0.05248586729829831, 0.029564727278005694, 0.05306639723599919, 0.10028650939104058, 0.05805025500575862, 0.016990947244208188, 0.13104595844784092, 0.22723586628994635, 0.18446732252355547, 0.10253886917545911, 0.12419963751228587, 0.1994808991589854, 0.1503493210240718, 0.15200656838715076, 0.21291679432315214, 0.2536867832344386, 0.15576386193354286, 0.16231988917195028, 0.18372148996399296, 0.11232404128438044, 0.12368340150363023, 0.1366765055084421, 0.12819965069572772, 0.13149494725850322, 0.14814640455428632, 0.16469807123705266, 0.14142421284510245, 0.10897029987386159, 0.13572436547087086, 0.17883554972227544, 0.1145321288476548, 0.1966966904940144, 0.17359212221157166, 0.15833122175066702, 0.20940873982204547, 0.1435212099984769, 0.11002989906457164, 0.2680219890129182, 0.08622888791104479, 0.17474575869498715, 0.09545590368009384, 0.2056354963250699, 0.14410841639243788, 0.07641122601325474, 0.15468805998323426, 0.15949035874537884, 0.17757364969340064, 0.12508252320150215, 0.09592715500583572, 0.14377501492779102, 0.1343962141583043, 0.12307315118490689, 0.12894949755601345, 0.14276462156445752, 0.14055079600263026, 0.20104722720721077, 0.16258596682981138, 0.14318174111746973, 0.11404139590599846, 0.2118795725607103, 0.1404594323567806, 0.0919496265029715, 0.15410417841086466, 0.5596695167403067, 3.1280348089433487, 9.101085316750313, 20.858525230038552, 31.32922768592835, 45.42588680021225, 59.74905298602197, 61.22904169944025, 56.93301085502871, 53.87005552168816, 45.6689090113486, 48.77175877171178, 55.14173107762491, 34.81233750620196, 37.110399276979514, 40.128592521913596, 29.2032834406822, 28.34246047081486, 25.077846280990112, 23.33699445570669, 24.65627189605467, 19.193939970385646, 14.535333071985553, 10.563882281703334, 8.15729441181306, 7.385003259105067, 5.684385636160451, 4.012742071382461, 2.359219611652436, 2.538024533179499, 2.302618584325237, 2.138375462062897, 1.287853862008741, 1.2752174562023533, 1.161818302446796, 1.3206282065760706, 0.9013911865411267, 1.4454583727544354, 1.3271829774302821, 1.4674946161047107, 1.9931164888604997, 2.02080731911044, 2.039962458995081, 3.538210050713632, 5.540081147224673, 8.715081926315062, 8.275571523174163, 12.163228719465195, 12.283946525666023, 19.13345898351362, 22.860261740223056, 25.058742377065844, 36.18034647357079, 29.067241914810676, 23.99194790470985, 26.920460078024096, 22.040592278203658, 35.180593152200025, 35.28533612528155, 37.23823324326546, 48.544990862569506, 46.533426853918264, 44.918143826146284, 35.505706648672785, 23.659419167426325, 13.117114824633445, 6.309903658205464, 0.9928324830628211, 0.24748111864732159, 0.250726466277434, 0.17765166808760938, 0.12519693843299343, 0.17961786338879218, 0.1630964878225519, 0.15262198213848377, 0.12890944647933208, 0.12683020724404243, 0.12014726221921945, 0.11208715157643442, 0.23867536696695515, 0.1875242738113288, 0.11908700419289452, 0.16437652881347364, 0.08166852737626723, 0.08055741643352855, 0.17292865942562782, 0.4155333526432515, 0.10712189825191613, 0.22349178009936888, 0.21859070196026759, 0.2202339758796077, 0.13037264377119082, 0.0926605944011, 0.10094344510786957, 0.0964333399409248, 0.21266611503256908, 0.10508784288240057, 0.13944451907469382, 0.2505756082433847, 0.31456029823710846, 0.21184725897206416, 0.2707003549702706, 0.10564229135671932, 0.26312984345901397, 0.10214234206585154, 0.12582472450430357, 0.1616865796067061, 0.09473485406488182, 0.19057912601818963, 0.13231846113358775, 0.13389359919294236, 0.16890580916116316, 0.08673516477668479, 0.15020115961951597, 0.1416724406543278, 0.1472395096695231, 0.28398867095670394, 0.11654690944499548, 0.12670478332907925], [0.02757169017117591, 0.034111482091248035, 0.129054865289119, 0.12312551329453146, 0.0369924514914953, 0.0866817454657247, 0.012521759790909148, 0.01729004520682558, 0.044635442581268094, 0.051396769892063834, 0.07073872031704073, 0.0371271642225404, 0.025695203765926343, 0.11970005839342072, 0.02995394207837601, 0.0895720113429331, 0.01223622733021095, 0.014884748417253216, 0.00928474623980301, 0.06578433011928875, 0.05195930825486299, 0.06721675365922913, 0.04400400610099878, 0.08479484026470492, 0.0456752039251789, 0.0337545502360069, 0.02452137703526645, 0.0914919579161271, 0.03712724083133283, 0.050663405413469004, 0.12394656036649981, 0.02299026030326082, 0.053177288463038784, 0.02389288233262637, 0.06729347736484582, 0.03583631373100704, 0.09768719604659466, 0.08071539142439443, 0.02469571566419496, 0.0521745598093877, 0.0033191994636229453, 0.060707339040574536, 0.05914707457826984, 0.023774519833105228, 0.019629283192297144, 0.027233504487441915, 0.05911398724082017, 0.04198971963036926, 0.024680713747417735, 0.031656118582994226, 0.0274518663589392, 0.0613659524899577, 0.049879199509779294, 0.1032206108192763, 0.030854656548810103, 0.0451232337452952, 0.09133453450856671, 0.06915718542351838, 0.062218367031985716, 1.073151163516506, 4.256983159049865, 10.755545958395928, 18.024463730473673, 31.756161989704257, 37.24737236576696, 44.20512753148233, 43.077230376581994, 43.729489157276774, 39.904962508909165, 29.551048624900083, 29.999067629537276, 32.96233984731859, 31.07671530016007, 26.123334438570087, 23.32970669192653, 23.852186010729884, 19.702430155969438, 14.183267989466268, 16.004205788335494, 20.200830044284945, 14.616487891443315, 13.16414894596223, 8.304865744806106, 8.505199820764604, 5.090901121016472, 2.620873816551701, 3.6609883269956036, 6.442961731264669, 4.250492126710953, 2.3179584837728933, 2.128171661207753, 2.520824694825757, 2.8597988668949377, 2.1388206510774554, 2.961374035766048, 2.2572325939132325, 4.311686004361799, 4.462988982277532, 3.806859312518951, 5.898294544989064, 6.388030898186469, 6.826411168421469, 7.201462320743069, 9.168414761943202, 13.064586443285789, 17.920511114981867, 11.21541444332369, 11.968154541907772, 16.529295444488525, 24.126155722525812, 12.217605517756555, 24.66357731050061, 21.62249703561106, 22.463992526454312, 22.497095369523574, 34.0083339906508, 36.800567334698094, 35.21386661837178, 28.42979596507165, 24.392782757359168, 16.990115104183076, 7.912096265823611, 3.5797695238744063, 0.46457827091217047, 0.03309027156642368, 0.08503477900258957, 0.061867782215197245, 0.059446718378533284, 0.02564007033323569, 0.059504757199676774, 0.08578291748680415, 0.0700883652954813, 0.06284397741359088, 0.05789647051583856, 0.044323066399703105, 0.06012377922513312, 0.08379941625941185, 0.04344339444932919, 0.039766972974663785, 0.026343258608493115, 0.04844897081174197, 0.03702545838971292, 0.07424331976160889, 0.07609434140425536, 0.06391821271409431, 0.04858842562703837, 0.016853202720202746, 0.025156873781534455, 0.06469945002707743, 0.035429210777604775, 0.018555869521092505, 0.029289345482304215, 0.023383016345061125, 0.05408817849632713, 0.06758163367668468, 0.0314113688129451, 0.023766477825120095, 0.03713184118931813, 0.06831582169979811, 0.05425515885074293, 0.030271339966284654, 0.07183103146211756, 0.02173883844197037, 0.05269220925026363, 0.020970400542982166, 0.027542940806597475, 0.03351559975154458, 0.07136688943231298, 0.08366227119920716, 0.03247844310657632, 0.022909420790270935, 0.026013965290340207, 0.13553698036459186, 0.01658973933738326, 0.043606199624557654, 0.02367045636469078, 0.04490953734925678, 0.040926565791690545, 0.056257130457989635, 0.028222142868945678, 0.011086012386987287, 0.03951412948569463, 0.08634968465494533, 0.08200274855499307, 0.06831177675555791, 0.02749152481555939, 0.06315328924345874, 0.10149440788213285, 0.05986936142547958, 0.018365977392081293, 0.15679676296009173, 0.026780658424080863, 0.08509797359546346, 0.02216936644887732, 0.06517085457040418, 0.038149033582979636, 0.042732583599225174, 0.013436651675991956, 0.03074762832012869, 0.034985799087031234, 0.07721596307331517, 0.12163980067857813, 0.04174157992125519, 0.06793943504171987, 0.02236449287363118, 0.08486368092558078, 0.09684605448837243, 0.0491147548440964, 0.01053067142023675, 0.039897303682782, 0.037365333297319954, 0.02972773355131428, 0.03692420071832115, 0.04277399065153253, 0.03113769730853458, 0.044898218400175535, 0.02776996713251837, 0.044048308965659914, 0.025261914012052362, 0.06479226923998326, 0.019423902680676793, 0.045039695687592037, 0.027250601654692043, 0.007823576208113903, 0.03452498570925767, 0.03967267138162448, 0.0473262268238731, 0.0342086220400468, 0.05191193337762549, 0.05434224389553551, 0.026334741625994928, 0.06820749686730486, 0.0805197861946879, 0.007301106158974431, 0.24742770699724076, 1.7976722601921329, 6.171264542687324, 13.83301700315168, 24.464407197890747, 37.94646032394902, 45.09500741958619, 50.72897049688524, 50.0113336501583, 49.46473567716537, 47.45003769474645, 38.58499473141086, 32.23590708548023, 36.90003864226803, 35.925627754580596, 26.62344644146581, 25.312345181742025, 27.49930189501855, 21.887786542215657, 20.5142411493486, 19.73009071042461, 26.126760628915605, 19.786090389374767, 15.779618717009022, 12.422812158061612, 12.696059173153294, 8.030316502817216, 4.4342492857287015, 6.708379695492407, 6.715099696190127, 5.414035781737297, 3.2959200970588194, 3.576774794247843, 2.6012099942853375, 3.0855383796076623, 2.8884044674135025, 2.8490187227725987, 2.5290288223374278, 4.45802326163938, 5.146909135003244, 5.574081232470851, 8.196372005247301, 8.189735845212015, 8.00078840986375, 10.499932939006436, 11.899405198712504, 15.646961216003666, 23.312826771889966, 18.6582540312121, 17.798564626324563, 20.61706412223078, 29.58689908827505, 18.27850191823898, 26.665239295651837, 24.403749704360965, 23.82926760181304, 29.119886006078413, 37.40732269902384, 39.238422378416985, 39.71452751467305, 34.31515355263987, 29.069879708751557, 19.369815126542125, 10.493836595166115, 4.545876999055186, 0.8410720587257416, 0.0949250813573599, 0.029331514792096232, 0.08836808118728862, 0.014340476463398626, 0.05274001696717836, 0.028304979956198125, 0.023293349583963716, 0.037341343253971114, 0.01711321296170354, 0.03787521460664369, 0.052489893090340405, 0.0020562266722516788, 0.050552518016869025, 0.06158048392183358, 0.009702693167773467, 0.06316864547590095, 0.05076952008230071, 0.018148988733188282, 0.032572246742464846, 0.054549558779164675, 0.058515726198111816, 0.03500094081485464, 0.038237114542073784, 0.04781488366725464, 0.035206869079340855, 0.042610442371017514, 0.0565320257878592, 0.04091398662797386, 0.024805147493738803, 0.03952798418580525, 0.0478611936822774, 0.005072991620944513, 0.019547240921266137, 0.05174592978531315, 0.08562668917640563, 0.004237549278073975, 0.025088990730563962, 0.07908189278696814, 0.006948089970636272, 0.01711274947850935, 0.022299471161057873, 0.031502876100280595, 0.06245876159218531, 0.07041886328689514, 0.02832069624996474, 0.05787341893019696, 0.02127172016057997, 0.01098065710281052, 0.06201066910439442, 0.050407371168295224, 0.018684924692816792, 0.06473927127738154, 0.1687241084272823, 0.13597769542567192, 0.178936091101458, 0.1376539877345485, 0.09664036754158237, 0.20193319256988265, 0.13484665853602273, 0.12347678759045179, 0.19228008635822805, 0.1663600223799867, 0.16891009925353914, 0.20993401566820763, 0.14369819163074418, 0.3443909346336319, 0.20991523119230426, 0.20114966848444557, 0.19115309441281905, 0.17623011533531452, 0.15389603232183766, 0.18266084123282664, 0.14436238986109534, 0.12687035025127474, 0.058272841852158315, 0.15027877964800404, 0.13642219496109795, 0.2083015282668414, 0.24827437204939706, 0.20502333078653584, 0.21702932284003307, 0.2025889944765837, 0.22584622876057703, 0.13701545344966073, 0.08820623745240512, 0.0817438721236202, 0.11705061991608913, 0.13092415046788033, 0.14081285935976814, 0.12000876118338878, 0.11131588489778581, 0.10820195199020448, 0.11986040059597262, 0.24619033710370142, 0.15378200779518775, 0.15252338662262888, 0.12023133270802999, 0.17572394572198394, 0.21929346505672703, 0.15014230874517273, 0.1271475208622794, 0.22693712264299395, 0.15163703821599483, 0.1476049182876464, 0.16563035427562653, 0.26094275436574416, 0.09929171357784541, 0.13626523886717137, 0.19377901399087524, 0.15181077163546317, 0.2390972515868564, 1.8888335362557445, 6.56792305169567, 14.565678488823677, 27.48905666412846, 43.884414934342914, 52.36103734662456, 59.35596481446297, 56.576228141784675, 60.71068871405817, 54.67548677998205, 43.43803744162283, 41.432188326312655, 46.87736772721814, 44.85781385052589, 37.598067560503566, 34.42392872225854, 36.51956873555338, 31.734169260148082, 27.40191140482503, 27.993736267089847, 30.890361532088253, 22.76523251687327, 20.31187234386321, 13.565451541254598, 13.230043784264597, 9.182815744030862, 5.857462671495253, 6.290464391631465, 8.669272565072584, 6.404007692490855, 4.1929127131738975, 3.658631963114585, 4.116121530532837, 4.049270614500969, 3.5933284221156954, 4.33326002090208, 3.194636899617411, 5.984372919605625, 6.054300935037675, 6.032018930681291, 9.038178343926708, 10.372002874651264, 11.447806050700526, 11.718125016458574, 15.770073629194691, 20.03589241735397, 28.317804451911684, 19.58036207383679, 20.618003529887048, 28.291502998721217, 34.788144326979115, 23.465132405680997, 38.130988228705625, 33.77745543756793, 34.235902063308224, 34.48410964781238, 47.71878673184303, 50.381523024651315, 47.102288200009255, 38.93329728034235, 32.66797184944153, 21.210875664987874, 11.570672335163241, 4.530616527603519, 0.9286461434056683, 0.13734566798854259, 0.17436824588766023, 0.25830397983231856, 0.1756557179314475, 0.12122785987993404, 0.11946179738809025, 0.26142998628558656, 0.18809373760896345, 0.14359470847393238, 0.10513314932224252, 0.14947035770502784, 0.10629554985151177, 0.14416970342638033, 0.14406329381369776, 0.10866158942301428, 0.13530485572353487, 0.2072033718709023, 0.11344996836757469, 0.12598175720702257, 0.17186516084738318, 0.2316766328388645, 0.11664753509384972, 0.15032799313625983, 0.12185316382636949, 0.23494701622234238, 0.08892476663834627, 0.13402947254719275, 0.15580185989458717, 0.187386209445615, 0.2453099641828768, 0.239245658139548, 0.09564400124814242, 0.162175404989431, 0.13981253239175967, 0.28933473892750283, 0.12215995905740608, 0.13205497285291073, 0.21496313774297315, 0.08395508532562564, 0.08901845153060653, 0.14948238528543903, 0.08508833620937602, 0.2197375968699494, 0.14989156816755572, 0.15929958753047452, 0.08337288914668946, 0.14834995411576765, 0.1530761497035142, 0.19670425944270628, 0.18097751623680516, 0.15785589483716797, 0.16798385298780857], [0.02697875535476112, 0.02543521650706328, 0.07188088080335049, 0.016356201264105977, 0.07836450507203419, 0.054941221230453065, 0.016862541331999728, 0.039624618516573985, 0.019450560625221942, 0.05469272146001459, 0.07660492368402981, 0.06432802761874853, 0.030570780753248164, 0.05357655433697566, 0.01867213102448131, 0.06560924838507368, 0.06703086242440247, 0.04440444791989942, 0.05801127645217123, 0.08338265676772402, 0.0454398540539607, 0.06194369769805382, 0.05223634863092054, 0.028959376091558128, 0.03706101253027878, 0.08281173740303324, 0.024862075487392086, 0.03595685766589257, 0.10009104205716042, 0.04530785327416755, 0.06990102615447776, 0.03249785194413797, 0.05260995438983364, 0.10647815456914325, 0.012922013918268345, 0.0041788123593094854, 0.07339181303377114, 0.0713995017952496, 0.04919204928521668, 0.07518043681498497, 0.05515813519577346, 0.07153580415873759, 0.036424178960582906, 0.01708510902620131, 0.03877501168678846, 0.06876415933572477, 0.01766778975574961, 0.031241278141556732, 0.018674459931771123, 0.025377170025040547, 0.035289242683399114, 0.024688338237484137, 0.09396107461784156, 0.02406293278439872, 0.02940766010133009, 0.0206710038060743, 0.010360992521107679, 0.027271366467879667, 0.01737490668141794, 0.11236668173824588, 0.8992356602703372, 3.639859009173609, 6.622127265699449, 16.60794484999872, 31.10305597705226, 40.28679347807362, 41.93479299545288, 42.56378035391531, 43.528957982217115, 42.51600196284633, 38.68791380236226, 34.12392623962895, 28.689317626337854, 30.555881415644002, 22.454843598027384, 17.576262335623465, 26.898618359719556, 21.440499059615597, 25.517687143818026, 11.838388808311956, 28.5371708485388, 18.896585087622366, 12.456212120671427, 12.341756378450702, 10.447205497372536, 10.30848793445095, 4.493924225530317, 10.638393586681737, 17.674751089465236, 10.704754206442065, 4.208425687205407, 6.65075566499464, 6.705777202883075, 5.175086952024891, 6.7064430252198255, 7.594891248210785, 9.263722473575223, 7.0373591780662546, 6.62239202568608, 4.524028906899114, 12.588637221244074, 12.42732680612995, 14.008637205246957, 19.380758539322887, 23.691635554836644, 22.041029622477872, 15.949776038046807, 24.10136045948152, 17.063785060759514, 20.607938728024884, 19.85091736239772, 16.2860986878795, 23.32978710051506, 31.51801528469209, 28.500986983699185, 40.50019002729847, 38.32927973039689, 33.01511141561693, 20.99354890085036, 12.121644731490845, 7.63541276416471, 2.5643402049618387, 0.7391359705117442, 0.07491442810503707, 0.08650972808320677, 0.10466372894663965, 0.023725022892317465, 0.08247467403810832, 0.01863681628639179, 0.0857299654894779, 0.044239229567709475, 0.0564037022301026, 0.0261014276334355, 0.06987926925742818, 0.00935148686215642, 0.03191959345713258, 0.08814052243026034, 0.07076814575421234, 0.04940591805103806, 0.03394017334006006, 0.03396050914401009, 0.03910429925928193, 0.03951701763716917, 0.03058325266465545, 0.08859947804481753, 0.05990044544300726, 0.022544544603255008, 0.0477263736989229, 0.042856931160654754, 0.018159185363460454, 0.008176854781566129, 0.030197132859499227, 0.019348778183602037, 0.007181823396334245, 0.08858629367164067, 0.06105118228362934, 0.016263889584449992, 0.019609908828692093, 0.06331837353026194, 0.06915603629163197, 0.025220430350952575, 0.052622970223667166, 0.053609787231130954, 0.08002519983077243, 0.043148331854852943, 0.07211048501513659, 0.05627776120579051, 0.028531443207494678, 0.07682277610705746, 0.07751227056066837, 0.11733472362280854, 0.03352893351186668, 0.03721689227067175, 0.09870701229139682, 0.041608261470232284, 0.08176671686552225, 0.07175796199589968, 0.02876690607668171, 0.026998367205622698, 0.04329722104293685, 0.05020847942139353, 0.06274424042672881, 0.018349837834736513, 0.08303374968348973, 0.04470031107625654, 0.07089299510323233, 0.07672170612720713, 0.07323085030000057, 0.06247049422874566, 0.03323027413458594, 0.08780974864719376, 0.0492590245219969, 0.04749371662675854, 0.012237522976412889, 0.04074666153399214, 0.029398467046238726, 0.04937527836450646, 0.04824799147524661, 0.011588368797674777, 0.028348296482656753, 0.025704423634095058, 0.052062948459699276, 0.015156483634435123, 0.02895020410388468, 0.044598609073868686, 0.10324760009684872, 0.05194223981591002, 0.04132863937786991, 0.008619554967979991, 0.03383275249131745, 0.02193547022949544, 0.04601806657569063, 0.05391560186962447, 0.044842960478197184, 0.03463135701754401, 0.019352945701910124, 0.03539613876191359, 0.012787670824646711, 0.07989648173773482, 0.08267218682674632, 0.07309892995943947, 0.042436459972973795, 0.07102178980506237, 0.045736896985721205, 0.025612745892196417, 0.0118057175178922, 0.04864061153644035, 0.04081956629130629, 0.005223501084988276, 0.05417756180489256, 0.0640442073645611, 0.05199062209876795, 0.028282878319582636, 0.05450709069508219, 0.04684749464955061, 0.2354876597922656, 1.4655855249974037, 5.351623517851676, 9.700141068427794, 22.10308151860391, 36.271051283805605, 47.31316658758348, 47.742477847683816, 49.16590206084713, 50.25716035596786, 45.32061038478729, 43.30199003219605, 38.87344583388298, 31.8837135453378, 29.859831333160404, 25.121967061873406, 19.339861946721232, 26.228842273835216, 20.919957391677364, 32.87853644740197, 19.209605916853874, 33.46346578290386, 21.16062814189542, 15.907799813055224, 18.914575038417695, 12.816627929287574, 14.77619601834205, 8.186354271827206, 14.793455427692784, 17.689595299382365, 10.333801930950536, 5.402924197335397, 8.399836132603308, 8.594197419381912, 7.042598974320197, 8.717836410768571, 9.913319926108084, 9.782729514183538, 9.62143773032773, 9.403958974346038, 7.963960295723331, 16.028833370054922, 16.953213445601925, 15.988221149290762, 26.988787766425844, 26.210042353599306, 29.05155243412141, 19.888432871910837, 25.245623703925844, 19.166044073720133, 23.665071302844634, 22.78453253930615, 22.71144897707047, 27.00418503053727, 36.6355336096979, 31.793789286767286, 45.848930112777225, 45.17010119653518, 38.13477723829208, 26.531961079566713, 15.983912425656474, 10.92847933692317, 3.821503971853564, 1.1130069797077486, 0.16386567074204647, 0.018559328408070633, 0.07742266125616527, 0.03904015854782155, 0.032821087422029625, 0.04112018685367319, 0.012108351933890054, 0.011748472555360247, 0.04681745634203957, 0.02833984461763213, 0.02544229132904401, 0.017792499293723417, 0.04236276231465801, 0.07360749742797307, 0.07431569208781566, 0.05423686850155073, 0.010445483400666667, 0.03013539191846165, 0.09852443055640306, 0.01727575383659813, 0.042525804977143006, 0.041787717566494985, 0.0734251301975981, 0.04813393247464011, 0.035085306247516025, 0.04241901615093793, 0.007958540311759158, 0.019188056767527616, 0.0327048565621578, 0.04223793977871538, 0.003708259131188595, 0.08731336197665623, 0.059225583268750104, 0.08256992174973411, 0.04831120905075823, 0.03505213080995506, 0.05828894885076631, 0.027041325585976727, 0.016395028515328324, 0.06341655152819811, 0.07003860022392004, 0.11105946760864989, 0.05052466689038181, 0.0682881506039731, 0.029548564738023187, 0.036001853840125185, 0.12034939451804084, 0.14236368178840608, 0.057459382881079955, 0.0781225898273049, 0.043157643653572574, 0.012215297808119608, 0.02140503286594345, 0.19074118425769193, 0.14135765512624096, 0.21930615147275312, 0.12668622867955318, 0.21947872043857652, 0.10663912496379307, 0.15442755944546194, 0.14136114848717568, 0.11284036156270774, 0.24501433085289695, 0.26437038495655985, 0.24852544970570073, 0.161571697061581, 0.11581917188220447, 0.15047212491833395, 0.2093302311315652, 0.14539856974396015, 0.14221228749280976, 0.12031574027552722, 0.18456355848860356, 0.2026084990751359, 0.12133004068727456, 0.11566719535978572, 0.09450613085420863, 0.1316111168313411, 0.12133023220925562, 0.055809681484055136, 0.12108106977276265, 0.17179978290392509, 0.137962261515279, 0.18119369092727863, 0.18424336437977132, 0.08369449285730239, 0.16461662076894315, 0.2516503376705993, 0.11158947021730485, 0.10599949517317357, 0.2732261162131064, 0.08164461011127119, 0.2245115197353786, 0.13149703101765725, 0.18478026944062403, 0.26861429755245486, 0.16743537999929922, 0.19590699173990758, 0.14728725226896425, 0.12249611843858035, 0.10649959737014388, 0.1419346878725675, 0.09185084712601478, 0.1359480325012438, 0.10614649212408452, 0.15689583345045968, 0.11888919262996606, 0.13398022841541998, 0.10996639803652802, 0.10203270722300777, 0.1011984681169833, 0.11958804101713243, 0.3537958590013366, 1.4173358366374047, 5.690250560160607, 10.799686351130086, 25.777997201488866, 40.53878222742389, 52.71989891605993, 56.15490282735517, 58.46917967642508, 58.43865971411429, 56.069963901273674, 52.512946821028194, 47.40118849662043, 40.91209773094424, 44.96698125716179, 33.18726032010971, 27.758239123129076, 43.21353274006998, 33.92163392036192, 41.12275254341864, 21.75457108405329, 41.56116370231875, 28.286509821491858, 22.45696363910552, 21.30877998567397, 19.172888609670824, 17.781300314011112, 9.171864486509754, 16.826640521326375, 22.402395625268262, 13.790994690310571, 8.095722025440585, 9.818310314609159, 10.174179115603048, 8.216730577330436, 10.34806170771199, 10.572815479770785, 11.958086798267981, 11.160783671563673, 11.382809435167621, 9.545375127946178, 18.621777949794648, 21.65330529212952, 22.074703170407204, 28.092860444899532, 33.43341258264358, 33.15807004128733, 26.854658396013324, 36.067488116602746, 28.389144520605768, 32.68362798998433, 32.37142301374866, 26.974100451315604, 33.68120047353929, 46.76801204681397, 42.41588346419796, 54.34183428364416, 49.174860754320704, 44.13405418395997, 28.96407573453842, 17.363579657769975, 11.30927578095467, 3.585761189460755, 1.1069543948096614, 0.28310420712636364, 0.177763854003241, 0.17901079999583383, 0.13417803231746922, 0.1496406437288369, 0.13889083668829935, 0.13918362017120087, 0.0955258934728561, 0.13867571919916138, 0.13944585206768206, 0.295158539327883, 0.09531547210269398, 0.0742566190479744, 0.16213786668114125, 0.16802696841618708, 0.2230393745365643, 0.1981032892100273, 0.08767811942004389, 0.22314917025787218, 0.110903637663972, 0.17499482920092924, 0.11613608713472083, 0.1233191879826688, 0.13781417671951557, 0.16267722322335168, 0.11409633973192786, 0.10484134643188409, 0.0997747396749835, 0.12122693291354565, 0.10793752142138059, 0.09266304588245769, 0.18331455938037367, 0.16409920498488412, 0.16148057856386708, 0.24955168576730838, 0.16667713681536336, 0.25531681915444715, 0.16805753532436588, 0.1236210419465938, 0.11636303302140967, 0.22706374165511903, 0.19883870297381956, 0.16964580413074265, 0.11282630384929719, 0.14875337601669375, 0.15146286046553045, 0.31561759150316643, 0.4589319271185706, 0.14499910085672332, 0.12477638680608043, 0.17435100890936392, 0.13675023381027485, 0.2724734501492593], [0.04025728456796177, 0.04580915056829972, 0.031208851554941748, 0.021799734771071423, 0.053175403886745055, 0.03186090920691288, 0.06813916948533828, 0.0317292416753668, 0.03805170594263942, 0.06151505235222079, 0.03566154609284094, 0.029704990316062208, 0.0509946656623675, 0.07863282736751341, 0.037350091978066394, 0.07345338352024555, 0.06292049427546802, 0.012089345292488654, 0.055620515223352186, 0.034146538274663116, 0.01505321785507183, 0.041633588337008996, 0.022505131294770588, 0.037641477350506096, 0.04969300567022255, 0.031965541495611115, 0.022337658728863445, 0.033836169243459745, 0.053320650326749014, 0.019005080497252847, 0.026373189663694754, 0.04638352881996863, 0.05117059392373889, 0.010289483959035528, 0.02705871578185789, 0.09216165665777461, 0.03485428477307001, 0.011946721746015453, 0.08435269261920646, 0.046850344496628935, 0.020017986628978003, 0.01763015185602971, 0.04719993722955546, 0.038911861803142295, 0.048059694724337715, 0.024371729420137503, 0.04019052766623997, 0.03905539220619587, 0.09022147770250037, 0.017792313517401778, 0.11085322907855434, 0.04846808470545277, 0.03365731069577798, 0.02012455520490485, 0.03517342934144601, 0.034731534504962545, 0.015164486380414137, 0.012954860895631776, 0.036251885786412225, 0.03530501643376004, 0.20141130283234582, 0.48107192941731025, 2.263452002117711, 5.959280537020776, 16.612459498067057, 23.530284935428252, 36.23595783787389, 42.236827265831735, 46.209360630281516, 44.0251652656063, 47.633490870075846, 43.346324582253736, 36.545691720901, 34.744394210077104, 25.305620278081587, 24.89745059321004, 23.311391184406897, 25.830431445952385, 15.877646592355545, 23.221912114850937, 17.81961794822447, 18.833803630644276, 20.65805289053148, 20.215560505467078, 22.41053258219073, 15.091664406561083, 18.34060480517726, 10.181551210341915, 24.412178877861272, 37.17820921251851, 18.57368184674171, 8.127208361702582, 7.54600037490168, 10.360534844859954, 11.2182395304403, 12.31614035944785, 13.413896060759022, 10.84433469080156, 13.586635281962733, 15.05014709887966, 11.704304545156418, 17.109678752960697, 24.757918157885154, 17.77480290782067, 26.260564442603822, 27.55011816178599, 24.54226624581122, 25.083345443971698, 25.214970381029193, 19.61752849240457, 20.75743594477254, 27.654408101112615, 26.5341870246395, 36.08170278610722, 38.96525283013621, 31.731221598963586, 25.22368392636699, 18.357294490260465, 9.803834807488228, 4.666733559100859, 2.065854269650675, 0.46682833243281613, 0.20933603807803125, 0.030036288869356918, 0.054859464327173854, 0.07408166754870646, 0.09889126409806552, 0.02838625613930485, 0.09599082457322268, 0.054237776315741004, 0.03402274229653901, 0.04178885137662292, 0.010135844068211174, 0.0040348840693402435, 0.03667115421605207, 0.0509091702500178, 0.04437558938779178, 0.07382695097476244, 0.08318883652288107, 0.04104656197371022, 0.07183652431253465, 0.05974932310862407, 0.11125067549367106, 0.02991340453586271, 0.009224369892880563, 0.03854857524856925, 0.09140652379081135, 0.02820513380180684, 0.03214286212178488, 0.013552742724817608, 0.0143759798506395, 0.053984166738847573, 0.027287019559392528, 0.03622352138101574, 0.04288480143934008, 0.05226887672418549, 0.017709273416849396, 0.036386625330534675, 0.043545291804137735, 0.08363106077717197, 0.02925123643851088, 0.08166396149223851, 0.04085197181050335, 0.00663385841987967, 0.02798006483053248, 0.010257643429682621, 0.016229203038458383, 0.019373017205526272, 0.05827902801214688, 0.005089627699025216, 0.02853039366703841, 0.11827801534485434, 0.051742616455040635, 0.03222848393864209, 0.009923311168207757, 0.06840670271025551, 0.029311782282386577, 0.05050876673551337, 0.031685827472697825, 0.01616145596809445, 0.015384810394607486, 0.03975368901005676, 0.0823691301047802, 0.051616227269292846, 0.016827598146553484, 0.01832210545187756, 0.0830930219061913, 0.028848149701051658, 0.025237887579527114, 0.06810791309802763, 0.02482587017209059, 0.04684354929674057, 0.04077075116877114, 0.029280117953256257, 0.06499050981214931, 0.05552479253721334, 0.016375403257928068, 0.07119773721863186, 0.09065226426408177, 0.05193113537144758, 0.07641065144731153, 0.0923738630128003, 0.039091501760506825, 0.06620313506573439, 0.027797952324392337, 0.029448513655112158, 0.04290946564006229, 0.08994060688682141, 0.07027046439508278, 0.011264678455078074, 0.007849706509601205, 0.09332656229455626, 0.02260233636104292, 0.02870035601869947, 0.07956203073263168, 0.018807307238720598, 0.017010066883578416, 0.024079579874993335, 0.013903046004293908, 0.0661044322975701, 0.03820860841041131, 0.02775376628813965, 0.035441770789123354, 0.034892355512467124, 0.016243333530221737, 0.039829773032256675, 0.049358037555770534, 0.022704097735244903, 0.01861925946638709, 0.03182057659291933, 0.09907489537351555, 0.0494015398585508, 0.01871045265767363, 0.04151429695587966, 0.05070125398736808, 0.06291320494886848, 0.21154949591765482, 0.8729337167836005, 3.0792135577048025, 8.227438157604587, 20.615161772697203, 30.451818973787372, 43.0509897201292, 47.6650502604823, 51.48368158648091, 50.03407947478756, 52.07162134109005, 48.95840475636144, 39.89429366204047, 39.021793796170144, 25.434525051424583, 27.331142040991015, 25.75264692306519, 28.979963294921387, 22.784352110278224, 20.428839383586762, 23.575835420239358, 22.46977213890322, 23.257835142074093, 26.816072079443163, 29.132910236235592, 22.48486541932629, 18.51046500667449, 16.05092121708778, 30.94664166050573, 37.418987827916304, 20.34880538140574, 14.126030802726747, 12.692727119691911, 14.946906393574132, 16.685233193059123, 15.661281789502791, 18.283073440674816, 13.204468950148552, 15.737450295878997, 15.074212801071907, 19.620146674494592, 26.67121502660936, 28.667499442254346, 22.698197249443304, 33.48038296545706, 33.62706392042099, 23.307462930679325, 27.966579737201815, 25.722838870940674, 24.2220635567942, 24.759534174396148, 28.180354795148297, 29.773441130115142, 40.49007815699424, 43.42454448823006, 39.13308320506927, 30.186172531497096, 23.19461045726653, 12.046029279308936, 6.658335645352641, 2.7219327034488803, 0.6302601062963087, 0.10740444680014927, 0.03118139879417516, 0.0331227766770509, 0.07064054614954418, 0.05448344922173889, 0.03338185229128407, 0.21200219259387065, 0.036360911589356205, 0.022073048129377347, 0.0743723979159709, 0.007464365241298032, 0.036792973687331525, 0.023480319087543798, 0.046164872004620494, 0.03988524928929345, 0.033550341838910695, 0.03295093549475555, 0.10169830984405934, 0.053075735847796165, 0.015305538489032659, 0.017809044877668063, 0.02388290595263243, 0.02449605782936898, 0.05105422516804069, 0.015477275291848329, 0.029421353922976606, 0.02892135514787609, 0.06966149344319297, 0.07083403697657971, 0.028114965253119028, 0.04718062798342398, 0.023078203366528598, 0.023510803641270728, 0.02379959963652636, 0.010507939676303538, 0.09065817080197797, 0.04366264881325826, 0.08953254249307419, 0.013158241917769755, 0.016059249305286478, 0.07210917500478607, 0.040061809573202364, 0.015136490654831213, 0.03617202878118523, 0.025116018312532577, 0.037274678282800226, 0.047492192111789226, 0.012317327313095093, 0.03245475949839719, 0.03839122078892204, 0.06428294334440462, 0.07757187986205663, 0.016445241748325286, 0.06911528807493948, 0.09477026264874205, 0.3334994932576534, 0.14825783970375217, 0.16461472087089093, 0.1839590844728293, 0.12200229816258916, 0.22365855744048474, 0.11352246326784934, 0.1404985181626774, 0.15358409664082914, 0.15968733527246984, 0.15121593500577635, 0.1391527008625769, 0.14544030621407494, 0.15304831006834585, 0.10572868309194043, 0.17830797561234046, 0.11882187648405952, 0.19560915207670582, 0.26329151865455414, 0.09036894196704512, 0.1297486191915889, 0.23237627029659289, 0.07922766399720023, 0.1864842941323596, 0.21762788265703187, 0.13111616274522198, 0.218565252519423, 0.12409176467166794, 0.1085497176034316, 0.08729830068806488, 0.20082791155624777, 0.13461229691822685, 0.09851782687849577, 0.0817975442435953, 0.2625537146964381, 0.171753557158574, 0.1274674161968212, 0.30791754984567243, 0.19235096481298247, 0.10589136952354063, 0.10283357553905058, 0.13303896682637353, 0.21364226426568725, 0.11617676640350012, 0.24810042412530994, 0.12221816641789292, 0.18959592877616807, 0.2134004103079919, 0.12872463542847865, 0.253561757685196, 0.23022229152341045, 0.12672693859184944, 0.10298487024321672, 0.21308335715964918, 0.14985887153494745, 0.11571847728543705, 0.14834387137764884, 0.1200506815146054, 0.1336505807816021, 0.3550018652552559, 0.8790524916783456, 3.5431436569459978, 9.644608151528145, 23.973414705645656, 34.00517256029191, 47.34638514057283, 55.382901930039935, 59.156586816233975, 58.44457464833414, 61.72997543888708, 56.40844091292351, 48.86549949645997, 47.1331415637847, 36.83077742976528, 36.98447550496748, 33.9445052608367, 36.660883888121575, 26.69425699018663, 33.825225983896566, 30.232923261580932, 31.427430106747536, 31.43987382611921, 31.81293437557836, 34.565290943268806, 25.553555257858772, 27.746948580588064, 18.056083917617798, 33.808916768720074, 45.90218021023659, 27.111455971194854, 15.570558348009664, 15.056088509098178, 18.944543907719275, 20.023081956371186, 20.0694247599571, 21.564016457526915, 19.403218030929565, 23.137273250087617, 25.64146145697563, 20.05140539138548, 30.454562671722908, 36.027860410751835, 28.47550726705982, 37.20404978721373, 37.750016258608916, 37.45207694268996, 36.52452268908101, 36.15146998436221, 31.257428699924102, 33.23024165245795, 40.79124166119484, 38.359364309618556, 49.78148668043075, 50.76220081698511, 44.38703137059366, 34.71862423804499, 25.246135573233328, 14.054496576709134, 7.398133393256896, 2.7251193840657515, 0.6229809227008974, 0.2874442484349974, 0.11151245539827694, 0.23222715894301094, 0.22893642826426416, 0.1762982971605755, 0.15055005138199176, 0.24742056705778648, 0.14773141472570359, 0.12792935955428308, 0.18966642418696036, 0.10261527878502685, 0.10901559865282429, 0.149323774441596, 0.15273447448928512, 0.08625779240842789, 0.15210761538436338, 0.18761592857058973, 0.17125970623906583, 0.12826265376662055, 0.12365848066345339, 0.20415921425146444, 0.11037829286989667, 0.09830676199447724, 0.1454565319563112, 0.18772547914376184, 0.12467661151482214, 0.14261817619685205, 0.12041500228787623, 0.19691410624692518, 0.13961719529282662, 0.20850138528452766, 0.11124001921064432, 0.18963149057761317, 0.16222507813044135, 0.08965171513057525, 0.165817785347181, 0.10733993453604561, 0.3000347502529621, 0.16137481246504093, 0.1611547460479121, 0.17652757195455415, 0.14758083248330703, 0.12624494671340913, 0.1639800017038661, 0.16406741233602648, 0.1708438737137664, 0.1738416523702683, 0.11635787724967926, 0.23099772572036714, 0.20588061381732264, 0.08216627768330997, 0.10651040687075547, 0.12139272966211843, 0.13313508021735376], [0.021270312474019105, 0.020851070857456615, 0.08368310879074758, 0.027085186034861593, 0.013900411619444289, 0.0799149674393477, 0.03038372314955679, 0.07015312270772073, 0.016720127502095797, 0.09106333938337142, 0.04111937863091308, 0.02530973322028595, 0.0400209924085967, 0.05530738444518178, 0.03093153155679184, 0.0024156246124015703, 0.024915060043455135, 0.038881915426182176, 0.031361201545223594, 0.08442049140050527, 0.07337297493171308, 0.012657186898943639, 0.02237165196528358, 0.029649506398146192, 0.02444599206829744, 0.009154692280947441, 0.060049706183734446, 0.01110516650031411, 0.05291245952849427, 0.00436841145968966, 0.03645289959686418, 0.12036630973940897, 0.0961043511427218, 0.05769460634779065, 0.032151974737644196, 0.043331898012829405, 0.02840834628460148, 0.028640773530388554, 0.12037314324369354, 0.042919742709566513, 0.14218205766331765, 0.05465792957693339, 0.03928161797023589, 0.06731475928738233, 0.05369098872066506, 0.021787111557299094, 0.03378049380356266, 0.021759400241858056, 0.007460509425014138, 0.0574148808335585, 0.09806208883322055, 0.008954841008920585, 0.027515189271540414, 0.0381359794447499, 0.010885198717005553, 0.053603145248827436, 0.06403519050969232, 0.04087486634812048, 0.030291873037875183, 0.016828689821845582, 0.05115968483169714, 0.05095651065329871, 0.2529919721306332, 1.7755885806775864, 4.216198844294395, 10.459944375099676, 18.747215347905314, 30.463021262999508, 32.54770609640306, 44.90523922827936, 48.568756503443566, 48.688314268665934, 47.38702874029837, 39.11498146672403, 42.99184822267102, 26.253829733017955, 32.257274196993926, 23.638461943595644, 21.686967072948335, 29.407197660015477, 31.158367280037176, 28.347522289522235, 22.060817979997207, 26.611157655715946, 18.936985500397224, 17.661687635606338, 19.00820593680105, 16.879580751542125, 15.43134460526128, 40.98324952587005, 51.860703729814105, 19.834743468992173, 10.916050326439644, 13.99894698973625, 16.77452006647664, 24.48581353310616, 19.14524374469634, 19.445699261080836, 23.16180963670054, 19.211382750541933, 16.664283813968783, 17.858741629508234, 34.555806652192146, 32.17099774268366, 28.178595612126013, 22.342218622084587, 24.456203560675345, 22.768872476393177, 23.150428879645563, 22.31906290977232, 26.6247800473244, 31.382275781323834, 38.953454340657885, 36.07692926160751, 30.508110869315367, 25.13499325321567, 14.73192422620712, 7.025167961274424, 3.47582794004871, 1.2012339551602642, 0.25216760023707346, 0.04533179352180131, 0.04772656522090397, 0.017913004924212734, 0.013546961633819006, 0.009378793108607493, 0.03255189561675633, 0.05793831806870238, 0.01145781783927833, 0.028457167152796062, 0.051560946364676764, 0.022693598500242638, 0.06055791742138325, 0.06240810019775264, 0.014388746705897635, 0.02117486366431319, 0.05348046775907279, 0.04934687182427414, 0.022724259254192154, 0.025968003845323, 0.04383814806539205, 0.05901032405334616, 0.01338393237787269, 0.09604134041094974, 0.021797877007855043, 0.027214501676480138, 0.037217271484194264, 0.07491455833998419, 0.02024224929271206, 0.04085315924678599, 0.01779368673000605, 0.06437069105525171, 0.02809038532206849, 0.057390063415251436, 0.02305272519738684, 0.026631725185941306, 0.056325599566222205, 0.016978879444180958, 0.03664584650147346, 0.0755968592279861, 0.04825034336517415, 0.018553621053034743, 0.10755549635617964, 0.029183836022932685, 0.05777833209703526, 0.05823669782389076, 0.06308116972626698, 0.014752400025064427, 0.06715863056841397, 0.01395334829501207, 0.03210180555470288, 0.10266909646170755, 0.026935457980500597, 0.01754051190800965, 0.01471993130361361, 0.01570602244276914, 0.009997166832157922, 0.0054820006968633785, 0.04881881507894686, 0.03835738268530658, 0.02805998120757361, 0.055794313760294076, 0.07926992906798279, 0.04795478281354712, 0.08546198793356458, 0.0738347267671939, 0.019438847140859694, 0.049276920335908095, 0.011247089076336595, 0.031110782724534793, 0.0810599088248226, 0.0361351722911481, 0.03862780789213796, 0.05187683122893495, 0.04234975031126411, 0.04037395975882969, 0.05876189323082086, 0.024839544841538996, 0.08624008045561853, 0.04461954242639965, 0.03612745395531097, 0.03068661707783899, 0.09421817372523009, 0.027578642419088754, 0.021663959093031385, 0.031147955225840695, 0.12842629780812612, 0.03045121358046609, 0.027895207186379743, 0.036560852876714164, 0.09849452248383915, 0.07450797249593082, 0.014119906343459604, 0.009733356794552698, 0.044342256902206334, 0.10137132819621794, 0.0871904584909639, 0.05033213750369126, 0.02689536476898338, 0.048615361278456067, 0.09136256566571613, 0.054283772234714804, 0.05573452059780398, 0.0441069913006598, 0.01373001738571592, 0.09098094662711506, 0.07106260696966803, 0.036818082219049815, 0.08859635240608647, 0.017644663476535392, 0.044158813318297754, 0.04828716921169431, 0.08120182661279556, 0.034530007415601326, 0.09710730579231056, 0.037548405328585256, 0.05243298424888523, 0.06675106413181751, 0.4487825491495671, 2.5881301155013423, 6.056798994541169, 14.186449031676016, 23.842615427509433, 36.96774659618255, 39.306346062690984, 49.51720130059027, 57.01436865714289, 53.6477473474318, 50.80760225172966, 43.521560392072125, 46.219225391264885, 31.671305433396373, 33.92010419599472, 25.770148538774063, 22.621632583679695, 29.764462824790712, 33.14135289961292, 30.25933061876605, 25.37835474937193, 25.17929054075672, 21.840533748749767, 21.716492714420443, 25.36753293006651, 20.005823527612996, 26.18167381132803, 51.179603761242284, 55.20024891822569, 21.291825540604133, 18.95211212096676, 20.835667617859382, 23.434822290174424, 28.084021383716216, 24.861064726306548, 26.037660068081273, 27.568133607987438, 27.77537399722684, 20.40157694970408, 24.2903834004556, 39.71661029323455, 30.32803289351925, 30.911916917370213, 27.540071010589603, 26.27580285072327, 27.522033991352206, 28.91647973368245, 26.915996420768003, 29.674181630534513, 36.08062021193966, 41.28755877094884, 41.208554390938055, 35.44611407864478, 28.76765520341935, 18.837031741296094, 9.79755215106472, 5.081920364210683, 1.8793628509006195, 0.4161526274777228, 0.04942964762449265, 0.030855031931893002, 0.02839520979191988, 0.06478807873903744, 0.07487858285105999, 0.0261805874986514, 0.015496622842376032, 0.004674026436517917, 0.035190792724249825, 0.06943984888494015, 0.035432531768756534, 0.026821253423188484, 0.08424727892082545, 0.06668802275652848, 0.043296171502480586, 0.06665147270166105, 0.04285774704429411, 0.03245789662844712, 0.007942741663540684, 0.025612142597956043, 0.10382030444640307, 0.037350149434660716, 0.0319556953505643, 0.028742017795241652, 0.07672350643382919, 0.0629671145561001, 0.03272611550205658, 0.036888271194672397, 0.04224300745033449, 0.028193382013048378, 0.07098136334529809, 0.06844279311236835, 0.04514175009042506, 0.03140058037975142, 0.031235750817183047, 0.10012206095721453, 0.013524118807136774, 0.05055464008041928, 0.039385844232334245, 0.051398551046487786, 0.029455910234021086, 0.09919620539632537, 0.04068204201757908, 0.025367388997467297, 0.04696460651053537, 0.04631743841474095, 0.08101634906544801, 0.04939254981675937, 0.0384433837156863, 0.05498615228721211, 0.07603245682173199, 0.022406847959744836, 0.058924093196589145, 0.13051440068069967, 0.030240579620904984, 0.11891855678010373, 0.15051219131677382, 0.2107117021636617, 0.13857226668586656, 0.11160857645013642, 0.20917299924598587, 0.23714867630793204, 0.20964481747679173, 0.11851217777978991, 0.24280147056185433, 0.22561327674456183, 0.20822979179361176, 0.10987496544276515, 0.18246781771942494, 0.11207772103408653, 0.16043722809803102, 0.21188482792387087, 0.14348376362073806, 0.1624334693676041, 0.1188807733236782, 0.18055109637639216, 0.20447600692991288, 0.12393458641224331, 0.24523615927225162, 0.16748039532572995, 0.12450820240642756, 0.2176864270962054, 0.12973395626871817, 0.07655689763205667, 0.14148667965444828, 0.15746076200758258, 0.1936128495200988, 0.21587603875706274, 0.11082227912641342, 0.1344624194767206, 0.11623784659370301, 0.12777522266391786, 0.10035273769209463, 0.1727993131404923, 0.2944207966568009, 0.15603634408645092, 0.1393351830061405, 0.15619135431704984, 0.20005246203753257, 0.2512265531526458, 0.199624540644788, 0.12889319009357883, 0.10014230100017402, 0.28061653577512313, 0.23267505990882076, 0.2592001188426249, 0.1389091921549651, 0.31205764220606896, 0.08832485084572146, 0.13057197984908858, 0.1071900417727809, 0.1478900562130636, 0.10997045064164747, 0.18075997790982648, 0.11374426870456628, 0.12031911106239404, 0.1250535957214813, 0.469808598319369, 2.675744833484773, 6.338172670333616, 16.238228121111472, 26.690295396312592, 41.08337586925876, 44.45687701625209, 55.73805685966246, 62.97946606912921, 60.20210635277533, 60.964677872196326, 53.77089015899166, 56.31729287485923, 40.59272266203358, 46.53261492329259, 35.43408416932629, 34.102525787968794, 42.72652733710505, 44.79047459940757, 39.527359854790475, 34.6021298439272, 40.14010860073952, 30.67900657653809, 29.921867539805753, 32.270372952184374, 29.819825118587865, 26.583526519037065, 52.54636149252615, 65.9282333620133, 32.1799329019362, 24.660741436866022, 25.160202326313144, 27.62992270531193, 36.42780096300187, 32.50084357876932, 31.012410002370036, 37.36142704563756, 30.78265128597137, 27.661305589060632, 30.09167478930566, 46.62651646521784, 45.229811437668346, 40.80236550300352, 33.057759346500525, 38.5784012271512, 34.62778214485415, 36.185865248403246, 35.46766358037149, 38.734346820462136, 43.87147895751461, 50.670425199693256, 48.92454293466384, 42.03902998278218, 33.229445411312966, 20.24813775093325, 10.518740703982692, 4.816984361217869, 2.2488617656692385, 0.4155385007541026, 0.21321389854194658, 0.18764415124972023, 0.12896583055055913, 0.0825630269584156, 0.25862193696441194, 0.0785303631076409, 0.1196501401042746, 0.16768829626662118, 0.18326670952862312, 0.16557067602632508, 0.06638070658570336, 0.14744592439984122, 0.29193545421285017, 0.10650139767676593, 0.09373926152024539, 0.27962331810305197, 0.2732866678026415, 0.09112918464046332, 0.16060043546941974, 0.25232484744441125, 0.2233071375878588, 0.15911868352803493, 0.2885659237302119, 0.10365752608425195, 0.09220367658042139, 0.12525232658991892, 0.18019868060946467, 0.14137245594493805, 0.14240964706386292, 0.08665474852727306, 0.14303256847685383, 0.14493044405694933, 0.14582730318990447, 0.14908749760398943, 0.06180768261753744, 0.2642636842304661, 0.13731343100868887, 0.08011644090255422, 0.16662852087568852, 0.25619510831611775, 0.07472041633821304, 0.17582428791830618, 0.09603140425057181, 0.11011933982973138, 0.1419519401726223, 0.07625415500613951, 0.22134069713854024, 0.10766498564231781, 0.1520088972944406, 0.18687464657329744, 0.2078894495723709, 0.1674501808179963, 0.16316755013840814, 0.21560473637955807, 0.0930698155876129], [0.06258006778455551, 0.07967963288988798, 0.03255606313506442, 0.025803616698530894, 0.02232862463701637, 0.02647393980183669, 0.055682874780388615, 0.07483192043559206, 0.05150845785054469, 0.05626490241998146, 0.017798564794863907, 0.04246361778988954, 0.0240284415908278, 0.10097025052434015, 0.015762842226503117, 0.011658828776900568, 0.0677526091796256, 0.03160000264254068, 0.014213827765366484, 0.01730525588256217, 0.03192608413707105, 0.0187572663755066, 0.07073630714007924, 0.03483779090006025, 0.05901022829235562, 0.010568249948142518, 0.07060043378582886, 0.02028461395492477, 0.017513695000220212, 0.07207493853544997, 0.02881920498405253, 0.03997069490592807, 0.03343034565689103, 0.014918536725153607, 0.045351570081566615, 0.061898804945690986, 0.03445069433280057, 0.02520037033865529, 0.011021463733707226, 0.051143095197696845, 0.025834342569953976, 0.016692349153961387, 0.05083560665708877, 0.06003354555897175, 0.028826478988893574, 0.060604809663228454, 0.06965426157318777, 0.03877205841784035, 0.06788475934656397, 0.05048619012438482, 0.05384243281197645, 0.033391995295401544, 0.027661822330687317, 0.026454707164497628, 0.025512591387415608, 0.07171702991810537, 0.022065753057118387, 0.04065752337356249, 0.031536940199833725, 0.03753900159931472, 0.08005866255130499, 0.01931952511621339, 0.08423239383245669, 0.03483311776372214, 0.4742660349415195, 3.713615503041975, 8.723848423650189, 13.060455206901798, 23.57318585918796, 31.629073273751047, 39.47580422124555, 45.0100371145433, 54.35294635834233, 46.73214197158814, 44.939238332933, 38.18014729407526, 43.067491131444136, 35.187939751532774, 27.589018267969934, 34.97753597074939, 31.056846534052205, 24.993683984202725, 27.31127327488315, 28.76896135268673, 27.762345844699492, 21.53179418656134, 19.43878412246704, 18.485822716066917, 14.145757382915868, 18.320730155514134, 64.17341593773135, 57.32644811753304, 25.048130404564645, 18.81704334289797, 29.215527119175082, 28.440894311474217, 25.372206434126824, 17.106556546303533, 19.968074637074626, 15.675578828780884, 29.64466775617292, 22.21344917051254, 20.63920786303859, 25.645389710703206, 42.793458661725445, 27.622279967031172, 24.72636268984887, 26.372632441982148, 26.05773868099336, 33.60163519459386, 34.87062784933275, 34.55528105458906, 37.92913129252773, 29.215409448069913, 20.96996957255948, 12.584430479234266, 6.400202012831166, 1.412829768753821, 0.28455925324270803, 0.09032316055269012, 0.06001466532207786, 0.0583114258704647, 0.03550113494237585, 0.023453873732397636, 0.03541213084733294, 0.05589944017570346, 0.03938633069816617, 0.02722647371551683, 0.023113412767528527, 0.027542393053731615, 0.02271787965700271, 0.021990804760266217, 0.035992254758433956, 0.056622179014788526, 0.03310384664444193, 0.011521442398999729, 0.01990888038680198, 0.020148822955126246, 0.05365671011649313, 0.04212227965434713, 0.06558206758552021, 0.011995124138681399, 0.03982220408356479, 0.015852542503947215, 0.0655631835181867, 0.04456601586313017, 0.012458904191941745, 0.0636746810238448, 0.0677728875269813, 0.01106937391488182, 0.028313629088863253, 0.027156236859398986, 0.030500553473229372, 0.08960604096852964, 0.029986927909175717, 0.02451879914940125, 0.04756420054623196, 0.041028692972876375, 0.031241967620688583, 0.06662868924679295, 0.07706272250582134, 0.05274866609984348, 0.076076629451446, 0.021469922428349816, 0.08401001382979655, 0.06771073481368442, 0.03678645810953552, 0.029073751103433392, 0.01756689789134168, 0.06891684831991311, 0.013470689920077642, 0.07275745392807069, 0.044442648894243666, 0.12959164777590385, 0.13542382917817564, 0.05168792543812625, 0.10647985528433516, 0.058339395740580176, 0.05308459948508009, 0.05156397624241729, 0.020650116418818795, 0.07892594026822237, 0.052385969432972135, 0.04777559484805792, 0.01619619039458133, 0.10671083845438496, 0.08948059407092872, 0.03566255732890099, 0.010118499837605464, 0.1507917061568268, 0.07203180778531298, 0.017287141733592557, 0.05200394819821081, 0.04812518375054483, 0.03477051305854994, 0.03132816208826919, 0.03055209395355515, 0.03767479451433305, 0.05582652775751007, 0.06686457537955816, 0.013365307822823526, 0.04428187768245417, 0.0047709174067412895, 0.07904657613365881, 0.06718350544331536, 0.07776235996354973, 0.0761592443732004, 0.04277396000801556, 0.00839872916619624, 0.047028582513092027, 0.048744531363369, 0.045168314189199484, 0.012904574884282006, 0.029897874018417734, 0.06947926410864438, 0.09697383029326316, 0.01805460861613674, 0.013077208967578989, 0.017912518458380815, 0.025205845952094085, 0.06761978485531385, 0.08536814982371946, 0.07807755151823645, 0.0437945768146986, 0.06422043056978334, 0.05337329205846595, 0.030822105472907427, 0.015450570424417815, 0.0477389375408811, 0.023176036624898835, 0.019649245528384082, 0.03834794831251906, 0.024374351356058352, 0.04799985176613254, 0.06098573922269768, 0.009607185943863325, 0.0406100259222571, 0.057334912745582486, 0.04840176447384781, 0.1075683742941868, 0.8497048277528056, 5.171360210064919, 11.002067904318533, 17.860614561265518, 28.118693174854403, 39.1700005531311, 46.83348817210044, 53.92319971515287, 59.20394159132435, 53.45452747037334, 50.14722808714836, 43.12447532530754, 49.19194659879131, 38.269479274749756, 27.837112103739095, 38.22714905585013, 35.423587906745176, 27.32024569665232, 27.984975653309977, 28.33387636369275, 31.878494831823538, 20.40613082147414, 21.233635217912738, 25.106942422928352, 18.294267885146603, 30.941330771292414, 77.05169077842467, 57.42085172284035, 25.646921396255497, 22.377025734993722, 28.13281959103, 36.267305420291045, 34.6993536333884, 25.4540466877722, 29.49090692304796, 21.24535329880253, 28.870250678831532, 24.25803953601468, 31.01594209671021, 30.408212023396647, 41.988874635388775, 28.641745159702918, 31.181848549073745, 31.931233059975412, 29.177307544216035, 38.169623574902936, 39.03252147859143, 37.46529140780049, 43.34929381647418, 33.850595874171105, 24.838968053940807, 16.64611343414553, 7.6304852866357376, 2.3382562591183573, 0.4729767702519894, 0.08758879356807278, 0.06051922615076746, 0.03443557558761489, 0.0738312563888969, 0.0628515310405243, 0.045897568606080553, 0.04215841985217506, 0.034877003110464544, 0.02696961018016502, 0.04244498653157104, 0.036536878155123804, 0.04486876231948695, 0.02252531579635557, 0.03462363102082764, 0.015171279665082695, 0.0824962011087806, 0.06850363581531471, 0.05748275239321013, 0.020663166726608912, 0.04632704898775105, 0.09102736389444721, 0.06170760472154906, 0.012475131849397816, 0.03726502174451467, 0.02477304266405202, 0.06828175376980536, 0.06348859060615783, 0.06481268548316534, 0.043806631208187154, 0.04968013922353426, 0.049909620861252474, 0.015341014105586276, 0.07497782188077128, 0.0054590065678161, 0.030476904339006836, 0.04525682798797085, 0.008204104529032785, 0.04043450368748557, 0.009736605007351648, 0.04175217108680837, 0.09066125047543357, 0.10799244226467226, 0.024797613019003503, 0.03721606872615315, 0.031313010784346736, 0.04179825510589346, 0.028366129094314192, 0.02233551751311508, 0.03765538950721103, 0.016728602349758148, 0.0344613850897839, 0.03223984885299879, 0.055783527242320205, 0.04310089952102111, 0.021661467392057664, 0.09484536990883852, 0.05493507337486071, 0.278275371078522, 0.18236647960880112, 0.10285864959681228, 0.207593877529425, 0.16324572175020174, 0.13871667425959341, 0.22997676034367856, 0.20259898426311634, 0.17357398124952472, 0.1806499830056583, 0.25689292248458634, 0.1683772391369266, 0.08985403895137772, 0.23143105569385716, 0.1540182233457604, 0.11728911840867613, 0.16609454227070655, 0.1696672545926225, 0.0813264154919213, 0.1495350308475956, 0.08826474358718242, 0.14937620549913377, 0.24238098022197527, 0.21900523213609574, 0.17620184669090858, 0.07395527070207943, 0.08695754477934492, 0.19241170026361945, 0.14289189941219746, 0.18117012606272775, 0.17637945651527376, 0.1929928545629786, 0.12377193828503932, 0.16164565518979104, 0.1650097617699254, 0.11995521929836082, 0.13848015227385108, 0.06878076812192317, 0.1440146012652305, 0.16329882696511286, 0.09899070231063713, 0.15207217615698615, 0.19065260917188662, 0.12422542403181716, 0.1361153920691821, 0.14670615925663902, 0.2344833185235339, 0.1706120555078791, 0.14839426464130803, 0.11757624050181721, 0.08793934008046504, 0.11364716706016373, 0.1412578645132242, 0.19191798723993764, 0.08712567043520751, 0.17550746459634076, 0.13357332847531767, 0.21126679415183686, 0.15082454068526147, 0.10407784022390844, 0.1509558787990001, 0.1579483616496286, 0.1828422202097793, 0.2270553606532274, 1.2017464373380908, 5.1886441342292295, 11.341216621860383, 19.170356719724595, 31.431693723124845, 42.064964694361535, 50.99849224090577, 60.79451760938091, 67.44231531696936, 62.86268534198884, 59.387583040422015, 52.27416861441828, 58.4623469075849, 47.022522880185036, 39.64660383039905, 49.23088396749189, 43.73823996513121, 37.62078985091179, 39.71637887339438, 43.78901896938201, 40.56417172954929, 34.03805378944644, 33.14846023436516, 31.869547905460482, 26.815995593224805, 30.219255762715495, 79.7209107491278, 73.64457099668442, 37.611552669155984, 31.776970163468395, 41.637606774607015, 41.76931212025304, 38.8838283477291, 29.095510436642556, 32.18578507823329, 29.035586426334998, 42.41263966406546, 34.973554765024495, 35.47138590966502, 40.000232958024554, 57.05653021412512, 38.78507091153053, 39.00286443771855, 40.54433630358788, 38.434407095755304, 47.61823677247571, 46.45003726405483, 46.68794862685665, 49.659022438910704, 38.7616543616018, 28.626075290864517, 17.780341294503984, 8.494334855387288, 2.5173021612628816, 0.5829322362138379, 0.28132433973012433, 0.21373445528649518, 0.14451966771195013, 0.15326324369638197, 0.08532355584564709, 0.12887858845774205, 0.14164202696373387, 0.1793560298580316, 0.12322649134383087, 0.10892340763201637, 0.12936333825270976, 0.08045369578946023, 0.12390218089304625, 0.13524182200912507, 0.10733454127705867, 0.1490718694103341, 0.16297497095600252, 0.10735175527271726, 0.15464188020315864, 0.1358774145163836, 0.1812834764320043, 0.1449405717393083, 0.12549215807549416, 0.1446139271701536, 0.1307045283817476, 0.25089880541688014, 0.1394703055942251, 0.07680870307188842, 0.1209767745627511, 0.2068317732623508, 0.1520768186498073, 0.1183360848095148, 0.10549135671387758, 0.21947562544336244, 0.16530125822511413, 0.25957200856458756, 0.12354973448260177, 0.16351656447495186, 0.1548114154608019, 0.12347837339245504, 0.19237322732806209, 0.29575853939017943, 0.06820013476235252, 0.13816578043324335, 0.11393394441373887, 0.16762751485070876, 0.2471377427179006, 0.12494335566917736, 0.07478371818339632, 0.084429822351423, 0.17619698969346864, 0.16062406162100454, 0.14780008684723608, 0.12955671416655665, 0.2090847305953503, 0.223305850560146, 0.1420756327288766], [0.08369655363381871, 0.03508411498079377, 0.08613334142512853, 0.028711770728771246, 0.10087906307871304, 0.03408466901389822, 0.037506515640885606, 0.014612491302672895, 0.025428984381799257, 0.0432331569402689, 0.04411671295641892, 0.08068686231009423, 0.07352749486604045, 0.09486073763259957, 0.021965322760684837, 0.04362813655226942, 0.056104207816984386, 0.09798951732415347, 0.025850539583893075, 0.02730169205836231, 0.06324555687305909, 0.07238306675947483, 0.031580082441289584, 0.038769258366477106, 0.012563886008255426, 0.01506341927339353, 0.019309822612652378, 0.07412537286478667, 0.06896022421818587, 0.056837675717449, 0.036103651603503574, 0.058469351065615495, 0.022817476832818602, 0.02930643307345529, 0.028906268961427194, 0.03241933176233884, 0.09426361040001917, 0.0334262968822112, 0.07721421639284781, 0.02439166111270747, 0.051991981904833555, 0.08368863994556089, 0.03234957179595386, 0.00943322174040781, 0.007410300501261748, 0.03227410064409337, 0.02638908024246414, 0.03950798163010229, 0.05409079851702817, 0.09428819416150933, 0.009228923327980504, 0.013208343110407793, 0.05556290158100667, 0.08397029983180185, 0.008260384220780145, 0.03296146537327478, 0.03506177968736138, 0.03638981225629968, 0.03632594733649204, 0.03625039191495988, 0.01778585348098028, 0.07797366999570401, 0.013055173406046967, 0.07455500263360239, 0.08682125773761543, 0.1648779793251907, 1.4052185320085095, 4.987030385002013, 9.039493318526976, 15.735760734927272, 23.369546205766742, 31.09192429050323, 35.77389478683472, 41.25504232222035, 45.901862498252626, 44.55226513647264, 47.37247674695907, 44.89528033041185, 45.38116785787767, 36.442949156607355, 32.481902453207205, 34.28986995450912, 31.536934837218258, 25.523609922778224, 19.574201991481168, 32.977656702841486, 32.40572414090557, 20.835436198019213, 38.15562071338777, 25.17311476892041, 36.2980136563701, 88.31246252982848, 54.614333106625466, 20.18239490447506, 28.641578458970596, 30.681220754500362, 20.870764986161266, 18.60286820319391, 15.916293705663374, 23.860240597878736, 19.365926096516272, 23.668040537065078, 18.793836639773463, 22.383179933794086, 35.630579225478634, 26.9572126865387, 23.04863552893362, 30.23480796044873, 37.239421721427675, 43.8779273340779, 32.4460147273156, 35.3683138662769, 26.506414682634418, 18.410917212886197, 10.115200396507017, 2.9263085367218142, 1.090923545341338, 0.0880535714508545, 0.030999560164467945, 0.08369160470582786, 0.07024526776325318, 0.030921660513887485, 0.02925166736296829, 0.07687683893187393, 0.04726783177184482, 0.09119286952960877, 0.027924707317123973, 0.0813830447112841, 0.05990174779247853, 0.06243292910737857, 0.010946338279022565, 0.014748124296837037, 0.03285518216509973, 0.03774391096686164, 0.0463074064933725, 0.045263515935549815, 0.013817674123621998, 0.04150701145971975, 0.017413297262523445, 0.03576896311114392, 0.02590253397131399, 0.03777819723191281, 0.03052600674451359, 0.017102326852299513, 0.02635523256274962, 0.029497811413039605, 0.05667432278935468, 0.04290152513872712, 0.02220312219804093, 0.061745208147312367, 0.01423946489775253, 0.09612734144132945, 0.06996904710127462, 0.03380314319304401, 0.01939630819364421, 0.07898351177573204, 0.07321996419059654, 0.026919038801063454, 0.05598737174765237, 0.04773216532363046, 0.052469066990118836, 0.033430215421943896, 0.024633183737375566, 0.0697658729228762, 0.07537041895932729, 0.0845146359455201, 0.031944617719179204, 0.022514818476573117, 0.045137214849913315, 0.003346009189338093, 0.056441466534330006, 0.01986848265533486, 0.020992747327733426, 0.06966806647758331, 0.08405116041220966, 0.07101525507506824, 0.03414851478150776, 0.016804349293271383, 0.05077318964345802, 0.022573655944377668, 0.055066304236289956, 0.027210209668884357, 0.02657489869893799, 0.034494089383271434, 0.04891556432290424, 0.050169604289675915, 0.049831135153409936, 0.010460269855215185, 0.0537844016517122, 0.09011804051096402, 0.030064538361564763, 0.044956329999671835, 0.11786161591449093, 0.026935327745553468, 0.022126354442368594, 0.06346823181957006, 0.0284599480519612, 0.039898874163026773, 0.04921439606996794, 0.04695689583557749, 0.012824696811637091, 0.016006783773792128, 0.11755627625051046, 0.0570530881504378, 0.05854348922448774, 0.03384060872298095, 0.03998541911583274, 0.021559265517299215, 0.046692388657961166, 0.06396948314842678, 0.08285034057353774, 0.012831136738250573, 0.016172979845695438, 0.08206965101342048, 0.05460509249279576, 0.02431483015478138, 0.08458668651479868, 0.12749802907027546, 0.05026258438104584, 0.012549584104319014, 0.04205935702268635, 0.040671044825426036, 0.03745712595240724, 0.04553401009029439, 0.0435763375172692, 0.012666239185378918, 0.04589751497992585, 0.06353147237771942, 0.05953537007313102, 0.08111089197618347, 0.04586809720363348, 0.028296286773477352, 0.04782309229936331, 0.04132334187987351, 0.05882665830393953, 0.041568846246528054, 0.018087891306007103, 0.052750466406465545, 0.029195911483839158, 0.03767135477955303, 0.11780884011738724, 0.5641426121996296, 2.555652890474566, 6.53934270143509, 12.507349041200454, 18.354856737198368, 27.872654661055538, 36.91968579446116, 44.196961156783566, 46.98908467446604, 52.12883303242346, 49.274179089453916, 55.86476902807913, 48.234370523883456, 47.22856890770697, 43.07138996739542, 35.97766583965671, 38.536898628357925, 33.42907836360316, 29.37178454091472, 21.415929332856212, 31.932766706712787, 33.23100651464155, 23.603386148329704, 33.25023789559641, 23.086488362281557, 46.87864249752414, 93.15920983591388, 48.71365277997909, 21.23824792523538, 34.8635793501331, 33.14314934515184, 26.634266299586145, 19.59075439360834, 21.048226741052446, 26.01804625603461, 23.171582221984867, 26.390581207890666, 20.897068400536817, 28.46738011606278, 45.03338306180893, 34.57865053607572, 30.11145530208465, 37.29460554738199, 42.37359639137022, 47.19851570744669, 37.42260817558535, 38.887884078487275, 31.712609952495946, 22.124538844631566, 12.511563627950608, 4.6952658603268285, 1.739617626993887, 0.11308321143470465, 0.04380140648854356, 0.05506039003751451, 0.02426707797924117, 0.04853251653032438, 0.06736746613657282, 0.10863843824594252, 0.030649172615319974, 0.06155768514520699, 0.05722479526734641, 0.040266052444255164, 0.07559725759370674, 0.01764915849743111, 0.030548717421028885, 0.020815530123429436, 0.07399301585410872, 0.017547734201915802, 0.046292843161931926, 0.025098505542583527, 0.04276839820968528, 0.007628222351007525, 0.03594049402782994, 0.02886108318043332, 0.03152662099549367, 0.016524495459311915, 0.024912792423199263, 0.024269665441205426, 0.01046517090271077, 0.044758740602241415, 0.05409116240879221, 0.04498238081953699, 0.03939152094385317, 0.012260200136581497, 0.05546034156014362, 0.08499312680214645, 0.08726162039825032, 0.03964524926437486, 0.028190128054589998, 0.03331484641098688, 0.011600091858136078, 0.02484458186964114, 0.012223859798283348, 0.03725965529860508, 0.015498336006496704, 0.010677340868560058, 0.04127973998566309, 0.027021432197802973, 0.07301288296378429, 0.020787261479023485, 0.039836552910386555, 0.030539499468079982, 0.03555243985066491, 0.03568648225477627, 0.16292994030781333, 0.05168282712299017, 0.058101146226568576, 0.06547807881067838, 0.062371105811889135, 0.04925590271370546, 0.1526483508848375, 0.09311726707364283, 0.15171563883702602, 0.10051568459358909, 0.28497042795342786, 0.10425766404237478, 0.1224824361082527, 0.122238299208543, 0.177445498505427, 0.18913863557240657, 0.1880119194186503, 0.222088368309121, 0.1995275232700571, 0.21693604397437266, 0.2877503771695399, 0.20807907165538883, 0.18484189355325314, 0.15984481230618494, 0.14363010173603413, 0.09693403968647604, 0.2392798563044879, 0.13171711275654455, 0.08852443973263426, 0.1256391167220089, 0.14703275786051828, 0.09120391651747689, 0.2829773736096198, 0.20519953100912033, 0.19634484163215085, 0.2525855778085609, 0.11465924581693065, 0.1738878627938609, 0.09424077331899636, 0.1450130896222207, 0.14651296720389398, 0.13700817561438008, 0.14751629723656565, 0.20071356527266965, 0.21881677450672274, 0.20091365211673323, 0.17156448665886156, 0.2078265537537875, 0.13496609164341805, 0.11419850521750989, 0.07906045764684677, 0.268981498816321, 0.16714972113409352, 0.12432097817861265, 0.15193089422199035, 0.18254062671574856, 0.12491183115109322, 0.15981329544898004, 0.15060021481927366, 0.2833692735481647, 0.18536905397570905, 0.11158714131001504, 0.20762928611328527, 0.08399472271482791, 0.13796302760320325, 0.1832295542642955, 0.19105213934615736, 0.10238421900618462, 0.15372727847387715, 0.190063931889111, 0.21096005254695493, 0.6905866498428007, 2.194892158431392, 6.801839480476995, 12.148599259314999, 21.36800385290577, 31.65122093692903, 42.322738939715975, 50.48436757056944, 57.221948331402196, 61.531974192588564, 58.8950784744755, 64.93616788618027, 58.969834927589666, 58.68736151726016, 50.812567972367816, 44.84665862975582, 48.41985156459194, 44.753820050147276, 37.1117603394293, 30.58069629053916, 48.798725066646455, 41.672868882456136, 31.410667857816144, 54.03038632485175, 35.758405347024244, 49.75744255127446, 95.64073654913133, 68.49034909279116, 28.94254388347749, 42.95087122148083, 42.49848858002694, 33.49465254814395, 30.24541404939467, 27.729131214080322, 37.53247376411192, 32.84224471738262, 37.747329435040875, 29.69230101954553, 37.466177863459436, 52.44701177843156, 41.02602297259916, 38.57697348440848, 46.29382494957217, 50.263855841852006, 56.35011919083134, 44.15270505412933, 44.40168534555743, 35.723406037976666, 25.032715489787442, 14.213418268388319, 5.372637616049859, 1.8294125699227857, 0.28999780334772607, 0.21673938920420988, 0.2824262499568924, 0.07397509705755981, 0.13193419143076868, 0.17521797529151364, 0.17883887454386682, 0.142044345698049, 0.12746865725925854, 0.1219443895763928, 0.1912244784856035, 0.1491098826931369, 0.13933921262862223, 0.14924984695690294, 0.16342526211613612, 0.11391640100027285, 0.19786684383307734, 0.20139967361765526, 0.20764134433721343, 0.15686586409086184, 0.15462471983365475, 0.0992099030484115, 0.11813268846561832, 0.20062103717317506, 0.11961363601468264, 0.07492549807554291, 0.11031840777685566, 0.12649153509447653, 0.18300037140086775, 0.3352987886436524, 0.1588349858479154, 0.09739502543403257, 0.13156741917614015, 0.07751386402355087, 0.22224822021540136, 0.15499513866680284, 0.1340648658092945, 0.10247537580829474, 0.1162148103298199, 0.10633424495256717, 0.055441170209838506, 0.12018437151827159, 0.2155560131875738, 0.14303361035643086, 0.12120417244131527, 0.18860266513882146, 0.10869392599429815, 0.16457885263427613, 0.14666831451317958, 0.10588190067679652, 0.10460813394597462, 0.17267617216754347, 0.18178797597365995, 0.23552260872337127, 0.1730760394205009, 0.1381794167982955, 0.22691686727827598, 0.23647474876094252, 0.13030571833012566], [0.010640752509296423, 0.02847947180271149, 0.043916189442238504, 0.01404931708689659, 0.020189896759186542, 0.01697208041385297, 0.11364544336233409, 0.13557917648746123, 0.0858543015595886, 0.05441812490443549, 0.05478023168360514, 0.047502603246680195, 0.0688052369702247, 0.05648929340344283, 0.05933388894904525, 0.03295815587344189, 0.052667173496898145, 0.008184632489217386, 0.03400794147784191, 0.04512160197801648, 0.02493758877408841, 0.024151119080582456, 0.058248939908920765, 0.06318360334262252, 0.05354103850080602, 0.034305501518951315, 0.045964903904185186, 0.053409822961135264, 0.03045253508213547, 0.053034734822088675, 0.023974514746617888, 0.048129236355664275, 0.03963727045864348, 0.08516118351009586, 0.0526255174660154, 0.03826193579082047, 0.07934347350871371, 0.029370098810402617, 0.03796564362522575, 0.01565467827247396, 0.028693714036395954, 0.02546116582027847, 0.06987510173912011, 0.04239291936579732, 0.05065969754791549, 0.03620347286003732, 0.07993707673684244, 0.014616596576337133, 0.1017049441654836, 0.019430931537382064, 0.045960123515537674, 0.05733168751542127, 0.013357493725995864, 0.01162286477929522, 0.03200581473779054, 0.01882134963037266, 0.05060239417117931, 0.10867393109947444, 0.04754600978846993, 0.04800023864053431, 0.04824490414091176, 0.03342042864871121, 0.03440056153903565, 0.009147627992675671, 0.015902908954529033, 0.0248242613874496, 0.03274269364473801, 0.6288919958376116, 2.1134088404716986, 3.2703636490529586, 8.254364248244993, 14.455190224032249, 17.87558036465799, 26.497134354806718, 31.50786222950105, 40.65157782646918, 42.691547639908336, 50.903763078874164, 52.72012249115975, 50.32285613398398, 45.89258217042493, 45.64876371814359, 44.17000662895941, 29.312080183336814, 37.177809130760934, 24.523309430768414, 18.488411480380645, 38.288730267555486, 32.85932271711288, 41.035550409747714, 33.30205632794288, 45.040015789770315, 77.89255280648509, 46.19337697182932, 22.92316871304666, 35.03400241175006, 30.741633099894372, 29.996802460762765, 22.872319106132757, 22.294536329084828, 27.678154130135816, 31.037364121406313, 33.96516830690446, 34.43094584249681, 40.80638985480032, 35.448553792891964, 32.12312913710071, 36.1964556478685, 42.36908174330189, 32.69663653066082, 22.220317240684263, 20.22860826984529, 13.69708530364498, 6.205396517630547, 2.075118172553278, 0.6231566326272103, 0.052232602460970806, 0.03025751207925139, 0.054978556525442875, 0.011994145461358132, 0.03204567046205123, 0.042177817198417844, 0.022686816706892945, 0.07446536268558233, 0.0171035411016595, 0.0373291356428977, 0.049350644807301225, 0.02655984315600607, 0.058429652389379284, 0.03217785318772639, 0.046037341347865524, 0.02863169921892545, 0.05119746445768303, 0.08232923224568367, 0.07022610024338768, 0.07194220614168914, 0.04399818766321387, 0.01990183812355803, 0.04630188299943844, 0.052121852960197196, 0.030151075653491483, 0.07217340381635774, 0.043029806561647885, 0.01387959030727225, 0.04402275993338516, 0.028938396773751707, 0.02562600304372609, 0.009278960360754884, 0.05552563140349043, 0.016613738956831155, 0.05994417757216481, 0.07434527840345137, 0.03037634572284597, 0.0770554140270237, 0.04747199803410519, 0.045062038641903675, 0.022898065452013287, 0.05397240728920987, 0.034144435363310965, 0.05019588876635798, 0.04464891806785618, 0.04845485436700044, 0.059937083597985975, 0.06651303295286433, 0.04575855429134062, 0.042661440844136866, 0.03012412659553511, 0.042987660234493595, 0.014946883893571796, 0.04720806159199246, 0.044707454846150456, 0.10873069055378438, 0.01750759119468351, 0.05215766374021769, 0.04740210400233346, 0.09358623545737037, 0.09441957057964417, 0.01796344415314736, 0.023081120246300296, 0.03241252507113161, 0.008992336224764585, 0.027163528101218325, 0.09248515260556052, 0.028974617410811688, 0.008193566989634306, 0.03490337185681828, 0.041268424867021467, 0.043924011199945406, 0.03886191670091883, 0.03580764289044085, 0.02167560937513988, 0.04885064603220071, 0.09355040552515177, 0.07331262252503827, 0.02257199353358198, 0.01712323147653332, 0.06540264979365372, 0.029971489322281657, 0.05765344444361906, 0.06067772208142185, 0.06309045471190926, 0.04912896194465218, 0.03172984496960717, 0.03828439365832075, 0.07234563570349448, 0.022340853315507694, 0.026724866155775327, 0.061181076321630716, 0.051239871254731575, 0.09812939731824784, 0.007749254666944786, 0.1331891200595325, 0.04968499622097419, 0.057661266201325966, 0.04366240366512249, 0.010940812869868692, 0.046464967796759266, 0.021944755215137716, 0.08456902818814402, 0.018970604625440413, 0.10429000061365867, 0.008675455446204832, 0.06220733153543646, 0.07449322530338842, 0.05270592605454787, 0.054735867531910065, 0.05302258466760959, 0.06674415401874051, 0.03150900480367484, 0.012103335015595922, 0.0952145170360323, 0.03819123353628862, 0.031405716999283725, 0.043705300758442575, 0.07956201541087321, 0.03064700650171407, 0.05715962416762787, 0.0488170683984795, 0.02273630024114203, 0.029329293137115818, 0.03731446888958735, 0.03698716931525738, 0.1274976460263133, 1.1272965419676997, 3.0252000689506535, 5.66300283516607, 10.908531142819314, 19.55751426758305, 23.415630132921283, 34.23274455531951, 39.06144895861226, 48.57961362408054, 50.21952129179432, 56.46446020372453, 59.3472336184594, 53.538207315629535, 49.09317739548222, 48.55187069985175, 47.5112384365451, 32.84551009055107, 37.05314836194439, 29.61920176782916, 19.496862657608528, 34.01168761714813, 35.02611060296336, 36.6227819842677, 34.49919116112494, 55.92400074005128, 76.87186579550468, 41.33900457812894, 27.88325878881639, 38.689349389845326, 32.400293619402, 31.813916929306526, 26.810598411867698, 26.013955223944883, 31.738291671199185, 37.002753749970466, 37.822776225305375, 36.48720918163177, 48.08109214228969, 37.52040855346188, 36.02260443472093, 39.2570379472548, 46.379536582577614, 39.16849044061477, 28.004638494983798, 25.229916572570804, 17.597600029360866, 8.215842160486407, 3.554268969643501, 1.0115086034901681, 0.06252720771778016, 0.06693398294549796, 0.01817277193279757, 0.015422487556333504, 0.07237764285697092, 0.0409307448013175, 0.02319336936418568, 0.028331825592284723, 0.06640204213439457, 0.08194126999906956, 0.10469377491502993, 0.03703113510123184, 0.04506464334084623, 0.03681073543585597, 0.0764202198854858, 0.034867836868450526, 0.0029599523470331466, 0.06766734359365317, 0.0050507018139826195, 0.03470094844458565, 0.02792754184244381, 0.03963313741429199, 0.006033349866723462, 0.10576475051141555, 0.0028171506851175504, 0.08158500847076217, 0.032670328979410475, 0.04424697854706357, 0.029069192880283923, 0.028419971668852434, 0.060258737104313995, 0.03255013361453049, 0.0403249952491493, 0.0487534792703246, 0.02933748836268581, 0.057437020774570205, 0.02379176064184116, 0.016329098988564748, 0.064756607847108, 0.003522959459880968, 0.05938393364269888, 0.022976394111831343, 0.05609932017602748, 0.05315519448730254, 0.052838512891603094, 0.07481106752229315, 0.0519364558520817, 0.03918833144369625, 0.023465232901094903, 0.136472710798825, 0.01489167864013824, 0.012308888854609143, 0.02869345165128189, 0.037698290430970734, 0.038103321116537824, 0.0662081299590007, 0.049921047062643116, 0.0637551853733678, 0.015216478852615243, 0.048822852362307816, 0.15798055266420688, 0.07362963736898477, 0.14840676719623228, 0.11130245537647318, 0.15588214590905175, 0.09247304075547765, 0.1873025066790081, 0.170796912524008, 0.14011993283225646, 0.11738810462937241, 0.1820126082748175, 0.1903805866717331, 0.22116944584394657, 0.16741739225483712, 0.17404359314710866, 0.12908740870414243, 0.13984814015848024, 0.17026014535898165, 0.10093059015250015, 0.13836096431459152, 0.20061198201391006, 0.16108710048419816, 0.1232207686670365, 0.12329920840960358, 0.16205535901169624, 0.24376680263348166, 0.11915189184008107, 0.16036121685418392, 0.16578193243232467, 0.1780144720067901, 0.09360777018892188, 0.16234492492531577, 0.1647604154723306, 0.27098803630759644, 0.15112078688558073, 0.19484101103678828, 0.13451167893025184, 0.13651118373438237, 0.08137394358674366, 0.09979218349701936, 0.1294458152786378, 0.11214282318589189, 0.21724534431292167, 0.10113550335048668, 0.1535371660945877, 0.13388079020284838, 0.33007930904146165, 0.16009408199498731, 0.20579000093763877, 0.2689771474369111, 0.12007153442790432, 0.1656005687771305, 0.21738075801441747, 0.0658033827259656, 0.16001439352910365, 0.12182876392598115, 0.14410107727012328, 0.10598862438552803, 0.12001606966218642, 0.21580673844343234, 0.20932344359255609, 0.19982275823431633, 0.11087903091984411, 0.15082550595604605, 0.11972411355424313, 0.13262374717141354, 0.1904294477595437, 1.134373355777033, 2.886306734815721, 5.679793030984941, 11.684714267330786, 20.48140306626597, 25.20355824501284, 36.65509839211741, 42.75575683962914, 55.87881895803637, 56.541056248449514, 64.95163379176971, 67.94612807612266, 63.96371818357899, 58.92151132706673, 60.44690539759975, 57.389229574511134, 41.55874359992243, 49.751727657933394, 37.56096193867345, 29.268814479151082, 50.39631036020095, 45.108245418917754, 52.71627072365054, 45.222649189733694, 52.72083636253111, 86.67626150192754, 59.22050968293221, 35.26124492768319, 48.55880152794623, 43.937021763094016, 45.09627042278167, 36.04626809397052, 37.795288255137784, 42.17798779087682, 47.199594359244074, 48.270083704302394, 47.97367019038047, 56.38026652797576, 48.720866018725985, 46.04561736506801, 48.703964525653475, 53.94022672407089, 44.44904404301798, 31.937224480413626, 27.433025606216926, 18.747766440914525, 9.30815508288722, 3.7232103559278675, 1.1421177079600673, 0.1677892053680074, 0.20228550108450077, 0.2059403073883826, 0.10446286069289332, 0.12103061522206954, 0.13853993777546192, 0.15640702338949328, 0.1616676572349764, 0.175053634109997, 0.16353340308752753, 0.18499215403872152, 0.14319341629743576, 0.09051266006164013, 0.11951444295024681, 0.18353830301953902, 0.17872982958872474, 0.13294711288425232, 0.15607873939218062, 0.2094710993790819, 0.1446732223754929, 0.16100348964814218, 0.16569433793906244, 0.14632046463028078, 0.23351366571601362, 0.14099802281106674, 0.24660289077268494, 0.12403434638174311, 0.1465241214440715, 0.1058319287614957, 0.10897520283657698, 0.1653657168630631, 0.08552738885966041, 0.17380157065006996, 0.14093782362197677, 0.12994320552435615, 0.16275197808300296, 0.09446067885766107, 0.126499027434376, 0.12232611586730327, 0.14741149640852405, 0.27016590139077556, 0.12920506448755342, 0.12815543210073826, 0.13525781792498406, 0.12179554635358435, 0.19846561815469496, 0.15853296334464706, 0.1976811134767148, 0.17707701021384809, 0.29768310547355686, 0.07120624079459137, 0.11321150051850466, 0.19379559213355665, 0.14219197084105786, 0.10266028645057833, 0.2453415576488741, 0.16512289763458315, 0.1666233267995619, 0.11668944010330785, 0.2128755328275504], [0.04691735420736575, 0.022954167985928156, 0.08577738633199085, 0.03236971990836244, 0.013377710786317627, 0.028391733667963458, 0.03407572493738225, 0.03313973403325485, 0.045339404605329044, 0.042399886935468645, 0.05163569356344881, 0.06351100250838265, 0.1029789254009243, 0.07350794430221282, 0.027092092317498984, 0.035977174317644495, 0.0358727641944443, 0.06175727020168017, 0.03160132414421007, 0.056657342450513, 0.037437085092308066, 0.08490819829486071, 0.03850025425274526, 0.040727091817966396, 0.05355681225116696, 0.05794146669007117, 0.02430857504687963, 0.058200618913096774, 0.03420875227499393, 0.045553575975880514, 0.007831714455894525, 0.07159408812801685, 0.045677023383999066, 0.021633558808976126, 0.053798838578645265, 0.014880382673694723, 0.03480234784224341, 0.051802018912689346, 0.04638540956582274, 0.04333890005645733, 0.024448322890807065, 0.07069060233451667, 0.04747136601156766, 0.05788942250693518, 0.061343866175100695, 0.05072091180350512, 0.02855808774550115, 0.03277285452631693, 0.03363030992688672, 0.05102896724917716, 0.05863261972403815, 0.06134511489841727, 0.02791667105479827, 0.034974257972451954, 0.02316574997929556, 0.04647830155708137, 0.04815583875883491, 0.014902577198471033, 0.034042970848179636, 0.007857088724361553, 0.015192609468114474, 0.049802632852187084, 0.09441326567602736, 0.009919920271532911, 0.06811276243458833, 0.04137029923919228, 0.04989649777510955, 0.01379897391739031, 0.1061260145938685, 0.21598721343663432, 1.3046539863271098, 3.1135171363430643, 5.636982321739198, 9.947349429130554, 16.931979694674094, 24.53176017730467, 38.22723534799392, 39.55015667023198, 46.42576955979871, 53.080007799210094, 49.64206995502595, 54.67833834309732, 48.212530766764, 45.27419697853827, 44.375919295895486, 39.6202023567692, 45.78725476418772, 45.45322572031329, 42.57394713740195, 38.166164044410955, 39.742560694294596, 28.46680352764745, 57.92040478798651, 59.964112620199884, 33.05837515861758, 30.17483884288419, 31.94288838294245, 30.407590327724336, 26.096719195765836, 32.45829566832512, 30.901183351393673, 34.215980345203036, 34.06565158597885, 42.06060301872992, 41.77070063929404, 38.544727679221864, 37.670666710022964, 36.772110539097945, 24.973179794126942, 16.484415684976888, 11.00024204100332, 6.912279696233812, 2.0553430530332752, 1.273249284394326, 0.13816288462088955, 0.04236370077236526, 0.03747786012207789, 0.07748533490925066, 0.05103159876119706, 0.10811356076550101, 0.026694126877813574, 0.03194499118704229, 0.0619308082687278, 0.058808444563539765, 0.0164355794643803, 0.0665090186521411, 0.05554528921962746, 0.0688935439252565, 0.035788843092779, 0.03706968081514201, 0.03235927429951487, 0.04305068628802415, 0.016411939906256817, 0.06803250706364071, 0.03319979915695806, 0.0537500924040233, 0.07272234411850091, 0.01060893975063077, 0.03655869633920732, 0.008494188509611113, 0.04474808431921467, 0.05212141245964074, 0.022801781606469906, 0.04092411814077247, 0.07168855442995987, 0.040722751929875345, 0.022140421731878194, 0.044319929269653176, 0.022196223576282783, 0.035913945250814004, 0.03447887487709522, 0.03147155459549639, 0.03945886390283704, 0.04806320723747054, 0.08298770013836124, 0.07459984175981053, 0.05019679275010863, 0.058429640898060416, 0.03810370033006034, 0.07074884799939972, 0.06438024417166749, 0.058386962139798756, 0.04081248763888594, 0.049273342705301704, 0.02915557695462579, 0.06849721599850925, 0.07422788308993464, 0.024365886084495053, 0.04433778294872853, 0.033322748607925834, 0.05486129144687326, 0.09964283465618089, 0.04657125100493432, 0.07224820464128448, 0.02644143852164909, 0.14447693532753375, 0.020757506624044433, 0.06738076542293833, 0.03768140202267997, 0.04355045140630776, 0.09828255361606998, 0.06402631921152915, 0.02402215009374965, 0.026280630920683185, 0.05606297696489961, 0.042469378771080125, 0.10463927542009663, 0.053135498366769285, 0.10988195216463459, 0.13602238899517444, 0.01452851465963308, 0.034548657826117934, 0.025256160691741015, 0.049500476283532, 0.09186383997721058, 0.06175592571737305, 0.06588264218261165, 0.042039446397534305, 0.02419813772693517, 0.06848468280006802, 0.06148972165500445, 0.05341911943809641, 0.048920907786176096, 0.05350293711789193, 0.04384491645220307, 0.03272855932253503, 0.05665701303270556, 0.13698064241438143, 0.0020608440278128033, 0.03410460645212762, 0.08883844385103834, 0.026750656505746227, 0.03571113113373999, 0.051247796434308254, 0.034338163677603006, 0.07519664723546275, 0.04840344986728123, 0.024527339114537163, 0.00417204445130342, 0.06905491268562694, 0.030421497029883247, 0.04609723793222539, 0.046522627404380235, 0.034644510747203906, 0.03826008568848333, 0.040660147224703146, 0.051294615897800655, 0.03199880120284375, 0.046782070740817056, 0.0253794165778785, 0.04542429480821856, 0.01865481169173314, 0.0482775548082446, 0.010240235039213253, 0.02118294589191435, 0.04668273978055485, 0.013948594719441909, 0.049620372874121514, 0.024947976926341656, 0.06301347053639832, 0.0422892906522799, 0.05201505647311288, 0.014918183367098532, 0.021193404907300588, 0.19715206847796518, 0.4833577519222614, 2.5223362782309136, 5.081076564327364, 9.2977794331889, 13.774286373969048, 22.049388193315078, 31.391448243971798, 42.53089128002044, 47.35947016746768, 53.2430136588312, 59.83663558959962, 54.910581881000155, 59.7474330471408, 53.971323274797015, 47.38604422538511, 47.292691815283995, 43.79076050173852, 46.66731695975027, 50.22460860590781, 43.26450001808905, 42.86147648288358, 42.68010216374552, 30.53614797130708, 65.42563261524325, 63.118639607583326, 36.74939609343006, 35.578074378352014, 36.47360640187418, 36.05143777785763, 31.187112369844993, 36.94751108846357, 36.50049032703523, 39.90654322408861, 39.800988320381414, 50.20530269991968, 48.533066857245664, 44.033225736310406, 42.41640121706071, 43.02373316980178, 32.746650672728016, 21.681626765958725, 14.680443117695471, 9.542867752813525, 3.212239761506358, 1.9342838780533884, 0.21504673325727064, 0.03894193075417031, 0.07827971446057481, 0.07987922943768003, 0.08230608106861192, 0.09311335236434976, 0.021947696992766955, 0.07816231148617883, 0.04505020641391316, 0.03837099989816066, 0.03752735323242603, 0.09619310242874969, 0.08981874528070612, 0.06730296153334842, 0.014883640462592726, 0.015320803748533852, 0.043647901620715863, 0.025645846636184765, 0.038589852065929485, 0.06068012759750409, 0.017750109733653166, 0.05708051409812705, 0.060691584442411704, 0.07456248731262262, 0.08468397202030306, 0.04761502281912873, 0.038090588735236276, 0.0503968068158194, 0.060575797913535956, 0.018274355191557158, 0.03575466024959761, 0.017798781214702516, 0.08114967134691055, 0.10797879823874082, 0.036690819693068345, 0.02843058390182353, 0.05762457442019255, 0.03900563479551385, 0.028027020274631442, 0.022908800259052266, 0.08250898711623685, 0.1065753787876137, 0.03823836326539036, 0.02271911114334099, 0.02958612411373085, 0.025678263646700693, 0.07375289325512226, 0.06937066348449838, 0.04316346975223672, 0.022681469413181467, 0.04123348359679503, 0.026855909325663122, 0.027458713269762458, 0.02230161620724586, 0.06757339823149866, 0.07261192020509513, 0.10038153493716832, 0.04253275722505585, 0.04779541354265906, 0.051666053627888044, 0.025924869264746388, 0.0951604848547328, 0.11897158538622242, 0.09989849351827176, 0.3082574783794342, 0.13320741423916432, 0.16101194725882623, 0.1786453300906766, 0.1622820597502493, 0.21204153886966168, 0.1634718096184154, 0.14706114907899212, 0.160945113748312, 0.13518264937785365, 0.28650226672330215, 0.2191290932316934, 0.14331946840449689, 0.1872189418082276, 0.13205966131100733, 0.1121941740594564, 0.14869628714457636, 0.2125514316703043, 0.19141747135548823, 0.19458879957035666, 0.1069398221349524, 0.20268129274970104, 0.1618562221166588, 0.13962736894046107, 0.15908857627261072, 0.1675141798031907, 0.20417254418134692, 0.2262282921301742, 0.1406387122528207, 0.22830429847442338, 0.12999071829742, 0.07869343258320324, 0.1268959375879457, 0.11862417217344047, 0.12764047545891616, 0.15562952075514103, 0.12213802596013393, 0.2508060015257328, 0.09184052792167471, 0.10911298374975882, 0.20986051719275214, 0.2661331532703292, 0.2063140970083975, 0.12928990106428825, 0.16864106449629032, 0.11780622775756544, 0.14794784988607132, 0.08050084850119968, 0.17469061568619745, 0.14048152633251684, 0.22133626915033788, 0.1272112363949418, 0.13394362473439786, 0.14164279305165814, 0.15508806513201806, 0.1287520460544094, 0.11190338240515803, 0.17360194345876095, 0.20446751867571186, 0.17920736283544572, 0.11529572698618136, 0.11278674306888735, 0.1647822489781726, 0.22683734735173566, 0.16337621716722367, 0.2313270669190153, 0.3540988008101141, 0.5287934767623101, 2.3437934200609885, 4.858881158213462, 9.8796748153625, 15.42798411461615, 23.523765956201864, 35.1432482657894, 46.582491782403764, 53.88806312314926, 61.30592015481765, 67.09045517829158, 64.65363956266835, 67.51165497687556, 64.1929611083, 59.40193891525269, 56.509944008242705, 53.929110727002545, 60.17203354066419, 61.3751813673204, 56.836842183143865, 53.23156033792804, 53.63463094157558, 38.29437848060362, 68.27676034742787, 70.64288308543544, 46.43486553622831, 45.584095601112615, 46.37717531573388, 44.28438294318415, 40.466312516120176, 46.7488944145941, 43.675666393772254, 49.13937899374193, 47.870001946726155, 57.7691032809596, 56.920937799638324, 51.71911008896367, 50.855537537605535, 48.047638247090006, 37.22110425272296, 23.71429312613703, 16.960881679288804, 10.471558513179904, 4.1662979606659185, 2.182421227616649, 0.6551168402356486, 0.14706566899774537, 0.17570270976472288, 0.1402504435710369, 0.13993340574445265, 0.2508844029639037, 0.06434716449509706, 0.19325758390609296, 0.15609456676869624, 0.13170390540072996, 0.11414682492613794, 0.19505908562531396, 0.19443026533530605, 0.15435980662943857, 0.14338017321161686, 0.0686460975257139, 0.2047792245303431, 0.13433917125146236, 0.1117540259034403, 0.15867498072405017, 0.09540986179584458, 0.19245979526350576, 0.21670978756681566, 0.14514952988153504, 0.20240828965700444, 0.11073904367344034, 0.15021971426904202, 0.10518530458812753, 0.31515907255872605, 0.1743455083980676, 0.15276012311299003, 0.26219834183012286, 0.24561572519521563, 0.14258462154576856, 0.19813218604653113, 0.10758447746235518, 0.19649263531450303, 0.10818547343895321, 0.1183269223979404, 0.1476659295299361, 0.20334947463725844, 0.2994343211814281, 0.11405885504979281, 0.16074248349233983, 0.18209975843708362, 0.1812199983865984, 0.16199771855627337, 0.2078712626450485, 0.1223082583577883, 0.15028452530743616, 0.1312887163892869, 0.05707863335227294, 0.18019478888280932, 0.13862221561852964, 0.11745146776158964, 0.15311955624530393, 0.17680201529254838, 0.230930294661272, 0.13015308297209202, 0.21247908232673524, 0.09785259442944681, 0.1889740952080296], [0.0427144579589367, 0.056093578347034996, 0.011578023737867274, 0.03211206155678919, 0.058042149795519735, 0.07388330440247252, 0.019438002528923175, 0.133753941364346, 0.06628116112082236, 0.024432727255888527, 0.0034563804341990866, 0.023282091921916413, 0.03615553107773585, 0.06622326019550524, 0.04518013109543151, 0.030518966396489454, 0.09098702936523384, 0.016614464825139414, 0.07190970103106192, 0.04845630610361696, 0.02914438249483224, 0.15763069563094648, 0.023641090299333298, 0.10780413019200487, 0.014195710743567156, 0.05050581729700489, 0.013363457720486388, 0.06660483326883086, 0.16728490500921206, 0.14501354927497526, 0.020903591930325476, 0.00903397501866904, 0.02481617341418901, 0.006995323600412737, 0.04086715184272297, 0.0311088866569222, 0.04507487444507499, 0.08710545337488575, 0.02730249070502337, 0.018550602666613077, 0.0319851361094944, 0.004457633889790986, 0.049785755935215184, 0.061579771460064, 0.07130434601417474, 0.042106479090908845, 0.02813015294621789, 0.05212010244929022, 0.032284906314265345, 0.05921252146964112, 0.02054472761829534, 0.03247524468949245, 0.04622242052949244, 0.04946104956850891, 0.029441818046653946, 0.04441186748144608, 0.08748131909317548, 0.037375912971554265, 0.04838376906850646, 0.05093815135619333, 0.03750735450716269, 0.08863833402433703, 0.016168266489741304, 0.013235691491694701, 0.04778196486914831, 0.10147221431496645, 0.03768489538361469, 0.1133937911400872, 0.0855434613843118, 0.01638520918335886, 0.1263799620491843, 0.031646364368498325, 1.0603708557544216, 2.25006127549756, 5.2730241225611785, 10.307703460416487, 17.132734444833574, 22.359429982400712, 33.10716944356119, 35.56435784985943, 47.565174948784616, 52.405909261395855, 54.565895757367535, 53.735082841688595, 56.17329089872299, 53.67277991387152, 49.1250309636516, 43.54087806517079, 53.46883235439178, 38.54148780145953, 42.546859248991936, 49.235528053775916, 36.99555620070427, 26.13814530834075, 43.77679686392508, 42.80501396425309, 39.518448229758974, 44.561188528614665, 38.27329574092742, 39.691307083252944, 38.7279062886392, 45.16337825405983, 40.84098123734997, 36.65933062953334, 33.04090099949991, 29.488300508068455, 23.202423818649788, 17.79455988637863, 13.459871142141282, 6.687569560543184, 3.1085286169282855, 1.0774769249462313, 0.3122164981980478, 0.053876278576471155, 0.025400625722062205, 0.033549541277029825, 0.03695281410229303, 0.040126612950717254, 0.021053595776339213, 0.08994619166778942, 0.016931450940788757, 0.04055466840884859, 0.047948045070253076, 0.07306952750490558, 0.04924155771732331, 0.036597425914219314, 0.01288221469299207, 0.05847746393673363, 0.036661800282496604, 0.04449963434449127, 0.031662490519304434, 0.009653666413449233, 0.0497211862145172, 0.08511166358667036, 0.04621276399120689, 0.006325317944790567, 0.008795825096087591, 0.06261070364064748, 0.05754883513755857, 0.09113093898180993, 0.031163830482851596, 0.013563480404686305, 0.06045624989295199, 0.01848352975362251, 0.022938344439852144, 0.04164020733667478, 0.013947481019121986, 0.010643163771038095, 0.006098936569140924, 0.06226837725168275, 0.07969296281977047, 0.0789538105469077, 0.03761835681695131, 0.026349186213807236, 0.03620523103182355, 0.08284711534337652, 0.02722373686640734, 0.01952943129224643, 0.028381301465654568, 0.045137482980686816, 0.05873009292108398, 0.02968571554388731, 0.07632655797586327, 0.04726872809471623, 0.06286793298298313, 0.06269730988048738, 0.030360064439235196, 0.01363903103816894, 0.016307981774931955, 0.016368652108095346, 0.019352782908226215, 0.07437524776304923, 0.024988380403468208, 0.027829277659616167, 0.019966474876949386, 0.05122462227459877, 0.013918170495139015, 0.011703199631864987, 0.03049999997470408, 0.008686094492253278, 0.03256223780373412, 0.04971646711290364, 0.01005701840885224, 0.0642004509967181, 0.08251727618757757, 0.01759724454924224, 0.06562696033788305, 0.046283864611459356, 0.06523183516917691, 0.039588723466881824, 0.02032856824958036, 0.010724674568571632, 0.00683292253656433, 0.08765506017352305, 0.006738159375550647, 0.01716420760438327, 0.057039317719998865, 0.15033758455707183, 0.06667750436932811, 0.09047594146742936, 0.04952566142404272, 0.038549858445842425, 0.013007186616079943, 0.03603571492637839, 0.0400342189166094, 0.050731457003782836, 0.010856576714544527, 0.07406562566757202, 0.05930234144832339, 0.020322968146853873, 0.018871392408806472, 0.00935891408458232, 0.09050008855880269, 0.043369650825737946, 0.040561796856984016, 0.07532508953684762, 0.010819174386861344, 0.06950420027057971, 0.09893231108904847, 0.028735335593322114, 0.03755522351111135, 0.06019663035629257, 0.02382449174840604, 0.022148701227119854, 0.051265374321730874, 0.09081341085895415, 0.009351982904087392, 0.055258825962101264, 0.02047802434272824, 0.028377687445871776, 0.01716838661401022, 0.05365220934993798, 0.04953506132287364, 0.04130351935483275, 0.013825829129575962, 0.07774482421096295, 0.03604653974874847, 0.18494909989737696, 0.043385125801808415, 0.024388719335078232, 0.03434233885679034, 0.05823937530118612, 0.0041481018096448915, 0.029924545369501558, 0.11867608229118971, 0.037406468388414195, 0.1953036208907443, 0.35954004754462554, 1.819323130672978, 3.8285956171251114, 8.488655263377774, 13.38145805943397, 22.134150612738825, 28.423610387309907, 39.72300375661543, 42.45043562304589, 53.876280323151626, 57.29377477399765, 59.363676194221746, 59.16240369119952, 59.64825199496362, 58.70247833190426, 54.44153701105426, 48.81871346504458, 57.58078636661653, 43.741448463932166, 47.55897760391236, 48.648859147102606, 42.26536643120551, 33.049259570337114, 48.269546339588786, 48.079480048148866, 44.69069734696419, 50.19972508953464, 43.674434769538145, 43.61412832813878, 43.8325455111842, 49.93343930090628, 46.817645718974454, 44.08607182964202, 38.80503185333745, 35.94660851263231, 28.506503797346546, 24.486337169524163, 16.129256832984186, 9.153358744036767, 4.7559552231142606, 1.4145774298137235, 0.5947046174157051, 0.06980675903539504, 0.020499396280595855, 0.08992332394324964, 0.05439758991762515, 0.002889829446494039, 0.029127055501204827, 0.030077774445676518, 0.04768190229491842, 0.03877362889808513, 0.025754119757743135, 0.0077398921149001735, 0.07728282722734636, 0.029626374373272545, 0.03218193260592318, 0.006482842859000929, 0.038803579105484876, 0.08934645973626645, 0.04683083989807675, 0.06736628636116944, 0.03165235709128601, 0.026876637749674342, 0.040577762129326025, 0.06311776191597024, 0.05343190161511303, 0.05200357664556754, 0.06131688072796791, 0.03036452881661394, 0.029848516888676152, 0.048150568073915864, 0.05313620699809925, 0.03772025417175986, 0.031558086141763676, 0.011476714355540613, 0.010836971566952285, 0.056527865930430354, 0.019864297900048476, 0.05028137268738882, 0.12083098803076053, 0.024923919850299438, 0.011009686089481318, 0.10634916834533216, 0.04012878480998259, 0.02852476675123457, 0.016964877272144924, 0.031127860739586816, 0.01585201964893889, 0.02939492580480874, 0.03400586537956711, 0.015783655877795913, 0.054702829990175464, 0.03675253190580876, 0.038818820424738436, 0.024391940734799833, 0.03733905265107751, 0.045215773336108656, 0.025889765200836044, 0.023359143130120733, 0.04426650612825348, 0.04204870073965961, 0.05971801692559835, 0.04875663172213301, 0.06667815554406374, 0.06017361707504719, 0.14381745619879616, 0.09902902202860964, 0.10411216862379544, 0.10908983257268706, 0.08745649018354955, 0.1626097921642565, 0.11785934829423506, 0.19513725723710754, 0.17064142731889603, 0.13088409939119894, 0.09756873587086316, 0.15227522010043745, 0.1811884049206011, 0.16680207043405504, 0.13979379388113178, 0.10744047591522818, 0.19193200664895196, 0.14213138860800575, 0.2216495991113686, 0.15516190068616023, 0.14007458042713905, 0.35092606299346496, 0.22159214251704756, 0.18728382945541414, 0.19078057649875843, 0.1495270328896661, 0.09736939213208615, 0.1171718150257103, 0.1837509537055608, 0.3435429978755213, 0.09881923651142467, 0.14886810534423398, 0.1728737615649739, 0.07732104735388871, 0.07269776801789, 0.15293759504152885, 0.1558814564299199, 0.14441705789537201, 0.1501784221299233, 0.23062208216757546, 0.1608156602108671, 0.16218283604229652, 0.2122083774978115, 0.1546723551807865, 0.1614991945004271, 0.14134596462451643, 0.13185009029844116, 0.13758658731897033, 0.12247745653674488, 0.15426231428019463, 0.11066806562725576, 0.09572561259471601, 0.13218588195741177, 0.17774661702494468, 0.09356342901986453, 0.17577665257117442, 0.11351435039673122, 0.18568653613328936, 0.13999904415780498, 0.17044509430566143, 0.13916946286636014, 0.39071375864648056, 0.11852316348062408, 0.056350018618808645, 0.10934156906460563, 0.2487837898755266, 0.18179033552446675, 0.20541820314622697, 0.2080424526526082, 0.168692484317768, 0.22351244915156598, 0.5612316619484656, 1.6288310169212281, 3.562573362742701, 8.620776380262068, 14.010352261604803, 23.98691942614894, 30.946353366298062, 44.437888822247906, 49.914553088526574, 60.72783731645154, 67.68951092996906, 69.07485285112935, 68.87071701788133, 69.10902454007056, 67.74693442929176, 64.01004529768421, 58.72421218502907, 66.7480871754308, 52.478524100395944, 57.04779117338119, 60.86654017048498, 51.438770448007894, 38.08933265747563, 59.06129675526773, 59.49708777089273, 57.040366126645, 61.47253851736746, 51.44141412550404, 53.84295586616763, 54.16506482708839, 59.91020356455157, 54.01180213497531, 51.96827473178987, 46.259370849978545, 41.638034312955796, 32.50118090260413, 26.140602673253706, 18.91054480306564, 9.748247957998707, 5.007077618952721, 1.7383204256334615, 0.733477216093771, 0.14636849834313317, 0.09299793355767766, 0.11488579333789888, 0.2172223157099178, 0.10152636907033383, 0.16899916463561598, 0.19097360001216013, 0.18357201088820735, 0.09967168552740928, 0.2228348290607814, 0.1912588605116452, 0.204176175438108, 0.10689461528654061, 0.1795349113883511, 0.19097914648873193, 0.13363106086129142, 0.16372929176976606, 0.10325242645077168, 0.09911215789015256, 0.13164344574174575, 0.27157050827818535, 0.1566976618262068, 0.08709115817421868, 0.11071426072908987, 0.2415903928058763, 0.3442234371698672, 0.13132294519774376, 0.2056114105207305, 0.16454669226321483, 0.15097570515448047, 0.0634481756377124, 0.05858474305921024, 0.10580680873845855, 0.11095927862991249, 0.19028631189177114, 0.11768199127888489, 0.20365381072605812, 0.39368587335751903, 0.21494066072327478, 0.14532042877568355, 0.1684976681586235, 0.14205966745653462, 0.11741726959664976, 0.07661728068224846, 0.14489474435967786, 0.14872176722893793, 0.20408062895219173, 0.14471540317660378, 0.10471611403890195, 0.1684729694839447, 0.11765182273642671, 0.20213262057833134, 0.1578926823792919, 0.17851368554176825, 0.1018420892256883, 0.19646298771183338, 0.09378535703064934, 0.13471044810308566, 0.14768108274907837, 0.17905304208397868, 0.1612857317612056, 0.1496779215672324, 0.19392924383282664], [0.038995131730071964, 0.05369732426779886, 0.08786755764195997, 0.017969417723736936, 0.05497050494135869, 0.10483864980239062, 0.0731467568285523, 0.0645772590031547, 0.06536227696004414, 0.05301129636204532, 0.04626257885848323, 0.06019757647487906, 0.05391364451497794, 0.005575654945606667, 0.03956758327061131, 0.038715881190352866, 0.05218411292580347, 0.03406105435363228, 0.07391641472255991, 0.022115592822252263, 0.03217208071521694, 0.04104750426185708, 0.05518597866138143, 0.033866199890091535, 0.01855479316755889, 0.04515096995859377, 0.0034113102846012842, 0.05520055348414087, 0.011396771165422134, 0.08722755246825757, 0.05145399282956797, 0.04828191767897337, 0.018634613783609484, 0.046966866469911994, 0.029029838943613634, 0.05481801130959103, 0.054628634374708905, 0.07229725725107616, 0.07489437958405865, 0.12484905024569844, 0.04154085722421447, 0.04057090181196409, 0.09654640685766937, 0.019708433481413993, 0.03468425538871558, 0.04306423072252543, 0.07262797740798804, 0.021857934470679012, 0.013332368914909182, 0.06757306115281198, 0.04144384751036283, 0.03028615993717986, 0.022427875158046524, 0.03489255852576706, 0.039680496969771, 0.06057862860841617, 0.028011248439490318, 0.0359140525031234, 0.025066023414594032, 0.06687861011033097, 0.04562589467593259, 0.058055506538479566, 0.03199109818876511, 0.027278016111062422, 0.00327604549144575, 0.02126390223331269, 0.009085165971379367, 0.029364280372617707, 0.01661581888554558, 0.05482796662216706, 0.03933544713823546, 0.09847131001973346, 0.028896901621333057, 0.12838315173623063, 0.7443763796360262, 2.2157133250467242, 4.411888343672599, 8.038682428098495, 14.324640016401968, 21.173018909269764, 26.62617248873557, 34.155669981433505, 44.46087783382785, 46.957384078733384, 52.14197297250071, 44.51958787056708, 49.0986216452814, 52.997194797761985, 49.005351604953894, 57.236994543383204, 49.265161560427764, 48.0661714461542, 52.35718557911535, 46.441788519582445, 46.53427408587548, 43.43470734934653, 43.93772778972503, 47.033772237839244, 37.06888491107572, 41.71333205315375, 41.147953771775775, 42.01849245255993, 28.13475331952495, 26.883107346873132, 21.470642474389848, 13.545069925246702, 8.250584063991424, 5.115226189936362, 3.8426384377864102, 1.4551449110431056, 0.3775168522711723, 0.15698028698323235, 0.02757832640781999, 0.03757512264494454, 0.03744512901551301, 0.0277220789763716, 0.03700354444463888, 0.06839074509879274, 0.04664703625284376, 0.011982459747683138, 0.07358079160293264, 0.03285471485146592, 0.009442435862917093, 0.03425931790843606, 0.06138911898878794, 0.013765772624361901, 0.03920307097535941, 0.05434647653131716, 0.03439011209974847, 0.04226666424543627, 0.06323015850578105, 0.021452292829992312, 0.029438104435440995, 0.009566668511158036, 0.023263853283659108, 0.031345035174801465, 0.04480608100552232, 0.08889491219193706, 0.01976591688881238, 0.036036074987702796, 0.039586436694427844, 0.06444211343243238, 0.026815107482815945, 0.01646426179626536, 0.10268197439971471, 0.026269901859303637, 0.027452843121042656, 0.03140207425120377, 0.03603951472248282, 0.040377774876692606, 0.01587873983812789, 0.02076938098687078, 0.015519644742110565, 0.029315132001835494, 0.029199328235981446, 0.015205202995979739, 0.037382099131542834, 0.02063013301531394, 0.01648264599122828, 0.01955440192813835, 0.09896244132711042, 0.01640493594740908, 0.07213997940022139, 0.03313014644288248, 0.040898588260695826, 0.03956900819415047, 0.0328719824732792, 0.02316815741059761, 0.030891560919342503, 0.06533914876561012, 0.033831469294044285, 0.08767998101369989, 0.02219572178869238, 0.04671988355356359, 0.0319810375390995, 0.03927598339355281, 0.04183901098346518, 0.06765216739187319, 0.0460381955359011, 0.03955551355536427, 0.04219113563698146, 0.1044651129913907, 0.020313985765941685, 0.011244506402421865, 0.037540495470767064, 0.0200909526733261, 0.005333352347670664, 0.04702495508677056, 0.05590762199473478, 0.05897863099591867, 0.007492014790900173, 0.03595712579666607, 0.032270488539530386, 0.052715429375248576, 0.029463291491171526, 0.0416581797593784, 0.018105787119918296, 0.028516636643138145, 0.014774472933382759, 0.03874709544282767, 0.040628435015077555, 0.05029500139156177, 0.057626600722752275, 0.025231521388876344, 0.05565403157003945, 0.043294091573766166, 0.07974583054742507, 0.04603291335966318, 0.026333701661637714, 0.040152740379374836, 0.05544444906615442, 0.02500769731047894, 0.0210473119401403, 0.0632147218341068, 0.04240802661966413, 0.016563066071079626, 0.05870594199927104, 0.05690974160848607, 0.039872765886567296, 0.019532127921739896, 0.14327094439537297, 0.05109368635702038, 0.03481188180646108, 0.06144322777887987, 0.05733298986489254, 0.022824892563925638, 0.017655762175338405, 0.031070551617191206, 0.009179894658436459, 0.04132503493418617, 0.04582685102979022, 0.02195470861249393, 0.04988920844851002, 0.0411562695949068, 0.03175313595772511, 0.03558912397091908, 0.05173500920195253, 0.026788721499483914, 0.04127861000597477, 0.08479674782363639, 0.03567619369395318, 0.025929253202893084, 0.06807726192017717, 0.03656888913903986, 0.008482734537533215, 0.029416418401524428, 0.012965030712826599, 0.031458050380611134, 0.11056658195992632, 0.42082809272312355, 1.281559193326581, 3.332610437946935, 6.714127928979936, 11.748497889887902, 17.439740319405836, 25.883148101068315, 32.72897647273156, 41.02202999976374, 51.66545990974673, 52.54977787694624, 58.359773005208666, 50.8379888534546, 56.5743257922511, 58.824628783810525, 56.23857482787102, 60.61233135961718, 55.7661606419471, 51.772434711456306, 56.36390239961686, 47.04413906220467, 52.87709966782601, 49.49139210485643, 50.86583768167804, 54.50913513860395, 43.657407760620124, 47.47694907649871, 45.93216280783377, 48.703968448023645, 33.82396690307125, 31.12928878876471, 26.196794548342307, 18.076815605163574, 11.495723685910626, 7.703491382060513, 5.373832468063601, 2.299087715725745, 0.39517095012049525, 0.1006239481390484, 0.016958275509457436, 0.045356381113731095, 0.055111036110188694, 0.05340361764894859, 0.06520253230607317, 0.03265693010161481, 0.04577889009529064, 0.030706508550792936, 0.0164432575806014, 0.029486645681543217, 0.03573666867469588, 0.029927318607787454, 0.05287530809460629, 0.05235525696808773, 0.09172983587749543, 0.03938232405832218, 0.05667293233977211, 0.05255805193296364, 0.04008865712450878, 0.04215938512295966, 0.05743336653517139, 0.13025504927481377, 0.03236671684369926, 0.036988395055936235, 0.0199919990113666, 0.06420094129298964, 0.010944880796746622, 0.021226624394917203, 0.018683024794764577, 0.03252084990362487, 0.040746075476730065, 0.030579719084104708, 0.03411767591211585, 0.04462629549145218, 0.04313967506130857, 0.00245644201640971, 0.010978383736895218, 0.05393416418002979, 0.03507512876944196, 0.05064120418542335, 0.021124866851154837, 0.07867972727023786, 0.039425650160879865, 0.05545545008874709, 0.008124809640820229, 0.01023975144621105, 0.045985266521212556, 0.010425002997620933, 0.09355774464746637, 0.04357429589295099, 0.034385239780550046, 0.09016541538820153, 0.024949319495428956, 0.05859457579771838, 0.04986009710738736, 0.02146035207495574, 0.03274944670979054, 0.05129012662256437, 0.036894583759168466, 0.036961198934624274, 0.02728978130635956, 0.034018444543283795, 0.03968846811462314, 0.013623606815423458, 0.1653228006175449, 0.1770836138917554, 0.25318579237547617, 0.08907028503956334, 0.1396009542288319, 0.2573806293789418, 0.1821800750950652, 0.14913219117349194, 0.1576042655975588, 0.11415562727638792, 0.2830611223415021, 0.1055686779680752, 0.14675364138618593, 0.15184135386540046, 0.16018005238185007, 0.14351224676976282, 0.1500459808495737, 0.10445141533930456, 0.13735165879611047, 0.1342502131216949, 0.18804965690980036, 0.11183012141695908, 0.1643078107266657, 0.08723244010921448, 0.15107408616571658, 0.12147679249004972, 0.17828326161590316, 0.18655670476296257, 0.18038090228313403, 0.17415623871549485, 0.1465052756811342, 0.1621682650499767, 0.08570534342359151, 0.12361952509250372, 0.23883944767857754, 0.0877106934785843, 0.14254841623046707, 0.12627808001613425, 0.17002952225025625, 0.17273272477811383, 0.11090726125985385, 0.08765708264564315, 0.2995290709359031, 0.1686371574478765, 0.2440731918379184, 0.11710423840990952, 0.16500073725417738, 0.18162479924578823, 0.09808843459693656, 0.10548066212645463, 0.12245418278560524, 0.08044566718801376, 0.07842737790797988, 0.1544172785455181, 0.13587667907197631, 0.3559349909905465, 0.18353712324413562, 0.09542394249189286, 0.1624713753980975, 0.13759464656393375, 0.1363914595135758, 0.16086671231014116, 0.08947239693013892, 0.2557330653672257, 0.06060822258493113, 0.10589516931964506, 0.1264267776822371, 0.09339168742899934, 0.10087683376285339, 0.11802937384814986, 0.1653571979653451, 0.15685942895229787, 0.14237299741756532, 0.340101118049314, 1.5047372757427155, 3.2362027466297154, 6.5809100193362084, 12.174694788071418, 18.58703555599336, 29.053193946038526, 35.47623003682783, 44.86691767169584, 55.87733630211123, 59.75512481504872, 66.87388543159732, 57.11496568495228, 64.88981331548383, 69.1149159400694, 64.39875610413091, 72.25273363051876, 65.19708002767256, 62.97896792811733, 66.01378025547152, 57.48716723534369, 61.45741778035318, 59.65619087219239, 58.25181368858584, 61.215003536593535, 52.222103072750954, 55.915112649240804, 53.069397787893976, 53.16269920718286, 40.07599746027301, 35.47259399967809, 30.295728252780055, 20.635034461175245, 13.477030531052621, 9.180539788738374, 6.049985347255585, 2.5015614446132415, 0.5576895165347284, 0.2740195994415591, 0.10418014360531684, 0.10064991851968151, 0.1170464983630565, 0.12114917498923118, 0.17171526808411847, 0.11649120719202104, 0.16020084400811505, 0.12342293927025412, 0.11350184784180696, 0.24510921850319833, 0.18764844134209618, 0.19300143474773054, 0.22092150914813244, 0.1990521503912826, 0.11683059180335653, 0.12187790846632374, 0.1531576154933822, 0.19243327329956716, 0.14684590901578629, 0.13945697566434262, 0.10035536537367491, 0.264970722097543, 0.09673577613167225, 0.15314203326500234, 0.11212494269373918, 0.14816593979635548, 0.10815409447757468, 0.06362665497187166, 0.10127414228214372, 0.1706816009696453, 0.10253742893016148, 0.1049302279528591, 0.21097679922897972, 0.1012806693512586, 0.20557557292763265, 0.1616205581493916, 0.07962532491693575, 0.15416641539383322, 0.18681535136795815, 0.1305057438871553, 0.13455264931244237, 0.17020964484301307, 0.18348889034842292, 0.16091591047663845, 0.10814149999209952, 0.07156093184265398, 0.14257153676402184, 0.07281143248321549, 0.17369618759520594, 0.13913148022707433, 0.16663414396105275, 0.12758991365591366, 0.08634608404170122, 0.17990942113101485, 0.08862764709779332, 0.10056629236186705, 0.1338069852922232, 0.17298611601994884, 0.12898274577192723, 0.2121145623706041, 0.1038521124170192, 0.15888700321797403, 0.17900263349856102, 0.13488180664998872], [0.03641457221801243, 0.17485394563165405, 0.08980995059133538, 0.06794059949536478, 0.02366690937760136, 0.041384950670744144, 0.04236738182484143, 0.04789112856791866, 0.015015749452305178, 0.021060230097763484, 0.02883191438271634, 0.09183236908528114, 0.10099713254960314, 0.06723274957508811, 0.045683048665523536, 0.050680481513301213, 0.00872447932769935, 0.021010761885272882, 0.046410204001492074, 0.02760960194732874, 0.027180560150994893, 0.04634928468975329, 0.026334000435928186, 0.0816372556671981, 0.018805399679789142, 0.027282281305580854, 0.08340604543205231, 0.043180415617121805, 0.017854148304210078, 0.011381775951914249, 0.07465167526876734, 0.048000510601747426, 0.037020961453597394, 0.02318640370973416, 0.006406383453718117, 0.03853840543137443, 0.059101791121065624, 0.02103976214364652, 0.027497961869343158, 0.05659992416058818, 0.023268242967465234, 0.020912624106952743, 0.01934088364754233, 0.046470430003659385, 0.018156653442870707, 0.05638598644685361, 0.07835984725745455, 0.03275755958090867, 0.01843239338467679, 0.02911922416739887, 0.04209011162240659, 0.07979207927541387, 0.0237168142602088, 0.04396159930395023, 0.01697812101713592, 0.017292780140715263, 0.027318421503408786, 0.07709680575757258, 0.07269353921254797, 0.059972538147121675, 0.016877673483724077, 0.0972281561623658, 0.05227237008512021, 0.07173602123774829, 0.036288615871941855, 0.027535588277744192, 0.04377551271670288, 0.03130892753571032, 0.0403082792106415, 0.03957034884801796, 0.03807247458626667, 0.05470894720225085, 0.06631131434152204, 0.07397100614804415, 0.023492741203236005, 0.11395652868574667, 0.7335556634972173, 0.9142692471223494, 3.4629532502543543, 7.136596614314664, 9.994946410579066, 16.855648409935736, 19.89260235140401, 26.212758594943633, 28.498747310330792, 33.74410352399273, 37.88666379067206, 42.14275313961891, 45.454488723508774, 44.234933622421764, 43.75504732131959, 48.15921791138188, 45.04876267525458, 46.89428098740117, 37.55683952762235, 40.30563262201125, 34.38603470402379, 31.378708385652114, 30.088295667402207, 30.826724998412598, 26.451111224389848, 24.0902974144105, 19.399834986655943, 13.26689249084842, 8.544225442794062, 4.0332116955711, 2.0647344329664787, 1.4272803933389726, 0.16219794329616333, 0.02901272453938521, 0.06842120475466214, 0.02833476353947434, 0.031180349253718893, 0.008570984993580609, 0.06874119201975484, 0.04747570973009833, 0.03293804606542953, 0.05762037242792788, 0.004218892643092982, 0.08202826694375084, 0.004576782108239469, 0.02989660422768324, 0.03318230553920711, 0.07640435420457395, 0.02992642611535567, 0.07584799817132373, 0.055172112469951955, 0.03831523252771266, 0.05713829244937628, 0.04325415924071305, 0.04287180475770466, 0.016007175436243415, 0.060398781807312084, 0.07760660662766426, 0.012271317987582617, 0.07571810030288274, 0.03346470470029501, 0.035333836661471475, 0.028533071144333774, 0.0665878184560326, 0.03097516026407961, 0.032435944378976865, 0.014572530241322615, 0.01753174977737569, 0.07611721678967438, 0.035821987886823, 0.02830737206574169, 0.038762777262637695, 0.031230334575558384, 0.022019153843904217, 0.02424862292114525, 0.03184154824984651, 0.0683688503059168, 0.06583633982846815, 0.10247376702365377, 0.10829657917061161, 0.0874564288965156, 0.025287792462134556, 0.03066568564052784, 0.010634642958100285, 0.033737891654093424, 0.05282071666912206, 0.015116790703858341, 0.05285647765342748, 0.009595268488591237, 0.0213476452195356, 0.04936835292967097, 0.027954544526554888, 0.06304944219488291, 0.025276758880805106, 0.06211897478468957, 0.03129822911784774, 0.07963228865616745, 0.03240080775632974, 0.07176154728738532, 0.03864323690293297, 0.08242198251067631, 0.04946641601441849, 0.024385599442006602, 0.08667554015353804, 0.038124580056436604, 0.03787647099083951, 0.03353292482995218, 0.03832872716649886, 0.04564754432067276, 0.03935891241135617, 0.06326656300394286, 0.05450557767143173, 0.07235008667433455, 0.09921800059777114, 0.029592586065372153, 0.05671328602118358, 0.02479755364718937, 0.02782808830811372, 0.030767962208858905, 0.017689738174780242, 0.02523552611350052, 0.03403755460655497, 0.033448800714986945, 0.034341768121286746, 0.0227553547630387, 0.11768641926708723, 0.06341419580783095, 0.03086062437374025, 0.06638514989566419, 0.0220601357174136, 0.12164141712409836, 0.1227709754640537, 0.039186737980813756, 0.05622744838136339, 0.028632147380361156, 0.020509523962954843, 0.04929096655799978, 0.03925682736500617, 0.016692889245948004, 0.040616905391817136, 0.02170082132872795, 0.06775580376626984, 0.05099095013593474, 0.08019834336253905, 0.033527447301293575, 0.0076529162376368, 0.04657362204705996, 0.05418942084596042, 0.06673823215908582, 0.04304116764556497, 0.04511674115013692, 0.051947587109621496, 0.04982137136281498, 0.046125506576631344, 0.06651561466916915, 0.01686823145005732, 0.015906988372725826, 0.0656880711716029, 0.028139118090151783, 0.060897183289090474, 0.04519551797139068, 0.042349436215215155, 0.06489107159957772, 0.014248233731655825, 0.06282102541937944, 0.05777444420081954, 0.06452165634161042, 0.05125061946830923, 0.04097273025000769, 0.057842641347838994, 0.04941699185198353, 0.031346316456854824, 0.018888470423858494, 0.03938040117763224, 0.06359951247671439, 0.3383266745555786, 1.0224943043243502, 1.7666092947606118, 4.689427902621608, 9.71123549246019, 13.052151549247004, 20.306147644596717, 24.848671997747115, 31.339865153835667, 33.85853867377005, 38.95820433093656, 42.1158339131263, 48.497161480688284, 50.22045089352516, 51.48501911470967, 50.212641454512074, 53.65484683744369, 52.17896092322565, 53.38419545081354, 43.86898040771485, 44.47786954141433, 42.704726803687315, 36.93832881989018, 36.24081765451739, 35.76886630827381, 32.531620456326394, 30.186235289419855, 23.75191846201497, 16.973974550923995, 11.84588739948888, 5.516129193767425, 2.831051325605762, 2.206631322060862, 0.3439379008787294, 0.06754031855492823, 0.06944408535116142, 0.01100236994980444, 0.005918566434223566, 0.03347954765382794, 0.03644604310994187, 0.07169194053858519, 0.07141261722051329, 0.030215482580505555, 0.010089431588928546, 0.022321653236905416, 0.09049872492229746, 0.030893179280082547, 0.02708651711263003, 0.022125952246208346, 0.016742570047837593, 0.04024126183902545, 0.061254272192356095, 0.035123599152411186, 0.02943721768866864, 0.02170237265677462, 0.031674202088446866, 0.006498470573851298, 0.08428392856712304, 0.018100794141871795, 0.00394584717615808, 0.029964468126455625, 0.021914025513275016, 0.04017065917592376, 0.047553360402103395, 0.035132753903106335, 0.02723539480939508, 0.007978085608732316, 0.041737194067888686, 0.03637512635079123, 0.04182755796899719, 0.027182475370805592, 0.012220308023144402, 0.018403236078278675, 0.04379369198314605, 0.07168472399033847, 0.03779892757114384, 0.03328983747069875, 0.00944965145355391, 0.12114236446758433, 0.047216649437623645, 0.04328589443297636, 0.09512960385050505, 0.03223747398043352, 0.03337570826613134, 0.007233006209360376, 0.03215637591276919, 0.06128563966241576, 0.019847325222086043, 0.04150654031564632, 0.0822938160009442, 0.013034872076053534, 0.02376450514871507, 0.008682795526129345, 0.03099963294282075, 0.0240432424095249, 0.04247570282689506, 0.037983589234852025, 0.02933126198308122, 0.05401394457646436, 0.030239633502318498, 0.008213080206675636, 0.1961755055573679, 0.22779737809492698, 0.1465211643446838, 0.1589973352008289, 0.15158474505428346, 0.1640203285722002, 0.08897440913583964, 0.0949466850368246, 0.1182944555917094, 0.12804077938199043, 0.10436330756713307, 0.13089315455046394, 0.21351265751065748, 0.2245163307675431, 0.14922793684226854, 0.1744291805211575, 0.1491058683924137, 0.13315398726732502, 0.13103517192986705, 0.16869340362327714, 0.21871203496571512, 0.10270840443310239, 0.10271175223733149, 0.23085409955632305, 0.07237368984328163, 0.15601190588166639, 0.1273593901386184, 0.11894812011310171, 0.15014382559926281, 0.05933566627302959, 0.18087443144571397, 0.23774982550211493, 0.145470061069054, 0.16815214718301452, 0.07270476240063868, 0.17134835793366357, 0.20650771807038015, 0.22644515629977952, 0.1188410210212873, 0.18224865528604678, 0.1625481527298689, 0.10683905092939254, 0.1269859069537732, 0.11095912541232764, 0.13407503945692895, 0.19935395838993214, 0.19764961194126837, 0.14580531646647762, 0.2687648797948515, 0.20306522537383342, 0.22865098390367725, 0.2888008062877963, 0.1229816266605931, 0.2131877902654871, 0.17689878751914348, 0.10598223521223954, 0.148272916314102, 0.194328666754788, 0.10878965634131625, 0.1320066480266471, 0.07520440004525647, 0.20586121647107988, 0.1682337355469504, 0.15062439255416393, 0.20501053711820036, 0.143201153785471, 0.18284389028145423, 0.13417875244011804, 0.10237311839216179, 0.09809521447506644, 0.10167368011729372, 0.20194641524745574, 0.14923602673074893, 0.09615243082084964, 0.13109115763537346, 0.4030011960815999, 0.9730197945910116, 2.1972968164951574, 5.09471268423142, 10.458300901997475, 14.580910032795323, 22.607066862044796, 27.5120319474128, 34.90669012069702, 39.0179459510311, 44.54625606536866, 49.46561428808397, 54.8895775887274, 56.646654298228604, 58.01942894535681, 59.014102797354425, 61.60098045103012, 60.25252449897028, 59.96046873830981, 50.38531203423777, 51.48186160672096, 47.825965496801565, 42.83565159766905, 42.04576861473822, 41.03363237073345, 37.500871227633574, 32.978711820417836, 26.50342191419294, 18.951470813443585, 12.890226302608369, 6.335388768103815, 3.132154033068688, 2.4417222555606597, 0.7246841814729476, 0.18647401323241575, 0.12947653540440146, 0.1797976642246208, 0.1911562506950671, 0.15433595065147648, 0.10063569226692762, 0.18591717456377324, 0.2870119909846014, 0.14441647566854954, 0.0872641561492797, 0.17425512534476098, 0.1183827625467412, 0.1492433045660296, 0.15558317243572206, 0.12754395604133606, 0.22483836348739364, 0.17566155552143053, 0.152487579673048, 0.13510271576383423, 0.12914843526819061, 0.12405884587356161, 0.15452702830155052, 0.06938400873613935, 0.1718851557422069, 0.1640284491041976, 0.16976228013875025, 0.10142819490283729, 0.0981887921150173, 0.2251573012120301, 0.15683059340282796, 0.1209986080685931, 0.08487496540070542, 0.07455534737316832, 0.1299366631334828, 0.09718522459508912, 0.14316649596777656, 0.17385001805040146, 0.07426427226633796, 0.11339706999640312, 0.12185124860655878, 0.18427003956129476, 0.10596259271786099, 0.1565531010348951, 0.24845124642935493, 0.296780102315449, 0.25909847429683136, 0.1461549743168777, 0.18563490180719286, 0.14195765518853742, 0.1212457710156037, 0.15514087923351796, 0.14280738459239084, 0.22534785792231563, 0.12792860112723806, 0.13979881941791505, 0.12608032974023975, 0.16800230038502525, 0.12954191334785956, 0.1485722115443599, 0.17348372077028598, 0.07728152487787508, 0.15615255962456429, 0.14135195543208431, 0.2349498813911792, 0.1883258928935374, 0.1720219637237249, 0.13674456475963517], [0.06196860321647218, 0.005958690768062708, 0.10493988832158428, 0.08733413062028347, 0.050251522071419225, 0.037955159711981976, 0.015472370413913122, 0.012117091081886282, 0.009697736578903372, 0.06411777861836938, 0.07402374364075161, 0.01619240017457595, 0.0870542940233023, 0.017892035182505366, 0.019295688290449402, 0.035108924738221595, 0.026081530414822123, 0.007304419010441991, 0.042934455428152316, 0.025219505299784006, 0.015056891246668756, 0.013358006047295227, 0.017230646579616496, 0.0359913507746833, 0.053085342590366645, 0.015636084360941764, 0.022834851706941283, 0.047667630076889074, 0.03830240438542059, 0.03163928571607798, 0.056530819199378454, 0.005954870383345312, 0.05016711450392201, 0.062262210243892294, 0.03172518332458792, 0.007758885349762897, 0.03167001541794068, 0.030122724654633674, 0.017604625806392684, 0.0481258234339616, 0.05803148968205337, 0.06817612556680556, 0.04571006092573366, 0.07298462198025758, 0.05442529931784638, 0.04964374621669131, 0.03958009348641481, 0.09532883267609343, 0.030894113907350168, 0.015362850484257985, 0.03074565564372367, 0.058620745361211805, 0.0522821951627491, 0.023021307931612098, 0.03619889931512937, 0.030294056388459382, 0.029342376003642718, 0.021144174182066516, 0.0055610853897017105, 0.05721989996551026, 0.055726695009657455, 0.025671671460112257, 0.019952457383154862, 0.02567000138843733, 0.08119487819532234, 0.0719421448546552, 0.0318238286361579, 0.02685759471909654, 0.03036521255008636, 0.06699878632301284, 0.01553967985655031, 0.011546469533876067, 0.05357324100670315, 0.043325497348222046, 0.009033864893529926, 0.010549516225564144, 0.00788818471201305, 0.06556326012697912, 0.4020092960807585, 0.7340231609921302, 1.079563135581632, 3.715936810739579, 4.709946801585536, 7.456028557592823, 9.061117345286954, 10.486049709781524, 16.587742682426207, 19.195618744819395, 21.155127017728745, 21.906711978297082, 23.963018463503932, 26.183962514323575, 25.948757586940644, 21.11715062972038, 19.860638956869803, 24.59228627143368, 18.692857180872274, 17.64061470185557, 13.522593763566787, 14.959639387746012, 11.634224537880192, 8.008391434146512, 6.688072604517783, 4.1167437165014205, 2.394294671473965, 0.39287942792138747, 0.30375386197720805, 0.05165355107296379, 0.08408942650402747, 0.029673322156492262, 0.045875463139025435, 0.02752318339903028, 0.014830193380945393, 0.04015516121721557, 0.020979578276315046, 0.06493569622116704, 0.017754043595144348, 0.011379527483856487, 0.056052489221216216, 0.024784342460935155, 0.022886840348702767, 0.05760814183421674, 0.0137892896084175, 0.04075966204606718, 0.008836373172309852, 0.06432458022308928, 0.0010911530355975454, 0.07338772212425548, 0.04192768183026103, 0.02048176859745816, 0.024292542741844253, 0.029189600834562898, 0.020832569834085244, 0.025058500431177598, 0.02470580312693792, 0.03773144671633359, 0.008198311946715319, 0.06921838818778915, 0.11516610490939311, 0.02311101682754534, 0.04592691743445974, 0.05024874117225409, 0.05980393751674603, 0.023324073540166985, 0.0644476292654872, 0.03139516222290695, 0.012027591902522311, 0.08750885995405336, 0.028849884890200152, 0.05632720835086319, 0.047876201344714056, 0.06065999863729362, 0.07957737547375503, 0.06345891619041082, 0.04828373713779354, 0.03496725975926365, 0.023805249534967928, 0.021437507333053697, 0.09081226172706774, 0.03475358251542334, 0.022878129929003697, 0.09294416184627241, 0.04566090106363258, 0.004576543663373037, 0.023676108178352157, 0.08064092001727513, 0.009798475225726444, 0.03643711435518438, 0.06586102318138846, 0.023926220563871246, 0.01483197166253963, 0.042392701030738895, 0.016491911824672453, 0.06496457007503317, 0.08680890840027602, 0.047021005903520895, 0.04356847745516608, 0.07501583516357407, 0.04335698356190997, 0.06819569911327093, 0.07755026086083344, 0.050084327212384636, 0.015964048516546047, 0.039519365696657094, 0.06303182600306408, 0.07420077889917359, 0.07523527338860497, 0.04875359801395286, 0.08180866784025585, 0.06535724376238163, 0.04916356613619193, 0.044921875195277315, 0.02205672088049112, 0.07959084329946388, 0.00819304509223589, 0.008409418965569668, 0.05033470772867722, 0.019610611714362618, 0.024688958768702807, 0.02348584258147786, 0.07384048774838448, 0.060471211590113184, 0.017763334326446056, 0.0307052138622009, 0.01980711518216037, 0.05369011154999176, 0.02767755777665204, 0.03172451874331361, 0.04418536592575331, 0.03948320634663105, 0.020995587598712697, 0.008563961882534768, 0.044819353478810484, 0.062473144892963677, 0.0841170669563355, 0.018138730815882166, 0.03968683634734443, 0.036579265799974246, 0.028575466450063453, 0.02352206130331803, 0.056838790375378825, 0.020845516720005584, 0.02133768607651995, 0.02594003972086695, 0.029342954400025552, 0.04653881484222028, 0.014559483763972118, 0.06008053739224711, 0.04365177802561272, 0.03433398466797606, 0.03628565877255413, 0.06649824745592571, 0.03078341037185202, 0.057454276905064626, 0.019032862675826878, 0.005785336562116901, 0.06393797395210113, 0.08214151006071799, 0.015240036056286868, 0.022781704357194326, 0.014031245072762814, 0.0780987874754975, 0.029784429803370472, 0.009854380492000811, 0.03438261592940938, 0.06345190265546403, 0.013688360397223265, 0.016033400541111346, 0.022000093576348117, 0.022346346165924784, 0.030068102585632476, 0.03318051672390392, 0.07724669852083729, 0.04050821283712022, 0.6309011073843126, 1.0116835166850398, 1.7050997888849628, 4.512203941422125, 6.596501440771165, 9.337570897994503, 11.777614624269548, 13.546066207270469, 20.403708757892733, 22.951674538273966, 24.124537744829734, 25.53214696145827, 28.490763325845045, 30.625642730343728, 28.74240886780524, 26.15845141872283, 25.487549612599036, 29.031985690516812, 23.821089460003762, 22.44647914363492, 17.93888153568391, 17.818721686640096, 15.03877026419486, 10.561654375445459, 9.252752584795799, 5.271965572910925, 3.270424200642494, 0.862355268289966, 0.42778098414982524, 0.10073701505579295, 0.13371249600764246, 0.0335047404552179, 0.02719483619946386, 0.014420948254184858, 0.03706895303161394, 0.036091198844294396, 0.09016291028068912, 0.012845152316825285, 0.09327947086985074, 0.0345116749315733, 0.030730320478699384, 0.028053364123127637, 0.03689181052088257, 0.0070383107090639255, 0.023576365445830652, 0.011367168570418033, 0.05461695536430325, 0.02901520857947969, 0.024312842156617873, 0.008412593442405905, 0.005675714168201892, 0.02788297084700917, 0.016476613048824574, 0.012444284361516757, 0.01782370013965955, 0.05011826490743026, 0.07652150436995492, 0.028982404694561998, 0.023891091602103367, 0.04025425085978162, 0.07721226286864089, 0.11272753979409895, 0.04672234269580053, 0.017836273557716803, 0.0894898254304163, 0.04202540783632187, 0.020128985108327002, 0.029112164667176626, 0.018608095650110516, 0.08424551691859962, 0.09145330111946791, 0.05893857991923729, 0.07819709187794117, 0.030452458473343044, 0.06667869180561074, 0.029802875285367333, 0.03761774394661188, 0.04370184570190407, 0.047868084643156304, 0.020379101324285713, 0.10393067473365415, 0.029484035236941233, 0.047582774347956144, 0.02770200172709602, 0.056251001754595395, 0.08296369094281428, 0.03568949298031869, 0.035010068752472444, 0.020763685123153755, 0.051006631955744765, 0.07433884326488742, 0.06548930965964833, 0.031010955722341617, 0.0629585956583821, 0.059035643259243625, 0.06354133192930492, 0.05512756445715505, 0.04449036085016785, 0.17786848629193922, 0.21058348968865412, 0.2135822949029746, 0.19799163955594265, 0.17872140262155764, 0.12786633350075255, 0.15094835581558366, 0.13724088248225952, 0.3103418504038165, 0.32690117796582563, 0.10877118596146185, 0.09616075053570733, 0.1881111584483616, 0.14343137852847576, 0.1428027574213282, 0.12775259242663461, 0.10887286881165159, 0.13301275129760468, 0.14053631694086138, 0.11711041307857922, 0.08863449592383639, 0.04888746038740201, 0.10996423000770231, 0.06907457816264323, 0.163384904604285, 0.13466147976296564, 0.18433858910875936, 0.12024429491570882, 0.07855421142472375, 0.17898674483501142, 0.14226831916359164, 0.16709903675702312, 0.16143537937633454, 0.13189383391891757, 0.13501150533556938, 0.15257356538166925, 0.2420509801877122, 0.15819953123648323, 0.13081104524673956, 0.18922448338520145, 0.16538948091047426, 0.11688281601715474, 0.0936562022674949, 0.2099194599976463, 0.12658274552274135, 0.2391524099174046, 0.10133143799800066, 0.19265637342487613, 0.11207474861294033, 0.1055191197402535, 0.12558726023041433, 0.13294188816460872, 0.21220025696581413, 0.1269242292149894, 0.09876294437074855, 0.14038427913140866, 0.13061598393945925, 0.14927675196480367, 0.09015664368146852, 0.11296941673443203, 0.29166949912905693, 0.2484311596039803, 0.09772274252628127, 0.14078653657868986, 0.14269449387586888, 0.22451876692714232, 0.0790676205689388, 0.1452265830049592, 0.1722282099146997, 0.16333973606026944, 0.115945331241575, 0.08735940386090549, 0.1286711471696054, 0.2339418169351355, 0.0932024866943398, 0.1560991786180004, 0.1834763571499817, 0.13947050477708542, 0.7553090058988141, 1.65087265353049, 1.8811575804025897, 4.83067637489688, 6.8003568245518595, 10.90787414581545, 13.022543538001276, 15.526103185069179, 22.364501607033517, 25.586799306254235, 26.701229003167924, 30.154283661996168, 32.8852201661756, 33.967945344986454, 34.076461638173754, 29.028312390850438, 28.88661872956061, 31.35798062047651, 26.77583052266029, 23.533120809062837, 20.653257792995824, 20.00303864479065, 17.430873801631314, 11.994760959379136, 9.798040486151173, 6.015997519416194, 3.279709431432909, 1.093378703921072, 0.5619299664132057, 0.14108564794784592, 0.24352844203672103, 0.07154905747982764, 0.17688197955008478, 0.11167195490411214, 0.16885517074936823, 0.1250210216629409, 0.1382976088432535, 0.11319560419407584, 0.1810275264565022, 0.1163450529378268, 0.17522165251355018, 0.10516789907048787, 0.22140936926007274, 0.10882740915422479, 0.07168493849495727, 0.10956740412380427, 0.15382072587888088, 0.192766705407731, 0.055184990407959114, 0.20828047617068216, 0.23724066814587963, 0.097323763935316, 0.11879327842184614, 0.18814463649065266, 0.12089962184789682, 0.16249706998707789, 0.20596480688020108, 0.1108460967999793, 0.14106625060160316, 0.24593172114222284, 0.22858690830969045, 0.24033681249185918, 0.14870074577629566, 0.15640544524836927, 0.16373007317944882, 0.16828244341717613, 0.18151979923488634, 0.19194118438228486, 0.06713489716451976, 0.224595237823744, 0.2618685563004786, 0.19585050041637114, 0.20925002172589305, 0.23724618397893446, 0.1939899639617051, 0.1702307888697232, 0.16636533903018122, 0.1479300000374356, 0.16442419480412238, 0.13951343634436209, 0.23311988120117497, 0.1597532035121995, 0.16678595194412818, 0.23026105557237903, 0.08591440115724841, 0.1543919363569829, 0.20139889220797247, 0.17742660677721425, 0.1061945105151784, 0.18307685761922793, 0.2150173920897707, 0.17205490550446897, 0.12598813871943182, 0.18440269534626316, 0.2081118755403065, 0.2560170235172395, 0.24182961142111212, 0.1271929958414647], [0.030806998219040614, 0.07892498265831702, 0.04747466018964206, 0.05480685323897389, 0.13381499857191118, 0.050690321912688595, 0.04194429827733867, 0.048993697630301605, 0.06413460190918657, 0.017981705774042397, 0.03195742479405336, 0.08163095842446051, 0.04298736146020313, 0.008833847954989442, 0.03766712214377138, 0.0598905552479048, 0.04885840267243405, 0.02555217515046318, 0.043503333168524894, 0.04783236962412635, 0.015283512503599689, 0.03639908958106272, 0.06455586982830878, 0.07701009226542327, 0.0826652767136693, 0.03306407518985291, 0.015803351998329163, 0.039601256665323055, 0.007105026433559796, 0.016914564447717804, 0.02828564772742891, 0.06797200910026027, 0.0711668562144041, 0.02614046364361721, 0.05219583024060534, 0.03417351606091665, 0.046392158800435644, 0.04623419530088863, 0.008997703628284077, 0.06187947654736139, 0.0483566265733492, 0.04927798136768322, 0.04054740206488679, 0.06134423006686473, 0.017608601802719698, 0.0539047425732978, 0.1098084153847829, 0.060557101537743886, 0.049246521967072646, 0.02411956008854172, 0.049433435929278215, 0.027421236248506654, 0.019436336287687865, 0.03981916271450539, 0.146704044853968, 0.04365665417525076, 0.025460717658842766, 0.020594010054464304, 0.012730942013853741, 0.028364631392422224, 0.04327844422791274, 0.022929229908773018, 0.03550105833358342, 0.025836232891907136, 0.08405368850235978, 0.12414709154155948, 0.0881010152760052, 0.06120428112485717, 0.059385109587662646, 0.009823918920911608, 0.002694561056071712, 0.012860993099879595, 0.05270509101871041, 0.033117789444663835, 0.012806192915436002, 0.0764571606451946, 0.1020313359256233, 0.05402186592560142, 0.015314206773895892, 0.04733548116599841, 0.08814220016281452, 0.20210266654049197, 0.27611877228463855, 0.6772024196482475, 1.2877640152169814, 2.1550509285542274, 2.98587340501047, 3.0640094703243625, 4.955946581978952, 4.91214596456097, 6.406218928675498, 6.395121072569202, 8.509362436109974, 6.731641802095599, 7.053996891744676, 7.734754143222687, 6.714345130228228, 3.7868716495652355, 3.8463999907816615, 4.367997021444382, 3.2220356358635813, 1.5491831230540432, 0.6952538413386191, 0.658672530083887, 0.025053049715596343, 0.05830970217263507, 0.031215752091919704, 0.013796941869171157, 0.0123628951804412, 0.06691790275996731, 0.0684589958719669, 0.06807292586252575, 0.05168824719505445, 0.030501198902305578, 0.001986861001745227, 0.03232776893362884, 0.060008532788243994, 0.05883432684406158, 0.022673532742285923, 0.10406038874099333, 0.06503239183896972, 0.019775653866329984, 0.03908680947197061, 0.12776684166202623, 0.0739216011378073, 0.05292975013294528, 0.005263645528635431, 0.046114888598000815, 0.03729049033755737, 0.162644388694917, 0.03819787551859214, 0.05889695070143189, 0.077807045872173, 0.028777208044043476, 0.08904920229988714, 0.01922573105642392, 0.03939073570373078, 0.022099803750132842, 0.053235151083959695, 0.053541069144322995, 0.0159103840574502, 0.0500500294560146, 0.05026926083730594, 0.02003870739210998, 0.02979405186769943, 0.07662705596416228, 0.012066458415750776, 0.07678837109837802, 0.03195468986016368, 0.0230630271647486, 0.04663663277883203, 0.051569986202183275, 0.02344708619338851, 0.00524552419759153, 0.032472505925163146, 0.028965403288302403, 0.054778324124673684, 0.07327459392047699, 0.03235853502466794, 0.03335122409607134, 0.10760842537086819, 0.04580179612422663, 0.0244876136252236, 0.018823335713316357, 0.05376932504136236, 0.05582590339585178, 0.07681667804718018, 0.033569566815370516, 0.027426865079530308, 0.048233171504351406, 0.06450007564478344, 0.02475596847943962, 0.020374795910151258, 0.08383327734566505, 0.06159472549634595, 0.03019958242563711, 0.08073692615594595, 0.07276487732005697, 0.004819387310905563, 0.02871200438558815, 0.022632650460206696, 0.035963338769731984, 0.04862104182041461, 0.05842887097969652, 0.03757383944767137, 0.0498211951625924, 0.041336591370523944, 0.10260526601585651, 0.03649575455534843, 0.07528781169845213, 0.03850907192475373, 0.03551782799824592, 0.037802252392735214, 0.035961071149476116, 0.033846748917694056, 0.03989908866764557, 0.04508978634652111, 0.007745651180870952, 0.06743755552076525, 0.06559601804662137, 0.04770911756842848, 0.04796912780992928, 0.042278370068919276, 0.029273271042432998, 0.031494213561076796, 0.05142035773925243, 0.03114782690611338, 0.02083876173973324, 0.018251468314819278, 0.06472730498400427, 0.027851674240082506, 0.07142823775328937, 0.05651039146487752, 0.02765472644128867, 0.06065969603256353, 0.04200810957099161, 0.017056516709647352, 0.07266799784115247, 0.027798184065989433, 0.06218792652831443, 0.019133729642377268, 0.06652688382253533, 0.030197510157801935, 0.049451358556266756, 0.0364630502618609, 0.013775682929272373, 0.023262359412206758, 0.04525855934667972, 0.01705224576946949, 0.00327417791272784, 0.10190466328734353, 0.045066171686255166, 0.05078201114590611, 0.018104341128961216, 0.043461830355227, 0.04357284415633448, 0.03564241687737165, 0.04501554093533947, 0.03345177313613315, 0.024599866573548606, 0.0125015274088289, 0.05857656507061855, 0.05814932932656619, 0.014339054412689182, 0.03601362861152138, 0.03606337836132415, 0.010847700628331833, 0.017138495778424606, 0.08180598653252087, 0.03892586205995852, 0.04980739025819687, 0.04095983699024205, 0.026462599785337527, 0.04609160718598193, 0.07841287586357325, 0.015309639932257275, 0.019903075355555744, 0.2510762313801435, 0.504262820487061, 1.1440218961046589, 1.9295476160703169, 2.726218628306543, 4.200581437157047, 4.906047169239291, 6.567510222235034, 6.700907090017873, 8.391748205307993, 8.78682796032198, 10.818244065007857, 9.025421815533793, 9.23136095846853, 9.786101771939187, 8.958275741146458, 6.1569567168912585, 5.850844162125742, 6.094237527539653, 4.2584932715662065, 2.5121447347825576, 1.3711528696360127, 0.9049614014164095, 0.18086200549958215, 0.029251811004454092, 0.03192714516884618, 0.022424824212888078, 0.05205936316821364, 0.04300542964389728, 0.007453654853311638, 0.09951282187455124, 0.05572854128155497, 0.05999127665774957, 0.028184949300221862, 0.014921550323525745, 0.029586895947314562, 0.036093600529937014, 0.09384974672068512, 0.09880990556050694, 0.044680182116046074, 0.02448207097909143, 0.039583923926036206, 0.042953423765157504, 0.04082397895775015, 0.060064901537712545, 0.004018880971406977, 0.006881843474994024, 0.0546576461244014, 0.06109626272753362, 0.017492160268668688, 0.03406502268908005, 0.07697766376358849, 0.014818516285759548, 0.08628258301365761, 0.032780959736555815, 0.005035390110401016, 0.016245269817450357, 0.011756887073598564, 0.0417979218576464, 0.042706984771235336, 0.03574066765366062, 0.018026253786839305, 0.05756739361752426, 0.049798216355303605, 0.016158772745139657, 0.02103209168830466, 0.01562537540937023, 0.04432825281495049, 0.012077232484795876, 0.05479589818165668, 0.02885048243878109, 0.036781424911873, 0.04411320427372571, 0.055068751887208035, 0.02091931396975152, 0.04938231105165136, 0.08875992749967883, 0.0798491221822558, 0.04403739987361816, 0.07288399633140334, 0.020876928240120895, 0.049589664239676735, 0.024750935281777096, 0.06777353870171694, 0.010955034334573054, 0.057147451030511054, 0.07323618227195355, 0.05170739173228222, 0.08699229452759029, 0.08995095673467844, 0.0476056573942544, 0.0077592961644122925, 0.0450717258237062, 0.05130649409106663, 0.003649245463161459, 0.218313945036742, 0.2554124575709143, 0.2080821819723614, 0.18636009595807523, 0.16788691222187013, 0.2560875955368242, 0.1821835990995169, 0.1896836305217397, 0.19597094475982652, 0.15713912765345267, 0.10655454885695251, 0.24418162392272105, 0.1243764659269683, 0.22711900723797662, 0.11638258358523731, 0.13624354325715574, 0.14528814583055435, 0.15752977120780176, 0.1684073770358678, 0.12720339931547642, 0.10326851429718156, 0.1627166920732106, 0.1330134714202535, 0.13299533045820652, 0.2484325232404855, 0.12207905251172282, 0.14576756365356908, 0.12542219126536963, 0.09609082969085825, 0.1430823335484151, 0.16672506327590636, 0.09006482038286426, 0.10382654806298595, 0.20422062385947476, 0.07901073087968173, 0.19760928507293427, 0.1517687900172126, 0.1358166331004712, 0.13339421711862087, 0.1146604715576095, 0.12458921620442022, 0.27792726072572893, 0.09372554854640076, 0.17586380273344057, 0.1256352556388705, 0.20852905638035268, 0.1953554697214596, 0.20659854545468287, 0.26543147801872224, 0.20261568497986565, 0.1392099889175546, 0.15934872440993786, 0.15616910712372872, 0.10857366551194461, 0.2673721932355435, 0.1263916678726673, 0.1070650851714515, 0.15379671668333394, 0.11030801962460242, 0.10431396384393016, 0.10398523551562142, 0.1870438907175295, 0.13324486061690316, 0.13938750681136886, 0.24357154214334106, 0.2000486009543942, 0.1332994367206289, 0.18029274088480782, 0.10828447498140797, 0.10207719394877073, 0.0784578069203323, 0.10888432948699883, 0.15769109400289674, 0.08215445694663832, 0.14108207797811878, 0.15873176316099782, 0.2507529575978556, 0.1707057787045356, 0.13489132146200827, 0.11628345180783542, 0.20938610958476223, 0.36911498214448657, 0.5576317228617207, 1.124242609066348, 1.9548595288107473, 3.1430910719979197, 4.1428902360700794, 5.149426316061328, 7.240728187945582, 7.480609070870185, 9.010902181748422, 9.72860178639812, 10.853091382211256, 9.379969758372154, 9.850487478317755, 10.263338511989964, 9.652572524163032, 6.574107158568598, 6.091779182034155, 6.513643822362346, 4.498798260765692, 2.824404379052501, 1.6992344971626037, 0.9473156448333495, 0.433919340251915, 0.12262351886038819, 0.1291788029935091, 0.10979687043976401, 0.23088376248075118, 0.13436269015073776, 0.15622564441254064, 0.13482713861571205, 0.11309815781010736, 0.15776402557328825, 0.13855309916600106, 0.11634444772836663, 0.16458050738419258, 0.1546157259614237, 0.13618551975777074, 0.24948333540270407, 0.21171285650662838, 0.11721935844229114, 0.21404940935392536, 0.16508650845817982, 0.13656522357656112, 0.2950017977385752, 0.07455887903849925, 0.0922550964018991, 0.1546577841884667, 0.2731001713583546, 0.10709408159938552, 0.2460458988864576, 0.1726490986202994, 0.1054541325016368, 0.15301127737808615, 0.15077301361147435, 0.146419795590543, 0.12051024999950202, 0.12305644280727833, 0.2068721307742019, 0.12846904551430097, 0.14190831912621377, 0.12635216837929142, 0.1919895858173409, 0.19010654169945948, 0.2022273090457724, 0.08580600737684196, 0.14622289567224442, 0.11451691434147859, 0.1367543247197905, 0.2274243852063533, 0.1133985868504932, 0.14050237924581574, 0.09222829864630777, 0.11824027785370428, 0.12214882779986629, 0.1159872822163086, 0.19895545477347992, 0.2229911416408516, 0.17589109078530343, 0.2239189354041892, 0.16155773893960063, 0.13961256812176398, 0.12407641226966536, 0.16645641156261967, 0.17024270919782503, 0.11390919977378462, 0.18330250115644547, 0.20171527119894184, 0.1658287710480152, 0.24177249190547775, 0.20524097636582392, 0.0992334908956001, 0.16409365850831234, 0.1910588196328571, 0.10655379809078672], [0.03527999600215304, 0.05302718885603452, 0.02749259159299395, 0.018765212622501196, 0.019624692410410895, 0.016463457403944868, 0.0550506875339535, 0.03317098275968625, 0.03932127834207589, 0.022389260496223168, 0.04572867686229368, 0.04181507073583142, 0.014273241714334056, 0.05096765340215737, 0.022999470595330484, 0.012913855081874759, 0.007848242324055925, 0.02626200732324393, 0.04455657382946342, 0.019226234759234132, 0.02738969449344422, 0.007082590591087337, 0.03175808105527634, 0.05824897055243773, 0.04079566051762912, 0.004354141635685078, 0.04708409324408539, 0.09223426647123792, 0.007853502954070968, 0.027698638601108428, 0.09973875652518004, 0.026170187855079293, 0.03876887532251497, 0.06898896783710488, 0.04920654749918369, 0.07885785037351233, 0.017374131017394604, 0.03221102862528736, 0.017751827685823365, 0.03948784500901257, 0.01665422478840957, 0.04509547071891927, 0.015321011549883313, 0.0656465492061069, 0.00523559665570276, 0.11670257851120927, 0.06434250668051743, 0.02498702251262242, 0.08739773890063648, 0.019778386884999853, 0.0521114724688232, 0.07273561276134945, 0.05410335852854675, 0.06984264259376834, 0.0511427657798894, 0.0897178898054746, 0.067120012076151, 0.02585494458945769, 0.061923373385422656, 0.0305965768488785, 0.03815211708687487, 0.12180194318775209, 0.02285418202049069, 0.052602293510590835, 0.026805799514535936, 0.054409161675721414, 0.032973650001710465, 0.03541822124633097, 0.041762130229824015, 0.05701502124148031, 0.034767590433118806, 0.08277585384465995, 0.037234110096769954, 0.027115381390397108, 0.04792698148277499, 0.05699606056535437, 0.011964404970527658, 0.05102050580805348, 0.010667790624973996, 0.047393439547909845, 0.08212534560551567, 0.022111557454111117, 0.05391781203328602, 0.03651078903086243, 0.05546204227533552, 0.011043907237058927, 0.1316769084622783, 0.03103136621986426, 0.34679467339188824, 0.14504192517169062, 0.46248078346252447, 0.5421761747810149, 0.7331723130999074, 0.6441246429758688, 0.41172166685423545, 0.7782342789634582, 0.48661239985977456, 0.8675530829256581, 0.6776023175447219, 0.2305244059572297, 0.20073244167912394, 0.1355600242893542, 0.0589857594440541, 0.03457453627620013, 0.013038922765953167, 0.06397385751047442, 0.03784221153886568, 0.017912637202009078, 0.07421474468203322, 0.015172521685129933, 0.05314096823454865, 0.04163627730562322, 0.032932771550070856, 0.027881099677254117, 0.014531240975033614, 0.03023674535084396, 0.07386866446223951, 0.016793949649699273, 0.048725536213286465, 0.062071906342621774, 0.030683539319603197, 0.03694615679823103, 0.005067995291263346, 0.038026559106524915, 0.012804980581295828, 0.041562744356211156, 0.06696245843364347, 0.01058561428855624, 0.03165557466056799, 0.0405863308227591, 0.06622868409800915, 0.02463590334950676, 0.07554612122476101, 0.027854194669353387, 0.041366863334851886, 0.026998524253647176, 0.04226370714604855, 0.03121147732130222, 0.04273200520284234, 0.02752894629544068, 0.02428221396140514, 0.08050510795005868, 0.017479724746437806, 0.010655786027200522, 0.03421666979369137, 0.03257655598703892, 0.03559143755645041, 0.03570062423785848, 0.028210333623592893, 0.054563164500699896, 0.07518683364915271, 0.0737317109240159, 0.003933444212663979, 0.05180885624741355, 0.03404528060327134, 0.02318156586449233, 0.012134840381481956, 0.11906880194381361, 0.013258017209028045, 0.04048680834051582, 0.02696168308536853, 0.04389428698848333, 0.023123839224177985, 0.07604376427949437, 0.035453656643268563, 0.03277956545653363, 0.023841983450937177, 0.01700480768997823, 0.04398439425013719, 0.08779647234346598, 0.025035360745424708, 0.1121688854970759, 0.01350303894029029, 0.01246980658071416, 0.0314030452676478, 0.030179784798453894, 0.04904896321315919, 0.010493958571685419, 0.08030063908306823, 0.041303327832851684, 0.043598757080373265, 0.06316370037834972, 0.030505314709678776, 0.039467501544183305, 0.07045326829557458, 0.006518114504644708, 0.0768898624265867, 0.03272719185559019, 0.05137835696880376, 0.018626238527377287, 0.03349367431515167, 0.018794655296651107, 0.016101369776973323, 0.03181318192923021, 0.027623500697494998, 0.0700051604860252, 0.0229371914775261, 0.007748374144636816, 0.03592644780573826, 0.02946903715060363, 0.030416490645298076, 0.09009760128514421, 0.04609072618486901, 0.08426545818726863, 0.024041375070209467, 0.01430705396248208, 0.03779529248394313, 0.04428162870387878, 0.013135676797960075, 0.03671835672350661, 0.022248593346786597, 0.00803406173813968, 0.02260671646874999, 0.021384208680941694, 0.010715959360823037, 0.09002627083851446, 0.06729251209406123, 0.04122306480102482, 0.023573910134033333, 0.05418907993683412, 0.014101858269573461, 0.013658828665352157, 0.06068397335888398, 0.03913420733184584, 0.04878787278768517, 0.03924602552527382, 0.005342524335344112, 0.007455374241896695, 0.01143063703972486, 0.09129652122576391, 0.044552111367304484, 0.033042701336765484, 0.035090791437053875, 0.028045741548281045, 0.08761306323351399, 0.036396626608386155, 0.02892553798794266, 0.09594449923644144, 0.03726624748519352, 0.03913068715783377, 0.0892768836309833, 0.03329524605144416, 0.012854933344398536, 0.062093467887250654, 0.03674193690981596, 0.04551181652312798, 0.004580271159929614, 0.052014225267715035, 0.061666255125836025, 0.03317230426135563, 0.06854752499249674, 0.08527435001827056, 0.014416932995851724, 0.06695744055773943, 0.01525355272010089, 0.041309073492283785, 0.1022039355349637, 0.04263079732716565, 0.019523551567427574, 0.059202259721895384, 0.06048879713841504, 0.029445230968356616, 0.2528948168600759, 0.22732303177397098, 0.3423106994840407, 0.20466464842038773, 0.9300932528511171, 0.7357250406376777, 1.2563135931568763, 0.8497396387880849, 0.778450622193275, 1.147817402116714, 0.8947631776813538, 1.173031991047244, 0.7162741295272305, 0.3461265221478478, 0.3601090363677471, 0.20793146183413846, 0.035189609118406816, 0.0770449952312535, 0.004612395620619458, 0.010374732308029648, 0.02499076293691272, 0.017873719935455633, 0.012350456785380602, 0.0544573026408832, 0.022130611976007783, 0.06169898623240091, 0.01315353909552458, 0.05006694850782233, 0.05748701567250875, 0.0634620265073834, 0.053854479544585755, 0.051572560257608854, 0.090541020636597, 0.013168207764054739, 0.07366110060003496, 0.00869226437287345, 0.03620460283972564, 0.04501630702326375, 0.06310478438653293, 0.12511505895564634, 0.07328100607640321, 0.05754633769092541, 0.05392620452649651, 0.08046569272635445, 0.08539721519956667, 0.0325113350916053, 0.019227108099467812, 0.04328001470815751, 0.021598378136273355, 0.005027071831958188, 0.031797699292280504, 0.03153393330473093, 0.031024685933164535, 0.05095298664884702, 0.04637528571390337, 0.016305928659294883, 0.048312358182644656, 0.09434278558699355, 0.022582829847270926, 0.00929142365367302, 0.06384249641409805, 0.05589864344426221, 0.05251434278644381, 0.10291278136954193, 0.0693215036223973, 0.03596105582771763, 0.06735879402126997, 0.04081267916086701, 0.03749464510849888, 0.05150110340647159, 0.034421728548383525, 0.08134725308346172, 0.07738220415288403, 0.012748616619876797, 0.03433632889702436, 0.007655996389897361, 0.05296860994290441, 0.07778632319382123, 0.04243679705166048, 0.02369432957963117, 0.0140660886667789, 0.05656597880466331, 0.060582110478032025, 0.08763842840468691, 0.010500171544751333, 0.05670856691957001, 0.05710704372294488, 0.04760130601484449, 0.058085207767303915, 0.05034368627914979, 0.16879123305120777, 0.14565773728874423, 0.13478169428004375, 0.17214997701587217, 0.12817761800702543, 0.11497821418508408, 0.1433153008861888, 0.22528917558731573, 0.13712105100914357, 0.11607740479972094, 0.1664025402597843, 0.1428791823526544, 0.15427835616132907, 0.1386923126636013, 0.09246767814000768, 0.1472887997665713, 0.16085341302377565, 0.2810312651338116, 0.12391941787134256, 0.21155960827825532, 0.0916607117640876, 0.11306760622368706, 0.11863136573904946, 0.11311459805696242, 0.053136061441393635, 0.16728297446764287, 0.1081731394233723, 0.2131395880132914, 0.12150064846801183, 0.20484313158498657, 0.2243594053171335, 0.14964484189066196, 0.2214268513865048, 0.10644711268645142, 0.08412233764125455, 0.16649345957463788, 0.15342499550071456, 0.10393105011673705, 0.159564194299521, 0.1250924670227593, 0.14007116367499675, 0.1392456273277921, 0.14877522484429423, 0.15718873950742906, 0.1078544085424754, 0.27528888455802397, 0.13644827259404047, 0.10948356346137102, 0.12661325880476546, 0.11269200863617082, 0.06915202965178797, 0.1184002829775695, 0.16001206462181386, 0.1700956662816386, 0.15182157347519554, 0.1979889276046907, 0.12479155534698118, 0.09521033419596572, 0.13144083080753205, 0.134103185527267, 0.08163799877248465, 0.30431497541646807, 0.09109447319661418, 0.12256994633184326, 0.1460259651104289, 0.2026077483089701, 0.09916135605664984, 0.16023533328646616, 0.15795013897361296, 0.09790040597680116, 0.1716121526495103, 0.18852038729575374, 0.1596320084025783, 0.13636518269777298, 0.165018173415334, 0.19410248695602342, 0.0793154270298058, 0.1716383528565207, 0.11202119140615387, 0.1309224650744469, 0.27222986483285505, 0.07565625402475558, 0.12040630718993565, 0.13435663805613596, 0.15394049606496288, 0.1512052404183534, 0.32749710244036495, 0.5100193583676892, 0.699893024659926, 0.46878354203316475, 0.8667021124593673, 0.8451384534278225, 1.4991976633187265, 1.0344273188421804, 0.8708875878683983, 1.5012459985671507, 1.2264855614592953, 1.3131189514552395, 0.8352665831485103, 0.4671693028461549, 0.547969209090356, 0.22663978859782222, 0.12079048496220382, 0.15567168623449343, 0.08743623481883157, 0.14859661910562746, 0.12381032695092502, 0.10472991894329749, 0.1375799989628215, 0.09934743881345758, 0.10527823105334275, 0.1749876126526825, 0.12578175463263067, 0.17867306247353557, 0.11823289276611422, 0.14620185889784368, 0.0989791726873767, 0.10844234271996445, 0.16052900543135984, 0.23120490653860956, 0.2089335201608558, 0.19168276760366657, 0.07840500047971165, 0.2493242342625895, 0.2036919465829288, 0.24402077610213913, 0.16699590600065647, 0.13200863985525024, 0.16711596730014971, 0.13888794087594555, 0.20216170127593702, 0.10519589958412033, 0.13904849758311627, 0.07644941549628012, 0.14936633828666904, 0.06677610754606224, 0.1171364141027293, 0.11464363294503382, 0.07998386172637825, 0.16222996577139825, 0.09952906293854599, 0.17489555952770097, 0.10960835918423631, 0.09935561297160965, 0.13317398216214874, 0.2003619462371834, 0.18955080619742795, 0.0883157267385433, 0.11625079347962335, 0.316079052225236, 0.17299363900336528, 0.18215670941337464, 0.11929045416294567, 0.12717152239694712, 0.11576147013974768, 0.1382122360049717, 0.07119635826036816, 0.2660240010628777, 0.1345264337836735, 0.10658163006507582, 0.20539604788345678, 0.12821152505855407, 0.10373827175147111, 0.31523457818454315, 0.1052135042846203, 0.10822141828436045, 0.13810337491093144, 0.19419106204182873, 0.13862595412760012, 0.19057094419915832, 0.0659144195097108, 0.1512700821002645, 0.12368752305666286, 0.1955383808742608, 0.13854896229120994, 0.13192409439192665], [0.05285700625409523, 0.014630961682527296, 0.02608190388268521, 0.045291516449182265, 0.029165748687040423, 0.009736658633506347, 0.07456539844673488, 0.05331043071383911, 0.007323339945756861, 0.004257991376723494, 0.033719731539848356, 0.07975420388843744, 0.028989165420493776, 0.04985615175457732, 0.03803655655393678, 0.021874575815614195, 0.08648801715143266, 0.0328695118397234, 0.07288408826195425, 0.0401496913494362, 0.006483164615929128, 0.03886247594510356, 0.028194904612797885, 0.02941528076095687, 0.05316856655202085, 0.10114894053267856, 0.02435412471963754, 0.029200778057378148, 0.013623896013614873, 0.021733989105409673, 0.0028974812284427425, 0.03836027083678111, 0.050858114320304126, 0.06061055532266056, 0.0016662794200050074, 0.06252058871811436, 0.03860785513215008, 0.01012593184808089, 0.006494742119684816, 0.07703653762056943, 0.03831483033155242, 0.07076020908331679, 0.10325022011754975, 0.014112656278866193, 0.07208079144719147, 0.014296537490501521, 0.03766629476881316, 0.015998080057362397, 0.056731986227415265, 0.017523788208622607, 0.054054148870730595, 0.08024708953716102, 0.02361859221221699, 0.010296747430167612, 0.023416507793890855, 0.09239647026744582, 0.030021629776925813, 0.00929250288003635, 0.03421458603453732, 0.0167802807259103, 0.018787113161036567, 0.044997085877243555, 0.05182846043739588, 0.04141675864136027, 0.03110189610461314, 0.04813542251565284, 0.08606180413475922, 0.04189453703621703, 0.04073399810060378, 0.02343304954739588, 0.04766998579725624, 0.025697366049092625, 0.06100978672264084, 0.05807768095344786, 0.05240113414343327, 0.06507625037263479, 0.08051928057665787, 0.029132726467064315, 0.03984283483136566, 0.04583260051966195, 0.04801639160441776, 0.07793792433315709, 0.008101347240529234, 0.08157383124794691, 0.007629751175221417, 0.08024725041562512, 0.03989743008728951, 0.026581607713934877, 0.014397755899887173, 0.04633515802842956, 0.03641490929669911, 0.026532848132774237, 0.02106374261089631, 0.03431583987548947, 0.043286258324740395, 0.06241127180175916, 0.05989895923243416, 0.009494200423960725, 0.02476831781677902, 0.023840039502829317, 0.03829170213711839, 0.04615872797946777, 0.04543890793537421, 0.06712830880837095, 0.014529178283297488, 0.06513482545532527, 0.02898904859208532, 0.024520375375305454, 0.04611408420568032, 0.05303830479181582, 0.05388413480813465, 0.056817202017672604, 0.08674546099838712, 0.03426926939057247, 0.0909226626578358, 0.04661516699519369, 0.025947698684889945, 0.08629133939863214, 0.05868118969843753, 0.07538387146327766, 0.039849384883118254, 0.027897403943502617, 0.0683357553075879, 0.03557748326490964, 0.044305178246671156, 0.03631594605864056, 0.038580000175223235, 0.09315800762945607, 0.05289134997574072, 0.03534342808228347, 0.0257168514954467, 0.07198199674847626, 0.03937138432276346, 0.014771585739518126, 0.07935863438873522, 0.03312722381745135, 0.017131279230177883, 0.06736518319455848, 0.04593900247146526, 0.08118317237183933, 0.08497797358300417, 0.015869210661959746, 0.09511290313375574, 0.027306384346898527, 0.038911172324010444, 0.04278122252153774, 0.02580089517117989, 0.021443873523704467, 0.057699965132820996, 0.02116030033287262, 0.0166328432744429, 0.03515259941078482, 0.036660520915663054, 0.041445877643362175, 0.0019324198013149023, 0.03143566529146366, 0.05969292754607816, 0.027109547630853714, 0.03958645201618633, 0.08181440583880871, 0.011751696827911563, 0.05300227184629729, 0.04275197711502833, 0.02335251646957571, 0.023743782470363285, 0.03009081326214777, 0.007551753848430611, 0.012919540411882825, 0.09184628124198607, 0.03913359063106679, 0.061322756622347145, 0.018633219503587293, 0.05093781044706703, 0.056413140433329734, 0.08539271060257189, 0.07224105704095095, 0.01795041108233554, 0.030121171411367196, 0.04412633502074788, 0.02609720265853309, 0.04420263737800621, 0.06168359552600211, 0.05955405495760422, 0.04414788507405789, 0.05312019959092141, 0.005279437473584568, 0.02442721908371295, 0.024289932297242266, 0.012188365029531622, 0.01860969485865245, 0.015022057228751723, 0.06158958887681366, 0.07097556405971128, 0.027037261489538417, 0.01016784547602818, 0.03633262379275214, 0.06131930156580864, 0.03798676849973779, 0.04622139397167391, 0.03740017880655585, 0.023384134833430572, 0.04796546974009083, 0.0486261937617054, 0.0714298005726549, 0.06794970828078448, 0.0545859134816114, 0.042977632143564766, 0.011397702919860041, 0.024533023486935326, 0.09031362275803283, 0.01004963044843246, 0.08597330565774634, 0.03701233147313038, 0.03110419245316617, 0.025409891555506377, 0.025640800031983567, 0.051594899381480874, 0.030559178351634936, 0.06203430291685847, 0.02810666277523964, 0.032842281244454846, 0.03920079952466392, 0.03046036641594143, 0.05955812671492177, 0.02498022731273405, 0.03998509735890454, 0.0487475382584718, 0.02695784306964807, 0.026986263016419067, 0.02899474637102216, 0.02547911142990474, 0.020345217255394787, 0.020201889865641153, 0.04342627238422152, 0.056542479057586005, 0.03040527703330642, 0.0279205417140357, 0.0676202062036722, 0.011075104252555439, 0.044260339120463024, 0.07064444553707877, 0.0576510350970972, 0.03412506866058515, 0.017100549528315183, 0.023693368139286197, 0.022395065527469404, 0.03800058106501256, 0.010026093354568848, 0.021688397297815933, 0.01777612416434192, 0.0872432342880676, 0.029522579035631595, 0.05590502878711109, 0.005953412901069368, 0.02490287349979964, 0.049557729864553104, 0.02177847391595283, 0.037922819310258475, 0.03369403312042837, 0.024896545613545085, 0.03214442877159004, 0.0389142060321906, 0.009725135713515264, 0.05292939390206049, 0.056829896094577934, 0.05792282010999419, 0.027600060322231827, 0.046279643466996576, 0.03582848048198127, 0.033696262436288024, 0.03238652021654191, 0.06758290538263899, 0.021318468760939378, 0.06453055828329056, 0.04954636111975678, 0.06346131787605344, 0.07194197631531185, 0.04454393720915241, 0.033628999916536194, 0.06140962333208131, 0.06257850496518998, 0.046792194592736425, 0.04405842898713966, 0.03501543902882165, 0.04412606305953476, 0.06895389633193132, 0.016496144460454103, 0.07154305901138053, 0.011890616339270868, 0.033226631386505986, 0.01650121021685341, 0.01969736159568833, 0.015892762119971936, 0.05272818090874822, 0.042994340521193324, 0.0047527314370287765, 0.041199672306256915, 0.029854469391847813, 0.033208551711492965, 0.04997474982613518, 0.03324752643464073, 0.01530256606788645, 0.036596269121453646, 0.07507526826473974, 0.043870189692825086, 0.033152975863026034, 0.022808268455968752, 0.056363551561991056, 0.015446058166543803, 0.02244067265682163, 0.06463967218634582, 0.04017479222027525, 0.03998298295623353, 0.05758178074874225, 0.04006125798989688, 0.08871720277614172, 0.04229493288984222, 0.051394245632353334, 0.04672825306413635, 0.13334996788011444, 0.086802281739731, 0.020545993578590212, 0.07104710901095983, 0.0526600067443665, 0.04542045670771792, 0.042993379080848354, 0.0799917294493606, 0.03790475495700394, 0.03339089212879058, 0.03532012751806648, 0.02794226030668905, 0.06749570925509737, 0.007805680394202712, 0.01989593924654107, 0.09013818096249335, 0.04114347975701094, 0.029144033924826694, 0.0338878840087883, 0.04409287613065493, 0.05050811556077773, 0.04774445720437554, 0.04898123337977356, 0.06552173050060388, 0.04984307463370985, 0.047952473058455417, 0.029443821366575938, 0.031642118326178005, 0.021179059910918438, 0.010709677439843936, 0.07885820277395748, 0.06085031786032262, 0.05589289778483011, 0.1717457737052633, 0.14730298771492897, 0.1967562002039725, 0.2628937964477847, 0.15624249834687481, 0.17747906847826897, 0.15611243193909047, 0.14602247174949418, 0.09024026983928296, 0.12176302592119864, 0.22055534976384333, 0.2485981054844395, 0.1476176966342234, 0.18097530990358324, 0.14651341153489006, 0.13157760814553307, 0.14586402944499446, 0.18185750611366766, 0.22727429326022827, 0.07058805380497249, 0.1624960740727763, 0.13932353846969145, 0.09830808732658626, 0.10622147681011308, 0.19724727788519478, 0.22980023836416585, 0.17770403785811317, 0.17193194839262194, 0.20188410165569476, 0.13491873208793903, 0.13195752646894227, 0.07142834500559876, 0.18330602516089717, 0.13178619856555618, 0.09298078850993226, 0.1624133518987125, 0.16300955216490454, 0.122530308942641, 0.06402301354213588, 0.14736560774185967, 0.17310259202795644, 0.17334248480056563, 0.22563507960688686, 0.1301747172950737, 0.12894151491984246, 0.09886365428927446, 0.10830017212297648, 0.1282398626508732, 0.1700179543225996, 0.14622245134124834, 0.2151840468568187, 0.138343405579367, 0.1983746681963244, 0.09835065117165928, 0.08566379847545778, 0.18682037690474143, 0.09000377083617835, 0.16516679447264443, 0.12303108529698466, 0.16482775460087484, 0.0957253061595463, 0.22401604470947098, 0.08121282763538823, 0.14282187897591822, 0.1484457151063027, 0.22212314870088334, 0.15799155368679957, 0.13620297124068584, 0.08773114802616258, 0.19065728230822473, 0.24824976530526918, 0.14265701685461307, 0.15897801446337856, 0.13122934457515517, 0.1826236400032236, 0.31991160624930937, 0.14913016870137186, 0.09674404988125448, 0.17573079454802698, 0.14037493285873245, 0.19278280857589938, 0.17318156037119128, 0.11219255761393618, 0.1478579111637608, 0.10650207949501854, 0.15649637988498136, 0.14807793161561414, 0.15440843789087189, 0.120122448631352, 0.12418871309848563, 0.10913549141297418, 0.13533649515480767, 0.17595017148602396, 0.13455534594193583, 0.1448827780663006, 0.10009706350824527, 0.1477627017565312, 0.20617983243878812, 0.08061213809395991, 0.18169947749664708, 0.12169249220601014, 0.0934564141977218, 0.1915382680993888, 0.14862163953723448, 0.19894286028800473, 0.10103162182795425, 0.09594945582531153, 0.08398606592128355, 0.10001141487831071, 0.15450874944367718, 0.11477913857708055, 0.14620499985833324, 0.23550367102988307, 0.08714845389007561, 0.16246651840065757, 0.2129532601083479, 0.12523148133749926, 0.09622458098155838, 0.13768182736971687, 0.1319936704972098, 0.12700442329890307, 0.11438487142684961, 0.1723345735621068, 0.17656639729055668, 0.1349774297446974, 0.13463212327370722, 0.183396163066068, 0.19075109743543212, 0.11350162567630892, 0.09632083992924421, 0.08768135231108436, 0.152098422329272, 0.14402382496383884, 0.09309784674476232, 0.1742619128837701, 0.08779860972877472, 0.11145610197056686, 0.2247590733872306, 0.16419124278810718, 0.16053141094744205, 0.2325290435504529, 0.14531604675275667, 0.15933142614460763, 0.1774909888063708, 0.17927407377189208, 0.16430324484263698, 0.17444061055298776, 0.17445086080941463, 0.15085415764441415, 0.11231366845388567, 0.18545280270759137, 0.2514173703328256, 0.1754995279254452, 0.22157686672383742, 0.11099959783736738, 0.10305386412167743, 0.13641674041507706, 0.11412934279970585, 0.22938734761649565, 0.10299757964188054, 0.15715247290509363, 0.1783352943077203, 0.14341156749475387, 0.19712824314352007, 0.22043706578833444, 0.11614764740149822, 0.13872534637489628, 0.13308007510439043, 0.09681885070618122, 0.11771416697170466, 0.20141249792950772, 0.09637425157932505, 0.1533016706666639, 0.20996075213676502, 0.17043881238468234, 0.18746355368245035], [0.035212492164705074, 0.031910860054795785, 0.020740112597723643, 0.02232724376353285, 0.02241505276141388, 0.02670035134219835, 0.03179443384250326, 0.03641192155379442, 0.06590983064304437, 0.02126878795904979, 0.028899875957699075, 0.015419036330234621, 0.05349845933397451, 0.01053482553200616, 0.02715436185920431, 0.07520398635777735, 0.03974762159369646, 0.029533775410644954, 0.07870807252343624, 0.01976600307370386, 0.06160308351559986, 0.01750861200684261, 0.053746384538469784, 0.041591518618647134, 0.03465952224008018, 0.026898484662055012, 0.05349635642262236, 0.04832776804124156, 0.047209930846527706, 0.006630361707310283, 0.04695634042183238, 0.11008478926434634, 0.008314131034327852, 0.1325472149877779, 0.021989450699860053, 0.012706047029144341, 0.08968022892311697, 0.02867966206864484, 0.009524003159435046, 0.06896340348307164, 0.08569121676226778, 0.1279146659878954, 0.03454481589517767, 0.02920168395634861, 0.053847159574469255, 0.026847038027499954, 0.051893348084582444, 0.018111684081715443, 0.03055419303446768, 0.05331957014277578, 0.03321414032290059, 0.015419468212301935, 0.049040743089731664, 0.03963907842614478, 0.03332705785249991, 0.023231420951384692, 0.0455744595326964, 0.02406301513885058, 0.01915952382278779, 0.01167772529316285, 0.01654235679926651, 0.021335519962914048, 0.06653055338369263, 0.03818557980740744, 0.05660798723599123, 0.04401277780773179, 0.07529591690869102, 0.04649724691144882, 0.03962356897611772, 0.049670976811959866, 0.013143179671568497, 0.07357097801662262, 0.0248596086842759, 0.021699271915901094, 0.045603103560185244, 0.052238198733257676, 0.053893760702903235, 0.03949201252732066, 0.0858359537538021, 0.04824821364074465, 0.05459218774171126, 0.027745404438446128, 0.011781089706346394, 0.0946816799020575, 0.0370662066064054, 0.009235261747944019, 0.039272398102067174, 0.06201461062676484, 0.0012194039347025777, 0.06614951657191401, 0.06611878112439187, 0.05877090625525002, 0.08426031773729671, 0.021487942731548703, 0.056558099590362086, 0.06833248411215122, 0.16888664164129766, 0.043720519095058405, 0.07130903447227133, 0.02490297500644961, 0.04186019714501116, 0.04668965372407148, 0.13879161298034653, 0.0656935487002615, 0.03904687713891749, 0.033748632206791834, 0.016534224775950276, 0.025671987471381025, 0.02520444401119265, 0.05400265627090008, 0.08850668181454943, 0.006361987222091205, 0.031087127844652826, 0.01842273301595161, 0.03227900743724839, 0.056334754316917354, 0.05197515861401635, 0.017291142627777114, 0.1320661730583637, 0.026393565687260805, 0.033609169730616194, 0.030073162596372348, 0.012520553202428406, 0.05217308125969383, 0.027608094669337717, 0.044621725776983846, 0.027779529825033202, 0.029136493704431964, 0.0638622270085879, 0.056572984678730856, 0.07479792911439173, 0.018821518169716, 0.09278353619118852, 0.01822974780694612, 0.08870511390869656, 0.03560050803747389, 0.022910324774021586, 0.021416522269587845, 0.02824203817233924, 0.0026374884633227225, 0.04544868704772765, 0.07899353986666088, 0.032027518008685404, 0.006205479289600325, 0.033438531306361964, 0.027949185741524545, 0.02554168740677978, 0.02436320094632045, 0.08365939070861186, 0.028504645451903347, 0.026135152739082134, 0.02888809544064345, 0.06311149531674963, 0.05744533282854865, 0.01602968597228849, 0.0757014685340466, 0.04156541034218766, 0.022116755360677358, 0.06359140726647551, 0.06750094163562022, 0.16650991514325145, 0.030273808684620648, 0.01936304274075214, 0.04057280171001631, 0.0412987849314607, 0.011630022913337716, 0.03451554367559091, 0.05865052319882859, 0.053820059214147835, 0.025523046572362224, 0.034029234891697284, 0.01808469288892323, 0.0663231733825899, 0.048182590549150785, 0.046782587850165945, 0.06728222353323814, 0.02433041812882068, 0.06143776174154013, 0.023994094038742687, 0.08001183925737297, 0.011497296265236313, 0.04355753771960736, 0.03151811167387472, 0.016342834945047097, 0.08083379797397122, 0.02909474191255868, 0.045029920405678214, 0.02084862129131873, 0.023780192714184526, 0.06181570738854428, 0.022470381546525225, 0.016162086075412172, 0.05485337775861544, 0.01844618871297327, 0.09985019933552512, 0.0913967255262598, 0.016384328182245937, 0.022730320924893025, 0.07473017629836837, 0.03454258657931801, 0.023673122350667274, 0.019335277799156406, 0.030792714509692405, 0.017911290802482157, 0.039145491806970495, 0.03321968296903276, 0.009293941210114188, 0.03566781652250117, 0.03461340757747812, 0.046239136568000244, 0.0404047450020669, 0.016513270356001395, 0.02338426315315789, 0.027692737808871656, 0.043390476925959515, 0.007277702172887662, 0.04683752018477648, 0.0940773591038681, 0.05462613692807575, 0.07093460899927924, 0.08905676358769979, 0.05804298866179682, 0.027734085489364884, 0.015324796024229259, 0.0295714037342658, 0.07218868727044714, 0.024387734912095532, 0.03250489995304135, 0.045868376825725844, 0.07615729850987274, 0.025070926377309427, 0.06830236919584774, 0.03747034862998032, 0.03295034560705385, 0.06052276547697764, 0.07578833524378077, 0.023089422724179687, 0.06196927354340592, 0.03387224432381411, 0.02758494540748577, 0.054174271457257776, 0.012938614085977598, 0.02783644824258743, 0.009255930800141107, 0.04442280338656518, 0.08878453424380672, 0.02287223488242636, 0.10070196653325712, 0.04367288374792665, 0.016768438921820734, 0.020298836377239036, 0.014368776708931453, 0.03156699382910325, 0.006371649984841145, 0.03510655369609594, 0.03311303586909368, 0.011786480092503613, 0.035773054020659584, 0.04820402568927215, 0.025007670497401588, 0.021976603405369867, 0.02599999184660133, 0.03977466066698394, 0.04926654367497371, 0.055809976427905986, 0.03634947772708632, 0.010957392927769934, 0.035768319597287525, 0.04234296277225499, 0.03402230179598255, 0.06481205729106743, 0.02988073088589215, 0.08490606090955197, 0.06940811752311646, 0.029933242382661953, 0.013018997776652537, 0.03842185664501402, 0.07473108028211901, 0.13860055065203097, 0.019922194994925972, 0.07854482684765132, 0.011863544707246607, 0.05034259460385769, 0.03392312788374482, 0.035757556061951384, 0.036857531916710644, 0.013195322488524742, 0.06825899329757498, 0.04094810818412131, 0.015591860020292864, 0.021372173439651247, 0.02030199074426726, 0.08485106345746787, 0.10894541733808095, 0.028318717827900287, 0.03382751244991537, 0.07239130220466083, 0.029866186706649683, 0.030664389036715995, 0.05439461366603932, 0.0830857364100314, 0.0601151837186227, 0.012959537862409509, 0.049603028643515804, 0.03351889009917936, 0.0552038170186983, 0.02784428532205282, 0.04595257371904389, 0.058559335753201484, 0.03692785878815959, 0.015413541564597719, 0.0949106942261419, 0.009571604032610214, 0.03278107848018408, 0.03563834128961448, 0.08237929609153541, 0.020552497665067355, 0.09416318393402523, 0.012412922637116526, 0.010023303836914561, 0.008988521106901669, 0.04656859267983706, 0.039239762756492824, 0.02209629889787926, 0.016607351698762467, 0.020440032127343362, 0.04634699025642007, 0.061670388170187516, 0.04930607381186659, 0.05750403431574664, 0.05575654562562705, 0.11409338263254012, 0.05089132040138206, 0.015630795481434513, 0.06492435045900845, 0.03256160195075697, 0.09861719614315419, 0.022313046239076123, 0.031951372699451544, 0.06333047771946558, 0.021286919344997695, 0.045559628070482326, 0.06171027070752556, 0.020862520041484988, 0.11480712376895452, 0.020145574742327296, 0.050194291473035856, 0.01451612989072718, 0.06320790748202032, 0.0418427724751734, 0.07346434623844202, 0.048235596172631755, 0.18050968166320555, 0.1338475573086931, 0.19604255865898826, 0.19548280885623348, 0.10457787347296554, 0.08248820315085112, 0.10455887449244339, 0.08986929176195015, 0.1678952625802448, 0.10406101693309124, 0.14602449422161426, 0.11270643407178503, 0.17340816917919344, 0.12344166245912352, 0.07975955118214892, 0.0902433724953763, 0.2114632803826563, 0.1610839595237086, 0.15132825881723436, 0.13520990678619954, 0.09404575797699152, 0.1685214322060347, 0.28070947756209685, 0.14399952465488067, 0.15535993441458673, 0.1445554899832895, 0.11300062715646722, 0.1342349986155187, 0.14954327395366085, 0.11260526450050455, 0.1297191248065041, 0.1579807671688257, 0.19913432098204092, 0.1743714634569422, 0.10733788908128777, 0.1289119745694822, 0.2028351844919305, 0.09457519368058252, 0.08883046121486733, 0.15285029166167782, 0.1683270910214032, 0.17378421109770575, 0.09820810519158842, 0.09143777251724275, 0.27953947744061874, 0.14617421844553563, 0.15254393310075806, 0.21411763714446178, 0.11635209328585094, 0.339752946409487, 0.11147412801942519, 0.2611841027054095, 0.14638522970339946, 0.18063216380053954, 0.10630974546074869, 0.18336824682210723, 0.09528446852439836, 0.08538388526968418, 0.2506167318431601, 0.1960860724530874, 0.15344152767812053, 0.20685270278444215, 0.14866020440334274, 0.15914848434828943, 0.1886075374580199, 0.14747295198180985, 0.14486495886118184, 0.13081712798485834, 0.17555422660323883, 0.18738634734144136, 0.1464518333875364, 0.2200431740211864, 0.1759322297068373, 0.0892653769903606, 0.1378993044096616, 0.1134419167834905, 0.14996192568252165, 0.10300332530131263, 0.1575622226922743, 0.16275766245540113, 0.11774745349201465, 0.12796798570742532, 0.1895830278555232, 0.18540034100653666, 0.18686870173100503, 0.10470196439494049, 0.20375289653818454, 0.16598647790810755, 0.17112450704218882, 0.1120425116330866, 0.21019272356023713, 0.18035431903216148, 0.1774341297606307, 0.07795894578579934, 0.1274507154800719, 0.21307771875252648, 0.3654417744086635, 0.16737222371082153, 0.10621363206976846, 0.1951029977851337, 0.14603325826746805, 0.09660947121559613, 0.27693171414636797, 0.18219361952956648, 0.10096521732667763, 0.14189201677518506, 0.09171706519179768, 0.14761781920829128, 0.16311875033763149, 0.15035856004443862, 0.13734326247246037, 0.19116395753958534, 0.11957168503994904, 0.13549686800087654, 0.13252887484287063, 0.10638914281322111, 0.12732206633494747, 0.15026177249608502, 0.30321845844868694, 0.136726132684177, 0.15700694684299732, 0.08155577455557163, 0.14433085768213197, 0.08377751380565666, 0.14141459078077348, 0.14265534678293815, 0.1391859337567322, 0.22747140768314564, 0.10882047605851006, 0.2255427200467356, 0.08259255964789661, 0.10411697965595992, 0.2268562544017069, 0.15442903033427655, 0.27798361415343903, 0.1771787007249171, 0.11559097727219905, 0.12396228049070605, 0.10894592295611098, 0.15898414316677278, 0.0866029609835917, 0.21557101318913124, 0.10445876212249841, 0.17511887415762872, 0.2044823961032014, 0.12655131293520813, 0.10899283051971467, 0.159914480342019, 0.2039802867558695, 0.12154618473423105, 0.13251579006112393, 0.09543682809077925, 0.08494418910554341, 0.1400996468240215, 0.13381217936834983, 0.19331212936630174, 0.1605854661113793, 0.08468538162208374, 0.1878177161298452, 0.21333466464233017, 0.28919727211036994, 0.1303411575575029, 0.18732303783537882, 0.19626849330961707, 0.12506141747918822, 0.15630196209155744, 0.1272043799080195, 0.16486684040677163, 0.14925517892885595, 0.11451033364620902, 0.12695155557124846, 0.1412298563387125, 0.18512361472652805, 0.13509778215760185, 0.15590822354199427, 0.17226931819271657], [0.08986296387569559, 0.05379923694436589, 0.07866519458231427, 0.048656952191865256, 0.07000208081256959, 0.02409489014216008, 0.024082069660747246, 0.03440654085528466, 0.05953092676317019, 0.048074997330625216, 0.008180982080258189, 0.04915830311215213, 0.05542955631690641, 0.043123705958526944, 0.027284887919743216, 0.06952552815839168, 0.0475266047813479, 0.057581393874340484, 0.06313417918018757, 0.028644318602258162, 0.020232998781026374, 0.04648537254862247, 0.01718419675354756, 0.022499467989790346, 0.023724306600108266, 0.04142276860112625, 0.02278087315179648, 0.013189999135060897, 0.01816342949056097, 0.029782261774544756, 0.04396927550495152, 0.06064232115844085, 0.07032712425796256, 0.05667093668072935, 0.08262759284867395, 0.046276916193986134, 0.0050457423522828095, 0.03807098837569356, 0.011896635875135902, 0.0468190536353617, 0.038706592374270966, 0.025261871877216527, 0.10596006462771086, 0.006690277922673212, 0.04067446540800795, 0.054085550814746856, 0.032784499062765995, 0.025257083827689774, 0.036556202723013784, 0.03660613250347876, 0.049071961172646096, 0.023679839026543404, 0.05140565268154587, 0.022994588700033004, 0.004846331580812413, 0.059909240132378, 0.010048818395232723, 0.07215920054624159, 0.011094791754599542, 0.038655161061474395, 0.019638459010410215, 0.028298282432520104, 0.07058341897303058, 0.02765098601699837, 0.03894503341026364, 0.008541028082911527, 0.045452283830532146, 0.039094638890556754, 0.08162201817838416, 0.009171684111107983, 0.1054747172841622, 0.07422983661414155, 0.010537985644693817, 0.04122976807036227, 0.09557619480596435, 0.07837724511421497, 0.052548215364015875, 0.028125387879328865, 0.04899116954015148, 0.034033019366043235, 0.04495097121464149, 0.047225371348641576, 0.08789316030038942, 0.014032473686271378, 0.020305568374873652, 0.032467277375079935, 0.057755816772940664, 0.033242313206316, 0.06720754528237928, 0.04133448079829255, 0.03526558588829733, 0.012465453286084437, 0.09721965258640629, 0.056743021723964525, 0.11085203398139247, 0.03810843475343239, 0.044751064401240125, 0.04328582548506318, 0.06624629645938836, 0.04632132631095667, 0.031138208672224037, 0.020872816263187318, 0.030022221579847318, 0.03693938841142001, 0.01326783654099751, 0.057305747778305126, 0.02250073969574465, 0.03632439217800575, 0.04410994840004752, 0.0721322495730654, 0.03433305004070844, 0.058108826258009484, 0.02510480661576073, 0.07157066882017159, 0.02323780820945338, 0.03597163167151232, 0.027853277279064063, 0.021372253878883297, 0.05811130072200491, 0.05223194745579555, 0.015846007773953102, 0.017568198325593146, 0.07655841448614675, 0.037236546256369164, 0.06163180032144151, 0.05026477156206966, 0.06590048437036815, 0.05488228991687779, 0.01793737992674353, 0.04693359144092087, 0.08952200878411533, 0.00824865158421979, 0.06114915343782595, 0.07032621261333266, 0.03772587725712407, 0.07552942816889094, 0.026435819266724492, 0.025525591899490645, 0.044202717817238266, 0.03735887517611827, 0.04608028057602145, 0.02588283976600055, 0.010301991302009312, 0.05203969769119736, 0.0984901098173953, 0.06974118190907663, 0.01739329279160067, 0.03244566603473598, 0.028414863777617295, 0.05344215953241914, 0.06069421212399199, 0.031952935518817074, 0.03294469570861228, 0.019364258905331937, 0.009824622764192041, 0.029582508178728244, 0.062451460774266915, 0.02270348678012529, 0.10758035590932255, 0.04585336533284957, 0.05224984710014636, 0.07161743848794891, 0.037731615255676934, 0.047543075671719934, 0.13066006463862237, 0.06319165109626709, 0.01564641026855116, 0.06858630436322383, 0.004336226669575779, 0.10819890296026584, 0.035102255942840735, 0.0766874083708371, 0.057338164788821054, 0.03218852862295124, 0.044819142804631305, 0.017088579404498302, 0.026158256035658623, 0.049935169893527226, 0.07003856191952383, 0.028414813981902216, 0.04671581179624604, 0.09539348283602346, 0.02661105996418384, 0.004350270976447651, 0.06845763223546167, 0.04806946617581191, 0.018474340528970765, 0.0529665683185862, 0.03454492697792669, 0.031224117772052848, 0.017040465252413865, 0.04526363084873846, 0.02320808974365073, 0.07115887357823311, 0.02242733889649953, 0.05474171661321194, 0.05334800732652507, 0.028304955058340586, 0.011193355669327562, 0.03504226742792995, 0.09415349292178309, 0.043603552790779265, 0.01828975547405501, 0.08886981515153762, 0.008122994970049589, 0.0951525022185618, 0.03651784470064506, 0.06786476445174025, 0.07465686934489398, 0.03667454032467739, 0.0364561248270254, 0.07326671087573614, 0.014122924729881269, 0.04385200659594229, 0.027472828439767324, 0.029085671431535197, 0.035472747554341634, 0.005041510195306112, 0.10732681144990268, 0.01701534522937671, 0.10211742888655394, 0.052945730727045774, 0.11385663848129973, 0.07982321308865663, 0.017906768968509092, 0.017857997896029584, 0.07094772442454292, 0.03477641576600652, 0.026138377969243357, 0.0034599872719075896, 0.038170181440129396, 0.032126486992403384, 0.006125154013129613, 0.05055097051926198, 0.009394236483551081, 0.06235524013097729, 0.09169405957143154, 0.04066183644857618, 0.010179171128378761, 0.028787372115578864, 0.026588485268275105, 0.032483480134678465, 0.05817475195433344, 0.08872877070379835, 0.0504932381332882, 0.024312974306784814, 0.05839854538921387, 0.09262392943304393, 0.052239949244164655, 0.11530800737560758, 0.07477125393286829, 0.03717060523828672, 0.044875768193554495, 0.06254037293875891, 0.045405452875720884, 0.043025669686856775, 0.028190758161907716, 0.04067440029053439, 0.05133809138750357, 0.020981028097711747, 0.013874716072854017, 0.05878410595018537, 0.04054040002125887, 0.09020117637250694, 0.024543637635126233, 0.03532225724249598, 0.03925735979611355, 0.011291307671326063, 0.042120613413111824, 0.06897745353560295, 0.08014477083399411, 0.03716628450239378, 0.005590042076824654, 0.11583448597981084, 0.013405265053734185, 0.06113491952419282, 0.05675757739452585, 0.021225019440715833, 0.007889857656517698, 0.011291388110558112, 0.07460537291462384, 0.07637419332299503, 0.03294021792469486, 0.012486297580894205, 0.04043842222721827, 0.06977980040133962, 0.028139535608070514, 0.004228342337638981, 0.035895861745361364, 0.020141422545777696, 0.05919152683007622, 0.030403490133223035, 0.04331923457944105, 0.03847669704907364, 0.04880758039953728, 0.015349390319428377, 0.026738435488134146, 0.045043721479634126, 0.1145436737926737, 0.015191333931720546, 0.02496773050346923, 0.050607821904122836, 0.06314377826187881, 0.06707861268472287, 0.02297693228859815, 0.030354540945301135, 0.20701445458877474, 0.01999701688727064, 0.04502773705509402, 0.044346723194804885, 0.043749036718039744, 0.07789957397166761, 0.03807933107318898, 0.039548002063266696, 0.06341037685952841, 0.03733163308953086, 0.06514580349528021, 0.018792713263763056, 0.06834627369478827, 0.03401057682030144, 0.06893389377622836, 0.06192381771641874, 0.006130416079559514, 0.045388687041498, 0.12876444135702428, 0.09791917513094603, 0.08139896401835066, 0.03239288640719268, 0.03727504600500388, 0.01736586492869162, 0.09809899894941239, 0.023438230216983828, 0.05810272053725297, 0.04612745627039864, 0.0363126595414454, 0.015392849529762904, 0.08368428856615098, 0.09929631776627033, 0.056545076095649315, 0.012053987461953394, 0.07184934096350785, 0.036601631736923615, 0.0501529916730379, 0.06646579597145319, 0.022292011379895192, 0.024060483218260834, 0.018785107925894762, 0.05826565211698894, 0.028168145161602768, 0.05070003207712885, 0.037435208176893574, 0.026046282709425977, 0.23805410030388066, 0.16160116080314885, 0.26730097770210237, 0.1330290996139088, 0.11259390341658747, 0.16848107469418358, 0.09361806641062421, 0.10623468416592768, 0.21804601344610416, 0.214486860880448, 0.11567743029445411, 0.13688451370164273, 0.11556197318338579, 0.11948562272253538, 0.08872294843557382, 0.12795754392901737, 0.19588071492410478, 0.14100122505859022, 0.17195171346106838, 0.1297099623949297, 0.1572761194960725, 0.10075500280025507, 0.0973032174571868, 0.09945123606631834, 0.1985652249066099, 0.09199917706991396, 0.11446145723663992, 0.11200667403998876, 0.08955698069785872, 0.12961213296699908, 0.11016889805755309, 0.19111137326446273, 0.23459859943437963, 0.1523728197019908, 0.1580559050724391, 0.1625374121771705, 0.08055648946714017, 0.11198563726558802, 0.16514235626785986, 0.17057031903776432, 0.13615093854886873, 0.15832452614220882, 0.25346115501897953, 0.12456966564059259, 0.2864676089056077, 0.12471210436835406, 0.16863931781582295, 0.11935295161580849, 0.14301085754507972, 0.09979284233263425, 0.12826594794469495, 0.11224490440180225, 0.13934433009595643, 0.1306057183612739, 0.23304023870056678, 0.20105470422535174, 0.07103773975564588, 0.14325709352570196, 0.1100630017237798, 0.26635991529591624, 0.14853838110162368, 0.09847898622073474, 0.15696977625691122, 0.16100456217123618, 0.0774975846551599, 0.06563302009336411, 0.10780363223485409, 0.2049479783783036, 0.10539725813413821, 0.08363988611005968, 0.16529172809133608, 0.16760741270357565, 0.07852117005254954, 0.18717671504184125, 0.14581167499624914, 0.15925803492146154, 0.1783251819471198, 0.1785203198631925, 0.0944743765097472, 0.15876263650434633, 0.08462950316888672, 0.18028491146622166, 0.24964868782028077, 0.11339313230447232, 0.11277872212832013, 0.3080823813234606, 0.10357262822048319, 0.18900692973646427, 0.1359984870519369, 0.13459345115528953, 0.14061323216845914, 0.06915671810988458, 0.22795036585340578, 0.14681206325129156, 0.2198368205779022, 0.17813428815814758, 0.15086535784986713, 0.2621868811547756, 0.18534979452529263, 0.14514033682644367, 0.17818268959320363, 0.18710410522837795, 0.1533916400324914, 0.14276420787697838, 0.17361801598341237, 0.13098744465218437, 0.14418792099721972, 0.1161583113454042, 0.12183150652075007, 0.1256820712719233, 0.23737468756735328, 0.08457092042531698, 0.11801020632828436, 0.15541674749505135, 0.10841594333009374, 0.14720941773585736, 0.10748539931110798, 0.10040768151802403, 0.23016815975068078, 0.11237837990084965, 0.11413915638601589, 0.08821163071139206, 0.20739421969459904, 0.11485466718553536, 0.15140097588300705, 0.17307718855238732, 0.09379533915630273, 0.15175126192550506, 0.09560959623946298, 0.09045696546954494, 0.2209595683962107, 0.09418143980926084, 0.16929086027366502, 0.12982651501172973, 0.11038656661947889, 0.13810340555444842, 0.18736581618507064, 0.1562453635157116, 0.1598916968871509, 0.07693617244160945, 0.12354450210207894, 0.10095428525199814, 0.13885150573426677, 0.19506386601396147, 0.2792283844563269, 0.17000727505693514, 0.07314035233350531, 0.13905364569396744, 0.18317773607709717, 0.15258655823286504, 0.19265245105470383, 0.22022530376430483, 0.2118912937059518, 0.08388600717749327, 0.25168683409931203, 0.1815197379478524, 0.2592668910661052, 0.19263521407640752, 0.08760067559177838, 0.1558570795121693, 0.24571695605353003, 0.31245760138957734, 0.1529968289598342, 0.14362202716931222, 0.22800940058885083, 0.1541879118209885, 0.12498593483600887, 0.18775716454031008, 0.08529907167558709, 0.1296777100933175, 0.09894719617741723, 0.1702797725316017, 0.11807983605972222, 0.10530942615361945, 0.08854197548522104, 0.13813191934699012], [0.04284276619493481, 0.044563353707593296, 0.019419049513676477, 0.03492876384106856, 0.06936049749774319, 0.01553811895240459, 0.08279204128249999, 0.031023647884027134, 0.056787948950283954, 0.02555045528307317, 0.02316402436624612, 0.011851952839342338, 0.006297841722581295, 0.09380990248774329, 0.04877021063059088, 0.05004067552245913, 0.02666292411665763, 0.05117159366848008, 0.058598344950305845, 0.026431261043575023, 0.025836529750977794, 0.03586925934219072, 0.03384038272704329, 0.09313951426696393, 0.024273400119836294, 0.06456180700972196, 0.03316783030787784, 0.06351509724833793, 0.07656343236205078, 0.07640692059912028, 0.03626402061913283, 0.025037235745619384, 0.01684469148336399, 0.01710742708265541, 0.07618018921705023, 0.004691400831835646, 0.05720515277296786, 0.02338682571726461, 0.006562121467845094, 0.02909502153465104, 0.04685135956312861, 0.04299649705870017, 0.06657295635030155, 0.0573981647950507, 0.049776379019021995, 0.02256571927348212, 0.015512711646395828, 0.06067615160117708, 0.02084588827264886, 0.05087665747851134, 0.01734120455840903, 0.03292977997672654, 0.02596779125592401, 0.0582213492523278, 0.041655460147247206, 0.04323506449920036, 0.029680038832368392, 0.10459332546639828, 0.046342543116019624, 0.07905695662503281, 0.09176535171366508, 0.012151144647730455, 0.04735893877823988, 0.05774568526014205, 0.03405191109425599, 0.030309904832392934, 0.013230753097412808, 0.03212551789117917, 0.02054622532018731, 0.010448081396339882, 0.01385782191890382, 0.03503183714084087, 0.04317675371684375, 0.02217286172503185, 0.014264138674573794, 0.0036616833794171056, 0.04829112988626284, 0.019445628934209386, 0.00872628154954122, 0.037416224518129905, 0.08090279951331117, 0.029653279381173275, 0.022996609256933295, 0.03186695364063546, 0.02524120282501944, 0.02039566989086809, 0.09087504263246253, 0.03800031676467869, 0.016052277905175525, 0.06583889856213523, 0.007730608086867799, 0.0293326543478836, 0.014807199251898115, 0.03786760352311596, 0.018574510355510058, 0.04331327441539015, 0.013040986415299197, 0.030169511559389295, 0.058847059225363124, 0.011926109192802781, 0.033691573978191426, 0.04008094261911127, 0.08217981445693201, 0.05047815386205912, 0.13121854273542283, 0.01603185112828449, 0.01696718894245644, 0.039824249538322615, 0.03754925568618121, 0.05846021546711845, 0.04704841652945165, 0.08105256204162875, 0.05612440189466842, 0.012350575529008865, 0.05179725767623994, 0.033070073658300024, 0.043379062215887734, 0.024425263644286224, 0.011370392842969347, 0.055600344128305876, 0.06496894443708082, 0.044979247519926685, 0.07904390248680308, 0.05286728715403907, 0.07333054132158719, 0.04876769020132, 0.018042701694573608, 0.032870538397541935, 0.02964334705123498, 0.06885557660772916, 0.01867076164231666, 0.019542514158773328, 0.02473685458572882, 0.019413719456943295, 0.03374248435119948, 0.0553692766885844, 0.0535464394206722, 0.03540245515684928, 0.017668881431041707, 0.028551214021600546, 0.03407536870649746, 0.010644169261438713, 0.025446485660429445, 0.01923659609841003, 0.031222062741195968, 0.10149718112041874, 0.04127096444849045, 0.062071163237335227, 0.04853167766404729, 0.07473682594155112, 0.07060821723913954, 0.052498749066745086, 0.015983159537427127, 0.007567926443317124, 0.12524406050121592, 0.02723267519726388, 0.07569874126103616, 0.014135477080520605, 0.05264489949049969, 0.13021887460302922, 0.08415638258860958, 0.011638960286584354, 0.017909735643995867, 0.01679391326052287, 0.028204471135752338, 0.09769629717113511, 0.07386563075405937, 0.07564925198112765, 0.11665858208171784, 0.06475021101294026, 0.010987898548914781, 0.01622651790028378, 0.05304203180956745, 0.07548458138180357, 0.011950164353625189, 0.0214729082560347, 0.009708714618858312, 0.06087324687189633, 0.044491747469310804, 0.04696177581565515, 0.04007343495745332, 0.019456767852628426, 0.04018041147519985, 0.010598791000853864, 0.06197359427929886, 0.03828577644702408, 0.0055834498902362206, 0.028904192863152395, 0.01883743747678255, 0.03815099476806579, 0.07037005582523924, 0.021356562482974222, 0.020400982710622975, 0.04858523104039412, 0.05421452171679947, 0.024336780489031828, 0.03925013558698758, 0.04281271256566529, 0.03875312455479176, 0.037486356037158164, 0.042519603495395956, 0.059961307298151724, 0.014276347243257109, 0.05073578923099464, 0.05652095581735334, 0.06340903620566092, 0.01750874224178974, 0.0053036889444375715, 0.03557982366351831, 0.031239807252742113, 0.03868799942034868, 0.055903875824785045, 0.015519977032747722, 0.03598012375615297, 0.03592798764246606, 0.05557541179681017, 0.01291306409609294, 0.008853382239448688, 0.03177763927998322, 0.04140135644364261, 0.06584220040108889, 0.022127882787777532, 0.016961912511877956, 0.06726581392990005, 0.03122534734317132, 0.07694903505785812, 0.03360867943434465, 0.026107133073251576, 0.009827519534155726, 0.016017319397970794, 0.07131028319558791, 0.008890686890921526, 0.03162062381424251, 0.05125595910114147, 0.05683510549246304, 0.019591549531586712, 0.03372025631007648, 0.03842836073149116, 0.02488398751724632, 0.02995265313544341, 0.05611087278192563, 0.03930159754330113, 0.028174603282804453, 0.028906816714293057, 0.05926444690914885, 0.036456952201983625, 0.03749104832569438, 0.06681682511923775, 0.009108005925231885, 0.023031098535284403, 0.025927979581718965, 0.03861286534717487, 0.03499043008853351, 0.04411660953454914, 0.03769042270798837, 0.06656295890288969, 0.03958437208747191, 0.008750942877433714, 0.02883348869340074, 0.04706808583690755, 0.02455076991370128, 0.010123724557249057, 0.09238756832576568, 0.05475459072077948, 0.07884209194490988, 0.03053201670427957, 0.018292785351795536, 0.061584425444204005, 0.013758987958182492, 0.024902256799020597, 0.07270866178817327, 0.057399509279357816, 0.08021980914617739, 0.006914318420909226, 0.07512513292773117, 0.027076347295435208, 0.053573263989340876, 0.059048513536371534, 0.019863809518996748, 0.043199579306547685, 0.09750390951071056, 0.05131392514393215, 0.0326014117097422, 0.013229015035434596, 0.013712510361426301, 0.09182650851266039, 0.022393242238209616, 0.04498483996177393, 0.02325545504478918, 0.013921075883591849, 0.02746024927605064, 0.01808684942643008, 0.00827121861924928, 0.02584954366959151, 0.01568409509115642, 0.04298988955035325, 0.05838053466211404, 0.02332821424539772, 0.034696363408358834, 0.05190799568569468, 0.043657435584933534, 0.021056049172916723, 0.03836681705809409, 0.05407231281541529, 0.028715775453395424, 0.01768385844996139, 0.047925004975930344, 0.03601765440356347, 0.062183391287802696, 0.014942247146410088, 0.04706371913573915, 0.07760008721942864, 0.03466379701069767, 0.012904890895550771, 0.07479611348601119, 0.04375976577941929, 0.00841440715556664, 0.110319112577746, 0.04769941123442785, 0.06627298696267028, 0.06253490690141916, 0.06980859764641331, 0.012660764529550029, 0.05486664257102436, 0.013620346153695739, 0.04396840216471784, 0.06301060153712189, 0.02680621894767448, 0.013161772625490785, 0.02305529350715299, 0.07532301343857281, 0.01750562809437754, 0.0955088020512654, 0.01477552917710836, 0.04794370901260165, 0.057621360681350195, 0.05659538508963682, 0.00780484248553553, 0.028526735597199974, 0.039789733446894154, 0.019541740409969803, 0.038738090079277754, 0.06506619929906822, 0.044052219844513366, 0.05626568766010385, 0.024825533093403906, 0.0520832306374946, 0.017448610085393154, 0.05820591641109317, 0.07157470610353255, 0.030266316344721184, 0.012408784804715505, 0.13838796125304315, 0.16465864835246918, 0.25169458690910573, 0.19069705759325337, 0.351182579874031, 0.11889636321293733, 0.2237722908537234, 0.15483226837410083, 0.1666856097478059, 0.09851120021795073, 0.15183548563190047, 0.1158678031436378, 0.0536473983177735, 0.16057354578327748, 0.10039473463210369, 0.1097392070017034, 0.1392817407125427, 0.09983356756668899, 0.23560464141830323, 0.27847663769798897, 0.15073227305566111, 0.101236320521322, 0.0961058909794496, 0.18716853322280994, 0.18600516742275608, 0.20622653315865225, 0.1460092490719211, 0.1389949020719336, 0.15785353528636117, 0.18735794080120904, 0.1512275948639839, 0.0951201809690364, 0.07021774988501303, 0.09590538278702768, 0.11782946320430887, 0.21232129885785042, 0.25455269241525286, 0.2163569121471336, 0.13748699588881386, 0.10589092519254455, 0.15160702289112155, 0.11558799719017361, 0.13717305305744373, 0.12994576425802323, 0.18764186830770588, 0.17203135596167657, 0.08441810886706076, 0.3044248324248099, 0.13596401309534428, 0.12708221952761375, 0.12371284992343957, 0.13111702076369716, 0.11813181512538465, 0.1413418737150008, 0.11351196020240746, 0.08616107380798749, 0.10215140488599578, 0.2493257357949211, 0.12060676941708212, 0.1404762250040808, 0.16985172856478922, 0.09707202744339744, 0.15949710031911252, 0.11503760898185354, 0.1989309706034199, 0.07623301097942937, 0.08894903630378748, 0.12688584820998292, 0.13471352777654125, 0.11380702662732332, 0.07928779423837701, 0.13546340528034395, 0.09171401616185905, 0.07781737273739231, 0.12725639727807816, 0.14643775269148812, 0.2473359756291874, 0.10342577682627786, 0.11216660255506156, 0.20886087970387554, 0.1494117366570619, 0.06908208582430117, 0.1317821076560405, 0.15680514396198336, 0.10625988079775726, 0.14100703200505627, 0.23135996273448392, 0.1439751017718546, 0.16031866833086938, 0.13177017200618021, 0.06124104568434339, 0.1586462983921651, 0.1579840460251416, 0.06513142402494146, 0.1748016065046672, 0.2394807858452682, 0.16495636544160305, 0.13428551445324577, 0.11542247623325357, 0.13460238374048664, 0.12980124943198698, 0.18556333387330656, 0.18335281781131224, 0.23374485572980297, 0.17874649966195708, 0.18310160225918218, 0.18971615861500465, 0.1389443402689311, 0.15022884603709946, 0.21989700444523366, 0.11223022615717304, 0.32119578411502225, 0.11019645424018945, 0.16821921051990602, 0.09553135567975622, 0.07304510462187952, 0.10868407410359192, 0.1413185233550687, 0.09610899363554294, 0.10787023591899103, 0.16073842322634113, 0.11439125293925886, 0.12281869508085713, 0.17860598381488554, 0.23329834904401536, 0.10743975579257935, 0.18069358873030833, 0.2726049414805828, 0.06997585762292147, 0.13247650507236683, 0.1611993783303807, 0.16134122717044047, 0.14541355442375908, 0.05679421171906495, 0.1386943198139629, 0.27970164293243044, 0.13988737918196187, 0.06185255238726255, 0.1978356027675252, 0.16030956720632894, 0.1578055935040597, 0.1727563049644232, 0.08785728440289536, 0.1530539025101931, 0.22145052350336508, 0.2767669745991307, 0.16892842407668793, 0.08696478431022937, 0.13723709800791356, 0.16834950675406765, 0.1456216698692691, 0.14826513286079132, 0.1341492886985502, 0.06941693519512493, 0.1735718821686122, 0.0686711715834756, 0.23872615859633495, 0.1368282062392081, 0.1405908930445871, 0.426628113754334, 0.14732639936189498, 0.19096488193158181, 0.18041752128591462, 0.16858420545055022, 0.10558513353668875, 0.21306000679971712, 0.1744024287308416, 0.18786591838204092, 0.27307482916981946, 0.1613942404548007, 0.08765672258431874, 0.17039160604678816, 0.1157215109936172, 0.09399822988216916, 0.07777754382620897, 0.08970628357342175], [0.056872260756790645, 0.023682845921646205, 0.05062523508264173, 0.050583046620651606, 0.027067679010571975, 0.040734526701271534, 0.09816620018213026, 0.022553333546966318, 0.027297120428674167, 0.05837265161737319, 0.17800927793066348, 0.04299517938747041, 0.040712467199491884, 0.016852011453480493, 0.08498561147960924, 0.02298362406661674, 0.033841263728156205, 0.02201406318964737, 0.008218925457537897, 0.055903297428402214, 0.08950098733147306, 0.02412294811238685, 0.0269752083676717, 0.00963802194042552, 0.08999557369538853, 0.03618502163238103, 0.035557013395572865, 0.05167385623339684, 0.03666116442951945, 0.05247103583608424, 0.025797687177996964, 0.10934080297668135, 0.03396331302581295, 0.04586724301559791, 0.041946631015068105, 0.052495795797796986, 0.004474380571815756, 0.032185238275316455, 0.032421369556217425, 0.015545573945517744, 0.03687404877235813, 0.02664637278705355, 0.04331420138177853, 0.0354528216074311, 0.026318106026719176, 0.06388081230163094, 0.07231721384150368, 0.033175755487454515, 0.0981218207086767, 0.04850578006176699, 0.02335869879912465, 0.060657631425607594, 0.05952670561870741, 0.02656134277311785, 0.09008713652409854, 0.057591207460650516, 0.019181816981384353, 0.052282585867590485, 0.0035616248750293088, 0.1033385347334608, 0.02434874678240909, 0.009248902901045738, 0.04891215906208081, 0.013132541583129957, 0.04618843686917136, 0.0740160980832673, 0.02753268863495079, 0.02407128888843281, 0.10654373169546166, 0.04159134241842455, 0.04666299386430652, 0.04467497271816096, 0.07434750005843178, 0.06161724082044056, 0.025569166980623722, 0.036423133250566266, 0.05103386255101331, 0.06001662267672439, 0.01361174298630607, 0.02276022708223712, 0.03487136470334184, 0.0801205701164661, 0.11700843911497824, 0.006578498033641448, 0.046836394035527786, 0.08784864293110949, 0.02967962514488928, 0.04071059028407739, 0.057231222745031125, 0.043229081352511724, 0.0407645343652656, 0.015676805764556895, 0.03062028727013498, 0.04702641065382669, 0.10890643112361433, 0.036297709335603064, 0.041686118985976905, 0.012432942429797785, 0.04687807687948789, 0.04159671652521338, 0.006208774425284637, 0.013628336450745984, 0.037288004382243084, 0.06267829557820674, 0.06335157578090025, 0.02465841101272212, 0.06834938401176084, 0.07448787800967693, 0.04311688011512161, 0.05245338517030882, 0.04206720559347061, 0.02016443582702308, 0.023843280054749023, 0.05438751586142087, 0.030079764359059836, 0.06952148321415148, 0.1037678887106238, 0.02513978810560319, 0.06101635592659155, 0.03685907941431769, 0.04264668982115485, 0.015998312756569398, 0.060578670743252, 0.033993964203663414, 0.03802743627719822, 0.014197583828542023, 0.032289702024671345, 0.015551580074844102, 0.043030971015292796, 0.032604663752980774, 0.053213769569993026, 0.09213945542972896, 0.04363522669600864, 0.021302777365030303, 0.041139128377601024, 0.06994730552598354, 0.0294544278538876, 0.09660164945788922, 0.07034448381032675, 0.03798661911259255, 0.06391271986367722, 0.043113137775611494, 0.011037858972896733, 0.03218807663107592, 0.03439711031293677, 0.08757583136039396, 0.008512343835806655, 0.03164682593647271, 0.055945528025228175, 0.04624403953071564, 0.020266679836617365, 0.09986536787642587, 0.07387269408472123, 0.02843716076665348, 0.04533349040655359, 0.02653264128903468, 0.03743603938229142, 0.06338301219887311, 0.117115706746136, 0.03293895004918018, 0.1061268572905852, 0.035993982286703204, 0.014775660369665393, 0.035954272119148124, 0.046602614644554355, 0.021734785836850925, 0.06378554543780704, 0.10744065977633001, 0.02578472688553795, 0.01609792238131406, 0.09019595931374258, 0.043805635293885585, 0.04935489659528098, 0.061467719609819116, 0.0867249145202579, 0.0729991393464227, 0.08778458265888114, 0.011569836173176525, 0.04058138572520787, 0.046633330939878384, 0.01902423652579948, 0.06399712743117444, 0.09449416456083137, 0.03426658425239786, 0.04346202570764769, 0.06495750674437131, 0.025086368794643113, 0.017131658443700404, 0.09118329343055526, 0.008158957052435125, 0.028852443623867248, 0.028170271055592645, 0.05178005517190022, 0.03338130070797859, 0.02120075743615387, 0.06594268815411676, 0.016934511462046255, 0.03814040360251262, 0.020578220982344884, 0.0682074509020294, 0.04028422788025872, 0.031369034794249365, 0.021445712134722742, 0.029806431848555807, 0.040787199076505444, 0.0537203835143197, 0.08301672720981222, 0.010980415785114371, 0.021435498267472274, 0.017494146351612384, 0.015871318361361422, 0.08113764376649935, 0.01676435758840413, 0.05763830271579566, 0.033865671289423784, 0.02944800037620289, 0.04678870889268095, 0.052978603559876644, 0.054730443629406156, 0.037981164566571676, 0.08037896391244666, 0.023317241951102213, 0.05204605622096889, 0.014305312070064248, 0.013825070702530926, 0.027090274773898627, 0.05560217890888453, 0.023739570901999553, 0.014329687072595042, 0.0215362292534161, 0.1391128796122728, 0.0945504567015075, 0.022800082806497816, 0.08299877010886708, 0.024556919684513442, 0.023573040624239275, 0.059330391757670915, 0.051973691555641355, 0.015304509058384406, 0.02747545995178723, 0.0829121868516649, 0.05094826371679383, 0.03924846168487303, 0.05129504873747787, 0.05674874823119852, 0.035727931441919464, 0.021071767381903146, 0.08723501416464007, 0.037634655337540374, 0.07472886628801785, 0.023606129876908757, 0.08237970211813528, 0.03838081731491032, 0.0612293436913, 0.006439714981693655, 0.03514890686698979, 0.01796385209496704, 0.0467871958690305, 0.021283820519343983, 0.02414451540267516, 0.07059615135433213, 0.061113051544394226, 0.014018749221107893, 0.05727652535443345, 0.029315377149971265, 0.03177048593399025, 0.013597374049676283, 0.024685383053316225, 0.06833916439885093, 0.015711464539861247, 0.03800180297525179, 0.07721137420664873, 0.07159444818934126, 0.032892375733823545, 0.060154395929026994, 0.05732924752538243, 0.01679521944043377, 0.012229566195709331, 0.05732339461364093, 0.042226655303590724, 0.06713089818555502, 0.024087181382422006, 0.03529012368451204, 0.043109862749735196, 0.022338443968985832, 0.012409925318112778, 0.04899629083792529, 0.020650899743721373, 0.020993969237972653, 0.06870805871702972, 0.051630461182925975, 0.019355793633768638, 0.04750936397261197, 0.04701322628064983, 0.04350761943046124, 0.026705116409087376, 0.01702993345867482, 0.011732486215600324, 0.0822570744240957, 0.042226850656011415, 0.023144898981216456, 0.055276882654476556, 0.07775846057601514, 0.07217659840300199, 0.05299658747389913, 0.06560151089703845, 0.010134136649749933, 0.03982430699491694, 0.11201867097688299, 0.03414551937772382, 0.08253475831400964, 0.09393960117332398, 0.013425551061969132, 0.05306061327217087, 0.02688095082468804, 0.02555542336326213, 0.09023559670294486, 0.03177423401915979, 0.059584667831058466, 0.06838484622177578, 0.02886402687328237, 0.10173077665029034, 0.023195100722894556, 0.032466959448591355, 0.056708061301539985, 0.060539301484823234, 0.041743491310626275, 0.05348338272362467, 0.044085150133938565, 0.03668302474843879, 0.02203494674646326, 0.07175188691866013, 0.008471424206941119, 0.03755675568695992, 0.02468173455957684, 0.021759365767901464, 0.05650676020811643, 0.029375765945822484, 0.019678197906262452, 0.04909728803942281, 0.002695563434240138, 0.024663833000006217, 0.045121222764493964, 0.06030384436129563, 0.021768566483872074, 0.023874176380735253, 0.0690660745866837, 0.036409676916176276, 0.07782013065391973, 0.009449532709925646, 0.1165927674681429, 0.0151183046851187, 0.1334158361198441, 0.08782566029338107, 0.17001516576255524, 0.07250321232863972, 0.22304547259644156, 0.1683787253474997, 0.15813252918662565, 0.12339365938978812, 0.12320935395696472, 0.17782313388682183, 0.2711122957689147, 0.24867037821921611, 0.19927175715565684, 0.08256301163665711, 0.1433145347982645, 0.12424436172530537, 0.10591265144607714, 0.10226384361064243, 0.07425934632098483, 0.17751306746034853, 0.2669825915607714, 0.11778766544716013, 0.1369613063551726, 0.16972340883747225, 0.21659184066999346, 0.12205530378607013, 0.10914758794129857, 0.09763119501932975, 0.2496242649372547, 0.1728132559407142, 0.11020191644708957, 0.24480296719458797, 0.11087842571038393, 0.1831048811154981, 0.20785160482891146, 0.1757449365311092, 0.20106829462512849, 0.21180446530061386, 0.09543637609890393, 0.1146638346835971, 0.18185416597031778, 0.18026482464084703, 0.09585648339482085, 0.12525023516988562, 0.1547829016682602, 0.16827564055640853, 0.20236374930508677, 0.18990729755211264, 0.1605880401668049, 0.13238535593113593, 0.09378958583599138, 0.1292521329296212, 0.144857328625456, 0.09567759420362212, 0.20487029706278156, 0.23737545365527754, 0.15227941826226252, 0.20224731926235462, 0.18432391086413016, 0.12320762259825585, 0.13691607652412308, 0.11014027701270197, 0.15999341804173686, 0.15549735526644415, 0.2487715477904966, 0.24271893224889235, 0.10697284818536813, 0.11046376529960863, 0.20996822915490598, 0.16023542521701706, 0.11659219290219969, 0.14209498410984395, 0.18709013178463907, 0.1619882343877708, 0.13367898732183442, 0.2583124374430026, 0.2771215813775217, 0.1317397429938278, 0.08663796354085208, 0.1642727698650091, 0.17355041638497384, 0.20913313203040632, 0.14915889699853238, 0.12498042666383329, 0.12665456626564264, 0.20153380029143828, 0.10141580726110166, 0.14056712899717594, 0.12430624630782874, 0.12939361404747735, 0.13060522806500235, 0.09743411890080861, 0.11034465394914152, 0.16221786158219462, 0.23451650545241373, 0.15886144652482004, 0.20802331577625968, 0.14774148112102864, 0.18709780798564035, 0.1186244632868517, 0.07993287091413814, 0.116238919116797, 0.09057043841288936, 0.12088433839380743, 0.18966633225640944, 0.10292268688640288, 0.1294919337716795, 0.1729243999767688, 0.16166696775584452, 0.2035679169479878, 0.26351319385632394, 0.1509779268094609, 0.14055988180541223, 0.16801681009031114, 0.17356095775481195, 0.18278467168490733, 0.13676325730498762, 0.1891291360821455, 0.1807516581949688, 0.17309761245644864, 0.21225205983125398, 0.11513432758229394, 0.18455035113278898, 0.16493062488734722, 0.1703397265725559, 0.1441460772747955, 0.10129579958776314, 0.18423472290798543, 0.17076764796530047, 0.1702935161489633, 0.13071690836260397, 0.17615552901500658, 0.1682770654799477, 0.11152978430712417, 0.2826184767388529, 0.14590221126714062, 0.1027503937122322, 0.20104359595044968, 0.15323803940367314, 0.13661871183543436, 0.2131002570592588, 0.17304626924376335, 0.11504373002436855, 0.16002236084351618, 0.10020215544969806, 0.25441499577174265, 0.11865210373915973, 0.20606026143556644, 0.15415999557702773, 0.17576926748358435, 0.1232567441559607, 0.1127486838208091, 0.17936661719314514, 0.15170114445349864, 0.16748057918683176, 0.22593725532774003, 0.19959172143811182, 0.0999137846332404, 0.2296959584759128, 0.13924031067759762, 0.18703109704919402, 0.10805029722471392, 0.12534766623209562, 0.12985879795685892, 0.06246796613859554, 0.19174276760989623, 0.1749517290943092, 0.183068783052506, 0.1472051123217229, 0.10993001652100395, 0.15121144573054007, 0.15584797838762884, 0.2372378182988013, 0.19210649083458609, 0.20090416794823063, 0.12681991868321935], [0.013823953171771382, 0.03175173401682368, 0.04134322952238783, 0.04231758227932357, 0.04394965216277107, 0.02689083527413107, 0.0392375027971162, 0.08317484009650447, 0.043941650374401967, 0.02003313410246084, 0.04424037869959589, 0.006432742623972797, 0.09832910877922851, 0.04977481619965646, 0.06842101323268107, 0.028134236194854303, 0.06851612304848048, 0.030001809167104865, 0.04854570856438049, 0.041871037289139726, 0.03801370032071587, 0.02321983578674976, 0.027633839054033164, 0.048098566025615706, 0.04971847043282563, 0.04576367175867481, 0.039416016605232036, 0.03983685168467703, 0.07587069735652016, 0.07473858794377697, 0.020805706961020347, 0.05647456919353816, 0.0856578229896484, 0.00810199458482525, 0.035623823923449364, 0.026424408387092334, 0.05996304631773984, 0.01030987817718978, 0.05780252898412366, 0.026123626946261334, 0.07658910396839343, 0.029806542931304827, 0.018053177946938143, 0.03255127891597729, 0.03108780008680638, 0.011472931796414478, 0.05388035799466795, 0.05261859586161952, 0.029577208765512033, 0.026372933024240118, 0.044302140708051385, 0.026738134798623865, 0.011619659658942011, 0.025759210411999977, 0.02443279045814228, 0.05702782257069504, 0.031319361653239015, 0.05049908338415046, 0.05812124071282245, 0.035531717172313126, 0.034034781368269075, 0.01565641824967198, 0.010030000402982677, 0.015086243905487563, 0.09585416980928953, 0.012745083996935958, 0.02875147323544708, 0.0540112134730143, 0.013459763591057591, 0.06424489175720562, 0.02343651034959382, 0.017674858832070907, 0.07031937144816884, 0.026562606818192912, 0.03253166706511571, 0.05905069688695574, 0.02903980000184909, 0.07499451493664135, 0.043617319390778585, 0.05578857576174121, 0.04626493457885039, 0.06241796741021737, 0.01701327104632172, 0.07661715044730133, 0.038971264260791005, 0.07144464735662745, 0.10437026364548553, 0.034576964774920095, 0.02826585010024569, 0.02938370070149822, 0.06111918024778847, 0.020222512952562784, 0.052977236092931805, 0.029563285117488236, 0.06360155793147222, 0.022230699448095217, 0.049201338101298585, 0.04774082211717483, 0.016247566166003386, 0.032421882835126696, 0.062021371352696614, 0.08448652817957825, 0.046758881259349086, 0.04683725205400298, 0.04343509005622999, 0.036619703751057386, 0.048013920970861955, 0.025908367730857387, 0.04769609024327609, 0.010879584250130482, 0.07612166776051445, 0.030123956140971957, 0.03552741941905791, 0.04207938639146667, 0.011257311562076213, 0.012767064974703377, 0.006752171602490689, 0.01570047596619735, 0.021072533469827428, 0.037947043010424224, 0.03572807316818545, 0.01428002733812337, 0.042082217086346886, 0.04810393630196491, 0.056525724714681994, 0.08071468662350409, 0.016855659947219877, 0.030466284445156495, 0.05782717786308739, 0.0633978130175702, 0.03390498309125824, 0.07096857733784184, 0.022564639089508884, 0.04999844109519355, 0.048839461148506215, 0.01644660921527013, 0.05390883348281345, 0.024165326181138237, 0.01902491451361247, 0.02127537823041841, 0.04534822993821675, 0.03267936498647736, 0.044402364160745375, 0.007323662660294964, 0.07772510510779197, 0.03917669839856606, 0.015838596830895592, 0.030839357772962223, 0.0714629108927423, 0.0390613945050826, 0.055833211874649416, 0.056344349568168965, 0.05444589176125104, 0.09717354941512309, 0.027120696125371803, 0.06463995563887781, 0.06341046879007932, 0.018232517214792392, 0.04306137704500749, 0.018134258777624177, 0.016554656340890837, 0.06426605110567424, 0.03557848300965082, 0.021595074382099896, 0.023635616601114313, 0.03215954751677571, 0.03854936431913126, 0.042334463026735096, 0.03481780749655539, 0.042807621911408446, 0.024859717851805112, 0.01092351268931863, 0.026977780507877473, 0.07743733183991525, 0.01979684385831558, 0.09612746401539735, 0.04182100025636535, 0.05033873735115894, 0.011083349273840507, 0.06304551599427097, 0.012324390643756959, 0.055797454720783624, 0.0277627237711943, 0.06289176980874712, 0.02814132442337371, 0.06696737671811735, 0.05414498774635215, 0.020151490856322552, 0.08593388277316287, 0.01871758110580906, 0.04357495855900549, 0.005171430567579885, 0.032952234013787204, 0.05137199843903223, 0.09839642492513503, 0.0112723967909152, 0.01293288374830398, 0.10582339454201922, 0.0502564748298497, 0.03173657696724179, 0.01835730336155863, 0.06179737490451625, 0.019481209887852593, 0.029991300356003548, 0.025291230281694763, 0.025962915106285966, 0.03978128349708934, 0.02249461482279003, 0.0346729479309532, 0.05157245300529946, 0.019122362812800754, 0.051379138378486525, 0.08597083119375092, 0.07662119539154154, 0.0021470832636564853, 0.03366676039032398, 0.0719134012357362, 0.0047646565531801075, 0.0445675786824957, 0.03779571383230148, 0.0292424704774373, 0.05138032964520878, 0.04073180708914034, 0.052967234815080325, 0.016194617999116742, 0.02279359978743859, 0.05927779982166906, 0.04568632752183945, 0.04509974165909714, 0.03444570326997388, 0.03876783727337757, 0.004795345077816878, 0.08853424565806504, 0.008903732410662116, 0.07361559497733271, 0.026357322067563093, 0.050078290439541304, 0.04112445779385106, 0.03304734382958662, 0.041758793916913776, 0.03024218265988654, 0.05784463700688174, 0.023196311141814918, 0.09947277079786986, 0.00554747104967734, 0.02670930691003319, 0.052638460521496115, 0.03729546224818595, 0.013632648568149778, 0.015063515034384065, 0.009226869254733526, 0.07763334309622165, 0.037313764088697014, 0.06932334989429483, 0.018545165357570496, 0.04702595483151175, 0.03691915219890014, 0.0790727916624277, 0.017420755128466317, 0.014625532991973864, 0.012841753759271195, 0.026379553939125715, 0.046311432285414594, 0.052271684436427976, 0.028823966220501932, 0.015195800224319102, 0.05186911672353745, 0.02816946091761272, 0.05708505316907841, 0.03732812057639803, 0.055316899257201346, 0.03420118715674166, 0.007231034490565259, 0.02021827265590189, 0.12503490317612886, 0.016850984895661954, 0.003410102738510637, 0.06277034870318829, 0.03740045076776897, 0.061940606533279347, 0.01128580716002973, 0.01397403937223698, 0.02315332594838354, 0.036083645217360995, 0.1234716011752044, 0.015618240257965462, 0.058014888556734215, 0.02152988413018325, 0.08953339285067013, 0.05956525133261758, 0.10538915292389932, 0.024623741703708808, 0.05052019293690401, 0.06914950156163785, 0.09890025797029657, 0.013421730198446783, 0.038566172288189975, 0.03201013738890329, 0.02560672252589176, 0.041975010742223075, 0.08278796569474282, 0.02741285907705465, 0.05376755154781765, 0.08588373465763946, 0.038597811719462756, 0.008212546817958355, 0.09905385859911481, 0.028940394348014268, 0.05125984699735719, 0.0736479162268581, 0.02507631197541712, 0.049134516082103216, 0.052451117550052946, 0.05227661804266034, 0.03447422472339484, 0.03826541766043633, 0.013281777425999603, 0.015901769398741664, 0.07682705087767494, 0.020016659381649187, 0.014245172252788419, 0.04160476044841832, 0.09408327330264354, 0.041201016790564024, 0.006876009715450628, 0.06048368733196009, 0.09740886098194508, 0.06883168232537086, 0.03834496440005399, 0.06145623212139453, 0.06328215289320197, 0.042044196142664844, 0.030568978531406294, 0.024085536208604614, 0.04425792594350154, 0.05421264863182461, 0.02299375557941535, 0.054733569268137224, 0.01759868479453989, 0.010557204875494204, 0.03403695322753441, 0.017824600292970578, 0.025646863617904248, 0.01472133803256457, 0.0069969424399577325, 0.08137827964439508, 0.02450917133941285, 0.08936541275151315, 0.013052826304168952, 0.039364562309797735, 0.04872091670310305, 0.055994726191725464, 0.10574866266500567, 0.1845752489903281, 0.07259556422791175, 0.12035726224102321, 0.19088445802129086, 0.1477349234083968, 0.23384665349318137, 0.24272467790832444, 0.10890972530168873, 0.13700839011899887, 0.17074861834126134, 0.1425566746582908, 0.2312990740662621, 0.0885735919338561, 0.12202291358863154, 0.11172096154862836, 0.13705892127848443, 0.18755862519385355, 0.26806908809850294, 0.13051199516461742, 0.1101116100025754, 0.16987389914931791, 0.12631185683271579, 0.20688749849796298, 0.17935848133938928, 0.17502622348406624, 0.12106436139513409, 0.08254937527160491, 0.11662895746168592, 0.09641081695595095, 0.09463309460589964, 0.17539851157174957, 0.2177600021804533, 0.11656932517765992, 0.12710246723145247, 0.068024470801315, 0.2330350139809232, 0.1745344869672291, 0.13686174556853312, 0.06490933513569255, 0.18029798092620988, 0.08915530547739998, 0.09163505547950346, 0.127948350873926, 0.16436866875137054, 0.10805598159711208, 0.12616990074034662, 0.21003271843637192, 0.10145663974746581, 0.08981484589317153, 0.11281508832208573, 0.12042130719149306, 0.08899753733027367, 0.12315351380816392, 0.07494721666819627, 0.2320431293018403, 0.1775842523502727, 0.1992327173150355, 0.2127220700945585, 0.16113525677111842, 0.12931637706295138, 0.1489626405940902, 0.07462252562324848, 0.11833152658636532, 0.30267300384659923, 0.29287317647568645, 0.17373950220644477, 0.19350313040758335, 0.1048626130326621, 0.18210752656863582, 0.11711399837006485, 0.12929022282121644, 0.10132924698653722, 0.13895790002519084, 0.12150570464831208, 0.24654273754887043, 0.14653432573522293, 0.12816128501247975, 0.17177554388200084, 0.12540796501261572, 0.11622663872737078, 0.2672316314231965, 0.1356415820097731, 0.09757414445160859, 0.12405811809003355, 0.1501481923004312, 0.225486412584301, 0.17073582467292586, 0.16830588570765911, 0.12024670043179106, 0.16047133433242, 0.11161963875976302, 0.13511770044363317, 0.18413448796397258, 0.17698996730389135, 0.17218196884759013, 0.09652748448593963, 0.07076437660162488, 0.23367114274972872, 0.21500861272215846, 0.24261419270788473, 0.23286898740597312, 0.09265559950783368, 0.12469396340630709, 0.08190267448944431, 0.10635452329992287, 0.13784117365796722, 0.09716526034378237, 0.2944115423146756, 0.14953143023435148, 0.15207654285815456, 0.11359632180462922, 0.170571192377998, 0.10243083545637709, 0.17970283786135335, 0.11967999455068382, 0.120172489494566, 0.19928560802532783, 0.19304651136119522, 0.10163860861212017, 0.11709066333189128, 0.07123151403521338, 0.0870207546939773, 0.17458990576767153, 0.1564539539357347, 0.15446370347372948, 0.14240477474466448, 0.1717038227305297, 0.17492886903064866, 0.19443359015689743, 0.24178280344893857, 0.12875419110059738, 0.20166481664824873, 0.19504517346860903, 0.14057649059161065, 0.16205319864374979, 0.12759689271690386, 0.11721677672598632, 0.09938703023738439, 0.1214870963726313, 0.1255667597175606, 0.11305178650805067, 0.1311931239380952, 0.14227981048245586, 0.2790146765689696, 0.15397290158415997, 0.175110079468258, 0.15939737099312967, 0.11605192471535937, 0.13561228680754864, 0.15835844851549596, 0.11332555568867153, 0.20275705884541237, 0.22514106014803534, 0.11816807406684084, 0.224000079437129, 0.17336224986901208, 0.08126352733421711, 0.10783187023574307, 0.12394728815002788, 0.10235202033072711, 0.21196158993388378, 0.23812605128172906, 0.08637854318705299, 0.16204752959311008, 0.10135481134057046, 0.1069967348068472, 0.15616398965639455, 0.1437461793783211, 0.22727273044086274, 0.1662091643459374, 0.20087452034556097, 0.10978025399268636, 0.20475022044152985, 0.10895193674631658, 0.17492392010265784], [0.032173685669418306, 0.017558128099828478, 0.09486074529347882, 0.09074270860442231, 0.029794295100615393, 0.025629542369936264, 0.044666346568133564, 0.02617894998571325, 0.017266784862224615, 0.03335710382089019, 0.04991425186275475, 0.04117537199729874, 0.028370062955805374, 0.03244067880234892, 0.022061951345794147, 0.03447864122027832, 0.01740063382913509, 0.013978156137220083, 0.03138542907582897, 0.007150297441835245, 0.05432709450683287, 0.02136559465960149, 0.0662087198467024, 0.09015307371174136, 0.05710746507130324, 0.004560715329247497, 0.0181215915137962, 0.06772191969737892, 0.030308351589126453, 0.05252077792500777, 0.12478708139350339, 0.04995015074288653, 0.11457797920992298, 0.030298072604402423, 0.054386684656023025, 0.04826135204864606, 0.015250670314285786, 0.10877919924114982, 0.1471057966832192, 0.05514505424446637, 0.025614048241667693, 0.02843883466876803, 0.04605133394380251, 0.016031106107778127, 0.00683260748290547, 0.10434129020018924, 0.030623633159144275, 0.055426288951909354, 0.06158057202194488, 0.036484837802427436, 0.01958455323361822, 0.059321386394120997, 0.05727373679438907, 0.037102469378301216, 0.04315408517516429, 0.050721528504284165, 0.030274457944136475, 0.003030793215598791, 0.0909459134263377, 0.06291530786022063, 0.03953505900778598, 0.015153599313400207, 0.065113014932121, 0.013030433554142233, 0.023990215718626015, 0.04664207200309442, 0.03133139689452946, 0.04544279583158993, 0.03026282681422609, 0.012918885406707565, 0.01511048196980189, 0.03979681976019375, 0.04496436626199753, 0.05964189842944184, 0.031187343636467576, 0.026297618920404105, 0.03469297346929389, 0.026701201699794303, 0.01614269447482882, 0.038110162281701644, 0.04930356487391457, 0.016941366033748757, 0.03147050313982031, 0.009264340530329896, 0.02874728464972108, 0.0438050109322273, 0.01676896752248849, 0.06436945765369362, 0.028884694010259646, 0.047795133920566696, 0.05158987001425797, 0.06478756546012818, 0.0616469037448687, 0.07166789303864203, 0.0690800327086641, 0.016036429461241973, 0.0470315127994024, 0.09678679758742934, 0.030074242780345584, 0.05715350695555249, 0.01817586309757204, 0.014025611453689637, 0.07599781432579603, 0.06184812056862059, 0.023056421571621494, 0.01886685333785511, 0.03454869996095377, 0.05157811056462027, 0.04448141677365188, 0.048964865911271305, 0.01739369690298073, 0.025036904412592133, 0.01956379991174946, 0.008807775110096462, 0.03895013555583935, 0.03515205931879821, 0.044995201300949826, 0.027639197839063503, 0.06424306080706658, 0.015193565162800014, 0.025518597516741966, 0.059954086919465376, 0.057819846401652025, 0.04803067148332635, 0.009077318358205019, 0.09108218514630873, 0.03391321470600463, 0.029155211147641944, 0.030464173872925104, 0.017144697260171655, 0.05583606555216736, 0.024758795343880213, 0.049056068678656896, 0.035686880620496894, 0.05370365981493266, 0.0802237315163497, 0.016137025424189145, 0.009573430194699717, 0.012944199824555507, 0.05090001166888303, 0.06774320928079468, 0.02701380962295638, 0.047925989398913044, 0.04066970034111892, 0.009929956023340986, 0.0007261410475269171, 0.0702866671546813, 0.06693782104599862, 0.06449334939280826, 0.023013675780666452, 0.06557180966821409, 0.01891262517611106, 0.06686567854616912, 0.007167359656323829, 0.10305722724766501, 0.05579586891878036, 0.03344794652695137, 0.0024845368546178386, 0.022586807758817752, 0.06228653736592782, 0.05097989548718737, 0.0416091769453018, 0.03414703623181389, 0.016070500264064442, 0.015446218087397998, 0.010985443237117462, 0.012137837700485703, 0.012997689041038676, 0.038783101575268854, 0.06370386131288064, 0.0026855997425774417, 0.0237097087947111, 0.004572922940320906, 0.02880789561107034, 0.026627682156920917, 0.03747889434077567, 0.04631093432826381, 0.01069818612097973, 0.11127555036857245, 0.08003184181307593, 0.06251234944248873, 0.024294078748132435, 0.021265152871849078, 0.009567379057707806, 0.014092717883026889, 0.03649990292145841, 0.022182397604469332, 0.038977798990785115, 0.03745424546181195, 0.07917757716871078, 0.04554402668990436, 0.04444141166224595, 0.03894794454437591, 0.045268461033101046, 0.0291979416168385, 0.040824607149848056, 0.020870619506064444, 0.06481427894604784, 0.08618553499540976, 0.028639157084868323, 0.009706781204459409, 0.03598788422682593, 0.016416743277542053, 0.10608191857294691, 0.045172952851581, 0.030524985932354486, 0.06349487252713693, 0.024918549573950233, 0.018985183278639472, 0.031349828969987656, 0.007459834788835818, 0.05724714588253729, 0.029218520653704484, 0.054546287583727995, 0.0064994176500476905, 0.009761667573794482, 0.07727394060742471, 0.07679615455168871, 0.010004597885023442, 0.010297148668717955, 0.004359229417112206, 0.12819213537319055, 0.0636256973619663, 0.02689329058592839, 0.032366023534127784, 0.010364131566377418, 0.057948545342491525, 0.005799618835050252, 0.018135093813461643, 0.036463103888015595, 0.02506465211720957, 0.057854400797476696, 0.033116586686622713, 0.023089336539288203, 0.0512550704391493, 0.05252276592317128, 0.02163767461634932, 0.019756706596742717, 0.03375022566967434, 0.006676924052543097, 0.036926238512199734, 0.06436816296510159, 0.033232871172649246, 0.022139060010592786, 0.028008210900870543, 0.024863306973730365, 0.03620518506654809, 0.04386550889560773, 0.08011179840973309, 0.034717005647478566, 0.053029222819473476, 0.041559488482532964, 0.0301896117913026, 0.07338547748663733, 0.010914033308865563, 0.05154990320724826, 0.048582404175953525, 0.02895960591793541, 0.01825021001540365, 0.026279613938963702, 0.018327751519879507, 0.07010420799375543, 0.030871544957100868, 0.029764398519370346, 0.042338944641092134, 0.07085649101364036, 0.0443713337693724, 0.0535897157275148, 0.068121901863525, 0.1260149824402986, 0.013982510389459711, 0.031045314765745596, 0.07420723702037528, 0.04643787892775671, 0.07032394499307679, 0.0423598779936231, 0.03139158459230056, 0.07003581166387567, 0.03188364861172534, 0.042595913513533534, 0.08360112972197034, 0.028887756446736957, 0.06886957303410576, 0.007203536243328164, 0.03624894017834337, 0.023302557960813566, 0.0060741272905180535, 0.09349775996299521, 0.06928075540570483, 0.07442061548992511, 0.05188405543806092, 0.08951630142907943, 0.008443464870534597, 0.02542584342130971, 0.013685900297376418, 0.018370288551875183, 0.011664160748853559, 0.01663505343810445, 0.05175635241152299, 0.06273068067046904, 0.03652350609040549, 0.05077574071624587, 0.02695628599594197, 0.019880743892562967, 0.005515209650771032, 0.06867967515943513, 0.07817180331556067, 0.062205485263538945, 0.047065906316762975, 0.11610190429153944, 0.05069587605013963, 0.023389610446869366, 0.06086942409315418, 0.0528419487959435, 0.07518872588632569, 0.04473637083485242, 0.042906531523312294, 0.029234650634950208, 0.025080581000375173, 0.03165166952737397, 0.0769775948156753, 0.015302966348826887, 0.023137579011099956, 0.009502036545816208, 0.03778322276869609, 0.012801445085525274, 0.02815608119201516, 0.014239224537666288, 0.03639408319647755, 0.0341415778553534, 0.03400400761635073, 0.05429621350260512, 0.024452574678786823, 0.014152322396365626, 0.06218311549614995, 0.026348726561052666, 0.035475846379995346, 0.011390064065645059, 0.13977540777094905, 0.03234379932344441, 0.023556253722598477, 0.052967702128714135, 0.009811921984017377, 0.02853508404035482, 0.05245957133029738, 0.11688126851954769, 0.011187022995023478, 0.011966036737806374, 0.011874952714049048, 0.03510441248034758, 0.033902956788698514, 0.027690133109929103, 0.09488824018908125, 0.1253218337472889, 0.16280779524916605, 0.24256009157867203, 0.20455667598833963, 0.13209041208028793, 0.25811775917968444, 0.08012071567317171, 0.1483748060080313, 0.17668938504592066, 0.2034720946704188, 0.14393909563941343, 0.14908878463170222, 0.16592938903599017, 0.11011203901181299, 0.08465315230310926, 0.11854027788485251, 0.1266596760720976, 0.10067423415039817, 0.18310964618238712, 0.11695044625911022, 0.2634682398169272, 0.16452142668347206, 0.15488918870687485, 0.20857531276922073, 0.15338522021568593, 0.06927583712123095, 0.14927613909446424, 0.11437324987303828, 0.14670399888869257, 0.19832360077529185, 0.26350136545877306, 0.2832751366640291, 0.07442136625609092, 0.10777420679768247, 0.1568368293585316, 0.15726649743174353, 0.14698478543469984, 0.21455392421733951, 0.12139261474892979, 0.14462157272763793, 0.1776096864693588, 0.11175736604679017, 0.12293956077267086, 0.10583324643272547, 0.1799174650542198, 0.10921947763211305, 0.1057979067967784, 0.1698908296924445, 0.13751193971162842, 0.11144184507429601, 0.11681734614314572, 0.13798417162991342, 0.13714173538309915, 0.12149589872288129, 0.15853253433540945, 0.15582933180755185, 0.10335558018977604, 0.1686942003547184, 0.34184378421595024, 0.11045021320422811, 0.10026894299493683, 0.08135230160288273, 0.1380200705100452, 0.21718013490880692, 0.1852977618334755, 0.15350744188312562, 0.10821590245130563, 0.21163998622327082, 0.1436275889676425, 0.06259963750058124, 0.14851326873946577, 0.19939259986483282, 0.2590704967658366, 0.1014409043015011, 0.20882252934238604, 0.15908246289097494, 0.14205853364640667, 0.10302266136052148, 0.16050559378439383, 0.15029506667727424, 0.15926993992780486, 0.13295791472398466, 0.07679428529715346, 0.09824849334695647, 0.20499262598253068, 0.1081106955966642, 0.1477018130883094, 0.24684310530222234, 0.15855435251949296, 0.1902788042301132, 0.2800042476625212, 0.17290828148684195, 0.21072097182754548, 0.15057406057753872, 0.1618500474479891, 0.217233807028782, 0.15124113929848518, 0.1090005143815952, 0.1936638403323389, 0.19163827321702437, 0.14618272202149515, 0.09323751989511714, 0.11822903168297584, 0.196499606714614, 0.11978668761589836, 0.12782986005467753, 0.1603306805895221, 0.20166875434017953, 0.13869854861930495, 0.10086832252601463, 0.16999322500440384, 0.12857437494301027, 0.13307023853544267, 0.18869928414783171, 0.22912693900927422, 0.16254919460944592, 0.13674802747705292, 0.16387984336864564, 0.06173845891269946, 0.09594911108574561, 0.12001574024437897, 0.14903034744483812, 0.15485712026636447, 0.1269344871322955, 0.25047949485240445, 0.08123993182614928, 0.16095363264603002, 0.20236974011265463, 0.21968737214563355, 0.16630939928995025, 0.22485181599134402, 0.22410206106160918, 0.24949133336063356, 0.15523644104119272, 0.15470650738045094, 0.17251975233516387, 0.08687420207406245, 0.1452244532805297, 0.20266021001002482, 0.12728946929376933, 0.10499605788819252, 0.15835336169167874, 0.1679562431790175, 0.19964899417133103, 0.08896154651959097, 0.20689381106245905, 0.14872631779120815, 0.15720278955996037, 0.1671484494281392, 0.1588861911647743, 0.06919876867604834, 0.15087136397919348, 0.07697169593865834, 0.11231677110997901, 0.15233128241473629, 0.09399242293570312, 0.12763138199525495, 0.22007865921383907, 0.11281798413443951, 0.10532605792245558, 0.12555207381205213, 0.27172053893727643, 0.09890736726623389, 0.16658229513033745, 0.13194971237211459, 0.15255712513481418, 0.09266413372731017, 0.12846948984529705, 0.23891769589916353, 0.13446557575896864, 0.1545832744769512, 0.10221597843713338, 0.1137731042540362, 0.10374204856493782, 0.14379900880157948], [0.05310868528941947, 0.12379053123896161, 0.013750891366432753, 0.05452568747944409, 0.016740886569623987, 0.05652195556209453, 0.03464632637558445, 0.037675296301923455, 0.09824781152870386, 0.11140327254730849, 0.03537939591032844, 0.0646010460332036, 0.057481526652531284, 0.05388492387869666, 0.017081134945094105, 0.019568559232979052, 0.0404123331029569, 0.008666446252215293, 0.04615143099198899, 0.03230775871704663, 0.045414013908274715, 0.0733582507218084, 0.04972199826771694, 0.09977385101299133, 0.03791471793045921, 0.01766766526646191, 0.03690326353535056, 0.08936535146447921, 0.06746600036539378, 0.043572307894787485, 0.03145589001266466, 0.01287687793298955, 0.02714952401396248, 0.007144646106978819, 0.03653977779791721, 0.039921029425796964, 0.03628842818040041, 0.02245230953239145, 0.04348909542445214, 0.002186627764697938, 0.029709222951843858, 0.13056462540501548, 0.07562142766771779, 0.0631440119186957, 0.02551406610666985, 0.03685795709550862, 0.019796196514019565, 0.03171272098927969, 0.0267351164122022, 0.06032638266802796, 0.01379573815352013, 0.07402042648003948, 0.04662211541266692, 0.042738612711189256, 0.03807761503623859, 0.05726609506734437, 0.11150419697045319, 0.026328049847976338, 0.016908267204980218, 0.08358500357116423, 0.04097830353965683, 0.02166146547683785, 0.06538157471485677, 0.038958570183885675, 0.0766815018329409, 0.03322873429785813, 0.027843750975725633, 0.051391820964072986, 0.009331081152683305, 0.012538199080154301, 0.04574933059273228, 0.1288015506560764, 0.008723993819477338, 0.015333933537946114, 0.022813037353297396, 0.04354321187542331, 0.038076764678642634, 0.059662276368227705, 0.0345232198765922, 0.048489431745462844, 0.04830080557674651, 0.04380100429238331, 0.014728714501665486, 0.06106687559475822, 0.0677611127555851, 0.01733229304062984, 0.03590952109305128, 0.03690559244264038, 0.04373715469433416, 0.01885994130955829, 0.02929704083550361, 0.030815769925773628, 0.032564375189042864, 0.02438483909974175, 0.03064755425457993, 0.046510178475610675, 0.055033151781366724, 0.01276961413227142, 0.0553472631520802, 0.053275343886907064, 0.03034818816118904, 0.06541788728246767, 0.017558175980323748, 0.07461022991206377, 0.026590913766995076, 0.08049255176897972, 0.04385285312309862, 0.0847549960317631, 0.0771009809367599, 0.04549910329402455, 0.052438902278100295, 0.01972525102657176, 0.04872357885863993, 0.04183796527344854, 0.07171156771120525, 0.07130780873159248, 0.023816330996792645, 0.11898073247603833, 0.005316004286625333, 0.026263311587935014, 0.03535741684778083, 0.08849603319240194, 0.07322105203544901, 0.06603720808221449, 0.018467702377106876, 0.009634523791441274, 0.01983297831048408, 0.031109273531323964, 0.031977352656183705, 0.045764882177595174, 0.02878088335086021, 0.07206942270239515, 0.07068005330379933, 0.011843637912534179, 0.04807579023162684, 0.02467485125957718, 0.013872043383608182, 0.025862555672985413, 0.022919333968011123, 0.0318666931707412, 0.06142573799156855, 0.027703689035749244, 0.055927934816047076, 0.03553444061488394, 0.040466411249531854, 0.01842810712274044, 0.016672712405242266, 0.049555749527268836, 0.01840005298295329, 0.08686373731301678, 0.03897977549762976, 0.04653295043915991, 0.04054542938848177, 0.03056771065589161, 0.05374720042210914, 0.04412271142486603, 0.016837593678745533, 0.041785457607118354, 0.019920069100936095, 0.0541707321310476, 0.04174718768486092, 0.06447093366014381, 0.06998217784829679, 0.02358437106463938, 0.02539020501107218, 0.05416204469398626, 0.011269416708889748, 0.030185898180089654, 0.07174562798031876, 0.03303208718857458, 0.029166443911831708, 0.0742842901437994, 0.0378574988233947, 0.03809892377185245, 0.03959503603137789, 0.0948210619390011, 0.030686850734655897, 0.0262569013472286, 0.019800812193763354, 0.0903403745483487, 0.04683032661916749, 0.053578025225790284, 0.019167565830772924, 0.006463865424701644, 0.09385073497410744, 0.048048302996903665, 0.08785654129760881, 0.04014087367742773, 0.030782983277834235, 0.06310888295692783, 0.12201262502780846, 0.03665624997548519, 0.06123426963665313, 0.011224538320675494, 0.03239285576367571, 0.021165804674608574, 0.057331825411247636, 0.022747487040056337, 0.010905874472471976, 0.09907982131886868, 0.027957400119292642, 0.04051091712749293, 0.016054033204132033, 0.047660137736989606, 0.02891348934011354, 0.03996852687710235, 0.03165372647345066, 0.04342991130186185, 0.022811041694254647, 0.02403266273529059, 0.028853403148992412, 0.02380104179704382, 0.05483224905366379, 0.07802992383198393, 0.018935828064117703, 0.05864622927601299, 0.029936992383051305, 0.09937576108401823, 0.08911093366482566, 0.03782824192556643, 0.029924869041649566, 0.027597513079883593, 0.008919535846930117, 0.06648908504435132, 0.00793081750499926, 0.0437574407025691, 0.02359296465593, 0.06267829940864636, 0.01495224842426157, 0.0691883115758819, 0.02223484015332595, 0.01387702008228629, 0.042882158436001315, 0.036698078376150904, 0.04485284684286003, 0.03370576575698872, 0.047206858833951336, 0.042463227085048155, 0.06021967045061531, 0.0792466476559639, 0.1305627101852048, 0.024744327773430178, 0.06272360967892794, 0.06837327829411916, 0.0340881547139537, 0.01897283011086045, 0.09941710684929164, 0.05113752573848732, 0.026807069305270433, 0.012519799563432894, 0.049324639952711524, 0.04728334122187188, 0.017663461358977423, 0.029066867803433732, 0.017780770487602682, 0.007420251983398151, 0.03213414021076695, 0.05063326751452781, 0.048073143397848454, 0.059242705333857774, 0.06676614074216736, 0.014500443282867632, 0.01811117846368542, 0.047981197525176315, 0.06261327769607306, 0.060173019526466254, 0.01533777355366657, 0.0076178830368594545, 0.08443044288264168, 0.013308216077876429, 0.034761817960609356, 0.09365902147105626, 0.03009520677639352, 0.02031746763555754, 0.05883550661946497, 0.03517714103743915, 0.06529067072176165, 0.06923485141728195, 0.032019793927188844, 0.03263153428692491, 0.024662921355376323, 0.03953076125453076, 0.04780341150058855, 0.05086377187962494, 0.033828558159932014, 0.020155654544191017, 0.05646218921268179, 0.03281917986309817, 0.029122457058439334, 0.012370756200154223, 0.09013863295436868, 0.07974603739116462, 0.006167469358432197, 0.0381733492136963, 0.04823870265916471, 0.019058254660077153, 0.05161426991464631, 0.054519064649338686, 0.01579683642053316, 0.026947824554818294, 0.029632658209471457, 0.03059534727776003, 0.007946698986474545, 0.010038913835981681, 0.052792118606908675, 0.0411009120814983, 0.03444382635455939, 0.00803742103368765, 0.04596711789828636, 0.03440487078360973, 0.018680559906868205, 0.042166781701868584, 0.019961160141974688, 0.024284866540842963, 0.028912901367631652, 0.021385673824096882, 0.0541174162419573, 0.04222560959357408, 0.0422941591410387, 0.006740362835942858, 0.03239944795026414, 0.0387406756260222, 0.05830399481759918, 0.03153671037345644, 0.028166988368837104, 0.027447321542328405, 0.049490612901506886, 0.01849453269143499, 0.05862425787434463, 0.024805501809403784, 0.027306618003715432, 0.030860287295053565, 0.03704173775810388, 0.07390172881705147, 0.054302529897540815, 0.005252301202891696, 0.0023558628116358794, 0.034990694388867385, 0.06938308176975097, 0.04050859205064274, 0.05817131221955342, 0.07116369227127683, 0.02975601751747872, 0.04900348440353428, 0.042452796797959075, 0.07468079427076925, 0.03533515050226162, 0.03234237439990525, 0.04784568423225034, 0.051896500536390854, 0.01807080946051546, 0.03296515791706982, 0.13541337973888845, 0.2074795618893639, 0.14108682772324932, 0.09478111045374986, 0.10300533245167426, 0.12657310047577466, 0.15162580736702488, 0.12303175179347878, 0.16355344394762672, 0.17244202505436637, 0.11926619215838372, 0.14186200145031178, 0.09013146237139741, 0.2158575607163291, 0.19416987204984312, 0.18644035132902284, 0.1655902725554282, 0.05824836917341717, 0.11238198817497301, 0.19410812536314612, 0.10577575153400821, 0.18293218957560678, 0.12625346561112713, 0.19907179288566115, 0.14849261500902716, 0.12924732189745675, 0.223470360281006, 0.180929773637364, 0.13094671941812963, 0.16189351527681275, 0.14079784403645224, 0.09774265315143332, 0.1620879943572706, 0.14833310018143347, 0.10209552643279876, 0.11637639359480913, 0.11899554095561467, 0.09344872267496201, 0.15284653783084887, 0.13789979470593317, 0.0717108935538319, 0.1794551309919165, 0.20914278473825226, 0.1962993206876901, 0.25328647165048507, 0.17005377659393897, 0.12636008206754923, 0.20762141072942367, 0.16002035369315457, 0.20749011858096048, 0.1194324562205903, 0.18975218006920433, 0.17457061567373816, 0.15076852433623808, 0.1681013708753932, 0.1605531065574577, 0.18024977867401418, 0.11211346669663345, 0.2537092449323785, 0.12598761011876408, 0.12266768382922297, 0.11404698068696646, 0.16681103366276911, 0.14195848256349564, 0.2004946173439103, 0.1532803427788519, 0.20551425525017325, 0.21432877097639347, 0.12018448643146024, 0.1341359740904262, 0.2523041630704557, 0.19197944281322343, 0.08073701042561762, 0.11246304027736188, 0.10933884179159518, 0.1214737970862658, 0.1185741389711057, 0.12291788048441372, 0.11770978494877778, 0.14817982130954344, 0.13097598397683713, 0.1522616450224192, 0.19005305344058623, 0.14548961163288163, 0.1762134146185652, 0.05396370069995042, 0.10366100412342819, 0.12313012514383563, 0.15324772275503606, 0.21015314745806882, 0.1354992428734418, 0.07589198693993592, 0.14195042331853222, 0.1192138223878799, 0.28002477881889193, 0.132541254823727, 0.1276302405242478, 0.08008470187985128, 0.10228441307140936, 0.1279793467913424, 0.12366242601626343, 0.23221012114757494, 0.06511963393178678, 0.13190748560572826, 0.12256238504403061, 0.13404012116934025, 0.1673407374971336, 0.17136012504418052, 0.19387600072208913, 0.10606531744762775, 0.11072220506086466, 0.16633987426757815, 0.1421728339647093, 0.07209760707712944, 0.15241795760248938, 0.17082357238377296, 0.12317727019469585, 0.17860845061800174, 0.103920447459865, 0.1395956069351204, 0.10147968367222818, 0.18681715933545945, 0.18520583128256185, 0.21857181023205483, 0.11500904156315712, 0.10259713782297988, 0.09339895760340076, 0.11448159768816926, 0.1733982100361778, 0.11480490211397411, 0.180139247508299, 0.1367911735489484, 0.19456482101832667, 0.16942455793821043, 0.24099535699332916, 0.10668040944203254, 0.051452050796679916, 0.10909872685348797, 0.14127091865145391, 0.08818982018818779, 0.1254359502044897, 0.1756033481609437, 0.14103215968897267, 0.07043304357437358, 0.13650713879014217, 0.09447838314959119, 0.11822967519683224, 0.18526596918461785, 0.10439144597659189, 0.1838743551484039, 0.13549875257717026, 0.11190162806381142, 0.14998006664456862, 0.1443154899583709, 0.12095281899335886, 0.157781844778407, 0.1653816668136466, 0.11112070101643763, 0.10721965873193358, 0.17934996244167128, 0.11140138031013551, 0.1961068181140769, 0.17627710716858988, 0.10263475274006206, 0.20055962756516474, 0.19241510169400325, 0.07111133782253151, 0.22129087077994503, 0.23175701078388, 0.13273067772388458, 0.13853059150278568, 0.15009533223365584, 0.14247127117649203, 0.18689392134547236, 0.10468281985771273, 0.11582154675476974], [0.030550377916604764, 0.028055108888375185, 0.023541165620929772, 0.03691444841904506, 0.008142634591598424, 0.025620807052379655, 0.009870045074832537, 0.025846452504817038, 0.01732527759046324, 0.041253765774590355, 0.04429548723442901, 0.0276597251649946, 0.10036759979782567, 0.08174708969290219, 0.05683886698417126, 0.03473033557736105, 0.07071045167263477, 0.03208562769296189, 0.030558764664155823, 0.03915913200246231, 0.02297531584307792, 0.021469290405812285, 0.032800789922475815, 0.02682555692210313, 0.03981666526787224, 0.0460321817456955, 0.0268693101186786, 0.036598000480162526, 0.01434368254136174, 0.05624823617718874, 0.04966698932431398, 0.06202775669554549, 0.06621652628265082, 0.022857198491692546, 0.015445410822247787, 0.015757761148345328, 0.025213476187819918, 0.03201117543804069, 0.044471767896245566, 0.03218263740681353, 0.01906149712721667, 0.04774560633626196, 0.026886342168455164, 0.06991662370461611, 0.028438976395034024, 0.016725840602791118, 0.030618169037024343, 0.0615723978637928, 0.03486476868631379, 0.04831235052176541, 0.004732168200726231, 0.03482452991809096, 0.01318208544680308, 0.01971298787412384, 0.0640779075723502, 0.03469496529789702, 0.013356700824994235, 0.05989239002848345, 0.04925723570669371, 0.06748482314569336, 0.07927280189769884, 0.08476417376509598, 0.06145928881221241, 0.08541871162672197, 0.04234919872795863, 0.021866932173349687, 0.06850493816478599, 0.04818831322594516, 0.05074660639248548, 0.04646079644801156, 0.02629866846086037, 0.039940227589179436, 0.03280514896276497, 0.04150484343089404, 0.05202841704651233, 0.05363211103324449, 0.03758348066419844, 0.017792493548063983, 0.015039077787209424, 0.048524001463046, 0.030620337065850056, 0.028158519266834183, 0.0440465163199171, 0.06579207526820322, 0.014336610592210726, 0.07143263509797473, 0.04009459430592195, 0.04847750758692142, 0.01879685205377398, 0.018158086027289112, 0.03381275376605411, 0.08203481699550345, 0.018989695536513484, 0.029256825049918507, 0.06395080975527245, 0.02798107223615291, 0.051542724963397755, 0.07521541638960762, 0.030866456218063835, 0.04471021659311749, 0.04503706800601175, 0.03406835900199029, 0.04450624185283819, 0.031306006825499, 0.003330867700917166, 0.005471694420257043, 0.0145124823545977, 0.08551275658030665, 0.022679188386386922, 0.07288125373663441, 0.03022379846492362, 0.025876893008488323, 0.041725384822535905, 0.02704161669938795, 0.03402883269553704, 0.06971121254947878, 0.016462733450856422, 0.008610079417966546, 0.028249564986195297, 0.03360308316205779, 0.044933722745026314, 0.034145641951791705, 0.05234278122624082, 0.028208077494655887, 0.09390046940215173, 0.04940569971597964, 0.01460980041883886, 0.023318356609032042, 0.01386981981340796, 0.05266441941081036, 0.03600417125609613, 0.05178927887050856, 0.047963336185221715, 0.023376211569073702, 0.04963688206888976, 0.06289142889962082, 0.016111156550206004, 0.03924789477980906, 0.05496454094686816, 0.04636390547778818, 0.013894066496211437, 0.038427533356532935, 0.024421735809394912, 0.07652247730161875, 0.031841232238577745, 0.015252480197006897, 0.052222873144332445, 0.0745503678016605, 0.05863720476026497, 0.016778961139460726, 0.012927767238579692, 0.1164625095383775, 0.03347793120830771, 0.03475451714269096, 0.03697089760774567, 0.04694219077787092, 0.04673527809040201, 0.04282974653066166, 0.065871357707487, 0.033819625574734904, 0.02192679045331334, 0.04236692217208686, 0.011526453571634428, 0.044871558540410576, 0.028791353857565313, 0.009820840205065906, 0.030147204994254058, 0.07177408814670579, 0.015559556007745768, 0.06407041523245073, 0.1086497993298596, 0.01627614699123848, 0.055369452888806986, 0.07094038530222832, 0.020140250431253545, 0.025457620748408863, 0.05163206613712734, 0.04283572584691067, 0.025022488553076986, 0.04155468894168735, 0.045370124731092684, 0.04786218193569972, 0.07608915498900799, 0.030528885319889076, 0.014838741006960553, 0.04615453364808233, 0.04251530191170112, 0.036295480019743406, 0.040262003669575344, 0.03322191611533204, 0.034905601172677936, 0.027283878598902977, 0.07669598089470979, 0.014423621901040597, 0.04463366525728376, 0.013280119803253443, 0.021034110329985138, 0.06984515536215997, 0.005445665625419709, 0.02612060664461986, 0.027785434447709593, 0.07475159611673125, 0.051000602843780676, 0.03913890345082168, 0.03290378661345571, 0.025008649174724857, 0.0254486077239797, 0.01906733088676007, 0.10155858306754982, 0.04695359782706346, 0.03271706800367082, 0.021061335179594257, 0.03899570246557555, 0.036094657731272524, 0.009844658836241691, 0.02335142670950342, 0.03103770176699806, 0.06295977160334587, 0.041050626070148526, 0.04109102954727508, 0.018020739869004297, 0.04612181786327593, 0.03511328377851075, 0.03340432931098246, 0.12531320759726147, 0.06979490765520642, 0.02403726309327589, 0.06956606187046536, 0.0734773544113963, 0.03576300677753264, 0.02846045558521104, 0.05956690991297365, 0.08570864526254517, 0.05356683268121654, 0.0171603829104213, 0.015434463425809819, 0.025908545846299782, 0.024783901960378694, 0.013526479315553463, 0.016424375428487698, 0.08797025172820977, 0.08039558035952431, 0.07106279083076986, 0.03482932562849695, 0.041981296493641795, 0.043182357650009856, 0.061249181538099245, 0.04980948167823015, 0.0247417364810263, 0.04876246165123679, 0.0601511400553488, 0.0519801956421185, 0.011618713540355525, 0.04854999865675646, 0.010052121191796277, 0.023161743339451573, 0.013038138483440685, 0.06194257154880513, 0.0340370758016023, 0.04010653761666148, 0.04058892019994317, 0.03506122044317665, 0.02175494927101799, 0.03959366090355381, 0.061510134067746906, 0.03691455950179408, 0.040170050136023955, 0.06925776510709716, 0.03207481244669086, 0.025058961999151978, 0.016712206152958736, 0.02347892863796123, 0.048047307082602096, 0.05170463764619443, 0.03257671686550302, 0.046576916225134365, 0.020609892972354448, 0.030662182703494068, 0.02323234025689383, 0.01834908706857072, 0.04117632960720409, 0.03467135829851031, 0.04250360374909736, 0.06231744901367253, 0.04357881198126463, 0.030486823262406454, 0.017728603730398803, 0.022993447229025826, 0.02897841529169631, 0.02144688233402708, 0.08016548585146666, 0.0495009244449677, 0.04478616654993065, 0.0810578327265478, 0.035720243749599305, 0.05457006312245804, 0.04033193600574329, 0.06395006281954628, 0.023994588165453846, 0.060154185254847815, 0.09943432084495023, 0.0430482616197438, 0.06650061466761174, 0.02125202404004672, 0.002746989240779752, 0.0031839243761609282, 0.08207904325137216, 0.026494444145130056, 0.0199570098606449, 0.00977472841529356, 0.016731094050731872, 0.07902203833744412, 0.019228213181298588, 0.03750037161573287, 0.07936336881210727, 0.038486912831543915, 0.03630949942875774, 0.05325134618267898, 0.016643729383846926, 0.03703336441709149, 0.021984727767806862, 0.0234768295570487, 0.05082203923994976, 0.06237145438189469, 0.05872824281874684, 0.07623000025388695, 0.011490222400865488, 0.0369746974038501, 0.008624546030806679, 0.019902117745650393, 0.04994798271406082, 0.04352315952400527, 0.027507488172681584, 0.051388182046432654, 0.04276876976232856, 0.09940220643916439, 0.008654359299989959, 0.025687916354546626, 0.019854608803026138, 0.03549841149980503, 0.019072327695246187, 0.040232689315152746, 0.014617286055468985, 0.08004010024089968, 0.04083682242180071, 0.05241428404265354, 0.08125366778263161, 0.039919037597193834, 0.021431510779826392, 0.031048310169529532, 0.054003832215863856, 0.1268700208334673, 0.12738016644312491, 0.17456264835932564, 0.1080858743479175, 0.18920306356683855, 0.12891969673575895, 0.145159718850928, 0.1223704876798776, 0.15914379589019284, 0.10719575678869601, 0.084715711043006, 0.18210486058265934, 0.22536765363427902, 0.3236110754791768, 0.21478450136078944, 0.13361452868388546, 0.0977130285314014, 0.13536312437105563, 0.10777265930007543, 0.17281530905635129, 0.1142424097164504, 0.11189068832825269, 0.24297256863886313, 0.15675700299682158, 0.15656791717535065, 0.10527662226870176, 0.21339654922485354, 0.13016446703864684, 0.14707241057147905, 0.08438261601352885, 0.17679207147129122, 0.10460747511035974, 0.32518940046429634, 0.1411587174140638, 0.09768291361509793, 0.05593589063914073, 0.1838788137801232, 0.14132241508172405, 0.11552543845027687, 0.1523229780216371, 0.11874800262552117, 0.12382989283651115, 0.22433515097345078, 0.09634333993158034, 0.14718969863268638, 0.10443465333552131, 0.15374981678060948, 0.14773624107962655, 0.1427554744746416, 0.19746322274929096, 0.20552913267766276, 0.15280351433302128, 0.12167089618742467, 0.15929166618133747, 0.10523603493047338, 0.20242425492934643, 0.0975318027720336, 0.19929933632093094, 0.14096734865057853, 0.0730670070756347, 0.16922653953154243, 0.14939365698204887, 0.22622980898426426, 0.09087892669823863, 0.11219154637787612, 0.1952254646007092, 0.11155563211368938, 0.2787674753175628, 0.1738929955829536, 0.10802621908125379, 0.14261868181488208, 0.10655493956179389, 0.16191046114169783, 0.0916362812201823, 0.06705630420436783, 0.14536982612504115, 0.144398441958812, 0.12154026287457637, 0.12122449675394643, 0.11638826795763547, 0.1878116487134849, 0.14086009634117927, 0.1889673995995714, 0.13474464626802554, 0.11344547143145917, 0.19668667006396479, 0.13803704701844724, 0.11013379590886255, 0.15442918355186142, 0.1405917817065793, 0.16898335258085884, 0.1401233802279157, 0.1952232429457288, 0.0996630976817781, 0.1494323903875005, 0.11178939618290433, 0.12568873623686452, 0.15539270765598745, 0.16329537956945359, 0.12055969331413509, 0.1641639700580028, 0.14048362541342937, 0.15603185481121465, 0.10122788589327567, 0.15515701304520332, 0.08188690073908338, 0.0939684367227939, 0.2604529177469592, 0.23921285425463032, 0.15173445395644636, 0.11111181439651598, 0.08968847202918223, 0.12552968872290465, 0.20752211041267843, 0.0734028140563638, 0.13981927396549335, 0.1495595150176556, 0.1307711627094015, 0.23665093366176854, 0.15304029678865788, 0.15041630775217088, 0.1343904378553552, 0.14141630681772388, 0.15826454145773766, 0.1262217112666657, 0.24932800341517697, 0.11935250728481239, 0.09376188409664939, 0.11391554298179765, 0.084624148214296, 0.2503398829890836, 0.146488988651864, 0.1479679826767214, 0.1573996435129835, 0.09869346785689555, 0.11226784107425522, 0.18752145460776745, 0.11746358727255177, 0.21422636034267567, 0.1279426741624071, 0.18096463063791876, 0.12488051347674863, 0.13011845579791453, 0.1337918627165979, 0.17927474792926543, 0.13773048927466716, 0.06376552756034559, 0.09140303042987663, 0.17532616222818054, 0.12704232166851723, 0.18966539762914184, 0.08700485836954848, 0.19853741591495855, 0.1216071883156415, 0.08287064956441041, 0.1546782234142865, 0.09488354407010541, 0.10892049649790411, 0.10870630597515453, 0.16252277989781674, 0.15162709439473768, 0.08921967218479804, 0.16779703478659355, 0.08459889029543247, 0.2034878301163835, 0.11223486864999418, 0.09638039560447778, 0.15552096609627047, 0.3868461177954751, 0.14303770126594653, 0.13054807790585105, 0.18398298641606686, 0.13112682668912795, 0.13432630097433446, 0.15229308527083169, 0.11956305888992165, 0.18868370191945186], [0.04119457399112083, 0.008251760943582463, 0.07467400673176013, 0.02776023781588001, 0.09279388603904555, 0.02974060957410163, 0.020186022269509492, 0.05192043312314538, 0.011095544435985146, 0.0890653897377272, 0.042951232753694064, 0.013458970690055961, 0.03354269628142638, 0.01940625393012118, 0.06345428135846892, 0.056323469841792706, 0.024094899718259132, 0.029184437401953246, 0.015217415395102676, 0.05064949325676407, 0.03880629871761607, 0.004751092966480722, 0.04914105464253695, 0.05761337038429995, 0.03333087297036283, 0.04884141084227351, 0.03499255598252339, 0.037084140724712805, 0.07812403007260255, 0.025897163694964784, 0.019856336331295393, 0.04644833219748351, 0.02833482099606866, 0.05049986096339361, 0.014316588884309657, 0.03526956954550359, 0.06531682496349658, 0.019344911354804234, 0.06009627283821183, 0.03624202240438711, 0.0316346547145757, 0.050715771353533196, 0.018413499741244222, 0.0502050741605701, 0.03115723063538392, 0.02349766331814951, 0.04149969148960325, 0.028588193085705562, 0.060237822903981136, 0.05953029091019304, 0.07375591930242316, 0.014502537575730634, 0.0531065785476277, 0.08630329803113015, 0.059304926995067835, 0.08508350985545306, 0.012750366173173874, 0.019905618767464356, 0.0631916702484652, 0.053940564844637155, 0.03445892594754696, 0.014291665171303097, 0.02989327174521262, 0.013614135095849635, 0.04021144186657283, 0.04264659789060393, 0.02800606585468256, 0.09883798268293181, 0.052945523883306214, 0.01696757198641858, 0.019045202437067227, 0.05317205225207633, 0.025281047057961265, 0.07064593174765188, 0.024640695229473136, 0.0605789925001802, 0.02085353957579261, 0.05668424745841373, 0.03173969877553323, 0.12375613389116143, 0.05913001763063574, 0.028470552624053055, 0.02478765962164729, 0.03557139286591161, 0.042556915807748036, 0.03379446341686192, 0.018060656880298932, 0.026780742693752534, 0.05664755567728032, 0.10218387935310604, 0.030678255228145473, 0.04815285484636984, 0.02480462272351067, 0.06261601646040237, 0.059300426228512684, 0.06599313504393063, 0.05401273415754399, 0.017208958630480112, 0.029989837128068172, 0.0430651921628704, 0.04561692378633926, 0.04775948018857068, 0.003881850824390929, 0.004127595072326761, 0.08204048604614313, 0.0360993959850842, 0.03317460252512847, 0.015131521617032349, 0.04009216580720198, 0.024177794262105902, 0.03962742622881647, 0.1177082680946877, 0.049492344260215766, 0.02684047265398887, 0.012944107894004594, 0.016396560691176884, 0.052854489655263966, 0.055534123488131075, 0.009643048434818705, 0.005827167835612331, 0.035633442157338706, 0.053408926638263854, 0.04456415809991379, 0.04114910667281478, 0.05752918498230077, 0.05210305316253536, 0.012227540850759515, 0.04774760582574433, 0.049357175706855716, 0.04405295145848105, 0.07317971393105484, 0.05622324255865909, 0.01930459023212954, 0.07339986461785532, 0.04388833448531167, 0.014240295145540469, 0.057138602714985616, 0.07355138148751951, 0.09426870488471563, 0.03780360453792157, 0.026625364740949967, 0.04605060999071406, 0.010650957758057742, 0.0530401434028341, 0.041038066058629946, 0.042847998575457645, 0.02115224683356862, 0.045031889251643614, 0.04209643567822153, 0.05201623624851627, 0.022999095212247585, 0.048188125534403714, 0.03267805880656646, 0.029091920793777513, 0.054493672665088415, 0.026854605060972037, 0.19001451921799492, 0.08675851513661685, 0.043526028523281704, 0.09879859044186531, 0.03894166645383643, 0.018063949143153527, 0.06111967820493926, 0.025499608112318863, 0.011418256101258581, 0.09359053321062558, 0.051003962139328646, 0.06685634759525139, 0.0037613806254681082, 0.038781956273822055, 0.021848199408381216, 0.007674578810110689, 0.0403998228871534, 0.05325437606041951, 0.01919484813697636, 0.04008430191465924, 0.041747934620587096, 0.023963084714787624, 0.028071399748085007, 0.04162684676327533, 0.025339823238731875, 0.0485298352225894, 0.01856883555921095, 0.06426658736722124, 0.023612565015472715, 0.07242320976670712, 0.03242429218164856, 0.03777872200214094, 0.012596013820579937, 0.05363946547731758, 0.014542541729526655, 0.02173542935070732, 0.016782833713917963, 0.015936692474379895, 0.06187942675164631, 0.04316176903704482, 0.005515735378609069, 0.05679842520264849, 0.03437774744065058, 0.010988367777768402, 0.03054454607228118, 0.050519932467009754, 0.02533063209886032, 0.04493127892454786, 0.043703013985988595, 0.012302453716045186, 0.11831368439860883, 0.024184708205622532, 0.04113190033803544, 0.06364693714966697, 0.018876611382790634, 0.0258155370266327, 0.034730032972630956, 0.006874141897330242, 0.016971844841816255, 0.03727719488163148, 0.047733490655739466, 0.06796729765952596, 0.03446253805210994, 0.0807761651794276, 0.03498580674791048, 0.036432671045223554, 0.04877306430810883, 0.02281142856865641, 0.0611389797901915, 0.054537519707434604, 0.0440480025304902, 0.0498916752516262, 0.0416175541167538, 0.04828716921169431, 0.08311588196985184, 0.0043677157560934226, 0.010599370354846602, 0.021441048574483684, 0.03160629030917922, 0.05463858202640569, 0.045198046061540806, 0.0503983466525472, 0.017051378174895243, 0.0755292060033929, 0.033961179470943834, 0.021423512821896903, 0.03885355485122531, 0.09271762964706268, 0.08825815523103361, 0.05385884241531453, 0.02412010592618777, 0.0409653949581327, 0.035678457483769424, 0.04332779561199489, 0.04927723443195705, 0.016111817301040696, 0.023136052580910827, 0.061443940240649454, 0.010844100972697621, 0.03669714374888328, 0.0269112974825886, 0.04409497521156746, 0.014066397017168423, 0.046648828898586576, 0.0505629827779147, 0.03153708001087991, 0.028578477175605875, 0.012496280664157484, 0.06369395196558007, 0.010789153316328603, 0.04506990636488603, 0.04331515899168388, 0.03832313472465162, 0.006638245709661034, 0.03007341157494774, 0.020082556349675984, 0.027176258567300056, 0.022904778297449795, 0.06921834222251369, 0.09181383741839279, 0.01331092419868876, 0.021648997395870187, 0.05585928950759192, 0.047007323573193247, 0.026736639011951707, 0.02470197460253633, 0.03548789694304428, 0.023887240095064047, 0.052700915839523084, 0.008779584032092846, 0.030307834479777567, 0.04313381831912745, 0.05386903521514708, 0.07228771945641888, 0.04619482987289948, 0.05710551920797556, 0.06441199085524967, 0.05281088393061392, 0.052168622627974524, 0.008895536227482221, 0.036027575242182905, 0.00726611509303292, 0.05051617480574116, 0.026224352186545733, 0.03913512663735498, 0.04352308291521284, 0.008713570235657596, 0.028777096961294452, 0.012586877264472987, 0.03593734923690077, 0.0535903783935693, 0.04942101764402563, 0.0654197182326067, 0.003807151027309198, 0.029636921488770077, 0.030244685852179126, 0.01770128120457934, 0.0385384897010461, 0.12190672869403517, 0.04002507948767274, 0.05871217795497468, 0.0494675268419087, 0.049812879278174335, 0.054132446887031685, 0.02962993668212045, 0.04326894090721204, 0.04051851288926217, 0.01668045180849731, 0.06695816068038826, 0.014404103895949741, 0.04896776172362509, 0.03418316876876258, 0.051239626106595805, 0.03364181273706979, 0.016806214717367006, 0.02337743156409312, 0.07330361333104872, 0.044602669339867375, 0.028301484680043596, 0.03744174673732731, 0.12006129949323593, 0.023300207986105836, 0.10418761296257859, 0.040379188308912906, 0.0356292171824363, 0.032274805444983706, 0.03649666619997832, 0.015308404615479372, 0.03871321903481599, 0.04439666063614911, 0.013853497352571258, 0.06032563956274141, 0.019054150344022823, 0.11511073973510536, 0.10964665591957108, 0.05135758832517651, 0.15139507700599011, 0.08527146186679603, 0.1271427404736319, 0.18451239913702014, 0.1882606222023887, 0.12066839352971125, 0.09779497695666167, 0.15510432151777132, 0.12127449165188497, 0.14260355923925677, 0.20226706900904257, 0.1906169554398906, 0.0917408905262428, 0.1075386654044832, 0.2125016819205015, 0.09267374813075989, 0.10337707661693135, 0.08565468969003809, 0.11702475678776542, 0.19890133832250873, 0.12596951512199256, 0.11154285376711238, 0.13448578515841117, 0.14651995392576342, 0.1194882044388402, 0.13131791966096049, 0.0989321731932221, 0.15568426539821012, 0.2023436011926782, 0.1325039769853315, 0.2327209179319682, 0.11912839592344339, 0.11003455687915126, 0.1426754029647958, 0.15698037891378328, 0.1691746294137932, 0.15308292192076484, 0.11232316028326751, 0.15450632860583646, 0.146575250152138, 0.11207906934883326, 0.14316055112548415, 0.175699369621373, 0.11076935011172488, 0.2461479877632472, 0.1707785723791007, 0.16253839276971357, 0.12250269913384992, 0.13277180132365998, 0.15416047055154078, 0.16078866327241545, 0.13875926874818342, 0.12754923438713436, 0.16547212647574563, 0.22643191830044795, 0.14280686365260234, 0.11461132701726691, 0.17050425161517438, 0.19101365108884152, 0.1982687182363964, 0.1574816149208815, 0.060629470033511046, 0.11722045394802287, 0.13272097905076322, 0.15175097081209385, 0.0927591745951964, 0.10476289136755852, 0.17908754668408827, 0.15774589993299978, 0.12860553939977, 0.15468945426325645, 0.18254533049560365, 0.10733664801885044, 0.13644580579092427, 0.17589351162314418, 0.10201062856903, 0.0987761976918386, 0.1811229044030751, 0.16148453157755638, 0.20103455611294319, 0.1310713312798931, 0.1905252853588712, 0.19856433624461775, 0.1334740434803309, 0.11165169953939416, 0.15203181864513507, 0.24201250725215484, 0.13597787928677377, 0.10494391794406599, 0.27690110127291373, 0.21023864287041852, 0.16303290252483663, 0.15437172695754037, 0.14113256317232886, 0.13357823143803305, 0.13327384938395795, 0.14307301791925586, 0.10295248004577814, 0.14291845201965303, 0.23685322683905405, 0.11731158776749527, 0.13114846101210964, 0.23265714877315108, 0.17125610562582172, 0.12086270407082574, 0.17557169340791243, 0.12245900147864897, 0.12314524005858168, 0.14993108298269012, 0.15153779918628354, 0.09916740815125166, 0.20384350941786844, 0.14440107730127152, 0.17898335872638613, 0.09672557950140008, 0.24012143453282697, 0.1486877376033414, 0.18982554064883342, 0.1555075289140786, 0.18214852759434333, 0.09476883772520289, 0.11252861740368028, 0.14872593474724602, 0.1694206508897966, 0.1648823307046006, 0.1513959350244653, 0.11058232506677029, 0.09184106418322172, 0.13692119399145727, 0.17767242907035738, 0.20691293261704907, 0.1813910964636072, 0.15014036288184507, 0.11442308389251271, 0.16437462891542143, 0.10048422136253889, 0.14896841689703927, 0.1475255056134155, 0.3073833107707962, 0.09534763247375527, 0.11542011668244678, 0.17590034512742875, 0.14423485154346113, 0.14956616466083836, 0.09035061714389632, 0.20298115488502289, 0.09065306865640226, 0.10879319566752642, 0.18224217418220737, 0.12665995952462958, 0.17856245469902793, 0.1425146317530063, 0.15110266124529226, 0.18706866600100072, 0.09834540346937795, 0.12117079399045437, 0.41452720340701843, 0.16255874006498247, 0.17156065621924016, 0.14415286481380463, 0.25757638016535395, 0.06036008287581706, 0.16671200913767661, 0.20485889767446827, 0.18170681661896168, 0.17147358266576646, 0.09740764290214547, 0.14115811986548288, 0.1143596364906238, 0.14093793087428616, 0.11141834915765833, 0.14520289556634042, 0.12830905571219423, 0.23302111714597673, 0.15884469984279526, 0.11263724867134325], [0.02049163006426346, 0.03703946630740839, 0.058366373526833715, 0.026703059463010683, 0.010888964996763296, 0.03943821400283806, 0.08383545303537, 0.04798565615689562, 0.03288126362848186, 0.04546694292296325, 0.018954003500121257, 0.047263782997165, 0.0173018965870142, 0.06744748402026392, 0.00522579791234626, 0.017808529683538986, 0.03544233769418732, 0.1120280861974724, 0.013691215032351114, 0.07228619494144956, 0.012867552727731246, 0.07477266353464897, 0.01811279873964527, 0.04926370531921426, 0.03544262880759855, 0.07616741087047324, 0.04135658626534766, 0.04801549145110673, 0.004228963826467554, 0.016795230931752635, 0.030343072609074657, 0.06080021571007468, 0.06463769567950119, 0.02603281871415675, 0.08158366781689468, 0.050850242766882145, 0.05337074481611771, 0.09843614658400898, 0.052672329268628554, 0.013801603514190405, 0.030458615905034448, 0.06716478991532518, 0.050947915146788286, 0.03855516743515769, 0.06830943252650962, 0.09496802824639505, 0.08438646943578798, 0.006025401225704099, 0.02552852218580102, 0.03251934454085366, 0.038192654629388166, 0.10057569226069797, 0.046113632213804996, 0.012889668728495318, 0.07705283231071888, 0.0391952300654544, 0.01797879272471032, 0.028552939634649988, 0.01031695299917051, 0.05909893361310806, 0.028917593656167872, 0.03262093546049249, 0.014402045992263144, 0.10717802951412816, 0.02984284975325629, 0.015130404086272805, 0.04801690871376665, 0.045333130345229185, 0.04601168123284175, 0.027424396361194314, 0.0649667764082551, 0.06994698376905534, 0.013301675602222883, 0.03388096623483204, 0.029624269546700582, 0.04519108998318834, 0.03342662630001864, 0.005807580403803338, 0.04176437869788178, 0.030838109049645644, 0.009583309856093219, 0.033523624522551414, 0.040249481962452975, 0.041469300781647046, 0.013133595911635747, 0.08873646222655812, 0.06663766013638628, 0.11511979489437035, 0.03235788768037193, 0.023814138070109393, 0.08047979640504045, 0.015012645838601936, 0.046146294372456695, 0.038985559461458076, 0.03523779221840444, 0.05725869465799582, 0.05953342420980335, 0.027360000925499107, 0.04053931983728563, 0.01643992701335059, 0.040008673714774276, 0.0788791093134111, 0.046489386849345705, 0.027684439161431887, 0.034311718322456844, 0.054234773251077825, 0.04728290455175504, 0.05085256401329272, 0.0827701541505033, 0.03709140323823498, 0.025120245202654795, 0.027216395828872923, 0.015425461892699523, 0.026475180864274025, 0.037465307771438555, 0.049615182628434513, 0.02957200702850617, 0.030922673665167346, 0.04381375199544334, 0.02658235848010067, 0.03058448989665316, 0.05801458978244375, 0.11585752224369396, 0.03665652576713793, 0.037429213538886084, 0.037042779637680906, 0.07567454820438739, 0.013813242304980034, 0.040762814497875596, 0.03219676789857688, 0.04568729279262405, 0.017901120985287334, 0.026990390315111128, 0.0342856521808332, 0.09818640958157279, 0.011417109842201876, 0.008808131340981252, 0.0514836902279527, 0.05409162972242602, 0.030004837129625584, 0.04916167006857934, 0.06808973383158445, 0.03528635453192457, 0.01092423951523679, 0.07444859302091984, 0.02293516709018619, 0.013600909545446837, 0.037522335356521996, 0.06811822464148845, 0.06276457623067884, 0.05698711648883839, 0.02661698948471777, 0.006464393546564445, 0.04032294213351223, 0.059896013624365294, 0.06285596668960587, 0.04502527408241745, 0.021105423539636597, 0.01968755375503773, 0.02992337325497741, 0.05820479792272372, 0.024755928259823593, 0.07790707397244631, 0.05213935040838776, 0.09694842681769403, 0.039326978036232536, 0.07698258204806237, 0.008337511080166986, 0.0328094313942617, 0.017195582735322176, 0.030512035215994528, 0.03766037290915847, 0.018869515493391983, 0.046343726721862634, 0.096094828669823, 0.09662663924597925, 0.05235551743798199, 0.0455566709710946, 0.05248079579623957, 0.05115590418779081, 0.08399426306207335, 0.11066282558585368, 0.06105135082297268, 0.014333003275697271, 0.030354175138317292, 0.016229789095720457, 0.025555386974085725, 0.04621276782164651, 0.009235853550865526, 0.027987612711806453, 0.00818689723664354, 0.03935995812137281, 0.03409487713548926, 0.04967545076543766, 0.051134200916895946, 0.027806224158754753, 0.049054233898078246, 0.04482530981242176, 0.0054624166166890534, 0.05666433683326168, 0.10507534798835555, 0.09447028560023155, 0.038081399510584535, 0.05673714582958529, 0.05120693713486676, 0.030872092709966728, 0.06395075229867812, 0.033203139300307924, 0.03555383030024748, 0.047570892324250554, 0.01794893827830111, 0.022069413042176637, 0.026471030582944234, 0.06834405203980785, 0.048807649347450466, 0.01298206180499326, 0.015327220692509606, 0.05743489871101995, 0.02778165571902308, 0.06434048420839733, 0.04223135908344581, 0.06867233603712052, 0.09098443232717053, 0.02302600979624737, 0.02349980836433749, 0.07314576857512997, 0.006310932728792391, 0.018124247923673644, 0.0646264418478935, 0.0927601934921357, 0.09941224219097246, 0.07045401140086113, 0.020403031995820425, 0.022093985312347932, 0.03597415593122283, 0.025803503700562065, 0.02598027082821054, 0.028103267090515267, 0.041897191530874664, 0.09546993841086665, 0.012787315551371825, 0.04045487396539219, 0.04621567129487953, 0.022185929269800266, 0.024681165739293062, 0.011206470136981339, 0.06016771819803023, 0.10441577692906703, 0.023037278949613535, 0.07215090381402163, 0.03844319602414485, 0.04498909941063293, 0.053192062468658534, 0.027321079828506036, 0.028858905575508555, 0.03693479954475357, 0.03610648612882342, 0.013996121856654364, 0.027767793358033224, 0.04729606211185456, 0.021539971592926213, 0.04081095546303738, 0.028408223710533594, 0.03881518533753772, 0.043855040304122433, 0.03919912562254937, 0.06205573805697984, 0.03367710257730177, 0.010499714764826482, 0.048650310209561745, 0.03435637741800278, 0.1054952101361367, 0.004186139990305228, 0.030556703887639508, 0.03961328424573426, 0.026018715035470746, 0.05202083660650158, 0.017593161300605824, 0.08062022798244031, 0.022158564609144966, 0.04306510023231949, 0.031212071039443536, 0.020587481070129622, 0.04590943530802766, 0.045690345653002305, 0.08304514907180302, 0.1098936962925138, 0.04385399842454542, 0.03104770304484954, 0.05510627487373929, 0.042673843807630965, 0.027316431590025465, 0.04297131574862907, 0.10980203387237365, 0.07428717829527394, 0.04203394588623797, 0.058051526711712924, 0.006182743715227492, 0.028719467997190454, 0.05187701125959716, 0.05385064527452473, 0.019048948607016957, 0.06324700094879636, 0.04041714413512138, 0.004914794943385548, 0.06471229732156762, 0.05135997851950027, 0.03321054737053571, 0.0167214164450284, 0.04262899702054359, 0.04065410279098057, 0.03595882651185797, 0.00712993290958806, 0.002773107093338284, 0.019099066079023386, 0.07953442092384062, 0.014148539837239491, 0.06426940657078259, 0.023787434160288785, 0.08113036593121868, 0.013370859087444844, 0.037367830743953105, 0.030438176679214647, 0.02209187282489673, 0.09132595432381477, 0.014550559797264157, 0.06931805622673805, 0.015068635374547975, 0.058772361822306156, 0.05400503114346535, 0.03523992960371318, 0.03344793886607213, 0.02495110448029253, 0.05933598036907854, 0.05335762939085403, 0.04199821554544953, 0.05548510535229599, 0.04667612461132869, 0.04556039798884623, 0.043080720765095566, 0.06727001975260435, 0.01712342108329458, 0.05122303647259551, 0.017083017606168024, 0.06216986983593914, 0.04578152926818979, 0.03015843967366363, 0.0469654185637351, 0.04488917090178979, 0.012553932610899212, 0.10225442839005303, 0.058344302533735196, 0.12921131576501554, 0.17938544763432396, 0.19234213948009476, 0.19909434651415195, 0.13713871699667748, 0.18520255242624592, 0.21439957282235547, 0.10832831819331455, 0.09584745887907282, 0.10594592264462864, 0.09265045905786176, 0.11827377887863307, 0.08241825166248506, 0.16239530286721646, 0.13920660280892927, 0.15055971941159618, 0.15949097161571826, 0.22560884875635948, 0.15394360638193547, 0.10530691338522781, 0.12369254859344614, 0.17523223984866373, 0.13413851750233483, 0.1304276029188787, 0.2515671711655394, 0.3176855079589352, 0.14640841152398817, 0.14563184351690356, 0.13489513657987118, 0.07310449175776974, 0.13887949858702, 0.08393729676402385, 0.10712017455408651, 0.24922551617266672, 0.18525530524071188, 0.1017458379388817, 0.16107904123923472, 0.18908612790607637, 0.18065546819519612, 0.21445059427811256, 0.16832074781339015, 0.2141003695226485, 0.2309271843442994, 0.1623840720182465, 0.3066737907788446, 0.16503145737994104, 0.21299233059248618, 0.10741264394093906, 0.08411394131760444, 0.12397616966477326, 0.089435831553513, 0.12057393488864745, 0.11828159297546072, 0.17125734668825904, 0.16404979231376804, 0.16605283644410873, 0.07132754315652194, 0.0980973901647714, 0.1046085399725745, 0.19131639371475867, 0.14388663393835868, 0.1439811691882149, 0.10003579179606131, 0.15591176286820443, 0.12372462469483576, 0.06368498873686598, 0.17431820502444623, 0.08832663583058505, 0.15178973486106243, 0.09222884256873401, 0.21540680990344097, 0.13178163268152746, 0.09090197062300098, 0.18172912509931674, 0.1843967964692462, 0.15254341216096956, 0.13742616850762598, 0.14599032670019135, 0.1433304081400556, 0.13941370701837924, 0.13438312937655758, 0.09930093727645375, 0.1828930118391591, 0.14801155775785446, 0.10158028633844468, 0.14329846227361312, 0.18158422722931833, 0.16853676928627878, 0.18938831894868807, 0.10391585859319857, 0.19882356507643578, 0.14424312529304337, 0.1697191800321302, 0.10940324680338945, 0.10077305183175111, 0.13922736379167727, 0.09491925142825612, 0.12018448643146024, 0.17810396639810455, 0.15934346904677732, 0.22462491606993062, 0.20087562351217195, 0.21330713144233152, 0.1537690762310259, 0.16573901618680648, 0.1912591975903319, 0.2212574540246879, 0.16232079315570094, 0.2056109815114929, 0.21051467967129525, 0.20058012807801848, 0.22086705561847458, 0.14580790584366168, 0.11087664072552036, 0.1283710858514232, 0.17671972212772216, 0.10700980426683541, 0.2314828432375385, 0.16624095699479505, 0.1994674926203105, 0.11999376118183137, 0.19629631762302693, 0.37182359325308956, 0.16393149301650065, 0.1323957900486646, 0.07748846820886097, 0.1978201737567302, 0.11603631950434178, 0.10898782030468988, 0.17647645856824615, 0.1322656010668124, 0.1214855565359035, 0.1293620359032385, 0.14570223167538643, 0.1250546299401791, 0.11768859495679218, 0.07069541336668116, 0.15288943875460856, 0.0840217273141588, 0.15219430589387495, 0.10855668134266332, 0.25053560313197876, 0.07715598604972325, 0.12247651424859801, 0.11171680935207876, 0.12019058449133752, 0.1527580240320775, 0.11448794855706154, 0.2153633114311003, 0.13846950365170357, 0.16674582425865436, 0.15283227327369875, 0.22449881799759405, 0.1324418319329139, 0.09977497716224003, 0.11580763459806481, 0.2052845361251985, 0.14221708320321577, 0.11062438329381329, 0.07216559738040933, 0.20565150756268732, 0.105132092120907, 0.2114712630188273, 0.26948475729553933, 0.18521859430738036, 0.13248618842372972, 0.19326409565344935, 0.12425546233932819, 0.15921887250677233, 0.23472034612730627, 0.16125257547584274, 0.10990432959290282, 0.10678492681754213, 0.18991014739919096, 0.22047688703863855, 0.26173381675635615], [0.01699939527879319, 0.07089807426617031, 0.01944295528735365, 0.044620948197740706, 0.04707616423406909, 0.07373225484644214, 0.06226297250137695, 0.0458232848905027, 0.01930540803098871, 0.08073641287703669, 0.04213516525323353, 0.027496535030584184, 0.027861125849848314, 0.027382518164813522, 0.03023568814950845, 0.024870014073507443, 0.030071586370468143, 0.0683913809517699, 0.0667692817026569, 0.048434281075793895, 0.027380719773411274, 0.021325936202981302, 0.02713804993207657, 0.027909454506551547, 0.057983777726129185, 0.010788352754447731, 0.04398516033806148, 0.03144577382162454, 0.02787878417650298, 0.02821496654031498, 0.0664219834030636, 0.030309424112220446, 0.04665791470136854, 0.05355324994231905, 0.04248688004971032, 0.03949316932008632, 0.0584333602549328, 0.05226028121767506, 0.08106064426922992, 0.07549434900283813, 0.004446552906771221, 0.033477440912036166, 0.016141225501234015, 0.031169727444648746, 0.029780268030721816, 0.07606345273914837, 0.0441363248072805, 0.017430394429773573, 0.0729565984839874, 0.045019712284087174, 0.005166418916140233, 0.045706820373813954, 0.11001074686646463, 0.039683063364317345, 0.03722243874724354, 0.027893996767459378, 0.007482194980125755, 0.0574749612790202, 0.044588178786779606, 0.007190732998893627, 0.11584433020963786, 0.045371672228699735, 0.03294916583165046, 0.036315605149514256, 0.09600168769998897, 0.09782545959516879, 0.034775772252150124, 0.01203454319282525, 0.01868010408455326, 0.03277170539443051, 0.011610863054351462, 0.013406245646277263, 0.03693912028064651, 0.055662638567868745, 0.04177560954685173, 0.06776133492108315, 0.020308148175958666, 0.03490563564663453, 0.016509863179958156, 0.06401879622811271, 0.06307697539488155, 0.06311146850367227, 0.06090437302425985, 0.03505368596844135, 0.014855079747165644, 0.09486796184172554, 0.03399389525575023, 0.04352569910547426, 0.03860225885986321, 0.041998939498537974, 0.03778676592534588, 0.0816161729275219, 0.07843981151499095, 0.054942362701460246, 0.034390207860739, 0.054602939785728534, 0.05575849148895472, 0.038670701155018423, 0.024406170817993345, 0.040682758309788285, 0.11421718244110385, 0.019829768402081345, 0.06324818455463936, 0.04325391409257728, 0.047406294503279274, 0.05865738734663014, 0.032291153761287855, 0.08642463869745694, 0.016010368107667854, 0.014938206990219414, 0.04789070338912068, 0.052367146652672565, 0.05296966714423992, 0.037618736030473825, 0.10724866282074683, 0.017313703917147174, 0.04219740989708132, 0.030543668901607878, 0.017353940770150195, 0.025175524192051064, 0.03831685663411214, 0.05199872730900684, 0.018702272753862124, 0.034000655981682004, 0.06130859931750644, 0.04460779829852043, 0.053948980320485375, 0.026782060364982294, 0.05774196207283005, 0.05252957261437851, 0.020349329232328364, 0.12728637429855524, 0.03598839367529558, 0.06398630643924398, 0.032056363134254376, 0.016335292809432553, 0.07166069947303304, 0.02686272176252979, 0.016188803391771454, 0.010362495011049173, 0.016352721309709935, 0.031009413970394, 0.1017049977916383, 0.04695961161726906, 0.01496686538185684, 0.045989771118207325, 0.03295653176704242, 0.023194778965966358, 0.021195636138380058, 0.05052331857563508, 0.06461820640270749, 0.03486365785882358, 0.020458295663458206, 0.06049187298143103, 0.048425930717419234, 0.04119011918984113, 0.021854194046388713, 0.07958335095956441, 0.035339249072656516, 0.032094928000362656, 0.03368357602026194, 0.02743338065732631, 0.0693643662417608, 0.017148464497539307, 0.04306245722898072, 0.017056514794427543, 0.02527261434513475, 0.024888275694402478, 0.04680903703575173, 0.033606951906075405, 0.08857471042222555, 0.045686779513714776, 0.1151523229876353, 0.016909904717918367, 0.02834820263688603, 0.030943402089178566, 0.016138634208830136, 0.04734561650923664, 0.03235847756807362, 0.06708648806858448, 0.05148647878799708, 0.04331910817493354, 0.03479411622749702, 0.03863918812825315, 0.0675189983279955, 0.05869450047612191, 0.027295312461172862, 0.022465331111884406, 0.044983062637789596, 0.07184762492655747, 0.02115109578646239, 0.0110101658520439, 0.03298355168813179, 0.057453035842627294, 0.0037102387502654308, 0.03674523491832999, 0.02310409713836928, 0.02970462450907836, 0.07306332985359816, 0.03705601763701247, 0.04553239747521378, 0.010239770598409158, 0.059464208165844606, 0.038794328593799186, 0.04592117943590687, 0.017795609610695994, 0.02827090436532613, 0.01949805041564809, 0.06625601811514747, 0.0650934337247764, 0.07093625608831644, 0.02235111697847324, 0.09162570920682724, 0.04331384515089374, 0.046798959149107824, 0.08876980237302282, 0.04626397696894504, 0.03138157948400946, 0.04313521642958926, 0.026797680897758375, 0.015763129509474724, 0.046121063266670516, 0.04092222590359949, 0.09627505851488921, 0.025791679133450793, 0.028585301103791403, 0.04288542963143799, 0.028860876336693767, 0.02822496015728722, 0.04329298457671558, 0.03901912560386043, 0.03297305245312952, 0.044092324547349446, 0.07187642983251041, 0.05000393011517102, 0.021870184216588255, 0.04242158637592389, 0.026878043521015395, 0.03544781522284593, 0.040421361449144544, 0.031887046211669524, 0.03490270536032415, 0.054284940518799334, 0.07077003033050606, 0.12195254075190715, 0.02151472899582117, 0.021352944632751808, 0.02890144835316366, 0.03375311382114887, 0.041306304084437515, 0.09394562262440882, 0.016978186134609486, 0.0424927827571669, 0.024916015738140673, 0.03762904374349502, 0.04397689807979811, 0.021917277556513588, 0.03795537421660077, 0.13589710297603763, 0.08451395412726749, 0.0032389517535545654, 0.08450224830378449, 0.033084035610720035, 0.024263013882802862, 0.0212770942673688, 0.040217164543367205, 0.014940850951168087, 0.04826250884141173, 0.062340581038546186, 0.033801430986533244, 0.035422224055735335, 0.02006728247168564, 0.06390789734019388, 0.0634453640950303, 0.013979341658282907, 0.038984379686054685, 0.047617895648844784, 0.002539860612277182, 0.05146879747870469, 0.08442257515965931, 0.05570997131027042, 0.06043628947208486, 0.10786066748081677, 0.058669127644069737, 0.061759882561501965, 0.009314401503351909, 0.017922152014028643, 0.020203665274405674, 0.08333367310584554, 0.008284401077206337, 0.0989908938326182, 0.028803456131549134, 0.009678564270988349, 0.06667457025257811, 0.059559904038906104, 0.056926549577544776, 0.06716107438889242, 0.040203938035354506, 0.05679664787866416, 0.022367850253959338, 0.12351487748204701, 0.022478812344131932, 0.08005903027350865, 0.01585231650800955, 0.0534635218941877, 0.020966763540561643, 0.013205156184642786, 0.07620806715661481, 0.034151632759359576, 0.06014396947237754, 0.03461873571899149, 0.02555965599904378, 0.024728883440876682, 0.041209428435972625, 0.018666684139339675, 0.04139799331765502, 0.06994005833421985, 0.00882642935105269, 0.09798011742532255, 0.04176762691068073, 0.030491678344626582, 0.03376745881753103, 0.03404277932619856, 0.03458025512255488, 0.09248583442381314, 0.012886604376798196, 0.05331208163331594, 0.07141993336019016, 0.03329008261883452, 0.033793199371786854, 0.012395968153742293, 0.04066520723544302, 0.02617518657878522, 0.04130001450257917, 0.019077899069675518, 0.09078873516691309, 0.05431100282998336, 0.02990177149073251, 0.03375075043990247, 0.031534369974847765, 0.02261898153641772, 0.03241365888125954, 0.03933478064174133, 0.05191347704479291, 0.0326693139129108, 0.059328511011816805, 0.09019494041680329, 0.005976207847256334, 0.06533365591519302, 0.02561177296053258, 0.04721101103050094, 0.04130643048894502, 0.12879523809158033, 0.19000639868599756, 0.12142053865376981, 0.14713205817726352, 0.16524421531827221, 0.15680220218435412, 0.19672281409223236, 0.14366285965567635, 0.19873820755991245, 0.09940343984072247, 0.12719471953929434, 0.08935432745924882, 0.174556412403622, 0.1574982390288384, 0.10566721219689616, 0.14373563800848302, 0.12932377747229992, 0.182354896359386, 0.15825219212039826, 0.13694367101115568, 0.08105143589238006, 0.10244697692894167, 0.16318428149867445, 0.0858783184160148, 0.16557530319738775, 0.10207452796279423, 0.13167517710356944, 0.11112145944348267, 0.26520137584978537, 0.18390516720471844, 0.17759664765288755, 0.09806316135631454, 0.17293635094838758, 0.22490372610909326, 0.19682000000630656, 0.1271409861322853, 0.17605075883048196, 0.1156457525587851, 0.11801132481665381, 0.12861146892030395, 0.14304758380016974, 0.13770775178507452, 0.28932615874275086, 0.09504178719174478, 0.07229855960054744, 0.2409530536181504, 0.11241787939422554, 0.16585477207216526, 0.14898254355836302, 0.08996403385554591, 0.1369957037029728, 0.27166207110689533, 0.190628232254136, 0.16608478231055124, 0.1587727948302223, 0.1223171909429854, 0.14666497436982973, 0.2081757672731915, 0.2052724012924779, 0.23952557134532163, 0.14481954516903048, 0.16031543543982893, 0.13763794585341407, 0.13559118874611395, 0.17742873650164376, 0.2143706759858516, 0.13368620387008115, 0.14739732378192488, 0.26103860728683015, 0.2605322844559147, 0.21239551745595472, 0.10746098408896117, 0.14959801859672994, 0.2638355330113442, 0.23590116341027523, 0.18930849258697804, 0.19052684817823673, 0.19088464188239268, 0.06235611347121097, 0.2238038230326868, 0.18576737373105942, 0.13394702616478169, 0.2555637139706843, 0.1130503079583568, 0.08406590760475205, 0.19152607197963423, 0.11265773386243852, 0.2045838567878931, 0.14758241062443103, 0.09537281378382638, 0.13943129639712074, 0.1224704085278415, 0.2845243809203948, 0.12429202005507485, 0.1397725732456292, 0.1652365544390294, 0.16701499691172955, 0.18294864514422032, 0.14905924428134196, 0.19439278831405027, 0.25660789181147853, 0.07712862904994719, 0.19130553058799238, 0.12040940218514974, 0.16856205018778003, 0.2182105691322396, 0.2005052659660578, 0.1597960891142007, 0.13787606130203894, 0.09524584237125613, 0.08009918094162019, 0.16156296365924422, 0.21593600811977542, 0.12662068985763097, 0.18933417185419993, 0.12384038058019455, 0.14333953990811302, 0.2227252631658508, 0.10150304935391873, 0.09389118441650945, 0.10950842301451391, 0.17643395601020706, 0.11324519306541452, 0.12591451766990847, 0.18873345166925462, 0.18055434458919112, 0.17548106520647005, 0.1091483616901021, 0.18534516735422998, 0.1635581324057233, 0.12623606775436672, 0.2578970032834238, 0.12951153030078258, 0.23265515694454794, 0.11198926852234911, 0.1251038281066764, 0.19260524471680965, 0.11537837255145274, 0.0862765155972973, 0.18892626067803753, 0.17315416506701903, 0.12529914988385094, 0.21330314778512527, 0.11259434774758355, 0.1268536265518877, 0.10736146926759713, 0.15097637931185384, 0.1223595709269566, 0.12665458158740114, 0.11577091600385406, 0.2254429600772358, 0.15576246765352067, 0.10231917048053396, 0.11565008095555729, 0.09327388608888273, 0.18547210812328324, 0.10732465874283545, 0.10812980182949575, 0.12121991554815924, 0.23813555077199014, 0.13454946238667737, 0.12812549338465737, 0.17959428320248283, 0.13210115263298636, 0.0788301256515326, 0.12732172159538155, 0.10663684968265796, 0.11743408522658771, 0.1298684200211879, 0.1696775967796003, 0.23258141332095672, 0.06718155957998768, 0.3034129222073863, 0.12198290081634638, 0.21069483290756905, 0.2177880869637574], [0.04432692365240186, 0.02696266750835123, 0.007637429291442518, 0.03731954805252533, 0.058258807121385495, 0.0971742159116172, 0.04188832789359074, 0.14845251796707032, 0.011316767645879619, 0.0474943180057791, 0.024224483490651174, 0.0569502140335258, 0.06048890439072444, 0.03476335396689754, 0.03643061026870724, 0.04850967561886196, 0.02399538298167529, 0.049294831471577774, 0.03369924251831347, 0.03560093321627186, 0.033322897995071064, 0.02018732270376096, 0.06560223101968728, 0.025997078797269254, 0.03488095229371421, 0.03321708976140907, 0.03677300177514553, 0.06056690363273506, 0.03192556894294197, 0.04777124346864801, 0.023617261134448553, 0.01064907796981354, 0.10084856511844743, 0.04490154705220654, 0.044909594805851105, 0.027412004889019077, 0.08256985280182093, 0.01993254292756319, 0.09688916991675094, 0.009027125235016068, 0.038920373039981054, 0.07582437201973892, 0.04636014015564034, 0.06212395818663701, 0.07232420056337312, 0.06431697297000116, 0.01905004985840811, 0.038712303559746475, 0.1151706861151803, 0.07035783672284696, 0.0425804806722989, 0.0819354247482073, 0.03301116532736248, 0.02224518617074336, 0.07647527862460383, 0.03836173406471649, 0.055671743522848816, 0.06706487672824053, 0.06262589516418596, 0.03916387791715322, 0.0325482030729613, 0.06563601549714804, 0.04204224644889755, 0.04052328944747006, 0.011659546026719675, 0.032162148385278644, 0.00593486447600768, 0.04311482699948453, 0.07270155249223595, 0.01785700006650821, 0.018054966762241338, 0.030600058718494354, 0.044635369802915284, 0.029101374318763137, 0.0411445292974672, 0.04939045839672608, 0.09095735111904722, 0.03162122710848288, 0.027584192726100167, 0.07126984141406513, 0.031129934922641808, 0.05508130423784737, 0.03898974996240389, 0.008035900349157953, 0.017115708493116884, 0.02041893981156811, 0.041046554312830975, 0.03964992240071297, 0.06893161849509324, 0.005332668614198244, 0.04726067268019242, 0.03293688544222424, 0.08683689359215, 0.07070043124258518, 0.05361451399362376, 0.044192988500599904, 0.05342706376987119, 0.05138614425255407, 0.04033456368732356, 0.02139460066363456, 0.04225513462217585, 0.018840699096120173, 0.02913331252432639, 0.04790417121482953, 0.02688138749480488, 0.054841691087330544, 0.06104367845241101, 0.019448662642389536, 0.035711889560785026, 0.023364703013231198, 0.12387862368937462, 0.009945558361528863, 0.04777954020086796, 0.040131397169804385, 0.016935509291567633, 0.02625673472310507, 0.017255921735458316, 0.012816198023727104, 0.03846338244094964, 0.026954142864973798, 0.038916029321450385, 0.07067023205661005, 0.038009620902519074, 0.01640457588608467, 0.10607440325040972, 0.020359721215021227, 0.04465764763975336, 0.01940862880268645, 0.020685425411248883, 0.028206832601778933, 0.041727575833999345, 0.037651677811217886, 0.04715755724558427, 0.04719943161152544, 0.04696273725600012, 0.005540654782371055, 0.0395366563011081, 0.042791300408181646, 0.07698529399931431, 0.029989130411958023, 0.015622169331407115, 0.034859949993270065, 0.02501998727600421, 0.028836595179933696, 0.04051265997752067, 0.07808053926114114, 0.05524135532698805, 0.002710688403890198, 0.06387437716306699, 0.05005829171427796, 0.02810942643742648, 0.024695866966560006, 0.03271001999476745, 0.05081463500016159, 0.051236217015332756, 0.03389612328441393, 0.03172557785986893, 0.034088576062312054, 0.06474359967415372, 0.06584642154555168, 0.06016520542963859, 0.05340275580003377, 0.02954455043729996, 0.06536319626555329, 0.023824489833186233, 0.05007396204276912, 0.02446983080928124, 0.008514109668472122, 0.028385817553968202, 0.1102238801878787, 0.035802345392444444, 0.05108161664177334, 0.03374995753890084, 0.014378960890274857, 0.05328575885223766, 0.0025732981955497378, 0.050156170937923655, 0.05251211347058416, 0.07171489253279663, 0.039834790908160715, 0.029563315761005207, 0.008661881325796487, 0.08412583866306851, 0.08225749577245406, 0.04532197993549128, 0.03305705399402688, 0.04849811918252418, 0.050046980426075964, 0.04116231019818976, 0.033009414816455494, 0.023694940534750783, 0.04134276220875402, 0.035523259561629064, 0.045945767027836655, 0.033411787176925334, 0.042511869837800344, 0.029827282846634908, 0.036451961139156934, 0.051562248714148044, 0.020349421162879276, 0.05219704832040495, 0.04041130271469874, 0.02654085566680278, 0.04766358513264887, 0.03797641099100152, 0.009042405816275747, 0.08109602987045243, 0.011815862437229485, 0.043478986894291256, 0.08284061125689939, 0.021177989303044254, 0.016776063411887136, 0.07541527340729391, 0.005606246751642997, 0.0550390008626686, 0.0220865159550862, 0.05156529774408668, 0.09113871477424138, 0.017350474222292824, 0.06960468036272834, 0.09637512491955873, 0.04806493476573979, 0.05360425607631764, 0.014342498935518727, 0.005172384347045614, 0.020010800724248254, 0.03228472628360314, 0.05008442297337517, 0.028653235865696788, 0.0454310133993145, 0.06001355066414803, 0.02163035464623282, 0.04272927409939228, 0.01725900523935355, 0.034123007884068836, 0.021596164142172185, 0.0455497800102157, 0.04483365250991718, 0.054006344984255494, 0.027017360440485423, 0.03218785063513825, 0.035686463102578156, 0.050278116813710624, 0.04000957003764568, 0.03158368496975351, 0.045492871168760524, 0.0393747934140265, 0.08995359973801721, 0.08914924572191893, 0.04678616931121196, 0.07622005643262979, 0.06849981303657256, 0.03299768217989514, 0.07544216309343615, 0.0048863252008994745, 0.08137221988891402, 0.03414180385129106, 0.057280531994277434, 0.049114329665298426, 0.013764634983794344, 0.011618073856938752, 0.013973255089724497, 0.032635774583585804, 0.03175921103496465, 0.03359192126100102, 0.05687034170654032, 0.04102211610804643, 0.06517798684897923, 0.04215008098511927, 0.048333084691436067, 0.05176234321909086, 0.023114935367278034, 0.06554093632486559, 0.08165739611872742, 0.0313263387990094, 0.0498694472105032, 0.03571746668087379, 0.025672910607329784, 0.04932732892132575, 0.04095000425173391, 0.05649883885897937, 0.08860257304003162, 0.03557911120174873, 0.022279937834208532, 0.024163294132919084, 0.05828686892205189, 0.09326627117491539, 0.039787431352681694, 0.02313412203934164, 0.056724654765979904, 0.024923396995291117, 0.0600010710918615, 0.03040970310628895, 0.04949624364775035, 0.015882082854307467, 0.027951018606883385, 0.045869372740027406, 0.020207631694633636, 0.07366804901750819, 0.019862009212374687, 0.040236872155219316, 0.05258598732912252, 0.04993530012847436, 0.04823870648960433, 0.0277481738462924, 0.025706440360555728, 0.04466741143034832, 0.06671325003187503, 0.009484758390293968, 0.02494307396362626, 0.052749531779197924, 0.022015378945657325, 0.048766031620963934, 0.07129097777989603, 0.03412380461551009, 0.007807271941865404, 0.025861134579885873, 0.002924338834653158, 0.014666952493209994, 0.03928046500790985, 0.0786530137843182, 0.06865240242933074, 0.012932361850905563, 0.02927452934184863, 0.04474135423679987, 0.03262758510367524, 0.03761991580587722, 0.02190485352560157, 0.03722796607161722, 0.019084562119396947, 0.0445150671857259, 0.0561019363662889, 0.030386571081415303, 0.06572254512819552, 0.07766777108753882, 0.027022922238815698, 0.04659043767699792, 0.00950294436000648, 0.014132494125665437, 0.03216011059140006, 0.04944484680891038, 0.024048620346753348, 0.09339161848108615, 0.043340137288455045, 0.014051904548860848, 0.02136103452123221, 0.014889396655733788, 0.011727110193591687, 0.047964270812489336, 0.042802604035504406, 0.046551068418569146, 0.018900317973607493, 0.1663167996992988, 0.12332710167092663, 0.1594222688506688, 0.17007424646327574, 0.13926447309072942, 0.15325824880311567, 0.10972187043197694, 0.2904140035952291, 0.1055965252641228, 0.10414110376469551, 0.14069976946038587, 0.18877927904888508, 0.14234627627076643, 0.10546283526045662, 0.15606996002456835, 0.1423870934353721, 0.13055662744708602, 0.12880841480387797, 0.10814399743873267, 0.18861786432323918, 0.17293754604554948, 0.09191974141304532, 0.18233698522371633, 0.13355028455055531, 0.22505769446011514, 0.10700012091547252, 0.12333037286636331, 0.1575226006248305, 0.09021655941802649, 0.14624341150685666, 0.15877222792515833, 0.10271650198246203, 0.2457102757668303, 0.18188496270487386, 0.1321986296604718, 0.13434102518423913, 0.18955318106999322, 0.1637134797150089, 0.1608826162954492, 0.11988607220231526, 0.16000610445776295, 0.16234878600845415, 0.12707060563468164, 0.14354514258523143, 0.3156336487060593, 0.10208156831081837, 0.22348701503247986, 0.13343100466074484, 0.15075223730696788, 0.17682300610167367, 0.08822369659619947, 0.15887949555631609, 0.1556399701944282, 0.11277453928825357, 0.15695261588740736, 0.13091566221367928, 0.17269461956476012, 0.12878593778417957, 0.1643272846817009, 0.10856284068957453, 0.13604337980429973, 0.2034710221473248, 0.12689259744459583, 0.1110093577975227, 0.11586741243879642, 0.15300163999199867, 0.12771375942975283, 0.1525409147143364, 0.15420982193562294, 0.12150552844808948, 0.18205874208961764, 0.13624159739382807, 0.19594954026322212, 0.15029390222362934, 0.21172644690640513, 0.19790147100725483, 0.208821518106326, 0.2600154508986781, 0.12665972969825232, 0.18031262852732213, 0.14707591925417224, 0.16291852559774153, 0.20242825390831118, 0.09423610784353749, 0.11723439674824478, 0.08414872170936677, 0.1164231709234657, 0.11357910780897064, 0.1968155260528288, 0.12139963977519544, 0.13637307340339308, 0.13256696473446586, 0.24905521482709916, 0.14630822254525078, 0.20998457747121013, 0.13224434978779287, 0.1615577542613591, 0.1798305753618479, 0.09778586051036274, 0.13371062675310721, 0.13635117861051715, 0.30631268757485575, 0.0977931000412472, 0.13305704650138656, 0.1802035376069046, 0.128463935707846, 0.21607905205699707, 0.10539336640748287, 0.15419427035076005, 0.1325999371587269, 0.19616928492342273, 0.07452943827956915, 0.14816117472946644, 0.18250924775437002, 0.1489428142386098, 0.2090987653261231, 0.15545138999098734, 0.1810276030652946, 0.10736324659158146, 0.1456511795761124, 0.16997194308186733, 0.13669322154694988, 0.1619261353006286, 0.10468262833573165, 0.2210983988498488, 0.14190099532565764, 0.1937420119441325, 0.11169308360906378, 0.08479845619970754, 0.29388401417001603, 0.1516163078767638, 0.1803429962526406, 0.24107254801257966, 0.14389568909762368, 0.19115940697731512, 0.10262941310722982, 0.13952420754057748, 0.2020276818544634, 0.14964013811080687, 0.19567915719122658, 0.09449704505142667, 0.1553195002939432, 0.14799626664288584, 0.13233551425078224, 0.15265002095651242, 0.10792305768137017, 0.16043306057972295, 0.069887466398218, 0.1962853778874682, 0.2049726923747409, 0.15284989329595722, 0.14373142452489945, 0.07506561555689381, 0.09477590105586475, 0.16229686056894643, 0.1288897120544026, 0.13825159760252123, 0.1670279284758914, 0.19139594428481596, 0.2231780058073421, 0.14344098527104626, 0.08990149043740765, 0.11952848534189886, 0.13229132629930973, 0.1756632868801394, 0.10970916869419237, 0.09931257415202357, 0.10419896638561642, 0.15589939820910656, 0.17282490047716326, 0.06554840568212733, 0.17230052861475176, 0.09841070480404362, 0.16006746810049782, 0.14949285004648472, 0.09598117186537675], [0.018990327559051015, 0.028988740241695798, 0.02409027829285591, 0.10113973981670796, 0.009262737491348339, 0.06386016623207158, 0.03694438330468632, 0.04456955135890073, 0.011574712322814571, 0.02487298649465365, 0.04139797033501729, 0.03329775498939618, 0.03404885057299849, 0.10378334836493577, 0.040759436050129515, 0.06438861751267988, 0.05645690320600426, 0.059182490823009325, 0.0011620427422683627, 0.031564900493850155, 0.018510072784979018, 0.10079552119057025, 0.03360429741141777, 0.03637748973203763, 0.02810106267251315, 0.04942292520295709, 0.04364322848437775, 0.10182825367777579, 0.01113439658506503, 0.026112407588610248, 0.045096570055090615, 0.034541004607754375, 0.023200721893038963, 0.08239672459181278, 0.04985080063042622, 0.033227286391681245, 0.05325404281217245, 0.0124665382581072, 0.046262237949356924, 0.0720601070732359, 0.032540067219205444, 0.010494813717330896, 0.012359456403271086, 0.021205572298757976, 0.03167771843201932, 0.03535831317065224, 0.029310353528407794, 0.07707429809435722, 0.020053433517234463, 0.03702804393645737, 0.06157507917152778, 0.02694081293509132, 0.05471036063447114, 0.044670441308088844, 0.05289765487935755, 0.013454291808058419, 0.02605134463538566, 0.03410843689174902, 0.010345597026659357, 0.07695226794889859, 0.04671075944638541, 0.09318422315822494, 0.01729473558014199, 0.05253487011237491, 0.046188007859933766, 0.019357867816823627, 0.011632882336515092, 0.04791260201243624, 0.036402379928697506, 0.05417509117133675, 0.09540948641276169, 0.019971375924444968, 0.03442193156168346, 0.07040097513386319, 0.043435143682384686, 0.0421267842513419, 0.026210792430285967, 0.031252857560532234, 0.06663836493727661, 0.02595543617292518, 0.053197877076003826, 0.03133380815627114, 0.07210551310450801, 0.021713689690636053, 0.028500031687379367, 0.02499393837135886, 0.008702686041473381, 0.017150674661200856, 0.033840390387922525, 0.04381795398770802, 0.06883267057879318, 0.00309961065443443, 0.04952279242476629, 0.05108758446670348, 0.004236817185301334, 0.041359719564957965, 0.045880530810644554, 0.050714001690428105, 0.019595136738292152, 0.020862751783082084, 0.037434625950071125, 0.08108952578397528, 0.04798811912957219, 0.055686728202647744, 0.009333288443515138, 0.01773943429842832, 0.09553757631370137, 0.0480822789963455, 0.06796951165362712, 0.0369774897943341, 0.02591444663853655, 0.04854663553076887, 0.06702894720459177, 0.04941614915526683, 0.03452140424821166, 0.01760836240024336, 0.0664260283473038, 0.033277308102697134, 0.004468192017802428, 0.032623708698778384, 0.059429481400236975, 0.055889825772253744, 0.0241263035774952, 0.010668035773109767, 0.06405494791725952, 0.051439762746374455, 0.03417808577538498, 0.01199366569879555, 0.05983514793878121, 0.05147119916434731, 0.02148900184810402, 0.03715290860723584, 0.07382884321193542, 0.028921941205138163, 0.0387837719022026, 0.03137783905971916, 0.05233422019368699, 0.05426356666571191, 0.049126472158898274, 0.027459063754987814, 0.026007821265187477, 0.019934879495732246, 0.10759782271399614, 0.03630334774272577, 0.1020940478831049, 0.07540029638837423, 0.03810580324141249, 0.01567606936253968, 0.007786903579178597, 0.008761593414801023, 0.015307115672546771, 0.065718584453627, 0.07498520696836133, 0.05331629511689948, 0.03272701182492799, 0.028565547526663834, 0.03813241713590199, 0.03802602667541754, 0.03362918760807764, 0.03276632362676244, 0.07590496446937323, 0.05733759405331747, 0.016810859125407956, 0.045967294098508936, 0.023391973828115774, 0.009228207035771301, 0.01970127055932197, 0.041059068359074094, 0.07960783512962442, 0.025892952126601053, 0.09454435864163023, 0.023086230052755247, 0.05791751495111854, 0.035588897974981416, 0.046794925696186485, 0.07218212189693606, 0.0200913644455854, 0.020674313305907195, 0.006381546883212944, 0.04559085764471562, 0.053111596423531734, 0.029033525741749236, 0.062379900501259876, 0.05484007081137069, 0.02812163404849989, 0.011955681144289914, 0.02883914816794136, 0.018590333901586074, 0.0412911968305707, 0.06933399085556308, 0.0664282653240427, 0.01522370018891149, 0.04919000383045885, 0.035246751616678895, 0.04352800503012635, 0.05267365843117718, 0.03163627116009593, 0.028293597804863128, 0.04149356661664863, 0.07733201773296441, 0.10996586177498104, 0.027140779120306817, 0.018004640531275543, 0.08955488161694619, 0.023444918164562796, 0.03575483644982019, 0.04489649087190629, 0.03419041596052628, 0.045619574450557275, 0.062014698726876136, 0.021501420133356607, 0.033973689686747334, 0.09516842918650759, 0.08195136703791157, 0.043252439373323036, 0.04900279492440243, 0.03227543746752124, 0.055786886537868174, 0.06339947925880551, 0.03514553991056258, 0.052710066759778615, 0.04284371614396092, 0.019173196577016386, 0.04354768199846149, 0.010896587571609887, 0.04008657719579436, 0.034110658546729435, 0.02223333096011512, 0.02590763803210951, 0.03168005116974875, 0.025458145518636992, 0.0756501023387236, 0.016989355696545496, 0.04839563194001394, 0.01620865081466975, 0.0431528517736062, 0.041889883052077026, 0.08174490634231799, 0.032172613146324316, 0.0739771195296799, 0.05537697970266304, 0.01610677452727912, 0.039606891242006136, 0.039816412458857225, 0.03853645956804676, 0.05841290570735451, 0.047925422493849075, 0.05349971954860995, 0.05650479136215103, 0.08695733793560537, 0.037429067982180465, 0.020680057050119487, 0.08083133883173428, 0.09576181791001752, 0.02241977952390669, 0.033149444197695103, 0.007386319076402054, 0.007737382698143202, 0.02118680122939329, 0.006810059121269132, 0.08169092012629395, 0.008574897787653872, 0.026403153277633172, 0.03627148614595494, 0.056397627152863054, 0.07377767619947273, 0.06011906012351956, 0.05986612470399949, 0.04420427297572455, 0.0809083000246075, 0.018610872718836033, 0.005080942655988639, 0.021527955503833872, 0.013518857698316776, 0.055958490232907, 0.044174249989972006, 0.05358401986379778, 0.031437394734952724, 0.040721139314794735, 0.017856036710943428, 0.006276974445133801, 0.03237042087881315, 0.06128171729224344, 0.018653156941816695, 0.0499666292941378, 0.036027268807013194, 0.08483971003443004, 0.042979317536998185, 0.01933515330986871, 0.01663717933209433, 0.025455335891174696, 0.014110240229074995, 0.02118491856831937, 0.04057999144518568, 0.02383147272461605, 0.08216350444502409, 0.12166179506288421, 0.021591339703469027, 0.02311073720545298, 0.053448338031528465, 0.031328303814535184, 0.007734743525244056, 0.05055079048859978, 0.02276865596462402, 0.03763568189535891, 0.033401736103358774, 0.048042718215935656, 0.02862246785943787, 0.07543003592159479, 0.052325938783225515, 0.026651005703775633, 0.06328081223933447, 0.03543510582418211, 0.021429465325068564, 0.026022859571141102, 0.026761270653937134, 0.0172759453585792, 0.01466504206144882, 0.028041667875743685, 0.03829852031964449, 0.05265384739745529, 0.028405887142364538, 0.01624431986842425, 0.0013616252850155318, 0.006767886459842445, 0.03179981752539114, 0.04773350980793757, 0.011686678945777879, 0.03131555419625535, 0.03067863444166799, 0.02713330401738565, 0.0639048214971779, 0.05752115255041469, 0.013968921904902787, 0.06629049973261934, 0.02913984533910069, 0.06616812484759478, 0.004482300005733006, 0.07142354929519278, 0.04719552456311161, 0.017998862313106656, 0.04035514846984898, 0.03412732478952216, 0.01476863151296012, 0.03129946060418602, 0.06513438112432919, 0.055066809854319984, 0.045569863005150715, 0.06850784163801901, 0.0616618309680733, 0.05484765891226069, 0.046848708898910595, 0.09187405959012047, 0.10489081272915488, 0.10624085883459738, 0.13818212874954747, 0.15267067468695103, 0.18389454922608792, 0.1810912802935608, 0.1409747490599271, 0.15691639525034737, 0.19770287037376436, 0.20364354514787275, 0.12687848610503058, 0.16420927649784475, 0.2059624320076358, 0.1413629411329185, 0.13538419178897335, 0.15710946472902454, 0.14232450405195837, 0.09358399081975223, 0.08782825733144438, 0.15048027609384831, 0.12101802839747361, 0.12267818689466485, 0.11438400574749517, 0.16134061430010105, 0.09208023683318207, 0.159977835813357, 0.24828831484961897, 0.13382655117780934, 0.18224551432555725, 0.10717279713360534, 0.11324608938828593, 0.10579188534569357, 0.1715599973836253, 0.12877306750705167, 0.250208483588311, 0.15996203908035833, 0.14137671539379706, 0.15286930596395848, 0.1665637251590529, 0.10618789151551263, 0.23127334883376477, 0.127667541345281, 0.15875621668754086, 0.13156627004425372, 0.16198055818676949, 0.10061208143710129, 0.10404795513398225, 0.13429121414740242, 0.18179695452413253, 0.11827300512982954, 0.1183930357858058, 0.11918474169027422, 0.12512531687295245, 0.16725320429090532, 0.16409214165422226, 0.2548125341174103, 0.16070614028121197, 0.1397034874366176, 0.1363138394850877, 0.1242260215803981, 0.14478487202957754, 0.14482109266663754, 0.1183299101408451, 0.1897101371639198, 0.11848139636699231, 0.0893366614717149, 0.11148656162643626, 0.15434440826216053, 0.11024474842293609, 0.1580445516494013, 0.12646011782870178, 0.1000730696344568, 0.15349515383282017, 0.13588050951159772, 0.10725975577389041, 0.1671828620976979, 0.21205203427422434, 0.11960694806710367, 0.12807422678076452, 0.09012552518998423, 0.1210326836594651, 0.19337098024064497, 0.17779495717296678, 0.3475782894078763, 0.08574334138463582, 0.1626785868598569, 0.10964225857488571, 0.17849965081099542, 0.22053094220257577, 0.3054437293641029, 0.17223956333773752, 0.11885415176830946, 0.1406155917192659, 0.09562853393295119, 0.14993017899893946, 0.06890181767483873, 0.1137505736081831, 0.18191062665033728, 0.1601312679028319, 0.1445770783409957, 0.22389042161164746, 0.1341138341494145, 0.15087501055771305, 0.07126192006492807, 0.11075711568757413, 0.19315419267983208, 0.07615431842784728, 0.14976303393561996, 0.11292571907923107, 0.2415718687998672, 0.15159669602590223, 0.23264824683147095, 0.12897044239986327, 0.16380139596519933, 0.07416215274603137, 0.13303614762281218, 0.1748455952732794, 0.09355709347273074, 0.10592773571730622, 0.1554622837612706, 0.12068797473705585, 0.1335630628971323, 0.2286754067867033, 0.13440309362786432, 0.1266018823990899, 0.12744503876855298, 0.05850877778063859, 0.1748552633028838, 0.15981265193512365, 0.18468777198464642, 0.06441653375664065, 0.12050065857869004, 0.11916700675482712, 0.12021187407475327, 0.248572564113044, 0.12371262009706228, 0.09616085778801672, 0.17629927775311857, 0.07846133858566323, 0.07384676966936358, 0.08122154571596654, 0.22953572352567028, 0.08618250128722961, 0.17238127428197092, 0.13709956990374675, 0.14009448339141187, 0.10500930354840333, 0.10912496536489456, 0.11953503539365147, 0.14521556666060803, 0.13389304760963688, 0.25999194732116115, 0.11710444525364908, 0.11075674796537047, 0.14228908014633965, 0.13188313933149462, 0.16528515505694574, 0.12493685924357946, 0.10201491866140597, 0.18310506497659992, 0.10948485048908381, 0.12878215330983364, 0.15762986825598826, 0.11499828568870023, 0.1906874355289244, 0.09838055158334394, 0.09207676645488509, 0.1891328592694575, 0.1353352847358873, 0.16975184602122154, 0.11555158503113255, 0.31279884759456883, 0.1510740708439581, 0.1530316706386305, 0.12134014538699582], [0.073240234877073, 0.04179456256209843, 0.04935618362299377, 0.026024604336388653, 0.05156697930708047, 0.02748510499875392, 0.022137068181989655, 0.026622252508757577, 0.07388017876374145, 0.01109157514292747, 0.055688670235535795, 0.06200325720372701, 0.006484032210503375, 0.03180519354739978, 0.03827946388252801, 0.02083851850681728, 0.05370332273624597, 0.06561435053064939, 0.03730495790800741, 0.03114207167058222, 0.1093921768328836, 0.05420391905992743, 0.10036315648786484, 0.04526026389231125, 0.03893280664699213, 0.009025636151613248, 0.03445614504838183, 0.052842335670345256, 0.027159705322476167, 0.06307717457774185, 0.048562822968608914, 0.06147470250124894, 0.06020641329908564, 0.08197934456890629, 0.02876056669910829, 0.017042342167828354, 0.027041632021146438, 0.05968821993578346, 0.04530528687962121, 0.05818493326284713, 0.026360388334480025, 0.05502663620357072, 0.05317273790076856, 0.044268727783233895, 0.01308470609552798, 0.06802842381500429, 0.05250633333719546, 0.03743042395780644, 0.03816805554613952, 0.01617497933517781, 0.018824390999432054, 0.022926791833953995, 0.020893818563631466, 0.05794296822240276, 0.032848838957086686, 0.07160651407414867, 0.04300796156448703, 0.03412317642341218, 0.019831319730128014, 0.0021191586406090327, 0.03400930128390751, 0.0738538942870594, 0.09527835514276259, 0.025993369016495925, 0.023687517142764503, 0.07445449189793679, 0.034647230359335104, 0.017572312217746532, 0.06471237393036004, 0.07341730077901194, 0.04116629385539601, 0.041847231106892716, 0.09244527772910173, 0.04691403321621399, 0.016874605301587332, 0.055387647477008646, 0.02801792681097023, 0.007100993938248365, 0.018567763036116958, 0.015153328309796993, 0.012623355498597508, 0.025928387523538647, 0.040767039472778, 0.025255618684534586, 0.029991147138418692, 0.08906587237311948, 0.0905253617994247, 0.03531173502485599, 0.042935807573338675, 0.03253531364363528, 0.07704110350459814, 0.06919070177020566, 0.023100917873483513, 0.056563427731875456, 0.02747701702549333, 0.021783625857243617, 0.028542120557939334, 0.024829240958957423, 0.023572852932697824, 0.05214187083765865, 0.034032452460979266, 0.042549894611922004, 0.09387705009430648, 0.02680327333960562, 0.07073086791581686, 0.021928224952951558, 0.04500036090311985, 0.031175944248154282, 0.03573380733629869, 0.03800327386406641, 0.05805415439329321, 0.03052813072328366, 0.01207728898378029, 0.040534803748972, 0.047300650978521, 0.027960094833566297, 0.03754281288673801, 0.054138954803948446, 0.036419938663922014, 0.055509103056524074, 0.08313317257430285, 0.04791626008227468, 0.16205693715282027, 0.049951717392691684, 0.011594548254394004, 0.12374375391030505, 0.012594560168743616, 0.06022770288250139, 0.01638750936235151, 0.0282098509882006, 0.06155617595199616, 0.01428230932252782, 0.0027091768166546022, 0.058142285148102435, 0.04725872681686475, 0.028702148664442283, 0.038422438871836474, 0.09026752724762886, 0.015860889989492154, 0.030907380634978898, 0.06867733859126607, 0.026718990261396094, 0.05708691476273441, 0.008032218817876833, 0.02504577762597511, 0.03314324654638767, 0.05049384334274838, 0.04259180728225939, 0.06479553277454068, 0.022337570628752152, 0.016742219562612234, 0.017311396077275276, 0.03369473026043946, 0.04985948423704794, 0.03488904984307385, 0.03790118498727679, 0.0572143419976196, 0.02046548348340777, 0.030936716056819406, 0.01805251145044402, 0.0075097166888055305, 0.04682835777320209, 0.018131225069444028, 0.08297513629640303, 0.08783794068280729, 0.0055034018418331065, 0.030014616241979025, 0.08277123433447654, 0.023884782868046916, 0.043936598024541335, 0.0666158649349405, 0.03498111062893464, 0.02854002722268624, 0.036003290254983215, 0.06824575529824342, 0.013272332519503131, 0.04123718763190893, 0.04854031530539355, 0.039014728259175055, 0.028410991203160058, 0.027755179720359947, 0.04662901020398544, 0.024411248065711513, 0.04446838944849949, 0.02376739904584904, 0.02281104743991408, 0.04402270630723046, 0.011236170408195786, 0.035765393141416774, 0.015397910498112682, 0.04176496858558348, 0.03955274414751799, 0.06027016330570464, 0.08885265478203375, 0.008753910510530396, 0.03346471619161387, 0.11325701380208616, 0.0021905091970468, 0.02195882250464732, 0.027295176480566303, 0.07002762984484434, 0.04637397187311323, 0.07635108811119873, 0.03656594736141063, 0.009778117396748595, 0.004774799078492629, 0.052194282742998296, 0.0343129632153338, 0.09666714231453596, 0.021609275736996246, 0.05460948600704151, 0.027444012042495514, 0.028536055056798845, 0.025423265535444505, 0.051462013770135186, 0.05660826302764397, 0.015039291334218316, 0.07567048793838871, 0.027563437489011598, 0.04091389086698333, 0.019803918680296313, 0.01432270322355532, 0.07259246923269765, 0.024411102509005897, 0.04245144848321234, 0.015480247712994536, 0.018801965690668554, 0.042569720967402386, 0.044720240853606694, 0.06788161838607443, 0.05909357865851733, 0.030985469892320615, 0.03324568782362246, 0.02444126339058482, 0.051019069393195456, 0.028865649064462033, 0.022381406179779482, 0.09458886835003093, 0.01807537534454417, 0.06937919770397487, 0.028961007858836846, 0.041075757584504546, 0.02939804952831999, 0.013397067912944384, 0.08628510344292849, 0.011067820671615342, 0.05756439055286108, 0.009320774397272016, 0.07285973432684138, 0.010186496844154694, 0.021277417939516808, 0.061729576123217424, 0.047479597626314055, 0.008221472699886129, 0.07773836608976126, 0.033429119916212176, 0.00671865381938856, 0.062386224557074814, 0.022624725280630014, 0.01715032992163493, 0.01984114097731729, 0.05412304315776114, 0.03538151031299945, 0.029063822603934718, 0.026850816756186467, 0.03351116410246299, 0.020475959735772303, 0.04253137443635253, 0.027619317857428428, 0.046388600322027365, 0.0315326041421823, 0.08449146944668987, 0.04262385274013204, 0.09236365872164888, 0.04388097621079895, 0.021361574613218828, 0.024289713962183847, 0.03953490579020112, 0.06609251963034754, 0.01377949613191548, 0.06396143539478222, 0.013687336712234445, 0.050335745777814626, 0.010630073243631952, 0.009671654157911339, 0.050712906184696385, 0.06561333929458935, 0.06395684269767615, 0.024146637466225414, 0.04041645848642915, 0.04845558215052851, 0.02881437288447013, 0.03617325452186408, 0.028524998492831667, 0.02291506685827288, 0.04764377409892698, 0.07825132324210099, 0.02619506847564011, 0.07171951970385929, 0.04716237210818837, 0.07043059975389512, 0.03487029218024785, 0.07594549052056766, 0.030922007168673223, 0.04200643949931668, 0.02262452035211027, 0.06778593400433179, 0.044471974739985126, 0.06591022900876499, 0.07978112421809666, 0.05579653541527449, 0.055358260344233245, 0.04901043282100751, 0.0758544869360424, 0.023576631661384337, 0.009872964827433951, 0.02625390019778523, 0.02346798124152326, 0.018850288601712357, 0.019218200412128243, 0.022960614615810976, 0.014720902320057636, 0.04702748317692069, 0.12315767366559276, 0.0307161306151219, 0.01952924934636441, 0.024579816137350375, 0.0728915959236122, 0.010114108238579526, 0.06051086430107394, 0.047296414512299725, 0.034036872788302364, 0.047409002624091603, 0.018072981319780794, 0.03441141317448309, 0.042495862430622505, 0.03379143736956101, 0.04876839883264996, 0.01839363699658744, 0.080711055366743, 0.06501520082594887, 0.02445163813629939, 0.07152559986758618, 0.04396774715954258, 0.011306458017638615, 0.033989892446345864, 0.03218773189150999, 0.03610169807929666, 0.05802313549323909, 0.02549913313780581, 0.059553407613308205, 0.02366944321341092, 0.13245267973792169, 0.16953826070793215, 0.1298244312525757, 0.1720099361433137, 0.12180732878585979, 0.12061825307506709, 0.14007353854756202, 0.21827986944587002, 0.1938368689509169, 0.10361716857240086, 0.25875443953179544, 0.15063914740758558, 0.17930773567528496, 0.0658827034696456, 0.1852954942132196, 0.13359467168488812, 0.12495738273907094, 0.16653905712789105, 0.0726794431947412, 0.08103848900645971, 0.2154932092995413, 0.18020048857696597, 0.23082871140251238, 0.09336859753896153, 0.16315576770613271, 0.16629545648972835, 0.08658318059338678, 0.09530080917982325, 0.1371993911602805, 0.15136362143581913, 0.09096210086417776, 0.2034994286875571, 0.22187078401686686, 0.17442196397291077, 0.1298090941723316, 0.1757131285604931, 0.11513445781724108, 0.16828392962774924, 0.1653469783524352, 0.2636528670066788, 0.09441872788292748, 0.1707071729845578, 0.19041394213995627, 0.14239757351817625, 0.09074189655122258, 0.10408995973487055, 0.19055523939671057, 0.0876821643642841, 0.1136171670570489, 0.14185273178642796, 0.12136667501181365, 0.0697726911054023, 0.14813381006881116, 0.1718128523639133, 0.20037351416484003, 0.13549579547778254, 0.20599143609644907, 0.16044905649558192, 0.12609620308203082, 0.22760057010717932, 0.07718755653308285, 0.30017656844950497, 0.16093417401275328, 0.13983370706198678, 0.16505957280676212, 0.15304927533913046, 0.15731523594548627, 0.11963402161434775, 0.21230203940743403, 0.17022095230077544, 0.15349487804116743, 0.16656354129795106, 0.13271328752800343, 0.09974311556546919, 0.10773129055216428, 0.1634066461795761, 0.14493867184125608, 0.09722417250515954, 0.11134676590201356, 0.10553004415405375, 0.1284693059841952, 0.15316913745576335, 0.16863366408694178, 0.13297155108903685, 0.09057174076236064, 0.1755590682789203, 0.08484154864544831, 0.15449119070845266, 0.20113472976992208, 0.12819505416818205, 0.11535287714533268, 0.2236535931907354, 0.10018491847140175, 0.15738208477775897, 0.13041335368348708, 0.15094814131096487, 0.2233491038843509, 0.12588083278387785, 0.13699951882083572, 0.1855724503196055, 0.1440040752171509, 0.11453543068660844, 0.1400024455881888, 0.06491114310319386, 0.13399375752816278, 0.12201742073821446, 0.1420623334425111, 0.076771080493927, 0.18221822627369436, 0.12261801068821263, 0.231251806441334, 0.18817846693338888, 0.16105440385158987, 0.10523403544099101, 0.17803756189682793, 0.14439500988491122, 0.14438327341791124, 0.12290674922687393, 0.11507349254022683, 0.20223026614516013, 0.24040571443976896, 0.1349591049215486, 0.22988832315369961, 0.12405138417717912, 0.21579693251800156, 0.1631328157119213, 0.1614944294335381, 0.10169987266342487, 0.136815014205152, 0.10287672927182528, 0.17673263837012554, 0.06530244549315783, 0.13536577503527367, 0.26388263209692897, 0.1314506520547213, 0.10883305522222674, 0.14711718074977398, 0.2067750367906786, 0.1375782982476296, 0.07962789897236132, 0.122252939148776, 0.13435771057922996, 0.14192690441925682, 0.1286734913986537, 0.09755451727898852, 0.14107276234895955, 0.17345885355626384, 0.20474848908282098, 0.12641866481111896, 0.11580246350457592, 0.1180776680308965, 0.10399270487288315, 0.14707527574031584, 0.10722401011134348, 0.11068703396426094, 0.15085354477407473, 0.13748774665497965, 0.13301845099176132, 0.1397512913230927, 0.15222648158669472, 0.21157489939322396, 0.1290949010440419, 0.12540647114116338, 0.29293761979187694, 0.2532326156694082, 0.1581699755643645, 0.11087124746653343, 0.17033477764456503, 0.08963917427125478, 0.08980652617831385, 0.20206171148005994, 0.14056349774041485, 0.14012046909380343, 0.21742998682443174, 0.183268440887332, 0.08771873740178925], [0.050137715879827745, 0.019510384431229006, 0.06299073304680568, 0.03579612858893891, 0.05597258625071376, 0.04615663655943448, 0.05810856961855485, 0.033914459598881584, 0.049443709168342814, 0.045404368861308025, 0.008797441541607822, 0.027827770381625143, 0.03562625242216933, 0.06261882034220523, 0.048056668677036805, 0.06815507347064634, 0.04588058826723888, 0.03835854330851186, 0.11291834165252025, 0.07217427715659142, 0.0713412254868496, 0.048922792362469825, 0.02706857150300376, 0.025787498208604036, 0.030872964134980595, 0.02645430496833738, 0.017645900708533103, 0.06152575077008336, 0.0659655482177773, 0.026083533734744115, 0.03722198675536821, 0.043890268857320475, 0.002467564416057881, 0.059014445606378786, 0.006657290655458647, 0.015541321199928081, 0.05398441954786259, 0.046805244900526545, 0.09019530813900695, 0.03439208477615349, 0.041093006054119724, 0.06105850991462508, 0.024057267564198664, 0.03903301477792763, 0.051324815083775795, 0.05793814569891942, 0.008268636902944456, 0.08208428329277424, 0.02744582575565625, 0.024043121750676827, 0.07039900628789779, 0.052686498064788125, 0.034450931820057096, 0.06828840341298811, 0.06500698836340059, 0.003606208798197669, 0.013430814086008939, 0.012713139088103368, 0.022257543168962005, 0.0711131457900328, 0.03468679880062419, 0.025887851896245154, 0.018288920438217542, 0.03337360152433957, 0.037194694873065724, 0.02737645074845322, 0.03574715258793966, 0.018786105755416137, 0.0434047031787134, 0.07850412459623429, 0.035637896958618395, 0.016689556763477383, 0.09875883047859516, 0.020323310971199986, 0.026608482078318636, 0.04237877355227548, 0.04619480689026175, 0.06340514447900557, 0.06612348490424695, 0.02770262991919393, 0.026975959133837494, 0.03395536869403816, 0.023788792051134572, 0.04811675295293812, 0.024100647292911045, 0.018473892367535064, 0.002151270652370107, 0.004478059709072113, 0.03864908215379523, 0.014496960455641873, 0.028540142135874882, 0.04647776912597399, 0.08975144445655808, 0.044734237279983304, 0.014652058786352076, 0.14118880934772954, 0.048038182975423914, 0.036979033461501526, 0.03601541742682457, 0.06667417954773673, 0.010927184165695743, 0.12209820470982984, 0.04149570400195737, 0.013349066758828779, 0.06023450957370862, 0.013211856581150525, 0.033596628871295726, 0.03378961408030122, 0.03849360844000213, 0.04022652996824153, 0.060163385970818425, 0.058592687390985033, 0.02297739960223196, 0.0529264597853105, 0.06069191002977952, 0.043551470303247054, 0.0333039679624621, 0.07063444808966692, 0.036058084693767374, 0.01096713565094697, 0.14982902474941748, 0.042996688580681244, 0.06643237155531684, 0.04009239180313964, 0.04447195941822664, 0.04136653008660482, 0.043695628898398536, 0.04699444946562571, 0.01660312289342044, 0.015638294524603313, 0.11995184085061474, 0.025814604314584887, 0.040827859193086624, 0.017493047015441042, 0.03816370799716923, 0.0694469964852737, 0.028019564323908383, 0.03031885848500796, 0.020690711417926416, 0.12076695074116993, 0.06573559926642526, 0.039471462218751835, 0.015953682389320628, 0.04184826149515087, 0.017772171150652633, 0.002579312464560292, 0.05106174049057788, 0.08651495280285036, 0.026215733697397575, 0.026679463954942844, 0.0563801680090687, 0.046801395308707035, 0.11383451386204652, 0.005827977494787305, 0.1048900466412306, 0.08075473770018547, 0.07494284996702787, 0.07802069247249635, 0.043430849759569096, 0.02684098593289814, 0.01664668456801484, 0.049422856255043904, 0.007726979224131473, 0.026986398997025627, 0.04715227123890673, 0.028524502450900695, 0.027380721688631083, 0.04778623580932618, 0.027521932760493893, 0.04658507889196758, 0.028291860700494824, 0.016223779135954478, 0.019161391162103223, 0.013621738518498117, 0.03499998703538891, 0.07598823822674251, 0.010926599066043574, 0.012700076331384482, 0.027217721160981926, 0.011522626004842742, 0.0445122211690872, 0.07026494856202795, 0.022097183729431803, 0.011701661710356994, 0.022048786124815384, 0.03129731172755842, 0.10949780503588338, 0.02763118455937553, 0.02981627799360262, 0.06415039481174561, 0.04212036826497605, 0.026731117433237455, 0.045498689606545434, 0.03688925178721547, 0.08825070119553036, 0.022025025907843825, 0.059766560086920384, 0.020498331418381106, 0.01854094804354733, 0.035681594613819353, 0.030320890533227115, 0.032573085608741933, 0.016902778185002746, 0.06419265222164892, 0.15882830556121566, 0.03497058458085503, 0.02657951054824216, 0.06204749495091458, 0.03782125903413661, 0.10153063618007208, 0.04903336949346047, 0.020902768385806875, 0.028124991428828048, 0.03564267734726591, 0.028611313619260347, 0.06119307708896457, 0.002542071972951113, 0.043618537470578186, 0.03418958092468881, 0.06401330720813525, 0.01757198088471928, 0.040257943403576656, 0.12078454011991141, 0.014439860092205627, 0.06590891133753524, 0.05241957004933108, 0.08708605602864297, 0.045495920198699163, 0.01275037287644321, 0.013213047847872781, 0.05311392533082155, 0.016445075124201756, 0.023458705831980033, 0.08649224595677468, 0.021353517283475208, 0.08011851700082903, 0.0408806503119488, 0.019746260987895153, 0.07351576605991972, 0.04576037375016078, 0.015335793216382305, 0.03378525887045168, 0.01836080438337259, 0.07903065682659227, 0.06544057114590561, 0.033716621222875776, 0.04667240525445631, 0.019398715624946262, 0.030572253557282592, 0.022225003584378192, 0.051292191229520306, 0.01917195168413943, 0.04525469060266211, 0.05929126764737791, 0.03332279074276167, 0.08440344594419004, 0.02070970273756933, 0.06905174874249967, 0.007115061227757965, 0.05622156099566529, 0.04957290989677272, 0.036867460416209315, 0.02302548885645886, 0.00496488272948491, 0.030947828162161094, 0.05637920656872373, 0.03746453785307465, 0.05569033647677111, 0.09918435401613675, 0.04216267547059444, 0.02576555936567245, 0.055909380166521, 0.059324772502746315, 0.05625050762788423, 0.06432274927295024, 0.02078566418570136, 0.03839620419086949, 0.09601894766092302, 0.028911011045678493, 0.04263637061681479, 0.04455316473820037, 0.04640144761651755, 0.01215980431410454, 0.07518080453718863, 0.03152815317134223, 0.05572620854382554, 0.039725393552573464, 0.03601809873455956, 0.02720809143577372, 0.04490557667468825, 0.06999237447856896, 0.04599065594975987, 0.10205650191393592, 0.08687310656833072, 0.006433263563761308, 0.04485927432054474, 0.02782478263872045, 0.05805618835673217, 0.048804684587183504, 0.061600934638972246, 0.06480264207047802, 0.03676719482867949, 0.06311328413205282, 0.033547526465788964, 0.0816929349375348, 0.014492103458201934, 0.04432990756486693, 0.016004242277103328, 0.011478939840960647, 0.06970598782983518, 0.0010481392335702456, 0.07869723237930767, 0.030395421312160553, 0.06292541639038152, 0.04239392677141775, 0.037743435992348584, 0.04875195475535528, 0.02116377262638942, 0.04800516841632705, 0.073099420255711, 0.06859301529344052, 0.014508444113626838, 0.018143649100356044, 0.03696280388882564, 0.025708621795920115, 0.032247839150049036, 0.00747911051862062, 0.06706745844454536, 0.03484404217752238, 0.1082876465854145, 0.029512721399265914, 0.025436760174230705, 0.031119935560010137, 0.030182818506634047, 0.0386158952249154, 0.017467306461185217, 0.08594810902591675, 0.06981150111964635, 0.03707351508520303, 0.12529361872903763, 0.00460669927809748, 0.07148396298890153, 0.006394926130005549, 0.04970602150405607, 0.02868181669093188, 0.0657145931355415, 0.07132816368774061, 0.050395374231400995, 0.022591886921755733, 0.031182611128315333, 0.04851482372971312, 0.08527846391042394, 0.14458541337761188, 0.07482778356080094, 0.11881477484900145, 0.1055007029865538, 0.1115558696009459, 0.14845749753857815, 0.24409151666106718, 0.17728449746726022, 0.11094210293865013, 0.11317889581644729, 0.0700585491534683, 0.12271144277145787, 0.0955223311640082, 0.11887279068750721, 0.21544186608685603, 0.11132797376523096, 0.06700349776374717, 0.20427432662296682, 0.27971080534400483, 0.13118661219073882, 0.25674396434858926, 0.18501579551206482, 0.10971934234182681, 0.10323550356852432, 0.16521104371115086, 0.10473610893372567, 0.12205718836236386, 0.14244880947855212, 0.20359805484692897, 0.10991373715261299, 0.1404517561557793, 0.10039723973961608, 0.10251643046015695, 0.19789071513279793, 0.13247138760503263, 0.05874389399503989, 0.15148333033486722, 0.12905560073352632, 0.10673085633184641, 0.16863605428126552, 0.25562303981954054, 0.14493939196390493, 0.07614003088805946, 0.14625393755493626, 0.1119788344048204, 0.09810299792837712, 0.15379838675500887, 0.1567600673485187, 0.1818377563669797, 0.09982499504281629, 0.1695271217895131, 0.2831500191842356, 0.11121372707308301, 0.1136960204870951, 0.10527643074672069, 0.089479751374212, 0.11340297653429932, 0.12885283258172775, 0.10773919657954287, 0.14584766580693184, 0.13567035627220908, 0.11305059907176804, 0.11162334662531653, 0.12092500234082823, 0.14066578580006478, 0.17715348111044976, 0.12569019180392066, 0.15795922477639493, 0.1564035913155925, 0.1415925836491008, 0.12361867473490777, 0.11348023650146301, 0.2781373833216006, 0.09631965249296158, 0.1276312134559116, 0.14088502484223536, 0.12197268886431573, 0.21697581925940132, 0.19550511733658854, 0.2227792570427541, 0.10363658124040212, 0.12000250990592665, 0.20298072587578528, 0.11268162814479683, 0.1702396601678864, 0.08371177580087416, 0.1231659320934165, 0.09053273922613553, 0.1925897697407392, 0.14052577557102328, 0.1640137402160514, 0.1179353135728067, 0.20987648246509416, 0.168587101262904, 0.09405837544510443, 0.19315894242496262, 0.15796449546131397, 0.11878941733870776, 0.12139230065288083, 0.11971489751651404, 0.11913308438153998, 0.17350547766733557, 0.1342258515257028, 0.11870645767738743, 0.15106238034223357, 0.09546924893173481, 0.12539953804544865, 0.24500876905456667, 0.06615581381465159, 0.13268328752488862, 0.19012285937224666, 0.12240788809234097, 0.11756129412641449, 0.11283353571930241, 0.18961299721512104, 0.37491598376824015, 0.12493376424836537, 0.311361298926415, 0.1802916070746799, 0.13507354313567763, 0.2934892030973589, 0.1441055205800841, 0.17513315403653731, 0.09279129666186149, 0.11637102331845992, 0.10627977610115083, 0.1388577876552459, 0.09743577365072505, 0.20841763655264534, 0.08967612269184283, 0.17448867490935713, 0.11798225177992737, 0.09844533963910035, 0.11954421312698435, 0.11593227710334525, 0.15653399480206354, 0.14022796655133848, 0.13070678068024497, 0.12040688175587885, 0.28543127580515804, 0.23219722022693004, 0.10379542957150167, 0.15163339163747527, 0.20860768764490084, 0.1460019099496065, 0.10483556246805577, 0.11586600283701574, 0.19649816646931634, 0.09240488191285441, 0.14209624049403977, 0.19528384050053937, 0.1485124720080245, 0.18575586709043673, 0.2257208508108893, 0.15040578170409127, 0.2468891471864716, 0.21223820896158296, 0.24843301353675706, 0.24674230345314552, 0.07952254656101428, 0.2424643918751709, 0.12567704573514002, 0.12023768357692227, 0.24788866210128033, 0.14941455586062324, 0.160373367008663, 0.10870500362568325, 0.09551270909967924, 0.1293096354892177, 0.16308767781142267, 0.1913891720675653, 0.2147736841992986, 0.20544256474221909, 0.11897023707147568, 0.1719652119302942, 0.20188722729442582], [0.051009140893696785, 0.1021298778153235, 0.02340185636233899, 0.035576303489506245, 0.05358948590113752, 0.05007665867226259, 0.054496920877887364, 0.1025540606989976, 0.02644540302665724, 0.04200919358540447, 0.02206521488035158, 0.028251568306117292, 0.02092087104345762, 0.0025740800840374565, 0.08941598987627415, 0.05007921357549006, 0.026100025692534064, 0.012389979261394232, 0.0664202137399585, 0.07160253041694242, 0.022337909622658646, 0.04665085137070668, 0.01868792201182054, 0.022822858600486672, 0.017485458914551045, 0.03434122419886051, 0.015898527889212054, 0.04105735998300295, 0.03428507378445037, 0.10881850721254464, 0.06890388611223429, 0.04475645766022705, 0.04021487394047361, 0.02625387338470788, 0.04930386747864466, 0.009924469876193233, 0.04031346179544926, 0.01611542940560368, 0.06948479526345769, 0.062450426555569136, 0.0207742169168928, 0.028348604833046277, 0.02304325635064273, 0.023964827564815362, 0.019669906919701927, 0.05338330482763629, 0.014920450029744497, 0.034402055410488, 0.03725093338758715, 0.020391374052832686, 0.041957122589191126, 0.03482645662922052, 0.0061585353368202285, 0.03395513120678163, 0.08717885225891106, 0.03537090765612741, 0.020978888797183192, 0.04743111192158634, 0.024679999370428345, 0.009679000941105187, 0.005789332668251929, 0.05659615500800072, 0.05225891375073022, 0.048953857227799394, 0.006229317551779171, 0.03508934736131661, 0.025456898710540226, 0.040097371374647466, 0.036787913676591656, 0.05232008587148401, 0.1697595528657398, 0.0600538851933614, 0.03344638370758584, 0.032522880036624215, 0.07413219104731276, 0.01291552515354969, 0.015214811653770028, 0.024652527457463647, 0.06050038421826978, 0.029781091575240417, 0.05980182311407501, 0.03937880388431011, 0.009304222110058031, 0.02739187784402842, 0.02225715054890081, 0.030499894637614492, 0.012421640717694837, 0.0457473119510518, 0.007584077970785721, 0.008340036297487396, 0.043238010107269215, 0.04702629957107767, 0.010781540317581067, 0.06189227787657611, 0.0029278444051141703, 0.09075678163959135, 0.025432280475093473, 0.03179511757597568, 0.06098970372770583, 0.08258348150599389, 0.03579580300157109, 0.06485863543686367, 0.024524410743446603, 0.014583612660757236, 0.08114393334835768, 0.007920974711587113, 0.021745030347618367, 0.05057656551681219, 0.03638662150009506, 0.02568459727861468, 0.023246482239976045, 0.03745385858741018, 0.04259428940713406, 0.01944823363315194, 0.06630586745638041, 0.047302589180969426, 0.017853330505350908, 0.046298332181909395, 0.07122822751801822, 0.05371475276807624, 0.02318093192673499, 0.04157088787084626, 0.017109202491419933, 0.006259062351854218, 0.056584809245842124, 0.009259115810686303, 0.030270087412528457, 0.07383797497999284, 0.0325611422980024, 0.017255645943805575, 0.06320286662347856, 0.026671138494425727, 0.03381184212142422, 0.04790515563781223, 0.0424058739125969, 0.1043667856063093, 0.07924473243615321, 0.11226297641593604, 0.018640303901667078, 0.03181165549904108, 0.04716392343623504, 0.021990301057456002, 0.05138241723480244, 0.09252529561279282, 0.007335831009362254, 0.059189661405980594, 0.03264399853745296, 0.030834033461888472, 0.038593111770047296, 0.05860157401090669, 0.08224741405537052, 0.03790499244426047, 0.02171575429759199, 0.026718898330845182, 0.012842932577064682, 0.019575718324631453, 0.041292403419051445, 0.025894267882611004, 0.06371876172300789, 0.1288466119477826, 0.011705064098350705, 0.008340505526341017, 0.023949819902378707, 0.08134965093866472, 0.037826671445321654, 0.019218734758455428, 0.03443039300280713, 0.04018734840135421, 0.08823561692430128, 0.0078249087222972, 0.007739053727428039, 0.06359063351767198, 0.05224065787549462, 0.033184144150225386, 0.04119725912929543, 0.08651242471270024, 0.04650915957867138, 0.12383072787234861, 0.03028992142888808, 0.034291133539931434, 0.04053012678219427, 0.04386381967173469, 0.02741370560421098, 0.01966488521335827, 0.0011878646933661415, 0.056997171392844576, 0.019041283897334532, 0.015688677254553526, 0.05097316157433295, 0.0215265822912296, 0.07151922601605616, 0.06735540791264466, 0.0496291215982168, 0.04062393807896203, 0.09559536232582985, 0.05883144252302666, 0.09931953023037604, 0.021977687419782725, 0.047013218619770585, 0.02826254443085242, 0.028821443876011238, 0.01996362119943144, 0.01149197291177247, 0.031529953477964286, 0.022443658484506513, 0.045203780229654045, 0.03496109275147319, 0.02210025765722798, 0.01719684869561705, 0.034199708607047796, 0.021406923187896613, 0.08786598716171519, 0.04130540010068686, 0.04624469070545128, 0.08307289677642046, 0.06368493128027167, 0.0201787214515911, 0.013925307561763594, 0.04349049353491395, 0.024039185973965836, 0.02438868103068202, 0.016212184395220493, 0.013046092391314526, 0.004611212493581397, 0.011671864720542106, 0.025816293538457928, 0.05159746577602722, 0.03067835290435582, 0.02169156315616302, 0.03673706842105716, 0.09062122238138992, 0.021374071422483654, 0.06353701502385159, 0.026487614471285094, 0.03312601339853099, 0.01578789138640728, 0.061475357506424196, 0.011438167684020535, 0.022083781021196517, 0.029221462431333722, 0.013102057029403025, 0.04386739347190146, 0.04850992076699773, 0.06465152356653445, 0.011724482512011403, 0.04705813818521077, 0.03739139560850398, 0.0666002597239229, 0.037975974320884676, 0.0071398111345667035, 0.041652882261382, 0.041409860019602125, 0.02833391892753782, 0.05745490126672292, 0.06484096178845053, 0.005812999518257716, 0.07139297472613473, 0.009216235954344515, 0.04788488112089615, 0.08919963132469885, 0.06259846155561748, 0.07039269372340172, 0.06049973304353415, 0.026900909330335357, 0.028283899131741737, 0.03863279895496465, 0.0820208665344023, 0.041458675142137275, 0.03099962911238113, 0.03681920836829851, 0.017431129874180884, 0.026597904319304134, 0.011766564679302037, 0.06260220772556721, 0.0719303317788628, 0.03211944281393963, 0.11774238198995592, 0.06979958079154454, 0.055496960562924226, 0.03980249647171267, 0.0576861678893047, 0.029008932404160023, 0.006368114010265638, 0.015522035894044226, 0.042022569480562405, 0.02920624217949808, 0.04910265831577201, 0.05471733969546134, 0.07290550041943789, 0.018447546603819056, 0.0397337937066632, 0.028778529545712857, 0.07246814848434541, 0.0424897222359094, 0.04135798054536985, 0.10610305493877781, 0.05635576044780113, 0.03414341263593205, 0.10456399962065682, 0.023433769670044704, 0.0556253683903525, 0.035925176099783955, 0.04226712006775122, 0.026113866986106002, 0.05362654540447458, 0.03236735652711603, 0.036480474931698655, 0.05131122851443868, 0.024222236937813224, 0.028952753261452722, 0.024886214917886163, 0.058250364832459926, 0.049808072076449474, 0.08936024165802425, 0.01949585940418465, 0.09581984907028177, 0.005681019805882487, 0.057700666103271715, 0.02460500319308091, 0.027179694471640453, 0.04019360733969558, 0.035507485811268134, 0.06312872080372707, 0.05481833306651923, 0.02781746075338414, 0.08705713620950138, 0.06086868481830724, 0.03714301458169376, 0.08040146391478278, 0.03527606980154111, 0.02523940443361719, 0.02118100194380649, 0.028190417252781413, 0.013507355845743611, 0.040327779978754065, 0.12210065619118753, 0.027005593329968474, 0.06029857367637658, 0.02437743294473377, 0.05229128096553107, 0.0276771211065352, 0.05429095813944455, 0.03214586135600844, 0.04397277269632586, 0.012215985372031649, 0.05152064630941999, 0.04291580118719609, 0.027579965835977948, 0.0343869136826646, 0.06200460551847374, 0.06468748373370017, 0.06307983673327873, 0.1996594282888597, 0.22484464540837273, 0.12777919099936563, 0.17503566168729337, 0.12537353702129858, 0.23850538737831578, 0.15358213545574298, 0.2345221898248119, 0.14579339613837583, 0.11641865866559169, 0.11661186604009521, 0.09432633767925924, 0.16927481839253058, 0.10536089960125186, 0.21766879175218845, 0.1298545385079999, 0.10916995770868756, 0.12299615168763746, 0.17737272015262037, 0.1312791249684749, 0.1940797188229138, 0.1980619511056331, 0.12930566715376993, 0.0994267825397753, 0.13671211327516264, 0.07536488014363474, 0.07476419060220642, 0.14451392205251803, 0.10582527145743371, 0.2585670850690334, 0.10647158153475293, 0.13180890541163184, 0.10798273593067162, 0.06400297268203671, 0.09447654453857292, 0.16732176916012842, 0.12737621342943561, 0.19719539841096248, 0.26926988495453713, 0.21157181971976835, 0.1335649627951845, 0.13405417122187155, 0.11295104594600779, 0.12733895857367786, 0.1363889161016672, 0.19219057664515513, 0.08666852278815163, 0.07873987283317313, 0.1800944007212116, 0.15399867278193274, 0.21532384258124138, 0.12543965807004323, 0.12645537574445048, 0.15492347880236565, 0.16863783160524984, 0.12621074088759002, 0.21013149781332863, 0.19312918756998357, 0.13244630588639167, 0.08008687756955624, 0.16780150874007135, 0.1581358693299755, 0.06749518831530887, 0.11727036457628974, 0.10617009529303159, 0.14184286457396325, 0.18643098973458816, 0.19117036203463234, 0.13461874737854929, 0.23429136753322619, 0.23594052500782475, 0.14047928935577794, 0.14925749251438727, 0.09295432017214837, 0.16377642149886779, 0.1082977053198603, 0.21112926604767002, 0.13089634147622894, 0.18791398273841028, 0.059434135384376974, 0.13713897746657172, 0.07439443826555245, 0.13736630639722272, 0.1605498123793833, 0.12419099604049999, 0.12978206659036298, 0.12870367526287033, 0.11858223652046536, 0.09111623775454299, 0.17946636184088646, 0.14477751758550444, 0.1153330507898523, 0.10691834869043482, 0.13848114818815263, 0.1127938217213077, 0.169166294377177, 0.06972385300022942, 0.12902734741087885, 0.24100099540045186, 0.13812124008132567, 0.22032428232412185, 0.19692890706562227, 0.11436270084232093, 0.08686459533149198, 0.24791463248191342, 0.10843199287210742, 0.08305219708070641, 0.11701267558119952, 0.10782238606724048, 0.18465671478019607, 0.2199026275305979, 0.15565480165664228, 0.14604836552133485, 0.07767363932103881, 0.23106123440929, 0.12084612592814431, 0.12433416255178953, 0.10770861434960559, 0.13630119903433707, 0.1984044843383374, 0.12878947711038974, 0.1312294211839476, 0.13360706698750296, 0.08785418940768128, 0.14023803294666354, 0.06881734115942832, 0.0769714201470056, 0.1861940234178497, 0.07097305895219888, 0.1243096017729371, 0.20887382658979586, 0.11132344618559846, 0.1280715378121503, 0.15798925542302672, 0.09984446133697226, 0.1587732085177014, 0.12049415449221289, 0.26747445065167647, 0.12432195877115573, 0.15543000081614142, 0.19257769619505252, 0.13613204682065597, 0.12964541182642983, 0.19289163902642267, 0.14012341087143268, 0.12043259166661771, 0.17165862354299716, 0.3824171796441079, 0.10925885455142106, 0.12408012013521888, 0.21810265798722545, 0.1829035225654802, 0.18857033622841682, 0.2269279142661441, 0.14270132738015345, 0.22471965050264714, 0.2224309628288592, 0.16541293852271574, 0.10766593559134392, 0.27345045740085266, 0.07943289129123574, 0.10747498051533777, 0.14555403962731361, 0.1823699270044604, 0.1797317806631327, 0.11349794079339313, 0.12568649159924639, 0.1413126551215687, 0.1537357514063197, 0.10959455427984077, 0.12503642003021895, 0.14546837567562057, 0.1031430061125467, 0.12586993135271535, 0.15840234535355724, 0.1579219622597579], [0.05415359857462106, 0.027536856153258876, 0.029911510383469925, 0.03713325462153843, 0.08054695167248288, 0.03912532454236381, 0.03944890475982139, 0.03659045451410836, 0.049971348395751375, 0.039110324540806395, 0.01857196885882126, 0.03544060633547845, 0.024363024746097868, 0.021205895970905983, 0.09279228491528381, 0.04458317623263405, 0.02855959310827236, 0.03446005209679565, 0.06701670511956177, 0.04206811340766088, 0.03495245511012693, 0.1049723398060568, 0.06751475420089499, 0.02145289229379306, 0.03888652727548634, 0.0008600589024999571, 0.027113092702723322, 0.06814196570626191, 0.08384288408823552, 0.025839812437733336, 0.059388763827061465, 0.05166331486355874, 0.03685955055839112, 0.060657899556381095, 0.052796416360163884, 0.07780857804802158, 0.040143612441757036, 0.028435919704216144, 0.021308630276771805, 0.053985863623599854, 0.03086901112129131, 0.03726132537028001, 0.05099907449837174, 0.03669428241048609, 0.0415727034992268, 0.05247996076040211, 0.042724367306237264, 0.022279445622717182, 0.06586334442779904, 0.024954295236497157, 0.060971336769721204, 0.0697054898726844, 0.04927177988593617, 0.015336729758869738, 0.07820426246091243, 0.026995892741627274, 0.053175009351464055, 0.01481091382072097, 0.08014403538958681, 0.01900023116069215, 0.027025613122649735, 0.06046985561448721, 0.020460239611566067, 0.08365527681645848, 0.024066943254682328, 0.03545877794104238, 0.040331288661447265, 0.04054642530278333, 0.0321172728698941, 0.01569011175419174, 0.027730500197879253, 0.0358411745588866, 0.07086930766461358, 0.01492470277533416, 0.03170361794951943, 0.06388460443685613, 0.09721949936882143, 0.04364743813752167, 0.017809240230088754, 0.030440553466999726, 0.04579582829929648, 0.034837649173794255, 0.03815784742454848, 0.024750416257208394, 0.042672280988265435, 0.05420314914156353, 0.03531106086748262, 0.03328326826674804, 0.11515537967845318, 0.048094620672805656, 0.0364752923468909, 0.053582131457064426, 0.0173133151275256, 0.032387772770298105, 0.052556048613041646, 0.03496332972821209, 0.042509751604689706, 0.04475879422839611, 0.04791024629206908, 0.05366151348777837, 0.006868923402151034, 0.05816666589629266, 0.02567617605710703, 0.03065454289166918, 0.044713522262510755, 0.036848292896343816, 0.05743175008965116, 0.040407273092217026, 0.012576342597904225, 0.03044980014824579, 0.04864143125051933, 0.002688951616648645, 0.030684991056219708, 0.03678200713869545, 0.042540038890776136, 0.01863814927938004, 0.034311802592128515, 0.035661220505473115, 0.08814694990794505, 0.009762002737261355, 0.04489976206734296, 0.057502785592430064, 0.05651470837033084, 0.04127024432584163, 0.031364126085874536, 0.017991048216278997, 0.03438285341666591, 0.045093038389759685, 0.0314850339125241, 0.008416254385074061, 0.02377668403149132, 0.0570304464218357, 0.04992012775713398, 0.05816409184086708, 0.06933612824087182, 0.009534386523638763, 0.024266277417360295, 0.05179259220078107, 0.03613441386410306, 0.07257181550225905, 0.022274052363730246, 0.06411816166233152, 0.012498089589268692, 0.02046332886112073, 0.05225260501667377, 0.07308705559661312, 0.03073877617416363, 0.03671668665183168, 0.049758268700492, 0.010798154849438898, 0.04938141472877995, 0.014224501285371522, 0.043294857661690445, 0.028672349759407585, 0.03894024919117651, 0.03998888949412973, 0.017899598385537827, 0.011804676595925084, 0.031239385904383757, 0.049535007696718945, 0.06516958286444988, 0.04048837115988135, 0.037002533208578825, 0.010736784503434696, 0.03656724588044229, 0.02386084262041315, 0.030409009796717477, 0.09870912669406784, 0.021379977960379857, 0.027095219871449857, 0.013450911445092532, 0.016591717759447715, 0.06350643662435394, 0.05758716634684994, 0.011223017636145796, 0.03570501009122499, 0.04087592737989561, 0.02212502527981997, 0.053450123016392036, 0.06549828054924166, 0.05609635158532089, 0.04409556509926916, 0.04703568797858973, 0.09019013704551805, 0.03894610210291801, 0.018105268095349594, 0.059106146330915155, 0.018952660931033954, 0.0717567285943416, 0.019165461004200964, 0.05241663210214146, 0.03220638996290584, 0.030491475331326647, 0.089081822323703, 0.018927561975414717, 0.018283663159837166, 0.009344724221004835, 0.024582924539103143, 0.08110408911541586, 0.013652713368496588, 0.03598489265348162, 0.023153963716580503, 0.03465373444581225, 0.029211738860354792, 0.04956058737251067, 0.0178915755297508, 0.04716418007568968, 0.0650433928615624, 0.05081472310027288, 0.05430311978524251, 0.029019404826084935, 0.02543767756452003, 0.055493501675946105, 0.026666388749295188, 0.03201456154666601, 0.03770915355773703, 0.012641038723109711, 0.02957687360204516, 0.028806058915271878, 0.02708102234699313, 0.00998318860036952, 0.048424524946078185, 0.008511453258594679, 0.02713300715831499, 0.049078901929240075, 0.0008525900240431751, 0.011002574878324185, 0.01894833444948158, 0.03713530007629626, 0.015031472449341129, 0.009297311996981021, 0.09282758624683465, 0.07509930810380368, 0.023372476890442834, 0.039182126131509586, 0.025049144582402323, 0.05611814295632705, 0.032942700049569534, 0.02603499823430133, 0.07276115413274496, 0.027018680026934996, 0.029133632366034775, 0.008895245114070995, 0.025652122811504433, 0.0915435539378274, 0.03427121142346052, 0.09743406527465391, 0.04656945452875188, 0.047010843747205315, 0.03361000476645366, 0.03258332437384994, 0.044688386917715116, 0.08580610696827212, 0.010637802113178036, 0.04553032137693898, 0.04511875596137778, 0.020562763243252714, 0.028147709766222585, 0.06308827136132507, 0.059922780736439654, 0.02322488622139058, 0.010633343481458725, 0.06961761958776944, 0.011436127017312234, 0.0399658685520051, 0.03742310781812957, 0.01970023634062419, 0.03563187550753355, 0.008991028129633878, 0.008960466009504613, 0.01643544348377374, 0.03532395795768788, 0.04655091903142391, 0.0481004812454264, 0.02474595379504946, 0.00921947459104441, 0.04519826439659923, 0.05778780860465862, 0.056556896832320964, 0.06318826881808139, 0.0479901607538904, 0.07770744678113731, 0.06608786947664715, 0.016395503489841378, 0.029428760077984586, 0.06616892923991527, 0.016320618395242962, 0.026803936005660126, 0.03421262867989079, 0.030204148309665824, 0.023958141532456203, 0.026522527013214368, 0.056419759432995514, 0.052044435945009036, 0.02260783878755906, 0.018661137662767883, 0.04229000311404948, 0.0382471579547611, 0.03107649454426381, 0.015205125429577407, 0.0907232346493871, 0.08091285058687772, 0.052142656077781034, 0.042656572355378064, 0.03762996687944378, 0.027368571534151995, 0.03658216927320727, 0.08467785097778806, 0.015256540463005584, 0.07112692005091137, 0.019791839388950218, 0.009520077916433015, 0.04209101177571763, 0.011899245362127981, 0.03361314955738283, 0.07119984396042363, 0.07825627983097108, 0.0034045282518491153, 0.005565737937426856, 0.03453145149133859, 0.084882871428084, 0.017202209395867203, 0.05680991269107308, 0.004396105059347446, 0.0689769249349352, 0.0322481915504942, 0.030215346599898996, 0.05737534686622601, 0.07957998017269759, 0.03733966552141694, 0.03014530126576222, 0.034648770196062904, 0.039901528657684406, 0.022290787554436156, 0.021550995598156607, 0.0027448937509043686, 0.022880192620739825, 0.04846830687095081, 0.029092018469987862, 0.0421362875720426, 0.0031707522125103546, 0.04847013782108984, 0.04217987797493416, 0.08482828000259977, 0.08118578473166113, 0.034929487794157, 0.06383268282778802, 0.015725778892726427, 0.014158207866843912, 0.055111978398335565, 0.023622993387341983, 0.05923392979668514, 0.18510066273231662, 0.09498652926976643, 0.11200766229341108, 0.13410280248330486, 0.23671096431151514, 0.15203388708253063, 0.12996704618055976, 0.1836680936356706, 0.138657501628322, 0.07572281940449631, 0.13963167435459553, 0.07444521457317375, 0.13405840002721356, 0.12535855234149965, 0.21162504750874736, 0.1455757812026047, 0.13043351711765414, 0.17959028422351808, 0.14303108226628075, 0.16826287753159003, 0.18921432505932548, 0.11958182038318728, 0.24648544949389276, 0.11896441480325115, 0.16820183564578334, 0.08602792772674754, 0.0735166930263081, 0.11063620403048494, 0.17585768935180482, 0.0963442285935725, 0.10591209220189242, 0.10049644046493116, 0.09624868976853548, 0.11351497858882913, 0.1224370837031353, 0.1554722735478032, 0.09135063767673508, 0.15820132388222605, 0.08787927878720146, 0.12909081013452622, 0.0752984909641166, 0.14588416223564457, 0.16554513465492957, 0.10099394562383814, 0.18390846138279285, 0.19251483101998607, 0.11086926329880954, 0.09177312750609652, 0.10804479671341759, 0.19219224671683005, 0.13719833395894498, 0.15254872881116407, 0.13183766435230934, 0.1412797746278586, 0.11931020390963364, 0.20305197205274336, 0.12057385827985503, 0.0882520495102771, 0.09816548005948145, 0.10555361667948385, 0.15373789645250768, 0.14730632785827885, 0.11751829361122464, 0.19031942221185855, 0.12915531473775066, 0.1981659858457504, 0.10616696199342128, 0.19260162878180706, 0.17625364955634842, 0.13915392660325573, 0.2660806609257575, 0.1575302921475903, 0.15224544992369993, 0.13980053545486543, 0.1305468521651722, 0.16003644153956445, 0.25912016990684694, 0.10792789169617238, 0.0861248531709275, 0.13334535603081027, 0.16023292777038392, 0.1265399978165665, 0.13631976900562165, 0.15558606824807583, 0.09580468819026025, 0.12570425717821046, 0.23187025390084715, 0.1220343589422203, 0.14295330902020778, 0.13364572378416217, 0.1702190983679987, 0.2040365022877532, 0.11590387822399217, 0.09967635100286815, 0.11198425064644507, 0.10457087909021687, 0.12057117697212005, 0.08715446001940197, 0.12094653707237975, 0.14357282900281493, 0.1712311924465241, 0.14766130235887345, 0.11086258301210981, 0.15590523579908958, 0.13280272063228393, 0.1665173921613924, 0.1714013558962653, 0.11529357427911413, 0.17510441041761832, 0.15849897968432597, 0.08764511635226589, 0.08669732003322533, 0.07824957656163363, 0.07049331171137672, 0.131665003455935, 0.17672893050457203, 0.0993932432104503, 0.09734102389625005, 0.239506526399524, 0.061894959184311094, 0.11239814496929608, 0.13062781233701015, 0.19674409601476886, 0.1386115976398991, 0.14333960119514697, 0.09729355708846162, 0.148638662010912, 0.10442809562288946, 0.1998384323932471, 0.13789950359252193, 0.2084064976342263, 0.26631456289079886, 0.10713699018402446, 0.1602098378803461, 0.21319010385101844, 0.09193714693068497, 0.16174584416852844, 0.09981721925038485, 0.08347791214022907, 0.12875736270460392, 0.18471020303906935, 0.16445382708503356, 0.18838160280739108, 0.23269287911393952, 0.11646781852769277, 0.1360816229134798, 0.12257127932483151, 0.23361425306047165, 0.18655088249473803, 0.0732782481598758, 0.16435874025187186, 0.0712498082148452, 0.14337001488574092, 0.1088868652380282, 0.10562509268281922, 0.21545230020438472, 0.10232087885660511, 0.16726943003314157, 0.11136933485226286, 0.09642787007314545, 0.1362247281377354, 0.1236961568675695, 0.0955582530267777, 0.0974964554752073, 0.10790339986523313, 0.1136939290670618, 0.1843232213849983, 0.25353466881619346, 0.29070922323772985, 0.12750589679325783, 0.1966849693487729, 0.06588587507365212, 0.09979066664292928, 0.1292001002378041, 0.08609661517003853, 0.1041306849689253], [0.00867385528005299, 0.08283645906034978, 0.06212286651134492, 0.05337668582797051, 0.02968538612607987, 0.0528723931300544, 0.03715020814730275, 0.08172156364326516, 0.037603789655071114, 0.07953690304871529, 0.01329076651018113, 0.10125102174858894, 0.04672644509663505, 0.02949364580995133, 0.023498885228388736, 0.01982494970903762, 0.056502412659146135, 0.03478021556211095, 0.08449385198013437, 0.0756371094875278, 0.0465573963048237, 0.020551819677254366, 0.06987284944062272, 0.012338663819396209, 0.03801339005510654, 0.06948963693913913, 0.03905143919250658, 0.02395913936197758, 0.020308014110571915, 0.06019072381839637, 0.06580440162290489, 0.026152360989081285, 0.05781511963915922, 0.042225410410713766, 0.06305768913138779, 0.03603098816388557, 0.030260492161276843, 0.0355448670715334, 0.0038995733109092523, 0.07949944134921798, 0.05278414363161691, 0.0247112576729588, 0.036774690999018575, 0.004973628101945525, 0.06365883449513106, 0.06052218325015518, 0.08567217181647017, 0.03171056062133322, 0.08106088175648644, 0.09259102595669609, 0.023135874465468432, 0.02574427169747651, 0.02859670240732451, 0.10814690857284492, 0.028868022021807493, 0.05443930723554185, 0.010266854679362189, 0.03135691145284763, 0.0155826851597897, 0.08848982021933602, 0.019132009774987257, 0.07226382517406056, 0.04758612215218525, 0.02810120822921876, 0.06653930976866715, 0.012681537003616893, 0.03545867834961222, 0.09842277068885104, 0.03931971552271036, 0.0783119437795493, 0.0685655050760796, 0.024865672270196582, 0.04086160536615118, 0.07268091408355583, 0.028194716921256437, 0.025556695069216435, 0.04713719845899651, 0.02704750408508605, 0.10361673190228401, 0.04375159545170684, 0.011838262848135446, 0.052573952087832075, 0.1393670369420321, 0.04493686753595549, 0.028714475019143957, 0.030656140184991305, 0.052752569317817695, 0.0568893636697002, 0.01558691588035154, 0.014925534938341908, 0.026300725406937064, 0.025557168128509677, 0.0343569902883422, 0.0604854608255048, 0.04691587182723227, 0.019801760227569652, 0.03431712307276265, 0.011669106804014695, 0.06666989711624, 0.028634679300950903, 0.040077947215327335, 0.023492352413614432, 0.07546351396388586, 0.04993388669625406, 0.03805611094820403, 0.014765924349757693, 0.03749612748863236, 0.07346518893515872, 0.008798895193444145, 0.04116443226174001, 0.07579037303765936, 0.03722000641808395, 0.027906420798371398, 0.031193930077396577, 0.023849209575282953, 0.05215998881706788, 0.037680095842769074, 0.047869574684169025, 0.03775728303157995, 0.04352684823736068, 0.0867329661043421, 0.04867701220416254, 0.03928265218893367, 0.05706397425984183, 0.07348005104088977, 0.04416832813031731, 0.04781266201227423, 0.05389632326700995, 0.04793571488511178, 0.005015997552207762, 0.04165518052515484, 0.0667471417616452, 0.06320072157729058, 0.08195504425994812, 0.030675010845786145, 0.062115500575952956, 0.0398065643985906, 0.06221419185279839, 0.09427558435427566, 0.0365433745807217, 0.037095310286648815, 0.026672952207586458, 0.04597570957435716, 0.06661630926593658, 0.02110482790627547, 0.054880156362008665, 0.019078081015557535, 0.03696533580941539, 0.03458747550124123, 0.023718547534137487, 0.022473051362941344, 0.026451014620702595, 0.044326938974160346, 0.031046186190759464, 0.04623956940767746, 0.04720353018192034, 0.04375168738225776, 0.037723510045438044, 0.10831512615925844, 0.03648569965134225, 0.04017454324169986, 0.015270447831660991, 0.02708965615789977, 0.054349782200710434, 0.037920210780876304, 0.041672919291041555, 0.06062764674425126, 0.0420738973714892, 0.045218921957477454, 0.02681635429091271, 0.01036387971497231, 0.014323937582723318, 0.0409889291791666, 0.04425219560582792, 0.07396539072355918, 0.013075751485303046, 0.022362866852011894, 0.06613447826596038, 0.04726210909505044, 0.007605551894108255, 0.018024261958236178, 0.032338957647762956, 0.039000789289392775, 0.031069837240201813, 0.0847791584448949, 0.09425677689573458, 0.059612541940183415, 0.04778564209118486, 0.03381018737150777, 0.03092124108074894, 0.01296949796303506, 0.042460718147096135, 0.022921082563698295, 0.06986878917462404, 0.054749090209483146, 0.04157072316194254, 0.007800329748856565, 0.03144172313172491, 0.0874087858885046, 0.041636790584532485, 0.024386566628011006, 0.02448889299205715, 0.04574488728277145, 0.05605116005866759, 0.06155125000664304, 0.025474949657256087, 0.04929720251370342, 0.011571701597272149, 0.03974360729297323, 0.03616678490934353, 0.028229596904448928, 0.04121531582167072, 0.04417893461762898, 0.01840161771753863, 0.02147343111104302, 0.08703694213181735, 0.04134665776584898, 0.03746949444194475, 0.047943567286335656, 0.017002938435442986, 0.0678226602594218, 0.09112458811291764, 0.050018010811219295, 0.03911536156890854, 0.008893542483659282, 0.08495157419313347, 0.04172077680367135, 0.061176579385515184, 0.022782849658641125, 0.026742045677477316, 0.03609501779259693, 0.03088982956063363, 0.02674790241965844, 0.020976826105447068, 0.016383332267944372, 0.04666502782774549, 0.010052967718952607, 0.05351697567910437, 0.044445096545161746, 0.036135325508732954, 0.03867244017460654, 0.058817817649293336, 0.013447442024405445, 0.05920317136652528, 0.041273178442591624, 0.06306016742582284, 0.02880142599854979, 0.04466843415772723, 0.026456509386339498, 0.07428838105331506, 0.03024214818592995, 0.03109781477119654, 0.023245605069302747, 0.03127838744060888, 0.019951448062314622, 0.01109088087574609, 0.040557614016917445, 0.04693890809111538, 0.038965062779043956, 0.03989768289630452, 0.03967740197455691, 0.03850528745040779, 0.1452985339828076, 0.037660966627299786, 0.03567123710508308, 0.03378472643934431, 0.04441217008617617, 0.10969400015329162, 0.04108262939318534, 0.07453489282559003, 0.004524290721277677, 0.024142485269675815, 0.03906403750842137, 0.028476706225304838, 0.02891253939108743, 0.08288443914704746, 0.016982820966551383, 0.036345731557136586, 0.041873006135105126, 0.055556638812225674, 0.030842887523073344, 0.01566053980270461, 0.038665725413950226, 0.013333373447699894, 0.06012263775412595, 0.028647639593409917, 0.046291280342566396, 0.04857090902664969, 0.05761877130416613, 0.03245898064285998, 0.026010517894680944, 0.0617164530370745, 0.029568159351906473, 0.05534192734968759, 0.038710039769930225, 0.05734229017229331, 0.04154515114703006, 0.056186405220820065, 0.08118152528280213, 0.025412528813185713, 0.06286108415694007, 0.030162494194002885, 0.05844090239054734, 0.10083958656797487, 0.043926631220646446, 0.02999791744044952, 0.03278986167823596, 0.05019544060492227, 0.008575898490004964, 0.02491450654492984, 0.05339632449190944, 0.019078858594800678, 0.042719927826716055, 0.04485894873317692, 0.03658973439145954, 0.035394089476716135, 0.021307134490099647, 0.010701022561519377, 0.009771944643298705, 0.02771686766326668, 0.04324992277449177, 0.013048921170974932, 0.10168285018974736, 0.05235334174827703, 0.04765336935017859, 0.03901703035338752, 0.06958651641804366, 0.024884998753306367, 0.032385892024443995, 0.04824989520373845, 0.03466856973846594, 0.02731559846940781, 0.08714668422697053, 0.05700655596991701, 0.08773696263350787, 0.03211117097957721, 0.021399348493545287, 0.030748516982120853, 0.0864258491163773, 0.05785121004127207, 0.10393154807388784, 0.02436959203482876, 0.07832400966435671, 0.07385504341894582, 0.03719483276889209, 0.046863444600134134, 0.040999512683840535, 0.027520272264918013, 0.025452742683551004, 0.03881432731906253, 0.09299364346530169, 0.024921460708062497, 0.0989560138494257, 0.19692051074197217, 0.18787523401120018, 0.1562392960993513, 0.1032446276757025, 0.1683621472048183, 0.2790463006784839, 0.15189505662889252, 0.14139727719368475, 0.20013785019757288, 0.1302540227169952, 0.19482264024836404, 0.1852026903220723, 0.15442781991535617, 0.12468998740998008, 0.1557915943164018, 0.18796258335632665, 0.13869058130489242, 0.22547861380923181, 0.20165096577857772, 0.09781269657035029, 0.19148344684752727, 0.18742987645729897, 0.135885535048381, 0.15016519945235024, 0.13584565251104294, 0.17641662710135983, 0.1065936729672455, 0.1810922762078624, 0.13391990665226214, 0.11873905471856556, 0.12088190989508746, 0.12328897347493518, 0.10866566501077145, 0.19214628144137322, 0.14712680281410295, 0.21360265752000196, 0.21329332653793598, 0.10034251041830548, 0.18148924764846602, 0.10929105322687857, 0.09884030392934239, 0.13172860407540876, 0.11791862817781588, 0.18102591767186121, 0.15770152812042545, 0.18603293044913202, 0.10486319525948457, 0.1778480777096364, 0.24023666947839722, 0.16363705478368268, 0.18416290982596337, 0.09771677470135112, 0.1723893948139683, 0.14654751776927902, 0.14193635794424242, 0.1773404065639742, 0.15969168665187974, 0.08570021063449883, 0.20296604763115608, 0.07101532402298144, 0.20649576709876138, 0.10443610124169819, 0.1939678086989349, 0.12516134598803136, 0.1899263731414272, 0.16581429198624628, 0.2855982216856172, 0.18657276196585548, 0.10086865194382207, 0.13101332310226657, 0.17838590207599825, 0.06635260648064076, 0.1591656906830688, 0.13401134690690425, 0.11800406230313164, 0.1128047384742287, 0.12423428766910108, 0.22665892547417074, 0.09391756848462167, 0.17794995208180722, 0.1084374474181283, 0.26022492998069335, 0.16206162561091686, 0.08142321070115413, 0.18166941620649832, 0.2189873056786676, 0.15778510831296444, 0.10058785773693554, 0.1977063330911821, 0.14231311998540355, 0.15811892346509043, 0.1371571950374111, 0.19929248749488787, 0.12616018674546672, 0.11802424105905718, 0.09083748134153505, 0.10883476359829788, 0.12262871293651482, 0.12114377406936501, 0.16453710084240283, 0.10364690044474217, 0.16853516050163778, 0.2240184655473117, 0.13914134743953907, 0.1059007770832508, 0.10624072093877102, 0.18285441632953384, 0.15929102266748107, 0.160522953336758, 0.191135045381323, 0.22167198420051606, 0.15761240145131467, 0.11067883682347114, 0.10412890764494097, 0.14180129664319177, 0.11411291021373003, 0.13416375243856063, 0.1494529521873882, 0.13525738891574646, 0.13975480000578588, 0.10500135921662855, 0.14611573529339608, 0.16654244323651637, 0.3178702270792377, 0.13329004448267723, 0.17473779138057463, 0.11590194002154375, 0.11701071439611337, 0.09872687695127341, 0.1173797083057223, 0.14611939719367414, 0.07972648682733698, 0.1220417516906896, 0.12405607263527571, 0.09342821450122903, 0.17818621359765532, 0.1762891347490011, 0.14050230263702332, 0.16887300527624546, 0.13526644407501145, 0.13289789939599653, 0.09414377126602397, 0.17926236794840905, 0.07084248692638452, 0.10730425016053262, 0.15596123682635446, 0.13759467720745072, 0.08663188080273329, 0.1316902383921608, 0.12872385401879588, 0.1483819459474856, 0.2387811330657813, 0.13191012094818777, 0.189631674438715, 0.12446520955211694, 0.23635091830886182, 0.16526410296078653, 0.2544713798429697, 0.14519187922198928, 0.13817091322233602, 0.20028708412522273, 0.1665061306689055, 0.15683486817344544, 0.17485066677533811, 0.20857839244267634, 0.2120030965776213, 0.1524319770115037, 0.09601205286960449, 0.09944694597394237, 0.12611637417707713, 0.11932043884430202, 0.11318676353942965, 0.14448667996593062, 0.15484205897777312, 0.12554070506725581], [0.020509307543116233, 0.00398636915751042, 0.048398470295773405, 0.04606063042076365, 0.038826902652339595, 0.03366696723406354, 0.06641844407685342, 0.013855562917137099, 0.11348021351882528, 0.052458571585556196, 0.027837574391836123, 0.026221575117820216, 0.018809103714903037, 0.052390313151502804, 0.026323709959885287, 0.045764499133633035, 0.02188327282877459, 0.01813122889988365, 0.03960753475586253, 0.010785776783802338, 0.008400698969771546, 0.0036036663438989633, 0.0241549571810831, 0.02262081057133694, 0.050040687013778, 0.04132683141036861, 0.011534445783904484, 0.020462848140948245, 0.01890746365872122, 0.028540929291217078, 0.04360049609996138, 0.015029562017579955, 0.019035091991686535, 0.007572991720911477, 0.051848692819476135, 0.03316542862223522, 0.0840213136266797, 0.11424394189229897, 0.04793317530364279, 0.0580309036247913, 0.03592012374992332, 0.012369333191834872, 0.09790864142198717, 0.03819461964491395, 0.08284499327982627, 0.0448005460202694, 0.05893200688484696, 0.01702417630792385, 0.0529005277090736, 0.038540228720634215, 0.09061477958194672, 0.031304549343223055, 0.007331796120026059, 0.04552027413381204, 0.09540786230636221, 0.03122745408496309, 0.05209489815658139, 0.06444235858056815, 0.06376313353558222, 0.055129881873125994, 0.027260461206277533, 0.047129269448980216, 0.02389596009086217, 0.054416726793973684, 0.007662571818312451, 0.016545281339917454, 0.07333477012692921, 0.020573838959417997, 0.07796823843232087, 0.043420886786113826, 0.026968116308712674, 0.026731395140110005, 0.04011457387898718, 0.03370611049655465, 0.061420984415998386, 0.04260028404514155, 0.029098373169319767, 0.01929822404147877, 0.014419307868416994, 0.058780593437052546, 0.051597496419544184, 0.04591748689211184, 0.048477611008791194, 0.043833532385648265, 0.012146359471033418, 0.06036370264125928, 0.07567234187116546, 0.007273872690876165, 0.07741319240942117, 0.03497478274268008, 0.017503632435334787, 0.011267182604980566, 0.012095063181233504, 0.019070803180276867, 0.010997285041207028, 0.014642930848734274, 0.014393096170087737, 0.08330065471630904, 0.05085280916142849, 0.04202384118651671, 0.056219461914752765, 0.0637381092735356, 0.053730821462288025, 0.050384158704189524, 0.04205311723654309, 0.03885296496352361, 0.017095763394008243, 0.026551471730213494, 0.028888344419218843, 0.03458437284514789, 0.035587545829795064, 0.05895055004305417, 0.02247235996858968, 0.0252377956489762, 0.026503572082747857, 0.040563899768336166, 0.04976280011056412, 0.02404843840087133, 0.037434541680399454, 0.06646496859649498, 0.0509036582474026, 0.027431988292523933, 0.021210337365646998, 0.016354157724567962, 0.044984146652202454, 0.03195793615774282, 0.04428404571127988, 0.0135404996821777, 0.04782865409769359, 0.05985543777745578, 0.06756530834301826, 0.030311076946917082, 0.02915221957429763, 0.04027761271103256, 0.0422644502513351, 0.015772950756664, 0.029653794575302355, 0.01573177640356364, 0.0416880150535895, 0.013635174743080092, 0.04915061541983197, 0.08171975567576387, 0.05242577919195737, 0.033667120451648394, 0.04090183264305515, 0.024067153928861506, 0.04866334136515375, 0.046801372326069304, 0.029010357327699184, 0.06312921109999861, 0.01835791048623862, 0.02086523007751713, 0.07596988276007675, 0.08092311616506308, 0.02997482755041171, 0.07497551595611919, 0.030265326176079053, 0.02411250824919872, 0.012073063051267978, 0.015398354829108764, 0.10843637489503431, 0.09743190490670743, 0.035461957205928145, 0.026244712888353297, 0.04127151986223556, 0.053451823731583935, 0.07532471415376471, 0.05036810150129661, 0.020440210242785757, 0.022859303318264506, 0.026923284843383778, 0.03586717175259706, 0.058431460356880585, 0.03840459668407998, 0.03281136959671013, 0.05770665308039996, 0.0381548252076872, 0.021650056512425506, 0.05754494341090322, 0.02362069320834933, 0.0379280133863851, 0.04011072428716768, 0.0589001031532403, 0.08997446031219537, 0.043063832356804804, 0.04916448544170107, 0.014294864545996874, 0.05077797769298477, 0.03516470743042808, 0.04719526026277773, 0.06909341626470128, 0.05794721234950328, 0.03378746137323399, 0.054727429073424115, 0.06776305095803353, 0.06849341620240482, 0.04297635660717084, 0.07013908797694791, 0.04753386346443046, 0.05417397651340693, 0.03743633815658189, 0.019722314994601954, 0.06734208564364141, 0.01253258269805942, 0.04599285462210256, 0.04339079868288771, 0.03103090082145026, 0.055179256239845875, 0.06862384267151356, 0.006521310048898863, 0.014613885582695085, 0.07657634860445416, 0.013881463392247117, 0.0847126160477919, 0.008221909370002969, 0.046542162646449385, 0.009630275833901138, 0.05024484944559875, 0.061373785738983465, 0.02238121848823803, 0.06224379732063221, 0.03869338118801675, 0.05519235251291145, 0.05295347587596025, 0.03406219199419983, 0.009014336354730111, 0.09403944541249545, 0.010641557859226821, 0.010690918819408023, 0.04161124155225773, 0.04318238829352683, 0.03189929021191934, 0.04436076175601733, 0.06149038432105895, 0.03836673278842242, 0.04002889843597528, 0.014479914999326632, 0.03392536486048372, 0.07184442267903397, 0.05131143535817823, 0.05138699844058964, 0.042292872113325906, 0.022959264385844433, 0.02527065699048821, 0.024510864393725514, 0.04103186074644327, 0.031792765686048136, 0.036341881965317076, 0.01711660098554867, 0.01715565231748887, 0.04905193180386578, 0.03610341028580743, 0.08473379837889826, 0.04532512472642045, 0.039118330159615126, 0.05965866426366472, 0.08658324188042073, 0.028910612679957867, 0.03646627549202212, 0.04387686614908519, 0.0418031848816862, 0.007404109074418704, 0.04289071563811552, 0.026587713434691393, 0.055173035605900714, 0.03651200711066204, 0.05505356419410917, 0.0699741262642126, 0.0025481911002463034, 0.008000057489205634, 0.0232408361719741, 0.036180065043510935, 0.02210137423037762, 0.04319035943837897, 0.03360341641030485, 0.08536430406233958, 0.07478021716158237, 0.03440752910870699, 0.03899310542751224, 0.09367724670277489, 0.03728402455547645, 0.0723941060864637, 0.050401843843921545, 0.029832890610240644, 0.02289959954308166, 0.014421324594877662, 0.053296047413060745, 0.017044282285496593, 0.00501797118622269, 0.05750452461201818, 0.03290250341618254, 0.017276062186987653, 0.026233198586851362, 0.009925374817553788, 0.04421672573493374, 0.04827987988509479, 0.13612722046673298, 0.028859589308980974, 0.045128102234054, 0.04027695387541767, 0.026601976076621684, 0.06272252183407545, 0.02169150378434889, 0.02343364518075701, 0.04012248373680538, 0.0490974833918435, 0.03274421815970733, 0.014327177177033117, 0.04282733335370018, 0.058358892678253116, 0.024440472404803, 0.0029179599556711415, 0.02603441217703925, 0.054050946623207106, 0.031031787568222613, 0.05977779859676958, 0.02486623917526055, 0.07164591397609442, 0.02524936932229227, 0.09331079620507457, 0.01996400232817377, 0.04413480029231118, 0.07149173112045373, 0.03374507372838355, 0.0642317341971061, 0.03613290850133185, 0.058664354916301474, 0.012968385220325042, 0.047277840710575544, 0.024382134809369044, 0.02793026720023444, 0.07303218837947616, 0.02127917994174265, 0.0393773712998917, 0.025327671169032975, 0.007423915798896023, 0.061805227305740125, 0.030615654353412892, 0.01589031542666377, 0.023101302832665465, 0.03653227396669888, 0.06501022125444104, 0.08055118813870416, 0.04706198777703028, 0.03869308241372628, 0.06181327122894507, 0.06746427666756415, 0.02767318916026383, 0.05312254765040932, 0.02055759406498363, 0.04315735637060097, 0.07186107743050783, 0.15417033776400552, 0.1432225736038339, 0.20773572636948479, 0.15162173177926772, 0.08866605874631675, 0.10477267431035157, 0.17898934953395398, 0.12763554951356304, 0.18686292542805596, 0.27676859870553017, 0.16522811215010383, 0.14222921803593636, 0.11791515013863964, 0.11770138862512766, 0.1868699121499254, 0.1461957608379664, 0.15130651724194327, 0.12178230069337354, 0.10927092043622848, 0.15202939780729433, 0.09586603651123662, 0.14551642471023146, 0.12601482156183452, 0.11089827504850204, 0.3326902899049944, 0.1541702611552131, 0.08774705967234989, 0.12495645577268255, 0.11965198637617212, 0.09518150630737506, 0.11503708038118579, 0.16232771859053644, 0.13142411476902424, 0.10850822628145257, 0.09560897570824432, 0.1411892843222426, 0.1958652552697928, 0.17280781671645182, 0.09365432535208042, 0.20721438821525345, 0.06239223068640117, 0.11018404361581612, 0.17730433914449908, 0.15167109848510835, 0.16348864823099107, 0.09855526559535535, 0.1736315757396721, 0.1418910208608835, 0.08964971564109288, 0.09861751023920313, 0.1545390712037202, 0.08890130136522556, 0.14290469308053294, 0.13408659206282708, 0.2621528668509376, 0.15133264084016124, 0.0999025997495459, 0.14273724158204373, 0.16007105339198344, 0.09421111805544746, 0.09563477754953409, 0.11083557841277893, 0.14183425374569433, 0.21572239216296904, 0.12277636872304064, 0.0698143739493624, 0.15749845353345718, 0.06539894192810021, 0.17085858260191258, 0.12227054384927596, 0.1179030612711945, 0.14102698093460453, 0.14147531090965196, 0.1282057334338465, 0.17156156020299082, 0.140397256660846, 0.19844050579253705, 0.08775588500523761, 0.1436740905046463, 0.12581226791465475, 0.18364278209065238, 0.1209394047938047, 0.10917573401163663, 0.16658935846099931, 0.24185608741977524, 0.16513163103691994, 0.1763585269931824, 0.12459337606184906, 0.2235928883836154, 0.10952128563076259, 0.10265937480594843, 0.1476345199250406, 0.0769712056423868, 0.1101385992801478, 0.10829667110116252, 0.09955241329847805, 0.14253058170358981, 0.14188787990039395, 0.16838945057843963, 0.17740875692857852, 0.1367173839600817, 0.19677902962411606, 0.1344680732056018, 0.20571720726307363, 0.18300092298417323, 0.14443371264684585, 0.17748421658912014, 0.10456486530001126, 0.09712916228079027, 0.08364220735647025, 0.16462152373165856, 0.10858359401144328, 0.1294309072076313, 0.1288038948851247, 0.14243984624983805, 0.152159663397939, 0.09876901178710884, 0.12392205321380209, 0.08724613010042137, 0.18890880919512243, 0.31803070717761595, 0.1407116591449707, 0.14755237997779924, 0.08942545872301826, 0.18691512665921645, 0.10037383575352932, 0.11547286183603349, 0.15469628776754105, 0.14423236941858647, 0.12194764545007099, 0.2808553713463968, 0.10597244460856724, 0.16944458347655114, 0.18761186830459103, 0.11548996857938268, 0.1618680351924512, 0.09450223146667404, 0.14474575558016378, 0.11740992281345591, 0.1087642528657471, 0.1214937000505386, 0.17515869540793283, 0.18242880852232057, 0.18573339007073836, 0.15741190091977197, 0.17175643764916929, 0.14914599607788748, 0.13815363027876423, 0.20080716589525824, 0.22158129471203974, 0.2000516040190574, 0.07396704547347561, 0.2015284376759683, 0.13370558589456544, 0.10912538671325292, 0.21606163121759894, 0.1084321843940885, 0.18926067337874444, 0.10123288078654198, 0.16518306618015613, 0.24662352918136507, 0.19797872331353927, 0.11279942948491344, 0.18539427359017635, 0.11612348498836642, 0.10757708471388587, 0.2147239497712543, 0.1546766452731625, 0.11474633469216286, 0.12382227026166455, 0.22884785317845885, 0.12178317403360722, 0.19815368247368645, 0.11389394696321219, 0.19007410553674545, 0.25959070110994004], [0.020783808337704792, 0.015606102552415143, 0.030013038100855007, 0.03797431957096823, 0.020305181500471888, 0.05756765791785814, 0.04018605754320179, 0.007296550329849725, 0.03427409957493505, 0.03891126808500098, 0.0015177760290117155, 0.018803191431347403, 0.05932827352456028, 0.04349594808093483, 0.061790208151984605, 0.07967229376757338, 0.021662430747622446, 0.02338226940933495, 0.059494694634791345, 0.04538161988039652, 0.06429372220149925, 0.049025363874651735, 0.035532421973203464, 0.03583830939004979, 0.007544036949008344, 0.05882783807934292, 0.08631658965661641, 0.07013542607666985, 0.025548248949851242, 0.01864539455592392, 0.07122742312569773, 0.05098046239225134, 0.07681912186765864, 0.0860810406025379, 0.031064735094626105, 0.04524251363510567, 0.01880088359147551, 0.031451787611830144, 0.043228537430085485, 0.029365498452417316, 0.01624059093545281, 0.016490789505863385, 0.004687253902140524, 0.05993642859281071, 0.02127524416503166, 0.0469424550782048, 0.04494794899778021, 0.042014870296923384, 0.09880530137208202, 0.030847313596055876, 0.04856338221279364, 0.03321805120175404, 0.03258750338347689, 0.0697960644479721, 0.03075710291253223, 0.054433680319738005, 0.018611456860878298, 0.08978094650252212, 0.027069544434667598, 0.03604882269076282, 0.011770879669535545, 0.010653821011674742, 0.022032020290592508, 0.016083188595310334, 0.03636702114055234, 0.01166199367763775, 0.0469967553902778, 0.0613977911040908, 0.0818583409812662, 0.08704016736197857, 0.049715402250688885, 0.008299265098157189, 0.07246069444884216, 0.05030261247508949, 0.03795730858860958, 0.02348884756136085, 0.048416971319144776, 0.0527077378524888, 0.026197807239969412, 0.039341545198112726, 0.04570308569518309, 0.05971021048964993, 0.05912855057226074, 0.05451256822374079, 0.04054134613984535, 0.046151438652868235, 0.01830724143092671, 0.022805420524110238, 0.08243167352291846, 0.04545734767171164, 0.04335543606430293, 0.025895702382249218, 0.052255006702316385, 0.0064803923352531375, 0.026586252121975826, 0.07312038808219856, 0.04644380461785101, 0.12112364893959415, 0.02174665445401784, 0.03345510561860377, 0.07885777376471989, 0.044323112364978566, 0.03596487094558055, 0.03200767058578711, 0.024634461188989303, 0.05261316046779675, 0.05529968143110314, 0.012905560264874612, 0.0351130960869693, 0.050516684254210804, 0.01880817674851466, 0.047217522777857325, 0.02963097664647766, 0.012079672474834708, 0.05148036540636132, 0.02707409308171801, 0.040921076771713076, 0.03228513231020301, 0.029806646353174603, 0.04137019198688288, 0.07101678725091681, 0.01777587710098634, 0.03290924882035583, 0.02701932162557158, 0.0804935859876775, 0.01606943157141007, 0.02123587873704251, 0.013578896966552543, 0.09461657008937291, 0.03180027909336552, 0.062033720690036015, 0.03154409546104651, 0.063035246585646, 0.04708043900468657, 0.056121812517484354, 0.032256664482936744, 0.021081517765959425, 0.008174681964690888, 0.05913972013419675, 0.029038763867931503, 0.06085406403027235, 0.04326575015100741, 0.020614857222103787, 0.04609161867730079, 0.00688431267213497, 0.03074473633821453, 0.019927588253912908, 0.0826989232953037, 0.028840088540868416, 0.06585497874766588, 0.007908487957226294, 0.015546434836822654, 0.02126207319839347, 0.007936421916970323, 0.018700583529989087, 0.04942385983022471, 0.029071630955102946, 0.059008849334091916, 0.0809137775532661, 0.05454549085228674, 0.019424475331400192, 0.03330480299829956, 0.04782847023659176, 0.04699116677887017, 0.025084143309223077, 0.0383559194573712, 0.045086139768001535, 0.020287651493544542, 0.0714792515481672, 0.04498500850111727, 0.07581962993548763, 0.04219832537215083, 0.030451161869531198, 0.035383188045553626, 0.061548568698908054, 0.06225076105986392, 0.00762995754015602, 0.01939600750413393, 0.05484186728755313, 0.03779458385261317, 0.03860854461128193, 0.010074055246678332, 0.036610231073873664, 0.02038127126833124, 0.018572560661742767, 0.008020010727998472, 0.025098126329061006, 0.08004158645147279, 0.027701260537029277, 0.03345958723296081, 0.046442739755636266, 0.11568642416668516, 0.03563133158510731, 0.03811650548971469, 0.052643455414762425, 0.029318906900082386, 0.06381989298989216, 0.05564069397927773, 0.015686116605666618, 0.034418013021950765, 0.06062955430318272, 0.05867751630684061, 0.00850386132726506, 0.0608443538658321, 0.05007914079713726, 0.054349950740053776, 0.09686532926054732, 0.04829206834397009, 0.06689777763019647, 0.06097107629982695, 0.04771931419870065, 0.03465680645838861, 0.030273274338293462, 0.027789318513485695, 0.04556642327037069, 0.02292817462265732, 0.04012263312395062, 0.030282674237124385, 0.05064311174435481, 0.09850869511043835, 0.04943673393779224, 0.023574574715307644, 0.04357741004036319, 0.025346484373233495, 0.044911195929612846, 0.03222646912740123, 0.020459609504248348, 0.04137545501092269, 0.08816320629369828, 0.016623803436936393, 0.0363324016272541, 0.02632357972493816, 0.03386859008441529, 0.10665361168644122, 0.08879107663468008, 0.019195652529296857, 0.01936672762366793, 0.022154737999963186, 0.010728126752280421, 0.017138878822386745, 0.033585669983538895, 0.006619183526885126, 0.06420389073149813, 0.020160779672404452, 0.06927599799969504, 0.03992636522818958, 0.005081144232873715, 0.03058473121434931, 0.02742231260204027, 0.040935004250176495, 0.020263404810741063, 0.07792899940883921, 0.030907076115028995, 0.04157724640061779, 0.020644895529614824, 0.04632473540221972, 0.054645626204869444, 0.011452993400575174, 0.05167561440518306, 0.025118149952181888, 0.04068447434673867, 0.003411867374163722, 0.029355937675122293, 0.051962077662709265, 0.053327832401039145, 0.038058753951542804, 0.06035359794153802, 0.10356125181480762, 0.03407690471278564, 0.04461154829890979, 0.003728593738126238, 0.026288617387293812, 0.0312660783228855, 0.02597658403007494, 0.03964767776309483, 0.03762044057610535, 0.06395440653807695, 0.03775617220408974, 0.02998299596290435, 0.021209458279753887, 0.028864432899882237, 0.02420094926961728, 0.044059099314073404, 0.027595816195131313, 0.02339142032959048, 0.015095463773656278, 0.046058397274464376, 0.05676547959146481, 0.03985054550632354, 0.03604548254741296, 0.0474803407316006, 0.07245421334500275, 0.017732353730788155, 0.019169701300861857, 0.01814698924370591, 0.04385218662660449, 0.03030096650153639, 0.05380794736406496, 0.02059550009547703, 0.023813584571584098, 0.022537402748580904, 0.030227016034205596, 0.048156447798734715, 0.05411737027668184, 0.07763070009288288, 0.061435072772925904, 0.052104520220910354, 0.028658046897861267, 0.03356959745888749, 0.03921483425543674, 0.05293163853967863, 0.02228067136339603, 0.0315708146926256, 0.02808995248239127, 0.033883049993986086, 0.002524902745555606, 0.029664690260805433, 0.05491925748966395, 0.15760405109294, 0.048971182306207, 0.07852244941938309, 0.025570436771358215, 0.059385481140305924, 0.06649354367607063, 0.048068922253385674, 0.043037494253968044, 0.038359466444460616, 0.04062165130650805, 0.06300461072955402, 0.05559886557861202, 0.03291703227366651, 0.03172190255305219, 0.022536010383778525, 0.043900649348694476, 0.044499262791847995, 0.043278371449559934, 0.026132404398653778, 0.030180391923133886, 0.029203685361050793, 0.04455370099974736, 0.08329898464463412, 0.023993948482037075, 0.06373633194955126, 0.02887124342152909, 0.0345828713128163, 0.014642367774109929, 0.05444461622485711, 0.03980189892313173, 0.03834441664718813, 0.00936047115828842, 0.05472385527325734, 0.049001779857902765, 0.16514056362211704, 0.05972218061346681, 0.1856752133537685, 0.09956665487299043, 0.12695789111838227, 0.1372365617463666, 0.07674342471986048, 0.1541692958844285, 0.11013784851398199, 0.1658085003615387, 0.14052934554075042, 0.13955181734936853, 0.1287575772092227, 0.128709880575057, 0.1606037909345281, 0.20353145116279203, 0.12824323343774005, 0.1558615687874056, 0.1590720900604802, 0.17413080459640873, 0.1280454295356908, 0.14511154724224923, 0.06597879387798809, 0.20082166027878562, 0.1040910245970853, 0.171205222065891, 0.2010213181136116, 0.23758494805905128, 0.14995277859270573, 0.20559601215345247, 0.26855527813876834, 0.16702350048768907, 0.18676462102561228, 0.13958840570863218, 0.18190956944900175, 0.11377643673650681, 0.17372038065185472, 0.1674980919567808, 0.15523844819155433, 0.1215083399907716, 0.1354128894426169, 0.10546523311565961, 0.09961646590982715, 0.2571168499848535, 0.15889302466905889, 0.14413720597663235, 0.11248313476361575, 0.10286661691122478, 0.13682986098912456, 0.14830703787024946, 0.14455369733754667, 0.08492545825579474, 0.12615663209749808, 0.1211407863264603, 0.13688927876853174, 0.12205101369369416, 0.08900381159037353, 0.25033436715602875, 0.19877045986152467, 0.14826508689551585, 0.09720292888701924, 0.12960526881919754, 0.10617423216782271, 0.11906504045210539, 0.17514619285300856, 0.16146263678468045, 0.169801963493228, 0.1788144976261162, 0.13035958963296107, 0.15297260525966846, 0.04821259438270523, 0.17442847572026715, 0.1453647699447409, 0.1426555766093154, 0.16885320956428207, 0.21498405194330603, 0.1670245117237491, 0.21556404178902028, 0.14399716510407387, 0.2294142219808794, 0.12053553090100327, 0.1754485217914466, 0.12427014824483665, 0.20716666093757077, 0.18893507068916676, 0.09993534234742965, 0.058242336231013464, 0.1116347230309921, 0.13963625556038273, 0.11702629662449322, 0.2045757668994127, 0.23803513196687545, 0.10199032723903657, 0.09078335722968464, 0.12724971699137844, 0.24280081172623943, 0.1806256980184586, 0.2159964064917257, 0.16701709599264208, 0.2594378818908046, 0.23068320066217454, 0.13494035108916222, 0.07446065890572726, 0.0790942497851868, 0.044519698187228174, 0.11073653856592794, 0.07190436139822969, 0.1803008460950467, 0.15809456186909832, 0.08749016740870091, 0.14709318687598552, 0.13103442116370126, 0.120601843471729, 0.09954359562646958, 0.13357078506340905, 0.13003233219346694, 0.1743127045131499, 0.16363946029976492, 0.13349031518784263, 0.13316299646131455, 0.23387018771421528, 0.13894211861395067, 0.13527689351429864, 0.0994903525157321, 0.1080824729175337, 0.12943274581864958, 0.17737797551578094, 0.10649430370258708, 0.15148714545273012, 0.13809018287687533, 0.10190798044805566, 0.11163837727039091, 0.10720544014005892, 0.16275591577493376, 0.1648600528677625, 0.08333573388236185, 0.15975475100980652, 0.08059703850097234, 0.14351670540148212, 0.08121728626710754, 0.15186740085482597, 0.1006596171928029, 0.299112901331917, 0.09433141684219723, 0.12354723703596862, 0.2030579015732773, 0.19079879406959782, 0.21894988994444572, 0.11603922297757481, 0.13511079033055615, 0.1355177975229679, 0.12315732892602684, 0.20334781988734202, 0.0893146824091673, 0.09594552579425997, 0.12199908059330718, 0.1101293832424187, 0.13729135235471113, 0.14812037288661928, 0.17207917516991017, 0.10273304948162648, 0.13515839503417093, 0.15836612471649725, 0.1788036498211084, 0.18217555517631193, 0.13927910537008317, 0.1248685548442506, 0.09090580872350162, 0.12922740361142543, 0.09485702976704606, 0.12959449762298217, 0.14119176644711726, 0.1469886771613552, 0.1240304776377255, 0.1718454264224537, 0.11006852521771386], [0.028163406907791094, 0.047118643809470444, 0.03601648611947894, 0.05985672480516857, 0.0379244510775372, 0.03686933733162381, 0.02135238155812746, 0.12040431536133252, 0.03198949131934393, 0.021099652982346957, 0.05364274816407312, 0.06206079806771971, 0.043630545898791284, 0.09921272225197285, 0.08998261914858896, 0.06161169051342915, 0.025109052658081058, 0.020526295542837154, 0.037413037592364896, 0.02367109030244812, 0.043277180182837674, 0.04653087434088511, 0.028721574738982226, 0.03672355079963323, 0.069167175210051, 0.004902287600411764, 0.08015798585068795, 0.007797204110125501, 0.025951988777265917, 0.04672373697582272, 0.0247770837778526, 0.04573547972306129, 0.021625112689610933, 0.029883243654283787, 0.051258854913495244, 0.034391257401195266, 0.02007460052658233, 0.04525284433076459, 0.03835881143928536, 0.012523939311053726, 0.05444458175090052, 0.02919837828695534, 0.01635590823547494, 0.0036114471637824132, 0.1297688592345484, 0.04118971699368089, 0.0742843437699541, 0.07655159630362066, 0.04679217544053832, 0.047554172455303134, 0.07122091137834134, 0.006604723138509379, 0.04463044002712254, 0.060558158739079396, 0.0719120605818687, 0.06470276718778957, 0.021099951756637425, 0.07095534699938952, 0.05749741148564124, 0.06166114531938107, 0.05952387109338757, 0.02161065086482033, 0.06289031807213061, 0.0571480677312901, 0.025665676822104765, 0.05939797220391132, 0.047545917857919014, 0.026643932797014717, 0.023155919156007232, 0.059694854257207726, 0.041856336061872786, 0.010288079145304378, 0.07102048745559109, 0.038516533621136224, 0.049029642475708846, 0.01232361785256334, 0.04220563385094847, 0.008466098938257465, 0.028890654174310547, 0.048371726166336775, 0.045466885466368935, 0.04848866182709894, 0.0392068094844299, 0.027109775542011185, 0.033837264749191465, 0.02897036179239231, 0.04308373915151723, 0.017955078473014217, 0.014566116170176576, 0.06961897556339541, 0.025654840508415818, 0.04382047824741852, 0.049429191802177704, 0.03248040429166248, 0.028653729992407947, 0.04888006380849308, 0.04877668024311143, 0.03435306408773026, 0.06672726944088936, 0.029145972127275124, 0.07589139705223423, 0.12400341175136068, 0.06414261135843492, 0.07656865708169437, 0.009404869783940095, 0.04807503946546105, 0.026403777639291463, 0.06989773197640335, 0.038208550953816985, 0.05799454892234457, 0.013853602689660847, 0.043958335769392794, 0.025428903942567208, 0.04887481993665138, 0.050949060448235085, 0.08426641579717399, 0.014295410383642923, 0.029673195751984755, 0.06086859288775633, 0.04358658394325645, 0.03825303767957995, 0.06490722073302155, 0.04496361166539212, 0.014166233595460655, 0.009467695697000431, 0.05509276874363423, 0.043339106900196885, 0.05224960578245021, 0.024013343913060044, 0.0941484827067583, 0.026115102302883903, 0.08924890609998858, 0.006563487019570124, 0.0378562462696385, 0.027323383837938312, 0.018172576580376878, 0.02936731599601767, 0.046289204244291594, 0.024059182784009366, 0.02254744999170784, 0.01168526168311796, 0.01473401295727179, 0.018659588249941027, 0.03871549048551148, 0.04402214706304573, 0.010261628044498785, 0.04542470466525805, 0.044663761021389116, 0.03511525645491577, 0.05059123227012254, 0.010602691345998358, 0.0353128113783896, 0.05622716875927103, 0.003365887255753361, 0.02512604831868122, 0.030026933020581643, 0.05594357833146088, 0.10601044256961155, 0.05131314373424938, 0.024997188499377623, 0.04591034695265755, 0.04742760323889313, 0.07003695313488284, 0.006117313103224602, 0.046876242098909233, 0.026715904842281056, 0.03941382559376859, 0.06941682794281552, 0.0288441488068671, 0.049704366754139626, 0.024811054031635006, 0.026354351561636697, 0.0801656007646553, 0.12633593497617593, 0.02427040471605236, 0.06413146477913664, 0.06518197816706474, 0.04236507973062896, 0.03129433356075278, 0.023367089377115333, 0.0695134699344635, 0.07320942282075844, 0.05903634806013396, 0.019010684430418957, 0.02603158914303828, 0.08954460071700235, 0.025889058484725898, 0.019595992841547536, 0.025398386830103495, 0.046845767121281356, 0.11243212862961716, 0.013321357358607554, 0.04205052019847978, 0.04602698383912925, 0.05663209219252872, 0.02836335968646792, 0.06886455515820174, 0.03426998185234205, 0.019706692546606064, 0.017471115833388704, 0.044729353469466014, 0.09010583673033024, 0.01740894396789372, 0.09062112278995976, 0.026299627985985532, 0.010521525288030747, 0.00507154323596267, 0.030027563127899365, 0.016813753022541924, 0.0423110896841653, 0.046953138174308885, 0.04648899997494394, 0.15032043950932641, 0.0656544782161232, 0.04815708748215149, 0.03747866451439839, 0.019807048149467, 0.0507213025083465, 0.07160028577932427, 0.011645066007340868, 0.07133436133904804, 0.06094833881023431, 0.06359778111800551, 0.07106023209710276, 0.020930230722672517, 0.06439057869776603, 0.024664099215559905, 0.09089559677147097, 0.019274553839838313, 0.0971946704591955, 0.055694128611996296, 0.05644577194846446, 0.018659285645210938, 0.06753293346733817, 0.02236004381801092, 0.02496994832801002, 0.020191107178106904, 0.0972317720973684, 0.051641301327054544, 0.08010839697934928, 0.024502343580787702, 0.03870183113782156, 0.030326687903594107, 0.013106116337791808, 0.055864989201748566, 0.03846559643505081, 0.04595338960268325, 0.04525721486237261, 0.06918188409819719, 0.0894295113281377, 0.02127892521750783, 0.05499651745682763, 0.09515484644761009, 0.02617939431670933, 0.011904166519431578, 0.045105257492151954, 0.01586486407059936, 0.04370997006434106, 0.05537409538162812, 0.01123773514278113, 0.02880156197915635, 0.03417026401767808, 0.03378478772637825, 0.01755540465725766, 0.012809953449534313, 0.0838626721393197, 0.06755538750439882, 0.01221736528790526, 0.025010367126895056, 0.01688568101775262, 0.04792374093085528, 0.019030508870679527, 0.04610444681959287, 0.072708684770811, 0.07005859511874377, 0.02514784926578643, 0.034493399904139584, 0.041782527320807984, 0.06955739741604175, 0.04834164955442952, 0.019589758801063704, 0.004511246637951944, 0.06868021142098212, 0.04223974774621668, 0.03542943677354244, 0.06027828766814163, 0.027741876603554816, 0.005961574610292671, 0.016243053908129374, 0.0634515042897434, 0.037406100666210536, 0.042384737546766, 0.05133429159139914, 0.029992786566576654, 0.004209919359474894, 0.04245178939233865, 0.03844444091702181, 0.05246389589662995, 0.02121861877610847, 0.05497963670941611, 0.07988060073506448, 0.05479500951966452, 0.07091719582076035, 0.009713137819011126, 0.04297283643315877, 0.04087266001489855, 0.04289278024507146, 0.018576272357735905, 0.031813383027310335, 0.02598837986888905, 0.023514069091047973, 0.07809808267460716, 0.008814315585750005, 0.10293206380259606, 0.015777593249485137, 0.04521490765675422, 0.052082066183849696, 0.015271164123870194, 0.02864540644711064, 0.02131028311146844, 0.06424464277863022, 0.04027857798181715, 0.01032345517042784, 0.04725909836950803, 0.014026014607459789, 0.025040462891000415, 0.033677504773462014, 0.06201256900244664, 0.024114883121763988, 0.049773268702049414, 0.0520411724104516, 0.007359979537150433, 0.06088576091813946, 0.03074782558776919, 0.07664089917295402, 0.021631153292893883, 0.03722209783811723, 0.01587734747332551, 0.059090165736814665, 0.05315355122870496, 0.03370638245776777, 0.03375699022604573, 0.02379619246048312, 0.05655289785335622, 0.016689363326276505, 0.047062056724943464, 0.03595987605231424, 0.02542072020831608, 0.03998008331344013, 0.05517248402259523, 0.0853038520642346, 0.07680668826064757, 0.13375260837135777, 0.16048754475289778, 0.14517986696333657, 0.13053508505465525, 0.2170421777954025, 0.10844606590727646, 0.11111496301788477, 0.2170859214158789, 0.13732354336928937, 0.10752386458578611, 0.1753654931822131, 0.11764194786308274, 0.14297947858370122, 0.22833900225739326, 0.32942451837082065, 0.12823962516361667, 0.08394944691850294, 0.12154912651186028, 0.19613271188591758, 0.11751732834044004, 0.14252707302089662, 0.14415835000334248, 0.07819381302162524, 0.09495832957327367, 0.18898350276773979, 0.13133842017381422, 0.10337884628003645, 0.25804501147039477, 0.1000195737147043, 0.17535053914593113, 0.08911173805714616, 0.1647710334509611, 0.10727180633693935, 0.17243287796455045, 0.11689781601871214, 0.12564194358644948, 0.3151768151550524, 0.22802247004883908, 0.12324220380715786, 0.10053566416665431, 0.10447366253262567, 0.17550291403407053, 0.194201955812112, 0.10147222197584568, 0.13079339458096412, 0.22526245444051682, 0.14240609241589425, 0.1926912304254309, 0.1993748572685065, 0.12854258229415264, 0.14562928478323645, 0.18151380842731846, 0.1184953698107312, 0.18807280808687213, 0.13056261825465387, 0.1641152009007431, 0.09538383012817753, 0.22621297037168858, 0.11768115624304741, 0.12172177208647614, 0.1627765541836139, 0.15351602206787757, 0.1241859858254752, 0.31550384276816923, 0.11938400115937957, 0.18722013690538947, 0.10804773849104682, 0.11297745299675774, 0.17859553437559836, 0.14358983615473395, 0.21169111493133733, 0.10158876693176647, 0.12195343707477856, 0.16277511393831623, 0.09523530100141803, 0.11642339308896374, 0.20690596121693813, 0.08610540985940926, 0.12606954322226588, 0.17047642730176452, 0.13286434474491304, 0.20626184981196158, 0.2155023717111157, 0.10897052970023886, 0.13336188820821623, 0.11258895448859661, 0.11700634769494496, 0.08547377036584002, 0.09501899607599744, 0.1363613369363931, 0.17741145355807197, 0.11335852811293257, 0.09692460914412815, 0.10862416602791318, 0.18549031037236416, 0.16834215230999455, 0.1605810994102109, 0.12851891783817163, 0.13090892063994564, 0.08923250415752973, 0.20410287614551284, 0.22478531955951647, 0.21794777033069443, 0.1889192739561681, 0.12589384095683215, 0.10922131624313132, 0.22029463472145222, 0.14759004086015687, 0.07467089641478754, 0.14073150082220956, 0.15586441863448391, 0.06451136778078734, 0.11746777011261833, 0.20187611901952376, 0.11399237393972375, 0.19490592932749182, 0.18935796654512807, 0.13004891033614838, 0.133899298887099, 0.20099594528155945, 0.23031460511828625, 0.1700173261305017, 0.11744481811840689, 0.21027320875756203, 0.2575898326693043, 0.0940896548150528, 0.1132307829515588, 0.176633675132067, 0.1682411819215744, 0.14831105217097268, 0.13458631121583525, 0.2074583412538613, 0.08781740952643656, 0.11471187605732873, 0.06929828349741236, 0.11763215725941044, 0.22393047268832886, 0.32289729603836614, 0.16630749939189804, 0.0905595982687608, 0.11283078546365423, 0.09462201697451454, 0.10230896618938255, 0.09838167773259264, 0.12909700012495443, 0.08464221256755053, 0.20186281973315826, 0.11256818584496937, 0.10930917886716705, 0.14324284429031034, 0.11545303548055312, 0.21165314761380996, 0.1721780617991763, 0.11048114783461056, 0.1473667415519876, 0.10972695725579416, 0.16760529830090462, 0.2451522879663014, 0.17306159100224897, 0.18144205663233035, 0.13633201109065166, 0.16087068064558893, 0.18104424249501, 0.14544432051479816, 0.103234515315102, 0.12955766411558275, 0.12241016337347609, 0.19947853960817863, 0.1861166178939804, 0.1393155864770374, 0.09336655208420369, 0.20885726376887292, 0.11483635002326582, 0.20159462767262615, 0.1676067998332362, 0.22899463562475098], [0.030579665457950007, 0.010411204796494737, 0.04161670375915785, 0.047388540415634076, 0.06901323750254608, 0.054107403472786954, 0.08435014920729784, 0.08040566973748707, 0.030674691004077756, 0.044004304875289245, 0.03970944360198994, 0.024132221606710268, 0.07687618009625904, 0.04365808675966917, 0.07448194082826376, 0.0889851956538135, 0.028271218461375085, 0.04132074867224982, 0.045879362526560025, 0.05308996210055006, 0.0450334788840865, 0.007967522213866395, 0.039925009252563606, 0.04944552096628374, 0.04958430162420677, 0.0314261160054875, 0.07667011776638609, 0.020869248208679983, 0.06548522641101191, 0.011332650563769765, 0.022513113930941592, 0.041566892722321135, 0.06416920610072632, 0.03336759539501321, 0.03235910192973191, 0.02587344561282906, 0.08434493214853349, 0.05033710558388022, 0.03130880113120281, 0.027928564569822727, 0.032060388926296465, 0.07597021983876344, 0.01978271911221166, 0.036196267803109465, 0.0505952695534835, 0.08332088709838929, 0.05876997545842202, 0.03982930954906248, 0.034845681605680336, 0.09418523194448603, 0.02721813867890066, 0.07850276095972908, 0.022002374603142662, 0.06086848946588655, 0.01036772930679182, 0.026365090199115298, 0.05211043058924618, 0.022541480251557888, 0.03078243552496837, 0.08681943444835563, 0.017535612775733875, 0.0362578229678254, 0.03262913643172191, 0.08911280291936091, 0.031917124738796585, 0.058279238686326056, 0.034325209130803426, 0.0668273741499551, 0.0714604057852299, 0.009862249172593077, 0.02869721888864954, 0.07299827366706825, 0.03805248735232219, 0.043956378414746256, 0.018129635437001145, 0.0983023340062749, 0.031138501700855074, 0.037249328433385784, 0.026305477067287412, 0.0183845205502885, 0.0688014448349995, 0.06166641983473974, 0.03794002181459819, 0.09045541031105865, 0.04643124843677206, 0.036132115600330215, 0.05505766276450408, 0.17608134106041926, 0.01664985234158174, 0.07405323036495717, 0.026839591652875947, 0.06980109764563461, 0.024891140863239288, 0.031019152863131418, 0.054422656314507614, 0.017684059548041513, 0.026225809668821674, 0.009407182411861517, 0.04091838014221961, 0.02549457108421672, 0.05509511680312215, 0.02210590755566955, 0.05819414163969698, 0.03203999758097193, 0.010514828721962629, 0.06822392945328067, 0.05950415199021659, 0.07584282707783484, 0.007893301700542291, 0.006885033752393699, 0.015974882915015184, 0.02918906840345552, 0.0294566112044718, 0.011511730319339664, 0.02401229437260378, 0.046549593699314905, 0.023482094496308316, 0.028625811833227356, 0.07062145523847112, 0.05643088686009569, 0.04048586605236896, 0.02196991928823052, 0.04429176787755663, 0.04351145753096189, 0.025484678973894448, 0.05942439840685937, 0.04574059335995586, 0.012013632822932016, 0.03603918147423575, 0.022606840958037687, 0.053576784163352945, 0.015125844905513431, 0.04707914814653416, 0.014949988464884942, 0.0024182099197435406, 0.06415501815236865, 0.05033586835188251, 0.00950093625203496, 0.1967575638404777, 0.04319701674244097, 0.017456347573428385, 0.0461541352823617, 0.041798347036444375, 0.08708699065591059, 0.020065518554239985, 0.07203679501770005, 0.04222457920531592, 0.04260942730451784, 0.030475948644321293, 0.030072049853662332, 0.04358985513869313, 0.0366035086523381, 0.030927417664638454, 0.03690088866278529, 0.01991191601020194, 0.035810266741581505, 0.0032736658308309538, 0.028116598935617555, 0.04065688369014571, 0.02517958445804975, 0.07129637103888296, 0.06375346933641741, 0.065140180409916, 0.017448610085393154, 0.04984115941389915, 0.01897498281792768, 0.02574868053348074, 0.04472065454108581, 0.061155320445616404, 0.005201801644533032, 0.04413467005736405, 0.04875215393821559, 0.044047006616188634, 0.04440372396681098, 0.08981862270663823, 0.02014831925231603, 0.010840430453930412, 0.06644213917635142, 0.02677605998131537, 0.05738902536611404, 0.014813868047278977, 0.035692653093006343, 0.08717097687504946, 0.05137742617197576, 0.03689055030624713, 0.04485701053072849, 0.019699453015721614, 0.021837158166172526, 0.13841849751770496, 0.03751688464094074, 0.02693708400211988, 0.04457520891822154, 0.02205590116641214, 0.022041085025956555, 0.0464534841387743, 0.019765801975623738, 0.05968242448063628, 0.05254879759083833, 0.08397861954665954, 0.04862168916471062, 0.03403348284923742, 0.035238619593362656, 0.07181557946868482, 0.025986977927987615, 0.020548098405162175, 0.05638713940917965, 0.015195610617557842, 0.029689478950815338, 0.04994227918946455, 0.01080904000123302, 0.08356224309893386, 0.045030360906234676, 0.026860433074856, 0.0375289581866274, 0.03879145576408313, 0.03082902324686368, 0.0671147337303527, 0.10241729868275505, 0.03261733101680875, 0.10042977549376027, 0.07471180550994412, 0.016268300335674037, 0.0671594962477684, 0.010052566480402265, 0.03574069063629835, 0.053513133748164105, 0.014576252471024712, 0.0524633328220056, 0.04439730031956588, 0.04551065206948308, 0.007271159782014307, 0.010166341070866874, 0.05335980891099861, 0.045775978961178375, 0.020100568991995627, 0.029665398892135392, 0.0217240069797563, 0.03679697266629627, 0.05016139565756725, 0.06845340343011964, 0.02261081503914489, 0.10530516670476045, 0.00861377196176158, 0.05100384722614, 0.05484479374342388, 0.009806957734268039, 0.032038800568590244, 0.03756700211294717, 0.025722336684984547, 0.03395079131869059, 0.014408529968932273, 0.009263178949514705, 0.014361290114691422, 0.008611620212304256, 0.03194265078843361, 0.05054237501275155, 0.03334901776284941, 0.05405074360990717, 0.060234329543046417, 0.04149566952800078, 0.0351347878665453, 0.06752849781825658, 0.026696865642142874, 0.1335375062039783, 0.007581165879063549, 0.025441896793763005, 0.06272992990430325, 0.05001376285367916, 0.10618965351773847, 0.027300563993893807, 0.0035622363089538754, 0.03485720356806152, 0.0150266527986875, 0.047871233264525095, 0.022054769271504016, 0.04979525925591589, 0.02530469044652437, 0.017119372308614756, 0.018966936979502923, 0.0885418069458777, 0.01879884388237711, 0.03887935669251508, 0.08028986022597359, 0.05627843153272426, 0.037585729132256204, 0.01067601170601143, 0.050284268499742595, 0.12095736955562908, 0.029486279874559373, 0.02057168433713096, 0.07265971643069098, 0.05232920231778295, 0.03324877898839693, 0.03079982955128916, 0.09260175884851525, 0.03665297111916927, 0.012218342050008718, 0.028718313119644602, 0.029201885054428733, 0.023798657348379496, 0.028282313329738476, 0.05949891577925413, 0.047124941052208026, 0.044310039074550715, 0.007938974426173034, 0.05568210869246433, 0.03321843041527656, 0.03967454829703897, 0.04711827991770641, 0.045303310372776566, 0.02271580738916753, 0.0565061818117336, 0.01149024059545369, 0.03923299053924219, 0.03611894654891184, 0.04236715199846414, 0.02395177151136581, 0.02927471894860989, 0.07173295688605116, 0.021297297921151887, 0.08702669953626972, 0.041590779343800205, 0.030131657239830786, 0.04164909778703605, 0.0436889294595007, 0.020725399879137837, 0.03913442566690426, 0.028120630473319082, 0.021766471233399167, 0.047025188743587465, 0.03712610702120489, 0.049091006118443706, 0.034472757665019844, 0.025235528028720332, 0.013505866762340791, 0.0348020414070737, 0.04692540579144994, 0.022327622977055372, 0.019069973890098835, 0.013189686954231753, 0.03267348526165851, 0.03278025493566548, 0.016490632457838907, 0.05703790045733895, 0.036226382719412926, 0.03940175204808193, 0.0497822319307635, 0.01011690828994277, 0.03705817800495894, 0.05398898926233092, 0.062337248556075565, 0.018197740653469678, 0.10782012610786385, 0.13880370184779167, 0.1500477734953165, 0.17598787833365703, 0.19649868740910487, 0.09405762467893863, 0.2517364306315299, 0.19212300769023358, 0.20671011849997506, 0.13290957457596256, 0.11586643184625334, 0.11363097962232367, 0.2698483732679198, 0.11800121245605331, 0.17537085579768305, 0.12439958646052307, 0.10150131799520985, 0.1084561323026015, 0.0981579187716688, 0.1417524202336227, 0.11516603596147992, 0.1270483890848775, 0.14731057198537936, 0.06514515232054457, 0.11827940196399728, 0.11564151609256385, 0.2525701641195244, 0.1336715562689689, 0.17890796035287843, 0.168241610930812, 0.22827866517247694, 0.08857378345583716, 0.10294874153670766, 0.11326878857348235, 0.16444201400924116, 0.1707960545055328, 0.2092861657541606, 0.11191322663498503, 0.18054119852041045, 0.1829634919281929, 0.06880061746004128, 0.14043292571460048, 0.10406314665752073, 0.19075990744656135, 0.2817647483560347, 0.19226370739840692, 0.17822283260043592, 0.12432081730014856, 0.08335398975759746, 0.14455797210816415, 0.1279357487275716, 0.23869327810262483, 0.12185675677873435, 0.09701976492520302, 0.1423129667678187, 0.11351084171403801, 0.24134598011451386, 0.09640289560681391, 0.13497798132800287, 0.17169786256647881, 0.14653224197606887, 0.12177093194857722, 0.11814147549410982, 0.21312961354851725, 0.13011600431655684, 0.25820386746237356, 0.12118996151031987, 0.23296496290112698, 0.12565070763230324, 0.07370780131989911, 0.1016638512092252, 0.13232115776308123, 0.10467765642510307, 0.17684221958681462, 0.11420008335863391, 0.10674956419895734, 0.06313445880227993, 0.1998792035925773, 0.13713458012188637, 0.10731759541217359, 0.07983128765537854, 0.1438359189177713, 0.09736692532896997, 0.1829632621018156, 0.09154989714584044, 0.16824462931723366, 0.166001983527695, 0.3795102743371841, 0.13347880854721994, 0.23244170952708493, 0.1274455980127377, 0.16258406693175917, 0.13717876807335885, 0.10446021768955455, 0.1209315294099431, 0.15580474038518247, 0.08558784851864462, 0.07620799054782237, 0.136015938534852, 0.21862105436382756, 0.11998189447988426, 0.08537359670886109, 0.20751446485519412, 0.17880112173095827, 0.09762605456935783, 0.10889934481031473, 0.107499755798809, 0.22628548825460099, 0.09873225488850186, 0.07881849643684204, 0.12200741562992336, 0.15650315210223198, 0.18421190880960037, 0.18582156679082304, 0.11297570631629038, 0.1876252288779905, 0.08268101215963403, 0.18332189850268826, 0.17287285758122323, 0.12973174993549624, 0.15037973471466573, 0.12467163194331432, 0.11378818086438602, 0.13413401290534005, 0.1353003664482986, 0.1572974473838845, 0.21505482314575106, 0.12615608817507185, 0.10355424211030045, 0.17142662147600807, 0.16966518615522694, 0.19901704824259206, 0.18581173022187528, 0.14555923370344026, 0.1471678344833274, 0.1608339543904989, 0.14260067874866147, 0.13252398720191372, 0.31996581463083146, 0.10546228367715113, 0.1145918530622317, 0.20932160498153782, 0.23383240425778976, 0.10390700261679389, 0.2959906640312364, 0.19667917772406535, 0.1660900223519533, 0.15382126214042788, 0.09203600291643413, 0.19445934603291173, 0.09469922331552352, 0.06641950127818892, 0.10811230438130517, 0.12171175165642655, 0.12500341696244094, 0.0971807659633698, 0.091865778179659, 0.11428567836241377, 0.12298427732481111, 0.10602299108981125, 0.1803277664247059, 0.10977355838422814, 0.16791482846583092, 0.20643414298613227, 0.1380724556023075, 0.12056546961708416, 0.09888121302449897, 0.24203231828587674, 0.15501458197832108, 0.1349326289228855, 0.13718391618421003, 0.10978130353314262, 0.09988729331281879, 0.14942751806830207, 0.23565515725603028, 0.11565493795299724], [0.02069656624488773, 0.03258993571263648, 0.01746966218155238, 0.04253658766467725, 0.028168181550779173, 0.09068244046741918, 0.03690748084937373, 0.06552764469937933, 0.013186669525419994, 0.0258413446135819, 0.0487283707386063, 0.03216375333948001, 0.09104873774753464, 0.045212168892424916, 0.028189928871729684, 0.010944419228772243, 0.05503114846144473, 0.015887887885553703, 0.06875157251112884, 0.05036489542333349, 0.05848339345726756, 0.05392324742710879, 0.04892841161739442, 0.017420695756652185, 0.026381354245747772, 0.01656692523899819, 0.024254364750137734, 0.028955384773472627, 0.026645916964738604, 0.040537722543963504, 0.014371537498288579, 0.013918972014629794, 0.05381625558760378, 0.027331446913341363, 0.06870832684780322, 0.0399733494005857, 0.020768928994995453, 0.0592501555389214, 0.07770735485058639, 0.029069089458414146, 0.028859732950466777, 0.022345970782841888, 0.0342890153068208, 0.005503131317034845, 0.07622325868015328, 0.027831821071524775, 0.04861591669220117, 0.06509076007792065, 0.008193452076445664, 0.004623904176461961, 0.028108240916363658, 0.027859926922246817, 0.019643158959825675, 0.022539835077740496, 0.035239937264592416, 0.02657199522570497, 0.041987007679117304, 0.07339821752881812, 0.04861896189170019, 0.05401414758976429, 0.011517904988009364, 0.023913503504328193, 0.02749974493898692, 0.05085385487144513, 0.0848270159575247, 0.04093254893837918, 0.07040744857682336, 0.05752905091691402, 0.050010173731753906, 0.027560890246663364, 0.009926614922381217, 0.04105305456886849, 0.011607968199607587, 0.025322569023457267, 0.01599089511024255, 0.032022683993883194, 0.04651308960972294, 0.013819517522689798, 0.0962953138796072, 0.011094526496655759, 0.03119301268710725, 0.028009258526106997, 0.10136205853233415, 0.09984895827308779, 0.04740426820071955, 0.014830234558171323, 0.059936811636772856, 0.05117529387315435, 0.05563782114956168, 0.04355375324526141, 0.05770222509219762, 0.0467926733976891, 0.018117094577680674, 0.035656187307810595, 0.06498633463296198, 0.07296206069088752, 0.007640151297598477, 0.043599369950712695, 0.014130784791984386, 0.02013185410760343, 0.015113216903691572, 0.007622784084355039, 0.022261540232706937, 0.043023405897040526, 0.016861419013190656, 0.07378673135873771, 0.029101650110415878, 0.053471787982890685, 0.03370731708503539, 0.030710764169212312, 0.022802317868016904, 0.09902665481692362, 0.046801479578378706, 0.019099207805289377, 0.043411674578824354, 0.05233993904004174, 0.07574847568908046, 0.0727560060218938, 0.02413119313367192, 0.08047360641461226, 0.04842856605987876, 0.008210078099622362, 0.0545019579059895, 0.019013777510413242, 0.01233937628116579, 0.058038300203700224, 0.018461638791186195, 0.03270541963678214, 0.011828205071299547, 0.02613784362291617, 0.02377092496552054, 0.09066820655378605, 0.025079531459918907, 0.019493095741997805, 0.028679313498639294, 0.04617993712365147, 0.0831648962752473, 0.03093994703264006, 0.041997326883457364, 0.009413965162821114, 0.04965731746426994, 0.05615624816968076, 0.018936389223522237, 0.02751841067126201, 0.022666547935636296, 0.01624650513422826, 0.030764650793806202, 0.06868978752003563, 0.03999817831021163, 0.03294389514673141, 0.09393138871077569, 0.019889594123308218, 0.05328556733025659, 0.008347403190489258, 0.012873006316142218, 0.049328512527168765, 0.014741941967288093, 0.019191251354171865, 0.04631939959982711, 0.044050611059872374, 0.061098200929982055, 0.08766588499589313, 0.018304230705384287, 0.042229803924959515, 0.0635954330585176, 0.05679498163742885, 0.01975084410890216, 0.009016477570478475, 0.024578249487545223, 0.03327163139117822, 0.007228489163436837, 0.018071184843598355, 0.05328162197744655, 0.023186532029461478, 0.018016614485532045, 0.03752944465245932, 0.017340176085370685, 0.048542042833662806, 0.05669462794978773, 0.011627130931423557, 0.06117961309369534, 0.09579346500216954, 0.10088031180202962, 0.0062611662208162736, 0.014320246954148096, 0.036690241296685515, 0.011120503580558204, 0.05330823970237567, 0.032185939245767174, 0.04270391275865897, 0.017589901596488013, 0.031863450703601685, 0.05339457398100246, 0.020187305466782664, 0.06271671105716979, 0.03898760491621591, 0.018750258586219242, 0.026762594070826328, 0.04462445304999429, 0.053930946610747814, 0.02596325218497265, 0.02780142844834876, 0.06567965186531506, 0.023820883474282684, 0.022664987031490575, 0.056437705042621786, 0.012074925602533886, 0.029332060629742283, 0.0638638740976251, 0.025166300493442727, 0.009986110268190745, 0.03490136087601704, 0.03415691493559749, 0.026347355263668205, 0.021376120707681103, 0.03872601270315148, 0.0375822740757177, 0.04734186267840767, 0.028934926395454717, 0.02395816068465431, 0.0632524325121795, 0.03293488212230225, 0.0949879005671509, 0.04752581954122551, 0.022529483314663656, 0.028852407234690847, 0.06699151614861143, 0.051219523959462686, 0.06733473119956833, 0.030004118922196572, 0.027691510152972998, 0.08513878309918989, 0.01666302330821993, 0.045627583899805625, 0.023899397910422376, 0.026863702355072867, 0.017839701801177957, 0.029124299499897227, 0.0572657962930539, 0.025305370349557172, 0.06740299729450096, 0.028680192584532405, 0.06127794813965598, 0.05293420876466459, 0.005874411520292802, 0.019177524973788572, 0.007723878962062901, 0.01904395179853084, 0.050822797666994796, 0.06067586048776585, 0.03440393232590249, 0.010102734705733677, 0.04899337587337341, 0.07086022952271086, 0.0030366911350058453, 0.03584487476356087, 0.03912324844408901, 0.0501490731333052, 0.10817370632843626, 0.008477361388354292, 0.07708876183436764, 0.021465063515690067, 0.029944455994653608, 0.09989959668488273, 0.004933011556615032, 0.020442742163375504, 0.027115352662099947, 0.03694039964748006, 0.021687780597036885, 0.03747499112280146, 0.008584158833048517, 0.009193066582684557, 0.052008900956641284, 0.038324862252920866, 0.024939921511817845, 0.11766302294187969, 0.021169102683122602, 0.004765237822392655, 0.027286519687021935, 0.02906806481581542, 0.02129670420301057, 0.007149592640944907, 0.15993645174368737, 0.012737727637643055, 0.0374894050670968, 0.025818907813499534, 0.08008034283956213, 0.14265177681321098, 0.004550245301347347, 0.0478821691696442, 0.01650670115205069, 0.035924130389767314, 0.01998019742689306, 0.01202802474219953, 0.02609375717809364, 0.023827918076647386, 0.013318316947158067, 0.04788686145818041, 0.03718839379988852, 0.03371333470568061, 0.046014791549814325, 0.0984215832525684, 0.013614103494722758, 0.017683075125058813, 0.014694722222855255, 0.0025540825557864963, 0.03666948414437714, 0.049384842972241105, 0.02703458784268268, 0.009851032687771705, 0.023171501384387096, 0.0064780313480314955, 0.01892104256717909, 0.07355282939369641, 0.010783668126790755, 0.047848882649334214, 0.054580045248111414, 0.04966123983444226, 0.046313485401051666, 0.030248889759663614, 0.06558726932252608, 0.013894117249536419, 0.0714230360162835, 0.022197889817518093, 0.08282289930409001, 0.013241458218544723, 0.05521184945058438, 0.022820958702434457, 0.04196691702330305, 0.060379664083161665, 0.017643146622445316, 0.014757112423408658, 0.012048910214235226, 0.01505500379754531, 0.11083341804483246, 0.05483919747113701, 0.02856494040198384, 0.07570732144578811, 0.004608067223847274, 0.026920848683784568, 0.004434122172589865, 0.040259889266904325, 0.06618209063045441, 0.07070924891459365, 0.019964900566264987, 0.028889202437694037, 0.03027170960370812, 0.03712969997356977, 0.027359003095977733, 0.016733516803792408, 0.039498095265439445, 0.05989272327673051, 0.16676906736627703, 0.20128221701710455, 0.22710481928961895, 0.23674669465230358, 0.17501854728306496, 0.23057984007943064, 0.1251402326048382, 0.18071280221544928, 0.12852997248691897, 0.19795765589562156, 0.1333752641033742, 0.10974340516352847, 0.14883196131596643, 0.12725656581742148, 0.1638208086332006, 0.10187441047521369, 0.1331182262830196, 0.10098698188460643, 0.19063843654528742, 0.12459470905483731, 0.16410763195205122, 0.09332922061965351, 0.1817927257187905, 0.21446536445329267, 0.08762093095649635, 0.08113445684073434, 0.22107664195279922, 0.14566031134416982, 0.08239302438713851, 0.15364751339920107, 0.2150520039421897, 0.13536084142904128, 0.12159445593433997, 0.1360549324101979, 0.14488109267286717, 0.10040266364211999, 0.11605115096655585, 0.18599517763622347, 0.15451037355007666, 0.1029401766737142, 0.1128428973137371, 0.12459514572495416, 0.12339227277064517, 0.12526768665280075, 0.14743556689110496, 0.2544110274362949, 0.3618481785299317, 0.16377110484867327, 0.14361674116263468, 0.07326028339805142, 0.09656297733947154, 0.18142051423989958, 0.16664975683294958, 0.11532338276024788, 0.10067559012602414, 0.1260967010391816, 0.22046007906957982, 0.12934698993640562, 0.19820756909828033, 0.22785181630282636, 0.11037389552521129, 0.12730721189009567, 0.1361948200651715, 0.18974522399085184, 0.19696655262622143, 0.10377160423705656, 0.18247256746455548, 0.2196936081013372, 0.11984220600777096, 0.13952413093178503, 0.0950585415346488, 0.13442828259881467, 0.18547382416023364, 0.15205587380595748, 0.12200466537427519, 0.09073715446697128, 0.12241478288365949, 0.13546604062280349, 0.1742049312639621, 0.2783342679181407, 0.12171123837751728, 0.09241138599933156, 0.254126088693738, 0.17249188205647856, 0.20200399441584466, 0.11911156497174695, 0.25381821327872817, 0.17987149977876296, 0.17337424680590632, 0.11232213372544897, 0.13149366023079043, 0.16083049167308117, 0.18114213320997455, 0.13708935029083683, 0.1274098063849153, 0.11870199904566812, 0.2701710188581098, 0.2679567183217695, 0.1227218462454696, 0.19482685373194758, 0.06692960092257108, 0.10109973470530204, 0.15075752331364542, 0.17807355270751063, 0.21524231550433945, 0.2090820339658568, 0.2499289074612241, 0.10074209421873094, 0.17024611062820882, 0.26176013953743443, 0.1257925717941215, 0.21508421027852645, 0.10893155114665147, 0.12702028131893567, 0.08271236047749558, 0.15637569039339022, 0.1085996665360947, 0.15988598187123576, 0.1125480377325608, 0.18339289953151058, 0.11779012458939707, 0.1327619800764707, 0.08110007481469263, 0.11518116619798446, 0.08846948824582562, 0.22096398106265455, 0.1674996854196633, 0.1107093271228575, 0.09098672293006413, 0.08093744200924713, 0.08885460064536141, 0.2455946424555394, 0.12288105463789356, 0.1071978635304878, 0.14139238955272784, 0.22018355197243153, 0.18922285927880197, 0.13039023314993228, 0.11018033575026259, 0.14085456518636597, 0.3042700826641052, 0.13241014653636565, 0.19308637857677477, 0.16959642210314352, 0.12783117006502806, 0.09524801040008184, 0.18626123997232608, 0.1209576070428856, 0.15652532268676067, 0.12391895821858799, 0.12013138887742836, 0.07536893274875418, 0.13297132126265956, 0.1537789740870076, 0.21491708053696543, 0.12064492059571129, 0.08327260823740114, 0.09935272482013512, 0.21839429233824054, 0.17228937437457426, 0.09854675435851659, 0.17811611655258364, 0.08150711265062133, 0.11772581150815373, 0.1794372504997638, 0.1149669067273217, 0.20810764673496449, 0.1760216474893593, 0.06403711722082188, 0.10866116807465592, 0.12380176208793156, 0.13736483550840808, 0.2013162619644596, 0.11709123023695524, 0.12859755676359902, 0.11547473875144798], [0.044894008747031616, 0.03798803254481285, 0.035056014875731165, 0.04209859987660762, 0.025969687323536605, 0.04147618791208633, 0.029325215634138837, 0.006199095861971259, 0.07284752288532835, 0.07682517396226045, 0.036283758874501915, 0.028440774786436272, 0.023803633089447697, 0.02632991718729177, 0.023926674470966382, 0.01754239648430338, 0.027499951782726476, 0.044293146835820335, 0.03138310016853915, 0.008640686545761363, 0.058928138140829346, 0.051822898639065605, 0.013541405581148162, 0.07234871537695009, 0.05740816224246256, 0.043430987655395464, 0.044579544975872964, 0.04887238760749179, 0.02459492339121719, 0.042362057513767676, 0.02986235435180847, 0.05647201812075031, 0.03398773207839939, 0.01076233545092926, 0.047669303979003624, 0.014390054801028344, 0.06464131927538304, 0.07695032974645015, 0.004962371397508128, 0.08526668913902775, 0.07455939231740852, 0.0733614529693319, 0.04683986058338516, 0.030439339217639742, 0.04034859075721714, 0.01623425155787939, 0.0618268080025671, 0.04342318504988667, 0.01571074920526195, 0.029806941297025453, 0.05697798089034135, 0.0810764103587116, 0.019331230939696395, 0.06046442788154368, 0.02963482815351698, 0.0466289680691496, 0.022739477590807987, 0.02843274043933038, 0.017285310783453526, 0.07117324538769261, 0.049547249781748945, 0.02413850735812899, 0.05275657595766168, 0.018773787061593706, 0.0404063920911041, 0.034437831716551896, 0.05501553941998751, 0.055846377095628175, 0.033994944796206496, 0.07578406813404254, 0.042016467590245514, 0.01579275221428684, 0.08668250389276974, 0.022695329858951514, 0.014170400156158836, 0.02935698721557856, 0.03609433214390471, 0.014830124433032207, 0.03220100819523777, 0.0520239009581987, 0.045575474599196066, 0.020430182151856924, 0.05333593761127803, 0.0208286072442969, 0.05263969775349383, 0.03189704365908139, 0.024550480715509866, 0.04919234805950715, 0.03987208789875431, 0.053540567356732585, 0.06354032835412411, 0.007881837194755433, 0.02819243014880246, 0.009122185255100411, 0.05803894371755662, 0.041118198855509686, 0.03600701344229522, 0.020641538149286664, 0.05822328745477623, 0.04862831199481603, 0.0391362757692414, 0.057923609180556196, 0.010938190933947843, 0.03049385211911173, 0.04084533365863947, 0.028726563886589104, 0.06895813279815259, 0.04304025600093507, 0.023449194850400094, 0.018914366110918984, 0.03223599926117928, 0.06214055548151655, 0.06291957113951926, 0.018749004117243232, 0.04405119328669483, 0.04246315047625573, 0.147559565882529, 0.03414451580254301, 0.03842653744223137, 0.049463183123378024, 0.03193353625735448, 0.02838980312639427, 0.05419540399264905, 0.011494093060102916, 0.061965837639065525, 0.026113595024892883, 0.024849339275650924, 0.03111484490575329, 0.02763023269512961, 0.03766290866018784, 0.08575579031340538, 0.02818290384546403, 0.047990264175760175, 0.006879495415506104, 0.04277140127434846, 0.052478884406868494, 0.013787739237980738, 0.014165621682731135, 0.025939409613549232, 0.05071219755336643, 0.04572896414526528, 0.04124482935895363, 0.015679370243883422, 0.023179673627319358, 0.0076655250872605515, 0.03991476282657635, 0.04515444416733039, 0.04205074236397782, 0.023324069709727363, 0.035125667589806744, 0.06660853347350514, 0.006401828103398364, 0.04168883093722886, 0.01588529946597954, 0.14384198633413162, 0.013508725227908263, 0.03302100572674986, 0.051093717000537345, 0.04361904691904784, 0.05741296178330818, 0.08594164324383582, 0.030229572852652882, 0.01505338064875574, 0.039961091993797215, 0.054210515076955484, 0.04641593050872607, 0.05888095478557291, 0.007103152390975025, 0.007642214946944508, 0.05678686110543148, 0.049755024318132675, 0.06165478678960955, 0.03306800905134409, 0.007852612855663944, 0.07341851119793232, 0.05026690511693878, 0.022822772415595192, 0.05920776789407096, 0.03271822862687611, 0.020636430258051525, 0.010177970285557452, 0.09940743881968722, 0.028551932229029558, 0.04641313428780244, 0.025758990161721746, 0.015541925451778358, 0.053198578046454545, 0.04352721979000396, 0.015120016891629466, 0.015945502485509123, 0.04948870151213581, 0.060249697266807484, 0.054022842687704874, 0.042440987552606294, 0.026828324414729595, 0.04707097781882171, 0.08896664100428743, 0.06689127354371933, 0.03497341527573524, 0.04245898678838726, 0.054197510734440825, 0.05150253599089, 0.03277486167667854, 0.06248723708033081, 0.0196899650167794, 0.0018112391755435496, 0.03668391724087058, 0.033362431962403565, 0.01229219196829945, 0.016717685596837152, 0.025533425148516416, 0.022445259608268257, 0.04589810486762755, 0.015473009139719992, 0.019203591115412214, 0.06982493830183822, 0.15642717150190186, 0.040189351721276204, 0.029970085466160413, 0.06489229734025656, 0.03685644407185816, 0.039312253826327866, 0.016738940706296314, 0.053075218738447276, 0.04713177455649261, 0.007821333964520526, 0.04427232839647801, 0.007939843935967094, 0.022434836982058424, 0.03189102412321635, 0.00907469833750398, 0.04011686448188078, 0.040625025923814506, 0.07183999469083163, 0.03764944849535823, 0.04005975645756529, 0.04486056900913677, 0.030197466107746287, 0.03148907694154449, 0.016994565094430602, 0.043275345402259024, 0.045362850726251645, 0.018817461734156937, 0.06568506810693972, 0.014111612484069362, 0.045114163264271714, 0.031545598908597906, 0.01771054129236408, 0.04708749084402958, 0.04155116876767528, 0.09124035932003491, 0.04363254155783404, 0.08038788883676452, 0.034868288860325856, 0.06366717336218684, 0.027067487488590905, 0.03358604536662179, 0.017610974760065158, 0.000170026107533035, 0.044692814905917456, 0.022467502971149744, 0.043842798219092434, 0.028374734176923672, 0.038017925295618274, 0.03440217798455589, 0.07216261729838387, 0.06726647276551494, 0.015245629455744019, 0.002744618198654104, 0.03239149595761011, 0.056491266079847856, 0.07922510526353314, 0.06573926882758256, 0.00394789717956296, 0.04190550358485311, 0.07307720370590687, 0.039036538782379324, 0.034372817664857835, 0.056870797528855266, 0.022884340986849803, 0.07281838856156796, 0.02540858346037567, 0.013485031086020173, 0.011380490839421269, 0.01580558801745816, 0.038337878086754394, 0.029327240021478747, 0.08914560680427859, 0.07968121869189125, 0.020365275352472262, 0.060529560676866004, 0.043437924581549825, 0.05937943670658335, 0.06534651853144169, 0.040611849211516886, 0.05700923344721237, 0.018334784207024404, 0.026705890157890898, 0.10238697692271202, 0.05035811554520361, 0.04553882878333811, 0.046368854405779036, 0.11981140161233565, 0.02758543187331769, 0.0662294272032957, 0.018038767833082427, 0.09457381472231881, 0.026339836110691392, 0.012876671089249994, 0.07355233909742487, 0.025945408081996347, 0.039784933906048536, 0.036369832683234446, 0.03762302995328942, 0.05223791528072569, 0.05118388171878554, 0.03363017586149997, 0.06486529274092567, 0.04177743283611152, 0.030368190716892004, 0.026650082567826878, 0.010385130036381945, 0.031406419884954254, 0.05644174615642237, 0.03126695740877861, 0.13235359392579527, 0.02224341076197884, 0.02789733116514981, 0.016402137811265646, 0.04529589464166953, 0.04370946827675066, 0.010852234911233669, 0.13592377815756107, 0.015067607859119534, 0.03131180419586599, 0.10049349868730192, 0.06474929936831036, 0.03899356891070643, 0.02756737326572259, 0.08767287171776257, 0.016653089063061823, 0.04512844697361992, 0.015073218495554984, 0.01956622841046943, 0.004859841062552146, 0.025766606990908904, 0.07047688678628014, 0.05028496180931407, 0.03610450196109953, 0.027373932234402147, 0.018422631509301644, 0.05308530045553081, 0.13861103073483513, 0.15900822897111216, 0.21121261641383174, 0.1345689056981956, 0.09545291593718915, 0.23334869634239908, 0.11573797422311, 0.13612568829088442, 0.1294488949520934, 0.14361599039646888, 0.12224753056803059, 0.21753817376109863, 0.05354466592712749, 0.1762516270842283, 0.1066104043275118, 0.12028587050735952, 0.1613476929525214, 0.13245146931900134, 0.08537081580969595, 0.17414398130870637, 0.14759517364924954, 0.1630114060976813, 0.1207228470593691, 0.1358756065488823, 0.12465211202300365, 0.1501513792261962, 0.08251319293894115, 0.0977898977937237, 0.12947023816166386, 0.15109388187768, 0.10008634593818458, 0.12902774577659945, 0.18141335897868682, 0.1250232586396798, 0.0961085033392714, 0.09953507672875159, 0.20967146201479822, 0.14515981078147888, 0.15783726357884947, 0.18212166855171805, 0.25582033810355975, 0.14387282903396315, 0.09845872319513753, 0.14533021937935584, 0.17278628964577952, 0.15489142568361375, 0.16749505824860067, 0.1451422520462544, 0.1484752094913875, 0.0571433601209954, 0.12932163242611194, 0.1675323820522716, 0.1400635640827879, 0.23429872197729928, 0.11194018526904045, 0.1077337803379182, 0.10309127985589928, 0.11926934077975251, 0.17676968638214374, 0.1799846203216622, 0.21435520100978114, 0.1958650254434155, 0.1299201462778353, 0.16618540029852621, 0.15600712549301887, 0.17799069263762046, 0.1119735713807806, 0.11741187633766283, 0.15352467886142193, 0.18177072367360517, 0.14978851401998153, 0.09304494837359076, 0.11946245622370513, 0.15159968376880692, 0.13785531564104941, 0.19437156767854769, 0.15586130831751133, 0.1714241393511334, 0.19316887092446128, 0.13239939066190876, 0.1513413129554641, 0.13199800655486124, 0.18643881915317428, 0.17318764310931006, 0.12465442560853497, 0.12039942005949637, 0.12308150920416079, 0.1729466624918484, 0.10954088215986568, 0.18731822680321433, 0.10026305177879911, 0.08362724565930905, 0.08256633645824848, 0.0884236838488329, 0.1662514370775992, 0.2032425440847874, 0.13173393604736175, 0.08831665370493166, 0.1574434024552184, 0.3058289490159481, 0.1042327355413187, 0.185167312381729, 0.1519735346758558, 0.16468881689492734, 0.16351610482219728, 0.12414077897706341, 0.13986433525719952, 0.1444052448195796, 0.07189441757697253, 0.07726654785895541, 0.15394247257180754, 0.22080523232298516, 0.14100096458869596, 0.1178676603482135, 0.12467111866440504, 0.0991211134579874, 0.18904843638020177, 0.11479485104040754, 0.08185379041899597, 0.15422874430735267, 0.13217973793225904, 0.10726022308752423, 0.20027547023229061, 0.23506531551960977, 0.12352581721760574, 0.13677883953336747, 0.1301859175005267, 0.12022619991893731, 0.162805175228465, 0.15266249286791972, 0.18649249127314937, 0.10410681366920473, 0.1500666499017708, 0.13964515750206288, 0.0786299085725219, 0.20019539872244482, 0.10877819566596901, 0.12999283270009104, 0.22769486020889976, 0.0964855794764815, 0.10135763820501105, 0.2006499493314374, 0.13506680156194395, 0.1563125647484295, 0.08690137521273668, 0.10712223533060282, 0.16552228991302753, 0.22919761828116833, 0.12084834758312472, 0.2147318404768744, 0.10417202307331948, 0.170235799084748, 0.0434867435345246, 0.13148809843246015, 0.3312923020172504, 0.13823305827475366, 0.16323876567184925, 0.20868256507862, 0.11923669011241968, 0.17968835879958447, 0.1357379558706476, 0.1449408934962365, 0.12934548840407403, 0.17697147394139923, 0.12552800332947125, 0.11444946796062494, 0.11106384963157678, 0.14266035699796292, 0.10474570035453766, 0.09025245063727902, 0.13766301225029653, 0.13895549450910863, 0.13748773133322117, 0.1008927837134369, 0.13694195497420528, 0.1495859144075263], [0.03213580262156264, 0.015676810552606422, 0.07969412727341538, 0.020080828821406733, 0.026857634938712564, 0.04343661840163893, 0.07305104946417194, 0.04513598910923447, 0.022456852433782433, 0.059997880335656874, 0.00910896257752733, 0.015222669800653335, 0.051732343215976036, 0.004670364536239856, 0.00441806209686723, 0.02383147655505567, 0.026163526720577673, 0.045889620443866144, 0.011555077489315262, 0.031218860493672472, 0.04662774998935, 0.028484962737908768, 0.034142332451958815, 0.013794956743837366, 0.06650782355497922, 0.030771706463588826, 0.03422723031572757, 0.06451803274572858, 0.05620545782749692, 0.03063126722530973, 0.033379262914100004, 0.055010291717706196, 0.08152706158016959, 0.03829242992064646, 0.03230790427375225, 0.0631041523639954, 0.05187901074907953, 0.06577535156881617, 0.03347627262795164, 0.01608716076119773, 0.03718429139905399, 0.03973108175541124, 0.014204625134176065, 0.026583898316828475, 0.06165286773935922, 0.02797466199544649, 0.033748410041293794, 0.06395031945900091, 0.006762654558124562, 0.04911249105428015, 0.03705306053762475, 0.024288306275622982, 0.007024984609621067, 0.03153630243163676, 0.04049283745247991, 0.01688500494515944, 0.025402044899941936, 0.05572295267014735, 0.06793414137416309, 0.04065342480316758, 0.029459405510175615, 0.0770655263876242, 0.012179969663491413, 0.019049335481418718, 0.03442963840620172, 0.02088079698413851, 0.045615035379605914, 0.06070266973467604, 0.008306661677066117, 0.011849698625625142, 0.03709065630250881, 0.05331963142980972, 0.05346954334527255, 0.0442183843152898, 0.10391248780633174, 0.0391137259711902, 0.01350313182845111, 0.014023599515278495, 0.046633307957240654, 0.05920031768900733, 0.08009311352525988, 0.06779830632430893, 0.04439348520170297, 0.05562097487610675, 0.029117962037543618, 0.0024669683038918, 0.021216174955630017, 0.08360523595324448, 0.04191893310616574, 0.021110694224555648, 0.04724944566166209, 0.0249044765387812, 0.04816733390813874, 0.03256760808008333, 0.023628166396050684, 0.03877238783564779, 0.04837017100785048, 0.012888573222763598, 0.08262776138801729, 0.01905696571714455, 0.03627562302074606, 0.11242028491030778, 0.017755545127475937, 0.015557297005979045, 0.03692204035037468, 0.011646432516675805, 0.025436505449995882, 0.05008411653820546, 0.04130545755728118, 0.02146554423586255, 0.042811904342905174, 0.06915626611800925, 0.04780381369674879, 0.0172909434449168, 0.025951305043793498, 0.03392042359337211, 0.05404381051419243, 0.016155001677332387, 0.06288495162622103, 0.020473448882600474, 0.01885923459344814, 0.03530245003921371, 0.05213038334923406, 0.029465559111427397, 0.015474231049959219, 0.09086243282522886, 0.06633271117724719, 0.04479545919645218, 0.0032237508933195065, 0.03464446095148883, 0.09239549733578198, 0.01621129764844814, 0.05161646858698899, 0.013334268812961398, 0.0605094968341291, 0.032526856032951225, 0.022669522272002314, 0.10482853744179012, 0.04196923826971362, 0.023527647999505845, 0.13471790979946816, 0.020628635313421972, 0.030426700682108922, 0.04527655475202107, 0.020600868456606424, 0.017982665299167557, 0.011803465219394816, 0.01507419334243863, 0.014461662954530649, 0.012987653289230601, 0.03315361937688243, 0.04373826169138474, 0.014432809210472531, 0.031671566745987347, 0.0649728055202192, 0.0329986589419986, 0.01328434669337566, 0.03081249489989733, 0.018754299700019822, 0.03014983459105415, 0.03126603618804966, 0.03570163547391853, 0.05261084688226542, 0.013554003897062955, 0.04441130823726135, 0.0549841451368505, 0.037030962731448874, 0.019450079905049458, 0.05167909627479892, 0.03361405737157311, 0.05372991364809775, 0.020983169313460108, 0.026425436860130682, 0.09207524960079501, 0.03286869978652366, 0.025806483782587514, 0.07349371038857969, 0.046297841885637854, 0.07354360569508807, 0.009245737042698649, 0.017468449847412207, 0.03174261757052474, 0.050815895214797034, 0.04538398326164292, 0.05489225289033306, 0.043031514937719034, 0.09278732066553447, 0.03609646952921345, 0.07741911426907586, 0.003335564538100434, 0.03511355957016349, 0.03636270423509902, 0.02495271709537314, 0.02133763053514544, 0.03859781554990238, 0.01827170835777877, 0.022500067453591094, 0.029629655144808274, 0.016914870882887515, 0.046466519124805934, 0.030408530991764802, 0.038273342840013005, 0.10753292740593035, 0.03960012285519512, 0.03091445737217944, 0.03424707582340606, 0.035911436312861984, 0.020855872313522046, 0.01587085966621676, 0.026288525456742897, 0.06582556097137351, 0.04472232461276074, 0.030526299773144628, 0.05419887054050642, 0.0011914374162217663, 0.034654806968906236, 0.05193439124512577, 0.04336364469641159, 0.037297821798992735, 0.048773746126361435, 0.09426564819389775, 0.006855899428633312, 0.06471197556463942, 0.04812794549751186, 0.00988685304389125, 0.05896458860426661, 0.043751790804127534, 0.010127197808375763, 0.07637145838910535, 0.01647523409056087, 0.04329850424021002, 0.026647378277454167, 0.029891764467221596, 0.03944535011185273, 0.04458003144170489, 0.05816122667203027, 0.054781901755280075, 0.07071894758771505, 0.007992549827547685, 0.029071594565926544, 0.039533116974897926, 0.03168794953624808, 0.0814604502351534, 0.026828167366705118, 0.008918538017408743, 0.05318835843354464, 0.025669530244363893, 0.013769989938385064, 0.04176935443894998, 0.08213812395209268, 0.1356921591345341, 0.06532332904997372, 0.021383760519505992, 0.04154319379238352, 0.05112773896525464, 0.06827153415689546, 0.031291177278504737, 0.04529358871701745, 0.013275081817541393, 0.01103633541553732, 0.04684310496574448, 0.03585140949355499, 0.03360396033273109, 0.059703721724931276, 0.0482563303423024, 0.04687931028104598, 0.03245185985560379, 0.054410992625860445, 0.06139388022523734, 0.008430666414149588, 0.028400706472776593, 0.0331952600860067, 0.044685226805027456, 0.00023738803916315985, 0.02303953124811092, 0.03516313311974368, 0.09581765039793907, 0.09716805656470599, 0.04924330439779067, 0.024502621287660255, 0.056196383516033815, 0.027186123864544977, 0.06591519325851433, 0.046539293647172957, 0.012233351627665182, 0.0335014118031869, 0.025243102723071655, 0.02529659098194492, 0.013054334539769879, 0.014393699464328108, 0.08974183005310836, 0.03509076462397653, 0.030004283631100293, 0.02848991166589962, 0.08344510059443214, 0.04423766674834394, 0.0462923911700566, 0.011180599347778387, 0.02505856363343135, 0.029096963567539092, 0.0745222523748394, 0.025815764937790173, 0.017047949931434086, 0.08482864772480342, 0.03594262375225944, 0.0357566635695196, 0.06659304317567619, 0.015620713764350983, 0.032882286355860775, 0.0167020516575224, 0.08352750867244699, 0.0321256481261263, 0.03324609768066195, 0.03041458691680624, 0.017464820505870927, 0.03782325852361899, 0.04337103361444127, 0.027383244033121777, 0.04200116115351839, 0.05132092335712045, 0.025483981833883354, 0.027943143223021782, 0.026236345293000344, 0.062351375217399294, 0.06204301716699716, 0.03037966096833829, 0.02114169971807109, 0.033094086684286594, 0.030888688089626453, 0.018355627544224262, 0.03531486066358705, 0.0508847933322672, 0.032442797035459554, 0.04181003753816889, 0.02408221713267267, 0.06428128859448819, 0.018788396358309735, 0.03185536081512128, 0.05416777120122025, 0.0356553829154901, 0.014756853868734213, 0.014660418720825788, 0.03583998329216435, 0.03211304406455207, 0.04366988068326347, 0.0436264320066379, 0.04234292063741915, 0.013322259427138395, 0.06960176156773683, 0.01173685962003806, 0.027236430943312667, 0.04211024824349631, 0.13256077474403766, 0.17512235219680494, 0.2405939269210062, 0.06936635040948469, 0.2073765996723406, 0.12938753130935854, 0.1939435390334937, 0.12157190996672838, 0.05759158284373342, 0.12704951523412622, 0.18983713922000703, 0.16597382213559844, 0.13031829749384236, 0.1449319609110394, 0.059871395388918544, 0.1462081101753058, 0.10935937294796591, 0.20043055707168198, 0.12476144809155695, 0.08026620343087182, 0.11152468982242769, 0.10349745201247354, 0.15831265177938247, 0.06595994045417156, 0.09558865139561315, 0.26452314288866136, 0.19180393206977076, 0.1210477909133319, 0.14468480562490804, 0.1013801075638302, 0.1002510931463011, 0.1410688553005457, 0.1579298376436195, 0.09951896589970398, 0.12614053659020893, 0.11488307372576768, 0.1642606350322885, 0.18716732280388956, 0.09327739477157594, 0.18778658231660245, 0.1936287075401314, 0.1659949355187916, 0.09094664120986577, 0.1323418114935198, 0.15897271313494252, 0.15630102746428984, 0.09326510672127047, 0.2093189389955613, 0.10527698999090541, 0.18078297586931338, 0.11608444514774507, 0.10120168568626528, 0.09970183874810896, 0.1894312045506893, 0.16111437321430253, 0.1337475828345745, 0.09800391977712994, 0.07536269679305053, 0.11946078615203021, 0.18311985047353854, 0.1691881125612605, 0.19178320173053973, 0.22460571790654815, 0.09000642150039635, 0.09934248222458748, 0.09471875855759268, 0.1445978546455022, 0.2347992378617487, 0.09760608265717184, 0.1378744831609149, 0.12720258726227668, 0.08321627013144955, 0.18122036610880207, 0.17944874181862802, 0.23887752224841427, 0.1736489659355533, 0.10904402817569434, 0.09961272740075666, 0.13499079031809685, 0.18176916085423964, 0.12438384335367911, 0.18377430406549286, 0.09081585467943261, 0.13299295558564125, 0.08253395392168915, 0.09988530148421565, 0.15561994465608753, 0.15286261035550028, 0.099606774897585, 0.11779528036112748, 0.2622878821867128, 0.2754710602664179, 0.10066012281083292, 0.1284708611426815, 0.05421145353466273, 0.11864441221639996, 0.22868846092493306, 0.12025607734798424, 0.1903108420271066, 0.10023803134719211, 0.19650452499908788, 0.24468878945035322, 0.13373506495789175, 0.07312600350668354, 0.14702540341644518, 0.12481404002755882, 0.17862795521655392, 0.1370076087093161, 0.12485894810168013, 0.09535659570246936, 0.10333780694993273, 0.13637451364869072, 0.0882761046710995, 0.0677721367608155, 0.1666278160747982, 0.15899281528207565, 0.14853749243963152, 0.11685985636206404, 0.16013531284707208, 0.1021157741366375, 0.12729447950879413, 0.09821648619348004, 0.21765121769520546, 0.09600534960026703, 0.07996482444145987, 0.2219192927042323, 0.12306825588307074, 0.18418059113525576, 0.12029875610624591, 0.12306945098023261, 0.19687998469077772, 0.09740648610937981, 0.12030156764892802, 0.1988343056291342, 0.1817058513481771, 0.12881417578506854, 0.07696421892051736, 0.15759695711876118, 0.14871346283583872, 0.1355432163202955, 0.18375271570778665, 0.11836415427106044, 0.11665519597309253, 0.11977612326342253, 0.08939458537966975, 0.1681541696551346, 0.09444698886645418, 0.22166145815243646, 0.17638108062167324, 0.0839255296535069, 0.1061088159199684, 0.0818588236166585, 0.0852282008817119, 0.09590519126504661, 0.12028112076222898, 0.12063502273972958, 0.11705789009049056, 0.09369420788941846, 0.07504526060074568, 0.11030302473133612, 0.10645714843825949, 0.10940323914251021, 0.1837703050865281, 0.12248414448432385, 0.12036090115866355, 0.14249825279318518, 0.156929035701098, 0.09916065891663875, 0.14233392693342703, 0.1099572662684706, 0.17903336894608315, 0.1377997589447806, 0.16771363845515638, 0.15569601718696857, 0.12003070960241942, 0.16054480216435849], [0.02268382130310901, 0.025245079229916298, 0.01905496622766218, 0.028542260368985516, 0.032940892082068234, 0.0353581101573523, 0.1058959277466901, 0.04551996386820271, 0.0028667330925893643, 0.043398593627517267, 0.04002313745478469, 0.06153790475500207, 0.023525621696946122, 0.06736247890418576, 0.03569467556512645, 0.015674488348585945, 0.05599990877653322, 0.028097534837621837, 0.011148595067131664, 0.031502115758015745, 0.04399938659081536, 0.02022820881627981, 0.06571302265529672, 0.09828213992859088, 0.02121572296375469, 0.04406016417628816, 0.04478217140140553, 0.06735496358164857, 0.049745444388639544, 0.01468045192004572, 0.01729037270941321, 0.017228976507941564, 0.029677865057883245, 0.02568923977143582, 0.01649711547689813, 0.03639778723159144, 0.048155907706748095, 0.03913390472711575, 0.07806246724700736, 0.08145432153175916, 0.02987243415367219, 0.04676963713380598, 0.038098226631841356, 0.0048077221858435345, 0.028355991835856152, 0.03879151705111708, 0.02279152751960341, 0.02913784776483813, 0.029146010431671338, 0.03628018124389552, 0.03185767057021299, 0.01747189724307147, 0.02083108170829233, 0.07266415974065181, 0.03468398342750246, 0.04337051650509239, 0.03806172254224939, 0.032924651018073486, 0.09327986923557136, 0.02311076401853033, 0.04310145876520584, 0.1059381468521972, 0.035726246048486045, 0.1093993703984926, 0.10478475551691749, 0.05325698458980169, 0.014712578774760328, 0.0216494110833493, 0.01631023790386896, 0.04884349077098793, 0.008182101526237544, 0.05066883314641253, 0.02128746709786356, 0.034904620580134854, 0.03444449285105352, 0.08488767479936923, 0.051989534253915476, 0.04252636422132773, 0.01736059232855276, 0.031037192318528414, 0.0657110155049351, 0.020271136553116867, 0.043267998619065176, 0.08734941407437287, 0.04261349906183539, 0.039260596517593636, 0.07320272721230023, 0.02474887450526078, 0.053637661340255896, 0.03806700088804768, 0.08366885955535597, 0.0054875725500976615, 0.0204381418053902, 0.036518254557684544, 0.09351514249799714, 0.011827958007943968, 0.050879396242840644, 0.06063451855293205, 0.031694375098712986, 0.024716897995301315, 0.03458189072027322, 0.043075074697093624, 0.07550496698146866, 0.007206616874393677, 0.023265768503469807, 0.022500504123707934, 0.01477984416734187, 0.04560879176302303, 0.004495323021640821, 0.03551518882534677, 0.02151420422559304, 0.024095809447669217, 0.07038570700153228, 0.003120611039658768, 0.09656587315182533, 0.017620183136915008, 0.09538436638972453, 0.033251349213382894, 0.03630188068435077, 0.044173376649738326, 0.033309066277598186, 0.05211357921061497, 0.074117022506412, 0.019723538820060994, 0.03728401306415758, 0.02397719413913306, 0.06534857930795801, 0.04400476452804381, 0.030833822787709297, 0.02844096822363715, 0.08757466690674906, 0.051644978549091086, 0.05216610985958288, 0.02806541660139638, 0.012278685838194385, 0.03738417139937801, 0.018821853333182873, 0.07783575118669579, 0.05437709706565065, 0.07715722711216058, 0.06121983270972006, 0.057460823126377604, 0.02542298399813233, 0.020466860526451663, 0.09243793860678712, 0.07128244356041954, 0.06249656037036931, 0.008858385751204146, 0.029509605336633903, 0.0044028097650997584, 0.01871586506885867, 0.031100561196405082, 0.022200540481736104, 0.012739127663324678, 0.033150535872987205, 0.04944378577713524, 0.04257586882299474, 0.02448846015237993, 0.032654336893991116, 0.07206099573522806, 0.06204067293794886, 0.06579059671850936, 0.05525330629860682, 0.017631398664126476, 0.04740914051991798, 0.027844329372108467, 0.02771098793844783, 0.1017855519368764, 0.04380776501831509, 0.02211115334273106, 0.017408756276352272, 0.04320259769296935, 0.04515628660878828, 0.04788843576886481, 0.1056801054566618, 0.05115793815122978, 0.035496588210545243, 0.02118275436993328, 0.06911374057733244, 0.059147009460796277, 0.04195977325340913, 0.06914483608617898, 0.009969937194499278, 0.06670905953092922, 0.061136325295533867, 0.013380479236553996, 0.03253466246889965, 0.008582726248630114, 0.06820359747977027, 0.04313989722680661, 0.01980274082011273, 0.027669628766635736, 0.06654007585659143, 0.025667097915204305, 0.02672356380630405, 0.025022796903466506, 0.04157571805520885, 0.02822643487654146, 0.02546676592300496, 0.036746755602859685, 0.012670377017779937, 0.03367736304719602, 0.023007229150783633, 0.08986533108738162, 0.06045238114893437, 0.02377291487890386, 0.02380206069398311, 0.05608911971531569, 0.045621604583556616, 0.020027380782149492, 0.04391448489660698, 0.0952346881310786, 0.021876027552230705, 0.03519328634044336, 0.04851429512904537, 0.02052686053268131, 0.035646580565240116, 0.045896239443531925, 0.05679679343536977, 0.06539203181502319, 0.05434273036136743, 0.05231162826079996, 0.011569320979047448, 0.025522414549824693, 0.05820593173285166, 0.02948776608513248, 0.017016839100829056, 0.05205901842864771, 0.018580888037479693, 0.046125897281472726, 0.046462286489024285, 0.043187218477889415, 0.045134816994710315, 0.05987201208969759, 0.015487549488522835, 0.012779050420278744, 0.03256180113361728, 0.0492036325346318, 0.07694939511918253, 0.06795075782124074, 0.062466012614388625, 0.03219929215828738, 0.03852712095624978, 0.03322438674888784, 0.026417563391488888, 0.01930879413961403, 0.02306433142943969, 0.08280837427704565, 0.0553028951699455, 0.040049456405423345, 0.04453086008828494, 0.016280414100976724, 0.07925107564416625, 0.05910920302173304, 0.035678415348933595, 0.007864023256491149, 0.06465736115651746, 0.011523768433459826, 0.07779550092715411, 0.0668309900849577, 0.014996489044278862, 0.018347685127669287, 0.04166202935119791, 0.0690639601840127, 0.004584035524467548, 0.028005991161109942, 0.04690509297013764, 0.043791202197392146, 0.017141397336437818, 0.020875374996854414, 0.05332040900905287, 0.03967799186225861, 0.05870368970077365, 0.062988392648197, 0.04134260133028992, 0.08784040748592346, 0.07155458863464094, 0.03876160131767392, 0.037258383592650775, 0.026466518325070222, 0.02521670333320095, 0.03539433845529153, 0.07094630716188301, 0.06531452669972374, 0.034025787496038025, 0.04857743992620418, 0.03323387474783006, 0.04884015828851731, 0.025442615001192017, 0.03607683852615376, 0.07320434365782046, 0.017411265214304292, 0.038610727961866126, 0.028353839128788923, 0.07380152451655558, 0.06521171003940605, 0.053314104105436036, 0.129149645687111, 0.0515273955440329, 0.010223728717274724, 0.03346812528287692, 0.03773669058817529, 0.027058719612297513, 0.06215844746498812, 0.005003221120850574, 0.033549357415927995, 0.025472731832715294, 0.018497503197361386, 0.023269717686719472, 0.03445077860247224, 0.026731655610004262, 0.058320021376975124, 0.03143976003141894, 0.04038165511202909, 0.08843183502434723, 0.07158584502195159, 0.04136996982138484, 0.03523889921545502, 0.06422154139727354, 0.029739473848753882, 0.025245146262609673, 0.04695891447725797, 0.08846545096246466, 0.010795099116230925, 0.025910160376600204, 0.0566772990409405, 0.019049331650979096, 0.047277484479690754, 0.07414286265209799, 0.016251199337984287, 0.04439609756152477, 0.07337294428819612, 0.08607191649535972, 0.05650029059559588, 0.027825255698013692, 0.010393780126656977, 0.05831961918081488, 0.05407590193734054, 0.03252975567574463, 0.024266712172257326, 0.005626640012187343, 0.06580574993765162, 0.08753960306245474, 0.06315012530033147, 0.0023537050771166483, 0.04903191392640433, 0.017835936479030118, 0.054223649654417276, 0.0359399845793603, 0.024942786680654656, 0.026214002338688702, 0.14289833455076142, 0.1448547852135474, 0.17028364893649856, 0.1788759378776435, 0.10282607553827186, 0.11476406962760996, 0.19671930540953914, 0.17323547763930214, 0.17846107062312866, 0.18414303750520755, 0.18217648980357956, 0.1341520619368361, 0.125326759692642, 0.17469688228541808, 0.20743338210928827, 0.1195484112888094, 0.12216773484983753, 0.12071821222742721, 0.11369428912838621, 0.12540036542040686, 0.18717956488891957, 0.10081080464465965, 0.1555601131892012, 0.18628353313092263, 0.15042078170564868, 0.1408851780598202, 0.31600976723336405, 0.13559500386397685, 0.19717008686594426, 0.10300446677231982, 0.13187114239460038, 0.08417045562377862, 0.13366147455188537, 0.2225808862356409, 0.17141683087233575, 0.08974717734681983, 0.3442442747614076, 0.12531821015140704, 0.11750559187344006, 0.15423099660585005, 0.12398178508925824, 0.14427677187467777, 0.1595458694763722, 0.17741842495818294, 0.3197359269665134, 0.11500192460634055, 0.13990999409748664, 0.06860708832860955, 0.12147136858754581, 0.09946396078674064, 0.13426551955842203, 0.08843152092829829, 0.11598094666917479, 0.14148762960347439, 0.13220632118323158, 0.15118109332698007, 0.09986928258571895, 0.12690869295188498, 0.1680083371578686, 0.16220375024262937, 0.13081060091574348, 0.1800946152258304, 0.18813878357891115, 0.16222166137829905, 0.221552811563015, 0.23452087215358214, 0.2096401749839706, 0.08767713116662157, 0.08415768493808086, 0.10231699479082901, 0.10547432657932082, 0.1416836102162638, 0.14477069940297835, 0.15079507694369362, 0.10653152791482788, 0.17260478809475902, 0.08645213359305937, 0.14675552596247968, 0.13158370620541035, 0.14899270188423896, 0.1301260707118819, 0.15937409724199003, 0.08331052958965303, 0.19657298261600156, 0.22568726551628884, 0.13908197562540733, 0.07980511043100588, 0.12324552862874924, 0.1358412092010821, 0.07986385405303971, 0.11570067340207678, 0.17186793408566908, 0.17149183088012282, 0.09233899069048705, 0.10041780920038301, 0.21312354613215695, 0.20149646116600883, 0.22624131562488697, 0.1734992723551489, 0.10583630312354335, 0.18945349770928585, 0.2367210307068402, 0.13987694506443318, 0.18816100012871528, 0.1193109853193164, 0.12143124090207201, 0.11548409268500344, 0.12474244145015556, 0.1252011748992147, 0.11087563715033955, 0.1582465077480001, 0.08633299925995451, 0.10712560611746966, 0.12612333791630884, 0.23137283301161182, 0.14323024980483517, 0.06065641717624761, 0.1314483537909485, 0.13270472266500996, 0.14186572463762376, 0.19456359527764783, 0.10509971724522692, 0.18563713878393176, 0.31039596685478765, 0.09332158272304843, 0.09096020862700478, 0.1330462446616542, 0.12813536825800134, 0.11561205235099602, 0.07022997664828455, 0.09833757405079181, 0.17625352698228053, 0.171181274157378, 0.17443792924525278, 0.16106301467985878, 0.13016149461750062, 0.16448171268547737, 0.11896089079879946, 0.21485203967219402, 0.17780946687825266, 0.11868367422251933, 0.13506519277730297, 0.1880607038976685, 0.1352382673611564, 0.08502849708161048, 0.2003870585993413, 0.22076671342215232, 0.12873385912708699, 0.07844479874737802, 0.1269618134885546, 0.14830906034236954, 0.10333074361927087, 0.09984698176624314, 0.31957575330330484, 0.1298506161378276, 0.1483497702546658, 0.16891730048002737, 0.13653033593248937, 0.14273106691337403, 0.14841983665622052, 0.16137373994194693, 0.190081505946094, 0.08967444495928865, 0.1286218570725572, 0.1431488912672766, 0.10520887711355764, 0.23168607104209163, 0.21160258581080746, 0.2840210917976595, 0.13887520849464402, 0.15492208452234346, 0.14963764066417373, 0.14666716538129315, 0.12476659620240813, 0.18973993798417432, 0.18464258811887235, 0.2633174430699118], [0.0678745627162918, 0.013178617941335806, 0.05321167814995974, 0.029048650232594342, 0.056031946573526635, 0.09968100881744778, 0.023143836034221515, 0.058243221062566006, 0.028207629333220186, 0.050332773356668414, 0.08579641595602998, 0.006813668353002399, 0.006619126549095757, 0.052975795847634156, 0.037619789401369716, 0.016122132674941135, 0.1162116080822964, 0.044638886146487734, 0.02435817349431736, 0.039554326119081634, 0.03440580541087735, 0.011610538424593548, 0.011560232303435765, 0.027079122448940913, 0.026138153888525504, 0.019266343292509838, 0.04564817251277067, 0.030983257813439257, 0.028042845735927264, 0.09379425897232949, 0.01832635915507713, 0.02471722358266913, 0.03260989996394323, 0.029533444077617703, 0.019507459890578064, 0.01908350874850106, 0.029157471107018572, 0.07938258995812747, 0.018150607093928323, 0.09325759139873328, 0.07027897563192152, 0.006655262916484067, 0.004032891283127209, 0.02677076056809916, 0.05108396853170088, 0.05384845426306129, 0.0302922522513977, 0.027726543353750344, 0.017847860637571544, 0.00673598895270017, 0.01859740489312718, 0.016175391107437112, 0.14442159313588374, 0.06997816354757355, 0.0976401352654061, 0.04088219397911622, 0.032019966296971805, 0.016814984508880207, 0.03801023760329812, 0.07332945347673471, 0.041805199692927064, 0.07467891735535476, 0.05001812955484756, 0.010609146594370325, 0.042014479592082, 0.040816892644450556, 0.027820540426839745, 0.03411684087627838, 0.07966145362344482, 0.01625688754082207, 0.05062520060868514, 0.04277438135637392, 0.020377245476289142, 0.08295928593724966, 0.02668742935413555, 0.040780748616183, 0.02764511778349838, 0.016171934135678797, 0.0206886506414101, 0.028788850665272727, 0.05026372968249264, 0.040148251104138555, 0.015654143926146773, 0.0763141243688522, 0.0435776628493782, 0.043087485321466966, 0.027863889512035157, 0.05468197324643693, 0.02401776424038314, 0.04364879794358727, 0.07041059719819216, 0.048771264001486764, 0.0325320232960005, 0.04602381606556235, 0.027580329727741982, 0.07186342932043538, 0.06794796926119635, 0.012616691491266173, 0.03610444450450521, 0.018239429243089213, 0.01761735052681498, 0.04052549578069199, 0.016586286196064566, 0.02556850814500884, 0.10636576947065131, 0.0046592045504029005, 0.03072886108120363, 0.013144469572111003, 0.012786085980253355, 0.026165171894395066, 0.04704750871526138, 0.015803790583665815, 0.051794748738287925, 0.015645997538681955, 0.04760496408468293, 0.06703073985033459, 0.06591637303391773, 0.026385609864167152, 0.03059753828922347, 0.022164819717046716, 0.016094815894781102, 0.06948938413012413, 0.05033666891376338, 0.034979758483748284, 0.023633758837897933, 0.06970692245710282, 0.03167707683338273, 0.02102941038056968, 0.04652066621929408, 0.01525961247558195, 0.012356418864651313, 0.060197499866086635, 0.05593821954643054, 0.024411740277202863, 0.09939089132052276, 0.022697314026675398, 0.07842350150308303, 0.051948694106672084, 0.013522286899387838, 0.028549712489268957, 0.03511263260377511, 0.03423912766119165, 0.015234577679826368, 0.038502043068048455, 0.028762319125235084, 0.017016869744346026, 0.0521640184395496, 0.032006948547918475, 0.05790046183392406, 0.06561441947856257, 0.017321682722878554, 0.051722345768564174, 0.026687281882210125, 0.039413706850140326, 0.10755111433325276, 0.04335615235651213, 0.0538410998189882, 0.06012503943976857, 0.0750202248473802, 0.0956977959421854, 0.05531917070789684, 0.014763615552275894, 0.054152794182300575, 0.06089683088864531, 0.04358879793735762, 0.016987229802555615, 0.04340987044176267, 0.05595680100903396, 0.04206939277449443, 0.028566761776023818, 0.004484122337382888, 0.020431268081489592, 0.08930033358234553, 0.042104717088683, 0.016632071440859188, 0.0300887601465107, 0.02027415302431872, 0.03394790316721605, 0.04313870979052398, 0.07066968813418381, 0.05311742635263551, 0.01653147643552192, 0.06911217775796691, 0.03113014176638136, 0.06286657317691753, 0.03347306654998853, 0.06456434276075133, 0.02082411988428043, 0.053440688643604524, 0.05588826678332783, 0.021213328938991315, 0.01743376904708003, 0.12732473232092398, 0.021979616046132102, 0.037150016625321684, 0.09493588319709224, 0.07811898921406077, 0.031367150217955636, 0.04754363491590466, 0.05483379272083121, 0.0407514151095623, 0.04455831667949115, 0.05760365255898046, 0.04388359240106037, 0.04517017578285548, 0.05255098094142253, 0.0711852882898623, 0.006216769989189362, 0.044183983137049986, 0.03160159035976375, 0.012664794152031743, 0.016267155034227238, 0.05717291962355376, 0.025173459585095127, 0.01338791986551857, 0.02260871021257293, 0.07070021673796639, 0.02499455890257753, 0.03275493189932839, 0.04485124188865866, 0.04891814986964868, 0.031498915425712065, 0.006498192388173794, 0.03536687037276645, 0.011569826597077473, 0.012497484379808509, 0.010653846867142186, 0.053505997639149434, 0.05473815430436404, 0.08384066243325511, 0.09753076855333583, 0.030666227647734266, 0.029945702802750374, 0.03038808985072519, 0.017902591874101953, 0.0209917763112894, 0.034397876400861054, 0.0555988617481724, 0.01806084457184038, 0.02525664524235312, 0.01880744704976678, 0.03384151653717122, 0.044454385361243645, 0.06358615573375456, 0.05147533986957804, 0.0709166672200926, 0.028569845279919046, 0.03840669576499251, 0.03675661515444517, 0.04886249741238933, 0.06531496336984058, 0.0204630013585331, 0.04124009110514195, 0.04461063282384027, 0.03398040827784327, 0.06894956793515913, 0.06236541377861173, 0.006568138609685365, 0.06317521851029127, 0.054866129292115096, 0.059454750810419364, 0.05160415755404581, 0.0617761044732986, 0.014792420458228839, 0.021026173659089594, 0.019288613468468673, 0.10980010333080446, 0.031140445648962935, 0.05311577160271907, 0.030545220229654547, 0.047097641509026296, 0.08523575450864532, 0.037880600204751376, 0.04991005753136931, 0.058994791620681365, 0.03806738393200982, 0.018541013161020897, 0.018248497808892882, 0.023936901744755528, 0.032726142315133926, 0.08668317038926386, 0.05179842212988485, 0.027129628710568916, 0.08006011045748189, 0.04096558648011377, 0.014145716803238518, 0.029668560920042858, 0.052181960218736244, 0.01751074556171173, 0.02858900705412511, 0.024514535870102626, 0.01802484418505863, 0.023607629494020538, 0.052779229177582654, 0.062286418622299555, 0.04345786201977923, 0.01057669798272752, 0.01712649118065113, 0.01701573018855866, 0.03267374190111314, 0.09804460670678847, 0.05367222339695981, 0.034515195105585365, 0.02453968079099732, 0.06481563492167382, 0.025081544355939955, 0.03740745664183651, 0.043056535369326035, 0.03848882805135462, 0.02319579594768584, 0.04998706468951799, 0.04281910939983303, 0.040149024852942077, 0.01807354439440514, 0.07658917291630661, 0.04659502654366436, 0.01605845927711456, 0.01350633216075479, 0.014848780589208249, 0.08108676786744788, 0.02820447879663158, 0.04199106028423675, 0.07237896052820068, 0.07417140708815667, 0.053987966534952005, 0.037085102165057775, 0.04891058475139642, 0.02000167661707007, 0.05187515349638078, 0.01942370924347591, 0.02671206291134079, 0.08250984513471205, 0.03187908847335606, 0.10480291180072293, 0.035082559822307485, 0.058764612842952056, 0.04280716225865387, 0.027770474665768208, 0.019113399584086675, 0.022165107000018322, 0.02851549325691116, 0.01796571177340323, 0.052299501088958596, 0.014613412523401842, 0.05626967131731011, 0.055687513442770134, 0.028610624140128497, 0.0362319253655451, 0.021717221355966983, 0.06161981104542652, 0.02503228298718891, 0.009325642886030818, 0.18404784341973646, 0.11904441736518376, 0.1520040862622761, 0.1544642090917595, 0.11754925122424481, 0.175130304189459, 0.12195757394956967, 0.17675064143634614, 0.10351925487479857, 0.06395641751887818, 0.38069679131430967, 0.0771048803242945, 0.13659703154717723, 0.1411764140451147, 0.17191494124070292, 0.1097777718678117, 0.2903185183963468, 0.10453755426551066, 0.09693581701046038, 0.1606237858293518, 0.17414571266741524, 0.12919414007375318, 0.15536849927758017, 0.15036490325245166, 0.08792631658575228, 0.11677356421827309, 0.21758073760617166, 0.11913895261503997, 0.1612010943673311, 0.224875258281827, 0.20355824891838337, 0.08664735577880375, 0.1364516433809073, 0.1261274824519792, 0.12206478029369347, 0.10746900502952839, 0.11206506526157742, 0.13047640271965535, 0.17848144856191453, 0.12089221377766902, 0.19439165450392232, 0.0754606947603245, 0.08617824183837061, 0.19682102656412512, 0.12484736485226501, 0.19110532116986093, 0.200970878884677, 0.12710682627174164, 0.09228577056238729, 0.17261313845313367, 0.16585320925279973, 0.1488225231127393, 0.18041928328814047, 0.16370578819224912, 0.1661395269536203, 0.1286061829136264, 0.09370359246649089, 0.11641417705123464, 0.18101074913096044, 0.08448334125381324, 0.20175768182643, 0.1334231752421587, 0.12917716356535114, 0.09433071204130689, 0.09295059698483638, 0.12874147404105435, 0.1916030791377829, 0.10926103790200527, 0.1432344632884187, 0.14104515254016847, 0.19360118966189124, 0.2377441104861998, 0.11087328526041201, 0.21895284704383344, 0.1581993167318644, 0.213303959838325, 0.1776113871845507, 0.19226591373162885, 0.17199050815355393, 0.2724919588335099, 0.11878869721605895, 0.10367890759821861, 0.16253181973532324, 0.1596304302614543, 0.15900793785770095, 0.08607426072440802, 0.08455360683822825, 0.15315594542170727, 0.12175318169137164, 0.08927256289509036, 0.3031918292324389, 0.1345969904814997, 0.1508792240412966, 0.12230656530347564, 0.1368781398501127, 0.2801954632084216, 0.1932623336512235, 0.1455566136827392, 0.1439221804180453, 0.14432606197172596, 0.08820085185429744, 0.10748283291656165, 0.15341658385530596, 0.09305153672973956, 0.22591540650013955, 0.177008950962655, 0.15944166619691158, 0.13262924768270987, 0.14190432014724902, 0.19178223645975515, 0.1376614647526895, 0.2824678638529393, 0.09480104406153965, 0.15369242147332238, 0.1378034974538511, 0.2288923169215841, 0.14886499502726142, 0.11269404643004942, 0.1667533319203123, 0.11844058686326589, 0.07340935644723716, 0.15210430588453047, 0.13513887511386027, 0.10803040192132035, 0.1928275021454019, 0.1870265464869238, 0.21849140164352235, 0.13242497799857972, 0.16562813262064613, 0.12341127941204656, 0.12806724771977435, 0.09112553040106451, 0.18923413609304737, 0.17735171402173658, 0.27533285800487767, 0.08949007823943131, 0.14912901956948543, 0.08918338259982486, 0.15117723224384172, 0.08017785051056454, 0.15178098613696714, 0.16181111485967714, 0.18415803750676496, 0.17763542702361462, 0.1698598337750281, 0.18747193468434198, 0.20616927574719154, 0.1931694837948007, 0.2013267880125392, 0.12644619035023835, 0.29275991803696083, 0.13906366612401702, 0.2368855251059417, 0.15468612944166507, 0.1475770326872026, 0.1445821958083299, 0.14690449942023526, 0.20543890284194102, 0.1148147080394049, 0.21421580365107906, 0.1861874197399424, 0.2472481666313064, 0.11074807585006761, 0.12309106998145582, 0.08343274359621349, 0.13932983571242902, 0.09442813544263763, 0.16556955753795563, 0.11452342608883498, 0.1287218162249173, 0.12188990540321797, 0.17684749027173366, 0.1800504119525994, 0.12141469340290754, 0.10282049841818311, 0.1059840891450163], [0.0531341232389452, 0.019671915985283353, 0.05208538717500145, 0.07582086333704573, 0.08774476906945629, 0.013938619297057872, 0.03778726388249667, 0.059996612460142186, 0.03555736579601804, 0.053954530627496784, 0.004507330013439059, 0.0040097240660895385, 0.0866732801941614, 0.039380910626101884, 0.07298036253139858, 0.047380151752863205, 0.023572527345330007, 0.09117559424691624, 0.038839573746607195, 0.04611969579972568, 0.013212873562870008, 0.018559753586868608, 0.02037871253466414, 0.0357873032560512, 0.005046473487445544, 0.03511234915124313, 0.05088237632486609, 0.01474078900496205, 0.0376103014024275, 0.04397646140968127, 0.022243096665929885, 0.07489902207687979, 0.07501629481632864, 0.0430530573301498, 0.02955188189873532, 0.05915261722440201, 0.01766265313621731, 0.04943809374385784, 0.04605861560952279, 0.02827334052492534, 0.0748646094073211, 0.01469549788687859, 0.021987391838563547, 0.03549643499296039, 0.1020702072269013, 0.07710100391939764, 0.039829861132367965, 0.04191308785530348, 0.10319972726246042, 0.04971470511067779, 0.017699720300433618, 0.08959691686135146, 0.06465213643687387, 0.027902649730564128, 0.058346566323551445, 0.026912726236567385, 0.021622057914012865, 0.052809501141910596, 0.010818046322392841, 0.013693901128135623, 0.018430524130141544, 0.05841530356255751, 0.055231737093098705, 0.024884418441703724, 0.01655054436395726, 0.02504918480201835, 0.0679335514864614, 0.06318389062559412, 0.05683578348027603, 0.14690312046197154, 0.09367635037990348, 0.0324631366698492, 0.031669686000133236, 0.0014590999184762158, 0.05304679687645647, 0.07348163684289302, 0.05503427793061542, 0.05071484438714482, 0.052314370855568885, 0.07198359021135876, 0.025299203341766715, 0.04493945691313955, 0.008247128026860376, 0.09073396754120627, 0.031032561317026138, 0.020289379021813794, 0.04056609461023923, 0.0757003194021602, 0.03867389191122305, 0.030835289846084295, 0.0494590079441907, 0.060937824253473556, 0.05746220591508093, 0.03421503419597303, 0.05148130769450819, 0.07774280939972208, 0.021352548182250995, 0.033069123709273916, 0.05436875436815524, 0.004922743105599958, 0.06328560794974047, 0.020278812754118157, 0.026551385545322014, 0.008696369646537689, 0.06665562489821066, 0.05945077098365273, 0.03156158333313802, 0.06636856409210352, 0.018139429871113073, 0.023217715638419314, 0.023835833680125016, 0.06427303782754368, 0.008767766168250913, 0.01599388764119677, 0.050924645226088264, 0.07188708611553715, 0.05123887534043001, 0.05121871190626295, 0.004348895369818615, 0.06686754013982511, 0.059475243662393866, 0.005601064645640192, 0.03132427227683365, 0.11089374746886954, 0.037907083864293756, 0.018420658832896623, 0.01398893882475433, 0.03741994387500229, 0.06643363560039191, 0.04163032097201194, 0.06032251775444997, 0.03473779727374354, 0.018544157951950066, 0.03018717180126377, 0.10444324118115249, 0.042602394617372946, 0.030104809688524376, 0.019371090494396708, 0.015745879124639737, 0.0316063592570924, 0.023975819011308977, 0.03392324662737308, 0.01660972848654755, 0.040800130640667294, 0.034172056663420894, 0.059816175771336404, 0.04136982426467923, 0.004521913933492596, 0.042323182382050066, 0.06731905704063755, 0.04677982227275929, 0.03685926327541952, 0.06032706448628057, 0.005847691331103805, 0.05412227323939724, 0.08300560361315167, 0.023457432210805918, 0.06343728952830838, 0.024791225760934815, 0.026080344893759298, 0.05972441759020571, 0.01638613423452743, 0.03023179642285311, 0.039054660592228174, 0.04919957226863311, 0.13223135693659707, 0.07267741306174187, 0.08650063461954556, 0.046715195095466996, 0.06724124549016838, 0.059598886422933116, 0.1320662956324316, 0.08763809898687948, 0.11665896512567998, 0.032207822547324245, 0.030783596148173657, 0.04706682179183249, 0.004074373986617092, 0.05282352821180417, 0.05017510480097225, 0.006701176481006006, 0.02267516642478445, 0.005824626338923531, 0.013305329841621702, 0.03191716495841261, 0.07203863362871832, 0.04269183155209307, 0.014126264873231131, 0.0774915861867128, 0.047732019766924844, 0.029328931160571597, 0.03408036743020339, 0.0137340584995165, 0.06512690410618821, 0.061602891993618784, 0.07123034958156847, 0.08740178384487668, 0.01975134398127275, 0.0314356901893212, 0.047060260248761025, 0.03955232662959926, 0.00940353200290232, 0.025233681756822814, 0.060192861203705116, 0.028661256806264003, 0.04121733063291158, 0.05576130303163683, 0.0038175047056058487, 0.013583576806159991, 0.12640820771095254, 0.039386901433669755, 0.03509387111050948, 0.046271944283357555, 0.01654515876584957, 0.017065334381655823, 0.08480420185913963, 0.08364243718284754, 0.024384444564460747, 0.011045621358789505, 0.05918100844287585, 0.007267799528856432, 0.06303733034480004, 0.08761009847324702, 0.044148371539889805, 0.04296326033410527, 0.026732952213816108, 0.028466164855466738, 0.04545973403559578, 0.038958236935638615, 0.024622638537097844, 0.03422813429947823, 0.03350335766651458, 0.016291765608794747, 0.028842689409371347, 0.05498488824213705, 0.029018878140636993, 0.02135988155890617, 0.01681849319157341, 0.04400409037067045, 0.03570805912116363, 0.008799414218012846, 0.026316430209384813, 0.057343761061107924, 0.07963875443824837, 0.0285262931814237, 0.08674900032459729, 0.03794910378694054, 0.031614119727765365, 0.03542135454594128, 0.027437465821182536, 0.021218162953793522, 0.03304363979447273, 0.042656878790547775, 0.047858194448053844, 0.07740565410424625, 0.08994313497697154, 0.03542356854004245, 0.027660979633970607, 0.031007297652503176, 0.06112055154517294, 0.0392351049419132, 0.006541344684533656, 0.043401217478657925, 0.019862083905947306, 0.05345054819519001, 0.027130674420585556, 0.06299534872654947, 0.06607218765683713, 0.05073712222398289, 0.010403384954007644, 0.01398508923293482, 0.023519023764698256, 0.050272543524061485, 0.05673558684065939, 0.0063752635258189855, 0.038238121947694215, 0.026097489941504695, 0.03779341939896826, 0.0714491289709845, 0.04295433924022702, 0.07104962944023072, 0.048357936583699725, 0.010134309019532897, 0.01973950600762281, 0.040467491433505094, 0.021270325880557783, 0.06278566280079466, 0.0257973175405735, 0.06499208029239409, 0.029348916479296265, 0.018437020555739442, 0.07161435115361406, 0.005025071384865912, 0.04032517527981151, 0.01962383822237532, 0.041108151612382744, 0.006752016469686022, 0.029605582747007572, 0.018168387994650873, 0.05042598710485524, 0.05277804174130002, 0.04534476339035938, 0.020612009290245273, 0.07499245416012502, 0.05323956758084317, 0.03380193277412365, 0.043357435553785295, 0.021026765462011102, 0.034994616759039705, 0.0697552779268834, 0.0627613126961214, 0.00707895789791139, 0.02128799569853131, 0.031443165292242364, 0.033717287719369896, 0.023952518447091984, 0.0010489723541879006, 0.02163455280805788, 0.010933148160186267, 0.03643039959452806, 0.033170254976158185, 0.11509960081668631, 0.05103796878228745, 0.041091025716835455, 0.04409033654918594, 0.04024374396390012, 0.04470662364075261, 0.04314750831033434, 0.019747645691818288, 0.03148855408653617, 0.0420732538576328, 0.1443628648356084, 0.008588128126106195, 0.0811811805432362, 0.014350243126823297, 0.06654456513182772, 0.04035140229989925, 0.03088698162877512, 0.027320692954104275, 0.05167030158542818, 0.186143139857919, 0.024328253930434588, 0.02072166328528716, 0.023513737758020722, 0.020865189857901107, 0.057863210808605924, 0.04207175615574083, 0.027188628972057375, 0.061274090886957226, 0.09100568360619007, 0.05000799421160933, 0.012713412964536298, 0.12363333765777851, 0.11716596977484804, 0.13188724556276876, 0.23199765432265498, 0.2962494178885414, 0.08653915352037839, 0.13134156113430379, 0.1338431906075247, 0.16334310684713627, 0.11926485150451623, 0.09495465235123712, 0.19135434571052753, 0.15063655803040152, 0.1148061891416869, 0.0959085007648795, 0.27364412442811076, 0.15687369350944796, 0.20413384141941227, 0.2284918674418042, 0.21752239234985846, 0.20684594588895, 0.12296169305280333, 0.087882956009238, 0.13478468202294844, 0.198758386315838, 0.12972736791256936, 0.15422970957813725, 0.11350901842477823, 0.10420527895011249, 0.1452023899483104, 0.13985069889214732, 0.24906692065058217, 0.15198102701575528, 0.18505483535268616, 0.1296768673966008, 0.16737075282200692, 0.10676935991092075, 0.2574770645268502, 0.10876231466329868, 0.18529705703258517, 0.17110178487435465, 0.14312255316443984, 0.08371660215479713, 0.11851067624745831, 0.19363269119733767, 0.192838579776787, 0.2487312975309549, 0.11035533321480598, 0.14646635841458075, 0.10043588121451678, 0.12249533702889759, 0.10791028699567241, 0.1091872176696216, 0.07812932374015932, 0.15943979694237634, 0.09039858190883553, 0.08656913054085548, 0.16813933819292054, 0.14316361547718126, 0.10515271520782864, 0.14236722111461625, 0.08646381643390463, 0.12132381239245016, 0.1821242732506606, 0.08567031022281417, 0.12271020170902053, 0.1292656773641225, 0.15200705868342232, 0.08547116566689746, 0.22290204561525778, 0.1693692617118359, 0.20449085371388545, 0.054826863455556096, 0.13637269035943095, 0.08914387544556972, 0.16668214703038817, 0.15818106851750807, 0.27184063088028665, 0.19517012240905918, 0.19728850873727954, 0.15011224745502397, 0.07773209182966141, 0.06195559887395752, 0.25187892298544606, 0.10737538142430206, 0.09558919531803939, 0.1284780930126867, 0.21350600786747473, 0.1202168383245026, 0.1078640918938383, 0.18779266505472123, 0.11311450612641151, 0.12842304193444792, 0.0930609749329667, 0.14071564280217694, 0.10367352966099017, 0.19847243633722106, 0.21446525720098328, 0.13891435558757476, 0.0923735029514759, 0.17550291403407053, 0.16855109513046282, 0.1905549789268163, 0.12833396889149182, 0.18577409998303462, 0.1381881808441493, 0.09907395308536869, 0.13979862023505474, 0.17229557968676093, 0.0861602004677538, 0.07225729044406645, 0.13835155675488134, 0.09513236176703246, 0.05526556370539531, 0.1294622248819759, 0.24292592920603293, 0.13119430371349858, 0.1409945447718905, 0.0821954196679496, 0.13323376766375958, 0.16645408265532988, 0.09226206780201004, 0.13988598490193968, 0.1615528819421607, 0.1359567352600636, 0.12564824082918707, 0.14408451444920034, 0.10122909631219604, 0.24584938201212117, 0.1602132546324884, 0.12770237536319803, 0.09358660317957403, 0.15055657845110665, 0.1745480926887643, 0.1879839265658971, 0.1446756891786091, 0.11150178379349171, 0.1173231710169104, 0.1095278739869114, 0.09081653649768523, 0.2125993428090888, 0.16965983886151545, 0.17741673956474951, 0.10135830470150518, 0.09907920078765, 0.23041405865261633, 0.09702808464006071, 0.10657953864504253, 0.11910672329606549, 0.12710593760974948, 0.1236805133521557, 0.17089713214626237, 0.11599903400506704, 0.179820325105421, 0.1959048466937196, 0.27897943652445273, 0.2008847246367124, 0.1621654918116908, 0.1139938678111761, 0.10627552431317107, 0.12436259973553881, 0.1306674803697294, 0.1416195193005185, 0.10652858613719864, 0.2270325771983593, 0.27405392018056685, 0.1480081410057122, 0.13706835948171156, 0.15161140491404843, 0.1461788302948398, 0.14600563313691847, 0.27521491110805546, 0.2005612823150812, 0.22574859851550674, 0.11106684503536071, 0.1105826851280947], [0.029345930651611382, 0.02517234301194549, 0.05542219421195407, 0.049222708123946385, 0.003260114453657861, 0.06613167438415751, 0.023061280484281244, 0.03411613990582767, 0.044325808994472034, 0.0788309453656116, 0.03818578665114699, 0.015152003935297892, 0.026012645703890634, 0.08472020797912153, 0.014703447006702905, 0.0588407734739444, 0.08570898234123185, 0.020566664546007113, 0.08728246565067, 0.021529208057590073, 0.020516851593950586, 0.024830474360515515, 0.03600659209393686, 0.045332283818072854, 0.041795933859482895, 0.09785385847452188, 0.01795811984207361, 0.009991653871932819, 0.0458550354045245, 0.026873879833146933, 0.044535885625068224, 0.028639854224879416, 0.07691780931406444, 0.023793258343733126, 0.02810852436889564, 0.046374565591254545, 0.005993385932543466, 0.023310766592922232, 0.0398901445911296, 0.04897382913998539, 0.01541324279030725, 0.054040382270731276, 0.034495859046376524, 0.04002484583085583, 0.023965871359612194, 0.038976814567802415, 0.015488779059641305, 0.029577923142501426, 0.0590636131293591, 0.04736518622526238, 0.06307438218725786, 0.029548650922914668, 0.018404471395056576, 0.021846694045610005, 0.07418387133868472, 0.07845498771677095, 0.056661548273217295, 0.038808305867977684, 0.025263840723181927, 0.046907709160399054, 0.020486727101548065, 0.0271838007029146, 0.0008688944698435315, 0.034061831932875423, 0.05233728454538411, 0.0285643600903812, 0.027984617308022517, 0.018746407079179923, 0.05964802713283609, 0.031906629334233945, 0.02022042536296912, 0.0402174671480973, 0.09208045133780088, 0.07328494376833401, 0.07204827867568502, 0.06348855613220124, 0.05920848035584054, 0.011958974364754415, 0.05761929607439426, 0.01589139848346672, 0.05808449913597396, 0.05786886070704749, 0.02963310445568735, 0.015615611618775276, 0.04804196361933024, 0.047022729601350524, 0.02527980216508431, 0.036475074011832476, 0.0275357146822517, 0.05437474900616273, 0.0390038000149352, 0.04420485520254701, 0.04564977363653241, 0.03140148053306245, 0.018293593574555653, 0.03423032148050205, 0.04801054252311588, 0.006098141752919483, 0.04006495053369192, 0.029806284376630382, 0.030155086123775092, 0.061954334828882456, 0.03275288261413094, 0.09608393489953973, 0.03221662872801385, 0.03240833840062542, 0.03653753316029906, 0.04029985224347442, 0.024747407446885784, 0.057529219456257365, 0.03530017092763897, 0.0363352821178494, 0.021446775081717682, 0.07493652208077331, 0.022586124025345333, 0.04321241894015863, 0.023670111625124852, 0.11323411543402942, 0.03051704734623913, 0.03739933994027876, 0.06627461106906976, 0.07289988499495291, 0.007349214565399434, 0.03793973070118697, 0.023210681036054608, 0.07484237753575848, 0.05279049833094882, 0.035388431917395324, 0.02595036658608625, 0.062481782534309936, 0.0935549943918182, 0.11079846911372677, 0.04083458544506181, 0.057295696704738566, 0.041228228233634465, 0.028254860568971887, 0.04207744052813899, 0.04489786599973037, 0.022831228111059438, 0.04676796706213106, 0.024808795987478188, 0.01604267020499514, 0.06195656797518173, 0.02426798196299182, 0.050644816289986336, 0.11771477218116484, 0.06285099477897729, 0.02786632567163437, 0.03360870624742201, 0.05565855531923233, 0.013454059108851418, 0.04461363971894307, 0.0653173459032851, 0.004624603231692868, 0.004368801206921138, 0.042754064704621994, 0.04165340320117051, 0.05946292496857144, 0.044730314909810984, 0.05923216013358005, 0.08878321657257696, 0.02264157155408494, 0.05800169269223848, 0.05573048714488264, 0.048952895787454424, 0.047485147933325464, 0.07296320982277393, 0.0375992773971971, 0.04434182023208949, 0.015889420061402263, 0.06267829174776712, 0.04488129551792818, 0.029158250601481528, 0.048005038181379925, 0.036726193802972, 0.06342773258145298, 0.0164091628375313, 0.06053012758192997, 0.04222629907270593, 0.037954274880429434, 0.054865516421775666, 0.06841388861498526, 0.02910794543793365, 0.024565235568931507, 0.037648084858853015, 0.07913653017772783, 0.03424981841817498, 0.00996018872566281, 0.05782734640243073, 0.02708468424727119, 0.043343435296969074, 0.06852592897391127, 0.046127755044689106, 0.018987786062362216, 0.06697487671889606, 0.02269987659078212, 0.026323370965978792, 0.02641980994432684, 0.05702226077236476, 0.028678204586368897, 0.013411897459938643, 0.020728558076605685, 0.009074856343138362, 0.05201398395001889, 0.03861515595006847, 0.006053383065943396, 0.054567286053732525, 0.07968309560730573, 0.012672658044574483, 0.0749776839849449, 0.03554918397698672, 0.05518224398275057, 0.07022224682112856, 0.11728058418919964, 0.014763231550703847, 0.06765998914958009, 0.03941122472526566, 0.04517168880650594, 0.05119101399736059, 0.006092164351890285, 0.04194478091273097, 0.027586268824374968, 0.033017336165592555, 0.051248619978826855, 0.00549245109376047, 0.010912247366392085, 0.040076579748382496, 0.05189958020984646, 0.047040391758444815, 0.04511026387673713, 0.04588033545822386, 0.023457474345641754, 0.06324209415564133, 0.069402486776873, 0.02941322956053961, 0.05055077516684129, 0.030420865007345716, 0.05154633706796074, 0.05679099414978297, 0.010052464016142392, 0.04450492801204805, 0.021368819889762712, 0.052816219733006535, 0.03531994365696465, 0.034223265810719425, 0.0671746724495484, 0.05060308365031116, 0.022900622270460573, 0.04715907409967435, 0.03211161339535348, 0.051390836541090286, 0.041665266072677995, 0.05347497873909531, 0.014090195538536196, 0.012239605777957028, 0.010525090469708367, 0.13753856892787641, 0.027884259789941773, 0.07001479787211265, 0.029290431411936883, 0.03505226104490219, 0.0456000353780485, 0.029460958753442092, 0.03599349199043166, 0.03706933224513646, 0.028019443665060307, 0.03467828756378543, 0.0830406521356875, 0.062078038876455646, 0.013530834525402997, 0.06582906199318748, 0.03788063850914759, 0.028046860036650495, 0.10915631368275612, 0.04281819392476351, 0.032021360576994, 0.06275083261331724, 0.01717081511273019, 0.041268673845596855, 0.02907405370816348, 0.07123340627238636, 0.020283076033416777, 0.035844169962670536, 0.05313062987801048, 0.05089577520266176, 0.02116874262179819, 0.03553197764220738, 0.023352696500237913, 0.04761230703743716, 0.056603777582847306, 0.043072960294422605, 0.019267750979070703, 0.041433677693168004, 0.14963874383078468, 0.03416930257733311, 0.1069112776988937, 0.09653491553880515, 0.07547584031858752, 0.07705755141233245, 0.04034950240184704, 0.019591760205765887, 0.1241957228029928, 0.022907564942274364, 0.052000435685077985, 0.02433528661757948, 0.03907309266768637, 0.06321510104762931, 0.08177408663135383, 0.05011370285384117, 0.05957163284502684, 0.05239013695128022, 0.0312658638182667, 0.052921522348638506, 0.05128935287376085, 0.024330580922504588, 0.021785292098478928, 0.10562592005777745, 0.04036644060585288, 0.051577279359222426, 0.057532371908065774, 0.03320698506168781, 0.05149311693986097, 0.038843461642822916, 0.04334661456185483, 0.026288188378056212, 0.02548395119036638, 0.06574198843971377, 0.04902684625478522, 0.06565771110716366, 0.02798123694505663, 0.012352400733488462, 0.039394872578521895, 0.10635533535312261, 0.009897671162991995, 0.044305362107772986, 0.029805778758600358, 0.025417563926068046, 0.1149786125508047, 0.013615320616912459, 0.024796222569420937, 0.06605380920753365, 0.07799271494150162, 0.07084111562900006, 0.01969198940411931, 0.032312791914709156, 0.03290550265040609, 0.055560450099648974, 0.029767292416504318, 0.033918692234663234, 0.04160915779310369, 0.02081218040398052, 0.06729789769216891, 0.06448054806359353, 0.13822861496479283, 0.13404297101641857, 0.10618224544751068, 0.22676081516810004, 0.2600897614273333, 0.17246454803934022, 0.09726704278540227, 0.11006798895616686, 0.2554858334723019, 0.14840695105733412, 0.13731243509438731, 0.15186819758626724, 0.095437356691447, 0.12524575355552858, 0.21067713627651816, 0.15909973051278822, 0.12996802677310285, 0.16569974651980787, 0.10842554241178498, 0.1576140868447481, 0.10997608138789093, 0.15798962314523038, 0.2854325934763878, 0.14963929541409016, 0.1526048064472214, 0.1831326594636325, 0.11449220800592054, 0.09863917520570178, 0.13439488116531603, 0.14866784996082708, 0.21789500219447, 0.16532195792082818, 0.1638133622585766, 0.10385088667634035, 0.1060406264338282, 0.11585468771837412, 0.26983758674994596, 0.13079178579632314, 0.10970340771300179, 0.11573047422233129, 0.18204620889117643, 0.24823193077839192, 0.11895072481204426, 0.11056867337995961, 0.15420093531570128, 0.19899866213240933, 0.22159983403980735, 0.13142279709779447, 0.15905990926248414, 0.13084887466844053, 0.179821933890062, 0.15771096632365258, 0.13233680127849504, 0.17476276584690617, 0.1789396151059097, 0.12152853406845562, 0.14293748164369216, 0.10464063905660184, 0.15088633333723392, 0.06811594169947409, 0.08668743749900211, 0.13172685739494142, 0.1216544023144149, 0.14098342117522994, 0.11393302510822974, 0.11654470311177355, 0.19281480040761734, 0.10895579782945496, 0.2881532781306775, 0.12203470368178622, 0.126423682687023, 0.12810574363796942, 0.19318086786135552, 0.19747250773493322, 0.1346845083659695, 0.1615272026749388, 0.0983687308466723, 0.13413081065781657, 0.08365736823649177, 0.23406267496606997, 0.10945328000572421, 0.13403725600050342, 0.12895809306252387, 0.1446403418817828, 0.14642338088202864, 0.11052309880934416, 0.199681491621079, 0.092752693491357, 0.1383932625814792, 0.08548838732343528, 0.14364946843875995, 0.1485506844736876, 0.11297930692953449, 0.11996368456992412, 0.19343789035995163, 0.1113887245376264, 0.1663540775376943, 0.1869137630227112, 0.14411621516750706, 0.11465602824764867, 0.1736097728773471, 0.12019652167275069, 0.11709492278075027, 0.16786114102409733, 0.1003315247174713, 0.10292513070688133, 0.1681934699656502, 0.14476309981076949, 0.09895973703673772, 0.11377109710367457, 0.15902876012748288, 0.08911506287873754, 0.21088699840249556, 0.11389347964957838, 0.17781142806333883, 0.10887417882200211, 0.23528233290679995, 0.09552523463724122, 0.22028694319869244, 0.12424547255279557, 0.22220659099759596, 0.21005758565039406, 0.0820571791020132, 0.09145154677812131, 0.3267672045096275, 0.08809752957594973, 0.1298029195036619, 0.09847214505557092, 0.2146856300532818, 0.2986582741141319, 0.22453385885925065, 0.21037140590769632, 0.10821306026510655, 0.10614654575023921, 0.10836984015881054, 0.15810482744728366, 0.13602009073140162, 0.17875992152239048, 0.19455676177336326, 0.14535062796165868, 0.14076284914007112, 0.1576826363922127, 0.22979231701502878, 0.1341817555047812, 0.1590546079340481, 0.08737405912289697, 0.09031210590394274, 0.14091425875742591, 0.227643501674456, 0.19103163883330362, 0.156906129672162, 0.1338100956091958, 0.13816345152595352, 0.08006703589231738, 0.11731771647088951, 0.16340086987662703, 0.07555762786538371, 0.1493575282755398, 0.24433206826929124, 0.14285154190034638, 0.1589351595048943, 0.10927129581931139, 0.10617490632519608, 0.09030653644473323, 0.13918009616674917, 0.18415918663865138, 0.09463533158263854, 0.16845236171878156, 0.07929397656792596, 0.14672256885997711, 0.13293378295436983, 0.07505356499384488, 0.10876867319307021, 0.16219622725921293, 0.17591897638574724], [0.08182826436935894, 0.029360888518332958, 0.04030822941492643, 0.04619091899404603, 0.012807621669414784, 0.12884187752441054, 0.010755342025790485, 0.07078366669555826, 0.03268940073828543, 0.013458675746205113, 0.03489431669755328, 0.03278946331251533, 0.041723370011295044, 0.04613859901925729, 0.056264634289207964, 0.07936706135590231, 0.027938682676082658, 0.03527995003687759, 0.0752418311012368, 0.04024915254464553, 0.03864799047850313, 0.044137470108727296, 0.013247208666026354, 0.09963933363436692, 0.028173729942570773, 0.0403701139974498, 0.016882120624124523, 0.03317809588606319, 0.02234846439903542, 0.011231012721245569, 0.047146211483425675, 0.055823494049329916, 0.01565398113246286, 0.0690972850087189, 0.03979790760504623, 0.039105892722164436, 0.02994287785352959, 0.03746005240827799, 0.040295711538243684, 0.008982007444325474, 0.08116277911129498, 0.012583013308504898, 0.0671594426216137, 0.024596591547672308, 0.03989492114933749, 0.036768661887054487, 0.06001633922419241, 0.03138612430062025, 0.03146030267910852, 0.0044330386369819605, 0.056140229271184054, 0.04833159848086296, 0.05066473457601763, 0.08025769219403306, 0.05805952466964241, 0.08482970492613894, 0.035503157414495945, 0.03902517386802262, 0.037053485716422724, 0.010179736118222918, 0.04898604441193804, 0.041468944550762256, 0.054128474721144286, 0.03853672386838063, 0.016739678065923434, 0.07508087602834548, 0.04173900203538999, 0.005848914198952938, 0.049738342753581466, 0.025758160871543714, 0.030229900355240515, 0.01841442096197317, 0.022223297123526855, 0.03168281100149597, 0.03477325565331886, 0.022658710856170907, 0.03207023698656309, 0.010238158940938453, 0.052864969738068125, 0.015633020009244644, 0.06547702160934288, 0.03496290837985373, 0.051521374092948054, 0.031244857687382933, 0.010171277549928956, 0.01992641996982838, 0.046355363597432454, 0.011477890300504383, 0.06960510171108669, 0.07229042374679158, 0.061644015593394164, 0.07759385126372499, 0.048269304041300094, 0.023126135572731014, 0.07257449680999403, 0.016348549960962227, 0.06145725484877344, 0.040384210015256564, 0.032082705067530755, 0.03522166223715871, 0.029704229973797357, 0.018527539589652614, 0.06448898269163986, 0.013894453370613197, 0.03577099707458289, 0.01621783046322244, 0.056557659089805624, 0.011328935037337003, 0.011853991590830828, 0.025829108274211327, 0.013453354307961081, 0.03983948702713655, 0.006807719680270361, 0.022315917153572364, 0.03207033466277344, 0.0756546299183561, 0.019588395164558486, 0.07784284516087464, 0.013175059462927524, 0.055965875320497065, 0.08071233473357656, 0.02046247467308516, 0.02886358828794572, 0.07595256151210877, 0.051652175945139704, 0.03224567112122332, 0.014216016861610116, 0.05646842899882505, 0.05917692519423943, 0.042834833354478886, 0.028276544687668645, 0.03195897612210003, 0.028316505749018926, 0.05891385443148114, 0.03447364632701201, 0.02342187232458063, 0.08656759070412767, 0.024907891375703678, 0.05746337802960508, 0.031933214500426285, 0.1095511400771718, 0.06365040752796397, 0.02145070511276924, 0.041825175435552676, 0.0029231875481444502, 0.02981444512824378, 0.06983852104073571, 0.04025471817341544, 0.006357807733659303, 0.02673823247483421, 0.055453584664651466, 0.02785354732505737, 0.05244508460764924, 0.07472467578707204, 0.06450222835185067, 0.017429383193713524, 0.0476763328357089, 0.02621752251270077, 0.05670830261923614, 0.009962620097212493, 0.06055093452995343, 0.058778697369439956, 0.013352167499702305, 0.021081102163260503, 0.013626341749313138, 0.11133891350078969, 0.0893597130573565, 0.03355536354525435, 0.011121179653151382, 0.03994802253380899, 0.022929116910804185, 0.022309007040495356, 0.04231287849946849, 0.0435236115158806, 0.011663022150676097, 0.08185565967353121, 0.004811845175291022, 0.017925564935731313, 0.06088902828313651, 0.0314145710604686, 0.033621457780921654, 0.07290263525060109, 0.027984058063837792, 0.016169712480698383, 0.01958782634427471, 0.017170956838996183, 0.07496869011271386, 0.04452776509307085, 0.017772577177252502, 0.014293909808921238, 0.05270864183623945, 0.03275071458530522, 0.07380021450620505, 0.008848481191953105, 0.016535988693395932, 0.049963867547170776, 0.02417221905723695, 0.05461544234065279, 0.07038687911605643, 0.03902867105939696, 0.035884240191550024, 0.08877120431392424, 0.013764996002728661, 0.02444448479030642, 0.013618427103445416, 0.024560330690996304, 0.02856807753203377, 0.03237530468933044, 0.0242373920721753, 0.040514038935784376, 0.03865224226648289, 0.05575956018160909, 0.04512850826065387, 0.033311724602695436, 0.040068646907926574, 0.036961972683427796, 0.029310225208680478, 0.04615927956277325, 0.06500375547236012, 0.012237375504487466, 0.04793954149429356, 0.0364771539405469, 0.012795062615506112, 0.059664961506402305, 0.061107221615290454, 0.10669101975978383, 0.02721980108969635, 0.05541339952258333, 0.07096129950256118, 0.034121249712282614, 0.037677697987566074, 0.0686581940540383, 0.05214103197138156, 0.01618535599611219, 0.027628602843070706, 0.01488297875414813, 0.11564359219083864, 0.026328482687653556, 0.04988086575101461, 0.05276754633673737, 0.047744625743718884, 0.02604194665177455, 0.062078854760095004, 0.03938350766416519, 0.03709507279939229, 0.02974017290398479, 0.03559988750625522, 0.009203778407085807, 0.052841106099226785, 0.023398096785850586, 0.03377166847067495, 0.03764206723820779, 0.05352797670169704, 0.09209339822372122, 0.026350220432505015, 0.011687057201690491, 0.03965177250305011, 0.03957929292453393, 0.022799245855440537, 0.08507527441026703, 0.010356562617685526, 0.038752504023573095, 0.03565172867609128, 0.022125703267632954, 0.023386218592584617, 0.051360786742260384, 0.03531189973375971, 0.053165153630318186, 0.009890943953406908, 0.03644192921778849, 0.05578378005133522, 0.07270705300353228, 0.06653006308742108, 0.015172356018616308, 0.015253310444794837, 0.06764723378564082, 0.043674795137297724, 0.052546824914433306, 0.05557462272624816, 0.04763876388390218, 0.030083236652576638, 0.09022507065486524, 0.013070439623158066, 0.05962581058303195, 0.07197558459255003, 0.03425440728484142, 0.02729731961153448, 0.032579788878079385, 0.026473658264524517, 0.06257246819234664, 0.033701494816810854, 0.10927921716844845, 0.07248225982391066, 0.044725465573250286, 0.07486634076602998, 0.06749674347379515, 0.027202213626174677, 0.001010563937597908, 0.05177749643823312, 0.029313245510321953, 0.04581268989450989, 0.0005261875506426629, 0.02030810604112283, 0.05005721153030473, 0.018299364131845294, 0.06206157947740248, 0.056714320239881356, 0.0511310063302517, 0.017665512559394685, 0.07621388942483934, 0.04508132490539744, 0.006257634555485341, 0.04966849851752481, 0.021148458528783054, 0.04216858583893027, 0.025410996637337153, 0.04416586515764075, 0.019035476950868484, 0.09464555119554843, 0.02044461907878999, 0.05023359178355144, 0.0721832940114602, 0.07836979873959096, 0.019373645397624182, 0.020389060467301358, 0.059613032236454956, 0.05131761385728756, 0.07030968809680593, 0.01698685441947272, 0.03436438303681151, 0.04520091889125686, 0.05049046489500231, 0.04411915677689737, 0.025827465015613747, 0.044241799792695435, 0.0221300067665476, 0.08729459282251135, 0.04153329976684144, 0.03214383888388834, 0.06339422389564496, 0.0255778256893879, 0.09008668453222321, 0.02287472275296046, 0.022583613172173504, 0.043767304084594214, 0.023685843240649953, 0.04587318019701108, 0.028188025143237847, 0.010285586486720752, 0.031047245307314782, 0.027668284282328624, 0.06584673564160062, 0.22864649462844097, 0.08426694439784174, 0.15092027103227956, 0.2697851556924082, 0.0895858622126041, 0.32403472210130385, 0.09735006373375656, 0.26991882271343665, 0.21183769819476914, 0.08968375292756865, 0.06996127130884318, 0.15037985728873363, 0.1631979638290021, 0.10010606504135555, 0.1147544322415225, 0.1598172791061863, 0.1125033135195413, 0.10326507456240155, 0.16556828583200134, 0.12761404542552848, 0.2589214773428056, 0.24593123084595128, 0.17127904229827468, 0.20079990338173606, 0.1121805530161627, 0.13987616365475042, 0.07139580925145457, 0.14422643989805253, 0.07411312311887741, 0.06578121214143692, 0.141971429449416, 0.14733975993529444, 0.10940243475018971, 0.1430501884991123, 0.08306892844097269, 0.12781950254594127, 0.11554381689958035, 0.14507138891325844, 0.1524954703786681, 0.07342825583632916, 0.12208698152173912, 0.1224929391736946, 0.13727172518209105, 0.1420334978930412, 0.14350305371467145, 0.181243333424772, 0.1320292476204134, 0.16574840842475816, 0.14818032692757346, 0.18106134157747994, 0.14158335995049248, 0.1403990339848303, 0.17789133103384128, 0.19379582195993394, 0.27014062048927434, 0.21158819867958947, 0.1794852842126162, 0.11224421492267041, 0.05354769963530764, 0.07137399872825032, 0.19699811544870177, 0.09887634070530053, 0.1694467591662561, 0.08661253708264521, 0.11463877594759388, 0.11165454938647248, 0.16673813273589458, 0.1539379373312958, 0.10239542687251683, 0.1732788535375749, 0.07354222673682437, 0.11494574737885307, 0.13698091820603417, 0.18894798693157014, 0.10589158402815943, 0.14527398852571366, 0.196116823222368, 0.21065965415008608, 0.14838637393568793, 0.1257519614732554, 0.15165516385628333, 0.12624140738719894, 0.1477518539515234, 0.23829762433325094, 0.12953875706561152, 0.2130393837127955, 0.13334036113754397, 0.0684456812638429, 0.13057216371019043, 0.16494501201856523, 0.12334489789340766, 0.16640313780836521, 0.10163714538418478, 0.15984465908860007, 0.20652103267850416, 0.18970808404828274, 0.09110638586383674, 0.21163057866356066, 0.10084231384098531, 0.16489740731495042, 0.149490934826674, 0.19462649109623126, 0.16206706483517924, 0.12189657036815921, 0.1483390143802089, 0.12687398916891507, 0.1630890261261694, 0.11476266002582927, 0.17912434954797068, 0.10952439594773516, 0.14191573485732079, 0.10244520726583659, 0.10475722997779809, 0.21007551210782222, 0.0918358701070951, 0.16263467470003715, 0.2501410984944913, 0.22517361888481727, 0.13629421231246766, 0.15068243137530743, 0.13796973853341996, 0.10389132845786311, 0.12513689246148835, 0.10239852952861017, 0.14390063802561454, 0.08310400760702549, 0.1347604583227827, 0.14752991827985934, 0.14962107784325077, 0.1742952377084763, 0.18565074450546698, 0.11711627365119996, 0.1161548562888657, 0.17370596287711976, 0.18700508070328545, 0.09392317624822741, 0.1258086979449276, 0.1149567407405665, 0.13242666339201312, 0.14243031611606, 0.16068111984960495, 0.15533517445287398, 0.12017565343769328, 0.11900989744331568, 0.15460228877923182, 0.10675420669177849, 0.2663258703485612, 0.09976609054231837, 0.12836317982404463, 0.12450990312161947, 0.1730057738360859, 0.19798949450975467, 0.15219332530133187, 0.11083565502157135, 0.16534639612561272, 0.16210426606478232, 0.13395900777991743, 0.12467353184136654, 0.15987655898976713, 0.12823453833979945, 0.13772704187900792, 0.12744726808441262, 0.10124599621180566, 0.12253140444837271, 0.0684729922983435, 0.19340324786401566, 0.1179408600493785, 0.12716822821887272, 0.14934905534309728, 0.12803576916696566, 0.08643749365282637, 0.18946819127567355, 0.13289756231730984, 0.10327185444053143, 0.16364600269063828, 0.12727309033394824], [0.054569316186731866, 0.04091559924305447, 0.023773799710456404, 0.028630255143188184, 0.034096313550347285, 0.027143184636389057, 0.022922088054098913, 0.04524115765947969, 0.06285956730284999, 0.06934165939568512, 0.043513690677261165, 0.057704592303883646, 0.040954256039713664, 0.04796976749334605, 0.03344993069467526, 0.044027249208621444, 0.01275186195984603, 0.010817326199744019, 0.014693757909680567, 0.022137219484354702, 0.05404081894084812, 0.004294533770711672, 0.07016042352563913, 0.043168717454518044, 0.06700552789674652, 0.05080988525503105, 0.05252097327742846, 0.017187941008277478, 0.08010267430255491, 0.08237221743911505, 0.06469727433737248, 0.0501685279361423, 0.11514188120922736, 0.05162335571742827, 0.00035327740636515256, 0.06163682585822479, 0.04729136216243909, 0.03892787304075976, 0.026217388447314024, 0.02360124989683109, 0.022088565240283648, 0.03942297651402412, 0.02634968800139764, 0.0326416083431292, 0.1077054121020821, 0.042070756410999645, 0.06702574495706828, 0.09487587552998336, 0.008160295791082807, 0.02305941506018562, 0.049705784016799544, 0.030576348297237873, 0.050262519263572274, 0.03423562280893807, 0.01652875107773129, 0.061656809261729645, 0.033181374742379116, 0.014527035152329313, 0.03610695344245723, 0.023650168441236023, 0.043638241251990686, 0.07833421395550813, 0.04544579123537387, 0.08208707951369786, 0.056559677731486104, 0.016081675571659883, 0.04094648790816146, 0.04731228785409082, 0.02014230546211043, 0.04120731020286199, 0.03527393241623237, 0.01809176962612377, 0.020282555093628266, 0.00598596110414233, 0.061614505886550874, 0.0011487326827914184, 0.023290900017825827, 0.018903600660363035, 0.010917491238233785, 0.028076720228719137, 0.007383672721428617, 0.013980734023085285, 0.041958428769102024, 0.04738090634946862, 0.02784188555163001, 0.046438173871607556, 0.02805921895008895, 0.02861828884981092, 0.03198984563500891, 0.008632013472848603, 0.07028883518350702, 0.05028872713146191, 0.08265625219792128, 0.05763982723076498, 0.04023387675143538, 0.01053545180888426, 0.04305112678858061, 0.08068107834626591, 0.01751581514855066, 0.024363405874840195, 0.05472547171877758, 0.020715482870958025, 0.028956281096344034, 0.020271224653228156, 0.031040712492540482, 0.07858745197975829, 0.08460996026593832, 0.00920743168887472, 0.038690033383787646, 0.028557800462529547, 0.06297897359716796, 0.007907225827371042, 0.015291622501888103, 0.01969679277540455, 0.025637685884571364, 0.027538171909268827, 0.0220868204750361, 0.020998263160788247, 0.11515006302825867, 0.037834343815883326, 0.006632446902879184, 0.0344682224245081, 0.04858649125502956, 0.018842455352686586, 0.04510949395837323, 0.06603490981844164, 0.05900157532925087, 0.01754857306819289, 0.05766553331106421, 0.015412132920426948, 0.0648302212357521, 0.036347183293753096, 0.025332759908070008, 0.042955465389475714, 0.058965684109998334, 0.036319064036492384, 0.033567153638409036, 0.03458831053707869, 0.013249784636671745, 0.02185030998061261, 0.09276294374778386, 0.028610920999199155, 0.013359504706797101, 0.06143734039318177, 0.09129207791580309, 0.034104836278504906, 0.07125742312881254, 0.04883723566308618, 0.04471660576640599, 0.03817612628242181, 0.036539226214611725, 0.058089007563408346, 0.025582891445787206, 0.13382809867541637, 0.04344046416301881, 0.03445866930809233, 0.009049192397674967, 0.046920169580487475, 0.05184423801819644, 0.009343715857774501, 0.008518367202111311, 0.046542675925358656, 0.04300503510861628, 0.06797304331895805, 0.08854998876490901, 0.05971177713945509, 0.01928426783471819, 0.05183186186777969, 0.030574942525896816, 0.04441200154683283, 0.045224238607671954, 0.025990932856896715, 0.024177210120063637, 0.06676011929108251, 0.03924998619984235, 0.04289755297283973, 0.03350600066985335, 0.049729927277733246, 0.0813465329608129, 0.030773571887684446, 0.039901505675046675, 0.02779310298783164, 0.06132187945167385, 0.025337528805398656, 0.04119519069189987, 0.0707461973351817, 0.07153355952111945, 0.01538636268026406, 0.0604619802306256, 0.022288947028198072, 0.008525119309553937, 0.06175185779049512, 0.041522750736124096, 0.021896788534978708, 0.10784755971643234, 0.015814319504575146, 0.04911576224971683, 0.04363123537792314, 0.022984325037067457, 0.00945383237840067, 0.015318072645083792, 0.06114082989252864, 0.022845341365844495, 0.033035503940716866, 0.061159254307107586, 0.03879984825729363, 0.053642656233522205, 0.01906501155556931, 0.07124301301495684, 0.018990277763335936, 0.007664500444661827, 0.04570886965901141, 0.009066666863227804, 0.029107937777054407, 0.013958056862916679, 0.018411783704293833, 0.041675539311742595, 0.04236969157993313, 0.055431322149571874, 0.0579315918167272, 0.16171536919090057, 0.036464628402984915, 0.09081989962367282, 0.030641913932237416, 0.06025916228311197, 0.05209649161946389, 0.009819648938343651, 0.08228878280328167, 0.010472691013297487, 0.06621120197157707, 0.01650162773477214, 0.025976400168973113, 0.014517612270860663, 0.03289871894183659, 0.029167832446194468, 0.06314135742403808, 0.04018254119962935, 0.0077290481403319835, 0.01717144138960829, 0.011900027729420653, 0.02808066175108956, 0.027354772375415892, 0.02003046237082491, 0.021686399723553372, 0.04674279724337882, 0.024060264883202412, 0.028726169351308097, 0.03448185112868105, 0.035777248352045016, 0.05206460704005534, 0.013148706038332274, 0.034651658347537445, 0.06018678995690519, 0.029967113045014204, 0.04693755594592902, 0.03340948891315249, 0.027039984932109237, 0.01972071961649964, 0.03018357118801965, 0.014087266209835728, 0.02597092838597394, 0.04917001276607475, 0.08164460245039194, 0.041002121213222706, 0.06248749371978545, 0.021188668568708727, 0.057728417638328776, 0.018327958363619064, 0.046981590679816665, 0.07904115989203415, 0.041668357237452464, 0.13342309863336627, 0.01107152662194905, 0.10747671187404664, 0.04030241097714152, 0.030543509938363588, 0.025604384042502894, 0.04975716170344142, 0.06288987374113453, 0.02646564115439692, 0.0675212353047344, 0.07588781942162784, 0.07940687494532717, 0.014544283621944489, 0.03823664339800035, 0.041555163916200406, 0.007639636103469398, 0.029803424953453006, 0.08613373979084915, 0.005531948671916561, 0.04027628354848393, 0.030941086588427428, 0.03494197119688315, 0.04670830030414847, 0.0969641546027795, 0.036259990996651115, 0.016944349946213827, 0.04231353350464375, 0.07942843265951642, 0.024020152519487088, 0.03962443082503254, 0.08645909733229107, 0.04109284900609524, 0.04716771174102061, 0.08525072386668575, 0.09535579897102811, 0.08011884641863647, 0.07098993586917078, 0.023181359020752773, 0.02585260036040939, 0.012301470250672391, 0.04254717116935119, 0.053054810156144445, 0.08421066757892409, 0.040693855093371485, 0.021169794077474265, 0.012871528724058261, 0.040371600208022905, 0.012361155203243178, 0.0922934850677848, 0.09633899621304967, 0.032559035556210626, 0.014022543271552893, 0.10285937738034034, 0.07862624667224385, 0.005021679530581159, 0.06724071688950062, 0.0725977935437714, 0.023634961595939055, 0.041363952200739615, 0.041815040092314446, 0.07384725996563513, 0.0289097776441204, 0.04496168495426255, 0.058520747904455474, 0.011505540328911476, 0.02310249218416791, 0.07814246214806073, 0.0298534466644689, 0.03110628770363908, 0.048301732543134884, 0.05794661097048272, 0.04342840593909064, 0.10524694402251514, 0.031817075571105365, 0.04593111942672441, 0.031869924146561854, 0.012370199828799213, 0.030059949494898323, 0.13457474328817862, 0.06437760882920797, 0.05590444656028863, 0.1928807452561394, 0.1761708201299752, 0.13358069824114924, 0.09916010733333327, 0.14404673099277482, 0.1811470668162069, 0.12506398387373457, 0.08352177067389412, 0.23053156121844248, 0.2587026826316311, 0.17541941045032394, 0.17061927205612584, 0.08238732469298186, 0.10899640048944181, 0.08966013443686309, 0.1678392462312214, 0.14110294621317618, 0.08813168177561415, 0.16804327076721579, 0.13820747093808267, 0.08451184738547572, 0.15848056293062626, 0.09601737718067824, 0.10610567495947885, 0.13001898694182598, 0.1125965923852017, 0.14717387125617074, 0.09188721331978038, 0.1394644220389666, 0.16815697353693748, 0.13590977407030522, 0.09671779604808939, 0.2504888258033222, 0.1469529927858422, 0.08798103824618363, 0.11364464663089284, 0.1156635411203869, 0.29180855940907235, 0.08028657370877844, 0.09834877425624479, 0.12448093733720242, 0.08457776925136005, 0.18295270541021902, 0.1356960202176725, 0.2706994050212445, 0.08083483985354824, 0.17181335798194333, 0.17121957855359202, 0.16067450084993917, 0.13333248575368237, 0.15009854980293783, 0.14232487177416203, 0.24484537782207613, 0.12674344778661767, 0.191937844238935, 0.1331763417129555, 0.16259877581990537, 0.11951170801635712, 0.13514707225465006, 0.16806988466170528, 0.0872259283618581, 0.1819248758857289, 0.10256834823878543, 0.10255765365136248, 0.1767607691187051, 0.17474614173894928, 0.09262062759409029, 0.21219863285941465, 0.13925829842205972, 0.12829664508782088, 0.08018683672191636, 0.16841134537131558, 0.13005626478022145, 0.07541703540951976, 0.11872653684188282, 0.19949105748486137, 0.19741607769843073, 0.10163189768190346, 0.1164860284376529, 0.12544577911255822, 0.14648361071463556, 0.06721546663151634, 0.19599377417997008, 0.10103421886601757, 0.10725767967561561, 0.09059280818027836, 0.13037788381259288, 0.1940903521233028, 0.11193505247994778, 0.2445155769706734, 0.15474078215418324, 0.17836437500532598, 0.11323714914220957, 0.16225590550851438, 0.0916821698868467, 0.15085933639878227, 0.0968806816625499, 0.2342802745800826, 0.1534683101119534, 0.07128425918880009, 0.1839171641416127, 0.118573296274389, 0.09705954787111092, 0.10471016919660954, 0.0769688614133385, 0.13178514136422065, 0.17982669895695103, 0.13318015683081844, 0.18632815009163273, 0.12322439226291834, 0.14356181265846377, 0.10343025077975566, 0.1879708264623919, 0.17514107538567436, 0.2372353974609606, 0.18635623487493685, 0.15775323905531438, 0.18750369668968264, 0.26322440935238717, 0.13398427335966018, 0.17340495160991148, 0.11297199078985762, 0.14121715460092793, 0.12600721430874642, 0.1356765156191203, 0.1348160150190515, 0.1667262890165852, 0.07809864191879189, 0.23120202604801426, 0.13724812967402322, 0.11622428683744324, 0.16140098202853434, 0.1123939085030748, 0.17506926230365233, 0.09287356684404997, 0.2974683863501395, 0.16914344963527497, 0.1481191777894574, 0.19247516298726683, 0.11365522630512716, 0.17668906328899248, 0.20742638006566033, 0.11673238699234302, 0.2027147554702336, 0.20679910727325948, 0.08508846644432315, 0.08405374978939373, 0.1368589723302472, 0.16509076790703883, 0.1634400476130747, 0.15580038900577253, 0.13549899772530602, 0.2291926693531775, 0.3153712789137518, 0.12936381322722282, 0.15565444925619712, 0.11167030015419568, 0.12240158318872414, 0.08146835626253197, 0.12319117469052154, 0.12187351112163837, 0.21210164612820073, 0.13411473813316516, 0.15242197190321263, 0.200857451906608, 0.2655219989678552, 0.18087688292707169, 0.24065308423051912, 0.11587239201030425, 0.16039801971806636, 0.17072946614315435, 0.11659971588561613, 0.09275631708723885, 0.1645570650937096, 0.12473544706740688, 0.16684111027467638], [0.10763187532223041, 0.02059151260783115, 0.020149700125799547, 0.010495429460500038, 0.04428830516013888, 0.020571806911198844, 0.024365014659481186, 0.02511480214795278, 0.023162586036168283, 0.04082780173649231, 0.0347335301640053, 0.02441544622753657, 0.08170511573553085, 0.05891439069302813, 0.03779989284192843, 0.015959913556974743, 0.02935557186813845, 0.08109000841936759, 0.034459569461403355, 0.02518556760473838, 0.044795102965567386, 0.037453326156302806, 0.018283573144506064, 0.09424228251220719, 0.06905111288952251, 0.012252534469289166, 0.07426886113300439, 0.09239195034869256, 0.014368721167556943, 0.018501134454122475, 0.015813891452947454, 0.016446138071196697, 0.06294829560624016, 0.08829016238451005, 0.09365243311490744, 0.08038943633437157, 0.03578750243891151, 0.037490243933373885, 0.03768787163520052, 0.025873889943825144, 0.11186101774294531, 0.05842110667858393, 0.06462123245000839, 0.027466211355321353, 0.062094674475731394, 0.004279042036467863, 0.07622894305255144, 0.031797969338273814, 0.04775945337549333, 0.11731384006599266, 0.01930942233171194, 0.02796864629002108, 0.019097528157515392, 0.058543443259212284, 0.07365183093615117, 0.02324444061565784, 0.026110379370830716, 0.024560344097534978, 0.014987377386029451, 0.0317789952556092, 0.051907777350636265, 0.03617112479743458, 0.08987840054736984, 0.09253559183449515, 0.020943723446238908, 0.09772791361977017, 0.02967140310624194, 0.017500514457482966, 0.060321157948384364, 0.020779968321984334, 0.002682547839809089, 0.02627542343801789, 0.0187987347148479, 0.01140452876326538, 0.05438432893565586, 0.015849464745711417, 0.007505927905215011, 0.0396525768953706, 0.04528881215880956, 0.001769839185609242, 0.08872042034542368, 0.016227050331391154, 0.039876286060579365, 0.040679571384023276, 0.011802060405663665, 0.04625701322971333, 0.06012456446525551, 0.035308345085791046, 0.07970953330157265, 0.10810098926266355, 0.03277934329103559, 0.03883197415439833, 0.029653737118708032, 0.022995414159771417, 0.035369831302593795, 0.016627764111504923, 0.03247904448559688, 0.016730994459301714, 0.06812161841099301, 0.03201742671550282, 0.013245741607651356, 0.06254835940536953, 0.06374401198099218, 0.009832644662369164, 0.039854598111442985, 0.02040847696574225, 0.05544108210972721, 0.07890583046021, 0.03563398991020457, 0.03630545065407792, 0.07838804695394733, 0.06011252539352544, 0.0317772600664607, 0.031222221704440254, 0.04319899324928561, 0.048932487205151594, 0.031182245321331487, 0.010558700662166362, 0.06936572987826602, 0.0216311379711354, 0.03234293364408997, 0.08917795103644172, 0.06396374514987392, 0.05069230991085211, 0.046966483425949855, 0.13703308879367768, 0.05171191548147509, 0.056808798033143246, 0.0027582531272914382, 0.010824609780684115, 0.01316708736046548, 0.07488868755078124, 0.045939577037408474, 0.04408668614022675, 0.03524513517115866, 0.010677909688843835, 0.03308013622318545, 0.049546954837898095, 0.017725991370577007, 0.04641907146921562, 0.008734096603978787, 0.012797018054932838, 0.05894623696804047, 0.034641917539580215, 0.048350666409298304, 0.07477018907065354, 0.015247740027975413, 0.05172071783172508, 0.05156396858153805, 0.007213028072709999, 0.01278999398627709, 0.028636738162247405, 0.01928912291693832, 0.009939014055435697, 0.007365558572459005, 0.04140566185777707, 0.03711897474262984, 0.026513644223732334, 0.018842771363955353, 0.046522581439104774, 0.024865469256896647, 0.07768970418481097, 0.01582665352015606, 0.02039239869543141, 0.05597810208376858, 0.06503054556707222, 0.04855253057734621, 0.02442517171373531, 0.04987195997889485, 0.00985019956715405, 0.031095487779126536, 0.011402196025535946, 0.007530008921504862, 0.03245305878320529, 0.07603475508550483, 0.05200749135486061, 0.0497394229375547, 0.06901014250733199, 0.027750596599352938, 0.0631630338818556, 0.04116401474382128, 0.003797666380001653, 0.020008320514593395, 0.016494415016965042, 0.030402967278214715, 0.009140508163029389, 0.017357930173015883, 0.021698046175222245, 0.06740138084898073, 0.03416392847054428, 0.022828479770631082, 0.03808380502666678, 0.0099187012341234, 0.048469819894601265, 0.07101000737278693, 0.020615577344752608, 0.06399256920802497, 0.04568407522334207, 0.041671184101893056, 0.020829430788815505, 0.022523808518364545, 0.053429553555625106, 0.039076789041921016, 0.0637199989550056, 0.03425067643665018, 0.04121317843636198, 0.03766810656675408, 0.01340463781924618, 0.05186340553806194, 0.04075456756137071, 0.08574819838207576, 0.08041140007516069, 0.018674898517107772, 0.055104834628441644, 0.07229394775124327, 0.00973820900394311, 0.032032083892714114, 0.06936315582284043, 0.023094287382498867, 0.07057562019796142, 0.05373246855132523, 0.08912666911079038, 0.07009757367233116, 0.03628689983499147, 0.06103063197506051, 0.07303120778693308, 0.010083312461633357, 0.044675899684549346, 0.02330756051495912, 0.006313383731345136, 0.07064579385182551, 0.031370448226469665, 0.05218497477471829, 0.04226011802412329, 0.04680291599323673, 0.02562918230861185, 0.11940352874056948, 0.015806087889828752, 0.02966296273253618, 0.038179665608631994, 0.0635515477117752, 0.0423273767134355, 0.022039859285277706, 0.09997334030847396, 0.060410686813655405, 0.05434055850210209, 0.014617504390527405, 0.023726606779100917, 0.077336706191061, 0.05003348195685014, 0.08966146742985134, 0.04301153153421418, 0.026657618957781987, 0.007156400768566998, 0.03147677739992017, 0.018269475211479494, 0.05776774476192171, 0.00892671121795091, 0.05042420211999167, 0.015934670959869703, 0.004362064900041949, 0.04170822828347164, 0.021222376437377066, 0.026738389522858688, 0.06039497435032841, 0.04900317413792495, 0.03750623984923286, 0.029458038043230775, 0.09398355163753995, 0.054321770195759116, 0.04776961936224853, 0.04656912511094444, 0.005334981242119665, 0.04139243534976437, 0.06426687081975323, 0.015442834851602394, 0.03436128804159742, 0.05202077148902801, 0.12859571815258072, 0.03773978941382901, 0.011335073316830301, 0.02597751674212275, 0.03101957421148977, 0.08553971521436207, 0.03868249890905234, 0.034475289585609595, 0.03459722013963807, 0.032497625948200305, 0.023675056722676082, 0.11782257607386959, 0.06836593151092529, 0.016578303559893565, 0.07220970106221015, 0.017710374668240547, 0.009947651696781959, 0.04119735105984634, 0.035105427546847257, 0.05638529313728214, 0.0707114246042986, 0.09156241502252319, 0.055889013719054005, 0.07530448943256371, 0.011363430061347542, 0.021362859725711808, 0.05095188348223606, 0.01618589800331862, 0.04389671931764291, 0.03151904630114234, 0.06633232047240581, 0.08225571844846973, 0.05182603959955516, 0.0687076603513091, 0.01183761933427905, 0.03406357095246354, 0.05842675274658588, 0.04700711672945369, 0.012085458353882837, 0.05285969139226983, 0.019675957099083933, 0.03111612235736703, 0.060598340050707904, 0.058000915112995335, 0.034598392254162225, 0.09474515028658415, 0.0484152208082378, 0.05146200993969556, 0.05577664777276017, 0.014407666204797645, 0.07009598787032789, 0.022628055847880822, 0.004385829905063034, 0.05584729640113731, 0.02689349168400851, 0.03753059761478536, 0.016939674894655907, 0.019392556278035045, 0.03431939835389776, 0.10734748050209977, 0.030591871153803605, 0.009763690045914583, 0.024619202632757447, 0.0816018930486133, 0.06788130429002547, 0.016350543704785166, 0.06224233409269683, 0.02471016982810632, 0.013927437286193093, 0.07431767625553955, 0.004482449871683193, 0.026618661471612515, 0.007742204264016643, 0.06514994037007132, 0.15074661422160365, 0.12142938696929526, 0.14541634298380346, 0.15991982763573048, 0.163159751363339, 0.16989251508587794, 0.14028972855979396, 0.08918021099581834, 0.10521335106703544, 0.1540438719694653, 0.09709291866109257, 0.08934233818323382, 0.15221656840895453, 0.16148646211912557, 0.1375268631043934, 0.12492840929377465, 0.15542462287891298, 0.12730505152214922, 0.2205469687619517, 0.16054898500442505, 0.11470243785410159, 0.1272360193392923, 0.10827715118085185, 0.23290675554064014, 0.1679608397065632, 0.1979635854161555, 0.22182362364424815, 0.3002059862257973, 0.13459129078734305, 0.12828624161380914, 0.13304235293499886, 0.09403983611733684, 0.19601925426433164, 0.11563759372239152, 0.20994198298262012, 0.1846359384756896, 0.10744910972613482, 0.16456863302136623, 0.27493501322404035, 0.10529035822518411, 0.2389776959053932, 0.15254791675796434, 0.19278478508274402, 0.21878184089737557, 0.24833921373130816, 0.14176090848782372, 0.09232545391686502, 0.11084392877115358, 0.11557600791415862, 0.16861576827303057, 0.11517161308156869, 0.29660454560672084, 0.10254859083121824, 0.08240866790255232, 0.2038641171830316, 0.1462325024148149, 0.1370249989051973, 0.13736210823539766, 0.14088822708975884, 0.09244183033344247, 0.18291991684705983, 0.09599837053927684, 0.1946435901787012, 0.24484032164177588, 0.12558693847348615, 0.18622926346236662, 0.12482877955922198, 0.17407429795111382, 0.14841072020992158, 0.11069074182981446, 0.13694281299268046, 0.18201322114515692, 0.17761408381404417, 0.16915189192420052, 0.23719540767131314, 0.12048608758637022, 0.06879603625425408, 0.142732675698015, 0.1334263621679237, 0.06869072214730325, 0.1776762288664618, 0.0677462583107333, 0.21152220786579196, 0.12959429844012185, 0.1677717385633338, 0.14839331469228192, 0.11146596152215235, 0.16882486431108368, 0.14530670048008043, 0.1993166192645027, 0.15830301439329503, 0.20763900010816513, 0.16740305108889458, 0.169780635605416, 0.2017424519984953, 0.16698096728613301, 0.12102262492501929, 0.08819758065886076, 0.17726510012101743, 0.15326730396238067, 0.08820310415279481, 0.21012788187832604, 0.23082436002310247, 0.1640577902716975, 0.11859332947360894, 0.06359166773636976, 0.08549464626177665, 0.20040706881592352, 0.1525462466862894, 0.13065670917351402, 0.1850155963292045, 0.09072740216769519, 0.158752876544191, 0.218535972638957, 0.19851138424729148, 0.07029377645061863, 0.15998194204463115, 0.11285821141134347, 0.20982673271529137, 0.12045369738893164, 0.14475493331349668, 0.20033718627547065, 0.1205922137465208, 0.17554757696005607, 0.15243219151612253, 0.2249446658477668, 0.22909667853626514, 0.11497711867935236, 0.13925492763519287, 0.11363562977602405, 0.18021138234724923, 0.22940129041671756, 0.21121417923319727, 0.22480776593569787, 0.09414164920247371, 0.1182988069711193, 0.0964998976597863, 0.1640339649372524, 0.09036668200766848, 0.12979911970755748, 0.10856592036303013, 0.11361984836478388, 0.32928058577160685, 0.08330253929260277, 0.13971960592654445, 0.1342406370226414, 0.0758707739653126, 0.17818265894968666, 0.139898962431377, 0.1257539303192208, 0.12438686940098002, 0.17325823045065328, 0.1782078325988785, 0.12740047543399757, 0.13236543764510464, 0.12892211757359967, 0.21942524750146175, 0.07456316913087523, 0.11857393212736615, 0.18024953352587839, 0.2023403989451547, 0.18837138319448118, 0.13374621919806928, 0.08754024657631114, 0.11080832100443302, 0.1636559771554124, 0.22576148411439312, 0.13108703608234085, 0.10355830237629915, 0.077661718992937, 0.10453814415321236, 0.14783918797489137, 0.12450857778951047, 0.20749056291195656, 0.1340613418048428, 0.15896097666794257], [0.016730697600231055, 0.06474267270776533, 0.02171330090101448, 0.013511474525946523, 0.02289750237738894, 0.05411898672220208, 0.02686926032296352, 0.03201197408470175, 0.052203460476331176, 0.031225358834490183, 0.06371345273369262, 0.02949397714297858, 0.07833324868472354, 0.016289218366446517, 0.049839573611895886, 0.029492408577953617, 0.064134425708964, 0.067767892633715, 0.05631340727690728, 0.023204284201886867, 0.03777181954994317, 0.006625143212131075, 0.031891671467512366, 0.05864591517996404, 0.0184206013763023, 0.06891723136387526, 0.03096712783219353, 0.02356999159430064, 0.01799826859496534, 0.03584461812410624, 0.05272851415699529, 0.07706795488634417, 0.06498349244676291, 0.04248421789417344, 0.03063793410547078, 0.06730756572177334, 0.062401121136762445, 0.021254803023992047, 0.03164501222331197, 0.033240375003867575, 0.02357729049699922, 0.031635646798437646, 0.068949973961759, 0.03257169132871974, 0.01820964949025262, 0.04381717640846487, 0.014576595295370828, 0.05624349026249782, 0.02188308513723314, 0.03521658307422073, 0.010224151023242985, 0.02468703588801286, 0.03548838723931582, 0.024275428337615826, 0.06191621812420988, 0.04555843297332045, 0.036649795684723124, 0.018030760299053886, 0.022166962848014893, 0.007110911425233128, 0.06391730106946442, 0.04584139520903269, 0.029873949092542453, 0.022436920741212465, 0.00854625663299474, 0.03955935165586491, 0.01700435952854253, 0.053311667945836826, 0.02812117248052551, 0.026131094388303258, 0.01717838023098246, 0.06871374308942788, 0.004191598366765727, 0.05237505268005114, 0.037443129526030634, 0.03140294759143745, 0.01642252341093075, 0.060233283833029776, 0.031693059342703035, 0.03368717663350605, 0.028898611912624012, 0.11788749436457312, 0.006040749318462106, 0.018777743905722614, 0.024828932608567902, 0.04160184165342681, 0.05430593898880386, 0.05790965871945505, 0.051647694330782666, 0.03878199840865789, 0.04838610563667552, 0.06872120478581037, 0.060318537927683324, 0.03478960780006263, 0.04031462624909417, 0.04281661195319988, 0.04631905102982156, 0.08760694219099899, 0.02624216181556544, 0.01297234206445395, 0.03496238360962561, 0.012747902242887407, 0.02294296969569499, 0.0677028364471851, 0.054045538042461684, 0.026968784720426606, 0.03149789652877277, 0.017245363128641923, 0.032271407845039526, 0.03630199176709979, 0.07851933144153127, 0.02601026508566593, 0.01040313022977282, 0.027260533984630343, 0.03622109671273539, 0.01441106763518145, 0.021564480660843755, 0.05037619138977701, 0.012376229898373206, 0.03754956978223017, 0.04269988313617726, 0.04516598528190967, 0.03076366254038388, 0.09008488422560115, 0.002719428748898809, 0.043355884225738626, 0.040022762071701794, 0.026561743054058284, 0.03517539435697179, 0.05149020197530908, 0.018928211234930544, 0.04349970574220342, 0.01482659564053099, 0.006507589414174999, 0.04278952308419732, 0.012605172401714711, 0.10497526626192755, 0.05119351144399374, 0.03141635987577179, 0.008160577328394978, 0.026347487413835143, 0.0614712589360293, 0.005787502675722804, 0.02231256551890364, 0.028727799203367006, 0.013635384459649364, 0.07937439281733767, 0.018130288526956594, 0.0434237634462695, 0.010916102703871026, 0.06170610318921747, 0.04195889991317545, 0.07114488481273575, 0.00766082130740547, 0.03596727646166279, 0.05818042866585236, 0.07119284957767495, 0.04667198773653758, 0.06791682012619511, 0.009138371735330551, 0.028604072173156088, 0.04237069132467432, 0.13482350735895096, 0.03646549408233935, 0.04115406326168487, 0.019124218660797325, 0.05165491470946901, 0.038797599789235866, 0.004683898437032176, 0.03238866526272989, 0.018963593005713437, 0.00668731747165082, 0.02426299090016513, 0.04580100705366462, 0.0318135017709386, 0.021114967079953324, 0.03252888616595057, 0.08730345645979529, 0.06782822971863132, 0.01687063505091975, 0.09049600531016627, 0.049111675170640794, 0.03777275417721079, 0.020853773232609518, 0.013001161334555478, 0.06452821405424226, 0.025238711124045715, 0.03401807682108014, 0.04575265158388404, 0.0764269691200987, 0.08512086430264097, 0.1064311474141094, 0.07627110853190384, 0.035643271065407225, 0.03215718796596893, 0.032166059264132095, 0.01652552967800969, 0.02027775746800246, 0.06597787457247896, 0.07543494654518944, 0.057570515425815705, 0.042391042450382825, 0.025917317553032792, 0.017167469223720894, 0.05211562083493318, 0.03781903354871658, 0.021922672730720332, 0.03848865185113203, 0.0648363959044218, 0.01803066262284354, 0.030990252196187937, 0.039231592428780375, 0.008192339333735647, 0.02790495948565583, 0.013860732095406182, 0.09588522701373986, 0.07420038053345296, 0.028522399539548545, 0.010386596137147036, 0.05252255141855248, 0.04251142167636464, 0.03863307091617777, 0.004359409447774411, 0.038049760079311754, 0.04334407114994623, 0.039253858774299585, 0.0230084759588804, 0.06506176364998664, 0.01877038180077028, 0.018162274613015113, 0.07207503046600089, 0.026823959628781004, 0.02517188335919092, 0.044061826587083845, 0.023029003284811493, 0.012834623395915956, 0.05720120358971819, 0.02228801431615026, 0.07253963980943927, 0.09076471064960764, 0.03478855825960636, 0.038329451119587306, 0.022663813001746615, 0.09223586759499966, 0.0304500165680844, 0.019521557823604634, 0.011421320452955703, 0.038625934807163094, 0.055626015734648517, 0.050058594319008054, 0.044093274496375554, 0.05671822345785557, 0.01735684998904265, 0.0481961234923332, 0.034212272449006, 0.05007578533202891, 0.022945392448755524, 0.059040320226021355, 0.028828585730685346, 0.026949061786816008, 0.01903814485206479, 0.031194579336912404, 0.03296004811061486, 0.027171589261401567, 0.02542606750202756, 0.03248197477190726, 0.0317948360386635, 0.01084389700178778, 0.050139968178325126, 0.02246015044229646, 0.06237851388211693, 0.026657532772890506, 0.08004670391880697, 0.04828894270523902, 0.024354260700244098, 0.027069532943348733, 0.048834378155128616, 0.027549557891043446, 0.09413619465645283, 0.07318051066249609, 0.013360794607339608, 0.0353625304846754, 0.010968739647538433, 0.014239041634174365, 0.04244663745104786, 0.015541062645253637, 0.05229251053664954, 0.031954816264671185, 0.014466357158286678, 0.042939051955698, 0.03619092817027723, 0.057342864738236514, 0.05483425237358578, 0.03467154215961214, 0.03981821659591891, 0.002529736999760292, 0.017500882179686622, 0.06580989447332199, 0.021132146601655313, 0.03424345988840346, 0.05974044798002128, 0.041578836033060666, 0.0865255018335677, 0.07775194116777952, 0.030292623804040977, 0.035281995491635416, 0.02958528333223395, 0.059660257726547226, 0.038531342100712566, 0.0165065958149611, 0.03289355167878732, 0.029018939427670934, 0.03288106444562155, 0.06178044819182927, 0.03810810150518533, 0.07918081772063049, 0.02037486677328425, 0.08947724626669962, 0.0865255018335677, 0.027254008830735282, 0.048252978707633676, 0.06354501298178108, 0.010321232557837522, 0.03593127415966123, 0.0314983849098245, 0.05200554549153294, 0.016658045651931918, 0.03725538435842722, 0.04592793250095941, 0.07084587303500983, 0.01034079557059393, 0.03126263284244605, 0.06835165929289595, 0.03885031046886598, 0.03130838552850389, 0.013840702726625869, 0.04354678567559008, 0.02943666419014335, 0.01980129674437546, 0.030087904043255315, 0.026480669884251493, 0.04388029056210672, 0.06024721514193281, 0.06038262501298901, 0.033824838803059636, 0.04114135769346068, 0.01077529670099818, 0.031113182494957602, 0.051935528885693326, 0.030689675683876684, 0.02522829615871512, 0.03549934995751228, 0.2487713179641193, 0.1583837447387557, 0.12923930861776875, 0.11739041821490373, 0.13238629055840354, 0.14399696592121355, 0.16328253993584266, 0.13515968206188372, 0.08060855280247428, 0.17017921583066065, 0.09491335255123916, 0.10969099708862844, 0.14036385522734734, 0.11686150345110125, 0.19202576048912542, 0.20365557272828397, 0.1802994824585415, 0.1504811341123235, 0.14045915656512784, 0.11130677611236611, 0.09801299791903266, 0.05056490182816502, 0.14840476004587067, 0.12743236767428537, 0.12281317158692306, 0.18039423221301648, 0.11590718772382506, 0.16030444973899474, 0.20702668135204624, 0.1454407965103465, 0.13294239378263875, 0.13252495247269833, 0.17197259701788428, 0.13641378331568935, 0.1398723485368875, 0.10888806799606932, 0.16904175912420596, 0.09904664971174733, 0.09082411310725635, 0.19184113329937383, 0.1470129161832794, 0.09756665211170913, 0.12354290097831719, 0.16021556821801972, 0.09728042634143945, 0.11559973365717358, 0.07167473420380585, 0.14863388162226449, 0.08721914082284897, 0.10991993480392041, 0.10607274083961403, 0.13718626041325832, 0.08370105056993424, 0.17800697966689066, 0.2217750383480903, 0.11774123285806949, 0.09986640209512365, 0.09159305087861516, 0.08149842521355999, 0.15963827500179892, 0.2554070643119274, 0.12196526547232944, 0.2457906690336043, 0.18359906911369295, 0.09143594156710372, 0.11028702881547714, 0.11950881220400335, 0.20295809563850203, 0.06682265504834152, 0.09012499658931648, 0.12359219873624465, 0.2259413462372557, 0.16100200343756907, 0.17275998218645974, 0.15036444359969708, 0.13957031071186066, 0.15386854508711448, 0.1638084286523442, 0.10287218637043431, 0.17489166780104562, 0.08686262648552658, 0.22281944601526185, 0.1237627682125857, 0.12673839926719666, 0.07087335260885377, 0.14461337558684811, 0.1446277780398246, 0.2112117890388735, 0.14718856482255846, 0.10755744221950732, 0.13918792558533533, 0.10285636665479791, 0.16537382207330198, 0.10313813379334827, 0.16101184000651683, 0.1528938973863279, 0.17506489560248392, 0.14801330443832184, 0.08974782852155548, 0.09336038507641324, 0.13226146419202128, 0.15545319795848864, 0.2632805482754784, 0.24785889192454277, 0.13224353773459313, 0.10841543771206372, 0.13024564171510358, 0.1038604704362731, 0.09852390961661454, 0.12517948695007833, 0.12594561317875502, 0.16947513506297143, 0.08253042225635822, 0.09103919995287735, 0.13124227613931702, 0.14527135318325413, 0.1376741358469571, 0.1359198098221133, 0.12319182586525718, 0.144822716773037, 0.12846345307245371, 0.13201237836432073, 0.1171785795820817, 0.11398649038446527, 0.1574833156360734, 0.09992143019072472, 0.14983366724223862, 0.162739169092909, 0.1303602025033005, 0.09511582192874725, 0.1380421951292984, 0.167804021508463, 0.12350086573391192, 0.09944511502380333, 0.13599715405894866, 0.12044157021709027, 0.13133762344237299, 0.141872956507629, 0.1078430091541621, 0.15824620131283038, 0.11650688901183107, 0.199183733653157, 0.1431348258929868, 0.09536797976902417, 0.21366150839434517, 0.2040789588805168, 0.17904017180685075, 0.1352162346724541, 0.11772491518528232, 0.1136165771693472, 0.09613654215730007, 0.0850203765496131, 0.1701468103114636, 0.1769627405390624, 0.22923691859168394, 0.15440348896288103, 0.1718848186635202, 0.12391829172209387, 0.1732488382127016, 0.1505655570015792, 0.14692916745139709, 0.1143314291332518, 0.18047123937116516, 0.13881847202297182, 0.1197139628892464, 0.10653685222590163, 0.1436391722170576, 0.1322360300729352, 0.13821945255321844, 0.18893530051554405, 0.13881893167572637, 0.1419329718356171, 0.09681927205453958, 0.12768480896709428, 0.13750285390884648, 0.1014755544583163], [0.07272351623302506, 0.10033290367573501, 0.02745164802388078, 0.05455489458155729, 0.02268396111415519, 0.06986554096182508, 0.006702222669827602, 0.007101332453349906, 0.03217055620024762, 0.10839744996760162, 0.04776824806486407, 0.030484597776986422, 0.05232044593280843, 0.039724554686296376, 0.045097899217639244, 0.08810999382647776, 0.024061099919039878, 0.045774098215324265, 0.031126621592369293, 0.02660428583171339, 0.028051741931947972, 0.005579093243971828, 0.06242331470392885, 0.03524582081985089, 0.014665157932247368, 0.0655773944491821, 0.08318975582839021, 0.08370055261278346, 0.05696622910158289, 0.03449908810697737, 0.03802861605260161, 0.03218299363769832, 0.0709753725377302, 0.055494708264426845, 0.036932263793724204, 0.09170635528261624, 0.04728685373500471, 0.041218962400190295, 0.05733318138687361, 0.03405307554790089, 0.004685871592242151, 0.005389661246520137, 0.04079163472558703, 0.009721139607380235, 0.07127380208863367, 0.028062227760411562, 0.05593031351905196, 0.044280537028586676, 0.02566328854300082, 0.023519709413390488, 0.021386143052950505, 0.02436194647734444, 0.024538190749984597, 0.019107110002228332, 0.020332737683108257, 0.0510956054072707, 0.023228237856059306, 0.11300167669692349, 0.042263619045937256, 0.07303003567240893, 0.008319824982825066, 0.021805173995333816, 0.06918887848094588, 0.04860103543427202, 0.0031694874492278627, 0.02156386587528452, 0.05780988725863638, 0.08151459732964154, 0.006797433513472038, 0.06207617345236002, 0.0665491616593734, 0.07212534712086763, 0.03784270183513722, 0.005275943633844896, 0.05685821453469896, 0.028854619313572204, 0.02589250204994554, 0.03274818266471548, 0.02001035447803236, 0.03141631582571614, 0.04928385343162283, 0.02475548775926713, 0.03715035753444799, 0.07007129685652834, 0.08706284356453727, 0.07762994166583785, 0.0573767947724029, 0.018391219989186334, 0.014193253516550026, 0.02450383745224005, 0.028075672603482683, 0.03488837568570049, 0.0252072268255776, 0.04419122649837406, 0.0822433997546473, 0.031943918663948294, 0.05596312889528852, 0.030339253660772118, 0.053117165882741256, 0.03335244983675019, 0.032384218122329445, 0.04973502559286933, 0.04617775377306727, 0.0358424807387975, 0.022242380373720682, 0.015090836602593622, 0.03097296925261617, 0.04963296352915707, 0.004710120669070391, 0.025140196047422868, 0.04421853370243504, 0.0260407917742287, 0.09669449931431202, 0.020811052339512016, 0.0751030006475987, 0.03183756459264025, 0.040572399513856064, 0.010509922886417519, 0.02742305379210701, 0.010223779470599707, 0.02305015688762069, 0.06748468524986698, 0.019048527258658604, 0.014324878913260276, 0.027617130676404606, 0.014657708684793644, 0.04519410453917039, 0.045266790961426114, 0.04899465140976733, 0.03046219928130027, 0.025416797838143768, 0.0165220229105363, 0.03618201473727822, 0.06005952743092372, 0.03665793153847899, 0.048365340823487896, 0.005943287612735144, 0.058008775175098455, 0.009274334147302134, 0.05537513343076553, 0.0433611051149426, 0.028739868918614044, 0.01698156458235556, 0.02320910289493059, 0.03590261097997427, 0.04674031511850415, 0.029443670064210895, 0.08377284066931856, 0.04165559038219433, 0.10765050658054891, 0.01530085864942521, 0.03781463237359159, 0.011681061606073092, 0.05450866117532696, 0.05577726064309959, 0.034498735706532196, 0.02867465185362005, 0.031556280089482185, 0.07494326365450699, 0.016931362840677464, 0.03434944049184842, 0.028314289839697943, 0.04864127803293448, 0.04971315378263112, 0.014448066809094481, 0.030042046020107887, 0.01617677964179987, 0.017405845142240008, 0.06910722882997605, 0.003542369733857472, 0.02992743926663553, 0.05528833949938417, 0.02956250179258566, 0.02956591662950814, 0.05379891135699807, 0.04810990412689505, 0.07706207133108571, 0.06382803267408764, 0.026950998074044625, 0.0270723904513063, 0.02853096248732219, 0.06007286502168544, 0.013697321710717535, 0.01626620891564075, 0.06545712630594931, 0.01591053248698553, 0.09652664178922292, 0.0805004041702036, 0.03407342284316978, 0.05611522416133554, 0.054558330485897685, 0.05790138496987282, 0.011865221482190874, 0.027346203681982817, 0.04296223760672635, 0.03598645930328677, 0.07991331268943126, 0.04880553877521907, 0.04310361530271269, 0.037551764624133226, 0.07280174147097335, 0.03613562428302342, 0.04629212686972273, 0.06948411344520508, 0.027822045789610957, 0.02659202076404566, 0.006488720189795019, 0.024119812897556735, 0.11266804540589934, 0.05003315636948232, 0.03542829147209564, 0.03936949208559048, 0.04014824344325931, 0.05317135128162561, 0.05240088516485788, 0.048545463416244716, 0.01405181932157927, 0.046024486392496095, 0.034022416709171194, 0.005744416454446412, 0.024488718707054376, 0.01994971670360575, 0.017085290972083327, 0.09994532447308303, 0.06028765309301596, 0.02120847768721081, 0.017105954278620984, 0.01732339684460913, 0.016752927556573864, 0.03409862713587861, 0.011537633667279397, 0.05198697168980876, 0.004015074472033209, 0.015494014312993857, 0.030014288739391395, 0.023756342481881864, 0.003180585429823447, 0.029318299775402394, 0.05800791715662326, 0.03266433434140298, 0.028593406314030293, 0.062124479126425526, 0.049311340666346015, 0.024825987000499043, 0.051217520639540694, 0.10121981132655375, 0.06409300333489815, 0.0059162341752990845, 0.020141340191325834, 0.0050971818047635745, 0.08507165847526443, 0.06115993995579982, 0.022161263153858246, 0.022029178104393428, 0.04704321862288541, 0.04995576999781113, 0.03821334283378336, 0.03597361200879659, 0.06241730474416287, 0.041339778296288945, 0.027586182639483484, 0.10188428534855766, 0.009407914025829205, 0.03880606123035954, 0.04818346771982409, 0.03493928988914817, 0.07528097819416754, 0.020291953077239376, 0.021738871000707153, 0.054937861934905095, 0.11710594678598067, 0.013898838266369798, 0.03144952765245351, 0.05314129765235609, 0.040084999054670334, 0.01288351225441382, 0.023437291759276585, 0.014037006053953402, 0.015172941118268477, 0.05136501171716279, 0.02660805498430085, 0.02567091686350684, 0.05175153371847926, 0.04173710213733777, 0.02980914763024738, 0.04159388966077278, 0.03815404379800443, 0.015648804293314538, 0.054718427540313815, 0.07495960430993188, 0.01266546830940511, 0.06862326044469111, 0.031425522287346186, 0.020733623833004988, 0.02448234868596398, 0.07285482370324674, 0.10248645343967985, 0.05124227677081382, 0.03263121636043633, 0.03338657139289764, 0.01783616055974797, 0.03489519003778696, 0.04371030331258813, 0.046184958829995126, 0.06405401712043152, 0.10894714103591059, 0.05509177665977229, 0.013754694992976805, 0.049573503614914034, 0.09769039063323891, 0.020395622010372823, 0.07079738733028212, 0.00532602615308978, 0.0064412801950839505, 0.028911507087609464, 0.023586043051534125, 0.03170068191754962, 0.054130504854143634, 0.025871369514554262, 0.055458790232096954, 0.012901110251644447, 0.029091870998062437, 0.020238254144186937, 0.05580170650876338, 0.03519012239731608, 0.025615967291918014, 0.02659289410427934, 0.0324784392761367, 0.04252942857302485, 0.06174352658431857, 0.06262077769685177, 0.04033116608737938, 0.03790132288310317, 0.009995020828360032, 0.07919637696637262, 0.028333909351438768, 0.0185473314711764, 0.04053947305487048, 0.025693414950623147, 0.02826809856830345, 0.029162508135120717, 0.04610839983328216, 0.050375793024056384, 0.07053157780319452, 0.04491399598097609, 0.025878245153674678, 0.011805562385087533, 0.05165601787607997, 0.035724032054384874, 0.023996664263728647, 0.06696496354115587, 0.04559091127087032, 0.17844384896659082, 0.33674890115376444, 0.14153236913825237, 0.23179698525176895, 0.14624647585855377, 0.19155363582314985, 0.06479302000614905, 0.12008959878115885, 0.11423989694805876, 0.14382396794615254, 0.1988307816246825, 0.12674376188266662, 0.1222263252542865, 0.20221552661349698, 0.1830981548635229, 0.22540114699832856, 0.08826629108478946, 0.10979602008216804, 0.12310646834873384, 0.17089279608861094, 0.1070170667803576, 0.13615400290056584, 0.14857506139143822, 0.15443211000773216, 0.13282997804062982, 0.16793335247184002, 0.18287719978440195, 0.14173262452165927, 0.14138183286113126, 0.11969174633944228, 0.16126025167684402, 0.21484866888532717, 0.16260199338918732, 0.22832915036668702, 0.14236789527198962, 0.1324314744241776, 0.12212140185217704, 0.12398894801135026, 0.16280480750626133, 0.08898470535754197, 0.04152430589461038, 0.07437938463784034, 0.0870206474416679, 0.12243365929011377, 0.13372846127998445, 0.1027608814559156, 0.11582419741898776, 0.2768338387531619, 0.1617810229260114, 0.09952151697249183, 0.12315899133682252, 0.1250401891828064, 0.13728762916739912, 0.16602983848462183, 0.18611317049832116, 0.12332946122173341, 0.14874412167456844, 0.1459446985034212, 0.18215041217063704, 0.12457250016591243, 0.09470430247846151, 0.06958873807302407, 0.1555541530251503, 0.10119015606300485, 0.10467495213473037, 0.1815429504119581, 0.1078708181458135, 0.2197925253741203, 0.11673660813680581, 0.16157424047348962, 0.21141656434103367, 0.15462059828062213, 0.20434975563999147, 0.17089429762094252, 0.16458614579131528, 0.08360032532964984, 0.11943419524017843, 0.11965695062592147, 0.12190945596704561, 0.12314151687126969, 0.09378459860360432, 0.08872165374698178, 0.15580956673910543, 0.13960749661970523, 0.14475484138294575, 0.1893222515260981, 0.1033856951060795, 0.09877033711921784, 0.21956775517713642, 0.2205556102337376, 0.11262758064173883, 0.10627177814322133, 0.13855855371202194, 0.21062134975387206, 0.19530250240237484, 0.10786465879890228, 0.17330391993445737, 0.1951972572433372, 0.25709984283293447, 0.10729098917856332, 0.07058161100552929, 0.15946150787415045, 0.14018491240999392, 0.15540910193756705, 0.07108842413271628, 0.15574014385140714, 0.09420238465311066, 0.12063929751034706, 0.13606657694664695, 0.10423785300865289, 0.07990201289254813, 0.15584042476069543, 0.1843536810408677, 0.17640619298383114, 0.17079973172756935, 0.15992042518431143, 0.0919580917745348, 0.08671543801263457, 0.12071137872314262, 0.15589570566531152, 0.16800639129454092, 0.21813483368004524, 0.12049412384869591, 0.13691624506346642, 0.0687523692425701, 0.1973016394843017, 0.1210335263561818, 0.13416586684123163, 0.18212804240324806, 0.1932512713415969, 0.16588469546648765, 0.15126861121144988, 0.15405501088788434, 0.19624944836381944, 0.08031242151534365, 0.14246531101244111, 0.12994351195952586, 0.1621054458401857, 0.2621975757421986, 0.2074578203140728, 0.1476586976599309, 0.11141931442844291, 0.16485807636091787, 0.1601553383854128, 0.13249181150909395, 0.09251108468179742, 0.11789665677614751, 0.16236485853310556, 0.12263491824870149, 0.16671648309115442, 0.10620626230393687, 0.10491135920728407, 0.14403402925499026, 0.14563565863476646, 0.17155121801601303, 0.10407798578061404, 0.08726810916296898, 0.06985955781513645, 0.2276574444746779, 0.13541180159776442, 0.16508709068500227, 0.11414530807204785, 0.12653511783648885, 0.15927551704789364, 0.13889403893582283, 0.1280073396440956, 0.12683560050302936, 0.16369244294060817, 0.14438868199865665, 0.10870819055144826, 0.15798131875213117, 0.12003798743770008, 0.09973277337849142, 0.17108011990785602, 0.21710153428777573, 0.15493731435027816], [0.029926343760903806, 0.042905052973618435, 0.028239377932022178, 0.04147590062911472, 0.039030927188333966, 0.024247433569642807, 0.01973907316794559, 0.04114129640642674, 0.04458668491532726, 0.07476283462658044, 0.031469576173431935, 0.04008829706318436, 0.020570652033652992, 0.06532027235915584, 0.016426415137586095, 0.07135340628484566, 0.026879939588627992, 0.010936534268811587, 0.07023282649536287, 0.07559247720505922, 0.014498180450661289, 0.066401865934172, 0.05164246195025983, 0.06973977230729596, 0.014637233069797438, 0.02559483858696636, 0.029770542544523076, 0.06456051232112993, 0.018103963830658508, 0.01084991558004291, 0.03279521280238706, 0.04248090839434055, 0.023668973984557296, 0.03139149266174965, 0.04186760138479933, 0.03692980848192688, 0.06701488183030198, 0.022105654746654536, 0.01872312758238085, 0.05873791467879088, 0.013078344692926736, 0.031775381235826405, 0.029621716558692918, 0.05506679836300112, 0.03565218449840623, 0.059600008741742184, 0.0215737771378049, 0.04305005809592624, 0.019582109413139766, 0.040905096177612586, 0.0949875788102227, 0.07880775588414363, 0.025639913285211213, 0.018318340129729722, 0.043093870664315845, 0.07166859017865312, 0.019965519182263844, 0.023595096295579307, 0.015297738756353577, 0.05257888952450407, 0.04483114357196516, 0.12106477508261321, 0.022374580336374142, 0.036566981580108404, 0.024043861025523756, 0.038977979021447326, 0.017890478108799266, 0.05701332052628841, 0.012553167480584836, 0.026738138629063487, 0.029334845359347043, 0.042434713292506435, 0.03586753564436109, 0.09513049251249722, 0.03376134543589527, 0.03216102223602995, 0.0453085236011013, 0.058556420788649595, 0.0237934498657142, 0.02367534209042788, 0.08676355599515861, 0.11521963147266258, 0.053381098494414365, 0.0024168855452444404, 0.047929298898745934, 0.02588338943408622, 0.0147720999760373, 0.07922427788857492, 0.10571972752410559, 0.08245626494528786, 0.029116504555267674, 0.08956252717443051, 0.045557980981445124, 0.024789469504368403, 0.007015063771001634, 0.049153660619330984, 0.011721835678233015, 0.0547363578281816, 0.05468540148989809, 0.010795962880365552, 0.013104396470401798, 0.0258956449256549, 0.06002298503693554, 0.056843413716001864, 0.02768266758310699, 0.011795358093936118, 0.06282020570530046, 0.032679529695381085, 0.033501132181094545, 0.10984364776842057, 0.04056299578458552, 0.022669365223977837, 0.021402138968809478, 0.03591247819243901, 0.03543564974660835, 0.05379487024319749, 0.044995117031278155, 0.014964224293737885, 0.07125822752113305, 0.053216481521244974, 0.03516365022909257, 0.004298021864791912, 0.026925573531057567, 0.029598243624692964, 0.037917736316880876, 0.03675475356078917, 0.03059532812556192, 0.05483077433440955, 0.055144935500838106, 0.11110785372194745, 0.005863131833217678, 0.027099659350971063, 0.001445129946073247, 0.08478560890521734, 0.06599419224526613, 0.054888284554885286, 0.015039434975704119, 0.011612079218931256, 0.08302511587258309, 0.0016306114435616522, 0.03586031909611437, 0.0638144231221128, 0.036442277787794033, 0.040564206203505884, 0.0301771188124774, 0.04776680781956642, 0.010691475190763033, 0.012527746768037399, 0.09093747113741214, 0.08290171442974, 0.01554156060240442, 0.05313582778457673, 0.014310273446983868, 0.04508802434429527, 0.022863436362615997, 0.042093945892467614, 0.06109550430048859, 0.011432567581294045, 0.037633839453901016, 0.048449978217362404, 0.010977600411992642, 0.022201969235714887, 0.03599471007023127, 0.06416319997139996, 0.0722792771674933, 0.053767700934962886, 0.06191505367056497, 0.018129660334858685, 0.016136205710110166, 0.0499550307229642, 0.009779911957711223, 0.03875386382963869, 0.04074029917378099, 0.015273088919779947, 0.02529318189068187, 0.01975363841460597, 0.019933527350545894, 0.006809998313040143, 0.03412399613749116, 0.03708538944802938, 0.030954274792043917, 0.02373525591176604, 0.06649466982531933, 0.018872282986018448, 0.03741917012619876, 0.05194504752815251, 0.02953551059979345, 0.14564561777778212, 0.05179474107740868, 0.0117296899946767, 0.04004168444343152, 0.00943367085945342, 0.008436960784057456, 0.013988471511120518, 0.009348584346533304, 0.02641556964766595, 0.04589922718643662, 0.04255742908665731, 0.011300655859222096, 0.029978152372003086, 0.008850952783118813, 0.037026664978193666, 0.09421611294871378, 0.056559133809059865, 0.010271705931142695, 0.027359690659889774, 0.05791702082440738, 0.02192834369657982, 0.0597237702459097, 0.012780721449563581, 0.024194904835894707, 0.034971722221422585, 0.03754586574711627, 0.06764002489827334, 0.024190252766974514, 0.044903286071794654, 0.03697697268498521, 0.03930137154736346, 0.016203665497502493, 0.010541083512737626, 0.03781966557125411, 0.03686218590085064, 0.05607228876361924, 0.013815108686685564, 0.08305894631531932, 0.04243974649016896, 0.05683639252017583, 0.07762579713016748, 0.029881883848218188, 0.009004628105509666, 0.03177995478073436, 0.0562263950104675, 0.06149668156379654, 0.08927826258924701, 0.07600843230442655, 0.06647214684034548, 0.05511531854168542, 0.040281627011755784, 0.005743714047580837, 0.0092721622880368, 0.03722023624446123, 0.05965166605047642, 0.005915497294476917, 0.021136798670575507, 0.010534515266396828, 0.060672236891884, 0.02672741339812356, 0.03411704388957831, 0.041259595703694134, 0.06149712972523225, 0.024309954005143335, 0.0496203154175272, 0.03728082613839257, 0.054172356237447074, 0.031013646606175654, 0.02487997704696271, 0.009615491294572431, 0.05093255891434608, 0.025850079931138505, 0.032839845084855636, 0.0638869793094214, 0.012744865661877538, 0.042877029477348255, 0.018092215872339664, 0.09341979519494119, 0.058445311226551576, 0.06322645064022753, 0.01218800688342702, 0.03021984162079471, 0.019384521930929155, 0.006833127943889028, 0.09666531902527618, 0.00950807714909916, 0.027133913057285453, 0.06877361286071039, 0.06789572972563968, 0.05167695505905056, 0.08196224548643635, 0.030910810793659864, 0.005019275929718729, 0.055391569847180966, 0.04357790799751397, 0.013088164024896199, 0.09664467295571681, 0.02141214216188077, 0.012648091520062618, 0.05824679486273278, 0.034622987506971244, 0.06339022491668021, 0.026880364767425967, 0.04719553222399085, 0.032083873351615284, 0.01250849306328042, 0.0329984980635345, 0.05492014998209573, 0.04207395865852314, 0.08549187302349076, 0.06714202178221557, 0.014724973119765282, 0.013980456316212734, 0.013859313875136357, 0.07426169821091237, 0.027587963793907436, 0.04615064192142698, 0.028349690762678945, 0.05623684061931507, 0.06950182539801444, 0.05642244840160974, 0.08083607325510633, 0.027404196537850846, 0.0393701394298865, 0.05036974092945457, 0.04621311639165206, 0.025901624241903908, 0.03717481106099102, 0.05392416673261793, 0.011383426871391074, 0.029587964639968933, 0.027495983447278702, 0.08042801652223834, 0.03495180393539129, 0.01452749097464426, 0.029168864749672434, 0.009504547398988037, 0.08119953600990196, 0.032159551347215334, 0.0027397434854309166, 0.032997797093083786, 0.06786897027444455, 0.03438889785038848, 0.020244030447136012, 0.04398613326972531, 0.06162463356890987, 0.02634950605551562, 0.020771495389541792, 0.01687871727852091, 0.025489865389141827, 0.05533711631752311, 0.01598636657300015, 0.016087417400652365, 0.007229257166580929, 0.045274402044953845, 0.061290056159299236, 0.059848650238446655, 0.041500928721600966, 0.06704465966791877, 0.00960892975150097, 0.057925616330917806, 0.0123780541452429, 0.052957639563828714, 0.011379504501218758, 0.0615537666054743, 0.11854762466804636, 0.09500028820888651, 0.12831639483450882, 0.12203214494811913, 0.07469790867499768, 0.1747268669667744, 0.1730474030538913, 0.10965692915863569, 0.10810195453344815, 0.1261906923666116, 0.1178678748528323, 0.29521348315381235, 0.16464651351974857, 0.09727435892507916, 0.22233232134772887, 0.14766130235887345, 0.1041119464582974, 0.06367757683619857, 0.1898582526032002, 0.1425140954914593, 0.0956341723400739, 0.17069421077687896, 0.11312895454466344, 0.12637276082269608, 0.09838068947917032, 0.13794042800943698, 0.17851601444905807, 0.18142662762153536, 0.06786759897706009, 0.06457433254728395, 0.10840294281801871, 0.11569086747664599, 0.11100745789947049, 0.13534584142748388, 0.21936048242834308, 0.13504139808637483, 0.1608819727815928, 0.1740897269619088, 0.12637901976103746, 0.0966960544727983, 0.14455172083070203, 0.08581616570271793, 0.10560668358999876, 0.1470640602131044, 0.10120759988504072, 0.1265427480722147, 0.1261792929782983, 0.09264463678963723, 0.16603567607460484, 0.13186639264946984, 0.14350385044611272, 0.25183246741371773, 0.108976780977701, 0.1473781102967839, 0.06980849039410392, 0.18897020348137428, 0.08432288413807269, 0.1122510331051965, 0.16558400595620756, 0.12861795002414336, 0.16887248433645696, 0.143929427609809, 0.06589835464593864, 0.09910322530495544, 0.10995142867848759, 0.11563961619451163, 0.12737347849554595, 0.22513140744018942, 0.2216324540636232, 0.09365191217511894, 0.14639834512866315, 0.16597575267716763, 0.14118784407694496, 0.190567021828986, 0.21639550765675886, 0.1205487612394556, 0.10949095620984033, 0.12373351131475742, 0.09520400630971117, 0.1141767789639773, 0.09393091373626264, 0.1657679743103443, 0.14992192057111572, 0.06203135347834999, 0.1547044082995384, 0.0860085916675387, 0.16766733610101286, 0.13035490117486448, 0.30287856055844214, 0.1242038816393864, 0.12698476548276602, 0.1730964786463207, 0.1638929894374263, 0.14155740489161786, 0.1620890668803646, 0.14031168463970387, 0.12003244862200753, 0.16440286691631043, 0.1914463681919921, 0.2175676068591495, 0.18507944209681404, 0.10512522031222621, 0.13242502396385517, 0.1717404570550688, 0.08599148492418951, 0.19741676717756257, 0.24679274268208012, 0.23016334871851632, 0.1188226578937423, 0.20249928558065047, 0.2631558904484395, 0.11765189934521915, 0.13874537191323696, 0.0979042977034565, 0.11528084955869183, 0.0873272817942404, 0.16251553270605304, 0.12274293664602504, 0.11060592057483812, 0.10239708162243329, 0.1467687026747773, 0.24983037323240312, 0.1817901669851234, 0.09080069379941111, 0.11712673841224563, 0.19262283409555114, 0.10085081741694482, 0.15571521535035104, 0.2368411073280919, 0.1353372918862489, 0.14076569898714944, 0.1392083801329136, 0.18174309854305562, 0.23327283831613682, 0.1833100701051374, 0.16864178461893914, 0.1773780980898488, 0.143775581832855, 0.16372662578378955, 0.1448468638644103, 0.12241976245516732, 0.17650020729389884, 0.10915374728820978, 0.15161384107364764, 0.25251281477751275, 0.23161663283263487, 0.11349555825994861, 0.07833257452735017, 0.16427155944608873, 0.166349618905975, 0.10947240156031425, 0.13965925351986963, 0.11040100737685159, 0.15506650741782882, 0.11834872526026542, 0.16164875018500513, 0.1849063521912021, 0.15430659416221804, 0.07678384351874552, 0.20066067456237732, 0.08901589279693943, 0.12284590652392757, 0.10391773550861305, 0.11156363007161887, 0.1342848402958724, 0.09136386035430817, 0.1677407426459174, 0.12194563063883013, 0.10774380076796779, 0.17407032961566604, 0.10179747992585744, 0.23221171461045745, 0.1239217697612701, 0.14743582736099922, 0.1467635852074431, 0.1792569134023882], [0.1982078295681746, 0.004498463024520466, 0.03125051141626412, 0.0843558872058507, 0.0397471274669853, 0.01796483077229031, 0.09330978496901451, 0.07417548267591385, 0.012934573929786924, 0.08415149494765267, 0.025184625316591516, 0.044913214571293325, 0.09960838368222599, 0.07261565105328638, 0.06782619192475273, 0.01695328444663075, 0.0559492550429798, 0.05242531570876318, 0.017162778850404486, 0.04908945862083666, 0.022162167137608896, 0.021112458142001304, 0.03573732367987114, 0.04069996464456763, 0.035426184730303865, 0.033139649763583176, 0.030210066338880893, 0.024607895174995068, 0.009756872820998392, 0.03726339380767557, 0.029007137843197393, 0.036485259150785786, 0.033275496304756215, 0.05368992385845031, 0.030409710767168193, 0.05534421795258119, 0.06641593896934102, 0.05780896795312724, 0.03499747426699727, 0.10533193381683481, 0.052678906133458506, 0.05253664360591962, 0.02076564247780029, 0.039627483685410796, 0.05480436345321998, 0.023857925740641453, 0.019445726610419732, 0.018222466141225833, 0.035045879532492934, 0.014008879135813446, 0.008791379870906954, 0.08232753919137102, 0.04094984337326981, 0.04466172322751053, 0.021062660511703264, 0.014531898853038589, 0.11701481296650826, 0.08349428343917094, 0.06464729476119242, 0.03848286022642448, 0.014229050890031843, 0.03526448272168636, 0.07096817131124197, 0.04329529433180729, 0.018618391871812846, 0.06155415347987606, 0.01592322752150076, 0.06264119394003384, 0.04630415445013393, 0.0476942669540163, 0.03511865788529958, 0.03697257534029984, 0.014363739680829308, 0.02224136530722101, 0.05853820704824983, 0.04039061067986392, 0.02966452172146209, 0.06786222870071089, 0.0702554720544046, 0.04118025580781602, 0.03955274797795762, 0.044692903006028746, 0.05989148987517242, 0.020309069396687612, 0.04827416103874003, 0.039281070217370026, 0.02669234189295, 0.021700461267403538, 0.027121655650496967, 0.01927076936549237, 0.024945343499101942, 0.07679235475558428, 0.05147309140152028, 0.03330936122144903, 0.027614259761908365, 0.020848008420979305, 0.04050591457334738, 0.040372140300009525, 0.011103372896961387, 0.01896913948228523, 0.05304791536482592, 0.03613528337389712, 0.03374079895776606, 0.042022324332426635, 0.018529726770676432, 0.0745589403255332, 0.023832880411176913, 0.047910648488229325, 0.051833290621758475, 0.01957163124555542, 0.03462736186901889, 0.01816386616067781, 0.08787825989026217, 0.005635301114976286, 0.0037844269442552283, 0.05219186190515757, 0.019396043893310334, 0.0184960916803609, 0.007753330733506911, 0.05328301242702911, 0.026641149982629765, 0.03631043405602536, 0.05655701557594923, 0.05955046583567897, 0.06879321705069273, 0.026272562099620703, 0.014995078484888279, 0.025238270623489253, 0.04210324619986838, 0.040202658668520956, 0.050994432005550594, 0.04528455654039018, 0.0517968210061231, 0.07938353224627434, 0.04813614263830166, 0.049372382552152684, 0.020655666725830208, 0.026281284010638634, 0.038547016259643345, 0.007408098477284394, 0.025421589718110142, 0.03431703497265135, 0.035720979194006616, 0.06740410812199116, 0.021839450684285933, 0.03637060260159835, 0.024988512553635146, 0.06361923924076461, 0.041629677458155545, 0.03170479772492282, 0.02932014796251972, 0.01486557036367876, 0.05179280287496025, 0.09180462904154293, 0.03961702275480475, 0.033899329362377044, 0.05480737034832278, 0.018947803933594017, 0.01681373770078344, 0.04909828012328475, 0.0486225433527462, 0.030294839713361957, 0.010622355865404732, 0.027844637722497987, 0.03467822627675149, 0.011347901459122378, 0.035608900530684384, 0.036176816830711986, 0.03529462062062756, 0.05515633105871178, 0.0310743801415928, 0.03549501773030047, 0.042078015094082204, 0.007300152858313654, 0.036973904502848466, 0.022083491823005102, 0.15302859096517488, 0.022526503232638204, 0.030306007360078158, 0.01927749178702793, 0.029337467295267892, 0.021709688796451496, 0.09732151929769786, 0.04441670915712753, 0.010510078019222185, 0.06642739198380901, 0.06206937059159241, 0.028225237864159772, 0.07809409135652166, 0.0164831860832149, 0.06936677175784303, 0.020077967483009544, 0.04469973267987371, 0.024138082179331014, 0.006428684273193921, 0.004879246548479123, 0.01777415723359633, 0.036639461158624584, 0.0149262311207431, 0.045424382908329855, 0.06962488210129161, 0.008588817605238048, 0.004520061437130696, 0.049515292423987584, 0.037984228918268796, 0.06331138297795288, 0.03267978250439609, 0.04665039937883135, 0.04548372407894462, 0.08476619623721608, 0.008884544780988608, 0.09306494326841447, 0.029435072642480655, 0.12264922877112705, 0.03138468788576222, 0.056479652186915766, 0.023601305438205603, 0.005208108942174623, 0.1022271326773109, 0.023596588251811844, 0.02198393103636561, 0.016816116403788328, 0.04638058321189977, 0.03200448174480229, 0.009628313691205075, 0.01947249180727428, 0.04308781473927441, 0.1048866298890883, 0.03289524473309998, 0.048203255770908254, 0.002223071285463389, 0.02941006178697271, 0.0642653999309386, 0.06829034927631579, 0.02294136474149362, 0.028835773550634904, 0.020835789318587032, 0.011644745208022576, 0.06079828133806587, 0.06139785239112474, 0.08931789231757004, 0.0446231315483249, 0.029180660588486545, 0.017702742517294905, 0.010991695472189497, 0.025933616073621858, 0.0018599299284922442, 0.030003199616687435, 0.01876513409848896, 0.040869695254631584, 0.034528310530849045, 0.0912357934360062, 0.032192902984998883, 0.08541454410841388, 0.036797267610147115, 0.033302657952111576, 0.0600269150679871, 0.07006587295402443, 0.09509168249825317, 0.023993540540217392, 0.06664858455018652, 0.016816549243465546, 0.02036332948914459, 0.07626831231098022, 0.03274103506438194, 0.029086734378530137, 0.013324930201164417, 0.06579554564650021, 0.10531350940225587, 0.041030167692130616, 0.044751976045870015, 0.02084760814003887, 0.018359900399621938, 0.04464424110107845, 0.0304270722347522, 0.04690099439974274, 0.02552578916713115, 0.030409005966277856, 0.08430007003968762, 0.0310115609318018, 0.03033190113191884, 0.027355463769767555, 0.022493699347720515, 0.07296614393952393, 0.04759716147917414, 0.01323914367540349, 0.10289587380905306, 0.049962097884065686, 0.08028423714060938, 0.028396422126060052, 0.023664298932999376, 0.052518567761346224, 0.04896671218316882, 0.011367369668498155, 0.02447136490034961, 0.05060308748075078, 0.030830762266451796, 0.042942621925425147, 0.042888199039284265, 0.03292974167233033, 0.008970728714860255, 0.01239820130004157, 0.02857185243028066, 0.06335382807939764, 0.029590571254131295, 0.024540977394809167, 0.02958790335293499, 0.02829830158471821, 0.03494795051313216, 0.06492328559679371, 0.03226846989784991, 0.0581179925000235, 0.022030131883859154, 0.0218804651165321, 0.03950572550116528, 0.0075429103209546985, 0.01421894714792049, 0.06380937460269179, 0.04384543739199158, 0.04682533172590118, 0.05382698464898333, 0.04243826411003548, 0.018492307206014955, 0.037398558530595996, 0.008337258271151974, 0.040927527232035514, 0.039554693841285286, 0.03122827188382226, 0.023348959906387235, 0.020848669171813997, 0.05312818222709241, 0.021791930250342817, 0.00487574887829983, 0.06008414183593085, 0.05682201304983708, 0.11230239930051951, 0.05230367626814593, 0.05695410192974153, 0.024480655631651322, 0.014022575830289674, 0.0608645785870331, 0.031588473019280264, 0.011271168177406634, 0.02725859961262153, 0.04198019332703083, 0.02447679454851295, 0.022836353239272873, 0.07537281681453029, 0.0641507318904323, 0.013725936052299315, 0.059027760214502775, 0.04032594136773579, 0.31051369924699107, 0.07908794488156996, 0.09776290085527206, 0.29967530179888974, 0.1655772797042324, 0.10722081552469924, 0.17248602914473704, 0.19590872309861646, 0.07823884366981446, 0.17544531954392312, 0.19964631286359605, 0.1411128440691579, 0.2379865619924761, 0.2512262620392346, 0.18366456963121894, 0.11641823731723333, 0.14116132211300636, 0.12766330487905972, 0.07755976035109452, 0.16744513995945456, 0.05887327092369238, 0.14956953544770518, 0.13526797625086, 0.20557077721722666, 0.13736523387412872, 0.10301090191088377, 0.21907814838472875, 0.12184016331429444, 0.20803410229423355, 0.15079233434892472, 0.13087236292419896, 0.14735184880273958, 0.16976663151816015, 0.16890239240902086, 0.11544339809446566, 0.18534967195122473, 0.169296728507165, 0.13534216420544734, 0.12572023777231095, 0.21958961932649537, 0.07023488727187918, 0.2073449602410678, 0.2515521251987065, 0.11392618394306592, 0.08947886271221984, 0.09965920595512276, 0.2893067920400251, 0.11631713669386604, 0.13345395665495627, 0.13779318591039028, 0.1150049200101245, 0.26954895546359403, 0.13490589245432807, 0.1389319909315917, 0.1537114510973615, 0.13116070309713965, 0.23799917179970975, 0.15785456184417973, 0.19217075028967476, 0.14355589845968833, 0.15284940299968566, 0.11987105687899936, 0.21222196789758824, 0.12272832734930901, 0.1863828181259094, 0.20406569023766827, 0.21097013426403846, 0.13631397738091408, 0.13418739391190393, 0.11897352358867085, 0.09533677700786822, 0.06366964399574265, 0.13604079042711567, 0.15013699209497822, 0.15736729928082036, 0.18676901837029766, 0.0824202971172429, 0.21198991986532367, 0.18116333852371863, 0.18219161237920486, 0.1444378341998785, 0.09671361320802281, 0.17260062057645092, 0.06724909789139225, 0.2791487419557187, 0.1135864545921645, 0.1699707786282224, 0.21106278493760094, 0.15456352473026322, 0.12259567922521984, 0.15982855592043171, 0.19578064851943525, 0.1990300870590633, 0.11570709321888224, 0.09906774777318202, 0.11817158274953404, 0.08595786898607209, 0.09338110775476502, 0.0987935419224443, 0.10856775897404841, 0.11608184044880253, 0.11778385799017646, 0.16450484854079064, 0.11426498632757895, 0.11406709049497882, 0.20425109883710263, 0.07237418013955317, 0.17047458869074622, 0.1414621648408713, 0.12264653214163358, 0.19962486240171617, 0.15699475072324276, 0.14097094926382267, 0.08939458537966975, 0.08119818003427598, 0.24720027081428037, 0.1183519964557021, 0.0972440678085531, 0.08772215415393153, 0.16861791331921855, 0.09413750466680336, 0.15373071054777793, 0.13762682225675354, 0.09878574314737514, 0.15168508725060573, 0.0800673270057286, 0.10613006719898795, 0.11987603645050719, 0.11242293557452579, 0.159589750992675, 0.1943141570495021, 0.14728342182934284, 0.2344133746960471, 0.11104400795433791, 0.12674820519262744, 0.22051258673591, 0.31153501702412484, 0.10913040458915696, 0.11015659468548913, 0.12127594721894111, 0.11446770851410205, 0.21093608931668345, 0.08071602727737158, 0.1315423221357407, 0.15130930580198765, 0.09846688203153112, 0.15412536840285027, 0.14149352848049135, 0.10107286034091827, 0.15787659453288203, 0.15749574158220522, 0.1965744381830577, 0.14923820242045388, 0.18635931454839247, 0.10133493901981462, 0.1473113687168206, 0.12736646879103877, 0.1614771618117248, 0.09390589330465564, 0.24681051592192343, 0.2000555417109882, 0.18216450818844382, 0.15742008273880329, 0.06849045910301708, 0.15919829538512617, 0.09285514242947103, 0.12352715021059399, 0.08838999130192304, 0.12310762514149952, 0.12304119765758516, 0.1547563643825631, 0.17315796486312346, 0.1898859083772667, 0.06455928658045108, 0.21593833702706525, 0.08367077477516667], [0.0591961769837766, 0.06381589784136703, 0.04397367284963689, 0.049563004379911776, 0.02612528361139759, 0.06580036433954393, 0.04930403218754838, 0.008626476572375865, 0.02499322207914966, 0.04702452990797259, 0.03398684724684685, 0.019354636841002974, 0.028394049168714595, 0.027067385981940938, 0.06333061178485233, 0.03892458269312497, 0.02729347001971497, 0.05607496241047498, 0.03326091382111753, 0.03435925790859807, 0.05102150938323429, 0.021815142714448517, 0.020007226924081484, 0.0386421873624767, 0.08030620854227774, 0.06289861863479018, 0.047635952341220075, 0.014801244833506646, 0.012861072581501739, 0.014540766320762136, 0.051875410135835416, 0.07828715317431958, 0.0787718493431326, 0.07089342411246992, 0.02500805545658354, 0.013136825929846496, 0.05602834596028251, 0.007237103822145372, 0.04581392712650761, 0.03088796796697763, 0.0658973970360333, 0.009595814326237287, 0.05465738565450715, 0.09151851052358266, 0.027103051205255815, 0.040263566488940875, 0.05308824223316005, 0.0020490697352215648, 0.021367680333975344, 0.03695290986328356, 0.04169691699526964, 0.02351158122051387, 0.02388571749531454, 0.019271232848686558, 0.016965654851388068, 0.03777601388132861, 0.0725679237756037, 0.015621883006045416, 0.06723422812478197, 0.009793587584769534, 0.02966872754416639, 0.11009651040958782, 0.033351434770250515, 0.012952039776850614, 0.03525505984021771, 0.03936417543539598, 0.04054945518052386, 0.03865208138801879, 0.0609350395238688, 0.03833884718797861, 0.06513855630351652, 0.07845970681838452, 0.0633701074477886, 0.011446233632253304, 0.051252025239650285, 0.007892780281948827, 0.035815039469349774, 0.08327429363083455, 0.05016366710826274, 0.11603628886082482, 0.08661960807418631, 0.044936132091548175, 0.058523095963943395, 0.06682607946136306, 0.02230383594700646, 0.05166145326990274, 0.11242318072266157, 0.013041228690605252, 0.06562066309514546, 0.016948764527877493, 0.02454003127622268, 0.04185399183282449, 0.04029087369300185, 0.004766845170618786, 0.03415461284138503, 0.08321360414547306, 0.03259042600890802, 0.11108818058405193, 0.12766112152847553, 0.04339185971466284, 0.035536961044154824, 0.021115263939023982, 0.01209102494026264, 0.025557790574948155, 0.037989208489776626, 0.050390049920327244, 0.07828445654482612, 0.01802749676449645, 0.041774862611125556, 0.05522423709232, 0.04679188049668747, 0.03377316617256692, 0.04537015154417004, 0.007430848894610762, 0.019926209295649203, 0.015271219665244704, 0.05223968494383078, 0.007291665561722532, 0.03267410196243756, 0.02055190586214585, 0.011455939966253938, 0.02099835317611935, 0.038798905969146764, 0.03188889439878685, 0.037565113706213814, 0.07849930590319057, 0.021288009105069984, 0.012202489775635544, 0.023917282233014706, 0.0418473000548059, 0.055650779526800885, 0.04933523494870432, 0.01962902272240289, 0.021541017302942854, 0.09706429761624145, 0.0772032613355306, 0.06423130135742888, 0.07513101648298964, 0.02087891432306459, 0.008152255698317483, 0.02434058986123531, 0.026352660422543847, 0.04884881508206168, 0.033054426312446594, 0.03669548899896684, 0.04311927030944536, 0.003983505185685992, 0.005145932288630115, 0.09618351866881694, 0.03224186749467927, 0.02129665057685587, 0.12806673444086505, 0.01166768858374487, 0.03405610542564142, 0.03723346275247393, 0.09823935391801981, 0.018214799516323595, 0.04455988715973593, 0.022244238136937062, 0.06387705847080197, 0.027627262189203215, 0.022916520510109204, 0.06705806620659367, 0.02184320068467529, 0.04875496931133732, 0.05488987801776779, 0.07338752294139517, 0.03353225067257881, 0.07873249540646231, 0.051062357191356926, 0.010036376169732502, 0.04711080289956543, 0.02271200950828291, 0.060412127058953054, 0.039602930567437605, 0.0551277176747399, 0.030144119575139017, 0.028251141212099505, 0.022182407180568384, 0.01641719718463719, 0.01840066010763328, 0.04199094920148773, 0.017906504668175213, 0.0035607915150091774, 0.035835693199788375, 0.023586724869786732, 0.008430311140874702, 0.08189946458104157, 0.06600388325750828, 0.03758550313631854, 0.027009366312995556, 0.03754085553209147, 0.05259775060919985, 0.030304772043300253, 0.043060967187967994, 0.020253026234586875, 0.034591654510868174, 0.09927907312709479, 0.013185239813831306, 0.03573709002305423, 0.06189690887807839, 0.01789887060200976, 0.00345690903486684, 0.027115000261654778, 0.010718278692013795, 0.06054923764520115, 0.03615137888118625, 0.09479336019965912, 0.006945053868431359, 0.025532226220914916, 0.04137689908665996, 0.12559799312223352, 0.008968108694159217, 0.06014195466113668, 0.00929924445377002, 0.060741613814306844, 0.039354089887872826, 0.04466161597520114, 0.026864435884260365, 0.01734248392524258, 0.012794503371321387, 0.047456534549353585, 0.1138687503313826, 0.05891558579019001, 0.034794495441019535, 0.04546736427132161, 0.02147539421134899, 0.02449654046476128, 0.034867959442518415, 0.02045455906960753, 0.02375950259456952, 0.04975877431852203, 0.04314746234505888, 0.03979468237488501, 0.03511221508585638, 0.07172974697764843, 0.06545147257706811, 0.012564378219746776, 0.03734668671724297, 0.06589755025361815, 0.04754782158641085, 0.04097589802357458, 0.038715586246502016, 0.03715546351046332, 0.07750849374720166, 0.03155208192765713, 0.09179165151210562, 0.029754069738931237, 0.0832479555279978, 0.045640772103422114, 0.04394006074195908, 0.03710456845921375, 0.03306091124672563, 0.03819097689683399, 0.06850313019728468, 0.040341339735013824, 0.029876291406370943, 0.060459574714543364, 0.03841614928997813, 0.07009541330438468, 0.03962435804667973, 0.04966424672954506, 0.049155748208924654, 0.026537324001471845, 0.01648747042993144, 0.05438550105018001, 0.03942801737256589, 0.03317357213687032, 0.01729569510526715, 0.021314333801368074, 0.07332615163778106, 0.10859728400265017, 0.04694568413880564, 0.05278110226255752, 0.03309181523359111, 0.02565803892549969, 0.006696867236431929, 0.04333168350821061, 0.02417205626355304, 0.03411290318434758, 0.0620298519460184, 0.023376085164566195, 0.051774294190709634, 0.0382793374780205, 0.029925186968138142, 0.05938821607419561, 0.033016129577111815, 0.0633858582155118, 0.08466062932125024, 0.021904870762579867, 0.04872545960449404, 0.03621626652837281, 0.06748505297207064, 0.025987046875900803, 0.03415400380148523, 0.04253032106545664, 0.03727971531090237, 0.017298573680642634, 0.024526159339133772, 0.10883749087130833, 0.04108008215083711, 0.07006581932786973, 0.01756204280912155, 0.03694988381598265, 0.0842217835147054, 0.026088145584048286, 0.032668222237618706, 0.004481442466062764, 0.04448939940982288, 0.0101827219459078, 0.039048505075756586, 0.053647382996015014, 0.028522991342470053, 0.13604653608654776, 0.0882121746338183, 0.048553400087140264, 0.03278389002286619, 0.06660837259504103, 0.010970993861255628, 0.042388345820889364, 0.0239013705868274, 0.08051745728739808, 0.04103381427065019, 0.07557750784701879, 0.037212617500054265, 0.005527124712018357, 0.036911054649540496, 0.06131907556987098, 0.02899243470071064, 0.04275371613461645, 0.022054706069250262, 0.04498935221964794, 0.04430614734789537, 0.02441853930753085, 0.0780755213852371, 0.05268406573562853, 0.004652360991214312, 0.01077170662146302, 0.024707996053621176, 0.012965620600528294, 0.06171615043234441, 0.04201764353520928, 0.005864898144688097, 0.020593058190218384, 0.03716896964056838, 0.036492333972766515, 0.05276065537585847, 0.0400507012983003, 0.06522974374914361, 0.0408584950491786, 0.027220341181682966, 0.045316916094311786, 0.13786274669391496, 0.16340637038792336, 0.12823407102616566, 0.1522844284772873, 0.09918428506822356, 0.10469733722387783, 0.10254934925826327, 0.13074706158330365, 0.23589615319525045, 0.10671477614631576, 0.14103900851501575, 0.19919899412460867, 0.22605481918060014, 0.134416209053128, 0.08068061103263209, 0.1457104901032102, 0.14186215466789662, 0.2050821356956036, 0.08677788183934267, 0.1133467226980194, 0.11976267075947217, 0.18679367107970102, 0.1570959509380402, 0.11771297953542202, 0.1363374043496386, 0.15543288130673671, 0.14364467272835393, 0.1298259174631488, 0.13517255233901163, 0.07467839641556626, 0.08336768740968359, 0.17827511044038882, 0.14271249694208946, 0.15891847410990348, 0.19292960634395, 0.15590401005841073, 0.1810747940814303, 0.10186356267020588, 0.19354773204653494, 0.15007788075074074, 0.19885673668355713, 0.1110966228729775, 0.16417422031442966, 0.12640599371685138, 0.08788595907390119, 0.11712649326410987, 0.20918346400703156, 0.1664674738722463, 0.09061888581322086, 0.12536877195440954, 0.14059501459761975, 0.13026100943886465, 0.09748658060186333, 0.10186567707287689, 0.17707665781340293, 0.150115939998819, 0.15530724288715472, 0.106982309371233, 0.204581834315773, 0.13088641297673026, 0.14524694562198656, 0.20865945986682372, 0.1229428243072283, 0.19215879931805596, 0.0857579583422311, 0.10653236295066534, 0.14868755374223958, 0.12412357264228406, 0.16658738195415468, 0.15959341289295306, 0.1447001733486691, 0.14025441190648463, 0.1991997908560499, 0.09767172107052419, 0.16085318319739836, 0.10893013388399156, 0.15497342773502873, 0.10817598927045062, 0.15419702826728746, 0.28388285889260234, 0.1381737783911728, 0.20533537371985375, 0.15689684468651974, 0.1777545843393572, 0.11531908500699267, 0.1400973179167317, 0.17467497217078365, 0.15425597107218159, 0.16101940895520872, 0.12966605023510996, 0.11732982832097238, 0.09046173819731321, 0.07251491815212273, 0.1482210521616282, 0.14370214464443345, 0.1698978777013479, 0.1288798295201794, 0.2677534292301824, 0.24293184340480836, 0.18301838978884682, 0.11862033407293981, 0.17621623382212656, 0.07258153715801817, 0.10951608389375672, 0.1479538100501222, 0.10851839226820778, 0.16347836733104723, 0.0727418487170531, 0.16326438365203721, 0.22118279109558753, 0.117786462689119, 0.15148804943648078, 0.17733774057799773, 0.06668361009008462, 0.1030347808714836, 0.139838257624257, 0.1416133599536073, 0.11999687149880395, 0.13422631117845737, 0.09637621276441122, 0.2123989495298555, 0.10441871870669628, 0.10295342233392502, 0.22143754597392776, 0.16420160029684344, 0.20458679856552234, 0.09623270151355574, 0.19386794147712572, 0.1484735087761956, 0.07362875636787185, 0.18943664377495167, 0.08129741140310803, 0.18713202147233873, 0.14037260395144263, 0.2033697759672519, 0.1672019070434955, 0.22856305233172833, 0.3875649840601029, 0.2175331941895908, 0.15274212004676943, 0.08569248846822208, 0.1942657402926876, 0.08382147193075189, 0.09214226697241107, 0.08944117118634524, 0.1384089827056854, 0.09425417985767127, 0.22277539595961574, 0.19982295741717662, 0.12867099395202053, 0.11892981827259065, 0.2733069844543934, 0.15150617507676925, 0.16063440380798233, 0.13808512669657508, 0.16352574220828472, 0.07537933622276591, 0.13548079547622513, 0.13901019318690225, 0.2652416107875686, 0.2198975866720561, 0.05611485643913189, 0.1510015529610457, 0.09354741778224708, 0.1674705127915067, 0.15936577752713235, 0.18474766473856666, 0.08396973292673789, 0.11803117415477192, 0.11806797701865436, 0.07365831970086983, 0.10971620138133727, 0.09786469861865045, 0.14155706781293118, 0.12432768144795012, 0.12150718319800594], [0.034583350117768974, 0.030941655408711206, 0.036832032680150964, 0.04860519529170087, 0.03990978708550815, 0.009221179136675934, 0.055752638577213215, 0.020385662867357175, 0.007565086651142808, 0.039101981843310984, 0.07470648885974962, 0.02125581809049172, 0.021426383736393145, 0.023349614911562493, 0.03177342005074024, 0.05010764309836011, 0.03575545698103886, 0.01211486080841672, 0.017566823197769064, 0.08248532266025582, 0.1114849221982783, 0.026557569790090767, 0.005359988745992943, 0.049508623628606724, 0.058834882257806684, 0.02174851221723422, 0.06918174620237082, 0.039234235432119145, 0.028176953257512183, 0.01259645815157602, 0.058650798990481326, 0.024503419934321317, 0.03661639808166412, 0.05681877249791738, 0.014344431392307726, 0.036956361089382446, 0.036237307133213166, 0.014817375772362276, 0.0157836711995544, 0.0330548016955295, 0.01812655576354554, 0.04442186492885794, 0.018362840262031364, 0.07369306178823595, 0.05221099495106647, 0.04717185244625134, 0.0733489963796831, 0.0715276989484987, 0.061305056160856644, 0.04508619339415624, 0.055336055285747976, 0.022724864463652336, 0.0589461335461707, 0.08269545291700671, 0.09015189393633798, 0.002598042835503997, 0.04284927411185157, 0.015529343415231956, 0.016812845208351652, 0.03033425876750581, 0.00761756558917583, 0.03891456992395463, 0.07773505658992837, 0.01098325222565402, 0.043763500458050164, 0.03742287416131266, 0.019105683163469358, 0.01577288659680034, 0.04574541205299958, 0.045689782578377955, 0.014522303601786976, 0.025078472343363592, 0.036439358992802526, 0.05040159103490653, 0.04588752519339324, 0.03025155574564011, 0.04988737366793137, 0.005044165647573649, 0.024951165767326474, 0.07188924648348363, 0.08132118311139845, 0.06718271637275335, 0.08113274846466319, 0.026683589338415095, 0.040231666587773836, 0.045057227609739195, 0.01991887783421384, 0.0792731159937478, 0.025194408259384578, 0.01156237543440394, 0.034845237274684256, 0.03665237357058833, 0.06470681979290901, 0.005899685239719768, 0.014312673217406677, 0.03805810660724679, 0.0515319422758635, 0.025026636919186964, 0.042413297304583174, 0.009743011417618443, 0.029944714549328053, 0.022227993242502696, 0.06611621472984552, 0.048268197044249506, 0.05273658489327758, 0.07704904017549369, 0.010649959928536368, 0.038907012466581604, 0.013544479508944338, 0.05883364502580897, 0.02784868075151838, 0.06176675820062238, 0.021969980575264465, 0.043958492817417275, 0.029034971732706315, 0.0701198821526862, 0.020657901787349296, 0.07884711748169315, 0.06175293031358912, 0.02835664109537198, 0.0512414877002518, 0.055804092872647516, 0.019457461162199898, 0.02017751869354998, 0.03149893074747055, 0.034977322324149074, 0.03691953524286228, 0.014862474410854762, 0.018611860972258355, 0.02547878967297654, 0.021600046292728475, 0.003485853033658538, 0.04410308425224597, 0.059016640448281844, 0.02372673126838861, 0.08833279517749626, 0.08565285107901982, 0.07647576125999613, 0.025135024953933976, 0.0917222592679243, 0.05546167455313187, 0.017680985620245337, 0.05328516513409634, 0.045701021088227156, 0.002341118970728149, 0.022192862365515004, 0.0409617790231301, 0.06356074076686656, 0.034080060995033676, 0.007863734058299734, 0.05510047558815249, 0.01500927983978463, 0.02251209886444192, 0.027368937341135838, 0.04435039275596219, 0.07433733407167659, 0.019829021466355172, 0.058114334430185065, 0.056552124104552695, 0.048288348987097704, 0.018044634151362607, 0.02552278227202835, 0.02904022709586688, 0.03280790687929238, 0.03946483938864643, 0.0630684488362843, 0.047854172486451366, 0.044420371057405594, 0.058947945344111616, 0.020388748286472216, 0.06812099787977434, 0.026903604044609015, 0.012875546855221113, 0.009982093094637799, 0.00845488915670543, 0.00844602839225122, 0.018990498013614167, 0.031908965902403, 0.045074342013967615, 0.045839874524502985, 0.030513923622727878, 0.022987981191686085, 0.03715123470512129, 0.07334212457100231, 0.03552557314716039, 0.05691357970898671, 0.0536403120044739, 0.03587962834224586, 0.012878889871400692, 0.008496453257037268, 0.08249627771757304, 0.015262171209249047, 0.02040332310923165, 0.025965184641761646, 0.04652068154105256, 0.04940927734658603, 0.04387365624068245, 0.023474958387293646, 0.0058537515653898165, 0.06383150305238462, 0.024233588445631248, 0.014063802851934828, 0.059039519664140484, 0.01351307373448846, 0.038862751736756296, 0.0440484851658825, 0.07898348879309432, 0.038513507573835315, 0.05989481086632418, 0.055086456179138155, 0.057330710753317804, 0.020644868716537472, 0.02204996781543859, 0.01787164000674121, 0.02042344632378269, 0.07459091683549267, 0.01918503263544652, 0.06746698095793686, 0.02343255733590453, 0.021524276366577517, 0.07566083523054278, 0.02751621774457876, 0.03528446612519122, 0.05213723217527713, 0.02234734016500654, 0.008387974249349247, 0.04940448163618003, 0.0280114782658676, 0.05701435091454656, 0.03996627840904459, 0.06986850572209205, 0.05041473327324756, 0.0230736221607414, 0.012443094052404407, 0.03158192296752767, 0.06922646275451107, 0.008766839201862534, 0.04709917368487485, 0.0511007075528464, 0.07833756942061648, 0.018888556608749975, 0.028324831209536043, 0.04277558794485466, 0.03221490503018422, 0.01590750643968462, 0.04447280977582259, 0.024819814247049155, 0.014187827698826311, 0.020789615284170837, 0.06550545113221293, 0.05764265792564519, 0.007395714187183448, 0.049069992326680696, 0.029117852870014407, 0.013717126998779996, 0.03507563055703237, 0.022231220387883728, 0.03812156550045456, 0.029924736891482628, 0.00838639993866485, 0.11216601266735986, 0.050419325970353625, 0.010223063178390506, 0.045139861683691704, 0.05449235116341903, 0.09691880985854134, 0.016456742643288547, 0.03465043643729822, 0.018711613280878916, 0.0716605309336897, 0.029185525246805726, 0.019697844231080626, 0.026445611785616607, 0.009801771319020661, 0.03448483887158575, 0.02366715069529751, 0.009634329396630488, 0.025556909573835232, 0.03238509912344237, 0.02870804179579981, 0.038467377589474765, 0.02993875630049696, 0.03800014439489573, 0.0825391020325403, 0.06990220592988115, 0.008407829333126785, 0.0373764913679371, 0.0425060284173777, 0.04084873508902327, 0.041732030635279034, 0.008064091427161569, 0.026770810363814238, 0.045760576763460716, 0.07781283749688057, 0.05418918718914351, 0.053783869220604824, 0.07003496130627972, 0.03519570334784446, 0.01616833352243468, 0.05806476854148412, 0.04767182823871413, 0.03857030150210185, 0.02341917186464754, 0.026792425534597812, 0.06990721614490594, 0.08887357664324584, 0.05889343052741982, 0.10016067944947751, 0.04959146837673841, 0.016903258905175234, 0.09772940749122251, 0.11746505816136638, 0.04465822986657581, 0.038487368653858864, 0.05438805978384711, 0.023566706992325284, 0.042831355315302654, 0.05827512862461229, 0.023748390489227833, 0.05834685743696267, 0.04159954338965397, 0.01040094687918862, 0.042175220160354535, 0.04334088805462084, 0.04289442733410866, 0.041622162135618354, 0.03082154814394251, 0.026688256729093772, 0.028637559791546197, 0.05748156878736712, 0.014629625816709332, 0.02357575449071104, 0.06423863664930386, 0.09911998730873871, 0.025941669572925857, 0.038784660564194766, 0.014824832680695241, 0.061097932799208554, 0.008591814924241796, 0.016724107328862432, 0.04914028472417305, 0.023116184090594613, 0.05310982676042665, 0.05801970724977794, 0.051645997446030385, 0.02244524237128996, 0.054647579729076357, 0.02539803634487814, 0.024419615661064466, 0.029615476772549654, 0.00512319288381766, 0.025787774000256777, 0.1237341701503723, 0.0844300368560418, 0.11825179215520622, 0.19708630749054495, 0.1380497487562318, 0.14384342657942928, 0.268104174925435, 0.07510504610235653, 0.09021262172609569, 0.1926505358348931, 0.18718045355091173, 0.1442437228416243, 0.10133423421892429, 0.14391703230719413, 0.19791071002762164, 0.12191960663204232, 0.08412481210524998, 0.08105027143873515, 0.11931127643272763, 0.13136151006385205, 0.26884642219351185, 0.1585258846922267, 0.07440056696894669, 0.1550347913777636, 0.11746083701690359, 0.13506903853868285, 0.18663872213613603, 0.17793945667724456, 0.15090865713934745, 0.1109048174393754, 0.16296416911627018, 0.151495786924516, 0.15140675218595614, 0.15039790632022967, 0.149323774441596, 0.18936342109114895, 0.10161538848713522, 0.08970357928304903, 0.10703801928508667, 0.13128241914654934, 0.09779758931648347, 0.12645001312898052, 0.1158281427717978, 0.1311890636720965, 0.15891133417044917, 0.15260241625289764, 0.10973518504010094, 0.15273782995439347, 0.14461524484138336, 0.10679170669567202, 0.12701437478103947, 0.08138350436403867, 0.299249173051888, 0.23203769007757788, 0.34039339591418544, 0.11099542265818005, 0.08622377810458984, 0.07883409398698038, 0.21934382767686922, 0.18219127530051818, 0.07290361584314416, 0.1540057514343531, 0.24947857033581505, 0.15855344853574233, 0.1314557695220555, 0.14640612858197383, 0.11862062518635105, 0.13028321066691032, 0.17943306765969724, 0.10343448724597694, 0.07573716823131808, 0.10233812349578066, 0.1821671894961788, 0.17197651938805658, 0.10846938562369156, 0.10274481659214343, 0.10197199475500854, 0.10320575637442451, 0.19288422329531563, 0.19804996949049736, 0.2255105596756743, 0.24275938169129435, 0.15355458693398585, 0.12412122841323577, 0.2878864343848921, 0.10429071307542825, 0.12667367249847422, 0.2423630231210301, 0.14364448886725212, 0.150113794952631, 0.07436227789449115, 0.1192662611062969, 0.09994246696512546, 0.2047035350434242, 0.08909908994551628, 0.1808771740404829, 0.13144573377024743, 0.07921025081868134, 0.11399250417467087, 0.2073019827085157, 0.13512916111898038, 0.06649484602554191, 0.1631507574911079, 0.104726180434227, 0.12210535997104262, 0.17530333280803698, 0.18823299707183916, 0.15327294236950337, 0.11386106646950207, 0.11680849782762029, 0.135379258182741, 0.2140043174187022, 0.1324363007781006, 0.19043836502298234, 0.09258131196181621, 0.1907387634198512, 0.12756080997567024, 0.2782499369594359, 0.191133972858229, 0.21995355705580405, 0.2598502823422032, 0.18723239431217795, 0.19638712968557112, 0.11057244253254707, 0.1744571886956692, 0.13883684281139605, 0.09472787500389161, 0.1412760361187881, 0.13241494224677164, 0.17519350644321213, 0.12687270214120228, 0.14599492322773705, 0.1147920701412424, 0.19421690984839396, 0.15598432671639229, 0.29843181852371464, 0.13280537129650194, 0.16630805097520354, 0.11861495613571137, 0.13470692409863397, 0.15499299362061486, 0.2404294172001462, 0.14108825264678848, 0.13658796106615376, 0.18605002953160196, 0.14988023006627638, 0.14892050575825477, 0.12054787257746344, 0.13494099460301862, 0.14477420808567157, 0.10663524855889621, 0.2148758956501561, 0.11615678683043489, 0.17595326648123805, 0.1256348955775461, 0.08956268805289462, 0.1839897586333175, 0.23600856893725936, 0.12668697178483973, 0.24003013217401123, 0.1003873648662721, 0.198976660087224, 0.16765651893952202, 0.081506407849731, 0.1454160978356677, 0.18701658734390814, 0.12702000552728293, 0.1518857869650087, 0.11234209797675572, 0.13789985599296709, 0.23471314490081804, 0.08298099686902377, 0.12420712985218534, 0.14754277323522877, 0.17328485966690127, 0.12920247511036936], [0.06417489813400373, 0.034714128987322894, 0.0009890224429264275, 0.0683527241551107, 0.062207775866432544, 0.07805859850298974, 0.025388335756536935, 0.037465664002323346, 0.03356356068604416, 0.047112086096838604, 0.07360337587494044, 0.03176055551927177, 0.0016075775737033017, 0.044356437189684766, 0.04651107096804246, 0.02102621579392543, 0.01764419424768177, 0.018720319870138363, 0.016984764914659244, 0.051183923853621374, 0.05960162518726242, 0.036391260162476576, 0.02300580422724447, 0.027334697041360122, 0.04832654996144195, 0.06925578093937329, 0.03973470918173271, 0.03103936417779375, 0.03980816169191272, 0.05410089555587019, 0.03218093669162162, 0.0357269010536613, 0.022216500008418676, 0.0038370780126687383, 0.05823414675110291, 0.041787434113963, 0.018482372960856846, 0.01057065546422476, 0.10337159142739351, 0.029771189888819095, 0.004862084742560382, 0.022270302363340894, 0.047541252382460146, 0.043643167197343805, 0.08495823915807471, 0.03586408441826221, 0.06030493603658773, 0.09298569147264765, 0.01352810054912322, 0.015707839986369494, 0.020329998918778954, 0.04555231193080545, 0.04437896783553785, 0.08120059321123747, 0.07734572304592979, 0.013287314326472342, 0.04510251872782265, 0.0392305773622807, 0.02217471182736899, 0.11911742554436769, 0.09780338860207027, 0.03450833095778381, 0.018298793396341707, 0.012662423109906095, 0.04766502920838614, 0.03666392234604686, 0.0692593432482212, 0.06192461061742037, 0.056799375151674596, 0.02504036713000988, 0.018947231282870618, 0.03149636052248459, 0.07916122885240663, 0.03176173337945535, 0.056628625644671346, 0.0033074445626322902, 0.025162713286737283, 0.038585286181900776, 0.04276321945531715, 0.03467186774697996, 0.02887156326323748, 0.04277154683105407, 0.03051584650341782, 0.02347052465343187, 0.03901613020007649, 0.011067783324829033, 0.050803101546461546, 0.06302929408247433, 0.059163016867974115, 0.0169664841415661, 0.020329671416191325, 0.0582853329157637, 0.06356232656886981, 0.066807241359305, 0.03623383292447656, 0.03127837977972964, 0.0830625928938389, 0.017369618759520592, 0.06907051789664453, 0.059050038051340854, 0.06542681986766477, 0.04737247172142229, 0.08273460000993745, 0.037434392293254216, 0.02907547480126302, 0.03464375232015887, 0.024005020367762735, 0.04247521253062352, 0.032590357060994835, 0.011530701529174563, 0.01746870265642722, 0.03509339613599643, 0.05766335379091963, 0.03726439355241676, 0.05373450251476419, 0.05641602858480427, 0.03209401252529314, 0.046114716228217854, 0.04144562483434716, 0.043825476971124454, 0.028322193951856707, 0.024930054299353112, 0.013121743573837224, 0.06499653126323415, 0.058236402880039916, 0.08046364727159662, 0.02366302914226488, 0.02995156912103055, 0.014963927434667226, 0.060426556325006875, 0.041493547464450525, 0.07100390165203041, 0.09729311275746554, 0.050150532530800956, 0.049391006149591944, 0.006289045117990745, 0.021570684057810617, 0.020264900597413222, 0.06635495070968905, 0.030002791674867756, 0.032036584659269264, 0.12315503832313324, 0.0848253152423328, 0.0439285924057326, 0.027923697996283733, 0.039479402720087, 0.030408950424903346, 0.06693782104599862, 0.06009124347098893, 0.031842683975194255, 0.09659717550441142, 0.008760375335001418, 0.0294535142940379, 0.04549438419241098, 0.016406360870948242, 0.08597381893665561, 0.06535067838887054, 0.00617767317077866, 0.05233896993881753, 0.010896263899461878, 0.04107110360036454, 0.05154396219539547, 0.10994506248783682, 0.07648205084185447, 0.1032393646516627, 0.03163120348847682, 0.041661171332722714, 0.024253711660182285, 0.048330759614585876, 0.03605205175136367, 0.013709637531710249, 0.036569808444549004, 0.048046506520721226, 0.031168170370942647, 0.010655190393839394, 0.07933923704249245, 0.034419196627793774, 0.051052984105603355, 0.051077663628084045, 0.030530111060567924, 0.03288274600861534, 0.05542256576459735, 0.04825436532677663, 0.08837217209680427, 0.035324904076274366, 0.01367143943019572, 0.09383908277677913, 0.041252425120722865, 0.01363976648257625, 0.04838002672899635, 0.03651731226953768, 0.033815404430272124, 0.021716411217987057, 0.02679196205140362, 0.04006461728544485, 0.08784938603639604, 0.0660371391343013, 0.012976563208916736, 0.006456716866758202, 0.011698090783019942, 0.09342313533829105, 0.09658012238721694, 0.013963029731155164, 0.07431617472320795, 0.05010372455862742, 0.10704446208452988, 0.06462729220548946, 0.03140379220337397, 0.03794735327603356, 0.022876536466121193, 0.028715830994769934, 0.05667362564934358, 0.0062005887758137005, 0.04024067961220299, 0.0893385766915256, 0.04095919347638565, 0.07848885646390338, 0.06023338725489955, 0.037091349612080285, 0.04165322700094792, 0.0916641285162299, 0.00656975026715607, 0.0889862145507528, 0.03292031496042206, 0.044487909368810155, 0.03860434261901725, 0.022183119642337965, 0.03467290962655698, 0.05499766275827443, 0.04494777662799724, 0.06729958308560234, 0.08625936288867267, 0.028219859926931323, 0.04073809284055906, 0.0665635334688329, 0.07146769128138981, 0.09685847277362501, 0.055642835195026094, 0.016698763225107424, 0.09472648838474866, 0.017946170785674648, 0.03456010317970668, 0.051420311773976976, 0.03875760233870918, 0.03799223070663791, 0.0359538201272728, 0.08117253141057107, 0.041298160569802414, 0.04645652550783369, 0.019555531907826662, 0.05602404437658768, 0.07057316871660371, 0.03967310805174132, 0.03725443823984073, 0.029515841292337548, 0.07616629238210379, 0.012521441864420571, 0.011267137597315015, 0.03427033808322684, 0.01946910761386877, 0.037319337378346154, 0.06350228059736472, 0.029726800839266473, 0.020351313400052248, 0.010423968778923156, 0.01221403663587426, 0.03536935632808074, 0.0860158771636986, 0.08224436502543189, 0.04533521410438322, 0.11265818585431385, 0.03815456473779294, 0.08669443188175079, 0.021703322605800726, 0.04368387327920045, 0.007232447443980604, 0.02376092368766906, 0.07858922164286337, 0.025248978617450884, 0.04927565246039341, 0.05141385748321491, 0.057368337161718845, 0.03997764332340129, 0.01484727235360732, 0.07589016365067613, 0.056334620251530604, 0.02124582255829967, 0.03208202899493758, 0.09244694780077665, 0.05454945918773452, 0.07859534268537838, 0.021549721976982492, 0.03857943710059889, 0.05561673457944586, 0.038979652923561876, 0.04702312413663153, 0.04904522853452833, 0.022410207255292806, 0.031139005403665286, 0.09669120513623762, 0.050523594367287816, 0.015617147625063457, 0.07704314129847674, 0.11145634711870264, 0.02612003399389646, 0.035332879051566124, 0.014550511916768889, 0.04112964803953806, 0.0477371487255779, 0.058589450669504946, 0.09596434857455954, 0.08519119117408992, 0.06965702715059442, 0.01802986397618248, 0.051965360349464806, 0.003054857473715299, 0.09716667760644229, 0.08062931378522227, 0.0684758038410256, 0.02630902405437683, 0.020380277269249483, 0.04488476589622517, 0.04102185180771255, 0.009874881004854556, 0.03555066252668058, 0.015837389284804944, 0.05724210502399553, 0.02872320459104113, 0.04261963542610888, 0.05047137781436886, 0.02806443792407311, 0.05194237388129677, 0.033750489970008214, 0.01986520954467837, 0.05259261782010717, 0.06982542859810976, 0.038278743759879184, 0.07674657334122928, 0.0899705456029023, 0.017504965428323034, 0.020853192921006874, 0.033823670518975106, 0.021734172966511502, 0.014961457758721326, 0.032207849360401594, 0.047020649672636104, 0.037026779891382304, 0.005549835867338604, 0.05023270312155928, 0.07503479583970002, 0.08192902791403955, 0.00629049206655773, 0.17135142228536068, 0.14828129731599363, 0.17864559056057086, 0.1262456898186957, 0.1038788182420596, 0.25824866828418547, 0.12249620270825202, 0.16918708600344198, 0.09532938425939891, 0.10416412470682014, 0.2878302035312499, 0.12014613606997075, 0.10646876999207082, 0.1458103420032609, 0.1694454568167848, 0.16235312206610558, 0.0901336074175854, 0.12487090673417815, 0.12474971928543623, 0.2298797276471892, 0.1614390565983711, 0.11978117944372278, 0.08289893353057486, 0.11335416141176417, 0.16030711572497122, 0.20348257475322296, 0.1060660069267596, 0.15476874436341947, 0.16327446536912074, 0.17269822017800424, 0.14305182792727025, 0.15044250795918127, 0.11553586490692631, 0.1112141024561659, 0.17539032975271826, 0.15663700298436228, 0.12726317715620802, 0.08402674519006284, 0.21560518071055415, 0.15037820253881717, 0.1548643214928527, 0.1250481871407359, 0.1353677515421183, 0.14576272197788762, 0.20185243158090502, 0.19821936685231425, 0.17326051339266763, 0.15634757496656912, 0.1077845030193848, 0.15961388276228983, 0.15383413241755578, 0.12496626935899259, 0.1648412377483422, 0.21884219330405036, 0.40655443444848066, 0.1404289573791527, 0.11302393155112384, 0.10547790420992721, 0.07602378470642913, 0.1650914420644122, 0.13080917599220432, 0.1156522106799868, 0.08962998887704265, 0.17207856229957075, 0.1318962547567583, 0.12358650670296724, 0.1952403573499572, 0.13375548886195307, 0.125489660628861, 0.10403176003526296, 0.11816449643623446, 0.19216969308833923, 0.24975394830107692, 0.13023571321560493, 0.15114013826654804, 0.1206848337765663, 0.13805190912417828, 0.15277853986668974, 0.13797519307944084, 0.1192671727509268, 0.06509610737163214, 0.12244496674787615, 0.08198921178137103, 0.0775052608561612, 0.1296971840483527, 0.2181103954752607, 0.13104444159375084, 0.22390525307386155, 0.10248029409276863, 0.13110120870894001, 0.18479614278241513, 0.21806061508194094, 0.15226827934384346, 0.16979793387074626, 0.1992648623643383, 0.0785921251160964, 0.1379676700960244, 0.19704743618926696, 0.2013764151882741, 0.08755216690441293, 0.1009210063925674, 0.13660817046559628, 0.21791164162418536, 0.08095587408470531, 0.11397635504122704, 0.1527443876670253, 0.12291486975887131, 0.11957963703260308, 0.08476692402074415, 0.09207368678142948, 0.15516812132010538, 0.12133877408961136, 0.21042106372694816, 0.13136298095266666, 0.11360487900674344, 0.1327317349252201, 0.19531174142274166, 0.12235998461443572, 0.2010547501906272, 0.08854591317715184, 0.1100792351268953, 0.12179306422870968, 0.08695920719014061, 0.1546189128871887, 0.11530423822302012, 0.2303048604798894, 0.14646421336839277, 0.1533009045787396, 0.10935424781975248, 0.13644644930478067, 0.10643667090804347, 0.17386354716314426, 0.19483891195587574, 0.12738286307261837, 0.18081461530058615, 0.13826753223134627, 0.16651268838153732, 0.13886843627739337, 0.19933304418959927, 0.11632248398757751, 0.15879911761130058, 0.13611309380540926, 0.2523447197651671, 0.15256694638200347, 0.15102876440411614, 0.1364963522721683, 0.15745368335516224, 0.1368117200270776, 0.12812439787892566, 0.06452862008084213, 0.194191828129753, 0.04367161204197234, 0.1494011646437068, 0.14779115426203898, 0.2041055880967648, 0.21810913909106486, 0.1605849298498323, 0.12280829160684541, 0.1376936251237508, 0.1567593165823529, 0.14171144985143216, 0.19387963197885022, 0.21297331629020555, 0.2158638426373082, 0.14503155234119586, 0.08744280019234266, 0.10071058502240528, 0.1434891722014835, 0.09416869210620081, 0.10054730870310338, 0.11450461863029389, 0.0826801311585211, 0.12609301615626584, 0.16976054878004138, 0.19218967266140446, 0.1360488649938376], [0.048867545931810336, 0.05645489988608226, 0.04858393252136246, 0.0044013350458455185, 0.04003990328900757, 0.021709796048760898, 0.03927179672304661, 0.08955490459958393, 0.03646099714622383, 0.020926143643596483, 0.04089059030276634, 0.0491852694070868, 0.09162550236308768, 0.03837054407584571, 0.06669017546359571, 0.005116379968146043, 0.035193542979898, 0.09719400396270138, 0.05153550841515103, 0.044839739078475584, 0.03325101213469621, 0.04372195167947681, 0.08324994735660092, 0.06986859765264296, 0.0472014119488097, 0.02402295448607014, 0.009769064152703412, 0.0060965664846251814, 0.09229846463929262, 0.029820681083947424, 0.04167017669627263, 0.021336659518701416, 0.07763301367841421, 0.056343165962325956, 0.04080389596281513, 0.0267604949899138, 0.034282538033421, 0.08771417917863977, 0.03465468822527797, 0.0936310745835785, 0.028244390062266783, 0.07188783688170296, 0.02927635837676785, 0.04967459274696247, 0.025051245578534664, 0.0450709022791876, 0.062353907137989044, 0.05850152292799565, 0.0065098484159417215, 0.010185239502348968, 0.015681229922319614, 0.09276885028568008, 0.0705306968020816, 0.05961184480017232, 0.039332762000060854, 0.02329360430819854, 0.025285358217755155, 0.05575267305116981, 0.06969234380390375, 0.02029111421096229, 0.029471423514487765, 0.030160174862812125, 0.025761359288627585, 0.026437575523290905, 0.010021548537958053, 0.03807903995977775, 0.04847350477751705, 0.03137727981553443, 0.06409193081180416, 0.030832924549618078, 0.05137992361860891, 0.02368138843937026, 0.005177205434114102, 0.04716705673584535, 0.052927516986646, 0.041762586052138964, 0.044554225769975496, 0.08012077696020566, 0.021398496220729524, 0.0645999888318681, 0.04462058430597667, 0.05651128778774893, 0.05120069351828387, 0.01898772477532827, 0.03573039824503564, 0.030163643325889306, 0.0619440347767405, 0.010797155104697713, 0.058462349021987575, 0.05031432212901212, 0.05173896604608144, 0.04985136370505056, 0.02724048737887173, 0.036495800520623886, 0.009210700011481682, 0.023131754827655615, 0.05973296713144068, 0.02414973246143951, 0.05385465574480834, 0.017394047388206088, 0.03067079161654317, 0.05149633833958257, 0.09505063550727022, 0.0799448372075154, 0.03867233675273676, 0.031650348025704586, 0.018453604444080306, 0.06827487430024533, 0.06155375128371581, 0.06942149341827439, 0.08860291777959756, 0.01377188792121747, 0.05226400057454744, 0.05334939394566802, 0.04054493909221023, 0.06332894171317739, 0.04084576266787706, 0.04872346394545129, 0.02044199139720971, 0.013290403576027001, 0.06122341034032645, 0.03643451731712107, 0.043094698039274064, 0.022635553933439717, 0.07134848800037177, 0.07325542640061149, 0.015858978600121074, 0.03434527680397995, 0.03046192348964753, 0.02123156566202881, 0.02101299311635235, 0.05089106376192743, 0.01849756639961514, 0.0449927996153072, 0.016466590703555172, 0.017917955767423395, 0.016917778186560158, 0.03256404577123542, 0.035629358908702294, 0.08912907462687263, 0.08046078210275981, 0.04460607843113042, 0.0337506661702308, 0.009689258858411303, 0.0536973855548328, 0.06447494029998779, 0.0567951693289703, 0.004882782044249677, 0.03764271458250381, 0.03273160069159443, 0.18449303243429432, 0.1203513173987308, 0.02010174110651978, 0.04572991409429139, 0.05052073685933025, 0.059935264139165806, 0.02543018713984038, 0.07709986244839045, 0.027895379556162704, 0.030479522444488063, 0.027239727036606882, 0.030483073262017102, 0.05013931317314987, 0.028489450097925244, 0.036627042873372, 0.04045333029822477, 0.06206817932487015, 0.01751251522481682, 0.03277553966449153, 0.01865066141040335, 0.04395100813839705, 0.06206737876298928, 0.04899851632334533, 0.02882221379437514, 0.06987289540589818, 0.009868212209473695, 0.036079722847188675, 0.054185663184691826, 0.014591079145189256, 0.02338175421520587, 0.017453878855092392, 0.03587068809616951, 0.07682624648535445, 0.0554912110730525, 0.0467659714030883, 0.07510515335466593, 0.05143856381877296, 0.03295792604706461, 0.04777044290676714, 0.05502652512082169, 0.03330260432595688, 0.00843982308006455, 0.011769517948250137, 0.03947823443600247, 0.015060823192940125, 0.017042750109648033, 0.015362028854959195, 0.042883058589312344, 0.019637367335118113, 0.03143609813114088, 0.09054988427388092, 0.0069231193347443504, 0.030058842497847738, 0.02175252268751783, 0.06701865864376869, 0.018975988308328296, 0.01947533207825355, 0.02121889648298102, 0.009063750941066012, 0.037371297291810476, 0.05597445933568863, 0.0657738883408808, 0.031184394197959094, 0.10183216838706886, 0.026283032606325807, 0.03445275127887726, 0.05557850296158464, 0.0735866521755534, 0.021929590504676588, 0.05475463668605494, 0.007124571730532954, 0.06421669589115248, 0.07377775280826515, 0.026662006726368304, 0.07788369296899728, 0.029602853558777325, 0.024083538634342053, 0.04280804709020642, 0.04565436633363847, 0.052064342739721464, 0.021781632113420678, 0.011208180428272294, 0.029342448781995528, 0.03562730962350484, 0.057074032994287635, 0.04455257102005905, 0.04763389156470376, 0.060173437044384985, 0.009566044149499749, 0.03179814745371621, 0.02122623369007582, 0.05661708453009206, 0.02582122522947048, 0.0474000891910926, 0.08687000391223738, 0.031946328010470156, 0.05935119870569437, 0.06020393883509021, 0.01071269199582598, 0.04153833296450396, 0.05639171295408761, 0.021787768477694164, 0.010334850728301512, 0.0406544475305465, 0.06041407675272035, 0.12038625100807798, 0.03636199177332944, 0.062185459725198254, 0.029573462595562303, 0.023585828546915325, 0.10975781527738418, 0.028410692428869587, 0.030750504980284362, 0.014965348527766766, 0.020357581914492676, 0.04238405572851339, 0.017043114001412066, 0.03556164056663552, 0.005852942863824748, 0.08053739089518785, 0.015631214914573057, 0.012141173055786039, 0.053692367678928765, 0.031149290134048754, 0.006593594753799299, 0.008210096294210564, 0.05617967130796564, 0.05929672602383841, 0.027494522134563135, 0.011726095127092015, 0.02566053062647341, 0.009772524954901348, 0.010942493475252583, 0.06468598986224783, 0.060955011436054786, 0.07728679556279414, 0.04836814470529076, 0.007181585430272765, 0.0530480187866957, 0.006880891610748105, 0.029326303478991313, 0.0037532423776874863, 0.05375358576495802, 0.029129832569930344, 0.041808421092648665, 0.05606976833434836, 0.021156782074080362, 0.03722886239448863, 0.03500769004946755, 0.026818556793695016, 0.006196415511846182, 0.0647947283822202, 0.03970934784099941, 0.030905911661384088, 0.11534528521400307, 0.0035961661037177814, 0.007000070951518513, 0.06108631507583684, 0.02880041093205012, 0.05380530436072619, 0.020588578491081155, 0.007645800717235093, 0.07220350341090272, 0.03463403066439975, 0.025732269014922843, 0.00861856862977748, 0.06220252050327198, 0.04037476798158981, 0.06319325222002883, 0.04100566820031212, 0.051731979324212, 0.031947199435484026, 0.01821192668660754, 0.08817961589703638, 0.019691150537842227, 0.03117752430449811, 0.03194646973673615, 0.09538665699261813, 0.007337523584869961, 0.02852017788456813, 0.049527331495717655, 0.075594583946851, 0.00764574469705563, 0.05575106809696844, 0.02372404996065363, 0.02063559905265368, 0.06923645254104369, 0.013650915934704246, 0.0680255969505637, 0.009337409038937861, 0.11954333212587143, 0.029826344388927666, 0.056707459922519424, 0.05273445516884808, 0.024578107761279232, 0.01155792254834406, 0.03358077468170274, 0.02929474065651096, 0.043618391913872574, 0.0699823234050024, 0.06913807919068683, 0.040937551492524725, 0.13643592325670106, 0.19165135799877106, 0.10952627286314966, 0.0864888828307871, 0.17098180018365386, 0.07959345565928568, 0.14101104630577949, 0.19285813034061464, 0.1973140960739505, 0.18980880928856714, 0.22645611135709673, 0.08550940877607754, 0.20535038904316966, 0.09672150391364291, 0.12400253841112699, 0.10692613214374551, 0.11569587003079154, 0.18399429387382923, 0.12550511262229375, 0.07592680563609447, 0.09364847244033891, 0.12048313814786174, 0.1905596673849129, 0.14078092881508414, 0.1931685338457746, 0.17572394572198394, 0.31291694770897593, 0.07493521973130203, 0.20350350427531427, 0.15553930624117776, 0.2067516251437126, 0.12787151225512067, 0.16893187147234717, 0.17353155530027806, 0.09778530126617802, 0.11615400593126975, 0.17066986450264532, 0.2509071404534963, 0.09654515047347355, 0.24083245605711015, 0.12915223506429505, 0.1999512924662521, 0.09745053616502593, 0.10257404793294207, 0.08796103569048067, 0.16578121230967585, 0.1523842956990965, 0.15789392344172926, 0.1702215498493564, 0.12844967115069592, 0.1688407070093578, 0.1462414503217705, 0.22118162664194263, 0.13495234802605646, 0.11524803035201565, 0.15665938807350976, 0.11483693991096751, 0.14115038237744762, 0.17664158115944556, 0.22313568711040482, 0.08409880342022066, 0.13717933497842283, 0.14049729242199852, 0.1923928851441991, 0.11300105616570481, 0.1889344731405858, 0.09548583473529547, 0.0654471365194167, 0.1806355805526818, 0.16397025706546922, 0.17647973742456208, 0.15253034270098134, 0.06534780555915448, 0.1363432419396216, 0.11305636005295862, 0.1332103406950351, 0.11643775723754399, 0.11947181015726059, 0.16383931731745122, 0.2736487822426904, 0.10253522259693953, 0.2003738818870437, 0.1620803028345108, 0.12992987559447366, 0.22883170404501502, 0.15387710995010792, 0.18499151052486512, 0.10213512551760483, 0.1437635389306853, 0.13110358358150528, 0.06351960567577232, 0.13655498864189272, 0.0900482575619413, 0.12233877163981238, 0.09539740520619577, 0.1027341603091167, 0.14913501037705332, 0.1629910741241709, 0.1854588394804347, 0.19145333959210306, 0.2392304589551303, 0.2168770092389276, 0.1680959469728893, 0.1678964117121312, 0.115515441002865, 0.08275264138055426, 0.18731799697683704, 0.13783849235023224, 0.1616293068734869, 0.17363919065363947, 0.18094396158572168, 0.15639162502221524, 0.1593559562799431, 0.1467556025712721, 0.09291741771683579, 0.11352735090880625, 0.11719901114702226, 0.1285593596196944, 0.0974252246200077, 0.21970116172827062, 0.08181934710592031, 0.14807259964366115, 0.14757715526127047, 0.11554803804404314, 0.15009307993515847, 0.1495874312616164, 0.13258423235627914, 0.12098009938434248, 0.21401226941135623, 0.1719113406274588, 0.10278947185724975, 0.15945003187704473, 0.11180679403966474, 0.28741173566349093, 0.12301318948307347, 0.09500814827098962, 0.17033051819570605, 0.1914223896399621, 0.1123822026795918, 0.18702964148213788, 0.11904987957208388, 0.14631922356784344, 0.16664679973356186, 0.16803959354517922, 0.11108254983780846, 0.20308528155569108, 0.14063621480618754, 0.12491019172293526, 0.09187633487125559, 0.12551497217387925, 0.17049861320805165, 0.2862379357459084, 0.13339594847732975, 0.17449491086506075, 0.12138021944631493, 0.12029312536000245, 0.15296290658654707, 0.13985193995458467, 0.12396249499532486, 0.1055988158670164, 0.08089804210730138, 0.10840808326799063, 0.17182748464326705, 0.09114652887106904, 0.21554504280849812, 0.09844011491945676, 0.13643518781229375, 0.21630561489972377, 0.16958774998784068, 0.09018356401112773, 0.1159883930437988, 0.14672364138307112, 0.146787119428477, 0.17301659099757674, 0.14320001997534307, 0.22157035497648103], [0.0810769466202586, 0.036824034722221476, 0.042612200542803735, 0.05014364923080129, 0.07118344201796478, 0.027130563337836536, 0.08743385228538707, 0.030957831355232387, 0.01626663600965854, 0.021702665685405655, 0.0375939071208479, 0.0074263404671763705, 0.06732730780758205, 0.043038133937384815, 0.014429358941983553, 0.04544286860994274, 0.02831329392539638, 0.09956075599597347, 0.01595669694530267, 0.06130370784610991, 0.07550666003578133, 0.02395084262975762, 0.02488194780814792, 0.08176074137971287, 0.06257143780408848, 0.059799011571392904, 0.030197422057690642, 0.020372715981436834, 0.0400254127359198, 0.05392024053200599, 0.03494541093166317, 0.03836686302336954, 0.03315437014304823, 0.031509682791487824, 0.040396475082924294, 0.021602660567770084, 0.03817167531158175, 0.04295499424540228, 0.01913284289560491, 0.03672158578410745, 0.051728654502620625, 0.017205823415649996, 0.04186306614428759, 0.02341660355488139, 0.029920921773619713, 0.03212671490356086, 0.03457902555143641, 0.027304578294617035, 0.03518631110989279, 0.05715770128693792, 0.048657469301214146, 0.01655385194857034, 0.01997752378003732, 0.08050071826625256, 0.014439529716788281, 0.01206865517287365, 0.026038284751496492, 0.04019477945421973, 0.045119575675456755, 0.03670219226830429, 0.05081299940244325, 0.03131693506973886, 0.056717200730476654, 0.03830476776666699, 0.02897412328410053, 0.05492344032973052, 0.09074159011605287, 0.04833290849121348, 0.06886247905992693, 0.017731871095395858, 0.049131168277874115, 0.06111089500688738, 0.031716026658672965, 0.033319144164242094, 0.03346006603791349, 0.08126282253332677, 0.010123204575070452, 0.03850044960516595, 0.044166056679621826, 0.012267116952927844, 0.021624894354552514, 0.06670763460739006, 0.05776225191150462, 0.037150752069728996, 0.03879718610175675, 0.04050150190690353, 0.06468055063798543, 0.10429710224871674, 0.027531154543882417, 0.013301032088366489, 0.10365947194757963, 0.03828834667201004, 0.03056560582931965, 0.05719560731743133, 0.024952171257727092, 0.07467325596559433, 0.026618577201940843, 0.07622562589183932, 0.060451281812763026, 0.07074608242199307, 0.040794369659476706, 0.006557302295996418, 0.029761638687623125, 0.061946045757541736, 0.08980007571799141, 0.02604527913424517, 0.034244168519733414, 0.02830638764275899, 0.01949163442928224, 0.03960443593020882, 0.002568118962376649, 0.09700163928491455, 0.04614960004184996, 0.06727082414492484, 0.05257822685844956, 0.04519928329353852, 0.020190703066726847, 0.017405877700976787, 0.0947185670356116, 0.05372971063479782, 0.012273043600632059, 0.02576224986583956, 0.04029717859661868, 0.030322708076827472, 0.0422745626119356, 0.010373580303313512, 0.011354963832174339, 0.039193812802794485, 0.018724479727567207, 0.04715628937006958, 0.01876024837275186, 0.0561225364705728, 0.07190376384964875, 0.014431927251749703, 0.03909545860463574, 0.05789239875852101, 0.11313646986720063, 0.008939099817296431, 0.029575295460921143, 0.011142877178386816, 0.06549826522748317, 0.025614691755524086, 0.07220950954022907, 0.010584163509549634, 0.019274877511986324, 0.018853318479452884, 0.027146099600940946, 0.023564366593716607, 0.007066245626417861, 0.025199686605182868, 0.018803750675532128, 0.031045741859763384, 0.06304278489082091, 0.059889455911733454, 0.054244740054972714, 0.04972169566298685, 0.04400822724546156, 0.08489837704767143, 0.05696352098077055, 0.08074639500269006, 0.01767716284150318, 0.010005796812624942, 0.01351764823700632, 0.062084412727985656, 0.013995012944383968, 0.08167231185061317, 0.015729484843060134, 0.04844563832927135, 0.058841991553744005, 0.019977079449041237, 0.013977259814348674, 0.011570593642611659, 0.05069720138224864, 0.04328502492318231, 0.032569703330556234, 0.06060859796801402, 0.09073716212785052, 0.03251156108754297, 0.019702609297969652, 0.03940839786082506, 0.03168933232495141, 0.04786081063831526, 0.008251749452263599, 0.018476799671207706, 0.03159947212665312, 0.06505172023729933, 0.06199046353539152, 0.06774468783048854, 0.06613113812261051, 0.02830521169779522, 0.061375038292739666, 0.016456654543177258, 0.042303708427014856, 0.05908359653286396, 0.04641036104951655, 0.06599933269523806, 0.033689608962665644, 0.03127116897714234, 0.010650819862231372, 0.05520603101279947, 0.03425367184043412, 0.022799617408083814, 0.06711653403697476, 0.050356131377479726, 0.01679686652947097, 0.005788612066798153, 0.047992294308759516, 0.05833470345204396, 0.01777169617613958, 0.06363335824120911, 0.06868208067551737, 0.05037593475032238, 0.021095138809253133, 0.04760429375774918, 0.020355274074620778, 0.0731708273111332, 0.04956299671903253, 0.06290106245526864, 0.04036802640785614, 0.05451533380114744, 0.04124290647826368, 0.06990582952576299, 0.04623972262526232, 0.019868137915768934, 0.05173917672026062, 0.09364072729142443, 0.02780501373983439, 0.03398880460149339, 0.03348250475321566, 0.06601577294209311, 0.02388675745967175, 0.07386644280725911, 0.05257969391682456, 0.05438986775134841, 0.04619783293756266, 0.1205937535832486, 0.02819685430656518, 0.015285021696810522, 0.03575698149600818, 0.05222479985546201, 0.0629985586349522, 0.024098023441770387, 0.06744761425521105, 0.05171525945526458, 0.03279037878758485, 0.04656141826642617, 0.032891571341503056, 0.03858112632447193, 0.05608327829489305, 0.0212100156087188, 0.11217743503831087, 0.02271648920742014, 0.01066019390559485, 0.036241750443173994, 0.0786063896732465, 0.057648495515628215, 0.04438776635534821, 0.06152372446752364, 0.030231549359497525, 0.030300887977524154, 0.037737862702699444, 0.018811382826477773, 0.08022069780816955, 0.11370109198915382, 0.03246841884608711, 0.0205187514920028, 0.0716525866019149, 0.00667401435484569, 0.058850158051016836, 0.048364111252369425, 0.03920998108843642, 0.04223196429290599, 0.02497508494754232, 0.0014516408555209639, 0.0231205488765432, 0.012128626450806135, 0.047768098677718834, 0.1263551178177999, 0.07334035490789721, 0.032023668416865894, 0.08164926026497157, 0.018771542423975565, 0.024411539179122737, 0.04575658927581484, 0.023822310313041654, 0.03114026561830073, 0.012564894371485759, 0.08065566720981752, 0.08062698487793246, 0.025857457357849327, 0.05400898415715464, 0.04046628484502435, 0.011204740693492275, 0.03411261590137597, 0.024686832874712926, 0.0857803664140163, 0.04229001077492872, 0.015400639686342931, 0.027487537327913508, 0.015134103333337173, 0.04178187997651197, 0.029144445697085995, 0.07318781914129373, 0.057797124233817866, 0.0054627958302115726, 0.05245074599740967, 0.04361736152561442, 0.009971290297295538, 0.06121408705028796, 0.06907169001116868, 0.04967070485074675, 0.11574452427486259, 0.011829773636324512, 0.010557553445499752, 0.04830105838576152, 0.0431482169416643, 0.0658020573938566, 0.017294687699646722, 0.07802101422942455, 0.02675973656286876, 0.02558560914269859, 0.027511420118952953, 0.01502961660134456, 0.03380137736037855, 0.03289908666404025, 0.02235132956787223, 0.020118644836569027, 0.042728906377188625, 0.020095321289714307, 0.04767103150727288, 0.09401247145668154, 0.07938513337003608, 0.057739514421911976, 0.03473117444363814, 0.05097654002207903, 0.030612620645232742, 0.062040458433330066, 0.03325984129802354, 0.01770682768115113, 0.022929413769874844, 0.04686647830831428, 0.00781700748296815, 0.02628692433298115, 0.02687095529249599, 0.019666970887732123, 0.01934067297336315, 0.030715927601821964, 0.07629078166979937, 0.05125821906051809, 0.04129845551365326, 0.014373019878422062, 0.020104855253931977, 0.2964440348648256, 0.11272102038586333, 0.1826215868875865, 0.11884281366703012, 0.1847912704632167, 0.1860524350476842, 0.11407884994461653, 0.15203926501975906, 0.09628959120281282, 0.2974257305745156, 0.12704049837925743, 0.10072633579012849, 0.2234703449592475, 0.14058415147085346, 0.1688609317305588, 0.10971050934805986, 0.11856074009331004, 0.2289922607521857, 0.1125910612303884, 0.19121133241682284, 0.17278943060626908, 0.14521150639460934, 0.1081704734373958, 0.20765974576915466, 0.15073745181002926, 0.1687474434654559, 0.13818773651315322, 0.13772517262447265, 0.14757939223800937, 0.15241480132024135, 0.1621425857827548, 0.13924057114749186, 0.1034517701895487, 0.13059168363050108, 0.21084193711078938, 0.1787442320417012, 0.09546510439606444, 0.12204002033198073, 0.17765073346034174, 0.2138415390565511, 0.1274290964788487, 0.12873654043482197, 0.1430166644915458, 0.1325414693283458, 0.10952106346526455, 0.1627798330399298, 0.13174202593584217, 0.13289690348169497, 0.0672694375257819, 0.10291242130821752, 0.0916391617107776, 0.08415366297647839, 0.09469374578686492, 0.162619904524857, 0.07881376967434922, 0.27849624954885055, 0.15326978608725533, 0.11967029587756242, 0.10696485022743864, 0.19770052614471606, 0.13127037624437965, 0.21263387805271536, 0.19065052541273256, 0.12351627176206921, 0.14155463165333196, 0.1397984516957114, 0.24887328426684105, 0.10801952347279557, 0.17865050884504474, 0.18740059657683297, 0.12773092746013595, 0.12984205127483414, 0.098854553164734, 0.08138382612096687, 0.24794049561023715, 0.14194253261291212, 0.09321230794152907, 0.11425106650999478, 0.12194471899420024, 0.29068133763728604, 0.13165001877613608, 0.20385593536400026, 0.21121491467760456, 0.18800197559739315, 0.15904817279548417, 0.16943350584516603, 0.1339137779488679, 0.132694594982651, 0.15495732456686037, 0.11821934833161293, 0.20052955095325747, 0.14086766528987116, 0.09596064836988527, 0.15560497529804707, 0.16270674825195344, 0.10180894060120468, 0.1550699548134881, 0.14967519429422196, 0.12351506134314884, 0.14315532640584056, 0.09210997636640265, 0.18832385509965882, 0.15043729856129617, 0.12651252590360182, 0.19132256838342837, 0.07912190555925332, 0.16546604373762686, 0.10970795061439277, 0.12338188461839192, 0.15215488300929148, 0.0758209476067174, 0.15722204901037679, 0.13101111676904464, 0.13950409007168588, 0.21344936332635342, 0.09753703515255645, 0.05380560313501666, 0.096824144373738, 0.14801405520448763, 0.18082367045985115, 0.10893037903212732, 0.1269544820271192, 0.12652672151283872, 0.1188949459502774, 0.11214342073447282, 0.19345883520380144, 0.16018232000210594, 0.14585299777888483, 0.07448841427122393, 0.17970102989385206, 0.09314879925260622, 0.10088662436652569, 0.21158778499211037, 0.11874913643564909, 0.1407100656820882, 0.20527405604239435, 0.22202237749532347, 0.052460789410096985, 0.16209825993545596, 0.13048112182126892, 0.1461804390794808, 0.08347844840177605, 0.1569066812554675, 0.16130050193638573, 0.11910385046634944, 0.12026548490769441, 0.1633042049023413, 0.09542930510736282, 0.12751755665146536, 0.09858495916330046, 0.20488460758520713, 0.09863429522562413, 0.1559473553131665, 0.12391574831018526, 0.1251882893003283, 0.16825985914516836, 0.17485668822642297, 0.15877071107106824, 0.15173937224092024, 0.1528829116854937, 0.10835028959498291, 0.09542987201242678, 0.18215741421426498, 0.13683946773169503, 0.15014845277032546, 0.10252458929655053, 0.06892699132403059, 0.08598378574055049, 0.12390072532599011, 0.12309897600883439, 0.16265902097427076, 0.14418180761558397, 0.1932405307888985, 0.12784499795206133, 0.1429538299599963, 0.20339035308889805], [0.02558401951025571, 0.04833712580523664, 0.018040424498218684, 0.033474043312091986, 0.005775487065435418, 0.04778813953781801, 0.021912681028967904, 0.019062290028218302, 0.01333639374934137, 0.035737760349987976, 0.005407095013651998, 0.01886253260196217, 0.04091779025451791, 0.04151716212471647, 0.10098430057687145, 0.03334589595455797, 0.03288058181022925, 0.038190406161330404, 0.029802055571288354, 0.025813550943689003, 0.011434632188249982, 0.05471996737704162, 0.05783660840543528, 0.07921451026754034, 0.047150850145807194, 0.019065185840572083, 0.043913887348026044, 0.031411152393106496, 0.07070797720863935, 0.005047385610880391, 0.03936984448603565, 0.030874835304735653, 0.028279572650189364, 0.019860371699436538, 0.019484651537852424, 0.0030148559533465175, 0.004494940935288586, 0.048020945997127605, 0.0607879238293296, 0.029227834367643923, 0.05258856138454811, 0.03520727893638034, 0.01928986219178525, 0.08360135954834762, 0.01936132095814232, 0.038271937068671956, 0.02877650898881257, 0.028589346048031605, 0.031211055972943866, 0.018695906563211354, 0.028365786269968076, 0.008654577635048379, 0.06694689152702209, 0.04955981745414677, 0.031849375753212845, 0.04200084705746943, 0.030460328111545216, 0.01287907373250252, 0.04291217376087462, 0.06780156219798712, 0.039899559811719006, 0.0034122427572466194, 0.045116427054087964, 0.0756416370671603, 0.06160954163680154, 0.0783145944437673, 0.01091553962924668, 0.012516927691326748, 0.035175968922915, 0.02988237222926992, 0.03277428328029571, 0.07227274243749919, 0.022098692922642636, 0.056621554653130235, 0.017501349493320432, 0.015599147431672582, 0.007846487503904369, 0.021056213881820444, 0.05511860505888059, 0.008028476478366723, 0.04306015896520788, 0.11278583142425745, 0.039911468648501945, 0.0936466261684414, 0.0352119788857958, 0.009674081699021403, 0.030265333836958296, 0.016662565570685173, 0.015184015876823857, 0.029496311795927828, 0.07343830690989572, 0.06025109154682967, 0.03382451704613144, 0.021192862900094162, 0.03723159349793869, 0.04344616002673584, 0.04303089057606074, 0.07903572066777176, 0.05584873664643496, 0.020824596774013295, 0.00810522651825581, 0.027968745881451235, 0.07913188768490668, 0.037142056971788406, 0.09075642923914617, 0.034585476011758855, 0.059362153763011585, 0.07790225527940259, 0.06977066863328218, 0.029679339777137485, 0.049764780447848385, 0.01707483578713671, 0.05177657330228437, 0.010837865016993978, 0.03545080679619024, 0.07537300067563212, 0.03238383124792769, 0.021254492758382714, 0.014136185711850564, 0.06221102024879187, 0.056076034933568976, 0.023922832540026116, 0.007076565788367824, 0.025166618419931303, 0.0066558250334985075, 0.01957261566853812, 0.040824549693253734, 0.08088288888815912, 0.015873355197630102, 0.0581258678838851, 0.06506762422260738, 0.04798787398143642, 0.03430148338778846, 0.05281435813935054, 0.026676673479678652, 0.04875928621679064, 0.02304032606433236, 0.038599286438717, 0.09364268081563135, 0.02879301243792138, 0.022531185945075367, 0.021013807084771897, 0.05242749522890776, 0.042658319035845424, 0.030559998065713915, 0.03362805379794971, 0.03474692904180096, 0.027244178007446954, 0.04018175212906734, 0.016591828842196735, 0.03908364552884333, 0.030342607210660656, 0.030791297247032487, 0.008339804555890302, 0.017065315229457714, 0.02610079944133759, 0.0571325506203838, 0.04583483366596122, 0.14830437188427295, 0.09842930541884515, 0.01123323054578636, 0.03771561933981796, 0.04127196419323164, 0.027757029822697083, 0.05408558911914307, 0.018368350349426753, 0.05640701556037511, 0.023832535671610987, 0.06525512424207504, 0.02815165703425244, 0.11786461131827486, 0.03197702323837626, 0.03821921106728335, 0.021453210220281637, 0.0352795401798381, 0.04906980080469962, 0.02368867585074998, 0.03494499724418406, 0.01974865884309815, 0.04228208176491242, 0.021489850290480162, 0.03377071852164884, 0.06015292120977275, 0.04398940829560161, 0.06905232330844288, 0.011772708704454765, 0.029416014290144368, 0.09814399895408461, 0.05489316453496295, 0.0642511353737885, 0.032994047092694434, 0.030866509844218532, 0.059185896083832755, 0.011961300399214512, 0.0799421329171427, 0.024423302459200064, 0.05094136509503569, 0.026270386409915747, 0.03416511973726653, 0.056945000805201075, 0.04404865370522584, 0.020312574248941197, 0.031603884793096976, 0.010382610564720968, 0.040921371715563926, 0.02114840107218873, 0.03410153826999088, 0.03915689119528379, 0.07976061604436367, 0.028775492007093086, 0.038638257331425147, 0.040807580845730926, 0.01688992131441351, 0.03297795541584492, 0.04943589890195478, 0.018436355974465128, 0.03432781382974598, 0.03685053370352234, 0.038237643142741536, 0.03698434628125641, 0.020431687514628136, 0.06517438623573511, 0.05240098092584841, 0.061576258946931174, 0.02705182290575918, 0.03526831316130777, 0.017023718570389094, 0.021141772496423895, 0.03276616274829834, 0.06952473142695043, 0.040876141884514404, 0.044000543383581024, 0.08130086645964654, 0.06591428927476368, 0.02660185158733399, 0.048396761919702255, 0.08649717190212781, 0.03981884095757719, 0.044813017931676684, 0.0398803731396554, 0.0922391847557118, 0.03897231763168689, 0.09698084765864957, 0.007469141320700968, 0.07079667486851254, 0.043319360983948556, 0.006759548550396557, 0.05216782589653327, 0.021032041892589583, 0.021300442712081057, 0.043005732248627374, 0.030706590905244795, 0.028704399047719858, 0.021449462135112094, 0.02551967003983596, 0.057430179609406384, 0.07110694813872538, 0.04830862350401379, 0.016941124716052608, 0.029737194737179146, 0.04868528978418439, 0.017764673065093738, 0.028187316511907888, 0.016291353836535447, 0.032327677003077926, 0.04711884682277038, 0.010037579885383528, 0.01520276013311119, 0.008739478371646858, 0.04774327742897215, 0.0025770687845520558, 0.026533225431076946, 0.05295801877735123, 0.043565516525338736, 0.05785342786581286, 0.0042311466982468005, 0.02018016935776799, 0.013221878926419925, 0.07067068404848538, 0.030154279816234787, 0.07880905823361489, 0.0375953397052663, 0.033460257559894555, 0.028364822914403294, 0.05195591065491881, 0.04692018490224596, 0.040884124520685405, 0.02387055661529303, 0.05223509224672472, 0.062508603272539, 0.0731856664342265, 0.06948084991064764, 0.033262924801918774, 0.012567673355431087, 0.04025501311726628, 0.056034616389942754, 0.004052700880434244, 0.054315779388191245, 0.03099460740603747, 0.035158203343950936, 0.048402224126602375, 0.043801241779639837, 0.04708923369405731, 0.07528044193262055, 0.03843384592102901, 0.04690579011014873, 0.022507272510518952, 0.06927028298377991, 0.010236078054614125, 0.02339164632552814, 0.07796215569420208, 0.0265896114175238, 0.033015378810946024, 0.03305261068406605, 0.03893284495138834, 0.04860056429019859, 0.017644538987247695, 0.022614019201888193, 0.026052417158479654, 0.019996758332596194, 0.0553132756613195, 0.06390668309083389, 0.07656419844997507, 0.030059336624558897, 0.01779855330354504, 0.024928962624061014, 0.020141796013640783, 0.035671712079596136, 0.04356278159144906, 0.04371950402855874, 0.07965973758649442, 0.018954643183538032, 0.006641182220435792, 0.0691618049337018, 0.057023731661179376, 0.034391464244934826, 0.017694775202882387, 0.016246252325213244, 0.0058671514007953875, 0.09124238945303426, 0.01904412799875342, 0.03633963732769893, 0.09490441996604206, 0.05546993681139523, 0.049564371846856616, 0.03698364148036607, 0.0817521918384779, 0.05523322713411143, 0.01991431195018513, 0.023977368424135833, 0.014179037797505097, 0.02373046594701948, 0.10845830799230646, 0.16491514991127676, 0.12822623394670027, 0.2652019580766078, 0.15807344848590513, 0.2094315845639475, 0.16821665178623893, 0.09387684325056692, 0.1467181408717748, 0.0734651506307625, 0.0975833987937339, 0.11897749192411862, 0.08866002963435266, 0.17534721432433975, 0.2238684348882206, 0.11406629376353757, 0.13838816043590346, 0.1085659127021509, 0.1782697018596434, 0.1301532974767108, 0.1189365751680828, 0.12427334283148089, 0.19844763041023286, 0.23685888056793522, 0.1020822884334672, 0.10134382563973628, 0.13517143385064218, 0.12240761996156747, 0.19950173675052582, 0.08647071122522317, 0.1297638490195236, 0.09473865386098625, 0.10816690346766865, 0.1030519795453837, 0.0984498595578536, 0.13522314478553113, 0.10711514135642398, 0.15549044515336716, 0.22508055452377568, 0.11378606646171502, 0.11870506339736524, 0.20725422478731603, 0.1565770336216496, 0.15626027158671812, 0.05862111691385508, 0.13716353824542415, 0.12143851873735267, 0.17477079444835264, 0.13997713404317058, 0.0900311125141959, 0.11661147533525383, 0.09788293917212756, 0.14668486201234404, 0.20561740132829837, 0.19563955044554127, 0.16128655913616383, 0.1328067962200411, 0.21105972058590383, 0.1360623481413049, 0.19566417251142765, 0.2741207536910811, 0.0906681452667521, 0.18037290432520453, 0.14675180277516767, 0.2129304460099628, 0.17116622819054514, 0.11399068854629033, 0.16833504301405725, 0.06914307408395313, 0.3032533307710002, 0.11751924356025074, 0.15799729934623166, 0.08626896963124314, 0.1388379612997655, 0.22882335368664036, 0.13598918674453614, 0.1122885101264523, 0.09542296956022901, 0.09144361010722576, 0.19181968283749398, 0.13239108626880955, 0.18814049961586155, 0.2099146642872403, 0.15475791188017016, 0.10609280468235094, 0.09828685903020444, 0.08564895935236447, 0.12311725486670771, 0.06693470306814679, 0.1158934670891012, 0.1307413465673885, 0.13420990157511928, 0.12031076070401939, 0.12533389197121705, 0.10878564204059302, 0.13040284295716595, 0.13541966165986755, 0.17426198949256252, 0.1817391914946418, 0.08946402358912653, 0.12726906837234575, 0.1248913536208772, 0.12266126401241749, 0.111960900286513, 0.19373451960423302, 0.12639532977294538, 0.1865809591066453, 0.2440873491427591, 0.13873676108496805, 0.11266912558987258, 0.13805319615189107, 0.0943861768070248, 0.08614443437827211, 0.10985567534883177, 0.1253263306834044, 0.1353001213001628, 0.11551292057359412, 0.12722731658047245, 0.12283331969933164, 0.1127264749318842, 0.12415015589325659, 0.12641888697661702, 0.11009374483218116, 0.15569393342781454, 0.08883734834530661, 0.09418029067737442, 0.18016697989115793, 0.2673671064117263, 0.1965849948746543, 0.14568712442151963, 0.1994114609495286, 0.15289329983774694, 0.057999329310992075, 0.11208191153503234, 0.1644352417919905, 0.17038239766993832, 0.07050854153931141, 0.15043549059379488, 0.2251536546335105, 0.12498585822721645, 0.12466565645750492, 0.07261131499563495, 0.09810351886816564, 0.13636519801953148, 0.09745451982223219, 0.12754001834940526, 0.140834309821648, 0.09733422103548243, 0.22660235754184185, 0.12308610573170647, 0.13017513098255282, 0.16806237700004734, 0.09197450137787289, 0.1472698620730831, 0.1365068017114555, 0.07530723968821187, 0.11196354328985177, 0.1749712183711029, 0.14514907022878049, 0.12564660906190836, 0.10477747002075757, 0.08453446996187972, 0.11331427121354688, 0.18879502981660828, 0.10882358637548263, 0.12925380300129616, 0.10989627800881864, 0.15073504629394702, 0.15197846828208816, 0.11313152860008902, 0.24128037234467847, 0.09511291079463498, 0.14695115417482393, 0.16683009393032522, 0.1186959086466701, 0.12811135140157517], [0.025764337455433224, 0.03191227157179627, 0.04151574869249617, 0.02611538384019608, 0.021614843280985955, 0.054747125193957365, 0.034729209428112355, 0.04763075443465383, 0.039958200011883056, 0.009323908654492228, 0.04698767341793545, 0.049383364422547246, 0.06010706318662532, 0.03469307689116367, 0.04824338728682168, 0.027974041464227824, 0.040705541764656385, 0.0858471769418928, 0.0603862026435954, 0.02990521505595215, 0.01710113175513764, 0.008772653809207822, 0.01521732154933195, 0.008782637850081008, 0.05454078324199204, 0.029401146438753897, 0.047920860440259984, 0.054411348856745236, 0.06951899342839757, 0.030587471893898426, 0.038904231567416465, 0.039548703033717415, 0.11479445267468692, 0.0628543081092498, 0.04137709826952027, 0.02138198319552166, 0.025085646756774476, 0.050617432477132934, 0.022780124300850496, 0.012587735282948181, 0.02632342076169387, 0.023065244989289392, 0.08886287439494364, 0.02492979765989848, 0.013138749768146345, 0.01087436719136613, 0.03238781490513394, 0.03613023102403649, 0.035208102480898944, 0.05385505028008934, 0.04512718292854486, 0.04529923095457977, 0.028771554315162283, 0.10501535564300515, 0.07942767423247138, 0.044880245977471915, 0.019307821207950195, 0.020977343214795958, 0.011794165869603955, 0.054581140753843134, 0.030160368300013007, 0.044254398108610225, 0.045278182688860164, 0.029009079876085444, 0.039194858512811126, 0.008158303962479676, 0.03723278859510057, 0.044186380992252985, 0.04330942865401026, 0.034346379970590916, 0.0368100076523279, 0.023040937019451972, 0.017651044988944646, 0.07180008150997662, 0.03601018504630174, 0.029243052704259757, 0.03621325197239076, 0.02391019208927549, 0.03550370133692219, 0.09265589062124492, 0.00990953594971929, 0.030377653817976677, 0.04233560066730265, 0.027340333533263015, 0.03645951859652996, 0.05373059546635036, 0.00931433542826844, 0.17688931867239938, 0.01068737278992851, 0.06838787992995593, 0.05074670598391564, 0.03339771797219592, 0.047645919145114964, 0.032910861435436436, 0.03203345327487877, 0.045215221752803174, 0.028902195288889834, 0.05931431540257989, 0.035273051415119445, 0.034512257158395745, 0.016201982019288887, 0.0383881526067853, 0.0572860210142549, 0.033128847923850825, 0.03688569330880719, 0.05236404782701885, 0.02876384172498459, 0.012805647077789951, 0.044800998012144724, 0.033421336462901484, 0.01379927460690059, 0.05485824241693463, 0.04628668381502071, 0.027841259274751912, 0.08896687849154396, 0.002386993752048922, 0.034298419036091335, 0.07399091677319619, 0.032724679087198554, 0.032925857606554226, 0.025963763548662106, 0.07209753812921625, 0.015771730761644582, 0.021056941665348508, 0.07128887103810426, 0.04525111297205572, 0.038933082438644864, 0.047898777955842596, 0.04699212438877552, 0.051024443499984286, 0.14786296734406104, 0.09795846778058237, 0.03795836578994509, 0.03624558471323502, 0.05365374918666579, 0.048741382742000204, 0.05384551631587167, 0.012766100661528688, 0.03854626932391717, 0.10307556739257229, 0.12723637173973745, 0.018360601370072654, 0.02350450256809352, 0.042668653561943964, 0.05248996586869321, 0.03270854527551321, 0.07898329727111325, 0.03540274627026051, 0.06418965298742538, 0.041534621268510825, 0.0558991069274564, 0.05299373762682081, 0.006511301110168138, 0.03952148776020735, 0.06078604308347549, 0.007885898418364026, 0.051079877622185216, 0.07518329432294255, 0.024850038330881827, 0.01777969604928888, 0.054698313901861834, 0.013929822692467321, 0.0463732325982663, 0.07159522959902402, 0.03267117167612718, 0.10952104048262681, 0.05962633535326008, 0.014887123289818486, 0.020135253622767427, 0.013237080983667365, 0.03743806568485114, 0.03247090097096178, 0.04568796694999741, 0.013748713761507986, 0.03408877524517236, 0.006846589545133494, 0.04074652746860539, 0.021213256160638506, 0.07306614139628026, 0.060301523114885056, 0.012426695940385183, 0.03407441875747135, 0.028457285896424326, 0.07703194109302375, 0.02023777725445407, 0.03267797070645517, 0.028827599392482833, 0.03248015914352671, 0.033112488116227815, 0.030722538940608505, 0.023822183908534147, 0.02648150683530877, 0.04040222840323564, 0.017789159150373553, 0.04744271049275995, 0.012690954139426112, 0.06553407983794328, 0.012834510397947124, 0.030534265172337333, 0.0481142440149861, 0.03739739790739071, 0.04962748983093808, 0.052567244988055005, 0.03830091817484748, 0.018075405988061143, 0.033386962097739024, 0.04952148624485539, 0.06119327244138526, 0.010922717873097188, 0.011690924988098202, 0.014410634795504232, 0.047396254921031576, 0.05421353346337715, 0.04152909394413714, 0.028517803012002862, 0.028096604040793838, 0.01721787972435836, 0.03643496164811715, 0.04102229996914825, 0.09565785977869265, 0.007059200969149149, 0.020210914381389177, 0.06836275990691877, 0.07669151460211124, 0.06543301751897221, 0.030261074388099295, 0.10500306759269969, 0.07421898880913373, 0.09067659521655691, 0.048381681478912794, 0.08636677607653603, 0.047657479411892356, 0.03152709405478691, 0.04690905364470617, 0.08405446225116331, 0.058990976502818454, 0.05247981137325687, 0.02630787492249041, 0.04693336927542283, 0.08008146898881083, 0.030883656807183742, 0.032737177811683185, 0.035093499557866205, 0.0128420946683975, 0.055322204416076985, 0.052347967641488205, 0.025068045886714133, 0.012237287404376173, 0.07651495431820232, 0.03866552623108991, 0.054636394845381867, 0.04346555737297862, 0.06628210340896923, 0.06204158458257876, 0.01718624603874501, 0.03487012747134413, 0.01351371437551514, 0.04543945568824007, 0.04640036360210469, 0.009188069774198436, 0.02482559629565766, 0.0391138868496543, 0.02620162235783233, 0.024068567361081802, 0.06441975898680187, 0.023255757649519274, 0.020171797931975415, 0.026566803064798156, 0.05148162945143638, 0.037803999073202574, 0.02489292967854248, 0.04810482496395708, 0.030600771180263935, 0.02105099682305609, 0.039122302325502525, 0.04279288237974529, 0.026169013825335333, 0.025410027536112937, 0.07341949945135463, 0.05821976728076416, 0.08084811615727602, 0.02274790647319488, 0.016282808125740098, 0.043654627872691046, 0.051977491351745786, 0.03882519810670807, 0.02589884717317839, 0.03972953808824382, 0.07707789870760134, 0.046888170087890285, 0.0031591577111788455, 0.01390563250864826, 0.03465910472216145, 0.03525134431378495, 0.05505072200791009, 0.048566488699326595, 0.00794368778212717, 0.04238369566718898, 0.02186350009944891, 0.03637215776008464, 0.038701923068372474, 0.05302631168536121, 0.020405305361735727, 0.0825955473908013, 0.04592731196974074, 0.0011475087376311421, 0.031082751567385374, 0.06379912434626492, 0.06542418452520525, 0.05530845313783615, 0.01440784240502023, 0.09051479744694887, 0.010025880765169859, 0.002385027539510761, 0.11102305544960885, 0.05262377461598766, 0.12124574037208674, 0.08383859399585955, 0.0984274897904646, 0.06023694573330784, 0.02704655222084013, 0.0742449515288876, 0.06808575783525744, 0.044296571248841864, 0.04997478430009177, 0.014638205043851368, 0.0328490917661017, 0.03429819304015368, 0.098000135302784, 0.05429555849742986, 0.0784970919090894, 0.024116802172014312, 0.1207562791363847, 0.053965623580640366, 0.06068797233784872, 0.05902440857983405, 0.057400677563442346, 0.061576998221778104, 0.018975296913976633, 0.05729873807379796, 0.04198817979364146, 0.08732575727927108, 0.028146413162410743, 0.07971386935922407, 0.040956864569095836, 0.02099666012180669, 0.055912425366020015, 0.029147837551370747, 0.07996493935464852, 0.04534469061200658, 0.0687220321607686, 0.07815406071923434, 0.13263614247402838, 0.12271688199572026, 0.17288634072869055, 0.16412738169873917, 0.06424548164490732, 0.12280681305715155, 0.11776409292173003, 0.1366547486113925, 0.1010489737194392, 0.14364850316797534, 0.08876222576345168, 0.18736495816659543, 0.08550491950084126, 0.10389524316715618, 0.08814757810004296, 0.20863067028262924, 0.09324004032438801, 0.14191044885064327, 0.1679408448117395, 0.07380200715194787, 0.1314723936300124, 0.07953919365160889, 0.1513123548319263, 0.1419505458926001, 0.11509180970249638, 0.10320197190007857, 0.2067380807092113, 0.12008131737069738, 0.14276285956223167, 0.12245218329612287, 0.10493298586938651, 0.14409405990473687, 0.12311912412124297, 0.1108490155949708, 0.21241347455689985, 0.11308233809447098, 0.1321982159729927, 0.09961163955590419, 0.08408988615678203, 0.20547146157872295, 0.15777703374624252, 0.1468560979851792, 0.1947706075565469, 0.16706882224928948, 0.06826200402311741, 0.1345987218402086, 0.23640583149127423, 0.22633914505281758, 0.12424204813977405, 0.166811156236837, 0.100755600348836, 0.1383734362259988, 0.16842743321772546, 0.1564395821262752, 0.23944419748600454, 0.12923918604370088, 0.08980500166334453, 0.06359464398795558, 0.22984347636661223, 0.128541678310402, 0.09290142180097681, 0.1594964721270146, 0.12073905747984687, 0.0955649639569944, 0.1442148719703959, 0.1295569593146924, 0.14043839558237983, 0.1593349654708178, 0.21729711653484454, 0.12846182896605424, 0.11908582441749112, 0.09364425895675536, 0.1179708217480971, 0.18403642870966466, 0.1350351161653957, 0.0917328542639171, 0.17656463528833083, 0.11251769298988004, 0.14150511172990646, 0.22459824088840719, 0.07051711406318412, 0.142624075073869, 0.1377486608802311, 0.17750876204621407, 0.14320535194729606, 0.12559835318355791, 0.11103727404148349, 0.359729056757304, 0.1563027435012402, 0.10699850446995228, 0.17711465577444724, 0.1162239574196358, 0.15586300903270323, 0.12023543127842488, 0.12151998452722065, 0.12500491083389328, 0.14010065806008157, 0.09416276258566687, 0.14618158821136723, 0.12103593953314329, 0.16662859748448097, 0.20167502093940012, 0.1681969786483434, 0.16394373510153065, 0.16522582920808948, 0.10394767422469393, 0.10922087957301449, 0.10341403269839865, 0.1795011422326488, 0.1968382788641799, 0.1514866398347001, 0.13047153040045692, 0.13249555001816443, 0.26065029263977085, 0.16317482797368882, 0.08097896397474312, 0.12877415535190415, 0.16748707561242968, 0.12183316127066651, 0.1393265874996301, 0.11231905405199337, 0.09847974464777978, 0.14636083746389036, 0.11306401327132218, 0.189474611092479, 0.1501980186590264, 0.08338477883127429, 0.177344344255905, 0.12194114902447309, 0.1713716316848032, 0.16391016512868867, 0.34908585851230933, 0.15904719220294108, 0.08452827231057229, 0.12386681827446147, 0.142111424356699, 0.14461751246163923, 0.0813933332721072, 0.18517956978851752, 0.18414663811845167, 0.2056010836555112, 0.14637695595381722, 0.24749930557464403, 0.16513877097637425, 0.1284533943380079, 0.1105609205701659, 0.1787504067103709, 0.14210138860489094, 0.24775252827713568, 0.15091880014346493, 0.08735686044899688, 0.21199633968212914, 0.2663007426646448, 0.20967172248469246, 0.2050147352800254, 0.11128301206495493, 0.17323252053991442, 0.15594756981778532, 0.1935773796492046, 0.11637751974405781, 0.12211289827621753, 0.12386857261580807, 0.0883134744400459, 0.17853970188767682, 0.07755340948220223, 0.3061845976739161, 0.13243061640570242, 0.1441937739089612, 0.22575570781144405, 0.10112043440101609, 0.10471718656199594, 0.07230464233866624, 0.1655681019708995, 0.1470337231313029, 0.09737662400209135, 0.15474162485089996], [0.026331169741047968, 0.03870417919730948, 0.03386987328168846, 0.05565944398122449, 0.012204472028139618, 0.018845496721745982, 0.04772894775434848, 0.07279047997848642, 0.06963972122438493, 0.010580805171611569, 0.03522527051128207, 0.05612111920791288, 0.040910129375275106, 0.06294159999778194, 0.024630044692105824, 0.04376094555482269, 0.04465267572912478, 0.05453006567193135, 0.016734079878416755, 0.0831368881007356, 0.07871057763094864, 0.036441687900092334, 0.028088948907210465, 0.014784371746974367, 0.043717592639187654, 0.017928165804234245, 0.09412737698444436, 0.005275835423925591, 0.021474677919139786, 0.03972877200031954, 0.021895723672763958, 0.03631213094077764, 0.02402712200437823, 0.018334975729005474, 0.0031762505691844013, 0.019252532642454873, 0.03051314604348473, 0.07832368024654927, 0.016687356175914887, 0.045176335129766695, 0.038695962904321576, 0.0050095585832041845, 0.06974320438119673, 0.03978799442730604, 0.010473006066956348, 0.03819522485437413, 0.04494124572844275, 0.03725363001708062, 0.011623606926971867, 0.02123992559650252, 0.015855559932758972, 0.04528761706164768, 0.034178193027694384, 0.06231729196564806, 0.06717072709673835, 0.05541115105452557, 0.013519500254563267, 0.011350195892455598, 0.017350893655431368, 0.029579999240776225, 0.03793127309050291, 0.04516971996054054, 0.02360181871711487, 0.04875660107861604, 0.04967158968229929, 0.014827659545135836, 0.0379729712562215, 0.040251853004578626, 0.04460324390581058, 0.07418435397407702, 0.01336205865241467, 0.01722110686973939, 0.0004721416037007716, 0.07529472947240838, 0.07863110366968379, 0.016237013304846424, 0.01456832537622822, 0.05705321072450569, 0.022615859728126277, 0.03624913170032444, 0.04460619334431906, 0.020562583212590507, 0.04225829090442389, 0.012953471403659112, 0.0316112258306314, 0.06479167935228156, 0.05587058164359582, 0.019818045341620044, 0.02522255816016226, 0.04842795701997896, 0.06817653925428468, 0.03797459919306059, 0.020369638223201036, 0.05724681263429023, 0.08821054286653958, 0.04078858569564839, 0.02384975349770919, 0.03470381361342246, 0.04329491128784515, 0.008192978059542517, 0.052863062179136666, 0.012353303759629208, 0.0454422174352071, 0.020518609765736807, 0.06667311468552198, 0.03972261648384794, 0.024329150253305995, 0.051658618744582906, 0.08196124191125555, 0.01980285190286175, 0.03151923016224417, 0.027917391177447095, 0.04031043191770873, 0.02407761102902793, 0.08861512922111059, 0.04592258520724793, 0.10329060827291782, 0.029778567315529914, 0.1688698949592729, 0.02256095995225253, 0.050516190127499645, 0.026714870623583277, 0.029058933047757998, 0.05968233638052499, 0.0480788430920051, 0.026215207011949633, 0.035943688614474195, 0.06026084767654539, 0.01980502950778652, 0.08352071347255861, 0.03963201509548291, 0.07847731917976372, 0.012823291040296036, 0.05241950876229713, 0.04614182041897889, 0.15448775863455189, 0.024225709231330023, 0.07813345295407119, 0.080432896502316, 0.06727118420624925, 0.007013943846217327, 0.017957459091238918, 0.039712511784126686, 0.029823931211966182, 0.041717819704283635, 0.06143739018889685, 0.07373664453024827, 0.016019096721955124, 0.07659393032231639, 0.03630215264556389, 0.003990895300728059, 0.02696567248823422, 0.1266730443063763, 0.02013741590593371, 0.02180193535863392, 0.030748381001514294, 0.04347696442217116, 0.030510832457953406, 0.028661706882919517, 0.049224784222221186, 0.02059329567747491, 0.06623811464035703, 0.043776060469568744, 0.05372668841793653, 0.019825091435303612, 0.05697943262695786, 0.06304770700573441, 0.044085732360761014, 0.03398566747144346, 0.02789071599592365, 0.017525691937114445, 0.01774348307310814, 0.007880950447983079, 0.02190021103278043, 0.0020229317728550204, 0.08278622667515471, 0.09066958551204975, 0.02035699394201079, 0.04082775194077723, 0.006586047830135232, 0.08560435771341286, 0.04548788393637346, 0.019696120533250996, 0.035481615022065184, 0.0201300403944427, 0.0778469743747865, 0.08977559920881065, 0.024613236723047112, 0.0111813893759503, 0.016652746238715706, 0.041645052842795856, 0.016114602030645457, 0.05344827674449452, 0.050786236120808514, 0.02461826225983039, 0.007417205826289231, 0.036416506590021235, 0.03287962803076352, 0.04126917563318726, 0.09126318107929923, 0.03656263020069849, 0.02300897200081137, 0.03171574895180041, 0.044929696952984224, 0.034576826879093726, 0.04126932118989287, 0.07248469598350987, 0.07188318672800256, 0.018012399086728692, 0.07895381820778694, 0.03480749212265496, 0.032619939546190926, 0.023165568033413544, 0.07863744687769683, 0.048435058655037035, 0.013613617028890839, 0.06888154698836227, 0.05352113553653321, 0.031640568913351146, 0.01866715719863292, 0.03518647964923613, 0.034765905039685394, 0.02200512102835121, 0.061957291928270174, 0.007186488871793113, 0.0433479322330846, 0.027399389336125988, 0.023889283634602063, 0.02927187867763062, 0.06258424679418245, 0.045168325680518345, 0.04965809887395271, 0.018529203915668112, 0.02481415285728872, 0.05220531057866831, 0.032188398388004115, 0.0188741713927518, 0.03137445103587403, 0.0517967137538137, 0.04416925126626607, 0.0402082511103682, 0.04761420693548937, 0.039483972434555335, 0.013785867110615777, 0.06275478945744616, 0.0509995149989282, 0.10585095838553484, 0.02295081826647924, 0.003988515879515739, 0.008097218026617363, 0.009742641780194978, 0.060675803031171524, 0.04134983703073475, 0.02774242627164049, 0.08615221017070356, 0.00940773782560662, 0.022745535431069233, 0.013922601356171073, 0.042188201520231464, 0.049965725310387156, 0.017842319906659184, 0.08000921923667192, 0.039530902980796756, 0.02026538897846495, 0.022976283029082323, 0.03496598422286972, 0.03314238469747286, 0.0039292017613808, 0.006783064098037299, 0.03003454027366975, 0.008652248727758566, 0.071433148376884, 0.022510463266723582, 0.04842519910345155, 0.014107234291582098, 0.03627913936431851, 0.07432296226221709, 0.053732227233629075, 0.05287379507095583, 0.033475054548152035, 0.06389264836006107, 0.02990509439710408, 0.04628169658263365, 0.044263158324024374, 0.016456106790311394, 0.030894962349726312, 0.04076097971729694, 0.0282946128713628, 0.08048063144087791, 0.07957006699495739, 0.08397991423525157, 0.006654511192708367, 0.09805415982320424, 0.03689169560769393, 0.07919623907054625, 0.05090050196515457, 0.03754962723882448, 0.04653362459653328, 0.0612401340397135, 0.05150116852394516, 0.07141088586180441, 0.031187370449544925, 0.014303137337969197, 0.04650639783170435, 0.00786258444760836, 0.03670262510798151, 0.043483836230851954, 0.11646125315418167, 0.04152748132905653, 0.024331885187195677, 0.05791992812808003, 0.02918313505248197, 0.06693651103564809, 0.09825483655496951, 0.037549389751567956, 0.03035416747743805, 0.06644319637768692, 0.01638130979582427, 0.022075809876344377, 0.044651212501189405, 0.03661117719246015, 0.08481561656921141, 0.02258945076215652, 0.07846740600202354, 0.012800104431657782, 0.02584997459404892, 0.020089213653737982, 0.006298941537557591, 0.0051042135342985635, 0.03966877582452951, 0.036833040085771394, 0.022534836354034565, 0.02104265604078049, 0.037034946388655135, 0.08044732193793021, 0.048328572433562055, 0.016888649608459205, 0.04733673755019423, 0.014798472552830655, 0.014383885878018074, 0.028033399871820887, 0.07256998455212002, 0.031153641513458667, 0.06304960690378662, 0.04826403335638104, 0.0064464302211549255, 0.013144797074698634, 0.1029766501197892, 0.020584841897230477, 0.01632596568895444, 0.09609546452280014, 0.028873219928373734, 0.13639938086271286, 0.11273970527033653, 0.1985303066190212, 0.1387986763110084, 0.10808969712665967, 0.12356173908037525, 0.16452269838942638, 0.0876513829514865, 0.1381681706275671, 0.1753987873634023, 0.16051710042501652, 0.11766127626141233, 0.09783555663401082, 0.08590422750961396, 0.08650494003368002, 0.11591320151403067, 0.1531569719795258, 0.12225583496112978, 0.07957525341020477, 0.1296776181627666, 0.26144264205809564, 0.08425690098515443, 0.1784712442707631, 0.1776812084379696, 0.11563559423290914, 0.10419256189056944, 0.159469980806593, 0.11417654147672077, 0.10451732954430966, 0.17735154548239324, 0.14722314603146047, 0.11867999700048279, 0.08703967706570703, 0.17660517666128375, 0.11210210561271637, 0.0756462182729475, 0.14178952953267482, 0.14030333428132918, 0.15347341225752908, 0.1704398082989839, 0.1345460149910181, 0.08691833639938025, 0.1905587327576453, 0.20584509798115302, 0.06663702428340912, 0.14153367148772364, 0.19293420287149568, 0.13404670952548906, 0.17919487560227995, 0.16318287189689376, 0.08113458707568147, 0.13024801658766885, 0.11613210347751457, 0.1650238271442152, 0.22033609539991428, 0.13643328791424153, 0.13698404384476526, 0.07207928225398064, 0.13750446269348746, 0.09874435141682626, 0.11489735360467628, 0.11377120435598398, 0.15681654335029666, 0.1451915421433026, 0.14274179214431396, 0.13398569828319934, 0.15329051642648636, 0.16671850556327453, 0.13424339493916881, 0.13015924231900325, 0.12381035759444199, 0.12206504076358773, 0.15920951091233762, 0.125782459433521, 0.1438527728521055, 0.1934970170259476, 0.16981086543490811, 0.2750478120100114, 0.2617121517898575, 0.07206451207880052, 0.12288132276866706, 0.16087181445571686, 0.1346562090780466, 0.1429280587622235, 0.10506342766025376, 0.14804361087660636, 0.16646900604809486, 0.09582191750767732, 0.1006533352718238, 0.08719966686781376, 0.15083500544630712, 0.12522581994773882, 0.09566491544847527, 0.15056647630708833, 0.23126536619759377, 0.13575991195055748, 0.12739689014251196, 0.16366235100694243, 0.15143353461978898, 0.13749082632843526, 0.18071241917148714, 0.14286880952215966, 0.1549461243614074, 0.13570815505039308, 0.20585260564281097, 0.14959506149734222, 0.16089530271147529, 0.21336855637210034, 0.12883813901534005, 0.11579967494453154, 0.09812952755319496, 0.16497755543358866, 0.12673818476257787, 0.1662734697663015, 0.21385284651431347, 0.12468965799217263, 0.18839738421863128, 0.1375960714874729, 0.2984014201548792, 0.14207462149281658, 0.20952343850606875, 0.11827023189154365, 0.09071791033831336, 0.14414644499699916, 0.26640591121489005, 0.1574019724202733, 0.1255447270288583, 0.19893994915389246, 0.11078915348456753, 0.11637140636242206, 0.12135537521493052, 0.2684411616815675, 0.17274688208295455, 0.1265544768783354, 0.20861151808452225, 0.2621202927923972, 0.2025367319583893, 0.11903263493290833, 0.161709577566193, 0.23782807372270093, 0.14308683814540987, 0.09347850817345804, 0.09208806625176823, 0.08275167610976966, 0.12283452245737277, 0.18965258863904785, 0.1286972401243064, 0.11592984860462528, 0.12221763781722515, 0.13458405891733785, 0.09129192469821823, 0.09405109760982376, 0.22166852148309832, 0.08926067321050553, 0.10875193417192468, 0.2678792515108662, 0.15999484296527602, 0.10288514857811314, 0.2173054668932192, 0.09701903714167495, 0.2511250924679541, 0.19783033208260614, 0.1065768113720321, 0.11167774652881969, 0.09627277557287486, 0.11701815310985812, 0.1755664074012349, 0.3768874344325835, 0.21533294370578182, 0.06668783889542665, 0.15218528137812692, 0.163028750328287, 0.13384417120006778, 0.10544513862940574, 0.1642133827291189, 0.12773615217977954], [0.008642042521387339, 0.014071116118781991, 0.017233814353183392, 0.03668619635244531, 0.03457677325293903, 0.015297061726150495, 0.05275683259711631, 0.03558869496168148, 0.019849738399047526, 0.1455603521918097, 0.1087974168119892, 0.05130175200681533, 0.021065399276032563, 0.09465285201346683, 0.019691399516417615, 0.022107843842898166, 0.06500443729061274, 0.021136145580620058, 0.021385746602449688, 0.02679136450282268, 0.02998157870024443, 0.04375374432833445, 0.02095564568956052, 0.03549154735200348, 0.004234684588042118, 0.03499941629988532, 0.08635687822055432, 0.018888727063313127, 0.08899476409198777, 0.008666937506096739, 0.027286577143616257, 0.06221816401868578, 0.03345064315644484, 0.020370827574703484, 0.041881444593591076, 0.04397338556666528, 0.09807739526994767, 0.02630839586227892, 0.013830339472230165, 0.03052537472197606, 0.10939560124590512, 0.08034350170243172, 0.059871284306169524, 0.04415877501390154, 0.04533734765925235, 0.07195277815504421, 0.06288930300563093, 0.057125108076199416, 0.028999247137577306, 0.07290312554687262, 0.015052089790603327, 0.0335108959716895, 0.035459069054453604, 0.03261926155837794, 0.0177579544739978, 0.009940558680213027, 0.050736674062547185, 0.05696611801883387, 0.059143703791403004, 0.03643359418117231, 0.004932532751662356, 0.02564929786228365, 0.11544119176124373, 0.026465392175821528, 0.006470154527755034, 0.05616282120407109, 0.019824220010289745, 0.03164536270853733, 0.0704048438778808, 0.0032986498732615506, 0.04430096476308761, 0.014071732819561037, 0.038509719269049746, 0.039519499762043844, 0.024930368395402067, 0.04025793957313703, 0.021919148726268642, 0.05498193114274933, 0.03706710675971643, 0.010953685062216416, 0.021605698106389855, 0.0824816837426155, 0.04762182184945672, 0.008325476796486446, 0.00585848072190739, 0.07078847772772275, 0.01804562815044436, 0.05739565202665906, 0.016512806872807203, 0.028819187747074232, 0.03239837925760977, 0.045920746596229654, 0.06325696392225162, 0.03215494715879041, 0.04047846947346003, 0.05889850202947856, 0.02889657986440486, 0.034833933647361495, 0.083067266030177, 0.04782845108439365, 0.04305432520566448, 0.03712421095359229, 0.013071846352109026, 0.10763935234037139, 0.013627134650314768, 0.05782645774043857, 0.035056397919693304, 0.04103903132941454, 0.05714820945755609, 0.007353513276264553, 0.02154546061290368, 0.11125149520775003, 0.05795867302485051, 0.020625934853488882, 0.034564278358894016, 0.00369715660194596, 0.10892111702912277, 0.03195692300646296, 0.03522530115479904, 0.06198492088925935, 0.041797952501163374, 0.060039904088743275, 0.028256327627346884, 0.030498479290174383, 0.024513817662673614, 0.025095607815009933, 0.05733171049805899, 0.033234495279048724, 0.03018755484522591, 0.033716219026715524, 0.03486671838008108, 0.022638355900022774, 0.02521512710729674, 0.056472090899103114, 0.042151034764584996, 0.08064799866969548, 0.07061341897614541, 0.03449942518566405, 0.07881451277963578, 0.03916676606862776, 0.05487468649422931, 0.02966419230365465, 0.024367232484021978, 0.0192051999000532, 0.05493047301687541, 0.030522166728793137, 0.028369976770913893, 0.08380606590259461, 0.03234761444130733, 0.03656012892362572, 0.009304237431816516, 0.038566145475112626, 0.10688089465181674, 0.04343762580725936, 0.049143054132019325, 0.06944688157208505, 0.017485916652085803, 0.1011773853773071, 0.03146845193940305, 0.02183277997368526, 0.030786177864478483, 0.03570266203173707, 0.020052458670350815, 0.01246775346507709, 0.07988129787507557, 0.009521181083043978, 0.06639510903867983, 0.052135703829868194, 0.020202062235424117, 0.027570288230274475, 0.07031922589146322, 0.0077512584656717325, 0.047310303686366934, 0.018549549295717192, 0.03795063979322872, 0.031904769655797756, 0.03512008663927836, 0.031328008870684335, 0.017638205355333707, 0.06674368670510669, 0.046692771701923305, 0.016015760409044885, 0.0253487941283252, 0.061756906309916135, 0.027733030203249187, 0.038252133695829305, 0.008773518530952354, 0.029982249027178175, 0.06138261873275042, 0.013679561877412903, 0.07944988312139627, 0.005263901689285112, 0.03046107887771101, 0.033675930462777615, 0.045463185261694655, 0.01372097754820941, 0.05041154251704293, 0.02406651424544473, 0.020102285028946017, 0.04093407728378812, 0.04237831772996053, 0.04226524698277635, 0.03187661017892102, 0.0012258950934459967, 0.062448262357183044, 0.016235787564167575, 0.013992374729094727, 0.08336397188325083, 0.09105410802388385, 0.03935821144090545, 0.020308220954311472, 0.009435045987277502, 0.02469435585812936, 0.02153553594384463, 0.020937378323006055, 0.03560219343090731, 0.06118827371767933, 0.05446887822941907, 0.0339724141503534, 0.03492370383032868, 0.04275230653283577, 0.020049338777279182, 0.008110949195050185, 0.012129563950903475, 0.019194961134945194, 0.02587595455078108, 0.010385795575266164, 0.009499898202897561, 0.03337999069762807, 0.00872726597252392, 0.03251836011787096, 0.0476187574977596, 0.04923943182333343, 0.018272108638719208, 0.009600512360432937, 0.0704866697290732, 0.06288941791881958, 0.03671600866401869, 0.07169334247948662, 0.048116726139860774, 0.016492271885996865, 0.03188850752438509, 0.05469207794615819, 0.05485053557241636, 0.0070429986883555696, 0.048336631678525484, 0.06757171283806525, 0.0032730725914945887, 0.010660767513928155, 0.0549762352790323, 0.02551806317041478, 0.017382724608685222, 0.018748437212179267, 0.026903613620708068, 0.11325597192250914, 0.028409627566654837, 0.054899258764400605, 0.05583456018939615, 0.014766434755837245, 0.007183606465978007, 0.04685103014532117, 0.011157425188068903, 0.028834519081658898, 0.06127478036608908, 0.05417555848497057, 0.09595340117812158, 0.04620552446032244, 0.025257608597917904, 0.033904898821586565, 0.04973928121128871, 0.06518740973044788, 0.05764497151117652, 0.028633426747194705, 0.013422288485021602, 0.05478409659718314, 0.024162918749836185, 0.04878636359447434, 0.036101004769725185, 0.015159310498875717, 0.06341776194711847, 0.040345729418819955, 0.1004955901073352, 0.021313033367116607, 0.016076876030814265, 0.022724912344147603, 0.023552672261552467, 0.03783256649189899, 0.037881128805419134, 0.02559175125263151, 0.00915534537090289, 0.02564679466999106, 0.053749609768631, 0.05581415543753294, 0.040366455927611365, 0.026187982162340518, 0.028785675230826584, 0.007465263000584298, 0.04279202819170971, 0.054017893759714025, 0.009887217893265188, 0.05441128373927167, 0.010279214550410549, 0.040855327275611704, 0.05069409489571568, 0.008050290353205657, 0.08849204187431643, 0.03397463963577344, 0.032025279116726695, 0.06642578319916803, 0.030969351402393756, 0.0564343419166342, 0.03884932604588328, 0.04291709970622774, 0.09240179457851956, 0.06363145068227764, 0.012522546946251345, 0.025947240947355187, 0.045824751948877696, 0.03995201385189449, 0.038915512212101495, 0.07969854760073847, 0.059821473269332806, 0.025885911778576916, 0.04680489250008137, 0.07578019172914567, 0.08644384452171865, 0.06923531107003651, 0.05363145985850885, 0.05899713201929004, 0.15849079786529466, 0.022238456088328556, 0.035014029427040974, 0.015698792487983743, 0.007976988666585737, 0.043121105090024016, 0.020364461384052714, 0.04519611551997162, 0.03912318332661544, 0.030156760025889646, 0.026998817282278213, 0.044491207377324184, 0.006409638848591356, 0.029201019375074296, 0.02827896169506975, 0.03871762020994098, 0.06759852591541506, 0.04191647013348918, 0.03209041957292826, 0.015923428619580886, 0.028274526045988166, 0.048073384715544606, 0.02825057622225535, 0.1985978449304258, 0.13311765937795564, 0.14537837566627612, 0.1384115414393525, 0.1310232975670407, 0.11334840809145283, 0.13871664361607644, 0.2246989201634161, 0.15660464343044067, 0.19473412644959268, 0.21790027287938904, 0.12085271428429312, 0.14793496428718492, 0.18853573969775633, 0.19258204757446246, 0.18922780820679283, 0.1175097517308689, 0.10354651994402371, 0.15699957707716575, 0.11246460309672741, 0.314379777278631, 0.07958315177670411, 0.19868291133353788, 0.07735253356757664, 0.07532692048698664, 0.1406185947839291, 0.12608399930139705, 0.06774971336727181, 0.2419461027508782, 0.15568728378463179, 0.08296633394615305, 0.21998810762118912, 0.1795444874874046, 0.15244440295763556, 0.18848214418657366, 0.11025310644219, 0.14699944835757056, 0.07399678500669618, 0.1251842060516919, 0.09611468566882034, 0.21265215691058867, 0.19041942732949413, 0.13595990686407014, 0.16310655421787695, 0.12631519697606564, 0.21725959354831328, 0.13341632641611562, 0.13722911537174257, 0.06805781860865893, 0.14357105167883058, 0.13628517247496114, 0.1265666653372107, 0.09916250518853627, 0.1318714641515286, 0.10102773010129891, 0.14186080635314988, 0.11694819396061283, 0.11195850243131, 0.20638497546315196, 0.17588462500322252, 0.16058506774565867, 0.08308320831988128, 0.24355992825040895, 0.0941731277552824, 0.16952027296347005, 0.06564729231139345, 0.1516821148294595, 0.11828169256689088, 0.17679106023523117, 0.09718873327778232, 0.19413835519263822, 0.10301509241182959, 0.14723669046596174, 0.1537369158599646, 0.10286502344834228, 0.11564520863635887, 0.12702641768320916, 0.19255022428208785, 0.2920969455472885, 0.11664813264243065, 0.15868374476990393, 0.13609732771592756, 0.17282047248896093, 0.05958330802499287, 0.15859095620051508, 0.21113064500593373, 0.11025675302070957, 0.17526354220124984, 0.16021682460221554, 0.24558131252565693, 0.19591892738976788, 0.10497134389175523, 0.18925100534914002, 0.15617135942222612, 0.1083994341353255, 0.16565866888530795, 0.10056856764300216, 0.11006168405255003, 0.17270897605246113, 0.1317089615810302, 0.13842792039917362, 0.08629896963435797, 0.06313473076349305, 0.15402381578760763, 0.1435790189932431, 0.24699776313237606, 0.1518034171913901, 0.14309462159872055, 0.132523680766744, 0.10084743896919875, 0.09421982081426729, 0.18848957523943918, 0.12099983380927194, 0.07738961988399107, 0.1643523051133079, 0.07053103388076828, 0.2670669225194762, 0.15588927052674756, 0.12036806408075557, 0.13067583072810404, 0.08162294514477253, 0.0930582553208355, 0.19033940178492378, 0.07572389958846955, 0.19389823259365177, 0.19297371768663008, 0.12510555180450603, 0.14214520883415976, 0.0941955894532223, 0.1454532377782368, 0.10317433910864977, 0.12873488568490551, 0.16785556390400858, 0.09352888611535873, 0.15517412744943174, 0.17875291947876254, 0.248090771417464, 0.15760811135893868, 0.3022270487441171, 0.14096687367606547, 0.21528487934941248, 0.11607393442142395, 0.1238898928427408, 0.1034857385281113, 0.25782860695354404, 0.15430930611347, 0.06469363541973215, 0.16098108923723622, 0.17413258192039308, 0.12431352414310941, 0.24073464195093802, 0.20572004178839348, 0.26286937356475865, 0.139162705970868, 0.15426101193072336, 0.14459437660632596, 0.06514269317830763, 0.22199942550111204, 0.11361474621920817, 0.16430566568047772, 0.12259715011403446, 0.11488075247935711, 0.13040950792210718, 0.07921485500710626, 0.15276098113146522, 0.09355491778302578, 0.18309248581288323, 0.10086724234204139, 0.12283647598157968, 0.11545154926998001, 0.21448531338284094, 0.1253577556100584, 0.14307827328241643, 0.10128135883039045, 0.13929010639267583, 0.10260862148096485], [0.00554578134699935, 0.06143334141421703, 0.05206500157533635, 0.023281254970859137, 0.039179444823774605, 0.04091623509603162, 0.021460168213853915, 0.08666181951881417, 0.0400987733155489, 0.03954607535213713, 0.06324163067244715, 0.062173209979289004, 0.02945745390118851, 0.010418953775848833, 0.023232690742119186, 0.05129838505038812, 0.07772266128731352, 0.04312639875758079, 0.07741408107141334, 0.04342572463135566, 0.06603356150369491, 0.007688736114951392, 0.06255283335884733, 0.022930442242913192, 0.01450649537746945, 0.006383324686002227, 0.0383923584294896, 0.03192756843242434, 0.03112166691871901, 0.032137947667750626, 0.04909583247236667, 0.054686305473648736, 0.09837754851868076, 0.08879109195643857, 0.013323507192845066, 0.018249953375949014, 0.01859237361068447, 0.05489295386078377, 0.0364957851988654, 0.04372752496912595, 0.0691683549854544, 0.09458821717529528, 0.04193115986943726, 0.07731535532061132, 0.06420554165097495, 0.026038715675953897, 0.015312202496363994, 0.0727798619998559, 0.08123266165174785, 0.12971929334584745, 0.03087280517173631, 0.012887268000462604, 0.011168216494092298, 0.04925035623713367, 0.02060888365151421, 0.023883070661536148, 0.07792143046014732, 0.021456207539285385, 0.01816670834687689, 0.0320599656627183, 0.022538887043934197, 0.09106552273395563, 0.0262150039986497, 0.01185397722668225, 0.04978058484172629, 0.013541492723649549, 0.03405905869458953, 0.061411661125959895, 0.07129547471601157, 0.018971801637822104, 0.020322039265245683, 0.04260414512827993, 0.03743066910594221, 0.051488512751436046, 0.05011806955500957, 0.10288012304132986, 0.04719331822988968, 0.053571295143375476, 0.019481403325053475, 0.017449267005788225, 0.016459625049103654, 0.037621892312721866, 0.025515370371360934, 0.05469574750731549, 0.05231546253086098, 0.03226526381988679, 0.04283109101496878, 0.03547926696257726, 0.09246249172476032, 0.02245608634585815, 0.029286729292042797, 0.04587561635661029, 0.04700065094737276, 0.05550475550755378, 0.012205826088545785, 0.057228506963339545, 0.05425887054673607, 0.04231451026674721, 0.08272791972323772, 0.05915401533486382, 0.03612636611045849, 0.012905601442100541, 0.023899646888997768, 0.05272748376873713, 0.038498304558977965, 0.025272256199030146, 0.005775224680321352, 0.057373688285869945, 0.024244836531579498, 0.07512054406106472, 0.050129744734975605, 0.035356666081615036, 0.056332425409627546, 0.057018924459454515, 0.012322672691586758, 0.05899631230521107, 0.02769304615926118, 0.019344650884909977, 0.05132777218316352, 0.05448697322619058, 0.07514975499361753, 0.12179625115447468, 0.02910196037602521, 0.021166729725777142, 0.06289494907363288, 0.04121473742528789, 0.03441346629012016, 0.09914818700523147, 0.04173839682592981, 0.046062116631336754, 0.06903828091679082, 0.015466419825961274, 0.019616769146054022, 0.02880183202514966, 0.04476778810062716, 0.010616253975087838, 0.024850220276763844, 0.014686918659736554, 0.046780802865302375, 0.041623119745523705, 0.149755526273962, 0.032249589660956014, 0.07282512247442238, 0.06300794321202463, 0.08946295106603254, 0.012386067424930874, 0.012759329401887955, 0.07728933131382351, 0.010078511963177834, 0.05219928529714385, 0.02000459158162196, 0.06468692448951545, 0.03950259220155497, 0.025754916489184387, 0.07470301848145262, 0.010250594463169335, 0.0388885957128819, 0.04802779099273105, 0.02399095882391257, 0.016787275108658982, 0.10140393289827532, 0.06651024439281995, 0.04673329775311774, 0.0188076117586705, 0.05851199534992057, 0.09455243320835215, 0.06642383733584035, 0.05168998621464257, 0.05532172178068469, 0.010341513778022941, 0.041120060449165684, 0.025183368932395696, 0.10087396859401658, 0.056649355983902375, 0.0475809050934209, 0.03367681912476978, 0.021736316097479676, 0.08880236110980473, 0.0657065032470611, 0.018898912202266437, 0.0579547161807216, 0.009306033907998956, 0.061790280930337414, 0.08260629560437896, 0.021148374259111383, 0.023471279250037287, 0.027556659526101528, 0.048205741726222544, 0.05169975383567715, 0.05057184641519862, 0.0684292716605048, 0.009053244045184506, 0.11005766209094756, 0.04680511849601904, 0.0837033335119486, 0.09025612019843633, 0.029811267778577826, 0.040841782841110424, 0.055645432233089404, 0.0970057301944302, 0.02898008727859105, 0.054473256421906334, 0.06017091278467448, 0.03125618812778304, 0.0483682059923247, 0.038957685352333134, 0.01284137167291896, 0.030825089385372498, 0.02548475749790669, 0.023636993644158208, 0.03666530130431056, 0.005043649495834666, 0.012571319933950663, 0.06093417767495398, 0.04918616572995821, 0.023793327291646314, 0.046583864642607595, 0.02575219687705319, 0.05292207776238361, 0.059802052940452294, 0.026310132966647228, 0.0393046350819209, 0.015496195748358246, 0.0893350680088324, 0.058353173831898364, 0.07300936662021183, 0.0180631926313283, 0.010475303373119284, 0.0506213280342279, 0.04429849029909219, 0.03772134584705195, 0.033208501915777885, 0.02265683585597623, 0.03226178578071056, 0.052972095642959884, 0.04842865032955043, 0.05266969009572941, 0.059950911485019236, 0.04684324286157086, 0.029670755761945923, 0.049843549608222903, 0.018536671357710036, 0.04078997231479134, 0.04670964095801596, 0.054827790421944474, 0.01809135785386447, 0.021531701673783606, 0.0506310650117455, 0.016173372465756633, 0.03103199441196217, 0.07009596488769017, 0.08318663785053838, 0.031226843129843477, 0.030244739478333827, 0.03192427808478956, 0.04267508103962868, 0.030229595835290612, 0.027626748910293947, 0.059878677054638826, 0.03418247545919111, 0.04999342321928951, 0.062453797342435974, 0.03331758517531618, 0.016945629313047376, 0.04697416728783039, 0.07582158345969454, 0.025764316388015306, 0.026561750714937528, 0.028038660980640884, 0.041949205070493684, 0.02889240276999772, 0.05195577658953206, 0.03319371258839965, 0.041499871520265456, 0.05205294335140817, 0.07181053861014305, 0.03925725637424377, 0.04016834175995281, 0.06610109215422023, 0.07917255929280674, 0.011629931940396708, 0.013896212500009327, 0.05396282352927712, 0.09409807412134064, 0.050942747883739016, 0.006624612217438558, 0.05495850800446445, 0.00833276516547607, 0.0263554796261052, 0.04411412357923485, 0.08232079761763735, 0.06386251046111988, 0.02268166668082197, 0.04790620134782888, 0.056420517860040556, 0.06635115091358462, 0.015892355135762166, 0.027055749106371117, 0.08498496030487361, 0.0185347676292182, 0.06771307904273272, 0.04543222381823486, 0.018016445946188706, 0.026160523655914494, 0.10600971478608348, 0.03458672090463581, 0.03407130077961953, 0.04259257337018367, 0.027897639515539332, 0.012122035221827608, 0.015798647260864176, 0.06423874007117364, 0.043780243309635314, 0.07068393736957543, 0.048274544082702174, 0.05255991735705926, 0.04495064945771329, 0.019715385729326837, 0.033584367634067615, 0.05349311204026303, 0.06720814283096022, 0.028689950629467928, 0.017914897161385706, 0.024116771528497342, 0.026482977724123388, 0.0812606085392256, 0.005569920777493427, 0.03843564239721145, 0.06604568101465702, 0.01339607391386263, 0.027019748719589367, 0.025938961452113527, 0.0042896092617734066, 0.02828128485670013, 0.0612435354700973, 0.018608089904451085, 0.04822867456823588, 0.05542194140293906, 0.02698337103450491, 0.04860407680333142, 0.07404989788248655, 0.01918285311530194, 0.05019105092111615, 0.07274331194498847, 0.03357101089110778, 0.04885822647221146, 0.05913087947955055, 0.017317017247419686, 0.060483894175699646, 0.010441300560600095, 0.0223322635546567, 0.03275818777300658, 0.09127333174429594, 0.20647496015073794, 0.13236577472379132, 0.11129617345549407, 0.08738853818466587, 0.09211219802138307, 0.1357915054165548, 0.3046469979228512, 0.13051512080334848, 0.14891364161045323, 0.13898855886392056, 0.19254138362744164, 0.11530614578195157, 0.13153505962221854, 0.14310560729955474, 0.09230283900134026, 0.23782477954462652, 0.20981645181534753, 0.2025519464645655, 0.12084435626503923, 0.18880785412846074, 0.20741157924696324, 0.1616461454860626, 0.18339962578348576, 0.19459187924381227, 0.09955030655668629, 0.15120412192998395, 0.10431233973753068, 0.1473053013004603, 0.10609855034178305, 0.12024434854186351, 0.20527905093566065, 0.16746259144236966, 0.10447809052082802, 0.14758751277000676, 0.09440817119133088, 0.11037663045910098, 0.15006807482530996, 0.20372358601420157, 0.16595719802764156, 0.22740313392733374, 0.16084843345226782, 0.19328176164098326, 0.23563243508819612, 0.20776710533086332, 0.13670900295819008, 0.1010035830099256, 0.17564019699010158, 0.2855334106472231, 0.18942496859498564, 0.08966913596997339, 0.09463041329816466, 0.13431628054428485, 0.14106998911067364, 0.18202246016552373, 0.1382793146636217, 0.1501690758572471, 0.1076121868625764, 0.1701564017322756, 0.20818656911292385, 0.17216330694575466, 0.2537292245054438, 0.20463414279924286, 0.1022153732276732, 0.11702259641981895, 0.08359061133476996, 0.293010949727989, 0.1715711669455613, 0.1673176476070958, 0.08263004433003165, 0.07405206591131226, 0.15320138975737557, 0.2152913451314934, 0.10842485293265312, 0.09786354948676403, 0.1936683142858167, 0.08863734577091471, 0.1968974974607268, 0.1712077807995581, 0.17512674954149032, 0.14923864675144996, 0.09027269068023852, 0.14497789554297924, 0.12698119551303888, 0.10338620072410953, 0.11370895971213618, 0.13102438541189318, 0.240425372255906, 0.2136296391366951, 0.19734722171579638, 0.16672274969037504, 0.180474610158032, 0.12708494680062418, 0.22279549810674884, 0.09596932814606736, 0.14264174106140293, 0.102461532599503, 0.08729852285356292, 0.12077520150811442, 0.20841356096488817, 0.1332012702140116, 0.15875221770857612, 0.16160670727972062, 0.26338056871487253, 0.07057917484593007, 0.10923626261853403, 0.1101461529070812, 0.20860299918680422, 0.11518681226598641, 0.16681800506288008, 0.15214435696121187, 0.09195387063007202, 0.15369691074855868, 0.13120325162045418, 0.16465970555380469, 0.18698343105854529, 0.07751858312516444, 0.1179337737360789, 0.27794779188209967, 0.09557441748198002, 0.15715754440715238, 0.22121069201778984, 0.1465604493334409, 0.11128783075799865, 0.12134494109740182, 0.11511869172775939, 0.12656049832942026, 0.202670659449312, 0.1085424321072717, 0.14284860012271713, 0.18984129141655662, 0.13402614772560137, 0.07646751049305163, 0.11682143705266139, 0.3217298699723136, 0.18556814490547105, 0.15302255419233154, 0.11461763958176298, 0.19727154755063597, 0.15609969955778893, 0.22783782753732898, 0.10608344308791623, 0.21988269392280813, 0.16419041541314897, 0.16044314229680648, 0.1391558877883419, 0.15431816208987467, 0.1893432423352234, 0.09768682066351177, 0.1786838643132679, 0.1240984526192469, 0.10367012823060637, 0.13415328767751494, 0.09856437438077505, 0.1593754302349783, 0.09402544898611885, 0.10256550605258635, 0.1736644868768992, 0.16621612042428988, 0.20673193668405856, 0.2058672838874402, 0.1309415100202445, 0.1703089451597583, 0.1102959154353988, 0.1134012528364697, 0.16515225412384157, 0.15489806000503803, 0.23060199534220083, 0.13536238892664834, 0.09316187637347369, 0.11419244546202884, 0.12166113622726933, 0.1986591626078852, 0.1864257956584615, 0.06643578064657989, 0.1232572804175077], [0.017924567106209936, 0.0931718125338516, 0.034732836854433825, 0.04507107081853094, 0.04787455808611647, 0.0330023285031559, 0.015360035111136256, 0.029586338618349646, 0.023730893041037267, 0.009456119150854647, 0.055397415098043225, 0.027874513236325116, 0.06836549484080846, 0.07016095212630688, 0.0341507057929712, 0.06803829102746903, 0.001443953642005762, 0.012479554091940724, 0.03187047956030696, 0.044124875623252124, 0.031184200760758216, 0.004505755702754664, 0.02059539284316763, 0.03892796880175029, 0.04141582018365303, 0.028455523894198483, 0.03631704922525152, 0.015056901780377715, 0.03958382816504567, 0.031123124400994955, 0.003876225345001947, 0.015241754966066971, 0.03342007241782642, 0.05049247587580354, 0.014264740053594354, 0.04343641538833899, 0.012964931121396442, 0.028065857101952838, 0.0511921439770489, 0.06308873867495887, 0.04661345861912255, 0.0015955048659253086, 0.09041546648668666, 0.06693844923809653, 0.07065507883746779, 0.03632278722380439, 0.04171278650662111, 0.06272819854559437, 0.04058531958669905, 0.07563167792414466, 0.05332456886648171, 0.06203886497044756, 0.01832654876183839, 0.051475734404859044, 0.033276247070922006, 0.05265273656996508, 0.07333820220082998, 0.017922762969148257, 0.06665760140505529, 0.06905507356409105, 0.024130752633115458, 0.0068079495066476455, 0.10647843802167524, 0.03244356695382345, 0.06826073997804234, 0.049008965762632514, 0.015753477759238695, 0.041425124321493416, 0.09260064802102505, 0.02301814398848482, 0.020671143617120483, 0.0596150815216524, 0.07156532152646011, 0.012152432633053151, 0.030619373710285273, 0.01791313324394005, 0.0870069191460648, 0.07438870792787883, 0.05155828037870027, 0.016378858314466574, 0.05857589857412442, 0.045317482999375755, 0.0313323334370169, 0.061289554371708826, 0.0874289186791547, 0.021931344846023187, 0.02900485873162266, 0.027385835325525656, 0.06320977673655556, 0.03749862876570514, 0.028006157785233472, 0.10092996196040224, 0.011804925574500476, 0.03344231578070791, 0.02415804260019814, 0.04175081894162201, 0.01014396172737883, 0.027219873868049155, 0.003640604948985481, 0.06700063259491036, 0.02127403757655092, 0.05306705607161407, 0.06760798710127992, 0.020941754600273508, 0.019344292738805377, 0.05465527891271538, 0.015874806934246616, 0.016731540296947765, 0.011509919479008646, 0.04441671298756715, 0.11816468029733627, 0.021044644038943995, 0.02848990592024019, 0.03112380621924756, 0.05271678918131417, 0.06858320170713049, 0.04501350314146088, 0.003987849143619139, 0.07086523207685641, 0.01854692544457653, 0.0037304208578256472, 0.05213227558640703, 0.061114713955189914, 0.04803410355722712, 0.08082352473490662, 0.02128532013645576, 0.027750416568690733, 0.027818519869939457, 0.07561690008808529, 0.05490135784531313, 0.05469863948922965, 0.05760123555157935, 0.08304560872455759, 0.042044958400149504, 0.05116604336146867, 0.02365995138402908, 0.009233191395328652, 0.06488462880013451, 0.06586516005617958, 0.015832621345086204, 0.02017377252360025, 0.04566080913308167, 0.09446500725443326, 0.04174603089209526, 0.017156895295146014, 0.09114860496934384, 0.011182179404122215, 0.07968920132806225, 0.03557570594092531, 0.02459530835039914, 0.024320910977680358, 0.06669094921239922, 0.02896774177169127, 0.03943187079482502, 0.02951363495911562, 0.013692451306738922, 0.02756546953723075, 0.055607292545779105, 0.06054296338510129, 0.03341362195750398, 0.061582927742312034, 0.010823400319373656, 0.0608245964582649, 0.010232891128849118, 0.03506154603054447, 0.06525457265876955, 0.028289550945403117, 0.03227841754954669, 0.02517001985031511, 0.0408818683917484, 0.019042065307017297, 0.03723055544880129, 0.0397732932000391, 0.033307457492957195, 0.04182958810199653, 0.07416597552477353, 0.02255812351171288, 0.01684914053898425, 0.04476944285054361, 0.08483271565168135, 0.048918241800199595, 0.02392366183020415, 0.03794454556379107, 0.08246093808162598, 0.012257679707310613, 0.030719106866707726, 0.07227445081357034, 0.0036889448576051024, 0.021835166337569396, 0.016131042277500514, 0.03529831699486222, 0.03270167346683241, 0.036732793650439674, 0.05497521255165339, 0.023190350977764018, 0.01553629183270518, 0.018817011657501423, 0.04880076604745081, 0.028101273346692327, 0.042745622415696426, 0.056820323825964046, 0.04041595286839912, 0.047085759485320705, 0.059008581203318415, 0.05496986142750229, 0.05080271467205979, 0.07189395792421795, 0.04934781794286063, 0.009485665246874336, 0.0229235359602758, 0.016931586921395316, 0.04890855078795745, 0.02577688597563294, 0.017517123243681366, 0.0826089539294762, 0.022145611977565195, 0.0924350351335541, 0.09327117413763078, 0.05159941546979451, 0.027162398121530013, 0.01773660168832829, 0.030445412379659476, 0.02887334633288124, 0.05722798219311142, 0.020693293134231242, 0.04644553980699951, 0.034820783748141224, 0.026800965499733726, 0.04184433529453893, 0.06219805421067342, 0.046575092935874585, 0.08995288727624763, 0.06036713471516006, 0.03117340275146548, 0.12423738266431517, 0.03665335799357103, 0.05168229469188279, 0.05807103897114435, 0.05865047340311351, 0.05380486002973011, 0.0680214447540141, 0.1038135092465147, 0.04352346595917498, 0.016639299480424776, 0.10554001861882788, 0.018813719394646825, 0.09955464261433772, 0.014728639808092869, 0.04430685597922533, 0.06204171098708626, 0.03960887540973002, 0.014679773932232734, 0.07764839672393377, 0.05918130338672669, 0.05413902375186163, 0.02065193204719934, 0.054765676013043815, 0.11183963622897865, 0.06191466679616321, 0.006326581989865631, 0.06917775488428532, 0.031697931661901456, 0.008172103121215779, 0.08174821584215088, 0.048919961667589607, 0.05849696087440657, 0.008974300599807214, 0.04484092651475822, 0.0597532301570379, 0.08845283349435176, 0.029020720582094886, 0.032284216835133495, 0.06667715196888294, 0.05373671650886536, 0.03775979963041121, 0.01011459566202135, 0.009407813476789142, 0.02051560670107363, 0.05438753884405859, 0.02879948588088155, 0.040556468715470646, 0.05355929820648125, 0.02184281955593296, 0.06549778259209087, 0.0187590743430079, 0.05349136535979567, 0.03069595377441616, 0.02672536794336573, 0.07500992862567787, 0.0646250092634751, 0.05613728749355482, 0.015094909317521079, 0.05164085316561884, 0.043774915168121944, 0.09482219574912902, 0.03025657170632434, 0.06799719041033138, 0.02461669752524505, 0.019984033612173893, 0.029465302471972765, 0.03490678860896057, 0.05989132899670832, 0.03342086148838843, 0.056846516372095195, 0.031315561857134584, 0.1225528242667356, 0.01917525926875251, 0.1070748221489691, 0.11369651078336662, 0.045829674063791195, 0.04292535813405149, 0.017367594372180682, 0.0654495190528612, 0.038683468010276556, 0.06908718796987688, 0.030061922171303344, 0.05735837801870319, 0.04168423057924356, 0.04362575018838529, 0.07499810788900622, 0.024827432991456122, 0.06379871448922543, 0.017990441091599006, 0.04503815968130385, 0.09629629447215027, 0.032209573058231224, 0.04372415801269874, 0.08010719422130816, 0.013120621255028152, 0.033579284640690016, 0.03653660236347107, 0.028739049204535065, 0.021628447087301363, 0.033959823495317856, 0.04797713725917763, 0.06101857758157196, 0.022165355978593714, 0.061483439734025355, 0.027017536640708006, 0.019414110161784678, 0.00833885939491372, 0.011100696377275933, 0.027302994407833587, 0.012705449480563404, 0.047914115036086696, 0.016597603229926, 0.03955844384167464, 0.07815681863576174, 0.05886646423248514, 0.07140543131578354, 0.03628630228641053, 0.02508267433562827, 0.12807682381882785, 0.1716977706359279, 0.12975986536231734, 0.13612916633006067, 0.11294743001100518, 0.10498977596721343, 0.10298738301160837, 0.17557366991475706, 0.1045751998261098, 0.08353802705964736, 0.14184453464563818, 0.15475184446380985, 0.14241995860732373, 0.1240925460813507, 0.16213890856071828, 0.2245706310796161, 0.18383831837244574, 0.14819069975806823, 0.09299904438516787, 0.07779802135642498, 0.12783328446769907, 0.1660341132552393, 0.1386686865120165, 0.20763541481667952, 0.17751999289518405, 0.11044261361201925, 0.1156084364159934, 0.17071500240314394, 0.2252321480022323, 0.13689962095550953, 0.16873468044063739, 0.19134728237986567, 0.13823471302467008, 0.17894237302243712, 0.12453373611694384, 0.24085505565087642, 0.11122349469411759, 0.08593605080198857, 0.1904410616524758, 0.16528622758003975, 0.2387338501190947, 0.21259972585305092, 0.2191208960909036, 0.10789570834247336, 0.19436481078305554, 0.09880933865544297, 0.21162440399489096, 0.1400441820583036, 0.15984318819978546, 0.1782984454785624, 0.20595268736923897, 0.1442979159013879, 0.12989083575385232, 0.14235415165462803, 0.12474375146050608, 0.24450250751068517, 0.1386501625060074, 0.10373359095425376, 0.14870128203784266, 0.17746310320592698, 0.13274757762349423, 0.13819944233663622, 0.21789943018267233, 0.2129533367171403, 0.11937556653133324, 0.18561417146796183, 0.10053152729186321, 0.09191661577431426, 0.18139074406316205, 0.09214238954647895, 0.15159295751683174, 0.18431105590876073, 0.16859281627881914, 0.08403154856134808, 0.0861906064974685, 0.12913415538928202, 0.12708456375666205, 0.16679764244585268, 0.1723390475155846, 0.06516997356929126, 0.15120019955981165, 0.1646104920655489, 0.18629841055841218, 0.1251090911307162, 0.19374568916616902, 0.09381322730933467, 0.08905399801029314, 0.12724399431458405, 0.23285380354331386, 0.15352351440777703, 0.11812262973117253, 0.15027353960660197, 0.08726005757888479, 0.11008310387091291, 0.13660864544010934, 0.1613721771225814, 0.10942958490622622, 0.11051492465119209, 0.10515649202129534, 0.10212419344292534, 0.09797209648475533, 0.22791108086464867, 0.18687705208937969, 0.12288706076721992, 0.10218954074286646, 0.22565531964984634, 0.11352013436055954, 0.11242231504330713, 0.08989129380713548, 0.13580457487654302, 0.20930156412143863, 0.09230319140178543, 0.1222803038094313, 0.13681153616597577, 0.21536176393349327, 0.18745184785896735, 0.19092650092657537, 0.11384633459871817, 0.17773282744230764, 0.15631683951904699, 0.15552101206154595, 0.1615741485429387, 0.07269645800753947, 0.1167391821922314, 0.17743592240637351, 0.07618356000391707, 0.11077888024550293, 0.19064022919103024, 0.13016615243208024, 0.28917879406963626, 0.15448915291457407, 0.2300243190820179, 0.17095670314325442, 0.18846063243765987, 0.11355424059494851, 0.16892963449560827, 0.1278077660789413, 0.13045545787580554, 0.15017914225257215, 0.11084598188679065, 0.1413662353109929, 0.11828799747050771, 0.12151159586444979, 0.20596338195666192, 0.0821626311047904, 0.1796513720746002, 0.1047976794202001, 0.08958684280514718, 0.17307518140202569, 0.12367000262583457, 0.09300014755177884, 0.20380814679928366, 0.10072677246024532, 0.18037373170016274, 0.16128807599025388, 0.12835440811731164, 0.12092340887794573, 0.15314943367435088, 0.0843414617702365, 0.19125555101181232, 0.14605283947481265, 0.15049089407247884, 0.14417859004630199, 0.12287731612882308, 0.171768986169369, 0.13560778221055386, 0.11779082172940816, 0.05637326172643131, 0.20169670122765726, 0.10401692091216964, 0.1371137731738629, 0.2942852603812372, 0.18953496349915383, 0.14798289074772789, 0.19989567448294934, 0.13935517790096422], [0.07287895547286158, 0.08111310597028464, 0.07135077860326537, 0.04484039791409047, 0.07144596502785722, 0.01696292949359744, 0.0555420027024323, 0.005921027491680317, 0.015636584233312358, 0.05973413924596483, 0.05898722267198948, 0.02613161915853139, 0.03549645414515849, 0.04594092152171558, 0.036234415151299014, 0.0720302373050682, 0.04396421932465127, 0.067873559141111, 0.036549461149280114, 0.0631714991534189, 0.049228243109199314, 0.014798046416422773, 0.020952288309232365, 0.08532242203551917, 0.031938747570459405, 0.0680136766224619, 0.08446937547095361, 0.01762627545113285, 0.03580007394174895, 0.05023297891321202, 0.049621318992708004, 0.017665981788248304, 0.044796753885044206, 0.049536103202450665, 0.003058120050662828, 0.017791673833985003, 0.02407877356745303, 0.06861883245648877, 0.027886031368266673, 0.06608101298972484, 0.02057125149745374, 0.006698062812398759, 0.019456930646312334, 0.015771215567515505, 0.0675082041491424, 0.03517678480655436, 0.02227167940638479, 0.008855677630391814, 0.10760849431878138, 0.03976442190187593, 0.026956996542491743, 0.10054917029675939, 0.06730633232021524, 0.024965508848488815, 0.032246548291896625, 0.03333131730135891, 0.03978336342580376, 0.058904864389689705, 0.014992847253808813, 0.07530766103657023, 0.041493930508412664, 0.009975010611777826, 0.00598025183388663, 0.006816345351492807, 0.05174466574023809, 0.09128159783299893, 0.04597911100474097, 0.01167522688891979, 0.011268950352865842, 0.04359327189083542, 0.022271595136713118, 0.08086407376873879, 0.01425138809868405, 0.06838401884681757, 0.05845234391369647, 0.06663625819548484, 0.04986429909965204, 0.05526408132526183, 0.004279936444119461, 0.0864323455419752, 0.01856407815320117, 0.050996554069100856, 0.034044139132264166, 0.059626814158212756, 0.03126059887900708, 0.04709977506389541, 0.011120528478415744, 0.008181493443947646, 0.06475679936908907, 0.0628039454891076, 0.06459261140515728, 0.0395466958833558, 0.026457185458932674, 0.018809586350295334, 0.037389185444842425, 0.06894035189743004, 0.0350015421938752, 0.04388742284068177, 0.06809151115556879, 0.04713753170724358, 0.05741098144602391, 0.04574180760931584, 0.054285089905944564, 0.02908646816297645, 0.09321341876901927, 0.06712265507948977, 0.03414139016381195, 0.06470765482874648, 0.06754236400968607, 0.036446767063030315, 0.02921151861007656, 0.055087180132226604, 0.026548570172200282, 0.02012002379483273, 0.021100286920104298, 0.06687736138701439, 0.04335668095717988, 0.062073158896377975, 0.05023934510386279, 0.001339930632609814, 0.016378749146937363, 0.06839380945048987, 0.05853675914207294, 0.055424687828147606, 0.06344871572969903, 0.008053337467924483, 0.00738847513510395, 0.0443311371359854, 0.018580809513467456, 0.0285735416541537, 0.021472935069112048, 0.05940862848693806, 0.04546531498612416, 0.01325800188726956, 0.013188633583335867, 0.010934801952492808, 0.06112372697961908, 0.07190010194937069, 0.054389611111893776, 0.01153291839610545, 0.07908559299164242, 0.07253399374143732, 0.010995600605383517, 0.043235279003819155, 0.026129493264541514, 0.04324655198762494, 0.07278507905862025, 0.03856408852903593, 0.03529397327633154, 0.03254876997802527, 0.026821002529393283, 0.0332956290954063, 0.00813941031904711, 0.04802800932778947, 0.05553744830972245, 0.02987216027723926, 0.062330372916955146, 0.0490156039144964, 0.005912030746619548, 0.07178532665655499, 0.012308183096108899, 0.04624313171652537, 0.052077764600154855, 0.03043939092857463, 0.026895437547336185, 0.06328288833760927, 0.021115579950292746, 0.022357563608356064, 0.03307173606909571, 0.043707893966066266, 0.058465459338960156, 0.05351446291071273, 0.04732725721213126, 0.019862388425897208, 0.038419500924646854, 0.022340625404350223, 0.02022744464357534, 0.02424501081658227, 0.049453327402232156, 0.04341098893013212, 0.06811085487565688, 0.07063729027586599, 0.06592822441410634, 0.0514881641814305, 0.019528525393275965, 0.010862232358645528, 0.04772586042001363, 0.042137823578330784, 0.09037300989392305, 0.009954941980991392, 0.003627610182569873, 0.09117430721920344, 0.0032087209664525525, 0.0025785384763542924, 0.03727430673015695, 0.03652753571288721, 0.04037036297602519, 0.057664897458087054, 0.036780329406141274, 0.023815015240782694, 0.011376718814004094, 0.07364966290732546, 0.07708449472462939, 0.01707177909631883, 0.048963881488288605, 0.02845319498690867, 0.042908339490813595, 0.023060332450474945, 0.009945735519361353, 0.053987533695274786, 0.04265623144625176, 0.0151702961997099, 0.0013639421024802894, 0.013093816796167484, 0.07798990339881952, 0.032570883105959625, 0.004072731685629416, 0.04804895034119968, 0.03419100201778835, 0.022070964370223305, 0.023551243507573684, 0.04630612712653895, 0.05421046911168003, 0.01606654150471572, 0.027839782640277862, 0.0239478855303699, 0.03833264570623156, 0.030100142297845696, 0.034446798775705605, 0.03537955678879254, 0.04160200636233053, 0.043863624319313996, 0.012095680839622454, 0.007798111445510821, 0.04407911336109523, 0.06709221840625809, 0.049459157331335935, 0.041888048271498377, 0.03850866206771424, 0.023187141069361282, 0.07604750278856486, 0.06368025814393355, 0.01784678811447755, 0.021364711743268757, 0.010665674307083171, 0.04535809715068148, 0.01667632834024487, 0.06598652370514409, 0.01994960753607654, 0.032158854207204234, 0.03431808834354724, 0.05297091969799611, 0.06686345689118871, 0.05408832788347237, 0.10353430850251068, 0.03176837536175886, 0.03630540085836284, 0.012399575470255749, 0.020249892934976567, 0.07022161862903065, 0.006907409265442121, 0.01741494626678046, 0.06754647024096021, 0.04474559836390038, 0.007992979794395188, 0.02424200583669928, 0.058166616100577585, 0.04878241441122467, 0.0517373840745178, 0.023264561914989067, 0.08393978654977777, 0.027517872494495207, 0.016085145949956872, 0.05702498421493558, 0.0960568153870202, 0.045494073926801645, 0.07581206864767498, 0.0604722879436468, 0.030295649851341883, 0.016144400935680155, 0.062403135948003306, 0.00776749809325162, 0.02954272523282036, 0.007813051117644196, 0.014650413612534684, 0.04590762351008673, 0.059797352991036834, 0.044014172087753975, 0.03307931267866685, 0.05793719958033293, 0.026515032758095095, 0.015931625760370688, 0.06168561033724297, 0.05083739164195234, 0.04776313825840912, 0.014515534257366052, 0.014268832878329822, 0.029571645051961946, 0.10272958676420874, 0.036686012491343484, 0.04345033903636279, 0.0511878309020352, 0.03602212069616203, 0.030587207593564546, 0.03735003069103245, 0.017884192357380545, 0.052045309285242716, 0.08520235307514669, 0.015783420305759195, 0.012287736209409853, 0.07666801868547356, 0.0387127019254671, 0.03379609518414063, 0.06505338264809502, 0.05890011081411954, 0.032101954941848115, 0.049538321026991454, 0.09507393224104758, 0.047169707400063356, 0.09083738941098414, 0.04885668663548366, 0.05373549076818651, 0.04260118419845258, 0.04395258627952107, 0.022197336318992802, 0.09340819662376758, 0.005581318729391863, 0.00590718811332819, 0.0400175373520582, 0.028131554887119322, 0.04206410676781689, 0.025907335427379417, 0.024247215234584386, 0.011142700978164232, 0.05098836841962991, 0.07129390423576679, 0.03784035760608893, 0.012349140071760745, 0.019179258247717254, 0.026664257109645876, 0.046144965209908066, 0.020762465128134337, 0.04412070810494404, 0.012021651848279422, 0.023402609043724598, 0.03743481747205219, 0.027511021753232327, 0.05606314933468258, 0.03604076727623901, 0.03673262511109633, 0.0846286221677738, 0.028936969934992736, 0.14041804828711096, 0.18440963610285716, 0.1329667094133554, 0.17993946709940511, 0.16938269889402777, 0.15451179847361582, 0.17298246944142928, 0.21773285202441678, 0.12952570292738178, 0.11630055089030536, 0.19030932517301655, 0.17149158573198706, 0.15688363733070512, 0.10899203378827342, 0.11843863333905898, 0.12196597793409902, 0.06410661671731262, 0.17205936413618828, 0.10522166312101389, 0.1868893094961682, 0.19904963762289096, 0.08358976863805326, 0.13999568869269666, 0.12365723194013681, 0.13667963114717316, 0.16175519044120468, 0.0904556171547982, 0.10535378264443529, 0.14150800754226026, 0.14363446843720254, 0.12306051839503551, 0.09226782878320064, 0.13924409515194355, 0.1341060660178623, 0.11900471102806831, 0.14619819699756562, 0.11816250460763132, 0.17621909899096336, 0.17537859328571828, 0.15903553234473353, 0.10129850387813584, 0.16963529340442152, 0.10851921198228676, 0.08278204383508814, 0.16847137602106219, 0.1661081173487248, 0.16372003742764074, 0.12418436937995496, 0.17732191320148208, 0.09082723874598743, 0.18641484060114433, 0.2060714769627779, 0.12251189984982053, 0.1621926726112443, 0.11727555865241636, 0.08998982037507719, 0.13773617364706534, 0.12134828124075167, 0.11185848199191595, 0.21870979798897622, 0.17713701022007775, 0.13574244514588388, 0.11180477156754463, 0.09845510726013491, 0.15530911214168996, 0.1764062389491066, 0.08552015698965519, 0.09075542566396537, 0.1258596121483753, 0.11372290251235809, 0.1775771890196108, 0.1412775529728782, 0.20528885686109144, 0.1238981282879268, 0.1647372183299834, 0.15826869365428725, 0.11640354375084562, 0.12960966616388292, 0.16046063974499702, 0.21872516571273729, 0.10698157392682568, 0.15191880535454522, 0.10530970960615144, 0.1744627198504825, 0.13158563674697954, 0.11666084970197371, 0.18466155645587753, 0.13400452872437818, 0.14300318134407844, 0.13160742428754607, 0.14058220560752577, 0.1380629714338049, 0.15854359664503606, 0.15244135392769692, 0.1880421645699009, 0.1693178112468412, 0.10912135709077121, 0.1257283583043083, 0.26759141695595556, 0.11743020116081161, 0.11857299750009853, 0.11888177689885902, 0.16785917983901116, 0.09755904485862102, 0.2226369179064228, 0.13898940156063727, 0.1577229785823053, 0.09005083161736689, 0.11257760106555878, 0.09507665951405803, 0.09771099839840205, 0.14546667496042867, 0.11910795669762358, 0.10422656853352824, 0.1413255866857306, 0.17744131566536042, 0.23257041229836403, 0.16543006824870266, 0.14352263492201606, 0.12850527381224017, 0.15973258042527785, 0.2299746765845245, 0.1924775378598321, 0.12114264025923707, 0.12939721466072146, 0.162668367246947, 0.10585344817128875, 0.2449229212417718, 0.11521627600755423, 0.10122945637352045, 0.13066026382148266, 0.14216269096059186, 0.1916135285770701, 0.12228759696647046, 0.2270695179580681, 0.16462798951373947, 0.13507499870273376, 0.15884952619671822, 0.19334286481382387, 0.10854682179107782, 0.13670979968963132, 0.12810524568081866, 0.12693785791916232, 0.24702293678156792, 0.13034630566835403, 0.12409043933955893, 0.12342356746235203, 0.1095974577530738, 0.1531161854584371, 0.19538550036809138, 0.10748087939235473, 0.08081384904442296, 0.194940862936839, 0.2738143185213689, 0.12519622597122385, 0.08930903634116535, 0.08498155121361056, 0.14393713445432726, 0.11333392902968392, 0.16688650864506924, 0.12909752106474293, 0.09718252030471641, 0.0962415345073227, 0.09618626126358587, 0.10835207457984648, 0.15347833054200297, 0.14999454570633752, 0.09912027076127068, 0.0935263580252086, 0.1668147874935981, 0.2131454102815159, 0.15804445971885037, 0.18522142883270018, 0.23312616312215406, 0.10389610118563138, 0.1284032079180883], [0.017443513685476877, 0.01296766509767622, 0.002464086137479171, 0.03482167624057301, 0.007776322947334379, 0.04574626241059554, 0.030457357605618816, 0.03187559894286096, 0.0293499430371148, 0.039795291414784814, 0.04512133001680336, 0.021308819883533066, 0.05370976553568917, 0.07836050609306944, 0.046839075343262766, 0.022833304209334236, 0.04085435051350825, 0.004121779507371567, 0.0218981828150009, 0.03945232917284293, 0.0567712941988101, 0.03473744104285875, 0.026737048868991198, 0.07797235232447425, 0.01796038171667005, 0.027413203816620574, 0.01222903280699205, 0.016715414146141663, 0.008867096170903215, 0.1685500685726443, 0.050393788429397735, 0.03672185391488095, 0.0300236503338261, 0.12333562056864462, 0.013015981305450683, 0.034091345470158324, 0.008682501539888402, 0.017722653142446955, 0.036041782342738686, 0.061911920370954665, 0.014385956230633443, 0.08778937070840791, 0.04327827951900902, 0.03344632242055189, 0.02225846247447114, 0.07682534250160379, 0.07347062049854187, 0.017103123583740765, 0.04360048460864252, 0.031272145739245805, 0.04979496048162541, 0.05088113909286838, 0.04264469799255172, 0.005181259954453356, 0.0631756513499685, 0.038487613801994634, 0.028197359924595204, 0.024734441408767335, 0.04828548764870052, 0.00980496590566491, 0.05732019619655706, 0.0633399848706059, 0.008710276057583191, 0.044564414739368424, 0.019329794524838368, 0.038363427119029146, 0.036787228027899424, 0.0953513403393088, 0.05344255406770015, 0.05286460967674371, 0.030958218229634148, 0.023847612281960827, 0.08206046561920836, 0.02440982314217235, 0.056323040832555106, 0.048211054545977426, 0.07935340966909163, 0.027374108434624733, 0.03489901664696875, 0.008018974594080882, 0.03823186683979246, 0.03248805751002604, 0.058745054618245175, 0.0328255920190244, 0.023001659691574115, 0.04210280569931192, 0.02959732814962345, 0.0881575908692133, 0.024310461538393172, 0.09128484604579788, 0.018504652712914734, 0.04557598021722609, 0.015529450667541356, 0.08772276702427095, 0.018931440295531385, 0.06856545911080415, 0.058052373238869255, 0.04115432373157913, 0.021845205919817094, 0.06402865577969821, 0.0505285318039598, 0.0036020589956728324, 0.037223419339786616, 0.031572034687645016, 0.061891105762051965, 0.04076468375241084, 0.03445280107459234, 0.037970623196733576, 0.040155498295902245, 0.06781329100410785, 0.020798329534309528, 0.04917425689317527, 0.04857713349103447, 0.02872841398892624, 0.04722775771252571, 0.03990357794288186, 0.02253100208397354, 0.05216148651895985, 0.023907911062480944, 0.019597896570039373, 0.01953068959166206, 0.02659131021749589, 0.04835018377390601, 0.016322209942905654, 0.019689384705176758, 0.0355794444499958, 0.01930934572291951, 0.06691176639569384, 0.014488285467509302, 0.02330093002397447, 0.026059285136720827, 0.050971843903103185, 0.058748264526647914, 0.009869086507317281, 0.06900690195541229, 0.02564062000132136, 0.02467498532496393, 0.09946304914211074, 0.03595967686945393, 0.05562400092340766, 0.0408223242078337, 0.04987786268635143, 0.08314893866378455, 0.03637591542135324, 0.05569418606859061, 0.04056374272031169, 0.056487194322530306, 0.0509212323043856, 0.07295285231403767, 0.03592365541525426, 0.04654910723348299, 0.04320224146208456, 0.05416387181368567, 0.051568128438966895, 0.04150045374708791, 0.016687208703989466, 0.049423001811749516, 0.05458457282774391, 0.0433393060830572, 0.007874784876607479, 0.09158525976442522, 0.042292761030576886, 0.01960621245445744, 0.021784960765451677, 0.063660221114274, 0.042157799320956396, 0.020553951316903678, 0.09100720046028014, 0.05613041951531365, 0.06311797259014941, 0.015602882110303449, 0.02616840287021572, 0.06120130487327134, 0.04118256939334735, 0.024973661939222968, 0.017022873958452575, 0.005232629980215984, 0.024614470124605204, 0.09817245912047164, 0.03893630000792685, 0.0004917006962416289, 0.01514115421507027, 0.04558536479429853, 0.06362724485957334, 0.05469923703781059, 0.03664526427465101, 0.028069679880695, 0.015918771762611167, 0.03103653348291353, 0.018129966770028396, 0.01631288473764735, 0.050101365007820635, 0.05711166706356791, 0.02557733347789655, 0.033739404677743876, 0.031033829192540822, 0.03051573350544899, 0.018669530155978376, 0.02064638940106717, 0.024221323377963518, 0.022426484708463954, 0.04890560517988859, 0.045167256987863974, 0.02430731100180457, 0.13694508061293634, 0.03206008823678619, 0.07919363437160369, 0.07565171878424383, 0.030594673120386662, 0.044729364960784876, 0.03548202870954429, 0.0584466748630568, 0.009516747349182205, 0.07381087845011104, 0.006825053377167112, 0.02725911097631099, 0.0595022022964493, 0.03905338505583425, 0.04957703911068459, 0.044084303606782234, 0.057371179347917925, 0.011001717817458895, 0.07663669335024972, 0.06818899584393348, 0.04389662355665238, 0.032007329676660805, 0.012750829656368062, 0.048281741478750785, 0.03485852123929128, 0.01747968452682178, 0.03929397113801491, 0.037272111888253884, 0.027093544054115494, 0.08718187064533273, 0.029526593336354823, 0.05952299775315389, 0.046193113835949096, 0.027977046444110816, 0.07002292606498926, 0.037789983494627866, 0.08409280495177354, 0.06964852357463491, 0.05109562838990843, 0.08499937807960857, 0.05567330251177473, 0.06334178900766758, 0.04970321762225321, 0.055365220253025337, 0.026038298158035166, 0.05193319997840351, 0.0020066601850445413, 0.0535846863602919, 0.06750320159499684, 0.01646592229184124, 0.015027386327874998, 0.0379314492907255, 0.030630989518437176, 0.04404426402141971, 0.03395615010372093, 0.009821115039108742, 0.017545843879962643, 0.02049218164756894, 0.006540408620851175, 0.058225049457002076, 0.038952345719500896, 0.060661519321823315, 0.03331752771872186, 0.035487988873595194, 0.023173460654253443, 0.04643482989781807, 0.013389313187930855, 0.01938276758958255, 0.06240995030008978, 0.04435844050960676, 0.03599434617846724, 0.02960054763412524, 0.01874888537361497, 0.010657601655581066, 0.04529417477427952, 0.02307564271764169, 0.10277181353059509, 0.02999794425352687, 0.0076269822461800954, 0.0480316290932317, 0.10975706451121839, 0.07126850842107689, 0.05720104271125409, 0.03279941479465173, 0.036684066628015814, 0.010993650911616222, 0.0579455346169491, 0.07043099811961574, 0.07439433867412229, 0.02820293895990378, 0.0445869070808253, 0.019989965047927636, 0.052067426243616696, 0.024032496111167055, 0.039544386128264095, 0.005691079497938195, 0.012073765936938506, 0.04832654230056271, 0.05664611926242229, 0.03702518259806018, 0.039109658044312275, 0.04805989773763765, 0.09328107965449173, 0.041578280619315566, 0.021077034236382575, 0.055439760608057824, 0.03753681058785127, 0.013781712041236462, 0.007494299169329386, 0.07664174186967074, 0.04481575669600599, 0.030616428102216417, 0.05508755168486988, 0.07927931364505522, 0.012028064961815554, 0.017935570044022416, 0.02718359577439485, 0.03411606712747486, 0.059231079949606816, 0.033860783648466876, 0.01115713120182796, 0.09079273414587782, 0.048119897743867296, 0.026283088147700317, 0.04090199735195887, 0.010380873460352663, 0.041381947606080965, 0.02947812869904503, 0.020703602762472247, 0.05386828827942091, 0.012103487275570873, 0.0063774104872267815, 0.03817865054213232, 0.013530010980884395, 0.04058009486705546, 0.037289900449855674, 0.026804368845337344, 0.005291150479141864, 0.02362151292242831, 0.019417611183598638, 0.04324458697209916, 0.025554019507140886, 0.0618334653066291, 0.017641698716268424, 0.03704477912716327, 0.018135610922810533, 0.04131425990753117, 0.02123953297644133, 0.24532041362216397, 0.1723789760181981, 0.14997032200617177, 0.10518443890877309, 0.0723148925950931, 0.09985698687453425, 0.12756170629854166, 0.1213821116834879, 0.15588121128178414, 0.12662425982735812, 0.1293362647054657, 0.10214021234142204, 0.10622309325563331, 0.18885941184576482, 0.1098796998661372, 0.10009229078047699, 0.12348384326023441, 0.10193576645706931, 0.08229459741062696, 0.12771464809174501, 0.14902507675991905, 0.17915594301396803, 0.16003409731051615, 0.22829452319250954, 0.12508371829866402, 0.06990668754423819, 0.18994613820987363, 0.14690722669324568, 0.23499943195812165, 0.2514418545028856, 0.15664823383333223, 0.15357524066442443, 0.1848435483031696, 0.17563750036060813, 0.17598233185708526, 0.17643245447787548, 0.14798155775473965, 0.20219202303598005, 0.1166127930064836, 0.14511481077680666, 0.1423631148833421, 0.16454453189526835, 0.12710795242099032, 0.11206304278945732, 0.10517328466859557, 0.1676042717430861, 0.19125798717141154, 0.1058831494001131, 0.15344728865931112, 0.11917617682728077, 0.15145305454009964, 0.12148567144909214, 0.24248063293916566, 0.11702699376450432, 0.13062840988559107, 0.061313306927801146, 0.08634360191682655, 0.17882137709567625, 0.23206318548369795, 0.22126871551717484, 0.14673001523460114, 0.12032485672182615, 0.11595077046583738, 0.15137604738195098, 0.13090400235547175, 0.1703211106359959, 0.1300495078847293, 0.17970856819902697, 0.16279362262256686, 0.18609476906637992, 0.13329545306342264, 0.19584406527780718, 0.14214448871151095, 0.12312026559225014, 0.2016427992813049, 0.17637081504348787, 0.15229245707873376, 0.13464165340748527, 0.08537447004909478, 0.09600193284812475, 0.14575575057777668, 0.3070739031799378, 0.16657037480223566, 0.1255103526636958, 0.10725766435385713, 0.0791098396744459, 0.09655097274169808, 0.2499110269690714, 0.12550033223364623, 0.1575621154399649, 0.07646485216795437, 0.15539782512332165, 0.07176852634837551, 0.14783760983376734, 0.05695613589318049, 0.12509299562342707, 0.11330560675912327, 0.17178789321934024, 0.14574523985145554, 0.21171130900902135, 0.11169343600950896, 0.09344296169377143, 0.18148967665770363, 0.09651646814158849, 0.18711126048959073, 0.12411295466365353, 0.14749685392504738, 0.18237582588147733, 0.17282969618756927, 0.1688342105837599, 0.16572583947450886, 0.10767589473435957, 0.10845492954456037, 0.17176081967209617, 0.14154772154025494, 0.15597297329335444, 0.12588012798298753, 0.1694971064646398, 0.11539503496380583, 0.08132896656470914, 0.14203202700422657, 0.1578303994310479, 0.12237123078516415, 0.11115122962022021, 0.12422568450171141, 0.16492999669524933, 0.0939007681764422, 0.24347850842581642, 0.11018798130774692, 0.10298090190776896, 0.1671893278797788, 0.1076147455962435, 0.1888072872233968, 0.1477111746827441, 0.16598422560961018, 0.13035971220702897, 0.06236804529063164, 0.1671273820102215, 0.1490255670561906, 0.12118167243897916, 0.1278983942803837, 0.1432170271272621, 0.20702720229183474, 0.06780154687622864, 0.15680592537166613, 0.15006795225124206, 0.12656547790092806, 0.15615802949234364, 0.11023225352889109, 0.23191597402816821, 0.26898575826518, 0.1231213840806196, 0.19014204221387065, 0.13005536079647081, 0.13689959031199256, 0.1306974803728442, 0.11660842630531519, 0.22050455813446354, 0.13668966689898124, 0.14110139871556915, 0.15638886710568783, 0.10996731734203716, 0.19452729803179541, 0.1082303585304368, 0.14568464229664496, 0.12452085051805743, 0.09822078394673525, 0.2091561606334102, 0.15450315700182993, 0.2764603249247997, 0.10507743940838885, 0.14021298187153955, 0.15815491427577313, 0.08098778164675159, 0.17920101962743268, 0.17726136161194694], [0.052328765647666114, 0.025177935453792735, 0.06647298187618295, 0.06492329325767295, 0.06403091956951446, 0.06053139545744466, 0.07512075090480429, 0.007555334351866717, 0.050549170212639924, 0.04717436138420336, 0.04768168779029962, 0.05183602555564815, 0.04528844826704553, 0.032369084055385286, 0.03454531002188883, 0.00550274396382813, 0.12578421377486762, 0.02299569378186378, 0.016289329449195537, 0.018483242470650904, 0.040722246311845324, 0.014337269427825608, 0.08652099723657293, 0.12715515875888447, 0.022393462488487847, 0.02995065939162047, 0.042461346339194045, 0.02782762099447991, 0.029862921256872437, 0.02942442593555297, 0.0565479719080031, 0.023200555268915433, 0.04139968254152806, 0.03157920335539647, 0.08879556590991636, 0.07869690296150024, 0.014608304632166702, 0.03311148454104701, 0.09253183034278693, 0.02992305341326902, 0.02189635952574111, 0.07268398609613219, 0.04095732422185041, 0.04658902807521724, 0.07315262506205229, 0.00350012022423588, 0.04184248902264141, 0.01684092041555672, 0.05185219384129009, 0.05352747108366701, 0.08030818504912239, 0.021310325246304277, 0.02600599797592769, 0.04680628294966394, 0.024671616453316905, 0.009378702135666484, 0.08271452084544205, 0.07053413653686162, 0.09360031615341864, 0.08454565484557422, 0.031776233508642164, 0.10023095269477177, 0.031786824674195344, 0.05275000292327135, 0.014236531738612442, 0.03949278627612418, 0.06239897226013484, 0.020434330517966903, 0.050413813967738426, 0.07492274015901551, 0.02121714405685423, 0.036246890893145915, 0.04786362218099737, 0.02679608360443625, 0.06182841295676847, 0.03339815847275238, 0.028853253761847174, 0.019511663798062552, 0.02960737539275039, 0.05561039903231206, 0.03147746879427183, 0.027705811099299503, 0.03202340603175183, 0.037312902239782196, 0.03557078382601181, 0.017859779050453536, 0.015179606083209719, 0.07378840909129189, 0.025821478038485494, 0.023932326284627763, 0.046201150098274794, 0.029767369025296746, 0.0171671302298144, 0.038541469783071554, 0.021192267266733032, 0.058118038465298956, 0.027140470769917293, 0.03505612212804056, 0.0586297468943221, 0.0441871164366603, 0.056310346755649776, 0.03551082978505762, 0.019621254590850686, 0.06407732534552775, 0.0377816139840551, 0.05241979604526874, 0.006799896486148599, 0.0023979828045177726, 0.05727315073712699, 0.11389837495141453, 0.024912309787806966, 0.04124748385361126, 0.03810518271019382, 0.017365003079776804, 0.02907016389672795, 0.006941073562859768, 0.01086453253763818, 0.05698612440497645, 0.008123861607013932, 0.05114763043820859, 0.04489563668387071, 0.057462692380912846, 0.05422647651885787, 0.02273932820366275, 0.03540265433970959, 0.013815728260294325, 0.023696616352085146, 0.02442385978816498, 0.032241986238307534, 0.059612641531613574, 0.036027146232945305, 0.042874248578183116, 0.043136989923133966, 0.05847493201614388, 0.0026937343993209185, 0.027894569418182778, 0.007500749629651828, 0.09435037751832316, 0.06994778816137584, 0.0905670446433848, 0.042313763331021034, 0.010266183394818537, 0.04568052823625265, 0.08728251927682469, 0.04250710860135094, 0.0548458892491556, 0.06756773684173822, 0.0800044005436282, 0.03641826476180746, 0.042241291413384105, 0.029950693865577062, 0.08085426018242875, 0.0013979767555288311, 0.05068626547712953, 0.02359157612156724, 0.004660741035496035, 0.014083045065372944, 0.08208256725582384, 0.0905692433157275, 0.040792833653188525, 0.012368902267377463, 0.04912850995277686, 0.05194510881518645, 0.03828014953122024, 0.036266008617296334, 0.01957319789536057, 0.02271081632634084, 0.042004658344892726, 0.05376992642038292, 0.038227358412358074, 0.020179870583477522, 0.014362369341054752, 0.02713229852698503, 0.034445446630519246, 0.11161430678781002, 0.023984343654686407, 0.06517033363061567, 0.060987669764266866, 0.06634188124970083, 0.028465532832929206, 0.10188840690159029, 0.04870307068490694, 0.05179330466255065, 0.015176871149320037, 0.017491307995852926, 0.08035169118234227, 0.06689104371734204, 0.054759524327011845, 0.03855492994790116, 0.05395348108704052, 0.1422758115034911, 0.04808913165282819, 0.026300786693971005, 0.01680076783222537, 0.06388038712283296, 0.0362288112181329, 0.0490657520300198, 0.054049249738454826, 0.03196995799249459, 0.09363999950789637, 0.04057223480495234, 0.04216024697187447, 0.01683332465378748, 0.03570249732283335, 0.06431844385881579, 0.018497899647862203, 0.04664197624210389, 0.09436042093101049, 0.01058450633389575, 0.15230056228897265, 0.04786057315105873, 0.025948376672702934, 0.09146388845458146, 0.05417879520645065, 0.009679904924855839, 0.010734536035376932, 0.06079793659849994, 0.08696957235975612, 0.0071000396799776825, 0.06596935567476096, 0.011502534391418582, 0.02273216719679054, 0.02312901797854612, 0.0048362800284409, 0.02959962258295667, 0.06713414639835397, 0.047424044760484854, 0.09992428769868228, 0.03448464734960468, 0.02359255671411032, 0.026888293777442267, 0.07883705108636811, 0.025778931430390766, 0.02544627690147008, 0.1387995343294836, 0.0009316039734497487, 0.06239712598823732, 0.02741261201369907, 0.03664714502050512, 0.027681786581994067, 0.02187014591219204, 0.02977208429647069, 0.09262823484717839, 0.012891174091266529, 0.04782192401527878, 0.058289914121550906, 0.034981761803670276, 0.015910885845040603, 0.06073439726606012, 0.026462756833362005, 0.03146110898664883, 0.023180487595738906, 0.05199809145602969, 0.015649908417535406, 0.019503342167985056, 0.012338384197303846, 0.010260168647003031, 0.045273049899767485, 0.04010535784125809, 0.03626033573621704, 0.02450233400468865, 0.010706962615762268, 0.02427283896043176, 0.014532873699922236, 0.07639623367257657, 0.02362806871984034, 0.039233588087823124, 0.05245525825528368, 0.028086566373765953, 0.030258917850592447, 0.010438470823329785, 0.1331580628550822, 0.043187264443164876, 0.028084480699392098, 0.05396357429544291, 0.017145936407389182, 0.05333953822452215, 0.013947098932769752, 0.017361971286816463, 0.03121393646353916, 0.08509199810965408, 0.020890505233358954, 0.05179864812582251, 0.0769423930755546, 0.04783710021705878, 0.049689113943567204, 0.033679017797112465, 0.012032775444939975, 0.01044523346448137, 0.025177470055378737, 0.017284184634204836, 0.03444649617097551, 0.042760346625601096, 0.023499515335706454, 0.0333533997857763, 0.04746382004551349, 0.02192691877304066, 0.03988213514188125, 0.04890818306575379, 0.011977510819692287, 0.04186667441841095, 0.050445223572633924, 0.077947071422973, 0.014451082322686432, 0.03729673778457988, 0.031075477562544328, 0.1220248900954762, 0.08394493466062893, 0.042133062341881376, 0.054215866201106584, 0.05736762086950964, 0.022147251405723156, 0.03263567882259527, 0.11263634468759261, 0.029707378595166152, 0.058586570178909655, 0.02545472685127489, 0.0441356276672694, 0.01719040398095404, 0.008303872159411831, 0.07026564570203905, 0.0302926276344806, 0.04552962040648826, 0.08441725850946481, 0.038902412108596296, 0.062321934458469196, 0.04339051906079535, 0.017114423380623904, 0.036014793065166285, 0.020262318881108396, 0.018816477311174237, 0.02386193429570525, 0.017579360226649913, 0.04253195283273536, 0.0074918903016124765, 0.03403416849792965, 0.06629923313495613, 0.033004714867040034, 0.010508195358148266, 0.034015023960701884, 0.03084405006149844, 0.037186356006009925, 0.041863744132100575, 0.06561398280844574, 0.013477490865625443, 0.024421423628565767, 0.028939021135409995, 0.038311639575347785, 0.025130409274190187, 0.05022075981081975, 0.03743502814623137, 0.08313803723262203, 0.18998266528210334, 0.14415105684630333, 0.255081691448727, 0.1645372387382292, 0.13069168874813666, 0.09413625594348678, 0.2857982932079223, 0.10960268247271739, 0.1426044785447659, 0.1510970534816865, 0.15331397403872785, 0.12341268901382724, 0.1445198056077765, 0.12588518416328778, 0.27613813898736433, 0.1563468395221618, 0.15551649214279267, 0.12000827854799649, 0.11976978771628873, 0.05638130948007588, 0.06910312259870191, 0.1109806295003622, 0.1934708014971787, 0.22493807749161798, 0.08586220758696718, 0.10425166557392768, 0.10186676491772938, 0.09580573006983727, 0.24053518329897236, 0.13333050924683773, 0.12151416225899613, 0.1926796318542573, 0.19857712991295323, 0.2655651450397507, 0.25207543985978254, 0.09086748900552911, 0.20814887758704925, 0.23443686295180555, 0.11914993831587416, 0.1284755649225366, 0.17439933373562752, 0.21634814810127984, 0.11396759865625251, 0.2212089913025979, 0.13689943709440772, 0.14926323817381937, 0.09580822751647043, 0.09784305663478952, 0.2502889687856359, 0.22451554935786033, 0.2191535927235119, 0.31774023728024575, 0.13100449776937886, 0.15665972515219645, 0.14650553615102846, 0.1678765240696169, 0.15546147170807087, 0.20124270220197019, 0.1920063018558487, 0.16185125786690943, 0.15647943402009626, 0.16757719819584202, 0.1693296396443921, 0.09409563796174142, 0.09915603940645534, 0.17407681071950545, 0.1706045172027042, 0.09163650338568034, 0.10365456132398498, 0.16234812717283928, 0.07892871350650826, 0.10335488304976495, 0.1305341504273876, 0.07294892994386536, 0.19454824287564526, 0.1871044576288231, 0.18353326216099725, 0.09386204243186982, 0.08605119381700793, 0.1883533648065021, 0.1186073029173478, 0.1337517197093656, 0.08506039698277751, 0.15954173260158108, 0.1252987515181303, 0.09230658517128999, 0.08373337948033888, 0.09610389148996723, 0.30551080802275293, 0.13148596870803064, 0.18456205695627198, 0.11152718726906086, 0.1399979563129525, 0.20283496998731168, 0.1213938328287294, 0.27723171417751624, 0.0935178008230944, 0.10040992615564216, 0.16347576263210467, 0.1687573413214376, 0.15328179834590805, 0.1332000904386082, 0.12386559253378261, 0.16251283607655959, 0.19337672590007707, 0.07650909374558157, 0.1199277627071546, 0.1503912719988054, 0.17289737239480021, 0.16629766282295028, 0.1419930331288807, 0.13348784838472644, 0.10138517140500969, 0.0961955539101074, 0.16764133507686277, 0.11916908285310192, 0.11902780091810612, 0.13190675016132095, 0.1018940989348677, 0.13361169415856564, 0.12046764018915354, 0.14722844735989649, 0.11690680223006396, 0.1233193105567367, 0.29230363606925935, 0.11466605633857752, 0.13428637247172096, 0.14502441240174158, 0.10551790932133313, 0.1043264817206129, 0.1558359814507346, 0.19287466251802063, 0.10179558002780523, 0.15246611388940967, 0.17385842969581006, 0.13887444240671976, 0.169166294377177, 0.12485726270824672, 0.22547400195992764, 0.1972933350912025, 0.1284241527619381, 0.14112461117967484, 0.18007661215960982, 0.09861924159791201, 0.21786383773771026, 0.16639327059590048, 0.1677890827939395, 0.24888566424769742, 0.1301439358822761, 0.18017487059677803, 0.1867095699473735, 0.13506635723094787, 0.1405522515696864, 0.16247120685875416, 0.13510771065710053, 0.09336772419872785, 0.044906438523603064, 0.1548517576508945, 0.2353295392446941, 0.13558231744795077, 0.17639862403513926, 0.1529755163937807, 0.13572502430648575, 0.10016199712070728, 0.11038526427000762, 0.14594604681816795, 0.09205823478799674, 0.130981438522858, 0.09662218827513919, 0.1656407271061213, 0.10653944926396494, 0.1254950845313649, 0.16237679418296586, 0.1642643582196005, 0.17142564088346499, 0.1900990646813185], [0.019551157545779022, 0.06300546491758958, 0.04834115159727874, 0.015217032351140535, 0.012683762489036928, 0.023135504828044967, 0.035232912238326766, 0.0720186387338946, 0.04775153202635627, 0.01680390879271492, 0.014424671441496862, 0.006051233710510837, 0.029124676798199935, 0.013196145075433438, 0.03311743704421866, 0.035077051650131905, 0.006033224898630814, 0.0651748152449727, 0.0431847631660921, 0.023881090324251883, 0.028439278999764114, 0.036988383564617366, 0.04449423342462509, 0.0681835412979126, 0.025824571118479776, 0.04941683863439868, 0.030425823511435624, 0.03405032912269235, 0.0426166859876004, 0.05278395977051509, 0.032603162220649184, 0.02876473613263619, 0.030379561376908136, 0.08670373218915156, 0.029627467963784456, 0.04147721446990486, 0.01958723645657301, 0.012576489112219744, 0.04444701176497244, 0.02661685350411121, 0.06111747953259657, 0.06706715967025488, 0.05374128622333369, 0.005487009475473315, 0.0680150019545709, 0.03431855948762067, 0.031482086389235435, 0.016511630927843433, 0.10312128751989334, 0.03513305267739681, 0.07578841951345244, 0.03631167894890232, 0.061648861099515236, 0.06443308891668435, 0.005488586658987427, 0.09095673058782855, 0.02588365948007953, 0.05406711873928866, 0.02378528336844137, 0.017373447283922185, 0.060965085492259076, 0.03361022310151208, 0.06570377597405065, 0.012575791014598743, 0.05933600335171627, 0.04336529944632803, 0.04041337498253392, 0.04301200650872723, 0.05426906717700824, 0.08891086980339982, 0.05183986748658842, 0.03405007631367734, 0.02755727048122114, 0.04387935976527872, 0.01753445023730878, 0.03939618258887241, 0.040227755708920385, 0.040354056794556885, 0.03005347222149853, 0.07237542886286974, 0.05029960941042631, 0.05028058361682681, 0.023175598039562186, 0.02947987920995201, 0.03727520305302836, 0.011566028716192852, 0.00833156815309438, 0.03274606443160484, 0.01942449065315868, 0.04624079131791669, 0.05353652624293201, 0.017120655505887924, 0.07801486254339257, 0.05863551553639193, 0.017919231303817323, 0.040211974297680204, 0.033814826033889286, 0.0480108872626818, 0.03204794382796653, 0.07669882308090888, 0.046607054124075564, 0.07310818430156478, 0.02449799220137779, 0.0661331759164891, 0.04348712657848674, 0.04926004724937582, 0.07246314593019985, 0.059791113204893574, 0.007208958709417212, 0.02227074477911717, 0.02738443338462422, 0.032448014094223904, 0.07598176478378235, 0.04227049085461805, 0.04961633176032094, 0.03605141972882613, 0.013271458221659546, 0.028073460524601322, 0.03687787538153991, 0.031858532419127804, 0.02881535347701321, 0.054311033473500324, 0.05040917147491729, 0.05001029247538217, 0.10594116523861886, 0.03546396435628976, 0.024399841016518976, 0.01619002721723049, 0.06829566592651029, 0.05689661469190352, 0.030424990390817967, 0.020487167602104527, 0.06665392418301876, 0.04329253641527988, 0.012662489184989564, 0.02425877358614197, 0.02277300351359431, 0.06320557091385126, 0.007968672782167672, 0.011523605639775916, 0.031686432682158004, 0.021687483737966227, 0.04003836728271939, 0.016728158018762068, 0.04228392420637031, 0.00912517395561501, 0.020841169171035293, 0.014511989185496446, 0.035890460825495185, 0.026276474893693964, 0.026567289530630075, 0.0235595689680908, 0.02521108024783673, 0.027785706408922712, 0.06476028506914455, 0.045074613975180734, 0.01245759513920113, 0.03947155414930275, 0.04834102519277123, 0.06614449103513072, 0.061705176222829096, 0.022070623461097, 0.06618179951704319, 0.0643778846208607, 0.021831031377998092, 0.02214577094080948, 0.07853851428315525, 0.10107723470296591, 0.07954693880052337, 0.03465656514069246, 0.06022100727404318, 0.003349177202307469, 0.030820289844526883, 0.023413460679172028, 0.10429346333107642, 0.04173499156510638, 0.010483876854601887, 0.04233165531449261, 0.029600783206161954, 0.03889667411004344, 0.031269282485628803, 0.04840285614913991, 0.059307512541812275, 0.03288580269943322, 0.026392129272402778, 0.01247864244731083, 0.050630348719536304, 0.0891599249875834, 0.036641537256899386, 0.0106210975659891, 0.017685260390862823, 0.03213226329535246, 0.02216482737792596, 0.055049768228444367, 0.040997608955348694, 0.07654113154257498, 0.06618084956801708, 0.04070206755591978, 0.04565503283013259, 0.0407278617363303, 0.024990512043117516, 0.016458947061290665, 0.062496545048610824, 0.007297654454070594, 0.029933115978154446, 0.010571674361164051, 0.04596286227986698, 0.009991918172266696, 0.011805873608306773, 0.01891681376183706, 0.012589326830610875, 0.04532856446120047, 0.029508663048487038, 0.057717569833320964, 0.0328224433976556, 0.03582256245276621, 0.04313282623526551, 0.03942059781101923, 0.054767223510650866, 0.05837446341531412, 0.040159949266742316, 0.05199531438730417, 0.07115247674406537, 0.08082288888192947, 0.08132276891340172, 0.084166050618214, 0.05578139368745108, 0.05439811851829291, 0.010879788221040321, 0.02440713800399775, 0.04721374596439062, 0.0373081065293762, 0.08584705436782492, 0.03605785869782971, 0.027720355278541966, 0.03349525628671531, 0.07751777873284395, 0.027768946320359266, 0.04461229523463596, 0.02503509261465121, 0.010964262821230917, 0.027753423463793534, 0.03652593458912546, 0.03585208748136798, 0.023328668152492855, 0.025531734009423566, 0.024598460802207553, 0.02693609766391737, 0.026121148651826288, 0.07888170635147441, 0.027157629224201365, 0.01798052025297957, 0.008520874224843518, 0.0046547607616371205, 0.03117359235822674, 0.012202483072366205, 0.03912508705510728, 0.055200894393267176, 0.056092839072188067, 0.04558562526419278, 0.009231505044285328, 0.04934115680835901, 0.03327040182005975, 0.031573880959542534, 0.030892507037928993, 0.056736919833647634, 0.03411033295936162, 0.0067939803721533435, 0.06002514923532164, 0.06825838808811481, 0.01955101964995265, 0.05837236816484121, 0.10025124636388595, 0.036361800251348365, 0.02166754438451702, 0.04695313434386927, 0.058938189214395906, 0.025112770099733627, 0.06212506135324798, 0.023673727560127457, 0.017690197827534813, 0.09274324762725061, 0.05355224253669862, 0.035824067815537416, 0.014859487625559973, 0.038466121205278946, 0.08744849222562007, 0.028695713525878328, 0.027739551526704626, 0.01739752351216251, 0.033202189351281816, 0.040617510601277315, 0.029355198400275364, 0.04291579735675647, 0.04680951967114403, 0.037548681120238, 0.013536541880438886, 0.10449243168677054, 0.012980521010655551, 0.03964331489236605, 0.047542213822805116, 0.03812308235454463, 0.04385267309243641, 0.02416336116561246, 0.07907419360332912, 0.026624884020777482, 0.07612166009963521, 0.052205502100649386, 0.07362140192379875, 0.06404712232911298, 0.02790634610479878, 0.09418537750119164, 0.06711279552790426, 0.06345222824283185, 0.05325796518234476, 0.01951583706203007, 0.04894987357059314, 0.032847188037609866, 0.06279467582522381, 0.05021236731760925, 0.04563529074432389, 0.03956666396510217, 0.008387592162997013, 0.018479959783895362, 0.024023720573994423, 0.0491511401900601, 0.04281632467022827, 0.0660777647769259, 0.019296850828874498, 0.046191482068670374, 0.02905685886470301, 0.014012971002939007, 0.04122510642534302, 0.05203373752714646, 0.040431853023267565, 0.026581979266578154, 0.03305855552635847, 0.0626935522192188, 0.05975208868603072, 0.04762880091044692, 0.03850834414122566, 0.047940445478044214, 0.02194625674746931, 0.09149182768117997, 0.0622101315867997, 0.027289315907945557, 0.021288503231781147, 0.03530210529964778, 0.05410387946833527, 0.019887502703274933, 0.051390323262181015, 0.01782165660012153, 0.09530346750492051, 0.11364920485404231, 0.16961490014387717, 0.13345202611338708, 0.18683225126756778, 0.1843364134190544, 0.16050983791149434, 0.15345257466598866, 0.15321131825687426, 0.07856700509305924, 0.13378184228654832, 0.1508075794986179, 0.10068387919736486, 0.13533798136538075, 0.08833825738439638, 0.09971100115968336, 0.17232666753472822, 0.15139484717961282, 0.08246105299481461, 0.13585584148043586, 0.17894807271659377, 0.1600611861795187, 0.15584577205440692, 0.1564824830500349, 0.09962845518584214, 0.15496818769362666, 0.13874748631590797, 0.09712704021724002, 0.14534315094351768, 0.08734428128528018, 0.17176460414644212, 0.07200214486088484, 0.10271713783543918, 0.25550003674241806, 0.16382967993136377, 0.21485901107230496, 0.10737151268028444, 0.18784927895232556, 0.15714668128038609, 0.13502698031163987, 0.25395779449853206, 0.1226051940372394, 0.24865122602110912, 0.1814437267040053, 0.209625925748579, 0.11849036725658564, 0.11313769560787948, 0.14892307981368036, 0.22659192342431317, 0.1452167617577699, 0.14716735950881435, 0.18225024874892928, 0.18266200568647156, 0.14949439754409177, 0.12052801557846608, 0.16247774924962752, 0.2049668394629994, 0.1338349934667349, 0.08787474354668971, 0.1736985624677712, 0.16250888306287029, 0.21114570629452506, 0.11937115386488939, 0.17747899186947655, 0.20310801904528372, 0.0983633988747193, 0.09393922579024108, 0.1856530580909983, 0.17413791389234606, 0.18718224619665455, 0.1847586044741254, 0.12641355500466403, 0.15123897893053873, 0.1469147649984206, 0.15610503152974192, 0.09511861814967087, 0.07938300364560659, 0.23474841558885193, 0.12237681556613215, 0.2543932082311761, 0.10885757769668296, 0.21396766777240464, 0.13978237917105998, 0.18391840520405, 0.2036030497401953, 0.13640696513316325, 0.09318056891882613, 0.11003691642995804, 0.12085772449931792, 0.2589462373045183, 0.11985492306731402, 0.07624716062339083, 0.2232296248116801, 0.15762464353634467, 0.12160897330050507, 0.1637142304811747, 0.147498355457379, 0.10510158649976216, 0.0851508489839973, 0.17124394014958413, 0.11125714127575198, 0.18513237877238184, 0.20603936255699207, 0.20453027659846892, 0.08706138799748114, 0.19202016804727817, 0.15116022509192267, 0.12336519156252185, 0.1800270003056334, 0.11051781280266662, 0.2199463864728328, 0.12368102663106496, 0.12138338338944221, 0.08774149787401961, 0.06869082939961264, 0.17647134110091195, 0.18428499359757672, 0.24177629170158219, 0.10494625451223505, 0.07700444619742132, 0.08655038436934834, 0.19935287054507964, 0.14394948379166667, 0.157784526086142, 0.1531752814809161, 0.1949880386312162, 0.15384004661633124, 0.1648100120045485, 0.16363708542719965, 0.11273349995814985, 0.20281572585865376, 0.13161818016200297, 0.19698176713239765, 0.22191883305147772, 0.0853503842447554, 0.14951669070268833, 0.0927978850180103, 0.17244260728118882, 0.09097189146785006, 0.11229844628683022, 0.155317033490827, 0.17803161705453552, 0.1712004416772435, 0.1532484275559264, 0.11366530036133145, 0.171762045412775, 0.10336191573690984, 0.16146484311790238, 0.11717039010217113, 0.11768024459841753, 0.06426789737757176, 0.11222746824064564, 0.06622938889889948, 0.1711748849840895, 0.11679659282127697, 0.11261065009861224, 0.1272409452846454, 0.18579536658381263, 0.18546887523224279, 0.11661179709218203, 0.12783677782863379, 0.11461212374870816, 0.18205158682840486, 0.12216973433931991, 0.08301498052934486, 0.1671272747579121, 0.11725013985508874, 0.15509328985166165, 0.13168305248743103, 0.11063771322369577, 0.14330540303020708, 0.12984096342998167, 0.13723619402416293, 0.09834522726915537, 0.15540236036383337, 0.14068506057223967], [0.05576569654588258, 0.06845885797614051, 0.02106612705956063, 0.05236847964566081, 0.07396021963007028, 0.03220149466106969, 0.025417623297882178, 0.05873486564885225, 0.051347793891064586, 0.16738582943235675, 0.04100512810832551, 0.02627933048643172, 0.03146864346138412, 0.023326507784546386, 0.07974500317246684, 0.04795457596980757, 0.040595960547967304, 0.030731214886350982, 0.019613348563472112, 0.050986223373441934, 0.03424182429068512, 0.05694306260275264, 0.03333443910965035, 0.04447908020548282, 0.06769859232008457, 0.06804861789268833, 0.04500625211925757, 0.03655457478617469, 0.02366455748767382, 0.04269382721113582, 0.05460108585295178, 0.022446807105875304, 0.019415824283515255, 0.07832875174860801, 0.024580863762586832, 0.01603193731317597, 0.044438626932641195, 0.040805799691306974, 0.03123754154770605, 0.03051307901079136, 0.06523629380089623, 0.043137468728086645, 0.04881139934783982, 0.09842490807415978, 0.04949506770278658, 0.03135389881208539, 0.04110277750559392, 0.01746176764549267, 0.04197886799492183, 0.03218588561961248, 0.048564297687863155, 0.05515216354040369, 0.01585660085472609, 0.021911976228077567, 0.019516934482981602, 0.02300512049377205, 0.03856938985747196, 0.040748967458644224, 0.04705609273045294, 0.004360682590143575, 0.0682846265995214, 0.01861218081396674, 0.05338050477627305, 0.033076738623241266, 0.04261097863256451, 0.048226150308525374, 0.046105243551034125, 0.025860123343825824, 0.013880603458552111, 0.026809434601736647, 0.009830936286298018, 0.07314160871770113, 0.0444072901060985, 0.03864793302190881, 0.05781554481795719, 0.023229465511957967, 0.06187874876383332, 0.036891963738467426, 0.07295754843301351, 0.024941672022724827, 0.026169517528145548, 0.02320934804306636, 0.03316417606847902, 0.06818385539396156, 0.022733538494175, 0.039603286798322396, 0.015265152248884402, 0.04540234638918792, 0.0172479007948911, 0.07304944834041019, 0.006771931404082646, 0.03622343711134407, 0.0531012274234766, 0.008958726989916496, 0.07114556663098835, 0.085882363360255, 0.033372387274979584, 0.02174383333523668, 0.03312302565562629, 0.04846326984284867, 0.047108025830839916, 0.04406845324762887, 0.05272936451459124, 0.049281597302685824, 0.0335531878555494, 0.10290820016375474, 0.040045767692067934, 0.017187297494421085, 0.021459566834833355, 0.01185941453572483, 0.01963407507226352, 0.025676099448314598, 0.01615241804580775, 0.023930368929981224, 0.026415812880581906, 0.01780848946392296, 0.025456299246739478, 0.034715653502292214, 0.02312652819279221, 0.00814013522974546, 0.009010704140359116, 0.10050529644133584, 0.041211581143039855, 0.06382124896551813, 0.0268279854208231, 0.08017822589364745, 0.023761569116745266, 0.038096150533566554, 0.034869143048361424, 0.02677458526206113, 0.005535963451444742, 0.03859643659163867, 0.009898976385292989, 0.04797971514504283, 0.10156786039231286, 0.0211740420350144, 0.05305367634601651, 0.05896870632685962, 0.05972677331057288, 0.03367311892009551, 0.0078086657430826425, 0.07934791681867454, 0.08629533071671763, 0.04353978746240178, 0.035585588475148526, 0.07425542395081251, 0.07520797001498361, 0.03345466894848693, 0.05924403066596678, 0.012115246725208577, 0.07791435180772698, 0.08399475335834489, 0.024435425800601804, 0.023709557492346055, 0.06361621319346371, 0.023292585411259246, 0.05287982418291992, 0.04299540155296845, 0.02618100501657013, 0.045849308897290504, 0.06130502551733967, 0.01356418137513702, 0.054354838381010684, 0.07271025525105577, 0.019510736831674175, 0.02309462254596574, 0.0418854933682709, 0.053816653953324405, 0.022205071891808224, 0.04086683774667402, 0.04058176876917001, 0.015307202815048158, 0.0034062002387438574, 0.10318204595316803, 0.01907515264446697, 0.013814311955244312, 0.025895259966472947, 0.03634792639903965, 0.0088707982907973, 0.06000899627143818, 0.11667404173602981, 0.05594576934292432, 0.01666826526484182, 0.031118326775369146, 0.041082614071426854, 0.049395016619875554, 0.014225665739016428, 0.004674236153087189, 0.0324934009732979, 0.004309836376999175, 0.02600687514660099, 0.006915208998121202, 0.03672093077893219, 0.036189487924979585, 0.035164205642837676, 0.025015969144841357, 0.09154337007672557, 0.043492297671975634, 0.026873812800453558, 0.030545406005976182, 0.044089344465324, 0.048354358953093333, 0.047969721528070594, 0.05901023212279524, 0.03300409050538175, 0.02064499320582517, 0.05568138090893627, 0.024031004154934518, 0.01889395178295672, 0.0416556554996679, 0.025039880664177963, 0.04275689922994183, 0.010960449618587812, 0.07087818662365598, 0.015049297400119324, 0.025451892325955055, 0.03460850844520234, 0.04306628766860213, 0.035385662509549054, 0.12094991552012584, 0.03911064629773459, 0.06622453956233879, 0.007629480171618202, 0.09939614668368332, 0.0499448111100543, 0.02696061822315378, 0.042653718677860115, 0.003550132837957673, 0.012697175730981175, 0.04035283488431766, 0.027887153687075745, 0.013866342731841631, 0.02211820709729387, 0.03519127535964212, 0.005818438263715155, 0.02459998340195706, 0.06268966049256344, 0.027514643433894363, 0.0428557398939325, 0.04411997266053673, 0.03508719082380976, 0.04177501582871041, 0.03698303627090589, 0.025714275524801305, 0.04292443116766311, 0.0944295067400221, 0.04391784419215495, 0.04024251439278165, 0.055214182188313816, 0.03900828545973186, 0.032459283247590065, 0.009067508602334608, 0.07177373574626061, 0.03289514897210944, 0.021350175224905534, 0.04420521526387142, 0.04126833676691017, 0.022158365426284653, 0.08265395393414844, 0.02633706478762531, 0.02231393490106829, 0.04750739129620695, 0.047391283010403, 0.07234495388524187, 0.013209186764734407, 0.01742142928583968, 0.023526475884981697, 0.02092255643689104, 0.030174577315788598, 0.038951656240369045, 0.05916233504972151, 0.09975354202211865, 0.06152533708260425, 0.012045788405943784, 0.0889110460036224, 0.0206344575816465, 0.065726030828251, 0.06002509943960656, 0.047854835152505874, 0.11205379610821126, 0.02027571201324463, 0.021608670527536063, 0.029018092900514606, 0.033187246806318724, 0.07032959106107874, 0.020105795626859033, 0.01146072610056088, 0.026048699716827082, 0.03762598705267714, 0.021993219852447513, 0.08092195937229742, 0.05720522555132067, 0.018758739179541028, 0.03784789974170347, 0.04229141654626977, 0.016559595692782633, 0.023128297855897297, 0.1150388194007739, 0.04877321369525406, 0.07285312298805484, 0.035237378530925324, 0.03948203806254653, 0.03597834260172902, 0.040602809374010375, 0.029111283666063702, 0.01349576206261953, 0.027533674973153302, 0.0625093195647482, 0.005783812525952536, 0.043914810483974796, 0.022391382559773423, 0.029164521031141765, 0.011394320641674343, 0.06111759827622484, 0.015082094581767678, 0.04467679600742075, 0.0279253565766398, 0.05264386910224154, 0.05425021758363132, 0.06394661925432664, 0.06475709814337954, 0.01059954559745928, 0.05337909517449237, 0.022243701875390067, 0.050804135765159325, 0.03031809048186387, 0.031112493015825752, 0.05896866036158416, 0.055090110418536974, 0.029631072407468196, 0.007243741495204309, 0.002601602271522185, 0.02694783604613716, 0.04439316344477477, 0.04793155502768294, 0.10713755708908844, 0.02399980905465782, 0.03988144183230977, 0.07195217294558402, 0.1084005066584195, 0.053372476174826586, 0.022981147687401504, 0.07587602166759391, 0.07859907353356962, 0.06451556594261239, 0.11329305057804431, 0.03435335137070187, 0.0360220977135243, 0.04634786359665375, 0.024385723931294297, 0.06041225729390018, 0.016562474268158118, 0.2011096020860057, 0.15074381033980078, 0.11919460124185971, 0.1663351398442061, 0.13798145967866146, 0.09928409866387806, 0.19709292649021073, 0.23647035141625714, 0.16222205974401968, 0.19807451494759132, 0.14775499491201294, 0.11618886293182451, 0.09467828613255294, 0.11153727664702362, 0.15154208927865953, 0.12612719133856798, 0.13112650493219977, 0.19543684358077665, 0.22859427807552202, 0.07363612613370342, 0.15153321798049635, 0.12961174992303695, 0.2039829374200875, 0.09831511235285191, 0.1273185116869788, 0.14062738947329984, 0.2393791719429916, 0.08410347655655877, 0.15001536797611945, 0.1102589057277768, 0.16671153416316356, 0.15701128290064875, 0.08675637009042887, 0.1738789302086638, 0.1295621993560945, 0.10077628472279157, 0.12392950724930533, 0.19693894281743035, 0.11313013432006683, 0.07573048028373912, 0.14760966803277695, 0.20085717611495527, 0.19911545989734514, 0.289156761380934, 0.1592881115333688, 0.15756845864797794, 0.060793183022929784, 0.17604116740967, 0.12132336806145408, 0.09498205531628863, 0.12998740879758713, 0.17006456311191284, 0.10578982456917725, 0.08944432746859328, 0.15559688540956668, 0.08010060586515935, 0.15283239584776664, 0.1978428652810474, 0.10285629770688473, 0.09923535248925609, 0.20397497010567497, 0.05615224919071602, 0.14351491275573933, 0.19022602077213027, 0.0813297096699957, 0.17986521785778387, 0.17192897597147574, 0.10196044980998963, 0.09591515040806226, 0.18252159709170943, 0.07750109333785311, 0.09931422890194001, 0.18922630667446122, 0.14335624062486235, 0.1414690749539483, 0.11091659221077159, 0.2380613934609198, 0.08714076236731584, 0.20064247231329643, 0.14474662892039747, 0.17184481355211428, 0.13881566814116894, 0.16548277509789314, 0.19201808428812414, 0.18934213916861242, 0.2786038389369365, 0.09896898371798378, 0.1711330412616653, 0.10140387161124138, 0.13655339517901022, 0.11543781331349766, 0.15810154859096776, 0.20398108348731073, 0.09843617722752596, 0.13988932504528953, 0.21566110512902661, 0.14219347237338945, 0.10040379745224792, 0.2345515616358288, 0.12827403783317537, 0.20537936248846594, 0.23687248628947044, 0.16543955241720523, 0.1524494591379358, 0.18177919660604772, 0.19004517805672463, 0.16931188172630726, 0.23804593380660782, 0.16916355178240808, 0.11746049993821692, 0.16790819414440664, 0.14779077121807685, 0.1189939704753699, 0.12154862089383027, 0.09617730569575103, 0.16780491017045515, 0.12495085566995606, 0.13861899804924765, 0.1591937907881314, 0.1214486540805909, 0.1464867516751251, 0.2979462413537887, 0.14635734410295564, 0.2448855667945839, 0.14224149076448334, 0.15431532756455485, 0.1616705990126056, 0.2179763147667531, 0.1201794685555562, 0.10226139212928473, 0.05730891938231165, 0.1258770789530489, 0.10631614229491643, 0.11633654170098806, 0.21990989004412007, 0.10629849929002025, 0.2320536400281614, 0.23415494259567032, 0.12109880470820975, 0.13093752636303826, 0.07464144033409896, 0.12812251330263194, 0.2346204789054971, 0.11153035887306738, 0.12602868009238474, 0.15706037381483665, 0.16854082955227745, 0.10873781517148019, 0.19125676143073267, 0.07568831480438672, 0.1445846626114461, 0.1679545424638256, 0.10533328213158155, 0.12223216284426952, 0.12438133058528747, 0.09270237683649026, 0.06924674110186678, 0.12228875375923612, 0.08189914282411337, 0.12401502564429276, 0.15689017972157848, 0.15218088403344154, 0.15222632836910988, 0.21144638048304668, 0.15948726375016475, 0.11888810478511358, 0.20286800369860666, 0.24004482574039893, 0.15422439292794274, 0.1970456741870411, 0.15117088903582868, 0.1849265922341616, 0.0961144098771676, 0.15405182396211933, 0.16050640583759354, 0.11022645424330428], [0.03522601361656862, 0.03707191013100167, 0.055180007006011667, 0.04474314688254268, 0.04854919809487559, 0.03493961547651599, 0.03152962789059647, 0.05337804563403611, 0.03271013490795609, 0.022630488177040414, 0.06598859214253965, 0.007067898461114496, 0.0013881641268287035, 0.061570524778817935, 0.025602807816598686, 0.1460682225203322, 0.022723638722973487, 0.08982453690541368, 0.10539141288327594, 0.049745440558199926, 0.06852651886161297, 0.02754776333008082, 0.011957135753736142, 0.05602489090374401, 0.015169657473903031, 0.025816594227968205, 0.09933813084517756, 0.0365813878635245, 0.042531071831622434, 0.03989970536842462, 0.025263727725213094, 0.041818445353137876, 0.018343220750290542, 0.020381204235637863, 0.06956184838688181, 0.030850230475827575, 0.024143467777438705, 0.06784090081289892, 0.05074921875230728, 0.0550569503027345, 0.07384742084409922, 0.0412873127647946, 0.009258007856025811, 0.03554128561048739, 0.03401689704567675, 0.041328191216434204, 0.06714636550074624, 0.029557759708334363, 0.03861403746169902, 0.08599099462791797, 0.06363235083558867, 0.02913635006294616, 0.018170714986720876, 0.05092967076287155, 0.060828043853924166, 0.06320933240555948, 0.06671544870421772, 0.02797563875754995, 0.008479178931954648, 0.020568259924109426, 0.04187714684033587, 0.01556370150102603, 0.03033685772078893, 0.012002255459646545, 0.03362616922165598, 0.018211461288193544, 0.06703288489652258, 0.04504012086639001, 0.055767646239649867, 0.009615987336503403, 0.019835673024757736, 0.02662045603257514, 0.02489799926538141, 0.0388168094439372, 0.06753971334546804, 0.016513957919913436, 0.035753813722441276, 0.0365779864331407, 0.02488369448861528, 0.037067888169399196, 0.024133439686509873, 0.04185023034111627, 0.08051452317064808, 0.03323200549329481, 0.024486228921300462, 0.05034589644281134, 0.057455445189149155, 0.028777336363770792, 0.023299665978899407, 0.022988450420539708, 0.04268741505520959, 0.04240797682394905, 0.028458354589078697, 0.0697247110187046, 0.03219586008438661, 0.05401514350406585, 0.07378059499446424, 0.03454979163624587, 0.027459764725438533, 0.042149138696972406, 0.06075048128203039, 0.029759924565892548, 0.026876153199062235, 0.02880814267442592, 0.025636802968238632, 0.04559151264989088, 0.009797610503981912, 0.03464149236078224, 0.03263624572765923, 0.04050501442003635, 0.011759586575921747, 0.05310773917083299, 0.0580484432078177, 0.0521088064828467, 0.04627184086148778, 0.020190800742937193, 0.04167885264201511, 0.03889595015695499, 0.09902883050662857, 0.04823056297496923, 0.049447248494552995, 0.05229826768740051, 0.03895122340069183, 0.02607939877517281, 0.03494595485408941, 0.05625086385876902, 0.046922640214043285, 0.033286838236475186, 0.018389661000260425, 0.046667774252954035, 0.04301396386337377, 0.08607457482045697, 0.020095476422518976, 0.055266720498160976, 0.02738396607099041, 0.046260073750970826, 0.05357164754382065, 0.1323152282425473, 0.02728197870085076, 0.027639994570504756, 0.04687538024999442, 0.016851580529023084, 0.05536194905758866, 0.006906497142007275, 0.049780535046011216, 0.02580764249057299, 0.047047930063619736, 0.017074676823892423, 0.029690310156213182, 0.11222690133558166, 0.04612740647468356, 0.09542248692483672, 0.07142173366681223, 0.039515573561431906, 0.04239904806919156, 0.016443025839004307, 0.04094056221806715, 0.036992466813253785, 0.034023768854357546, 0.07609252577587482, 0.053730315844258, 0.021312263448752707, 0.05000972173987858, 0.03337955402751123, 0.09751336303569617, 0.026196108439997322, 0.011165606049490313, 0.05332712760014881, 0.029514316777368228, 0.07453472428624669, 0.05199952021000847, 0.022275894805188143, 0.012605295933392501, 0.0472259305928263, 0.039412894796940594, 0.014916501804104736, 0.017748330494449023, 0.018110835639339302, 0.023195640814881173, 0.08069086128905897, 0.06893213943488176, 0.07090371267329301, 0.05265873120797258, 0.011707100934619385, 0.015727378101268365, 0.016897603261074232, 0.032492929829224464, 0.06507717733902317, 0.010616911853092813, 0.0640004828962828, 0.06885630439125723, 0.02461136938373168, 0.028681883723625255, 0.03206799809460438, 0.028491106763061498, 0.013865393740425428, 0.007396113510513979, 0.025276128773487387, 0.032252968108702096, 0.08009914263722398, 0.024273685487588088, 0.04763681802057451, 0.06549328565597534, 0.06766568118285748, 0.03479253425593338, 0.01880750067592148, 0.02036499956081952, 0.02054303647920249, 0.07285289316167755, 0.033534457005800745, 0.0743616037371178, 0.05099971035134889, 0.04403668741184858, 0.024899688489254446, 0.018538718727687677, 0.012083261596759962, 0.019517997429976543, 0.051320214725790486, 0.011058045389701524, 0.04244073091315166, 0.05720943137402496, 0.011765056443701108, 0.004413347783303189, 0.024952860736858942, 0.03988601920765735, 0.034137092410556735, 0.011908201887572726, 0.0033946248896104558, 0.03605854434652194, 0.027070492468473893, 0.04430333963565288, 0.05402990218792712, 0.0513855237213354, 0.044909793988711415, 0.03836637655753763, 0.04455218797609691, 0.0257718144735742, 0.058203307881711, 0.017474482789815917, 0.010871053861093619, 0.028663235228328456, 0.03256712544469103, 0.06120193689580887, 0.017074435506196275, 0.02497476127539431, 0.09151675618223606, 0.022590406456842058, 0.011364671123784878, 0.021060829561564232, 0.025561994482432644, 0.0458956801993472, 0.0632828040679376, 0.027816964711453167, 0.04883345501917986, 0.024758944731025447, 0.04749924778157184, 0.008548009059121533, 0.03689112104175072, 0.05563457676720235, 0.022820004922968727, 0.06851633755309929, 0.01632804370244905, 0.025313272546496124, 0.0480802565242254, 0.004133833900860121, 0.008222519367512676, 0.04584225322750788, 0.04813309743880265, 0.029507015959449837, 0.06426878603956392, 0.035276855041663495, 0.02903392219225005, 0.08496461300960473, 0.01724661568239812, 0.022753315053940303, 0.03138498474483288, 0.07235109024951536, 0.05515820414368665, 0.04738552585965203, 0.03949736748191138, 0.059652301903453574, 0.05041270314024822, 0.058457649072572115, 0.009884727149901372, 0.07014939952040873, 0.04440674618367226, 0.05160999897446844, 0.05216489944066252, 0.02843500614436644, 0.007706750672490848, 0.08782665620768264, 0.027201730990782384, 0.02869979485929493, 0.013265627334945867, 0.02450965397480515, 0.04400220579437671, 0.023294268889472853, 0.027110380751471368, 0.0434174815252904, 0.04570391307014131, 0.06523217990874283, 0.06945053581148386, 0.021907006232668797, 0.035983203429608576, 0.05755595592481475, 0.08226193908241489, 0.052177589687128226, 0.108704743155789, 0.0354869699766559, 0.026330577938126463, 0.03305885813108856, 0.061959858322816516, 0.03655586947476672, 0.019233152533190388, 0.03861165875869413, 0.020550879304327314, 0.032911355562147596, 0.025311227091738296, 0.06161555159656752, 0.03178913059884743, 0.03413701580176431, 0.06601586487264403, 0.040017138986337575, 0.024354256869804476, 0.06133245529546853, 0.026226060562616876, 0.050204943925622976, 0.03199820365426281, 0.015039374646280083, 0.032133128974706895, 0.07298754077524909, 0.030025973495456482, 0.06183089891208276, 0.0898210512053582, 0.03794293294871046, 0.02427527512003097, 0.008722778612507448, 0.06403859960095537, 0.03150862750537213, 0.008460328380967821, 0.019622459264111616, 0.023025743580693682, 0.04359807143168103, 0.07445426207155952, 0.01789914064800307, 0.022973019494524887, 0.03862170600182107, 0.030632349324502775, 0.026725957831067425, 0.007731807493274251, 0.035375366287846724, 0.01834455757371841, 0.09466926161680492, 0.07465862368624057, 0.09112052784691896, 0.2385478746145964, 0.11914908795827821, 0.09129028527006026, 0.18071275625017383, 0.09692860046221365, 0.1503940452370913, 0.13372443165750275, 0.2313704121737711, 0.17221540092460572, 0.1175857246703198, 0.10355404292744014, 0.11888047454938774, 0.3242421174241651, 0.12030048746495478, 0.10017372592682801, 0.1806333588977014, 0.13391071359717077, 0.11480807371798063, 0.15722479160514571, 0.20912383172300555, 0.24350095480199785, 0.14544735422297833, 0.20624046063711568, 0.2721340119117691, 0.1312046305787179, 0.21595382732489418, 0.11575230006729403, 0.1025931848092906, 0.08989848737274447, 0.15987635980690681, 0.17208976250502372, 0.1806181290697667, 0.14594531137376063, 0.14260634779930115, 0.2110729585852354, 0.15328101693622528, 0.11973488475045851, 0.14381172586112254, 0.13580167906418925, 0.117238411048968, 0.12901380297637757, 0.23870057125966396, 0.08237251621340552, 0.14712246675645152, 0.1075571894104923, 0.15995768770094843, 0.17412973207331475, 0.15152053156447026, 0.14535482612348374, 0.08560446496572226, 0.20429792213103465, 0.1718914529849445, 0.22732666303073207, 0.11933843424964337, 0.18008001358999362, 0.11244548920301661, 0.18659104082372882, 0.10809057812777259, 0.13017218920492357, 0.11383027739582524, 0.22199346533706113, 0.1590032034343289, 0.12736092231446697, 0.1408249329054548, 0.08766374761058439, 0.17256513538379825, 0.14535554624613256, 0.12114195844098447, 0.0838302436374849, 0.10882380088010143, 0.16617596209529908, 0.11431736375896201, 0.1679638274494679, 0.13215916081061288, 0.1400326600959224, 0.1056896279295606, 0.11944611556828023, 0.11116784606729785, 0.17610964034834217, 0.11459803539178065, 0.17550524294136033, 0.16302383204381313, 0.19880326374644236, 0.11178673019692784, 0.09463121769048514, 0.2087073710056082, 0.15920489906303345, 0.17241386366226982, 0.1900282628353565, 0.177802158399455, 0.1345992427799971, 0.1273818978018338, 0.15404872896690525, 0.2342178843795292, 0.13212122413660252, 0.08237209486504717, 0.17540448705755896, 0.14741302858437264, 0.20619163019282205, 0.12951552927974733, 0.07239684868123263, 0.1273082920740689, 0.1189400455463798, 0.14125302283754274, 0.09293116133419738, 0.1764868160769824, 0.12230593711137773, 0.09329212664235985, 0.14358422839112822, 0.11587337260284733, 0.14546865146727334, 0.17717839428974738, 0.23870167442627493, 0.07772471440295059, 0.09979632037181048, 0.17930007479604215, 0.15424172183678997, 0.141087164801936, 0.11577841600463276, 0.10860376510648959, 0.07342590394640162, 0.1769666016222008, 0.1573517170524405, 0.3077388368546963, 0.14474123566141053, 0.20754932185574887, 0.13559664329213483, 0.1594577233998045, 0.23198654604775293, 0.2155536076714916, 0.10357263588136244, 0.08265770776497741, 0.145659591221521, 0.10334624923885831, 0.18639529003731667, 0.11915438928671422, 0.14351040815874455, 0.11605962389899839, 0.0889096670453587, 0.22061348051553775, 0.09943255118184513, 0.15409155328187252, 0.19210048470525973, 0.19135920270796747, 0.11224060664854704, 0.13876495312058157, 0.2839646464393985, 0.11197197791789809, 0.18464943694491542, 0.11837428961429866, 0.11895354401560561, 0.1866501521679663, 0.15765087438687203, 0.23446499370038512, 0.2597050627152766, 0.09496173100365747, 0.14831062316173507, 0.10259784262387023, 0.20407350433449592, 0.137432542359156, 0.09194492272311643, 0.18986557640375631, 0.08267846874772541, 0.12245264294887744, 0.15671589471880468, 0.12265713479850562, 0.07585552881561941, 0.09445409050151225, 0.17526792422417672, 0.1103015002163668, 0.08526220752467072, 0.229907076986086, 0.17061672864421723], [0.05152713890457827, 0.04710621403289899, 0.03549655756702827, 0.02705188419279312, 0.04787505221282763, 0.01229103230270407, 0.0494239824042926, 0.011956247091743977, 0.030945941670647556, 0.03479693160061875, 0.011484894259352119, 0.01688549332621117, 0.05255829708109941, 0.011399314577330746, 0.07124555642686545, 0.07783215057345168, 0.09127435064123524, 0.01602893712134251, 0.059394927004412304, 0.012160034140481824, 0.02632743123197748, 0.045764142902748245, 0.016905057296577482, 0.07424161138553774, 0.07579758192502684, 0.027021075966918183, 0.019905867746039745, 0.04010943342901526, 0.07431377686800496, 0.054924784814037626, 0.0353638366645863, 0.07292318938960952, 0.03696420582972708, 0.011024528085404347, 0.06155094740191295, 0.04405323874145266, 0.0070329208017116595, 0.05888133016865581, 0.07550043174095693, 0.07389677222818136, 0.03198640398500908, 0.04004059276813942, 0.030942827523235353, 0.0618235674506474, 0.01930401566618633, 0.04786800037348463, 0.04478626997180043, 0.02240729420596073, 0.056301356713858344, 0.07776756936143484, 0.04139982426779405, 0.03713643388642419, 0.015725969457097592, 0.10789026911821097, 0.0880204611307671, 0.02864636214179618, 0.006349506213389818, 0.03561100727247615, 0.05647396398407798, 0.056255897056431546, 0.06310729715492457, 0.05293710074657875, 0.03580743987714091, 0.06307168555776439, 0.08859236108800096, 0.051954190787528796, 0.017303652843580614, 0.02947869943454862, 0.031511132612884525, 0.0565598386099502, 0.03808727157452414, 0.002694521794065593, 0.039677329196204106, 0.05658842901128435, 0.08383172218717876, 0.02884233892414599, 0.04000433765712284, 0.015635527989586756, 0.012859660106891347, 0.04030213518548877, 0.055094377528275215, 0.013282103013367423, 0.02178401081642557, 0.1260484298390727, 0.03883677752568357, 0.02302861257997011, 0.022979098402204055, 0.02863436903534157, 0.030129054456108043, 0.04076900065786416, 0.04042165639299539, 0.040469571362219514, 0.05051854967830643, 0.0298401492933232, 0.013416019012971271, 0.023265540592312332, 0.039398860066167773, 0.0462620732404532, 0.03180025419550798, 0.02849705926623316, 0.02583640717690991, 0.03648590266464218, 0.029724115701091867, 0.04702739507680939, 0.061788189510304126, 0.03183778484291848, 0.03377104027857704, 0.042363252610929554, 0.02861760320111869, 0.039138010958389896, 0.039744767916178515, 0.010831662577637022, 0.018421285109774723, 0.0312784276602249, 0.056988353720836105, 0.025827248595775138, 0.013242108435670455, 0.03838871185097002, 0.04588138499868013, 0.05562527645980159, 0.031350999169291995, 0.007968967247213568, 0.026636857975033984, 0.03683729187375115, 0.024785895704201637, 0.02907798373921504, 0.010713603640455874, 0.01911792716371917, 0.04875157937227238, 0.05049414211703886, 0.017960580899530364, 0.042837503170895005, 0.04554858874349345, 0.036075160793599584, 0.04700086928243118, 0.040140793238195686, 0.07185470357897782, 0.0268875832308925, 0.020593211407803243, 0.04687023213914326, 0.08041850937109801, 0.04775488749146462, 0.10086502068706098, 0.02373585346034698, 0.02437242847536841, 0.0768371019512415, 0.045788738155557264, 0.040980950373435215, 0.02817509166385618, 0.08185944414787716, 0.07433888156928363, 0.02927445081783639, 0.046663028338263114, 0.06943599546268102, 0.04558574783826067, 0.04550451953564921, 0.03328526392579079, 0.04077261659286676, 0.023816325251133214, 0.014815732513764694, 0.0886526828511588, 0.02137469195370232, 0.053239693985350674, 0.06284957368587775, 0.047875933213940555, 0.02042686499114479, 0.035623957988836115, 0.05012316787014565, 0.0536629154286798, 0.002528916806876359, 0.02501927481423463, 0.024544566516734423, 0.09410517575639872, 0.015605271347017299, 0.0281051344298307, 0.028992532376920985, 0.06789903922547257, 0.034702859833956726, 0.016686919505798047, 0.02599280402665177, 0.037848305768303336, 0.05281068091731399, 0.046358228766269265, 0.059220550071087584, 0.054033625375239126, 0.01639065223806087, 0.04783782800058684, 0.09464571207401254, 0.03813822408236804, 0.022284277722299583, 0.036946264050540426, 0.037891819562402465, 0.027670147791204434, 0.013750462357195155, 0.06354194863008396, 0.048747959606830156, 0.10139519949593853, 0.07822726808127858, 0.0702941288510638, 0.07459012010405142, 0.03242821455182087, 0.013028297126443397, 0.06945538514804456, 0.03151660822632332, 0.04859091541279228, 0.07336025787217003, 0.046976668564903165, 0.08009191076721876, 0.048672453981013074, 0.030361638749919595, 0.026350463665420973, 0.07047375348666984, 0.033667488173852046, 0.035123491900101785, 0.05837855432482977, 0.04131152880408111, 0.02643280854118207, 0.0399621453646931, 0.021280499528192227, 0.032394242382818655, 0.0394269103755153, 0.05858675404001148, 0.017029293775258046, 0.03600419806917349, 0.06533054559822045, 0.022360922903904033, 0.08505691128272204, 0.022553852571535016, 0.006053810159961183, 0.024384320075173053, 0.05544928308095663, 0.016629252237297835, 0.06744176134346955, 0.10583100945598657, 0.007571963726678082, 0.03686728421598673, 0.061741174694391034, 0.023627909756596052, 0.011440987845191793, 0.07018650881946087, 0.041395354144755876, 0.04532883259197397, 0.03797435404492482, 0.023311293278370174, 0.07880362667023175, 0.014114628955271217, 0.06380376683908605, 0.025386006849247123, 0.01153195216771095, 0.04365516796467766, 0.04974251027188955, 0.027434683006797588, 0.017708229622052565, 0.08929878608473847, 0.024248398840427402, 0.07783627978736356, 0.03803498224325238, 0.038293824200668646, 0.05463166042200981, 0.08698118625268822, 0.06206404628051866, 0.006985915083092668, 0.035195320303882324, 0.04190950639425747, 0.022472394442546274, 0.05781755579875843, 0.03062594291423598, 0.03540789821155129, 0.04136079208805196, 0.10394341477583494, 0.02150702215130291, 0.002606694122791411, 0.014251516418411367, 0.08159174238361659, 0.009672197122727672, 0.022498763188900008, 0.06787427160288058, 0.03909859573468566, 0.0310861032020541, 0.014391560163799555, 0.06300256144435656, 0.05417614071179302, 0.0366924399690282, 0.0768880008329307, 0.03456340118822071, 0.03446813432439681, 0.06195569463494805, 0.021603765649600856, 0.07991171922654876, 0.08263203615863478, 0.037774941358234615, 0.007005060577930342, 0.021916745125406215, 0.023827008347237305, 0.04046002207624336, 0.010574324067772157, 0.052328114472930475, 0.023116400510433222, 0.02340360495802616, 0.1141071415716602, 0.018327642352350296, 0.06464547147193263, 0.0321512048192803, 0.03314803842635405, 0.03628291617778521, 0.038998575295291604, 0.05952839484258045, 0.04102099761967698, 0.052234705372322957, 0.02324117133544097, 0.0869384998335473, 0.02048436563552147, 0.06341093610371314, 0.048267534378195004, 0.018325577745394363, 0.059097485706931165, 0.021472350927069787, 0.017952255439013243, 0.021789769882396347, 0.01960957941088465, 0.004280726951096327, 0.12569871070163866, 0.0135234973183082, 0.03734868620672534, 0.03936689121708755, 0.05751402410227926, 0.015081150378401001, 0.04038589157825036, 0.017977419512106046, 0.038202755498669805, 0.015128783810312952, 0.02226370826153265, 0.03392380204111819, 0.019100807013831312, 0.06939388360948333, 0.031001287692737196, 0.10267705611524083, 0.03518899241762777, 0.038246709793325395, 0.05805648713102264, 0.021144603191304113, 0.07118198645090865, 0.033035599701707406, 0.10400588924606001, 0.09977580453719824, 0.05642758119070242, 0.0032035510699760412, 0.04086853846186592, 0.03409710262090929, 0.021115570374193694, 0.04553878664850228, 0.010695961593169599, 0.12903471717671042, 0.10416594033520069, 0.10448785048098334, 0.05170362257969476, 0.22696946687515707, 0.17517207130309076, 0.16621293349852487, 0.09720325830482668, 0.14151108721571584, 0.13509928368993346, 0.20225773805812483, 0.1975177682094997, 0.15691650250265676, 0.24534618481993678, 0.16336166149666234, 0.1438742692792608, 0.17434797520118375, 0.17928547316020538, 0.16564886295987716, 0.1556596586540822, 0.16023256004818026, 0.18682356383050644, 0.07258120774021072, 0.17334649910128888, 0.07856808527703248, 0.1497023904155339, 0.11747209850939051, 0.2328776135560005, 0.16427690673980022, 0.26647963951672277, 0.11330910012005799, 0.22261513036585626, 0.14210573998430084, 0.11856994847015989, 0.19881028111182875, 0.09918250774423923, 0.08037234491278088, 0.22371841955088803, 0.19638699178974475, 0.1520989432690605, 0.1440649638853727, 0.14220402906498603, 0.12916774068388248, 0.19042904939382307, 0.12830718645765898, 0.13447119884433287, 0.13709958522550522, 0.07968550112338797, 0.1839415257376048, 0.18308142350325662, 0.11480173050996759, 0.11349763435822342, 0.09876155009072635, 0.16414837250786443, 0.13859624523789654, 0.06725898808649472, 0.1968830030771994, 0.20596298359094128, 0.10811614248180583, 0.1377915771257493, 0.12902907876958772, 0.16426350020112532, 0.09963752566686562, 0.17513021225890807, 0.27767941596046575, 0.1490415476502911, 0.08586953904840254, 0.12510201247829583, 0.14834715023396478, 0.15727507761649548, 0.16575441455408452, 0.09621558710932733, 0.11800092900352133, 0.14252204748411335, 0.26664214208722115, 0.20127752855900796, 0.17670813887830705, 0.22596085083580789, 0.13171657649499754, 0.18649308882173032, 0.1459769661267919, 0.12729732169499322, 0.18385687302197182, 0.2468623953961557, 0.18343262885126377, 0.1626185102448348, 0.16126860203521867, 0.11320786160086432, 0.16096019035866185, 0.19492315098402963, 0.10632753402235047, 0.12193418528524139, 0.17306064105322286, 0.21127678393836946, 0.10931122432192487, 0.1543294235823616, 0.12565013306636003, 0.17287820487493472, 0.0821141300783042, 0.15983434754513925, 0.12337784733503096, 0.15516418362817458, 0.16919588069281272, 0.19295295670388207, 0.1924705051726872, 0.1635531221906985, 0.1633491282982211, 0.16870895520814005, 0.12235230841343442, 0.1313321688963521, 0.10787595093490616, 0.07408203527091012, 0.1549085247660837, 0.14110735887962003, 0.0979720045542044, 0.19579160357675246, 0.07590511002607885, 0.12637876695202244, 0.14385395262750889, 0.13839586728042172, 0.1622853845718407, 0.14166758365688786, 0.21341274432357282, 0.1490388510207976, 0.10670714591058994, 0.20281463801380128, 0.11724526753589032, 0.14511386082778055, 0.132608333482377, 0.14575575057777668, 0.1584773300395858, 0.1437099740630196, 0.17340539594090756, 0.12393336067156446, 0.1763193492567347, 0.10653179604560138, 0.190994514212493, 0.15973820351064205, 0.15447727855174773, 0.09972268400052864, 0.12082380212603078, 0.15359906599886958, 0.1776373422434253, 0.06113780767566735, 0.13876639336587923, 0.21923927199696341, 0.161912422326784, 0.09133180723555627, 0.1334186706451639, 0.151583090304367, 0.17305224472957273, 0.16606500192034632, 0.11498854105030337, 0.1350914389495888, 0.12230312556869562, 0.1454204338933191, 0.07534566665849379, 0.17686181611591772, 0.1344613469536266, 0.10850752914144147, 0.20017004121215115, 0.22183205061141523, 0.15665724302732176, 0.19310574527950058, 0.135025248952931, 0.26929412397646135, 0.09382130187605658, 0.3060636170689137, 0.14949036792161005, 0.22503926238465696, 0.1471263278395899, 0.11699495596751092, 0.22768839442681885, 0.1358402745738145, 0.1735535573454634, 0.12358648372032952]]}],                        {\"autosize\": false, \"font\": {\"family\": \"Courier New, monospace\", \"size\": 14}, \"height\": 500, \"margin\": {\"b\": 60, \"l\": 50, \"r\": 50, \"t\": 35}, \"showlegend\": false, \"sliders\": [{\"active\": 0, \"currentvalue\": {\"prefix\": \"Current slice is: <b>\"}, \"pad\": {\"b\": 10, \"t\": 50}, \"steps\": [{\"args\": [\"visible\", [true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"4\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"5\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"6\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"7\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"8\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"9\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"10\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"11\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"12\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"13\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"14\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"15\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"16\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"17\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"18\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"19\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"20\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"21\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"22\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"23\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false]], \"label\": \"24\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false]], \"label\": \"25\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false]], \"label\": \"26\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false]], \"label\": \"27\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false]], \"label\": \"28\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false]], \"label\": \"29\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false]], \"label\": \"30\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false]], \"label\": \"31\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false]], \"label\": \"32\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false]], \"label\": \"33\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]], \"label\": \"34\", \"method\": \"restyle\"}]}], \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"autotypenumbers\": \"strict\", \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Echo1\\t\\t\\tEcho2\\t\\t\\tEcho3\"}, \"width\": 800, \"xaxis\": {\"showgrid\": false, \"showticklabels\": false}, \"yaxis\": {\"showgrid\": false, \"showticklabels\": false}},                        {\"displayModeBar\": false, \"responsive\": true}                    )                };                            </script>        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "n=35\n",
    "\n",
    "layers = []\n",
    "for path in raw_images_path:\n",
    "    layers.append(load_image(path))\n",
    "\n",
    "# for layer in layers:\n",
    "#     tmp1=[]\n",
    "#     tmp2=[]\n",
    "#     for array in layer:\n",
    "#         for a in array:\n",
    "#             tmp1.append(max(a))\n",
    "#             tmp2.append(min(a))\n",
    "#     print(max(tmp1))\n",
    "#     print(min(tmp2))\n",
    "\n",
    "mapp_layers = []\n",
    "mapp_layer=[]\n",
    "n=n-1\n",
    "for i in range(n+1):\n",
    "    mapp_layer.append(mapp(layers[0][i],[0,31],[0,255]))\n",
    "mapp_layers.append(mapp_layer)\n",
    "\n",
    "mapp_layer=[]\n",
    "for i in range(n+1):\n",
    "     mapp_layer.append(mapp(layers[1][i],[0,31],[0,255]))\n",
    "mapp_layers.append(mapp_layer)\n",
    "\n",
    "mapp_layer=[]\n",
    "for i in range(n+1):\n",
    "     mapp_layer.append(mapp(layers[2][i],[0,31],[0,255]))\n",
    "mapp_layers.append(mapp_layer)\n",
    "\n",
    "compare_scans(mapp_layers,n,\"fig32.html\")\n",
    "display(HTML('fig32.html'))"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Edit Metadata",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.4"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
